--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: area; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE area (
    id integer NOT NULL,
    name character varying,
    district_id integer,
    bounds_left double precision,
    bounds_right double precision,
    bounds_top double precision,
    bounds_bottom double precision,
    box geometry,
    CONSTRAINT enforce_dims_box CHECK ((st_ndims(box) = 2)),
    CONSTRAINT enforce_geotype_box CHECK (((geometrytype(box) = 'POLYGON'::text) OR (box IS NULL))),
    CONSTRAINT enforce_srid_box CHECK ((st_srid(box) = 4326))
);


--
-- Name: area_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE area_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: area_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE area_id_seq OWNED BY area.id;


--
-- Name: area_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('area_id_seq', 1, false);


--
-- Name: district; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE district (
    id integer NOT NULL,
    name character varying
);


--
-- Name: district_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE district_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: district_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE district_id_seq OWNED BY district.id;


--
-- Name: district_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('district_id_seq', 1, false);


--
-- Name: locality; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE locality (
    id integer NOT NULL,
    name character varying,
    district_id integer,
    area_id integer,
    sub_area_id integer,
    bounds_left double precision,
    bounds_right double precision,
    bounds_top double precision,
    bounds_bottom double precision,
    box geometry,
    CONSTRAINT enforce_dims_box CHECK ((st_ndims(box) = 2)),
    CONSTRAINT enforce_geotype_box CHECK (((geometrytype(box) = 'POLYGON'::text) OR (box IS NULL))),
    CONSTRAINT enforce_srid_box CHECK ((st_srid(box) = 4326))
);


--
-- Name: locality_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE locality_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: locality_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE locality_id_seq OWNED BY locality.id;


--
-- Name: locality_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('locality_id_seq', 1, false);


--
-- Name: location; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE location (
    id integer NOT NULL,
    district_id integer,
    area_id integer,
    sub_area_id integer,
    locality_id integer,
    street_id integer,
    lon double precision,
    lat double precision,
    raw_address character varying,
    address character varying,
    point geometry,
    CONSTRAINT enforce_dims_point CHECK ((st_ndims(point) = 2)),
    CONSTRAINT enforce_geotype_point CHECK (((geometrytype(point) = 'POINT'::text) OR (point IS NULL))),
    CONSTRAINT enforce_srid_point CHECK ((st_srid(point) = 4326))
);


--
-- Name: location_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE location_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: location_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE location_id_seq OWNED BY location.id;


--
-- Name: location_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('location_id_seq', 1, false);


--
-- Name: street; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE street (
    id integer NOT NULL,
    locality_id integer,
    bounds_left double precision,
    bounds_right double precision,
    bounds_top double precision,
    bounds_bottom double precision,
    name character varying,
    box geometry,
    CONSTRAINT enforce_dims_box CHECK ((st_ndims(box) = 2)),
    CONSTRAINT enforce_geotype_box CHECK (((geometrytype(box) = 'POLYGON'::text) OR (box IS NULL))),
    CONSTRAINT enforce_srid_box CHECK ((st_srid(box) = 4326))
);


--
-- Name: street_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE street_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: street_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE street_id_seq OWNED BY street.id;


--
-- Name: street_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('street_id_seq', 1, false);


--
-- Name: sub_area; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE sub_area (
    id integer NOT NULL,
    name character varying,
    district_id integer,
    area_id integer,
    bounds_left double precision,
    bounds_right double precision,
    bounds_top double precision,
    bounds_bottom double precision,
    box geometry,
    CONSTRAINT enforce_dims_box CHECK ((st_ndims(box) = 2)),
    CONSTRAINT enforce_geotype_box CHECK (((geometrytype(box) = 'POLYGON'::text) OR (box IS NULL))),
    CONSTRAINT enforce_srid_box CHECK ((st_srid(box) = 4326))
);


--
-- Name: sub_area_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sub_area_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: sub_area_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE sub_area_id_seq OWNED BY sub_area.id;


--
-- Name: sub_area_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sub_area_id_seq', 1, false);


--
-- Name: voting_station; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE voting_station (
    id integer NOT NULL,
    location_id integer,
    name character varying,
    address character varying,
    is_standalone boolean,
    size character varying
);


--
-- Name: voting_station_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE voting_station_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: voting_station_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE voting_station_id_seq OWNED BY voting_station.id;


--
-- Name: voting_station_id_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('voting_station_id_seq', 1, false);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE area ALTER COLUMN id SET DEFAULT nextval('area_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE district ALTER COLUMN id SET DEFAULT nextval('district_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE locality ALTER COLUMN id SET DEFAULT nextval('locality_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE location ALTER COLUMN id SET DEFAULT nextval('location_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE street ALTER COLUMN id SET DEFAULT nextval('street_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE sub_area ALTER COLUMN id SET DEFAULT nextval('sub_area_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE voting_station ALTER COLUMN id SET DEFAULT nextval('voting_station_id_seq'::regclass);


--
-- Data for Name: area; Type: TABLE DATA; Schema: public; Owner: -
--

COPY area (id, name, district_id, bounds_left, bounds_right, bounds_top, bounds_bottom, box) FROM stdin;
19	республика Калмыкия	2	41.635511999999999	47.603271999999997	48.272267999999997	44.760078	0103000020E61000000100000005000000971B0C7558D144405D34643C4A614640971B0C7558D14440A8DF85ADD9224840D74B530438CD4740A8DF85ADD9224840D74B530438CD47405D34643C4A614640971B0C7558D144405D34643C4A614640
18	республика Адыгея	2	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
23	Ростовская область	2	38.221195000000002	44.325786999999998	50.214013000000001	45.951694000000003	0103000020E61000000100000005000000F584251E501C434054E6E61BD1F94640F584251E501C43409DF529C7641B4940213B6F63B32946409DF529C7641B4940213B6F63B329464054E6E61BD1F94640F584251E501C434054E6E61BD1F94640
20	Краснодарский край	2	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
22	Волгоградская область	2	41.131593000000002	47.432187999999996	51.247875000000001	47.444153999999997	0103000020E61000000100000005000000F7B0170AD89044409C31CC09DAB84740F7B0170AD89044407D3F355EBA9F4940A0DCB6EF51B747407D3F355EBA9F4940A0DCB6EF51B747409C31CC09DAB84740F7B0170AD89044409C31CC09DAB84740
21	Астраханская область	2	44.971918000000002	49.582915999999997	48.863947000000003	45.335656999999998	0103000020E6100000010000000500000066321CCF677C464034D6FECEF6AA464066321CCF677C4640193DB7D0956E48405628D2FD9CCA4840193DB7D0956E48405628D2FD9CCA484034D6FECEF6AA464066321CCF677C464034D6FECEF6AA4640
17	Ярославская область	1	37.329402000000002	41.194088999999998	58.952478999999997	56.534638999999999	0103000020E61000000100000005000000569E40D829AA42404415FE0C6F444C40569E40D829AA42403A90F5D4EA794D40B5C189E8D79844403A90F5D4EA794D40B5C189E8D79844404415FE0C6F444C40569E40D829AA42404415FE0C6F444C40
16	Тульская область	1	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
15	Тверская область	1	30.770676000000002	38.326999000000001	58.863194	55.631483000000003	0103000020E61000000100000005000000E6CFB7054BC53E40707D586FD4D04B40E6CFB7054BC53E403D0D18247D6E4D4090696D1ADB2943403D0D18247D6E4D4090696D1ADB294340707D586FD4D04B40E6CFB7054BC53E40707D586FD4D04B40
14	Тамбовская область	1	39.918176000000003	43.245437000000003	53.823079999999997	51.589821999999998	0103000020E610000001000000050000006EFC89CA86F543400C3B8C497FCB49406EFC89CA86F54340EFFE78AF5AE94A403B1DC87A6A9F4540EFFE78AF5AE94A403B1DC87A6A9F45400C3B8C497FCB49406EFC89CA86F543400C3B8C497FCB4940
13	Смоленская область	1	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
12	Рязанская область	1	38.658665999999997	42.692146000000001	55.363284	53.308596000000001	0103000020E610000001000000050000005A7EE02A4F54434095D6DF1280A74A405A7EE02A4F5443407D94111780AE4B405307793D985845407D94111780AE4B405307793D9858454095D6DF1280A74A405A7EE02A4F54434095D6DF1280A74A40
11	Орловская область	1	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
10	Московская область	1	35.144106000000001	40.204334000000003	56.961320000000001	54.256076	0103000020E610000001000000050000002594BE10729241402FA52E19C7204B402594BE1072924140D07EA4880C7B4C40FEBAD39D271A4440D07EA4880C7B4C40FEBAD39D271A44402FA52E19C7204B402594BE10729241402FA52E19C7204B40
9	Липецкая область	1	37.722244000000003	40.763570999999999	53.587829999999997	51.887303000000003	0103000020E61000000100000005000000BADDCB7D72DC424044520B2593F14940BADDCB7D72DC4240C8CD70033ECB4A404696CCB1BC614440C8CD70033ECB4A404696CCB1BC61444044520B2593F14940BADDCB7D72DC424044520B2593F14940
8	Курская область	1	34.081434999999999	38.518420999999996	52.444595999999997	50.903858	0103000020E61000000100000005000000F8DF4A766C0A41402E1D739EB1734940F8DF4A766C0A414059F78F85E8384A40A1478C9E5B42434059F78F85E8384A40A1478C9E5B4243402E1D739EB1734940F8DF4A766C0A41402E1D739EB1734940
7	Костромская область	1	39.998198000000002	47.644737999999997	59.625143999999999	57.185422000000003	0103000020E610000001000000050000006077BAF3C4FF4340BEFA78E8BB974C406077BAF3C4FF434033A5F5B704D04D40853E58C686D2474033A5F5B704D04D40853E58C686D24740BEFA78E8BB974C406077BAF3C4FF4340BEFA78E8BB974C40
6	Калужская область	1	33.443434000000003	37.275906999999997	55.341996999999999	53.276775000000001	0103000020E610000001000000050000009DF7FF71C2B84040DAACFA5C6DA34A409DF7FF71C2B84040412AC58EC6AB4B4065DEAAEB50A34240412AC58EC6AB4B4065DEAAEB50A34240DAACFA5C6DA34A409DF7FF71C2B84040DAACFA5C6DA34A40
5	Ивановская область	1	39.376123	43.324883999999997	57.739004000000001	56.350422000000002	0103000020E61000000100000005000000FF2268CC24B0434043E6CAA0DA2C4C40FF2268CC24B043407DCEDDAE97DE4C40307F85CC95A945407DCEDDAE97DE4C40307F85CC95A9454043E6CAA0DA2C4C40FF2268CC24B0434043E6CAA0DA2C4C40
4	Воронежская область	1	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
3	Владимирская область	1	38.276963000000002	42.972842999999997	56.810733999999997	55.104182000000002	0103000020E61000000100000005000000DD990986732343407B6AF5D5558D4B40DD99098673234340ACE0B721C6674C403E92921E867C4540ACE0B721C6674C403E92921E867C45407B6AF5D5558D4B40DD990986732343407B6AF5D5558D4B40
2	Брянская область	1	31.259520999999999	35.325978999999997	54.034362999999999	51.843729000000003	0103000020E610000001000000050000000EA0DFF76F423F40E9D7D64FFFEB49400EA0DFF76F423F40A298BC0166044B4065170CAEB9A94140A298BC0166044B4065170CAEB9A94140E9D7D64FFFEB49400EA0DFF76F423F40E9D7D64FFFEB4940
1	Белгородская область	1	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33	Ямало-Ненецкий автономный округ	6	62.001389000000003	86.014298999999994	73.524799999999999	62.203499999999998	0103000020E610000001000000050000007EC9C6832D004F40355EBA490C1A4F407EC9C6832D004F40363CBD529661524064575A46EA805540363CBD529661524064575A46EA805540355EBA490C1A4F407EC9C6832D004F40355EBA490C1A4F40
58	Челябинская область	6	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
59	Ханты-Мансийский автономный округ	6	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
57	Тюменская область	6	64.827461	75.199634000000003	59.989877	55.146110999999998	0103000020E61000000100000005000000CA6DFB1EF5345040FD4AE7C3B3924B40CA6DFB1EF534504003081F4AB4FE4D40DC4AAFCDC6CC524003081F4AB4FE4D40DC4AAFCDC6CC5240FD4AE7C3B3924B40CA6DFB1EF5345040FD4AE7C3B3924B40
56	Свердловская область	6	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
55	Курганская область	6	61.966821000000003	68.723859000000004	56.843043000000002	54.187348	0103000020E61000000100000005000000030B60CAC0FB4E404A7CEE04FB174B40030B60CAC0FB4E40950F41D5E86B4C4094FAB2B4532E5140950F41D5E86B4C4094FAB2B4532E51404A7CEE04FB174B40030B60CAC0FB4E404A7CEE04FB174B40
54	Томская область	5	75.382441	89.378902999999994	58.000521999999997	55.664318999999999	0103000020E6100000010000000500000092E9D0E979D85240438EAD6708D54B4092E9D0E979D85240D976DA1A11004D40CD565EF23F585640D976DA1A11004D40CD565EF23F585640438EAD6708D54B4092E9D0E979D85240438EAD6708D54B40
46	Республика Хакасия	5	87.856572999999997	91.936092000000002	55.437260000000002	51.284191	0103000020E61000000100000005000000BE688F17D2F65540A568E55E60A44940BE688F17D2F65540ABECBB22F8B74B4006836BEEE8FB5640ABECBB22F8B74B4006836BEEE8FB5640A568E55E60A44940BE688F17D2F65540A568E55E60A44940
45	Республика Тыва	5	88.791809000000001	99.273622000000003	53.729601000000002	49.743535000000001	0103000020E610000001000000050000006CEBA7FFAC3256403737A6272CDF48406CEBA7FFAC3256408010C99063DD4A40D55DD90583D158408010C99063DD4A40D55DD90583D158403737A6272CDF48406CEBA7FFAC3256403737A6272CDF4840
44	Республика Бурятия	5	98.629555999999994	116.921699	57.249796000000003	49.960414999999998	0103000020E6100000010000000500000009C03FA54AA858403ECBF3E0EEFA484009C03FA54AA85840F855B950F99F4C406170CD1DFD3A5D40F855B950F99F4C406170CD1DFD3A5D403ECBF3E0EEFA484009C03FA54AA858403ECBF3E0EEFA4840
43	Республика Алтай	5	83.925715999999994	89.865870999999999	52.660009000000002	49.070692999999999	0103000020E61000000100000005000000925852EE3EFB54402F87DD770C894840925852EE3EFB54406808C72C7B544A4082E3326E6A7756406808C72C7B544A4082E3326E6A7756402F87DD770C894840925852EE3EFB54402F87DD770C894840
53	Омская область	5	70.357275000000001	76.305946000000006	58.575800999999998	53.435012999999998	0103000020E610000001000000050000006B2BF697DD965140DC2A8881AEB74A406B2BF697DD9651408600E0D8B3494D40E415889E941353408600E0D8B3494D40E415889E94135340DC2A8881AEB74A406B2BF697DD965140DC2A8881AEB74A40
52	Новосибирская область	5	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
49	Красноярский край	5	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51	Кемеровская область	5	84.452399	89.402564999999996	56.832393000000003	52.162630999999998	0103000020E610000001000000050000008F6FEF1AF41C55406B28B517D1144A408F6FEF1AF41C5540AD3594DA8B6A4C40E960FD9FC3595640AD3594DA8B6A4C40E960FD9FC35956406B28B517D1144A408F6FEF1AF41C55406B28B517D1144A40
50	Иркутская область	5	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
48	Забайкальский край	5	107.734359	122.14574399999999	58.438729000000002	49.154963000000002	0103000020E610000001000000050000007D21E4BCFFEE5A40878BDCD3D59348407D21E4BCFFEE5A404567994528384D40A565A4DE53895E404567994528384D40A565A4DE53895E40878BDCD3D59348407D21E4BCFFEE5A40878BDCD3D5934840
47	Алтайский край	5	77.893394000000001	87.162893999999994	54.452229000000003	50.639975999999997	0103000020E61000000100000005000000541C075E2D795340C91CCBBBEA514940541C075E2D795340C2A6CEA3E2394B40BCADF4DA6CCA5540C2A6CEA3E2394B40BCADF4DA6CCA5540C91CCBBBEA514940541C075E2D795340C91CCBBBEA514940
80	республика Чеченская	8	44.833398000000003	46.660426999999999	44.009798000000004	42.475405000000002	0103000020E61000000100000005000000A24621C9AC6A46406DAD2F12DA3C4540A24621C9AC6A46407AC8940F410146409C3237DF885447407AC8940F410146409C3237DF885447406DAD2F12DA3C4540A24621C9AC6A46406DAD2F12DA3C4540
79	республика Северная Осетия-Алания	8	43.397700999999998	44.957608	43.836956999999998	42.547142999999998	0103000020E61000000100000005000000124BCADDE7B245401F9E25C808464540124BCADDE7B2454042942F6821EB4540A93121E6927A464042942F6821EB4540A93121E6927A46401F9E25C808464540124BCADDE7B245401F9E25C808464540
78	республика Карачаево-Черкесская	8	40.676147	42.680280000000003	44.499535999999999	43.187351999999997	0103000020E61000000100000005000000EE2422FC8B5644408B6B7C26FB974540EE2422FC8B5644405B96AFCBF03F4640BB0F406A135745405B96AFCBF03F4640BB0F406A135745408B6B7C26FB974540EE2422FC8B5644408B6B7C26FB974540
77	республика Кабардино-Балкарская	8	42.398083	44.475527	44.020572000000001	42.888719000000002	0103000020E61000000100000005000000FA0B3D62F4324540BB2A508BC1714540FA0B3D62F43245404E9B711AA2024640B8AE9811DE3C46404E9B711AA2024640B8AE9811DE3C4640BB2A508BC1714540FA0B3D62F4324540BB2A508BC1714540
76	республика Ингушская	8	44.477305000000001	45.293892	43.615417999999998	42.614910999999999	0103000020E61000000100000005000000D09B8A54183D4640AF795567B54E4540D09B8A54183D464053AF5B04C6CE45402C47C8409EA5464053AF5B04C6CE45402C47C8409EA54640AF795567B54E4540D09B8A54183D4640AF795567B54E4540
75	республика Дагестан	8	45.103879999999997	48.591796000000002	44.992620000000002	41.185778999999997	0103000020E61000000100000005000000AF5A99F04B8D46404CA4349BC7974440AF5A99F04B8D464082AD122C0E7F4640AAF3A8F8BF4B484082AD122C0E7F4640AAF3A8F8BF4B48404CA4349BC7974440AF5A99F04B8D46404CA4349BC7974440
81	Ставропольский край	8	40.844149999999999	45.716701999999998	46.236933000000001	43.658575999999996	0103000020E610000001000000050000008E75711B0D6C44401AF7E6374CD445408E75711B0D6C4440ED2B0FD2531E4740287D21E4BCDB4640ED2B0FD2531E4740287D21E4BCDB46401AF7E6374CD445408E75711B0D6C44401AF7E6374CD44540
25	республика Коми	3	45.399965000000002	66.253608999999997	68.423252000000005	59.198726000000001	0103000020E61000000100000005000000B745990D32B34640B56E83DA6F994D40B745990D32B34640DD7D8E8F161B5140293E3E213B905040DD7D8E8F161B5140293E3E213B905040B56E83DA6F994D40B745990D32B34640B56E83DA6F994D40
24	республика Карелия	3	29.308129000000001	37.945870999999997	66.668670000000006	60.679619000000002	0103000020E61000000100000005000000FEF2C98AE14E3D40C05E61C1FD564E40FEF2C98AE14E3D403F74417DCBAA50400E9E094D12F942403F74417DCBAA50400E9E094D12F94240C05E61C1FD564E40FEF2C98AE14E3D40C05E61C1FD564E40
32	Псковская область	3	27.325196999999999	31.517040999999999	59.021518999999998	55.589731999999998	0103000020E61000000100000005000000DFC14F1C40533B40CCB392567CCB4B40DFC14F1C40533B400E9F7422C1824D40EEB089CC5C843F400E9F7422C1824D40EEB089CC5C843F40CCB392567CCB4B40DFC14F1C40533B40CCB392567CCB4B40
31	Новгородская область	3	29.619834999999998	36.229064000000001	59.434798000000001	56.910355000000003	0103000020E6100000010000000500000089EAAD81AD9E3D4003603C8386744C4089EAAD81AD9E3D40E02EFB75A7B74D4071581AF8511D4240E02EFB75A7B74D4071581AF8511D424003603C8386744C4089EAAD81AD9E3D4003603C8386744C40
60	Ненецкий автономный округ	3	43.266871000000002	65.672865999999999	69.865477999999996	65.820004999999995	0103000020E610000001000000050000001BA034D428A245409D6340F67A7450401BA034D428A24540145AD6FD63775140C8258E3C106B5040145AD6FD63775140C8258E3C106B50409D6340F67A7450401BA034D428A245409D6340F67A745040
30	Мурманская область	3	28.417090000000002	41.406135999999996	69.953256999999994	66.054203999999999	0103000020E61000000100000005000000187D0569C66A3C40FED30D1478835040187D0569C66A3C40B7EBA529027D514037DDB243FCB34440B7EBA529027D514037DDB243FCB34440FED30D1478835040187D0569C66A3C40FED30D1478835040
29	Ленинградская область	3	26.580233	35.967061999999999	61.330865000000003	58.417071999999997	0103000020E610000001000000050000005A0F5F268A943A40E509849D62354D405A0F5F268A943A400E32C9C859AA4E40289A07B0C8FB41400E32C9C859AA4E40289A07B0C8FB4140E509849D62354D405A0F5F268A943A40E509849D62354D40
28	Калининградская область	3	19.639102999999999	22.887384999999998	55.294432	54.318204000000001	0103000020E6100000010000000500000086C613419CA333406BBA9EE8BA284B4086C613419CA33340AC72A1F2AFA54B4001F6D1A92BE33640AC72A1F2AFA54B4001F6D1A92BE336406BBA9EE8BA284B4086C613419CA333406BBA9EE8BA284B40
27	Вологодская область	3	34.721080000000001	47.156368999999998	61.604494000000003	58.477536000000001	0103000020E610000001000000050000005CE674594C5C4140D2544FE61F3D4D405CE674594C5C41406A50340F60CD4E40DA8D3EE6039447406A50340F60CD4E40DA8D3EE603944740D2544FE61F3D4D405CE674594C5C4140D2544FE61F3D4D40
26	Архангельская область	3	35.502282000000001	50.502405000000003	66.777968000000001	60.636313999999999	0103000020E610000001000000050000004BAFCDC64AC0414054FEB5BC72514E404BAFCDC64AC0414069554B3ACAB15040672C9ACE4E40494069554B3ACAB15040672C9ACE4E40494054FEB5BC72514E404BAFCDC64AC0414054FEB5BC72514E40
66	республика Чувашская	7	45.911223	48.420648999999997	56.314765999999999	54.632212000000003	0103000020E61000000100000005000000772E8CF4A2F44640C311A452EC504B40772E8CF4A2F4464045F295404A284C402C0C91D3D735484045F295404A284C402C0C91D3D7354840C311A452EC504B40772E8CF4A2F44640C311A452EC504B40
65	республика Удмуртская	7	51.124830000000003	54.434052000000001	58.545209	55.856203999999998	0103000020E61000000100000005000000A4C7EF6DFA8F4940295AB91798ED4B40A4C7EF6DFA8F4940103E9468C9454D40B76114048F374B40103E9468C9454D40B76114048F374B40295AB91798ED4B40A4C7EF6DFA8F4940295AB91798ED4B40
64	республика Татарстан	7	47.257779999999997	54.268591999999998	56.675643000000001	53.974775999999999	0103000020E610000001000000050000000CC85EEFFEA047407D76C075C5FC4A400CC85EEFFEA04740BB6246787B564C40CEFBFF3861224B40BB6246787B564C40CEFBFF3861224B407D76C075C5FC4A400CC85EEFFEA047407D76C075C5FC4A40
63	республика Мордовия	7	42.164313999999997	46.730441999999996	55.190255999999998	53.644064	0103000020E610000001000000050000003123BC3D08154540F6436CB070D24A403123BC3D0815454013EF004F5A984B40FACF9A1F7F5D474013EF004F5A984B40FACF9A1F7F5D4740F6436CB070D24A403123BC3D08154540F6436CB070D24A40
62	республика Марий Эл	7	45.626556000000001	50.202807999999997	57.343263999999998	55.828344000000001	0103000020E61000000100000005000000698EACFC32D046403EEB1A2D07EA4B40698EACFC32D0464073F22213F0AB4C40FFAECF9CF519494073F22213F0AB4C40FFAECF9CF51949403EEB1A2D07EA4B40698EACFC32D046403EEB1A2D07EA4B40
61	республика Башкортостан	7	53.157313000000002	59.997571000000001	56.533661000000002	51.572012999999998	0103000020E610000001000000050000002A1E17D522944A4084F1D3B837C949402A1E17D522944A404913EF004F444C4011381268B0FF4D404913EF004F444C4011381268B0FF4D4084F1D3B837C949402A1E17D522944A4084F1D3B837C94940
74	Ульяновская область	7	45.796517000000001	50.243626999999996	54.890044000000003	52.532910000000001	0103000020E61000000100000005000000A1DAE044F4E546400EDB166536444A40A1DAE044F4E54640220038F6EC714B4017B6662B2F1F4940220038F6EC714B4017B6662B2F1F49400EDB166536444A40A1DAE044F4E546400EDB166536444A40
73	Саратовская область	7	42.501936999999998	50.833129	52.818674000000001	49.801195999999997	0103000020E6100000010000000500000080D3BB783F404540CFD72C978DE6484080D3BB783F404540F20A444FCA684A40B22C98F8A36A4940F20A444FCA684A40B22C98F8A36A4940CFD72C978DE6484080D3BB783F404540CFD72C978DE64840
72	Самарская область	7	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
71	Пермский край	7	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
70	Пензенская область	7	42.082307	46.981171000000003	54.029561000000001	52.291775000000001	0103000020E61000000100000005000000AE9D2809890A45402C6519E258254A40AE9D2809890A4540581EA4A7C8034B404E64E602977D4740581EA4A7C8034B404E64E602977D47402C6519E258254A40AE9D2809890A45402C6519E258254A40
69	Оренбургская область	7	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
68	Нижегородская область	7	41.776566000000003	47.770995999999997	58.091237	54.461975000000002	0103000020E61000000100000005000000C097C28366E34440E9482EFF213B4B40C097C28366E34440B3976DA7AD0B4D4064AC36FFAFE24740B3976DA7AD0B4D4064AC36FFAFE24740E9482EFF213B4B40C097C28366E34440E9482EFF213B4B40
67	Кировская область	7	46.262419999999999	53.931992999999999	61.065370999999999	56.058951	0103000020E610000001000000050000007DE882FA962147408388D4B48B074C407DE882FA96214740AC8DB1135E884E40EB8CEF8B4BF74A40AC8DB1135E884E40EB8CEF8B4BF74A408388D4B48B074C407DE882FA962147408388D4B48B074C40
42	Чукотский автономный округ	4	157.72459900000001	190.343693	71.612297999999996	61.808397999999997	0103000020E61000000100000005000000DCF63DEA2FB763406E13EE9579E74E40DCF63DEA2FB76340FF59F3E32FE75140A75B7688FFCA6740FF59F3E32FE75140A75B7688FFCA67406E13EE9579E74E40DCF63DEA2FB763406E13EE9579E74E40
37	Хабаровский край	4	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
40	Сахалинская область	4	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
34	Республика Саха (Якутия)	4	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
36	Приморский край	4	130.59105700000001	139.01091299999999	48.459895000000003	42.293455999999999	0103000020E610000001000000050000004DA25EF0E9526040516859F78F2545404DA25EF0E9526040064CE0D6DD3A48403D43386659606140064CE0D6DD3A48403D43386659606140516859F78F2545404DA25EF0E9526040516859F78F254540
39	Магаданская область	4	144.72429700000001	163.483698	66.340896999999998	58.834000000000003	0103000020E61000000100000005000000E9F2E6702D176240986E1283C06A4D40E9F2E6702D1762407D93A641D195504080643A747A6F64407D93A641D195504080643A747A6F6440986E1283C06A4D40E9F2E6702D176240986E1283C06A4D40
35	Камчатский край	4	155.54569900000001	174.49339599999999	64.947699999999998	50.863999999999997	0103000020E61000000100000005000000B8CEBF5D767163403BDF4F8D976E4940B8CEBF5D76716340D49AE61DA73C5040457F68E6C9CF6540D49AE61DA73C5040457F68E6C9CF65403BDF4F8D976E4940B8CEBF5D767163403BDF4F8D976E4940
41	Еврейская автономная область	4	130.52173400000001	134.992209	49.494084000000001	47.652951999999999	0103000020E61000000100000005000000C366800BB2506040CCED5EEE93D34740C366800BB25060400ABDFE243EBF484080B9162DC0DF60400ABDFE243EBF484080B9162DC0DF6040CCED5EEE93D34740C366800BB2506040CCED5EEE93D34740
38	Амурская область	4	119.656153	134.92041599999999	57.060602000000003	48.851351000000001	0103000020E61000000100000005000000070B2769FEE95D405D35CF11F96C4840070B2769FEE95D403E096CCEC1874C40E256410C74DD60403E096CCEC1874C40E256410C74DD60405D35CF11F96C4840070B2769FEE95D405D35CF11F96C4840
\.


--
-- Data for Name: district; Type: TABLE DATA; Schema: public; Owner: -
--

COPY district (id, name) FROM stdin;
2	Южный ф. о.
1	Центральный ф. о.
6	Уральский ф. о.
5	Сибирский ф. о.
8	Северо-Кавказский ф. о.
3	Северо-Западный ф. о.
7	Приволжский ф. о.
4	Дальневосточный ф. о.
\.


--
-- Data for Name: locality; Type: TABLE DATA; Schema: public; Owner: -
--

COPY locality (id, name, district_id, area_id, sub_area_id, bounds_left, bounds_right, bounds_top, bounds_bottom, box) FROM stdin;
57158	Яшкуль	2	19	\N	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
11360	Элиста	2	19	\N	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57159	Лагань	2	19	\N	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57156	Городовиковск	2	19	\N	41.890183999999998	41.960433000000002	46.115588000000002	46.052672000000001	0103000020E6100000010000000500000013B69F8CF1F144401CB5C2F4BD06474013B69F8CF1F14440B0E76B96CB0E4740E57FF277EFFA4440B0E76B96CB0E4740E57FF277EFFA44401CB5C2F4BD06474013B69F8CF1F144401CB5C2F4BD064740
32542	Яшкуль	2	19	1925	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
57153	Яшкуль	2	19	1925	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
57184	Элвг	2	19	1925	44.894401999999999	44.907122000000001	46.353343000000002	46.337696999999999	0103000020E610000001000000050000000EBDC5C37B724640897AC1A7392B47400EBDC5C37B724640A1A2EA573A2D4740B6BDDD921C744640A1A2EA573A2D4740B6BDDD921C744640897AC1A7392B47400EBDC5C37B724640897AC1A7392B4740
57163	Чилгир	2	19	1925	45.043756000000002	45.059925999999997	46.489406000000002	46.475158999999998	0103000020E610000001000000050000007C80EECB9985464035B39602D23C47407C80EECB99854640AC3B16DBA43E47400D17B9A7AB874640AC3B16DBA43E47400D17B9A7AB87464035B39602D23C47407C80EECB9985464035B39602D23C4740
57190	Цаган Усн	2	19	1925	45.288179	45.304726000000002	46.053747999999999	46.042064000000003	0103000020E610000001000000050000006E32AA0CE3A44640632B685A620547406E32AA0CE3A44640DA1CE736E1064740D61EF64201A74640DA1CE736E1064740D61EF64201A74640632B685A620547406E32AA0CE3A44640632B685A62054740
57182	Хулхута	2	19	1925	46.359814999999998	46.386558000000001	46.321511000000001	46.313214000000002	0103000020E610000001000000050000001CCEFC6A0E2E47401E537765172847401CCEFC6A0E2E4740F226BF4527294740EB0088BB7A314740F226BF4527294740EB0088BB7A3147401E537765172847401CCEFC6A0E2E47401E53776517284740
57204	Хар Толга	2	19	1925	45.087198999999998	45.110815000000002	46.110596000000001	46.090674	0103000020E61000000100000005000000389F3A56298B46407B4CA4349B0B4740389F3A56298B4640C2887D02280E47400074982F2F8E4640C2887D02280E47400074982F2F8E46407B4CA4349B0B4740389F3A56298B46407B4CA4349B0B4740
57168	Улан Эрге	2	19	1925	44.845075999999999	44.872636	46.317528000000003	46.300787999999997	0103000020E6100000010000000500000037514B732B6C4640BE839F388026474037514B732B6C46403BC8EBC1A4284740F8A75489B26F46403BC8EBC1A4284740F8A75489B26F4640BE839F388026474037514B732B6C4640BE839F3880264740
57196	Тавн Гашун	2	19	1925	45.911546999999999	45.927528000000002	46.027267000000002	46.016089999999998	0103000020E610000001000000050000002AE27492ADF4464075E5B33C0F0247402AE27492ADF4464049A12C7C7D034740E90FCD3CB9F6464049A12C7C7D034740E90FCD3CB9F6464075E5B33C0F0247402AE27492ADF4464075E5B33C0F024740
57189	Молодежный	2	19	1925	46.215679999999999	46.232379999999999	46.593623000000001	46.583193000000001	0103000020E610000001000000050000005D33F9669B1B4740C9207711A64A47405D33F9669B1B4740A393A5D6FB4B47404B1FBAA0BE1D4740A393A5D6FB4B47404B1FBAA0BE1D4740C9207711A64A47405D33F9669B1B4740C9207711A64A4740
57195	Гашун	2	19	1925	45.078924999999998	45.101211999999997	46.217692999999997	46.203285999999999	0103000020E610000001000000050000001CEBE2361A8A464009DE9046051A47401CEBE2361A8A4640B8C83D5DDD1B47403BFBCA83F48C4640B8C83D5DDD1B47403BFBCA83F48C464009DE9046051A47401CEBE2361A8A464009DE9046051A4740
57155	Яшалта	2	19	417	42.253787000000003	42.295611999999998	46.350636999999999	46.329259999999998	0103000020E610000001000000050000003293A8177C204540C3F01131252A47403293A8177C2045403FE257ACE12C47400F27309DD62545403FE257ACE12C47400F27309DD6254540C3F01131252A47403293A8177C204540C3F01131252A4740
22386	Яшалта	2	19	417	42.253787000000003	42.295611999999998	46.350636999999999	46.329259999999998	0103000020E610000001000000050000003293A8177C204540C3F01131252A47403293A8177C2045403FE257ACE12C47400F27309DD62545403FE257ACE12C47400F27309DD6254540C3F01131252A47403293A8177C204540C3F01131252A4740
22377	Эсто-Алтай	2	19	417	42.207245	42.263461	46.209117999999997	46.195357999999999	0103000020E6100000010000000500000038A11001871A45408881AE7D0119474038A11001871A4540A180ED60C41A4740BF620D17B9214540A180ED60C41A4740BF620D17B92145408881AE7D0119474038A11001871A45408881AE7D01194740
46412	Ульяновское	2	19	417	42.235605	42.284446000000003	46.291784999999997	46.272091000000003	0103000020E6100000010000000500000015E3FC4D281E45409A44BDE0D322474015E3FC4D281E45404F3BFC355925474030BDFDB9682445404F3BFC355925474030BDFDB9682445409A44BDE0D322474015E3FC4D281E45409A44BDE0D3224740
22275	Соленое	2	19	417	42.522751	42.563211000000003	46.247317000000002	46.208705999999999	0103000020E61000000100000005000000C4793881E94245404F3DD2E0B61A4740C4793881E9424540575F5D15A81F4740ADDF4C4C17484540575F5D15A81F4740ADDF4C4C174845404F3DD2E0B61A4740C4793881E94245404F3DD2E0B61A4740
46313	Матросово	2	19	417	42.556545999999997	42.574728	46.158808999999998	46.139760000000003	0103000020E610000001000000050000001C5C3AE63C474540FDA4DAA7E31147401C5C3AE63C474540BDA772DA53144740390CE6AF90494540BDA772DA53144740390CE6AF90494540FDA4DAA7E31147401C5C3AE63C474540FDA4DAA7E3114740
57169	Манычский	2	19	417	42.328004999999997	42.370477999999999	46.420920000000002	46.405810000000002	0103000020E6100000010000000500000055F65D11FC294540E4310395F133474055F65D11FC294540BD1DE1B4E035474099F1B6D26B2F4540BD1DE1B4E035474099F1B6D26B2F4540E4310395F133474055F65D11FC294540E4310395F1334740
46346	Красный Партизан	2	19	417	42.690458	42.705962999999997	46.099716999999998	46.093755000000002	0103000020E610000001000000050000007BA180ED60584540126BF129000C47407BA180ED6058454078EDD286C30C4740D097DEFE5C5A454078EDD286C30C4740D097DEFE5C5A4540126BF129000C47407BA180ED60584540126BF129000C4740
45563	Красный Маныч	2	19	417	42.157451000000002	42.200947999999997	46.548316999999997	46.536211999999999	0103000020E610000001000000050000007BDCB75A2714454083DC4598A24447407BDCB75A27144540A06B5F402F4647402A1900AAB8194540A06B5F402F4647402A1900AAB819454083DC4598A24447407BDCB75A2714454083DC4598A2444740
57199	Краснополье	2	19	417	42.350436000000002	42.377654999999997	46.221845999999999	46.205500999999998	0103000020E61000000100000005000000A8AB3B16DB2C4540CC2555DB4D1A4740A8AB3B16DB2C4540CC5F2173651C4740DF15C1FF56304540CC5F2173651C4740DF15C1FF56304540CC2555DB4D1A4740A8AB3B16DB2C4540CC2555DB4D1A4740
22025	Красномихайловское	2	19	417	42.522751	42.552027000000002	46.179867000000002	46.153109000000001	0103000020E61000000100000005000000C4793881E942454094DC611399134740C4793881E94245409850C1E10517474027C11BD2A84645409850C1E10517474027C11BD2A846454094DC611399134740C4793881E942454094DC611399134740
21882	Березовское	2	19	417	42.385857000000001	42.402422000000001	46.267431000000002	46.249510000000001	0103000020E6100000010000000500000062F71DC363314540320395F1EF1F474062F71DC363314540E277D32D3B2247407098689082334540E277D32D3B2247407098689082334540320395F1EF1F474062F71DC363314540320395F1EF1F4740
2227	Бага Тугтун	2	19	417	42.215806000000001	42.239457999999999	46.460577999999998	46.448036999999999	0103000020E61000000100000005000000EA23F0879F1B4540F032C34659394740EA23F0879F1B4540E8A04B38F43A4740FE614B8FA61E4540E8A04B38F43A4740FE614B8FA61E4540F032C34659394740EA23F0879F1B4540F032C34659394740
21545	Юста	2	19	1559	46.285460999999998	46.307326000000003	47.127679000000001	47.117617000000003	0103000020E6100000010000000500000048A46DFC89244740113AE8120E8F474048A46DFC8924474068B114C957904740F29A57755627474068B114C957904740F29A577556274740113AE8120E8F474048A46DFC89244740113AE8120E8F4740
21848	Эрдниевский	2	19	1559	46.269651000000003	46.290123999999999	46.873489999999997	46.859492000000003	0103000020E61000000100000005000000B72A89EC832247403A9677D5036E4740B72A89EC8322474007B13385CE6F474071E481C82225474007B13385CE6F474071E481C8222547403A9677D5036E4740B72A89EC832247403A9677D5036E4740
21498	Чомпот	2	19	1559	46.427520999999999	46.434401999999999	47.355068000000003	47.352003000000003	0103000020E6100000010000000500000036AD1402B9364740058C2E6F0EAD474036AD1402B936474096ED43DE72AD474093A8177C9A37474096ED43DE72AD474093A8177C9A374740058C2E6F0EAD474036AD1402B9364740058C2E6F0EAD4740
33019	Цаган Аман	2	19	1559	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
57165	Цаган Аман	2	19	1559	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
21712	Харба	2	19	1559	46.590142999999998	46.607238000000002	47.021877000000003	47.006380999999998	0103000020E610000001000000050000004E7B4ACE894B47406B28B517D18047404E7B4ACE894B47406EC493DDCC824740B9718BF9B94D47406EC493DDCC824740B9718BF9B94D47406B28B517D18047404E7B4ACE894B47406B28B517D1804740
21463	Татал	2	19	1559	46.261583999999999	46.276091999999998	47.291671000000001	47.279085000000002	0103000020E610000001000000050000001494A2957B214740EFE6A90EB9A347401494A2957B2147408718AF7955A54740F7578FFB562347408718AF7955A54740F7578FFB56234740EFE6A90EB9A347401494A2957B214740EFE6A90EB9A34740
57175	Октябрьский	2	19	1559	46.162823000000003	46.172964999999998	47.029021	47.023620999999999	0103000020E61000000100000005000000B0045262D7144740D93F4F0306834740B0045262D7144740D8F2CAF5B6834740232D95B723164740D8F2CAF5B6834740232D95B723164740D93F4F0306834740B0045262D7144740D93F4F0306834740
57192	Бергин	2	19	1559	45.695492999999999	47.252372000000001	47.641357999999997	46.446168	0103000020E6100000010000000500000068CC24EA05D94640C84274081C39474068CC24EA05D946409483D90418D247408B36C7B94DA047409483D90418D247408B36C7B94DA04740C84274081C39474068CC24EA05D94640C84274081C394740
21609	Белоозерный	2	19	1559	45.958933000000002	45.973719000000003	47.114533000000002	47.106786999999997	0103000020E6100000010000000500000010070951BEFA4640A8514832AB8D474010070951BEFA464009A87004A98E4740363FFED2A2FC464009A87004A98E4740363FFED2A2FC4640A8514832AB8D474010070951BEFA4640A8514832AB8D4740
21730	Барун	2	19	1559	45.800910000000002	45.822712000000003	47.566934000000003	47.552365000000002	0103000020E610000001000000050000000A85083884E646403F3A75E5B3C647400A85083884E64640C87E164B91C847406D0377A04EE94640C87E164B91C847406D0377A04EE946403F3A75E5B3C647400A85083884E646403F3A75E5B3C64740
57185	Салын	2	19	7420	44.199618000000001	44.209724000000001	46.367511	46.356354000000003	0103000020E61000000100000005000000B2D826158D1946403FE603029D2D4740B2D826158D194640CBF5B6990A2F4740D9976C3CD81A4640CBF5B6990A2F4740D9976C3CD81A46403FE603029D2D4740B2D826158D1946403FE603029D2D4740
57187	Сарул	2	19	1928	45.465336000000001	45.479996	45.826897000000002	45.813757000000003	0103000020E6100000010000000500000063D34A2190BB46400FF27A3029E8464063D34A2190BB46408C14CAC2D7E94640FC1A498270BD46408C14CAC2D7E94640FC1A498270BD46400FF27A3029E8464063D34A2190BB46400FF27A3029E84640
32999	Прикумский	2	19	1928	45.807423	45.827742999999998	45.258473000000002	45.245789000000002	0103000020E61000000100000005000000E48409A359E74640B85B9203769F4640E48409A359E7464013F3ACA415A14640183F8D7BF3E9464013F3ACA415A14640183F8D7BF3E94640B85B9203769F4640E48409A359E74640B85B9203769F4640
57203	Нарын Худук	2	19	1928	46.535966000000002	46.550285000000002	45.440764000000001	45.429715000000002	0103000020E610000001000000050000004CE2AC889A444740E2CCAFE600B746404CE2AC889A44474088A06AF46AB846405C3D27BD6F46474088A06AF46AB846405C3D27BD6F464740E2CCAFE600B746404CE2AC889A444740E2CCAFE600B74640
52910	Маныч	2	19	1928	45.507978999999999	45.514653000000003	45.172502999999999	45.167819999999999	0103000020E610000001000000050000000307B47405C14640AFCE31207B9546400307B47405C146401FBB0B9414964640E7E44526E0C146401FBB0B9414964640E7E44526E0C14640AFCE31207B9546400307B47405C14640AFCE31207B954640
57198	Кумской	2	19	1928	46.055241000000002	46.074528000000001	44.983905	44.975501999999999	0103000020E61000000100000005000000FD321823120747405F97E13FDD7C4640FD3218231207474079AF5A99F07D464072512D228A09474079AF5A99F07D464072512D228A0947405F97E13FDD7C4640FD321823120747405F97E13FDD7C4640
57170	Комсомольское сельское муниципальное образование Республики Калмыкия	2	19	1928	45.264293000000002	47.158830999999999	46.375694000000003	44.863036000000001	0103000020E61000000100000005000000E7C75F5AD4A14640A5A2B1F6776E4640E7C75F5AD4A14640D7A6B1BD16304740A54BFF9254944740D7A6B1BD16304740A54BFF9254944740A5A2B1F6776E4640E7C75F5AD4A14640A5A2B1F6776E4640
32984	Комсомольский	2	19	1928	46.022435000000002	46.057755999999998	45.337316999999999	45.321202999999997	0103000020E6100000010000000500000094A46B26DF02474044300E2E1DA9464094A46B26DF02474042B115342DAB4640EA92718C6407474042B115342DAB4640EA92718C6407474044300E2E1DA9464094A46B26DF02474044300E2E1DA94640
57161	Ачинеры	2	19	1928	45.347664999999999	45.370671000000002	45.411482999999997	45.393853	0103000020E610000001000000050000005F7B664980AC46403B376DC669B246405F7B664980AC464013EE9579ABB44640AE49B72572AF464013EE9579ABB44640AE49B72572AF46403B376DC669B246405F7B664980AC46403B376DC669B24640
32962	Артезиан	2	19	1928	46.642712000000003	46.678178000000003	44.957416000000002	44.936185999999999	0103000020E61000000100000005000000965F0663445247408D7C5EF1D4774640965F0663445247406555849B8C7A4640F06E6589CE5647406555849B8C7A4640F06E6589CE5647408D7C5EF1D4774640965F0663445247408D7C5EF1D4774640
57172	Адык	2	19	1928	45.623052999999999	45.640318000000001	45.809907000000003	45.796152999999997	0103000020E610000001000000050000005C566133C0CF46405FCE6C57E8E546405C566133C0CF464097E65608ABE746402385B2F0F5D1464097E65608ABE746402385B2F0F5D146405FCE6C57E8E546405C566133C0CF46405FCE6C57E8E54640
20295	Ялмта	2	19	1607	44.885131999999999	44.905416000000002	46.543210000000002	46.532746000000003	0103000020E61000000100000005000000505260014C71464094895B0531444740505260014C7146401A6EC0E78745474038A3E6ABE47346401A6EC0E78745474038A3E6ABE473464094895B0531444740505260014C71464094895B0531444740
20272	Чагорта	2	19	1607	43.957000999999998	43.977977000000003	46.730607999999997	46.722349000000001	0103000020E61000000100000005000000A19E3E027FFA45402FA699EE755C4740A19E3E027FFA454015191D90845D4740BF9EAF592EFD454015191D90845D4740BF9EAF592EFD45402FA699EE755C4740A19E3E027FFA45402FA699EE755C4740
20115	Хар-Булук	2	19	1607	43.974294	43.988208999999998	46.313015	46.309218000000001	0103000020E61000000100000005000000325871AAB5FC4540D2AA967494274740325871AAB5FC4540271422E010284740724EECA17DFE4540271422E010284740724EECA17DFE4540D2AA967494274740325871AAB5FC4540D2AA967494274740
32888	Троицкое	2	19	1607	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
20069	Овата	2	19	1607	44.341211000000001	44.415968999999997	46.859214999999999	46.843432	0103000020E610000001000000050000008A0453CDAC2B46402F336C94F56B47408A0453CDAC2B4640C79DD2C1FA6D47402D93E1783E354640C79DD2C1FA6D47402D93E1783E3546402F336C94F56B47408A0453CDAC2B46402F336C94F56B4740
19995	Найнтахн	2	19	1607	44.052708000000003	44.071249000000002	46.629899000000002	46.618386999999998	0103000020E61000000100000005000000691EC022BF064640C2A2224E274F4740691EC022BF0646403D64CA87A0504740B56FEEAF1E0946403D64CA87A0504740B56FEEAF1E094640C2A2224E274F4740691EC022BF064640C2A2224E274F4740
57174	Ики-Чонос	2	19	1607	44.468547000000001	44.498730000000002	46.426188000000003	46.413775999999999	0103000020E61000000100000005000000C8D11C59F93B464052EFA99CF6344740C8D11C59F93B46404DF910548D3647405DC47762D63F46404DF910548D3647405DC47762D63F464052EFA99CF6344740C8D11C59F93B464052EFA99CF6344740
19898	Вознесеновка	2	19	1607	44.337240000000001	44.371079999999999	46.277323000000003	46.259013000000003	0103000020E61000000100000005000000977329AE2A2B4640931E865627214740977329AE2A2B4640DDB6EF517F2347408F19A88C7F2F4640DDB6EF517F2347408F19A88C7F2F4640931E865627214740977329AE2A2B4640931E865627214740
19830	Верхняя Яшкуль	2	19	1607	44.144426000000003	44.171545999999999	46.498500999999997	46.489189000000003	0103000020E610000001000000050000009758198D7C1246400F48C2BE9D3E47409758198D7C124640FB027AE1CE3F47403BE12538F5154640FB027AE1CE3F47403BE12538F51546400F48C2BE9D3E47409758198D7C1246400F48C2BE9D3E4740
19809	Бага-Чонос	2	19	1607	44.403356000000002	44.433700999999999	46.729723999999997	46.713551000000002	0103000020E610000001000000050000009C525E2BA13346409983A0A3555B47409C525E2BA13346409B8D9598675D47400A9FAD83833746409B8D9598675D47400A9FAD83833746409983A0A3555B47409C525E2BA13346409983A0A3555B4740
20186	Аршан-Булг	2	19	1607	44.504821	44.533332999999999	46.674351000000001	46.657375000000002	0103000020E61000000100000005000000C1AA7AF99D404640A01A2FDD24544740C1AA7AF99D4046403083312251564740547078414444464030833122515647405470784144444640A01A2FDD24544740C1AA7AF99D404640A01A2FDD24544740
32778	Шарнут	2	19	1927	43.753686000000002	43.786150999999997	47.674593000000002	47.660854999999998	0103000020E61000000100000005000000FEB968C878E04540F4328AE596D44740FEB968C878E04540268E3C1059D64740DD5B9198A0E44540268E3C1059D64740DD5B9198A0E44540F4328AE596D44740FEB968C878E04540F4328AE596D44740
57186	Уманцево	2	19	1927	44.246994999999998	44.293348000000002	47.738914000000001	47.725774999999999	0103000020E6100000010000000500000044A33B889D1F464090A0F831E6DC474044A33B889D1F46403D47E4BB94DE47406B2C616D8C2546403D47E4BB94DE47406B2C616D8C25464090A0F831E6DC474044A33B889D1F464090A0F831E6DC4740
57183	Салын Тугтун	2	19	1927	43.854053999999998	43.888505000000002	47.514591000000003	47.496513	0103000020E610000001000000050000004D8237A451ED4540F984ECBC8DBF47404D8237A451ED454071E82D1EDEC147408FAA2688BAF1454071E82D1EDEC147408FAA2688BAF14540F984ECBC8DBF47404D8237A451ED4540F984ECBC8DBF4740
57154	Садовое	2	19	1927	44.490250000000003	44.535525	47.790559000000002	47.756405000000001	0103000020E61000000100000005000000986E1283C03E4640F4C308E1D1E04740986E1283C03E46407C478D0931E547405F984C158C4446407C478D0931E547405F984C158C444640F4C308E1D1E04740986E1283C03E4640F4C308E1D1E04740
32825	Обильное	2	19	1927	44.407083999999998	44.435974000000002	47.525239999999997	47.49879	0103000020E61000000100000005000000C85C19541B34464032C9C859D8BF4740C85C19541B344640884677103BC3474002F4FBFECD374640884677103BC3474002F4FBFECD37464032C9C859D8BF4740C85C19541B34464032C9C859D8BF4740
57205	Коробкин	2	19	1927	44.369948000000001	44.397238999999999	47.822778	47.804541	0103000020E610000001000000050000003D9CC0745A2F464044A51133FBE647403D9CC0745A2F464024EF1CCA50E947400ED940BAD832464024EF1CCA50E947400ED940BAD832464044A51133FBE647403D9CC0745A2F464044A51133FBE64740
57191	Кировский	2	19	1927	44.480547999999999	44.510902000000002	47.656405999999997	47.639142	0103000020E610000001000000050000004014CC98823D464001C0B167CFD147404014CC98823D4640F7729F1C05D4474002BB9A3C65414640F7729F1C05D4474002BB9A3C6541464001C0B167CFD147404014CC98823D464001C0B167CFD14740
57160	Кануково	2	19	1927	44.025381000000003	44.070197999999998	47.608581999999998	47.589593999999998	0103000020E610000001000000050000004B7842AF3F0346407BF5F1D077CB47404B7842AF3F0346409677D503E6CD47404F1F813FFC0846409677D503E6CD47404F1F813FFC0846407BF5F1D077CB47404B7842AF3F0346407BF5F1D077CB4740
57164	Аршань-Зельмень	2	19	1927	44.597410000000004	44.622599000000001	47.616418000000003	47.599316999999999	0103000020E61000000100000005000000D5264EEE774C4640EA77616BB6CC4740D5264EEE774C46403755F7C8E6CE4740DBC2F352B14F46403755F7C8E6CE4740DBC2F352B14F4640EA77616BB6CC4740D5264EEE774C4640EA77616BB6CC4740
18955	Ульдючины	2	19	1542	43.758338999999999	43.774760000000001	46.133682999999998	46.121822000000002	0103000020E6100000010000000500000003249A4011E1454077F700DD970F474003249A4011E14540FD8348861C114740DE1FEF552BE34540FD8348861C114740DE1FEF552BE3454077F700DD970F474003249A4011E1454077F700DD970F4740
18763	Приютное	2	19	1542	43.482035000000003	43.532986999999999	46.111721000000003	46.089030000000001	0103000020E610000001000000050000008143A852B3BD4540732EC555650B47408143A852B3BD454062A3ACDF4C0E4740B91803EB38C4454062A3ACDF4C0E4740B91803EB38C44540732EC555650B47408143A852B3BD4540732EC555650B4740
18686	Песчаный	2	19	1542	44.152330999999997	44.170521999999998	46.240723000000003	46.227974000000003	0103000020E610000001000000050000005F950B957F1346404E2B85402E1D47405F950B957F1346409032E202D01E4740CF9F36AAD31546409032E202D01E4740CF9F36AAD31546404E2B85402E1D47405F950B957F1346404E2B85402E1D4740
32706	Первомайский	2	19	1542	44.176397000000001	44.197777000000002	45.887976000000002	45.875014	0103000020E61000000100000005000000670E492D9416464065C5707500F04640670E492D9416464003D19332A9F146405473B9C15019464003D19332A9F146405473B9C15019464065C5707500F04640670E492D9416464065C5707500F04640
52054	Октябрьский	2	19	1542	43.101419	43.119062	46.309685000000002	46.300322000000001	0103000020E61000000100000005000000B5183C4CFB8C4540792288F370264740B5183C4CFB8C4540E88711C2A32747402219726C3D8F4540E88711C2A32747402219726C3D8F4540792288F370264740B5183C4CFB8C4540792288F370264740
18440	Нарын	2	19	1542	44.231535000000001	44.248154	46.264333999999998	46.252988000000002	0103000020E610000001000000050000008F705AF0A21D4640E62329E9612047408F705AF0A21D4640459C4EB2D5214740902FA182C31F4640459C4EB2D5214740902FA182C31F4640E62329E9612047408F705AF0A21D4640E62329E961204740
18549	Нарта	2	19	1542	43.881489000000002	43.898834999999998	46.122703000000001	46.114407	0103000020E610000001000000050000005264ADA1D4F045407CB779E3A40E47405264ADA1D4F04540800F5EBBB40F474005C078060DF34540800F5EBBB40F474005C078060DF345407CB779E3A40E47405264ADA1D4F045407CB779E3A40E4740
18471	Воробьевка	2	19	1542	43.755859999999998	43.778388999999997	46.214624999999998	46.191940000000002	0103000020E61000000100000005000000622D3E05C0E04540AA656B7D91184740622D3E05C0E04540B6F3FDD4781B474077483140A2E34540B6F3FDD4781B474077483140A2E34540AA656B7D91184740622D3E05C0E04540AA656B7D91184740
18358	Бурата	2	19	1542	44.229523	44.260523999999997	46.230511999999997	46.219363999999999	0103000020E6100000010000000500000004577902611D4640BAF59A1E141C474004577902611D4640F3AACE6A811D47405BE9B5D958214640F3AACE6A811D47405BE9B5D958214640BAF59A1E141C474004577902611D4640BAF59A1E141C4740
32637	Цаган Нур	2	19	1926	45.217787000000001	45.249093000000002	47.375073999999998	47.363522000000003	0103000020E610000001000000050000003A3FC571E09B464032B08EE387AE47403A3FC571E09B46403ACAC16C02B04740CE548847E29F46403ACAC16C02B04740CE548847E29F464032B08EE387AE47403A3FC571E09B464032B08EE387AE4740
57179	Хошеут	2	19	1926	45.396399000000002	45.408095000000003	47.235626000000003	47.224831999999999	0103000020E610000001000000050000006495D233BDB24640118C834BC79C47406495D233BDB246402D0B26FE289E4740A054FB743CB446402D0B26FE289E4740A054FB743CB44640118C834BC79C47406495D233BDB24640118C834BC79C4740
57188	Мирный	2	19	1926	45.505167	45.527588999999999	47.802076999999997	47.787005000000001	0103000020E610000001000000050000005C02F04FA9C04640ED647094BCE447405C02F04FA9C04640D8EF8975AAE647405B5D4E0988C34640D8EF8975AAE647405B5D4E0988C34640ED647094BCE447405C02F04FA9C04640ED647094BCE44740
57180	Иджил	2	19	1926	45.513340999999997	45.54233	47.449503999999997	47.420003999999999	0103000020E6100000010000000500000014596B28B5C146403718EAB0C2B5474014596B28B5C14640E9B5D95889B94740E1D1C6116BC54640E9B5D95889B94740E1D1C6116BC546403718EAB0C2B5474014596B28B5C146403718EAB0C2B54740
57177	Джангар	2	19	1926	45.751340999999996	45.765552	47.666364999999999	47.652546000000001	0103000020E610000001000000050000006C921FF12BE046405C9198A086D347406C921FF12BE046407A19C5724BD5474096B1A19BFDE146407A19C5724BD5474096B1A19BFDE146405C9198A086D347406C921FF12BE046405C9198A086D34740
57157	Восход	2	19	1926	45.283732000000001	45.308346	47.885930000000002	47.875686999999999	0103000020E61000000100000005000000126A865451A446402444F98216F04740126A865451A44640CC457C2766F147401CEDB8E177A74640CC457C2766F147401CEDB8E177A746402444F98216F04740126A865451A446402444F98216F04740
32600	Большой Царын	2	19	1926	45.411633999999999	45.457583	47.865955999999997	47.835917000000002	0103000020E61000000100000005000000F9F5436CB0B44640D1950854FFEA4740F9F5436CB0B4464032E36DA5D7EE4740501A6A1492BA464032E36DA5D7EE4740501A6A1492BA4640D1950854FFEA4740F9F5436CB0B44640D1950854FFEA4740
17778	Хонч-Нур	2	19	1491	45.013627	45.027479	48.195059000000001	48.182107999999999	0103000020E61000000100000005000000DAAB8F87BE814640842BA0504F174840DAAB8F87BE8146402EE57CB1F7184840D4298F6E848346402EE57CB1F7184840D4298F6E84834640842BA0504F174840DAAB8F87BE814640842BA0504F174840
17762	Ханата	2	19	1491	44.866213000000002	44.883181999999998	47.705502000000003	47.696812000000001	0103000020E610000001000000050000005E2F4D11E06E4640EDBAB72231D947405E2F4D11E06E46409DA1B8E34DDA47403B35971B0C7146409DA1B8E34DDA47403B35971B0C714640EDBAB72231D947405E2F4D11E06E4640EDBAB72231D94740
17682	Унгун-Терячи	2	19	1491	44.706771000000003	44.723120000000002	47.823202000000002	47.813248999999999	0103000020E610000001000000050000007061DD78775A46409A40118B18E847407061DD78775A46403B00E2AE5EE94740B18A37328F5C46403B00E2AE5EE94740B18A37328F5C46409A40118B18E847407061DD78775A46409A40118B18E84740
17573	Тундутово	2	19	1491	44.603887	44.645892000000003	47.949553999999999	47.930655000000002	0103000020E6100000010000000500000062BD512B4C4D4640F06DFAB31FF7474062BD512B4C4D46409BE447FC8AF94740C05FCC96AC5246409BE447FC8AF94740C05FCC96AC524640F06DFAB31FF7474062BD512B4C4D4640F06DFAB31FF74740
17539	Плодовитое	2	19	1491	44.395173	44.455359999999999	48.146019000000003	48.125689000000001	0103000020E6100000010000000500000090A1630795324640C53BC0931610484090A16307953246401DCC26C0B01248400AF4893C493A46401DCC26C0B01248400AF4893C493A4640C53BC0931610484090A1630795324640C53BC09316104840
17366	Малые Дербеты	2	19	1491	44.661945000000003	44.695695000000001	47.968885999999998	47.930968999999997	0103000020E6100000010000000500000018601F9DBA5446407F4B00FE29F7474018601F9DBA544640B0C6D97404FC4740D07EA4880C594640B0C6D97404FC4740D07EA4880C5946407F4B00FE29F7474018601F9DBA5446407F4B00FE29F74740
17345	Ики-Манлан	2	19	1491	45.663342	45.677554000000001	48.026653000000003	48.018034999999998	0103000020E6100000010000000500000018080264E8D4464078978BF84E02484018080264E8D446408FAB915D6903484012A3E716BAD646408FAB915D6903484012A3E716BAD6464078978BF84E02484018080264E8D4464078978BF84E024840
17268	Ики-Бухус	2	19	1491	45.204760999999998	45.239086	48.046408	48.037101	0103000020E61000000100000005000000853FC39B359A46400FD3BEB9BF044840853FC39B359A4640EA2285B2F00548403A77BB5E9A9E4640EA2285B2F00548403A77BB5E9A9E46400FD3BEB9BF044840853FC39B359A46400FD3BEB9BF044840
17644	Зурган	2	19	1491	44.969977999999998	44.985230999999999	47.644612000000002	47.629530000000003	0103000020E6100000010000000500000074EB353D287C4640EAEC647094D0474074EB353D287C4640F94D61A582D24740B000A60C1C7E4640F94D61A582D24740B000A60C1C7E4640EAEC647094D0474074EB353D287C4640EAEC647094D04740
57173	Улан Хол	2	19	1930	46.844302999999996	46.864749000000003	45.450104000000003	45.426881000000002	0103000020E610000001000000050000001475E61E126C474053245F09A4B646401475E61E126C47403FE603029DB94640D61F6118B06E47403FE603029DB94640D61F6118B06E474053245F09A4B646401475E61E126C474053245F09A4B64640
57171	Улан Хол	2	19	1930	46.844302999999996	46.864749000000003	45.450104000000003	45.426881000000002	0103000020E610000001000000050000001475E61E126C474053245F09A4B646401475E61E126C47403FE603029DB94640D61F6118B06E47403FE603029DB94640D61F6118B06E474053245F09A4B646401475E61E126C474053245F09A4B64640
33143	Северное	2	19	1930	47.317886000000001	47.344206999999997	45.381174000000001	45.361026000000003	0103000020E610000001000000050000009AED0A7DB0A84740BB80971936AE46409AED0A7DB0A84740F20A444FCAB04640F20698F90EAC4740F20A444FCAB04640F20698F90EAC4740BB80971936AE46409AED0A7DB0A84740BB80971936AE4640
33051	Лагань	2	19	1930	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
33140	Красинское	2	19	1930	47.310493000000001	47.353180999999999	45.450406999999998	45.440010999999998	0103000020E610000001000000050000008751103CBEA74740AC70CB4752B846408751103CBEA74740DA71C3EFA6B94640C748F60835AD4740DA71C3EFA6B94640C748F60835AD4740AC70CB4752B846408751103CBEA74740AC70CB4752B84640
57166	Джалыково	2	19	1930	47.421883999999999	47.455185	45.615851999999997	45.600195999999997	0103000020E61000000100000005000000535A7F4B00B647405298F738D3CC4640535A7F4B00B647408D96033DD4CE46409C50888043BA47408D96033DD4CE46409C50888043BA47405298F738D3CC4640535A7F4B00B647405298F738D3CC4640
57201	Эвдик	2	19	1371	45.194107000000002	45.204968000000001	47.345830999999997	47.337923000000004	0103000020E610000001000000050000005C76887FD89846407AC8940F41AB47405C76887FD8984640B378B13044AC4740FF5C34643C9A4640B378B13044AC4740FF5C34643C9A46407AC8940F41AB47405C76887FD89846407AC8940F41AB4740
15604	Шин Мер	2	19	1371	44.508450000000003	44.527557000000002	47.401294999999998	47.394122000000003	0103000020E610000001000000050000005BD3BCE3144146402B51F69672B247405BD3BCE3144146402F8672A25DB3474050E3DEFC864346402F8672A25DB3474050E3DEFC864346402B51F69672B247405BD3BCE3144146402B51F69672B24740
16032	Шатта	2	19	1371	44.789873999999998	44.807175999999998	46.858930999999998	46.845230999999998	0103000020E61000000100000005000000F8FA5A971A6546405E488787306C4740F8FA5A971A654640A2427573F16D4740DC0E0D8B51674640A2427573F16D4740DC0E0D8B516746405E488787306C4740F8FA5A971A6546405E488787306C4740
15880	Чкаловский	2	19	1371	44.863554000000001	44.887593000000003	47.250368999999999	47.233637000000002	0103000020E610000001000000050000003D2AFEEF886E46405A1135D1E79D47403D2AFEEF886E4640537765170CA047404B94BDA59C714640537765170CA047404B94BDA59C7146405A1135D1E79D47403D2AFEEF886E46405A1135D1E79D4740
15974	Тугтун	2	19	1371	45.041851999999999	45.054831999999998	47.414296999999998	47.395902999999997	0103000020E61000000100000005000000D7A205685B854640B3B112F3ACB24740D7A205685B8546405BEA20AF07B547401B6327BC048746405BEA20AF07B547401B6327BC04874640B3B112F3ACB24740D7A205685B854640B3B112F3ACB24740
15845	Сарпа	2	19	1371	45.492536999999999	45.509883000000002	47.087094999999998	47.076822999999997	0103000020E61000000100000005000000F488D1730BBF4640514A0856D5894740F488D1730BBF46409352D0ED258B4740A8E49CD843C146409352D0ED258B4740A8E49CD843C14640514A0856D5894740F488D1730BBF4640514A0856D5894740
15375	Кетченеры	2	19	1371	44.499322999999997	44.551417000000001	47.316290000000002	47.297899000000001	0103000020E61000000100000005000000FF91E9D0E93F46406C41EF8D21A64740FF91E9D0E93F4640A306D3307CA84740AEBA0ED594464640A306D3307CA84740AEBA0ED5944646406C41EF8D21A64740FF91E9D0E93F46406C41EF8D21A64740
15785	Кегульта	2	19	1371	44.347273999999999	44.434213	46.941099999999999	46.929777999999999	0103000020E6100000010000000500000024607479732C464028452BF70277474024607479732C4640FF21FDF675784740C03FA54A94374640FF21FDF675784740C03FA54A9437464028452BF70277474024607479732C464028452BF702774740
14839	Ергенинский	2	19	1371	44.457183000000001	44.501452	47.112963000000001	47.097493999999998	0103000020E61000000100000005000000C2A4F8F8843A464032C7F2AE7A8C4740C2A4F8F8843A46403B545392758E4740C44142942F4046403B545392758E4740C44142942F40464032C7F2AE7A8C4740C2A4F8F8843A464032C7F2AE7A8C4740
15744	Годжур	2	19	1371	44.440959999999997	44.451208999999999	47.020131999999997	47.0122	0103000020E610000001000000050000000D6C9560713846406F8104C58F8147400D6C95607138464031CD74AF9382474097546D37C139464031CD74AF9382474097546D37C13946406F8104C58F8147400D6C9560713846406F8104C58F814740
57202	Гаршун-Бургуста	2	19	1371	44.478186000000001	44.511208000000003	47.244644000000001	47.229354000000001	0103000020E61000000100000005000000D9B3E732353D4640789ACC785B9D4740D9B3E732353D4640D1949D7E509F47400FBA84436F414640D1949D7E509F47400FBA84436F414640789ACC785B9D4740D9B3E732353D4640789ACC785B9D4740
15647	Алцынхута	2	19	1371	44.909376999999999	44.932194000000003	47.047100999999998	47.030163000000002	0103000020E61000000100000005000000075E2D77667446404E469561DC834740075E2D7766744640F04DD3670786474083C30B2252774640F04DD3670786474083C30B22527746404E469561DC834740075E2D77667446404E469561DC834740
52927	Южный	2	19	1357	44.681187000000001	44.707526000000001	45.530712000000001	45.518253999999999	0103000020E61000000100000005000000EDBAB72231574640B682A62556C24640EDBAB7223157464021CCED5EEEC34640EC884336905A464021CCED5EEEC34640EC884336905A4640B682A62556C24640EDBAB72231574640B682A62556C24640
57178	Шееринг	2	19	1357	44.598371	44.605880999999997	46.125501999999997	46.121360000000003	0103000020E61000000100000005000000FAEFC16B974C4640738577B9880F4740FAEFC16B974C464092CA147310104740462234828D4D464092CA147310104740462234828D4D4640738577B9880F4740FAEFC16B974C4640738577B9880F4740
15302	Чолун Хамур	2	19	1357	44.845632999999999	44.859699999999997	45.508180000000003	45.495944000000001	0103000020E610000001000000050000008DB5BFB33D6C4640DF52CE177BBF46408DB5BFB33D6C46409B3DD00A0CC14640832F4CA60A6E46409B3DD00A0CC14640832F4CA60A6E4640DF52CE177BBF46408DB5BFB33D6C4640DF52CE177BBF4640
15206	Хомутников	2	19	1357	44.792155999999999	44.833362000000001	45.612397000000001	45.597906999999999	0103000020E6100000010000000500000043AA285E656546405586713788CC464043AA285E6565464092955F0663CE464055DD239BAB6A464092955F0663CE464055DD239BAB6A46405586713788CC464043AA285E656546405586713788CC4640
52921	Ут-Сала	2	19	1357	44.898130000000002	44.920822000000001	45.881563999999997	45.873784000000001	0103000020E610000001000000050000003BC780ECF572464050E27327D8EF46403BC780ECF57246405CAAD216D7F04640FAB7CB7EDD7546405CAAD216D7F04640FAB7CB7EDD75464050E27327D8EF46403BC780ECF572464050E27327D8EF4640
52920	Светлый	2	19	1357	45.253943999999997	45.267786999999998	45.599376999999997	45.578487000000003	0103000020E61000000100000005000000F981AB3C81A04640A114ADDC0BCA4640F981AB3C81A04640BF7CB262B8CC4640A0A52BD846A24640BF7CB262B8CC4640A0A52BD846A24640A114ADDC0BCA4640F981AB3C81A04640A114ADDC0BCA4640
15075	Приманыч	2	19	1357	44.524951999999999	44.540447999999998	45.977817000000002	45.966493	0103000020E6100000010000000500000022FC8BA0314346400E68E90AB6FB464022FC8BA031434640863C821B29FD464024986A662D454640863C821B29FD464024986A662D4546400E68E90AB6FB464022FC8BA0314346400E68E90AB6FB4640
14987	Оргакин	2	19	1357	44.450130999999999	44.459958999999998	46.100335999999999	46.093324000000003	0103000020E6100000010000000500000038F581E49D39464049F7730AF20B474038F581E49D394640444E5FCFD70C47401C40BFEFDF3A4640444E5FCFD70C47401C40BFEFDF3A464049F7730AF20B474038F581E49D39464049F7730AF20B4740
14897	Манцин Кец	2	19	1357	44.733280000000001	44.747860000000003	45.503442999999997	45.493707999999998	0103000020E61000000100000005000000CB67791EDC5D464004E3E0D231BF4640CB67791EDC5D46403733FAD170C0464048FE60E0B95F46403733FAD170C0464048FE60E0B95F464004E3E0D231BF4640CB67791EDC5D464004E3E0D231BF4640
57197	Лола	2	19	1357	44.246304000000002	44.264980000000001	46.161611000000001	46.146521999999997	0103000020E61000000100000005000000DF6FB4E3861F46407F129F3BC1124740DF6FB4E3861F464041D653ABAF1447400B0C59DDEA21464041D653ABAF1447400B0C59DDEA2146407F129F3BC1124740DF6FB4E3861F46407F129F3BC1124740
14791	Кевюды	2	19	1357	44.229199999999999	44.246169000000002	45.844203	45.831060999999998	0103000020E61000000100000005000000211FF46C561D464093FDF33460EA4640211FF46C561D4640B1170AD80EEC4640FF243E77821F4640B1170AD80EEC4640FF243E77821F464093FDF33460EA4640211FF46C561D464093FDF33460EA4640
14699	Ики-Бурул	2	19	1357	44.622698	44.66075	45.834018	45.812727000000002	0103000020E610000001000000050000006EA46C91B44F4640C1C9367007E846406EA46C91B44F46403E23111AC1EA46407F6ABC74935446403E23111AC1EA46407F6ABC7493544640C1C9367007E846406EA46C91B44F4640C1C9367007E84640
14638	Зунда Толга	2	19	1357	44.250804000000002	44.267207999999997	45.617351999999997	45.607106999999999	0103000020E610000001000000050000005EDA70581A2046401A16A3AEB5CD46405EDA70581A204640620FED6305CF4640629D2ADF33224640620FED6305CF4640629D2ADF332246401A16A3AEB5CD46405EDA70581A2046401A16A3AEB5CD4640
15263	Южный	2	19	1289	42.010010999999999	42.028120999999999	46.109690000000001	46.095655000000001	0103000020E61000000100000005000000D5CC5A0A4801454075594C6C3E0C4740D5CC5A0A48014540605969520A0E474058AA0B7899034540605969520A0E474058AA0B789903454075594C6C3E0C4740D5CC5A0A4801454075594C6C3E0C4740
32798	Пушкинское	2	19	1289	41.788648000000002	41.809049000000002	46.118637	46.105072999999997	0103000020E610000001000000050000002507EC6AF2E44440A7583508730D47402507EC6AF2E444403B8C497F2F0F474046EEE9EA8EE744403B8C497F2F0F474046EEE9EA8EE74440A7583508730D47402507EC6AF2E44440A7583508730D4740
32739	Лазаревский	2	19	1289	41.885036999999997	41.925407	46.076977999999997	46.062897999999997	0103000020E61000000100000005000000FE5F75E448F14440ED7DAA0A0D084740FE5F75E448F144407841446ADA094740A73E90BC73F644407841446ADA094740A73E90BC73F64440ED7DAA0A0D084740FE5F75E448F14440ED7DAA0A0D084740
57167	Дружное	2	19	1289	42.050928999999996	42.072938000000001	46.297102000000002	46.290795000000003	0103000020E6100000010000000500000080B56AD784064540906B43C53825474080B56AD784064540C1C93670072647405D514A0856094540C1C93670072647405D514A0856094540906B43C53825474080B56AD784064540906B43C538254740
32704	Городовиковск	2	19	1289	41.890183999999998	41.960433000000002	46.115588000000002	46.052672000000001	0103000020E6100000010000000500000013B69F8CF1F144401CB5C2F4BD06474013B69F8CF1F14440B0E76B96CB0E4740E57FF277EFFA4440B0E76B96CB0E4740E57FF277EFFA44401CB5C2F4BD06474013B69F8CF1F144401CB5C2F4BD064740
57152	Виноградное	2	19	1289	41.932774000000002	42.026125999999998	46.226633999999997	46.212972000000001	0103000020E610000001000000050000009147702365F744405B7B9FAA421B47409147702365F74440B114C957021D4740A3C9C51858034540B114C957021D4740A3C9C518580345405B7B9FAA421B47409147702365F744405B7B9FAA421B4740
46265	Веселое	2	19	1289	41.982010000000002	42.012318999999998	46.265293999999997	46.250793999999999	0103000020E61000000100000005000000282CF180B2FD44403A048E041A204740282CF180B2FD44409AE95E27F5214740490F43AB930145409AE95E27F5214740490F43AB930145403A048E041A204740282CF180B2FD44403A048E041A204740
14598	Бага-Бурул	2	19	1289	41.740093999999999	41.764572999999999	45.988889	45.980041	0103000020E61000000100000005000000A0FB7266BBDE44409CDEC5FB71FD4640A0FB7266BBDE4440E42F2DEA93FE4640CA332F87DDE14440E42F2DEA93FE4640CA332F87DDE144409CDEC5FB71FD4640A0FB7266BBDE44409CDEC5FB71FD4640
57194	Розенталь	2	19	7419	42.041955000000002	42.068491000000002	46.072608000000002	46.062359999999998	0103000020E61000000100000005000000AC730CC85E0545400E4A9869FB074740AC730CC85E054540C8B60C384B09474001892650C4084540C8B60C384B09474001892650C40845400E4A9869FB074740AC730CC85E0545400E4A9869FB074740
57030	Майкоп	2	18	\N	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
58944	Игнатьевский	2	18	\N	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
58881	Дмитриевский	2	18	\N	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
57050	Адыгейск	2	18	\N	39.166367000000001	39.212145	44.897570000000002	44.872298999999998	0103000020E610000001000000050000001B118C834B954340B0AA5E7EA76F46401B118C834B95434074EFE192E372464045813E91279B434074EFE192E372464045813E91279B4340B0AA5E7EA76F46401B118C834B954340B0AA5E7EA76F4640
40357	аул Хакуринохабль	2	18	1763	39.887956000000003	40.365850999999999	45.122836999999997	44.913594000000003	0103000020E61000000100000005000000BC24CE8AA8F1434032E9EFA5F0744640BC24CE8AA8F143408FDE701FB98F4640BD1AA034D42E44408FDE701FB98F4640BD1AA034D42E444032E9EFA5F0744640BC24CE8AA8F1434032E9EFA5F0744640
57055	Чернышев	2	18	1763	40.029414000000003	40.049239999999998	45.058382999999999	45.043233999999998	0103000020E61000000100000005000000B40584D6C3034440A20914B188854640B40584D6C303444039D2191879874640D8D30E7F4D06444039D2191879874640D8D30E7F4D064440A20914B188854640B40584D6C3034440A20914B188854640
57056	Хатажукай	2	18	1763	40.175884000000003	40.194192000000001	45.080097000000002	45.059184999999999	0103000020E61000000100000005000000E1F1ED5D83164440F6B4C35F93874640E1F1ED5D83164440FDC0559E408A46408A929048DB184440FDC0559E408A46408A929048DB184440F6B4C35F93874640E1F1ED5D83164440F6B4C35F93874640
57053	Хакуринохабль	2	18	1763	40.218572000000002	40.254739000000001	45.030163999999999	45.00956	0103000020E6100000010000000500000021E9D32AFA1B4440C5AC17433981464021E9D32AFA1B44401EC2F869DC83464004029D499B2044401EC2F869DC83464004029D499B204440C5AC17433981464021E9D32AFA1B4440C5AC174339814640
25097	Тихонов	2	18	1763	39.946328999999999	39.966262999999998	44.973162000000002	44.957863000000003	0103000020E61000000100000005000000D120054F21F94340348639419B7A4640D120054F21F94340E0DA8992907C4640DC2A8881AEFB4340E0DA8992907C4640DC2A8881AEFB4340348639419B7A4640D120054F21F94340348639419B7A4640
57091	Семено-Макаровский	2	18	1763	40.232146	40.253776999999999	44.923991000000001	44.913651000000002	0103000020E61000000100000005000000D8F2CAF5B61D4440967A1684F2744640D8F2CAF5B61D444030664B56457646400EBDC5C37B20444030664B56457646400EBDC5C37B204440967A1684F2744640D8F2CAF5B61D4440967A1684F2744640
25372	Свободный Труд	2	18	1763	40.282811000000002	40.312095999999997	44.988003999999997	44.974915000000003	0103000020E610000001000000050000007BF99D26332444409FB0C403CA7C46407BF99D2633244440992842EA767E4640309B00C3F2274440992842EA767E4640309B00C3F22744409FB0C403CA7C46407BF99D26332444409FB0C403CA7C4640
57080	Пшичо	2	18	1763	40.164844000000002	40.185963999999998	45.079338999999997	45.049016999999999	0103000020E610000001000000050000008E78B29B1915444059F96530468646408E78B29B191544400F26C5C7278A4640DE1D19ABCD1744400F26C5C7278A4640DE1D19ABCD17444059F96530468646408E78B29B1915444059F9653046864640
57057	Пшизов	2	18	1763	40.092889	40.117421999999998	45.09939	45.087333000000001	0103000020E610000001000000050000003E9468C9E30B4440486E4DBA2D8B46403E9468C9E30B444054C6BFCFB88C46405BEA20AF070F444054C6BFCFB88C46405BEA20AF070F4440486E4DBA2D8B46403E9468C9E30B4440486E4DBA2D8B4640
57096	Михайлов	2	18	1763	40.147911000000001	40.154890999999999	44.979768	44.972389999999997	0103000020E61000000100000005000000FDDB65BFEE1244408D7A8846777C4640FDDB65BFEE1244406BD5AE09697D4640EDB8E177D31344406BD5AE09697D4640EDB8E177D31344408D7A8846777C4640FDDB65BFEE1244408D7A8846777C4640
57049	Мамхег	2	18	1763	40.203921000000001	40.233995999999998	45.023839000000002	45.001199	0103000020E61000000100000005000000DBFB54151A1A4440DAE4F04927804640DBFB54151A1A444047AF06280D83464089B2B794F31D444047AF06280D83464089B2B794F31D4440DAE4F04927804640DBFB54151A1A4440DAE4F04927804640
25136	Мамацев	2	18	1763	39.984867000000001	39.995987999999997	44.948875000000001	44.936523999999999	0103000020E610000001000000050000006FF4311F10FE4340A5F5B704E07746406FF4311F10FE4340FA7E6ABC74794640AE9AE7887CFF4340FA7E6ABC74794640AE9AE7887CFF4340A5F5B704E07746406FF4311F10FE4340A5F5B704E0774640
57101	Киров	2	18	1763	40.254550000000002	40.273594000000003	45.094650000000001	45.089177999999997	0103000020E6100000010000000500000031992A1895204440E7C2482F6A8B464031992A18952044408048BF7D1D8C4640E030D120052344408048BF7D1D8C4640E030D12005234440E7C2482F6A8B464031992A1895204440E7C2482F6A8B4640
57081	Кабехабль	2	18	1763	40.176279999999998	40.187302000000003	45.049442999999997	45.038832999999997	0103000020E610000001000000050000002D78D15790164440B680D07AF88446402D78D157901644401002F22554864640DA3C0E83F91744401002F22554864640DA3C0E83F9174440B680D07AF88446402D78D15790164440B680D07AF8844640
25226	Зарево	2	18	1763	40.071517999999998	40.094138000000001	45.014581	44.987347999999997	0103000020E61000000100000005000000A489778027094440B0E2546B617E4640A4897780270944404D124BCADD814640CAA7C7B60C0C44404D124BCADD814640CAA7C7B60C0C4440B0E2546B617E4640A489778027094440B0E2546B617E4640
25053	Дукмасов	2	18	1763	39.901701000000003	39.929423	45.013823000000002	44.996935000000001	0103000020E61000000100000005000000A0E238F06AF343406F9EEA909B7F4640A0E238F06AF343406077BAF3C48146403A933655F7F643406077BAF3C48146403A933655F7F643406F9EEA909B7F4640A0E238F06AF343406F9EEA909B7F4640
57079	Джерокай	2	18	1763	40.295881000000001	40.321367000000002	44.997329999999998	44.978676999999998	0103000020E61000000100000005000000FF40B96DDF254440772CB649457D4640FF40B96DDF254440EBA86A82A87F4640BF81C98D22294440EBA86A82A87F4640BF81C98D22294440772CB649457D4640FF40B96DDF254440772CB649457D4640
57069	Шевченко	2	18	1298	39.509504999999997	39.529133000000002	44.905952999999997	44.889678000000004	0103000020E610000001000000050000000113B87537C1434040FCFCF7E07146400113B87537C14340465B9544F6734640001E51A1BAC34340465B9544F6734640001E51A1BAC3434040FCFCF7E07146400113B87537C1434040FCFCF7E0714640
24202	Четук	2	18	1298	39.145175000000002	39.158209999999997	44.879019	44.864888999999998	0103000020E6100000010000000500000031992A1895924340C7D5C8AEB46E464031992A189592434004C8D0B18370464038F3AB394094434004C8D0B18370464038F3AB3940944340C7D5C8AEB46E464031992A1895924340C7D5C8AEB46E4640
57102	Тугургой	2	18	1298	39.106349999999999	39.123831000000003	44.956809999999997	44.947899	0103000020E61000000100000005000000FDF675E09C8D43409F7422C154794640FDF675E09C8D43402D3E05C0787A4640919DB7B1D98F43402D3E05C0787A4640919DB7B1D98F43409F7422C154794640FDF675E09C8D43409F7422C154794640
23996	Тлюстенхабль	2	18	1298	39.076858999999999	39.113895999999997	44.997278999999999	44.971957000000003	0103000020E610000001000000050000009EB30584D6894340240F4416697C46409EB30584D689434069FE98D6A67F46409692E524948E434069FE98D6A67F46409692E524948E4340240F4416697C46409EB30584D6894340240F4416697C4640
57082	Тауйхабль	2	18	1298	39.363574	39.378521999999997	44.968870000000003	44.961556000000002	0103000020E6100000010000000500000084D6C39789AE4340E4A25A44147B464084D6C39789AE4340AB09A2EE037C46408368AD6873B04340AB09A2EE037C46408368AD6873B04340E4A25A44147B464084D6C39789AE4340E4A25A44147B4640
57099	Пшикуйхабль	2	18	1298	39.361229000000002	39.374811999999999	44.949359999999999	44.935234999999999	0103000020E61000000100000005000000F3AE7AC03CAE43408B89CDC7B5774640F3AE7AC03CAE4340B610E4A084794640FD12F1D6F9AF4340B610E4A084794640FD12F1D6F9AF43408B89CDC7B5774640F3AE7AC03CAE43408B89CDC7B5774640
57067	Пчегатлукай	2	18	1298	39.255318000000003	39.273032999999998	44.903297000000002	44.871079000000002	0103000020E61000000100000005000000420A9E42AEA04340BF9D44847F6F4640420A9E42AEA0434097C9703C9F73464048DDCEBEF2A2434097C9703C9F73464048DDCEBEF2A24340BF9D44847F6F4640420A9E42AEA04340BF9D44847F6F4640
57039	Понежукай	2	18	1298	39.365504999999999	39.399866000000003	44.900717999999998	44.878833999999998	0103000020E6100000010000000500000022C32ADEC8AE4340724EECA17D70464022C32ADEC8AE4340927538BA4A734640246420CF2EB34340927538BA4A734640246420CF2EB34340724EECA17D70464022C32ADEC8AE4340724EECA17D704640
57074	Петров	2	18	1298	39.495348	39.509748000000002	44.941589999999998	44.925879999999999	0103000020E61000000100000005000000CB11329067BF43409F02603C83764640CB11329067BF4340CD1E680586784640C899266C3FC14340CD1E680586784640C899266C3FC143409F02603C83764640CB11329067BF43409F02603C83764640
57059	Нешукай	2	18	1298	39.408507999999998	39.426537000000003	44.916766000000003	44.898521000000002	0103000020E61000000100000005000000C2137AFD49B4434076E272BC02734640C2137AFD49B44340D90A9A965875464059C4B0C398B64340D90A9A965875464059C4B0C398B6434076E272BC02734640C2137AFD49B4434076E272BC02734640
57086	Начерезий	2	18	1298	39.376249000000001	39.391916000000002	44.929760000000002	44.918534000000001	0103000020E610000001000000050000008C135FED28B04340CD21A985927546408C135FED28B0434082902C6002774640BB63B14D2AB2434082902C6002774640BB63B14D2AB24340CD21A985927546408C135FED28B04340CD21A98592754640
24649	Красное	2	18	1298	39.446416999999997	39.464365000000001	44.883367999999997	44.866543999999998	0103000020E6100000010000000500000070B0373124B94340C345EEE9EA6E464070B0373124B943409D2ADF33127146401A34F44F70BB43409D2ADF33127146401A34F44F70BB4340C345EEE9EA6E464070B0373124B94340C345EEE9EA6E4640
57103	Красненский	2	18	1298	39.072951000000003	39.651007999999997	45.030616999999999	44.806161000000003	0103000020E61000000100000005000000F29A577556894340C4279D4830674640F29A577556894340CFD90242EB83464099B7EA3A54D34340CFD90242EB83464099B7EA3A54D34340C4279D4830674640F29A577556894340C4279D4830674640
57088	Кончукохабль	2	18	1298	39.464688000000002	39.487549999999999	44.990752000000001	44.975821000000003	0103000020E61000000100000005000000FD6B79E57ABB434001E0D8B3E77C4640FD6B79E57ABB43402A3927F6D07E46401895D40968BE43402A3927F6D07E46401895D40968BE434001E0D8B3E77C4640FD6B79E57ABB434001E0D8B3E77C4640
57095	Казазов	2	18	1298	39.165253	39.185994999999998	44.909764000000003	44.896707999999997	0103000020E610000001000000050000006F48A30227954340E107E753C77246406F48A30227954340018A912573744640191C25AFCE974340018A912573744640191C25AFCE974340E107E753C77246406F48A30227954340E107E753C7724640
57075	Джиджихабль	2	18	1298	39.394196999999998	39.425108000000002	44.960318000000001	44.936746999999997	0103000020E6100000010000000500000035971B0C75B2434024D06053E777464035971B0C75B243404CE141B3EB7A46404DA25EF069B643404CE141B3EB7A46404DA25EF069B6434024D06053E777464035971B0C75B2434024D06053E7774640
57087	Городской	2	18	1298	39.426681000000002	39.440002999999997	44.996290999999999	44.988329999999998	0103000020E610000001000000050000008C69A67B9DB64340EDD3F198817E46408C69A67B9DB643404A26A776867F46402992AF0452B843404A26A776867F46402992AF0452B84340EDD3F198817E46408C69A67B9DB64340EDD3F198817E4640
57040	Габукай	2	18	1298	39.549830999999998	39.579636999999998	44.943286999999998	44.915075000000002	0103000020E61000000100000005000000DAA9B9DC60C643409031772D21754640DAA9B9DC60C64340F8DEDFA0BD7846409946938B31CA4340F8DEDFA0BD7846409946938B31CA43409031772D21754640DAA9B9DC60C643409031772D21754640
57048	Вочепший	2	18	1298	39.273634999999999	39.297099000000003	44.888043000000003	44.860660000000003	0103000020E610000001000000050000003E05C07806A34340D97C5C1B2A6E46403E05C07806A343408B389D64AB71464050560C5707A643408B389D64AB71464050560C5707A64340D97C5C1B2A6E46403E05C07806A34340D97C5C1B2A6E4640
57052	Ассоколай	2	18	1298	39.453907999999998	39.488627999999999	44.858021000000001	44.828116999999999	0103000020E6100000010000000500000046B247A819BA43407D21E4BCFF69464046B247A819BA4340FF23D3A1D36D464077F4BF5C8BBE4340FF23D3A1D36D464077F4BF5C8BBE43407D21E4BCFF69464046B247A819BA43407D21E4BCFF694640
13653	Адыгейск	2	18	1298	39.166367000000001	39.212145	44.897570000000002	44.872298999999998	0103000020E610000001000000050000001B118C834B954340B0AA5E7EA76F46401B118C834B95434074EFE192E372464045813E91279B434074EFE192E372464045813E91279B4340B0AA5E7EA76F46401B118C834B954340B0AA5E7EA76F4640
57083	аул Новая Адыгея	2	18	1196	38.683145000000003	39.131898	45.064495000000001	44.819180000000003	0103000020E6100000010000000500000085B69C4B71574340C6C4E6E3DA68464085B69C4B71574340B5E0455F4188464033349E08E2904340B5E0455F4188464033349E08E2904340C6C4E6E3DA68464085B69C4B71574340C6C4E6E3DA684640
23063	Яблоновский	2	18	1196	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
11525	Энем	2	18	1196	38.886837999999997	38.925960000000003	44.941437000000001	44.907069999999997	0103000020E61000000100000005000000CE6C57E8837143406397A8DE1A744640CE6C57E883714340471FF30181784640BCB376DB85764340471FF30181784640BCB376DB857643406397A8DE1A744640CE6C57E8837143406397A8DE1A744640
57037	Шенджий	2	18	1196	39.031556999999999	39.075996000000004	44.898713000000001	44.872535999999997	0103000020E61000000100000005000000DD7A4D0F0A844340944A7842AF6F4640DD7A4D0F0A844340BABE0F07097346403C50A73CBA894340BABE0F07097346403C50A73CBA894340944A7842AF6F4640DD7A4D0F0A844340944A7842AF6F4640
23710	Хомуты	2	18	1196	38.863742000000002	38.880361000000001	45.001052000000001	44.994137000000002	0103000020E6100000010000000500000040170D198F6E43402D5F97E13F7F464040170D198F6E434036CCD0782280464041D653ABAF70434036CCD0782280464041D653ABAF7043402D5F97E13F7F464040170D198F6E43402D5F97E13F7F4640
57085	Хаштук	2	18	1196	38.746026999999998	38.763849999999998	45.048921	45.035590999999997	0103000020E610000001000000050000006C770FD07D5F43401684F23E8E8446406C770FD07D5F4340378B170B43864640598638D6C5614340378B170B43864640598638D6C56143401684F23E8E8446406C770FD07D5F43401684F23E8E844640
57034	Тахтамукай	2	18	1196	38.973075999999999	39.013986000000003	44.935355999999999	44.909891999999999	0103000020E61000000100000005000000E1421EC18D7C43402E724F5777744640E1421EC18D7C4340060FD3BEB97746400A4D124BCA814340060FD3BEB97746400A4D124BCA8143402E724F5777744640E1421EC18D7C43402E724F5777744640
12310	Суповский	2	18	1196	38.932338000000001	38.955739000000001	44.911053000000003	44.890712000000001	0103000020E61000000100000005000000B66801DA56774340CF13CFD902724640B66801DA567743401BF67B629D7446408141D2A7557A43401BF67B629D7446408141D2A7557A4340CF13CFD902724640B66801DA56774340CF13CFD902724640
57041	Старобжегокай	2	18	1196	38.884205999999999	38.903601000000002	45.046889999999998	45.024928000000003	0103000020E61000000100000005000000A77686A92D7143409A6038D730834640A77686A92D7143403541D47D0086464003D19332A97343403541D47D0086464003D19332A97343409A6038D730834640A77686A92D7143409A6038D730834640
57097	Псейтук	2	18	1196	38.694419000000003	38.716912999999998	45.05986	45.043343	0103000020E610000001000000050000004B5CC7B8E258434059C16F438C8546404B5CC7B8E2584340562B137EA9874640E38920CEC35B4340562B137EA9874640E38920CEC35B434059C16F438C8546404B5CC7B8E258434059C16F438C854640
22713	Прикубанский	2	18	1196	39.022475	39.035276000000003	44.966670000000001	44.946694000000001	0103000020E6100000010000000500000022FDF675E0824340E3A8DC442D79464022FDF675E08243401D03B2D7BB7B4640B72A89EC838443401D03B2D7BB7B4640B72A89EC83844340E3A8DC442D79464022FDF675E0824340E3A8DC442D794640
57105	Перекатный	2	18	1196	38.683145000000003	39.131898	45.064495000000001	44.819180000000003	0103000020E6100000010000000500000085B69C4B71574340C6C4E6E3DA68464085B69C4B71574340B5E0455F4188464033349E08E2904340B5E0455F4188464033349E08E2904340C6C4E6E3DA68464085B69C4B71574340C6C4E6E3DA684640
57047	Панахес	2	18	1196	38.692999	38.738247999999999	44.996048999999999	44.975456999999999	0103000020E610000001000000050000009294F430B4584340BFD364C6DB7C46409294F430B4584340541B9C887E7F4640302B14E97E5E4340541B9C887E7F4640302B14E97E5E4340BFD364C6DB7C46409294F430B4584340BFD364C6DB7C4640
22743	Отрадный	2	18	1196	38.945901999999997	38.962853000000003	44.880999000000003	44.863458000000001	0103000020E61000000100000005000000499C1551137943401BBCAFCA856E4640499C15511379434084674293C470464081ED60C43E7B434084674293C470464081ED60C43E7B43401BBCAFCA856E4640499C1551137943401BBCAFCA856E4640
57066	Новый Сад	2	18	1196	38.901435999999997	38.918017999999996	44.909399999999998	44.900226000000004	0103000020E61000000100000005000000F1B73D41627343402481069B3A734640F1B73D4162734340BF7D1D3867744640D591239D81754340BF7D1D3867744640D591239D817543402481069B3A734640F1B73D41627343402481069B3A734640
57094	Новобжегокай	2	18	1196	38.829687	38.849603000000002	44.939841999999999	44.924456999999997	0103000020E610000001000000050000004B75012F336A434075C7629B547646404B75012F336A434020B41EBE4C784640B0CA85CABF6C434020B41EBE4C784640B0CA85CABF6C434075C7629B547646404B75012F336A434075C7629B54764640
57073	Натухай	2	18	1196	38.980441999999996	38.997644999999999	44.870575000000002	44.857523	0103000020E61000000100000005000000FACF9A1F7F7D4340AE484C50C36D4640FACF9A1F7F7D43408CDB68006F6F46404B02D4D4B27F43408CDB68006F6F46404B02D4D4B27F4340AE484C50C36D4640FACF9A1F7F7D4340AE484C50C36D4640
57089	Кубаньстрой	2	18	1196	38.683145000000003	39.131898	45.064495000000001	44.819180000000003	0103000020E6100000010000000500000085B69C4B71574340C6C4E6E3DA68464085B69C4B71574340B5E0455F4188464033349E08E2904340B5E0455F4188464033349E08E2904340C6C4E6E3DA68464085B69C4B71574340C6C4E6E3DA684640
57045	Козет	2	18	1196	38.990161999999998	39.012098999999999	45.003014999999998	44.984938	0103000020E61000000100000005000000F8DEDFA0BD7E4340384BC972127E4640F8DEDFA0BD7E4340DF32A7CB628046403BA8C4758C814340DF32A7CB628046403BA8C4758C814340384BC972127E4640F8DEDFA0BD7E4340384BC972127E4640
12216	Дружный	2	18	1196	38.885122000000003	38.898938000000001	44.964993	44.950330000000001	0103000020E610000001000000050000002D7C7DAD4B7143402F34D769A47946402D7C7DAD4B71434039EFFFE3847B4640DA907F661073434039EFFFE3847B4640DA907F66107343402F34D769A47946402D7C7DAD4B7143402F34D769A4794640
57038	Афипсип	2	18	1196	38.766365	38.795029999999997	45.010171999999997	44.976458000000001	0103000020E6100000010000000500000047E6913F1862434073F56393FC7C464047E6913F18624340DEAAEB504D81464060AB048BC3654340DEAAEB504D81464060AB048BC365434073F56393FC7C464047E6913F1862434073F56393FC7C4640
57110	пос. Трехречный	2	18	1243	39.765732	40.482658999999998	44.793356000000003	43.761000000000003	0103000020E6100000010000000500000016C0948103E24340C520B07268E1454016C0948103E24340EE0A7DB08C6546405E0F26C5C73D4440EE0A7DB08C6546405E0F26C5C73D4440C520B07268E1454016C0948103E24340C520B07268E14540
60675	аул Кошехабль	2	18	1243	39.765732	40.482658999999998	44.793356000000003	43.761000000000003	0103000020E6100000010000000500000016C0948103E24340C520B07268E1454016C0948103E24340EE0A7DB08C6546405E0F26C5C73D4440EE0A7DB08C6546405E0F26C5C73D4440C520B07268E1454016C0948103E24340C520B07268E14540
57077	Шунтук	2	18	1243	40.154935999999999	40.179073000000002	44.461939000000001	44.446072000000001	0103000020E610000001000000050000008D7C5EF1D4134440A6D425E3183946408D7C5EF1D41344409CDF30D1203B46405E4C33DDEB1644409CDF30D1203B46405E4C33DDEB164440A6D425E3183946408D7C5EF1D4134440A6D425E318394640
57063	Шаумян	2	18	1243	40.131059	40.147101999999997	44.501927999999999	44.479480000000002	0103000020E61000000100000005000000596C938AC6104440058BC3995F3D4640596C938AC61044402D793C2D3F4046408D96033DD41244402D793C2D3F4046408D96033DD4124440058BC3995F3D4640596C938AC6104440058BC3995F3D4640
17220	Цветочный	2	18	1243	40.152250000000002	40.174537000000001	44.505149000000003	44.490051999999999	0103000020E61000000100000005000000736891ED7C13444071AB2006BA3E4640736891ED7C134440B64DF1B8A84046409278793A57164440B64DF1B8A84046409278793A5716444071AB2006BA3E4640736891ED7C13444071AB2006BA3E4640
22098	Ханская	2	18	1243	39.928623000000002	39.991101	44.721632	44.645187	0103000020E610000001000000050000001EA8531EDDF64340F566D47C955246401EA8531EDDF64340A0DFF76F5E5C46403604C765DCFE4340A0DFF76F5E5C46403604C765DCFE4340F566D47C955246401EA8531EDDF64340F566D47C95524640
57090	Усть-Сахрайский	2	18	1243	40.275444999999998	40.288884000000003	44.212178000000002	44.202950999999999	0103000020E61000000100000005000000616C21C84123444062D8614CFA194640616C21C841234440217711A6281B4640392BA226FA244440217711A6281B4640392BA226FA24444062D8614CFA194640616C21C84123444062D8614CFA194640
18483	Удобный	2	18	1243	40.147452999999999	40.166361999999999	44.559913999999999	44.544395000000002	0103000020E610000001000000050000003A596ABDDF1244408F8D40BCAE4546403A596ABDDF12444049490F43AB47464009A69A594B15444049490F43AB47464009A69A594B1544408F8D40BCAE4546403A596ABDDF1244408F8D40BCAE454640
16951	Тульский	2	18	1243	40.15896	40.204225999999998	44.534320999999998	44.489609000000002	0103000020E61000000100000005000000A3AF20CD58144440E469F981AB3E4640A3AF20CD5814444073486AA164444640177FDB13241A444073486AA164444640177FDB13241A4440E469F981AB3E4640A3AF20CD58144440E469F981AB3E4640
57078	Тимирязева	2	18	1243	40.161332000000002	40.177464999999998	44.474746000000003	44.461700999999998	0103000020E610000001000000050000002EE6E786A6144440E7C3B304193B46402EE6E786A614444013F4177AC43C4640A297512CB716444013F4177AC43C4640A297512CB7164440E7C3B304193B46402EE6E786A6144440E7C3B304193B4640
18322	Табачный	2	18	1243	40.082469000000003	40.103876	44.564121	44.544722999999998	0103000020E6100000010000000500000088F71C588E0A44408330B77BB945464088F71C588E0A444050FEEE1D354846406E6B0BCF4B0D444050FEEE1D354846406E6B0BCF4B0D44408330B77BB945464088F71C588E0A44408330B77BB9454640
18544	Совхозный	2	18	1243	40.147030999999998	40.160721000000002	44.548307000000001	44.536287000000002	0103000020E61000000100000005000000C43F6CE9D11244408E226B0DA5444640C43F6CE9D11244407D957CEC2E464640E5637781921444407D957CEC2E464640E5637781921444408E226B0DA5444640C43F6CE9D11244408E226B0DA5444640
12776	Советский	2	18	1243	40.091883000000003	40.113675999999998	44.674301999999997	44.666924000000002	0103000020E61000000100000005000000790778D2C20B4440717500C45D554640790778D2C20B44404ED026874F564640882B67EF8C0E44404ED026874F564640882B67EF8C0E4440717500C45D554640790778D2C20B4440717500C45D554640
33093	Северо-Восточные Сады	2	18	1243	40.111277999999999	40.15119	44.653190000000002	44.613805999999997	0103000020E61000000100000005000000D461855B3E0E4440560BEC31914E4640D461855B3E0E44408109DCBA9B534640BABDA4315A1344408109DCBA9B534640BABDA4315A134440560BEC31914E4640D461855B3E0E4440560BEC31914E4640
22324	Северный	2	18	1243	40.110836999999997	40.126018999999999	44.665987999999999	44.647348999999998	0103000020E61000000100000005000000E71725E82F0E4440950C0055DC524640E71725E82F0E4440A4C343183F5546405AD6FD6321104440A4C343183F5546405AD6FD6321104440950C0055DC524640E71725E82F0E4440950C0055DC524640
57098	Севастопольская	2	18	1243	40.279811000000002	40.331184999999998	44.364131999999998	44.340857999999997	0103000020E61000000100000005000000D107CBD8D02344403C4A253CA12B4640D107CBD8D0234440AAB69BE09B2E46407FF62345642A4440AAB69BE09B2E46407FF62345642A44403C4A253CA12B4640D107CBD8D02344403C4A253CA12B4640
22228	Родниковый	2	18	1243	39.99288	40.014493000000002	44.689177000000001	44.672885000000001	0103000020E610000001000000050000001E6D1CB116FF4340077C7E18215646401E6D1CB116FF4340E413B2F336584640AE8218E8DA014440E413B2F336584640AE8218E8DA014440077C7E18215646401E6D1CB116FF4340077C7E1821564640
57064	Пролетарский	2	18	1243	40.168905000000002	40.198934999999999	44.624879999999997	44.611097999999998	0103000020E61000000100000005000000C190D5AD9E15444054539275384E4640C190D5AD9E15444055F65D11FC4F4640CF83BBB37619444055F65D11FC4F4640CF83BBB37619444054539275384E4640C190D5AD9E15444054539275384E4640
17878	Победа	2	18	1243	40.130960000000002	40.160415	44.567279999999997	44.551769999999998	0103000020E61000000100000005000000C68A1A4CC3104440FB743C66A0464640C68A1A4CC310444062D68BA19C484640D8648D7A8814444062D68BA19C484640D8648D7A88144440FB743C66A0464640C68A1A4CC3104440FB743C66A0464640
17481	Первомайский	2	18	1243	40.174554999999998	40.201962999999999	44.414980999999997	44.397820000000003	0103000020E61000000100000005000000382D78D157164440EDD808C4EB324640382D78D1571644400EBBEF181E354640430070ECD91944400EBBEF181E354640430070ECD9194440EDD808C4EB324640382D78D157164440EDD808C4EB324640
17580	Новосвободная	2	18	1243	40.398567999999997	40.425769000000003	44.370119000000003	44.333843000000002	0103000020E61000000100000005000000B69DB64604334440D07F0F5EBB2A4640B69DB646043344406A50340F602F464048533D997F3644406A50340F602F464048533D997F364440D07F0F5EBB2A4640B69DB64604334440D07F0F5EBB2A4640
17994	Новопрохладное	2	18	1243	40.274878999999999	40.293663000000002	44.145766000000002	44.128065999999997	0103000020E61000000100000005000000B8AD2D3C2F23444061DD787764104640B8AD2D3C2F234440336FD575A8124640CB85CABF96254440336FD575A8124640CB85CABF9625444061DD787764104640B8AD2D3C2F23444061DD787764104640
32525	Майкоп	2	18	1243	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
18142	Курджипская	2	18	1243	40.038297999999998	40.071356000000002	44.48912	44.439700000000002	0103000020E6100000010000000500000048C0E8F2E60444408E06F0164838464048C0E8F2E6044440E6E8F17B9B3E4640CB2F833122094440E6E8F17B9B3E4640CB2F8331220944408E06F0164838464048C0E8F2E60444408E06F01648384640
19069	Кужорская	2	18	1243	40.283422000000002	40.328769000000001	44.692073000000001	44.651395000000001	0103000020E61000000100000005000000C47B0E2C4724444093E34EE960534640C47B0E2C47244440E9B81AD9955846402578431A152A4440E9B81AD9955846402578431A152A444093E34EE960534640C47B0E2C4724444093E34EE960534640
18236	Краснооктябрьский	2	18	1243	40.057361	40.107360999999997	44.585419000000002	44.567453999999998	0103000020E610000001000000050000006E88F19A5707444000FE2955A24846406E88F19A5707444080BA8102EF4A4640D4EE5701BE0D444080BA8102EF4A4640D4EE5701BE0D444000FE2955A24846406E88F19A5707444000FE2955A2484640
15404	Красная Улька	2	18	1243	40.170026999999997	40.178677999999998	44.702959	44.692464000000001	0103000020E61000000100000005000000EF37DA71C315444024D40CA9A2584640EF37DA71C3154440E5B67D8FFA594640E141B3EBDE164440E5B67D8FFA594640E141B3EBDE16444024D40CA9A2584640EF37DA71C315444024D40CA9A2584640
22357	Косинов	2	18	1243	40.083457000000003	40.093589999999999	44.736218999999998	44.728971000000001	0103000020E61000000100000005000000A7CF0EB8AE0A4440C05DF6EB4E5D4640A7CF0EB8AE0A4440CFD8976C3C5E4640C79DD2C1FA0B4440CFD8976C3C5E4640C79DD2C1FA0B4440C05DF6EB4E5D4640A7CF0EB8AE0A4440C05DF6EB4E5D4640
17658	Каменномостский	2	18	1243	40.160505000000001	40.207847000000001	44.318933999999999	44.280864999999999	0103000020E6100000010000000500000018EC866D8B144440A7CB6262F323464018EC866D8B1444408ECA4DD4D22846402EC901BB9A1A44408ECA4DD4D22846402EC901BB9A1A4440A7CB6262F323464018EC866D8B144440A7CB6262F3234640
21928	Западный	2	18	1243	40.038415000000001	40.081713999999998	44.634918999999996	44.621878000000002	0103000020E61000000100000005000000825660C8EA0444400B0DC4B2994F4640825660C8EA044440F44D9A06455146400BD0B69A750A4440F44D9A06455146400BD0B69A750A44400B0DC4B2994F4640825660C8EA0444400B0DC4B2994F4640
17943	Даховская	2	18	1243	40.190015000000002	40.221124000000003	44.245657000000001	44.215254000000002	0103000020E61000000100000005000000EE5F596952184440A62A6D718D1B4640EE5F596952184440498446B0711F46402C2E8ECA4D1C4440498446B0711F46402C2E8ECA4D1C4440A62A6D718D1B4640EE5F596952184440A62A6D718D1B4640
57072	Дагестанская	2	18	1243	39.999833000000002	40.041801999999997	44.387095000000002	44.363185000000001	0103000020E61000000100000005000000153B1A87FAFF4340EAB298D87C2E4640153B1A87FAFF4340FAB836548C314640257497C459054440FAB836548C314640257497C459054440EAB298D87C2E4640153B1A87FAFF4340EAB298D87C2E4640
57076	Грозный	2	18	1243	40.126764999999999	40.142170999999998	44.564492999999999	44.548442000000001	0103000020E6100000010000000500000083A3E4D5391044405DE0F2583346464083A3E4D53910444014E97E4E4148464045B8C9A83212444014E97E4E4148464045B8C9A8321244405DE0F2583346464083A3E4D5391044405DE0F25833464640
21997	Гавердовский	2	18	1243	40.008169000000002	40.040975000000003	44.621479999999998	44.606388000000003	0103000020E61000000100000005000000A7EB89AE0B014440EB573A1F9E4D4640A7EB89AE0B0144401D8F19A88C4F4640107A36AB3E0544401D8F19A88C4F4640107A36AB3E054440EB573A1F9E4D4640A7EB89AE0B014440EB573A1F9E4D4640
57068	Веселый	2	18	1243	40.190635	40.211061999999998	44.394978999999999	44.380834	0103000020E610000001000000050000008A3C49BA66184440399A232BBF3046408A3C49BA66184440ABCDFFAB8E324640D4B66114041B4440ABCDFFAB8E324640D4B66114041B4440399A232BBF3046408A3C49BA66184440399A232BBF304640
17350	Абадзехская	2	18	1243	40.202689999999997	40.237527	44.409436999999997	44.374842000000001	0103000020E61000000100000005000000F59CF4BEF1194440689599D2FA2F4640F59CF4BEF1194440DC627E6E683446406075E448671E4440DC627E6E683446406075E448671E4440689599D2FA2F4640F59CF4BEF1194440689599D2FA2F4640
16868	Штурбино	2	18	1167	39.896993000000002	39.929898999999999	45.066119	45.039923000000002	0103000020E61000000100000005000000D7DEA7AAD0F24340DAAD65321C854640D7DEA7AAD0F2434076525F9676884640A3CA30EE06F7434076525F9676884640A3CA30EE06F74340DAAD65321C854640D7DEA7AAD0F24340DAAD65321C854640
57033	Хатукай	2	18	1167	39.647019	39.678612999999999	45.203375999999999	45.178648000000003	0103000020E610000001000000050000000072C284D1D2434077BF0AF0DD9646400072C284D1D2434049658A39089A4640FAD170CADCD6434049658A39089A4640FAD170CADCD6434077BF0AF0DD9646400072C284D1D2434077BF0AF0DD964640
57042	Уляп	2	18	1167	39.931659000000003	39.974499999999999	45.066068000000001	45.040616999999997	0103000020E610000001000000050000001503249A40F74340B05417F0328546401503249A40F74340F4A78DEA74884640DBF97E6ABCFC4340F4A78DEA74884640DBF97E6ABCFC4340B05417F0328546401503249A40F74340B05417F032854640
11623	Саратовский	2	18	1167	39.755006000000002	39.772621999999998	45.105274999999999	45.093753	0103000020E6100000010000000500000053245F09A4E0434071732A19008C464053245F09A4E043400F0BB5A6798D4640C6151747E5E243400F0BB5A6798D4640C6151747E5E2434071732A19008C464053245F09A4E0434071732A19008C4640
16593	Садовое	2	18	1167	39.678820000000002	39.710988	45.012625	44.990043999999997	0103000020E6100000010000000500000074EFE192E3D64340EECC04C3B97E464074EFE192E3D64340560E2DB29D8146409AEC9FA701DB4340560E2DB29D8146409AEC9FA701DB4340EECC04C3B97E464074EFE192E3D64340EECC04C3B97E4640
16446	Преображенское	2	18	1167	39.611418999999998	39.638306	45.093989000000001	45.076296999999997	0103000020E61000000100000005000000969350FA42CE434036E49F19C4894640969350FA42CE43408597E0D4078C4640986BD102B4D143408597E0D4078C4640986BD102B4D1434036E49F19C4894640969350FA42CE434036E49F19C4894640
16543	Новосевастопольское	2	18	1167	39.694549000000002	39.718525	45.069524000000001	45.052346999999997	0103000020E61000000100000005000000193C4CFBE6D843409885764EB3864640193C4CFBE6D84340C0249529E6884640E02D90A0F8DB4340C0249529E6884640E02D90A0F8DB43409885764EB3864640193C4CFBE6D843409885764EB3864640
16181	Красногвардейское	2	18	1167	39.534388999999997	39.618093999999999	45.156978000000002	45.089063000000003	0103000020E61000000100000005000000CB2BD7DB66C443404F24986A668B4640CB2BD7DB66C443408318E8DA179446404AED45B41DCF43408318E8DA179446404AED45B41DCF43404F24986A668B4640CB2BD7DB66C443404F24986A668B4640
11077	Еленовское	2	18	1167	39.643228000000001	39.778199999999998	45.131326999999999	45.067200999999997	0103000020E610000001000000050000008DEF8B4B55D2434016A1D80A9A8846408DEF8B4B55D24340780AB952CF904640A4DFBE0E9CE34340780AB952CF904640A4DFBE0E9CE3434016A1D80A9A8846408DEF8B4B55D2434016A1D80A9A884640
57054	Джамбечи	2	18	1167	39.842008	39.871059000000002	45.098123999999999	45.076017	0103000020E61000000100000005000000357C0BEBC6EB43405378D0ECBA894640357C0BEBC6EB4340F279C5538F8C464078F17EDC7EEF4340F279C5538F8C464078F17EDC7EEF43405378D0ECBA894640357C0BEBC6EB43405378D0ECBA894640
16716	Верхненазаровское	2	18	1167	39.733787999999997	39.766154	45.021469000000003	44.994219999999999	0103000020E610000001000000050000003F19E3C3ECDD4340BA83D899427F46403F19E3C3ECDD43405D70067FBF8246408CD9925511E243405D70067FBF8246408CD9925511E24340BA83D899427F46403F19E3C3ECDD4340BA83D899427F4640
16746	Большесидоровское	2	18	1167	39.825145999999997	39.856417	45.046202000000001	45.022863999999998	0103000020E610000001000000050000006D3656629EE94340BC202235ED8246406D3656629EE94340418177F2E9854640855E7F129FED4340418177F2E9854640855E7F129FED4340BC202235ED8246406D3656629EE94340BC202235ED824640
57061	Бжедугхабль	2	18	1167	39.694082000000002	39.717384000000003	44.986876000000002	44.965127000000003	0103000020E61000000100000005000000035FD1ADD7D8434049BE1248897B4640035FD1ADD7D84340899AE8F3517E46403B56293DD3DB4340899AE8F3517E46403B56293DD3DB434049BE1248897B4640035FD1ADD7D8434049BE1248897B4640
57065	Белосельское	2	18	1167	39.293630999999998	40.017412999999998	45.218488999999998	44.957397	0103000020E61000000100000005000000BF0B5BB395A54340EE2422FC8B7A4640BF0B5BB395A5434093C49272F79B46403BC3D4963A02444093C49272F79B46403BC3D4963A024440EE2422FC8B7A4640BF0B5BB395A54340EE2422FC8B7A4640
57062	Адамий	2	18	1167	39.483463	39.510026000000003	45.07687	45.062368999999997	0103000020E61000000100000005000000BCE9961DE2BD434061A417B5FB874640BCE9961DE2BD434092054CE0D68946400B0E2F8848C1434092054CE0D68946400B0E2F8848C1434061A417B5FB874640BCE9961DE2BD434061A417B5FB874640
57043	аул Ходзь	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
57084	аул Хачемзий	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
57044	аул Егерухай	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
58958	Шелковников	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
61684	Поселок Дружба	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
57036	Майский	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
61122	Комсомольский	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
58894	Кармалино-Гидроицкий	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
58880	Казенно-Кужорский	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
57046	Вольное	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
58953	Вольное	2	18	7417	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
57058	Тамбовский	2	18	1319	40.363470999999997	40.376989999999999	44.764808000000002	44.745367999999999	0103000020E61000000100000005000000AF05BD37862E444012BEF737685F4640AF05BD37862E44400EDC813AE5614640A3755435413044400EDC813AE5614640A37554354130444012BEF737685F4640AF05BD37862E444012BEF737685F4640
57092	Смольчев-Малиновский	2	18	1319	40.414099999999998	40.436441000000002	44.875920999999998	44.861541000000003	0103000020E6100000010000000500000005A3923A01354440E294B9F9466E464005A3923A013544409770E82D1E70464018D1764CDD3744409770E82D1E70464018D1764CDD374440E294B9F9466E464005A3923A01354440E294B9F9466E4640
14799	Сергиевское	2	18	1319	40.332883000000002	40.368600000000001	44.822485	44.790177	0103000020E610000001000000050000007B32FFE89B2A444094861A85246546407B32FFE89B2A4440AC394030476946401EA7E8482E2F4440AC394030476946401EA7E8482E2F444094861A85246546407B32FFE89B2A444094861A8524654640
57100	Садовый	2	18	1319	40.230215000000001	40.241435000000003	44.841316999999997	44.833807	0103000020E610000001000000050000003A0664AF771D444083161230BA6A46403A0664AF771D4440CF488446B06B46400D8E9257E71E4440CF488446B06B46400D8E9257E71E444083161230BA6A46403A0664AF771D444083161230BA6A4640
57035	Прогресс	2	18	1319	40.181246999999999	40.199196000000001	44.875346	44.864179999999998	0103000020E61000000100000005000000C2BF081A33174440BBED42739D6E4640C2BF081A331744409B5775560B7046403CBF28417F1944409B5775560B7046403CBF28417F194440BBED42739D6E4640C2BF081A33174440BBED42739D6E4640
14291	Новый	2	18	1319	40.15605	40.193078	44.949354	44.912956000000001	0103000020E6100000010000000500000039454772F9134440EF5701BEDB74464039454772F9134440D4298F6E84794640DEC9A7C7B6184440D4298F6E84794640DEC9A7C7B6184440EF5701BEDB74464039454772F9134440EF5701BEDB744640
14313	Ниж. Айрюм	2	18	1319	40.175758999999999	40.190482000000003	44.911448999999998	44.901406999999999	0103000020E61000000100000005000000247D5A457F16444057B1F84D61734640247D5A457F164440677C5F5CAA744640043DD4B661184440677C5F5CAA744640043DD4B66118444057B1F84D61734640247D5A457F16444057B1F84D61734640
15073	Лесной	2	18	1319	40.181579999999997	40.189250999999999	44.801985000000002	44.794578000000001	0103000020E61000000100000005000000C8CD70033E174440800F5EBBB4654640C8CD70033E174440F870C971A76646401EDE736039184440F870C971A76646401EDE736039184440800F5EBBB4654640C8CD70033E174440800F5EBBB4654640
14994	Келермесская	2	18	1319	40.111260000000001	40.146616999999999	44.814678000000001	44.769024999999999	0103000020E610000001000000050000002EAD86C43D0E4440386744696F6246402EAD86C43D0E4440A662635E47684640D1048A58C4124440A662635E47684640D1048A58C4124440386744696F6246402EAD86C43D0E4440386744696F624640
57029	Дондуковская	2	18	1319	40.334913	40.374465999999998	44.904012000000002	44.855893000000002	0103000020E61000000100000005000000AC00DF6DDE2A44400BF0DDE68D6D4640AC00DF6DDE2A444085984BAAB673464062BB7B80EE2F444085984BAAB673464062BB7B80EE2F44400BF0DDE68D6D4640AC00DF6DDE2A44400BF0DDE68D6D4640
57027	Дондуковская	2	18	1319	40.334913	40.374465999999998	44.904012000000002	44.855893000000002	0103000020E61000000100000005000000AC00DF6DDE2A44400BF0DDE68D6D4640AC00DF6DDE2A444085984BAAB673464062BB7B80EE2F444085984BAAB673464062BB7B80EE2F44400BF0DDE68D6D4640AC00DF6DDE2A44400BF0DDE68D6D4640
57071	Днепровский	2	18	1319	40.296106000000002	40.304065000000001	44.758209000000001	44.746417999999998	0103000020E610000001000000050000001F1329CDE6254440A79201A08A5F46401F1329CDE6254440354415FE0C614640DB6D179AEB264440354415FE0C614640DB6D179AEB264440A79201A08A5F46401F1329CDE6254440A79201A08A5F4640
14223	Гончарка	2	18	1319	39.947029999999998	39.966828999999997	44.817126999999999	44.796292000000001	0103000020E610000001000000050000005A2A6F4738F94340810871E5EC6546405A2A6F4738F94340DCD6169E9768464085E97B0DC1FB4340DCD6169E9768464085E97B0DC1FB4340810871E5EC6546405A2A6F4738F94340810871E5EC654640
57031	Гиагинская	2	18	1319	40.022371	40.093499999999999	44.901623999999998	44.840026000000002	0103000020E610000001000000050000007DB08C0DDD02444015E5D2F8856B46407DB08C0DDD024440F4A44C6A687346408716D9CEF70B4440F4A44C6A687346408716D9CEF70B444015E5D2F8856B46407DB08C0DDD02444015E5D2F8856B4640
14833	Георгиевское	2	18	1319	40.405529999999999	40.418033999999999	44.776671999999998	44.754573999999998	0103000020E6100000010000000500000000C63368E8334440B9347EE19560464000C63368E833444005DCF3FC69634640DB4E5B238235444005DCF3FC69634640DB4E5B2382354440B9347EE19560464000C63368E8334440B9347EE195604640
57070	Вольно-Веселый	2	18	1319	40.247695999999998	40.269120999999998	44.915565999999998	44.902313999999997	0103000020E61000000100000005000000CDACA580B41F4440895C70067F734640CDACA580B41F44402EAA4544317546405AD5928E722244402EAA4544317546405AD5928E72224440895C70067F734640CDACA580B41F4440895C70067F734640
54820	Шахты	2	23	\N	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
56619	Цимлянск	2	23	\N	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
193	Таганрог	2	23	\N	38.793359000000002	38.960768999999999	47.284757999999997	47.187893000000003	0103000020E610000001000000050000005F7EA7C98C654340DC12B9E00C9847405F7EA7C98C6543401EA33CF372A447405C01857AFA7A43401EA33CF372A447405C01857AFA7A4340DC12B9E00C9847405F7EA7C98C654340DC12B9E00C984740
56609	Семикаракорск	2	23	\N	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
56620	Сальск	2	23	\N	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
378	Ростов-на-Дону	2	23	\N	39.501958999999999	39.859766999999998	47.345292999999998	47.158563999999998	0103000020E610000001000000050000006877483140C0434056293DD34B9447406877483140C04340D4449F8F32AC47400B9755D80CEE4340D4449F8F32AC47400B9755D80CEE434056293DD34B9447406877483140C0434056293DD34B944740
56611	Пролетарск	2	23	\N	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
54821	Новошахтинск	2	23	\N	39.785584	40.019596	47.849257000000001	47.722447000000003	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
54826	Новочеркасск	2	23	\N	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
56614	Морозовск	2	23	\N	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
56613	Миллерово	2	23	\N	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
56821	Красный Сулин	2	23	\N	39.992026000000003	40.138658	47.916677	47.850557999999999	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
56612	Константиновск	2	23	\N	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
54808	Каменск-Шахтинский	2	23	\N	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
56615	Зерноград	2	23	\N	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
54823	Зверево	2	23	\N	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
54811	Донецк	2	23	\N	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
54824	Гуково	2	23	\N	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
56617	Волгодонск	2	23	\N	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
54830	Волгодонск	2	23	\N	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
54829	Белая Калитва	2	23	\N	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
54817	Батайск	2	23	\N	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
11987	Аксай	2	23	\N	39.849248000000003	39.911726000000002	47.282783999999999	47.246375	0103000020E61000000100000005000000C2189128B4EC4340A8C64B37899F4740C2189128B4EC434081EA1F4432A44740DA740470B3F4434081EA1F4432A44740DA740470B3F44340A8C64B37899F4740C2189128B4EC4340A8C64B37899F4740
54819	Азов	2	23	\N	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
1920	Шахты	2	23	374	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
20596	Новошахтинск	2	23	1638	39.785584	40.019596	47.849257000000001	47.722447000000003	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
12804	Каменск-Шахтинский	2	23	1247	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
1460	Донецк	2	23	320	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
14830	Гуково	2	23	1370	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
1116	Волгодонск	2	23	265	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
5338	Белая Калитва	2	23	758	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
2228	Батайск	2	23	418	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
589	Азов	2	23	183	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
5809	Чукаринский	2	23	290	41.707403999999997	41.739958999999999	49.491906999999998	49.458616999999997	0103000020E61000000100000005000000A087DA368CDA4440DF313CF6B3BA4840A087DA368CDA444034D6FECEF6BE4840C0B0FCF9B6DE444034D6FECEF6BE4840C0B0FCF9B6DE4440DF313CF6B3BA4840A087DA368CDA4440DF313CF6B3BA4840
5655	Черновский	2	23	290	41.693551999999997	41.710270000000001	49.756498000000001	49.714210000000001	0103000020E61000000100000005000000A609DB4FC6D84440F33CB83B6BDB4840A609DB4FC6D84440A5BE2CEDD4E048403BAA9A20EADA4440A5BE2CEDD4E048403BAA9A20EADA4440F33CB83B6BDB4840A609DB4FC6D84440F33CB83B6BDB4840
5592	Ушаковский	2	23	290	41.765211000000001	41.810962000000004	49.822378999999998	49.795242000000002	0103000020E610000001000000050000000DC51D6FF2E14440EC33677DCAE548400DC51D6FF2E1444066F50EB743E948403E26529ACDE7444066F50EB743E948403E26529ACDE74440EC33677DCAE548400DC51D6FF2E14440EC33677DCAE54840
6139	Терновской	2	23	290	41.953173999999997	41.98413	49.768101000000001	49.751916999999999	0103000020E61000000100000005000000E1B20A9B01FA44403927F6D03EE04840E1B20A9B01FA44403083312251E248409981CAF8F7FD44403083312251E248409981CAF8F7FD44403927F6D03EE04840E1B20A9B01FA44403927F6D03EE04840
5918	Сингиновский	2	23	290	41.831012000000001	41.884281999999999	49.490748000000004	49.466358	0103000020E61000000100000005000000B24AE9995EEA44402E1D739EB1BB4840B24AE9995EEA4440E94999D4D0BE484082380F2730F14440E94999D4D0BE484082380F2730F144402E1D739EB1BB4840B24AE9995EEA44402E1D739EB1BB4840
28470	Рубежинский	2	23	290	41.936753000000003	41.962381999999998	49.592596999999998	49.584871	0103000020E6100000010000000500000007B7B585E7F744407DB08C0DDDCA484007B7B585E7F74440965AEF37DACB4840292158552FFB4440965AEF37DACB4840292158552FFB44407DB08C0DDDCA484007B7B585E7F744407DB08C0DDDCA4840
6184	Поповский	2	23	290	41.921221000000003	41.941065000000002	49.824976999999997	49.807039000000003	0103000020E61000000100000005000000B8B1D991EAF544405CCCCF0D4DE74840B8B1D991EAF54440E179A9D898E94840833463D174F84440E179A9D898E94840833463D174F844405CCCCF0D4DE74840B8B1D991EAF544405CCCCF0D4DE74840
5436	Плешаковский	2	23	290	42.024814999999997	42.047336000000001	49.593665999999999	49.581710999999999	0103000020E61000000100000005000000A1B94E232D0345409A5C8C8175CA4840A1B94E232D034540A25F5B3FFDCB484034F6251B0F064540A25F5B3FFDCB484034F6251B0F0645409A5C8C8175CA4840A1B94E232D0345409A5C8C8175CA4840
56784	Пигаревский	2	23	290	41.663108000000001	41.697595	49.641677000000001	49.630147999999998	0103000020E61000000100000005000000A5DB12B9E0D44440E5D18DB0A8D04840A5DB12B9E0D4444036CCD07822D24840336DFFCA4AD9444036CCD07822D24840336DFFCA4AD94440E5D18DB0A8D04840A5DB12B9E0D44440E5D18DB0A8D04840
5429	Нижнекривской	2	23	290	41.990184999999997	42.011439000000003	49.571249000000002	49.548780999999998	0103000020E61000000100000005000000B0FECF61BEFE444045D5AF743EC64840B0FECF61BEFE4440B56FEEAF1EC94840117349D576014540B56FEEAF1EC94840117349D57601454045D5AF743EC64840B0FECF61BEFE444045D5AF743EC64840
5985	Меркуловский	2	23	290	41.498896000000002	41.561374000000001	49.618471	49.601576999999999	0103000020E61000000100000005000000780DFAD2DBBF44404D83A27900CD4840780DFAD2DBBF44402043C70E2ACF484090696D1ADBC744402043C70E2ACF484090696D1ADBC744404D83A27900CD4840780DFAD2DBBF44404D83A27900CD4840
5819	Максаевский	2	23	290	41.782305999999998	41.817698999999998	49.465251000000002	49.447085999999999	0103000020E6100000010000000500000077BB5E9A22E44440EE3F321D3AB9484077BB5E9A22E4444035B742588DBB4840677C5F5CAAE8444035B742588DBB4840677C5F5CAAE84440EE3F321D3AB9484077BB5E9A22E44440EE3F321D3AB94840
5270	Лосевский	2	23	290	41.676088999999997	41.689303000000002	49.915289999999999	49.906089000000001	0103000020E61000000100000005000000B91798158AD64440F7216FB9FAF34840B91798158AD644408C2D043928F548407104A9143BD844408C2D043928F548407104A9143BD84440F7216FB9FAF34840B91798158AD64440F7216FB9FAF34840
4917	Лебяженский	2	23	290	41.908070000000002	41.926412999999997	49.601309000000001	49.594028000000002	0103000020E61000000100000005000000473D44A33BF444404374081C09CC4840473D44A33BF444402EE57CB1F7CC48406CCB80B394F644402EE57CB1F7CC48406CCB80B394F644404374081C09CC4840473D44A33BF444404374081C09CC4840
5727	Кружилинский	2	23	290	41.745303999999997	41.801699999999997	49.447519	49.417299999999997	0103000020E61000000100000005000000FBC9181F66DF4440764F1E166AB54840FBC9181F66DF444058AB764D48B94840029A081B9EE6444058AB764D48B94840029A081B9EE64440764F1E166AB54840FBC9181F66DF4440764F1E166AB54840
5497	Колундаевский	2	23	290	41.813118000000003	41.859470999999999	49.769567000000002	49.748221000000001	0103000020E61000000100000005000000FCE4284014E844401897AAB4C5DF4840FCE4284014E84440598AE42B81E24840226E4E2503EE4440598AE42B81E24840226E4E2503EE44401897AAB4C5DF4840FCE4284014E844401897AAB4C5DF4840
6068	Калиновский	2	23	290	41.386526000000003	41.419511999999997	49.566388000000003	49.532528999999997	0103000020E61000000100000005000000E08618AF79B14440F69507E929C44840E08618AF79B14440666CE8667FC84840C823B891B2B54440666CE8667FC84840C823B891B2B54440F69507E929C44840E08618AF79B14440F69507E929C44840
5277	Калининский	2	23	290	41.833582	41.85718	49.573177000000001	49.550096000000003	0103000020E610000001000000050000006344A2D0B2EA444089D4B48B69C648406344A2D0B2EA4440E2E82ADD5DC9484084640113B8ED4440E2E82ADD5DC9484084640113B8ED444089D4B48B69C648406344A2D0B2EA444089D4B48B69C64840
5110	Зубковский	2	23	290	41.543622999999997	41.571795000000002	49.753208999999998	49.735612000000003	0103000020E610000001000000050000003C2D3F7095C54440C845B58828DE48403C2D3F7095C54440C4060B2769E0484017821C9430C94440C4060B2769E0484017821C9430C94440C845B58828DE48403C2D3F7095C54440C845B58828DE4840
5969	Затонский	2	23	290	41.439751000000001	41.459766000000002	49.598576000000001	49.588538	0103000020E6100000010000000500000010B1C1C249B84440043A933655CB484010B1C1C249B84440D3156C239ECC484008E8BE9CD9BA4440D3156C239ECC484008E8BE9CD9BA4440043A933655CB484010B1C1C249B84440043A933655CB4840
56913	Еланская	2	23	290	42.033448	42.050040000000003	49.619427999999999	49.611286	0103000020E61000000100000005000000ED0E2906480445405740A19E3ECE4840ED0E290648044540041DAD6A49CF4840F5BEF1B567064540041DAD6A49CF4840F5BEF1B5670645405740A19E3ECE4840ED0E2906480445405740A19E3ECE4840
5113	Дударевский	2	23	290	41.545006999999998	41.682808000000001	49.918213000000002	49.878349	0103000020E61000000100000005000000A88B14CAC2C54440B6BC72BD6DF04840A88B14CAC2C544408BE1EA0088F548403DB9A64066D744408BE1EA0088F548403DB9A64066D74440B6BC72BD6DF04840A88B14CAC2C54440B6BC72BD6DF04840
4976	Дубровский	2	23	290	41.621831	41.647396999999998	49.715358000000002	49.686050000000002	0103000020E61000000100000005000000CA51802898CF4440DDB5847CD0D74840CA51802898CF44404B77D7D990DB4840A643A7E7DDD244404B77D7D990DB4840A643A7E7DDD24440DDB5847CD0D74840CA51802898CF4440DDB5847CD0D74840
4530	Громковский	2	23	290	41.759110999999997	41.796598000000003	49.590541000000002	49.573726000000001	0103000020E6100000010000000500000055849B8C2AE14440B56E83DA6FC9484055849B8C2AE144403CF9F4D896CB48408E075BECF6E544403CF9F4D896CB48408E075BECF6E54440B56E83DA6FC9484055849B8C2AE14440B56E83DA6FC94840
5649	Гороховский	2	23	290	41.742753	41.777850000000001	49.736688999999998	49.690531999999997	0103000020E61000000100000005000000C100C28712DF4440B56B425A63D84840C100C28712DF444056293DD34BDE4840C898BB9690E3444056293DD34BDE4840C898BB9690E34440B56B425A63D84840C100C28712DF4440B56B425A63D84840
31179	Водянский	2	23	290	41.536059999999999	41.565919999999998	49.573790000000002	49.560550999999997	0103000020E61000000100000005000000CD58349D9DC44440BB5E9A22C0C74840CD58349D9DC44440CC6262F371C948407F130A1170C84440CC6262F371C948407F130A1170C84440BB5E9A22C0C74840CD58349D9DC44440BB5E9A22C0C74840
4694	Вешенская	2	23	290	41.700164000000001	41.757700999999997	49.644261	49.621791999999999	0103000020E6100000010000000500000014EB54F99ED944400C7558E196CF484014EB54F99ED944404C8BFA2477D24840C092AB58FCE044404C8BFA2477D24840C092AB58FCE044400C7558E196CF484014EB54F99ED944400C7558E196CF4840
4601	Верхнетокинский	2	23	290	41.686185999999999	41.713889999999999	49.543841999999998	49.520798999999997	0103000020E610000001000000050000008D7C5EF1D4D744400E65A88AA9C248408D7C5EF1D4D744407A185A9D9CC5484081785DBF60DB44407A185A9D9CC5484081785DBF60DB44400E65A88AA9C248408D7C5EF1D4D744400E65A88AA9C24840
1346	Варваринский	2	23	290	41.361885000000001	41.379500999999998	49.553829999999998	49.533768999999999	0103000020E61000000100000005000000DCF4673F52AE44402F4FE78A52C44840DCF4673F52AE444097C5C4E6E3C648404FE61F7D93B0444097C5C4E6E3C648404FE61F7D93B044402F4FE78A52C44840DCF4673F52AE44402F4FE78A52C44840
1240	Базковская	2	23	290	41.717232000000003	41.761564	49.602119999999999	49.585220999999997	0103000020E6100000010000000500000085D21742CEDB444059F78F85E8CA484085D21742CEDB44403E22A64412CD4840CDE7DCED7AE144403E22A64412CD4840CDE7DCED7AE1444059F78F85E8CA484085D21742CEDB444059F78F85E8CA4840
5056	Антиповский	2	23	290	41.526761999999998	41.561886000000001	49.736927999999999	49.704259999999998	0103000020E610000001000000050000004563EDEF6CC34440C3F0113125DA48404563EDEF6CC34440DBC01DA853DE4840460A65E1EBC74440DBC01DA853DE4840460A65E1EBC74440C3F0113125DA48404563EDEF6CC34440C3F0113125DA4840
4858	Андроповский	2	23	290	41.931910999999999	41.950839000000002	49.676316	49.657040000000002	0103000020E610000001000000050000002EE411DC48F74440F91400E319D448402EE411DC48F744407AE1CE8591D648407461A417B5F944407AE1CE8591D648407461A417B5F94440F91400E319D448402EE411DC48F74440F91400E319D44840
4534	Альшанский	2	23	290	41.631964000000004	41.657286999999997	49.616230000000002	49.604799999999997	0103000020E61000000100000005000000EB1F4432E4D04440764F1E166ACD4840EB1F4432E4D044403468E89FE0CE4840008BFCFA21D444403468E89FE0CE4840008BFCFA21D44440764F1E166ACD4840EB1F4432E4D04440764F1E166ACD4840
3030	Щедровка	2	23	355	40.283062000000001	40.314934999999998	49.507815000000001	49.479920999999997	0103000020E61000000100000005000000C45E28603B244440F1D4230D6EBD4840C45E28603B24444089B5F81400C14840D1AE42CA4F28444089B5F81400C14840D1AE42CA4F284440F1D4230D6EBD4840C45E28603B244440F1D4230D6EBD4840
3485	Шептуховка	2	23	355	40.317154000000002	40.368178	49.307353999999997	49.274943	0103000020E61000000100000005000000D6E5948098284440CFA10C5531A34840D6E5948098284440BB25396057A74840A88DEA74202F4440BB25396057A74840A88DEA74202F4440CFA10C5531A34840D6E5948098284440CFA10C5531A34840
1803	Чертково	2	23	355	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
3739	Тихая Журавка	2	23	355	40.632030999999998	40.699351	49.593612999999998	49.574252000000001	0103000020E6100000010000000500000072874D64E6504440D0D4EB1681C9484072874D64E65044407FBDC282FBCB484063B66455845944407FBDC282FBCB484063B6645584594440D0D4EB1681C9484072874D64E6504440D0D4EB1681C94840
2566	Тарасово-Меловское	2	23	355	40.063326000000004	40.092340999999998	49.488067999999998	49.442991999999997	0103000020E61000000100000005000000467EFD101B084440DF313CF6B3B84840467EFD101B084440B01C210379BE48403B8A73D4D10B4440B01C210379BE48403B8A73D4D10B4440DF313CF6B3B84840467EFD101B084440DF313CF6B3B84840
3699	Сохрановка	2	23	355	40.478886000000003	40.529839000000003	49.524811	49.469237999999997	0103000020E610000001000000050000009241EE224C3D44402D05A4FD0FBC48409241EE224C3D444060CAC0012DC348409B92ACC3D143444060CAC0012DC348409B92ACC3D14344402D05A4FD0FBC48409241EE224C3D44402D05A4FD0FBC4840
56790	Сетраки	2	23	355	40.807768000000003	40.852657000000001	49.387343000000001	49.345278	0103000020E61000000100000005000000AF601BF1646744409F03CB1132AC4840AF601BF164674440D2AA967494B148404DDA54DD236D4440D2AA967494B148404DDA54DD236D44409F03CB1132AC4840AF601BF1646744409F03CB1132AC4840
57026	Семено-Камышенская	2	23	355	40.562268000000003	40.589523	49.257337	49.240958999999997	0103000020E610000001000000050000002ECBD765F8474440A35698BED79E48402ECBD765F84744407F86376BF0A04840B29E5A7D754B44407F86376BF0A04840B29E5A7D754B4440A35698BED79E48402ECBD765F8474440A35698BED79E4840
56956	Полтава	2	23	355	40.166237000000002	40.194344999999998	49.393980999999997	49.384931999999999	0103000020E610000001000000050000004D310741471544408997A77345B148404D31074147154440681F2BF86DB248401092054CE0184440681F2BF86DB248401092054CE01844408997A77345B148404D310741471544408997A77345B14840
56806	Павловка	2	23	355	40.717533000000003	40.764406999999999	49.262445999999997	49.227535000000003	0103000020E610000001000000050000008066101FD85B444002D9EBDD1F9D48408066101FD85B4440A67B9DD497A14840AFEAAC16D8614440A67B9DD497A14840AFEAAC16D861444002D9EBDD1F9D48408066101FD85B444002D9EBDD1F9D4840
2502	Осиково	2	23	355	40.113774999999997	40.170315000000002	49.410237000000002	49.390889999999999	0103000020E610000001000000050000001B0DE02D900E4440AE2AFBAE08B248401B0DE02D900E4440F94D61A582B448405682C5E1CC154440F94D61A582B448405682C5E1CC154440AE2AFBAE08B248401B0DE02D900E4440AE2AFBAE08B24840
4160	Ольховчик	2	23	355	40.755054999999999	40.819006000000002	49.281649000000002	49.259171000000002	0103000020E6100000010000000500000034D769A4A56044402B89EC832CA1484034D769A4A5604440BEF90D130DA44840289D4830D5684440BEF90D130DA44840289D4830D56844402B89EC832CA1484034D769A4A56044402B89EC832CA14840
57011	Новостепановский	2	23	355	40.255951000000003	40.284669999999998	49.589444	49.559030999999997	0103000020E6100000010000000500000073309B00C32044409F39EB538EC7484073309B00C32044406669A7E672CB48407F130A11702444406669A7E672CB48407F130A11702444409F39EB538EC7484073309B00C32044409F39EB538EC74840
3532	Новоселовка	2	23	355	40.343347999999999	40.379199999999997	49.275801999999999	49.245480999999998	0103000020E61000000100000005000000D192C7D3F22B44400A65E1EB6B9F4840D192C7D3F22B4440F015DD7A4DA34840545227A089304440F015DD7A4DA34840545227A0893044400A65E1EB6B9F4840D192C7D3F22B44400A65E1EB6B9F4840
56709	Нагибин	2	23	355	40.549807999999999	40.569831999999998	49.574339000000002	49.557564999999997	0103000020E61000000100000005000000228AC91B604644407632384A5EC74840228AC91B604644409FE8BAF083C948406D1B4641F04844409FE8BAF083C948406D1B4641F04844407632384A5EC74840228AC91B604644407632384A5EC74840
3600	Михайлово-Александровка	2	23	355	40.211323	40.257173000000002	49.221563000000003	49.191091	0103000020E6100000010000000500000041F2CEA10C1B4440ACC77DAB7598484041F2CEA10C1B44407880272D5C9C484005357C0BEB2044407880272D5C9C484005357C0BEB204440ACC77DAB7598484041F2CEA10C1B4440ACC77DAB75984840
56988	Марьяны	2	23	355	40.395558000000001	40.402510999999997	49.432651999999997	49.423651999999997	0103000020E61000000100000005000000E9D500A5A132444047718E3A3AB64840E9D500A5A13244404546072461B74840DFA3FE7A853344404546072461B74840DFA3FE7A8533444047718E3A3AB64840E9D500A5A132444047718E3A3AB64840
3205	Маньково-Калитвенское	2	23	355	40.261251000000001	40.303697	49.418278000000001	49.366250000000001	0103000020E610000001000000050000000E863AAC702144407B14AE47E1AE48400E863AAC7021444072512D228AB548405872158BDF26444072512D228AB548405872158BDF2644407B14AE47E1AE48400E863AAC702144407B14AE47E1AE4840
56785	Малая Лозовка	2	23	355	40.622697000000002	40.641427	49.463166999999999	49.430590000000002	0103000020E610000001000000050000009E280989B44F444009FEB7921DB748409E280989B44F444010CB660E49BB4840BDE2A9471A52444010CB660E49BB4840BDE2A9471A52444009FEB7921DB748409E280989B44F444009FEB7921DB74840
56954	Лозовой	2	23	355	40.292566999999998	40.309202999999997	49.433090999999997	49.425767999999998	0103000020E61000000100000005000000C571E0D57225444077D7D9907FB64840C571E0D5722544409198A0866FB748409C69C2F6932744409198A0866FB748409C69C2F69327444077D7D9907FB64840C571E0D57225444077D7D9907FB64840
3634	Кутейниково	2	23	355	40.458207000000002	40.476317000000002	49.398771000000004	49.388199	0103000020E610000001000000050000002EE6E786A63A444082AB3C81B0B148402EE6E786A63A4440EFCB99ED0AB34840B1C398F4F73C4440EFCB99ED0AB34840B1C398F4F73C444082AB3C81B0B148402EE6E786A63A444082AB3C81B0B14840
56874	Кадамов	2	23	355	40.336951999999997	40.371051999999999	49.533031999999999	49.515331000000003	0103000020E6100000010000000500000030293E3E212B4440B8CEBF5DF6C1484030293E3E212B444059DC7F643AC44840C58EC6A17E2F444059DC7F643AC44840C58EC6A17E2F4440B8CEBF5DF6C1484030293E3E212B4440B8CEBF5DF6C14840
56928	Гусев	2	23	355	40.394866999999998	40.410254999999999	49.395611000000002	49.385671000000002	0103000020E6100000010000000500000083A279008B3244400002D6AA5DB1484083A279008B3244400C789961A3B248409F02603C833444400C789961A3B248409F02603C833444400002D6AA5DB1484083A279008B3244400002D6AA5DB14840
3994	Греково-Степановка	2	23	355	40.66057	40.685713999999997	49.348759000000001	49.333326999999997	0103000020E61000000100000005000000FF5BC98E8D544440D8EF8975AAAA4840FF5BC98E8D544440C4978922A4AC48406534F279C5574440C4978922A4AC48406534F279C5574440D8EF8975AAAA4840FF5BC98E8D544440D8EF8975AAAA4840
56812	Галдин	2	23	355	40.071572000000003	40.090446	49.52008	49.49973	0103000020E6100000010000000500000098A7734529094440406A1327F7BF484098A7734529094440DFA63FFB91C24840EA060ABC930B4440DFA63FFB91C24840EA060ABC930B4440406A1327F7BF484098A7734529094440406A1327F7BF4840
56927	Богуны	2	23	355	40.825474	40.850968000000002	49.486159999999998	49.479188999999998	0103000020E6100000010000000500000062D9CC21A96944402DCDAD1056BD484062D9CC21A9694440CA4FAA7D3ABE4840A5F8F884EC6C4440CA4FAA7D3ABE4840A5F8F884EC6C44402DCDAD1056BD484062D9CC21A96944402DCDAD1056BD4840
56847	Бакай	2	23	355	40.253517000000002	40.288981999999997	49.543883000000001	49.520097999999997	0103000020E6100000010000000500000072FDBB3E73204440855B3E9292C2484072FDBB3E73204440D9EC48F59DC54840FB90B75CFD244440D9EC48F59DC54840FB90B75CFD244440855B3E9292C2484072FDBB3E73204440855B3E9292C24840
56808	Артамошкин	2	23	355	41.002037999999999	41.044879000000002	49.379871000000001	49.367229999999999	0103000020E61000000100000005000000B4ACFBC742804440170E846401AF4840B4ACFBC74280444073D9E89C9FB048407BA35698BE85444073D9E89C9FB048407BA35698BE854440170E846401AF4840B4ACFBC742804440170E846401AF4840
56811	Анно-Ребриковская	2	23	355	40.189224000000003	40.215051000000003	49.624540000000003	49.600169999999999	0103000020E6100000010000000500000025CFF57D381844402905DD5ED2CC484025CFF57D381844409D853DEDF0CF48406EFC89CA861B44409D853DEDF0CF48406EFC89CA861B44402905DD5ED2CC484025CFF57D381844402905DD5ED2CC4840
3881	Алексеево-Лозовское	2	23	355	40.635120999999998	40.664766	49.418970000000002	49.367781999999998	0103000020E610000001000000050000005C001AA54B5144405B07077B13AF48405C001AA54B514440A80018CFA0B5484012BF620D17554440A80018CFA0B5484012BF620D175544405B07077B13AF48405C001AA54B5144405B07077B13AF4840
56880	Черкасский	2	23	254	42.005825000000002	42.033250000000002	48.028405999999997	48.019922000000001	0103000020E61000000100000005000000E63FA4DFBE004540473CD9CD8C024840E63FA4DFBE0045404D81CCCEA2034840C74B3789410445404D81CCCEA2034840C74B378941044540473CD9CD8C024840E63FA4DFBE004540473CD9CD8C024840
1189	Цимлянск	2	23	254	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
11332	Хорошевская	2	23	254	42.202635999999998	42.236826000000001	47.730271999999999	47.710656	0103000020E61000000100000005000000027FF8F9EF194540645A9BC6F6DA4740027FF8F9EF1945409E978A8D79DD4740D76B7A50501E45409E978A8D79DD4740D76B7A50501E4540645A9BC6F6DA4740027FF8F9EF194540645A9BC6F6DA4740
12014	Терновская	2	23	254	42.146680000000003	42.179710999999998	47.780842	47.768954999999998	0103000020E61000000100000005000000187D0569C61245403F8C101E6DE24740187D0569C6124540EFAB72A1F2E34740A0DD21C500174540EFAB72A1F2E34740A0DD21C5001745403F8C101E6DE24740187D0569C61245403F8C101E6DE24740
11473	Сосенки	2	23	254	42.001314999999998	42.009148000000003	47.646991999999997	47.636823	0103000020E6100000010000000500000043FF04172B004540992B836A83D1474043FF04172B004540066344A2D0D247407369FCC22B014540066344A2D0D247407369FCC22B014540992B836A83D1474043FF04172B004540992B836A83D14740
56916	Синий Курган	2	23	254	41.797649	41.809694999999998	47.776161000000002	47.769803000000003	0103000020E61000000100000005000000F357C85C19E644406DAE9AE788E24740F357C85C19E6444020B75F3E59E347400B5EF415A4E7444020B75F3E59E347400B5EF415A4E744406DAE9AE788E24740F357C85C19E644406DAE9AE788E24740
11104	Саркел	2	23	254	42.146464999999999	42.162536000000003	47.684742	47.671146	0103000020E610000001000000050000001B81785DBF124540AD6BB41CE8D547401B81785DBF1245404C1938A0A5D747401A36CAFACD1445404C1938A0A5D747401A36CAFACD144540AD6BB41CE8D547401B81785DBF124540AD6BB41CE8D54740
56748	Паршиков	2	23	254	41.94782	41.975821000000003	47.788294	47.766683999999998	0103000020E61000000100000005000000533F6F2A52F94440E82E89B322E24740533F6F2A52F9444007D15AD1E6E4474001E0D8B3E7FC444007D15AD1E6E4474001E0D8B3E7FC4440E82E89B322E24740533F6F2A52F94440E82E89B322E24740
12111	Новоцимлянская	2	23	254	42.267395999999998	42.297956999999997	47.986426000000002	47.966002000000003	0103000020E61000000100000005000000658A39083A22454070EF1AF4A5FB4740658A39083A22454049F6083543FE4740A04E79742326454049F6083543FE4740A04E79742326454070EF1AF4A5FB4740658A39083A22454070EF1AF4A5FB4740
11698	Маркинская	2	23	254	41.984948000000003	42.015346999999998	47.843676000000002	47.831204999999997	0103000020E610000001000000050000005C21ACC612FE4440C6A2E9EC64EA47405C21ACC612FE4440C6353E93FDEB4740BD8BF7E3F6014540C6353E93FDEB4740BD8BF7E3F6014540C6A2E9EC64EA47405C21ACC612FE4440C6A2E9EC64EA4740
56638	Лозной	2	23	254	41.954234	41.990059000000002	47.636015	47.623742999999997	0103000020E610000001000000050000009A5DF75624FA4440F10D85CFD6CF47409A5DF75624FA4440FA6184F068D14740240ED940BAFE4440FA6184F068D14740240ED940BAFE4440F10D85CFD6CF47409A5DF75624FA4440F10D85CFD6CF4740
11530	Лозновская	2	23	254	41.901746000000003	41.925389000000003	47.628771	47.614170999999999	0103000020E6100000010000000500000040A6B5696CF344406893C3279DCE474040A6B5696CF344402CD670917BD04740018A912573F644402CD670917BD04740018A912573F644406893C3279DCE474040A6B5696CF344406893C3279DCE4740
11914	Кумшацкая	2	23	254	41.973044999999999	41.982638999999999	47.744790999999999	47.733054000000003	0103000020E61000000100000005000000A64412BD8CFC4440DB19A6B6D4DD4740A64412BD8CFC444075ADBD4F55DF47401763601DC7FD444075ADBD4F55DF47401763601DC7FD4440DB19A6B6D4DD4740A64412BD8CFC4440DB19A6B6D4DD4740
1066	Красноярская	2	23	254	42.030304000000001	42.071896000000002	47.669193	47.634326999999999	0103000020E6100000010000000500000010786000E103454022FC8BA031D1474010786000E103454027DBC01DA8D547404B5B5CE33309454027DBC01DA8D547404B5B5CE33309454022FC8BA031D1474010786000E103454022FC8BA031D14740
56922	Карпов	2	23	254	41.873699999999999	41.894199999999998	47.604183999999997	47.599086	0103000020E61000000100000005000000F241CF66D5EF4440E8BE9CD9AECC4740F241CF66D5EF44401B62BCE655CD4740A60A462575F244401B62BCE655CD4740A60A462575F24440E8BE9CD9AECC4740F241CF66D5EF4440E8BE9CD9AECC4740
11517	Камышевская	2	23	254	41.804152999999999	41.839978000000002	47.620590999999997	47.607112000000001	0103000020E610000001000000050000007AFD497CEEE644402C8194D8B5CD47407AFD497CEEE644409198A0866FCF474004AE2B6684EB44409198A0866FCF474004AE2B6684EB44402C8194D8B5CD47407AFD497CEEE644402C8194D8B5CD4740
11977	Калининская	2	23	254	42.21754	42.263345000000001	47.854970999999999	47.829813999999999	0103000020E6100000010000000500000032C9C859D81B4540A8E15B5837EA474032C9C859D81B4540A30392B06FED47405648F949B5214540A30392B06FED47405648F949B5214540A8E15B5837EA474032C9C859D81B4540A8E15B5837EA4740
57006	Железнодорожный	2	23	254	41.982298	41.993886000000003	47.939534999999999	47.931125999999999	0103000020E610000001000000050000008E76DCF0BBFD4440473A03232FF747408E76DCF0BBFD44404339D1AE42F84740E4F90CA837FF44404339D1AE42F84740E4F90CA837FF4440473A03232FF747408E76DCF0BBFD4440473A03232FF74740
11397	Дубравный	2	23	254	41.977086999999997	41.997523999999999	47.681218000000001	47.667099	0103000020E61000000100000005000000622CD32F11FD4440DF18028063D54740622CD32F11FD444028B9C32632D74740D07CCEDDAEFF444028B9C32632D74740D07CCEDDAEFF4440DF18028063D54740622CD32F11FD4440DF18028063D54740
56731	Антонов	2	23	254	42.140436999999999	42.159148999999999	47.880896	47.864505000000001	0103000020E61000000100000005000000FD12F1D6F91145403F1D8F19A8EE4740FD12F1D6F9114540AF963B33C1F04740761893FE5E144540AF963B33C1F04740761893FE5E1445403F1D8F19A8EE4740FD12F1D6F91145403F1D8F19A8EE4740
56656	Юловский	2	23	238	40.704138999999998	41.33596	46.917597999999998	46.229301999999997	0103000020E61000000100000005000000486B0C3A215A4440257497C4591D4740486B0C3A215A44400070ECD973754740D061BEBC00AB44400070ECD973754740D061BEBC00AB4440257497C4591D4740486B0C3A215A4440257497C4591D4740
9482	Целина	2	23	238	41.007015000000003	41.055802	46.540371	46.524456999999998	0103000020E610000001000000050000006DCA15DEE580444042942F68214347406DCA15DEE5804440795A7EE02A45474094861A8524874440795A7EE02A45474094861A852487444042942F68214347406DCA15DEE580444042942F6821434740
56786	Хлеборобное	2	23	238	40.885427999999997	40.906402999999997	46.702094000000002	46.687005999999997	0103000020E61000000100000005000000397B67B455714440F01307D0EF574740397B67B455714440E25B5837DE59474086FF740305744440E25B5837DE59474086FF740305744440F01307D0EF574740397B67B455714440F01307D0EF574740
56764	Хлебодарное	2	23	238	40.827593999999998	40.844833000000001	46.691153999999997	46.668816	0103000020E61000000100000005000000D32EA699EE69444051853FC39B554740D32EA699EE694440F23FF9BB7758474071CADC7C236C4440F23FF9BB7758474071CADC7C236C444051853FC39B554740D32EA699EE69444051853FC39B554740
10255	Степное	2	23	238	41.031305000000003	41.087198000000001	46.632133000000003	46.619166999999997	0103000020E61000000100000005000000C4995FCD0184444097E13FDD404F4740C4995FCD0184444077DCF0BBE95047406823D74D298B444077DCF0BBE95047406823D74D298B444097E13FDD404F4740C4995FCD0184444097E13FDD404F4740
9949	Старченский	2	23	238	40.888131999999999	40.894609000000003	46.493166000000002	46.482537000000001	0103000020E61000000100000005000000FA43334FAE714440130EBDC5C33D4740FA43334FAE714440E4BF4010203F474088DA368C82724440E4BF4010203F474088DA368C82724440130EBDC5C33D4740FA43334FAE714440130EBDC5C33D4740
9270	Средний Егорлык	2	23	238	40.767659000000002	40.858325999999998	46.379038999999999	46.334927999999998	0103000020E6100000010000000500000073BD6DA642624440E141B3EBDE2A474073BD6DA6426244404B749659843047403BA759A0DD6D44404B749659843047403BA759A0DD6D4440E141B3EBDE2A474073BD6DA642624440E141B3EBDE2A4740
56728	Сладкая Балка	2	23	238	41.002110000000002	41.089892999999996	46.426504999999999	46.411079000000001	0103000020E610000001000000050000004E7FF623458044404489963C9E3447404E7FF623458044404D4A41B797364740D591239D818B44404D4A41B797364740D591239D818B44404489963C9E3447404E7FF623458044404489963C9E344740
9727	Северный	2	23	238	40.960006	40.999181	46.542943999999999	46.536987000000003	0103000020E610000001000000050000005DFB027AE17A444047B071FDBB4447405DFB027AE17A44409BC761307F4547406DE4BA29E57F44409BC761307F4547406DE4BA29E57F444047B071FDBB4447405DFB027AE17A444047B071FDBB444740
9884	Свободный	2	23	238	41.000996000000001	41.028188	46.496076000000002	46.484175	0103000020E61000000100000005000000A2B60DA32080444039454772F93D4740A2B60DA3208044404E2A1A6B7F3F4740E01115AA9B8344404E2A1A6B7F3F4740E01115AA9B83444039454772F93D4740A2B60DA32080444039454772F93D4740
10405	Рассвет	2	23	238	41.230704000000003	41.238402999999998	46.743471999999997	46.741885000000003	0103000020E6100000010000000500000038876BB5879D44404D327216F65E474038876BB5879D4440F0BE2A172A5F4740572250FD839E4440F0BE2A172A5F4740572250FD839E44404D327216F65E474038876BB5879D44404D327216F65E4740
10597	Плодородное	2	23	238	41.100349999999999	41.113402000000001	46.754722999999998	46.734375	0103000020E61000000100000005000000A913D044D88C444000000000005E4740A913D044D88C4440FE4465C39A60474087A6ECF4838E4440FE4465C39A60474087A6ECF4838E444000000000005E4740A913D044D88C444000000000005E4740
56950	Первомайский	2	23	238	40.827522000000002	40.836353000000003	46.443323999999997	46.438648000000001	0103000020E610000001000000050000003A5CAB3DEC694440583A1F9E253847403A5CAB3DEC69444015C440D7BE384740AC74779D0D6B444015C440D7BE384740AC74779D0D6B4440583A1F9E253847403A5CAB3DEC694440583A1F9E25384740
10505	Ольшанка	2	23	238	40.938544999999998	40.955218000000002	46.849767999999997	46.832317000000003	0103000020E610000001000000050000008369183E22784440D2730B5D896A47408369183E22784440FA97A432C56C474078465B95447A4440FA97A432C56C474078465B95447A4440D2730B5D896A47408369183E22784440D2730B5D896A4740
948	Новая Целина	2	23	238	41.010860000000001	41.055442999999997	46.548124999999999	46.537909999999997	0103000020E61000000100000005000000D36A48DC638144407E18213CDA444740D36A48DC638144405C8FC2F52846474064E597C1188744405C8FC2F52846474064E597C1188744407E18213CDA444740D36A48DC638144407E18213CDA444740
10500	Михайловка	2	23	238	40.989659000000003	41.011541999999999	46.710115000000002	46.699973999999997	0103000020E6100000010000000500000096986725AD7E444070067FBF9859474096986725AD7E444014B35E0CE55A4740E54350357A81444014B35E0CE55A4740E54350357A81444070067FBF9859474096986725AD7E444070067FBF98594740
10189	Лопанка	2	23	238	40.943674999999999	40.999181	46.422696999999999	46.390197000000001	0103000020E61000000100000005000000C286A757CA784440A8FFACF9F1314740C286A757CA784440048F6FEF1A3647406DE4BA29E57F4440048F6FEF1A3647406DE4BA29E57F4440A8FFACF9F1314740C286A757CA784440A8FFACF9F1314740
996	Красный Юг	2	23	238	40.969276999999998	40.978008000000003	46.589108000000003	46.572972999999998	0103000020E61000000100000005000000EBE1CB44117C4440D93EE42D57494740EBE1CB44117C4440EFE714E4674B4740FA9CBB5D2F7D4440EFE714E4674B4740FA9CBB5D2F7D4440D93EE42D57494740EBE1CB44117C4440D93EE42D57494740
10339	Коренной	2	23	238	41.121262000000002	41.125889000000001	46.505982000000003	46.500672000000002	0103000020E61000000100000005000000B01F6283858F4440EF02250516404740B01F6283858F4440AE2EA704C44047408CF678211D904440AE2EA704C44047408CF678211D904440EF02250516404740B01F6283858F4440EF02250516404740
10564	Журавлевка	2	23	238	41.079023999999997	41.095247000000001	46.847037	46.821964999999999	0103000020E61000000100000005000000AFCC5B751D8A444073BA2C2636694740AFCC5B751D8A444040C05AB56B6C47406405BF0D318C444040C05AB56B6C47406405BF0D318C444073BA2C2636694740AFCC5B751D8A444073BA2C2636694740
9938	Вороново	2	23	238	40.910096000000003	40.948884999999997	46.489027999999998	46.473737	0103000020E61000000100000005000000371C96067E744440DCF3FC69A33C4740371C96067E744440056A3178983E47401D554D1075794440056A3178983E47401D554D1075794440DCF3FC69A33C4740371C96067E744440DCF3FC69A33C4740
9999	Васильевка	2	23	238	40.843054000000002	40.858460000000001	46.655419999999999	46.635029000000003	0103000020E6100000010000000500000089618731E96B44407C8159A14851474089618731E96B4440799274CDE45347404B766C04E26D4440799274CDE45347404B766C04E26D44407C8159A14851474089618731E96B44407C8159A148514740
24678	Черни	2	23	221	40.894860000000001	40.904139999999998	47.760838999999997	47.749735000000001	0103000020E61000000100000005000000D13FC1C58A72444052D50451F7DF4740D13FC1C58A724440BB421F2C63E14740B28009DCBA734440BB421F2C63E14740B28009DCBA73444052D50451F7DF4740D13FC1C58A72444052D50451F7DF4740
2399	Усть-Донецкий	2	23	221	40.859431000000001	40.888733999999999	47.648114999999997	47.637611999999997	0103000020E610000001000000050000009415C3D5016E4440C1C41F459DD147409415C3D5016E44400586AC6EF5D24740F06B2409C27144400586AC6EF5D24740F06B2409C2714440C1C41F459DD147409415C3D5016E4440C1C41F459DD14740
24899	Усть-Быстрянская	2	23	221	41.005164000000001	41.054445999999999	47.838959000000003	47.803179	0103000020E61000000100000005000000EB8EC536A9804440C0EAC891CEE64740EB8EC536A9804440AAD72D0263EB4740F2B22616F8864440AAD72D0263EB4740F2B22616F8864440C0EAC891CEE64740EB8EC536A9804440C0EAC891CEE64740
24850	Тереховский	2	23	221	40.800429000000001	40.824558000000003	47.836775000000003	47.824604999999998	0103000020E610000001000000050000008FE21C75746644401D8F19A88CE947408FE21C7574664440228E75711BEB4740DDD3D51D8B694440228E75711BEB4740DDD3D51D8B6944401D8F19A88CE947408FE21C75746644401D8F19A88CE94740
2345	Раздорская	2	23	221	40.634546	40.668529999999997	47.553221999999998	47.531525000000002	0103000020E6100000010000000500000060E7A6CD38514440D200DE0209C4474060E7A6CD38514440BFB67EFACFC647408B321B6492554440BFB67EFACFC647408B321B6492554440D200DE0209C4474060E7A6CD38514440D200DE0209C44740
23972	Пухляковский	2	23	221	40.571376999999998	40.605342	47.519143	47.510556000000001	0103000020E61000000100000005000000E257ACE122494440676325E659C14740E257ACE12249444042791F4773C247409772BED87B4D444042791F4773C247409772BED87B4D4440676325E659C14740E257ACE122494440676325E659C14740
24116	Ольховский	2	23	221	40.695397999999997	40.714073999999997	47.649698999999998	47.631473	0103000020E6100000010000000500000016DA39CD025944404CA7751BD4D0474016DA39CD02594440389F3A5629D347404276DEC6665B4440389F3A5629D347404276DEC6665B44404CA7751BD4D0474016DA39CD025944404CA7751BD4D04740
24575	Нижнекундрюченская	2	23	221	40.933568000000001	40.960428	47.758246	47.742252000000001	0103000020E61000000100000005000000CB4BFE277F774440FFB1101D02DF4740CB4BFE277F774440522976340EE14740D314014EEF7A4440522976340EE14740D314014EEF7A4440FFB1101D02DF4740CB4BFE277F774440FFB1101D02DF4740
24766	Мостовой	2	23	221	40.807274	40.824468000000003	47.803536000000001	47.794814000000002	0103000020E610000001000000050000009F7422C15467444094331477BCE547409F7422C1546744404F948444DAE647409D4CDC2A886944404F948444DAE647409D4CDC2A8869444094331477BCE547409F7422C15467444094331477BCE54740
23858	Мелиховская	2	23	221	40.468879000000001	40.516345999999999	47.489595999999999	47.465173999999998	0103000020E61000000100000005000000FE63213A043C4440897956D28ABB4740FE63213A043C44404F20EC14ABBE4740D0B52FA0174244404F20EC14ABBE4740D0B52FA017424440897956D28ABB4740FE63213A043C4440897956D28ABB4740
24212	Крымский	2	23	221	40.763193999999999	40.782553	47.677359000000003	47.659931999999998	0103000020E6100000010000000500000070404B57B0614440BCCADAA678D4474070404B57B06144405D5320B3B3D647407F315BB22A6444405D5320B3B3D647407F315BB22A644440BCCADAA678D4474070404B57B0614440BCCADAA678D44740
24071	Коныгин	2	23	221	40.684995999999998	40.698945999999999	47.595512999999997	47.585504	0103000020E6100000010000000500000006F2ECF2AD574440AED689CBF1CA474006F2ECF2AD574440E2AB1DC539CC4740C3D5011077594440E2AB1DC539CC4740C3D5011077594440AED689CBF1CA474006F2ECF2AD574440AED689CBF1CA4740
23800	Керчикский	2	23	221	40.448962999999999	40.460614	47.515315000000001	47.504707000000003	0103000020E61000000100000005000000990E9D9E77394440F9872D3D9AC04740990E9D9E77394440B21188D7F5C14740350A4966F53A4440B21188D7F5C14740350A4966F53A4440F9872D3D9AC04740990E9D9E77394440F9872D3D9AC04740
56858	Исаевский	2	23	221	40.459932000000002	40.471358000000002	47.543284	47.529474999999998	0103000020E610000001000000050000002331410DDF3A4440598638D6C5C347402331410DDF3A4440543882548AC547409F5A7D75553C4440543882548AC547409F5A7D75553C4440598638D6C5C347402331410DDF3A4440598638D6C5C34740
24379	Ещеулов	2	23	221	40.816355999999999	40.831116000000002	47.662117000000002	47.652455000000003	0103000020E610000001000000050000005AF2785A7E6844404C8E3BA583D347405AF2785A7E6844401590F63FC0D4474057975302626A44401590F63FC0D4474057975302626A44404C8E3BA583D347405AF2785A7E6844404C8E3BA583D34740
24823	Евсеевский	2	23	221	40.784277000000003	40.803564000000001	47.834138000000003	47.821174999999997	0103000020E61000000100000005000000A4005130636444407AA52C431CE94740A400513063644440E92CB308C5EA4740191F662FDB664440E92CB308C5EA4740191F662FDB6644407AA52C431CE94740A4005130636444407AA52C431CE94740
24145	Виноградный	2	23	221	40.711981000000002	40.725375	47.657170999999998	47.649904999999997	0103000020E61000000100000005000000CB2F8331225B4440E140481630D34740CB2F8331225B44409770E82D1ED44740022B8716D95C44409770E82D1ED44740022B8716D95C4440E140481630D34740CB2F8331225B4440E140481630D34740
24693	Верхнекундрюченская	2	23	221	40.835912999999998	40.855262000000003	47.791956999999996	47.765332999999998	0103000020E610000001000000050000008FA67A32FF6A444058C6866EF6E147408FA67A32FF6A44404C6BD3D85EE547407BC1A739796D44404C6BD3D85EE547407BC1A739796D444058C6866EF6E147408FA67A32FF6A444058C6866EF6E14740
2462	Бронницкий	2	23	221	40.923462000000001	40.939399000000002	47.689084999999999	47.672463	0103000020E61000000100000005000000A48CB800347644409162804413D64740A48CB800347644400395F1EF33D847409372F7393E7844400395F1EF33D847409372F7393E7844409162804413D64740A48CB800347644409162804413D64740
24481	Апаринский	2	23	221	40.901535000000003	40.935608000000002	47.671515999999997	47.651865999999998	0103000020E610000001000000050000008599B67F65734440EAAF575870D347408599B67F65734440D05E7D3CF4D5474020F0C000C2774440D05E7D3CF4D5474020F0C000C2774440EAAF575870D347408599B67F65734440EAAF575870D34740
30583	Чумаков	2	23	76	41.369942999999999	41.380094	47.889682000000001	47.881416000000002	0103000020E610000001000000050000002B31CF4A5AAF4440E8154F3DD2F047402B31CF4A5AAF444081EB8A19E1F14740F2B391EBA6B0444081EB8A19E1F14740F2B391EBA6B04440E8154F3DD2F047402B31CF4A5AAF4440E8154F3DD2F04740
515	Углегорский	2	23	76	41.247107	41.269511000000001	48.247135	48.235481	0103000020E610000001000000050000006CCEC133A19F444029EACC3D241E48406CCEC133A19F44403659A31EA21F4840C57421567FA244403659A31EA21F4840C57421567FA2444029EACC3D241E48406CCEC133A19F444029EACC3D241E4840
91	Тацинская	2	23	76	41.214255999999999	41.327713000000003	48.207856	48.182203999999999	0103000020E61000000100000005000000637C98BD6C9B4440A699EE7552174840637C98BD6C9B4440812381069B1A4840AEBCE47FF2A94440812381069B1A4840AEBCE47FF2A94440A699EE7552174840637C98BD6C9B4440A699EE7552174840
997	Скосырская	2	23	76	41.294134	41.318784000000001	48.417437999999997	48.408019000000003	0103000020E610000001000000050000002252D32EA6A54440C59272F7393448402252D32EA6A54440C70DBF9B6E354840793E03EACDA84440C70DBF9B6E354840793E03EACDA84440C59272F7393448402252D32EA6A54440C59272F739344840
708	Потапов	2	23	76	41.153089999999999	41.166412000000001	48.288666999999997	48.281753999999999	0103000020E610000001000000050000001DACFF739893444033C2DB83102448401DACFF73989344409B374E0AF3244840BBD408FD4C9544409B374E0AF3244840BBD408FD4C95444033C2DB83102448401DACFF739893444033C2DB8310244840
1413	Новосуховый	2	23	76	41.393973000000003	41.421165000000002	48.125545000000002	48.110621000000002	0103000020E61000000100000005000000E6400FB56DB244401BA034D4280E4840E6400FB56DB244409296CADB11104840249C16BCE8B544409296CADB11104840249C16BCE8B544401BA034D4280E4840E6400FB56DB244401BA034D4280E4840
1575	Новороссошанский	2	23	76	41.349435	41.368667000000002	47.924942999999999	47.900877000000001	0103000020E61000000100000005000000F4893C49BAAC4440FB5B02F04FF34740F4893C49BAAC444002D53F8864F64740A60EF27A30AF444002D53F8864F64740A60EF27A30AF4440FB5B02F04FF34740F4893C49BAAC4440FB5B02F04FF34740
947	Надежевка	2	23	76	41.221856000000002	41.252353999999997	48.408444000000003	48.395536	0103000020E61000000100000005000000F03504C7659C4440013274ECA0324840F03504C7659C4440AC1F9BE447344840E481C8224DA04440AC1F9BE447344840E481C8224DA04440013274ECA0324840F03504C7659C4440013274ECA0324840
762	Михайлов	2	23	76	41.159835999999999	41.195974999999997	48.254136000000003	48.223945999999998	0103000020E610000001000000050000009A5C8C8175944440F6083543AA1C48409A5C8C81759444403E5E488787204840B3EA73B5159944403E5E488787204840B3EA73B515994440F6083543AA1C48409A5C8C8175944440F6083543AA1C4840
588	Маслов	2	23	76	41.142435999999996	41.163268000000002	48.322856999999999	48.310496000000001	0103000020E61000000100000005000000F3E2C4573B924440F8C43A55BE274840F3E2C4573B9244407024D06053294840DE3D40F7E59444407024D06053294840DE3D40F7E5944440F8C43A55BE274840F3E2C4573B924440F8C43A55BE274840
1246	Луговой	2	23	76	41.393793000000002	41.423797	48.305432000000003	48.296987999999999	0103000020E6100000010000000500000066321CCF67B24440F8A6E9B30326484066321CCF67B2444071935165182748404B92E7FA3EB6444071935165182748404B92E7FA3EB64440F8A6E9B30326484066321CCF67B24440F8A6E9B303264840
878	Крюков	2	23	76	41.232115	41.256287999999998	48.369534999999999	48.347444000000003	0103000020E610000001000000050000009DF4BEF1B59D44408198840B792C48409DF4BEF1B59D44401ADD41EC4C2F4840BA2D910BCEA044401ADD41EC4C2F4840BA2D910BCEA044408198840B792C48409DF4BEF1B59D44408198840B792C4840
1348	Крылов	2	23	76	41.510727000000003	41.552705000000003	48.147835000000001	48.134247000000002	0103000020E61000000100000005000000941799805FC14440064B75012F114840941799805FC14440221ADD41EC124840F8AA9509BFC64440221ADD41EC124840F8AA9509BFC64440064B75012F114840941799805FC14440064B75012F114840
1307	Ковылкин	2	23	76	41.464948999999997	41.485143000000001	48.251376	48.237287999999999	0103000020E6100000010000000500000069A7E67283BB4440DBDD03745F1E484069A7E67283BB4440E97FB9162D2048401171732A19BE4440E97FB9162D2048401171732A19BE4440DBDD03745F1E484069A7E67283BB4440DBDD03745F1E4840
1073	Качалин	2	23	76	41.394044999999998	41.415838000000001	48.467953999999999	48.456721999999999	0103000020E610000001000000050000007F130A1170B244408EAED2DD753A48407F130A1170B244402504ABEAE53B48408F37F92D3AB544402504ABEAE53B48408F37F92D3AB544408EAED2DD753A48407F130A1170B244408EAED2DD753A4840
641	Карпово-Обрывский	2	23	76	41.127290000000002	41.147959999999998	48.291065000000003	48.275123000000001	0103000020E61000000100000005000000CE8DE9094B9044404FB0FF3A37234840CE8DE9094B9044405001309E41254840DE8E705AF09244405001309E41254840DE8E705AF09244404FB0FF3A37234840CE8DE9094B9044404FB0FF3A37234840
194	Исаев	2	23	76	41.099944999999998	41.122089000000003	48.092835000000001	48.074506	0103000020E6100000010000000500000009336DFFCA8C44408AADA0698909484009336DFFCA8C44404B766C04E20B4840C619C39CA08F44404B766C04E20B4840C619C39CA08F44408AADA0698909484009336DFFCA8C44408AADA06989094840
1535	Зазерский	2	23	76	41.513601999999999	41.541279000000003	47.996062000000002	47.973205	0103000020E610000001000000050000008194D8B5BDC14440DFA63FFB91FC47408194D8B5BDC14440E964A9F57EFF47407C8159A148C54440E964A9F57EFF47407C8159A148C54440DFA63FFB91FC47408194D8B5BDC14440DFA63FFB91FC4740
56616	Жирнов	2	23	76	41.037773000000001	41.683301999999998	48.554696999999997	47.853580999999998	0103000020E61000000100000005000000FED5E3BED584444055BE672442ED4740FED5E3BED58444403B18B14F004748404CA59F7076D744403B18B14F004748404CA59F7076D7444055BE672442ED4740FED5E3BED584444055BE672442ED4740
54931	Жирнов	2	23	76	41.096918000000002	41.149487999999998	48.182665999999998	48.148003000000003	0103000020E6100000010000000500000066321CCF678C4440DE5A26C3F112484066321CCF678C4440AA0B7899611748407D923B6C22934440AA0B7899611748407D923B6C22934440DE5A26C3F112484066321CCF678C4440DE5A26C3F1124840
1696	Ермаковская	2	23	76	41.255552000000002	41.314948000000001	48.049835000000002	48.036124999999998	0103000020E61000000100000005000000B5368DEDB5A04440B4C876BE9F044840B5368DEDB5A044401C9947FE6006484066F84F3750A844401C9947FE6006484066F84F3750A84440B4C876BE9F044840B5368DEDB5A04440B4C876BE9F044840
1186	Верхнеобливский	2	23	76	41.454689999999999	41.492517999999997	48.398705999999997	48.384622999999998	0103000020E61000000100000005000000BCE82B4833BA44400B2593533B314840BCE82B4833BA4440075C57CC083348407D586FD40ABF4440075C57CC083348407D586FD40ABF44400B2593533B314840BCE82B4833BA44400B2593533B314840
1650	Верхнекольцов	2	23	76	41.320715	41.345903999999997	48.049425999999997	48.033901999999998	0103000020E61000000100000005000000172B6A300DA944406EA296E656044840172B6A300DA944403AC95697530648401DC70F9546AC44403AC95697530648401DC70F9546AC44406EA296E656044840172B6A300DA944406EA296E656044840
458	Быстрогорский	2	23	76	41.126607	41.154508999999997	48.216994	48.182552000000001	0103000020E61000000100000005000000EB387EA834904440E2E82ADD5D174840EB387EA834904440D0B69A75C61B484005F86EF3C6934440D0B69A75C61B484005F86EF3C6934440E2E82ADD5D174840EB387EA834904440E2E82ADD5D174840
1458	Араканцев	2	23	76	41.534109999999998	41.565640999999999	48.058616000000001	48.032353000000001	0103000020E61000000100000005000000B83B6BB75DC44440B876A22424044840B83B6BB75DC44440DC82A5BA800748406C239EEC66C84440DC82A5BA800748406C239EEC66C84440B876A22424044840B83B6BB75DC44440B876A22424044840
56898	Шарпаевка	2	23	1878	40.971361000000002	41.004041000000001	48.594804000000003	48.576126000000002	0103000020E6100000010000000500000010CEA78E557C44400A302C7FBE49484010CEA78E557C4440D7C39789224C4840EC6B5D6A84804440D7C39789224C4840EC6B5D6A848044400A302C7FBE49484010CEA78E557C44400A302C7FBE494840
57016	Чеботовка	2	23	1878	39.979171000000001	40.005654	48.660136000000001	48.639868	0103000020E610000001000000050000008718AF7955FD4340E3E0D231E75148408718AF7955FD4340C57421567F544840B98B3045B9004440C57421567F544840B98B3045B9004440E3E0D231E75148408718AF7955FD4340E3E0D231E7514840
56875	Ушаковка	2	23	1878	39.784461999999998	39.808348000000002	48.805788999999997	48.781989000000003	0103000020E61000000100000005000000357A354069E44340776A2E3718644840357A354069E44340FF3C0D1824674840BDE47FF277E74340FF3C0D1824674840BDE47FF277E74340776A2E3718644840357A354069E44340776A2E3718644840
30874	Тарасовский	2	23	1878	40.322426999999998	40.399375999999997	48.761158999999999	48.718184000000001	0103000020E61000000100000005000000772CB6494529444057410C74ED5B4840772CB649452944402D077AA86D6148405567B5C01E3344402D077AA86D6148405567B5C01E33444057410C74ED5B4840772CB6494529444057410C74ED5B4840
56912	Сергеевка	2	23	1878	40.930649000000003	40.964021000000002	48.688758	48.677003999999997	0103000020E610000001000000050000000E87A5811F7744406EA12B11A85648400E87A5811F774440DF6DDE382958484020D4450A657B4440DF6DDE382958484020D4450A657B44406EA12B11A85648400E87A5811F7744406EA12B11A8564840
56947	Россошь	2	23	1878	40.454523999999999	40.542011000000002	48.767425000000003	48.744129000000001	0103000020E61000000100000005000000A19FA9D72D3A4440AA807B9E3F5F4840A19FA9D72D3A444000917EFB3A6248404089CF9D6045444000917EFB3A6248404089CF9D60454440AA807B9E3F5F4840A19FA9D72D3A4440AA807B9E3F5F4840
56864	Прогной	2	23	1878	39.791809999999998	39.872990999999999	48.777363999999999	48.746589	0103000020E61000000100000005000000A852B3075AE54340D446753A905F4840A852B3075AE543403B8BDEA980634840E659492BBEEF43403B8BDEA980634840E659492BBEEF4340D446753A905F4840A852B3075AE54340D446753A905F4840
56826	Новоалексеевка	2	23	1878	40.691194000000003	40.735418000000003	48.659545999999999	48.645826999999997	0103000020E610000001000000050000008198840B79584440D8EF8975AA5248408198840B79584440931ADA006C544840E371512D225E4440931ADA006C544840E371512D225E4440D8EF8975AA5248408198840B79584440D8EF8975AA524840
30769	Нижняя Тарасовка	2	23	1878	40.310685999999997	40.339575000000004	48.735531999999999	48.723526999999997	0103000020E610000001000000050000009BA9108FC4274440F16261889C5C48409BA9108FC4274440AB949EE9255E484005C58F31772B4440AB949EE9255E484005C58F31772B4440F16261889C5C48409BA9108FC4274440F16261889C5C4840
56807	Нижнемитякин	2	23	1878	40.003335999999997	40.088684999999998	48.737237	48.660356	0103000020E61000000100000005000000217365506D004440D3DB9F8B86544840217365506D004440593332C85D5E4840A852B3075A0B4440593332C85D5E4840A852B3075A0B4440D3DB9F8B86544840217365506D004440D3DB9F8B86544840
56920	Нижнемакеевский	2	23	1878	40.955047	40.978501999999999	48.793498999999997	48.775530000000003	0103000020E610000001000000050000004B92E7FA3E7A444090882991446348404B92E7FA3E7A444050340F60916548400989B48D3F7D444050340F60916548400989B48D3F7D444090882991446348404B92E7FA3E7A44409088299144634840
56782	Можаевка	2	23	1878	39.729754	39.785682999999999	48.778457000000003	48.729899000000003	0103000020E6100000010000000500000006103E9468DD43400A3197546D5D484006103E9468DD4340D02B9E7AA4634840F702B34291E44340D02B9E7AA4634840F702B34291E443400A3197546D5D484006103E9468DD43400A3197546D5D4840
30231	Митякинская	2	23	1878	39.742545999999997	39.810144000000001	48.621087000000003	48.603943999999998	0103000020E6100000010000000500000047E350BF0BDF4340C64E78094E4D484047E350BF0BDF4340427C60C77F4F48407B8670CCB2E74340427C60C77F4F48407B8670CCB2E74340C64E78094E4D484047E350BF0BDF4340C64E78094E4D4840
56829	Мартыновка	2	23	1878	40.600301999999999	40.686819	48.663854999999998	48.646065	0103000020E6100000010000000500000098DC28B2D64C44408D0B0742B252484098DC28B2D64C44409E245D33F9544840BEA25BAFE95744409E245D33F9544840BEA25BAFE95744408D0B0742B252484098DC28B2D64C44408D0B0742B2524840
31381	Малое Полесье	2	23	1878	40.214691999999999	40.224941000000001	48.662337000000001	48.653869	0103000020E610000001000000050000003E5B07077B1B4440226FB9FAB15348403E5B07077B1B444023F77475C7544840C843DFDDCA1C444023F77475C7544840C843DFDDCA1C4440226FB9FAB15348403E5B07077B1B4440226FB9FAB1534840
57001	Курно-Липовка	2	23	1878	40.623882999999999	40.680782999999998	48.697066	48.674397999999997	0103000020E61000000100000005000000E3C3EC65DB4F4440703E75AC52564840E3C3EC65DB4F4440A7936C75395948401D56B8E523574440A7936C75395948401D56B8E523574440703E75AC52564840E3C3EC65DB4F4440703E75AC52564840
56850	Красновка	2	23	1878	40.086044000000001	40.108592000000002	48.82647	48.809029000000002	0103000020E610000001000000050000002E02637D030B4440FF4124438E6748402E02637D030B44400490DAC4C9694840BA4DB857E60D44400490DAC4C9694840BA4DB857E60D4440FF4124438E6748402E02637D030B4440FF4124438E674840
56872	Каюковка	2	23	1878	40.294561000000002	40.331473000000003	48.710076000000001	48.660314	0103000020E61000000100000005000000AAD6C22CB4254440A48B4D2B85544840AAD6C22CB425444056D636C5E35A4840E6400FB56D2A444056D636C5E35A4840E6400FB56D2A4440A48B4D2B85544840AAD6C22CB4254440A48B4D2B85544840
30284	Изумрудный	2	23	1878	40.773434999999999	40.784511000000002	48.649053000000002	48.645713999999998	0103000020E61000000100000005000000774A07EBFF624440E048A0C1A6524840774A07EBFF624440732F302B14534840172D40DB6A644440732F302B14534840172D40DB6A644440E048A0C1A6524840774A07EBFF624440E048A0C1A6524840
56738	Зеленовка	2	23	1878	39.953344999999999	40.004297000000001	48.633229999999998	48.600476999999998	0103000020E610000001000000050000000E677E3507FA434006802A6EDC4C48400E677E3507FA43404C6C3EAE0D514840473CD9CD8C0044404C6C3EAE0D514840473CD9CD8C00444006802A6EDC4C48400E677E3507FA434006802A6EDC4C4840
56729	Ефремово-Степановка	2	23	1878	40.805656999999997	40.851714000000001	48.738264999999998	48.693027999999998	0103000020E610000001000000050000009065C1C41F6744402C9B3924B55848409065C1C41F6744400664AF777F5E4840CEC5DFF6046D44400664AF777F5E4840CEC5DFF6046D44402C9B3924B55848409065C1C41F6744402C9B3924B5584840
57010	Ерофеевка	2	23	1878	40.565564999999999	40.582354000000002	48.600185000000003	48.572173999999997	0103000020E610000001000000050000009161156F644844408DCF64FF3C4948409161156F644844405F46B1DCD24C4840EF586C938A4A44405F46B1DCD24C4840EF586C938A4A44408DCF64FF3C4948409161156F644844408DCF64FF3C494840
56889	Елань	2	23	1878	39.749355000000001	39.804251000000001	48.698047000000003	48.676515999999999	0103000020E610000001000000050000000B0C59DDEADF4340419C8713985648400B0C59DDEADF43401409A69A595948403D635FB2F1E643401409A69A595948403D635FB2F1E64340419C8713985648400B0C59DDEADF4340419C871398564840
56867	Егоро-Калитвенский	2	23	1878	40.577755000000003	40.594400999999998	48.641077000000003	48.623958000000002	0103000020E61000000100000005000000DD0C37E0F3494440EE0912DBDD4F4840DD0C37E0F3494440E19BA6CF0E524840D7DAFB54154C4440E19BA6CF0E524840D7DAFB54154C4440EE0912DBDD4F4840DD0C37E0F3494440EE0912DBDD4F4840
56769	Дячкино	2	23	1878	40.278885000000002	40.339278999999998	48.639856000000002	48.617978999999998	0103000020E61000000100000005000000282CF180B2234440B14E95EF194F4840282CF180B22344401F1329CDE65148401B9C887E6D2B44401F1329CDE65148401B9C887E6D2B4440B14E95EF194F4840282CF180B2234440B14E95EF194F4840
56795	Дубы	2	23	1878	39.820466000000003	39.901646999999997	48.666265000000003	48.609037999999998	0103000020E610000001000000050000006FBDA60705E94340B8020AF5F44D48406FBDA60705E9434017BCE82B48554840ACC43C2B69F3434017BCE82B48554840ACC43C2B69F34340B8020AF5F44D48406FBDA60705E94340B8020AF5F44D4840
30760	Донская Нива	2	23	1878	40.434922999999998	40.454335	48.742086	48.728780999999998	0103000020E610000001000000050000009CA38E8EAB3744401C7920B2485D48409CA38E8EAB374440E4688EACFC5E4840CE3637A6273A4440E4688EACFC5E4840CE3637A6273A44401C7920B2485D48409CA38E8EAB3744401C7920B2485D4840
32235	Деркул	2	23	1878	39.802796000000001	39.8123	48.826399000000002	48.821587999999998	0103000020E6100000010000000500000008AEF204C2E643409D64ABCB2969484008AEF204C2E643403B394371C769484039454772F9E743403B394371C769484039454772F9E743409D64ABCB2969484008AEF204C2E643409D64ABCB29694840
56886	Грачи	2	23	1878	40.521799000000001	40.554335999999999	48.646796999999999	48.626668000000002	0103000020E61000000100000005000000F20A444FCA42444091B932A836504840F20A444FCA42444051137D3ECA5248406B7F677BF446444051137D3ECA5248406B7F677BF446444091B932A836504840F20A444FCA42444091B932A836504840
32088	Войково	2	23	1878	39.838692999999999	39.867671999999999	48.712887000000002	48.699354999999997	0103000020E610000001000000050000002B31CF4A5AEB4340A4A5F276845948402B31CF4A5AEB43402D5F97E13F5B4840D4D347E00FEF43402D5F97E13F5B4840D4D347E00FEF4340A4A5F276845948402B31CF4A5AEB4340A4A5F27684594840
31470	Весенний	2	23	1878	40.190069000000001	40.211503	48.752405000000003	48.739798	0103000020E61000000100000005000000E17D552E54184440B7D26BB3B15E4840E17D552E54184440672C9ACE4E604840C100C287121B4440672C9ACE4E604840C100C287121B4440B7D26BB3B15E4840E17D552E54184440B7D26BB3B15E4840
31576	Верхний Митякин	2	23	1878	40.077744000000003	40.128283000000003	48.788234000000003	48.733535000000003	0103000020E61000000100000005000000E9BAF083F309444056BC9179E45D4840E9BAF083F309444032CC09DAE4644840FFD0CC936B10444032CC09DAE4644840FFD0CC936B10444056BC9179E45D4840E9BAF083F309444056BC9179E45D4840
31887	Верхние Грачики	2	23	1878	39.958914	39.985405999999998	48.558478000000001	48.551155000000001	0103000020E6100000010000000500000099D6A6B1BDFA434071033E3F8C46484099D6A6B1BDFA43408BC404357C4748401EA4A7C821FE43408BC404357C4748401EA4A7C821FE434071033E3F8C46484099D6A6B1BDFA434071033E3F8C464840
31501	Верхнетарасовский	2	23	1878	40.275435999999999	40.296528000000002	48.789012	48.772989000000003	0103000020E610000001000000050000000E12A27C412344407995B54DF16248400E12A27C4123444066136058FE644840952C27A1F425444066136058FE644840952C27A1F42544407995B54DF16248400E12A27C412344407995B54DF1624840
56680	Васильевка	2	23	1878	40.324592000000003	40.348244000000001	48.720663000000002	48.696007000000002	0103000020E6100000010000000500000089450C3B8C294440BF64E3C11659484089450C3B8C294440F83768AF3E5C48409D836742932C4440F83768AF3E5C48409D836742932C4440BF64E3C11659484089450C3B8C294440BF64E3C116594840
54932	Большинка	2	23	1878	41.062179999999998	41.104024000000003	48.669066999999998	48.640076999999998	0103000020E610000001000000050000008E3BA583F5874440FDF50A0BEE5148408E3BA583F58744409AEAC9FCA3554840E3FF8EA8508D44409AEAC9FCA3554840E3FF8EA8508D4440FDF50A0BEE5148408E3BA583F5874440FDF50A0BEE514840
29953	Александровка	2	23	1878	40.832104000000001	40.887358999999996	48.807153999999997	48.781852999999998	0103000020E61000000100000005000000766F4562826A4440C6A354C213644840766F4562826A4440F46A80D250674840D767CEFA94714440F46A80D250674840D767CEFA94714440C6A354C213644840766F4562826A4440C6A354C213644840
29775	Чистяково	2	23	1373	42.043976000000001	42.066029999999998	49.053704000000003	49.036278000000003	0103000020E610000001000000050000008AE76C01A10545403BC8EBC1A48448408AE76C01A10545400BD5CDC5DF8648400647C9AB730845400BD5CDC5DF8648400647C9AB730845403BC8EBC1A48448408AE76C01A10545403BC8EBC1A4844840
29615	Чирский	2	23	1373	42.164431	42.182119	48.906725999999999	48.893785999999999	0103000020E610000001000000050000006BB933130C154540B3CF6394677248406BB933130C1545406937FA980F744840787DE6AC4F1745406937FA980F744840787DE6AC4F174540B3CF6394677248406BB933130C154540B3CF639467724840
29694	Усть-Грязновский	2	23	1373	42.078642000000002	42.144309	48.844735	48.823652000000003	0103000020E61000000100000005000000C80BE9F0100A45407BA4C16D6D694840C80BE9F0100A4540AE64C746206C48405DC2A1B778124540AE64C746206C48405DC2A1B7781245407BA4C16D6D694840C80BE9F0100A45407BA4C16D6D694840
14946	Ставиднянский	2	23	1373	41.977034000000003	42.004826999999999	49.055109000000002	49.039873999999998	0103000020E61000000100000005000000408A3A730FFD4440F8FA5A971A854840408A3A730FFD44408E5BCCCF0D874840A391CF2B9E0045408E5BCCCF0D874840A391CF2B9E004540F8FA5A971A854840408A3A730FFD4440F8FA5A971A854840
29416	Советская	2	23	1373	42.097479999999997	42.136960999999999	49.018082999999997	48.997824999999999	0103000020E61000000100000005000000CD0182397A0C4540CB10C7BAB87F4840CD0182397A0C454089CE328B50824840EAE923F08711454089CE328B50824840EAE923F087114540CB10C7BAB87F4840CD0182397A0C4540CB10C7BAB87F4840
14910	Русаков	2	23	1373	42.149932	42.169201000000001	49.021532999999998	49.009155	0103000020E61000000100000005000000DB4FC6F83013454025CCB4FD2B814840DB4FC6F8301345407364E597C1824840AAB9DC60A81545407364E597C1824840AAB9DC60A815454025CCB4FD2B814840DB4FC6F83013454025CCB4FD2B814840
29828	Пичугин	2	23	1373	42.070242999999998	42.095979	49.127215	49.117427999999997	0103000020E61000000100000005000000EFE2FDB8FD0845403DD175E1078F4840EFE2FDB8FD084540C347C49448904840280D350A490C4540C347C49448904840280D350A490C45403DD175E1078F4840EFE2FDB8FD0845403DD175E1078F4840
29527	Петрово	2	23	1373	42.336008999999997	42.353068	49.012327999999997	49.001956	0103000020E61000000100000005000000B114C957022B4540F7031E1840804840B114C957022B45409C69C2F693814840CFA10C55312D45409C69C2F693814840CFA10C55312D4540F7031E1840804840B114C957022B4540F7031E1840804840
29450	Парамонов	2	23	1373	41.987679	42.018599000000002	48.994656999999997	48.978687999999998	0103000020E6100000010000000500000016F9F5436CFE44406B7EFCA5457D484016F9F5436CFE444065DEAAEB507F4840815EB8736102454065DEAAEB507F4840815EB873610245406B7EFCA5457D484016F9F5436CFE44406B7EFCA5457D4840
29683	Осиновский	2	23	1373	42.226253	42.252977999999999	48.880338000000002	48.864226000000002	0103000020E610000001000000050000009ACFB9DBF51C45402C2D23F59E6E48409ACFB9DBF51C454089B663EAAE704840C24D46956120454089B663EAAE704840C24D4695612045402C2D23F59E6E48409ACFB9DBF51C45402C2D23F59E6E4840
29597	Новорябухин	2	23	1373	42.286709999999999	42.307792999999997	48.995147000000003	48.984264000000003	0103000020E61000000100000005000000D4B7CCE9B2244540A950DD5CFC7D4840D4B7CCE9B224454034DB15FA607F48400778D2C26527454034DB15FA607F48400778D2C265274540A950DD5CFC7D4840D4B7CCE9B2244540A950DD5CFC7D4840
31309	Малые Озера	2	23	1373	42.254441999999997	42.268447000000002	48.895212999999998	48.885457000000002	0103000020E610000001000000050000004A5D328E91204540D481ACA7567148404A5D328E912045401EFAEE5696724840CBDAA6785C2245401EFAEE5696724840CBDAA6785C224540D481ACA7567148404A5D328E91204540D481ACA756714840
29511	Калач-Куртлак	2	23	1373	42.414675000000003	42.445819	49.001773	48.984546999999999	0103000020E6100000010000000500000002BC051214354540FD2FD7A2057E484002BC051214354540068200193A804840BC77D49810394540068200193A804840BC77D49810394540FD2FD7A2057E484002BC051214354540FD2FD7A2057E4840
56677	Шаминка	2	23	264	41.078045000000003	41.097008000000002	47.384666000000003	47.367860999999998	0103000020E61000000100000005000000E44EE960FD894440A73CBA1116AF4740E44EE960FD8944400BF148BC3CB14740A6B915C26A8C44400BF148BC3CB14740A6B915C26A8C4440A73CBA1116AF4740E44EE960FD894440A73CBA1116AF4740
56643	Чебачий	2	23	264	40.901004999999998	40.930092000000002	47.573481000000001	47.554006999999999	0103000020E610000001000000050000002844C02154734440A6608DB3E9C647402844C021547344404EF04DD367C94740B82231410D7744404EF04DD367C94740B82231410D774440A6608DB3E9C647402844C02154734440A6608DB3E9C64740
54814	Топилин	2	23	264	41.132266999999999	41.154698000000003	47.376044999999998	47.355086	0103000020E6100000010000000500000086AB0320EE9044403CA2427573AD474086AB0320EE9044408369183E22B04740D960E124CD9344408369183E22B04740D960E124CD9344403CA2427573AD474086AB0320EE9044403CA2427573AD4740
56701	Титов	2	23	264	41.363115999999998	41.382043000000003	47.533861000000002	47.511291999999997	0103000020E61000000100000005000000C153C8957AAE44406C5A290472C14740C153C8957AAE444010CEA78E55C447403755F7C8E6B0444010CEA78E55C447403755F7C8E6B044406C5A290472C14740C153C8957AAE44406C5A290472C14740
56658	Сусат	2	23	264	40.683909	40.707777	47.435724999999998	47.416595000000001	0103000020E61000000100000005000000543882548A574440AC5626FC52B54740543882548A574440598638D6C5B7474035EECD6F985A4440598638D6C5B7474035EECD6F985A4440AC5626FC52B54740543882548A574440AC5626FC52B54740
56706	Страхов	2	23	264	41.011470000000003	41.034332999999997	47.400221000000002	47.382286999999998	0103000020E610000001000000050000004C7155D977814440CD57C9C7EEB047404C7155D977814440121615713AB347403716140665844440121615713AB347403716140665844440CD57C9C7EEB047404C7155D977814440CD57C9C7EEB04740
4374	Старая Станица	2	23	264	40.795057	40.806080000000001	47.569401999999997	47.554402000000003	0103000020E610000001000000050000005ABA826DC4654440236B0DA5F6C647405ABA826DC465444074232C2AE2C84740D7FA22A12D67444074232C2AE2C84740D7FA22A12D674440236B0DA5F6C647405ABA826DC4654440236B0DA5F6C64740
56777	Слободской	2	23	264	40.822150000000001	40.842784999999999	47.441344999999998	47.414723000000002	0103000020E61000000100000005000000053411363C69444013F3ACA415B54740053411363C69444066A032FE7DB847409947FE60E06B444066A032FE7DB847409947FE60E06B444013F3ACA415B54740053411363C69444013F3ACA415B54740
1115	Семикаракорск	2	23	264	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
56888	Павлов	2	23	264	41.133318000000003	41.162998000000002	47.317022999999999	47.307974999999999	0103000020E61000000100000005000000ECFB709010914440287E8CB96BA74740ECFB709010914440378AAC3594A847401EA8531EDD944440378AAC3594A847401EA8531EDD944440287E8CB96BA74740ECFB709010914440287E8CB96BA74740
56909	Новоромановский	2	23	264	40.78125	40.789667000000001	47.446263000000002	47.432713999999997	0103000020E610000001000000050000000000000000644440BB421F2C63B7474000000000006444401A355F251FB947407FDDE9CE136544401A355F251FB947407FDDE9CE13654440BB421F2C63B747400000000000644440BB421F2C63B74740
22637	Новозолотовская	2	23	264	40.933038000000003	40.967748999999998	47.574472	47.557034999999999	0103000020E610000001000000050000006FF607CA6D7744401ADD41EC4CC747406FF607CA6D774440DE3B6A4C88C947404CDE0033DF7B4440DE3B6A4C88C947404CDE0033DF7B44401ADD41EC4CC747406FF607CA6D7744401ADD41EC4CC74740
2113	Нижний Саловск	2	23	264	40.942165000000003	40.953851999999998	47.483544000000002	47.473903	0103000020E61000000100000005000000CA37DBDC98784440F73C7FDAA8BC4740CA37DBDC98784440A91611C5E4BD4740B29C84D2177A4440A91611C5E4BD4740B29C84D2177A4440F73C7FDAA8BC4740CA37DBDC98784440F73C7FDAA8BC4740
56664	Маломечетный	2	23	264	41.077218000000002	41.102299000000002	47.517707000000001	47.502381	0103000020E61000000100000005000000CE548847E2894440DE9046054EC04740CE548847E289444084F4143944C24740EEB43522188D444084F4143944C24740EEB43522188D4440DE9046054EC04740CE548847E2894440DE9046054EC04740
56907	Лиманский	2	23	264	41.045436000000002	41.076104000000001	47.228986999999996	47.221533000000001	0103000020E61000000100000005000000D107CBD8D08544400DFE7E315B9C4740D107CBD8D0854440C51A2E724F9D4740228C9FC6BD894440C51A2E724F9D4740228C9FC6BD8944400DFE7E315B9C4740D107CBD8D08544400DFE7E315B9C4740
56693	Кузнецовка	2	23	264	40.940477000000001	40.967174	47.419522000000001	47.399574999999999	0103000020E61000000100000005000000F2D1E28C617844404CA60A4625B34740F2D1E28C61784440ECF99AE5B2B5474050C58D5BCC7B4440ECF99AE5B2B5474050C58D5BCC7B44404CA60A4625B34740F2D1E28C617844404CA60A4625B34740
22878	Крымский	2	23	264	41.280712999999999	41.294736	47.488086000000003	47.482374	0103000020E61000000100000005000000F1475167EEA344406938656EBEBD4740F1475167EEA3444057D11F9A79BE4740187AC4E8B9A5444057D11F9A79BE4740187AC4E8B9A544406938656EBEBD4740F1475167EEA344406938656EBEBD4740
1693	Кочетовская	2	23	264	40.829669000000003	40.861604	47.587983999999999	47.570836999999997	0103000020E61000000100000005000000A5C00298326A4440622CD32F11C94740A5C00298326A44401F49490F43CB4740280D350A496E44401F49490F43CB4740280D350A496E4440622CD32F11C94740A5C00298326A4440622CD32F11C94740
56890	Костылевка	2	23	264	40.696987999999997	40.738643000000003	47.445684	47.436571999999998	0103000020E610000001000000050000002BDA1CE736594440B62C5F97E1B747402BDA1CE736594440DC2C5E2C0CB94740AD3594DA8B5E4440DC2C5E2C0CB94740AD3594DA8B5E4440B62C5F97E1B747402BDA1CE736594440B62C5F97E1B74740
57025	Кирсановка	2	23	264	40.991275999999999	41.010607999999998	47.373927000000002	47.357160999999998	0103000020E61000000100000005000000A4A7C821E27E44400D349F73B7AD4740A4A7C821E27E4440B30B06D7DCAF4740B9895A9A5B814440B30B06D7DCAF4740B9895A9A5B8144400D349F73B7AD4740A4A7C821E27E44400D349F73B7AD4740
54909	Золотаревка	2	23	264	41.074092	41.105829	47.345342000000002	47.320596999999999	0103000020E610000001000000050000009772BED87B8944400D198F5209A947409772BED87B894440B6F7A92A34AC4740F4FBFECD8B8D4440B6F7A92A34AC4740F4FBFECD8B8D44400D198F5209A947409772BED87B8944400D198F5209A94740
22800	Зеленая Горка	2	23	264	41.203296999999999	41.218164000000002	47.483390999999997	47.473373000000002	0103000020E61000000100000005000000FD2FD7A2059A44409BE7887C97BC4740FD2FD7A2059A444022179CC1DFBD4740109546CCEC9B444022179CC1DFBD4740109546CCEC9B44409BE7887C97BC4740FD2FD7A2059A44409BE7887C97BC4740
2002	Задоно-Кагальницкая	2	23	264	41.272961000000002	41.318019999999997	47.528002999999998	47.516021000000002	0103000020E61000000100000005000000AF0AD462F0A244404D86E3F90CC24740AF0AD462F0A244404E98309A95C34740A9BC1DE1B4A844404E98309A95C34740A9BC1DE1B4A844404D86E3F90CC24740AF0AD462F0A244404D86E3F90CC24740
56756	Жуков	2	23	264	41.192273999999998	41.210994999999997	47.520305	47.509143999999999	0103000020E6100000010000000500000080EF366F9C984440317A6EA12BC1474080EF366F9C984440FF78AF5A99C247404C4F58E2019B4440FF78AF5A99C247404C4F58E2019B4440317A6EA12BC1474080EF366F9C984440317A6EA12BC14740
56657	Вислый	2	23	264	41.130138000000002	41.185383999999999	47.509746	47.458339000000002	0103000020E61000000100000005000000C2FBAA5CA89044409DBD33DAAABA4740C2FBAA5CA890444027A25F5B3FC14740D099B4A9BA97444027A25F5B3FC14740D099B4A9BA9744409DBD33DAAABA4740C2FBAA5CA89044409DBD33DAAABA4740
2043	Вершинный	2	23	264	41.000205999999999	41.022016999999998	47.493073000000003	47.480012000000002	0103000020E61000000100000005000000A9A10DC00680444002D8800871BD4740A9A10DC00680444033C51C041DBF47405F7AFB73D182444033C51C041DBF47405F7AFB73D182444002D8800871BD4740A9A10DC00680444002D8800871BD4740
56902	Бугры	2	23	264	40.817442999999997	40.827396999999998	47.603582000000003	47.598697000000001	0103000020E610000001000000050000000CACE3F8A16844404E9B711AA2CC47400CACE3F8A1684440263ACB2C42CD47407DE71725E8694440263ACB2C42CD47407DE71725E86944404E9B711AA2CC47400CACE3F8A16844404E9B711AA2CC4740
56938	Балабинка	2	23	264	40.899512999999999	40.914596000000003	47.422772000000002	47.411783999999997	0103000020E61000000100000005000000D6A9F23D237344400E828E56B5B44740D6A9F23D237344400FD594641DB64740B686527B117544400FD594641DB64740B686527B117544400E828E56B5B44740D6A9F23D237344400E828E56B5B44740
56793	Бакланники	2	23	264	40.977595000000001	40.991087999999998	47.447316999999998	47.436821999999999	0103000020E61000000100000005000000D7DD3CD5217D44402F1686C8E9B74740D7DD3CD5217D4440F0F8F6AE41B94740A1BAB9F8DB7E4440F0F8F6AE41B94740A1BAB9F8DB7E44402F1686C8E9B74740D7DD3CD5217D44402F1686C8E9B74740
2795	Ясенево	2	23	461	41.332087999999999	41.342823000000003	46.552363999999997	46.544977000000003	0103000020E6100000010000000500000070B20DDC81AA44403E096CCEC145474070B20DDC81AA44406EBE11DDB346474087A8C29FE1AB44406EBE11DDB346474087A8C29FE1AB44403E096CCEC145474070B20DDC81AA44403E096CCEC1454740
56627	Юловский	2	23	461	41.118279999999999	42.177439	47.041088999999999	46.143811999999997	0103000020E61000000100000005000000ACE28DCC238F4440DC627E6E68124740ACE28DCC238F4440D89C83674285474079043752B6164540D89C83674285474079043752B6164540DC627E6E68124740ACE28DCC238F4440DC627E6E68124740
28061	Шаблиевка	2	23	461	41.611015000000002	41.648484000000003	46.554087000000003	46.534481999999997	0103000020E61000000100000005000000C72E51BD35CE44407C26FBE769444740C72E51BD35CE4440C311A452EC46474059FD118601D34440C311A452EC46474059FD118601D344407C26FBE769444740C72E51BD35CE44407C26FBE769444740
29777	Тальники	2	23	461	41.247	41.257024999999999	46.927526	46.920676	0103000020E61000000100000005000000560E2DB29D9F4440261B0FB6D8754740560E2DB29D9F44404818062CB976474090A0F831E6A044404818062CB976474090A0F831E6A04440261B0FB6D8754740560E2DB29D9F4440261B0FB6D8754740
28304	Сысоево-Александровское	2	23	461	41.247646000000003	41.305686999999999	46.419646999999998	46.405355999999998	0103000020E610000001000000050000001C7E37DDB29F4440629E95B4E23347401C7E37DDB29F4440A86E2EFEB6354740FBE769C020A74440A86E2EFEB6354740FBE769C020A74440629E95B4E23347401C7E37DDB29F4440629E95B4E2334740
27428	Супрун	2	23	461	41.377327000000001	41.387450999999999	46.763173999999999	46.755636000000003	0103000020E61000000100000005000000EB724A404CB0444013D731AEB8604740EB724A404CB04440299485AFAF614740B8E68EFE97B14440299485AFAF614740B8E68EFE97B1444013D731AEB8604740EB724A404CB0444013D731AEB8604740
27531	Степной Курган	2	23	461	41.207932	41.224263000000001	46.992775000000002	46.975481000000002	0103000020E610000001000000050000005CE509849D9A4440486FB88FDC7C47405CE509849D9A4440A9A44E40137F4740F75965A6B49C4440A9A44E40137F4740F75965A6B49C4440486FB88FDC7C47405CE509849D9A4440486FB88FDC7C4740
28466	Сеятель Северный	2	23	461	41.180928999999999	41.200665000000001	46.527433000000002	46.508853999999999	0103000020E61000000100000005000000F1F274AE289744402A38BC2022414740F1F274AE2897444064EAAEEC82434740D6390664AF99444064EAAEEC82434740D6390664AF9944402A38BC2022414740F1F274AE289744402A38BC2022414740
27690	Сандата	2	23	461	41.706721000000002	41.816783000000001	46.301167999999997	46.250526000000001	0103000020E61000000100000005000000BE326FD575DA44401B66683C11204740BE326FD575DA4440054D4BAC8C264740E27668588CE84440054D4BAC8C264740E27668588CE844401B66683C11204740BE326FD575DA44401B66683C11204740
29910	Сальский Беслан	2	23	461	41.505848999999998	41.510907000000003	46.656317000000001	46.651944	0103000020E610000001000000050000006EDBF7A8BFC044406669A7E6725347406EDBF7A8BFC04440886709320254474014268C6665C14440886709320254474014268C6665C144406669A7E6725347406EDBF7A8BFC044406669A7E672534740
2683	Сальск	2	23	461	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
28418	Рыбасово	2	23	461	41.612614000000001	41.621704999999999	46.447142999999997	46.443404999999998	0103000020E610000001000000050000002F89B3226ACE444002F1BA7EC13847402F89B3226ACE444052D158FB3B3947403D61890794CF444052D158FB3B3947403D61890794CF444002F1BA7EC13847402F89B3226ACE444002F1BA7EC1384740
27779	Романовка	2	23	461	42.111995999999998	42.150731999999998	46.355918000000003	46.336117000000002	0103000020E6100000010000000500000033A48AE2550E45409850C1E1052B474033A48AE2550E4540640795B88E2D4740F73AA92F4B134540640795B88E2D4740F73AA92F4B1345409850C1E1052B474033A48AE2550E45409850C1E1052B4740
28712	Приречный	2	23	461	41.375836	41.401114999999997	46.450918000000001	46.441777999999999	0103000020E610000001000000050000006954E0641BB04440D00B772E8C3847406954E0641BB04440C09657AEB7394740AF777FBC57B34440C09657AEB7394740AF777FBC57B34440D00B772E8C3847406954E0641BB04440D00B772E8C384740
29852	Поливной	2	23	461	41.573771000000001	41.586768999999997	46.616722000000003	46.604824000000001	0103000020E610000001000000050000005532005471C94440FFEA71DF6A4D47405532005471C94440A35C1ABFF04E47403FA7203F1BCB4440A35C1ABFF04E47403FA7203F1BCB4440FFEA71DF6A4D47405532005471C94440FFEA71DF6A4D4740
28074	Новый Маныч	2	23	461	41.862327999999998	41.880617000000001	46.517034000000002	46.498854999999999	0103000020E6100000010000000500000069368FC360EE444019390B7BDA3F474069368FC360EE4440C5758C2B2E4247409CA6CF0EB8F04440C5758C2B2E4247409CA6CF0EB8F0444019390B7BDA3F474069368FC360EE444019390B7BDA3F4740
27879	Новый Егорлык	2	23	461	41.830401999999999	41.915202999999998	46.412533000000003	46.371825999999999	0103000020E610000001000000050000003944DC9C4AEA4440B8E68EFE972F47403944DC9C4AEA4440A9C29FE1CD344740BD19355F25F54440A9C29FE1CD344740BD19355F25F54440B8E68EFE972F47403944DC9C4AEA4440B8E68EFE972F4740
29832	Новостепной	2	23	461	41.273859000000002	41.284962	46.825695000000003	46.820756000000003	0103000020E610000001000000050000008E5BCCCF0DA3444076FF58880E6947408E5BCCCF0DA3444041BCAE5FB0694740274D83A279A4444041BCAE5FB0694740274D83A279A4444076FF58880E6947408E5BCCCF0DA3444076FF58880E694740
28227	Новоселый 1-й	2	23	461	41.439365000000002	41.452112	46.428766000000003	46.410693999999999	0103000020E61000000100000005000000E700C11C3DB84440EB54F99E91344740E700C11C3DB8444081D1E5CDE1364740881057CEDEB9444081D1E5CDE1364740881057CEDEB94440EB54F99E91344740E700C11C3DB84440EB54F99E91344740
56787	Маяк	2	23	461	41.721147999999999	41.731290000000001	46.350524999999998	46.342886	0103000020E61000000100000005000000B4C9E1934EDC4440CD203EB0E32B4740B4C9E1934EDC444017B7D100DE2C474028F224E99ADD444017B7D100DE2C474028F224E99ADD4440CD203EB0E32B4740B4C9E1934EDC4440CD203EB0E32B4740
28159	Манычстрой	2	23	461	41.652993000000002	41.662568999999998	46.626866999999997	46.615434999999998	0103000020E610000001000000050000002BC24D4695D3444029E8F692C64E47402BC24D4695D3444087F8872D3D504740F52B9D0FCFD4444087F8872D3D504740F52B9D0FCFD4444029E8F692C64E47402BC24D4695D3444029E8F692C64E4740
28256	Крученая Балка	2	23	461	41.324399	41.393227000000003	46.430667	46.408195999999997	0103000020E6100000010000000500000074ED0BE885A94440D32D3BC43F34474074ED0BE885A94440B43BA41820374740BD73284355B24440B43BA41820374740BD73284355B24440D32D3BC43F34474074ED0BE885A94440D32D3BC43F344740
11240	Конезавод им. Буденного	2	23	461	41.567140999999999	41.595196000000001	46.558425	46.538747000000001	0103000020E61000000100000005000000419C871398C84440B8E864A9F5444740419C871398C8444068226C787A474740E25AED612FCC444068226C787A474740E25AED612FCC4440B8E864A9F5444740419C871398C84440B8E864A9F5444740
29941	Клены	2	23	461	41.262990000000002	41.273786999999999	46.513312999999997	46.507328000000001	0103000020E61000000100000005000000689604A8A9A144402C2CB81FF0404740689604A8A9A144404ACE893DB4414740F488D1730BA344404ACE893DB4414740F488D1730BA344402C2CB81FF0404740689604A8A9A144402C2CB81FF0404740
27659	Ивановка	2	23	461	41.637281999999999	41.695528000000003	46.221246999999998	46.179254999999998	0103000020E610000001000000050000002C2AE27492D144407E52EDD3F11647402C2AE27492D1444047AB5AD2511C4740E5B9BE0F07D9444047AB5AD2511C4740E5B9BE0F07D944407E52EDD3F11647402C2AE27492D144407E52EDD3F1164740
28010	Екатериновка	2	23	461	41.660054000000002	41.715139000000001	46.545794999999998	46.518163000000001	0103000020E6100000010000000500000008CC43A67CD44440A67F492A5342474008CC43A67CD4444000A94D9CDC4547400D8CBCAC89DB444000A94D9CDC4547400D8CBCAC89DB4440A67F492A5342474008CC43A67CD44440A67F492A53424740
2726	Гигант	2	23	461	41.320078000000002	41.356468	46.515453000000001	46.493259000000002	0103000020E61000000100000005000000A515DF50F8A8444095BA641C233F4740A515DF50F8A8444003D0285DFA414740070951BEA0AD444003D0285DFA414740070951BEA0AD444095BA641C233F4740A515DF50F8A8444095BA641C233F4740
27613	Березовка	2	23	461	41.815939	41.853721999999998	46.343384	46.295757000000002	0103000020E61000000100000005000000F6436CB070E844401348895DDB254740F6436CB070E844401EFCC401F42B474017F032C346ED44401EFCC401F42B474017F032C346ED44401348895DDB254740F6436CB070E844401348895DDB254740
27517	Белозерный	2	23	461	41.326033000000002	41.345005999999998	46.843173	46.833655	0103000020E6100000010000000500000059350873BBA94440CD920035B56A474059350873BBA9444063EFC517ED6B47403E76172829AC444063EFC517ED6B47403E76172829AC4440CD920035B56A474059350873BBA94440CD920035B56A4740
27813	Бараники	2	23	461	41.904513000000001	41.935271	46.500802999999998	46.472552	0103000020E6100000010000000500000047E7FC14C7F3444067D47C957C3C474047E7FC14C7F344408D5E0D501A404740D8F2CAF5B6F744408D5E0D501A404740D8F2CAF5B6F7444067D47C957C3C474047E7FC14C7F3444067D47C957C3C4740
24069	Чистополье	2	23	1729	39.431494999999998	39.450018999999998	47.524583	47.517122999999998	0103000020E610000001000000050000009AB1683A3BB743403481221631C247409AB1683A3BB74340CF84268925C3474010CAFB389AB94340CF84268925C3474010CAFB389AB943403481221631C247409AB1683A3BB743403481221631C24740
54827	Родионово-Несветайская	2	23	1729	39.696570000000001	39.732844	47.624077	47.594067000000003	0103000020E61000000100000005000000F7AFAC3429D94340015130630ACC4740F7AFAC3429D94340C89750C1E1CF4740F0880AD5CDDD4340C89750C1E1CF4740F0880AD5CDDD4340015130630ACC4740F7AFAC3429D94340015130630ACC4740
23599	Плато-Ивановка	2	23	1729	39.406126999999998	39.432060999999997	47.695295999999999	47.677292000000001	0103000020E61000000100000005000000E48233F8FBB34340D5EB1681B1D64740E48233F8FBB3434012859675FFD8474043705CC64DB7434012859675FFD8474043705CC64DB74340D5EB1681B1D64740E48233F8FBB34340D5EB1681B1D64740
56814	Новопрохоровка	2	23	1729	39.530327999999997	39.539518000000001	47.828834000000001	47.821986000000003	0103000020E610000001000000050000009813B4C9E1C343408BE255D636E947409813B4C9E1C343400CE8853B17EA47403ACD02ED0EC543400CE8853B17EA47403ACD02ED0EC543408BE255D636E947409813B4C9E1C343408BE255D636E94740
24375	Кутейниково	2	23	1729	39.755895000000002	39.783042000000002	47.557873999999998	47.544713999999999	0103000020E61000000100000005000000DF1AD82AC1E0434030D63730B9C54740DF1AD82AC1E04340F4A44C6A68C747407DB262B83AE44340F4A44C6A68C747407DB262B83AE4434030D63730B9C54740DF1AD82AC1E0434030D63730B9C54740
24380	Каменный Брод	2	23	1729	39.837291	39.867421	47.442307	47.425826000000001	0103000020E61000000100000005000000191EFB592CEB4340ACE4637781B64740191EFB592CEB43405CE509849DB847408B6EBDA607EF43405CE509849DB847408B6EBDA607EF4340ACE4637781B64740191EFB592CEB4340ACE4637781B64740
56744	Дарьевка	2	23	1729	39.674821999999999	39.695231999999997	47.692433000000001	47.678317999999997	0103000020E61000000100000005000000874F3A9160D64340E124CD1FD3D64740874F3A9160D64340E9D500A5A1D84740FB90B75CFDD84340E9D500A5A1D84740FB90B75CFDD84340E124CD1FD3D64740874F3A9160D64340E124CD1FD3D64740
24115	Греково-Ульяновка	2	23	1729	39.241556000000003	39.258578999999997	47.628613000000001	47.618295000000003	0103000020E610000001000000050000008813984EEB9E4340E223624A24CF47408813984EEB9E4340946B0A6476D047405837DE1D19A14340946B0A6476D047405837DE1D19A14340E223624A24CF47408813984EEB9E4340E223624A24CF4740
56917	Гребцово	2	23	1729	39.816451000000001	39.833841999999997	47.533557000000002	47.520736999999997	0103000020E61000000100000005000000ACE4637781E8434098689082A7C24740ACE4637781E84340A4C684984BC44740FF03AC55BBEA4340A4C684984BC44740FF03AC55BBEA434098689082A7C24740ACE4637781E8434098689082A7C24740
24218	Генеральское	2	23	1729	39.574516000000003	39.611662000000003	47.475883000000003	47.465223000000002	0103000020E61000000100000005000000AE8383BD89C943406B2C616D8CBB4740AE8383BD89C9434077DCF0BBE9BC47405D1ABFF04ACE434077DCF0BBE9BC47405D1ABFF04ACE43406B2C616D8CBB4740AE8383BD89C943406B2C616D8CBB4740
56666	Выдел	2	23	1729	39.533175999999997	39.550423000000002	47.628825999999997	47.621094999999997	0103000020E610000001000000050000008C81751C3FC44340C45A7C0A80CF47408C81751C3FC44340EF6FD05E7DD04740ADFBC74274C64340EF6FD05E7DD04740ADFBC74274C64340C45A7C0A80CF47408C81751C3FC44340C45A7C0A80CF4740
56707	Волошино	2	23	1729	39.653675999999997	39.671956999999999	47.519252999999999	47.507506999999997	0103000020E610000001000000050000000D17B9A7ABD34340DBBE47FDF5C047400D17B9A7ABD34340C9ACDEE176C24740BDA8DDAF02D64340C9ACDEE176C24740BDA8DDAF02D64340DBBE47FDF5C047400D17B9A7ABD34340DBBE47FDF5C04740
56732	Веселый	2	23	1729	39.634182000000003	39.644863000000001	47.598557	47.590226000000001	0103000020E610000001000000050000001FDB32E02CD14340DC9F8B868CCB47401FDB32E02CD143405CE509849DCC474042B3EBDE8AD243405CE509849DCC474042B3EBDE8AD24340DC9F8B868CCB47401FDB32E02CD14340DC9F8B868CCB4740
56852	Бунако-Соколовец	2	23	1729	39.595914	39.620832999999998	47.808225999999998	47.799747000000004	0103000020E61000000100000005000000419DF2E846CC43407D09151C5EE64740419DF2E846CC434071E316F373E7474087A3AB7477CF434071E316F373E7474087A3AB7477CF43407D09151C5EE64740419DF2E846CC43407D09151C5EE64740
56635	Большекрепинская	2	23	1729	39.348491000000003	39.399372	47.622984000000002	47.585115000000002	0103000020E61000000100000005000000A5F9635A9BAC434014B35E0CE5CA4740A5F9635A9BAC434034F790F0BDCF47401478279F1EB3434034F790F0BDCF47401478279F1EB3434014B35E0CE5CA4740A5F9635A9BAC434014B35E0CE5CA4740
56725	Болдыревка	2	23	1729	39.715443999999998	39.738197999999997	47.725816999999999	47.713256999999999	0103000020E61000000100000005000000490F43AB93DB4340505260014CDB4740490F43AB93DB4340BFF04A92E7DC47407EFCA5457DDE4340BFF04A92E7DC47407EFCA5457DDE4340505260014CDB4740490F43AB93DB4340505260014CDB4740
56713	Барило-Крепинская	2	23	1729	39.515497000000003	39.551879	47.765405999999999	47.745136000000002	0103000020E61000000100000005000000D31742CEFBC143404089CF9D60DF4740D31742CEFBC14340C214E5D2F8E14740B22C98F8A3C64340C214E5D2F8E14740B22C98F8A3C643404089CF9D60DF4740D31742CEFBC143404089CF9D60DF4740
56936	Атамано-Власовка	2	23	1729	39.581667000000003	39.597765000000003	47.781162999999999	47.768597	0103000020E61000000100000005000000CB14731074CA4340E066F16261E24740CB14731074CA434031EC3026FDE34740C3D8429083CC434031EC3026FDE34740C3D8429083CC4340E066F16261E24740CB14731074CA4340E066F16261E24740
56766	Алексеево-Тузловка	2	23	1729	39.438879999999997	39.463501999999998	47.849397000000003	47.835287999999998	0103000020E610000001000000050000002A6F47382DB84340E15E99B7EAEA47402A6F47382DB843400729780AB9EC4740B7D0950854BB43400729780AB9EC4740B7D0950854BB4340E15E99B7EAEA47402A6F47382DB84340E15E99B7EAEA4740
56675	Аграфеновка	2	23	1729	39.469718999999998	39.508535000000002	47.740743999999999	47.719445999999998	0103000020E61000000100000005000000A8A78FC01FBC4340779E78CE16DC4740A8A78FC01FBC4340A75A0BB3D0DE474089EFC4AC17C14340A75A0BB3D0DE474089EFC4AC17C14340779E78CE16DC4740A8A78FC01FBC4340779E78CE16DC4740
56778	Авилов	2	23	1729	39.878200999999997	39.899346999999999	47.651634999999999	47.626184000000002	0103000020E610000001000000050000004128EFE368F04340A5A31CCC26D047404128EFE368F04340E8F692C668D34740BB6070CD1DF34340E8F692C668D34740BB6070CD1DF34340A5A31CCC26D047404128EFE368F04340A5A31CCC26D04740
8826	Тихий Лиман	2	23	989	43.401437999999999	43.414518000000001	46.313426	46.302463000000003	0103000020E6100000010000000500000092AF045262B3454002A08A1BB726474092AF045262B34540A9DBD9571E2847403ACD02ED0EB54540A9DBD9571E2847403ACD02ED0EB5454002A08A1BB726474092AF045262B3454002A08A1BB7264740
8379	Ремонтное	2	23	989	43.636420000000001	43.699041000000001	46.577334	46.544871000000001	0103000020E610000001000000050000009A42E73576D14540F8C43A55BE4547409A42E73576D14540376F9C14E649474015C8EC2C7AD94540376F9C14E649474015C8EC2C7AD94540F8C43A55BE4547409A42E73576D14540F8C43A55BE454740
8962	Раздольный	2	23	989	42.945624000000002	42.974235	46.645826	46.626055999999998	0103000020E6100000010000000500000007280D350A79454077BB5E9A2250474007280D350A7945400874266DAA5247402DCF83BBB37C45400874266DAA5247402DCF83BBB37C454077BB5E9A2250474007280D350A79454077BB5E9A22504740
9146	Привольный	2	23	989	43.389895000000003	43.421776000000001	46.659156000000003	46.649729000000001	0103000020E61000000100000005000000DDEF5014E8B14540A321E3512A534740DDEF5014E8B14540297B4B395F5447406D1E87C1FCB54540297B4B395F5447406D1E87C1FCB54540A321E3512A534740DDEF5014E8B14540A321E3512A534740
8866	Подгорное	2	23	989	43.111542999999998	43.148167000000001	46.544437000000002	46.522392000000004	0103000020E61000000100000005000000828C800A478E454095D8B5BDDD424740828C800A478E4540BEDD921CB045474058ACE122F7924540BEDD921CB045474058ACE122F792454095D8B5BDDD424740828C800A478E454095D8B5BDDD424740
8772	Первомайское	2	23	989	43.583796	43.635800000000003	46.370328000000001	46.349834999999999	0103000020E610000001000000050000008FC4CBD3B9CA454082FFAD64C72C47408FC4CBD3B9CA454084656CE8662F4740FE65F7E461D1454084656CE8662F4740FE65F7E461D1454082FFAD64C72C47408FC4CBD3B9CA454082FFAD64C72C4740
9222	Новопривольный	2	23	989	43.501716999999999	43.524445	46.608625000000004	46.595993999999997	0103000020E61000000100000005000000726C3D4338C045405D4E0988494C4740726C3D4338C0454096438B6CE74D47407EC6850321C3454096438B6CE74D47407EC6850321C345405D4E0988494C4740726C3D4338C045405D4E0988494C4740
9061	Краснопартизанский	2	23	989	43.131782000000001	43.162863999999999	46.347365000000003	46.330125000000002	0103000020E61000000100000005000000CA198A3BDE904540C74B3789412A4740CA198A3BDE9045403563D174762C47400ED940BAD89445403563D174762C47400ED940BAD8944540C74B3789412A4740CA198A3BDE904540C74B3789412A4740
8777	Кормовое	2	23	989	43.485278000000001	43.514294	46.277571999999999	46.258316000000001	0103000020E61000000100000005000000F1BBE9961DBE45404B04AA7F10214740F1BBE9961DBE45408524B37A87234740B743C362D4C145408524B37A87234740B743C362D4C145404B04AA7F10214740F1BBE9961DBE45404B04AA7F10214740
8953	Киевка	2	23	989	43.015495000000001	43.055075000000002	46.573852000000002	46.553584999999998	0103000020E6100000010000000500000032207BBDFB81454030478FDFDB46474032207BBDFB814540425F7AFB73494740E2E995B20C874540425F7AFB73494740E2E995B20C87454030478FDFDB46474032207BBDFB81454030478FDFDB464740
9108	Денисовский	2	23	989	43.364221000000001	43.387478000000002	46.463856	46.449514999999998	0103000020E610000001000000050000001AC231CB9EAE4540DD0720B5893947401AC231CB9EAE4540D50627A25F3B4740B2F50CE198B14540D50627A25F3B4740B2F50CE198B14540DD0720B5893947401AC231CB9EAE4540DD0720B589394740
8594	Вольный	2	23	989	43.599516999999999	43.613844999999998	46.708551999999997	46.692464999999999	0103000020E61000000100000005000000B1321AF9BCCC4540F44F70B1A2584740B1321AF9BCCC4540F8C1F9D4B15A474014E8137992CE4540F8C1F9D4B15A474014E8137992CE4540F44F70B1A2584740B1321AF9BCCC4540F44F70B1A2584740
8505	Валуевка	2	23	989	43.714672	43.755374000000003	46.729711999999999	46.695982000000001	0103000020E61000000100000005000000F7AE415F7ADB4540664D2CF015594740F7AE415F7ADB4540D7BFEB33675D4740D61F6118B0E04540D7BFEB33675D4740D61F6118B0E04540664D2CF015594740F7AE415F7ADB4540664D2CF015594740
8653	Большое Ремонтное	2	23	989	43.806345	43.857585	46.481153999999997	46.457605000000001	0103000020E6100000010000000500000085251E5036E7454038BEF6CC923A474085251E5036E74540772B4B74963D474024456458C5ED4540772B4B74963D474024456458C5ED454038BEF6CC923A474085251E5036E7454038BEF6CC923A4740
8702	Богородское	2	23	989	43.875641000000002	43.904989	46.352043000000002	46.335706000000002	0103000020E61000000100000005000000B404190115F045401689096AF82A4740B404190115F0454093E4B9BE0F2D4740B01EF7ADD6F3454093E4B9BE0F2D4740B01EF7ADD6F345401689096AF82A4740B404190115F045401689096AF82A4740
8052	Уютный	2	23	924	41.727266	41.747388000000001	46.663955000000001	46.645127000000002	0103000020E6100000010000000500000012BF620D17DD4440206283859352474012BF620D17DD44400282397AFC54474020B6F468AADF44400282397AFC54474020B6F468AADF4440206283859352474012BF620D17DD44402062838593524740
8041	Татнинов	2	23	924	41.616342000000003	41.634326000000001	47.132786000000003	47.119126000000001	0103000020E610000001000000050000005C936E4BE4CE4440390D51853F8F47405C936E4BE4CE4440EFAEB321FF9047405280289831D14440EFAEB321FF9047405280289831D14440390D51853F8F47405C936E4BE4CE4440390D51853F8F4740
7761	Сухой	2	23	924	41.346677	41.375594	47.111564999999999	47.093260999999998	0103000020E6100000010000000500000040A374E95FAC4440027FF8F9EF8B474040A374E95FAC44406A300DC3478E47407349D57613B044406A300DC3478E47407349D57613B04440027FF8F9EF8B474040A374E95FAC4440027FF8F9EF8B4740
7364	Пролетарск	2	23	924	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
8212	Привольный	2	23	924	41.604233000000001	41.631784000000003	46.810766000000001	46.792797	0103000020E61000000100000005000000FD14C78157CD4440F7AE415F7A654740FD14C78157CD4440B85A272EC76747406B11514CDED04440B85A272EC76747406B11514CDED04440F7AE415F7A654740FD14C78157CD4440F7AE415F7A654740
8265	Опенки	2	23	924	41.868606999999997	41.893194000000001	46.647762	46.632894	0103000020E61000000100000005000000D009A1832EEF4440D5EAABAB02514740D009A1832EEF4440B8CB7EDDE9524740E17D552E54F24440B8CB7EDDE9524740E17D552E54F24440D5EAABAB02514740D009A1832EEF4440D5EAABAB02514740
7755	Новомоисеевский	2	23	924	41.135069999999999	41.147826000000002	47.164971999999999	47.152326000000002	0103000020E61000000100000005000000DA5548F9499144404E2A1A6B7F934740DA5548F949914440BB6070CD1D954740CFBF5DF6EB924440BB6070CD1D954740CFBF5DF6EB9244404E2A1A6B7F934740DA5548F9499144404E2A1A6B7F934740
8269	Николаевский 2-й	2	23	924	42.188704000000001	42.213039000000002	46.637714000000003	46.611386000000003	0103000020E61000000100000005000000EC4FE27327184540BB9D7DE5414E4740EC4FE27327184540C619C39CA0514740E3E2A8DC441B4540C619C39CA0514740E3E2A8DC441B4540BB9D7DE5414E4740EC4FE27327184540BB9D7DE5414E4740
7903	Наумовский	2	23	924	41.428953	41.452364000000003	47.010302000000003	47.001213	0103000020E61000000100000005000000B34291EEE7B644403FAA61BF27804740B34291EEE7B64440AD8A709351814740A2F14410E7B94440AD8A709351814740A2F14410E7B944403FAA61BF27804740B34291EEE7B644403FAA61BF27804740
8106	Мокрая Ельмута	2	23	924	41.674706	41.696165999999998	46.850976000000003	46.840257000000001	0103000020E610000001000000050000001E3526C45CD64440179E978A8D6B47401E3526C45CD6444028D714C8EC6C4740274BADF71BD9444028D714C8EC6C4740274BADF71BD94440179E978A8D6B47401E3526C45CD64440179E978A8D6B4740
7908	Коврино	2	23	924	41.742896999999999	41.768687	47.015033000000003	47.006301000000001	0103000020E61000000100000005000000F4A5B73F17DF44404F779E78CE804740F4A5B73F17DF44402EAEF199EC81474020EEEA5564E244402EAEF199EC81474020EEEA5564E244404F779E78CE804740F4A5B73F17DF44404F779E78CE804740
7687	Дальний	2	23	924	41.14302	41.164355	47.057034000000002	47.047542999999997	0103000020E610000001000000050000004356B77A4E924440AD1397E3158647404356B77A4E9244404A61DEE34C87474090F7AA95099544404A61DEE34C87474090F7AA9509954440AD1397E3158647404356B77A4E924440AD1397E315864740
7961	Ганчуков	2	23	924	41.589123000000001	41.603127999999998	47.019683000000001	47.005982000000003	0103000020E610000001000000050000002429E96168CB4440AE2EA704C48047402429E96168CB4440C2A4F8F884824740A4A65D4C33CD4440C2A4F8F884824740A4A65D4C33CD4440AE2EA704C48047402429E96168CB4440AE2EA704C4804740
7813	Буденновская	2	23	924	41.542707	41.573932999999997	46.943057000000003	46.915523999999998	0103000020E61000000100000005000000B727486C77C54440FF59F3E32F754740B727486C77C54440C7A17E17B67847402E8CF4A276C94440C7A17E17B67847402E8CF4A276C94440FF59F3E32F754740B727486C77C54440FF59F3E32F754740
6555	Рассыпное	2	23	845	41.180309000000001	41.231898999999999	46.113425999999997	46.089767999999999	0103000020E610000001000000050000005516855D14974440191D90847D0B47405516855D149744400F4240BE840E4740D07CCEDDAE9D44400F4240BE840E4740D07CCEDDAE9D4440191D90847D0B47405516855D14974440191D90847D0B4740
7068	Развильное	2	23	845	41.237701999999999	41.336849000000001	46.252876000000001	46.221403000000002	0103000020E61000000100000005000000CE18E6046D9E44403F1EFAEE561C4740CE18E6046D9E4440BEF8A23D5E2047405C5837DE1DAB4440BEF8A23D5E2047405C5837DE1DAB44403F1EFAEE561C4740CE18E6046D9E44403F1EFAEE561C4740
6937	Поливянка	2	23	845	41.375557999999998	41.425944000000001	46.266527000000004	46.235405	0103000020E6100000010000000500000026E0D74812B044404E2844C0211E474026E0D74812B044402140868E1D224740B6F63E5585B644402140868E1D224740B6F63E5585B644404E2844C0211E474026E0D74812B044404E2844C0211E4740
6287	Песчанокопское	2	23	845	41.031574999999997	41.131098999999999	46.214188	46.164625999999998	0103000020E61000000100000005000000832F4CA60A8444402009FB7612154740832F4CA60A8444400B992B836A1B4740E7C41EDAC79044400B992B836A1B4740E7C41EDAC79044402009FB7612154740832F4CA60A8444402009FB7612154740
7024	Николаевка	2	23	845	41.439131000000003	41.496138000000002	46.291947	46.276445000000002	0103000020E6100000010000000500000074D4D17135B844404512BD8C6223474074D4D17135B844402995F0845E254740C426327381BF44402995F0845E254740C426327381BF44404512BD8C6223474074D4D17135B844404512BD8C62234740
6614	Летник	2	23	845	41.242598000000001	41.290128000000003	46.042608000000001	45.990430000000003	0103000020E610000001000000050000009A0986730D9F4440187D0569C6FE46409A0986730D9F44402446CF2D74054740B3D30FEA22A544402446CF2D74054740B3D30FEA22A54440187D0569C6FE46409A0986730D9F4440187D0569C6FE4640
6806	Красная Поляна	2	23	845	41.470194999999997	41.529905999999997	46.136868	46.086798999999999	0103000020E6100000010000000500000011DF89592FBC4440AA29C93A1C0B474011DF89592FBC444039EFFFE38411474022FAB5F5D3C3444039EFFFE38411474022FAB5F5D3C34440AA29C93A1C0B474011DF89592FBC4440AA29C93A1C0B4740
6752	Жуковское	2	23	845	41.322457999999997	41.384154000000002	46.104148000000002	46.060096000000001	0103000020E61000000100000005000000B22AC24D46A944406A4FC939B1074740B22AC24D46A94440CFF8BEB8540D4740555051F52BB14440CFF8BEB8540D4740555051F52BB144406A4FC939B1074740B22AC24D46A944406A4FC939B1074740
6885	Дальнее Поле	2	23	845	41.647432999999999	41.664760999999999	46.104004000000003	46.089548999999998	0103000020E61000000100000005000000F3ACA415DFD24440DB317557760B4740F3ACA415DFD244409C53C900500D4740005471E316D544409C53C900500D4740005471E316D54440DB317557760B4740F3ACA415DFD24440DB317557760B4740
7326	Богородицкое	2	23	845	41.143270999999999	41.205317999999998	46.338686000000003	46.318356000000001	0103000020E610000001000000050000008CBB41B456924440213EB0E3BF2847408CBB41B45692444079CE16105A2B4740DBA337DC479A444079CE16105A2B4740DBA337DC479A4440213EB0E3BF2847408CBB41B456924440213EB0E3BF284740
56919	Широкий	2	23	529	42.220880999999999	42.245558000000003	46.961461	46.933605999999997	0103000020E6100000010000000500000065A71FD4451C4540B8ACC2668077474065A71FD4451C454092B06F27117B4740B6A2CD716E1F454092B06F27117B4740B6A2CD716E1F4540B8ACC2668077474065A71FD4451C4540B8ACC26680774740
56933	Черкесский	2	23	529	42.423892000000002	42.446869999999997	46.743022000000003	46.723385999999998	0103000020E610000001000000050000009D84D217423645402F3196E9975C47409D84D21742364540B11A4B581B5F474021C8410933394540B11A4B581B5F474021C84109333945402F3196E9975C47409D84D217423645402F3196E9975C4740
56923	Успенский	2	23	529	41.895277999999998	41.917628000000001	47.057532000000002	47.045461000000003	0103000020E61000000100000005000000056A317898F244402A1F82AAD1854740056A317898F244409B3C65355D8747406BF294D574F544409B3C65355D8747406BF294D574F544402A1F82AAD1854740056A317898F244402A1F82AAD1854740
57005	Токмацкий	2	23	529	42.220657000000003	42.239916999999998	47.009914000000002	46.991200999999997	0103000020E610000001000000050000001651137D3E1C45409961A3ACDF7E47401651137D3E1C4540E3E2A8DC448147409160AA99B51E4540E3E2A8DC448147409160AA99B51E45409961A3ACDF7E47401651137D3E1C45409961A3ACDF7E4740
56838	Таловый	2	23	529	42.676264000000003	42.685957000000002	46.720433	46.712395000000001	0103000020E6100000010000000500000028BB99D18F564540BE6A65C22F5B474028BB99D18F564540C6FA0626375C47402CBB6070CD574540C6FA0626375C47402CBB6070CD574540BE6A65C22F5B474028BB99D18F564540BE6A65C22F5B4740
4531	Стрепетов	2	23	529	42.519562000000001	42.533675000000002	46.591392999999997	46.578443	0103000020E61000000100000005000000471FF30181424540D1CC936B0A4A4740471FF30181424540AA0A0DC4B24B4740AED85F764F444540AA0A0DC4B24B4740AED85F764F444540D1CC936B0A4A4740471FF30181424540D1CC936B0A4A4740
3209	Рунный	2	23	529	42.851903	42.863491000000003	46.487172999999999	46.479365999999999	0103000020E61000000100000005000000A12E52280B6D45403C6876DD5B3D4740A12E52280B6D4540423F53AF5B3E4740F7B182DF866E4540423F53AF5B3E4740F7B182DF866E45403C6876DD5B3D4740A12E52280B6D45403C6876DD5B3D4740
56871	Романовский	2	23	529	41.961492999999997	41.988881999999997	46.752667000000002	46.743485	0103000020E610000001000000050000009D2ADF3312FB4440850838842A5F47409D2ADF3312FB4440A4E36A645760474031CD74AF93FE4440A4E36A645760474031CD74AF93FE4440850838842A5F47409D2ADF3312FB4440850838842A5F4740
56670	Ребричанский	2	23	529	41.889645000000002	41.921455000000002	46.830374999999997	46.821323999999997	0103000020E6100000010000000500000064062AE3DFF14440BFB513252169474064062AE3DFF144403F355EBA496A47402BDEC83CF2F544403F355EBA496A47402BDEC83CF2F54440BFB513252169474064062AE3DFF14440BFB5132521694740
56984	Раздорский	2	23	529	42.195064000000002	42.218688999999998	47.041303999999997	47.025593000000001	0103000020E6100000010000000500000040506EDBF7184540D600A5A14683474040506EDBF7184540D4981073498547405A7F4B00FE1B4540D4981073498547405A7F4B00FE1B4540D600A5A14683474040506EDBF7184540D600A5A146834740
56771	Пролетарский	2	23	529	42.367998	42.391947000000002	46.674103000000002	46.657232999999998	0103000020E61000000100000005000000287FF78E1A2F45400D6D003620544740287FF78E1A2F45405891D10149564740F661BD512B3245405891D10149564740F661BD512B3245400D6D003620544740287FF78E1A2F45400D6D003620544740
56676	Островянский	2	23	529	42.196851000000002	42.231445000000001	46.769593999999998	46.747906	0103000020E61000000100000005000000AB97DF6932194540B83D4162BB5F4740AB97DF69321945405299620E826247404FE960FD9F1D45405299620E826247404FE960FD9F1D4540B83D4162BB5F4740AB97DF6932194540B83D4162BB5F4740
5805	Орловский	2	23	529	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
4759	Орден Ленина	2	23	529	42.045071999999998	42.071914	47.003566999999997	46.992811000000003	0103000020E610000001000000050000008FFB56EBC4054540F60D4C6E147F47408FFB56EBC4054540232C2AE274804740F10F5B7A34094540232C2AE274804740F10F5B7A34094540F60D4C6E147F47408FFB56EBC4054540F60D4C6E147F4740
56835	Нижнеантоновский	2	23	529	42.665241999999999	42.696575000000003	46.620410999999997	46.592044000000001	0103000020E610000001000000050000007BF65CA62655454082E50819C84B47407BF65CA626554540118AADA0694F4740091B9E5E29594540118AADA0694F4740091B9E5E2959454082E50819C84B47407BF65CA62655454082E50819C84B4740
4527	Маныч	2	23	529	42.702925999999998	42.7301	46.437983000000003	46.428468000000002	0103000020E6100000010000000500000009C1AA7AF9594540F7B0170AD836474009C1AA7AF95945401C9AB2D30F384740A167B3EA735D45401C9AB2D30F384740A167B3EA735D4540F7B0170AD836474009C1AA7AF9594540F7B0170AD8364740
56700	Майорский	2	23	529	42.001368999999997	42.018957999999998	47.066954000000003	47.052264000000001	0103000020E61000000100000005000000361D01DC2C0045400B613596B0864740361D01DC2C0045400F2BDCF291884740B0FF3A376D0245400F2BDCF291884740B0FF3A376D0245400B613596B0864740361D01DC2C0045400B613596B0864740
56723	Луганский	2	23	529	42.033842999999997	42.055007000000003	46.843640999999998	46.821162999999999	0103000020E610000001000000050000006919A9F754044540B6D782DE1B6947406919A9F7540445404948A46DFC6B47408A0629780A0745404948A46DFC6B47408A0629780A074540B6D782DE1B6947406919A9F754044540B6D782DE1B694740
56840	Курмоярский	2	23	529	42.168014999999997	42.185451999999998	46.838574000000001	46.828384	0103000020E61000000100000005000000641EF98381154540CC43A67C086A4740641EF9838115454051A39064566B4740287D21E4BC17454051A39064566B4740287D21E4BC174540CC43A67C086A4740641EF98381154540CC43A67C086A4740
56684	Курганный	2	23	529	42.783721	42.818261	46.577966000000004	46.557997	0103000020E610000001000000050000001E1840F850644540102219726C4747401E1840F850644540981936CAFA494740CF4BC5C6BC684540981936CAFA494740CF4BC5C6BC684540102219726C4747401E1840F850644540102219726C474740
56967	Кундрюченский	2	23	529	42.088155	42.123522000000001	46.778494000000002	46.760001000000003	0103000020E610000001000000050000004CFDBCA9480B4540B2F677B6476147404CFDBCA9480B4540ED10FFB0A5634740132BA391CF0F4540ED10FFB0A5634740132BA391CF0F4540B2F677B6476147404CFDBCA9480B4540B2F677B647614740
4972	Красноармейский	2	23	529	42.193652999999998	42.231284000000002	47.023860999999997	46.994624999999999	0103000020E61000000100000005000000DAE21A9FC91845405A643BDF4F7F4740DAE21A9FC91845402E5393E00D834740460BD0B69A1D45402E5393E00D834740460BD0B69A1D45405A643BDF4F7F4740DAE21A9FC91845405A643BDF4F7F4740
56624	Камышевка	2	23	529	42.614963000000003	42.651417000000002	46.664166000000002	46.645572000000001	0103000020E6100000010000000500000002A08A1BB74E45404E9B711AA252474002A08A1BB74E4540BD8E3864035547407B87DBA161534540BD8E3864035547407B87DBA1615345404E9B711AA252474002A08A1BB74E45404E9B711AA2524740
4755	Каменная Балка	2	23	529	41.990724	42.029082000000002	46.948483000000003	46.938245000000002	0103000020E6100000010000000500000060AE450BD0FE4440595183691878474060AE450BD0FE4440EFE714E4677947407E737FF5B8034540EFE714E4677947407E737FF5B8034540595183691878474060AE450BD0FE44405951836918784740
56745	Гундоровский	2	23	529	41.888872999999997	41.907629999999997	46.789223999999997	46.775765999999997	0103000020E6100000010000000500000011A62897C6F14440A3ACDF4C4C63474011A62897C6F14440F19BC24A056547402A6F47382DF44440F19BC24A056547402A6F47382DF44440A3ACDF4C4C63474011A62897C6F14440A3ACDF4C4C634740
56970	Греков	2	23	529	41.827365	41.842897000000001	46.941617000000001	46.932726000000002	0103000020E61000000100000005000000726DA818E7E944408010C99063774740726DA818E7E94440C72DE6E786784740C172840CE4EB4440C72DE6E786784740C172840CE4EB44408010C99063774740726DA818E7E944408010C99063774740
4418	Волочаевский	2	23	529	42.635562	42.664513999999997	46.552146999999998	46.534067	0103000020E61000000100000005000000494A7A185A514540B96FB54E5C444740494A7A185A514540D1CABDC0AC464740F8DD74CB0E554540D1CABDC0AC464740F8DD74CB0E554540B96FB54E5C444740494A7A185A514540B96FB54E5C444740
56797	Веселый	2	23	529	42.177142000000003	42.190860000000001	46.712376999999996	46.700344999999999	0103000020E61000000100000005000000C05FCC96AC1645406475ABE7A4594740C05FCC96AC16454017B6662B2F5B4740AA0EB9196E18454017B6662B2F5B4740AA0EB9196E1845406475ABE7A4594740C05FCC96AC1645406475ABE7A4594740
56982	Верхнетавричанский	2	23	529	42.278345999999999	42.290914000000001	46.942391999999998	46.934005999999997	0103000020E61000000100000005000000787C7BD7A0234540462234828D774740787C7BD7A02345408A01124DA07847406AF981AB3C2545408A01124DA07847406AF981AB3C254540462234828D774740787C7BD7A0234540462234828D774740
56816	Верхнезундов	2	23	529	42.242486	42.252924	46.805492000000001	46.783492000000003	0103000020E6100000010000000500000072DEFFC7091F4540BD5642774964474072DEFFC7091F45404698A25C1A674740CF2F4AD05F2045404698A25C1A674740CF2F4AD05F204540BD5642774964474072DEFFC7091F4540BD56427749644740
56833	Верхневодяной	2	23	529	42.883136999999998	42.905450999999999	46.618022000000003	46.605832999999997	0103000020E610000001000000050000009B711AA20A71454035EB8CEF8B4D47409B711AA20A714540B11A4B581B4F4740B49080D1E5734540B11A4B581B4F4740B49080D1E573454035EB8CEF8B4D47409B711AA20A71454035EB8CEF8B4D4740
56734	Быстрянский	2	23	529	42.019587000000001	42.040320000000001	46.839333000000003	46.818005999999997	0103000020E61000000100000005000000A036AAD38102454044F7AC6BB4684740A036AAD3810245400FBA84436F6B4740F7AFAC34290545400FBA84436F6B4740F7AFAC342905454044F7AC6BB4684740A036AAD38102454044F7AC6BB4684740
56908	Большевик	2	23	529	42.246608999999999	42.270226000000001	46.716856	46.695945000000002	0103000020E610000001000000050000001BF33AE2901F45404968CBB9145947401BF33AE2901F45407FF8F9EFC15B4740B343FCC3962245407FF8F9EFC15B4740B343FCC3962245404968CBB9145947401BF33AE2901F45404968CBB914594740
21138	Яново-Грушевский	2	23	898	40.035091999999999	40.053705000000001	47.495714999999997	47.485444000000001	0103000020E61000000100000005000000F52C08E57D0444400C056C0723BE4740F52C08E57D0444407D91D09673BF4740DB5031CEDF0644407D91D09673BF4740DB5031CEDF0644400C056C0723BE4740F52C08E57D0444400C056C0723BE4740
26890	Ягодинка	2	23	898	40.331615999999997	40.345953999999999	47.632584000000001	47.622978000000003	0103000020E61000000100000005000000486AA164722A444052103CBEBDCF4740486AA164722A444087FC3383F8D04740CFF57D38482C444087FC3383F8D04740CFF57D38482C444052103CBEBDCF4740486AA164722A444052103CBEBDCF4740
20220	Равнинный	2	23	898	40.595073999999997	40.609492000000003	47.856011000000002	47.847110999999998	0103000020E61000000100000005000000965984622B4C44407A8A1C226EEC4740965984622B4C44401502B9C491ED47403A9677D5034E44401502B9C491ED47403A9677D5034E44407A8A1C226EEC4740965984622B4C44407A8A1C226EEC4740
21703	Персиановский	2	23	898	40.096958000000001	40.136619000000003	47.538716000000001	47.50394	0103000020E61000000100000005000000F48AA71E690C4440B8921D1B81C04740F48AA71E690C44407DEA58A5F4C4474091813CBB7C1144407DEA58A5F4C4474091813CBB7C114440B8921D1B81C04740F48AA71E690C4440B8921D1B81C04740
6945	Новочеркасск	2	23	898	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
20846	Новосветловский	2	23	898	40.178310000000003	40.194282000000001	47.650117999999999	47.633896	0103000020E610000001000000050000005F46B1DCD216444059880E8123D147405F46B1DCD21644403D450E1137D34740CA198A3BDE1844403D450E1137D34740CA198A3BDE18444059880E8123D147405F46B1DCD216444059880E8123D14740
21083	Новоперсиановка	2	23	898	39.923718000000001	39.970125000000003	47.555332	47.531063000000003	0103000020E61000000100000005000000FF5C34643CF64340CE8E54DFF9C34740FF5C34643CF643400D36751E15C747401904560E2DFC43400D36751E15C747401904560E2DFC4340CE8E54DFF9C34740FF5C34643CF64340CE8E54DFF9C34740
20956	Новопавловка	2	23	898	39.962211000000003	39.980958999999999	47.774895000000001	47.761093000000002	0103000020E61000000100000005000000FD6CE4BA29FB4340761BD47E6BE14740FD6CE4BA29FB4340BE6A65C22FE34740C2DB831090FD4340BE6A65C22FE34740C2DB831090FD4340761BD47E6BE14740FD6CE4BA29FB4340761BD47E6BE14740
19983	Новокадамово	2	23	898	40.299430000000001	40.310155999999999	47.773902	47.763697999999998	0103000020E610000001000000050000007CB8E4B853264440A30227DBC0E147407CB8E4B8532644408D2782380FE347403F541A31B32744408D2782380FE347403F541A31B3274440A30227DBC0E147407CB8E4B853264440A30227DBC0E14740
21584	Новозарянский	2	23	898	40.420845999999997	40.436818000000002	47.674295000000001	47.662365999999999	0103000020E6100000010000000500000082531F48DE354440BDFDB968C8D4474082531F48DE3544409C6D6E4C4FD64740EE26F8A6E93744409C6D6E4C4FD64740EE26F8A6E9374440BDFDB968C8D4474082531F48DE354440BDFDB968C8D44740
21324	Нижнедонской	2	23	898	40.459626	40.472382000000003	47.593446999999998	47.578715000000003	0103000020E6100000010000000500000016325706D53A4440325A475513CA474016325706D53A444064744012F6CB47400B9C6C03773C444064744012F6CB47400B9C6C03773C4440325A475513CA474016325706D53A4440325A475513CA4740
21573	Мокрый Лог	2	23	898	40.536073000000002	40.558602999999998	47.663567	47.659731999999998	0103000020E6100000010000000500000062A2410A9E444440F50F221972D4474062A2410A9E44444038DA71C3EFD447404739984D8047444038DA71C3EFD447404739984D80474440F50F221972D4474062A2410A9E444440F50F221972D44740
21047	Марьевка	2	23	898	40.077689999999997	40.083969000000003	47.659744000000003	47.654232999999998	0103000020E61000000100000005000000F59CF4BEF1094440637B2DE8BDD34740F59CF4BEF1094440BADDCB7D72D447405D70067FBF0A4440BADDCB7D72D447405D70067FBF0A4440637B2DE8BDD34740F59CF4BEF1094440637B2DE8BDD34740
21668	Маркин	2	23	898	40.331895000000003	40.351191	47.693488000000002	47.679476000000001	0103000020E610000001000000050000005C5A0D897B2A44405D35CF11F9D647405C5A0D897B2A44409015FC36C4D8474024D3A1D3F32C44409015FC36C4D8474024D3A1D3F32C44405D35CF11F9D647405C5A0D897B2A44405D35CF11F9D64740
21414	Кривянская	2	23	898	40.137985	40.196230999999997	47.423399000000003	47.378168000000002	0103000020E61000000100000005000000562B137EA911444066321CCF67B04740562B137EA91144405E143DF031B647400EBBEF181E1944405E143DF031B647400EBBEF181E19444066321CCF67B04740562B137EA911444066321CCF67B04740
21211	Красюковская	2	23	898	40.067134000000003	40.117412999999999	47.558700999999999	47.506034	0103000020E610000001000000050000008F39CFD8970844400055DCB8C5C047408F39CFD8970844400A9FAD8383C747400890A163070F44400A9FAD8383C747400890A163070F44400055DCB8C5C047408F39CFD8970844400055DCB8C5C04740
56810	Красный Луч	2	23	898	40.336511999999999	40.361378000000002	47.668894999999999	47.654961	0103000020E61000000100000005000000145B41D3122B4440E69315C3D5D34740145B41D3122B44409DBAF2599ED5474038BF61A2412E44409DBAF2599ED5474038BF61A2412E4440E69315C3D5D34740145B41D3122B4440E69315C3D5D34740
54810	Красный Кут	2	23	898	40.023862999999999	40.046185999999999	47.695441000000002	47.680508000000003	0103000020E61000000100000005000000CF4A5AF10D0344404C55DAE21AD74740CF4A5AF10D03444016A6EF3504D947403BC43F6CE905444016A6EF3504D947403BC43F6CE90544404C55DAE21AD74740CF4A5AF10D0344404C55DAE21AD74740
20598	Красногорняцкий	2	23	898	40.192889999999998	40.206975	47.656478999999997	47.639080999999997	0103000020E61000000100000005000000DBDC989EB01844405B3FFD67CDD14740DBDC989EB018444061C1FD8007D44740780B24287E1A444061C1FD8007D44740780B24287E1A44405B3FFD67CDD14740DBDC989EB01844405B3FFD67CDD14740
20105	Костиков	2	23	898	40.292718999999998	40.309562999999997	47.690443999999999	47.681254000000003	0103000020E610000001000000050000007BF5F1D0772544407522C15433D747407BF5F1D07725444016DC0F7860D847409C86A8C29F27444016DC0F7860D847409C86A8C29F2744407522C15433D747407BF5F1D0772544407522C15433D74740
19895	Киреевка	2	23	898	40.383305	40.401468999999999	47.782851999999998	47.764012999999998	0103000020E6100000010000000500000057B2632310314440035C902DCBE1474057B2632310314440D9CD8C7E34E44740CDAD105663334440D9CD8C7E34E44740CDAD105663334440035C902DCBE1474057B2632310314440035C902DCBE14740
20455	Керчик-Савров	2	23	898	40.592227000000001	40.610075999999999	47.778807	47.758034000000002	0103000020E6100000010000000500000073672618CE4B4440C7A0134207E1474073672618CE4B4440AC72A1F2AFE3474089096AF8164E4440AC72A1F2AFE3474089096AF8164E4440C7A0134207E1474073672618CE4B4440C7A0134207E14740
22006	Каменоломни	2	23	898	40.182172999999999	40.218823999999998	47.679476000000001	47.642864000000003	0103000020E610000001000000050000006B9BE271511744404CE3175E49D247406B9BE271511744405D35CF11F9D647403ACAC16C021C44405D35CF11F9D647403ACAC16C021C44404CE3175E49D247406B9BE271511744404CE3175E49D24740
56618	Каменоломни	2	23	898	40.182172999999999	40.218823999999998	47.679476000000001	47.642864000000003	0103000020E610000001000000050000006B9BE271511744404CE3175E49D247406B9BE271511744405D35CF11F9D647403ACAC16C021C44405D35CF11F9D647403ACAC16C021C44404CE3175E49D247406B9BE271511744404CE3175E49D24740
26887	Калиновка	2	23	898	40.006704999999997	40.022011999999997	47.781005	47.766404999999999	0103000020E610000001000000050000001EDC9DB5DB004440D53E1D8F19E247401EDC9DB5DB0044409981CAF8F7E347404D0F0A4AD10244409981CAF8F7E347404D0F0A4AD1024440D53E1D8F19E247401EDC9DB5DB004440D53E1D8F19E24740
20415	Калинин	2	23	898	40.409841999999998	40.441633000000003	47.443885999999999	47.375946999999996	0103000020E610000001000000050000007C43E1B375344440C00303081FB047407C43E1B3753444407D93A641D1B84740CDEA1D6E873844407D93A641D1B84740CDEA1D6E87384440C00303081FB047407C43E1B375344440C00303081FB04740
21881	Казачьи Лагери	2	23	898	40.114026000000003	40.132657999999999	47.567991999999997	47.548515000000002	0103000020E6100000010000000500000065726A67980E4440C72E51BD35C6474065726A67980E4440DF313CF6B3C84740C1C6F5EFFA104440DF313CF6B3C84740C1C6F5EFFA104440C72E51BD35C6474065726A67980E4440C72E51BD35C64740
21870	Кадамовский	2	23	898	40.174007000000003	40.198144999999997	47.465997000000002	47.453867000000002	0103000020E61000000100000005000000362383DC45164440E8DD585018BA4740362383DC451644405E8429CAA5BB4740D66EBBD05C1944405E8429CAA5BB4740D66EBBD05C194440E8DD585018BA4740362383DC45164440E8DD585018BA4740
20987	Интернациональный	2	23	898	40.127896	40.142512000000004	47.702446000000002	47.694544	0103000020E6100000010000000500000005A568E55E10444007D15AD1E6D8474005A568E55E1044405F9A22C0E9D94740CFA44DD53D1244405F9A22C0E9D94740CFA44DD53D12444007D15AD1E6D8474005A568E55E10444007D15AD1E6D84740
19849	Ильичевка	2	23	898	39.873835	39.899042000000001	47.751147000000003	47.736181000000002	0103000020E61000000100000005000000D28C45D3D9EF4340E277D32D3BDE4740D28C45D3D9EF434088BEBB9525E047407FDDE9CE13F3434088BEBB9525E047407FDDE9CE13F34340E277D32D3BDE4740D28C45D3D9EF4340E277D32D3BDE4740
20236	Заплавская	2	23	898	40.294758999999999	40.333674000000002	47.416381999999999	47.397494999999999	0103000020E61000000100000005000000D099B4A9BA25444069A9BC1DE1B24740D099B4A9BA254440505260014CB5474044C362D4B52A4440505260014CB5474044C362D4B52A444069A9BC1DE1B24740D099B4A9BA25444069A9BC1DE1B24740
20688	Заозерье	2	23	898	40.328868	40.335659	47.594996999999999	47.583699000000003	0103000020E61000000100000005000000B859BC58182A44409DDA19A6B6CA4740B859BC58182A4440EB1B98DC28CC4740D5CDC5DFF62A4440EB1B98DC28CC4740D5CDC5DFF62A44409DDA19A6B6CA4740B859BC58182A44409DDA19A6B6CA4740
20588	Залужный	2	23	898	40.533073000000002	40.546942999999999	47.752425000000002	47.743355000000001	0103000020E61000000100000005000000B8B06EBC3B444440B728B34126DF4740B8B06EBC3B444440AED85F764FE0474058E36C3A02464440AED85F764FE0474058E36C3A02464440B728B34126DF4740B8B06EBC3B444440B728B34126DF4740
52150	Веселая Бахмутовка	2	23	898	40.463723000000002	40.471125000000001	47.740107000000002	47.725561999999996	0103000020E6100000010000000500000096B377465B3B4440349C3237DFDC474096B377465B3B4440354580D3BBDE4740FCA9F1D24D3C4440354580D3BBDE4740FCA9F1D24D3C4440349C3237DFDC474096B377465B3B4440349C3237DFDC4740
20110	Верхняя Кадамовка	2	23	898	40.439576000000002	40.460991999999997	47.843578999999998	47.839086000000002	0103000020E61000000100000005000000A20DC006443844400744882B67EB4740A20DC00644384440D34B8C65FAEB4740DBDB2DC9013B4440D34B8C65FAEB4740DBDB2DC9013B44400744882B67EB4740A20DC006443844400744882B67EB4740
20706	Верхнегрушевский	2	23	898	40.155852000000003	40.170062999999999	47.604286999999999	47.593592999999998	0103000020E61000000100000005000000138255F5F21344403811FDDAFACB4740138255F5F2134440F032C34659CD47403CA1D79FC4154440F032C34659CD47403CA1D79FC41544403811FDDAFACB4740138255F5F21344403811FDDAFACB4740
20340	Бессергеневская	2	23	898	40.326182000000003	40.354604000000002	47.407387999999997	47.394024000000002	0103000020E610000001000000050000009E45EF54C029444068EBE0606FB247409E45EF54C029444034643C4A25B44740F183F3A9632D444034643C4A25B44740F183F3A9632D444068EBE0606FB247409E45EF54C029444068EBE0606FB24740
21293	Аюта	2	23	898	40.034229000000003	40.042557000000002	47.638661999999997	47.630282999999999	0103000020E6100000010000000500000093C9A99D61044440C51C041DADD0474093C9A99D61044440569929ADBFD14740A29BFD8172054440569929ADBFD14740A29BFD8172054440C51C041DADD0474093C9A99D61044440C51C041DADD04740
19998	Атюхта	2	23	898	40.210011000000002	40.214880000000001	47.765073000000001	47.758222000000004	0103000020E610000001000000050000006F66F4A3E11A4440CA8D226B0DE147406F66F4A3E11A4440BC067DE9EDE1474041481630811B4440BC067DE9EDE1474041481630811B4440CA8D226B0DE147406F66F4A3E11A4440CA8D226B0DE14740
19806	Алексеевка	2	23	898	39.914205000000003	39.943534999999997	47.706296000000002	47.676904	0103000020E610000001000000050000007B6B60AB04F543400B444FCAA4D647407B6B60AB04F54340D7A546E867DA4740D0D03FC1C5F84340D7A546E867DA4740D0D03FC1C5F843400B444FCAA4D647407B6B60AB04F543400B444FCAA4D64740
28828	Шаповаловка	2	23	1758	42.516660999999999	42.642380000000003	48.897742000000001	48.852732000000003	0103000020E61000000100000005000000300F99F22142454058207A52266D4840300F99F221424540711FB935E972484060CD018239524540711FB935E972484060CD01823952454058207A52266D4840300F99F22142454058207A52266D4840
28610	Средний Чир	2	23	1758	42.434950000000001	42.479030000000002	48.554757000000002	48.540275000000001	0103000020E6100000010000000500000096B20C71AC37454057EC2FBB2745484096B20C71AC374540111D024702474840C5E6E3DA503D4540111D024702474840C5E6E3DA503D454057EC2FBB2745484096B20C71AC37454057EC2FBB27454840
29333	Сосновый	2	23	1758	42.182011000000003	42.194254999999998	48.666032999999999	48.655154000000003	0103000020E610000001000000050000009241EE224C174540FBEB1516DC5348409241EE224C1745404487C09140554840D00A0C59DD1845404487C09140554840D00A0C59DD184540FBEB1516DC5348409241EE224C174540FBEB1516DC534840
28929	Солонецкий	2	23	1758	42.269812000000002	42.295028000000002	48.551352000000001	48.522973	0103000020E61000000100000005000000C0081A338922454073D87DC7F0424840C0081A3389224540C74ACCB392464840C0B33D7AC3254540C74ACCB392464840C0B33D7AC325454073D87DC7F0424840C0081A338922454073D87DC7F0424840
28960	Сиволобов	2	23	1758	42.145296999999999	42.191982000000003	48.484475000000003	48.466341999999997	0103000020E610000001000000050000007C9A93179912454028603B18B13B48407C9A931799124540645DDC46033E4840D9B5BDDD92184540645DDC46033E4840D9B5BDDD9218454028603B18B13B48407C9A93179912454028603B18B13B4840
28868	Пухов	2	23	1758	42.430242999999997	42.446781000000001	48.895805000000003	48.880474	0103000020E610000001000000050000009D2ADF3312374540397D3D5FB37048409D2ADF3312374540F14BFDBCA9724840B2BCAB1E30394540F14BFDBCA9724840B2BCAB1E30394540397D3D5FB37048409D2ADF3312374540397D3D5FB3704840
28310	Обливская	2	23	1758	42.466749999999998	42.529012000000002	48.550314	48.526094000000001	0103000020E6100000010000000500000039B4C876BE3B4540984F560C5743484039B4C876BE3B4540F6436CB07046484085984BAAB6434540F6436CB07046484085984BAAB6434540984F560C5743484039B4C876BE3B4540984F560C57434840
29012	Новополеевский	2	23	1758	42.108429999999998	42.128768000000001	48.560225000000003	48.549824999999998	0103000020E61000000100000005000000E0F3C308E10D4540F8C264AA60464840E0F3C308E10D454068B3EA73B5474840BB6246787B10454068B3EA73B5474840BB6246787B104540F8C264AA60464840E0F3C308E10D4540F8C264AA60464840
28707	Нестеркин	2	23	1758	42.491041000000003	42.514352000000002	48.684201999999999	48.651933999999997	0103000020E6100000010000000500000061FF756EDA3E45404293C4927253484061FF756EDA3E4540CCED5EEE93574840EC504D49D6414540CCED5EEE93574840EC504D49D64145404293C4927253484061FF756EDA3E45404293C49272534840
29174	Машинский	2	23	1758	42.228130999999998	42.252718000000002	48.741146999999998	48.730373999999998	0103000020E61000000100000005000000151A8865331D4540A2EC2DE57C5D4840151A8865331D4540A643A7E7DD5E4840268E3C1059204540A643A7E7DD5E4840268E3C1059204540A2EC2DE57C5D4840151A8865331D4540A2EC2DE57C5D4840
28605	Лобачев	2	23	1758	42.371592	42.405009	48.543633999999997	48.531894000000001	0103000020E6100000010000000500000045BA9F53902F45402578431A1544484045BA9F53902F4540307F85CC95454840F7CABC55D7334540307F85CC95454840F7CABC55D73345402578431A1544484045BA9F53902F45402578431A15444840
29079	Леонов	2	23	1758	42.019047999999998	42.099590999999997	48.715456000000003	48.701597	0103000020E61000000100000005000000F086342A7002454061FC34EECD594840F086342A700245400EDDEC0F945B4840EBFCDB65BF0C45400EDDEC0F945B4840EBFCDB65BF0C454061FC34EECD594840F086342A7002454061FC34EECD594840
24901	Кривов	2	23	1758	42.622545000000002	42.653618000000002	48.760952000000003	48.742674000000001	0103000020E61000000100000005000000E8A4F78DAF4F454075CB0EF10F5F4840E8A4F78DAF4F4540B4E908E066614840D9092FC1A9534540B4E908E066614840D9092FC1A953454075CB0EF10F5F4840E8A4F78DAF4F454075CB0EF10F5F4840
28549	Ковыленский	2	23	1758	42.574764000000002	42.602656000000003	48.570981000000003	48.551065000000001	0103000020E610000001000000050000008675E3DD91494540317C444C894648408675E3DD9149454096D1C8E7154948407D5EF1D4234D454096D1C8E7154948407D5EF1D4234D4540317C444C894648408675E3DD91494540317C444C89464840
29281	Киреев	2	23	1758	42.245880999999997	42.291398999999998	48.630406999999998	48.617252000000001	0103000020E6100000010000000500000098DA5207791F4540FFB1101D024F484098DA5207791F4540B115342DB1504840268BFB8F4C254540B115342DB1504840268BFB8F4C254540FFB1101D024F484098DA5207791F4540FFB1101D024F4840
28784	Каштановский	2	23	1758	42.509796999999999	42.534052000000003	48.757317	48.745662000000003	0103000020E61000000100000005000000A94C3107414145405BEF37DA715F4840A94C31074141454038DA71C3EF604840842EE1D05B44454038DA71C3EF604840842EE1D05B4445405BEF37DA715F4840A94C3107414145405BEF37DA715F4840
29229	Караичев	2	23	1758	42.194021999999997	42.225867000000001	48.637725000000003	48.608144000000003	0103000020E610000001000000050000002D5A80B6D51845401BA19FA9D74D48402D5A80B6D5184540BA6B09F9A0514840711FB935E91C4540BA6B09F9A0514840711FB935E91C45401BA19FA9D74D48402D5A80B6D51845401BA19FA9D74D4840
28674	Дубовой	2	23	1758	42.683163	42.698523999999999	48.631704999999997	48.621856000000001	0103000020E610000001000000050000002B6B9BE271574540236937FA984F48402B6B9BE2715745401EDC9DB5DB5048404DBC033C695945401EDC9DB5DB5048404DBC033C69594540236937FA984F48402B6B9BE271574540236937FA984F4840
29145	Алексеевский	2	23	1758	42.329137000000003	42.360111000000003	48.768577000000001	48.748918000000003	0103000020E61000000100000005000000A8734529212A454060B1868BDC5F4840A8734529212A454099BA2BBB6062484006F7031E182E454099BA2BBB6062484006F7031E182E454060B1868BDC5F4840A8734529212A454060B1868BDC5F4840
29067	Александровский	2	23	1758	42.093885999999998	42.122632000000003	48.786102999999997	48.764752000000001	0103000020E61000000100000005000000B0C6D974040C45407AC6BE64E3614840B0C6D974040C4540CC24EA059F644840B7B8C667B20F4540CC24EA059F644840B7B8C667B20F45407AC6BE64E3614840B0C6D974040C45407AC6BE64E3614840
2233	Щербаково	2	23	73	38.404603999999999	38.41789	47.284703	47.269266000000002	0103000020E6100000010000000500000057EA5910CA3343405EF6EB4E77A2474057EA5910CA3343405B09DD2571A44740A8A9656B7D3543405B09DD2571A44740A8A9656B7D3543405EF6EB4E77A2474057EA5910CA3343405EF6EB4E77A24740
56863	Чекилев	2	23	73	38.396572999999997	38.403706	47.364834000000002	47.354304999999997	0103000020E6100000010000000500000001BD70E7C232434096E7C1DD59AD474001BD70E7C2324340043C69E1B2AE4740789961A3AC334340043C69E1B2AE4740789961A3AC33434096E7C1DD59AD474001BD70E7C232434096E7C1DD59AD4740
89	Христофоровка	2	23	73	38.707256000000001	38.721888999999997	47.162951	47.156492999999998	0103000020E610000001000000050000002CF3565D875A4340C6866EF6079447402CF3565D875A4340DDEC0F94DB944740CB2BD7DB665C4340DDEC0F94DB944740CB2BD7DB665C4340C6866EF6079447402CF3565D875A4340C6866EF607944740
31740	Халыбо-Адабашев	2	23	73	39.203251999999999	39.216053000000002	47.332604000000003	47.325068000000002	0103000020E610000001000000050000005D6C5A29049A4340F27C06D49BA947405D6C5A29049A4340684293C492AA4740F299EC9FA79B4340684293C492AA4740F299EC9FA79B4340F27C06D49BA947405D6C5A29049A4340F27C06D49BA94740
882	Федоровка	2	23	73	38.372399999999999	38.398325	47.343204999999998	47.329276	0103000020E61000000100000005000000E4839ECDAA2F4340C9AD49B725AA4740E4839ECDAA2F43406E693524EEAB4740F0164850FC3243406E693524EEAB4740F0164850FC324340C9AD49B725AA4740E4839ECDAA2F4340C9AD49B725AA4740
31102	Троицкое	2	23	73	38.879641999999997	38.917596000000003	47.382542999999998	47.342435999999999	0103000020E610000001000000050000001118EB1B987043408D7C5EF1D4AB47401118EB1B987043402828452BF7B04740607825C9737543402828452BF7B04740607825C9737543408D7C5EF1D4AB47401118EB1B987043408D7C5EF1D4AB4740
1347	Таврический	2	23	73	38.574295999999997	38.601802999999997	47.296382999999999	47.284543999999997	0103000020E610000001000000050000009F1C058882494340F22213F06BA447409F1C058882494340910BCEE0EFA547403DD175E1074D4340910BCEE0EFA547403DD175E1074D4340F22213F06BA447409F1C058882494340F22213F06BA44740
30883	Сухосарматка	2	23	73	38.782812999999997	38.804479999999998	47.323138	47.314103000000003	0103000020E610000001000000050000001BF1643733644340AA49F08634A847401BF1643733644340240C03965CA947409E245D33F9664340240C03965CA947409E245D33F9664340AA49F08634A847401BF1643733644340AA49F08634A84740
31818	Советка	2	23	73	39.245094999999999	39.269196999999998	47.510294000000002	47.496786999999998	0103000020E61000000100000005000000E1B4E0455F9F4340FA0967B796BF4740E1B4E0455F9F43402AAC545051C1474035971B0C75A243402AAC545051C1474035971B0C75A24340FA0967B796BF4740E1B4E0455F9F4340FA0967B796BF4740
31651	Синявское	2	23	73	39.251562999999997	39.317005000000002	47.284153000000003	47.271552999999997	0103000020E610000001000000050000001BF1643733A04340BA10AB3FC2A247401BF1643733A04340B80721205FA4474091D5AD9E93A84340B80721205FA4474091D5AD9E93A84340BA10AB3FC2A247401BF1643733A04340BA10AB3FC2A24740
31238	Самбек	2	23	73	39.011586999999999	39.040134999999999	47.345874000000002	47.313442999999999	0103000020E610000001000000050000008507CDAE7B8143407F1475E61EA847408507CDAE7B814340B344679945AC47406536C82423854340B344679945AC47406536C824238543407F1475E61EA847408507CDAE7B8143407F1475E61EA84740
256	Русский Колодец	2	23	73	38.666741999999999	38.678652999999997	47.193416999999997	47.182326000000003	0103000020E61000000100000005000000506F46CD57554340F29A577556974740506F46CD57554340C6BE64E3C1984740882AFC19DE564340C6BE64E3C1984740882AFC19DE564340F29A577556974740506F46CD57554340F29A577556974740
1807	Рожок	2	23	73	38.409464	38.427377	47.148833000000003	47.138725999999998	0103000020E61000000100000005000000D671FC50693443406D8D08C6C1914740D671FC506934434065C8B1F50C93474003081F4AB436434065C8B1F50C93474003081F4AB43643406D8D08C6C1914740D671FC50693443406D8D08C6C1914740
30657	Родионовка	2	23	73	38.653931999999998	38.670596000000003	47.383823999999997	47.373775000000002	0103000020E6100000010000000500000068E7340BB4534340FD87F4DBD7AF474068E7340BB4534340BFB5132521B147400A6AF816D6554340BFB5132521B147400A6AF816D6554340FD87F4DBD7AF474068E7340BB4534340FD87F4DBD7AF4740
2276	Пудовой	2	23	73	38.359535999999999	38.372804000000002	47.204253999999999	47.197432999999997	0103000020E6100000010000000500000009DE9046052E434059130B7C4599474009DE9046052E4340E109BDFE249A4740B4E89D0AB82F4340E109BDFE249A4740B4E89D0AB82F434059130B7C4599474009DE9046052E434059130B7C45994740
32094	Приют	2	23	73	39.158641000000003	39.178843999999998	47.410826999999998	47.400342999999999	0103000020E61000000100000005000000026729594E9443405D177E703EB34740026729594E9443402AA8A8FA95B44740FC8A355CE49643402AA8A8FA95B44740FC8A355CE49643405D177E703EB34740026729594E9443405D177E703EB34740
31469	Приморка	2	23	73	39.032544999999999	39.078313999999999	47.291158000000003	47.263646999999999	0103000020E61000000100000005000000FC523F6F2A8443402158552FBFA14740FC523F6F2A84434001FC53AA44A54740D3687231068A434001FC53AA44A54740D3687231068A43402158552FBFA14740FC523F6F2A8443402158552FBFA14740
1867	Приазовский	2	23	73	38.370944000000001	38.386144000000002	47.147587999999999	47.139308	0103000020E61000000100000005000000DF52CE177B2F43401C0934D8D4914740DF52CE177B2F43401AA4E029E4924740F8C5A52A6D3143401AA4E029E4924740F8C5A52A6D3143401C0934D8D4914740DF52CE177B2F43401C0934D8D4914740
30229	Покровское	2	23	73	38.891948999999997	38.928628000000003	47.437944000000002	47.388375000000003	0103000020E61000000100000005000000965984622B724340C1CAA145B6B14740965984622B7243405EBD8A8C0EB8474030134548DD7643405EBD8A8C0EB8474030134548DD764340C1CAA145B6B14740965984622B724340C1CAA145B6B14740
32126	Петрушино	2	23	73	38.862251000000001	38.875473999999997	47.190176999999998	47.176293000000001	0103000020E61000000100000005000000BEF8A23D5E6E4340C2C1DEC490964740BEF8A23D5E6E4340C7B94DB857984740C83F33880F704340C7B94DB857984740C83F33880F704340C2C1DEC490964740BEF8A23D5E6E4340C2C1DEC490964740
949	Петровский	2	23	73	38.308034999999997	38.324511000000001	47.333013999999999	47.329892999999998	0103000020E61000000100000005000000FD82DDB06D274340F4160FEF39AA4740FD82DDB06D274340198EE733A0AA47409C18929389294340198EE733A0AA47409C18929389294340F4160FEF39AA4740FD82DDB06D274340F4160FEF39AA4740
30585	Отрадное	2	23	73	38.735399999999998	38.758792	47.404935999999999	47.388582999999997	0103000020E610000001000000050000003CBD5296215E43400A647616BDB147403CBD5296215E43408D7C5EF1D4B34740B43BA418206143408D7C5EF1D4B34740B43BA418206143400A647616BDB147403CBD5296215E43400A647616BDB14740
1241	Носово	2	23	73	38.663812999999998	38.682794999999999	47.282966999999999	47.266154	0103000020E610000001000000050000006FD40AD3F75443408CD9925511A247406FD40AD3F7544340726C3D4338A44740A86F99D365574340726C3D4338A44740A86F99D3655743408CD9925511A247406FD40AD3F75443408CD9925511A24740
56830	Новофедоровский	2	23	73	38.340806000000001	38.353076999999999	47.369588	47.365786	0103000020E61000000100000005000000EA23F0879F2B4340D6AA5D13D2AE4740EA23F0879F2B43403D7FDAA84EAF474022FC8BA0312D43403D7FDAA84EAF474022FC8BA0312D4340D6AA5D13D2AE4740EA23F0879F2B4340D6AA5D13D2AE4740
31976	Новостроенка	2	23	73	39.211139000000003	39.225960999999998	47.449925	47.442374999999998	0103000020E6100000010000000500000080F44D9A069B4340B4C876BE9FB8474080F44D9A069B43408F53742497B94740F295404AEC9C43408F53742497B94740F295404AEC9C4340B4C876BE9FB8474080F44D9A069B4340B4C876BE9FB84740
31511	Новоприморский	2	23	73	39.067326999999999	39.079256999999998	47.305787000000002	47.299506000000001	0103000020E61000000100000005000000A391CF2B9E884340577A6D3656A64740A391CF2B9E8843405F45460724A74740527DE717258A43405F45460724A74740527DE717258A4340577A6D3656A64740A391CF2B9E884340577A6D3656A64740
760	Новозолотовка	2	23	73	38.805306999999999	38.815196999999998	47.183208	47.174742999999999	0103000020E61000000100000005000000B41EBE4C146743403B1A87FA5D964740B41EBE4C14674340CB2E185C739747400E66136058684340CB2E185C739747400E661360586843403B1A87FA5D964740B41EBE4C146743403B1A87FA5D964740
32236	Новобессергеневка	2	23	73	38.835445	38.864792999999999	47.192559000000003	47.174804999999999	0103000020E61000000100000005000000A94D9CDCEF6A4340B1169F0260964740A94D9CDCEF6A434076C6F7C5A5984740A5677A89B16E434076C6F7C5A5984740A5677A89B16E4340B1169F0260964740A94D9CDCEF6A4340B1169F0260964740
32395	Никольское	2	23	73	38.720910000000003	38.744042	47.242784	47.236066000000001	0103000020E6100000010000000500000000AE64C7465C434049D92269379E474000AE64C7465C4340FCFECD8B139F4740DB6CACC43C5F4340FCFECD8B139F4740DB6CACC43C5F434049D92269379E474000AE64C7465C434049D92269379E4740
1539	Николаево-Отрадное	2	23	73	38.521070999999999	38.536952999999997	47.218882999999998	47.209524999999999	0103000020E610000001000000050000006FF25B74B2424340E25817B7D19A47406FF25B74B24243403F53AF5B049C47409A3E3BE0BA4443403F53AF5B049C47409A3E3BE0BA444340E25817B7D19A47406FF25B74B2424340E25817B7D19A4740
2176	Николаево-Козловский	2	23	73	38.350256000000002	38.374231999999999	47.225853999999998	47.214402999999997	0103000020E61000000100000005000000289D4830D52C43400795B88E719B4740289D4830D52C4340DCD5ABC8E89C4740EF8E8CD5E62F4340DCD5ABC8E89C4740EF8E8CD5E62F43400795B88E719B4740289D4830D52C43400795B88E719B4740
2119	Николаево-Иловайский	2	23	73	38.401173	38.416139000000001	47.254094000000002	47.239786000000002	0103000020E61000000100000005000000E48409A359334340F304C24EB19E4740E48409A3593343400F0EF62686A047408ACBF10A443543400F0EF62686A047408ACBF10A44354340F304C24EB19E4740E48409A359334340F304C24EB19E4740
883	Николаевка	2	23	73	38.819409999999998	38.865116999999998	47.324933000000001	47.277262999999998	0103000020E61000000100000005000000F701486DE268434007B29E5A7DA34740F701486DE26843401232906797A94740581B6327BC6E43401232906797A94740581B6327BC6E434007B29E5A7DA34740F701486DE268434007B29E5A7DA34740
31795	Некрасовка	2	23	73	39.104221000000003	39.122556000000003	47.372194	47.362153999999997	0103000020E6100000010000000500000039471D1D578D4340CB0EF10F5BAE474039471D1D578D43403BE2900DA4AF4740DCF63DEAAF8F43403BE2900DA4AF4740DCF63DEAAF8F4340CB0EF10F5BAE474039471D1D578D4340CB0EF10F5BAE4740
1412	Натальевка	2	23	73	38.457873999999997	38.491022000000001	47.183508000000003	47.157815999999997	0103000020E6100000010000000500000027D87F9D9B3A43408C648F503394474027D87F9D9B3A4340F646AD307D974740EACE13CFD93E4340F646AD307D974740EACE13CFD93E43408C648F503394474027D87F9D9B3A43408C648F5033944740
31570	Морской Чулек	2	23	73	39.193908999999998	39.223077000000004	47.289195999999997	47.279232	0103000020E6100000010000000500000035B39602D298434093FFC9DFBDA3474035B39602D29843402711E15F04A54740B2BE81C98D9C43402711E15F04A54740B2BE81C98D9C434093FFC9DFBDA3474035B39602D298434093FFC9DFBDA34740
1188	Михайловка	2	23	73	38.472571000000002	38.485992000000003	47.376966000000003	47.367483	0103000020E61000000100000005000000DE04DF347D3C4340016BD5AE09AF4740DE04DF347D3C43401BDA006C40B047400F0F61FC343E43401BDA006C40B047400F0F61FC343E4340016BD5AE09AF4740DE04DF347D3C4340016BD5AE09AF4740
31567	Мержаново	2	23	73	39.131261000000002	39.154428000000003	47.292825999999998	47.285967999999997	0103000020E61000000100000005000000C11E1329CD904340ECD973999AA44740C11E1329CD90434091B586527BA5474019CBF44BC493434091B586527BA5474019CBF44BC4934340ECD973999AA44740C11E1329CD904340ECD973999AA44740
30691	Марьевка	2	23	73	38.620631000000003	38.632803000000003	47.356313	47.341813000000002	0103000020E6100000010000000500000020F12BD6704F4340802C4487C0AB474020F12BD6704F4340E01115AA9BAD4740C5E74EB0FF504340E01115AA9BAD4740C5E74EB0FF504340802C4487C0AB474020F12BD6704F4340802C4487C0AB4740
454	Малофедоровка	2	23	73	38.586855	38.613813	47.236224999999997	47.221997999999999	0103000020E610000001000000050000003E3F8C101E4B434082E3326E6A9C47403E3F8C101E4B4340B1BFEC9E3C9E4740096EA46C914E4340B1BFEC9E3C9E4740096EA46C914E434082E3326E6A9C47403E3F8C101E4B434082E3326E6A9C4740
1690	Максимов	2	23	73	38.238587000000003	38.268068999999997	47.170442999999999	47.162877000000002	0103000020E610000001000000050000001920D1048A1E4340A3224E27D99447401920D1048A1E4340836A8313D19547402409C21550224340836A8313D19547402409C21550224340A3224E27D99447401920D1048A1E4340A3224E27D9944740
32019	Любовка	2	23	73	39.160366000000003	39.167957000000001	47.475968000000002	47.468086	0103000020E61000000100000005000000F7B182DF8694434094DBF63DEABB4740F7B182DF86944340A5F8F884ECBC474030116F9D7F954340A5F8F884ECBC474030116F9D7F95434094DBF63DEABB4740F7B182DF8694434094DBF63DEABB4740
56960	Ломакин	2	23	73	38.510156000000002	38.520155000000003	47.203536999999997	47.194158000000002	0103000020E61000000100000005000000D9EDB3CA4C414340DE205A2BDA984740D9EDB3CA4C41434052431B800D9A4740EAEC64709442434052431B800D9A4740EAEC647094424340DE205A2BDA984740D9EDB3CA4C414340DE205A2BDA984740
637	Лакедемоновка	2	23	73	38.529093000000003	38.561720000000001	47.205306999999998	47.190465000000003	0103000020E6100000010000000500000072C5C551B94343402E0439286198474072C5C551B9434340E751F17F479A47402BC1E270E6474340E751F17F479A47402BC1E270E64743402E0439286198474072C5C551B94343402E04392861984740
31177	Курлацкий	2	23	73	39.051929999999999	39.083542000000001	47.365834999999997	47.349293000000003	0103000020E6100000010000000500000034D769A4A586434062DC0DA2B5AC474034D769A4A5864340B75D68AED3AE4740D5EB1681B18A4340B75D68AED3AE4740D5EB1681B18A434062DC0DA2B5AC474034D769A4A586434062DC0DA2B5AC4740
56697	Красный Десант	2	23	73	38.724144000000003	38.748578000000002	47.173028000000002	47.159163999999997	0103000020E610000001000000050000001DCC26C0B05C4340AB59677C5F9447401DCC26C0B05C43406AA510C825964740A7406667D15F43406AA510C825964740A7406667D15F4340AB59677C5F9447401DCC26C0B05C4340AB59677C5F944740
32035	Копани	2	23	73	39.046306999999999	39.057751000000003	47.456457	47.450626	0103000020E61000000100000005000000B6494563ED854340185DDE1CAEB94740B6494563ED854340E083D72E6DBA4740D927806264874340E083D72E6DBA4740D927806264874340185DDE1CAEB94740B6494563ED854340185DDE1CAEB94740
114	Ключникова Балка	2	23	73	38.666930000000001	38.69238	47.159984999999999	47.149873999999997	0103000020E61000000100000005000000535C55F65D554340A6423C122F934740535C55F65D554340DF6C73637A944740C63368E89F584340DF6C73637A944740C63368E89F584340A6423C122F934740535C55F65D554340A6423C122F934740
1311	Ивановка	2	23	73	38.583998000000001	38.608648000000002	47.253824999999999	47.242576	0103000020E61000000100000005000000F7764B72C04A4340B265F9BA0C9F4740F7764B72C04A43401FF46C567DA047404E637B2DE84D43401FF46C567DA047404E637B2DE84D4340B265F9BA0C9F4740F7764B72C04A4340B265F9BA0C9F4740
196	Золотая Коса	2	23	73	38.628348000000003	38.650751999999997	47.148654999999998	47.141043000000003	0103000020E61000000100000005000000E6400FB56D504340352A70B20D924740E6400FB56D50434085B18520079347403EE76ED74B53434085B18520079347403EE76ED74B534340352A70B20D924740E6400FB56D504340352A70B20D924740
30540	Жатва	2	23	73	38.781995999999999	38.788058999999997	47.440784000000001	47.434036999999996	0103000020E6100000010000000500000029CDE67118644340812040868EB7474029CDE67118644340CF4C309C6BB84740C328081EDF644340CF4C309C6BB84740C328081EDF644340812040868EB7474029CDE67118644340812040868EB74740
1117	Ефремовка	2	23	73	38.461827	38.485965	47.327047	47.309246000000002	0103000020E6100000010000000500000074B4AA251D3B43409C35785F95A7474074B4AA251D3B4340A1A014ADDCA947401500E319343E4340A1A014ADDCA947401500E319343E43409C35785F95A7474074B4AA251D3B43409C35785F95A74740
32247	Дмитриадовка	2	23	73	38.813831999999998	38.827081999999997	47.184353000000002	47.176696999999997	0103000020E610000001000000050000001938A0A52B6843409126DE019E9647401938A0A52B684340B2F50CE1989747401D8EAED2DD694340B2F50CE1989747401D8EAED2DD6943409126DE019E9647401938A0A52B6843409126DE019E964740
32336	Дарагановка	2	23	73	38.789648999999997	38.801901999999998	47.242258	47.238452000000002	0103000020E61000000100000005000000D828EB371365434039D55A98859E4740D828EB3713654340E198654F029F47406A4C88B9A4664340E198654F029F47406A4C88B9A466434039D55A98859E4740D828EB371365434039D55A98859E4740
31898	Горская Порада	2	23	73	39.279294	39.297350000000002	47.537475000000001	47.521053999999999	0103000020E6100000010000000500000009FCE1E7BFA3434099B9C0E5B1C2474009FCE1E7BFA3434074B515FBCBC4474099BB96900FA6434074B515FBCBC4474099BB96900FA6434099B9C0E5B1C2474009FCE1E7BFA3434099B9C0E5B1C24740
31042	Гаевка	2	23	73	38.83099	38.846089999999997	47.276345999999997	47.269908000000001	0103000020E61000000100000005000000CAA65CE15D6A4340E27668588CA24740CAA65CE15D6A4340B130444E5FA347407FBC57AD4C6C4340B130444E5FA347407FBC57AD4C6C4340E27668588CA24740CAA65CE15D6A4340E27668588CA24740
337	Гаевка	2	23	73	38.632390000000001	38.680368999999999	47.242313000000003	47.231074	0103000020E61000000100000005000000A228D027F25043405B7A34D5939D4740A228D027F2504340A532C51C049F47402A1BD65416574340A532C51C049F47402A1BD654165743405B7A34D5939D4740A228D027F25043405B7A34D5939D4740
56623	Веселый	2	23	73	38.743844000000003	38.771673999999997	47.178088000000002	47.167783999999997	0103000020E61000000100000005000000B5A9BA47365F4340626534F279954740B5A9BA47365F4340B0E76B96CB9647403596B036C6624340B0E76B96CB9647403596B036C6624340626534F279954740B5A9BA47365F4340626534F279954740
1652	Весело-Вознесенка	2	23	73	38.331293000000002	38.353166999999999	47.159255999999999	47.137217999999997	0103000020E6100000010000000500000066321CCF672A43401536035C9091474066321CCF672A43408CD827806294474062838593342D43408CD827806294474062838593342D43401536035C9091474066321CCF672A43401536035C90914740
2055	Васильево-Ханжоновка	2	23	73	38.36842	38.386718999999999	47.232706999999998	47.223638999999999	0103000020E610000001000000050000009E98F562282F4340198EE733A09C47409E98F562282F43406F46CD57C99D4740F4DE1802803143406F46CD57C99D4740F4DE180280314340198EE733A09C47409E98F562282F4340198EE733A09C4740
31304	Вареновка	2	23	73	39.006700000000002	39.035921999999999	47.298253000000003	47.276676000000002	0103000020E610000001000000050000000D71AC8BDB80434047CB811E6AA347400D71AC8BDB8043408A7780272DA647407C9A9317998443408A7780272DA647407C9A93179984434047CB811E6AA347400D71AC8BDB80434047CB811E6AA34740
30459	Большая Неклиновка	2	23	73	38.847653000000001	38.881152	47.436523999999999	47.416674999999998	0103000020E610000001000000050000009BADBCE47F6C4340C8073D9B55B547409BADBCE47F6C4340A5F5B704E0B747400A67B796C9704340A5F5B704E0B747400A67B796C9704340C8073D9B55B547409BADBCE47F6C4340C8073D9B55B54740
31374	Бессергеновка	2	23	73	38.978501999999999	38.998651000000002	47.282373999999997	47.272348000000001	0103000020E610000001000000050000000989B48D3F7D4340C5909C4CDCA247400989B48D3F7D4340CF9ECBD424A44740118FC4CBD37F4340CF9ECBD424A44740118FC4CBD37F4340C5909C4CDCA247400989B48D3F7D4340C5909C4CDCA24740
705	Беглица	2	23	73	38.493096999999999	38.590825000000002	47.157926000000003	47.124755	0103000020E61000000100000005000000BB6070CD1D3F43409981CAF8F78F4740BB6070CD1D3F434014984EEB3694474061545227A04B434014984EEB3694474061545227A04B43409981CAF8F78F4740BB6070CD1D3F43409981CAF8F78F4740
30790	Андреево-Мелентьево	2	23	73	38.801003999999999	38.813580000000002	47.311494000000003	47.298357000000003	0103000020E610000001000000050000008BFB8F4C876643402FC4EA8F30A647408BFB8F4C876643403B730F09DFA747400057B263236843403B730F09DFA747400057B263236843402FC4EA8F30A647408BFB8F4C876643402FC4EA8F30A64740
1574	Александрово-Марково	2	23	73	38.547435999999998	38.576532999999998	47.241016000000002	47.224587	0103000020E610000001000000050000009753026212464340AA0D4E44BF9C4740975302621246434008E8BE9CD99E47404A0856D5CB49434008E8BE9CD99E47404A0856D5CB494340AA0D4E44BF9C47409753026212464340AA0D4E44BF9C4740
28343	Александрова Коса	2	23	73	38.786478000000002	38.808504999999997	47.182737000000003	47.171736000000003	0103000020E610000001000000050000000283A44FAB644340DFC5FB71FB9547400283A44FAB64434074620FED6397474084D382177D67434074620FED6397474084D382177D674340DFC5FB71FB9547400283A44FAB644340DFC5FB71FB954740
56798	Чкалова	2	23	1296	39.242355000000003	39.257851000000002	47.431916000000001	47.423715999999999	0103000020E61000000100000005000000D482177D059F43405E656D533CB64740D482177D059F4340404F030649B74740D61EF64201A14340404F030649B74740D61EF64201A143405E656D533CB64740D482177D059F43405E656D533CB64740
13597	Чалтырь	2	23	1296	39.472701000000001	39.519638	47.297196	47.272371999999997	0103000020E61000000100000005000000ACE4637781BC43404D2CF015DDA24740ACE4637781BC43404240BE840AA6474022E17B7F83C243404240BE840AA6474022E17B7F83C243404D2CF015DDA24740ACE4637781BC43404D2CF015DDA24740
25864	Хапры	2	23	1296	39.422395999999999	39.455382	47.275044000000001	47.262858000000001	0103000020E6100000010000000500000009FB761211B64340F9BEB854A5A1474009FB761211B64340037B4CA434A34740F29716F549BA4340037B4CA434A34740F29716F549BA4340F9BEB854A5A1474009FB761211B64340F9BEB854A5A14740
25697	Султан-Салы	2	23	1296	39.573169	39.590156	47.362423	47.349854000000001	0103000020E610000001000000050000005F0A0F9A5DC94340F92F1004C8AC47405F0A0F9A5DC94340BB287AE063AE4740E3C4573B8ACB4340BB287AE063AE4740E3C4573B8ACB4340F92F1004C8AC47405F0A0F9A5DC94340F92F1004C8AC4740
56662	Петровка	2	23	1296	39.434244	39.457321999999998	47.490034999999999	47.482745999999999	0103000020E61000000100000005000000FB3DB14E95B743402D23F59ECABD4740FB3DB14E95B743409B728577B9BE4740E3DEFC8689BA43409B728577B9BE4740E3DEFC8689BA43402D23F59ECABD4740FB3DB14E95B743402D23F59ECABD4740
25715	Несветай	2	23	1296	39.656973000000001	39.671489000000001	47.456274000000001	47.448962000000002	0103000020E6100000010000000500000071ADF6B017D44340C992399677B9474071ADF6B017D44340EF01BA2F67BA4740D74FFF59F3D54340EF01BA2F67BA4740D74FFF59F3D54340C992399677B9474071ADF6B017D44340C992399677B94740
56893	Мокрый Чалтырь	2	23	1296	39.469988000000001	39.484963	47.272415000000002	47.264215	0103000020E6100000010000000500000098C1189128BC43406B0E10CCD1A1474098C1189128BC43404DF8A57EDEA247409162804413BE43404DF8A57EDEA247409162804413BE43406B0E10CCD1A1474098C1189128BC43406B0E10CCD1A14740
57017	Ленинакан	2	23	1296	39.643704999999997	39.654232999999998	47.311995000000003	47.304254	0103000020E61000000100000005000000C6A2E9EC64D24340AED689CBF1A64740C6A2E9EC64D24340FDC1C073EFA74740637B2DE8BDD34340FDC1C073EFA74740637B2DE8BDD34340AED689CBF1A64740C6A2E9EC64D24340AED689CBF1A64740
56629	Ленинаван	2	23	1296	39.610269000000002	39.639733999999997	47.289726999999999	47.277441000000003	0103000020E610000001000000050000009E616A4B1DCE4340E7C8CA2F83A347409E616A4B1DCE434054E23AC615A54740D311C0CDE2D1434054E23AC615A54740D311C0CDE2D14340E7C8CA2F83A347409E616A4B1DCE4340E7C8CA2F83A34740
25055	Крым	2	23	1296	39.496803	39.533841000000002	47.319172999999999	47.294432999999998	0103000020E6100000010000000500000000C79E3D97BF43407CEE04FBAFA5474000C79E3D97BF434013622EA9DAA84740C921E2E654C4434013622EA9DAA84740C921E2E654C443407CEE04FBAFA5474000C79E3D97BF43407CEE04FBAFA54740
56674	Красный Крым	2	23	1296	39.624533999999997	39.647226000000003	47.339865000000003	47.333685000000003	0103000020E61000000100000005000000BA9EE8BAF0CF43403815A930B6AA4740BA9EE8BAF0CF43400C0742B280AB47407A8F334DD8D243400C0742B280AB47407A8F334DD8D243403815A930B6AA4740BA9EE8BAF0CF43403815A930B6AA4740
56633	Калинин	2	23	1296	39.483956999999997	39.532682000000001	47.256962000000001	47.232205999999998	0103000020E61000000100000005000000CBD58F4DF2BD4340ADF71BEDB89D4740CBD58F4DF2BD43404A287D21E4A047407D957CEC2EC443404A287D21E4A047407D957CEC2EC44340ADF71BEDB89D4740CBD58F4DF2BD4340ADF71BEDB89D4740
25912	Веселый	2	23	1296	39.292310999999998	39.318218000000002	47.337533000000001	47.323357000000001	0103000020E610000001000000050000006AA164726AA5434062F71DC363A947406AA164726AA543400F29064834AB4740D07F0F5EBBA843400F29064834AB4740D07F0F5EBBA8434062F71DC363A947406AA164726AA5434062F71DC363A94740
25788	Большие Салы	2	23	1296	39.671875999999997	39.70205	47.399434999999997	47.380553999999997	0103000020E61000000100000005000000D07B630800D64340552E54FEB5B04740D07B630800D643405AF0A2AF20B3474012143FC6DCD943405AF0A2AF20B3474012143FC6DCD94340552E54FEB5B04740D07B630800D64340552E54FEB5B04740
26039	Александровка 2-я	2	23	1296	39.367949000000003	39.384971999999998	47.458297000000002	47.448492999999999	0103000020E6100000010000000500000047CCECF318AF434012BEF73768B9474047CCECF318AF43406E6DE179A9BA474017F032C346B143406E6DE179A9BA474017F032C346B1434012BEF73768B9474047CCECF318AF434012BEF73768B94740
27439	Широко-Атамановский	2	23	351	41.865068000000001	41.887642	48.261220000000002	48.244152	0103000020E610000001000000050000007768588CBAEE444062A06B5F401F48407768588CBAEE4440D3872EA86F2148402C47C8409EF14440D3872EA86F2148402C47C8409EF1444062A06B5F401F48407768588CBAEE444062A06B5F401F4840
27974	Чертковская	2	23	351	41.984543000000002	41.997120000000002	47.883125999999997	47.869872999999998	0103000020E61000000100000005000000BC40498105FE444032569BFF57EF4740BC40498105FE4440A71FD4450AF147400118CFA0A1FF4440A71FD4450AF147400118CFA0A1FF444032569BFF57EF4740BC40498105FE444032569BFF57EF4740
27660	Чекалов	2	23	351	42.018293	42.038621999999997	48.144558000000004	48.120474999999999	0103000020E61000000100000005000000745FCE6C57024540287E8CB96B0F4840745FCE6C57024540063065E080124840FB73D190F1044540063065E080124840FB73D190F1044540287E8CB96B0F4840745FCE6C57024540287E8CB96B0F4840
28259	Трофименков	2	23	351	41.696382	41.728020999999998	48.377321999999999	48.367463999999998	0103000020E61000000100000005000000F4C29D0B23D944408A3A730F092F4840F4C29D0B23D94440D90759164C3048408EE6C8CA2FDD4440D90759164C3048408EE6C8CA2FDD44408A3A730F092F4840F4C29D0B23D944408A3A730F092F4840
27745	Табунный	2	23	351	41.836959	41.853192	48.081501000000003	48.074120999999998	0103000020E61000000100000005000000E38BF67821EB4440317903CC7C094840E38BF67821EB4440B0CBF09F6E0A4840BB9A3C6535ED4440B0CBF09F6E0A4840BB9A3C6535ED4440317903CC7C094840E38BF67821EB4440317903CC7C094840
28014	Старопетровский	2	23	351	41.848754	41.861510000000003	47.909362999999999	47.900762	0103000020E61000000100000005000000B22C98F8A3EC444062BD512B4CF34740B22C98F8A3EC4440A298BC0166F44740A796ADF545EE4440A298BC0166F44740A796ADF545EE444062BD512B4CF34740B22C98F8A3EC444062BD512B4CF34740
28075	Сибирьки	2	23	351	41.710583999999997	41.734515000000002	48.307015	48.290897000000001	0103000020E61000000100000005000000CA87A06AF4DA444094C0E61C3C254840CA87A06AF4DA4440D3307C444C274840F2B5679604DE4440D3307C444C274840F2B5679604DE444094C0E61C3C254840CA87A06AF4DA444094C0E61C3C254840
27778	Разлатный	2	23	351	41.880510000000001	41.891640000000002	48.011315000000003	48.003031999999997	0103000020E6100000010000000500000086E63A8DB4F04440B56B425A6300484086E63A8DB4F04440257A19C57201484019E76F4221F24440257A19C57201484019E76F4221F24440B56B425A6300484086E63A8DB4F04440B56B425A63004840
27422	Покровский	2	23	351	42.080078999999998	42.099555000000002	48.314444999999999	48.299463000000003	0103000020E61000000100000005000000560C5707400A454058AEB7CD54264840560C5707400A454003B2D7BB3F2848409F93DE37BE0C454003B2D7BB3F2848409F93DE37BE0C454058AEB7CD54264840560C5707400A454058AEB7CD54264840
27902	Парамонов	2	23	351	41.907414000000003	41.974294	47.977524000000003	47.939903000000001	0103000020E610000001000000050000005EF7562426F44440C634D3BD4EF847405EF7562426F444400E87A5811FFD4740325871AAB5FC44400E87A5811FFD4740325871AAB5FC4440C634D3BD4EF847405EF7562426F44440C634D3BD4EF84740
27147	Общий	2	23	351	41.818849	41.842098	48.455694999999999	48.441806	0103000020E6100000010000000500000060AE450BD0E844409A9658198D38484060AE450BD0E84440B1F9B836543A4840750305DEC9EB4440B1F9B836543A4840750305DEC9EB44409A9658198D38484060AE450BD0E844409A9658198D384840
28230	Новопроциков	2	23	351	41.609020999999998	41.647765	48.381833999999998	48.368805000000002	0103000020E61000000100000005000000E2C96E66F4CD4440F7CC9200352F4840E2C96E66F4CD44401C40BFEFDF304840293FA9F6E9D244401C40BFEFDF304840293FA9F6E9D24440F7CC9200352F4840E2C96E66F4CD4440F7CC9200352F4840
27816	Николаев	2	23	351	41.727670000000003	41.747971999999997	48.029744000000001	48.010235999999999	0103000020E61000000100000005000000E223624A24DD4440F59ECA694F014840E223624A24DD444049A0C1A6CE0348406F29E78BBDDF444049A0C1A6CE0348406F29E78BBDDF4440F59ECA694F014840E223624A24DD4440F59ECA694F014840
1764	Морозовск	2	23	351	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
27295	Морозов	2	23	351	41.861986000000002	41.897801999999999	48.344946999999998	48.323816000000001	0103000020E6100000010000000500000010CEA78E55EE4440F5F57CCD7229484010CEA78E55EE444039ED2939272C484046240A2DEBF2444039ED2939272C484046240A2DEBF24440F5F57CCD7229484010CEA78E55EE4440F5F57CCD72294840
27522	Малая Хлоповая	2	23	351	41.826529999999998	41.841028999999999	48.207616000000002	48.196404000000001	0103000020E61000000100000005000000D9942BBCCBE94440DC662AC423194840D9942BBCCBE944402C103D29931A484069FE98D6A6EB44402C103D29931A484069FE98D6A6EB4440DC662AC423194840D9942BBCCBE94440DC662AC423194840
28156	Костино-Быстрянский	2	23	351	41.629260000000002	41.673205000000003	48.410955999999999	48.392615999999997	0103000020E610000001000000050000002A5778978BD0444073F1B73D413248402A5778978BD04440280CCA349A3448407940D9942BD64440280CCA349A3448407940D9942BD6444073F1B73D413248402A5778978BD0444073F1B73D41324840
27537	Комсомольский	2	23	351	41.898457999999998	41.923825999999998	48.199443000000002	48.185074999999998	0103000020E610000001000000050000002F6AF7AB00F344405227A089B01748402F6AF7AB00F344404435255987194840E5982CEE3FF644404435255987194840E5982CEE3FF644405227A089B01748402F6AF7AB00F344405227A089B0174840
27689	Знаменка	2	23	351	41.806147000000003	41.831021	48.045395999999997	48.034022	0103000020E610000001000000050000005F622CD32FE7444019AC38D55A0448405F622CD32FE7444042AF3F89CF05484005A568E55EEA444042AF3F89CF05484005A568E55EEA444019AC38D55A0448405F622CD32FE7444019AC38D55A044840
27354	Донской	2	23	351	42.012616000000001	42.031229000000003	48.275584000000002	48.263302000000003	0103000020E6100000010000000500000003B4AD669D014540577C43E1B321484003B4AD669D01454083A6255646234840E9D7D64FFF03454083A6255646234840E9D7D64FFF034540577C43E1B321484003B4AD669D014540577C43E1B3214840
27276	Гурин	2	23	351	42.048171000000004	42.066146000000003	48.447142999999997	48.436324999999997	0103000020E61000000100000005000000CDCEA2772A064540AEB6627FD9374840CDCEA2772A06454052D158FB3B3948407061DD787708454052D158FB3B3948407061DD7877084540AEB6627FD9374840CDCEA2772A064540AEB6627FD9374840
27081	Грузинов	2	23	351	41.758679999999998	41.796149	48.428612999999999	48.383372000000001	0103000020E610000001000000050000008C101E6D1CE14440DF196D55123148408C101E6D1CE14440FAD170CADC3648401EDFDE35E8E54440FAD170CADC3648401EDFDE35E8E54440DF196D55123148408C101E6D1CE14440DF196D5512314840
28065	Вольно-Донская	2	23	351	41.617024999999998	41.638396	48.304132000000003	48.290135999999997	0103000020E610000001000000050000003EE8D9ACFACE444035B22B2D232548403EE8D9ACFACE444063D520CCED264840D8F2CAF5B6D1444063D520CCED264840D8F2CAF5B6D1444035B22B2D232548403EE8D9ACFACE444035B22B2D23254840
27163	Вознесенский	2	23	351	41.916863999999997	41.961680999999999	48.390815000000003	48.366715999999997	0103000020E610000001000000050000009B70AFCC5BF54440C075C58CF02E48409B70AFCC5BF54440A4E4D53906324840A017EE5C18FB4440A4E4D53906324840A017EE5C18FB4440C075C58CF02E48409B70AFCC5BF54440C075C58CF02E4840
29224	Владимиров	2	23	351	41.800991000000003	41.817169	48.168492999999998	48.148471999999998	0103000020E61000000100000005000000F7B182DF86E64440942F682101134840F7B182DF86E644406E4DBA2D911548400B2769FE98E844406E4DBA2D911548400B2769FE98E84440942F682101134840F7B182DF86E64440942F682101134840
28140	Вишневка	2	23	351	41.700738999999999	41.738242999999997	48.224767999999997	48.206077999999998	0103000020E610000001000000050000001004C8D0B1D9444069368FC3601A48401004C8D0B1D94440FA97A432C51C48401EC022BF7EDE4440FA97A432C51C48401EC022BF7EDE444069368FC3601A48401004C8D0B1D9444069368FC3601A4840
27232	Вербочки	2	23	351	41.995753999999998	42.014493000000002	48.458993	48.443933999999999	0103000020E610000001000000050000003B6EF8DD74FF44408ECA4DD4D23848403B6EF8DD74FF4440E50B5A48C03A4840AE8218E8DA014540E50B5A48C03A4840AE8218E8DA0145408ECA4DD4D23848403B6EF8DD74FF44408ECA4DD4D2384840
29168	Быстрый	2	23	351	42.058267999999998	42.074455999999998	48.396935999999997	48.384945999999999	0103000020E61000000100000005000000A033695375074540EE5C18E945314840A033695375074540724D81CCCE324840D87E32C687094540724D81CCCE324840D87E32C687094540EE5C18E945314840A033695375074540EE5C18E945314840
27607	Беляев	2	23	351	41.803758000000002	41.830114000000002	48.146765000000002	48.127096999999999	0103000020E61000000100000005000000FEF2C98AE1E64440B935E9B644104840FEF2C98AE1E6444046990D32C9124840D3F9F02C41EA444046990D32C9124840D3F9F02C41EA4440B935E9B644104840FEF2C98AE1E64440B935E9B644104840
27882	Александров	2	23	351	41.731999999999999	41.752904000000001	47.910632	47.895995999999997	0103000020E6100000010000000500000004560E2DB2DD444064AC36FFAFF2474004560E2DB2DD44407558E1968FF44740888384285FE044407558E1968FF44740888384285FE0444064AC36FFAFF2474004560E2DB2DD444064AC36FFAFF24740
56781	Юдин	2	23	167	41.679448999999998	41.732745999999999	48.633074999999998	48.617936999999998	0103000020E610000001000000050000006326512FF8D6444082FE428F184F48406326512FF8D644402575029A085148402D23F59ECADD44402575029A085148402D23F59ECADD444082FE428F184F48406326512FF8D6444082FE428F184F4840
56904	Широко-Бахолдинский	2	23	167	41.930796999999998	41.949131999999999	48.573723000000001	48.565586000000003	0103000020E61000000100000005000000821B295B24F74440A9893E1F65484840821B295B24F7444044FB58C16F49484025CB49287DF9444044FB58C16F49484025CB49287DF94440A9893E1F65484840821B295B24F74440A9893E1F65484840
56972	Терновой	2	23	167	41.539122999999996	41.580221000000002	48.596747000000001	48.575434000000001	0103000020E61000000100000005000000BDC282FB01C54440D48041D2A7494840BDC282FB01C54440397EA834624C4840E9B985AE44CA4440397EA834624C4840E9B985AE44CA4440D48041D2A7494840BDC282FB01C54440D48041D2A7494840
56752	Сулинский	2	23	167	41.495294000000001	41.545105999999997	48.564363	48.536720000000003	0103000020E61000000100000005000000D8F335CB65BF4440F88DAF3DB3444840D8F335CB65BF44404609FA0B3D4848403B6D8D08C6C544404609FA0B3D4848403B6D8D08C6C54440F88DAF3DB3444840D8F335CB65BF4440F88DAF3DB3444840
56690	Старокузнецов	2	23	167	41.619405	41.664518999999999	48.625839999999997	48.600881999999999	0103000020E610000001000000050000004CFDBCA948CF4440A6608DB3E94C48404CFDBCA948CF4440AA436E861B5048400A4966F50ED54440AA436E861B5048400A4966F50ED54440A6608DB3E94C48404CFDBCA948CF4440A6608DB3E94C4840
594	Селивановская	2	23	167	41.705849999999998	41.757475999999997	48.868243999999997	48.827395000000003	0103000020E61000000100000005000000D8F0F44A59DA4440DDEF5014E8694840D8F0F44A59DA44405F79909E226F4840A0C03BF9F4E044405F79909E226F4840A0C03BF9F4E04440DDEF5014E8694840D8F0F44A59DA4440DDEF5014E8694840
57009	Севостьянов	2	23	167	41.784992000000003	41.882710000000003	48.835763	48.786963999999998	0103000020E6100000010000000500000092CF2B9E7AE444408E90813CBB64484092CF2B9E7AE444407A1A3048FA6A484014ED2AA4FCF044407A1A3048FA6A484014ED2AA4FCF044408E90813CBB64484092CF2B9E7AE444408E90813CBB644840
26088	Светоч	2	23	167	41.780276000000001	41.795977999999998	48.557124999999999	48.546503000000001	0103000020E6100000010000000500000046ED7E15E0E344403C1570CFF345484046ED7E15E0E344405A643BDF4F474840F12A6B9BE2E544405A643BDF4F474840F12A6B9BE2E544403C1570CFF345484046ED7E15E0E344403C1570CFF3454840
56859	Решетняков	2	23	167	41.594566999999998	41.630651999999998	48.793878999999997	48.767187	0103000020E61000000100000005000000F2237EC51ACC44404B75012F33624840F2237EC51ACC444097FDBAD39D65484018946934B9D0444097FDBAD39D65484018946934B9D044404B75012F33624840F2237EC51ACC44404B75012F33624840
56975	Павловка	2	23	167	41.520958999999998	41.550989999999999	48.756652000000003	48.742922999999998	0103000020E6100000010000000500000047C7D5C8AEC244401D39D219185F484047C7D5C8AEC24440FC3905F9D960484026361FD786C64440FC3905F9D960484026361FD786C644401D39D219185F484047C7D5C8AEC244401D39D219185F4840
56945	Орлов	2	23	167	41.854782	41.894486999999998	48.657581999999998	48.644826999999999	0103000020E61000000100000005000000D09A1F7F69ED4440F549EEB089524840D09A1F7F69ED44401938A0A52B5448403CD9CD8C7EF244401938A0A52B5448403CD9CD8C7EF24440F549EEB089524840D09A1F7F69ED4440F549EEB089524840
57002	Образцов	2	23	167	41.688628999999999	41.691898999999999	48.615155000000001	48.610073999999997	0103000020E61000000100000005000000E109BDFE24D84440E811A3E7164E4840E109BDFE24D84440467C2766BD4E48404B917C2590D84440467C2766BD4E48404B917C2590D84440E811A3E7164E4840E109BDFE24D84440E811A3E7164E4840
56843	Новодмитриевский	2	23	167	41.759622999999998	41.801017999999999	48.946734999999997	48.897765999999997	0103000020E610000001000000050000000B2593533BE14440F9BA0CFFE97248400B2593533BE14440417DCB9C2E794840F0C000C287E64440417DCB9C2E794840F0C000C287E64440F9BA0CFFE97248400B2593533BE14440F9BA0CFFE9724840
56672	Николовка	2	23	167	41.397458	41.433534999999999	48.687336000000002	48.668436999999997	0103000020E610000001000000050000004CC45BE7DFB24440DA37F7578F5548404CC45BE7DFB2444086AE44A0FA574840EF552B137EB7444086AE44A0FA574840EF552B137EB74440DA37F7578F5548404CC45BE7DFB24440DA37F7578F554840
56948	Нижнепетровский	2	23	167	41.515982000000001	41.563898000000002	48.747033999999999	48.727218000000001	0103000020E610000001000000050000008FA9BBB20BC244400188BB7A155D48408FA9BBB20BC24440028063CF9E5F4840D12346CF2DC84440028063CF9E5F4840D12346CF2DC844400188BB7A155D48408FA9BBB20BC244400188BB7A155D4840
519	Милютинская	2	23	167	41.653405999999997	41.695861000000001	48.637802000000001	48.618878000000002	0103000020E610000001000000050000004D81CCCEA2D34440611BF164374F48404D81CCCEA2D3444065A9F57EA3514840EBC726F911D9444065A9F57EA3514840EBC726F911D94440611BF164374F48404D81CCCEA2D34440611BF164374F4840
25701	Маньково-Березовская	2	23	167	41.538440000000001	41.578792	48.786245999999998	48.752898000000002	0103000020E61000000100000005000000DB6D179AEBC44440A69C2FF65E604840DB6D179AEBC444402F4E7CB5A3644840DD9733DB15CA44402F4E7CB5A3644840DD9733DB15CA4440A69C2FF65E604840DB6D179AEBC44440A69C2FF65E604840
56901	Кутейников	2	23	167	41.860737999999998	41.888081999999997	48.920775999999996	48.891067	0103000020E610000001000000050000005436ACA92CEE4440BDC5C37B0E7248405436ACA92CEE44408978EBFCDB7548404815C5ABACF144408978EBFCDB7548404815C5ABACF14440BDC5C37B0E7248405436ACA92CEE4440BDC5C37B0E724840
26011	Доброполье	2	23	167	41.897739000000001	41.921957999999997	48.722076999999999	48.704897000000003	0103000020E6100000010000000500000000AC8E1CE9F2444036069D103A5A484000AC8E1CE9F24440CE18E6046D5C48408D2441B802F64440CE18E6046D5C48408D2441B802F6444036069D103A5A484000AC8E1CE9F2444036069D103A5A4840
636	Вячеслав	2	23	167	41.793695999999997	41.818184000000002	48.961956999999998	48.949615999999999	0103000020E61000000100000005000000A67B9DD497E5444011E15F048D794840A67B9DD497E5444042942F68217B4840240ED940BAE8444042942F68217B4840240ED940BAE8444011E15F048D794840A67B9DD497E5444011E15F048D794840
56995	Волоцков	2	23	167	41.820357999999999	41.858212999999999	48.894941000000003	48.866905000000003	0103000020E610000001000000050000008881AE7D01E9444094DE37BEF66E48408881AE7D01E94440BE6C3B6D8D724840430070ECD9ED4440BE6C3B6D8D724840430070ECD9ED444094DE37BEF66E48408881AE7D01E9444094DE37BEF66E4840
56964	Антоновка	2	23	167	41.331755999999999	41.370311000000001	48.645493999999999	48.629038000000001	0103000020E610000001000000050000003A2009FB76AA44407BF83251845048403A2009FB76AA4440D2E1218C9F524840AE2CD15966AF4440D2E1218C9F524840AE2CD15966AF44407BF83251845048403A2009FB76AA44407BF8325184504840
26405	Аграрный	2	23	167	41.425082000000003	41.449317999999998	48.594386999999998	48.581972999999998	0103000020E61000000100000005000000240F441669B64440D7135D177E4A4840240F441669B6444072158BDF144C484087C0914083B9444072158BDF144C484087C0914083B94440D7135D177E4A4840240F441669B64440D7135D177E4A4840
16236	Ярский	2	23	1388	40.801380999999999	40.824522000000002	49.023086999999997	49.010088000000003	0103000020E61000000100000005000000615111A793664440810A47904A814840615111A7936644403BFBCA83F4824840906AD8EF896944403BFBCA83F4824840906AD8EF89694440810A47904A814840615111A793664440810A47904A814840
56699	Хмызов	2	23	1388	40.776507000000002	40.815206000000003	49.133299000000001	49.111189000000003	0103000020E61000000100000005000000BB0ED594646344406556EF703B8E4840BB0ED5946463444075CB0EF10F91484062C092AB5868444075CB0EF10F91484062C092AB586844406556EF703B8E4840BB0ED594646344406556EF703B8E4840
56941	Фоминка	2	23	1388	40.571125000000002	40.601883999999998	49.032319999999999	49.008310000000002	0103000020E61000000100000005000000C976BE9F1A494440691D554D10814840C976BE9F1A494440DC80CF0F238448402AFEEF880A4D4440DC80CF0F238448402AFEEF880A4D4440691D554D10814840C976BE9F1A494440691D554D10814840
56788	Туроверово-Глубокинский	2	23	1388	40.372695999999998	40.383215999999997	48.858778999999998	48.844431999999998	0103000020E61000000100000005000000CDACA580B42F444012D90759166C4840CDACA580B42F4440ECBE6378EC6D4840E7A6CD380D314440ECBE6378EC6D4840E7A6CD380D31444012D90759166C4840CDACA580B42F444012D90759166C4840
56800	Треневка	2	23	1388	40.338901999999997	40.376747999999999	48.988562000000002	48.963045000000001	0103000020E6100000010000000500000045460724612B4440C5C9FD0E457B484045460724612B4440C0081A33897E4840AD6A494739304440C0081A33897E4840AD6A494739304440C5C9FD0E457B484045460724612B4440C5C9FD0E457B4840
17558	Титовка	2	23	1388	39.717007000000002	39.763567000000002	49.002606	48.979349999999997	0103000020E610000001000000050000006500A8E2C6DB434036AB3E575B7D48406500A8E2C6DB4340FE62B6645580484005A73E90BCE14340FE62B6645580484005A73E90BCE1434036AB3E575B7D48406500A8E2C6DB434036AB3E575B7D4840
26822	Терновой	2	23	1388	40.325857999999997	40.354765999999998	48.934514999999998	48.925032999999999	0103000020E61000000100000005000000EA9106B7B5294440425C397B67764840EA9106B7B52944408B4F01309E774840CADDE7F8682D44408B4F01309E774840CADDE7F8682D4440425C397B67764840EA9106B7B5294440425C397B67764840
16544	Терновая	2	23	1388	40.653537	40.670721	49.108358000000003	49.090414000000003	0103000020E61000000100000005000000ECDCB419A7534440DF8C9AAF928B4840ECDCB419A75344404721C9ACDE8D4840C6DE8B2FDA5544404721C9ACDE8D4840C6DE8B2FDA554440DF8C9AAF928B4840ECDCB419A7534440DF8C9AAF928B4840
56758	Сулин	2	23	1388	40.090257000000001	40.171716000000004	48.916857	48.904156	0103000020E61000000100000005000000179E978A8D0B4440B83D4162BB734840179E978A8D0B4440E90DF7915B754840981936CAFA154440E90DF7915B754840981936CAFA154440B83D4162BB734840179E978A8D0B4440B83D4162BB734840
17759	Рогалик	2	23	1388	40.045099	40.074016	48.946415000000002	48.918100000000003	0103000020E61000000100000005000000890AD5CDC5054440933A014D84754840890AD5CDC5054440D0B8702024794840BCB0355B79094440D0B8702024794840BCB0355B79094440933A014D84754840890AD5CDC5054440933A014D84754840
17005	Поповка	2	23	1388	40.463444000000003	40.482622999999997	49.052269000000003	49.039265999999998	0103000020E6100000010000000500000083C30B22523B444020EC14AB0685484083C30B22523B44401DCC26C0B086484011A62897C63D44401DCC26C0B086484011A62897C63D444020EC14AB0685484083C30B22523B444020EC14AB06854840
16391	Позднеевка	2	23	1388	40.899504	40.932850000000002	48.868789	48.842618000000002	0103000020E61000000100000005000000834F73F222734440AE8218E8DA6B4840834F73F222734440F10F5B7A346F48406C09F9A067774440F10F5B7A346F48406C09F9A067774440AE8218E8DA6B4840834F73F222734440AE8218E8DA6B4840
16497	Ольховый Рог	2	23	1388	40.664631	40.708325000000002	49.034824999999998	49.000566999999997	0103000020E610000001000000050000003274ECA012554440793A5794128048403274ECA012554440A60A46257584484038F8C264AA5A4440A60A46257584484038F8C264AA5A4440793A5794128048403274ECA012554440793A579412804840
56718	Новоспасовка	2	23	1388	40.444454	40.470998999999999	48.915916000000003	48.907744999999998	0103000020E61000000100000005000000C74961DEE3384440C30DF8FC30744840C74961DEE33844400BF148BC3C7548406FB9FAB1493C44400BF148BC3C7548406FB9FAB1493C4440C30DF8FC30744840C74961DEE3384440C30DF8FC30744840
56841	Новая Деревня	2	23	1388	40.068292999999997	40.093716000000001	49.070103000000003	49.059595999999999	0103000020E61000000100000005000000DAC534D3BD084440787C7BD7A0874840DAC534D3BD084440FE2C9622F9884840548EC9E2FE0B4440FE2C9622F9884840548EC9E2FE0B4440787C7BD7A0874840DAC534D3BD084440787C7BD7A0874840
16169	Никольская	2	23	1388	40.666814000000002	40.687196999999998	48.976216000000001	48.945729	0103000020E61000000100000005000000EA4141295A5544407CF0DAA50D794840EA4141295A5544407DEA58A5F47C484064744012F65744407DEA58A5F47C484064744012F65744407CF0DAA50D794840EA4141295A5544407CF0DAA50D794840
17494	Нижненагольная	2	23	1388	39.943579999999997	39.964412000000003	49.018579000000003	48.972667999999999	0103000020E610000001000000050000007094BC3AC7F84340D0EE9062807C48407094BC3AC7F843403AB2F2CB608248405BEF37DA71FB43403AB2F2CB608248405BEF37DA71FB4340D0EE9062807C48407094BC3AC7F84340D0EE9062807C4840
17699	Нижнекамышинка	2	23	1388	39.839798000000002	39.856820999999997	49.008771000000003	48.989508000000001	0103000020E61000000100000005000000849F38807EEB4340B090B932A87E4840849F38807EEB43409D137B681F81484054C37E4FACED43409D137B681F81484054C37E4FACED4340B090B932A87E4840849F38807EEB4340B090B932A87E4840
54851	Миллерово	2	23	1388	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
17598	Машлыкино	2	23	1388	39.775272000000001	39.802517999999999	48.964506	48.935515000000002	0103000020E6100000010000000500000094C0E61C3CE343406FF59CF4BE77484094C0E61C3CE34340DC65BFEE747B4840C539EAE8B8E64340DC65BFEE747B4840C539EAE8B8E643406FF59CF4BE77484094C0E61C3CE343406FF59CF4BE774840
17349	Мальчевско-Полненская	2	23	1388	40.197443999999997	40.226908999999999	48.999384999999997	48.9666	0103000020E610000001000000050000004D6551D84519444024287E8CB97B48404D6551D845194440758E01D9EB7F48408315A75A0B1D4440758E01D9EB7F48408315A75A0B1D444024287E8CB97B48404D6551D84519444024287E8CB97B4840
16936	Мальчевская	2	23	1388	40.320504	40.389989	49.085239999999999	49.038339000000001	0103000020E610000001000000050000005C1E6B4606294440A794D74AE88448405C1E6B4606294440D027F224E98A48405E66D828EB314440D027F224E98A48405E66D828EB314440A794D74AE88448405C1E6B4606294440A794D74AE8844840
56783	Малотакмацкий	2	23	1388	40.465456000000003	40.503464000000001	48.953136999999998	48.941220000000001	0103000020E610000001000000050000000EDDEC0F943B4440AA2B9FE5797848400EDDEC0F943B4440C4CDA964007A48404F5B238271404440C4CDA964007A48404F5B238271404440AA2B9FE5797848400EDDEC0F943B4440AA2B9FE579784840
16921	Кудиновка	2	23	1388	40.476083000000003	40.509537000000002	49.220408999999997	49.197119999999998	0103000020E610000001000000050000003E97A949F03C44409AB1683A3B9948403E97A949F03C44403D5FB35C369C48400D8D2782384144403D5FB35C369C48400D8D2782384144409AB1683A3B9948403E97A949F03C44409AB1683A3B994840
56883	Криничный	2	23	1388	40.883577000000002	40.896324	48.908253999999999	48.888643999999999	0103000020E61000000100000005000000B83F170D19714440B0E42A16BF714840B83F170D19714440083BC5AA41744840594FADBEBA724440083BC5AA41744840594FADBEBA724440B0E42A16BF714840B83F170D19714440B0E42A16BF714840
16310	Криворожье	2	23	1388	40.733198999999999	40.781717	48.865108999999997	48.839208999999997	0103000020E61000000100000005000000DE3AFF76D95D444022C154336B6B4840DE3AFF76D95D4440D53C47E4BB6E484016DD7A4D0F644440D53C47E4BB6E484016DD7A4D0F64444022C154336B6B4840DE3AFF76D95D444022C154336B6B4840
16864	Колодези	2	23	1388	40.417495000000002	40.460299999999997	49.174290999999997	49.136369999999999	0103000020E610000001000000050000002C9FE57970354440E8137992749148402C9FE579703544405A7EE02A4F964840A52C431CEB3A44405A7EE02A4F964840A52C431CEB3A4440E8137992749148402C9FE57970354440E813799274914840
56794	Каменка	2	23	1388	40.594203	40.615780000000001	48.898749000000002	48.879828000000003	0103000020E61000000100000005000000B1170AD80E4C4440740D33349E704840B1170AD80E4C444007280D350A734840F4C308E1D14E444007280D350A734840F4C308E1D14E4440740D33349E704840B1170AD80E4C4440740D33349E704840
56969	Ивановка	2	23	1388	40.472005000000003	40.496799000000003	48.987166000000002	48.978309000000003	0103000020E610000001000000050000003546EBA86A3C4440F530B43A397D48403546EBA86A3C444090DC9A745B7E4840BFD7101C973F444090DC9A745B7E4840BFD7101C973F4440F530B43A397D48403546EBA86A3C4440F530B43A397D4840
56993	Зеленая Роща	2	23	1388	40.375022999999999	40.403714999999998	49.026944999999998	49.012085999999996	0103000020E61000000100000005000000B81FF0C000304440A65EB7088C814840B81FF0C00030444036E50AEF72834840CBF3E0EEAC33444036E50AEF72834840CBF3E0EEAC334440A65EB7088C814840B81FF0C000304440A65EB7088C814840
56998	Жеребковский	2	23	1388	40.073908000000003	40.096015000000001	48.926600999999998	48.917549999999999	0103000020E61000000100000005000000D6743DD175094440EF38454772754840D6743DD1750944406FB88FDC9A764840757632384A0C44406FB88FDC9A764840757632384A0C4440EF38454772754840D6743DD175094440EF38454772754840
56882	Еритовка	2	23	1388	40.828636000000003	40.863599000000001	49.152369999999998	49.144609000000003	0103000020E61000000100000005000000E62494BE106A444088DA368C82924840E62494BE106A44401D7233DC80934840DDED7A698A6E44401D7233DC80934840DDED7A698A6E444088DA368C82924840E62494BE106A444088DA368C82924840
56873	Екатериновка	2	23	1388	40.733586000000003	40.759070999999999	48.832638000000003	48.820076	0103000020E61000000100000005000000D8666325E65D4440041E1840F8684840D8666325E65D444014B4C9E1936A4840C72B103D2961444014B4C9E1936A4840C72B103D29614440041E1840F8684840D8666325E65D4440041E1840F8684840
17285	Долотинка	2	23	1388	40.254252999999999	40.304558999999998	48.943066000000002	48.919468000000002	0103000020E6100000010000000500000077F4BF5C8B204440F9DB9E20B175484077F4BF5C8B2044401AFCFD62B6784840EA5910CAFB2644401AFCFD62B6784840EA5910CAFB264440F9DB9E20B175484077F4BF5C8B204440F9DB9E20B1754840
16774	Дегтево	2	23	1388	40.650787999999999	40.685391000000003	49.177689000000001	49.1492	0103000020E610000001000000050000008B506C054D534440174850FC189348408B506C054D534440F2ED5D83BE96484083FC6CE4BA574440F2ED5D83BE96484083FC6CE4BA574440174850FC189348408B506C054D534440174850FC18934840
56837	Греково-Станичный	2	23	1388	40.442081999999999	40.487878000000002	48.847658000000003	48.838034	0103000020E610000001000000050000003C139A2496384440D177B7B2446B48403C139A2496384440AD18AE0E806C48400D384BC9723E4440AD18AE0E806C48400D384BC9723E4440D177B7B2446B48403C139A2496384440D177B7B2446B4840
17254	Греково	2	23	1388	40.191766999999999	40.251271000000003	48.912931999999998	48.889420000000001	0103000020E61000000100000005000000DCB930D28B1844404434BA83D8714840DCB930D28B18444066BCADF4DA74484074B7EBA52920444066BCADF4DA74484074B7EBA5292044404434BA83D8714840DCB930D28B1844404434BA83D8714840
56918	Грай-Воронец	2	23	1388	40.589055999999999	40.637762000000002	49.174779999999998	49.154798	0103000020E610000001000000050000009CC1DF2F664B44403CBEBD6BD09348409CC1DF2F664B444058FFE7305F964840D7506A2FA251444058FFE7305F964840D7506A2FA25144403CBEBD6BD09348409CC1DF2F664B44403CBEBD6BD0934840
56802	Гетманов	2	23	1388	40.262957999999998	40.288021000000001	49.060068000000001	49.050680999999997	0103000020E610000001000000050000005C1C959BA8214440A8C30AB77C8648405C1C959BA8214440A0C4E74EB0874840D6C743DFDD244440A0C4E74EB0874840D6C743DFDD244440A8C30AB77C8648405C1C959BA8214440A8C30AB77C864840
57019	Гернер	2	23	1388	40.149869000000002	40.167521000000001	49.111566000000003	49.098377999999997	0103000020E6100000010000000500000095D74AE82E134440AC527AA6978C484095D74AE82E1344403BAC70CB478E484055320054711544403BAC70CB478E48405532005471154440AC527AA6978C484095D74AE82E134440AC527AA6978C4840
17657	Волошино	2	23	1388	39.918149	39.948943	48.932585000000003	48.906750000000002	0103000020E6100000010000000500000074ED0BE885F54340F2D24D621074484074ED0BE885F54340BEDEFDF15E7748405262D7F676F94340BEDEFDF15E7748405262D7F676F94340F2D24D621074484074ED0BE885F54340F2D24D6210744840
56739	Верхнеталовка	2	23	1388	40.336556999999999	40.377682	48.834297999999997	48.800057000000002	0103000020E61000000100000005000000B41EBE4C142B4440CBF78C4468664840B41EBE4C142B4440218FE046CA6A4840D9243FE257304440218FE046CA6A4840D9243FE257304440CBF78C4468664840B41EBE4C142B4440CBF78C4468664840
56773	Венделеевка	2	23	1388	40.199941000000003	40.220962	49.088448999999997	49.054305999999997	0103000020E610000001000000050000009510ACAA9719444000FDBE7FF38648409510ACAA97194440942EFD4B528B484052D4997B481C4440942EFD4B528B484052D4997B481C444000FDBE7FF38648409510ACAA9719444000FDBE7FF3864840
57008	Беляевск	2	23	1388	40.142933999999997	40.176217000000001	49.056165999999997	49.042957000000001	0103000020E6100000010000000500000044BE4BA94B12444030116F9D7F85484044BE4BA94B124440D5928E7230874840E7FF55478E164440D5928E7230874840E7FF55478E16444030116F9D7F85484044BE4BA94B12444030116F9D7F854840
56963	Ануфриевка	2	23	1388	40.071105000000003	40.114035000000001	48.999681000000002	48.958407999999999	0103000020E6100000010000000500000082CAF8F719094440C51C041DAD7A484082CAF8F7190944405FB7088CF57F4840B8CCE9B2980E44405FB7088CF57F4840B8CCE9B2980E4440C51C041DAD7A484082CAF8F719094440C51C041DAD7A4840
56866	Шапошниково	2	23	431	38.803815999999998	38.809232999999999	47.589528000000001	47.582107000000001	0103000020E6100000010000000500000032005471E3664340E7E26F7B82CA474032005471E3664340C4094CA775CB474007EC6AF294674340C4094CA775CB474007EC6AF294674340E7E26F7B82CA474032005471E3664340E7E26F7B82CA4740
25614	Сухореченский	2	23	431	38.861531999999997	38.870128999999999	47.537194999999997	47.531816999999997	0103000020E610000001000000050000008E3A3AAE466E4340793A579412C447408E3A3AAE466E4340904946CEC2C447408D261763606F4340904946CEC2C447408D261763606F4340793A579412C447408E3A3AAE466E4340793A579412C44740
56698	Староротовка	2	23	431	38.853240999999997	38.882292	47.606413000000003	47.598545000000001	0103000020E610000001000000050000009C4D4700376D43409817601F9DCC47409C4D4700376D4340446FF1F09ECD4740DFC2BAF1EE704340446FF1F09ECD4740DFC2BAF1EE7043409817601F9DCC47409C4D4700376D43409817601F9DCC4740
2798	Рясное	2	23	431	38.906627999999998	38.923012999999997	47.497706000000001	47.470284999999997	0103000020E61000000100000005000000A6D1E4620C7443405166834C32BC4740A6D1E4620C744340F18288D4B4BF474034643C4A25764340F18288D4B4BF474034643C4A257643405166834C32BC4740A6D1E4620C7443405166834C32BC4740
2724	Ряженое	2	23	431	38.844357000000002	38.894815000000001	47.524948000000002	47.496988000000002	0103000020E610000001000000050000000893E2E3136C43409240834D9DBF47400893E2E3136C4340E10CFE7E31C34740317C444C89724340E10CFE7E31C34740317C444C897243409240834D9DBF47400893E2E3136C43409240834D9DBF4740
2923	Политотдельское	2	23	431	39.053116000000003	39.082293	47.534798000000002	47.516075999999998	0103000020E610000001000000050000007A724D81CC864340102043C70EC247407A724D81CC864340ADFBC74274C4474049D8B793888A4340ADFBC74274C4474049D8B793888A4340102043C70EC247407A724D81CC864340102043C70EC24740
3483	Новониколаевка	2	23	431	38.672733000000001	38.690403000000003	47.627374000000003	47.607743999999997	0103000020E6100000010000000500000051F86C1D1C5643408C2B2E8ECACD474051F86C1D1C5643402C2E8ECA4DD04740B80721205F5843402C2E8ECA4DD04740B80721205F5843408C2B2E8ECACD474051F86C1D1C5643408C2B2E8ECACD4740
3028	Новоандриановка	2	23	431	39.030200000000001	39.046756000000002	47.578667000000003	47.568387000000001	0103000020E610000001000000050000006B2BF697DD8343405C3CBCE7C0C847406B2BF697DD8343402123A0C211CA47402672C119FC8543402123A0C211CA47402672C119FC8543405C3CBCE7C0C847406B2BF697DD8343405C3CBCE7C0C84740
3204	Надежда	2	23	431	38.830981000000001	38.849747000000001	47.648654999999998	47.641437000000003	0103000020E61000000100000005000000774CDD955D6A4340E1B88C9B1AD24740774CDD955D6A434085B1852007D34740E36F7B82C46C434085B1852007D34740E36F7B82C46C4340E1B88C9B1AD24740774CDD955D6A4340E1B88C9B1AD24740
2342	Матвеев Курган	2	23	431	38.842846999999999	38.884582999999999	47.597602999999999	47.552036000000001	0103000020E610000001000000050000000F441669E26B43407A1B9B1DA9C647400F441669E26B4340E97E4E417ECC47407DCC07043A714340E97E4E417ECC47407DCC07043A7143407A1B9B1DA9C647400F441669E26B43407A1B9B1DA9C64740
2966	Марьевка	2	23	431	39.129832	39.143872999999999	47.599601999999997	47.584307000000003	0103000020E61000000100000005000000B5FCC0559E90434075E95F92CACA4740B5FCC0559E904340DF4E22C2BFCC474082E3326E6A924340DF4E22C2BFCC474082E3326E6A92434075E95F92CACA4740B5FCC0559E90434075E95F92CACA4740
3606	Марфинка	2	23	431	38.509402000000001	38.539135999999999	47.606413000000003	47.585273000000001	0103000020E610000001000000050000002D42B11534414340AC1DC539EACA47402D42B11534414340446FF1F09ECD4740520C906802454340446FF1F09ECD4740520C906802454340AC1DC539EACA47402D42B11534414340AC1DC539EACA4740
3885	Малокирсановка	2	23	431	38.508315000000003	38.536549000000001	47.482326	47.457034999999998	0103000020E610000001000000050000007B884677104143404D10751F80BA47407B884677104143405801BEDBBCBD4740CBD93BA3AD4443405801BEDBBCBD4740CBD93BA3AD4443404D10751F80BA47407B884677104143404D10751F80BA4740
56953	Малоекатериновка	2	23	431	38.336719000000002	38.354460000000003	47.503428	47.500287	0103000020E610000001000000050000008E78B29B192B434096CE876709C047408E78B29B192B434002F2255470C04740BEDEFDF15E2D434002F2255470C04740BEDEFDF15E2D434096CE876709C047408E78B29B192B434096CE876709C04740
3533	Ленинский	2	23	431	38.631591	38.665348999999999	47.569864000000003	47.561225	0103000020E6100000010000000500000056B950F9D75043404B598638D6C7474056B950F9D75043407995B54DF1C8474091B6F1272A5543407995B54DF1C8474091B6F1272A5543404B598638D6C7474056B950F9D75043404B598638D6C74740
3934	Латоново	2	23	431	38.620263000000001	38.647050999999998	47.483987999999997	47.471716999999998	0103000020E610000001000000050000009DF529C7644F4340CEFBFF3861BC47409DF529C7644F434006D49B51F3BD47400BEC3191D252434006D49B51F3BD47400BEC3191D2524340CEFBFF3861BC47409DF529C7644F4340CEFBFF3861BC4740
3158	Кульбаково	2	23	431	38.910840999999998	38.942146999999999	47.693384999999999	47.684486999999997	0103000020E610000001000000050000008F6D197096744340C1C41F459DD747408F6D197096744340BB44F5D6C0D847402383DC4598784340BB44F5D6C0D847402383DC4598784340C1C41F459DD747408F6D197096744340C1C41F459DD74740
3385	Крынка	2	23	431	38.795470000000002	38.804201999999997	47.622073	47.604244000000001	0103000020E610000001000000050000007D7901F6D1654340F1660DDE57CD47407D7901F6D1654340C05C8B16A0CF47405BB05417F0664340C05C8B16A0CF47405BB05417F0664340F1660DDE57CD47407D7901F6D1654340F1660DDE57CD4740
2629	Красный Бумажник	2	23	431	38.795084000000003	38.804040000000001	47.575816000000003	47.572502999999998	0103000020E6100000010000000500000054C90050C565434052EE3EC747C9474054C90050C5654340BC41B456B4C94740825660C8EA664340BC41B456B4C94740825660C8EA66434052EE3EC747C9474054C90050C565434052EE3EC747C94740
4038	Красная Горка	2	23	431	38.680233999999999	38.692362000000003	47.433458000000002	47.418613000000001	0103000020E610000001000000050000004AD05FE81157434019575C1C95B547404AD05FE81157434044183F8D7BB74740207F69519F58434044183F8D7BB74740207F69519F58434019575C1C95B547404AD05FE81157434019575C1C95B54740
56780	Колесниково	2	23	431	38.878376000000003	38.889353	47.546227999999999	47.535832999999997	0103000020E61000000100000005000000B0CBF09F6E7043400C8FFD2C96C44740B0CBF09F6E7043406A1492CCEAC54740BCCCB051D67143406A1492CCEAC54740BCCCB051D67143400C8FFD2C96C44740B0CBF09F6E7043400C8FFD2C96C44740
2856	Каменно-Андрианово	2	23	431	38.979095000000001	39.042309000000003	47.514366000000003	47.497602000000001	0103000020E61000000100000005000000AC5626FC527D43404C361E6CB1BF4740AC5626FC527D43405116BEBED6C14740CAA99D616A8543405116BEBED6C14740CAA99D616A8543404C361E6CB1BF4740AC5626FC527D43404C361E6CB1BF4740
3695	Екатериновка	2	23	431	38.379973	38.393869000000002	47.554098000000003	47.525683999999998	0103000020E61000000100000005000000772E8CF4A2304340E603029D49C34740772E8CF4A2304340B763EAAEECC6474041F4A44C6A324340B763EAAEECC6474041F4A44C6A324340E603029D49C34740772E8CF4A2304340E603029D49C34740
3801	Григорьевка	2	23	431	38.380322999999997	38.394776999999998	47.456597000000002	47.432817999999997	0103000020E6100000010000000500000053758F6CAE304340608F899466B7474053758F6CAE304340D2393FC571BA4740431B800D88324340D2393FC571BA4740431B800D88324340608F899466B7474053758F6CAE304340608F899466B74740
3830	Греково-Тимофеевка	2	23	431	38.502825999999999	38.517226000000001	47.435146000000003	47.423375	0103000020E610000001000000050000000CCA349A5C404340D578E92631B647400CCA349A5C4043401C7E37DDB2B7474009522976344243401C7E37DDB2B747400952297634424340D578E92631B647400CCA349A5C404340D578E92631B64740
3082	Большая Кирсановка	2	23	431	38.882013999999998	38.909205999999998	47.666874999999997	47.645285999999999	0103000020E610000001000000050000009C4EB2D5E570434088484DBB98D247409C4EB2D5E57043408FC2F5285CD54740DAA9B9DC607443408FC2F5285CD54740DAA9B9DC6074434088484DBB98D247409C4EB2D5E570434088484DBB98D24740
3644	Анастасиевка	2	23	431	38.512627000000002	38.532964999999997	47.578667000000003	47.547243999999999	0103000020E61000000100000005000000F705F4C29D414340537765170CC64740F705F4C29D4143402123A0C211CA4740D1747632384443402123A0C211CA4740D174763238444340537765170CC64740F705F4C29D414340537765170CC64740
3268	Алексеевка	2	23	431	38.813769000000001	38.825626999999997	47.643476999999997	47.627367999999997	0103000020E61000000100000005000000D3BF249529684340494739984DD04740D3BF249529684340355D4F745DD24740E8D84125AE694340355D4F745DD24740E8D84125AE694340494739984DD04740D3BF249529684340494739984DD04740
30759	Александровка	2	23	431	38.784734999999998	38.803151	47.644666999999998	47.624684000000002	0103000020E6100000010000000500000066834C3272644340D02A33A5F5CF474066834C3272644340BCE7C07284D24740F65FE7A6CD664340BCE7C07284D24740F65FE7A6CD664340D02A33A5F5CF474066834C3272644340D02A33A5F5CF4740
56997	Авило-Федоровка	2	23	431	38.736190000000001	38.749583999999999	47.681362999999997	47.672572000000002	0103000020E6100000010000000500000035D252793B5E4340481ADCD616D6474035D252793B5E43402BDA1CE736D747406CCD565EF25F43402BDA1CE736D747406CCD565EF25F4340481ADCD616D6474035D252793B5E4340481ADCD616D64740
3430	Авило-Успенка	2	23	431	38.670074	38.684384999999999	47.699103999999998	47.681975999999999	0103000020E6100000010000000500000030F31DFCC4554340155454FD4AD7474030F31DFCC45543405B40683D7CD94740BD6F7CED995743405B40683D7CD94740BD6F7CED99574340155454FD4AD7474030F31DFCC4554340155454FD4AD74740
4100	Южный	2	23	406	41.853344999999997	41.877814999999998	47.345007000000003	47.333905000000001	0103000020E61000000100000005000000419AB1683AED4440467C2766BDAA4740419AB1683AED44400FF27A3029AC47401878EE3D5CF044400FF27A3029AC47401878EE3D5CF04440467C2766BDAA4740419AB1683AED4440467C2766BDAA4740
2273	Черемухи	2	23	406	41.221029000000001	41.235878999999997	47.443441	47.432166000000002	0103000020E61000000100000005000000DA3BA3AD4A9C4440B9382A3751B74740DA3BA3AD4A9C44404F5AB8ACC2B8474016687748319E44404F5AB8ACC2B8474016687748319E4440B9382A3751B74740DA3BA3AD4A9C4440B9382A3751B74740
4214	Центральный	2	23	406	41.848717999999998	41.855491000000001	47.372028999999998	47.362264000000003	0103000020E6100000010000000500000065C39ACAA2EC44405342B0AA5EAE474065C39ACAA2EC4440F01472A59EAF4740DC82A5BA80ED4440F01472A59EAF4740DC82A5BA80ED44405342B0AA5EAE474065C39ACAA2EC44405342B0AA5EAE4740
2506	Типчаковый	2	23	406	41.701546999999998	41.710099	47.161161999999997	47.151240999999999	0103000020E61000000100000005000000AFCDC64ACCD944403C6876DD5B934740AFCDC64ACCD94440D1ADD7F4A09447400EF62686E4DA4440D1ADD7F4A09447400EF62686E4DA44403C6876DD5B934740AFCDC64ACCD944403C6876DD5B934740
2630	Степной Маяк	2	23	406	41.882387000000001	41.897137000000001	47.157331999999997	47.145730999999998	0103000020E6100000010000000500000031B5A50EF2F04440B6813B50A792474031B5A50EF2F04440A04E7974239447400A849D62D5F24440A04E7974239447400A849D62D5F24440B6813B50A792474031B5A50EF2F04440B6813B50A7924740
2926	Сальский Кагальник	2	23	406	41.342616	41.365164	47.320224000000003	47.304864999999999	0103000020E610000001000000050000000D8B51D7DAAB4440F758FAD005A747400D8B51D7DAAB444079B29B19FDA8474099D6A6B1BDAE444079B29B19FDA8474099D6A6B1BDAE4440F758FAD005A747400D8B51D7DAAB4440F758FAD005A74740
56884	Пробуждение	2	23	406	41.836877999999999	41.851394999999997	47.315550999999999	47.306153999999999	0103000020E61000000100000005000000F65E7CD11EEB444011C5E40D30A74740F65E7CD11EEB44402C9CA4F963A847402C7DE882FAEC44402C9CA4F963A847402C7DE882FAEC444011C5E40D30A74740F65E7CD11EEB444011C5E40D30A74740
3698	Поречье	2	23	406	41.694755999999998	41.700702999999997	47.287624999999998	47.283132000000002	0103000020E610000001000000050000009259BDC3EDD84440BD395CAB3DA447409259BDC3EDD84440894160E5D0A44740C39ACAA2B0D94440894160E5D0A44740C39ACAA2B0D94440BD395CAB3DA447409259BDC3EDD84440BD395CAB3DA44740
56669	Новоселовка	2	23	406	41.469692000000002	41.492626000000001	47.278804000000001	47.262515	0103000020E61000000100000005000000AF9811DE1EBC4440CFDA6D179AA14740AF9811DE1EBC44403BFF76D9AFA347406494675E0EBF44403BFF76D9AFA347406494675E0EBF4440CFDA6D179AA14740AF9811DE1EBC4440CFDA6D179AA14740
56645	Новосадковский	2	23	406	41.290936000000002	41.313161000000001	47.208263000000002	47.187666999999998	0103000020E61000000100000005000000529D0E643DA54440EBC4E57805984740529D0E643DA54440C2FBAA5CA89A4740FBB0DEA815A84440C2FBAA5CA89A4740FBB0DEA815A84440EBC4E57805984740529D0E643DA54440EBC4E57805984740
57028	Новониколаевский	2	23	406	41.806749000000003	41.819899999999997	47.261512000000003	47.254131000000001	0103000020E61000000100000005000000558A1D8D43E744402CF3565D87A04740558A1D8D43E744407BC1A73979A14740C5FEB27BF2E844407BC1A73979A14740C5FEB27BF2E844402CF3565D87A04740558A1D8D43E744402CF3565D87A04740
3798	Новомартыновский	2	23	406	41.707835000000003	41.716422999999999	47.278723999999997	47.272970999999998	0103000020E610000001000000050000006AFB57569ADA4440D2E0B6B6F0A247406AFB57569ADA44401E4E603AADA34740158DB5BFB3DB44401E4E603AADA34740158DB5BFB3DB4440D2E0B6B6F0A247406AFB57569ADA4440D2E0B6B6F0A24740
3428	Новоберезовка	2	23	406	41.624758999999997	41.631227000000003	47.238520000000001	47.233980000000003	0103000020E61000000100000005000000DA70581AF8CF444084F57F0EF39D4740DA70581AF8CF444091B8C7D2879E474015ADDC0BCCD0444091B8C7D2879E474015ADDC0BCCD0444084F57F0EF39D4740DA70581AF8CF444084F57F0EF39D4740
56836	Несмеяновка	2	23	406	41.471803000000001	41.490271999999997	47.288314999999997	47.279366000000003	0103000020E61000000100000005000000CD936B0A64BC4440A3CEDC43C2A34740CD936B0A64BC44401EF98381E7A447407F129F3BC1BE44401EF98381E7A447407F129F3BC1BE4440A3CEDC43C2A34740CD936B0A64BC4440A3CEDC43C2A34740
56910	Московский	2	23	406	41.593164999999999	41.604591999999997	47.168984999999999	47.155132000000002	0103000020E61000000100000005000000E010AAD4ECCB44401348895DDB934740E010AAD4ECCB4440DD41EC4CA19547402CB6494563CD4440DD41EC4CA19547402CB6494563CD44401348895DDB934740E010AAD4ECCB44401348895DDB934740
56648	Малоорловский	2	23	406	41.378576000000002	41.404268000000002	47.297671999999999	47.282905999999997	0103000020E610000001000000050000007786A92D75B04440CCEB884336A447407786A92D75B04440AB77B81D1AA64740E068C70DBFB34440AB77B81D1AA64740E068C70DBFB34440CCEB884336A447407786A92D75B04440CCEB884336A44740
56682	Малая Мартыновка	2	23	406	41.821759999999998	41.844405999999999	47.339773999999998	47.322856999999999	0103000020E610000001000000050000009A94826E2FE944407024D06053A947409A94826E2FE94440FB03E5B67DAB4740E945ED7E15EC4440FB03E5B67DAB4740E945ED7E15EC44407024D06053A947409A94826E2FE944407024D06053A94740
2348	Малая Горка	2	23	406	41.326914000000002	41.341197000000001	47.430154000000002	47.420205000000003	0103000020E61000000100000005000000624D6551D8A94440CF4E0647C9B54740624D6551D8A944402E1F49490FB74740253FE257ACAB44402E1F49490FB74740253FE257ACAB4440CF4E0647C9B54740624D6551D8A94440CF4E0647C9B54740
56763	Лесной	2	23	406	41.443973	41.458947999999999	47.347423999999997	47.335456000000001	0103000020E610000001000000050000004CA7751BD4B844409D9FE238F0AA47404CA7751BD4B8444039ECBE6378AC47404548DDCEBEBA444039ECBE6378AC47404548DDCEBEBA44409D9FE238F0AA47404CA7751BD4B844409D9FE238F0AA4740
2793	Крутоярский	2	23	406	41.483283999999998	41.502346000000003	47.372621000000002	47.363106999999999	0103000020E610000001000000050000000C570740DCBD44406EF9484A7AAE47400C570740DCBD4440C366800BB2AF474062A3ACDF4CC04440C366800BB2AF474062A3ACDF4CC044406EF9484A7AAE47400C570740DCBD44406EF9484A7AAE4740
2167	Крутобережный	2	23	406	41.204993999999999	41.226894999999999	47.349744000000001	47.340012000000002	0103000020E6100000010000000500000028F04E3E3D9A4440B01F628385AB474028F04E3E3D9A444072FC5069C4AC47401E5036E50A9D444072FC5069C4AC47401E5036E50A9D4440B01F628385AB474028F04E3E3D9A4440B01F628385AB4740
56751	Кривой Лиман	2	23	406	41.740354000000004	41.751798999999998	47.251035999999999	47.241351999999999	0103000020E610000001000000050000003DBB7CEBC3DE44407F69519FE49E47403DBB7CEBC3DE4440300F99F221A047402F151BF33AE04440300F99F221A047402F151BF33AE044407F69519FE49E47403DBB7CEBC3DE44407F69519FE49E4740
56943	Красноармейский	2	23	406	41.421002999999999	41.433598000000003	47.256203999999997	47.243524000000001	0103000020E610000001000000050000004A42226DE3B5444043E55FCB2B9F47404A42226DE3B544405C8DEC4ACBA0474036CEA62380B744405C8DEC4ACBA0474036CEA62380B7444043E55FCB2B9F47404A42226DE3B5444043E55FCB2B9F4740
54884	Комаров	2	23	406	41.251446000000001	41.274776000000003	47.280974000000001	47.269962999999997	0103000020E61000000100000005000000E25AED612FA04440A510C8258EA24740E25AED612FA044405E83BEF4F6A34740E4DC26DC2BA344405E83BEF4F6A34740E4DC26DC2BA34440A510C8258EA24740E25AED612FA04440A510C8258EA24740
56721	Ильинов	2	23	406	41.928722	41.950839000000002	47.316564999999997	47.304315000000003	0103000020E61000000100000005000000B189CC5CE0F6444054573ECBF3A64740B189CC5CE0F644407407B13385A847407461A417B5F944407407B13385A847407461A417B5F9444054573ECBF3A64740B189CC5CE0F6444054573ECBF3A64740
2231	Зеленолугский	2	23	406	41.198104000000001	41.214596999999998	47.421424000000002	47.405912000000001	0103000020E61000000100000005000000789ACC785B994440E886A6ECF4B34740789ACC785B994440F0DFBC38F1B54740EC681CEA779B4440F0DFBC38F1B54740EC681CEA779B4440E886A6ECF4B34740789ACC785B994440E886A6ECF4B34740
56877	Засальский	2	23	406	41.749993000000003	41.762067000000002	47.309691999999998	47.298931000000003	0103000020E610000001000000050000004E9D47C5FFDF44405B61FA5E43A647404E9D47C5FFDF44409AEAC9FCA3A74740302E55698BE144409AEAC9FCA3A74740302E55698BE144405B61FA5E43A647404E9D47C5FFDF44405B61FA5E43A64740
56765	Долгий	2	23	406	41.334054999999999	41.349102000000002	47.263340999999997	47.254137	0103000020E610000001000000050000005B087250C2AA44400EDAAB8F87A047405B087250C2AA444014596B28B5A14740EE7BD45FAFAC444014596B28B5A14740EE7BD45FAFAC44400EDAAB8F87A047405B087250C2AA44400EDAAB8F87A04740
56768	Денисов	2	23	406	41.429223	41.449399	47.375464999999998	47.364102000000003	0103000020E6100000010000000500000073D87DC7F0B644404034F3E49AAE474073D87DC7F0B6444075E5B33C0FB0474074ED0BE885B9444075E5B33C0FB0474074ED0BE885B944404034F3E49AAE474073D87DC7F0B644404034F3E49AAE4740
3380	Гром-Гора	2	23	406	41.553029000000002	41.567914000000002	47.211502000000003	47.202734999999997	0103000020E61000000100000005000000AB5E7EA7C9C6444095607138F3994740AB5E7EA7C9C64440F1845E7F129B47406478EC67B1C84440F1845E7F129B47406478EC67B1C8444095607138F3994740AB5E7EA7C9C6444095607138F3994740
4312	Восход	2	23	406	41.846086	41.855410999999997	47.414302999999997	47.404953999999996	0103000020E610000001000000050000003ECDC98B4CEC444033315D88D5B347403ECDC98B4CEC44403DD175E107B54740BFD18E1B7EED44403DD175E107B54740BFD18E1B7EED444033315D88D5B347403ECDC98B4CEC444033315D88D5B34740
56959	Веселый	2	23	406	42.057414999999999	42.075228000000003	47.295484999999999	47.281951999999997	0103000020E6100000010000000500000061A6ED5F590745405985CD0017A4474061A6ED5F59074540B2BAD573D2A547402BDF3312A1094540B2BAD573D2A547402BDF3312A10945405985CD0017A4474061A6ED5F590745405985CD0017A44740
56641	Большая Орловка	2	23	406	41.255516	41.299928000000001	47.338265	47.316803	0103000020E6100000010000000500000068CD8FBFB4A0444029232E008DA8474068CD8FBFB4A04440D3307C444CAB4740CD936B0A64A64440D3307C444CAB4740CD936B0A64A6444029232E008DA8474068CD8FBFB4A0444029232E008DA84740
3161	Большая Мартыновка	2	23	406	41.652076999999998	41.682853000000001	47.293742999999999	47.258816000000003	0103000020E61000000100000005000000A5BC564277D344403DD7F7E120A14740A5BC564277D34440E736E15E99A54740DD7C23BA67D74440E736E15E99A54740DD7C23BA67D744403DD7F7E120A14740A5BC564277D344403DD7F7E120A14740
56722	Арбузов	2	23	406	41.663629	41.678154999999997	47.246245999999999	47.231563000000001	0103000020E61000000100000005000000AED689CBF1D4444059FB3BDBA39D4740AED689CBF1D44440AA622AFD849F4740374F75C8CDD64440AA622AFD849F4740374F75C8CDD6444059FB3BDBA39D4740AED689CBF1D4444059FB3BDBA39D4740
2398	Абрикосовый	2	23	406	41.250844000000001	41.265334000000003	47.409272000000001	47.400092999999998	0103000020E61000000100000005000000EC32FCA71BA04440E42D573F36B34740EC32FCA71BA0444092955F0663B447402942EA76F6A1444092955F0663B447402942EA76F6A14440E42D573F36B34740EC32FCA71BA04440E42D573F36B34740
20417	Свободный	2	23	141	38.818997000000003	38.840178999999999	47.787756000000002	47.783718	0103000020E61000000100000005000000D542C9E4D4684340ADA415DF50E44740D542C9E4D4684340289D4830D5E447409BE447FC8A6B4340289D4830D5E447409BE447FC8A6B4340ADA415DF50E44740D542C9E4D4684340ADA415DF50E44740
20237	Русское	2	23	141	38.932760000000002	38.949361000000003	47.750286000000003	47.740113000000001	0103000020E610000001000000050000002C82FFAD64774340172CD505BCDE47402C82FFAD64774340C652245F09E04740878C47A984794340C652245F09E04740878C47A984794340172CD505BCDE47402C82FFAD64774340172CD505BCDE4740
20698	Русско-Лютино	2	23	141	39.253162000000003	39.278593000000001	47.751958000000002	47.742972999999999	0103000020E61000000100000005000000844BC79C67A04340CF6740BD19DF4740844BC79C67A0434098FBE42840E0474080F277EFA8A3434098FBE42840E0474080F277EFA8A34340CF6740BD19DF4740844BC79C67A04340CF6740BD19DF4740
28961	Ольховский	2	23	141	38.855710999999999	38.867075	47.809485000000002	47.802743	0103000020E61000000100000005000000EAE923F0876D4340E50B5A48C0E64740EAE923F0876D434021CD58349DE74740F0164850FC6E434021CD58349DE74740F0164850FC6E4340E50B5A48C0E64740EAE923F0876D4340E50B5A48C0E64740
29068	Новоспасовка	2	23	141	39.067345000000003	39.090862999999999	47.709546000000003	47.701554000000002	0103000020E610000001000000050000004A46CEC29E88434062307F85CCD947404A46CEC29E884340FA804067D2DA47404EB51666A18B4340FA804067D2DA47404EB51666A18B434062307F85CCD947404A46CEC29E88434062307F85CCD94740
336	Новобахмутский	2	23	141	38.874414000000002	38.880378999999998	47.787126000000001	47.770105000000001	0103000020E61000000100000005000000109546CCEC6F434038BEF6CC92E24740109546CCEC6F434068EA758BC0E44740E78A5242B070434068EA758BC0E44740E78A5242B070434038BEF6CC92E24740109546CCEC6F434038BEF6CC92E24740
20341	Новиковка	2	23	141	39.067560999999998	39.089748999999998	47.746093999999999	47.739586000000003	0103000020E6100000010000000500000016BEBED6A58843402C4A09C1AADE474016BEBED6A5884340F4DE180280DF4740A2EC2DE57C8B4340F4DE180280DF4740A2EC2DE57C8B43402C4A09C1AADE474016BEBED6A58843402C4A09C1AADE4740
20453	Новая Надежда	2	23	141	39.056151999999997	39.080587000000001	47.854826000000003	47.837465000000002	0103000020E6100000010000000500000070CD1DFD2F874340B745990D32EB474070CD1DFD2F874340A0E238F06AED4740CBBDC0AC508A4340A0E238F06AED4740CBBDC0AC508A4340B745990D32EB474070CD1DFD2F874340B745990D32EB4740
20527	Миллерово	2	23	141	39.240684000000002	39.261012999999998	47.833927000000003	47.816673000000002	0103000020E61000000100000005000000D255BABBCE9E43405B43A9BD88E84740D255BABBCE9E43402E20B41EBEEA4740596ABDDF68A143402E20B41EBEEA4740596ABDDF68A143405B43A9BD88E84740D255BABBCE9E43405B43A9BD88E84740
20714	Лысогорка	2	23	141	39.190522000000001	39.217453999999996	47.712116999999999	47.692148000000003	0103000020E6100000010000000500000092955F0663984340F4FE3F4E98D8474092955F06639843407BF65CA626DB474033315D88D59B43407BF65CA626DB474033315D88D59B4340F4FE3F4E98D8474092955F0663984340F4FE3F4E98D84740
20120	Куйбышево	2	23	141	38.890431	38.932364999999997	47.827364000000003	47.796315	0103000020E610000001000000050000001B2C9CA4F9714340392861A6EDE547401B2C9CA4F9714340A2F14410E7E94740AF777FBC57774340A2F14410E7E94740AF777FBC57774340392861A6EDE547401B2C9CA4F9714340392861A6EDE54740
56719	Крюково	2	23	141	39.225924999999997	39.236310000000003	47.672207999999998	47.651992999999997	0103000020E61000000100000005000000A52C431CEB9C4340471CB28174D34740A52C431CEB9C4340060E68E90AD64740E0DBF4673F9E4340060E68E90AD64740E0DBF4673F9E4340471CB28174D34740A52C431CEB9C4340471CB28174D34740
56747	Кринично-Лугский	2	23	141	39.207473999999998	39.237791999999999	47.754956999999997	47.744414999999996	0103000020E6100000010000000500000099620E828E9A43406FD39FFD48DF474099620E828E9A43407171546EA2E047400EA0DFF76F9E43407171546EA2E047400EA0DFF76F9E43406FD39FFD48DF474099620E828E9A43406FD39FFD48DF4740
29017	Карташево	2	23	141	39.135007000000002	39.147035000000002	47.764097	47.758507000000002	0103000020E6100000010000000500000094DDCCE847914340BF64E3C116E1474094DDCCE84791434061FC34EECDE14740062FFA0AD292434061FC34EECDE14740062FFA0AD2924340BF64E3C116E1474094DDCCE847914340BF64E3C116E14740
8332	Каменно-Тузловка	2	23	141	39.155174000000002	39.163823999999998	47.823008000000002	47.817297000000003	0103000020E610000001000000050000004298DBBDDC934340390F27309DE847404298DBBDDC934340562C7E5358E947406326512FF8944340562C7E5358E947406326512FF8944340390F27309DE847404298DBBDDC934340390F27309DE84740
26269	Зайцево	2	23	141	39.356476999999998	39.367158000000003	47.725914000000003	47.720973999999998	0103000020E610000001000000050000005A63D009A1AD434016A243E048DC47405A63D009A1AD4340B2DAFCBFEADC47407E3B8908FFAE4340B2DAFCBFEADC47407E3B8908FFAE434016A243E048DC47405A63D009A1AD434016A243E048DC4740
16829	станция Замчалово	2	23	1337	40.050165	40.076791	48.125106000000002	48.108455999999997	0103000020E61000000100000005000000B13385CE6B0644400987DEE2E10D4840B13385CE6B064440464431790310484046D09849D4094440464431790310484046D09849D40944400987DEE2E10D4840B13385CE6B0644400987DEE2E10D4840
16887	Ясный	2	23	1337	40.015920999999999	40.025613999999997	48.076546999999998	48.070635000000003	0103000020E61000000100000005000000E92807B309024440FB7953910A094840E92807B309024440AFCDC64ACC094840ED28CE5147034440AFCDC64ACC094840ED28CE5147034440FB7953910A094840E92807B309024440FB7953910A094840
56831	Шахтенки	2	23	1337	39.785414000000003	39.801979000000003	47.779612	47.772007000000002	0103000020E6100000010000000500000008E9297288E443403CA41820D1E2474008E9297288E44340DAC87553CAE34740168A743FA7E64340DAC87553CAE34740168A743FA7E643403CA41820D1E2474008E9297288E443403CA41820D1E24740
18632	Чичерино	2	23	1337	40.137796000000002	40.162103999999999	48.142327999999999	48.130988000000002	0103000020E6100000010000000500000083C2A04CA31144409015FC36C410484083C2A04CA31144400DA7CCCD371248408046E9D2BF1444400DA7CCCD371248408046E9D2BF1444409015FC36C410484083C2A04CA31144409015FC36C4104840
57014	Черников	2	23	1337	39.767124000000003	39.786715999999998	47.830437000000003	47.815494000000001	0103000020E6100000010000000500000005FD851E31E24340C80A7E1B62E8474005FD851E31E24340B63176C24BEA4740B69E211CB3E44340B63176C24BEA4740B69E211CB3E44340C80A7E1B62E8474005FD851E31E24340C80A7E1B62E84740
56974	Чернецов	2	23	1337	40.468933	40.483134999999997	48.116425999999997	48.108257000000002	0103000020E61000000100000005000000F1811DFF053C44401348895DDB0D4840F1811DFF053C4440B933130CE70E4840C746205ED73D4440B933130CE70E4840C746205ED73D44401348895DDB0D4840F1811DFF053C44401348895DDB0D4840
56991	Чекунов	2	23	1337	40.534796999999998	40.557965000000003	48.124443999999997	48.113756000000002	0103000020E61000000100000005000000DC7F643A74444440A5DC7D8E8F0E4840DC7F643A744444407A17EFC7ED0F484005A8A9656B4744407A17EFC7ED0F484005A8A9656B474440A5DC7D8E8F0E4840DC7F643A74444440A5DC7D8E8F0E4840
56796	Украинский	2	23	1337	39.857405	39.868884999999999	47.976667999999997	47.960915999999997	0103000020E61000000100000005000000A4367172BFED4340001AA54BFFFA4740A4367172BFED43405D86FF7403FD4740137EA99F37EF43405D86FF7403FD4740137EA99F37EF4340001AA54BFFFA4740A4367172BFED4340001AA54BFFFA4740
16781	Углеродовский	2	23	1337	40.053184000000002	40.082962999999999	48.152102999999997	48.139220000000002	0103000020E61000000100000005000000D255BABBCE0644407D7901F6D1114840D255BABBCE064440CE4F711C7813484097E315889E0A4440CE4F711C7813484097E315889E0A44407D7901F6D1114840D255BABBCE0644407D7901F6D1114840
18368	Тополевый	2	23	1337	40.373764999999999	40.394309999999997	48.089483000000001	48.081417000000002	0103000020E61000000100000005000000D9B11188D72F4440522B4CDF6B0A4840D9B11188D72F44402446CF2D740B48402D3E05C0783244402446CF2D740B48402D3E05C078324440522B4CDF6B0A4840D9B11188D72F4440522B4CDF6B0A4840
19979	Табунщиково	2	23	1337	40.271707999999997	40.288991000000003	47.809987	47.794536000000001	0103000020E61000000100000005000000E107E753C722444051BF0B5BB3E54740E107E753C7224440B3976DA7ADE747404FEB36A8FD244440B3976DA7ADE747404FEB36A8FD24444051BF0B5BB3E54740E107E753C722444051BF0B5BB3E54740
56663	Садки	2	23	1337	40.458863000000001	40.474080000000001	47.902434999999997	47.895215999999998	0103000020E61000000100000005000000172CD505BC3A44408F6D197096F24740172CD505BC3A444004E275FD82F3474006D847A7AE3C444004E275FD82F3474006D847A7AE3C44408F6D197096F24740172CD505BC3A44408F6D197096F24740
19993	Рябиновка	2	23	1337	40.206516999999998	40.215212999999999	47.795867000000001	47.792344	0103000020E61000000100000005000000B58828266F1A4440469737876BE54740B58828266F1A44409A7B48F8DEE5474047567E198C1B44409A7B48F8DEE5474047567E198C1B4440469737876BE54740B58828266F1A4440469737876BE54740
57024	Русско-Прохоровский	2	23	1337	40.179918000000001	40.194074999999998	47.995773	47.986668000000002	0103000020E610000001000000050000001AFB928D071744403F0114234BFE47401AFB928D07174440B29E5A7D75FF474050FC1873D7184440B29E5A7D75FF474050FC1873D71844403F0114234BFE47401AFB928D071744403F0114234BFE4740
18585	Розет	2	23	1337	40.114852999999997	40.135711999999998	48.120227999999997	48.113112000000001	0103000020E610000001000000050000007A6CCB80B30E444080643A747A0E48407A6CCB80B30E4440200890A1630F48405ED6C4025F114440200890A1630F48405ED6C4025F11444080643A747A0E48407A6CCB80B30E444080643A747A0E4840
19356	Прохоровка	2	23	1337	40.263829999999999	40.294075999999997	47.890734000000002	47.875264000000001	0103000020E6100000010000000500000012DA722EC5214440DEAE97A608F0474012DA722EC5214440B7B75B9203F24740ED444948A4254440B7B75B9203F24740ED444948A4254440DEAE97A608F0474012DA722EC5214440DEAE97A608F04740
56655	Пролетарка	2	23	1337	40.183736000000003	40.211790000000001	47.887633999999998	47.880715000000002	0103000020E61000000100000005000000878C47A9841744405F0CE544BBF04740878C47A984174440A968ACFD9DF1474057CF49EF1B1B4440A968ACFD9DF1474057CF49EF1B1B44405F0CE544BBF04740878C47A9841744405F0CE544BBF04740
19852	Пригородный	2	23	1337	40.038775000000001	40.060217000000002	47.936197	47.918258999999999	0103000020E6100000010000000500000082734694F6044440FB20CB8289F5474082734694F604444081CEA44DD5F74740E5D4CE30B507444081CEA44DD5F74740E5D4CE30B5074440FB20CB8289F5474082734694F6044440FB20CB8289F54740
56646	Платово	2	23	1337	39.902724999999997	39.924211999999997	48.075372999999999	48.050196999999997	0103000020E610000001000000050000000B24287E8CF34340BCADF4DA6C0648400B24287E8CF343402E008DD2A50948400E492D944CF643402E008DD2A50948400E492D944CF64340BCADF4DA6C0648400B24287E8CF34340BCADF4DA6C064840
14336	Первомайский	2	23	1337	40.085056000000002	40.099204	48.042456000000001	48.025008	0103000020E610000001000000050000000F2A711DE30A4440B6114F76330348400F2A711DE30A44406EC2BD326F054840F2D077B7B20C44406EC2BD326F054840F2D077B7B20C4440B6114F76330348400F2A711DE30A4440B6114F7633034840
19511	Павловка	2	23	1337	39.811591	39.843767999999997	47.936776000000002	47.924326999999998	0103000020E610000001000000050000002D5DC136E2E74340A7E7DD5850F647402D5DC136E2E74340BFD6A546E8F74740A6B4FE9600EC4340BFD6A546E8F74740A6B4FE9600EC4340A7E7DD5850F647402D5DC136E2E74340A7E7DD5850F64740
18267	Октябрьский	2	23	1337	39.936573000000003	39.956730999999998	47.948436999999998	47.934590999999998	0103000020E6100000010000000500000087A8C29FE1F7434066118AADA0F7474087A8C29FE1F743407EA8346266F94740E108522976FA43407EA8346266F94740E108522976FA434066118AADA0F7474087A8C29FE1F7434066118AADA0F74740
56673	Новоровенецкий	2	23	1337	39.796481	39.821660999999999	48.018751999999999	48.003104	0103000020E610000001000000050000005471E316F3E543404F3E3DB6650048405471E316F3E54340075E2D776602484007B309302CE94340075E2D776602484007B309302CE943404F3E3DB6650048405471E316F3E543404F3E3DB665004840
56861	Нижняя Ковалевка	2	23	1337	39.933275999999999	39.976188999999998	48.131120000000003	48.109453999999999	0103000020E610000001000000050000002312859675F743404C35B396020E48402312859675F74340FFEC478AC810484083DBDAC2F3FC4340FFEC478AC810484083DBDAC2F3FC43404C35B396020E48402312859675F743404C35B396020E4840
25026	Молодежный	2	23	1337	40.260551	40.271887	48.050347000000002	48.045444000000003	0103000020E6100000010000000500000055F833BC5921444054E6E61BD105484055F833BC59214440D2393FC571064840919A7631CD224440D2393FC571064840919A7631CD22444054E6E61BD105484055F833BC5921444054E6E61BD1054840
56848	Молаканский	2	23	1337	40.079791999999998	40.086573999999999	48.039082999999998	48.030847000000001	0103000020E61000000100000005000000C03DCF9F360A4440011764CBF2034840C03DCF9F360A44402F6AF7AB000548408A5759DB140B44402F6AF7AB000548408A5759DB140B4440011764CBF2034840C03DCF9F360A4440011764CBF2034840
14780	Михайловка	2	23	1337	40.203004999999997	40.216973000000003	48.041758000000002	48.019916000000002	0103000020E6100000010000000500000055F65D11FC1944406555849B8C02484055F65D11FC194440562C7E5358054840B98E71C5C51B4440562C7E5358054840B98E71C5C51B44406555849B8C02484055F65D11FC1944406555849B8C024840
56696	Марс	2	23	1337	39.903703999999998	39.918373000000003	48.040035000000003	48.028604999999999	0103000020E61000000100000005000000D7A19A92ACF3434044C02154A9034840D7A19A92ACF3434002D9EBDD1F054840C443183F8DF5434002D9EBDD1F054840C443183F8DF5434044C02154A9034840D7A19A92ACF3434044C02154A9034840
56853	Малая Гнилуша	2	23	1337	40.160595000000001	40.172075999999997	47.939129999999999	47.926954000000002	0103000020E61000000100000005000000587380608E144440BD72BD6DA6F64740587380608E144440A3586E6935F8474097361C9606164440A3586E6935F8474097361C9606164440BD72BD6DA6F64740587380608E144440BD72BD6DA6F64740
56632	Лихой	2	23	1337	40.179487000000002	40.218086999999997	48.134583999999997	48.114452999999997	0103000020E610000001000000050000005187156EF9164440ECF65965A60E48405187156EF91644404D486B0C3A11484064575A46EA1B44404D486B0C3A11484064575A46EA1B4440ECF65965A60E48405187156EF9164440ECF65965A60E4840
16973	Красный Сулин	2	23	1337	39.992026000000003	40.138658	47.916677	47.850557999999999	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
56813	Коминтерн	2	23	1337	39.848430999999998	39.860477000000003	48.006504	48.000753000000003	0103000020E61000000100000005000000CFF4126399EC4340DC2F9FAC18004840CFF4126399EC434087A5811FD5004840E8FA3E1C24EE434087A5811FD5004840E8FA3E1C24EE4340DC2F9FAC18004840CFF4126399EC4340DC2F9FAC18004840
19518	Киселево	2	23	1337	39.875093	39.893248	47.894002	47.876472999999997	0103000020E61000000100000005000000B1FA230C03F04340DB696B4430F04740B1FA230C03F04340804754A86EF24740D49B51F355F24340804754A86EF24740D49B51F355F24340DB696B4430F04740B1FA230C03F04340DB696B4430F04740
56930	Зайцевка	2	23	1337	40.499395	40.515897000000002	47.994362000000002	47.984876	0103000020E610000001000000050000009964E42CEC3F4440C24EB16A10FE47409964E42CEC3F44404D31074147FF4740618DB3E9084244404D31074147FF4740618DB3E908424440C24EB16A10FE47409964E42CEC3F4440C24EB16A10FE4740
56905	Дудкино	2	23	1337	40.540035000000003	40.549196999999999	47.898375999999999	47.891796999999997	0103000020E6100000010000000500000002D9EBDD1F454440E0D5726726F2474002D9EBDD1F45444072C119FCFDF24740D90759164C46444072C119FCFDF24740D90759164C464440E0D5726726F2474002D9EBDD1F454440E0D5726726F24740
56952	Долотинка	2	23	1337	40.040166999999997	40.060612999999996	48.009264999999999	47.986704000000003	0103000020E6100000010000000500000070B03731240544408C6A11514CFE474070B0373124054440ACFF73982F014840315BB22AC2074440ACFF73982F014840315BB22AC20744408C6A11514CFE474070B03731240544408C6A11514CFE4740
56681	Гуково	2	23	1337	39.930213000000002	39.960720000000002	47.993505999999996	47.972053000000002	0103000020E6100000010000000500000033A8363811F74340467D923B6CFC474033A8363811F743409C3061342BFF47407B4E7ADFF8FA43409C3061342BFF47407B4E7ADFF8FA4340467D923B6CFC474033A8363811F74340467D923B6CFC4740
56926	Гривенный	2	23	1337	40.334752000000002	40.349725999999997	47.849663	47.836564000000003	0103000020E61000000100000005000000A3224E27D92A44406781768714EB4740A3224E27D92A444085CFD6C1C1EC4740CB4752D2C32C444085CFD6C1C1EC4740CB4752D2C32C44406781768714EB4740A3224E27D92A44406781768714EB4740
17410	Горный	2	23	1337	39.711841999999997	40.609977000000001	48.190980000000003	47.727884000000003	0103000020E61000000100000005000000A9F57EA31DDB43400EA48B4D2BDD4740A9F57EA31DDB434055185B0872184840F627F1B9134E444055185B0872184840F627F1B9134E44400EA48B4D2BDD4740A9F57EA31DDB43400EA48B4D2BDD4740
18482	Владимировская	2	23	1337	40.287571999999997	40.308017999999997	47.939751999999999	47.930062999999997	0103000020E61000000100000005000000669FC728CF2444401D1CEC4D0CF74740669FC728CF244440E02C25CB49F84740274A42226D274440E02C25CB49F84740274A42226D2744401D1CEC4D0CF74740669FC728CF2444401D1CEC4D0CF74740
56772	Большая Федоровка	2	23	1337	40.353248000000001	40.372957	47.981426999999996	47.969465	0103000020E610000001000000050000004FB0FF3A372D4440EECEDA6D17FC47404FB0FF3A372D4440A83462669FFD47403AE8120EBD2F4440A83462669FFD47403AE8120EBD2F4440EECEDA6D17FC47404FB0FF3A372D4440EECEDA6D17FC4740
18782	Хрящевский	2	23	182	40.93479	40.959735999999999	47.721774000000003	47.709043000000001	0103000020E610000001000000050000005D50DF32A7774440973AC8EBC1DA47405D50DF32A7774440338D261763DC47409D6516A1D87A4440338D261763DC47409D6516A1D87A4440973AC8EBC1DA47405D50DF32A7774440973AC8EBC1DA4740
27658	Холмистый	2	23	182	41.292616000000002	41.303908	47.792223	47.780957000000001	0103000020E61000000100000005000000A724EB7074A54440884A2366F6E34740A724EB7074A54440CB11329067E54740137F1475E6A64440CB11329067E54740137F1475E6A64440884A2366F6E34740A724EB7074A54440884A2366F6E34740
19164	Упраздно-Кагальницкий	2	23	182	41.216143000000002	41.240900000000003	47.646025999999999	47.635572000000003	0103000020E610000001000000050000003221E692AA9B44406D205D6C5AD147403221E692AA9B4440CF2EDFFAB0D247409FCDAACFD59E4440CF2EDFFAB0D247409FCDAACFD59E44406D205D6C5AD147403221E692AA9B44406D205D6C5AD14740
27441	Трофимов	2	23	182	41.278477000000002	41.294476000000003	47.878062	47.865043	0103000020E6100000010000000500000017D86322A5A344401E51A1BAB9EE474017D86322A5A3444020EEEA5564F047407CBABA63B1A5444020EEEA5564F047407CBABA63B1A544401E51A1BAB9EE474017D86322A5A344401E51A1BAB9EE4740
27616	Суворов	2	23	182	41.690345000000001	41.708069000000002	47.818482000000003	47.810895000000002	0103000020E6100000010000000500000083FA96395DD84440B6BE4868CBE7474083FA96395DD84440AE2EA704C4E84740DD274701A2DA4440AE2EA704C4E84740DD274701A2DA4440B6BE4868CBE7474083FA96395DD84440B6BE4868CBE74740
19593	Стычновский	2	23	182	41.511518000000002	41.530768000000002	47.893614999999997	47.875433000000001	0103000020E610000001000000050000005DA8FC6B79C144406A6B44300EF047405DA8FC6B79C14440861BF0F961F24740B5E1B034F0C34440861BF0F961F24740B5E1B034F0C344406A6B44300EF047405DA8FC6B79C144406A6B44300EF04740
56801	Старая Станица	2	23	182	41.456980999999999	41.476464999999997	47.600501999999999	47.596066	0103000020E610000001000000050000005AF2785A7EBA4440F72004E44BCC47405AF2785A7EBA44405F97E13FDDCC474025581CCEFCBC44405F97E13FDDCC474025581CCEFCBC4440F72004E44BCC47405AF2785A7EBA4440F72004E44BCC4740
19536	Савельев	2	23	182	41.422566000000003	41.437865000000002	47.711182999999998	47.699995999999999	0103000020E61000000100000005000000663387A416B6444058AA0B7899D94740663387A416B644404F3C670B08DB47401288D7F50BB844404F3C670B08DB47401288D7F50BB8444058AA0B7899D94740663387A416B6444058AA0B7899D94740
27541	Правда	2	23	182	41.754143999999997	41.770932999999999	47.620773	47.612870999999998	0103000020E61000000100000005000000C03C64CA87E044405AD5928E72CE4740C03C64CA87E04440B29E5A7D75CF47401E34BBEEADE24440B29E5A7D75CF47401E34BBEEADE244405AD5928E72CE4740C03C64CA87E044405AD5928E72CE4740
18881	Почтовый	2	23	182	41.039363000000002	41.057617	47.844074999999997	47.833624	0103000020E6100000010000000500000013D6C6D8098544409294F430B4EA474013D6C6D809854440832F4CA60AEC4740C9586DFE5F874440832F4CA60AEC4740C9586DFE5F8744409294F430B4EA474013D6C6D8098544409294F430B4EA4740
584	Новая Жизнь	2	23	182	41.387900000000002	41.396963999999997	47.646875999999999	47.641770999999999	0103000020E61000000100000005000000280F0BB5A6B14440B742588D25D24740280F0BB5A6B144409D4830D5CCD247403CD862B7CFB244409D4830D5CCD247403CD862B7CFB24440B742588D25D24740280F0BB5A6B14440B742588D25D24740
19247	Николаевская	2	23	182	41.480499000000002	41.553154999999997	47.624203999999999	47.588835000000003	0103000020E610000001000000050000005F61C1FD80BD4440BEDEFDF15ECB47405F61C1FD80BD44402504ABEAE5CF4740374F75C8CDC644402504ABEAE5CF4740374F75C8CDC64440BEDEFDF15ECB47405F61C1FD80BD4440BEDEFDF15ECB4740
18916	Нижнекалинов	2	23	182	41.016258000000001	41.047016999999997	47.909623000000003	47.894866	0103000020E610000001000000050000003126FDBD14824440B32616F88AF247403126FDBD148244403F58C6866EF4474092AD2EA7048644403F58C6866EF4474092AD2EA704864440B32616F88AF247403126FDBD14824440B32616F88AF24740
18644	Нижнежуравский	2	23	182	41.058110999999997	41.084215999999998	47.728914000000003	47.710534000000003	0103000020E61000000100000005000000D844662E70874440195932C7F2DA4740D844662E708744405CCCCF0D4DDD474064E60297C78A44405CCCCF0D4DDD474064E60297C78A4440195932C7F2DA4740D844662E70874440195932C7F2DA4740
18813	Михайловский	2	23	182	40.958820000000003	40.970615000000002	47.676813000000003	47.666055	0103000020E6100000010000000500000018601F9DBA7A44402C2B4D4A41D5474018601F9DBA7A4440FB40F2CEA1D64740E700C11C3D7C4440FB40F2CEA1D64740E700C11C3D7C44402C2B4D4A41D5474018601F9DBA7A44402C2B4D4A41D54740
19321	Мариинская	2	23	182	41.694324999999999	41.722279999999998	47.607823000000003	47.600282999999997	0103000020E61000000100000005000000C9E53FA4DFD8444021ACC612D6CC4740C9E53FA4DFD84440D960E124CDCD47400647C9AB73DC4440D960E124CDCD47400647C9AB73DC444021ACC612D6CC4740C9E53FA4DFD8444021ACC612D6CC4740
19427	Лисичкин	2	23	182	41.306657000000001	41.314481000000001	47.757865000000002	47.750104999999998	0103000020E61000000100000005000000740B5D8940A7444075C8CD7003E04740740B5D8940A744403BE466B801E14740501BD5E940A844403BE466B801E14740501BD5E940A8444075C8CD7003E04740740B5D8940A7444075C8CD7003E04740
18975	Крюков	2	23	182	41.272376999999999	41.290137000000001	47.842393999999999	47.830593999999998	0103000020E610000001000000050000005F97E13FDDA244407D2079E750EA47405F97E13FDDA244405E2C0C91D3EB4740062E8F3523A544405E2C0C91D3EB4740062E8F3523A544407D2079E750EA47405F97E13FDDA244407D2079E750EA4740
27518	Кременской	2	23	182	41.102434000000002	41.136606	47.831175000000002	47.809303	0103000020E61000000100000005000000CEFFAB8E1C8D444000C79E3D97E74740CEFFAB8E1C8D44405C2041F163EA4740FC372F4E7C9144405C2041F163EA4740FC372F4E7C91444000C79E3D97E74740CEFFAB8E1C8D444000C79E3D97E74740
18724	Костино-Горский	2	23	182	40.891905000000001	40.901184000000001	47.629955000000002	47.622630999999998	0103000020E61000000100000005000000C7116BF129724440E63C635FB2CF4740C7116BF129724440D1798D5DA2D04740D8D64FFF59734440D1798D5DA2D04740D8D64FFF59734440E63C635FB2CF4740C7116BF129724440E63C635FB2CF4740
18084	Константиновск	2	23	182	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
25535	Кастырский	2	23	182	41.262981000000003	41.295265999999998	47.638936000000001	47.625844000000001	0103000020E61000000100000005000000153C855CA9A14440EC32FCA71BD04740153C855CA9A14440581EA4A7C8D1474074CFBA46CBA54440581EA4A7C8D1474074CFBA46CBA54440EC32FCA71BD04740153C855CA9A14440EC32FCA71BD04740
19093	Камышный	2	23	182	41.182949999999998	41.199002999999998	47.633975	47.618755999999998	0103000020E61000000100000005000000CF66D5E76A974440151A886533CF4740CF66D5E76A974440A5BDC11726D14740276728EE78994440A5BDC11726D14740276728EE78994440151A886533CF4740CF66D5E76A974440151A886533CF4740
19677	Ермилов	2	23	182	41.469054	41.481836999999999	47.782705999999997	47.772920999999997	0103000020E610000001000000050000006C0723F609BC444020B24813EFE247406C0723F609BC44400531D0B52FE447405A80B6D5ACBD44400531D0B52FE447405A80B6D5ACBD444020B24813EFE247406C0723F609BC444020B24813EFE24740
19379	Гапкин	2	23	182	41.413097999999998	41.439346999999998	47.724114	47.709522	0103000020E6100000010000000500000081053065E0B4444071E5EC9DD1DA474081053065E0B44440B2497EC4AFDC4740404CC2853CB84440B2497EC4AFDC4740404CC2853CB8444071E5EC9DD1DA474081053065E0B4444071E5EC9DD1DA4740
19768	Вифлянцев	2	23	182	41.501204999999999	41.513027000000001	47.901311999999997	47.890625	0103000020E61000000100000005000000BCCB457C27C044400000000000F24740BCCB457C27C0444005BF0D315EF34740857B65DEAAC1444005BF0D315EF34740857B65DEAAC144400000000000F24740BCCB457C27C044400000000000F24740
27293	Верхнепотапов	2	23	182	41.039937999999999	41.059243000000002	47.893495000000001	47.878812000000003	0103000020E610000001000000050000000FEF39B01C8544408BAA5FE97CF047400FEF39B01C854440DC114E0B5EF247402BC24D4695874440DC114E0B5EF247402BC24D46958744408BAA5FE97CF047400FEF39B01C8544408BAA5FE97CF04740
18630	Ведерников	2	23	182	41.141447999999997	41.155911000000003	47.585965999999999	47.576380999999998	0103000020E61000000100000005000000D40AD3F71A924440948444DAC6C94740D40AD3F71A924440B24813EF00CB4740180B43E4F4934440B24813EF00CB4740180B43E4F4934440948444DAC6C94740D40AD3F71A924440948444DAC6C94740
19017	Богоявленская	2	23	182	41.32076	41.359127000000001	47.659896000000003	47.638286000000001	0103000020E61000000100000005000000B7EEE6A90EA9444051BF0B5BB3D14740B7EEE6A90EA944407061DD7877D44740280EA0DFF7AD44407061DD7877D44740280EA0DFF7AD444051BF0B5BB3D14740B7EEE6A90EA9444051BF0B5BB3D14740
19478	Белянский	2	23	182	41.546084999999998	41.570663000000003	47.762396000000003	47.748722999999998	0103000020E6100000010000000500000007EBFF1CE6C54440AA61BF27D6DF474007EBFF1CE6C54440F54C2F3196E14740C504357C0BC94440F54C2F3196E14740C504357C0BC94440AA61BF27D6DF474007EBFF1CE6C54440AA61BF27D6DF4740
27686	Белоковыльный	2	23	182	41.670788999999999	41.686005999999999	47.809116000000003	47.801563000000002	0103000020E610000001000000050000001EC2F869DCD544408257CB9D99E647401EC2F869DCD54440CE55F31C91E747400D6E6B0BCFD74440CE55F31C91E747400D6E6B0BCFD744408257CB9D99E647401EC2F869DCD544408257CB9D99E64740
27365	Базки	2	23	182	41.059215999999999	41.072259000000003	47.818185999999997	47.810495000000003	0103000020E6100000010000000500000031B3CF63948744402849D74CBEE7474031B3CF6394874440C405A051BAE84740BCEB6CC83F894440C405A051BAE84740BCEB6CC83F8944402849D74CBEE7474031B3CF63948744402849D74CBEE74740
27273	Авилов	2	23	182	41.035240000000002	41.055326000000001	47.702682000000003	47.686653	0103000020E610000001000000050000006AC18BBE82844440A359D93EE4D747406AC18BBE8284444073BED87BF1D947402B4F20EC1487444073BED87BF1D947402B4F20EC14874440A359D93EE4D747406AC18BBE82844440A359D93EE4D74740
24374	Шалаевка	2	23	1731	41.297978999999998	41.360698999999997	49.136369999999999	49.108463999999998	0103000020E6100000010000000500000088F2052D24A644408C65FA25E28D484088F2052D24A64440E813799274914840965984622BAE4440E813799274914840965984622BAE44408C65FA25E28D484088F2052D24A644408C65FA25E28D4840
25022	Чернигово-Песчаный	2	23	1731	41.266160999999997	41.307375	48.801048000000002	48.783307000000001	0103000020E610000001000000050000003E3C4B9011A244402BDD5D67436448403E3C4B9011A244405B43A9BD88664840D34D621058A744405B43A9BD88664840D34D621058A744402BDD5D67436448403E3C4B9011A244402BDD5D6743644840
24573	Усть-Мечетка	2	23	1731	41.142831000000001	41.158721999999997	48.975434999999997	48.960867999999998	0103000020E6100000010000000500000070ED444948924440EFE2FDB8FD7A484070ED444948924440D72FD80DDB7C4840EE93A30051944440D72FD80DDB7C4840EE93A30051944440EFE2FDB8FD7A484070ED444948924440EFE2FDB8FD7A4840
25498	Третий Интернационал	2	23	1731	41.210025000000002	41.234997999999997	49.100648999999997	49.083044999999998	0103000020E61000000100000005000000D42B6519E29A4440548CF337A18A4840D42B6519E29A444003B00111E28C48400D501A6A149E444003B00111E28C48400D501A6A149E4440548CF337A18A4840D42B6519E29A4440548CF337A18A4840
25339	Теплые Ключи	2	23	1731	41.699157999999997	41.737425999999999	48.983749000000003	48.970993999999997	0103000020E610000001000000050000004E5E64027ED944405D4E0988497C48404E5E64027ED94440823CBB7CEB7D48402C9CA4F963DE4440823CBB7CEB7D48402C9CA4F963DE44405D4E0988497C48404E5E64027ED944405D4E0988497C4840
24590	Талловеров	2	23	1731	41.258614999999999	41.312496000000003	49.021166999999998	49.004964999999999	0103000020E61000000100000005000000A5A0DB4B1AA14440F44F70B1A2804840A5A0DB4B1AA144409160AA99B5824840BF1072DEFFA744409160AA99B5824840BF1072DEFFA74440F44F70B1A2804840A5A0DB4B1AA14440F44F70B1A2804840
24774	Сергеевка	2	23	1731	41.145580000000002	41.169339999999998	48.862476999999998	48.832697000000003	0103000020E61000000100000005000000D1798D5DA2924440193DB7D0956A4840D1798D5DA2924440AE4676A5656E4840CBF3E0EEAC954440AE4676A5656E4840CBF3E0EEAC954440193DB7D0956A4840D1798D5DA2924440193DB7D0956A4840
24848	Сариновка	2	23	1731	41.130065999999999	41.150575000000003	48.832917000000002	48.801077999999997	0103000020E610000001000000050000002829B000A6904440C5C551B9896648402829B000A690444027A435069D6A4840304CA60A4693444027A435069D6A4840304CA60A46934440C5C551B9896648402829B000A6904440C5C551B989664840
25118	Россошь	2	23	1731	41.330866	41.372278999999999	48.928401000000001	48.893590000000003	0103000020E61000000100000005000000DEAD2CD159AA44402E04392861724840DEAD2CD159AA44406F490ED8D576484069FE98D6A6AF44406F490ED8D576484069FE98D6A6AF44402E04392861724840DEAD2CD159AA44402E04392861724840
56819	Речка	2	23	1731	41.014839000000002	41.063167999999997	49.239646999999998	49.178190000000001	0103000020E6100000010000000500000049DA8D3EE6814440B43C0FEECE96484049DA8D3EE6814440D1CABDC0AC9E4840AD1397E315884440D1CABDC0AC9E4840AD1397E315884440B43C0FEECE96484049DA8D3EE6814440B43C0FEECE964840
24257	Поповка	2	23	1731	41.20026	41.259486000000003	49.255578	49.230800000000002	0103000020E610000001000000050000003659A31EA29944405AF5B9DA8A9D48403659A31EA2994440DEC9A7C7B6A048408BE255D636A14440DEC9A7C7B6A048408BE255D636A144405AF5B9DA8A9D48403659A31EA29944405AF5B9DA8A9D4840
25403	Пономарев	2	23	1731	41.467841	41.508795999999997	49.066313999999998	49.048721	0103000020E610000001000000050000002D5DC136E2BB444070D05E7D3C8648402D5DC136E2BB44402BA226FA7C884840F52A323A20C144402BA226FA7C884840F52A323A20C1444070D05E7D3C8648402D5DC136E2BB444070D05E7D3C864840
24948	Первомайское	2	23	1731	41.215423999999999	41.246811000000001	48.834831999999999	48.818277999999999	0103000020E6100000010000000500000002637D03939B4440A5846055BD68484002637D03939B4440BFD364C6DB6A484083A5BA80979F4440BFD364C6DB6A484083A5BA80979F4440A5846055BD68484002637D03939B4440A5846055BD684840
24153	Ольховый	2	23	1731	40.976238000000002	41.009053999999999	49.321032000000002	49.290793000000001	0103000020E61000000100000005000000658EE55DF57C4440EF737CB438A54840658EE55DF57C4440187C9A9317A94840F1F274AE28814440187C9A9317A94840F1F274AE28814440EF737CB438A54840658EE55DF57C4440EF737CB438A54840
23983	Новочигириновский	2	23	1731	41.100879999999997	41.159754999999997	49.187846999999998	49.150148999999999	0103000020E610000001000000050000000569C6A2E98C444078431A15389348400569C6A2E98C44406BD3D85E0B984840AD2F12DA729444406BD3D85E0B984840AD2F12DA7294444078431A15389348400569C6A2E98C444078431A1538934840
23809	Новопавловка	2	23	1731	41.019699000000003	41.054572	49.125157000000002	49.094019000000003	0103000020E61000000100000005000000C861307F85824440F01989D0088C4840C861307F85824440C8EE0225059048407FA31D37FC864440C8EE0225059048407FA31D37FC864440F01989D0088C4840C861307F85824440F01989D0088C4840
52874	Нижний Астахов	2	23	1731	41.374173999999996	41.445042000000001	49.17548	49.154432	0103000020E61000000100000005000000BA8102EFE4AF44405ABA826DC4934840BA8102EFE4AF4440118DEE207696484058ACE122F7B84440118DEE207696484058ACE122F7B844405ABA826DC4934840BA8102EFE4AF44405ABA826DC4934840
24958	Михайловка	2	23	1731	41.443936999999998	41.461570999999999	48.967320999999998	48.959727000000001	0103000020E61000000100000005000000FF3D78EDD2B844404A0B9755D87A4840FF3D78EDD2B84440F4DDAD2CD17B484019E42EC214BB4440F4DDAD2CD17B484019E42EC214BB44404A0B9755D87A4840FF3D78EDD2B844404A0B9755D87A4840
23860	Лысогорка	2	23	1731	40.932850000000002	40.957652000000003	48.962229000000001	48.949888000000001	0103000020E610000001000000050000006C09F9A067774440726E13EE957948406C09F9A067774440A321E3512A7B484079793A57947A4440A321E3512A7B484079793A57947A4440726E13EE957948406C09F9A067774440726E13EE95794840
24700	Ленинский	2	23	1731	41.093091000000001	41.130946000000002	48.938763999999999	48.930016999999999	0103000020E61000000100000005000000A646E867EA8B4440ADDC0BCC0A774840A646E867EA8B4440C154336B2978484061C5A9D6C2904440C154336B2978484061C5A9D6C2904440ADDC0BCC0A774840A646E867EA8B4440ADDC0BCC0A774840
25408	Красный Колос	2	23	1731	41.122340000000001	41.141644999999997	49.054436000000003	49.043483000000002	0103000020E610000001000000050000000F7F4DD6A88F44404B77D7D9908548400F7F4DD6A88F4440CFDC43C2F78648402A52616C21924440CFDC43C2F78648402A52616C219244404B77D7D9908548400F7F4DD6A88F44404B77D7D990854840
25200	Краснояровка	2	23	1731	41.232618000000002	41.260052000000002	48.873471000000002	48.862377000000002	0103000020E61000000100000005000000003B376DC69D44404BE9995E626E4840003B376DC69D44409180D1E5CD6F484034A1496249A144409180D1E5CD6F484034A1496249A144404BE9995E626E4840003B376DC69D44404BE9995E626E4840
23589	Кашары	2	23	1731	40.970229000000003	41.052694000000002	49.071477999999999	49.016345999999999	0103000020E61000000100000005000000BE50C076307C4440D0B52FA017824840BE50C076307C44401631EC302689484004594FADBE8644401631EC302689484004594FADBE864440D0B52FA017824840BE50C076307C4440D0B52FA017824840
24297	Каменка	2	23	1731	41.308731999999999	41.328333000000001	49.275883999999998	49.259687999999997	0103000020E61000000100000005000000459DB98784A74440F294D5743DA14840459DB98784A74440ADBEBA2A50A348404A99D4D006AA4440ADBEBA2A50A348404A99D4D006AA4440F294D5743DA14840459DB98784A74440F294D5743DA14840
25255	Калашников	2	23	1731	41.40813	41.444808999999999	48.971809999999998	48.957147999999997	0103000020E610000001000000050000001C42959A3DB4444045B75ED3837A48401C42959A3DB444407FF62345647C4840B5FB5580EFB844407FF62345647C4840B5FB5580EFB8444045B75ED3837A48401C42959A3DB4444045B75ED3837A4840
25054	Индустриальный	2	23	1731	41.156799999999997	41.194304000000002	48.738318999999997	48.711936000000001	0103000020E61000000100000005000000A301BC05129444402B6C06B8205B4840A301BC0512944440F981AB3C815E4840B2BD16F4DE984440F981AB3C815E4840B2BD16F4DE9844402B6C06B8205B4840A301BC05129444402B6C06B8205B4840
24204	Дибровый	2	23	1731	41.167427000000004	41.202264	49.218220000000002	49.199168999999998	0103000020E61000000100000005000000D4BB783F6E95444042B0AA5E7E994840D4BB783F6E954440A4AA09A2EE9B48403E9468C9E3994440A4AA09A2EE9B48403E9468C9E399444042B0AA5E7E994840D4BB783F6E95444042B0AA5E7E994840
24122	Вяжа	2	23	1731	41.014659000000002	41.086227999999998	49.292473000000001	49.239888000000001	0103000020E61000000100000005000000C9CB9A58E0814440F75965A6B49E4840C9CB9A58E081444044FB58C16FA54840EFFFE384098B444044FB58C16FA54840EFFFE384098B4440F75965A6B49E4840C9CB9A58E0814440F75965A6B49E4840
24514	Второй Киевский	2	23	1731	41.143047000000003	41.181125999999999	49.065269000000001	49.045827000000003	0103000020E610000001000000050000003D65355D4F9244400C23BDA8DD8548403D65355D4F924440A8380EBC5A884840473A03232F974440A8380EBC5A884840473A03232F9744400C23BDA8DD8548403D65355D4F9244400C23BDA8DD854840
24679	Вишневка	2	23	1731	41.133192000000001	41.146281000000002	48.912357	48.900543999999996	0103000020E610000001000000050000005F0B7A6F0C914440F44D9A06457348405F0B7A6F0C9144406AA33A1DC87448405A83F755B99244406AA33A1DC87448405A83F755B9924440F44D9A06457348405F0B7A6F0C914440F44D9A0645734840
25283	Верхнесвечниково	2	23	1731	41.555436	41.596066999999998	48.991416999999998	48.976098	0103000020E61000000100000005000000B282DF8618C7444073D87DC7F07C4840B282DF8618C7444066D993C0E67E4840C79C67EC4BCC444066D993C0E67E4840C79C67EC4BCC444073D87DC7F07C4840B282DF8618C7444073D87DC7F07C4840
23967	Верхнемакеевка	2	23	1731	41.058219000000001	41.092480000000002	49.191409	49.153384000000003	0103000020E61000000100000005000000BF805EB87387444066DD3F16A2934840BF805EB8738744407D941117809848405DC47762D68B44407D941117809848405DC47762D68B444066DD3F16A2934840BF805EB87387444066DD3F16A2934840
23903	Верхнекалиновка	2	23	1731	40.948534000000002	40.973695999999997	49.010466999999998	48.979787999999999	0103000020E610000001000000050000007192E68F69794440B28174B1697D48407192E68F69794440F7578FFB568148407D1F0E12A27C4440F7578FFB568148407D1F0E12A27C4440B28174B1697D48407192E68F69794440B28174B1697D4840
24389	Верхнегреково	2	23	1731	41.345939999999999	41.391286999999998	49.153973000000001	49.138545000000001	0103000020E610000001000000050000006A300DC347AC44401D03B2D7BB9148406A300DC347AC4440C7BB2363B5934840CB2C42B115B24440C7BB2363B5934840CB2C42B115B244401D03B2D7BB9148406A300DC347AC44401D03B2D7BB914840
19591	станция Репная	2	23	1602	40.480243000000002	40.496592	48.189737000000001	48.184505000000001	0103000020E610000001000000050000000491459A783D444068791EDC9D1748400491459A783D4440ABEB504D4918484045BA9F53903F4440ABEB504D4918484045BA9F53903F444068791EDC9D1748400491459A783D444068791EDC9D174840
21571	Чистоозерный	2	23	1602	40.420189999999998	40.441192999999998	48.267896	48.249654	0103000020E61000000100000005000000990D32C9C835444065A88AA9F41F4840990D32C9C8354440575D876A4A224840B01C210379384440575D876A4A224840B01C21037938444065A88AA9F41F4840990D32C9C835444065A88AA9F41F4840
56965	Филиппенков	2	23	1602	40.197938000000001	40.238542000000002	48.366045999999997	48.352407999999997	0103000020E610000001000000050000005D514A0856194440A46C91B41B2D48405D514A0856194440726A6798DA2E4840795C548B881E4440726A6798DA2E4840795C548B881E4440A46C91B41B2D48405D514A0856194440A46C91B41B2D4840
56737	Урывский	2	23	1602	40.228606999999997	40.257389000000003	48.564864	48.552348000000002	0103000020E610000001000000050000007E5182FE421D44406901DA56B34648407E5182FE421D44400858AB764D484840D2AC6C1FF22044400858AB764D484840D2AC6C1FF22044406901DA56B34648407E5182FE421D44406901DA56B3464840
56823	Уляшкин	2	23	1602	39.941298000000003	39.986860999999998	48.471173999999998	48.462237000000002	0103000020E6100000010000000500000026E5EE737CF843402600FF942A3B484026E5EE737CF84340DD5CFC6D4F3C48405359147651FE4340DD5CFC6D4F3C48405359147651FE43402600FF942A3B484026E5EE737CF843402600FF942A3B4840
56630	Старая Станица	2	23	1602	40.271977	40.332253999999999	48.358611000000003	48.313588000000003	0103000020E61000000100000005000000D1217024D02244408335CEA623284840D1217024D0224440317E1AF7E62D48408BFB8F4C872A4440317E1AF7E62D48408BFB8F4C872A44408335CEA623284840D1217024D02244408335CEA623284840
56921	Сибилев	2	23	1602	40.304999000000002	40.323962999999999	48.607078000000001	48.589863999999999	0103000020E6100000010000000500000007280D350A2744403B8BDEA9804B484007280D350A274440800F5EBBB44D4840990E9D9E77294440800F5EBBB44D4840990E9D9E772944403B8BDEA9804B484007280D350A2744403B8BDEA9804B4840
56961	Светлый	2	23	1602	40.062463000000001	40.076666000000003	48.171424999999999	48.154573999999997	0103000020E61000000100000005000000E31A9FC9FE074440EC67B114C9134840E31A9FC9FE074440C05B2041F11548408A5B0531D0094440C05B2041F11548408A5B0531D0094440EC67B114C9134840E31A9FC9FE074440EC67B114C9134840
56671	Самбуров	2	23	1602	40.575284000000003	40.615430000000003	48.420667000000002	48.392454999999998	0103000020E61000000100000005000000BFF4F6E7A24944406A1327F73B324840BFF4F6E7A2494440D3C08F6AD8354840187D0569C64E4440D3C08F6AD8354840187D0569C64E44406A1327F73B324840BFF4F6E7A24944406A1327F73B324840
56804	Разъезд Северный Донец	2	23	1602	40.280799000000002	40.305025999999998	48.245874999999998	48.239376	0103000020E61000000100000005000000F0DFBC38F123444041B96DDFA31E4840F0DFBC38F1234440B6F3FDD4781F484000378B170B274440B6F3FDD4781F484000378B170B27444041B96DDFA31E4840F0DFBC38F123444041B96DDFA31E4840
56749	Плешаков	2	23	1602	40.543897000000001	40.569544	48.566397000000002	48.527042999999999	0103000020E610000001000000050000003EB2B96A9E454440F94A2025764348403EB2B96A9E454440B9C667B27F48484007D15AD1E6484440B9C667B27F48484007D15AD1E6484440F94A2025764348403EB2B96A9E454440F94A202576434840
56818	Нижнеясиновский	2	23	1602	40.564315999999998	40.583342000000002	48.263463999999999	48.255420000000001	0103000020E61000000100000005000000054EB6813B484440465F419AB1204840054EB6813B48444030D63730B92148400E315EF3AA4A444030D63730B92148400E315EF3AA4A4440465F419AB1204840054EB6813B484440465F419AB1204840
57015	Нижнеерохин	2	23	1602	40.481707	40.507452999999998	48.403587000000002	48.373013	0103000020E610000001000000050000008CA03193A83D4440CEFDD5E3BE2F48408CA03193A83D44409E0B23BDA8334840E8A04B38F44044409E0B23BDA8334840E8A04B38F4404440CEFDD5E3BE2F48408CA03193A83D4440CEFDD5E3BE2F4840
57007	Нижнеговейный	2	23	1602	40.331194000000004	40.350983999999997	48.291232999999998	48.279476000000003	0103000020E61000000100000005000000D350A390642A44402A029CDEC5234840D350A390642A44400B42791F47254840AAB5300BED2C44400B42791F47254840AAB5300BED2C44402A029CDEC5234840D350A390642A44402A029CDEC5234840
21497	Молодежный	2	23	1602	40.302717999999999	40.309922	48.455689	48.451076	0103000020E610000001000000050000008CF4A276BF2644405801BEDBBC3948408CF4A276BF264440CF126404543A4840CC272B86AB274440CF126404543A4840CC272B86AB2744405801BEDBBC3948408CF4A276BF2644405801BEDBBC394840
56976	Михайловка	2	23	1602	39.986879000000002	40.016784000000001	48.382348999999998	48.371223000000001	0103000020E61000000100000005000000FA0D130D52FE4340F2423A3C842F4840FA0D130D52FE43404354E1CFF03048404C8C65FA250244404354E1CFF03048404C8C65FA25024440F2423A3C842F4840FA0D130D52FE4340F2423A3C842F4840
56640	Масаловка	2	23	1602	40.245683999999997	40.279046999999998	48.422724000000002	48.399275000000003	0103000020E610000001000000050000004293C492721F4440228E75711B3348404293C492721F4440FE9DEDD11B3648400186E5CFB7234440FE9DEDD11B3648400186E5CFB7234440228E75711B3348404293C492721F4440228E75711B334840
56637	Малая Каменка	2	23	1602	40.136439000000003	40.182127999999999	48.336683000000001	48.314864999999998	0103000020E61000000100000005000000117349D576114440D8D30E7F4D284840117349D576114440410FB56D182B4840CBD765F84F174440410FB56D182B4840CBD765F84F174440D8D30E7F4D284840117349D576114440D8D30E7F4D284840
23420	Лесной	2	23	1602	40.318187000000002	40.328733	48.320022999999999	48.313870000000001	0103000020E610000001000000050000009581035ABA284440079964E42C2848409581035ABA284440E17B7F83F6284840D80E46EC132A4440E17B7F83F6284840D80E46EC132A4440079964E42C2848409581035ABA284440079964E42C284840
56659	Красновка	2	23	1602	40.243068999999998	40.266911	48.38476	48.362119	0103000020E61000000100000005000000F1D58EE21C1F44404F2157EA592E4840F1D58EE21C1F44408C67D0D03F314840A9F8BF232A2244408C67D0D03F314840A9F8BF232A2244404F2157EA592E4840F1D58EE21C1F44404F2157EA592E4840
57021	Кочетовка	2	23	1602	40.130015999999998	40.15128	48.490715999999999	48.481363999999999	0103000020E6100000010000000500000076FA415DA410444062BCE6559D3D484076FA415DA4104440DDCF29C8CF3E4840FA449E245D134440DDCF29C8CF3E4840FA449E245D13444062BCE6559D3D484076FA415DA410444062BCE6559D3D4840
22166	Каменногорье	2	23	1602	40.346043000000002	40.386459000000002	48.537166999999997	48.514833000000003	0103000020E610000001000000050000003F0114234B2C444067F3380CE64148403F0114234B2C4440C6BE64E3C1444840581F0F7D77314440C6BE64E3C1444840581F0F7D7731444067F3380CE64148403F0114234B2C444067F3380CE6414840
22499	Калитвенская	2	23	1602	40.521062000000001	40.540106000000002	48.297682999999999	48.281395000000003	0103000020E610000001000000050000001C98DC28B2424440042159C0042448401C98DC28B24244409FC9FE791A264840CB2F8331224544409FC9FE791A264840CB2F833122454440042159C0042448401C98DC28B2424440042159C004244840
56885	Диченский	2	23	1602	40.351433	40.395397000000003	48.303353000000001	48.293126999999998	0103000020E610000001000000050000001ADEACC1FB2C44408C497F2F852548401ADEACC1FB2C44405E126745D4264840E0F76F5E9C3244405E126745D4264840E0F76F5E9C3244408C497F2F852548401ADEACC1FB2C44408C497F2F85254840
56846	Данилов	2	23	1602	40.805235000000003	40.824091000000003	48.503253000000001	48.490673999999999	0103000020E610000001000000050000001B4CC3F011674440AE7FD767CE3E48401B4CC3F011674440944E24986A404840C7F65AD07B694440944E24986A404840C7F65AD07B694440AE7FD767CE3E48401B4CC3F011674440AE7FD767CE3E4840
56775	Гусев	2	23	1602	40.483566000000003	40.516984000000001	48.454326000000002	48.430706000000001	0103000020E6100000010000000500000091BA9D7DE53D44407218CC5F2137484091BA9D7DE53D44407BDCB75A273A484013471E882C4244407BDCB75A273A484013471E882C4244407218CC5F2137484091BA9D7DE53D44407218CC5F21374840
56736	Груцинов	2	23	1602	40.640492999999999	40.705531000000001	48.494596999999999	48.447662999999999	0103000020E610000001000000050000009128B4ACFB5144408B506C054D3948409128B4ACFB51444090D959F44E3F484037A8FDD64E5A444090D959F44E3F484037A8FDD64E5A44408B506C054D3948409128B4ACFB5144408B506C054D394840
21884	Глубокий	2	23	1602	39.845771999999997	40.861460999999998	48.639951000000003	48.097757000000001	0103000020E61000000100000005000000AEEFC34142EC434040FA264D830C4840AEEFC34142EC4340710514EAE9514840C5E3A25A446E4440710514EAE9514840C5E3A25A446E444040FA264D830C4840AEEFC34142EC434040FA264D830C4840
56740	Волченский	2	23	1602	40.110621999999999	40.133628000000002	48.266084999999997	48.221136000000001	0103000020E61000000100000005000000EB1B98DC280E4440F0FB372F4E1C4840EB1B98DC280E4440637AC2120F2248403AEAE8B81A114440637AC2120F2248403AEAE8B81A114440F0FB372F4E1C4840EB1B98DC280E4440F0FB372F4E1C4840
56724	Вишневецкий	2	23	1602	40.064591999999998	40.095098999999998	48.402146000000002	48.370193999999998	0103000020E61000000100000005000000A7CAF78C4408444074965984622F4840A7CAF78C44084440CE1B278579334840EF703B342C0C4440CE1B278579334840EF703B342C0C444074965984622F4840A7CAF78C4408444074965984622F4840
56644	Верхний Пиховкин	2	23	1602	40.308852999999999	40.334401	48.573884	48.546765000000001	0103000020E61000000100000005000000C022BF7E8827444079CC4065FC454840C022BF7E882744404DD9E90775494840F65FE7A6CD2A44404DD9E90775494840F65FE7A6CD2A444079CC4065FC454840C022BF7E8827444079CC4065FC454840
56977	Верхние Грачики	2	23	1602	39.966047000000003	40.013074000000003	48.510666999999998	48.490786999999997	0103000020E6100000010000000500000010B3976DA7FB4340A626C11BD23E484010B3976DA7FB4340BE1248895D414840C636A968AC014440BE1248895D414840C636A968AC014440A626C11BD23E484010B3976DA7FB4340A626C11BD23E4840
56992	Верхнеясиновский	2	23	1602	40.546214999999997	40.559545999999997	48.224606000000001	48.204642999999997	0103000020E61000000100000005000000D5CA845FEA4544407B2DE8BD311A4840D5CA845FEA454440213EB0E3BF1C4840C64D0D349F474440213EB0E3BF1C4840C64D0D349F4744407B2DE8BD311A4840D5CA845FEA4544407B2DE8BD311A4840
22876	Васильевский	2	23	1602	40.554057	40.5717	48.187694999999998	48.176291999999997	0103000020E61000000100000005000000588FFB56EB464440F1457BBC90164840588FFB56EB464440B54FC76306184840C58F31772D494440B54FC76306184840C58F31772D494440F1457BBC90164840588FFB56EB464440F1457BBC90164840
56820	Белгородцев	2	23	1602	40.119165000000002	40.156086000000002	48.224317999999997	48.192776000000002	0103000020E61000000100000005000000F7E978CC400F444013BA4BE2AC184840F7E978CC400F4440BAF3C473B61C484086AE44A0FA134440BAF3C473B61C484086AE44A0FA13444013BA4BE2AC184840F7E978CC400F444013BA4BE2AC184840
56980	Астахов	2	23	1602	40.270657	40.309697999999997	48.476598000000003	48.446086000000001	0103000020E610000001000000050000007CB779E3A42244400B9A9658193948407CB779E3A422444065ABCB29013D48407CD11E2FA427444065ABCB29013D48407CD11E2FA42744400B9A9658193948407CB779E3A42244400B9A965819394840
56869	Аникин	2	23	1602	39.970466999999999	39.996689000000003	48.184294000000001	48.158473999999998	0103000020E61000000100000005000000726C3D4338FC434016A243E048144840726C3D4338FC4340AD6C1FF29617484038A4518193FF4340AD6C1FF29617484038A4518193FF434016A243E048144840726C3D4338FC434016A243E048144840
56981	Абрамовка	2	23	1602	40.324663000000001	40.349843	48.302388000000001	48.292017999999999	0103000020E61000000100000005000000529CA38E8E294440F2EB87D860254840529CA38E8E294440F75965A6B426484005DEC9A7C72C4440F75965A6B426484005DEC9A7C72C4440F2EB87D860254840529CA38E8E294440F2EB87D860254840
10344	Хомутовская	2	23	1052	40.056103	40.076512999999998	47.051552000000001	47.038871999999998	0103000020E610000001000000050000008F1A13622E074440745DF8C1F98447408F1A13622E0744408E05854199864740035C902DCB0944408E05854199864740035C902DCB094440745DF8C1F98447408F1A13622E074440745DF8C1F9844740
56854	Середин	2	23	1052	39.994810999999999	40.018706000000002	46.878098000000001	46.872326000000001	0103000020E61000000100000005000000BC5983F755FF4340AAB9DC60A86F4740BC5983F755FF43406D57E88365704740971E4DF5640244406D57E88365704740971E4DF564024440AAB9DC60A86F4740BC5983F755FF4340AAB9DC60A86F4740
9584	Светлый Яр	2	23	1052	40.138865000000003	40.153013000000001	46.808256	46.802087	0103000020E610000001000000050000008FC70C54C6114440FCC56CC9AA6647408FC70C54C6114440DC65BFEE74674740726E13EE95134440DC65BFEE74674740726E13EE95134440FCC56CC9AA6647408FC70C54C6114440FCC56CC9AA664740
56962	Родники	2	23	1052	40.197139	40.243977000000001	46.971257000000001	46.947603000000001	0103000020E6100000010000000500000011E2CAD93B194440B64B1B0E4B79474011E2CAD93B1944406B813D26527C4740F4FC69A33A1F44406B813D26527C4740F4FC69A33A1F4440B64B1B0E4B79474011E2CAD93B194440B64B1B0E4B794740
56900	Раково-Таврический	2	23	1052	40.349195999999999	40.380133999999998	47.007807	46.997987000000002	0103000020E610000001000000050000006FF25B74B22C4440A56ABB09BE7F47406FF25B74B22C444006D7DCD1FF804740800C1D3BA830444006D7DCD1FF804740800C1D3BA8304440A56ABB09BE7F47406FF25B74B22C4440A56ABB09BE7F4740
56931	Первомайский	2	23	1052	40.132074000000003	40.173836000000001	47.108902999999998	47.094126000000003	0103000020E61000000100000005000000725303CDE710444006DA1D520C8C4740725303CDE7104440D8B79388F08D4740096F0F4240164440D8B79388F08D4740096F0F424016444006DA1D520C8C4740725303CDE710444006DA1D520C8C4740
10104	Новоракитный	2	23	1052	39.914565000000003	39.932423	46.969363000000001	46.965384999999998	0103000020E610000001000000050000007B88467710F54340448655BC917B47407B88467710F54340EA793716147C4740E48409A359F74340EA793716147C4740E48409A359F74340448655BC917B47407B88467710F54340448655BC917B4740
30647	Новонатальин	2	23	1052	39.958618000000001	39.976764000000003	47.121473999999999	47.115416000000003	0103000020E61000000100000005000000B0AD9FFEB3FA4340B3B794F3C58E4740B0AD9FFEB3FA43403BA8C4758C8F474080F44D9A06FD43403BA8C4758C8F474080F44D9A06FD4340B3B794F3C58E4740B0AD9FFEB3FA4340B3B794F3C58E4740
9888	Новобатайск	2	23	1052	39.761465000000001	39.807116999999998	46.908445	46.883955999999998	0103000020E610000001000000050000003A0664AF77E143402E8D5F78257147403A0664AF77E143407C9BFEEC47744740D7851F9C4FE743407C9BFEEC47744740D7851F9C4FE743402E8D5F78257147403A0664AF77E143402E8D5F7825714740
56703	Николаевский	2	23	1052	39.985999	40.031928999999998	46.968933	46.962173999999997	0103000020E61000000100000005000000C171193735FE4340DF878384287B4740C171193735FE4340F1811DFF057C4740A165DD3F16044440F1811DFF057C4740A165DD3F16044440DF878384287B4740C171193735FE4340DF878384287B4740
10195	Мокрый Батай	2	23	1052	39.834192000000002	39.853352999999998	47.046799999999998	47.039209999999997	0103000020E61000000100000005000000DC4AAFCDC6EA43408CD651D504854740DC4AAFCDC6EA4340F5B9DA8AFD854740C478CDAB3AED4340F5B9DA8AFD854740C478CDAB3AED43408CD651D504854740DC4AAFCDC6EA43408CD651D504854740
30763	Малодубравный	2	23	1052	39.839016000000001	39.856740000000002	46.995528	46.991176000000003	0103000020E610000001000000050000000E6954E064EB4340414AECDADE7E47400E6954E064EB43404B2025766D7F4740689604A8A9ED43404B2025766D7F4740689604A8A9ED4340414AECDADE7E47400E6954E064EB4340414AECDADE7E4740
9404	Малиновка	2	23	1052	40.177537000000001	40.186646000000003	46.907386000000002	46.901463	0103000020E610000001000000050000003C6A4C88B9164440EBC6BB23637347403C6A4C88B9164440946C753925744740F1F62004E4174440946C753925744740F1F62004E4174440EBC6BB23637347403C6A4C88B9164440EBC6BB2363734740
10677	Красный Яр	2	23	1052	40.175865999999999	40.198774	46.952702000000002	46.940823000000002	0103000020E610000001000000050000003A3DEFC6821644408D2958E36C7847403A3DEFC682164440BA6A9E23F2794740C6A52A6D71194440BA6A9E23F2794740C6A52A6D711944408D2958E36C7847403A3DEFC6821644408D2958E36C784740
9579	Ключевой	2	23	1052	39.985190000000003	39.990642999999999	46.812758000000002	46.809465000000003	0103000020E61000000100000005000000522CB7B41AFE4340DA20938C9C674740522CB7B41AFE4340FCC74274086847407381CB63CDFE4340FCC74274086847407381CB63CDFE4340DA20938C9C674740522CB7B41AFE4340DA20938C9C674740
52110	Кировская	2	23	1052	40.027653000000001	40.076251999999997	46.992744000000002	46.965895000000003	0103000020E6100000010000000500000072512D228A0344405A2F8672A27B474072512D228A0344406EA6423C127F4740962023A0C20944406EA6423C127F4740962023A0C20944405A2F8672A27B474072512D228A0344405A2F8672A27B4740
56832	Камышеваха	2	23	1052	40.258125	40.270862999999999	47.049022000000001	47.028744000000003	0103000020E61000000100000005000000D7A3703D0A21444066FA25E2AD834740D7A3703D0A2144406B64575A46864740255987A3AB2244406B64575A46864740255987A3AB22444066FA25E2AD834740D7A3703D0A21444066FA25E2AD834740
57003	Кагальничек	2	23	1052	40.201585000000001	40.214709999999997	46.929611999999999	46.919333999999999	0103000020E610000001000000050000009D2E8B89CD194440E90C8CBCAC7547409D2E8B89CD1944400DFCA886FD764740E40F069E7B1B44400DFCA886FD764740E40F069E7B1B4440E90C8CBCAC7547409D2E8B89CD194440E90C8CBCAC754740
9217	Кагальницкая	2	23	1052	40.134472000000002	40.183914999999999	46.904522999999998	46.869824999999999	0103000020E61000000100000005000000261DE56036114440211FF46C566F4740261DE560361144406ABDDF68C7734740361FD7868A1744406ABDDF68C7734740361FD7868A174440211FF46C566F4740261DE56036114440211FF46C566F4740
9725	Иваново-Шамшево	2	23	1052	39.908850999999999	39.920952	46.883124000000002	46.870914999999997	0103000020E61000000100000005000000ECF7C43A55F44340444C89247A6F4740ECF7C43A55F4434007280D350A714740C89750C1E1F5434007280D350A714740C89750C1E1F54340444C89247A6F4740ECF7C43A55F44340444C89247A6F4740
57018	Зеленая Роща	2	23	1052	40.213281000000002	40.250382000000002	47.110455000000002	47.083696000000003	0103000020E61000000100000005000000D9EDB3CA4C1B44402C67EF8CB68A4740D9EDB3CA4C1B44400057B263238E4740E8C072840C2044400057B263238E4740E8C072840C2044402C67EF8CB68A4740D9EDB3CA4C1B44402C67EF8CB68A4740
56717	Жуково-Татарский	2	23	1052	40.289656000000001	40.338892999999999	47.004575000000003	46.993543000000003	0103000020E610000001000000050000008B8BA37213254440BA15C26A2C7F47408B8BA372132544408AB0E1E995804740F2EB87D8602B44408AB0E1E995804740F2EB87D8602B4440BA15C26A2C7F47408B8BA37213254440BA15C26A2C7F4740
9485	Двуречье	2	23	1052	40.048234000000001	40.067259999999997	46.856676	46.842396000000001	0103000020E6100000010000000500000013471E882C064440FF23D3A1D36B474013471E882C06444051A2258FA76D47401B2AC6F99B08444051A2258FA76D47401B2AC6F99B084440FF23D3A1D36B474013471E882C064440FF23D3A1D36B4740
30774	Глубокий Яр	2	23	1052	40.142611000000002	40.151944	46.970807999999998	46.963391999999999	0103000020E610000001000000050000006286C61341124440309DD66D507B47406286C61341124440FB58C16F437C47406669A7E672134440FB58C16F437C47406669A7E672134440309DD66D507B47406286C61341124440309DD66D507B4740
10254	Воронцовка	2	23	1052	39.767403000000002	39.782961	46.951723999999999	46.946384999999999	0103000020E6100000010000000500000018EDF1423AE243406536C8242379474018EDF1423AE24340BE688F17D27947409085E81038E44340BE688F17D27947409085E81038E443406536C8242379474018EDF1423AE243406536C82423794740
9742	Васильево-Шамшево	2	23	1052	39.952770000000001	39.965544000000001	46.872571999999998	46.863897999999999	0103000020E61000000100000005000000124E0B5EF4F94340378AAC35946E4740124E0B5EF4F94340E1B37570B06F4740AD6C1FF296FB4340E1B37570B06F4740AD6C1FF296FB4340378AAC35946E4740124E0B5EF4F94340378AAC35946E4740
12209	Березовая Роща	2	23	1052	39.974392000000002	39.984003999999999	47.036956000000004	47.031213000000001	0103000020E61000000100000005000000F5BD86E0B8FC4340E31A9FC9FE834740F5BD86E0B8FC43400CB265F9BA8447400C91D3D7F3FD43400CB265F9BA8447400C91D3D7F3FD4340E31A9FC9FE834740F5BD86E0B8FC4340E31A9FC9FE834740
56770	Хуторской	2	23	66	42.970283000000002	42.999324999999999	46.877833000000003	46.843536	0103000020E61000000100000005000000B16EBC3B327C4540D47FD6FCF86B4740B16EBC3B327C4540BF2CEDD45C704740A089B0E1E97F4540BF2CEDD45C704740A089B0E1E97F4540D47FD6FCF86B4740B16EBC3B327C4540D47FD6FCF86B4740
56915	Харьковский	2	23	66	42.088163999999999	42.103966	47.146245999999998	47.118445000000001	0103000020E610000001000000050000009F573CF5480B4540F7AFAC34298F47409F573CF5480B4540DD955D30B8924740AEF204C24E0D4540DD955D30B8924740AEF204C24E0D4540F7AFAC34298F47409F573CF5480B4540F7AFAC34298F4740
1923	Савоськин	2	23	66	42.780647999999999	42.817712999999998	46.764902999999997	46.750123000000002	0103000020E610000001000000050000000AD80E46EC6345401C7DCC07046047400AD80E46EC6345405FCE6C57E8614740CC41D0D1AA6845405FCE6C57E8614740CC41D0D1AA6845401C7DCC07046047400AD80E46EC6345401C7DCC0704604740
56996	Погорелов	2	23	66	42.599854000000001	42.619374000000001	46.936940999999997	46.929144000000001	0103000020E61000000100000005000000F92F1004C84C454027A3CA30EE764740F92F1004C84C454009A4C4AEED77474011FFB0A5474F454009A4C4AEED77474011FFB0A5474F454027A3CA30EE764740F92F1004C84C454027A3CA30EE764740
56741	Плотников	2	23	66	42.838921999999997	42.858415999999998	47.050846	47.029161999999999	0103000020E610000001000000050000008CF2CCCB616B45409A249694BB8347408CF2CCCB616B4540F390291F828647407B2E5393E06D4540F390291F828647407B2E5393E06D45409A249694BB8347408CF2CCCB616B45409A249694BB834740
57020	Нариманов	2	23	66	42.448388999999999	42.474943000000003	47.059643999999999	47.041463	0103000020E610000001000000050000006D718DCF643945403D7FDAA84E8547406D718DCF6439454089B3226AA2874740693BA6EECA3C454089B3226AA2874740693BA6EECA3C45403D7FDAA84E8547406D718DCF643945403D7FDAA84E854740
1860	Мокрый Гашун	2	23	66	42.739711999999997	42.774306000000003	46.888444999999997	46.872011999999998	0103000020E61000000100000005000000B83A00E2AE5E45401ADCD6169E6F4740B83A00E2AE5E4540B9A5D590B87147405D8C81751C634540B9A5D590B87147405D8C81751C6345401ADCD6169E6F4740B83A00E2AE5E45401ADCD6169E6F4740
56958	Марченков	2	23	66	42.597563000000001	42.606527999999997	47.077345000000001	47.063032	0103000020E610000001000000050000005B26C3F17C4C4540FD4CBD6E118847405B26C3F17C4C45402BC1E270E6894740DC0DA2B5A24D45402BC1E270E6894740DC0DA2B5A24D4540FD4CBD6E118847405B26C3F17C4C4540FD4CBD6E11884740
56870	Майкопский	2	23	66	42.484276000000001	42.505944	47.239871999999998	47.225444000000003	0103000020E610000001000000050000006D1E87C1FC3D45402B8A5759DB9C47406D1E87C1FC3D4540F19C2D20B49E4740C0CDE2C5C2404540F19C2D20B49E4740C0CDE2C5C24045402B8A5759DB9C47406D1E87C1FC3D45402B8A5759DB9C4740
56937	Ленинский	2	23	66	42.450553999999997	42.468628000000002	47.109448999999998	47.086322000000003	0103000020E610000001000000050000007E8AE3C0AB39454071766B990C8B47407E8AE3C0AB3945403ACAC16C028E4740B5FE9600FC3B45403ACAC16C028E4740B5FE9600FC3B454071766B990C8B47407E8AE3C0AB39454071766B990C8B4740
56839	Лагунный	2	23	66	42.366345000000003	42.384473	47.135703999999997	47.125877000000003	0103000020E61000000100000005000000CD069964E42E4540C828CFBC1C904740CD069964E42E4540DBF7A8BF5E914740F698486936314540DBF7A8BF5E914740F698486936314540C828CFBC1C904740CD069964E42E4540C828CFBC1C904740
1112	Кутейниковская	2	23	66	42.122300000000003	42.144236999999997	47.247273999999997	47.227530999999999	0103000020E610000001000000050000008126C286A70F4540C0E95DBC1F9D47408126C286A70F45405793A7ACA69F4740C3EFA65B761245405793A7ACA69F4740C3EFA65B76124540C0E95DBC1F9D47408126C286A70F4540C0E95DBC1F9D4740
1692	Красностепной	2	23	66	43.088312000000002	43.113940999999997	46.753852000000002	46.742935000000003	0103000020E6100000010000000500000014ECBFCE4D8B4540E2067C7E185F474014ECBFCE4D8B45401903EB387E6047403656629E958E45401903EB387E6047403656629E958E4540E2067C7E185F474014ECBFCE4D8B4540E2067C7E185F4740
56653	Камышев	2	23	66	42.503248999999997	42.535156999999998	46.900145000000002	46.877623999999997	0103000020E61000000100000005000000525F96766A404540A417B5FB55704740525F96766A40454037548CF337734740DC9C4A068044454037548CF337734740DC9C4A0680444540A417B5FB55704740525F96766A404540A417B5FB55704740
42353	Ильичев	2	23	66	42.678958999999999	42.705117999999999	47.145755999999999	47.132283000000001	0103000020E610000001000000050000009529E620E85645408C683BA6EE9047409529E620E85645400F99F221A892474014E97E4E415A45400F99F221A892474014E97E4E415A45408C683BA6EE9047409529E620E85645408C683BA6EE904740
81	Зимовники	2	23	66	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
56789	Глубокий	2	23	66	42.773327000000002	42.815575000000003	47.020432999999997	46.997753000000003	0103000020E61000000100000005000000910E0F61FC624540323ECC5EB67F4740910E0F61FC6245402C616D8C9D824740B537F8C2646845402C616D8C9D824740B537F8C264684540323ECC5EB67F4740910E0F61FC624540323ECC5EB67F4740
54835	Гашун	2	23	66	42.592694000000002	42.614190999999998	47.288913999999998	47.273980000000002	0103000020E610000001000000050000008944A165DD4B454009E1D1C611A347408944A165DD4B4540A3AD4A22FBA44740AF3F89CF9D4E4540A3AD4A22FBA44740AF3F89CF9D4E454009E1D1C611A347408944A165DD4B454009E1D1C611A34740
56939	Верхоломов	2	23	66	42.398155000000003	42.420900000000003	47.374701999999999	47.359730999999996	0103000020E6100000010000000500000094DE37BEF6324540BE2D58AA0BAE474094DE37BEF632454076DF313CF6AF474076711B0DE035454076DF313CF6AF474076711B0DE0354540BE2D58AA0BAE474094DE37BEF6324540BE2D58AA0BAE4740
56660	Верхнесеребряковка	2	23	66	42.213254999999997	42.266579	47.336573999999999	47.322405000000003	0103000020E61000000100000005000000AF5A99F04B1B45409088299144A94740AF5A99F04B1B45408A5759DB14AB47407366BB421F2245408A5759DB14AB47407366BB421F2245409088299144A94740AF5A99F04B1B45409088299144A94740
1462	Байков	2	23	66	42.954022999999999	42.974550000000001	47.140644000000002	47.117151	0103000020E61000000100000005000000DF50F86C1D7A4540CBD8D0CDFE8E4740DF50F86C1D7A45407730629F009247408D28ED0DBE7C45407730629F009247408D28ED0DBE7C4540CBD8D0CDFE8E4740DF50F86C1D7A4540CBD8D0CDFE8E4740
16854	Экспериментальный	2	23	1220	40.289396000000004	40.307281000000003	46.814262999999997	46.804831999999998	0103000020E61000000100000005000000EFCB99ED0A2544401B6327BC04674740EFCB99ED0A254440E2AB1DC53968474052D7DAFB54274440E2AB1DC53968474052D7DAFB542744401B6327BC04674740EFCB99ED0A2544401B6327BC04674740
16937	Шоссейный	2	23	1220	40.338811999999997	40.349628000000003	46.803666999999997	46.796455000000002	0103000020E6100000010000000500000005BF0D315E2B44402BDEC83CF265474005BF0D315E2B4440EDEF6C8FDE66474009E23C9CC02C4440EDEF6C8FDE66474009E23C9CC02C44402BDEC83CF265474005BF0D315E2B44402BDEC83CF2654740
56634	Чернышевка	2	23	1220	40.710292000000003	40.737475000000003	46.884183	46.866652000000002	0103000020E61000000100000005000000234E27D9EA5A4440AA81E673EE6E4740234E27D9EA5A4440EF5696E82C7147400E4FAF94655E4440EF5696E82C7147400E4FAF94655E4440AA81E673EE6E4740234E27D9EA5A4440AA81E673EE6E4740
56891	Средние Хороли	2	23	1220	40.476497000000002	40.480331999999997	46.959954000000003	46.950592999999998	0103000020E6100000010000000500000031D28BDAFD3C44403C670B08AD79474031D28BDAFD3C44400BD5CDC5DF7A4740739CDB847B3D44400BD5CDC5DF7A4740739CDB847B3D44403C670B08AD79474031D28BDAFD3C44403C670B08AD794740
16493	Сорговый	2	23	1220	40.390878000000001	40.420513999999997	47.054174000000003	47.032294	0103000020E61000000100000005000000EA5C514A08324440B3EDB43522844740EA5C514A083244409225732CEF8647404CC11A67D33544409225732CEF8647404CC11A67D3354440B3EDB43522844740EA5C514A08324440B3EDB43522844740
15844	Светлоречное	2	23	1220	40.327807999999997	40.368259000000002	46.617465000000003	46.597845999999997	0103000020E61000000100000005000000FFAECF9CF5294440AF05BD37864C4740FFAECF9CF52944405BB6D617094F474095BA641C232F44405BB6D617094F474095BA641C232F4440AF05BD37864C4740FFAECF9CF5294440AF05BD37864C4740
56865	Революционный	2	23	1220	40.249079000000002	40.281778000000003	46.736265000000003	46.724936999999997	0103000020E61000000100000005000000698F17D2E11F4440865451BCCA5C4740698F17D2E11F4440401878EE3D5E4740BC5D2F4D11244440401878EE3D5E4740BC5D2F4D11244440865451BCCA5C4740698F17D2E11F4440865451BCCA5C4740
56906	Ракитный	2	23	1220	40.285837999999998	40.335999999999999	46.899664999999999	46.894696000000003	0103000020E610000001000000050000001EFAEE569624444057EE0566857247401EFAEE56962444408C2D0439287347405EBA490C022B44408C2D0439287347405EBA490C022B444057EE0566857247401EFAEE569624444057EE056685724740
56625	Путь Правды	2	23	1220	40.998624	41.056314	46.946914	46.920264000000003	0103000020E61000000100000005000000178046E9D27F4440D4D7F335CB754740178046E9D27F4440F10F5B7A347947404A27124C35874440F10F5B7A347947404A27124C35874440D4D7F335CB754740178046E9D27F4440D4D7F335CB754740
56809	Прудовой	2	23	1220	40.228543999999999	40.241712999999997	46.799657000000003	46.790106999999999	0103000020E6100000010000000500000038D906EE401D44409BABE6392265474038D906EE401D44403D821B295B6647404F029B73F01E44403D821B295B6647404F029B73F01E44409BABE6392265474038D906EE401D44409BABE63922654740
56985	Попов	2	23	1220	40.614998999999997	40.673461000000003	46.919992999999998	46.906923999999997	0103000020E610000001000000050000004E098849B84E44408FFAEB15167447404E098849B84E444043C6A354C2754740D41055F83356444043C6A354C2754740D41055F8335644408FFAEB15167447404E098849B84E44408FFAEB1516744740
56990	Пишванов	2	23	1220	40.594374000000002	40.618304999999999	46.795597999999998	46.782653000000003	0103000020E61000000100000005000000DECB7D72144C4440E38E37F92D644740DECB7D72144C4440AA61BF27D665474005FA449E244F4440AA61BF27D665474005FA449E244F4440E38E37F92D644740DECB7D72144C4440E38E37F92D644740
16240	Осокино	2	23	1220	40.385848000000003	40.395091000000001	47.126525999999998	47.123215999999999	0103000020E610000001000000050000000F9D9E7763314440062CB98AC58F47400F9D9E7763314440FE0B040132904740D3F8855792324440FE0B040132904740D3F8855792324440062CB98AC58F47400F9D9E7763314440062CB98AC58F4740
14519	Новые Постройки	2	23	1220	40.354928000000001	40.370719999999999	47.056941999999999	47.048696999999997	0103000020E61000000100000005000000A437DC476E2D4440E7340BB43B864740A437DC476E2D444069E21DE0498747408FFCC1C0732F444069E21DE0498747408FFCC1C0732F4440E7340BB43B864740A437DC476E2D4440E7340BB43B864740
15895	Новокузнецовка	2	23	1220	40.505378	40.562286	46.922651999999999	46.908315999999999	0103000020E61000000100000005000000170FEF39B04044407E37DDB243744740170FEF39B040444064CBF27519764740D47FD6FCF847444064CBF27519764740D47FD6FCF84744407E37DDB243744740170FEF39B04044407E37DDB243744740
12193	Новоивановка	2	23	1220	40.262203999999997	40.311332	46.529924999999999	46.515675999999999	0103000020E61000000100000005000000B07092E68F21444082AAD1AB01424740B07092E68F214440992A1895D443474061191BBAD9274440992A1895D443474061191BBAD927444082AAD1AB01424740B07092E68F21444082AAD1AB01424740
56825	Новая Поляна	2	23	1220	40.199007000000002	40.229981000000002	46.582909000000001	46.578423999999998	0103000020E610000001000000050000006956B60F791944405A9C31CC094A47406956B60F79194440A4C519C39C4A4740C7D97404701D4440A4C519C39C4A4740C7D97404701D44405A9C31CC094A47406956B60F791944405A9C31CC094A4740
15437	Нижнекугоейский	2	23	1220	40.067951999999998	40.087032000000001	46.541666999999997	46.536658000000003	0103000020E6100000010000000500000051D9B0A6B208444082919735B144474051D9B0A6B208444045292158554547404DDA54DD230B444045292158554547404DDA54DD230B444082919735B144474051D9B0A6B208444082919735B1444740
54860	Мечетинская	2	23	1220	40.438218999999997	40.491273999999997	46.791538000000003	46.755654999999997	0103000020E610000001000000050000002FBE688F173844408907944DB96047402FBE688F1738444048C5FF1D5165474003B00111E23E444048C5FF1D5165474003B00111E23E44408907944DB96047402FBE688F173844408907944DB9604740
16180	Междупольный	2	23	1220	40.314889999999998	40.326739000000003	47.099347000000002	47.089654000000003	0103000020E6100000010000000500000031EBC5504E28444051FA42C8798B474031EBC5504E28444055FA0967B78C4740F4A96395D229444055FA0967B78C4740F4A96395D229444051FA42C8798B474031EBC5504E28444051FA42C8798B4740
16301	Малый Лог	2	23	1220	40.463866000000003	40.477117	47.087015000000001	47.082407000000003	0103000020E61000000100000005000000F9DC09F65F3B444012FB04508C8A4740F9DC09F65F3B444077A1B94E238B4740CDAE7B2B123D444077A1B94E238B4740CDAE7B2B123D444012FB04508C8A4740F9DC09F65F3B444012FB04508C8A4740
15767	Лободин	2	23	1220	40.841436999999999	40.848633	46.887551999999999	46.882693000000003	0103000020E610000001000000050000007A522635B46B44403EB48F15FC7047407A522635B46B4440ECBFCE4D9B71474037A79201A06C4440ECBFCE4D9B71474037A79201A06C44403EB48F15FC7047407A522635B46B44403EB48F15FC704740
15343	Ленинка	2	23	1220	40.320962000000002	40.351092000000001	46.520383000000002	46.510776999999997	0103000020E610000001000000050000001FA166481529444045460724614147401FA16648152944407B32FFE89B42474091F12895F02C44407B32FFE89B42474091F12895F02C444045460724614147401FA16648152944404546072461414740
56940	Краснюков	2	23	1220	40.894384000000002	40.917534000000003	46.886524000000001	46.878042999999998	0103000020E610000001000000050000006808C72C7B724440A9BD88B6637047406808C72C7B7244403F8F519E79714740EA7B0DC1717544403F8F519E79714740EA7B0DC171754440A9BD88B6637047406808C72C7B724440A9BD88B663704740
56892	Красноармейский	2	23	1220	40.600068999999998	40.618107000000002	46.705295	46.701524999999997	0103000020E61000000100000005000000F52B9D0FCF4C4440C7293A92CB594740F52B9D0FCF4C44402384471B475A4740DF3653211E4F44402384471B475A4740DF3653211E4F4440C7293A92CB594740F52B9D0FCF4C4440C7293A92CB594740
16701	Комсомольский	2	23	1220	40.365672000000004	40.380187999999997	46.928437000000002	46.921832999999999	0103000020E610000001000000050000000E881057CE2E4440D1AFAD9FFE7547400E881057CE2E4440BCB20B06D7764740732A1900AA304440BCB20B06D7764740732A1900AA304440D1AFAD9FFE7547400E881057CE2E4440D1AFAD9FFE754740
56776	Клюев	2	23	1220	40.636387999999997	40.651758000000001	46.738475999999999	46.725802000000002	0103000020E610000001000000050000008EC87729755144408AAF7614E75C47408EC8772975514440C170AE61865E474004745FCE6C534440C170AE61865E474004745FCE6C5344408AAF7614E75C47408EC87729755144408AAF7614E75C4740
16804	Кленовый	2	23	1220	40.363866000000002	40.372858000000001	46.859923000000002	46.846784999999997	0103000020E610000001000000050000002C103D29932E444026DF6C73636C47402C103D29932E4440030AF5F4116E4740A7069ACFB92F4440030AF5F4116E4740A7069ACFB92F444026DF6C73636C47402C103D29932E444026DF6C73636C4740
17061	Зерноград	2	23	1220	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
17008	Зерновой	2	23	1220	40.238388999999998	40.250238000000003	46.837268000000002	46.833143	0103000020E61000000100000005000000F25CDF87831E444017F2086EA46A4740F25CDF87831E444061FE0A992B6B4740B51B7DCC0720444061FE0A992B6B4740B51B7DCC0720444017F2086EA46A4740F25CDF87831E444017F2086EA46A4740
56705	Заполосный	2	23	1220	40.808855000000001	40.839227000000001	46.988447000000001	46.980566000000003	0103000020E61000000100000005000000611A868F88674440E7C8CA2F837D4740611A868F88674440276A696E857E4740C97553CA6B6B4440276A696E857E4740C97553CA6B6B4440E7C8CA2F837D4740611A868F88674440E7C8CA2F837D4740
30288	Займище	2	23	1220	40.080545999999998	40.113343999999998	46.589813999999997	46.578175999999999	0103000020E610000001000000050000006CE9D1544F0A444082AAD1AB014A47406CE9D1544F0A4440895C70067F4B47405299620E820E4440895C70067F4B47405299620E820E444082AAD1AB014A47406CE9D1544F0A444082AAD1AB014A4740
15948	Донской	2	23	1220	40.540779999999998	40.558306000000002	46.857236999999998	46.840676000000002	0103000020E610000001000000050000005A2A6F47384544401C446B459B6B47405A2A6F4738454440E8F527F1B96D47408E942D9276474440E8F527F1B96D47408E942D92764744401C446B459B6B47405A2A6F47384544401C446B459B6B4740
54831	Гуляй-Борисовка	2	23	1220	40.196384000000002	40.228104000000002	46.632052999999999	46.623358000000003	0103000020E6100000010000000500000095BA641C2319444099D9E731CA4F474095BA641C231944405A2BDA1CE75047401C0B0A83321D44405A2BDA1CE75047401C0B0A83321D444099D9E731CA4F474095BA641C2319444099D9E731CA4F4740
56994	Голубовка	2	23	1220	40.786262999999998	40.815916000000001	46.907823	46.902786999999996	0103000020E6100000010000000500000005871744A4644440812040868E73474005871744A46444403FC7478B337447403E247CEF6F6844403FC7478B337447403E247CEF6F684440812040868E73474005871744A4644440812040868E734740
56934	Верхние Хороли	2	23	1220	40.456347000000001	40.467469000000001	47.012433999999999	46.998176999999998	0103000020E6100000010000000500000059501894693A4440484F9143C47F474059501894693A4440E2ADF36F9781474069723106D63B4440E2ADF36F9781474069723106D63B4440484F9143C47F474059501894693A4440484F9143C47F4740
56944	Булочкин	2	23	1220	40.509715999999997	40.539054999999998	47.030237	47.021317000000003	0103000020E61000000100000005000000BC1FB75F3E414440A7ECF483BA824740BC1FB75F3E414440881057CEDE83474065DF15C1FF444440881057CEDE83474065DF15C1FF444440A7ECF483BA824740BC1FB75F3E414440A7ECF483BA824740
57000	Большие Эльбуздовские	2	23	1220	40.131732	40.165078000000001	46.632826000000001	46.627133000000001	0103000020E6100000010000000500000018EB1B98DC104440069FE6E44550474018EB1B98DC1044407D073F710051474001A5A146211544407D073F710051474001A5A14621154440069FE6E44550474018EB1B98DC104440069FE6E445504740
56712	Большая Таловая	2	23	1220	40.609375	40.632201999999999	46.991373000000003	46.967654000000003	0103000020E6100000010000000500000000000000004E4440FBEB1516DC7B474000000000004E444097917A4FE57E47409F3BC1FEEB50444097917A4FE57E47409F3BC1FEEB504440FBEB1516DC7B474000000000004E4440FBEB1516DC7B4740
56887	Болдиновка	2	23	1220	40.233682000000002	40.269722000000002	46.630375999999998	46.620133000000003	0103000020E61000000100000005000000FAD4B14AE91D4440CF15A584604F4740FAD4B14AE91D444076172829B0504740808120408622444076172829B05047408081204086224440CF15A584604F4740FAD4B14AE91D4440CF15A584604F4740
57013	2-й Россошинский	2	23	1220	40.179423999999997	40.211592000000003	46.697921999999998	46.690424999999998	0103000020E610000001000000050000000A0F9A5DF71644409FABADD85F5847400A0F9A5DF71644405794128255594740310C5872151B44405794128255594740310C5872151B44409FABADD85F5847400A0F9A5DF71644409FABADD85F584740
56715	1-й Россошинский	2	23	1220	40.252671999999997	40.417262000000001	46.692816999999998	46.673076999999999	0103000020E61000000100000005000000B54E5C8E572044404B581B6327564740B54E5C8E57204440718E3A3AAE58474089EE59D768354440718E3A3AAE58474089EE59D7683544404B581B6327564740B54E5C8E572044404B581B6327564740
32241	Шебалин	2	23	1766	43.601402999999998	43.630985000000003	47.369630999999998	47.357064000000001	0103000020E61000000100000005000000AF5B04C6FACC45401B4AED45B4AD4740AF5B04C6FACC45403C4B901150AF47401FA2D11DC4D045403C4B901150AF47401FA2D11DC4D045401B4AED45B4AD4740AF5B04C6FACC45401B4AED45B4AD4740
32329	Фомин	2	23	1766	43.636428000000002	43.682521000000001	46.967063000000003	46.952733000000002	0103000020E610000001000000050000001D21037976D14540F568AA27F37947401D21037976D14540F9156BB8C87B4740A7EA1ED95CD74540F9156BB8C87B4740A7EA1ED95CD74540F568AA27F37947401D21037976D14540F568AA27F3794740
32475	Федосеевка	2	23	1766	43.981121000000002	44.023980000000002	46.887442	46.858635999999997	0103000020E610000001000000050000009C35785F95FD45408995D1C8E76D47409C35785F95FD4540658C0FB39771474009E1D1C611034640658C0FB39771474009E1D1C6110346408995D1C8E76D47409C35785F95FD45408995D1C8E76D4740
32418	Тюльпаны	2	23	1766	43.656955000000004	43.676825999999998	46.833593	46.810414000000002	0103000020E61000000100000005000000CBF8F71917D445403B1C5DA5BB674740CBF8F71917D445405796E82CB36A47408F8AFF3BA2D645405796E82CB36A47408F8AFF3BA2D645403B1C5DA5BB674740CBF8F71917D445403B1C5DA5BB674740
32387	Савдя	2	23	1766	43.463099	43.494252000000003	46.792309000000003	46.775388999999997	0103000020E61000000100000005000000B8E7F9D346BB4540CD565EF23F634740B8E7F9D346BB4540CAA99D616A654740C6FD47A643BF4540CAA99D616A654740C6FD47A643BF4540CD565EF23F634740B8E7F9D346BB4540CD565EF23F634740
25203	Новобеляевский	2	23	1766	43.555356000000003	43.570267999999999	47.257305000000002	47.250821999999999	0103000020E6100000010000000500000096D1C8E715C74540048F6FEF1AA0474096D1C8E715C74540740CC85EEFA0474048FAB48AFEC84540740CC85EEFA0474048FAB48AFEC84540048F6FEF1AA0474096D1C8E715C74540048F6FEF1AA04740
25249	Никольский	2	23	1766	43.692106000000003	43.712668999999998	47.249322999999997	47.23554	0103000020E61000000100000005000000C5AEEDED96D845402E73BA2C269E4740C5AEEDED96D84540FF91E9D0E99F4740BFEFDFBC38DB4540FF91E9D0E99F4740BFEFDFBC38DB45402E73BA2C269E4740C5AEEDED96D845402E73BA2C269E4740
32168	Кичкино	2	23	1766	44.014898000000002	44.067619999999998	47.086561000000003	47.062154	0103000020E610000001000000050000004E637B2DE801464065A88AA9F48747404E637B2DE8014640F60D4C6E148B47401B47ACC5A7084640F60D4C6E148B47401B47ACC5A708464065A88AA9F48747404E637B2DE801464065A88AA9F4874740
32234	Киселевка	2	23	1766	44.119138	44.193131999999999	47.319490999999999	47.287422999999997	0103000020E61000000100000005000000FDDAFAE93F0F4640218FE046CAA44740FDDAFAE93F0F4640E42EC214E5A84740D1E7A38CB8184640E42EC214E5A84740D1E7A38CB8184640218FE046CAA44740FDDAFAE93F0F4640218FE046CAA44740
32093	Заветное	2	23	1766	43.858680999999997	43.940328999999998	47.137732999999997	47.097892999999999	0103000020E6100000010000000500000029594E42E9ED4540F0C000C2878C474029594E42E9ED45403C4A253CA19147407D3D5FB35CF845403C4A253CA19147407D3D5FB35CF84540F0C000C2878C474029594E42E9ED4540F0C000C2878C4740
25128	Андреев	2	23	1766	44.139853000000002	44.160612999999998	47.061264000000001	47.047142999999998	0103000020E61000000100000005000000AE9FFEB3E61146401F9E25C808864740AE9FFEB3E61146400936AE7FD7874740FE277FF78E1446400936AE7FD7874740FE277FF78E1446401F9E25C808864740AE9FFEB3E61146401F9E25C808864740
14644	Шаумяновский	2	23	1286	40.499763000000002	40.582721999999997	46.382508000000001	46.356552999999998	0103000020E610000001000000050000001C60E63BF83F444035255987A32D47401C60E63BF83F4440AC3AAB05F630474071546EA2964A4440AC3AAB05F630474071546EA2964A444035255987A32D47401C60E63BF83F444035255987A32D4740
14185	Украинский	2	23	1286	40.815009000000003	40.846359999999997	46.582487	46.560724	0103000020E610000001000000050000000C79043752684440890AD5CDC54747400C790437526844402EAC1BEF8E4A47403F524486556C44402EAC1BEF8E4A47403F524486556C4440890AD5CDC54747400C79043752684440890AD5CDC5474740
14237	Таганрогский	2	23	1286	40.683566999999996	40.701101999999999	46.678857999999998	46.661296	0103000020E61000000100000005000000FACF9A1F7F574440E17CEA58A5544740FACF9A1F7F5744406150A6D1E45647408194D8B5BD5944406150A6D1E45647408194D8B5BD594440E17CEA58A5544740FACF9A1F7F574440E17CEA58A5544740
13642	Тавричанка	2	23	1286	40.478284000000002	40.492297999999998	46.399695000000001	46.393093999999998	0103000020E610000001000000050000009C19FD68383D44407D2079E7503247409C19FD68383D4440F7AFAC34293347406FF1F09E033F4440F7AFAC34293347406FF1F09E033F44407D2079E7503247409C19FD68383D44407D2079E750324740
14851	Роговский	2	23	1286	40.605691999999998	40.642209000000001	46.435262999999999	46.421815000000002	0103000020E6100000010000000500000073B9C150874D44402BFBAE08FE35474073B9C150874D44405514AFB2B637474033198EE7335244405514AFB2B637474033198EE7335244402BFBAE08FE35474073B9C150874D44402BFBAE08FE354740
14381	Объединенный	2	23	1286	40.413103	40.475706000000002	46.625196000000003	46.599865000000001	0103000020E610000001000000050000009370218FE0344440ED815660C84C47409370218FE034444086CB2A6C06504740684128EFE33C444086CB2A6C06504740684128EFE33C4440ED815660C84C47409370218FE0344440ED815660C84C4740
14777	Новороговская	2	23	1286	40.647005999999998	40.701641000000002	46.344223999999997	46.329003999999998	0103000020E610000001000000050000006B28B517D1524440682096CD1C2A47406B28B517D1524440C83F33880F2C474031444E5FCF594440C83F33880F2C474031444E5FCF594440682096CD1C2A47406B28B517D1524440682096CD1C2A4740
14572	Мирный	2	23	1286	40.412582	40.426558999999997	46.408456999999999	46.395952999999999	0103000020E610000001000000050000008A75AA7CCF34444065E08096AE3247408A75AA7CCF3444404069A8514834474040683D7C993644404069A8514834474040683D7C9936444065E08096AE3247408A75AA7CCF34444065E08096AE324740
14458	Кугейский	2	23	1286	40.447212	40.548012	46.469678000000002	46.454127999999997	0103000020E610000001000000050000007B30293E3E3944405419C6DD203A47407B30293E3E3944404AD3A0681E3C474064E8D841254644404AD3A0681E3C474064E8D841254644405419C6DD203A47407B30293E3E3944405419C6DD203A4740
14711	Кавалерский	2	23	1286	40.324644999999997	40.506914000000002	46.351464999999997	46.337716	0103000020E61000000100000005000000ABE7A4F78D29444000AB23473A2B4740ABE7A4F78D29444025581CCEFC2C474039F1D58EE240444025581CCEFC2C474039F1D58EE240444000AB23473A2B4740ABE7A4F78D29444000AB23473A2B4740
14426	Ильинский	2	23	1286	40.473038000000003	40.539324999999998	46.535995	46.503737000000001	0103000020E61000000100000005000000F4E159828C3C444080643A747A404740F4E159828C3C4440E6E8F17B9B4447402575029A08454440E6E8F17B9B4447402575029A0845444080643A747A404740F4E159828C3C444080643A747A404740
14016	Изобильный	2	23	1286	40.553285000000002	40.582965000000002	46.664568000000003	46.659187000000003	0103000020E61000000100000005000000062FFA0AD24644406479573D60544740062FFA0AD2464440ECFB70901055474038DBDC989E4A4440ECFB70901055474038DBDC989E4A44406479573D60544740062FFA0AD24644406479573D60544740
13475	Егорлыкская	2	23	1286	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
14106	Войнов	2	23	1286	40.764325999999997	40.810194000000003	46.509566999999997	46.499276999999999	0103000020E61000000100000005000000C2BD326FD56144408F52094FE83F4740C2BD326FD5614440770FD07D394147402DB5DE6FB4674440770FD07D394147402DB5DE6FB46744408F52094FE83F4740C2BD326FD56144408F52094FE83F4740
14618	Балко-Грузский	2	23	1286	40.295836000000001	40.405681999999999	46.419038	46.395493000000002	0103000020E610000001000000050000005F7D3CF4DD2544400266BE839F3247405F7D3CF4DD25444000E48409A3354740B6494563ED33444000E48409A3354740B6494563ED3344400266BE839F3247405F7D3CF4DD2544400266BE839F324740
31893	Эркетиновская	2	23	480	42.992804	43.026724000000002	47.306232999999999	47.289171000000003	0103000020E6100000010000000500000043AB9333147F4540CFF9298E03A5474043AB9333147F45405DFA97A432A74740580229B16B8345405DFA97A432A74740580229B16B834540CFF9298E03A5474043AB9333147F4540CFF9298E03A54740
31503	Щеглов	2	23	480	42.622644000000001	42.654344999999999	47.404874999999997	47.395513000000001	0103000020E610000001000000050000007B8670CCB24F45404912842BA0B247407B8670CCB24F4540E7FBA9F1D2B347408BA6B393C1534540E7FBA9F1D2B347408BA6B393C15345404912842BA0B247407B8670CCB24F45404912842BA0B24740
31792	Семичный	2	23	480	42.978510999999997	43.007697999999998	47.494425	47.479841	0103000020E610000001000000050000005CE333D93F7D4540D5230D6E6BBD47405CE333D93F7D454093A9825149BF47404F1F813FFC80454093A9825149BF47404F1F813FFC804540D5230D6E6BBD47405CE333D93F7D4540D5230D6E6BBD4740
56735	Романов	2	23	480	42.733243999999999	42.758693999999998	47.367361000000002	47.352772000000002	0103000020E610000001000000050000007EFE7BF0DA5D4540E67805A227AD47407EFE7BF0DA5D4540B6696CAF05AF4740F1D58EE21C614540B6696CAF05AF4740F1D58EE21C614540E67805A227AD47407EFE7BF0DA5D4540E67805A227AD4740
32017	Присальский	2	23	480	43.240676000000001	43.273643999999997	47.066482000000001	47.046812000000003	0103000020E610000001000000050000004F779E78CE9E4540BA8784EFFD8547404F779E78CE9E4540E7E26F7B82884740915F3FC406A34540E7E26F7B82884740915F3FC406A34540BA8784EFFD8547404F779E78CE9E4540BA8784EFFD854740
39345	Подгоренская	2	23	480	42.372174999999999	42.384770000000003	47.571103999999998	47.557411999999999	0103000020E61000000100000005000000C4B12E6EA32F4540F032C34659C74740C4B12E6EA32F4540B14E95EF19C94740B03DB32440314540B14E95EF19C94740B03DB32440314540F032C34659C74740C4B12E6EA32F4540F032C34659C74740
31361	Новогашунский	2	23	480	42.798479999999998	42.820703999999999	47.246436000000003	47.231324000000001	0103000020E610000001000000050000004A41B79734664540D4635B069C9D47404A41B797346645404E4700378B9F474023D923D40C6945404E4700378B9F474023D923D40C694540D4635B069C9D47404A41B79734664540D4635B069C9D4740
32046	Мирный	2	23	480	43.192830999999998	43.220221000000002	46.915733000000003	46.901240999999999	0103000020E61000000100000005000000D653ABAFAE9845403C6876DD5B734740D653ABAFAE9845401A6F2BBD367547403B72A433309C45401A6F2BBD367547403B72A433309C45403C6876DD5B734740D653ABAFAE9845403C6876DD5B734740
31690	Малая Лучка	2	23	480	42.664217999999998	42.682327999999998	47.737496	47.72775	0103000020E610000001000000050000000FB56D1805554540FED478E926DD47400FB56D18055545402577D84466DE474092921E86565745402577D84466DE474092921E8656574540FED478E926DD47400FB56D1805554540FED478E926DD4740
56730	Лесной	2	23	480	42.341202000000003	42.362222000000003	47.488481999999998	47.479945000000001	0103000020E6100000010000000500000037AAD381AC2B45407A7077D66EBD474037AAD381AC2B4540A357039486BE474024F25D4A5D2E4540A357039486BE474024F25D4A5D2E45407A7077D66EBD474037AAD381AC2B45407A7077D66EBD4740
31648	Жуковская	2	23	480	42.490475000000004	42.518484000000001	47.633465000000001	47.611060000000002	0103000020E61000000100000005000000B84082E2C73E454067F2CD3637CE4740B84082E2C73E45409014916115D14740E8BF07AF5D4245409014916115D14740E8BF07AF5D42454067F2CD3637CE4740B84082E2C73E454067F2CD3637CE4740
31472	Ериковский	2	23	480	42.727665999999999	42.743000000000002	47.416662000000002	47.403863000000001	0103000020E61000000100000005000000A034D428245D4540408864C8B1B34740A034D428245D454034BE2F2E55B54740C976BE9F1A5F454034BE2F2E55B54740C976BE9F1A5F4540408864C8B1B34740A034D428245D4540408864C8B1B34740
25057	Дубовское	2	23	480	42.747563	42.784224000000002	47.425576	47.394072999999999	0103000020E610000001000000050000008E59F624B05F4540499EEBFB70B247408E59F624B05F454033FB3C4679B64740815EB8736164454033FB3C4679B64740815EB87361644540499EEBFB70B247408E59F624B05F4540499EEBFB70B24740
31815	Гуреев	2	23	480	43.246335000000002	43.275773000000001	47.348163	47.333813999999997	0103000020E610000001000000050000001A6EC0E7879F45403579CA6ABAAA47401A6EC0E7879F4540B056ED9A90AC4740560F98874CA34540B056ED9A90AC4740560F98874CA345403579CA6ABAAA47401A6EC0E7879F45403579CA6ABAAA4740
56760	Веселый	2	23	480	42.844608000000001	42.876409000000002	47.388655999999997	47.378821000000002	0103000020E6100000010000000500000051F86C1D1C6C4540DE04DF347DB0474051F86C1D1C6C454074B2D47ABFB14740C5758C2B2E70454074B2D47ABFB14740C5758C2B2E704540DE04DF347DB0474051F86C1D1C6C4540DE04DF347DB04740
31568	Вербовый Лог	2	23	480	42.585355	42.610183999999997	47.535893000000002	47.518923999999998	0103000020E6100000010000000500000069C6A2E9EC4A4540048E041A6CC2474069C6A2E9EC4A4540E2934E2498C447406F4562821A4E4540E2934E2498C447406F4562821A4E4540048E041A6CC2474069C6A2E9EC4A4540048E041A6CC24740
31876	Андреевская	2	23	480	43.021945000000002	43.054293000000001	47.373621999999997	47.353273000000002	0103000020E61000000100000005000000C6A70018CF824540A8C7B60C38AD4740C6A70018CF82454076887FD8D2AF47406CB3B112F386454076887FD8D2AF47406CB3B112F3864540A8C7B60C38AD4740C6A70018CF824540A8C7B60C38AD4740
2860	Алдабульский	2	23	480	42.610858	42.633899999999997	47.670532999999999	47.654730999999998	0103000020E61000000100000005000000FF3F4E98304E4540B456B439CED34740FF3F4E98304E4540C3F17C06D4D547409A779CA223514540C3F17C06D4D547409A779CA223514540B456B439CED34740FF3F4E98304E4540B456B439CED34740
30150	Ясырев	2	23	82	41.82441	41.852338000000003	47.499355999999999	47.488866000000002	0103000020E61000000100000005000000683F524486E944402C103D2993BE4740683F524486E94440DB87BCE5EABF4740AC915D6919ED4440DB87BCE5EABF4740AC915D6919ED44402C103D2993BE4740683F524486E944402C103D2993BE4740
30063	Холодный	2	23	82	41.713396000000003	41.740777000000001	47.510500999999998	47.499015	0103000020E61000000100000005000000728C648F50DB4440529B38B9DFBF4740728C648F50DB4440A3C9C51858C147408350DEC7D1DE4440A3C9C51858C147408350DEC7D1DE4440529B38B9DFBF4740728C648F50DB4440529B38B9DFBF4740
30511	Сухая Балка	2	23	82	42.217063000000003	42.228929999999998	47.461696000000003	47.451661000000001	0103000020E61000000100000005000000F9156BB8C81B454078F01307D0B94740F9156BB8C81B4540D658C2DA18BB4740618907944D1D4540D658C2DA18BB4740618907944D1D454078F01307D0B94740F9156BB8C81B454078F01307D0B94740
30199	Степной	2	23	82	41.882449999999999	41.906812000000002	47.474755999999999	47.468263	0103000020E61000000100000005000000772D211FF4F04440A376BF0AF0BB4740772D211FF4F0444036CAFACDC4BC474068CF656A12F4444036CAFACDC4BC474068CF656A12F44440A376BF0AF0BB4740772D211FF4F04440A376BF0AF0BB4740
30461	Солнечный	2	23	82	42.315078999999997	42.325004999999997	47.500810999999999	47.494272000000002	0103000020E6100000010000000500000004543882542845400DAA0D4E44BF47400454388254284540103D29931AC04740AB048BC399294540103D29931AC04740AB048BC3992945400DAA0D4E44BF474004543882542845400DAA0D4E44BF4740
28072	Сибирьковый	2	23	82	42.027329999999999	42.034768	47.429147999999998	47.423240999999997	0103000020E610000001000000050000008F19A88C7F034540C5A9D6C22CB647408F19A88C7F03454068925852EEB6474042791F477304454068925852EEB6474042791F4773044540C5A9D6C22CB647408F19A88C7F034540C5A9D6C22CB64740
31010	Семенкин	2	23	82	42.082208000000001	42.097498000000002	47.349836000000003	47.337563000000003	0103000020E610000001000000050000001BBCAFCA850A45407AABAE4335AB47401BBCAFCA850A4540537B116DC7AC474074B680D07A0C4540537B116DC7AC474074B680D07A0C45407AABAE4335AB47401BBCAFCA850A45407AABAE4335AB4740
30582	Саловский	2	23	82	42.249178000000001	42.258412999999997	47.411009999999997	47.401667000000003	0103000020E61000000100000005000000FC709010E51F4540F47002D369B34740FC709010E51F45401B2AC6F99BB447403DEE5BAD132145401B2AC6F99BB447403DEE5BAD13214540F47002D369B34740FC709010E51F4540F47002D369B34740
30294	Савельевский	2	23	82	41.861258999999997	41.866531999999999	47.360945999999998	47.357216000000001	0103000020E610000001000000050000005D3123BC3DEE4440D1CDFE40B9AD47405D3123BC3DEE44409ECF807A33AE4740FF774485EAEE44409ECF807A33AE4740FF774485EAEE4440D1CDFE40B9AD47405D3123BC3DEE4440D1CDFE40B9AD4740
30093	Рябичев	2	23	82	41.767789	41.789563999999999	47.523336	47.497596000000001	0103000020E61000000100000005000000419DF2E846E244406A4FC939B1BF4740419DF2E846E24440E4688EACFCC24740AA0CE36E10E54440E4688EACFCC24740AA0CE36E10E544406A4FC939B1BF4740419DF2E846E244406A4FC939B1BF4740
27914	Романовская	2	23	82	42.010809999999999	42.054549000000002	47.550333000000002	47.530211000000001	0103000020E61000000100000005000000213CDA38620145405F7D3CF4DDC34740213CDA38620145406D74CE4F71C64740C7832D76FB0645406D74CE4F71C64740C7832D76FB0645405F7D3CF4DDC34740213CDA38620145405F7D3CF4DDC34740
30646	Прогресс	2	23	82	41.784883999999998	41.794694	47.427947000000003	47.421168000000002	0103000020E61000000100000005000000AB93331477E44440950F41D5E8B54740AB93331477E44440EEB5A0F7C6B64740E9297288B8E54440EEB5A0F7C6B64740E9297288B8E54440950F41D5E8B54740AB93331477E44440950F41D5E8B54740
99	Потапов	2	23	82	41.926026999999998	41.961008	47.478805999999999	47.463414	0103000020E61000000100000005000000431B800D88F644401841632651BB4740431B800D88F644407590D78349BD4740E198654F02FB44407590D78349BD4740E198654F02FB44401841632651BB4740431B800D88F644401841632651BB4740
31100	Погожев	2	23	82	42.073926	42.086053	47.551318999999999	47.545431000000001	0103000020E610000001000000050000007C293C6876094540BF9CD9AED0C547407C293C6876094540EB54F99E91C64740815CE2C8030B4540EB54F99E91C64740815CE2C8030B4540BF9CD9AED0C547407C293C6876094540BF9CD9AED0C54740
30766	Победа	2	23	82	41.645358000000002	41.662757999999997	47.424892999999997	47.416516000000001	0103000020E61000000100000005000000221B48179BD244406021736550B54740221B48179BD2444050A6D1E462B64740C8940F41D5D4444050A6D1E462B64740C8940F41D5D444406021736550B54740221B48179BD244406021736550B54740
29850	Пирожок	2	23	82	41.416753999999997	41.440398000000002	47.526822000000003	47.517214000000003	0103000020E61000000100000005000000143DF03158B5444045847F1134C24740143DF03158B544401B683EE76EC34740A69C2FF65EB844401B683EE76EC34740A69C2FF65EB8444045847F1134C24740143DF03158B5444045847F1134C24740
29942	Морозов	2	23	82	41.568075999999998	41.595429000000003	47.525872999999997	47.513745	0103000020E610000001000000050000003DD2E0B6B6C84440E4BD6A65C2C147403DD2E0B6B6C84440B96C74CE4FC34740850B790437CC4440B96C74CE4FC34740850B790437CC4440E4BD6A65C2C147403DD2E0B6B6C84440E4BD6A65C2C14740
30367	Мокросоленый	2	23	82	42.298738	42.323144999999997	47.503293999999997	47.486941999999999	0103000020E610000001000000050000004609FA0B3D26454040868E1D54BE47404609FA0B3D264540F22213F06BC04740D66EBBD05C294540F22213F06BC04740D66EBBD05C29454040868E1D54BE47404609FA0B3D26454040868E1D54BE4740
30781	Мичуринский	2	23	82	41.591988999999998	41.600954000000002	47.424118999999997	47.416876000000002	0103000020E61000000100000005000000BE4BA94BC6CB4440603E59315CB54740BE4BA94BC6CB44405D4E098849B647404033880FECCC44405D4E098849B647404033880FECCC4440603E59315CB54740BE4BA94BC6CB4440603E59315CB54740
31048	Лагутники	2	23	82	42.056139000000002	42.074967999999998	47.531750000000002	47.516046000000003	0103000020E61000000100000005000000DC8310902F074540A69D9ACB0DC24740DC8310902F074540F2D24D6210C447408E1F2A8D98094540F2D24D6210C447408E1F2A8D98094540A69D9ACB0DC24740DC8310902F074540A69D9ACB0DC24740
30964	Краснодонский	2	23	82	41.420976000000003	41.436356000000004	47.443531999999998	47.432574000000002	0103000020E610000001000000050000005133A48AE2B54440CA8CB7955EB747405133A48AE2B544405F5D15A8C5B84740EAB46E83DAB744405F5D15A8C5B84740EAB46E83DAB74440CA8CB7955EB747405133A48AE2B54440CA8CB7955EB74740
30362	Калинин	2	23	82	41.874822999999999	41.884704999999997	47.336573999999999	47.332495000000002	0103000020E61000000100000005000000F1643733FAEF4440B18A37328FAA4740F1643733FAEF44408A5759DB14AB4740C8CD70033EF144408A5759DB14AB4740C8CD70033EF14440B18A37328FAA4740F1643733FAEF4440B18A37328FAA4740
29911	Дубенцовская	2	23	82	41.464193999999999	41.511490999999999	47.534481999999997	47.513263999999999	0103000020E61000000100000005000000ED7F80B56ABB4440691B7FA2B2C14740ED7F80B56ABB44407C26FBE769C4474063997E8978C144407C26FBE769C4474063997E8978C14440691B7FA2B2C14740ED7F80B56ABB4440691B7FA2B2C14740
30877	Донской	2	23	82	41.507914999999997	41.523311999999997	47.417442999999999	47.407125000000001	0103000020E61000000100000005000000EC12D55B03C14440273108AC1CB44740EC12D55B03C14440D978B0C56EB547405BCD3AE3FBC24440D978B0C56EB547405BCD3AE3FBC24440273108AC1CB44740EC12D55B03C14440273108AC1CB44740
40369	Виноградный	2	23	82	41.713405000000002	41.722918	47.426070000000003	47.419564999999999	0103000020E61000000100000005000000C5E6E3DA50DB4440EBC5504EB4B54740C5E6E3DA50DB444043E7357689B6474049D8B79388DC444043E7357689B6474049D8B79388DC4440EBC5504EB4B54740C5E6E3DA50DB4440EBC5504EB4B54740
30003	Большовская	2	23	82	41.642510000000001	41.669620999999999	47.520999000000003	47.509892000000001	0103000020E610000001000000050000002EAD86C43DD24440FB3E1C2444C147402EAD86C43DD24440D61F6118B0C247407FDB1324B6D54440D61F6118B0C247407FDB1324B6D54440FB3E1C2444C147402EAD86C43DD24440FB3E1C2444C14740
56779	Чаканиха	2	23	1846	40.816167999999998	40.835419000000002	47.278792000000003	47.271864999999998	0103000020E6100000010000000500000057056A3178684440A9F6E978CCA2474057056A31786844407731CD74AFA3474080BA8102EF6A44407731CD74AFA3474080BA8102EF6A4440A9F6E978CCA2474057056A3178684440A9F6E978CCA24740
29332	Средний Маныч	2	23	1846	40.667774999999999	40.6937	47.235931999999998	47.217126999999998	0103000020E610000001000000050000000F0BB5A6795544400F0A4AD1CA9B47400F0BB5A679554440390A1005339E47401B9E5E29CB584440390A1005339E47401B9E5E29CB5844400F0A4AD1CA9B47400F0BB5A6795544400F0A4AD1CA9B4740
56946	Спорный	2	23	1846	40.749782000000003	40.769131999999999	47.139284000000004	47.123694	0103000020E61000000100000005000000939048DBF85F4440105B7A34D58F4740939048DBF85F4440946DE00ED49147404E27D9EA72624440946DE00ED49147404E27D9EA72624440105B7A34D58F4740939048DBF85F4440105B7A34D58F4740
56868	Свобода	2	23	1846	40.635947999999999	40.673515000000002	47.190280999999999	47.175454000000002	0103000020E6100000010000000500000072FA7ABE66514440E8F9D3467596474072FA7ABE665144406C06B8205B984740C72E51BD355644406C06B8205B984740C72E51BD35564440E8F9D3467596474072FA7ABE66514440E8F9D34675964740
29518	Садковский	2	23	1846	40.982337999999999	40.993485999999997	47.290771999999997	47.282991000000003	0103000020E610000001000000050000001CCF6740BD7D4440FB07910C39A447401CCF6740BD7D4440D74B530438A5474055849B8C2A7F4440D74B530438A5474055849B8C2A7F4440FB07910C39A447401CCF6740BD7D4440FB07910C39A44740
56895	Проциков	2	23	1846	40.682022000000003	40.703187	47.020198999999998	47.010092999999998	0103000020E610000001000000050000008693347F4C574440927538BA4A8147408693347F4C574440B9347EE19582474076FC1708025A4440B9347EE19582474076FC1708025A4440927538BA4A8147408693347F4C574440927538BA4A814740
56753	Позднеевка	2	23	1846	40.606842	40.629004000000002	47.099665999999999	47.071686	0103000020E610000001000000050000006CEBA7FFAC4D444060CAC0012D8947406CEBA7FFAC4D4440F64201DBC18C4740CF86FC3383504440F64201DBC18C4740CF86FC338350444060CAC0012D8947406CEBA7FFAC4D444060CAC0012D894740
56792	Новый	2	23	1846	40.715232999999998	40.731043	47.260216	47.255623	0103000020E610000001000000050000008E0244C18C5B44407E8D2441B8A047408E0244C18C5B4440AEF204C24EA14740207C28D1925D4440AEF204C24EA14740207C28D1925D44407E8D2441B8A047408E0244C18C5B44407E8D2441B8A04740
56774	Нижнесоленый	2	23	1846	40.768304999999998	40.813822999999999	47.242685999999999	47.218564999999998	0103000020E61000000100000005000000382D78D1576244406E861BF0F99B4740382D78D1576244403999B855109F4740C6DD205A2B6844403999B855109F4740C6DD205A2B6844406E861BF0F99B4740382D78D1576244406E861BF0F99B4740
56894	Маныч-Балабинка	2	23	1846	40.741697000000002	40.755476999999999	47.166516000000001	47.152644000000002	0103000020E610000001000000050000004A4563EDEF5E44401FF7ADD6899347404A4563EDEF5E44406021736550954740AAF06778B36044406021736550954740AAF06778B36044401FF7ADD6899347404A4563EDEF5E44401FF7ADD689934740
56727	Малая Западенка	2	23	1846	40.549053999999998	40.581752000000002	47.170743000000002	47.162723999999997	0103000020E6100000010000000500000076DEC666474644401C23D923D494474076DEC66647464440AE8218E8DA954740F9307BD9764A4440AE8218E8DA954740F9307BD9764A44401C23D923D494474076DEC666474644401C23D923D4944740
56702	Ленинский	2	23	1846	40.880783000000001	40.906959999999998	47.181842000000003	47.172066999999998	0103000020E61000000100000005000000B7EF517FBD70444044DC9C4A06964740B7EF517FBD7044400685419946974740DC63E943177444400685419946974740DC63E9431774444044DC9C4A06964740B7EF517FBD70444044DC9C4A06964740
56679	Красный Октябрь	2	23	1846	40.974828000000002	41.009593000000002	47.037894999999999	47.016544000000003	0103000020E61000000100000005000000D09CF529C77C4440F778211D1E824740D09CF529C77C444049D74CBED9844740A1A2EA573A81444049D74CBED9844740A1A2EA573A814440F778211D1E824740D09CF529C77C4440F778211D1E824740
46289	Красный Маныч	2	23	1846	41.097475000000003	41.151113000000002	46.991501999999997	46.974215000000001	0103000020E61000000100000005000000BC96900F7A8C4440E622BE13B37C4740BC96900F7A8C444094F59B89E97E47400F80B8AB5793444094F59B89E97E47400F80B8AB57934440E622BE13B37C4740BC96900F7A8C4440E622BE13B37C4740
29273	Красный Кут	2	23	1846	40.655135999999999	40.680557999999998	47.108252999999998	47.095353000000003	0103000020E610000001000000050000005437177FDB534440AA49F086348C47405437177FDB534440D158FB3BDB8D4740FD8348861C574440D158FB3BDB8D4740FD8348861C574440AA49F086348C47405437177FDB534440AA49F086348C4740
28419	Красное Знамя	2	23	1846	40.529659000000002	40.546151999999999	47.115293000000001	47.091861999999999	0103000020E610000001000000050000001B84B9DDCB43444061DF4E22C28B47401B84B9DDCB434440973AC8EBC18E47408F52094FE8454440973AC8EBC18E47408F52094FE845444061DF4E22C28B47401B84B9DDCB43444061DF4E22C28B4740
56827	Каракашев	2	23	1846	40.825958999999997	40.859349999999999	47.072975	47.058275000000002	0103000020E610000001000000050000001E6B4606B96944405396218E758747401E6B4606B96944407A36AB3E57894740A7E8482EFF6D44407A36AB3E57894740A7E8482EFF6D44405396218E758747401E6B4606B96944405396218E75874740
56935	Казачий	2	23	1846	40.898102999999999	40.921396000000001	47.061036999999999	47.042157000000003	0103000020E6100000010000000500000041B8020AF572444014268C666585474041B8020AF5724440486C770FD08747402655DB4DF0754440486C770FD08747402655DB4DF075444014268C666585474041B8020AF572444014268C6665854740
28782	Веселый	2	23	1846	40.722617	40.796503999999999	47.102173999999998	47.073625999999997	0103000020E610000001000000050000004E44BFB67E5C44405111A7936C8947404E44BFB67E5C44403140A209148D47400C91D3D7F36544403140A209148D47400C91D3D7F36544405111A7936C8947404E44BFB67E5C44405111A7936C894740
29069	Верхний Хомутец	2	23	1846	40.736604	40.779812999999997	46.983277000000001	46.970512999999997	0103000020E61000000100000005000000280D350A495E4440E2AB1DC5397C4740280D350A495E44405AF44E05DC7D474071FF91E9D06344405AF44E05DC7D474071FF91E9D0634440E2AB1DC5397C4740280D350A495E4440E2AB1DC5397C4740
56661	Верхнесоленый	2	23	1846	40.812916000000001	40.828932999999999	47.248294999999999	47.224691	0103000020E610000001000000050000009432A9A10D6844404F5AB8ACC29C47409432A9A10D68444052616C21C89F47409FC9FE791A6A444052616C21C89F47409FC9FE791A6A44404F5AB8ACC29C47409432A9A10D6844404F5AB8ACC29C4740
21338	Шумилинская	2	23	1585	41.415146	41.465164999999999	49.990591999999999	49.931981	0103000020E6100000010000000500000059880E8123B5444027BF45274BF7484059880E8123B54440F1D6F9B7CBFE4840361FD7868ABB4440F1D6F9B7CBFE4840361FD7868ABB444027BF45274BF7484059880E8123B5444027BF45274BF74840
56842	Тубянский	2	23	1585	41.127470000000002	41.161479999999997	49.788041999999997	49.769910000000003	0103000020E610000001000000050000004E9CDCEF50904440836E2F698CE248404E9CDCEF50904440EDEF6C8FDEE44840A27A6B60AB944440EDEF6C8FDEE44840A27A6B60AB944440836E2F698CE248404E9CDCEF50904440836E2F698CE24840
20106	Суходольный	2	23	1585	41.002837999999997	41.019798000000002	49.616948000000001	49.609440999999997	0103000020E61000000100000005000000D097DEFE5C804440B7EBA52902CE4840D097DEFE5C80444093AAED26F8CE48405B43A9BD8882444093AAED26F8CE48405B43A9BD88824440B7EBA52902CE4840D097DEFE5C804440B7EBA52902CE4840
20962	Суровский	2	23	1585	41.081710000000001	41.112827000000003	49.803150000000002	49.795229999999997	0103000020E61000000100000005000000CAE02879758A44402766BD18CAE54840CAE02879758A444026E4839ECDE648408B8D791D718E444026E4839ECDE648408B8D791D718E44402766BD18CAE54840CAE02879758A44402766BD18CAE54840
21214	Стоговской	2	23	1585	41.177030000000002	41.211255999999999	49.747062999999997	49.728019000000003	0103000020E61000000100000005000000983446EBA8964440EEEE01BA2FDD4840983446EBA89644409C86A8C29FDF4840B98AC56F0A9B44409C86A8C29FDF4840B98AC56F0A9B4440EEEE01BA2FDD4840983446EBA8964440EEEE01BA2FDD4840
21052	Солонцовский	2	23	1585	41.305121	41.323841999999999	49.822808999999999	49.784460000000003	0103000020E61000000100000005000000522976340EA7444095826E2F69E44840522976340EA744405FED28CE51E948401E8997A773A944405FED28CE51E948401E8997A773A9444095826E2F69E44840522976340EA7444095826E2F69E44840
21374	Свидовский	2	23	1585	41.398698000000003	41.425324000000003	49.930253	49.909917999999998	0103000020E61000000100000005000000857D3B8908B3444057056A3178F44840857D3B8908B34440C100C28712F748401A1A4F0471B64440C100C28712F748401A1A4F0471B6444057056A3178F44840857D3B8908B3444057056A3178F44840
20795	Раскольный	2	23	1585	41.511383000000002	41.528064999999998	50.076680000000003	50.061844000000001	0103000020E610000001000000050000007D5D86FF74C1444017BA1281EA0749407D5D86FF74C14440EF2076A6D0094940C49448A297C34440EF2076A6D0094940C49448A297C3444017BA1281EA0749407D5D86FF74C1444017BA1281EA074940
20603	Придонский	2	23	1585	41.108460999999998	41.118541	49.717028999999997	49.708938000000003	0103000020E610000001000000050000001BF2CF0CE28D44402272FA7ABEDA48401BF2CF0CE28D44404CA4349BC7DB4840191EFB592C8F44404CA4349BC7DB4840191EFB592C8F44402272FA7ABEDA48401BF2CF0CE28D44402272FA7ABEDA4840
19846	Поповка	2	23	1585	41.073436000000001	41.113663000000003	49.823988999999997	49.811177999999998	0103000020E61000000100000005000000AE2CD159668944400A9E42AED4E74840AE2CD15966894440C2A1B77878E94840F4E159828C8E4440C2A1B77878E94840F4E159828C8E44400A9E42AED4E74840AE2CD159668944400A9E42AED4E74840
19435	Поздняковский	2	23	1585	40.734375999999997	40.767147000000001	49.627305999999997	49.602967	0103000020E61000000100000005000000D07B6308005E44409BC8CC052ECD4840D07B6308005E4440D34A21904BD04840BD1C76DF31624440D34A21904BD04840BD1C76DF316244409BC8CC052ECD4840D07B6308005E44409BC8CC052ECD4840
21423	Песковатская Лопатина	2	23	1585	41.316052999999997	41.349469999999997	49.989671000000001	49.976551999999998	0103000020E61000000100000005000000BE66B96C74A84440F46BEBA7FFFC4840BE66B96C74A844405A66118AADFE48407077D66EBBAC44405A66118AADFE48407077D66EBBAC4440F46BEBA7FFFC4840BE66B96C74A84440F46BEBA7FFFC4840
20996	Парижский	2	23	1585	41.368712000000002	41.40372	50.163103	50.151474	0103000020E6100000010000000500000046D26EF431AF4440DF1802806313494046D26EF431AF44409370218FE0144940DD5ED218ADB344409370218FE0144940DD5ED218ADB34440DF1802806313494046D26EF431AF4440DF18028063134940
19387	Павловский	2	23	1585	40.762070999999999	40.779381999999998	49.600591000000001	49.581139	0103000020E61000000100000005000000711DE38A8B6144400FB743C362CA4840711DE38A8B614440CFA2772AE0CC4840A88B14CAC2634440CFA2772AE0CC4840A88B14CAC26344400FB743C362CA4840711DE38A8B6144400FB743C362CA4840
20849	Новониколаевский	2	23	1585	41.467382999999998	41.490837999999997	50.066839999999999	50.053480999999998	0103000020E610000001000000050000006ADAC534D3BB44408BFA2477D80649406ADAC534D3BB444046088F368E08494028D192C7D3BE444046088F368E08494028D192C7D3BE44408BFA2477D80649406ADAC534D3BB44408BFA2477D8064940
20249	Нижнетиховский	2	23	1585	41.224604999999997	41.264606999999998	49.567259	49.553964999999998	0103000020E6100000010000000500000050C24CDBBF9C444077103B53E8C6484050C24CDBBF9C44404BAE62F19BC8484076A565A4DEA144404BAE62F19BC8484076A565A4DEA1444077103B53E8C6484050C24CDBBF9C444077103B53E8C64840
20001	Назаровский	2	23	1585	40.912692	40.955730000000003	49.563308999999997	49.536510999999997	0103000020E6100000010000000500000011A96917D3744440DD787764ACC4484011A96917D37444406F4562821AC848402EE7525C557A44406F4562821AC848402EE7525C557A4440DD787764ACC4484011A96917D3744440DD787764ACC44840
20124	Мрыховский	2	23	1585	41.142032	41.210160000000002	49.626080999999999	49.593390999999997	0103000020E61000000100000005000000247EC51A2E924440D05E7D3CF4CB4840247EC51A2E924440D0D2156C23D04840B476DB85E69A4440D0D2156C23D04840B476DB85E69A4440D05E7D3CF4CB4840247EC51A2E924440D05E7D3CF4CB4840
19241	Михайловский	2	23	1585	40.853448	40.872393000000002	49.653751	49.647258999999998	0103000020E61000000100000005000000166BB8C83D6D444055850662D9D24840166BB8C83D6D4440185DDE1CAED348403221E692AA6F4440185DDE1CAED348403221E692AA6F444055850662D9D24840166BB8C83D6D444055850662D9D24840
20452	Мигулинская	2	23	1585	41.248949000000003	41.269582999999997	49.709071999999999	49.679440999999997	0103000020E610000001000000050000009BAF928FDD9F4440E04735ECF7D648409BAF928FDD9F444031410DDFC2DA48405E471CB281A2444031410DDFC2DA48405E471CB281A24440E04735ECF7D648409BAF928FDD9F4440E04735ECF7D64840
20213	Мещеряковский	2	23	1585	41.189382000000002	41.251752000000003	49.594330999999997	49.556798999999998	0103000020E61000000100000005000000BD395CAB3D98444006B98B3045C74840BD395CAB3D984440DEFFC70913CC4840EF59D76839A04440DEFFC70913CC4840EF59D76839A0444006B98B3045C74840BD395CAB3D98444006B98B3045C74840
19981	Мешковская	2	23	1585	40.935310999999999	41.034979	49.554577999999999	49.516378000000003	0103000020E61000000100000005000000664B5645B8774440DC2F9FAC18C24840664B5645B8774440618A7269FCC64840FD851E317A844440618A7269FCC64840FD851E317A844440DC2F9FAC18C24840664B5645B8774440DC2F9FAC18C24840
19904	Меловатский	2	23	1585	41.029696999999999	41.065055000000001	49.528202999999998	49.507919999999999	0103000020E6100000010000000500000008E57D1CCD834440FE7DC68503C1484008E57D1CCD8344401553E9279CC348407CB8E4B8538844401553E9279CC348407CB8E4B853884440FE7DC68503C1484008E57D1CCD834440FE7DC68503C14840
19161	Макаровский	2	23	1585	40.879598000000001	40.901166000000003	49.683323000000001	49.66816	0103000020E6100000010000000500000042D0D1AA96704440683F524486D5484042D0D1AA9670444064CDC82077D74840322251685973444064CDC82077D748403222516859734440683F524486D5484042D0D1AA96704440683F524486D54840
19814	Кукуевский	2	23	1585	41.109495000000003	41.146343000000002	49.828673000000002	49.798428000000001	0103000020E61000000100000005000000AB09A2EE038E4440F81A82E332E64840AB09A2EE038E4440030AF5F411EA4840D07F0F5EBB924440030AF5F411EA4840D07F0F5EBB924440F81A82E332E64840AB09A2EE038E4440F81A82E332E64840
20519	Коноваловский	2	23	1585	41.099460000000001	41.146577000000001	49.649697000000003	49.622228999999997	0103000020E610000001000000050000004DA1F31ABB8C4440B7CF2A33A5CF48404DA1F31ABB8C444098A7734529D3484043ACFE08C392444098A7734529D3484043ACFE08C3924440B7CF2A33A5CF48404DA1F31ABB8C4440B7CF2A33A5CF4840
19773	Колодезный	2	23	1585	41.145077000000001	41.169322000000001	49.976962999999998	49.952823000000002	0103000020E610000001000000050000006E3315E29192444035F0A31AF6F948406E3315E2919244407633A31F0DFD4840253FE257AC9544407633A31F0DFD4840253FE257AC95444035F0A31AF6F948406E3315E29192444035F0A31AF6F94840
56817	Каменный	2	23	1585	41.346093000000003	41.361984	50.024124999999998	50.021022000000002	0103000020E61000000100000005000000F12F82C64CAC44408E3F51D9B0024940F12F82C64CAC44400C022B87160349406FD6E07D55AE44400C022B87160349406FD6E07D55AE44408E3F51D9B0024940F12F82C64CAC44408E3F51D9B0024940
19675	Казанская Лопатина	2	23	1585	41.228701000000001	41.259099999999997	49.944828999999999	49.919170000000001	0103000020E6100000010000000500000000C80913469D44406FBBD05CA7F5484000C80913469D4440FCA71B28F0F84840613255302AA14440FCA71B28F0F84840613255302AA144406FBBD05CA7F5484000C80913469D44406FBBD05CA7F54840
19483	Казанская	2	23	1585	41.129795999999999	41.172341000000003	49.802439999999997	49.780800999999997	0103000020E610000001000000050000006893C3279D90444090D78349F1E348406893C3279D90444049809A5AB6E64840466117450F96444049809A5AB6E64840466117450F96444090D78349F1E348406893C3279D90444090D78349F1E34840
21096	Заикинский	2	23	1585	41.196820000000002	41.215288999999999	49.776600999999999	49.763609000000002	0103000020E610000001000000050000007099D3653199444034F790F0BDE148407099D365319944403C855CA967E34840221807978E9B44403C855CA967E34840221807978E9B444034F790F0BDE148407099D3653199444034F790F0BDE14840
20719	Дубровский	2	23	1585	41.389023000000002	41.422764000000001	49.763528000000001	49.748448000000003	0103000020E6100000010000000500000027327381CBB14440D960E124CDDF484027327381CBB1444047CA1649BBE148408CF678211DB6444047CA1649BBE148408CF678211DB64440D960E124CDDF484027327381CBB14440D960E124CDDF4840
21212	Гормиловский	2	23	1585	41.161372	41.173751000000003	49.771982000000001	49.758831000000001	0103000020E61000000100000005000000BC3E73D6A79444407218CC5F21E14840BC3E73D6A7944440E38C614ED0E24840DB5207793D964440E38C614ED0E24840DB5207793D9644407218CC5F21E14840BC3E73D6A79444407218CC5F21E14840
19300	Верхняковский	2	23	1585	40.760247999999997	40.891697999999998	49.591143000000002	49.570442999999997	0103000020E61000000100000005000000B96C74CE4F614440B69DB64604C94840B96C74CE4F6144403221E692AACB48404DF4F928237244403221E692AACB48404DF4F92823724440B69DB64604C94840B96C74CE4F614440B69DB64604C94840
20682	Быковский	2	23	1585	41.443568999999997	41.518892999999998	49.897728000000001	49.862551000000003	0103000020E610000001000000050000007C4276DEC6B84440E910381268EE48407C4276DEC6B844400C5A48C0E8F24840C98FF8156BC244400C5A48C0E8F24840C98FF8156BC24440E910381268EE48407C4276DEC6B84440E910381268EE4840
20354	Бирюковский	2	23	1585	41.123804999999997	41.177137999999999	49.546559999999999	49.525255999999999	0103000020E61000000100000005000000670A9DD7D88F44408E03AF963BC34840670A9DD7D88F4440A0A696ADF5C548407E703E75AC964440A0A696ADF5C548407E703E75AC9644408E03AF963BC34840670A9DD7D88F44408E03AF963BC34840
20424	Алексеевский	2	23	1585	41.124217999999999	41.154328999999997	49.472498999999999	49.437666999999998	0103000020E610000001000000050000008AC91B60E68F4440EBC4E57805B848408AC91B60E68F44404432E4D87ABC484085E97B0DC19344404432E4D87ABC484085E97B0DC1934440EBC4E57805B848408AC91B60E68F4440EBC4E57805B84840
18555	Яблоновский	2	23	1522	41.385367000000002	41.427596999999999	49.287350000000004	49.264915000000002	0103000020E6100000010000000500000094FAB2B453B14440249C16BCE8A1484094FAB2B453B14440B84082E2C7A44840116F9D7FBBB64440B84082E2C7A44840116F9D7FBBB64440249C16BCE8A1484094FAB2B453B14440249C16BCE8A14840
31367	Свиридов	2	23	1522	41.902509000000002	41.922353000000001	49.179625999999999	49.165779000000001	0103000020E610000001000000050000003FAC376A85F344408AAE0B3F389548403FAC376A85F3444072C119FCFD9648400A2FC1A90FF6444072C119FCFD9648400A2FC1A90FF644408AAE0B3F389548403FAC376A85F344408AAE0B3F38954840
18801	Попов	2	23	1522	41.772315999999996	41.816693000000001	49.303659000000003	49.278399	0103000020E61000000100000005000000B9162D40DBE244409B1E1494A2A34840B9162D40DBE244406B11514CDEA64840A2EF6E6589E844406B11514CDEA64840A2EF6E6589E844409B1E1494A2A34840B9162D40DBE244409B1E1494A2A34840
18383	Пономаревка	2	23	1522	41.704754000000001	41.723978000000002	49.203265999999999	49.178814000000003	0103000020E61000000100000005000000D3DC0A6135DA444092088D60E3964840D3DC0A6135DA4440C231CB9E049A48400283A44FABDC4440C231CB9E049A48400283A44FABDC444092088D60E3964840D3DC0A6135DA444092088D60E3964840
18343	Малаховский	2	23	1522	41.707493999999997	41.755087000000003	49.147638000000001	49.127426999999997	0103000020E61000000100000005000000E00ED4298FDA44404ED026874F904840E00ED4298FDA4440CCD24ECDE59248404051D9B0A6E04440CCD24ECDE59248404051D9B0A6E044404ED026874F904840E00ED4298FDA44404ED026874F904840
18983	Лиховидовский	2	23	1522	41.575082000000002	41.607979	49.389482999999998	49.364607999999997	0103000020E61000000100000005000000574277499CC9444013EE9579ABAE4840574277499CC944408AAC3594DAB14840D0D38041D2CD44408AAC3594DAB14840D0D38041D2CD444013EE9579ABAE4840574277499CC9444013EE9579ABAE4840
18650	Латышев	2	23	1522	41.690426000000002	41.728434	49.350952999999997	49.325237000000001	0103000020E61000000100000005000000702711E15FD844407E39B35DA1A94840702711E15FD844406FB72407ECAC4840B1A547533DDD44406FB72407ECAC4840B1A547533DDD44407E39B35DA1A94840702711E15FD844407E39B35DA1A94840
17926	Краснокутская	2	23	1522	41.940157999999997	41.969290000000001	49.161625999999998	49.145104000000003	0103000020E610000001000000050000005089EB1857F84440684293C4929248405089EB1857F8444076172829B0944840802BD9B111FC444076172829B0944840802BD9B111FC4440684293C4929248405089EB1857F84440684293C492924840
18484	Краснозоринский	2	23	1522	41.524434999999997	41.556406000000003	49.277565000000003	49.257694999999998	0103000020E610000001000000050000005AF0A2AF20C34440DEAB5626FCA048405AF0A2AF20C34440D3C1FA3F87A348402BA6D24F38C74440D3C1FA3F87A348402BA6D24F38C74440DEAB5626FCA048405AF0A2AF20C34440DEAB5626FCA04840
18778	Коньков	2	23	1522	41.796993000000001	41.84393	49.272486000000001	49.253515	0103000020E610000001000000050000000A12DBDD03E64440D105F52D73A048400A12DBDD03E64440164F3DD2E0A24840800EF3E505EC4440164F3DD2E0A24840800EF3E505EC4440D105F52D73A048400A12DBDD03E64440D105F52D73A04840
18715	Климовка	2	23	1522	41.496668	41.569082000000002	49.351891999999999	49.318795000000001	0103000020E61000000100000005000000207C28D192BF44406D904946CEA84840207C28D192BF4440ADDC0BCC0AAD4840035FD1ADD7C84440ADDC0BCC0AAD4840035FD1ADD7C844406D904946CEA84840207C28D192BF44406D904946CEA84840
18627	Каргинская	2	23	1522	41.610072000000002	41.690480000000001	49.363024000000003	49.338510999999997	0103000020E61000000100000005000000481ADCD616CE44400A2B155454AB4840481ADCD616CE4440E1D4079277AE484063450DA661D84440E1D4079277AE484063450DA661D844400A2B155454AB4840481ADCD616CE44400A2B155454AB4840
18061	Каменка	2	23	1522	42.023566000000002	42.035998999999997	49.188187999999997	49.170068000000001	0103000020E6100000010000000500000016A6EF35040345404E0CC9C9C495484016A6EF3504034540F4BF5C8B1698484027D87F9D9B044540F4BF5C8B1698484027D87F9D9B0445404E0CC9C9C495484016A6EF35040345404E0CC9C9C4954840
18011	Илларионов	2	23	1522	41.990571000000003	42.009759000000003	49.141657000000002	49.132114000000001	0103000020E61000000100000005000000DAAED007CBFE444000AC8E1CE9904840DAAED007CBFE4440EF1F0BD121924840BCEB6CC83F014540EF1F0BD121924840BCEB6CC83F01454000AC8E1CE9904840DAAED007CBFE444000AC8E1CE9904840
18449	Земцов	2	23	1522	41.810530999999997	41.854422	49.217702000000003	49.190537999999997	0103000020E6100000010000000500000074B2D47ABFE744409752978C6398484074B2D47ABFE744400C23BDA8DD9B4840D07D39B35DED44400C23BDA8DD9B4840D07D39B35DED44409752978C6398484074B2D47ABFE744409752978C63984840
18203	Дуленков	2	23	1522	41.865228999999999	41.910181000000001	49.237575999999997	49.223103999999999	0103000020E610000001000000050000008046E9D2BFEE4440ABCDFFAB8E9C48408046E9D2BFEE44404128EFE3689E484065389ECF80F444404128EFE3689E484065389ECF80F44440ABCDFFAB8E9C48408046E9D2BFEE4440ABCDFFAB8E9C4840
18883	Грушинский	2	23	1522	41.751618999999998	41.781011999999997	49.385519000000002	49.340788000000003	0103000020E61000000100000005000000AF06280D35E04440446FF1F09EAB4840AF06280D35E044404A7EC4AF58B148404BE48233F8E344404A7EC4AF58B148404BE48233F8E34440446FF1F09EAB4840AF06280D35E04440446FF1F09EAB4840
19024	Грачев	2	23	1522	41.511122	41.554583000000001	49.424238000000003	49.399357000000002	0103000020E61000000100000005000000102219726CC14440DF3653211EB34840102219726CC1444038DC476E4DB6484073F56393FCC6444038DC476E4DB6484073F56393FCC64440DF3653211EB34840102219726CC14440DF3653211EB34840
31466	Горбатов	2	23	1522	42.012597999999997	42.034013999999999	49.358035999999998	49.340916999999997	0103000020E610000001000000050000005CFFAECF9C01454041D3122BA3AB48405CFFAECF9C0145403465A71FD4AD484096CD1C925A0445403465A71FD4AD484096CD1C925A04454041D3122BA3AB48405CFFAECF9C01454041D3122BA3AB4840
19156	Верхнечирский	2	23	1522	41.277119999999996	41.346192000000002	49.423335999999999	49.397821	0103000020E61000000100000005000000A4880CAB78A34440BD546CCCEBB24840A4880CAB78A34440179CC1DF2FB648408411FB0450AC4440179CC1DF2FB648408411FB0450AC4440BD546CCCEBB24840A4880CAB78A34440BD546CCCEBB24840
31383	Вербовка	2	23	1522	41.745384999999999	41.766171999999997	49.167264000000003	49.152788000000001	0103000020E61000000100000005000000E8F692C668DF4440529CA38E8E934840E8F692C668DF44402AE620E868954840328E91EC11E244402AE620E868954840328E91EC11E24440529CA38E8E934840E8F692C668DF4440529CA38E8E934840
19077	Большенаполовский	2	23	1522	41.400432000000002	41.454510999999997	49.449950000000001	49.432535000000001	0103000020E61000000100000005000000CD22145B41B344400CB08F4E5DB74840CD22145B41B34440E86A2BF697B948400C569C6A2DBA4440E86A2BF697B948400C569C6A2DBA44400CB08F4E5DB74840CD22145B41B344400CB08F4E5DB74840
18253	Боковская	2	23	1522	41.814698999999997	41.848934	49.242482000000003	49.211405999999997	0103000020E61000000100000005000000BD8A8C0E48E84440CE16105A0F9B4840BD8A8C0E48E8444031EF71A6099F4840323B8BDEA9EC444031EF71A6099F4840323B8BDEA9EC4440CE16105A0F9B4840BD8A8C0E48E84440CE16105A0F9B4840
18085	Белавин	2	23	1522	41.977321000000003	42.013621999999998	49.315593999999997	49.284199999999998	0103000020E61000000100000005000000D658C2DA18FD4440F8C264AA60A44840D658C2DA18FD44402B685A6265A84840C8409E5DBE0145402B685A6265A84840C8409E5DBE014540F8C264AA60A44840D658C2DA18FD4440F8C264AA60A44840
56746	Поцелуев	2	23	7337	40.704048999999998	40.715052999999997	48.249276000000002	48.236358000000003	0103000020E6100000010000000500000008E412471E5A4440F1129CFA401E484008E412471E5A4440BFD6A546E81F48400EF450DB865B4440BFD6A546E81F48400EF450DB865B4440F1129CFA401E484008E412471E5A4440F1129CFA401E4840
54809	Белая Калитва	2	23	7337	40.633226000000001	40.831583000000002	48.363872999999998	48.136080999999997	0103000020E610000001000000050000000B7DB08C0D514440B14D2A1A6B1148400B7DB08C0D514440DE72F563932E48406D74CE4F716A4440DE72F563932E48406D74CE4F716A4440B14D2A1A6B1148400B7DB08C0D514440B14D2A1A6B114840
6745	Ясногорка	2	23	855	40.743009000000001	40.778177999999997	48.034979999999997	48.020083999999997	0103000020E610000001000000050000001CD13DEB1A5F44402096CD1C920248401CD13DEB1A5F4440CD0182397A044840BC3B32569B634440CD0182397A044840BC3B32569B6344402096CD1C920248401CD13DEB1A5F44402096CD1C92024840
7392	Шолоховский	2	23	855	41.028672999999998	41.064757999999998	48.290975000000003	48.270535000000002	0103000020E610000001000000050000009CA38E8EAB83444031B610E4A02248409CA38E8EAB834440107A36AB3E254840C2137AFD49884440107A36AB3E254840C2137AFD4988444031B610E4A02248409CA38E8EAB83444031B610E4A0224840
56914	Чернышев	2	23	855	40.731878999999999	40.748092999999997	47.920378999999997	47.900272999999999	0103000020E6100000010000000500000089D00836AE5D4440643C4A253CF3474089D00836AE5D44406C76A4FACEF54740EAAEEC82C15F44406C76A4FACEF54740EAAEEC82C15F4440643C4A253CF3474089D00836AE5D4440643C4A253CF34740
56694	Чапаев	2	23	855	40.764837999999997	40.788715000000003	48.058677000000003	48.037016000000001	0103000020E61000000100000005000000785E2A36E6614440E1B6B6F0BC044840785E2A36E661444082035ABA82074840AD6EF59CF464444082035ABA82074840AD6EF59CF4644440E1B6B6F0BC044840785E2A36E6614440E1B6B6F0BC044840
57023	Усть-Быстрый	2	23	855	40.956440000000001	40.979678999999997	47.979472000000001	47.972794999999998	0103000020E610000001000000050000000A4B3CA06C7A44402D5BEB8B84FC47400A4B3CA06C7A444082ACA7565FFD4740FBC9181F667D444082ACA7565FFD4740FBC9181F667D44402D5BEB8B84FC47400A4B3CA06C7A44402D5BEB8B84FC4740
6493	Углекаменный	2	23	855	40.878402999999999	40.891131999999999	47.994875	47.983936	0103000020E61000000100000005000000A9DA6E826F704440B4AD669DF1FD4740A9DA6E826F704440D34D621058FF4740A435069D10724440D34D621058FF4740A435069D10724440B4AD669DF1FD4740A9DA6E826F704440B4AD669DF1FD4740
12799	Сосны	2	23	855	40.838365000000003	40.846027999999997	48.181705000000001	48.176803	0103000020E61000000100000005000000378E588B4F6B4440D76A0F7BA1164840378E588B4F6B44408542041C4217484009C03FA54A6C44408542041C4217484009C03FA54A6C4440D76A0F7BA1164840378E588B4F6B4440D76A0F7BA1164840
6501	Синегорский	2	23	855	40.810094999999997	40.889183000000003	48.022646000000002	47.995730999999999	0103000020E6100000010000000500000099D36531B1674440834E081D74FF474099D36531B16744404FB16A10E60248406094A0BFD07144404FB16A10E60248406094A0BFD0714440834E081D74FF474099D36531B1674440834E081D74FF4740
6751	Русичи	2	23	855	40.588687	40.601658999999998	48.237395999999997	48.225932	0103000020E61000000100000005000000494A7A185A4B4440588FFB56EB1C4840494A7A185A4B4440C119FCFD621E48400A2C8029034D4440C119FCFD621E48400A2C8029034D4440588FFB56EB1C4840494A7A185A4B4440588FFB56EB1C4840
56973	Рудаков	2	23	855	40.891806000000003	40.916581000000001	48.293984000000002	48.274163000000001	0103000020E610000001000000050000003430F2B226724440FA62EFC5172348403430F2B2267244400DC68844A12548404791B586527544400DC68844A12548404791B58652754440FA62EFC5172348403430F2B226724440FA62EFC517234840
56942	Разъезд Васильевский	2	23	855	40.556815	40.565322000000002	48.176760999999999	48.174188999999998	0103000020E610000001000000050000000C76C3B64547444056293DD34B1648400C76C3B645474440A81ABD1AA0164840CBDAA6785C484440A81ABD1AA0164840CBDAA6785C48444056293DD34B1648400C76C3B64547444056293DD34B164840
56844	Погорелов	2	23	855	40.872681	40.894537	48.225451999999997	48.205274000000003	0103000020E61000000100000005000000986BD102B46F44400C5C1E6B461A4840986BD102B46F4440AD68739CDB1C4840EE073C3080724440AD68739CDB1C4840EE073C30807244400C5C1E6B461A4840986BD102B46F44400C5C1E6B461A4840
56896	Нижнесеребряковский	2	23	855	41.022995999999999	41.051355999999998	47.986576999999997	47.964705000000002	0103000020E610000001000000050000002BF86D88F1824440D3A414747BFB47402BF86D88F18244402EFEB62748FE4740083A5AD5928644402EFEB62748FE4740083A5AD592864440D3A414747BFB47402BF86D88F1824440D3A414747BFB4740
56755	Нижнепопов	2	23	855	40.867057000000003	40.879722999999998	48.172818999999997	48.164382000000003	0103000020E610000001000000050000004A6249B9FB6E44408A0629780A1548404A6249B9FB6E44404F90D8EE1E164840FE4465C39A7044404F90D8EE1E164840FE4465C39A7044408A0629780A1548404A6249B9FB6E44408A0629780A154840
56899	Насонтов	2	23	855	41.016609000000003	41.039444000000003	48.038136999999999	48.025796999999997	0103000020E61000000100000005000000DEE8633E20824440DEAAEB504D034840DEE8633E208244403FE257ACE1044840000341800C8544403FE257ACE1044840000341800C854440DEAAEB504D034840DEE8633E20824440DEAAEB504D034840
56845	Мечетный	2	23	855	40.630727999999998	40.648873999999999	48.072526000000003	48.057411999999999	0103000020E61000000100000005000000F355F2B1BB504440F032C34659074840F355F2B1BB5044400B0E2F8848094840C39CA04D0E5344400B0E2F8848094840C39CA04D0E534440F032C34659074840F355F2B1BB504440F032C34659074840
31244	Мельничный	2	23	855	40.901642000000002	40.917093000000001	48.019277000000002	48.001223000000003	0103000020E610000001000000050000009B594B016973444063804413280048409B594B0169734440524832AB77024840FD31AD4D63754440524832AB77024840FD31AD4D6375444063804413280048409B594B01697344406380441328004840
56791	Марьевка	2	23	855	41.216420999999997	41.240459999999999	48.579607000000003	48.567774	0103000020E610000001000000050000007495EEAEB39B444072C284D1AC4848407495EEAEB39B44402FC4EA8F304A484082FFAD64C79E44402FC4EA8F304A484082FFAD64C79E444072C284D1AC4848407495EEAEB39B444072C284D1AC484840
12480	Литвиновка	2	23	855	40.869123000000002	40.903672999999998	48.405614999999997	48.378956000000002	0103000020E61000000100000005000000C899266C3F6F4440BE4F55A181304840C899266C3F6F44402EE23B31EB3348409CA38E8EAB7344402EE23B31EB3348409CA38E8EAB734440BE4F55A181304840C899266C3F6F4440BE4F55A181304840
56652	Ленина	2	23	855	40.869715999999997	40.895344999999999	48.311526999999998	48.286833000000001	0103000020E610000001000000050000006A6798DA526F4440F03499F1B62448406A6798DA526F44401669E21DE02748408DD13AAA9A7244401669E21DE02748408DD13AAA9A724440F03499F1B62448406A6798DA526F4440F03499F1B6244840
56759	Крутинский	2	23	855	40.884368000000002	40.903700000000001	48.254705999999999	48.237504000000001	0103000020E6100000010000000500000081D07AF832714440A855F487661E484081D07AF832714440280CCA349A20484096B20C71AC734440280CCA349A20484096B20C71AC734440A855F487661E484081D07AF832714440A855F487661E4840
13003	Краснодонецкая	2	23	855	40.890934000000001	40.927855000000001	48.032552000000003	48.018161999999997	0103000020E610000001000000050000007E7214200A724440D503E621530248407E7214200A724440AFB5F7A92A0448400D37E0F3C3764440AFB5F7A92A0448400D37E0F3C3764440D503E621530248407E7214200A724440D503E62153024840
56726	Кононов	2	23	855	40.921145000000003	40.950789	48.430137999999999	48.413097	0103000020E61000000100000005000000DDEF5014E8754440B189CC5CE0344840DDEF5014E8754440286211C30E374840C2323674B3794440286211C30E374840C2323674B3794440B189CC5CE0344840DDEF5014E8754440B189CC5CE0344840
6801	Коксовый	2	23	855	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
56968	Какичев	2	23	855	40.733981	40.758387999999997	48.142904999999999	48.129195000000003	0103000020E610000001000000050000005471E316F35D444043E73576891048405471E316F35D4440AAB706B64A124840E4D6A4DB12614440AAB706B64A124840E4D6A4DB1261444043E73576891048405471E316F35D444043E7357689104840
56757	Ильинка	2	23	855	41.076076999999998	41.104903999999998	48.554667999999999	48.525784000000002	0103000020E61000000100000005000000287D21E4BC8944404A61DEE34C434840287D21E4BC894440A1116C5CFF4648401B9C887E6D8D4440A1116C5CFF4648401B9C887E6D8D44404A61DEE34C434840287D21E4BC8944404A61DEE34C434840
56924	Западный	2	23	855	41.161704999999998	41.172359	48.564726999999998	48.560327000000001	0103000020E61000000100000005000000C24CDBBFB29444406C088ECBB8474840C24CDBBFB294444087156EF948484840EC1516DC0F96444087156EF948484840EC1516DC0F9644406C088ECBB8474840C24CDBBFB29444406C088ECBB8474840
56815	Дороговский	2	23	855	40.818880999999998	40.839810999999997	48.153016999999998	48.146752999999997	0103000020E610000001000000050000006B28B517D168444081CB63CDC81248406B28B517D1684440B35DA10F9613484018E945ED7E6B4440B35DA10F9613484018E945ED7E6B444081CB63CDC81248406B28B517D168444081CB63CDC8124840
57012	Гусынка	2	23	855	41.028035000000003	41.046433	48.465367999999998	48.452725000000001	0103000020E610000001000000050000005A12A0A696834440728A8EE4F23948405A12A0A6968344406E4DBA2D913B4840433A3C84F18544406E4DBA2D913B4840433A3C84F1854440728A8EE4F23948405A12A0A696834440728A8EE4F2394840
56767	Грушевка	2	23	855	40.650005999999998	40.679516	47.927630000000001	47.916176	0103000020E61000000100000005000000151A886533534440A7B0524145F54740151A886533534440ED647094BCF64740EB8D5A61FA564440ED647094BCF64740EB8D5A61FA564440A7B0524145F54740151A886533534440A7B0524145F54740
7246	Горняцкий	2	23	855	40.911003000000001	40.992731999999997	48.302933000000003	48.278235000000002	0103000020E6100000010000000500000069C70DBF9B74444021CD58349D23484069C70DBF9B74444089F02F82C6264840A9D898D7117F444089F02F82C6264840A9D898D7117F444021CD58349D23484069C70DBF9B74444021CD58349D234840
56704	Голубинка	2	23	855	40.767614000000002	40.784089000000002	47.875450999999998	47.861584999999998	0103000020E61000000100000005000000D3F9F02C41624440B1DCD26A48EE4740D3F9F02C41624440102043C70EF04740A11342075D644440102043C70EF04740A11342075D644440B1DCD26A48EE4740D3F9F02C41624440B1DCD26A48EE4740
56999	Головка	2	23	855	41.011381	41.034854000000003	48.498703999999996	48.482396999999999	0103000020E61000000100000005000000DC65BFEE748144402158552FBF3D4840DC65BFEE7481444033315D88D53F484041118B187684444033315D88D53F484041118B18768444402158552FBF3D4840DC65BFEE748144402158552FBF3D4840
6396	Виноградный	2	23	855	40.906978000000002	40.919375000000002	47.999504999999999	47.992221000000001	0103000020E610000001000000050000008318E8DA17744440C4B3041901FF47408318E8DA177444402098A3C7EFFF474048E17A14AE7544402098A3C7EFFF474048E17A14AE754440C4B3041901FF47408318E8DA17744440C4B3041901FF4740
56636	Богураев	2	23	855	40.666688000000001	40.735481	48.161864000000001	48.137807000000002	0103000020E610000001000000050000005D514A08565544407714E7A8A31148405D514A08565544402B33A5F5B714484029EACC3D245E44402B33A5F5B714484029EACC3D245E44407714E7A8A31148405D514A08565544407714E7A8A3114840
56822	Богатов	2	23	855	40.778770999999999	40.805568000000001	48.102752000000002	48.091475000000003	0103000020E610000001000000050000005F09A4C4AE63444068B3EA73B50B48405F09A4C4AE6344409FCC3FFA260D4840215A2BDA1C6744409FCC3FFA260D4840215A2BDA1C67444068B3EA73B50B48405F09A4C4AE63444068B3EA73B50B4840
56750	Апанасовка	2	23	855	41.078457999999998	41.104194	48.154074999999999	48.128076999999998	0103000020E61000000100000005000000060E68E90A8A4440552FBFD364104840060E68E90A8A4440CB10C7BAB81348403F389F3A568D4440CB10C7BAB81348403F389F3A568D4440552FBFD364104840060E68E90A8A4440552FBFD364104840
11522	Ясный	2	23	1141	40.149203999999997	40.158700000000003	47.145173999999997	47.138818000000001	0103000020E610000001000000050000005837DE1D191344404E0CC9C9C49147405837DE1D19134440601DC70F9592474007F0164850144440601DC70F9592474007F01648501444404E0CC9C9C49147405837DE1D191344404E0CC9C9C4914740
56691	Федулов	2	23	1141	40.460731000000003	40.478274999999996	47.264166000000003	47.249684000000002	0103000020E610000001000000050000006FA0C03BF93A4440D02A33A5F59F47406FA0C03BF93A44408A5B0531D0A1474048BF7D1D383D44408A5B0531D0A1474048BF7D1D383D4440D02A33A5F59F47406FA0C03BF93A4440D02A33A5F59F4740
56667	Усьман	2	23	1141	40.281453999999997	40.312725	47.163294	47.141435000000001	0103000020E6100000010000000500000008AA46AF0624444040C1C58A1A92474008AA46AF0624444007D15AD1E694474020D26F5F0728444007D15AD1E694474020D26F5F0728444040C1C58A1A92474008AA46AF0624444040C1C58A1A924740
56987	Тузлуков	2	23	1141	40.456733999999997	40.474978999999998	47.210743000000001	47.199165999999998	0103000020E61000000100000005000000527C7C42763A4440D13C80457E994740527C7C42763A4440336E6AA0F99A4740B5A4A31CCC3C4440336E6AA0F99A4740B5A4A31CCC3C4440D13C80457E994740527C7C42763A4440D13C80457E994740
11838	Садовый	2	23	1141	40.388013000000001	40.397544000000003	47.150033999999998	47.143175999999997	0103000020E6100000010000000500000020B6F468AA3144403AC956975392474020B6F468AA314440DFA46950349347404B5CC7B8E2324440DFA46950349347404B5CC7B8E23244403AC956975392474020B6F468AA3144403AC9569753924740
56857	Пустошкин	2	23	1141	40.226171999999998	40.262445999999997	47.187654000000002	47.179673999999999	0103000020E61000000100000005000000ADA23F34F31C444083F8C08EFF964740ADA23F34F31C4440577BD80B05984740A67B9DD497214440577BD80B05984740A67B9DD49721444083F8C08EFF964740ADA23F34F31C444083F8C08EFF964740
11224	Привольный	2	23	1141	40.669527000000002	40.680028	47.339205999999997	47.327584000000002	0103000020E61000000100000005000000FE648C0FB3554440B058C345EEA94740FE648C0FB3554440B14D2A1A6BAB4740A12E52280B574440B14D2A1A6BAB4740A12E52280B574440B058C345EEA94740FE648C0FB3554440B058C345EEA94740
11690	Первомайский	2	23	1141	40.289988000000001	40.303167000000002	47.220663999999999	47.208747000000002	0103000020E61000000100000005000000C11DA8531E254440AE11C138B89A4740C11DA8531E254440C8B3CBB73E9C4740FC1C1F2DCE264440C8B3CBB73E9C4740FC1C1F2DCE264440AE11C138B89A4740C11DA8531E254440AE11C138B89A4740
11893	Отрадный	2	23	1141	40.453454999999998	40.472741999999997	47.130726000000003	47.121394000000002	0103000020E61000000100000005000000959A3DD00A3A44401FF7ADD6898F4740959A3DD00A3A4440535E2BA1BB9047400AB952CF823C4440535E2BA1BB9047400AB952CF823C44401FF7ADD6898F4740959A3DD00A3A44401FF7ADD6898F4740
10808	Манычская	2	23	1141	40.221124000000003	40.271124	47.240372999999998	47.216532999999998	0103000020E610000001000000050000002C2E8ECA4D1C44409CC0745AB79B47402C2E8ECA4D1C4440B3EBDE8AC49E47409294F430B4224440B3EBDE8AC49E47409294F430B42244409CC0745AB79B47402C2E8ECA4D1C44409CC0745AB79B4740
56710	Кудинов	2	23	1141	40.536675000000002	40.560434999999998	47.343004000000001	47.325555999999999	0103000020E6100000010000000500000058CA32C4B14444401F82AAD1ABA9474058CA32C4B1444440D732198EE7AB474052448655BC474440D732198EE7AB474052448655BC4744401F82AAD1ABA9474058CA32C4B14444401F82AAD1ABA94740
56649	Красный	2	23	1141	40.342458999999998	40.367603000000003	47.220236	47.187618000000001	0103000020E61000000100000005000000459C4EB2D52B44400A12DBDD03984740459C4EB2D52B444070B378B1309C4740AC74779D0D2F444070B378B1309C4740AC74779D0D2F44400A12DBDD03984740459C4EB2D52B44400A12DBDD03984740
56949	Карповка	2	23	1141	40.573802000000001	40.595883000000001	47.412143999999998	47.397281999999997	0103000020E6100000010000000500000090300C58724944400DA5F622DAB2474090300C58724944400E9F7422C1B44740069FE6E4454C44400E9F7422C1B44740069FE6E4454C44400DA5F622DAB2474090300C58724944400DA5F622DAB24740
11091	Задонский	2	23	1141	40.310451999999998	40.317144999999996	47.320003999999997	47.316155000000002	0103000020E61000000100000005000000287D21E4BC274440C3BB5CC477A84740287D21E4BC2744406A4B1DE4F5A84740828B1535982844406A4B1DE4F5A84740828B153598284440C3BB5CC477A84740287D21E4BC274440C3BB5CC477A84740
56639	Елкин	2	23	1141	40.482559999999999	40.513804	47.324787000000001	47.300685000000001	0103000020E61000000100000005000000CB2DAD86C43D4440EAB298D87CA64740CB2DAD86C43D44403E95D39E92A94740E9465854C44144403E95D39E92A94740E9465854C4414440EAB298D87CA64740CB2DAD86C43D4440EAB298D87CA64740
11036	Дачный	2	23	1141	40.442109000000002	40.451765999999999	47.257182999999998	47.245823999999999	0103000020E61000000100000005000000362218079738444034492C29779F47403622180797384440280B5F5FEBA04740EDB8E177D3394440280B5F5FEBA04740EDB8E177D339444034492C29779F4740362218079738444034492C29779F4740
56754	Белянин	2	23	1141	40.330637000000003	40.352826	47.303165999999997	47.290985999999997	0103000020E610000001000000050000007DEC2E50522A444003CC7C073FA547407DEC2E50522A44402BA1BB24CEA64740D9960167292D44402BA1BB24CEA64740D9960167292D444003CC7C073FA547407DEC2E50522A444003CC7C073FA54740
10661	Багаевская	2	23	1141	40.359886000000003	40.412779	47.336793999999998	47.296602999999998	0103000020E61000000100000005000000E62494BE102E44409F724C16F7A54740E62494BE102E444098BED7101CAB4740E0BC38F1D534444098BED7101CAB4740E0BC38F1D53444409F724C16F7A54740E62494BE102E44409F724C16F7A54740
56642	Арпачин	2	23	1141	40.159157999999998	40.200659999999999	47.242643000000001	47.215173999999998	0103000020E61000000100000005000000C972124A5F144440897956D28A9B4740C972124A5F1444403ACD02ED0E9F4740C4CE143AAF1944403ACD02ED0E9F4740C4CE143AAF194440897956D28A9B4740C972124A5F144440897956D28A9B4740
56692	Ажинов	2	23	1141	40.560723000000003	40.576785000000001	47.375233000000001	47.356264000000003	0103000020E61000000100000005000000B98E71C5C5474440FF5E0A0F9AAD4740B98E71C5C5474440A3B08BA207B0474064E94317D4494440A3B08BA207B0474064E94317D4494440FF5E0A0F9AAD4740B98E71C5C5474440FF5E0A0F9AAD4740
16304	Элитный	2	23	88	39.721544000000002	39.729125000000003	47.442672999999999	47.438144999999999	0103000020E610000001000000050000000150C58D5BDC4340F5F3A62215B847400150C58D5BDC43403EE94482A9B8474017D9CEF753DD43403EE94482A9B8474017D9CEF753DD4340F5F3A62215B847400150C58D5BDC4340F5F3A62215B84740
16101	Щепкин	2	23	88	39.781668000000003	39.808005999999999	47.387027000000003	47.373078999999997	0103000020E61000000100000005000000352A70B20DE4434085E97B0DC1AF4740352A70B20DE44340A2D5C9198AB14740637C98BD6CE74340A2D5C9198AB14740637C98BD6CE7434085E97B0DC1AF4740352A70B20DE4434085E97B0DC1AF4740
56716	Черюмкин	2	23	88	40.085577000000001	40.109355000000001	47.200482000000001	47.187525999999998	0103000020E610000001000000050000001825E82FF40A444029931ADA009847401825E82FF40A4440E5B7E864A9994740B9533A58FF0D4440E5B7E864A9994740B9533A58FF0D444029931ADA009847401825E82FF40A444029931ADA00984740
56803	Темерницкий	2	23	88	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
30087	Степной	2	23	88	39.870601000000001	39.880285000000001	47.352125000000001	47.344847999999999	0103000020E61000000100000005000000B56E83DA6FEF4340A60BB1FA23AC4740B56E83DA6FEF4340508D976E12AD47406614CB2DADF04340508D976E12AD47406614CB2DADF04340A60BB1FA23AC4740B56E83DA6FEF4340A60BB1FA23AC4740
17146	Старочеркасская	2	23	88	40.026234000000002	40.058698999999997	47.267346000000003	47.232872999999998	0103000020E610000001000000050000008A05BEA25B0344408A8F4FC8CE9D47408A05BEA25B034440B45BCB6438A2474069A7E67283074440B45BCB6438A2474069A7E672830744408A8F4FC8CE9D47408A05BEA25B0344408A8F4FC8CE9D4740
56805	Слава Труда	2	23	88	40.071195000000003	40.079154000000003	47.145933999999997	47.139192000000001	0103000020E61000000100000005000000C251F2EA1C094440B3EE1F0BD1914740C251F2EA1C094440EEAF1EF7AD9247407EACE0B7210A4440EEAF1EF7AD9247407EACE0B7210A4440B3EE1F0BD1914740C251F2EA1C094440B3EE1F0BD1914740
17255	Рыбацкий	2	23	88	40.013074000000003	40.033645	47.236984	47.230663999999997	0103000020E61000000100000005000000C636A968AC014440A92EE065869D4740C636A968AC0144406FD6E07D559E47404356B77A4E0444406FD6E07D559E47404356B77A4E044440A92EE065869D4740C636A968AC014440A92EE065869D4740
15572	Российский	2	23	88	39.881695000000001	39.896732999999998	47.296377	47.285649999999997	0103000020E61000000100000005000000FB05BB61DBF043401B0DE02D90A44740FB05BB61DBF04340AF2479AEEFA547403A1F9E25C8F24340AF2479AEEFA547403A1F9E25C8F243401B0DE02D90A44740FB05BB61DBF043401B0DE02D90A44740
15484	Реконструктор	2	23	88	39.934632999999998	39.951385999999999	47.308653	47.300764999999998	0103000020E610000001000000050000009561DC0DA2F743400664AF777FA647409561DC0DA2F74340F96706F181A74740A6EF3504C7F94340F96706F181A74740A6EF3504C7F943400664AF777FA647409561DC0DA2F743400664AF777FA64740
15843	Рассвет	2	23	88	39.865192999999998	39.895682000000001	47.365260999999997	47.357044999999999	0103000020E6100000010000000500000033DDEBA4BEEE4340A4198BA6B3AD474033DDEBA4BEEE43408BC058DFC0AE4740D5CE30B5A5F243408BC058DFC0AE4740D5CE30B5A5F24340A4198BA6B3AD474033DDEBA4BEEE4340A4198BA6B3AD4740
56979	Пчеловодный	2	23	88	39.947434000000001	39.966101000000002	47.304358000000001	47.295355999999998	0103000020E610000001000000050000002A8F6E8445F94340B456B439CEA547402A8F6E8445F943405323F433F5A6474003D19332A9FB43405323F433F5A6474003D19332A9FB4340B456B439CEA547402A8F6E8445F94340B456B439CEA54740
56720	Островского	2	23	88	39.927391999999998	39.940885000000002	47.118493999999998	47.108896999999999	0103000020E610000001000000050000003849F3C7B4F64340F6D03E56F08D47403849F3C7B4F64340D862B7CF2A8F4740032670EB6EF84340D862B7CF2A8F4740032670EB6EF84340F6D03E56F08D47403849F3C7B4F64340F6D03E56F08D4740
15790	Опытный	2	23	88	39.971634999999999	39.984310000000001	47.340806000000001	47.314207000000003	0103000020E61000000100000005000000115322895EFC43404F965AEF37A84740115322895EFC4340EA23F0879FAB47401990BDDEFDFD4340EA23F0879FAB47401990BDDEFDFD43404F965AEF37A84740115322895EFC43404F965AEF37A84740
16940	Ольгинская	2	23	88	39.926493999999998	39.968823	47.201217	47.173395999999997	0103000020E6100000010000000500000059F8FA5A97F64340ECA012D73196474059F8FA5A97F643401A33897AC19947406A4E5E6402FC43401A33897AC19947406A4E5E6402FC4340ECA012D73196474059F8FA5A97F64340ECA012D731964740
16018	Октябрьский	2	23	88	39.825335000000003	39.843328	47.407277999999998	47.391235999999999	0103000020E61000000100000005000000419FC893A4E943404982700514B24740419FC893A4E94340AD307DAF21B447408AE6012CF2EB4340AD307DAF21B447408AE6012CF2EB43404982700514B24740419FC893A4E943404982700514B24740
56742	Нижнеподпольный	2	23	88	40.001691999999998	40.018346999999999	47.197322999999997	47.190288000000002	0103000020E6100000010000000500000019558671370044401F69705B5B9847401955867137004440D2DF4BE141994740677DCA3159024440D2DF4BE141994740677DCA31590244401F69705B5B98474019558671370044401F69705B5B984740
105	Мишкинская	2	23	88	40.031875999999997	40.057414999999999	47.368465	47.355257000000002	0103000020E610000001000000050000007EC34483140444406956B60F79AD47407EC34483140444403E5C72DC29AF474061A6ED5F590744403E5C72DC29AF474061A6ED5F590744406956B60F79AD47407EC34483140444406956B60F79AD4740
56897	Малый Мишкин	2	23	88	40.065994000000003	40.076988999999998	47.385002	47.377240999999998	0103000020E61000000100000005000000BADDCB7D72084440ECDADE6E49B04740BADDCB7D720844408272DBBE47B147406C938AC6DA0944408272DBBE47B147406C938AC6DA094440ECDADE6E49B04740BADDCB7D72084440ECDADE6E49B04740
14534	Ленина	2	23	88	39.842187000000003	39.863370000000003	47.121726000000002	47.104444000000001	0103000020E61000000100000005000000E50E9BC8CCEB4340B821C66B5E8D4740E50E9BC8CCEB43405589B2B7948F47407C2C7DE882EE43405589B2B7948F47407C2C7DE882EE4340B821C66B5E8D4740E50E9BC8CCEB4340B821C66B5E8D4740
15954	Красный Колос	2	23	88	39.941747999999997	39.954009999999997	47.407339	47.397184000000003	0103000020E610000001000000050000006589CE328BF843404B3FE1ECD6B247406589CE328BF8434053B131AF23B447404A07EBFF1CFA434053B131AF23B447404A07EBFF1CFA43404B3FE1ECD6B247406589CE328BF843404B3FE1ECD6B24740
16177	Красный	2	23	88	39.873125000000002	39.890059000000001	47.393317000000003	47.386361999999998	0103000020E61000000100000005000000F6285C8FC2EF434065355D4F74B14740F6285C8FC2EF4340FDFA213658B2474057410C74EDF14340FDFA213658B2474057410C74EDF1434065355D4F74B14740F6285C8FC2EF434065355D4F74B14740
56929	Краснодворск	2	23	88	40.073306000000002	40.078308999999997	47.293474000000003	47.285938000000002	0103000020E61000000100000005000000E04C4C17620944408257CB9D99A44740E04C4C1762094440F81C588E90A54740C1FD8007060A4440F81C588E90A54740C1FD8007060A44408257CB9D99A44740E04C4C17620944408257CB9D99A44740
16006	Ковалевка	2	23	88	39.829566	39.842187000000003	47.342955000000003	47.336953000000001	0103000020E61000000100000005000000D0EFFB372FEA434001A5A14621AB4740D0EFFB372FEA4340F67F0EF3E5AB4740E50E9BC8CCEB4340F67F0EF3E5AB4740E50E9BC8CCEB434001A5A14621AB4740D0EFFB372FEA434001A5A14621AB4740
56862	Киров	2	23	88	40.003264000000001	40.018777999999998	47.390633000000001	47.385136000000003	0103000020E6100000010000000500000088A06AF46A0044409241EE224CB1474088A06AF46A00444083DE1B4300B2474030F147516702444083DE1B4300B2474030F14751670244409241EE224CB1474088A06AF46A0044409241EE224CB14740
56903	Камышеваха	2	23	88	39.87724	39.910072999999997	47.443525999999999	47.434584999999998	0103000020E610000001000000050000001C5F7B6649F04340842A357BA0B747401C5F7B6649F043407D76C075C5B847407EFCA5457DF443407D76C075C5B847407EFCA5457DF44340842A357BA0B747401C5F7B6649F04340842A357BA0B74740
56695	Истомино	2	23	88	39.854979	39.874895000000002	47.088236000000002	47.071275	0103000020E6100000010000000500000026E2ADF36FED4340DE02098A1F89474026E2ADF36FED4340392A37514B8B47408B37328FFCEF4340392A37514B8B47408B37328FFCEF4340DE02098A1F89474026E2ADF36FED4340DE02098A1F894740
16916	Дорожный	2	23	88	39.875577999999997	39.888603000000003	47.140735999999997	47.129272999999998	0103000020E610000001000000050000006D8C9DF012F04340BEA085048C9047406D8C9DF012F0434057AF22A30392474052103CBEBDF1434057AF22A30392474052103CBEBDF14340BEA085048C9047406D8C9DF012F04340BEA085048C904740
16770	Дивный	2	23	88	39.987876	40.012652000000003	47.138474000000002	47.131093999999997	0103000020E610000001000000050000006C4084B872FE4340D5592DB0C79047406C4084B872FE434054AC1A84B9914740501DAB949E01444054AC1A84B9914740501DAB949E014440D5592DB0C79047406C4084B872FE4340D5592DB0C7904740
13066	Грушевская	2	23	88	39.923009	40.038621999999997	47.449711999999998	47.420302	0103000020E61000000100000005000000F374AE2825F64340C138B874CCB54740F374AE2825F64340334FAE2990B94740FB73D190F1044440334FAE2990B94740FB73D190F1044440C138B874CCB54740F374AE2825F64340C138B874CCB54740
16238	Возрожденный	2	23	88	39.750262999999997	39.757764000000002	47.431708	47.426184999999997	0103000020E610000001000000050000000D33349E08E04340DB85E63A8DB647400D33349E08E04340F6B52E3542B74740070B2769FEE04340F6B52E3542B74740070B2769FEE04340DB85E63A8DB647400D33349E08E04340DB85E63A8DB64740
15519	Водопадный	2	23	88	39.826844000000001	39.837085000000002	47.305824000000001	47.300201999999999	0103000020E6100000010000000500000069723106D6E94340CE18E6046DA6474069723106D6E943407C2AA73D25A74740707CED9925EB43407C2AA73D25A74740707CED9925EB4340CE18E6046DA6474069723106D6E94340CE18E6046DA64740
56651	Верхнеподпольный	2	23	88	40.044533000000001	40.077573000000001	47.193282000000004	47.185523000000003	0103000020E61000000100000005000000E04BE141B3054440F2D3B837BF974740E04BE141B3054440E773EE76BD984740BC067DE9ED094440E773EE76BD984740BC067DE9ED094440F2D3B837BF974740E04BE141B3054440F2D3B837BF974740
56650	Большой Лог	2	23	88	39.905096	39.923521000000001	47.330325999999999	47.283645	0103000020E61000000100000005000000C6DE8B2FDAF343404356B77A4EA44740C6DE8B2FDAF343405E82531F48AA4740A915A6EF35F643405E82531F48AA4740A915A6EF35F643404356B77A4EA44740C6DE8B2FDAF343404356B77A4EA44740
56855	Большой Лог	2	23	88	39.905096	39.923521000000001	47.330325999999999	47.283645	0103000020E61000000100000005000000C6DE8B2FDAF343404356B77A4EA44740C6DE8B2FDAF343405E82531F48AA4740A915A6EF35F643405E82531F48AA4740A915A6EF35F643404356B77A4EA44740C6DE8B2FDAF343404356B77A4EA44740
57022	Алитуб	2	23	88	40.094147	40.113002000000002	47.236164000000002	47.222396000000003	0103000020E610000001000000050000001D0247020D0C44407061DD78779C47401D0247020D0C44400C3F389F3A9E4740F9307BD9760E44400C3F389F3A9E4740F9307BD9760E44407061DD78779C47401D0247020D0C44407061DD78779C4740
56628	Александровка	2	23	88	39.992628000000003	40.010379	47.332604000000003	47.323143999999999	0103000020E61000000100000005000000058C2E6F0EFF434006F357C85CA94740058C2E6F0EFF4340684293C492AA474058C85C1954014440684293C492AA474058C85C195401444006F357C85CA94740058C2E6F0EFF434006F357C85CA94740
54816	Аксай	2	23	88	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
6344	Южный	2	23	779	38.961021000000002	38.994681	46.659452999999999	46.647119000000004	0103000020E6100000010000000500000076E272BC027B434064CF9ECBD452474076E272BC027B4340E21FB6F468544740EE79FEB4517F4340E21FB6F468544740EE79FEB4517F434064CF9ECBD452474076E272BC027B434064CF9ECBD4524740
56856	Чумбур-Коса	2	23	779	38.890000000000001	38.923389999999998	46.95635	46.950716	0103000020E6100000010000000500000052B81E85EB71434058E4D70FB179474052B81E85EB714340CAC342AD697A47400ABABDA431764340CAC342AD697A47400ABABDA43176434058E4D70FB179474052B81E85EB71434058E4D70FB1794740
56955	Христичево	2	23	779	39.034233999999998	39.062144000000004	46.758395999999998	46.745367999999999	0103000020E61000000100000005000000A4349BC76184434012BEF737685F4740A4349BC76184434067B5C01E1361474042D2A755F487434067B5C01E1361474042D2A755F487434012BEF737685F4740A4349BC76184434012BEF737685F4740
56957	Харьковский	2	23	779	39.205694999999999	39.245311000000001	46.804703000000003	46.790495	0103000020E61000000100000005000000B1F9B836549A43406553AEF02E654740B1F9B836549A43401EFF058200674740AE2CD159669F43401EFF058200674740AE2CD159669F43406553AEF02E654740B1F9B836549A43406553AEF02E654740
56881	Усть-Койсуг	2	23	779	39.562173000000001	39.578423999999998	47.149213000000003	47.137095000000002	0103000020E61000000100000005000000DCD8EC48F5C74340FAB836548C914740DCD8EC48F5C74340AC915D69199347405A9C31CC09CA4340AC915D69199347405A9C31CC09CA4340FAB836548C914740DCD8EC48F5C74340FAB836548C914740
56799	Узяк	2	23	779	39.320391999999998	39.352372000000003	47.121946000000001	47.113644000000001	0103000020E6100000010000000500000034F3E49A02A943407DB1F7E28B8E474034F3E49A02A9434063F030ED9B8F4740580394861AAD434063F030ED9B8F4740580394861AAD43407DB1F7E28B8E474034F3E49A02A943407DB1F7E28B8E4740
7635	Тимирязевский	2	23	779	39.608203000000003	39.612397999999999	47.055892999999998	47.050643000000001	0103000020E61000000100000005000000202A8D98D9CD4340BB6246787B864740202A8D98D9CD4340A4897780278747406211C30E63CE4340A4897780278747406211C30E63CE4340BB6246787B864740202A8D98D9CD4340BB6246787B864740
9054	Суходольск	2	23	779	39.694774000000002	39.712947	47.005287000000003	47.000923999999998	0103000020E61000000100000005000000390EBC5AEED8434008E412471E804740390EBC5AEED84340070C923EAD8047400264E8D841DB4340070C923EAD8047400264E8D841DB434008E412471E804740390EBC5AEED8434008E412471E804740
7223	Стефанидинодар	2	23	779	39.159171000000001	39.203287000000003	47.034137000000001	47.022644	0103000020E610000001000000050000005EBC1FB75F944340AEB9A3FFE58247405EBC1FB75F944340B24AE9995E844740DA59F44E059A4340B24AE9995E844740DA59F44E059A4340AEB9A3FFE58247405EBC1FB75F944340AEB9A3FFE5824740
56911	Степнянский	2	23	779	39.675522999999998	39.683698	46.817222999999998	46.811728000000002	0103000020E610000001000000050000001059A48977D64340AE9FFEB3E66747401059A48977D64340FE4465C39A684740992B836A83D74340FE4465C39A684740992B836A83D74340AE9FFEB3E66747401059A48977D64340AE9FFEB3E6674740
24839	Солнечный	2	23	779	39.446057000000003	39.460214999999998	46.873533000000002	46.868346000000003	0103000020E610000001000000050000007193516518B9434064CE33F6256F47407193516518B94340077DE9EDCF6F474077103B53E8BA4340077DE9EDCF6F474077103B53E8BA434064CE33F6256F47407193516518B9434064CE33F6256F4740
8263	Советский Дар	2	23	779	39.149847000000001	39.166753	46.631445999999997	46.614747999999999	0103000020E61000000100000005000000AD33BE2F2E93434005A4FD0FB04E4740AD33BE2F2E9343405298F738D350474044C18C29589543405298F738D350474044C18C295895434005A4FD0FB04E4740AD33BE2F2E93434005A4FD0FB04E4740
9057	Семибалки	2	23	779	39.024532000000001	39.063113999999999	47.017816000000003	46.994292999999999	0103000020E610000001000000050000004DDA54DD2383434024D236FE447F47404DDA54DD238343403BAC70CB47824740BAF59A1E148843403BAC70CB47824740BAF59A1E1488434024D236FE447F47404DDA54DD2383434024D236FE447F4740
8656	Самарское	2	23	779	39.665219	39.705131000000002	46.956294999999997	46.926135000000002	0103000020E61000000100000005000000C3D66CE525D543402A5778978B764740C3D66CE525D54340062AE3DF677A4740A9328CBB41DA4340062AE3DF677A4740A9328CBB41DA43402A5778978B764740C3D66CE525D543402A5778978B764740
56683	Рогожкино	2	23	779	39.338231999999998	39.355004000000001	47.185437	47.160156999999998	0103000020E61000000100000005000000F73AA92F4BAB4340DC9C4A0680944740F73AA92F4BAB4340F33B4D66BC9747407FF964C570AD4340F33B4D66BC9747407FF964C570AD4340DC9C4A0680944740F73AA92F4BAB4340DC9C4A0680944740
7899	Приморский	2	23	779	38.917039000000003	38.938195	46.866646000000003	46.852473000000003	0103000020E610000001000000050000000A14B188617543408CDCD3D51D6D47400A14B18861754340C89A9141EE6E4740A72215C616784340C89A9141EE6E4740A72215C6167843408CDCD3D51D6D47400A14B188617543408CDCD3D51D6D4740
7906	Порт-Катон	2	23	779	38.736559	38.772041999999999	46.883764999999997	46.869936000000003	0103000020E610000001000000050000008849B890475E434079CE16105A6F47408849B890475E4340BA2C26361F714740B891B245D2624340BA2C26361F714740B891B245D262434079CE16105A6F47408849B890475E434079CE16105A6F4740
7373	Полтава 2-я	2	23	779	39.156198000000003	39.184305999999999	46.814343000000001	46.809057000000003	0103000020E61000000100000005000000AED9CA4BFE934340C9CC052E8F674740AED9CA4BFE934340FF5C34643C684740713AC95697974340FF5C34643C684740713AC95697974340C9CC052E8F674740AED9CA4BFE934340C9CC052E8F674740
7328	Полтава 1-я	2	23	779	39.200915999999999	39.248491000000001	46.850377999999999	46.837496000000002	0103000020E610000001000000050000001F9F909DB7994340F243A511336B47401F9F909DB7994340739EB12FD96C4740D82C978DCE9F4340739EB12FD96C4740D82C978DCE9F4340F243A511336B47401F9F909DB7994340F243A511336B4740
54868	Победа	2	23	779	39.623573	39.648240999999999	46.950654	46.933753000000003	0103000020E6100000010000000500000095D5743DD1CF43405DC5E2378577474095D5743DD1CF4340E2E7BF07AF7947409276A38FF9D24340E2E7BF07AF7947409276A38FF9D243405DC5E2378577474095D5743DD1CF43405DC5E23785774740
8056	Платоно-Петровка	2	23	779	39.467256999999996	39.482492999999998	46.997605	46.984667000000002	0103000020E61000000100000005000000DDE9CE13CFBB4340A8397991097E4740DDE9CE13CFBB4340BDA94885B17F474043C6A354C2BD4340BDA94885B17F474043C6A354C2BD4340A8397991097E4740DDE9CE13CFBB4340A8397991097E4740
8323	Пешково	2	23	779	39.364553000000001	39.411884999999998	47.028075000000001	47.008887999999999	0103000020E61000000100000005000000505436ACA9AE4340D6A9F23D23814740505436ACA9AE4340E86A2BF697834740425BCEA5B8B44340E86A2BF697834740425BCEA5B8B44340D6A9F23D23814740505436ACA9AE4340D6A9F23D23814740
56761	Песчаный	2	23	779	39.589562999999998	39.606406	46.961872999999997	46.953907999999998	0103000020E6100000010000000500000040F7E5CC76CB434046B247A8197A474040F7E5CC76CB4340E4F38AA71E7B4740910C39B69ECD4340E4F38AA71E7B4740910C39B69ECD434046B247A8197A474040F7E5CC76CB434046B247A8197A4740
56743	Павловка	2	23	779	39.439455000000002	39.452139000000003	47.028467999999997	47.014485999999998	0103000020E610000001000000050000002788BA0F40B84340FB1F60ADDA8147402788BA0F40B84340C37DE4D6A4834740821FD5B0DFB94340C37DE4D6A4834740821FD5B0DFB94340FB1F60ADDA8147402788BA0F40B84340FB1F60ADDA814740
56925	Павло-Очаково	2	23	779	39.069474	39.088186	47.027631999999997	47.017477999999997	0103000020E610000001000000050000000EF62686E4884340223317B83C8247400EF62686E48843405A2904728983474087FBC8AD498B43405A2904728983474087FBC8AD498B4340223317B83C8247400EF62686E4884340223317B83C824740
8206	Отрадовка	2	23	779	39.079787000000003	39.109637999999997	46.666386000000003	46.659725000000002	0103000020E61000000100000005000000AFD2DD75368A434043AD69DE71544740AFD2DD75368A43409241EE224C5547400D33349E088E43409241EE224C5547400D33349E088E434043AD69DE71544740AFD2DD75368A434043AD69DE71544740
8271	Орловка	2	23	779	39.183543	39.261076000000003	46.742645000000003	46.720446000000003	0103000020E61000000100000005000000723447567E9743405B441493375C4740723447567E974340DBC4C9FD0E5F4740A0E238F06AA14340DBC4C9FD0E5F4740A0E238F06AA143405B441493375C4740723447567E9743405B441493375C4740
7686	Овощной	2	23	779	39.639401999999997	39.651142999999998	47.110515999999997	47.099235999999998	0103000020E610000001000000050000009D7FBBECD7D14340FD4AE7C3B38C47409D7FBBECD7D14340A5D76663258E4740790261A758D34340A5D76663258E4740790261A758D34340FD4AE7C3B38C47409D7FBBECD7D14340FD4AE7C3B38C4740
56622	Обуховка	2	23	779	39.422835999999997	39.442221000000004	47.164555999999997	47.155714000000003	0103000020E6100000010000000500000025C9737D1FB64340C2C3B46FEE93474025C9737D1FB64340272EC72B109547405E4D9EB29AB84340272EC72B109547405E4D9EB29AB84340C2C3B46FEE93474025C9737D1FB64340C2C3B46FEE934740
6694	Новотроицкое	2	23	779	39.663297	39.686931000000001	46.908014000000001	46.898077000000001	0103000020E61000000100000005000000784485EAE6D443401825E82FF4724740784485EAE6D44340B32781CD39744740E6CDE15AEDD74340B32781CD39744740E6CDE15AEDD743401825E82FF4724740784485EAE6D443401825E82FF4724740
8589	Новополтавский	2	23	779	39.132230999999997	39.148741999999999	46.882367000000002	46.870145000000001	0103000020E61000000100000005000000394206F2EC90434093E34EE9606F4740394206F2EC904340EA08E066F170474054C554FA09934340EA08E066F170474054C554FA0993434093E34EE9606F4740394206F2EC90434093E34EE9606F4740
8956	Новониколаевка	2	23	779	39.589050999999998	39.627561999999998	46.985526999999998	46.971024	0103000020E610000001000000050000008A56EE0566CB4340C8D0B1834A7C47408A56EE0566CB43409929ADBF257E47402E1B9DF353D043409929ADBF257E47402E1B9DF353D04340C8D0B1834A7C47408A56EE0566CB4340C8D0B1834A7C4740
7064	Новомирский	2	23	779	39.398437000000001	39.429079000000002	46.842803000000004	46.824888000000001	0103000020E610000001000000050000001842CEFBFFB24340726E13EE956947401842CEFBFFB2434040FCFCF7E06B47404033880FECB6434040FCFCF7E06B47404033880FECB64340726E13EE956947401842CEFBFFB24340726E13EE95694740
7963	Новомаргаритово	2	23	779	38.815727000000003	38.845902000000002	46.90701	46.892491	0103000020E610000001000000050000006BBB09BE69684340B77C24253D7247406BBB09BE696843408E9257E7187447407DCF4884466C43408E9257E7187447407DCF4884466C4340B77C24253D7247406BBB09BE69684340B77C24253D724740
56626	Новоалександровка	2	23	779	39.506199000000002	39.515605000000001	47.086218000000002	47.071446999999999	0103000020E610000001000000050000004B22FB20CBC04340DB32E02C258947404B22FB20CBC04340CC290131098B4740B9533A58FFC14340CC290131098B4740B9533A58FFC14340DB32E02C258947404B22FB20CBC04340DB32E02C25894740
5729	Нижняя Козинка	2	23	779	38.948363999999998	38.975358	46.852392999999999	46.835726000000001	0103000020E61000000100000005000000145AD6FD637943405D35CF11F96A4740145AD6FD637943406F2BBD361B6D47402CF2EB87D87C43406F2BBD361B6D47402CF2EB87D87C43405D35CF11F96A4740145AD6FD637943405D35CF11F96A4740
7765	Маргаритово	2	23	779	38.861721000000003	38.887224000000003	46.943142999999999	46.914563999999999	0103000020E6100000010000000500000062A3ACDF4C6E4340AA0CE36E1075474062A3ACDF4C6E4340C539EAE8B8784740F81C588E90714340C539EAE8B8784740F81C588E90714340AA0CE36E1075474062A3ACDF4C6E4340AA0CE36E10754740
5961	Ленинский Лесхоз	2	23	779	39.130937000000003	39.142902999999997	46.761606	46.752234000000001	0103000020E610000001000000050000000E6B2A8BC29043403A782634496047400E6B2A8BC2904340FC372F4E7C61474009C03FA54A924340FC372F4E7C61474009C03FA54A9243403A782634496047400E6B2A8BC29043403A78263449604740
56932	Левобережный	2	23	779	39.623483	39.639923000000003	46.961103999999999	46.950937000000003	0103000020E61000000100000005000000554E7B4ACECF434037C7B94DB8794740554E7B4ACECF43400307B474057B4740A77A32FFE8D143400307B474057B4740A77A32FFE8D1434037C7B94DB8794740554E7B4ACECF434037C7B94DB8794740
7498	Кулешовка	2	23	779	39.533562000000003	39.578415	47.086525000000002	47.071288000000003	0103000020E61000000100000005000000B63176C24BC44340734C16F71F894740B63176C24BC44340A9A44E40138B47400742B28009CA4340A9A44E40138B47400742B28009CA4340734C16F71F894740B63176C24BC44340734C16F71F894740
7225	Кугей	2	23	779	39.301966999999998	39.334207999999997	46.892885999999997	46.870663	0103000020E6100000010000000500000051BCCADAA6A643402B6B9BE2716F474051BCCADAA6A643403387A4164A724740E107E753C7AA43403387A4164A724740E107E753C7AA43402B6B9BE2716F474051BCCADAA6A643402B6B9BE2716F4740
7138	Круглое	2	23	779	39.212926000000003	39.260680999999998	47.025556000000002	47.005034999999999	0103000020E61000000100000005000000EB3BBF28419B4340ED2AA4FCA4804740EB3BBF28419B4340B91B446B4583474023D8B8FE5DA14340B91B446B4583474023D8B8FE5DA14340ED2AA4FCA4804740EB3BBF28419B4340ED2AA4FCA4804740
56631	Красный Сад	2	23	779	39.719774000000001	39.729018000000003	47.102756999999997	47.099511999999997	0103000020E610000001000000050000006C41EF8D21DC43409FC728CFBC8C47406C41EF8D21DC4340B0373124278D474001193A7650DD4340B0373124278D474001193A7650DD43409FC728CFBC8C47406C41EF8D21DC43409FC728CFBC8C4740
56711	Кочеванчик	2	23	779	39.628163999999998	39.652687999999998	46.978968000000002	46.970243000000004	0103000020E6100000010000000500000024438EAD67D04340231631EC307C474024438EAD67D043404FEACBD24E7D4740EE3EC7478BD343404FEACBD24E7D4740EE3EC7478BD34340231631EC307C474024438EAD67D04340231631EC307C4740
56708	Колузаево	2	23	779	39.539167999999997	39.555489999999999	47.166074999999999	47.142679000000001	0103000020E610000001000000050000005D86FF7403C54340BA69334E439247405D86FF7403C5434073D712F241954740A5A0DB4B1AC7434073D712F241954740A5A0DB4B1AC74340BA69334E439247405D86FF7403C54340BA69334E43924740
6748	Каяльский	2	23	779	39.672620999999999	39.691198	46.890003999999998	46.864773	0103000020E6100000010000000500000029CDE67118D643405EBBB4E1B06E474029CDE67118D6434093A7ACA6EB714740C287122D79D8434093A7ACA6EB714740C287122D79D843405EBBB4E1B06E474029CDE67118D643405EBBB4E1B06E4740
57004	Калиновка	2	23	779	39.462136999999998	39.485070999999998	46.842205	46.837138000000003	0103000020E61000000100000005000000C2A2224E27BB4340931E8656276B4740C2A2224E27BB43408BC3995FCD6B4740779E78CE16BE43408BC3995FCD6B4740779E78CE16BE4340931E8656276B4740C2A2224E27BB4340931E8656276B4740
6753	Кагальник	2	23	779	39.304625999999999	39.342652000000001	47.088985000000001	47.065027000000001	0103000020E6100000010000000500000072C119FCFDA64340B22D03CE5288474072C119FCFDA64340D36A48DC638B47405AF44E05DCAB4340D36A48DC638B47405AF44E05DCAB4340B22D03CE5288474072C119FCFDA64340B22D03CE52884740
32246	Зеленый	2	23	779	39.371631999999998	39.384343000000001	47.052804000000002	47.047517999999997	0103000020E61000000100000005000000D3122BA391AF434054FCDF1115864740D3122BA391AF43408B8C0E48C286474028B9C32632B143408B8C0E48C286474028B9C32632B1434054FCDF1115864740D3122BA391AF434054FCDF1115864740
8435	Займо-Обрыв	2	23	779	39.290908999999999	39.332348000000003	47.027467000000001	47.011136999999998	0103000020E61000000100000005000000588E90813CA543404563EDEF6C814740588E90813CA54340105CE509848347400D7217618AAA4340105CE509848347400D7217618AAA43404563EDEF6C814740588E90813CA543404563EDEF6C814740
56714	Задонский	2	23	779	39.651673000000002	39.668435000000002	46.935673000000001	46.924123000000002	0103000020E61000000100000005000000D65757056AD343409F3D97A949764740D65757056AD3434007600322C47747403A4030478FD5434007600322C47747403A4030478FD543409F3D97A949764740D65757056AD343409F3D97A949764740
56851	Еремеевка	2	23	779	39.534531999999999	39.577641999999997	46.973796999999998	46.960428	0103000020E610000001000000050000002E55698B6BC44340D314014EEF7A47402E55698B6BC44340B1F84D61A57C4740E4654D2CF0C94340B1F84D61A57C4740E4654D2CF0C94340D314014EEF7A47402E55698B6BC44340D314014EEF7A4740
56879	Ельбузд	2	23	779	39.712857	39.731811	46.871721999999998	46.866244999999999	0103000020E61000000100000005000000C2DCEEE53EDB434069A9BC1DE16E4740C2DCEEE53EDB4340139A2496946F474031ED9BFBABDD4340139A2496946F474031ED9BFBABDD434069A9BC1DE16E4740C2DCEEE53EDB434069A9BC1DE16E4740
6286	Елизаветовка	2	23	779	38.871673999999999	38.929679	46.672854000000001	46.648077999999998	0103000020E6100000010000000500000002637D03936F4340E8A04B38F452474002637D03936F4340CC7D7214205647409563B2B8FF764340CC7D7214205647409563B2B8FF764340E8A04B38F452474002637D03936F4340E8A04B38F4524740
5970	Елизаветинская	2	23	779	39.469026999999997	39.482303999999999	47.142874999999997	47.128132999999998	0103000020E6100000010000000500000072F8A41309BC4340E94482A96690474072F8A41309BC43403F355EBA49924740705D3123BCBD43403F355EBA49924740705D3123BCBD4340E94482A96690474072F8A41309BC4340E94482A966904740
56986	Дугино	2	23	779	39.411130999999997	39.425027999999998	47.166786000000002	47.161375999999997	0103000020E6100000010000000500000096AFCBF09FB44340FD2D01F8A794474096AFCBF09FB4434020B75F3E5995474030F1475167B6434020B75F3E5995474030F1475167B64340FD2D01F8A794474096AFCBF09FB44340FD2D01F8A7944740
56860	Донской	2	23	779	39.309567000000001	39.330362999999998	47.130076000000003	47.120995999999998	0103000020E61000000100000005000000DE7536E49FA74340317903CC7C8F4740DE7536E49FA743404CFF9254A69047407B67B45549AA43404CFF9254A69047407B67B45549AA4340317903CC7C8F4740DE7536E49FA74340317903CC7C8F4740
7074	Гусарева Балка	2	23	779	39.525989000000003	39.550711	46.831738000000001	46.821373000000001	0103000020E610000001000000050000002387889B53C34340A1681EC0226947402387889B53C34340946B0A64766A47401346B3B27DC64340946B0A64766A47401346B3B27DC64340A1681EC0226947402387889B53C34340A1681EC022694740
56878	Григорьевка	2	23	779	39.053573999999998	39.067174999999999	46.666398000000001	46.658394999999999	0103000020E610000001000000050000003CF54883DB864340CA6C9049465447403CF54883DB864340560F98874C554740ED0DBE3099884340560F98874C554740ED0DBE3099884340CA6C9049465447403CF54883DB864340CA6C904946544740
8374	Головатовка	2	23	779	39.332177999999999	39.364688000000001	47.030163000000002	47.010123	0103000020E61000000100000005000000B03907CF84AA4340FDF7E0B54B814740B03907CF84AA43404E469561DC834740309FAC18AEAE43404E469561DC834740309FAC18AEAE4340FDF7E0B54B814740B03907CF84AA4340FDF7E0B54B814740
7367	Высочино	2	23	779	39.547916999999998	39.572729000000002	47.010092999999998	46.990524999999998	0103000020E6100000010000000500000012F6ED2422C64340696FF085C97E474012F6ED2422C64340927538BA4A814740433C122F4FC94340927538BA4A814740433C122F4FC94340696FF085C97E474012F6ED2422C64340696FF085C97E4740
6390	Васильево-Петровское	2	23	779	39.490605000000002	39.515631999999997	46.972394999999999	46.962826	0103000020E6100000010000000500000086200725CCBE434087DEE2E13D7B474086200725CCBE43409FE57970777C4740B262B83A00C243409FE57970777C4740B262B83A00C2434087DEE2E13D7B474086200725CCBE434087DEE2E13D7B4740
24585	Васильево-Петровский	2	23	779	39.466566	39.471857	46.931477000000001	46.927815000000002	0103000020E6100000010000000500000078B6476FB8BB43407FDE54A4C276474078B6476FB8BB4340F4FC69A33A774740C0B167CF65BC4340F4FC69A33A774740C0B167CF65BC43407FDE54A4C276474078B6476FB8BB43407FDE54A4C2764740
56983	Бурхановка	2	23	779	39.621265000000001	39.638306	46.819406000000001	46.808613000000001	0103000020E6100000010000000500000021938C9C85CF43406B0F7BA18067474021938C9C85CF4340B612BA4BE2684740986BD102B4D14340B612BA4BE2684740986BD102B4D143406B0F7BA18067474021938C9C85CF43406B0F7BA180674740
56876	Береговой	2	23	779	39.315451000000003	39.334504000000003	47.047517999999997	47.037545000000001	0103000020E61000000100000005000000C93EC8B260A843406D904946CE844740C93EC8B260A8434054FCDF1115864740CB30EE06D1AA434054FCDF1115864740CB30EE06D1AA43406D904946CE844740C93EC8B260A843406D904946CE844740
5490	Александровка	2	23	779	38.968046000000001	39.024433000000002	46.800896999999999	46.760686	0103000020E6100000010000000500000006836BEEE87B43403543AA285E61474006836BEEE87B4340753BFBCA83664740BAF8DB9E20834340753BFBCA83664740BAF8DB9E208343403543AA285E61474006836BEEE87B43403543AA285E614740
50720	х. Журавлевка	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50389	ст. Ладожская	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50296	ст. Воронежская	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50625	с.Галицино	2	20	\N	39.966864000000001	39.993400999999999	43.558216999999999	43.540118	0103000020E6100000010000000500000002D71533C2FB43408FFD2C9622C5454002D71533C2FB43401E8997A773C74540276893C327FF43401E8997A773C74540276893C327FF43408FFD2C9622C5454002D71533C2FB43408FFD2C9622C54540
50475	пос.Грушовая балка	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50331	п. Пригородный	2	20	\N	39.186498	39.195678999999998	45.076895	45.072121000000003	0103000020E610000001000000050000007C629D2ADF9743406B2DCC423B8946407C629D2ADF974340EB1C03B2D7894640CAC16C020C994340EB1C03B2D7894640CAC16C020C9943406B2DCC423B8946407C629D2ADF9743406B2DCC423B894640
50674	жилой городок Лесная сказка	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50277	Шесхарис	2	20	\N	37.826358999999997	37.849894999999997	44.732467	44.703586999999999	0103000020E61000000100000005000000ACE0B721C6E94240047289230F5A4640ACE0B721C6E942401A33897AC15D46405704FF5BC9EC42401A33897AC15D46405704FF5BC9EC4240047289230F5A4640ACE0B721C6E94240047289230F5A4640
50332	Черноморская	2	20	\N	39.352857	39.371003000000002	44.711472999999998	44.688684000000002	0103000020E6100000010000000500000014950D6B2AAD4340A5A31CCC2658464014950D6B2AAD4340567E198C115B4640E4DBBB067DAF4340567E198C115B4640E4DBBB067DAF4340A5A31CCC2658464014950D6B2AAD4340A5A31CCC26584640
23618	Цемдолина	2	20	\N	37.704152000000001	37.738979999999998	44.767021999999997	44.738056999999998	0103000020E61000000100000005000000DDB419A721DA4240BCCADAA6785E4640DDB419A721DA424000A8E2C62D624640F4328AE596DE424000A8E2C62D624640F4328AE596DE4240BCCADAA6785E4640DDB419A721DA4240BCCADAA6785E4640
50490	Хадыженск	2	20	\N	39.510682000000003	39.552418000000003	44.466236000000002	44.384737999999999	0103000020E61000000100000005000000F4531C075EC14340A4C343183F314640F4531C075EC14340E31B0A9FAD3B464062DC0DA2B5C64340E31B0A9FAD3B464062DC0DA2B5C64340A4C343183F314640F4531C075EC14340A4C343183F314640
50327	Фанагорийское	2	20	\N	39.099640000000001	39.121029	44.520389000000002	44.506903999999999	0103000020E61000000100000005000000CDAFE600C18C4340151BF33AE2404640CDAFE600C18C43405D19541B9C4246400D6FD6E07D8F43405D19541B9C4246400D6FD6E07D8F4340151BF33AE2404640CDAFE600C18C4340151BF33AE2404640
50459	Усть-Лабинск	2	20	\N	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
50702	Украинская	2	20	\N	39.80621	39.843598	45.954732999999997	45.930267000000001	0103000020E61000000100000005000000A5DAA7E331E7434026C632FD12F74640A5DAA7E331E74340BBB4E1B034FA46404A7CEE04FBEB4340BBB4E1B034FA46404A7CEE04FBEB434026C632FD12F74640A5DAA7E331E7434026C632FD12F74640
100	Туапсе	2	20	\N	39.030909999999999	39.129302000000003	44.132393999999998	44.066648999999998	0103000020E61000000100000005000000478FDFDBF4834340D2A755F487084640478FDFDBF4834340E3175E49F210464059A7CAF78C904340E3175E49F210464059A7CAF78C904340D2A755F487084640478FDFDBF4834340D2A755F487084640
50396	Тихорецк	2	20	\N	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
50512	Тихорецк	2	20	\N	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
50425	Тимашевск	2	20	\N	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
50589	Терновый	2	20	\N	39.840111999999998	39.847980999999997	44.627029	44.613273999999997	0103000020E61000000100000005000000137D3ECA88EB434059BE2EC37F4E4640137D3ECA88EB434061527C7C425046408F5033A48AEC434061527C7C425046408F5033A48AEC434059BE2EC37F4E4640137D3ECA88EB434059BE2EC37F4E4640
50516	Темрюк	2	20	\N	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
50259	Суздальская	2	20	\N	39.354815000000002	39.386526000000003	44.777650999999999	44.752096000000002	0103000020E61000000100000005000000AC90F2936AAD4340E9B985AE44604640AC90F2936AAD4340D15966118A634640E08618AF79B14340D15966118A634640E08618AF79B14340E9B985AE44604640AC90F2936AAD4340E9B985AE44604640
50535	Старокорсунская	2	20	\N	39.291376	39.339633999999997	45.069085000000001	45.037762999999998	0103000020E610000001000000050000006E6B0BCF4BA54340DAFF006BD58446406E6B0BCF4BA5434074D2FBC6D7884640094E7D2079AB434074D2FBC6D7884640094E7D2079AB4340DAFF006BD58446406E6B0BCF4BA54340DAFF006BD5844640
50727	Станица Ярославская	2	20	\N	40.439413999999999	40.485156000000003	44.640256000000001	44.585278000000002	0103000020E61000000100000005000000C8B3CBB73E384440BE88B663EA4A4640C8B3CBB73E384440AD889AE8F3514640A6BA8097193E4440AD889AE8F3514640A6BA8097193E4440BE88B663EA4A4640C8B3CBB73E384440BE88B663EA4A4640
50262	Сочи	2	20	\N	39.707835000000003	39.780876999999997	43.656854000000003	43.546933000000003	0103000020E610000001000000050000006AFB57569ADA4340350D8AE601C645406AFB57569ADA4340971FB8CA13D445406B990CC7F3E34340971FB8CA13D445406B990CC7F3E34340350D8AE601C645406AFB57569ADA4340350D8AE601C64540
50410	Славянск-На-Кубани	2	20	\N	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
50675	Семёновкский	2	20	\N	39.109845	39.110123000000002	45.048794000000001	45.046602999999998	0103000020E610000001000000050000008750A5660F8E43409F724C16F78546408750A5660F8E4340DA1EBDE13E864640CAC4AD82188E4340DA1EBDE13E864640CAC4AD82188E43409F724C16F78546408750A5660F8E43409F724C16F7854640
50371	Свобода	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50270	Саратовская	2	20	\N	39.191699	39.238762000000001	44.729559999999999	44.694828999999999	0103000020E6100000010000000500000084D6C39789984340FCA71B28F058464084D6C39789984340213CDA38625D464087C3D2C08F9E4340213CDA38625D464087C3D2C08F9E4340FCA71B28F058464084D6C39789984340FCA71B28F0584640
50586	Передовая	2	20	\N	41.450944	41.505014000000003	44.139057999999999	44.095880000000001	0103000020E61000000100000005000000E9297288B8B94440952BBCCB450C4640E9297288B8B94440A31F0DA7CC114640D6027B4CA4C04440A31F0DA7CC114640D6027B4CA4C04440952BBCCB450C4640E9297288B8B94440952BBCCB450C4640
50592	Отрадненая	2	20	\N	41.484226999999997	41.543101999999998	44.438284000000003	44.353955999999997	0103000020E610000001000000050000008B6B7C26FBBD44408A1C226E4E2D46408B6B7C26FBBD4440172EABB0193846403332C85D84C54440172EABB0193846403332C85D84C544408A1C226E4E2D46408B6B7C26FBBD44408A1C226E4E2D4640
50300	Октябрьский	2	20	\N	39.068468000000003	39.106557000000002	45.195735999999997	45.170456999999999	0103000020E610000001000000050000004969368FC3884340E82FF488D19546404969368FC38843402E5393E00D9946407714E7A8A38D43402E5393E00D9946407714E7A8A38D4340E82FF488D19546404969368FC3884340E82FF488D1954640
6023	Новороссийск	2	20	\N	37.695798000000003	37.844738	44.767693999999999	44.663186000000003	0103000020E61000000100000005000000A54FABE80FD9424021956247E3544640A54FABE80FD94240EFAA07CC436246401FD8F15F20EC4240EFAA07CC436246401FD8F15F20EC424021956247E3544640A54FABE80FD9424021956247E3544640
50394	Новокубанск	2	20	\N	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
50329	Мирный	2	20	\N	38.613211	38.623244999999997	45.680531999999999	45.671458000000001	0103000020E610000001000000050000001346B3B27D4E43409C51F355F2D546401346B3B27D4E4340D4F02DAC1BD74640A032FE7DC64F4340D4F02DAC1BD74640A032FE7DC64F43409C51F355F2D546401346B3B27D4E43409C51F355F2D54640
5827	Мефодиевка	2	20	\N	37.742851000000002	37.810108	44.757069999999999	44.734414000000001	0103000020E610000001000000050000008466D7BD15DF4240BEDC2747015E46408466D7BD15DF4240306475ABE76046402E1D739EB1E74240306475ABE76046402E1D739EB1E74240BEDC2747015E46408466D7BD15DF4240BEDC2747015E4640
50462	Маяк	2	20	\N	40.931286999999998	40.945129999999999	45.035127000000003	45.027603999999997	0103000020E610000001000000050000005018946934774440909E2287888346405018946934774440721AA20A7F844640F73B1405FA784440721AA20A7F844640F73B1405FA784440909E2287888346405018946934774440909E228788834640
50248	Мартанская	2	20	\N	39.424992000000003	39.453252999999997	44.773823999999998	44.747672999999999	0103000020E61000000100000005000000E4874A2366B64340158DB5BFB35F4640E4874A2366B64340116E32AA0C6346402DE8BD3104BA4340116E32AA0C6346402DE8BD3104BA4340158DB5BFB35F4640E4874A2366B64340158DB5BFB35F4640
50783	Ленина	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50856	Лазурный	2	20	\N	39.086381000000003	39.158892999999999	45.163193999999997	45.133940000000003	0103000020E6100000010000000500000076FF58880E8B434029D027F22491464076FF58880E8B4340A3737E8AE39446401B48179B56944340A3737E8AE39446401B48179B5694434029D027F22491464076FF58880E8B434029D027F224914640
50405	Лабинск	2	20	\N	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
50392	Курганинск	2	20	\N	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
50299	Кура-Цеце	2	20	\N	39.326860000000003	39.346891999999997	44.493557000000003	44.482971999999997	0103000020E610000001000000050000006F2F698CD6A943401D71C806D23D46406F2F698CD6A943401FDB32E02C3F46403C9F01F566AC43401FDB32E02C3F46403C9F01F566AC43401D71C806D23D46406F2F698CD6A943401D71C806D23D4640
50286	Кубань	2	20	\N	38.881267999999999	38.888033	45.067678000000001	45.056612999999999	0103000020E610000001000000050000007381CB63CD704340A4C343183F8746407381CB63CD704340505436ACA98846406762BA10AB714340505436ACA98846406762BA10AB714340A4C343183F8746407381CB63CD704340A4C343183F874640
50444	Крымск	2	20	\N	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
50476	Кропоткин	2	20	\N	40.49926	40.616059	45.469239999999999	45.410882000000001	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
50242	Краснодар, поселок Пригородный	2	20	\N	39.186498	39.195678999999998	45.076895	45.072121000000003	0103000020E610000001000000050000007C629D2ADF9743406B2DCC423B8946407C629D2ADF974340EB1C03B2D7894640CAC16C020C994340EB1C03B2D7894640CAC16C020C9943406B2DCC423B8946407C629D2ADF9743406B2DCC423B894640
242	Краснодар	2	20	\N	38.648533	39.383265000000002	45.220457000000003	44.968698000000003	0103000020E610000001000000050000003AB01C2103534340AED9CA4BFE7B46403AB01C21035343404F965AEF379C4640C959D8D30EB143404F965AEF379C4640C959D8D30EB14340AED9CA4BFE7B46403AB01C2103534340AED9CA4BFE7B4640
50406	Кореновск	2	20	\N	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
50457	Кореновск	2	20	\N	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
50782	Калининский	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50854	Индустриальный	2	20	\N	39.081629	39.121746999999999	45.110778000000003	45.07687	0103000020E61000000100000005000000DDB3AED1728A434092054CE0D6894640DDB3AED1728A4340E38E37F92D8E46406CB1DB67958F4340E38E37F92D8E46406CB1DB67958F434092054CE0D6894640DDB3AED1728A434092054CE0D6894640
50468	Имеретинская	2	20	\N	39.407474999999998	39.445770000000003	44.697046	44.674211999999997	0103000020E6100000010000000500000003780B2428B443400E492D944C56464003780B2428B4434060E7A6CD38594640DBC4C9FD0EB9434060E7A6CD38594640DBC4C9FD0EB943400E492D944C56464003780B2428B443400E492D944C564640
50598	Елизаветовская	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
50422	Ейск	2	20	\N	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
50496	Гулькевичи	2	20	\N	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
50863	Грушевый	2	20	\N	39.968570999999997	39.989483999999997	44.770305	44.756315000000001	0103000020E61000000100000005000000506D7022FAFB4340B43C0FEECE604640506D7022FAFB4340FF78AF5A9962464027F56569A7FE4340FF78AF5A9962464027F56569A7FE4340B43C0FEECE604640506D7022FAFB4340B43C0FEECE604640
50377	Горячий Ключ, поселок Первомайский	2	20	\N	39.291285999999999	39.323993999999999	44.699846000000001	44.683083000000003	0103000020E610000001000000050000002EE411DC48A543400FBA84436F5746402EE411DC48A54340431EC18D94594640D40CA9A278A94340431EC18D94594640D40CA9A278A943400FBA84436F5746402EE411DC48A543400FBA84436F574640
27694	Горячий Ключ	2	20	\N	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
25997	Геленджик	2	20	\N	37.972442999999998	38.134273999999998	44.638184000000003	44.532760000000003	0103000020E61000000100000005000000B01C210379FC4240F94ECC7A31444640B01C210379FC42404D6A6803B0514640FF59F3E32F1143404D6A6803B0514640FF59F3E32F114340F94ECC7A31444640B01C210379FC4240F94ECC7A31444640
50256	Вимовец	2	20	\N	39.884210000000003	39.905222000000002	45.313465000000001	45.301198999999997	0103000020E61000000100000005000000E96514CB2DF14340404B57B08DA64640E96514CB2DF1434067B8019F1FA8464053CF8250DEF3434067B8019F1FA8464053CF8250DEF34340404B57B08DA64640E96514CB2DF14340404B57B08DA64640
50301	Веселая Жизнь	2	20	\N	39.805284	39.850299	46.230344000000002	46.221060000000001	0103000020E61000000100000005000000FCFECD8B13E74340153AAFB14B1C4740FCFECD8B13E74340386A85E97B1D47402769FE98D6EC4340386A85E97B1D47402769FE98D6EC4340153AAFB14B1C4740FCFECD8B13E74340153AAFB14B1C4740
50388	Березовый	2	20	\N	38.984870999999998	39.004095	45.197215999999997	45.128718999999997	0103000020E61000000100000005000000B0E3BF40107E4340D9AF3BDD79904640B0E3BF40107E4340BC1FB75F3E994640DF89592F86804340BC1FB75F3E994640DF89592F86804340D9AF3BDD79904640B0E3BF40107E4340D9AF3BDD79904640
50696	Белый	2	20	\N	37.257778999999999	37.282446999999998	45.174028	45.163333999999999	0103000020E610000001000000050000003C4CFBE6FEA042409529E620E89446403C4CFBE6FEA042404D4BAC8C4696464039ED293927A442404D4BAC8C4696464039ED293927A442409529E620E89446403C4CFBE6FEA042409529E620E8944640
50428	Белореченск	2	20	\N	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
50246	Безымянное	2	20	\N	39.120731999999997	39.133668	44.55836	44.543591999999997	0103000020E6100000010000000500000053CA6B25748F4340012F336C9445464053CA6B25748F434081B2295778474640C84274081C91434081B2295778474640C84274081C914340012F336C9445464053CA6B25748F4340012F336C94454640
50356	Бакинская	2	20	\N	39.265585999999999	39.298644000000003	44.786696999999997	44.745880999999997	0103000020E610000001000000050000004223D8B8FEA1434098DA5207795F46404223D8B8FEA143403F6EBF7CB2644640C59272F739A643403F6EBF7CB2644640C59272F739A6434098DA5207795F46404223D8B8FEA1434098DA5207795F4640
50379	Армавир, п.Южный	2	20	\N	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
50370	Армавир п.ВНИИМК	2	20	\N	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
8849	Армавир	2	20	\N	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
50361	Апшеронск	2	20	\N	39.673026	39.795762000000003	44.487043	44.420718000000001	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
9001	Анапская	2	20	\N	37.356405000000002	37.369529999999997	44.907471999999999	44.899428	0103000020E61000000100000005000000C190D5AD9EAD4240A88DEA7420734640C190D5AD9EAD42409204E10A28744640087250C24CAF42409204E10A28744640087250C24CAF4240A88DEA7420734640C190D5AD9EAD4240A88DEA7420734640
7955	Анапа	2	20	\N	37.241627000000001	37.377740000000003	44.998229000000002	44.856231999999999	0103000020E61000000100000005000000516A2FA2ED9E4240F3E49A02996D4640516A2FA2ED9E42409B75C6F7C57F46400E32C9C859B042409B75C6F7C57F46400E32C9C859B04240F3E49A02996D4640516A2FA2ED9E4240F3E49A02996D4640
50767	Адербиевка	2	20	\N	38.093778	38.123916999999999	44.615704999999998	44.587935000000002	0103000020E61000000100000005000000CA8AE1EA000C43403E963E74414B4640CA8AE1EA000C4340E97DE36BCF4E46408F352383DC0F4340E97DE36BCF4E46408F352383DC0F43403E963E74414B4640CA8AE1EA000C43403E963E74414B4640
50438	Эстосадок	2	20	842	40.229261999999999	40.284410000000001	43.691496000000001	43.67868	0103000020E61000000100000005000000971B0C75581D444082397AFCDED64540971B0C75581D44404CA8E0F082D84540E353008C672444404CA8E0F082D84540E353008C6724444082397AFCDED64540971B0C75581D444082397AFCDED64540
50263	Наджиго	2	20	842	39.257868999999999	39.266222999999997	44.051906000000002	44.046410999999999	0103000020E610000001000000050000007CD3F4D901A143405B96AFCBF00546407CD3F4D901A14340AC3B16DBA4064640B438639813A24340AC3B16DBA4064640B438639813A243405B96AFCBF00546407CD3F4D901A143405B96AFCBF0054640
60652	Монастырь	2	20	842	39.993904000000001	40.011752999999999	43.599797000000002	43.588777	0103000020E610000001000000050000008AAE0B3F38FF434089D1730B5DCB45408AAE0B3F38FF4340959EE925C6CC4540A0504F1F81014440959EE925C6CC4540A0504F1F8101444089D1730B5DCB45408AAE0B3F38FF434089D1730B5DCB4540
46911	Красная Поляна	2	20	842	40.188488	40.222794	43.691405000000003	43.671038000000003	0103000020E610000001000000050000001FD8F15F20184440C72FBC92E4D545401FD8F15F201844403CA583F57FD845405DDF8783841C44403CA583F57FD845405DDF8783841C4440C72FBC92E4D545401FD8F15F20184440C72FBC92E4D54540
8516	Кепша	2	20	842	40.043886000000001	40.050668000000002	43.620182	43.614072999999998	0103000020E610000001000000050000004A60730E9E054440A52DAEF199CE45404A60730E9E054440B0C8AF1F62CF4540147AFD497C064440B0C8AF1F62CF4540147AFD497C064440A52DAEF199CE45404A60730E9E054440A52DAEF199CE4540
50721	Калиновое Озеро	2	20	842	39.876520999999997	39.887804000000003	43.626531999999997	43.611241	0103000020E61000000100000005000000ECA012D731F04340B77C24253DCE4540ECA012D731F04340E0F2583332D0454006A1BC8FA3F14340E0F2583332D0454006A1BC8FA3F14340B77C24253DCE4540ECA012D731F04340B77C24253DCE4540
50400	Калеж	2	20	842	39.344835000000003	39.363897000000001	44.012605000000001	44.004396999999997	0103000020E6100000010000000500000012C2A38D23AC4340AA99B5149000464012C2A38D23AC43400F62670A9D014640670E492D94AE43400F62670A9D014640670E492D94AE4340AA99B5149000464012C2A38D23AC4340AA99B51490004640
45550	Ермоловка	2	20	842	40.0291	40.078687000000002	43.525869999999998	43.504916999999999	0103000020E6100000010000000500000024287E8CB9034440E318C91EA1C0454024287E8CB903444048F949B54FC3454068CF656A120A444048F949B54FC3454068CF656A120A4440E318C91EA1C0454024287E8CB9034440E318C91EA1C04540
49189	Варваровка	2	20	842	39.693129999999996	39.704448999999997	43.696541000000003	43.690753000000001	0103000020E6100000010000000500000030F0DC7BB8D84340944E24986AD8454030F0DC7BB8D843405DA9674128D94540965984622BDA43405DA9674128D94540965984622BDA4340944E24986AD8454030F0DC7BB8D84340944E24986AD84540
6355	Ахштырь	2	20	842	39.998548	40.013145999999999	43.516261	43.507303999999998	0103000020E610000001000000050000003CBEBD6BD0FF4340A3906456EFC045403CBEBD6BD0FF4340A29927D714C245405F09A4C4AE014440A29927D714C245405F09A4C4AE014440A3906456EFC045403CBEBD6BD0FF4340A3906456EFC04540
6240	Аибга	2	20	842	40.183421000000003	40.213416000000002	43.589931999999997	43.583095999999998	0103000020E610000001000000050000002733DE567A174440D636C5E3A2CA45402733DE567A174440936E4BE482CB4540B9382A37511B4440936E4BE482CB4540B9382A37511B4440D636C5E3A2CA45402733DE567A174440D636C5E3A2CA4540
28335	Широкая Балка	2	20	1844	37.686114000000003	37.689312000000001	44.672552000000003	44.666519999999998	0103000020E61000000100000005000000F4A96395D2D74240A110018750554640F4A96395D2D74240016E162F16564640C45E28603BD84240016E162F16564640C45E28603BD84240A110018750554640F4A96395D2D74240A110018750554640
50250	Раевская	2	20	1844	37.534531999999999	37.592041999999999	44.849395000000001	44.816544999999998	0103000020E610000001000000050000002E55698B6BC442402D5BEB8B846846402E55698B6BC442406631B1F9B86C4640E1ED4108C8CB42406631B1F9B86C4640E1ED4108C8CB42402D5BEB8B846846402E55698B6BC442402D5BEB8B84684640
45533	Глебовское	2	20	1844	37.636060000000001	37.647036999999997	44.713689000000002	44.703671	0103000020E610000001000000050000009A25016A6AD1424062122EE4115A46409A25016A6AD14240EA4141295A5B4640A626C11BD2D24240EA4141295A5B4640A626C11BD2D2424062122EE4115A46409A25016A6AD1424062122EE4115A4640
50249	Гайдук	2	20	1844	37.685566000000001	37.716665999999996	44.795991999999998	44.775717999999998	0103000020E61000000100000005000000F19F6EA0C0D74240927538BA4A634640F19F6EA0C0D7424056F0DB10E3654640DB1324B6BBDB424056F0DB10E3654640DB1324B6BBDB4240927538BA4A634640F19F6EA0C0D74240927538BA4A634640
50321	Верхнебаканский	2	20	1844	37.641162000000001	37.684190999999998	44.85266	44.830233	0103000020E610000001000000050000000FB8AE9811D24240AD872F13456A46400FB8AE9811D24240BE4D7FF6236D4640D89B189293D74240BE4D7FF6236D4640D89B189293D74240AD872F13456A46400FB8AE9811D24240AD872F13456A4640
50487	Большие Хутора	2	20	1844	37.592824	37.609479	44.751623000000002	44.739741000000002	0103000020E61000000100000005000000572426A8E1CB4240534145D5AF5E4640572426A8E1CB4240F1F5B52E35604640A54C6A6803CE4240F1F5B52E35604640A54C6A6803CE4240534145D5AF5E4640572426A8E1CB4240534145D5AF5E4640
50308	Абрау-Дюрсо	2	20	1844	37.583525999999999	37.606245000000001	44.724212999999999	44.693381000000002	0103000020E61000000100000005000000CF2EDFFAB0CA42407A5567B5C0584640CF2EDFFAB0CA4240452BF702B35C4640882EA86F99CD4240452BF702B35C4640882EA86F99CD42407A5567B5C0584640CF2EDFFAB0CA42407A5567B5C0584640
27612	Тешебс	2	20	1783	38.582219000000002	38.601084	44.375388999999998	44.369545000000002	0103000020E610000001000000050000000F0EF626864A43403EB324404D2F46400F0EF626864A43409A232BBF0C3046400E130D52F04C43409A232BBF0C3046400E130D52F04C43403EB324404D2F46400F0EF626864A43403EB324404D2F4640
27317	Пшада	2	20	1783	38.387419999999999	38.418097000000003	44.481653999999999	44.463534000000003	0103000020E610000001000000050000007DE882FA96314340C34A0515553B46407DE882FA9631434069FE98D6A63D464022C7D6338435434069FE98D6A63D464022C7D63384354340C34A0515553B46407DE882FA96314340C34A0515553B4640
25873	Прасковеевка	2	20	1783	38.213317000000004	38.224663	44.481383999999998	44.467947000000002	0103000020E610000001000000050000002657B1F84D1B434073A1F2AFE53B46402657B1F84D1B4340A968ACFD9D3D464085CFD6C1C11C4340A968ACFD9D3D464085CFD6C1C11C434073A1F2AFE53B46402657B1F84D1B434073A1F2AFE53B4640
50903	Михайловский Перевал	2	20	1783	38.287346999999997	38.333584000000002	44.526435999999997	44.502436000000003	0103000020E6100000010000000500000046CD57C9C7244340A22AA6D24F40464046CD57C9C7244340F1B73D4162434640043C69E1B22A4340F1B73D4162434640043C69E1B22A4340A22AA6D24F40464046CD57C9C7244340A22AA6D24F404640
46814	Кабардинка	2	20	1783	37.917098000000003	37.921759999999999	44.669629	44.666533000000001	0103000020E610000001000000050000000F9D9E7763F54240365A0EF4505546400F9D9E7763F5424002BA2F67B655464067614F3BFCF5424002BA2F67B655464067614F3BFCF54240365A0EF4505546400F9D9E7763F54240365A0EF450554640
27126	Дивноморское	2	20	1783	38.117789999999999	38.152869000000003	44.536203999999998	44.492052000000001	0103000020E61000000100000005000000DEE522BE130F434038F7578FFB3E4640DEE522BE130F434000FE2955A24446403FC91D369113434000FE2955A24446403FC91D369113434038F7578FFB3E4640DEE522BE130F434038F7578FFB3E4640
50480	Береговое	2	20	1783	38.354550000000003	38.372408999999998	44.430824999999999	44.410299999999999	0103000020E61000000100000005000000FE65F7E4612D43403FC6DCB584344640FE65F7E4612D43404CA60A462537464037DE1D19AB2F43404CA60A462537464037DE1D19AB2F43403FC6DCB584344640FE65F7E4612D43403FC6DCB584344640
27504	Архипо-Осиповка	2	20	1783	38.516463000000002	38.550975999999999	44.393388999999999	44.356721	0103000020E610000001000000050000000A4CA7751B424340F165A208A92D46400A4CA7751B42434096CD1C925A324640C170AE618646434096CD1C925A324640C170AE6186464340F165A208A92D46400A4CA7751B424340F165A208A92D4640
5937	Щербиновский	2	20	776	38.492612000000001	38.518096999999997	46.639156	46.626631000000003	0103000020E61000000100000005000000FFCEF6E80D3F434074D4D17135504740FFCEF6E80D3F4340668522DDCF514740EE93A30051424340668522DDCF514740EE93A3005142434074D4D17135504740FFCEF6E80D3F434074D4D17135504740
5987	Шабельское	2	20	776	38.451469000000003	38.490968000000002	46.861592999999999	46.842100000000002	0103000020E61000000100000005000000341477BCC939434016FBCBEEC96B4740341477BCC939434034BBEEAD486E4740F7B0170AD83E434034BBEEAD486E4740F7B0170AD83E434016FBCBEEC96B4740341477BCC939434016FBCBEEC96B4740
5481	Старощербиновская	2	20	776	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
50466	Старощербиновская	2	20	776	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
5812	Новощербиновская	2	20	776	38.619993000000001	38.679893	46.488035000000004	46.460293	0103000020E61000000100000005000000DD5F3DEE5B4F4340F3C98AE1EA3A4740DD5F3DEE5B4F4340D5264EEE773E4740C1E3DBBB06574340D5264EEE773E4740C1E3DBBB06574340F3C98AE1EA3A4740DD5F3DEE5B4F4340F3C98AE1EA3A4740
49293	Николаевка	2	20	776	38.555188999999999	38.587403000000002	46.739082000000003	46.724733000000001	0103000020E61000000100000005000000AA0CE36E104743407EAA0A0DC45C4740AA0CE36E10474340F9872D3D9A5E474041498105304B4340F9872D3D9A5E474041498105304B43407EAA0A0DC45C4740AA0CE36E104743407EAA0A0DC45C4740
6311	Любимов	2	20	776	38.752817999999998	38.804723000000003	46.822038999999997	46.806584000000001	0103000020E6100000010000000500000089EB18575C6043400ABDFE243E67474089EB18575C604340AD84EE923869474065ABCB2901674340AD84EE923869474065ABCB29016743400ABDFE243E67474089EB18575C6043400ABDFE243E674740
6363	Красный Дар	2	20	776	38.831969000000001	38.861181999999999	46.677745000000002	46.669440999999999	0103000020E610000001000000050000009624CFF57D6A4340FFCC203EB05547409624CFF57D6A434086032159C0564740B2F336363B6E434086032159C0564740B2F336363B6E4340FFCC203EB05547409624CFF57D6A4340FFCC203EB0554740
49302	Екатериновка	2	20	776	38.724944000000001	38.788257000000002	46.702934999999997	46.681775999999999	0103000020E6100000010000000500000039B709F7CA5C43404E999B6F4457474039B709F7CA5C43405C1B2AC6F9594740EAEBF99AE56443405C1B2AC6F9594740EAEBF99AE56443404E999B6F4457474039B709F7CA5C43404E999B6F44574740
50828	Ейское Укрепление	2	20	776	38.594526000000002	38.630800000000001	46.717726999999996	46.695036000000002	0103000020E61000000100000005000000944F8F6D194C434076C58CF0F6584740944F8F6D194C4340643A747ADE5B47408D28ED0DBE504340643A747ADE5B47408D28ED0DBE50434076C58CF0F6584740944F8F6D194C434076C58CF0F6584740
49260	Глафировка	2	20	776	38.397373000000002	38.421996	46.772044000000001	46.75526	0103000020E610000001000000050000001EA8531EDD3243400DFD135CAC6047401EA8531EDD32434059897956D26247407B8505F70336434059897956D26247407B8505F7033643400DFD135CAC6047401EA8531EDD3243400DFD135CAC604740
45493	Южный	2	20	421	39.822890999999998	39.849670000000003	45.369404000000003	45.350056000000002	0103000020E610000001000000050000001C96067E54E9434061E28FA2CEAC46401C96067E54E943407C8159A148AF464038328FFCC1EC43407C8159A148AF464038328FFCC1EC434061E28FA2CEAC46401C96067E54E9434061E28FA2CEAC4640
2261	Усть-Лабинск	2	20	421	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
50684	Тенгинская	2	20	421	39.992035000000001	40.049680000000002	45.106293000000001	45.091475000000003	0103000020E6100000010000000500000062BEBC00FBFE434068B3EA73B58B464062BEBC00FBFE434099654F029B8D4640F5A10BEA5B06444099654F029B8D4640F5A10BEA5B06444068B3EA73B58B464062BEBC00FBFE434068B3EA73B58B4640
5068	Суворовское	2	20	421	39.410744000000001	39.516162000000001	45.297553999999998	45.269080000000002	0103000020E610000001000000050000009D83674293B44340FC00A43671A246409D83674293B44340A165DD3F16A646400FB8AE9811C24340A165DD3F16A646400FB8AE9811C24340FC00A43671A246409D83674293B44340FC00A43671A24640
50803	Согласный	2	20	421	39.967790000000001	39.985818999999999	45.240997	45.228043	0103000020E61000000100000005000000ABB2EF8AE0FB4340768A5583309D4640ABB2EF8AE0FB434091B75CFDD89E4640416326512FFE434091B75CFDD89E4640416326512FFE4340768A5583309D4640ABB2EF8AE0FB4340768A5583309D4640
50676	Саратовский	2	20	421	39.964682000000003	40.013972000000003	45.221573999999997	45.199914999999997	0103000020E610000001000000050000001B8524B37AFB43406B7D91D0969946401B8524B37AFB43406BD26D895C9C4640A587A1D5C90144406BD26D895C9C4640A587A1D5C90144406B7D91D0969946401B8524B37AFB43406B7D91D096994640
4970	Новолабинская	2	20	421	39.862983	39.939978000000004	45.129629000000001	45.098123999999999	0103000020E610000001000000050000008200193A76EE4340F279C5538F8C46408200193A76EE43407DCEDDAE97904640D17AF83251F843407DCEDDAE97904640D17AF83251F84340F279C5538F8C46408200193A76EE4340F279C5538F8C4640
50774	Некрасовская	2	20	421	39.723547000000003	39.789807000000003	45.159610000000001	45.134245	0103000020E61000000100000005000000390F27309DDC43406553AEF02E914640390F27309DDC4340AA0EB9196E9446407193516518E54340AA0EB9196E9446407193516518E543406553AEF02E914640390F27309DDC43406553AEF02E914640
50283	Ладожская	2	20	421	39.891863999999998	39.975487999999999	45.332141	45.280408000000001	0103000020E61000000100000005000000683D7C9928F24340B5C4CA68E4A34640683D7C9928F243409354A69883AA4640FAD170CADCFC43409354A69883AA4640FAD170CADCFC4340B5C4CA68E4A34640683D7C9928F24340B5C4CA68E4A34640
50708	Кирпильская	2	20	421	39.633563000000002	39.750917999999999	45.393523000000002	45.361576999999997	0103000020E61000000100000005000000537AA69718D143402EFEB62748AE4640537AA69718D14340A69C2FF65EB2464026FDBD141EE04340A69C2FF65EB2464026FDBD141EE043402EFEB62748AE4640537AA69718D143402EFEB62748AE4640
50838	Кадухин	2	20	421	39.787515999999997	39.822432999999997	45.196434000000004	45.181035999999999	0103000020E61000000100000005000000D2890453CDE4434007B309302C974640D2890453CDE4434047E9D2BF2499464059130B7C45E9434047E9D2BF2499464059130B7C45E9434007B309302C974640D2890453CDE4434007B309302C974640
50771	Железный	2	20	421	39.537424999999999	39.571784999999998	45.305084999999998	45.288080999999998	0103000020E61000000100000005000000C286A757CAC44340ABCC94D6DFA44640C286A757CAC4434005C078060DA74640F3AB394030C9434005C078060DA74640F3AB394030C94340ABCC94D6DFA44640C286A757CAC44340ABCC94D6DFA44640
3433	Двубратский	2	20	421	39.782611000000003	39.819423999999998	45.303607999999997	45.237366999999999	0103000020E61000000100000005000000B43EE5982CE443402713B70A629E4640B43EE5982CE44340E8667FA0DCA646405CC7B8E2E2E84340E8667FA0DCA646405CC7B8E2E2E843402713B70A629E4640B43EE5982CE443402713B70A629E4640
50899	Восточная	2	20	421	39.747171999999999	39.805644000000001	45.382300999999998	45.354756000000002	0103000020E61000000100000005000000533E0455A3DF4340A70705A568AD4640533E0455A3DF4340321D3A3DEFB04640FC1BB4571FE74340321D3A3DEFB04640FC1BB4571FE74340A70705A568AD4640533E0455A3DF4340A70705A568AD4640
50294	Воронежская	2	20	421	39.538789999999999	39.590649999999997	45.223002000000001	45.197597000000002	0103000020E61000000100000005000000B7B41A12F7C44340D464C6DB4A994640B7B41A12F7C44340A7785C548B9C4640F2B0506B9ACB4340A7785C548B9C4640F2B0506B9ACB4340D464C6DB4A994640B7B41A12F7C44340D464C6DB4A994640
50703	Болгов	2	20	421	39.850560000000002	39.925002999999997	45.242876000000003	45.220818999999999	0103000020E6100000010000000500000094A46B26DFEC4340EFAA07CC439C464094A46B26DFEC4340DD7D8E8F169F4640D7D9907F66F64340DD7D8E8F169F4640D7D9907F66F64340EFAA07CC439C464094A46B26DFEC4340EFAA07CC439C4640
50859	Безлесный	2	20	421	39.963487000000001	40.026279000000002	45.445273	45.411002000000003	0103000020E61000000100000005000000828FC18A53FB4340994BAAB69BB44640828FC18A53FB43405A65A6B4FEB846402AC93A1C5D0344405A65A6B4FEB846402AC93A1C5D034440994BAAB69BB44640828FC18A53FB4340994BAAB69BB44640
50766	Александровский	2	20	421	40.033177999999999	40.076206999999997	45.260300000000001	45.245522000000001	0103000020E610000001000000050000002D793C2D3F0444406939D0436D9F46402D793C2D3F0444400C93A98251A14640F65CA626C10944400C93A98251A14640F65CA626C10944406939D0436D9F46402D793C2D3F0444406939D0436D9F4640
1036	Успенское	2	20	251	41.362433000000003	41.432493000000001	44.846136000000001	44.821776	0103000020E61000000100000005000000DFFE5C3464AE4440A051BAF42F694640DFFE5C3464AE4440F0FB372F4E6C4640DD5F3DEE5BB74440F0FB372F4E6C4640DD5F3DEE5BB74440A051BAF42F694640DFFE5C3464AE4440A051BAF42F694640
50427	Успенское	2	20	251	41.362433000000003	41.432493000000001	44.846136000000001	44.821776	0103000020E61000000100000005000000DFFE5C3464AE4440A051BAF42F694640DFFE5C3464AE4440F0FB372F4E6C4640DD5F3DEE5BB74440F0FB372F4E6C4640DD5F3DEE5BB74440A051BAF42F694640DFFE5C3464AE4440A051BAF42F694640
32332	Убеженская	2	20	251	41.264040999999999	41.311399999999999	44.932305999999997	44.894626000000002	0103000020E61000000100000005000000CDE67118CCA144405E13D21A83724640CDE67118CCA14440AAEE91CD55774640B9FC87F4DBA74440AAEE91CD55774640B9FC87F4DBA744405E13D21A83724640CDE67118CCA144405E13D21A83724640
1928	Трехсельское	2	20	251	41.293298999999998	41.319699999999997	44.694046999999998	44.660986999999999	0103000020E61000000100000005000000897956D28AA54440630AD6389B544640897956D28AA5444086713788D6584640FE43FAEDEBA8444086713788D6584640FE43FAEDEBA84440630AD6389B544640897956D28AA54440630AD6389B544640
2034	Новоурупское	2	20	251	41.332717000000002	41.358445000000003	44.652907999999996	44.628453	0103000020E6100000010000000500000060E97C7896AA44405B09DD257150464060E97C7896AA4440FCA5457D9253464016359886E1AD4440FCA5457D9253464016359886E1AD44405B09DD257150464060E97C7896AA44405B09DD2571504640
47840	Новенький	2	20	251	41.194718000000002	41.212153999999998	44.994002999999999	44.975808000000001	0103000020E61000000100000005000000A5F8F884EC9844406C96CB46E77C4640A5F8F884EC9844401D90847D3B7F464098DBBDDC279B44401D90847D3B7F464098DBBDDC279B44406C96CB46E77C4640A5F8F884EC9844406C96CB46E77C4640
50671	Николаевская	2	20	251	41.550351999999997	41.596777000000003	44.871493999999998	44.852812999999998	0103000020E61000000100000005000000E3A430EF71C64440444DF4F9286D4640E3A430EF71C6444082548A1D8D6F4640A400513063CC444082548A1D8D6F4640A400513063CC4440444DF4F9286D4640E3A430EF71C64440444DF4F9286D4640
47710	Мичуринский	2	20	251	41.469107999999999	41.491584000000003	44.788500999999997	44.774861000000001	0103000020E610000001000000050000005F251FBB0BBC444012F92EA52E6346405F251FBB0BBC444080EECB99ED644640529E7939ECBE444080EECB99ED644640529E7939ECBE444012F92EA52E6346405F251FBB0BBC444012F92EA52E634640
50336	Марьино	2	20	251	41.246802000000002	41.281396000000001	44.911378999999997	44.891643999999999	0103000020E61000000100000005000000304B3B35979F44405AD6FD6321724640304B3B35979F44406EA12B11A8744640D49CBCC804A444406EA12B11A8744640D49CBCC804A444405AD6FD6321724640304B3B35979F44405AD6FD6321724640
1543	Маламино	2	20	251	41.501834000000002	41.532305000000001	44.836247999999998	44.821295999999997	0103000020E61000000100000005000000AC02B5183CC04440F52A323A20694640AC02B5183CC0444036ACA92C0A6B4640A73FFB9122C4444036ACA92C0A6B4640A73FFB9122C44440F52A323A20694640AC02B5183CC04440F52A323A20694640
1488	Коноково	2	20	251	41.306468000000002	41.343218	44.879657000000002	44.842830999999997	0103000020E61000000100000005000000A1A2EA573AA744400987DEE2E16B4640A1A2EA573AA744404759BF999870464003B34291EEAB44404759BF999870464003B34291EEAB44400987DEE2E16B4640A1A2EA573AA744400987DEE2E16B4640
1691	Державный	2	20	251	41.419997000000002	41.435799000000003	44.861010999999998	44.846423000000001	0103000020E6100000010000000500000085B53176C2B5444086CABF96576C464085B53176C2B54440853FC39B356E46409450FA42C8B74440853FC39B356E46409450FA42C8B7444086CABF96576C464085B53176C2B5444086CABF96576C4640
50679	поселокПансионат отдыха Южный	2	20	541	38.604399000000001	39.581513999999999	44.514412	44.029049999999998	0103000020E61000000100000005000000185E49F25C4D434072F90FE9B7034640185E49F25C4D4340C1559E40D84146404415FE0C6FCA4340C1559E40D84146404415FE0C6FCA434072F90FE9B7034640185E49F25C4D434072F90FE9B7034640
30302	Шепси	2	20	541	39.134188999999999	39.165415000000003	44.05245	44.025460000000002	0103000020E61000000100000005000000D13DEB1A2D91434097ADF54542034640D13DEB1A2D9143406D567DAEB606464049A297512C9543406D567DAEB606464049A297512C95434097ADF54542034640D13DEB1A2D91434097ADF54542034640
31347	Шаумян	2	20	541	39.282752000000002	39.301760999999999	44.33334	44.309311000000001	0103000020E610000001000000050000007670B03731A4434083A5BA80972746407670B03731A443406D3997E2AA2A4640A81ABD1AA0A643406D3997E2AA2A4640A81ABD1AA0A6434083A5BA80972746407670B03731A4434083A5BA8097274640
31791	Цыпка	2	20	541	39.168450999999997	39.181333000000002	44.166733000000001	44.152596000000003	0103000020E610000001000000050000003FFD67CD8F9543400EC00644881346403FFD67CD8F954340FD14C78157154640C15774EB35974340FD14C78157154640C15774EB359743400EC00644881346403FFD67CD8F9543400EC0064488134640
30112	Тюменский	2	20	541	38.968665000000001	38.979796	44.182876	44.177562999999999	0103000020E61000000100000005000000D2E3F736FD7B434065FD6662BA164640D2E3F736FD7B4340959C137B68174640356090F4697D4340959C137B68174640356090F4697D434065FD6662BA164640D2E3F736FD7B434065FD6662BA164640
31385	Терзиян	2	20	541	39.420473000000001	39.435107000000002	44.213852000000003	44.207720000000002	0103000020E61000000100000005000000EEEC2B0FD2B54340D15CA791961A4640EEEC2B0FD2B54340941799805F1B46405EA10F96B1B74340941799805F1B46405EA10F96B1B74340D15CA791961A4640EEEC2B0FD2B54340D15CA791961A4640
29551	Тенгинка	2	20	541	38.776784999999997	38.794707000000002	44.333972000000003	44.319997999999998	0103000020E61000000100000005000000FD82DDB06D6343408864C8B1F5284640FD82DDB06D634340CEE33098BF2A46407E737FF5B8654340CEE33098BF2A46407E737FF5B86543408864C8B1F5284640FD82DDB06D6343408864C8B1F5284640
50486	Сосновый	2	20	541	38.939909999999998	38.949162999999999	44.181421999999998	44.172882000000001	0103000020E6100000010000000500000078978BF84E784340960854FF2016464078978BF84E78434030630AD63817464060C9552C7E79434030630AD63817464060C9552C7E794340960854FF2016464078978BF84E784340960854FF20164640
50338	Садовое	2	20	541	39.163052	39.177236000000001	44.391533000000003	44.383268999999999	0103000020E6100000010000000500000011C64FE3DE9443400A4966F50E31464011C64FE3DE9443400327DBC01D32464041D653ABAF9643400327DBC01D32464041D653ABAF9643400A4966F50E31464011C64FE3DE9443400A4966F50E314640
50777	Псебе	2	20	541	38.944806	38.962601999999997	44.293564000000003	44.280605999999999	0103000020E6100000010000000500000044882B67EF784340DB87BCE5EA23464044882B67EF78434038A45181932546403788D68A367B434038A45181932546403788D68A367B4340DB87BCE5EA23464044882B67EF784340DB87BCE5EA234640
50436	Поселок Джубга	2	20	541	38.692594999999997	38.716562000000003	44.345402	44.301841000000003	0103000020E61000000100000005000000C22FF5F3A6584340C5CBD3B9A2264640C22FF5F3A65843408BFCFA21362C464037C7B94DB85B43408BFCFA21362C464037C7B94DB85B4340C5CBD3B9A2264640C22FF5F3A6584340C5CBD3B9A2264640
50302	Пляхо	2	20	541	38.827207999999999	38.838597999999998	44.276276000000003	44.268343000000002	0103000020E61000000100000005000000AA7EA5F3E1694340268E3C1059224640AA7EA5F3E1694340B95510035D234640D93EE42D576B4340B95510035D234640D93EE42D576B4340268E3C1059224640AA7EA5F3E1694340268E3C1059224640
50664	Островская Щель	2	20	541	39.288268000000002	39.297924999999999	44.28069	44.273049	0103000020E61000000100000005000000DE3D40F7E5A443404E9A0645F3224640DE3D40F7E5A44340392861A6ED23464095D4096822A64340392861A6ED23464095D4096822A643404E9A0645F3224640DE3D40F7E5A443404E9A0645F3224640
29917	Ольгинка	2	20	541	38.884205999999999	38.896459	44.215144000000002	44.201911000000003	0103000020E61000000100000005000000A77686A92D714340F1D93A38D8194640A77686A92D7143401FF7ADD6891B4640399A232BBF7243401FF7ADD6891B4640399A232BBF724340F1D93A38D8194640A77686A92D714340F1D93A38D8194640
46103	Новомихайловский	2	20	541	38.826264999999999	38.886353	44.270466999999996	44.243338000000001	0103000020E610000001000000050000002B6A300DC3694340E1EF17B3251F46402B6A300DC3694340D8D2A3A99E22464012DBDD0374714340D8D2A3A99E22464012DBDD0374714340E1EF17B3251F46402B6A300DC3694340E1EF17B3251F4640
30018	Небуг	2	20	541	38.994177999999998	39.009557000000001	44.179456999999999	44.161987000000003	0103000020E610000001000000050000008B338639417F434047B071FDBB1446408B338639417F4340E6046D72F81646405439ED2939814340E6046D72F81646405439ED293981434047B071FDBB1446408B338639417F434047B071FDBB144640
31218	Навагинское	2	20	541	39.328989	39.367570999999998	44.379558000000003	44.365943000000001	0103000020E6100000010000000500000033DFC14F1CAA43409E996038D72E464033DFC14F1CAA4340B477465B95304640A0FA07910CAF4340B477465B95304640A0FA07910CAF43409E996038D72E464033DFC14F1CAA43409E996038D72E4640
32963	Молдавановка	2	20	541	38.866491000000003	38.889972999999998	44.474232000000001	44.462518000000003	0103000020E61000000100000005000000A1A3552DE96E4340DAE731CA333B4640A1A3552DE96E4340BC5B59A2B33C464058A9A0A2EA714340BC5B59A2B33C464058A9A0A2EA714340DAE731CA333B4640A1A3552DE96E4340DAE731CA333B4640
31712	Мессажай	2	20	541	39.111902000000001	39.127775	44.143495999999999	44.137194999999998	0103000020E61000000100000005000000B22D03CE528E43405D16139B8F114640B22D03CE528E4340AC8DB1135E1246408A1F63EE5A904340AC8DB1135E1246408A1F63EE5A9043405D16139B8F114640B22D03CE528E43405D16139B8F114640
31011	Мал. Псеушхо	2	20	541	39.293883000000001	39.311731999999999	44.122281000000001	44.108942999999996	0103000020E61000000100000005000000D9EC48F59DA5434066101FD8F10D4640D9EC48F59DA543400AF65FE7A60F4640EF8E8CD5E6A743400AF65FE7A60F4640EF8E8CD5E6A7434066101FD8F10D4640D9EC48F59DA5434066101FD8F10D4640
50346	Лермонтово	2	20	541	38.740501999999999	38.769230999999998	44.312910000000002	44.298189999999998	0103000020E61000000100000005000000B14F00C5C85E434043FF04172B264640B14F00C5C85E4340B24B546F0D284640E108522976624340B24B546F0D284640E10852297662434043FF04172B264640B14F00C5C85E434043FF04172B264640
30782	Кривенковское	2	20	541	39.226993999999998	39.242849	44.204160000000002	44.176333999999997	0103000020E61000000100000005000000B131AF230E9D43402096CD1C92164640B131AF230E9D4340609335EA211A4640E36E10AD159F4340609335EA211A4640E36E10AD159F43402096CD1C92164640B131AF230E9D43402096CD1C92164640
32982	Кирпичное	2	20	541	39.190361000000003	39.215845999999999	44.172811000000003	44.161921999999997	0103000020E6100000010000000500000089B7CEBF5D9843405F402FDCB914464089B7CEBF5D984340CDB1BCAB1E164640787C7BD7A09B4340CDB1BCAB1E164640787C7BD7A09B43405F402FDCB914464089B7CEBF5D9843405F402FDCB9144640
23288	Индюк	2	20	541	39.23366	39.259010000000004	44.259892999999998	44.206389000000001	0103000020E6100000010000000500000012312592E89D434088A06AF46A1A464012312592E89D4340CBBA7F2C4421464022AB5B3D27A14340CBBA7F2C4421464022AB5B3D27A1434088A06AF46A1A464012312592E89D434088A06AF46A1A4640
29361	Джубга	2	20	541	38.692594999999997	38.716562000000003	44.345402	44.301841000000003	0103000020E61000000100000005000000C22FF5F3A6584340C5CBD3B9A2264640C22FF5F3A65843408BFCFA21362C464037C7B94DB85B43408BFCFA21362C464037C7B94DB85B4340C5CBD3B9A2264640C22FF5F3A6584340C5CBD3B9A2264640
18863	Дефановка	2	20	541	38.766247999999997	38.799737	44.438541999999998	44.422049999999999	0103000020E610000001000000050000000D501A6A146243406EA301BC053646400D501A6A1462434012F6ED2422384640593332C85D66434012F6ED2422384640593332C85D6643406EA301BC053646400D501A6A146243406EA301BC05364640
30442	Дедеркой	2	20	541	39.124594999999999	39.135474000000002	44.057800999999998	44.051147	0103000020E61000000100000005000000601F9DBAF28F4340EE2422FC8B064640601F9DBAF28F43408A56EE0566074640AABA4736579143408A56EE0566074640AABA473657914340EE2422FC8B064640601F9DBAF28F4340EE2422FC8B064640
50755	Гунайка Четвёртая	2	20	541	39.428944000000001	39.449767000000001	44.280948000000002	44.269717999999997	0103000020E6100000010000000500000060E811A3E7B643403E92921E8622464060E811A3E7B6434035F0A31AF6234640F7E80DF791B9434035F0A31AF6234640F7E80DF791B943403E92921E8622464060E811A3E7B643403E92921E86224640
47394	Горское	2	20	541	38.725087000000002	38.737411999999999	44.391263000000002	44.383881000000002	0103000020E610000001000000050000009CE09BA6CF5C434024473A03233146409CE09BA6CF5C43404391EEE714324640C7D63384635E43404391EEE714324640C7D63384635E434024473A03233146409CE09BA6CF5C434024473A0323314640
31096	Горный	2	20	541	39.266241000000001	39.290208	44.296906	44.269227999999998	0103000020E610000001000000050000005BED612F14A2434070952710762246405BED612F14A243403BFE0B0401264640CF84268925A543403BFE0B0401264640CF84268925A5434070952710762246405BED612F14A243407095271076224640
31552	Гойтх	2	20	541	39.366447999999998	39.382142000000002	44.256793999999999	44.236427999999997	0103000020E61000000100000005000000A1D79FC4E7AE4340E9EDCF45431E4640A1D79FC4E7AE43408EE733A0DE204640CA367007EAB043408EE733A0DE204640CA367007EAB04340E9EDCF45431E4640A1D79FC4E7AE4340E9EDCF45431E4640
46669	Георгиевское	2	20	541	39.241734999999998	39.265082999999997	44.170166000000002	44.155306000000003	0103000020E6100000010000000500000037A6272CF19E4340B16F2711E113464037A6272CF19E43401172DEFFC7154640DFDC5F3DEEA143401172DEFFC7154640DFDC5F3DEEA14340B16F2711E113464037A6272CF19E4340B16F2711E1134640
50574	Вольное	2	20	541	39.104033000000001	39.118037000000001	44.080857999999999	44.069440999999998	0103000020E61000000100000005000000365A0EF4508D434032005471E3084640365A0EF4508D43405BCF108E590A4640E65B1FD61B8F43405BCF108E590A4640E65B1FD61B8F434032005471E3084640365A0EF4508D434032005471E3084640
50634	Большое Псеушхо	2	20	541	39.333139000000003	39.351995000000002	44.079931999999999	44.072141999999999	0103000020E61000000100000005000000D6027B4CA4AA43408255F5F23B094640D6027B4CA4AA4340B2F336363B0A464082AD122C0EAD4340B2F336363B0A464082AD122C0EAD43408255F5F23B094640D6027B4CA4AA43408255F5F23B094640
3297	Бжид	2	20	541	38.660615	38.671691000000003	44.361657999999998	44.352466999999997	0103000020E610000001000000050000009F1F46088F544340A9F57EA31D2D46409F1F46088F5443401B2B31CF4A2E46403F027FF8F95543401B2B31CF4A2E46403F027FF8F9554340A9F57EA31D2D46409F1F46088F544340A9F57EA31D2D4640
46678	Анастасиевка	2	20	541	39.275368	39.288142000000001	44.174788999999997	44.163823000000001	0103000020E61000000100000005000000B62E35423FA3434093AAED26F8144640B62E35423FA34340AB59677C5F164640514D49D6E1A44340AB59677C5F164640514D49D6E1A4434093AAED26F8144640B62E35423FA3434093AAED26F8144640
50635	Агуй-Шапсуг	2	20	541	39.061947000000004	39.075718000000002	44.193845000000003	44.170166000000002	0103000020E61000000100000005000000EC8A19E1ED8743401172DEFFC7154640EC8A19E1ED8743401FBFB7E9CF184640F9DB9E20B18943401FBFB7E9CF184640F9DB9E20B18943401172DEFFC7154640EC8A19E1ED8743401172DEFFC7154640
30148	Агой	2	20	541	39.024540999999999	39.046415000000003	44.153261999999998	44.141387000000002	0103000020E61000000100000005000000A034D428248343402F8A1EF818124640A034D428248343401ADCD6169E1346409D853DEDF08543401ADCD6169E1346409D853DEDF08543402F8A1EF818124640A034D428248343402F8A1EF818124640
50759	Туапсе	2	20	7087	39.080038999999999	39.246065000000002	44.256878	44.087327000000002	0103000020E61000000100000005000000C8B3CBB73E8A43406687F8872D0B4640C8B3CBB73E8A4340EC87D860E12046405AD8D30E7F9F4340EC87D860E12046405AD8D30E7F9F43406687F8872D0B4640C8B3CBB73E8A43406687F8872D0B4640
47442	Южный	2	20	1034	40.107773999999999	40.114485000000002	45.984881999999999	45.983235000000001	0103000020E61000000100000005000000F7ADD689CB0D44402BA4FCA4DAFD4640F7ADD689CB0D4440A435069D10FE4640F870C971A70E4440A435069D10FE4640F870C971A70E44402BA4FCA4DAFD4640F7ADD689CB0D44402BA4FCA4DAFD4640
27723	Юго-Северная	2	20	1034	40.213569	40.281688000000003	45.766492999999997	45.748389000000003	0103000020E610000001000000050000003F389F3A561B4440D4D7F335CBDF46403F389F3A561B444074CE4F711CE246407CD6355A0E24444074CE4F711CE246407CD6355A0E244440D4D7F335CBDF46403F389F3A561B4440D4D7F335CBDF4640
50691	Школьный	2	20	1034	40.13926	40.150776999999998	45.787154000000001	45.780492000000002	0103000020E610000001000000050000000BD28C45D311444013656F29E7E346400BD28C45D311444032755776C1E4464097FE25A94C13444032755776C1E4464097FE25A94C13444013656F29E7E346400BD28C45D311444013656F29E7E34640
27542	Хоперская	2	20	1034	40.396132999999999	40.444336999999997	45.652189	45.640721999999997	0103000020E61000000100000005000000E5EE737CB4324440F2E9B12D03D24640E5EE737CB4324440CDE7DCED7AD346408DB3E908E0384440CDE7DCED7AD346408DB3E908E0384440F2E9B12D03D24640E5EE737CB4324440F2E9B12D03D24640
50367	Фастовецкая	2	20	1034	40.117862000000002	40.201442	45.931958999999999	45.895327999999999	0103000020E6100000010000000500000078B81D1A160F4440B7989F1B9AF2464078B81D1A160F44403F1BB96E4AF746403A05F9D9C81944403F1BB96E4AF746403A05F9D9C8194440B7989F1B9AF2464078B81D1A160F4440B7989F1B9AF24640
27259	Фастовецкая	2	20	1034	40.117862000000002	40.201442	45.931958999999999	45.895327999999999	0103000020E6100000010000000500000078B81D1A160F4440B7989F1B9AF2464078B81D1A160F44403F1BB96E4AF746403A05F9D9C81944403F1BB96E4AF746403A05F9D9C8194440B7989F1B9AF2464078B81D1A160F4440B7989F1B9AF24640
50452	Тихорецк	2	20	1034	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
14835	Тихорецк	2	20	1034	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
50278	Терновская	2	20	1034	40.378588999999998	40.443294999999999	45.872115000000001	45.834162999999997	0103000020E610000001000000050000000BD0B69A7530444041446ADAC5EA46400BD0B69A75304440EFACDD76A1EF46407BBDFBE3BD384440EFACDD76A1EF46407BBDFBE3BD38444041446ADAC5EA46400BD0B69A7530444041446ADAC5EA4640
26957	Садовый	2	20	1034	40.227528999999997	40.234220999999998	45.837183000000003	45.833917999999997	0103000020E610000001000000050000001FF296AB1F1D4440DAC534D3BDEA46401FF296AB1F1D444033E202D028EB4640A98427F4FA1D444033E202D028EB4640A98427F4FA1D4440DAC534D3BDEA46401FF296AB1F1D4440DAC534D3BDEA4640
50616	Привольный	2	20	1034	40.383718999999999	40.401702999999998	45.712674	45.704718999999997	0103000020E610000001000000050000004AED45B41D31444056EF703B34DA46404AED45B41D314440D15AD1E638DB464040DAFF006B334440D15AD1E638DB464040DAFF006B33444056EF703B34DA46404AED45B41D31444056EF703B34DA4640
26987	Полевой	2	20	1034	40.257407000000001	40.269677999999999	45.806362999999997	45.800162	0103000020E6100000010000000500000078616BB6F220444040C05AB56BE6464078616BB6F22044402BDA1CE736E74640B03907CF842244402BDA1CE736E74640B03907CF8422444040C05AB56BE6464078616BB6F220444040C05AB56BE64640
13198	Парковый	2	20	1034	40.146977	40.160981	45.841377000000001	45.833139000000003	0103000020E61000000100000005000000D1217024D0124440D6027B4CA4EA4640D1217024D0124440A54DD53DB2EB4640812381069B144440A54DD53DB2EB4640812381069B144440D6027B4CA4EA4640D1217024D0124440D6027B4CA4EA4640
50818	Отрадненская	2	20	1034	39.815911999999997	40.565761999999999	46.090192999999999	45.566361000000001	0103000020E61000000100000005000000FC34EECD6FE843406C5D6A847EC84640FC34EECD6FE8434000AAB8718B0B4740E7A8A3E36A48444000AAB8718B0B4740E7A8A3E36A4844406C5D6A847EC84640FC34EECD6FE843406C5D6A847EC84640
50343	Отрадная	2	20	1034	40.074230999999997	40.180349	45.616148000000003	45.604256999999997	0103000020E61000000100000005000000B8ACC2668009444085B01A4B58CD4640B8ACC2668009444077BF0AF0DDCE4640E36E10AD1517444077BF0AF0DDCE4640E36E10AD1517444085B01A4B58CD4640B8ACC2668009444085B01A4B58CD4640
27043	Новоромановская	2	20	1034	40.331418999999997	40.362141000000001	45.940088000000003	45.932366000000002	0103000020E61000000100000005000000F22213F06B2A444080F3E2C457F74640F22213F06B2A444058AEB7CD54F8464037C5E3A25A2E444058AEB7CD54F8464037C5E3A25A2E444080F3E2C457F74640F22213F06B2A444080F3E2C457F74640
9005	Новорождественская	2	20	1034	39.908456000000001	39.995933999999998	45.897284999999997	45.833188999999997	0103000020E6100000010000000500000070ED444948F443408731E9EFA5EA464070ED444948F443407E18213CDAF24640BB7CEBC37AFF43407E18213CDAF24640BB7CEBC37AFF43408731E9EFA5EA464070ED444948F443408731E9EFA5EA4640
26333	Мирный	2	20	1034	40.098010000000002	40.114753999999998	46.003484	45.994574999999998	0103000020E610000001000000050000002A5778978B0C4440A835CD3B4EFF46402A5778978B0C44409607E92972004740E78A5242B00E44409607E92972004740E78A5242B00E4440A835CD3B4EFF46402A5778978B0C4440A835CD3B4EFF4640
26060	Малороссийский	2	20	1034	40.263146999999996	40.290284999999997	45.715833000000003	45.700488999999997	0103000020E610000001000000050000002F8507CDAE214440971AA19FA9D946402F8507CDAE214440E4326E6AA0DB46407AC2120F28254440E4326E6AA0DB46407AC2120F28254440971AA19FA9D946402F8507CDAE214440971AA19FA9D94640
27309	Ленинское Возрождение	2	20	1034	40.141424999999998	40.187581000000002	45.980153000000001	45.968378000000001	0103000020E610000001000000050000001CEBE2361A1244403C1570CFF3FB46401CEBE2361A124440C4094CA775FD4640ED2C7AA702184440C4094CA775FD4640ED2C7AA7021844403C1570CFF3FB46401CEBE2361A1244403C1570CFF3FB4640
50797	Ленинский	2	20	1034	40.4315	40.444867000000002	45.601683999999999	45.591374000000002	0103000020E61000000100000005000000AC1C5A643B37444034DAAA24B2CB4640AC1C5A643B374440634337FB03CD4640EA08E066F1384440634337FB03CD4640EA08E066F138444034DAAA24B2CB4640AC1C5A643B37444034DAAA24B2CB4640
26806	Крутой	2	20	1034	40.225848999999997	40.238334999999999	45.876550999999999	45.868738999999998	0103000020E61000000100000005000000CA6ABA9EE81C44403FE1ECD632EF4640CA6ABA9EE81C44405723BBD232F04640FF3EE3C2811E44405723BBD232F04640FF3EE3C2811E44403FE1ECD632EF4640CA6ABA9EE81C44403FE1ECD632EF4640
50796	Красный	2	20	1034	40.339243000000003	40.366695999999997	45.623497999999998	45.611078999999997	0103000020E61000000100000005000000CF328B506C2B4440DD2230D637CE4640CF328B506C2B44408A8F4FC8CECF464079C9FFE4EF2E44408A8F4FC8CECF464079C9FFE4EF2E4440DD2230D637CE4640CF328B506C2B4440DD2230D637CE4640
25983	Краснооктябрьская	2	20	1034	40.044308000000001	40.129424	45.822526000000003	45.786639000000001	0103000020E61000000100000005000000C07971E2AB0544400B613596B0E44640C07971E2AB0544400B0E2F8848E94640A4A833F7901044400B0E2F8848E94640A4A833F7901044400B613596B0E44640C07971E2AB0544400B613596B0E44640
45758	Каменный	2	20	1034	40.026054000000002	40.049950000000003	45.871305	45.860830999999997	0103000020E610000001000000050000000AF7CABC550344400531D0B52FEE46400AF7CABC55034440AFEB17EC86EF4640B537F8C264064440AFEB17EC86EF4640B537F8C2640644400531D0B52FEE46400AF7CABC550344400531D0B52FEE4640
27701	Казаче-Борисовский	2	20	1034	40.363129000000001	40.406922000000002	45.717582999999998	45.714838999999998	0103000020E61000000100000005000000569DD5027B2E4440E27327D87FDB4640569DD5027B2E444031957EC2D9DB4640EF0225051634444031957EC2D9DB4640EF02250516344440E27327D87FDB4640569DD5027B2E4440E27327D87FDB4640
26873	Зеленый	2	20	1034	40.296509999999998	40.309123	45.839179999999999	45.828423000000001	0103000020E61000000100000005000000EE77280AF42544408A20CEC309EA4640EE77280AF425444088BA0F406AEB464080B8AB579127444088BA0F406AEB464080B8AB57912744408A20CEC309EA4640EE77280AF42544408A20CEC309EA4640
50667	Западный	2	20	1034	39.815911999999997	40.565761999999999	46.090192999999999	45.566361000000001	0103000020E61000000100000005000000FC34EECD6FE843406C5D6A847EC84640FC34EECD6FE8434000AAB8718B0B4740E7A8A3E36A48444000AAB8718B0B4740E7A8A3E36A4844406C5D6A847EC84640FC34EECD6FE843406C5D6A847EC84640
26412	Еремизино-Борисовская	2	20	1034	40.447947999999997	40.550545	45.715966000000002	45.705694999999999	0103000020E6100000010000000500000080272D5C56394440B1F9B83654DA464080272D5C5639444023861DC6A4DB4640F8FC30427846444023861DC6A4DB4640F8FC304278464440B1F9B83654DA464080272D5C56394440B1F9B83654DA4640
40468	Восточный	2	20	1034	40.143014999999998	40.164969999999997	45.833019999999998	45.827688000000002	0103000020E6100000010000000500000031EBC5504E12444055A52DAEF1E9464031EBC5504E124440FB743C66A0EA46401A69A9BC1D154440FB743C66A0EA46401A69A9BC1D15444055A52DAEF1E9464031EBC5504E12444055A52DAEF1E94640
26303	Братский	2	20	1034	40.097273000000001	40.124115000000003	46.038666999999997	46.029876000000002	0103000020E6100000010000000500000054E41071730C4440B8770DFAD203474054E41071730C44409B374E0AF3044740B6F81400E30F44409B374E0AF3044740B6F81400E30F4440B8770DFAD203474054E41071730C4440B8770DFAD2034740
26082	Архангельская	2	20	1034	40.237796000000003	40.299914999999999	45.699992000000002	45.657896999999998	0103000020E61000000100000005000000508F6D19701E4440799109F835D44640508F6D19701E444017BB7D5699D94640384A5E9D6326444017BB7D5699D94640384A5E9D63264440799109F835D44640508F6D19701E4440799109F835D44640
25804	Алексеевская	2	20	1034	40.138793	40.172272999999997	45.780749999999998	45.758394000000003	0103000020E61000000100000005000000F5F411F8C3114440C7BDF90D13E14640F5F411F8C31144400E2DB29DEFE34640ED7DAA0A0D1644400E2DB29DEFE34640ED7DAA0A0D164440C7BDF90D13E14640F5F411F8C3114440C7BDF90D13E14640
23047	Тимашевск	2	20	1377	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
24723	Танцура Крамаренко	2	20	1377	38.909286999999999	38.936075000000002	45.550136999999999	45.517578	0103000020E61000000100000005000000C7D63384637443408690F3FE3FC24640C7D6338463744340E7A8A3E36AC6464036CD3B4ED1774340E7A8A3E36AC6464036CD3B4ED17743408690F3FE3FC24640C7D63384637443408690F3FE3FC24640
25386	Стринский	2	20	1377	39.177424999999999	39.256010000000003	45.724843999999997	45.713014000000001	0103000020E61000000100000005000000143FC6DCB59643408ACBF10A44DB4640143FC6DCB5964340D5592DB0C7DC464078B988EFC4A04340D5592DB0C7DC464078B988EFC4A043408ACBF10A44DB4640143FC6DCB59643408ACBF10A44DB4640
50534	Советский	2	20	1377	38.775644	38.792928000000003	45.548079000000001	45.529279000000002	0103000020E6100000010000000500000058AB764D48634340D4BA0D6ABFC3464058AB764D48634340EC4FE27327C64640960A2AAA7E654340EC4FE27327C64640960A2AAA7E654340D4BA0D6ABFC3464058AB764D48634340D4BA0D6ABFC34640
50295	Садовый	2	20	1377	38.916742999999997	38.950536999999997	45.525579	45.507947000000001	0103000020E6100000010000000500000020EBA9D557754340F88C446804C1464020EBA9D557754340713B342C46C34640A8514832AB794340713B342C46C34640A8514832AB794340F88C446804C1464020EBA9D557754340F88C446804C14640
48647	Роговская	2	20	1377	38.706726000000003	38.764541000000001	45.753602999999998	45.705002	0103000020E61000000100000005000000D09D60FF755A4340ABCE6A813DDA4640D09D60FF755A43407095271076E04640BFB9BF7ADC6143407095271076E04640BFB9BF7ADC614340ABCE6A813DDA4640D09D60FF755A4340ABCE6A813DDA4640
50274	Ольховский	2	20	1377	38.560048999999999	39.396946	45.773119000000001	45.363337999999999	0103000020E61000000100000005000000299485AFAF47434070B20DDC81AE4640299485AFAF47434047753A90F5E2464096236420CFB2434047753A90F5E2464096236420CFB2434070B20DDC81AE4640299485AFAF47434070B20DDC81AE4640
25236	Новокорсунская	2	20	1377	39.114201999999999	39.173904	45.655634999999997	45.625445999999997	0103000020E61000000100000005000000A391CF2B9E8E4340FEB4519D0ED04640A391CF2B9E8E4340758E01D9EBD3464061527C7C42964340758E01D9EBD3464061527C7C42964340FEB4519D0ED04640A391CF2B9E8E4340FEB4519D0ED04640
25324	Незаймановский	2	20	1377	39.257815000000001	39.379663000000001	45.725121000000001	45.700754000000003	0103000020E6100000010000000500000089B5F81400A1434046459C4EB2D9464089B5F81400A143404852D2C3D0DC4640294014CC98B043404852D2C3D0DC4640294014CC98B0434046459C4EB2D9464089B5F81400A1434046459C4EB2D94640
14961	Медведовская	2	20	1377	38.992381000000002	39.060769999999998	45.476298999999997	45.418264999999998	0103000020E61000000100000005000000FD153257067F4340DD0720B589B54640FD153257067F43400A0F9A5DF7BC4640F949B54FC78743400A0F9A5DF7BC4640F949B54FC7874340DD0720B589B54640FD153257067F4340DD0720B589B54640
16997	Крупской	2	20	1377	38.834429999999998	38.851641999999998	45.662602	45.649298000000002	0103000020E6100000010000000500000090662C9ACE6A4340DAAD65321CD3464090662C9ACE6A4340D1217024D0D4464034F3E49A026D4340D1217024D0D4464034F3E49A026D4340DAAD65321CD3464090662C9ACE6A4340DAAD65321CD34640
48609	Калинина	2	20	1377	38.866993999999998	38.880468999999998	45.672541000000002	45.666620999999999	0103000020E6100000010000000500000003EACDA8F96E4340D5E940D653D5464003EACDA8F96E43400D1CD0D215D6464027124C35B37043400D1CD0D215D6464027124C35B3704340D5E940D653D5464003EACDA8F96E4340D5E940D653D54640
24873	Днепровская	2	20	1377	38.796700999999999	38.819445999999999	45.636651000000001	45.609130999999998	0103000020E6100000010000000500000062D8614CFA65434069FD2D01F8CD464062D8614CFA6543409CFBABC77DD14640446B459BE36843409CFBABC77DD14640446B459BE368434069FD2D01F8CD464062D8614CFA65434069FD2D01F8CD4640
24738	Беднягина	2	20	1377	38.963580999999998	39.011057000000001	45.535138000000003	45.506709000000001	0103000020E610000001000000050000000306499F567B434060CB2BD7DBC046400306499F567B4340666CE8667FC4464029B2D6506A814340666CE8667FC4464029B2D6506A81434060CB2BD7DBC046400306499F567B434060CB2BD7DBC04640
50463	поселек Тамань	2	20	699	36.686289000000002	36.744247999999999	45.222411999999998	45.195653	0103000020E61000000100000005000000624D6551D8574240A12E52280B994640624D6551D8574240751E15FF779C4640840EBA84435F4240751E15FF779C4640840EBA84435F4240A12E52280B994640624D6551D8574240A12E52280B994640
50313	Юбилейный	2	20	699	36.976984000000002	36.993153	45.335169	45.325468000000001	0103000020E610000001000000050000008E5BCCCF0D7D424080F277EFA8A946408E5BCCCF0D7D424007D15AD1E6AA46404F7633A31F7F424007D15AD1E6AA46404F7633A31F7F424080F277EFA8A946408E5BCCCF0D7D424080F277EFA8A94640
22417	Фонталовская	2	20	699	36.925024999999998	36.946494999999999	45.367674999999998	45.358669999999996	0103000020E61000000100000005000000BF7D1D3867764240350708E6E8AD4640BF7D1D3867764240454772F90FAF4640EC6987BF26794240454772F90FAF4640EC6987BF26794240350708E6E8AD4640BF7D1D3867764240350708E6E8AD4640
20427	Темрюк	2	20	699	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
50413	Тамань	2	20	699	36.686289000000002	36.744247999999999	45.222411999999998	45.195653	0103000020E61000000100000005000000624D6551D8574240A12E52280B994640624D6551D8574240751E15FF779C4640840EBA84435F4240751E15FF779C4640840EBA84435F4240A12E52280B994640624D6551D8574240A12E52280B994640
50531	Тамань	2	20	699	36.686289000000002	36.744247999999999	45.222411999999998	45.195653	0103000020E61000000100000005000000624D6551D8574240A12E52280B994640624D6551D8574240751E15FF779C4640840EBA84435F4240751E15FF779C4640840EBA84435F4240A12E52280B994640624D6551D8574240A12E52280B994640
22866	Таманский	2	20	699	36.779229000000001	36.795963999999998	45.150412000000003	45.141086000000001	0103000020E61000000100000005000000228C9FC6BD63424034F6251B0F924640228C9FC6BD63424086764EB3409346408C65FA25E265424086764EB3409346408C65FA25E265424034F6251B0F924640228C9FC6BD63424034F6251B0F924640
47422	Стрелка	2	20	699	37.256117000000003	37.324990999999997	45.215161999999999	45.18927	0103000020E610000001000000050000008E791D71C8A04240950ED6FF399846408E791D71C8A04240C5ABAC6D8A9B4640463F1A4E99A94240C5ABAC6D8A9B4640463F1A4E99A94240950ED6FF399846408E791D71C8A04240950ED6FF39984640
22046	Старотитаровская	2	20	699	37.124423999999998	37.203611000000002	45.240260999999997	45.192649000000003	0103000020E61000000100000005000000336B2920ED8F4240B64DF1B8A8984640336B2920ED8F42408BC058DFC09E46408D0DDDEC0F9A42408BC058DFC09E46408D0DDDEC0F9A4240B64DF1B8A8984640336B2920ED8F4240B64DF1B8A8984640
47351	Сенной	2	20	699	36.983434000000003	37.008488	45.318129999999996	45.278447999999997	0103000020E6100000010000000500000022E3512AE17D42407CD11E2FA4A3464022E3512AE17D424030F0DC7BB8A84640483481221681424030F0DC7BB8A8464048348122168142407CD11E2FA4A3464022E3512AE17D42407CD11E2FA4A34640
47218	Светлый Путь Ленина	2	20	699	37.646202000000002	37.672548999999997	45.212406000000001	45.199711999999998	0103000020E610000001000000050000000E4E44BFB6D24240334FAE29909946400E4E44BFB6D24240B2BCAB1E309B46408FFAEB1516D64240B2BCAB1E309B46408FFAEB1516D64240334FAE29909946400E4E44BFB6D24240334FAE2990994640
47386	Приморский	2	20	699	36.901587999999997	36.925735000000003	45.271534000000003	45.258270000000003	0103000020E61000000100000005000000A73B4F3C67734240DBC4C9FD0EA14640A73B4F3C6773424044E048A0C1A246409CE1067C7E76424044E048A0C1A246409CE1067C7E764240DBC4C9FD0EA14640A73B4F3C67734240DBC4C9FD0EA14640
47306	Пересыпь	2	20	699	37.120193	37.203000000000003	45.350676999999997	45.334820999999998	0103000020E61000000100000005000000A41AF67B628F4240CB811E6ADBAA4640A41AF67B628F4240CD3AE3FBE2AC4640448B6CE7FB994240CD3AE3FBE2AC4640448B6CE7FB994240CB811E6ADBAA4640A41AF67B628F4240CB811E6ADBAA4640
47616	Кучугуры	2	20	699	36.942371999999999	36.979382000000001	45.414292000000003	45.395947	0103000020E6100000010000000500000043554CA59F78424083F92B64AEB2464043554CA59F7842404A7F2F8507B546404225AE635C7D42404A7F2F8507B546404225AE635C7D424083F92B64AEB2464043554CA59F78424083F92B64AEB24640
21335	Курчанская	2	20	699	37.535646	37.604897000000001	45.235652999999999	45.212628000000002	0103000020E61000000100000005000000DA1D520C90C44240611BF164379B4640DA1D520C90C44240261AA4E0299E46406939D0436DCD4240261AA4E0299E46406939D0436DCD4240611BF164379B4640DA1D520C90C44240611BF164379B4640
47233	Красный Октябрь	2	20	699	37.640515000000001	37.676771000000002	45.203344000000001	45.183799999999998	0103000020E6100000010000000500000079CC4065FCD142409D8026C28697464079CC4065FCD142403EEB1A2D079A4640CCF09F6EA0D642403EEB1A2D079A4640CCF09F6EA0D642409D8026C28697464079CC4065FCD142409D8026C286974640
47327	Красноармейский	2	20	699	36.860823000000003	36.876336000000002	45.399732	45.390219000000002	0103000020E610000001000000050000008352B4722F6E424090A339B2F2B146408352B4722F6E424014950D6B2AB346405B272EC72B70424014950D6B2AB346405B272EC72B70424090A339B2F2B146408352B4722F6E424090A339B2F2B14640
50478	Ильич	2	20	699	36.765880000000003	36.782246999999998	45.429253000000003	45.417859999999997	0103000020E610000001000000050000008B54185B086242403D27BD6F7CB546408B54185B08624240DE5A26C3F1B64640723271AB20644240DE5A26C3F1B64640723271AB206442403D27BD6F7CB546408B54185B086242403D27BD6F7CB54640
22486	Запорожская	2	20	699	36.858173000000001	36.878070000000001	45.386516999999998	45.369124999999997	0103000020E61000000100000005000000B5A7E49CD86D42406891ED7C3FAF4640B5A7E49CD86D42408C2C996379B14640A3CC0699647042408C2C996379B14640A3CC0699647042406891ED7C3FAF4640B5A7E49CD86D42406891ED7C3FAF4640
21558	Голубицкая	2	20	699	37.253278999999999	37.299030000000002	45.330638999999998	45.315316000000003	0103000020E61000000100000005000000BDE13E726BA04240E9F351465CA84640BDE13E726BA042401DE4F56052AA4640EE42739D46A642401DE4F56052AA4640EE42739D46A64240E9F351465CA84640BDE13E726BA04240E9F351465CA84640
22583	Гаркуша	2	20	699	36.835633999999999	36.866652999999999	45.323650000000001	45.315373000000001	0103000020E610000001000000050000007CB60E0EF66A42404D8578245EA846407CB60E0EF66A4240DAACFA5C6DA946407AFD497CEE6E4240DAACFA5C6DA946407AFD497CEE6E42404D8578245EA846407CB60E0EF66A42404D8578245EA84640
22222	Вышестеблиевская	2	20	699	36.978205000000003	37.028905999999999	45.203432999999997	45.185946999999999	0103000020E6100000010000000500000050E449D2357D424008E57D1CCD97464050E449D2357D4240ADF6B0170A9A46403F541A31B3834240ADF6B0170A9A46403F541A31B383424008E57D1CCD97464050E449D2357D424008E57D1CCD974640
47714	Волна	2	20	699	36.703743000000003	36.714325000000002	45.130411000000002	45.122207000000003	0103000020E61000000100000005000000FCE42840145A4240D02B9E7AA48F4640FCE42840145A4240F304C24EB19046408CDB68006F5B4240F304C24EB19046408CDB68006F5B4240D02B9E7AA48F4640FCE42840145A4240D02B9E7AA48F4640
4879	Виноградный	2	20	699	36.892415999999997	36.905926999999998	45.197692000000004	45.188862999999998	0103000020E61000000100000005000000AC36FFAF3A7242405436ACA92C984640AC36FFAF3A7242402657B1F84D9946401DC87A6AF57342402657B1F84D9946401DC87A6AF57342405436ACA92C984640AC36FFAF3A7242405436ACA92C984640
47818	Веселовка	2	20	699	36.899163000000001	36.913805000000004	45.132745	45.124313000000001	0103000020E61000000100000005000000FA62EFC517734240DCBB067DE98F4640FA62EFC51773424090DAC4C9FD904640EDF5EE8FF774424090DAC4C9FD904640EDF5EE8FF7744240DCBB067DE98F4640FA62EFC517734240DCBB067DE98F4640
50688	Белый	2	20	699	37.257778999999999	37.282446999999998	45.174028	45.163333999999999	0103000020E610000001000000050000003C4CFBE6FEA042409529E620E89446403C4CFBE6FEA042404D4BAC8C4696464039ED293927A442404D4BAC8C4696464039ED293927A442409529E620E89446403C4CFBE6FEA042409529E620E8944640
22620	Батарейка	2	20	699	36.821745999999997	36.832157000000002	45.396954000000001	45.387794999999997	0103000020E6100000010000000500000035CF11F92E694240B2463D44A3B1464035CF11F92E69424019028063CFB246409911DE1E846A424019028063CFB246409911DE1E846A4240B2463D44A3B1464035CF11F92E694240B2463D44A3B14640
21676	Ахтанизовская	2	20	699	37.079732999999997	37.127191000000003	45.336759000000001	45.299937	0103000020E61000000100000005000000BBB4E1B0348A424020EEEA5564A64640BBB4E1B0348A42401CD13DEB1AAB46403BAC70CB479042401CD13DEB1AAB46403BAC70CB4790424020EEEA5564A64640BBB4E1B0348A424020EEEA5564A64640
19326	Шереметьевское	2	20	1525	40.186332	40.215186000000003	45.331119999999999	45.321899999999999	0103000020E6100000010000000500000061191BBAD91744408C4AEA0434A9464061191BBAD91744409886E12362AA46404E4700378B1B44409886E12362AA46404E4700378B1B44408C4AEA0434A9464061191BBAD91744408C4AEA0434A94640
50843	Шевченко	2	20	1525	40.240976000000003	40.267279000000002	45.331905999999996	45.318173999999999	0103000020E610000001000000050000007A8F334DD81E44400038F6ECB9A846407A8F334DD81E44404FAC53E57BAA46402CF4C132362244404FAC53E57BAA46402CF4C132362244400038F6ECB9A846407A8F334DD81E44400038F6ECB9A84640
20008	Чернобабов	2	20	1525	40.097254999999997	40.108249999999998	45.551133999999998	45.546393999999999	0103000020E61000000100000005000000AD2F12DA720C4440855D143DF0C54640AD2F12DA720C444059DB148F8BC6464060E5D022DB0D444059DB148F8BC6464060E5D022DB0D4440855D143DF0C54640AD2F12DA720C4440855D143DF0C54640
19836	Терско-Каламбетский	2	20	1525	40.093060000000001	40.127572999999998	45.327952000000003	45.320670999999997	0103000020E610000001000000050000006B48DC63E90B444047E350BF0BA946406B48DC63E90B44403354C554FAA94640226DE34F541044403354C554FAA94640226DE34F5410444047E350BF0BA946406B48DC63E90B444047E350BF0BA94640
18756	Терновый	2	20	1525	40.010846000000001	40.025452999999999	45.464790000000001	45.454946999999997	0103000020E610000001000000050000006EA5D76663014440E7340BB43BBA46406EA5D7666301444001C11C3D7EBB4640E44A3D0B4203444001C11C3D7EBB4640E44A3D0B42034440E7340BB43BBA46406EA5D76663014440E7340BB43BBA4640
18001	Тбилисская	2	20	1525	40.15419	40.247301	45.376001000000002	45.347827000000002	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
50716	Средний	2	20	1525	40.126244	40.140895	45.205877999999998	45.194529000000003	0103000020E610000001000000050000007AA86DC328104440D28F8653E69846407AA86DC328104440A27BD6355A9A4640C095ECD808124440A27BD6355A9A4640C095ECD808124440D28F8653E69846407AA86DC328104440D28F8653E6984640
19198	Северокубанский	2	20	1525	40.266542000000001	40.304971999999999	45.332577999999998	45.325006000000002	0103000020E6100000010000000500000056815A0C1E2244407C80EECB99A9464056815A0C1E2244403EAF78EA91AA46400D198F52092744403EAF78EA91AA46400D198F52092744407C80EECB99A9464056815A0C1E2244407C80EECB99A94640
18648	Северин	2	20	1525	40.202466000000001	40.221564000000001	45.354362999999999	45.340732000000003	0103000020E61000000100000005000000A646E867EA194440B0592E1B9DAB4640A646E867EA194440CBF44BC45BAD464048FC8A355C1C4440CBF44BC45BAD464048FC8A355C1C4440B0592E1B9DAB4640A646E867EA194440B0592E1B9DAB4640
50380	Песчаный	2	20	1525	40.347327999999997	40.394103000000001	45.269232000000002	45.246093000000002	0103000020E61000000100000005000000177E703E752C44402463B5F97F9F4640177E703E752C4440B284B53176A24640B42094F771324440B284B53176A24640B42094F7713244402463B5F97F9F4640177E703E752C44402463B5F97F9F4640
19115	Новопеховский-Первый	2	20	1525	40.319040000000001	40.335892000000001	45.343392000000001	45.335245	0103000020E61000000100000005000000D40E7F4DD6284440E292E34EE9AA4640D40E7F4DD6284440A1DAE044F4AB4640787E5182FE2A4440A1DAE044F4AB4640787E5182FE2A4440E292E34EE9AA4640D40E7F4DD6284440E292E34EE9AA4640
19933	Нововладимировская	2	20	1525	40.081130000000002	40.168230999999999	45.554504000000001	45.539141000000001	0103000020E61000000100000005000000BC5CC477620A44406477819202C54640BC5CC477620A444027C0B0FCF9C646403196E9978815444027C0B0FCF9C646403196E997881544406477819202C54640BC5CC477620A44406477819202C54640
20061	Новобекешевская	2	20	1525	40.134121999999998	40.188937000000003	45.559780000000003	45.553916999999998	0103000020E6100000010000000500000049D6E1E82A11444066D993C0E6C6464049D6E1E82A1144403A7AFCDEA6C746408F006E162F1844403A7AFCDEA6C746408F006E162F18444066D993C0E6C6464049D6E1E82A11444066D993C0E6C64640
50265	Марьинский	2	20	1525	40.119793999999999	40.145180000000003	45.285094000000001	45.275308000000003	0103000020E61000000100000005000000E620E868550F4440E129E44A3DA34640E620E868550F44409624CFF57DA4464043041C42951244409624CFF57DA4464043041C4295124440E129E44A3DA34640E620E868550F4440E129E44A3DA34640
19634	Ловлинская	2	20	1525	40.201352	40.278041000000002	45.533774999999999	45.504353000000002	0103000020E61000000100000005000000FA7DFFE6C5194440DB519CA38EC04640FA7DFFE6C519444011363CBD52C446403CF9F4D89623444011363CBD52C446403CF9F4D896234440DB519CA38EC04640FA7DFFE6C5194440DB519CA38EC04640
19038	Красный Зеленчук	2	20	1525	40.332101000000002	40.350751000000002	45.285094000000001	45.268577999999998	0103000020E6100000010000000500000005FC1A49822A444069368FC360A2464005FC1A49822A44409624CFF57DA446400805A568E52C44409624CFF57DA446400805A568E52C444069368FC360A2464005FC1A49822A444069368FC360A24640
20401	Зубов	2	20	1525	40.070512000000001	40.082864000000001	45.263154999999998	45.258091999999998	0103000020E61000000100000005000000DFFC868906094440FBAD9D2809A14640DFFC868906094440B2632310AFA1464004029D499B0A4440B2632310AFA1464004029D499B0A4440FBAD9D2809A14640DFFC868906094440FBAD9D2809A14640
19803	Зиссермановский	2	20	1525	40.170845	40.185999000000002	45.286375	45.277248999999998	0103000020E61000000100000005000000B2D7BB3FDE154440A2EC2DE57CA34640B2D7BB3FDE1544402DB29DEFA7A446405B0BB3D0CE1744402DB29DEFA7A446405B0BB3D0CE174440A2EC2DE57CA34640B2D7BB3FDE154440A2EC2DE57CA34640
19914	Еремин	2	20	1525	40.025246000000003	40.075730999999998	45.548842999999998	45.538932000000003	0103000020E610000001000000050000006B2DCC423B0344404A6249B9FBC446406B2DCC423B034440BBD1C77C40C646408D25AC8DB1094440BBD1C77C40C646408D25AC8DB10944404A6249B9FBC446406B2DCC423B0344404A6249B9FBC44640
20294	Екатеринославский	2	20	1525	40.157890999999999	40.176639000000002	45.348612000000003	45.338273999999998	0103000020E6100000010000000500000097AAB4C535144440268BFB8F4CAB464097AAB4C535144440207F69519FAC46405D19541B9C164440207F69519FAC46405D19541B9C164440268BFB8F4CAB464097AAB4C535144440268BFB8F4CAB4640
19397	Геймановская	2	20	1525	40.183771999999998	40.220872	45.275537	45.257299000000003	0103000020E61000000100000005000000D3F544D7851744409225732CEFA04640D3F544D78517444042EBE1CB44A34640124DA088451C444042EBE1CB44A34640124DA088451C44409225732CEFA04640D3F544D7851744409225732CEFA04640
50723	Веселый	2	20	1525	40.280898000000001	40.304146000000003	45.270006000000002	45.254601999999998	0103000020E6100000010000000500000083C13577F423444083BF5FCC96A0464083C13577F4234440A5DC7D8E8FA24640C89A9141EE264440A5DC7D8E8FA24640C89A9141EE26444083BF5FCC96A0464083C13577F423444083BF5FCC96A04640
50832	Веревкин	2	20	1525	40.343311999999997	40.368473999999999	45.227465000000002	45.208691000000002	0103000020E610000001000000050000008429CAA5F12B44401AFCFD62B69A46408429CAA5F12B444009FEB7921D9D464091B6F1272A2F444009FEB7921D9D464091B6F1272A2F44401AFCFD62B69A46408429CAA5F12B44401AFCFD62B69A4640
19298	Ванновское	2	20	1525	40.212885999999997	40.241577999999997	45.331265999999999	45.316856000000001	0103000020E610000001000000050000005CE333D93F1B44404CC5C6BC8EA846405CE333D93F1B44406C239EEC66AA46406FB72407EC1E44406C239EEC66AA46406FB72407EC1E44404CC5C6BC8EA846405CE333D93F1B44404CC5C6BC8EA84640
19519	Алексее-Тенгинская	2	20	1525	40.166856000000003	40.194991999999999	45.214888999999999	45.201940999999998	0103000020E61000000100000005000000199293895B1544405B5CE333D9994640199293895B15444094A2957B819B4640A67D737FF518444094A2957B819B4640A67D737FF51844405B5CE333D9994640199293895B1544405B5CE333D9994640
50448	Алексее-Тенгинская	2	20	1525	40.166856000000003	40.194991999999999	45.214888999999999	45.201940999999998	0103000020E61000000100000005000000199293895B1544405B5CE333D9994640199293895B15444094A2957B819B4640A67D737FF518444094A2957B819B4640A67D737FF51844405B5CE333D9994640199293895B1544405B5CE333D9994640
17640	Ясени	2	20	1478	38.830953999999998	38.866149999999998	46.513157999999997	46.495635	0103000020E610000001000000050000007D3D5FB35C6A434061E0B9F7703F47407D3D5FB35C6A434023D74D29AF41474017B7D100DE6E434023D74D29AF41474017B7D100DE6E434061E0B9F7703F47407D3D5FB35C6A434061E0B9F7703F4740
16957	Староминская	2	20	1478	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
50322	Рассвет	2	20	1478	39.086182999999998	39.105181999999999	46.428331	46.413583000000003	0103000020E610000001000000050000004F3C670B088B43403E97A949F03447404F3C670B088B4340766EDA8CD33647405E10919A768D4340766EDA8CD33647405E10919A768D43403E97A949F03447404F3C670B088B43403E97A949F0344740
49448	Первомайский	2	20	1478	39.058964000000003	39.073183999999998	46.457151000000003	46.444690000000001	0103000020E6100000010000000500000018D2E1218C874340DB6D179AEB38474018D2E1218C874340B72A89EC833A4740944BE3175E894340B72A89EC833A4740944BE3175E894340DB6D179AEB38474018D2E1218C874340DB6D179AEB384740
17604	Новоясенская	2	20	1478	38.777396000000003	38.800043000000002	46.494996	46.476579999999998	0103000020E6100000010000000500000047054EB681634340BEF6CC92003D474047054EB6816343404ED367075C3F474066321CCF676643404ED367075C3F474066321CCF67664340BEF6CC92003D474047054EB681634340BEF6CC92003D4740
17895	Канеловская	2	20	1478	39.145615999999997	39.224775000000001	46.605634999999999	46.574731999999997	0103000020E610000001000000050000001DE38A8BA39243407AFB73D1904947401DE38A8BA39243400F289B72854D4740ADFA5C6DC59C43400F289B72854D4740ADFA5C6DC59C43407AFB73D1904947401DE38A8BA39243407AFB73D190494740
50297	Заря	2	20	1478	39.045202000000003	39.052971999999997	46.402323000000003	46.391801000000001	0103000020E610000001000000050000005EDBDB2DC985434022C50089263247405EDBDB2DC9854340DDB6EF517F33474046CD57C9C7864340DDB6EF517F33474046CD57C9C786434022C50089263247405EDBDB2DC985434022C5008926324740
17535	Желтые Копани	2	20	1478	38.857481	38.887027000000003	46.409680999999999	46.399931000000002	0103000020E610000001000000050000007FF8F9EFC16D43400BD462F0303347407FF8F9EFC16D43407365506D70344740A2D5C9198A7143407365506D70344740A2D5C9198A7143400BD462F0303347407FF8F9EFC16D43400BD462F030334740
17803	Восточный Сосык	2	20	1478	39.211461999999997	39.244259999999997	46.447893999999998	46.421554	0103000020E61000000100000005000000622CD32F119B4340BEBF417BF5354740622CD32F119B43408D0931975439474048DC63E9439F43408D0931975439474048DC63E9439F4340BEBF417BF5354740622CD32F119B4340BEBF417BF5354740
48880	Веселый	2	20	1478	39.188079000000002	39.200018	46.478211999999999	46.467461999999998	0103000020E610000001000000050000003E0801F912984340B60F79CBD53B47403E0801F9129843400247020D363D4740404E98309A9943400247020D363D4740404E98309A994340B60F79CBD53B47403E0801F912984340B60F79CBD53B4740
50461	пос. МТФ-2	2	20	479	37.577677999999999	38.208438999999998	45.749194000000003	45.121495000000003	0103000020E6100000010000000500000031CF4A5AF1C9424053D0ED258D8F464031CF4A5AF1C94240022EC896E5DF4640001B1021AE1A4340022EC896E5DF4640001B1021AE1A434053D0ED258D8F464031CF4A5AF1C9424053D0ED258D8F4640
50885	Черный Ерик	2	20	479	37.729483999999999	37.741109000000002	45.595447999999998	45.580758000000003	0103000020E61000000100000005000000467A51BB5FDD4240F871344756CA4640467A51BB5FDD4240FB3BDBA337CC4640B9E2E2A8DCDE4240FB3BDBA337CC4640B9E2E2A8DCDE4240F871344756CA4640467A51BB5FDD4240F871344756CA4640
5046	Черноерковская	2	20	479	37.748134	37.784596000000001	45.455680000000001	45.419795999999998	0103000020E610000001000000050000004983DBDAC2DF4240ED7E15E0BBB546404983DBDAC2DF42407CB8E4B853BA4640454948A46DE442407CB8E4B853BA4640454948A46DE44240ED7E15E0BBB546404983DBDAC2DF4240ED7E15E0BBB54640
50432	Черноерковская	2	20	479	37.748134	37.784596000000001	45.455680000000001	45.419795999999998	0103000020E610000001000000050000004983DBDAC2DF4240ED7E15E0BBB546404983DBDAC2DF42407CB8E4B853BA4640454948A46DE442407CB8E4B853BA4640454948A46DE44240ED7E15E0BBB546404983DBDAC2DF4240ED7E15E0BBB54640
5773	Целинный	2	20	479	37.948726999999998	37.969217999999998	45.565415000000002	45.551164999999997	0103000020E6100000010000000500000085EAE6E26FF9424094D920938CC6464085EAE6E26FF942407CD5CA845FC84640E658DE550FFC42407CD5CA845FC84640E658DE550FFC424094D920938CC6464085EAE6E26FF9424094D920938CC64640
50555	Ханьков	2	20	479	37.841360999999999	37.935819000000002	45.178139000000002	45.153888999999999	0103000020E610000001000000050000009F909DB7B1EB4240691B7FA2B29346409F909DB7B1EB424032923D42CD964640DBFCBFEAC8F7424032923D42CD964640DBFCBFEAC8F74240691B7FA2B29346409F909DB7B1EB4240691B7FA2B2934640
5421	Совхозный	2	20	479	38.097354000000003	38.121464000000003	45.309389000000003	45.281618999999999	0103000020E6100000010000000500000041118B18760C4340537765170CA4464041118B18760C4340FF5E0A0F9AA7464018D2E1218C0F4340FF5E0A0F9AA7464018D2E1218C0F4340537765170CA4464041118B18760C4340537765170CA44640
2858	Славянск-На-Кубани	2	20	479	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
50741	Сербин	2	20	479	38.193913000000002	38.206256000000003	45.183405999999998	45.173850999999999	0103000020E6100000010000000500000077A22424D21843403EB0E3BF4096464077A22424D2184340F1F109D979974640494DBB98661A4340F1F109D979974640494DBB98661A43403EB0E3BF4096464077A22424D21843403EB0E3BF40964640
50710	Семисводный	2	20	479	37.956498000000003	37.987668999999997	45.310231999999999	45.288766000000003	0103000020E610000001000000050000003F58C6866EFA42402F19C748F6A446403F58C6866EFA42401A16A3AEB5A74640F22213F06BFE42401A16A3AEB5A74640F22213F06BFE42402F19C748F6A446403F58C6866EFA42402F19C748F6A44640
5495	Садовый	2	20	479	38.036565000000003	38.075865999999998	45.328377000000003	45.306593999999997	0103000020E61000000100000005000000D1967329AE0443402D93E1783EA74640D1967329AE0443401AE1ED4108AA46406D7022FAB50943401AE1ED4108AA46406D7022FAB50943402D93E1783EA74640D1967329AE0443402D93E1783EA74640
5717	Рисовый	2	20	479	37.892671999999997	37.919666999999997	45.299874000000003	45.288848000000002	0103000020E6100000010000000500000007077B1343F24240ECC1A4F8F8A4464007077B1343F24240DA756F4562A64640EF1AF4A5B7F54240DA756F4562A64640EF1AF4A5B7F54240ECC1A4F8F8A4464007077B1343F24240ECC1A4F8F8A44640
50895	Прорвенский	2	20	479	37.657232999999998	37.713144	45.561836999999997	45.516188999999997	0103000020E610000001000000050000000D6D003620D4424008C72C7B12C246400D6D003620D4424064575A46EAC7464058AB764D48DB424064575A46EAC7464058AB764D48DB424008C72C7B12C246400D6D003620D4424008C72C7B12C24640
19419	Прикубанский	2	20	479	38.031516000000003	38.115248000000001	45.169625000000003	45.147951999999997	0103000020E610000001000000050000007FA65EB7080443405BB05417F09246407FA65EB708044340C1CAA145B6954640F7764B72C00E4340C1CAA145B6954640F7764B72C00E43405BB05417F09246407FA65EB7080443405BB05417F0924640
5474	Прибрежный	2	20	479	38.079127	38.101657000000003	45.308971	45.299309999999998	0103000020E61000000100000005000000849D62D5200A4340D1AE42CA4FA64640849D62D5200A4340CA349A5C8CA746406A34B918030D4340CA349A5C8CA746406A34B918030D4340D1AE42CA4FA64640849D62D5200A4340D1AE42CA4FA64640
50638	Петровская	2	20	479	37.890579000000002	38.001818	45.464941000000003	45.397644	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
50324	Петровская	2	20	479	37.890579000000002	38.001818	45.464941000000003	45.397644	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
50612	Нещадимовский	2	20	479	38.001351	38.056372000000003	45.411008000000002	45.368048999999999	0103000020E61000000100000005000000906802452C004340AA29C93A1CAF4640906802452C0043407B32FFE89BB446407F349C32370743407B32FFE89BB446407F349C3237074340AA29C93A1CAF4640906802452C004340AA29C93A1CAF4640
50864	Маевский	2	20	479	38.152124000000001	38.175272999999997	45.175490000000003	45.164006999999998	0103000020E61000000100000005000000E6779ACC7813434054A86E2EFE944640E6779ACC781343403563D17476964640976F7D586F1643403563D17476964640976F7D586F16434054A86E2EFE944640E6779ACC7813434054A86E2EFE944640
50823	Красноармейский Городок	2	20	479	38.061610000000002	38.074931999999997	45.546722000000003	45.504238999999998	0103000020E61000000100000005000000A48D23D6E2074340122F4FE78AC04640A48D23D6E20743407A008BFCFAC5464041B62C5F970943407A008BFCFAC5464041B62C5F97094340122F4FE78AC04640A48D23D6E2074340122F4FE78AC04640
50670	Коржевский	2	20	479	37.704152000000001	37.734299	45.203147000000001	45.187058999999998	0103000020E61000000100000005000000DDB419A721DA424013B69F8CF1974640DDB419A721DA4240E8A38CB8009A4640253E7782FDDD4240E8A38CB8009A4640253E7782FDDD424013B69F8CF1974640DDB419A721DA424013B69F8CF1974640
4420	Забойский	2	20	479	38.068095	38.106012999999997	45.588774999999998	45.555942999999999	0103000020E61000000100000005000000B4024356B708434056B8E52329C74640B4024356B7084340E8D9ACFA5CCB4640B5F97FD5910D4340E8D9ACFA5CCB4640B5F97FD5910D434056B8E52329C74640B4024356B708434056B8E52329C74640
50689	Деревянковка	2	20	479	38.068697	38.109031999999999	45.665815000000002	45.645730999999998	0103000020E61000000100000005000000AA2A3410CB084340B6813B50A7D24640AA2A3410CB084340D717096D39D54640D61BB5C2F40D4340D717096D39D54640D61BB5C2F40D4340B6813B50A7D24640AA2A3410CB084340B6813B50A7D24640
5817	Голубая Нива	2	20	479	37.843111999999998	37.863351000000002	45.669511999999997	45.657342999999997	0103000020E61000000100000005000000BD6E1118EBEB424094A0BFD023D44640BD6E1118EBEB4240C823B891B2D5464005FC1A4982EE4240C823B891B2D5464005FC1A4982EE424094A0BFD023D44640BD6E1118EBEB424094A0BFD023D44640
50891	Галицын	2	20	479	38.038927000000001	38.066837999999997	45.492583000000003	45.460554000000002	0103000020E6100000010000000500000038F7578FFB0443406005F86EF3BA464038F7578FFB04434065C8B1F50CBF4640A510C8258E08434065C8B1F50CBF4640A510C8258E0843406005F86EF3BA464038F7578FFB0443406005F86EF3BA4640
50789	Водный	2	20	479	38.044128000000001	38.065742	45.456749000000002	45.412824000000001	0103000020E61000000100000005000000406B7EFCA50543408080B56AD7B44640406B7EFCA505434088BD50C076BA4640A0FCDD3B6A08434088BD50C076BA4640A0FCDD3B6A0843408080B56AD7B44640406B7EFCA50543408080B56AD7B44640
50764	Верхний	2	20	479	37.718085000000002	37.757179999999998	45.497928000000002	45.456344000000001	0103000020E61000000100000005000000C45F9335EADB4240E8DCED7A69BA4640C45F9335EADB4240A0E1CD1ABCBF4640B7973446EBE04240A0E1CD1ABCBF4640B7973446EBE04240E8DCED7A69BA4640C45F9335EADB4240E8DCED7A69BA4640
50325	Беликов	2	20	479	37.950496999999999	37.996876999999998	45.508578	45.468254000000002	0103000020E610000001000000050000001AF9BCE2A9F94240501C40BFEFBB46401AF9BCE2A9F9424088BB7A1519C146403A9160AA99FF424088BB7A1519C146403A9160AA99FF4240501C40BFEFBB46401AF9BCE2A9F94240501C40BFEFBB4640
50881	Бараниковский	2	20	479	38.000785	38.049689000000001	45.379344000000003	45.325367	0103000020E61000000100000005000000E7A90EB9190043404C1938A0A5A94640E7A90EB91900434088F71C588EB0464048FC8A355C06434088F71C588EB0464048FC8A355C0643404C1938A0A5A94640E7A90EB9190043404C1938A0A5A94640
6152	Ачуево	2	20	479	37.766835999999998	37.780355999999998	45.726636999999997	45.706740000000003	0103000020E610000001000000050000009EB29AAE27E242403563D17476DA46409EB29AAE27E242402288F37002DD4640629E95B4E2E342402288F37002DD4640629E95B4E2E342403563D17476DA46409EB29AAE27E242403563D17476DA4640
4070	Анастасиевская	2	20	479	37.852096000000003	37.927337999999999	45.236896999999999	45.197889000000004	0103000020E61000000100000005000000B686527B11ED42407C9E3F6D54994640B686527B11ED4240A0C211A4529E4640452BF702B3F64240A0C211A4529E4640452BF702B3F642407C9E3F6D54994640B686527B11ED42407C9E3F6D54994640
40302	станция Северская	2	20	85	38.627656000000002	38.759456999999998	44.917762000000003	44.824038999999999	0103000020E61000000100000005000000B09124085750434074D0251C7A694640B0912408575043407BC1A73979754640F0DB10E3356143407BC1A73979754640F0DB10E33561434074D0251C7A694640B09124085750434074D0251C7A694640
50402	ст. Северская	2	20	85	38.627656000000002	38.759456999999998	44.917762000000003	44.824038999999999	0103000020E61000000100000005000000B09124085750434074D0251C7A694640B0912408575043407BC1A73979754640F0DB10E3356143407BC1A73979754640F0DB10E33561434074D0251C7A694640B09124085750434074D0251C7A694640
2709	Шабановское	2	20	85	38.797302999999999	38.823847999999998	44.573836	44.561841000000001	0103000020E61000000100000005000000580053060E664340A646E867EA474640580053060E6643403CA24275734946400070ECD9736943403CA24275734946400070ECD973694340A646E867EA474640580053060E664340A646E867EA474640
2281	Черноморский	2	20	85	38.483314999999997	38.504758000000002	44.861324000000003	44.835538999999997	0103000020E6100000010000000500000047551344DD3D43402AC423F1F26A464047551344DD3D434045A165DD3F6E46407B32FFE89B40434045A165DD3F6E46407B32FFE89B4043402AC423F1F26A464047551344DD3D43402AC423F1F26A4640
50733	Убинская	2	20	85	38.532344999999999	38.554927999999997	44.749189999999999	44.721356	0103000020E61000000100000005000000359886E123444340FE62B664555C4640359886E123444340C03E3A75E55F46403DD175E107474340C03E3A75E55F46403DD175E107474340FE62B664555C4640359886E123444340FE62B664555C4640
2730	Тхамаха	2	20	85	38.844526999999999	38.870722000000001	44.608364999999999	44.597389999999997	0103000020E6100000010000000500000064CBF275196C43408D7A8846774C464064CBF275196C4340F98381E7DE4D464030F488D1736F4340F98381E7DE4D464030F488D1736F43408D7A8846774C464064CBF275196C43408D7A8846774C4640
747	Стефановский	2	20	85	38.655926000000001	38.688049999999997	45.069270000000003	45.050550999999999	0103000020E610000001000000050000004D4C1762F5534340DAE38574788646404D4C1762F5534340064CE0D6DD884640A301BC0512584340064CE0D6DD884640A301BC0512584340DAE38574788646404D4C1762F5534340DAE3857478864640
50404	Ставропольская	2	20	85	38.817838000000002	38.837403999999999	44.728183000000001	44.704869000000002	0103000020E6100000010000000500000089B663EAAE6843406C7BBB25395A464089B663EAAE6843406840BD19355D464011C5E40D306B43406840BD19355D464011C5E40D306B43406C7BBB25395A464089B663EAAE6843406C7BBB25395A4640
50614	Смоленская	2	20	85	38.772481999999997	38.833244000000001	44.807957999999999	44.762376000000003	0103000020E61000000100000005000000D45FAFB0E0624340AEA0698995614640D45FAFB0E06243405245F12A6B6746404BCB48BDA76A43405245F12A6B6746404BCB48BDA76A4340AEA0698995614640D45FAFB0E0624340AEA0698995614640
40276	Северская	2	20	85	38.656796999999997	38.705880999999998	44.871456000000002	44.832113	0103000020E61000000100000005000000328E91EC11544340C9C9C4AD826A4640328E91EC1154434095F3C5DE8B6F464013EF004F5A5A434095F3C5DE8B6F464013EF004F5A5A4340C9C9C4AD826A4640328E91EC11544340C9C9C4AD826A4640
40283	Северская	2	20	85	38.656796999999997	38.705880999999998	44.871456000000002	44.832113	0103000020E61000000100000005000000328E91EC11544340C9C9C4AD826A4640328E91EC1154434095F3C5DE8B6F464013EF004F5A5A434095F3C5DE8B6F464013EF004F5A5A4340C9C9C4AD826A4640328E91EC11544340C9C9C4AD826A4640
50900	Свободный	2	20	85	38.710183999999998	38.723668000000004	44.830098999999997	44.818297000000001	0103000020E610000001000000050000003C122F4FE75A43401CB5C2F4BD6846403C122F4FE75A43409DB81CAF406A4640B4942C27A15C43409DB81CAF406A4640B4942C27A15C43401CB5C2F4BD6846403C122F4FE75A43401CB5C2F4BD684640
50314	Новоивановский	2	20	85	38.542478000000003	38.566426999999997	44.967455000000001	44.957371999999999	0103000020E6100000010000000500000056664AEB6F454340950D6B2A8B7A464056664AEB6F45434004ADC090D57B4640234910AE8048434004ADC090D57B4640234910AE80484340950D6B2A8B7A464056664AEB6F454340950D6B2A8B7A4640
1034	Новодмитриевская	2	20	85	38.860956999999999	38.899819000000001	44.854219000000001	44.810758999999997	0103000020E610000001000000050000009221C7D6336E434005F86EF3C66746409221C7D6336E4340984F560C576D4640E3A8DC442D734340984F560C576D4640E3A8DC442D73434005F86EF3C66746409221C7D6336E434005F86EF3C6674640
48207	Михайловское	2	20	85	38.488030999999999	38.523316999999999	45.020117999999997	44.998674999999999	0103000020E610000001000000050000009337C0CC773E4340992A1895D47F46409337C0CC773E4340CC07043A938246406D382C0DFC424340CC07043A938246406D382C0DFC424340992A1895D47F46409337C0CC773E4340992A1895D47F4640
33113	Львовское	2	20	85	38.580432000000002	38.682983	45.015281999999999	44.972504999999998	0103000020E61000000100000005000000A4C684984B4A43402619390B7B7C4640A4C684984B4A4340D61BB5C2F4814640AB5CA8FC6B574340D61BB5C2F4814640AB5CA8FC6B5743402619390B7B7C4640A4C684984B4A43402619390B7B7C4640
50641	Крепостная	2	20	85	38.662438999999999	38.698703999999999	44.720415000000003	44.700653000000003	0103000020E61000000100000005000000274C18CDCA544340126C5CFFAE594640274C18CDCA5443402046088F365C4640CDCAF6216F5943402046088F365C4640CDCAF6216F594340126C5CFFAE594640274C18CDCA544340126C5CFFAE594640
50681	Красный	2	20	85	38.561926	38.576676999999997	44.952357999999997	44.936625999999997	0103000020E61000000100000005000000D462F030ED474340A94A5B5CE3774640D462F030ED474340BF0AF0DDE67946407DAD4B8DD0494340BF0AF0DDE67946407DAD4B8DD0494340A94A5B5CE3774640D462F030ED474340A94A5B5CE3774640
50615	Коваленко	2	20	85	38.750087000000001	38.758747	44.950488999999997	44.927002999999999	0103000020E61000000100000005000000CF13CFD9026043409E25C808A8764640CF13CFD902604340971AA19FA97946401478279F1E614340971AA19FA97946401478279F1E6143409E25C808A8764640CF13CFD9026043409E25C808A8764640
50609	Карский	2	20	85	38.501533000000002	38.519300999999999	44.840632999999997	44.813329000000003	0103000020E61000000100000005000000B16EBC3B32404340B7F1272A1B684640B16EBC3B324043401C78B5DC996B4640DAE38574784243401C78B5DC996B4640DAE3857478424340B7F1272A1B684640B16EBC3B32404340B7F1272A1B684640
50287	Калужская	2	20	85	38.954230000000003	38.997402999999998	44.779505999999998	44.744945999999999	0103000020E61000000100000005000000596E6935247A43409CA4F9635A5F4640596E6935247A4340948444DAC663464055F7C8E6AA7F4340948444DAC663464055F7C8E6AA7F43409CA4F9635A5F4640596E6935247A43409CA4F9635A5F4640
102	Ильский	2	20	85	38.538184000000001	38.598075000000001	44.868127999999999	44.815471000000002	0103000020E61000000100000005000000809D9B36E344434010EB8D5A61684640809D9B36E3444340F65E7CD11E6F464011C7BAB88D4C4340F65E7CD11E6F464011C7BAB88D4C434010EB8D5A61684640809D9B36E344434010EB8D5A61684640
50736	Дербентская	2	20	85	38.487051999999998	38.513660000000002	44.777030000000003	44.755386999999999	0103000020E61000000100000005000000C7B94DB8573E43406A696E85B0604640C7B94DB8573E4340650113B875634640B6A1629CBF414340650113B875634640B6A1629CBF4143406A696E85B0604640C7B94DB8573E43406A696E85B0604640
50682	Григорьевская	2	20	85	38.829560999999998	38.853546000000001	44.779927999999998	44.761397000000002	0103000020E61000000100000005000000BE840A0E2F6A4340E222F77475614640BE840A0E2F6A43400A9E42AED4634640D9D0CDFE406D43400A9E42AED4634640D9D0CDFE406D4340E222F77475614640BE840A0E2F6A4340E222F77475614640
46541	Веселый	2	20	85	38.490025000000003	38.496887999999998	44.874037000000001	44.869118	0103000020E61000000100000005000000789CA223B93E4340B62E35423F6F4640789CA223B93E43403A3FC571E06F46402EE3A6069A3F43403A3FC571E06F46402EE3A6069A3F4340B62E35423F6F4640789CA223B93E4340B62E35423F6F4640
31543	Афипский	2	20	85	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
50873	Ананьевский	2	20	85	38.539935999999997	38.561118	45.015824000000002	45.006852000000002	0103000020E610000001000000050000006EF7729F1C454340C3F4BD86E08046406EF7729F1C454340F73E5585068246403599F1B6D2474340F73E5585068246403599F1B6D2474340C3F4BD86E08046406EF7729F1C454340C3F4BD86E0804640
50840	Азовская	2	20	85	38.589548999999998	38.648910000000001	44.805571999999998	44.777203	0103000020E61000000100000005000000DB317557764B434032AD4D637B634640DB317557764B43406249B9FB1C67464010069E7B0F5343406249B9FB1C67464010069E7B0F53434032AD4D637B634640DB317557764B434032AD4D637B634640
30914	им. Тамаровского	2	20	1082	38.395325	38.409787999999999	46.069600999999999	46.061183999999997	0103000020E61000000100000005000000462575029A324340EC8497E0D4074740462575029A3243406B6281AFE80847408925E5EE733443406B6281AFE80847408925E5EE73344340EC8497E0D4074740462575029A324340EC8497E0D4074740
31371	Степная	2	20	1082	38.41966	38.460757999999998	45.767423000000001	45.742842000000003	0103000020E610000001000000050000003DB83B6BB7354340310C587215DF46403DB83B6BB73543405F99B7EA3AE2464068AF3E1EFA3A43405F99B7EA3AE2464068AF3E1EFA3A4340310C587215DF46403DB83B6BB7354340310C587215DF4640
50692	Свободный	2	20	1082	38.353651999999997	38.379190999999999	45.951011000000001	45.93394	0103000020E610000001000000050000001E15FF77442D43408F368E588BF746401E15FF77442D434071917BBABAF9464001F8A7548930434071917BBABAF9464001F8A754893043408F368E588BF746401E15FF77442D43408F368E588BF74640
50494	Садки	2	20	1082	38.099339000000001	38.112400000000001	45.953297999999997	45.933275000000002	0103000020E61000000100000005000000D21BEE23B70C43405396218E75F74640D21BEE23B70C4340CDAB3AAB05FA464003098A1F630E4340CDAB3AAB05FA464003098A1F630E43405396218E75F74640D21BEE23B70C43405396218E75F74640
9539	Приморско-Ахтарск	2	20	1082	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
32571	Пригородное	2	20	1082	38.611072999999998	38.617766000000003	45.767347999999998	45.763035000000002	0103000020E61000000100000005000000FB3BDBA3374E4340085A8121ABE14640FB3BDBA3374E43405453927538E24640564ACFF4124F43405453927538E24640564ACFF4124F4340085A8121ABE14640FB3BDBA3374E4340085A8121ABE14640
31222	Приазовская	2	20	1082	38.596943000000003	38.624575	45.854297000000003	45.837063999999998	0103000020E61000000100000005000000BF49D3A0684C43405854C4E924EB4640BF49D3A0684C43401409A69A59ED46401973D712F24F43401409A69A59ED46401973D712F24F43405854C4E924EB4640BF49D3A0684C43405854C4E924EB4640
50310	Ольгинская	2	20	1082	38.529048000000003	38.577575000000003	45.957946999999997	45.929326000000003	0103000020E61000000100000005000000D20149D8B743434048A98427F4F64640D20149D8B74343409126DE019EFA46405DFE43FAED4943409126DE019EFA46405DFE43FAED49434048A98427F4F64640D20149D8B743434048A98427F4F64640
31196	Октябрьский	2	20	1082	38.468834000000001	38.487402000000003	45.960960999999998	45.953048000000003	0103000020E610000001000000050000005EA0A4C0023C434055C2137AFDF946405EA0A4C0023C4340A0DD21C500FB4640A4005130633E4340A0DD21C500FB4640A4005130633E434055C2137AFDF946405EA0A4C0023C434055C2137AFDF94640
30607	Огородный	2	20	1082	38.173287999999999	38.181804	45.953687000000002	45.946894	0103000020E6100000010000000500000006651A4D2E164340AA6395D233F9464006651A4D2E16434068CF656A12FA464018247D5A4517434068CF656A12FA464018247D5A45174340AA6395D233F9464006651A4D2E164340AA6395D233F94640
47345	Новонекрасовский	2	20	1082	38.264215999999998	38.276415	45.878884999999997	45.868085999999998	0103000020E610000001000000050000003B8A73D4D1214340C70E2A711DEF46403B8A73D4D1214340F4F8BD4D7FF04640DA8F149161234340F4F8BD4D7FF04640DA8F149161234340C70E2A711DEF46403B8A73D4D1214340C70E2A711DEF4640
50739	Нов. Лиманокирпили	2	20	1082	38.342359999999999	38.353983999999997	45.837226999999999	45.825986	0103000020E61000000100000005000000B2BAD573D22B4340187AC4E8B9E94640B2BAD573D22B4340022A1C412AEB464054A703594F2D4340022A1C412AEB464054A703594F2D4340187AC4E8B9E94640B2BAD573D22B4340187AC4E8B9E94640
50363	Морозовский	2	20	1082	38.225884999999998	38.239637999999999	46.149037999999997	46.140228	0103000020E6100000010000000500000017D4B7CCE91C4340E3FDB8FDF211474017D4B7CCE91C43403DEE5BAD131347407E703E75AC1E43403DEE5BAD131347407E703E75AC1E4340E3FDB8FDF211474017D4B7CCE91C4340E3FDB8FDF2114740
31480	Максима Горького	2	20	1082	38.555458000000002	38.566561999999998	45.788373	45.777310999999997	0103000020E610000001000000050000009A266C3F1947434018E945ED7EE346409A266C3F1947434053060E68E9E446400394861A8548434053060E68E9E446400394861A8548434018E945ED7EE346409A266C3F1947434018E945ED7EE34640
9689	Курчанский	2	20	1082	38.349780000000003	38.377853000000002	45.982145000000003	45.958523999999997	0103000020E61000000100000005000000BF654E97C52C43402E3718EAB0FA4640BF654E97C52C4340087767EDB6FD464006D9B27C5D304340087767EDB6FD464006D9B27C5D3043402E3718EAB0FA4640BF654E97C52C43402E3718EAB0FA4640
47288	Возрождение	2	20	1082	38.682211000000002	38.703384	45.969467999999999	45.958637000000003	0103000020E6100000010000000500000059FCA6B05257434027DE019EB4FA464059FCA6B0525743405F42058717FC4640CC43A67C085A43405F42058717FC4640CC43A67C085A434027DE019EB4FA464059FCA6B05257434027DE019EB4FA4640
30780	Бриньковская	2	20	1082	38.548793000000003	38.608305999999999	46.046661	46.018988	0103000020E610000001000000050000000AA359D93E4643401B82E3326E0247400AA359D93E464340D47FD6FCF8054740F4FA93F8DC4D4340D47FD6FCF8054740F4FA93F8DC4D43401B82E3326E0247400AA359D93E4643401B82E3326E024740
47209	Бородинская	2	20	1082	38.243447000000003	38.266866	46.110320999999999	46.095218000000003	0103000020E6100000010000000500000098A77345291F4340CAFE791A300C474098A77345291F4340F0879FFF1E0E4740093543AA28224340F0879FFF1E0E4740093543AA28224340CAFE791A300C474098A77345291F4340CAFE791A300C4740
30632	Ахтарский	2	20	1082	38.336494000000002	38.359355999999998	46.014225000000003	46.000309999999999	0103000020E610000001000000050000006EA6423C122B43404EEE77280A0047406EA6423C122B43408FE4F21FD201474089CF9D60FF2D43408FE4F21FD201474089CF9D60FF2D43404EEE77280A0047406EA6423C122B43404EEE77280A004740
9614	Аджановка	2	20	1082	38.290393000000002	38.307532000000002	45.973990999999998	45.963379000000003	0103000020E6100000010000000500000061FE0A992B2543409C53C90050FB464061FE0A992B25434096CCB1BCABFC46409B3C65355D27434096CCB1BCABFC46409B3C65355D2743409C53C90050FB464061FE0A992B2543409C53C90050FB4640
9528	Упорный	2	20	1079	39.956398999999998	40.011960000000002	46.147415000000002	46.137155999999997	0103000020E61000000100000005000000AB764D486BFA43409F39EB538E114740AB764D486BFA43404DF8A57EDE1247401A6EC0E7870144404DF8A57EDE1247401A6EC0E7870144409F39EB538E114740AB764D486BFA43409F39EB538E114740
29696	Старолеушковская	2	20	1079	39.734110999999999	39.789006999999998	46.012397	45.965308999999998	0103000020E6100000010000000500000022516859F7DD434069C4CC3E8FFB464022516859F7DD4340C5C892399601474054A86E2EFEE44340C5C892399601474054A86E2EFEE4434069C4CC3E8FFB464022516859F7DD434069C4CC3E8FFB4640
32677	Сред. Челбас	2	20	1079	39.516646999999999	39.569108	45.966191999999999	45.934742	0103000020E61000000100000005000000CB49287D21C243404C1938A0A5F74640CB49287D21C2434013D4F02DACFB46402CF2EB87D8C8434013D4F02DACFB46402CF2EB87D8C843404C1938A0A5F74640CB49287D21C243404C1938A0A5F74640
50762	Пушкина	2	20	1079	39.816262000000002	39.835979999999999	46.052253	46.045723000000002	0103000020E61000000100000005000000D97BF1457BE8434067D65240DA054740D97BF1457BE84340170FEF39B0064740170E846401EB4340170FEF39B0064740170E846401EB434067D65240DA054740D97BF1457BE8434067D65240DA054740
47698	Первомайский	2	20	1079	39.849975999999998	39.928559999999997	46.016109	45.996372000000001	0103000020E6100000010000000500000044317903CCEC43403753211E89FF464044317903CCEC4340EC1516DC0F024740D72FD80DDBF64340EC1516DC0F024740D72FD80DDBF643403753211E89FF464044317903CCEC43403753211E89FF4640
46255	Павловская	2	20	1079	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
50434	Павловская	2	20	1079	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
28339	Новый Урал	2	20	1079	39.620887000000003	39.647711000000001	46.068688000000002	46.056331	0103000020E610000001000000050000007BC1A73979CF43402060ADDA350747407BC1A73979CF434057D0B4C4CA0847403621AD31E8D2434057D0B4C4CA0847403621AD31E8D243402060ADDA350747407BC1A73979CF43402060ADDA35074740
50637	Новый	2	20	1079	39.913873000000002	39.942726999999998	46.125070999999998	46.094929999999998	0103000020E6100000010000000500000045D95BCAF9F4434063B48EAA260C474045D95BCAF9F44340C95697530210474031074147ABF84340C95697530210474031074147ABF8434063B48EAA260C474045D95BCAF9F4434063B48EAA260C4740
28223	Новопластуновская	2	20	1079	39.594476999999998	39.619773000000002	46.071702000000002	46.051890999999998	0103000020E61000000100000005000000B29C84D217CC434076FA415DA4064740B29C84D217CC43406687F8872D094740CFF8BEB854CF43406687F8872D094740CFF8BEB854CF434076FA415DA4064740B29C84D217CC434076FA415DA4064740
28433	Новопетровская	2	20	1079	39.920853000000001	39.957504	46.222000999999999	46.203772999999998	0103000020E6100000010000000500000035B6D782DEF543406667D13B151A474035B6D782DEF54340F3565D876A1C474004E5B67D8FFA4340F3565D876A1C474004E5B67D8FFA43406667D13B151A474035B6D782DEF543406667D13B151A4740
28034	Новолеушковская	2	20	1079	39.943643000000002	40.017395	46.018380999999998	45.980542	0103000020E61000000100000005000000B70C384BC9F843405E2D776682FD4640B70C384BC9F8434013EF004F5A024740950ED6FF3902444013EF004F5A024740950ED6FF390244405E2D776682FD4640B70C384BC9F843405E2D776682FD4640
28392	Незамаевская	2	20	1079	40.238532999999997	40.320199000000002	46.183635000000002	46.142426	0103000020E610000001000000050000002502D53F881E4440D00CE2033B1247402502D53F881E444053B3075A81174740209BE447FC28444053B3075A81174740209BE447FC284440D00CE2033B1247402502D53F881E4440D00CE2033B124740
46773	Набережный	2	20	1079	39.648905999999997	39.659379999999999	46.035007	46.031621999999999	0103000020E61000000100000005000000CE16105A0FD34340C4EA8F300C044740CE16105A0FD34340C710001C7B04474078D1579066D44340C710001C7B04474078D1579066D44340C4EA8F300C044740CE16105A0FD34340C4EA8F300C044740
46127	Междуреченский	2	20	1079	39.594630000000002	39.693049000000002	46.111058	46.086785999999996	0103000020E61000000100000005000000399CF9D51CCC434015E0BBCD1B0B4740399CF9D51CCC4340C6FA0626370E474044C362D4B5D84340C6FA0626370E474044C362D4B5D8434015E0BBCD1B0B4740399CF9D51CCC434015E0BBCD1B0B4740
29439	Ленинодар	2	20	1079	39.542312000000003	39.600926999999999	45.983559999999997	45.978281000000003	0103000020E610000001000000050000003B1DC87A6AC543402BA6D24F38FD46403B1DC87A6AC54340AED3484BE5FD464046240A2DEBCC4340AED3484BE5FD464046240A2DEBCC43402BA6D24F38FD46403B1DC87A6AC543402BA6D24F38FD4640
29262	Краснопартизанское	2	20	1079	39.763612000000002	39.790157000000001	46.079659999999997	46.069913	0103000020E61000000100000005000000A56ABB09BEE143405A48C0E8F2084740A56ABB09BEE143405166834C320A47404DDA54DD23E543405166834C320A47404DDA54DD23E543405A48C0E8F2084740A56ABB09BEE143405A48C0E8F2084740
45921	Веселая	2	20	1079	40.071572000000003	40.121644000000003	46.180047000000002	46.157117	0103000020E6100000010000000500000098A7734529094440A452EC681C14474098A7734529094440185FB4C70B17474098E0D407920F4440185FB4C70B17474098E0D407920F4440A452EC681C14474098A7734529094440A452EC681C144740
29548	Бейсужек	2	20	1079	39.520896	39.549030999999999	45.899925000000003	45.886156999999997	0103000020E61000000100000005000000014F5AB8ACC243408C0FB3976DF14640014F5AB8ACC2434029ED0DBE30F34640BEBED6A546C6434029ED0DBE30F34640BEBED6A546C643408C0FB3976DF14640014F5AB8ACC243408C0FB3976DF14640
28306	Бальчанский	2	20	1079	39.529879000000001	39.550567000000001	46.093949000000002	46.087049	0103000020E6100000010000000500000029EB3713D3C343402313F06B240B474029EB3713D3C34340F73E5585060C4740E0A0BDFA78C64340F73E5585060C4740E0A0BDFA78C643402313F06B240B474029EB3713D3C343402313F06B240B4740
50450	Атаманская	2	20	1079	39.611105000000002	39.683391999999998	46.187640999999999	46.163178000000002	0103000020E6100000010000000500000007B64AB038CE43409EB64604E314474007B64AB038CE4340C231CB9E041847408C2C996379D74340C231CB9E041847408C2C996379D743409EB64604E314474007B64AB038CE43409EB64604E3144740
50648	Чайкин	2	20	1027	41.579349000000001	41.604151999999999	44.518050000000002	44.498257000000002	0103000020E6100000010000000500000033FCA71B28CA44406500A8E2C63F464033FCA71B28CA4440AED85F764F42464010E84CDA54CD4440AED85F764F42464010E84CDA54CD44406500A8E2C63F464033FCA71B28CA44406500A8E2C63F4640
50890	Хорин	2	20	1027	41.281171999999998	41.304546000000002	44.505218999999997	44.477460000000001	0103000020E610000001000000050000008446B071FDA34440F792C6681D3D46408446B071FDA34440AE282504AB4046405610035DFBA64440AE282504AB4046405610035DFBA64440F792C6681D3D46408446B071FDA34440F792C6681D3D4640
50649	Хлопонин	2	20	1027	41.575665999999998	41.586382999999998	44.297221999999998	44.285175000000002	0103000020E61000000100000005000000A6B5696CAFC944408351499D80244640A6B5696CAFC944406BD3D85E0B26464016F71F990ECB44406BD3D85E0B26464016F71F990ECB44408351499D80244640A6B5696CAFC944408351499D80244640
9998	Урупский	2	20	1027	41.564014999999998	41.583418999999999	44.458019999999998	44.448754999999998	0103000020E610000001000000050000000ABABDA431C844404F75C8CD703946400ABABDA431C84440FB743C66A03A4640B96E4A79ADCA4440FB743C66A03A4640B96E4A79ADCA44404F75C8CD703946400ABABDA431C844404F75C8CD70394640
50333	Удобная	2	20	1027	41.528647999999997	41.591673999999998	44.252119999999998	44.17539	0103000020E61000000100000005000000438CD7BCAAC34440D105F52D73164640438CD7BCAAC344407155D977452046405EF23FF9BBCB44407155D977452046405EF23FF9BBCB4440D105F52D73164640438CD7BCAAC34440D105F52D73164640
50563	Удобная	2	20	1027	41.528647999999997	41.591673999999998	44.252119999999998	44.17539	0103000020E61000000100000005000000438CD7BCAAC34440D105F52D73164640438CD7BCAAC344407155D977452046405EF23FF9BBCB44407155D977452046405EF23FF9BBCB4440D105F52D73164640438CD7BCAAC34440D105F52D73164640
26055	Спокойная Синюха	2	20	1027	41.229410999999999	41.266762999999997	44.412374	44.356844000000002	0103000020E61000000100000005000000DC2BF3565D9D44400DE36E10AD2D4640DC2BF3565D9D444040DCD5ABC834464034643C4A25A2444040DCD5ABC834464034643C4A25A244400DE36E10AD2D4640DC2BF3565D9D44400DE36E10AD2D4640
50643	Спокойная	2	20	1027	41.343460999999998	41.436166999999998	44.284064999999998	44.231105999999997	0103000020E61000000100000005000000C939B187F6AB444066F4A3E1941D4640C939B187F6AB44401878EE3D5C244640164CFC51D4B744401878EE3D5C244640164CFC51D4B7444066F4A3E1941D4640C939B187F6AB444066F4A3E1941D4640
50630	Солдатская Балка	2	20	1027	41.266950999999999	41.299999999999997	44.366213999999999	44.340187	0103000020E6100000010000000500000037514B732BA244401EC3633F8B2B464037514B732BA244402EABB019E02E46406666666666A644402EABB019E02E46406666666666A644401EC3633F8B2B464037514B732BA244401EC3633F8B2B4640
46866	Светлый	2	20	1027	41.520339	41.536059999999999	44.477164999999999	44.468860999999997	0103000020E61000000100000005000000ABEAE5779AC2444057AF22A3033C4640ABEAE5779AC24440DEE522BE133D4640CD58349D9DC44440DEE522BE133D4640CD58349D9DC4444057AF22A3033C4640ABEAE5779AC2444057AF22A3033C4640
26239	Рудь	2	20	1027	41.200493999999999	41.238232000000004	44.474649999999997	44.442886000000001	0103000020E61000000100000005000000A98592C9A99944409AED0A7DB0384640A98592C9A9994440F085C954C13C46402B6EDC627E9E4440F085C954C13C46402B6EDC627E9E44409AED0A7DB0384640A98592C9A99944409AED0A7DB0384640
50700	Романчуков	2	20	1027	41.534666999999999	41.557098000000003	44.223336000000003	44.214511000000002	0103000020E610000001000000050000000EA0DFF76FC44440EED0B018751B46400EA0DFF76FC444407E022846961C46406155BDFC4EC744407E022846961C46406155BDFC4EC74440EED0B018751B46400EA0DFF76FC44440EED0B018751B4640
9857	Попутная	2	20	1027	41.377524999999999	41.463233000000002	44.541317999999997	44.489075	0103000020E6100000010000000500000011363CBD52B04440462575029A3E464011363CBD52B04440395E81E849454640C8B60C384BBB4440395E81E849454640C8B60C384BBB4440462575029A3E464011363CBD52B04440462575029A3E4640
9832	Подгорная Синюха	2	20	1027	41.196154999999997	41.227946000000003	44.398457000000001	44.353608000000001	0103000020E6100000010000000500000033F9669B1B9944404FCDE506432D464033F9669B1B9944405FEE93A30033464084A0A3552D9D44405FEE93A30033464084A0A3552D9D44404FCDE506432D464033F9669B1B9944404FCDE506432D4640
50596	Подгорная	2	20	1027	41.249623	41.320419000000001	44.235221000000003	44.193140999999997	0103000020E610000001000000050000002AAA7EA5F39F4440244223D8B81846402AAA7EA5F39F44408D2AC3B81B1E46402E02637D03A944408D2AC3B81B1E46402E02637D03A94440244223D8B81846402AAA7EA5F39F4440244223D8B8184640
8939	Пискуновское	2	20	1027	41.505085999999999	41.535888999999997	44.574716000000002	44.565251000000004	0103000020E610000001000000050000006FD575A8A6C0444002840F255A4846406FD575A8A6C04440753E3C4B90494640A0A4C00298C44440753E3C4B90494640A0A4C00298C4444002840F255A4846406FD575A8A6C0444002840F255A484640
50281	Петровское	2	20	1027	41.643371999999999	41.688279000000001	44.483691999999998	44.469819000000001	0103000020E61000000100000005000000C09481035AD244400C056C07233C4640C09481035AD244401DAB949EE93D464005C3B98619D844401DAB949EE93D464005C3B98619D844400C056C07233C4640C09481035AD244400C056C07233C4640
50654	Отрадо-Тенгинский	2	20	1027	41.435817	41.472817999999997	44.308576000000002	44.287000999999997	0103000020E610000001000000050000003A05F9D9C8B74440AB75E272BC2446403A05F9D9C8B744404E2A1A6B7F274640E57ADB4C85BC44404E2A1A6B7F274640E57ADB4C85BC4440AB75E272BC2446403A05F9D9C8B74440AB75E272BC244640
50577	Отрадо-Солдатский	2	20	1027	41.301096000000001	41.361013999999997	44.392325999999997	44.363598000000003	0103000020E610000001000000050000006C7A50508AA644400D7217618A2E46406C7A50508AA644406CAF05BD37324640F6B2EDB435AE44406CAF05BD37324640F6B2EDB435AE44400D7217618A2E46406C7A50508AA644400D7217618A2E4640
50345	Отрадная	2	20	1027	41.484226999999997	41.543101999999998	44.438284000000003	44.353955999999997	0103000020E610000001000000050000008B6B7C26FBBD44408A1C226E4E2D46408B6B7C26FBBD4440172EABB0193846403332C85D84C54440172EABB0193846403332C85D84C544408A1C226E4E2D46408B6B7C26FBBD44408A1C226E4E2D4640
50599	Надежная	2	20	1027	41.357132999999997	41.470041999999999	44.228568000000003	44.174227000000002	0103000020E6100000010000000500000043A9BD88B6AD4440448A01124D16464043A9BD88B6AD4440C1745AB7411D46408BDF14562ABC4440C1745AB7411D46408BDF14562ABC4440448A01124D16464043A9BD88B6AD4440448A01124D164640
49443	Маяк	2	20	1027	41.309361000000003	41.333309999999997	44.326549999999997	44.310214000000002	0103000020E6100000010000000500000035D4282499A744407461A417B527464035D4282499A744402041F163CC29464002B7EEE6A9AA44402041F163CC29464002B7EEE6A9AA44407461A417B527464035D4282499A744407461A417B5274640
10080	Малотенгинская	2	20	1027	41.495652999999997	41.558022999999999	44.297821999999996	44.262740000000001	0103000020E610000001000000050000000795B88E71BF4440EFACDD76A12146400795B88E71BF4440C00303081F26464039B5334C6DC74440C00303081F26464039B5334C6DC74440EFACDD76A12146400795B88E71BF4440EFACDD76A1214640
47670	Ильич	2	20	1027	41.354931999999998	41.377066999999997	44.091354000000003	44.062911999999997	0103000020E61000000100000005000000E5266A696EAD444052431B800D084640E5266A696EAD4440ED2DE57CB10B46404EB340BB43B04440ED2DE57CB10B46404EB340BB43B0444052431B800D084640E5266A696EAD444052431B800D084640
49576	Изобильное	2	20	1027	41.207751999999999	41.226590000000002	44.510156000000002	44.474798	0103000020E61000000100000005000000DCD6169E979A4440651A4D2EC63C4640DCD6169E979A4440D9EDB3CA4C414640E2CCAFE6009D4440D9EDB3CA4C414640E2CCAFE6009D4440651A4D2EC63C4640DCD6169E979A4440651A4D2EC63C4640
50541	Зеленчук Мостовой	2	20	1027	41.714751999999997	41.736114000000001	44.272165000000001	44.238979	0103000020E61000000100000005000000136058FE7CDB444024B726DD961E4640136058FE7CDB4440D40E7F4DD62246405A10CAFB38DE4440D40E7F4DD62246405A10CAFB38DE444024B726DD961E4640136058FE7CDB444024B726DD961E4640
26410	Гусаровское	2	20	1027	41.379069999999999	41.432592	44.618085999999998	44.572687000000002	0103000020E610000001000000050000008672A25D85B0444014ECBFCE4D4946408672A25D85B04440C70E2A711D4F46407041B62C5FB74440C70E2A711D4F46407041B62C5FB7444014ECBFCE4D4946408672A25D85B0444014ECBFCE4D494640
32572	Благодарное	2	20	1027	41.526716999999998	41.565748999999997	44.510779999999997	44.481955999999997	0103000020E61000000100000005000000A59F70766BC34440340EF5BBB03D4640A59F70766BC34440B6B9313D61414640525F96766AC84440B6B9313D61414640525F96766AC84440340EF5BBB03D4640A59F70766BC34440340EF5BBB03D4640
27719	Бесстрашная	2	20	1027	41.123023000000003	41.166339999999998	44.269002	44.234884999999998	0103000020E61000000100000005000000F2D3B837BF8F444015A930B6101E4640F2D3B837BF8F4440804754A86E22464021020EA14A954440804754A86E22464021020EA14A95444015A930B6101E4640F2D3B837BF8F444015A930B6101E4640
50618	Хлебороб	2	20	1132	40.615591999999999	40.642901000000002	46.051071	46.043501999999997	0103000020E61000000100000005000000F1D6F9B7CB4E4440C1A7397991054740F1D6F9B7CB4E44401363997E8906474069C878944A5244401363997E8906474069C878944A524440C1A7397991054740F1D6F9B7CB4E4440C1A7397991054740
46117	Степной	2	20	1132	40.782336999999998	40.791967	45.823957999999998	45.817149000000001	0103000020E61000000100000005000000B2B96A9E23644440C47AA35698E84640B2B96A9E2364444087A3AB7477E946407041B62C5F65444087A3AB7477E946407041B62C5F654440C47AA35698E84640B2B96A9E23644440C47AA35698E84640
13978	Северный	2	20	1132	40.566077	40.577359999999999	46.028399	46.021903999999999	0103000020E6100000010000000500000047020D367548444067D311C0CD02474047020D36754844409B1E1494A20347406002B7EEE64944409B1E1494A20347406002B7EEE649444067D311C0CD02474047020D367548444067D311C0CD024740
50812	Плоская	2	20	1132	40.597365000000003	40.648936999999997	46.231409999999997	46.217979999999997	0103000020E610000001000000050000003563D174764C44404E97C5C4E61B47403563D174764C4440D2FBC6D79E1D474009151C5E10534440D2FBC6D79E1D474009151C5E105344404E97C5C4E61B47403563D174764C44404E97C5C4E61B4740
14264	Новопокровский	2	20	1132	40.763446000000002	40.777540000000002	45.844723999999999	45.831544000000001	0103000020E610000001000000050000008A213999B8614440AF97A60870EA46408A213999B8614440BA1281EA1FEC46407AAA436E86634440BA1281EA1FEC46407AAA436E86634440AF97A60870EA46408A213999B8614440AF97A60870EA4640
20617	Новопокровская	2	20	1132	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
10454	Новоивановская	2	20	1132	40.467207999999999	40.510317999999998	46.182187999999996	46.165388	0103000020E61000000100000005000000FC36C478CD3B44404F93196F2B154740FC36C478CD3B4440A0DCB6EF51174740B247A81952414440A0DCB6EF51174740B247A819524144404F93196F2B154740FC36C478CD3B44404F93196F2B154740
14085	Незамаевский	2	20	1132	40.372686999999999	40.389494999999997	46.127769000000001	46.114238	0103000020E610000001000000050000007A522635B42F4440F0FACC599F0E47407A522635B42F4440A8380EBC5A1047404E7ADFF8DA314440A8380EBC5A1047404E7ADFF8DA314440F0FACC599F0E47407A522635B42F4440F0FACC599F0E4740
49072	Мирный	2	20	1132	40.740735999999998	40.753582000000002	45.820748000000002	45.817318999999998	0103000020E61000000100000005000000247CEF6FD05E444020B3B3E89DE84640247CEF6FD05E4440F3203D450EE94640596DFE5F75604440F3203D450EE94640596DFE5F7560444020B3B3E89DE84640247CEF6FD05E444020B3B3E89DE84640
10927	Малокубанский	2	20	1132	40.559806000000002	40.577368999999997	45.991444000000001	45.982809000000003	0103000020E61000000100000005000000630D17B9A7474440749B70AFCCFD4640630D17B9A747444060E811A3E7FE4640B35C363AE749444060E811A3E7FE4640B35C363AE7494440749B70AFCCFD4640630D17B9A7474440749B70AFCCFD4640
10914	Кубанский	2	20	1132	40.558611999999997	40.590107000000003	45.939073	45.919446000000001	0103000020E610000001000000050000009A9317998047444011381268B0F546409A931799804744403FC7478B33F8464002124DA0884B44403FC7478B33F8464002124DA0884B444011381268B0F546409A9317998047444011381268B0F54640
10994	Калниболотская	2	20	1132	40.412474000000003	40.463282	46.018568000000002	45.991518999999997	0103000020E61000000100000005000000A439B2F2CB3444406A2E3718EAFE4640A439B2F2CB3444404660AC6F60024740A96917D34C3B44404660AC6F60024740A96917D34C3B44406A2E3718EAFE4640A439B2F2CB3444406A2E3718EAFE4640
50619	Ильинская	2	20	1132	40.683414999999997	40.762484000000001	45.749521000000001	45.703366000000003	0103000020E61000000100000005000000444C89247A574440268FA7E507DA4640444C89247A5744402655DB4DF0DF464094DC6113996144402655DB4DF0DF464094DC611399614440268FA7E507DA4640444C89247A574440268FA7E507DA4640
10607	Животновод	2	20	1132	40.690466000000001	40.700842000000002	45.817847	45.812883999999997	0103000020E61000000100000005000000FE7F9C306158444088B839950CE84640FE7F9C3061584440DC10E335AFE84640E5D4CE30B5594440DC10E335AFE84640E5D4CE30B559444088B839950CE84640FE7F9C306158444088B839950CE84640
14166	Горькая Балка	2	20	1132	40.667470000000002	40.71199	46.109065000000001	46.067780999999997	0103000020E61000000100000005000000D3872EA86F55444024253D0CAD084740D3872EA86F554440B21188D7F50D47401E8A027D225B4440B21188D7F50D47401E8A027D225B444024253D0CAD084740D3872EA86F55444024253D0CAD084740
11044	Балка Грузская	2	20	1132	40.265490999999997	40.285308000000001	45.987122999999997	45.977516999999999	0103000020E61000000100000005000000F030ED9BFB2144405B24ED461FFD4640F030ED9BFB2144409010E50B5AFE4640C2A4F8F8842444409010E50B5AFE4640C2A4F8F8842444405B24ED461FFD4640F030ED9BFB2144405B24ED461FFD4640
50879	Южный	2	20	937	41.147035000000002	41.161794	44.677334000000002	44.671115999999998	0103000020E61000000100000005000000062FFA0AD292444042E90B21E7554640062FFA0AD2924440043C69E1B2564640325871AAB5944440043C69E1B2564640325871AAB594444042E90B21E7554640062FFA0AD292444042E90B21E7554640
50756	Энгельса	2	20	937	40.844051	40.853797999999998	45.129266000000001	45.122182000000002	0103000020E61000000100000005000000FB93F8DC096C44407714E7A8A38F4640FB93F8DC096C44400C3ECDC98B904640F2B1BB40496D44400C3ECDC98B904640F2B1BB40496D44407714E7A8A38F4640FB93F8DC096C44407714E7A8A38F4640
50655	Фортштадт	2	20	937	41.134656	41.145876000000001	45.035553	45.028292	0103000020E61000000100000005000000E71A66683C914440855E7F129F834640E71A66683C91444029232E008D844640BAA29410AC92444029232E008D844640BAA29410AC924440855E7F129F834640E71A66683C914440855E7F129F834640
50845	Федоровский	2	20	937	40.947519	40.961362000000001	45.102691999999998	45.093606999999999	0103000020E6100000010000000500000058AB764D487944409DD66D50FB8B464058AB764D48794440C9C7EE02258D4640FFCEF6E80D7B4440C9C7EE02258D4640FFCEF6E80D7B44409DD66D50FB8B464058AB764D487944409DD66D50FB8B4640
50435	Степной	2	20	937	41.214418000000002	41.224469999999997	45.161275000000003	45.151220000000002	0103000020E610000001000000050000003DD68C0C729B444025404D2D5B9346403DD68C0C729B4440CA54C1A8A49446407077D66EBB9C4440CA54C1A8A49446407077D66EBB9C444025404D2D5B9346403DD68C0C729B444025404D2D5B934640
50695	Стебницкий	2	20	937	41.135573000000001	41.152515000000001	44.910760000000003	44.888661999999997	0103000020E610000001000000050000003D9CC0745A914440569929ADBF7146403D9CC0745A914440A3409FC89374464021938C9C85934440A3409FC89374464021938C9C85934440569929ADBF7146403D9CC0745A914440569929ADBF714640
50593	Советская	2	20	937	41.142445000000002	41.216330999999997	44.814621000000002	44.737827000000003	0103000020E61000000100000005000000473D44A33B9244408B8D791D715E4640473D44A33B92444042D13C8045684640340EF5BBB09B444042D13C8045684640340EF5BBB09B44408B8D791D715E4640473D44A33B9244408B8D791D715E4640
50836	Роте-Фане	2	20	937	40.862772	40.883721000000001	45.151372000000002	45.134951000000001	0103000020E61000000100000005000000C7F319506F6E444000C8091346914640C7F319506F6E4440DBC35E2860934640EBE40CC51D714440DBC35E2860934640EBE40CC51D71444000C8091346914640C7F319506F6E444000C8091346914640
50742	Родниковский	2	20	937	41.231431999999998	41.256971	44.729534000000001	44.707231999999998	0103000020E61000000100000005000000BA9F53909F9D4440A3570394865A4640BA9F53909F9D4440F8A8BF5E615D46409D82FC6CE4A04440F8A8BF5E615D46409D82FC6CE4A04440A3570394865A4640BA9F53909F9D4440A3570394865A4640
23141	Раздольный	2	20	937	41.027980999999997	41.047888	44.814729999999997	44.804031000000002	0103000020E6100000010000000500000066F4A3E1948344402FFCE07CEA66464066F4A3E194834440F88898124968464078EFA83121864440F88898124968464078EFA831218644402FFCE07CEA66464066F4A3E1948344402FFCE07CEA664640
32712	Радищево	2	20	937	41.131494000000004	41.142274	44.884511000000003	44.866365000000002	0103000020E6100000010000000500000064CF9ECBD490444014B35E0CE56E464064CF9ECBD4904440E4F90CA8377146401A89D00836924440E4F90CA8377146401A89D0083692444014B35E0CE56E464064CF9ECBD490444014B35E0CE56E4640
50613	Прочноокопская	2	20	937	41.104689	41.134045999999998	45.082025000000002	45.042126000000003	0103000020E610000001000000050000001FA0FB72668D4440D9278062648546401FA0FB72668D44402A3A92CB7F8A46406E14596B289144402A3A92CB7F8A46406E14596B28914440D9278062648546401FA0FB72668D4440D927806264854640
50320	Прогресс	2	20	937	40.968224999999997	40.987026999999998	45.207287999999998	45.185896	0103000020E61000000100000005000000B515FBCBEE7B4440863AAC70CB974640B515FBCBEE7B4440376DC669889A46406EA296E6567E4440376DC669889A46406EA296E6567E4440863AAC70CB974640B515FBCBEE7B4440863AAC70CB974640
47127	Передовой	2	20	937	41.258111999999997	41.275233999999998	45.072884999999999	45.056058999999998	0103000020E61000000100000005000000425A63D009A14440BFD2F9F02C874640425A63D009A144403AAFB14B54894640A65F22DE3AA344403AAFB14B54894640A65F22DE3AA34440BFD2F9F02C874640425A63D009A14440BFD2F9F02C874640
32676	Новосельское	2	20	937	41.013429000000002	41.036138000000001	44.901693999999999	44.882519000000002	0103000020E61000000100000005000000B4E89D0AB8814440A08CF161F6704640B4E89D0AB8814440ED7F80B56A7346404912842BA0844440ED7F80B56A7346404912842BA0844440A08CF161F6704640B4E89D0AB8814440A08CF161F6704640
50393	Новокубанск	2	20	937	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
13546	Новокубанск	2	20	937	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
50288	Марьинский	2	20	937	40.886380000000003	40.899611999999998	45.061636999999997	45.052836999999997	0103000020E610000001000000050000000CEA5BE6747144406682E15CC38646400CEA5BE6747144409D9CA1B8E3874640698B6B7C267344409D9CA1B8E3874640698B6B7C267344406682E15CC38646400CEA5BE6747144406682E15CC3864640
50728	Ляпино	2	20	937	41.103952	41.132941000000002	45.161712999999999	45.149121999999998	0103000020E61000000100000005000000492D944C4E8D44409B8E006E16934640492D944C4E8D4440452BF702B394464016A6EF3504914440452BF702B394464016A6EF35049144409B8E006E16934640492D944C4E8D44409B8E006E16934640
19718	Косякинская	2	20	937	41.387352	41.409253	45.030374999999999	45.011535000000002	0103000020E61000000100000005000000250516C094B1444033E197FA79814640250516C094B14440D9CEF753E38346401B65FD6662B44440D9CEF753E38346401B65FD6662B4444033E197FA79814640250516C094B1444033E197FA79814640
46881	Комсомольский	2	20	937	40.865170999999997	40.875366999999997	45.217103999999999	45.207839999999997	0103000020E610000001000000050000004B395FECBD6E44407B6649809A9A46404B395FECBD6E444057EA5910CA9B4640B27F9E060C70444057EA5910CA9B4640B27F9E060C7044407B6649809A9A46404B395FECBD6E44407B6649809A9A4640
17692	Ковалевское	2	20	937	40.983038999999998	41.013787999999998	45.180236000000001	45.149236000000002	0103000020E61000000100000005000000A5D8D138D47D444064B14D2A1A934640A5D8D138D47D4440EBC726F911974640E38920CEC3814440EBC726F911974640E38920CEC381444064B14D2A1A934640A5D8D138D47D444064B14D2A1A934640
50804	Кирова	2	20	937	40.888626000000002	40.917245999999999	45.175522000000001	45.151614000000002	0103000020E610000001000000050000000A302C7FBE714440D1CE6916689346400A302C7FBE71444040DD408177964640833122516875444040DD4081779646408331225168754440D1CE6916689346400A302C7FBE714440D1CE691668934640
46999	Камышеваха	2	20	937	41.292571000000002	41.346722	45.224513000000002	45.186754000000001	0103000020E6100000010000000500000007616EF772A54440D732198EE797464007616EF772A5444070438CD7BC9C4640E066F16261AC444070438CD7BC9C4640E066F16261AC4440D732198EE797464007616EF772A54440D732198EE7974640
50690	Измайлов	2	20	937	40.911208999999999	40.927379000000002	45.004219999999997	44.994430000000001	0103000020E6100000010000000500000012691B7FA2744440A514747B497F464012691B7FA27444409BFEEC478A804640A4FFE55AB47644409BFEEC478A804640A4FFE55AB4764440A514747B497F464012691B7FA2744440A514747B497F4640
18154	Зорька	2	20	937	40.799242999999997	40.810938999999998	45.003582000000002	44.998586000000003	0103000020E61000000100000005000000494739984D6644402A1F82AAD17F4640494739984D664440596DFE5F75804640850662D9CC674440596DFE5F75804640850662D9CC6744402A1F82AAD17F4640494739984D6644402A1F82AAD17F4640
47835	Горькая Балка	2	20	937	41.328612	41.352066999999998	45.109059999999999	45.092201000000003	0103000020E610000001000000050000005D8940F50FAA44404AD40B3ECD8B46405D8940F50FAA4440A0A696ADF58D46401B800D8810AD4440A0A696ADF58D46401B800D8810AD44404AD40B3ECD8B46405D8940F50FAA44404AD40B3ECD8B4640
47215	Глубокий	2	20	937	41.005549999999999	41.029463999999997	44.955024000000002	44.934054000000003	0103000020E61000000100000005000000143FC6DCB58044405859DB148F774640143FC6DCB58044409372F7393E7A46406534F279C58344409372F7393E7A46406534F279C58344405859DB148F774640143FC6DCB58044405859DB148F774640
46351	Восход	2	20	937	40.962674	40.985239999999997	45.240585000000003	45.207942000000003	0103000020E61000000100000005000000D15AD1E6387B444080BBECD79D9A4640D15AD1E6387B44403F74417DCB9E4640035B25581C7E44403F74417DCB9E4640035B25581C7E444080BBECD79D9A4640D15AD1E6387B444080BBECD79D9A4640
50851	Большевик	2	20	937	40.911721	40.928780000000003	45.123790999999997	45.117182999999997	0103000020E61000000100000005000000C8091346B3744440D65240DAFF8E4640C8091346B374444002452C62D88F4640E6965643E276444002452C62D88F4640E6965643E2764440D65240DAFF8E4640C8091346B3744440D65240DAFF8E4640
20432	Бесскорбная	2	20	937	41.274954999999999	41.351616999999997	44.674185999999999	44.612388000000003	0103000020E61000000100000005000000936FB6B931A344403F3BE0BA624E4640936FB6B931A34440E5B512BA4B564640DBDB2DC901AD4440E5B512BA4B564640DBDB2DC901AD44403F3BE0BA624E4640936FB6B931A344403F3BE0BA624E4640
50663	Ярославская	2	20	1395	40.439413999999999	40.485156000000003	44.640256000000001	44.585278000000002	0103000020E61000000100000005000000C8B3CBB73E384440BE88B663EA4A4640C8B3CBB73E384440AD889AE8F3514640A6BA8097193E4440AD889AE8F3514640A6BA8097193E4440BE88B663EA4A4640C8B3CBB73E384440BE88B663EA4A4640
16433	Шедок	2	20	1395	40.818629000000001	40.878610000000002	44.264806	44.204431	0103000020E610000001000000050000005247C7D5C8684440F0A485CB2A1A46405247C7D5C86844406DE4BA29E521464023F8DF4A767044406DE4BA29E521464023F8DF4A76704440F0A485CB2A1A46405247C7D5C8684440F0A485CB2A1A4640
50724	Хамкетинская	2	20	1395	40.480547999999999	40.525562999999998	44.375441000000002	44.343384999999998	0103000020E610000001000000050000004014CC98823D4440EE77280AF42B46404014CC98823D4440ED4960730E3046406B7EFCA545434440ED4960730E3046406B7EFCA545434440EE77280AF42B46404014CC98823D4440EE77280AF42B4640
17382	Унароково	2	20	1395	40.492342999999998	40.526389000000002	44.756027000000003	44.728893999999997	0103000020E610000001000000050000000FB56D18053F444014200A664C5D46400FB56D18053F44404EF2237EC5604640B1FCF9B6604344404EF2237EC5604640B1FCF9B66043444014200A664C5D46400FB56D18053F444014200A664C5D4640
16768	Узловой	2	20	1395	40.589207999999999	40.602764000000001	44.147731999999998	44.127702999999997	0103000020E610000001000000050000005245F12A6B4B4440F04C6892581046405245F12A6B4B44404D49D6E1E8124640639AE95E274D44404D49D6E1E8124640639AE95E274D4440F04C6892581046405245F12A6B4B4440F04C689258104640
16397	Соленое	2	20	1395	40.854453999999997	40.893763999999997	44.061869000000002	44.024481000000002	0103000020E61000000100000005000000DBF7A8BF5E6D4440CB2F833122034640DBF7A8BF5E6D444070D1C952EB074640CB2BD7DB6672444070D1C952EB074640CB2BD7DB66724440CB2F833122034640DBF7A8BF5E6D4440CB2F833122034640
50565	Славянский	2	20	1395	40.501766000000003	40.530054	44.713869000000003	44.659948	0103000020E61000000100000005000000541F48DE39404440C287122D79544640541F48DE394044406A50340F605B4640978E39CFD84344406A50340F605B4640978E39CFD8434440C287122D79544640541F48DE39404440C287122D79544640
50770	Северный	2	20	1395	40.532128999999998	40.582093999999998	44.638157999999997	44.627068000000001	0103000020E61000000100000005000000682096CD1C4444401F2FA4C343504640682096CD1C44444023D74D29AF5146405299620E824A444023D74D29AF5146405299620E824A44401F2FA4C343504640682096CD1C4444401F2FA4C343504640
50809	Свободный Мир	2	20	1395	40.871926000000002	40.888984999999998	44.300725	44.285252999999997	0103000020E610000001000000050000001C446B459B6F4440FE0A992B832446401C446B459B6F4440780B24287E26464039D1AE42CA714440780B24287E26464039D1AE42CA714440FE0A992B832446401C446B459B6F4440FE0A992B83244640
15931	Псебай	2	20	1395	40.763347000000003	40.844222000000002	44.187964000000001	44.083914999999998	0103000020E61000000100000005000000F73FC05AB561444069520ABABD0A4640F73FC05AB5614440A56950340F18464028486C770F6C4440A56950340F18464028486C770F6C444069520ABABD0A4640F73FC05AB561444069520ABABD0A4640
45348	Пролетарский	2	20	1395	40.699970999999998	40.714666999999999	44.364421999999998	44.351022999999998	0103000020E61000000100000005000000FF9254A69859444068925852EE2C4640FF9254A698594440B1F84D61A52E4640E54350357A5B4440B1F84D61A52E4640E54350357A5B444068925852EE2C4640FF9254A69859444068925852EE2C4640
50773	Переправная	2	20	1395	40.751227999999998	40.790331999999999	44.354638999999999	44.315173999999999	0103000020E6100000010000000500000074EB353D286044405646239F5728464074EB353D286044406D718DCF642D4640BB7D5699296544406D718DCF642D4640BB7D5699296544405646239F5728464074EB353D286044405646239F57284640
16288	Перевалка	2	20	1395	40.743754000000003	40.771808999999998	44.061176000000003	44.040294000000003	0103000020E610000001000000050000007522C154335F4440CE1C925A280546407522C154335F44406AA67B9DD407464015E126A3CA6244406AA67B9DD407464015E126A3CA624440CE1C925A280546407522C154335F4440CE1C925A28054640
50341	Первомайский	2	20	1395	40.735776999999999	40.743071999999998	44.388654000000002	44.376491000000001	0103000020E610000001000000050000001213D4F02D5E4440821E6ADB303046401213D4F02D5E4440D4BA0D6ABF3146406249B9FB1C5F4440D4BA0D6ABF3146406249B9FB1C5F4440821E6ADB303046401213D4F02D5E4440821E6ADB30304640
15327	Мостовской	2	20	1395	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
50892	Махошевская	2	20	1395	40.424565000000001	40.462823999999998	44.572243999999998	44.535117999999997	0103000020E610000001000000050000005C035B25583644401EC022BF7E4446405C035B255836444086AA984A3F494640E6E61BD13D3B444086AA984A3F494640E6E61BD13D3B44401EC022BF7E4446405C035B25583644401EC022BF7E444640
50787	Красный Кут	2	20	1395	40.563454	40.584088000000001	44.623756999999998	44.583596	0103000020E610000001000000050000007366BB421F484440C8091346B34A46407366BB421F48444056D3F544D74F464037FE4465C34A444056D3F544D74F464037FE4465C34A4440C8091346B34A46407366BB421F484440C8091346B34A4640
50852	Костромская	2	20	1395	40.565007999999999	40.606994999999998	44.545532000000001	44.492341000000003	0103000020E610000001000000050000003BFDA02E524844406FBDA607053F46403BFDA02E52484440F37519FED3454640F2EA1C03B24D4440F37519FED3454640F2EA1C03B24D44406FBDA607053F46403BFDA02E524844406FBDA607053F4640
50833	Губская	2	20	1395	40.590088999999999	40.666338000000003	44.327485000000003	44.302925000000002	0103000020E610000001000000050000005B5D4E09884B44400612143FC62646405B5D4E09884B44401D774A07EB294640810A47904A5544401D774A07EB294640810A47904A5544400612143FC62646405B5D4E09884B44400612143FC6264640
47071	Высокий	2	20	1395	40.736739	40.744069000000003	44.374268000000001	44.368017999999999	0103000020E610000001000000050000000858AB764D5E44406F2BBD361B2F46400858AB764D5E44403CF88903E82F4640D57B2AA73D5F44403CF88903E82F4640D57B2AA73D5F44406F2BBD361B2F46400858AB764D5E44406F2BBD361B2F4640
17007	Восточный	2	20	1395	40.60183	40.630215999999997	44.601742000000002	44.579473999999998	0103000020E6100000010000000500000037E0F3C3084D4440EF703B342C4A464037E0F3C3084D44409850C1E1054D46403DB5FAEAAA5044409850C1E1054D46403DB5FAEAAA504440EF703B342C4A464037E0F3C3084D4440EF703B342C4A4640
50683	Бесленеевская	2	20	1395	40.681635999999997	40.753762000000002	44.248362	44.214866000000001	0103000020E610000001000000050000005CE333D93F574440DC82A5BA801B46405CE333D93F574440DAC87553CA1F4640D97BF1457B604440DAC87553CA1F4640D97BF1457B604440DC82A5BA801B46405CE333D93F574440DC82A5BA801B4640
16654	Беноково	2	20	1395	40.657076000000004	40.698830000000001	44.435105	44.405965999999999	0103000020E61000000100000005000000467EFD101B544440DBA4A2B1F6334640467EFD101B544440BDA94885B13746405ABBED4273594440BDA94885B13746405ABBED4273594440DBA4A2B1F6334640467EFD101B544440DBA4A2B1F6334640
50752	Баракаевская	2	20	1395	40.495927000000002	40.549565999999999	44.301130999999998	44.278509	0103000020E61000000100000005000000091A33897A3F44402252D32EA6234640091A33897A3F4440E867EA758B2646402C7FBE2D58464440E867EA758B2646402C7FBE2D584644402252D32EA6234640091A33897A3F44402252D32EA6234640
50826	Баговская	2	20	1395	40.576873999999997	40.625625999999997	44.192985999999998	44.153494999999999	0103000020E61000000100000005000000D3F4D901D7494440BD8C62B9A5134640D3F4D901D7494440FD4AE7C3B31846407EC3448314504440FD4AE7C3B31846407EC3448314504440BD8C62B9A5134640D3F4D901D7494440BD8C62B9A5134640
50794	Андрюки	2	20	1395	40.812151999999998	40.846916999999998	44.143948000000002	44.111493000000003	0103000020E61000000100000005000000C4B0C398F4674440D15D1267450E4640C4B0C398F46744408D2958E36C12464095B6B8C6676C44408D2958E36C12464095B6B8C6676C4440D15D1267450E4640C4B0C398F4674440D15D1267450E4640
14667	Уманский	2	20	1358	39.259118000000001	39.274281000000002	46.241332999999997	46.230026000000002	0103000020E6100000010000000500000008E753C72AA14340679DF17D711D474008E753C72AA143400839EFFFE31E47400475CAA31BA343400839EFFFE31E47400475CAA31BA34340679DF17D711D474008E753C72AA14340679DF17D711D4740
15176	Образцовый	2	20	1358	39.537703	39.567186	46.113357999999998	46.100599000000003	0103000020E6100000010000000500000005FBAF73D3C443405281936DE00C474005FBAF73D3C44340B75ED383820E4740E15F048D99C84340B75ED383820E4740E15F048D99C843405281936DE00C474005FBAF73D3C443405281936DE00C4740
14966	Новоплатнировская	2	20	1358	39.398553999999997	39.439211999999998	46.117525000000001	46.091436999999999	0103000020E6100000010000000500000051D845D103B343407A522635B40B474051D845D103B3434030BB270F0B0F474060014C1938B8434030BB270F0B0F474060014C1938B843407A522635B40B474051D845D103B343407A522635B40B4740
49148	Ленинградская	2	20	1358	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
50841	Куликовский	2	20	1358	39.523555000000002	39.590102000000002	46.346899000000001	46.334958999999998	0103000020E610000001000000050000002254A9D903C343401C40BFEFDF2A47402254A9D903C34340EF01BA2F672C4740F0A65B7688CB4340EF01BA2F672C4740F0A65B7688CB43401C40BFEFDF2A47402254A9D903C343401C40BFEFDF2A4740
50252	Крыловская	2	20	1358	39.278261000000001	39.335006999999997	46.127825000000001	46.089892999999996	0103000020E610000001000000050000004A60730E9EA34340D591239D810B47404A60730E9EA343403C4ED1915C1047402D776682E1AA43403C4ED1915C1047402D776682E1AA4340D591239D810B47404A60730E9EA34340D591239D810B4740
50661	Краснострелецкий	2	20	1358	39.487217999999999	39.494619999999998	46.178455999999997	46.169857	0103000020E61000000100000005000000E202D0285DBE434093FFC9DFBD154740E202D0285DBE434032E36DA5D716474048F949B54FBF434032E36DA5D716474048F949B54FBF434093FFC9DFBD154740E202D0285DBE434093FFC9DFBD154740
50817	Коржи	2	20	1358	39.190818999999998	39.301248999999999	46.055931000000001	46.007702999999999	0103000020E610000001000000050000004B3ACAC16C984340618A7269FC0047404B3ACAC16C98434092EA3BBF28074740F279C5538FA6434092EA3BBF28074740F279C5538FA64340618A7269FC0047404B3ACAC16C984340618A7269FC004740
14761	Звезда	2	20	1358	39.357771	39.378495000000001	46.197273000000003	46.184297000000001	0103000020E61000000100000005000000863AAC70CBAD43401EE0490B97174740863AAC70CBAD434021B1DD3D401947408A592F8672B0434021B1DD3D401947408A592F8672B043401EE0490B97174740863AAC70CBAD43401EE0490B97174740
46545	Западный	2	20	1358	39.284818999999999	39.329194999999999	46.406374999999997	46.384124	0103000020E61000000100000005000000C423F1F274A44340EACDA8F92A314740C423F1F274A44340BC74931804344740DC80CF0F23AA4340BC74931804344740DC80CF0F23AA4340EACDA8F92A314740C423F1F274A44340EACDA8F92A314740
21044	Высотный	2	20	1358	39.571193000000001	39.581685	46.125594999999997	46.120984999999997	0103000020E61000000100000005000000215A2BDA1CC943403D27BD6F7C0F4740215A2BDA1CC9434043C5387F1310474071C971A774CA434043C5387F1310474071C971A774CA43403D27BD6F7C0F4740215A2BDA1CC943403D27BD6F7C0F4740
50821	Восточный	2	20	1358	39.519593	39.530920999999999	46.274737999999999	46.264415	0103000020E61000000100000005000000821DFF0582C2434032C9C859D8214740821DFF0582C24340F67B629D2A2347403BE12538F5C34340F67B629D2A2347403BE12538F5C3434032C9C859D8214740821DFF0582C2434032C9C859D8214740
15108	Бичевой	2	20	1358	39.557887999999998	39.621723000000003	46.251005999999997	46.238197999999997	0103000020E61000000100000005000000596ABDDF68C743407EFCA5457D1E4740596ABDDF68C74340C58CF0F620204740E415889E94CF4340C58CF0F620204740E415889E94CF43407EFCA5457D1E4740596ABDDF68C743407EFCA5457D1E4740
50378	Малый Кичмай	2	20	7075	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
50861	Аше	2	20	7075	39.248581000000001	39.288511	43.972721	43.948582000000002	0103000020E6100000010000000500000018B49080D19F434082C98D226BF9454018B49080D19F4340F390291F82FC4540A4C4AEEDEDA44340F390291F82FC4540A4C4AEEDEDA4434082C98D226BF9454018B49080D19F434082C98D226BF94540
50502	станция Владимирская	2	20	1002	40.703527999999999	40.835329000000002	44.609045000000002	44.514817000000001	0103000020E61000000100000005000000FFE89B340D5A444061360186E5414640FFE89B340D5A44406B65C22FF54D46404033880FEC6A44406B65C22FF54D46404033880FEC6A444061360186E5414640FFE89B340D5A444061360186E5414640
50857	Чернореченская	2	20	1002	40.940755000000003	40.970759000000001	44.24689	44.226469000000002	0103000020E610000001000000050000003546EBA86A7844406747AAEFFC1C46403546EBA86A784440CFDA6D179A1F46401AA6B6D4417C4440CFDA6D179A1F46401AA6B6D4417C44406747AAEFFC1C46403546EBA86A7844406747AAEFFC1C4640
12231	Чамлыкская	2	20	1002	40.840386000000002	40.902092000000003	44.733108000000001	44.687601000000001	0103000020E610000001000000050000001502B9C4916B444034D93F4F035846401502B9C4916B4440CE37A27BD65D4640DBFD2AC077734440CE37A27BD65D4640DBFD2AC07773444034D93F4F035846401502B9C4916B444034D93F4F03584640
50849	Харьковский	2	20	1002	41.138654000000002	41.156098999999998	44.494579000000002	44.457138999999998	0103000020E61000000100000005000000D4BA0D6ABF914440F25CDF87833A4640D4BA0D6ABF914440EA245B5D4E3F46401AF8510DFB934440EA245B5D4E3F46401AF8510DFB934440F25CDF87833A4640D4BA0D6ABF914440F25CDF87833A4640
13471	Упорная	2	20	1002	40.999378999999998	41.046666000000002	44.431306999999997	44.355013	0103000020E6100000010000000500000093A7ACA6EB7F4440D253E410712D464093A7ACA6EB7F444097C4591135374640E6EAC726F985444097C4591135374640E6EAC726F9854440D253E410712D464093A7ACA6EB7F4440D253E410712D4640
50311	Соколихин	2	20	1002	40.936262999999997	40.960428	44.654209999999999	44.639921999999999	0103000020E6100000010000000500000038BA4A77D7774440D6FECEF6E851464038BA4A77D7774440AB5B3D27BD534640D314014EEF7A4440AB5B3D27BD534640D314014EEF7A4440D6FECEF6E851464038BA4A77D7774440D6FECEF6E8514640
50554	Сладкий	2	20	1002	41.023122000000001	41.044500999999997	44.475845999999997	44.448787000000003	0103000020E61000000100000005000000B8E864A9F58244405BEF37DA71394640B8E864A9F582444059F78F85E83C4640D4D17135B285444059F78F85E83C4640D4D17135B28544405BEF37DA71394640B8E864A9F58244405BEF37DA71394640
13410	Розовый	2	20	1002	41.023822000000003	41.043145000000003	44.497942000000002	44.474502000000001	0103000020E6100000010000000500000071766B990C8344407CF1457BBC3C464071766B990C83444005A73E90BC3F464033FE7DC68585444005A73E90BC3F464033FE7DC6858544407CF1457BBC3C464071766B990C8344407CF1457BBC3C4640
50442	Поселок Братский	2	20	1002	41.037486000000001	41.049064999999999	44.717711999999999	44.700544000000001	0103000020E6100000010000000500000068075C57CC8444405BB4006DAB59464068075C57CC8444402FF99FFCDD5B46406A300DC3478644402FF99FFCDD5B46406A300DC3478644405BB4006DAB59464068075C57CC8444405BB4006DAB594640
50745	Первая Синюха	2	20	1002	41.057409999999997	41.110275999999999	44.665557999999997	44.627952999999998	0103000020E610000001000000050000004F3BFC355987444069368FC3605046404F3BFC3559874440ABCB29013155464050C422861D8E4440ABCB29013155464050C422861D8E444069368FC3605046404F3BFC355987444069368FC360504640
49013	Отважная	2	20	1002	41.008434000000001	41.081225000000003	44.260978000000001	44.221390999999997	0103000020E610000001000000050000005516855D148144407A50508A561C46405516855D14814440DD7C23BA672146400E4FAF94658A4440DD7C23BA672146400E4FAF94658A44407A50508A561C46405516855D148144407A50508A561C4640
50769	Новый Мир	2	20	1002	41.002954000000003	41.015019000000002	44.330142000000002	44.309117000000001	0103000020E610000001000000050000003AB2F2CB608044409ED15625912746403AB2F2CB608044409D84D217422A4640C9E88024EC8144409D84D217422A4640C9E88024EC8144409ED15625912746403AB2F2CB608044409ED1562591274640
50385	Лабинск	2	20	1002	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
8663	Лабинск	2	20	1002	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
12981	Каладжинская	2	20	1002	40.880586000000001	40.932931000000004	44.323093999999998	44.287652999999999	0103000020E6100000010000000500000061A8C30AB770444053CC41D0D124464061A8C30AB770444054C4E9245B294640593673486A77444054C4E9245B294640593673486A77444053CC41D0D124464061A8C30AB770444053CC41D0D1244640
12955	Зассовская	2	20	1002	40.795974000000001	40.833739000000001	44.453265999999999	44.411279	0103000020E61000000100000005000000B03BDD79E26544400B444FCAA4344640B03BDD79E2654440C231CB9E043A46402B33A5F5B76A4440C231CB9E043A46402B33A5F5B76A44400B444FCAA4344640B03BDD79E26544400B444FCAA4344640
48885	Ереминская	2	20	1002	40.987170999999996	41.019500999999998	44.611015000000002	44.580880000000001	0103000020E61000000100000005000000A1478C9E5B7E444043739D465A4A4640A1478C9E5B7E4440C72E51BD354E4640A19E3E027F824440C72E51BD354E4640A19E3E027F82444043739D465A4A4640A1478C9E5B7E444043739D465A4A4640
49033	Гофицкое	2	20	1002	40.952711999999998	40.995291999999999	44.272190000000002	44.229937	0103000020E61000000100000005000000DD408177F2794440F7915B936E1D4640DD408177F27944402D26361FD722464037FC6EBA657F44402D26361FD722464037FC6EBA657F4440F7915B936E1D4640DD408177F2794440F7915B936E1D4640
48795	Вознесенская	2	20	1002	41.002433000000003	41.060859999999998	44.583069000000002	44.512341999999997	0103000020E6100000010000000500000031B77BB94F804440012F336C9441464031B77BB94F804440DD274701A24A464039D1AE42CA874440DD274701A24A464039D1AE42CA874440012F336C9441464031B77BB94F804440012F336C94414640
50251	Владимирская	2	20	1002	40.768880000000003	40.847239999999999	44.574227999999998	44.521867	0103000020E610000001000000050000003546EBA86A6244404AEEB089CC4246403546EBA86A6244404739984D8049464078EE3D5C726C44404739984D8049464078EE3D5C726C44404AEEB089CC4246403546EBA86A6244404AEEB089CC424640
50686	Веселый	2	20	1002	40.898623999999998	40.924163	44.484521999999998	44.469748000000003	0103000020E610000001000000050000004AB3791C0673444043AED4B3203C46404AB3791C06734440A41820D1043E46402D9622F94A764440A41820D1043E46402D9622F94A76444043AED4B3203C46404AB3791C0673444043AED4B3203C4640
45934	Братский	2	20	1002	41.037486000000001	41.049064999999999	44.717711999999999	44.700544000000001	0103000020E6100000010000000500000068075C57CC8444405BB4006DAB59464068075C57CC8444402FF99FFCDD5B46406A300DC3478644402FF99FFCDD5B46406A300DC3478644405BB4006DAB59464068075C57CC8444405BB4006DAB594640
12373	Ахметовская	2	20	1002	41.036821000000003	41.066932000000001	44.178953	44.120869999999996	0103000020E610000001000000050000002C67EF8CB6844440A4880CAB780F46402C67EF8CB6844440B34291EEE716464027874F3A91884440B34291EEE716464027874F3A91884440A4880CAB780F46402C67EF8CB6844440A4880CAB780F4640
11046	Шкуринская	2	20	1015	39.329815000000004	39.392634000000001	46.610754999999997	46.563326000000004	0103000020E61000000100000005000000795DBF6037AA4340467EFD101B484740795DBF6037AA43402A6F47382D4E47401AA6B6D441B243402A6F47382D4E47401AA6B6D441B24340467EFD101B484740795DBF6037AA4340467EFD101B484740
11003	Тауруп 1-й	2	20	1015	39.484146000000003	39.545077999999997	46.766125000000002	46.751086000000001	0103000020E610000001000000050000009F3E027FF8BD4340E23D0796236047409F3E027FF8BD4340F2D24D621062474071E2AB1DC5C54340F2D24D621062474071E2AB1DC5C54340E23D0796236047409F3E027FF8BD4340E23D079623604740
9478	Степное	2	20	1015	39.662255000000002	39.691099999999999	46.658425999999999	46.642057999999999	0103000020E61000000100000005000000664E97C5C4D443404D11E0F42E524740664E97C5C4D44340056B9C4D47544740FF21FDF675D84340056B9C4D47544740FF21FDF675D843404D11E0F42E524740664E97C5C4D443404D11E0F42E524740
10777	Средние Чубурки	2	20	1015	39.289876	39.502265000000001	46.753203999999997	46.721421999999997	0103000020E6100000010000000500000099F221A81AA54340B54E5C8E575C474099F221A81AA54340B29B19FD68604740757632384AC04340B29B19FD68604740757632384AC04340B54E5C8E575C474099F221A81AA54340B54E5C8E575C4740
50414	Средние Чубурки	2	20	1015	39.289876	39.502265000000001	46.753203999999997	46.721421999999997	0103000020E6100000010000000500000099F221A81AA54340B54E5C8E575C474099F221A81AA54340B29B19FD68604740757632384AC04340B29B19FD68604740757632384AC04340B54E5C8E575C474099F221A81AA54340B54E5C8E575C4740
9427	Северный	2	20	1015	39.552292000000001	39.590327000000002	46.681628000000003	46.670355999999998	0103000020E61000000100000005000000D5EB1681B1C64340B456B439CE554740D5EB1681B1C64340DA0418963F5747401079CBD58FCB4340DA0418963F5747401079CBD58FCB4340B456B439CE554740D5EB1681B1C64340B456B439CE554740
9529	Садовый	2	20	1015	39.722513999999997	39.744746999999997	46.626396	46.617353999999999	0103000020E610000001000000050000007973B8567BDC43400307B474054F47407973B8567BDC4340302C7FBE2D504740A565A4DE53DF4340302C7FBE2D504740A565A4DE53DF43400307B474054F47407973B8567BDC43400307B474054F4740
9688	Ровный	2	20	1015	39.998485000000002	40.011538000000002	46.613033000000001	46.606631999999998	0103000020E61000000100000005000000F645425BCEFF4340815A0C1EA64D4740F645425BCEFF4340342F87DD774E4740A454C2137A014440342F87DD774E4740A454C2137A014440815A0C1EA64D4740F645425BCEFF4340815A0C1EA64D4740
10461	Раздольное	2	20	1015	39.650621999999998	39.676574000000002	46.714848000000003	46.703200000000002	0103000020E610000001000000050000007007EA9447D343400B462575025A47407007EA9447D3434036CEA623805B474076A911FA99D6434036CEA623805B474076A911FA99D643400B462575025A47407007EA9447D343400B462575025A4740
50765	Пролетарский	2	20	1015	39.528441999999998	39.548259000000002	46.394449000000002	46.387929	0103000020E610000001000000050000009AEAC9FCA3C34340C21550A8A73147409AEAC9FCA3C343404F78094E7D3247406C5ED5592DC643404F78094E7D3247406C5ED5592DC64340C21550A8A73147409AEAC9FCA3C34340C21550A8A7314740
10440	Полтавченское	2	20	1015	40.003658999999999	40.038927000000001	46.733170999999999	46.726716000000003	0103000020E6100000010000000500000004ABEAE5770044406FBDA607055D474004ABEAE57700444014B01D8CD85D474038F7578FFB04444014B01D8CD85D474038F7578FFB0444406FBDA607055D474004ABEAE5770044406FBDA607055D4740
10274	Первомайский	2	20	1015	39.562569000000003	39.582089000000003	46.482128000000003	46.471775999999998	0103000020E61000000100000005000000295FD04202C84340D384ED27633C4740295FD04202C84340323ECC5EB63D4740412E71E481CA4340323ECC5EB63D4740412E71E481CA4340D384ED27633C4740295FD04202C84340D384ED27633C4740
10138	Новомихайловское	2	20	1015	39.756765999999999	39.861043000000002	46.563412999999997	46.532913999999998	0103000020E61000000100000005000000C45C52B5DDE043404FCAA48636444740C45C52B5DDE043401492CCEA1D48474091B932A836EE43401492CCEA1D48474091B932A836EE43404FCAA48636444740C45C52B5DDE043404FCAA48636444740
9610	Новоивановское	2	20	1015	39.664949999999997	39.678199999999997	46.542757999999999	46.533887	0103000020E61000000100000005000000D3BCE3141DD543403961C26856444740D3BCE3141DD5434039D2191879454740D712F241CFD6434039D2191879454740D712F241CFD643403961C26856444740D3BCE3141DD543403961C26856444740
10931	Нововысоченский	2	20	1015	39.429825000000001	39.453792	46.781714999999998	46.778697000000001	0103000020E6100000010000000500000069006F8104B74340253FE257AC63474069006F8104B7434075E5B33C0F644740DD9733DB15BA434075E5B33C0F644740DD9733DB15BA4340253FE257AC63474069006F8104B74340253FE257AC634740
9534	Мирный	2	20	1015	39.835908000000003	39.844900000000003	46.622298999999998	46.608271999999999	0103000020E610000001000000050000007E3B8908FFEA434048895DDBDB4D47407E3B8908FFEA4340B0AA5E7EA74F4740F931E6AE25EC4340B0AA5E7EA74F4740F931E6AE25EC434048895DDBDB4D47407E3B8908FFEA434048895DDBDB4D4740
8781	Кущевская	2	20	1015	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
50282	Кущевская	2	20	1015	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
50419	Кущевская	2	20	1015	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
50395	Красный	2	20	1015	39.277667999999998	39.311830999999998	46.776266	46.758384	0103000020E61000000100000005000000A79201A08AA34340A3E716BA12614740A79201A08AA34340957F2DAF5C63474082700514EAA74340957F2DAF5C63474082700514EAA74340A3E716BA12614740A79201A08AA34340A3E716BA12614740
10001	Красное	2	20	1015	39.506936000000003	39.577615000000002	46.745497999999998	46.727345999999997	0103000020E6100000010000000500000021956247E3C043402E7079AC195D474021956247E3C04340E09D7C7A6C5F4740EB56CF49EFC94340E09D7C7A6C5F4740EB56CF49EFC943402E7079AC195D474021956247E3C043402E7079AC195D4740
50714	Красная Поляна	2	20	1015	39.323338	39.403109000000001	46.666052000000001	46.651288000000001	0103000020E61000000100000005000000EBC6BB2363A943407D23BA675D534740EBC6BB2363A94340BBB722314155474094DC611399B34340BBB722314155474094DC611399B343407D23BA675D534740EBC6BB2363A943407D23BA675D534740
10290	Комсомольский	2	20	1015	39.376105000000003	39.399982999999999	46.504815999999998	46.492266000000001	0103000020E61000000100000005000000596E693524B0434064778192023F4740596E693524B04340AF3F89CF9D4047405DFA97A432B34340AF3F89CF9D4047405DFA97A432B3434064778192023F4740596E693524B0434064778192023F4740
10238	Коммунар	2	20	1015	39.939044000000003	39.950057000000001	46.534841999999998	46.525770999999999	0103000020E61000000100000005000000A5C0029832F84340B517D1764C434740A5C0029832F843407C43E1B375444740FE2AC0779BF943407C43E1B375444740FE2AC0779BF94340B517D1764C434740A5C0029832F84340B517D1764C434740
9831	Кисляковская	2	20	1015	39.643300000000004	39.705086000000001	46.461906999999997	46.407307000000003	0103000020E6100000010000000500000027C286A757D243404837C2A22234474027C286A757D243409065C1C41F3B4740096F0F4240DA43409065C1C41F3B4740096F0F4240DA43404837C2A22234474027C286A757D243404837C2A222344740
9916	Кисляковка	2	20	1015	39.598483000000002	39.614294000000001	46.396014999999998	46.387531000000003	0103000020E61000000100000005000000221B48179BCC4340D597A59D9A314740221B48179BCC4340DBDC989EB03247408410902FA1CE4340DBDC989EB03247408410902FA1CE4340D597A59D9A314740221B48179BCC4340D597A59D9A314740
50763	Исаевский	2	20	1015	39.497629000000003	39.539059999999999	46.717998999999999	46.699838	0103000020E6100000010000000500000046459C4EB2BF4340C03FA54A9459474046459C4EB2BF4340C5C72764E75B4740774A07EBFFC44340C5C72764E75B4740774A07EBFFC44340C03FA54A9459474046459C4EB2BF4340C03FA54A94594740
9771	Ильинское	2	20	1015	39.826934000000001	39.869469000000002	46.678524000000003	46.652030000000003	0103000020E61000000100000005000000A9F92AF9D8E94340650113B875534740A9F92AF9D8E943408BC6DADFD956474063F19BC24AEF43408BC6DADFD956474063F19BC24AEF4340650113B875534740A9F92AF9D8E94340650113B875534740
10671	Ивано-Слюсаревское	2	20	1015	39.743651	39.760593	46.665823000000003	46.651572999999999	0103000020E61000000100000005000000A051BAF42FDF434072FA7ABE66534740A051BAF42FDF43405AF624B0395547408448861C5BE143405AF624B0395547408448861C5BE1434072FA7ABE66534740A051BAF42FDF434072FA7ABE66534740
50799	Зеленая Роща	2	20	1015	39.782674	39.829413000000002	46.77205	46.756889999999999	0103000020E61000000100000005000000FAB660A92EE44340B05582C5E1604740FAB660A92EE443403B70CE88D26247404AF086342AEA43403B70CE88D26247404AF086342AEA4340B05582C5E1604740FAB660A92EE44340B05582C5E1604740
10690	Гослесопитомник	2	20	1015	39.743912000000002	39.760224999999998	46.660572000000002	46.648466999999997	0103000020E610000001000000050000000D8D278238DF434082C476F7005347400D8D278238DF4340A053909F8D544740014D840D4FE14340A053909F8D544740014D840D4FE1434082C476F7005347400D8D278238DF434082C476F700534740
9666	Глебовка	2	20	1015	39.970350000000003	40.016199999999998	46.648876000000001	46.636755000000001	0103000020E6100000010000000500000039D6C56D34FC4340414816308151474039D6C56D34FC43406494675E0E534740FC1873D7120244406494675E0E534740FC1873D712024440414816308151474039D6C56D34FC43404148163081514740
10533	Водяная Балка	2	20	1015	39.580283000000001	39.692293999999997	46.736432000000001	46.720556999999999	0103000020E610000001000000050000005FB69DB646CA4340B2F336363B5C47405FB69DB646CA43402BDD5D67435E4740C79BFC169DD843402BDD5D67435E4740C79BFC169DD84340B2F336363B5C47405FB69DB646CA4340B2F336363B5C4740
9373	Бол. Лопатина	2	20	1015	39.553963000000003	39.603423999999997	46.646456999999998	46.640177000000001	0103000020E61000000100000005000000D7187442E8C643406153E751F1514740D7187442E8C6434098A25C1ABF5247408DCF64FF3CCD434098A25C1ABF5247408DCF64FF3CCD43406153E751F1514740D7187442E8C643406153E751F1514740
10594	Алексеевское	2	20	1015	39.705482000000003	39.718615	46.762358999999996	46.746220000000001	0103000020E6100000010000000500000056F5F23B4DDA434081CF0F23845F474056F5F23B4DDA4340D767CEFA9461474020B58993FBDB4340D767CEFA9461474020B58993FBDB434081CF0F23845F474056F5F23B4DDA434081CF0F23845F4740
8089	Щебенозаводской	2	20	821	40.834950999999997	40.850887999999998	44.931342999999998	44.923161	0103000020E610000001000000050000009961A3ACDF6A4440A9F8BF232A7646409961A3ACDF6A4440E42D573F367746408847E2E5E96C4440E42D573F367746408847E2E5E96C4440A9F8BF232A7646409961A3ACDF6A4440A9F8BF232A764640
8253	Урмия	2	20	821	40.850825	40.868952999999998	44.863241000000002	44.842185999999998	0103000020E6100000010000000500000042CF66D5E76C4440149337C0CC6B464042CF66D5E76C44407EC85BAE7E6E46406B6116DA396F44407EC85BAE7E6E46406B6116DA396F4440149337C0CC6B464042CF66D5E76C4440149337C0CC6B4640
7458	Темиргоевская	2	20	821	40.243447000000003	40.325839999999999	45.127930999999997	45.08522	0103000020E6100000010000000500000098A77345291F4440897B2C7DE88A464098A77345291F44408192020B6090464044DD0720B52944408192020B6090464044DD0720B5294440897B2C7DE88A464098A77345291F4440897B2C7DE88A4640
7737	Сухой Кут	2	20	821	40.189188999999999	40.228192999999997	45.133431000000002	45.118029	0103000020E61000000100000005000000A8E15B5837184440637D03931B8F4640A8E15B5837184440E4A25A44149146408B16A06D351D4440E4A25A44149146408B16A06D351D4440637D03931B8F4640A8E15B5837184440637D03931B8F4640
33091	Светлая Заря	2	20	821	40.726551999999998	40.758909000000003	44.964858999999997	44.950476000000002	0103000020E61000000100000005000000F46BEBA7FF5C444003D19332A9794640F46BEBA7FF5C44402920ED7F807B4640EED11BEE236144402920ED7F807B4640EED11BEE2361444003D19332A9794640F46BEBA7FF5C444003D19332A9794640
8486	Родниковская	2	20	821	40.641112999999997	40.686459999999997	44.787222	44.725929000000001	0103000020E610000001000000050000002D05A4FD0F524440E71BD13DEB5C46402D05A4FD0F5244408A58C4B0C36446408E01D9EBDD5744408A58C4B0C36446408E01D9EBDD574440E71BD13DEB5C46402D05A4FD0F524440E71BD13DEB5C4640
40310	Петропавловская	2	20	821	40.413587999999997	40.495218000000001	45.101743999999997	45.059458999999997	0103000020E610000001000000050000004F029B73F0344440F7393E5A9C8746404F029B73F0344440384888F2058D4640FD31AD4D633F4440384888F2058D4640FD31AD4D633F4440F7393E5A9C8746404F029B73F0344440F7393E5A9C874640
8281	Новоалексеевская	2	20	821	40.866339000000004	40.947259000000003	44.843080999999998	44.805540000000001	0103000020E61000000100000005000000EB1F4432E46E444057CF49EF1B674640EB1F4432E46E444082700514EA6B4640BCEB6CC83F79444082700514EA6B4640BCEB6CC83F79444057CF49EF1B674640EB1F4432E46E444057CF49EF1B674640
46418	Михайловская	2	20	821	40.563884999999999	40.647337999999998	45.022385999999997	44.972174000000003	0103000020E610000001000000050000003CDA38622D484440C1029832707C46403CDA38622D484440B2F1608BDD824640A1BAB9F8DB524440B2F1608BDD824640A1BAB9F8DB524440C1029832707C46403CDA38622D484440C1029832707C4640
46141	Мира	2	20	821	40.704901999999997	40.721592999999999	45.034444999999998	45.022888999999999	0103000020E6100000010000000500000047718E3A3A5A44401538D906EE82464047718E3A3A5A44405F419AB168844640E202D0285D5C44405F419AB168844640E202D0285D5C44401538D906EE82464047718E3A3A5A44401538D906EE824640
5900	Курганинск	2	20	821	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
50266	Красный	2	20	821	40.556697999999997	40.569203000000002	45.042712000000002	45.033425999999999	0103000020E61000000100000005000000D2DF4BE141474440056B9C4D47844640D2DF4BE141474440C9923996778546407EE4D6A4DB484440C9923996778546407EE4D6A4DB484440056B9C4D47844640D2DF4BE141474440056B9C4D47844640
46377	Красное Поле	2	20	821	40.677377999999997	40.697940000000003	44.918788999999997	44.888030000000001	0103000020E61000000100000005000000D3838252B4564440F6EE8FF7AA714640D3838252B45644405776C1E09A754640FE481119565944405776C1E09A754640FE48111956594440F6EE8FF7AA714640D3838252B4564440F6EE8FF7AA714640
50729	Красное Знамя	2	20	821	40.511459000000002	40.536073000000002	45.016098	45.000535999999997	0103000020E61000000100000005000000581F0F7D774144403E3C4B9011804640581F0F7D77414440F8C3CF7F0F82464062A2410A9E444440F8C3CF7F0F82464062A2410A9E4444403E3C4B9011804640581F0F7D774144403E3C4B9011804640
8110	Кочергин	2	20	821	40.782831000000002	40.795470000000002	44.941276999999999	44.934814000000003	0103000020E61000000100000005000000C2A563CE33644440E6EB32FCA7774640C2A563CE336444400EBDC5C37B7846407D7901F6D16544400EBDC5C37B7846407D7901F6D1654440E6EB32FCA7774640C2A563CE33644440E6EB32FCA7774640
47115	Константиновская	2	20	821	40.713417999999997	40.740583000000001	44.858173999999998	44.814480000000003	0103000020E610000001000000050000005930F147515B4440809F71E1406846405930F147515B4440852348A5D86D46409E7C7A6CCB5E4440852348A5D86D46409E7C7A6CCB5E4440809F71E1406846405930F147515B4440809F71E140684640
7678	Воздвиженская	2	20	821	40.125660000000003	40.162588999999997	45.135891999999998	45.119453999999998	0103000020E610000001000000050000002B357BA0151044402DB0C7444A8F46402B357BA015104440DEE4B7E8649146403CD862B7CF144440DEE4B7E8649146403CD862B7CF1444402DB0C7444A8F46402B357BA0151044402DB0C7444A8F4640
50867	Андрее-Дмитриевский	2	20	821	40.836784000000002	40.852432999999998	44.955547000000003	44.946783000000003	0103000020E6100000010000000500000075E8F4BC1B6B444053B4722F3079464075E8F4BC1B6B44403D65355D4F7A4640FD8348861C6D44403D65355D4F7A4640FD8348861C6D444053B4722F3079464075E8F4BC1B6B444053B4722F30794640
45633	Южный	2	20	433	38.072901000000002	38.090975999999998	45.042068999999998	45.019728999999998	0103000020E61000000100000005000000406CE9D15409434032E4D87A86824640406CE9D1540943407496598462854640465C001AA50B43407496598462854640465C001AA50B434032E4D87A86824640406CE9D15409434032E4D87A86824640
3535	Экономическое	2	20	433	37.927680000000002	37.959516000000001	45.001454000000003	44.981814	0103000020E610000001000000050000009F93DE37BEF64240A260C614AC7D46409F93DE37BEF64240653909A52F8046408FFE976BD1FA4240653909A52F8046408FFE976BD1FA4240A260C614AC7D46409F93DE37BEF64240A260C614AC7D4640
2395	Черноморский	2	20	433	38.021687999999997	38.039456999999999	45.004564000000002	44.991134000000002	0103000020E610000001000000050000009A5B21ACC602434012FA997ADD7E46409A5B21ACC6024340965E9B8D95804640944C4EED0C054340965E9B8D95804640944C4EED0C05434012FA997ADD7E46409A5B21ACC602434012FA997ADD7E4640
45504	Фадеево	2	20	433	37.545447000000003	37.561472999999999	45.075915000000002	45.059044999999998	0103000020E61000000100000005000000C5591135D1C5424004FF5BC98E874640C5591135D1C542404F232D95B7894640234BE658DEC742404F232D95B7894640234BE658DEC7424004FF5BC98E874640C5591135D1C5424004FF5BC98E874640
45726	Троицкая	2	20	433	38.094738999999997	38.151693000000002	45.153075999999999	45.119039999999998	0103000020E61000000100000005000000EF535568200C43403A75E5B33C8F4640EF535568200C4340B8E68EFE979346401D041DAD6A134340B8E68EFE979346401D041DAD6A1343403A75E5B33C8F4640EF535568200C43403A75E5B33C8F4640
50693	Саукдере	2	20	433	37.879620000000003	37.894936000000001	44.907331999999997	44.897205999999997	0103000020E610000001000000050000002A745E6397F0424032E36DA5D77246402A745E6397F04240A04E797423744640AC014A438DF24240A04E797423744640AC014A438DF2424032E36DA5D77246402A745E6397F0424032E36DA5D7724640
45601	Русское	2	20	433	37.82891	37.849293000000003	44.965108000000001	44.953263999999997	0103000020E61000000100000005000000E7A90EB919EA4240213A048E047A4640E7A90EB919EA4240D28DB0A8887B464062DC0DA2B5EC4240D28DB0A8887B464062DC0DA2B5EC4240213A048E047A4640E7A90EB919EA4240213A048E047A4640
48674	Прохладный	2	20	433	37.790928999999998	37.804834999999997	44.982534999999999	44.973972000000003	0103000020E610000001000000050000009F3A56293DE54240209C4F1DAB7C46409F3A56293DE542407216F6B4C37D46408CD651D504E742407216F6B4C37D46408CD651D504E74240209C4F1DAB7C46409F3A56293DE54240209C4F1DAB7C4640
45950	Пролетарский	2	20	433	37.754547000000002	37.760809000000002	45.052252000000003	45.047393	0103000020E61000000100000005000000C02500FF94E0424098874CF910864640C02500FF94E0424047938B31B086464051C0763062E1424047938B31B086464051C0763062E1424098874CF910864640C02500FF94E0424098874CF910864640
50779	Плавненский	2	20	433	37.921965999999998	37.944631000000001	45.042126000000003	45.026597000000002	0103000020E6100000010000000500000010035DFB02F64240FB95CE876783464010035DFB02F64240D927806264854640D6E429ABE9F84240D927806264854640D6E429ABE9F84240FB95CE876783464010035DFB02F64240FB95CE8767834640
4961	Новоукраинский	2	20	433	38.028407999999999	38.071948999999996	44.905926999999998	44.884715999999997	0103000020E61000000100000005000000EE7893DFA2034340BC1FB75F3E714640EE7893DFA20343401DC87A6AF57346406DFDF49F350943401DC87A6AF57346406DFDF49F35094340BC1FB75F3E714640EE7893DFA2034340BC1FB75F3E714640
50887	Новотроицкий	2	20	433	38.000425	38.037489999999998	45.046526999999998	45.022092999999998	0103000020E61000000100000005000000E78C28ED0D0043403A3C84F1D3824640E78C28ED0D004340C4B0C398F4854640A9F6E978CC044340C4B0C398F4854640A9F6E978CC0443403A3C84F1D3824640E78C28ED0D0043403A3C84F1D3824640
45397	Новопокровское	2	20	433	37.643991999999997	37.662846999999999	45.053665000000002	45.030183999999998	0103000020E610000001000000050000005C7171546ED24240656EBE11DD8346405C7171546ED242404DF8A57EDE86464038A0A52BD8D442404DF8A57EDE86464038A0A52BD8D44240656EBE11DD8346405C7171546ED24240656EBE11DD834640
50865	Новомихайловский	2	20	433	37.68862	37.694648000000001	45.043303999999999	45.038514999999997	0103000020E610000001000000050000008EAF3DB324D84240E5B33C0FEE8446408EAF3DB324D842409BE447FC8A854640AC1DC539EAD842409BE447FC8A854640AC1DC539EAD84240E5B33C0FEE8446408EAF3DB324D84240E5B33C0FEE844640
4715	Новокрымский	2	20	433	37.788485999999999	37.804332000000002	44.942431999999997	44.926938999999997	0103000020E610000001000000050000004BADF71BEDE442408731E9EFA57646404BADF71BEDE44240185A9D9CA17846402A90D959F4E64240185A9D9CA17846402A90D959F4E642408731E9EFA57646404BADF71BEDE442408731E9EFA5764640
50453	Нижнебаканская	2	20	433	37.837587999999997	37.893543999999999	44.877333	44.856915999999998	0103000020E61000000100000005000000D2C2651536EB4240A6B5696CAF6D4640D2C2651536EB4240CD599F724C704640BDC458A65FF24240CD599F724C704640BDC458A65FF24240A6B5696CAF6D4640D2C2651536EB4240A6B5696CAF6D4640
5599	Нижнебаканская	2	20	433	37.837587999999997	37.893543999999999	44.877333	44.856915999999998	0103000020E61000000100000005000000D2C2651536EB4240A6B5696CAF6D4640D2C2651536EB4240CD599F724C704640BDC458A65FF24240CD599F724C704640BDC458A65FF24240A6B5696CAF6D4640D2C2651536EB4240A6B5696CAF6D4640
4224	Непиль	2	20	433	37.733176999999998	37.742519000000001	45.056007999999999	45.051321999999999	0103000020E61000000100000005000000F69672BED8DD42405CC823B891864640F69672BED8DD42403D2828452B8746404ED4D2DC0ADF42403D2828452B8746404ED4D2DC0ADF42405CC823B891864640F69672BED8DD42405CC823B891864640
5706	Неберджаевская	2	20	433	37.879548	37.911977	44.83869	44.814346	0103000020E6100000010000000500000090A1630795F0424070D05E7D3C68464090A1630795F04240BABDA4315A6B464023DA8EA9BBF44240BABDA4315A6B464023DA8EA9BBF4424070D05E7D3C68464090A1630795F0424070D05E7D3C684640
4819	Молдаванское	2	20	433	37.855877	37.886699	44.954315999999999	44.935701000000002	0103000020E610000001000000050000000533A6608DED4240D1EAE40CC57746400533A6608DED42405706D506277A4640AD32535A7FF142405706D506277A4640AD32535A7FF14240D1EAE40CC57746400533A6608DED4240D1EAE40CC5774640
5252	Могукоровский	2	20	433	38.189081000000002	38.214925000000001	45.162697999999999	45.145860999999996	0103000020E61000000100000005000000C2A563CE331843408461C092AB924640C2A563CE33184340F38FBE49D3944640E10B93A9821B4340F38FBE49D3944640E10B93A9821B43408461C092AB924640C2A563CE331843408461C092AB924640
5079	Мерчанское	2	20	433	38.121400999999999	38.137768999999999	44.960095000000003	44.942157999999999	0103000020E61000000100000005000000D15966118A0F434017D522A298784640D15966118A0F4340CD069964E47A464089B3226AA2114340CD069964E47A464089B3226AA211434017D522A298784640D15966118A0F434017D522A298784640
50778	Ленинский	2	20	433	37.891199	37.897820000000003	44.920563999999999	44.912450999999997	0103000020E610000001000000050000002C9D0FCF12F24240EB19C231CB7446402C9D0FCF12F24240FEEF880AD5754640EDD808C4EBF24240FEEF880AD5754640EDD808C4EBF24240EB19C231CB7446402C9D0FCF12F24240EB19C231CB744640
5316	Кувичинский	2	20	433	38.173063999999997	38.199123999999998	45.080477999999999	45.053199999999997	0103000020E61000000100000005000000B60E0EF626164340D712F241CF864640B60E0EF6261643401406651A4D8A4640A2EC2DE57C1943401406651A4D8A4640A2EC2DE57C194340D712F241CF864640B60E0EF626164340D712F241CF864640
4110	Кубанская Колонка	2	20	433	37.665604999999999	37.683455000000002	45.097253000000002	45.070995000000003	0103000020E61000000100000005000000EC866D8B32D54240FB96395D16894640EC866D8B32D542400D384BC9728C4640D3A414747BD742400D384BC9728C4640D3A414747BD74240FB96395D16894640EC866D8B32D54240FB96395D16894640
2380	Крымск	2	20	433	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
50253	Крымск	2	20	433	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
50291	Красный	2	20	433	38.038899999999998	38.056462000000003	44.994736000000003	44.964661999999997	0103000020E610000001000000050000003EE8D9ACFA044340D3D85E0B7A7B46403EE8D9ACFA044340B2135E82537F4640BFBB95253A074340B2135E82537F4640BFBB95253A074340D3D85E0B7A7B46403EE8D9ACFA044340D3D85E0B7A7B4640
3823	Красная Батарея	2	20	433	37.773484000000003	37.806192000000003	45.120319000000002	45.081108999999998	0103000020E6100000010000000500000059FD118601E34240A4349BC7618A464059FD118601E34240310BED9C668F4640FF25A94C31E74240310BED9C668F4640FF25A94C31E74240A4349BC7618A464059FD118601E34240A4349BC7618A4640
49498	Киевское	2	20	433	37.867896999999999	37.908662	45.063859000000001	45.010688000000002	0103000020E61000000100000005000000F4A5B73F17EF4240D63A71395E814640F4A5B73F17EF424013471E882C884640198F52094FF4424013471E882C884640198F52094FF44240D63A71395E814640F4A5B73F17EF4240D63A71395E814640
3741	Кеслерово	2	20	433	37.807315000000003	37.838881000000001	45.076348000000003	45.050545	0103000020E61000000100000005000000FE48111956E74240F8FC304278864640FE48111956E74240B98E71C5C58946402E1EDE7360EB4240B98E71C5C58946402E1EDE7360EB4240F8FC304278864640FE48111956E74240F8FC304278864640
50878	Западный	2	20	433	38.054206999999998	38.064134000000003	45.152782999999999	45.144316000000003	0103000020E610000001000000050000006D1B4641F006434010255AF2789246406D1B4641F00643404031B2648E934640E547FC8A350843404031B2648E934640E547FC8A3508434010255AF2789246406D1B4641F006434010255AF278924640
50678	Евсеевский	2	20	433	38.126072999999998	38.177573000000002	45.057746999999999	45.033636000000001	0103000020E610000001000000050000004DF4F92823104340F0FB372F4E8446404DF4F928231043409738F2406487464089D349B6BA1643409738F2406487464089D349B6BA164340F0FB372F4E8446404DF4F92823104340F0FB372F4E844640
4663	Даманка	2	20	433	37.777338	37.799832000000002	44.977555000000002	44.962040000000002	0103000020E6100000010000000500000012F8C3CF7FE34240D0B87020247B464012F8C3CF7FE342404985B185207D4640AB251DE560E642404985B185207D4640AB251DE560E64240D0B87020247B464012F8C3CF7FE34240D0B87020247B4640
3998	Гладковская	2	20	433	37.717967999999999	37.735008999999998	44.992046000000002	44.978071999999997	0103000020E610000001000000050000008AC91B60E6DB424010919A76317D46408AC91B60E6DB42405610035DFB7E464001A260C614DE42405610035DFB7E464001A260C614DE424010919A76317D46408AC91B60E6DB424010919A76317D4640
49466	Гвардейское	2	20	433	37.867780000000003	37.880868999999997	45.129978999999999	45.125413000000002	0103000020E61000000100000005000000BB0F406A13EF424023BF7E880D904640BB0F406A13EF42405915E126A3904640B587BD50C0F042405915E126A3904640B587BD50C0F0424023BF7E880D904640BB0F406A13EF424023BF7E880D904640
4280	Варениковская	2	20	433	37.603478000000003	37.671641999999999	45.137590000000003	45.098481	0103000020E6100000010000000500000081ED60C43ECD4240812381069B8C464081ED60C43ECD4240DA20938C9C9146405D4F745DF8D54240DA20938C9C9146405D4F745DF8D54240812381069B8C464081ED60C43ECD4240812381069B8C4640
50421	Варениковская	2	20	433	37.603478000000003	37.671641999999999	45.137590000000003	45.098481	0103000020E6100000010000000500000081ED60C43ECD4240812381069B8C464081ED60C43ECD4240DA20938C9C9146405D4F745DF8D54240DA20938C9C9146405D4F745DF8D54240812381069B8C464081ED60C43ECD4240812381069B8C4640
45687	Армянский	2	20	433	37.984363000000002	38.003712999999998	44.868633000000003	44.849567	0103000020E610000001000000050000003C32569BFFFD42406361889CBE6C46403C32569BFFFD4240FA9CBB5D2F6F4640F7C8E6AA79004340FA9CBB5D2F6F4640F7C8E6AA790043406361889CBE6C46403C32569BFFFD42406361889CBE6C4640
4075	Адагум	2	20	433	37.693201999999999	37.774768999999999	45.133977999999999	45.074393999999998	0103000020E61000000100000005000000CAC2D7D7BAD8424062821ABE85894640CAC2D7D7BAD842401631EC3026914640317A6EA12BE342401631EC3026914640317A6EA12BE3424062821ABE85894640CAC2D7D7BAD8424062821ABE85894640
50387	отделение N5 совхоза Новосергиеский	2	20	98	39.674650999999997	40.434195000000003	46.595480000000002	46.207191000000002	0103000020E610000001000000050000005A9BC6F65AD643404583143C851A47405A9BC6F65AD6434007B64AB0384C47401A8BA6B39337444007B64AB0384C47401A8BA6B3933744404583143C851A47405A9BC6F65AD643404583143C851A4740
50245	отделение N1 Совхоза Новосергиевский	2	20	98	39.674650999999997	40.434195000000003	46.595480000000002	46.207191000000002	0103000020E610000001000000050000005A9BC6F65AD643404583143C851A47405A9BC6F65AD6434007B64AB0384C47401A8BA6B39337444007B64AB0384C47401A8BA6B3933744404583143C851A47405A9BC6F65AD643404583143C851A4740
748	Шевченковское	2	20	98	40.218474000000001	40.317055000000003	46.298023999999998	46.280966999999997	0103000020E610000001000000050000005E83BEF4F61B4440AB2006BAF62347405E83BEF4F61B444028B682A62526474043041C429528444028B682A62526474043041C4295284440AB2006BAF62347405E83BEF4F61B4440AB2006BAF6234740
48855	Темп	2	20	98	39.846131	39.855787999999997	46.257860999999998	46.250433000000001	0103000020E61000000100000005000000DE9046054EEC43406A6B44300E204740DE9046054EEC4340F9F4D89601214740952710768AED4340F9F4D89601214740952710768AED43406A6B44300E204740DE9046054EEC43406A6B44300E204740
50316	Тверской	2	20	98	40.232621999999999	40.283296	46.420827000000003	46.409066000000003	0103000020E61000000100000005000000412AC58EC61D4440E9F351465C344740412AC58EC61D44400C23BDA8DD354740378B170B432444400C23BDA8DD354740378B170B43244440E9F351465C344740412AC58EC61D4440E9F351465C344740
62089	Сиротино	2	20	98	40.214548000000001	40.232379999999999	46.486707000000003	46.469672000000003	0103000020E610000001000000050000000BB6114F761B444068EC4B361E3C47400BB6114F761B4440FDDD3B6A4C3E47404B1FBAA0BE1D4440FDDD3B6A4C3E47404B1FBAA0BE1D444068EC4B361E3C47400BB6114F761B444068EC4B361E3C4740
50275	Сборный	2	20	98	39.755220999999999	39.787748999999998	46.247728000000002	46.241190000000003	0103000020E610000001000000050000004F20EC14ABE04340A60F5D50DF1E47404F20EC14ABE04340D926158DB51F4740753A90F5D4E44340D926158DB51F4740753A90F5D4E44340A60F5D50DF1E47404F20EC14ABE04340A60F5D50DF1E4740
1428	Решетиловский	2	20	98	40.147623000000003	40.159122000000004	46.248787999999998	46.241307999999997	0103000020E6100000010000000500000097917A4FE5124440AF21382EE31E474097917A4FE512444091D10149D81F47407D09151C5E14444091D10149D81F47407D09151C5E144440AF21382EE31E474097917A4FE5124440AF21382EE31E4740
126	Октябрьская	2	20	98	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
1234	Обильный	2	20	98	39.923780999999998	39.935566999999999	46.251710000000003	46.246144999999999	0103000020E6100000010000000500000045D5AF743EF643407689EAAD811F474045D5AF743EF64340C009850838204740C11BD2A8C0F74340C009850838204740C11BD2A8C0F743407689EAAD811F474045D5AF743EF643407689EAAD811F4740
50335	Новосергиевская	2	20	98	39.936698999999997	39.958286000000001	46.479551999999998	46.460715	0103000020E610000001000000050000001399B9C0E5F7434069E388B5F83A47401399B9C0E5F743409E5DBEF5613D47407A1B9B1DA9FA43409E5DBEF5613D47407A1B9B1DA9FA434069E388B5F83A47401399B9C0E5F7434069E388B5F83A4740
1484	Новопашковская	2	20	98	40.059148	40.103389999999997	46.416733000000001	46.402236000000002	0103000020E61000000100000005000000D9CF6229920744400EA320787C334740D9CF622992074440FD14C78157354740E15D2EE23B0D4440FD14C78157354740E15D2EE23B0D44400EA320787C334740D9CF6229920744400EA320787C334740
2056	Кугоейская	2	20	98	40.081732000000002	40.110604000000002	46.538882999999998	46.525846000000001	0103000020E61000000100000005000000B284B531760A4440C05DF6EB4E434740B284B531760A444068AF3E1EFA44474045679945280E444068AF3E1EFA44474045679945280E4440C05DF6EB4E434740B284B531760A4440C05DF6EB4E434740
50471	Крыловская	2	20	98	39.924912999999997	40.008159999999997	46.345405999999997	46.290233999999998	0103000020E610000001000000050000009752978C63F64340F8174163262547409752978C63F64340CCEB8843362C474053910A630B014440CCEB8843362C474053910A630B014440F8174163262547409752978C63F64340F817416326254740
48908	Ковалевка	2	20	98	40.086447999999997	40.094614	46.252426999999997	46.242187000000001	0103000020E61000000100000005000000FD6662BA100B44401842CEFBFF1E4740FD6662BA100B44404ED026874F20474033DFC14F1C0C44404ED026874F20474033DFC14F1C0C44401842CEFBFF1E4740FD6662BA100B44401842CEFBFF1E4740
49064	Ключевой	2	20	98	39.882610999999997	39.896175999999997	46.486694999999997	46.473762000000001	0103000020E61000000100000005000000800BB265F9F04340350BB43BA43C4740800BB265F9F04340381092054C3E4740E4BA29E5B5F24340381092054C3E4740E4BA29E5B5F24340350BB43BA43C4740800BB265F9F04340350BB43BA43C4740
50307	Калинин	2	20	98	40.163451999999999	40.207172999999997	46.536087999999999	46.527607000000003	0103000020E610000001000000050000009F3BC1FEEB14444002124DA0884347409F3BC1FEEB14444097E315889E4447409ECE15A5841A444097E315889E4447409ECE15A5841A444002124DA0884347409F3BC1FEEB14444002124DA088434740
49122	Ириновка	2	20	98	39.998933999999998	40.015158	46.543495	46.536082	0103000020E61000000100000005000000656EBE11DDFF4340B5FCC0559E444740656EBE11DDFF43400F45813E91454740EA2285B2F00144400F45813E91454740EA2285B2F0014440B5FCC0559E444740656EBE11DDFF4340B5FCC0559E444740
48888	Запрудный	2	20	98	39.998475999999997	40.005555000000001	46.255423999999998	46.243882999999997	0103000020E61000000100000005000000A2EBC20FCEFF43407286E28E371F4740A2EBC20FCEFF4340874ECFBBB120474026AAB706B6004440874ECFBBB120474026AAB706B60044407286E28E371F4740A2EBC20FCEFF43407286E28E371F4740
48983	Грузское	2	20	98	40.192117000000003	40.200812999999997	46.412297000000002	46.407525	0103000020E61000000100000005000000B900344A97184440B5A679C729344740B900344A97184440959EE925C63447404ACE893DB4194440959EE925C63447404ACE893DB4194440B5A679C729344740B900344A97184440B5A679C729344740
1922	Водораздельный	2	20	98	40.018805	40.027591000000001	46.474984999999997	46.468586000000002	0103000020E610000001000000050000002A00C6336802444086AE44A0FA3B47402A00C63368024440978BF84ECC3C4740FC54151A88034440978BF84ECC3C4740FC54151A8803444086AE44A0FA3B47402A00C6336802444086AE44A0FA3B4740
32734	Элитный	2	20	1322	38.117485000000002	38.144641	45.345799999999997	45.328401999999997	0103000020E61000000100000005000000A2629CBF090F434072F8A41309AA4640A2629CBF090F4340787AA52C43AC46409354A69883124340787AA52C43AC46409354A6988312434072F8A41309AA4640A2629CBF090F434072F8A41309AA4640
15828	Чигрина	2	20	1322	38.165005999999998	38.175417000000003	45.243364999999997	45.234149000000002	0103000020E6100000010000000500000067D2A6EA1E15434010B22C98F89D464067D2A6EA1E154340DAFE9595269F4640CB14731074164340DAFE9595269F4640CB1473107416434010B22C98F89D464067D2A6EA1E15434010B22C98F89D4640
16519	Чебургольская	2	20	1322	38.077500999999998	38.141362000000001	45.574348999999998	45.542985000000002	0103000020E610000001000000050000002234828DEB094340FA9B508880C546402234828DEB094340C2BE9D4484C94640D672672618124340C2BE9D4484C94640D672672618124340FA9B508880C546402234828DEB094340FA9B508880C54640
15589	Трудобеликовский	2	20	1322	38.116461000000001	38.174284999999998	45.313198999999997	45.25235	0103000020E610000001000000050000003621AD31E80E4340A3923A014DA046403621AD31E80E4340E811A3E716A8464078978BF84E164340E811A3E716A8464078978BF84E164340A3923A014DA046403621AD31E80E4340A3923A014DA04640
15901	Тиховский	2	20	1322	38.208393999999998	38.233502000000001	45.199171999999997	45.185482999999998	0103000020E61000000100000005000000605793A7AC1A4340637B2DE8BD974640605793A7AC1A4340B323D5777E9946407AC6BE64E31D4340B323D5777E9946407AC6BE64E31D4340637B2DE8BD974640605793A7AC1A4340637B2DE8BD974640
17060	Старонижестеблиевская	2	20	1322	38.407164999999999	38.468609000000001	45.412736000000002	45.359189000000001	0103000020E61000000100000005000000B58993FB1D3443409E0AB8E7F9AD4640B58993FB1D344340E1F08288D4B446403ECE3461FB3B4340E1F08288D4B446403ECE3461FB3B43409E0AB8E7F9AD4640B58993FB1D3443409E0AB8E7F9AD4640
16649	Староджерелиевская	2	20	1322	38.265616999999999	38.313901000000001	45.485872999999998	45.446626000000002	0103000020E610000001000000050000007D21E4BCFF2143408BC56F0A2BB946407D21E4BCFF2143403481221631BE4640429770E82D2843403481221631BE4640429770E82D2843408BC56F0A2BB946407D21E4BCFF2143408BC56F0A2BB94640
15385	Рисоопытный	2	20	1322	38.301253000000003	38.319766999999999	45.236117	45.219295000000002	0103000020E61000000100000005000000346953758F2643409296CADB119C4640346953758F264340CB83F414399E464086AB0320EE284340CB83F414399E464086AB0320EE2843409296CADB119C4640346953758F2643409296CADB119C4640
16597	Протоцкие	2	20	1322	38.073	38.087535000000003	45.543061000000002	45.504151	0103000020E61000000100000005000000D34D621058094340739F1C0588C04640D34D621058094340D55DD90583C54640B020CD58340B4340D55DD90583C54640B020CD58340B4340739F1C0588C04640D34D621058094340739F1C0588C04640
16763	Протичка	2	20	1322	38.062094999999999	38.085002000000003	45.393003999999998	45.360754	0103000020E61000000100000005000000601F9DBAF20743405AF3E32F2DAE4640601F9DBAF20743403D997FF44DB246401C0C7558E10A43403D997FF44DB246401C0C7558E10A43405AF3E32F2DAE4640601F9DBAF20743405AF3E32F2DAE4640
50640	Прикубанский	2	20	1322	38.452528999999998	38.516696000000003	45.121532999999999	45.096839000000003	0103000020E61000000100000005000000ECBE6378EC3943401AFD6838658C4640ECBE6378EC3943404031B2648E8F4640ADFC3218234243404031B2648E8F4640ADFC3218234243401AFD6838658C4640ECBE6378EC3943401AFD6838658C4640
14023	Полтавская	2	20	1322	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
46110	Подлесный	2	20	1322	38.328480999999996	38.340743000000003	45.206462000000002	45.196357999999996	0103000020E61000000100000005000000BE2D58AA0B2A43406B274A4222994640BE2D58AA0B2A4340F2EEC8586D9A4640A4AB74779D2B4340F2EEC8586D9A4640A4AB74779D2B43406B274A4222994640BE2D58AA0B2A43406B274A4222994640
47108	Первомайский	2	20	1322	38.298279999999998	38.318258	45.184047999999997	45.171906	0103000020E610000001000000050000008386FE092E2643403BFE0B04019646408386FE092E264340757286E28E9746405ED89AADBC284340757286E28E9746405ED89AADBC2843403BFE0B04019646408386FE092E2643403BFE0B0401964640
50376	Октябрьский	2	20	1322	38.281858999999997	38.306868000000001	45.241283000000003	45.227345	0103000020E61000000100000005000000A88AA9F4132443405EF415A4199D4640A88AA9F413244340570A815CE29E46402F185C7347274340570A815CE29E46402F185C73472743405EF415A4199D4640A88AA9F4132443405EF415A4199D4640
14725	Новомышастовская	2	20	1322	38.541947999999998	38.610408	45.217606000000004	45.178851000000002	0103000020E61000000100000005000000F910548D5E454340AFEDED96E4964640F910548D5E454340EAB46E83DA9B4640BF9B6ED9214E4340EAB46E83DA9B4640BF9B6ED9214E4340AFEDED96E4964640F910548D5E454340AFEDED96E4964640
45742	Мирный	2	20	1322	38.321626999999999	38.332496999999996	45.255172999999999	45.244259	0103000020E610000001000000050000005B41D3122B294340786000E1439F46405B41D3122B2943403EE94482A9A046405182FE428F2A43403EE94482A9A046405182FE428F2A4340786000E1439F46405B41D3122B294340786000E1439F4640
16281	Марьянская	2	20	1322	38.602746000000003	38.677584000000003	45.120776999999997	45.089159000000002	0103000020E61000000100000005000000BDE5EAC7264D43407192E68F698B4640BDE5EAC7264D4340F38DE89E758F46407D259012BB564340F38DE89E758F46407D259012BB5643407192E68F698B4640BDE5EAC7264D43407192E68F698B4640
15924	Крикуна	2	20	1322	38.198971	38.230026000000002	45.271186	45.257120999999998	0103000020E610000001000000050000001CEDB8E177194340B20E4757E9A046401CEDB8E17719434008910C39B6A24640679DF17D711D434008910C39B6A24640679DF17D711D4340B20E4757E9A046401CEDB8E177194340B20E4757E9A04640
15524	Красный Лес	2	20	1322	38.401333999999999	38.412069000000002	45.185242000000002	45.175719000000001	0103000020E61000000100000005000000ED629AE95E3343409624CFF57D964640ED629AE95E3343403EEC8502B697464004594FADBE3443403EEC8502B697464004594FADBE3443409624CFF57D964640ED629AE95E3343409624CFF57D964640
15087	Краснодарский	2	20	1322	38.309922	38.319471	45.288384999999998	45.279234000000002	0103000020E61000000100000005000000CC272B86AB27434034F790F0BDA34640CC272B86AB27434017D4B7CCE9A446409D82FC6CE428434017D4B7CCE9A446409D82FC6CE428434034F790F0BDA34640CC272B86AB27434034F790F0BDA34640
46052	Колос	2	20	1322	38.340653000000003	38.353337000000003	45.15558	45.142707999999999	0103000020E6100000010000000500000064247B849A2B4340547078414492464064247B849A2B4340B2F4A10BEA934640BFBB95253A2D4340B2F4A10BEA934640BFBB95253A2D4340547078414492464064247B849A2B43405470784144924640
16838	Казачий Ерик	2	20	1322	38.086959999999998	38.10286	45.416671000000001	45.410001999999999	0103000020E61000000100000005000000B3075A81210B4340B5A50EF27AB44640B3075A81210B43408718AF7955B54640850838842A0D43408718AF7955B54640850838842A0D4340B5A50EF27AB44640B3075A81210B4340B5A50EF27AB44640
50416	Ивановская	2	20	1322	38.425113000000003	38.496977999999999	45.295645	45.249271999999998	0103000020E610000001000000050000005F0D501A6A3643407DE71725E89F46405F0D501A6A364340EB1C03B2D7A546406E6AA0F99C3F4340EB1C03B2D7A546406E6AA0F99C3F43407DE71725E89F46405F0D501A6A3643407DE71725E89F4640
46321	Ивановская	2	20	1322	38.425113000000003	38.496977999999999	45.295645	45.249271999999998	0103000020E610000001000000050000005F0D501A6A3643407DE71725E89F46405F0D501A6A364340EB1C03B2D7A546406E6AA0F99C3F4340EB1C03B2D7A546406E6AA0F99C3F43407DE71725E89F46405F0D501A6A3643407DE71725E89F4640
16814	Заветное	2	20	1322	38.052087	38.078507000000002	45.354179999999999	45.31709	0103000020E61000000100000005000000FCC56CC9AA064340BFF1B56796A84640FCC56CC9AA064340DA722EC555AD4640E8C072840C0A4340DA722EC555AD4640E8C072840C0A4340BFF1B56796A84640FCC56CC9AA064340BFF1B56796A84640
40471	Восточный	2	20	1322	38.465052	38.483916999999998	45.356465999999998	45.347675000000002	0103000020E610000001000000050000003E78EDD2863B43408351499D80AC46403E78EDD2863B434066118AADA0AD46403D7D04FEF03D434066118AADA0AD46403D7D04FEF03D43408351499D80AC46403E78EDD2863B43408351499D80AC4640
45847	Водный	2	20	1322	38.350758999999996	38.363030000000002	45.284605999999997	45.276380000000003	0103000020E610000001000000050000008AE3C0ABE52C43405EA27A6B60A346408AE3C0ABE52C4340681F2BF86DA44640C3BB5CC4772E4340681F2BF86DA44640C3BB5CC4772E43405EA27A6B60A346408AE3C0ABE52C43405EA27A6B60A34640
50257	Белозерный	2	20	1322	38.662689999999998	38.688983999999998	45.085633000000001	45.070771999999998	0103000020E6100000010000000500000070B1A206D35443407BBC900E0F89464070B1A206D3544340AC3AAB05F68A4640CFBBB1A030584340AC3AAB05F68A4640CFBBB1A0305843407BBC900E0F89464070B1A206D35443407BBC900E0F894640
50785	Чехрак	2	20	6957	40.369103000000003	40.398828000000002	44.943286999999998	44.933289000000002	0103000020E6100000010000000500000081ED60C43E2F4440B85B92037677464081ED60C43E2F4440F8DEDFA0BD784640535DC0CB0C334440F8DEDFA0BD784640535DC0CB0C334440B85B92037677464081ED60C43E2F4440B85B920376774640
46308	Комсомольский	2	20	6957	40.418411999999996	40.425606999999999	44.905582000000003	44.899856	0103000020E61000000100000005000000812040868E354440008E3D7B2E734640812040868E35444053EC681CEA7346406EF9484A7A36444053EC681CEA7346406EF9484A7A364440008E3D7B2E734640812040868E354440008E3D7B2E734640
46573	Вольное	2	20	6957	40.677207000000003	40.726326999999998	44.639851999999998	44.596556	0103000020E61000000100000005000000A7CF0EB8AE564440C51D6FF25B4C4640A7CF0EB8AE564440DD239BABE6514640D4997B48F85C4440DD239BABE6514640D4997B48F85C4440C51D6FF25B4C4640A7CF0EB8AE564440C51D6FF25B4C4640
49337	Сергиевская	2	20	1193	39.179788000000002	39.220013999999999	45.436191999999998	45.413696999999999	0103000020E610000001000000050000004C1B0E4B0397434006BAF605F4B446404C1B0E4B039743406F63B323D5B74640C154336B299C43406F63B323D5B74640C154336B299C434006BAF605F4B446404C1B0E4B0397434006BAF605F4B44640
49211	Раздольная	2	20	1193	39.515442999999998	39.619593999999999	45.389960000000002	45.362735999999998	0103000020E61000000100000005000000DFF94509FAC143407A8A1C226EAE4640DFF94509FAC14340C45F9335EAB146401F662FDB4ECF4340C45F9335EAB146401F662FDB4ECF43407A8A1C226EAE4640DFF94509FAC143407A8A1C226EAE4640
12571	Платнировская	2	20	1193	39.349138000000004	39.417509000000003	45.410305999999999	45.375368000000002	0103000020E610000001000000050000003BE5D18DB0AC434083FB010F0CB046403BE5D18DB0AC434021AD31E884B44640916456EF70B5434021AD31E884B44640916456EF70B5434083FB010F0CB046403BE5D18DB0AC434083FB010F0CB04640
50465	Платнировская	2	20	1193	39.349138000000004	39.417509000000003	45.410305999999999	45.375368000000002	0103000020E610000001000000050000003BE5D18DB0AC434083FB010F0CB046403BE5D18DB0AC434021AD31E884B44640916456EF70B5434021AD31E884B44640916456EF70B5434083FB010F0CB046403BE5D18DB0AC434083FB010F0CB04640
13330	Новоберезанский	2	20	1193	39.443102000000003	39.461956999999998	45.702767999999999	45.687710000000003	0103000020E610000001000000050000006765FB90B7B84340EB909BE106D846406765FB90B7B843407156444DF4D9464042942F6821BB43407156444DF4D9464042942F6821BB4340EB909BE106D846406765FB90B7B84340EB909BE106D84640
50904	Нижний	2	20	1193	39.196981000000001	39.248005999999997	45.412761000000003	45.387624000000002	0103000020E61000000100000005000000797764AC369943408692C9A99DB14640797764AC369943403A083A5AD5B446401B9B1DA9BE9F43403A083A5AD5B446401B9B1DA9BE9F43408692C9A99DB14640797764AC369943408692C9A99DB14640
47524	Мирный	2	20	1193	39.545949999999998	39.559244999999997	45.498812999999998	45.489077000000002	0103000020E6100000010000000500000027A089B0E1C54340E71C3C139ABE464027A089B0E1C54340EAE8B81AD9BF4640CBB9145795C74340EAE8B81AD9BF4640CBB9145795C74340E71C3C139ABE464027A089B0E1C54340E71C3C139ABE4640
50687	Левченко	2	20	1193	39.257230999999997	39.273966999999999	45.404111	45.394764000000002	0103000020E61000000100000005000000394206F2ECA04340AFD172A087B24640394206F2ECA04340187AC4E8B9B346407497C45911A34340187AC4E8B9B346407497C45911A34340AFD172A087B24640394206F2ECA04340AFD172A087B24640
11444	Кореновск	2	20	1193	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
50348	Кореновск	2	20	1193	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
50298	Казачий	2	20	1193	39.404626999999998	39.465981999999997	45.396763999999997	45.372214999999997	0103000020E610000001000000050000000F0A4AD1CAB34340520ABABDA4AF46400F0A4AD1CAB34340751DAA29C9B246402843554CA5BB4340751DAA29C9B246402843554CA5BB4340520ABABDA4AF46400F0A4AD1CAB34340520ABABDA4AF4640
50474	Казачий	2	20	1193	39.115566999999999	39.669226000000002	45.814667999999998	45.306694999999998	0103000020E6100000010000000500000098BF42E6CA8E4340616C21C841A7464098BF42E6CA8E4340828C800A47E8464003D19332A9D54340828C800A47E8464003D19332A9D54340616C21C841A7464098BF42E6CA8E4340616C21C841A74640
13551	Казаче-Малеваный	2	20	1193	39.525576000000001	39.573132999999999	45.536116999999997	45.527169999999998	0103000020E6100000010000000500000000C8091346C3434056B77A4E7AC3464000C8091346C3434031EA5A7B9FC4464012A1116C5CC9434031EA5A7B9FC4464012A1116C5CC9434056B77A4E7AC3464000C8091346C3434056B77A4E7AC34640
50622	Журавский	2	20	1193	39.294386000000003	39.373832999999998	45.59384	45.579970000000003	0103000020E610000001000000050000003C33C170AEA54340A054FB743CCA46403C33C170AEA543404087F9F202CC464031957EC2D9AF43404087F9F202CC464031957EC2D9AF4340A054FB743CCA46403C33C170AEA54340A054FB743CCA4640
13523	Журавская	2	20	1193	39.480345999999997	39.640794	45.588509999999999	45.567106000000003	0103000020E61000000100000005000000D8614CFA7BBD4340C5AEEDED96C84640D8614CFA7BBD43403AAFB14B54CB46408CBCAC8905D243403AAFB14B54CB46408CBCAC8905D24340C5AEEDED96C84640D8614CFA7BBD4340C5AEEDED96C84640
50583	Дядьковская	2	20	1193	39.164749999999998	39.214112	45.568922999999998	45.534115999999997	0103000020E610000001000000050000000C022B87169543409A22C0E95DC446400C022B87169543409A780778D2C8464030D7A205689B43409A780778D2C8464030D7A205689B43409A22C0E95DC446400C022B87169543409A22C0E95DC44640
12907	Дядьковская	2	20	1193	39.164749999999998	39.214112	45.568922999999998	45.534115999999997	0103000020E610000001000000050000000C022B87169543409A22C0E95DC446400C022B87169543409A780778D2C8464030D7A205689B43409A780778D2C8464030D7A205689B43409A22C0E95DC446400C022B87169543409A22C0E95DC44640
12383	Бураковский	2	20	1193	39.558427000000002	39.657924999999999	45.471204999999998	45.449154999999998	0103000020E61000000100000005000000091A33897AC74340DDEA39E97DB94640091A33897AC74340185B087250BC4640431CEBE236D44340185B087250BC4640431CEBE236D44340DDEA39E97DB94640091A33897AC74340DDEA39E97DB94640
13245	Братковское	2	20	1193	39.269862000000003	39.403190000000002	45.645631000000002	45.631520999999999	0103000020E61000000100000005000000723788D68AA243405DDE1CAED5D04640723788D68AA2434053245F09A4D246408109DCBA9BB3434053245F09A4D246408109DCBA9BB343405DDE1CAED5D04640723788D68AA243405DDE1CAED5D04640
13047	Бабиче-Кореновский	2	20	1193	39.308416999999999	39.370482000000003	45.557381999999997	45.541122999999999	0103000020E61000000100000005000000E54350357AA74340840EBA8443C54640E54350357AA7434085B01A4B58C74640DBE044F46BAF434085B01A4B58C74640DBE044F46BAF4340840EBA8443C54640E54350357AA74340840EBA8443C54640
13367	Анапский	2	20	1193	39.470581000000003	39.510278	45.786790000000003	45.775677000000002	0103000020E610000001000000050000003B8F8AFF3BBC434034A1496249E346403B8F8AFF3BBC4340F168E388B5E4464024EF1CCA50C14340F168E388B5E4464024EF1CCA50C1434034A1496249E346403B8F8AFF3BBC434034A1496249E34640
39762	Павловский	2	20	5147	31.586822999999999	31.588529000000001	59.865541999999998	59.864700999999997	0103000020E61000000100000005000000658A39083A963F40C4E8B985AEEE4D40658A39083A963F403FA88B14CAEE4D4062BF27D6A9963F403FA88B14CAEE4D4062BF27D6A9963F40C4E8B985AEEE4D40658A39083A963F40C4E8B985AEEE4D40
50580	Ленинский	2	20	7084	39.079616000000001	39.081583999999999	45.022576999999998	45.021762000000003	0103000020E61000000100000005000000821E6ADB308A4340D525E318C9824640821E6ADB308A434026529ACDE38246403DF03158718A434026529ACDE38246403DF03158718A4340D525E318C9824640821E6ADB308A4340D525E318C9824640
40520	станция Челбасская	2	20	1033	39.333407999999999	39.410637000000001	45.996552999999999	45.959702	0103000020E61000000100000005000000C51C041DADAA4340F1F3DF83D7FA4640C51C041DADAA434087DD770C8FFF464087C3D2C08FB4434087DD770C8FFF464087C3D2C08FB44340F1F3DF83D7FA4640C51C041DADAA4340F1F3DF83D7FA4640
50241	ст.Придорожная	2	20	1033	38.910859000000002	39.042659999999998	46.040168000000001	45.948304	0103000020E6100000010000000500000036221807977443403F55850662F946403622180797744340412C9B3924054740766C04E275854340412C9B3924054740766C04E2758543403F55850662F9464036221807977443403F55850662F94640
10778	Челбасская	2	20	1033	39.333407999999999	39.410637000000001	45.996552999999999	45.959702	0103000020E61000000100000005000000C51C041DADAA4340F1F3DF83D7FA4640C51C041DADAA434087DD770C8FFF464087C3D2C08FB4434087DD770C8FFF464087C3D2C08FB44340F1F3DF83D7FA4640C51C041DADAA4340F1F3DF83D7FA4640
50722	Ударный	2	20	1033	38.994222999999998	39.020381999999998	46.207652000000003	46.196461999999997	0103000020E610000001000000050000002BF702B3427F43401074B4AA251947402BF702B3427F434079793A57941A4740AAB69BE09B82434079793A57941A4740AAB69BE09B8243401074B4AA251947402BF702B3427F43401074B4AA25194740
50748	Труд	2	20	1033	38.517082000000002	38.543655000000001	46.168615000000003	46.142595	0103000020E61000000100000005000000D6AC33BE2F4243405CC98E8D40124740D6AC33BE2F424340BA4E232D9515474048A7AE7C96454340BA4E232D9515474048A7AE7C964543405CC98E8D40124740D6AC33BE2F4243405CC98E8D40124740
50807	Сухие Челбасы	2	20	1033	39.140934999999999	39.211094000000003	45.984512000000002	45.967796	0103000020E610000001000000050000004EEE77280A9243408D9944BDE0FB46404EEE77280A92434081423D7D04FE4640E030D120059B434081423D7D04FE4640E030D120059B43408D9944BDE0FB46404EEE77280A9243408D9944BDE0FB4640
11040	Степной	2	20	1033	39.151805000000003	39.164183999999999	45.944387999999996	45.938904000000001	0103000020E61000000100000005000000452FA3586E934340B30A9B012EF84640452FA3586E9343400F5EBBB4E1F84640634337FB039543400F5EBBB4E1F84640634337FB03954340B30A9B012EF84640452FA3586E934340B30A9B012EF84640
10437	Стародеревянковская	2	20	1033	38.939990999999999	38.990125999999997	46.162959999999998	46.103223	0103000020E6100000010000000500000065C405A051784340F6984869360D474065C405A05178434030478FDFDB144740AB75E272BC7E434030478FDFDB144740AB75E272BC7E4340F6984869360D474065C405A051784340F6984869360D4740
50719	Средние Челбасы	2	20	1033	38.508324000000002	39.522091000000003	46.395363000000003	45.880440999999998	0103000020E61000000100000005000000CEE2C5C2104143405D876A4AB2F04640CEE2C5C210414340348639419B3247409A44BDE0D3C24340348639419B3247409A44BDE0D3C243405D876A4AB2F04640CEE2C5C2104143405D876A4AB2F04640
50758	Сладкий Лиман	2	20	1033	38.770361999999999	38.822356999999997	46.189999	46.174106999999999	0103000020E61000000100000005000000630AD6389B62434099805F2349164740630AD6389B624340E8A221E3511847407E5182FE42694340E8A221E3511847407E5182FE4269434099805F2349164740630AD6389B62434099805F2349164740
50446	Раздольный	2	20	1033	38.595109999999998	38.632111999999999	46.303316000000002	46.286292000000003	0103000020E61000000100000005000000E3C281902C4C4340A08D5C37A5244740E3C281902C4C4340412D060FD32647405FB4C70BE9504340412D060FD32647405FB4C70BE9504340A08D5C37A5244740E3C281902C4C4340A08D5C37A5244740
50304	Приютный	2	20	1033	38.707498000000001	38.722912999999998	46.205537999999997	46.192594999999997	0103000020E6100000010000000500000022FE614B8F5A4340C22FF5F3A618474022FE614B8F5A4340E90AB6114F1A4740376DC669885C4340E90AB6114F1A4740376DC669885C4340C22FF5F3A618474022FE614B8F5A4340C22FF5F3A6184740
50423	Привольная	2	20	1033	38.675077999999999	38.719940000000001	46.153128000000002	46.125594999999997	0103000020E61000000100000005000000E21FB6F46856434043C5387F13104740E21FB6F4685643400B0DC4B299134740878A71FE265C43400B0DC4B299134740878A71FE265C434043C5387F13104740E21FB6F46856434043C5387F13104740
10142	Привольная	2	20	1033	38.675077999999999	38.719940000000001	46.153128000000002	46.125594999999997	0103000020E61000000100000005000000E21FB6F46856434043C5387F13104740E21FB6F4685643400B0DC4B299134740878A71FE265C43400B0DC4B299134740878A71FE265C434043C5387F13104740E21FB6F46856434043C5387F13104740
10363	Партизанский	2	20	1033	39.020677999999997	39.037953000000002	45.936391	45.927213999999999	0103000020E6100000010000000500000093DFA293A58243405932C7F2AEF6464093DFA293A582434066A208A9DBF746407EE4D6A4DB84434066A208A9DBF746407EE4D6A4DB8443405932C7F2AEF6464093DFA293A58243405932C7F2AEF64640
50668	Орджоникидзе	2	20	1033	38.770119999999999	38.786541	46.129468000000003	46.123615000000001	0103000020E610000001000000050000006DFFCA4A93624340C425C79DD20F47406DFFCA4A9362434074F04C689210474048FB1F60AD64434074F04C689210474048FB1F60AD644340C425C79DD20F47406DFFCA4A93624340C425C79DD20F4740
9984	Новоминская	2	20	1033	38.928258999999997	38.996952999999998	46.333105000000003	46.294916999999998	0103000020E61000000100000005000000DC9BDF30D176434068041BD7BF254740DC9BDF30D17643402A91442FA32A47401553E9279C7F43402A91442FA32A47401553E9279C7F434068041BD7BF254740DC9BDF30D176434068041BD7BF254740
9683	Новодеревянковская	2	20	1033	38.711782999999997	38.780208000000002	46.336888000000002	46.302345000000003	0103000020E61000000100000005000000A46C91B41B5B4340F88DAF3DB3264740A46C91B41B5B43401A355F251F2B4740EE0912DBDD6343401A355F251F2B4740EE0912DBDD634340F88DAF3DB3264740A46C91B41B5B4340F88DAF3DB3264740
50744	Мигуты	2	20	1033	39.103206	39.147412000000003	46.163091000000001	46.148238999999997	0103000020E610000001000000050000002060ADDA358D4340F17EDC7EF91247402060ADDA358D4340CFA2772AE0144740DC847B65DE924340CFA2772AE0144740DC847B65DE924340F17EDC7EF91247402060ADDA358D4340F17EDC7EF9124740
9670	Кубанская Степь	2	20	1033	39.211804000000001	39.242158000000003	45.969467999999999	45.953386000000002	0103000020E61000000100000005000000BC94BA641C9B43406D3B6D8D08FA4640BC94BA641C9B43405F42058717FC46407E3B8908FF9E43405F42058717FC46407E3B8908FF9E43406D3B6D8D08FA4640BC94BA641C9B43406D3B6D8D08FA4640
9535	Красногвардеец	2	20	1033	39.146289000000003	39.205587000000001	46.167036000000003	46.145722999999997	0103000020E61000000100000005000000DD611399B992434033A31F0DA7124740DD611399B992434099A0866F61154740CBBDC0AC509A434099A0866F61154740CBBDC0AC509A434033A31F0DA7124740DD611399B992434033A31F0DA7124740
9000	Каневская	2	20	1033	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
50561	Бол. Челбасы	2	20	1033	39.142857999999997	39.177829000000003	46.111421	46.098579999999998	0103000020E6100000010000000500000069FCC22B499243401405FA449E0C474069FCC22B49924340378B170B430E4740E4A3C519C3964340378B170B430E4740E4A3C519C39643401405FA449E0C474069FCC22B499243401405FA449E0C4740
50792	Александровская	2	20	1033	39.048839999999998	39.085059999999999	46.229433	46.205232000000002	0103000020E610000001000000050000004A5E9D6340864340DD0BCC0A451A47404A5E9D6340864340C4CF7F0F5E1D47405019FF3EE38A4340C4CF7F0F5E1D47405019FF3EE38A4340DD0BCC0A451A47404A5E9D6340864340DD0BCC0A451A4740
50579	Албаши	2	20	1033	38.583378000000003	38.627116999999998	46.263157	46.247172999999997	0103000020E610000001000000050000005B9A5B21AC4A434023BA675DA31F47405B9A5B21AC4A4340535BEA20AF21474000E2AE5E45504340535BEA20AF21474000E2AE5E4550434023BA675DA31F47405B9A5B21AC4A434023BA675DA31F4740
8182	Старовеличковская	2	20	977	38.66057	38.748911	45.473474000000003	45.384408999999998	0103000020E61000000100000005000000FF5BC98E8D544340DFA4695034B14640FF5BC98E8D544340CFC0C8CB9ABC4640AD4ECE50DC5F4340CFC0C8CB9ABC4640AD4ECE50DC5F4340DFA4695034B14640FF5BC98E8D544340DFA4695034B14640
8637	Рогачевский	2	20	977	38.601182999999999	38.625680000000003	45.644339000000002	45.631470999999998	0103000020E61000000100000005000000A1F48590F34C4340ABAFAE0AD4D04640A1F48590F34C4340C8444AB379D2464072E1404816504340C8444AB379D2464072E1404816504340ABAFAE0AD4D04640A1F48590F34C4340ABAFAE0AD4D04640
50753	Редант	2	20	977	38.506788	38.537438000000002	45.729267	45.712699999999998	0103000020E61000000100000005000000AC00DF6DDE404340FAEDEBC039DB4640AC00DF6DDE404340A986FD9E58DD464057D0B4C4CA444340A986FD9E58DD464057D0B4C4CA444340FAEDEBC039DB4640AC00DF6DDE404340FAEDEBC039DB4640
50680	Пригибский	2	20	977	38.070332000000001	38.085144999999997	45.761676000000001	45.753507999999997	0103000020E610000001000000050000005FEE93A3000943401EA33CF372E046405FEE93A300094340F51263997EE146407E350708E60A4340F51263997EE146407E350708E60A43401EA33CF372E046405FEE93A3000943401EA33CF372E04640
50408	Поселок Гришковское	2	20	977	38.584726000000003	38.616292000000001	45.397751	45.367435	0103000020E610000001000000050000007A8F334DD84A4340F0332E1C08AF46407A8F334DD84A4340C4793881E9B24640AA6400A8E24E4340C4793881E9B24640AA6400A8E24E4340F0332E1C08AF46407A8F334DD84A4340F0332E1C08AF4640
8669	Новониколаевская	2	20	977	38.343967999999997	38.397894000000001	45.600991	45.560594000000002	0103000020E610000001000000050000006D6FB724072C4340BB2A508BC1C746406D6FB724072C43405D18E945EDCC464027A3CA30EE3243405D18E945EDCC464027A3CA30EE324340BB2A508BC1C746406D6FB724072C4340BB2A508BC1C74640
50875	Могукоровка	2	20	977	38.419319000000002	38.472372999999997	45.713315999999999	45.689397	0103000020E61000000100000005000000B4CBB73EAC354340F27A30293ED84640B4CBB73EAC35434055DB4DF04DDB4640B741EDB7763C434055DB4DF04DDB4640B741EDB7763C4340F27A30293ED84640B4CBB73EAC354340F27A30293ED84640
47491	Калининская	2	20	977	38.626389000000003	38.696295999999997	45.500765000000001	45.468051000000003	0103000020E610000001000000050000007EC9C6832D50434018EE5C18E9BB46407EC9C6832D504340A0FD481119C04640F52A323A20594340A0FD481119C04640F52A323A2059434018EE5C18E9BB46407EC9C6832D50434018EE5C18E9BB4640
50757	Джумайловка	2	20	977	38.582811999999997	38.609780000000001	45.464846999999999	45.444583000000002	0103000020E61000000100000005000000B1DB6795994A4340C5AD8218E8B84640B1DB6795994A43406552431B80BB4640A0E062450D4E43406552431B80BB4640A0E062450D4E4340C5AD8218E8B84640B1DB6795994A4340C5AD8218E8B84640
8785	Гривенская	2	20	977	38.128174999999999	38.209786999999999	45.669449	45.626939	0103000020E610000001000000050000001895D4096810434021CB82893FD046401895D4096810434082AB3C81B0D546401F10E84CDA1A434082AB3C81B0D546401F10E84CDA1A434021CB82893FD046401895D4096810434021CB82893FD04640
50822	Гречаная Балка	2	20	977	38.554721999999998	38.587546000000003	45.674121999999997	45.653235000000002	0103000020E61000000100000005000000942F68210147434021CD58349DD34640942F682101474340CEC133A149D64640A47213B5344B4340CEC133A149D64640A47213B5344B434021CD58349DD34640942F68210147434021CD58349DD34640
50848	Греки	2	20	977	38.511594000000002	38.530763999999998	45.676546000000002	45.656680999999999	0103000020E61000000100000005000000386A85E97B414340C9737D1F0ED44640386A85E97B414340AC1E300F99D6464073F22213F0434340AC1E300F99D6464073F22213F0434340C9737D1F0ED44640386A85E97B414340C9737D1F0ED44640
50285	Бойкопонура	2	20	977	38.748632000000001	38.777639000000001	45.377716999999997	45.335270999999999	0103000020E610000001000000050000009A5E622CD35F43400B26FE28EAAA46409A5E622CD35F43405512D90759B046400D8CBCAC896343405512D90759B046400D8CBCAC896343400B26FE28EAAA46409A5E622CD35F43400B26FE28EAAA4640
50717	Андреевская	2	20	977	38.652476	38.685121000000002	45.330804000000001	45.304160000000003	0103000020E6100000010000000500000063B66455845343402D6002B7EEA6464063B664558453434068B114C957AA4640C366800BB257434068B114C957AA4640C366800BB25743402D6002B7EEA6464063B66455845343402D6002B7EEA64640
50830	Ангелинский	2	20	977	38.392575999999998	38.427835000000002	45.558985	45.520262000000002	0103000020E61000000100000005000000E5982CEE3F32434000ADF9F197C24640E5982CEE3F3243402FFA0AD28CC74640C68A1A4CC33643402FFA0AD28CC74640C68A1A4CC336434000ADF9F197C24640E5982CEE3F32434000ADF9F197C24640
6939	Черномуровский	2	20	91	40.779741000000001	40.804166000000002	45.544947999999998	45.539608000000001	0103000020E61000000100000005000000D82C978DCE6344407A54FCDF11C54640D82C978DCE634440A30227DBC0C546400F4757E9EE664440A30227DBC0C546400F4757E9EE6644407A54FCDF11C54640D82C978DCE6344407A54FCDF11C54640
50391	Темижбекская	2	20	91	40.81765	40.883451000000001	45.457512999999999	45.428538000000003	0103000020E6100000010000000500000086C954C1A8684440F08B4B55DAB6464086C954C1A8684440573F36C98FBA46402B4F20EC14714440573F36C98FBA46402B4F20EC14714440F08B4B55DAB6464086C954C1A8684440F08B4B55DAB64640
6848	Темижбекская	2	20	91	40.81765	40.883451000000001	45.457512999999999	45.428538000000003	0103000020E6100000010000000500000086C954C1A8684440F08B4B55DAB6464086C954C1A8684440573F36C98FBA46402B4F20EC14714440573F36C98FBA46402B4F20EC14714440F08B4B55DAB6464086C954C1A8684440F08B4B55DAB64640
50319	Степной	2	20	91	40.524825999999997	40.620820000000002	45.609560000000002	45.591133999999997	0103000020E61000000100000005000000950B957F2D434440DEC66647AACB4640950B957F2D4344409279E40F06CE4640F3599E07774F44409279E40F06CE4640F3599E07774F4440DEC66647AACB4640950B957F2D434440DEC66647AACB4640
7533	Расцвет	2	20	91	40.261448999999999	40.277655000000003	45.564940999999997	45.552301	0103000020E6100000010000000500000034492C2977214440284696CCB1C6464034492C2977214440B39597FC4FC846401349F4328A234440B39597FC4FC846401349F4328A234440284696CCB1C6464034492C2977214440284696CCB1C64640
47140	Озерный	2	20	91	40.728105999999997	40.743125999999997	45.536842999999998	45.523975	0103000020E61000000100000005000000BC02D193325D4440F775E09C11C34640BC02D193325D4440130B7C45B7C446405567B5C01E5F4440130B7C45B7C446405567B5C01E5F4440F775E09C11C34640BC02D193325D4440F775E09C11C34640
47395	Мирской	2	20	91	40.384770000000003	40.418177999999997	45.558681999999997	45.527619000000001	0103000020E61000000100000005000000B03DB32440314440C6DFF60489C34640B03DB32440314440936E4BE482C746400EF450DB86354440936E4BE482C746400EF450DB86354440C6DFF60489C34640B03DB32440314440C6DFF60489C34640
47208	Лосево	2	20	91	40.582112000000002	40.610273999999997	45.559105000000002	45.545231999999999	0103000020E61000000100000005000000F94D61A5824A4440C85D8429CAC54640F94D61A5824A4440DA03ADC090C74640AFCC5B751D4E4440DA03ADC090C74640AFCC5B751D4E4440C85D8429CAC54640F94D61A5824A4440C85D8429CAC54640
50328	Кропоткинское городское поселение	2	20	91	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
32672	Кропоткин	2	20	91	40.49926	40.616059	45.469239999999999	45.410882000000001	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
50893	Красная Звезда	2	20	91	40.464289000000001	40.481662	45.572808999999999	45.567332999999998	0103000020E610000001000000050000003F726BD26D3B44408578245E9EC846403F726BD26D3B44405FED28CE51C94640ECDCB419A73D44405FED28CE51C94640ECDCB419A73D44408578245E9EC846403F726BD26D3B44408578245E9EC84640
50591	Казанская	2	20	91	40.389746000000002	40.483144000000003	45.429101000000003	45.396985000000001	0103000020E6100000010000000500000098DF6932E331444054008C67D0B2464098DF6932E331444028D714C8ECB646401BA19FA9D73D444028D714C8ECB646401BA19FA9D73D444054008C67D0B2464098DF6932E331444054008C67D0B24640
50600	Казанская	2	20	91	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
50484	Кавказская	2	20	91	40.633665999999998	40.709204999999997	45.461236999999997	45.427191000000001	0103000020E61000000100000005000000274BADF71B514440A112D731AEB64640274BADF71B514440425A63D009BB46407094BC3AC75A4440425A63D009BB46407094BC3AC75A4440A112D731AEB64640274BADF71B514440A112D731AEB64640
6733	Кавказская	2	20	91	40.633665999999998	40.709204999999997	45.461236999999997	45.427191000000001	0103000020E61000000100000005000000274BADF71B514440A112D731AEB64640274BADF71B514440425A63D009BB46407094BC3AC75A4440425A63D009BB46407094BC3AC75A4440A112D731AEB64640274BADF71B514440A112D731AEB64640
47206	Дмитриевская	2	20	91	40.722779000000003	40.797797000000003	45.674128000000003	45.639519	0103000020E61000000100000005000000289EB305845C4440D71533C2DBD14640289EB305845C4440B1A888D349D6464068EC4B361E664440B1A888D349D6464068EC4B361E664440D71533C2DBD14640289EB305845C4440D71533C2DBD14640
7404	Десятихатка	2	20	91	40.495010999999998	40.519688000000002	45.470497000000002	45.461939000000001	0103000020E6100000010000000500000083143C855C3F44409CDF30D120BB464083143C855C3F4440DDEEE53E39BC4640D40FEA2285424440DDEEE53E39BC4640D40FEA22854244409CDF30D120BB464083143C855C3F44409CDF30D120BB4640
46882	Возрождение	2	20	91	40.447992999999997	40.463444000000003	45.522195000000004	45.507555000000004	0103000020E6100000010000000500000020EBA9D557394440EDF5EE8FF7C0464020EBA9D5573944403F912749D7C2464083C30B22523B44403F912749D7C2464083C30B22523B4440EDF5EE8FF7C0464020EBA9D557394440EDF5EE8FF7C04640
45882	им. Николая Островского	2	20	301	38.315958999999999	38.326208000000001	46.448751000000001	46.431499000000002	0103000020E610000001000000050000003DF0315871284340DCA0F65B3B3747403DF03158712843400E863AAC70394740C7D8092FC12943400E863AAC70394740C7D8092FC1294340DCA0F65B3B3747403DF0315871284340DCA0F65B3B374740
4271	Ясенская Переправа	2	20	301	38.286934000000002	38.302430000000001	46.263112999999997	46.246993000000003	0103000020E61000000100000005000000240ED940BA244340A4AB74779D1F4740240ED940BA2443408313D1AFAD21474026AAB706B62643408313D1AFAD21474026AAB706B6264340A4AB74779D1F4740240ED940BA244340A4AB74779D1F4740
50811	Ясенская	2	20	301	38.251674999999999	38.285846999999997	46.369812000000003	46.348728000000001	0103000020E61000000100000005000000431CEBE23620434089997D1EA32C4740431CEBE2362043408DD5E6FF552F474071546EA2962443408DD5E6FF552F474071546EA29624434089997D1EA32C4740431CEBE23620434089997D1EA32C4740
6025	Широчанка	2	20	301	38.317405000000001	38.344965000000002	46.665601000000002	46.650942000000001	0103000020E610000001000000050000001F4B1FBAA0284340E2CB4411525347401F4B1FBAA0284340AB97DF6932554740E0A128D0272C4340AB97DF6932554740E0A128D0272C4340E2CB4411525347401F4B1FBAA0284340E2CB441152534740
45824	Советский	2	20	301	38.128408	38.145583999999999	46.520859999999999	46.511718999999999	0103000020E61000000100000005000000BB4560AC6F104340F4DE180280414740BB4560AC6F104340B4E55C8AAB42474012691B7FA2124340B4E55C8AAB42474012691B7FA2124340F4DE180280414740BB4560AC6F104340F4DE180280414740
6198	Морской	2	20	301	38.186484	38.209356	46.697291999999997	46.687550000000002	0103000020E61000000100000005000000179D2CB5DE174340B22E6EA301584740179D2CB5DE17434097E13FDD40594740569C6A2DCC1A434097E13FDD40594740569C6A2DCC1A4340B22E6EA301584740179D2CB5DE174340B22E6EA301584740
50791	Моревка	2	20	301	38.051962000000003	38.067655000000002	46.555097000000004	46.538760000000003	0103000020E610000001000000050000004051D9B0A60643404D327216F64447404051D9B0A6064340CA8D226B0D474740983446EBA8084340CA8D226B0D474740983446EBA80843404D327216F64447404051D9B0A60643404D327216F6444740
50334	Мирный	2	20	301	38.002186000000002	38.017493000000002	46.565308999999999	46.551937000000002	0103000020E6100000010000000500000029417FA147004340E73922DFA546474029417FA1470043403691990B5C4847405874EB353D0243403691990B5C4847405874EB353D024340E73922DFA546474029417FA147004340E73922DFA5464740
3424	Кухаривка	2	20	301	38.132531999999998	38.160173	46.633470000000003	46.617390999999998	0103000020E6100000010000000500000034D6FECEF610434020EC14AB064F474034D6FECEF6104340A27F828B15514740E259828C80144340A27F828B15514740E259828C8014434020EC14AB064F474034D6FECEF610434020EC14AB064F4740
6155	Краснофлотский	2	20	301	38.255367	38.269326999999997	46.654387	46.645733	0103000020E6100000010000000500000023BDA8DDAF20434057790261A752474023BDA8DDAF204340BAF605F4C25347400377A04E79224340BAF605F4C25347400377A04E7922434057790261A752474023BDA8DDAF20434057790261A7524740
50357	Копанская	2	20	301	38.459544999999999	38.504550999999999	46.288615	46.267960000000002	0103000020E610000001000000050000002905DD5ED23A43406E5166834C2247402905DD5ED23A434049111956F124474001158E209540434049111956F124474001158E20954043406E5166834C2247402905DD5ED23A43406E5166834C224740
3720	Комсомолец	2	20	301	38.251001000000002	38.270755000000001	46.584252999999997	46.574601999999999	0103000020E61000000100000005000000B421FFCC20204340AC1BEF8E8C494740B421FFCC2020434081CB63CDC84A47403F1D8F19A822434081CB63CDC84A47403F1D8F19A8224340AC1BEF8E8C494740B421FFCC20204340AC1BEF8E8C494740
50646	Камышеватская	2	20	301	37.926521000000001	37.985657000000003	46.420124999999999	46.399296999999997	0103000020E610000001000000050000005307793D98F642400932022A1C3347405307793D98F64240B29DEFA7C6354740680932022AFE4240B29DEFA7C6354740680932022AFE42400932022A1C3347405307793D98F642400932022A1C334740
50647	Камышеватская	2	20	301	37.926521000000001	37.985657000000003	46.420124999999999	46.399296999999997	0103000020E610000001000000050000005307793D98F642400932022A1C3347405307793D98F64240B29DEFA7C6354740680932022AFE4240B29DEFA7C6354740680932022AFE42400932022A1C3347405307793D98F642400932022A1C334740
50473	Заводской	2	20	301	38.457309000000002	38.465392999999999	46.430833999999997	46.421691000000003	0103000020E610000001000000050000004F95EF19893A43403F027FF8F93547404F95EF19893A43409F008A9125374740C76471FF913B43409F008A9125374740C76471FF913B43403F027FF8F93547404F95EF19893A43403F027FF8F9354740
50243	Ейск	2	20	301	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
1328	Ейск	2	20	301	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
50560	Должанская	2	20	301	37.779682000000001	37.819603000000001	46.648634000000001	46.609392999999997	0103000020E61000000100000005000000D3A3A99ECCE34240A6B4FE96004E4740D3A3A99ECCE342406E895C70065347400C5A48C0E8E842406E895C70065347400C5A48C0E8E84240A6B4FE96004E4740D3A3A99ECCE34240A6B4FE96004E4740
50567	Должанская	2	20	301	37.779682000000001	37.819603000000001	46.648634000000001	46.609392999999997	0103000020E61000000100000005000000D3A3A99ECCE34240A6B4FE96004E4740D3A3A99ECCE342406E895C70065347400C5A48C0E8E842406E895C70065347400C5A48C0E8E84240A6B4FE96004E4740D3A3A99ECCE34240A6B4FE96004E4740
45686	Воронцовка	2	20	301	38.064844000000001	38.094029999999997	46.661178999999997	46.642949000000002	0103000020E61000000100000005000000C1ABE5CE4C0843407AFF1F274C524740C1ABE5CE4C084340A7E67283A1544740E36BCF2C090C4340A7E67283A1544740E36BCF2C090C43407AFF1F274C524740C1ABE5CE4C0843407AFF1F274C524740
45831	Большевик	2	20	301	38.227761999999998	38.238208999999998	46.519831000000003	46.511192000000001	0103000020E61000000100000005000000C2A2224E271D434009FD4CBD6E414740C2A2224E271D434037397CD289424740724EECA17D1E434037397CD289424740724EECA17D1E434009FD4CBD6E414740C2A2224E271D434009FD4CBD6E414740
46070	Александровка	2	20	301	38.391705000000002	38.409391999999997	46.654901000000002	46.635702999999999	0103000020E610000001000000050000000057B263233243400B7C45B75E5147400057B26323324340118FC4CBD35347403C9F01F566344340118FC4CBD35347403C9F01F5663443400B7C45B75E5147400057B263233243400B7C45B75E514740
34234	Дальний	2	20	2678	43.339212000000003	43.347107999999999	47.123614000000003	47.119701999999997	0103000020E6100000010000000500000094347F4C6BAB454005A22765528F474094347F4C6BAB4540F4A96395D28F47400917F2086EAC4540F4A96395D28F47400917F2086EAC454005A22765528F474094347F4C6BAB454005A22765528F4740
50497	ст.Васюринская	2	20	175	39.312271000000003	39.444071999999998	45.160054000000002	45.06673	0103000020E610000001000000050000009F3E027FF8A74340BFD4CF9B8A8846409F3E027FF8A7434008CC43A67C944640DF88EE59D7B8434008CC43A67C944640DF88EE59D7B84340BFD4CF9B8A8846409F3E027FF8A74340BFD4CF9B8A884640
32718	Янтарный	2	20	175	39.241025999999998	39.250960999999997	45.135942999999997	45.125584000000003	0103000020E610000001000000050000002BBEA1F0D99E43405073F222139046402BBEA1F0D99E4340608F89946691464025C9737D1FA04340608F89946691464025C9737D1FA043405073F222139046402BBEA1F0D99E43405073F22213904640
1227	Украинский	2	20	175	39.336184000000003	39.37509	45.259557999999998	45.245345	0103000020E6100000010000000500000020B8CA1308AB43405A9E0777679F464020B8CA1308AB434024B5503239A146404087F9F202B0434024B5503239A146404087F9F202B043405A9E0777679F464020B8CA1308AB43405A9E0777679F4640
2045	Старомышастовская	2	20	175	39.048400000000001	39.122124999999997	45.360658999999998	45.326830999999999	0103000020E610000001000000050000002E90A0F831864340D4282499D5A946402E90A0F8318643400801F9122AAE46401283C0CAA18F43400801F9122AAE46401283C0CAA18F4340D4282499D5A946402E90A0F831864340D4282499D5A94640
50344	Ст. Васюринская	2	20	175	39.378368999999999	39.388807999999997	45.118983	45.109741	0103000020E61000000100000005000000FD6838656EB04340E2033BFE0B8E4640FD6838656EB04340D6E3BED53A8F46402A36E675C4B14340D6E3BED53A8F46402A36E675C4B14340E2033BFE0B8E4640FD6838656EB04340E2033BFE0B8E4640
50606	Примаки	2	20	175	38.848570000000002	38.868763999999999	45.220500999999999	45.183793999999999	0103000020E61000000100000005000000F12E17F19D6C4340BB99D18F86974640F12E17F19D6C43401EDE7360399C464098F8A3A8336F43401EDE7360399C464098F8A3A8336F4340BB99D18F86974640F12E17F19D6C4340BB99D18F86974640
1795	Пластуновская	2	20	175	39.221254000000002	39.315289	45.308368999999999	45.281047999999998	0103000020E61000000100000005000000FA0D130D529C4340984D8061F9A34640FA0D130D529C4340D40CA9A278A74640EFE4D3635BA84340D40CA9A278A74640EFE4D3635BA84340984D8061F9A34640FA0D130D529C4340984D8061F9A34640
1688	Первореченское	2	20	175	39.260455999999998	39.362333999999997	45.172516000000002	45.149351000000003	0103000020E610000001000000050000000306499F56A14340FD4FFEEE1D9346400306499F56A14340B4041901159646404B1DE4F560AE4340B4041901159646404B1DE4F560AE4340FD4FFEEE1D9346400306499F56A14340FD4FFEEE1D934640
50584	Новотитаровская	2	20	175	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
50605	Новотитаровская	2	20	175	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
50658	Нововеличковская	2	20	175	38.820093	38.876364000000002	45.306575000000002	45.255153999999997	0103000020E61000000100000005000000DA56B3CEF8684340C7B8E2E2A8A04640DA56B3CEF8684340B7627FD93DA7464025B20FB22C704340B7627FD93DA7464025B20FB22C704340C7B8E2E2A8A04640DA56B3CEF8684340C7B8E2E2A8A04640
3065	Найдорф	2	20	175	38.809249999999999	38.833604000000001	45.332470000000001	45.324472999999998	0103000020E61000000100000005000000DD24068195674340AEB7CD5488A94640DD24068195674340587380608EAA46404BE82E89B36A4340587380608EAA46404BE82E89B36A4340AEB7CD5488A94640DD24068195674340AEB7CD5488A94640
49526	Красносельское	2	20	175	39.149298999999999	39.18383	45.315956	45.264201	0103000020E61000000100000005000000AA29C93A1C93434006499F56D1A14640AA29C93A1C934340CC7C073F71A846400803CFBD87974340CC7C073F71A846400803CFBD8797434006499F56D1A14640AA29C93A1C93434006499F56D1A14640
1375	Зарождение	2	20	175	39.223868000000003	39.242894	45.164763999999998	45.151595	0103000020E610000001000000050000007B4FE5B4A79C43405A9E0777679346407B4FE5B4A79C434071C79BFC1695464083328D26179F434071C79BFC1695464083328D26179F43405A9E0777679346407B4FE5B4A79C43405A9E077767934640
554	Динская	2	20	175	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
49685	Дальний	2	20	175	38.847949999999997	38.854472000000001	45.406838999999998	45.401890000000002	0103000020E61000000100000005000000545227A0896C4340734BAB2171B34640545227A0896C434061DEE34C13B4464082ACA7565F6D434061DEE34C13B4464082ACA7565F6D4340734BAB2171B34640545227A0896C4340734BAB2171B34640
50254	Восточный	2	20	175	39.089281999999997	39.102829	45.389802000000003	45.380527999999998	0103000020E610000001000000050000008C0FB3976D8B43402C9B3924B5B046408C0FB3976D8B43402CF52C08E5B146404A0A2C80298D43402CF52C08E5B146404A0A2C80298D43402C9B3924B5B046408C0FB3976D8B43402C9B3924B5B04640
50775	Воронцовская	2	20	175	38.727494999999998	38.749926000000002	45.227218000000001	45.211573999999999	0103000020E610000001000000050000007380608E1E5D43408A5759DB149B46407380608E1E5D43400188BB7A159D4640C6353E93FD5F43400188BB7A159D4640C6353E93FD5F43408A5759DB149B46407380608E1E5D43408A5759DB149B4640
50455	Васюринская	2	20	175	39.394117000000001	39.449731	45.131956000000002	45.099085000000002	0103000020E6100000010000000500000019E6046D72B24340184339D1AE8C464019E6046D72B24340684128EFE3904640AA7F10C990B94340684128EFE3904640AA7F10C990B94340184339D1AE8C464019E6046D72B24340184339D1AE8C4640
1243	Агроном	2	20	175	39.180416000000001	39.222017000000001	45.151417000000002	45.129826000000001	0103000020E610000001000000050000006BD619DF17974340D3156C239E9046406BD619DF179743407B87DBA161934640F913950D6B9C43407B87DBA161934640F913950D6B9C4340D3156C239E9046406BD619DF17974340D3156C239E904640
50571	Черединовский	2	20	1188	40.718763000000003	40.736721000000003	45.422092999999997	45.409008999999998	0103000020E6100000010000000500000095490D6D005C444084622B685AB4464095490D6D005C44406D6FB72407B6464062A3ACDF4C5E44406D6FB72407B6464062A3ACDF4C5E444084622B685AB4464095490D6D005C444084622B685AB44640
50882	Чаплыгин	2	20	1188	40.743763000000001	40.769033	45.120986000000002	45.104633	0103000020E61000000100000005000000C87C40A0335F44408B8A389D648D4640C87C40A0335F44400EA320787C8F4640BB4560AC6F6244400EA320787C8F4640BB4560AC6F6244408B8A389D648D4640C87C40A0335F44408B8A389D648D4640
50289	Урожайный	2	20	1188	40.465527999999999	40.480089999999997	45.351120999999999	45.340598999999997	0103000020E61000000100000005000000A7AFE76B963B444070067FBF98AB4640A7AFE76B963B44402BF86D88F1AC46407D91D096733D44402BF86D88F1AC46407D91D096733D444070067FBF98AB4640A7AFE76B963B444070067FBF98AB4640
50665	Тысячный	2	20	1188	40.758011000000003	40.781942000000001	45.188735999999999	45.172998999999997	0103000020E610000001000000050000000F81238106614440CF9ECBD4249646400F81238106614440F7C951802898464036AFEAAC16644440F7C951802898464036AFEAAC16644440CF9ECBD4249646400F81238106614440CF9ECBD424964640
50369	Тельман	2	20	1188	40.620505999999999	40.637124	45.368245000000002	45.352944999999998	0103000020E61000000100000005000000637C98BD6C4F4440B324404D2DAD4640637C98BD6C4F444030F5F3A622AF464094BF7B478D51444030F5F3A622AF464094BF7B478D514440B324404D2DAD4640637C98BD6C4F4440B324404D2DAD4640
49010	Соколовское	2	20	1188	40.601973000000001	40.686711000000003	45.266008999999997	45.246943999999999	0103000020E610000001000000050000009A0986730D4D4440C2F869DC9B9F46409A0986730D4D444088B839950CA24640D8666325E657444088B839950CA24640D8666325E6574440C2F869DC9B9F46409A0986730D4D4440C2F869DC9B9F4640
50312	Советский	2	20	1188	40.434950000000001	40.452826000000002	45.367649999999998	45.358638999999997	0103000020E6100000010000000500000096B20C71AC374440FA08FCE1E7AD464096B20C71AC374440EC2FBB270FAF4640A663CE33F6394440EC2FBB270FAF4640A663CE33F6394440FA08FCE1E7AD464096B20C71AC374440FA08FCE1E7AD4640
50660	Скобелевская	2	20	1188	40.397219999999997	40.436278999999999	45.204157000000002	45.189872999999999	0103000020E6100000010000000500000097A8DE1AD83244405BB22AC24D98464097A8DE1AD8324440EF1F0BD1219A46403E7782FDD7374440EF1F0BD1219A46403E7782FDD73744405BB22AC24D98464097A8DE1AD83244405BB22AC24D984640
50898	Самойлов	2	20	1188	40.592379000000001	40.617308000000001	45.370113000000003	45.364553000000001	0103000020E6100000010000000500000029EB3713D34B4440505436ACA9AE464029EB3713D34B44408869DFDC5FAF464093C7D3F2034F44408869DFDC5FAF464093C7D3F2034F4440505436ACA9AE464029EB3713D34B4440505436ACA9AE4640
48947	Пушкинское	2	20	1188	40.574539000000001	40.640340000000002	45.182256000000002	45.169834999999999	0103000020E6100000010000000500000066A3737E8A494440AB5B3D27BD95464066A3737E8A494440F9BF232A549746400B293FA9F6514440F9BF232A549746400B293FA9F6514440AB5B3D27BD95464066A3737E8A494440AB5B3D27BD954640
32140	Отрадо-Ольгинское	2	20	1188	40.914866000000004	40.960760000000001	45.325189000000002	45.287688000000003	0103000020E61000000100000005000000761C3F541A754440D0B9DBF5D2A44640761C3F541A7544406D020CCB9FA9464009A7052FFA7A44406D020CCB9FA9464009A7052FFA7A4440D0B9DBF5D2A44640761C3F541A754440D0B9DBF5D2A44640
11374	Отрадо-Кубанское	2	20	1188	40.816473000000002	40.852352000000003	45.257660999999999	45.232607000000002	0103000020E610000001000000050000009488F02F826844400CE9F010C69D46409488F02F82684440323A2009FBA046401157CEDE196D4440323A2009FBA046401157CEDE196D44400CE9F010C69D46409488F02F826844400CE9F010C69D4640
50627	Орлов	2	20	1188	40.480835999999996	40.491570000000003	45.248187000000001	45.244069000000003	0103000020E61000000100000005000000A65EB7088C3D4440D57B2AA73D9F4640A65EB7088C3D44406C257497C49F4640EDD808C4EB3E44406C257497C49F4640EDD808C4EB3E4440D57B2AA73D9F4640A65EB7088C3D4440D57B2AA73D9F4640
30791	Новоукраинское	2	20	1188	40.479398000000003	40.556752000000003	45.389718999999999	45.369227000000002	0103000020E6100000010000000500000048E2E5E95C3D44406DE690D442AF464048E2E5E95C3D44409ED0EB4FE2B14640C6FD47A6434744409ED0EB4FE2B14640C6FD47A6434744406DE690D442AF464048E2E5E95C3D44406DE690D442AF4640
50888	Новопавловский	2	20	1188	40.687007999999999	40.728735	45.253872999999999	45.240533999999997	0103000020E61000000100000005000000910BCEE0EF574440BCC96FD1C99E4640910BCEE0EF574440302B14E97EA04640AC394030475D4440302B14E97EA04640AC394030475D4440BCC96FD1C99E4640910BCEE0EF574440BCC96FD1C99E4640
33131	Новомихайловское	2	20	1188	40.993476999999999	41.023355000000002	45.299253	45.277889999999999	0103000020E61000000100000005000000022A1C412A7F444056F146E691A34640022A1C412A7F44406D1D1CEC4DA646405B99F04BFD8244406D1D1CEC4DA646405B99F04BFD82444056F146E691A34640022A1C412A7F444056F146E691A34640
50860	Новокрасный	2	20	1188	40.654552000000002	40.687969000000002	45.162863000000002	45.139713	0103000020E6100000010000000500000005C4245CC8534440BCE9961DE291464005C4245CC85344403E5DDDB1D8944640B7D4415E0F5844403E5DDDB1D8944640B7D4415E0F584440BCE9961DE291464005C4245CC8534440BCE9961DE2914640
31785	Николенское	2	20	1188	40.515591000000001	40.586387999999999	45.251010999999998	45.234403	0103000020E61000000100000005000000548EC9E2FE414440CA8AE1EA009E4640548EC9E2FE414440D7F7E12021A04640286211C30E4B4440D7F7E12021A04640286211C30E4B4440CA8AE1EA009E4640548EC9E2FE414440CA8AE1EA009E4640
50503	Мирный	2	20	1188	40.300148	40.320289000000002	45.348985999999996	45.337349000000003	0103000020E61000000100000005000000DBFAE93F6B2644404E2B85402EAB4640DBFAE93F6B2644408461C092ABAC46406022DE3AFF2844408461C092ABAC46406022DE3AFF2844404E2B85402EAB4640DBFAE93F6B2644404E2B85402EAB4640
50644	Машевский	2	20	1188	40.689191000000001	40.707445	45.287909999999997	45.279431000000002	0103000020E6100000010000000500000049D92269375844408A3E1F65C4A3464049D92269375844407E18213CDAA44640FF5BC98E8D5A44407E18213CDAA44640FF5BC98E8D5A44408A3E1F65C4A3464049D92269375844408A3E1F65C4A34640
30178	Майкопское	2	20	1188	40.729875	40.779992999999997	45.407395000000001	45.381148000000003	0103000020E610000001000000050000008195438B6C5D4440C9772975C9B046408195438B6C5D4440E7C6F48425B44640F10D85CFD6634440E7C6F48425B44640F10D85CFD6634440C9772975C9B046408195438B6C5D4440C9772975C9B04640
31086	Лесодача	2	20	1188	40.933298999999998	40.945076	45.372253000000001	45.364305999999999	0103000020E61000000100000005000000DB3175577677444048DE3994A1AE4640DB31755776774440406B7EFCA5AF4640041E1840F8784440406B7EFCA5AF4640041E1840F878444048DE3994A1AE4640DB3175577677444048DE3994A1AE4640
50309	Кубань	2	20	1188	40.400570999999999	40.421492999999998	45.360298	45.350467999999999	0103000020E61000000100000005000000EE5C18E945334440B325AB22DCAC4640EE5C18E9453344403868AF3E1EAE4640183F8D7BF33544403868AF3E1EAE4640183F8D7BF3354440B325AB22DCAC4640EE5C18E945334440B325AB22DCAC4640
50902	Крупский	2	20	1188	40.759501999999998	40.785257000000001	45.348377999999997	45.340409000000001	0103000020E61000000100000005000000909F8D5C37614440CD21A98592AB4640909F8D5C37614440AC527AA697AC464040FA264D83644440AC527AA697AC464040FA264D83644440CD21A98592AB4640909F8D5C37614440CD21A98592AB4640
30608	Красносельский	2	20	1188	40.569589000000001	40.618789999999997	45.40258	45.380724000000001	0103000020E61000000100000005000000A794D74AE8484440B2666490BBB04640A794D74AE84844400803CFBD87B34640C18BBE82344F44400803CFBD87B34640C18BBE82344F4440B2666490BBB04640A794D74AE8484440B2666490BBB04640
46580	Красная Поляна	2	20	1188	40.856565000000003	40.870570000000001	45.362608999999999	45.350892999999999	0103000020E61000000100000005000000FAF202ECA36D44409AB2D30FEAAC4640FAF202ECA36D44401D1EC2F869AE46407A7077D66E6F44401D1EC2F869AE46407A7077D66E6F44409AB2D30FEAAC4640FAF202ECA36D44409AB2D30FEAAC4640
50366	Киевка	2	20	1188	41.005361999999998	41.021656999999998	45.268090000000001	45.250478000000001	0103000020E610000001000000050000001152B7B3AF8044400A2FC1A90FA046401152B7B3AF8044403C31EBC550A246405F5D15A8C58244403C31EBC550A246405F5D15A8C58244400A2FC1A90FA046401152B7B3AF8044400A2FC1A90FA04640
50846	Журавлев	2	20	1188	40.406661999999997	40.434420000000003	45.244748000000001	45.237824000000003	0103000020E6100000010000000500000052431B800D3444401A1A4F04719E464052431B800D34444076E107E7539F46403A5D16139B37444076E107E7539F46403A5D16139B3744401A1A4F04719E464052431B800D3444401A1A4F04719E4640
50801	Духовский	2	20	1188	40.909160999999997	40.923713999999997	45.423926999999999	45.413083999999998	0103000020E610000001000000050000003AE63C635F7444401C40BFEFDFB446403AE63C635F74444019726C3D43B64640BD6DA6423C76444019726C3D43B64640BD6DA6423C7644401C40BFEFDFB446403AE63C635F7444401C40BFEFDFB44640
48646	Дальний	2	20	1188	40.515492999999999	40.527180000000001	45.308222999999998	45.301578999999997	0103000020E610000001000000050000009128B4ACFB414440871403249AA646409128B4ACFB4144400070ECD973A746407A8D5DA27A4344400070ECD973A746407A8D5DA27A434440871403249AA646409128B4ACFB414440871403249AA64640
29398	Гулькевичи	2	20	1188	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
30321	Гирей	2	20	1188	40.641067999999997	40.691795999999997	45.416361000000002	45.395238999999997	0103000020E610000001000000050000008D4127840E524440478D093197B246408D4127840E524440392A37514BB5464076C075C58C584440392A37514BB5464076C075C58C584440478D093197B246408D4127840E524440478D093197B24640
50339	Воздвиженский	2	20	1188	40.798560999999999	40.816688999999997	45.179029	45.166167999999999	0103000020E61000000100000005000000376E313F3766444024D236FE44954640376E313F376644408E041A6CEA9646406000E143896844408E041A6CEA9646406000E1438968444024D236FE44954640376E313F3766444024D236FE44954640
30748	Венцы	2	20	1188	40.819653000000002	40.843324000000003	45.382503	45.366751000000001	0103000020E61000000100000005000000BE88B663EA6844403D635FB2F1AE4640BE88B663EA6844409ACFB9DBF5B0464049F7730AF26B44409ACFB9DBF5B0464049F7730AF26B44403D635FB2F1AE4640BE88B663EA6844403D635FB2F1AE4640
50666	Булгаков	2	20	1188	40.48442	40.538983000000002	45.194172999999999	45.186219999999999	0103000020E61000000100000005000000A0C37C79013E444039EE940ED6974640A0C37C79013E444013622EA9DA984640CC0C1B65FD44444013622EA9DA984640CC0C1B65FD44444039EE940ED6974640A0C37C79013E444039EE940ED6974640
12269	Ботаника	2	20	1188	40.788580000000003	40.801946999999998	45.220030999999999	45.210284999999999	0103000020E61000000100000005000000CD237F30F064444070EB6E9EEA9A4640CD237F30F0644440978DCEF9299C46400A100533A6664440978DCEF9299C46400A100533A666444070EB6E9EEA9A4640CD237F30F064444070EB6E9EEA9A4640
50602	Алексеевский	2	20	1188	40.606904999999998	40.627315000000003	45.233280000000001	45.224195999999999	0103000020E61000000100000005000000B2632310AF4D44406FF25B74B29C4640B2632310AF4D4440CB67791EDC9D464027A5A0DB4B504440CB67791EDC9D464027A5A0DB4B5044406FF25B74B29C4640B2632310AF4D44406FF25B74B29C4640
50349	Кутаис	2	20	7074	39.273589999999999	39.317239000000001	44.537790999999999	44.510509999999996	0103000020E610000001000000050000009E4143FF04A34340F6234564584146409E4143FF04A34340A48AE255D644464004029D499BA84340A48AE255D644464004029D499BA84340F6234564584146409E4143FF04A34340F623456458414640
50464	ст. Березанская	2	20	1739	39.548015999999997	39.618893	45.724730999999998	45.691827000000004	0103000020E61000000100000005000000A5D7666325C64340B2BE81C98DD84640A5D7666325C64340DDB243FCC3DC4640965CC5E237CF4340DDB243FCC3DC4640965CC5E237CF4340B2BE81C98DD84640A5D7666325C64340B2BE81C98DD84640
25147	Советский	2	20	1739	39.999267000000003	40.014412	45.756193000000003	45.747836	0103000020E610000001000000050000006C7C26FBE7FF4340BF620D17B9DF46406C7C26FBE7FF4340693BA6EECAE04640C1559E40D8014440693BA6EECAE04640C1559E40D8014440BF620D17B9DF46406C7C26FBE7FF4340BF620D17B9DF4640
25009	Первомайское	2	20	1739	39.680031999999997	39.745223000000003	45.671028999999997	45.645598999999997	0103000020E61000000100000005000000E21DE0490BD7434047AAEFFCA2D24640E21DE0490BD7434073D53C47E4D546400F9D9E7763DF434073D53C47E4D546400F9D9E7763DF434047AAEFFCA2D24640E21DE0490BD7434047AAEFFCA2D24640
25583	Первомайский	2	20	1739	40.115544999999997	40.123736999999998	45.708477000000002	45.702402999999997	0103000020E61000000100000005000000B01BB62DCA0E44405FCE6C57E8D94640B01BB62DCA0E4440EE7BD45FAFDA46400F27309DD60F4440EE7BD45FAFDA46400F27309DD60F44405FCE6C57E8D94640B01BB62DCA0E44405FCE6C57E8D94640
25513	Память Ленина	2	20	1739	39.515407000000003	39.556306999999997	45.890836	45.877485999999998	0103000020E61000000100000005000000939048DBF8C143405359147651F04640939048DBF8C14340BB0CFFE906F2464097C4591135C74340BB0CFFE906F2464097C4591135C743405359147651F04640939048DBF8C143405359147651F04640
25171	Октябрьский	2	20	1739	39.989179	39.997532999999997	45.808442999999997	45.801771000000002	0103000020E61000000100000005000000EB71DF6A9DFE4340CCF09F6EA0E64640EB71DF6A9DFE43400ED76A0F7BE7464023D74D29AFFF43400ED76A0F7BE7464023D74D29AFFF4340CCF09F6EA0E64640EB71DF6A9DFE4340CCF09F6EA0E64640
25709	Новомалороссийская	2	20	1739	39.83766	39.956919999999997	45.652831999999997	45.610852000000001	0103000020E610000001000000050000006C95607138EB43401D59F96530CE46406C95607138EB434021E4BCFF8FD34640B471C45A7CFA434021E4BCFF8FD34640B471C45A7CFA43401D59F96530CE46406C95607138EB43401D59F96530CE4640
24155	Новодонецкая	2	20	1739	39.755930999999997	39.849580000000003	45.714499000000004	45.688768000000003	0103000020E610000001000000050000002B84D558C2E043400344C18C29D846402B84D558C2E043402A0307B474DB4640F8AA9509BFEC43402A0307B474DB4640F8AA9509BFEC43400344C18C29D846402B84D558C2E043400344C18C29D84640
50713	Новогражданская	2	20	1739	39.520510000000002	40.168716000000003	45.909495	45.419049999999999	0103000020E61000000100000005000000D89E5912A0C24340C4B12E6EA3B54640D89E5912A0C24340117008556AF44640EE27637C98154440117008556AF44640EE27637C98154440C4B12E6EA3B54640D89E5912A0C24340C4B12E6EA3B54640
25622	Новобейсугская	2	20	1739	39.782431000000003	39.971823000000001	45.481355000000001	45.447871999999997	0103000020E610000001000000050000003430F2B226E44340A565A4DE53B946403430F2B226E443400F62670A9DBD4640144031B264FC43400F62670A9DBD4640144031B264FC4340A565A4DE53B946403430F2B226E44340A565A4DE53B94640
50889	Крупская	2	20	1739	39.934696000000002	39.99765	45.705846000000001	45.689152	0103000020E61000000100000005000000DCD9571EA4F743408BFCFA2136D84640DCD9571EA4F743409701672959DA46405D6DC5FEB2FF43409701672959DA46405D6DC5FEB2FF43408BFCFA2136D84640DCD9571EA4F743408BFCFA2136D84640
25390	Ирклиевская	2	20	1739	39.617176999999998	39.693615000000001	45.868783000000001	45.836925999999998	0103000020E61000000100000005000000F46BEBA7FFCE43400796236420EB4640F46BEBA7FFCE43400F29064834EF4640ED815660C8D843400F29064834EF4640ED815660C8D843400796236420EB4640F46BEBA7FFCE43400796236420EB4640
50576	Иногородне-Малеваный	2	20	1739	39.595725000000002	39.665371999999998	45.550325999999998	45.537140000000001	0103000020E610000001000000050000006E3480B740CC4340CDAFE600C1C446406E3480B740CC4340BA11161571C6464049D6E1E82AD54340BA11161571C6464049D6E1E82AD54340CDAFE600C1C446406E3480B740CC4340CDAFE600C1C44640
24383	Заря	2	20	1739	39.616835999999999	39.672882000000001	45.682924999999997	45.636688999999997	0103000020E610000001000000050000006B7F677BF4CE4340895C70067FD146406B7F677BF4CE4340764F1E166AD74640960854FF20D64340764F1E166AD74640960854FF20D64340895C70067FD146406B7F677BF4CE4340895C70067FD14640
24451	Заречный	2	20	1739	39.608975999999998	39.657449	45.741829000000003	45.730978	0103000020E610000001000000050000004206F2ECF2CD4340390CE6AF90DD46404206F2ECF2CD4340B91CAF40F4DE4640DAE4F04927D44340B91CAF40F4DE4640DAE4F04927D44340390CE6AF90DD46404206F2ECF2CD4340390CE6AF90DD4640
25229	Гражданский	2	20	1739	39.861007000000001	39.882809000000002	45.792672000000003	45.773589999999999	0103000020E610000001000000050000004450357A35EE43409E4143FF04E346404450357A35EE43403B3AAE4676E54640A7CEA3E2FFF043403B3AAE4676E54640A7CEA3E2FFF043409E4143FF04E346404450357A35EE43409E4143FF04E34640
25088	Газырь	2	20	1739	39.923214999999999	39.953398999999997	45.767643	45.741798000000003	0103000020E610000001000000050000009C16BCE82BF643407E1EA33CF3DE46409C16BCE82BF643406D00362042E2464001857AFA08FA43406D00362042E2464001857AFA08FA43407E1EA33CF3DE46409C16BCE82BF643407E1EA33CF3DE4640
24645	Выселки	2	20	1739	39.592519000000003	39.690731	45.611274999999999	45.563478000000003	0103000020E610000001000000050000001BA19FA9D7CB4340FC010F0C20C846401BA19FA9D7CB434063EE5A423ECE4640ACAA97DF69D8434063EE5A423ECE4640ACAA97DF69D84340FC010F0C20C846401BA19FA9D7CB4340FC010F0C20C84640
24488	Бузиновская	2	20	1739	39.763603000000003	39.812443999999999	45.650374999999997	45.577005	0103000020E6100000010000000500000052103CBEBDE143407250C24CDBC9464052103CBEBDE143406891ED7C3FD346406CEA3C2AFEE743406891ED7C3FD346406CEA3C2AFEE743407250C24CDBC9464052103CBEBDE143407250C24CDBC94640
24278	Березанская	2	20	1739	39.548015999999997	39.618893	45.724730999999998	45.691827000000004	0103000020E61000000100000005000000A5D7666325C64340B2BE81C98DD84640A5D7666325C64340DDB243FCC3DC4640965CC5E237CF4340DDB243FCC3DC4640965CC5E237CF4340B2BE81C98DD84640A5D7666325C64340B2BE81C98DD84640
24008	Бейсуг	2	20	1739	39.839509999999997	39.869675999999998	45.693759999999997	45.685538000000001	0103000020E610000001000000050000001D554D1075EB434027158DB5BFD746401D554D1075EB4340F0A2AF20CDD84640DC0E0D8B51EF4340F0A2AF20CDD84640DC0E0D8B51EF434027158DB5BFD746401D554D1075EB434027158DB5BFD74640
25312	Балковская	2	20	1739	39.699669999999998	39.763486	45.814919000000003	45.793539000000003	0103000020E6100000010000000500000004FF5BC98ED94340DF8C9AAF92E5464004FF5BC98ED94340CCF10A444FE84640187AC4E8B9E14340CCF10A444FE84640187AC4E8B9E14340DF8C9AAF92E5464004FF5BC98ED94340DF8C9AAF92E54640
50780	Александроневская	2	20	1739	39.852176999999998	39.909416999999998	45.702081999999997	45.682282999999998	0103000020E61000000100000005000000A2B3CC2214ED4340F2CEA10C55D74640A2B3CC2214ED43401D8EAED2DDD9464095B6B8C667F443401D8EAED2DDD9464095B6B8C667F44340F2CEA10C55D74640A2B3CC2214ED4340F2CEA10C55D74640
50735	2-й Бейсужек	2	20	1739	39.669172000000003	39.764429	45.497821000000002	45.469921999999997	0103000020E6100000010000000500000010B3976DA7D54340E0D5726726BC464010B3976DA7D543408A213999B8BF4640978E39CFD8E143408A213999B8BF4640978E39CFD8E14340E0D5726726BC464010B3976DA7D54340E0D5726726BC4640
23118	Чепигинская	2	20	1198	38.857607000000002	38.888680000000001	45.940382999999997	45.921039	0103000020E610000001000000050000000CE9F010C66D434097AB1F9BE4F546400CE9F010C66D4340705B5B785EF84640FD4D2844C0714340705B5B785EF84640FD4D2844C071434097AB1F9BE4F546400CE9F010C66D434097AB1F9BE4F54640
23014	Челюскинец	2	20	1198	38.611207999999998	38.646377000000001	45.859017000000001	45.846418999999997	0103000020E61000000100000005000000DB8651103C4E434044DB317557EC4640DB8651103C4E4340A1DAE044F4ED46407CF1457BBC524340A1DAE044F4ED46407CF1457BBC52434044DB317557EC4640DB8651103C4E434044DB317557EC4640
32644	Свободное	2	20	1198	39.140037	39.278297000000002	45.892460999999997	45.868343000000003	0103000020E610000001000000050000006F9D7FBBEC914340F35A09DD25EF46406F9D7FBBEC9143404CFA7B293CF2464097C9703C9FA343404CFA7B293CF2464097C9703C9FA34340F35A09DD25EF46406F9D7FBBEC914340F35A09DD25EF4640
50386	Приречное	2	20	1198	39.280552	39.322125999999997	45.804453000000002	45.788724999999999	0103000020E61000000100000005000000E869C020E9A34340D044D8F0F4E44640E869C020E9A34340A515DF50F8E646407C98BD6C3BA94340A515DF50F8E646407C98BD6C3BA94340D044D8F0F4E44640E869C020E9A34340D044D8F0F4E44640
49602	Привольный	2	20	1198	39.152856	39.170848999999997	45.812399999999997	45.800426000000002	0103000020E61000000100000005000000AA7F10C9909343401E6FF25B74E64640AA7F10C9909343409CA223B9FCE74640F3C64961DE9543409CA223B9FCE74640F3C64961DE9543401E6FF25B74E64640AA7F10C9909343401E6FF25B74E64640
15123	Полтавский	2	20	1198	39.434351999999997	39.461723999999997	45.799553000000003	45.783690999999997	0103000020E61000000100000005000000E179A9D898B74340B39597FC4FE44640E179A9D898B743409835B1C057E646409FE3A3C519BB43409835B1C057E646409FE3A3C519BB4340B39597FC4FE44640E179A9D898B74340B39597FC4FE44640
23322	Переясловская	2	20	1198	39.005074	39.048571000000003	45.860196999999999	45.824384999999999	0103000020E61000000100000005000000AB07CC43A68043400F289B7285E94640AB07CC43A6804340048F6FEF1AEE46405B44149337864340048F6FEF1AEE46405B441493378643400F289B7285E94640AB07CC43A68043400F289B7285E94640
50330	Новое Село	2	20	1198	39.434451000000003	39.513817000000003	45.894243000000003	45.875622	0103000020E61000000100000005000000755B22179CB743403DD4B66114F04640755B22179CB74340A6D6FB8D76F246407E9065C1C4C14340A6D6FB8D76F246407E9065C1C4C143403DD4B66114F04640755B22179CB743403DD4B66114F04640
22929	Новоджерелиевская	2	20	1198	38.635696000000003	38.692416000000001	45.786437999999997	45.759526000000001	0103000020E6100000010000000500000059198D7C5E514340193BE12538E1464059198D7C5E514340732A1900AAE44640139D6516A1584340732A1900AAE44640139D6516A1584340193BE12538E1464059198D7C5E514340193BE12538E14640
23220	Лиманский	2	20	1198	38.934520999999997	38.943441	45.867646999999998	45.860097000000003	0103000020E610000001000000050000006D3656629E774340A13193A817EE46406D3656629E7743407BBC900E0FEF46404F5AB8ACC27843407BBC900E0FEF46404F5AB8ACC2784340A13193A817EE46406D3656629E774340A13193A817EE4640
23286	Лебяжий Остров	2	20	1198	38.908082999999998	38.918008999999998	45.888415000000002	45.881483000000003	0103000020E61000000100000005000000DB8651103C744340707D586FD4F04640DB8651103C7443404F232D95B7F146408237A451817543404F232D95B7F146408237A45181754340707D586FD4F04640DB8651103C744340707D586FD4F04640
50874	Красная Поляна	2	20	1198	39.021217	39.029615999999997	45.776525999999997	45.761142	0103000020E61000000100000005000000438F183DB782434057CEDE196DE14640438F183DB7824340313F373465E346401BB80375CA834340313F373465E346401BB80375CA83434057CEDE196DE14640438F183DB782434057CEDE196DE14640
49360	Красная Нива	2	20	1198	38.999791999999999	39.033712999999999	45.758890999999998	45.730645000000003	0103000020E61000000100000005000000B6662B2FF97F434033FE7DC685DD4640B6662B2FF97F4340471D1D5723E146409B3924B550844340471D1D5723E146409B3924B55084434033FE7DC685DD4640B6662B2FF97F434033FE7DC685DD4640
23235	Киновия	2	20	1198	38.917327	38.945031	45.912354999999998	45.904980000000002	0103000020E61000000100000005000000705E9CF86A7543405DC47762D6F34640705E9CF86A754340C9AB730CC8F44640645A9BC6F6784340C9AB730CC8F44640645A9BC6F67843405DC47762D6F34640705E9CF86A7543405DC47762D6F34640
48464	Заря	2	20	1198	39.314579999999999	39.335510999999997	45.788781999999998	45.775708999999999	0103000020E61000000100000005000000E3FC4D2844A843403F1BB96E4AE34640E3FC4D2844A8434034D6FECEF6E4464060394206F2AA434034D6FECEF6E4464060394206F2AA43403F1BB96E4AE34640E3FC4D2844A843403F1BB96E4AE34640
22874	Гарбузовая Балка	2	20	1198	38.799216000000001	38.834905999999997	45.868493999999998	45.844239999999999	0103000020E610000001000000050000005038BBB54C664340CEFC6A0E10EC46405038BBB54C664340D862B7CF2AEF4640F99D2633DE6A4340D862B7CF2AEF4640F99D2633DE6A4340CEFC6A0E10EC46405038BBB54C664340CEFC6A0E10EC4640
50398	Брюховецкая	2	20	1198	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
11582	Брюховецкая	2	20	1198	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
50323	Большой Бейсуг	2	20	1198	39.154373999999997	39.262521999999997	45.810943000000002	45.775588999999997	0103000020E6100000010000000500000025ADF886C29343409411178046E3464025ADF886C2934340C7F5EFFACCE74640813D26529AA14340C7F5EFFACCE74640813D26529AA143409411178046E3464025ADF886C29343409411178046E34640
23684	Бол. Бейсуг	2	20	1198	39.154373999999997	39.262521999999997	45.810943000000002	45.775588999999997	0103000020E6100000010000000500000025ADF886C29343409411178046E3464025ADF886C2934340C7F5EFFACCE74640813D26529AA14340C7F5EFFACCE74640813D26529AA143409411178046E3464025ADF886C29343409411178046E34640
23045	Бейсугское	2	20	1198	38.692262999999997	38.708486000000001	45.895597000000002	45.873947000000001	0103000020E610000001000000050000008C9DF0129C584340FAB7CB7EDDEF46408C9DF0129C584340A7B228ECA2F2464041D653ABAF5A4340A7B228ECA2F2464041D653ABAF5A4340FAB7CB7EDDEF46408C9DF0129C584340FAB7CB7EDDEF4640
23767	Батуринская	2	20	1198	39.340254000000002	39.409683999999999	45.808354999999999	45.778354999999998	0103000020E61000000100000005000000A62A6D718DAB4340CBD6FA22A1E34640A62A6D718DAB43406F47382D78E74640E4D87A8670B443406F47382D78E74640E4D87A8670B44340CBD6FA22A1E34640A62A6D718DAB4340CBD6FA22A1E34640
50715	ст. Надежная	2	20	440	39.649939000000003	39.660511999999997	43.686515999999997	43.679931000000003	0103000020E610000001000000050000008EB27E3331D34340AF44A0FA07D745408EB27E3331D3434022179CC1DFD74540CA4E3FA88BD4434022179CC1DFD74540CA4E3FA88BD44340AF44A0FA07D745408EB27E3331D34340AF44A0FA07D74540
13823	Русская Мамайка	2	20	440	39.711796999999997	39.727983999999999	43.655537000000002	43.640501	0103000020E610000001000000050000000932022A1CDB43401407D0EFFBD145400932022A1CDB4340B328ECA2E8D34540710168942EDD4340B328ECA2E8D34540710168942EDD43401407D0EFFBD145400932022A1CDB43401407D0EFFBD14540
12377	Пластунка	2	20	440	39.747990000000001	39.774130999999997	43.706713999999998	43.656357999999997	0103000020E6100000010000000500000016DEE522BEDF4340E63BF88903D4454016DEE522BEDF43400BD0B69A75DA4540EEE87FB916E343400BD0B69A75DA4540EEE87FB916E34340E63BF88903D4454016DEE522BEDF4340E63BF88903D44540
15416	Новая Заря	2	20	440	39.739896000000002	39.753003	43.641303000000001	43.630178999999998	0103000020E610000001000000050000007A3881E9B4DE434020D099B4A9D045407A3881E9B4DE4340D1E9793716D245401B65FD6662E04340D1E9793716D245401B65FD6662E0434020D099B4A9D045407A3881E9B4DE434020D099B4A9D04540
15668	Новагинка	2	20	440	39.737470999999999	39.765597	43.628704999999997	43.600653000000001	0103000020E61000000100000005000000CC5F217365DE4340459F8F32E2CC4540CC5F217365DE434074EACA6779D0454036751E15FFE1434074EACA6779D0454036751E15FFE14340459F8F32E2CC4540CC5F217365DE4340459F8F32E2CC4540
10695	Мамайка	2	20	440	39.684173999999999	39.701152	43.639327000000002	43.625168000000002	0103000020E6100000010000000500000002637D0393D74340BC40498105D0454002637D0393D7434093399677D5D1454033C34659BFD9434093399677D5D1454033C34659BFD94340BC40498105D0454002637D0393D74340BC40498105D04540
9466	Барановка	2	20	440	39.730581000000001	39.757683	43.658439000000001	43.635432000000002	0103000020E610000001000000050000001C0A9FAD83DD43407B6AF5D555D145401C0A9FAD83DD43409AB4A9BA47D445401ADEACC1FBE043409AB4A9BA47D445401ADEACC1FBE043407B6AF5D555D145401C0A9FAD83DD43407B6AF5D555D14540
13693	Хоста	2	20	148	39.840400000000002	39.888387999999999	43.543098000000001	43.500216000000002	0103000020E610000001000000050000007AC7293A92EB4340CD77F01307C045407AC7293A92EB4340F2423A3C84C545405514AFB2B6F14340F2423A3C84C545405514AFB2B6F14340CD77F01307C045407AC7293A92EB4340CD77F01307C04540
8792	Хлебороб	2	20	148	39.876350000000002	39.896850000000001	43.568106999999998	43.554440999999997	0103000020E61000000100000005000000C0EC9E3C2CF04340E04735ECF7C64540C0EC9E3C2CF0434078D0ECBAB7C8454074B515FBCBF2434078D0ECBAB7C8454074B515FBCBF24340E04735ECF7C64540C0EC9E3C2CF04340E04735ECF7C64540
12468	Раздольное	2	20	148	39.760224999999998	39.779071999999999	43.601174999999998	43.582475000000002	0103000020E61000000100000005000000014D840D4FE143406ADE718A8ECA4540014D840D4FE143401E166A4DF3CC45405A9D9CA1B8E343401E166A4DF3CC45405A9D9CA1B8E343406ADE718A8ECA4540014D840D4FE143406ADE718A8ECA4540
12593	Прогресс	2	20	148	39.808625999999997	39.850389	43.616565999999999	43.572299999999998	0103000020E61000000100000005000000FF58880E81E743401AC05B2041C94540FF58880E81E74340ABE97AA2EBCE454067F0F78BD9EC4340ABE97AA2EBCE454067F0F78BD9EC43401AC05B2041C94540FF58880E81E743401AC05B2041C94540
50264	Новагинка	2	20	148	39.737470999999999	39.765597	43.628704999999997	43.600653000000001	0103000020E61000000100000005000000CC5F217365DE4340459F8F32E2CC4540CC5F217365DE434074EACA6779D0454036751E15FFE1434074EACA6779D0454036751E15FFE14340459F8F32E2CC4540CC5F217365DE4340459F8F32E2CC4540
9842	Малый Ахун	2	20	148	39.809649999999998	39.835808999999998	43.548253000000003	43.532249	0103000020E610000001000000050000006B9A779CA2E74340132A38BC20C445406B9A779CA2E743408A7780272DC64540EA5910CAFBEA43408A7780272DC64540EA5910CAFBEA4340132A38BC20C445406B9A779CA2E74340132A38BC20C44540
30712	Кудепста	2	20	148	39.877822999999999	39.914555999999997	43.509573000000003	43.490124999999999	0103000020E610000001000000050000009B560A815CF04340DBF97E6ABCBE45409B560A815CF043405AF624B039C14540272EC72B10F543405AF624B039C14540272EC72B10F54340DBF97E6ABCBE45409B560A815CF04340DBF97E6ABCBE4540
50698	Красный Октябрь	2	20	148	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
382	Красная Воля	2	20	148	39.900801999999999	39.936672000000002	43.570622	43.549219999999998	0103000020E61000000100000005000000F015DD7A4DF34340912749D74CC64540F015DD7A4DF34340663046240AC945401A8A3BDEE4F74340663046240AC945401A8A3BDEE4F74340912749D74CC64540F015DD7A4DF34340912749D74CC64540
48184	Измайловка	2	20	148	39.818210999999998	39.839205	43.635900999999997	43.622140000000002	0103000020E610000001000000050000001D1D5723BBE8434048C49448A2CF45401D1D5723BBE84340313F373465D14540E1D1C6116BEB4340313F373465D14540E1D1C6116BEB434048C49448A2CF45401D1D5723BBE8434048C49448A2CF4540
8095	Дубравный	2	20	148	39.890749999999997	39.910027999999997	43.519634000000003	43.508245000000002	0103000020E61000000100000005000000BC74931804F2434082AD122C0EC14540BC74931804F24340E1F1ED5D83C24540DE3829CC7BF44340E1F1ED5D83C24540DE3829CC7BF4434082AD122C0EC14540BC74931804F2434082AD122C0EC14540
40381	Бытха	2	20	148	39.750335	39.78951	43.573645999999997	43.546287	0103000020E61000000100000005000000A7052FFA0AE043406F9D7FBBECC54540A7052FFA0AE0434098BD6C3B6DC94540B7EEE6A90EE5434098BD6C3B6DC94540B7EEE6A90EE543406F9D7FBBECC54540A7052FFA0AE043406F9D7FBBECC54540
50368	микрорайон Якорная Щель	2	20	1078	39.489158000000003	39.517491	43.781146999999997	43.75779	0103000020E61000000100000005000000D449B6BA9CBE4340309E4143FFE04540D449B6BA9CBE43402B2FF99FFCE34540B77C24253DC243402B2FF99FFCE34540B77C24253DC24340309E4143FFE04540D449B6BA9CBE4340309E4143FFE04540
50284	микрорайон Дагомыс	2	20	1078	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
50712	аул Кургоковский	2	20	1078	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
11043	Якорная Щель	2	20	1078	39.489158000000003	39.517491	43.781146999999997	43.75779	0103000020E61000000100000005000000D449B6BA9CBE4340309E4143FFE04540D449B6BA9CBE43402B2FF99FFCE34540B77C24253DC243402B2FF99FFCE34540B77C24253DC24340309E4143FFE04540D449B6BA9CBE4340309E4143FFE04540
9524	Шахе	2	20	1078	39.460833999999998	39.492517999999997	43.797845000000002	43.772171	0103000020E610000001000000050000004371C79BFCBA4340B6F5D37FD6E245404371C79BFCBA43407923F3C81FE645407D586FD40ABF43407923F3C81FE645407D586FD40ABF4340B6F5D37FD6E245404371C79BFCBA4340B6F5D37FD6E24540
50318	Чемитоквадже	2	20	1078	39.418577999999997	39.434863999999997	43.837860999999997	43.827229000000003	0103000020E610000001000000050000009C69C2F693B54340C2A6CEA3E2E945409C69C2F693B5434003CC7C073FEB4540971AA19FA9B7434003CC7C073FEB4540971AA19FA9B74340C2A6CEA3E2E945409C69C2F693B54340C2A6CEA3E2E94540
50293	Харциз Первый	2	20	1078	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
10779	Солоники	2	20	1078	39.365523000000003	39.414230000000003	43.902873999999997	43.876322999999999	0103000020E61000000100000005000000C9772975C9AE4340C6DD205A2BF04540C9772975C9AE434050340F6091F34540D482177D05B5434050340F6091F34540D482177D05B54340C6DD205A2BF04540C9772975C9AE4340C6DD205A2BF04540
9976	Совет-Квадже	2	20	1078	39.210213000000003	39.241222999999998	44.009247000000002	43.979571	0103000020E61000000100000005000000D7187442E89A4340158E209562FD4540D7187442E89A4340064B75012F01464081053065E09E4340064B75012F01464081053065E09E4340158E209562FD4540D7187442E89A4340158E209562FD4540
11935	Сергей-Поле	2	20	1078	39.676879	39.735539000000003	43.691757000000003	43.657375999999999	0103000020E61000000100000005000000B22C98F8A3D64340709692E524D44540B22C98F8A3D64340B9E34D7E8BD845405EF7562426DE4340B9E34D7E8BD845405EF7562426DE4340709692E524D44540B22C98F8A3D64340709692E524D44540
12323	Нижняя Беранда	2	20	1078	39.514293000000002	39.538952000000002	43.765303000000003	43.745873000000003	0103000020E61000000100000005000000E7C75F5AD4C1434016FC36C478DF4540E7C75F5AD4C14340EE43DE72F5E14540910E0F61FCC44340EE43DE72F5E14540910E0F61FCC4434016FC36C478DF4540E7C75F5AD4C1434016FC36C478DF4540
12177	Мамедова Щель	2	20	1078	39.307285	39.320275000000002	43.955168999999998	43.947744999999998	0103000020E6100000010000000500000093C6681D55A7434048F949B54FF9454093C6681D55A74340969350FA42FA4540FB5C6DC5FEA84340969350FA42FA4540FB5C6DC5FEA8434048F949B54FF9454093C6681D55A7434048F949B54FF94540
9843	Макопсе	2	20	1078	39.188124000000002	39.213366999999998	44.013278999999997	43.992355000000003	0103000020E61000000100000005000000DECB7D7214984340D482177D05FF4540DECB7D72149843409E5C5320B3014640D7851F9C4F9B43409E5C5320B3014640D7851F9C4F9B4340D482177D05FF4540DECB7D7214984340D482177D05FF4540
9837	Магри	2	20	1078	39.152729999999998	39.173203000000001	44.026347999999999	44.013033	0103000020E610000001000000050000001D8F19A88C9343406762BA10AB0146401D8F19A88C93434052280B5F5F034640D84812842B96434052280B5F5F034640D84812842B9643406762BA10AB0146401D8F19A88C9343406762BA10AB014640
10081	Лоо	2	20	1078	39.572262000000002	39.605445000000003	43.715530999999999	43.691718000000002	0103000020E610000001000000050000002D5F97E13FC94340FB0626378AD845402D5F97E13FC943401823128596DB45406C43C5387FCD43401823128596DB45406C43C5387FCD4340FB0626378AD845402D5F97E13FC94340FB0626378AD84540
10702	Лазаревское	2	20	1078	39.297018000000001	39.364122000000002	43.945928000000002	43.88729	0103000020E61000000100000005000000632992AF04A64340AF08FEB792F14540632992AF04A64340732F302B14F9454087E0B88C9BAE4340732F302B14F9454087E0B88C9BAE4340AF08FEB792F14540632992AF04A64340AF08FEB792F14540
11491	Культурное Учдере	2	20	1078	39.618398999999997	39.651860999999997	43.681260999999999	43.658889000000002	0103000020E610000001000000050000008670CCB227CF4340DA58897956D445408670CCB227CF43402785798F33D74540D844662E70D343402785798F33D74540D844662E70D34340DA58897956D445408670CCB227CF4340DA58897956D44540
10856	Каткова Щель	2	20	1078	39.399065999999998	39.427767000000003	43.874588000000003	43.832613000000002	0103000020E6100000010000000500000007793D9814B34340BB9C121093EA454007793D9814B34340AEBCE47FF2EF45406EA7AD11C1B64340AEBCE47FF2EF45406EA7AD11C1B64340BB9C121093EA454007793D9814B34340BB9C121093EA4540
11544	Дагомыс	2	20	1078	39.642859999999999	39.687658999999996	43.685791999999999	43.648426999999998	0103000020E610000001000000050000000AF4893C49D24340F46BEBA7FFD245400AF4893C49D24340E1ED4108C8D7454068E6C93505D84340E1ED4108C8D7454068E6C93505D84340F46BEBA7FFD245400AF4893C49D24340F46BEBA7FFD24540
11583	Грузинская Мамайка	2	20	1078	39.637794	39.701627999999999	43.666617000000002	43.640689999999999	0103000020E61000000100000005000000E2CAD93BA3D14340E76F422102D24540E2CAD93BA3D1434094FAB2B453D545409CFA40F2CED9434094FAB2B453D545409CFA40F2CED94340E76F422102D24540E2CAD93BA3D14340E76F422102D24540
10008	Голубая Дача	2	20	1078	39.227837999999998	39.257266999999999	43.982432000000003	43.966861999999999	0103000020E610000001000000050000009D64ABCB299D434061DF4E22C2FB45409D64ABCB299D43409E45EF54C0FD454086AB0320EEA043409E45EF54C0FD454086AB0320EEA0434061DF4E22C2FB45409D64ABCB299D434061DF4E22C2FB4540
10369	Волковка	2	20	1078	39.647001000000003	39.678353000000001	43.706381999999998	43.677081999999999	0103000020E610000001000000050000005ABDC3EDD0D24340EA5A7B9FAAD645405ABDC3EDD0D24340D53DB2B96ADA45405E126745D4D64340D53DB2B96ADA45405E126745D4D64340EA5A7B9FAAD645405ABDC3EDD0D24340EA5A7B9FAAD64540
11371	Верхнее Буу	2	20	1078	39.547548999999997	39.577975000000002	43.767608000000003	43.745437000000003	0103000020E610000001000000050000008FFAEB1516C643403B1DC87A6ADF45408FFAEB1516C64340F1129CFA40E24540EB73B515FBC94340F1129CFA40E24540EB73B515FBC943403B1DC87A6ADF45408FFAEB1516C643403B1DC87A6ADF4540
11241	Верхнеармянское Лоо	2	20	1078	39.609434	39.629519999999999	43.744382000000002	43.732312999999998	0103000020E610000001000000050000000589EDEE01CE4340C3B7B06EBCDD45400589EDEE01CE434094DDCCE847DF4540C616821C94D0434094DDCCE847DF4540C616821C94D04340C3B7B06EBCDD45400589EDEE01CE4340C3B7B06EBCDD4540
11208	Вардане	2	20	1078	39.523904999999999	39.569279000000002	43.752091999999998	43.726345999999999	0103000020E61000000100000005000000FE9AAC510FC343404BCADDE7F8DC4540FE9AAC510FC34340A7CAF78C44E0454059A65F22DEC84340A7CAF78C44E0454059A65F22DEC843404BCADDE7F8DC4540FE9AAC510FC343404BCADDE7F8DC4540
10913	Большой Кичмай	2	20	1078	39.472396000000003	39.519620000000003	43.841079000000001	43.811970000000002	0103000020E610000001000000050000007061DD7877BC4340A4AA09A2EEE745407061DD7877BC43401B2D077AA8EB45407C2C7DE882C243401B2D077AA8EB45407C2C7DE882C24340A4AA09A2EEE745407061DD7877BC4340A4AA09A2EEE74540
11129	Беранда	2	20	1078	39.517473000000003	39.531613	43.775717999999998	43.765003999999998	0103000020E6100000010000000500000011C8258E3CC2434093A7ACA6EBE1454011C8258E3CC24340927538BA4AE34540719010E50BC44340927538BA4AE34540719010E50BC4434093A7ACA6EBE1454011C8258E3CC2434093A7ACA6EBE14540
50365	Высокое	2	20	7073	39.955419999999997	39.990094999999997	43.500647000000001	43.458329999999997	0103000020E61000000100000005000000DFF8DA334BFA43404963B48EAABA4540DFF8DA334BFA434096EB6D3315C045407077D66EBBFE434096EB6D3315C045407077D66EBBFE43404963B48EAABA4540DFF8DA334BFA43404963B48EAABA4540
50317	Веселое	2	20	7073	39.981318000000002	40.015185000000002	43.434899000000001	43.391461	0103000020E61000000100000005000000F27C06D49BFD43406954E0641BB24540F27C06D49BFD434014083BC5AAB74540E4310395F101444014083BC5AAB74540E4310395F10144406954E0641BB24540F27C06D49BFD43406954E0641BB24540
6574	Черешня	2	20	164	39.971626000000001	39.997101999999998	43.461596	43.430303000000002	0103000020E61000000100000005000000BEF8A23D5EFC4340732F302B14B74540BEF8A23D5EFC434072FBE59315BB45405A63D009A1FF434072FBE59315BB45405A63D009A1FF4340732F302B14B74540BEF8A23D5EFC4340732F302B14B74540
7182	Орел-Изумрудный	2	20	164	39.918669999999999	39.946579999999997	43.478430000000003	43.450968000000003	0103000020E610000001000000050000007DE882FA96F5434072C5C551B9B945407DE882FA96F5434070B6B9313DBD45401A868F8829F9434070B6B9313DBD45401A868F8829F9434072C5C551B9B945407DE882FA96F5434072C5C551B9B94540
50704	Нововмихайловский	2	20	164	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
6456	Нижняя Шиловка	2	20	164	39.993139999999997	40.037185000000001	43.483472999999996	43.429150999999997	0103000020E61000000100000005000000BA2C26361FFF4340D905836BEEB64540BA2C26361FFF4340DFBF7971E2BD45406D73637AC2044440DFBF7971E2BD45406D73637AC2044440D905836BEEB64540BA2C26361FFF4340D905836BEEB64540
50280	Нижнеимеретинская Бухта	2	20	164	39.926341000000001	39.995952000000003	43.417830000000002	43.385814000000003	0103000020E61000000100000005000000D3F8855792F64340632B685A62B14540D3F8855792F64340D3A414747BB545406231EA5A7BFF4340D3A414747BB545406231EA5A7BFF4340632B685A62B14540D3F8855792F64340632B685A62B14540
8335	Молдовка	2	20	164	39.931542999999998	39.963836999999998	43.463166000000001	43.448075000000003	0103000020E61000000100000005000000ABE80FCD3CF74340DE9387855AB94540ABE80FCD3CF74340404F030649BB45405ED6C4025FFB4340404F030649BB45405ED6C4025FFB4340DE9387855AB94540ABE80FCD3CF74340DE9387855AB94540
504	Веселое	2	20	164	39.957531000000003	40.032873000000002	43.476937999999997	43.394441999999998	0103000020E61000000100000005000000FEF3346090FA43409C1551137DB24540FEF3346090FA43401D1CEC4D0CBD4540F1F5B52E350444401D1CEC4D0CBD4540F1F5B52E350444409C1551137DB24540FEF3346090FA43409C1551137DB24540
8028	Верхнениколаевское	2	20	164	39.914205000000003	39.953721999999999	43.531112	43.497705000000003	0103000020E610000001000000050000007B6B60AB04F54340210725CCB4BF45407B6B60AB04F54340AF415F7AFBC34540E4BCFF8F13FA4340AF415F7AFBC34540E4BCFF8F13FA4340210725CCB4BF45407B6B60AB04F54340210725CCB4BF4540
13104	Адлер	2	20	164	39.886178000000001	39.967556000000002	43.494284	43.414648	0103000020E61000000100000005000000A437DC476EF1434008AD872F13B54540A437DC476EF14340D177B7B244BF4540388600E0D8FB4340D177B7B244BF4540388600E0D8FB434008AD872F13B54540A437DC476EF1434008AD872F13B54540
47651	Южный	2	20	1205	39.844056000000002	39.886958999999997	44.737653999999999	44.717506999999998	0103000020E610000001000000050000000DFFE9060AEC434056D3F544D75B46400DFFE9060AEC4340BDE13E726B5E464049F25CDF87F14340BDE13E726B5E464049F25CDF87F1434056D3F544D75B46400DFFE9060AEC434056D3F544D75B4640
20418	Школьное	2	20	1205	39.835225000000001	39.864590999999997	44.921968	44.889901000000002	0103000020E610000001000000050000009BE61DA7E8EA4340BFD6A546E87146409BE61DA7E8EA4340B1FA230C037646403DB5FAEAAAEE4340B1FA230C037646403DB5FAEAAAEE4340BFD6A546E87146409BE61DA7E8EA4340BFD6A546E8714640
21652	Черниговская	2	20	1205	39.655498999999999	39.687677000000001	44.718564000000001	44.683852000000002	0103000020E61000000100000005000000C5C72764E7D34340F0A65B7688574640C5C72764E7D343409E0AB8E7F95B46400F9BC8CC05D843409E0AB8E7F95B46400F9BC8CC05D84340F0A65B7688574640C5C72764E7D34340F0A65B7688574640
21189	Фокин Первый	2	20	1205	39.514598999999997	39.524299999999997	45.018965000000001	45.009954999999998	0103000020E61000000100000005000000F3C64961DEC1434041B7973446814640F3C64961DEC143406362F3716D8246407AA52C431CC343406362F3716D8246407AA52C431CC3434041B7973446814640F3C64961DEC1434041B7973446814640
22148	Фадеевский	2	20	1205	39.856200999999999	39.879018000000002	44.647162999999999	44.635528999999998	0103000020E61000000100000005000000B8E68EFE97ED43406D54A70359514640B8E68EFE97ED43403317B83CD6524640344C6DA983F043403317B83CD6524640344C6DA983F043406D54A70359514640B8E68EFE97ED43406D54A70359514640
46907	Северный	2	20	1205	39.588476	39.606766	45.043469999999999	45.025807	0103000020E610000001000000050000008E3D7B2E53CB43400281CEA44D8346408E3D7B2E53CB4340B62DCA6C9085464091291F82AACD4340B62DCA6C9085464091291F82AACD43400281CEA44D8346408E3D7B2E53CB43400281CEA44D834640
48541	Садовый	2	20	1205	39.814807000000002	39.823591999999998	44.790753000000002	44.782333999999999	0103000020E61000000100000005000000A4C684984BE843404146408523644640A4C684984BE84340611BF16437654640A59F70766BE94340611BF16437654640A59F70766BE943404146408523644640A4C684984BE843404146408523644640
21215	Рязанская	2	20	1205	39.555732999999996	39.606459999999998	44.977708	44.940384000000002	0103000020E610000001000000050000006B274A4222C7434041D7BE805E7846406B274A4222C74340CF842689257D4640842A357BA0CD4340CF842689257D4640842A357BA0CD434041D7BE805E7846406B274A4222C7434041D7BE805E784640
48469	Родники	2	20	1205	39.908698999999999	39.920341000000001	44.744836999999997	44.732191999999998	0103000020E610000001000000050000003674B33F50F443404832AB77B85D46403674B33F50F44340E5EC9DD1565F46407F15E0BBCDF54340E5EC9DD1565F46407F15E0BBCDF543404832AB77B85D46403674B33F50F443404832AB77B85D4640
22165	Пшехская	2	20	1205	39.776484000000004	39.821849	44.716341	44.676051999999999	0103000020E6100000010000000500000003EFE4D363E343409C3237DF8856464003EFE4D363E3434058E4D70FB15B46400AA0185932E9434058E4D70FB15B46400AA0185932E943409C3237DF8856464003EFE4D363E343409C3237DF88564640
48759	Проточный	2	20	1205	39.759452000000003	39.778452000000001	44.874248000000001	44.852404	0103000020E61000000100000005000000DF701FB935E14340637D03931B6D4640DF701FB935E14340F54BC45BE76F4640BEC0AC50A4E34340F54BC45BE76F4640BEC0AC50A4E34340637D03931B6D4640DF701FB935E14340637D03931B6D4640
50267	Пос.Первомайский	2	20	1205	39.726951	39.753585999999999	44.905008000000002	44.885603000000003	0103000020E61000000100000005000000B265F9BA0CDD4340A81E69705B714640B265F9BA0CDD4340274F594DD77346409A5C8C8175E04340274F594DD77346409A5C8C8175E04340A81E69705B714640B265F9BA0CDD4340A81E69705B714640
50360	Октябрьская	2	20	1205	39.605814000000002	39.63288	44.860582999999998	44.843234000000002	0103000020E61000000100000005000000BFBA2A508BCD434009707A17EF6B4640BFBA2A508BCD43402D3F7095276E464070253B3602D143402D3F7095276E464070253B3602D1434009707A17EF6B4640BFBA2A508BCD434009707A17EF6B4640
21577	Новогурийский	2	20	1205	39.646867	39.661355999999998	44.787593000000001	44.774624000000003	0103000020E610000001000000050000004AEEB089CCD243402E5915E1266346404AEEB089CCD243407EC7F0D8CF644640B6813B50A7D443407EC7F0D8CF644640B6813B50A7D443402E5915E1266346404AEEB089CCD243402E5915E126634640
32941	Новоалексеевское	2	20	1205	39.851512	39.873583000000004	44.963659999999997	44.946112999999997	0103000020E6100000010000000500000066136058FEEC434004A9143B1A79464066136058FEEC43404F3BFC35597B4640B9AB5791D1EF43404F3BFC35597B4640B9AB5791D1EF434004A9143B1A79464066136058FEEC434004A9143B1A794640
21351	Нижневеденеевский	2	20	1205	39.646399000000002	39.663764	44.888317000000001	44.868957999999999	0103000020E610000001000000050000006495D233BDD243407DCC07043A6F46406495D233BDD243408CBD175FB47146408E210038F6D443408CBD175FB47146408E210038F6D443407DCC07043A6F46406495D233BDD243407DCC07043A6F4640
48813	Молодежный	2	20	1205	39.666189000000003	39.690049000000002	44.685901999999999	44.670397999999999	0103000020E610000001000000050000003CFA5FAE45D54340E3A6069ACF5546403CFA5FAE45D54340682101A3CB5746409AD18F8653D84340682101A3CB5746409AD18F8653D84340E3A6069ACF5546403CFA5FAE45D54340E3A6069ACF554640
48643	Леонтьевское	2	20	1205	39.770071000000002	39.787227999999999	44.904848000000001	44.894658	0103000020E610000001000000050000008C4CC0AF91E24340698D4127847246408C4CC0AF91E24340EEEC2B0FD27346406C3F19E3C3E44340EEEC2B0FD27346406C3F19E3C3E44340698D4127847246408C4CC0AF91E24340698D412784724640
20569	Лантратов	2	20	1205	39.911160000000002	39.934058	44.919944999999998	44.904381999999998	0103000020E6100000010000000500000031B610E4A0F44340A88B14CAC273464031B610E4A0F44340328FFCC1C0754640994869368FF74340328FFCC1C0754640994869368FF74340A88B14CAC273464031B610E4A0F44340A88B14CAC2734640
50746	Заречный	2	20	1205	39.815416999999997	39.842385	44.770772000000001	44.740361999999998	0103000020E610000001000000050000001CCD91955FE84340BF99982EC45E46401CCD91955FE8434015562AA8A86246400BD28C45D3EB434015562AA8A86246400BD28C45D3EB4340BF99982EC45E46401CCD91955FE84340BF99982EC45E4640
21831	Дружный	2	20	1205	39.759963999999997	39.787075999999999	44.749338000000002	44.713375999999997	0103000020E610000001000000050000009411178046E143402AE09EE74F5B46409411178046E1434035D3BD4EEA5F4640B6BB07E8BEE4434035D3BD4EEA5F4640B6BB07E8BEE443402AE09EE74F5B46409411178046E143402AE09EE74F5B4640
21924	Долгогусевский	2	20	1205	39.771391000000001	39.799266000000003	44.827184000000003	44.787413999999998	0103000020E61000000100000005000000E1B6B6F0BCE24340CE3461FBC9644640E1B6B6F0BCE2434022E3512AE1694640026729594EE6434022E3512AE1694640026729594EE64340CE3461FBC9644640E1B6B6F0BCE24340CE3461FBC9644640
21740	Гурийская	2	20	1205	39.603262000000001	39.625388000000001	44.675474999999999	44.638088000000003	0103000020E61000000100000005000000B47570B037CD43402BFC19DEAC514640B47570B037CD4340FF21FDF675564640CAA7C7B60CD04340FF21FDF675564640CAA7C7B60CD043402BFC19DEAC514640B47570B037CD43402BFC19DEAC514640
21129	Ганжинский	2	20	1205	39.669719999999998	39.686976000000001	44.909668000000003	44.900436999999997	0103000020E6100000010000000500000012BD8C62B9D54340DE8D05854173464012BD8C62B9D54340DF1B43007074464086915ED4EED74340DF1B43007074464086915ED4EED74340DE8D05854173464012BD8C62B9D54340DE8D058541734640
20856	Верхневеденеевский	2	20	1205	39.770806999999998	39.793875999999997	44.839987000000001	44.828736999999997	0103000020E610000001000000050000009143C4CDA9E2434019FED30D146A46409143C4CDA9E243405708ABB1846B4640268A90BA9DE543405708ABB1846B4640268A90BA9DE5434019FED30D146A46409143C4CDA9E2434019FED30D146A4640
20721	Великовечное	2	20	1205	39.717564000000003	39.785333000000001	44.958998000000001	44.910069999999997	0103000020E61000000100000005000000BB641C23D9DB43400D897B2C7D744640BB641C23D9DB4340F7764B72C07A46401BBCAFCA85E44340F7764B72C07A46401BBCAFCA85E443400D897B2C7D744640BB641C23D9DB43400D897B2C7D744640
21439	Бжедуховская	2	20	1205	39.663207	39.700451000000001	44.857120000000002	44.823687	0103000020E6100000010000000500000038BD8BF7E3D44340F7915B936E69464038BD8BF7E3D44340AF5FB01BB66D4640AAB9DC60A8D94340AF5FB01BB66D4640AAB9DC60A8D94340F7915B936E69464038BD8BF7E3D44340F7915B936E694640
11745	Белореченск	2	20	1205	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
40522	Белореченск	2	20	1205	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
32947	Архиповское	2	20	1205	39.843947999999997	39.862301000000002	45.015613000000002	44.995654000000002	0103000020E6100000010000000500000026C3F17C06EC4340D8101C97717F464026C3F17C06EC43403C32569BFF814640702711E15FEE43403C32569BFF814640702711E15FEE4340D8101C97717F464026C3F17C06EC4340D8101C97717F4640
18051	Центральный	2	20	1501	40.834609999999998	40.857472000000001	46.204796000000002	46.192576000000003	0103000020E6100000010000000500000010751F80D46A44404CFF9254A618474010751F80D46A4440022D5DC1361A47402C9E7AA4C16D4440022D5DC1361A47402C9E7AA4C16D44404CFF9254A618474010751F80D46A44404CFF9254A6184740
18377	Успенская	2	20	1501	41.023201999999998	41.097690999999998	45.791024999999998	45.745955000000002	0103000020E61000000100000005000000D4997B48F8824440D3A414747BDF4640D4997B48F8824440C1A8A44E40E54640880E8123818C4440C1A8A44E40E54640880E8123818C4440D3A414747BDF4640D4997B48F8824440D3A414747BDF4640
18472	Туркинский	2	20	1501	40.948551999999999	40.961855999999997	45.744363999999997	45.723925000000001	0103000020E610000001000000050000001747E5266A794440DFE00B93A9DC46401747E5266A794440ED28CE5147DF46400EBBEF181E7B4440ED28CE5147DF46400EBBEF181E7B4440DFE00B93A9DC46401747E5266A794440DFE00B93A9DC4640
17991	Селекционный	2	20	1501	40.698695000000001	40.721611000000003	46.189725000000003	46.182712000000002	0103000020E610000001000000050000007A7077D66E5944401B4B581B631747407A7077D66E594440E71DA7E84818474089B7CEBF5D5C4440E71DA7E84818474089B7CEBF5D5C44401B4B581B631747407A7077D66E5944401B4B581B63174740
18074	Садовый	2	20	1501	40.905954000000001	40.926102999999998	46.202638	46.198994999999996	0103000020E6100000010000000500000017D7F84CF6734440A4880CAB7819474017D7F84CF6734440A376BF0AF01947401EDD088B8A764440A376BF0AF01947401EDD088B8A764440A4880CAB7819474017D7F84CF6734440A4880CAB78194740
18186	Новопавловка	2	20	1501	40.921810000000001	41.012072000000003	46.002043999999998	45.961154999999998	0103000020E610000001000000050000001990BDDEFD75444085B1852007FB46401990BDDEFD754440969350FA42004740429946938B814440969350FA42004740429946938B81444085B1852007FB46401990BDDEFD75444085B1852007FB4640
18315	Новолокинская	2	20	1501	41.198563	41.230694999999997	45.811942000000002	45.791226999999999	0103000020E610000001000000050000000B992B836A994440295B24ED46E546400B992B836A994440DA1F28B7EDE74640E42CEC69879D4440DA1F28B7EDE74640E42CEC69879D4440295B24ED46E546400B992B836A994440295B24ED46E54640
18285	Меклета	2	20	1501	40.963203999999998	41.014983000000001	45.899737000000002	45.879173999999999	0103000020E610000001000000050000002DB0C7444A7B44402BBF0CC688F046402DB0C7444A7B44402600FF942AF346407C7F83F6EA8144402600FF942AF346407C7F83F6EA8144402BBF0CC688F046402DB0C7444A7B44402BBF0CC688F04640
18158	Магистральный	2	20	1501	40.959789999999998	40.981332000000002	46.278257000000004	46.268813999999999	0103000020E6100000010000000500000090831266DA7A44407D5A457F6822474090831266DA7A44400971E5EC9D234740574277499C7D44400971E5EC9D234740574277499C7D44407D5A457F6822474090831266DA7A44407D5A457F68224740
18220	Кулешовка	2	20	1501	41.062610999999997	41.126778000000002	45.969135999999999	45.951687999999997	0103000020E6100000010000000500000057AF22A30388444071FF91E9D0F9464057AF22A30388444029B000A60CFC464018EDF1423A90444029B000A60CFC464018EDF1423A90444071FF91E9D0F9464057AF22A30388444071FF91E9D0F94640
17927	Западный	2	20	1501	40.594921999999997	40.611424	46.179310999999998	46.171754	0103000020E61000000100000005000000E0D57267264C4440857AFA08FC154740E0D57267264C44401268B0A9F3164740A8FE4124434E44401268B0A9F3164740A8FE4124434E4440857AFA08FC154740E0D57267264C4440857AFA08FC154740
17464	Белая Глина	2	20	1501	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
12901	Ширванская	2	20	722	39.797396999999997	39.820008000000001	44.389504000000002	44.367148	0103000020E61000000100000005000000D976DA1A11E643405A65A6B4FE2E4640D976DA1A11E64340A2D45E44DB314640AC3AAB05F6E84340A2D45E44DB314640AC3AAB05F6E843405A65A6B4FE2E4640D976DA1A11E643405A65A6B4FE2E4640
45660	Черниговское	2	20	722	39.748384999999999	39.775191	44.263804999999998	44.241484999999997	0103000020E6100000010000000500000092E86514CBDF4340BEBC00FBE81E464092E86514CBDF4340B9C2BB5CC4214640A7936C7539E34340B9C2BB5CC4214640A7936C7539E34340BEBC00FBE81E464092E86514CBDF4340BEBC00FBE81E4640
50827	Цуревский	2	20	722	39.784559999999999	39.794288999999999	44.413507000000003	44.404877999999997	0103000020E61000000100000005000000F8DF4A766CE44340586FD40AD3334640F8DF4A766CE4434063D520CCED34464049490F43ABE5434063D520CCED34464049490F43ABE54340586FD40AD3334640F8DF4A766CE44340586FD40AD3334640
12074	Хадыженск	2	20	722	39.510682000000003	39.552418000000003	44.466236000000002	44.384737999999999	0103000020E61000000100000005000000F4531C075EC14340A4C343183F314640F4531C075EC14340E31B0A9FAD3B464062DC0DA2B5C64340E31B0A9FAD3B464062DC0DA2B5C64340A4C343183F314640F4531C075EC14340A4C343183F314640
13244	Тубы	2	20	722	39.682071999999998	39.692841999999999	44.118566999999999	44.105842000000003	0103000020E6100000010000000500000037C2A2224ED7434089450C3B8C0D464037C2A2224ED7434042B115342D0F4640CAA5F10BAFD8434042B115342D0F4640CAA5F10BAFD8434089450C3B8C0D464037C2A2224ED7434089450C3B8C0D4640
50897	Травалев	2	20	722	39.525432000000002	39.553145000000001	44.376767999999998	44.360833	0103000020E61000000100000005000000CD22145B41C34340A62897C62F2E4640CD22145B41C34340F4160FEF3930464014799274CDC64340F4160FEF3930464014799274CDC64340A62897C62F2E4640CD22145B41C34340A62897C62F2E4640
13794	Тверская	2	20	722	39.597396000000003	39.628568000000001	44.621262000000002	44.585714000000003	0103000020E610000001000000050000007061DD7877CC4340996725ADF84A46407061DD7877CC4340B01F6283854F4640F4A78DEA74D04340B01F6283854F4640F4A78DEA74D04340996725ADF84A46407061DD7877CC4340996725ADF84A4640
45837	Станционный	2	20	722	39.462622000000003	39.490461000000003	44.442917999999999	44.430329	0103000020E610000001000000050000007F349C3237BB43409CC24A05153746407F349C3237BB4340A5677A89B1384640537B116DC7BE4340A5677A89B1384640537B116DC7BE43409CC24A05153746407F349C3237BB43409CC24A0515374640
50305	Спасов	2	20	722	39.652794999999998	39.671973999999999	44.445594999999997	44.435600999999998	0103000020E6100000010000000500000004FF5BC98ED343406D8D08C6C137464004FF5BC98ED343406C21C8410939464093E1783E03D643406C21C8410939464093E1783E03D643406D8D08C6C137464004FF5BC98ED343406D8D08C6C1374640
50513	Самурская	2	20	722	39.816234999999999	39.840902999999997	44.286878999999999	44.265368000000002	0103000020E61000000100000005000000DF6C73637AE84340D5B32094F7214640DF6C73637AE8434060747973B8244640DC0DA2B5A2EB434060747973B8244640DC0DA2B5A2EB4340D5B32094F7214640DF6C73637AE84340D5B32094F7214640
13271	Режет	2	20	722	39.677005000000001	39.689473999999997	44.192281000000001	44.181105000000002	0103000020E610000001000000050000003F1D8F19A8D643403012DA722E1746403F1D8F19A8D643403352EFA99C1846409DB81CAF40D843403352EFA99C1846409DB81CAF40D843403012DA722E1746403F1D8F19A8D643403012DA722E174640
45713	Отдаленный	2	20	722	39.697792	39.711024000000002	44.073664000000001	44.060637999999997	0103000020E6100000010000000500000089B48D3F51D943408A7269FCC207464089B48D3F51D943403F726BD26D094640E7559DD502DB43403F726BD26D094640E7559DD502DB43408A7269FCC207464089B48D3F51D943408A7269FCC2074640
12821	Новые Поляны	2	20	722	39.814160000000001	39.838476999999997	44.312064999999997	44.289833999999999	0103000020E610000001000000050000000EDB166536E843406AA2CF47192546400EDB166536E84340F59CF4BEF12746405EB9DE3653EB4340F59CF4BEF12746405EB9DE3653EB43406AA2CF47192546400EDB166536E843406AA2CF4719254640
50871	Николаенко	2	20	722	39.670205000000003	39.679574000000002	44.414717000000003	44.400286000000001	0103000020E61000000100000005000000CF4E0647C9D54340F98557923C334640CF4E0647C9D54340310C587215354640209BE447FCD64340310C587215354640209BE447FCD64340F98557923C334640CF4E0647C9D54340F98557923C334640
45619	Нижегородская	2	20	722	39.913127000000003	39.928398999999999	44.291538000000003	44.254935000000003	0103000020E610000001000000050000001C0C7558E1F443408ACDC7B5A12046401C0C7558E1F4434048C5FF1D51254640CE5147C7D5F6434048C5FF1D51254640CE5147C7D5F643408ACDC7B5A12046401C0C7558E1F443408ACDC7B5A1204640
50747	Нефтяная	2	20	722	39.624274	39.666423000000002	44.389118000000003	44.361167999999999	0103000020E610000001000000050000001EDFDE35E8CF43404D2EC6C03A2E46401EDFDE35E8CF434079245E9ECE314640AF264F594DD5434079245E9ECE314640AF264F594DD543404D2EC6C03A2E46401EDFDE35E8CF43404D2EC6C03A2E4640
9757	Нефтегорск	2	20	722	39.681424999999997	39.750236000000001	44.406623000000003	44.343693999999999	0103000020E61000000100000005000000A1D634EF38D743406CEA3C2AFE2B4640A1D634EF38D743409566F3380C3446401424B6BB07E043409566F3380C3446401424B6BB07E043406CEA3C2AFE2B4640A1D634EF38D743406CEA3C2AFE2B4640
13125	Мезмай	2	20	722	39.945089000000003	39.968885999999998	44.208508000000002	44.191640999999997	0103000020E61000000100000005000000996725ADF8F843404FC939B187184640996725ADF8F84340297AE063B01A4640B0C6D97404FC4340297AE063B01A4640B0C6D97404FC43404FC939B187184640996725ADF8F843404FC939B187184640
50844	Малько	2	20	722	39.678325999999998	39.692338999999997	44.469073000000002	44.461019	0103000020E610000001000000050000006403E962D3D64340D5EAABAB023B46406403E962D3D64340E33785950A3C4640675F79909ED84340E33785950A3C4640675F79909ED84340D5EAABAB023B46406403E962D3D64340D5EAABAB023B4640
50884	Линейная	2	20	722	39.479897000000001	39.498707000000003	44.598481	44.586536000000002	0103000020E610000001000000050000006939D0436DBD43409DF6949C134B46406939D0436DBD4340812381069B4C4640A5A487A1D5BF4340812381069B4C4640A5A487A1D5BF43409DF6949C134B46406939D0436DBD43409DF6949C134B4640
50896	Лесогорская	2	20	722	39.526069999999997	39.550361000000002	44.551782000000003	44.539563999999999	0103000020E610000001000000050000000FB4024356C34340AA0CE36E104546400FB4024356C34340C042E6CAA046464037FFAF3A72C64340C042E6CAA046464037FFAF3A72C64340AA0CE36E104546400FB4024356C34340AA0CE36E10454640
50651	Куринская	2	20	722	39.401212999999998	39.442194000000001	44.424670999999996	44.395893999999998	0103000020E6100000010000000500000072DD94F25AB34340605793A7AC32464072DD94F25AB34340A1478C9E5B364640643E20D099B84340A1478C9E5B364640643E20D099B84340605793A7AC32464072DD94F25AB34340605793A7AC324640
50653	Куринская	2	20	722	39.401212999999998	39.442194000000001	44.424670999999996	44.395893999999998	0103000020E6100000010000000500000072DD94F25AB34340605793A7AC32464072DD94F25AB34340A1478C9E5B364640643E20D099B84340A1478C9E5B364640643E20D099B84340605793A7AC32464072DD94F25AB34340605793A7AC324640
13329	Кабардинская	2	20	722	39.477767999999998	39.509405999999998	44.521211999999998	44.478456999999999	0103000020E61000000100000005000000A489778027BD434069C537143E3D4640A489778027BD434031242713B74246406E313F3734C1434031242713B74246406E313F3734C1434069C537143E3D4640A489778027BD434069C537143E3D4640
50868	Заречный	2	20	722	39.727966000000002	39.737622999999999	44.602249	44.594534000000003	0103000020E61000000100000005000000CB4C69FD2DDD4340172EABB0194C4640CB4C69FD2DDD43403C86C77E164D464082E3326E6ADE43403C86C77E164D464082E3326E6ADE4340172EABB0194C4640CB4C69FD2DDD4340172EABB0194C4640
50258	Зазулин	2	20	722	39.814402000000001	39.845070999999997	44.449714	44.430231999999997	0103000020E6100000010000000500000004E621533EE84340A9D898D71137464004E621533EE84340D446753A9039464025E659492BEC4340D446753A9039464025E659492BEC4340A9D898D71137464004E621533EE84340A9D898D711374640
13606	Ерик	2	20	722	39.686149999999998	39.712353999999998	44.595368000000001	44.572405000000003	0103000020E61000000100000005000000401361C3D3D743409088299144494640401361C3D3D74340DF8AC404354C46405F96766A2EDB4340DF8AC404354C46405F96766A2EDB43409088299144494640401361C3D3D743409088299144494640
12989	Гуамка	2	20	722	39.897424999999998	39.906336000000003	44.239547999999999	44.224783000000002	0103000020E6100000010000000500000070CE88D2DEF2434030D978B0C51C464070CE88D2DEF243403EE94482A91E4640FF976BD102F443403EE94482A91E4640FF976BD102F4434030D978B0C51C464070CE88D2DEF2434030D978B0C51C4640
32682	Вперед	2	20	722	39.697127000000002	39.713683000000003	44.569592	44.527065999999998	0103000020E610000001000000050000004D1421753BD94340B16A10E6764346404D1421753BD9434018080264E8484640085BECF659DB434018080264E8484640085BECF659DB4340B16A10E6764346404D1421753BD94340B16A10E676434640
10038	Апшеронск	2	20	722	39.673026	39.795762000000003	44.487043	44.420718000000001	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
50326	Апшеронск	2	20	722	39.673026	39.795762000000003	44.487043	44.420718000000001	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
50276	ст.Гостагаевская	2	20	1018	37.264471999999998	37.396272000000003	45.082304999999998	44.988852000000001	0103000020E61000000100000005000000965AEF37DAA14240C74ACCB3927E4640965AEF37DAA142400DA661F8888A46400729780AB9B242400DA661F8888A46400729780AB9B24240C74ACCB3927E4640965AEF37DAA14240C74ACCB3927E4640
32915	Юровка	2	20	1018	37.392077	37.439275000000002	45.119422	45.108144000000003	0103000020E61000000100000005000000C44142942FB242401BA19FA9D78D4640C44142942FB2424022365838498F4640A779C7293AB8424022365838498F4640A779C7293AB842401BA19FA9D78D4640C44142942FB242401BA19FA9D78D4640
50732	Черный	2	20	1018	37.370238999999998	37.388160999999997	45.088554000000002	45.083112999999997	0103000020E61000000100000005000000145AD6FD63AF4240AC6F6072A38A4640145AD6FD63AF42400AF7CABC558B4640944A7842AFB142400AF7CABC558B4640944A7842AFB14240AC6F6072A38A4640145AD6FD63AF4240AC6F6072A38A4640
8867	Чембурка	2	20	1018	37.329859999999996	37.356028000000002	44.932274	44.925426999999999	0103000020E6100000010000000500000018213CDA38AA4240EEEA55647476464018213CDA38AA42409F7422C154774640EB3A545392AD42409F7422C154774640EB3A545392AD4240EEEA55647476464018213CDA38AA4240EEEA556474764640
10545	Цибанобалка	2	20	1018	37.321038000000001	37.369017999999997	44.986308999999999	44.974437000000002	0103000020E61000000100000005000000FA62EFC517A942409581035ABA7C4640FA62EFC517A942400F60915F3F7E464052D158FB3BAF42400F60915F3F7E464052D158FB3BAF42409581035ABA7C4640FA62EFC517A942409581035ABA7C4640
32786	Усатова Балка	2	20	1018	37.417230000000004	37.437218000000001	44.898871999999997	44.889467000000003	0103000020E610000001000000050000007E74EACA67B5424085EFFD0DDA7146407E74EACA67B5424022A5D93C0E7346407C9C69C2F6B7424022A5D93C0E7346407C9C69C2F6B7424085EFFD0DDA7146407E74EACA67B5424085EFFD0DDA714640
10845	Супсех	2	20	1018	37.349479000000002	37.382708000000001	44.871699	44.855854999999998	0103000020E61000000100000005000000C4D155BABBAC42401D8F19A88C6D4640C4D155BABBAC42405B7A34D5936F464073F56393FCB042405B7A34D5936F464073F56393FCB042401D8F19A88C6D4640C4D155BABBAC42401D8F19A88C6D4640
10940	Сукко	2	20	1018	37.404842000000002	37.442886000000001	44.803244999999997	44.791936	0103000020E610000001000000050000000C06D7DCD1B342403543AA285E6546400C06D7DCD1B3424077D66EBBD06646409AED0A7DB0B8424077D66EBBD06646409AED0A7DB0B842403543AA285E6546400C06D7DCD1B342403543AA285E654640
32832	Суворов-Черкесский	2	20	1018	37.261256000000003	37.286552	45.077677999999999	45.058905000000003	0103000020E6100000010000000500000020F12BD670A142401349F4328A87464020F12BD670A1424031CF4A5AF18946403C4D66BCADA4424031CF4A5AF18946403C4D66BCADA442401349F4328A87464020F12BD670A142401349F4328A874640
10699	Пятихатки	2	20	1018	37.295383000000001	37.319313999999999	44.982503000000001	44.966338999999998	0103000020E61000000100000005000000AE65321CCFA54240B7EC10FFB07B4640AE65321CCFA54240679C86A8C27D4640D593F947DFA84240679C86A8C27D4640D593F947DFA84240B7EC10FFB07B4640AE65321CCFA54240B7EC10FFB07B4640
10985	Просторный	2	20	1018	37.372816999999998	37.386032	44.962493000000002	44.927481999999998	0103000020E610000001000000050000004832AB77B8AF424078D0ECBAB77646404832AB77B8AF424081D07AF8327B4640D09A1F7F69B1424081D07AF8327B4640D09A1F7F69B1424078D0ECBAB77646404832AB77B8AF424078D0ECBAB7764640
32978	Ниж. Гостагайка	2	20	1018	37.335276999999998	37.369636999999997	45.043508000000003	45.033617	0103000020E61000000100000005000000ED0C535BEAAA424079CBD58F4D844640ED0C535BEAAA4240A48E8EAB918546401E32E54350AF4240A48E8EAB918546401E32E54350AF424079CBD58F4D844640ED0C535BEAAA424079CBD58F4D844640
50355	Красный Курган	2	20	1018	37.326329999999999	37.358300999999997	45.018709999999999	45.010592000000003	0103000020E6100000010000000500000012DA722EC5A94240B4CC22145B81464012DA722EC5A94240D80DDB1665824640E28FA2CEDCAD4240D80DDB1665824640E28FA2CEDCAD4240B4CC22145B81464012DA722EC5A94240B4CC22145B814640
50498	Красная Горка	2	20	1018	37.451025000000001	37.461984000000001	45.134315000000001	45.128847	0103000020E61000000100000005000000D656EC2FBBB942400798F90E7E904640D656EC2FBBB942405E2EE23B319146403CA3AD4A22BB42405E2EE23B319146403CA3AD4A22BB42400798F90E7E904640D656EC2FBBB942400798F90E7E904640
50839	Иванов	2	20	1018	37.437809999999999	37.467436999999997	45.119745999999999	45.104722000000002	0103000020E610000001000000050000004EEE77280AB84240FB95CE87678D46404EEE77280AB84240D5E940D6538F46405DF8C1F9D4BB4240D5E940D6538F46405DF8C1F9D4BB4240FB95CE87678D46404EEE77280AB84240FB95CE87678D4640
9950	Джигинка	2	20	1018	37.324533000000002	37.360509999999998	45.142243999999998	45.125304999999997	0103000020E6100000010000000500000084BC1E4C8AA942403C8386FE0990464084BC1E4C8AA94240AF06280D35924640C3F0113125AE4240AF06280D35924640C3F0113125AE42403C8386FE0990464084BC1E4C8AA942403C8386FE09904640
50272	Гостагаевская	2	20	1018	37.464570999999999	37.546883999999999	45.037305000000003	45.001899999999999	0103000020E61000000100000005000000C3D5011077BB424063EE5A423E804640C3D5011077BB4240187D0569C6844640535A7F4B00C64240187D0569C6844640535A7F4B00C6424063EE5A423E804640C3D5011077BB424063EE5A423E804640
50734	Воскресенский	2	20	1018	37.315289	37.341799000000002	44.971944000000001	44.960158999999997	0103000020E61000000100000005000000EFE4D3635BA84240E3FA777DE67A4640EFE4D3635BA842408FC536A9687C46401B67D311C0AB42408FC536A9687C46401B67D311C0AB4240E3FA777DE67A4640EFE4D3635BA84240E3FA777DE67A4640
50657	Вестник	2	20	1018	37.444476000000002	37.465119000000001	45.105122999999999	45.094459000000001	0103000020E61000000100000005000000AFEDED96E4B842400CE8853B178C4640AFEDED96E4B842405987A3AB748D4640C6DFF60489BB42405987A3AB748D4640C6DFF60489BB42400CE8853B178C4640AFEDED96E4B842400CE8853B178C4640
32919	Бол. Разнокол	2	20	1018	37.451096999999997	37.479788999999997	45.151314999999997	45.137264999999999	0103000020E610000001000000050000006F29E78BBDB9424056F146E6919146406F29E78BBDB942407632384A5E93464082FDD7B969BD42407632384A5E93464082FDD7B969BD424056F146E6919146406F29E78BBDB9424056F146E691914640
50740	Благовещенская	2	20	1018	37.113878	37.144627	45.060281000000003	45.050066999999999	0103000020E61000000100000005000000F0DDE68D938E4240EECD6F9868864640F0DDE68D938E4240FCC8AD49B78746402E8F352383924240FCC8AD49B78746402E8F352383924240EECD6F9868864640F0DDE68D938E4240EECD6F9868864640
40434	Эриванская	2	20	755	38.167907	38.199356999999999	44.732959999999999	44.717616	0103000020E610000001000000050000007EE200FA7D1543400D8B51D7DA5B46407EE200FA7D15434059A31EA2D15D4640459DB9878419434059A31EA2D15D4640459DB987841943400D8B51D7DA5B46407EE200FA7D1543400D8B51D7DA5B4640
50894	Шапсугская	2	20	755	38.066999000000003	38.084786000000001	44.765281000000002	44.738179000000002	0103000020E61000000100000005000000AFEE586C9308434008CC43A67C5E4640AFEE586C9308434006A051BAF46146404F948444DA0A434006A051BAF46146404F948444DA0A434008CC43A67C5E4640AFEE586C9308434008CC43A67C5E4640
50743	Холмская	2	20	755	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
50559	Холмская	2	20	755	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
48041	Федоровская	2	20	755	38.435830000000003	38.490366999999999	45.091405000000002	45.065660000000001	0103000020E61000000100000005000000CF4E0647C9374340E353008C67884640CF4E0647C93743406FD8B628B38B4640D1048A58C43E43406FD8B628B38B4640D1048A58C43E4340E353008C67884640CF4E0647C9374340E353008C67884640
7464	Синегорск	2	20	755	38.327348999999998	38.354604000000002	44.787849000000001	44.759784000000003	0103000020E610000001000000050000006CB07092E62943401503249A406146406CB07092E6294340D9976C3CD8644640F183F3A9632D4340D9976C3CD8644640F183F3A9632D43401503249A406146406CB07092E62943401503249A40614640
6909	Светлогорское	2	20	755	38.211547000000003	38.221024999999997	44.839502000000003	44.831581999999997	0103000020E610000001000000050000009148DBF8131B43409CF86A47716A46409148DBF8131B43409B7631CD746B4640984C158C4A1C43409B7631CD746B4640984C158C4A1C43409CF86A47716A46409148DBF8131B43409CF86A47716A4640
50440	Пролетарий	2	20	755	37.978192	38.588912000000001	45.189314000000003	44.583634000000004	0103000020E61000000100000005000000BB9A3C6535FD4240B66AD784B44A4640BB9A3C6535FD42406556EF703B984640691CEA77614B43406556EF703B984640691CEA77614B4340B66AD784B44A4640BB9A3C6535FD4240B66AD784B44A4640
45897	Первомайский	2	20	755	38.436709999999998	38.457667999999998	44.937773999999997	44.926627000000003	0103000020E6100000010000000500000007EBFF1CE6374340994BAAB69B76464007EBFF1CE637434001857AFA087846407E3672DD943A434001857AFA087846407E3672DD943A4340994BAAB69B76464007EBFF1CE6374340994BAAB69B764640
50831	Ольгинский	2	20	755	38.339342000000002	38.384168000000003	45.136946999999999	45.111356999999998	0103000020E610000001000000050000006214048F6F2B4340209738F2408E46406214048F6F2B43408524B37A87914640BA15C26A2C3143408524B37A87914640BA15C26A2C314340209738F2408E46406214048F6F2B4340209738F2408E4640
48164	Новый	2	20	755	38.320028000000001	38.348370000000003	44.727331	44.720139000000003	0103000020E61000000100000005000000F3E670ADF62843407EC9C6832D5C4640F3E670ADF6284340F92EA52E195D46402A745E63972C4340F92EA52E195D46402A745E63972C43407EC9C6832D5C4640F3E670ADF62843407EC9C6832D5C4640
50472	Мингрельская	2	20	755	38.307254	38.362769999999998	45.037329999999997	44.987034999999999	0103000020E6100000010000000500000058C85C1954274340F180B229577E464058C85C19542743407094BC3AC784464026FC523F6F2E43407094BC3AC784464026FC523F6F2E4340F180B229577E464058C85C1954274340F180B229577E4640
7675	Мингрельская	2	20	755	38.307254	38.362769999999998	45.037329999999997	44.987034999999999	0103000020E6100000010000000500000058C85C1954274340F180B229577E464058C85C19542743407094BC3AC784464026FC523F6F2E43407094BC3AC784464026FC523F6F2E4340F180B229577E464058C85C1954274340F180B229577E4640
50544	Ленинский	2	20	755	38.222434999999997	38.254154999999997	45.180470999999997	45.161369999999998	0103000020E610000001000000050000002D3E05C0781C43401B47ACC5A79446402D3E05C0781C43402E7079AC19974640B48EAA26882043402E7079AC19974640B48EAA26882043401B47ACC5A79446402D3E05C0781C43401B47ACC5A7944640
50662	Краснооктябрьский	2	20	755	38.362293999999999	38.381220999999996	44.939025000000001	44.921042	0103000020E61000000100000005000000BDC458A65F2E4340081F4AB4E4754640BDC458A65F2E43402E90A0F83178464032C687D9CB3043402E90A0F83178464032C687D9CB304340081F4AB4E4754640BDC458A65F2E4340081F4AB4E4754640
50707	Екатериновский	2	20	755	38.481679999999997	38.500732999999997	45.099384000000001	45.078315000000003	0103000020E610000001000000050000009291B3B0A73D4340A4E4D539068A46409291B3B0A73D434072DF6A9DB88C46409483D9041840434072DF6A9DB88C46409483D90418404340A4E4D539068A46409291B3B0A73D4340A4E4D539068A4640
5327	Варнавинское	2	20	755	38.178686999999996	38.210326000000002	44.996685999999997	44.989235000000001	0103000020E61000000100000005000000349C3237DF1643407F87A2409F7E4640349C3237DF164340C6302768937F4640CFBF5DF6EB1A4340C6302768937F4640CFBF5DF6EB1A43407F87A2409F7E4640349C3237DF1643407F87A2409F7E4640
6623	Ахтырский	2	20	755	38.271239999999999	38.346456000000003	44.873998	44.818393	0103000020E61000000100000005000000FBAE08FEB72243403E23111AC1684640FBAE08FEB72243407C629D2ADF6F464062C092AB582C43407C629D2ADF6F464062C092AB582C43403E23111AC1684640FBAE08FEB72243403E23111AC1684640
6114	Абинск	2	20	755	38.132280000000002	38.186987000000002	44.893037	44.842371	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
50350	Абинск	2	20	755	38.132280000000002	38.186987000000002	44.893037	44.842371	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
51748	Хутор Первомайский	2	22	\N	41.155461000000003	47.432510999999998	51.247807000000002	47.495417000000003	0103000020E61000000100000005000000D8666325E6934440F47002D369BF4740D8666325E6934440255CC823B89F494083143C855CB74740255CC823B89F494083143C855CB74740F47002D369BF4740D8666325E6934440F47002D369BF4740
51447	Хутор Княжеский-1	2	22	\N	43.003709000000001	43.022995999999999	49.965091000000001	49.948238000000003	0103000020E61000000100000005000000B6D95889798045408869DFDC5FF94840B6D9588979804540FC54151A88FB48402BF86D88F1824540FC54151A88FB48402BF86D88F18245408869DFDC5FF94840B6D95889798045408869DFDC5FF94840
51444	Хутор Кепенский	2	22	\N	41.155461000000003	47.432510999999998	51.247807000000002	47.495417000000003	0103000020E61000000100000005000000D8666325E6934440F47002D369BF4740D8666325E6934440255CC823B89F494083143C855CB74740255CC823B89F494083143C855CB74740F47002D369BF4740D8666325E6934440F47002D369BF4740
16895	Фролово	2	22	\N	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
7479	Урюпинск	2	22	\N	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
51603	Третья Карта	2	22	\N	44.705460000000002	44.720559999999999	48.756864999999998	48.745055999999998	0103000020E610000001000000050000006E5166834C5A464023D8B8FE5D5F48406E5166834C5A4640573ECBF3E06048402367614F3B5C4640573ECBF3E06048402367614F3B5C464023D8B8FE5D5F48406E5166834C5A464023D8B8FE5D5F4840
51547	Третий Решающий	2	22	\N	44.706439000000003	44.729714000000001	48.700460999999997	48.690685000000002	0103000020E610000001000000050000003ACFD8976C5A46403C6BB75D685848403ACFD8976C5A4640CD8FBFB4A859484078B7B244675D4640CD8FBFB4A859484078B7B244675D46403C6BB75D685848403ACFD8976C5A46403C6BB75D68584840
51456	Суровикино	2	22	\N	42.802270999999998	42.920292000000003	48.627524999999999	48.584100999999997	0103000020E61000000100000005000000BDC3EDD0B0664540CB4752D2C34A4840BDC3EDD0B066454011363CBD525048409E62D520CC75454011363CBD525048409E62D520CC754540CB4752D2C34A4840BDC3EDD0B0664540CB4752D2C34A4840
51659	Старенький	2	22	\N	44.646171000000002	44.665717999999998	48.753580999999997	48.742424	0103000020E61000000100000005000000D34F38BBB5524640FCE1E7BF075F4840D34F38BBB552464088F19A5775604840E42D573F3655464088F19A5775604840E42D573F36554640FCE1E7BF075F4840D34F38BBB5524640FCE1E7BF075F4840
51417	Средняя Ахтуба	2	22	\N	44.837476000000002	44.906582999999998	48.728746000000001	48.695667999999998	0103000020E61000000100000005000000AB97DF69326B4640D66F26A60B594840AB97DF69326B4640A08B868C475D4840060E68E90A744640A08B868C475D4840060E68E90A744640D66F26A60B594840AB97DF69326B4640D66F26A60B594840
51490	Серафимович	2	22	\N	42.708047000000001	42.758361000000001	49.591715000000001	49.559604	0103000020E61000000100000005000000F583BA48A15A4540FB5A971AA1C74840F583BA48A15A4540BDC62E51BDCB4840EBC726F911614540BDC62E51BDCB4840EBC726F911614540FB5A971AA1C74840F583BA48A15A4540FB5A971AA1C74840
51466	Рыбный	2	22	\N	42.447660999999997	42.463425999999998	49.574170000000002	49.564284999999998	0103000020E61000000100000005000000EA58A5F44C394540CA4FAA7D3AC84840EA58A5F44C394540132C0E677EC94840DC0E0D8B513B4540132C0E677EC94840DC0E0D8B513B4540CA4FAA7D3AC84840EA58A5F44C394540CA4FAA7D3AC84840
51548	Рыбачий	2	22	\N	44.723739999999999	44.743315000000003	48.707025999999999	48.701447999999999	0103000020E610000001000000050000004D672783A35C46401CEC4D0CC95948404D672783A35C4640FAB5F5D37F5A484029D027F2245F4640FAB5F5D37F5A484029D027F2245F46401CEC4D0CC95948404D672783A35C46401CEC4D0CC9594840
51468	Петров Вал	2	22	\N	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
51449	Палласовка	2	22	\N	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
51573	Новоаннинский	2	22	\N	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
51612	Новенький	2	22	\N	44.743665	44.761612999999997	48.715069	48.703113000000002	0103000020E6100000010000000500000005172B6A305F46403C32569BFF59484005172B6A305F464014B18861875B4840AE9AE7887C61464014B18861875B4840AE9AE7887C6146403C32569BFF59484005172B6A305F46403C32569BFF594840
14060	Михайловка	2	22	\N	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
51379	Ленинск	2	22	\N	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
51669	Лебяжья Поляна	2	22	\N	44.690618999999998	44.712699999999998	48.774116999999997	48.763582999999997	0103000020E61000000100000005000000847F1134665846400A647616BD614840847F11346658464089230F4416634840FAEDEBC0395B464089230F4416634840FAEDEBC0395B46400A647616BD614840847F1134665846400A647616BD614840
51495	Красный Буксир	2	22	\N	44.694464000000004	44.712412999999998	48.730231000000003	48.719230000000003	0103000020E61000000100000005000000EB1F4432E4584640AB2688BA0F5C4840EB1F4432E458464040C39B35785D4840641F6459305B464040C39B35785D4840641F6459305B4640AB2688BA0F5C4840EB1F4432E4584640AB2688BA0F5C4840
51593	Краснослободск	2	22	\N	44.545873999999998	44.610050000000001	48.712989	48.677706000000001	0103000020E610000001000000050000004CDE0033DF454640C826F911BF5648404CDE0033DF45464031B43A39435B484060764F1E164E464031B43A39435B484060764F1E164E4640C826F911BF5648404CDE0033DF454640C826F911BF564840
51496	Кировец	2	22	\N	44.717677000000002	44.736730000000001	48.767572999999999	48.756652000000003	0103000020E61000000100000005000000B30B06D7DC5B4640FC3905F9D9604840B30B06D7DC5B4640742502D53F624840B5FD2B2B4D5E4640742502D53F624840B5FD2B2B4D5E4640FC3905F9D9604840B30B06D7DC5B4640FC3905F9D9604840
12417	Камышин	2	22	\N	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
51589	Иловля	2	22	\N	43.967421999999999	44.012974999999997	49.333086000000002	49.284435000000002	0103000020E6100000010000000500000028B7ED7BD4FB45403C6BB75D68A4484028B7ED7BD4FB4540B360E28FA2AA48403255302AA9014640B360E28FA2AA48403255302AA90146403C6BB75D68A4484028B7ED7BD4FB45403C6BB75D68A44840
51507	Жирновск	2	22	\N	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
51453	Дубовка	2	22	\N	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
51701	Госпитомник	2	22	\N	44.613534999999999	44.646493999999997	48.711317999999999	48.693562999999997	0103000020E61000000100000005000000C6F99B50884E46409A5B21ACC6584840C6F99B50884E46402F87DD770C5B4840B587BD50C05246402F87DD770C5B4840B587BD50C05246409A5B21ACC6584840C6F99B50884E46409A5B21ACC6584840
51723	Горьковский	2	22	\N	44.297077000000002	44.367846	48.702364000000003	48.676284000000003	0103000020E6100000010000000500000068B27F9E062646406F675F799056484068B27F9E06264640A2F14410E759484072FBE593152F4640A2F14410E759484072FBE593152F46406F675F799056484068B27F9E062646406F675F7990564840
51270	Волжский	2	22	\N	44.648721999999999	44.885382999999997	48.938906000000003	48.724156999999998	0103000020E610000001000000050000000D198F5209534640B115342DB15C48400D198F5209534640540262122E78484099B7EA3A54714640540262122E78484099B7EA3A54714640B115342DB15C48400D198F5209534640B115342DB15C4840
416	Волгоград	2	22	\N	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
51656	Бурковский	2	22	\N	44.647284999999997	44.670873999999998	48.713166999999999	48.698481000000001	0103000020E610000001000000050000007E18213CDA5246404EF04DD3675948407E18213CDA52464010CB660E495B48404CDE0033DF55464010CB660E495B48404CDE0033DF5546404EF04DD3675948407E18213CDA5246404EF04DD367594840
51476	Ярской	2	22	1170	42.322499000000001	42.338712999999998	48.502291999999997	48.49259	0103000020E6100000010000000500000011FFB0A547294540172B6A300D3F484011FFB0A5472945406E85B01A4B40484072DD94F25A2B45406E85B01A4B40484072DD94F25A2B4540172B6A300D3F484011FFB0A547294540172B6A300D3F4840
11109	Чернышковский	2	22	1170	42.205852	42.261512000000003	48.438262000000002	48.404305000000001	0103000020E6100000010000000500000079E8BB5B591A4540FD4D2844C033484079E8BB5B591A45402F8A1EF8183848407BC1A739792145402F8A1EF8183848407BC1A73979214540FD4D2844C033484079E8BB5B591A4540FD4D2844C0334840
51567	Фирсовка	2	22	1170	42.240535999999999	42.261746000000002	48.105272999999997	48.095585	0103000020E610000001000000050000005DC136E2C91E45407C7E18213C0C48405DC136E2C91E45406E13EE95790D4840EEED96E4802145406E13EE95790D4840EEED96E4802145407C7E18213C0C48405DC136E2C91E45407C7E18213C0C4840
51722	Тормосин	2	22	1170	42.656680999999999	42.719059999999999	48.186331000000003	48.161310999999998	0103000020E61000000100000005000000C9737D1F0E54454016BEBED6A5144840C9737D1F0E544540919DB7B1D91748404EEE77280A5C4540919DB7B1D91748404EEE77280A5C454016BEBED6A5144840C9737D1F0E54454016BEBED6A5144840
51719	Сизов	2	22	1170	42.272525000000002	42.297238	48.152614	48.137151000000003	0103000020E61000000100000005000000D42B6519E22245408ECEF9298E114840D42B6519E2224540B47405DB88134840719010E50B264540B47405DB88134840719010E50B2645408ECEF9298E114840D42B6519E22245408ECEF9298E114840
51627	Раздольный	2	22	1170	42.130690000000001	42.144101999999997	48.148429999999998	48.141810999999997	0103000020E6100000010000000500000006F52D73BA104540459BE3DC2612484006F52D73BA10454065DF15C1FF124840E3A430EF7112454065DF15C1FF124840E3A430EF71124540459BE3DC2612484006F52D73BA104540459BE3DC26124840
51404	Пристеновский	2	22	1170	42.868898999999999	42.888320999999998	48.267829999999996	48.256326000000001	0103000020E6100000010000000500000078431A15386F4540A88E554ACF20484078431A15386F45409F71E14048224840CDACA580B47145409F71E14048224840CDACA580B4714540A88E554ACF20484078431A15386F4540A88E554ACF204840
51340	Попов	2	22	1170	42.837952000000001	42.865665	48.189551000000002	48.179597000000001	0103000020E6100000010000000500000014CFD902426B4540D8BAD408FD16484014CFD902426B454049F60835431848405B25581CCE6E454049F60835431848405B25581CCE6E4540D8BAD408FD16484014CFD902426B4540D8BAD408FD164840
51505	Нижняя Вербовка	2	22	1170	42.160415999999998	42.190671000000002	48.439917999999999	48.42624	0103000020E61000000100000005000000A8E0F082881445409F1F46088F364840A8E0F08288144540FB75A73B4F384840D7A546E867184540FB75A73B4F384840D7A546E8671845409F1F46088F364840A8E0F082881445409F1F46088F364840
51689	Нижнегнутов	2	22	1170	42.124347999999998	42.897708000000002	48.502752000000001	47.898296999999999	0103000020E6100000010000000500000058A9A0A2EA0F4540268C6665FBF2474058A9A0A2EA0F4540D2FF722D5A404840C5AD8218E8724540D2FF722D5A404840C5AD8218E8724540268C6665FBF2474058A9A0A2EA0F4540268C6665FBF24740
51320	Морской	2	22	1170	42.576165000000003	42.602477	48.103870999999998	48.081935000000001	0103000020E61000000100000005000000C80C54C6BF494540EAB298D87C0A4840C80C54C6BF4945405C001AA54B0D4840CDCB61F71D4D45405C001AA54B0D4840CDCB61F71D4D4540EAB298D87C0A4840C80C54C6BF494540EAB298D87C0A4840
51399	Лозной	2	22	1170	42.424582999999998	42.450850000000003	48.075271000000001	48.054949000000001	0103000020E6100000010000000500000002B859BC5836454055F99E910807484002B859BC583645402AABE97AA209484068B3EA73B53945402AABE97AA209484068B3EA73B539454055F99E910807484002B859BC5836454055F99E9108074840
11547	Красный	2	22	1170	42.353670000000001	42.369318999999997	48.396445	48.385652	0103000020E61000000100000005000000C5C9FD0E452D454089D1730B5D314840C5C9FD0E452D4540D4D4B2B5BE3248404D6551D8452F4540D4D4B2B5BE3248404D6551D8452F454089D1730B5D314840C5C9FD0E452D454089D1730B5D314840
11483	Красноярский	2	22	1170	42.271286000000003	42.304532000000002	48.411267000000002	48.392969000000001	0103000020E610000001000000050000006CEEE87FB9224540C1ABE5CE4C3248406CEEE87FB92245404776A565A4344840F14A92E7FA2645404776A565A4344840F14A92E7FA264540C1ABE5CE4C3248406CEEE87FB9224540C1ABE5CE4C324840
51592	Захаров	2	22	1170	42.725231000000001	42.777630000000002	48.176538000000001	48.157626999999998	0103000020E61000000100000005000000CF85915ED45C4540B9FB1C1F2D144840CF85915ED45C4540294014CC98164840BA313D6189634540294014CC98164840BA313D6189634540B9FB1C1F2D144840CF85915ED45C4540B9FB1C1F2D144840
51687	Елкино	2	22	1170	42.348818999999999	42.364998	48.314469000000003	48.300620000000002	0103000020E61000000100000005000000999CDA19A62C4540034356B77A264840999CDA19A62C45408C4D2B85402848407E8D2441B82E45408C4D2B85402848407E8D2441B82E4540034356B77A264840999CDA19A62C4540034356B77A264840
51460	Волоцкий	2	22	1170	42.197291	42.230457000000001	48.374108	48.360604000000002	0103000020E61000000100000005000000C765DCD44019454045679945282E4840C765DCD44019454003965CC5E22F484030116F9D7F1D454003965CC5E22F484030116F9D7F1D454045679945282E4840C765DCD44019454045679945282E4840
51443	Водяновский	2	22	1170	42.843611000000003	42.875672000000002	48.231568000000003	48.223711000000002	0103000020E61000000100000005000000DFC5FB71FB6B4540B360E28FA21C4840DFC5FB71FB6B45406B662D05A41D4840EF022505167045406B662D05A41D4840EF02250516704540B360E28FA21C4840DFC5FB71FB6B4540B360E28FA21C4840
51671	Верхнегнутов	2	22	1170	42.234338000000001	42.262903999999999	48.256278000000002	48.230386000000003	0103000020E61000000100000005000000E31A9FC9FE1D454067BAD7497D1D4840E31A9FC9FE1D45409757AEB7CD20484069FE98D6A62145409757AEB7CD20484069FE98D6A621454067BAD7497D1D4840E31A9FC9FE1D454067BAD7497D1D4840
51357	Большетерновой	2	22	1170	42.432093000000002	42.469391000000002	48.492387000000001	48.481239000000002	0103000020E610000001000000050000004FEACBD24E374540A647533D993D48404FEACBD24E374540DFFC8689063F4840B4041901153C4540DFFC8689063F4840B4041901153C4540A647533D993D48404FEACBD24E374540A647533D993D4840
51536	Богомазовка	2	22	1170	42.305394999999997	42.322409	48.393520000000002	48.371420999999998	0103000020E6100000010000000500000053AEF02E1727454018062CB98A2F484053AEF02E17274540352905DD5E324840D177B7B244294540352905DD5E324840D177B7B24429454018062CB98A2F484053AEF02E1727454018062CB98A2F4840
11785	Басакин	2	22	1170	42.249070000000003	42.301963000000001	48.177264999999998	48.153480000000002	0103000020E6100000010000000500000016359886E11F4540884B8E3BA513484016359886E11F4540DBDC989EB016484010CD3CB9A6264540DBDC989EB016484010CD3CB9A6264540884B8E3BA513484016359886E11F4540884B8E3BA5134840
51704	Алешкин	2	22	1170	42.620820000000002	42.673641000000003	48.259523000000002	48.226832999999999	0103000020E61000000100000005000000F3599E07774F4540A8531EDD081D4840F3599E07774F4540A8C7B60C38214840541F48DE39564540A8C7B60C38214840541F48DE39564540A8531EDD081D4840F3599E07774F4540A8531EDD081D4840
10764	Шуруповский	2	22	1121	43.678649	43.719450999999999	49.737335000000002	49.717955000000003	0103000020E61000000100000005000000473B6EF8DDD64540F67F0EF3E5DB4840473B6EF8DDD645401C9947FE60DE484089096AF816DC45401C9947FE60DE484089096AF816DC4540F67F0EF3E5DB4840473B6EF8DDD64540F67F0EF3E5DB4840
10484	Шляховский	2	22	1121	43.688395999999997	43.709695000000004	49.589187000000003	49.580548999999998	0103000020E610000001000000050000003E59315C1DD84540DD5CFC6D4FCA48403E59315C1DD845403B1DC87A6ACB48403F912749D7DA45403B1DC87A6ACB48403F912749D7DA4540DD5CFC6D4FCA48403E59315C1DD84540DD5CFC6D4FCA4840
51341	Школьный	2	22	1121	43.428387999999998	43.455885000000002	49.794305999999999	49.784238000000002	0103000020E61000000100000005000000DAFF006BD5B64540E62329E961E44840DAFF006BD5B645401F82AAD1ABE5484055DE8E705ABA45401F82AAD1ABE5484055DE8E705ABA4540E62329E961E44840DAFF006BD5B64540E62329E961E44840
51397	Фролово	2	22	1121	43.235295000000001	44.268293999999997	50.2181	49.486494	0103000020E61000000100000005000000C7F484251E9E4540A1D9756F45BE4840C7F484251E9E4540F9A067B3EA1B494044DB317557224640F9A067B3EA1B494044DB317557224640A1D9756F45BE4840C7F484251E9E4540A1D9756F45BE4840
51398	Рубежный	2	22	1121	44.044972999999999	44.063882999999997	49.826237999999996	49.811138	0103000020E61000000100000005000000FC19DEACC10546407C45B75ED3E74840FC19DEACC1054640315BB22AC2E948409BE271512D084640315BB22AC2E948409BE271512D0846407C45B75ED3E74840FC19DEACC10546407C45B75ED3E74840
45689	Пригородный	2	22	1121	43.663063999999999	43.695788999999998	49.796008999999998	49.778905000000002	0103000020E61000000100000005000000D593F947DFD445406FD8B628B3E34840D593F947DFD445402C29779FE3E5484051F52B9D0FD945402C29779FE3E5484051F52B9D0FD945406FD8B628B3E34840D593F947DFD445406FD8B628B3E34840
51426	Писаревка	2	22	1121	43.969371000000002	43.997838999999999	49.696919000000001	49.652742000000003	0103000020E610000001000000050000006D58535914FC4540E25CC30C8DD348406D58535914FC4540037B4CA434D9484030D63730B9FF4540037B4CA434D9484030D63730B9FF4540E25CC30C8DD348406D58535914FC4540E25CC30C8DD34840
51633	Перелазовский	2	22	1121	43.717564000000003	43.731856999999998	50.07564	50.061092000000002	0103000020E61000000100000005000000BB641C23D9DB45400C06D7DCD1074940BB641C23D9DB45407D224F92AE094940A12C7C7DADDD45407D224F92AE094940A12C7C7DADDD45400C06D7DCD1074940BB641C23D9DB45400C06D7DCD1074940
10829	Образцы	2	22	1121	43.998925999999997	44.025004000000003	49.793858	49.778212000000003	0103000020E61000000100000005000000E28FA2CEDCFF454069AD68739CE34840E28FA2CEDCFF454080D591239DE548407522C1543303464080D591239DE548407522C1543303464069AD68739CE34840E28FA2CEDCFF454069AD68739CE34840
10330	Новая Паника	2	22	1121	43.626052999999999	43.646543999999999	49.657069	49.642493999999999	0103000020E610000001000000050000000648348122D0454028F04E3E3DD248400648348122D04540931B45D61AD4484067B62BF4C1D24540931B45D61AD4484067B62BF4C1D2454028F04E3E3DD248400648348122D0454028F04E3E3DD24840
51284	Манский	2	22	1121	43.979422999999997	43.997138	49.825186000000002	49.812207000000001	0103000020E61000000100000005000000A0F99CBB5DFD4540884A2366F6E74840A0F99CBB5DFD4540FC8EE1B19FE94840A7CCCD37A2FF4540FC8EE1B19FE94840A7CCCD37A2FF4540884A2366F6E74840A0F99CBB5DFD4540884A2366F6E74840
11090	Малодельская	2	22	1121	43.872416000000001	43.920834999999997	50.202685000000002	50.165446000000003	0103000020E61000000100000005000000EA40D653ABEF454084A0A3552D154940EA40D653ABEF4540E4310395F11949408E01D9EBDDF54540E4310395F11949408E01D9EBDDF5454084A0A3552D154940EA40D653ABEF454084A0A3552D154940
10519	Лычак	2	22	1121	43.782252	43.803623000000002	49.855646	49.835681000000001	0103000020E61000000100000005000000849D62D520E44540BD715298F7EA4840849D62D520E44540037AE1CE85ED48401EA8531EDDE64540037AE1CE85ED48401EA8531EDDE64540BD715298F7EA4840849D62D520E44540BD715298F7EA4840
51257	Лесхоз Арчединский	2	22	1121	43.45478	43.475881999999999	49.790531000000001	49.784779	0103000020E61000000100000005000000FC6F253B36BA454036CB65A373E44840FC6F253B36BA4540B2BCAB1E30E54840A6608DB3E9BC4540B2BCAB1E30E54840A6608DB3E9BC454036CB65A373E44840FC6F253B36BA454036CB65A373E44840
10436	Красные Липки	2	22	1121	43.728712000000002	43.754781999999999	49.649521999999997	49.630673000000002	0103000020E61000000100000005000000F419506F46DD454030BC92E4B9D04840F419506F46DD45402904728923D3484003CE52B29CE045402904728923D3484003CE52B29CE0454030BC92E4B9D04840F419506F46DD454030BC92E4B9D04840
51501	Калиновский	2	22	1121	43.758132000000003	43.781156000000003	49.758603999999998	49.744059	0103000020E610000001000000050000008A0629780AE14540B1A547533DDF48408A0629780AE14540B14E95EF19E148407F8978EBFCE34540B14E95EF19E148407F8978EBFCE34540B1A547533DDF48408A0629780AE14540B1A547533DDF4840
11025	Дудаченский	2	22	1121	44.159301999999997	44.189045	50.007292	49.992410999999997	0103000020E61000000100000005000000FC170802641446406798DA5207FF4840FC17080264144640DFC2BAF1EE004940753C66A032184640DFC2BAF1EE004940753C66A0321846406798DA5207FF4840FC170802641446406798DA5207FF4840
10178	Гуляевка	2	22	1121	43.481155000000001	43.512542000000003	49.797910999999999	49.779933999999997	0103000020E6100000010000000500000048A7AE7C96BD4540EC8497E0D4E3484048A7AE7C96BD4540300F99F221E64840C9E9EBF99AC14540300F99F221E64840C9E9EBF99AC14540EC8497E0D4E3484048A7AE7C96BD4540EC8497E0D4E34840
51484	Ветютнев	2	22	1121	43.518920000000001	43.552508000000003	49.779933999999997	49.753326000000001	0103000020E61000000100000005000000C39E76F86BC24540FE9C82FC6CE04840C39E76F86BC24540EC8497E0D4E34840A2630795B8C64540EC8497E0D4E34840A2630795B8C64540FE9C82FC6CE04840C39E76F86BC24540FE9C82FC6CE04840
10352	Верхние Липки	2	22	1121	43.836106000000001	43.867061999999997	49.636479000000001	49.619188999999999	0103000020E61000000100000005000000A4FE7A8505EB45407F85CC9541CF4840A4FE7A8505EB45409FCBD42478D148405BCD3AE3FBEE45409FCBD42478D148405BCD3AE3FBEE45407F85CC9541CF4840A4FE7A8505EB45407F85CC9541CF4840
10975	Большой Лычак	2	22	1121	43.763558000000003	43.800308000000001	50.119712	50.092084	0103000020E61000000100000005000000B24CBF44BCE14540103E9468C90B4940B24CBF44BCE1454029780AB9520F4940145D177E70E6454029780AB9520F4940145D177E70E64540103E9468C90B4940B24CBF44BCE14540103E9468C90B4940
10951	Арчедино-Чернушинский	2	22	1121	44.144632000000001	44.174627000000001	49.878593000000002	49.864362999999997	0103000020E6100000010000000500000040FA264D83124640AC6F6072A3EE484040FA264D831246404DBF44BC75F04840D2FF722D5A1646404DBF44BC75F04840D2FF722D5A164640AC6F6072A3EE484040FA264D83124640AC6F6072A3EE4840
10724	Амелино	2	22	1121	43.840319000000001	43.871886000000003	49.818263999999999	49.778288000000003	0103000020E610000001000000050000008D9AAF928FEB4540446FF1F09EE348408D9AAF928FEB454040BFEFDFBCE848408EEBDFF599EF454040BFEFDFBCE848408EEBDFF599EF4540446FF1F09EE348408D9AAF928FEB4540446FF1F09EE34840
51462	Фролово	2	22	7113	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
51309	Тепикинская	2	22	1385	41.886591000000003	41.921042	50.666319999999999	50.657510000000002	0103000020E61000000100000005000000C7F65AD07BF144408065A54929544940C7F65AD07BF14440DA5548F949554940081F4AB4E4F54440DA5548F949554940081F4AB4E4F544408065A54929544940C7F65AD07BF144408065A54929544940
51360	Салтынский	2	22	1385	41.885072999999998	41.927599000000001	51.055995000000003	51.010368999999997	0103000020E610000001000000050000004BC972124AF1444034F279C5538149404BC972124AF14440A9DE1AD82A874940B2666490BBF64440A9DE1AD82A874940B2666490BBF6444034F279C5538149404BC972124AF1444034F279C553814940
51575	Россошинский	2	22	1385	41.771462999999997	41.809075999999997	50.685823999999997	50.678438999999997	0103000020E610000001000000050000007A89B14CBFE244405CAAD216D75649407A89B14CBFE24440EC67B114C95749403FFD67CD8FE74440EC67B114C95749403FFD67CD8FE744405CAAD216D75649407A89B14CBFE244405CAAD216D7564940
51445	Провоторовский	2	22	1385	41.932917000000003	41.959355000000002	50.521160000000002	50.495828000000003	0103000020E61000000100000005000000F47002D369F744407638BA4A773F4940F47002D369F74440DFFDF15EB542494086200725CCFA4440DFFDF15EB542494086200725CCFA44407638BA4A773F4940F47002D369F744407638BA4A773F4940
51634	Попов	2	22	1385	42.035010999999997	42.064233000000002	50.840077000000001	50.825347999999998	0103000020E6100000010000000500000008008E3D7B044540D5E8D500A569494008008E3D7B044540978FA4A4876B4940782975C938084540978FA4A4876B4940782975C938084540D5E8D500A569494008008E3D7B044540D5E8D500A5694940
51623	Петровский	2	22	1385	41.941657999999997	41.996930999999996	50.761612999999997	50.744916000000003	0103000020E610000001000000050000002502D53F88F8444032225168595F49402502D53F88F84440AE9AE7887C6149402DAF5C6F9BFF4440AE9AE7887C6149402DAF5C6F9BFF444032225168595F49402502D53F88F8444032225168595F4940
48248	Первомайский	2	22	1385	41.842232000000003	41.878003	51.128433000000001	51.108164000000002	0103000020E6100000010000000500000085D21742CEEB4440624D6551D88D494085D21742CEEB4440145D177E709049401B65FD6662F04440145D177E709049401B65FD6662F04440624D6551D88D494085D21742CEEB4440624D6551D88D4940
51642	Ольшанка	2	22	1385	41.994919000000003	42.076045999999998	50.826093	50.807479000000001	0103000020E61000000100000005000000A3957B8159FF4440789ACC785B674940A3957B8159FF44402E3A596ABD694940ED7E15E0BB0945402E3A596ABD694940ED7E15E0BB094540789ACC785B674940A3957B8159FF4440789ACC785B674940
51297	Ольховский	2	22	1385	41.610368000000001	41.997281999999998	50.857273999999997	50.578845999999999	0103000020E610000001000000050000003143E38920CE4440D0B52FA0174A49403143E38920CE444005DB8827BB6D4940DA71C3EFA6FF444005DB8827BB6D4940DA71C3EFA6FF4440D0B52FA0174A49403143E38920CE4440D0B52FA0174A4940
51478	Окладненский	2	22	1385	42.222031000000001	42.246079000000002	50.738428999999996	50.727984999999997	0103000020E610000001000000050000005ED905836B1C4540417DCB9C2E5D49405ED905836B1C454080B56AD7845E4940BF9D44847F1F454080B56AD7845E4940BF9D44847F1F4540417DCB9C2E5D49405ED905836B1C4540417DCB9C2E5D4940
51311	Моховской	2	22	1385	41.902231	41.941721000000001	51.056334	51.017797999999999	0103000020E61000000100000005000000FC372F4E7CF3444094F7713447824940FC372F4E7CF3444091D3D7F3358749406C7A50508AF8444091D3D7F3358749406C7A50508AF8444094F7713447824940FC372F4E7CF3444094F7713447824940
51666	Михайловская	2	22	1385	41.884605999999998	41.917574000000002	50.973087	50.948630000000001	0103000020E6100000010000000500000035ECF7C43AF14440930035B56C79494035ECF7C43AF14440D594641D8E7C494078D4981073F54440D594641D8E7C494078D4981073F54440930035B56C79494035ECF7C43AF14440930035B56C794940
51310	Лощиновский	2	22	1385	41.335743999999998	41.386445000000002	50.784118999999997	50.764899999999997	0103000020E6100000010000000500000003EACDA8F9AA4440EE5A423EE861494003EACDA8F9AA44400B96EA025E644940F3599E0777B144400B96EA025E644940F3599E0777B14440EE5A423EE861494003EACDA8F9AA4440EE5A423EE8614940
51342	Криушинский	2	22	1385	42.119129000000001	42.142530000000001	51.129123	51.117483	0103000020E61000000100000005000000AA807B9E3F0F4540016BD5AE098F4940AA807B9E3F0F4540A9143B1A8790494075594C6C3E124540A9143B1A8790494075594C6C3E124540016BD5AE098F4940AA807B9E3F0F4540016BD5AE098F4940
51598	Креповский	2	22	1385	42.073557999999998	42.102097000000001	50.848362999999999	50.834974000000003	0103000020E61000000100000005000000F92D3A596A0945405281936DE06A4940F92D3A596A0945407711A628976C49408602B683110D45407711A628976C49408602B683110D45405281936DE06A4940F92D3A596A0945405281936DE06A4940
51394	Красный	2	22	1385	42.261035999999997	42.280591999999999	50.808418000000003	50.796002000000001	0103000020E61000000100000005000000118AADA0692145407AC6BE64E3654940118AADA069214540B6BFB33D7A67494076C24B70EA234540B6BFB33D7A67494076C24B70EA2345407AC6BE64E3654940118AADA0692145407AC6BE64E3654940
51502	Котовский	2	22	1385	41.931175000000003	41.971212000000001	50.860576999999999	50.845115999999997	0103000020E6100000010000000500000029ED0DBE30F74440C5A9D6C22C6C494029ED0DBE30F744404B581B63276E4940CBBDC0AC50FC44404B581B63276E4940CBBDC0AC50FC4440C5A9D6C22C6C494029ED0DBE30F74440C5A9D6C22C6C4940
15965	Искра	2	22	1385	41.414121999999999	41.443237000000003	50.665863000000002	50.652918	0103000020E61000000100000005000000ED461FF301B54440207C28D192534940ED461FF301B54440E84EB0FF3A55494047B071FDBBB84440E84EB0FF3A55494047B071FDBBB84440207C28D192534940ED461FF301B54440207C28D192534940
51370	Забурдяевский	2	22	1385	41.759901999999997	41.792375999999997	50.860151000000002	50.855113000000003	0103000020E610000001000000050000001E15FF7744E1444036B1C057746D49401E15FF7744E14440944F8F6D196E49405111A7936CE54440944F8F6D196E49405111A7936CE5444036B1C057746D49401E15FF7744E1444036B1C057746D4940
51337	Дьяконовский 2-й	2	22	1385	42.068527000000003	42.096896000000001	50.770699999999998	50.756450000000001	0103000020E610000001000000050000004EF2237EC50845409487855AD36049404EF2237EC50845407B832F4CA66249407E8E8F16670C45407B832F4CA66249407E8E8F16670C45409487855AD36049404EF2237EC50845409487855AD3604940
51371	Дубовский	2	22	1385	41.965805000000003	42.003946999999997	50.543242999999997	50.518113	0103000020E610000001000000050000001AA88C7F9FFB4440F450DB86514249401AA88C7F9FFB4440F56393FC884549406AF5D55581004540F56393FC884549406AF5D55581004540F450DB86514249401AA88C7F9FFB4440F450DB8651424940
51551	Долгий	2	22	1385	42.286026999999997	42.341444000000003	50.652718	50.630332000000003	0103000020E61000000100000005000000F16261889C244540A7CF0EB8AE504940F16261889C24454059C16F438C5349402DB5DE6FB42B454059C16F438C5349402DB5DE6FB42B4540A7CF0EB8AE504940F16261889C244540A7CF0EB8AE504940
51261	Добринка	2	22	1385	41.820349	41.862202000000003	50.834474	50.799855999999998	0103000020E6100000010000000500000035272F3201E9444033C170AE6166494035272F3201E9444060AE450BD06A4940DD4598A25CEE444060AE450BD06A4940DD4598A25CEE444033C170AE6166494035272F3201E9444033C170AE61664940
51442	Горский	2	22	1385	41.917887999999998	41.964160999999997	50.807723000000003	50.790553000000003	0103000020E6100000010000000500000007B29E5A7DF544409A6038D73065494007B29E5A7DF544400F9D9E7763674940118AADA069FB44400F9D9E7763674940118AADA069FB44409A6038D73065494007B29E5A7DF544409A6038D730654940
51587	Вишняковский	2	22	1385	42.079467999999999	42.114350000000002	50.965997000000002	50.945411999999997	0103000020E610000001000000050000000D8AE6012C0A45407B9FAA42037949400D8AE6012C0A45405E8429CAA57B494018265305A30E45405E8429CAA57B494018265305A30E45407B9FAA42037949400D8AE6012C0A45407B9FAA4203794940
51441	Вихлянцевский	2	22	1385	41.585026999999997	41.620356999999998	50.973694000000002	50.925556	0103000020E6100000010000000500000074232C2AE2CA4440EC4E779E7876494074232C2AE2CA4440DD274701A27C49401E6CB1DB67CF4440DD274701A27C49401E6CB1DB67CF4440EC4E779E7876494074232C2AE2CA4440EC4E779E78764940
51440	Верхнесоинский	2	22	1385	41.647917999999997	41.728639999999999	50.723224000000002	50.694892000000003	0103000020E61000000100000005000000AF3E1EFAEED2444043209738F2584940AF3E1EFAEED2444056D7A19A925C49405A47551344DD444056D7A19A925C49405A47551344DD444043209738F2584940AF3E1EFAEED2444043209738F2584940
51597	Верхнебезымянский	2	22	1385	41.668461999999998	41.700595	50.784523	50.762923000000001	0103000020E61000000100000005000000334FAE2990D54440E02EFB75A7614940334FAE2990D54440DBFAE93F6B644940DD5ED218ADD94440DBFAE93F6B644940DD5ED218ADD94440E02EFB75A7614940334FAE2990D54440E02EFB75A7614940
51446	Булековский	2	22	1385	41.797963000000003	41.825226999999998	50.663927999999999	50.637175999999997	0103000020E610000001000000050000008335CEA623E64440E6E5B0FB8E5149408335CEA623E644400873BB97FB5449405A63D009A1E944400873BB97FB5449405A63D009A1E94440E6E5B0FB8E5149408335CEA623E64440E6E5B0FB8E514940
51570	Бугровский	2	22	1385	41.788997999999999	41.849446	51.045389	51.022675999999997	0103000020E61000000100000005000000014EEFE2FDE44440B933130CE7824940014EEFE2FDE44440904C874ECF854940E8DB82A5BAEC4440904C874ECF854940E8DB82A5BAEC4440B933130CE7824940014EEFE2FDE44440B933130CE7824940
51542	Бубновский	2	22	1385	41.789070000000002	41.870942999999997	50.985624999999999	50.954832000000003	0103000020E610000001000000050000009B20EA3E00E544404F965AEF377A49409B20EA3E00E544405C8FC2F5287E49400ED76A0F7BEF44405C8FC2F5287E49400ED76A0F7BEF44404F965AEF377A49409B20EA3E00E544404F965AEF377A4940
51259	Большинский	2	22	1385	42.128067000000001	42.188668	51.059046000000002	51.037348000000001	0103000020E610000001000000050000003259DC7F641045401749BBD1C78449403259DC7F64104540D57ABFD18E8749409FE6E44526184540D57ABFD18E8749409FE6E445261845401749BBD1C78449403259DC7F641045401749BBD1C7844940
51572	Бесплемяновский	2	22	1385	41.847461000000003	41.875253999999998	50.748569000000003	50.738833999999997	0103000020E6100000010000000500000057D11F9A79EC44402096CD1C925E494057D11F9A79EC444054E6E61BD15F4940BAD8B45208F0444054E6E61BD15F4940BAD8B45208F044402096CD1C925E494057D11F9A79EC44402096CD1C925E4940
51390	Беспаловский	2	22	1385	41.507331000000001	41.549939000000002	50.887678000000001	50.870246999999999	0103000020E610000001000000050000009D9FE238F0C044409738F240646F49409D9FE238F0C0444079B0C56E9F714940C1E5B16664C6444079B0C56E9F714940C1E5B16664C644409738F240646F49409D9FE238F0C044409738F240646F4940
51459	Акчернский	2	22	1385	41.975074999999997	42.027366000000001	50.650444999999998	50.632046000000003	0103000020E61000000100000005000000D712F241CFFC4440A8C821E2E6504940D712F241CFFC4440616C21C841534940DC82A5BA80034540616C21C841534940DC82A5BA80034540A8C821E2E6504940D712F241CFFC4440A8C821E2E6504940
51465	Чувилевский	2	22	940	42.718376999999997	42.744957999999997	48.599415999999998	48.583069999999999	0103000020E610000001000000050000006B990CC7F35B4540ADA3AA09A24A48406B990CC7F35B45407D59DAA9B94C48406072A3C85A5F45407D59DAA9B94C48406072A3C85A5F4540ADA3AA09A24A48406B990CC7F35B4540ADA3AA09A24A4840
9104	Сысоевский	2	22	940	42.833019999999998	42.865107999999999	48.464280000000002	48.444280999999997	0103000020E61000000100000005000000FB743C66A06A4540F99D2633DE384840FB743C66A06A4540EC17EC866D3B484005C1E3DBBB6E4540EC17EC866D3B484005C1E3DBBB6E4540F99D2633DE384840FB743C66A06A4540F99D2633DE384840
8447	Сухановский	2	22	940	43.236310000000003	43.257581999999999	48.930585000000001	48.912055000000002	0103000020E61000000100000005000000E0DBF4673F9E45409F93DE37BE744840E0DBF4673F9E4540F792C6681D774840E6046D72F8A04540F792C6681D774840E6046D72F8A045409F93DE37BE744840E0DBF4673F9E45409F93DE37BE744840
7598	Суровикино	2	22	940	42.802270999999998	42.920292000000003	48.627524999999999	48.584100999999997	0103000020E61000000100000005000000BDC3EDD0B0664540CB4752D2C34A4840BDC3EDD0B066454011363CBD525048409E62D520CC75454011363CBD525048409E62D520CC754540CB4752D2C34A4840BDC3EDD0B0664540CB4752D2C34A4840
8992	Суворовская	2	22	940	43.032563000000003	43.059441	48.245274999999999	48.232984999999999	0103000020E61000000100000005000000A3073E062B844540B2BAD573D21D4840A3073E062B84454061C3D32B651F484051853FC39B87454061C3D32B651F484051853FC39B874540B2BAD573D21D4840A3073E062B844540B2BAD573D21D4840
9188	Синяпкинский	2	22	940	42.485335999999997	42.505898999999999	48.516503999999998	48.504452999999998	0103000020E6100000010000000500000025C9737D1F3E45403EAF78EA9140484025C9737D1F3E4540682096CD1C424840200A664CC1404540682096CD1C424840200A664CC14045403EAF78EA9140484025C9737D1F3E45403EAF78EA91404840
8189	Пещеровский	2	22	940	42.814990999999999	42.833235999999999	48.349642000000003	48.324444999999997	0103000020E6100000010000000500000065C405A051684540E42CEC698729484065C405A0516845406EA7AD11C12C4840C8EC2C7AA76A45406EA7AD11C12C4840C8EC2C7AA76A4540E42CEC698729484065C405A051684540E42CEC6987294840
9029	Новомаксимовский	2	22	940	43.14443	43.172691	48.492184000000002	48.470188999999998	0103000020E61000000100000005000000D847A7AE7C9245402FF834272F3C4840D847A7AE7C924540A7CEA3E2FF3E484022A81ABD1A964540A7CEA3E2FF3E484022A81ABD1A9645402FF834272F3C4840D847A7AE7C9245402FF834272F3C4840
9181	Новодербеновский	2	22	940	42.685670000000002	42.720362000000002	48.553820999999999	48.533116999999997	0103000020E6100000010000000500000096ECD808C457454087F8872D3D44484096ECD808C4574540446B459BE3464840FDA36FD2345C4540446B459BE3464840FDA36FD2345C454087F8872D3D44484096ECD808C457454087F8872D3D444840
8790	Нижний Чир	2	22	940	43.067830999999998	43.100861999999999	48.381487	48.335113	0103000020E61000000100000005000000D653ABAFAE88454073BB97FBE42A4840D653ABAFAE884540B16CE690D43048405FB4C70BE98C4540B16CE690D43048405FB4C70BE98C454073BB97FBE42A4840D653ABAFAE88454073BB97FBE42A4840
8654	Нижнеосиновский	2	22	940	42.769571999999997	42.798552000000001	48.639040999999999	48.615459000000001	0103000020E610000001000000050000006AF5D55581624540B2834A5CC74E48406AF5D55581624540CDE67118CC514840E413B2F336664540CDE67118CC514840E413B2F336664540B2834A5CC74E48406AF5D55581624540B2834A5CC74E4840
8393	Майоровский	2	22	940	43.174011999999998	43.195310999999997	48.904150000000001	48.884568000000002	0103000020E61000000100000005000000478E740646964540488B338639714840478E740646964540D656EC2FBB73484047C66AF3FF984540D656EC2FBB73484047C66AF3FF984540488B338639714840478E740646964540488B338639714840
8582	Лысов	2	22	940	43.166699000000001	43.180568999999998	48.664800999999997	48.642339	0103000020E6100000010000000500000051A390645695454001F9122A3852484051A39064569545408EACFC3218554840F1D58EE21C9745408EACFC3218554840F1D58EE21C97454001F9122A3852484051A390645695454001F9122A38524840
8482	Лобакин	2	22	940	42.822932000000002	42.852882000000001	48.812494000000001	48.777489000000003	0103000020E610000001000000050000007B6AF5D555694540F8FF71C2846348407B6AF5D5556945401E19ABCDFF6748406DACC43C2B6D45401E19ABCDFF6748406DACC43C2B6D4540F8FF71C2846348407B6AF5D555694540F8FF71C284634840
9183	Кумовка	2	22	940	43.497225999999998	43.519198000000003	48.636069999999997	48.621504000000002	0103000020E61000000100000005000000465C001AA5BF4540A62A6D718D4F4840465C001AA5BF4540BDFBE3BD6A51484006137F1475C24540BDFBE3BD6A51484006137F1475C24540A62A6D718D4F4840465C001AA5BF4540A62A6D718D4F4840
8515	Киселев	2	22	940	42.790207000000002	42.809350000000002	48.886150000000001	48.855601999999998	0103000020E61000000100000005000000FF08C380256545403332C85D846D4840FF08C38025654540DAACFA5C6D7148404182E2C798674540DAACFA5C6D7148404182E2C7986745403332C85D846D4840FF08C380256545403332C85D846D4840
51564	Качалин	2	22	940	43.194296000000001	43.221460999999998	48.765250999999999	48.735187000000003	0103000020E610000001000000050000002FDFFAB0DE984540E1B88C9B1A5E48402FDFFAB0DE9845409B1DA9BEF3614840732B84D5589C45409B1DA9BEF3614840732B84D5589C4540E1B88C9B1A5E48402FDFFAB0DE984540E1B88C9B1A5E4840
8007	Жирковский	2	22	940	42.908226999999997	42.933765999999999	48.654744000000001	48.635843000000001	0103000020E610000001000000050000000E2C47C840744540FD31AD4D635148400E2C47C84074454049A0C1A6CE534840F10EF0A48577454049A0C1A6CE534840F10EF0A485774540FD31AD4D635148400E2C47C840744540FD31AD4D63514840
8268	Добринка	2	22	940	42.950313000000001	42.984529999999999	48.831136999999998	48.806851000000002	0103000020E6100000010000000500000059FB3BDBA379454059DFC0E44667484059FB3BDBA37945406EBF7CB2626A484027F73B14057E45406EBF7CB2626A484027F73B14057E454059DFC0E44667484059FB3BDBA379454059DFC0E446674840
51349	Верхнечирский	2	22	940	43.191420999999998	43.214956999999998	48.490864999999999	48.477739	0103000020E610000001000000050000004162BB7B809845400A83328D263D48404162BB7B8098454022E010AAD43E4840EC8502B6839B454022E010AAD43E4840EC8502B6839B45400A83328D263D48404162BB7B809845400A83328D263D4840
8077	Верхнесолоновский	2	22	940	42.823847999999998	42.844608000000001	48.387872000000002	48.361293000000003	0103000020E610000001000000050000000070ECD9736945400AA359D93E2E48400070ECD9736945405E8429CAA531484051F86C1D1C6C45405E8429CAA531484051F86C1D1C6C45400AA359D93E2E48400070ECD9736945400AA359D93E2E4840
8737	Верхнеосиновский	2	22	940	42.753286000000003	42.793171000000001	48.691415999999997	48.674446000000003	0103000020E610000001000000050000007044F7AC6B60454082751C3F545648407044F7AC6B6045402FF7C951805848405C9198A0866545402FF7C951805848405C9198A08665454082751C3F545648407044F7AC6B60454082751C3F54564840
8264	Верхнеаксеновский	2	22	940	42.615673000000001	42.632938000000003	48.350898999999998	48.335431	0103000020E61000000100000005000000DE03745FCE4E454044882B67EF2A4840DE03745FCE4E45407C992842EA2C4840A532C51C045145407C992842EA2C4840A532C51C0451454044882B67EF2A4840DE03745FCE4E454044882B67EF2A4840
8623	Бурацкий	2	22	940	43.119717999999999	43.142381999999998	48.533808999999998	48.514738000000001	0103000020E610000001000000050000000B5F5FEB528F454015014EEFE24148400B5F5FEB528F4540BDA772DA5344484000C5C89239924540BDA772DA5344484000C5C8923992454015014EEFE24148400B5F5FEB528F454015014EEFE2414840
51368	Ближнеосиновский	2	22	940	43.021900000000002	43.049289999999999	48.537388	48.522472	0103000020E6100000010000000500000026E4839ECD824540B189CC5CE042484026E4839ECD824540A5A14621C94448408A027D224F864540A5A14621C94448408A027D224F864540B189CC5CE042484026E4839ECD824540B189CC5CE0424840
8946	Ближнемельничный	2	22	940	43.043638999999999	43.067391000000001	48.442355999999997	48.429749000000001	0103000020E6100000010000000500000042EA76F6958545408E3EE6030237484042EA76F6958545403D98141F9F384840BA85AE44A08845403D98141F9F384840BA85AE44A08845408E3EE6030237484042EA76F6958545408E3EE60302374840
51377	Черобаево	2	22	871	45.898358999999999	45.926054000000001	50.728886000000003	50.714818000000001	0103000020E610000001000000050000009C887E6DFDF24640CB4BFE277F5B49409C887E6DFDF246409241EE224C5D49403D2AFEEF88F646409241EE224C5D49403D2AFEEF88F64640CB4BFE277F5B49409C887E6DFDF24640CB4BFE277F5B4940
48634	Цветочное	2	22	871	46.744841999999998	46.758622000000003	50.351529999999997	50.344884999999998	0103000020E61000000100000005000000F7578FFB565F4740C3F01131252C4940F7578FFB565F47400CC85EEFFE2C4940580394861A6147400CC85EEFFE2C4940580394861A614740C3F01131252C4940F7578FFB565F4740C3F01131252C4940
48924	Харьковка	2	22	871	46.790081000000001	46.840333000000001	50.439714000000002	50.413397000000003	0103000020E610000001000000050000007218CC5F21654740DCA16131EA3449407218CC5F21654740F3CB608C48384940F25F2008906B4740F3CB608C48384940F25F2008906B4740DCA16131EA3449407218CC5F21654740DCA16131EA344940
7432	Торгун	2	22	871	47.201312000000001	47.215667000000003	50.306992999999999	50.289363000000002	0103000020E610000001000000050000006C257497C499474013D6C6D8092549406C257497C4994740EB8CEF8B4B274940C9E9EBF99A9B4740EB8CEF8B4B274940C9E9EBF99A9B474013D6C6D8092549406C257497C499474013D6C6D809254940
7394	Старая Полтавка	2	22	871	46.461593999999998	46.499322999999997	50.500939000000002	50.465156	0103000020E61000000100000005000000D1031F83153B4740E3C4573B8A3B4940D1031F83153B47403E25E7C41E404940FF91E9D0E93F47403E25E7C41E404940FF91E9D0E93F4740E3C4573B8A3B4940D1031F83153B4740E3C4573B8A3B4940
7355	Салтово	2	22	871	46.622923	46.661945000000003	50.652346999999999	50.627217999999999	0103000020E610000001000000050000008E76DCF0BB4F474034BBEEAD485049408E76DCF0BB4F47406552431B8053494018601F9DBA5447406552431B8053494018601F9DBA54474034BBEEAD485049408E76DCF0BB4F474034BBEEAD48504940
7286	Новый Тихонов	2	22	871	46.426856000000001	46.454631999999997	50.309426999999999	50.300238999999998	0103000020E61000000100000005000000FA0CA837A3364740EBFD463B6E264940FA0CA837A3364740ECBFCE4D9B27494087DBA161313A4740ECBFCE4D9B27494087DBA161313A4740EBFD463B6E264940FA0CA837A3364740EBFD463B6E264940
7142	Новая Полтавка	2	22	871	46.380000000000003	46.411549000000001	50.441302999999998	50.413110000000003	0103000020E61000000100000005000000713D0AD7A330474046D3D9C9E0344940713D0AD7A33047403750E09D7C384940CBD93BA3AD3447403750E09D7C384940CBD93BA3AD34474046D3D9C9E0344940713D0AD7A330474046D3D9C9E0344940
7259	Новая Квасниковка	2	22	871	46.449430999999997	46.477359999999997	50.582552999999997	50.566724000000001	0103000020E610000001000000050000007F677BF486394740DDED7A698A4849407F677BF486394740E597C118914A49409335EA211A3D4740E597C118914A49409335EA211A3D4740DDED7A698A4849407F677BF486394740DDED7A698A484940
7106	Лятошинка	2	22	871	46.529057999999999	46.583316000000003	50.622264000000001	50.603766999999998	0103000020E61000000100000005000000F5D72B2CB8434740B7B3AF3C484D4940F5D72B2CB843474034BDC458A64F4940E59D4319AA4A474034BDC458A64F4940E59D4319AA4A4740B7B3AF3C484D4940F5D72B2CB8434740B7B3AF3C484D4940
7059	Курнаевка	2	22	871	45.927841999999998	45.948574999999998	50.401921999999999	50.373682000000002	0103000020E6100000010000000500000078EDD286C3F646404C8DD0CFD42F494078EDD286C3F646407EC51A2E72334940CF66D5E76AF946407EC51A2E72334940CF66D5E76AF946404C8DD0CFD42F494078EDD286C3F646404C8DD0CFD42F4940
6980	Колышкино	2	22	871	45.911915	45.931165999999997	50.455373000000002	50.432043	0103000020E61000000100000005000000ADDD76A1B9F446409DBB5D2F4D374940ADDD76A1B9F446409F3D97A9493A4940D5928E7230F746409F3D97A9493A4940D5928E7230F746409DBB5D2F4D374940ADDD76A1B9F446409DBB5D2F4D374940
6850	Кано	2	22	871	46.606833999999999	46.644258000000001	50.443139000000002	50.424985	0103000020E61000000100000005000000E90C8CBCAC4D4740312592E865364940E90C8CBCAC4D4740844A5CC7B8384940DB17D00B77524740844A5CC7B8384940DB17D00B77524740312592E865364940E90C8CBCAC4D4740312592E865364940
48805	Калинино	2	22	871	46.186619999999998	46.210020999999998	50.492573	50.474770999999997	0103000020E61000000100000005000000C763062AE31747406B0BCF4BC53C4940C763062AE317474041F2CEA10C3F4940923CD7F7E11A474041F2CEA10C3F4940923CD7F7E11A47406B0BCF4BC53C4940C763062AE31747406B0BCF4BC53C4940
6789	Иловатка	2	22	871	45.864384999999999	45.905070000000002	50.529068000000002	50.496647000000003	0103000020E610000001000000050000009413ED2AA4EE46400954FF20923F49409413ED2AA4EE464019AE0E80B84349409D4B7155D9F3464019AE0E80B84349409D4B7155D9F346400954FF20923F49409413ED2AA4EE46400954FF20923F4940
6650	Гмелинка	2	22	871	46.887341999999997	46.925538000000003	50.391188999999997	50.361311000000001	0103000020E61000000100000005000000012F336C94714740B05758703F2E4940012F336C9471474008C72C7B12324940469A78077876474008C72C7B12324940469A780778764740B05758703F2E4940012F336C94714740B05758703F2E4940
6560	Верхняя Водянка	2	22	871	47.095463000000002	47.119124999999997	50.407604999999997	50.387973000000002	0103000020E61000000100000005000000317DAF21388C4740925D6919A9314940317DAF21388C4740D15790662C3449406891ED7C3F8F4740D15790662C3449406891ED7C3F8F4740925D6919A9314940317DAF21388C4740925D6919A9314940
6911	Верхний Еруслан	2	22	871	46.512869999999999	46.532893000000001	50.515684	50.502732000000002	0103000020E61000000100000005000000BD8C62B9A54147408B53AD8559404940BD8C62B9A54147400589EDEE0142494038A27BD6354447400589EDEE0142494038A27BD6354447408B53AD8559404940BD8C62B9A54147408B53AD8559404940
51375	Вербный	2	22	871	46.841572999999997	46.864893000000002	50.286917000000003	50.279578000000001	0103000020E610000001000000050000002A1900AAB86B47402E573F36C92349402A1900AAB86B47404ED53DB2B924494009C556D0B46E47404ED53DB2B924494009C556D0B46E47402E573F36C92349402A1900AAB86B47402E573F36C9234940
48550	Валуевка	2	22	871	46.394499000000003	46.425671000000001	50.366931000000001	50.339953000000001	0103000020E6100000010000000500000001A777F17E324740AB967494832B494001A777F17E324740BD715298F72E494085ED27637C364740BD715298F72E494085ED27637C364740AB967494832B494001A777F17E324740AB967494832B4940
48538	Беляевка	2	22	871	46.197246999999997	46.233260000000001	50.314765000000001	50.300773999999997	0103000020E61000000100000005000000F71DC3633F19474059BE2EC37F264940F71DC3633F194740757632384A28494084BBB376DB1D4740757632384A28494084BBB376DB1D474059BE2EC37F264940F71DC3633F19474059BE2EC37F264940
48668	Белокаменка	2	22	871	45.817968999999998	45.834867000000003	50.563715000000002	50.553626000000001	0103000020E6100000010000000500000027124C35B3E846408F1B7E37DD46494027124C35B3E84640E0A128D0274849403CC1FEEBDCEA4640E0A128D0274849403CC1FEEBDCEA46408F1B7E37DD46494027124C35B3E846408F1B7E37DD464940
51529	Ямы	2	22	629	44.602522	44.628869000000002	48.654046999999998	48.645059000000003	0103000020E610000001000000050000006D8FDE701F4D4640C87E164B915248406D8FDE701F4D46400186E5CFB7534840EF3B86C77E5046400186E5CFB7534840EF3B86C77E504640C87E164B915248406D8FDE701F4D4640C87E164B91524840
51302	Чапаевец	2	22	629	44.842632000000002	44.857534999999999	48.591914000000003	48.582890999999996	0103000020E610000001000000050000001348895DDB6B4640FD101B2C9C4A48401348895DDB6B4640B40584D6C34B48407216F6B4C36D4640B40584D6C34B48407216F6B4C36D4640FD101B2C9C4A48401348895DDB6B4640FD101B2C9C4A4840
51691	Тумак	2	22	629	44.609268	44.628779000000002	48.632646000000001	48.620593	0103000020E61000000100000005000000EA3F6B7EFC4D4640329067976F4F4840EA3F6B7EFC4D4640FDF84B8BFA504840AFB48CD47B504640FDF84B8BFA504840AFB48CD47B504640329067976F4F4840EA3F6B7EFC4D4640329067976F4F4840
51699	Суходол	2	22	629	44.875708000000003	44.918019000000001	48.623821	48.610551000000001	0103000020E610000001000000050000003C6C22331770464022C50089264E48403C6C2233177046406DC7D45DD94F4840A60D87A5817546406DC7D45DD94F4840A60D87A58175464022C50089264E48403C6C22331770464022C50089264E4840
5600	Стандартный	2	22	629	44.933883000000002	44.946154	48.724449	48.716894000000003	0103000020E610000001000000050000002BA5677A897746406D59BE2EC35B48402BA5677A89774640594FADBEBA5C4840637D03931B794640594FADBEBA5C4840637D03931B7946406D59BE2EC35B48402BA5677A897746406D59BE2EC35B4840
4067	Средняя Ахтуба	2	22	629	44.838545000000003	44.889524000000002	48.727936999999997	48.694913	0103000020E61000000100000005000000B79C4B71556B46405A48C0E8F2584840B79C4B71556B46403046240A2D5D4840E98024ECDB7146403046240A2D5D4840E98024ECDB7146405A48C0E8F2584840B79C4B71556B46405A48C0E8F2584840
51721	Репино	2	22	629	44.770829999999997	44.802280000000003	48.559038999999999	48.548549000000001	0103000020E610000001000000050000004963B48EAA62464073A087DA364648404963B48EAA624640221807978E474840111E6D1CB1664640221807978E474840111E6D1CB166464073A087DA364648404963B48EAA62464073A087DA36464840
6014	Рахинка	2	22	629	44.910949000000002	44.932831999999998	49.029874999999997	49.003664000000001	0103000020E6100000010000000500000076A911FA997446401616DC0F7880484076A911FA99744640E7FBA9F1D2834840C554FA0967774640E7FBA9F1D2834840C554FA09677746401616DC0F7880484076A911FA997446401616DC0F78804840
45891	Приканальный	2	22	629	44.663840999999998	44.678268000000003	48.758315000000003	48.752915000000002	0103000020E61000000100000005000000395FECBDF85446407CD5CA845F604840395FECBDF85446407B8846771061484030F65E7CD15646407B8846771061484030F65E7CD15646407CD5CA845F604840395FECBDF85446407CD5CA845F604840
5374	Пламенка	2	22	629	44.719149999999999	44.725124000000001	48.578218	48.570307999999997	0103000020E610000001000000050000008E75711B0D5C4640D65240DAFF4848408E75711B0D5C4640B1FA230C034A4840B9C5FCDCD05C4640B1FA230C034A4840B9C5FCDCD05C4640D65240DAFF4848408E75711B0D5C4640D65240DAFF484840
51434	Песчанка	2	22	629	44.548236000000003	45.581280999999997	49.231023	48.486888	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
51695	Максима Горького	2	22	629	45.142167000000001	45.164247000000003	48.954267000000002	48.938971000000002	0103000020E6100000010000000500000004C93B87329246403B72A4333078484004C93B87329246407653CA6B257A4840AABBB20B069546407653CA6B257A4840AABBB20B069546403B72A4333078484004C93B87329246403B72A43330784840
47815	Куйбышев	2	22	629	44.839568999999997	44.866492000000001	48.686849000000002	48.672142999999998	0103000020E6100000010000000500000022DE3AFF766B46401F9E25C80856484022DE3AFF766B4640292504ABEA574840711FB935E96E4640292504ABEA574840711FB935E96E46401F9E25C80856484022DE3AFF766B46401F9E25C808564840
48202	Красный Сад	2	22	629	44.883380000000002	44.902298000000002	48.688865	48.672029999999999	0103000020E6100000010000000500000062F888981271464027F73B140556484062F8889812714640F52D73BA2C584840849F38807E734640F52D73BA2C584840849F38807E73464027F73B140556484062F888981271464027F73B1405564840
51430	Красный Октябрь	2	22	629	45.291628000000003	45.322153	49.092367000000003	49.070971	0103000020E61000000100000005000000884CF91054A5464072FBE59315894840884CF91054A54640651D8EAED28B484076A73B4F3CA94640651D8EAED28B484076A73B4F3CA9464072FBE59315894840884CF91054A5464072FBE59315894840
47533	Краснослободск	2	22	629	44.544795999999998	44.623407	48.735883000000001	48.677253999999998	0103000020E61000000100000005000000ED7E15E0BB454640E78A5242B0564840ED7E15E0BB4546405857056A315E48407A8CF2CCCB4F46405857056A315E48407A8CF2CCCB4F4640E78A5242B0564840ED7E15E0BB454640E78A5242B0564840
51620	Кочетково	2	22	629	44.853591999999999	44.865251999999998	48.646892999999999	48.638058000000001	0103000020E610000001000000050000004910AE80426D4640C07971E2AB5148404910AE80426D46407381CB63CD5248403866D993C06E46407381CB63CD5248403866D993C06E4640C07971E2AB5148404910AE80426D4640C07971E2AB514840
4570	Колхозная Ахтуба	2	22	629	44.782248000000003	44.812665000000003	48.720657000000003	48.710777	0103000020E6100000010000000500000043AED4B320644640DFDFA0BDFA5A484043AED4B3206446401651137D3E5C48404BCD1E68056846401651137D3E5C48404BCD1E6805684640DFDFA0BDFA5A484043AED4B320644640DFDFA0BDFA5A4840
51718	Клетский	2	22	629	44.679408000000002	44.728717000000003	48.604171000000001	48.590620999999999	0103000020E61000000100000005000000055262D7F656464058AA0B78994B4840055262D7F65646408718AF79554D484006854199465D46408718AF79554D484006854199465D464058AA0B78994B4840055262D7F656464058AA0B78994B4840
4648	Киляковка	2	22	629	44.777199000000003	44.802737999999998	48.743701999999999	48.727527000000002	0103000020E61000000100000005000000F1BDBF417B6346407FFACF9A1F5D4840F1BDBF417B63464022FC8BA0315F4840D3A0681EC066464022FC8BA0315F4840D3A0681EC06646407FFACF9A1F5D4840F1BDBF417B6346407FFACF9A1F5D4840
51491	Калинина	2	22	629	44.926426999999997	44.956530000000001	48.676284000000003	48.664800999999997	0103000020E61000000100000005000000D190F128957646408EACFC3218554840D190F128957646406F675F79905648404AD235936F7A46406F675F79905648404AD235936F7A46408EACFC3218554840D190F128957646408EACFC3218554840
47990	Звездный	2	22	629	44.917012999999997	44.930594999999997	48.820283000000003	48.810102999999998	0103000020E61000000100000005000000E08096AE607546401CB28174B1674840E08096AE607546407E3B8908FF6848401A69A9BC1D7746407E3B8908FF6848401A69A9BC1D7746401CB28174B1674840E08096AE607546401CB28174B1674840
51608	Закутский	2	22	629	44.658720000000002	44.675257999999999	48.688014000000003	48.667687000000001	0103000020E610000001000000050000004E9CDCEF50544640707B82C4765548404E9CDCEF505446405798BED710584840622EA9DA6E5646405798BED710584840622EA9DA6E564640707B82C4765548404E9CDCEF50544640707B82C476554840
47688	Вторая Пятилетка	2	22	629	44.548236000000003	44.566175999999999	48.674452000000002	48.658206999999997	0103000020E61000000100000005000000B43EE5982C464640C77F812040544840B43EE5982C464640645C717154564840DAE3857478484640645C717154564840DAE3857478484640C77F812040544840B43EE5982C464640C77F812040544840
4766	Верхнепогромное	2	22	629	44.831026000000001	44.862763999999999	48.960341999999997	48.938101000000003	0103000020E6100000010000000500000017105A0F5F6A464026AC8DB11378484017105A0F5F6A4640D47C957CEC7A48404415FE0C6F6E4640D47C957CEC7A48404415FE0C6F6E464026AC8DB11378484017105A0F5F6A464026AC8DB113784840
5913	Великий Октябрь	2	22	629	44.700743000000003	44.738239	48.665788999999997	48.641368	0103000020E6100000010000000500000052F355F2B1594640B859BC581852484052F355F2B1594640AD84EE9238554840DDD0949D7E5E4640AD84EE9238554840DDD0949D7E5E4640B859BC581852484052F355F2B1594640B859BC5818524840
1892	Чеботаревский	2	22	313	42.273909000000003	42.302906	49.495049000000002	49.478540000000002	0103000020E61000000100000005000000408A3A730F234540F7E978CC40BD4840408A3A730F234540717500C45DBF48408FE1B19FC5264540717500C45DBF48408FE1B19FC5264540F7E978CC40BD4840408A3A730F234540F7E978CC40BD4840
2103	Хохлачев	2	22	313	42.071131999999999	42.102277000000001	49.135415000000002	49.128287999999998	0103000020E610000001000000050000007BD976DA1A094540103CBEBD6B9048407BD976DA1A094540A5315A47559148400611A969170D4540A5315A47559148400611A969170D4540103CBEBD6B9048407BD976DA1A094540103CBEBD6B904840
1512	Хованский	2	22	313	42.529209999999999	42.564585999999998	49.586039	49.574170000000002	0103000020E61000000100000005000000AB5B3D27BD434540132C0E677EC94840AB5B3D27BD4345401C97715303CB4840C5E3A25A444845401C97715303CB4840C5E3A25A44484540132C0E677EC94840AB5B3D27BD434540132C0E677EC94840
2442	Фомихинский	2	22	313	42.548963999999998	42.570729999999998	49.43018	49.398905999999997	0103000020E610000001000000050000003657CD7344464540CE16105A0FB348403657CD734446454057B2632310B748404C6C3EAE0D49454057B2632310B748404C6C3EAE0D494540CE16105A0FB348403657CD7344464540CE16105A0FB34840
1548	Усть-Хоперская	2	22	313	42.381068999999997	42.427494000000003	49.578972	49.564225999999998	0103000020E610000001000000050000007C4276DEC6304540C5C6BC8E38C848407C4276DEC63045405DA626C11BCA48403D9E961FB83645405DA626C11BCA48403D9E961FB8364540C5C6BC8E38C848407C4276DEC6304540C5C6BC8E38C84840
1755	Тюковной	2	22	313	42.133339999999997	42.157100999999997	49.586378000000003	49.575391000000003	0103000020E61000000100000005000000D39FFD4811114540D5B48B69A6C94840D39FFD4811114540058C2E6F0ECB48409E95B4E21B144540058C2E6F0ECB48409E95B4E21B144540D5B48B69A6C94840D39FFD4811114540D5B48B69A6C94840
2901	Трясиновский	2	22	313	42.966366000000001	42.989704000000003	49.774180999999999	49.762725000000003	0103000020E61000000100000005000000B1FB8EE1B17B4540BA6B09F9A0E14840B1FB8EE1B17B4540A017EE5C18E34840365CE49EAE7E4540A017EE5C18E34840365CE49EAE7E4540BA6B09F9A0E14840B1FB8EE1B17B4540BA6B09F9A0E14840
3016	Теркин	2	22	313	43.111615	43.146980999999997	49.763126	49.720728000000001	0103000020E610000001000000050000001C5F7B66498E4540DFA7AAD040DC48401C5F7B66498E4540185DDE1CAEE148401211FE45D0924540185DDE1CAEE148401211FE45D0924540DFA7AAD040DC48401C5F7B66498E4540DFA7AAD040DC4840
2375	Среднецарицынский	2	22	313	42.546422	42.575113999999999	49.360253999999998	49.334560000000003	0103000020E610000001000000050000004FE8F527F14545405F46B1DCD2AA48404FE8F527F1454540682096CD1CAE484062BCE6559D494540682096CD1CAE484062BCE6559D4945405F46B1DCD2AA48404FE8F527F14545405F46B1DCD2AA4840
3360	Серафимович	2	22	313	42.708047000000001	42.758361000000001	49.591715000000001	49.559604	0103000020E61000000100000005000000F583BA48A15A4540FB5A971AA1C74840F583BA48A15A4540BDC62E51BDCB4840EBC726F911614540BDC62E51BDCB4840EBC726F911614540FB5A971AA1C74840F583BA48A15A4540FB5A971AA1C74840
2096	Пронин	2	22	313	42.208655	42.228670000000001	49.214041999999999	49.199686999999997	0103000020E61000000100000005000000CD920035B51A4540DA37F7578F994840CD920035B51A454037FC6EBA659B4840C5C9FD0E451D454037FC6EBA659B4840C5C9FD0E451D4540DA37F7578F994840CD920035B51A4540DA37F7578F994840
51328	Подольховский	2	22	313	42.781618999999999	42.802433000000001	49.691395	49.681702000000001	0103000020E61000000100000005000000537765170C64454014CFD90242D74840537765170C64454018CFA0A17FD84840971DE21FB666454018CFA0A17FD84840971DE21FB666454014CFD90242D74840537765170C64454014CFD90242D74840
3274	Отрожки	2	22	313	42.838275000000003	42.861659000000003	49.581961999999997	49.559826000000001	0103000020E61000000100000005000000F7065F984C6B4540AAB9DC60A8C74840F7065F984C6B4540E3C116BB7DCA4840ECA694D74A6E4540E3C116BB7DCA4840ECA694D74A6E4540AAB9DC60A8C74840F7065F984C6B4540AAB9DC60A8C74840
3023	Орлиновский	2	22	313	43.143900000000002	43.166583000000003	49.752446999999997	49.731727999999997	0103000020E610000001000000050000007CF2B0506B924540A3C85A43A9DD48407CF2B0506B924540957CEC2E50E04840E8887C9752954540957CEC2E50E04840E8887C9752954540A3C85A43A9DD48407CF2B0506B924540A3C85A43A9DD4840
2294	Новопавловский	2	22	313	42.233879999999999	42.251891000000001	49.163775999999999	49.151586000000002	0103000020E610000001000000050000002098A3C7EF1D45400744882B679348402098A3C7EF1D454052EFA99CF69448401094DBF63D20454052EFA99CF69448401094DBF63D2045400744882B679348402098A3C7EF1D45400744882B67934840
51385	Новоалександровский	2	22	313	42.695830000000001	42.712978	49.638731	49.627388000000003	0103000020E61000000100000005000000B0C91AF51059454091F3FE3F4ED04840B0C91AF5105945407FF8F9EFC1D148403D62F4DC425B45407FF8F9EFC1D148403D62F4DC425B454091F3FE3F4ED04840B0C91AF51059454091F3FE3F4ED04840
2789	Мостовский	2	22	313	42.879257000000003	42.901229000000001	49.745189000000003	49.73319	0103000020E61000000100000005000000B9E34D7E8B7045408BE07F2BD9DD4840B9E34D7E8B704540632B685A62DF4840789ACC785B734540632B685A62DF4840789ACC785B7345408BE07F2BD9DD4840B9E34D7E8B7045408BE07F2BD9DD4840
1742	Крутовский	2	22	313	42.223702000000003	42.242558000000002	49.589858	49.575834999999998	0103000020E6100000010000000500000060066344A21C4540327216F6B4C9484060066344A21C454059A4897780CB48400CB1FA230C1F454059A4897780CB48400CB1FA230C1F4540327216F6B4C9484060066344A21C4540327216F6B4C94840
3242	Козиновский	2	22	313	43.224451999999999	43.241781000000003	49.382821	49.372368999999999	0103000020E61000000100000005000000CAC2D7D7BA9C4540A98592C9A9AF4840CAC2D7D7BA9C45406B9C4D4700B14840A8E507AEF29E45406B9C4D4700B14840A8E507AEF29E4540A98592C9A9AF4840CAC2D7D7BA9C4540A98592C9A9AF4840
3129	Клетско-Почтовский	2	22	313	43.039282	43.077810999999997	49.605372000000003	49.576109000000002	0103000020E6100000010000000500000026A94C310785454034F790F0BDC9484026A94C310785454002F566D47CCD48407022FAB5F589454002F566D47CCD48407022FAB5F589454034F790F0BDC9484026A94C310785454034F790F0BDC94840
51665	Калмыковский	2	22	313	42.353284000000002	42.391840000000002	49.454225000000001	49.433537000000001	0103000020E610000001000000050000009C19FD68382D4540904DF2237EB748409C19FD68382D45404703780B24BA4840E0A128D0273245404703780B24BA4840E0A128D027324540904DF2237EB748409C19FD68382D4540904DF2237EB74840
2779	Зимняцкий	2	22	313	42.831718000000002	42.884664000000001	49.736829	49.703054000000002	0103000020E610000001000000050000004DBF44BC756A454037A968ACFDD948404DBF44BC756A454048DFA46950DE48406AF981AB3C71454048DFA46950DE48406AF981AB3C71454037A968ACFDD948404DBF44BC756A454037A968ACFDD94840
51285	Затонский	2	22	313	42.657139000000001	42.688921000000001	49.565237000000003	49.552486000000002	0103000020E610000001000000050000008CF678211D544540BABF7ADCB7C648408CF678211D5445409DBE9EAF59C84840894336902E5845409DBE9EAF59C84840894336902E584540BABF7ADCB7C648408CF678211D544540BABF7ADCB7C64840
51429	Ендовский	2	22	313	43.067076	43.091492000000002	49.650630999999997	49.630107000000002	0103000020E610000001000000050000005A2C45F29588454087FD9E58A7D048405A2C45F295884540C36169E047D348403EEC8502B68B4540C36169E047D348403EEC8502B68B454087FD9E58A7D048405A2C45F29588454087FD9E58A7D04840
51534	Горбатовский	2	22	313	42.08034	43.455615999999999	49.903582999999998	49.126773	0103000020E61000000100000005000000C347C494480A4540068200193A904840C347C494480A45405C1C959BA8F3484065C405A051BA45405C1C959BA8F3484065C405A051BA4540068200193A904840C347C494480A4540068200193A904840
1407	Буерак-Поповский	2	22	313	42.604067000000001	42.621206000000001	49.557237000000001	49.542129000000003	0103000020E61000000100000005000000E2CB4411524D45404A9BAA7B64C54840E2CB4411524D4540828FC18A53C748401C0A9FAD834F4540828FC18A53C748401C0A9FAD834F45404A9BAA7B64C54840E2CB4411524D45404A9BAA7B64C54840
51628	Большой	2	22	313	42.298881999999999	42.333916000000002	49.402546000000001	49.360664999999997	0103000020E6100000010000000500000079AEEFC341264540EAE74D452AAE484079AEEFC3412645405C9198A086B348403ACE6DC2BD2A45405C9198A086B348403ACE6DC2BD2A4540EAE74D452AAE484079AEEFC341264540EAE74D452AAE4840
2547	Бобровский 2-й	2	22	313	42.736128000000001	42.766482000000003	49.495001999999999	49.482602	0103000020E61000000100000005000000BFD53A71395E4540FA7DFFE6C5BD4840BFD53A71395E454030BABC395CBF4840817C09151C62454030BABC395CBF4840817C09151C624540FA7DFFE6C5BD4840BFD53A71395E4540FA7DFFE6C5BD4840
1603	Бобровский 1-й	2	22	313	42.309356000000001	42.343401999999998	49.600614	49.582493999999997	0103000020E61000000100000005000000236937FA98274540E00ED4298FCA4840236937FA9827454087C267EBE0CC4840C4B0C398F42B454087C267EBE0CC4840C4B0C398F42B4540E00ED4298FCA4840236937FA98274540E00ED4298FCA4840
2211	Блиновский	2	22	313	42.278157999999998	42.300660999999998	49.310912999999999	49.283048000000001	0103000020E61000000100000005000000758F6CAE9A2345405F99B7EA3AA44840758F6CAE9A2345405C7347FFCBA748406117450F7C2645405C7347FFCBA748406117450F7C2645405F99B7EA3AA44840758F6CAE9A2345405F99B7EA3AA44840
47183	Березки	2	22	313	42.728383999999998	42.755764999999997	49.610422	49.604678	0103000020E61000000100000005000000FF76D9AF3B5D45402B4EB51666CD4840FF76D9AF3B5D45402461DF4E22CE4840103B53E8BC6045402461DF4E22CE4840103B53E8BC6045402B4EB51666CD4840FF76D9AF3B5D45402B4EB51666CD4840
51351	Базки	2	22	313	42.748227999999997	42.774656999999998	49.437455999999997	49.416607999999997	0103000020E61000000100000005000000CAF962EFC55F454040A0336953B54840CAF962EFC55F454030B8E68EFEB74840094FE8F52763454030B8E68EFEB74840094FE8F52763454040A0336953B54840CAF962EFC55F454040A0336953B54840
970	Червленое	2	22	6	44.353454999999997	44.387805999999998	48.452432000000002	48.432307999999999	0103000020E61000000100000005000000C8CD70033E2D46404BE658DE55374840C8CD70033E2D4640FAD4B14AE9394840A69883A0A3314640FAD4B14AE9394840A69883A0A33146404BE658DE55374840C8CD70033E2D46404BE658DE55374840
8982	Цаца	2	22	6	44.662385	44.697105000000001	48.211032000000003	48.181201000000001	0103000020E61000000100000005000000342E1C08C95446405280289831174840342E1C08C95446406A34B918031B4840657094BC3A5946406A34B918031B4840657094BC3A5946405280289831174840342E1C08C95446405280289831174840
51362	Станция Абганерово	2	22	6	44.087491	44.122695999999998	48.144865000000003	48.127006000000002	0103000020E61000000100000005000000E0D8B3E7320B4640A9328CBB41104840E0D8B3E7320B4640E3AAB2EF8A124840CDACA580B40F4640E3AAB2EF8A124840CDACA580B40F4640A9328CBB41104840E0D8B3E7320B4640A9328CBB41104840
51451	Северный	2	22	6	44.042431000000001	44.081059000000003	48.330573000000001	48.309663	0103000020E6100000010000000500000015AB06616E05464000E48409A327484015AB06616E05464066F84F37502A4840F3052D24600A464066F84F37502A4840F3052D24600A464000E48409A327484015AB06616E05464000E48409A3274840
32203	Светлый Яр	2	22	6	44.728473999999999	44.804220000000001	48.487096999999999	48.453477999999997	0103000020E610000001000000050000003FFED2A23E5D46404DBA2D910B3A48403FFED2A23E5D4640677DCA31593E4840026553AEF0664640677DCA31593E4840026553AEF06646404DBA2D910B3A48403FFED2A23E5D46404DBA2D910B3A4840
173	Райгород	2	22	6	44.881044000000003	44.945678000000001	48.429696	48.413803000000001	0103000020E61000000100000005000000242BBF0CC67046404CFE277FF7344840242BBF0CC67046406B9C4D4700374840FA4509FA0B7946406B9C4D4700374840FA4509FA0B7946404CFE277FF7344840242BBF0CC67046404CFE277FF7344840
46559	Прудовый	2	22	6	44.273217000000002	44.287258000000001	48.322132000000003	48.308998000000003	0103000020E610000001000000050000000ADB4FC6F8224640C443183F8D2748400ADB4FC6F82246405F7F129F3B294840D7C1C1DEC42446405F7F129F3B294840D7C1C1DEC4244640C443183F8D2748400ADB4FC6F8224640C443183F8D274840
45700	Привольный	2	22	6	44.073441000000003	44.192818000000003	48.240425999999999	48.148496000000002	0103000020E61000000100000005000000C097C283660946401DCBBBEA01134840C097C28366094640D68D7747C61E4840420A9E42AE184640D68D7747C61E4840420A9E42AE1846401DCBBBEA01134840C097C283660946401DCBBBEA01134840
46462	Приволжский	2	22	6	44.560516	44.589872999999997	48.245472999999997	48.230181999999999	0103000020E610000001000000050000003F7100FDBE4746405E10919A761D48403F7100FDBE4746408786C5A86B1F48408EE55DF5804B46408786C5A86B1F48408EE55DF5804B46405E10919A761D48403F7100FDBE4746405E10919A761D4840
46555	Нариман	2	22	6	44.191353999999997	44.218671999999998	48.485621999999999	48.472321000000001	0103000020E61000000100000005000000B9FAB1497E184640651BB803753C4840B9FAB1497E184640EB1B98DC283E48408446B071FD1B4640EB1B98DC283E48408446B071FD1B4640651BB803753C4840B9FAB1497E184640651BB803753C4840
403	Малые Чапурники	2	22	6	44.571323	44.580773000000001	48.458945	48.440061	0103000020E61000000100000005000000EF39B01C214946405E9F39EB53384840EF39B01C21494640D4D4B2B5BE3A48402DB308C5564A4640D4D4B2B5BE3A48402DB308C5564A46405E9F39EB53384840EF39B01C214946405E9F39EB53384840
46480	Луговой	2	22	6	44.474395000000001	44.510184000000002	48.224966000000002	48.215792999999998	0103000020E610000001000000050000006631B1F9B83C464055DAE21A9F1B48406631B1F9B83C4640215B96AFCB1C4840A37895B54D414640215B96AFCB1C4840A37895B54D41464055DAE21A9F1B48406631B1F9B83C464055DAE21A9F1B4840
46508	Краснопартизанский	2	22	6	44.245108999999999	44.265293999999997	48.174970000000002	48.162038000000003	0103000020E61000000100000005000000467A51BB5F1F4640C95A43A9BD144840467A51BB5F1F4640FCE3BD6A651648409AE95E27F5214640FCE3BD6A651648409AE95E27F5214640C95A43A9BD144840467A51BB5F1F4640C95A43A9BD144840
46658	Кирова	2	22	6	44.498874000000001	44.556761000000002	48.491677000000003	48.456429999999997	0103000020E6100000010000000500000090696D1ADB3F4640E674594C6C3A484090696D1ADB3F464003999D45EF3E48401958C7F14347464003999D45EF3E48401958C7F143474640E674594C6C3A484090696D1ADB3F4640E674594C6C3A4840
51550	Кирова	2	22	6	43.926189000000001	45.073948999999999	48.584589999999999	48.054220000000001	0103000020E610000001000000050000001D75745C8DF64540026553AEF00648401D75745C8DF64540C9C859D8D34A484034492C2977894640C9C859D8D34A484034492C2977894640026553AEF00648401D75745C8DF64540026553AEF0064840
51565	Канальная	2	22	6	44.378644000000001	44.388103000000001	48.430627999999999	48.417205000000003	0103000020E61000000100000005000000CF69166877304640255D33F966354840CF69166877304640F65E7CD11E374840603DEE5BAD314640F65E7CD11E374840603DEE5BAD314640255D33F966354840CF69166877304640255D33F966354840
46722	Ивановка	2	22	6	44.372041000000003	44.389350999999998	48.480510000000002	48.468456000000003	0103000020E61000000100000005000000B5E21B0A9F2F4640B8CEBF5DF63B4840B5E21B0A9F2F464053B3075A813D48401BD5E940D631464053B3075A813D48401BD5E940D6314640B8CEBF5DF63B4840B5E21B0A9F2F4640B8CEBF5DF63B4840
489	Дубовый Овраг	2	22	6	44.605665999999999	44.636361000000001	48.349043000000002	48.312707000000003	0103000020E610000001000000050000004A26A776864D46407A1D71C8062848404A26A776864D4640E9F2E670AD2C484095B9F94674514640E9F2E670AD2C484095B9F946745146407A1D71C8062848404A26A776864D46407A1D71C806284840
305	Большие Чапурники	2	22	6	44.565061999999998	44.596108000000001	48.438769999999998	48.400854000000002	0103000020E610000001000000050000002E1B9DF353484640433C122F4F3348402E1B9DF353484640A33B889D29384840267156444D4C4640A33B889D29384840267156444D4C4640433C122F4F3348402E1B9DF353484640433C122F4F334840
31945	Ушинка	2	22	1917	44.460479999999997	44.510247	50.652484000000001	50.637028000000001	0103000020E61000000100000005000000253B3602F13A464072512D228A514940253B3602F13A4640E694809884534940E9F010C64F414640E694809884534940E9F010C64F41464072512D228A514940253B3602F13A464072512D228A514940
32170	Сосновка	2	22	1917	44.253301999999998	44.291552000000003	50.805281000000001	50.786732000000001	0103000020E6100000010000000500000075012F336C204640BC5B59A2B364494075012F336C2046408B8BA37213674940AD8A7093512546408B8BA37213674940AD8A709351254640BC5B59A2B364494075012F336C204640BC5B59A2B3644940
31540	Садовый	2	22	1917	44.571376999999998	44.583882000000003	50.872503999999999	50.866393000000002	0103000020E61000000100000005000000E257ACE122494640DE3D40F7E56E4940E257ACE12249464089D00836AE6F49408E5C37A5BC4A464089D00836AE6F49408E5C37A5BC4A4640DE3D40F7E56E4940E257ACE122494640DE3D40F7E56E4940
51569	Рудня	2	22	1917	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
31297	Рудня	2	22	1917	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
32095	Подкуйково	2	22	1917	44.545262999999998	44.576515000000001	50.893013000000003	50.878079	0103000020E61000000100000005000000035C902DCB454640F62686E464704940035C902DCB45464091F3FE3F4E724940A453573ECB49464091F3FE3F4E724940A453573ECB494640F62686E464704940035C902DCB454640F62686E464704940
32034	Осички	2	22	1917	44.494373000000003	44.521700000000003	50.959721999999999	50.940486	0103000020E6100000010000000500000041834D9D473F4640452C62D86178494041834D9D473F464038A0A52BD87A49405F29CB10C742464038A0A52BD87A49405F29CB10C7424640452C62D86178494041834D9D473F4640452C62D861784940
31715	Новая Кондаль	2	22	1917	44.389198999999998	44.415734999999998	50.544925999999997	50.530551000000003	0103000020E610000001000000050000006551D845D131464018EE5C18E94349406551D845D1314640BB5E9A22C0454940BA66F2CD36354640BB5E9A22C0454940BA66F2CD3635464018EE5C18E94349406551D845D131464018EE5C18E9434940
32013	Матышево	2	22	1917	44.173997999999997	44.246825000000001	50.860947000000003	50.812755000000003	0103000020E61000000100000005000000E2C80391451646408B54185B08684940E2C80391451646406F4BE482336E4940E86A2BF6971F46406F4BE482336E4940E86A2BF6971F46408B54185B08684940E2C80391451646408B54185B08684940
31924	Лопуховка	2	22	1917	44.432785000000003	44.503743	50.635210999999998	50.615451	0103000020E610000001000000050000008599B67F653746402FA52E19C74E49408599B67F653746409C8713984E514940624B8FA67A4046409C8713984E514940624B8FA67A4046402FA52E19C74E49408599B67F653746402FA52E19C74E4940
31854	Лемешкино	2	22	1917	44.462159999999997	44.489809999999999	51.029831000000001	50.996215999999997	0103000020E610000001000000050000007AC2120F283B46403FE08101847F49407AC2120F283B464018B49080D18349407BA01518B23E464018B49080D18349407BA01518B23E46403FE08101847F49407AC2120F283B46403FE08101847F4940
31826	Козловка	2	22	1917	44.345370000000003	44.371879	51.009258000000003	50.986612000000001	0103000020E6100000010000000500000080828B15352C4640ABEB504D497E494080828B15352C4640FA9CBB5D2F814940DB8827BB992F4640FA9CBB5D2F814940DB8827BB992F4640ABEB504D497E494080828B15352C4640ABEB504D497E4940
31781	Ильмень	2	22	1917	44.361234000000003	44.417180999999999	50.850746000000001	50.823214	0103000020E61000000100000005000000051A6CEA3C2E4640FFCD8B135F694940051A6CEA3C2E4640F699B33EE56C49409CC1DF2F66354640F699B33EE56C49409CC1DF2F66354640FFCD8B135F694940051A6CEA3C2E4640FFCD8B135F694940
31697	Громки	2	22	1917	44.430584000000003	44.465617999999999	50.595837000000003	50.579481000000001	0103000020E61000000100000005000000271763601D374640A2D3F36E2C4A4940271763601D374640965F0663444C4940E736E15E993B4640965F0663444C4940E736E15E993B4640A2D3F36E2C4A4940271763601D374640A2D3F36E2C4A4940
31649	Большое Судачье	2	22	1917	44.045817999999997	44.124070000000003	50.845092999999999	50.813825000000001	0103000020E61000000100000005000000B8C83D5DDD05464067D5E76A2B684940B8C83D5DDD0546400D8AE6012C6C494016359886E10F46400D8AE6012C6C494016359886E10F464067D5E76A2B684940B8C83D5DDD05464067D5E76A2B684940
32122	Баранниково	2	22	1917	44.570281000000001	44.598129	50.901631000000002	50.887774	0103000020E61000000100000005000000DD43C2F7FE4846409B1E1494A2714940DD43C2F7FE484640A70705A56873494004E5B67D8F4C4640A70705A56873494004E5B67D8F4C46409B1E1494A2714940DD43C2F7FE4846409B1E1494A2714940
30556	Эльтон	2	22	862	46.828915000000002	46.864730999999999	49.140023999999997	49.114285000000002	0103000020E61000000100000005000000F91400E3196A474031B610E4A08E4840F91400E3196A4740DA53724EEC9148402F6B6281AF6E4740DA53724EEC9148402F6B6281AF6E474031B610E4A08E4840F91400E3196A474031B610E4A08E4840
51527	Худушный	2	22	862	46.776166000000003	46.798642000000001	49.908839	49.892986999999998	0103000020E6100000010000000500000032225168596347406760E4654DF248403222516859634740282A1BD654F44840249BABE639664740282A1BD654F44840249BABE6396647406760E4654DF2484032225168596347406760E4654DF24840
26585	Старая Иванцовка	2	22	862	46.697986	46.722679999999997	50.048859	50.026190999999997	0103000020E610000001000000050000006E88F19A575947408A39083A5A0349406E88F19A57594740C18EFF024106494094BC3AC7805C4740C18EFF024106494094BC3AC7805C47408A39083A5A0349406E88F19A575947408A39083A5A034940
51675	Старая Балка	2	22	862	46.682265000000001	46.69388	49.992247999999996	49.983623999999999	0103000020E610000001000000050000004C1AA37554574740C5C72764E7FD48404C1AA37554574740BDC282FB01FF48409BAC510FD1584740BDC282FB01FF48409BAC510FD1584740C5C72764E7FD48404C1AA37554574740C5C72764E7FD4840
51621	Смычка	2	22	862	47.155219000000002	47.168892	50.116154000000002	50.107708000000002	0103000020E61000000100000005000000E25B5837DE93474040C23060C90D4940E25B5837DE93474059A65F22DE0E49402C47C8409E95474059A65F22DE0E49402C47C8409E95474040C23060C90D4940E25B5837DE93474040C23060C90D4940
51461	Село Серогодский	2	22	862	47.023805000000003	47.046675999999998	49.941989	49.931784	0103000020E610000001000000050000009B3DD00A0C834740D177B7B244F748409B3DD00A0C8347408B18761893F8484009C1AA7AF98547408B18761893F8484009C1AA7AF9854740D177B7B244F748409B3DD00A0C834740D177B7B244F74840
51544	Сапунков	2	22	862	46.369526	46.389693000000001	49.847566999999998	49.838818000000003	0103000020E61000000100000005000000C782C2A04C2F4740E8A562635EEB4840C782C2A04C2F47409C1551137DEC4840753DD175E13147409C1551137DEC4840753DD175E1314740E8A562635EEB4840C782C2A04C2F4740E8A562635EEB4840
49370	Савинка	2	22	862	47.071074000000003	47.126545	50.091603999999997	50.056558000000003	0103000020E6100000010000000500000047CCECF318894740E129E44A3D07494047CCECF31889474065170CAEB90B4940753C66A03290474065170CAEB90B4940753C66A032904740E129E44A3D07494047CCECF318894740E129E44A3D074940
48783	Ромашки	2	22	862	46.659762000000001	46.684933000000001	50.210040999999997	50.184697999999997	0103000020E610000001000000050000006092CA14735447407CD11E2FA41749406092CA1473544740D9E89C9FE21A4940C07971E2AB574740D9E89C9FE21A4940C07971E2AB5747407CD11E2FA41749406092CA14735447407CD11E2FA4174940
18989	Путь Ильича	2	22	862	46.683109999999999	46.702072999999999	49.327326999999997	49.318513000000003	0103000020E6100000010000000500000008C9022670574740E92CB308C5A8484008C9022670574740840CE4D9E5A94840CA332F87DD594740840CE4D9E5A94840CA332F87DD594740E92CB308C5A8484008C9022670574740E92CB308C5A84840
51312	Прудентов	2	22	862	46.288561000000001	46.321511000000001	49.656556000000002	49.644319000000003	0103000020E6100000010000000500000056F31C91EF2447408198840B79D2484056F31C91EF2447400DFFE9060AD44840F226BF45272947400DFFE9060AD44840F226BF45272947408198840B79D2484056F31C91EF2447408198840B79D24840
51373	Приозерный	2	22	862	46.757283999999999	46.772886999999997	49.069395	49.063102000000001	0103000020E610000001000000050000005CE49EAEEE604740F627F1B9138848405CE49EAEEE604740C2C073EFE1884840744012F6ED624740C2C073EFE1884840744012F6ED624740F627F1B9138848405CE49EAEEE604740F627F1B913884840
6484	Палласовка	2	22	862	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
23656	Новая Иванцовка	2	22	862	46.773012999999999	46.812395000000002	50.034778000000003	50.022984000000001	0103000020E6100000010000000500000001310917F2624740672AC423F102494001310917F2624740664F029B730449408B37328FFC674740664F029B730449408B37328FFC674740672AC423F102494001310917F2624740672AC423F1024940
49408	Лиманный	2	22	862	47.037377999999997	47.067022999999999	50.034303999999999	50.020629	0103000020E6100000010000000500000081CB63CDC8844740B22C98F8A302494081CB63CDC88447409D0FCF1264044940378AAC35948847409D0FCF1264044940378AAC3594884740B22C98F8A302494081CB63CDC8844740B22C98F8A3024940
51450	Кумысолечебница	2	22	862	47.191941999999997	47.212595	50.191405000000003	50.174666000000002	0103000020E610000001000000050000004A5D328E9198474090DC9A745B1649404A5D328E919847403CA583F57F18494085251E50369B47403CA583F57F18494085251E50369B474090DC9A745B1649404A5D328E9198474090DC9A745B164940
29457	Куликов	2	22	862	47.310062000000002	47.325763999999999	50.115859999999998	50.109290999999999	0103000020E61000000100000005000000BEDD921CB0A74740A25F5B3FFD0D4940BEDD921CB0A7474010751F80D40E4940691B7FA2B2A9474010751F80D40E4940691B7FA2B2A94740A25F5B3FFD0D4940BEDD921CB0A74740A25F5B3FFD0D4940
51546	Красный Октябрь	2	22	862	46.518664000000001	46.552674000000003	49.995525999999998	49.974663	0103000020E6100000010000000500000068CEFA946342474085CFD6C1C1FC484068CEFA9463424740AA285E656DFF4840BDAC8905BE464740AA285E656DFF4840BDAC8905BE46474085CFD6C1C1FC484068CEFA946342474085CFD6C1C1FC4840
45382	Комсомольский	2	22	862	46.740583999999998	46.772644999999997	49.548704999999998	49.533956000000003	0103000020E610000001000000050000006EF8DD74CB5E474062C092AB58C448406EF8DD74CB5E47406A1327F73BC648407E350708E66247406A1327F73BC648407E350708E662474062C092AB58C448406EF8DD74CB5E474062C092AB58C44840
48208	Калинина	2	22	862	46.926526000000003	46.947951000000003	49.125239999999998	49.113788999999997	0103000020E6100000010000000500000065726A679876474080D250A3908E484065726A6798764740551344DD07904840F29A577556794740551344DD07904840F29A57755679474080D250A3908E484065726A679876474080D250A3908E4840
29955	Калашники	2	22	862	46.721952999999999	46.737206	49.917929000000001	49.902289000000003	0103000020E61000000100000005000000E21FB6F4685C47403145B9347EF34840E21FB6F4685C474066868DB27EF548401E3526C45C5E474066868DB27EF548401E3526C45C5E47403145B9347EF34840E21FB6F4685C47403145B9347EF34840
30266	Кайсацкое	2	22	862	46.835768999999999	46.861407	49.752277999999997	49.732467999999997	0103000020E610000001000000050000005C01857AFA6A4740EAAEEC82C1DD48405C01857AFA6A474009C03FA54AE04840D2C5A695426E474009C03FA54AE04840D2C5A695426E4740EAAEEC82C1DD48405C01857AFA6A4740EAAEEC82C1DD4840
29985	Золотари	2	22	862	46.436647999999998	46.464692999999997	49.774047000000003	49.754629999999999	0103000020E6100000010000000500000091EEE714E43747404D4A41B797E0484091EEE714E43747409148DBF813E348400ED76A0F7B3B47409148DBF813E348400ED76A0F7B3B47404D4A41B797E0484091EEE714E43747404D4A41B797E04840
49391	Заливной	2	22	862	47.032266999999997	47.047359	50.043444999999998	50.032902999999997	0103000020E61000000100000005000000B9DE3653218447405B785E2A36044940B9DE3653218447405D16139B8F054940EC1516DC0F8647405D16139B8F054940EC1516DC0F8647405B785E2A36044940B9DE3653218447405B785E2A36044940
29827	Жолобов	2	22	862	46.590646	46.603735	49.874110999999999	49.861882999999999	0103000020E61000000100000005000000B1C1C2499A4B47403BFDA02E52EE4840B1C1C2499A4B4740740987DEE2EF4840AC394030474D4740740987DEE2EF4840AC394030474D47403BFDA02E52EE4840B1C1C2499A4B47403BFDA02E52EE4840
51383	Ерши	2	22	862	45.619010000000003	47.352184000000001	50.316496000000001	48.613343999999998	0103000020E61000000100000005000000D0F23CB83BCF46405299620E824E4840D0F23CB83BCF46404CA8E0F0822849405516855D14AD47404CA8E0F0822849405516855D14AD47405299620E824E4840D0F23CB83BCF46405299620E824E4840
30235	Гормаки	2	22	862	46.085037999999997	46.099178000000002	49.660468999999999	49.651440999999998	0103000020E6100000010000000500000068757286E20A474003232F6B62D3484068757286E20A4740CB82893F8AD44840C93D5DDDB10C4740CB82893F8AD44840C93D5DDDB10C474003232F6B62D3484068757286E20A474003232F6B62D34840
45398	Вишневка	2	22	862	46.76041	46.785760000000003	49.43844	49.413108999999999	0103000020E6100000010000000500000093C6681D55614740755776C1E0B4484093C6681D556147400EA14ACD1EB84840A3409FC8936447400EA14ACD1EB84840A3409FC893644740755776C1E0B4484093C6681D55614740755776C1E0B44840
30510	Венгеловка	2	22	862	46.805208999999998	46.820058000000003	49.289417999999998	49.276189000000002	0103000020E61000000100000005000000F1B8A81611674740EA4141295AA34840F1B8A81611674740D66F26A60BA548405E6919A9F7684740D66F26A60BA548405E6919A9F7684740EA4141295AA34840F1B8A81611674740EA4141295AA34840
30708	Большой Симкин	2	22	862	46.657094000000001	46.675645000000003	48.897658999999997	48.885438999999998	0103000020E61000000100000005000000EC32FCA71B5447402DCDAD1056714840EC32FCA71B544740E3FA777DE67248405C5A0D897B564740E3FA777DE67248405C5A0D897B5647402DCDAD1056714840EC32FCA71B5447402DCDAD1056714840
51709	Ягодное	2	22	1835	44.722537000000003	44.775500999999998	49.771877000000003	49.747342000000003	0103000020E610000001000000050000003293A8177C5C4640B07614E7A8DF48403293A8177C5C46406EC493DDCCE24840F581E49D436346406EC493DDCCE24840F581E49D43634640B07614E7A8DF48403293A8177C5C4640B07614E7A8DF4840
51361	Солодча	2	22	1835	44.267791000000003	44.310389999999998	49.673389999999998	49.631349999999998	0103000020E61000000100000005000000E294B9F946224640302AA913D0D04840E294B9F9462246400ABABDA431D64840B28009DCBA2746400ABABDA431D64840B28009DCBA274640302AA913D0D04840E294B9F946224640302AA913D0D04840
51641	Рыбинка	2	22	1835	44.749181	44.793880999999999	50.005775	49.981852000000003	0103000020E610000001000000050000006DE4BA29E55F464090C18A53ADFD48406DE4BA29E55F46403411363CBD00494038F581E49D6546403411363CBD00494038F581E49D65464090C18A53ADFD48406DE4BA29E55F464090C18A53ADFD4840
51524	Романовка	2	22	1835	45.081978999999997	45.104033000000001	49.776612999999998	49.749490000000002	0103000020E61000000100000005000000B9FAB1497E8A4640EB56CF49EFDF4840B9FAB1497E8A46400053060E68E34840365A0EF4508D46400053060E68E34840365A0EF4508D4640EB56CF49EFDF4840B9FAB1497E8A4640EB56CF49EFDF4840
51729	Погожья Балка	2	22	1835	44.262914000000002	44.286045000000001	49.917883000000003	49.905306000000003	0103000020E610000001000000050000008DD47B2AA7214640B16F2711E1F348408DD47B2AA7214640F646AD307DF548409817601F9D244640F646AD307DF548409817601F9D244640B16F2711E1F348408DD47B2AA7214640B16F2711E1F34840
51697	Ольховка	2	22	1835	44.535767999999997	44.580539999999999	49.873136000000002	49.844006	0103000020E61000000100000005000000251FBB0B944446405BD07B6308EC4840251FBB0B94444640EA7AA2EBC2EF48408A027D224F4A4640EA7AA2EBC2EF48408A027D224F4A46405BD07B6308EC4840251FBB0B944446405BD07B6308EC4840
51321	Ольховка	2	22	1835	44.535767999999997	44.580539999999999	49.873136000000002	49.844006	0103000020E61000000100000005000000251FBB0B944446405BD07B6308EC4840251FBB0B94444640EA7AA2EBC2EF48408A027D224F4A4640EA7AA2EBC2EF48408A027D224F4A46405BD07B6308EC4840251FBB0B944446405BD07B6308EC4840
51403	Нежинский	2	22	1835	44.316175000000001	44.337077999999998	49.974772999999999	49.963456999999998	0103000020E610000001000000050000000A68226C78284640170D198F52FB48400A68226C782846400C03965CC5FC4840BD19355F252B46400C03965CC5FC4840BD19355F252B4640170D198F52FB48400A68226C78284640170D198F52FB4840
51607	Липовка	2	22	1835	44.902828	44.961264	49.794764999999998	49.748972000000002	0103000020E61000000100000005000000E0F42EDE8F73464053CF8250DEDF4840E0F42EDE8F734640B28009DCBAE548403C69E1B20A7B4640B28009DCBAE548403C69E1B20A7B464053CF8250DEDF4840E0F42EDE8F73464053CF8250DEDF4840
51517	Клиновка	2	22	1835	44.512968999999998	44.540241000000002	49.897421000000001	49.881599999999999	0103000020E61000000100000005000000506EDBF7A8414640A913D044D8F04840506EDBF7A84146402FDFFAB0DEF24840AB7AF99D264546402FDFFAB0DEF24840AB7AF99D26454640A913D044D8F04840506EDBF7A8414640A913D044D8F04840
51611	Киреево	2	22	1835	44.461593999999998	44.511539999999997	50.029316000000001	50.003059999999998	0103000020E61000000100000005000000D1031F83153B46407FF6234564004940D1031F83153B4640F19F6EA0C0034940444C89247A414640F19F6EA0C0034940444C89247A4146407FF6234564004940D1031F83153B46407FF6234564004940
28480	Каменный Брод	2	22	1835	44.460714000000003	44.505170999999997	49.832078000000003	49.80733	0103000020E61000000100000005000000996725ADF83A4640338AE59656E74840996725ADF83A46404DDC2A8881EA48409DF17D71A94046404DDC2A8881EA48409DF17D71A9404640338AE59656E74840996725ADF83A4640338AE59656E74840
51400	Зензеватка	2	22	1835	44.516005	44.562969000000002	49.816316999999998	49.788989999999998	0103000020E6100000010000000500000047C9AB730C4246407E6FD39FFDE4484047C9AB730C4246409C1551137DE84840B7D4415E0F4846409C1551137DE84840B7D4415E0F4846407E6FD39FFDE4484047C9AB730C4246407E6FD39FFDE44840
51705	Захаровка	2	22	1835	44.349879000000001	44.406455000000001	49.715544000000001	49.699401000000002	0103000020E610000001000000050000005247C7D5C82C464015E5D2F885D948405247C7D5C82C4640AD6C1FF296DB4840D925AAB706344640AD6C1FF296DB4840D925AAB70634464015E5D2F885D948405247C7D5C82C464015E5D2F885D94840
51497	Забурунный	2	22	1835	44.748398999999999	44.775986000000003	49.944597000000002	49.934156000000002	0103000020E61000000100000005000000F7ADD689CB5F46405CAE7E6C92F74840F7ADD689CB5F46402A73F38DE8F84840B2135E82536346402A73F38DE8F84840B2135E82536346405CAE7E6C92F74840F7ADD689CB5F46405CAE7E6C92F74840
51322	Гусевка	2	22	1835	44.671126000000001	44.697023999999999	49.917419000000002	49.900519000000003	0103000020E6100000010000000500000066BFEE74E75546409C36E33444F3484066BFEE74E755464051DD5CFC6DF5484078431A153859464051DD5CFC6DF5484078431A15385946409C36E33444F3484066BFEE74E75546409C36E33444F34840
51609	Гурово	2	22	1835	44.400382999999998	44.424709	50.081426	50.043855999999998	0103000020E61000000100000005000000EB6F09C03F334640DFDDCA129D054940EB6F09C03F334640A585CB2A6C0A49408FA850DD5C364640A585CB2A6C0A49408FA850DD5C364640DFDDCA129D054940EB6F09C03F334640DFDDCA129D054940
27854	Шелестово	2	22	1226	44.039574000000002	44.071339000000002	47.998522000000001	47.972596000000003	0103000020E61000000100000005000000CEE2C5C210054640371C96067EFC4740CEE2C5C210054640132BA391CFFF4740F5F6E7A221094640132BA391CFFF4740F5F6E7A221094640371C96067EFC4740CEE2C5C210054640371C96067EFC4740
51688	Шебалино	2	22	1226	43.334989999999998	43.380310000000001	48.284883999999998	48.262245999999998	0103000020E61000000100000005000000573ECBF3E0AA4540DFC0E44691214840573ECBF3E0AA4540AB93331477244840BF2B82FFADB04540AB93331477244840BF2B82FFADB04540DFC0E44691214840573ECBF3E0AA4540DFC0E44691214840
12440	Советский	2	22	1226	43.502364	43.522765	48.102654999999999	48.08719	0103000020E610000001000000050000000858AB764DC04540E544BB0A290B48400858AB764DC04540ACE28DCC230D4840293FA9F6E9C24540ACE28DCC230D4840293FA9F6E9C24540E544BB0A290B48400858AB764DC04540E544BB0A290B4840
26961	Самохино	2	22	1226	43.735477000000003	43.761878000000003	47.840803000000001	47.815837999999999	0103000020E61000000100000005000000E8FA3E1C24DE4540C26A2C616DE84740E8FA3E1C24DE454079B0C56E9FEB47405DC5E23785E1454079B0C56E9FEB47405DC5E23785E14540C26A2C616DE84740E8FA3E1C24DE4540C26A2C616DE84740
27590	Перегрузное	2	22	1226	43.965733	43.997911000000002	47.911085	47.885924000000003	0103000020E6100000010000000500000080D591239DFB4540EA5E27F565F1474080D591239DFB45402670EB6E9EF44740CAA8328CBBFF45402670EB6E9EF44740CAA8328CBBFF4540EA5E27F565F1474080D591239DFB4540EA5E27F565F14740
27400	Октябрьский	2	22	1226	43.629475999999997	43.680858999999998	47.979249000000003	47.95478	0103000020E61000000100000005000000F6CE68AB92D04540FC6F253B36FA4740F6CE68AB92D0454003D2FE0758FD4740F817416326D7454003D2FE0758FD4740F817416326D74540FC6F253B36FA4740F6CE68AB92D04540FC6F253B36FA4740
51425	Октябрьский	2	22	1226	43.629475999999997	43.680858999999998	47.979249000000003	47.95478	0103000020E61000000100000005000000F6CE68AB92D04540FC6F253B36FA4740F6CE68AB92D0454003D2FE0758FD4740F817416326D7454003D2FE0758FD4740F817416326D74540FC6F253B36FA4740F6CE68AB92D04540FC6F253B36FA4740
51682	Новоаксайский	2	22	1226	43.247188000000001	43.286372999999998	48.016733000000002	47.997943999999997	0103000020E6100000010000000500000059FB3BDBA39F4540A59E05A1BCFF474059FB3BDBA39F4540CAE1934E240248408CBAD6DEA7A44540CAE1934E240248408CBAD6DEA7A44540A59E05A1BCFF474059FB3BDBA39F4540A59E05A1BCFF4740
51640	Нижнекумский	2	22	1226	43.476725999999999	43.493219000000003	48.222073000000002	48.210563999999998	0103000020E610000001000000050000009293895B05BD454083DBDAC2F31A48409293895B05BD45408D2958E36C1C48400762D9CC21BF45408D2958E36C1C48400762D9CC21BF454083DBDAC2F31A48409293895B05BD454083DBDAC2F31A4840
27100	Молокановский	2	22	1226	43.122492999999999	43.142282999999999	48.204745000000003	48.192506000000002	0103000020E61000000100000005000000957EC2D9AD8F454053245F09A4184840957EC2D9AD8F454080828B15351A48406DE34F543692454080828B15351A48406DE34F543692454053245F09A4184840957EC2D9AD8F454053245F09A4184840
27316	Ковалевка	2	22	1226	43.796185000000001	43.828460999999997	47.950670000000002	47.929440999999997	0103000020E610000001000000050000006B48DC63E9E54540E04735ECF7F647406B48DC63E9E54540E8A4F78DAFF94740778192020BEA4540E8A4F78DAFF94740778192020BEA4540E04735ECF7F647406B48DC63E9E54540E04735ECF7F64740
27268	Каменка	2	22	1226	43.798512000000002	43.819451000000001	47.996417999999998	47.976444999999998	0103000020E6100000010000000500000056BB26A435E64540DEAB5626FCFC474056BB26A435E64540A79201A08AFF474056D636C5E3E84540A79201A08AFF474056D636C5E3E84540DEAB5626FCFC474056BB26A435E64540DEAB5626FCFC4740
51657	Ильмень-Суворовский	2	22	1226	43.126069000000001	43.145372999999999	48.233356999999998	48.221136000000001	0103000020E610000001000000050000000C056C0723904540F0FB372F4E1C48400C056C072390454076A565A4DE1D4840575C1C959B92454076A565A4DE1D4840575C1C959B924540F0FB372F4E1C48400C056C0723904540F0FB372F4E1C4840
26841	Ивановка	2	22	1226	43.681047999999997	43.707566	48.197161000000001	48.17595	0103000020E61000000100000005000000CB80B3942CD7454098DD938785164840CB80B3942CD74540F98557923C1948407AE1CE8591DA4540F98557923C1948407AE1CE8591DA454098DD938785164840CB80B3942CD7454098DD938785164840
51372	Заливский	2	22	1226	43.445743	43.480561999999999	47.985612000000003	47.969791000000001	0103000020E61000000100000005000000E1B54B1B0EB94540427A8A1C22FC4740E1B54B1B0EB94540C845B58828FE4740A5D93C0E83BD4540C845B58828FE4740A5D93C0E83BD4540427A8A1C22FC4740E1B54B1B0EB94540427A8A1C22FC4740
26925	Жутово 2-е	2	22	1226	43.748573999999998	43.778551	47.958044000000001	47.945601000000003	0103000020E610000001000000050000006551D845D1DF45404F081D7409F947406551D845D1DF45408410902FA1FA474051A2258FA7E345408410902FA1FA474051A2258FA7E345404F081D7409F947406551D845D1DF45404F081D7409F94740
27197	Жутово 1-е	2	22	1226	43.748573999999998	43.778551	47.958044000000001	47.945601000000003	0103000020E610000001000000050000006551D845D1DF45404F081D7409F947406551D845D1DF45408410902FA1FA474051A2258FA7E345408410902FA1FA474051A2258FA7E345404F081D7409F947406551D845D1DF45404F081D7409F94740
26823	Громославка	2	22	1226	43.597045999999999	43.643867	48.206780999999999	48.190398000000002	0103000020E61000000100000005000000931ADA006CCC4540A69C2FF65E184840931ADA006CCC45409337C0CC771A4840A0FCDD3B6AD245409337C0CC771A4840A0FCDD3B6AD24540A69C2FF65E184840931ADA006CCC4540A69C2FF65E184840
51693	Гончаровское	2	22	1226	44.064413000000002	44.085540999999999	48.019578000000003	48.008566000000002	0103000020E61000000100000005000000F83768AF3E084640C4EDD0B018014840F83768AF3E0846404DDC2A8881024840CBBBEA01F30A46404DDC2A8881024840CBBBEA01F30A4640C4EDD0B018014840F83768AF3E084640C4EDD0B018014840
51615	Водянский	2	22	1226	43.390281000000002	43.423248999999998	47.987541999999998	47.967776000000001	0103000020E6100000010000000500000006A051BAF4B1454046ED7E15E0FB474006A051BAF4B1454095B6B8C667FE47404888F2052DB6454095B6B8C667FE47404888F2052DB6454046ED7E15E0FB474006A051BAF4B1454046ED7E15E0FB4740
27952	Водино	2	22	1226	43.964537999999997	43.991227000000002	48.026682999999998	48.011538000000002	0103000020E61000000100000005000000E7DF2EFB75FB4540A454C2137A014840E7DF2EFB75FB4540F92D3A596A034840C3F4BD86E0FE4540F92D3A596A034840C3F4BD86E0FE4540A454C2137A014840E7DF2EFB75FB4540A454C2137A014840
51649	Верхнерубежный	2	22	1226	43.155605000000001	43.165595000000003	48.273173999999997	48.251598000000001	0103000020E610000001000000050000000B0C59DDEA93454098DEFE5C342048400B0C59DDEA9345400A0F9A5DF7224840C9B08A37329545400A0F9A5DF7224840C9B08A373295454098DEFE5C342048400B0C59DDEA93454098DEFE5C34204840
51381	Верхнекумский	2	22	1226	43.431719999999999	43.452660000000002	48.097600999999997	48.084114	0103000020E61000000100000005000000BA83D89942B7454060915F3FC40A4840BA83D89942B74540488787307E0C48408B1A4CC3F0B94540488787307E0C48408B1A4CC3F0B9454060915F3FC40A4840BA83D89942B7454060915F3FC40A4840
26757	Васильевка	2	22	1226	43.805168000000002	43.829324	48.141703	48.130867000000002	0103000020E6100000010000000500000093E4B9BE0FE745401590F63FC010484093E4B9BE0FE745405F5FEB5223124840DAE4F04927EA45405F5FEB5223124840DAE4F04927EA45401590F63FC010484093E4B9BE0FE745401590F63FC0104840
51480	Антонов	2	22	1226	43.580202999999997	43.654161000000002	47.994723999999998	47.965085000000002	0103000020E610000001000000050000004205871744CA45401A6EC0E787FB47404205871744CA4540ED45B41D53FF4740CAA8328CBBD34540ED45B41D53FF4740CAA8328CBBD345401A6EC0E787FB47404205871744CA45401A6EC0E787FB4740
26676	Аксай	2	22	1226	43.925848000000002	44.009974999999997	47.976390000000002	47.938254999999998	0103000020E610000001000000050000009488F02F82F645407C2766BD18F847409488F02F82F645401B12F758FAFC474088635DDC460146401B12F758FAFC474088635DDC460146407C2766BD18F847409488F02F82F645407C2766BD18F84740
51367	Абганерово	2	22	1226	44.165275999999999	44.207504999999998	48.103605999999999	48.055911999999999	0103000020E61000000100000005000000276893C3271546401BBAD91F28074840276893C327154640AED51EF6420D4840D4601A868F1A4640AED51EF6420D4840D4601A868F1A46401BBAD91F28074840276893C3271546401BBAD91F28074840
26485	Хоперский	2	22	1775	42.777737999999999	42.805990000000001	51.017333000000001	50.993619000000002	0103000020E61000000100000005000000A06D35EB8C63454095D74AE82E7F4940A06D35EB8C6345401F12BEF737824940977329AE2A6745401F12BEF737824940977329AE2A67454095D74AE82E7F4940A06D35EB8C63454095D74AE82E7F4940
51606	Фоминский	2	22	1775	42.282263	42.304864999999999	51.045808000000001	51.023921999999999	0103000020E6100000010000000500000078EFA83121244540D4D347E00F83494078EFA8312124454095F25A09DD854940F758FAD00527454095F25A09DD854940F758FAD005274540D4D347E00F83494078EFA83121244540D4D347E00F834940
26388	Серп и Молот	2	22	1775	42.475104000000002	42.505772999999998	50.862726000000002	50.842955000000003	0103000020E6100000010000000500000072193735D03C4540F67F0EF3E56B494072193735D03C454057B439CE6D6E494093196F2BBD40454057B439CE6D6E494093196F2BBD404540F67F0EF3E56B494072193735D03C4540F67F0EF3E56B4940
51386	Орловский	2	22	1775	42.370702000000001	42.393214	51.036859999999997	51.010731	0103000020E61000000100000005000000E947C329732F4540D50627A25F814940E947C329732F4540E94317D4B7844940282A1BD654324540E94317D4B7844940282A1BD654324540D50627A25F814940E947C329732F4540D50627A25F814940
25387	Новониколаевский	2	22	1775	42.325642999999999	42.403841	50.996521999999999	50.947591000000003	0103000020E61000000100000005000000EE9579ABAE294540F27D71A94A794940EE9579ABAE2945404CDF6B088E7F494058E4D70FB13345404CDF6B088E7F494058E4D70FB1334540F27D71A94A794940EE9579ABAE294540F27D71A94A794940
51538	Новониколаевский	2	22	1775	42.325642999999999	42.403841	50.996521999999999	50.947591000000003	0103000020E61000000100000005000000EE9579ABAE294540F27D71A94A794940EE9579ABAE2945404CDF6B088E7F494058E4D70FB13345404CDF6B088E7F494058E4D70FB1334540F27D71A94A794940EE9579ABAE294540F27D71A94A794940
51276	Новокардаильский	2	22	1775	42.623632000000001	42.652962000000002	50.987734000000003	50.967613	0103000020E610000001000000050000009A5E622CD34F45409C1727BEDA7B49409A5E622CD34F4540DA9255116E7E4940F0C3414294534540DA9255116E7E4940F0C34142945345409C1727BEDA7B49409A5E622CD34F45409C1727BEDA7B4940
51292	Николаевский	2	22	1775	42.667127999999998	42.686289000000002	51.154460999999998	51.134706999999999	0103000020E61000000100000005000000791F47736455454069C537143E914940791F477364554540F4C0C760C5934940624D6551D8574540F4C0C760C5934940624D6551D857454069C537143E914940791F47736455454069C537143E914940
51680	Нижнекардаильский	2	22	1775	42.727935000000002	42.746647000000003	50.890723000000001	50.871492000000003	0103000020E61000000100000005000000904E5DF92C5D4540E25CC30C8D6F4940904E5DF92C5D4540C3651536037249400954FF20925F4540C3651536037249400954FF20925F4540E25CC30C8D6F4940904E5DF92C5D4540E25CC30C8D6F4940
26276	Мирный	2	22	1775	42.802836999999997	42.834853000000003	51.190530000000003	51.177584000000003	0103000020E610000001000000050000006682E15CC36645407D259012BB9649406682E15CC366454015747B4963984940D7FB8D76DC6A454015747B4963984940D7FB8D76DC6A45407D259012BB9649406682E15CC36645407D259012BB964940
26350	Купава	2	22	1775	42.894339000000002	42.928879000000002	51.117279000000003	51.105738000000002	0103000020E61000000100000005000000C8444AB379724540E4F8A1D2888D4940C8444AB379724540F9C08EFF028F49407978CF81E5764540F9C08EFF028F49407978CF81E5764540E4F8A1D2888D4940C8444AB379724540E4F8A1D2888D4940
51700	Куликовский	2	22	1775	42.522517999999998	42.569023000000001	50.850313999999997	50.826241000000003	0103000020E6100000010000000500000021C9ACDEE1424540A3CEDC43C269494021C9ACDEE14245405CAAD216D76C4940FED5E3BED54845405CAAD216D76C4940FED5E3BED5484540A3CEDC43C269494021C9ACDEE1424540A3CEDC43C2694940
26180	Красноармейский	2	22	1775	42.895263999999997	42.926876	51.052773000000002	51.034571999999997	0103000020E61000000100000005000000A0A4C00298724540BCADF4DA6C844940A0A4C00298724540508E0244C186494041B96DDFA3764540508E0244C186494041B96DDFA3764540BCADF4DA6C844940A0A4C00298724540BCADF4DA6C844940
26101	Комсомольский	2	22	1775	42.465617999999999	42.491247000000001	50.985647999999998	50.975043999999997	0103000020E61000000100000005000000E736E15E993B45409C14E63DCE7C4940E736E15E993B454014AFB2B6297E49400AA1832EE13E454014AFB2B6297E49400AA1832EE13E45409C14E63DCE7C4940E736E15E993B45409C14E63DCE7C4940
51631	Киквидзе	2	22	1775	42.751561000000002	42.783082999999998	50.902346999999999	50.873572000000003	0103000020E610000001000000050000007BF99D2633604540C5591135D16F49407BF99D26336045406552431B80734940DB8651103C6445406552431B80734940DB8651103C644540C5591135D16F49407BF99D2633604540C5591135D16F4940
51582	Каменка	2	22	1775	42.352556	42.370953999999998	50.845753000000002	50.831549000000003	0103000020E610000001000000050000001901158E202D4540C1029832706A49401901158E202D454038BF61A2416C49400229B16B7B2F454038BF61A2416C49400229B16B7B2F4540C1029832706A49401901158E202D4540C1029832706A4940
51365	Дуплятский	2	22	1775	42.322139	42.380692000000003	51.126233999999997	51.074860000000001	0103000020E6100000010000000500000011E2CAD93B294540A8E331039589494011E2CAD93B29454056D28A6F28904940A7ECF483BA30454056D28A6F28904940A7ECF483BA304540A8E331039589494011E2CAD93B294540A8E3310395894940
51535	Двойновский	2	22	1775	42.428787	42.484940999999999	51.056629000000001	51.023197000000003	0103000020E6100000010000000500000098F90E7EE2364540C32E8A1EF882494098F90E7EE2364540AA807B9E3F874940A9BEF38B123E4540AA807B9E3F874940A9BEF38B123E4540C32E8A1EF882494098F90E7EE2364540C32E8A1EF8824940
51395	Грачи	2	22	1775	42.263415999999999	42.297713999999999	50.909610999999998	50.886938999999998	0103000020E610000001000000050000001F9F909DB721454002469737877149401F9F909DB72145407A8A1C226E744940DAC70A7E1B2645407A8A1C226E744940DAC70A7E1B26454002469737877149401F9F909DB72145400246973787714940
51555	Верхнекардаильский	2	22	1775	42.647562999999998	42.691248000000002	51.094816000000002	51.071640000000002	0103000020E61000000100000005000000C18C2958E3524540F08AE07F2B894940C18C2958E35245409B9141EE228C494074B680D07A5845409B9141EE228C494074B680D07A584540F08AE07F2B894940C18C2958E3524540F08AE07F2B894940
51388	Алексиковский	2	22	1775	42.278525999999999	42.349294999999998	50.954259	50.930978000000003	0103000020E61000000100000005000000F88A6EBDA6234540D3A57F492A774940F88A6EBDA6234540F374AE28257A494002D4D4B2B52C4540F374AE28257A494002D4D4B2B52C4540D3A57F492A774940F88A6EBDA6234540D3A57F492A774940
51577	Ярыженский	2	22	1723	42.456041999999997	42.490716999999997	50.531255000000002	50.509332000000001	0103000020E610000001000000050000001CCD91955F3A454034677DCA314149401CCD91955F3A4540126BF12900444940AD4B8DD0CF3E4540126BF12900444940AD4B8DD0CF3E454034677DCA314149401CCD91955F3A454034677DCA31414940
51324	Черкесовский	2	22	1723	42.540277000000003	42.582147999999997	50.698087000000001	50.673501999999999	0103000020E61000000100000005000000F8E3F6CB2745454032E5435035564940F8E3F6CB27454540A26131EA5A59494045B75ED3834A4540A26131EA5A59494045B75ED3834A454032E5435035564940F8E3F6CB2745454032E5435035564940
51482	Челышевский	2	22	1723	42.789909999999999	42.835715	50.838290000000001	50.813209999999998	0103000020E61000000100000005000000456458C51B654540DC63E94317684940456458C51B6545402C4833164D6B494069E388B5F86A45402C4833164D6B494069E388B5F86A4540DC63E94317684940456458C51B654540DC63E94317684940
25180	Филоновская	2	22	1723	42.720137999999999	42.743054000000001	50.588957999999998	50.570625999999997	0103000020E61000000100000005000000AD4D637B2D5C4540A71FD4450A494940AD4D637B2D5C4540D95BCAF9624B4940BC94BA641C5F4540D95BCAF9624B4940BC94BA641C5F4540A71FD4450A494940AD4D637B2D5C4540A71FD4450A494940
51583	Тростянский	2	22	1723	43.210672000000002	43.234343000000003	50.478388000000002	50.464708999999999	0103000020E610000001000000050000006A17D34CF79A45401494A2957B3B49406A17D34CF79A4540416667D13B3D4940F58590F3FE9D4540416667D13B3D4940F58590F3FE9D45401494A2957B3B49406A17D34CF79A45401494A2957B3B4940
51364	Троецкий	2	22	1723	42.859116	42.886713	50.368281000000003	50.356380999999999	0103000020E6100000010000000500000034BC5983F76D454038F581E49D2D494034BC5983F76D45407D5EF1D4232F494012F8C3CF7F7145407D5EF1D4232F494012F8C3CF7F71454038F581E49D2D494034BC5983F76D454038F581E49D2D4940
51574	Страховский	2	22	1723	43.016311999999999	43.033344999999997	50.472306000000003	50.457977	0103000020E610000001000000050000002444F98216824540FCA886FD9E3A49402444F9821682454030DAE385743C4940183E22A64484454030DAE385743C4940183E22A644844540FCA886FD9E3A49402444F98216824540FCA886FD9E3A4940
24922	Староаннинская	2	22	1723	42.527358999999997	42.564261999999999	50.506284000000001	50.482922000000002	0103000020E610000001000000050000002920ED7F804345406C425A63D03D49402920ED7F80434540793E03EACD4049401230BABC39484540793E03EACD4049401230BABC394845406C425A63D03D49402920ED7F804345406C425A63D03D4940
51396	Соломатин	2	22	1723	42.815871000000001	42.861865000000002	50.643293999999997	50.622703999999999	0103000020E610000001000000050000009E60FF756E684540508BC1C3B44F49409E60FF756E68454044DB3175575249409548A297516E454044DB3175575249409548A297516E4540508BC1C3B44F49409E60FF756E684540508BC1C3B44F4940
51354	Сатаровский	2	22	1723	42.584232	42.606949999999998	50.288786999999999	50.272612000000002	0103000020E610000001000000050000006AA33A1DC84A4540A33F34F3E42249406AA33A1DC84A45404641F0F8F62449405227A089B04D45404641F0F8F62449405227A089B04D4540A33F34F3E42249406AA33A1DC84A4540A33F34F3E4224940
51286	Рожновский	2	22	1723	42.812063000000002	42.834466999999997	50.624709000000003	50.601697999999999	0103000020E6100000010000000500000055A52DAEF1674540C808A870044D494055A52DAEF16745402942EA76F64F4940AD4B8DD0CF6A45402942EA76F64F4940AD4B8DD0CF6A4540C808A870044D494055A52DAEF1674540C808A870044D4940
51487	Родниковский	2	22	1723	42.586216999999998	42.612448000000001	50.496732999999999	50.471578000000001	0103000020E61000000100000005000000FBAD9D28094B4540ADC1FBAA5C3C4940FBAD9D28094B454007EC6AF2943F4940144031B2644E454007EC6AF2943F4940144031B2644E4540ADC1FBAA5C3C4940FBAD9D28094B4540ADC1FBAA5C3C4940
51401	Рог-Измайловский	2	22	1723	42.731743999999999	42.771979999999999	50.671937	50.643380000000001	0103000020E61000000100000005000000A98592C9A95D454043739D465A524940A98592C9A95D454076FC17080256494042959A3DD062454076FC17080256494042959A3DD062454043739D465A524940A98592C9A95D454043739D465A524940
51283	Поповский	2	22	1723	42.405090000000001	42.436718999999997	50.611736000000001	50.594132999999999	0103000020E61000000100000005000000E4F736FDD9334540B83CD68C0C4C4940E4F736FDD933454097E4805D4D4E49405A457F68E637454097E4805D4D4E49405A457F68E6374540B83CD68C0C4C4940E4F736FDD9334540B83CD68C0C4C4940
51586	Полтавский	2	22	1723	43.060662000000001	43.078879999999998	50.378478999999999	50.368034000000002	0103000020E61000000100000005000000130EBDC5C387454075E8F4BC1B2F4940130EBDC5C3874540849CF7FF713049407C2766BD188A4540849CF7FF713049407C2766BD188A454075E8F4BC1B2F4940130EBDC5C387454075E8F4BC1B2F4940
24905	Полевой	2	22	1723	42.624611000000002	42.655853999999998	50.740082000000001	50.721741000000002	0103000020E6100000010000000500000066DCD440F34F454057975302625C494066DCD440F34F4540DC2DC901BB5E4940B3791C06F3534540DC2DC901BB5E4940B3791C06F353454057975302625C494066DCD440F34F454057975302625C4940
24748	Панфилово	2	22	1723	42.845435000000002	42.911811	50.419263000000001	50.392671	0103000020E6100000010000000500000067F2CD36376C4540378B170B4332494067F2CD36376C454020B6F468AA35494008910C39B674454020B6F468AA35494008910C39B6744540378B170B4332494067F2CD36376C4540378B170B43324940
24831	Новосельский	2	22	1723	42.979050000000001	42.996118000000003	50.379168	50.363168000000002	0103000020E610000001000000050000000C93A982517D4540147AFD497C2E49400C93A982517D454049D8B793883049407D7A6CCB807F454049D8B793883049407D7A6CCB807F4540147AFD497C2E49400C93A982517D4540147AFD497C2E4940
51514	Новокиевка	2	22	1723	43.115845999999998	43.145679000000001	50.434263999999999	50.416657999999998	0103000020E61000000100000005000000ABAFAE0AD48E4540F2CEA10C55354940ABAFAE0AD48E454042EA76F695374940645B069CA592454042EA76F695374940645B069CA5924540F2CEA10C55354940ABAFAE0AD48E4540F2CEA10C55354940
51269	Новоаннинский	2	22	1723	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
51584	Мартыновский	2	22	1723	42.272049000000003	42.310352999999999	50.513227000000001	50.474105999999999	0103000020E610000001000000050000006BF46A80D22245402F6B6281AF3C49406BF46A80D22245404C361E6CB1414940959BA8A5B92745404C361E6CB1414940959BA8A5B92745402F6B6281AF3C49406BF46A80D22245402F6B6281AF3C4940
51402	Кузнецовский	2	22	1723	42.675922999999997	42.716742000000004	50.441091	50.423802999999999	0103000020E610000001000000050000009ECE15A5845645402D793C2D3F3649409ECE15A584564540ACC77DAB75384940B7D5AC33BE5B4540ACC77DAB75384940B7D5AC33BE5B45402D793C2D3F3649409ECE15A5845645402D793C2D3F364940
51352	Краснокоротковский	2	22	1723	42.635849	42.678178000000003	50.626458	50.600005000000003	0103000020E61000000100000005000000DF18028063514540DF37BEF6CC4C4940DF18028063514540A62897C62F504940F06E6589CE564540A62897C62F504940F06E6589CE564540DF37BEF6CC4C4940DF18028063514540DF37BEF6CC4C4940
51345	Красногорский	2	22	1723	42.811819999999997	42.828339999999997	50.431682000000002	50.414757999999999	0103000020E610000001000000050000008E1EBFB7E96745408FE046CA163549408E1EBFB7E9674540CD22145B41374940FCFB8C0B076A4540CD22145B41374940FCFB8C0B076A45408FE046CA163549408E1EBFB7E96745408FE046CA16354940
51387	Дурновский	2	22	1723	42.375031999999997	42.429344	50.480905	50.458241000000001	0103000020E610000001000000050000000B7A6F0C01304540DA571EA4A73A49400B7A6F0C01304540CFBD874B8E3D4940EE5D83BEF4364540CFBD874B8E3D4940EE5D83BEF4364540DA571EA4A73A49400B7A6F0C01304540DA571EA4A73A4940
51358	Деминский	2	22	1723	42.271087999999999	42.302169999999997	50.582782000000002	50.565173999999999	0103000020E61000000100000005000000452BF702B32245405646239F57484940452BF702B32245404759BF99984A494089EAAD81AD2645404759BF99984A494089EAAD81AD2645405646239F57484940452BF702B32245405646239F57484940
51277	Галушкинский	2	22	1723	42.828707999999999	42.862439999999999	50.765025000000001	50.730659000000003	0103000020E610000001000000050000007FF78E1A136A454098C3EE3B865D49407FF78E1A136A4540ABCFD556EC6149409161156F646E4540ABCFD556EC6149409161156F646E454098C3EE3B865D49407FF78E1A136A454098C3EE3B865D4940
51481	Бочаровский	2	22	1723	42.630208000000003	42.675167999999999	50.394945	50.371924	0103000020E61000000100000005000000BBD6DEA7AA5045407B4CA4349B2F4940BBD6DEA7AA504540FF5BC98E8D32494022A7AFE76B564540FF5BC98E8D32494022A7AFE76B5645407B4CA4349B2F4940BBD6DEA7AA5045407B4CA4349B2F4940
51405	Борисовский	2	22	1723	42.463425999999998	42.506518999999997	50.471049999999998	50.462609999999998	0103000020E61000000100000005000000DC0E0D8B513B4540BA66F2CD363B4940DC0E0D8B513B4540F163CC5D4B3C4940BCE6559DD5404540F163CC5D4B3C4940BCE6559DD5404540BA66F2CD363B4940DC0E0D8B513B4540BA66F2CD363B4940
51409	Большой Головский	2	22	1723	42.168258000000002	42.208350000000003	50.602704000000003	50.589689999999997	0103000020E610000001000000050000002BA5677A891545409D6340F67A4B49402BA5677A891545408E959867254D4940910F7A36AB1A45408E959867254D4940910F7A36AB1A45409D6340F67A4B49402BA5677A891545409D6340F67A4B4940
24001	Березовка 2-я	2	22	1723	42.546259999999997	42.570236000000001	50.561638000000002	50.535217000000003	0103000020E61000000100000005000000758E01D9EB454540B2A19BFD81444940758E01D9EB4545406E1805C1E34749403D80457EFD4845406E1805C1E34749403D80457EFD484540B2A19BFD81444940758E01D9EB454540B2A19BFD81444940
23928	Березовка 1-я	2	22	1723	42.606904999999998	42.635677999999999	50.554416000000003	50.541651999999999	0103000020E61000000100000005000000B2632310AF4D454010E84CDA54454940B2632310AF4D454088307E1AF7464940B2648EE55D51454088307E1AF7464940B2648EE55D51454010E84CDA54454940B2632310AF4D454010E84CDA54454940
23833	АМО	2	22	1723	42.915638000000001	42.941501000000002	50.429174000000003	50.416566000000003	0103000020E61000000100000005000000C87C40A0337545401250E10852354940C87C40A0337545409225732CEF3649405E13D21A837845409225732CEF3649405E13D21A837845401250E10852354940C87C40A0337545401250E10852354940
22580	Торгунский	2	22	1688	46.388759	46.421438999999999	50.165872999999998	50.148651999999998	0103000020E610000001000000050000004983DBDAC2314740143E5B07071349404983DBDAC23147400B2593533B154940252191B6F13547400B2593533B154940252191B6F1354740143E5B07071349404983DBDAC2314740143E5B0707134940
23253	Степновский	2	22	1688	45.802607999999999	45.858887000000003	49.950764999999997	49.935471999999997	0103000020E6100000010000000500000005C1E3DBBBE646406F29E78BBDF7484005C1E3DBBBE646403997E2AAB2F94840D3FA5B02F0ED46403997E2AAB2F94840D3FA5B02F0ED46406F29E78BBDF7484005C1E3DBBBE646406F29E78BBDF74840
23103	Солодушино	2	22	1688	45.409891999999999	45.443083999999999	49.968561999999999	49.950406000000001	0103000020E610000001000000050000002E724F5777B446400AF65FE7A6F948402E724F5777B44640FD12F1D6F9FB4840C0B0FCF9B6B84640FD12F1D6F9FB4840C0B0FCF9B6B846400AF65FE7A6F948402E724F5777B446400AF65FE7A6F94840
23189	Рулевой	2	22	1688	45.853910999999997	45.869272000000002	50.028360999999997	50.013961000000002	0103000020E61000000100000005000000EA58A5F44CED4640B1355B79C9014940EA58A5F44CED4640ADBD4F55A10349400DAA0D4E44EF4640ADBD4F55A10349400DAA0D4E44EF4640B1355B79C9014940EA58A5F44CED4640B1355B79C9014940
46832	Политотдельское	2	22	1688	45.699534999999997	45.731991000000001	50.210836999999998	50.193539000000001	0103000020E6100000010000000500000024B4E55C8AD9464012C0CDE2C518494024B4E55C8AD94640B4E4F1B4FC1A4940B1FB8EE1B1DD4640B4E4F1B4FC1A4940B1FB8EE1B1DD464012C0CDE2C518494024B4E55C8AD9464012C0CDE2C5184940
46732	Пионер	2	22	1688	45.667403	45.685001	50.069592	50.057709000000003	0103000020E610000001000000050000004B2025766DD54640AAD72D02630749404B2025766DD5464018080264E8084940185DDE1CAED7464018080264E8084940185DDE1CAED74640AAD72D02630749404B2025766DD54640AAD72D0263074940
23171	Очкуровка	2	22	1688	45.422404999999998	45.443326999999996	49.997686000000002	49.983125999999999	0103000020E610000001000000050000005C55F65D11B6464074ECA012D7FD48405C55F65D11B64640AAD6C22CB4FF484086376BF0BEB84640AAD6C22CB4FF484086376BF0BEB8464074ECA012D7FD48405C55F65D11B6464074ECA012D7FD4840
51355	Новый Быт	2	22	1688	45.894326	45.923791000000001	49.823726999999998	49.812747999999999	0103000020E6100000010000000500000033FB3C4679F24640D8F15F2008E8484033FB3C4679F2464085EAE6E26FE9484069AB92C83EF6464085EAE6E26FE9484069AB92C83EF64640D8F15F2008E8484033FB3C4679F24640D8F15F2008E84840
22351	Николаевск	2	22	1688	45.426546000000002	45.506101000000001	50.053423000000002	50.002510000000001	0103000020E61000000100000005000000AC1E300F99B64640DCF4673F52004940AC1E300F99B6464057ED9A90D606494088BCE5EAC7C0464057ED9A90D606494088BCE5EAC7C04640DCF4673F52004940AC1E300F99B64640DCF4673F52004940
46765	Ленинское	2	22	1688	45.531218000000003	45.559677000000001	50.051062999999999	50.033441000000003	0103000020E61000000100000005000000F58590F3FEC346403BAC70CB47044940F58590F3FEC3464090847D3B8906494065A9F57EA3C7464090847D3B8906494065A9F57EA3C746403BAC70CB47044940F58590F3FEC346403BAC70CB47044940
22761	Левчуновка	2	22	1688	45.695843000000004	45.725461000000003	50.129922999999998	50.110666000000002	0103000020E610000001000000050000004513286211D94640BB63B14D2A0E49404513286211D94640C5FF1D51A110494001C3F2E7DBDC4640C5FF1D51A110494001C3F2E7DBDC4640BB63B14D2A0E49404513286211D94640BB63B14D2A0E4940
23044	Кумысолечебница	2	22	1688	45.986483999999997	46.010649000000001	49.912610000000001	49.902794	0103000020E610000001000000050000007D03931B45FE46403483F8C08EF348407D03931B45FE464054008C67D0F44840185E49F25C01474054008C67D0F44840185E49F25C0147403483F8C08EF348407D03931B45FE46403483F8C08EF34840
22644	Красный Мелиоратор	2	22	1688	46.069183000000002	46.112248000000001	50.035223999999999	50.021208000000001	0103000020E61000000100000005000000373811FDDA084740F03499F1B6024940373811FDDA08474064045438820449404D8578245E0E474064045438820449404D8578245E0E4740F03499F1B6024940373811FDDA084740F03499F1B6024940
46781	Комсомолец	2	22	1688	45.632674000000002	45.649417999999997	49.965815999999997	49.952874999999999	0103000020E61000000100000005000000C7832D76FBD046408716D9CEF7F94840C7832D76FBD046400DFAD2DB9FFB484084B7072120D346400DFAD2DB9FFB484084B7072120D346408716D9CEF7F94840C7832D76FBD046408716D9CEF7F94840
22663	Бережновка	2	22	1688	45.882325000000002	45.918571999999998	50.271495000000002	50.246738000000001	0103000020E61000000100000005000000BBB88D06F0F0464019575C1C951F4940BBB88D06F0F0464086032159C0224940BA826DC493F5464086032159C0224940BA826DC493F5464019575C1C951F4940BBB88D06F0F0464019575C1C951F4940
21901	Хорошенский	2	22	1657	41.722378999999997	41.759695000000001	50.291417000000003	50.278253999999997	0103000020E61000000100000005000000992842EA76DC444097FDBAD39D234940992842EA76DC4440CD3FFA264D254940A5F78DAF3DE14440CD3FFA264D254940A5F78DAF3DE1444097FDBAD39D234940992842EA76DC444097FDBAD39D234940
51599	Упорниковский	2	22	1657	41.825263	41.878380999999997	50.251997000000003	50.218623999999998	0103000020E61000000100000005000000A7CCCD37A2E94440730F09DFFB1B4940A7CCCD37A2E9444056D80C7041204940C136E2C96EF0444056D80C7041204940C136E2C96EF04440730F09DFFB1B4940A7CCCD37A2E94440730F09DFFB1B4940
51601	Тушкановский	2	22	1657	41.805095999999999	41.832081000000002	50.536712000000001	50.523381999999998	0103000020E61000000100000005000000F911BF620DE7444054A86E2EFE424940F911BF620DE7444075AF93FAB2444940BE4F55A181EA444075AF93FAB2444940BE4F55A181EA444054A86E2EFE424940F911BF620DE7444054A86E2EFE424940
21950	Тишанская	2	22	1657	41.980590999999997	42.013190999999999	50.366230000000002	50.352770999999997	0103000020E610000001000000050000003FE0810184FD444015FDA199272D49403FE0810184FD44403468E89FE02E4940FFCC203EB00145403468E89FE02E4940FFCC203EB001454015FDA199272D49403FE0810184FD444015FDA199272D4940
22301	Солонка	2	22	1657	41.443936999999998	41.487037999999998	50.216728000000003	50.176824000000003	0103000020E61000000100000005000000FF3D78EDD2B84440EF92382BA2164940FF3D78EDD2B8444052103CBEBD1B494062F4DC4257BE444052103CBEBD1B494062F4DC4257BE4440EF92382BA2164940FF3D78EDD2B84440EF92382BA2164940
51318	Соколовский	2	22	1657	41.826053999999999	41.866146000000001	50.398471000000001	50.375008999999999	0103000020E61000000100000005000000705D3123BCE94440535A7F4B00304940705D3123BCE94440C4B3041901334940D6C743DFDDEE4440C4B3041901334940D6C743DFDDEE4440535A7F4B00304940705D3123BCE94440535A7F4B00304940
51431	Село Успенка	2	22	1657	41.439706000000001	42.558458999999999	50.892467000000003	49.684458999999997	0103000020E6100000010000000500000070ED444948B84440F7393E5A9CD7484070ED444948B844402FE1D05B3C7249401494A2957B4745402FE1D05B3C7249401494A2957B474540F7393E5A9CD7484070ED444948B84440F7393E5A9CD74840
51467	Роднички	2	22	1657	41.657575000000001	41.690596999999997	50.138387999999999	50.119522000000003	0103000020E6100000010000000500000067D5E76A2BD444408693347F4C0F494067D5E76A2BD444405514AFB2B61149409CDB847B65D844405514AFB2B61149409CDB847B65D844408693347F4C0F494067D5E76A2BD444408693347F4C0F4940
21466	Нижнедолговский	2	22	1657	41.655320000000003	41.699309999999997	50.543849999999999	50.513100999999999	0103000020E6100000010000000500000016359886E1D34440BF45274BAD41494016359886E1D34440FDF675E09C45494004E275FD82D94440FDF675E09C45494004E275FD82D94440BF45274BAD41494016359886E1D34440BF45274BAD414940
21130	Нехаевская	2	22	1657	41.719881999999998	41.780616999999999	50.428668999999999	50.394497000000001	0103000020E61000000100000005000000527DE71725DC444060AFB0E07E324940527DE71725DC44408EE733A0DE364940CFD90242EBE344408EE733A0DE364940CFD90242EBE3444060AFB0E07E324940527DE71725DC444060AFB0E07E324940
51526	Нехаевская	2	22	1657	41.719881999999998	41.780616999999999	50.428668999999999	50.394497000000001	0103000020E61000000100000005000000527DE71725DC444060AFB0E07E324940527DE71725DC44408EE733A0DE364940CFD90242EBE344408EE733A0DE364940CFD90242EBE3444060AFB0E07E324940527DE71725DC444060AFB0E07E324940
22047	Мазинский	2	22	1657	41.879610999999997	41.908465	50.375118000000001	50.348644999999998	0103000020E61000000100000005000000D619DF1797F04440FB743C66A02C4940D619DF1797F044400A12DBDD03304940C347C49448F444400A12DBDD03304940C347C49448F44440FB743C66A02C4940D619DF1797F04440FB743C66A02C4940
21409	Луковская	2	22	1657	41.831938000000001	41.881067000000002	50.591000000000001	50.559091000000002	0103000020E610000001000000050000005B26C3F17CEA4440753E3C4B904749405B26C3F17CEA4440CFF753E3A54B4940DC4AAFCDC6F04440CFF753E3A54B4940DC4AAFCDC6F04440753E3C4B904749405B26C3F17CEA4440753E3C4B90474940
51301	Лобачевский	2	22	1657	41.439706000000001	42.558458999999999	50.892467000000003	49.684458999999997	0103000020E6100000010000000500000070ED444948B84440F7393E5A9CD7484070ED444948B844402FE1D05B3C7249401494A2957B4745402FE1D05B3C7249401494A2957B474540F7393E5A9CD7484070ED444948B84440F7393E5A9CD74840
22280	Кулички	2	22	1657	41.744791999999997	41.789518999999999	50.127288999999998	50.111480999999998	0103000020E610000001000000050000004529215855DF44400C906802450E49404529215855DF4440FD1186014B1049400A4966F50EE54440FD1186014B1049400A4966F50EE544400C906802450E49404529215855DF44400C906802450E4940
51316	Кругловка	2	22	1657	41.559711999999998	41.603667000000002	50.148935000000002	50.104196000000002	0103000020E61000000100000005000000E1968FA4A4C74440E02F664B560D4940E1968FA4A4C74440691D554D101349405456D3F544CD4440691D554D101349405456D3F544CD4440E02F664B560D4940E1968FA4A4C74440E02F664B560D4940
46163	Краснополье	2	22	1657	41.439706000000001	41.476609000000003	50.507533000000002	50.485604000000002	0103000020E6100000010000000500000070ED444948B8444045679945283E494070ED444948B84440055262D7F640494059FD118601BD4440055262D7F640494059FD118601BD444045679945283E494070ED444948B8444045679945283E4940
51605	Захоперский	2	22	1657	41.901682999999998	41.930796999999998	50.504702999999999	50.480674999999998	0103000020E61000000100000005000000F92D3A596AF344409D8026C2863D4940F92D3A596AF34440B7989F1B9A404940821B295B24F74440B7989F1B9A404940821B295B24F744409D8026C2863D4940F92D3A596AF344409D8026C2863D4940
46267	Динамо	2	22	1657	41.638171	41.675351999999997	50.253822	50.234949999999998	0103000020E61000000100000005000000B8205B96AFD14440FC1873D7121E4940B8205B96AFD14440AE80423D7D204940E3A430EF71D64440AE80423D7D204940E3A430EF71D64440FC1873D7121E4940B8205B96AFD14440FC1873D7121E4940
51532	Денисовский	2	22	1657	41.901511999999997	41.947802000000003	50.207199000000003	50.182962000000003	0103000020E61000000100000005000000CC79C6BE64F3444094347F4C6B174940CC79C6BE64F34440C861307F851A4940AD8A709351F94440C861307F851A4940AD8A709351F9444094347F4C6B174940CC79C6BE64F3444094347F4C6B174940
21579	Верхнереченский	2	22	1657	41.590659000000002	41.616278999999999	50.489679000000002	50.461458	0103000020E61000000100000005000000460BD0B69ACB4440213D450E113B4940460BD0B69ACB4440DD442DCDAD3E4940151BF33AE2CE4440DD442DCDAD3E4940151BF33AE2CE4440213D450E113B4940460BD0B69ACB4440213D450E113B4940
21981	Артановский	2	22	1657	41.914358	41.953623	50.351770999999999	50.333508000000002	0103000020E61000000100000005000000016BD5AE09F54440297AE063B02A4940016BD5AE09F54440325706D5062D494051DB865110FA4440325706D5062D494051DB865110FA4440297AE063B02A4940016BD5AE09F54440297AE063B02A4940
51314	Авраамовский	2	22	1657	41.600620999999997	41.650658	50.406095000000001	50.388661999999997	0103000020E6100000010000000500000039252026E1CC4440569929ADBF31494039252026E1CC4440D908C4EBFA334940BD70E7C248D34440D908C4EBFA334940BD70E7C248D34440569929ADBF31494039252026E1CC4440569929ADBF314940
20429	Черемухов	2	22	1310	43.532097999999998	43.553038000000001	50.046909999999997	50.034146999999997	0103000020E610000001000000050000002D228AC91BC44540D520CCED5E0449402D228AC91BC445407CED992501064940FEB8FDF2C9C645407CED992501064940FEB8FDF2C9C64540D520CCED5E0449402D228AC91BC44540D520CCED5E044940
51710	Троицкий	2	22	1310	43.016222999999997	43.072017000000002	50.245787	50.225292000000003	0103000020E61000000100000005000000B4386398138245407506465ED61C4940B4386398138245401764CBF2751F4940C6E061DA378945401764CBF2751F4940C6E061DA378945407506465ED61C4940B4386398138245407506465ED61C4940
20414	Сухов 2-й	2	22	1310	43.453415	43.497477000000003	50.004303999999998	49.987226999999997	0103000020E610000001000000050000000742B28009BA4540355D4F745DFE48400742B28009BA4540F99E91088D00494090C18A53ADBF4540F99E91088D00494090C18A53ADBF4540355D4F745DFE48400742B28009BA4540355D4F745DFE4840
19496	Сухов 1-й	2	22	1310	43.399200999999998	43.435429999999997	49.924447999999998	49.906838	0103000020E61000000100000005000000E7C3B30419B345409162804413F44840E7C3B30419B34540226DE34F54F6484040D9942BBCB74540226DE34F54F6484040D9942BBCB745409162804413F44840E7C3B30419B345409162804413F44840
20544	Субботин	2	22	1310	43.602373	43.621696	50.154007999999997	50.133347000000001	0103000020E61000000100000005000000287FF78E1ACD45408602B68311114940287FF78E1ACD454043A9BD88B6134940EA060ABC93CF454043A9BD88B6134940EA060ABC93CF45408602B68311114940287FF78E1ACD45408602B68311114940
13835	Страховский	2	22	1310	42.976894000000001	42.998553000000001	50.312975999999999	50.294508	0103000020E610000001000000050000004ED4D2DC0A7D454087342A70B22549404ED4D2DC0A7D45406937FA980F2849404E29AF95D07F45406937FA980F2849404E29AF95D07F454087342A70B22549404ED4D2DC0A7D454087342A70B2254940
45373	Староселье	2	22	1310	43.205246000000002	43.269286999999998	50.017184999999998	49.945658000000002	0103000020E6100000010000000500000042D13C80459A4540B39943520BF9484042D13C80459A4540AA7D3A1E33024940751E15FF77A24540AA7D3A1E33024940751E15FF77A24540B39943520BF9484042D13C80459A4540B39943520BF94840
45801	Сидоры	2	22	1310	43.310195999999998	43.350673999999998	50.133792	50.106813000000002	0103000020E61000000100000005000000CDACA580B4A74540D2E4620CAC0D4940CDACA580B4A74540B43BA418201149405CC7B8E2E2AC4540B43BA418201149405CC7B8E2E2AC4540D2E4620CAC0D4940CDACA580B4A74540D2E4620CAC0D4940
20629	Сенной	2	22	1310	43.601205999999998	43.644100000000002	50.275727000000003	50.245344000000003	0103000020E6100000010000000500000059147651F4CC45408A22A46E671F494059147651F4CC4540E6CFB7054B23494043AD69DE71D24540E6CFB7054B23494043AD69DE71D245408A22A46E671F494059147651F4CC45408A22A46E671F4940
19919	Сеничкин	2	22	1310	42.878914999999999	42.909916000000003	50.052531999999999	50.034911000000001	0103000020E610000001000000050000005F7B664980704540A5A2B1F6770449405F7B6649807045402AFF5A5EB9064940B70DA320787445402AFF5A5EB9064940B70DA32078744540A5A2B1F6770449405F7B664980704540A5A2B1F677044940
20200	Секачи	2	22	1310	43.603110000000001	43.643408000000001	50.514459000000002	50.490189000000001	0103000020E61000000100000005000000FEF15EB532CD4540F2ED5D83BE3E4940FEF15EB532CD45400211E2CAD94149400DFE7E315BD245400211E2CAD94149400DFE7E315BD24540F2ED5D83BE3E4940FEF15EB532CD4540F2ED5D83BE3E4940
21103	Рогожин	2	22	1310	42.981915999999998	43.025897000000001	50.183238000000003	50.158268	0103000020E61000000100000005000000A6B5696CAF7D45406D00362042144940A6B5696CAF7D454036B1C057741749404208C8975083454036B1C057741749404208C897508345406D00362042144940A6B5696CAF7D45406D00362042144940
20864	Реконструкция	2	22	1310	43.059134999999998	43.084971000000003	50.27731	50.248080000000002	0103000020E61000000100000005000000448655BC918745405665DF15C11F4940448655BC91874540486DE2E47E234940E10D6954E08A4540486DE2E47E234940E10D6954E08A45405665DF15C11F4940448655BC918745405665DF15C11F4940
20524	Раздоры	2	22	1310	43.642015999999998	43.661914000000003	50.213661000000002	50.197830000000003	0103000020E610000001000000050000001EC18D942DD245407715527E521949401EC18D942DD2454020B75F3E591B4940DD611399B9D4454020B75F3E591B4940DD611399B9D445407715527E521949401EC18D942DD245407715527E52194940
20024	Плотников 2-й	2	22	1310	43.548340000000003	43.579853	50.415624999999999	50.396214000000001	0103000020E61000000100000005000000598B4F0130C64540D21BEE23B7324940598B4F0130C64540333333333335494066BE839F38CA4540333333333335494066BE839F38CA4540D21BEE23B7324940598B4F0130C64540D21BEE23B7324940
19936	Отруба	2	22	1310	43.106261000000003	43.131844999999998	50.059207000000001	50.031751999999997	0103000020E610000001000000050000008EEBDFF5998D454092CA1473100449408EEBDFF5998D4540DE585018940749401092054CE0904540DE585018940749401092054CE090454092CA1473100449408EEBDFF5998D454092CA147310044940
45661	Отрадное	2	22	1310	43.161543000000002	43.184756	50.024147999999997	50.007998000000001	0103000020E61000000100000005000000E9F2E670AD9445407A37161406014940E9F2E670AD944540C4211B4817034940B1DEA815A6974540C4211B4817034940B1DEA815A69745407A37161406014940E9F2E670AD9445407A37161406014940
45789	Орлы	2	22	1310	43.696705000000001	43.741801000000002	50.232610999999999	50.212277999999998	0103000020E61000000100000005000000D7FA22A12DD9454084D4EDEC2B1B4940D7FA22A12DD945404DD87E32C61D4940EF91CD55F3DE45404DD87E32C61D4940EF91CD55F3DE454084D4EDEC2B1B4940D7FA22A12DD9454084D4EDEC2B1B4940
19606	Моховский	2	22	1310	43.396676999999997	43.433616000000001	50.202218000000002	50.181888999999998	0103000020E61000000100000005000000A609DB4FC6B245404640852348174940A609DB4FC6B24540CE548847E2194940DC82A5BA80B74540CE548847E2194940DC82A5BA80B745404640852348174940A609DB4FC6B245404640852348174940
20084	Мишин	2	22	1310	43.522728999999998	43.542932	50.368718000000001	50.355231000000003	0103000020E61000000100000005000000DCD5ABC8E8C2454040C39B35782D4940DCD5ABC8E8C2454028B9C326322F4940D7F9B7CB7EC5454028B9C326322F4940D7F9B7CB7EC5454040C39B35782D4940DCD5ABC8E8C2454040C39B35782D4940
51439	Михайловка	2	22	1310	42.650294000000002	43.754798999999998	50.588797999999997	49.820798000000003	0103000020E610000001000000050000007C6473D53C534540A54FABE80FE948407C6473D53C534540A0F99CBB5D4B4940D906EE409DE04540A0F99CBB5D4B4940D906EE409DE04540A54FABE80FE948407C6473D53C534540A54FABE80FE94840
51643	Крутинский	2	22	1310	42.855361000000002	42.875906000000001	50.236316000000002	50.216757000000001	0103000020E610000001000000050000000EA320787C6D4540EC1681B1BE1B49400EA320787C6D4540C2C2499A3F1E4940622F14B01D704540C2C2499A3F1E4940622F14B01D704540EC1681B1BE1B49400EA320787C6D4540EC1681B1BE1B4940
19863	Катасонов	2	22	1310	42.999567999999996	43.011586999999999	50.095816999999997	50.085565000000003	0103000020E6100000010000000500000066101FD8F17F454054573ECBF30A494066101FD8F17F45404EB340BB430C49408507CDAE7B8145404EB340BB430C49408507CDAE7B81454054573ECBF30A494066101FD8F17F454054573ECBF30A4940
19762	Карагичевский	2	22	1310	42.876480999999998	42.913921999999999	50.170431999999998	50.150089000000001	0103000020E610000001000000050000005E48878730704540A33EC91D361349405E488787307045408F183DB7D0154940268C6665FB7445408F183DB7D0154940268C6665FB744540A33EC91D361349405E48878730704540A33EC91D36134940
19694	Ильменский 2-й	2	22	1310	43.548743999999999	43.564445999999997	50.238736000000003	50.223269999999999	0103000020E6100000010000000500000028F04E3E3DC64540C616821C941C494028F04E3E3DC645405E30B8E68E1E4940D32D3BC43FC845405E30B8E68E1E4940D32D3BC43FC84540C616821C941C494028F04E3E3DC64540C616821C941C4940
19269	Ильменский 1-й	2	22	1310	43.101913000000003	43.138762	49.981574000000002	49.937826000000001	0103000020E61000000100000005000000C504357C0B8D454054ABAFAE0AF84840C504357C0B8D45404D4D8237A4FD4840BAF605F4C29145404D4D8237A4FD4840BAF605F4C291454054ABAFAE0AF84840C504357C0B8D454054ABAFAE0AF84840
19660	Етеревская	2	22	1310	43.526870000000002	43.568883999999997	50.197736999999996	50.168978000000003	0103000020E610000001000000050000002C9FE57970C345402BDF3312A11549402C9FE57970C34540C51A2E724F194940DC9BDF30D1C84540C51A2E724F194940DC9BDF30D1C845402BDF3312A11549402C9FE57970C345402BDF3312A1154940
20842	Большой Орешкин	2	22	1310	43.377175000000001	43.393093	50.164257999999997	50.146988999999998	0103000020E6100000010000000500000035EF384547B0454095EF1989D012494035EF384547B045409D0DF96706154940ADA415DF50B245409D0DF96706154940ADA415DF50B2454095EF1989D012494035EF384547B0454095EF1989D0124940
51323	Большой	2	22	1310	43.421551000000001	43.471677	50.241069000000003	50.208871000000002	0103000020E610000001000000050000004D4C1762F5B545409A0AF148BC1A49404D4C1762F5B545402B8A5759DB1E494040A374E95FBC45402B8A5759DB1E494040A374E95FBC45409A0AF148BC1A49404D4C1762F5B545409A0AF148BC1A4940
20999	Большемедведевский	2	22	1310	43.145238999999997	43.174883000000001	50.238746999999996	50.221673000000003	0103000020E61000000100000005000000478D093197924540FFB3E6C75F1C4940478D0931979245405182FE428F1E49402DD0EE90629645405182FE428F1E49402DD0EE9062964540FFB3E6C75F1C4940478D093197924540FFB3E6C75F1C4940
51618	Безымянка	2	22	1310	43.225261000000003	43.315739000000001	49.918596000000001	49.895569999999999	0103000020E610000001000000050000003A083A5AD59C4540ADA3AA09A2F248403A083A5AD59C4540431EC18D94F548402F89B3226AA84540431EC18D94F548402F89B3226AA84540ADA3AA09A2F248403A083A5AD59C4540ADA3AA09A2F24840
19174	Арчединская	2	22	1310	43.089444	43.132959	49.909163999999997	49.882308000000002	0103000020E610000001000000050000006669A7E6728B4540E57FF277EFF048406669A7E6728B4540AB59677C5FF44840BC5AEECC04914540AB59677C5FF44840BC5AEECC04914540E57FF277EFF048406669A7E6728B4540E57FF277EFF04840
18539	Царев	2	22	1151	45.357644999999998	45.387416000000002	48.673648999999997	48.659112	0103000020E61000000100000005000000F949B54FC7AD4640593332C85D544840F949B54FC7AD4640D6FD63213A5648403CF9F4D896B14640D6FD63213A5648403CF9F4D896B14640593332C85D544840F949B54FC7AD4640593332C85D544840
19009	Тракторострой	2	22	1151	45.560960999999999	45.575729000000003	49.059430999999996	49.048278000000003	0103000020E610000001000000050000006DAAEE91CDC74640E38E37F92D8648406DAAEE91CDC746402DAF5C6F9B874840ED2DE57CB1C946402DAF5C6F9B874840ED2DE57CB1C94640E38E37F92D8648406DAAEE91CDC74640E38E37F92D864840
51295	Степной	2	22	1151	45.587263999999998	45.608293000000003	48.935687000000001	48.922783000000003	0103000020E610000001000000050000001F0F7D772BCB46400327DBC01D7648401F0F7D772BCB46406C257497C477484060B1868BDCCD46406C257497C477484060B1868BDCCD46400327DBC01D7648401F0F7D772BCB46400327DBC01D764840
51541	Степана Разина	2	22	1151	45.069465999999998	45.09196	48.513083999999999	48.498137	0103000020E610000001000000050000008B170B43E4884640BAF605F4C23F48408B170B43E4884640E90C8CBCAC41484024456458C58B4640E90C8CBCAC41484024456458C58B4640BAF605F4C23F48408B170B43E4884640BAF605F4C23F4840
49382	Солодовка	2	22	1151	45.366214999999997	45.416080999999998	48.686943999999997	48.667163000000002	0103000020E61000000100000005000000FE261422E0AE4640F60CE19865554840FE261422E0AE46407A17EFC7ED57484055BE672442B546407A17EFC7ED57484055BE672442B54640F60CE19865554840FE261422E0AE4640F60CE19865554840
49530	Рассвет	2	22	1151	45.460214999999998	45.479951	49.114297000000001	49.097392999999997	0103000020E6100000010000000500000077103B53E8BA4640FEEDB25F778C484077103B53E8BA4640F583BA48A18E48405C57CC086FBD4640F583BA48A18E48405C57CC086FBD4640FEEDB25F778C484077103B53E8BA4640FEEDB25F778C4840
30424	Путь Ильича	2	22	1151	45.545015999999997	45.576143000000002	48.977068000000003	48.963583	0103000020E61000000100000005000000FBE59315C3C54640A4FD0FB0567B4840FBE59315C3C54640ECFB7090107D4840E068C70DBFC94640ECFB7090107D4840E068C70DBFC94640A4FD0FB0567B4840FBE59315C3C54640A4FD0FB0567B4840
49425	Покровка	2	22	1151	45.015270999999998	45.060968000000003	48.489868000000001	48.471957000000003	0103000020E61000000100000005000000E2C96E66F4814640240F4416693C4840E2C96E66F4814640B0AD9FFEB33E4840200DA7CCCD874640B0AD9FFEB33E4840200DA7CCCD874640240F4416693C4840E2C96E66F4814640240F4416693C4840
49472	Новостройка	2	22	1151	45.312119000000003	45.331980999999999	48.678556999999998	48.673082999999998	0103000020E61000000100000005000000E9BAF083F3A746402D3F709527564840E9BAF083F3A7464066BCADF4DA5648405AF2785A7EAA464066BCADF4DA5648405AF2785A7EAA46402D3F709527564840E9BAF083F3A746402D3F709527564840
19113	Маяк Октября	2	22	1151	45.629835	45.661366000000001	49.241511000000003	49.227282000000002	0103000020E610000001000000050000002670EB6E9ED04640187C9A93179D48402670EB6E9ED04640E84F1BD5E99E4840DA571EA4A7D44640E84F1BD5E99E4840DA571EA4A7D44640187C9A93179D48402670EB6E9ED04640187C9A93179D4840
18454	Маляевка	2	22	1151	45.273778999999998	45.295274999999997	48.690809999999999	48.675367999999999	0103000020E6100000010000000500000071AAB5300BA34640E96168757256484071AAB5300BA34640F8DF4A766C584840C7293A92CBA54640F8DF4A766C584840C7293A92CBA54640E96168757256484071AAB5300BA34640E961687572564840
18786	Лещев	2	22	1151	44.937396	44.952317000000001	48.505056000000003	48.499127999999999	0103000020E610000001000000050000005BB39597FC7746404A42226DE33F48405BB39597FC7746400553CDACA540484061360186E57946400553CDACA540484061360186E57946404A42226DE33F48405BB39597FC7746404A42226DE33F4840
10821	Ленинск	2	22	1151	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
49342	Коммунар	2	22	1151	45.290128000000003	45.322035999999997	48.884135999999998	48.867621999999997	0103000020E61000000100000005000000B3D30FEA22A5464022A5D93C0E6F4840B3D30FEA22A54640AE9B525E2B7148403C11C47938A94640AE9B525E2B7148403C11C47938A9464022A5D93C0E6F4840B3D30FEA22A5464022A5D93C0E6F4840
18641	Колобовка	2	22	1151	45.439275000000002	45.472135999999999	48.664014999999999	48.647660999999999	0103000020E61000000100000005000000A779C7293AB8464084F23E8EE6524840A779C7293AB84640D7868A71FE544840D3A1D3F36EBC4640D7868A71FE544840D3A1D3F36EBC464084F23E8EE6524840A779C7293AB8464084F23E8EE6524840
18882	Каршевитое	2	22	1151	45.296182999999999	45.332681000000001	48.463175	48.450220999999999	0103000020E61000000100000005000000CA501553E9A54640787C7BD7A0394840CA501553E9A5464093A98251493B484013807F4A95AA464093A98251493B484013807F4A95AA4640787C7BD7A0394840CA501553E9A54640787C7BD7A0394840
49361	Заплавное	2	22	1151	44.984242999999999	45.045445000000001	48.718451000000002	48.691308999999997	0103000020E610000001000000050000009128B4ACFB7D4640193735D07C5848409128B4ACFB7D4640A663CE33F65B484024624A24D1854640A663CE33F65B484024624A24D1854640193735D07C5848409128B4ACFB7D4640193735D07C584840
18338	Бахтияровка	2	22	1151	45.122044000000002	45.148139999999998	48.718291000000001	48.708762	0103000020E61000000100000005000000265646239F8F4640E35295B6B85A4840265646239F8F46406D01A1F5F05B48405E9D6340F69246406D01A1F5F05B48405E9D6340F6924640E35295B6B85A4840265646239F8F4640E35295B6B85A4840
51407	Шакин	2	22	1624	42.167017999999999	42.225974999999998	49.871673000000001	49.834501000000003	0103000020E61000000100000005000000F2EB87D8601545405ABDC3EDD0EA4840F2EB87D86015454032E719FB92EF4840575BB1BFEC1C454032E719FB92EF4840575BB1BFEC1C45405ABDC3EDD0EA4840F2EB87D8601545405ABDC3EDD0EA4840
51581	Суляевский	2	22	1624	42.609878999999999	42.632210999999998	50.077750000000002	50.066249999999997	0103000020E6100000010000000500000033C2DB83104E454014AE47E17A08494033C2DB83104E4540CBA145B6F3094940F295404AEC504540CBA145B6F3094940F295404AEC50454014AE47E17A08494033C2DB83104E454014AE47E17A084940
51458	Слащевская	2	22	1624	42.307442999999999	42.352744999999999	49.867556	49.846167000000001	0103000020E610000001000000050000002B31CF4A5A2745402BFA43334FEC48402B31CF4A5A2745406BB933130CEF4840EC6987BF262D45406BB933130CEF4840EC6987BF262D45402BFA43334FEC48402B31CF4A5A2745402BFA43334FEC4840
51406	Попов	2	22	1624	42.051369000000001	42.143014999999998	49.982373000000003	49.966743000000001	0103000020E610000001000000050000009D836742930645408751103CBEFB48409D8367429306454099BC0166BEFD484031EBC5504E12454099BC0166BEFD484031EBC5504E1245408751103CBEFB48409D836742930645408751103CBEFB4840
20334	Поддубный	2	22	1624	42.529291000000001	42.535696000000002	49.887479999999996	49.884061000000003	0103000020E610000001000000050000009888B7CEBF434540A4552DE928F148409888B7CEBF43454052EDD3F198F148408C4CC0AF9144454052EDD3F198F148408C4CC0AF91444540A4552DE928F148409888B7CEBF434540A4552DE928F14840
51554	Кумылженская	2	22	1624	42.558791999999997	42.621377000000003	49.895558000000001	49.864275999999997	0103000020E610000001000000050000001AA20A7F86474540DD5B9198A0EE48401AA20A7F86474540E9D500A5A1F2484049BE1248894F4540E9D500A5A1F2484049BE1248894F4540DD5B9198A0EE48401AA20A7F86474540DD5B9198A0EE4840
51531	Краснянский	2	22	1624	42.626237000000003	42.659241000000002	49.709265000000002	49.696348	0103000020E61000000100000005000000C845B58828504540485167EE21D94840C845B5882850454046990D32C9DA4840579753026254454046990D32C9DA48405797530262544540485167EE21D94840C845B58828504540485167EE21D94840
51578	Глазуновская	2	22	1624	42.821404999999999	42.866024000000003	49.829684	49.797353000000001	0103000020E61000000100000005000000ACE28DCC236945400A2FC1A90FE64840ACE28DCC23694540DA01D71533EA48408BC6DADFD96E4540DA01D71533EA48408BC6DADFD96E45400A2FC1A90FE64840ACE28DCC236945400A2FC1A90FE64840
51376	Букановская	2	22	1624	42.295988999999999	42.336162000000002	49.689227000000002	49.667641000000003	0103000020E61000000100000005000000E57CB1F7E2254540003CA24275D54840E57CB1F7E22545409642209738D8484038143E5B072B45409642209738D8484038143E5B072B4540003CA24275D54840E57CB1F7E2254540003CA24275D54840
51454	Белогорский	2	22	1624	41.896355999999997	41.951107999999998	49.932653999999999	49.905549999999998	0103000020E6100000010000000500000064C91CCBBBF244404772F90FE9F3484064C91CCBBBF24440E63DCE3461F74840637B2DE8BDF94440E63DCE3461F74840637B2DE8BDF944404772F90FE9F3484064C91CCBBBF244404772F90FE9F34840
51558	Тарасово	2	22	1459	44.762548000000002	44.809627999999996	50.558169999999997	50.548898999999999	0103000020E61000000100000005000000ABD0402C9B6146404FE78A5242464940ABD0402C9B614640DDCD531D7247494083F6EAE3A1674640DDCD531D7247494083F6EAE3A16746404FE78A5242464940ABD0402C9B6146404FE78A5242464940
51418	Сосновка	2	22	1459	44.529452999999997	44.560265000000001	50.624972	50.612388000000003	0103000020E6100000010000000500000071E2AB1DC54346403F3BE0BA624E494071E2AB1DC543464036751E15FF4F4940F60B76C3B647464036751E15FF4F4940F60B76C3B64746403F3BE0BA624E494071E2AB1DC54346403F3BE0BA624E4940
49140	Смородино	2	22	1459	45.089292	45.122681999999998	50.356513	50.343097	0103000020E61000000100000005000000B0E595EB6D8B4640882D3D9AEA2B4940B0E595EB6D8B4640A7CCCD37A22D494068E7340BB48F4640A7CCCD37A22D494068E7340BB48F4640882D3D9AEA2B4940B0E595EB6D8B4640882D3D9AEA2B4940
17226	Слюсарево	2	22	1459	44.762672999999999	44.791688999999998	50.486246000000001	50.468963000000002	0103000020E610000001000000050000006745D4449F6146405C04C6FA063C49406745D4449F614640C9E7154F3D3E49402DCDAD1056654640C9E7154F3D3E49402DCDAD10566546405C04C6FA063C49406745D4449F6146405C04C6FA063C4940
51327	Романов	2	22	1459	44.566068000000001	44.620057000000003	50.121167999999997	50.098522000000003	0103000020E61000000100000005000000F4A78DEA74484640E0F76F5E9C0C4940F4A78DEA744846402EA9DA6E820F4940F4531C075E4F46402EA9DA6E820F4940F4531C075E4F4640E0F76F5E9C0C4940F4A78DEA74484640E0F76F5E9C0C4940
51560	Попки	2	22	1459	44.467621999999999	44.525302000000003	50.204259	50.170997	0103000020E61000000100000005000000EF71A609DB3B4640685BCD3AE3154940EF71A609DB3B4640F374AE28251A4940FF428F183D434640F374AE28251A4940FF428F183D434640685BCD3AE3154940EF71A609DB3B4640685BCD3AE3154940
17834	Племхоз	2	22	1459	44.826642	44.848686999999998	50.233625000000004	50.217044999999999	0103000020E6100000010000000500000001C0B167CF69464052616C21C81B494001C0B167CF69464096438B6CE71D49402AC58EC6A16C464096438B6CE71D49402AC58EC6A16C464052616C21C81B494001C0B167CF69464052616C21C81B4940
17489	Перещепное	2	22	1459	45.094807000000003	45.122314000000003	50.546534999999999	50.518915	0103000020E610000001000000050000004837C2A2228C4640B13385CE6B4249404837C2A2228C4640478FDFDBF4454940E6EB32FCA78F4640478FDFDBF4454940E6EB32FCA78F4640B13385CE6B4249404837C2A2228C4640B13385CE6B424940
49179	Новониколаевка	2	22	1459	45.092525999999999	45.111058	50.208801999999999	50.192461000000002	0103000020E61000000100000005000000CD0358E4D78B4640B360E28FA2184940CD0358E4D78B464071AB2006BA1A4940C6FA0626378E464071AB2006BA1A4940C6FA0626378E4640B360E28FA2184940CD0358E4D78B4640B360E28FA2184940
17328	Нижние Коробки	2	22	1459	44.485489000000001	44.502054000000001	50.332996000000001	50.321851000000002	0103000020E61000000100000005000000ACC8E880243E4640AB97DF6932294940ACC8E880243E464073D9E89C9F2A4940BA69334E4340464073D9E89C9F2A4940BA69334E43404640AB97DF6932294940ACC8E880243E4640AB97DF6932294940
17426	Неткачево	2	22	1459	44.913366000000003	45.006430999999999	50.567663000000003	50.534353000000003	0103000020E61000000100000005000000A1A3552DE97446407FC2D9AD65444940A1A3552DE97446401B13622EA94849401D5723BBD28046401B13622EA94849401D5723BBD28046407FC2D9AD65444940A1A3552DE97446407FC2D9AD65444940
17525	Мокрая Ольховка	2	22	1459	44.975214999999999	45.009036000000002	50.490000000000002	50.457123000000003	0103000020E61000000100000005000000C9C859D8D37C4640ED9FA701833A4940C9C859D8D37C46401F85EB51B83E49404B3E7617288146401F85EB51B83E49404B3E761728814640ED9FA701833A4940C9C859D8D37C4640ED9FA701833A4940
51272	Мирошники	2	22	1459	44.637906000000001	44.664200000000001	50.604739000000002	50.585515000000001	0103000020E610000001000000050000000AF65FE7A6514640A228D027F24A49400AF65FE7A6514640D1CE6916684D494069006F8104554640D1CE6916684D494069006F8104554640A228D027F24A49400AF65FE7A6514640A228D027F24A4940
51329	Лапшинская	2	22	1459	44.983775999999999	45.012216000000002	50.370964999999998	50.352645000000003	0103000020E610000001000000050000007B4B395FEC7D4640890CAB78232D49407B4B395FEC7D4640F67AF7C77B2F4940753E3C4B90814640F67AF7C77B2F4940753E3C4B90814640890CAB78232D49407B4B395FEC7D4640890CAB78232D4940
17701	Купцово	2	22	1459	44.989227999999997	45.020767999999997	50.326751000000002	50.311836999999997	0103000020E61000000100000005000000CC24EA059F7E464064575A46EA274940CC24EA059F7E4640B8770DFAD2294940D3669C86A8824640B8770DFAD2294940D3669C86A882464064575A46EA274940CC24EA059F7E464064575A46EA274940
17389	Крячки	2	22	1459	44.867597000000004	44.888159000000002	50.533774000000001	50.517391000000003	0103000020E61000000100000005000000CA8D226B0D6F4640541F48DE39424940CA8D226B0D6F464041BAD8B452444940F452B131AF71464041BAD8B452444940F452B131AF714640541F48DE39424940CA8D226B0D6F4640541F48DE39424940
16682	Котово	2	22	1459	44.755189999999999	44.851391	50.351754	50.287222	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
17880	Коростино	2	22	1459	44.914866000000004	44.950592	50.199542000000001	50.157915000000003	0103000020E61000000100000005000000761C3F541A7546402046088F36144940761C3F541A754640D7169E978A1949406CEBA7FFAC794640D7169E978A1949406CEBA7FFAC7946402046088F36144940761C3F541A7546402046088F36144940
51412	Калиновка	2	22	1459	44.678905	44.722158999999998	50.320270000000001	50.298690999999998	0103000020E61000000100000005000000A20BEA5BE6564640054EB6813B264940A20BEA5BE6564640E9F17B9BFE2849408BC1C3B46F5C4640E9F17B9BFE2849408BC1C3B46F5C4640054EB6813B264940A20BEA5BE6564640054EB6813B264940
49231	Ефимовка	2	22	1459	44.691139999999997	44.710185000000003	50.272962999999997	50.258924999999998	0103000020E610000001000000050000008D7A884677584640F38E5374242149408D7A8846775846404F029B73F02249400D8E9257E75A46404F029B73F02249400D8E9257E75A4640F38E5374242149408D7A884677584640F38E537424214940
17058	Бурлук	2	22	1459	44.522095	44.541848999999999	50.586499000000003	50.552522000000003	0103000020E61000000100000005000000DB334B02D44246400729780AB9464940DB334B02D442464080113466124B4940662FDB4E5B45464080113466124B4940662FDB4E5B4546400729780AB9464940DB334B02D44246400729780AB9464940
17734	Авилово	2	22	1459	45.056224999999998	45.084189000000002	50.227079000000003	50.216594999999998	0103000020E61000000100000005000000DA1B7C613287464012BD8C62B91B4940DA1B7C6132874640E04DB7EC101D49406BD784B4C68A4640E04DB7EC101D49406BD784B4C68A464012BD8C62B91B4940DA1B7C613287464012BD8C62B91B4940
40325	ской округ город Камышин, село Ленина	2	22	1259	43.260734999999997	43.287872999999998	47.640605000000001	47.627301000000003	0103000020E6100000010000000500000016F6B4C35FA14540C2DF2F664BD0474016F6B4C35FA14540B9533A58FFD147406133C005D9A44540B9533A58FFD147406133C005D9A44540C2DF2F664BD0474016F6B4C35FA14540C2DF2F664BD04740
51378	Чилеково	2	22	1259	43.490532999999999	43.503352	47.844087000000002	47.833824	0103000020E61000000100000005000000EC4D0CC9C9BE4540594FADBEBAEA4740EC4D0CC9C9BE454048FDF50A0BEC474027309DD66DC0454048FDF50A0BEC474027309DD66DC04540594FADBEBAEA4740EC4D0CC9C9BE4540594FADBEBAEA4740
51595	Семичный	2	22	1259	43.017434999999999	43.043747000000003	47.622480000000003	47.613272000000002	0103000020E610000001000000050000002367614F3B824540B9C667B27FCE47402367614F3B8245400135B56CADCF474029266F80998545400135B56CADCF474029266F8099854540B9C667B27FCE47402367614F3B824540B9C667B27FCE4740
51590	Пугачевская	2	22	1259	43.147440000000003	43.167005000000003	48.020035999999998	48.008132000000003	0103000020E61000000100000005000000A60F5D50DF9245408A0629780A014840A60F5D50DF9245400F5F268A900248405EA27A6B609545400F5F268A900248405EA27A6B609545408A0629780A014840A60F5D50DF9245408A0629780A014840
51384	Поперечный	2	22	1259	43.515596000000002	43.540291000000003	47.521425000000001	47.504877	0103000020E6100000010000000500000066F9BA0CFFC1454055C03DCF9FC0474066F9BA0CFFC145408D28ED0DBEC247405DA9674128C545408D28ED0DBEC247405DA9674128C5454055C03DCF9FC0474066F9BA0CFFC1454055C03DCF9FC04740
51319	Пимено-Черни	2	22	1259	43.448492000000002	43.491377999999997	47.709739999999996	47.690122000000002	0103000020E610000001000000050000004242942F68B945400420EEEA55D847404242942F68B94540DE54A4C2D8DA4740A8FC6B79E5BE4540DE54A4C2D8DA4740A8FC6B79E5BE45400420EEEA55D847404242942F68B945400420EEEA55D84740
51353	Нижнеяблочный	2	22	1259	43.086596999999998	43.127173999999997	47.856276999999999	47.842466999999999	0103000020E610000001000000050000004277499C158B4540C87A6AF5D5EB47404277499C158B454093A8177C9AED47406473D53C4790454093A8177C9AED47406473D53C47904540C87A6AF5D5EB47404277499C158B4540C87A6AF5D5EB4740
51464	Нагольный	2	22	1259	43.155146999999999	43.183714000000002	47.588554999999999	47.566471999999997	0103000020E6100000010000000500000048895DDBDB934540C30C8D2782C8474048895DDBDB934540DA722EC555CB47409FE8BAF083974540DA722EC555CB47409FE8BAF083974540C30C8D2782C8474048895DDBDB934540C30C8D2782C84740
51512	Нагавская	2	22	1259	42.801085	42.840521000000003	47.771279999999997	47.757665000000003	0103000020E6100000010000000500000078280AF4896645407429AE2AFBE0474078280AF4896645408907944DB9E24740F54C2F31966B45408907944DB9E24740F54C2F31966B45407429AE2AFBE0474078280AF4896645407429AE2AFBE04740
51489	Майоровский	2	22	1259	42.944392999999998	42.997681	47.684742	47.665382000000001	0103000020E6100000010000000500000021C9ACDEE17845406DACC43C2BD5474021C9ACDEE17845404C1938A0A5D74740986BD102B47F45404C1938A0A5D74740986BD102B47F45406DACC43C2BD5474021C9ACDEE17845406DACC43C2BD54740
51273	Красноярский	2	22	1259	43.053862000000002	43.074694000000001	47.913325	47.889071999999999	0103000020E61000000100000005000000A33F34F3E486454008E57D1CCDF14740A33F34F3E486454042CF66D5E7F447408D9AAF928F89454042CF66D5E7F447408D9AAF928F89454008E57D1CCDF14740A33F34F3E486454008E57D1CCDF14740
51339	Котельниково	2	22	1259	43.107005999999998	43.169511	47.660235999999998	47.609887999999998	0103000020E61000000100000005000000E63C635FB28D4540861C5BCF10CE4740E63C635FB28D454028D2FD9C82D44740F8A75489B295454028D2FD9C82D44740F8A75489B2954540861C5BCF10CE4740E63C635FB28D4540861C5BCF10CE4740
51539	Захаров	2	22	1259	43.099361999999999	43.118828000000001	47.692318	47.679222000000003	0103000020E610000001000000050000008A3BDEE4B78C4540A35C1ABFF0D647408A3BDEE4B78C4540503750E09DD84740AFEC82C1358F4540503750E09DD84740AFEC82C1358F4540A35C1ABFF0D647408A3BDEE4B78C4540A35C1ABFF0D64740
51477	Генераловский	2	22	1259	43.202443000000002	43.2303	48.014629999999997	47.998545999999997	0103000020E61000000100000005000000EE26F8A6E99945409BC6F65AD0FF4740EE26F8A6E99945402EC55565DF01484068226C787A9D45402EC55565DF01484068226C787A9D45409BC6F65AD0FF4740EE26F8A6E99945409BC6F65AD0FF4740
51525	Выпасной	2	22	1259	43.562685999999999	43.594315000000002	47.609487000000001	47.594061000000004	0103000020E6100000010000000500000062F5471806C845401F6ADB300ACC474062F5471806C84540282B86AB03CE4740D942908312CC4540282B86AB03CE4740D942908312CC45401F6ADB300ACC474062F5471806C845401F6ADB300ACC4740
51428	Веселый	2	22	1259	42.970489000000001	42.998049999999999	47.846929000000003	47.820540000000001	0103000020E610000001000000050000005A10CAFB387C4540A987687407E947405A10CAFB387C45405A84622B68EC4740EBE2361AC07F45405A84622B68EC4740EBE2361AC07F4540A987687407E947405A10CAFB387C4540A987687407E94740
51392	Селиванов	2	22	1353	42.963239999999999	42.998291999999999	49.175192000000003	49.161090000000002	0103000020E610000001000000050000007A19C5724B7B454038DBDC989E9448407A19C5724B7B4540AB4203B16C964840E1ED4108C87F4540AB4203B16C964840E1ED4108C87F454038DBDC989E9448407A19C5724B7B454038DBDC989E944840
15186	Перекопская	2	22	1353	43.336103999999999	43.354052000000003	49.419691	49.396678000000001	0103000020E610000001000000050000000307B47405AB454077853E58C6B248400307B47405AB454078B6476FB8B54840AD8A709351AD454078B6476FB8B54840AD8A709351AD454077853E58C6B248400307B47405AB454077853E58C6B24840
51677	Перекопка	2	22	1353	43.319799000000003	43.348104999999997	49.379958999999999	49.347766999999997	0103000020E610000001000000050000009225732CEFA8454063D009A183AC48409225732CEFA8454012691B7FA2B048407B4963B48EAC454012691B7FA2B048407B4963B48EAC454063D009A183AC48409225732CEFA8454063D009A183AC4840
51655	Орехов	2	22	1353	43.199156000000002	43.223014999999997	49.239899999999999	49.227851999999999	0103000020E61000000100000005000000AE669DF17D994540022A1C412A9D4840AE669DF17D994540BB270F0BB59E48403BC269C18B9C4540BB270F0BB59E48403BC269C18B9C4540022A1C412A9D4840AE669DF17D994540022A1C412A9D4840
51662	Новоцарицынский	2	22	1353	42.566327999999999	42.601973999999998	49.192922000000003	49.172063999999999	0103000020E610000001000000050000009067976F7D484540D3687231069648409067976F7D484540E75608ABB19848406A85E97B0D4D4540E75608ABB19848406A85E97B0D4D4540D3687231069648409067976F7D484540D368723106964840
51287	Мелоклетский	2	22	1353	43.115153999999997	43.134369	49.304200000000002	49.296427999999999	0103000020E610000001000000050000007500C45DBD8E454031CF4A5AF1A548407500C45DBD8E4540BBB88D06F0A64840514CDE0033914540BBB88D06F0A64840514CDE003391454031CF4A5AF1A548407500C45DBD8E454031CF4A5AF1A54840
15432	Манойлин	2	22	1353	42.876220000000004	42.936388999999998	49.017119999999998	49.001046000000002	0103000020E61000000100000005000000F20C1AFA2770454054E57B4622804840F20C1AFA27704540C30DF8FC30824840C5AA4198DB774540C30DF8FC30824840C5AA4198DB77454054E57B4622804840F20C1AFA2770454054E57B4622804840
51674	Малая Донщинка	2	22	1353	42.430529999999997	42.443114999999999	49.097493	49.080418999999999	0103000020E6100000010000000500000033F9669B1B3745400F7D772B4B8A484033F9669B1B374540624B8FA67A8C4840FBAE08FEB7384540624B8FA67A8C4840FBAE08FEB73845400F7D772B4B8A484033F9669B1B3745400F7D772B4B8A4840
51676	Максари	2	22	1353	42.630603000000001	42.647024000000002	49.112333	49.096513999999999	0103000020E6100000010000000500000037E15E99B750454096CD1C925A8C484037E15E99B75045407BA180ED608E484012DDB3AED15245407BA180ED608E484012DDB3AED152454096CD1C925A8C484037E15E99B750454096CD1C925A8C4840
51289	Майоровский	2	22	1353	43.000152	43.019528000000001	49.054011000000003	49.042076999999999	0103000020E61000000100000005000000B68311FB04804540F77475C762854840B68311FB04804540E84F1BD5E98648409BADBCE47F824540E84F1BD5E98648409BADBCE47F824540F77475C762854840B68311FB04804540F77475C762854840
51716	Логовский	2	22	1353	43.259036999999999	43.273319999999998	49.332998000000003	49.319676000000001	0103000020E610000001000000050000001BBAD91F28A1454076A8A624EBA848401BBAD91F28A1454014D1AFAD9FAA4840DEAB5626FCA2454014D1AFAD9FAA4840DEAB5626FCA2454076A8A624EBA848401BBAD91F28A1454076A8A624EBA84840
51667	Липовский	2	22	1353	42.522212000000003	42.543259999999997	49.080413	49.058120000000002	0103000020E6100000010000000500000015CAC2D7D74245402C9FE5797087484015CAC2D7D74245402D9622F94A8A4840CB9C2E8B894545402D9622F94A8A4840CB9C2E8B894545402C9FE5797087484015CAC2D7D74245402C9FE57970874840
15129	Кременская	2	22	1353	43.445715999999997	43.469459000000001	49.484527	49.472299999999997	0103000020E61000000100000005000000E7A6CD380DB945404DF38E5374BC4840E7A6CD380DB94540B68311FB04BE48400CE8853B17BC4540B68311FB04BE48400CE8853B17BC45404DF38E5374BC4840E7A6CD380DB945404DF38E5374BC4840
15199	Клетская	2	22	1353	43.040225999999997	43.078502999999998	49.322183000000003	49.290581000000003	0103000020E61000000100000005000000753925202685454064EB19C231A548407539252026854540E129E44A3DA94840A6D1E4620C8A4540E129E44A3DA94840A6D1E4620C8A454064EB19C231A54840753925202685454064EB19C231A54840
51668	Караженский	2	22	1353	43.017732000000002	43.032617000000002	49.342396000000001	49.329492999999999	0103000020E61000000100000005000000DD0BCC0A4582454066A19DD32CAA4840DD0BCC0A45824540FF23D3A1D3AB484096253ACB2C844540FF23D3A1D3AB484096253ACB2C84454066A19DD32CAA4840DD0BCC0A4582454066A19DD32CAA4840
23437	Казачий	2	22	1353	42.893908000000003	42.904293000000003	49.144739000000001	49.133222000000004	0103000020E61000000100000005000000FFD0CC936B724540CA8D226B0D914840FFD0CC936B72454056BABBCE8692484039807EDFBF73454056BABBCE8692484039807EDFBF734540CA8D226B0D914840FFD0CC936B724540CA8D226B0D914840
51600	Зотовский	2	22	1353	42.711387999999999	42.748793999999997	49.057447000000003	49.039265999999998	0103000020E61000000100000005000000286211C30E5B454020EC14AB06854840286211C30E5B45406D205D6C5A87484073B8567BD85F45406D205D6C5A87484073B8567BD85F454020EC14AB06854840286211C30E5B454020EC14AB06854840
51650	Евстратовский	2	22	1353	42.862476000000001	42.886111	49.193876000000003	49.182901000000001	0103000020E61000000100000005000000DECA129D656E4540EEB3CA4C69974840DECA129D656E45405ABDC3EDD09848401CD0D2156C7145405ABDC3EDD09848401CD0D2156C714540EEB3CA4C69974840DECA129D656E4540EEB3CA4C69974840
14524	Верхняя Бузиновка	2	22	1353	43.196137	43.241098000000001	49.074494000000001	49.041834999999999	0103000020E610000001000000050000008D4468041B994540016A6AD95A8548408D4468041B994540C6DFF60489894840C5909C4CDC9E4540C6DFF60489894840C5909C4CDC9E4540016A6AD95A8548408D4468041B994540016A6AD95A854840
51635	Верхнечеренский	2	22	1353	42.657175000000002	42.688777999999999	49.226092999999999	49.202559000000001	0103000020E61000000100000005000000D95F764F1E54454057410C74ED994840D95F764F1E544540616D8C9DF09C4840261AA4E029584540616D8C9DF09C4840261AA4E02958454057410C74ED994840D95F764F1E54454057410C74ED994840
51661	Венцы	2	22	1353	43.303998	43.314517000000002	49.185302999999998	49.175367999999999	0103000020E6100000010000000500000053060E68E9A64540E96168757296484053060E68E9A64540E36C3A02B89748409D84D21742A84540E36C3A02B89748409D84D21742A84540E96168757296484053060E68E9A64540E961687572964840
51317	Борисов	2	22	1353	42.920076000000002	42.938302999999998	48.892553999999997	48.880670000000002	0103000020E61000000100000005000000D1EAE40CC5754540BF4868CBB9704840D1EAE40CC5754540FDF49F353F7248408D5E0D501A784540FDF49F353F7248408D5E0D501A784540BF4868CBB9704840D1EAE40CC5754540BF4868CBB9704840
37535	Красный Яр	2	22	5103	45.763261999999997	45.786205000000002	50.625841000000001	50.607649000000002	0103000020E61000000100000005000000C823B891B2E146403B394371C74D4940C823B891B2E146407BBFD18E1B504940D1798D5DA2E446407BBFD18E1B504940D1798D5DA2E446403B394371C74D4940C823B891B2E146403B394371C74D4940
51427	Ширяевский	2	22	1306	42.977801999999997	43.023345999999997	50.737926999999999	50.715046000000001	0103000020E6100000010000000500000050FBAD9D287D45405C9198A0865B494050FBAD9D287D4540EEEA5564745E4940073F7100FD824540EEEA5564745E4940073F7100FD8245405C9198A0865B494050FBAD9D287D45405C9198A0865B4940
14129	Чернолагутинский	2	22	1306	43.310510999999998	43.35575	50.648629	50.626561000000002	0103000020E610000001000000050000002D060FD3BEA745407BF99D26335049402D060FD3BEA745405C1E6B4606534940A8C64B3789AD45405C1E6B4606534940A8C64B3789AD45407BF99D26335049402D060FD3BEA745407BF99D2633504940
47878	Семеновка	2	22	1306	43.149451999999997	43.181728	50.808183999999997	50.789141000000001	0103000020E6100000010000000500000030293E3E21934540647781920265494030293E3E219345404293C492726749403D62F4DC429745404293C492726749403D62F4DC42974540647781920265494030293E3E219345406477819202654940
51549	Расстригин	2	22	1306	42.863562999999999	42.894751999999997	50.712632999999997	50.700392000000001	0103000020E6100000010000000500000090847D3B896E4540A530EF71A659494090847D3B896E45407286E28E375B4940EA03C93B877245407286E28E375B4940EA03C93B87724540A530EF71A659494090847D3B896E4540A530EF71A6594940
51511	Преображенская	2	22	1306	43.013294000000002	43.104391999999997	50.762985999999998	50.727989999999998	0103000020E61000000100000005000000D49D279EB381454053E8BCC62E5D4940D49D279EB381454026A77686A961494065FB90B75C8D454026A77686A961494065FB90B75C8D454053E8BCC62E5D4940D49D279EB381454053E8BCC62E5D4940
51521	Озерки	2	22	1306	43.192706000000001	43.269503	50.783765000000002	50.762621000000003	0103000020E610000001000000050000001ADF1797AA984540151F9F909D6149401ADF1797AA984540EE5F596952644940429605137FA24540EE5F596952644940429605137FA24540151F9F909D6149401ADF1797AA984540151F9F909D614940
51282	Мордвинцево	2	22	1306	43.249370999999996	43.268613000000002	50.559721000000003	50.540300999999999	0103000020E6100000010000000500000010C99063EB9F4540807F4A952845494010C99063EB9F454035F10EF0A4474940E62329E961A2454035F10EF0A4474940E62329E961A24540807F4A952845494010C99063EB9F4540807F4A9528454940
14261	Мачеха	2	22	1306	43.276707000000002	43.331783000000001	50.827772000000003	50.788930000000001	0103000020E6100000010000000500000082C98D226BA34540A96A82A8FB64494082C98D226BA34540B345D26EF4694940342F87DD77AA4540B345D26EF4694940342F87DD77AA4540A96A82A8FB64494082C98D226BA34540A96A82A8FB644940
51356	Калачевский	2	22	1306	42.984171000000003	43.012782000000001	50.568761000000002	50.539282	0103000020E61000000100000005000000F855B950F97D454026A94C3107454940F855B950F97D4540C11E1329CD4849401EFD2FD7A2814540C11E1329CD4849401EFD2FD7A281454026A94C3107454940F855B950F97D454026A94C3107454940
51566	Казарино	2	22	1306	43.157887000000002	43.183650999999998	50.777836999999998	50.760900999999997	0103000020E6100000010000000500000056BB26A435944540313F37346561494056BB26A435944540334FAE299063494058703FE081974540334FAE299063494058703FE081974540313F37346561494056BB26A435944540313F373465614940
13756	Завязка	2	22	1306	43.030074999999997	43.067112000000002	50.834632999999997	50.791258999999997	0103000020E61000000100000005000000AEB6627FD983454034D593F947654940AEB6627FD9834540C8940F41D56A4940A795422097884540C8940F41D56A4940A79542209788454034D593F947654940AEB6627FD983454034D593F947654940
51338	Дубровский	2	22	1306	42.895031000000003	42.937539000000001	50.745429000000001	50.725406999999997	0103000020E61000000100000005000000FEF33460907245400DA5F622DA5C4940FEF3346090724540B83EAC376A5F4940BEDC274701784540B83EAC376A5F4940BEDC2747017845400DA5F622DA5C4940FEF33460907245400DA5F622DA5C4940
14067	Гришин	2	22	1306	43.132877999999998	43.161650999999999	50.653934999999997	50.617325999999998	0103000020E61000000100000005000000CF2D742502914540397CD289044F4940CF2D742502914540D95A5F24B4534940CF2EDFFAB0944540D95A5F24B4534940CF2EDFFAB0944540397CD289044F4940CF2D742502914540397CD289044F4940
13770	Алонцево	2	22	1306	43.011839000000002	43.047583000000003	50.922421999999997	50.893574999999998	0103000020E610000001000000050000009FE8BAF083814540F8C264AA607249409FE8BAF083814540328E91EC117649403C6C223317864540328E91EC117649403C6C223317864540F8C264AA607249409FE8BAF083814540F8C264AA60724940
46971	Щербатовка	2	22	1024	45.674356000000003	45.692932999999996	50.494062999999997	50.485255000000002	0103000020E6100000010000000500000042EE224C51D64640399CF9D51C3E494042EE224C51D64640F294D5743D3F4940DAA84E07B2D84640F294D5743D3F4940DAA84E07B2D84640399CF9D51C3E494042EE224C51D64640399CF9D51C3E4940
46998	Щербаковка	2	22	1024	45.753919000000003	45.767429999999997	50.513857000000002	50.507361000000003	0103000020E61000000100000005000000A16AF46A80E0464008228B34F1404940A16AF46A80E046400CE9F010C641494011FC6F253BE246400CE9F010C641494011FC6F253BE2464008228B34F1404940A16AF46A80E0464008228B34F1404940
12937	Чухонастовка	2	22	1024	45.083390000000001	45.119402999999998	49.871597999999999	49.853659999999998	0103000020E610000001000000050000001F680586AC8A4640A1F31ABB44ED48401F680586AC8A464027A1F48590EF4840AB05F698488F464027A1F48590EF4840AB05F698488F4640A1F31ABB44ED48401F680586AC8A4640A1F31ABB44ED4840
11647	Усть-Грязнуха	2	22	1024	45.416530000000002	45.432600999999998	50.485083000000003	50.470156000000003	0103000020E61000000100000005000000C5E6E3DA50B54640540262122E3C4940C5E6E3DA50B546403C6C2233173E4940C39B35785FB746403C6C2233173E4940C39B35785FB74640540262122E3C4940C5E6E3DA50B54640540262122E3C4940
46470	Умет	2	22	1024	45.321066000000002	45.355732000000003	50.301211000000002	50.279296000000002	0103000020E61000000100000005000000C4EDD0B018A94640AAF3A8F8BF234940C4EDD0B018A94640051901158E26494002124DA088AD4640051901158E26494002124DA088AD4640AAF3A8F8BF234940C4EDD0B018A94640AAF3A8F8BF234940
51389	Терновка	2	22	1024	45.483696999999999	45.511158999999999	50.21452	50.199415000000002	0103000020E610000001000000050000002F1686C8E9BD46407AAA436E861949402F1686C8E9BD4640412B3064751B49402D077AA86DC14640412B3064751B49402D077AA86DC146407AAA436E861949402F1686C8E9BD46407AAA436E86194940
51382	Таловка	2	22	1024	45.018900000000002	45.050106999999997	49.990482	49.961157	0103000020E610000001000000050000007CF2B0506B82464026A94C3107FB48407CF2B0506B8246406AA33A1DC8FE48407C26FBE7698646406AA33A1DC8FE48407C26FBE76986464026A94C3107FB48407CF2B0506B82464026A94C3107FB4840
13403	Средняя Камышинка	2	22	1024	45.269987999999998	45.292419000000002	50.126325000000001	50.111058999999997	0103000020E61000000100000005000000FE277FF78EA2464096766A2E370E4940FE277FF78EA2464067D5E76A2B10494051DD5CFC6DA5464067D5E76A2B10494051DD5CFC6DA5464096766A2E370E4940FE277FF78EA2464096766A2E370E4940
51416	Семеновка	2	22	1024	45.307321999999999	45.333579999999998	50.496132000000003	50.481397000000001	0103000020E61000000100000005000000B0ABC95356A746403EB2B96A9E3D4940B0ABC95356A74640E23FDD40813F4940C24CDBBFB2AA4640E23FDD40813F4940C24CDBBFB2AA46403EB2B96A9E3D4940B0ABC95356A746403EB2B96A9E3D4940
13116	Саломатино	2	22	1024	44.825924000000001	44.872304	50.024344999999997	50.001339999999999	0103000020E61000000100000005000000A27DACE0B76946409C16BCE82B004940A27DACE0B76946401A69A9BC1D034940C21550A8A76F46401A69A9BC1D034940C21550A8A76F46409C16BCE82B004940A27DACE0B76946409C16BCE82B004940
12450	Петрунино	2	22	1024	45.057788000000002	45.093423999999999	50.119348000000002	50.090800999999999	0103000020E61000000100000005000000F60CE19865874640D8B8FE5D9F0B4940F60CE19865874640E86B96CB460F4940AC545051F58B4640E86B96CB460F4940AC545051F58B4640D8B8FE5D9F0B4940F60CE19865874640D8B8FE5D9F0B4940
12508	Петров Вал	2	22	1024	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
46846	Пановка	2	22	1024	45.397665000000003	45.408974999999998	50.594928000000003	50.580362000000001	0103000020E61000000100000005000000C6E1CCAFE6B24640ABEB504D494A4940C6E1CCAFE6B24640C3BCC799264C4940D8F0F44A59B44640C3BCC799264C4940D8F0F44A59B44640ABEB504D494A4940C6E1CCAFE6B24640ABEB504D494A4940
12244	Нижняя Добринка	2	22	1024	45.691594000000002	45.709874999999997	50.320517000000002	50.305078000000002	0103000020E610000001000000050000000F0EF62686D84640535DC0CB0C2749400F0EF62686D84640F16778B306294940BE9F1A2FDDDA4640F16778B306294940BE9F1A2FDDDA4640535DC0CB0C2749400F0EF62686D84640535DC0CB0C274940
51638	Мичуринский	2	22	1024	44.787196999999999	45.896293	50.612558999999997	49.751992999999999	0103000020E6100000010000000500000031410DDFC264464014E97E4E41E0484031410DDFC26446406BEF5355684E49401E51A1BAB9F246406BEF5355684E49401E51A1BAB9F2464014E97E4E41E0484031410DDFC264464014E97E4E41E04840
47599	Лебяжье	2	22	1024	45.193621999999998	45.222161999999997	50.191284000000003	50.164862999999997	0103000020E610000001000000050000009FE40E9BC898464004A9143B1A1549409FE40E9BC8984640C11F7EFE7B184940FC34EECD6F9C4640C11F7EFE7B184940FC34EECD6F9C464004A9143B1A1549409FE40E9BC898464004A9143B1A154940
13196	Костарево	2	22	1024	44.928583000000003	44.975968999999999	50.077004000000002	50.054805000000002	0103000020E61000000100000005000000904FC8CEDB7646402254A9D903074940904FC8CEDB764640A2D45E44DB09494075745C8DEC7C4640A2D45E44DB09494075745C8DEC7C46402254A9D903074940904FC8CEDB7646402254A9D903074940
13390	Ельшанка	2	22	1024	45.378441000000002	45.401384	50.171643000000003	50.157615	0103000020E61000000100000005000000973B33C170B04640F52D73BA2C144940973B33C170B046402ECBD765F81549409F91088D60B346402ECBD765F81549409F91088D60B34640F52D73BA2C144940973B33C170B04640F52D73BA2C144940
47072	Дубовка	2	22	1024	45.550953999999997	45.570554999999999	50.243062000000002	50.228306000000003	0103000020E61000000100000005000000D9CC21A985C6464084BD8921391D4940D9CC21A985C646403F73D6A71C1F4940DEC83CF207C946403F73D6A71C1F4940DEC83CF207C9464084BD8921391D4940D9CC21A985C6464084BD8921391D4940
13288	Дворянское	2	22	1024	45.276420000000002	45.293253999999997	50.251691000000001	50.236770999999997	0103000020E61000000100000005000000ECFA05BB61A3464013D21A834E1E4940ECFA05BB61A3464049D9226937204940E9B5D95889A5464049D9226937204940E9B5D95889A5464013D21A834E1E4940ECFA05BB61A3464013D21A834E1E4940
11862	Гуселка	2	22	1024	45.128951999999998	45.179032999999997	50.469892000000002	50.447108999999998	0103000020E610000001000000050000007C60C77F81904640A65F22DE3A3949407C60C77F819046407653CA6B253C4940CFF3A78DEA9646407653CA6B253C4940CFF3A78DEA964640A65F22DE3A3949407C60C77F81904640A65F22DE3A394940
13098	Госселекстанция	2	22	1024	45.121046999999997	45.132320999999997	50.037861999999997	50.021664999999999	0103000020E61000000100000005000000B323D5777E8F4640E23B31EBC5024940B323D5777E8F46406DE179A9D804494079C9FFE4EF9046406DE179A9D804494079C9FFE4EF904640E23B31EBC5024940B323D5777E8F4640E23B31EBC5024940
12119	Галка	2	22	1024	45.790273999999997	45.80489	50.384165000000003	50.372292000000002	0103000020E610000001000000050000008670CCB227E54640FE47A643A72F49408670CCB227E5464049A297512C3149405070B1A206E7464049A297512C3149405070B1A206E74640FE47A643A72F49408670CCB227E54640FE47A643A72F4940
11924	Воднобуерачное	2	22	1024	45.622622	45.644936000000001	50.548966999999998	50.531002999999998	0103000020E6100000010000000500000093E2E313B2CF4640F88903E8F743494093E2E313B2CF4640A7CAF78C44464940AC014A438DD24640A7CAF78C44464940AC014A438DD24640F88903E8F743494093E2E313B2CF4640F88903E8F7434940
51728	Вихлянцево	2	22	1024	45.277273000000001	45.317768999999998	50.013035000000002	50.003354999999999	0103000020E610000001000000050000002B8881AE7DA3464098A3C7EF6D0049402B8881AE7DA34640085A8121AB014940605793A7ACA84640085A8121AB014940605793A7ACA8464098A3C7EF6D0049402B8881AE7DA3464098A3C7EF6D004940
12358	Верхняя Липовка	2	22	1024	45.447296999999999	45.47475	50.186815000000003	50.169024	0103000020E61000000100000005000000A94C310741B946409B1E1494A2154940A94C310741B946407DB3CD8DE917494054E3A59BC4BC46407DB3CD8DE917494054E3A59BC4BC46409B1E1494A2154940A94C310741B946409B1E1494A2154940
11978	Верхняя Куланинка	2	22	1024	45.692897000000002	45.705294000000002	50.421944000000003	50.413851000000001	0103000020E610000001000000050000008E3F51D9B0D846405D35CF11F93449408E3F51D9B0D84640295FD042023649405308E41247DA4640295FD042023649405308E41247DA46405D35CF11F93449408E3F51D9B0D846405D35CF11F9344940
11684	Верхняя Грязнуха	2	22	1024	45.453172000000002	45.479664	50.486550000000001	50.471795999999998	0103000020E6100000010000000500000041BB438A01BA46401A31B3CF633C494041BB438A01BA464035EF3845473E4940C68844A165BD464035EF3845473E4940C68844A165BD46401A31B3CF633C494041BB438A01BA46401A31B3CF633C4940
8914	Белогорки	2	22	1024	45.172969999999999	45.191637	49.966244000000003	49.953488999999998	0103000020E61000000100000005000000359886E123964640410C74ED0BFA4840359886E12396464066FA25E2ADFB48400EDAAB8F8798464066FA25E2ADFB48400EDAAB8F87984640410C74ED0BFA4840359886E123964640410C74ED0BFA4840
47146	Барановка	2	22	1024	45.148248000000002	45.168604000000002	50.146752999999997	50.124985000000002	0103000020E6100000010000000500000045D95BCAF9924640CBBE2B82FF0F494045D95BCAF992464081CB63CDC8124940C6FCDCD09495464081CB63CDC8124940C6FCDCD094954640CBBE2B82FF0F494045D95BCAF9924640CBBE2B82FF0F4940
12931	Антиповка	2	22	1024	45.295886000000003	45.330624	49.839928	49.816026000000001	0103000020E6100000010000000500000011ACAA97DFA54640C5573B8A73E8484011ACAA97DFA54640527FBDC282EB4840E8A221E351AA4640527FBDC282EB4840E8A221E351AA4640C5573B8A73E8484011ACAA97DFA54640C5573B8A73E84840
40309	Камышин	2	22	6895	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
10203	Ярки-Рубежный	2	22	1048	43.903947000000002	43.913110000000003	48.435751000000003	48.425505000000001	0103000020E610000001000000050000009E280989B4F345406AA4A5F2763648409E280989B4F34540831953B0C637484046D3D9C9E0F44540831953B0C637484046D3D9C9E0F445406AA4A5F2763648409E280989B4F345406AA4A5F276364840
51436	Тихоновка	2	22	1048	43.659433999999997	43.684604999999998	48.544105000000002	48.533665999999997	0103000020E610000001000000050000006BEF535568D445405A7EE02A4F4448406BEF535568D44540884B8E3BA5454840CBD6FA22A1D74540884B8E3BA5454840CBD6FA22A1D745405A7EE02A4F4448406BEF535568D445405A7EE02A4F444840
10171	Степаневка	2	22	1048	43.926547999999997	43.948692000000001	48.396994999999997	48.382750000000001	0103000020E610000001000000050000004C16F71F99F64540A245B6F3FD3048404C16F71F99F6454077D66EBBD032484009FD4CBD6EF9454077D66EBBD032484009FD4CBD6EF94540A245B6F3FD3048404C16F71F99F64540A245B6F3FD304840
9251	Светлый Лог	2	22	1048	43.306548999999997	43.338088999999997	48.703778999999997	48.691195999999998	0103000020E610000001000000050000008DCF64FF3CA7454021904B1C795848408DCF64FF3CA74540484E266E155A48409411178046AB4540484E266E155A48409411178046AB454021904B1C795848408DCF64FF3CA7454021904B1C79584840
9432	Рюмино-Красноярский	2	22	1048	43.586779	43.605293000000003	48.814796000000001	48.804727	0103000020E61000000100000005000000637D03931BCB4540A69A594B01674840637D03931BCB4540B0743E3C4B684840B6BFB33D7ACD4540B0743E3C4B684840B6BFB33D7ACD4540A69A594B01674840637D03931BCB4540A69A594B01674840
51670	Пятиморский	2	22	1048	43.588664999999999	43.621768000000003	48.653863000000001	48.639481000000004	0103000020E6100000010000000500000061A6ED5F59CB4540EAB46E83DA51484061A6ED5F59CB4540408864C8B153484084D9041896CF4540408864C8B153484084D9041896CF4540EAB46E83DA51484061A6ED5F59CB4540EAB46E83DA514840
9179	Пятиизбянский	2	22	1048	43.4251	43.463602000000002	48.597926000000001	48.583880999999998	0103000020E61000000100000005000000CAC342AD69B64540BDE0D39CBC4A4840CAC342AD69B64540CCB6D3D6884C48401B2E724F57BB4540CCB6D3D6884C48401B2E724F57BB4540BDE0D39CBC4A4840CAC342AD69B64540BDE0D39CBC4A4840
9652	Прудбой	2	22	1048	43.877392999999998	43.926763999999999	48.700800000000001	48.680062	0103000020E61000000100000005000000A25EF0694EF045404DA088450C574840A25EF0694EF04540B6847CD0B3594840198EE733A0F64540B6847CD0B3594840198EE733A0F645404DA088450C574840A25EF0694EF045404DA088450C574840
51305	Приморский	2	22	1048	43.534353000000003	43.551690000000001	48.573497000000003	48.559443999999999	0103000020E610000001000000050000007FC2D9AD65C44540C2F869DC9B4748407FC2D9AD65C4454054AD855968494840DFC325C79DC6454054AD855968494840DFC325C79DC64540C2F869DC9B4748407FC2D9AD65C44540C2F869DC9B474840
51423	Первомайский	2	22	1048	43.341898	43.360978000000003	48.398353	48.386572999999999	0103000020E61000000100000005000000AE484C50C3AB454020425C397B314840AE484C50C3AB4540BAA1293BFD324840AA49F08634AE4540BAA1293BFD324840AA49F08634AE454020425C397B314840AE484C50C3AB454020425C397B314840
11022	Пархоменко	2	22	1048	44.137715	44.149051999999998	48.576250999999999	48.564906000000001	0103000020E61000000100000005000000969526A5A011464037A8FDD64E484840969526A5A0114640C6A4BF97C2494840A2B3CC2214134640C6A4BF97C2494840A2B3CC221413464037A8FDD64E484840969526A5A011464037A8FDD64E484840
51596	Октябрьский	2	22	1048	43.800057000000002	43.809004000000002	48.658231000000001	48.646695999999999	0103000020E61000000100000005000000CBF78C4468E645401D3A3DEFC6524840CBF78C4468E64540501BD5E940544840A62A6D718DE74540501BD5E940544840A62A6D718DE745401D3A3DEFC6524840CBF78C4468E645401D3A3DEFC6524840
46434	Овражный	2	22	1048	43.755598999999997	43.780662	48.330142000000002	48.318950999999998	0103000020E61000000100000005000000F5F1D077B7E045406403E962D3284840F5F1D077B7E045409D84D217422A48406F9D7FBBECE345409D84D217422A48406F9D7FBBECE345406403E962D3284840F5F1D077B7E045406403E962D3284840
10323	Новоляпичев	2	22	1048	43.551887999999998	43.578567999999997	48.497062999999997	48.483638999999997	0103000020E6100000010000000500000005871744A4C64540FA08FCE1E73D484005871744A4C645409C86A8C29F3F48408D4127840ECA45409C86A8C29F3F48408D4127840ECA4540FA08FCE1E73D484005871744A4C64540FA08FCE1E73D4840
9540	Мариновка	2	22	1048	43.820959999999999	43.852939999999997	48.695008000000001	48.679836000000002	0103000020E610000001000000050000007EA99F3715E945405D52B5DD045748407EA99F3715E94540AC3AAB05F6584840A1B94E232DED4540AC3AAB05F6584840A1B94E232DED45405D52B5DD045748407EA99F3715E945405D52B5DD04574840
9277	Малоголубинский	2	22	1048	43.576878999999998	43.612039000000003	48.906672999999998	48.892837999999998	0103000020E61000000100000005000000E55FCB2BD7C945402250FD8348724840E55FCB2BD7C94540469561DC0D7448403370404B57CE4540469561DC0D7448403370404B57CE45402250FD8348724840E55FCB2BD7C945402250FD8348724840
10442	Ляпичев	2	22	1048	43.486418999999998	43.514023999999999	48.502448000000001	48.485537999999998	0103000020E61000000100000005000000969350FA42BE45408D7BF31B263E4840969350FA42BE454066F84F3750404840F7ADD689CBC1454066F84F3750404840F7ADD689CBC145408D7BF31B263E4840969350FA42BE45408D7BF31B263E4840
10507	Логовский	2	22	1048	43.353656999999998	43.376133000000003	48.438997000000001	48.417791000000001	0103000020E610000001000000050000003080F0A144AD454015C8EC2C7A3548403080F0A144AD45406405BF0D3138484023F94A2025B045406405BF0D3138484023F94A2025B0454015C8EC2C7A3548403080F0A144AD454015C8EC2C7A354840
10725	Крепинский	2	22	1048	43.675351999999997	43.693129999999996	48.367854000000001	48.351073	0103000020E61000000100000005000000E3A430EF71D645401AC1C6F5EF2C4840E3A430EF71D64540F5D901D7152F484030F0DC7BB8D84540F5D901D7152F484030F0DC7BB8D845401AC1C6F5EF2C4840E3A430EF71D645401AC1C6F5EF2C4840
51271	Комсомольский	2	22	1048	43.857126999999998	43.877958999999997	48.663967999999997	48.650637000000003	0103000020E6100000010000000500000061C26856B6ED4540A648BE124853484061C26856B6ED454096CB46E7FC5448404B1DE4F560F0454096CB46E7FC5448404B1DE4F560F04540A648BE124853484061C26856B6ED4540A648BE1248534840
10044	Колпачки	2	22	1048	43.590488999999998	43.619503999999999	48.613571	48.597039000000002	0103000020E61000000100000005000000E9D2BF2495CB4540E1B721C66B4C4840E9D2BF2495CB45401363997E894E4840DFDE35E84BCF45401363997E894E4840DFDE35E84BCF4540E1B721C66B4C4840E9D2BF2495CB4540E1B721C66B4C4840
9357	Камыши	2	22	1048	43.488790000000002	43.514617000000001	48.745750999999998	48.728133	0103000020E61000000100000005000000514EB4AB90BE4540B6114F76335D4840514EB4AB90BE4540CAFACDC4745F48409A7B48F8DEC14540CAFACDC4745F48409A7B48F8DEC14540B6114F76335D4840514EB4AB90BE4540B6114F76335D4840
11110	Калач-на-Дону	2	22	1048	43.481451	43.571866999999997	48.713565000000003	48.655856999999997	0103000020E6100000010000000500000031D0B52FA0BD454024ED461FF353484031D0B52FA0BD4540FE481119565B4840B05417F032C94540FE481119565B4840B05417F032C9454024ED461FF353484031D0B52FA0BD454024ED461FF3534840
9439	Ильевка	2	22	1048	43.620690000000003	43.649984000000003	48.654369000000003	48.643940000000001	0103000020E61000000100000005000000257A19C572CF45400A4B3CA06C524840257A19C572CF45401442075DC25348402E76FBAC32D345401442075DC25348402E76FBAC32D345400A4B3CA06C524840257A19C572CF45400A4B3CA06C524840
46566	Заря	2	22	1048	44.097579000000003	44.128211	48.543007000000003	48.526159999999997	0103000020E6100000010000000500000061E3FA777D0C46404F3BFC355943484061E3FA777D0C4640E23FDD408145484065FED13769104640E23FDD408145484065FED137691046404F3BFC355943484061E3FA777D0C46404F3BFC3559434840
9328	Голубинская	2	22	1048	43.540812000000003	43.593947	48.858494	48.841597999999998	0103000020E6100000010000000500000066A4DE5339C545408330B77BB96B484066A4DE5339C54540F7E7A221E36D484056478E7406CC4540F7E7A221E36D484056478E7406CC45408330B77BB96B484066A4DE5339C545408330B77BB96B4840
9901	Волгодонской	2	22	1048	43.709910999999998	43.738970999999999	48.64472	48.629334999999998	0103000020E610000001000000050000000B09185DDEDA4540349D9D0C8E5048400B09185DDEDA4540DF89592F86524840A1D80A9A96DE4540DF89592F86524840A1D80A9A96DE4540349D9D0C8E5048400B09185DDEDA4540349D9D0C8E504840
10286	Вербовский	2	22	1048	43.567070000000001	43.598744000000003	48.523850000000003	48.509645999999996	0103000020E610000001000000050000007845F0BF95C84540C34483143C4148407845F0BF95C845403B014D840D4348408F56B5A4A3CC45403B014D840D4348408F56B5A4A3CC4540C34483143C4148407845F0BF95C84540C34483143C414840
10132	Бузиновка	2	22	1048	43.881219000000002	43.912328000000002	48.510798000000001	48.488881999999997	0103000020E6100000010000000500000092CEC0C8CBF0454031CD74AF933E484092CEC0C8CBF045405D6E30D461414840D09CF529C7F445405D6E30D461414840D09CF529C7F4454031CD74AF933E484092CEC0C8CBF0454031CD74AF933E4840
51303	Братский	2	22	1048	43.616638999999999	43.630930999999997	48.413772999999999	48.399023	0103000020E610000001000000050000001538D906EECE454008AD872F133348401538D906EECE4540E17B7F83F63448402B84D558C2D04540E17B7F83F63448402B84D558C2D0454008AD872F133348401538D906EECE454008AD872F13334840
10903	Береславка	2	22	1048	44.034785999999997	44.079433000000002	48.636802000000003	48.602538000000003	0103000020E61000000100000005000000E82D1EDE73044640734C16F71F4D4840E82D1EDE7304464082035ABA82514840919C4CDC2A0A464082035ABA82514840919C4CDC2A0A4640734C16F71F4D4840E82D1EDE73044640734C16F71F4D4840
10636	Белоглинский	2	22	1048	43.644117999999999	43.664347999999997	48.388578000000003	48.377237999999998	0103000020E61000000100000005000000E961687572D245407B67B45549304840E961687572D24540F9F884ECBC314840DD94F25A09D54540F9F884ECBC314840DD94F25A09D545407B67B45549304840E961687572D245407B67B45549304840
51463	Шохинский	2	22	917	43.553235999999998	43.573582000000002	49.283524	49.256737000000001	0103000020E61000000100000005000000247CEF6FD0C645402A560DC2DCA04840247CEF6FD0C64540C8D0B1834AA4484082C98D226BC94540C8D0B1834AA4484082C98D226BC945402A560DC2DCA04840247CEF6FD0C645402A560DC2DCA04840
51343	Ширяевский	2	22	917	44.006650999999998	44.087606999999998	49.601373000000002	49.542807000000003	0103000020E610000001000000050000002BBEA1F0D90046401B8524B37AC548402BBEA1F0D900464045D95BCAF9CC484049F3C7B4360B464045D95BCAF9CC484049F3C7B4360B46401B8524B37AC548402BBEA1F0D90046401B8524B37AC54840
51280	Чернозубовка	2	22	917	44.238757999999997	44.266399	49.495961999999999	49.481805999999999	0103000020E6100000010000000500000045D4449F8F1E46401F82AAD1ABBD484045D4449F8F1E46408507CDAE7BBF4840F357C85C192246408507CDAE7BBF4840F357C85C192246401F82AAD1ABBD484045D4449F8F1E46401F82AAD1ABBD4840
51350	Трехостровская	2	22	917	43.902113999999997	43.931435	49.103037999999998	49.083983000000003	0103000020E61000000100000005000000C2A1B77878F34540C23577F4BF8A4840C2A1B77878F34540641F6459308D4840C5AC174339F74540641F6459308D4840C5AC174339F74540C23577F4BF8A4840C2A1B77878F34540C23577F4BF8A4840
51594	Тары	2	22	917	43.974474000000001	44.008502	49.362478000000003	49.339883999999998	0103000020E61000000100000005000000B2666490BBFC45408237A45181AB4840B2666490BBFC45407FC2D9AD65AE4840ADF9F197160146407FC2D9AD65AE4840ADF9F197160146408237A45181AB4840B2666490BBFC45408237A45181AB4840
51344	Сиротинская	2	22	917	43.661104999999999	43.690497999999998	49.263497999999998	49.247504999999997	0103000020E610000001000000050000006D1CB1169FD44540594C6C3EAE9F48406D1CB1169FD44540DC476E4DBAA1484009FA0B3D62D84540DC476E4DBAA1484009FA0B3D62D84540594C6C3EAE9F48406D1CB1169FD44540594C6C3EAE9F4840
51293	Песчанка	2	22	917	44.021258000000003	44.050587999999998	49.365529000000002	49.345143	0103000020E61000000100000005000000A2630795B8024640BFB854A52DAC4840A2630795B8024640AB5E7EA7C9AE4840F7C8E6AA79064640AB5E7EA7C9AE4840F7C8E6AA79064640BFB854A52DAC4840A2630795B8024640BFB854A52DAC4840
51291	Озерки	2	22	917	43.757188999999997	43.789385000000003	49.416091999999999	49.395218	0103000020E610000001000000050000000AF2B391EBE045403065E08096B248400AF2B391EBE045404910AE8042B54840FB7953910AE545404910AE8042B54840FB7953910AE545403065E08096B248400AF2B391EBE045403065E08096B24840
51359	Новогригорьевская	2	22	917	43.627966000000001	43.651107000000003	49.424584000000003	49.409469000000001	0103000020E61000000100000005000000FE7F9C3061D04540E8DCED7A69B44840FE7F9C3061D04540D333BDC458B648402D99637957D34540D333BDC458B648402D99637957D34540E8DCED7A69B44840FE7F9C3061D04540E8DCED7A69B44840
51580	Медведев	2	22	917	44.202663999999999	44.261997000000001	49.241616999999998	49.224857999999998	0103000020E61000000100000005000000CC09DAE4F01946403A1F9E25C89C4840CC09DAE4F01946402D944C4EED9E48403753211E892146402D944C4EED9E48403753211E892146403A1F9E25C89C4840CC09DAE4F01946403A1F9E25C89C4840
51268	Лог	2	22	917	43.825882999999997	43.874051000000001	49.498711999999998	49.462645999999999	0103000020E6100000010000000500000043A9BD88B6E9454007D0EFFB37BB484043A9BD88B6E94540B60F79CBD5BF48409F0436E7E0EF4540B60F79CBD5BF48409F0436E7E0EF454007D0EFFB37BB484043A9BD88B6E9454007D0EFFB37BB4840
51485	Лог	2	22	917	43.825882999999997	43.874051000000001	49.498711999999998	49.462645999999999	0103000020E6100000010000000500000043A9BD88B6E9454007D0EFFB37BB484043A9BD88B6E94540B60F79CBD5BF48409F0436E7E0EF4540B60F79CBD5BF48409F0436E7E0EF454007D0EFFB37BB484043A9BD88B6E9454007D0EFFB37BB4840
51506	Красноярский	2	22	917	44.073701	44.096555000000002	49.400593999999998	49.391939999999998	0103000020E610000001000000050000005C57CC086F09464043FF04172BB248405C57CC086F094640A67C08AA46B34840F5A10BEA5B0C4640A67C08AA46B34840F5A10BEA5B0C464043FF04172BB248405C57CC086F09464043FF04172BB24840
51559	Краснодонский	2	22	917	44.064807999999999	44.096285000000002	49.204355	49.184337999999997	0103000020E610000001000000050000007442E8A04B0846407CB43863989748407442E8A04B08464015E3FC4D289A4840350C1F11530C464015E3FC4D289A4840350C1F11530C46407CB43863989748407442E8A04B0846407CB4386398974840
51348	Кондраши	2	22	917	44.142845000000001	44.198234999999997	49.443859000000003	49.423822000000001	0103000020E61000000100000005000000D5B2B5BE48124640A4A99ECC3FB64840D5B2B5BE481246408484285FD0B8484016F6B4C35F1946408484285FD0B8484016F6B4C35F194640A4A99ECC3FB64840D5B2B5BE48124640A4A99ECC3FB64840
51380	Колоцкий	2	22	917	43.989502000000002	44.007244	49.269494000000002	49.247728000000002	0103000020E61000000100000005000000CEA96400A8FE4540D926158DB59F4840CEA96400A8FE4540EF3B86C77EA24840CE8B135FED004640EF3B86C77EA24840CE8B135FED004640D926158DB59F4840CEA96400A8FE4540D926158DB59F4840
51563	Качалинская	2	22	917	44.018526999999999	44.049815000000002	49.123629999999999	49.097647000000002	0103000020E61000000100000005000000E78BBD175F024640B9C667B27F8C4840E78BBD175F024640F9669B1BD38F4840D5EC815660064640F9669B1BD38F4840D5EC815660064640B9C667B27F8C4840E78BBD175F024640B9C667B27F8C4840
51290	Качалино	2	22	917	44.053876000000002	44.073521999999997	49.129620000000003	49.110387000000003	0103000020E610000001000000050000000805A568E5064640A8734529218E48400805A568E50646402A745E6397904840ACC43C2B690946402A745E6397904840ACC43C2B69094640A8734529218E48400805A568E5064640A8734529218E4840
51552	Каменский	2	22	917	43.590299999999999	43.611249000000001	49.475320000000004	49.460034	0103000020E61000000100000005000000166A4DF38ECB45402786E464E2BA4840166A4DF38ECB45403F912749D7BC48403A5B40683DCE45403F912749D7BC48403A5B40683DCE45402786E464E2BA4840166A4DF38ECB45402786E464E2BA4840
7291	Иловля	2	22	917	43.967421999999999	44.012974999999997	49.333086000000002	49.284435000000002	0103000020E6100000010000000500000028B7ED7BD4FB45403C6BB75D68A4484028B7ED7BD4FB4540B360E28FA2AA48403255302AA9014640B360E28FA2AA48403255302AA90146403C6BB75D68A4484028B7ED7BD4FB45403C6BB75D68A44840
51471	Городище	2	22	917	43.394395000000003	44.520496000000001	49.659198000000004	48.936101000000001	0103000020E610000001000000050000005C5A0D897BB245405F605628D27748405C5A0D897BB2454058CB9D9960D4484073D9E89C9F42464058CB9D9960D4484073D9E89C9F4246405F605628D27748405C5A0D897BB245405F605628D2774840
51576	Большая Ивановка	2	22	917	44.310372000000001	44.358701000000003	49.470607999999999	49.441110999999999	0103000020E610000001000000050000000CCC0A45BA274640F373435376B848400CCC0A45BA274640349E08E23CBC4840710514EAE92D4640349E08E23CBC4840710514EAE92D4640F373435376B848400CCC0A45BA274640F373435376B84840
51266	Александровка	2	22	917	44.302492999999998	44.327025999999996	49.592678999999997	49.557763000000001	0103000020E610000001000000050000006C223317B82646409DF529C764C748406C223317B82646405303CDE7DCCB48408978EBFCDB2946405303CDE7DCCB48408978EBFCDB2946409DF529C764C748406C223317B82646409DF529C764C74840
51537	Авилов	2	22	917	44.001683	44.026314999999997	49.388064	49.362729999999999	0103000020E61000000100000005000000C6FA06263700464098A3C7EF6DAE4840C6FA062637004640A260C614ACB148407632384A5E034640A260C614ACB148407632384A5E03464098A3C7EF6DAE4840C6FA06263700464098A3C7EF6DAE4840
48757	Фоменково	2	22	471	44.643754000000001	44.661586	50.666410999999997	50.659770999999999	0103000020E61000000100000005000000A855F48766524640B3EC496073544940A855F48766524640EA58A5F44C554940E8BE9CD9AE544640EA58A5F44C554940E8BE9CD9AE544640B3EC496073544940A855F48766524640B3EC496073544940
6323	Тетеревятка	2	22	471	45.119691000000003	45.147350000000003	50.673450000000003	50.652706999999999	0103000020E610000001000000050000001250E108528F4640656F29E78B5349401250E108528F4640E0BE0E9C335649406688635DDC924640E0BE0E9C335649406688635DDC924640656F29E78B5349401250E108528F4640656F29E78B534940
7047	Тарапатино	2	22	471	44.532228000000003	44.562680999999998	50.954497000000003	50.936706000000001	0103000020E61000000100000005000000FC010F0C20444640C6FB71FBE5774940FC010F0C20444640A8902BF52C7A4940508A56EE05484640A8902BF52C7A4940508A56EE05484640C6FB71FBE5774940FC010F0C20444640C6FB71FBE5774940
49305	Романовка	2	22	471	44.274816000000001	44.293078999999999	51.105680999999997	51.090200000000003	0103000020E610000001000000050000007235B22B2D234640B30C71AC8B8B49407235B22B2D2346407F677BF4868D49407B12D89C832546407F677BF4868D49407B12D89C83254640B30C71AC8B8B49407235B22B2D234640B30C71AC8B8B4940
6537	Подчинный	2	22	471	45.213070999999999	45.233822000000004	50.883671999999997	50.869990999999999	0103000020E61000000100000005000000EE5C18E9459B46403C6876DD5B6F4940EE5C18E9459B46400932022A1C714940EC8A19E1ED9D46400932022A1C714940EC8A19E1ED9D46403C6876DD5B6F4940EE5C18E9459B46403C6876DD5B6F4940
6679	Песковка	2	22	471	44.952595000000002	44.979446000000003	51.077491999999999	51.056820999999999	0103000020E61000000100000005000000A4AA09A2EE794640EE5C18E945874940A4AA09A2EE794640CFD90242EB89494059198D7C5E7D4640CFD90242EB89494059198D7C5E7D4640EE5C18E945874940A4AA09A2EE794640EE5C18E945874940
49106	Новинка	2	22	471	45.127882999999997	45.144376000000001	51.025843000000002	51.012363000000001	0103000020E61000000100000005000000705B5B785E90464019575C1C95814940705B5B785E9046404FEACBD24E834940E529ABE97A9246404FEACBD24E834940E529ABE97A92464019575C1C95814940705B5B785E90464019575C1C95814940
6983	Новая Бахметьевка	2	22	471	44.750447000000001	44.776418	51.099499999999999	51.091009	0103000020E61000000100000005000000CF30B5A50E6046402252D32EA68B4940CF30B5A50E604640DBF97E6ABC8C49404B033FAA61634640DBF97E6ABC8C49404B033FAA616346402252D32EA68B4940CF30B5A50E6046402252D32EA68B4940
4282	Нижняя Добринка	2	22	471	44.720075000000001	44.751696000000003	50.853760000000001	50.822315000000003	0103000020E6100000010000000500000067D5E76A2B5C46405001309E4169494067D5E76A2B5C46400551F701486D49405B441493376046400551F701486D49405B441493376046405001309E4169494067D5E76A2B5C46405001309E41694940
51632	Недоступов	2	22	471	44.884970000000003	44.907615999999997	50.661878000000002	50.650410999999998	0103000020E6100000010000000500000077F86BB246714640B5FAEAAA4053494077F86BB24671464090F8156BB8544940C5A9D6C22C74464090F8156BB8544940C5A9D6C22C744640B5FAEAAA4053494077F86BB246714640B5FAEAAA40534940
49220	Моисеево	2	22	471	44.836253999999997	44.861713000000002	50.648721000000002	50.639009999999999	0103000020E610000001000000050000001893FE5E0A6B464092E86514CB5149401893FE5E0A6B46403D9D2B4A09534940DFC4909C4C6E46403D9D2B4A09534940DFC4909C4C6E464092E86514CB5149401893FE5E0A6B464092E86514CB514940
2780	Мельзавод	2	22	471	44.680280000000003	44.693916000000002	50.823658000000002	50.815936000000001	0103000020E61000000100000005000000BB0F406A1357464085D0419770684940BB0F406A135746405D8B16A06D694940E8154F3DD25846405D8B16A06D694940E8154F3DD258464085D0419770684940BB0F406A1357464085D0419770684940
6997	Меловатка	2	22	471	44.681671999999999	44.709772000000001	50.888734999999997	50.869849000000002	0103000020E61000000100000005000000A94C310741574640AABA4736576F4940A94C310741574640C0E78711C2714940EACE13CFD95A4640C0E78711C2714940EACE13CFD95A4640AABA4736576F4940A94C310741574640AABA4736576F4940
30181	Медведицкий	2	22	471	44.692658999999999	44.725797	50.792158999999998	50.770386000000002	0103000020E61000000100000005000000D923D40CA9584640ECA529029C624940D923D40CA9584640B41D537765654940784485EAE65C4640B41D537765654940784485EAE65C4640ECA529029C624940D923D40CA9584640ECA529029C624940
49127	Медведица	2	22	471	44.803213999999997	44.838355999999997	51.1008	51.052970999999999	0103000020E610000001000000050000003CD862B7CF6646407651F4C0C78649403CD862B7CF664640E9B7AF03E78C4940E333D93F4F6B4640E9B7AF03E78C4940E333D93F4F6B46407651F4C0C78649403CD862B7CF6646407651F4C0C7864940
45450	Линево	2	22	471	44.802036999999999	44.847437999999997	50.914330999999997	50.858462000000003	0103000020E610000001000000050000004A97FE25A9664640EC6D3315E26D49404A97FE25A9664640075C57CC087549409EB12FD9786C4640075C57CC087549409EB12FD9786C4640EC6D3315E26D49404A97FE25A9664640EC6D3315E26D4940
48739	Красный Яр	2	22	471	44.698155999999997	44.762197	50.723981999999999	50.671435000000002	0103000020E61000000100000005000000CAC0012D5D594640E4310395F1554940CAC0012D5D59464043723271AB5C4940FE0DDAAB8F61464043723271AB5C4940FE0DDAAB8F614640E4310395F1554940CAC0012D5D594640E4310395F1554940
7101	Кленовка	2	22	471	44.454622999999998	44.497768999999998	51.143448999999997	51.125295999999999	0103000020E6100000010000000500000034812216313A4640E92807B30990494034812216313A46406BD26D895C92494037FB03E5B63F46406BD26D895C92494037FB03E5B63F4640E92807B30990494034812216313A4640E92807B309904940
5911	Жирновск	2	22	471	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
49292	Ершовка	2	22	471	44.306266000000001	44.331141000000002	51.158585000000002	51.144568	0103000020E6100000010000000500000039F06AB933274640290648348192494039F06AB9332746406E5166834C944940B0AE0AD4622A46406E5166834C944940B0AE0AD4622A4640290648348192494039F06AB9332746402906483481924940
6711	Гречихино	2	22	471	44.795318000000002	44.815610999999997	51.155484000000001	51.139837999999997	0103000020E61000000100000005000000C7F5EFFACC654640785E2A36E6914940C7F5EFFACC654640908653E6E693494001A1F5F065684640908653E6E693494001A1F5F065684640785E2A36E6914940C7F5EFFACC654640785E2A36E6914940
49071	Вишневое	2	22	471	45.239840000000001	45.271020999999998	50.766306999999998	50.754626999999999	0103000020E61000000100000005000000E622BE13B39E4640DCD6169E97604940E622BE13B39E464012D9075916624940BDC3EDD0B0A2464012D9075916624940BDC3EDD0B0A24640DCD6169E97604940E622BE13B39E4640DCD6169E97604940
6357	Верхняя Добринка	2	22	471	45.033731000000003	45.077362000000001	50.791088000000002	50.768791	0103000020E6100000010000000500000042EE224C51844640C53A55BE6762494042EE224C518446400821205F4265494001FA7DFFE68946400821205F4265494001FA7DFFE6894640C53A55BE6762494042EE224C51844640C53A55BE67624940
7141	Бутырка	2	22	471	44.478096000000001	44.504911	51.071005999999997	51.053027999999998	0103000020E61000000100000005000000992CEE3F323D4640DAE21A9FC9864940992CEE3F323D4640EEE87FB916894940013274ECA0404640EEE87FB916894940013274ECA0404640DAE21A9FC9864940992CEE3F323D4640DAE21A9FC9864940
6239	Бородачи	2	22	471	44.947223000000001	44.979140000000001	50.661661000000002	50.649799999999999	0103000020E610000001000000050000006F826F9A3E7946406C787AA52C5349406F826F9A3E794640F304C24EB15449404C1AA375547D4640F304C24EB15449404C1AA375547D46406C787AA52C5349406F826F9A3E7946406C787AA52C534940
6918	Большая Князевка	2	22	471	44.736640000000001	44.762323000000002	51.140324	51.125391999999998	0103000020E61000000100000005000000757632384A5E46400B9755D80C904940757632384A5E4640056C0723F69149408BFED0CC93614640056C0723F69149408BFED0CC936146400B9755D80C904940757632384A5E46400B9755D80C904940
49178	Андреевка	2	22	471	44.687448000000003	44.706538000000002	50.991737000000001	50.971975	0103000020E61000000100000005000000AED9CA4BFE574640CAC342AD697C4940AED9CA4BFE574640D89DEE3CF17E4940CDB051D66F5A4640D89DEE3CF17E4940CDB051D66F5A4640CAC342AD697C4940AED9CA4BFE574640CAC342AD697C4940
6476	Алешники	2	22	471	45.158920000000002	45.183982999999998	50.911757999999999	50.890557999999999	0103000020E610000001000000050000001557957D579446407898F6CDFD7149401557957D57944640E5EE737CB47449408E0244C18C974640E5EE737CB47449408E0244C18C9746407898F6CDFD7149401557957D579446407898F6CDFD714940
51652	Александровка	2	22	471	44.736631000000003	44.788482000000002	51.046477000000003	51.011032	0103000020E61000000100000005000000221CB3EC495E4640D09A1F7F69814940221CB3EC495E4640138255F5F28549400ABE69FAEC644640138255F5F28549400ABE69FAEC644640D09A1F7F69814940221CB3EC495E4640D09A1F7F69814940
51510	Щелоковка	2	22	599	44.096842000000002	44.127006999999999	51.051696999999997	51.038707000000002	0103000020E610000001000000050000008B709351650C46402A90D959F48449408B709351650C46409126DE019E86494079AEEFC3411046409126DE019E86494079AEEFC3411046402A90D959F48449408B709351650C46402A90D959F4844940
51408	Хвощинка	2	22	599	44.146805999999998	44.182397999999999	51.09046	51.069575	0103000020E61000000100000005000000A46DFC89CA12464042CF66D5E7884940A46DFC89CA1246404FCC7A31948B49408B6D52D1581746404FCC7A31948B49408B6D52D15817464042CF66D5E7884940A46DFC89CA12464042CF66D5E7884940
5521	Тростянка	2	22	599	43.438386000000001	43.478414999999998	50.834195000000001	50.808497000000003	0103000020E610000001000000050000001B834E081DB8454002F566D47C6749401B834E081DB845404DBED9E6C66A49403A75E5B33CBD45404DBED9E6C66A49403A75E5B33CBD454002F566D47C6749401B834E081DB8454002F566D47C674940
5783	Торяное	2	22	599	43.513629000000002	43.542994999999998	51.041997000000002	51.026001999999998	0103000020E610000001000000050000007BA35698BEC14540B7D09508548349407BA35698BEC14540DBC35E28608549401D7233DC80C54540DBC35E28608549401D7233DC80C54540B7D09508548349407BA35698BEC14540B7D0950854834940
5184	Терса	2	22	599	43.764870000000002	43.840336999999998	50.909742000000001	50.870764000000001	0103000020E6100000010000000500000084D89942E7E145405F44DB31756F494084D89942E7E1454019E6046D72744940334FAE2990EB454019E6046D72744940334FAE2990EB45405F44DB31756F494084D89942E7E145405F44DB31756F4940
4476	Терновое	2	22	599	43.682189000000001	43.731695000000002	51.060330999999998	51.022914	0103000020E6100000010000000500000071581AF851D745406E4F90D8EE82494071581AF851D74540ADF71BEDB8874940C8D2872EA8DD4540ADF71BEDB8874940C8D2872EA8DD45406E4F90D8EE82494071581AF851D745406E4F90D8EE824940
5370	Таловка	2	22	599	43.552453999999997	43.575899999999997	50.618772	50.596299999999999	0103000020E61000000100000005000000AE450BD0B6C645406A4DF38E534C4940AE450BD0B6C645401BD7BFEB334F494019E25817B7C945401BD7BFEB334F494019E25817B7C945406A4DF38E534C4940AE450BD0B6C645406A4DF38E534C4940
5822	Родинское	2	22	599	43.383670000000002	43.398752000000002	50.917738	50.900483000000001	0103000020E61000000100000005000000693A3B191CB145404FCDE50643734940693A3B191CB14540F225547078754940789B374E0AB34540F225547078754940789B374E0AB345404FCDE50643734940693A3B191CB145404FCDE50643734940
46233	Новопетровский	2	22	599	43.823600999999996	43.842286000000001	50.683450000000001	50.671247000000001	0103000020E61000000100000005000000F8F9EFC16BE94540E144F46BEB554940F8F9EFC16BE94540C139234A7B57494078F01307D0EB4540C139234A7B57494078F01307D0EB4540E144F46BEB554940F8F9EFC16BE94540E144F46BEB554940
51493	Новодобринка	2	22	599	44.135702999999999	44.156247999999998	51.037726999999997	51.023904999999999	0103000020E610000001000000050000000B7C45B75E114640FE9AAC510F8349400B7C45B75E1146408D96033DD48449405F0839EFFF1346408D96033DD48449405F0839EFFF134640FE9AAC510F8349400B7C45B75E114640FE9AAC510F834940
4405	Набат	2	22	599	43.736590999999997	43.761609	50.984048999999999	50.970551999999998	0103000020E6100000010000000500000093C3279D48DE4540A088450C3B7C494093C3279D48DE4540AC545051F57D49406DAB59677CE14540AC545051F57D49406DAB59677CE14540A088450C3B7C494093C3279D48DE4540A088450C3B7C4940
4629	Морец	2	22	599	43.969163999999999	44.072955999999998	51.037042	51.001334	0103000020E61000000100000005000000F33AE2900DFC4540BA2F67B62B804940F33AE2900DFC45400A4AD1CABD8449400306499F560946400A4AD1CABD8449400306499F56094640BA2F67B62B804940F33AE2900DFC4540BA2F67B62B804940
51646	Красноталовский	2	22	599	43.500540000000001	43.549570000000003	50.794840999999998	50.750433000000001	0103000020E61000000100000005000000802BD9B111C045406A6B44300E604940802BD9B111C045408D429259BD6549406E6E4C4F58C645408D429259BD6549406E6E4C4F58C645406A6B44300E604940802BD9B111C045406A6B44300E604940
5017	Краишево	2	22	599	43.904567	43.957397	50.864693000000003	50.815776999999997	0103000020E610000001000000050000003A05F9D9C8F345401CEA77616B6849403A05F9D9C8F34540420A9E42AE6E4940EE2422FC8BFA4540420A9E42AE6E4940EE2422FC8BFA45401CEA77616B6849403A05F9D9C8F345401CEA77616B684940
5579	Ивановка	2	22	599	43.63138	43.674742000000002	50.830173000000002	50.806955000000002	0103000020E610000001000000050000009BAC510FD1D04540FE2B2B4D4A6749409BAC510FD1D04540D882DE1B436A49406B9E23F25DD64540D882DE1B436A49406B9E23F25DD64540FE2B2B4D4A6749409BAC510FD1D04540FE2B2B4D4A674940
5163	Журавка	2	22	599	43.840184000000001	43.87247	50.863852000000001	50.846071000000002	0103000020E61000000100000005000000AD4F39268BEB4540098CF50D4C6C4940AD4F39268BEB4540C74ACCB3926E4940DD5ED218ADEF4540C74ACCB3926E4940DD5ED218ADEF4540098CF50D4C6C4940AD4F39268BEB4540098CF50D4C6C4940
3785	Елань	2	22	599	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
51415	Елань	2	22	599	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
5613	Дубовое	2	22	599	43.595033999999998	43.634605000000001	50.975616000000002	50.954593000000003	0103000020E610000001000000050000000801F9122ACC4540CAFE791A307A49400801F9122ACC454028BA2EFCE07C4940657094BC3AD1454028BA2EFCE07C4940657094BC3AD14540CAFE791A307A49400801F9122ACC4540CAFE791A307A4940
5048	Вязовка	2	22	599	43.895511999999997	43.991703000000001	50.906942000000001	50.864942999999997	0103000020E6100000010000000500000078962023A0F24540BAF3C473B66E494078962023A0F2454036AFEAAC167449402C2CB81FF0FE454036AFEAAC167449402C2CB81FF0FE4540BAF3C473B66E494078962023A0F24540BAF3C473B66E4940
5690	Волково	2	22	599	43.566037000000001	43.602480999999997	51.000275000000002	50.984099999999998	0103000020E61000000100000005000000B9A981E673C845402EFF21FDF67D4940B9A981E673C84540D200DE02098049400EBBEF181ECD4540D200DE02098049400EBBEF181ECD45402EFF21FDF67D4940B9A981E673C845402EFF21FDF67D4940
4582	Водопьяново	2	22	599	43.852652999999997	43.886043000000001	51.051828	51.036158	0103000020E610000001000000050000000BEBC6BB23ED454090BE49D3A08449400BEBC6BB23ED45403082C64CA2864940C4EC65DB69F145403082C64CA2864940C4EC65DB69F1454090BE49D3A08449400BEBC6BB23ED454090BE49D3A0844940
4929	Большой Морец	2	22	599	43.810585000000003	43.889465999999999	50.934901000000004	50.906902000000002	0103000020E6100000010000000500000068D0D03FC1E74540A8565F5D1574494068D0D03FC1E74540B5FF01D6AA774940B4739A05DAF14540B5FF01D6AA774940B4739A05DAF14540A8565F5D1574494068D0D03FC1E74540A8565F5D15744940
5291	Большевик	2	22	599	43.743893999999997	43.778371	50.649102999999997	50.636319	0103000020E6100000010000000500000066D828EB37DF45406669A7E67251494066D828EB37DF4540245E9ECE15534940D19332A9A1E34540245E9ECE15534940D19332A9A1E345406669A7E67251494066D828EB37DF45406669A7E672514940
4486	Березовка	2	22	599	43.911034000000001	44.016945999999997	51.103012	50.850068999999998	0103000020E61000000100000005000000A4C519C39CF44540F52B9D0FCF6C4940A4C519C39CF445403B8C497F2F8D494025E659492B0246403B8C497F2F8D494025E659492B024640F52B9D0FCF6C4940A4C519C39CF44540F52B9D0FCF6C4940
5744	Бабинкино	2	22	599	43.543551999999998	43.574032000000003	51.027973000000003	51.006402000000001	0103000020E6100000010000000500000073D6A71C93C545408350DEC7D180494073D6A71C93C54540E415889E94834940C26D6DE179C94540E415889E94834940C26D6DE179C945408350DEC7D180494073D6A71C93C545408350DEC7D1804940
51679	Алявы	2	22	599	43.723305000000003	43.748807999999997	50.768352999999998	50.746248999999999	0103000020E6100000010000000500000043041C4295DC45401BD65416855F494043041C4295DC454049641F6459624940D87DC7F0D8DF454049641F6459624940D87DC7F0D8DF45401BD65416855F494043041C4295DC45401BD65416855F4940
51684	Челюскинец	2	22	348	44.644221000000002	44.663660999999998	49.048738	49.036673	0103000020E61000000100000005000000BE326FD575524640B7D26BB3B1844840BE326FD5755246404609FA0B3D864840B950F9D7F25446404609FA0B3D864840B950F9D7F2544640B7D26BB3B1844840BE326FD575524640B7D26BB3B1844840
3015	Усть-Погожье	2	22	348	44.603932	44.624647000000003	49.488278999999999	49.465263	0103000020E610000001000000050000000281CEA44D4D4640F984ECBC8DBB48400281CEA44D4D46406B2920ED7FBE4840B345D26EF44F46406B2920ED7FBE4840B345D26EF44F4640F984ECBC8DBB48400281CEA44D4D4640F984ECBC8DBB4840
3020	Суводская	2	22	348	45.047493000000003	45.062925999999997	49.492725999999998	49.482666000000002	0103000020E61000000100000005000000FCE42840148646401172DEFFC7BD4840FCE4284014864640C7F143A511BF4840B7088CF50D884640C7F143A511BF4840B7088CF50D8846401172DEFFC7BD4840FCE42840148646401172DEFFC7BD4840
2903	Стрельноширокое	2	22	348	44.933208999999998	44.955784000000001	49.321496000000003	49.297055999999998	0103000020E610000001000000050000009BAA7B6473774640508A56EE05A648409BAA7B6473774640BDE5EAC726A9484021054F21577A4640BDE5EAC726A9484021054F21577A4640508A56EE05A648409BAA7B6473774640508A56EE05A64840
46858	Семеновка	2	22	348	44.613436	44.634698999999998	49.525688000000002	49.509493999999997	0103000020E6100000010000000500000033182312854E46400DC1711937C1484033182312854E464028F38FBE49C34840E6E61BD13D51464028F38FBE49C34840E6E61BD13D5146400DC1711937C1484033182312854E46400DC1711937C14840
48065	Садки	2	22	348	44.404246000000001	44.433576000000002	49.193916999999999	49.177748000000001	0103000020E61000000100000005000000F8C43A55BE334640F7764B72C0964840F8C43A55BE334640B891B245D29848404E2A1A6B7F374640B891B245D29848404E2A1A6B7F374640F7764B72C0964840F8C43A55BE334640F7764B72C0964840
48095	Родники	2	22	348	44.905703000000003	44.927945000000001	49.314971999999997	49.302508000000003	0103000020E61000000100000005000000CE716E13EE734640A2630795B8A64840CE716E13EE734640EE93A30051A848404DBED9E6C6764640EE93A30051A848404DBED9E6C6764640A2630795B8A64840CE716E13EE734640A2630795B8A64840
29901	Прямая Балка	2	22	348	44.705495999999997	44.737349999999999	49.240282000000001	49.222262999999998	0103000020E61000000100000005000000BABA63B14D5A4640300E2E1D739C4840BABA63B14D5A4640A3E8818FC19E484051DA1B7C615E4640A3E8818FC19E484051DA1B7C615E4640300E2E1D739C4840BABA63B14D5A4640300E2E1D739C4840
3366	Полунино	2	22	348	44.901077000000001	44.923786	49.641368	49.626629999999999	0103000020E61000000100000005000000C216BB7D56734640A3586E6935D04840C216BB7D56734640B859BC5818D248405740A19E3E764640B859BC5818D248405740A19E3E764640A3586E6935D04840C216BB7D56734640A3586E6935D04840
2592	Пичуга	2	22	348	44.694895000000002	44.724727999999999	48.997033000000002	48.976877999999999	0103000020E61000000100000005000000B493C151F258464048179B560A7D4840B493C151F2584640320400C79E7F48406C3F19E3C35C4640320400C79E7F48406C3F19E3C35C464048179B560A7D4840B493C151F258464048179B560A7D4840
48118	Петропавловка	2	22	348	44.517280999999997	44.532184000000001	49.451115000000001	49.443922999999998	0103000020E61000000100000005000000CCEB8843364246409A780778D2B84840CCEB88433642464016DEE522BEB948402CBAF59A1E44464016DEE522BEB948402CBAF59A1E4446409A780778D2B84840CCEB8843364246409A780778D2B84840
51267	Песковатка	2	22	348	44.841760999999998	44.872644999999999	49.124008000000003	49.102742999999997	0103000020E610000001000000050000002D060FD3BE6B46404B72C0AE268D48402D060FD3BE6B4640A038807EDF8F48404B02D4D4B26F4640A038807EDF8F48404B02D4D4B26F46404B72C0AE268D48402D060FD3BE6B46404B72C0AE268D4840
47806	Оленье	2	22	348	44.860517999999999	44.884681999999998	49.188299999999998	49.170302999999997	0103000020E6100000010000000500000046CF2D74256E464091B41B7DCC95484046CF2D74256E46401CEBE2361A98484010AE80423D7146401CEBE2361A98484010AE80423D71464091B41B7DCC95484046CF2D74256E464091B41B7DCC954840
19499	Малая Ивановка	2	22	348	44.512852000000002	44.545326000000003	49.367494000000001	49.346269999999997	0103000020E6100000010000000500000017D86322A5414640FFCA4A9352AC484017D86322A5414640F5BC1B0B0AAF48404AD40B3ECD454640F5BC1B0B0AAF48404AD40B3ECD454640FFCA4A9352AC484017D86322A5414640FFCA4A9352AC4840
1739	Лозное	2	22	348	44.407614000000002	44.443339999999999	49.297508999999998	49.278264	0103000020E6100000010000000500000025B20FB22C344640BBD39D279EA3484025B20FB22C34464001A260C614A648401B81785DBF38464001A260C614A648401B81785DBF384640BBD39D279EA3484025B20FB22C344640BBD39D279EA34840
3230	Караваинка	2	22	348	45.212783000000002	45.238591999999997	49.730260999999999	49.720413000000001	0103000020E6100000010000000500000088122D793C9B46407F4E417E36DC484088122D793C9B4640AA45443179DD48402A8BC22E8A9E4640AA45443179DD48402A8BC22E8A9E46407F4E417E36DC484088122D793C9B46407F4E417E36DC4840
1882	Дубовка	2	22	348	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
46252	Давыдовка	2	22	348	44.629534	44.655943999999998	49.308024000000003	49.288395999999999	0103000020E610000001000000050000002BDCF291945046400B26FE28EAA448402BDCF291945046400A3197546DA74840F30016F9F55346400A3197546DA74840F30016F9F55346400B26FE28EAA448402BDCF291945046400B26FE28EAA44840
3128	Горный Балыклей	2	22	348	45.037675	45.106279000000001	49.567334000000002	49.541362999999997	0103000020E610000001000000050000003B70CE88D2844640D921FE614BC548403B70CE88D284464056F487669EC8484034A0DE8C9A8D464056F487669EC8484034A0DE8C9A8D4640D921FE614BC548403B70CE88D2844640D921FE614BC54840
2797	Горноводяное	2	22	348	44.913797000000002	44.951678999999999	49.262605000000001	49.247599000000001	0103000020E610000001000000050000006A17D34CF7744640DBC2F352B19F48406A17D34CF77446400F62670A9DA148401EA5129ED07946400F62670A9DA148401EA5129ED0794640DBC2F352B19F48406A17D34CF7744640DBC2F352B19F4840
2937	Горная Пролейка	2	22	348	44.956708999999996	44.993594000000002	49.391395000000003	49.372222000000001	0103000020E61000000100000005000000F964C570757A4640056D72F8A4AF4840F964C570757A4640B2683A3B19B248403CC093162E7F4640B2683A3B19B248403CC093162E7F4640056D72F8A4AF4840F964C570757A4640056D72F8A4AF4840
3384	Варькино	2	22	348	45.059207000000001	45.080264	49.693848000000003	49.678887000000003	0103000020E61000000100000005000000DE58501894874640FC56EBC4E5D64840DE585018948746409032E202D0D84840E8853B17468A46409032E202D0D84840E8853B17468A4640FC56EBC4E5D64840DE58501894874640FC56EBC4E5D64840
51452	Бойкие Дворики	2	22	348	44.574530000000003	44.5854	49.223244999999999	49.212135000000004	0103000020E610000001000000050000001349F4328A49464022AB5B3D279B48401349F4328A4946406DFFCA4A939C4840098A1F63EE4A46406DFFCA4A939C4840098A1F63EE4A464022AB5B3D279B48401349F4328A49464022AB5B3D279B4840
1030	Сергиевская	2	22	145	43.757548	43.816468999999998	50.241638999999999	50.227032999999999	0103000020E610000001000000050000003A933655F7E045406F0ED76A0F1D49403A933655F7E045401538D906EE1E49405299620E82E845401538D906EE1E49405299620E82E845406F0ED76A0F1D49403A933655F7E045406F0ED76A0F1D4940
51334	Рогачи	2	22	145	44.128588000000001	44.175030999999997	50.179344999999998	50.170096999999998	0103000020E610000001000000050000003B54539275104640E8120EBDC51549403B54539275104640BED9E6C6F4164940A164726A67164640BED9E6C6F4164940A164726A67164640E8120EBDC51549403B54539275104640E8120EBDC5154940
593	Профсоюзник	2	22	145	43.816198999999997	43.83616	50.504204999999999	50.489645000000003	0103000020E610000001000000050000009203763579E8454031D3F6AFAC3E49409203763579E8454066BD18CA89404940971C774A07EB454066BD18CA89404940971C774A07EB454031D3F6AFAC3E49409203763579E8454031D3F6AFAC3E4940
51262	Попов	2	22	145	44.416615	44.436557999999998	50.378461999999999	50.357421000000002	0103000020E61000000100000005000000F302ECA353354640AAF3A8F8BF2D4940F302ECA353354640AE635C71713049405167EE21E1374640AE635C71713049405167EE21E1374640AAF3A8F8BF2D4940F302ECA353354640AAF3A8F8BF2D4940
51347	Плотников 1-й	2	22	145	43.920645999999998	43.976934999999997	50.304681000000002	50.276417000000002	0103000020E61000000100000005000000BB9866BAD7F545407B87DBA161234940BB9866BAD7F54540365B79C9FF264940ACA8C1340CFD4540365B79C9FF264940ACA8C1340CFD45407B87DBA161234940BB9866BAD7F545407B87DBA161234940
51483	Островская	2	22	145	44.382415999999999	44.464036999999998	50.451467999999998	50.422317	0103000020E61000000100000005000000CBBBEA01F3304640BDC5C37B0E364940CBBBEA01F3304640639813B4C939494025917D90653B4640639813B4C939494025917D90653B4640BDC5C37B0E364940CBBBEA01F3304640BDC5C37B0E364940
807	Орехово	2	22	145	44.400077000000003	44.437806999999999	50.488137999999999	50.460608999999998	0103000020E61000000100000005000000DF701FB935334640239F573CF53A4940DF701FB935334640A9F7544E7B3E4940DD7A4D0F0A384640A9F7544E7B3E4940DD7A4D0F0A384640239F573CF53A4940DF701FB935334640239F573CF53A4940
480	Миусово	2	22	145	44.047767	44.06559	50.433340000000001	50.416289999999996	0103000020E61000000100000005000000FD69A33A1D0646406FD39FFD48354940FD69A33A1D0646403A0664AF77374940EA78CC40650846403A0664AF77374940EA78CC40650846406FD39FFD48354940FD69A33A1D0646406FD39FFD48354940
51336	Ловягин	2	22	145	44.027096999999998	44.060639999999999	50.319206000000001	50.298777000000001	0103000020E61000000100000005000000EC681CEA7703464004E621533E264940EC681CEA77034640EF5701BEDB2849402B6A300DC3074640EF5701BEDB2849402B6A300DC307464004E621533E264940EC681CEA7703464004E621533E264940
691	Лобойково	2	22	145	44.191102000000001	44.228876	50.472867999999998	50.447487000000002	0103000020E61000000100000005000000A019C407761846404D31074147394940A019C4077618464097A949F0863C49406E6B0BCF4B1D464097A949F0863C49406E6B0BCF4B1D46404D31074147394940A019C407761846404D31074147394940
51393	Кувшинов	2	22	145	44.218922999999997	44.251092	50.198053999999999	50.185066999999997	0103000020E61000000100000005000000CDAB3AAB051C4640CF488446B0174940CDAB3AAB051C4640C66B5ED559194940C4245CC823204640C66B5ED559194940C4245CC823204640CF488446B0174940CDAB3AAB051C4640CF488446B0174940
51391	Красный	2	22	145	44.123683999999997	44.140554000000002	50.338366000000001	50.328470000000003	0103000020E61000000100000005000000EC8497E0D40F4640CBDB114E0B2A4940EC8497E0D40F4640070ABC934F2B494037A968ACFD114640070ABC934F2B494037A968ACFD114640CBDB114E0B2A4940EC8497E0D40F4640CBDB114E0B2A4940
51335	Каменный	2	22	145	44.324367000000002	44.346834000000001	50.384855000000002	50.368108999999997	0103000020E6100000010000000500000069739CDB842946407F2E1A321E2F494069739CDB84294640DE59BBED423149400892770E652C4640DE59BBED423149400892770E652C46407F2E1A321E2F494069739CDB842946407F2E1A321E2F4940
51509	Каменночерновский	2	22	145	44.217001000000003	44.245468000000002	50.419131	50.402093999999998	0103000020E61000000100000005000000831953B0C61B46407BF5F1D077334940831953B0C61B4640B1DEA815A6354940761BD47E6B1F4640B1DEA815A6354940761BD47E6B1F46407BF5F1D077334940831953B0C61B46407BF5F1D077334940
51306	Заполянский	2	22	145	43.772829000000002	43.801512000000002	50.224198000000001	50.203375999999999	0103000020E610000001000000050000004033880FECE2454049658A39081A49404033880FECE2454010EA2285B21C494000ADF9F197E6454010EA2285B21C494000ADF9F197E6454049658A39081A49404033880FECE2454049658A39081A4940
51332	Заплавка	2	22	145	43.930753000000003	43.960800999999996	50.389093000000003	50.370401999999999	0103000020E61000000100000005000000B3D30FEA22F74540BE2F2E55692F4940B3D30FEA22F74540200DA7CCCD314940677BF486FBFA4540200DA7CCCD314940677BF486FBFA4540BE2F2E55692F4940B3D30FEA22F74540BE2F2E55692F4940
51692	Даниловка	2	22	145	44.093733999999998	44.13944	50.373556000000001	50.345821999999998	0103000020E61000000100000005000000FA42C879FF0B4640601E32E5432C4940FA42C879FF0B4640BF9CD9AED02F49408BE07F2BD9114640BF9CD9AED02F49408BE07F2BD9114640601E32E5432C4940FA42C879FF0B4640601E32E5432C4940
28213	Даниловка	2	22	145	44.093733999999998	44.13944	50.373556000000001	50.345821999999998	0103000020E61000000100000005000000FA42C879FF0B4640601E32E5432C4940FA42C879FF0B4640BF9CD9AED02F49408BE07F2BD9114640BF9CD9AED02F49408BE07F2BD9114640601E32E5432C4940FA42C879FF0B4640601E32E5432C4940
1850	Грязнуха	2	22	145	44.026404999999997	44.049751999999998	50.708337999999998	50.693317	0103000020E61000000100000005000000B6B9313D610346406361889CBE584940B6B9313D61034640CC41D0D1AA5A49408E7406465E064640CC41D0D1AA5A49408E7406465E0646406361889CBE584940B6B9313D610346406361889CBE584940
51325	Горин	2	22	145	43.848897999999998	43.876987999999997	50.270896	50.257122000000003	0103000020E61000000100000005000000E5D18DB0A8EC4540838AAA5FE9204940E5D18DB0A8EC4540014F5AB8AC224940027E8D2441F04540014F5AB8AC224940027E8D2441F04540838AAA5FE9204940E5D18DB0A8EC4540838AAA5FE9204940
51346	Гончары	2	22	145	43.950848000000001	43.967961000000003	50.464221999999999	50.448937999999998	0103000020E61000000100000005000000C7BB2363B5F9454040F7E5CC76394940C7BB2363B5F94540B70A62A06B3B4940D8666325E6FB4540B70A62A06B3B4940D8666325E6FB454040F7E5CC76394940C7BB2363B5F9454040F7E5CC76394940
51258	Бобры	2	22	145	43.999977000000001	44.020691999999997	50.325319	50.313402000000004	0103000020E6100000010000000500000048E00F3FFFFF45402140868E1D28494048E00F3FFFFF45403BE2900DA4294940F8A41309A60246403BE2900DA4294940F8A41309A60246402140868E1D28494048E00F3FFFFF45402140868E1D284940
1200	Березовская	2	22	145	43.962139999999998	43.998044999999998	50.283192999999997	50.247658999999999	0103000020E6100000010000000500000033164D6727FB4540B0C7444AB31F494033164D6727FB454062BA10AB3F244940D97745F0BFFF454062BA10AB3F244940D97745F0BFFF4540B0C7444AB31F494033164D6727FB4540B0C7444AB31F4940
51288	Белые Пруды	2	22	145	44.020656000000002	44.045009	50.579566999999997	50.566358000000001	0103000020E61000000100000005000000AC3B16DBA4024640FBE93F6B7E484940AC3B16DBA4024640A06B5F402F4A49404983DBDAC2054640A06B5F402F4A49404983DBDAC2054640FBE93F6B7E484940AC3B16DBA4024640FBE93F6B7E484940
51333	Атамановка	2	22	145	44.052455999999999	44.098387000000002	50.179310000000001	50.159277000000003	0103000020E610000001000000050000004F3DD2E0B6064640A4005130631449404F3DD2E0B606464042EC4CA1F316494000ADF9F1970C464042EC4CA1F316494000ADF9F1970C4640A4005130631449404F3DD2E0B6064640A400513063144940
51717	Царицын	2	22	3	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
31935	Степной	2	22	3	44.204092000000003	44.233241999999997	48.858606999999999	48.842771999999997	0103000020E6100000010000000500000008B0C8AF1F1A464004FEF0F3DF6B484008B0C8AF1F1A4640EF8E8CD5E66D4840DD06B5DFDA1D4640EF8E8CD5E66D4840DD06B5DFDA1D464004FEF0F3DF6B484008B0C8AF1F1A464004FEF0F3DF6B4840
32368	Самофаловка	2	22	3	44.200526000000004	44.229469000000002	48.961975000000002	48.936421000000003	0103000020E61000000100000005000000B5FF01D6AA194640D124B1A4DC774840B5FF01D6AA194640E9482EFF217B484011397D3D5F1D4640E9482EFF217B484011397D3D5F1D4640D124B1A4DC774840B5FF01D6AA194640D124B1A4DC774840
5	Сады Придонья	2	22	3	44.001998	44.040624999999999	49.060605000000002	49.041007999999998	0103000020E610000001000000050000002654707841004640EB6F09C03F8548402654707841004640AF7C96E7C18748403333333333054640AF7C96E7C18748403333333333054640EB6F09C03F8548402654707841004640EB6F09C03F854840
32007	Россошка	2	22	3	44.135567999999999	44.158709000000002	48.833877000000001	48.822952000000001	0103000020E610000001000000050000002B31CF4A5A114640C216BB7D566948402B31CF4A5A1146407CF1457BBC6A48405A4A9693501446407CF1457BBC6A48405A4A969350144640C216BB7D566948402B31CF4A5A114640C216BB7D56694840
51369	Радужный	2	22	3	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
306	Песковатка	2	22	3	43.796975000000003	43.828048000000003	48.920527999999997	48.894111000000002	0103000020E61000000100000005000000645DDC4603E6454037FFAF3A72724840645DDC4603E64540B1868BDCD375484055C2137AFDE94540B1868BDCD375484055C2137AFDE9454037FFAF3A72724840645DDC4603E6454037FFAF3A72724840
166	Паньшино	2	22	3	44.007863999999998	44.138820000000003	49.046635999999999	49.018343000000002	0103000020E610000001000000050000006A6803B001014640268E3C10598248406A6803B0010146407B681F2BF8854840EF0390DAC41146407B681F2BF8854840EF0390DAC4114640268E3C10598248406A6803B001014640268E3C1059824840
31539	Орловка	2	22	3	44.521645999999997	44.579597	48.858173999999998	48.837328999999997	0103000020E610000001000000050000006B0BCF4BC5424640067FBF982D6B48406B0BCF4BC5424640852348A5D86D48400BEE073C304A4640852348A5D86D48400BEE073C304A4640067FBF982D6B48406B0BCF4BC5424640067FBF982D6B4840
51622	Областная сельскохозяйственная опытная станция	2	22	3	44.372373000000003	44.392549000000002	48.889626999999997	48.878833	0103000020E61000000100000005000000EB7420EBA92F4640A2D288997D704840EB7420EBA92F4640BD512B4CDF714840EC89AE0B3F324640BD512B4CDF714840EC89AE0B3F324640A2D288997D704840EB7420EBA92F4640A2D288997D704840
31777	Новый Рогачик	2	22	3	44.044424999999997	44.073135000000001	48.691000000000003	48.659154000000001	0103000020E61000000100000005000000F90FE9B7AF054640888384285F544840F90FE9B7AF0546409CC420B072584840B398D87C5C0946409CC420B072584840B398D87C5C094640888384285F544840F90FE9B7AF054640888384285F544840
32023	Новая Надежда	2	22	3	44.292943999999999	44.309553999999999	48.844580999999998	48.835413000000003	0103000020E610000001000000050000009BC761307F2546409ED32CD0EE6A48409BC761307F25464057E9EE3A1B6C4840492C29779F27464057E9EE3A1B6C4840492C29779F2746409ED32CD0EE6A48409BC761307F2546409ED32CD0EE6A4840
32282	Кузьмичи	2	22	3	44.348415000000003	44.385308999999999	48.953828999999999	48.893211000000001	0103000020E61000000100000005000000CA37DBDC982C4640B7B6F0BC54724840CA37DBDC982C4640FA7C9411177A48405FED28CE51314640FA7C9411177A48405FED28CE51314640B7B6F0BC54724840CA37DBDC982C4640B7B6F0BC54724840
51713	Красный Пахарь	2	22	3	44.224815999999997	44.239477000000001	48.805599000000001	48.795873	0103000020E610000001000000050000000BCF4BC5C61C46407C629D2ADF6548400BCF4BC5C61C46405C5837DE1D6748407592AD2EA71E46405C5837DE1D6748407592AD2EA71E46407C629D2ADF6548400BCF4BC5C61C46407C629D2ADF654840
32436	Котлубань	2	22	3	44.218411000000003	44.243051999999999	49.036638000000004	49.008049999999997	0103000020E61000000100000005000000180B43E4F41B4640CC5D4BC807814840180B43E4F41B46403BE5D18DB08448401B9DF3531C1F46403BE5D18DB08448401B9DF3531C1F4640CC5D4BC807814840180B43E4F41B4640CC5D4BC807814840
31917	Карповка	2	22	3	43.967106999999999	43.997776000000002	48.715646	48.696072999999998	0103000020E61000000100000005000000C85D8429CAFB4540765089EB18594840C85D8429CAFB4540B1C1C2499A5B4840EA5DBC1FB7FF4540B1C1C2499A5B4840EA5DBC1FB7FF4540765089EB18594840C85D8429CAFB4540765089EB18594840
31717	Каменный	2	22	3	44.548352999999999	44.577889999999996	48.991079999999997	48.973100000000002	0103000020E61000000100000005000000EDD45C6E304646406ADE718A8E7C4840EDD45C6E304646401EDC9DB5DB7E4840BC57AD4CF84946401EDC9DB5DB7E4840BC57AD4CF84946406ADE718A8E7C4840EDD45C6E304646406ADE718A8E7C4840
31580	Ерзовка	2	22	3	44.622069000000003	44.667676	48.948776000000002	48.924469999999999	0103000020E610000001000000050000007F6DFDF49F4F46400A117008557648407F6DFDF49F4F4640679DF17D717948407C293C6876554640679DF17D717948407C293C68765546400A117008557648407F6DFDF49F4F46400A11700855764840
51499	Ерзовка	2	22	3	44.622069000000003	44.667676	48.948776000000002	48.924469999999999	0103000020E610000001000000050000007F6DFDF49F4F46400A117008557648407F6DFDF49F4F4640679DF17D717948407C293C6876554640679DF17D717948407C293C68765546400A117008557648407F6DFDF49F4F46400A11700855764840
51617	Донской	2	22	3	43.959291999999998	43.974643999999998	49.000030000000002	48.992486999999997	0103000020E610000001000000050000003FA88B14CAFA4540425A63D0097F48403FA88B14CAFA45406B82A8FB008048400E9F7422C1FC45406B82A8FB008048400E9F7422C1FC4540425A63D0097F48403FA88B14CAFA4540425A63D0097F4840
51630	Грачи	2	22	3	44.294120999999997	44.313740000000003	48.965955000000001	48.947243999999998	0103000020E610000001000000050000008D08C6C1A525464086AA984A3F7948408D08C6C1A52546402F34D769A47B484039B9DFA1282846402F34D769A47B484039B9DFA12828464086AA984A3F7948408D08C6C1A525464086AA984A3F794840
51703	Городище 2	2	22	3	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
30858	Городище	2	22	3	44.442504999999997	44.536738	48.824191999999996	48.778320000000001	0103000020E6100000010000000500000082A8FB00A43846404FE960FD9F63484082A8FB00A4384640FACF9A1F7F6948409E42AED4B3444640FACF9A1F7F6948409E42AED4B34446404FE960FD9F63484082A8FB00A43846404FE960FD9F634840
195	Вертячий	2	22	3	43.874698000000002	43.928578999999999	48.953082999999999	48.933141999999997	0103000020E6100000010000000500000035F0A31AF6EF4540134372327177484035F0A31AF6EF4540D1AFAD9FFE7948404E603AADDBF64540D1AFAD9FFE7948404E603AADDBF64540134372327177484035F0A31AF6EF45401343723271774840
51683	Варламов	2	22	3	44.314773000000002	44.338112000000002	49.031433999999997	49.022070999999997	0103000020E61000000100000005000000F8544E7B4A2846405298F738D3824840F8544E7B4A284640C1FD8007068448404D310741472B4640C1FD8007068448404D310741472B46405298F738D3824840F8544E7B4A2846405298F738D3824840
30725	Краснооктябрьский	2	22	1901	44.729382000000001	44.779111999999998	48.889727999999998	48.860646000000003	0103000020E610000001000000050000004225AE635C5D464074B7EBA5296E48404225AE635C5D4640F12A6B9BE2714840E8F527F1B9634640F12A6B9BE2714840E8F527F1B963464074B7EBA5296E48404225AE635C5D464074B7EBA5296E4840
32172	Студено-Яблоневка	2	22	1923	44.355117	44.372787000000002	48.718237000000002	48.712482999999999	0103000020E6100000010000000500000077A04E79742D46405DFA97A4325B484077A04E79742D46407AE3A430EF5B4840DEAF027CB72F46407AE3A430EF5B4840DEAF027CB72F46405DFA97A4325B484077A04E79742D46405DFA97A4325B4840
51494	Соляной	2	22	1923	44.427259999999997	44.447526000000003	48.443120999999998	48.434669	0103000020E61000000100000005000000C971A774B0364640E2CAD93BA3374840C971A774B0364640DD955D30B83848400B0E2F8848394640DD955D30B83848400B0E2F8848394640E2CAD93BA3374840C971A774B0364640E2CAD93BA3374840
51522	Майский	2	22	1923	44.176630000000003	44.187939999999998	48.553147000000003	48.540573999999999	0103000020E610000001000000050000000ABFD4CF9B164640B1886187314548400ABFD4CF9B164640B5705985CD4648401CCEFC6A0E184640B5705985CD4648401CCEFC6A0E184640B1886187314548400ABFD4CF9B164640B188618731454840
51474	Горный	2	22	1923	44.230817000000002	44.246834	48.589303999999998	48.575249999999997	0103000020E61000000100000005000000302E55698B1D46401283C0CAA1494840302E55698B1D464074B33F506E4B48403BC5AA41981F464074B33F506E4B48403BC5AA41981F46401283C0CAA1494840302E55698B1D46401283C0CAA1494840
46646	Солянка	2	22	1346	45.370330000000003	45.393084000000002	49.747238000000003	49.740822999999999	0103000020E61000000100000005000000255D33F966AF4640F38FBE49D3DE4840255D33F966AF46400B2AAA7EA5DF48405A4A969350B246400B2AAA7EA5DF48405A4A969350B24640F38FBE49D3DE4840255D33F966AF4640F38FBE49D3DE4840
51604	Солдатско-Степное	2	22	1346	45.489455	45.533931000000003	49.542813000000002	49.516922000000001	0103000020E610000001000000050000008DEE2076A6BE46409D4A06802AC248408DEE2076A6BE4640FD6B79E57AC5484009A9DBD957C44640FD6B79E57AC5484009A9DBD957C446409D4A06802AC248408DEE2076A6BE46409D4A06802AC24840
51647	Садовое	2	22	1346	45.915678999999997	45.933663000000003	49.683188999999999	49.673121999999999	0103000020E6100000010000000500000026512FF834F54640EB1B98DC28D6484026512FF834F5464054FEB5BC72D748401D3EE94482F7464054FEB5BC72D748401D3EE94482F74640EB1B98DC28D6484026512FF834F54640EB1B98DC28D64840
48570	Раздолье	2	22	1346	45.444971000000002	45.466081000000003	49.772779	49.759652000000003	0103000020E610000001000000050000008F554ACFF4B84640A62BD8463CE148408F554ACFF4B846408E041A6CEAE24840BC24CE8AA8BB46408E041A6CEAE24840BC24CE8AA8BB4640A62BD8463CE148408F554ACFF4B84640A62BD8463CE14840
51673	Приморск	2	22	1346	45.012531000000003	45.049964000000003	49.281737999999997	49.242640999999999	0103000020E61000000100000005000000D597A59D9A81464099D53BDC0E9F4840D597A59D9A8146402D05A4FD0FA448401AFD6838658646402D05A4FD0FA448401AFD68386586464099D53BDC0E9F4840D597A59D9A81464099D53BDC0E9F4840
51660	Победа	2	22	1346	45.453415	45.468649999999997	49.656450999999997	49.643864000000001	0103000020E610000001000000050000000742B28009BA46402F89B3226AD248400742B28009BA464097361C9606D448409CA223B9FCBB464097361C9606D448409CA223B9FCBB46402F89B3226AD248400742B28009BA46402F89B3226AD24840
51363	Песчаный	2	22	1346	45.453468999999998	45.472405000000002	49.886232	49.876334999999997	0103000020E61000000100000005000000FA5FAE450BBA46408AABCABE2BF04840FA5FAE450BBA46409755D80C70F14840C3BB5CC477BC46409755D80C70F14840C3BB5CC477BC46408AABCABE2BF04840FA5FAE450BBA46408AABCABE2BF04840
51653	Новоникольское	2	22	1346	44.989642000000003	45.029096000000003	49.208004000000003	49.183095000000002	0103000020E61000000100000005000000C05FCC96AC7E4640D3872EA86F974840C05FCC96AC7E4640F6B704E09F9A4840E338F06AB9834640F6B704E09F9A4840E338F06AB9834640D3872EA86F974840C05FCC96AC7E4640D3872EA86F974840
51619	Луговая Пролейка	2	22	1346	45.064435000000003	45.083516000000003	49.357033000000001	49.341545000000004	0103000020E61000000100000005000000E0DBF4673F884640618E1EBFB7AB4840E0DBF4673F884640E04BE141B3AD4840AC58FCA6B08A4640E04BE141B3AD4840AC58FCA6B08A4640618E1EBFB7AB4840E0DBF4673F884640618E1EBFB7AB4840
51613	Красноселец	2	22	1346	45.728749000000001	45.758132000000003	49.672626000000001	49.654648999999999	0103000020E6100000010000000500000011FFB0A547DD4640F7ADD689CBD3484011FFB0A547DD46403B38D89B18D648408A0629780AE146403B38D89B18D648408A0629780AE14640F7ADD689CBD3484011FFB0A547DD4640F7ADD689CBD34840
51486	Кислово	2	22	1346	45.369126000000001	45.400548999999998	49.909762000000001	49.877763000000002	0103000020E61000000100000005000000390D51853FAF4640C651B9895AF04840390D51853FAF46406092CA1473F4484006B98B3045B346406092CA1473F4484006B98B3045B34640C651B9895AF04840390D51853FAF4640C651B9895AF04840
51424	Катричев	2	22	1346	45.528613	45.573231999999997	49.396279	49.373624	0103000020E61000000100000005000000C79E3D97A9C34640178046E9D2AF4840C79E3D97A9C34640B98B3045B9B24840A5828AAA5FC94640B98B3045B9B24840A5828AAA5FC94640178046E9D2AF4840C79E3D97A9C34640178046E9D2AF4840
51473	Зеленый	2	22	1346	45.342948999999997	45.355435999999997	49.620455	49.608226999999999	0103000020E610000001000000050000001399B9C0E5AB4640A8C5E061DACD48401399B9C0E5AB4640E1D1C6116BCF484018E945ED7EAD4640E1D1C6116BCF484018E945ED7EAD4640A8C5E061DACD48401399B9C0E5AB4640A8C5E061DACD4840
49438	Заволжский	2	22	1346	45.462631999999999	45.482968999999997	49.916066999999998	49.909413999999998	0103000020E61000000100000005000000A20A7F8637BB464024438EAD67F44840A20A7F8637BB4640F0F8F6AE41F54840ACFD9DEDD1BD4640F0F8F6AE41F54840ACFD9DEDD1BD464024438EAD67F44840A20A7F8637BB464024438EAD67F44840
51686	Демидов	2	22	1346	45.357098000000001	45.379689999999997	49.2318	49.219043999999997	0103000020E61000000100000005000000C7BB2363B5AD4640483140A2099C4840C7BB2363B5AD46403D9B559FAB9D4840224F92AE99B046403D9B559FAB9D4840224F92AE99B04640483140A2099C4840C7BB2363B5AD4640483140A2099C4840
51715	Верхний Балыклей	2	22	1346	45.158946999999998	45.192813999999998	49.552498	49.522933999999999	0103000020E610000001000000050000000E66136058944640B5FB5580EFC248400E661360589446407E8D2441B8C64840001B1021AE9846407E8D2441B8C64840001B1021AE984640B5FB5580EFC248400E66136058944640B5FB5580EFC24840
51470	Быково	2	22	1346	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
51708	Быково	2	22	1346	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
40257	Александровка	2	22	1346	45.632188999999997	45.653326	49.803806999999999	49.789600999999998	0103000020E610000001000000050000000AF2B391EBD04640C7F143A511E548400AF2B391EBD04640DFA5D425E3E6484031D0B52FA0D34640DFA5D425E3E6484031D0B52FA0D34640C7F143A511E548400AF2B391EBD04640C7F143A511E54840
12512	Яминский	2	22	521	42.203327999999999	42.353158000000001	50.343471000000001	50.177995000000003	0103000020E61000000100000005000000382EE3A6061A4540FFEC478AC8164940382EE3A6061A4540ED0F94DBF62B49400F290648342D4540ED0F94DBF62B49400F290648342D4540FFEC478AC8164940382EE3A6061A4540FFEC478AC8164940
13761	Шарашенский	2	22	521	42.672536000000001	42.709322	50.219113999999998	50.179403000000001	0103000020E61000000100000005000000FBB0DEA815564540F3E670ADF6164940FBB0DEA815564540410C74ED0B1C4940AA2A3410CB5A4540410C74ED0B1C4940AA2A3410CB5A4540F3E670ADF6164940FBB0DEA815564540F3E670ADF6164940
13416	Чечеровский	2	22	521	42.244678	42.260344000000003	50.283313999999997	50.261747	0103000020E610000001000000050000007D06D49B511F4540BE69FAEC802149407D06D49B511F4540DD3F16A243244940DCDAC2F352214540DD3F16A243244940DCDAC2F352214540BE69FAEC802149407D06D49B511F4540BE69FAEC80214940
13837	Усть-Бузулукская	2	22	521	42.114376999999998	42.184930999999999	50.199230999999997	50.173985999999999	0103000020E610000001000000050000001135D1E7A30E45401EFB592C451649401135D1E7A30E4540B8ACC266801949401F82AAD1AB174540B8ACC266801949401F82AAD1AB1745401EFB592C451649401135D1E7A30E45401EFB592C45164940
14042	Трехложинский	2	22	521	42.030627000000003	42.066380000000002	50.081842000000002	50.069921999999998	0103000020E61000000100000005000000F3AFE595EB034540ADA23F34F3084940F3AFE595EB03454039B874CC790A4940E38DCC237F08454039B874CC790A4940E38DCC237F084540ADA23F34F3084940F3AFE595EB034540ADA23F34F3084940
13889	Титовский	2	22	521	42.244570000000003	42.270341999999999	50.183047999999999	50.173541	0103000020E6100000010000000500000097CADB114E1F4540F0C16B973616494097CADB114E1F454092CCEA1D6E1749401C5E10919A22454092CCEA1D6E1749401C5E10919A224540F0C16B973616494097CADB114E1F4540F0C16B9736164940
13476	Стеженский	2	22	521	42.130214000000002	42.152420999999997	50.305509000000001	50.271845999999996	0103000020E610000001000000050000009DBD33DAAA10454032C687D9CB2249409DBD33DAAA1045401CD13DEB1A2749409F1C0588821345401CD13DEB1A2749409F1C05888213454032C687D9CB2249409DBD33DAAA10454032C687D9CB224940
51540	Солонцовский	2	22	521	42.388173999999999	42.422589000000002	50.191890000000001	50.159905999999999	0103000020E61000000100000005000000299485AFAF3145409337C0CC77144940299485AFAF314540F836FDD98F1849401E53776517364540F836FDD98F1849401E537765173645409337C0CC77144940299485AFAF3145409337C0CC77144940
13485	Самолшинский	2	22	521	42.054639000000002	42.071446000000002	50.382148999999998	50.357863000000002	0103000020E61000000100000005000000070B2769FE06454067B96C74CE2D4940070B2769FE0645407C992842EA3049400BB77C24250945407C992842EA3049400BB77C242509454067B96C74CE2D4940070B2769FE06454067B96C74CE2D4940
51330	Рябовский	2	22	521	41.855517999999996	41.911042999999999	50.020583000000002	50.000425	0103000020E61000000100000005000000D591239D81ED4440E78C28ED0D004940D591239D81ED444042EDB776A2024940F71F990E9DF4444042EDB776A2024940F71F990E9DF44440E78C28ED0D004940D591239D81ED4440E78C28ED0D004940
14066	Реченский	2	22	521	42.013164000000003	42.053165999999997	50.186520000000002	50.169606000000002	0103000020E6100000010000000500000006BEA25BAF0145404A9A3FA6B515494006BEA25BAF01454064062AE3DF1749402BA1BB24CE06454064062AE3DF1749402BA1BB24CE0645404A9A3FA6B515494006BEA25BAF0145404A9A3FA6B5154940
13563	Поклоновский	2	22	521	42.133915000000002	42.153875999999997	50.411135999999999	50.396965999999999	0103000020E61000000100000005000000D0B8702024114540DDCF29C8CF324940D0B8702024114540A81ABD1AA0344940D4D17135B2134540A81ABD1AA0344940D4D17135B2134540DDCF29C8CF324940D0B8702024114540DDCF29C8CF324940
13352	Ларинский	2	22	521	42.230187999999998	42.255690999999999	50.255065999999999	50.229562999999999	0103000020E6100000010000000500000040F7E5CC761D454092AF0452621D494040F7E5CC761D45402829B000A6204940D670917BBA2045402829B000A6204940D670917BBA20454092AF0452621D494040F7E5CC761D454092AF0452621D4940
48284	Красный Октябрь	2	22	521	42.518331000000003	42.539388000000002	50.333927000000003	50.316674999999996	0103000020E6100000010000000500000062C092AB58424540FB3A70CE8828494062C092AB584245402E20B41EBE2A49406CED7DAA0A4545402E20B41EBE2A49406CED7DAA0A454540FB3A70CE8828494062C092AB58424540FB3A70CE88284940
13610	Исакиевский	2	22	521	42.178175000000003	42.220692999999997	50.475430000000003	50.463287000000001	0103000020E610000001000000050000007FFB3A70CE164540BBD408FD4C3B49407FFB3A70CE164540C6C4E6E3DA3C494062BA10AB3F1C4540C6C4E6E3DA3C494062BA10AB3F1C4540BBD408FD4C3B49407FFB3A70CE164540BBD408FD4C3B4940
14178	Ежовка	2	22	521	41.680948999999998	41.722146000000002	50.008617999999998	49.975166999999999	0103000020E61000000100000005000000389F3A5629D74440B891B245D2FC4840389F3A5629D74440161406651A014940F777B6476FDC4440161406651A014940F777B6476FDC4440B891B245D2FC4840389F3A5629D74440B891B245D2FC4840
13643	Большой Бабинский	2	22	521	42.250498999999998	42.266829999999999	50.377128999999996	50.365633000000003	0103000020E610000001000000050000002157EA591020454050ABE80FCD2E49402157EA5910204540C4AF58C345304940BCCB457C27224540C4AF58C345304940BCCB457C2722454050ABE80FCD2E49402157EA591020454050ABE80FCD2E4940
13927	Аржановская	2	22	521	42.340491999999998	42.360632000000003	50.122270999999998	50.109886000000003	0103000020E610000001000000050000005A46EA3D952B4540E62494BE100E49405A46EA3D952B4540E61F7D93A60F49400FF27A30292E4540E61F7D93A60F49400FF27A30292E4540E62494BE100E49405A46EA3D952B4540E62494BE100E4940
47387	Алексеевская	2	22	521	42.171537000000001	42.204352	50.31335	50.280096	0103000020E61000000100000005000000E886A6ECF4154540C6DE8B2FDA234940E886A6ECF4154540CE1951DA1B284940A46FD234281A4540CE1951DA1B284940A46FD234281A4540C6DE8B2FDA234940E886A6ECF4154540C6DE8B2FDA234940
57104	Харабали	2	21	\N	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
57122	Солянка	2	21	\N	45.871777999999999	45.882576	48.521152999999998	48.509455000000003	0103000020E61000000100000005000000A7AFE76B96EF464050E449D235414840A7AFE76B96EF46402C9B3924B5424840041E1840F8F046402C9B3924B5424840041E1840F8F0464050E449D235414840A7AFE76B96EF464050E449D235414840
57134	Сокрутовка	2	21	\N	46.519122000000003	46.557903000000003	47.926482999999998	47.898412	0103000020E610000001000000050000002B51F69672424740BF2A172AFFF247402B51F6967242474065A6B4FE96F647408FAB915D6947474065A6B4FE96F647408FAB915D69474740BF2A172AFFF247402B51F69672424740BF2A172AFFF24740
57136	Образцово-Травино	2	21	\N	47.982199000000001	48.011457	45.984862999999997	45.935651	0103000020E61000000100000005000000FB9463B2B8FD47401FBC7669C3F74640FB9463B2B8FD47402D05A4FD0FFE4640B727486C770148402D05A4FD0FFE4640B727486C770148401FBC7669C3F74640FB9463B2B8FD47401FBC7669C3F74640
57113	Нариманов	2	21	\N	47.841945000000003	47.862535000000001	46.699393000000001	46.684088000000003	0103000020E61000000100000005000000EF0390DAC4EB474004CB113290574740EF0390DAC4EB47409206B7B585594740E353008C67EE47409206B7B585594740E353008C67EE474004CB113290574740EF0390DAC4EB474004CB113290574740
57131	Мумра	2	21	\N	47.645941999999998	47.684272999999997	45.787852000000001	45.763078999999998	0103000020E61000000100000005000000718E3A3AAED24740D7A19A92ACE14640718E3A3AAED247404A0B9755D8E446409544F64196D747404A0B9755D8E446409544F64196D74740D7A19A92ACE14640718E3A3AAED24740D7A19A92ACE14640
57133	Красный Яр	2	21	\N	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
57109	Камызяк	2	21	\N	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
15786	Ахтубинск	2	21	\N	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
3394	Астрахань	2	21	\N	47.877643999999997	48.230853000000003	46.559125000000002	46.233547999999999	0103000020E61000000100000005000000EBC37AA356F04740EA059FE6E41D4740EBC37AA356F0474021B07268914747407D9752978C1D484021B07268914747407D9752978C1D4840EA059FE6E41D4740EBC37AA356F04740EA059FE6E41D4740
15153	Черный Яр	2	21	1383	46.084257000000001	46.123359999999998	48.080641	48.043444000000001	0103000020E61000000100000005000000C3BAF1EEC80A47408D9AAF928F054840C3BAF1EEC80A4740BEDBBC71520A484039D1AE42CA0F4740BEDBBC71520A484039D1AE42CA0F47408D9AAF928F054840C3BAF1EEC80A47408D9AAF928F054840
15849	Ушаковка	2	21	1383	45.098939999999999	45.133884000000002	48.438536999999997	48.417701999999998	0103000020E610000001000000050000001422E010AA8C4640A5BC5642773548401422E010AA8C4640008BFCFA2138484095BA641C23914640008BFCFA2138484095BA641C23914640A5BC5642773548401422E010AA8C4640A5BC564277354840
15609	Ступино	2	21	1383	45.781516000000003	45.795287000000002	48.310417999999999	48.299823000000004	0103000020E610000001000000050000007FA65EB708E4464058CB9D99602648407FA65EB708E446407C0BEBC6BB2748408CF7E3F6CBE546407C0BEBC6BB2748408CF7E3F6CBE5464058CB9D99602648407FA65EB708E4464058CB9D9960264840
15410	Старица	2	21	1383	45.913226999999999	45.967852999999998	48.234316999999997	48.205088000000003	0103000020E610000001000000050000007F69519FE4F44640AA66D652401A48407F69519FE4F44640CBF27519FE1D4840F12A6B9BE2FB4640CBF27519FE1D4840F12A6B9BE2FB4640AA66D652401A48407F69519FE4F44640AA66D652401A4840
15733	Солодники	2	21	1383	45.258569999999999	45.321263999999999	48.418156000000003	48.399459999999998	0103000020E6100000010000000500000005DD5ED218A14640B3075A812133484005DD5ED218A146402750C42286354840EAB0C22D1FA946402750C42286354840EAB0C22D1FA94640B3075A812133484005DD5ED218A14640B3075A8121334840
15120	Соленое Займище	2	21	1383	46.125839999999997	46.143725000000003	47.928812999999998	47.906168000000001	0103000020E61000000100000005000000AA436E861B10474043572250FDF34740AA436E861B104740C18C2958E3F647400E4FAF9465124740C18C2958E3F647400E4FAF946512474043572250FDF34740AA436E861B10474043572250FDF34740
15512	Поды	2	21	1383	45.876080999999999	45.901952999999999	48.261214000000002	48.247357000000001	0103000020E61000000100000005000000D0D2156C23F04640E5B7E864A91F4840D0D2156C23F04640F1A0D9756F214840B9C3263273F34640F1A0D9756F214840B9C3263273F34640E5B7E864A91F4840D0D2156C23F04640E5B7E864A91F4840
15696	Каменный Яр	2	21	1383	45.551690999999998	45.578200000000002	48.450347000000001	48.434161000000003	0103000020E61000000100000005000000AF3F89CF9DC646406E19709692374840AF3F89CF9DC64640056D72F8A43948400B46257502CA4640056D72F8A43948400B46257502CA46406E19709692374840AF3F89CF9DC646406E19709692374840
15353	Зубовка	2	21	1383	46.023513000000001	46.052160000000001	48.153756000000001	48.132033999999997	0103000020E61000000100000005000000F303577902034740E3FA777DE6104840F3035779020347402AC8CF46AE1348406614CB2DAD0647402AC8CF46AE1348406614CB2DAD064740E3FA777DE6104840F303577902034740E3FA777DE6104840
15637	Вязовка	2	21	1383	45.590929000000003	45.619512999999998	48.325133999999998	48.310209	0103000020E6100000010000000500000006A1BC8FA3CB464062F6B2EDB427484006A1BC8FA3CB4640A968ACFD9D2948403239B5334CCF4640A968ACFD9D2948403239B5334CCF464062F6B2EDB427484006A1BC8FA3CB464062F6B2EDB4274840
14033	Чапчачи	2	21	996	47.114193	47.135941000000003	47.538088999999999	47.527078000000003	0103000020E61000000100000005000000503750E09D8E47407638BA4A77C34740503750E09D8E47402EABB019E0C44740C097C283669147402EABB019E0C44740C097C283669147407638BA4A77C34740503750E09D8E47407638BA4A77C34740
14918	Хошеутово	2	21	996	47.799095999999999	47.828048000000003	47.046149	47.023885	0103000020E61000000100000005000000A52E19C748E64740B7EEE6A90E834740A52E19C748E647401EDFDE35E885474055C2137AFDE947401EDFDE35E885474055C2137AFDE94740B7EEE6A90E834740A52E19C748E64740B7EEE6A90E834740
14090	Харабали	2	21	996	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
14549	Тамбовка	2	21	996	47.356622000000002	47.392294	47.323504	47.304419000000003	0103000020E610000001000000050000005E8429CAA5AD4740F9A3A833F7A647405E8429CAA5AD474006103E9468A94740613596B036B2474006103E9468A94740613596B036B24740F9A3A833F7A647405E8429CAA5AD4740F9A3A833F7A64740
57149	Сероглазово	2	21	996	47.692537999999999	47.708069000000002	47.154673000000003	47.139558999999998	0103000020E610000001000000050000005E9ECE15A5D84740656EBE11DD9147405E9ECE15A5D8474080492A53CC934740DD274701A2DA474080492A53CC934740DD274701A2DA4740656EBE11DD9147405E9ECE15A5D84740656EBE11DD914740
14641	Селитренное	2	21	996	47.435780999999999	47.478504999999998	47.178412000000002	47.155940999999999	0103000020E61000000100000005000000ED9BFBABC7B74740828DEBDFF5934740ED9BFBABC7B74740639B5434D69647407AFCDEA63FBD4740639B5434D69647407AFCDEA63FBD4740828DEBDFF5934740ED9BFBABC7B74740828DEBDFF5934740
13948	Сасыколи	2	21	996	46.974550000000001	47.016312999999997	47.555453999999997	47.541240000000002	0103000020E610000001000000050000008D28ED0DBE7C4740BEA4315A47C547408D28ED0DBE7C47405837DE1D19C74740F4BF5C8B168247405837DE1D19C74740F4BF5C8B16824740BEA4315A47C547408D28ED0DBE7C4740BEA4315A47C54740
15070	Речное	2	21	996	47.612695000000002	47.624248000000001	46.935777999999999	46.925334999999997	0103000020E610000001000000050000001CB62DCA6CCE47400D6C9560717647401CB62DCA6CCE47407C28D192C7774740F54BC45BE7CF47407C28D192C7774740F54BC45BE7CF47400D6C9560717647401CB62DCA6CCE47400D6C956071764740
13819	Михайловка	2	21	996	46.864471000000002	46.873966000000003	47.655380000000001	47.638553000000002	0103000020E6100000010000000500000093AB58FCA66E4740A0E1CD1ABCD1474093AB58FCA66E4740EB39E97DE3D3474071E82D1EDE6F4740EB39E97DE3D3474071E82D1EDE6F4740A0E1CD1ABCD1474093AB58FCA66E4740A0E1CD1ABCD14740
14991	Лапас	2	21	996	47.826529999999998	47.836196000000001	46.954419000000001	46.948593000000002	0103000020E61000000100000005000000D9942BBCCBE94740761BD47E6B794740D9942BBCCBE947402CD7DB662A7A4740E485747808EB47402CD7DB662A7A4740E485747808EB4740761BD47E6B794740D9942BBCCBE94740761BD47E6B794740
13969	Кочковатка	2	21	996	47.017885	47.047699999999999	47.551951000000003	47.535606999999999	0103000020E61000000100000005000000630B410E4A8247401C412AC58EC44740630B410E4A8247404CFF9254A6C6474075029A081B8647404CFF9254A6C6474075029A081B8647401C412AC58EC44740630B410E4A8247401C412AC58EC44740
15029	Заволжское	2	21	996	47.604151999999999	47.628819999999997	46.990808000000001	46.963563999999998	0103000020E6100000010000000500000010E84CDA54CD47402DCDAD10567B474010E84CDA54CD4740BE4EEACBD27E47400D897B2C7DD04740BE4EEACBD27E47400D897B2C7DD047402DCDAD10567B474010E84CDA54CD47402DCDAD10567B4740
14740	Вольное	2	21	996	47.626340999999996	47.662174999999998	47.148287000000003	47.130296999999999	0103000020E610000001000000050000006C921FF12BD047402AE27492AD9047406C921FF12BD0474003B68311FB924740499D8026C2D4474003B68311FB924740499D8026C2D447402AE27492AD9047406C921FF12BD047402AE27492AD904740
13881	Бугор	2	21	996	46.910086999999997	46.932580999999999	47.567115999999999	47.549590999999999	0103000020E61000000100000005000000E3C116BB7D744740859675FF58C64740E3C116BB7D744740E884D04197C847407CEF6FD05E774740E884D04197C847407CEF6FD05E774740859675FF58C64740E3C116BB7D744740859675FF58C64740
14586	Ашулук	2	21	996	47.389284000000004	47.403936000000002	47.322068999999999	47.309837999999999	0103000020E61000000100000005000000946DE00ED4B147406E8786C5A8A74740946DE00ED4B147401807978E39A94740AAD6C22CB4B347401807978E39A94740AAD6C22CB4B347406E8786C5A8A74740946DE00ED4B147406E8786C5A8A74740
57146	Ахтубинка	2	21	996	47.773305000000001	47.780914000000003	47.075209000000001	47.068550000000002	0103000020E61000000100000005000000A96A82A8FBE247400612143FC6884740A96A82A8FBE24740B4AED172A0894740897E6DFDF4E34740B4AED172A0894740897E6DFDF4E347400612143FC6884740A96A82A8FBE247400612143FC6884740
57141	с.Яманцуг	2	21	7418	47.951467999999998	48.456949999999999	46.464438999999999	46.122253000000001	0103000020E61000000100000005000000639813B4C9F94740406B7EFCA50F4740639813B4C9F9474054FEB5BC723B47401FF46C567D3A484054FEB5BC723B47401FF46C567D3A4840406B7EFCA50F4740639813B4C9F94740406B7EFCA50F4740
57115	с.Растопуловка	2	21	1232	48.032622000000003	48.036969999999997	46.505740000000003	46.504382	0103000020E61000000100000005000000A8902BF52C0448407558E1968F404740A8902BF52C044840B8239C16BC4047407077D66EBB044840B8239C16BC4047407077D66EBB0448407558E1968F404740A8902BF52C0448407558E1968F404740
57143	п.Ассадулаево	2	21	1232	47.951467999999998	48.456949999999999	46.464438999999999	46.122253000000001	0103000020E61000000100000005000000639813B4C9F94740406B7EFCA50F4740639813B4C9F9474054FEB5BC723B47401FF46C567D3A484054FEB5BC723B47401FF46C567D3A4840406B7EFCA50F4740639813B4C9F94740406B7EFCA50F4740
13389	Яксатово	2	21	1232	48.000560999999998	48.027645	46.251555000000003	46.234575999999997	0103000020E61000000100000005000000975302621200484097361C96061E47409753026212004840991249F432204740EF7211DF89034840991249F432204740EF7211DF8903484097361C96061E4740975302621200484097361C96061E4740
13114	Фунтово 1-е	2	21	1232	48.096581999999998	48.111665000000002	46.236147000000003	46.223860000000002	0103000020E61000000100000005000000EEB089CC5C0C4840F870C971A71C4740EEB089CC5C0C484036069D103A1E4740CE8DE9094B0E484036069D103A1E4740CE8DE9094B0E4840F870C971A71C4740EEB089CC5C0C4840F870C971A71C4740
13520	Татарская Башмаковка	2	21	1232	47.962023000000002	48.011035	46.255543000000003	46.225824000000003	0103000020E61000000100000005000000FA7FD59123FB4740725303CDE71C4740FA7FD59123FB474062DC0DA2B5204740410E4A986901484062DC0DA2B5204740410E4A9869014840725303CDE71C4740FA7FD59123FB4740725303CDE71C4740
57142	Стеклозавода	2	21	1232	47.916586000000002	48.230853000000003	46.559001000000002	46.236626999999999	0103000020E6100000010000000500000059FCA6B052F54740E02C25CB491E474059FCA6B052F5474035B742588D4747407D9752978C1D484035B742588D4747407D9752978C1D4840E02C25CB491E474059FCA6B052F54740E02C25CB491E4740
13670	Пойменный	2	21	1232	48.182792999999997	48.198684	46.463546000000001	46.455264	0103000020E610000001000000050000000778D2C265174840E8853B17463A47400778D2C2651748408718AF79553B4740861E317A6E1948408718AF79553B4740861E317A6E194840E8853B17463A47400778D2C265174840E8853B17463A4740
12694	Начало	2	21	1232	48.218843	48.230744999999999	46.294960000000003	46.287936000000002	0103000020E61000000100000005000000B1FA230C031C4840A8AB3B16DB244740B1FA230C031C484068D0D03FC1254740965B5A0D891D484068D0D03FC1254740965B5A0D891D4840A8AB3B16DB244740B1FA230C031C4840A8AB3B16DB244740
57106	Кирпичный Завод №1	2	21	1232	48.067844999999998	48.085281000000002	46.263922999999998	46.251336000000002	0103000020E610000001000000050000003B191C25AF0848405B272EC72B2047403B191C25AF084840C3D4963AC82147402FFCE07CEA0A4840C3D4963AC82147402FFCE07CEA0A48405B272EC72B2047403B191C25AF0848405B272EC72B204740
12675	Килинчи	2	21	1232	48.230035999999998	48.258791000000002	46.299525000000003	46.284180999999997	0103000020E610000001000000050000008A73D4D1711D48408192020B602447408A73D4D1711D4840CEAACFD556264740E4BF401020214840CEAACFD556264740E4BF4010202148408192020B602447408A73D4D1711D48408192020B60244740
13270	Евпраксино	2	21	1232	48.186225	48.201532	46.240031000000002	46.232306999999999	0103000020E610000001000000050000004B598638D6174840E1D05B3CBC1D47404B598638D61748405A83F755B91E47407A8CF2CCCB1948405A83F755B91E47407A8CF2CCCB194840E1D05B3CBC1D47404B598638D6174840E1D05B3CBC1D4740
13235	Водяновка	2	21	1232	48.164971000000001	48.176873000000001	46.245727000000002	46.236172000000003	0103000020E61000000100000005000000EBE40CC51D1548408F1D54E23A1E4740EBE40CC51D154840425F7AFB731F4740D04543C6A3164840425F7AFB731F4740D04543C6A31648408F1D54E23A1E4740EBE40CC51D1548408F1D54E23A1E4740
13184	Веселая Грива	2	21	1232	48.201774999999998	48.207326000000002	46.194378999999998	46.188895000000002	0103000020E61000000100000005000000401361C3D319484060B01BB62D184740401361C3D3194840BC033C69E118474025CE8AA8891A4840BC033C69E118474025CE8AA8891A484060B01BB62D184740401361C3D319484060B01BB62D184740
12773	Болдинский	2	21	1232	48.260057000000003	48.268006999999997	46.325251999999999	46.318648000000003	0103000020E61000000100000005000000460C3B8C49214840C9772975C9284740460C3B8C49214840B37A87DBA1294740AE0CAA0D4E224840B37A87DBA1294740AE0CAA0D4E224840C9772975C9284740460C3B8C49214840C9772975C9284740
12638	Бирюковка	2	21	1232	48.310308999999997	48.327188	46.324629999999999	46.312044	0103000020E61000000100000005000000C5538F34B8274840DE74CB0EF1274740C5538F34B827484076A6D0798D29474063D2DF4BE129484076A6D0798D29474063D2DF4BE1294840DE74CB0EF1274740C5538F34B8274840DE74CB0EF1274740
13458	Атал	2	21	1232	48.018141	48.028328000000002	46.197504000000002	46.185307999999999	0103000020E61000000100000005000000BEDBBC7152024840F5D72B2CB8174740BEDBBC7152024840236AA2CF47194740D2C77C40A0034840236AA2CF47194740D2C77C40A0034840F5D72B2CB8174740BEDBBC7152024840F5D72B2CB8174740
11751	Янго-Аскер	2	21	1186	47.632162000000001	47.661752	46.256914000000002	46.252021999999997	0103000020E6100000010000000500000011E335AFEAD04740AEEFC3414220474011E335AFEAD0474039F1D58EE220474003081F4AB4D4474039F1D58EE220474003081F4AB4D44740AEEFC3414220474011E335AFEAD04740AEEFC34142204740
11837	Туркменка	2	21	1186	47.454143000000002	47.466971000000001	46.252862999999998	46.249279999999999	0103000020E610000001000000050000008A5A9A5B21BA474000C63368E81F47408A5A9A5B21BA474029AF95D05D2047401897AAB4C5BB474029AF95D05D2047401897AAB4C5BB474000C63368E81F47408A5A9A5B21BA474000C63368E81F4740
57132	Тулугановка	2	21	1186	48.050964999999998	48.058304999999997	46.541269999999997	46.534816999999997	0103000020E61000000100000005000000CD1E680586064840232C2AE274444740CD1E6805860648402827DA5548454740BD18CA89760748402827DA5548454740BD18CA8976074840232C2AE274444740CD1E680586064840232C2AE274444740
11446	Тинаки	2	21	1186	47.873997000000003	47.941434000000001	46.409270999999997	46.385205999999997	0103000020E61000000100000005000000ACE63922DFEF47408A1C226E4E314740ACE63922DFEF4740C119FCFD62344740D6ABC8E880F84740C119FCFD62344740D6ABC8E880F847408A1C226E4E314740ACE63922DFEF47408A1C226E4E314740
11410	Рассвет	2	21	1186	47.922946000000003	47.963540999999999	46.564956000000002	46.542999000000002	0103000020E61000000100000005000000ADFC321823F647405F61C1FD80454740ADFC321823F64740E9D66B7A5048474075ADBD4F55FB4740E9D66B7A5048474075ADBD4F55FB47405F61C1FD80454740ADFC321823F647405F61C1FD80454740
11486	Разночиновка	2	21	1186	47.899078000000003	47.924616999999998	46.652000000000001	46.623536999999999	0103000020E61000000100000005000000CC46E7FC14F34740486C770FD04F4740CC46E7FC14F34740FA7E6ABC74534740AE2990D959F64740FA7E6ABC74534740AE2990D959F64740486C770FD04F4740CC46E7FC14F34740486C770FD04F4740
12208	Прикаспийский	2	21	1186	47.170140000000004	47.200547999999998	46.227307000000003	46.220092999999999	0103000020E61000000100000005000000E8DEC325C79547400D8AE6012C1C4740E8DEC325C795474071935165181D47409CA38E8EAB99474071935165181D47409CA38E8EAB9947400D8AE6012C1C4740E8DEC325C79547400D8AE6012C1C4740
11626	Петропавловка	2	21	1186	47.770232999999998	47.790840000000003	46.841453000000001	46.818950000000001	0103000020E6100000010000000500000065A6B4FE96E247409487855AD368474065A6B4FE96E24740800F5EBBB46B4740302FC03E3AE54740800F5EBBB46B4740302FC03E3AE547409487855AD368474065A6B4FE96E247409487855AD3684740
12046	Новокучергановка	2	21	1186	47.867179	47.892853000000002	46.293534000000001	46.285674999999998	0103000020E610000001000000050000009563B2B8FFEE4740742497FF902447409563B2B8FFEE4740CD21A985922547405891D10149F24740CD21A985922547405891D10149F24740742497FF902447409563B2B8FFEE4740742497FF90244740
12538	Николаевка	2	21	1186	47.707881	47.740507999999998	46.334268999999999	46.330461	0103000020E61000000100000005000000DA3A38D89BDA47403ECDC98B4C2A4740DA3A38D89BDA474087889B53C92A4740933655F7C8DE474087889B53C92A4740933655F7C8DE47403ECDC98B4C2A4740DA3A38D89BDA47403ECDC98B4C2A4740
11535	Нижнелебяжье	2	21	1186	47.879845000000003	47.896490999999997	46.702514000000001	46.684156000000002	0103000020E610000001000000050000004A46CEC29EF047405CAE7E6C925747404A46CEC29EF04740B77D8FFAEB59474044149337C0F24740B77D8FFAEB59474044149337C0F247405CAE7E6C925747404A46CEC29EF047405CAE7E6C92574740
12292	Нариманов	2	21	1186	47.841945000000003	47.862535000000001	46.699393000000001	46.684088000000003	0103000020E61000000100000005000000EF0390DAC4EB474004CB113290574740EF0390DAC4EB47409206B7B585594740E353008C67EE47409206B7B585594740E353008C67EE474004CB113290574740EF0390DAC4EB474004CB113290574740
11792	Линейное	2	21	1186	47.401699000000001	47.450369999999999	46.261699	46.251030999999998	0103000020E61000000100000005000000FFEA71DF6AB347401EA4A7C821204740FFEA71DF6AB34740AD32535A7F214740BD8C62B9A5B94740AD32535A7F214740BD8C62B9A5B947401EA4A7C821204740FFEA71DF6AB347401EA4A7C821204740
11693	Курченко	2	21	1186	47.517007	47.554332000000002	46.234695000000002	46.231484000000002	0103000020E61000000100000005000000CB660E492DC247400DC68844A11D4740CB660E492DC2474072C45A7C0A1E47402A90D959F4C6474072C45A7C0A1E47402A90D959F4C647400DC68844A11D4740CB660E492DC247400DC68844A11D4740
11297	Волжское	2	21	1186	47.848593000000001	47.886825000000002	46.677553000000003	46.633772999999998	0103000020E61000000100000005000000A94E07B29EEC47403D0B42791F514740A94E07B29EEC47404227840EBA5647403A234A7B83F147404227840EBA5647403A234A7B83F147403D0B42791F514740A94E07B29EEC47403D0B42791F514740
11355	Верхнелебяжье	2	21	1186	47.799401000000003	47.816631000000001	46.759217	46.746782000000003	0103000020E61000000100000005000000E2B19FC552E64740E99E758D965F4740E2B19FC552E647409BC8CC052E6147402CF3565D87E847409BC8CC052E6147402CF3565D87E84740E99E758D965F4740E2B19FC552E64740E99E758D965F4740
12186	Буруны	2	21	1186	47.231701999999999	47.272153000000003	46.192906999999998	46.182156999999997	0103000020E610000001000000050000007A354069A89D474065DEAAEB501747407A354069A89D4740B115342DB11847401041D5E8D5A24740B115342DB11847401041D5E8D5A2474065DEAAEB501747407A354069A89D474065DEAAEB50174740
11584	Барановка	2	21	1186	47.778111000000003	47.794612999999998	46.797910999999999	46.780653000000001	0103000020E6100000010000000500000035D4282499E347401C430070EC63474035D4282499E34740300F99F221664740FCFCF7E0B5E54740300F99F221664740FCFCF7E0B5E547401C430070EC63474035D4282499E347401C430070EC634740
10828	Яр-Базар	2	21	1098	47.488430999999999	47.512928000000002	45.960678999999999	45.956719	0103000020E6100000010000000500000021AD31E884BE47401D3BA8C475FA464021AD31E884BE47401C7A8B87F7FA4640F299EC9FA7C147401C7A8B87F7FA4640F299EC9FA7C147401D3BA8C475FA464021AD31E884BE47401D3BA8C475FA4640
9966	Яндыки	2	21	1098	47.093505	47.140801000000003	45.778467999999997	45.759934999999999	0103000020E610000001000000050000009981CAF8F78B4740FA0AD28C45E146409981CAF8F78B4740C37DE4D6A4E346403F1F65C405924740C37DE4D6A4E346403F1F65C405924740FA0AD28C45E146409981CAF8F78B4740FA0AD28C45E14640
11000	Судачье	2	21	1098	47.549688000000003	47.566198999999997	45.861528	45.854717999999998	0103000020E610000001000000050000007880272D5CC64740B9A6406667ED46407880272D5CC647404D4BAC8C46EE46409203763579C847404D4BAC8C46EE46409203763579C84740B9A6406667ED46407880272D5CC64740B9A6406667ED4640
57118	Село Зензели	2	21	1098	46.911856999999998	47.686959000000002	46.172795999999998	45.414918	0103000020E6100000010000000500000078D0ECBAB7744740C84274081CB5464078D0ECBAB77447409770E82D1E164740B058C345EED747409770E82D1E164740B058C345EED74740C84274081CB5464078D0ECBAB7744740C84274081CB54640
57140	Село Басы	2	21	1098	46.911856999999998	47.686959000000002	46.172795999999998	45.414918	0103000020E6100000010000000500000078D0ECBAB7744740C84274081CB5464078D0ECBAB77447409770E82D1E164740B058C345EED747409770E82D1E164740B058C345EED74740C84274081CB5464078D0ECBAB7744740C84274081CB54640
10279	Рынок	2	21	1098	47.558734000000001	47.570528000000003	45.648578999999998	45.638509999999997	0103000020E61000000100000005000000E694809884C74740A01518B2BAD14640E694809884C74740AAEFFCA204D34640E5B9BE0F07C94740AAEFFCA204D34640E5B9BE0F07C94740A01518B2BAD14640E694809884C74740A01518B2BAD14640
10882	Проточное	2	21	1098	47.292211999999999	47.308939000000002	45.893388999999999	45.889180000000003	0103000020E61000000100000005000000D7BFEB3367A54740EF2076A6D0F14640D7BFEB3367A5474096CD1C925AF24640BFBA2A508BA7474096CD1C925AF24640BFBA2A508BA74740EF2076A6D0F14640D7BFEB3367A54740EF2076A6D0F14640
10444	Промысловка	2	21	1098	47.152920000000002	47.182437999999998	45.729097000000003	45.715972000000001	0103000020E61000000100000005000000C173EFE192934740056D72F8A4DB4640C173EFE1929347404D4EED0C53DD464019C6DD205A9747404D4EED0C53DD464019C6DD205A974740056D72F8A4DB4640C173EFE192934740056D72F8A4DB4640
9905	Песчаное	2	21	1098	47.320113999999997	47.334944999999998	45.811025000000001	45.804251999999998	0103000020E61000000100000005000000F17EDC7EF9A847400DDFC2BAF1E64640F17EDC7EF9A84740849ECDAACFE74640B77A4E7ADFAA4740849ECDAACFE74640B77A4E7ADFAA47400DDFC2BAF1E64640F17EDC7EF9A847400DDFC2BAF1E64640
10055	Оля	2	21	1098	47.520322	47.548330999999997	45.792853999999998	45.780982000000002	0103000020E61000000100000005000000D5B14AE999C24740E161DA37F7E34640D5B14AE999C247405B40683D7CE546400531D0B52FC647405B40683D7CE546400531D0B52FC64740E161DA37F7E34640D5B14AE999C24740E161DA37F7E34640
10577	Михайловка	2	21	1098	47.109872000000003	47.137611999999997	45.935412999999997	45.919677999999998	0103000020E61000000100000005000000815F2349108E4740E36C3A02B8F54640815F2349108E47406AA0F99CBBF74640C1C41F459D9147406AA0F99CBBF74640C1C41F459D914740E36C3A02B8F54640815F2349108E4740E36C3A02B8F54640
57112	Лиман	2	21	1098	47.19903	47.263278	45.795304999999999	45.775481999999997	0103000020E610000001000000050000002176A6D0799947407E5182FE42E346402176A6D07999474032ACE28DCCE54640CEE0EF17B3A1474032ACE28DCCE54640CEE0EF17B3A147407E5182FE42E346402176A6D0799947407E5182FE42E34640
57111	Лиман	2	21	1098	47.19903	47.263278	45.795304999999999	45.775481999999997	0103000020E610000001000000050000002176A6D0799947407E5182FE42E346402176A6D07999474032ACE28DCCE54640CEE0EF17B3A1474032ACE28DCCE54640CEE0EF17B3A147407E5182FE42E346402176A6D0799947407E5182FE42E34640
10112	Лесное	2	21	1098	47.515183	47.534137999999999	45.783150999999997	45.77469	0103000020E61000000100000005000000433A3C84F1C14740E544BB0A29E34640433A3C84F1C14740336ABE4A3EE4464082C64CA25EC44740336ABE4A3EE4464082C64CA25EC44740E544BB0A29E34640433A3C84F1C14740E544BB0A29E34640
10943	Кряжевое	2	21	1098	47.511598999999997	47.538359999999997	45.860849999999999	45.849688999999998	0103000020E6100000010000000500000049D576137CC14740AE62F19BC2EC464049D576137CC147407C61325530EE4640BEBC00FBE8C447407C61325530EE4640BEBC00FBE8C44740AE62F19BC2EC464049D576137CC14740AE62F19BC2EC4640
10658	Караванное	2	21	1098	47.123679000000003	47.169052999999998	45.992896999999999	45.977792000000001	0103000020E61000000100000005000000DB19A6B6D48F47402D25CB4928FD4640DB19A6B6D48F4740F4A5B73F17FF464035255987A3954740F4A5B73F17FF464035255987A39547402D25CB4928FD4640DB19A6B6D48F47402D25CB4928FD4640
10750	Камышово	2	21	1098	47.433275000000002	47.468066999999998	45.952233	45.944305999999997	0103000020E610000001000000050000005396218E75B7474052B5DD04DFF846405396218E75B7474003965CC5E2F946401DAB949EE9BB474003965CC5E2F946401DAB949EE9BB474052B5DD04DFF846405396218E75B7474052B5DD04DFF84640
10853	Заречное	2	21	1098	47.424596999999999	47.485098999999998	45.881883999999999	45.875064000000002	0103000020E61000000100000005000000677DCA3159B6474017F4DE1802F04640677DCA3159B64740CE6E2D93E1F0464041295AB917BE4740CE6E2D93E1F0464041295AB917BE474017F4DE1802F04640677DCA3159B6474017F4DE1802F04640
10200	Забурунное	2	21	1098	47.525433	47.540067000000001	45.730085000000003	45.720905000000002	0103000020E610000001000000050000009D9E776341C34740EE42739D46DC46409D9E776341C347406C26DF6C73DD46400D535BEA20C547406C26DF6C73DD46400D535BEA20C54740EE42739D46DC46409D9E776341C34740EE42739D46DC4640
10302	Вышка	2	21	1098	47.639124000000002	47.646858000000002	45.620983000000003	45.602106999999997	0103000020E610000001000000050000005B0BB3D0CED14740A9D898D711CD46405B0BB3D0CED147409D2FF65E7CCF4640F793313ECCD247409D2FF65E7CCF4640F793313ECCD24740A9D898D711CD46405B0BB3D0CED14740A9D898D711CD4640
10536	Воскресеновка	2	21	1098	47.519494999999999	47.538980000000002	45.616759000000002	45.611899000000001	0103000020E61000000100000005000000BFB7E9CF7EC2474041BAD8B452CE4640BFB7E9CF7EC24740C0417BF5F1CE46405B99F04BFDC44740C0417BF5F1CE46405B99F04BFDC4474041BAD8B452CE4640BFB7E9CF7EC2474041BAD8B452CE4640
10456	Бударино	2	21	1098	47.399425999999998	47.416547999999999	45.703259000000003	45.697316999999998	0103000020E610000001000000050000000796236420B34740F0F8F6AE41D946400796236420B3474010CF126404DA46406B9BE27151B5474010CF126404DA46406B9BE27151B54740F0F8F6AE41D946400796236420B34740F0F8F6AE41D94640
10163	Бирючья Коса	2	21	1098	47.568040000000003	47.605527000000002	45.729675999999998	45.713096	0103000020E61000000100000005000000F168E388B5C847404774CFBA46DB4640F168E388B5C847408A56EE0566DD464029ECA2E881CD47408A56EE0566DD464029ECA2E881CD47404774CFBA46DB4640F168E388B5C847404774CFBA46DB4640
57125	с.Новоурусовка	2	21	961	48.04421	48.067008999999999	46.691859000000001	46.67662	0103000020E61000000100000005000000FD135CACA8054840E6E8F17B9B564740FD135CACA8054840BD38F1D58E584740D2C43BC093084840BD38F1D58E584740D2C43BC093084840E6E8F17B9B564740FD135CACA8054840E6E8F17B9B564740
57147	пос.Топал	2	21	961	47.811096999999997	49.014012999999998	47.519995000000002	46.405698000000001	0103000020E610000001000000050000001D71C806D2E74740BC067DE9ED3347401D71C806D2E74740B18A37328FC24740035C902DCB814840B18A37328FC24740035C902DCB814840BC067DE9ED3347401D71C806D2E74740BC067DE9ED334740
9596	Ясын-Сокан	2	21	961	48.114072	48.133403999999999	46.677368000000001	46.658617999999997	0103000020E61000000100000005000000D5B14AE9990E4840494739984D544740D5B14AE9990E4840B0AD9FFEB3564740EA93DC6113114840B0AD9FFEB3564740EA93DC6113114840494739984D544740D5B14AE9990E4840494739984D544740
9498	Шмагино	2	21	961	48.209589999999999	48.224448000000002	46.604216999999998	46.598427999999998	0103000020E61000000100000005000000C9C859D8D31A48405E81E849994C4740C9C859D8D31A4840F7578FFB564D474089D349B6BA1C4840F7578FFB564D474089D349B6BA1C48405E81E849994C4740C9C859D8D31A48405E81E849994C4740
9091	Черемуха	2	21	961	48.358755000000002	48.384393000000003	46.512526000000001	46.489635999999997	0103000020E61000000100000005000000642310AFEB2D4840DD787764AC3E4740642310AFEB2D4840C32CB4739A414740DAE731CA33314840C32CB4739A414740DAE731CA33314840DD787764AC3E4740642310AFEB2D4840DD787764AC3E4740
9297	Тальниковый	2	21	961	48.050021999999998	48.060352999999999	46.649512999999999	46.629193999999998	0103000020E610000001000000050000004E0AF31E67064840726BD26D895047404E0AF31E67064840D6A9F23D23534740959BA8A5B9074840D6A9F23D23534740959BA8A5B9074840726BD26D895047404E0AF31E67064840726BD26D89504740
8662	Сеитовка	2	21	961	48.041021000000001	48.071348	46.729118999999997	46.723861999999997	0103000020E6100000010000000500000080B9162D4005484098689082A75C474080B9162D4005484034F279C5535D4740485167EE2109484034F279C5535D4740485167EE2109484098689082A75C474080B9162D4005484098689082A75C4740
9036	Малый Арал	2	21	961	48.458396	48.475644000000003	46.665768	46.662346999999997	0103000020E61000000100000005000000014F5AB8AC3A484046CD57C9C7544740014F5AB8AC3A4840965CC5E237554740F24410E7E13C4840965CC5E237554740F24410E7E13C484046CD57C9C7544740014F5AB8AC3A484046CD57C9C7544740
8522	Кривой Бузан	2	21	961	48.525517999999998	48.541418999999998	46.519750000000002	46.513269999999999	0103000020E61000000100000005000000CBBA7F2C444348404B02D4D4B2414740CBBA7F2C444348404A0C022B874247406D37C1374D4548404A0C022B874247406D37C1374D4548404B02D4D4B2414740CBBA7F2C444348404B02D4D4B2414740
8058	Красный Яр	2	21	961	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
9426	Кошелевка	2	21	961	48.718369000000003	48.742066000000001	46.532418	46.529100999999997	0103000020E61000000100000005000000E9BAF083F35B4840F4A3E194B9434740E9BAF083F35B48409FE6E445264447409DBCC804FC5E48409FE6E445264447409DBCC804FC5E4840F4A3E194B9434740E9BAF083F35B4840F4A3E194B9434740
8843	Комсомольский	2	21	961	47.931885000000001	47.942583999999997	46.863238000000003	46.847352000000001	0103000020E610000001000000050000000551F70148F74740A019C407766C47400551F70148F747400D5531957E6E4740CEDDAE97A6F847400D5531957E6E4740CEDDAE97A6F84740A019C407766C47400551F70148F74740A019C407766C4740
8969	Караозек	2	21	961	48.622501	48.646683000000003	46.547561000000002	46.523997999999999	0103000020E61000000100000005000000185DDE1CAE4F4840AF95D05D12434740185DDE1CAE4F484054C8957A1646474089F02F82C652484054C8957A1646474089F02F82C6524840AF95D05D12434740185DDE1CAE4F4840AF95D05D12434740
9674	Забузан	2	21	961	48.300293000000003	48.313983	46.527185000000003	46.519731999999998	0103000020E61000000100000005000000DF1B430070264840A357039486424740DF1B4300702648408CF84ECC7A434740FF3F4E98302848408CF84ECC7A434740FF3F4E9830284840A357039486424740DF1B430070264840A357039486424740
8885	Досанг	2	21	961	47.889510999999999	47.924374999999998	46.919992999999998	46.894418999999999	0103000020E610000001000000050000005437177FDBF14740E4F560527C7247405437177FDBF1474043C6A354C2754740B81E85EB51F6474043C6A354C2754740B81E85EB51F64740E4F560527C7247405437177FDBF14740E4F560527C724740
7974	Джанай	2	21	961	48.214072999999999	48.226953999999999	46.635505000000002	46.617725	0103000020E6100000010000000500000072FA7ABE661B4840F775E09C114F474072FA7ABE661B4840E5B8533A5851474023D923D40C1D4840E5B8533A5851474023D923D40C1D4840F775E09C114F474072FA7ABE661B4840F775E09C114F4740
8803	Вишневый	2	21	961	47.930753000000003	47.944316999999998	46.828555999999999	46.817388999999999	0103000020E61000000100000005000000B3D30FEA22F74740198EE733A0684740B3D30FEA22F74740C9737D1F0E6A474046072461DFF84740C9737D1F0E6A474046072461DFF84740198EE733A0684740B3D30FEA22F74740198EE733A0684740
9469	Верхний Бузан	2	21	961	48.148648000000001	48.181049999999999	46.628673999999997	46.611063999999999	0103000020E61000000100000005000000D34ECDE506134840A8E15B58374E4740D34ECDE50613484039ECBE63785047406C787AA52C17484039ECBE63785047406C787AA52C174840A8E15B58374E4740D34ECDE506134840A8E15B58374E4740
9353	Ватажное	2	21	961	48.383575999999998	48.393098000000002	46.558883999999999	46.549885000000003	0103000020E61000000100000005000000E7C3B30419314840CEC7B5A162464740E7C3B30419314840FB20CB8289474740BF0F070951324840FB20CB8289474740BF0F070951324840CEC7B5A162464740E7C3B30419314840CEC7B5A162464740
8736	Бузан-Пристань	2	21	961	48.024016000000003	48.043742999999999	46.728273000000002	46.711962999999997	0103000020E61000000100000005000000564ACFF412034840247B849A215B4740564ACFF412034840A8C7B60C385D4740E736E15E99054840A8C7B60C385D4740E736E15E99054840247B849A215B4740564ACFF412034840247B849A215B4740
9212	Бузан	2	21	961	47.967728000000001	47.985891000000002	46.715131999999997	46.706462999999999	0103000020E6100000010000000500000035B6D782DEFB4740C26A2C616D5A474035B6D782DEFB47405A290472895B4740DB3521AD31FE47405A290472895B4740DB3521AD31FE4740C26A2C616D5A474035B6D782DEFB4740C26A2C616D5A4740
8740	Бахаревский	2	21	961	47.937444999999997	47.962983999999999	46.813436000000003	46.804535999999999	0103000020E610000001000000050000003C66A032FEF74740323A2009FB6647403C66A032FEF74740CDB1BCAB1E6847401F49490F43FB4740CDB1BCAB1E6847401F49490F43FB4740323A2009FB6647403C66A032FEF74740323A2009FB664740
8586	Бакланье	2	21	961	48.674683999999999	48.714272000000001	46.479317000000002	46.471986999999999	0103000020E610000001000000050000003691990B5C5648408E91EC116A3C47403691990B5C5648405BB56B425A3D47406939D0436D5B48405BB56B425A3D47406939D0436D5B48408E91EC116A3C47403691990B5C5648408E91EC116A3C4740
9175	Байбек	2	21	961	48.450060000000001	48.463102999999997	46.656582999999998	46.648677999999997	0103000020E610000001000000050000006F9EEA909B3948403DD175E1075347406F9EEA909B394840060E68E90A544740F9D687F5463B4840060E68E90A544740F9D687F5463B48403DD175E1075347406F9EEA909B3948403DD175E107534740
8610	Алча	2	21	961	48.325418999999997	48.339827999999997	46.582183999999998	46.576058000000003	0103000020E610000001000000050000009E3F6D54A7294840B24CBF44BC4947409E3F6D54A729484092205C01854A4740EE21E17B7F2B484092205C01854A4740EE21E17B7F2B4840B24CBF44BC4947409E3F6D54A7294840B24CBF44BC494740
9345	Аллайский	2	21	961	47.999203999999999	48.022067	46.653613999999997	46.648443	0103000020E610000001000000050000002504ABEAE5FF4740FA28232E005347402504ABEAE5FF4740971AA19FA953474011A96917D3024840971AA19FA953474011A96917D3024840FA28232E005347402504ABEAE5FF4740FA28232E00534740
9103	Аксарайский	2	21	961	48.006391000000001	48.013801999999998	46.797781999999998	46.787182000000001	0103000020E610000001000000050000008FFE976BD1004840FCFF3861C26447408FFE976BD100484032AB77B81D664740484F9143C401484032AB77B81D664740484F9143C4014840FCFF3861C26447408FFE976BD1004840FCFF3861C2644740
57151	п.Азовский	2	21	783	47.759892999999998	48.613211999999997	46.210895000000001	45.413229000000001	0103000020E61000000100000005000000CBBA7F2C44E14740206118B0E4B44640CBBA7F2C44E14740E9F17B9BFE1A4740E3C116BB7D4E4840E9F17B9BFE1A4740E3C116BB7D4E4840206118B0E4B44640CBBA7F2C44E14740206118B0E4B44640
6999	Чапаево	2	21	783	48.259860000000003	48.281159000000002	45.980905	45.972982000000002	0103000020E61000000100000005000000F0C4AC174321484060CC96AC8AFC4640F0C4AC1743214840CFBD874B8EFD4640F0FCA204FD234840CFBD874B8EFD4640F0FCA204FD23484060CC96AC8AFC4640F0C4AC174321484060CC96AC8AFC4640
8016	Чаган	2	21	783	47.945126000000002	47.983708999999998	46.180584000000003	46.166929000000003	0103000020E61000000100000005000000B64C86E3F9F8474083E0F1ED5D154740B64C86E3F9F84740271763601D174740F3E32F2DEAFD4740271763601D174740F3E32F2DEAFD474083E0F1ED5D154740B64C86E3F9F8474083E0F1ED5D154740
7307	Хмелевка	2	21	783	47.900713000000003	47.92398	46.098461	46.081079000000003	0103000020E61000000100000005000000810A47904AF347403AB2F2CB600A4740810A47904AF347403A77BB5E9A0C47403C1405FA44F647403A77BB5E9A0C47403C1405FA44F647403AB2F2CB600A4740810A47904AF347403AB2F2CB600A4740
7976	Успех	2	21	783	48.036259999999999	48.044848000000002	46.076583999999997	46.068331000000001	0103000020E610000001000000050000009413ED2AA4044840C826F911BF0847409413ED2AA4044840CCB22781CD09474040A54A94BD054840CCB22781CD09474040A54A94BD054840C826F911BF0847409413ED2AA4044840C826F911BF084740
7938	Увары	2	21	783	48.031903	48.044550999999998	46.057419000000003	46.034675	0103000020E6100000010000000500000078D2C26515044840917EFB3A7004474078D2C26515044840A3957B81590747408600E0D8B3054840A3957B81590747408600E0D8B3054840917EFB3A7004474078D2C26515044840917EFB3A70044740
6507	Тузуклей	2	21	783	48.315995000000001	48.349736	46.157598	46.122528000000003	0103000020E610000001000000050000008A592F8672284840126C5CFFAE0F47408A592F86722848401FF5D72B2C144740EF1D3526C42C48401FF5D72B2C144740EF1D3526C42C4840126C5CFFAE0F47408A592F8672284840126C5CFFAE0F4740
6659	Трехизбенка	2	21	783	48.345585999999997	48.365268	46.163041	46.150443000000003	0103000020E610000001000000050000004CFA7B293C2C4840C1745AB7411347404CFA7B293C2C48401D740987DE1447403E23111AC12E48401D740987DE1447403E23111AC12E4840C1745AB7411347404CFA7B293C2C4840C1745AB741134740
6442	Станья	2	21	783	48.106462999999998	48.116677000000003	45.827047999999998	45.811382999999999	0103000020E61000000100000005000000F59D5F94A00D4840E3C3EC65DBE74640F59D5F94A00D4840711C78B5DCE9464003999D45EF0E4840711C78B5DCE9464003999D45EF0E4840E3C3EC65DBE74640F59D5F94A00D4840E3C3EC65DBE74640
6665	Сизова Грива	2	21	783	48.387985999999998	48.404443000000001	46.102885999999998	46.082504999999998	0103000020E6100000010000000500000026A77686A9314840D4601A868F0A474026A77686A9314840AE9B525E2B0D47404E0CC9C9C4334840AE9B525E2B0D47404E0CC9C9C4334840D4601A868F0A474026A77686A9314840D4601A868F0A4740
6915	Семибугры	2	21	783	48.228606999999997	48.273218	46.184452999999998	46.157952999999999	0103000020E610000001000000050000007E5182FE421D48400DA7CCCD371447407E5182FE421D48401553E9279C174740DA56B3CEF82248401553E9279C174740DA56B3CEF82248400DA7CCCD371447407E5182FE421D48400DA7CCCD37144740
7771	Самосделка	2	21	783	47.835234999999997	47.850496999999997	46.045879999999997	46.010275	0103000020E61000000100000005000000BEBC00FBE8EA4740B37BF2B050014740BEBC00FBE8EA47402EC55565DF0547404D2CF015DDEC47402EC55565DF0547404D2CF015DDEC4740B37BF2B050014740BEBC00FBE8EA4740B37BF2B050014740
6734	Раздор	2	21	783	48.215833000000003	48.234572	46.083486000000001	46.057243999999997	0103000020E61000000100000005000000E4326E6AA01B484034F279C553074740E4326E6AA01B484041D653ABAF0A474056478E74061E484041D653ABAF0A474056478E74061E484034F279C553074740E4326E6AA01B484034F279C553074740
7735	Полдневое	2	21	783	47.942700000000002	47.966937000000001	45.870176000000001	45.837560000000003	0103000020E6100000010000000500000038F8C264AAF847400938842A35EB464038F8C264AAF84740CEE15AED61EF46406C257497C4FB4740CEE15AED61EF46406C257497C4FB47400938842A35EB464038F8C264AAF847400938842A35EB4640
6217	Парыгино	2	21	783	48.235345000000002	48.244318999999997	45.946913000000002	45.936221000000003	0103000020E610000001000000050000007923F3C81F1E48400A6AF816D6F746407923F3C81F1E48402194F77134F946404D6551D8451F48402194F77134F946404D6551D8451F48400A6AF816D6F746407923F3C81F1E48400A6AF816D6F74640
7444	Октябрьский	2	21	783	48.101261999999998	48.110263000000003	45.871782000000003	45.851484999999997	0103000020E61000000100000005000000ED293927F60C48406C04E275FDEC4640ED293927F60C4840E99E758D96EF4640BC7A15191D0E4840E99E758D96EF4640BC7A15191D0E48406C04E275FDEC4640ED293927F60C48406C04E275FDEC4640
6332	Обуховский	2	21	783	48.139009000000001	48.152645999999997	45.837584999999997	45.827713000000003	0103000020E61000000100000005000000C26C020CCB114840AEBCE47FF2E94640C26C020CCB114840614F3BFC35EB4640BFEE74E789134840614F3BFC35EB4640BFEE74E789134840AEBCE47FF2E94640C26C020CCB114840AEBCE47FF2E94640
7582	Образцово-Травино	2	21	783	47.982199000000001	48.011457	45.984862999999997	45.935651	0103000020E61000000100000005000000FB9463B2B8FD47401FBC7669C3F74640FB9463B2B8FD47402D05A4FD0FFE4640B727486C770148402D05A4FD0FFE4640B727486C770148401FBC7669C3F74640FB9463B2B8FD47401FBC7669C3F74640
7490	Никольское	2	21	783	47.909472000000001	47.930869999999999	46.168745999999999	46.133564999999997	0103000020E610000001000000050000005950189469F44740F3716DA8181147405950189469F4474058AA0B7899154740EC6987BF26F7474058AA0B7899154740EC6987BF26F74740F3716DA8181147405950189469F44740F3716DA818114740
7697	Нижненикольский	2	21	783	47.981535000000001	47.995035999999999	45.925753	45.895378000000001	0103000020E610000001000000050000008F705AF0A2FD474069C70DBF9BF246408F705AF0A2FD4740429605137FF64640DC2BF3565DFF4740429605137FF64640DC2BF3565DFF474069C70DBF9BF246408F705AF0A2FD474069C70DBF9BF24640
7210	Нижнекалиновский	2	21	783	48.171222999999998	48.186475999999999	45.983879999999999	45.976728000000001	0103000020E6100000010000000500000058A9A0A2EA154840338B506C05FD464058A9A0A2EA1548402098A3C7EFFD464094BE1072DE1748402098A3C7EFFD464094BE1072DE174840338B506C05FD464058A9A0A2EA154840338B506C05FD4640
7365	Лебяжье	2	21	783	48.113632000000003	48.128912	45.926147999999998	45.897585999999997	0103000020E61000000100000005000000B9E34D7E8B0E484079AC1919E4F24640B9E34D7E8B0E4840BEA085048CF64640EE073C3080104840BEA085048CF64640EE073C308010484079AC1919E4F24640B9E34D7E8B0E484079AC1919E4F24640
7518	Комаровка	2	21	783	47.871437	47.889654999999998	46.166055999999998	46.149175999999997	0103000020E610000001000000050000001EC3633F8BEF47408EACFC32181347401EC3633F8BEF4740FCA6B0524115474087DC0C37E0F14740FCA6B0524115474087DC0C37E0F147408EACFC32181347401EC3633F8BEF47408EACFC3218134740
6477	Кировский	2	21	783	48.113273	48.141156000000002	45.860711999999999	45.828141000000002	0103000020E610000001000000050000008942CBBA7F0E484006BD378600EA46408942CBBA7F0E48402BA391CF2BEE46402DD15966111248402BA391CF2BEE46402DD159661112484006BD378600EA46408942CBBA7F0E484006BD378600EA4640
7849	Качкаринский	2	21	783	47.962338000000003	47.966487999999998	46.005724999999998	46.000991999999997	0103000020E610000001000000050000005AD93EE42DFB474060C77F81200047405AD93EE42DFB474082E2C798BB004740FCFCF7E0B5FB474082E2C798BB004740FCFCF7E0B5FB474060C77F81200047405AD93EE42DFB474060C77F8120004740
6854	Каспий	2	21	783	48.356464000000003	48.367604	46.060158000000001	46.042726999999999	0103000020E61000000100000005000000C619C39CA02D4840FED30D1478054740C619C39CA02D4840E04BE141B30747407CF0DAA50D2F4840E04BE141B30747407CF0DAA50D2F4840FED30D1478054740C619C39CA02D4840FED30D1478054740
6255	Караульное	2	21	783	48.124563999999999	48.136090000000003	45.881068999999997	45.870477000000001	0103000020E61000000100000005000000252191B6F10F4840C97553CA6BEF4640252191B6F10F48407C4276DEC6F0464005A8A9656B1148407C4276DEC6F0464005A8A9656B114840C97553CA6BEF4640252191B6F10F4840C97553CA6BEF4640
6143	Каралат	2	21	783	48.289396000000004	48.313353999999997	45.935004999999997	45.907632999999997	0103000020E61000000100000005000000EFCB99ED0A2548409BE271512DF44640EFCB99ED0A254840594C6C3EAEF746400F09DFFB1B284840594C6C3EAEF746400F09DFFB1B2848409BE271512DF44640EFCB99ED0A2548409BE271512DF44640
5539	Камызяк	2	21	783	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
7237	Иванчуг	2	21	783	47.964440000000003	47.989341000000003	46.082991999999997	46.056462000000003	0103000020E61000000100000005000000257A19C572FB4740BFBB95253A074740257A19C572FB474031EA5A7B9F0A4740C5CBD3B9A2FE474031EA5A7B9F0A4740C5CBD3B9A2FE4740BFBB95253A074740257A19C572FB4740BFBB95253A074740
57130	Затон	2	21	783	48.142144000000002	48.167118000000002	45.923202000000003	45.896926999999998	0103000020E610000001000000050000004CA94BC6311248401FF30181CEF246404CA94BC63112484008CDAE7B2BF646405649641F6415484008CDAE7B2BF646405649641F641548401FF30181CEF246404CA94BC6311248401FF30181CEF24640
6794	Застенка	2	21	783	48.196007000000002	48.204892000000001	46.111457999999999	46.085042000000001	0103000020E61000000100000005000000BF64E3C116194840AA6400A8E20A4740BF64E3C11619484054707841440E4740249BABE6391A484054707841440E4740249BABE6391A4840AA6400A8E20A4740BF64E3C116194840AA6400A8E20A4740
57138	Жан-Аул	2	21	783	47.759892999999998	48.613211999999997	46.210895000000001	45.413229000000001	0103000020E61000000100000005000000CBBA7F2C44E14740206118B0E4B44640CBBA7F2C44E14740E9F17B9BFE1A4740E3C116BB7D4E4840E9F17B9BFE1A4740E3C116BB7D4E4840206118B0E4B44640CBBA7F2C44E14740206118B0E4B44640
57144	Грушево	2	21	783	48.467253999999997	48.491301999999997	46.107903	46.086505000000002	0103000020E610000001000000050000006C76A4FACE3B484062F88898120B47406C76A4FACE3B4840F511F8C3CF0D4740CD3AE3FBE23E4840F511F8C3CF0D4740CD3AE3FBE23E484062F88898120B47406C76A4FACE3B484062F88898120B4740
7657	Гандурино	2	21	783	47.995809000000001	48.006794999999997	45.858898000000003	45.841365000000003	0103000020E61000000100000005000000FF0758AB76FF4740E17F2BD9B1EB4640FF0758AB76FF4740C74CA25EF0ED46405E6397A8DE004840C74CA25EF0ED46405E6397A8DE004840E17F2BD9B1EB4640FF0758AB76FF4740E17F2BD9B1EB4640
7083	Волго-Каспийский	2	21	783	47.901603000000001	47.934804	46.208537999999997	46.193530000000003	0103000020E61000000100000005000000DD7C23BA67F34740BF654E97C5184740DD7C23BA67F3474093FC885FB11A4740C21550A8A7F7474093FC885FB11A4740C21550A8A7F74740BF654E97C5184740DD7C23BA67F34740BF654E97C5184740
7060	Верхнекалиновский	2	21	783	48.105313000000002	48.145783000000002	46.031658999999998	46.002519999999997	0103000020E61000000100000005000000FD6B79E57A0D4840FFCA4A9352004740FD6B79E57A0D4840E1CFF0660D04474009A87004A9124840E1CFF0660D04474009A87004A9124840FFCA4A9352004740FD6B79E57A0D4840FFCA4A9352004740
6961	Бирючек	2	21	783	48.217162999999999	48.230601999999998	46.121048000000002	46.105966000000002	0103000020E610000001000000050000005C7347FFCB1B4840753E3C4B900D47405C7347FFCB1B4840849F38807E0F47403332C85D841D4840849F38807E0F47403332C85D841D4840753E3C4B900D47405C7347FFCB1B4840753E3C4B900D4740
7861	Алексеевка	2	21	783	47.868428000000002	47.878883999999999	45.959307000000003	45.933732999999997	0103000020E61000000100000005000000217711A628EF474015191D9084F74640217711A628EF474075E95F92CAFA4640247D5A457FF0474075E95F92CAFA4640247D5A457FF0474015191D9084F74640217711A628EF474015191D9084F74640
4370	Ямное	2	21	544	47.693210999999998	47.713602999999999	45.993034000000002	45.981343000000003	0103000020E610000001000000050000001D1D5723BBD847404B94BDA59CFD46401D1D5723BBD8474075E8F4BC1BFF4640EBA9D55757DB474075E8F4BC1BFF4640EBA9D55757DB47404B94BDA59CFD46401D1D5723BBD847404B94BDA59CFD4640
5132	Чулпан	2	21	544	47.697828999999999	47.721975	45.908504999999998	45.882016	0103000020E61000000100000005000000A699EE7552D947403D4679E6E5F04640A699EE7552D9474051A04FE449F44640CAC342AD69DC474051A04FE449F44640CAC342AD69DC47403D4679E6E5F04640A699EE7552D947403D4679E6E5F04640
4791	Хмелевой	2	21	544	47.563035999999997	47.582844000000001	45.835821000000003	45.826456999999998	0103000020E610000001000000050000003E3C4B9011C847406F46CD57C9E946403E3C4B9011C84740AF27BA2EFCEA4640BD55D7A19ACA4740AF27BA2EFCEA4640BD55D7A19ACA47406F46CD57C9E946403E3C4B9011C847406F46CD57C9E94640
4735	Федоровка	2	21	544	47.623564999999999	47.645159999999997	45.868474999999997	45.850681000000002	0103000020E6100000010000000500000012F758FAD0CF47400F2A711DE3EC464012F758FAD0CF4740613255302AEF4640FB57569A94D24740613255302AEF4640FB57569A94D247400F2A711DE3EC464012F758FAD0CF47400F2A711DE3EC4640
4537	Трудфронт	2	21	544	47.656416	47.681227999999997	45.947037999999999	45.920718999999998	0103000020E610000001000000050000001B49827005D4474025E7C41EDAF546401B49827005D44740DD088B8A38F946404B8FA67A32D74740DD088B8A38F946404B8FA67A32D7474025E7C41EDAF546401B49827005D4474025E7C41EDAF54640
4453	Троицкий	2	21	544	47.634146999999999	47.653497000000002	45.984662	45.978743999999999	0103000020E61000000100000005000000A2ED98BA2BD14740FF93BF7B47FD4640A2ED98BA2BD1474096CE876709FE46405E8429CAA5D3474096CE876709FE46405E8429CAA5D34740FF93BF7B47FD4640A2ED98BA2BD14740FF93BF7B47FD4640
5295	Товарный	2	21	544	47.640292000000002	47.656784999999999	45.786526000000002	45.764701000000002	0103000020E61000000100000005000000FAF19716F5D14740F81BEDB8E1E14640FAF19716F5D1474013BA4BE2ACE446406EC0E78711D4474013BA4BE2ACE446406EC0E78711D44740F81BEDB8E1E14640FAF19716F5D14740F81BEDB8E1E14640
57145	Староволжское	2	21	544	47.681936999999998	47.705680000000001	45.872523000000001	45.851868000000003	0103000020E6100000010000000500000057772CB649D747402541B8020AED464057772CB649D7474000016BD5AEEF46407CB8E4B853DA474000016BD5AEEF46407CB8E4B853DA47402541B8020AED464057772CB649D747402541B8020AED4640
4130	Сергино	2	21	544	47.611733999999998	47.621130999999998	46.080773000000001	46.077278	0103000020E61000000100000005000000F6ECB94C4DCE4740A359D93EE4094740F6ECB94C4DCE47402DB308C5560A474011C4793881CF47402DB308C5560A474011C4793881CF4740A359D93EE4094740F6ECB94C4DCE4740A359D93EE4094740
4507	Сергиевка	2	21	544	47.612721999999998	47.629997000000003	45.970846000000002	45.965815999999997	0103000020E6100000010000000500000015C5ABAC6DCE47400DFAD2DB9FFB464015C5ABAC6DCE4740E9B985AE44FC464000CADFBDA3D04740E9B985AE44FC464000CADFBDA3D047400DFAD2DB9FFB464015C5ABAC6DCE47400DFAD2DB9FFB4640
5084	Седлистое	2	21	544	47.643839999999997	47.678209000000003	45.823298000000001	45.810346000000003	0103000020E61000000100000005000000A6ED5F5969D24740E338F06AB9E74640A6ED5F5969D247405D6E30D461E946402B6D718DCFD647405D6E30D461E946402B6D718DCFD64740E338F06AB9E74640A6ED5F5969D24740E338F06AB9E74640
4609	Светлое	2	21	544	47.609695000000002	47.627994000000001	45.897303000000001	45.885052999999999	0103000020E6100000010000000500000072C45A7C0ACE4740041DAD6A49F1464072C45A7C0ACE474025CD1FD3DAF24640C80A7E1B62D0474025CD1FD3DAF24640C80A7E1B62D04740041DAD6A49F1464072C45A7C0ACE4740041DAD6A49F14640
4816	Оранжереи	2	21	544	47.532476000000003	47.586995000000002	45.856858000000003	45.837797999999999	0103000020E61000000100000005000000D4F36E2C28C44740BD5301F73CEB4640D4F36E2C28C4474072A8DF85ADED464030F5F3A622CB474072A8DF85ADED464030F5F3A622CB4740BD5301F73CEB4640D4F36E2C28C44740BD5301F73CEB4640
4183	Озерное	2	21	544	47.464194999999997	47.484614000000001	46.081316999999999	46.075552999999999	0103000020E61000000100000005000000BDFBE3BD6ABB4740AE0E80B8AB094740BDFBE3BD6ABB4740EECD6F98680A47408597E0D407BE4740EECD6F98680A47408597E0D407BE4740AE0E80B8AB094740BDFBE3BD6ABB4740AE0E80B8AB094740
57150	Ново-Булгары	2	21	544	47.196739000000001	47.886457	46.256303000000003	45.336942999999998	0103000020E61000000100000005000000836C59BE2E994740DDCEBEF220AB4640836C59BE2E994740F06E6589CE204740B727486C77F14740F06E6589CE204740B727486C77F14740DDCEBEF220AB4640836C59BE2E994740DDCEBEF220AB4640
4651	Ниновка	2	21	544	47.598601000000002	47.626170000000002	45.873728	45.863472999999999	0103000020E610000001000000050000002C2D23F59ECC474050FD834886EE46402C2D23F59ECC4740BCCCB051D6EF464040DEAB5626D04740BCCCB051D6EF464040DEAB5626D0474050FD834886EE46402C2D23F59ECC474050FD834886EE4640
5377	Мумра	2	21	544	47.645941999999998	47.684272999999997	45.787852000000001	45.763078999999998	0103000020E61000000100000005000000718E3A3AAED24740D7A19A92ACE14640718E3A3AAED247404A0B9755D8E446409544F64196D747404A0B9755D8E446409544F64196D74740D7A19A92ACE14640718E3A3AAED24740D7A19A92ACE14640
4349	Маячное	2	21	544	47.709246	47.725335000000001	46.038997999999999	46.021754000000001	0103000020E61000000100000005000000CF68AB92C8DA47405247C7D5C8024740CF68AB92C8DA4740014EEFE2FD04474074D2FBC6D7DC4740014EEFE2FD04474074D2FBC6D7DC47405247C7D5C8024740CF68AB92C8DA47405247C7D5C8024740
3511	Красные Баррикады	2	21	544	47.834569999999999	47.886457	46.211401000000002	46.196854999999999	0103000020E61000000100000005000000821C9430D3EA4740EC866D8B32194740821C9430D3EA4740BDAB1E300F1B4740B727486C77F14740BDAB1E300F1B4740B727486C77F14740EC866D8B32194740821C9430D3EA4740EC866D8B32194740
4219	Карабулак	2	21	544	47.556657999999999	47.585647000000002	46.059527000000003	46.053373000000001	0103000020E610000001000000050000004487C09140C74740A5BE2CEDD40647404487C09140C74740501DAB949E07474011001C7BF6CA4740501DAB949E07474011001C7BF6CA4740A5BE2CEDD40647404487C09140C74740A5BE2CEDD4064740
3764	Икряное	2	21	544	47.688386999999999	47.751835	46.112695000000002	46.065266999999999	0103000020E61000000100000005000000EBFEB1101DD84740074147AB5A084740EBFEB1101DD847401CB62DCA6C0E47407C7E18213CE047401CB62DCA6C0E47407C7E18213CE04740074147AB5A084740EBFEB1101DD84740074147AB5A084740
5450	Зюзино	2	21	544	47.655679999999997	47.673133999999997	45.757306	45.745955000000002	0103000020E6100000010000000500000015527E52EDD34740D3A414747BDF464015527E52EDD3474044882B67EFE04640AFE9414129D6474044882B67EFE04640AFE9414129D64740D3A414747BDF464015527E52EDD34740D3A414747BDF4640
5238	Житное	2	21	544	47.680725000000002	47.704386	45.813205000000004	45.794846	0103000020E61000000100000005000000E9482EFF21D747409FAD8383BDE54640E9482EFF21D74740CBF8F71917E8464050E1085229DA4740CBF8F71917E8464050E1085229DA47409FAD8383BDE54640E9482EFF21D747409FAD8383BDE54640
4057	Восточное	2	21	544	47.663207999999997	47.677957999999997	46.127406999999998	46.119760999999997	0103000020E610000001000000050000000839EFFFE3D447400A2B1554540F47400839EFFFE3D44740072461DF4E104740E107E753C7D64740072461DF4E104740E107E753C7D647400A2B1554540F47400839EFFFE3D447400A2B1554540F4740
5035	Вахромеево	2	21	544	47.552489999999999	47.584370999999997	45.830257000000003	45.821603000000003	0103000020E61000000100000005000000FBAE08FEB7C64740D3A57F492AE94640FBAE08FEB7C64740362383DC45EA46408BDD3EABCCCA4740362383DC45EA46408BDD3EABCCCA4740D3A57F492AE94640FBAE08FEB7C64740D3A57F492AE94640
4000	Боркино	2	21	544	47.638621000000001	47.644792000000002	46.060352000000002	46.051009000000001	0103000020E61000000100000005000000F8C43A55BED147409D66817687064740F8C43A55BED14740C51F459DB9074740795C548B88D24740C51F459DB9074740795C548B88D247409D66817687064740F8C43A55BED147409D66817687064740
4301	Бекетовка	2	21	544	47.746049999999997	47.773763000000002	46.101505000000003	46.091430000000003	0103000020E610000001000000050000002497FF907EDF4740C8EF6DFAB30B47402497FF907EDF4740B4B0A71DFE0C47406CED7DAA0AE34740B4B0A71DFE0C47406CED7DAA0AE34740C8EF6DFAB30B47402497FF907EDF4740C8EF6DFAB30B4740
3608	Бахтемир	2	21	544	47.803282000000003	47.822560000000003	46.177252000000003	46.151324000000002	0103000020E6100000010000000500000095BBCFF1D1E64740CA8CB7955E13474095BBCFF1D1E6474047938B31B0164740B77F65A549E9474047938B31B0164740B77F65A549E94740CA8CB7955E13474095BBCFF1D1E64740CA8CB7955E134740
3673	Анатолия Зверева	2	21	544	47.792358	47.809274000000002	46.147047000000001	46.131791	0103000020E61000000100000005000000AB5CA8FC6BE547401D740987DE104740AB5CA8FC6BE54740CAFCA36FD212474066C0594A96E74740CAFCA36FD212474066C0594A96E747401D740987DE104740AB5CA8FC6BE547401D740987DE104740
3564	Алгаза	2	21	544	47.834803999999998	47.848773000000001	46.197659999999999	46.183436	0103000020E61000000100000005000000F54883DBDAEA47405C74B2D47A174740F54883DBDAEA47401ADD41EC4C194740295DFA97A4EC47401ADD41EC4C194740295DFA97A4EC47405C74B2D47A174740F54883DBDAEA47405C74B2D47A174740
2881	Федоровка	2	21	403	46.948247000000002	46.960411000000001	47.341965999999999	47.334369000000002	0103000020E61000000100000005000000DBC35E2860794740EBE5779ACCAA4740DBC35E2860794740062CB98AC5AB4740FDDB65BFEE7A4740062CB98AC5AB4740FDDB65BFEE7A4740EBE5779ACCAA4740DBC35E2860794740EBE5779ACCAA4740
2421	Табун-Арал	2	21	403	47.323841999999999	47.337513999999999	47.055672000000001	47.041113000000003	0103000020E610000001000000050000001E8997A773A947406138D730438547401E8997A773A94740C6A695422087474098F8A3A833AB4740C6A695422087474098F8A3A833AB47406138D730438547401E8997A773A947406138D73043854740
2308	Сероглазка	2	21	403	47.475783	47.490200999999999	47.011910999999998	47.002195999999998	0103000020E61000000100000005000000137F1475E6BC47404C1762F547804740137F1475E6BC474038BBB54C86814740B6BB07E8BEBE474038BBB54C86814740B6BB07E8BEBE47404C1762F547804740137F1475E6BC47404C1762F547804740
3104	Пришиб	2	21	403	46.463588000000001	46.503005999999999	47.685305999999997	47.671455999999999	0103000020E61000000100000005000000B66801DA563B4740FB592C45F2D54740B66801DA563B474054E0641BB8D747408CD827806240474054E0641BB8D747408CD8278062404740FB592C45F2D54740B66801DA563B4740FB592C45F2D54740
2199	Новострой	2	21	403	47.587685999999998	47.598447999999998	46.890669000000003	46.878622	0103000020E6100000010000000500000095287B4B39CB4740E7C589AF7670474095287B4B39CB4740D047197101724740A52DAEF199CC4740D047197101724740A52DAEF199CC4740E7C589AF7670474095287B4B39CB4740E7C589AF76704740
3179	Никольское	2	21	403	46.389918000000002	46.415430000000001	47.771244000000003	47.746783999999998	0103000020E61000000100000005000000950F41D5E831474089963C9E96DF4740950F41D5E83147403D9E961FB8E247407EE36BCF2C3547403D9E961FB8E247407EE36BCF2C35474089963C9E96DF4740950F41D5E831474089963C9E96DF4740
2940	Михайловка	2	21	403	46.843755000000002	46.853242000000002	47.384587000000003	47.376502000000002	0103000020E61000000100000005000000126BF129006C47407670B03731B04740126BF129006C4740BFBB95253AB147406DC9AA08376D4740BFBB95253AB147406DC9AA08376D47407670B03731B04740126BF129006C47407670B03731B04740
2357	Ленино	2	21	403	47.327021999999999	47.345024000000002	47.018312999999999	47.007831000000003	0103000020E6100000010000000500000048895DDBDBA947408F72309B0081474048895DDBDBA94740BB0B941458824740E52A16BF29AC4740BB0B941458824740E52A16BF29AC47408F72309B0081474048895DDBDBA947408F72309B00814740
2485	Косика	2	21	403	47.206226000000001	47.225054	47.097873999999997	47.092685000000003	0103000020E61000000100000005000000DECA129D659A474036EA211ADD8B4740DECA129D659A474079909E22878C4740C0EAC891CE9C474079909E22878C4740C0EAC891CE9C474036EA211ADD8B4740DECA129D659A474036EA211ADD8B4740
2983	Копановка	2	21	403	46.800735000000003	46.830514000000001	47.469968000000001	47.454268999999996	0103000020E610000001000000050000009CE1067C7E664740164B917C25BA47409CE1067C7E664740511553E927BC4740616F62484E6A4740511553E927BC4740616F62484E6A4740164B917C25BA47409CE1067C7E664740164B917C25BA4740
2813	Ивановка	2	21	403	47.013545999999998	47.034261000000001	47.303452999999998	47.291665000000002	0103000020E61000000100000005000000ED7E15E0BB814740A5315A4755A54740ED7E15E0BB814740C16F438CD7A647409E4319AA62844740C16F438CD7A647409E4319AA62844740A5315A4755A54740ED7E15E0BB814740A5315A4755A54740
2128	Замьяны	2	21	403	47.621642999999999	47.647585999999997	46.831632999999997	46.820287999999998	0103000020E61000000100000005000000C76471FF91CF47408FA67A32FF684740C76471FF91CF47401EA33CF3726A474079AC1919E4D247401EA33CF3726A474079AC1919E4D247408FA67A32FF684740C76471FF91CF47408FA67A32FF684740
2643	Енотаевка	2	21	403	47.015127	47.042462999999998	47.266024999999999	47.231409999999997	0103000020E61000000100000005000000AF2479AEEF814740D2FBC6D79E9D4740AF2479AEEF8147408E75711B0DA247402025766D6F8547408E75711B0DA247402025766D6F854740D2FBC6D79E9D4740AF2479AEEF814740D2FBC6D79E9D4740
3293	Грачи	2	21	403	46.268672000000002	46.283647000000002	47.801828999999998	47.789074999999997	0103000020E61000000100000005000000EBAC16D863224740AC8BDB6800E54740EBAC16D86322474000FE2955A2E64740E44D7E8B4E24474000FE2955A2E64740E44D7E8B4E244740AC8BDB6800E54740EBAC16D863224740AC8BDB6800E54740
2526	Восток	2	21	403	47.104393000000002	47.126787999999998	47.125563999999997	47.118524999999998	0103000020E610000001000000050000003677F4BF5C8D47401361C3D32B8F47403677F4BF5C8D474008C72C7B129047403BC3D4963A90474008C72C7B129047403BC3D4963A9047401361C3D32B8F47403677F4BF5C8D47401361C3D32B8F4740
2236	Волжский	2	21	403	47.540543	47.558670999999997	46.976644	46.962623000000001	0103000020E61000000100000005000000768A558330C547404FB0FF3A377B4740768A558330C54740D5EAABAB027D47409F1C058882C74740D5EAABAB027D47409F1C058882C747404FB0FF3A377B4740768A558330C547404FB0FF3A377B4740
2587	Владимировка	2	21	403	47.029895000000003	47.047367999999999	47.179881999999999	47.169310000000003	0103000020E610000001000000050000002FA86F99D3834740617138F3AB9547402FA86F99D3834740CD91955F069747403F70952710864740CD91955F069747403F70952710864740617138F3AB9547402FA86F99D3834740617138F3AB954740
3051	Ветлянка	2	21	403	46.618476000000001	46.638435999999999	47.639918999999999	47.630186000000002	0103000020E6100000010000000500000032AEB8382A4F4740D33252EFA9D0474032AEB8382A4F4740658BA4DDE8D14740664B5645B8514740658BA4DDE8D14740664B5645B8514740D33252EFA9D0474032AEB8382A4F4740D33252EFA9D04740
1546	Ямное	2	21	60	48.704625	48.710850000000001	46.326073000000001	46.322476000000002	0103000020E61000000100000005000000D578E926315A484059DFC0E446294740D578E926315A4840E78D93C2BC294740492EFF21FD5A4840E78D93C2BC294740492EFF21FD5A484059DFC0E446294740D578E926315A484059DFC0E446294740
2089	Яблонка	2	21	60	48.378805999999997	48.391525999999999	46.248849999999997	46.213078000000003	0103000020E61000000100000005000000A8C30AB77C304840A1BFD023461B4740A8C30AB77C30484007CE1951DA1F474050C422861D32484007CE1951DA1F474050C422861D324840A1BFD023461B4740A8C30AB77C304840A1BFD023461B4740
273	Цветное	2	21	60	48.720219	48.729795000000003	46.197266999999997	46.186473999999997	0103000020E610000001000000050000009A7ADD22305C4840F3C64961DE1747409A7ADD22305C48403ECA880B4019474065E42CEC695D48403ECA880B4019474065E42CEC695D4840F3C64961DE1747409A7ADD22305C4840F3C64961DE174740
1371	Тюрино	2	21	60	48.619419000000001	48.632463000000001	46.451706999999999	46.429063999999997	0103000020E61000000100000005000000B1C22D1F494F48400AF2B391EB364740B1C22D1F494F4840E82FF488D13947400C772E8CF4504840E82FF488D13947400C772E8CF45048400AF2B391EB364740B1C22D1F494F48400AF2B391EB364740
1832	Тумак	2	21	60	48.468592000000001	48.525472999999998	46.254669999999997	46.214967999999999	0103000020E61000000100000005000000689599D2FA3B4840E0D74812841B4740689599D2FA3B4840DBA2CC06992047402BF702B342434840DBA2CC06992047402BF702B342434840E0D74812841B4740689599D2FA3B4840E0D74812841B4740
1658	Тулугановка	2	21	60	48.450806	48.459015999999998	46.350681000000002	46.344870999999998	0103000020E61000000100000005000000986BD102B43948405E2BA1BB242C4740986BD102B43948400F2A711DE32C47409D2B4A09C13A48400F2A711DE32C47409D2B4A09C13A48405E2BA1BB242C4740986BD102B43948405E2BA1BB242C4740
1152	Трубный	2	21	60	48.536935999999997	48.549880999999999	46.388818000000001	46.381456999999997	0103000020E61000000100000005000000C405A051BA44484046EA3D95D3304740C405A051BA4448404E0CC9C9C43147408CD82780624648404E0CC9C9C43147408CD827806246484046EA3D95D3304740C405A051BA44484046EA3D95D3304740
1781	Тишково	2	21	60	48.596539	48.627620999999998	46.024056999999999	46.008046999999998	0103000020E61000000100000005000000EFE4D3635B4C48405BEA20AF07014740EFE4D3635B4C4840B41EBE4C1403474033A48AE255504840B41EBE4C1403474033A48AE2555048405BEA20AF07014740EFE4D3635B4C48405BEA20AF07014740
436	Сорочье	2	21	60	48.705675999999997	48.715736999999997	46.262590000000003	46.242474000000001	0103000020E610000001000000050000003AC95697535A4840AE105663091F47403AC95697535A4840DA20938C9C214740C1C41F459D5B4840DA20938C9C214740C1C41F459D5B4840AE105663091F47403AC95697535A4840AE105663091F4740
1895	Сизый Бугор	2	21	60	48.498263999999999	48.512771000000001	46.218060999999999	46.205931	0103000020E610000001000000050000001763601DC73F4840C51D6FF25B1A47401763601DC73F48403BC43F6CE91B47402AABE97AA24148403BC43F6CE91B47402AABE97AA2414840C51D6FF25B1A47401763601DC73F4840C51D6FF25B1A4740
2015	Сахма	2	21	60	48.450302000000001	48.465860999999997	46.246195	46.236134999999997	0103000020E6100000010000000500000065A9F57EA33948407138F3AB391E474065A9F57EA339484028B85851831F4740ADBD4F55A13B484028B85851831F4740ADBD4F55A13B48407138F3AB391E474065A9F57EA33948407138F3AB391E4740
1426	Самойловский	2	21	60	48.677782999999998	48.704318999999998	46.474817000000002	46.462217000000003	0103000020E610000001000000050000007364E597C1564840DF5339ED293B47407364E597C1564840DC4AAFCDC63C4740C879FF1F275A4840DC4AAFCDC63C4740C879FF1F275A4840DF5339ED293B47407364E597C1564840DF5339ED293B4740
1489	Разбугорье	2	21	60	48.589595000000003	48.611038000000001	46.396163999999999	46.383907000000001	0103000020E610000001000000050000004C7155D9774B48404DDA54DD233147404C7155D9774B484020ED7F80B53247407F4E417E364E484020ED7F80B53247407F4E417E364E48404DDA54DD233147404C7155D9774B48404DDA54DD23314740
779	Новый Рычан	2	21	60	48.359724999999997	48.377170999999997	46.379013999999998	46.364823999999999	0103000020E61000000100000005000000DC4603780B2E4840E065868DB22E4740DC4603780B2E4840F25CDF8783304740F3FFAA2347304840F25CDF8783304740F3FFAA2347304840E065868DB22E4740DC4603780B2E4840E065868DB22E4740
1263	Новокрасное	2	21	60	48.832535999999998	48.839821000000001	46.447006000000002	46.441789999999997	0103000020E610000001000000050000000F5F268A906A484094D920938C3847400F5F268A906A4840D28E1B7E373947403CBF28417F6B4840D28E1B7E373947403CBF28417F6B484094D920938C3847400F5F268A906A484094D920938C384740
944	Нововасильево	2	21	60	48.803052999999998	48.825304000000003	46.282660999999997	46.270957000000003	0103000020E6100000010000000500000033FAD170CA664840A7CF0EB8AE22474033FAD170CA664840656D533C2E24474006A1BC8FA3694840656D533C2E24474006A1BC8FA3694840A7CF0EB8AE22474033FAD170CA664840A7CF0EB8AE224740
21449	Новинка	2	21	60	48.536378999999997	48.567253999999998	46.284866000000001	46.279833000000004	0103000020E610000001000000050000006EA12B11A8444840B9AB5791D12347406EA12B11A844484005DF347D76244740394371C79B48484005DF347D76244740394371C79B484840B9AB5791D12347406EA12B11A8444840B9AB5791D1234740
1713	Нижняя Султановка	2	21	60	48.459851999999998	48.464019999999998	46.281987999999998	46.278924000000004	0103000020E6100000010000000500000006802A6EDC3A4840E60819C8B323474006802A6EDC3A4840A6EECA2E182447404F58E201653B4840A6EECA2E182447404F58E201653B4840E60819C8B323474006802A6EDC3A4840E60819C8B3234740
848	Мултаново	2	21	60	48.766626000000002	48.787987999999999	46.332047000000003	46.314577999999997	0103000020E61000000100000005000000B421FFCC206248404205871744284740B421FFCC2062484012DE1E84802A4740FAD170CADC64484012DE1E84802A4740FAD170CADC6448404205871744284740B421FFCC206248404205871744284740
32438	Марфино	2	21	60	48.706763000000002	48.731726999999999	46.419572000000002	46.390782000000002	0103000020E61000000100000005000000ED82C135775A4840C8EE022505324740ED82C135775A48409E280989B4354740D34CF73AA95D48409E280989B4354740D34CF73AA95D4840C8EE022505324740ED82C135775A4840C8EE022505324740
729	Маково	2	21	60	48.640394999999998	48.656699000000003	46.176709000000002	46.158884	0103000020E61000000100000005000000CEC29E76F8514840C8ED974F56144740CEC29E76F851484056F487669E16474070287CB60E54484056F487669E16474070287CB60E544840C8ED974F56144740CEC29E76F8514840C8ED974F56144740
1080	Лебяжье	2	21	60	48.728996000000002	48.755487000000002	46.383949999999999	46.377982000000003	0103000020E610000001000000050000001975ADBD4F5D4840043DD4B6613047401975ADBD4F5D48404CA60A4625314740CEC64ACCB36048404CA60A4625314740CEC64ACCB3604840043DD4B6613047401975ADBD4F5D4840043DD4B661304740
26437	Крутое	2	21	60	48.633110000000002	48.643853	46.270234000000002	46.261418999999997	0103000020E61000000100000005000000A2629CBF09514840C9C6832D76214740A2629CBF0951484036221807972247403B376DC66952484036221807972247403B376DC669524840C9C6832D76214740A2629CBF09514840C9C6832D76214740
1199	Костюбе	2	21	60	48.427135	48.443447999999997	46.434294000000001	46.429803	0103000020E610000001000000050000000DFD135CAC364840815CE2C8033747400DFD135CAC364840AD6C1FF29637474001BD70E7C2384840AD6C1FF29637474001BD70E7C2384840815CE2C8033747400DFD135CAC364840815CE2C803374740
656	Коровье	2	21	60	48.579479999999997	48.591957999999998	46.313811999999999	46.308228	0103000020E61000000100000005000000D15790662C4A484012DBDD0374274740D15790662C4A4840D28BDAFD2A284740834D9D47C54B4840D28BDAFD2A284740834D9D47C54B484012DBDD0374274740D15790662C4A484012DBDD0374274740
1314	Козлово	2	21	60	48.553600000000003	48.577800000000003	46.421902000000003	46.415514999999999	0103000020E610000001000000050000006688635DDC464840ACFF73982F3547406688635DDC464840FA0E7EE2003647407DD0B359F5494840FA0E7EE2003647407DD0B359F5494840ACFF73982F3547406688635DDC464840ACFF73982F354740
562	Камардан	2	21	60	48.548299999999998	48.566473000000002	46.278033000000001	46.272826000000002	0103000020E61000000100000005000000CA32C4B12E464840CFBF5DF6EB224740CA32C4B12E464840B91AD995962347409488F02F82484840B91AD995962347409488F02F82484840CFBF5DF6EB224740CA32C4B12E464840CFBF5DF6EB224740
1045	Калинино	2	21	60	48.865197999999999	48.888779	46.347278000000003	46.337175000000002	0103000020E610000001000000050000004548DDCEBE6E4840B003E78C282B47404548DDCEBE6E4840664F029B732C4740902FA182C3714840664F029B732C4740902FA182C3714840B003E78C282B47404548DDCEBE6E4840B003E78C282B4740
599	Казенный Бугор	2	21	60	48.658405999999999	48.662565000000001	46.230286999999997	46.222549999999998	0103000020E61000000100000005000000BEBED6A546544840C6DCB5847C1C4740BEBED6A546544840D3D85E0B7A1D4740B43C0FEECE544840D3D85E0B7A1D4740B43C0FEECE544840C6DCB5847C1C4740BEBED6A546544840C6DCB5847C1C4740
57121	Ильинка	2	21	60	48.625779000000001	48.640205999999999	46.367001000000002	46.362690999999998	0103000020E6100000010000000500000005C3B98619504840DAC69FA86C2E474005C3B98619504840B64C86E3F92E4740FB592C45F2514840B64C86E3F92E4740FB592C45F2514840DAC69FA86C2E474005C3B98619504840DAC69FA86C2E4740
218	Зеленга	2	21	60	48.597959000000003	48.639631000000001	46.182499999999997	46.171267	0103000020E61000000100000005000000A8ACA6EB894C484028F1B913EC154740A8ACA6EB894C48408FC2F5285C174740FF40B96DDF5148408FC2F5285C174740FF40B96DDF51484028F1B913EC154740A8ACA6EB894C484028F1B913EC154740
20953	Володарский	2	21	60	48.524360000000001	48.550465000000003	46.420366999999999	46.379112999999997	0103000020E6100000010000000500000050AA7D3A1E434840853E58C68630474050AA7D3A1E434840A8A8FA95CE354740DC4B1AA375464840A8A8FA95CE354740DC4B1AA375464840853E58C68630474050AA7D3A1E434840853E58C686304740
1598	Винный	2	21	60	48.270207999999997	48.290753000000002	46.477603999999999	46.466977999999997	0103000020E610000001000000050000000C8FFD2C96224840CAF962EFC53B47400C8FFD2C962248402A38BC20223D4740611BF164372548402A38BC20223D4740611BF16437254840CAF962EFC53B47400C8FFD2C96224840CAF962EFC53B4740
73	Большой Могой	2	21	60	48.646206999999997	48.660426999999999	46.324362000000001	46.300066000000001	0103000020E610000001000000050000001FB935E9B65248401E520C90682647401FB935E9B65248405708ABB1842947409C3237DF885448405708ABB1842947409C3237DF885448401E520C90682647401FB935E9B65248401E520C9068264740
136	Болдырево	2	21	60	48.563687999999999	48.581752999999999	46.356800999999997	46.345294000000003	0103000020E61000000100000005000000E692AAED26484840A5C00298322C4740E692AAED264848400D17B9A7AB2D4740C9ACDEE1764A48400D17B9A7AB2D4740C9ACDEE1764A4840A5C00298322C4740E692AAED26484840A5C00298322C4740
927	Блиново	2	21	60	48.872214	48.886704000000002	46.266495999999997	46.258913999999997	0103000020E61000000100000005000000828E56B5A46F4840FF3C0D1824214740828E56B5A46F4840E5417A8A1C224740BF9D44847F714840E5417A8A1C224740BF9D44847F714840FF3C0D1824214740828E56B5A46F4840FF3C0D1824214740
1942	Ахтерек	2	21	60	48.338192999999997	48.351559999999999	46.290508000000003	46.273747999999998	0103000020E61000000100000005000000395E81E8492B484036ACA92C0A234740395E81E8492B4840FA9CBB5D2F254740774A07EBFF2C4840FA9CBB5D2F254740774A07EBFF2C484036ACA92C0A234740395E81E8492B484036ACA92C0A234740
457	Алтынжар	2	21	60	48.499512000000003	48.510184000000002	46.281489999999998	46.269848000000003	0103000020E61000000100000005000000D3FA5B02F03F48400D7217618A224740D3FA5B02F03F4840551344DD07244740A37895B54D414840551344DD07244740A37895B54D4148400D7217618A224740D3FA5B02F03F48400D7217618A224740
346	Алексеевка	2	21	60	48.688310999999999	48.696091000000003	46.183292000000002	46.179335999999999	0103000020E61000000100000005000000103D29931A5848406B7F677BF4164740103D29931A58484029CFBC1C761747401D0588821959484029CFBC1C761747401D058882195948406B7F677BF4164740103D29931A5848406B7F677BF4164740
30330	Успенка	2	21	1175	46.225858000000002	46.246349000000002	48.212994999999999	48.195754999999998	0103000020E610000001000000050000001EC539EAE81C4740A583F57F0E1948401EC539EAE81C4740139B8F6B431B48407F33315D881F4740139B8F6B431B48407F33315D881F4740A583F57F0E1948401EC539EAE81C4740A583F57F0E194840
30734	Удачное	2	21	1175	46.787593000000001	46.809646000000001	47.754883999999997	47.737786	0103000020E610000001000000050000007EC7F0D8CF6447402CB98AC56FDE47407EC7F0D8CF6447400723F609A0E047402AABE97AA26747400723F609A0E047402AABE97AA26747402CB98AC56FDE47407EC7F0D8CF6447402CB98AC56FDE4740
31214	Средний Баскунчак	2	21	1175	46.781672999999998	46.799467999999997	48.212743000000003	48.203214000000003	0103000020E61000000100000005000000469561DC0D644740700B96EA021A4840469561DC0D644740FAB9A1293B1B48406919A9F754664740FAB9A1293B1B48406919A9F754664740700B96EA021A4840469561DC0D644740700B96EA021A4840
11162	Солянка	2	21	1175	45.871777999999999	45.882576	48.521152999999998	48.509455000000003	0103000020E61000000100000005000000A7AFE76B96EF464050E449D235414840A7AFE76B96EF46402C9B3924B5424840041E1840F8F046402C9B3924B5424840041E1840F8F0464050E449D235414840A7AFE76B96EF464050E449D235414840
57148	Село Садовое	2	21	1175	45.203772999999998	47.210375999999997	48.863928999999999	47.663894999999997	0103000020E610000001000000050000006667D13B159A46402C7DE882FAD447406667D13B159A46407288B839956E484080EECB99ED9A47407288B839956E484080EECB99ED9A47402C7DE882FAD447406667D13B159A46402C7DE882FAD44740
30196	Пологое Займище	2	21	1175	45.901359999999997	45.970359000000002	48.494011999999998	48.4602	0103000020E6100000010000000500000016F6B4C35FF3464042CF66D5E73A484016F6B4C35FF3464070EA03C93B3F48408C3045B934FC464070EA03C93B3F48408C3045B934FC464042CF66D5E73A484016F6B4C35FF3464042CF66D5E73A4840
57139	Покровка	2	21	1175	46.068330000000003	46.090662000000002	48.370247999999997	48.358604999999997	0103000020E61000000100000005000000F8AA9509BF0847404E97C5C4E62D4840F8AA9509BF08474067B45549642F4840B77EFACF9A0B474067B45549642F4840B77EFACF9A0B47404E97C5C4E62D4840F8AA9509BF0847404E97C5C4E62D4840
30618	Пироговка	2	21	1175	46.632184000000002	46.643126000000002	47.884244000000002	47.867038000000001	0103000020E61000000100000005000000F986C267EB504740D331E719FBEE4740F986C267EB50474095D74AE82EF14740899AE8F35152474095D74AE82EF14740899AE8F351524740D331E719FBEE4740F986C267EB504740D331E719FBEE4740
30423	Новониколаевка	2	21	1175	46.354343999999998	46.382829999999998	48.068624	48.040227999999999	0103000020E6100000010000000500000054C4E9245B2D47401631EC302605484054C4E9245B2D474040DCD5ABC8084840BEF6CC920031474040DCD5ABC8084840BEF6CC92003147401631EC302605484054C4E9245B2D47401631EC3026054840
31131	Нижний Баскунчак	2	21	1175	46.818773	46.839911000000001	48.232852999999999	48.20758	0103000020E6100000010000000500000085ECBC8DCD684740DFA63FFB911A484085ECBC8DCD68474043E38920CE1D48407C462234826B474043E38920CE1D48407C462234826B4740DFA63FFB911A484085ECBC8DCD684740DFA63FFB911A4840
29009	Капустин Яр	2	21	1175	45.695357999999999	45.707619999999999	48.404328999999997	48.399825	0103000020E610000001000000050000008881AE7D01D94640C58F31772D3348408881AE7D01D9464085E97B0DC13348406DFFCA4A93DA464085E97B0DC13348406DFFCA4A93DA4640C58F31772D3348408881AE7D01D94640C58F31772D334840
30696	Золотуха	2	21	1175	46.711576999999998	46.734493000000001	47.814760999999997	47.800885000000001	0103000020E61000000100000005000000FBCA83F4145B4740B16D516683E64740FBCA83F4145B47403387A4164AE847400A12DBDD035E47403387A4164AE847400A12DBDD035E4740B16D516683E64740FBCA83F4145B4740B16D516683E64740
57108	Знаменск	2	21	1175	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
30808	Верхний Баскунчак	2	21	1175	46.708173000000002	46.734986999999997	48.238625999999996	48.214683000000001	0103000020E610000001000000050000008274B169A55A4740EB0088BB7A1B48408274B169A55A4740D6FCF84B8B1E484019FED30D145E4740D6FCF84B8B1E484019FED30D145E4740EB0088BB7A1B48408274B169A55A4740EB0088BB7A1B4840
11592	Верблюжий	2	21	1175	46.871530999999997	46.884943	47.730350999999999	47.720556000000002	0103000020E610000001000000050000009F39EB538E6F4740E277D32D3BDC47409F39EB538E6F4740EACC3D247CDD47407DE9EDCF45714740EACC3D247CDD47407DE9EDCF45714740E277D32D3BDC47409F39EB538E6F4740E277D32D3BDC4740
30487	Болхуны	2	21	1175	46.409339000000003	46.431572000000003	47.998589000000003	47.982042	0103000020E610000001000000050000001AFD68386534474033A6608DB3FD47401AFD6838653447409B92ACC3D1FF474046EF54C03D3747409B92ACC3D1FF474046EF54C03D37474033A6608DB3FD47401AFD68386534474033A6608DB3FD4740
30400	Батаевка	2	21	1175	46.283960999999998	46.300373	48.152151000000003	48.129140999999997	0103000020E61000000100000005000000732B84D5582447404FC939B187104840732B84D558244740E08618AF79134840FBCC599F72264740E08618AF79134840FBCC599F722647404FC939B187104840732B84D5582447404FC939B187104840
46844	пгт Лесная Поляна	1	17	\N	39.888289	39.897218000000002	57.689987000000002	57.684386000000003	0103000020E61000000100000005000000C2323674B3F143408EEBDFF599D74C40C2323674B3F1434024D5777E51D84C40F7B0170AD8F2434024D5777E51D84C40F7B0170AD8F243408EEBDFF599D74C40C2323674B3F143408EEBDFF599D74C40
50639	д. Заболотье	1	17	\N	38.710408999999999	38.719042000000002	57.291969000000002	57.287489000000001	0103000020E610000001000000050000005CE49EAEEE5A4340D97A8670CCA44C405CE49EAEEE5A434011397D3D5FA54C40A8397991095C434011397D3D5FA54C40A8397991095C4340D97A8670CCA44C405CE49EAEEE5A4340D97A8670CCA44C40
2085	Ярославль	1	17	\N	39.730688000000001	40.002923000000003	57.775405999999997	57.530433000000002	0103000020E6100000010000000500000032CA332F87DD43400EDC813AE5C34C4032CA332F87DD4340A38FF98040E34C40FFB3E6C75F004440A38FF98040E34C40FFB3E6C75F0044400EDC813AE5C34C4032CA332F87DD43400EDC813AE5C34C40
50506	Ченцы	1	17	\N	39.728226999999997	39.733328999999998	57.731585000000003	57.727514999999997	0103000020E610000001000000050000003788D68A36DD4340BA2C26361FDD4C403788D68A36DD4340419FC893A4DD4C40AC1A84B9DDDD4340419FC893A4DD4C40AC1A84B9DDDD4340BA2C26361FDD4C403788D68A36DD4340BA2C26361FDD4C40
165	Углич	1	17	\N	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
3130	Рыбинск	1	17	\N	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
28001	Ростов	1	17	\N	39.371837999999997	39.464796	57.211801000000001	57.172649	0103000020E610000001000000050000007CB4386398AF4340F357C85C19964C407CB4386398AF43404B21904B1C9B4C40E3A7716F7EBB43404B21904B1C9B4C40E3A7716F7EBB4340F357C85C19964C407CB4386398AF4340F357C85C19964C40
50628	Покровское на Сити	1	17	\N	37.329402000000002	41.194088999999998	58.952478999999997	56.534638999999999	0103000020E61000000100000005000000569E40D829AA42404415FE0C6F444C40569E40D829AA42403A90F5D4EA794D40B5C189E8D79844403A90F5D4EA794D40B5C189E8D79844404415FE0C6F444C40569E40D829AA42404415FE0C6F444C40
12457	Переславль-Залесский	1	17	\N	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
50631	Переславль - Залесский	1	17	\N	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
50909	Нагорный	1	17	\N	39.833041999999999	39.842466000000002	57.563637999999997	57.557839999999999	0103000020E61000000100000005000000E318C91EA1EA43404833164D67C74C40E318C91EA1EA434034643C4A25C84C40F8FE06EDD5EB434034643C4A25C84C40F8FE06EDD5EB43404833164D67C74C40E318C91EA1EA43404833164D67C74C40
4288	Карачиха	1	17	\N	39.765461999999999	39.778424999999999	57.651542999999997	57.641274000000003	0103000020E61000000100000005000000562AA8A8FAE1434037E3344415D24C40562AA8A8FAE143400778D2C265D34C40C4B12E6EA3E343400778D2C265D34C40C4B12E6EA3E3434037E3344415D24C40562AA8A8FAE1434037E3344415D24C40
4225	Ивняки	1	17	\N	39.786473999999998	39.800119000000002	57.620877	57.613737999999998	0103000020E61000000100000005000000C093162EABE44340FE277FF78ECE4C40C093162EABE4434057EBC4E578CF4C4041F4A44C6AE6434057EBC4E578CF4C4041F4A44C6AE64340FE277FF78ECE4C40C093162EABE44340FE277FF78ECE4C40
4086	Заволжье	1	17	\N	40.011484000000003	40.019703	57.672066999999998	57.668621000000002	0103000020E61000000100000005000000B136C64E780144409C35785F95D54C40B136C64E7801444044DC9C4A06D64C400951BEA08502444044DC9C4A06D64C400951BEA0850244409C35785F95D54C40B136C64E780144409C35785F95D54C40
3953	Григорьевское	1	17	\N	40.003318	40.010882000000002	57.710196000000003	57.701842999999997	0103000020E610000001000000050000007BBE66B96C00444098F6CDFDD5D94C407BBE66B96C00444001E0D8B3E7DA4C40BB0ED5946401444001E0D8B3E7DA4C40BB0ED5946401444098F6CDFDD5D94C407BBE66B96C00444098F6CDFDD5D94C40
47161	Ананьино	1	17	\N	39.722020000000001	39.726996	57.685021999999996	57.682004999999997	0103000020E610000001000000050000006A87BF266BDC4340AF5A99F04BD74C406A87BF266BDC43402F8507CDAED74C40522976340EDD43402F8507CDAED74C40522976340EDD4340AF5A99F04BD74C406A87BF266BDC4340AF5A99F04BD74C40
50521	Ярославка	1	17	585	39.832422999999999	39.850226999999997	57.744835000000002	57.736400000000003	0103000020E6100000010000000500000017B83CD68CEA43402063EE5A42DE4C4017B83CD68CEA434045F5D6C056DF4C408D96033DD4EC434045F5D6C056DF4C408D96033DD4EC43402063EE5A42DE4C4017B83CD68CEA43402063EE5A42DE4C40
5299	Ширинье	1	17	585	39.327893000000003	39.340271999999999	57.559306999999997	57.548355999999998	0103000020E610000001000000050000002ECBD765F8A943405E48878730C64C402ECBD765F8A9434041B62C5F97C74C404CDF6B088EAB434041B62C5F97C74C404CDF6B088EAB43405E48878730C64C402ECBD765F8A943405E48878730C64C40
3666	Туношна	1	17	585	40.111232999999999	40.132334	57.548108999999997	57.535690000000002	0103000020E61000000100000005000000349E08E23C0E4440AA656B7D91C44C40349E08E23C0E444056D28A6F28C64C400E130D52F010444056D28A6F28C64C400E130D52F0104440AA656B7D91C44C40349E08E23C0E4440AA656B7D91C44C40
4980	Толбухино	1	17	585	40.032440999999999	40.059094000000002	57.857965	57.846480999999997	0103000020E610000001000000050000005706D50627044440BAD7497D59EC4C405706D506270444406B0E10CCD1ED4C40E6B16664900744406B0E10CCD1ED4C40E6B1666490074440BAD7497D59EC4C405706D50627044440BAD7497D59EC4C40
50944	Спасс	1	17	585	40.188209000000001	40.192242999999998	57.802003999999997	57.796607999999999	0103000020E610000001000000050000000CE8853B17184440B1DD3D40F7E54C400CE8853B171844406EA12B11A8E64C4045F12A6B9B1844406EA12B11A8E64C4045F12A6B9B184440B1DD3D40F7E54C400CE8853B17184440B1DD3D40F7E54C40
4179	Сарафоново	1	17	585	39.982782999999998	39.989071000000003	57.462218999999997	57.458635999999998	0103000020E610000001000000050000004A0856D5CBFD434056629E95B4BA4C404A0856D5CBFD43407F4B00FE29BB4C400536E7E099FE43407F4B00FE29BB4C400536E7E099FE434056629E95B4BA4C404A0856D5CBFD434056629E95B4BA4C40
46172	Прусово	1	17	585	40.144990999999997	40.157685000000001	57.576799999999999	57.572037000000002	0103000020E610000001000000050000006F9BA9108F1244400D8D278238C94C406F9BA9108F124440992A1895D4C94C40EE08A7052F144440992A1895D4C94C40EE08A7052F1444400D8D278238C94C406F9BA9108F1244400D8D278238C94C40
4120	Пестрецово	1	17	585	40.065750999999999	40.078130000000002	57.663561000000001	57.656526999999997	0103000020E61000000100000005000000F3565D876A08444072F8A41309D44C40F3565D876A08444056F31C91EFD44C40126BF129000A444056F31C91EFD44C40126BF129000A444072F8A41309D44C40F3565D876A08444072F8A41309D44C40
5367	Мордвиново	1	17	585	39.443398000000002	39.455786000000003	57.617773	57.612918000000001	0103000020E61000000100000005000000508E0244C1B843409B90D61874CE4C40508E0244C1B8434008AD872F13CF4C40C2FC153257BA434008AD872F13CF4C40C2FC153257BA43409B90D61874CE4C40508E0244C1B843409B90D61874CE4C40
49007	Михайловское	1	17	585	39.563763000000002	39.581235999999997	57.551495000000003	57.546109999999999	0103000020E61000000100000005000000F1D8CF6229C843406002B7EEE6C54C40F1D8CF6229C843402A745E6397C64C4001A1F5F065CA43402A745E6397C64C4001A1F5F065CA43406002B7EEE6C54C40F1D8CF6229C843406002B7EEE6C54C40
47457	Михайловский	1	17	585	39.725245000000001	39.751125000000002	57.790846999999999	57.777017999999998	0103000020E61000000100000005000000344B02D4D4DC4340A033695375E34C40344B02D4D4DC4340E29178793AE54C40A01A2FDD24E04340E29178793AE54C40A01A2FDD24E04340A033695375E34C40344B02D4D4DC4340A033695375E34C40
4792	Медягино	1	17	585	39.944361999999998	39.969155000000001	57.762166999999998	57.751584000000001	0103000020E61000000100000005000000E6CAA0DAE0F8434033198EE733E04C40E6CAA0DAE0F84340938B31B08EE14C40A0E062450DFC4340938B31B08EE14C40A0E062450DFC434033198EE733E04C40E6CAA0DAE0F8434033198EE733E04C40
47376	Курба	1	17	585	39.486293000000003	39.520806	57.568755000000003	57.553488999999999	0103000020E610000001000000050000000AA359D93EBE43400ED940BAD8C64C400AA359D93EBE4340DF37BEF6CCC84C40C1C760C5A9C24340DF37BEF6CCC84C40C1C760C5A9C243400ED940BAD8C64C400AA359D93EBE43400ED940BAD8C64C40
47226	Кузнечиха	1	17	585	39.878442999999997	39.931649999999998	57.811349	57.700851999999998	0103000020E610000001000000050000003733FAD170F0434008ABB184B5D94C403733FAD170F043403752B648DAE74C40C1A8A44E40F743403752B648DAE74C40C1A8A44E40F7434008ABB184B5D94C403733FAD170F0434008ABB184B5D94C40
4344	Красные Ткачи	1	17	585	39.741477000000003	39.766100000000002	57.499544	57.472427000000003	0103000020E610000001000000050000003CDEE4B7E8DE4340AB5FE97C78BC4C403CDEE4B7E8DE4340DE74CB0EF1BF4C4099BB96900FE24340DE74CB0EF1BF4C4099BB96900FE24340AB5FE97C78BC4C403CDEE4B7E8DE4340AB5FE97C78BC4C40
50910	Красное	1	17	585	40.351953999999999	40.364503999999997	57.595191999999997	57.587705	0103000020E6100000010000000500000023D923D40C2D44400C59DDEA39CB4C4023D923D40C2D4440A06B5F402FCC4C406EA12B11A82E4440A06B5F402FCC4C406EA12B11A82E44400C59DDEA39CB4C4023D923D40C2D44400C59DDEA39CB4C40
50912	Кормилицыно	1	17	585	39.716261000000003	39.736294000000001	57.479177999999997	57.467644999999997	0103000020E610000001000000050000003C33C170AEDB4340A79196CADBBB4C403C33C170AEDB4340397B67B455BD4C40DA1EBDE13EDE4340397B67B455BD4C40DA1EBDE13EDE4340A79196CADBBB4C403C33C170AEDB4340A79196CADBBB4C40
5140	Козьмодемьянск	1	17	585	39.672217000000003	39.680922000000002	57.534323000000001	57.529480999999997	0103000020E610000001000000050000005A68E7340BD643403B6D8D08C6C34C405A68E7340BD64340144031B264C44C403F90BC7328D74340144031B264C44C403F90BC7328D743403B6D8D08C6C34C405A68E7340BD643403B6D8D08C6C34C40
4512	Карабиха	1	17	585	39.759228	39.775559000000001	57.516829000000001	57.504185999999997	0103000020E610000001000000050000008F1A13622EE14340EF8CB62A89C04C408F1A13622EE14340EC4FE27327C24C402A8F6E8445E34340EC4FE27327C24C402A8F6E8445E34340EF8CB62A89C04C408F1A13622EE14340EF8CB62A89C04C40
50915	Ермаково	1	17	585	39.969648999999997	39.977375000000002	57.809935000000003	57.805979000000001	0103000020E61000000100000005000000AFCC5B751DFC4340A321E3512AE74C40AFCC5B751DFC4340617138F3ABE74C40C976BE9F1AFD4340617138F3ABE74C40C976BE9F1AFD4340A321E3512AE74C40AFCC5B751DFC4340A321E3512AE74C40
47078	Дубки	1	17	585	39.721606000000001	39.754322999999999	57.536932	57.523251999999999	0103000020E61000000100000005000000774CDD955DDC434086C8E9EBF9C24C40774CDD955DDC434083161230BAC44C4070CFF3A78DE0434083161230BAC44C4070CFF3A78DE0434086C8E9EBF9C24C40774CDD955DDC434086C8E9EBF9C24C40
5042	Глебовское	1	17	585	39.944262999999999	39.962822000000003	57.801898000000001	57.790089000000002	0103000020E6100000010000000500000053E9279CDDF84340F5F6E7A221E54C4053E9279CDDF84340295DFA97A4E64C4046EF54C03DFB4340295DFA97A4E64C4046EF54C03DFB4340F5F6E7A221E54C4053E9279CDDF84340F5F6E7A221E54C40
4939	Андроники	1	17	585	39.978577999999999	39.991892	57.864113000000003	57.856400000000001	0103000020E61000000100000005000000E44A3D0B42FD4340AF25E4839EED4C40E44A3D0B42FD4340348639419BEE4C40FF942A51F6FE4340348639419BEE4C40FF942A51F6FE4340AF25E4839EED4C40E44A3D0B42FD4340AF25E4839EED4C40
15292	Михальково	1	17	802	38.022623000000003	38.040571	58.665070999999998	58.659861999999997	0103000020E6100000010000000500000097917A4FE5024340C3EFA65B76544D4097917A4FE50243404E42E90B21554D404015376E310543404E42E90B21554D404015376E31054340C3EFA65B76544D4097917A4FE5024340C3EFA65B76544D40
1534	Шубино	1	17	330	38.342269999999999	38.484779000000003	57.625706000000001	57.602421	0103000020E610000001000000050000007233DC80CF2B434039B69E211CCD4C407233DC80CF2B43409B745B2217D04C40D064FF3C0D3E43409B745B2217D04C40D064FF3C0D3E434039B69E211CCD4C407233DC80CF2B434039B69E211CCD4C40
3337	Шишкино	1	17	330	37.938369999999999	37.956992	57.416165999999997	57.411521999999998	0103000020E6100000010000000500000015C616821CF84240D1CABDC0ACB44C4015C616821CF8424083DA6FED44B54C404E44BFB67EFA424083DA6FED44B54C404E44BFB67EFA4240D1CABDC0ACB44C4015C616821CF84240D1CABDC0ACB44C40
2817	Чурьяково	1	17	330	38.363596000000001	38.379945999999997	57.547848000000002	57.537613	0103000020E610000001000000050000006C7A50508A2E4340C573B680D0C44C406C7A50508A2E4340EA961DE21FC64C407D1F0E12A2304340EA961DE21FC64C407D1F0E12A2304340C573B680D0C44C406C7A50508A2E4340C573B680D0C44C40
3253	Ульянкино	1	17	330	37.841504	37.853883000000003	57.521372	57.515833000000001	0103000020E6100000010000000500000002BA2F67B6EB42404A99D4D006C24C4002BA2F67B6EB42406A865451BCC24C4021CEC3094CED42406A865451BCC24C4021CEC3094CED42404A99D4D006C24C4002BA2F67B6EB42404A99D4D006C24C40
2662	Улейма	1	17	330	38.404595	38.420253000000002	57.446278999999997	57.436233000000001	0103000020E610000001000000050000000490DAC4C9334340CE37A27BD6B74C400490DAC4C93343401FF296AB1FB94C40E085ADD9CA3543401FF296AB1FB94C40E085ADD9CA354340CE37A27BD6B74C400490DAC4C9334340CE37A27BD6B74C40
2573	Сосновый	1	17	330	38.304802000000002	38.315086999999998	57.496583999999999	57.485807000000001	0103000020E61000000100000005000000B1E07EC0032743407D957CEC2EBE4C40B1E07EC003274340C2DB831090BF4C40873254C554284340C2DB831090BF4C40873254C5542843407D957CEC2EBE4C40B1E07EC0032743407D957CEC2EBE4C40
3468	Прилуки	1	17	330	38.028812000000002	38.048557000000002	57.369467	57.361705999999998	0103000020E61000000100000005000000BEDD921CB00343402C62D8614CAE4C40BEDD921CB0034340C2F9D4B14AAF4C40F67EA31D37064340C2F9D4B14AAF4C40F67EA31D370643402C62D8614CAE4C40BEDD921CB00343402C62D8614CAE4C40
2880	Покровское	1	17	330	38.551119999999997	38.569194000000003	57.664282999999998	57.656036	0103000020E61000000100000005000000F415A4198B464340D47FD6FCF8D34C40F415A4198B464340F624B03907D54C402B8A5759DB484340F624B03907D54C402B8A5759DB484340D47FD6FCF8D34C40F415A4198B464340D47FD6FCF8D34C40
1782	Платуново	1	17	330	38.018597999999997	38.039233000000003	57.617381999999999	57.608086999999998	0103000020E61000000100000005000000B0E2546B61024340B60F79CBD5CD4C40B0E2546B61024340CD91955F06CF4C4045F6419605054340CD91955F06CF4C4045F6419605054340B60F79CBD5CD4C40B0E2546B61024340B60F79CBD5CD4C40
1872	Отрадный	1	17	330	38.236879999999999	38.24456	57.590333999999999	57.584622000000003	0103000020E61000000100000005000000CA897615521E4340D542C9E4D4CA4C40CA897615521E4340C2DB831090CB4C4073F4F8BD4D1F4340C2DB831090CB4C4073F4F8BD4D1F4340D542C9E4D4CA4C40CA897615521E4340D542C9E4D4CA4C40
1730	Ордино	1	17	330	37.920259999999999	37.929602000000003	57.606250000000003	57.599941999999999	0103000020E6100000010000000500000092E86514CBF5424098BF42E6CACC4C4092E86514CBF542409A99999999CD4C40EA25C632FDF642409A99999999CD4C40EA25C632FDF6424098BF42E6CACC4C4092E86514CBF5424098BF42E6CACC4C40
2919	Овинищи Никольское	1	17	330	38.388613999999997	38.401173	57.477136000000002	57.473376000000002	0103000020E610000001000000050000004562821ABE3143400C5BB39597BC4C404562821ABE31434044DFDDCA12BD4C40E48409A35933434044DFDDCA12BD4C40E48409A3593343400C5BB39597BC4C404562821ABE3143400C5BB39597BC4C40
2131	Ново	1	17	330	38.604011999999997	38.625571999999998	57.306440000000002	57.29477	0103000020E610000001000000050000001E32E543504D4340C4EBFA05BBA54C401E32E543504D4340D717096D39A74C408BA548BE12504340D717096D39A74C408BA548BE12504340C4EBFA05BBA54C401E32E543504D4340C4EBFA05BBA54C40
1646	Нинорово	1	17	330	38.266101999999997	38.283520000000003	57.649009	57.636614999999999	0103000020E6100000010000000500000039B35DA10F2243404F92AE997CD14C4039B35DA10F224340A3E716BA12D34C4087E123624A244340A3E716BA12D34C4087E123624A2443404F92AE997CD14C4039B35DA10F2243404F92AE997CD14C40
2471	Нефедьево	1	17	330	38.598030000000001	38.625957999999997	57.427748999999999	57.417135000000002	0103000020E6100000010000000500000071033E3F8C4C43402C82FFAD64B54C4071033E3F8C4C4340C7F2AE7AC0B64C40B45549641F504340C7F2AE7AC0B64C40B45549641F5043402C82FFAD64B54C4071033E3F8C4C43402C82FFAD64B54C40
3026	Масальское	1	17	330	38.035342999999997	38.050345	57.549697999999999	57.539811	0103000020E610000001000000050000003E92921E86044340B282DF8618C54C403E92921E860443409B560A815CC64C40314278B4710643409B560A815CC64C40314278B471064340B282DF8618C54C403E92921E86044340B282DF8618C54C40
2522	Маймеры	1	17	330	38.208070999999997	38.232945000000001	57.417591000000002	57.408375999999997	0103000020E610000001000000050000007D1F0E12A21A4340533C2EAA45B44C407D1F0E12A21A43404E0D349F73B54C4024624A24D11D43404E0D349F73B54C4024624A24D11D4340533C2EAA45B44C407D1F0E12A21A4340533C2EAA45B44C40
3139	Климатино	1	17	330	37.945377000000001	37.963701999999998	57.526784999999997	57.519212000000003	0103000020E61000000100000005000000FFB1101D02F942406BD8EF8975C24C40FFB1101D02F94240FD82DDB06DC34C407E8B4E965AFB4240FD82DDB06DC34C407E8B4E965AFB42406BD8EF8975C24C40FFB1101D02F942406BD8EF8975C24C40
2773	Клементьево	1	17	330	38.778007000000002	38.794114	57.506169	57.497763999999997	0103000020E610000001000000050000009087BEBB95634340259012BBB6BF4C409087BEBB95634340E09F5225CAC04C40DBA50D87A5654340E09F5225CAC04C40DBA50D87A5654340259012BBB6BF4C409087BEBB95634340259012BBB6BF4C40
2225	Каблуково	1	17	330	38.497849000000002	38.512438000000003	57.263548999999998	57.257624999999997	0103000020E6100000010000000500000054AC1A84B93F4340E5D022DBF9A04C4054AC1A84B93F43405EF23FF9BBA14C40249D8191974143405EF23FF9BBA14C40249D819197414340E5D022DBF9A04C4054AC1A84B93F4340E5D022DBF9A04C40
1970	Ильинское	1	17	330	38.492899999999999	38.520423999999998	57.328364999999998	57.317951000000001	0103000020E610000001000000050000006519E258173F4340815D4D9EB2A84C406519E258173F4340551344DD07AA4C40D906EE409D424340551344DD07AA4C40D906EE409D424340815D4D9EB2A84C406519E258173F4340815D4D9EB2A84C40
50918	Зеленая  Роща	1	17	330	37.801403999999998	38.871296999999998	57.727597000000003	57.079498999999998	0103000020E610000001000000050000001971016894E642404888F2052D8A4C401971016894E6424078D503E621DD4C402C0DFCA8866F434078D503E621DD4C402C0DFCA8866F43404888F2052D8A4C401971016894E642404888F2052D8A4C40
3287	Заречье	1	17	330	37.916316000000002	37.922407	57.441749999999999	57.438896999999997	0103000020E610000001000000050000009966BAD749F5424000A8E2C62DB84C409966BAD749F54240068195438BB84C40FD4CBD6E11F64240068195438BB84C40FD4CBD6E11F6424000A8E2C62DB84C409966BAD749F5424000A8E2C62DB84C40
2327	Заозерье	1	17	330	38.229595000000003	38.263990999999997	57.207126000000002	57.186826000000003	0103000020E610000001000000050000009E29745E631D4340710514EAE9974C409E29745E631D43405E13D21A839A4C401BB80375CA2143405E13D21A839A4C401BB80375CA214340710514EAE9974C409E29745E631D4340710514EAE9974C40
3579	Головино	1	17	330	38.153049000000003	38.178705000000001	57.496617999999998	57.489803000000002	0103000020E61000000100000005000000BFD7101C97134340C93D5DDDB1BE4C40BFD7101C971343406E4DBA2D91BF4C40DB5031CEDF1643406E4DBA2D91BF4C40DB5031CEDF164340C93D5DDDB1BE4C40BFD7101C97134340C93D5DDDB1BE4C40
2331	Вякирево	1	17	330	38.303364000000002	38.317889999999998	57.140255000000003	57.135390000000001	0103000020E610000001000000050000005264ADA1D42643404C1AA37554914C405264ADA1D4264340DD0C37E0F3914C40DBDC989EB0284340DD0C37E0F3914C40DBDC989EB02843404C1AA37554914C405264ADA1D42643404C1AA37554914C40
3386	Воздвиженское	1	17	330	38.041558999999999	38.067439999999998	57.395733999999997	57.385188999999997	0103000020E610000001000000050000005FED28CE51054340B4E386DF4DB14C405FED28CE5105434027F56569A7B24C409B38B9DFA108434027F56569A7B24C409B38B9DFA1084340B4E386DF4DB14C405FED28CE51054340B4E386DF4DB14C40
2195	Василево	1	17	330	38.576030000000003	38.590933	57.240017000000002	57.230499000000002	0103000020E61000000100000005000000E8C1DD59BB4943405F61C1FD809D4C40E8C1DD59BB494340F5BD86E0B89E4C4047904AB1A34B4340F5BD86E0B89E4C4047904AB1A34B43405F61C1FD809D4C40E8C1DD59BB4943405F61C1FD809D4C40
2986	Варгуново	1	17	330	38.462474	38.472481000000002	57.507734999999997	57.502527999999998	0103000020E610000001000000050000000AA01859323B434082A966D652C04C400AA01859323B43406C04E275FDC04C409E7DE5417A3C43406C04E275FDC04C409E7DE5417A3C434082A966D652C04C400AA01859323B434082A966D652C04C40
1826	Бурмасово	1	17	330	38.175345	38.205978000000002	57.551287000000002	57.537984999999999	0103000020E61000000100000005000000314278B471164340895E46B1DCC44C40314278B471164340E0DA899290C64C4006D9B27C5D1A4340E0DA899290C64C4006D9B27C5D1A4340895E46B1DCC44C40314278B471164340895E46B1DCC44C40
2434	Белоусово	1	17	330	38.400830999999997	38.414709999999999	57.126855999999997	57.114106999999997	0103000020E610000001000000050000008A1C226E4E334340519FE40E9B8E4C408A1C226E4E33434093A641D13C904C407EA99F371535434093A641D13C904C407EA99F3715354340519FE40E9B8E4C408A1C226E4E334340519FE40E9B8E4C40
1632	Алтыново	1	17	330	38.277510999999997	38.295270000000002	57.570174000000002	57.560954000000002	0103000020E61000000100000005000000DFA3FE7A85234340BB473657CDC74C40DFA3FE7A85234340C7832D76FBC84C40B6BE4868CB254340C7832D76FBC84C40B6BE4868CB254340BB473657CDC74C40DFA3FE7A85234340BB473657CDC74C40
50520	Ясиплево	1	17	31	39.500647999999998	39.515165000000003	57.932031000000002	57.925106999999997	0103000020E610000001000000050000006667D13B15C043407C26FBE769F64C406667D13B15C04340D9EDB3CA4CF74C409D853DEDF0C14340D9EDB3CA4CF74C409D853DEDF0C143407C26FBE769F64C406667D13B15C043407C26FBE769F64C40
836	Чебаково	1	17	31	39.525162999999999	39.555723999999998	57.765920999999999	57.747962000000001	0103000020E61000000100000005000000DD088B8A38C343404C530438BDDF4C40DD088B8A38C34340E92807B309E24C4018CDCAF621C74340E92807B309E24C4018CDCAF621C743404C530438BDDF4C40DD088B8A38C343404C530438BDDF4C40
37	Фоминское	1	17	31	39.553576999999997	39.582808	57.847256999999999	57.833613	0103000020E61000000100000005000000AD68739CDBC643409E42AED4B3EA4C40AD68739CDBC643404E27D9EA72EC4C4070ECD97399CA43404E27D9EA72EC4C4070ECD97399CA43409E42AED4B3EA4C40AD68739CDBC643409E42AED4B3EA4C40
31124	Тутаев	1	17	31	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
50575	Столбищи	1	17	31	39.275089999999999	39.293971999999997	57.889124000000002	57.882100000000001	0103000020E6100000010000000500000073BA2C2636A343409BE61DA7E8F04C4073BA2C2636A343405B0BB3D0CEF14C4048F8DEDFA0A543405B0BB3D0CEF14C4048F8DEDFA0A543409BE61DA7E8F04C4073BA2C2636A343409BE61DA7E8F04C40
50533	Савинское	1	17	31	39.363565000000001	39.376725	57.944629999999997	57.936461000000001	0103000020E61000000100000005000000317C444C89AE43405F7D3CF4DDF74C40317C444C89AE43400569C6A2E9F84C40F54A598638B043400569C6A2E9F84C40F54A598638B043405F7D3CF4DDF74C40317C444C89AE43405F7D3CF4DDF74C40
50924	Рождественное	1	17	31	39.324829999999999	39.337325	57.921636999999997	57.913429000000001	0103000020E610000001000000050000003D61890794A94340E71BD13DEBF44C403D61890794A943404BE48233F8F54C40C58F31772DAB43404BE48233F8F54C40C58F31772DAB4340E71BD13DEBF44C403D61890794A94340E71BD13DEBF44C40
681	Пшеничище	1	17	31	39.627256000000003	39.649183999999998	57.850073000000002	57.840420999999999	0103000020E61000000100000005000000221CB3EC49D0434091EF52EA92EB4C40221CB3EC49D04340371B2B31CFEC4C40118B187618D34340371B2B31CFEC4C40118B187618D3434091EF52EA92EB4C40221CB3EC49D0434091EF52EA92EB4C40
49056	Погорелка	1	17	31	39.346325999999998	39.359549000000001	58.063434999999998	58.059306999999997	0103000020E6100000010000000500000093E00D6954AC434041B62C5F97074D4093E00D6954AC4340FC3559A31E084D409E279EB305AE4340FC3559A31E084D409E279EB305AE434041B62C5F97074D4093E00D6954AC434041B62C5F97074D40
50543	Першино	1	17	31	39.467266000000002	39.476770999999999	58.110897999999999	58.103352000000001	0103000020E6100000010000000500000031444E5FCFBB4340F4FC69A33A0D4D4031444E5FCFBB43408D98D9E7310E4D40325706D506BD43408D98D9E7310E4D40325706D506BD4340F4FC69A33A0D4D4031444E5FCFBB4340F4FC69A33A0D4D40
50511	Павловское	1	17	31	39.597225999999999	39.656461	57.950122999999998	57.771056999999999	0103000020E610000001000000050000001329CDE671CC43400A2DEBFEB1E24C401329CDE671CC4340B51666A19DF94C40BB0CFFE906D44340B51666A19DF94C40BB0CFFE906D443400A2DEBFEB1E24C401329CDE671CC43400A2DEBFEB1E24C40
777	Никульское	1	17	31	39.464418999999999	39.481855000000003	57.686556000000003	57.678789999999999	0103000020E610000001000000050000000D52F01472BB4340096D3997E2D64C400D52F01472BB4340B16F2711E1D74C400135B56CADBD4340B16F2711E1D74C400135B56CADBD4340096D3997E2D64C400D52F01472BB4340096D3997E2D64C40
50519	Никольское	1	17	31	39.756343999999999	39.774363999999998	58.008490000000002	57.998584999999999	0103000020E610000001000000050000004E4354E1CFE0434059A31EA2D1FF4C404E4354E1CFE04340E92B483316014D4091990B5C1EE34340E92B483316014D4091990B5C1EE3434059A31EA2D1FF4C404E4354E1CFE0434059A31EA2D1FF4C40
49107	Назарово	1	17	31	39.827894999999998	39.853264000000003	57.985567000000003	57.978591000000002	0103000020E61000000100000005000000CEC29E76F8E9434079944A7842FD4C40CEC29E76F8E943402882380F27FE4C40556D37C137ED43402882380F27FE4C40556D37C137ED434079944A7842FD4C40CEC29E76F8E9434079944A7842FD4C40
414	Микляиха	1	17	31	39.623735000000003	39.643245999999998	57.801414000000001	57.793514000000002	0103000020E610000001000000050000006F2F698CD6CF43408675E3DD91E54C406F2F698CD6CF43403D47E4BB94E64C4033A48AE255D243403D47E4BB94E64C4033A48AE255D243408675E3DD91E54C406F2F698CD6CF43408675E3DD91E54C40
290	Константиновский	1	17	31	39.566288	39.622441000000002	57.840420999999999	57.810946999999999	0103000020E61000000100000005000000020F0C207CC8434008E57D1CCDE74C40020F0C207CC8434091EF52EA92EB4C4043588D25ACCF434091EF52EA92EB4C4043588D25ACCF434008E57D1CCDE74C40020F0C207CC8434008E57D1CCDE74C40
47392	Иванищево	1	17	31	39.410420999999999	39.420473000000001	57.695937000000001	57.691082999999999	0103000020E61000000100000005000000BA4BE2AC88B4434029E9616875D84C40BA4BE2AC88B44340C689AF7614D94C40EEEC2B0FD2B54340C689AF7614D94C40EEEC2B0FD2B5434029E9616875D84C40BA4BE2AC88B4434029E9616875D84C40
50558	Емишево	1	17	31	39.394404000000002	39.408562000000003	57.906863999999999	57.897700999999998	0103000020E61000000100000005000000AFB48CD47BB24340124BCADDE7F24C40AFB48CD47BB24340BAF59A1E14F44C40B63176C24BB44340BAF59A1E14F44C40B63176C24BB44340124BCADDE7F24C40AFB48CD47BB24340124BCADDE7F24C40
579	Выползово	1	17	31	39.457321999999998	39.489849999999997	57.944606	57.938754000000003	0103000020E61000000100000005000000E3DEFC8689BA43409E7E501729F84C40E3DEFC8689BA43407DCD72D9E8F84C4009F9A067B3BE43407DCD72D9E8F84C4009F9A067B3BE43409E7E501729F84C40E3DEFC8689BA43409E7E501729F84C40
50542	Верещагино	1	17	31	39.791108999999999	39.802607999999999	57.949468000000003	57.945681	0103000020E610000001000000050000001F49490F43E543406BB933130CF94C401F49490F43E543409D4CDC2A88F94C4005C1E3DBBBE643409D4CDC2A88F94C4005C1E3DBBBE643406BB933130CF94C401F49490F43E543406BB933130CF94C40
32383	Великое Село	1	17	31	39.607224000000002	39.638378000000003	58.09901	58.088402000000002	0103000020E6100000010000000500000054AC1A84B9CD43405473B9C1500B4D4054AC1A84B9CD43400DFD135CAC0C4D40323ECC5EB6D143400DFD135CAC0C4D40323ECC5EB6D143405473B9C1500B4D4054AC1A84B9CD43405473B9C1500B4D40
32325	Борисоглеб	1	17	31	39.675728999999997	39.693767999999999	57.939245999999997	57.931181000000002	0103000020E61000000100000005000000B9FAB1497ED643400BD462F030F74C40B9FAB1497ED643400C73823639F84C407381CB63CDD843400C73823639F84C407381CB63CDD843400BD462F030F74C40B9FAB1497ED643400BD462F030F74C40
49266	Юбилейный	1	17	1894	38.708297999999999	38.735354999999998	58.064030000000002	58.043210000000002	0103000020E610000001000000050000003EE94482A95A43401A6EC0E787054D403EE94482A95A434040FB912232084D409CF9D51C205E434040FB912232084D409CF9D51C205E43401A6EC0E787054D403EE94482A95A43401A6EC0E787054D40
49273	Тихменево	1	17	1894	38.602969999999999	38.62771	58.002377000000003	57.982804000000002	0103000020E610000001000000050000000C3CF71E2E4D434062307F85CCFD4C400C3CF71E2E4D43409DA1B8E34D004D40A3AF20CD585043409DA1B8E34D004D40A3AF20CD5850434062307F85CCFD4C400C3CF71E2E4D434062307F85CCFD4C40
30911	Судоверфь	1	17	1894	38.630997999999998	38.650661999999997	58.119630999999998	58.107236999999998	0103000020E61000000100000005000000B3EBDE8AC4504340E8F527F1B90D4D40B3EBDE8AC45043403C4B9011500F4D40FE5F75E4485343403C4B9011500F4D40FE5F75E448534340E8F527F1B90D4D40B3EBDE8AC4504340E8F527F1B90D4D40
49036	Сретенье	1	17	1894	38.800555000000003	38.816949000000001	57.938882999999997	57.924599999999998	0103000020E610000001000000050000001CD3139678664340D8F0F44A59F64C401CD31396786643409BE271512DF84C40FDBFEAC8916843409BE271512DF84C40FDBFEAC891684340D8F0F44A59F64C401CD3139678664340D8F0F44A59F64C40
46562	Семеновское	1	17	1894	38.966068999999997	38.976534999999998	58.033766999999997	58.025298999999997	0103000020E61000000100000005000000F7562426A87B43408DCF64FF3C034D40F7562426A87B43408E57207A52044D401E335019FF7C43408E57207A52044D401E335019FF7C43408DCF64FF3C034D40F7562426A87B43408DCF64FF3C034D40
30957	Свингино	1	17	1894	38.614756	38.628976999999999	58.120714999999997	58.114249999999998	0103000020E6100000010000000500000088821953B04E4340B4C876BE9F0E4D4088821953B04E43407D91D096730F4D40D5777E51825043407D91D096730F4D40D5777E5182504340B4C876BE9F0E4D4088821953B04E4340B4C876BE9F0E4D40
50537	Октябрьский	1	17	1894	39.096639000000003	39.116267999999998	57.987451999999998	57.982089000000002	0103000020E610000001000000050000005342B0AA5E8C43407461A417B5FD4C405342B0AA5E8C4340552FBFD364FE4C4021C9ACDEE18E4340552FBFD364FE4C4021C9ACDEE18E43407461A417B5FD4C405342B0AA5E8C43407461A417B5FD4C40
47492	Мокеевское	1	17	1894	38.925178000000002	38.931511	57.956149000000003	57.952831000000003	0103000020E61000000100000005000000467D923B6C764340B8CEBF5DF6F94C40467D923B6C764340338D261763FA4C40A06EA0C03B774340338D261763FA4C40A06EA0C03B774340B8CEBF5DF6F94C40467D923B6C764340B8CEBF5DF6F94C40
30520	Милюшино	1	17	1894	38.861353000000001	38.879255999999998	58.303384000000001	58.282575999999999	0103000020E61000000100000005000000DFA7AAD0406E434037514B732B244D40DFA7AAD0406E434099107349D5264D40E867EA758B70434099107349D5264D40E867EA758B70434037514B732B244D40DFA7AAD0406E434037514B732B244D40
49095	Майский	1	17	1894	38.9741	38.984583999999998	58.075740000000003	58.069642999999999	0103000020E610000001000000050000004D840D4FAF7C43409AB2D30FEA084D404D840D4FAF7C4340E17F2BD9B1094D401A1538D9067E4340E17F2BD9B1094D401A1538D9067E43409AB2D30FEA084D404D840D4FAF7C43409AB2D30FEA084D40
46044	Лапино	1	17	1894	39.240189999999998	39.246603999999998	57.912568	57.908977	0103000020E61000000100000005000000C269C18BBE9E434079E8BB5B59F44C40C269C18BBE9E434025B03907CFF44C40098849B8909F434025B03907CFF44C40098849B8909F434079E8BB5B59F44C40C269C18BBE9E434079E8BB5B59F44C40
49188	Красная Горка	1	17	1894	38.833055999999999	38.866419	57.999910999999997	57.982785	0103000020E6100000010000000500000048DE3994A16A4340EBFF1CE6CBFD4C4048DE3994A16A434090F46915FDFF4C4007D15AD1E66E434090F46915FDFF4C4007D15AD1E66E4340EBFF1CE6CBFD4C4048DE3994A16A4340EBFF1CE6CBFD4C40
30814	Искра Октября	1	17	1894	38.760472	38.779713999999998	58.021771999999999	58.007922999999998	0103000020E6100000010000000500000009C38025576143406FF1F09E03014D4009C3802557614340F8FBC56CC9024D40DE1D19ABCD634340F8FBC56CC9024D40DE1D19ABCD6343406FF1F09E03014D4009C38025576143406FF1F09E03014D40
50570	Дюдьково	1	17	1894	39.217849000000001	39.230003000000004	57.968018999999998	57.961635999999999	0103000020E61000000100000005000000B03BDD79E29B4340005471E316FB4C40B03BDD79E29B43400C74ED0BE8FB4C40AF7D01BD709D43400C74ED0BE8FB4C40AF7D01BD709D4340005471E316FB4C40B03BDD79E29B4340005471E316FB4C40
27955	Шурскол	1	17	1827	39.282482999999999	39.302309000000001	57.156582999999998	57.148482999999999	0103000020E610000001000000050000008656276728A443408881AE7D01934C408656276728A44340060E68E90A944C40AB24B20FB2A64340060E68E90A944C40AB24B20FB2A643408881AE7D01934C408656276728A443408881AE7D01934C40
28751	Чепорово	1	17	1827	39.004579999999997	39.018064000000003	57.008186000000002	56.995621999999997	0103000020E610000001000000050000009B1BD31396804340CC96AC8A707F4C409B1BD313968043407D24253D0C814C40139ED0EB4F8243407D24253D0C814C40139ED0EB4F824340CC96AC8A707F4C409B1BD31396804340CC96AC8A707F4C40
29232	Хмельники	1	17	1827	39.284747000000003	39.302802999999997	56.943770999999998	56.935305999999997	0103000020E610000001000000050000002B51F69672A4434054E0641BB8774C402B51F69672A44340E4F4F57CCD784C40BA10AB3FC2A64340E4F4F57CCD784C40BA10AB3FC2A6434054E0641BB8774C402B51F69672A4434054E0641BB8774C40
29434	Угодичи	1	17	1827	39.494225	39.523977000000002	57.170917000000003	57.155836000000001	0103000020E61000000100000005000000CCEEC9C342BF43400DC51D6FF2934C40CCEEC9C342BF43404CAAB69BE0954C40986DA7AD11C343404CAAB69BE0954C40986DA7AD11C343400DC51D6FF2934C40CCEEC9C342BF43400DC51D6FF2934C40
29891	Татищев-Погост	1	17	1827	39.463088999999997	39.478279999999998	57.338703000000002	57.329813000000001	0103000020E610000001000000050000009411178046BB4340D865F84F37AA4C409411178046BB43404F07B29E5AAB4C405A2A6F4738BD43404F07B29E5AAB4C405A2A6F4738BD4340D865F84F37AA4C409411178046BB4340D865F84F37AA4C40
29529	Сулость	1	17	1827	39.511760000000002	39.526322	57.211319000000003	57.195337000000002	0103000020E6100000010000000500000053B3075A81C14340715985CD00994C4053B3075A81C14340000341800C9B4C402995F0845EC34340000341800C9B4C402995F0845EC34340715985CD00994C4053B3075A81C14340715985CD00994C40
27867	Судино	1	17	1827	39.28481	39.302011999999998	57.212609999999998	57.204006	0103000020E6100000010000000500000071C971A774A4434009185DDE1C9A4C4071C971A774A44340BA66F2CD369B4C40F17F4754A8A64340BA66F2CD369B4C40F17F4754A8A6434009185DDE1C9A4C4071C971A774A4434009185DDE1C9A4C40
28560	Скнятиново	1	17	1827	39.327092999999998	39.598699000000003	57.172342	57.075287000000003	0103000020E6100000010000000500000011E0F42EDEA9434030682101A3894C4011E0F42EDEA9434016DD7A4D0F964C40EF92382BA2CC434016DD7A4D0F964C40EF92382BA2CC434030682101A3894C4011E0F42EDEA9434030682101A3894C40
29757	Семибратово	1	17	1827	39.514454999999998	39.548627000000003	57.312939999999998	57.295518999999999	0103000020E61000000100000005000000C02154A9D9C143405E2C0C91D3A54C40C02154A9D9C143401CCEFC6A0EA84C40EF59D76839C643401CCEFC6A0EA84C40EF59D76839C643405E2C0C91D3A54C40C02154A9D9C143405E2C0C91D3A54C40
50525	Ростов	1	17	1827	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
29182	Приозерный	1	17	1827	39.419646999999998	39.430821999999999	56.974445000000003	56.966546000000001	0103000020E61000000100000005000000A86E2EFEB6B54340310A82C7B77B4C40A86E2EFEB6B5434018601F9DBA7C4C40DB32E02C25B7434018601F9DBA7C4C40DB32E02C25B74340310A82C7B77B4C40A86E2EFEB6B54340310A82C7B77B4C40
46677	Пречистое	1	17	1827	39.306736999999998	39.317543999999998	56.822558000000001	56.816459000000002	0103000020E6100000010000000500000090BC732843A743402FC37FBA81684C4090BC732843A7434016889E9449694C4040852348A5A8434016889E9449694C4040852348A5A843402FC37FBA81684C4090BC732843A743402FC37FBA81684C40
29958	Поречье-Рыбное	1	17	1827	39.365271999999997	39.404204999999997	57.105846999999997	57.086269000000001	0103000020E610000001000000050000007F129F3BC1AE43404ED4D2DC0A8B4C407F129F3BC1AE43409AB0FD648C8D4C4099F04BFDBCB343409AB0FD648C8D4C4099F04BFDBCB343404ED4D2DC0A8B4C407F129F3BC1AE43404ED4D2DC0A8B4C40
29249	Петровское	1	17	1827	39.241933000000003	39.300781999999998	57.020578999999998	56.993102	0103000020E610000001000000050000005E6919A9F79E4340CDCB61F71D7F4C405E6919A9F79E434000FE2955A2824C40DC9C4A0680A6434000FE2955A2824C40DC9C4A0680A64340CDCB61F71D7F4C405E6919A9F79E4340CDCB61F71D7F4C40
50590	Павлова Гора	1	17	1827	39.262846000000003	39.270383000000002	56.926288	56.922162	0103000020E6100000010000000500000035F10EF0A4A1434096CE876709764C4035F10EF0A4A14340B056ED9A90764C407B32FFE89BA24340B056ED9A90764C407B32FFE89BA2434096CE876709764C4035F10EF0A4A1434096CE876709764C40
29612	Новоникольское	1	17	1827	39.534272000000001	39.548914000000003	57.268586999999997	57.261408000000003	0103000020E6100000010000000500000092955F0663C44340D6743DD175A14C4092955F0663C44340BC900E0F61A24C4085285FD042C64340BC900E0F61A24C4085285FD042C64340D6743DD175A14C4092955F0663C44340D6743DD175A14C40
28630	Никольское	1	17	1827	39.230542	39.255541999999998	57.086087999999997	57.072073000000003	0103000020E610000001000000050000005E2D7766829D43405AF624B039894C405E2D7766829D4340FD497CEE048B4C409160AA99B5A04340FD497CEE048B4C409160AA99B5A043405AF624B039894C405E2D7766829D43405AF624B039894C40
29337	Мосейцево	1	17	1827	39.726610000000001	39.748421	57.115026	57.106067000000003	0103000020E610000001000000050000002979758E01DD4340A9177C9A938D4C402979758E01DD43404818062CB98E4C40DF516342CCDF43404818062CB98E4C40DF516342CCDF4340A9177C9A938D4C402979758E01DD4340A9177C9A938D4C40
27905	Марково	1	17	1827	39.347861999999999	39.359496	57.314869999999999	57.309838999999997	0103000020E61000000100000005000000B5C2F4BD86AC43403E03EACDA8A74C40B5C2F4BD86AC4340EA3E00A94DA84C407B8505F703AE4340EA3E00A94DA84C407B8505F703AE43403E03EACDA8A74C40B5C2F4BD86AC43403E03EACDA8A74C40
29388	Лазарцево	1	17	1827	39.574084999999997	39.594531000000003	57.096215999999998	57.083646999999999	0103000020E61000000100000005000000E40F069E7BC943404AB4E4F1B48A4C40E40F069E7BC943400CAD4ECE508C4C40A6BA809719CC43400CAD4ECE508C4C40A6BA809719CC43404AB4E4F1B48A4C40E40F069E7BC943404AB4E4F1B48A4C40
28863	Коленово	1	17	1827	39.183785	39.195247999999999	56.959018	56.949843999999999	0103000020E61000000100000005000000683F524486974340A226FA7C94794C40683F5244869743403E23111AC17A4C40014EEFE2FD9843403E23111AC17A4C40014EEFE2FD984340A226FA7C94794C40683F524486974340A226FA7C94794C40
30017	Климатино	1	17	1827	39.383822000000002	39.394727000000003	57.077835999999998	57.065627999999997	0103000020E610000001000000050000001FBE4C1421B14340D7D9907F66884C401FBE4C1421B14340C939B187F6894C4092EC116A86B24340C939B187F6894C4092EC116A86B24340D7D9907F66884C401FBE4C1421B14340D7D9907F66884C40
29089	Караш	1	17	1827	39.380443999999997	39.406970999999999	56.914994	56.897364000000003	0103000020E61000000100000005000000CEFA9463B2B04340CB4DD4D2DC724C40CEFA9463B2B04340A304FD851E754C40D0B52FA017B44340A304FD851E754C40D0B52FA017B44340CB4DD4D2DC724C40CEFA9463B2B04340CB4DD4D2DC724C40
27829	Ишня	1	17	1827	39.327533000000003	39.348374	57.198307	57.190762999999997	0103000020E610000001000000050000002EAEF199ECA94340B72407EC6A984C402EAEF199ECA94340B0C8AF1F62994C406B63EC8497AC4340B0C8AF1F62994C406B63EC8497AC4340B72407EC6A984C402EAEF199ECA94340B72407EC6A984C40
28953	Итларь	1	17	1827	39.274757000000001	39.300288000000002	56.866706000000001	56.851061999999999	0103000020E610000001000000050000006DACC43C2BA34340266F8099EF6C4C406DACC43C2BA343409D9FE238F06E4C40CDB051D66FA643409D9FE238F06E4C40CDB051D66FA64340266F8099EF6C4C406DACC43C2BA34340266F8099EF6C4C40
29034	Заозерье	1	17	1827	39.352263999999998	39.371873999999998	56.831029000000001	56.817424000000003	0103000020E6100000010000000500000071C79BFC16AD4340967B8159A1684C4071C79BFC16AD4340888384285F6A4C40C91D369199AF4340888384285F6A4C40C91D369199AF4340967B8159A1684C4071C79BFC16AD4340967B8159A1684C40
29130	Еремейцево	1	17	1827	39.316609999999997	39.338259000000001	56.879151	56.869273999999997	0103000020E6100000010000000500000014CB2DAD86A84340ADA1D45E446F4C4014CB2DAD86A84340739F1C0588704C40F14927124CAB4340739F1C0588704C40F14927124CAB4340ADA1D45E446F4C4014CB2DAD86A84340ADA1D45E446F4C40
28738	Дмитриановское	1	17	1827	39.132662000000003	39.152155	57.102601	57.094704999999998	0103000020E6100000010000000500000003B68311FB90434043E21E4B1F8C4C4003B68311FB904340B9C49107228D4C402176A6D079934340B9C49107228D4C402176A6D07993434043E21E4B1F8C4C4003B68311FB90434043E21E4B1F8C4C40
28689	Деревни	1	17	1827	39.260770999999998	39.270634000000001	57.041955000000002	57.036382000000003	0103000020E61000000100000005000000635FB2F160A14340E014562AA8844C40635FB2F160A14340AC730CC85E854C40C4978922A4A24340AC730CC85E854C40C4978922A4A24340E014562AA8844C40635FB2F160A14340E014562AA8844C40
28826	Горный	1	17	1827	39.137773000000003	39.148975	56.983176	56.976146999999997	0103000020E61000000100000005000000CBA2B08BA2914340548B8862F27C4C40CBA2B08BA2914340261B0FB6D87D4C40F775E09C11934340261B0FB6D87D4C40F775E09C11934340548B8862F27C4C40CBA2B08BA2914340548B8862F27C4C40
49042	Глебово	1	17	1827	39.427166	39.435519999999997	57.374966000000001	57.370249000000001	0103000020E6100000010000000500000048FB1F60ADB643403830B95164AF4C4048FB1F60ADB64340548EC9E2FEAF4C4080608E1EBFB74340548EC9E2FEAF4C4080608E1EBFB743403830B95164AF4C4048FB1F60ADB643403830B95164AF4C40
29659	Вахрушево	1	17	1827	39.581828999999999	39.594746000000001	57.303761999999999	57.298374000000003	0103000020E61000000100000005000000A46E675F79CA434005FD851E31A64C40A46E675F79CA43403FE257ACE1A64C40A2B60DA320CC43403FE257ACE1A64C40A2B60DA320CC434005FD851E31A64C40A46E675F79CA434005FD851E31A64C40
29492	Васильково	1	17	1827	39.639113999999999	39.669908	57.206584999999997	57.194400999999999	0103000020E610000001000000050000003735D07CCED14340A4A7C821E2984C403735D07CCED143400D6C9560719A4C4015AA9B8BBFD543400D6C9560719A4C4015AA9B8BBFD54340A4A7C821E2984C403735D07CCED14340A4A7C821E2984C40
29575	Белогостицы	1	17	1827	39.485951	39.504483999999998	57.238785	57.227474000000001	0103000020E61000000100000005000000B03A72A433BE43405C5837DE1D9D4C40B03A72A433BE43403FE3C281909E4C4079AD84EE92C043403FE3C281909E4C4079AD84EE92C043405C5837DE1D9D4C40B03A72A433BE43405C5837DE1D9D4C40
28999	Беклемишево	1	17	1827	39.241044000000002	39.246568000000003	56.809511999999998	56.804298000000003	0103000020E61000000100000005000000D272A087DA9E43407E1EA33CF3664C40D272A087DA9E43401ADCD6169E674C40BD1E4C8A8F9F43401ADCD6169E674C40BD1E4C8A8F9F43407E1EA33CF3664C40D272A087DA9E43407E1EA33CF3664C40
27353	Ясная Поляна	1	17	1803	39.078448999999999	39.094572999999997	58.492054000000003	58.477502999999999	0103000020E61000000100000005000000B3B3E89D0A8A4340F65E7CD11E3D4D40B3B3E89D0A8A4340D9EE1EA0FB3E4D40D40AD3F71A8C4340D9EE1EA0FB3E4D40D40AD3F71A8C4340F65E7CD11E3D4D40B3B3E89D0A8A4340F65E7CD11E3D4D40
27302	Яковлевское	1	17	1803	39.190998999999998	39.205793999999997	58.500946999999996	58.494311000000003	0103000020E61000000100000005000000CB48BDA772984340CB863595453F4D40CB48BDA772984340C00303081F404D4044DB3175579A4340C00303081F404D4044DB3175579A4340CB863595453F4D40CB48BDA772984340CB863595453F4D40
27727	Юдино	1	17	1803	39.290495999999997	39.310510000000001	58.712466999999997	58.703301000000003	0103000020E6100000010000000500000035CF11F92EA543403F1F65C4055A4D4035CF11F92EA54340573D601E325B4D405D8AABCABEA74340573D601E325B4D405D8AABCABEA743403F1F65C4055A4D4035CF11F92EA543403F1F65C4055A4D40
27679	Холм	1	17	1803	39.508696999999998	39.526411000000003	58.289785999999999	58.279367999999998	0103000020E610000001000000050000006249B9FB1CC1434043C6A354C2234D406249B9FB1CC14340596B28B517254D4099A0866F61C34340596B28B517254D4099A0866F61C3434043C6A354C2234D406249B9FB1CC1434043C6A354C2234D40
27591	Федорково	1	17	1803	38.88832	38.900322000000003	58.502654	58.492387999999998	0103000020E61000000100000005000000FD304278B4714340AF78EA91063F4D40FD304278B47143400F9A5DF756404D4046EF54C03D7343400F9A5DF756404D4046EF54C03D734340AF78EA91063F4D40FD304278B4714340AF78EA91063F4D40
27089	Ракоболь	1	17	1803	39.378386999999996	39.389760000000003	58.739680999999997	58.731209	0103000020E61000000100000005000000A31D37FC6EB043403BC5AA41985D4D40A31D37FC6EB043407D3CF4DDAD5E4D40FDA4DAA7E3B143407D3CF4DDAD5E4D40FDA4DAA7E3B143403BC5AA41985D4D40A31D37FC6EB043403BC5AA41985D4D40
26542	Пошехонье	1	17	1803	39.092407999999999	39.152307999999998	58.506495000000001	58.489792000000001	0103000020E61000000100000005000000C3F17C06D48B4340D5EB1681B13E4D40C3F17C06D48B4340344B02D4D4404D40A7751BD47E934340344B02D4D4404D40A7751BD47E934340D5EB1681B13E4D40C3F17C06D48B4340D5EB1681B13E4D40
27481	Покров-Рогули	1	17	1803	39.616737000000001	39.646704999999997	58.309095999999997	58.297958999999999	0103000020E61000000100000005000000D89DEE3CF1CE43404146408523264D40D89DEE3CF1CE434086A92D7590274D407094BC3AC7D2434086A92D7590274D407094BC3AC7D243404146408523264D40D89DEE3CF1CE43404146408523264D40
27454	Крестцы	1	17	1803	38.967579000000001	38.985984999999999	58.398750999999997	58.386322	0103000020E61000000100000005000000F0A5F0A0D97B4340D7DCD1FF72314D40F0A5F0A0D97B4340A71FD4450A334D405CACA8C1347E4340A71FD4450A334D405CACA8C1347E4340D7DCD1FF72314D40F0A5F0A0D97B4340D7DCD1FF72314D40
27392	Кременево	1	17	1803	38.960850000000001	39.007257000000003	58.433244999999999	58.418821000000001	0103000020E61000000100000005000000492EFF21FD7A434063F030ED9B354D40492EFF21FD7A4340E813799274374D4063D520CCED804340E813799274374D4063D520CCED80434063F030ED9B354D40492EFF21FD7A434063F030ED9B354D40
27204	Красное	1	17	1803	39.208587999999999	39.219197000000001	58.621983	58.613729999999997	0103000020E61000000100000005000000452BF702B39A43407B4963B48E4E4D40452BF702B39A434080D591239D4F4D40CF30B5A50E9C434080D591239D4F4D40CF30B5A50E9C43407B4963B48E4E4D40452BF702B39A43407B4963B48E4E4D40
27258	Колодино	1	17	1803	39.158237	39.172277999999999	58.790883000000001	58.783776000000003	0103000020E6100000010000000500000032022A1C41944340E2B19FC552644D4032022A1C419443402FFB75A73B654D40FFE89B340D9643402FFB75A73B654D40FFE89B340D964340E2B19FC552644D4032022A1C41944340E2B19FC552644D40
27173	Князево	1	17	1803	39.069887999999999	39.095210999999999	58.517138000000003	58.511375000000001	0103000020E6100000010000000500000001310917F2884340FA7E6ABC74414D4001310917F28843406AC2F69331424D40179CC1DF2F8C43406AC2F69331424D40179CC1DF2F8C4340FA7E6ABC74414D4001310917F2884340FA7E6ABC74414D40
27117	Кладово	1	17	1803	39.342067999999998	39.355175000000003	58.629596999999997	58.620980000000003	0103000020E610000001000000050000000A815CE2C8AB43402CBCCB457C4F4D400A815CE2C8AB434071546EA296504D40ACADD85F76AD434071546EA296504D40ACADD85F76AD43402CBCCB457C4F4D400A815CE2C8AB43402CBCCB457C4F4D40
27638	Зубарево	1	17	1803	38.955432999999999	38.991743	58.494100000000003	58.484782000000003	0103000020E610000001000000050000007442E8A04B7A434041D829560D3E4D407442E8A04B7A4340107A36AB3E3F4D40BA84436FF17E4340107A36AB3E3F4D40BA84436FF17E434041D829560D3E4D407442E8A04B7A434041D829560D3E4D40
27036	Ермаково	1	17	1803	38.686585999999998	38.694760000000002	58.620896000000002	58.613303999999999	0103000020E610000001000000050000001BF2CF0CE2574340C440D7BE804E4D401BF2CF0CE2574340CE1B2785794F4D40D4484BE5ED584340CE1B2785794F4D40D4484BE5ED584340C440D7BE804E4D401BF2CF0CE2574340C440D7BE804E4D40
27551	Дубасово	1	17	1803	39.284880999999999	39.30097	58.415126000000001	58.406131000000002	0103000020E610000001000000050000003A2009FB76A443402672C119FC334D403A2009FB76A4434012DC48D922354D40DF89592F86A6434012DC48D922354D40DF89592F86A643402672C119FC334D403A2009FB76A443402672C119FC334D40
27004	Гаютино	1	17	1803	38.509149999999998	38.523989999999998	58.700687000000002	58.693004999999999	0103000020E610000001000000050000001361C3D32B414340747B4963B4584D401361C3D32B414340BEDD921CB0594D402CB7B41A12434340BEDD921CB0594D402CB7B41A12434340747B4963B4584D401361C3D32B414340747B4963B4584D40
26954	Вощиково	1	17	1803	39.096038	39.107644000000001	58.325657999999997	58.319575999999998	0103000020E610000001000000050000002D9622F94A8C4340124BCADDE7284D402D9622F94A8C434023D74D29AF294D4029CE5147C78D434023D74D29AF294D4029CE5147C78D4340124BCADDE7284D402D9622F94A8C4340124BCADDE7284D40
26904	Владычное	1	17	1803	39.466566	39.502355000000001	58.813977000000001	58.806702000000001	0103000020E6100000010000000500000078B6476FB8BB434014CFD90242674D4078B6476FB8BB43401D59F96530684D40B5FD2B2B4DC043401D59F96530684D40B5FD2B2B4DC0434014CFD90242674D4078B6476FB8BB434014CFD90242674D40
26805	Васильевское	1	17	1803	39.206566000000002	39.215235	58.8414	58.835104000000001	0103000020E61000000100000005000000973B33C1709A4340206118B0E46A4D40973B33C1709A43405D6DC5FEB26B4D402FFA0AD28C9B43405D6DC5FEB26B4D402FFA0AD28C9B4340206118B0E46A4D40973B33C1709A4340206118B0E46A4D40
26764	Белое	1	17	1803	39.378073000000001	39.405453000000001	58.385789000000003	58.376399999999997	0103000020E61000000100000005000000144031B264B04340711B0DE02D304D40144031B264B043400A14B18861314D40558847E2E5B343400A14B18861314D40558847E2E5B34340711B0DE02D304D40144031B264B04340711B0DE02D304D40
26848	Андрюшино	1	17	1803	39.285303999999996	39.299864999999997	58.823709999999998	58.817121999999998	0103000020E6100000010000000500000080B56AD784A44340CA6B257497684D4080B56AD784A44340AFB14B546F694D40861BF0F961A64340AFB14B546F694D40861BF0F961A64340CA6B257497684D4080B56AD784A44340CA6B257497684D40
26006	Фонинское	1	17	830	38.270018999999998	38.292261000000003	56.905455000000003	56.888415999999999	0103000020E6100000010000000500000039268BFB8F2243401F9F909DB7714C4039268BFB8F224340F67F0EF3E5734C40B972F6CE68254340F67F0EF3E5734C40B972F6CE682543401F9F909DB7714C4039268BFB8F2243401F9F909DB7714C40
26251	Филимоново	1	17	830	39.091582000000002	39.110275999999999	56.786172999999998	56.769996999999996	0103000020E610000001000000050000007E737FF5B88B43405182FE428F624C407E737FF5B88B4340C5FF1D51A1644C4050C422861D8E4340C5FF1D51A1644C4050C422861D8E43405182FE428F624C407E737FF5B88B43405182FE428F624C40
25179	Троицкая-Слобода	1	17	830	38.885221000000001	38.894661999999997	56.77628	56.772497000000001	0103000020E61000000100000005000000C05DF6EB4E7143400AA1832EE1624C40C05DF6EB4E714340FA449E245D634C40AA7CCF4884724340FA449E245D634C40AA7CCF48847243400AA1832EE1624C40C05DF6EB4E7143400AA1832EE1624C40
26438	Смоленское	1	17	830	39.156198000000003	39.181987999999997	56.642108999999998	56.624678000000003	0103000020E61000000100000005000000AED9CA4BFE934340EE43DE72F54F4C40AED9CA4BFE934340CFBBB1A030524C40D921FE614B974340CFBBB1A030524C40D921FE614B974340EE43DE72F54F4C40AED9CA4BFE934340EE43DE72F54F4C40
26282	Рязанцево	1	17	830	39.187702000000002	39.196604000000001	56.716704999999997	56.712505999999998	0103000020E6100000010000000500000068B27F9E06984340151A8865335B4C4068B27F9E0698434099F04BFDBC5B4C40A321E3512A99434099F04BFDBC5B4C40A321E3512A994340151A8865335B4C4068B27F9E06984340151A8865335B4C40
25867	Рахманово	1	17	830	38.635247	38.651451999999999	57.038899000000001	57.026663999999997	0103000020E61000000100000005000000E9F010C64F51434082FDD7B969834C40E9F010C64F5143406E6C76A4FA844C40F77475C7625343406E6C76A4FA844C40F77475C76253434082FDD7B969834C40E9F010C64F51434082FDD7B969834C40
50564	Новоселье	1	17	830	38.704076000000001	38.721071999999999	56.719071	56.707926	0103000020E6100000010000000500000002F390291F5A43407AFEB4519D5A4C4002F390291F5A43404240BE840A5C4C40D90759164C5C43404240BE840A5C4C40D90759164C5C43407AFEB4519D5A4C4002F390291F5A43407AFEB4519D5A4C40
25970	Нагорье	1	17	830	38.248458999999997	38.283546999999999	56.926096999999999	56.910806999999998	0103000020E61000000100000005000000CCB22781CD1F4340E3FBE25295744C40CCB22781CD1F43403CF6B3588A764C4080F0A1444B2443403CF6B3588A764C4080F0A1444B244340E3FBE25295744C40CCB22781CD1F4340E3FBE25295744C40
25428	Лыченцы	1	17	830	38.801974000000001	38.823345000000003	56.960937000000001	56.952509999999997	0103000020E61000000100000005000000041F8315A7664340758E01D9EB794C40041F8315A76643401842CEFBFF7A4C409E29745E636943401842CEFBFF7A4C409E29745E63694340758E01D9EB794C40041F8315A7664340758E01D9EB794C40
25572	Купанское	1	17	830	38.635165999999998	38.701622999999998	56.829911000000003	56.805840000000003	0103000020E61000000100000005000000FCC3961E4D51434082E7DEC325674C40FCC3961E4D5143409BCB0D863A6A4C408A8F4FC8CE5943409BCB0D863A6A4C408A8F4FC8CE59434082E7DEC325674C40FCC3961E4D51434082E7DEC325674C40
50501	Кубринск	1	17	830	38.338954999999999	38.368949999999998	56.739100000000001	56.708132999999997	0103000020E6100000010000000500000068E89FE0622B4340F31B261AA45A4C4068E89FE0622B43409F3C2CD49A5E4C40FAEDEBC0392F43409F3C2CD49A5E4C40FAEDEBC0392F4340F31B261AA45A4C4068E89FE0622B4340F31B261AA45A4C40
25271	Красная	1	17	830	38.870713000000002	38.883074000000001	56.797328999999998	56.789067000000003	0103000020E61000000100000005000000DD990986736F43402AADBF2500654C40DD990986736F434081936DE00E664C4055F99E910871434081936DE00E664C4055F99E91087143402AADBF2500654C40DD990986736F43402AADBF2500654C40
25663	Копнино	1	17	830	38.460830000000001	38.487051999999998	56.886488999999997	56.874099999999999	0103000020E610000001000000050000000282397AFC3A434080B74082E26F4C400282397AFC3A4340C2A1B77878714C40C7B94DB8573E4340C2A1B77878714C40C7B94DB8573E434080B74082E26F4C400282397AFC3A434080B74082E26F4C40
25144	Кичибухино	1	17	830	38.946235000000001	38.962862000000001	56.685225000000003	56.673713999999997	0103000020E6100000010000000500000050AA7D3A1E794340BD6DA6423C564C4050AA7D3A1E79434068B3EA73B5574C40D447E00F3F7B434068B3EA73B5574C40D447E00F3F7B4340BD6DA6423C564C4050AA7D3A1E794340BD6DA6423C564C40
25327	Ивановское	1	17	830	38.994168999999999	39.014336	56.815646000000001	56.804875000000003	0103000020E6100000010000000500000038D906EE407F43401B2FDD2406674C4038D906EE407F43407E8E8F1667684C40E69315C3D58143407E8E8F1667684C40E69315C3D58143401B2FDD2406674C4038D906EE407F43401B2FDD2406674C40
25732	Загорье	1	17	830	38.345100000000002	38.358305000000001	57.033791000000001	57.022475	0103000020E61000000100000005000000C0EC9E3C2C2C434022FDF675E0824C40C0EC9E3C2C2C434017F3734353844C40247F30F0DC2D434017F3734353844C40247F30F0DC2D434022FDF675E0824C40C0EC9E3C2C2C434022FDF675E0824C40
25782	Ефимьево	1	17	830	38.963940000000001	38.984394999999999	56.639539999999997	56.629618999999998	0103000020E6100000010000000500000033A7CB62627B434059F8FA5A97504C4033A7CB62627B4340EE3D5C72DC514C4047ACC5A7007E4340EE3D5C72DC514C4047ACC5A7007E434059F8FA5A97504C4033A7CB62627B434059F8FA5A97504C40
26201	Дубровицы	1	17	830	39.161462	39.178485000000002	56.774687	56.766238000000001	0103000020E61000000100000005000000FCC56CC9AA944340EA79371614624C40FCC56CC9AA94434074D190F128634C40CDE9B298D896434074D190F128634C40CDE9B298D8964340EA79371614624C40FCC56CC9AA944340EA79371614624C40
50933	Дубки	1	17	830	39.125456999999997	39.147295	56.713726000000001	56.701838000000002	0103000020E61000000100000005000000F20698F90E904340878BDCD3D5594C40F20698F90E9043400727A25F5B5B4C40A2EE0390DA9243400727A25F5B5B4C40A2EE0390DA924340878BDCD3D5594C40F20698F90E904340878BDCD3D5594C40
25817	Дмитриевское	1	17	830	38.514674999999997	38.531869	57.060098000000004	57.050606999999999	0103000020E61000000100000005000000CE88D2DEE04143406EF9484A7A864C40CE88D2DEE04143400B47904AB1874C40CC608C48144443400B47904AB1874C40CC608C48144443406EF9484A7A864C40CE88D2DEE04143406EF9484A7A864C40
26391	Горки	1	17	830	39.274999999999999	39.293298999999998	56.661388000000002	56.651522	0103000020E610000001000000050000003333333333A34340F04FA91265534C403333333333A34340C2FBAA5CA8544C40897956D28AA54340C2FBAA5CA8544C40897956D28AA54340F04FA91265534C403333333333A34340F04FA91265534C40
47634	Глебовское	1	17	830	38.688445000000002	38.712933	56.666533000000001	56.648221999999997	0103000020E61000000100000005000000200C3CF71E5843401B4641F0F8524C40200C3CF71E584340365A0EF450554C409D9E7763415B4340365A0EF450554C409D9E7763415B43401B4641F0F8524C40200C3CF71E5843401B4641F0F8524C40
25524	Большая Брембола	1	17	830	38.890979000000002	38.923678000000002	56.751612999999999	56.729748000000001	0103000020E610000001000000050000001E3691990B7243402429E961685D4C401E3691990B724340CD1FD3DA34604C407104A9143B764340CD1FD3DA34604C407104A9143B7643402429E961685D4C401E3691990B7243402429E961685D4C40
50927	Берендеево	1	17	830	38.990107999999999	39.061641000000002	56.605960000000003	56.591678999999999	0103000020E6100000010000000500000005C1E3DBBB7E4340705D3123BC4B4C4005C1E3DBBB7E43409357E718904D4C40DF8B2FDAE38743409357E718904D4C40DF8B2FDAE3874340705D3123BC4B4C4005C1E3DBBB7E4340705D3123BC4B4C40
26473	Бектышево	1	17	830	39.221119000000002	39.244582999999999	56.579895999999998	56.563744999999997	0103000020E610000001000000050000001AC39CA04D9C43404A24D1CB28484C401AC39CA04D9C4340658A39083A4A4C402B14E97E4E9F4340658A39083A4A4C402B14E97E4E9F43404A24D1CB28484C401AC39CA04D9C43404A24D1CB28484C40
26043	Андрианово	1	17	830	38.262912999999998	38.280897000000003	56.871344999999998	56.860894999999999	0103000020E61000000100000005000000BC581822A72143401C25AFCE316E4C40BC581822A72143403D44A33B886F4C40B345D26EF42343403D44A33B886F4C40B345D26EF42343401C25AFCE316E4C40BC581822A72143401C25AFCE316E4C40
24609	Шильпухово	1	17	1593	40.435192000000001	40.451245	58.397275	58.387756000000003	0103000020E610000001000000050000008CBD175FB4374440F56915FDA1314D408CBD175FB43744405B423EE8D9324D40E4BD6A65C23944405B423EE8D9324D40E4BD6A65C2394440F56915FDA1314D408CBD175FB4374440F56915FDA1314D40
50935	Скалино	1	17	1593	40.199708000000001	40.222911000000003	58.549467999999997	58.526823	0103000020E61000000100000005000000F25F200890194440EBE3A1EF6E434D40F25F2008901944406919A9F754464D409775FF58881C44406919A9F754464D409775FF58881C4440EBE3A1EF6E434D40F25F200890194440EBE3A1EF6E434D40
46222	Путятино	1	17	1593	40.361818	40.372444999999999	58.434753000000001	58.429721000000001	0103000020E61000000100000005000000548D5E0D502E4440C4B3041901374D40548D5E0D502E4440406B7EFCA5374D4084471B47AC2F4440406B7EFCA5374D4084471B47AC2F4440C4B3041901374D40548D5E0D502E4440C4B3041901374D40
50934	Паршино	1	17	1593	39.510170000000002	39.520842000000002	58.654366000000003	58.650415000000002	0103000020E610000001000000050000003EB324404DC14340F7E978CC40534D403EB324404DC14340A3CEDC43C2534D400E315EF3AAC24340A3CEDC43C2534D400E315EF3AAC24340F7E978CC40534D403EB324404DC14340F7E978CC40534D40
24041	Николо-Ухтома	1	17	1593	39.510969000000003	39.521650000000001	58.684787999999998	58.680301999999998	0103000020E610000001000000050000008A22A46E67C14340A2B3CC2214574D408A22A46E67C14340BC581822A7574D40ADFA5C6DC5C24340BC581822A7574D40ADFA5C6DC5C24340A2B3CC2214574D408A22A46E67C14340A2B3CC2214574D40
50917	Никола-Гора	1	17	1593	40.107163	40.135209000000003	58.435257	58.428086	0103000020E61000000100000005000000AE2B6684B70D44400FF0A485CB364D40AE2B6684B70D4440732D5A80B6374D40FC8F4C874E114440732D5A80B6374D40FC8F4C874E1144400FF0A485CB364D40AE2B6684B70D44400FF0A485CB364D40
40433	Малино	1	17	1593	39.769280000000002	39.776528999999996	58.692678000000001	58.688533999999997	0103000020E61000000100000005000000C3BB5CC477E243408F17D2E121584D40C3BB5CC477E24340505436ACA9584D40A2B2614D65E34340505436ACA9584D40A2B2614D65E343408F17D2E121584D40C3BB5CC477E243408F17D2E121584D40
19330	Кукобой	1	17	1593	39.888289	39.922029999999999	58.705165999999998	58.688234999999999	0103000020E61000000100000005000000C2323674B3F14340357BA01518584D40C2323674B3F14340252026E1425A4D4027F73B1405F64340252026E1425A4D4027F73B1405F64340357BA01518584D40C2323674B3F14340357BA01518584D40
24394	Коза	1	17	1593	39.911771000000002	39.936464999999998	58.458959	58.450296000000002	0103000020E610000001000000050000007A3881E9B4F4434083C2A04CA3394D407A3881E9B4F44340399A232BBF3A4D40A06CCA15DEF74340399A232BBF3A4D40A06CCA15DEF7434083C2A04CA3394D407A3881E9B4F4434083C2A04CA3394D40
24337	Игнатцево	1	17	1593	39.754708999999998	39.765704999999997	58.579841000000002	58.571756000000001	0103000020E61000000100000005000000997FF44D9AE0434059A5F44C2F494D40997FF44D9AE04340A2F0D93A384A4D401CB1169F02E24340A2F0D93A384A4D401CB1169F02E2434059A5F44C2F494D40997FF44D9AE0434059A5F44C2F494D40
47468	Григорьевское	1	17	1593	40.205770999999999	40.222830000000002	58.383577000000002	58.378712	0103000020E610000001000000050000008CBB41B4561A4440274D83A279304D408CBB41B4561A4440B83F170D19314D40AA4885B1851C4440B83F170D19314D40AA4885B1851C4440274D83A279304D408CBB41B4561A4440274D83A279304D40
46548	Всехсвятское	1	17	1593	39.727293000000003	39.748978000000001	58.644692999999997	58.639859999999999	0103000020E610000001000000050000000CCEE0EF17DD43406002B7EEE6514D400CCEE0EF17DD4340E57ADB4C85524D4035B6D782DEDF4340E57ADB4C85524D4035B6D782DEDF43406002B7EEE6514D400CCEE0EF17DD43406002B7EEE6514D40
22675	Вараково	1	17	1593	39.999464000000003	40.020834999999998	58.624803999999997	58.615834999999997	0103000020E61000000100000005000000C2C3B46FEEFF4340B75D68AED34E4D40C2C3B46FEEFF43407A34D593F94F4D405BCEA5B8AA0244407A34D593F94F4D405BCEA5B8AA024440B75D68AED34E4D40C2C3B46FEEFF4340B75D68AED34E4D40
24543	Багряники	1	17	1593	40.282155000000003	40.296635999999999	58.334980999999999	58.329282999999997	0103000020E6100000010000000500000092B3B0A71D2444407B1002F2252A4D4092B3B0A71D24444004E44BA8E02A4D407B681F2BF825444004E44BA8E02A4D407B681F2BF82544407B1002F2252A4D4092B3B0A71D2444407B1002F2252A4D40
50929	Яснища	1	17	1699	40.438048999999999	40.448245	57.760773999999998	57.757326999999997	0103000020E61000000100000005000000D38558FD113844405BB05417F0E04C40D38558FD11384440D4D2DC0A61E14C403ACC971760394440D4D2DC0A61E14C403ACC9717603944405BB05417F0E04C40D38558FD113844405BB05417F0E04C40
23149	Черная Заводь	1	17	1699	40.534886999999998	40.555008999999998	57.740074999999997	57.724775000000001	0103000020E610000001000000050000001C075E2D77444440ADFA5C6DC5DC4C401C075E2D7744444029CB10C7BADE4C402AFEEF880A47444029CB10C7BADE4C402AFEEF880A474440ADFA5C6DC5DC4C401C075E2D77444440ADFA5C6DC5DC4C40
45963	Приволжский	1	17	1699	40.367413999999997	40.380583999999999	57.701828999999996	57.697442000000002	0103000020E61000000100000005000000D80B056C072F4440AD6D8AC745D94C40D80B056C072F444033315D88D5D94C40C0B0FCF9B630444033315D88D5D94C40C0B0FCF9B6304440AD6D8AC745D94C40D80B056C072F4440AD6D8AC745D94C40
49294	Песочное	1	17	1699	40.567667	40.595810999999998	57.681162999999998	57.670256999999999	0103000020E610000001000000050000005C02F04FA948444021753BFBCAD54C405C02F04FA9484440641F645930D74C406CCCEB88434C4440641F645930D74C406CCCEB88434C444021753BFBCAD54C405C02F04FA948444021753BFBCAD54C40
22791	Некрасовское	1	17	1699	40.343375000000002	40.385326999999997	57.692203999999997	57.660801999999997	0103000020E61000000100000005000000CBA145B6F32B4440D190F12895D44C40CBA145B6F32B4440871403249AD84C4005A2276552314440871403249AD84C4005A2276552314440D190F12895D44C40CBA145B6F32B4440D190F12895D44C40
50916	Наумиха	1	17	1699	40.051000999999999	40.715997000000002	57.911797999999997	57.312624	0103000020E610000001000000050000001A88653387064440ECF82F1004A84C401A886533870644407347FFCBB5F44C405E8429CAA55B44407347FFCBB5F44C405E8429CAA55B4440ECF82F1004A84C401A88653387064440ECF82F1004A84C40
60501	Малые Соли	1	17	1699	40.376747999999999	40.390563999999998	57.641244999999998	57.624428999999999	0103000020E61000000100000005000000AD6A49473930444045D61A4AEDCF4C40AD6A4947393044409CDCEF5014D24C405A7F4B00FE3144409CDCEF5014D24C405A7F4B00FE31444045D61A4AEDCF4C40AD6A49473930444045D61A4AEDCF4C40
49177	Лом	1	17	1699	40.388345000000001	40.395198999999998	57.384107	57.381419000000001	0103000020E610000001000000050000005648F949B531444059897956D2B04C405648F949B531444014950D6B2AB14C40B9347EE19532444014950D6B2AB14C40B9347EE19532444059897956D2B04C405648F949B531444059897956D2B04C40
46033	Левашово	1	17	1699	40.515421000000003	40.539468999999997	57.649366000000001	57.638233999999997	0103000020E61000000100000005000000F855B950F9414440FE98D6A6B1D14C40F855B950F94144403291D26C1ED34C40581AF8510D4544403291D26C1ED34C40581AF8510D454440FE98D6A6B1D14C40F855B950F9414440FE98D6A6B1D14C40
50922	Красный Профинтерн	1	17	1699	40.419921000000002	40.448585999999999	57.760683	57.740175999999998	0103000020E61000000100000005000000AAF3A8F8BF3544405DA45016BEDE4C40AAF3A8F8BF354440C4CF7F0F5EE14C40C3B81B446B394440C4CF7F0F5EE14C40C3B81B446B3944405DA45016BEDE4C40AAF3A8F8BF3544405DA45016BEDE4C40
50572	Коробиха	1	17	1699	40.347605999999999	40.355682000000002	57.476545999999999	57.472422999999999	0103000020E610000001000000050000005AF2785A7E2C444069705B5B78BC4C405AF2785A7E2C444012859675FFBC4C4050E3DEFC862D444012859675FFBC4C4050E3DEFC862D444069705B5B78BC4C405AF2785A7E2C444069705B5B78BC4C40
23332	Защитный	1	17	1699	40.365060999999997	40.374429999999997	57.730297	57.727240999999999	0103000020E61000000100000005000000C405A051BA2E4440B9A7AB3B16DD4C40C405A051BA2E4440F7AE415F7ADD4C4015527E52ED2F4440F7AE415F7ADD4C4015527E52ED2F4440B9A7AB3B16DD4C40C405A051BA2E4440B9A7AB3B16DD4C40
23529	Диево-Городище	1	17	1699	40.183205999999998	40.203076000000003	57.644722999999999	57.633561	0103000020E610000001000000050000002A37514B73174440B282DF8618D14C402A37514B7317444050FD834886D24C401F4DF564FE19444050FD834886D24C401F4DF564FE194440B282DF8618D14C402A37514B73174440B282DF8618D14C40
22631	Гашки	1	17	1699	40.262113999999997	40.271042999999999	57.501342999999999	57.497042999999998	0103000020E6100000010000000500000070E998F38C21444055DAE21A9FBF4C4070E998F38C2144400D8AE6012CC04C40A5677A89B12244400D8AE6012CC04C40A5677A89B122444055DAE21A9FBF4C4070E998F38C21444055DAE21A9FBF4C40
50508	Вятское	1	17	1699	40.255403000000001	40.272561000000003	57.874164999999998	57.859243999999997	0103000020E610000001000000050000007026A60BB120444061A417B5FBED4C407026A60BB1204440672783A3E4EF4C4021956247E3224440672783A3E4EF4C4021956247E322444061A417B5FBED4C407026A60BB120444061A417B5FBED4C40
50940	Бурмакино	1	17	1699	40.294857	40.328139999999998	57.444535000000002	57.425136999999999	0103000020E6100000010000000500000093FFC9DFBD254440E7A8A3E36AB64C4093FFC9DFBD254440B476DB85E6B84C403541D47D002A4440B476DB85E6B84C403541D47D002A4440E7A8A3E36AB64C4093FFC9DFBD254440E7A8A3E36AB64C40
50518	Бор	1	17	1699	40.394444999999997	40.419651000000002	57.777546000000001	57.770538999999999	0103000020E610000001000000050000000D897B2C7D32444072A59E05A1E24C400D897B2C7D3244405C9198A086E34C40EA5DBC1FB73544405C9198A086E34C40EA5DBC1FB735444072A59E05A1E24C400D897B2C7D32444072A59E05A1E24C40
22314	Шестихино	1	17	820	38.219965000000002	38.287095999999998	57.940240000000003	57.924757999999997	0103000020E61000000100000005000000E0A128D0271C4340705B5B785EF64C40E0A128D0271C43400E32C9C859F84C40FD67CD8FBF2443400E32C9C859F84C40FD67CD8FBF244340705B5B785EF64C40E0A128D0271C4340705B5B785EF64C40
21592	Станилово	1	17	820	37.861716000000001	37.877032999999997	58.028511000000002	58.016461999999997	0103000020E610000001000000050000005038BBB54CEE424039D0436D1B024D405038BBB54CEE4240C3499A3FA6034D40A2410A9E42F04240C3499A3FA6034D40A2410A9E42F0424039D0436D1B024D405038BBB54CEE424039D0436D1B024D40
21651	Спас-Ильдь	1	17	820	38.063935999999998	38.087598	57.999929999999999	57.989241	0103000020E61000000100000005000000BE840A0E2F084340616EF7729FFE4C40BE840A0E2F0843400725CCB4FDFF4C40F6984869360B43400725CCB4FDFF4C40F6984869360B4340616EF7729FFE4C40BE840A0E2F084340616EF7729FFE4C40
21839	Рожалово	1	17	820	37.603963	37.612074999999997	57.988287	57.979784000000002	0103000020E610000001000000050000003D7FDAA84ECD42407192E68F69FD4C403D7FDAA84ECD4240EE073C3080FE4C407FD93D7958CE4240EE073C3080FE4C407FD93D7958CE42407192E68F69FD4C403D7FDAA84ECD42407192E68F69FD4C40
21529	Правдино	1	17	820	37.884811999999997	37.897613	57.959139	57.953040999999999	0103000020E61000000100000005000000DE8D058541F14240A25F5B3FFDF94C40DE8D058541F14240B9A81611C5FA4C4073BB97FBE4F24240B9A81611C5FA4C4073BB97FBE4F24240A25F5B3FFDF94C40DE8D058541F14240A25F5B3FFDF94C40
21782	Парфеньево	1	17	820	37.695312999999999	37.705787000000001	57.992800000000003	57.987417999999998	0103000020E61000000100000005000000E8BD310400D94240A9BD88B663FE4C40E8BD310400D9424002BC051214FF4C409278793A57DA424002BC051214FF4C409278793A57DA4240A9BD88B663FE4C40E8BD310400D94240A9BD88B663FE4C40
22474	Октябрь	1	17	820	37.378998000000003	37.398518000000003	57.832419999999999	57.821100000000001	0103000020E61000000100000005000000ED9FA70183B04240705F07CE19E94C40ED9FA70183B04240A64412BD8CEA4C40056F48A302B34240A64412BD8CEA4C40056F48A302B34240705F07CE19E94C40ED9FA70183B04240705F07CE19E94C40
21301	Новый Некоуз	1	17	820	38.034319000000004	38.086824999999997	57.914690999999998	57.888952000000003	0103000020E61000000100000005000000D350A390640443405EDBDB2DC9F14C40D350A3906404434007793D9814F54C40D3BCE3141D0B434007793D9814F54C40D3BCE3141D0B43405EDBDB2DC9F14C40D350A390640443405EDBDB2DC9F14C40
21747	Новинское	1	17	820	37.794854999999998	37.811464999999998	57.898508999999997	57.883975999999997	0103000020E61000000100000005000000F20703CFBDE542407539252026F14C40F20703CFBDE54240B114C95702F34C40A06CCA15DEE74240B114C95702F34C40A06CCA15DEE742407539252026F14C40F20703CFBDE542407539252026F14C40
50948	Новая Ура	1	17	820	37.330983000000003	38.431545	58.210996000000002	57.690699000000002	0103000020E610000001000000050000001844A4A65DAA4240A13028D368D84C401844A4A65DAA42401DCBBBEA011B4D404CE0D6DD3C3743401DCBBBEA011B4D404CE0D6DD3C374340A13028D368D84C401844A4A65DAA4240A13028D368D84C40
49224	Никольское	1	17	820	38.286898000000001	38.297687000000003	57.913936	57.910708	0103000020E61000000100000005000000D7A4DB12B9244340501A6A1492F44C40D7A4DB12B92443408B51D7DAFBF44C40E1B88C9B1A2643408B51D7DAFBF44C40E1B88C9B1A264340501A6A1492F44C40D7A4DB12B9244340501A6A1492F44C40
21519	Некоуз	1	17	820	37.98413	38.005761	57.918582000000001	57.906883000000001	0103000020E610000001000000050000009981CAF8F7FD42403126FDBD14F44C409981CAF8F7FD4240DE58501894F54C40CF4BC5C6BC004340DE58501894F54C40CF4BC5C6BC0043403126FDBD14F44C409981CAF8F7FD42403126FDBD14F44C40
50942	Мокеиха	1	17	820	37.330983000000003	38.431545	58.210996000000002	57.690699000000002	0103000020E610000001000000050000001844A4A65DAA4240A13028D368D84C401844A4A65DAA42401DCBBBEA011B4D404CE0D6DD3C3743401DCBBBEA011B4D404CE0D6DD3C374340A13028D368D84C401844A4A65DAA4240A13028D368D84C40
22143	Марьино	1	17	820	38.18882	38.211880000000001	58.013415999999999	58.004460999999999	0103000020E61000000100000005000000556AF6402B184340C18D942D92004D40556AF6402B1843401F9F909DB7014D40975643E21E1B43401F9F909DB7014D40975643E21E1B4340C18D942D92004D40556AF6402B184340C18D942D92004D40
22007	Лацкое	1	17	820	38.112059000000002	38.135720999999997	58.083458999999998	58.064759000000002	0103000020E610000001000000050000007A1C06F3570E4340938FDD054A084D407A1C06F3570E434047C7D5C8AE0A4D40B130444E5F11434047C7D5C8AE0A4D40B130444E5F114340938FDD054A084D407A1C06F3570E4340938FDD054A084D40
21677	Данилово	1	17	820	38.053345	38.069927999999997	57.970883000000001	57.958685000000003	0103000020E61000000100000005000000DB334B02D40643403815A930B6FA4C40DB334B02D4064340069FE6E445FC4C408F899466F3084340069FE6E445FC4C408F899466F30843403815A930B6FA4C40DB334B02D40643403815A930B6FA4C40
5867	Воскресенское	1	17	820	38.035207999999997	38.057298000000003	58.120728999999997	58.110326999999998	0103000020E610000001000000050000005E471CB281044340D26EF4311F0E4D405E471CB281044340E256410C740F4D402810768A55074340E256410C740F4D402810768A55074340D26EF4311F0E4D405E471CB281044340D26EF4311F0E4D40
50923	Волга	1	17	820	38.361376999999997	38.421698999999997	57.964123000000001	57.936872000000001	0103000020E610000001000000050000006743FE99412E4340E144F46BEBF74C406743FE99412E43402429E96168FB4C40C1E09A3BFA3543402429E96168FB4C40C1E09A3BFA354340E144F46BEBF74C406743FE99412E4340E144F46BEBF74C40
22084	Веретея	1	17	820	38.199088000000003	38.212383000000003	58.120291999999999	58.111854000000001	0103000020E61000000100000005000000568330B77B194340A1F65B3B510E4D40568330B77B19434037FC6EBA650F4D40FA9CBB5D2F1B434037FC6EBA650F4D40FA9CBB5D2F1B4340A1F65B3B510E4D40568330B77B194340A1F65B3B510E4D40
21913	Борок	1	17	820	38.229998999999999	38.250470999999997	58.073478999999999	58.048001999999997	0103000020E610000001000000050000006D8E739B701D43404012F6ED24064D406D8E739B701D4340ADF886C267094D4057CC086F0F204340ADF886C267094D4057CC086F0F2043404012F6ED24064D406D8E739B701D43404012F6ED24064D40
50578	Андреевское	1	17	820	38.198009999999996	38.208188	58.004275	57.998489999999997	0103000020E61000000100000005000000F62345645819434007B13385CEFF4C40F6234564581943405F984C158C004D40B7B585E7A51A43405F984C158C004D40B7B585E7A51A434007B13385CEFF4C40F62345645819434007B13385CEFF4C40
50629	с. Флоровское	1	17	1633	37.633895000000003	38.646296	57.959176999999997	57.613298999999998	0103000020E61000000100000005000000890CAB7823D14240B2D5E59480CE4C40890CAB7823D14240A609DB4FC6FA4C408FC4CBD3B9524340A609DB4FC6FA4C408FC4CBD3B9524340B2D5E59480CE4C40890CAB7823D14240B2D5E59480CE4C40
21144	Шипилово	1	17	1633	38.198135999999998	38.222982999999999	57.763444	57.757542999999998	0103000020E6100000010000000500000083143C855C1943402828452BF7E04C4083143C855C194340E9297288B8E14C403048FAB48A1C4340E9297288B8E14C403048FAB48A1C43402828452BF7E04C4083143C855C1943402828452BF7E04C40
20529	Ступино	1	17	1633	38.132460000000002	38.152608999999998	57.784993999999998	57.778381000000003	0103000020E610000001000000050000009B030473F4104340F56915FDA1E34C409B030473F410434032C7F2AE7AE44C40A20914B18813434032C7F2AE7AE44C40A20914B188134340F56915FDA1E34C409B030473F4104340F56915FDA1E34C40
20981	Сера	1	17	1633	38.319668999999998	38.336620000000003	57.683107	57.671359000000002	0103000020E61000000100000005000000C345EEE9EA28434009707A17EFD54C40C345EEE9EA2843409755D80C70D74C40FB96395D162B43409755D80C70D74C40FB96395D162B434009707A17EFD54C40C345EEE9EA28434009707A17EFD54C40
21046	Рождествено	1	17	1633	37.927967000000002	37.950201	57.732785999999997	57.721127000000003	0103000020E610000001000000050000003562669FC7F642409DA1B8E34DDC4C403562669FC7F64240BB7B80EECBDD4C4031D0B52FA0F94240BB7B80EECBDD4C4031D0B52FA0F942409DA1B8E34DDC4C403562669FC7F642409DA1B8E34DDC4C40
20959	Поводнево	1	17	1633	38.424079999999996	38.439441000000002	57.749071999999998	57.741779999999999	0103000020E610000001000000050000009F71E14048364340D769A4A5F2DE4C409F71E14048364340B62C5F97E1DF4C40C2C2499A3F384340B62C5F97E1DF4C40C2C2499A3F384340D769A4A5F2DE4C409F71E14048364340D769A4A5F2DE4C40
20894	Охотино	1	17	1633	38.495801	38.508916999999997	57.803288999999999	57.795029999999997	0103000020E610000001000000050000007C293C68763F434060AB048BC3E54C407C293C68763F4340471E882CD2E64C4070B0373124414340471E882CD2E64C4070B037312441434060AB048BC3E54C407C293C68763F434060AB048BC3E54C40
21218	Мышкин	1	17	1633	38.430233000000001	38.481006000000001	57.802022999999998	57.773822000000003	0103000020E610000001000000050000007A54FCDF1137434071766B990CE34C407A54FCDF11374340E5D18DB0A8E64C400397C79A913D4340E5D18DB0A8E64C400397C79A913D434071766B990CE34C407A54FCDF1137434071766B990CE34C40
50569	Мартыново	1	17	1633	37.987076000000002	38.002490999999999	57.683168999999999	57.674016000000002	0103000020E610000001000000050000005055A18158FE4240897D022846D64C405055A18158FE42400D52F01472D74C4065C405A0510043400D52F01472D74C4065C405A051004340897D022846D64C405055A18158FE4240897D022846D64C40
20775	Крюково	1	17	1633	38.249285999999998	38.261080999999997	57.840235	57.836823000000003	0103000020E61000000100000005000000E2AC889AE81F434033C51C041DEB4C40E2AC889AE81F43402FFA0AD28CEB4C40B14D2A1A6B2143402FFA0AD28CEB4C40B14D2A1A6B21434033C51C041DEB4C40E2AC889AE81F434033C51C041DEB4C40
20675	Кривец	1	17	1633	38.475940000000001	38.485022000000001	57.843684000000003	57.835960999999998	0103000020E61000000100000005000000DB6D179AEB3C4340A0DD21C500EB4C40DB6D179AEB3C434049145AD6FDEB4C4096EB6D33153E434049145AD6FDEB4C4096EB6D33153E4340A0DD21C500EB4C40DB6D179AEB3C4340A0DD21C500EB4C40
20709	Коптево	1	17	1633	38.425733000000001	38.458404000000002	57.861628000000003	57.852521000000003	0103000020E61000000100000005000000FBE93F6B7E3643409D137B681FED4C40FBE93F6B7E364340B1A888D349EE4C40842D76FBAC3A4340B1A888D349EE4C40842D76FBAC3A43409D137B681FED4C40FBE93F6B7E3643409D137B681FED4C40
47617	Горелово	1	17	1633	38.158546999999999	38.166964	57.828173999999997	57.824930000000002	0103000020E6100000010000000500000080F0A1444B144340A1BE654E97E94C4080F0A1444B144340E1B20A9B01EA4C40FFCD8B135F154340E1B20A9B01EA4C40FFCD8B135F154340A1BE654E97E94C4080F0A1444B144340A1BE654E97E94C40
20620	Галачевская	1	17	1633	38.440438	38.447651999999998	57.811166999999998	57.808759999999999	0103000020E6100000010000000500000034F5BA45603843400F289B7285E74C4034F5BA4560384340164CFC51D4E74C4097FE25A94C394340164CFC51D4E74C4097FE25A94C3943400F289B7285E74C4034F5BA45603843400F289B7285E74C40
20540	Богородское	1	17	1633	37.765892999999998	37.785252	57.664447000000003	57.653829999999999	0103000020E610000001000000050000001F9E25C808E24240649291B3B0D34C401F9E25C808E2424071766B990CD54C402E8F352383E4424071766B990CD54C402E8F352383E44240649291B3B0D34C401F9E25C808E24240649291B3B0D34C40
49124	Шашково	1	17	818	40.526415999999998	40.533575999999996	58.293320000000001	58.290982999999997	0103000020E61000000100000005000000AA0B789961434440925852EE3E254D40AA0B789961434440A1A17F828B254D401AF7E6374C444440A1A17F828B254D401AF7E6374C444440925852EE3E254D40AA0B789961434440925852EE3E254D40
20307	Черново	1	17	818	40.571655	40.591292000000003	58.085562000000003	58.076943999999997	0103000020E6100000010000000500000025CCB4FD2B494440CCCF0D4DD9094D4025CCB4FD2B494440E3E313B2F30A4D407731CD74AF4B4440E3E313B2F30A4D407731CD74AF4B4440CCCF0D4DD9094D4025CCB4FD2B494440CCCF0D4DD9094D40
18589	Фрольцево	1	17	818	40.515618000000003	40.531339000000003	58.512193000000003	58.502676999999998	0103000020E610000001000000050000004E9D47C5FF414440C7B94DB857404D404E9D47C5FF414440BD1E4C8A8F414D40700B96EA02444440BD1E4C8A8F414D40700B96EA02444440C7B94DB857404D404E9D47C5FF414440C7B94DB857404D40
19118	Филиппово	1	17	818	40.536090999999999	40.555529999999997	58.184412000000002	58.178220000000003	0103000020E61000000100000005000000085740A19E4444401FBFB7E9CF164D40085740A19E444440B77EFACF9A174D4033F9669B1B474440B77EFACF9A174D4033F9669B1B4744401FBFB7E9CF164D40085740A19E4444401FBFB7E9CF164D40
20385	Троица	1	17	818	40.692784000000003	40.717343999999997	58.505826999999996	58.493042000000003	0103000020E6100000010000000500000096986725AD584440F8C610001C3F4D4096986725AD58444086376BF0BE404D40ACFD9DEDD15B444086376BF0BE404D40ACFD9DEDD15B4440F8C610001C3F4D4096986725AD584440F8C610001C3F4D40
19843	Страшево	1	17	818	40.435048000000002	40.451757000000001	58.285235	58.277332999999999	0103000020E61000000100000005000000591822A7AF374440008DD2A57F234D40591822A7AF37444058569A9482244D409A5E622CD339444058569A9482244D409A5E622CD3394440008DD2A57F234D40591822A7AF374440008DD2A57F234D40
5841	Соколиный	1	17	818	40.785184999999998	40.797393	58.344759000000003	58.337744999999998	0103000020E61000000100000005000000A6272CF1806444409AB1683A3B2B4D40A6272CF18064444037001B10212C4D4098874CF91066444037001B10212C4D4098874CF9106644409AB1683A3B2B4D40A6272CF1806444409AB1683A3B2B4D40
20182	Семендяево	1	17	818	40.722689000000003	40.731788999999999	58.188268999999998	58.179909000000002	0103000020E61000000100000005000000E816BA12815C4440C7A0134207174D40E816BA12815C4440E1ECD63219184D4049490F43AB5D4440E1ECD63219184D4049490F43AB5D4440C7A0134207174D40E816BA12815C4440C7A0134207174D40
20262	Рузбугино	1	17	818	40.649144	40.665726999999997	58.081698000000003	58.070247000000002	0103000020E6100000010000000500000083328D261753444031D28BDAFD084D4083328D261753444006137F14750A4D403788D68A3655444006137F14750A4D403788D68A3655444031D28BDAFD084D4083328D261753444031D28BDAFD084D40
20147	Раслово-Барское	1	17	818	40.669094999999999	40.685093999999999	58.283172	58.276718000000002	0103000020E610000001000000050000006475ABE7A4554440761BD47E6B234D406475ABE7A45544404B92E7FA3E244D40C9570229B15744404B92E7FA3E244D40C9570229B1574440761BD47E6B234D406475ABE7A4554440761BD47E6B234D40
20009	Покров	1	17	818	40.858083000000001	40.873265000000004	58.474387999999998	58.461624	0103000020E610000001000000050000007520EBA9D56D44403C86C77E163B4D407520EBA9D56D4440B3CEF8BEB83C4D40E8DEC325C76F4440B3CEF8BEB83C4D40E8DEC325C76F44403C86C77E163B4D407520EBA9D56D44403C86C77E163B4D40
19795	Отрадный	1	17	818	40.694149000000003	40.720551	58.381373000000004	58.370778999999999	0103000020E610000001000000050000008BC6DADFD95844409485AFAF752F4D408BC6DADFD9584440E94999D4D0304D40D00CE2033B5C4440E94999D4D0304D40D00CE2033B5C44409485AFAF752F4D408BC6DADFD95844409485AFAF752F4D40
20070	Обнорское	1	17	818	40.901445000000002	40.916060000000002	58.271738999999997	58.261671	0103000020E610000001000000050000004512BD8C62734440E3A7716F7E214D404512BD8C627344401C06F357C8224D403E963E74417544401C06F357C8224D403E963E7441754440E3A7716F7E214D404512BD8C62734440E3A7716F7E214D40
19380	Минино	1	17	818	41.093037000000002	41.114615000000001	58.349704000000003	58.339492999999997	0103000020E61000000100000005000000B328ECA2E88B4440471CB281742B4D40B328ECA2E88B4440E4A3C519C32C4D40C6504EB4AB8E4440E4A3C519C32C4D40C6504EB4AB8E4440471CB281742B4D40B328ECA2E88B4440471CB281742B4D40
17881	Любим	1	17	818	40.662537999999998	40.716256999999999	58.370806999999999	58.331031000000003	0103000020E61000000100000005000000BA2D910BCE544440297B4B395F2A4D40BA2D910BCE5444405E10919A762F4D40FA43334FAE5B44405E10919A762F4D40FA43334FAE5B4440297B4B395F2A4D40BA2D910BCE544440297B4B395F2A4D40
50530	Крутик	1	17	818	40.763705999999999	40.788437000000002	58.088763999999998	58.078142999999997	0103000020E6100000010000000500000026E1421EC1614440A6B4FE96000A4D4026E1421EC1614440F487669E5C0B4D406AFAEC80EB644440F487669E5C0B4D406AFAEC80EB644440A6B4FE96000A4D4026E1421EC1614440A6B4FE96000A4D40
50906	Красный Бор	1	17	818	40.852487000000004	40.866401000000003	58.115633000000003	58.112400000000001	0103000020E61000000100000005000000F1A1444B1E6D444003098A1F630E4D40F1A1444B1E6D444050ABE80FCD0E4D40611C5C3AE66E444050ABE80FCD0E4D40611C5C3AE66E444003098A1F630E4D40F1A1444B1E6D444003098A1F630E4D40
19590	Кириллово	1	17	818	40.857733000000003	40.871144999999999	58.409185999999998	58.399515000000001	0103000020E6100000010000000500000099D9E731CA6D444077A1B94E23334D4099D9E731CA6D444093FDF33460344D407689EAAD816F444093FDF33460344D407689EAAD816F444077A1B94E23334D4099D9E731CA6D444077A1B94E23334D40
19648	Кинтаново	1	17	818	40.944248999999999	40.954929999999997	58.386152000000003	58.367649999999998	0103000020E61000000100000005000000EE23B726DD784440EC2FBB270F2F4D40EE23B726DD7844407BA4C16D6D314D4011FC6F253B7A44407BA4C16D6D314D4011FC6F253B7A4440EC2FBB270F2F4D40EE23B726DD784440EC2FBB270F2F4D40
19480	Закобякино	1	17	818	40.716355999999998	40.733638999999997	58.113160999999998	58.098714999999999	0103000020E610000001000000050000008D25AC8DB15B4440F44F70B1A20C4D408D25AC8DB15B44406117450F7C0E4D40FA08FCE1E75D44406117450F7C0E4D40FA08FCE1E75D4440F44F70B1A20C4D408D25AC8DB15B4440F44F70B1A20C4D40
19428	Ермаково	1	17	818	40.998750000000001	41.020319000000001	58.328744	58.318134000000001	0103000020E61000000100000005000000A4703D0AD77F444072DF6A9DB8284D40A4703D0AD77F4440CC608C48142A4D40643E20D099824440CC608C48142A4D40643E20D09982444072DF6A9DB8284D40A4703D0AD77F444072DF6A9DB8284D40
50920	Гузыцыно	1	17	818	40.616813999999998	40.630251999999999	58.350955999999996	58.345165999999999	0103000020E6100000010000000500000083DBDAC2F34E444077D844662E2C4D4083DBDAC2F34E4440E02A4F20EC2C4D408A1EF818AC504440E02A4F20EC2C4D408A1EF818AC50444077D844662E2C4D4083DBDAC2F34E444077D844662E2C4D40
19903	Вахромейка	1	17	818	40.546501999999997	40.554775999999997	58.361871999999998	58.358849999999997	0103000020E610000001000000050000006B990CC7F3454440B515FBCBEE2D4D406B990CC7F345444047AB5AD2512E4D40874D64E60247444047AB5AD2512E4D40874D64E602474440B515FBCBEE2D4D406B990CC7F3454440B515FBCBEE2D4D40
18087	Шаготь	1	17	1488	39.604143000000001	39.630319999999998	58.204954999999998	58.195076999999998	0103000020E61000000100000005000000BD8DCD8E54CD4340D4997B48F8184D40BD8DCD8E54CD43406A1327F73B1A4D40E2016553AED043406A1327F73B1A4D40E2016553AED04340D4997B48F8184D40BD8DCD8E54CD4340D4997B48F8184D40
18865	Чурьяково	1	17	1488	40.400965999999997	40.548029999999997	57.993377000000002	57.976171000000001	0103000020E610000001000000050000006A6798DA52334440DD26DC2BF3FC4C406A6798DA523344409FCC3FFA26FF4C400A9DD7D8254644409FCC3FFA26FF4C400A9DD7D825464440DD26DC2BF3FC4C406A6798DA52334440DD26DC2BF3FC4C40
17993	Хабарово	1	17	1488	39.974114	40.017116000000001	58.305408	58.296796000000001	0103000020E61000000100000005000000B2497EC4AFFC4340B4CA4C69FD254D40B2497EC4AFFC4340E8F7FD9B17274D40821E6ADB30024440E8F7FD9B17274D40821E6ADB30024440B4CA4C69FD254D40B2497EC4AFFC4340B4CA4C69FD254D40
19012	Федурино	1	17	1488	40.440922999999998	40.459887000000002	58.050736000000001	58.041038	0103000020E61000000100000005000000F086342A7038444056F2B1BB40054D40F086342A703844406C5D6A847E064D40836DC493DD3A44406C5D6A847E064D40836DC493DD3A444056F2B1BB40054D40F086342A7038444056F2B1BB40054D40
50943	Трофимово	1	17	1488	39.515093	40.692191000000001	58.393996999999999	57.872998000000003	0103000020E6100000010000000500000003B34291EEC1434099BC0166BEEF4C4003B34291EEC143406EDC627E6E324D40F3CAF5B6995844406EDC627E6E324D40F3CAF5B69958444099BC0166BEEF4C4003B34291EEC1434099BC0166BEEF4C40
18271	Торопово	1	17	1488	39.947127999999999	39.964053	58.139403999999999	58.125933000000003	0103000020E610000001000000050000001D90847D3BF943405C3E92921E104D401D90847D3BF943403E7782FDD7114D402B4EB51666FB43403E7782FDD7114D402B4EB51666FB43405C3E92921E104D401D90847D3BF943405C3E92921E104D40
50524	Телицыно	1	17	1488	40.195673999999997	40.206149000000003	57.916578999999999	57.912100000000002	0103000020E61000000100000005000000B8567BD80B1944403F575BB1BFF44C40B8567BD80B194440A699EE7552F54C40338D2617631A4440A699EE7552F54C40338D2617631A44403F575BB1BFF44C40B8567BD80B1944403F575BB1BFF44C40
18171	Спас	1	17	1488	39.884714000000002	39.904854	58.214452000000001	58.204951000000001	0103000020E610000001000000050000001C28F04E3EF14340292499D53B1A4D401C28F04E3EF14340E947C329731B4D40D0D38041D2F34340E947C329731B4D40D0D38041D2F34340292499D53B1A4D401C28F04E3EF14340292499D53B1A4D40
18375	Скоково	1	17	1488	40.004243000000002	40.030383999999998	58.004474999999999	57.996344000000001	0103000020E61000000100000005000000541EDD088B0044406DC83F3388FF4C40541EDD088B004440265305A392004D402C29779FE3034440265305A392004D402C29779FE30344406DC83F3388FF4C40541EDD088B0044406DC83F3388FF4C40
18909	Середа	1	17	1488	40.428203000000003	40.456885999999997	58.012127999999997	57.998604999999998	0103000020E6100000010000000500000049861C5BCF364440A04FE449D2FF4C4049861C5BCF364440D5AE09698D014D4008008E3D7B3A4440D5AE09698D014D4008008E3D7B3A4440A04FE449D2FF4C4049861C5BCF364440A04FE449D2FF4C40
19075	Семлово	1	17	1488	40.353040999999997	40.372354999999999	58.087484000000003	58.081389000000001	0103000020E61000000100000005000000D5928E72302D444088A06AF46A0A4D40D5928E72302D44402E76FBAC320B4D4044C02154A92F44402E76FBAC320B4D4044C02154A92F444088A06AF46A0A4D40D5928E72302D444088A06AF46A0A4D40
18331	Рыжиково	1	17	1488	39.891658	39.914008000000003	58.040114000000003	58.030937000000002	0103000020E61000000100000005000000BF9B6ED921F24340419E5DBEF5034D40BF9B6ED921F243404E0E9F7422054D402524D236FEF443404E0E9F7422054D402524D236FEF44340419E5DBEF5034D40BF9B6ED921F24340419E5DBEF5034D40
17947	Рощино	1	17	1488	40.191083999999996	40.203687000000002	58.267195000000001	58.261088000000001	0103000020E61000000100000005000000F964C5707518444064B0E2546B214D40F964C57075184440CE531D7233224D4068CF656A121A4440CE531D7233224D4068CF656A121A444064B0E2546B214D40F964C5707518444064B0E2546B214D40
17785	Покров	1	17	1488	40.278382000000001	40.305314000000003	58.255132000000003	58.243642000000001	0103000020E61000000100000005000000C5E57805A22344404DF73AA92F1F4D40C5E57805A2234440E014562AA8204D406781768714274440E014562AA8204D4067817687142744404DF73AA92F1F4D40C5E57805A22344404DF73AA92F1F4D40
18232	Мишутино	1	17	1488	39.841135999999999	39.866253	58.135798000000001	58.127321000000002	0103000020E610000001000000050000007FBE2D58AAEB4340098CF50D4C104D407FBE2D58AAEB43405D6E30D461114D40EC87D860E1EE43405D6E30D461114D40EC87D860E1EE4340098CF50D4C104D407FBE2D58AAEB4340098CF50D4C104D40
17749	Малое Марьино	1	17	1488	40.280053000000002	40.294587999999997	58.163120999999997	58.157342999999997	0103000020E61000000100000005000000C712D6C6D823444094A0BFD023144D40C712D6C6D823444039252026E1144D40A3E5400FB525444039252026E1144D40A3E5400FB525444094A0BFD023144D40C712D6C6D823444094A0BFD023144D40
17844	Макарово	1	17	1488	40.191370999999997	40.22813	58.317155999999997	58.303832999999997	0103000020E610000001000000050000008F334DD87E1844400839EFFFE3264D408F334DD87E18444076DD5B9198284D40459E245D331D444076DD5B9198284D40459E245D331D44400839EFFFE3264D408F334DD87E1844400839EFFFE3264D40
18802	Лыкошино	1	17	1488	40.388883999999997	40.399349000000001	57.963206999999997	57.958174	0103000020E6100000010000000500000005F86EF3C631444052F01472A5FA4C4005F86EF3C63144409E23F25D4AFB4C405C5837DE1D3344409E23F25D4AFB4C405C5837DE1D33444052F01472A5FA4C4005F86EF3C631444052F01472A5FA4C40
18545	Кузьмино	1	17	1488	40.124293999999999	40.254818999999998	58.140093	58.110351000000001	0103000020E61000000100000005000000658BA4DDE80F44405B0A48FB1F0E4D40658BA4DDE80F444003B34291EE114D4020B3B3E89D20444003B34291EE114D4020B3B3E89D2044405B0A48FB1F0E4D40658BA4DDE80F44405B0A48FB1F0E4D40
18441	Костюшино	1	17	1488	40.007494999999999	40.027644000000002	57.970205	57.957166999999998	0103000020E6100000010000000500000017F19D98F5004440BCE7C07284FA4C4017F19D98F500444035B56CAD2FFC4C401FF7ADD68903444035B56CAD2FFC4C401FF7ADD689034440BCE7C07284FA4C4017F19D98F5004440BCE7C07284FA4C40
47745	Косково	1	17	1488	40.363146999999998	40.373873000000003	57.914642999999998	57.906619999999997	0103000020E61000000100000005000000FC51D4997B2E444023F3C81F0CF44C40FC51D4997B2E4440F641960513F54C40C0ED0912DB2F4440F641960513F54C40C0ED0912DB2F444023F3C81F0CF44C40FC51D4997B2E444023F3C81F0CF44C40
18970	Козлово	1	17	1488	40.344444000000003	40.369560999999997	58.038297999999998	58.029859999999999	0103000020E61000000100000005000000D7A6B1BD162C4440B2BAD573D2034D40D7A6B1BD162C444048C0E8F2E6044D4043705CC64D2F444048C0E8F2E6044D4043705CC64D2F4440B2BAD573D2034D40D7A6B1BD162C4440B2BAD573D2034D40
18044	Ермаково	1	17	1488	39.803066000000001	39.821148999999998	58.290647	58.286138999999999	0103000020E61000000100000005000000C843DFDDCAE64340198EE733A0244D40C843DFDDCAE643401BD7BFEB33254D40511212691BE943401BD7BFEB33254D40511212691BE94340198EE733A0244D40C843DFDDCAE64340198EE733A0244D40
18658	Дмитриевское	1	17	1488	40.165292999999998	40.182819000000002	57.999935000000001	57.990304999999999	0103000020E61000000100000005000000FDA02E52281544405B087250C2FE4C40FDA02E52281544401990BDDEFDFF4C40310BED9C661744401990BDDEFDFF4C40310BED9C661744405B087250C2FE4C40FDA02E52281544405B087250C2FE4C40
17191	Данилов	1	17	1488	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
17679	Горушка	1	17	1488	40.130915000000002	40.158501999999999	58.193986000000002	58.175333999999999	0103000020E6100000010000000500000026C79DD2C11044403DF0315871164D4026C79DD2C1104440E1F08288D4184D40E02C25CB49144440E1F08288D4184D40E02C25CB491444403DF0315871164D4026C79DD2C11044403DF0315871164D40
18150	Горинское	1	17	1488	39.758913	39.774265999999997	58.182290999999999	58.172786000000002	0103000020E610000001000000050000002FC1A90F24E14340749A05DA1D164D402FC1A90F24E1434075ADBD4F55174D40CE33F6251BE3434075ADBD4F55174D40CE33F6251BE34340749A05DA1D164D402FC1A90F24E14340749A05DA1D164D40
47121	Волково	1	17	1488	40.151549000000003	40.162768999999997	58.094718999999998	58.090766000000002	0103000020E61000000100000005000000EA5E27F5651344405CCB64389E0B4D40EA5E27F565134440A8A78FC01F0C4D40BCE6559DD5144440A8A78FC01F0C4D40BCE6559DD51444405CCB64389E0B4D40EA5E27F5651344405CCB64389E0B4D40
18481	Бабаево	1	17	1488	40.088146000000002	40.107460000000003	58.090623999999998	58.080722000000002	0103000020E61000000100000005000000F9A23D5E480B4440AB083719550A4D40F9A23D5E480B4440C91D3691990B4D4068D0D03FC10D4440C91D3691990B4D4068D0D03FC10D4440AB083719550A4D40F9A23D5E480B4440AB083719550A4D40
17026	Шопша	1	17	1422	39.636418999999997	39.657744999999998	57.428243000000002	57.416384000000001	0103000020E61000000100000005000000C9C6832D76D14340F14927124CB54C40C9C6832D76D14340D7DEA7AAD0B64C40C30DF8FC30D44340D7DEA7AAD0B64C40C30DF8FC30D44340F14927124CB54C40C9C6832D76D14340F14927124CB54C40
17089	Шалаево	1	17	1422	39.587021	39.599983999999999	57.364716000000001	57.357531000000002	0103000020E6100000010000000500000059880E8123CB434031276893C3AD4C4059880E8123CB4340FA298E03AFAE4C40C70F9546CCCC4340FA298E03AFAE4C40C70F9546CCCC434031276893C3AD4C4059880E8123CB434031276893C3AD4C40
16807	Ульяново	1	17	1422	40.109921	40.122613999999999	57.229773000000002	57.223911999999999	0103000020E6100000010000000500000062122EE4110E44404A97FE25A99C4C4062122EE4110E44407D40A033699D4C401004C8D0B10F44407D40A033699D4C401004C8D0B10F44404A97FE25A99C4C4062122EE4110E44404A97FE25A99C4C40
16743	Стогинское	1	17	1422	40.043284	40.068446000000002	57.240367999999997	57.229801999999999	0103000020E61000000100000005000000543882548A0544401747E5266A9D4C40543882548A054440A180ED60C49E4C4061C5A9D6C2084440A180ED60C49E4C4061C5A9D6C20844401747E5266A9D4C40543882548A0544401747E5266A9D4C40
16877	Ставотино	1	17	1422	39.931192000000003	39.950775999999998	57.310426999999997	57.303809999999999	0103000020E61000000100000005000000FF25A94C31F743405019FF3EE3A64C40FF25A94C31F74340CF656A12BCA74C402DE92807B3F94340CF656A12BCA74C402DE92807B3F943405019FF3EE3A64C40FF25A94C31F743405019FF3EE3A64C40
16714	Пружинино	1	17	1422	40.161600999999997	40.187112999999997	57.303790999999997	57.289755999999997	0103000020E610000001000000050000001D007157AF144440EEE87FB916A54C401D007157AF144440D9E89C9FE2A64C4006D49B51F3174440D9E89C9FE2A64C4006D49B51F3174440EEE87FB916A54C401D007157AF144440EEE87FB916A54C40
16954	Прошенино	1	17	1422	39.990436000000003	40.005823999999997	57.378498	57.373845000000003	0103000020E61000000100000005000000FA635A9BC6FE4340F6622827DAAF4C40FA635A9BC6FE4340FBCC599F72B04C4015C440D7BE004440FBCC599F72B04C4015C440D7BE004440F6622827DAAF4C40FA635A9BC6FE4340F6622827DAAF4C40
16389	Поляна	1	17	1422	39.767994999999999	39.781066000000003	57.401077999999998	57.38205	0103000020E61000000100000005000000EA3E00A94DE24340E9B7AF03E7B04C40EA3E00A94DE2434092921E8656B34C403F027FF8F9E3434092921E8656B34C403F027FF8F9E34340E9B7AF03E7B04C40EA3E00A94DE24340E9B7AF03E7B04C40
16271	Плотина	1	17	1422	39.812902000000001	39.823529000000001	57.335467999999999	57.328229	0103000020E610000001000000050000002F6D382C0DE84340A54C6A6803AA4C402F6D382C0DE84340616D8C9DF0AA4C405F27F56569E94340616D8C9DF0AA4C405F27F56569E94340A54C6A6803AA4C402F6D382C0DE84340A54C6A6803AA4C40
16214	Плещеево	1	17	1422	39.716898999999998	39.740848	57.329118000000001	57.319623	0103000020E610000001000000050000007EC4AF58C3DB434053060E68E9A84C407EC4AF58C3DB43403143E38920AA4C404CA7751BD4DE43403143E38920AA4C404CA7751BD4DE434053060E68E9A84C407EC4AF58C3DB434053060E68E9A84C40
50566	Остров	1	17	1422	40.353732999999998	40.370548999999997	57.303538000000003	57.293438000000002	0103000020E610000001000000050000000B42791F472D4440ABB35A608FA54C400B42791F472D4440F08B4B55DAA64C4062484E266E2F4440F08B4B55DAA64C4062484E266E2F4440ABB35A608FA54C400B42791F472D4440ABB35A608FA54C40
16857	Осенево	1	17	1422	40.189880000000002	40.208672999999997	57.238736000000003	57.228565000000003	0103000020E610000001000000050000000E15E3FC4D1844405001309E419D4C400E15E3FC4D1844405E30B8E68E9E4C407347FFCBB51A44405E30B8E68E9E4C407347FFCBB51A44405001309E419D4C400E15E3FC4D1844405001309E419D4C40
16630	Митино	1	17	1422	40.255510999999998	40.273603000000001	57.340122000000001	57.335904999999997	0103000020E6100000010000000500000056629E95B42044400CC85EEFFEAA4C4056629E95B42044403753211E89AB4C40338B506C052344403753211E89AB4C40338B506C052344400CC85EEFFEAA4C4056629E95B42044400CC85EEFFEAA4C40
16313	Лахость	1	17	1422	39.743813000000003	39.756371000000001	57.273603999999999	57.264074999999998	0103000020E610000001000000050000007AABAE4335DF43407958A835CDA14C407AABAE4335DF43400307B47405A34C404852D2C3D0E043400307B47405A34C404852D2C3D0E043407958A835CDA14C407AABAE4335DF43407958A835CDA14C40
17129	Ильинское-Урусово	1	17	1422	39.417077999999997	39.438709000000003	57.423091999999997	57.413378999999999	0103000020E61000000100000005000000C7F0D8CF62B5434035ED629AE9B44C40C7F0D8CF62B543408099EFE027B64C40FEBAD39D27B843408099EFE027B64C40FEBAD39D27B8434035ED629AE9B44C40C7F0D8CF62B5434035ED629AE9B44C40
17001	Заячий Холм	1	17	1422	39.907305999999998	39.920341000000001	57.414712000000002	57.403595000000003	0103000020E6100000010000000500000077BB5E9A22F4434021EA3E00A9B34C4077BB5E9A22F443401FA1664815B54C407F15E0BBCDF543401FA1664815B54C407F15E0BBCDF5434021EA3E00A9B34C4077BB5E9A22F4434021EA3E00A9B34C40
15842	Гаврилов-Ям	1	17	1422	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
16470	Великое	1	17	1422	39.759425	39.788989000000001	57.359423999999997	57.342005999999998	0103000020E61000000100000005000000E561A1D634E14340948444DAC6AB4C40E561A1D634E14340E1B20A9B01AE4C40AEF36F97FDE44340E1B20A9B01AE4C40AEF36F97FDE44340948444DAC6AB4C40E561A1D634E14340948444DAC6AB4C40
47566	Ульяниха	1	17	1332	37.751609999999999	37.765785000000001	58.156427000000001	58.148197000000003	0103000020E610000001000000050000005CACA8C134E04240C32E8A1EF8124D405CACA8C134E042400F9BC8CC05144D4039622D3E05E242400F9BC8CC05144D4039622D3E05E24240C32E8A1EF8124D405CACA8C134E04240C32E8A1EF8124D40
14284	Сутка	1	17	1332	37.529933	37.556676000000003	58.345761000000003	58.337504000000003	0103000020E610000001000000050000001C0934D8D4C342407522C154332B4D401C0934D8D4C34240BB9D7DE5412C4D40EB3BBF2841C74240BB9D7DE5412C4D40EB3BBF2841C742407522C154332B4D401C0934D8D4C342407522C154332B4D40
15564	Суминское	1	17	1332	37.691682999999998	37.713152999999998	58.368603	58.363377999999997	0103000020E610000001000000050000007E198C1189D84240FE0A992B832E4D407E198C1189D842408F1A13622E2F4D40AB05F69848DB42408F1A13622E2F4D40AB05F69848DB4240FE0A992B832E4D407E198C1189D84240FE0A992B832E4D40
15471	Севастьянцево	1	17	1332	37.94623	37.957422999999999	58.234026	58.227392000000002	0103000020E610000001000000050000003E3F8C101EF942409FAF592E1B1D4D403E3F8C101EF94240F4346090F41D4D4017B83CD68CFA4240F4346090F41D4D4017B83CD68CFA42409FAF592E1B1D4D403E3F8C101EF942409FAF592E1B1D4D40
15617	Себельское	1	17	1332	37.544359999999998	37.575459000000002	58.371434999999998	58.366177	0103000020E6100000010000000500000012A0A696ADC5424011C64FE3DE2E4D4012A0A696ADC542407DCB9C2E8B2F4D402D98F8A3A8C942407DCB9C2E8B2F4D402D98F8A3A8C9424011C64FE3DE2E4D4012A0A696ADC5424011C64FE3DE2E4D40
47668	Прозорово	1	17	1332	37.63738	37.678486999999997	58.405602999999999	58.382666	0103000020E61000000100000005000000EF8FF7AA95D1424044A51133FB304D40EF8FF7AA95D142406A1492CCEA334D406DE179A9D8D642406A1492CCEA334D406DE179A9D8D6424044A51133FB304D40EF8FF7AA95D1424044A51133FB304D40
15394	Остряковка	1	17	1332	37.935315000000003	37.948745000000002	58.271427000000003	58.265832000000003	0103000020E61000000100000005000000A83AE466B8F742407A1D71C806224D40A83AE466B8F742402E20B41EBE224D402C9FE57970F942402E20B41EBE224D402C9FE57970F942407A1D71C806224D40A83AE466B8F742407A1D71C806224D40
47499	Новинка	1	17	1332	37.787345000000002	37.804395	58.331986000000001	58.323346999999998	0103000020E61000000100000005000000A6D590B8C7E442403E213B6F63294D40A6D590B8C7E442406C5D6A847E2A4D407008556AF6E642406C5D6A847E2A4D407008556AF6E642403E213B6F63294D40A6D590B8C7E442403E213B6F63294D40
47521	Логинцево	1	17	1332	37.743389999999998	37.760333000000003	58.314726	58.307479000000001	0103000020E6100000010000000500000033164D6727DF4240789ACC785B274D4033164D6727DF4240B7990AF148284D40E8887C9752E14240B7990AF148284D40E8887C9752E14240789ACC785B274D4033164D6727DF4240789ACC785B274D40
47708	Лискино	1	17	1332	37.448051	37.465119000000001	58.345402	58.336961000000002	0103000020E6100000010000000500000055F833BC59B942408483BD89212B4D4055F833BC59B942408BFCFA21362C4D40C6DFF60489BB42408BFCFA21362C4D40C6DFF60489BB42408483BD89212B4D4055F833BC59B942408483BD89212B4D40
50510	Коростень	1	17	1332	37.869990000000001	37.884245999999997	58.202674000000002	58.197831999999998	0103000020E610000001000000050000006CEC12D55BEF4240170D198F52194D406CEC12D55BEF4240F0DFBC38F1194D4035CF11F92EF14240F0DFBC38F1194D4035CF11F92EF14240170D198F52194D406CEC12D55BEF4240170D198F52194D40
15757	Брейтово	1	17	1332	37.841397000000001	37.887273999999998	58.311870999999996	58.282953999999997	0103000020E61000000100000005000000ECF99AE5B2EB4240DD2230D637244D40ECF99AE5B2EB424010C99063EB274D40A94BC63192F1424010C99063EB274D40A94BC63192F14240DD2230D637244D40ECF99AE5B2EB4240DD2230D637244D40
14077	Яковцево	1	17	785	39.293604000000002	39.307913999999997	57.360585	57.350588000000002	0103000020E61000000100000005000000C6FCDCD094A543405E2F4D11E0AC4C40C6FCDCD094A54340CE3637A627AE4C4082FDD7B969A74340CE3637A627AE4C4082FDD7B969A743405E2F4D11E0AC4C40C6FCDCD094A543405E2F4D11E0AC4C40
14508	Юркино	1	17	785	39.070894000000003	39.086559999999999	57.423295000000003	57.411977999999998	0103000020E61000000100000005000000C7BDF90D13894340F355F2B1BBB44C40C7BDF90D13894340B9C7D2872EB64C402592E865148B4340B9C7D2872EB64C402592E865148B4340F355F2B1BBB44C40C7BDF90D13894340F355F2B1BBB44C40
15014	Щурово	1	17	785	38.810580000000002	38.822833000000003	57.170707	57.164490000000001	0103000020E610000001000000050000005665DF15C1674340704221020E954C405665DF15C167434061191BBAD9954C40E8887C975269434061191BBAD9954C40E8887C9752694340704221020E954C405665DF15C1674340704221020E954C40
14895	Сущево	1	17	785	39.092058000000002	39.099981	57.198003999999997	57.190806000000002	0103000020E61000000100000005000000E7AA798EC88B4340B7F0BC546C984C40E7AA798EC88B4340143DF03158994C40569C6A2DCC8C4340143DF03158994C40569C6A2DCC8C4340B7F0BC546C984C40E7AA798EC88B4340B7F0BC546C984C40
50946	Сигарь	1	17	785	39.100107000000001	39.107787999999999	57.462184999999998	57.455537999999997	0103000020E61000000100000005000000E38C614ED08C4340E90AB6114FBA4C40E38C614ED08C4340D3D9C9E028BB4C405C7347FFCB8D4340D3D9C9E028BB4C405C7347FFCB8D4340E90AB6114FBA4C40E38C614ED08C4340E90AB6114FBA4C40
14305	Селище	1	17	785	39.112513	39.138168999999998	57.269030000000001	57.259099999999997	0103000020E61000000100000005000000FBAF73D3668E4340613255302AA14C40FBAF73D3668E43404AD235936FA24C4017299485AF9143404AD235936FA24C4017299485AF914340613255302AA14C40FBAF73D3668E4340613255302AA14C40
14920	Покровское	1	17	785	38.975565000000003	38.991104999999997	57.152090999999999	57.145954000000003	0103000020E61000000100000005000000A60F5D50DF7C4340365CE49EAE924C40A60F5D50DF7C43400A82C7B777934C4077F35487DC7E43400A82C7B777934C4077F35487DC7E4340365CE49EAE924C40A60F5D50DF7C4340365CE49EAE924C40
14443	Неверково	1	17	785	38.9529	38.974837000000001	57.466227000000003	57.455813999999997	0103000020E61000000100000005000000E02D90A0F87943408B87F71C58BA4C40E02D90A0F879434090C18A53ADBB4C4023F77475C77C434090C18A53ADBB4C4023F77475C77C43408B87F71C58BA4C40E02D90A0F87943408B87F71C58BA4C40
14224	Красный Октябрь	1	17	785	39.004947999999999	39.015279	57.331114999999997	57.318350000000002	0103000020E610000001000000050000001E17D522A28043403F575BB1BFA84C401E17D522A2804340861BF0F961AA4C4065A88AA9F4814340861BF0F961AA4C4065A88AA9F48143403F575BB1BFA84C401E17D522A28043403F575BB1BFA84C40
5557	Красново	1	17	785	39.183363	39.201248	57.230918000000003	57.223571	0103000020E61000000100000005000000F225547078974340C1AA7AF99D9C4C40F225547078974340640795B88E9D4C405531957EC2994340640795B88E9D4C405531957EC2994340C1AA7AF99D9C4C40F225547078974340C1AA7AF99D9C4C40
14714	Кондаково	1	17	785	38.780388000000002	38.792954999999999	57.295966999999997	57.282673000000003	0103000020E610000001000000050000006E1805C1E36343402A3BFDA02EA44C406E1805C1E3634340FDD8243FE2A54C408F19A88C7F654340FDD8243FE2A54C408F19A88C7F6543402A3BFDA02EA44C406E1805C1E36343402A3BFDA02EA44C40
14654	Козино	1	17	785	38.774216000000003	38.784457000000003	57.217548000000001	57.208516000000003	0103000020E610000001000000050000001D05888219634340AC58FCA6B09A4C401D05888219634340B5A7E49CD89B4C40240F441669644340B5A7E49CD89B4C40240F441669644340AC58FCA6B09A4C401D05888219634340AC58FCA6B09A4C40
50936	Инальцыно	1	17	785	38.960976000000002	38.973274000000004	57.201309999999999	57.195945999999999	0103000020E61000000100000005000000D61EF642017B434019E42EC214994C40D61EF642017B4340CB2DAD86C4994C400806103E947C4340CB2DAD86C4994C400806103E947C434019E42EC214994C40D61EF642017B434019E42EC214994C40
13992	Зачатье	1	17	785	38.752746000000002	38.769266000000002	57.120894999999997	57.113731000000001	0103000020E61000000100000005000000F0181EFB596043404CC5C6BC8E8E4C40F0181EFB59604340FD9FC37C798F4C405EF6EB4E77624340FD9FC37C798F4C405EF6EB4E776243404CC5C6BC8E8E4C40F0181EFB596043404CC5C6BC8E8E4C40
14727	Давыдово	1	17	785	38.836649000000001	38.850608999999999	57.319530999999998	57.312866999999997	0103000020E61000000100000005000000959D7E50176B4340B27F9E060CA84C40959D7E50176B434072874D64E6A84C40755776C1E06C434072874D64E6A84C40755776C1E06C4340B27F9E060CA84C40959D7E50176B4340B27F9E060CA84C40
14594	Высоково	1	17	785	38.740924999999997	38.758189999999999	57.243791999999999	57.232832999999999	0103000020E61000000100000005000000F7E461A1D65E4340FC36C478CD9D4C40F7E461A1D65E434062838593349F4C40BE13B35E0C61434062838593349F4C40BE13B35E0C614340FC36C478CD9D4C40F7E461A1D65E4340FC36C478CD9D4C40
14428	Вощажниково	1	17	785	39.130119999999998	39.151651999999999	57.373038999999999	57.351666000000002	0103000020E610000001000000050000001B47ACC5A7904340BD8E386403AD4C401B47ACC5A7904340F790F0BDBFAF4C40BE2F2E5569934340F790F0BDBFAF4C40BE2F2E5569934340BD8E386403AD4C401B47ACC5A7904340BD8E386403AD4C40
46369	Бурмакино	1	17	785	39.233417000000003	39.242409000000002	57.362512000000002	57.359983	0103000020E610000001000000050000004CAAB69BE09D4340D80E46EC13AE4C404CAAB69BE09D43402B3410CB66AE4C40C7A01342079F43402B3410CB66AE4C40C7A01342079F4340D80E46EC13AE4C404CAAB69BE09D4340D80E46EC13AE4C40
14143	Борисоглебский	1	17	785	39.120553000000001	39.176679	57.274850000000001	57.248710000000003	0103000020E61000000100000005000000A437DC476E8F43401618B2BAD59F4C40A437DC476E8F43401EA7E8482EA34C40EB71DF6A9D9643401EA7E8482EA34C40EB71DF6A9D9643401618B2BAD59F4C40A437DC476E8F43401618B2BAD59F4C40
14984	Березники	1	17	785	38.890413000000002	38.944788000000003	57.230347999999999	57.150905000000002	0103000020E6100000010000000500000075779D0DF9714340C5E6E3DA50934C4075779D0DF97143407959130B7C9D4C409ED32CD0EE7843407959130B7C9D4C409ED32CD0EE784340C5E6E3DA50934C4075779D0DF9714340C5E6E3DA50934C40
14022	Андреевское	1	17	785	39.020569999999999	39.247394999999997	57.313265999999999	57.196649000000001	0103000020E61000000100000005000000ADA3AA09A282434043E55FCB2B994C40ADA3AA09A28243407079AC1919A84C40D218ADA3AA9F43407079AC1919A84C40D218ADA3AA9F434043E55FCB2B994C40ADA3AA09A282434043E55FCB2B994C40
14798	Алешкино	1	17	785	38.957158	38.966814999999997	57.320793999999999	57.316999000000003	0103000020E61000000100000005000000698D4127847A4340AFEE586C93A84C40698D4127847A434063601DC70FA94C4020240B98C07B434063601DC70FA94C4020240B98C07B4340AFEE586C93A84C40698D4127847A4340AFEE586C93A84C40
13305	Шельшедом	1	17	1276	39.316133999999998	39.337316000000001	57.771920999999999	57.764567	0103000020E61000000100000005000000AB93331477A84340E84CDA54DDE14C40AB93331477A843403D0CAD4ECEE24C407235B22B2DAB43403D0CAD4ECEE24C407235B22B2DAB4340E84CDA54DDE14C40AB93331477A84340E84CDA54DDE14C40
13933	Чудиново	1	17	1276	39.164102999999997	39.172826000000001	57.675170999999999	57.671581000000003	0103000020E610000001000000050000007616BD5301954340B8CEBF5DF6D54C407616BD5301954340931ADA006CD64C4002F390291F964340931ADA006CD64C4002F390291F964340B8CEBF5DF6D54C407616BD5301954340B8CEBF5DF6D54C40
47329	Устье	1	17	1276	38.662951	38.668025999999998	57.719493	57.716800999999997	0103000020E61000000100000005000000DDEC0F94DB544340BB5E9A22C0DB4C40DDEC0F94DB544340B859BC5818DC4C4058703FE081554340B859BC5818DC4C4058703FE081554340BB5E9A22C0DB4C40DDEC0F94DB544340BB5E9A22C0DB4C40
13577	Новое Гостилово	1	17	1276	38.981771999999999	38.997807000000002	57.814033999999999	57.794440000000002	0103000020E61000000100000005000000731074B4AA7D43402F51BD35B0E54C40731074B4AA7D434081EA1F4432E84C40255CC823B87F434081EA1F4432E84C40255CC823B87F43402F51BD35B0E54C40731074B4AA7D43402F51BD35B0E54C40
13874	Новое	1	17	1276	38.758153999999998	38.793044999999999	57.708195000000003	57.695028000000001	0103000020E6100000010000000500000071AAB5300B614340F3E670ADF6D84C4071AAB5300B6143406A183E22A6DA4C40CFA0A17F826543406A183E22A6DA4C40CFA0A17F82654340F3E670ADF6D84C4071AAB5300B614340F3E670ADF6D84C40
13723	Миглино	1	17	1276	39.127325999999996	39.141789000000003	57.700040000000001	57.690905000000001	0103000020E610000001000000050000001AF7E6374C9043404AD235936FD84C401AF7E6374C90434028F224E99AD94C405EF756242692434028F224E99AD94C405EF75624269243404AD235936FD84C401AF7E6374C9043404AD235936FD84C40
13779	Иванцево	1	17	1276	38.765179000000003	38.776389999999999	57.636614999999999	57.629170999999999	0103000020E61000000100000005000000024BAE62F1614340BA4BE2AC88D04C40024BAE62F16143404F92AE997CD14C4081785DBF606343404F92AE997CD14C4081785DBF60634340BA4BE2AC88D04C40024BAE62F1614340BA4BE2AC88D04C40
13432	Дунилово	1	17	1276	38.918152999999997	38.943486	57.764135000000003	57.750560999999998	0103000020E61000000100000005000000B5DC9909867543409753026212E04C40B5DC9909867543404F5DF92CCFE14C40EF1D3526C47843404F5DF92CCFE14C40EF1D3526C47843409753026212E04C40B5DC9909867543409753026212E04C40
13839	Гари	1	17	1276	38.742353000000001	38.754651000000003	57.777732999999998	57.768397999999998	0103000020E61000000100000005000000338B506C055F4340E9279CDD5AE24C40338B506C055F43408E0244C18CE34C4065726A67986043408E0244C18CE34C4065726A6798604340E9279CDD5AE24C40338B506C055F4340E9279CDD5AE24C40
13651	Высоково	1	17	1276	38.900419999999997	38.914864999999999	57.611215999999999	57.603341999999998	0103000020E6100000010000000500000008556AF640734340D026874F3ACD4C4008556AF6407343405E656D533CCE4C40A5A0DB4B1A7543405E656D533CCE4C40A5A0DB4B1A754340D026874F3ACD4C4008556AF640734340D026874F3ACD4C40
13452	Варегово	1	17	1276	39.272395000000003	39.301859999999998	57.787229000000004	57.764850000000003	0103000020E61000000100000005000000064CE0D6DDA243403D2CD49AE6E14C40064CE0D6DDA243403DBB7CEBC3E44C403BFC3559A3A643403DBB7CEBC3E44C403BFC3559A3A643403D2CD49AE6E14C40064CE0D6DDA243403D2CD49AE6E14C40
13510	Борисовское	1	17	1276	39.074649000000001	39.093764999999998	57.822572000000001	57.811584000000003	0103000020E61000000100000005000000EDD632198E8943407BFA08FCE1E74C40EDD632198E8943407B4D0F0A4AE94C403541D47D008C43407B4D0F0A4AE94C403541D47D008C43407BFA08FCE1E74C40EDD632198E8943407BFA08FCE1E74C40
13378	Большие Починки	1	17	1276	38.776767	38.783810000000003	57.596643999999998	57.59252	0103000020E6100000010000000500000057CEDE196D634340EB1C03B2D7CB4C4057CEDE196D63434064ADA1D45ECC4C408E23D6E25364434064ADA1D45ECC4C408E23D6E253644340EB1C03B2D7CB4C4057CEDE196D634340EB1C03B2D7CB4C40
13704	Байково	1	17	1276	39.008003000000002	39.019680999999999	57.672181999999999	57.666753	0103000020E610000001000000050000008CA2073E0681434044C18C2958D54C408CA2073E06814340DD7A4D0F0AD64C4021AD31E884824340DD7A4D0F0AD64C4021AD31E88482434044C18C2958D54C408CA2073E0681434044C18C2958D54C40
48967	Арефино	1	17	1276	39.116762000000001	39.126086000000001	57.715983999999999	57.712575999999999	0103000020E6100000010000000500000031B5A50EF28E43400EF5BBB035DB4C4031B5A50EF28E4340C93A1C5DA5DB4C40E23D079623904340C93A1C5DA5DB4C40E23D0796239043400EF5BBB035DB4C4031B5A50EF28E43400EF5BBB035DB4C40
60607	д.Сестрики	1	16	\N	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
60512	Ясногорск	1	16	\N	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
60511	Щекино	1	16	\N	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
51156	Узловая	1	16	\N	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
12984	Тула	1	16	\N	37.496164999999998	37.741889999999998	54.299897999999999	54.087431000000002	0103000020E61000000100000005000000BD35B05582BF42400BD462F0300B4B40BD35B05582BF42406211C30E63264B405E9D6340F6DE42406211C30E63264B405E9D6340F6DE42400BD462F0300B4B40BD35B05582BF42400BD462F0300B4B40
60507	Суворов	1	16	\N	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
51300	Серебряные Ключи	1	16	\N	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
20502	Плеханово	1	16	\N	37.540622999999997	37.590739999999997	54.259900000000002	54.231180000000002	0103000020E61000000100000005000000923B6C2233C54240A1BE654E971D4B40923B6C2233C542407E1D386744214B4032384A5E9DCB42407E1D386744214B4032384A5E9DCB4240A1BE654E971D4B40923B6C2233C54240A1BE654E971D4B40
60504	Плавск	1	16	\N	37.266950999999999	37.325448999999999	53.725104999999999	53.682718999999999	0103000020E6100000010000000500000037514B732BA24240CDAD105663D74A4037514B732BA2424042959A3DD0DC4A4009C21550A8A9424042959A3DD0DC4A4009C21550A8A94240CDAD105663D74A4037514B732BA24240CDAD105663D74A40
60498	Киреевск	1	16	\N	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
60496	Кимовск	1	16	\N	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
60494	Ефремов	1	16	\N	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
14206	Донской	1	16	\N	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
60492	Богородицк	1	16	\N	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
51186	Донской	1	16	7109	38.253427000000002	38.43291	54.012078000000002	53.915686999999998	0103000020E610000001000000050000003276C24B70204340A92F4B3B35F54A403276C24B7020434024809BC58B014B40410E4A986937434024809BC58B014B40410E4A9869374340A92F4B3B35F54A403276C24B70204340A92F4B3B35F54A40
51189	Донской	1	16	7110	38.253427000000002	38.43291	54.012078000000002	53.915686999999998	0103000020E610000001000000050000003276C24B70204340A92F4B3B35F54A403276C24B7020434024809BC58B014B40410E4A986937434024809BC58B014B40410E4A9869374340A92F4B3B35F54A403276C24B70204340A92F4B3B35F54A40
12660	Ясногорск	1	16	1206	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
60543	Шилово	1	16	1206	37.669530999999999	37.681263000000001	54.477902	54.470536000000003	0103000020E610000001000000050000003F541A31B3D542409BCB0D863A3C4B403F541A31B3D54240B4588AE42B3D4B40C87C40A033D74240B4588AE42B3D4B40C87C40A033D742409BCB0D863A3C4B403F541A31B3D542409BCB0D863A3C4B40
12550	Хотушь	1	16	1206	37.723888000000002	37.755400999999999	54.549486000000002	54.536741999999997	0103000020E61000000100000005000000C2FBAA5CA8DC4240DF313CF6B3444B40C2FBAA5CA8DC424010CEA78E55464B40CF2EDFFAB0E0424010CEA78E55464B40CF2EDFFAB0E04240DF313CF6B3444B40C2FBAA5CA8DC4240DF313CF6B3444B40
11946	Федяшево	1	16	1206	37.691594000000002	37.708500000000001	54.373122000000002	54.364147000000003	0103000020E610000001000000050000000F0EF62686D84240E0F76F5E9C2E4B400F0EF62686D8424085B53176C22F4B40A69BC420B0DA424085B53176C22F4B40A69BC420B0DA4240E0F76F5E9C2E4B400F0EF62686D84240E0F76F5E9C2E4B40
11760	Тормино	1	16	1206	37.639679999999998	37.655751000000002	54.505789999999998	54.492316000000002	0103000020E61000000100000005000000E0F3C308E1D1424016A6EF35043F4B40E0F3C308E1D1424069520ABABD404B40DFA815A6EFD3424069520ABABD404B40DFA815A6EFD3424016A6EF35043F4B40E0F3C308E1D1424016A6EF35043F4B40
46488	Теляково	1	16	1206	37.890121000000001	37.913558000000002	54.546373000000003	54.533408999999999	0103000020E61000000100000005000000CD3D247CEFF142402F3201BF46444B40CD3D247CEFF142406E35EB8CEF454B40E57FF277EFF442406E35EB8CEF454B40E57FF277EFF442402F3201BF46444B40CD3D247CEFF142402F3201BF46444B40
18517	Страхово	1	16	1206	37.745879000000002	37.771614999999997	54.680681	54.670763999999998	0103000020E61000000100000005000000F8E28BF678DF4240C5AA4198DB554B40F8E28BF678DF42401901158E20574B40300DC347C4E242401901158E20574B40300DC347C4E24240C5AA4198DB554B40F8E28BF678DF4240C5AA4198DB554B40
12453	Спицинский	1	16	1206	38.008446999999997	38.023251999999999	54.590817999999999	54.583993999999997	0103000020E61000000100000005000000E95F92CA14014340B587BD50C04A4B40E95F92CA14014340AEF199EC9F4B4B4086C8E9EBF9024340AEF199EC9F4B4B4086C8E9EBF9024340B587BD50C04A4B40E95F92CA14014340B587BD50C04A4B40
12436	Санталовский	1	16	1206	37.713926000000001	37.739195000000002	54.531205	54.515194000000001	0103000020E61000000100000005000000CEE15AED61DB4240378C82E0F1414B40CEE15AED61DB4240603C8386FE434B40F12E17F19DDE4240603C8386FE434B40F12E17F19DDE4240378C82E0F1414B40CEE15AED61DB4240378C82E0F1414B40
46530	Ревякино	1	16	1206	37.630319	37.682043999999998	54.377490000000002	54.356476999999998	0103000020E610000001000000050000001286014BAED042405A63D009A12D4B401286014BAED042409548A29751304B406D37C1374DD742409548A29751304B406D37C1374DD742405A63D009A12D4B401286014BAED042405A63D009A12D4B40
46368	Мызовка	1	16	1206	37.774894000000003	37.784461	54.455077000000003	54.451129999999999	0103000020E61000000100000005000000EEEE01BA2FE342404B1FBAA0BE394B40EEEE01BA2FE34240B61490F63F3A4B4065FED13769E44240B61490F63F3A4B4065FED13769E442404B1FBAA0BE394B40EEEE01BA2FE342404B1FBAA0BE394B40
46657	Михайловское	1	16	1206	37.972039000000002	37.983204999999998	54.632348	54.625494000000003	0103000020E61000000100000005000000E1B721C66BFC424010ECF82F10504B40E1B721C66BFC424073D87DC7F0504B40C02154A9D9FD424073D87DC7F0504B40C02154A9D9FD424010ECF82F10504B40E1B721C66BFC424010ECF82F10504B40
40440	Каменка	1	16	1206	37.624786	37.631272000000003	54.471671000000001	54.467725999999999	0103000020E61000000100000005000000D47FD6FCF8CF424094BE1072DE3B4B40D47FD6FCF8CF42405EBC1FB75F3C4B40B5705985CDD042405EBC1FB75F3C4B40B5705985CDD0424094BE1072DE3B4B40D47FD6FCF8CF424094BE1072DE3B4B40
33153	Есуковский	1	16	1206	37.805114000000003	37.82723	54.818863999999998	54.801608000000002	0103000020E61000000100000005000000A0C6BDF90DE74240221B48179B664B40A0C6BDF90DE7424095EF1989D0684B40922232ACE2E9424095EF1989D0684B40922232ACE2E94240221B48179B664B40A0C6BDF90DE74240221B48179B664B40
46170	Денисово	1	16	1206	37.837848000000001	37.871751000000003	54.465685000000001	54.453622000000003	0103000020E610000001000000050000006F826F9A3EEB4240815F2349103A4B406F826F9A3EEB42406F9EEA909B3B4B40AEA0698995EF42406F9EEA909B3B4B40AEA0698995EF4240815F2349103A4B406F826F9A3EEB4240815F2349103A4B40
46295	Григорьевское	1	16	1206	37.962004	37.978479999999998	54.829528000000003	54.812477999999999	0103000020E61000000100000005000000834F73F222FB4240185C7347FF674B40834F73F222FB4240E38E37F92D6A4B4021E527D53EFD4240E38E37F92D6A4B4021E527D53EFD4240185C7347FF674B40834F73F222FB4240185C7347FF674B40
12266	Воловниково	1	16	1206	37.755741999999998	37.763117000000001	54.500943999999997	54.487824000000003	0103000020E61000000100000005000000581B6327BCE042401A1A4F04713E4B40581B6327BCE042404F90D8EE1E404B40C5025FD1ADE142404F90D8EE1E404B40C5025FD1ADE142401A1A4F04713E4B40581B6327BCE042401A1A4F04713E4B40
27468	Верхнее Красино	1	16	1206	37.840597000000002	37.862309000000003	54.653036999999998	54.639924999999998	0103000020E61000000100000005000000D00EB8AE98EB42404772F90FE9514B40D00EB8AE98EB4240FA0967B796534B40F3052D2460EE4240FA0967B796534B40F3052D2460EE42404772F90FE9514B40D00EB8AE98EB42404772F90FE9514B40
11863	Бураково	1	16	1206	37.901341000000002	37.917088999999997	54.434238999999998	54.420605999999999	0103000020E61000000100000005000000A0C552245FF342402D40DB6AD6354B40A0C552245FF34240E9D2BF2495374B40BB421F2C63F54240E9D2BF2495374B40BB421F2C63F542402D40DB6AD6354B40A0C552245FF342402D40DB6AD6354B40
11836	Боровковский	1	16	1206	37.724957000000003	37.741306000000002	54.460593000000003	54.447963000000001	0103000020E61000000100000005000000CE001764CBDC4240B66801DA56394B40CE001764CBDC42401EE21FB6F43A4B400F2A711DE3DE42401EE21FB6F43A4B400F2A711DE3DE4240B66801DA56394B40CE001764CBDC4240B66801DA56394B40
12036	Богословское	1	16	1206	37.987426999999997	38.009399999999999	54.781145000000002	54.763883	0103000020E61000000100000005000000FC17080264FE4240357C0BEBC6614B40FC17080264FE42408B37328FFC634B408C4AEA04340143408B37328FFC634B408C4AEA0434014340357C0BEBC6614B40FC17080264FE4240357C0BEBC6614B40
47016	Архангельское	1	16	1206	37.604700000000001	37.627237999999998	54.465214000000003	54.448684999999998	0103000020E6100000010000000500000013F241CF66CD4240569A94826E394B4013F241CF66CD424018D2E1218C3B4B407B67B45549D0424018D2E1218C3B4B407B67B45549D04240569A94826E394B4013F241CF66CD4240569A94826E394B40
49181	Ясная Поляна	1	16	1060	37.517743000000003	37.552480000000003	54.087800999999999	54.057259000000002	0103000020E61000000100000005000000D15D126745C242406A334E4354074B40D15D126745C242402EC72B103D0B4B40D8D825AAB7C642402EC72B103D0B4B40D8D825AAB7C642406A334E4354074B40D15D126745C242406A334E4354074B40
40371	Ясенки	1	16	1060	37.501815000000001	37.520968000000003	54.029237999999999	54.021425999999998	0103000020E6100000010000000500000035D252793BC042405DA45016BE024B4035D252793BC0424075E61E12BE034B409B215514AFC2424075E61E12BE034B409B215514AFC242405DA45016BE024B4035D252793BC042405DA45016BE024B40
49185	Юбилейный	1	16	1060	37.475495000000002	37.490155000000001	54.055647	54.047020000000003	0103000020E61000000100000005000000AD342905DDBC4240042159C004064B40AD342905DDBC42406D8FDE701F074B40467C2766BDBE42406D8FDE701F074B40467C2766BDBE4240042159C004064B40AD342905DDBC4240042159C004064B40
9304	Щекино	1	16	1060	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
60559	Шахтерский	1	16	1060	37.488556000000003	37.505004	53.982025	53.973404000000002	0103000020E61000000100000005000000DE21C50089BE4240D6E5948098FC4A40DE21C50089BE42405D6DC5FEB2FD4A40B22C98F8A3C042405D6DC5FEB2FD4A40B22C98F8A3C04240D6E5948098FC4A40DE21C50089BE4240D6E5948098FC4A40
40974	Центральный	1	16	1060	37.505004	37.519764000000002	53.857173000000003	53.851787000000002	0103000020E61000000100000005000000B22C98F8A3C0424038143E5B07ED4A40B22C98F8A3C04240D20149D8B7ED4A40AFD172A087C24240D20149D8B7ED4A40AFD172A087C2424038143E5B07ED4A40B22C98F8A3C0424038143E5B07ED4A40
45930	Царево	1	16	1060	37.571371999999997	37.585610000000003	53.752059000000003	53.734634999999997	0103000020E61000000100000005000000D0ECBAB722C942409CBF098508DE4A40D0ECBAB722C94240CCD4247843E04A40F41ABB44F5CA4240CCD4247843E04A40F41ABB44F5CA42409CBF098508DE4A40D0ECBAB722C942409CBF098508DE4A40
60587	Стублевка	1	16	1060	37.406190000000002	37.422745999999997	53.760134999999998	53.753304999999997	0103000020E610000001000000050000002BFBAE08FEB34240E674594C6CE04A402BFBAE08FEB34240C1C58A1A4CE14A40E5417A8A1CB64240C1C58A1A4CE14A40E5417A8A1CB64240E674594C6CE04A402BFBAE08FEB34240E674594C6CE04A40
45996	Социалистический	1	16	1060	37.604331000000002	37.619863000000002	53.976253999999997	53.967632000000002	0103000020E61000000100000005000000C07ADCB75ACD42401348895DDBFB4A40C07ADCB75ACD42406A4B1DE4F5FC4A400F80B8AB57CF42406A4B1DE4F5FC4A400F80B8AB57CF42401348895DDBFB4A40C07ADCB75ACD42401348895DDBFB4A40
45596	Советск	1	16	1060	37.617015000000002	37.654510999999999	53.954504999999997	53.927024000000003	0103000020E610000001000000050000001B12F758FACE4240B64DF1B8A8F64A401B12F758FACE42402A6F47382DFA4A40A6EF3504C7D342402A6F47382DFA4A40A6EF3504C7D34240B64DF1B8A8F64A401B12F758FACE4240B64DF1B8A8F64A40
49235	Селиваново	1	16	1060	37.235850999999997	37.274262999999998	53.996917000000003	53.986176	0103000020E610000001000000050000004CDD955D309E4240D00CE2033BFE4A404CDD955D309E4240C9E9EBF99AFF4A405DC0CB0C1BA34240C9E9EBF99AFF4A405DC0CB0C1BA34240D00CE2033BFE4A404CDD955D309E4240D00CE2033BFE4A40
10933	Пришня	1	16	1060	37.302309000000001	37.329393000000003	53.932718000000001	53.920147	0103000020E61000000100000005000000AB24B20FB2A642409A417C60C7F54A40AB24B20FB2A64240FD31AD4D63F74A400344C18C29AA4240FD31AD4D63F74A400344C18C29AA42409A417C60C7F54A40AB24B20FB2A642409A417C60C7F54A40
11276	Пирогово 1-е	1	16	1060	37.379733999999999	37.396397999999998	53.797491000000001	53.785629	0103000020E61000000100000005000000F296AB1F9BB0424004E5B67D8FE44A40F296AB1F9BB042405BED612F14E64A4093196F2BBDB242405BED612F14E64A4093196F2BBDB2424004E5B67D8FE44A40F296AB1F9BB0424004E5B67D8FE44A40
10645	Огаревка	1	16	1060	37.548824000000003	37.582017	53.952903999999997	53.912495	0103000020E6100000010000000500000045A165DD3FC64240BB61DBA2CCF44A4045A165DD3FC64240211D1EC2F8F94A40A75B76887FCA4240211D1EC2F8F94A40A75B76887FCA4240BB61DBA2CCF44A4045A165DD3FC64240BB61DBA2CCF44A40
10766	Никольское	1	16	1060	37.166806999999999	37.18206	54.055926999999997	54.044060000000002	0103000020E6100000010000000500000037DF88EE59954240E88711C2A3054B4037DF88EE5995424050FBAD9D28074B4073F4F8BD4D97424050FBAD9D28074B4073F4F8BD4D974240E88711C2A3054B4037DF88EE59954240E88711C2A3054B40
11580	Мясоедово	1	16	1060	37.573501	37.594549000000001	54.056519000000002	54.035668999999999	0103000020E61000000100000005000000959C137B68C94240923D42CD90044B40959C137B68C94240234DBC033C074B404C6F7F2E1ACC4240234DBC033C074B404C6F7F2E1ACC4240923D42CD90044B40959C137B68C94240923D42CD90044B40
45718	Малынь	1	16	1060	37.136353999999997	37.153340999999998	53.878425999999997	53.858818999999997	0103000020E61000000100000005000000E256410C749142407A17EFC7EDED4A40E256410C7491424061FA5E4370F04A4066118AADA093424061FA5E4370F04A4066118AADA09342407A17EFC7EDED4A40E256410C749142407A17EFC7EDED4A40
29360	Майский	1	16	1060	37.541269	37.555283000000003	53.984895000000002	53.973579000000001	0103000020E6100000010000000500000058AB764D48C542404489963C9EFC4A4058AB764D48C54240397F130A11FE4A402C836A8313C74240397F130A11FE4A402C836A8313C742404489963C9EFC4A4058AB764D48C542404489963C9EFC4A40
46046	Львово	1	16	1060	37.515918999999997	37.526232	53.7819	53.774712000000001	0103000020E61000000100000005000000483140A209C24240CDE847C329E34A40483140A209C24240075F984C15E44A40E90DF7915BC34240075F984C15E44A40E90DF7915BC34240CDE847C329E34A40483140A209C24240CDE847C329E34A40
45839	Лукино	1	16	1060	37.383597000000002	37.405157000000003	53.816536999999997	53.808093999999997	0103000020E61000000100000005000000FFEBDCB419B14240020CCB9F6FE74A40FFEBDCB419B14240AA7CCF4884E84A406C5F402FDCB34240AA7CCF4884E84A406C5F402FDCB34240020CCB9F6FE74A40FFEBDCB419B14240020CCB9F6FE74A40
11488	Ломинцевский	1	16	1060	37.650370000000002	37.674453999999997	53.993465999999998	53.976587000000002	0103000020E610000001000000050000005726FC523FD34240715985CD00FD4A405726FC523FD342400ED8D5E429FF4A400454388254D642400ED8D5E429FF4A400454388254D64240715985CD00FD4A405726FC523FD34240715985CD00FD4A40
60575	Ломинцево	1	16	1060	37.661608000000001	37.690874999999998	54.019955000000003	54.006459	0103000020E61000000100000005000000D0622992AFD44240E7E104A6D3004B40D0622992AFD442402332ACE28D024B40DF4F8D976ED842402332ACE28D024B40DF4F8D976ED84240E7E104A6D3004B40D0622992AFD44240E7E104A6D3004B40
45865	Липово	1	16	1060	37.492581000000001	37.516205999999997	53.730341000000003	53.719206999999997	0103000020E61000000100000005000000C4D0EAE40CBF4240F20698F90EDC4A40C4D0EAE40CBF4240C7F65AD07BDD4A40DEFFC70913C24240C7F65AD07BDD4A40DEFFC70913C24240F20698F90EDC4A40C4D0EAE40CBF4240F20698F90EDC4A40
11086	Лапотково	1	16	1060	37.410268000000002	37.440919000000001	53.855176	53.830919000000002	0103000020E61000000100000005000000344C6DA983B442400150C58D5BEA4A40344C6DA983B442407C293C6876ED4A40AF97A60870B842407C293C6876ED4A40AF97A60870B842400150C58D5BEA4A40344C6DA983B442400150C58D5BEA4A40
45807	Лазарево	1	16	1060	37.476751999999998	37.49559	53.857534000000001	53.845137000000001	0103000020E61000000100000005000000BB26A43506BD4240DDD1FF722DEC4A40BB26A43506BD4240A29A92ACC3ED4A40C11C3D7E6FBF4240A29A92ACC3ED4A40C11C3D7E6FBF4240DDD1FF722DEC4A40BB26A43506BD4240DDD1FF722DEC4A40
10917	Крапивна	1	16	1060	37.142741000000001	37.170661000000003	53.949418000000001	53.930374	0103000020E6100000010000000500000030664B56459242403C86C77E16F74A4030664B5645924240EB1D6E8786F94A40F1D93A38D8954240EB1D6E8786F94A40F1D93A38D89542403C86C77E16F74A4030664B56459242403C86C77E16F74A40
12235	Климовское	1	16	1060	37.156261000000001	37.167867000000001	54.039095000000003	54.030920000000002	0103000020E61000000100000005000000F451465C009442406B65C22FF5034B40F451465C00944240F437A11001054B40F08975AA7C954240F437A11001054B40F08975AA7C9542406B65C22FF5034B40F451465C009442406B65C22FF5034B40
11008	Карамышево	1	16	1060	37.447521000000002	37.468856000000002	53.914112000000003	53.895789999999998	0103000020E61000000100000005000000F9A23D5E48B94240BB0A293FA9F24A40F9A23D5E48B94240CA703C9F01F54A404644317903BC4240CA703C9F01F54A404644317903BC4240BB0A293FA9F24A40F9A23D5E48B94240BB0A293FA9F24A40
48715	Ивановка	1	16	1060	37.658265999999998	37.665551000000001	53.809668000000002	53.805706999999998	0103000020E61000000100000005000000CC086F0F42D4424042942F6821E74A40CC086F0F42D44240124F7633A3E74A40F96871C630D54240124F7633A3E74A40F96871C630D5424042942F6821E74A40CC086F0F42D4424042942F6821E74A40
11175	Грецовка	1	16	1060	37.388322000000002	37.405003999999998	53.756354999999999	53.745398000000002	0103000020E610000001000000050000009E280989B4B142407D40A03369DF4A409E280989B4B1424042959A3DD0E04A40E55FCB2BD7B3424042959A3DD0E04A40E55FCB2BD7B342407D40A03369DF4A409E280989B4B142407D40A03369DF4A40
49282	Горячкино	1	16	1060	37.587488	37.612451999999998	53.933857000000003	53.925592000000002	0103000020E610000001000000050000006F6589CE32CB424039B874CC79F64A406F6589CE32CB424002124DA088F74A40552FBFD364CE424002124DA088F74A40552FBFD364CE424039B874CC79F64A406F6589CE32CB424039B874CC79F64A40
29098	Головеньковский	1	16	1060	37.407744000000001	37.438574000000003	54.045386999999998	54.035319999999999	0103000020E61000000100000005000000F39194F430B442408672A25D85044B40F39194F430B44240EF54C03DCF054B401E705D3123B84240EF54C03DCF054B401E705D3123B842408672A25D85044B40F39194F430B442408672A25D85044B40
29136	Большая Тросна	1	16	1060	37.468505999999998	37.486804999999997	54.015220999999997	54.009469000000003	0103000020E6100000010000000500000069FD2D01F8BB4240B5A9BA4736014B4069FD2D01F8BB4240309B00C3F2014B40BF4351A04FBE4240309B00C3F2014B40BF4351A04FBE4240B5A9BA4736014B4069FD2D01F8BB4240B5A9BA4736014B40
46072	Архангельское	1	16	1060	37.071190000000001	37.096674999999998	53.860778000000003	53.846204999999998	0103000020E61000000100000005000000B0E600C11C894240185B087250EC4A40B0E600C11C894240E38E37F92DEE4A409FABADD85F8C4240E38E37F92DEE4A409FABADD85F8C4240185B087250EC4A40B0E600C11C894240185B087250EC4A40
10810	Алимкина	1	16	1060	37.109737000000003	37.121738000000001	53.946736999999999	53.931525000000001	0103000020E61000000100000005000000A114ADDC0B8E4240053411363CF74A40A114ADDC0B8E4240E27492AD2EF94A4019575C1C958F4240E27492AD2EF94A4019575C1C958F4240053411363CF74A40A114ADDC0B8E4240053411363CF74A40
7658	Чернь	1	16	943	36.859807000000004	36.933819999999997	53.465927999999998	53.442355999999997	0103000020E610000001000000050000009AEFE0270E6E42403D98141F9FB84A409AEFE0270E6E424035255987A3BB4A40E42CEC698777424035255987A3BB4A40E42CEC69877742403D98141F9FB84A409AEFE0270E6E42403D98141F9FB84A40
9046	Тургенево	1	16	943	37.281719000000002	37.307842000000001	53.383558999999998	53.374358000000001	0103000020E61000000100000005000000B7D4415E0FA442407C7F83F6EAAF4A40B7D4415E0FA44240118B187618B14A40E92ADD5D67A74240118B187618B14A40E92ADD5D67A742407C7F83F6EAAF4A40B7D4415E0FA442407C7F83F6EAAF4A40
51217	Троицкое-Бочурино	1	16	943	36.459150000000001	36.485776000000001	53.441277999999997	53.429155000000002	0103000020E61000000100000005000000ADFA5C6DC53A42401BF5108DEEB64A40ADFA5C6DC53A4240DE3829CC7BB84A40429770E82D3E4240DE3829CC7BB84A40429770E82D3E42401BF5108DEEB64A40ADFA5C6DC53A42401BF5108DEEB64A40
8322	Степной	1	16	943	37.019429000000002	37.034215000000003	53.597129000000002	53.590801999999996	0103000020E6100000010000000500000008CC43A67C824240A83462669FCB4A4008CC43A67C824240213F1BB96ECC4A402E04392861844240213F1BB96ECC4A402E04392861844240A83462669FCB4A4008CC43A67C824240A83462669FCB4A40
51263	Станция Скуратово	1	16	943	36.380502	37.504600000000003	53.650495999999997	53.256169	0103000020E6100000010000000500000003081F4AB4304240E09F5225CAA04A4003081F4AB4304240E316F37343D34A40E3C798BB96C04240E316F37343D34A40E3C798BB96C04240E09F5225CAA04A4003081F4AB4304240E09F5225CAA04A40
9137	Спартак	1	16	943	37.131898	37.151130999999999	53.448604000000003	53.434209000000003	0103000020E6100000010000000500000033349E08E29042407F50172994B74A4033349E08E29042406A6D1ADB6BB94A40B534B742589342406A6D1ADB6BB94A40B534B742589342407F50172994B74A4033349E08E29042407F50172994B74A40
7806	Скуратовский	1	16	943	36.833891000000001	37.045399000000003	53.567583999999997	53.433205000000001	0103000020E61000000100000005000000E1B6B6F0BC6A42405ABBED4273B74A40E1B6B6F0BC6A4240CEDDAE97A6C84A40B4226AA2CF854240CEDDAE97A6C84A40B4226AA2CF8542405ABBED4273B74A40E1B6B6F0BC6A42405ABBED4273B74A40
8496	Синегубово 1-е	1	16	943	36.760328000000001	36.774360000000001	53.555304	53.545338000000001	0103000020E61000000100000005000000D61D8B6D526142400EA2B5A2CDC54A40D61D8B6D5261424043AB933314C74A4050AA7D3A1E63424043AB933314C74A4050AA7D3A1E6342400EA2B5A2CDC54A40D61D8B6D526142400EA2B5A2CDC54A40
48579	Сальница-Слободка	1	16	943	36.575023999999999	36.585875000000001	53.527779000000002	53.521917999999999	0103000020E610000001000000050000002235ED629A494240CC988235CEC24A402235ED629A494240FF4124438EC34A40A245B6F3FD4A4240FF4124438EC34A40A245B6F3FD4A4240CC988235CEC24A402235ED629A494240CC988235CEC24A40
9073	Поповка 1-я	1	16	943	37.079256999999998	37.093693000000002	53.535037000000003	53.525863000000001	0103000020E61000000100000005000000527DE717258A42409696917A4FC34A40527DE717258A42403293A8177CC44A409C6ED921FE8B42403293A8177CC44A409C6ED921FE8B42409696917A4FC34A40527DE717258A42409696917A4FC34A40
8981	Полтево	1	16	943	36.601452000000002	36.624754000000003	53.484889000000003	53.468077000000001	0103000020E61000000100000005000000910E0F61FC4C4240418177F2E9BB4A40910E0F61FC4C42405798BED710BE4A40C90567F0F74F42405798BED710BE4A40C90567F0F74F4240418177F2E9BB4A40910E0F61FC4C4240418177F2E9BB4A40
9238	Подгорный	1	16	943	37.036749	37.050628000000003	53.506321	53.497140999999999	0103000020E610000001000000050000009294F430B48442401840F850A2BF4A409294F430B484424096236420CFC04A40862172FA7A86424096236420CFC04A40862172FA7A8642401840F850A2BF4A409294F430B48442401840F850A2BF4A40
46463	Петровское	1	16	943	37.049810000000001	37.060042000000003	53.348978000000002	53.340538000000002	0103000020E61000000100000005000000C381902C60864240CB85CABF96AB4A40C381902C608642400283A44FABAC4A407731CD74AF8742400283A44FABAC4A407731CD74AF874240CB85CABF96AB4A40C381902C60864240CB85CABF96AB4A40
7981	Николо-Вяземское	1	16	943	36.8127	36.822330000000001	53.313932999999999	53.307271999999998	0103000020E61000000100000005000000C7BAB88D06684240FE7C5BB054A74A40C7BAB88D066842404D11E0F42EA84A408542041C426942404D11E0F42EA84A408542041C42694240FE7C5BB054A74A40C7BAB88D06684240FE7C5BB054A74A40
8309	Малое Скуратово	1	16	943	36.982984000000002	37.016528000000001	53.565862000000003	53.548985999999999	0103000020E61000000100000005000000E23E726BD27D42401EFB592C45C64A40E23E726BD27D42404B06802A6EC84A40F1BBE9961D8242404B06802A6EC84A40F1BBE9961D8242401EFB592C45C64A40E23E726BD27D42401EFB592C45C64A40
46802	Лобаново	1	16	943	36.641122000000003	36.656627	53.444496000000001	53.437572000000003	0103000020E61000000100000005000000815F2349105242409AD2FA5B02B84A40815F234910524240F699B33EE5B84A40D655815A0C544240F699B33EE5B84A40D655815A0C5442409AD2FA5B02B84A40815F2349105242409AD2FA5B02B84A40
8593	Липицы	1	16	943	37.235787999999999	37.285384000000001	53.376629999999999	53.359597999999998	0103000020E6100000010000000500000006651A4D2E9E42407FDAA84E07AE4A4006651A4D2E9E4240A3586E6935B04A409D66817687A44240A3586E6935B04A409D66817687A442407FDAA84E07AE4A4006651A4D2E9E42407FDAA84E07AE4A40
25819	Ленинский	1	16	943	37.028745000000001	37.041446999999998	53.405487999999998	53.397236999999997	0103000020E61000000100000005000000367689EAAD8342406DE179A9D8B24A40367689EAAD834240D175E107E7B34A4037C2A2224E854240D175E107E7B34A4037C2A2224E8542406DE179A9D8B24A40367689EAAD8342406DE179A9D8B24A40
8689	Левое Молчаново	1	16	943	37.415784000000002	37.421487999999997	53.332537000000002	53.328223999999999	0103000020E610000001000000050000009C19FD6838B5424093E1783E03AA4A409C19FD6838B54240E0DA899290AA4A4006D49B51F3B54240E0DA899290AA4A4006D49B51F3B5424093E1783E03AA4A409C19FD6838B5424093E1783E03AA4A40
8429	Кресты	1	16	943	36.866644000000001	36.884053000000002	53.512591	53.492378000000002	0103000020E6100000010000000500000027A3CA30EE6E42408CA2073E06BF4A4027A3CA30EE6E4240AA9CF6949CC14A40217711A628714240AA9CF6949CC14A40217711A6287142408CA2073E06BF4A4027A3CA30EE6E42408CA2073E06BF4A40
8763	Красный Путь	1	16	943	37.324533000000002	37.339264999999997	53.337784999999997	53.328826999999997	0103000020E6100000010000000500000084BC1E4C8AA942405985CD0017AA4A4084BC1E4C8AA94240280AF4893CAB4A40B6D617096DAB4240280AF4893CAB4A40B6D617096DAB42405985CD0017AA4A4084BC1E4C8AA942405985CD0017AA4A40
45968	Краснополье	1	16	943	37.185733999999997	37.192948000000001	53.443333000000003	53.431296000000003	0103000020E61000000100000005000000ACE0B721C6974240A47213B534B74A40ACE0B721C6974240691EC022BFB84A4010EA2285B2984240691EC022BFB84A4010EA2285B2984240A47213B534B74A40ACE0B721C6974240A47213B534B74A40
60564	Коженка	1	16	943	36.986811000000003	37.005721000000001	53.398632999999997	53.390175999999997	0103000020E61000000100000005000000A22AA6D24F7E424090D78349F1B14A40A22AA6D24F7E42409D0DF96706B34A4041F33977BB8042409D0DF96706B34A4041F33977BB80424090D78349F1B14A40A22AA6D24F7E424090D78349F1B14A40
8874	Жизнь	1	16	943	36.583863000000001	36.599943000000003	53.440592000000002	53.427095000000001	0103000020E61000000100000005000000172CD505BC4A42407FA4880CABB64A40172CD505BC4A42408B70935165B84A40693BA6EECA4C42408B70935165B84A40693BA6EECA4C42407FA4880CABB64A40172CD505BC4A42407FA4880CABB64A40
8123	Ержино	1	16	943	36.884466000000003	36.919986000000002	53.333365000000001	53.323614999999997	0103000020E610000001000000050000004436902E367142405DBF60376CA94A404436902E36714240C6504EB4ABAA4A409163EB19C2754240C6504EB4ABAA4A409163EB19C27542405DBF60376CA94A404436902E367142405DBF60376CA94A40
8954	Дьяково	1	16	943	36.628123000000002	36.652216000000003	53.519396	53.50609	0103000020E61000000100000005000000C66E9F5566504240946A9F8EC7C04A40C66E9F55665042402CD670917BC24A40C7F65AD07B5342402CD670917BC24A40C7F65AD07B534240946A9F8EC7C04A40C66E9F5566504240946A9F8EC7C04A40
7935	Долматово	1	16	943	36.752315000000003	36.768386	53.402518999999998	53.387608999999998	0103000020E6100000010000000500000027A5A0DB4B6042405051F52B9DB14A4027A5A0DB4B60424062821ABE85B34A40255AF2785A62424062821ABE85B34A40255AF2785A6242405051F52B9DB14A4027A5A0DB4B6042405051F52B9DB14A40
7896	Воропаевский	1	16	943	36.783163000000002	36.802126999999999	53.435389000000001	53.426321999999999	0103000020E61000000100000005000000F83768AF3E6442405CC823B891B64A40F83768AF3E644240E204A6D3BAB74A408A1EF818AC664240E204A6D3BAB74A408A1EF818AC6642405CC823B891B64A40F83768AF3E6442405CC823B891B64A40
9153	Велье-Никольское	1	16	943	36.937691000000001	36.958010999999999	53.477912000000003	53.462179999999996	0103000020E610000001000000050000007460394206784240C16ED8B628BB4A407460394206784240D82E6D382CBD4A40A81ABD1AA07A4240D82E6D382CBD4A40A81ABD1AA07A4240C16ED8B628BB4A407460394206784240C16ED8B628BB4A40
7808	Бредихино 1-е	1	16	943	36.866050999999999	36.884070999999999	53.386218	53.376952000000003	0103000020E6100000010000000500000084D558C2DA6E4240B61490F63FB04A4084D558C2DA6E4240329067976FB14A40C72B103D29714240329067976FB14A40C72B103D29714240B61490F63FB04A4084D558C2DA6E4240B61490F63FB04A40
8000	Архангельское	1	16	943	37.113168000000002	37.124890999999998	53.333188	53.323179000000003	0103000020E61000000100000005000000147AFD497C8E424083E0F1ED5DA94A40147AFD497C8E4240B7B585E7A5AA4A404948A46DFC8F4240B7B585E7A5AA4A404948A46DFC8F424083E0F1ED5DA94A40147AFD497C8E424083E0F1ED5DA94A40
28594	Шаховское	1	16	606	38.069074999999998	38.093446	54.038260000000001	54.030042000000002	0103000020E6100000010000000500000050FC1873D7084340D3C08F6AD8034B4050FC1873D70843405B5F24B4E5044B4094F8DC09F60B43405B5F24B4E5044B4094F8DC09F60B4340D3C08F6AD8034B4050FC1873D7084340D3C08F6AD8034B40
60585	Хитрово	1	16	606	38.109822000000001	38.142187999999997	53.983581999999998	53.976688000000003	0103000020E61000000100000005000000CF30B5A50E0E4340A532C51C04FD4A40CF30B5A50E0E43409677D503E6FD4A401BF16437331243409677D503E6FD4A401BF1643733124340A532C51C04FD4A40CF30B5A50E0E4340A532C51C04FD4A40
5644	Узловая	1	16	606	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
48642	Торбеевка	1	16	606	38.114952000000002	38.127160000000003	53.956422000000003	53.947795999999997	0103000020E610000001000000050000000E4E44BFB60E4340CAA31B6151F94A400E4E44BFB60E434064963D096CFA4A4000AE64C74610434064963D096CFA4A4000AE64C746104340CAA31B6151F94A400E4E44BFB60E4340CAA31B6151F94A40
47922	Смородино	1	16	606	38.301774000000002	38.339844999999997	53.941431999999999	53.926430000000003	0103000020E610000001000000050000003D64CA87A026434043041C4295F64A403D64CA87A026434035B401D880F84A40C45A7C0A802B434035B401D880F84A40C45A7C0A802B434043041C4295F64A403D64CA87A026434043041C4295F64A40
7154	Прилесье	1	16	606	38.128686999999999	38.153039999999997	53.852435	53.839706999999997	0103000020E61000000100000005000000CE35CCD078104340739CDB847BEB4A40CE35CCD0781043409E7B0F971CED4A406B7D91D0961343409E7B0F971CED4A406B7D91D096134340739CDB847BEB4A40CE35CCD078104340739CDB847BEB4A40
48606	Партизан	1	16	606	38.089421000000002	38.109256000000002	53.955209000000004	53.939306000000002	0103000020E61000000100000005000000AE49B725720B4340E277D32D3BF84A40AE49B725720B434025ECDB4944FA4A402672C119FC0D434025ECDB4944FA4A402672C119FC0D4340E277D32D3BF84A40AE49B725720B4340E277D32D3BF84A40
48680	Майский	1	16	606	38.199223000000003	38.222012999999997	53.966884999999998	53.957555999999997	0103000020E6100000010000000500000036CEA62380194340560BEC3191FA4A4036CEA6238019434019FF3EE3C2FB4A40B72407EC6A1C434019FF3EE3C2FB4A40B72407EC6A1C4340560BEC3191FA4A4036CEA62380194340560BEC3191FA4A40
28908	Люторичи	1	16	606	38.432749000000001	38.456814000000001	53.911544999999997	53.886451000000001	0103000020E610000001000000050000003830B95164374340D540F33977F14A403830B9516437434089EAAD81ADF44A406F2D93E1783A434089EAAD81ADF44A406F2D93E1783A4340D540F33977F14A403830B95164374340D540F33977F14A40
6066	Каменецкий	1	16	606	38.204487	38.237068999999998	54.018506000000002	53.993147999999998	0103000020E6100000010000000500000084BA48A12C1A43403D0B42791FFF4A4084BA48A12C1A4340D06394675E024B409DF2E846581E4340D06394675E024B409DF2E846581E43403D0B42791FFF4A4084BA48A12C1A43403D0B42791FFF4A40
45578	Ильинка	1	16	606	38.019074000000003	38.043733000000003	53.953026000000001	53.935267000000003	0103000020E610000001000000050000001A1A4F047102434097033DD4B6F74A401A1A4F04710243406D1E87C1FCF94A40C460FE0A990543406D1E87C1FCF94A40C460FE0A9905434097033DD4B6F74A401A1A4F047102434097033DD4B6F74A40
47756	Ивановка	1	16	606	38.228929999999998	38.248297000000001	53.874077999999997	53.858628000000003	0103000020E61000000100000005000000618907944D1D434007B7B585E7ED4A40618907944D1D43409813B4C9E1EF4A40F3583332C81F43409813B4C9E1EF4A40F3583332C81F434007B7B585E7ED4A40618907944D1D434007B7B585E7ED4A40
48802	Дубовое	1	16	606	38.395504000000003	38.432937000000003	53.982989000000003	53.969712999999999	0103000020E61000000100000005000000F6B704E09F324340C6C03A8E1FFC4A40F6B704E09F324340F4A96395D2FD4A403B1DC87A6A374340F4A96395D2FD4A403B1DC87A6A374340C6C03A8E1FFC4A40F6B704E09F324340C6C03A8E1FFC4A40
48549	Дубовка	1	16	606	38.083599999999997	38.139834999999998	53.934313000000003	53.913401	0103000020E6100000010000000500000009F9A067B30A43401D91EF52EAF44A4009F9A067B30A4340249D819197F74A4007EBFF1CE6114340249D819197F74A4007EBFF1CE61143401D91EF52EAF44A4009F9A067B30A43401D91EF52EAF44A40
46782	Волково	1	16	606	38.418545999999999	38.445900000000002	53.863746999999996	53.852775000000001	0103000020E6100000010000000500000091EF52EA9235434057EC2FBB27ED4A4091EF52EA923543405182FE428FEE4A40A9A44E40133943405182FE428FEE4A40A9A44E401339434057EC2FBB27ED4A4091EF52EA9235434057EC2FBB27ED4A40
60598	Бутырки	1	16	606	38.446646000000001	38.469614999999997	53.763137	53.752713999999997	0103000020E61000000100000005000000D27135B22B394340E49EAEEE58E04A40D27135B22B3943400CAF2479AEE14A40035B25581C3C43400CAF2479AEE14A40035B25581C3C4340E49EAEEE58E04A40D27135B22B394340E49EAEEE58E04A40
28780	Брусянский	1	16	606	38.077905000000001	38.103768000000002	54.009050999999999	53.988325000000003	0103000020E61000000100000005000000F29881CAF8094340DC68006F81FE4A40F29881CAF8094340807F4A9528014B40882F1345480D4340807F4A9528014B40882F1345480D4340DC68006F81FE4A40F29881CAF8094340DC68006F81FE4A40
3841	Бестужевский	1	16	606	38.357982	38.385002999999998	53.798096999999999	53.785252	0103000020E610000001000000050000004147AB5AD22D43402E8F352383E44A404147AB5AD22D43409204E10A28E64A4052EE3EC7473143409204E10A28E64A4052EE3EC7473143402E8F352383E44A404147AB5AD22D43402E8F352383E44A40
60510	Первомайский	1	16	7509	37.483750000000001	37.532601	54.058157000000001	54.029412999999998	0103000020E6100000010000000500000052B81E85EBBD4240E38920CEC3034B4052B81E85EBBD4240498446B071074B40906802452CC44240498446B071074B40906802452CC44240E38920CEC3034B4052B81E85EBBD4240E38920CEC3034B40
60545	Центральный	1	16	695	37.604833999999997	37.620778999999999	53.442473999999997	53.430244000000002	0103000020E6100000010000000500000022C154336BCD42406EA6423C12B74A4022C154336BCD424047AAEFFCA2B84A409485AFAF75CF424047AAEFFCA2B84A409485AFAF75CF42406EA6423C12B74A4022C154336BCD42406EA6423C12B74A40
60561	Федоровка	1	16	695	37.485070999999998	37.497737000000001	53.562733000000001	53.549793999999999	0103000020E61000000100000005000000779E78CE16BE4240BDC458A65FC64A40779E78CE16BE4240A3B08BA207C84A402C8194D8B5BF4240A3B08BA207C84A402C8194D8B5BF4240BDC458A65FC64A40779E78CE16BE4240BDC458A65FC64A40
48221	Успенское	1	16	695	37.759990999999999	37.774535	53.671492000000001	53.662860000000002	0103000020E610000001000000050000008E20956247E14240CDE9B298D8D44A408E20956247E1424048C32973F3D54A40BE4D7FF623E3424048C32973F3D54A40BE4D7FF623E34240CDE9B298D8D44A408E20956247E14240CDE9B298D8D44A40
46974	Троекурово	1	16	695	37.408903000000002	37.429977000000001	53.486168999999997	53.475746999999998	0103000020E610000001000000050000003F1EFAEE56B44240C6151747E5BC4A403F1EFAEE56B442401DAA29C93ABE4A401F84807C09B742401DAA29C93ABE4A401F84807C09B74240C6151747E5BC4A403F1EFAEE56B44240C6151747E5BC4A40
5384	Теплое	1	16	695	37.553936	37.610700000000001	53.635998000000001	53.599518000000003	0103000020E61000000100000005000000DD09F65FE7C6424082AE7D01BDCC4A40DD09F65FE7C642402429E96168D14A4067D5E76A2BCE42402429E96168D14A4067D5E76A2BCE424082AE7D01BDCC4A40DD09F65FE7C6424082AE7D01BDCC4A40
4957	Стрешнево	1	16	695	37.502856999999999	37.525154000000001	53.511707999999999	53.488531999999999	0103000020E6100000010000000500000047C8409E5DC042405586713788BE4A4047C8409E5DC04240008DD2A57FC14A408AAE0B3F38C34240008DD2A57FC14A408AAE0B3F38C342405586713788BE4A4047C8409E5DC042405586713788BE4A40
48929	Северный	1	16	695	37.735143999999998	37.754556000000001	53.722909999999999	53.713377000000001	0103000020E61000000100000005000000E1ECD63219DE4240FB5B02F04FDB4A40E1ECD63219DE4240C6F99B5088DC4A4013807F4A95E04240C6F99B5088DC4A4013807F4A95E04240FB5B02F04FDB4A40E1ECD63219DE4240FB5B02F04FDB4A40
5204	Мосюковка	1	16	695	37.672243999999999	37.681119000000002	53.616661999999998	53.609926000000002	0103000020E61000000100000005000000537765170CD64240747D1F0E12CE4A40537765170CD64240CD57C9C7EECE4A4095D74AE82ED74240CD57C9C7EECE4A4095D74AE82ED74240747D1F0E12CE4A40537765170CD64240747D1F0E12CE4A40
48877	Мичуринский	1	16	695	37.586804999999998	37.598590999999999	53.599518000000003	53.586402999999997	0103000020E610000001000000050000008C101E6D1CCB42405DA3E5400FCB4A408C101E6D1CCB424082AE7D01BDCC4A40085740A19ECC424082AE7D01BDCC4A40085740A19ECC42405DA3E5400FCB4A408C101E6D1CCB42405DA3E5400FCB4A40
48914	Механизаторов	1	16	695	37.632717999999997	37.653325000000002	53.701332000000001	53.692722000000003	0103000020E6100000010000000500000096CB46E7FCD04240209C4F1DABD84A4096CB46E7FCD04240B3D1393FC5D94A4061545227A0D34240B3D1393FC5D94A4061545227A0D34240209C4F1DABD84A4096CB46E7FCD04240209C4F1DABD84A40
5145	Малая Огаревка	1	16	695	37.828119000000001	37.845348999999999	53.638838	53.626798000000001	0103000020E610000001000000050000001E19ABCDFFE942405F99B7EA3AD04A401E19ABCDFFE9424095B88E71C5D14A40685A626534EC424095B88E71C5D14A40685A626534EC42405F99B7EA3AD04A401E19ABCDFFE942405F99B7EA3AD04A40
4869	Крюковка 1-я	1	16	695	37.508561999999998	37.530228999999999	53.450443999999997	53.442179000000003	0103000020E6100000010000000500000082FE428F18C142402FFD4B5299B84A4082FE428F18C14240F7562426A8B94A4005323B8BDEC34240F7562426A8B94A4005323B8BDEC342402FFD4B5299B84A4082FE428F18C142402FFD4B5299B84A40
28324	Красногвардеец	1	16	695	37.725836999999999	37.740031000000002	53.620148999999998	53.608103999999997	0103000020E61000000100000005000000069D103AE8DC42408C48145AD6CD4A40069D103AE8DC4240D4D2DC0A61CF4A405A83F755B9DE4240D4D2DC0A61CF4A405A83F755B9DE42408C48145AD6CD4A40069D103AE8DC42408C48145AD6CD4A40
48854	Кировский	1	16	695	37.491709	37.508893999999998	53.542431999999998	53.535246000000001	0103000020E610000001000000050000000E130D52F0BE42404CA8E0F082C44A400E130D52F0BE4240E5266A696EC54A40B890477023C14240E5266A696EC54A40B890477023C142404CA8E0F082C44A400E130D52F0BE42404CA8E0F082C44A40
48993	Доробино	1	16	695	37.695886999999999	37.712408000000003	53.486677999999998	53.469073999999999	0103000020E61000000100000005000000145B41D312D94240B3B3E89D0ABC4A40145B41D312D9424062D7F6764BBE4A4053B4722F30DB424062D7F6764BBE4A4053B4722F30DB4240B3B3E89D0ABC4A40145B41D312D94240B3B3E89D0ABC4A40
60540	Горьковский	1	16	695	37.606890999999997	37.624147999999998	53.661482999999997	53.651777000000003	0103000020E610000001000000050000004D9EB29AAECD42407BA4C16D6DD34A404D9EB29AAECD424013EE9579ABD44A4091EEE714E4CF424013EE9579ABD44A4091EEE714E4CF42407BA4C16D6DD34A404D9EB29AAECD42407BA4C16D6DD34A40
28417	Волчья Дубрава	1	16	695	37.622898999999997	37.660943000000003	53.556133000000003	53.534041000000002	0103000020E6100000010000000500000005DB8827BBCF424090DC9A745BC44A4005DB8827BBCF4240FA9CBB5D2FC74A4094C2BCC799D44240FA9CBB5D2FC74A4094C2BCC799D4424090DC9A745BC44A4005DB8827BBCF424090DC9A745BC44A40
5223	Бродиловка	1	16	695	37.753514000000003	37.774822	53.398524999999999	53.388629000000002	0103000020E61000000100000005000000018A912573E042407BA35698BEB14A40018A912573E04240B7D100DE02B34A40541C075E2DE34240B7D100DE02B34A40541C075E2DE342407BA35698BEB14A40018A912573E042407BA35698BEB14A40
28337	Большое Огарево	1	16	695	37.704664000000001	37.746327999999998	53.561241000000003	53.544331999999997	0103000020E610000001000000050000009355116E32DA42404815C5ABACC54A409355116E32DA42405116BEBED6C74A40670B08AD87DF42405116BEBED6C74A40670B08AD87DF42404815C5ABACC54A409355116E32DA42404815C5ABACC54A40
4853	Большое Минино	1	16	695	37.481800999999997	37.501339000000002	53.405531000000003	53.392597000000002	0103000020E610000001000000050000000D17B9A7ABBD4240FDC0559E40B24A400D17B9A7ABBD4240D1419770E8B34A40CC9A58E02BC04240D1419770E8B34A40CC9A58E02BC04240FDC0559E40B24A400D17B9A7ABBD4240FDC0559E40B24A40
47605	Богданово	1	16	695	37.700738000000001	37.714348000000001	53.677171999999999	53.672120999999997	0103000020E61000000100000005000000408864C8B1D9424037FA980F08D64A40408864C8B1D942402AE27492ADD64A4044FB58C16FDB42402AE27492ADD64A4044FB58C16FDB424037FA980F08D64A40408864C8B1D9424037FA980F08D64A40
4355	Черепеть	1	16	442	36.363407000000002	36.398890999999999	54.126668000000002	54.111533000000001	0103000020E610000001000000050000009911DE1E842E42405FB69DB6460E4B409911DE1E842E424091B932A836104B4099D53BDC0E33424091B932A836104B4099D53BDC0E3342405FB69DB6460E4B409911DE1E842E42405FB69DB6460E4B40
3110	Чекалин	1	16	442	36.227789000000001	36.256894000000003	54.103937000000002	54.086528000000001	0103000020E61000000100000005000000BCB1A030281D42401A187959130B4B40BCB1A030281D424014ECBFCE4D0D4B40F24410E7E120424014ECBFCE4D0D4B40F24410E7E12042401A187959130B4B40BCB1A030281D42401A187959130B4B40
60503	Центральный	1	16	442	35.968525999999997	36.856996000000002	54.310682999999997	53.933799	0103000020E61000000100000005000000B0A9F3A8F8FB4140CD04C3B986F74A40B0A9F3A8F8FB41402A36E675C4274B40C366800BB26D42402A36E675C4274B40C366800BB26D4240CD04C3B986F74A40B0A9F3A8F8FB4140CD04C3B986F74A40
3860	Ханино	1	16	442	36.591732	36.636755999999998	54.230826999999998	54.197758	0103000020E6100000010000000500000093FFC9DFBD4B4240DD42572250194B4093FFC9DFBD4B4240530438BD8B1D4B4011C4793881514240530438BD8B1D4B4011C4793881514240DD42572250194B4093FFC9DFBD4B4240DD42572250194B40
2477	Суворов	1	16	442	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
7086	Селюково	1	16	442	36.129019	36.145502999999998	54.110916000000003	54.099587	0103000020E6100000010000000500000004C8D0B183104240AA0D4E44BF0C4B4004C8D0B183104240344DD87E320E4B40253CA1D79F124240344DD87E320E4B40253CA1D79F124240AA0D4E44BF0C4B4004C8D0B183104240AA0D4E44BF0C4B40
4625	Северо-Агеевский	1	16	442	36.288927999999999	36.295997999999997	54.210923000000001	54.206795	0103000020E610000001000000050000000873BB97FB244240F8FC3042781A4B400873BB97FB244240B37C5D86FF1A4B4038D73043E3254240B37C5D86FF1A4B4038D73043E3254240F8FC3042781A4B400873BB97FB244240F8FC3042781A4B40
4049	Своино	1	16	442	36.632606000000003	36.651569000000002	54.160559999999997	54.148712000000003	0103000020E610000001000000050000006FA0C03BF9504240EA42ACFE08134B406FA0C03BF9504240DB85E63A8D144B40310BED9C66534240DB85E63A8D144B40310BED9C66534240EA42ACFE08134B406FA0C03BF9504240EA42ACFE08134B40
3677	Песоченский	1	16	442	36.094496999999997	36.123215999999999	54.180830999999998	54.159463000000002	0103000020E61000000100000005000000F9484A7A180C424006F6984869144B40F9484A7A180C42402E8D5F7825174B40062CB98AC50F42402E8D5F7825174B40062CB98AC50F424006F6984869144B40F9484A7A180C424006F6984869144B40
4296	Песковатское	1	16	442	36.252581999999997	36.276063999999998	54.053373999999998	54.039707999999997	0103000020E6100000010000000500000075C7629B54204240DDB1D82615054B4075C7629B54204240753A90F5D4064B402DCDAD1056234240753A90F5D4064B402DCDAD1056234240DDB1D82615054B4075C7629B54204240DDB1D82615054B40
4378	Новая Черепеть	1	16	442	36.337186000000003	36.356428000000001	54.109206	54.093561999999999	0103000020E61000000100000005000000A4552DE9282B4240FD12F1D6F90B4B40A4552DE9282B424074435376FA0D4B4079B0C56E9F2D424074435376FA0D4B4079B0C56E9F2D4240FD12F1D6F90B4B40A4552DE9282B4240FD12F1D6F90B4B40
3716	Машковичи	1	16	442	36.258699999999997	36.291505999999998	54.194155000000002	54.181279000000004	0103000020E61000000100000005000000D3BCE3141D214240CE39782634174B40D3BCE3141D2142406DAD2F12DA184B403C4B9011502542406DAD2F12DA184B403C4B901150254240CE39782634174B40D3BCE3141D214240CE39782634174B40
4144	Марково	1	16	442	36.570182000000003	36.587626999999998	54.154207	54.144319000000003	0103000020E610000001000000050000004A6249B9FB4842408198840B79124B404A6249B9FB4842403AE8120EBD134B40909F8D5C374B42403AE8120EBD134B40909F8D5C374B42408198840B79124B404A6249B9FB4842408198840B79124B40
47629	Малиновка	1	16	442	36.603805999999999	36.625284000000001	54.276257999999999	54.267834999999998	0103000020E610000001000000050000007590D783494D4240B1DCD26A48224B407590D783494D424012A1116C5C234B40255B5D4E0950424012A1116C5C234B40255B5D4E09504240B1DCD26A48224B407590D783494D4240B1DCD26A48224B40
4674	Лужковский	1	16	442	36.427619	36.436484999999998	54.124943000000002	54.120446999999999	0103000020E61000000100000005000000F9122A38BC3642405EF3AACE6A0F4B40F9122A38BC3642409C6ED921FE0F4B40E71890BDDE3742409C6ED921FE0F4B40E71890BDDE3742405EF3AACE6A0F4B40F9122A38BC3642405EF3AACE6A0F4B40
4495	Курорт Краинка	1	16	442	36.331553	36.338586999999997	54.112060999999997	54.108266	0103000020E6100000010000000500000002F22554702A424066A208A9DB0D4B4002F22554702A42401A14CD03580E4B40E5EC9DD1562B42401A14CD03580E4B40E5EC9DD1562B424066A208A9DB0D4B4002F22554702A424066A208A9DB0D4B40
47479	Кулешово	1	16	442	36.336610999999998	36.381805	54.030707999999997	54.002585000000003	0103000020E61000000100000005000000A73CBA11162B4240E73A8DB454004B40A73CBA11162B4240DFDC5F3DEE034B4082397AFCDE304240DFDC5F3DEE034B4082397AFCDE304240E73A8DB454004B40A73CBA11162B4240E73A8DB454004B40
46171	Зеленино	1	16	442	36.227249999999998	36.248989000000002	54.138776	54.129275	0103000020E610000001000000050000000C022B87161D42405F984C158C104B400C022B87161D42401FBC7669C3114B4029081EDFDE1F42401FBC7669C3114B4029081EDFDE1F42405F984C158C104B400C022B87161D42405F984C158C104B40
4748	Збродовский	1	16	442	36.418312	36.436072000000003	54.185651999999997	54.178643999999998	0103000020E610000001000000050000001EC3633F8B35424035D07CCEDD164B401EC3633F8B354240EF37DA71C3174B40C5591135D1374240EF37DA71C3174B40C5591135D137424035D07CCEDD164B401EC3633F8B35424035D07CCEDD164B40
51177	Желоба-1	1	16	442	36.157729000000003	36.173926000000002	54.040559999999999	54.030099999999997	0103000020E61000000100000005000000BE50C0763014424007CE1951DA034B40BE50C076301442404CC3F01131054B4049F60835431642404CC3F01131054B4049F608354316424007CE1951DA034B40BE50C0763014424007CE1951DA034B40
3508	Глубоковский	1	16	442	36.521510999999997	36.546322000000004	54.178665000000002	54.169342	0103000020E610000001000000050000008BC058DFC04242406CEBA7FFAC154B408BC058DFC04242404DF8A57EDE164B40EC8A19E1ED4542404DF8A57EDE164B40EC8A19E1ED4542406CEBA7FFAC154B408BC058DFC04242406CEBA7FFAC154B40
3773	Бряньково	1	16	442	36.227060999999999	36.258600999999999	54.165025	54.156759000000001	0103000020E610000001000000050000003999B855101D4240452DCDAD10144B403999B855101D4240DE02098A1F154B4040DB6AD619214240DE02098A1F154B4040DB6AD619214240452DCDAD10144B403999B855101D4240452DCDAD10144B40
49469	Борисово	1	16	442	36.512931999999999	36.523657999999998	54.193043000000003	54.185678000000003	0103000020E6100000010000000500000033897AC1A741424019CBF44BC4174B4033897AC1A741424062DC0DA2B5184B40F624B0390743424062DC0DA2B5184B40F624B0390743424019CBF44BC4174B4033897AC1A741424019CBF44BC4174B40
46560	Березовский	1	16	442	36.468384999999998	36.479371	54.027085999999997	54.022948999999997	0103000020E61000000100000005000000EE77280AF43B4240EA3C2AFEEF024B40EE77280AF43B4240F816D68D77034B404ED367075C3D4240F816D68D77034B404ED367075C3D4240EA3C2AFEEF024B40EE77280AF43B4240EA3C2AFEEF024B40
60615	Березово	1	16	442	36.381687999999997	36.438443999999997	54.053458999999997	54.036515000000001	0103000020E6100000010000000500000048A30227DB3042401F680586AC044B4048A30227DB304240A35698BED7064B404F90D8EE1E384240A35698BED7064B404F90D8EE1E3842401F680586AC044B4048A30227DB3042401F680586AC044B40
60608	Агеево	1	16	442	36.450966000000001	36.482596000000001	54.168072000000002	54.144356000000002	0103000020E61000000100000005000000D1CDFE40B93942409E7DE5417A124B40D1CDFE40B9394240C9AF1F6283154B401897AAB4C53D4240C9AF1F6283154B401897AAB4C53D42409E7DE5417A124B40D1CDFE40B93942409E7DE5417A124B40
51240	Тула	1	16	7111	37.570078000000002	37.572566999999999	54.199928	54.198695000000001	0103000020E61000000100000005000000A515DF50F8C842407A7077D66E194B40A515DF50F8C8424000C79E3D97194B4069E21DE049C9424000C79E3D97194B4069E21DE049C942407A7077D66E194B40A515DF50F8C842407A7077D66E194B40
47056	Юсупово	1	16	210	37.010769000000003	37.024352	53.697366000000002	53.689982000000001	0103000020E61000000100000005000000C367EBE060814240126A865451D84A40C367EBE060814240D2AB014A43D94A40CDCB61F71D834240D2AB014A43D94A40CDCB61F71D834240126A865451D84A40C367EBE060814240126A865451D84A40
2315	Юрьевский	1	16	210	37.268352	37.279563000000003	53.744152	53.733916000000001	0103000020E6100000010000000500000079E8BB5B59A242406D01A1F5F0DD4A4079E8BB5B59A2424062A06B5F40DF4A40F9156BB8C8A3424062A06B5F40DF4A40F9156BB8C8A342406D01A1F5F0DD4A4079E8BB5B59A242406D01A1F5F0DD4A40
60599	Стройка	1	16	210	37.351869000000001	37.366304999999997	53.426788999999999	53.419415999999998	0103000020E61000000100000005000000F5BC1B0B0AAD4240A6B5696CAFB54A40F5BC1B0B0AAD424072A59E05A1B64A403EAE0D15E3AE424072A59E05A1B64A403EAE0D15E3AE4240A6B5696CAFB54A40F5BC1B0B0AAD4240A6B5696CAFB54A40
1459	Сорочинка	1	16	210	37.102567999999998	37.455677999999999	53.812741000000003	53.664583	0103000020E61000000100000005000000DDCEBEF2208D4240213D450E11D54A40DDCEBEF2208D4240268FA7E507E84A40DBC01DA853BA4240268FA7E507E84A40DBC01DA853BA4240213D450E11D54A40DDCEBEF2208D4240213D450E11D54A40
60563	Советский	1	16	210	37.13232	37.146819000000001	53.6008	53.592170000000003	0103000020E61000000100000005000000A94D9CDCEF9042400FD6FF39CCCB4A40A94D9CDCEF904240E9B7AF03E7CC4A4039B709F7CA924240E9B7AF03E7CC4A4039B709F7CA9242400FD6FF39CCCB4A40A94D9CDCEF9042400FD6FF39CCCB4A40
1828	Савватеевка	1	16	210	37.175609999999999	37.201903999999999	53.587974000000003	53.577925	0103000020E61000000100000005000000DF6C73637A96424039454772F9C94A40DF6C73637A964240FC7266BB42CB4A403E7782FDD7994240FC7266BB42CB4A403E7782FDD799424039454772F9C94A40DF6C73637A96424039454772F9C94A40
60551	Рождествено 1-е	1	16	210	37.142777000000002	37.160015000000001	53.686191000000001	53.681322000000002	0103000020E610000001000000050000007DCF488446924240CD052E8F35D74A407DCF4884469242409FE74F1BD5D74A404AEF1B5F7B9442409FE74F1BD5D74A404AEF1B5F7B944240CD052E8F35D74A407DCF488446924240CD052E8F35D74A40
801	Плавск	1	16	210	37.266950999999999	37.325448999999999	53.725104999999999	53.682718999999999	0103000020E6100000010000000500000037514B732BA24240CDAD105663D74A4037514B732BA2424042959A3DD0DC4A4009C21550A8A9424042959A3DD0DC4A4009C21550A8A94240CDAD105663D74A4037514B732BA24240CDAD105663D74A40
45971	Новоникольское	1	16	210	37.368397999999999	37.381656999999997	53.430582000000001	53.416925999999997	0103000020E61000000100000005000000B6F468AA27AF4240116DC7D45DB54A40B6F468AA27AF4240861F9C4F1DB74A400DA5F622DAB04240861F9C4F1DB74A400DA5F622DAB04240116DC7D45DB54A40B6F468AA27AF4240116DC7D45DB54A40
46922	Новое Жуково	1	16	210	37.197465999999999	37.205829999999999	53.492068000000003	53.480736	0103000020E610000001000000050000003509DE90469942404301DBC188BD4A403509DE90469942403EB48F15FCBE4A4091442FA3589A42403EB48F15FCBE4A4091442FA3589A42404301DBC188BD4A403509DE90469942404301DBC188BD4A40
1729	Молочные Дворы	1	16	210	37.225709000000002	37.244070999999998	53.658714000000003	53.646877000000003	0103000020E61000000100000005000000D9B45208E49C42406EC493DDCCD24A40D9B45208E49C42406CB587BD50D44A407573F1B73D9F42406CB587BD50D44A407573F1B73D9F42406EC493DDCCD24A40D9B45208E49C42406EC493DDCCD24A40
46735	Мещерино	1	16	210	37.375126000000002	37.392319999999998	53.621704000000001	53.596980000000002	0103000020E610000001000000050000008DF0F62004B04240DC2E34D769CC4A408DF0F62004B042406DE525FF93CF4A408AC8B08A37B242406DE525FF93CF4A408AC8B08A37B24240DC2E34D769CC4A408DF0F62004B04240DC2E34D769CC4A40
2200	Крекшино	1	16	210	37.253045	37.265109000000002	53.781506	53.767479999999999	0103000020E610000001000000050000004AB54FC763A04240C32ADEC83CE24A404AB54FC763A042405BD07B6308E44A4009707A17EFA142405BD07B6308E44A4009707A17EFA14240C32ADEC83CE24A404AB54FC763A04240C32ADEC83CE24A40
47026	Красногорье	1	16	210	37.092874999999999	37.107382999999999	53.749077	53.738484999999997	0103000020E61000000100000005000000D9CEF753E38B424014CB2DAD86DE4A40D9CEF753E38B4240C89750C1E1DF4A40BC92E4B9BE8D4240C89750C1E1DF4A40BC92E4B9BE8D424014CB2DAD86DE4A40D9CEF753E38B424014CB2DAD86DE4A40
46706	Камынино	1	16	210	37.307752000000001	37.337693000000002	53.679188000000003	53.665714000000001	0103000020E61000000100000005000000A9A3E36A64A74240A33EC91D36D54A40A9A3E36A64A74240F7EAE3A1EFD64A40488B338639AB4240F7EAE3A1EFD64A40488B338639AB4240A33EC91D36D54A40A9A3E36A64A74240A33EC91D36D54A40
1676	Ивановское 1-е	1	16	210	37.458508000000002	37.465792999999998	53.572696000000001	53.567214999999997	0103000020E61000000100000005000000297AE063B0BA42407B6649809AC84A40297AE063B0BA424067463F1A4EC94A4055DAE21A9FBB424067463F1A4EC94A4055DAE21A9FBB42407B6649809AC84A40297AE063B0BA42407B6649809AC84A40
1588	Диктатура	1	16	210	37.392769000000001	37.405444000000003	53.552619	53.541302999999999	0103000020E61000000100000005000000FAF02C4146B24240041DAD6A49C54A40FAF02C4146B24240F9122A38BCC64A40022EC896E5B34240F9122A38BCC64A40022EC896E5B34240041DAD6A49C54A40FAF02C4146B24240041DAD6A49C54A40
46925	Гремячево	1	16	210	37.267023000000002	37.289157000000003	53.463836999999998	53.451622999999998	0103000020E61000000100000005000000D12346CF2DA242408A8F4FC8CEB94A40D12346CF2DA242405ED6C4025FBB4A406A34B91803A542405ED6C4025FBB4A406A34B91803A542408A8F4FC8CEB94A40D12346CF2DA242408A8F4FC8CEB94A40
60553	Горбачево	1	16	210	37.107823000000003	37.145265000000002	53.605753	53.599832999999997	0103000020E61000000100000005000000D960E124CD8D4240E107E753C7CC4A40D960E124CD8D4240193A765089CD4A407120240B98924240193A765089CD4A407120240B98924240E107E753C7CC4A40D960E124CD8D4240E107E753C7CC4A40
46857	Большие Озерки	1	16	210	37.168289000000001	37.196370000000002	53.561208999999998	53.545909999999999	0103000020E6100000010000000500000066A3737E8A9542409947FE60E0C54A4066A3737E8A954240459C4EB2D5C74A4030F5F3A622994240459C4EB2D5C74A4030F5F3A6229942409947FE60E0C54A4066A3737E8A9542409947FE60E0C54A40
226	Ченцовы Дворы	1	16	39	36.993763999999999	37.015673999999997	53.927273	53.915899000000003	0103000020E6100000010000000500000098F8A3A8337F424035B8AD2D3CF54A4098F8A3A8337F42405EBBB4E1B0F64A40E1B20A9B018242405EBBB4E1B0F64A40E1B20A9B0182424035B8AD2D3CF54A4098F8A3A8337F424035B8AD2D3CF54A40
674	Стрелецкий	1	16	39	36.630746000000002	36.650661999999997	53.794763000000003	53.781294000000003	0103000020E610000001000000050000009A0AF148BC504240D047197101E44A409A0AF148BC504240128942CBBAE54A40FE5F75E448534240128942CBBAE54A40FE5F75E448534240D047197101E44A409A0AF148BC504240D047197101E44A40
46302	Стояново	1	16	39	36.795577999999999	36.808962999999999	53.891008999999997	53.883839999999999	0103000020E6100000010000000500000063B5F97FD5654240C5724BAB21F14A4063B5F97FD565424088B839950CF24A4047567E198C67424088B839950CF24A4047567E198C674240C5724BAB21F14A4063B5F97FD5654240C5724BAB21F14A40
46409	Сомово	1	16	39	36.509284999999998	36.797122999999999	53.894241000000001	53.856647000000002	0103000020E61000000100000005000000F3AB394030414240B79BE09BA6ED4A40F3AB39403041424005DF347D76F24A40D8F15F200866424005DF347D76F24A40D8F15F2008664240B79BE09BA6ED4A40F3AB394030414240B79BE09BA6ED4A40
47	Северо-Ватцевское	1	16	39	36.568213999999998	36.582875000000001	54.055964000000003	54.047702000000001	0103000020E610000001000000050000008E90813CBB48424016FA60191B064B408E90813CBB4842406EE00ED429074B40F853E3A59B4A42406EE00ED429074B40F853E3A59B4A424016FA60191B064B408E90813CBB48424016FA60191B064B40
46337	Рылево	1	16	39	36.821854000000002	36.846009000000002	53.857214999999997	53.844383000000001	0103000020E610000001000000050000001C0B0A83326942403126FDBD14EC4A401C0B0A833269424000529B38B9ED4A40938FDD054A6C424000529B38B9ED4A40938FDD054A6C42403126FDBD14EC4A401C0B0A83326942403126FDBD14EC4A40
46205	Окороково	1	16	39	36.659061000000001	36.700598999999997	54.047871000000001	54.033723000000002	0103000020E61000000100000005000000D788601C5C544240BF0F070951044B40D788601C5C544240A2B60DA320064B401E4E603AAD594240A2B60DA320064B401E4E603AAD594240BF0F070951044B40D788601C5C544240BF0F070951044B40
32223	Одоев	1	16	39	36.660732000000003	36.712214000000003	53.952776999999998	53.912340999999998	0103000020E61000000100000005000000D9B5BDDD9254424064E60297C7F44A40D9B5BDDD92544240C4B0C398F4F94A406EE00ED4295B4240C4B0C398F4F94A406EE00ED4295B424064E60297C7F44A40D9B5BDDD9254424064E60297C7F44A40
612	Николо-Жупань	1	16	39	36.643034999999998	36.662672000000001	53.963897000000003	53.943694999999998	0103000020E6100000010000000500000078978BF84E52424009336DFFCAF84A4078978BF84E52424034DB15FA60FB4A40CAFCA36FD254424034DB15FA60FB4A40CAFCA36FD254424009336DFFCAF84A4078978BF84E52424009336DFFCAF84A40
8491	Мишенское	1	16	39	36.787860999999999	36.804488999999997	53.964480000000002	53.958827999999997	0103000020E610000001000000050000009D6516A1D86442409A3E3BE0BAFA4A409D6516A1D8644240B3D2A41474FB4A40F17EDC7EF9664240B3D2A41474FB4A40F17EDC7EF96642409A3E3BE0BAFA4A409D6516A1D86442409A3E3BE0BAFA4A40
150	Жемчужниково	1	16	39	36.795183000000002	36.828968000000003	53.944457999999997	53.935378999999998	0103000020E61000000100000005000000E7AA798EC8654240BE2EC37FBAF74A40E7AA798EC86542400839EFFFE3F84A401CB7989F1B6A42400839EFFFE3F84A401CB7989F1B6A4240BE2EC37FBAF74A40E7AA798EC8654240BE2EC37FBAF74A40
48484	Воскресенское	1	16	39	36.999710999999998	37.010302000000003	53.809429000000002	53.805441000000002	0103000020E61000000100000005000000C939B187F67F4240C4EDD0B018E74A40C939B187F67F42408DB7955E9BE74A40AD8A7093518142408DB7955E9BE74A40AD8A709351814240C4EDD0B018E74A40C939B187F67F4240C4EDD0B018E74A40
487	Ботвиньево	1	16	39	36.979131000000002	36.995992000000001	53.805664	53.795161	0103000020E61000000100000005000000F9BF232A547D4240FF06EDD5C7E54A40F9BF232A547D424043C879FF1FE74A40F08975AA7C7F424043C879FF1FE74A40F08975AA7C7F4240FF06EDD5C7E54A40F9BF232A547D4240FF06EDD5C7E54A40
45595	Березово	1	16	39	36.922384000000001	36.954858000000002	53.844116999999997	53.827745999999998	0103000020E61000000100000005000000452DCDAD1076424089B2B794F3E94A40452DCDAD10764240B27F9E060CEC4A40782975C9387A4240B27F9E060CEC4A40782975C9387A424089B2B794F3E94A40452DCDAD1076424089B2B794F3E94A40
46207	Апухтино	1	16	39	36.689279999999997	36.714128000000002	53.988537000000001	53.972197000000001	0103000020E61000000100000005000000B8E4B8533A584240792288F370FC4A40B8E4B8533A58424067F1626188FE4A403694DA8B685B424067F1626188FE4A403694DA8B685B4240792288F370FC4A40B8E4B8533A584240792288F370FC4A40
45879	Шишлово	1	16	1812	38.537419999999997	38.553994000000003	54.247070999999998	54.228512000000002	0103000020E61000000100000005000000B01BB62DCA4443402D5F97E13F1D4B40B01BB62DCA4443401F65C405A01F4B4012178046E94643401F65C405A01F4B4012178046E94643402D5F97E13F1D4B40B01BB62DCA4443402D5F97E13F1D4B40
31513	Ширинский	1	16	1812	38.34881	38.396977999999997	54.077153000000003	54.0608	0103000020E6100000010000000500000046425BCEA52C434064CC5D4BC8074B4046425BCEA52C4340E7E44526E0094B40A19DD32CD0324340E7E44526E0094B40A19DD32CD032434064CC5D4BC8074B4046425BCEA52C434064CC5D4BC8074B40
31856	Холтобино	1	16	1812	38.468744000000001	38.486530999999999	54.189523999999999	54.175687000000003	0103000020E610000001000000050000001E19ABCDFF3B43408BAA5FE97C164B401E19ABCDFF3B43404FE78A5242184B40BEBED6A5463E43404FE78A5242184B40BEBED6A5463E43408BAA5FE97C164B401E19ABCDFF3B43408BAA5FE97C164B40
40896	Хлопово	1	16	1812	38.433548000000002	38.451011000000001	54.175319000000002	54.164898000000001	0103000020E61000000100000005000000849F38807E3743408196AE601B154B40849F38807E37434008AF5DDA70164B4071917BBABA39434008AF5DDA70164B4071917BBABA3943408196AE601B154B40849F38807E3743408196AE601B154B40
51160	Савино	1	16	1812	38.530315000000002	38.560076000000002	54.157896999999998	54.143881	0103000020E6100000010000000500000004CAA65CE143434005C24EB16A124B4004CAA65CE1434340799109F835144B4023A30392B0474340799109F835144B4023A30392B047434005C24EB16A124B4004CAA65CE143434005C24EB16A124B40
31299	Рига-Васильевка	1	16	1812	38.157397000000003	38.171114000000003	54.059700999999997	54.050694	0103000020E6100000010000000500000088BEBB95251443403D0D18247D064B4088BEBB9525144340ED444948A4074B40A2F14410E7154340ED444948A4074B40A2F14410E71543403D0D18247D064B4088BEBB95251443403D0D18247D064B40
49461	Пушкари	1	16	1812	38.668349999999997	38.686746999999997	54.156874999999999	54.146824000000002	0103000020E610000001000000050000000B24287E8C5543404B22FB20CB124B400B24287E8C554340AE47E17A14144B4024D06053E7574340AE47E17A14144B4024D06053E75743404B22FB20CB124B400B24287E8C5543404B22FB20CB124B40
46000	Правда	1	16	1812	38.232486999999999	38.244731000000002	54.201639	54.194186000000002	0103000020E6100000010000000500000061DF4E22C21D4340A8AB3B16DB184B4061DF4E22C21D4340904C874ECF194B40A0A86C58531F4340904C874ECF194B40A0A86C58531F4340A8AB3B16DB184B4061DF4E22C21D4340A8AB3B16DB184B40
45528	Первомайский	1	16	1812	38.593457000000001	38.614899999999999	54.198827000000001	54.186605	0103000020E61000000100000005000000884A2366F64B4340922232ACE2174B40884A2366F64B4340E947C32973194B40BB270F0BB54E4340E947C32973194B40BB270F0BB54E4340922232ACE2174B40884A2366F64B4340922232ACE2174B40
47600	Орловка	1	16	1812	38.138900999999997	38.153067	54.108319000000002	54.098996	0103000020E61000000100000005000000DB300A82C7114340A837A3E6AB0C4B40DB300A82C71143408944A165DD0D4B40658C0FB3971343408944A165DD0D4B40658C0FB397134340A837A3E6AB0C4B40DB300A82C7114340A837A3E6AB0C4B40
45796	Ольховец	1	16	1812	38.418976999999998	38.442225999999998	54.110450999999998	54.099665999999999	0103000020E610000001000000050000005A63D009A1354340F64201DBC10C4B405A63D009A1354340BE672442230E4B406FB88FDC9A384340BE672442230E4B406FB88FDC9A384340F64201DBC10C4B405A63D009A1354340F64201DBC10C4B40
51159	Озерки	1	16	1812	38.441256000000003	38.460228000000001	54.145494999999997	54.135610999999997	0103000020E61000000100000005000000F7949C137B3843402AFD84B35B114B40F7949C137B384340A25D85949F124B400C5A48C0E83A4340A25D85949F124B400C5A48C0E83A43402AFD84B35B114B40F7949C137B3843402AFD84B35B114B40
27080	Новомосковск	1	16	1812	38.167476000000001	38.34872	54.10154	53.976953000000002	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
48792	Никольское	1	16	1812	38.393141999999997	38.401603999999999	54.166168999999996	54.160733999999998	0103000020E610000001000000050000008E57207A5232434079AD84EE92144B408E57207A52324340F44D9A0645154B40ADF886C267334340F44D9A0645154B40ADF886C26733434079AD84EE92144B408E57207A5232434079AD84EE92144B40
31416	Малое Колодезное	1	16	1812	38.320818000000003	38.332847000000001	54.042240999999997	54.033802000000001	0103000020E61000000100000005000000ECFB7090102943400B45BA9F53044B40ECFB70901029434071C6302768054B402EC901BB9A2A434071C6302768054B402EC901BB9A2A43400B45BA9F53044B40ECFB7090102943400B45BA9F53044B40
45719	Малиновский	1	16	1812	38.364134999999997	38.389485999999998	54.049135	54.04177	0103000020E610000001000000050000001B2AC6F99B2E43401AFA27B858054B401B2AC6F99B2E4340630B410E4A064B40FB1F60ADDA314340630B410E4A064B40FB1F60ADDA3143401AFA27B858054B401B2AC6F99B2E43401AFA27B858054B40
60536	Кукуй	1	16	1812	38.485632000000003	38.501837999999999	54.127665999999998	54.118051000000001	0103000020E610000001000000050000000FF27A30293E43404B21904B1C0F4B400FF27A30293E4340D367075C57104B40EDF1423A3C404340D367075C57104B40EDF1423A3C4043404B21904B1C0F4B400FF27A30293E43404B21904B1C0F4B40
31902	Красный Богатырь	1	16	1812	38.718843999999997	38.743045000000002	54.151749000000002	54.143479999999997	0103000020E6100000010000000500000081768714035C4340A6D0798D5D124B4081768714035C4340B119E0826C134B40693A3B191C5F4340B119E0826C134B40693A3B191C5F4340A6D0798D5D124B4081768714035C4340A6D0798D5D124B40
31334	Красное Гремячево	1	16	1812	38.217494000000002	38.239674000000001	54.037731000000001	54.026446	0103000020E61000000100000005000000C289E8D7D61B4340158E209562034B40C289E8D7D61B4340CF85915ED4044B40CBD93BA3AD1E4340CF85915ED4044B40CBD93BA3AD1E4340158E209562034B40C289E8D7D61B4340158E209562034B40
31994	Коммунаров	1	16	1812	38.344265	38.363857000000003	54.230943000000003	54.220346999999997	0103000020E61000000100000005000000271422E0102C4340C7629B54341C4B40271422E0102C4340BD1E4C8A8F1D4B40D9B5BDDD922E4340BD1E4C8A8F1D4B40D9B5BDDD922E4340C7629B54341C4B40271422E0102C4340C7629B54341C4B40
31235	Грицово	1	16	1812	38.157809999999998	38.175201999999999	54.119143999999999	54.108086999999998	0103000020E61000000100000005000000AA7D3A1E33144340B60F79CBD50D4B40AA7D3A1E33144340DFC14F1C400F4B40CE18E6046D164340DFC14F1C400F4B40CE18E6046D164340B60F79CBD50D4B40AA7D3A1E33144340B60F79CBD50D4B40
31702	Гремячее	1	16	1812	38.650770000000001	38.670425000000002	54.135162000000001	54.126711	0103000020E61000000100000005000000E59B6D6E4C5343409085E81038104B40E59B6D6E4C534340BBD408FD4C114B40DDB5847CD0554340BBD408FD4C114B40DDB5847CD05543409085E81038104B40E59B6D6E4C5343409085E81038104B40
45849	Березовка	1	16	1812	38.594185000000003	38.611018999999999	54.114552000000003	54.104343999999998	0103000020E610000001000000050000000B630B410E4C434054C4E9245B0D4B400B630B410E4C434080D8D2A3A90E4B40081EDFDE354E434080D8D2A3A90E4B40081EDFDE354E434054C4E9245B0D4B400B630B410E4C434054C4E9245B0D4B40
51175	ст. Присады	1	16	1162	37.807305999999997	37.812497999999998	54.120479000000003	54.119207000000003	0103000020E61000000100000005000000AAEE91CD55E74240263ACB2C420F4B40AAEE91CD55E742406A6D1ADB6B0F4B405F0839EFFFE742406A6D1ADB6B0F4B405F0839EFFFE74240263ACB2C420F4B40AAEE91CD55E74240263ACB2C420F4B40
27470	Ямны	1	16	1162	37.460357999999999	37.486221	54.226317000000002	54.214466999999999	0103000020E61000000100000005000000DA39CD02EDBA42401E8997A7731B4B40DA39CD02EDBA4240B1C398F4F71C4B4070D05E7D3CBE4240B1C398F4F71C4B4070D05E7D3CBE42401E8997A7731B4B40DA39CD02EDBA42401E8997A7731B4B40
26953	Южный	1	16	1162	37.215764999999998	37.239894	54.085340000000002	54.074939000000001	0103000020E610000001000000050000008B4F01309E9B4240F418E59997094B408B4F01309E9B42403485CE6BEC0A4B40D940BAD8B49E42403485CE6BEC0A4B40D940BAD8B49E4240F418E59997094B408B4F01309E9B4240F418E59997094B40
20702	Шатск 2-й	1	16	1162	37.832422000000001	37.863000999999997	54.137473	54.120525999999998	0103000020E61000000100000005000000473CD9CD8CEA4240AA285E656D0F4B40473CD9CD8CEA4240A08A1BB798114B4028B517D176EE4240A08A1BB798114B4028B517D176EE4240AA285E656D0F4B40473CD9CD8CEA4240AA285E656D0F4B40
20800	Частое	1	16	1162	37.775244999999998	37.793346	54.182532999999999	54.172103999999997	0103000020E610000001000000050000009AB1683A3BE3424061C1FD8007164B409AB1683A3BE342406BB8C83D5D174B40CA349A5C8CE542406BB8C83D5D174B40CA349A5C8CE5424061C1FD8007164B409AB1683A3BE3424061C1FD8007164B40
60495	Хрущево	1	16	1162	37.169798	38.028030999999999	54.409027000000002	54.039316999999997	0103000020E610000001000000050000008E76DCF0BB954240A296E65608054B408E76DCF0BB9542402B172AFF5A344B4018231285960343402B172AFF5A344B401823128596034340A296E65608054B408E76DCF0BB954240A296E65608054B40
27489	Федоровка	1	16	1162	37.388241000000001	37.692124	54.289971999999999	54.240288999999997	0103000020E61000000100000005000000B1FB8EE1B1B14240554B3ACAC11E4B40B1FB8EE1B1B14240BB6070CD1D254B406B63EC8497D84240BB6070CD1D254B406B63EC8497D84240554B3ACAC11E4B40B1FB8EE1B1B14240554B3ACAC11E4B40
27227	Торхово	1	16	1162	37.761887000000002	37.796363999999997	54.304679	54.289825	0103000020E61000000100000005000000B01F628385E14240174850FC18254B40B01F628385E142409563B2B8FF264B401ADB6B41EFE542409563B2B8FF264B401ADB6B41EFE54240174850FC18254B40B01F628385E14240174850FC18254B40
48114	Теплое	1	16	1162	37.829726999999998	37.849696999999999	54.331704000000002	54.320540999999999	0103000020E61000000100000005000000D9CD8C7E34EA42407903CC7C07294B40D9CD8C7E34EA4240E8F9D346752A4B4031410DDFC2EC4240E8F9D346752A4B4031410DDFC2EC42407903CC7C07294B40D9CD8C7E34EA42407903CC7C07294B40
60555	Старое Басово	1	16	1162	37.169798	38.028030999999999	54.409027000000002	54.039316999999997	0103000020E610000001000000050000008E76DCF0BB954240A296E65608054B408E76DCF0BB9542402B172AFF5A344B4018231285960343402B172AFF5A344B401823128596034340A296E65608054B408E76DCF0BB954240A296E65608054B40
26690	Сергиевский	1	16	1162	37.733212000000002	37.746048999999999	54.109844000000002	54.101407999999999	0103000020E6100000010000000500000073840CE4D9DD4240C1C6F5EFFA0C4B4073840CE4D9DD4240B7D4415E0F0E4B40541B9C887EDF4240B7D4415E0F0E4B40541B9C887EDF4240C1C6F5EFFA0C4B4073840CE4D9DD4240C1C6F5EFFA0C4B40
27250	Рождественский	1	16	1162	37.563485	37.576994999999997	54.300328999999998	54.289361999999997	0103000020E61000000100000005000000AE64C74620C84240425A63D009254B40AE64C74620C842402B85402E71264B404E7ADFF8DAC942402B85402E71264B404E7ADFF8DAC94240425A63D009254B40AE64C74620C84240425A63D009254B40
27000	Рассвет	1	16	1162	37.424264000000001	37.435924	54.180672999999999	54.166659000000003	0103000020E61000000100000005000000616F62484EB64240C34A051555154B40616F62484EB642409622F94A20174B4050C58D5BCCB742409622F94A20174B4050C58D5BCCB74240C34A051555154B40616F62484EB64240C34A051555154B40
26504	Осиновая Гора	1	16	1162	37.664923000000002	37.686346999999998	54.165294000000003	54.156309999999998	0103000020E61000000100000005000000DAAD65321CD54240D50451F701144B40DAAD65321CD54240CE1C925A28154B40965AEF37DAD74240CE1C925A28154B40965AEF37DAD74240D50451F701144B40DAAD65321CD54240D50451F701144B40
27328	Октябрьский	1	16	1162	37.545402000000003	37.570914000000002	54.344889999999999	54.330691000000002	0103000020E61000000100000005000000259694BBCFC54240700A2B15542A4B40259694BBCFC54240D55B035B252C4B400E6ABFB513C94240D55B035B252C4B400E6ABFB513C94240700A2B15542A4B40259694BBCFC54240700A2B15542A4B40
20469	Обидимо	1	16	1162	37.395778	37.408382000000003	54.300119000000002	54.290596999999998	0103000020E61000000100000005000000F73C7FDAA8B2424069A8514832254B40F73C7FDAA8B2424041F4A44C6A264B40362383DC45B4424041F4A44C6A264B40362383DC45B4424069A8514832254B40F73C7FDAA8B2424069A8514832254B40
60558	Морозовка	1	16	1162	37.169798	38.028030999999999	54.409027000000002	54.039316999999997	0103000020E610000001000000050000008E76DCF0BB954240A296E65608054B408E76DCF0BB9542402B172AFF5A344B4018231285960343402B172AFF5A344B401823128596034340A296E65608054B408E76DCF0BB954240A296E65608054B40
27134	Молодежный	1	16	1162	37.702750999999999	37.719028000000002	54.261904000000001	54.255060999999998	0103000020E610000001000000050000009B1DA9BEF3D9424016BEBED6A5204B409B1DA9BEF3D942408658FD1186214B404374081C09DC42408658FD1186214B404374081C09DC424016BEBED6A5204B409B1DA9BEF3D9424016BEBED6A5204B40
26645	Лутовиново	1	16	1162	37.671039999999998	37.697944999999997	54.090525999999997	54.076343999999999	0103000020E61000000100000005000000672783A3E4D54240779FE3A3C5094B40672783A3E4D5424006B8205B960B4B400FB4024356D9424006B8205B960B4B400FB4024356D94240779FE3A3C5094B40672783A3E4D54240779FE3A3C5094B40
25905	Ленинский	1	16	1162	37.436318999999997	37.470734	54.309317	54.267277999999997	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
40984	Кураково	1	16	1162	37.244501999999997	37.254913000000002	54.079994999999997	54.073349	0103000020E610000001000000050000003EE76ED74B9F4240DF18028063094B403EE76ED74B9F4240F86BB2463D0A4B40A2293BFDA0A04240F86BB2463D0A4B40A2293BFDA0A04240DF18028063094B403EE76ED74B9F4240DF18028063094B40
26541	Крутое	1	16	1162	37.647899000000002	37.812407999999998	54.192163000000001	54.101002000000001	0103000020E61000000100000005000000390EBC5AEED24240516A2FA2ED0C4B40390EBC5AEED24240294014CC98184B401F813FFCFCE74240294014CC98184B401F813FFCFCE74240516A2FA2ED0C4B40390EBC5AEED24240516A2FA2ED0C4B40
27622	Коптево	1	16	1162	37.310851999999997	37.320957999999997	54.204441000000003	54.199047999999998	0103000020E61000000100000005000000B6F292FFC9A74240C72AA5677A194B40B6F292FFC9A74240147B681F2B1A4B40DDB1D82615A94240147B681F2B1A4B40DDB1D82615A94240C72AA5677A194B40B6F292FFC9A74240C72AA5677A194B40
22053	Иншинский	1	16	1162	37.442967000000003	37.476042999999997	54.172241	54.160021999999998	0103000020E61000000100000005000000871A8524B3B84240FC51D4997B144B40871A8524B3B84240E2033BFE0B164B40AF3E1EFAEEBC4240E2033BFE0B164B40AF3E1EFAEEBC4240FC51D4997B144B40871A8524B3B84240FC51D4997B144B40
26332	Ильинка	1	16	1162	37.669359999999998	37.717689999999997	54.145321000000003	54.105446999999998	0103000020E6100000010000000500000012A0A696ADD542400C3B8C497F0D4B4012A0A696ADD542400536E7E099124B4047551344DDDB42400536E7E099124B4047551344DDDB42400C3B8C497F0D4B4012A0A696ADD542400C3B8C497F0D4B40
26886	Зайцево	1	16	1162	37.366179000000002	37.388528999999998	54.154476000000003	54.139113000000002	0103000020E61000000100000005000000B2BD16F4DEAE424067B96C74CE114B40B2BD16F4DEAE42402A029CDEC5134B4017467A51BBB142402A029CDEC5134B4017467A51BBB1424067B96C74CE114B40B2BD16F4DEAE424067B96C74CE114B40
60548	Восточный	1	16	1162	37.590856000000002	37.597000999999999	54.314506999999999	54.309832	0103000020E610000001000000050000009C525E2BA1CB42408CA03193A8274B409C525E2BA1CB424079AEEFC341284B40F3565D876ACC424079AEEFC341284B40F3565D876ACC42408CA03193A8274B409C525E2BA1CB42408CA03193A8274B40
19609	Барсуки	1	16	1162	37.477193	37.503289000000002	54.283996000000002	54.250757999999998	0103000020E61000000100000005000000A87004A914BD4240ED9A90D618204B40A87004A914BD4240F0181EFB59244B40E1B721C66BC04240F0181EFB59244B40E1B721C66BC04240ED9A90D618204B40A87004A914BD4240ED9A90D618204B40
27418	Архангельское	1	16	1162	37.650872999999997	37.668812000000003	54.297905999999998	54.282819000000003	0103000020E61000000100000005000000B96C74CE4FD34240FED7B96933244B40B96C74CE4FD342401EA4A7C821264B401096B1A19BD542401EA4A7C821264B401096B1A19BD54240FED7B96933244B40B96C74CE4FD34240FED7B96933244B40
27559	Алешня	1	16	1162	37.248041000000001	37.271073999999999	54.252310000000001	54.225521999999998	0103000020E610000001000000050000009888B7CEBF9F4240A643A7E7DD1C4B409888B7CEBF9F4240153AAFB14B204B40E065868DB2A24240153AAFB14B204B40E065868DB2A24240A643A7E7DD1C4B409888B7CEBF9F4240A643A7E7DD1C4B40
47918	Травино	1	16	1762	38.471744000000001	38.487088	53.415970999999999	53.406986000000003	0103000020E61000000100000005000000C80A7E1B623C434006F7031E18B44A40C80A7E1B623C4340CE8AA8893EB54A4014234BE6583E4340CE8AA8893EB54A4014234BE6583E434006F7031E18B44A40C80A7E1B623C434006F7031E18B44A40
46011	Софьинка	1	16	1762	38.530152999999999	38.552439999999997	53.495100000000001	53.482455999999999	0103000020E610000001000000050000002A70B20DDC43434026E1421EC1BD4A402A70B20DDC434340F31FD26F5FBF4A4049809A5AB6464340F31FD26F5FBF4A4049809A5AB646434026E1421EC1BD4A402A70B20DDC43434026E1421EC1BD4A40
47792	Самарский	1	16	1762	38.542109000000004	38.659132999999997	53.420012	53.393681999999998	0103000020E6100000010000000500000003EFE4D3634543400E83F92B64B24A4003EFE4D363454340BAF605F4C2B54A40705B5B785E544340BAF605F4C2B54A40705B5B785E5443400E83F92B64B24A4003EFE4D3634543400E83F92B64B24A40
46818	Ракитино	1	16	1762	38.420585000000003	38.427501999999997	53.431043000000003	53.428345	0103000020E610000001000000050000001618B2BAD5354340DB334B02D4B64A401618B2BAD5354340BA15C26A2CB74A40BF7CB262B8364340BA15C26A2CB74A40BF7CB262B8364340DB334B02D4B64A401618B2BAD5354340DB334B02D4B64A40
25027	Птань	1	16	1762	38.410299999999999	38.432577999999999	53.460158999999997	53.452067999999997	0103000020E610000001000000050000003FC6DCB584344340B8C83D5DDDB94A403FC6DCB584344340E3FA777DE6BA4A400B7C45B75E374340E3FA777DE6BA4A400B7C45B75E374340B8C83D5DDDB94A403FC6DCB584344340B8C83D5DDDB94A40
47690	Михайловский	1	16	1762	38.461081	38.477080000000001	53.562787	53.548766999999998	0103000020E610000001000000050000004BE7C3B3043B4340E00F3FFF3DC64A404BE7C3B3043B434096CE876709C84A40B0C91AF5103D434096CE876709C84A40B0C91AF5103D4340E00F3FFF3DC64A404BE7C3B3043B4340E00F3FFF3DC64A40
60613	Марьинка	1	16	1762	38.379477999999999	38.698740000000001	53.403587999999999	53.379987	0103000020E6100000010000000500000097C62FBC92304340DCF3FC69A3B04A4097C62FBC923043406E8786C5A8B34A401A34F44F705943406E8786C5A8B34A401A34F44F70594340DCF3FC69A3B04A4097C62FBC92304340DCF3FC69A3B04A40
25543	Куркино	1	16	1762	38.64423	38.684789000000002	53.452154	53.414977999999998	0103000020E61000000100000005000000118DEE20765243409D47C5FF1DB54A40118DEE2076524340B760A92EE0B94A408DD47B2AA7574340B760A92EE0B94A408DD47B2AA75743409D47C5FF1DB54A40118DEE20765243409D47C5FF1DB54A40
60593	Кресты	1	16	1762	38.589531999999998	38.612735000000001	53.508479000000001	53.495168999999997	0103000020E6100000010000000500000005F9D9C8754B43401B7FA2B261BF4A4005F9D9C8754B4340F5D901D715C14A40AA0EB9196E4E4340F5D901D715C14A40AA0EB9196E4E43401B7FA2B261BF4A4005F9D9C8754B43401B7FA2B261BF4A40
60609	Грибоедова	1	16	1762	38.857131000000003	38.879165999999998	53.573059000000001	53.565615999999999	0103000020E61000000100000005000000A3B1F677B66D4340130CE71A66C84A40A3B1F677B66D4340D8D64FFF59C94A40A8E0F08288704340D8D64FFF59C94A40A8E0F08288704340130CE71A66C84A40A3B1F677B66D4340130CE71A66C84A40
47694	Грачевка	1	16	1762	38.477682000000001	38.490861000000002	53.568888999999999	53.553260999999999	0103000020E61000000100000005000000A6F10BAF243D43407D93A641D1C64A40A6F10BAF243D4340EE06D15AD1C84A40E1F08288D43E4340EE06D15AD1C84A40E1F08288D43E43407D93A641D1C64A40A6F10BAF243D43407D93A641D1C64A40
60602	Андреевка	1	16	1762	38.689819	38.716687999999998	53.499780999999999	53.483763000000003	0103000020E6100000010000000500000068942EFD4B584340E7012CF2EBBD4A4068942EFD4B584340C214E5D2F8BF4A40C3B7B06EBC5B4340C214E5D2F8BF4A40C3B7B06EBC5B4340E7012CF2EBBD4A4068942EFD4B584340E7012CF2EBBD4A40
39105	Богданово	1	16	6182	34.509590000000003	34.526001999999998	56.922525999999998	56.919105999999999	0103000020E61000000100000005000000302FC03E3A41414058C7F143A5754C40302FC03E3A414140D7DAFB5415764C40B7D0950854434140D7DAFB5415764C40B7D095085443414058C7F143A5754C40302FC03E3A41414058C7F143A5754C40
21284	Шварцевский	1	16	1223	37.978875000000002	38.012884999999997	54.10389	54.081595	0103000020E610000001000000050000009EEFA7C64BFD4240314278B4710A4B409EEFA7C64BFD4240D3307C444C0D4B40F2CD3637A6014340D3307C444C0D4B40F2CD3637A6014340314278B4710A4B409EEFA7C64BFD4240314278B4710A4B40
47335	Шахтерский	1	16	1223	37.705679000000003	37.736159000000001	53.954017	53.947589999999998	0103000020E61000000100000005000000AC3C81B053DA424021020EA14AF94A40AC3C81B053DA4240FD69A33A1DFA4A40FAD346753ADE4240FD69A33A1DFA4A40FAD346753ADE424021020EA14AF94A40AC3C81B053DA424021020EA14AF94A40
47425	Черная Грязь	1	16	1223	38.017152000000003	38.047344000000002	53.906947000000002	53.893439000000001	0103000020E61000000100000005000000CF8767093202434048FC8A355CF24A40CF87670932024340481ADCD616F44A40B7D4415E0F064340481ADCD616F44A40B7D4415E0F06434048FC8A355CF24A40CF8767093202434048FC8A355CF24A40
22498	Сеченский	1	16	1223	37.802427999999999	37.819792	53.892612	53.885066000000002	0103000020E6100000010000000500000085B2F0F5B5E642409966BAD749F14A4085B2F0F5B5E6424032022A1C41F24A40DFC2BAF1EEE8424032022A1C41F24A40DFC2BAF1EEE842409966BAD749F14A4085B2F0F5B5E642409966BAD749F14A40
23969	Сергиевское	1	16	1223	37.749966000000001	37.761347999999998	54.111792000000001	54.105690000000003	0103000020E61000000100000005000000548EC9E2FEDF4240D3C1FA3F870D4B40548EC9E2FEDF42402BFA43334F0E4B400070ECD973E142402BFA43334F0E4B400070ECD973E14240D3C1FA3F870D4B40548EC9E2FEDF4240D3C1FA3F870D4B40
47280	Прогресс	1	16	1223	37.848906999999997	37.866253	53.88964	53.879030999999998	0103000020E61000000100000005000000382C0DFCA8EC4240C8957A1684F04A40382C0DFCA8EC4240529B38B9DFF14A40EC87D860E1EE4240529B38B9DFF14A40EC87D860E1EE4240C8957A1684F04A40382C0DFCA8EC4240C8957A1684F04A40
22405	Приупский	1	16	1223	37.721623999999998	37.745969000000002	53.913241999999997	53.902617999999997	0103000020E610000001000000050000001D01DC2C5EDC4240F56393FC88F34A401D01DC2C5EDC4240B4AA251DE5F44A40386A85E97BDF4240B4AA251DE5F44A40386A85E97BDF4240F56393FC88F34A401D01DC2C5EDC4240F56393FC88F34A40
24017	Подосинки	1	16	1223	37.746310000000001	37.764654	54.051054000000001	54.034906999999997	0103000020E61000000100000005000000C156091687DF424063B323D577044B40C156091687DF42403D2AFEEF88064B40B760A92EE0E142403D2AFEEF88064B40B760A92EE0E1424063B323D577044B40C156091687DF424063B323D577044B40
23025	Октябрьский	1	16	1223	37.792313	37.801780999999998	54.034987000000001	54.029767	0103000020E610000001000000050000000B992B836AE5424001C0B167CF034B400B992B836AE5424080643A747A044B40EFC682C2A0E6424080643A747A044B40EFC682C2A0E6424001C0B167CF034B400B992B836AE5424001C0B167CF034B40
24866	Новоселебное	1	16	1223	37.971338000000003	37.993068000000001	54.078426	54.066395999999997	0103000020E6100000010000000500000058AEB7CD54FC4240E84A04AA7F084B4058AEB7CD54FC4240FB93F8DC090A4B40215A2BDA1CFF4240FB93F8DC090A4B40215A2BDA1CFF4240E84A04AA7F084B4058AEB7CD54FC4240E84A04AA7F084B40
60604	Новое Село	1	16	1223	37.844558999999997	37.860143999999998	54.121803	54.109042000000002	0103000020E610000001000000050000006F4562821AEC4240FAF19716F50D4B406F4562821AEC424000C79E3D970F4B40E1ECD63219EE424000C79E3D970F4B40E1ECD63219EE4240FAF19716F50D4B406F4562821AEC4240FAF19716F50D4B40
47909	Моховое	1	16	1223	38.004576	38.013145000000002	54.088988999999998	54.085731000000003	0103000020E610000001000000050000005A2C45F2950043406FA0C03BF90A4B405A2C45F295004340145AD6FD630B4B408F8D40BCAE014340145AD6FD630B4B408F8D40BCAE0143406FA0C03BF90A4B405A2C45F2950043406FA0C03BF90A4B40
47319	Мостовая	1	16	1223	37.902563000000001	37.918318999999997	53.848877000000002	53.832124999999998	0103000020E6100000010000000500000032CA332F87F342408D976E1283EA4A4032CA332F87F34240CEA96400A8EC4A40D0251C7A8BF54240CEA96400A8EC4A40D0251C7A8BF542408D976E1283EA4A4032CA332F87F342408D976E1283EA4A40
47350	Майское	1	16	1223	37.802804999999999	37.823816999999998	53.862578999999997	53.850571000000002	0103000020E610000001000000050000005B087250C2E6424088F6B182DFEC4A405B087250C2E64240B29B19FD68EE4A40C571E0D572E94240B29B19FD68EE4A40C571E0D572E9424088F6B182DFEC4A405B087250C2E6424088F6B182DFEC4A40
23076	Липки	1	16	1223	37.684308000000001	37.714483000000001	53.950986	53.934128000000001	0103000020E610000001000000050000001232906797D7424092239D8191F74A401232906797D74240187AC4E8B9F94A402446CF2D74DB4240187AC4E8B9F94A402446CF2D74DB424092239D8191F74A401232906797D7424092239D8191F74A40
24183	Кузнецово	1	16	1223	37.873367999999999	37.885503999999997	53.834223999999999	53.826141	0103000020E61000000100000005000000BCAFCA85CAEF42403F7100FDBEE94A40BCAFCA85CAEF4240E7C41EDAC7EA4A40143DF03158F14240E7C41EDAC7EA4A40143DF03158F142403F7100FDBEE94A40BCAFCA85CAEF42403F7100FDBEE94A40
24358	Криволучье	1	16	1223	37.912399000000001	37.929467000000002	54.018093	54.005870999999999	0103000020E6100000010000000500000099F38C7DC9F44240567F8461C0004B4099F38C7DC9F44240ADA415DF50024B400ADB4FC6F8F64240ADA415DF50024B400ADB4FC6F8F64240567F8461C0004B4099F38C7DC9F44240567F8461C0004B40
24626	Красный Яр	1	16	1223	37.880643999999997	37.892816000000003	54.179392	54.168239999999997	0103000020E6100000010000000500000095B54DF1B8F0424084F068E388154B4095B54DF1B8F04240FF942A51F6164B403BAC70CB47F24240FF942A51F6164B403BAC70CB47F2424084F068E388154B4095B54DF1B8F0424084F068E388154B40
40469	Красногвардейский	1	16	1223	37.750675999999999	37.763908000000001	54.080168999999998	54.062026000000003	0103000020E6100000010000000500000030F2B22616E0424038C0CC77F0074B4030F2B22616E04240969350FA420A4B408E93C2BCC7E14240969350FA420A4B408E93C2BCC7E1424038C0CC77F0074B4030F2B22616E0424038C0CC77F0074B40
23258	Комсомольский	1	16	1223	37.662424999999999	37.678297999999998	53.959510999999999	53.945315999999998	0103000020E61000000100000005000000C286A757CAD4424059315C1D00F94A40C286A757CAD442407D93A641D1FA4A409A780778D2D642407D93A641D1FA4A409A780778D2D6424059315C1D00F94A40C286A757CAD4424059315C1D00F94A40
22107	Киреевск	1	16	1223	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
24051	Долгое	1	16	1223	37.756720999999999	37.780796000000002	53.983221999999998	53.972651999999997	0103000020E610000001000000050000002499D53BDCE04240CA3159DC7FFC4A402499D53BDCE04240965AEF37DAFD4A407F6C921FF1E34240965AEF37DAFD4A407F6C921FF1E34240CA3159DC7FFC4A402499D53BDCE04240CA3159DC7FFC4A40
21433	Дедилово	1	16	1223	37.910629999999998	37.967170000000003	54.008887000000001	53.952396	0103000020E61000000100000005000000D4601A868FF44240AD6BB41CE8F94A40D4601A868FF44240062E8F3523014B400FD6FF39CCFB4240062E8F3523014B400FD6FF39CCFB4240AD6BB41CE8F94A40D4601A868FF44240AD6BB41CE8F94A40
22424	Головлинский	1	16	1223	37.747981000000003	37.771157000000002	53.945708000000003	53.934731999999997	0103000020E61000000100000005000000C38366D7BDDF42402843554CA5F74A40C38366D7BDDF424065C8B1F50CF94A406E8AC745B5E2424065C8B1F50CF94A406E8AC745B5E242402843554CA5F74A40C38366D7BDDF42402843554CA5F74A40
12355	Васильевский	1	16	1223	37.792816000000002	37.813853999999999	53.952793	53.943106	0103000020E610000001000000050000006EDFA3FE7AE54240A85489B2B7F84A406EDFA3FE7AE54240CA6DFB1EF5F94A4001DC2C5E2CE84240CA6DFB1EF5F94A4001DC2C5E2CE84240A85489B2B7F84A406EDFA3FE7AE54240A85489B2B7F84A40
21244	Бородинский	1	16	1223	37.802455000000002	37.837066999999998	54.005982000000003	53.987096999999999	0103000020E610000001000000050000007FC16ED8B6E64240677DCA3159FE4A407FC16ED8B6E64240AE2EA704C4004B40C9C7EE0225EB4240AE2EA704C4004B40C9C7EE0225EB4240677DCA3159FE4A407FC16ED8B6E64240677DCA3159FE4A40
23867	Большие Калмыки	1	16	1223	37.814115000000001	37.835638000000003	54.056482000000003	54.042442000000001	0103000020E610000001000000050000006E179AEB34E8424009FD4CBD6E054B406E179AEB34E8424006685BCD3A074B40BEA59C2FF6EA424006685BCD3A074B40BEA59C2FF6EA424009FD4CBD6E054B406E179AEB34E8424009FD4CBD6E054B40
23289	Болохово	1	16	1223	37.806972999999999	37.848457000000003	54.099608000000003	54.064355999999997	0103000020E61000000100000005000000A4E029E44AE7424093A641D13C084B40A4E029E44AE74240C23577F4BF0C4B40F9872D3D9AEC4240C23577F4BF0C4B40F9872D3D9AEC424093A641D13C084B40A4E029E44AE7424093A641D13C084B40
51158	Шахтерский	1	16	153	38.591543999999999	38.602826999999998	54.018071999999997	54.012141	0103000020E610000001000000050000009012BBB6B74B43406AF816D68D014B409012BBB6B74B4340957CEC2E50024B40A912656F294D4340957CEC2E50024B40A912656F294D43406AF816D68D014B409012BBB6B74B43406AF816D68D014B40
45887	Черемухово	1	16	153	38.803545999999997	38.825671999999997	53.806026000000003	53.794533999999999	0103000020E61000000100000005000000726A6798DA664340B0C7444AB3E54A40726A6798DA664340E4DC26DC2BE74A40889CBE9EAF694340E4DC26DC2BE74A40889CBE9EAF694340B0C7444AB3E54A40726A6798DA664340B0C7444AB3E54A40
21899	Хитровщина	1	16	153	38.775995000000002	38.804614999999998	53.967292999999998	53.949455	0103000020E61000000100000005000000056EDDCD536343400803CFBD87F94A40056EDDCD536343402A53CC41D0FB4A407E6FD39FFD6643402A53CC41D0FB4A407E6FD39FFD6643400803CFBD87F94A40056EDDCD536343400803CFBD87F94A40
21339	Федосовка	1	16	153	38.581366000000003	38.605980000000002	53.818449999999999	53.805866000000002	0103000020E61000000100000005000000D0807A336A4A4340AB7AF99D26E74A40D0807A336A4A4340A2B437F8C2E84A40DA03ADC0904D4340A2B437F8C2E84A40DA03ADC0904D4340AB7AF99D26E74A40D0807A336A4A4340AB7AF99D26E74A40
46095	Устье	1	16	153	38.777019000000003	38.794635	53.659295999999998	53.648750999999997	0103000020E6100000010000000500000071AFCC5B75634340A71FD4450AD34A4071AFCC5B756343401A31B3CF63D44A40E4A08499B66543401A31B3CF63D44A40E4A08499B6654340A71FD4450AD34A4071AFCC5B75634340A71FD4450AD34A40
21198	Таболо	1	16	153	38.756798000000003	38.784744000000003	53.857683000000002	53.842247	0103000020E61000000100000005000000D0D6C1C1DE604340BA13ECBFCEEB4A40D0D6C1C1DE604340E7AA798EC8ED4A40BADDCB7D72644340E7AA798EC8ED4A40BADDCB7D72644340BA13ECBFCEEB4A40D0D6C1C1DE604340BA13ECBFCEEB4A40
45869	Суханово	1	16	153	38.712349000000003	38.741419	53.717891000000002	53.706732000000002	0103000020E610000001000000050000004E2B85402E5B4340B284B53176DA4A404E2B85402E5B4340DF8B2FDAE3DB4A4007D15AD1E65E4340DF8B2FDAE3DB4A4007D15AD1E65E4340B284B53176DA4A404E2B85402E5B4340B284B53176DA4A40
60539	Совхозный	1	16	153	38.765880000000003	38.782553	53.753289000000002	53.747388999999998	0103000020E610000001000000050000008B54185B08624340F0315871AADF4A408B54185B08624340E1B721C66BE04A407F315BB22A644340E1B721C66BE04A407F315BB22A644340F0315871AADF4A408B54185B08624340F0315871AADF4A40
20345	Пронь	1	16	153	38.521375999999997	38.531661999999997	54.040818999999999	54.029788000000003	0103000020E61000000100000005000000AB75E272BC42434019E8DA17D0034B40AB75E272BC4243401807978E39054B4052431B800D4443401807978E39054B4052431B800D44434019E8DA17D0034B40AB75E272BC42434019E8DA17D0034B40
22009	Новольвовск	1	16	153	38.775492	38.804138999999999	53.932527	53.917473999999999	0103000020E61000000100000005000000A2276552436343401477BCC96FF54A40A22765524363434089D1730B5DF74A401538D906EE66434089D1730B5DF74A401538D906EE6643401477BCC96FF54A40A2276552436343401477BCC96FF54A40
46146	Муравлянка	1	16	153	38.483342	38.503985	53.741216999999999	53.729894000000002	0103000020E6100000010000000500000041649126DE3D4340F8C5A52A6DDD4A4041649126DE3D43409F1EDB32E0DE4A4058569A94824043409F1EDB32E0DE4A4058569A9482404340F8C5A52A6DDD4A4041649126DE3D4340F8C5A52A6DDD4A40
20370	Монастырщино	1	16	153	38.613472000000002	38.668241999999999	53.674563999999997	53.661318000000001	0103000020E6100000010000000500000080812040864E4340C9207711A6D44A4080812040864E43408B87F71C58D64A4025E82FF4885543408B87F71C58D64A4025E82FF488554340C9207711A6D44A4080812040864E4340C9207711A6D44A40
46125	Молоденки	1	16	153	38.896666000000003	38.916679999999999	53.734406	53.725968000000002	0103000020E61000000100000005000000B3B794F3C5724340A5F8F884ECDC4A40B3B794F3C57243403BFE0B0401DE4A40DA722EC5557543403BFE0B0401DE4A40DA722EC555754340A5F8F884ECDC4A40B3B794F3C5724340A5F8F884ECDC4A40
60594	Михайловский	1	16	153	38.780433000000002	38.784888000000002	53.917335999999999	53.914090999999999	0103000020E610000001000000050000000EDC813AE5634340B24813EF00F54A400EDC813AE5634340C3B81B446BF54A40ED82C13577644340C3B81B446BF54A40ED82C13577644340B24813EF00F54A400EDC813AE5634340B24813EF00F54A40
60552	Мирный	1	16	153	38.580134999999999	38.598416	53.970100000000002	53.961471000000003	0103000020E61000000100000005000000EA211ADD414A4340B686527B11FB4A40EA211ADD414A4340C0EC9E3C2CFC4A409AB33EE5984C4340C0EC9E3C2CFC4A409AB33EE5984C4340B686527B11FB4A40EA211ADD414A4340B686527B11FB4A40
21761	Луговое	1	16	153	38.503957999999997	38.533135000000001	53.867171999999997	53.858649	0103000020E610000001000000050000005E471CB2814043401EDFDE35E8ED4A405E471CB281404340E200FA7DFFEE4A402EAD86C43D444340E200FA7DFFEE4A402EAD86C43D4443401EDFDE35E8ED4A405E471CB2814043401EDFDE35E8ED4A40
45561	Кудашево	1	16	153	38.690727000000003	38.727288000000001	53.905971000000001	53.892352000000002	0103000020E610000001000000050000006BBB09BE695843409642209738F24A406BBB09BE69584340ED0F94DBF6F34A40FA62EFC5175D4340ED0F94DBF6F34A40FA62EFC5175D43409642209738F24A406BBB09BE695843409642209738F24A40
20230	Кропотово	1	16	153	38.612797999999998	38.640942000000003	53.931615000000001	53.917602000000002	0103000020E61000000100000005000000F086342A704E4340425F7AFB73F54A40F086342A704E434045BB0A293FF74A40015130630A52434045BB0A293FF74A40015130630A524340425F7AFB73F54A40F086342A704E4340425F7AFB73F54A40
19534	Кимовск	1	16	153	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
60549	Каменка	1	16	153	38.506087000000001	38.521008000000002	53.943900999999997	53.936174000000001	0103000020E6100000010000000500000023F77475C7404340C9AEB48CD4F74A4023F77475C7404340B2D47ABFD1F84A40297AE063B0424340B2D47ABFD1F84A40297AE063B0424340C9AEB48CD4F74A4023F77475C7404340C9AEB48CD4F74A40
46275	Казановка	1	16	153	38.549430999999998	38.589450999999997	53.768692999999999	53.749088	0103000020E610000001000000050000004C3448C153464340BCE9961DE2DF4A404C3448C15346434002D53F8864E24A4018CC5F21734B434002D53F8864E24A4018CC5F21734B4340BCE9961DE2DF4A404C3448C153464340BCE9961DE2DF4A40
51157	Зубовский	1	16	153	38.548479	38.569212	53.995635999999998	53.992576	0103000020E610000001000000050000007AC5538F34464340B265F9BA0CFF4A407AC5538F34464340315C1D0071FF4A40D13E56F0DB484340315C1D0071FF4A40D13E56F0DB484340B265F9BA0CFF4A407AC5538F34464340B265F9BA0CFF4A40
46161	Зубовка	1	16	153	38.563121000000002	38.585417	54.011803	54.002637999999997	0103000020E610000001000000050000006D5853591448434009DD257156004B406D58535914484340527FBDC282014B40DFC2BAF1EE4A4340527FBDC282014B40DFC2BAF1EE4A434009DD257156004B406D5853591448434009DD257156004B40
22052	Епифань	1	16	153	38.532192000000002	38.581411000000003	53.837688999999997	53.816504999999999	0103000020E61000000100000005000000AF9811DE1E4443409F02603C83E84A40AF9811DE1E444340069CA56439EB4A407044F7AC6B4A4340069CA56439EB4A407044F7AC6B4A43409F02603C83E84A40AF9811DE1E4443409F02603C83E84A40
45917	Гранки	1	16	153	38.449393999999998	38.482002999999999	53.993132000000003	53.973182000000001	0103000020E6100000010000000500000062821ABE8539434027874F3A91FC4A4062821ABE85394340384E0AF31EFF4A4075C93846B23D4340384E0AF31EFF4A4075C93846B23D434027874F3A91FC4A4062821ABE8539434027874F3A91FC4A40
47702	Горки	1	16	153	38.516435999999999	38.536369000000001	53.724828000000002	53.716062999999998	0103000020E61000000100000005000000103D29931A4243401570CFF3A7DB4A40103D29931A424340D09CF529C7DC4A404BCB48BDA7444340D09CF529C7DC4A404BCB48BDA74443401570CFF3A7DB4A40103D29931A4243401570CFF3A7DB4A40
60588	Вишневая	1	16	153	38.630826999999996	38.645955000000001	53.701256999999998	53.692881999999997	0103000020E6100000010000000500000086376BF0BE50434058FE7C5BB0D84A4086376BF0BE504340A88B14CAC2D94A4006D847A7AE524340A88B14CAC2D94A4006D847A7AE52434058FE7C5BB0D84A4086376BF0BE50434058FE7C5BB0D84A40
20031	Бучалки	1	16	153	38.721331999999997	38.778106000000001	53.777771000000001	53.755268999999998	0103000020E6100000010000000500000075C7629B545C4340605793A7ACE04A4075C7629B545C43407C6308008EE34A40236937FA986343407C6308008EE34A40236937FA98634340605793A7ACE04A4075C7629B545C4340605793A7ACE04A40
45642	Богдановка	1	16	153	38.592208999999997	38.606465	53.774237999999997	53.765073999999998	0103000020E61000000100000005000000CCB22781CD4B43408C82E0F1EDE14A40CCB22781CD4B434004A9143B1AE34A40969526A5A04D434004A9143B1AE34A40969526A5A04D43408C82E0F1EDE14A40CCB22781CD4B43408C82E0F1EDE14A40
45500	Астапово	1	16	153	38.661954000000001	38.670631	53.766207999999999	53.762295999999999	0103000020E610000001000000050000006BBA9EE8BA54434091EF52EA92E14A406BBA9EE8BA5443407FF78E1A13E24A408657923CD75543407FF78E1A13E24A408657923CD755434091EF52EA92E14A406BBA9EE8BA54434091EF52EA92E14A40
21428	Апарки	1	16	153	38.701138	38.718521000000003	54.036985000000001	54.025827	0103000020E61000000100000005000000CEFDD5E3BE594340492D944C4E034B40CEFDD5E3BE594340A6B8AAECBB044B409F3E027FF85B4340A6B8AAECBB044B409F3E027FF85B4340492D944C4E034B40CEFDD5E3BE594340492D944C4E034B40
47036	Языково	1	16	1565	37.576312999999999	37.597907999999997	53.327869	53.312764999999999	0103000020E610000001000000050000003CA1D79FC4C94240AE2AFBAE08A84A403CA1D79FC4C94240A52F849CF7A94A402502D53F88CC4240A52F849CF7A94A402502D53F88CC4240AE2AFBAE08A84A403CA1D79FC4C94240AE2AFBAE08A84A40
19312	Яблонево	1	16	1565	37.889437999999998	37.924166999999997	53.235936000000002	53.218680999999997	0103000020E61000000100000005000000EAE8B81AD9F14240D7A02FBDFD9B4A40EAE8B81AD9F142407BF99D26339E4A406E85B01A4BF642407BF99D26339E4A406E85B01A4BF64240D7A02FBDFD9B4A40EAE8B81AD9F14240D7A02FBDFD9B4A40
46575	Соловьевка	1	16	1565	37.824634000000003	37.835107999999998	53.303710000000002	53.298512000000002	0103000020E61000000100000005000000B8955E9B8DE9424056BB26A435A64A40B8955E9B8DE94240EDBB22F8DFA64A406150A6D1E4EA4240EDBB22F8DFA64A406150A6D1E4EA424056BB26A435A64A40B8955E9B8DE9424056BB26A435A64A40
19335	Соклаково	1	16	1565	37.672262000000003	37.688099000000001	53.150230999999998	53.134588999999998	0103000020E61000000100000005000000FA2B64AE0CD642405FB35C363A914A40FA2B64AE0CD6424035ECF7C43A934A4085B4C6A013D8424035ECF7C43A934A4085B4C6A013D842405FB35C363A914A40FA2B64AE0CD642405FB35C363A914A40
19045	Ситово	1	16	1565	37.812632999999998	37.834578	53.348263000000003	53.335585999999999	0103000020E610000001000000050000003F53AF5B04E842406B7F677BF4AA4A403F53AF5B04E8424014B4C9E193AC4A4005FBAF73D3EA424014B4C9E193AC4A4005FBAF73D3EA42406B7F677BF4AA4A403F53AF5B04E842406B7F677BF4AA4A40
47989	Озерки	1	16	1565	37.767564	37.787039999999998	53.288065000000003	53.277991999999998	0103000020E6100000010000000500000021CB82893FE242405A46EA3D95A34A4021CB82893FE24240A60F5D50DFA44A4069520ABABDE44240A60F5D50DFA44A4069520ABABDE442405A46EA3D95A34A4021CB82893FE242405A46EA3D95A34A40
19432	Новоселки	1	16	1565	37.761356999999997	37.779898000000003	53.152563999999998	53.145035	0103000020E6100000010000000500000053CA6B2574E142403FE3C28190924A4053CA6B2574E142400246973787934A40A01B9AB2D3E342400246973787934A40A01B9AB2D3E342403FE3C28190924A4053CA6B2574E142403FE3C28190924A40
47102	Новопетровский	1	16	1565	37.789042999999999	37.820475000000002	53.228482	53.217370000000003	0103000020E61000000100000005000000A1116C5CFFE44240D690B8C7D29B4A40A1116C5CFFE44240C2DCEEE53E9D4A40C217265305E94240C2DCEEE53E9D4A40C217265305E94240D690B8C7D29B4A40A1116C5CFFE44240D690B8C7D29B4A40
47118	Каменское	1	16	1565	37.757376999999998	37.808095999999999	53.187590999999998	53.161489000000003	0103000020E610000001000000050000000DDFC2BAF1E04240F6D4EAABAB944A400DDFC2BAF1E0424010035DFB02984A40A30392B06FE7424010035DFB02984A40A30392B06FE74240F6D4EAABAB944A400DDFC2BAF1E04240F6D4EAABAB944A40
19064	Кадное	1	16	1565	37.900506	37.929260999999997	53.314588999999998	53.288361000000002	0103000020E6100000010000000500000007EDD5C743F342408F386403E9A44A4007EDD5C743F342403657CD7344A84A4060394206F2F642403657CD7344A84A4060394206F2F642408F386403E9A44A4007EDD5C743F342408F386403E9A44A40
19220	Закопы	1	16	1565	37.910217000000003	37.941101000000003	53.218454000000001	53.187494000000001	0103000020E61000000100000005000000B2A19BFD81F442401E19ABCDFF974A40B2A19BFD81F4424017D7F84CF69B4A40D09D60FF75F8424017D7F84CF69B4A40D09D60FF75F842401E19ABCDFF974A40B2A19BFD81F442401E19ABCDFF974A40
18855	Долгие Лески	1	16	1565	37.631883000000002	37.642384	53.24624	53.238689999999998	0103000020E61000000100000005000000FEF2C98AE1D04240EDF0D7648D9E4A40FEF2C98AE1D04240C87BD5CA849F4A40A1BC8FA339D24240C87BD5CA849F4A40A1BC8FA339D24240EDF0D7648D9E4A40FEF2C98AE1D04240EDF0D7648D9E4A40
19403	Галица	1	16	1565	37.849696999999999	37.870528999999998	53.135117999999999	53.120339999999999	0103000020E6100000010000000500000031410DDFC2EC42404833164D678F4A4031410DDFC2EC4240EB8CEF8B4B914A401B9C887E6DEF4240EB8CEF8B4B914A401B9C887E6DEF42404833164D678F4A4031410DDFC2EC42404833164D678F4A40
45829	Барановка	1	16	1565	37.652822	37.671425999999997	53.243690999999998	53.231828999999998	0103000020E61000000100000005000000FE0DDAAB8FD34240D7A19A92AC9D4A40FE0DDAAB8FD342402EAA4544319F4A4090D78349F1D542402EAA4544319F4A4090D78349F1D54240D7A19A92AC9D4A40FE0DDAAB8FD34240D7A19A92AC9D4A40
60497	Архангельское	1	16	1565	37.690111000000002	37.713126000000003	53.269677999999999	53.251891999999998	0103000020E6100000010000000500000010CEA78E55D84240E00F3FFF3DA04A4010CEA78E55D84240B03907CF84A24A40B2F677B647DB4240B03907CF84A24A40B2F677B647DB4240E00F3FFF3DA04A4010CEA78E55D84240E00F3FFF3DA04A40
49444	Авангард	1	16	1565	37.577660000000002	37.587837999999998	53.222211999999999	53.212328999999997	0103000020E610000001000000050000008B1A4CC3F0C94240067FBF982D9B4A408B1A4CC3F0C94240AE635C71719C4A404BAC8C463ECB4240AE635C71719C4A404BAC8C463ECB4240067FBF982D9B4A408B1A4CC3F0C94240067FBF982D9B4A40
51246	станция Приокская	1	16	1518	37.369025999999998	37.374318000000002	54.829901999999997	54.828097	0103000020E61000000100000005000000D5AF743E3CAF424036751E15FF694B40D5AF743E3CAF424047718E3A3A6A4B40EE26F8A6E9AF424047718E3A3A6A4B40EE26F8A6E9AF424036751E15FF694B40D5AF743E3CAF424036751E15FF694B40
17825	Теряево 1-е	1	16	1518	37.443469999999998	37.460197000000001	54.63646	54.627479999999998	0103000020E61000000100000005000000E960FD9FC3B842407172BF4351504B40E960FD9FC3B84240289B728577514B40D15B3CBCE7BA4240289B728577514B40D15B3CBCE7BA42407172BF4351504B40E960FD9FC3B842407172BF4351504B40
60518	Сосновый	1	16	1518	37.150897999999998	37.772119000000004	54.833843000000002	54.450355000000002	0103000020E6100000010000000500000012842BA050934240884B8E3BA5394B4012842BA050934240D07F0F5EBB6A4B4064CF9ECBD4E24240D07F0F5EBB6A4B4064CF9ECBD4E24240884B8E3BA5394B4012842BA050934240884B8E3BA5394B40
49312	Симоново	1	16	1518	37.394539000000002	37.425125999999999	54.538884000000003	54.523623000000001	0103000020E610000001000000050000008FFF024180B242407A37161406434B408FFF024180B24240392BA226FA444B40F3565D876AB64240392BA226FA444B40F3565D876AB642407A37161406434B408FFF024180B242407A37161406434B40
18401	Русятино	1	16	1518	37.524937999999999	37.533318999999999	54.70635	54.697906000000003	0103000020E61000000100000005000000BD361B2B31C3424052D7DAFB54594B40BD361B2B31C34240CAC342AD695A4B40EFAA07CC43C44240CAC342AD695A4B40EFAA07CC43C4424052D7DAFB54594B40BD361B2B31C3424052D7DAFB54594B40
40360	Пашково	1	16	1518	37.324308000000002	37.336129999999997	54.793329	54.789737000000002	0103000020E6100000010000000500000064EAAEEC82A9424078B81D1A16654B4064EAAEEC82A94240F4FBFECD8B654B402C9ACE4E06AB4240F4FBFECD8B654B402C9ACE4E06AB424078B81D1A16654B4064EAAEEC82A9424078B81D1A16654B40
49246	Пахомово	1	16	1518	37.525844999999997	37.566412999999997	54.638440000000003	54.622095999999999	0103000020E61000000100000005000000EFE192E34EC34240787C7BD7A04F4B40EFE192E34EC34240A83AE466B8514B40BE839F3880C84240A83AE466B8514B40BE839F3880C84240787C7BD7A04F4B40EFE192E34EC34240787C7BD7A04F4B40
18129	Ненашево	1	16	1518	37.453459000000002	37.477578999999999	54.587598999999997	54.569814999999998	0103000020E61000000100000005000000D789CBF10ABA424097E2AAB2EF484B40D789CBF10ABA4240C614AC71364B4B40D120054F21BD4240C614AC71364B4B40D120054F21BD424097E2AAB2EF484B40D789CBF10ABA424097E2AAB2EF484B40
18943	Молчаново	1	16	1518	37.671174999999998	37.696866999999997	54.680987999999999	54.670763999999998	0103000020E610000001000000050000004772F90FE9D54240C5AA4198DB554B404772F90FE9D54240F67B629D2A574B40B05417F032D94240F67B629D2A574B40B05417F032D94240C5AA4198DB554B404772F90FE9D54240C5AA4198DB554B40
17940	Миротинский	1	16	1518	37.696776999999997	37.713818000000003	54.637219999999999	54.626432999999999	0103000020E6100000010000000500000070CD1DFD2FD942404D11E0F42E504B4070CD1DFD2FD94240B62DCA6C90514B40E8A562635EDB4240B62DCA6C90514B40E8A562635EDB42404D11E0F42E504B4070CD1DFD2FD942404D11E0F42E504B40
60556	Малахово	1	16	1518	37.435214000000002	37.457887999999997	54.755571000000003	54.741014999999997	0103000020E610000001000000050000007461A417B5B74240376C5B94D95E4B407461A417B5B742402C67EF8CB6604B408C9DF0129CBA42402C67EF8CB6604B408C9DF0129CBA4240376C5B94D95E4B407461A417B5B74240376C5B94D95E4B40
49207	Ланьшинский Карьер	1	16	1518	37.259431999999997	37.274371000000002	54.833640000000003	54.827308000000002	0103000020E6100000010000000500000097C4591135A142400EDC813AE5694B4097C4591135A1424098512CB7B46A4B4044FCC3961EA3424098512CB7B46A4B4044FCC3961EA342400EDC813AE5694B4097C4591135A142400EDC813AE5694B40
18613	Заокский	1	16	1518	37.373967	37.426878000000002	54.751939	54.717827999999997	0103000020E6100000010000000500000041649126DEAF42409813B4C9E15B4B4041649126DEAF424021CB82893F604B40E2B034F0A3B6424021CB82893F604B40E2B034F0A3B642409813B4C9E15B4B4041649126DEAF42409813B4C9E15B4B40
49167	Дмитриевское	1	16	1518	37.613225	37.649138999999998	54.677504999999996	54.660671999999998	0103000020E61000000100000005000000780B24287ECE424003B16CE690544B40780B24287ECE424030F0DC7BB8564B4071C79BFC16D3424030F0DC7BB8564B4071C79BFC16D3424003B16CE690544B40780B24287ECE424003B16CE690544B40
51313	Велегож д.о.	1	16	1518	37.255209999999998	37.280641000000003	54.705329999999996	54.693306	0103000020E610000001000000050000005BCEA5B8AAA042406F0F4240BE584B405BCEA5B8AAA042409F71E140485A4B405875560BECA342409F71E140485A4B405875560BECA342406F0F4240BE584B405BCEA5B8AAA042406F0F4240BE584B40
17805	Бутиково	1	16	1518	37.362577000000002	37.385599999999997	54.710219000000002	54.702489999999997	0103000020E6100000010000000500000012A452EC68AE42402EE23B31EB594B4012A452EC68AE4240B9FFC874E85A4B4036AB3E575BB14240B9FFC874E85A4B4036AB3E575BB142402EE23B31EB594B4012A452EC68AE42402EE23B31EB594B40
60538	Ясеновая	1	16	328	38.021687999999997	38.045259999999999	53.158276999999998	53.143183000000001	0103000020E610000001000000050000009A5B21ACC6024340ED2B0FD253924A409A5B21ACC6024340C05AB56B42944A4092E86514CB054340C05AB56B42944A4092E86514CB054340ED2B0FD253924A409A5B21ACC6024340ED2B0FD253924A40
49558	Ярославка	1	16	328	38.29289	38.307558999999998	53.075808000000002	53.059646000000001	0103000020E61000000100000005000000A8A9656B7D2543402AABE97AA2874A40A8A9656B7D25434039639813B4894A40944BE3175E27434039639813B4894A40944BE3175E2743402AABE97AA2874A40A8A9656B7D2543402AABE97AA2874A40
11333	Яндовка	1	16	328	38.378374000000001	38.409087	53.039270999999999	53.015917000000002	0103000020E610000001000000050000000FD4298F6E304340A839799109824A400FD4298F6E304340325706D506854A40001C7BF65C344340325706D506854A40001C7BF65C344340A839799109824A400FD4298F6E304340A839799109824A40
14919	Шкилевка	1	16	328	38.060271	38.083843000000002	53.063721000000001	53.051656999999999	0103000020E61000000100000005000000D8F2CAF5B607434003CE52B29C864A40D8F2CAF5B6074340C2887D0228884A40D07F0F5EBB0A4340C2887D0228884A40D07F0F5EBB0A434003CE52B29C864A40D8F2CAF5B607434003CE52B29C864A40
48996	Чернятино	1	16	328	38.152205000000002	38.183340000000001	53.178114999999998	53.152262	0103000020E61000000100000005000000D3A414747B13434037363B527D934A40D3A414747B134340A9F6E978CC964A403A0664AF77174340A9F6E978CC964A403A0664AF7717434037363B527D934A40D3A414747B13434037363B527D934A40
17503	Тормасово	1	16	328	38.310837999999997	38.335433999999999	53.270442000000003	53.259842999999996	0103000020E61000000100000005000000512D228AC9274340198C118942A14A40512D228AC927434080BBECD79DA24A40B5FB5580EF2A434080BBECD79DA24A40B5FB5580EF2A4340198C118942A14A40512D228AC9274340198C118942A14A40
40390	Сретенка	1	16	328	38.237239000000002	38.251001000000002	53.048560999999999	53.039952999999997	0103000020E61000000100000005000000FA2AF9D85D1E434044300E2E1D854A40FA2AF9D85D1E4340376E313F37864A40B421FFCC20204340376E313F37864A40B421FFCC2020434044300E2E1D854A40FA2AF9D85D1E434044300E2E1D854A40
40465	Покровка	1	16	328	38.137256999999998	38.147821	53.156413999999998	53.144447	0103000020E61000000100000005000000D3122BA391114340AE80423D7D924A40D3122BA3911143407A51BB5F05944A40BD546CCCEB1243407A51BB5F05944A40BD546CCCEB124340AE80423D7D924A40D3122BA391114340AE80423D7D924A40
2846	Пожилино	1	16	328	37.956031000000003	37.977975999999998	53.131870999999997	53.110075999999999	0103000020E61000000100000005000000297B4B395FFA424089096AF8168E4A40297B4B395FFA424039252026E1904A40EE224C512EFD424039252026E1904A40EE224C512EFD424089096AF8168E4A40297B4B395FFA424089096AF8168E4A40
60569	Павлов Хутор	1	16	328	38.268554000000002	38.294372000000003	53.329155	53.307391000000003	0103000020E61000000100000005000000E19A3BFA5F224340D90A9A9658A74A40E19A3BFA5F2243404E2844C021AA4A40D76D50FBAD2543404E2844C021AA4A40D76D50FBAD254340D90A9A9658A74A40E19A3BFA5F224340D90A9A9658A74A40
6853	Новокрасивое	1	16	328	38.169533000000001	38.233834999999999	53.179873999999998	53.157769000000002	0103000020E61000000100000005000000E04BE141B31543404CA94BC631944A40E04BE141B31543404AB3791C06974A4080D4264EEE1D43404AB3791C06974A4080D4264EEE1D43404CA94BC631944A40E04BE141B31543404CA94BC631944A40
47477	Николаевка	1	16	328	38.317405000000001	38.334733	53.000945999999999	52.985309000000001	0103000020E610000001000000050000001F4B1FBAA02843402CBAF59A1E7E4A401F4B1FBAA0284340F0879FFF1E804A402CF2EB87D82A4340F0879FFF1E804A402CF2EB87D82A43402CBAF59A1E7E4A401F4B1FBAA02843402CBAF59A1E7E4A40
45453	Мордовка	1	16	328	38.579354000000002	38.602009000000002	53.056182	53.043227999999999	0103000020E6100000010000000500000045679945284A4340C022BF7E88854A4045679945284A4340DB4FC6F830874A40E77283A10E4D4340DB4FC6F830874A40E77283A10E4D4340C022BF7E88854A4045679945284A4340C022BF7E88854A40
15599	Мечнянка	1	16	328	38.564594	38.578930999999997	53.150517000000001	53.138337999999997	0103000020E6100000010000000500000048C2BE9D44484340A3E5400FB5914A4048C2BE9D44484340FB3E1C2444934A40FED137691A4A4340FB3E1C2444934A40FED137691A4A4340A3E5400FB5914A4048C2BE9D44484340A3E5400FB5914A40
60574	Малая Хмелевская	1	16	328	37.990670000000001	38.019865000000003	53.209702	53.202388999999997	0103000020E610000001000000050000006D904946CEFE4240FA08FCE1E7994A406D904946CEFE4240F1F3DF83D79A4A40E3AAB2EF8A024340F1F3DF83D79A4A40E3AAB2EF8A024340FA08FCE1E7994A406D904946CEFE4240FA08FCE1E7994A40
9350	Кытино	1	16	328	38.296663000000002	38.329855999999999	53.172885000000001	53.161365000000004	0103000020E6100000010000000500000075779D0DF92543400ADCBA9BA7944A4075779D0DF9254340077C7E1821964A40D731AEB8382A4340077C7E1821964A40D731AEB8382A43400ADCBA9BA7944A4075779D0DF92543400ADCBA9BA7944A40
46238	Круглики	1	16	328	38.142090000000003	38.164467000000002	53.063634	53.047083000000001	0103000020E61000000100000005000000598B4F01301243404A99D4D006864A40598B4F0130124340F374AE2825884A40B82231410D154340F374AE2825884A40B82231410D1543404A99D4D006864A40598B4F01301243404A99D4D006864A40
1527	Кременный	1	16	328	38.089179000000001	38.103489000000003	53.321027999999998	53.313744	0103000020E61000000100000005000000B83EAC376A0B43407AA86DC328A84A40B83EAC376A0B4340D68C0C7217A94A40753FA7203F0D4340D68C0C7217A94A40753FA7203F0D43407AA86DC328A84A40B83EAC376A0B43407AA86DC328A84A40
13958	Красина	1	16	328	38.185155000000002	38.200668999999998	53.163648999999999	53.154729000000003	0103000020E610000001000000050000006FD8B628B3174340145FED28CE934A406FD8B628B3174340F5824F73F2944A4017299485AF194340F5824F73F2944A4017299485AF194340145FED28CE934A406FD8B628B3174340145FED28CE934A40
49101	Кочкино	1	16	328	37.884335999999998	37.899876999999996	53.065604	53.053767999999998	0103000020E6100000010000000500000075560BEC31F1424021C9ACDEE1864A4075560BEC31F142404F3E3DB665884A4017B6662B2FF342404F3E3DB665884A4017B6662B2FF3424021C9ACDEE1864A4075560BEC31F1424021C9ACDEE1864A40
7954	Козьминский	1	16	328	38.443744000000002	38.461387000000002	53.182341000000001	53.176043	0103000020E61000000100000005000000EBE5779ACC38434049D8B79388964A40EBE5779ACC38434027DC2BF356974A4058E6ADBA0E3B434027DC2BF356974A4058E6ADBA0E3B434049D8B79388964A40EBE5779ACC38434049D8B79388964A40
5726	Козье	1	16	328	38.445746999999997	38.469408999999999	53.267792999999998	53.249386000000001	0103000020E6100000010000000500000022A5D93C0E394340460A65E1EB9F4A4022A5D93C0E394340828C800A47A24A405AB91798153C4340828C800A47A24A405AB91798153C4340460A65E1EB9F4A4022A5D93C0E394340460A65E1EB9F4A40
31803	Иноземка	1	16	328	38.104368999999998	38.135891000000001	53.121442000000002	53.098691000000002	0103000020E61000000100000005000000ADDBA0F65B0D43406CB41CE8A18C4A40ADDBA0F65B0D4340302E55698B8F4A400E6954E064114340302E55698B8F4A400E6954E0641143406CB41CE8A18C4A40ADDBA0F65B0D43406CB41CE8A18C4A40
16197	Ефремов	1	16	328	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
60542	Двенадцатый Октябрь	1	16	328	38.252358000000001	38.266407999999998	53.122095999999999	53.113633	0103000020E61000000100000005000000267156444D204340895FB1868B8E4A40267156444D204340787C7BD7A08F4A4046B247A819224340787C7BD7A08F4A4046B247A819224340895FB1868B8E4A40267156444D204340895FB1868B8E4A40
17234	Большие Плоты	1	16	328	38.181966000000003	38.199024999999999	53.311737999999998	53.297300999999997	0103000020E61000000100000005000000F27D71A94A174340B7088CF50DA64A40F27D71A94A174340D175E107E7A74A400F0BB5A679194340D175E107E7A74A400F0BB5A679194340B7088CF50DA64A40F27D71A94A174340B7088CF50DA64A40
7190	Большие Медведки	1	16	328	37.978020999999998	37.991325000000003	53.246395999999997	53.230918000000003	0103000020E610000001000000050000008EE6C8CA2FFD4240640795B88E9D4A408EE6C8CA2FFD4240BFEE74E7899F4A40865AD3BCE3FE4240BFEE74E7899F4A40865AD3BCE3FE4240640795B88E9D4A408EE6C8CA2FFD4240640795B88E9D4A40
24415	Скоморошки	1	16	1415	36.931438999999997	36.955252999999999	54.092179000000002	54.075277	0103000020E61000000100000005000000069CA564397742400C923EADA2094B40069CA5643977424062307F85CC0B4B40F433F5BA457A424062307F85CC0B4B40F433F5BA457A42400C923EADA2094B40069CA564397742400C923EADA2094B40
16026	Протасово	1	16	1415	36.963464000000002	37.006943	54.185141000000002	54.167977	0103000020E61000000100000005000000CA6FD1C9527B424077BD344580154B40CA6FD1C9527B42400A1346B3B2174B40D3F71A82E38042400A1346B3B2174B40D3F71A82E380424077BD344580154B40CA6FD1C9527B424077BD344580154B40
60603	Поречье	1	16	1415	37.053905999999998	37.074792000000002	54.188665	54.180993999999998	0103000020E6100000010000000500000072874D64E6864240D862B7CF2A174B4072874D64E68642402E73BA2C26184B405000C5C8928942402E73BA2C26184B405000C5C892894240D862B7CF2A174B4072874D64E6864240D862B7CF2A174B40
40670	Первомайский	1	16	1415	37.103754000000002	37.126688000000001	54.114134999999997	54.097079000000001	0103000020E61000000100000005000000236AA2CF478D42406F10AD156D0C4B40236AA2CF478D42401B2AC6F99B0E4B40D865F84F379042401B2AC6F99B0E4B40D865F84F379042406F10AD156D0C4B40236AA2CF478D42406F10AD156D0C4B40
25049	Опочня	1	16	1415	37.070912	37.098616	54.168787999999999	54.155203	0103000020E610000001000000050000006D72F8A413894240DC9E20B1DD134B406D72F8A41389424087FA5DD89A154B40616EF7729F8C424087FA5DD89A154B40616EF7729F8C4240DC9E20B1DD134B406D72F8A413894240DC9E20B1DD134B40
16106	Новое Павшино	1	16	1415	37.108092999999997	37.151643	54.263508000000002	54.251078999999997	0103000020E6100000010000000500000098F6CDFDD58D42402FDB4E5B23204B4098F6CDFDD58D4240001E51A1BA214B406BD5AE0969934240001E51A1BA214B406BD5AE09699342402FDB4E5B23204B4098F6CDFDD58D42402FDB4E5B23204B40
60572	Надеждино	1	16	1415	36.846971000000003	36.863948999999998	54.210459999999998	54.191789	0103000020E6100000010000000500000089D4B48B696C4240C45DBD8A8C184B4089D4B48B696C4240DE8E705AF01A4B40B9347EE1956E4240DE8E705AF01A4B40B9347EE1956E4240C45DBD8A8C184B4089D4B48B696C4240C45DBD8A8C184B40
48502	Лужное	1	16	1415	37.053296000000003	37.087198000000001	54.087231000000003	54.073064000000002	0103000020E61000000100000005000000FA804067D2864240EA4141295A094B40FA804067D28642404419AA622A0B4B406823D74D298B42404419AA622A0B4B406823D74D298B4240EA4141295A094B40FA804067D2864240EA4141295A094B40
30558	Лобжа	1	16	1415	36.843009000000002	36.868161999999998	54.255740000000003	54.237969	0103000020E61000000100000005000000E99D0AB8E76B42401D3BA8C4751E4B40E99D0AB8E76B4240B8239C16BC204B40A2D0B2EE1F6F4240B8239C16BC204B40A2D0B2EE1F6F42401D3BA8C4751E4B40E99D0AB8E76B42401D3BA8C4751E4B40
47564	Красавка	1	16	1415	37.223498999999997	37.235734000000001	54.114452	54.109237	0103000020E6100000010000000500000027D87F9D9B9C4240AF415F7AFB0D4B4027D87F9D9B9C42401C7BF65CA60E4B4013471E882C9E42401C7BF65CA60E4B4013471E882C9E4240AF415F7AFB0D4B4027D87F9D9B9C4240AF415F7AFB0D4B40
15723	Дубна	1	16	1415	36.930990000000001	36.989389000000003	54.168118999999997	54.143237999999997	0103000020E61000000100000005000000977329AE2A774240B0C56E9F55124B40977329AE2A774240096B63EC84154B40D6027B4CA47E4240096B63EC84154B40D6027B4CA47E4240B0C56E9F55124B40977329AE2A774240B0C56E9F55124B40
16007	Гвардейский	1	16	1415	36.934286999999998	36.956637000000001	54.128261999999999	54.111775999999999	0103000020E61000000100000005000000FA0967B796774240253D0CAD4E0E4B40FA0967B796774240E7A8A3E36A104B406092CA14737A4240E7A8A3E36A104B406092CA14737A4240253D0CAD4E0E4B40FA0967B796774240253D0CAD4E0E4B40
46787	Бабошино	1	16	1415	37.121262000000002	37.143082	54.227184999999999	54.214782999999997	0103000020E61000000100000005000000B01F6283858F42404E5E64027E1B4B40B01F6283858F42402592E865141D4B40B952CF82509242402592E865141D4B40B952CF82509242404E5E64027E1B4B40B01F6283858F42404E5E64027E1B4B40
13355	Ялта	1	16	1270	38.026161999999999	38.046706999999998	53.485247999999999	53.470987000000001	0103000020E61000000100000005000000F032C34659034340ABEB504D49BC4A40F032C346590343408639419B1CBE4A4044BFB67EFA0543408639419B1CBE4A4044BFB67EFA054340ABEB504D49BC4A40F032C34659034340ABEB504D49BC4A40
13903	Турдей	1	16	1270	37.983258999999997	38.237400999999998	53.459708999999997	53.353395999999996	0103000020E61000000100000005000000B33F506EDBFD4240C34483143CAD4A40B33F506EDBFD4240A35698BED7BA4A40D384ED27631E4340A35698BED7BA4A40D384ED27631E4340C34483143CAD4A40B33F506EDBFD4240C34483143CAD4A40
40344	Сухие Плоты	1	16	1270	38.132424	38.160792999999998	53.457500000000003	53.440323999999997	0103000020E610000001000000050000004E9A0645F31043406BD26D895CB84A404E9A0645F3104340C3F5285C8FBA4A407E3672DD94144340C3F5285C8FBA4A407E3672DD941443406BD26D895CB84A404E9A0645F31043406BD26D895CB84A40
47154	Становая	1	16	1270	37.947091999999998	37.986654000000001	53.524363999999998	53.492277000000001	0103000020E61000000100000005000000D026874F3AF9424058C9C7EE02BF4A40D026874F3AF9424091990B5C1EC34A40DA3BA3AD4AFE424091990B5C1EC34A40DA3BA3AD4AFE424058C9C7EE02BF4A40D026874F3AF9424058C9C7EE02BF4A40
60526	Садовый	1	16	1270	37.982548999999999	37.995241999999998	53.545113000000001	53.535508	0103000020E61000000100000005000000D7DB662AC4FD4240895FB1868BC44A40D7DB662AC4FD4240EECF4543C6C54A4085CD001764FF4240EECF4543C6C54A4085CD001764FF4240895FB1868BC44A40D7DB662AC4FD4240895FB1868BC44A40
60580	Победа	1	16	1270	37.900398000000003	37.917923999999999	53.569808000000002	53.558652000000002	0103000020E6100000010000000500000021B1DD3D40F3424029ECA2E881C74A4021B1DD3D40F34240E57FF277EFC84A40541B9C887EF54240E57FF277EFC84A40541B9C887EF5424029ECA2E881C74A4021B1DD3D40F3424029ECA2E881C74A40
47473	Панарино	1	16	1270	37.831730999999998	37.853856	53.492533999999999	53.476196999999999	0103000020E61000000100000005000000E108522976EA424006BAF605F4BC4A40E108522976EA42408315A75A0BBF4A4027BF45274BED42408315A75A0BBF4A4027BF45274BED424006BAF605F4BC4A40E108522976EA424006BAF605F4BC4A40
47721	Никитское	1	16	1270	38.122596000000001	38.199806000000002	53.551473999999999	53.535524000000002	0103000020E610000001000000050000006A4FC939B10F43408F1CE90C8CC44A406A4FC939B10F4340124C35B396C64A40B5C5353E93194340124C35B396C64A40B5C5353E931943408F1CE90C8CC44A406A4FC939B10F43408F1CE90C8CC44A40
13998	Непрядва	1	16	1270	38.233592000000002	38.321410999999998	53.551265000000001	53.537643000000003	0103000020E61000000100000005000000BA4DB857E61D434030F65E7CD1C44A40BA4DB857E61D4340F836FDD98FC64A408EC9E2FE23294340F836FDD98FC64A408EC9E2FE2329434030F65E7CD1C44A40BA4DB857E61D434030F65E7CD1C44A40
47752	Красный Холм	1	16	1270	38.111080000000001	38.141263000000002	53.590342	53.572391000000003	0103000020E61000000100000005000000AE9E93DE370E43402BC3B81B44C94A40AE9E93DE370E434045BA9F5390CB4A404391EEE71412434045BA9F5390CB4A404391EEE7141243402BC3B81B44C94A40AE9E93DE370E43402BC3B81B44C94A40
14198	Красная Дубровка	1	16	1270	37.886159999999997	37.909641999999998	53.400007000000002	53.383966999999998	0103000020E61000000100000005000000FD82DDB06DF1424022DFA5D425B14A40FD82DDB06DF14240E695EB6D33B34A40B58828266FF44240E695EB6D33B34A40B58828266FF4424022DFA5D425B14A40FD82DDB06DF1424022DFA5D425B14A40
14105	Казачка	1	16	1270	38.056578999999999	38.080043000000003	53.368834999999997	53.358620000000002	0103000020E61000000100000005000000F8510DFB3D07434084D89942E7AD4A40F8510DFB3D074340614F3BFC35AF4A400AA359D93E0A4340614F3BFC35AF4A400AA359D93E0A434084D89942E7AD4A40F8510DFB3D07434084D89942E7AD4A40
13347	Истленьево	1	16	1270	37.846975	37.869424000000002	53.549467999999997	53.523614999999999	0103000020E61000000100000005000000CAC342AD69EC4240F758FAD005C34A40CAC342AD69EC42406919A9F754C64A40C32D1F4949EF42406919A9F754C64A40C32D1F4949EF4240F758FAD005C34A40CAC342AD69EC4240F758FAD005C34A40
47587	Горный	1	16	1270	38.079127	38.092979	53.398992	53.388323	0103000020E61000000100000005000000849D62D5200A43406EA46C91B4B14A40849D62D5200A4340CDAE7B2B12B34A407E1B62BCE60B4340CDAE7B2B12B34A407E1B62BCE60B43406EA46C91B4B14A40849D62D5200A43406EA46C91B4B14A40
47640	Волово	1	16	1270	37.980294000000001	38.021166999999998	53.574342999999999	53.547257999999999	0103000020E61000000100000005000000863B17467AFD4240B83CD68C0CC64A40863B17467AFD4240E0D7481284C94A409160AA99B5024340E0D7481284C94A409160AA99B5024340B83CD68C0CC64A40863B17467AFD4240B83CD68C0CC64A40
13640	Верхоупье	1	16	1270	37.899912999999998	37.943373000000001	53.616368000000001	53.595751	0103000020E61000000100000005000000641F645930F3424097C79A9141CC4A40641F645930F3424085268925E5CE4A40F7764B72C0F8424085268925E5CE4A40F7764B72C0F8424097C79A9141CC4A40641F645930F3424097C79A9141CC4A40
47546	Борятино	1	16	1270	38.151485999999998	38.163164000000002	53.414355	53.405423999999996	0103000020E61000000100000005000000A3E6ABE463134340BA8102EFE4B34A40A3E6ABE46313434090F7AA9509B54A4039F1D58EE214434090F7AA9509B54A4039F1D58EE2144340BA8102EFE4B34A40A3E6ABE463134340BA8102EFE4B34A40
40532	Белый Колодезь	1	16	1270	38.198979999999999	38.227609000000001	53.498286999999998	53.486961999999998	0103000020E610000001000000050000006F47382D78194340873254C554BE4A406F47382D78194340CF8250DEC7BF4A403CA3AD4A221D4340CF8250DEC7BF4A403CA3AD4A221D4340873254C554BE4A406F47382D78194340873254C554BE4A40
13252	Баскаково	1	16	1270	37.907772999999999	37.933608999999997	53.480296000000003	53.467095999999998	0103000020E610000001000000050000008D98D9E731F44240D40B3ECDC9BB4A408D98D9E731F442402733DE567ABD4A402920ED7F80F742402733DE567ABD4A402920ED7F80F74240D40B3ECDC9BB4A408D98D9E731F44240D40B3ECDC9BB4A40
47995	Алексеевка	1	16	1270	38.088369999999998	38.106183999999999	53.599677999999997	53.587611000000003	0103000020E6100000010000000500000048F949B54F0B43408BE255D636CB4A4048F949B54F0B4340BA10AB3FC2CC4A40E2ADF36F970D4340BA10AB3FC2CC4A40E2ADF36F970D43408BE255D636CB4A4048F949B54F0B43408BE255D636CB4A40
12541	Тулубьево	1	16	777	38.285621999999996	38.301388000000003	54.465857999999997	54.455798999999999	0103000020E610000001000000050000005182FE428F2443405646239F573A4B405182FE428F2443403C4A253CA13B4B4014B4C9E1932643403C4A253CA13B4B4014B4C9E1932643405646239F573A4B405182FE428F2443405646239F573A4B40
5483	Теплое	1	16	777	38.476649000000002	38.490178	54.293204000000003	54.286192999999997	0103000020E61000000100000005000000E7559DD5023D43400CACE3F8A1244B40E7559DD5023D434038876BB587254B40FE9B1727BE3E434038876BB587254B40FE9B1727BE3E43400CACE3F8A1244B40E7559DD5023D43400CACE3F8A1244B40
12518	Студенец	1	16	777	38.103057999999997	38.12088	54.443491999999999	54.435062000000002	0103000020E61000000100000005000000ABCB2901310D4340BEDD921CB0374B40ABCB2901310D4340D1048A58C4384B40C85EEFFE780F4340D1048A58C4384B40C85EEFFE780F4340BEDD921CB0374B40ABCB2901310D4340BEDD921CB0374B40
12822	Сетка	1	16	777	38.165823000000003	38.186259999999997	54.674793000000001	54.663046999999999	0103000020E610000001000000050000005AF624B039154340FF5A5EB9DE544B405AF624B039154340ED48F59D5F564B40C746205ED7174340ED48F59D5F564B40C746205ED7174340FF5A5EB9DE544B405AF624B039154340FF5A5EB9DE544B40
45745	Рассвет	1	16	777	38.137445	38.154018999999998	54.31082	54.301464000000003	0103000020E61000000100000005000000D6FF39CC97114340EF75525F96264B40D6FF39CC97114340AB7823F3C8274B4037FB03E5B6134340AB7823F3C8274B4037FB03E5B6134340EF75525F96264B40D6FF39CC97114340EF75525F96264B40
47353	Прудищи	1	16	777	38.419328	38.444884999999999	54.399551000000002	54.390205000000002	0103000020E610000001000000050000000726378AAC3543402BDEC83CF2314B400726378AAC354340C40AB77C24334B4090BDDEFDF1384340C40AB77C24334B4090BDDEFDF13843402BDEC83CF2314B400726378AAC3543402BDEC83CF2314B40
12963	Поветкино	1	16	777	38.354892	38.383018	54.335887999999997	54.322961999999997	0103000020E6100000010000000500000057CEDE196D2D4340E5EC9DD156294B4057CEDE196D2D4340368FC360FE2A4B40C1E3DBBB06314340368FC360FE2A4B40C1E3DBBB06314340E5EC9DD156294B4057CEDE196D2D4340E5EC9DD156294B40
60565	Островки	1	16	777	38.466489000000003	38.48742	54.271453000000001	54.262472000000002	0103000020E61000000100000005000000CD785BE9B53B4340D00EB8AE98214B40CD785BE9B53B434057B3CEF8BE224B404AB54FC7633E434057B3CEF8BE224B404AB54FC7633E4340D00EB8AE98214B40CD785BE9B53B4340D00EB8AE98214B40
12790	Оленьковский	1	16	777	38.090535000000003	38.114995999999998	54.577486999999998	54.569381999999997	0103000020E610000001000000050000005A12A0A6960B43402D776682E1484B405A12A0A6960B4340BD6E1118EB494B40DD955D30B80E4340BD6E1118EB494B40DD955D30B80E43402D776682E1484B405A12A0A6960B43402D776682E1484B40
60557	Озеренская	1	16	777	38.274428999999998	38.286169999999998	54.372041000000003	54.361629000000001	0103000020E6100000010000000500000078094E7D202343408124ECDB492E4B4078094E7D20234340B5E21B0A9F2F4B40548CF337A1244340B5E21B0A9F2F4B40548CF337A12443408124ECDB492E4B4078094E7D202343408124ECDB492E4B40
12742	Мордвес	1	16	777	38.198476999999997	38.231166999999999	54.588590000000003	54.566307999999999	0103000020E610000001000000050000000C01C0B16719434049BBD1C77C484B400C01C0B1671943405760C8EA564B4B400C7558E1961D43405760C8EA564B4B400C7558E1961D434049BBD1C77C484B400C01C0B16719434049BBD1C77C484B40
12435	Метростроевский	1	16	777	38.188326000000004	38.212338000000003	54.412039999999998	54.400269999999999	0103000020E61000000100000005000000467EFD101B184340F3C81F0C3C334B40467EFD101B18434069520ABABD344B405AD93EE42D1B434069520ABABD344B405AD93EE42D1B4340F3C81F0C3C334B40467EFD101B184340F3C81F0C3C334B40
60621	Козловка	1	16	777	38.355997000000002	38.379855999999997	54.625509999999998	54.613849000000002	0103000020E61000000100000005000000B03C484F912D434056D7A19A924E4B40B03C484F912D434015A930B610504B403D98141F9F30434015A930B610504B403D98141F9F30434056D7A19A924E4B40B03C484F912D434056D7A19A924E4B40
47181	Дьяконово	1	16	777	38.302475000000001	38.340159	54.570295000000002	54.552357999999998	0103000020E61000000100000005000000C66D3480B72643408CD7BCAAB3464B40C66D3480B72643404209336DFF484B40543882548A2B43404209336DFF484B40543882548A2B43408CD7BCAAB3464B40C66D3480B72643408CD7BCAAB3464B40
12170	Грицовский	1	16	777	38.138838	38.171357	54.152546000000001	54.126843000000001	0103000020E6100000010000000500000095B88E71C5114340FF5C34643C104B4095B88E71C51143405C9198A086134B406878B306EF1543405C9198A086134B406878B306EF154340FF5C34643C104B4095B88E71C5114340FF5C34643C104B40
12883	Гати	1	16	777	38.286557000000002	38.317233999999999	54.302892999999997	54.274622999999998	0103000020E610000001000000050000004EB857E6AD2443405DDDB1D826234B404EB857E6AD244340FA97A432C5264B40F296AB1F9B284340FA97A432C5264B40F296AB1F9B2843405DDDB1D826234B404EB857E6AD2443405DDDB1D826234B40
11854	Венев	1	16	777	38.236708999999998	38.282532000000003	54.367545999999997	54.338780999999997	0103000020E610000001000000050000009DD5027B4C1E4340CAC0012D5D2B4B409DD5027B4C1E434047E350BF0B2F4B40680932022A24434047E350BF0B2F4B40680932022A244340CAC0012D5D2B4B409DD5027B4C1E4340CAC0012D5D2B4B40
13068	Бельковский	1	16	777	38.076782000000001	38.095117000000002	54.181641999999997	54.168703999999998	0103000020E61000000100000005000000F37519FED3094340295AB91798154B40F37519FED30943403ECA880B40174B4096253ACB2C0C43403ECA880B40174B4096253ACB2C0C4340295AB91798154B40F37519FED3094340295AB91798154B40
12332	Анишино	1	16	777	37.933194999999998	37.963324999999998	54.320394	54.307600000000001	0103000020E6100000010000000500000036E50AEF72F74240F31FD26F5F274B4036E50AEF72F74240D5EAABAB02294B40A835CD3B4EFB4240D5EAABAB02294B40A835CD3B4EFB4240F31FD26F5F274B4036E50AEF72F74240F31FD26F5F274B40
47153	Аксиньино	1	16	777	38.334831999999999	38.356724	54.509250999999999	54.500165000000003	0103000020E61000000100000005000000BFD364C6DB2A43404BCD1E6805404B40BFD364C6DB2A4340473A03232F414B4062D9CC21A92D4340473A03232F414B4062D9CC21A92D43404BCD1E6805404B40BFD364C6DB2A43404BCD1E6805404B40
60601	Шахтерский	1	16	1094	38.160577000000004	38.175139000000001	53.775632000000002	53.769502000000003	0103000020E61000000100000005000000B2BE81C98D144340721AA20A7FE24A40B2BE81C98D14434094DDCCE847E34A4088A06AF46A16434094DDCCE847E34A4088A06AF46A164340721AA20A7FE24A40B2BE81C98D144340721AA20A7FE24A40
46703	Черняевка	1	16	1094	37.906973999999998	37.932288	53.724476000000003	53.701124	0103000020E6100000010000000500000041295AB917F442406938656EBED94A4041295AB917F44240535E2BA1BBDC4A40043A933655F74240535E2BA1BBDC4A40043A933655F742406938656EBED94A4041295AB917F442406938656EBED94A40
40444	Упертовка	1	16	1094	38.139744999999998	38.152555	53.799086000000003	53.789028999999999	0103000020E61000000100000005000000C763062AE31143403C4CFBE6FEE44A40C763062AE31143408258367348E64A40AFEB17EC861343408258367348E64A40AFEB17EC861343403C4CFBE6FEE44A40C763062AE31143403C4CFBE6FEE44A40
10733	Товарковский	1	16	1094	38.155222999999999	38.241219000000001	53.700153999999998	53.665778000000003	0103000020E61000000100000005000000234BE658DE134340BA32A83638D54A40234BE658DE134340F01472A59ED94A404016A243E01E4340F01472A59ED94A404016A243E01E4340BA32A83638D54A40234BE658DE134340BA32A83638D54A40
46776	Товарково	1	16	1094	38.122318	38.169514999999997	53.723942999999998	53.687342000000001	0103000020E6100000010000000500000027DBC01DA80F4340689599D2FAD74A4027DBC01DA80F434085950A2AAADC4A403997E2AAB215434085950A2AAADC4A403997E2AAB2154340689599D2FAD74A4027DBC01DA80F4340689599D2FAD74A40
60531	Спасское	1	16	1094	38.257810999999997	38.277132999999999	53.749513999999998	53.743662	0103000020E6100000010000000500000047C66AF3FF20434094A3005130DF4A4047C66AF3FF20434073F22213F0DF4A4039D219187923434073F22213F0DF4A4039D219187923434094A3005130DF4A4047C66AF3FF20434094A3005130DF4A40
11377	Романцевский	1	16	1094	38.317441000000002	38.335290000000001	53.844059000000001	53.828994999999999	0103000020E610000001000000050000006CB41CE8A128434015C616821CEA4A406CB41CE8A12843407E7214200AEC4A40825660C8EA2A43407E7214200AEC4A40825660C8EA2A434015C616821CEA4A406CB41CE8A128434015C616821CEA4A40
60567	Пригородный	1	16	1094	38.094326000000002	38.123413999999997	53.764467000000003	53.748261999999997	0103000020E61000000100000005000000CD94D6DF120C4340766B990CC7DF4A40CD94D6DF120C434085EFFD0DDAE14A402CEFAA07CC0F434085EFFD0DDAE14A402CEFAA07CC0F4340766B990CC7DF4A40CD94D6DF120C4340766B990CC7DF4A40
46494	Папоротка	1	16	1094	38.328544000000001	38.364288000000002	53.645335000000003	53.6175	0103000020E6100000010000000500000005A6D3BA0D2A4340D7A3703D0ACF4A4005A6D3BA0D2A43406AFB57569AD24A40A2293BFDA02E43406AFB57569AD24A40A2293BFDA02E4340D7A3703D0ACF4A4005A6D3BA0D2A4340D7A3703D0ACF4A40
46717	Новопокровское	1	16	1094	38.029727999999999	38.085495999999999	53.802219000000001	53.787018000000003	0103000020E6100000010000000500000043E38920CE03434082AE7D01BDE44A4043E38920CE0343406B9DB81CAFE64A402BF86D88F10A43406B9DB81CAFE64A402BF86D88F10A434082AE7D01BDE44A4043E38920CE03434082AE7D01BDE44A40
51155	Малевка	1	16	1094	38.120511999999998	38.327222999999996	53.622734000000001	53.5959	0103000020E610000001000000050000004563EDEF6C0F4340DCD7817346CC4A404563EDEF6C0F4340BB0D6ABFB5CF4A40DFBF7971E2294340BB0D6ABFB5CF4A40DFBF7971E2294340DCD7817346CC4A404563EDEF6C0F4340DCD7817346CC4A40
60596	Ломовка	1	16	1094	38.061132999999998	38.083303999999998	53.725749	53.679380000000002	0103000020E610000001000000050000006ADAC534D30743403BC780ECF5D64A406ADAC534D3074340670DDE57E5DC4A4020D099B4A90A4340670DDE57E5DC4A4020D099B4A90A43403BC780ECF5D64A406ADAC534D30743403BC780ECF5D64A40
11761	Левинка	1	16	1094	38.181677999999998	38.216183000000001	53.680660000000003	53.660907000000002	0103000020E610000001000000050000008B338639411743404759BF9998D44A408B3386394117434002D9EBDD1FD74A40C07971E2AB1B434002D9EBDD1FD74A40C07971E2AB1B43404759BF9998D44A408B338639411743404759BF9998D44A40
46806	Кузовка	1	16	1094	38.078929000000002	38.154944999999998	53.660662000000002	53.63973	0103000020E610000001000000050000005EDA70581A0A4340922232ACE2D14A405EDA70581A0A4340E0DA899290D44A40E0D6DD3CD5134340E0DA899290D44A40E0D6DD3CD5134340922232ACE2D14A405EDA70581A0A4340922232ACE2D14A40
46621	Колодези	1	16	1094	38.199995000000001	38.288325999999998	53.836621000000001	53.815803000000002	0103000020E61000000100000005000000882EA86F99194340467D923B6CE84A40882EA86F99194340CB129D6516EB4A40124BCADDE7244340CB129D6516EB4A40124BCADDE7244340467D923B6CE84A40882EA86F99194340467D923B6CE84A40
51232	Кобловский	1	16	1094	38.189377	38.204253000000001	53.820624000000002	53.812167000000002	0103000020E61000000100000005000000ABCE6A813D184340FAF19716F5E74A40ABCE6A813D18434007280D350AE94A40118E59F6241A434007280D350AE94A40118E59F6241A4340FAF19716F5E74A40ABCE6A813D184340FAF19716F5E74A40
10929	Кичевский	1	16	1094	38.520567999999997	38.546582999999998	53.644182000000001	53.628906999999998	0103000020E610000001000000050000000CACE3F8A1424340DC9C4A0680D04A400CACE3F8A14243400056478E74D24A4058C6866EF64543400056478E74D24A4058C6866EF6454340DC9C4A0680D04A400CACE3F8A1424340DC9C4A0680D04A40
46684	Иевлево	1	16	1094	37.967781000000002	38.037965999999997	53.773418999999997	53.746718000000001	0103000020E610000001000000050000005858703FE0FB4240D2AA967494DF4A405858703FE0FB4240718DCF64FFE24A40122EE411DC044340718DCF64FFE24A40122EE411DC044340D2AA967494DF4A405858703FE0FB4240D2AA967494DF4A40
47805	Доброе	1	16	1094	38.495171999999997	38.511215999999997	53.648836000000003	53.640765000000002	0103000020E610000001000000050000008CF2CCCB613F4340F2B5679604D24A408CF2CCCB613F4340D63BDC0E0DD34A409198A0866F414340D63BDC0E0DD34A409198A0866F414340F2B5679604D24A408CF2CCCB613F4340F2B5679604D24A40
46465	Гагарино	1	16	1094	38.376154999999997	38.396726000000001	53.713845999999997	53.700543000000003	0103000020E610000001000000050000000A9DD7D8253043408B389D64ABD94A400A9DD7D825304340B130444E5FDB4A4088BCE5EAC7324340B130444E5FDB4A4088BCE5EAC73243408B389D64ABD94A400A9DD7D8253043408B389D64ABD94A40
9692	Богородицк	1	16	1094	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
11118	Бегичевский	1	16	1094	38.228057999999997	38.277897000000003	53.804383000000001	53.789481000000002	0103000020E61000000100000005000000ABCB2901311D43401DE8A1B60DE54A40ABCB2901311D4340AC3AAB05F6E64A400954FF2092234340AC3AAB05F6E64A400954FF20922343401DE8A1B60DE54A40ABCB2901311D43401DE8A1B60DE54A40
46415	Бахметьево	1	16	1094	38.399241000000004	38.435875000000003	53.675423000000002	53.664817999999997	0103000020E61000000100000005000000761C3F541A33434064E597C118D54A40761C3F541A334340ADFBC74274D64A406F1283C0CA374340ADFBC74274D64A406F1283C0CA37434064E597C118D54A40761C3F541A33434064E597C118D54A40
11648	Александринский	1	16	1094	38.065131000000001	38.084282999999999	53.854044999999999	53.845222	0103000020E61000000100000005000000577A6D36560843400BEE073C30EC4A40577A6D3656084340FA27B85851ED4A40EC4D0CC9C90A4340FA27B85851ED4A40EC4D0CC9C90A43400BEE073C30EC4A40577A6D36560843400BEE073C30EC4A40
5958	Фединское	1	16	827	36.180241000000002	36.196330000000003	53.741159000000003	53.729621999999999	0103000020E61000000100000005000000FD321823121742409738F24064DD4A40FD321823121742406B11514CDEDE4A40A29C6857211942406B11514CDEDE4A40A29C6857211942409738F24064DD4A40FD321823121742409738F24064DD4A40
40915	Таратухино	1	16	827	36.168877000000002	36.189278000000002	53.697702	53.686601000000003	0103000020E61000000100000005000000F705F4C29D1542405133A48AE2D74A40F705F4C29D154240492D944C4ED94A4018EDF1423A184240492D944C4ED94A4018EDF1423A1842405133A48AE2D74A40F705F4C29D1542405133A48AE2D74A40
60629	Слобода	1	16	827	35.973269000000002	36.100515000000001	53.880761	53.679758999999997	0103000020E61000000100000005000000F69A1E1494FC4140B114C95702D74A40F69A1E1494FC4140CF4BC5C6BCF04A40F4E0EEACDD0C4240CF4BC5C6BCF04A40F4E0EEACDD0C4240B114C95702D74A40F69A1E1494FC4140B114C95702D74A40
8950	Ровно	1	16	827	36.033231999999998	36.054540000000003	53.782767	53.768889999999999	0103000020E61000000100000005000000209738F240044240581CCEFC6AE24A40209738F240044240ABB184B531E44A407429AE2AFB064240ABB184B531E44A407429AE2AFB064240581CCEFC6AE24A40209738F240044240581CCEFC6AE24A40
14407	Новые Дольцы	1	16	827	36.113002000000002	36.127392999999998	53.615732000000001	53.611587	0103000020E61000000100000005000000F9307BD9760E424052D4997B48CE4A40F9307BD9760E4240E38C614ED0CE4A40A25EF0694E104240E38C614ED0CE4A40A25EF0694E10424052D4997B48CE4A40F9307BD9760E424052D4997B48CE4A40
9241	Кожурово	1	16	827	36.235495999999998	36.258682	53.712955999999998	53.704977999999997	0103000020E610000001000000050000005E2BA1BB241E4240223317B83CDA4A405E2BA1BB241E424055BE672442DB4A402D08E57D1C21424055BE672442DB4A402D08E57D1C214240223317B83CDA4A405E2BA1BB241E4240223317B83CDA4A40
45942	Иваньково	1	16	827	36.057099999999998	36.065049999999999	53.907105999999999	53.901122000000001	0103000020E61000000100000005000000014D840D4F07424062DA37F757F34A40014D840D4F074240B000A60C1CF44A406A4DF38E53084240B000A60C1CF44A406A4DF38E5308424062DA37F757F34A40014D840D4F07424062DA37F757F34A40
45632	Иваново	1	16	827	36.151001000000001	36.174275999999999	53.928386000000003	53.915427000000001	0103000020E61000000100000005000000E7543200541342400D7041B62CF54A40E7543200541342403A083A5AD5F64A40253D0CAD4E1642403A083A5AD5F64A40253D0CAD4E1642400D7041B62CF54A40E7543200541342400D7041B62CF54A40
60550	Жуково	1	16	827	36.161242000000001	36.182163000000003	53.838059999999999	53.825110000000002	0103000020E61000000100000005000000EE5EEE93A314424021CD58349DE94A40EE5EEE93A3144240FA0AD28C45EB4A4048C5FF1D51174240FA0AD28C45EB4A4048C5FF1D5117424021CD58349DE94A40EE5EEE93A314424021CD58349DE94A40
48431	Дубна	1	16	827	35.927768999999998	35.945762999999999	53.781629000000002	53.771838000000002	0103000020E610000001000000050000000E9F7422C1F64140B0E76B96CBE24A400E9F7422C1F64140774D486B0CE44A40286211C30EF94140774D486B0CE44A40286211C30EF94140B0E76B96CBE24A400E9F7422C1F64140B0E76B96CBE24A40
45627	Давыдово	1	16	827	36.124051000000001	36.143203	53.905509000000002	53.896129999999999	0103000020E610000001000000050000009F0436E7E00F4240747B4963B4F24A409F0436E7E00F4240E99D0AB8E7F34A4034D8D47954124240E99D0AB8E7F34A4034D8D47954124240747B4963B4F24A409F0436E7E00F4240747B4963B4F24A40
9321	Будоговищи	1	16	827	36.292727999999997	36.322533999999997	53.582613000000002	53.562444999999997	0103000020E61000000100000005000000CE4F711C782542403C66A032FEC74A40CE4F711C78254240BB9C121093CA4A408DEC4ACB48294240BB9C121093CA4A408DEC4ACB482942403C66A032FEC74A40CE4F711C782542403C66A032FEC74A40
60631	Болото	1	16	827	36.295988999999999	36.334508999999997	53.809769000000003	53.795965000000002	0103000020E61000000100000005000000E57CB1F7E22542405DE15D2EE2E54A40E57CB1F7E22542404628B682A6E74A40DC9BDF30D12A42404628B682A6E74A40DC9BDF30D12A42405DE15D2EE2E54A40E57CB1F7E22542405DE15D2EE2E54A40
40913	Бобрики	1	16	827	36.169029999999999	36.183726	53.670082999999998	53.661622000000001	0103000020E610000001000000050000007D0569C6A215424035289A07B0D44A407D0569C6A2154240834D9D47C5D54A4063B6645584174240834D9D47C5D54A4063B664558417424035289A07B0D44A407D0569C6A215424035289A07B0D44A40
49679	Беляево	1	16	827	36.248449999999998	36.271895999999998	53.648643999999997	53.638278	0103000020E610000001000000050000007958A835CD1F4240CEE0EF17B3D14A407958A835CD1F4240915F3FC406D34A40E4F4F57CCD224240915F3FC406D34A40E4F4F57CCD224240CEE0EF17B3D14A407958A835CD1F4240CEE0EF17B3D14A40
9387	Белев	1	16	827	36.102555000000002	36.168931000000001	53.828527999999999	53.788857999999998	0103000020E610000001000000050000004985B185200D42400F98874CF9E44A404985B185200D4240FFE89B340DEA4A40EA23F0879F154240FFE89B340DEA4A40EA23F0879F1542400F98874CF9E44A404985B185200D42400F98874CF9E44A40
45675	Астафьево	1	16	827	36.308951999999998	36.330817000000003	53.754108000000002	53.743374000000003	0103000020E61000000100000005000000530438BD8B2742402E5915E126DF4A40530438BD8B27424074D3669C86E04A40FDFA2136582A424074D3669C86E04A40FDFA2136582A42402E5915E126DF4A40530438BD8B2742402E5915E126DF4A40
49126	Александровка	1	16	827	36.151971000000003	36.164368000000003	53.764679999999998	53.755609999999997	0103000020E61000000100000005000000607825C973134240E94317D4B7E04A40607825C973134240E0F3C308E1E14A402541B8020A154240E0F3C308E1E14A402541B8020A154240E94317D4B7E04A40607825C973134240E94317D4B7E04A40
47380	Центральный	1	16	453	36.417234000000001	36.436673999999996	53.768777999999998	53.755949999999999	0103000020E61000000100000005000000BF6378EC67354240A2B437F8C2E04A40BF6378EC6735424030F1475167E24A40BA8102EFE437424030F1475167E24A40BA8102EFE4374240A2B437F8C2E04A40BF6378EC67354240A2B437F8C2E04A40
60612	Славный	1	16	453	36.271393000000003	37.038994000000002	53.806897999999997	53.455081999999997	0103000020E6100000010000000500000082AE7D01BD224240C77F812040BA4A4082AE7D01BD224240999A046F48E74A40C05E61C1FD844240999A046F48E74A40C05E61C1FD844240C77F812040BA4A4082AE7D01BD224240C77F812040BA4A40
8857	Рахлеево	1	16	453	36.561763999999997	36.582785000000001	53.768447999999999	53.754443999999999	0103000020E61000000100000005000000FA08FCE1E7474240EB54F99E91E04A40FA08FCE1E74742409B560A815CE24A40B8CCE9B2984A42409B560A815CE24A40B8CCE9B2984A4240EB54F99E91E04A40FA08FCE1E7474240EB54F99E91E04A40
40620	Мокрое	1	16	453	36.814425	36.847724999999997	53.654867000000003	53.643152000000001	0103000020E61000000100000005000000BC0512143F684240B22D03CE52D24A40BC0512143F684240651D8EAED2D34A403480B740826C4240651D8EAED2D34A403480B740826C4240B22D03CE52D24A40BC0512143F684240B22D03CE52D24A40
40873	Меркулово	1	16	453	36.678778999999999	36.704901999999997	53.600532999999999	53.581940000000003	0103000020E61000000100000005000000151BF33AE2564240FC1D8A027DCA4A40151BF33AE25642409A95ED43DECC4A4047718E3A3A5A42409A95ED43DECC4A4047718E3A3A5A4240FC1D8A027DCA4A40151BF33AE2564240FC1D8A027DCA4A40
40877	Манаенки	1	16	453	36.438155999999999	36.47072	53.725754999999999	53.697887999999999	0103000020E61000000100000005000000E945ED7E15384240AB22DC6454D94A40E945ED7E1538424049F4328AE5DC4A405CC98E8D403C424049F4328AE5DC4A405CC98E8D403C4240AB22DC6454D94A40E945ED7E15384240AB22DC6454D94A40
40876	Кузьменки	1	16	453	36.411791000000001	36.434572000000003	53.682532000000002	53.661808999999998	0103000020E61000000100000005000000C1E44691B534424067994528B6D44A40C1E44691B53442409B3C65355DD74A40F0E0270EA03742409B3C65355DD74A40F0E0270EA037424067994528B6D44A40C1E44691B534424067994528B6D44A40
30431	Иста	1	16	453	36.635506999999997	36.653060000000004	53.676020000000001	53.669832999999997	0103000020E6100000010000000500000085B01A4B585142400A647616BDD54A4085B01A4B5851424091B8C7D287D64A40B32957789753424091B8C7D287D64A40B3295778975342400A647616BDD54A4085B01A4B585142400A647616BDD54A40
40795	Варварино	1	16	453	36.540061000000001	36.569741	53.672387999999998	53.654561999999999	0103000020E610000001000000050000002B6C06B820454240289A07B0C8D34A402B6C06B820454240861C5BCF10D64A405D18E945ED484240861C5BCF10D64A405D18E945ED484240289A07B0C8D34A402B6C06B820454240289A07B0C8D34A40
40846	Буревестник	1	16	453	36.570073999999998	36.585444000000003	53.630893999999998	53.616421000000003	0103000020E610000001000000050000006326512FF8484240A8C821E2E6CE4A406326512FF84842400E9F7422C1D04A40D9D138D4EF4A42400E9F7422C1D04A40D9D138D4EF4A4240A8C821E2E6CE4A406326512FF8484240A8C821E2E6CE4A40
9291	Большие Голубочки	1	16	453	36.340662000000002	36.368070000000003	53.541212000000002	53.520173	0103000020E61000000100000005000000B77EFACF9A2B424090A1630795C24A40B77EFACF9A2B4240F419506F46C54A40C251F2EA1C2F4240F419506F46C54A40C251F2EA1C2F424090A1630795C24A40B77EFACF9A2B424090A1630795C24A40
40815	Боброво	1	16	453	36.642828000000002	36.657829999999997	53.706572000000001	53.696784999999998	0103000020E61000000100000005000000FF791A3048524240F3AB394030D94A40FF791A3048524240792288F370DA4A40F12900C633544240792288F370DA4A40F12900C633544240F3AB394030D94A40FF791A3048524240F3AB394030D94A40
47691	Белый Колодезь	1	16	453	36.888517999999998	36.915126000000001	53.696576999999998	53.683374999999998	0103000020E6100000010000000500000023F433F5BA714240B6F3FDD478D74A4023F433F5BA714240A912656F29D94A4012DC48D922754240A912656F29D94A4012DC48D922754240B6F3FDD478D74A4023F433F5BA714240B6F3FDD478D74A40
60506	Арсеньево	1	16	453	36.627485	36.694985000000003	53.745462000000003	53.725515000000001	0103000020E6100000010000000500000083DDB06D51504240F4E0EEACDDDC4A4083DDB06D5150424094347F4C6BDF4A40F41ABB44F558424094347F4C6BDF4A40F41ABB44F5584240F4E0EEACDDDC4A4083DDB06D51504240F4E0EEACDDDC4A40
12077	Араны	1	16	453	36.463982999999999	36.486899000000001	53.593966000000002	53.577427	0103000020E61000000100000005000000327381CB633B4240E869C020E9C94A40327381CB633B4240CD77F01307CC4A4041BAD8B4523E4240CD77F01307CC4A4041BAD8B4523E4240E869C020E9C94A40327381CB633B4240E869C020E9C94A40
51163	Хотманово	1	16	487	37.263969000000003	37.285600000000002	54.570666000000003	54.561870999999996	0103000020E61000000100000005000000341477BCC9A1424010C99063EB474B40341477BCC9A1424036785F950B494B406ADE718A8EA4424036785F950B494B406ADE718A8EA4424010C99063EB474B40341477BCC9A1424010C99063EB474B40
60605	Суходол	1	16	487	37.339975000000003	37.363053000000001	54.444471	54.433914999999999	0103000020E61000000100000005000000933A014D84AB4240361FD7868A374B40933A014D84AB42409D82FC6CE4384B407BDB4C8578AE42409D82FC6CE4384B407BDB4C8578AE4240361FD7868A374B40933A014D84AB4240361FD7868A374B40
46906	Ступино	1	16	487	37.178942999999997	37.192534000000002	54.415246000000003	54.405724999999997	0103000020E610000001000000050000008F6CAE9AE7964240B515FBCBEE334B408F6CAE9AE7964240BDE5EAC726354B401DAF40F4A4984240BDE5EAC726354B401DAF40F4A4984240B515FBCBEE334B408F6CAE9AE7964240B515FBCBEE334B40
8497	Спас-Конино	1	16	487	37.214067	37.231656000000001	54.412820000000004	54.402957999999998	0103000020E610000001000000050000009013268C669B4240AED4B32094334B409013268C669B42403F912749D7344B400AF65FE7A69D42403F912749D7344B400AF65FE7A69D4240AED4B32094334B409013268C669B4240AED4B32094334B40
8405	Солопенки	1	16	487	36.985095999999999	37.009430999999999	54.552598000000003	54.539144999999998	0103000020E61000000100000005000000D0B52FA0177E4240A5660FB402454B40D0B52FA0177E4240E2EA0088BB464B40C748F60835814240E2EA0088BB464B40C748F60835814240A5660FB402454B40D0B52FA0177E4240A5660FB402454B40
49462	Сенево	1	16	487	37.039560000000002	37.057715000000002	54.432794000000001	54.424681	0103000020E61000000100000005000000691D554D10854240C51D6FF25B364B40691D554D10854240D8F335CB65374B408CBE823463874240D8F335CB65374B408CBE823463874240C51D6FF25B364B40691D554D10854240C51D6FF25B364B40
49491	Поповка	1	16	487	37.159602	37.190584999999999	54.347855000000003	54.330753999999999	0103000020E6100000010000000500000027309DD66D944240B682A625562A4B4027309DD66D94424003603C83862C4B40D80DDB166598424003603C83862C4B40D80DDB1665984240B682A625562A4B4027309DD66D944240B682A625562A4B40
8098	Пластово	1	16	487	37.045121000000002	37.062674000000001	54.297901000000003	54.282608000000003	0103000020E6100000010000000500000071AE6186C685424043CBBA7F2C244B4071AE6186C68542400D39B69E21264B409E279EB3058842400D39B69E21264B409E279EB30588424043CBBA7F2C244B4071AE6186C685424043CBBA7F2C244B40
8616	Новогуровский	1	16	487	37.328099000000002	37.349048000000003	54.475023999999998	54.458849999999998	0103000020E61000000100000005000000D76CE525FFA9424082E2C798BB3A4B40D76CE525FFA9424055682096CD3C4B40FB5DD89AADAC424055682096CD3C4B40FB5DD89AADAC424082E2C798BB3A4B40D76CE525FFA9424082E2C798BB3A4B40
8325	Мичурина	1	16	487	36.916778999999998	36.939307999999997	54.458692999999997	54.445962999999999	0103000020E610000001000000050000006D54A70359754240EF1CCA5015394B406D54A70359754240BAF3C473B63A4B40826F9A3E3B784240BAF3C473B63A4B40826F9A3E3B784240EF1CCA5015394B406D54A70359754240EF1CCA5015394B40
46815	Заречье	1	16	487	37.422395000000002	37.431657000000001	54.498471000000002	54.495961000000001	0103000020E61000000100000005000000397F130A11B64240B58B69A67B3F4B40397F130A11B642409180D1E5CD3F4B40740B5D8940B742409180D1E5CD3F4B40740B5D8940B74240B58B69A67B3F4B40397F130A11B64240B58B69A67B3F4B40
8200	Егнышевка	1	16	487	37.185257999999997	37.211165999999999	54.641846999999999	54.624378999999998	0103000020E6100000010000000500000043A9BD88B697424093A7ACA6EB4F4B4043A9BD88B69742409204E10A28524B407903CC7C079B42409204E10A28524B407903CC7C079B424093A7ACA6EB4F4B4043A9BD88B697424093A7ACA6EB4F4B40
8119	Бунырево	1	16	487	37.142471	37.159008999999998	54.591031999999998	54.56317	0103000020E6100000010000000500000070D05E7D3C9242404E0B5EF415484B4070D05E7D3C924240DA71C3EFA64B4B4084622B685A944240DA71C3EFA64B4B4084622B685A9442404E0B5EF415484B4070D05E7D3C9242404E0B5EF415484B40
8227	Ботня	1	16	487	37.195839999999997	37.210087999999999	54.543202999999998	54.531356000000002	0103000020E61000000100000005000000D39FFD48119942404644317903444B40D39FFD4811994240670B08AD87454B401AA4E029E49A4240670B08AD87454B401AA4E029E49A42404644317903444B40D39FFD48119942404644317903444B40
8433	Большое Шелепино	1	16	487	37.152470000000001	37.167893999999997	54.485784000000002	54.477693000000002	0103000020E6100000010000000500000081CF0F23849342409A43520B253D4B4081CF0F2384934240C5758C2B2E3E4B40E998F38C7D954240C5758C2B2E3E4B40E998F38C7D9542409A43520B253D4B4081CF0F23849342409A43520B253D4B40
60568	Берники	1	16	487	37.123373000000001	37.136254999999998	54.299052000000003	54.292405000000002	0103000020E61000000100000005000000CE1ABCAFCA8F4240EC17EC866D254B40CE1ABCAFCA8F4240D6E6FF5547264B404F75C8CD70914240D6E6FF5547264B404F75C8CD70914240EC17EC866D254B40CE1ABCAFCA8F4240EC17EC866D254B40
2910	Алексин	1	16	487	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
60600	Александровка	1	16	487	37.436363999999998	37.450549000000002	54.458060000000003	54.452852	0103000020E610000001000000050000006C938AC6DAB74240CFF6E80DF7394B406C938AC6DAB742408ACDC7B5A13A4B406D1FF296ABB942408ACDC7B5A13A4B406D1FF296ABB94240CFF6E80DF7394B406C938AC6DAB74240CFF6E80DF7394B40
51260	Тула	1	16	7112	37.630257	37.636392000000001	54.197809999999997	54.195766999999996	0103000020E610000001000000050000009C89E942ACD0424069519FE40E194B409C89E942ACD042402F698CD651194B40D0B7054B75D142402F698CD651194B40D0B7054B75D1424069519FE40E194B409C89E942ACD0424069519FE40E194B40
41052	Черкассы	1	15	\N	30.770676000000002	38.326999000000001	58.863194	55.631483000000003	0103000020E61000000100000005000000E6CFB7054BC53E40707D586FD4D04B40E6CFB7054BC53E403D0D18247D6E4D4090696D1ADB2943403D0D18247D6E4D4090696D1ADB294340707D586FD4D04B40E6CFB7054BC53E40707D586FD4D04B40
29318	Удомля	1	15	\N	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
26786	Торжок	1	15	\N	34.899109000000003	35.034790000000001	57.090474999999998	57.008749999999999	0103000020E610000001000000050000000745F3001673414085EB51B81E814C400745F30016734140840D4FAF948B4C402A1DACFF73844140840D4FAF948B4C402A1DACFF7384414085EB51B81E814C400745F3001673414085EB51B81E814C40
1465	Тверь	1	15	\N	35.728442000000001	36.056049000000002	56.927669000000002	56.783239000000002	0103000020E61000000100000005000000348463963DDD4140D3F9F02C41644C40348463963DDD4140AB4198DBBD764C409CFC169D2C074240AB4198DBBD764C409CFC169D2C074240D3F9F02C41644C40348463963DDD4140D3F9F02C41644C40
12814	Ржев	1	15	\N	34.261296000000002	34.385227	56.288725999999997	56.230812	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
5955	Нелидово	1	15	\N	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
40997	Кувшиново	1	15	\N	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
28509	Конаково	1	15	\N	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
27735	Кимры	1	15	\N	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
1349	Кашин	1	15	\N	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
8097	Вышний Волочек	1	15	\N	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
1361	Бежецк	1	15	\N	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
20700	Аввакумово	1	15	\N	35.995601000000001	36.010271000000003	56.884256000000001	56.876063000000002	0103000020E61000000100000005000000B56E83DA6FFF41402A1E17D522704C40B56E83DA6FFF414059A5F44C2F714C40728C648F5001424059A5F44C2F714C40728C648F500142402A1E17D522704C40B56E83DA6FFF41402A1E17D522704C40
31631	Ходуново	1	15	1908	33.449075000000001	33.464984000000001	57.517432999999997	57.507953000000001	0103000020E61000000100000005000000C139234A7BB94040DA73999A04C14C40C139234A7BB94040826F9A3E3BC24C40E694809884BB4040826F9A3E3BC24C40E694809884BB4040DA73999A04C14C40C139234A7BB94040DA73999A04C14C40
31018	Фирово	1	15	1908	33.678306999999997	33.730013999999997	57.495075	57.464818999999999	0103000020E61000000100000005000000EDD286C3D2D640409BC761307FBB4C40EDD286C3D2D640409A081B9E5EBF4C40A2CF471971DD40409A081B9E5EBF4C40A2CF471971DD40409BC761307FBB4C40EDD286C3D2D640409BC761307FBB4C40
31409	Труд	1	15	1908	33.952671000000002	33.976529999999997	57.614927999999999	57.605029999999999	0103000020E610000001000000050000007F6C921FF1F94040A88C7F9F71CD4C407F6C921FF1F9404085B2F0F5B5CE4C400CC85EEFFEFC404085B2F0F5B5CE4C400CC85EEFFEFC4040A88C7F9F71CD4C407F6C921FF1F94040A88C7F9F71CD4C40
31288	Трестино	1	15	1908	33.614724000000002	33.637227000000003	57.264533	57.252679000000001	0103000020E610000001000000050000007D08AA46AFCE404068B114C957A04C407D08AA46AFCE40403CDBA337DCA14C40699082A790D140403CDBA337DCA14C40699082A790D1404068B114C957A04C407D08AA46AFCE404068B114C957A04C40
31111	Сосновка	1	15	1908	33.901538000000002	33.930590000000002	57.454689999999999	57.438645000000001	0103000020E61000000100000005000000F60CE19865F34040E7C6F48425B84C40F60CE19865F34040BCE82B4833BA4C4009FEB7921DF74040BCE82B4833BA4C4009FEB7921DF74040E7C6F48425B84C40F60CE19865F34040E7C6F48425B84C40
31342	Рождество	1	15	1908	33.778478	33.815058000000001	57.611780000000003	57.593204	0103000020E61000000100000005000000E753C72AA5E340409EEDD11BEECB4C40E753C72AA5E34040672C9ACE4ECE4C40ED2B0FD253E84040672C9ACE4ECE4C40ED2B0FD253E840409EEDD11BEECB4C40E753C72AA5E340409EEDD11BEECB4C40
31456	Лесной	1	15	1908	33.758670000000002	33.787686000000001	57.538114999999998	57.526542999999997	0103000020E61000000100000005000000693A3B191CE140400778D2C265C34C40693A3B191CE14040573ECBF3E0C44C402FC214E5D2E44040573ECBF3E0C44C402FC214E5D2E440400778D2C265C34C40693A3B191CE140400778D2C265C34C40
31508	Комсомольский	1	15	1908	33.859309000000003	33.894047	57.662536000000003	57.64978	0103000020E6100000010000000500000049145AD6FDED404025CCB4FD2BD34C4049145AD6FDED40401A36CAFACDD44C40200BD12170F240401A36CAFACDD44C40200BD12170F2404025CCB4FD2BD34C4049145AD6FDED404025CCB4FD2BD34C40
31191	Жуково	1	15	1908	33.819217000000002	33.849750999999998	57.417459999999998	57.396079	0103000020E61000000100000005000000E3A9471ADCE84040F2D077B7B2B24C40E3A9471ADCE84040AFB14B546FB54C40245F09A4C4EC4040AFB14B546FB54C40245F09A4C4EC4040F2D077B7B2B24C40E3A9471ADCE84040F2D077B7B2B24C40
31231	Дубровка	1	15	1908	33.686661000000001	33.703100999999997	57.347994999999997	57.334788000000003	0103000020E610000001000000050000002638F581E4D74040F08B4B55DAAA4C402638F581E4D74040F415A4198BAC4C407764AC36FFD94040F415A4198BAC4C407764AC36FFD94040F08B4B55DAAA4C402638F581E4D74040F08B4B55DAAA4C40
31051	Великооктябрьский	1	15	1908	33.800361000000002	33.829790000000003	57.444361000000001	57.425006000000003	0103000020E6100000010000000500000037FFAF3A72E64040494DBB9866B64C4037FFAF3A72E64040164F3DD2E0B84C402046088F36EA4040164F3DD2E0B84C402046088F36EA4040494DBB9866B64C4037FFAF3A72E64040494DBB9866B64C40
30680	Ряд	1	15	1881	35.062764000000001	35.073669000000002	57.940114999999999	57.927554000000001	0103000020E61000000100000005000000DEAE97A60888414012A3E716BAF64C40DEAE97A60888414051BD35B055F84C4051DD5CFC6D89414051BD35B055F84C4051DD5CFC6D89414012A3E716BAF64C40DEAE97A60888414012A3E716BAF64C40
30550	Порожки	1	15	1881	34.959718000000002	34.976903	57.966380999999998	57.958852	0103000020E61000000100000005000000F7B0170AD87A414023DA8EA9BBFA4C40F7B0170AD87A4140E63C635FB2FB4C40A12E52280B7D4140E63C635FB2FB4C40A12E52280B7D414023DA8EA9BBFA4C40F7B0170AD87A414023DA8EA9BBFA4C40
30015	Попово	1	15	1881	35.288789000000001	35.410744000000001	57.967159000000002	57.898820000000001	0103000020E61000000100000005000000E738B709F7A44140D07EA4880CF34C40E738B709F7A441401B84B9DDCBFB4C409D83674293B441401B84B9DDCBFB4C409D83674293B44140D07EA4880CF34C40E738B709F7A44140D07EA4880CF34C40
30508	Озера	1	15	1881	34.570137000000003	34.574708999999999	58.041595000000001	58.033582000000003	0103000020E61000000100000005000000AA9ECC3FFA484140FDDD3B6A4C044D40AA9ECC3FFA484140AC5626FC52054D40C2DB831090494140AC5626FC52054D40C2DB831090494140FDDD3B6A4C044D40AA9ECC3FFA484140FDDD3B6A4C044D40
30441	Мста	1	15	1881	34.512725000000003	34.528922000000001	57.922392000000002	57.906233	0103000020E61000000100000005000000BA6B09F9A04141402AC76471FFF34C40BA6B09F9A0414140C80BE9F010F64C40451152B7B3434140C80BE9F010F64C40451152B7B34341402AC76471FFF34C40BA6B09F9A04141402AC76471FFF34C40
30356	Молдино	1	15	1881	35.239623999999999	35.260716000000002	57.758177000000003	57.736640000000001	0103000020E6100000010000000500000019ABCDFFAB9E4140757632384ADE4C4019ABCDFFAB9E41402ACAA5F10BE14C40A0C552245FA141402ACAA5F10BE14C40A0C552245FA14140757632384ADE4C4019ABCDFFAB9E4140757632384ADE4C40
30662	Мишнево	1	15	1881	34.960040999999997	34.968791000000003	57.914422999999999	57.909115999999997	0103000020E61000000100000005000000D9E89C9FE27A41409A22C0E95DF44C40D9E89C9FE27A4140E8DA17D00BF54C405FD4EE57017C4140E8DA17D00BF54C405FD4EE57017C41409A22C0E95DF44C40D9E89C9FE27A41409A22C0E95DF44C40
30401	Михайлово	1	15	1881	34.877009999999999	34.892138000000003	57.939928999999999	57.930574	0103000020E61000000100000005000000EA211ADD417041400341800C1DF74C40EA211ADD41704140EFC7ED974FF84C406AC2F69331724140EFC7ED974FF84C406AC2F693317241400341800C1DF74C40EA211ADD417041400341800C1DF74C40
30189	Маслово	1	15	1881	34.849961999999998	34.858226000000002	58.071294999999999	58.066706000000003	0103000020E61000000100000005000000DF6B088ECB6C414037397CD289084D40DF6B088ECB6C414025AFCE3120094D40D8497D59DA6D414025AFCE3120094D40D8497D59DA6D414037397CD289084D40DF6B088ECB6C414037397CD289084D40
30260	Липны	1	15	1881	34.823326999999999	34.837502000000001	58.187989000000002	58.183131000000003	0103000020E61000000100000005000000F77475C76269414020F12BD670174D40F77475C762694140FE80070610184D40D42AFA43336B4140FE80070610184D40D42AFA43336B414020F12BD670174D40F77475C76269414020F12BD670174D40
30863	Лайково-Попово	1	15	1881	35.009988	35.029463	57.850006	57.841346000000001	0103000020E610000001000000050000001DAD6A49478141406A4FC939B1EB4C401DAD6A4947814140AFB321FFCCEC4C4095B88E71C5834140AFB321FFCCEC4C4095B88E71C58341406A4FC939B1EB4C401DAD6A49478141406A4FC939B1EB4C40
30279	Курово	1	15	1881	35.106476000000001	35.126013999999998	58.06174	58.054507000000001	0103000020E610000001000000050000008AE76C01A18D41409833DB15FA064D408AE76C01A18D4140726DA818E7074D40486B0C3A21904140726DA818E7074D40486B0C3A219041409833DB15FA064D408AE76C01A18D41409833DB15FA064D40
30143	Кузьминское	1	15	1881	34.934474999999999	34.951112000000002	58.066020000000002	58.048402000000003	0103000020E61000000100000005000000FDF675E09C774140CF87670932064D40FDF675E09C774140E370E65773084D40A56ABB09BE794140E370E65773084D40A56ABB09BE794140CF87670932064D40FDF675E09C774140CF87670932064D40
30105	Котлован	1	15	1881	34.887835000000003	34.917200999999999	58.088735	58.076096999999997	0103000020E61000000100000005000000419FC893A47141406F29E78BBD094D40419FC893A47141405A8121AB5B0B4D40E36DA5D7667541405A8121AB5B0B4D40E36DA5D7667541406F29E78BBD094D40419FC893A47141406F29E78BBD094D40
30045	Копачево	1	15	1881	34.769624999999998	34.794804999999997	57.900340999999997	57.868344999999998	0103000020E610000001000000050000008D976E12836241409352D0ED25EF4C408D976E1283624140BC1FB75F3EF34C4040D9942BBC654140BC1FB75F3EF34C4040D9942BBC6541409352D0ED25EF4C408D976E12836241409352D0ED25EF4C40
30580	Касково	1	15	1881	35.026857999999997	35.043844999999997	57.994188000000001	57.972667999999999	0103000020E6100000010000000500000067D13B1570834140D0EE906280FC4C4067D13B1570834140AF09698D41FF4C40EB8B84B69C854140AF09698D41FF4C40EB8B84B69C854140D0EE906280FC4C4067D13B1570834140D0EE906280FC4C40
29966	Еремково	1	15	1881	35.263734999999997	35.278925000000001	57.86665	57.854095999999998	0103000020E61000000100000005000000C0E78711C2A141407CD2890453ED4C40C0E78711C2A14140098A1F63EEEE4C40B6847CD0B3A34140098A1F63EEEE4C40B6847CD0B3A341407CD2890453ED4C40C0E78711C2A141407CD2890453ED4C40
30823	Дерягино	1	15	1881	34.851982999999997	34.865422000000002	57.835107999999998	57.826673999999997	0103000020E61000000100000005000000BDDF68C70D6D41400C3A2174D0E94C40BDDF68C70D6D41406150A6D1E4EA4C40959EE925C66E41406150A6D1E4EA4C40959EE925C66E41400C3A2174D0E94C40BDDF68C70D6D41400C3A2174D0E94C40
30757	Выскодня	1	15	1881	35.025699000000003	35.044708	57.778626000000003	57.768177000000001	0103000020E610000001000000050000001C45D61A4A8341400B45BA9F53E24C401C45D61A4A8341405CE84A04AAE34C404EEFE2FDB88541405CE84A04AAE34C404EEFE2FDB88541400B45BA9F53E24C401C45D61A4A8341400B45BA9F53E24C40
29895	Брусово	1	15	1881	35.391070999999997	35.433858000000001	57.865730999999997	57.849938999999999	0103000020E61000000100000005000000FEB4519D0EB24140274C18CDCAEC4C40FEB4519D0EB241401211FE45D0EE4C40D28DB0A888B741401211FE45D0EE4C40D28DB0A888B74140274C18CDCAEC4C40FEB4519D0EB24140274C18CDCAEC4C40
28729	Уварово	1	15	1790	30.918889	30.927710999999999	56.799227000000002	56.786966	0103000020E6100000010000000500000076A73B4F3CEB3E402F88484DBB644C4076A73B4F3CEB3E40448A01124D664C40B323D5777EED3E40448A01124D664C40B323D5777EED3E402F88484DBB644C4076A73B4F3CEB3E402F88484DBB644C40
27875	Торопец	1	15	1790	31.588546999999998	31.689913000000001	56.518681999999998	56.485484999999997	0103000020E61000000100000005000000AE282504AB963F406AD95A5F243E4C40AE282504AB963F400E83F92B64424C40D3156C239EB03F400E83F92B64424C40D3156C239EB03F406AD95A5F243E4C40AE282504AB963F406AD95A5F243E4C40
29215	Талица	1	15	1790	31.768345	31.778568	56.468502999999998	56.462983000000001	0103000020E610000001000000050000008D0B0742B2C43F404FCDE506433B4C408D0B0742B2C43F40F88903E8F73B4C404EB6813B50C73F40F88903E8F73B4C404EB6813B50C73F404FCDE506433B4C408D0B0742B2C43F404FCDE506433B4C40
28976	Скворцово	1	15	1790	31.343737999999998	31.366465999999999	56.457801000000003	56.449030999999998	0103000020E610000001000000050000007764AC36FF573F40F1F109D979394C407764AC36FF573F40BE892139993A4C408F183DB7D05D3F40BE892139993A4C408F183DB7D05D3F40F1F109D979394C407764AC36FF573F40F1F109D979394C40
29062	Речане	1	15	1790	31.621444	31.638539000000002	56.422953	56.417127999999998	0103000020E61000000100000005000000A14B38F4169F3F40791F477364354C40A14B38F4169F3F405F5FEB5223364C407638BA4A77A33F405F5FEB5223364C407638BA4A77A33F40791F477364354C40A14B38F4169F3F40791F477364354C40
28992	Пятницкое	1	15	1790	31.384315000000001	31.408237	56.379935000000003	56.373091000000002	0103000020E61000000100000005000000BC5CC47762623F404AB72572C12F4C40BC5CC47762623F408ACDC7B5A1304C406404543882683F408ACDC7B5A1304C406404543882683F404AB72572C12F4C40BC5CC47762623F404AB72572C12F4C40
29192	Понизовье	1	15	1790	31.818669	31.835557000000001	56.487965000000003	56.470263000000003	0103000020E61000000100000005000000C03FA54A94D13F406AC2F693313C4C40C03FA54A94D13F40DC4B1AA3753E4C40A2F14410E7D53F40DC4B1AA3753E4C40A2F14410E7D53F406AC2F693313C4C40C03FA54A94D13F406AC2F693313C4C40
28436	Пожня	1	15	1790	31.401921999999999	31.425727999999999	56.652141	56.639709000000003	0103000020E61000000100000005000000FC8A355CE4663F407BFA08FCE1514C40FC8A355CE4663F40BCB0355B79534C40D2FD9C82FC6C3F40BCB0355B79534C40D2FD9C82FC6C3F407BFA08FCE1514C40FC8A355CE4663F407BFA08FCE1514C40
28344	Подгороднее	1	15	1790	31.583876	31.612748	56.521844999999999	56.508913	0103000020E6100000010000000500000057EBC4E578953F402FC1A90F24414C4057EBC4E578953F40624A24D1CB424C407DB08C0DDD9C3F40624A24D1CB424C407DB08C0DDD9C3F402FC1A90F24414C4057EBC4E578953F402FC1A90F24414C40
28524	Плоскошь	1	15	1790	31.239507	31.267094	56.787528000000002	56.772927000000003	0103000020E61000000100000005000000BF29AC54503D3F4003999D45EF624C40BF29AC54503D3F409757AEB7CD644C4034F5BA4560443F409757AEB7CD644C4034F5BA4560443F4003999D45EF624C40BF29AC54503D3F4003999D45EF624C40
28685	Пестряково	1	15	1790	31.078547	31.084116000000002	56.691873999999999	56.689413000000002	0103000020E61000000100000005000000EC32FCA71B143F40F83768AF3E584C40EC32FCA71B143F40F279C5538F584C4002124DA088153F40F279C5538F584C4002124DA088153F40F83768AF3E584C40EC32FCA71B143F40F83768AF3E584C40
28887	Озерец	1	15	1790	31.094007000000001	31.109278	56.515906000000001	56.507686	0103000020E610000001000000050000005798BED710183F408B51D7DAFB404C405798BED710183F40B4E7323509424C401B2C9CA4F91B3F40B4E7323509424C401B2C9CA4F91B3F408B51D7DAFB404C405798BED710183F408B51D7DAFB404C40
28408	Нишевицы	1	15	1790	31.480606000000002	31.499604999999999	56.568917999999996	56.560966999999998	0103000020E61000000100000005000000EA42ACFE087B3F404F9143C4CD474C40EA42ACFE087B3F40880D164ED2484C4007EBFF1CE67F3F40880D164ED2484C4007EBFF1CE67F3F404F9143C4CD474C40EA42ACFE087B3F404F9143C4CD474C40
26059	Никольское	1	15	1790	31.451194999999998	31.47306	56.470795000000003	56.465434999999999	0103000020E61000000100000005000000641EF98381733F40F6B4C35F933B4C40641EF98381733F40670FB402433C4C40B70BCD751A793F40670FB402433C4C40B70BCD751A793F40F6B4C35F933B4C40641EF98381733F40F6B4C35F933B4C40
28503	Наговье	1	15	1790	31.551824	31.573294000000001	56.837406000000001	56.820039999999999	0103000020E61000000100000005000000DD257156448D3F40B7B41A12F7684C40DD257156448D3F40B2BCAB1E306B4C4037FE4465C3923F40B2BCAB1E306B4C4037FE4465C3923F40B7B41A12F7684C40DD257156448D3F40B7B41A12F7684C40
28591	Красноселье	1	15	1790	31.325961	31.340468999999999	56.762656	56.753804000000002	0103000020E610000001000000050000007EC51A2E72533F4008CC43A67C604C407EC51A2E72533F40910C39B69E614C40444DF4F928573F40910C39B69E614C40444DF4F928573F4008CC43A67C604C407EC51A2E72533F4008CC43A67C604C40
28825	Кочута	1	15	1790	30.963517	30.980055	56.883468999999998	56.873081999999997	0103000020E61000000100000005000000D923D40CA9F63E40F65CA626C16F4C40D923D40CA9F63E40D1031F8315714C4002486DE2E4FA3E40D1031F8315714C4002486DE2E4FA3E40F65CA626C16F4C40D923D40CA9F63E40F65CA626C16F4C40
28614	Захоломье	1	15	1790	31.280919000000001	31.301886	56.836263000000002	56.829734000000002	0103000020E6100000010000000500000035D3BD4EEA473F408C3045B9346A4C4035D3BD4EEA473F406CED7DAA0A6B4C40C91EA166484D3F406CED7DAA0A6B4C40C91EA166484D3F408C3045B9346A4C4035D3BD4EEA473F408C3045B9346A4C40
29093	Грядцы	1	15	1790	31.899652	31.922909000000001	56.398077000000001	56.391018000000003	0103000020E61000000100000005000000EFC7ED974FE63F40DC12B9E00C324C40EFC7ED974FE63F401825E82FF4324C401F2FA4C343EC3F401825E82FF4324C401F2FA4C343EC3F40DC12B9E00C324C40EFC7ED974FE63F40DC12B9E00C324C40
28903	Выдры	1	15	1790	31.172779999999999	31.191617999999998	56.585582000000002	56.579157000000002	0103000020E610000001000000050000002367614F3B2C3F40EF1F0BD1214A4C402367614F3B2C3F402A90D959F44A4C402E5393E00D313F402A90D959F44A4C402E5393E00D313F40EF1F0BD1214A4C402367614F3B2C3F40EF1F0BD1214A4C40
28767	Волок	1	15	1790	31.144024999999999	31.169232000000001	56.824463999999999	56.812033999999997	0103000020E6100000010000000500000070CE88D2DE243F40BA9EE8BAF0674C4070CE88D2DE243F405B5D4E0988694C40CA6FD1C9522B3F405B5D4E0988694C40CA6FD1C9522B3F40BA9EE8BAF0674C4070CE88D2DE243F40BA9EE8BAF0674C40
41053	дер.Митино	1	15	1463	34.355896999999999	35.405794	57.304398999999997	56.589998000000001	0103000020E610000001000000050000004CDF6B088E2D41404B5AF10D854B4C404CDF6B088E2D4140B1F7E28BF6A64C40DE74CB0EF1B34140B1F7E28BF6A64C40DE74CB0EF1B341404B5AF10D854B4C404CDF6B088E2D41404B5AF10D854B4C40
26687	Яконово	1	15	1463	34.555574999999997	34.584330000000001	57.172786000000002	57.162011	0103000020E61000000100000005000000D3BCE3141D474140CF4BC5C6BC944C40D3BCE3141D474140749A05DA1D964C402D095053CB4A4140749A05DA1D964C402D095053CB4A4140CF4BC5C6BC944C40D3BCE3141D474140CF4BC5C6BC944C40
25860	Тупиково	1	15	1463	34.722301999999999	34.739460000000001	56.988536000000003	56.977235999999998	0103000020E61000000100000005000000EEEA5564745C4140A73CBA11167D4C40EEEA5564745C41409775FF58887E4C409F5912A0A65E41409775FF58887E4C409F5912A0A65E4140A73CBA11167D4C40EEEA5564745C4140A73CBA11167D4C40
26637	Тредубье	1	15	1463	35.179572	35.213859999999997	56.739525	56.728893999999997	0103000020E610000001000000050000007FA31D37FC96414014200A664C5D4C407FA31D37FC96414086C954C1A85E4C4016F6B4C35F9B414086C954C1A85E4C4016F6B4C35F9B414014200A664C5D4C407FA31D37FC96414014200A664C5D4C40
26592	Тверецкий	1	15	1463	34.812294999999999	34.845371	57.272066000000002	57.256948000000001	0103000020E6100000010000000500000027DA5548F9674140E5620CACE3A04C4027DA5548F9674140412D060FD3A24C4050FEEE1D356C4140412D060FD3A24C4050FEEE1D356C4140E5620CACE3A04C4027DA5548F9674140E5620CACE3A04C40
26238	Таложня	1	15	1463	34.515573000000003	34.542630000000003	57.112490000000001	57.100279	0103000020E61000000100000005000000AED9CA4BFE414140E0BC38F1D58C4C40AED9CA4BFE41414043908312668E4C400CEA5BE67445414043908312668E4C400CEA5BE674454140E0BC38F1D58C4C40AED9CA4BFE414140E0BC38F1D58C4C40
26497	Сукромля	1	15	1463	34.723388999999997	34.737501999999999	56.891734999999997	56.884369	0103000020E61000000100000005000000A0A4C002985C4140514CDE0033714C40A0A4C002985C41406AD95A5F24724C40075E2D77665E41406AD95A5F24724C40075E2D77665E4140514CDE0033714C40A0A4C002985C4140514CDE0033714C40
26312	Страшевичи	1	15	1463	34.583548	34.605494	56.826394999999998	56.814360000000001	0103000020E61000000100000005000000B7D26BB3B14A4140D595CFF23C684C40B7D26BB3B14A4140F949B54FC7694C404DF6CFD3804D4140F949B54FC7694C404DF6CFD3804D4140D595CFF23C684C40B7D26BB3B14A4140D595CFF23C684C40
16726	Спирово	1	15	1463	34.459831999999999	34.474348999999997	57.106918	57.099555000000002	0103000020E61000000100000005000000BFD364C6DB3A41409F93DE37BE8C4C40BFD364C6DB3A414047AD307DAF8D4C40F5F1D077B73C414047AD307DAF8D4C40F5F1D077B73C41409F93DE37BE8C4C40BFD364C6DB3A41409F93DE37BE8C4C40
25154	Славный	1	15	1463	35.007660999999999	35.031457000000003	57.096446	57.082653999999998	0103000020E61000000100000005000000323A2009FB80414019710168948A4C40323A2009FB8041403EEAAF57588C4C407A1D71C8068441403EEAAF57588C4C407A1D71C80684414019710168948A4C40323A2009FB80414019710168948A4C40
25829	Селихово	1	15	1463	34.628158999999997	34.658450000000002	57.042357000000003	57.030327999999997	0103000020E6100000010000000500000012D89C83675041409813B4C9E1834C4012D89C8367504140DBE044F46B854C408E06F01648544140DBE044F46B854C408E06F016485441409813B4C9E1834C4012D89C83675041409813B4C9E1834C40
26433	Русино	1	15	1463	34.491247000000001	34.504064999999997	56.798634999999997	56.790911000000001	0103000020E610000001000000050000000AA1832EE13E4140F98557923C654C400AA1832EE13E41407138F3AB39664C407407B133854041407138F3AB39664C407407B13385404140F98557923C654C400AA1832EE13E4140F98557923C654C40
26218	Рудниково	1	15	1463	34.534014999999997	34.555098999999998	57.071716000000002	57.063637	0103000020E610000001000000050000006649809A5A44414064E8D84125884C406649809A5A444140CB4C69FD2D894C406A85E97B0D474140CB4C69FD2D894C406A85E97B0D47414064E8D84125884C406649809A5A44414064E8D84125884C40
26132	Пирогово	1	15	1463	35.068638999999997	35.101399999999998	56.900441999999998	56.885314000000001	0103000020E61000000100000005000000751DAA29C988414071581AF851714C40751DAA29C9884140F0F8F6AE41734C403EE8D9ACFA8C4140F0F8F6AE41734C403EE8D9ACFA8C414071581AF851714C40751DAA29C988414071581AF851714C40
26085	Осташково	1	15	1463	34.618186999999999	34.640008000000002	57.211362000000001	57.200042000000003	0103000020E61000000100000005000000FBE769C0204F4140C9E9EBF99A994C40FBE769C0204F4140FFCEF6E80D9B4C40D5963AC8EB514140FFCEF6E80D9B4C40D5963AC8EB514140C9E9EBF99A994C40FBE769C0204F4140C9E9EBF99A994C40
25921	Мошки	1	15	1463	35.036586999999997	35.057597999999999	56.839950999999999	56.824528000000001	0103000020E61000000100000005000000B83A00E2AE84414072512D228A694C40B83A00E2AE8441400A9FAD83836B4C4052280B5F5F8741400A9FAD83836B4C4052280B5F5F87414072512D228A694C40B83A00E2AE84414072512D228A694C40
25998	Мирный	1	15	1463	35.145659999999999	35.168576000000002	57.008941	56.998866999999997	0103000020E61000000100000005000000ED2AA4FCA4924140DD06B5DFDA7F4C40ED2AA4FCA4924140F94B8BFA24814C40FC71FBE593954140F94B8BFA24814C40FC71FBE593954140DD06B5DFDA7F4C40ED2AA4FCA4924140DD06B5DFDA7F4C40
25765	Маслово	1	15	1463	34.643188000000002	34.663246999999998	57.009126999999999	56.995117	0103000020E61000000100000005000000FF9600FC53524140C9586DFE5F7F4C40FF9600FC535241405B41D3122B814C40C6151747E55441405B41D3122B814C40C6151747E5544140C9586DFE5F7F4C40FF9600FC53524140C9586DFE5F7F4C40
25638	Марьино	1	15	1463	35.255443	35.280749	56.982764000000003	56.972002000000003	0103000020E61000000100000005000000FE7E315BB2A04140C4D2C08F6A7C4C40FE7E315BB2A04140D4D7F335CB7D4C403EB14E95EFA34140D4D7F335CB7D4C403EB14E95EFA34140C4D2C08F6A7C4C40FE7E315BB2A04140C4D2C08F6A7C4C40
26327	Лужково	1	15	1463	34.438147000000001	34.453229999999998	56.855885000000001	56.846730000000001	0103000020E6100000010000000500000096EB6D331538414063450DA6616C4C4096EB6D33153841408811C2A38D6D4C4075C8CD70033A41408811C2A38D6D4C4075C8CD70033A414063450DA6616C4C4096EB6D331538414063450DA6616C4C40
25539	Ладьино	1	15	1463	34.965026999999999	34.988759999999999	56.689408	56.671202000000001	0103000020E61000000100000005000000E5603601867B4140418177F2E9554C40E5603601867B4140E6CC76853E584C40E6CB0BB08F7E4140E6CC76853E584C40E6CB0BB08F7E4140418177F2E9554C40E5603601867B4140418177F2E9554C40
24863	Климово	1	15	1463	35.136713	35.157518000000003	57.125073	57.110359000000003	0103000020E6100000010000000500000012F8C3CF7F914140DEE8633E208E4C4012F8C3CF7F9141406A4E5E6402904C400344C18C299441406A4E5E6402904C400344C18C29944140DEE8633E208E4C4012F8C3CF7F914140DEE8633E208E4C40
26153	Ильино	1	15	1463	34.926363000000002	34.956564999999998	56.908256999999999	56.896951999999999	0103000020E61000000100000005000000BB9C121093764140780AB952CF724C40BB9C12109376414079AEEFC341744C40C6BFCFB8707A414079AEEFC341744C40C6BFCFB8707A4140780AB952CF724C40BB9C121093764140780AB952CF724C40
25677	Зеленый	1	15	1463	35.311551999999999	35.320067999999999	56.936346999999998	56.928975000000001	0103000020E610000001000000050000006F8099EFE0A741409BE61DA7E8764C406F8099EFE0A74140965AEF37DA774C40813FFCFCF7A84140965AEF37DA774C40813FFCFCF7A841409BE61DA7E8764C406F8099EFE0A741409BE61DA7E8764C40
25577	Дудорово	1	15	1463	35.031995999999999	35.049917999999998	56.707244000000003	56.700049	0103000020E6100000010000000500000029CDE671188441407B4CA4349B594C4029CDE671188441406825ADF8865A4C40A9BD88B6638641406825ADF8865A4C40A9BD88B6638641407B4CA4349B594C4029CDE671188441407B4CA4349B594C40
25024	Дубровка	1	15	1463	34.976139000000003	34.986685000000001	57.001064	56.994444999999999	0103000020E61000000100000005000000D2AC6C1FF27C4140DA5548F9497F4C40D2AC6C1FF27C4140FA997ADD22804C40153AAFB14B7E4140FA997ADD22804C40153AAFB14B7E4140DA5548F9497F4C40D2AC6C1FF27C4140DA5548F9497F4C40
25429	Грузины	1	15	1463	35.031250999999997	35.066465000000001	56.945500000000003	56.927771999999997	0103000020E61000000100000005000000D07B6308008441407F129F3BC1764C40D07B6308008441401B2FDD2406794C4011AAD4EC818841401B2FDD2406794C4011AAD4EC818841407F129F3BC1764C40D07B6308008441407F129F3BC1764C40
25377	Глухово	1	15	1463	34.526218	34.548712000000002	57.219672000000003	57.213569999999997	0103000020E610000001000000050000008448861C5B4341400FB40243569B4C408448861C5B43414068EC4B361E9C4C401D76DF313C46414068EC4B361E9C4C401D76DF313C4641400FB40243569B4C408448861C5B4341400FB40243569B4C40
25345	Высокое	1	15	1463	34.878034	34.914380000000001	56.704185000000003	56.691260999999997	0103000020E610000001000000050000005663096B6370414008008E3D7B584C405663096B63704140B9AAECBB225A4C40E90E62670A754140B9AAECBB225A4C40E90E62670A75414008008E3D7B584C405663096B6370414008008E3D7B584C40
25279	Воропуни	1	15	1463	34.697319999999998	34.714640000000003	56.740017999999999	56.734991999999998	0103000020E61000000100000005000000616C21C8415941402B69C537145E4C40616C21C841594140C539EAE8B85E4C40EC34D252795B4140C539EAE8B85E4C40EC34D252795B41402B69C537145E4C40616C21C8415941402B69C537145E4C40
60471	Быльцыно	1	15	1463	34.796323000000001	34.815862000000003	57.187178000000003	57.177137999999999	0103000020E61000000100000005000000BC067DE9ED6541407E703E75AC964C40BC067DE9ED654140EE43DE72F5974C404B06802A6E684140EE43DE72F5974C404B06802A6E6841407E703E75AC964C40BC067DE9ED6541407E703E75AC964C40
25981	Булатниково	1	15	1463	34.941724999999998	34.955818999999998	56.811965999999998	56.808176000000003	0103000020E61000000100000005000000AD69DE718A784140C0B4A84F72674C40AD69DE718A78414062BB7B80EE674C409DF2E846587A414062BB7B80EE674C409DF2E846587A4140C0B4A84F72674C40AD69DE718A784140C0B4A84F72674C40
25113	Будово	1	15	1463	34.899692999999999	34.922618	57.262298000000001	57.234036000000003	0103000020E6100000010000000500000056B8E52329734140180B43E4F49D4C4056B8E5232973414032E719FB92A14C40B859BC581876414032E719FB92A14C40B859BC5818764140180B43E4F49D4C4056B8E52329734140180B43E4F49D4C40
24960	Борисцево	1	15	1463	34.909745000000001	34.930540999999998	57.011538000000002	57.001533999999999	0103000020E610000001000000050000008A592F867274414081EA1F4432804C408A592F8672744140A454C2137A814C40274BADF71B774140A454C2137A814C40274BADF71B77414081EA1F4432804C408A592F867274414081EA1F4432804C40
24871	Большое Святцово	1	15	1463	34.857948	34.884312999999999	57.161507999999998	57.151592999999998	0103000020E6100000010000000500000095D5743DD16D4140B9A6406667934C4095D5743DD16D41406C054D4BAC944C40BD361B2B317141406C054D4BAC944C40BD361B2B31714140B9A6406667934C4095D5743DD16D4140B9A6406667934C40
24796	Большое Петрово	1	15	1463	35.035760000000003	35.052639999999997	57.196902000000001	57.187401999999999	0103000020E61000000100000005000000A3409FC8938441403D9AEAC9FC974C40A3409FC8938441402D42B11534994C40103B53E8BC8641402D42B11534994C40103B53E8BC8641403D9AEAC9FC974C40A3409FC8938441403D9AEAC9FC974C40
26729	Большое Вишенье	1	15	1463	34.658270000000002	34.683036999999999	57.153677999999999	57.137875999999999	0103000020E610000001000000050000000EF8FC30425441409F73B7EBA5914C400EF8FC3042544140AE0E80B8AB934C409E7AA4C16D574140AE0E80B8AB934C409E7AA4C16D5741409F73B7EBA5914C400EF8FC30425441409F73B7EBA5914C40
25233	Богатьково	1	15	1463	34.791131	34.838445	56.706581999999997	56.694285999999998	0103000020E6100000010000000500000007EDD5C7436541400B09185DDE584C4007EDD5C7436541409CF86A47715A4C40533F6F2A526B41409CF86A47715A4C40533F6F2A526B41400B09185DDE584C4007EDD5C7436541400B09185DDE584C40
26525	Альфимово	1	15	1463	34.813032	34.840052999999997	56.857070999999998	56.834215	0103000020E61000000100000005000000FD4CBD6E11684140946A9F8EC76A4C40FD4CBD6E11684140CDACA580B46D4C400EF450DB866B4140CDACA580B46D4C400EF450DB866B4140946A9F8EC76A4C40FD4CBD6E11684140946A9F8EC76A4C40
16512	Сергеевское	1	15	1429	37.389059000000003	37.401563000000003	57.940899000000002	57.936934000000001	0103000020E61000000100000005000000749B70AFCCB1424057410C74EDF74C40749B70AFCCB1424068EBE0606FF84C404F24986A66B3424068EBE0606FF84C404F24986A66B3424057410C74EDF74C40749B70AFCCB1424057410C74EDF74C40
41037	дер.Юрьевское Архангельского С/П	1	15	693	33.758994000000001	35.508237999999999	56.972698000000001	56.291722999999998	0103000020E610000001000000050000001CEE23B726E14040D93EE42D57254C401CEE23B726E140403B71395E817C4C40CF4A5AF10DC141403B71395E817C4C40CF4A5AF10DC14140D93EE42D57254C401CEE23B726E14040D93EE42D57254C40
18956	Степурино	1	15	693	35.252963999999999	35.280920000000002	56.396782000000002	56.385457000000002	0103000020E610000001000000050000005D88D51F61A04140D481ACA756314C405D88D51F61A041401CD2A8C0C9324C406B65C22FF5A341401CD2A8C0C9324C406B65C22FF5A34140D481ACA756314C405D88D51F61A04140D481ACA756314C40
41036	Старица	1	15	693	34.641184000000003	34.913328999999997	56.544341000000003	56.439850999999997	0103000020E61000000100000005000000F75B3B5112524140730E9E094D384C40F75B3B51125241409C6F44F7AC454C4083BEF4F6E77441409C6F44F7AC454C4083BEF4F6E7744140730E9E094D384C40F75B3B5112524140730E9E094D384C40
18295	Рясня	1	15	693	34.396949999999997	34.412590000000002	56.717421000000002	56.708786000000003	0103000020E61000000100000005000000D712F241CF3241406CEEE87FB95A4C40D712F241CF324140583B8A73D45B4C400D54C6BFCF344140583B8A73D45B4C400D54C6BFCF3441406CEEE87FB95A4C40D712F241CF3241406CEEE87FB95A4C40
18417	Родня	1	15	693	34.895595999999998	34.928258999999997	56.379998999999998	56.361733000000001	0103000020E61000000100000005000000D636C5E3A2724140267156444D2E4C40D636C5E3A2724140A0C1A6CEA3304C40DC9BDF30D1764140A0C1A6CEA3304C40DC9BDF30D1764140267156444D2E4C40D636C5E3A2724140267156444D2E4C40
18827	Покровское	1	15	693	34.697445999999999	34.718556	56.478530999999997	56.469751000000002	0103000020E61000000100000005000000EE5C18E945594140B421FFCC203C4C40EE5C18E945594140A38FF980403D4C401B2C9CA4F95B4140A38FF980403D4C401B2C9CA4F95B4140B421FFCC203C4C40EE5C18E945594140B421FFCC203C4C40
18732	Паньково	1	15	693	34.873227999999997	34.886119000000001	56.585894000000003	56.575290000000003	0103000020E61000000100000005000000CAF962EFC56F4140A1DB4B1AA3494C40CAF962EFC56F414019761893FE4A4C409FAEEE586C71414019761893FE4A4C409FAEEE586C714140A1DB4B1AA3494C40CAF962EFC56F4140A1DB4B1AA3494C40
18395	Орлово	1	15	693	34.950501000000003	34.969248999999998	56.449638	56.436884999999997	0103000020E610000001000000050000005CE84A04AA794140758E01D9EB374C405CE84A04AA794140F984ECBC8D394C402157EA59107C4140F984ECBC8D394C402157EA59107C4140758E01D9EB374C405CE84A04AA794140758E01D9EB374C40
18529	Орешки	1	15	693	34.139718000000002	34.167197000000002	56.744070999999998	56.735939999999999	0103000020E61000000100000005000000CE548847E2114140BCE82B48335E4C40CE548847E21141407573F1B73D5F4C40A27E17B6661541407573F1B73D5F4C40A27E17B666154140BCE82B48335E4C40CE548847E2114140BCE82B48335E4C40
49965	Новое	1	15	693	34.692559000000003	35.074424	56.611964	56.526879000000001	0103000020E6100000010000000500000076C6F7C5A55841407FF964C570434C4076C6F7C5A5584140282A1BD6544E4C40CD04C3B986894140282A1BD6544E4C40CD04C3B9868941407FF964C570434C4076C6F7C5A55841407FF964C570434C40
18013	Нестерово	1	15	693	35.317867	35.338439000000001	56.712985000000003	56.706176999999997	0103000020E6100000010000000500000023BDA8DDAFA84140FC170802645A4C4023BDA8DDAFA84140F0C4AC17435B4C4071581AF851AB4140F0C4AC17435B4C4071581AF851AB4140FC170802645A4C4023BDA8DDAFA84140FC170802645A4C40
18213	Луковниково	1	15	693	34.343662000000002	34.367179999999998	56.665964000000002	56.644252000000002	0103000020E610000001000000050000006170CD1DFD2B4140F9307BD976524C406170CD1DFD2B41401C28F04E3E554C4065DF15C1FF2E41401C28F04E3E554C4065DF15C1FF2E4140F9307BD976524C406170CD1DFD2B4140F9307BD976524C40
18118	Красное	1	15	693	34.679901999999998	34.708584999999999	56.607881999999996	56.596212999999999	0103000020E61000000100000005000000143E5B07075741409B3924B5504C4C40143E5B0707574140DDE9CE13CF4D4C40D4B7CCE9B25A4140DDE9CE13CF4D4C40D4B7CCE9B25A41409B3924B5504C4C40143E5B07075741409B3924B5504C4C40
18612	Коньково	1	15	693	34.901327000000002	34.923730999999997	56.515011999999999	56.509072000000003	0103000020E610000001000000050000003B00E2AE5E73414098A7734529414C403B00E2AE5E7341401686C8E9EB414C4093A641D13C7641401686C8E9EB414C4093A641D13C76414098A7734529414C403B00E2AE5E73414098A7734529414C40
18027	Емельяново	1	15	693	35.343181999999999	35.380633000000003	56.615481000000003	56.586013000000001	0103000020E61000000100000005000000B6494563EDAB4140F3035779024B4C40B6494563EDAB41409A27D714C84E4C40A2630795B8B041409A27D714C84E4C40A2630795B8B04140F3035779024B4C40B6494563EDAB4140F3035779024B4C40
17823	Дарьино	1	15	693	34.467351000000001	34.491408	56.640901999999997	56.627974999999999	0103000020E610000001000000050000005F605628D23B414051DA1B7C61504C405F605628D23B414072F8A41309524C40137F1475E63E414072F8A41309524C40137F1475E63E414051DA1B7C61504C405F605628D23B414051DA1B7C61504C40
18930	Гурьево	1	15	693	35.363627000000001	35.387559000000003	56.353689000000003	56.343992	0103000020E61000000100000005000000A7785C548BAE4140F60A0BEE072C4C40A7785C548BAE41403CFA5FAE452D4C409F2287889BB141403CFA5FAE452D4C409F2287889BB14140F60A0BEE072C4C40A7785C548BAE4140F60A0BEE072C4C40
17919	Васильевское	1	15	693	35.151859000000002	35.170121000000002	56.644751999999997	56.632536000000002	0103000020E61000000100000005000000384D9F1D7093414076C58CF0F6504C40384D9F1D70934140EA03C93B87524C4071AE6186C6954140EA03C93B87524C4071AE6186C695414076C58CF0F6504C40384D9F1D7093414076C58CF0F6504C40
17907	Броды	1	15	693	35.269393999999998	35.284387000000002	56.669283	56.657558999999999	0103000020E610000001000000050000008BDEA9807BA241406118B0E42A544C408BDEA9807BA241406762BA10AB554C402B3410CB66A441406762BA10AB554C402B3410CB66A441406118B0E42A544C408BDEA9807BA241406118B0E42A544C40
18195	Братково	1	15	693	34.656007000000002	34.68327	56.570152	56.554547999999997	0103000020E610000001000000050000003A799109F8534140F607CA6DFB464C403A799109F8534140DFDFA0BDFA484C40412B306475574140DFDFA0BDFA484C40412B306475574140F607CA6DFB464C403A799109F8534140F607CA6DFB464C40
17806	Берново	1	15	693	34.687286	34.729695	56.692458000000002	56.676399000000004	0103000020E61000000100000005000000D47FD6FCF85741400806103E94564C40D47FD6FCF857414042EDB776A2584C40018750A5665D414042EDB776A2584C40018750A5665D41400806103E94564C40D47FD6FCF85741400806103E94564C40
18841	Бабынино	1	15	693	35.171478	35.195103000000003	56.447240000000001	56.433948999999998	0103000020E61000000100000005000000E3FDB8FDF2954140E2900DA48B374C40E3FDB8FDF295414045BB0A293F394C40FE2C9622F998414045BB0A293F394C40FE2C9622F9984140E2900DA48B374C40E3FDB8FDF2954140E2900DA48B374C40
18513	Бабино	1	15	693	34.267898000000002	34.300255999999997	56.741815000000003	56.729778000000003	0103000020E61000000100000005000000F8544E7B4A2241408FAB915D695D4C40F8544E7B4A22414054573ECBF35E4C40C136E2C96E26414054573ECBF35E4C40C136E2C96E2641408FAB915D695D4C40F8544E7B4A2241408FAB915D695D4C40
17712	Архангельское	1	15	693	35.234206999999998	35.248508000000001	56.610081999999998	56.604329999999997	0103000020E6100000010000000500000044BFB67EFA9D4140EFFE78AF5A4D4C4044BFB67EFA9D41406BF0BE2A174E4C40AE65321CCF9F41406BF0BE2A174E4C40AE65321CCF9F4140EFFE78AF5A4D4C4044BFB67EFA9D4140EFFE78AF5A4D4C40
16708	Спирово	1	15	1462	34.942740000000001	35.045524999999998	57.435578999999997	57.410145	0103000020E61000000100000005000000C6504EB4AB78414018CFA0A17FB44C40C6504EB4AB78414085E97B0DC1B74C40401361C3D385414085E97B0DC1B74C40401361C3D385414018CFA0A17FB44C40C6504EB4AB78414018CFA0A17FB44C40
17393	Пеньково	1	15	1462	34.992291000000002	35.006906000000001	57.420296	57.408599000000002	0103000020E61000000100000005000000BD8E3864037F4140D316D7F84CB44C40BD8E3864037F4140DF516342CCB54C40B612BA4BE2804140DF516342CCB54C40B612BA4BE2804140D316D7F84CB44C40BD8E3864037F4140D316D7F84CB44C40
17120	Ососье	1	15	1462	35.515182000000003	35.528891000000002	57.611004000000001	57.604880999999999	0103000020E6100000010000000500000073BED87BF1C14140637C98BD6CCD4C4073BED87BF1C14140D3DC0A6135CE4C400A1346B3B2C34140D3DC0A6135CE4C400A1346B3B2C34140637C98BD6CCD4C4073BED87BF1C14140637C98BD6CCD4C40
17497	Новое Ободово	1	15	1462	35.073436000000001	35.086829999999999	57.366486999999999	57.354636999999997	0103000020E61000000100000005000000AE2CD15966894140CC79C6BE64AD4C40AE2CD159668941405FB4C70BE9AE4C40E527D53E1D8B41405FB4C70BE9AE4C40E527D53E1D8B4140CC79C6BE64AD4C40AE2CD15966894140CC79C6BE64AD4C40
17002	Никулино	1	15	1462	35.490434	35.507779999999997	57.513289999999998	57.502571000000003	0103000020E61000000100000005000000596C938AC6BE414082751C3F54C04C40596C938AC6BE414092AE997CB3C14C400CC85EEFFEC0414092AE997CB3C14C400CC85EEFFEC0414082751C3F54C04C40596C938AC6BE414082751C3F54C04C40
17199	Матвеево	1	15	1462	35.110635000000002	35.12932	57.433247999999999	57.422601999999998	0103000020E610000001000000050000008065A549298E4140B29C84D217B64C408065A549298E41405987A3AB74B74C40FF5BC98E8D9041405987A3AB74B74C40FF5BC98E8D904140B29C84D217B64C408065A549298E4140B29C84D217B64C40
17222	Красное Знамя	1	15	1462	35.191536999999997	35.221828000000002	57.434885999999999	57.425063999999999	0103000020E61000000100000005000000AA7CCF48849841407D5A457F68B64C40AA7CCF48849841407FBE2D58AAB74C4026AB22DC649C41407FBE2D58AAB74C4026AB22DC649C41407D5A457F68B64C40AA7CCF48849841407D5A457F68B64C40
17100	Козлово	1	15	1462	35.465989999999998	35.482743999999997	57.578870999999999	57.555168999999999	0103000020E61000000100000005000000AB21718FA5BB414063601DC70FC74C40AB21718FA5BB414029CDE67118CA4C408C2B2E8ECABD414029CDE67118CA4C408C2B2E8ECABD414063601DC70FC74C40AB21718FA5BB414063601DC70FC74C40
16930	Заболотье	1	15	1462	34.727736999999998	34.752260999999997	57.316668	57.307841000000003	0103000020E61000000100000005000000698B6B7C265D414019AF795567A74C40698B6B7C265D414049D8B79388A84C403387A4164A60414049D8B79388A84C403387A4164A60414019AF795567A74C40698B6B7C265D414019AF795567A74C40
17021	Еремеевка	1	15	1462	35.362099999999998	35.384836999999997	57.576293999999997	57.571274000000003	0103000020E61000000100000005000000D8F0F44A59AE41400E87A5811FC94C40D8F0F44A59AE4140C5707500C4C94C4037A5BC5642B14140C5707500C4C94C4037A5BC5642B141400E87A5811FC94C40D8F0F44A59AE41400E87A5811FC94C40
17317	Городок	1	15	1462	35.130648999999998	35.412011	57.528925999999998	57.489677	0103000020E61000000100000005000000A7203F1BB99041403C4D66BCADBE4C40A7203F1BB99041408600E0D8B3C34C40CF4BC5C6BCB441408600E0D8B3C34C40CF4BC5C6BCB441403C4D66BCADBE4C40A7203F1BB99041403C4D66BCADBE4C40
16907	Выдропужск	1	15	1462	34.829129999999999	34.863669999999999	57.374806	57.354657000000003	0103000020E61000000100000005000000F5108DEE206A414014268C6665AD4C40F5108DEE206A41401B2C9CA4F9AF4C40A64412BD8C6E41401B2C9CA4F9AF4C40A64412BD8C6E414014268C6665AD4C40F5108DEE206A414014268C6665AD4C40
17302	Бирючево	1	15	1462	35.280408000000001	35.299694000000002	57.376184000000002	57.366667	0103000020E61000000100000005000000B5C4CA68E4A34140DFC2BAF1EEAE4C40B5C4CA68E4A34140A5A31CCC26B04C405A677C5F5CA64140A5A31CCC26B04C405A677C5F5CA64140DFC2BAF1EEAE4C40B5C4CA68E4A34140DFC2BAF1EEAE4C40
15923	Сонково	1	15	1429	37.130048000000002	37.188536999999997	57.792501999999999	57.768892999999998	0103000020E610000001000000050000008274B169A5904240C98FF8156BE24C408274B169A5904240DE019EB470E54C40008BFCFA21984240DE019EB470E54C40008BFCFA21984240C98FF8156BE24C408274B169A5904240C98FF8156BE24C40
40388	Большое Шереметьево	1	14	137	\N	\N	\N	\N	\N
16103	Пригорки	1	15	1429	37.030271999999997	37.045901999999998	57.760184000000002	57.754570999999999	0103000020E6100000010000000500000004FEF0F3DF83424048C153C895E04C4004FEF0F3DF834240A37895B54DE14C401669E21DE0854240A37895B54DE14C401669E21DE085424048C153C895E04C4004FEF0F3DF83424048C153C895E04C40
16607	Пищалкино	1	15	1429	37.363843000000003	37.378351000000002	57.825577000000003	57.814092000000002	0103000020E6100000010000000500000074F04C6892AE4240B6F7A92A34E84C4074F04C6892AE424037AAD381ACE94C4057B439CE6DB0424037AAD381ACE94C4057B439CE6DB04240B6F7A92A34E84C4074F04C6892AE4240B6F7A92A34E84C40
16505	Петровское	1	15	1429	37.256565999999999	37.268360999999999	57.861130000000003	57.853544999999997	0103000020E61000000100000005000000FDA19927D7A0424008556AF640ED4C40FDA19927D7A0424060CD018239EE4C40CC423BA759A2424060CD018239EE4C40CC423BA759A2424008556AF640ED4C40FDA19927D7A0424008556AF640ED4C40
16311	Новые Горицы	1	15	1429	37.199353000000002	37.209440999999998	57.775353000000003	57.769593	0103000020E6100000010000000500000004AE2B6684994240821DFF0582E24C4004AE2B668499424081ED60C43EE34C4084B872F6CE9A424081ED60C43EE34C4084B872F6CE9A4240821DFF0582E24C4004AE2B6684994240821DFF0582E24C40
16396	Кой	1	15	1429	37.503431999999997	37.543120000000002	57.720852999999998	57.708258000000001	0103000020E6100000010000000500000043E1B37570C04240B090B932A8DA4C4043E1B37570C042409B1C3EE944DC4C40DAE6C6F484C542409B1C3EE944DC4C40DAE6C6F484C54240B090B932A8DA4C4043E1B37570C04240B090B932A8DA4C40
16299	Григорково	1	15	1429	37.242013999999998	37.259172	57.754987999999997	57.747298999999998	0103000020E610000001000000050000004A969350FA9E4240B0AA5E7EA7DF4C404A969350FA9E4240AC6F6072A3E04C40FB04508C2CA14240AC6F6072A3E04C40FB04508C2CA14240B0AA5E7EA7DF4C404A969350FA9E4240B0AA5E7EA7DF4C40
16211	Горка	1	15	1429	36.924846000000002	37.376562999999997	57.84731	57.696402999999997	0103000020E6100000010000000500000010EB8D5A617642400BEBC6BB23D94C4010EB8D5A6176424071C971A774EC4C401BF1643733B0424071C971A774EC4C401BF1643733B042400BEBC6BB23D94C4010EB8D5A617642400BEBC6BB23D94C40
16192	Гладышево	1	15	1429	37.142094	37.156539000000002	57.856169999999999	57.845757999999996	0103000020E610000001000000050000009A7ADD2230924240492A53CC41EC4C409A7ADD22309242407DE882FA96ED4C4037C64E78099442407DE882FA96ED4C4037C64E7809944240492A53CC41EC4C409A7ADD2230924240492A53CC41EC4C40
16413	Вепрь	1	15	1429	37.335312999999999	37.368209	57.739364000000002	57.731983999999997	0103000020E610000001000000050000003A765089EBAA4240FE98D6A6B1DD4C403A765089EBAA42407DEBC37AA3DE4C40E38BF67821AF42407DEBC37AA3DE4C40E38BF67821AF4240FE98D6A6B1DD4C403A765089EBAA4240FE98D6A6B1DD4C40
16011	Беляницы	1	15	1429	36.958460000000002	36.986614000000003	57.702261	57.690083000000001	0103000020E61000000100000005000000184339D1AE7A42404643C6A354D84C40184339D1AE7A4240CD203EB0E3D94C404CE3175E497E4240CD203EB0E3D94C404CE3175E497E42404643C6A354D84C40184339D1AE7A42404643C6A354D84C40
15814	Шуваево	1	15	1327	33.036963999999998	33.060957999999999	56.855034000000003	56.844323000000003	0103000020E610000001000000050000008E90813CBB8440405C21ACC6126C4C408E90813CBB844040EA7B0DC1716D4C40FC36C478CD874040EA7B0DC1716D4C40FC36C478CD8740405C21ACC6126C4C408E90813CBB8440405C21ACC6126C4C40
15734	Хотошино	1	15	1327	33.287818000000001	33.299945999999998	56.907401	56.901366000000003	0103000020E610000001000000050000009E996038D7A44040F9DC09F65F734C409E996038D7A44040C9AD49B725744C4073486AA164A64040C9AD49B725744C4073486AA164A64040F9DC09F65F734C409E996038D7A44040F9DC09F65F734C40
15146	Филистово	1	15	1327	33.373157999999997	33.381540000000001	56.797324000000003	56.788628000000003	0103000020E61000000100000005000000D11E2FA4C3AF4040DE5A26C3F1644C40D11E2FA4C3AF404070287CB60E664C40D40E7F4DD6B0404070287CB60E664C40D40E7F4DD6B04040DE5A26C3F1644C40D11E2FA4C3AF4040DE5A26C3F1644C40
15635	Селище	1	15	1327	33.252470000000002	33.298696999999997	56.897162999999999	56.880184	0103000020E610000001000000050000004E9CDCEF50A04040323B8BDEA9704C404E9CDCEF50A040403317B83CD6724C40E7340BB43BA640403317B83CD6724C40E7340BB43BA64040323B8BDEA9704C404E9CDCEF50A04040323B8BDEA9704C40
14116	Селижарово	1	15	1327	33.424379999999999	33.485987000000002	56.87077	56.832979000000002	0103000020E61000000100000005000000CA89761552B640409DA04D0E9F6A4C40CA89761552B64040412B3064756F4C40FDA36FD234BE4040412B3064756F4C40FDA36FD234BE40409DA04D0E9F6A4C40CA89761552B640409DA04D0E9F6A4C40
15805	Подсосонье	1	15	1327	33.531199000000001	33.541618999999997	56.832191000000002	56.827882000000002	0103000020E610000001000000050000007E552E54FEC340403A799109F8694C407E552E54FEC340404583143C856A4C4034F279C553C540404583143C856A4C4034F279C553C540403A799109F8694C407E552E54FEC340403A799109F8694C40
15628	Ольхово	1	15	1327	33.579608999999998	33.592841	56.719580000000001	56.708252000000002	0103000020E61000000100000005000000CFBBB1A030CA4040CEA96400A85A4C40CFBBB1A030CA4040876D8B321B5C4C402D5DC136E2CB4040876D8B321B5C4C402D5DC136E2CB4040CEA96400A85A4C40CFBBB1A030CA4040CEA96400A85A4C40
15448	Оковцы	1	15	1327	33.468981999999997	33.496254999999998	56.659627	56.641669	0103000020E61000000100000005000000D234289A07BC4040B3EDB43522524C40D234289A07BC4040804754A86E544C40FDBCA94885BF4040804754A86E544C40FDBCA94885BF4040B3EDB43522524C40D234289A07BC4040B3EDB43522524C40
15548	Малое  Ананкино	1	15	1327	33.612506000000003	33.634236000000001	56.609096000000001	56.599578000000001	0103000020E61000000100000005000000494DBB9866CE404057B3CEF8BE4C4C40494DBB9866CE4040ED0F94DBF64D4C4012F92EA52ED14040ED0F94DBF64D4C4012F92EA52ED1404057B3CEF8BE4C4C40494DBB9866CE404057B3CEF8BE4C4C40
15348	Максимково	1	15	1327	33.257598999999999	33.273580000000003	56.650784999999999	56.645589000000001	0103000020E61000000100000005000000BC3D0801F9A0404024D40CA9A2524C40BC3D0801F9A040401ADD41EC4C534C407B6B60AB04A340401ADD41EC4C534C407B6B60AB04A3404024D40CA9A2524C40BC3D0801F9A0404024D40CA9A2524C40
15044	Киселево	1	15	1327	33.787658999999998	33.809497	56.759942000000002	56.751306999999997	0103000020E6100000010000000500000035B39602D2E44040C020E9D32A604C4035B39602D2E44040AD6D8AC745614C40E59A02999DE74040AD6D8AC745614C40E59A02999DE74040C020E9D32A604C4035B39602D2E44040C020E9D32A604C40
15246	Захарово	1	15	1327	33.486210999999997	33.496470000000002	56.834347999999999	56.826985999999998	0103000020E610000001000000050000004CFA7B293CBE4040FB1F60ADDA694C404CFA7B293CBE4040D3BD4EEACB6A4C40FAB836548CBF4040D3BD4EEACB6A4C40FAB836548CBF4040FB1F60ADDA694C404CFA7B293CBE4040FB1F60ADDA694C40
15234	Ельцы	1	15	1327	33.833984999999998	33.85859	56.670732000000001	56.655707999999997	0103000020E61000000100000005000000622D3E05C0EA4040DFDC5F3DEE534C40622D3E05C0EA4040BA30D28BDA554C401956F146E6ED4040BA30D28BDA554C401956F146E6ED4040DFDC5F3DEE534C40622D3E05C0EA4040DFDC5F3DEE534C40
15713	Дубровки	1	15	1327	33.198920999999999	33.217255999999999	56.822823	56.814197	0103000020E610000001000000050000006ABE4A3E769940402BC0779B37684C406ABE4A3E76994040C4B2994352694C400D6E6B0BCF9B4040C4B2994352694C400D6E6B0BCF9B40402BC0779B37684C406ABE4A3E769940402BC0779B37684C40
15534	Дружная Горка	1	15	1327	33.491359000000003	33.501842000000003	56.551322999999996	56.545397999999999	0103000020E6100000010000000500000032CC09DAE4BE4040E3A6069ACF454C4032CC09DAE4BE40402C4487C091464C402FE1D05B3CC040402C4487C091464C402FE1D05B3CC04040E3A6069ACF454C4032CC09DAE4BE4040E3A6069ACF454C40
15127	Дмитрово	1	15	1327	33.311290999999997	33.321083000000002	56.750818000000002	56.741840000000003	0103000020E6100000010000000500000002452C62D8A74040AD6EF59CF45E4C4002452C62D8A74040C39FE1CD1A604C409A266C3F19A94040C39FE1CD1A604C409A266C3F19A94040AD6EF59CF45E4C4002452C62D8A74040AD6EF59CF45E4C40
15053	Гора	1	15	1327	33.218494999999997	33.228619000000002	56.703181999999998	56.695329000000001	0103000020E6100000010000000500000075ABE7A4F79B4040EE7A698A00594C4075ABE7A4F79B4040649126DE015A4C40431F2C63439D4040649126DE015A4C40431F2C63439D4040EE7A698A00594C4075ABE7A4F79B4040EE7A698A00594C40
15330	Большое Кашино	1	15	1327	33.202010999999999	33.209746000000003	56.569304000000002	56.55997	0103000020E610000001000000050000005437177FDB994040DD5ED218AD474C405437177FDB994040B2BD16F4DE484C40C13BF9F4D89A4040B2BD16F4DE484C40C13BF9F4D89A4040DD5ED218AD474C405437177FDB994040DD5ED218AD474C40
14969	Большая Коша	1	15	1327	33.706083	33.731191000000003	56.744110999999997	56.733718000000003	0103000020E610000001000000050000007BA180ED60DA4040473EAF78EA5D4C407BA180ED60DA404003CC7C073F5F4C409510ACAA97DD404003CC7C073F5F4C409510ACAA97DD4040473EAF78EA5D4C407BA180ED60DA4040473EAF78EA5D4C40
41031	станция Торопово	1	15	1317	35.765695000000001	36.902298000000002	58.607571	58.167797	0103000020E61000000100000005000000F9DA334B02E24140F7AE415F7A154D40F9DA334B02E24140BF7FF3E2C44D4D40849F38807E734240BF7FF3E2C44D4D40849F38807E734240F7AE415F7A154D40F9DA334B02E24140F7AE415F7A154D40
14392	Тухани	1	15	1317	36.610272999999999	36.636028000000003	58.539338000000001	58.524267000000002	0103000020E61000000100000005000000DF50F86C1D4E42409FAF592E1B434D40DF50F86C1D4E4240BABE0F0709454D408FAB915D69514240BABE0F0709454D408FAB915D695142409FAF592E1B434D40DF50F86C1D4E42409FAF592E1B434D40
14380	Топалки	1	15	1317	36.141289999999998	36.164403999999998	58.292411000000001	58.278700999999998	0103000020E610000001000000050000003CA06CCA15124240662E7079AC234D403CA06CCA15124240CEFE40B96D254D4071AAB5300B154240CEFE40B96D254D4071AAB5300B154240662E7079AC234D403CA06CCA15124240662E7079AC234D40
14097	Сушигорицы	1	15	1317	36.376092	36.398316000000001	58.403976	58.391874000000001	0103000020E61000000100000005000000C4245CC8233042408C135FED28324D40C4245CC823304240382F4E7CB5334D409DBCC804FC324240382F4E7CB5334D409DBCC804FC3242408C135FED28324D40C4245CC8233042408C135FED28324D40
25924	Стулово	1	15	1317	36.529263	36.539836999999999	58.448017	58.437457000000002	0103000020E61000000100000005000000CEFDD5E3BE43424001344A97FE374D40CEFDD5E3BE434240A986FD9E58394D40DB15FA6019454240A986FD9E58394D40DB15FA601945424001344A97FE374D40CEFDD5E3BE43424001344A97FE374D40
14470	Старое Сандово	1	15	1317	36.584923000000003	36.602871	58.401136999999999	58.386954000000003	0103000020E61000000100000005000000D0D6C1C1DE4A424038876BB587314D40D0D6C1C1DE4A4240971B0C7558334D40795A7EE02A4D4240971B0C7558334D40795A7EE02A4D424038876BB587314D40D0D6C1C1DE4A424038876BB587314D40
14013	Соболины	1	15	1317	36.468950999999997	36.497382000000002	58.459994999999999	58.451425999999998	0103000020E6100000010000000500000097361C96063C42403448C153C8394D4097361C96063C424069A9BC1DE13A4D403ECF9F36AA3F424069A9BC1DE13A4D403ECF9F36AA3F42403448C153C8394D4097361C96063C42403448C153C8394D40
13926	Сандово	1	15	1317	36.393258000000003	36.438462000000001	58.472392999999997	58.447263	0103000020E61000000100000005000000F871344756324240FDDAFAE93F394D40F871344756324240FEEDB25F773C4D40F644D7851F384240FEEDB25F773C4D40F644D7851F384240FDDAFAE93F394D40F871344756324240FDDAFAE93F394D40
22641	Садовая	1	15	1317	36.266928	36.274447000000002	58.351757999999997	58.347985000000001	0103000020E610000001000000050000007F315BB22A224240D13FC1C58A2C4D407F315BB22A2242409D0DF967062D4D401FBE4C14212342409D0DF967062D4D401FBE4C1421234240D13FC1C58A2C4D407F315BB22A224240D13FC1C58A2C4D40
14201	Пнево	1	15	1317	36.351801000000002	36.367818	58.315100000000001	58.306471000000002	0103000020E610000001000000050000009DD9AED0072D4240121615713A274D409DD9AED0072D42401C7C613255284D40A87004A9142F42401C7C613255284D40A87004A9142F4240121615713A274D409DD9AED0072D4240121615713A274D40
14287	Лукино	1	15	1317	36.183070999999998	36.204262	58.451920000000001	58.440618000000001	0103000020E610000001000000050000004AECDADE6E174240B403AE2B66384D404AECDADE6E1742404434BA83D8394D4064E8D841251A42404434BA83D8394D4064E8D841251A4240B403AE2B66384D404AECDADE6E174240B403AE2B66384D40
14564	Ладожское	1	15	1317	36.033096999999998	36.054926000000002	58.428877999999997	58.415559000000002	0103000020E61000000100000005000000404CC2853C0442407C478D0931354D40404CC2853C044240A8FC6B79E5364D409DD9AED007074240A8FC6B79E5364D409DD9AED0070742407C478D0931354D40404CC2853C0442407C478D0931354D40
14299	Кресты	1	15	1317	36.246456000000002	36.267000000000003	58.44455	58.434649	0103000020E6100000010000000500000095F3C5DE8B1F42409B1E1494A2374D4095F3C5DE8B1F4240E9B7AF03E7384D401904560E2D224240E9B7AF03E7384D401904560E2D2242409B1E1494A2374D4095F3C5DE8B1F42409B1E1494A2374D40
14660	Вокшино	1	15	1317	36.742137	36.773659000000002	58.440781999999999	58.427695	0103000020E6100000010000000500000066136058FE5E4240D4D4B2B5BE364D4066136058FE5E42402E55698B6B384D40C7A01342076342402E55698B6B384D40C7A0134207634240D4D4B2B5BE364D4066136058FE5E4240D4D4B2B5BE364D40
14189	Большое Малинское	1	15	1317	36.229666000000002	36.250991999999997	58.340210999999996	58.328904999999999	0103000020E6100000010000000500000067800BB2651D4240D53E1D8F192A4D4067800BB2651D4240A65EB7088C2B4D4060C77F8120204240A65EB7088C2B4D4060C77F8120204240D53E1D8F192A4D4067800BB2651D4240D53E1D8F192A4D40
14576	Березье	1	15	1317	36.660075999999997	36.676775999999997	58.302514000000002	58.291361000000002	0103000020E61000000100000005000000EF6FD05E7D544240392A37514B254D40EF6FD05E7D544240844A5CC7B8264D40DD5B9198A0564240844A5CC7B8264D40DD5B9198A0564240392A37514B254D40EF6FD05E7D544240392A37514B254D40
11766	Шолохово	1	15	928	33.937525000000001	33.969693999999997	56.553396999999997	56.533219000000003	0103000020E610000001000000050000005917B7D100F840408C4D2B8540444C405917B7D100F840402D5A80B6D5464C404F90D8EE1EFC40402D5A80B6D5464C404F90D8EE1EFC40408C4D2B8540444C405917B7D100F840408C4D2B8540444C40
12710	Чертолино	1	15	928	33.859155999999999	33.874670000000002	56.251156999999999	56.244864999999997	0103000020E61000000100000005000000C214E5D2F8ED4040AF777FBC571F4C40C214E5D2F8ED4040AB949EE925204C406B65C22FF5EF4040AB949EE925204C406B65C22FF5EF4040AF777FBC571F4C40C214E5D2F8ED4040AF777FBC571F4C40
12230	Хорошево	1	15	928	34.263964000000001	34.281364000000004	56.258347999999998	56.247391	0103000020E6100000010000000500000022A98592C921414091291F82AA1F4C4022A98592C9214140567E198C11214C40C9224DBC03244140567E198C11214C40C9224DBC0324414091291F82AA1F4C4022A98592C921414091291F82AA1F4C40
7456	Успенское	1	15	928	34.450355000000002	34.467162999999999	56.330739999999999	56.323557999999998	0103000020E61000000100000005000000884B8E3BA5394140F92D3A596A294C40884B8E3BA539414051BD35B0552A4C405C7347FFCB3B414051BD35B0552A4C405C7347FFCB3B4140F92D3A596A294C40884B8E3BA5394140F92D3A596A294C40
11665	Трубино	1	15	928	33.813234000000001	33.842509999999997	56.475230000000003	56.459482000000001	0103000020E6100000010000000500000065FF3C0D18E84040E38C614ED03A4C4065FF3C0D18E84040FF092E56D43C4C40C746205ED7EB4040FF092E56D43C4C40C746205ED7EB4040E38C614ED03A4C4065FF3C0D18E84040E38C614ED03A4C40
11851	Раменское	1	15	928	33.967834000000003	33.992258999999997	56.512090999999998	56.504595999999999	0103000020E610000001000000050000007BFA08FCE1FB4040A1D80A9A96404C407BFA08FCE1FB4040B8C9A8328C414C40B114C95702FF4040B8C9A8328C414C40B114C95702FF4040A1D80A9A96404C407BFA08FCE1FB4040A1D80A9A96404C40
12613	Пятницкое	1	15	928	34.004601999999998	34.030357000000002	56.099153999999999	56.089699000000003	0103000020E6100000010000000500000083BF5FCC96004140F1BDBF417B0B4C4083BF5FCC9600414040A20914B10C4C40331AF9BCE203414040A20914B10C4C40331AF9BCE2034140F1BDBF417B0B4C4083BF5FCC96004140F1BDBF417B0B4C40
11548	Победа	1	15	928	34.256382000000002	34.275120999999999	56.337710999999999	56.324077000000003	0103000020E610000001000000050000003CA41820D12041406231EA5A7B294C403CA41820D1204140EE3F321D3A2B4C40AEB8382A37234140EE3F321D3A2B4C40AEB8382A372341406231EA5A7B294C403CA41820D12041406231EA5A7B294C40
12121	Плешки	1	15	928	34.559086999999998	34.569032	56.350841000000003	56.346710999999999	0103000020E61000000100000005000000334FAE2990474140EC14AB06612C4C40334FAE2990474140488C9E5BE82C4C405130630AD6484140488C9E5BE82C4C405130630AD6484140EC14AB06612C4C40334FAE2990474140EC14AB06612C4C40
11643	Парихино	1	15	928	33.913082000000003	33.944172999999999	56.407570999999997	56.393588999999999	0103000020E610000001000000050000007C48F8DEDFF440405D88D51F61324C407C48F8DEDFF4404025E659492B344C4013622EA9DAF8404025E659492B344C4013622EA9DAF840405D88D51F61324C407C48F8DEDFF440405D88D51F61324C40
12543	Осуга	1	15	928	34.320495000000001	34.334895000000003	56.036994999999997	56.025120000000001	0103000020E6100000010000000500000009C4EBFA05294140DE3CD52137034C4009C4EBFA05294140C98E8D40BC044C40064CE0D6DD2A4140C98E8D40BC044C40064CE0D6DD2A4140DE3CD52137034C4009C4EBFA05294140DE3CD52137034C40
12169	Орехово	1	15	928	34.716301000000001	34.741481	56.315255999999998	56.305554000000001	0103000020E61000000100000005000000CA8B4CC0AF5B4140BC94BA641C274C40CA8B4CC0AF5B414013EF004F5A284C407DCD72D9E85E414013EF004F5A284C407DCD72D9E85E4140BC94BA641C274C40CA8B4CC0AF5B4140BC94BA641C274C40
12027	Озерютино	1	15	928	34.260055999999999	34.269435000000001	56.478889000000002	56.468110000000003	0103000020E610000001000000050000007590D783492141401D774A07EB3B4C407590D7834921414003B5183C4C3D4C40EAB298D87C22414003B5183C4C3D4C40EAB298D87C2241401D774A07EB3B4C407590D783492141401D774A07EB3B4C40
11482	Образцово	1	15	928	34.344380999999998	34.358898000000003	56.321117000000001	56.311810999999999	0103000020E61000000100000005000000902E36AD142C41403BC43F6CE9274C40902E36AD142C41404698A25C1A294C40C74CA25EF02D41404698A25C1A294C40C74CA25EF02D41403BC43F6CE9274C40902E36AD142C41403BC43F6CE9274C40
11754	Михалево	1	15	928	33.882745999999997	33.897029000000003	56.572780999999999	56.560217999999999	0103000020E61000000100000005000000605628D2FDF04040B5503239B5474C40605628D2FDF04040956247E350494C402448A5D8D1F24040956247E350494C402448A5D8D1F24040B5503239B5474C40605628D2FDF04040B5503239B5474C40
12444	Медведево	1	15	928	34.264080999999997	34.286934000000002	56.185076000000002	56.174996	0103000020E610000001000000050000005B3FFD67CD2141402577D84466164C405B3FFD67CD21414023A30392B0174C40240ED940BA24414023A30392B0174C40240ED940BA2441402577D84466164C405B3FFD67CD2141402577D84466164C40
12511	Курьяново	1	15	928	34.250937999999998	34.257998999999998	56.075116999999999	56.067202999999999	0103000020E610000001000000050000006DA983BC1E204140B7989F1B9A084C406DA983BC1E204140D32F116F9D094C404AB3791C06214140D32F116F9D094C404AB3791C06214140B7989F1B9A084C406DA983BC1E204140B7989F1B9A084C40
11928	Кривцово	1	15	928	34.032826999999997	34.049014999999997	56.483671000000001	56.475040999999997	0103000020E6100000010000000500000080B6D5AC330441402BA1BB24CE3C4C4080B6D5AC3304414006836BEEE83D4C40B8019F1F4606414006836BEEE83D4C40B8019F1F460641402BA1BB24CE3C4C4080B6D5AC330441402BA1BB24CE3C4C40
12336	Кокошкино	1	15	928	34.040705000000003	34.072020999999999	56.309323999999997	56.301574000000002	0103000020E6100000010000000500000050E449D23505414076A911FA99264C4050E449D23505414017EFC7ED97274C4007D0EFFB3709414017EFC7ED97274C4007D0EFFB3709414076A911FA99264C4050E449D23505414076A911FA99264C40
11948	Итомля	1	15	928	34.119945999999999	34.154288000000001	56.500129999999999	56.491146000000001	0103000020E610000001000000050000009CA4F9635A0F4140D6C743DFDD3E4C409CA4F9635A0F4140CEDF844204404C4027158DB5BF134140CEDF844204404C4027158DB5BF134140D6C743DFDD3E4C409CA4F9635A0F4140D6C743DFDD3E4C40
12788	Ильченко	1	15	928	33.855274999999999	33.869675000000001	56.343518000000003	56.340031000000003	0103000020E610000001000000050000000F0BB5A679ED40402750C422862B4C400F0BB5A679ED40402ECBD765F82B4C400C93A98251EF40402ECBD765F82B4C400C93A98251EF40402750C422862B4C400F0BB5A679ED40402750C422862B4C40
12658	Звягино	1	15	928	33.936950000000003	33.943174999999997	56.206577000000003	56.201363999999998	0103000020E610000001000000050000005DFE43FAEDF74040BE4BA94BC6194C405DFE43FAEDF740408B8D791D711A4C40D0B359F5B9F840408B8D791D711A4C40D0B359F5B9F84040BE4BA94BC6194C405DFE43FAEDF74040BE4BA94BC6194C40
12260	Заволжский	1	15	928	34.095143	34.111601	56.293871000000003	56.289265	0103000020E61000000100000005000000BFB854A52D0C41405070B1A206254C40BFB854A52D0C4140151F9F909D254C40B7990AF1480E4140151F9F909D254C40B7990AF1480E41405070B1A206254C40BFB854A52D0C41405070B1A206254C40
12344	Домашино	1	15	928	34.304765000000003	34.327978000000002	56.234175	56.219436999999999	0103000020E6100000010000000500000094FB1D8A022741402444F982161C4C4094FB1D8A0227414039454772F91D4C405CE7DF2EFB29414039454772F91D4C405CE7DF2EFB2941402444F982161C4C4094FB1D8A022741402444F982161C4C40
11831	Дмитрово	1	15	928	33.922621999999997	33.950091999999998	56.272665000000003	56.267316999999998	0103000020E61000000100000005000000F9484A7A18F640401955867137224C40F9484A7A18F64040C6E1CCAFE6224C407A185A9D9CF94040C6E1CCAFE6224C407A185A9D9CF940401955867137224C40F9484A7A18F640401955867137224C40
12064	Глебово	1	15	928	34.429603999999998	34.448037999999997	56.370429000000001	56.359110000000001	0103000020E610000001000000050000008A1D8D43FD36414052D50451F72D4C408A1D8D43FD364140B83EAC376A2F4C40C0AE264F59394140B83EAC376A2F4C40C0AE264F5939414052D50451F72D4C408A1D8D43FD36414052D50451F72D4C40
11575	Бахмутово	1	15	928	34.039698999999999	34.053893000000002	56.368011000000003	56.355798999999998	0103000020E610000001000000050000008A5759DB14054140897956D28A2D4C408A5759DB14054140BDC804FC1A2F4C40DE3D40F7E5064140BDC804FC1A2F4C40DE3D40F7E5064140897956D28A2D4C408A5759DB14054140897956D28A2D4C40
12738	Азарово	1	15	928	33.903910000000003	33.923377000000002	56.275078999999998	56.269165999999998	0103000020E610000001000000050000008143A852B3F34040FA980F0874224C408143A852B3F340407F68E6C935234C407670B03731F640407F68E6C935234C407670B03731F64040FA980F0874224C408143A852B3F34040FA980F0874224C40
11282	Рамешки	1	15	1150	36.024571999999999	36.066037999999999	57.352592999999999	57.331007999999997	0103000020E61000000100000005000000DB32E02C25034240705B5B785EAA4C40DB32E02C2503424036E675C421AD4C408925E5EE7308424036E675C421AD4C408925E5EE73084240705B5B785EAA4C40DB32E02C25034240705B5B785EAA4C40
11267	Никольское	1	15	1150	35.889617999999999	35.912174999999998	57.247985	57.238838999999999	0103000020E610000001000000050000006AF7AB00DFF141403201BF46929E4C406AF7AB00DFF141400473F4F8BD9F4C40499D8026C2F441400473F4F8BD9F4C40499D8026C2F441403201BF46929E4C406AF7AB00DFF141403201BF46929E4C40
11186	Некрасово	1	15	1150	36.684465000000003	36.700195000000001	57.379891000000001	57.370103	0103000020E61000000100000005000000DA20938C9C5742406493FC885FAF4C40DA20938C9C574240BA85AE44A0B04C404FE960FD9F594240BA85AE44A0B04C404FE960FD9F5942406493FC885FAF4C40DA20938C9C5742406493FC885FAF4C40
11099	Кушалино	1	15	1150	36.057549000000002	36.088236000000002	57.144224999999999	57.113124999999997	0103000020E61000000100000005000000717500C45D07424014AE47E17A8E4C40717500C45D074240FF21FDF675924C40392A37514B0B4240FF21FDF675924C40392A37514B0B424014AE47E17A8E4C40717500C45D07424014AE47E17A8E4C40
11078	Киверичи	1	15	1150	36.573900999999999	36.613785999999998	57.371147000000001	57.351776999999998	0103000020E610000001000000050000002312859675494240143E5B0707AD4C4023128596754942401781B1BE81AF4C400F5F268A904E42401781B1BE81AF4C400F5F268A904E4240143E5B0707AD4C402312859675494240143E5B0707AD4C40
11013	Ильгощи	1	15	1150	36.482353000000003	36.503535999999997	57.200178999999999	57.193356999999999	0103000020E6100000010000000500000052103CBEBD3D4240F1B913ECBF984C4052103CBEBD3D4240492C29779F994C40E82D1EDE73404240492C29779F994C40E82D1EDE73404240F1B913ECBF984C4052103CBEBD3D4240F1B913ECBF984C40
11002	Застолбье	1	15	1150	36.066029	36.089556000000002	57.213887	57.204172	0103000020E6100000010000000500000036CB65A3730842402461DF4E229A4C4036CB65A373084240100533A6609B4C408E942D92760B4240100533A6609B4C408E942D92760B42402461DF4E229A4C4036CB65A3730842402461DF4E229A4C40
10925	Заклинье	1	15	1150	36.200021999999997	36.226351000000001	57.455204000000002	57.444913	0103000020E61000000100000005000000813D26529A1942405A48C0E8F2B84C40813D26529A1942401381EA1F44BA4C405D35CF11F91C42401381EA1F44BA4C405D35CF11F91C42405A48C0E8F2B84C40813D26529A1942405A48C0E8F2B84C40
10909	Высоково	1	15	1150	35.991325000000003	36.004953	57.324041000000001	57.318038999999999	0103000020E61000000100000005000000865AD3BCE3FE414020ED7F80B5A84C40865AD3BCE3FE414015C8EC2C7AA94C403082C64CA200424015C8EC2C7AA94C403082C64CA200424020ED7F80B5A84C40865AD3BCE3FE414020ED7F80B5A84C40
10832	Ведное	1	15	1150	36.156804000000001	36.179108999999997	57.137642	57.125805999999997	0103000020E61000000100000005000000E5F0492712144240FED137691A904C40E5F04927121442402C47C8409E914C40AAB5300BED1642402C47C8409E914C40AAB5300BED164240FED137691A904C40E5F0492712144240FED137691A904C40
10804	Алешино	1	15	1150	36.368437999999998	36.383367999999997	57.316284000000003	57.301569000000001	0103000020E61000000100000005000000444DF4F9282F4240643E20D099A64C40444DF4F9282F4240C11F7EFE7BA84C409D2ADF3312314240C11F7EFE7BA84C409D2ADF3312314240643E20D099A64C40444DF4F9282F4240643E20D099A64C40
10642	Соблаго	1	15	741	32.589934999999997	32.592557999999997	56.865392	56.863723999999998	0103000020E6100000010000000500000004E275FD824B404099620E828E6E4C4004E275FD824B40402A1C412AC56E4C40D87DC7F0D84B40402A1C412AC56E4C40D87DC7F0D84B404099620E828E6E4C4004E275FD824B404099620E828E6E4C40
10720	Слаутино	1	15	741	32.320943999999997	32.332227000000003	57.067673999999997	57.061557000000001	0103000020E6100000010000000500000078EC67B11429404081EB8A19E1874C4078EC67B1142940400E65A88AA9884C4092EC116A862A40400E65A88AA9884C4092EC116A862A404081EB8A19E1874C4078EC67B11429404081EB8A19E1874C40
10292	Пено	1	15	741	32.701335	32.765788999999998	56.953035	56.903032000000003	0103000020E6100000010000000500000024456458C5594040E99E758D96734C4024456458C5594040C078060DFD794C407A51BB5F05624040C078060DFD794C407A51BB5F05624040E99E758D96734C4024456458C5594040E99E758D96734C40
10620	Охват	1	15	741	32.417341999999998	32.457245	56.783278000000003	56.763159000000002	0103000020E61000000100000005000000A59F70766B354040F452B131AF614C40A59F70766B35404091D6187442644C4038A11001873A404091D6187442644C4038A11001873A4040F452B131AF614C40A59F70766B354040F452B131AF614C40
10568	Мошары	1	15	741	32.840133999999999	32.856807000000003	56.648206999999999	56.638342000000002	0103000020E61000000100000005000000FB20CB82896B4040E5D4CE30B5514C40FB20CB82896B4040E6046D72F8524C40F0FD0DDAAB6D4040E6046D72F8524C40F0FD0DDAAB6D4040E5D4CE30B5514C40FB20CB82896B4040E5D4CE30B5514C40
10541	Заево	1	15	741	32.746583000000001	32.766167000000003	57.003588000000001	56.999073000000003	0103000020E61000000100000005000000F25F2008905F404087A8C29FE17F4C40F25F2008905F40403B54539275804C402123A0C2116240403B54539275804C402123A0C21162404087A8C29FE17F4C40F25F2008905F404087A8C29FE17F4C40
5200	Забелино	1	15	741	32.619193000000003	32.630395	56.996068000000001	56.991031999999997	0103000020E61000000100000005000000C1745AB7414F40400DA5F622DA7E4C40C1745AB7414F4040CB4BFE277F7F4C40ED478AC8B0504040CB4BFE277F7F4C40ED478AC8B05040400DA5F622DA7E4C40C1745AB7414F40400DA5F622DA7E4C40
10760	Жукопа	1	15	741	32.778644	32.794409999999999	56.891675999999997	56.879947999999999	0103000020E61000000100000005000000029D499BAA6340401E17D522A2704C40029D499BAA63404065506D7022724C40C4CE143AAF65404065506D7022724C40C4CE143AAF6540401E17D522A2704C40029D499BAA6340401E17D522A2704C40
10466	Ворошилово	1	15	741	32.222318000000001	32.235038000000003	56.972512000000002	56.964927000000003	0103000020E61000000100000005000000F4A78DEA741C404082035ABA827B4C40F4A78DEA741C4040D97BF1457B7C4C409CA8A5B9151E4040D97BF1457B7C4C409CA8A5B9151E404082035ABA827B4C40F4A78DEA741C404082035ABA827B4C40
41047	турбаза Сокол	1	15	1026	32.376603000000003	33.768597	57.467441999999998	56.865501000000002	0103000020E61000000100000005000000AA49F08634304040E1D39CBCC86E4C40AA49F086343040406F63B323D5BB4C40E066F16261E240406F63B323D5BB4C40E066F16261E24040E1D39CBCC86E4C40AA49F08634304040E1D39CBCC86E4C40
9772	Щучье	1	15	1026	33.406055000000002	33.421587000000002	57.374597000000001	57.363075000000002	0103000020E610000001000000050000004BB0389CF9B34040637FD93D79AE4C404BB0389CF9B34040011764CBF2AF4C409AB51490F6B54040011764CBF2AF4C409AB51490F6B54040637FD93D79AE4C404BB0389CF9B34040637FD93D79AE4C40
9890	Хитино	1	15	1026	32.949818	32.963912999999998	57.104135999999997	57.091546000000001	0103000020E610000001000000050000007993DFA293794040310A82C7B78B4C407993DFA2937940400A2B1554548D4C4039984D80617B40400A2B1554548D4C4039984D80617B4040310A82C7B78B4C407993DFA293794040310A82C7B78B4C40
10205	Сосница	1	15	1026	33.008721000000001	33.018872000000002	57.402810000000002	57.398682999999998	0103000020E61000000100000005000000EBE40CC51D8140404F3C670B08B34C40EBE40CC51D8140403A4030478FB34C40B267CF656A8240403A4030478FB34C40B267CF656A8240404F3C670B08B34C40EBE40CC51D8140404F3C670B08B34C40
9553	Сорога	1	15	1026	33.169825000000003	33.195273999999998	57.178924000000002	57.171708000000002	0103000020E6100000010000000500000088855AD3BC954040153B1A87FA954C4088855AD3BC954040193C4CFBE6964C402AE109BDFE984040193C4CFBE6964C402AE109BDFE984040153B1A87FA954C4088855AD3BC954040153B1A87FA954C40
9375	Сиговка	1	15	1026	33.199917999999997	33.227299000000002	57.102293000000003	57.090431000000002	0103000020E61000000100000005000000DCF0BBE996994040B5C5353E938B4C40DCF0BBE9969940400CCEE0EF178D4C40EEB43522189D40400CCEE0EF178D4C40EEB43522189D4040B5C5353E938B4C40DCF0BBE996994040B5C5353E938B4C40
9585	Святое	1	15	1026	33.338070000000002	33.357959000000001	57.258203999999999	57.250126999999999	0103000020E610000001000000050000001EE1B4E045AB40405D6C5A2904A04C401EE1B4E045AB404023D923D40CA14C408927BB99D1AD404023D923D40CA14C408927BB99D1AD40405D6C5A2904A04C401EE1B4E045AB40405D6C5A2904A04C40
10091	Свапуще	1	15	1026	32.683988999999997	32.709572999999999	57.271813000000002	57.254241999999998	0103000020E6100000010000000500000070E998F38C57404083A279008BA04C4070E998F38C57404057D0B4C4CAA24C40F38FBE49D35A404057D0B4C4CAA24C40F38FBE49D35A404083A279008BA04C4070E998F38C57404083A279008BA04C40
9390	Рогожа	1	15	1026	33.256656	33.268180999999998	57.100586999999997	57.092689999999997	0103000020E610000001000000050000003D29931ADAA0404047551344DD8B4C403D29931ADAA040408DB3E908E08C4C404C3448C153A240408DB3E908E08C4C404C3448C153A2404047551344DD8B4C403D29931ADAA0404047551344DD8B4C40
8934	Осташков	1	15	1026	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
9869	Новые Ельцы	1	15	1026	32.898344999999999	32.917209999999997	57.286225000000002	57.277943999999998	0103000020E6100000010000000500000037C30DF8FC724040490F43AB93A34C4037C30DF8FC72404018265305A3A44C4036C824236775404018265305A3A44C4036C8242367754040490F43AB93A34C4037C30DF8FC724040490F43AB93A34C40
9654	Мошенка	1	15	1026	33.254930999999999	33.268737999999999	57.366070000000001	57.361035999999999	0103000020E6100000010000000500000048DE3994A1A04040DE567A6D36AE4C4048DE3994A1A04040FB05BB61DBAE4C40A298BC0166A24040FB05BB61DBAE4C40A298BC0166A24040DE567A6D36AE4C4048DE3994A1A04040DE567A6D36AE4C40
49892	Мартюшино	1	15	1026	33.513106999999998	33.527991999999998	57.101526	57.093986000000001	0103000020E61000000100000005000000A12C7C7DADC140401424B6BB078C4C40A12C7C7DADC14040CBD8D0CDFE8C4C405A46EA3D95C34040CBD8D0CDFE8C4C405A46EA3D95C340401424B6BB078C4C40A12C7C7DADC140401424B6BB078C4C40
9459	Зехново	1	15	1026	33.263896000000003	33.277343999999999	57.005828000000001	56.996611999999999	0103000020E61000000100000005000000CAC51858C7A140408C6665FB907F4C40CAC51858C7A1404057B3CEF8BE804C40F4DE180280A3404057B3CEF8BE804C40F4DE180280A340408C6665FB907F4C40CAC51858C7A140408C6665FB907F4C40
10084	Занепречье	1	15	1026	32.896206999999997	32.911056000000002	56.973204000000003	56.963856999999997	0103000020E610000001000000050000001FB935E9B6724040A5828AAA5F7B4C401FB935E9B67240400F2BDCF2917C4C408C69A67B9D7440400F2BDCF2917C4C408C69A67B9D744040A5828AAA5F7B4C401FB935E9B6724040A5828AAA5F7B4C40
9988	Замошье	1	15	1026	33.079768999999999	33.101219999999998	57.104429000000003	57.095531000000001	0103000020E61000000100000005000000081EDFDE358A404089601C5C3A8C4C40081EDFDE358A404083E0F1ED5D8D4C40BED9E6C6F48C404083E0F1ED5D8D4C40BED9E6C6F48C404089601C5C3A8C4C40081EDFDE358A404089601C5C3A8C4C40
9680	Задубье	1	15	1026	32.999198999999997	33.004857999999999	57.298675000000003	57.294497999999997	0103000020E610000001000000050000001399B9C0E57F4040635E471CB2A54C401399B9C0E57F404000917EFB3AA64C40DE8FDB2F9F80404000917EFB3AA64C40DE8FDB2F9F804040635E471CB2A54C401399B9C0E57F4040635E471CB2A54C40
9491	Жданово	1	15	1026	33.529456000000003	33.550908	57.113970999999999	57.106194000000002	0103000020E61000000100000005000000E355D636C5C340400684D6C3978D4C40E355D636C5C34040A1D80A9A968E4C40698D412784C64040A1D80A9A968E4C40698D412784C640400684D6C3978D4C40E355D636C5C340400684D6C3978D4C40
8403	Холмина	1	15	608	33.533929999999998	33.552596999999999	56.168304999999997	56.154721000000002	0103000020E61000000100000005000000382D78D157C440409180D1E5CD134C40382D78D157C440406B60AB048B154C40116F9D7FBBC640406B60AB048B154C40116F9D7FBBC640409180D1E5CD134C40382D78D157C440409180D1E5CD134C40
8761	Холмец	1	15	608	33.342785999999997	33.372377	56.350971000000001	56.341636999999999	0103000020E6100000010000000500000069C36169E0AB4040410DDFC2BA2B4C4069C36169E0AB4040166C239EEC2C4C402C64AE0CAAAF4040166C239EEC2C4C402C64AE0CAAAF4040410DDFC2BA2B4C4069C36169E0AB4040410DDFC2BA2B4C40
8481	Хлебники	1	15	608	33.574703999999997	33.794558000000002	56.277568000000002	56.096578999999998	0103000020E61000000100000005000000B07092E68FC940407D3D5FB35C0C4C40B07092E68FC940404435255987234C4039639813B4E540404435255987234C4039639813B4E540407D3D5FB35C0C4C40B07092E68FC940407D3D5FB35C0C4C40
8214	Толокново	1	15	608	33.758904000000001	33.780175999999997	56.260762999999997	56.247841000000001	0103000020E61000000100000005000000DC662AC423E14040D1CDFE40B91F4C40DC662AC423E14040E08096AE60214C40E28FA2CEDCE34040E08096AE60214C40E28FA2CEDCE34040D1CDFE40B91F4C40DC662AC423E14040D1CDFE40B91F4C40
8576	Татево	1	15	608	33.339480999999999	33.375557000000001	56.174750000000003	56.156095000000001	0103000020E61000000100000005000000834E081D74AB4040D908C4EBFA134C40834E081D74AB4040EE7C3F355E164C405664744012B04040EE7C3F355E164C405664744012B04040D908C4EBFA134C40834E081D74AB4040D908C4EBFA134C40
8603	Тархово	1	15	608	33.215046000000001	33.245652	56.079898999999997	56.059393	0103000020E610000001000000050000005C9198A0869B4040404E98309A074C405C9198A0869B4040D6FD63213A0A4C4037195586719F4040D6FD63213A0A4C4037195586719F4040404E98309A074C405C9198A0869B4040404E98309A074C40
8101	Сады	1	15	608	33.606316	33.627578999999997	56.255087000000003	56.246110999999999	0103000020E6100000010000000500000051853FC39BCD4040CA17B490801F4C4051853FC39BCD40404051D9B0A6204C400454388254D040404051D9B0A6204C400454388254D04040CA17B490801F4C4051853FC39BCD4040CA17B490801F4C40
41049	Отрадное	1	15	608	33.035401	33.9358	56.531495999999997	55.880893999999998	0103000020E61000000100000005000000739F1C05888440400E9F7422C1F04B40739F1C058884404037FA980F08444C4064CC5D4BC8F7404037FA980F08444C4064CC5D4BC8F740400E9F7422C1F04B40739F1C05888440400E9F7422C1F04B40
7795	Оленино	1	15	608	33.465325999999997	33.518003	56.218141000000003	56.198019000000002	0103000020E610000001000000050000003FFD67CD8FBB40404A7EC4AF58194C403FFD67CD8FBB40405875560BEC1B4C406D1D1CEC4DC240405875560BEC1B4C406D1D1CEC4DC240404A7EC4AF58194C403FFD67CD8FBB40404A7EC4AF58194C40
8184	Никулино	1	15	608	33.769261999999998	33.794432	56.219773000000004	56.211357999999997	0103000020E610000001000000050000001C075E2D77E24040BDDF68C70D1B4C401C075E2D77E240409CC58B85211C4C40AC72A1F2AFE540409CC58B85211C4C40AC72A1F2AFE54040BDDF68C70D1B4C401C075E2D77E24040BDDF68C70D1B4C40
7883	Молодой Туд	1	15	608	33.585070999999999	33.642752000000002	56.433287	56.411893999999997	0103000020E61000000100000005000000446B459BE3CA404095B54DF1B8344C40446B459BE3CA40401764CBF275374C4024B891B245D240401764CBF275374C4024B891B245D2404095B54DF1B8344C40446B459BE3CA404095B54DF1B8344C40
7916	Мирный	1	15	608	33.162818000000001	33.190880999999997	56.237336999999997	56.228641000000003	0103000020E610000001000000050000009E996038D79440402BC3B81B441D4C409E996038D7944040BC900E0F611E4C40C136E2C96E984040BC900E0F611E4C40C136E2C96E9840402BC3B81B441D4C409E996038D79440402BC3B81B441D4C40
8004	Козлы	1	15	608	33.329770000000003	33.341951000000002	56.258167999999998	56.252696999999998	0103000020E61000000100000005000000D99942E735AA40400E66136058204C40D99942E735AA4040D66F26A60B214C40D1EAE40CC5AB4040D66F26A60B214C40D1EAE40CC5AB40400E66136058204C40D99942E735AA40400E66136058204C40
8779	Ильенки	1	15	608	33.488736000000003	33.496254999999998	56.335070999999999	56.330041000000001	0103000020E610000001000000050000005E30B8E68EBE404069AB92C83E2A4C405E30B8E68EBE4040446B459BE32A4C40FDBCA94885BF4040446B459BE32A4C40FDBCA94885BF404069AB92C83E2A4C405E30B8E68EBE404069AB92C83E2A4C40
7973	Знаменское	1	15	608	33.207059999999998	33.227370999999998	56.317877000000003	56.302942000000002	0103000020E61000000100000005000000A6272CF1809A4040DC4AAFCDC6264C40A6272CF1809A404047938B31B0284C408787307E1A9D404047938B31B0284C408787307E1A9D4040DC4AAFCDC6264C40A6272CF1809A4040DC4AAFCDC6264C40
8416	Завидово	1	15	608	33.621901999999999	33.650064	56.146391999999999	56.131284999999998	0103000020E6100000010000000500000093A8177C9ACF404049BA66F2CD104C4093A8177C9ACF4040B1321AF9BC124C404A27124C35D34040B1321AF9BC124C404A27124C35D3404049BA66F2CD104C4093A8177C9ACF404049BA66F2CD104C40
8512	Гусево	1	15	608	33.339409000000003	33.367992999999998	56.118375	56.100394999999999	0103000020E61000000100000005000000EA7B0DC171AB404049D74CBED90C4C40EA7B0DC171AB4040FED478E9260F4C40161406651AAF4040FED478E9260F4C40161406651AAF404049D74CBED90C4C40EA7B0DC171AB404049D74CBED90C4C40
8296	Гришино	1	15	608	33.514921999999999	33.535502000000001	56.121115000000003	56.103859	0103000020E61000000100000005000000D6FECEF6E8C14040983270404B0D4C40D6FECEF6E8C140400C0742B2800F4C40A7785C548BC440400C0742B2800F4C40A7785C548BC44040983270404B0D4C40D6FECEF6E8C14040983270404B0D4C40
8694	Городок	1	15	608	33.547279000000003	33.566161000000001	55.945045	55.934809999999999	0103000020E61000000100000005000000D064FF3C0DC64040A4FCA4DAA7F74B40D064FF3C0DC64040C91F0C3CF7F84B40A5A2B1F677C84040C91F0C3CF7F84B40A5A2B1F677C84040A4FCA4DAA7F74B40D064FF3C0DC64040A4FCA4DAA7F74B40
8088	Глазки	1	15	608	33.505201999999997	33.537855999999998	56.225503000000003	56.211317999999999	0103000020E61000000100000005000000D8EF8975AAC040402F87DD770C1B4C40D8EF8975AAC0404030134548DD1C4C408BFA2477D8C4404030134548DD1C4C408BFA2477D8C440402F87DD770C1B4C40D8EF8975AAC040402F87DD770C1B4C40
8687	Воротьково	1	15	608	33.411867000000001	33.427875	55.956536999999997	55.944929000000002	0103000020E610000001000000050000009CA6CF0EB8B440406005F86EF3F84B409CA6CF0EB8B44040FC34EECD6FFA4B4054E3A59BC4B64040FC34EECD6FFA4B4054E3A59BC4B640406005F86EF3F84B409CA6CF0EB8B440406005F86EF3F84B40
8313	Воронино	1	15	608	33.470832000000001	33.498204000000001	56.177906999999998	56.166947	0103000020E6100000010000000500000084F4143944BC40402995F0845E154C4084F4143944BC40405F5D15A8C5164C40425E0F26C5BF40405F5D15A8C5164C40425E0F26C5BF40402995F0845E154C4084F4143944BC40402995F0845E154C40
8851	Большая Каденка	1	15	608	33.315728999999997	33.331646999999997	56.413791000000003	56.402839999999998	0103000020E610000001000000050000000BB3D0CE69A84040A4C2D84290334C400BB3D0CE69A8404088307E1AF7344C408368AD6873AA404088307E1AF7344C408368AD6873AA4040A4C2D84290334C400BB3D0CE69A84040A4C2D84290334C40
3855	Бобровка	1	15	608	33.482708000000002	33.505901999999999	56.270051000000002	56.247781000000003	0103000020E6100000010000000500000040C23060C9BD4040FCC8AD49B71F4C4040C23060C9BD404045A0FA0791224C40917D9065C1C0404045A0FA0791224C40917D9065C1C04040FCC8AD49B71F4C4040C23060C9BD4040FCC8AD49B71F4C40
41045	пос.Заповедный	1	15	804	32.262498999999998	33.241492000000001	56.572899999999997	55.950695000000003	0103000020E61000000100000005000000C91D36919921404041BCAE5FB0F94B40C91D3691992140406FF085C954494C40711FB935E99E40406FF085C954494C40711FB935E99E404041BCAE5FB0F94B40C91D36919921404041BCAE5FB0F94B40
6958	Южный	1	15	804	32.781717	32.803230999999997	56.203637999999998	56.188848999999998	0103000020E6100000010000000500000016DD7A4D0F644040EF703B342C184C4016DD7A4D0F644040861C5BCF101A4C401211FE45D0664040861C5BCF101A4C401211FE45D0664040EF703B342C184C4016DD7A4D0F644040EF703B342C184C40
7092	Старое Кутьево	1	15	804	32.752980000000001	32.766857999999999	56.287002000000001	56.284154000000001	0103000020E6100000010000000500000063450DA661604040888384285F244C4063450DA6616040407CF1457BBC244C4086562767286240407CF1457BBC244C408656276728624040888384285F244C4063450DA661604040888384285F244C40
7278	Селы	1	15	804	33.031160999999997	33.057580000000002	56.298496999999998	56.287726999999997	0103000020E6100000010000000500000090F46915FD8340408D96033DD4244C4090F46915FD834040207A522635264C40AC730CC85E874040207A522635264C40AC730CC85E8740408D96033DD4244C4090F46915FD8340408D96033DD4244C40
7145	Пустое Подлесье	1	15	804	32.748623000000002	32.778751999999997	56.411307000000001	56.404522999999998	0103000020E610000001000000050000004704E3E0D25F40406ABDDF68C7334C404704E3E0D25F4040D5CE30B5A5344C40E8D84125AE634040D5CE30B5A5344C40E8D84125AE6340406ABDDF68C7334C404704E3E0D25F40406ABDDF68C7334C40
7343	Паникля	1	15	804	32.927289000000002	32.953069999999997	56.231048000000001	56.224877999999997	0103000020E610000001000000050000006478EC67B176404081CB63CDC81C4C406478EC67B176404032E719FB921D4C403C66A032FE79404032E719FB921D4C403C66A032FE79404081CB63CDC81C4C406478EC67B176404081CB63CDC81C4C40
7428	Новоселки	1	15	804	32.827916999999999	32.857776999999999	56.072107000000003	56.057403000000001	0103000020E61000000100000005000000B6662B2FF96940409DD843FB58074C40B6662B2FF969404006685BCD3A094C40682101A3CB6D404006685BCD3A094C40682101A3CB6D40409DD843FB58074C40B6662B2FF96940409DD843FB58074C40
5697	Нелидово	1	15	804	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
31769	Монино	1	15	804	32.797697999999997	32.816302	56.068936999999998	56.062690000000003	0103000020E61000000100000005000000D40AD3F71A664040A4E4D53906084C40D40AD3F71A664040FF3D78EDD2084C4067D47C957C684040FF3D78EDD2084C4067D47C957C684040A4E4D53906084C40D40AD3F71A664040A4E4D53906084C40
6984	Межа	1	15	804	32.744732999999997	32.758243999999998	56.212834999999998	56.203857999999997	0103000020E6100000010000000500000040A03369535F40409483D904181A4C4040A03369535F4040DA38622D3E1B4C40B131AF230E614040DA38622D3E1B4C40B131AF230E6140409483D904181A4C4040A03369535F40409483D904181A4C40
32272	Кривцово	1	15	804	32.764288999999998	32.788283	56.112558	56.092033999999998	0103000020E61000000100000005000000A5D8D138D46140405E0F26C5C70B4C40A5D8D138D46140409B73F04C680E4C40137F1475E66440409B73F04C680E4C40137F1475E66440405E0F26C5C70B4C40A5D8D138D46140405E0F26C5C70B4C40
32229	Копейки	1	15	804	32.819823	32.841410000000003	56.037326999999998	56.026287000000004	0103000020E610000001000000050000001AC1C6F5EF684040ADA7565F5D034C401AC1C6F5EF684040FF209221C7044C408143A852B36B4040FF209221C7044C408143A852B36B4040ADA7565F5D034C401AC1C6F5EF684040ADA7565F5D034C40
7555	Земцы	1	15	804	32.335540999999999	32.344577999999998	56.247470999999997	56.242108999999999	0103000020E61000000100000005000000CBBBEA01F32A40409C887E6DFD1E4C40CBBBEA01F32A4040ADDA3521AD1F4C40E675C4211B2C4040ADDA3521AD1F4C40E675C4211B2C40409C887E6DFD1E4C40CBBBEA01F32A40409C887E6DFD1E4C40
6884	Загородный	1	15	804	32.809815999999998	32.816552999999999	56.213059999999999	56.207658000000002	0103000020E6100000010000000500000086E3F90CA86740405B608F89941A4C4086E3F90CA8674040FA0AD28C451B4C40B03907CF84684040FA0AD28C451B4C40B03907CF846840405B608F89941A4C4086E3F90CA86740405B608F89941A4C40
7536	Горки	1	15	804	32.779775999999998	32.801354000000003	56.161347999999997	56.153472000000001	0103000020E61000000100000005000000541A31B3CF634040056D72F8A4134C40541A31B3CF63404033A31F0DA7144C40684293C49266404033A31F0DA7144C40684293C492664040056D72F8A4134C40541A31B3CF634040056D72F8A4134C40
7177	Высокое	1	15	804	32.772635000000001	32.885427	56.397744000000003	56.286082999999998	0103000020E610000001000000050000005B5F24B4E56240408578245E9E244C405B5F24B4E562404012178046E9324C4069FF03AC5571404012178046E9324C4069FF03AC557140408578245E9E244C405B5F24B4E56240408578245E9E244C40
31718	Верхнее Заборье	1	15	804	32.960498999999999	32.972392999999997	56.070121999999998	56.066167999999998	0103000020E610000001000000050000009C6B98A1F17A404057056A3178084C409C6B98A1F17A4040745DF8C1F9084C40FEEDB25F777C4040745DF8C1F9084C40FEEDB25F777C404057056A3178084C409C6B98A1F17A404057056A3178084C40
31704	Арбузово	1	15	804	32.440527000000003	32.454011000000001	56.361469	56.356447000000003	0103000020E61000000100000005000000A400513063384040F0E0270EA02D4C40A40051306338404048C2BE9D442E4C401B834E081D3A404048C2BE9D442E4C401B834E081D3A4040F0E0270EA02D4C40A400513063384040F0E0270EA02D4C40
5620	Черкасово	1	15	697	36.890683000000003	36.909726999999997	58.112053000000003	58.107084999999998	0103000020E61000000100000005000000350D8AE601724240327216F6B40D4D40350D8AE6017242409835B1C0570E4D40E3A430EF717442409835B1C0570E4D40E3A430EF71744240327216F6B40D4D40350D8AE601724240327216F6B40D4D40
5218	Тушитово	1	15	697	36.646242000000001	36.657327000000002	58.212949000000002	58.206667000000003	0103000020E610000001000000050000009CA6CF0EB8524240CB147310741A4D409CA6CF0EB8524240A35BAFE9411B4D408FE3874A23544240A35BAFE9411B4D408FE3874A23544240CB147310741A4D409CA6CF0EB8524240CB147310741A4D40
5354	Рамешки	1	15	697	36.733927000000001	36.751938000000003	58.121808000000001	58.115709000000003	0103000020E610000001000000050000006153E751F15D42402B6D718DCF0E4D406153E751F15D424012329067970F4D40514F1F813F60424012329067970F4D40514F1F813F6042402B6D718DCF0E4D406153E751F15D42402B6D718DCF0E4D40
4959	Покров	1	15	697	36.271357000000002	36.288361999999999	58.202773999999998	58.196351999999997	0103000020E61000000100000005000000354580D3BB2242408940F50F22194D40354580D3BB224240533D997FF4194D405FB4C70BE9244240533D997FF4194D405FB4C70BE92442408940F50F22194D40354580D3BB2242408940F50F22194D40
5513	Подертово	1	15	697	36.646053000000002	36.653851000000003	58.032895000000003	58.030293999999998	0103000020E61000000100000005000000C93D5DDDB1524240ECA17DACE0034D40C93D5DDDB1524240D99942E735044D407CBABA63B1534240D99942E735044D407CBABA63B1534240ECA17DACE0034D40C93D5DDDB1524240ECA17DACE0034D40
5380	Обросово	1	15	697	36.546224000000002	36.562806000000002	58.032604999999997	58.023631000000002	0103000020E61000000100000005000000292504ABEA454240FD15325706034D40292504ABEA454240D15790662C044D400DFFE9060A484240D15790662C044D400DFFE9060A484240FD15325706034D40292504ABEA454240FD15325706034D40
4860	Молоково	1	15	697	36.746737000000003	36.778779	58.174000999999997	58.153728999999998	0103000020E6100000010000000500000049DBF813955F424030B95164AD134D4049DBF813955F4240533C2EAA45164D40E2E7BF07AF634240533C2EAA45164D40E2E7BF07AF63424030B95164AD134D4049DBF813955F424030B95164AD134D40
41022	Карельский Городок	1	15	697	36.494776999999999	36.514082000000002	58.067695999999998	58.054521999999999	0103000020E6100000010000000500000010E84CDA543F4240CD74AF93FA064D4010E84CDA543F4240F6083543AA084D402CBB6070CD414240F6083543AA084D402CBB6070CD414240CD74AF93FA064D4010E84CDA543F4240CD74AF93FA064D40
5038	Деледино	1	15	697	36.904355000000002	36.925232000000001	58.243656999999999	58.238416999999998	0103000020E61000000100000005000000AF7C96E7C1734240BCE7C072841E4D40AF7C96E7C173424082380F27301F4D40399B8E006E76424082380F27301F4D40399B8E006E764240BCE7C072841E4D40AF7C96E7C1734240BCE7C072841E4D40
41021	Биколово	1	15	697	36.570577	36.577638	58.143546000000001	58.139594000000002	0103000020E61000000100000005000000C66CC9AA08494240E25B5837DE114D40C66CC9AA084942405EBC1FB75F124D40A376BF0AF04942405EBC1FB75F124D40A376BF0AF0494240E25B5837DE114D40C66CC9AA08494240E25B5837DE114D40
4945	Ахматово	1	15	697	36.480457999999999	36.500867999999997	58.208725000000001	58.198315999999998	0103000020E61000000100000005000000008DD2A57F3D424003232F6B62194D40008DD2A57F3D4240C66D3480B71A4D4074CE4F711C404240C66D3480B71A4D4074CE4F711C40424003232F6B62194D40008DD2A57F3D424003232F6B62194D40
5541	Антоновское	1	15	697	36.933495999999998	36.949100000000001	58.146614999999997	58.140130999999997	0103000020E61000000100000005000000317903CC7C774240F01307D0EF114D40317903CC7C774240300DC347C4124D401A51DA1B7C794240300DC347C4124D401A51DA1B7C794240F01307D0EF114D40317903CC7C774240F01307D0EF114D40
5124	Андрейцево	1	15	697	36.783442000000001	36.800060999999999	58.286881000000001	58.282007999999998	0103000020E610000001000000050000000B28D4D347644240ED9A90D618244D400B28D4D347644240016C4084B8244D400CE71A6668664240016C4084B8244D400CE71A6668664240ED9A90D618244D400B28D4D347644240ED9A90D618244D40
4474	Фабрика	1	15	545	35.878658999999999	35.907153000000001	57.819921000000001	57.806761000000002	0103000020E6100000010000000500000004ABEAE577F041401958C7F143E74C4004ABEAE577F04140DD26DC2BF3E84C40F1BBE9961DF44140DD26DC2BF3E84C40F1BBE9961DF441401958C7F143E74C4004ABEAE577F041401958C7F143E74C40
4740	Труженик	1	15	545	35.644593999999998	35.664312000000002	58.011032	58.002715999999999	0103000020E610000001000000050000005299620E82D24140859675FF58004D405299620E82D24140D09A1F7F69014D40912BF52C08D54140D09A1F7F69014D40912BF52C08D54140859675FF58004D405299620E82D24140859675FF58004D40
4671	Трестна	1	15	545	35.953380000000003	35.974679000000002	57.535955999999999	57.527002000000003	0103000020E610000001000000050000008B54185B08FA41409B7631CD74C34C408B54185B08FA4140280CCA349AC44C408B8C0E48C2FC4140280CCA349AC44C408B8C0E48C2FC41409B7631CD74C34C408B54185B08FA41409B7631CD74C34C40
3718	Сидорково	1	15	545	36.069586000000001	36.096122999999999	57.806085000000003	57.794967	0103000020E610000001000000050000003621AD31E80842401A33897AC1E54C403621AD31E8084240E96514CB2DE74C405BB22AC24D0C4240E96514CB2DE74C405BB22AC24D0C42401A33897AC1E54C403621AD31E80842401A33897AC1E54C40
4571	Сельцы	1	15	545	35.965508	36.000551000000002	57.959052999999997	57.939489999999999	0103000020E61000000100000005000000600322C495FB4140A375543541F84C40600322C495FB4140BA10AB3FC2FA4C40747D1F0E12004240BA10AB3FC2FA4C40747D1F0E12004240A375543541F84C40600322C495FB4140A375543541F84C40
4443	Рыбинское Заручье	1	15	545	35.980221999999998	36.007162999999998	57.823290999999998	57.81156	0103000020E61000000100000005000000EC681CEA77FD4140F25EB532E1E74C40EC681CEA77FD4140AA0B789961E94C40E15E99B7EA004240AA0B789961E94C40E15E99B7EA004240F25EB532E1E74C40EC681CEA77FD4140F25EB532E1E74C40
4336	Ручки	1	15	545	35.779628000000002	35.800235999999998	57.852266999999998	57.841355999999998	0103000020E61000000100000005000000E085ADD9CAE341408D25AC8DB1EB4C40E085ADD9CAE34140E23AC61517ED4C407A8A1C226EE64140E23AC61517ED4C407A8A1C226EE641408D25AC8DB1EB4C40E085ADD9CAE341408D25AC8DB1EB4C40
4221	Ривицкий	1	15	545	35.897927000000003	35.910674999999998	57.626669999999997	57.613394999999997	0103000020E6100000010000000500000003999D45EFF24140D44334BA83CE4C4003999D45EFF2414031B1F9B836D04C40742497FF90F4414031B1F9B836D04C40742497FF90F44140D44334BA83CE4C4003999D45EFF24140D44334BA83CE4C40
4022	Раевское	1	15	545	35.584792999999998	35.602992999999998	57.879888999999999	57.869843000000003	0103000020E6100000010000000500000001F73C7FDACA4140C8D3F20357EF4C4001F73C7FDACA4140198EE733A0F04C40C45BE7DF2ECD4140198EE733A0F04C40C45BE7DF2ECD4140C8D3F20357EF4C4001F73C7FDACA4140C8D3F20357EF4C40
4136	Пальчиха	1	15	545	36.016010999999999	36.031758000000004	57.741650999999997	57.725130999999998	0103000020E6100000010000000500000029B000A60C0242406B28B517D1DC4C4029B000A60C024240D905836BEEDE4C4075B169A510044240D905836BEEDE4C4075B169A5100442406B28B517D1DC4C4029B000A60C0242406B28B517D1DC4C40
41020	Новое Пхово	1	15	545	35.503360000000001	35.528207999999999	58.030937000000002	58.025222999999997	0103000020E61000000100000005000000AA0EB9196EC04140B20DDC813A034D40AA0EB9196EC04140419E5DBEF5034D4027BEDA519CC34140419E5DBEF5034D4027BEDA519CC34140B20DDC813A034D40AA0EB9196EC04140B20DDC813A034D40
3895	Малышево	1	15	545	35.631127999999997	35.636868	57.840536	57.835692999999999	0103000020E6100000010000000500000081CB63CDC8D04140813FFCFCF7EA4C4081CB63CDC8D041402A8E03AF96EB4C4039EFFFE384D141402A8E03AF96EB4C4039EFFFE384D14140813FFCFCF7EA4C4081CB63CDC8D04140813FFCFCF7EA4C40
3351	Максатиха	1	15	545	35.835611	35.925747999999999	57.806468000000002	57.779946000000002	0103000020E61000000100000005000000C4961E4DF5EA4140B1524145D5E34C40C4961E4DF5EA4140A1A2EA573AE74C40302B14E97EF64140A1A2EA573AE74C40302B14E97EF64140B1524145D5E34C40C4961E4DF5EA4140B1524145D5E34C40
3803	Кострецы	1	15	545	35.729421000000002	35.748502000000002	57.700342999999997	57.686002999999999	0103000020E610000001000000050000000002D6AA5DDD41409CFA40F2CED74C400002D6AA5DDD4140C37DE4D6A4D94C40CC7EDDE9CEDF4140C37DE4D6A4D94C40CC7EDDE9CEDF41409CFA40F2CED74C400002D6AA5DDD41409CFA40F2CED74C40
4180	Ключевая	1	15	545	36.114852999999997	36.139287000000003	57.636239000000003	57.624043	0103000020E610000001000000050000007A6CCB80B30E42401C261AA4E0CF4C407A6CCB80B30E42404AB8904770D14C4005E10A28D41142404AB8904770D14C4005E10A28D41142401C261AA4E0CF4C407A6CCB80B30E42401C261AA4E0CF4C40
3946	Кистутово	1	15	545	35.569755000000001	35.596992	57.796066000000003	57.782598999999998	0103000020E61000000100000005000000C2DD59BBEDC84140EF703B342CE44C40C2DD59BBEDC8414091BA9D7DE5E54C40A0FCDD3B6ACC414091BA9D7DE5E54C40A0FCDD3B6ACC4140EF703B342CE44C40C2DD59BBEDC84140EF703B342CE44C40
3758	Каменка	1	15	545	35.398850000000003	35.427345000000003	57.721939999999996	57.709369000000002	0103000020E610000001000000050000003B014D840DB34140EBE5779ACCDA4C403B014D840DB341404DD6A88768DC4C40F88DAF3DB3B641404DD6A88768DC4C40F88DAF3DB3B64140EBE5779ACCDA4C403B014D840DB34140EBE5779ACCDA4C40
4030	Засека	1	15	545	35.701717000000002	35.718488999999998	57.768264000000002	57.757663000000001	0103000020E610000001000000050000000C06D7DCD1D94140D331E719FBE04C400C06D7DCD1D94140DA58897956E24C4093C49272F7DB4140DA58897956E24C4093C49272F7DB4140D331E719FBE04C400C06D7DCD1D94140D331E719FBE04C40
41012	Заречье	1	15	545	35.920448	35.938648000000001	57.772891000000001	57.766078999999998	0103000020E6100000010000000500000095D5743DD1F5414081936DE00EE24C4095D5743DD1F54140B62FA017EEE24C40583A1F9E25F84140B62FA017EEE24C40583A1F9E25F8414081936DE00EE24C4095D5743DD1F5414081936DE00EE24C40
4608	Дымцево	1	15	545	35.883285000000001	35.891522000000002	58.065578000000002	58.061050000000002	0103000020E6100000010000000500000010069E7B0FF14140DDB5847CD0074D4010069E7B0FF1414026AB22DC64084D400FD594641DF2414026AB22DC64084D400FD594641DF24140DDB5847CD0074D4010069E7B0FF14140DDB5847CD0074D40
3618	Дубищи	1	15	545	36.138486999999998	36.159813	58.133626999999997	58.121341999999999	0103000020E61000000100000005000000E8F527F1B9114240CCD07822880F4D40E8F527F1B9114240696E85B01A114D40E23C9CC074144240696E85B01A114D40E23C9CC074144240CCD07822880F4D40E8F527F1B9114240CCD07822880F4D40
4375	Горка	1	15	545	35.774076999999998	35.780895000000001	57.878166	57.874395	0103000020E61000000100000005000000FBCA83F414E341409964E42CECEF4C40FBCA83F414E34140C53A55BE67F04C40124E0B5EF4E34140C53A55BE67F04C40124E0B5EF4E341409964E42CECEF4C40FBCA83F414E341409964E42CECEF4C40
3566	Буденовка	1	15	545	36.099671000000001	36.120638	58.057169000000002	58.044387	0103000020E6100000010000000500000008AEF204C20C42400CAF2479AE054D4008AEF204C20C42402AAC545051074D40D253E410710F42402AAC545051074D40D253E410710F42400CAF2479AE054D4008AEF204C20C42400CAF2479AE054D40
41019	Большая Воздвиженка	1	15	545	35.788800000000002	35.805545000000002	57.614759999999997	57.605445000000003	0103000020E61000000100000005000000DB8AFD65F7E441406C43C5387FCD4C40DB8AFD65F7E44140C971A774B0CE4C40693A3B191CE74140C971A774B0CE4C40693A3B191CE741406C43C5387FCD4C40DB8AFD65F7E441406C43C5387FCD4C40
1727	Язвиха	1	15	333	35.531657000000003	35.546947000000003	57.363604000000002	57.355345999999997	0103000020E6100000010000000500000041D829560DC44140D8614CFA7BAD4C4041D829560DC44140EF586C938AAE4C409AD2FA5B02C64140EF586C938AAE4C409AD2FA5B02C64140D8614CFA7BAD4C4041D829560DC44140D8614CFA7BAD4C40
2026	Толмачи	1	15	333	35.671543	35.705086000000001	57.443373000000001	57.418202000000001	0103000020E61000000100000005000000CA6DFB1EF5D54140978FA4A487B54C40CA6DFB1EF5D54140F7764B72C0B84C40096F0F4240DA4140F7764B72C0B84C40096F0F4240DA4140978FA4A487B54C40CA6DFB1EF5D54140978FA4A487B54C40
1682	Стан	1	15	333	35.401204	35.430633	57.386741000000001	57.378489000000002	0103000020E610000001000000050000001F8315A75AB34140A872DA5372B04C401F8315A75AB34140DC82A5BA80B14C4008CA6DFB1EB74140DC82A5BA80B14C4008CA6DFB1EB74140A872DA5372B04C401F8315A75AB34140A872DA5372B04C40
3245	Сосновицы	1	15	333	35.460762000000003	35.475664999999999	57.225709999999999	57.210450999999999	0103000020E61000000100000005000000AA9ECC3FFABA41408B34F10EF09A4C40AA9ECC3FFABA4140A930B610E49C4C40096D3997E2BC4140A930B610E49C4C40096D3997E2BC41408B34F10EF09A4C40AA9ECC3FFABA41408B34F10EF09A4C40
1965	Прудово	1	15	333	35.852113000000003	35.870789000000002	57.454675999999999	57.445135999999998	0103000020E610000001000000050000008CBFED0912ED4140D9226937FAB84C408CBFED0912ED41405723BBD232BA4C40B85B920376EF41405723BBD232BA4C40B85B920376EF4140D9226937FAB84C408CBFED0912ED4140D9226937FAB84C40
3003	Первитино	1	15	333	35.660584	35.683337999999999	57.134022999999999	57.120719000000001	0103000020E6100000010000000500000064213A048ED44140BF805EB8738F4C4064213A048ED44140B6F468AA27914C40990E9D9E77D74140B6F468AA27914C40990E9D9E77D74140BF805EB8738F4C4064213A048ED44140BF805EB8738F4C40
2767	Осиновая Гряда	1	15	333	35.396030000000003	35.412585999999997	57.035373	57.031827	0103000020E61000000100000005000000111E6D1CB1B241409D103AE812844C40111E6D1CB1B24140A9143B1A87844C40CB64389ECFB44140A9143B1A87844C40CB64389ECFB441409D103AE812844C40111E6D1CB1B241409D103AE812844C40
1894	Назарово	1	15	333	35.745033999999997	35.762740000000001	57.535516000000001	57.521169	0103000020E610000001000000050000003B342C465DDF4140325871AAB5C24C403B342C465DDF41400C3ECDC98BC44C40EFACDD76A1E141400C3ECDC98BC44C40EFACDD76A1E14140325871AAB5C24C403B342C465DDF4140325871AAB5C24C40
3290	Михайлова Гора	1	15	333	35.457762000000002	35.477642000000003	57.261208000000003	57.252645000000001	0103000020E6100000010000000500000000ADF9F197BA4140BC3FDEAB56A04C4000ADF9F197BA41400FBA84436FA14C401899805F23BD41400FBA84436FA14C401899805F23BD4140BC3FDEAB56A04C4000ADF9F197BA4140BC3FDEAB56A04C40
3117	Микшино	1	15	333	35.699525000000001	35.722710999999997	57.247180999999998	57.236013999999997	0103000020E6100000010000000500000001DE02098AD94140F6B2EDB4359E4C4001DE02098AD94140A69883A0A39F4C40CFBA46CB81DC4140A69883A0A39F4C40CFBA46CB81DC4140F6B2EDB4359E4C4001DE02098AD94140F6B2EDB4359E4C40
2088	Лихославль	1	15	333	35.432096999999999	35.496479000000001	57.137372999999997	57.109909000000002	0103000020E6100000010000000500000090D959F44EB741409E44847F118E4C4090D959F44EB741403C2D3F7095914C404D13B69F8CBF41403C2D3F7095914C404D13B69F8CBF41409E44847F118E4C4090D959F44EB741409E44847F118E4C40
2941	Кузовино	1	15	333	35.506081999999999	35.522620000000003	57.186211999999998	57.176693999999998	0103000020E61000000100000005000000118C834BC7C0414020B3B3E89D964C40118C834BC7C04140B60F79CBD5974C40261E5036E5C24140B60F79CBD5974C40261E5036E5C2414020B3B3E89D964C40118C834BC7C0414020B3B3E89D964C40
2825	Крючково	1	15	333	35.527444000000003	35.535348999999997	57.060524000000001	57.057474999999997	0103000020E61000000100000005000000583CF54883C3414036AB3E575B874C40583CF54883C34140C24F1C40BF874C402079E75086C44140C24F1C40BF874C402079E75086C4414036AB3E575B874C40583CF54883C3414036AB3E575B874C40
2483	Калашниково	1	15	333	35.210042000000001	35.247574	57.293841999999998	57.269779	0103000020E61000000100000005000000AA6400A8E29A4140E412471E88A24C40AA6400A8E29A41407A185A9D9CA54C4082AB3C81B09F41407A185A9D9CA54C4082AB3C81B09F4140E412471E88A24C40AA6400A8E29A4140E412471E88A24C40
2891	Кава	1	15	333	35.522575000000003	35.539076999999999	57.138447999999997	57.127853000000002	0103000020E61000000100000005000000865AD3BCE3C2414006D9B27C5D904C40865AD3BCE3C241402A1900AAB8914C404D83A27900C541402A1900AAB8914C404D83A27900C5414006D9B27C5D904C40865AD3BCE3C2414006D9B27C5D904C40
2654	Ильинское	1	15	333	35.359271	35.373437000000003	57.097287000000001	57.086514000000001	0103000020E610000001000000050000005BB39597FCAD4140B55208E4128B4C405BB39597FCAD4140B9A981E6738C4C40E50E9BC8CCAF4140B9A981E6738C4C40E50E9BC8CCAF4140B55208E4128B4C405BB39597FCAD4140B55208E4128B4C40
3173	Залазино	1	15	333	35.655822000000001	35.675747000000001	57.345008	57.334117999999997	0103000020E61000000100000005000000A8FFACF9F1D34140A180ED60C4AA4C40A8FFACF9F1D34140DF6DDE3829AC4C4060AFB0E07ED64140DF6DDE3829AC4C4060AFB0E07ED64140A180ED60C4AA4C40A8FFACF9F1D34140A180ED60C4AA4C40
1784	Гнездово	1	15	333	35.490451999999998	35.507753000000001	57.420160000000003	57.405442000000001	0103000020E61000000100000005000000FF209221C7BE414061360186E5B34C40FF209221C7BE41402F8B89CDC7B54C4013B9E00CFEC041402F8B89CDC7B54C4013B9E00CFEC0414061360186E5B34C40FF209221C7BE414061360186E5B34C40
3055	Вышково	1	15	333	35.624443999999997	35.649237999999997	57.186124	57.174273999999997	0103000020E610000001000000050000007A17EFC7EDCF41408445459C4E964C407A17EFC7EDCF4140178046E9D2974C4004A9143B1AD34140178046E9D2974C4004A9143B1AD341408445459C4E964C407A17EFC7EDCF41408445459C4E964C40
2704	Вески	1	15	333	35.443730000000002	35.472737000000002	57.073456999999998	57.062325000000001	0103000020E6100000010000000500000086200725CCB84140925CFE43FA874C4086200725CCB84140C554FA0967894C40F94D61A582BC4140C554FA0967894C40F94D61A582BC4140925CFE43FA874C4086200725CCB84140925CFE43FA874C40
1839	Березовка	1	15	333	35.580444999999997	35.593119999999999	57.48854	57.482430000000001	0103000020E61000000100000005000000381092054CCA4140FD4D2844C0BD4C40381092054CCA4140D8648D7A88BE4C40404D2D5BEBCB4140D8648D7A88BE4C40404D2D5BEBCB4140FD4D2844C0BD4C40381092054CCA4140FD4D2844C0BD4C40
2595	Барановка	1	15	333	35.330587000000001	35.346316999999999	57.208208999999997	57.199047999999998	0103000020E61000000100000005000000CBBDC0AC50AA4140C72AA5677A994C40CBBDC0AC50AA4140CEDDAE97A69A4C4040868E1D54AC4140CEDDAE97A69A4C4040868E1D54AC4140C72AA5677A994C40CBBDC0AC50AA4140C72AA5677A994C40
1583	Анцифарово	1	15	333	35.376463999999999	35.390056000000001	57.306061	57.298397999999999	0103000020E61000000100000005000000880FECF82FB041408D98D9E731A64C40880FECF82FB0414060CAC0012DA74C40E6CDE15AEDB1414060CAC0012DA74C40E6CDE15AEDB141408D98D9E731A64C40880FECF82FB041408D98D9E731A64C40
1455	Телятники	1	15	211	35.676493000000001	35.692473999999997	58.055979000000001	58.042915000000001	0103000020E61000000100000005000000897C975297D6414001C11C3D7E054D40897C975297D64140A321E3512A074D4047AAEFFCA2D84140A321E3512A074D4047AAEFFCA2D8414001C11C3D7E054D40897C975297D6414001C11C3D7E054D40
16618	Спирово	1	15	211	35.484656999999999	35.500377999999998	58.234555999999998	58.224539	0103000020E610000001000000050000008463963D09BE414099D6A6B1BD1C4D408463963D09BE4140508A56EE051E4D40A6D1E4620CC04140508A56EE051E4D40A6D1E4620CC0414099D6A6B1BD1C4D408463963D09BE414099D6A6B1BD1C4D40
1342	Никольское	1	15	211	35.649102999999997	35.666072	58.406399	58.394969000000003	0103000020E61000000100000005000000245E9ECE15D3414088F71C588E324D40245E9ECE15D341404510E7E104344D400264E8D841D541404510E7E104344D400264E8D841D5414088F71C588E324D40245E9ECE15D3414088F71C588E324D40
1253	Мотыли	1	15	211	35.478765000000003	35.490532000000002	58.174551000000001	58.164392999999997	0103000020E6100000010000000500000017BCE82B48BD41407D586FD40A154D4017BCE82B48BD4140F73DEAAF57164D401CD2A8C0C9BE4140F73DEAAF57164D401CD2A8C0C9BE41407D586FD40A154D4017BCE82B48BD41407D586FD40A154D40
1230	Михайловское	1	15	211	35.479599999999998	35.499084000000003	58.385840999999999	58.372298999999998	0103000020E61000000100000005000000AF94658863BD4140B0AA5E7EA72F4D40AF94658863BD41405C3AE63C63314D407BFA08FCE1BF41405C3AE63C63314D407BFA08FCE1BF4140B0AA5E7EA72F4D40AF94658863BD4140B0AA5E7EA72F4D40
1128	Медведково	1	15	211	35.560187999999997	35.583454000000003	58.251443000000002	58.235934999999998	0103000020E610000001000000050000004ACE893DB4C74140AA7D3A1E331E4D404ACE893DB4C7414071E7C2482F204D40365CE49EAECA414071E7C2482F204D40365CE49EAECA4140AA7D3A1E331E4D404ACE893DB4C74140AA7D3A1E331E4D40
1108	Лесное	1	15	211	35.506557999999998	35.545338999999998	58.293793000000001	58.278931999999998	0103000020E610000001000000050000007AC37DE4D6C0414068E7340BB4234D407AC37DE4D6C0414099654F029B254D40DE1D19ABCDC5414099654F029B254D40DE1D19ABCDC5414068E7340BB4234D407AC37DE4D6C0414068E7340BB4234D40
1004	Кожина Гора	1	15	211	35.433391	35.448366	58.119169999999997	58.111716000000001	0103000020E61000000100000005000000BCB0355B79B741405038BBB54C0E4D40BCB0355B79B7414008556AF6400F4D40B5519D0E64B9414008556AF6400F4D40B5519D0E64B941405038BBB54C0E4D40BCB0355B79B741405038BBB54C0E4D40
989	Застровье	1	15	211	35.468263	35.480786000000002	58.326542000000003	58.323815000000003	0103000020E61000000100000005000000A376BF0AF0BB4140257A19C572294D40A376BF0AF0BB41409E62D520CC294D40F52F49658ABD41409E62D520CC294D40F52F49658ABD4140257A19C572294D40A376BF0AF0BB4140257A19C572294D40
913	Городок	1	15	211	35.511391000000003	35.534182000000001	58.256656999999997	58.246409	0103000020E61000000100000005000000003CA24275C14140543882548A1F4D40003CA24275C141400DA5F622DA204D40520E661360C441400DA5F622DA204D40520E661360C44140543882548A1F4D40003CA24275C14140543882548A1F4D40
802	Борисовское	1	15	211	35.934372000000003	35.950190999999997	58.263148000000001	58.251756	0103000020E6100000010000000500000029266F8099F741403049658A39204D4029266F8099F7414000016BD5AE214D400DFAD2DB9FF9414000016BD5AE214D400DFAD2DB9FF941403049658A39204D4029266F8099F741403049658A39204D40
864	Бор-Пруды	1	15	211	35.290081999999998	35.303063000000002	58.215746000000003	58.205756999999998	0103000020E6100000010000000500000042942F6821A5414027F6D03E561A4D4042942F6821A54140151F9F909D1B4D4057D0B4C4CAA64140151F9F909D1B4D4057D0B4C4CAA6414027F6D03E561A4D4042942F6821A5414027F6D03E561A4D40
1571	Алексейково	1	15	211	35.421056999999998	35.439687999999997	58.165807999999998	58.157632999999997	0103000020E610000001000000050000003D601E32E5B541409BE271512D144D403D601E32E5B5414024B5503239154D40C93846B247B8414024B5503239154D40C93846B247B841409BE271512D144D403D601E32E5B541409BE271512D144D40
679	Тысяцкое	1	15	45	34.239106999999997	34.264789999999998	57.018853999999997	57.009725000000003	0103000020E61000000100000005000000519FE40E9B1E4140107A36AB3E814C40519FE40E9B1E41400BB3D0CE69824C40672783A3E42141400BB3D0CE69824C40672783A3E4214140107A36AB3E814C40519FE40E9B1E4140107A36AB3E814C40
227	Сокольники	1	15	45	34.029260999999998	34.051512000000002	56.900863999999999	56.889493000000002	0103000020E610000001000000050000002D060FD3BE034140AE8218E8DA714C402D060FD3BE0341406612F5824F734C4000ADF9F1970641406612F5824F734C4000ADF9F197064140AE8218E8DA714C402D060FD3BE034140AE8218E8DA714C40
163	Ранцево	1	15	45	34.027752	34.058995000000003	56.951503000000002	56.927782000000001	0103000020E610000001000000050000000533A6608D034140A3E8818FC1764C400533A6608D034140E085ADD9CA794C4053D0ED258D074140E085ADD9CA794C4053D0ED258D074140A3E8818FC1764C400533A6608D034140A3E8818FC1764C40
611	Прямухино	1	15	45	34.445244000000002	34.453104000000003	56.942976000000002	56.930404000000003	0103000020E61000000100000005000000C05E61C1FD384140A708707A17774C40C05E61C1FD384140DA740470B3784C40E9D7D64FFF394140DA740470B3784C40E9D7D64FFF394140A708707A17774C40C05E61C1FD384140A708707A17774C40
550	Пречисто Каменка	1	15	45	34.481634999999997	34.502709000000003	57.034565000000001	57.025233999999998	0103000020E61000000100000005000000F2CD3637A63D4140A65F22DE3A834C40F2CD3637A63D41400A4B3CA06C844C40D333BDC4584041400A4B3CA06C844C40D333BDC458404140A65F22DE3A834C40F2CD3637A63D4140A65F22DE3A834C40
492	Пень	1	15	45	34.137984000000003	34.158096999999998	57.087466999999997	57.076676999999997	0103000020E6100000010000000500000086AFAF75A91141407DAD4B8DD0894C4086AFAF75A9114140573D601E328B4C40404CC2853C144140573D601E328B4C40404CC2853C1441407DAD4B8DD0894C4086AFAF75A91141407DAD4B8DD0894C40
53	Могилевка	1	15	45	33.783715000000001	33.795906000000002	57.083232000000002	57.076059999999998	0103000020E610000001000000050000003C31EBC550E4404052448655BC894C403C31EBC550E4404087FD9E58A78A4C405858703FE0E5404087FD9E58A78A4C405858703FE0E5404052448655BC894C403C31EBC550E4404052448655BC894C40
731	Кувшиново	1	15	45	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
41007	Красный Городок	1	15	45	33.710071999999997	33.725836999999999	57.185222000000003	57.172825000000003	0103000020E6100000010000000500000014E7A8A3E3DA404032772D211F964C4014E7A8A3E3DA4040F73FC05AB5974C40069D103AE8DC4040F73FC05AB5974C40069D103AE8DC404032772D211F964C4014E7A8A3E3DA404032772D211F964C40
32428	Заовражье	1	15	45	34.309463000000001	34.324249999999999	56.909607999999999	56.895595	0103000020E610000001000000050000003929CC7B9C27414006BB61DBA2724C403929CC7B9C2741400917F2086E744C402FDD2406812941400917F2086E744C402FDD24068129414006BB61DBA2724C403929CC7B9C27414006BB61DBA2724C40
32407	Васильково	1	15	45	34.156723	34.173180000000002	56.989238	56.982228999999997	0103000020E61000000100000005000000F8C3CF7F0F14414065170CAEB97D4C40F8C3CF7F0F144140F0FACC599F7E4C40202922C32A164140F0FACC599F7E4C40202922C32A16414065170CAEB97D4C40F8C3CF7F0F14414065170CAEB97D4C40
356	Борзыни	1	15	45	34.255223000000001	34.277034	57.218083999999998	57.211050999999998	0103000020E61000000100000005000000F017B325AB204140E0641BB8039B4C40F017B325AB204140F3E32F2DEA9B4C40A6F0A0D975234140F3E32F2DEA9B4C40A6F0A0D975234140E0641BB8039B4C40F017B325AB204140E0641BB8039B4C40
426	Большой Борок	1	15	45	34.447794999999999	34.504595000000002	56.986609000000001	56.974238999999997	0103000020E61000000100000005000000FA27B858513941406EBE11DDB37C4C40FA27B858513941403A782634497E4C40D15CA791964041403A782634497E4C40D15CA791964041406EBE11DDB37C4C40FA27B858513941406EBE11DDB37C4C40
298	Большое Кузнечково	1	15	45	34.382702999999999	34.401828000000002	57.089804999999998	57.082076999999998	0103000020E61000000100000005000000618A7269FC3041407C60C77F818A4C40618A7269FC3041403602F1BA7E8B4C40FD4E93196F3341403602F1BA7E8B4C40FD4E93196F3341407C60C77F818A4C40618A7269FC3041407C60C77F818A4C40
31301	Юрово	1	15	1266	37.167893999999997	37.183802999999997	57.940114999999999	57.931677999999998	0103000020E61000000100000005000000E998F38C7D9542408B33863941F74C40E998F38C7D95424051BD35B055F84C400EF450DB8697424051BD35B055F84C400EF450DB869742408B33863941F74C40E998F38C7D9542408B33863941F74C40
31553	Хабоцкое	1	15	1266	37.016041999999999	37.038167999999999	58.146396000000003	58.124797000000001	0103000020E6100000010000000500000064AE0CAA0D824240C8D11C59F90F4D4064AE0CAA0D824240F321A81ABD124D407AE063B0E2844240F321A81ABD124D407AE063B0E2844240C8D11C59F90F4D4064AE0CAA0D824240C8D11C59F90F4D40
32010	Ульянино	1	15	1266	37.098165999999999	37.110905000000002	58.160390999999997	58.151781999999997	0103000020E6100000010000000500000021CA17B4908C42408C0FB3976D134D4021CA17B4908C42404FC939B187144D4040FB9122328E42404FC939B187144D4040FB9122328E42408C0FB3976D134D4021CA17B4908C42408C0FB3976D134D40
31971	Толстиково	1	15	1266	37.188025000000003	37.205407000000001	58.098723999999997	58.093307000000003	0103000020E610000001000000050000004BEA04341198424073BED87BF10B4D404BEA04341198424047AAEFFCA20C4D404BAFCDC64A9A424047AAEFFCA20C4D404BAFCDC64A9A424073BED87BF10B4D404BEA04341198424073BED87BF10B4D40
31415	Скоросово	1	15	1266	36.955559000000001	36.971072999999997	58.065348999999998	58.057564999999997	0103000020E610000001000000050000000133DFC14F7A42407632384A5E074D400133DFC14F7A4240C4E9245B5D084D40A983BC1E4C7C4240C4E9245B5D084D40A983BC1E4C7C42407632384A5E074D400133DFC14F7A42407632384A5E074D40
31874	Рачево	1	15	1266	37.435519999999997	37.456549000000003	58.117196999999997	58.105167999999999	0103000020E6100000010000000500000080608E1EBFB74240F94A2025760D4D4080608E1EBFB742403B18B14F000F4D40C102983270BA42403B18B14F000F4D40C102983270BA4240F94A2025760D4D4080608E1EBFB74240F94A2025760D4D40
13170	Овинищи	1	15	1266	37.043432000000003	37.054661000000003	58.265675999999999	58.257665000000003	0103000020E61000000100000005000000C9CC052E8F8542407429AE2AFB204D40C9CC052E8F85424082AAD1AB01224D40EFAEB321FF86424082AAD1AB01224D40EFAEB321FF8642407429AE2AFB204D40C9CC052E8F8542407429AE2AFB204D40
31836	Нивы	1	15	1266	37.439418000000003	37.458956999999998	58.090800000000002	58.079495000000001	0103000020E610000001000000050000000AA359D93EB84240079964E42C0A4D400AA359D93EB84240083D9B559F0B4D4098A25C1ABFBA4240083D9B559F0B4D4098A25C1ABFBA4240079964E42C0A4D400AA359D93EB84240079964E42C0A4D40
31708	Мартыново	1	15	1266	37.269385	37.282905	58.359563000000001	58.350413000000003	0103000020E6100000010000000500000038842A357BA24240F08B4B55DA2C4D4038842A357BA2424003ED0E29062E4D40FC6F253B36A4424003ED0E29062E4D40FC6F253B36A44240F08B4B55DA2C4D4038842A357BA24240F08B4B55DA2C4D40
31023	Красный Холм	1	15	1266	37.098229000000003	37.141528000000001	58.077272000000001	58.045582000000003	0103000020E61000000100000005000000684293C4928C4240A5A487A1D5054D40684293C4928C4240C172840CE4094D40F1BBE9961D924240C172840CE4094D40F1BBE9961D924240A5A487A1D5054D40684293C4928C4240A5A487A1D5054D40
31516	Ивакино	1	15	1266	37.329338999999997	37.345032000000003	58.017425000000003	58.011350999999998	0103000020E610000001000000050000000F26C5C727AA424071E316F373014D400F26C5C727AA424000917EFB3A024D40680932022AAC424000917EFB3A024D40680932022AAC424071E316F373014D400F26C5C727AA424071E316F373014D40
31613	Дмитровка	1	15	1266	37.039830000000002	37.045946999999998	58.244717999999999	58.241056	0103000020E6100000010000000500000029B341261985424096404AECDA1E4D4029B34126198542400B5F5FEB521F4D40B62C5F97E18542400B5F5FEB521F4D40B62C5F97E185424096404AECDA1E4D4029B341261985424096404AECDA1E4D40
31245	Грудино	1	15	1266	37.047457000000001	37.060644000000003	57.902048000000001	57.896628999999997	0103000020E61000000100000005000000AF7B2B121386424095D233BDC4F24C40AF7B2B12138642400BB6114F76F34C406D59BE2EC38742400BB6114F76F34C406D59BE2EC387424095D233BDC4F24C40AF7B2B121386424095D233BDC4F24C40
31460	Глебени	1	15	1266	37.205731	37.223131000000002	58.075997000000001	58.065272999999998	0103000020E61000000100000005000000FE62B664559A4240E9279CDD5A084D40FE62B664559A42400CCC0A45BA094D40A5DC7D8E8F9C42400CCC0A45BA094D40A5DC7D8E8F9C4240E9279CDD5A084D40FE62B664559A4240E9279CDD5A084D40
31348	Высокуша	1	15	1266	36.971665999999999	37.007733000000002	58.025371	58.015431999999997	0103000020E610000001000000050000004C512E8D5F7C4240EBA7FFACF9014D404C512E8D5F7C424027A25F5B3F034D40CC0C1B65FD80424027A25F5B3F034D40CC0C1B65FD804240EBA7FFACF9014D404C512E8D5F7C4240EBA7FFACF9014D40
31733	Васильки	1	15	1266	37.370131000000001	37.392805000000003	58.301245999999999	58.289440999999997	0103000020E610000001000000050000002E1EDE7360AF42408E8F16670C254D402E1EDE7360AF424081069B3A8F264D40475A2A6F47B2424081069B3A8F264D40475A2A6F47B242408E8F16670C254D402E1EDE7360AF42408E8F16670C254D40
31784	Братское	1	15	1266	37.144502000000003	37.156376999999999	58.281843000000002	58.274526999999999	0103000020E61000000100000005000000721AA20A7F9242403B6F63B323234D40721AA20A7F924240A3CD716E13244D405D6C5A2904944240A3CD716E13244D405D6C5A29049442403B6F63B323234D40721AA20A7F9242403B6F63B323234D40
31922	Бекрень	1	15	1266	37.511831999999998	37.526401999999997	58.070166	58.058674000000003	0103000020E61000000100000005000000EC8502B683C1424011902FA182074D40EC8502B683C1424044A51133FB084D404546072461C3424044A51133FB084D404546072461C3424011902FA182074D40EC8502B683C1424011902FA182074D40
31206	Барбино	1	15	1266	37.077595000000002	37.104545000000002	58.030389	58.024985000000001	0103000020E61000000100000005000000A4AA09A2EE894240FEF15EB532034D40A4AA09A2EE8942403E9468C9E3034D40ECFA05BB618D42403E9468C9E3034D40ECFA05BB618D4240FEF15EB532034D40A4AA09A2EE894240FEF15EB532034D40
30023	Юрьево-Девичье	1	15	1850	36.634850999999998	36.663220000000003	56.708351	56.696855999999997	0103000020E610000001000000050000009C6A2DCC42514240BC02D19332594C409C6A2DCC42514240618BDD3EAB5A4C40CD069964E4544240618BDD3EAB5A4C40CD069964E4544240BC02D19332594C409C6A2DCC42514240BC02D19332594C40
28741	Энергетик	1	15	1850	36.682965000000003	36.696672999999997	56.675069000000001	56.668253999999997	0103000020E6100000010000000500000005A8A9656B574240E9B5D95889554C4005A8A9656B5742408FC536A968564C40CB80B3942C5942408FC536A968564C40CB80B3942C594240E9B5D95889554C4005A8A9656B574240E9B5D95889554C40
30256	Старое Мелково	1	15	1850	36.422803999999999	36.433934000000001	56.669530000000002	56.663223000000002	0103000020E610000001000000050000001A4F04711E3642403E7AC37DE4544C401A4F04711E3642406FD8B628B3554C40AD4F39268B3742406FD8B628B3554C40AD4F39268B3742403E7AC37DE4544C401A4F04711E3642403E7AC37DE4544C40
29906	Селихово	1	15	1850	36.800339000000001	36.817945999999999	56.666493000000003	56.657034000000003	0103000020E610000001000000050000004F5B238271664240172EABB019544C404F5B238271664240A80183A44F554C406FF25B74B2684240A80183A44F554C406FF25B74B2684240172EABB019544C404F5B238271664240172EABB019544C40
30361	Редкино	1	15	1850	36.272748999999997	36.318105000000003	56.674143999999998	56.629486	0103000020E6100000010000000500000023827170E92242401AA54BFF92504C4023827170E9224240B665C0594A564C40D8D825AAB7284240B665C0594A564C40D8D825AAB72842401AA54BFF92504C4023827170E92242401AA54BFF92504C40
29406	Радченко	1	15	1850	36.364305999999999	36.384877000000003	56.689363	56.676088	0103000020E6100000010000000500000048DE3994A12E4240E99B340D8A564C4048DE3994A12E42404609FA0B3D584C40C6FD47A6433142404609FA0B3D584C40C6FD47A643314240E99B340D8A564C4048DE3994A12E4240E99B340D8A564C40
29973	Поповское	1	15	1850	36.691049999999997	36.712690000000002	56.856560000000002	56.848073999999997	0103000020E610000001000000050000004DF38E5374584240404B57B08D6C4C404DF38E5374584240E88711C2A36D4C40D717096D395B4240E88711C2A36D4C40D717096D395B4240404B57B08D6C4C404DF38E5374584240404B57B08D6C4C40
30694	Озерки	1	15	1850	36.200417000000002	36.22972	56.650838999999998	56.637569999999997	0103000020E61000000100000005000000FE47A643A71942409274CDE49B514C40FE47A643A71942400DFB3DB14E534C405A9E0777671D42400DFB3DB14E534C405A9E0777671D42409274CDE49B514C40FE47A643A71942409274CDE49B514C40
29461	Новозавидовский	1	15	1850	36.407218	36.456338000000002	56.572026999999999	56.534157	0103000020E61000000100000005000000D82B2CB81F344240F9F6AE415F444C40D82B2CB81F344240E9B6442E38494C4006F69848693A4240E9B6442E38494C4006F69848693A4240F9F6AE415F444C40D82B2CB81F344240F9F6AE415F444C40
30157	Мокшино	1	15	1850	36.489773	36.52196	56.594329999999999	56.576841999999999	0103000020E610000001000000050000005EBBB4E1B03E4240C87A6AF5D5494C405EBBB4E1B03E42400E846401134C4C40FBE8D495CF4242400E846401134C4C40FBE8D495CF424240C87A6AF5D5494C405EBBB4E1B03E4240C87A6AF5D5494C40
29882	Мал. Ручьи	1	15	1850	36.959322999999998	36.985804999999999	56.597110000000001	56.586562999999998	0103000020E610000001000000050000007AA69718CB7A42409605137F144B4C407AA69718CB7A4240AA0EB9196E4C4C40DC9DB5DB2E7E4240AA0EB9196E4C4C40DC9DB5DB2E7E42409605137F144B4C407AA69718CB7A42409605137F144B4C40
30871	Кошелево	1	15	1850	36.262903999999999	36.279809999999998	56.731003000000001	56.717382000000001	0103000020E6100000010000000500000069FE98D6A62142409A5E622CD35B4C4069FE98D6A621424092239D81915D4C40008C67D0D023424092239D81915D4C40008C67D0D02342409A5E622CD35B4C4069FE98D6A62142409A5E622CD35B4C40
29730	Козлово	1	15	1850	36.243375	36.296078999999999	56.517995999999997	56.498703999999996	0103000020E61000000100000005000000FED478E9261F424033315D88D53F4C40FED478E9261F4240BABA63B14D424C402504ABEAE5254240BABA63B14D424C402504ABEAE525424033315D88D53F4C40FED478E9261F424033315D88D53F4C40
28785	Карачарово	1	15	1850	36.691831999999998	36.713095000000003	56.694237000000001	56.680073	0103000020E61000000100000005000000C32973F38D58424041F2CEA10C574C40C32973F38D5842402A560DC2DC584C4077F86BB2465B42402A560DC2DC584C4077F86BB2465B424041F2CEA10C574C40C32973F38D58424041F2CEA10C574C40
30666	Изоплит	1	15	1850	36.190122000000002	36.232505000000003	56.630327000000001	56.619759999999999	0103000020E610000001000000050000000420EEEA551842403AAFB14B544F4C400420EEEA5518424095641D8EAE504C4008944DB9C21D424095641D8EAE504C4008944DB9C21D42403AAFB14B544F4C400420EEEA551842403AAFB14B544F4C40
30829	Игуменка	1	15	1850	36.312527000000003	36.325938999999998	56.782632	56.776719	0103000020E61000000100000005000000FA0E7EE200284240469737876B634C40FA0E7EE200284240CB660E492D644C40D7BE805EB8294240CB660E492D644C40D7BE805EB8294240469737876B634C40FA0E7EE200284240469737876B634C40
30926	Заполок	1	15	1850	36.237957999999999	36.250335999999997	56.642406000000001	56.637610000000002	0103000020E6100000010000000500000029E96168751E424021CD58349D514C4029E96168751E424089601C5C3A524C40778192020B20424089601C5C3A524C40778192020B20424021CD58349D514C4029E96168751E424021CD58349D514C40
30121	Завидово	1	15	1850	36.507362000000001	36.547013999999997	56.544232000000001	56.506484	0103000020E61000000100000005000000D89DEE3CF140424040F9BB77D4404C40D89DEE3CF1404240E5B7E864A9454C40213A048E04464240E5B7E864A9454C40213A048E0446424040F9BB77D4404C40D89DEE3CF140424040F9BB77D4404C40
29829	Дмитрова Гора	1	15	1850	36.963168000000003	36.989327000000003	56.671993000000001	56.652749	0103000020E61000000100000005000000E146CA16497B424094BF7B478D534C40E146CA16497B42400A12DBDD03564C4060066344A27E42400A12DBDD03564C4060066344A27E424094BF7B478D534C40E146CA16497B424094BF7B478D534C40
30765	Городня	1	15	1850	36.309885999999999	36.342962	56.721397000000003	56.696466000000001	0103000020E610000001000000050000007FBE2D58AA274240526342CC25594C407FBE2D58AA2742405D37A5BC565C4C40A8E2C62DE62B42405D37A5BC565C4C40A8E2C62DE62B4240526342CC25594C407FBE2D58AA274240526342CC25594C40
30285	Гаврилково	1	15	1850	36.347920000000002	36.373486999999997	56.550598999999998	56.541235	0103000020E61000000100000005000000EACF7EA4882C4240AC39403047454C40EACF7EA4882C4240EB1A2D077A464C40963D096CCE2F4240EB1A2D077A464C40963D096CCE2F4240AC39403047454C40EACF7EA4882C4240AC39403047454C40
30062	Вахонино	1	15	1850	36.614316000000002	36.635570000000001	56.616371999999998	56.601109000000001	0103000020E610000001000000050000006CB41CE8A14E4240672AC423F14C4C406CB41CE8A14E4240C6151747E54E4C40CC28965B5A514240C6151747E54E4C40CC28965B5A514240672AC423F14C4C406CB41CE8A14E4240672AC423F14C4C40
41044	пос.Центральный	1	15	1769	36.623542	37.674930000000003	57.322763000000002	56.769064	0103000020E610000001000000050000005AD76839D04F4240F6436CB070624C405AD76839D04F4240EFAD484C50A94C406E8B321B64D64240EFAD484C50A94C406E8B321B64D64240F6436CB070624C405AD76839D04F4240F6436CB070624C40
27621	Федоровка	1	15	1769	37.225610000000003	37.242328000000001	56.821832999999998	56.815035000000002	0103000020E6100000010000000500000046D3D9C9E09C4240350C1F1153684C4046D3D9C9E09C424004E3E0D231694C40DA73999A049F424004E3E0D231694C40DA73999A049F4240350C1F1153684C4046D3D9C9E09C4240350C1F1153684C40
27561	Устиново	1	15	1769	37.309531	37.331629999999997	57.085281000000002	57.075620000000001	0103000020E61000000100000005000000910C39B69EA74240367689EAAD894C40910C39B69EA742402FFCE07CEA8A4C40AD2F12DA72AA42402FFCE07CEA8A4C40AD2F12DA72AA4240367689EAAD894C40910C39B69EA74240367689EAAD894C40
27515	Титово	1	15	1769	37.422117	37.445078000000002	56.868152000000002	56.860436999999997	0103000020E61000000100000005000000F60A0BEE07B6424059A2B3CC226E4C40F60A0BEE07B642407FFACF9A1F6F4C40A515DF50F8B842407FFACF9A1F6F4C40A515DF50F8B8424059A2B3CC226E4C40F60A0BEE07B6424059A2B3CC226E4C40
27471	Стоянцы	1	15	1769	36.807758999999997	36.838858999999999	57.011268999999999	56.980944000000001	0103000020E610000001000000050000005B069CA5646742408D9AAF928F7D4C405B069CA564674240B43A394371814C40467A51BB5F6B4240B43A394371814C40467A51BB5F6B42408D9AAF928F7D4C405B069CA5646742408D9AAF928F7D4C40
26966	Радомино	1	15	1769	36.755916999999997	36.773147000000002	57.253984000000003	57.248412999999999	0103000020E61000000100000005000000C6BE64E3C16042405C7347FFCB9F4C40C6BE64E3C160424088DA368C82A04C4011001C7BF662424088DA368C82A04C4011001C7BF66242405C7347FFCB9F4C40C6BE64E3C16042405C7347FFCB9F4C40
27421	Приволжский	1	15	1769	37.540146999999997	37.558005000000001	56.962228000000003	56.953231000000002	0103000020E610000001000000050000002904728923C5424046443179037A4C402904728923C54240D3A57F492A7B4C40930035B56CC74240D3A57F492A7B4C40930035B56CC7424046443179037A4C402904728923C5424046443179037A4C40
27329	Печетово	1	15	1769	36.993243	37.009	57.142535000000002	57.134452000000003	0103000020E610000001000000050000008FFD2C96227F4240DF701FB935914C408FFD2C96227F424087C43D963E924C40FED478E92681424087C43D963E924C40FED478E926814240DF701FB935914C408FFD2C96227F4240DF701FB935914C40
27350	Паскино	1	15	1769	37.074119000000003	37.086838999999998	57.092210999999999	57.087691999999997	0103000020E6100000010000000500000091813CBB7C894240770FD07D398B4C4091813CBB7C8942406DAAEE91CD8B4C403882548A1D8B42406DAAEE91CD8B4C403882548A1D8B4240770FD07D398B4C4091813CBB7C894240770FD07D398B4C40
27267	Неклюдово	1	15	1769	37.336669000000001	37.359440999999997	57.141582999999997	57.133851999999997	0103000020E61000000100000005000000DC4944F817AB42408940F50F22914C40DC4944F817AB4240B45549641F924C40B7EBA52902AE4240B45549641F924C40B7EBA52902AE42408940F50F22914C40DC4944F817AB42408940F50F22914C40
27230	Малое Василево	1	15	1769	37.062575000000002	37.069482999999998	56.993400999999999	56.989624999999997	0103000020E610000001000000050000000B46257502884240E9263108AC7E4C400B46257502884240276893C3277F4C406150A6D1E4884240276893C3277F4C406150A6D1E4884240E9263108AC7E4C400B46257502884240E9263108AC7E4C40
27145	Кучино	1	15	1769	37.051983999999997	37.067335999999997	56.925502000000002	56.914458000000003	0103000020E6100000010000000500000027F56569A786424065C8B1F50C754C4027F56569A7864240F9307BD976764C40F6EB4E779E884240F9307BD976764C40F6EB4E779E88424065C8B1F50C754C4027F56569A786424065C8B1F50C754C40
27192	Красное	1	15	1769	36.864856000000003	36.893143999999999	57.292265999999998	57.281894999999999	0103000020E61000000100000005000000ECDFF599B36E4240F5F3A62215A44C40ECDFF599B36E4240CADDE7F868A54C402F4FE78A52724240CADDE7F868A54C402F4FE78A52724240F5F3A62215A44C40ECDFF599B36E4240F5F3A62215A44C40
27066	Кошкино	1	15	1769	36.743287000000002	36.766804999999998	57.091155000000001	57.082512999999999	0103000020E610000001000000050000005F454607245F4240573F36C98F8A4C405F454607245F4240F6EE8FF7AA8B4C4063B48EAA26624240F6EE8FF7AA8B4C4063B48EAA26624240573F36C98F8A4C405F454607245F4240573F36C98F8A4C40
27086	Ильинское	1	15	1769	37.162216000000001	37.192031	56.970078999999998	56.953310000000002	0103000020E61000000100000005000000A8716F7EC39442409279E40F067A4C40A8716F7EC3944240A8C4758C2B7C4C40BA68C87894984240A8C4758C2B7C4C40BA68C878949842409279E40F067A4C40A8716F7EC39442409279E40F067A4C40
27006	Горицы	1	15	1769	36.703392999999998	36.750644000000001	57.170537000000003	57.138041999999999	0103000020E610000001000000050000001F9E25C8085A4240BABC395CAB914C401F9E25C8085A424005E10A28D4954C402578431A1560424005E10A28D4954C402578431A15604240BABC395CAB914C401F9E25C8085A4240BABC395CAB914C40
40978	Белый Городок	1	15	1769	37.494906999999998	37.537630999999998	56.97392	56.958286999999999	0103000020E61000000100000005000000DEC7D11C59BF42404A97FE25A97A4C40DEC7D11C59BF4240CD751A69A97C4C406B28B517D1C44240CD751A69A97C4C406B28B517D1C442404A97FE25A97A4C40DEC7D11C59BF42404A97FE25A97A4C40
26882	Фенево	1	15	1794	37.472386999999998	37.481433000000003	57.632510000000003	57.627301000000003	0103000020E610000001000000050000001C075E2D77BC4240C2DF2F664BD04C401C075E2D77BC42404D327216F6D04C408B1BB7989FBD42404D327216F6D04C408B1BB7989FBD4240C2DF2F664BD04C401C075E2D77BC4240C2DF2F664BD04C40
26815	Федцово	1	15	1794	37.619315	37.638728	57.623224	57.616751000000001	0103000020E610000001000000050000000C76C3B645CF42403D635FB2F1CE4C400C76C3B645CF4240890AD5CDC5CF4C400E85CFD6C1D14240890AD5CDC5CF4C400E85CFD6C1D142403D635FB2F1CE4C400C76C3B645CF42403D635FB2F1CE4C40
26317	Стрелиха	1	15	1794	37.136541999999999	37.162522000000003	57.474924999999999	57.466884999999998	0103000020E61000000100000005000000E54350357A91424019FF3EE3C2BB4C40E54350357A914240C286A757CABC4C40B5705985CD944240C286A757CABC4C40B5705985CD94424019FF3EE3C2BB4C40E54350357A91424019FF3EE3C2BB4C40
26598	Страхиново	1	15	1794	37.371262999999999	37.382626999999999	57.546920999999998	57.537225999999997	0103000020E61000000100000005000000809BC58B85AF4240CB4752D2C3C44C40809BC58B85AF4240703FE08101C64C4086C8E9EBF9B04240703FE08101C64C4086C8E9EBF9B04240CB4752D2C3C44C40809BC58B85AF4240CB4752D2C3C44C40
26514	Петровское	1	15	1794	37.315415000000002	37.330165000000001	57.627459999999999	57.618659000000001	0103000020E610000001000000050000007CD5CA845FA842402330D63730CF4C407CD5CA845FA842402AC6F99B50D04C4055A4C2D842AA42402AC6F99B50D04C4055A4C2D842AA42402330D63730CF4C407CD5CA845FA842402330D63730CF4C40
26335	Никольское	1	15	1794	37.403863000000001	37.417580000000001	57.591501999999998	57.584130000000002	0103000020E61000000100000005000000408864C8B1B34240664E97C5C4CA4C40408864C8B1B3424061C26856B6CB4C405ABBED4273B5424061C26856B6CB4C405ABBED4273B54240664E97C5C4CA4C40408864C8B1B34240664E97C5C4CA4C40
26740	Матвеевское	1	15	1794	37.111874999999998	37.136893000000001	57.470999999999997	57.465172000000003	0103000020E61000000100000005000000B81E85EB518E4240E9818FC18ABB4C40B81E85EB518E42403F355EBA49BC4C409206B7B5859142403F355EBA49BC4C409206B7B585914240E9818FC18ABB4C40B81E85EB518E4240E9818FC18ABB4C40
26695	Лисково	1	15	1794	37.043019000000001	37.085428	57.568055000000001	57.556260999999999	0103000020E61000000100000005000000A60D87A5818542402785798F33C74C40A60D87A58185424026AAB706B6C84C40D314014EEF8A424026AAB706B6C84C40D314014EEF8A42402785798F33C74C40A60D87A5818542402785798F33C74C40
26140	Кесова Гора	1	15	1794	37.274864999999998	37.320912999999997	57.596725999999997	57.572467000000003	0103000020E6100000010000000500000053E8BCC62EA342400685419946C94C4053E8BCC62EA3424021567F8461CC4C403DEE5BAD13A9424021567F8461CC4C403DEE5BAD13A942400685419946C94C4053E8BCC62EA342400685419946C94C40
26649	Завидовская Горка	1	15	1794	37.267327999999999	37.278961000000002	57.512821000000002	57.500593000000002	0103000020E610000001000000050000000DA7CCCD37A24240A3CD716E13C04C400DA7CCCD37A24240DCD9571EA4C14C4003EE79FEB4A34240DCD9571EA4C14C4003EE79FEB4A34240A3CD716E13C04C400DA7CCCD37A24240A3CD716E13C04C40
26540	Елисеево	1	15	1794	37.309648000000003	37.328538999999999	57.543072000000002	57.534993999999998	0103000020E61000000100000005000000CBA2B08BA2A7424032C7F2AE7AC44C40CBA2B08BA2A74240C9AF1F6283C54C40F33AE2900DAA4240C9AF1F6283C54C40F33AE2900DAA424032C7F2AE7AC44C40CBA2B08BA2A7424032C7F2AE7AC44C40
26394	Горка-Ширятская	1	15	1794	37.223374	37.233282000000003	57.640825999999997	57.637872999999999	0103000020E610000001000000050000006B63EC84979C42402E008DD2A5D14C406B63EC84979C424097361C9606D24C406C5F402FDC9D424097361C9606D24C406C5F402FDC9D42402E008DD2A5D14C406B63EC84979C42402E008DD2A5D14C40
26248	Борисовское	1	15	1794	36.974620999999999	36.997672000000001	57.469354000000003	57.459629	0103000020E61000000100000005000000567F8461C07C424087A5811FD5BA4C40567F8461C07C4240971FB8CA13BC4C40451152B7B37F4240971FB8CA13BC4C40451152B7B37F424087A5811FD5BA4C40567F8461C07C424087A5811FD5BA4C40
26008	Шепели	1	15	1760	37.749490000000002	37.755527000000001	57.526403000000002	57.521551000000002	0103000020E61000000100000005000000EB56CF49EFDF42401A19E42EC2C24C40EB56CF49EFDF424016C26A2C61C34C405C1FD61BB5E0424016C26A2C61C34C405C1FD61BB5E042401A19E42EC2C24C40EB56CF49EFDF42401A19E42EC2C24C40
25984	Филипищево	1	15	1760	37.740264000000003	37.756262999999997	57.445790000000002	57.441110999999999	0103000020E61000000100000005000000FD3383F8C0DE4240F373435376B84C40FD3383F8C0DE424022718FA50FB94C406116DA39CDE0424022718FA50FB94C406116DA39CDE04240F373435376B84C40FD3383F8C0DE4240F373435376B84C40
25871	Фарафоновка	1	15	1760	37.660196999999997	37.680669999999999	57.344687	57.336590000000001	0103000020E610000001000000050000006AF5D55581D442409014916115AB4C406AF5D55581D442409D2D20B41EAC4C4025AFCE3120D742409D2D20B41EAC4C4025AFCE3120D742409014916115AB4C406AF5D55581D442409014916115AB4C40
25777	Уницы	1	15	1760	37.242291999999999	37.261327000000001	57.460858999999999	57.452055999999999	0103000020E610000001000000050000008D0A9C6C039F4240F4FA93F8DCB94C408D0A9C6C039F42409C887E6DFDBA4C40E947C32973A142409C887E6DFDBA4C40E947C32973A14240F4FA93F8DCB94C408D0A9C6C039F4240F4FA93F8DCB94C40
25034	Тиволино	1	15	1760	37.612093000000002	37.620061	57.247326999999999	57.241512999999998	0103000020E61000000100000005000000268E3C1059CE42408847E2E5E99E4C40268E3C1059CE42407A354069A89F4C403543AA285ECF42407A354069A89F4C403543AA285ECF42408847E2E5E99E4C40268E3C1059CE42408847E2E5E99E4C40
25242	Тетьково	1	15	1760	37.166223000000002	37.178485000000002	57.253442999999997	57.246602000000003	0103000020E61000000100000005000000E86B96CB46954240699082A7909F4C40E86B96CB469542403733FAD170A04C40CDE9B298D89642403733FAD170A04C40CDE9B298D8964240699082A7909F4C40E86B96CB46954240699082A7909F4C40
25748	Спасское	1	15	1760	37.092516000000003	37.116815000000003	57.325688	57.316406000000001	0103000020E61000000100000005000000AA2D7590D78B42400C21E7FD7FA84C40AA2D7590D78B42408E59F624B0A94C4054573ECBF38E42408E59F624B0A94C4054573ECBF38E42400C21E7FD7FA84C40AA2D7590D78B42400C21E7FD7FA84C40
25693	Славково	1	15	1760	37.070740999999998	37.082068999999997	57.346747000000001	57.340656000000003	0103000020E6100000010000000500000040BE840A0E894240D597A59D9AAB4C4040BE840A0E894240397EA83462AC4C40F981AB3C818A4240397EA83462AC4C40F981AB3C818A4240D597A59D9AAB4C4040BE840A0E894240D597A59D9AAB4C40
25832	Савцыно	1	15	1760	37.140692999999999	37.16395	57.427269000000003	57.416815	0103000020E6100000010000000500000058E36C3A02924240BABDA4315AB54C4058E36C3A029242401DCC26C0B0B64C40F0164850FC9442401DCC26C0B0B64C40F0164850FC944240BABDA4315AB54C4058E36C3A02924240BABDA4315AB54C40
25646	Путилово	1	15	1760	37.537038000000003	37.557969	57.359211000000002	57.351472000000001	0103000020E61000000100000005000000C95A43A9BDC44240D8BAD408FDAC4C40C95A43A9BDC4424086AE44A0FAAD4C40469737876BC7424086AE44A0FAAD4C40469737876BC74240D8BAD408FDAC4C40C95A43A9BDC44240D8BAD408FDAC4C40
25546	Письяковка	1	15	1760	37.581209000000001	37.601770999999999	57.347490000000001	57.336173000000002	0103000020E610000001000000050000000892770E65CA42402C6684B707AB4C400892770E65CA4240F1D7648D7AAC4C40325706D506CD4240F1D7648D7AAC4C40325706D506CD42402C6684B707AB4C400892770E65CA42402C6684B707AB4C40
25440	Пестриково	1	15	1760	37.627454	37.656334999999999	57.379027000000001	57.365720000000003	0103000020E6100000010000000500000048DFA46950D042401FBFB7E9CFAE4C4048DFA46950D0424087A6ECF483B04C402E1C08C902D4424087A6ECF483B04C402E1C08C902D442401FBFB7E9CFAE4C4048DFA46950D042401FBFB7E9CFAE4C40
25593	Никольское	1	15	1760	37.515075000000003	37.535654999999998	57.331221999999997	57.324041000000001	0103000020E610000001000000050000005DFE43FAEDC1424015C8EC2C7AA94C405DFE43FAEDC142409CDB847B65AA4C402D78D15790C442409CDB847B65AA4C402D78D15790C4424015C8EC2C7AA94C405DFE43FAEDC1424015C8EC2C7AA94C40
25349	Лобково	1	15	1760	37.452587999999999	37.469099	57.392246999999998	57.383816000000003	0103000020E61000000100000005000000F1475167EEB942403DD7F7E120B14C40F1475167EEB94240207A522635B24C400CCB9F6F0BBC4240207A522635B24C400CCB9F6F0BBC42403DD7F7E120B14C40F1475167EEB942403DD7F7E120B14C40
25155	Леушино	1	15	1760	37.405974000000001	37.419916000000001	57.284517000000001	57.277695999999999	0103000020E610000001000000050000005E83BEF4F6B34240711DE38A8BA34C405E83BEF4F6B34240F913950D6BA44C409888B7CEBFB54240F913950D6BA44C409888B7CEBFB54240711DE38A8BA34C405E83BEF4F6B34240711DE38A8BA34C40
25065	Коробово	1	15	1760	37.605049999999999	37.616827000000001	57.179806999999997	57.168174999999998	0103000020E61000000100000005000000EF38454772CD42409D8026C286954C40EF38454772CD4240C24B70EA03974C401825E82FF4CE4240C24B70EA03974C401825E82FF4CE42409D8026C286954C40EF38454772CD42409D8026C286954C40
26069	Козьмодемьяновское	1	15	1760	37.658904	37.674579000000001	57.499636000000002	57.490488999999997	0103000020E610000001000000050000000F9A5DF756D442401C06F357C8BE4C400F9A5DF756D44240BFF38B12F4BF4C40C1C8CB9A58D64240BFF38B12F4BF4C40C1C8CB9A58D642401C06F357C8BE4C400F9A5DF756D442401C06F357C8BE4C40
25391	Карабузино	1	15	1760	37.905321000000001	37.913549000000003	57.342146999999997	57.337269999999997	0103000020E61000000100000005000000E6B0FB8EE1F3424001F6D1A92BAB4C40E6B0FB8EE1F3424056B60F79CBAB4C409225732CEFF4424056B60F79CBAB4C409225732CEFF4424001F6D1A92BAB4C40E6B0FB8EE1F3424001F6D1A92BAB4C40
26093	Данильцево	1	15	1760	37.693021999999999	37.711742999999998	57.575507000000002	57.566723000000003	0103000020E610000001000000050000004AB4E4F1B4D842400D7217618AC84C404AB4E4F1B4D842403ECF9F36AAC94C40161406651ADB42403ECF9F36AAC94C40161406651ADB42400D7217618AC84C404AB4E4F1B4D842400D7217618AC84C40
25288	Давыдово	1	15	1760	37.308453	37.340262000000003	57.406624999999998	57.398882	0103000020E6100000010000000500000032AD4D637BA74240467BBC900EB34C4032AD4D637BA74240355EBA490CB44C40290989B48DAB4240355EBA490CB44C40290989B48DAB4240467BBC900EB34C4032AD4D637BA74240467BBC900EB34C40
25194	Верхняя Троица	1	15	1760	37.133361999999998	37.150314000000002	57.261567999999997	57.249381999999997	0103000020E61000000100000005000000BB438A0112914240041BD7BFEB9F4C40BB438A01129142400ED76A0F7BA14C40C310397D3D9342400ED76A0F7BA14C40C310397D3D934240041BD7BFEB9F4C40BB438A0112914240041BD7BFEB9F4C40
25117	Булатово	1	15	1760	37.346370999999998	37.360582000000001	57.279482000000002	57.271585000000002	0103000020E6100000010000000500000033A48AE255AC4240C68A1A4CC3A24C4033A48AE255AC42400CE9F010C6A34C405DC30C8D27AE42400CE9F010C6A34C405DC30C8D27AE4240C68A1A4CC3A24C4033A48AE255AC4240C68A1A4CC3A24C40
25488	Бузыково	1	15	1760	37.543478999999998	37.567805999999997	57.459744999999998	57.451838000000002	0103000020E61000000100000005000000098849B890C54240878BDCD3D5B94C40098849B890C54240F0BF95ECD8BA4C407D3CF4DDADC84240F0BF95ECD8BA4C407D3CF4DDADC84240878BDCD3D5B94C40098849B890C54240878BDCD3D5B94C40
24973	Барыково	1	15	1760	37.559074000000003	37.577624	57.242505999999999	57.230333000000002	0103000020E610000001000000050000009F05A1BC8FC7424044183F8D7B9D4C409F05A1BC8FC74240B98AC56F0A9F4C403EB14E95EFC94240B98AC56F0A9F4C403EB14E95EFC9424044183F8D7B9D4C409F05A1BC8FC7424044183F8D7B9D4C40
24022	Яринское	1	15	203	38.094271999999997	38.107126999999998	56.937407999999998	56.923394999999999	0103000020E61000000100000005000000D976DA1A110C43401C25AFCE31764C40D976DA1A110C43401F813FFCFC774C4061C26856B60D43401F813FFCFC774C4061C26856B60D43401C25AFCE31764C40D976DA1A110C43401C25AFCE31764C40
23695	Чигирево	1	15	203	37.902867999999998	37.912452999999999	57.263564000000002	57.260292999999997	0103000020E610000001000000050000006E4DBA2D91F342405930F14751A14C406E4DBA2D91F3424094331477BCA14C408C118942CBF4424094331477BCA14C408C118942CBF442405930F14751A14C406E4DBA2D91F342405930F14751A14C40
24528	Тимирязево	1	15	203	38.031094000000003	38.045026999999997	57.121814000000001	57.113022999999998	0103000020E61000000100000005000000098D60E3FA0343401059A489778E4C40098D60E3FA034340F418E599978F4C40EF37DA71C3054340F418E599978F4C40EF37DA71C30543401059A489778E4C40098D60E3FA0343401059A489778E4C40
24467	Старобислово	1	15	203	38.167870999999998	38.183717999999999	57.116287	57.104976999999998	0103000020E61000000100000005000000317903CC7C15434085EAE6E26F8D4C40317903CC7C15434098F90E7EE28E4C40E0D748128417434098F90E7EE28E4C40E0D748128417434085EAE6E26F8D4C40317903CC7C15434085EAE6E26F8D4C40
23632	Спасское	1	15	203	37.859507000000001	37.874661000000003	57.109557000000002	57.102347000000002	0103000020E610000001000000050000006FD74B5304EE4240FFEBDCB4198D4C406FD74B5304EE42402106BAF6058E4C40180B43E4F4EF42402106BAF6058E4C40180B43E4F4EF4240FFEBDCB4198D4C406FD74B5304EE4240FFEBDCB4198D4C40
24173	Семендяево	1	15	203	38.208215000000003	38.230125000000001	57.311773000000002	57.298126000000003	0103000020E61000000100000005000000B1C403CAA61A43402D0B26FE28A64C40B1C403CAA61A43404E637B2DE8A74C40FA7E6ABC741D43404E637B2DE8A74C40FA7E6ABC741D43402D0B26FE28A64C40B1C403CAA61A43402D0B26FE28A64C40
23974	Поречье	1	15	203	37.912795000000003	37.93289	57.091189	57.081290000000003	0103000020E61000000100000005000000E6797077D6F44240F5BEF1B5678A4C40E6797077D6F44240A260C614AC8B4C40FA6184F068F74240A260C614AC8B4C40FA6184F068F74240F5BEF1B5678A4C40E6797077D6F44240F5BEF1B5678A4C40
24425	Плоховка	1	15	203	38.081696000000001	38.092458000000001	57.172629999999998	57.166330000000002	0103000020E61000000100000005000000651BB803750A4340FE2B2B4D4A954C40651BB803750A43407C2766BD18964C407520EBA9D50B43407C2766BD18964C407520EBA9D50B4340FE2B2B4D4A954C40651BB803750A4340FE2B2B4D4A954C40
24361	Пенье	1	15	203	38.056741000000002	38.075119999999998	57.054582000000003	57.045200999999999	0103000020E61000000100000005000000D2AB014A430743408D5F7825C9854C40D2AB014A43074340A379008BFC864C4044A33B889D094340A379008BFC864C4044A33B889D0943408D5F7825C9854C40D2AB014A430743408D5F7825C9854C40
22397	Никольское	1	15	203	38.019613	38.033842999999997	57.190913999999999	57.186591999999997	0103000020E61000000100000005000000C9C9C4AD82024340FDD8243FE2974C40C9C9C4AD820243409D2CB5DE6F984C406919A9F7540443409D2CB5DE6F984C406919A9F754044340FDD8243FE2974C40C9C9C4AD82024340FDD8243FE2974C40
23898	Нерль	1	15	203	37.981929000000001	38.009076	57.054675000000003	57.026311	0103000020E610000001000000050000003BFF76D9AFFD42403543AA285E834C403BFF76D9AFFD424054742497FF864C40D99601672901434054742497FF864C40D9960167290143403543AA285E834C403BFF76D9AFFD42403543AA285E834C40
24112	Малахово	1	15	203	38.046526999999998	38.061779999999999	57.265296999999997	57.259946999999997	0103000020E61000000100000005000000C4B0C398F4054340BED87BF145A14C40C4B0C398F40543400B5D8940F5A14C4000C63368E80743400B5D8940F5A14C4000C63368E8074340BED87BF145A14C40C4B0C398F4054340BED87BF145A14C40
24322	Липовка	1	15	203	37.972614	37.988531999999999	57.207945000000002	57.202539000000002	0103000020E61000000100000005000000DDD0949D7EFC4240109546CCEC994C40DDD0949D7EFC4240F12E17F19D9A4C405586713788FE4240F12E17F19D9A4C405586713788FE4240109546CCEC994C40DDD0949D7EFC4240109546CCEC994C40
23871	Крюково	1	15	203	37.838476999999997	37.850002000000003	56.977829999999997	56.973109999999998	0103000020E610000001000000050000005EB9DE3653EB42408DB454DE8E7C4C405EB9DE3653EB42401A868F88297D4C406EC493DDCCEC42401A868F88297D4C406EC493DDCCEC42408DB454DE8E7C4C405EB9DE3653EB42408DB454DE8E7C4C40
23821	Капшино	1	15	203	37.788395999999999	37.804557000000003	57.093522	57.085638000000003	0103000020E610000001000000050000000B26FE28EAE44240BEA59C2FF68A4C400B26FE28EAE442406FBA6587F88B4C404A6249B9FBE642406FBA6587F88B4C404A6249B9FBE64240BEA59C2FF68A4C400B26FE28EAE44240BEA59C2FF68A4C40
766	Калязин	1	15	203	37.803334999999997	37.861474000000001	57.249527999999998	57.228341	0103000020E61000000100000005000000B75D68AED3E6424000AB23473A9D4C40B75D68AED3E64240D8B79388F09F4C405A2DB0C744EE4240D8B79388F09F4C405A2DB0C744EE424000AB23473A9D4C40B75D68AED3E6424000AB23473A9D4C40
24269	Исаково	1	15	203	38.045081000000003	38.053362999999997	57.195644000000001	57.190094000000002	0103000020E61000000100000005000000E355D636C50543403A950C0055984C40E355D636C50543404ED4D2DC0A994C4081E84999D40643404ED4D2DC0A994C4081E84999D40643403A950C0055984C40E355D636C50543403A950C0055984C40
23606	Дымово	1	15	203	37.754089	37.776618999999997	57.234411000000001	57.227020000000003	0103000020E61000000100000005000000FDA204FD85E04240DBC4C9FD0E9D4C40FDA204FD85E042404D69FD2D019E4C40E2395B4068E342404D69FD2D019E4C40E2395B4068E34240DBC4C9FD0E9D4C40FDA204FD85E04240DBC4C9FD0E9D4C40
23776	Воронцово	1	15	203	37.941074	37.953595999999997	56.946618999999998	56.936248999999997	0103000020E61000000100000005000000D68EE21C75F84240D3F4D901D7774C40D68EE21C75F84240D862B7CF2A794C4057CC086F0FFA4240D862B7CF2A794C4057CC086F0FFA4240D3F4D901D7774C40D68EE21C75F84240D3F4D901D7774C40
23546	Василево	1	15	203	37.907746000000003	37.920636999999999	57.147306	57.139366000000003	0103000020E6100000010000000500000094895B0531F442405116BEBED6914C4094895B0531F4424096404AECDA924C40683EE76ED7F5424096404AECDA924C40683EE76ED7F542405116BEBED6914C4094895B0531F442405116BEBED6914C40
23730	Бителево	1	15	203	38.064816999999998	38.075299999999999	56.837961999999997	56.828626	0103000020E61000000100000005000000C79C67EC4B084340C24EB16A106A4C40C79C67EC4B08434037A5BC56426B4C40C4B12E6EA309434037A5BC56426B4C40C4B12E6EA3094340C24EB16A106A4C40C79C67EC4B084340C24EB16A106A4C40
24065	Баринцево	1	15	203	38.148046000000001	38.160290000000003	57.251835999999997	57.244649000000003	0103000020E61000000100000005000000DD26DC2BF3124340E3FF8EA8509F4C40DD26DC2BF31243404CFA7B293CA04C401CF0F961841443404CFA7B293CA04C401CF0F96184144340E3FF8EA8509F4C40DD26DC2BF3124340E3FF8EA8509F4C40
24200	Апухтино	1	15	203	38.146419999999999	38.156660000000002	57.028609000000003	57.021960999999997	0103000020E610000001000000050000007BBDFBE3BD124340CB64389ECF824C407BBDFBE3BD12434086AFAF75A9834C40B24B546F0D14434086AFAF75A9834C40B24B546F0D144340CB64389ECF824C407BBDFBE3BD124340CB64389ECF824C40
25472	Андрианово	1	15	203	38.263343999999996	38.270314999999997	57.351384000000003	57.348339000000003	0103000020E6100000010000000500000085CC9541B5214340EF75525F96AC4C4085CC9541B5214340392BA226FAAC4C40224F92AE99224340392BA226FAAC4C40224F92AE99224340EF75525F96AC4C4085CC9541B5214340EF75525F96AC4C40
23484	Алферово	1	15	203	37.849490000000003	37.862434999999998	57.205117999999999	57.198107	0103000020E61000000100000005000000B8239C16BCEC4240E90DF7915B994C40B8239C16BCEC424014E97E4E419A4C407FF6234564EE424014E97E4E419A4C407FF6234564EE4240E90DF7915B994C40B8239C16BCEC4240E90DF7915B994C40
23031	Эммаус	1	15	1614	36.125191999999998	36.135962999999997	56.776812999999997	56.771259000000001	0103000020E6100000010000000500000044DC9C4A0610424072DF6A9DB8624C4044DC9C4A06104240C70DBF9B6E634C40A73B4F3C67114240C70DBF9B6E634C40A73B4F3C6711424072DF6A9DB8624C4044DC9C4A0610424072DF6A9DB8624C40
40971	Чуприяновка	1	15	1614	36.032027999999997	36.060675000000003	56.768112000000002	56.749614000000001	0103000020E610000001000000050000003447567E19044240D74FFF59F35F4C403447567E1904424024D5777E51624C40A857CA32C407424024D5777E51624C40A857CA32C4074240D74FFF59F35F4C403447567E19044240D74FFF59F35F4C40
22845	Черногубово	1	15	1614	35.743112000000004	35.777230000000003	56.939613000000001	56.932727999999997	0103000020E61000000100000005000000F1A1444B1EDF4140200890A163774C40F1A1444B1EDF4140BFF2203D45784C402CBCCB457CE34140BFF2203D45784C402CBCCB457CE34140200890A163774C40F1A1444B1EDF4140200890A163774C40
22681	Тургиново	1	15	1614	35.949590000000001	36.006318	56.522257000000003	56.492840000000001	0103000020E61000000100000005000000E84D452A8CF9414090149161153F4C40E84D452A8CF94140B58D3F51D9424C4025B03907CF004240B58D3F51D9424C4025B03907CF00424090149161153F4C40E84D452A8CF9414090149161153F4C40
23260	Суховерково	1	15	1614	35.553432000000001	35.571137999999998	56.631253000000001	56.620845000000003	0103000020E61000000100000005000000AA471ADCD6C641404C7155D9774F4C40AA471ADCD6C641403E40F7E5CC504C405DC0CB0C1BC941403E40F7E5CC504C405DC0CB0C1BC941404C7155D9774F4C40AA471ADCD6C641404C7155D9774F4C40
22892	Старый Погост	1	15	1614	36.063504999999999	36.080851000000003	56.720996999999997	56.705539000000002	0103000020E61000000100000005000000F5108DEE20084240BA86191A4F5A4C40F5108DEE20084240CEC133A1495C4C40A96C5853590A4240CEC133A1495C4C40A96C5853590A4240BA86191A4F5A4C40F5108DEE20084240BA86191A4F5A4C40
22132	Старые Мермерины	1	15	1614	35.607726999999997	35.625774	56.920816000000002	56.910542	0103000020E61000000100000005000000B6F292FFC9CD414035D1E7A38C744C40B6F292FFC9CD414018D1764CDD754C40F357C85C19D0414018D1764CDD754C40F357C85C19D0414035D1E7A38C744C40B6F292FFC9CD414035D1E7A38C744C40
22552	Славное	1	15	1614	36.042645999999998	36.060845999999998	57.000843000000003	56.988100000000003	0103000020E6100000010000000500000011A7936C75054240BC96900F7A7E4C4011A7936C750542401CB7989F1B804C40D40B3ECDC90742401CB7989F1B804C40D40B3ECDC9074240BC96900F7A7E4C4011A7936C75054240BC96900F7A7E4C40
21525	Савино	1	15	1614	35.759667999999998	35.763269999999999	56.725752999999997	56.723239999999997	0103000020E61000000100000005000000ABE80FCD3CE141405B94D920935C4C40ABE80FCD3CE14140A8FC6B79E55C4C404B02D4D4B2E14140A8FC6B79E55C4C404B02D4D4B2E141405B94D920935C4C40ABE80FCD3CE141405B94D920935C4C40
21655	Савватьево	1	15	1614	36.099086999999997	36.113784000000003	56.83419	56.827562	0103000020E61000000100000005000000B83A00E2AE0C4240C8B4368DED694C40B83A00E2AE0C42403B53E8BCC66A4C406F675F79900E42403B53E8BCC66A4C406F675F79900E4240C8B4368DED694C40B83A00E2AE0C4240C8B4368DED694C40
21326	Рязаново	1	15	1614	35.746786	35.768022000000002	56.710509999999999	56.697771000000003	0103000020E610000001000000050000002A8E03AF96DF4140728C648F50594C402A8E03AF96DF414090BDDEFDF15A4C40E44D7E8B4EE2414090BDDEFDF15A4C40E44D7E8B4EE24140728C648F50594C402A8E03AF96DF4140728C648F50594C40
22188	Романово	1	15	1614	35.516170000000002	35.527678000000002	56.967703999999998	56.953879000000001	0103000020E610000001000000050000009296CADB11C24140ACAB02B5187A4C409296CADB11C24140AC1A84B9DD7B4C40CB68E4F38AC34140AC1A84B9DD7B4C40CB68E4F38AC34140ACAB02B5187A4C409296CADB11C24140ACAB02B5187A4C40
21606	Рождествено	1	15	1614	36.540376000000002	36.564289000000002	56.870406000000003	56.850954000000002	0103000020E610000001000000050000008BC56F0A2B4542404033880FEC6C4C408BC56F0A2B454240001FBC76696F4C400C3F389F3A484240001FBC76696F4C400C3F389F3A4842404033880FEC6C4C408BC56F0A2B4542404033880FEC6C4C40
21277	Пушкино	1	15	1614	35.750900000000001	35.770330999999999	56.600935999999997	56.582796000000002	0103000020E610000001000000050000008048BF7D1DE04140AC1E300F994A4C408048BF7D1DE04140997E8978EB4C4C40280CCA349AE24140997E8978EB4C4C40280CCA349AE24140AC1E300F994A4C408048BF7D1DE04140AC1E300F994A4C40
21245	Полубратово	1	15	1614	35.581397000000003	35.595410999999999	56.556522000000001	56.549700999999999	0103000020E610000001000000050000000B7F86376BCA41400CCA349A5C464C400B7F86376BCA414094C0E61C3C474C40DE567A6D36CC414094C0E61C3C474C40DE567A6D36CC41400CCA349A5C464C400B7F86376BCA41400CCA349A5C464C40
21186	Петровское	1	15	1614	35.693964999999999	35.718848000000001	56.669593999999996	56.657978999999997	0103000020E61000000100000005000000C9C859D8D3D84140363AE7A738544C40C9C859D8D3D8414085CC9541B5554C40C365153603DC414085CC9541B5554C40C365153603DC4140363AE7A738544C40C9C859D8D3D84140363AE7A738544C40
21809	Первомайские Горки	1	15	1614	35.746948000000003	35.765667999999998	56.970319000000003	56.966796000000002	0103000020E6100000010000000500000004E8F7FD9BDF4140AAF3A8F8BF7B4C4004E8F7FD9BDF4140FED7B969337C4C40FFCBB56801E24140FED7B969337C4C40FFCBB56801E24140AAF3A8F8BF7B4C4004E8F7FD9BDF4140AAF3A8F8BF7B4C40
23215	Орша	1	15	1614	36.218266999999997	36.237651999999997	56.919100999999998	56.907784999999997	0103000020E61000000100000005000000E4654D2CF01B42405166834C32744C40E4654D2CF01B4240465C001AA5754C401CEA77616B1E4240465C001AA5754C401CEA77616B1E42405166834C32744C40E4654D2CF01B42405166834C32744C40
22374	Никулино	1	15	1614	35.823718	35.844298000000002	56.812117999999998	56.799748999999998	0103000020E61000000100000005000000329067976FE941401D01DC2C5E664C40329067976FE94140183F8D7BF3674C40030AF5F411EC4140183F8D7BF3674C40030AF5F411EC41401D01DC2C5E664C40329067976FE941401D01DC2C5E664C40
21156	Нестерово	1	15	1614	35.479968	35.506045999999998	56.469352999999998	56.459293000000002	0103000020E61000000100000005000000329067976FBD41401024EF1CCA3A4C40329067976FBD4140C6A354C2133C4C40C422861DC6C04140C6A354C2133C4C40C422861DC6C041401024EF1CCA3A4C40329067976FBD41401024EF1CCA3A4C40
21764	Мухино	1	15	1614	35.742097000000001	35.751798000000001	57.072302999999998	57.065657999999999	0103000020E61000000100000005000000D8BAD408FDDE4140425C397B67884C40D8BAD408FDDE41408B33863941894C405F99B7EA3AE041408B33863941894C405F99B7EA3AE04140425C397B67884C40D8BAD408FDDE4140425C397B67884C40
22278	Михайловское	1	15	1614	35.878838000000002	35.904125999999998	56.978138999999999	56.967973999999998	0103000020E61000000100000005000000B43D7AC37DF041406CB07092E67B4C40B43D7AC37DF0414098F8A3A8337D4C404DBB9866BAF3414098F8A3A8337D4C404DBB9866BAF341406CB07092E67B4C40B43D7AC37DF041406CB07092E67B4C40
21110	Митенево	1	15	1614	35.707709000000001	35.717779	56.507491999999999	56.493675000000003	0103000020E61000000100000005000000DD0A613596DA414029ED0DBE303F4C40DD0A613596DA4140A67D737FF5404C40B760A92EE0DB4140A67D737FF5404C40B760A92EE0DB414029ED0DBE303F4C40DD0A613596DA414029ED0DBE303F4C40
22051	Медное	1	15	1614	35.444898000000002	35.519430999999997	56.938616000000003	56.917785000000002	0103000020E610000001000000050000002507EC6AF2B8414033E197FA79754C402507EC6AF2B841404DC0AF9124784C40A8C30AB77CC241404DC0AF9124784C40A8C30AB77CC2414033E197FA79754C402507EC6AF2B8414033E197FA79754C40
22008	Кумордино	1	15	1614	35.387954000000001	35.411903000000002	56.862268	56.842343999999997	0103000020E610000001000000050000001B2D077AA8B14140ACFD9DEDD16B4C401B2D077AA8B1414094313ECC5E6E4C40E90FCD3CB9B4414094313ECC5E6E4C40E90FCD3CB9B44140ACFD9DEDD16B4C401B2D077AA8B14140ACFD9DEDD16B4C40
21708	Кулицкая	1	15	1614	35.667122999999997	35.694710999999998	56.983559	56.972217999999998	0103000020E6100000010000000500000067B4554964D54140904AB1A3717C4C4067B4554964D54140DE57E542E57D4C40F295404AECD84140DE57E542E57D4C40F295404AECD84140904AB1A3717C4C4067B4554964D54140904AB1A3717C4C40
22974	Кузьминское	1	15	1614	36.123323999999997	36.148116999999999	56.735391999999997	56.728144	0103000020E61000000100000005000000EC67B114C90F4240AA6395D2335D4C40EC67B114C90F4240B9DE3653215E4C40A67D737FF5124240B9DE3653215E4C40A67D737FF5124240AA6395D2335D4C40EC67B114C90F4240AA6395D2335D4C40
21845	Красная Гора	1	15	1614	35.597028000000002	35.617905	56.722583	56.713405000000002	0103000020E61000000100000005000000ED65DB696BCC4140C5E6E3DA505B4C40ED65DB696BCC4140A2D288997D5C4C407784D38217CF4140A2D288997D5C4C407784D38217CF4140C5E6E3DA505B4C40ED65DB696BCC4140C5E6E3DA505B4C40
21916	Колталово	1	15	1614	35.497098999999999	35.518487999999998	56.683118999999998	56.673060999999997	0103000020E61000000100000005000000E9EFA5F0A0BF4140459BE3DC26564C40E9EFA5F0A0BF41405B23827170574C4029AF95D05DC241405B23827170574C4029AF95D05DC24140459BE3DC26564C40E9EFA5F0A0BF4140459BE3DC26564C40
21054	Квакшино	1	15	1614	35.827697000000001	35.844935999999997	56.702584000000002	56.687336000000002	0103000020E61000000100000005000000A8FFACF9F1E9414086AE44A0FA574C40A8FFACF9F1E94140B058C345EE594C40459BE3DC26EC4140B058C345EE594C40459BE3DC26EC414086AE44A0FA574C40A8FFACF9F1E9414086AE44A0FA574C40
21565	Каблуково	1	15	1614	36.199860000000001	36.223252000000002	56.839725000000001	56.83126	0103000020E61000000100000005000000A8E33103951942408A3C49BA666A4C40A8E33103951942401A51DA1B7C6B4C4020628385931C42401A51DA1B7C6B4C4020628385931C42408A3C49BA666A4C40A8E33103951942408A3C49BA666A4C40
21012	Ильинское	1	15	1614	35.943615999999999	35.962426000000001	56.582320000000003	56.566125	0103000020E61000000100000005000000BDFDB968C8F841405839B4C876484C40BDFDB968C8F8414043E73576894A4C40F96871C630FB414043E73576894A4C40F96871C630FB41405839B4C876484C40BDFDB968C8F841405839B4C876484C40
22229	Загородный	1	15	1614	35.954934000000002	35.976008999999998	56.920988000000001	56.913809999999998	0103000020E6100000010000000500000053EBFD463BFA4140FE60E0B9F7744C4053EBFD463BFA414015014EEFE2754C4003CDE7DCEDFC414015014EEFE2754C4003CDE7DCEDFC4140FE60E0B9F7744C4053EBFD463BFA4140FE60E0B9F7744C40
21422	Заволжский	1	15	1614	35.738854000000003	35.769055000000002	56.898671999999998	56.887521999999997	0103000020E61000000100000005000000684293C492DE4140813D26529A714C40684293C492DE41405BEA20AF07734C40A3E9EC6470E241405BEA20AF07734C40A3E9EC6470E24140813D26529A714C40684293C492DE4140813D26529A714C40
20927	Езвино	1	15	1614	35.916451000000002	35.932755	56.649878999999999	56.641609000000003	0103000020E6100000010000000500000079B130444EF54140DEE8633E20524C4079B130444EF54140B8AD2D3C2F534C401A170E8464F74140B8AD2D3C2F534C401A170E8464F74140DEE8633E20524C4079B130444EF54140DEE8633E20524C40
22729	Дубровки	1	15	1614	35.530085	35.544790999999996	56.732849000000002	56.726562999999999	0103000020E61000000100000005000000D28C45D3D9C34140E8BD3104005D4C40D28C45D3D9C3414002F4FBFECD5D4C40DB1324B6BBC5414002F4FBFECD5D4C40DB1324B6BBC54140E8BD3104005D4C40D28C45D3D9C34140E8BD3104005D4C40
21953	Дмитровское	1	15	1614	35.427821000000002	35.746445000000001	56.990684000000002	56.842531000000001	0103000020E6100000010000000500000061C5A9D6C2B64140DF6E490ED86B4C4061C5A9D6C2B64140D255BABBCE7E4C40A1A17F828BDF4140D255BABBCE7E4C40A1A17F828BDF4140DF6E490ED86B4C4061C5A9D6C2B64140DF6E490ED86B4C40
40970	Дмитрово-Черкасский	1	15	1614	35.740614000000001	35.755696999999998	56.861628000000003	56.855403000000003	0103000020E61000000100000005000000D97A8670CCDE41403DF372D87D6D4C40D97A8670CCDE4140B1A888D3496E4C40B857E6ADBAE04140B1A888D3496E4C40B857E6ADBAE041403DF372D87D6D4C40D97A8670CCDE41403DF372D87D6D4C40
22325	Даниловское	1	15	1614	35.735242999999997	35.762794	56.805318	56.787208	0103000020E6100000010000000500000074CE4F711CDE41402593533BC3644C4074CE4F711CDE4140A87004A914674C40E2CAD93BA3E14140A87004A914674C40E2CAD93BA3E141402593533BC3644C4074CE4F711CDE41402593533BC3644C40
22487	Восток	1	15	1614	36.152006999999998	36.164583	57.014626	57.006162000000003	0103000020E61000000100000005000000ACE122F7741342402E3D9AEAC9804C40ACE122F774134240EDD5C743DF814C40213D450E11154240EDD5C743DF814C40213D450E111542402E3D9AEAC9804C40ACE122F7741342402E3D9AEAC9804C40
20095	Вахново	1	15	1614	35.659945999999998	35.682367999999997	56.503627000000002	56.497700000000002	0103000020E6100000010000000500000021904B1C79D441400F9C33A2B43F4C4021904B1C79D44140F9307BD976404C4020EBA9D557D74140F9307BD976404C4020EBA9D557D741400F9C33A2B43F4C4021904B1C79D441400F9C33A2B43F4C40
23166	Васильевский Мох	1	15	1614	35.908366000000001	35.935082000000001	57.022283999999999	57.000332999999998	0103000020E6100000010000000500000030664B5645F44140060E68E90A804C4030664B5645F44140AE9CBD33DA824C40058A58C4B0F74140AE9CBD33DA824C40058A58C4B0F74140060E68E90A804C4030664B5645F44140060E68E90A804C40
20722	Бурашево	1	15	1614	35.869109000000002	35.8949	56.740132000000003	56.724904000000002	0103000020E6100000010000000500000063D4B5F63EEF4140AB5E7EA7C95C4C4063D4B5F63EEF41408E5C37A5BC5E4C405F984C158CF241408E5C37A5BC5E4C405F984C158CF24140AB5E7EA7C95C4C4063D4B5F63EEF4140AB5E7EA7C95C4C40
22595	Большие Горки	1	15	1614	35.843795	35.860531000000002	56.4788	56.464440000000003	0103000020E61000000100000005000000A0C37C7901EC4140257A19C5723B4C40A0C37C7901EC414093A98251493D4C40DB183BE125EE414093A98251493D4C40DB183BE125EE4140257A19C5723B4C40A0C37C7901EC4140257A19C5723B4C40
21367	Большие Борки	1	15	1614	35.574444	35.599606000000001	56.832462	56.821522999999999	0103000020E6100000010000000500000014B1886187C94140B6F468AA27694C4014B1886187C94140D594641D8E6A4C40213EB0E3BFCC4140D594641D8E6A4C40213EB0E3BFCC4140B6F468AA27694C4014B1886187C94140B6F468AA27694C40
20913	Березино	1	15	1614	35.874094999999997	35.905715999999998	56.684275999999997	56.675286999999997	0103000020E610000001000000050000006E4C4F58E2EF4140FC34EECD6F564C406E4C4F58E2EF414006B8205B96574C4062BB7B80EEF3414006B8205B96574C4062BB7B80EEF34140FC34EECD6F564C406E4C4F58E2EF4140FC34EECD6F564C40
22438	Беле-Кушальское	1	15	1614	36.127715999999999	36.148736999999997	56.947758	56.937904000000003	0103000020E61000000100000005000000859675FF58104240D064FF3C0D784C40859675FF58104240DD42572250794C40425A63D009134240DD42572250794C40425A63D009134240D064FF3C0D784C40859675FF58104240D064FF3C0D784C40
41042	Андрейково	1	15	1614	35.231881000000001	36.695649000000003	57.091096	56.405450000000002	0103000020E610000001000000050000002AC8CF46AE9D4140E4141DC9E5334C402AC8CF46AE9D4140F165A208A98B4C40603FC4060B594240F165A208A98B4C40603FC4060B594240E4141DC9E5334C402AC8CF46AE9D4140E4141DC9E5334C40
40962	Щеколдино	1	15	1572	34.453535000000002	34.480449	56.065579999999997	56.053055000000001	0103000020E61000000100000005000000B24B546F0D3A4140D4F19881CA064C40B24B546F0D3A4140C6A2E9EC64084C40AD32535A7F3D4140C6A2E9EC64084C40AD32535A7F3D4140D4F19881CA064C40B24B546F0D3A4140D4F19881CA064C40
19183	Ульяново	1	15	1572	35.156385999999998	35.180253999999998	56.207102999999996	56.193250999999997	0103000020E61000000100000005000000B0C6D97404944140AB75E272BC184C40B0C6D97404944140A5F3E159821A4C40917C259012974140A5F3E159821A4C40917C259012974140AB75E272BC184C40B0C6D97404944140AB75E272BC184C40
19050	Столипино	1	15	1572	34.840907000000001	34.875051999999997	56.264347000000001	56.254997000000003	0103000020E610000001000000050000001EFD2FD7A26B414000CADFBDA3204C401EFD2FD7A26B4140DAE55B1FD6214C40522635B401704140DAE55B1FD6214C40522635B40170414000CADFBDA3204C401EFD2FD7A26B414000CADFBDA3204C40
19141	Старые Горки	1	15	1572	35.231960999999998	35.25	56.224666999999997	56.214081	0103000020E610000001000000050000004679E6E5B09D4140F5D89601671B4C404679E6E5B09D4140C6BE64E3C11C4C400000000000A04140C6BE64E3C11C4C400000000000A04140F5D89601671B4C404679E6E5B09D4140F5D89601671B4C40
20357	Старое Устиново	1	15	1572	34.896628999999997	34.919392999999999	55.992075	55.985064999999999	0103000020E6100000010000000500000095D233BDC472414095B7239C16FE4B4095D233BDC4724140F0164850FCFE4B40EE9579ABAE754140F0164850FCFE4B40EE9579ABAE75414095B7239C16FE4B4095D233BDC472414095B7239C16FE4B40
40965	Старое	1	15	1572	34.769050999999997	34.798972999999997	56.148663999999997	56.140369	0103000020E6100000010000000500000061FA5E4370624140A52F849CF7114C4061FA5E4370624140D80B056C07134C4089B14CBF44664140D80B056C07134C4089B14CBF44664140A52F849CF7114C4061FA5E4370624140A52F849CF7114C40
19057	Салино	1	15	1572	35.068126999999997	35.080119000000003	56.286611999999998	56.274698999999998	0103000020E61000000100000005000000BF7CB262B8884140389F3A5629234C40BF7CB262B88841401152B7B3AF244C40E564E256418A41401152B7B3AF244C40E564E256418A4140389F3A5629234C40BF7CB262B8884140389F3A5629234C40
41040	Рыльцово	1	15	1572	34.672319999999999	34.69388	56.099988000000003	56.09102	0103000020E610000001000000050000002E39EE940E56414016A4198BA60B4C402E39EE940E56414009FF2268CC0C4C409BAC510FD158414009FF2268CC0C4C409BAC510FD158414016A4198BA60B4C402E39EE940E56414016A4198BA60B4C40
20219	Раково	1	15	1572	34.854346	34.874558	56.084310000000002	56.069237999999999	0103000020E61000000100000005000000F5BBB0355B6D4140FAD170CADC084C40F5BBB0355B6D4140E65C8AABCA0A4C40433A3C84F16F4140E65C8AABCA0A4C40433A3C84F16F4140FAD170CADC084C40F5BBB0355B6D4140FAD170CADC084C40
40966	Погорелое-Городище	1	15	1572	34.922842000000003	34.965206999999999	56.146056000000002	56.127687999999999	0103000020E6100000010000000500000008B0C8AF1F764140BB0B941458104C4008B0C8AF1F7641403AB187F6B1124C40656F29E78B7B41403AB187F6B1124C40656F29E78B7B4140BB0B941458104C4008B0C8AF1F764140BB0B941458104C40
18960	Ошурково	1	15	1572	35.281827	35.298931000000003	56.292847000000002	56.285283	0103000020E610000001000000050000009D103AE812A44140698D412784244C409D103AE812A44140A9DDAF027C254C405B61FA5E43A64140A9DDAF027C254C405B61FA5E43A64140698D412784244C409D103AE812A44140698D412784244C40
20258	Орловка	1	15	1572	35.061093	35.077837000000002	56.163874999999997	56.156972000000003	0103000020E61000000100000005000000DC813AE5D1874140A13193A817144C40DC813AE5D1874140E5D022DBF9144C409AB51490F6894140E5D022DBF9144C409AB51490F6894140A13193A817144C40DC813AE5D1874140A13193A817144C40
20380	Новое	1	15	1572	35.002082000000001	35.021306000000003	56.054824000000004	56.042622000000001	0103000020E6100000010000000500000084F4143944804140890B40A374054C4084F414394480414099840B7904074C40B39AAE27BA82414099840B7904074C40B39AAE27BA824140890B40A374054C4084F4143944804140890B40A374054C40
19925	Никольское	1	15	1572	34.661971000000001	34.693762999999997	56.144024999999999	56.137008999999999	0103000020E6100000010000000500000041F33977BB544140FB20CB8289114C4041F33977BB544140386744696F124C406116DA39CD584140386744696F124C406116DA39CD584140FB20CB8289114C4041F33977BB544140FB20CB8289114C40
20618	Николо-Пустынь	1	15	1572	35.187683	35.206907000000001	56.039942000000003	56.028072999999999	0103000020E61000000100000005000000F1811DFF05984140477364E597034C40F1811DFF0598414051DEC7D11C054C402028B7ED7B9A414051DEC7D11C054C402028B7ED7B9A4140477364E597034C40F1811DFF05984140477364E597034C40
20581	Мерейкино	1	15	1572	35.269241000000001	35.283892999999999	56.188642999999999	56.176780000000001	0103000020E6100000010000000500000005DF347D76A241401F4B1FBAA0164C4005DF347D76A2414046CF2D7425184C401B48179B56A4414046CF2D7425184C401B48179B56A441401F4B1FBAA0164C4005DF347D76A241401F4B1FBAA0164C40
19860	Малое Коробино	1	15	1572	34.567936000000003	34.588202000000003	56.124426	56.111598999999998	0103000020E610000001000000050000004C1C7920B248414016A243E0480E4C404C1C7920B2484140D462F030ED0F4C408DB800344A4B4140D462F030ED0F4C408DB800344A4B414016A243E0480E4C404C1C7920B248414016A243E0480E4C40
20506	Княжьи Горы	1	15	1572	35.214677999999999	35.252837999999997	56.085645999999997	56.064957	0103000020E61000000100000005000000D99596917A9B4140B952CF8250084C40D99596917A9B41404084B872F60A4C40D097DEFE5CA041404084B872F60A4C40D097DEFE5CA04140B952CF8250084C40D99596917A9B4140B952CF8250084C40
40963	Карамзино	1	15	1572	34.545622000000002	34.586989000000003	56.011032	55.996540000000003	0103000020E6100000010000000500000033FD12F1D6454140F3936A9F8EFF4B4033FD12F1D6454140D09A1F7F69014C404E0E9F74224B4140D09A1F7F69014C404E0E9F74224B4140F3936A9F8EFF4B4033FD12F1D6454140F3936A9F8EFF4B40
19747	Игнатово	1	15	1572	34.490034000000001	34.503176000000003	55.997638000000002	55.985604000000002	0103000020E61000000100000005000000CBF6216FB93E41404567994528FE4B40CBF6216FB93E4140999F1B9AB2FF4B40E910381268404140999F1B9AB2FF4B40E9103812684041404567994528FE4B40CBF6216FB93E41404567994528FE4B40
19639	Зуево	1	15	1572	34.529730000000001	34.545504999999999	56.172871000000001	56.166224999999997	0103000020E61000000100000005000000E4DA5031CE43414088635DDC46154C40E4DA5031CE434140A2B60DA320164C40F9669B1BD3454140A2B60DA320164C40F9669B1BD345414088635DDC46154C40E4DA5031CE43414088635DDC46154C40
19301	Зубцов	1	15	1572	34.548074	34.606383999999998	56.183442999999997	56.159103000000002	0103000020E61000000100000005000000DAE4F0492746414006D9B27C5D144C40DAE4F049274641400ED76A0F7B174C40A968ACFD9D4D41400ED76A0F7B174C40A968ACFD9D4D414006D9B27C5D144C40DAE4F0492746414006D9B27C5D144C40
18931	Дорожаево	1	15	1572	35.370392000000002	35.403934999999997	56.269126	56.254021999999999	0103000020E610000001000000050000009B594B0169AF4140753BFBCA83204C409B594B0169AF41406C4084B872224C40D95A5F24B4B341406C4084B872224C40D95A5F24B4B34140753BFBCA83204C409B594B0169AF4140753BFBCA83204C40
19539	Брычево	1	15	1572	34.594552999999998	34.609357000000003	56.207858999999999	56.198154000000002	0103000020E610000001000000050000008D5E0D501A4C41402AC93A1C5D194C408D5E0D501A4C4140F296AB1F9B1A4C405A4B0169FF4D4140F296AB1F9B1A4C405A4B0169FF4D41402AC93A1C5D194C408D5E0D501A4C41402AC93A1C5D194C40
19605	Борки	1	15	1572	34.534914000000001	34.732669000000001	56.211809000000002	56.195320000000002	0103000020E610000001000000050000001616DC0F784441409B20EA3E00194C401616DC0F78444140CEFFAB8E1C1B4C4082E50819C85D4140CEFFAB8E1C1B4C4082E50819C85D41409B20EA3E00194C401616DC0F784441409B20EA3E00194C40
40959	Большое Пищалино	1	15	1572	34.675077999999999	34.687052000000001	56.218366000000003	56.210807000000003	0103000020E61000000100000005000000E21FB6F4685641404A6249B9FB1A4C40E21FB6F4685641407847C66AF31B4C406153E751F15741407847C66AF31B4C406153E751F15741404A6249B9FB1A4C40E21FB6F4685641404A6249B9FB1A4C40
19236	Белавино	1	15	1572	35.182338000000001	35.199209000000003	56.301983	56.290474000000003	0103000020E61000000100000005000000B66801DA569741404E2B85402E254C40B66801DA5697414057790261A7264C40D10836AE7F99414057790261A7264C40D10836AE7F9941404E2B85402E254C40B66801DA569741404E2B85402E254C40
18739	Шарапово	1	15	1504	31.777652	31.96593	56.157843999999997	56.136812999999997	0103000020E6100000010000000500000043AB933314C73F407555A01683114C4043AB933314C73F4056EF703B34144C40AC39403047F73F4056EF703B34144C40AC39403047F73F407555A01683114C4043AB933314C73F407555A01683114C40
40954	Фофаново	1	15	1504	32.045278000000003	32.059516000000002	56.215693000000002	56.204759000000003	0103000020E61000000100000005000000399D64ABCB054040E547FC8A351A4C40399D64ABCB054040F27C06D49B1B4C405CCB64389E074040F27C06D49B1B4C405CCB64389E074040E547FC8A351A4C40399D64ABCB054040E547FC8A351A4C40
17922	Улин	1	15	1504	31.903756999999999	31.932107999999999	56.290703999999998	56.281286000000001	0103000020E61000000100000005000000F487669E5CE73F404D69FD2D01244C40F487669E5CE73F407F68E6C935254C40085740A19EEE3F407F68E6C935254C40085740A19EEE3F404D69FD2D01244C40F487669E5CE73F404D69FD2D01244C40
17809	Старая Торопа	1	15	1504	31.643982000000001	31.695114	56.288321000000003	56.264676999999999	0103000020E6100000010000000500000072361D01DCA43F406F8099EFE0214C4072361D01DCA43F4001E0D8B3E7244C40E3FDB8FDF2B13F4001E0D8B3E7244C40E3FDB8FDF2B13F406F8099EFE0214C4072361D01DCA43F406F8099EFE0214C40
40955	Селяны	1	15	1504	31.706164000000001	31.718183	56.311290999999997	56.300944000000001	0103000020E61000000100000005000000D09CF529C7B43F40B6F63E5585264C40D09CF529C7B43F4002452C62D8274C400D8B51D7DAB73F4002452C62D8274C400D8B51D7DAB73F40B6F63E5585264C40D09CF529C7B43F40B6F63E5585264C40
18830	Севостьяново	1	15	1504	31.805966999999999	31.825711999999999	56.064464000000001	56.045267000000003	0103000020E61000000100000005000000BDA772DA53CE3F40454B1E4FCB054C40BDA772DA53CE3F407AE2395B40084C402DEA93DC61D33F407AE2395B40084C402DEA93DC61D33F40454B1E4FCB054C40BDA772DA53CE3F40454B1E4FCB054C40
18620	Пятиусово	1	15	1504	31.754987	31.779484	56.251987	56.241228999999997	0103000020E61000000100000005000000B8E7F9D346C13F4063EC8497E01E4C40B8E7F9D346C13F4032022A1C41204C4059C16F438CC73F4032022A1C41204C4059C16F438CC73F4063EC8497E01E4C40B8E7F9D346C13F4063EC8497E01E4C40
17905	Первомайский	1	15	1504	31.690991	31.69604	56.044970999999997	56.041877999999997	0103000020E6100000010000000500000091D442C9E4B03F40003620425C054C4091D442C9E4B03F405B22179CC1054C4035B56CAD2FB23F405B22179CC1054C4035B56CAD2FB23F40003620425C054C4091D442C9E4B03F40003620425C054C40
18514	Макеево	1	15	1504	31.610026000000001	31.626940999999999	56.218120999999996	56.210000999999998	0103000020E61000000100000005000000AFB5F7A92A9C3F404B901150E11A4C40AFB5F7A92A9C3F4010C99063EB1B4C40838593347FA03F4010C99063EB1B4C40838593347FA03F404B901150E11A4C40AFB5F7A92A9C3F404B901150E11A4C40
18297	Козино	1	15	1504	31.579241	31.601859999999999	55.985543999999997	55.970987999999998	0103000020E6100000010000000500000099805F2349943F407B67B45549FC4B4099805F2349943F406F62484E26FE4B4043C5387F139A3F406F62484E26FE4B4043C5387F139A3F407B67B45549FC4B4099805F2349943F407B67B45549FC4B40
18214	Ильино	1	15	1504	31.646920000000001	31.680516999999998	55.957459	55.935006999999999	0103000020E61000000100000005000000DA20938C9CA53F40FA43334FAEF74B40DA20938C9CA53F4064213A048EFA4B403D5FB35C36AE3F4064213A048EFA4B403D5FB35C36AE3F40FA43334FAEF74B40DA20938C9CA53F40FA43334FAEF74B40
17512	Западная Двина	1	15	1504	32.048825999999998	32.118059000000002	56.277113	56.233364000000002	0103000020E61000000100000005000000E5982CEE3F06404029081EDFDE1D4C40E5982CEE3F064040F225547078234C40CEFFAB8E1C0F4040F225547078234C40CEFFAB8E1C0F404029081EDFDE1D4C40E5982CEE3F06404029081EDFDE1D4C40
18110	Дуброво	1	15	1504	32.254584999999999	32.264619000000003	56.289749999999998	56.279516999999998	0103000020E61000000100000005000000AD86C43D9620404088D68A36C7234C40AD86C43D962040400C022B8716254C403B730F09DF2140400C022B8716254C403B730F09DF21404088D68A36C7234C40AD86C43D9620404088D68A36C7234C40
18407	Глазомичи	1	15	1504	31.466538	31.484397000000001	55.823368000000002	55.806494000000001	0103000020E610000001000000050000005C57CC086F773F40CA3505323BE74B405C57CC086F773F405649641F64E94B40D0471971017C3F405649641F64E94B40D0471971017C3F40CA3505323BE74B405C57CC086F773F40CA3505323BE74B40
18015	Велеса	1	15	1504	32.142026000000001	32.154269999999997	56.284284	56.273865000000001	0103000020E61000000100000005000000429770E82D124040704221020E234C40429770E82D1240405663096B63244C4080608E1EBF1340405663096B63244C4080608E1EBF134040704221020E234C40429770E82D124040704221020E234C40
18418	Васьково	1	15	1504	31.487532000000002	31.502893	55.929161999999998	55.916946000000003	0103000020E61000000100000005000000E4C0ABE5CE7C3F4059198D7C5EF54B40E4C0ABE5CE7C3F40CD57C9C7EEF64B4028637C98BD803F40CD57C9C7EEF64B4028637C98BD803F4059198D7C5EF54B40E4C0ABE5CE7C3F4059198D7C5EF54B40
18028	Бибирево	1	15	1504	32.289602000000002	32.310639999999999	56.381808999999997	56.373893000000002	0103000020E61000000100000005000000986DA7AD11254040079ACFB9DB2F4C40986DA7AD11254040C328081EDF304C402B6A300DC3274040C328081EDF304C402B6A300DC3274040079ACFB9DB2F4C40986DA7AD11254040079ACFB9DB2F4C40
17843	Бенцы	1	15	1504	31.725342999999999	31.75779	56.174700000000001	56.160851999999998	0103000020E61000000100000005000000ED612F14B0B93F4083BF5FCC96144C40ED612F14B0B93F403C4ED1915C164C40603C8386FEC13F403C4ED1915C164C40603C8386FEC13F4083BF5FCC96144C40ED612F14B0B93F4083BF5FCC96144C40
18145	Баево	1	15	1504	32.132136000000003	32.153649999999999	56.215088000000002	56.204174000000002	0103000020E61000000100000005000000E84F1BD5E9104040C558A65F221A4C40E84F1BD5E91040408BE1EA00881B4C40E4839ECDAA1340408BE1EA00881B4C40E4839ECDAA134040C558A65F221A4C40E84F1BD5E9104040C558A65F221A4C40
18645	Антоново	1	15	1504	31.641511999999999	31.653064000000001	56.264741999999998	56.257123	0103000020E61000000100000005000000D6FD63213AA43F4053060E68E9204C40D6FD63213AA43F4056F0DB10E3214C40E831CA332FA73F4056F0DB10E3214C40E831CA332FA73F4053060E68E9204C40D6FD63213AA43F4053060E68E9204C40
18318	Аксентьево	1	15	1504	31.621272999999999	31.642679999999999	55.831584999999997	55.821885999999999	0103000020E6100000010000000500000047E350BF0B9F3F402785798F33E94B4047E350BF0B9F3F400D6C956071EA4B4014CB2DAD86A43F400D6C956071EA4B4014CB2DAD86A43F402785798F33E94B4047E350BF0B9F3F402785798F33E94B40
17427	Щучье	1	15	1467	32.125902000000004	32.144424999999998	55.755343000000003	55.744602	0103000020E610000001000000050000002140868E1D104040A2444B1E4FDF4B402140868E1D1040409B215514AFE04B40C6DCB5847C1240409B215514AFE04B40C6DCB5847C124040A2444B1E4FDF4B402140868E1D104040A2444B1E4FDF4B40
17326	Троицкое	1	15	1467	32.032046000000001	32.045853000000001	55.852398999999998	55.842883	0103000020E61000000100000005000000DBFB54151A0440405CAD1397E3EB4B40DBFB54151A044040511212691BED4B4035B6D782DE054040511212691BED4B4035B6D782DE0540405CAD1397E3EB4B40DBFB54151A0440405CAD1397E3EB4B40
17228	Полоска	1	15	1467	31.679466000000001	31.697621000000002	55.780318999999999	55.774025999999999	0103000020E6100000010000000500000073BED87BF1AD3F407920B24813E34B4073BED87BF1AD3F4045B9347EE1E34B40B900344A97B23F4045B9347EE1E34B40B900344A97B23F407920B24813E34B4073BED87BF1AD3F407920B24813E34B40
17040	Новоселки	1	15	1467	31.803397	31.821497999999998	55.855719000000001	55.841867000000001	0103000020E610000001000000050000005BB4006DABCD3F40734A404CC2EB4B405BB4006DABCD3F406DC83F3388ED4B40BABA63B14DD23F406DC83F3388ED4B40BABA63B14DD23F40734A404CC2EB4B405BB4006DABCD3F40734A404CC2EB4B40
17128	Кривая Лука	1	15	1467	31.947586000000001	31.967590999999999	55.948276	55.940018000000002	0103000020E61000000100000005000000C02500FF94F23F405FD3838252F84B40C02500FF94F23F4075CAA31B61F94B4068E7340BB4F73F4075CAA31B61F94B4068E7340BB4F73F405FD3838252F84B40C02500FF94F23F405FD3838252F84B40
16918	Кривая	1	15	1467	32.261862000000001	32.299850999999997	55.817678999999998	55.808548000000002	0103000020E610000001000000050000005708ABB184214040849F38807EE74B405708ABB18421404020D099B4A9E84B4021567F846126404020D099B4A9E84B4021567F8461264040849F38807EE74B405708ABB184214040849F38807EE74B40
17204	Королевщина	1	15	1467	31.740227999999998	31.756218000000001	55.817202999999999	55.807870000000001	0103000020E610000001000000050000005F950B957FBD3F40B3B5BE4868E74B405F950B957FBD3F40B7989F1B9AE84B4083A5BA8097C13F40B7989F1B9AE84B4083A5BA8097C13F40B3B5BE4868E74B405F950B957FBD3F40B3B5BE4868E74B40
17020	Кащенки	1	15	1467	32.313693999999998	32.335783999999997	55.986595999999999	55.978332000000002	0103000020E61000000100000005000000C879FF1F27284040AD50A4FB39FD4B40C879FF1F27284040A52E19C748FE4B40914259F8FA2A4040A52E19C748FE4B40914259F8FA2A4040AD50A4FB39FD4B40C879FF1F27284040AD50A4FB39FD4B40
16944	Зеленьково	1	15	1467	32.154980000000002	32.167178999999997	56.063333	56.059196999999998	0103000020E610000001000000050000005DC47762D6134040BA826DC493074C405DC47762D6134040F8E0B54B1B084C40FBC9181F66154040F8E0B54B1B084C40FBC9181F66154040BA826DC493074C405DC47762D6134040BA826DC493074C40
16749	Жарковский	1	15	1467	32.223108000000003	32.314250999999999	55.866596000000001	55.833798999999999	0103000020E61000000100000005000000EDBC8DCD8E1C40400038F6ECB9EA4B40EDBC8DCD8E1C4040166C239EECEE4B401EDE736039284040166C239EECEE4B401EDE7360392840400038F6ECB9EA4B40EDBC8DCD8E1C40400038F6ECB9EA4B40
17106	Дубоцкое	1	15	1467	31.827176000000001	31.841557999999999	55.878622	55.868575999999997	0103000020E610000001000000050000003E096CCEC1D33F40950B957F2DEF4B403E096CCEC1D33F40E7C589AF76F04B40EAAF575870D73F40E7C589AF76F04B40EAAF575870D73F40950B957F2DEF4B403E096CCEC1D33F40950B957F2DEF4B40
17398	Гороватка	1	15	1467	32.228668999999996	32.247165000000003	55.725965000000002	55.719521	0103000020E61000000100000005000000F44D9A06451D404082E49D4319DC4B40F44D9A06451D40403485CE6BECDC4B40A1DB4B1AA31F40403485CE6BECDC4B40A1DB4B1AA31F404082E49D4319DC4B40F44D9A06451D404082E49D4319DC4B40
17309	Вороны	1	15	1467	32.124392	32.151395999999998	55.827049000000002	55.810657999999997	0103000020E6100000010000000500000028F1B913EC0F4040D11E2FA4C3E74B4028F1B913EC0F40404298DBBDDCE94B40635FB2F1601340404298DBBDDCE94B40635FB2F160134040D11E2FA4C3E74B4028F1B913EC0F4040D11E2FA4C3E74B40
40885	дер.Заречье	1	15	848	34.348081999999998	34.367646999999998	57.719267000000002	57.709898000000003	0103000020E61000000100000005000000C32973F38D2C414077BF0AF0DDDA4C40C32973F38D2C4140C80BE9F010DC4C407BBC900E0F2F4140C80BE9F010DC4C407BBC900E0F2F414077BF0AF0DDDA4C40C32973F38D2C414077BF0AF0DDDA4C40
15137	Трудовой	1	15	848	34.818772000000003	34.844554000000002	57.534621999999999	57.519333000000003	0103000020E61000000100000005000000B5705985CD684140E65DF58079C24C40B5705985CD6841406EDC627E6EC44C405EDA70581A6C41406EDC627E6EC44C405EDA70581A6C4140E65DF58079C24C40B5705985CD684140E65DF58079C24C40
15048	Терелесовский	1	15	848	34.715727000000001	34.785165999999997	57.573112999999999	57.552900000000001	0103000020E610000001000000050000009EEE3CF19C5B4140ADFA5C6DC5C64C409EEE3CF19C5B4140CBF44BC45BC94C402FF7C95180644140CBF44BC45BC94C402FF7C95180644140ADFA5C6DC5C64C409EEE3CF19C5B4140ADFA5C6DC5C64C40
14980	Старое	1	15	848	34.602269	34.693232999999999	57.742711999999997	57.508456000000002	0103000020E6100000010000000500000083328D26174D41403DBA111615C14C4083328D26174D4140622CD32F11DF4C4005C1E3DBBB584140622CD32F11DF4C4005C1E3DBBB5841403DBA111615C14C4083328D26174D41403DBA111615C14C40
14891	Сороки	1	15	848	34.606976000000003	34.628698	57.637915999999997	57.621214000000002	0103000020E610000001000000050000007CBABA63B14D41409FE8BAF083CF4C407CBABA63B14D41402DCC423BA7D14C40C287122D795041402DCC423BA7D14C40C287122D795041409FE8BAF083CF4C407CBABA63B14D41409FE8BAF083CF4C40
14773	Солнечный	1	15	848	34.427134000000002	34.467351000000001	57.674419999999998	57.660417000000002	0103000020E610000001000000050000003D81B053AC364140795C548B88D44C403D81B053AC36414058E2016553D64C405F605628D23B414058E2016553D64C405F605628D23B4140795C548B88D44C403D81B053AC364140795C548B88D44C40
14688	Садовый	1	15	848	34.482075000000002	34.499529000000003	57.747328000000003	57.730969999999999	0103000020E610000001000000050000000F9C33A2B43D4140B62DCA6C90DD4C400F9C33A2B43D41404BB1A371A8DF4C40A933F790F03F41404BB1A371A8DF4C40A933F790F03F4140B62DCA6C90DD4C400F9C33A2B43D4140B62DCA6C90DD4C40
14866	Подол	1	15	848	34.464252000000002	34.478786999999997	57.764923000000003	57.754508000000001	0103000020E61000000100000005000000228D0A9C6C3B41400249D8B793E04C40228D0A9C6C3B4140A77A32FFE8E14C40FE5F75E4483D4140A77A32FFE8E14C40FE5F75E4483D41400249D8B793E04C40228D0A9C6C3B41400249D8B793E04C40
13910	Осечно	1	15	848	34.945075000000003	34.961829000000002	57.643416999999999	57.634422999999998	0103000020E6100000010000000500000034A2B437F8784140446ADAC534D14C4034A2B437F87841406058FE7C5BD24C4015AC71361D7B41406058FE7C5BD24C4015AC71361D7B4140446ADAC534D14C4034A2B437F8784140446ADAC534D14C40
15065	Осеченка	1	15	848	34.790385999999998	34.821018000000002	57.550693000000003	57.53396	0103000020E61000000100000005000000AE9B525E2B654140A3AF20CD58C44C40AE9B525E2B6541406D91B41B7DC64C40B3B6291E176941406D91B41B7DC64C40B3B6291E17694140A3AF20CD58C44C40AE9B525E2B654140A3AF20CD58C44C40
14595	Овсище	1	15	848	34.998804	35.018754999999999	57.730932000000003	57.709378000000001	0103000020E61000000100000005000000978E39CFD87F41403E40F7E5CCDA4C40978E39CFD87F4140C9CC052E8FDD4C4078D1579066824140C9CC052E8FDD4C4078D15790668241403E40F7E5CCDA4C40978E39CFD87F41403E40F7E5CCDA4C40
14480	Лужниково	1	15	848	34.120530000000002	34.149850999999998	57.409742999999999	57.398125	0103000020E61000000100000005000000EC17EC866D0F4140295C8FC2F5B24C40EC17EC866D0F4140E961687572B44C40EE224C512E134140E961687572B44C40EE224C512E134140295C8FC2F5B24C40EC17EC866D0F4140295C8FC2F5B24C40
14669	Кузнецово	1	15	848	35.177945999999999	35.194529000000003	57.695365000000002	57.691088000000001	0103000020E610000001000000050000001D3A3DEFC69641403B54539275D84C401D3A3DEFC69641403BE466B801D94C40D28F8653E69841403BE466B801D94C40D28F8653E69841403B54539275D84C401D3A3DEFC69641403B54539275D84C40
15242	Красномайский	1	15	848	34.385398000000002	34.444614999999999	57.634003999999997	57.607239	0103000020E61000000100000005000000CFF8BEB85431414089EDEE01BACD4C40CFF8BEB8543141403FC4060B27D14C40D027F224E93841403FC4060B27D14C40D027F224E938414089EDEE01BACD4C40CFF8BEB85431414089EDEE01BACD4C40
14499	Красная Заря	1	15	848	34.060665999999998	34.087561999999998	57.474837000000001	57.458737999999997	0103000020E6100000010000000500000054FD4AE7C30741405AB741EDB7BA4C4054FD4AE7C307414023F77475C7BC4C40A92F4B3B350B414023F77475C7BC4C40A92F4B3B350B41405AB741EDB7BA4C4054FD4AE7C30741405AB741EDB7BA4C40
14294	Коломно	1	15	848	34.250318	34.289934000000002	57.707065	57.690232000000002	0103000020E61000000100000005000000D1CC936B0A2041408B53AD8559D84C40D1CC936B0A204140B8921D1B81DA4C40CEFFAB8E1C254140B8921D1B81DA4C40CEFFAB8E1C2541408B53AD8559D84C40D1CC936B0A2041408B53AD8559D84C40
14123	Княщины	1	15	848	34.577340999999997	34.591273999999999	57.302064999999999	57.292907999999997	0103000020E61000000100000005000000E9D1544FE64941404E5E64027EA54C40E9D1544FE64941401422E010AAA64C40D07CCEDDAE4B41401422E010AAA64C40D07CCEDDAE4B41404E5E64027EA54C40E9D1544FE64941404E5E64027EA54C40
14196	Ильинское	1	15	848	34.668367000000003	34.689630000000001	57.379089999999998	57.367434000000003	0103000020E61000000100000005000000E25CC30C8D55414020B8CA1308AF4C40E25CC30C8D554140CD1E680586B04C40952BBCCB45584140CD1E680586B04C40952BBCCB4558414020B8CA1308AF4C40E25CC30C8D55414020B8CA1308AF4C40
14102	Зеленогорский	1	15	848	34.544535000000003	34.576236000000002	57.511718999999999	57.501493000000004	0103000020E610000001000000050000008143A852B3454140231631EC30C04C408143A852B3454140F4DE180280C14C409163EB19C2494140F4DE180280C14C409163EB19C2494140231631EC30C04C408143A852B3454140231631EC30C04C40
14569	Жилотково	1	15	848	34.211376000000001	34.230412000000001	57.534593000000001	57.529206000000002	0103000020E610000001000000050000006494675E0E1B41406A6CAF05BDC34C406494675E0E1B4140D4D51D8B6DC44C40904DF2237E1D4140D4D51D8B6DC44C40904DF2237E1D41406A6CAF05BDC34C406494675E0E1B41406A6CAF05BDC34C40
14009	Есеновичи	1	15	848	34.190077000000002	34.241819999999997	57.285679999999999	57.272052000000002	0103000020E61000000100000005000000645C717154184140DC679599D2A24C40645C717154184140868F882991A44C4065C22FF5F31E4140868F882991A44C4065C22FF5F31E4140DC679599D2A24C40645C717154184140DC679599D2A24C40
13932	Дятлово	1	15	848	34.768188000000002	34.796719000000003	57.712007999999997	57.703214000000003	0103000020E61000000100000005000000FF9600FC53624140700B96EA02DA4C40FF9600FC53624140C43E011423DB4C40098D60E3FA654140C43E011423DB4C40098D60E3FA654140700B96EA02DA4C40FF9600FC53624140700B96EA02DA4C40
14405	Дорки	1	15	848	34.391191999999997	34.417808999999998	57.650863999999999	57.639029000000001	0103000020E61000000100000005000000793A5794123241400919C8B3CBD14C40793A5794123241406612F5824FD34C40BB7CEBC37A3541406612F5824FD34C40BB7CEBC37A3541400919C8B3CBD14C40793A5794123241400919C8B3CBD14C40
13829	Горняк	1	15	848	34.631886999999999	34.646223999999997	57.582774000000001	57.573244000000003	0103000020E610000001000000050000003FE257ACE15041406A50340F60C94C403FE257ACE1504140C47AA35698CA4C40F5F1D077B7524140C47AA35698CA4C40F5F1D077B75241406A50340F60C94C403FE257ACE15041406A50340F60C94C40
14028	Бухолово	1	15	848	34.412761000000003	34.433799	57.365371000000003	57.354778000000003	0103000020E610000001000000050000003A083A5AD53441408FAB915D69AD4C403A083A5AD534414013F4177AC4AE4C40CD04C3B98637414013F4177AC4AE4C40CD04C3B9863741408FAB915D69AD4C403A083A5AD53441408FAB915D69AD4C40
14216	Боровно	1	15	848	34.390303000000003	34.415832999999999	57.784287999999997	57.773688	0103000020E61000000100000005000000EE43DE72F531414061A7583508E34C40EE43DE72F53141409752978C63E44C407DCC07043A3541409752978C63E44C407DCC07043A35414061A7583508E34C40EE43DE72F531414061A7583508E34C40
13727	Борисовский	1	15	848	34.145386000000002	34.169856000000003	57.667031999999999	57.656179999999999	0103000020E61000000100000005000000ECA529029C1241400725CCB4FDD34C40ECA529029C12414057B1F84D61D54C40C38366D7BD15414057B1F84D61D54C40C38366D7BD1541400725CCB4FDD34C40ECA529029C1241400725CCB4FDD34C40
14391	Бельский	1	15	848	34.234211999999999	34.250678000000001	57.751016999999997	57.741515999999997	0103000020E61000000100000005000000562AA8A8FA1D4140F9BA0CFFE9DE4C40562AA8A8FA1D4140B9DE365321E04C40D1E9793716204140B9DE365321E04C40D1E9793716204140F9BA0CFFE9DE4C40562AA8A8FA1D4140F9BA0CFFE9DE4C40
13812	Белый Омут	1	15	848	34.665501999999996	34.698900999999999	57.556849999999997	57.539172999999998	0103000020E6100000010000000500000017B6662B2F5541406FF1F09E03C54C4017B6662B2F55414088635DDC46C74C40231285967559414088635DDC46C74C4023128596755941406FF1F09E03C54C4017B6662B2F5541406FF1F09E03C54C40
15164	Афимьино	1	15	848	34.710813000000002	34.740475000000004	57.476497000000002	57.465389999999999	0103000020E610000001000000050000002C499EEBFB5A414056F146E691BB4C402C499EEBFB5A414031D28BDAFDBC4C40B84082E2C75E414031D28BDAFDBC4C40B84082E2C75E414056F146E691BB4C402C499EEBFB5A414056F146E691BB4C40
14310	Академический	1	15	848	34.307299	34.335137000000003	57.718305999999998	57.705545999999998	0103000020E61000000100000005000000F88BD992552741406CE9D1544FDA4C40F88BD99255274140A2427573F1DB4C40FC56EBC4E52A4140A2427573F1DB4C40FC56EBC4E52A41406CE9D1544FDA4C40F88BD992552741406CE9D1544FDA4C40
13623	Чистая Дуброва	1	15	1246	37.275584000000002	37.297206000000003	58.506608	58.497999	0103000020E6100000010000000500000083A6255646A342406938656EBE3F4D4083A6255646A342402CF2EB87D8404D406616A1D80AA642402CF2EB87D8404D406616A1D80AA642406938656EBE3F4D4083A6255646A342406938656EBE3F4D40
13638	Чамерово	1	15	1246	37.358407999999997	37.378278999999999	58.471907999999999	58.459603999999999	0103000020E61000000100000005000000F84F3750E0AD42402E8ECA4DD43A4D40F84F3750E0AD4240425C397B673C4D40BDE13E726BB04240425C397B673C4D40BDE13E726BB042402E8ECA4DD43A4D40F84F3750E0AD42402E8ECA4DD43A4D40
13249	Тимошкино	1	15	1246	36.931268000000003	36.945515999999998	58.396349999999998	58.386110000000002	0103000020E61000000100000005000000DAE731CA337742404C546F0D6C314D40DAE731CA3377424082E2C798BB324D4020EC14AB0679424082E2C798BB324D4020EC14AB067942404C546F0D6C314D40DAE731CA337742404C546F0D6C314D40
13710	Телятово	1	15	1246	37.288699000000001	37.306404999999998	58.396411999999998	58.389057999999999	0103000020E61000000100000005000000A7B1BD16F4A44240A31F0DA7CC314D40A7B1BD16F4A44240F8DEDFA0BD324D405A2A6F4738A74240F8DEDFA0BD324D405A2A6F4738A74240A31F0DA7CC314D40A7B1BD16F4A44240A31F0DA7CC314D40
13448	Столбищи	1	15	1246	37.228135000000002	37.238771	58.430036999999999	58.422511	0103000020E6100000010000000500000057091687339D4240A29927D714364D4057091687339D4240F488D1730B374D40DA1D520C909E4240F488D1730B374D40DA1D520C909E4240A29927D714364D4057091687339D4240A29927D714364D40
13533	Романовское	1	15	1246	37.458157	37.471505999999998	58.448279999999997	58.437151	0103000020E610000001000000050000007CB779E3A4BA4240F4346090F4374D407CB779E3A4BA4240B6B9313D61394D4013EF004F5ABC4240B6B9313D61394D4013EF004F5ABC4240F4346090F4374D407CB779E3A4BA4240F4346090F4374D40
13436	Пронино	1	15	1246	37.128512000000001	37.153961000000002	58.473503999999998	58.457990000000002	0103000020E610000001000000050000006092CA147390424091F2936A9F3A4D406092CA1473904240394371C79B3C4D4003EE79FEB4934240394371C79B3C4D4003EE79FEB493424091F2936A9F3A4D406092CA147390424091F2936A9F3A4D40
13345	Любегощи	1	15	1246	36.802782000000001	36.830792000000002	58.585178999999997	58.575848000000001	0103000020E61000000100000005000000A3E8818FC1664240C7BB2363B5494D40A3E8818FC16642402AA73D25E74A4D40A4E36A64576A42402AA73D25E74A4D40A4E36A64576A4240C7BB2363B5494D40A3E8818FC1664240C7BB2363B5494D40
13269	Кесьма	1	15	1246	37.045929000000001	37.079642999999997	58.407479000000002	58.390624000000003	0103000020E6100000010000000500000010786000E185424030849CF7FF314D4010786000E18542404567994528344D407B2DE8BD318A42404567994528344D407B2DE8BD318A424030849CF7FF314D4010786000E185424030849CF7FF314D40
13074	Иваново	1	15	1246	37.077280999999999	37.101526	58.553871999999998	58.541654000000001	0103000020E6100000010000000500000014CD0358E4894240B1DF13EB54454D4014CD0358E4894240C6151747E5464D40CBD8D0CDFE8C4240C6151747E5464D40CBD8D0CDFE8C4240B1DF13EB54454D4014CD0358E4894240B1DF13EB54454D40
12966	Егна	1	15	1246	36.875124	36.900708000000002	58.686500000000002	58.679146000000003	0103000020E61000000100000005000000ECF82F1004704240C89A9141EE564D40ECF82F10047042401D5A643BDF574D406F9F55664A7342401D5A643BDF574D406F9F55664A734240C89A9141EE564D40ECF82F1004704240C89A9141EE564D40
13550	Дюдиково	1	15	1246	37.530391000000002	37.557870000000001	58.428514999999997	58.415247999999998	0103000020E61000000100000005000000DF8B2FDAE3C342405DDDB1D826354D40DF8B2FDAE3C34240376C5B94D9364D40B3B5BE4868C74240376C5B94D9364D40B3B5BE4868C742405DDDB1D826354D40DF8B2FDAE3C342405DDDB1D826354D40
12899	Гора	1	15	1246	36.894078	36.915098999999998	58.625357000000001	58.617947999999998	0103000020E610000001000000050000005B09DD2571724240765089EB184F4D405B09DD25717242408FA9BBB20B504D4018CDCAF6217542408FA9BBB20B504D4018CDCAF621754240765089EB184F4D405B09DD2571724240765089EB184F4D40
12795	Весьегонск	1	15	1246	37.235348000000002	37.283254999999997	58.682729999999999	58.634608999999998	0103000020E61000000100000005000000EA961DE21F9E4240A65F22DE3A514D40EA961DE21F9E4240C1FF56B263574D40D8B628B341A44240C1FF56B263574D40D8B628B341A44240A65F22DE3A514D40EA961DE21F9E4240A65F22DE3A514D40
40951	Большое Овсянниково	1	15	1246	36.814874000000003	36.844276000000001	58.739325999999998	58.725588999999999	0103000020E610000001000000050000002C2E8ECA4D6842402EABB019E05C4D402C2E8ECA4D6842408F8AFF3BA25E4D401B66683C116C42408F8AFF3BA25E4D401B66683C116C42402EABB019E05C4D402C2E8ECA4D6842402EABB019E05C4D40
13150	Бараново	1	15	1246	37.295076999999999	37.310006999999999	58.641934999999997	58.636510999999999	0103000020E61000000100000005000000A1664815C5A54240AA45443179514D40A1664815C5A54240319413ED2A524D40FA43334FAEA74240319413ED2A524D40FA43334FAEA74240AA45443179514D40A1664815C5A54240AA45443179514D40
13362	Алферово	1	15	1246	36.847239999999999	36.858809999999998	58.543081000000001	58.530346999999999	0103000020E6100000010000000500000078EE3D5C726C42400F441669E2434D4078EE3D5C726C42401C0A9FAD83454D4027BD6F7CED6D42401C0A9FAD83454D4027BD6F7CED6D42400F441669E2434D4078EE3D5C726C42400F441669E2434D40
40537	Бологое	1	15	6917	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
12442	Хотилово	1	15	711	34.056255	34.142187999999997	57.732219000000001	57.711070999999997	0103000020E61000000100000005000000459E245D330741402711E15F04DB4C40459E245D330741404241295AB9DD4C401BF16437331241404241295AB9DD4C401BF16437331241402711E15F04DB4C40459E245D330741402711E15F04DB4C40
12335	Тимково	1	15	711	34.241909999999997	34.267933999999997	57.998829000000001	57.992722999999998	0103000020E61000000100000005000000A54929E8F61E4140567E198C11FF4C40A54929E8F61E4140F0A5F0A0D9FF4C4044BE4BA94B224140F0A5F0A0D9FF4C4044BE4BA94B224140567E198C11FF4C40A54929E8F61E4140567E198C11FF4C40
11933	Михайловское	1	15	711	33.730992999999998	33.742122999999999	58.127353999999997	58.120330000000003	0103000020E610000001000000050000006E4DBA2D91DD4040255D33F9660F4D406E4DBA2D91DD4040E481C8224D104D40014EEFE2FDDE4040E481C8224D104D40014EEFE2FDDE4040255D33F9660F4D406E4DBA2D91DD4040255D33F9660F4D40
11832	Лыкошино	1	15	711	33.759101999999999	33.771382000000003	58.116222999999998	58.112195999999997	0103000020E61000000100000005000000022A1C412AE14040FA5E43705C0E4D40022A1C412AE1404081053065E00E4D408E5C37A5BCE2404081053065E00E4D408E5C37A5BCE24040FA5E43705C0E4D40022A1C412AE14040FA5E43705C0E4D40
12071	Куженкино	1	15	711	33.944819000000003	33.995950999999998	57.733421	57.718806000000001	0103000020E61000000100000005000000D9D138D4EFF840409415C3D501DC4C40D9D138D4EFF840408D9944BDE0DD4C4091B586527BFF40408D9944BDE0DD4C4091B586527BFF40409415C3D501DC4C40D9D138D4EFF840409415C3D501DC4C40
11860	Корыхново	1	15	711	33.762354000000002	33.79419	58.049816	58.032542999999997	0103000020E61000000100000005000000C6FCDCD094E140405B5B785E2A044D40C6FCDCD094E14040A568E55E60064D40B6679604A8E54040A568E55E60064D40B6679604A8E540405B5B785E2A044D40C6FCDCD094E140405B5B785E2A044D40
26375	Кемцы	1	15	711	34.235649000000002	34.257361000000003	58.077353000000002	58.069262000000002	0103000020E61000000100000005000000E52A16BF291E4140836DC493DD084D40E52A16BF291E4140AE9FFEB3E6094D4008228B34F1204140AE9FFEB3E6094D4008228B34F1204140836DC493DD084D40E52A16BF291E4140836DC493DD084D40
12439	Кафтино	1	15	711	34.292943000000001	34.311762999999999	57.943798999999999	57.926563999999999	0103000020E61000000100000005000000CB4BFE277F25414052D32EA699F64C40CB4BFE277F254140AE7FD767CEF84C402A8D98D9E7274140AE7FD767CEF84C402A8D98D9E727414052D32EA699F64C40CB4BFE277F25414052D32EA699F64C40
12033	Ильятино	1	15	711	33.711931	33.731226999999997	57.817289000000002	57.802861999999998	0103000020E610000001000000050000001901158E20DB4040BF99982EC4E64C401901158E20DB4040B6300BED9CE84C40E179A9D898DD4040B6300BED9CE84C40E179A9D898DD4040BF99982EC4E64C401901158E20DB4040BF99982EC4E64C40
12548	Заборки	1	15	711	34.027859999999997	34.039538	58.100783999999997	58.093150000000001	0103000020E61000000100000005000000EB6E9EEA90034140ABCFD556EC0B4D40EB6E9EEA90034140E3FA777DE60C4D408179C8940F054140E3FA777DE60C4D408179C8940F054140ABCFD556EC0B4D40EB6E9EEA90034140ABCFD556EC0B4D40
11775	Гузятино	1	15	711	33.866458999999999	33.900289999999998	57.909880999999999	57.900379000000001	0103000020E610000001000000050000009529E620E8EE4040AA807B9E3FF34C409529E620E8EE40403A2009FB76F44C403A75E5B33CF340403A2009FB76F44C403A75E5B33CF34040AA807B9E3FF34C409529E620E8EE4040AA807B9E3FF34C40
11962	Выползово	1	15	711	33.679223	33.712533000000001	57.885727000000003	57.861125999999999	0103000020E6100000010000000500000073D87DC7F0D640401EDE736039EE4C4073D87DC7F0D64040941799805FF14C400F29064834DB4040941799805FF14C400F29064834DB40401EDE736039EE4C4073D87DC7F0D640401EDE736039EE4C40
4965	Бологое	1	15	711	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
12246	Березовский Рядок	1	15	711	34.468347999999999	34.484158999999998	58.104579000000001	58.095419	0103000020E61000000100000005000000D192C7D3F23B4140613596B0360C4D40D192C7D3F23B4140986C3CD8620D4D4033880FECF83D4140986C3CD8620D4D4033880FECF83D4140613596B0360C4D40D192C7D3F23B4140613596B0360C4D40
11676	Березайка	1	15	711	33.881928000000002	33.924166999999997	57.997675000000001	57.972205000000002	0103000020E610000001000000050000009EB64604E3F04040FC00A43671FC4C409EB64604E3F04040B6847CD0B3FF4C406E85B01A4BF64040B6847CD0B3FF4C406E85B01A4BF64040FC00A43671FC4C409EB64604E3F04040FC00A43671FC4C40
11112	Шайтровщина	1	15	1143	33.042102	33.058038000000003	55.819934000000003	55.814208999999998	0103000020E61000000100000005000000508C2C9963854040EF8D210038E84B40508C2C99638540407270E998F3E84B406FF607CA6D8740407270E998F3E84B406FF607CA6D874040EF8D210038E84B40508C2C9963854040EF8D210038E84B40
49954	Чичата	1	15	1143	32.570613000000002	32.598263000000003	55.756067000000002	55.747252000000003	0103000020E6100000010000000500000013D6C6D80949404070EF1AF4A5DF4B4013D6C6D809494040DC4AAFCDC6E04B4014B4C9E1934C4040DC4AAFCDC6E04B4014B4C9E1934C404070EF1AF4A5DF4B4013D6C6D80949404070EF1AF4A5DF4B40
11192	Нестерово	1	15	1143	33.020228000000003	33.037205999999998	55.941510999999998	55.929268	0103000020E61000000100000005000000543BC3D496824040139CFA40F2F64B40543BC3D49682404081E9B46E83F84B40849B8C2AC384404081E9B46E83F84B40849B8C2AC3844040139CFA40F2F64B40543BC3D496824040139CFA40F2F64B40
11085	Комары	1	15	1143	33.166052000000001	33.195067000000002	55.722259000000001	55.707937999999999	0103000020E61000000100000005000000BBB72231419540403ECC5EB69DDA4B40BBB7223141954040EF1EA0FB72DC4B40B1C398F4F7984040EF1EA0FB72DC4B40B1C398F4F79840403ECC5EB69DDA4B40BBB72231419540403ECC5EB69DDA4B40
11023	Кавельщино	1	15	1143	33.082455000000003	33.135939999999998	55.802132999999998	55.773864000000003	0103000020E610000001000000050000002332ACE28D8A4040A0C6BDF90DE34B402332ACE28D8A40406C054D4BACE64B40EF1B5F7B669140406C054D4BACE64B40EF1B5F7B66914040A0C6BDF90DE34B402332ACE28D8A4040A0C6BDF90DE34B40
10904	Демяхи	1	15	1143	32.753483000000003	32.784708000000002	55.724159999999998	55.711635000000001	0103000020E61000000100000005000000C68B85217260404030D80DDB16DB4B40C68B85217260404022895E46B1DC4B406D74CE4F7164404022895E46B1DC4B406D74CE4F7164404030D80DDB16DB4B40C68B85217260404030D80DDB16DB4B40
10839	Грибаново	1	15	1143	33.252299000000001	33.277560000000001	55.875349	55.862388000000003	0103000020E6100000010000000500000021E868554BA040403F3BE0BA62EE4B4021E868554BA040400CCB9F6F0BF04B40C156091687A340400CCB9F6F0BF04B40C156091687A340403F3BE0BA62EE4B4021E868554BA040403F3BE0BA62EE4B40
10809	Верховье	1	15	1143	33.376455	33.410671999999998	55.921661999999998	55.907819000000003	0103000020E6100000010000000500000035B56CAD2FB04040FED7B96933F44B4035B56CAD2FB04040A4FB3905F9F54B4003B16CE690B44040A4FB3905F9F54B4003B16CE690B44040FED7B96933F44B4035B56CAD2FB04040FED7B96933F44B40
11012	Будино	1	15	1143	32.874917000000003	32.910848999999999	55.807223	55.790641000000001	0103000020E6100000010000000500000073DBBE47FD6F404039F06AB933E54B4073DBBE47FD6F40401DCA501553E74B40124C35B3967440401DCA501553E74B40124C35B39674404039F06AB933E54B4073DBBE47FD6F404039F06AB933E54B40
10727	Белый	1	15	1143	32.908433000000002	32.971252	55.863079999999997	55.815483	0103000020E61000000100000005000000B8CD548847744040D4B837BF61E84B40B8CD54884774404074EACA6779EE4B4059164CFC517C404074EACA6779EE4B4059164CFC517C4040D4B837BF61E84B40B8CD548847744040D4B837BF61E84B40
10269	Шульгино	1	15	591	36.411054	36.422310000000003	57.539037999999998	57.531143999999998	0103000020E61000000100000005000000EB71DF6A9D344240BABBCE86FCC34C40EB71DF6A9D3442408FA67A32FFC44C400B630B410E3642408FA67A32FFC44C400B630B410E364240BABBCE86FCC34C40EB71DF6A9D344240BABBCE86FCC34C40
40952	Шишкова-Дубрава	1	15	591	36.435084000000003	36.446511000000001	57.789278000000003	57.783900000000003	0103000020E61000000100000005000000A6811FD5B0374240CEAACFD556E44C40A6811FD5B0374240E5B9BE0F07E54C40F226BF4527394240E5B9BE0F07E54C40F226BF4527394240CEAACFD556E44C40A6811FD5B0374240CEAACFD556E44C40
10475	Хозницы	1	15	591	36.867758000000002	36.875779999999999	57.513339000000002	57.507232000000002	0103000020E61000000100000005000000D36BB3B1126F42400ABE69FAECC04C40D36BB3B1126F42407461A417B5C14C40D53E1D8F197042407461A417B5C14C40D53E1D8F197042400ABE69FAECC04C40D36BB3B1126F42400ABE69FAECC04C40
10573	Фралево	1	15	591	36.654389999999999	36.673217999999999	57.820089000000003	57.807696	0103000020E610000001000000050000002B6A300DC3534240158E209562E74C402B6A300DC3534240996725ADF8E84C400D8AE6012C564240996725ADF8E84C400D8AE6012C564240158E209562E74C402B6A300DC3534240158E209562E74C40
40948	Филиппково	1	15	591	36.512383999999997	36.537931999999998	57.799720999999998	57.790376999999999	0103000020E61000000100000005000000307F85CC954142405B41D3122BE54C40307F85CC954142405376FA415DE64C4066BCADF4DA4442405376FA415DE64C4066BCADF4DA4442405B41D3122BE54C40307F85CC954142405B41D3122BE54C40
10100	Сырцевка	1	15	591	36.426658000000003	36.446753000000001	57.674584000000003	57.66722	0103000020E61000000100000005000000D449B6BA9C3642405A9E077767D54C40D449B6BA9C364240D333BDC458D64C40E831CA332F394240D333BDC458D64C40E831CA332F3942405A9E077767D54C40D449B6BA9C3642405A9E077767D54C40
10403	Сукромны	1	15	591	36.791266	36.814720999999999	57.675474000000001	57.656979	0103000020E61000000100000005000000E7374C344865424053944BE317D44C40E7374C34486542402FA699EE75D64C40A52E19C7486842402FA699EE75D64C40A52E19C74868424053944BE317D44C40E7374C344865424053944BE317D44C40
10626	Потесы	1	15	591	36.537303000000001	36.552135	57.893591999999998	57.884616999999999	0103000020E6100000010000000500000077853E58C6444240293E3E213BF14C4077853E58C6444240CEFBFF3861F24C400DFD135CAC464240CEFBFF3861F24C400DFD135CAC464240293E3E213BF14C4077853E58C6444240293E3E213BF14C40
40947	Поречье	1	15	591	36.393805999999998	36.412204000000003	58.042028999999999	58.031151000000001	0103000020E61000000100000005000000FA7B293C683242406D1E87C1FC034D40FA7B293C68324240E63DCE3461054D40E4A3C519C3344240E63DCE3461054D40E4A3C519C33442406D1E87C1FC034D40FA7B293C683242406D1E87C1FC034D40
13257	Подобино	1	15	591	36.861227	36.892856999999999	57.806176000000001	57.798267000000003	0103000020E6100000010000000500000052B7B3AF3C6E4240EF3CF19C2DE64C4052B7B3AF3C6E4240F96871C630E74C4099805F2349724240F96871C630E74C4099805F2349724240EF3CF19C2DE64C4052B7B3AF3C6E4240EF3CF19C2DE64C40
10379	Плотники	1	15	591	36.835993000000002	36.867407	57.618067000000003	57.608916000000001	0103000020E61000000100000005000000AC5791D1016B42406D01A1F5F0CD4C40AC5791D1016B424051DEC7D11CCF4C4026A94C31076F424051DEC7D11CCF4C4026A94C31076F42406D01A1F5F0CD4C40AC5791D1016B42406D01A1F5F0CD4C40
12634	Морозово	1	15	591	36.736460000000001	36.758414999999999	57.977263999999998	57.969870999999998	0103000020E61000000100000005000000F5673F52445E42405E2BA1BB24FC4C40F5673F52445E424071C79BFC16FD4C40DEE522BE1361424071C79BFC16FD4C40DEE522BE136142405E2BA1BB24FC4C40F5673F52445E42405E2BA1BB24FC4C40
10213	Моркины Горы	1	15	591	36.285020000000003	36.318375000000003	57.561976999999999	57.542782000000003	0103000020E610000001000000050000005C5A0D897B244240C26D6DE179C54C405C5A0D897B244240560DC2DCEEC74C40986E1283C0284240560DC2DCEEC74C40986E1283C0284240C26D6DE179C54C405C5A0D897B244240C26D6DE179C54C40
10177	Михайлова Гора	1	15	591	36.466290999999998	36.487814999999998	57.828969999999998	57.816766999999999	0103000020E61000000100000005000000A6B5696CAF3B4240DCB930D28BE84C40A6B5696CAF3B4240BCAE5FB01BEA4C40C6BFCFB8703E4240BCAE5FB01BEA4C40C6BFCFB8703E4240DCB930D28BE84C40A6B5696CAF3B4240DCB930D28BE84C40
10088	Лаптиха	1	15	591	36.496960000000001	36.521295000000002	57.726126000000001	57.711590000000001	0103000020E61000000100000005000000C8B5A1629C3F42409014916115DB4C40C8B5A1629C3F42403D635FB2F1DC4C40BF4868CBB94242403D635FB2F1DC4C40BF4868CBB94242409014916115DB4C40C8B5A1629C3F42409014916115DB4C40
9316	Зобы	1	15	591	36.708477000000002	36.722921999999997	57.740487999999999	57.731138000000001	0103000020E61000000100000005000000EE7BD45FAF5A4240726E13EE95DD4C40EE7BD45FAF5A42404C8A8F4FC8DE4C408AC745B5885C42404C8A8F4FC8DE4C408AC745B5885C4240726E13EE95DD4C40EE7BD45FAF5A4240726E13EE95DD4C40
17944	Житищи	1	15	591	36.506922000000003	36.530583999999998	57.467272999999999	57.455606000000003	0103000020E61000000100000005000000BCCFF1D1E240424042EE224C51BA4C40BCCFF1D1E2404240E3A6069ACFBB4C40F3E32F2DEA434240E3A6069ACFBB4C40F3E32F2DEA43424042EE224C51BA4C40BCCFF1D1E240424042EE224C51BA4C40
17969	Градницы	1	15	591	36.795048000000001	36.810004999999997	57.860604000000002	57.855407999999997	0103000020E6100000010000000500000007600322C46542404E5E64027EED4C4007600322C46542404567994528EE4C40594C6C3EAE6742404567994528EE4C40594C6C3EAE6742404E5E64027EED4C4007600322C46542404E5E64027EED4C40
5476	Городищи	1	15	591	36.751838999999997	36.771701	57.797845000000002	57.788322999999998	0103000020E61000000100000005000000BD6DA6423C604240A1D79FC4E7E44C40BD6DA6423C6042407923F3C81FE64C402FA52E19C76242407923F3C81FE64C402FA52E19C7624240A1D79FC4E7E44C40BD6DA6423C604240A1D79FC4E7E44C40
3717	Васюково	1	15	591	36.691625000000002	36.701335999999998	57.6554	57.646600999999997	0103000020E610000001000000050000004A0C022B87584240CB4752D2C3D24C404A0C022B8758424032E6AE25E4D34C40F4C0C760C559424032E6AE25E4D34C40F4C0C760C5594240CB4752D2C3D24C404A0C022B87584240CB4752D2C3D24C40
11232	Борок-Сулежский	1	15	591	36.831204999999997	36.865017999999999	57.915976999999998	57.880730999999997	0103000020E61000000100000005000000C6A2E9EC646A424064C91CCBBBF04C40C6A2E9EC646A4240B071FDBB3EF54C40C539EAE8B86E4240B071FDBB3EF54C40C539EAE8B86E424064C91CCBBBF04C40C6A2E9EC646A424064C91CCBBBF04C40
9664	Хотилицы	1	15	995	31.877365000000001	31.896363999999998	56.655366999999998	56.640816999999998	0103000020E61000000100000005000000B1A71DFE9AE03F4044DC9C4A06524C40B1A71DFE9AE03F4056F0DB10E3534C40CE4F711C78E53F4056F0DB10E3534C40CE4F711C78E53F4044DC9C4A06524C40B1A71DFE9AE03F4044DC9C4A06524C40
9501	Торопаца	1	15	995	31.820025000000001	31.845483000000002	56.787503999999998	56.778686999999998	0103000020E6100000010000000500000004E78C28EDD13F400169FF03AC634C4004E78C28EDD13F400EBC5AEECC644C40F052EA9271D83F400EBC5AEECC644C40F052EA9271D83F400169FF03AC634C4004E78C28EDD13F400169FF03AC634C40
9471	Студеница	1	15	995	32.006532999999997	32.032089999999997	56.773341000000002	56.764259000000003	0103000020E6100000010000000500000021ACC612D60040403B56293DD3614C4021ACC612D6004040F6D37FD6FC624C40AA436E861B044040F6D37FD6FC624C40AA436E861B0440403B56293DD3614C4021ACC612D60040403B56293DD3614C40
9591	Спиридово	1	15	995	31.905383	31.918606	56.625093999999997	56.617590999999997	0103000020E61000000100000005000000B85A272EC7E73F40E7A6CD380D4F4C40B85A272EC7E73F408176871403504C40CDE847C329EB3F408176871403504C40CDE847C329EB3F40E7A6CD380D4F4C40B85A272EC7E73F40E7A6CD380D4F4C40
9132	Рогово	1	15	995	32.280034000000001	32.291289999999996	56.640282999999997	56.634901999999997	0103000020E6100000010000000500000050E27327D82340401E15FF7744514C4050E27327D8234040A69718CBF4514C406FD39FFD48254040A69718CBF4514C406FD39FFD482540401E15FF7744514C4050E27327D82340401E15FF7744514C40
8856	Мякишево	1	15	995	31.82696	31.836041999999999	57.046503999999999	57.03837	0103000020E61000000100000005000000A4198BA6B3D33F40E292E34EE9844C40A4198BA6B3D33F400C91D3D7F3854C401A1538D906D63F400C91D3D7F3854C401A1538D906D63F40E292E34EE9844C40A4198BA6B3D33F40E292E34EE9844C40
9301	Любино	1	15	995	32.032646999999997	32.047657999999998	56.976357999999998	56.965290000000003	0103000020E6100000010000000500000000A8E2C62D044040F3936A9F8E7B4C4000A8E2C62D0440400F98874CF97C4C4046B247A8190640400F98874CF97C4C4046B247A819064040F3936A9F8E7B4C4000A8E2C62D044040F3936A9F8E7B4C40
9398	Луги	1	15	995	32.445549	32.473962999999998	56.720429000000003	56.710732	0103000020E61000000100000005000000FCE1E7BF073940403F1C2444F95A4C40FCE1E7BF07394040850B7904375C4C40CC41D0D1AA3C4040850B7904375C4C40CC41D0D1AA3C40403F1C2444F95A4C40FCE1E7BF073940403F1C2444F95A4C40
8869	Крючково	1	15	995	31.775082000000001	31.799157000000001	57.071905999999998	57.059232000000002	0103000020E61000000100000005000000E1B721C66BC63F40377007EA94874C40E1B721C66BC63F406E313F3734894C40965E9B8D95CC3F406E313F3734894C40965E9B8D95CC3F40377007EA94874C40E1B721C66BC63F40377007EA94874C40
8974	Костюшино	1	15	995	32.214826000000002	32.233438999999997	56.696598999999999	56.687480000000001	0103000020E610000001000000050000004E2A1A6B7F1B4040B9533A58FF574C404E2A1A6B7F1B404091B6F1272A594C40334E4354E11D404091B6F1272A594C40334E4354E11D4040B9533A58FF574C404E2A1A6B7F1B4040B9533A58FF574C40
8941	Козлово	1	15	995	32.268644000000002	32.300156999999999	56.569498000000003	56.563049999999997	0103000020E61000000100000005000000212235ED62224040A301BC0512484C40212235ED6222404097917A4FE5484C402E55698B6B26404097917A4FE5484C402E55698B6B264040A301BC0512484C40212235ED62224040A301BC0512484C40
9381	Горка	1	15	995	31.843606000000001	31.84984	56.626494999999998	56.621136999999997	0103000020E610000001000000050000009AB51490F6D73F40F3AACE6A814F4C409AB51490F6D73F40C30DF8FC30504C4028D53E1D8FD93F40C30DF8FC30504C4028D53E1D8FD93F40F3AACE6A814F4C409AB51490F6D73F40F3AACE6A814F4C40
9232	Горицы	1	15	995	31.863700999999999	31.879079999999998	56.866228999999997	56.859827000000003	0103000020E61000000100000005000000C2853C821BDD3F40E19BA6CF0E6E4C40C2853C821BDD3F4063EC8497E06E4C4053910A630BE13F4063EC8497E06E4C4053910A630BE13F40E19BA6CF0E6E4C40C2853C821BDD3F40E19BA6CF0E6E4C40
9564	Воскресенское	1	15	995	31.752364	31.766054	56.666003000000003	56.652417999999997	0103000020E6100000010000000500000010B056ED9AC03F402EA9DA6E82534C4010B056ED9AC03F40DA0418963F554C4051F86C1D1CC43F40DA0418963F554C4051F86C1D1CC43F402EA9DA6E82534C4010B056ED9AC03F402EA9DA6E82534C40
9208	Волок	1	15	995	32.031838999999998	32.050308000000001	56.858572000000002	56.850515999999999	0103000020E6100000010000000500000061DEE34C13044040C45C52B5DD6C4C4061DEE34C1304404073A1F2AFE56D4C40145D177E7006404073A1F2AFE56D4C40145D177E70064040C45C52B5DD6C4C4061DEE34C13044040C45C52B5DD6C4C40
9145	Бологово	1	15	995	31.682016999999998	31.722729000000001	56.905991	56.891120999999998	0103000020E61000000100000005000000E75086AA98AE3F40B0E3BF4010724C40E75086AA98AE3F4034BC5983F7734C40ECDE8AC404B93F4034BC5983F7734C40ECDE8AC404B93F40B0E3BF4010724C40E75086AA98AE3F40B0E3BF4010724C40
9069	Бобровец	1	15	995	32.293177	32.311160999999998	56.748655999999997	56.742896000000002	0103000020E610000001000000050000003E78EDD286254040242A5437175F4C403E78EDD28625404022FAB5F5D35F4C403465A71FD427404022FAB5F5D35F4C403465A71FD4274040242A5437175F4C403E78EDD286254040242A5437175F4C40
8508	Андреаполь	1	15	995	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
40945	Аксеново	1	15	995	31.854215	31.868614999999998	57.023905999999997	57.014724000000001	0103000020E61000000100000005000000ADC090D5ADDA3F40B03BDD79E2814C40ADC090D5ADDA3F40CE16105A0F834C40A6D0798D5DDE3F40CE16105A0F834C40A6D0798D5DDE3F40B03BDD79E2814C40ADC090D5ADDA3F40B03BDD79E2814C40
51213	Уварово	1	14	\N	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
127	Тамбов	1	14	\N	41.367994000000003	41.516800000000003	52.768669000000003	52.670845	0103000020E61000000100000005000000E78F696D1AAF4440B2D7BB3FDE554A40E78F696D1AAF44407A39ECBE63624A4052499D8026C244407A39ECBE63624A4052499D8026C24440B2D7BB3FDE554A40E78F696D1AAF4440B2D7BB3FDE554A40
4588	Рассказово	1	14	\N	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
2288	Моршанск	1	14	\N	41.742088000000003	41.858905	53.470483999999999	53.41677	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
2401	Мичуринск	1	14	\N	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
51231	Мичуринск	1	14	\N	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
26221	Котовск	1	14	\N	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
60648	Кирсанов	1	14	\N	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
60435	Бокино	1	14	\N	41.439247999999999	41.491135	52.661883000000003	52.616197	0103000020E61000000100000005000000AD6A494739B844405872158BDF4E4A40AD6A494739B84440A2630795B8544A40E275FD82DDBE4440A2630795B8544A40E275FD82DDBE44405872158BDF4E4A40AD6A494739B844405872158BDF4E4A40
45628	Умет	1	14	548	42.941555000000001	42.998866999999997	52.576855999999999	52.549106000000002	0103000020E610000001000000050000005131CEDF84784540C904FC1A49464A405131CEDF847845402D40DB6AD6494A40DD06B5DFDA7F45402D40DB6AD6494A40DD06B5DFDA7F4540C904FC1A49464A405131CEDF84784540C904FC1A49464A40
51179	Совхоз Сулакский	1	14	548	42.998454000000002	43.000475000000002	52.612910999999997	52.610115999999998	0103000020E61000000100000005000000BB473657CD7F45401762F547184E4A40BB473657CD7F4540E82D1EDE734E4A4099BB96900F804540E82D1EDE734E4A4099BB96900F8045401762F547184E4A40BB473657CD7F45401762F547184E4A40
51193	Совхоз Глуховский	1	14	548	43.139758999999998	43.155119999999997	52.671543999999997	52.659686999999998	0103000020E610000001000000050000002C29779FE3914540554CA59F70544A402C29779FE39145409AE95E27F5554A404E7ADFF8DA9345409AE95E27F5554A404E7ADFF8DA934540554CA59F70544A402C29779FE3914540554CA59F70544A40
48277	Скачиха	1	14	548	42.860284	42.901643	52.620964999999998	52.592855	0103000020E61000000100000005000000D3A23EC91D6E4540922232ACE24B4A40D3A23EC91D6E4540F67AF7C77B4F4A406BD5AE0969734540F67AF7C77B4F4A406BD5AE0969734540922232ACE24B4A40D3A23EC91D6E4540922232ACE24B4A40
4166	Сергиевка	1	14	548	42.841599000000002	42.868997999999998	52.480074999999999	52.46951	0103000020E6100000010000000500000054AC1A84B96B45408E9257E7183C4A4054AC1A84B96B45404850FC18733D4A400B2593533B6F45404850FC18733D4A400B2593533B6F45408E9257E7183C4A4054AC1A84B96B45408E9257E7183C4A40
45358	Осиновка	1	14	548	42.823794999999997	42.837952000000001	52.545771000000002	52.531941000000003	0103000020E61000000100000005000000DDCD531D72694540663387A416444A40DDCD531D72694540780DFAD2DB454A4014CFD902426B4540780DFAD2DB454A4014CFD902426B4540663387A416444A40DDCD531D72694540663387A416444A40
46436	Оржевка	1	14	548	42.904336999999998	42.918163	52.721665999999999	52.707259000000001	0103000020E6100000010000000500000008C89750C17345409D668176875A4A4008C89750C17345404C512E8D5F5C4A40D9B27C5D867545404C512E8D5F5C4A40D9B27C5D867545409D668176875A4A4008C89750C17345409D668176875A4A40
51169	Нововоздвиженка	1	14	548	43.075088999999998	43.089947000000002	52.781025	52.773702999999998	0103000020E6100000010000000500000009A52F849C89454096E82CB308634A4009A52F849C894540E02D90A0F8634A40C9AF1F62838B4540E02D90A0F8634A40C9AF1F62838B454096E82CB308634A4009A52F849C89454096E82CB308634A40
3371	Нижние Пески	1	14	548	42.924801000000002	42.957121999999998	52.826140000000002	52.807070000000003	0103000020E61000000100000005000000702711E15F76454097CADB114E674A40702711E15F7645406FF59CF4BE694A401C2444F9827A45406FF59CF4BE694A401C2444F9827A454097CADB114E674A40702711E15F76454097CADB114E674A40
51168	Масловка	1	14	548	42.882508000000001	42.905478000000002	52.738424999999999	52.711804000000001	0103000020E61000000100000005000000AC3AAB05F6704540BC94BA641C5B4A40AC3AAB05F67045403FC6DCB5845E4A40AE9FFEB3E67345403FC6DCB5845E4A40AE9FFEB3E6734540BC94BA641C5B4A40AC3AAB05F6704540BC94BA641C5B4A40
46432	Красный Октябрь	1	14	548	43.016033999999998	43.033209999999997	52.578786999999998	52.566462000000001	0103000020E61000000100000005000000E1CFF0660D824540A036AAD381484A40E1CFF0660D824540CB2C42B1154A4A4038F3AB3940844540CB2C42B1154A4A4038F3AB3940844540A036AAD381484A40E1CFF0660D824540A036AAD381484A40
40452	Ильинка	1	14	548	42.801893999999997	42.836973	52.493367999999997	52.469059999999999	0103000020E61000000100000005000000E76D6C76A46645404EEE77280A3C4A40E76D6C76A46645404B72C0AE263F4A40485167EE216B45404B72C0AE263F4A40485167EE216B45404EEE77280A3C4A40E76D6C76A46645404EEE77280A3C4A40
46283	Ивановка	1	14	548	42.908020999999998	42.941312000000003	52.506996999999998	52.490648	0103000020E61000000100000005000000658A39083A74454085ECBC8DCD3E4A40658A39083A744540C6151747E5404A408BAA5FE97C784540C6151747E5404A408BAA5FE97C78454085ECBC8DCD3E4A40658A39083A74454085ECBC8DCD3E4A40
60584	Екатериновка	1	14	548	43.060257999999997	43.077981999999999	52.785969999999999	52.778202999999998	0103000020E6100000010000000500000043A9BD88B68745401553E9279C634A4043A9BD88B68745408DD13AAA9A644A409DD66D50FB8945408DD13AAA9A644A409DD66D50FB8945401553E9279C634A4043A9BD88B68745401553E9279C634A40
51207	Васильевка	1	14	548	42.994177999999998	43.023094999999998	52.852386000000003	52.834240999999999	0103000020E610000001000000050000008B338639417F4540BDFDB968C86A4A408B338639417F4540BDC804FC1A6D4A40BED9E6C6F4824540BDC804FC1A6D4A40BED9E6C6F4824540BDFDB968C86A4A408B338639417F4540BDFDB968C86A4A40
30783	Варваринка	1	14	548	42.773587999999997	42.788885999999998	52.519661999999997	52.512098999999999	0103000020E61000000100000005000000FD497CEE046345403BA8C4758C414A40FD497CEE04634540AA7CCF4884424A40D9226937FA644540AA7CCF4884424A40D9226937FA6445403BA8C4758C414A40FD497CEE046345403BA8C4758C414A40
47795	Бибиково	1	14	548	43.063572999999998	43.093496000000002	52.750756000000003	52.738888000000003	0103000020E610000001000000050000004DF4F9282388454014B4C9E1935E4A404DF4F928238845404DA3C9C518604A4046274BADF78B45404DA3C9C518604A4046274BADF78B454014B4C9E1935E4A404DF4F9282388454014B4C9E1935E4A40
47977	Березовка	1	14	548	42.946432999999999	42.962279000000002	52.454585000000002	52.439385999999999	0103000020E61000000100000005000000766D6FB724794540FE28EACC3D384A40766D6FB72479454047205ED72F3A4A40555051F52B7B454047205ED72F3A4A40555051F52B7B4540FE28EACC3D384A40766D6FB724794540FE28EACC3D384A40
49233	14-й	1	14	548	42.929544	42.945929	52.379435000000001	52.368614999999998	0103000020E61000000100000005000000B5183C4CFB76454053E8BCC62E2F4A40B5183C4CFB76454098FA795391304A4043AB93331479454098FA795391304A4043AB93331479454053E8BCC62E2F4A40B5183C4CFB76454053E8BCC62E2F4A40
26647	Энгуразово	1	14	16	41.955132999999996	41.97486	51.846600000000002	51.836016999999998	0103000020E61000000100000005000000492A53CC41FA444034F3E49A02EB4940492A53CC41FA4440956588635DEC4940DB166536C8FC4440956588635DEC4940DB166536C8FC444034F3E49A02EB4940492A53CC41FA444034F3E49A02EB4940
26371	Чуево-Подгорное	1	14	16	42.22222	42.239305999999999	51.888420000000004	51.875855999999999	0103000020E61000000100000005000000314278B4711C4540B000A60C1CF04940314278B4711C4540618E1EBFB7F1494048DE3994A11E4540618E1EBFB7F1494048DE3994A11E4540B000A60C1CF04940314278B4711C4540B000A60C1CF04940
27112	Чуево-Алабушка	1	14	16	42.084220999999999	42.112175999999998	51.865412999999997	51.840591000000003	0103000020E610000001000000050000007651F4C0C70A4540EE27637C98EB49407651F4C0C70A454041446ADAC5EE4940B3B27DC85B0E454041446ADAC5EE4940B3B27DC85B0E4540EE27637C98EB49407651F4C0C70A4540EE27637C98EB4940
47278	Ульяновка	1	14	16	41.970584000000002	41.99747	51.902591999999999	51.874721999999998	0103000020E61000000100000005000000AC02B5183CFC4440BD8BF7E3F6EF4940AC02B5183CFC4440CCD0782288F34940DD5ED218ADFF4440CCD0782288F34940DD5ED218ADFF4440BD8BF7E3F6EF4940AC02B5183CFC4440BD8BF7E3F6EF4940
20	Уварово	1	14	16	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
47261	Репное	1	14	16	41.929468	41.950721999999999	51.925896999999999	51.899514000000003	0103000020E61000000100000005000000DA56B3CEF8F64440A725564623F34940DA56B3CEF8F64440753BFBCA83F649403ACB2C42B1F94440753BFBCA83F649403ACB2C42B1F94440A725564623F34940DA56B3CEF8F64440A725564623F34940
20965	Павлодар	1	14	16	42.060236000000003	42.107261999999999	51.749752000000001	51.716797999999997	0103000020E610000001000000050000005C0531D0B50745404AEB6F09C0DB49405C0531D0B5074540280EA0DFF7DF4940410DDFC2BA0D4540280EA0DFF7DF4940410DDFC2BA0D45404AEB6F09C0DB49405C0531D0B50745404AEB6F09C0DB4940
26829	Нижний Шибряй	1	14	16	42.301881999999999	42.329559000000003	52.046149999999997	52.005009000000001	0103000020E6100000010000000500000023A0C211A4264540C4978922A4004A4023A0C211A4264540EE5A423EE8054A401E8D43FD2E2A4540EE5A423EE8054A401E8D43FD2E2A4540C4978922A4004A4023A0C211A4264540C4978922A4004A40
26278	Моисеево-Алабушка	1	14	16	42.052205000000001	42.118769999999998	51.932994999999998	51.889943000000002	0103000020E6100000010000000500000006D847A7AE064540EE26F8A6E9F1494006D847A7AE0645406F2A52616CF749407ADFF8DA330F45406F2A52616CF749407ADFF8DA330F4540EE26F8A6E9F1494006D847A7AE064540EE26F8A6E9F14940
47377	Моисеево	1	14	16	42.335245999999998	42.376190999999999	51.940057000000003	51.917743000000002	0103000020E61000000100000005000000B20E4757E92A45400491459A78F54940B20E4757E92A45401DB0ABC953F849405706D506273045401DB0ABC953F849405706D506273045400491459A78F54940B20E4757E92A45400491459A78F54940
47430	Луч	1	14	16	41.939385000000001	41.963307	51.780386999999997	51.767418999999997	0103000020E610000001000000050000002EAD86C43DF844401DAA29C93AE249402EAD86C43DF844409D9CA1B8E3E349400281CEA44DFB44409D9CA1B8E3E349400281CEA44DFB44401DAA29C93AE249402EAD86C43DF844401DAA29C93AE24940
47573	Лебяжье	1	14	16	42.353149000000002	42.364252	52.123130000000003	52.115409999999997	0103000020E61000000100000005000000BCCE86FC332D4540D0D03FC1C50E4A40BCCE86FC332D454008944DB9C20F4A4055C03DCF9F2E454008944DB9C20F4A4055C03DCF9F2E4540D0D03FC1C50E4A40BCCE86FC332D4540D0D03FC1C50E4A40
47557	Канино	1	14	16	42.311036000000001	42.363408	52.006528000000003	51.995517	0103000020E6100000010000000500000078F01307D027454057CEDE196DFF494078F01307D02745401041D5E8D5004A40698D4127842E45401041D5E8D5004A40698D4127842E454057CEDE196DFF494078F01307D027454057CEDE196DFF4940
26752	Григорьевка 2-я	1	14	16	42.107576999999999	42.121833000000002	51.684663999999998	51.671756999999999	0103000020E61000000100000005000000A1664815C50D4540F6ED2422FCD54940A1664815C50D4540D05FE811A3D749406B494739980F4540D05FE811A3D749406B494739980F4540F6ED2422FCD54940A1664815C50D4540F6ED2422FCD54940
26563	Вольная Вершина	1	14	16	42.229981000000002	42.261673999999999	51.849755000000002	51.831442000000003	0103000020E61000000100000005000000C7D97404701D4540AB4203B16CEA4940C7D97404701D4540664E97C5C4EC4940541B9C887E214540664E97C5C4EC4940541B9C887E214540AB4203B16CEA4940C7D97404701D4540AB4203B16CEA4940
27027	Верхний Шибряй	1	14	16	42.506625999999997	42.529938000000001	52.039180999999999	52.026426999999998	0103000020E61000000100000005000000D2A6EA1ED94045409E5DBEF561034A40D2A6EA1ED9404540F2CF0CE203054A402E742502D5434540F2CF0CE203054A402E742502D54345409E5DBEF561034A40D2A6EA1ED94045409E5DBEF561034A40
26503	Верхнее Чуево	1	14	16	42.338839	42.381490999999997	51.924075000000002	51.889648999999999	0103000020E61000000100000005000000FFCD8B135F2B4540A5F5B704E0F14940FFCD8B135F2B45408E06F01648F64940F25B74B2D43045408E06F01648F64940F25B74B2D4304540A5F5B704E0F14940FFCD8B135F2B4540A5F5B704E0F14940
60444	Березовка	1	14	16	42.043168000000001	42.088982000000001	52.010109999999997	51.992511	0103000020E61000000100000005000000EB1D6E8786054540CBF5B6990AFF4940EB1D6E878605454068AED3484B014A4062F71DC3630B454068AED3484B014A4062F71DC3630B4540CBF5B6990AFF4940EB1D6E8786054540CBF5B6990AFF4940
47591	Алаторка	1	14	16	42.285569000000002	42.308638000000002	52.160055999999997	52.151608000000003	0103000020E610000001000000050000002FE065868D244540EFE714E467134A402FE065868D244540A8C30AB77C144A40C426327381274540A8C30AB77C144A40C426327381274540EFE714E467134A402FE065868D244540EFE714E467134A40
51167	Уварово	1	14	7105	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
46946	Ястребовка	1	14	569	40.960625999999998	41.083381000000003	52.131881999999997	52.060138999999999	0103000020E61000000100000005000000F9D7F2CAF57A4440691B7FA2B2074A40F9D7F2CAF57A44402D776682E1104A40CC0D863AAC8A44402D776682E1104A40CC0D863AAC8A4440691B7FA2B2074A40F9D7F2CAF57A4440691B7FA2B2074A40
32188	Чичерино	1	14	569	41.335501999999998	41.36891	52.041535000000003	52.027923000000001	0103000020E610000001000000050000000DDFC2BAF1AA444032E719FB92034A400DDFC2BAF1AA4440D751D50451054A406C95607138AF4440D751D50451054A406C95607138AF444032E719FB92034A400DDFC2BAF1AA444032E719FB92034A40
3534	Троицкий Росляй	1	14	569	41.057113999999999	41.116833999999997	51.985401000000003	51.949395000000003	0103000020E610000001000000050000006612F5824F87444033FE7DC685F949406612F5824F8744400D39B69E21FE4940CA87A06AF48E44400D39B69E21FE4940CA87A06AF48E444033FE7DC685F949406612F5824F87444033FE7DC685F94940
24737	Токаревка	1	14	569	41.136209999999998	41.195095000000002	52.008419000000004	51.975527	0103000020E61000000100000005000000AFB14B546F914440B8AE9811DEFC4940AFB14B546F91444020D5B0DF13014A407B4E7ADFF898444020D5B0DF13014A407B4E7ADFF8984440B8AE9811DEFC4940AFB14B546F914440B8AE9811DEFC4940
24915	Старогрязное	1	14	569	41.106206999999998	41.158155999999998	51.983893000000002	51.963819999999998	0103000020E610000001000000050000009ACDE330988D4440889D29745EFB49409ACDE330988D4440B5E1B034F0FD494045D5AF743E944440B5E1B034F0FD494045D5AF743E944440889D29745EFB49409ACDE330988D4440889D29745EFB4940
60441	Сергиевка	1	14	569	41.063203999999999	41.108345	51.785173	51.763750999999999	0103000020E61000000100000005000000FA7C941117884440C6A4BF97C2E14940FA7C941117884440E259828C80E44940B2D7BB3FDE8D4440E259828C80E44940B2D7BB3FDE8D4440C6A4BF97C2E14940FA7C941117884440C6A4BF97C2E14940
25039	Розановка	1	14	569	41.265208999999999	41.288052999999998	52.206583000000002	52.189796999999999	0103000020E610000001000000050000006CCD565EF2A1444080F0A1444B184A406CCD565EF2A144406D74CE4F711A4A40E141B3EBDEA444406D74CE4F711A4A40E141B3EBDEA4444080F0A1444B184A406CCD565EF2A1444080F0A1444B184A40
47095	Полетаево	1	14	569	41.071477999999999	41.104554	51.89584	51.876379	0103000020E610000001000000050000001631EC30268944405AF3E32F2DF049401631EC30268944406D3997E2AAF249403F558506628D44406D3997E2AAF249403F558506628D44405AF3E32F2DF049401631EC30268944405AF3E32F2DF04940
51239	Новоникольское	1	14	569	40.954310999999997	40.992570000000001	51.939785000000001	51.919170999999999	0103000020E61000000100000005000000459BE3DC267A44403F373465A7F54940459BE3DC267A4440BC22F8DF4AF84940D07EA4880C7F4440BC22F8DF4AF84940D07EA4880C7F44403F373465A7F54940459BE3DC267A44403F373465A7F54940
45820	Малиновка	1	14	569	41.264696000000001	41.270985000000003	52.222034000000001	52.217360999999997	0103000020E61000000100000005000000E6B0FB8EE1A144408236397CD21B4A40E6B0FB8EE1A14440CF4C309C6B1C4A40715AF0A2AFA24440CF4C309C6B1C4A40715AF0A2AFA244408236397CD21B4A40E6B0FB8EE1A144408236397CD21B4A40
25261	Малая Зверяевка	1	14	569	41.379941000000002	41.441018	52.173186999999999	52.156177999999997	0103000020E610000001000000050000006CB41CE8A1B04440662D05A4FD134A406CB41CE8A1B04440D28BDAFD2A164A4042791F4773B84440D28BDAFD2A164A4042791F4773B84440662D05A4FD134A406CB41CE8A1B04440662D05A4FD134A40
49381	Малая Даниловка	1	14	569	40.963887	40.99248	52.024375999999997	52.007271000000003	0103000020E61000000100000005000000100533A6607B4440C89A9141EE004A40100533A6607B44405567B5C01E034A4090F7AA95097F44405567B5C01E034A4090F7AA95097F4440C89A9141EE004A40100533A6607B4440C89A9141EE004A40
32110	Кулешовка	1	14	569	41.053187999999999	41.182025000000003	52.147767000000002	51.807352999999999	0103000020E61000000100000005000000134548DDCE864440EBA9D55757E74940134548DDCE864440CA367007EA124A40F7065F984C974440CA367007EA124A40F7065F984C974440EBA9D55757E74940134548DDCE864440EBA9D55757E74940
47348	Красный Куст	1	14	569	41.162621000000001	41.177982	51.891615999999999	51.882232999999999	0103000020E610000001000000050000004852D2C3D0944440DA39CD02EDF049404852D2C3D0944440904B1C7920F249406AA33A1DC8964440904B1C7920F249406AA33A1DC8964440DA39CD02EDF049404852D2C3D0944440DA39CD02EDF04940
47042	Карловка	1	14	569	41.004427999999997	41.024514000000003	51.844746999999998	51.823087000000001	0103000020E61000000100000005000000E597C11891804440A26131EA5AE94940E597C11891804440723271AB20EC4940A725564623834440723271AB20EC4940A725564623834440A26131EA5AE94940E597C11891804440A26131EA5AE94940
24991	Ивано-Лебедянь	1	14	569	41.174973000000001	41.214930000000003	52.155796000000002	52.133817000000001	0103000020E610000001000000050000006D57E883659644400D535BEA20114A406D57E883659644407F6C921FF1134A40F37684D3829B44407F6C921FF1134A40F37684D3829B44400D535BEA20114A406D57E883659644400D535BEA20114A40
51190	Знаменка	1	14	569	40.968369000000003	40.992794000000004	51.972963999999997	51.962372000000002	0103000020E61000000100000005000000E9BAF083F37B4440064B75012FFB4940E9BAF083F37B4440B91798158AFC494020D5B0DF137F4440B91798158AFC494020D5B0DF137F4440064B75012FFB4940E9BAF083F37B4440064B75012FFB4940
51254	Васильевка	1	14	569	41.263789000000003	41.293784000000002	51.988123999999999	51.967298999999997	0103000020E61000000100000005000000B40584D6C3A144400C3A2174D0FB4940B40584D6C3A144404432E4D87AFE4940460BD0B69AA544404432E4D87AFE4940460BD0B69AA544400C3A2174D0FB4940B40584D6C3A144400C3A2174D0FB4940
51218	Березовка	1	14	569	41.188339999999997	41.210312000000002	52.123086000000001	52.100242999999999	0103000020E61000000100000005000000AA436E861B98444093533BC3D40C4A40AA436E861B984440384C3448C10F4A406AFAEC80EB9A4440384C3448C10F4A406AFAEC80EB9A444093533BC3D40C4A40AA436E861B98444093533BC3D40C4A40
25305	Безукладовка	1	14	569	41.104939999999999	41.144691000000002	52.016311999999999	51.994968	0103000020E61000000100000005000000680586AC6E8D44408448861C5BFF4940680586AC6E8D44402444F98216024A404583143C859244402444F98216024A404583143C859244408448861C5BFF4940680586AC6E8D44408448861C5BFF4940
45706	Александровка	1	14	569	41.291341000000003	41.302489000000001	52.100177000000002	52.077621999999998	0103000020E61000000100000005000000F27D71A94AA544409DB98784EF094A40F27D71A94AA54440DC679599D20C4A402B33A5F5B7A64440DC679599D20C4A402B33A5F5B7A644409DB98784EF094A40F27D71A94AA544409DB98784EF094A40
51183	Шестой километр	1	14	156	41.613045	41.621479999999998	52.752647000000003	52.744928999999999	0103000020E61000000100000005000000F8FC304278CE4440C66B5ED5595F4A40F8FC304278CE44405D37A5BC56604A401D8F19A88CCF44405D37A5BC56604A401D8F19A88CCF4440C66B5ED5595F4A40F8FC304278CE4440C66B5ED5595F4A40
24636	Черняное	1	14	156	41.479743999999997	41.510717999999997	53.010527000000003	52.955731	0103000020E61000000100000005000000E2395B4068BD4440FE62B664557A4A40E2395B4068BD4440CD5CE0F258814A4040BD19355FC14440CD5CE0F258814A4040BD19355FC14440FE62B664557A4A40E2395B4068BD4440FE62B664557A4A40
1176	Черняевка	1	14	156	40.933793000000001	40.950484000000003	52.637794	52.627015999999998	0103000020E61000000100000005000000EB1D6E8786774440CC086F0F42504A40EB1D6E8786774440E2CAD93BA3514A4086AFAF75A9794440E2CAD93BA3514A4086AFAF75A9794440CC086F0F42504A40EB1D6E8786774440CC086F0F42504A40
47159	Федоровка	1	14	156	41.316718000000002	41.333821999999998	52.590814000000002	52.577188999999997	0103000020E61000000100000005000000FB0626378AA84440334E4354E1494A40FB0626378AA844406D020CCB9F4B4A40B857E6ADBAAA44406D020CCB9F4B4A40B857E6ADBAAA4440334E4354E1494A40FB0626378AA84440334E4354E1494A40
22213	Учебное хозяйство Авангард	1	14	156	41.139398999999997	41.158534000000003	52.704585000000002	52.698124	0103000020E610000001000000050000002C0C91D3D7914440BF4692205C594A402C0C91D3D791444047205ED72F5A4A40ECA694D74A94444047205ED72F5A4A40ECA694D74A944440BF4692205C594A402C0C91D3D7914440BF4692205C594A40
51199	Тулиновка	1	14	156	41.550162999999998	41.581873999999999	52.820121999999998	52.801560000000002	0103000020E61000000100000005000000103CBEBD6BC6444011E4A08499664A40103CBEBD6BC64440745DF8C1F9684A404432E4D87ACA4440745DF8C1F9684A404432E4D87ACA444011E4A08499664A40103CBEBD6BC6444011E4A08499664A40
23039	Троицкая Дубрава	1	14	156	41.510691000000001	41.545636000000002	53.060468	53.037224000000002	0103000020E6100000010000000500000047AE9B525EC144402B508BC1C3844A4047AE9B525EC144402E3A596ABD874A4098C28366D7C544402E3A596ABD874A4098C28366D7C544402B508BC1C3844A4047AE9B525EC144402B508BC1C3844A40
24133	Татаново	1	14	156	41.463160999999999	41.482466000000002	52.86842	52.819735000000001	0103000020E610000001000000050000002EE411DC48BB44407B319413ED684A402EE411DC48BB44409E98F562286F4A404AB72572C1BD44409E98F562286F4A404AB72572C1BD44407B319413ED684A402EE411DC48BB44407B319413ED684A40
23877	Сурава	1	14	156	41.227758000000001	41.311633	52.966465999999997	52.912830999999997	0103000020E6100000010000000500000081B3942C279D444032E36DA5D7744A4081B3942C279D444014596B28B57B4A405CAD1397E3A7444014596B28B57B4A405CAD1397E3A7444032E36DA5D7744A4081B3942C279D444032E36DA5D7744A40
46417	Строитель	1	14	156	41.416826	41.444054000000001	52.661707999999997	52.645549000000003	0103000020E61000000100000005000000AE0FEB8D5AB54440967B8159A1524A40AE0FEB8D5AB5444033C005D9B2544A4039D4EFC2D6B8444033C005D9B2544A4039D4EFC2D6B84440967B8159A1524A40AE0FEB8D5AB54440967B8159A1524A40
23738	Стрельцы	1	14	156	41.307330999999998	41.329815000000004	52.730626999999998	52.712524000000002	0103000020E610000001000000050000000306499F56A74440BCCE86FC335B4A400306499F56A744408C497F2F855D4A40795DBF6037AA44408C497F2F855D4A40795DBF6037AA4440BCCE86FC335B4A400306499F56A74440BCCE86FC335B4A40
23835	Столовое	1	14	156	41.746059000000002	41.786006999999998	52.803939	52.768168000000003	0103000020E6100000010000000500000078F17EDC7EDF4440B8EA3A5453624A4078F17EDC7EDF44404E7D2079E7664A40AAB69BE09BE444404E7D2079E7664A40AAB69BE09BE44440B8EA3A5453624A4078F17EDC7EDF4440B8EA3A5453624A40
24243	Солдатская Духовка	1	14	156	41.420904999999998	41.456595	52.923734000000003	52.892842000000002	0103000020E6100000010000000500000087DC0C37E0B54440643F8BA548724A4087DC0C37E0B54440051A6CEA3C764A40314278B471BA4440051A6CEA3C764A40314278B471BA4440643F8BA548724A4087DC0C37E0B54440643F8BA548724A40
46551	Селезни	1	14	156	41.221254000000002	41.261381999999998	52.830226000000003	52.792335999999999	0103000020E61000000100000005000000FA0D130D529C4440C3B81B446B654A40FA0D130D529C4440FB2477D8446A4A40ACE122F774A14440FB2477D8446A4A40ACE122F774A14440C3B81B446B654A40FA0D130D529C4440C3B81B446B654A40
51174	Селезневский	1	14	156	41.132707000000003	41.183875	52.831135000000003	52.810499	0103000020E61000000100000005000000A379008BFC9044406938656EBE674A40A379008BFC904440CEC7B5A1626A4A40A8C64B3789974440CEC7B5A1626A4A40A8C64B37899744406938656EBE674A40A379008BFC9044406938656EBE674A40
51216	Роща	1	14	156	41.232106000000002	41.243020000000001	52.789630000000002	52.780453000000001	0103000020E610000001000000050000004A9A3FA6B59D4440558847E2E5634A404A9A3FA6B59D444062F8889812654A40102384471B9F444062F8889812654A40102384471B9F4440558847E2E5634A404A9A3FA6B59D4440558847E2E5634A40
46158	Пушкари	1	14	156	41.309289	41.337055999999997	52.762844000000001	52.729115999999998	0103000020E610000001000000050000009B012EC896A74440C37E4FAC535D4A409B012EC896A7444094F947DFA4614A40D575A8A624AB444094F947DFA4614A40D575A8A624AB4440C37E4FAC535D4A409B012EC896A74440C37E4FAC535D4A40
51212	Пригородное Лесничество	1	14	156	40.789918999999998	41.839438999999999	53.216535	52.484369000000001	0103000020E6100000010000000500000098BED7101C6544401E19ABCDFF3D4A4098BED7101C6544403DB83B6BB79B4A4054FEB5BC72EB44403DB83B6BB79B4A4054FEB5BC72EB44401E19ABCDFF3D4A4098BED7101C6544401E19ABCDFF3D4A40
23554	Покрово-Пригородное	1	14	156	41.408777000000001	41.437074000000003	52.698604000000003	52.660730000000001	0103000020E61000000100000005000000B22D03CE52B4444038BEF6CC92544A40B22D03CE52B444406A6D1ADB6B594A4049F7730AF2B744406A6D1ADB6B594A4049F7730AF2B7444038BEF6CC92544A40B22D03CE52B4444038BEF6CC92544A40
45979	Новосельцево	1	14	156	41.016950000000001	41.038868999999998	52.562406000000003	52.551997	0103000020E6100000010000000500000067D5E76A2B824440BC3E73D6A7464A4067D5E76A2B8244407F8978EBFC474A4003EACDA8F98444407F8978EBFC474A4003EACDA8F9844440BC3E73D6A7464A4067D5E76A2B824440BC3E73D6A7464A40
23099	Новая Ляда	1	14	156	41.627426999999997	41.71857	52.723804000000001	52.701267000000001	0103000020E610000001000000050000004ED026874FD04440CC61F71DC3594A404ED026874FD04440645B069CA55C4A4080F10C1AFADB4440645B069CA55C4A4080F10C1AFADB4440CC61F71DC3594A404ED026874FD04440CC61F71DC3594A40
22990	Лысые Горы	1	14	156	41.214776999999998	41.244124999999997	52.860574999999997	52.837173999999997	0103000020E610000001000000050000006C770FD07D9B4440DF878384286B4A406C770FD07D9B4440AA605452276E4A406891ED7C3F9F4440AA605452276E4A406891ED7C3F9F4440DF878384286B4A406C770FD07D9B4440DF878384286B4A40
24178	Куксово	1	14	156	41.478000999999999	41.510655	52.880637999999998	52.846860999999997	0103000020E61000000100000005000000473A03232FBD444001A1F5F0656C4A40473A03232FBD4440B3CEF8BEB8704A40FA449E245DC14440B3CEF8BEB8704A40FA449E245DC1444001A1F5F0656C4A40473A03232FBD444001A1F5F0656C4A40
22733	Кузьмино-Гать	1	14	156	41.462434000000002	41.489527000000002	52.574409000000003	52.526429	0103000020E610000001000000050000007C478D0931BB44403F55850662434A407C478D0931BB444098C3EE3B86494A4027C11BD2A8BE444098C3EE3B86494A4027C11BD2A8BE44403F55850662434A407C478D0931BB44403F55850662434A40
22776	Красносвободное	1	14	156	41.288061999999996	41.323743	52.656731999999998	52.642198999999998	0103000020E61000000100000005000000349C3237DFA444400F43AB9333524A40349C3237DFA444404B1E4FCB0F544A408BA71E6970A944404B1E4FCB0F544A408BA71E6970A944400F43AB9333524A40349C3237DFA444400F43AB9333524A40
22378	Красная-Криуша	1	14	156	41.008595999999997	41.052739000000003	52.812328000000001	52.781405999999997	0103000020E610000001000000050000002E7079AC19814440F7729F1C05644A402E7079AC1981444003D0285DFA674A40A41CCC26C086444003D0285DFA674A40A41CCC26C0864440F7729F1C05644A402E7079AC19814440F7729F1C05644A40
22897	Комсомолец	1	14	156	41.265900000000002	41.310716999999997	52.778725999999999	52.760053999999997	0103000020E61000000100000005000000D200DE0209A24440D498107349614A40D200DE0209A24440BF45274BAD634A40D6A71C93C5A74440BF45274BAD634A40D6A71C93C5A74440D498107349614A40D200DE0209A24440D498107349614A40
440	Козьмодемьяновка	1	14	156	41.213582000000002	41.250870999999997	52.896003999999998	52.857590000000002	0103000020E61000000100000005000000D481ACA7569B444036B05582C56D4A40D481ACA7569B4440E78A5242B0724A40E5417A8A1CA04440E78A5242B0724A40E5417A8A1CA0444036B05582C56D4A40D481ACA7569B444036B05582C56D4A40
23930	Иноземная Духовка	1	14	156	41.385357999999997	41.424182999999999	52.937466999999998	52.922435999999998	0103000020E6100000010000000500000040A0336953B144409753026212764A4040A0336953B14440240A2DEBFE774A407442E8A04BB64440240A2DEBFE774A407442E8A04BB644409753026212764A4040A0336953B144409753026212764A40
45389	Иванково	1	14	156	40.964156000000003	41.00582	52.619532	52.604773000000002	0103000020E61000000100000005000000001FBC76697B44407D40A033694D4A40001FBC76697B4440A96917D34C4F4A40D4D4B2B5BE804440A96917D34C4F4A40D4D4B2B5BE8044407D40A033694D4A40001FBC76697B44407D40A033694D4A40
45374	Дубровка	1	14	156	40.858953999999997	40.884242	52.614502000000002	52.588400999999998	0103000020E610000001000000050000005A626534F26D444083F755B9504B4A405A626534F26D4440CEA96400A84E4A40F4DF83D72E714440CEA96400A84E4A40F4DF83D72E71444083F755B9504B4A405A626534F26D444083F755B9504B4A40
45607	Донское	1	14	156	41.451653999999998	41.514769000000001	52.791705	52.761704999999999	0103000020E61000000100000005000000C58D5BCCCFB944408F19A88C7F614A40C58D5BCCCFB94440338AE59656654A4050FF59F3E3C14440338AE59656654A4050FF59F3E3C144408F19A88C7F614A40C58D5BCCCFB944408F19A88C7F614A40
24027	Горельский лесхоз	1	14	156	41.523690000000002	41.538539	52.855485999999999	52.843266	0103000020E61000000100000005000000029F1F4608C3444014EAE923F06B4A40029F1F4608C34440CA17B490806D4A406E4F90D8EEC44440CA17B490806D4A406E4F90D8EEC4444014EAE923F06B4A40029F1F4608C3444014EAE923F06B4A40
45576	Горелое	1	14	156	41.473824	41.515442999999998	52.958612000000002	52.909208999999997	0103000020E61000000100000005000000AB07CC43A6BC44404B1DE4F560744A40AB07CC43A6BC4440CEC64ACCB37A4A40DFF94509FAC14440CEC64ACCB37A4A40DFF94509FAC144404B1DE4F560744A40AB07CC43A6BC44404B1DE4F560744A40
5063	Георгиевский	1	14	156	41.553477999999998	41.567366	52.702041999999999	52.698183999999998	0103000020E610000001000000050000001A87FA5DD8C64440944BE3175E594A401A87FA5DD8C644408F352383DC594A40616EF7729FC844408F352383DC594A40616EF7729FC84440944BE3175E594A401A87FA5DD8C64440944BE3175E594A40
45736	Борщевка	1	14	156	41.308624000000002	41.320993999999999	52.616394	52.602493000000003	0103000020E610000001000000050000005F61C1FD80A74440D388997D1E4D4A405F61C1FD80A74440AEB9A3FFE54E4A402A1BD65416A94440AEB9A3FFE54E4A402A1BD65416A94440D388997D1E4D4A405F61C1FD80A74440D388997D1E4D4A40
23824	Большая Талинка	1	14	156	41.787768	41.839438999999999	52.857520000000001	52.822744999999998	0103000020E61000000100000005000000EC6AF294D5E4444048F949B54F694A40EC6AF294D5E444403DD52137C36D4A4054FEB5BC72EB44403DD52137C36D4A4054FEB5BC72EB444048F949B54F694A40EC6AF294D5E4444048F949B54F694A40
45502	Большая Липовица	1	14	156	41.300987999999997	41.350476999999998	52.566215999999997	52.527940999999998	0103000020E61000000100000005000000853E58C686A64440D89B189293434A40853E58C686A64440683C11C479484A4006802A6EDCAC4440683C11C479484A4006802A6EDCAC4440D89B189293434A40853E58C686A64440D89B189293434A40
22313	Беломестная-Криуша	1	14	156	41.098086000000002	41.184441	52.796061000000002	52.777968999999999	0103000020E61000000100000005000000051901158E8C4440A226FA7C94634A40051901158E8C44407F4FAC53E5654A4051853FC39B9744407F4FAC53E5654A4051853FC39B974440A226FA7C94634A40051901158E8C4440A226FA7C94634A40
22197	Беломестная Двойня	1	14	156	41.036093000000001	41.086489	52.715006000000002	52.685957999999999	0103000020E61000000100000005000000A94E07B29E844440FC36C478CD574A40A94E07B29E844440CE380D51855B4A405C3B5112128B4440CE380D51855B4A405C3B5112128B4440FC36C478CD574A40A94E07B29E844440FC36C478CD574A40
45343	Авдеевка	1	14	156	40.882624999999997	40.902495999999999	52.647046000000003	52.631149000000001	0103000020E61000000100000005000000E5D022DBF970444099F38C7DC9504A40E5D022DBF9704440FA804067D2524A40AA622AFD84734440FA804067D2524A40AA622AFD8473444099F38C7DC9504A40E5D022DBF970444099F38C7DC9504A40
22652	Красненькая	1	14	1702	41.430984000000002	41.484326000000003	52.766789000000003	52.751089	0103000020E61000000100000005000000B58CD47B2AB7444053B131AF23604A40B58CD47B2AB744405EF7562426624A401F4DF564FEBD44405EF7562426624A401F4DF564FEBD444053B131AF23604A40B58CD47B2AB7444053B131AF23604A40
17681	Троицко-Ивановское	1	14	806	40.516013999999998	40.549124999999997	53.453999000000003	53.438811000000001	0103000020E610000001000000050000009A232BBF0C424440021077F52AB84A409A232BBF0C42444057B5A4A31CBA4A403F355EBA4946444057B5A4A31CBA4A403F355EBA49464440021077F52AB84A409A232BBF0C424440021077F52AB84A40
5796	Староюрьево	1	14	806	40.661288999999996	40.733567999999998	53.352997999999999	53.297058999999997	0103000020E610000001000000050000002E1A321EA5544440C1FD800706A64A402E1A321EA5544440D6C6D8092FAD4A4031B2648EE55D4440D6C6D8092FAD4A4031B2648EE55D4440C1FD800706A64A402E1A321EA5544440C1FD800706A64A40
51251	Старая Александровка	1	14	806	40.595388999999997	40.616652000000002	53.285291999999998	53.265524999999997	0103000020E61000000100000005000000F6B2EDB4354C44409CA223B9FCA14A40F6B2EDB4354C4440BCE7C07284A44A40AA81E673EE4E4440BCE7C07284A44A40AA81E673EE4E44409CA223B9FCA14A40F6B2EDB4354C44409CA223B9FCA14A40
17584	Спасское	1	14	806	40.441732000000002	40.473298999999997	53.414388000000002	53.398744999999998	0103000020E6100000010000000500000060CC96AC8A384440C5387F130AB34A4060CC96AC8A3844406CED7DAA0AB54A40601DC70F953C44406CED7DAA0AB54A40601DC70F953C4440C5387F130AB34A4060CC96AC8A384440C5387F130AB34A40
17671	Скобелевка	1	14	806	40.506680000000003	40.538552000000003	53.398578999999998	53.382581999999999	0103000020E61000000100000005000000C6C4E6E3DA404440E6046D72F8B04A40C6C4E6E3DA404440AAEFFCA204B34A4003999D45EF444440AAEFFCA204B34A4003999D45EF444440E6046D72F8B04A40C6C4E6E3DA404440E6046D72F8B04A40
8660	Рахманино	1	14	806	40.726965	40.756672000000002	53.285648000000002	53.270001000000001	0103000020E61000000100000005000000172B6A300D5D444093718C648FA24A40172B6A300D5D44407B15191D90A44A4043E6CAA0DA6044407B15191D90A44A4043E6CAA0DA60444093718C648FA24A40172B6A300D5D444093718C648FA24A40
17514	Поповка	1	14	806	40.817703999999999	40.881835000000002	53.337344000000002	53.319662000000001	0103000020E6100000010000000500000079E75086AA68444011E335AFEAA84A4079E75086AA6844403CC093162EAB4A40EDBB22F8DF7044403CC093162EAB4A40EDBB22F8DF70444011E335AFEAA84A4079E75086AA68444011E335AFEAA84A40
17365	Подгорное	1	14	806	40.718521000000003	40.758369999999999	53.276468000000001	53.251519999999999	0103000020E610000001000000050000009F3E027FF85B44401C25AFCE31A04A409F3E027FF85B4440FD31AD4D63A34A403E22A64412614440FD31AD4D63A34A403E22A644126144401C25AFCE31A04A409F3E027FF85B44401C25AFCE31A04A40
17217	Новоюрьево	1	14	806	40.834924000000001	40.928699999999999	53.389048000000003	53.344822999999998	0103000020E61000000100000005000000A05225CADE6A44404DF4F92823AC4A40A05225CADE6A444080492A53CCB14A40C9E53FA4DF76444080492A53CCB14A40C9E53FA4DF7644404DF4F92823AC4A40A05225CADE6A44404DF4F92823AC4A40
5722	Новиково	1	14	806	40.584465000000002	40.609276999999999	53.353805000000001	53.310242000000002	0103000020E610000001000000050000000D54C6BFCF4A44403EEC8502B6A74A400D54C6BFCF4A4440A514747B49AD4A403D9AEAC9FC4D4440A514747B49AD4A403D9AEAC9FC4D44403EEC8502B6A74A400D54C6BFCF4A44403EEC8502B6A74A40
17453	Надеждина	1	14	806	40.774566999999998	40.794913999999999	53.218848000000001	53.210608000000001	0103000020E61000000100000005000000C9C7EE02256344405323F433F59A4A40C9C7EE0225634440C3651536039C4A40F790F0BDBF654440C3651536039C4A40F790F0BDBF6544405323F433F59A4A40C9C7EE02256344405323F433F59A4A40
17070	Мезинец	1	14	806	40.591929999999998	40.641956999999998	53.503086000000003	53.441262000000002	0103000020E61000000100000005000000B9C2BB5CC44B4440D97BF1457BB84A40B9C2BB5CC44B4440A9893E1F65C04A401938A0A52B524440A9893E1F65C04A401938A0A52B524440D97BF1457BB84A40B9C2BB5CC44B4440D97BF1457BB84A40
17462	Крутовское	1	14	806	40.863211999999997	40.902836999999998	53.300761000000001	53.289276000000001	0103000020E61000000100000005000000E3C116BB7D6E444044C2F7FE06A54A40E3C116BB7D6E4440C57421567FA64A40334FAE2990734440C57421567FA64A40334FAE299073444044C2F7FE06A54A40E3C116BB7D6E444044C2F7FE06A54A40
16881	Заворонежское	1	14	806	40.623649999999998	40.671638000000002	53.414307000000001	53.373283000000001	0103000020E61000000100000005000000401361C3D34F44408E93C2BCC7AF4A40401361C3D34F44407FC0030308B54A401C60E63BF85544407FC0030308B54A401C60E63BF85544408E93C2BCC7AF4A40401361C3D34F44408E93C2BCC7AF4A40
16925	Вишневое	1	14	806	40.674889999999998	40.707543000000001	53.235596999999999	53.214761000000003	0103000020E61000000100000005000000DF32A7CB6256444067BAD7497D9B4A40DF32A7CB625644409204E10A289E4A40C2C1DEC4905A44409204E10A289E4A40C2C1DEC4905A444067BAD7497D9B4A40DF32A7CB6256444067BAD7497D9B4A40
51252	Большая Дорога	1	14	806	40.659770999999999	40.689675999999999	53.409948999999997	53.376871999999999	0103000020E61000000100000005000000B3EC496073544440996379573DB04A40B3EC4960735444409203763579B44A40056B9C4D475844409203763579B44A40056B9C4D47584440996379573DB04A40B3EC496073544440996379573DB04A40
17161	Боголюбово	1	14	806	40.547508999999998	40.573596000000002	53.339092000000001	53.323599000000002	0103000020E6100000010000000500000001A260C614464440580229B16BA94A4001A260C614464440E92ADD5D67AB4A40E78EFE976B494440E92ADD5D67AB4A40E78EFE976B494440580229B16BA94A4001A260C614464440580229B16BA94A40
51253	Челнаво-Рождественская	1	14	799	41.162019000000001	41.208103000000001	52.969942000000003	52.950592999999998	0103000020E61000000100000005000000522AE109BD9444403C670B08AD794A40522AE109BD9444402882380F277C4A4089997D1EA39A44402882380F277C4A4089997D1EA39A44403C670B08AD794A40522AE109BD9444403C670B08AD794A40
47620	Чекмари	1	14	799	41.273167999999998	41.296793000000001	53.031028999999997	53.009188000000002	0103000020E610000001000000050000002828452BF7A2444001C287122D814A402828452BF7A24440211D1EC2F8834A4043572250FDA54440211D1EC2F8834A4043572250FDA5444001C287122D814A402828452BF7A2444001C287122D814A40
47762	Христофоровка	1	14	799	40.905137000000003	40.931826000000001	53.263209000000003	53.247247000000002	0103000020E6100000010000000500000025B37A87DB7344405E8429CAA59F4A4025B37A87DB734440A6811FD5B0A14A4000C8091346774440A6811FD5B0A14A4000C80913467744405E8429CAA59F4A4025B37A87DB7344405E8429CAA59F4A40
16570	Троицкие Росляи	1	14	799	41.361328	41.406692999999997	53.378182000000002	53.342446000000002	0103000020E610000001000000050000008690F3FE3FAE4440B1524145D5AB4A408690F3FE3FAE4440CBF78C4468B04A408D4127840EB44440CBF78C4468B04A408D4127840EB44440B1524145D5AB4A408690F3FE3FAE4440B1524145D5AB4A40
15585	Троицкая Вихляйка	1	14	799	41.337657999999998	41.371380000000002	53.105741000000002	53.082526000000001	0103000020E61000000100000005000000CB9D996038AB4440EC884336908A4A40CB9D996038AB4440556CCCEB888D4A40BA313D6189AF4440556CCCEB888D4A40BA313D6189AF4440EC884336908A4A40CB9D996038AB4440EC884336908A4A40
15403	Третьи Левые Ламки	1	14	799	41.264004999999997	41.318452000000001	53.209448999999999	53.193142999999999	0103000020E61000000100000005000000807D74EACAA14440C539EAE8B8984A40807D74EACAA1444007978E39CF9A4A4043ACFE08C3A8444007978E39CF9A4A4043ACFE08C3A84440C539EAE8B8984A40807D74EACAA14440C539EAE8B8984A40
47176	Стежки	1	14	799	41.185285	41.23357	53.110481999999998	53.062866	0103000020E610000001000000050000003DB83B6BB7974440E2033BFE0B884A403DB83B6BB7974440F9653046248E4A40D2A92B9FE59D4440F9653046248E4A40D2A92B9FE59D4440E2033BFE0B884A403DB83B6BB7974440E2033BFE0B884A40
16676	Старое Грязное	1	14	799	41.475530999999997	41.515658999999999	53.261319	53.238624999999999	0103000020E61000000100000005000000F99D2633DEBC4440068195438B9E4A40F99D2633DEBC44406669A7E672A14A40AC71361D01C244406669A7E672A14A40AC71361D01C24440068195438B9E4A40F99D2633DEBC4440068195438B9E4A40
45623	Сосновка	1	14	799	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
46579	Советское	1	14	799	41.196936999999998	41.238232000000004	53.137796999999999	53.101010000000002	0103000020E61000000100000005000000A92F4B3B35994440D4484BE5ED8C4A40A92F4B3B35994440533E0455A3914A402B6EDC627E9E4440533E0455A3914A402B6EDC627E9E4440D4484BE5ED8C4A40A92F4B3B35994440D4484BE5ED8C4A40
15150	Семикино	1	14	799	41.555309999999999	41.578648999999999	53.153109000000001	53.132482000000003	0103000020E610000001000000050000002592E86514C7444083A7902BF5904A402592E86514C7444094DC611399934A407A6EA12B11CA444094DC611399934A407A6EA12B11CA444083A7902BF5904A402592E86514C7444083A7902BF5904A40
16620	Савинские Карпели	1	14	799	41.461112999999997	41.512757000000001	53.353051999999998	53.321238000000001	0103000020E61000000100000005000000566133C005BB4440C11DA8531EA94A40566133C005BB4440C9E4D4CE30AD4A40C5E57805A2C14440C9E4D4CE30AD4A40C5E57805A2C14440C11DA8531EA94A40566133C005BB4440C11DA8531EA94A40
47355	Рабочий	1	14	799	41.572153999999998	41.582619000000001	53.193375000000003	53.184444999999997	0103000020E6100000010000000500000046239F573CC944409274CDE49B974A4046239F573CC94440986E1283C0984A409D83674293CA4440986E1283C0984A409D83674293CA44409274CDE49B974A4046239F573CC944409274CDE49B974A40
15449	Правые Ламки	1	14	799	41.252811999999999	41.331262000000002	53.240532999999999	53.207248	0103000020E61000000100000005000000A704C4245CA04440A9143B1A879A4A40A704C4245CA04440EC4D0CC9C99E4A402B3410CB66AA4440EC4D0CC9C99E4A402B3410CB66AA4440A9143B1A879A4A40A704C4245CA04440A9143B1A879A4A40
45993	Поповка	1	14	799	41.217300999999999	41.228090000000002	53.255862	53.250798000000003	0103000020E61000000100000005000000AD31E884D09B44407CF31B261AA04A40AD31E884D09B444003250516C0A04A40B745990D329D444003250516C0A04A40B745990D329D44407CF31B261AA04A40AD31E884D09B44407CF31B261AA04A40
16459	Покрово-Васильевка	1	14	799	41.014569999999999	41.057509000000003	53.418300000000002	53.383425000000003	0103000020E6100000010000000500000059C0046EDD81444002BC051214B14A4059C0046EDD8144405AF5B9DA8AB54A40E31C75745C8744405AF5B9DA8AB54A40E31C75745C87444002BC051214B14A4059C0046EDD81444002BC051214B14A40
47601	Подлесное	1	14	799	41.215181000000001	41.264454000000001	53.173451999999997	53.140920000000001	0103000020E610000001000000050000003CDC0E0D8B9B444019ADA3AA09924A403CDC0E0D8B9B444080B6D5AC33964A40F0A5F0A0D9A1444080B6D5AC33964A40F0A5F0A0D9A1444019ADA3AA09924A403CDC0E0D8B9B444019ADA3AA09924A40
5651	Перкинский лесокомбинат	1	14	799	41.573627000000002	41.599030999999997	53.099777000000003	53.089092000000001	0103000020E61000000100000005000000228D0A9C6CC94440E92ADD5D678B4A40228D0A9C6CC944404EF2237EC58C4A4024253D0CADCC44404EF2237EC58C4A4024253D0CADCC4440E92ADD5D678B4A40228D0A9C6CC94440E92ADD5D678B4A40
15285	Перкино	1	14	799	41.522548999999998	41.572594000000002	53.134464000000001	53.087420999999999	0103000020E610000001000000050000005CC7B8E2E2C24440E7FD7F9C308B4A405CC7B8E2E2C24440A33EC91D36914A4063F19BC24AC94440A33EC91D36914A4063F19BC24AC94440E7FD7F9C308B4A405CC7B8E2E2C24440E7FD7F9C308B4A40
15392	Первые Левые Ламки	1	14	799	41.251842000000003	41.276321000000003	53.192495000000001	53.172722999999998	0103000020E610000001000000050000002FE1D05B3CA044402D228AC91B964A402FE1D05B3CA044405FD218ADA3984A4059198D7C5EA344405FD218ADA3984A4059198D7C5EA344402D228AC91B964A402FE1D05B3CA044402D228AC91B964A40
16784	Отъяссы	1	14	799	41.621946999999999	41.696939	53.249090000000002	53.225467999999999	0103000020E61000000100000005000000336C94F59BCF4440B325AB22DC9C4A40336C94F59BCF44405DE15D2EE29F4A404A27124C35D944405DE15D2EE29F4A404A27124C35D94440B325AB22DC9C4A40336C94F59BCF4440B325AB22DC9C4A40
47884	Ольхи	1	14	799	41.191771000000003	41.226886	53.304065000000001	53.276634999999999	0103000020E610000001000000050000001EA9BEF38B984440E8F692C668A34A401EA9BEF38B984440DB6D179AEBA64A40CBF5B6990A9D4440DB6D179AEBA64A40CBF5B6990A9D4440E8F692C668A34A401EA9BEF38B984440E8F692C668A34A40
16364	Новочеркасовка	1	14	799	41.176374000000003	41.220275000000001	53.440061	53.417403999999998	0103000020E61000000100000005000000AFEE586C939644401B9C887E6DB54A40AFEE586C939644405E9F39EB53B84A402E90A0F8319C44405E9F39EB53B84A402E90A0F8319C44401B9C887E6DB54A40AFEE586C939644401B9C887E6DB54A40
16776	Новое Грязное	1	14	799	41.448276	41.476438000000002	53.250545000000002	53.227004999999998	0103000020E6100000010000000500000075CAA31B61B94440A583F57F0E9D4A4075CAA31B61B944409296CADB11A04A402C499EEBFBBC44409296CADB11A04A402C499EEBFBBC4440A583F57F0E9D4A4075CAA31B61B94440A583F57F0E9D4A40
51219	Новая Слобода	1	14	799	41.258893	41.290154999999999	53.048457999999997	53.022688000000002	0103000020E61000000100000005000000E814E46723A144407E01BD70E7824A40E814E46723A14440629D2ADF33864A40ACE28DCC23A54440629D2ADF33864A40ACE28DCC23A544407E01BD70E7824A40E814E46723A144407E01BD70E7824A40
16150	Новая Поповка	1	14	799	40.973039999999997	40.996369999999999	53.162908999999999	53.145414000000002	0103000020E6100000010000000500000094D920938C7C4440B6300BED9C924A4094D920938C7C4440AE9CBD33DA944A40965B5A0D897F4440AE9CBD33DA944A40965B5A0D897F4440B6300BED9C924A4094D920938C7C4440B6300BED9C924A40
16066	Новая Павловка	1	14	799	40.987126000000004	41.011785000000003	53.203235999999997	53.187834000000002	0103000020E6100000010000000500000002840F255A7E4440D789CBF10A984A4002840F255A7E444057AF22A3039A4A40ACCABE2B8281444057AF22A3039A4A40ACCABE2B82814440D789CBF10A984A4002840F255A7E4440D789CBF10A984A40
15967	Нижняя Ярославка	1	14	799	41.020336999999998	41.075609999999998	53.257904000000003	53.229813	0103000020E610000001000000050000000AF31E679A8244400B992B836A9D4A400AF31E679A824440F9C08EFF02A14A4012A0A696AD894440F9C08EFF02A14A4012A0A696AD8944400B992B836A9D4A400AF31E679A8244400B992B836A9D4A40
51227	Красный Хутор	1	14	799	41.493470000000002	41.516773000000001	53.139521000000002	53.119599999999998	0103000020E6100000010000000500000050C763062ABF4440014D840D4F8F4A4050C763062ABF4440780DFAD2DB914A40583A1F9E25C24440780DFAD2DB914A40583A1F9E25C24440014D840D4F8F4A4050C763062ABF4440014D840D4F8F4A40
15016	Космачевка	1	14	799	41.366951999999998	41.379519000000002	53.322350999999998	53.301504000000001	0103000020E61000000100000005000000D4997B48F8AE44407DCEDDAE97A64A40D4997B48F8AE44409C6A2DCC42A94A40F69A1E1494B044409C6A2DCC42A94A40F69A1E1494B044407DCEDDAE97A64A40D4997B48F8AE44407DCEDDAE97A64A40
47553	Каменный Брод	1	14	799	41.184108999999999	41.216825	52.997093	52.977837999999998	0103000020E610000001000000050000001BF33AE2909744409D64ABCB297D4A401BF33AE290974440070951BEA07F4A4044FAEDEBC09B4440070951BEA07F4A4044FAEDEBC09B44409D64ABCB297D4A401BF33AE2909744409D64ABCB297D4A40
47692	Зеленое	1	14	799	40.917290999999999	40.948903000000001	53.216788000000001	53.193967999999998	0103000020E6100000010000000500000023F59ECA697544403A3C84F1D3984A4023F59ECA6975444027158DB5BF9B4A40C4094CA77579444027158DB5BF9B4A40C4094CA7757944403A3C84F1D3984A4023F59ECA697544403A3C84F1D3984A40
49251	Заречье	1	14	799	41.584209000000001	41.605733000000001	53.111865000000002	53.093462000000002	0103000020E61000000100000005000000B2834A5CC7CA44409AB51490F68B4A40B2834A5CC7CA44409548A297518E4A40D28DB0A888CD44409548A297518E4A40D28DB0A888CD44409AB51490F68B4A40B2834A5CC7CA44409AB51490F68B4A40
16468	Дельная Дубрава	1	14	799	41.284405999999997	41.324255000000001	53.391582	53.358147000000002	0103000020E61000000100000005000000A164726A67A444408C14CAC2D7AD4A40A164726A67A44440E4D9E55B1FB24A404148163081A94440E4D9E55B1FB24A404148163081A944408C14CAC2D7AD4A40A164726A67A444408C14CAC2D7AD4A40
47551	Дегтянка	1	14	799	41.191052999999997	41.227640999999998	53.034115999999997	53.017569000000002	0103000020E61000000100000005000000BE66B96C74984440333674B33F824A40BE66B96C749844409A22C0E95D844A40471D1D57239D44409A22C0E95D844A40471D1D57239D4440333674B33F824A40BE66B96C74984440333674B33F824A40
15959	Вторые Левые Ламки	1	14	799	41.051777999999999	41.086174	53.291471999999999	53.260596999999997	0103000020E610000001000000050000007E5358A9A0864440C537143E5BA14A407E5358A9A086444090D959F44EA54A40FCE1E7BF078B444090D959F44EA54A40FCE1E7BF078B4440C537143E5BA14A407E5358A9A0864440C537143E5BA14A40
15091	Вирятино	1	14	799	41.453710999999998	41.498564000000002	53.191071000000001	53.171131000000003	0103000020E61000000100000005000000F06AB93313BA4440782AE09EE7954A40F06AB93313BA4440651BB80375984A40427BF5F1D0BF4440651BB80375984A40427BF5F1D0BF4440782AE09EE7954A40F06AB93313BA4440782AE09EE7954A40
16309	Верхняя Ярославка	1	14	799	41.091151000000004	41.148975999999998	53.398105999999999	53.348215000000003	0103000020E61000000100000005000000B5FF01D6AA8B4440037D224F92AC4A40B5FF01D6AA8B4440B22B2D23F5B24A40C7F143A511934440B22B2D23F5B24A40C7F143A511934440037D224F92AC4A40B5FF01D6AA8B4440037D224F92AC4A40
51202	Атаманов Угол	1	14	799	41.369484999999997	41.411346000000002	53.147373999999999	53.1158	0103000020E6100000010000000500000068AED3484BAF44403B70CE88D28E4A4068AED3484BAF4440EE23B726DD924A4093AB58FCA6B44440EE23B726DD924A4093AB58FCA6B444403B70CE88D28E4A4068AED3484BAF44403B70CE88D28E4A40
13867	Текино	1	14	610	41.541153000000001	41.602418	52.352038	52.317264999999999	0103000020E61000000100000005000000EF90628044C544402D95B7239C284A40EF90628044C544408179C8940F2D4A40C84274081CCD44408179C8940F2D4A40C84274081CCD44402D95B7239C284A40EF90628044C544402D95B7239C284A40
13964	Совхоз Россия	1	14	610	41.647181000000003	41.664158999999998	52.404809	52.396000999999998	0103000020E61000000100000005000000DACBB6D3D6D2444076172829B0324A40DACBB6D3D6D24440301004C8D0334A400A2C802903D54440301004C8D0334A400A2C802903D5444076172829B0324A40DACBB6D3D6D2444076172829B0324A40
14352	Серединовка	1	14	610	41.725811	41.812398999999999	52.257829999999998	52.238725000000002	0103000020E61000000100000005000000DD09F65FE7DC44406ADE718A8E1E4A40DD09F65FE7DC4440BEF6CC9200214A40CC26C0B0FCE74440BEF6CC9200214A40CC26C0B0FCE744406ADE718A8E1E4A40DD09F65FE7DC44406ADE718A8E1E4A40
5587	Сатинка	1	14	610	41.65249	41.699122000000003	52.387427000000002	52.369070999999998	0103000020E61000000100000005000000C87BD5CA84D344407573F1B73D2F4A40C87BD5CA84D34440304B3B3597314A4002F566D47CD94440304B3B3597314A4002F566D47CD944407573F1B73D2F4A40C87BD5CA84D344407573F1B73D2F4A40
13860	Сампур	1	14	610	41.608517999999997	41.640453000000001	52.330497999999999	52.296010000000003	0103000020E610000001000000050000007F83F6EAE3CD4440FDA4DAA7E3254A407F83F6EAE3CD44405BB22AC24D2A4A4003D0285DFAD144405BB22AC24D2A4A4003D0285DFAD14440FDA4DAA7E3254A407F83F6EAE3CD4440FDA4DAA7E3254A40
14436	Понзари	1	14	610	41.653486999999998	41.730409999999999	52.259506000000002	52.234637999999997	0103000020E610000001000000050000003AAE4676A5D344400D33349E081E4A403AAE4676A5D34440D28E1B7E37214A40EF552B137EDD4440D28E1B7E37214A40EF552B137EDD44400D33349E081E4A403AAE4676A5D344400D33349E081E4A40
14578	Петровка	1	14	610	41.642887000000002	41.665489000000001	52.421250000000001	52.404313999999999	0103000020E610000001000000050000000403081F4AD2444050A8A78FC0334A400403081F4AD2444052B81E85EB354A40836C59BE2ED5444052B81E85EB354A40836C59BE2ED5444050A8A78FC0334A400403081F4AD2444050A8A78FC0334A40
14533	Перикса	1	14	610	41.765237999999997	41.781748999999998	52.406599999999997	52.395994999999999	0103000020E6100000010000000500000006D49B51F3E144409430D3F6AF324A4006D49B51F3E14440DC4603780B344A402157EA5910E44440DC4603780B344A402157EA5910E444409430D3F6AF324A4006D49B51F3E144409430D3F6AF324A40
5433	Первомайское	1	14	610	41.454915	41.475810000000003	52.147137000000001	52.11421	0103000020E61000000100000005000000DCBA9BA73ABA44402670EB6E9E0E4A40DCBA9BA73ABA44400A849D62D5124A400D8E9257E7BC44400A849D62D5124A400D8E9257E7BC44402670EB6E9E0E4A40DCBA9BA73ABA44402670EB6E9E0E4A40
14252	Пановы Кусты	1	14	610	41.540577999999996	41.591934999999999	52.104348000000002	52.074893000000003	0103000020E61000000100000005000000F277EFA831C5444084D9041896094A40F277EFA831C5444096B377465B0D4A40CB2DAD86C4CB444096B377465B0D4A40CB2DAD86C4CB444084D9041896094A40F277EFA831C5444084D9041896094A40
51214	Осино-Лазовка	1	14	610	41.720708000000002	41.774428	52.318972000000002	52.291184999999999	0103000020E6100000010000000500000098FBE42840DC4440FA0AD28C45254A4098FBE42840DC44407C2B1213D4284A40A88DEA7420E344407C2B1213D4284A40A88DEA7420E34440FA0AD28C45254A4098FBE42840DC4440FA0AD28C45254A40
14444	Медное	1	14	610	41.843795	41.884318	52.342399999999998	52.329264999999999	0103000020E61000000100000005000000A0C37C7901EC4440D55B035B252A4A40A0C37C7901EC4440401361C3D32B4A40CFA10C5531F14440401361C3D32B4A40CFA10C5531F14440D55B035B252A4A40A0C37C7901EC4440D55B035B252A4A40
4426	Марьевка	1	14	610	41.519053999999997	41.533346999999999	52.209463999999997	52.202665000000003	0103000020E61000000100000005000000D26D895C70C244409D853DEDF0194A40D26D895C70C244403CD862B7CF1A4A40B935E9B644C444403CD862B7CF1A4A40B935E9B644C444409D853DEDF0194A40D26D895C70C244409D853DEDF0194A40
14078	Ивановка	1	14	610	41.567113999999997	41.901431000000002	52.351978000000003	52.236238	0103000020E61000000100000005000000478D093197C844404609FA0B3D1E4A40478D093197C84440AC74779D0D2D4A40E04C4C1762F34440AC74779D0D2D4A40E04C4C1762F344404609FA0B3D1E4A40478D093197C844404609FA0B3D1E4A40
14300	Верхоценье	1	14	610	41.808616999999998	41.850774999999999	52.264671	52.238526999999998	0103000020E61000000100000005000000ACFE08C380E74440431B800D881E4A40ACFE08C380E744408D9944BDE0214A4090A0F831E6EC44408D9944BDE0214A4090A0F831E6EC4440431B800D881E4A40ACFE08C380E74440431B800D881E4A40
14154	Бахарево	1	14	610	41.618991999999999	41.668309999999998	52.221432	52.155476	0103000020E61000000100000005000000293E3E213BCF44400DA837A3E6134A40293E3E213BCF4440D9243FE2571C4A407DCB9C2E8BD54440D9243FE2571C4A407DCB9C2E8BD544400DA837A3E6134A40293E3E213BCF44400DA837A3E6134A40
46451	Андреевка	1	14	610	41.706434000000002	41.720267999999997	52.431283000000001	52.423105999999997	0103000020E610000001000000050000002864E76D6CDA4440E55E605628364A402864E76D6CDA44400F29064834374A407B2DE8BD31DC44400F29064834374A407B2DE8BD31DC4440E55E605628364A402864E76D6CDA4440E55E605628364A40
4529	Александровские Верхи	1	14	610	41.630571000000003	41.670276999999999	52.141494999999999	52.128177999999998	0103000020E610000001000000050000002C67EF8CB6D044408908FF2268104A402C67EF8CB6D0444015C616821C124A40682101A3CBD5444015C616821C124A40682101A3CBD544408908FF2268104A402C67EF8CB6D044408908FF2268104A40
13589	Чакино	1	14	684	41.944299000000001	41.962912000000003	52.246346000000003	52.222591000000001	0103000020E61000000100000005000000A05225CADEF8444025B1A4DC7D1C4A40A05225CADEF844400EC00644881F4A4086764EB340FB44400EC00644881F4A4086764EB340FB444025B1A4DC7D1C4A40A05225CADEF8444025B1A4DC7D1C4A40
46531	Траковка	1	14	684	42.016461	42.032451000000002	52.353326000000003	52.337524999999999	0103000020E610000001000000050000006954E0641B0245408C4AEA04342B4A406954E0641B024540CB694FC9392D4A407BDCB75A27044540CB694FC9392D4A407BDCB75A270445408C4AEA04342B4A406954E0641B0245408C4AEA04342B4A40
46705	Тимофеевка	1	14	684	41.949975999999999	41.970979	52.197752000000001	52.174776999999999	0103000020E6100000010000000500000011FE45D098F94440E78BBD175F164A4011FE45D098F94440FB5B02F04F194A40280D350A49FC4440FB5B02F04F194A40280D350A49FC4440E78BBD175F164A4011FE45D098F94440E78BBD175F164A40
46640	Степановка	1	14	684	41.975408000000002	42.021113999999997	52.037984999999999	52.015802000000001	0103000020E61000000100000005000000DE205A2BDAFC44400F9BC8CC05024A40DE205A2BDAFC4440895E46B1DC044A406EBE11DDB3024540895E46B1DC044A406EBE11DDB30245400F9BC8CC05024A40DE205A2BDAFC44400F9BC8CC05024A40
46499	Серебряное	1	14	684	42.095511999999999	42.111916000000001	52.312811000000004	52.299370000000003	0103000020E610000001000000050000001230BABC390C4540A7B393C151264A401230BABC390C45401F6ADB300A284A4017F37343530E45401F6ADB300A284A4017F37343530E4540A7B393C151264A401230BABC390C4540A7B393C151264A40
12483	Ржакса	1	14	684	41.988559000000002	42.055618000000003	52.155282999999997	52.122450000000001	0103000020E610000001000000050000004F95EF1989FE444096B20C71AC0F4A404F95EF1989FE4440F84F3750E0134A40D388997D1E074540F84F3750E0134A40D388997D1E07454096B20C71AC0F4A404F95EF1989FE444096B20C71AC0F4A40
46378	Ракитино	1	14	684	41.643354000000002	41.663682999999999	52.036372	52.025956000000001	0103000020E610000001000000050000001AE0826C59D244404791B58652034A401AE0826C59D24440BC3E73D6A7044A40A1F48590F3D44440BC3E73D6A7044A40A1F48590F3D444404791B58652034A401AE0826C59D244404791B58652034A40
46536	Протасово	1	14	684	41.728586	41.746706000000003	52.143833000000001	52.118872000000003	0103000020E610000001000000050000006729594E42DD44407F349C32370F4A406729594E42DD4440F48AA71E69124A400EDDEC0F94DF4440F48AA71E69124A400EDDEC0F94DF44407F349C32370F4A406729594E42DD44407F349C32370F4A40
46343	Перевоз	1	14	684	42.253894000000003	42.304091999999997	52.138460000000002	52.119219999999999	0103000020E6100000010000000500000048533D997F204540BA83D899420F4A4048533D997F204540EFE6A90EB9114A40D47C957CEC264540EFE6A90EB9114A40D47C957CEC264540BA83D899420F4A4048533D997F204540BA83D899420F4A40
46214	Пахарь	1	14	684	41.883572999999998	41.905293999999998	52.111201000000001	52.101737	0103000020E61000000100000005000000765089EB18F1444086E5CFB7050D4A40765089EB18F14440292499D53B0E4A40ECA17DACE0F34440292499D53B0E4A40ECA17DACE0F3444086E5CFB7050D4A40765089EB18F1444086E5CFB7050D4A40
13580	Отхожее	1	14	684	42.062193999999998	42.100669000000003	52.074528000000001	52.052934	0103000020E61000000100000005000000F30016F9F5074540596C938AC6064A40F30016F9F507454072512D228A094A404B5CC7B8E20C454072512D228A094A404B5CC7B8E20C4540596C938AC6064A40F30016F9F5074540596C938AC6064A40
46227	Николаевский	1	14	684	41.885711000000001	41.892699999999998	52.164813000000002	52.162469999999999	0103000020E610000001000000050000008E5A61FA5EF14440624A24D1CB144A408E5A61FA5EF14440537AA69718154A40D1915CFE43F24440537AA69718154A40D1915CFE43F24440624A24D1CB144A408E5A61FA5EF14440624A24D1CB144A40
13506	Недобровка	1	14	684	41.987301000000002	41.997515	52.082321	52.075436000000003	0103000020E61000000100000005000000702711E15FFE4440757808E3A7094A40702711E15FFE44401363997E890A4A407D224F92AEFF44401363997E890A4A407D224F92AEFF4440757808E3A7094A40702711E15FFE4440757808E3A7094A40
46574	Лукино	1	14	684	42.093114	42.112841000000003	52.235593000000001	52.199623000000003	0103000020E610000001000000050000005E66D828EB0B4540C443183F8D194A405E66D828EB0B4540511553E9271E4A40F052EA92710E4540511553E9271E4A40F052EA92710E4540C443183F8D194A405E66D828EB0B4540C443183F8D194A40
51196	Каменка	1	14	684	41.780554000000002	41.816701999999999	52.085287000000001	52.063184	0103000020E6100000010000000500000089618731E9E34440B3D0CE6916084A4089618731E9E3444011E335AFEA0A4A40F549EEB089E8444011E335AFEA0A4A40F549EEB089E84440B3D0CE6916084A4089618731E9E34440B3D0CE6916084A40
45440	Ивановка	1	14	684	41.948225000000001	42.200192999999999	52.359783	52.204734999999999	0103000020E61000000100000005000000F31FD26F5FF944405CACA8C1341A4A40F31FD26F5FF9444011548D5E0D2E4A40AEF199EC9F19454011548D5E0D2E4A40AEF199EC9F1945405CACA8C1341A4A40F31FD26F5FF944405CACA8C1341A4A40
46491	Золотовка	1	14	684	42.042099	42.069237000000001	52.313746999999999	52.294544999999999	0103000020E61000000100000005000000DF18028063054540A4198BA6B3254A40DF18028063054540EB1B98DC28284A402A560DC2DC084540EB1B98DC28284A402A560DC2DC084540A4198BA6B3254A40DF18028063054540A4198BA6B3254A40
13677	Жемчужный	1	14	684	41.914475000000003	41.932350999999997	52.257201999999999	52.236750999999998	0103000020E610000001000000050000003B014D840DF54440CC2555DB4D1E4A403B014D840DF544409F3BC1FEEB204A404AB20E4757F744409F3BC1FEEB204A404AB20E4757F74440CC2555DB4D1E4A403B014D840DF54440CC2555DB4D1E4A40
60699	Гавриловка	1	14	684	42.010693000000003	42.028129999999997	52.121383000000002	52.103734000000003	0103000020E61000000100000005000000E8A562635E014540DCBDDC27470D4A40E8A562635E0145402BA5677A890F4A40AB048BC3990345402BA5677A890F4A40AB048BC399034540DCBDDC27470D4A40E8A562635E014540DCBDDC27470D4A40
51185	Вишневка	1	14	684	41.874203000000001	41.901800000000001	51.975183000000001	51.964945999999998	0103000020E61000000100000005000000558847E2E5EF4440F833BC5983FB4940558847E2E5EF4440BE4EEACBD2FC494033C4B12E6EF34440BE4EEACBD2FC494033C4B12E6EF34440F833BC5983FB4940558847E2E5EF4440F833BC5983FB4940
12735	Большая Ржакса	1	14	684	42.199536999999999	42.254505000000002	52.146563	52.111876000000002	0103000020E61000000100000005000000C5ABAC6D8A194540899AE8F3510E4A40C5ABAC6D8A194540DEE68D93C2124A4091D5AD9E93204540DEE68D93C2124A4091D5AD9E93204540899AE8F3510E4A40C5ABAC6D8A194540899AE8F3510E4A40
46273	Богданово	1	14	684	42.278804999999998	42.299627999999998	52.243600000000001	52.213410000000003	0103000020E610000001000000050000000B7BDAE1AF234540D751D504511B4A400B7BDAE1AF2345401EA7E8482E1F4A40A27BD6355A2645401EA7E8482E1F4A40A27BD6355A264540D751D504511B4A400B7BDAE1AF234540D751D504511B4A40
46585	Афанасьевка	1	14	684	41.823008000000002	41.859991999999998	52.026631999999999	52.015791	0103000020E61000000100000005000000562C7E5358E944401B49827005024A40562C7E5358E94440778368AD68034A402B69C53714EE4440778368AD68034A402B69C53714EE44401B49827005024A40562C7E5358E944401B49827005024A40
13105	Алкаладка	1	14	684	42.114449	42.137867999999997	52.151890000000002	52.128908000000003	0103000020E61000000100000005000000AB07CC43A60E4540AD18AE0E80104A40AB07CC43A60E4540734BAB2171134A401C959BA8A5114540734BAB2171134A401C959BA8A5114540AD18AE0E80104A40AB07CC43A60E4540AD18AE0E80104A40
45569	Александровка 2-я	1	14	684	41.899644000000002	42.138596	52.183315	52.118408000000002	0103000020E610000001000000050000007505DB8827F34440DACA4BFE270F4A407505DB8827F34440E1EEACDD76174A409FAD8383BD114540E1EEACDD76174A409FAD8383BD114540DACA4BFE270F4A407505DB8827F34440DACA4BFE270F4A40
45444	Хитрово	1	14	128	41.856462000000001	41.917178999999997	52.490642999999999	52.458019999999998	0103000020E610000001000000050000002522FC8BA0ED4440FB743C66A03A4A402522FC8BA0ED44407381CB63CD3E4A40FBC9181F66F544407381CB63CD3E4A40FBC9181F66F54440FB743C66A03A4A402522FC8BA0ED4440FB743C66A03A4A40
22115	Тригуляй	1	14	128	41.506101000000001	41.536329000000002	52.666383000000003	52.648062000000003	0103000020E6100000010000000500000088BCE5EAC7C04440E3E313B2F3524A4088BCE5EAC7C0444021CEC3094C554A40BD72BD6DA6C4444021CEC3094C554A40BD72BD6DA6C44440E3E313B2F3524A4088BCE5EAC7C04440E3E313B2F3524A40
48818	Телешовка	1	14	128	42.234642999999998	42.252727	52.74736	52.736587	0103000020E610000001000000050000001F9E25C8081E454052D4997B485E4A401F9E25C8081E4540562B137EA95F4A4079E8BB5B59204540562B137EA95F4A4079E8BB5B5920454052D4997B485E4A401F9E25C8081E454052D4997B485E4A40
9886	Татарщино	1	14	128	42.001584999999999	42.024374999999999	52.838664000000001	52.828757000000003	0103000020E610000001000000050000000395F1EF3300454061AA99B5146A4A400395F1EF33004540912A8A57596B4A4085EB51B81E034540912A8A57596B4A4085EB51B81E03454061AA99B5146A4A400395F1EF3300454061AA99B5146A4A40
9802	Саюкино	1	14	128	41.954666000000003	41.997892	52.806378000000002	52.768337000000002	0103000020E61000000100000005000000344DD87E32FA444044A7E7DD58624A40344DD87E32FA4440611BF16437674A405378D0ECBAFF4440611BF16437674A405378D0ECBAFF444044A7E7DD58624A40344DD87E32FA444044A7E7DD58624A40
49437	Рождественское	1	14	128	42.167062999999999	42.187769000000003	52.790534000000001	52.759422000000001	0103000020E6100000010000000500000092AF04526215454074EE76BD34614A4092AF0452621545402330D63730654A40F01989D0081845402330D63730654A40F01989D00818454074EE76BD34614A4092AF04526215454074EE76BD34614A40
51248	Поселок Каменные Озерки	1	14	128	41.490713	42.353814	52.838664000000001	52.359485999999997	0103000020E610000001000000050000006C5CFFAECFBE444057AF22A3032E4A406C5CFFAECFBE4440912A8A57596B4A40F86EF3C6492D4540912A8A57596B4A40F86EF3C6492D454057AF22A3032E4A406C5CFFAECFBE444057AF22A3032E4A40
11051	Подоскляй	1	14	128	41.694234999999999	41.713090999999999	52.591442999999998	52.570889999999999	0103000020E61000000100000005000000895E46B1DCD8444085CE6BEC12494A40895E46B1DCD844405C397B67B44B4A403509DE9046DB44405C397B67B44B4A403509DE9046DB444085CE6BEC12494A40895E46B1DCD8444085CE6BEC12494A40
49537	Платоновка	1	14	128	41.941783999999998	41.985253	52.730708999999997	52.704689000000002	0103000020E61000000100000005000000B2F2CB608CF84440EC6CC83F335A4A40B2F2CB608CF8444049F25CDF875D4A4098A432C51CFE444049F25CDF875D4A4098A432C51CFE4440EC6CC83F335A4A40B2F2CB608CF84440EC6CC83F335A4A40
10491	Пичер	1	14	128	42.028013000000001	42.056876000000003	52.603651999999997	52.578885999999997	0103000020E61000000100000005000000726E13EE950345405E0EBBEF184A4A40726E13EE950345401E15FF77444D4A40B2F677B6470745401E15FF77444D4A40B2F677B6470745405E0EBBEF184A4A40726E13EE950345405E0EBBEF184A4A40
51172	Новогородовка	1	14	128	42.191766999999999	42.217126	52.659359000000002	52.609444000000003	0103000020E61000000100000005000000DCB930D28B184540295FD042024E4A40DCB930D28B18454061A92EE065544A403F8EE6C8CA1B454061A92EE065544A403F8EE6C8CA1B4540295FD042024E4A40DCB930D28B184540295FD042024E4A40
48518	Никольское	1	14	128	42.175713999999999	42.206868	52.718125999999998	52.683320999999999	0103000020E6100000010000000500000084B9DDCB7D164540C3D5011077574A4084B9DDCB7D1645402234828DEB5B4A40624B8FA67A1A45402234828DEB5B4A40624B8FA67A1A4540C3D5011077574A4084B9DDCB7D164540C3D5011077574A40
45497	Нижнеспасское	1	14	128	41.730184999999999	41.818264999999997	52.656410000000001	52.620455999999997	0103000020E61000000100000005000000CF83BBB376DD4440B14D2A1A6B4F4A40CF83BBB376DD444039622D3E05544A40103B53E8BCE8444039622D3E05544A40103B53E8BCE84440B14D2A1A6B4F4A40CF83BBB376DD4440B14D2A1A6B4F4A40
51220	Меховая Фабрика	1	14	128	41.810907999999998	41.822738999999999	52.681995000000001	52.677222999999998	0103000020E610000001000000050000004A0856D5CBE74440AC8C463EAF564A404A0856D5CBE744408C84B69C4B574A406612F5824FE944408C84B69C4B574A406612F5824FE94440AC8C463EAF564A404A0856D5CBE74440AC8C463EAF564A40
46757	Маяк	1	14	128	42.033942000000003	42.057791999999999	52.698151000000003	52.679456000000002	0103000020E61000000100000005000000FDFA2136580445401689096AF8564A40FDFA213658044540B95510035D594A4037FC6EBA65074540B95510035D594A4037FC6EBA650745401689096AF8564A40FDFA2136580445401689096AF8564A40
48434	Липовка	1	14	128	42.014969000000001	42.045746000000001	52.569772999999998	52.543427000000001	0103000020E6100000010000000500000017BA1281EA014540B76114048F454A4017BA1281EA01454068925852EE484A401FF64201DB05454068925852EE484A401FF64201DB054540B76114048F454A4017BA1281EA014540B76114048F454A40
11324	Котовское	1	14	128	41.762569999999997	41.789178	52.543526	52.514445000000002	0103000020E610000001000000050000009274CDE49BE144409D4B7155D9414A409274CDE49BE144404A438D4292454A40815CE2C803E544404A438D4292454A40815CE2C803E544409D4B7155D9414A409274CDE49BE144409D4B7155D9414A40
45621	Коптево	1	14	128	41.691971000000002	41.754385999999997	52.487198999999997	52.468927999999998	0103000020E61000000100000005000000E563778192D84440DF162CD5053C4A40E563778192D844406BD26D895C3E4A40B6476FB88FE044406BD26D895C3E4A40B6476FB88FE04440DF162CD5053C4A40E563778192D84440DF162CD5053C4A40
9892	Керша	1	14	128	42.030214000000001	42.059660999999998	52.821210000000001	52.785066	0103000020E61000000100000005000000D0F0660DDE034540CC99ED0A7D644A40D0F0660DDE034540F792C6681D694A405FECBDF8A2074540F792C6681D694A405FECBDF8A2074540CC99ED0A7D644A40D0F0660DDE034540CC99ED0A7D644A40
51221	Имени 2-й Пятилетки	1	14	128	42.034804000000001	42.067449000000003	52.450825999999999	52.418602	0103000020E610000001000000050000008FE21C7574044540250516C094354A408FE21C7574044540DF1797AAB4394A40EF92382BA2084540DF1797AAB4394A40EF92382BA2084540250516C094354A408FE21C7574044540250516C094354A40
60448	Ивановка	1	14	128	42.044119999999999	42.079872999999999	52.649028999999999	52.620373999999998	0103000020E61000000100000005000000BD8C62B9A5054540F4A44C6A684F4A40BD8C62B9A5054540EA93DC6113534A40AD6A4947390A4540EA93DC6113534A40AD6A4947390A4540F4A44C6A684F4A40BD8C62B9A5054540F4A44C6A684F4A40
46683	Зеленый	1	14	128	42.007621	42.023691999999997	52.719403	52.710565000000003	0103000020E61000000100000005000000A4E194B9F900454054573ECBF35A4A40A4E194B9F900454078D2C265155C4A40A296E6560803454078D2C265155C4A40A296E6560803454054573ECBF35A4A40A4E194B9F900454054573ECBF35A4A40
10201	Дмитриевщина	1	14	128	41.994506000000001	42.038936	52.751955000000002	52.722681000000001	0103000020E6100000010000000500000080D6FCF84BFF444065389ECF805C4A4080D6FCF84BFF44402788BA0F40604A408B51D7DAFB0445402788BA0F40604A408B51D7DAFB04454065389ECF805C4A4080D6FCF84BFF444065389ECF805C4A40
10688	Верхнеспасское	1	14	128	41.847181999999997	41.957154000000003	52.588625999999998	52.559969000000002	0103000020E6100000010000000500000043E1B37570EC44400DE36E10AD474A4043E1B37570EC4440A3C9C518584B4A40289EB30584FA4440A3C9C518584B4A40289EB30584FA44400DE36E10AD474A4043E1B37570EC44400DE36E10AD474A40
45405	Богословка	1	14	128	42.069128999999997	42.105600000000003	52.515388000000002	52.485658000000001	0103000020E61000000100000005000000431A1538D90845403885950A2A3E4A40431A1538D90845401C60E63BF8414A40933A014D840D45401C60E63BF8414A40933A014D840D45403885950A2A3E4A40431A1538D90845403885950A2A3E4A40
45573	Ахтырка	1	14	128	41.629179000000001	41.687947000000001	52.556108999999999	52.538716999999998	0103000020E610000001000000050000003D2AFEEF88D044404D66BCADF4444A403D2AFEEF88D04440710168942E474A40CF30B5A50ED84440710168942E474A40CF30B5A50ED844404D66BCADF4444A403D2AFEEF88D044404D66BCADF4444A40
60583	Алексеевка	1	14	128	41.956632999999997	41.982512999999997	52.570884999999997	52.559690000000003	0103000020E610000001000000050000001EA33CF372FA4440FAF202ECA3474A401EA33CF372FA444073637AC212494A408A7269FCC2FD444073637AC212494A408A7269FCC2FD4440FAF202ECA3474A401EA33CF372FA4440FAF202ECA3474A40
49411	Александровка	1	14	128	42.055097000000004	42.092278	52.533287999999999	52.520051000000002	0103000020E61000000100000005000000CA8D226B0D07454045A0FA0791424A40CA8D226B0D074540B4ACFBC742444A40F511F8C3CF0B4540B4ACFBC742444A40F511F8C3CF0B454045A0FA0791424A40CA8D226B0D07454045A0FA0791424A40
51171	Рассказово	1	14	7106	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
26643	Таракса	1	14	137	42.204047000000003	42.238273	53.343392999999999	53.324336000000002	0103000020E6100000010000000500000068EC4B361E1A45402E7590D783A94A4068EC4B361E1A45407156444DF4AB4A408942CBBA7F1E45407156444DF4AB4A408942CBBA7F1E45402E7590D783A94A4068EC4B361E1A45402E7590D783A94A40
49374	Рудовка	1	14	137	42.34395	42.444544	53.125247000000002	53.085734000000002	0103000020E61000000100000005000000C7BAB88D062C4540E013EB54F98A4A40C7BAB88D062C45400876FC1708904A4007D15AD1E63845400876FC1708904A4007D15AD1E6384540E013EB54F98A4A40C7BAB88D062C4540E013EB54F98A4A40
9645	Покрово-Васильево	1	14	137	42.233564999999999	42.259813999999999	53.192706000000001	53.176527999999998	0103000020E61000000100000005000000C03E3A75E51D4540056A317898964A40C03E3A75E51D45401ADF1797AA984A407F85CC95412145401ADF1797AA984A407F85CC9541214540056A317898964A40C03E3A75E51D4540056A317898964A40
49334	Подъем	1	14	137	42.297058	42.327708999999999	53.328826999999997	53.311957999999997	0103000020E61000000100000005000000F1811DFF05264540DFDC5F3DEEA74A40F1811DFF052645405985CD0017AA4A406CCD565EF22945405985CD0017AA4A406CCD565EF2294540DFDC5F3DEEA74A40F1811DFF05264540DFDC5F3DEEA74A40
9489	Пичаево	1	14	137	42.185586000000001	42.216650000000001	53.252107000000002	53.222444000000003	0103000020E61000000100000005000000384C3448C11745408198840B799C4A40384C3448C1174540DD0BCC0A45A04A40D656EC2FBB1B4540DD0BCC0A45A04A40D656EC2FBB1B45408198840B799C4A40384C3448C11745408198840B799C4A40
45387	Питим	1	14	137	42.335084000000002	42.391084999999997	53.223990999999998	53.202841999999997	0103000020E61000000100000005000000D9B45208E42A4540AB2006BAF6994A40D9B45208E42A454096CCB1BCAB9C4A40637AC2120F32454096CCB1BCAB9C4A40637AC2120F324540AB2006BAF6994A40D9B45208E42A4540AB2006BAF6994A40
9575	Отделение N3 совхоза Подъем	1	14	137	42.235684999999997	42.242629000000001	53.307848	53.300480999999998	0103000020E61000000100000005000000319413ED2A1E4540E108522976A64A40319413ED2A1E4540CB11329067A74A40D50792770E1F4540CB11329067A74A40D50792770E1F4540E108522976A64A40319413ED2A1E4540E108522976A64A40
49149	Октябрьский	1	14	137	41.982486000000002	42.001916999999999	53.270986000000001	53.262180999999998	0103000020E610000001000000050000009163EB19C2FD4440F850A2258FA14A409163EB19C2FD444041D653ABAFA24A403927F6D03E00454041D653ABAFA24A403927F6D03E004540F850A2258FA14A409163EB19C2FD4440F850A2258FA14A40
45460	Липовка	1	14	137	42.302466000000003	42.335397999999998	53.232196000000002	53.208300000000001	0103000020E610000001000000050000007313B534B7264540DFE00B93A99A4A407313B534B72645408A213999B89D4A4068925852EE2A45408A213999B89D4A4068925852EE2A4540DFE00B93A99A4A407313B534B7264540DFE00B93A99A4A40
46668	Коршуновка	1	14	137	42.061044000000003	42.076476999999997	53.124723000000003	53.103529999999999	0103000020E61000000100000005000000FBCE2F4AD0074540D3139678408D4A40FBCE2F4AD00745408E075BECF68F4A40B6F292FFC90945408E075BECF68F4A40B6F292FFC9094540D3139678408D4A40FBCE2F4AD0074540D3139678408D4A40
49232	Егоровка	1	14	137	42.161188000000003	42.182881999999999	53.303021000000001	53.274120000000003	0103000020E61000000100000005000000FB40F2CEA1144540FB96395D16A34A40FB40F2CEA114454028806264C9A64A40778368AD6817454028806264C9A64A40778368AD68174540FB96395D16A34A40FB40F2CEA1144540FB96395D16A34A40
9142	Вышенка	1	14	137	42.264512000000003	42.313910999999997	53.175928999999996	53.133372999999999	0103000020E6100000010000000500000025B37A87DB214540AF95D05D12914A4025B37A87DB21454080B56AD784964A40656D533C2E28454080B56AD784964A40656D533C2E284540AF95D05D12914A4025B37A87DB214540AF95D05D12914A40
8959	Волхонщина	1	14	137	42.084148999999996	42.113083000000003	53.255054000000001	53.241427999999999	0103000020E61000000100000005000000DC7EF964C50A45405A2BDA1CE79E4A40DC7EF964C50A4540645B069CA5A04A40E65DF580790E4540645B069CA5A04A40E65DF580790E45405A2BDA1CE79E4A40DC7EF964C50A45405A2BDA1CE79E4A40
49362	Васильево	1	14	137	42.215463999999997	42.235864999999997	53.203797000000002	53.191049999999997	0103000020E6100000010000000500000090BB0853941B45404DF38E5374984A4090BB0853941B4540EF022505169A4A40B1A206D3301E4540EF022505169A4A40B1A206D3301E45404DF38E5374984A4090BB0853941B45404DF38E5374984A40
9056	Большой Ломовис	1	14	137	42.042789999999997	42.055286000000002	53.188248999999999	53.161656999999998	0103000020E61000000100000005000000444C89247A054540B115342DB1944A40444C89247A0545409A40118B18984A409DF6949C130745409A40118B18984A409DF6949C13074540B115342DB1944A40444C89247A054540B115342DB1944A40
8872	Байловка 2-я	1	14	137	42.036501999999999	42.082962999999999	53.287816999999997	53.272753000000002	0103000020E610000001000000050000008A1EF818AC0445406571FF91E9A24A408A1EF818AC044540CD1DFD2FD7A44A4097E315889E0A4540CD1DFD2FD7A44A4097E315889E0A45406571FF91E9A24A408A1EF818AC0445406571FF91E9A24A40
9393	Бадин Угол	1	14	137	42.421061999999999	42.451011999999999	53.186210000000003	53.152802000000001	0103000020E610000001000000050000004FCB0F5CE5354540B76114048F934A404FCB0F5CE53545401618B2BAD5974A40410DDFC2BA3945401618B2BAD5974A40410DDFC2BA394540B76114048F934A404FCB0F5CE5354540B76114048F934A40
51194	2-е	1	14	137	42.002923000000003	42.015329000000001	53.152158999999997	53.127181	0103000020E61000000100000005000000FFB3E6C75F00454017D68D7747904A40FFB3E6C75F004540626534F279934A4017D7F84CF6014540626534F279934A4017D7F84CF601454017D68D7747904A40FFB3E6C75F00454017D68D7747904A40
48945	Яблоновец	1	14	800	40.429667999999999	40.499709000000003	52.475884000000001	52.443361000000003	0103000020E61000000100000005000000A1116C5CFF36444033A9A10DC0384A40A1116C5CFF364440475854C4E93C4A402942EA76F63F4440475854C4E93C4A402942EA76F63F444033A9A10DC0384A40A1116C5CFF36444033A9A10DC0384A40
51238	Шехмань	1	14	800	40.433439999999997	40.503832000000003	52.528894999999999	52.503017	0103000020E610000001000000050000009D6340F67A374440802A6EDC62404A409D6340F67A3744404B02D4D4B2434A40D25625917D4044404B02D4D4B2434A40D25625917D404440802A6EDC62404A409D6340F67A374440802A6EDC62404A40
48775	Чибизовка	1	14	800	40.393222999999999	40.406256999999997	52.693316000000003	52.678936999999998	0103000020E610000001000000050000007B849A2155324440AD855968E7564A407B849A215532444093E52494BE584A40B262B83A0034444093E52494BE584A40B262B83A00344440AD855968E7564A407B849A2155324440AD855968E7564A40
5652	Центральное отделение совхоза Плавица	1	14	800	40.352412000000001	40.377673000000001	52.440978000000001	52.418678999999997	0103000020E61000000100000005000000E65B1FD61B2D4440D042024697354A40E65B1FD61B2D4440B42094F771384A4086CABF9657304440B42094F771384A4086CABF9657304440D042024697354A40E65B1FD61B2D4440D042024697354A40
8424	Хренное	1	14	800	40.449672999999997	40.509115000000001	52.483969000000002	52.460434999999997	0103000020E61000000100000005000000757286E28E3944408577B988EF3A4A40757286E28E39444090A339B2F23D4A40977329AE2A41444090A339B2F23D4A40977329AE2A4144408577B988EF3A4A40757286E28E3944408577B988EF3A4A40
48995	Федоровка	1	14	800	40.721682999999999	40.742497	52.429437999999998	52.415779000000001	0103000020E61000000100000005000000228AC91B605C44408AAE0B3F38354A40228AC91B605C44406FD40AD3F7364A40663046240A5F44406FD40AD3F7364A40663046240A5F44408AAE0B3F38354A40228AC91B605C44408AAE0B3F38354A40
48809	Успеновка	1	14	800	40.192628999999997	40.216569	52.751012000000003	52.736815999999997	0103000020E610000001000000050000006EA12B11A8184440B39597FC4F5E4A406EA12B11A8184440A873452921604A40E9297288B81B4440A873452921604A40E9297288B81B4440B39597FC4F5E4A406EA12B11A8184440B39597FC4F5E4A40
48706	Тынково	1	14	800	40.289296999999998	40.325812999999997	52.541558999999999	52.519443000000003	0103000020E610000001000000050000005BEA20AF072544406D91B41B7D424A405BEA20AF072544405FED28CE51454A404ACE893DB42944405FED28CE51454A404ACE893DB42944406D91B41B7D424A405BEA20AF072544406D91B41B7D424A40
7907	Сестренка	1	14	800	40.324969000000003	40.346654000000001	52.752740000000003	52.737105	0103000020E610000001000000050000005F9B8D9598294440EA5BE674595E4A405F9B8D95982944400E32C9C859604A40888384285F2C44400E32C9C859604A40888384285F2C4440EA5BE674595E4A405F9B8D9598294440EA5BE674595E4A40
46798	Семеновка	1	14	800	40.257317	40.268554999999999	52.732289999999999	52.711640000000003	0103000020E6100000010000000500000038DA71C3EF2044404243FF04175B4A4038DA71C3EF2044400B98C0ADBB5D4A40B1169F02602244400B98C0ADBB5D4A40B1169F02602244404243FF04175B4A4038DA71C3EF2044404243FF04175B4A40
8498	Свинино	1	14	800	40.376963000000003	40.388075999999998	52.440792000000002	52.428938000000002	0103000020E61000000100000005000000AA66D652403044407E01BD70E7364A40AA66D65240304440522B4CDF6B384A40662E7079AC314440522B4CDF6B384A40662E7079AC3144407E01BD70E7364A40AA66D652403044407E01BD70E7364A40
48619	Покровское	1	14	800	40.194901999999999	40.225740999999999	52.670310000000001	52.654164000000002	0103000020E6100000010000000500000066F6798CF21844403B1C5DA5BB534A4066F6798CF21844404417D4B7CC554A40E42EC214E51C44404417D4B7CC554A40E42EC214E51C44403B1C5DA5BB534A4066F6798CF21844403B1C5DA5BB534A40
7824	Покрово-Чичерино	1	14	800	40.359392	40.384033000000002	52.652427000000003	52.635936000000001	0103000020E61000000100000005000000D6389B8E002E4440AE2CD15966514A40D6389B8E002E444082035ABA82534A40DACA4BFE2731444082035ABA82534A40DACA4BFE27314440AE2CD15966514A40D6389B8E002E4440AE2CD15966514A40
25453	Петровское	1	14	800	40.227753	40.266416999999997	52.649614	52.611434000000003	0103000020E610000001000000050000006F48A302271D4440CCD42478434E4A406F48A302271D44400A83328D26534A40990CC7F3192244400A83328D26534A40990CC7F319224440CCD42478434E4A406F48A302271D4440CCD42478434E4A40
49074	Песчаное	1	14	800	40.548461000000003	40.590448000000002	52.648088999999999	52.630214000000002	0103000020E61000000100000005000000D41055F8334644409DBD33DAAA504A40D41055F833464440DCF29194F4524A408BFED0CC934B4440DCF29194F4524A408BFED0CC934B44409DBD33DAAA504A40D41055F8334644409DBD33DAAA504A40
48659	Песковатка	1	14	800	40.190984999999998	40.230331	52.551937000000002	52.526429	0103000020E6100000010000000500000066834C32721844403F55850662434A4066834C3272184440E73922DFA5464A40A320787C7B1D4440E73922DFA5464A40A320787C7B1D44403F55850662434A4066834C32721844403F55850662434A40
60597	Озерки	1	14	800	40.465501000000003	40.481141000000001	52.588746	52.562860000000001	0103000020E61000000100000005000000AEA06989953B4440001DE6CB0B484A40AEA06989953B44404ED367075C4B4A40E3E13D07963D44404ED367075C4B4A40E3E13D07963D4440001DE6CB0B484A40AEA06989953B4440001DE6CB0B484A40
8121	Новоситовка	1	14	800	40.017358999999999	40.063181999999998	52.673783	52.651159999999997	0103000020E6100000010000000500000048A5D8D1380244404F3BFC3559534A4048A5D8D138024440E6CC76853E564A4012D9075916084440E6CC76853E564A4012D90759160844404F3BFC3559534A4048A5D8D1380244404F3BFC3559534A40
8049	Новое Гаритово	1	14	800	40.099212999999999	40.132162999999998	52.796802	52.764986	0103000020E61000000100000005000000452BF702B30C4440EDF2AD0FEB614A40452BF702B30C444096B1A19BFD654A40E15E99B7EA10444096B1A19BFD654A40E15E99B7EA104440EDF2AD0FEB614A40452BF702B30C4440EDF2AD0FEB614A40
51256	Нарышкино	1	14	800	40.140284000000001	40.161098000000003	52.769365999999998	52.753214	0103000020E6100000010000000500000077137CD3F4114440D671FC5069604A4077137CD3F4114440C153C8957A624A40BBB9F8DB9E144440C153C8957A624A40BBB9F8DB9E144440D671FC5069604A4077137CD3F4114440D671FC5069604A40
47229	Найденовка	1	14	800	40.764882999999998	40.810149000000003	52.389432999999997	52.374129000000003	0103000020E610000001000000050000001822A7AFE76144401BBE8575E32F4A401822A7AFE7614440D87DC7F0D8314A408DF161F6B2674440D87DC7F0D8314A408DF161F6B26744401BBE8575E32F4A401822A7AFE76144401BBE8575E32F4A40
8211	Малый Самовец	1	14	800	40.112651999999997	40.147964999999999	52.688600000000001	52.667323000000003	0103000020E610000001000000050000001CEA77616B0E44402F6F0ED76A554A401CEA77616B0E44404703780B24584A40F0F96184F01244404703780B24584A40F0F96184F01244402F6F0ED76A554A401CEA77616B0E44402F6F0ED76A554A40
48650	Крутое	1	14	800	40.249349000000002	40.275319000000003	52.563205000000004	52.542009	0103000020E61000000100000005000000292504ABEA1F44409F91088D60454A40292504ABEA1F4440CBF8F71917484A40D57B2AA73D234440CBF8F71917484A40D57B2AA73D2344409F91088D60454A40292504ABEA1F44409F91088D60454A40
60591	Красный	1	14	800	40.710076999999998	40.720191999999997	52.456983000000001	52.446116000000004	0103000020E6100000010000000500000026529ACDE35A4440761C3F541A394A4026529ACDE35A4440FBE93F6B7E3A4A40A06B5F402F5C4440FBE93F6B7E3A4A40A06B5F402F5C4440761C3F541A394A4026529ACDE35A4440761C3F541A394A40
48690	Красиловка	1	14	800	40.332667000000001	40.365977000000001	52.525229000000003	52.503351000000002	0103000020E61000000100000005000000AEBA0ED5942A444057B439CE6D404A40AEBA0ED5942A444095F430B43A434A404A0B9755D82E444095F430B43A434A404A0B9755D82E444057B439CE6D404A40AEBA0ED5942A444057B439CE6D404A40
47081	Калиновка	1	14	800	40.276639000000003	40.289341999999998	52.527306000000003	52.517420999999999	0103000020E610000001000000050000002AE620E868234440BEA1F0D93A424A402AE620E868234440077E54C37E434A40FBAD9D2809254440077E54C37E434A40FBAD9D2809254440BEA1F0D93A424A402AE620E868234440BEA1F0D93A424A40
45988	Знаменка	1	14	800	40.576228	40.610399999999998	52.489123999999997	52.463797999999997	0103000020E610000001000000050000000E85CFD6C1494440A0F99CBB5D3B4A400E85CFD6C149444027D87F9D9B3E4A403CBD5296214E444027D87F9D9B3E4A403CBD5296214E4440A0F99CBB5D3B4A400E85CFD6C1494440A0F99CBB5D3B4A40
48629	Дубовое	1	14	800	40.274124	40.319318000000003	52.613605	52.605342	0103000020E610000001000000050000003C86C77E162344409772BED87B4D4A403C86C77E16234440BFD4CF9B8A4E4A4017838769DF284440BFD4CF9B8A4E4A4017838769DF2844409772BED87B4D4A403C86C77E162344409772BED87B4D4A40
48990	Волчки	1	14	800	40.684024999999998	40.715277999999998	52.502392	52.486041999999998	0103000020E61000000100000005000000BD5296218E574440C03DCF9F363E4A40BD5296218E574440D2E28C614E404A402EC6C03A8E5B4440D2E28C614E404A402EC6C03A8E5B4440C03DCF9F363E4A40BD5296218E574440C03DCF9F363E4A40
8365	Большой Избердей	1	14	800	40.370271000000002	40.420118000000002	52.557254	52.528461999999998	0103000020E6100000010000000500000020D4450A652F4440E1968FA4A4434A4020D4450A652F444058C85C1954474A40003B376DC635444058C85C1954474A40003B376DC6354440E1968FA4A4434A4020D4450A652F4440E1968FA4A4434A40
48740	Большая Алексеевка	1	14	800	39.985235000000003	40.028129999999997	52.622118	52.601289999999999	0103000020E61000000100000005000000F2EF332E1CFE4340B7B41A12F74C4A40F2EF332E1CFE434060200890A14F4A40AB048BC39903444060200890A14F4A40AB048BC399034440B7B41A12F74C4A40F2EF332E1CFE4340B7B41A12F74C4A40
51241	Барановка	1	14	800	40.759286000000003	40.770318000000003	52.539363000000002	52.522643000000002	0103000020E61000000100000005000000C4279D4830614440DE3D40F7E5424A40C4279D483061444013D6C6D809454A4094C2BCC79962444013D6C6D809454A4094C2BCC799624440DE3D40F7E5424A40C4279D4830614440DE3D40F7E5424A40
48342	Чернышевка	1	14	814	40.171016000000002	40.192683000000002	53.163508999999998	53.151224999999997	0103000020E61000000100000005000000DF8B2FDAE315444036AB3E575B934A40DF8B2FDAE315444003CDE7DCED944A4062BF27D6A918444003CDE7DCED944A4062BF27D6A918444036AB3E575B934A40DF8B2FDAE315444036AB3E575B934A40
5801	Хоботово	1	14	814	40.365689000000003	40.402223999999997	53.088227000000003	53.042687000000001	0103000020E61000000100000005000000E4C0ABE5CE2E4440707B82C476854A40E4C0ABE5CE2E4440E6CFB7054B8B4A4049D576137C334440E6CFB7054B8B4A4049D576137C334440707B82C476854A40E4C0ABE5CE2E4440707B82C476854A40
7230	Хоботец-Васильевское	1	14	814	40.471294999999998	40.508710000000001	53.199092999999998	53.172123999999997	0103000020E6100000010000000500000058E20165533C4440A86DC32808964A4058E20165533C444067EE21E17B994A40F792C6681D41444067EE21E17B994A40F792C6681D414440A86DC32808964A4058E20165533C4440A86DC32808964A40
7026	Хобот-Богоявленское	1	14	814	40.518267999999999	40.552349999999997	53.196930000000002	53.165483999999999	0103000020E610000001000000050000001B48179B56424440710168942E954A401B48179B56424440F7CC920035994A4009F9A067B3464440F7CC920035994A4009F9A067B3464440710168942E954A401B48179B56424440710168942E954A40
48350	Фонвизино	1	14	814	40.299734999999998	40.314971	53.151646	53.147007000000002	0103000020E61000000100000005000000B83B6BB75D2644403CA41820D1924A40B83B6BB75D264440DC48D92269934A401E1840F850284440DC48D92269934A401E1840F8502844403CA41820D1924A40B83B6BB75D2644403CA41820D1924A40
7325	Старосеславино	1	14	814	40.383000000000003	40.442261999999999	53.220255000000002	53.182701999999999	0103000020E610000001000000050000001B2FDD2406314440F77475C762974A401B2FDD2406314440E7E3DA50319C4A40BC218D0A9C384440E7E3DA50319C4A40BC218D0A9C384440F77475C762974A401B2FDD2406314440F77475C762974A40
51195	Старокозьмодемьяновское	1	14	814	40.505116999999998	40.537438000000002	53.210580999999998	53.186279999999996	0103000020E61000000100000005000000AAD381ACA74044400EF3E505D8974A40AAD381ACA740444059147651F49A4A4057D0B4C4CA44444059147651F49A4A4057D0B4C4CA4444400EF3E505D8974A40AAD381ACA74044400EF3E505D8974A40
6565	Старокленское	1	14	814	40.147120000000001	40.195323999999999	53.221446	53.201666000000003	0103000020E61000000100000005000000344B02D4D41244408A5B0531D0994A40344B02D4D41244403EEAAF57589C4A40DC0F7860001944403EEAAF57589C4A40DC0F7860001944408A5B0531D0994A40344B02D4D41244408A5B0531D0994A40
48122	Первомайский	1	14	814	40.264476000000002	40.309491000000001	53.266134000000001	53.231425000000002	0103000020E61000000100000005000000D8497D59DA214440083D9B559F9D4A40D8497D59DA214440452DCDAD10A24A4003B4AD669D274440452DCDAD10A24A4003B4AD669D274440083D9B559F9D4A40D8497D59DA214440083D9B559F9D4A40
48235	Парижская Коммуна	1	14	814	40.276800999999999	40.303238999999998	53.310828999999998	53.295928000000004	0103000020E61000000100000005000000034015376E23444040FCFCF7E0A54A40034015376E234440FED2A23EC9A74A4095EF1989D0264440FED2A23EC9A74A4095EF1989D026444040FCFCF7E0A54A40034015376E23444040FCFCF7E0A54A40
47923	Озерки	1	14	814	40.106102999999997	40.126801	53.275875999999997	53.266570000000002	0103000020E61000000100000005000000F58079C8940D4440200C3CF71EA24A40F58079C8940D44402AE09EE74FA34A40D00CE2033B1044402AE09EE74FA34A40D00CE2033B104440200C3CF71EA24A40F58079C8940D4440200C3CF71EA24A40
48378	Новоспасское	1	14	814	40.312095999999997	40.327601000000001	53.133881000000002	53.117891999999998	0103000020E61000000100000005000000309B00C3F2274440E23AC615178F4A40309B00C3F227444024473A0323914A4086915ED4EE29444024473A0323914A4086915ED4EE294440E23AC615178F4A40309B00C3F2274440E23AC615178F4A40
7125	Новосеславино	1	14	814	40.415106000000002	40.466282999999997	53.342694000000002	53.308154999999999	0103000020E61000000100000005000000CB2F833122354440A88C7F9F71A74A40CB2F8331223544408944A165DDAB4A4023D74D29AF3B44408944A165DDAB4A4023D74D29AF3B4440A88C7F9F71A74A40CB2F833122354440A88C7F9F71A74A40
51181	Новокозьмодемьяновское	1	14	814	40.494346	40.526981999999997	53.230713000000002	53.211486999999998	0103000020E610000001000000050000004774CFBA463F4440BB438A01129B4A404774CFBA463F44408BE1EA00889D4A4053CA6B25744344408BE1EA00889D4A4053CA6B2574434440BB438A01129B4A404774CFBA463F4440BB438A01129B4A40
6502	Новокленское	1	14	814	40.226154000000001	40.250965999999998	53.211924000000003	53.186554999999998	0103000020E6100000010000000500000007EE409DF21C4440E0F3C308E1974A4007EE409DF21C4440679E5C53209B4A40373465A71F204440679E5C53209B4A40373465A71F204440E0F3C308E1974A4007EE409DF21C4440E0F3C308E1974A40
48227	Новоархангельское	1	14	814	40.225983999999997	40.267558000000001	53.304516999999997	53.264028000000003	0103000020E61000000100000005000000AAB5300BED1C4440399D64ABCBA14A40AAB5300BED1C4440BB09BE69FAA64A403FE42D573F224440BB09BE69FAA64A403FE42D573F224440399D64ABCBA14A40AAB5300BED1C4440399D64ABCBA14A40
6606	Малый Снежеток	1	14	814	40.108044	40.138064999999997	53.225242000000001	53.208052000000002	0103000020E61000000100000005000000B743C362D40D444007EFAB72A19A4A40B743C362D40D4440C3D7D7BAD49C4A4072DC291DAC114440C3D7D7BAD49C4A4072DC291DAC11444007EFAB72A19A4A40B743C362D40D444007EFAB72A19A4A40
6951	Иловай-Рождественское	1	14	814	40.346725999999997	40.376190999999999	53.157682999999999	53.122923	0103000020E6100000010000000500000021567F84612C44408E76DCF0BB8F4A4021567F84612C44404D11E0F42E944A405706D506273044404D11E0F42E944A405706D506273044408E76DCF0BB8F4A4021567F84612C44408E76DCF0BB8F4A40
6333	Иловай-Дмитриевское	1	14	814	40.296590999999999	40.355781	53.226115	53.177705000000003	0103000020E61000000100000005000000DBA4A2B1F6254440F8AA9509BF964A40DBA4A2B1F625444049111956F19C4A40E3C4573B8A2D444049111956F19C4A40E3C4573B8A2D4440F8AA9509BF964A40DBA4A2B1F6254440F8AA9509BF964A40
6882	Иванжитово	1	14	814	40.339117000000002	40.351092000000001	53.171843000000003	53.157645000000002	0103000020E610000001000000050000004242942F682B444060B01BB62D944A404242942F682B4440F58590F3FE954A4091F12895F02C4440F58590F3FE954A4091F12895F02C444060B01BB62D944A404242942F682B444060B01BB62D944A40
48313	Змеевка	1	14	814	40.138263000000002	40.169182999999997	53.271723999999999	53.254821999999997	0103000020E61000000100000005000000999F1B9AB21144409126DE019EA04A40999F1B9AB2114440E7C41EDAC7A24A400305DEC9A7154440E7C41EDAC7A24A400305DEC9A71544409126DE019EA04A40999F1B9AB21144409126DE019EA04A40
47191	Заводской	1	14	814	40.296959000000001	40.321744000000002	53.107444000000001	53.095954999999996	0103000020E610000001000000050000005EA0A4C0022644409F71E140488C4A405EA0A4C002264440621399B9C08D4A4095D74AE82E294440621399B9C08D4A4095D74AE82E2944409F71E140488C4A405EA0A4C0022644409F71E140488C4A40
60421	рп.Дмитриевка	1	14	753	40.568393999999998	41.118693	53.179696	52.549802	0103000020E610000001000000050000000E9F7422C148444040A374E95F464A400E9F7422C14844406B9C4D4700974A40CFA10C55318F44406B9C4D4700974A40CFA10C55318F444040A374E95F464A400E9F7422C148444040A374E95F464A40
46749	Ярославка	1	14	753	40.812151999999998	40.875807000000002	52.919840999999998	52.897058000000001	0103000020E61000000100000005000000C4B0C398F4674440BE4EEACBD2724A40C4B0C398F46744408D429259BD754A40CF4D9B711A7044408D429259BD754A40CF4D9B711A704440BE4EEACBD2724A40C4B0C398F4674440BE4EEACBD2724A40
5917	Юрловка	1	14	753	40.659232000000003	40.716275000000003	52.720750000000002	52.698112999999999	0103000020E61000000100000005000000043DD4B661544440CBF44BC45B594A40043DD4B661544440C74B3789415C4A40A1F831E6AE5B4440C74B3789415C4A40A1F831E6AE5B4440CBF44BC45B594A40043DD4B661544440CBF44BC45B594A40
47911	Чебоксары	1	14	753	40.946359999999999	40.978718000000001	52.877735999999999	52.869774	0103000020E610000001000000050000000C1F1153227944409F7422C1546F4A400C1F115322794440CC423BA759704A40D600A5A1467D4440CC423BA759704A40D600A5A1467D44409F7422C1546F4A400C1F1153227944409F7422C1546F4A40
5984	Туровка	1	14	753	40.664388000000002	40.712322	52.753290999999997	52.739766000000003	0103000020E610000001000000050000006CED7DAA0A554440AC58FCA6B05E4A406CED7DAA0A55444081AFE8D66B604A40541C075E2D5B444081AFE8D66B604A40541C075E2D5B4440AC58FCA6B05E4A406CED7DAA0A554440AC58FCA6B05E4A40
47706	Сычевка	1	14	753	40.783810000000003	40.809384999999999	52.951445	52.926127999999999	0103000020E610000001000000050000008E23D6E25364444077F4BF5C8B764A408E23D6E253644440AB7823F3C8794A40BD6F7CED99674440AB7823F3C8794A40BD6F7CED9967444077F4BF5C8B764A408E23D6E25364444077F4BF5C8B764A40
51243	Степановка	1	14	753	40.791454999999999	40.814163999999998	52.988804999999999	52.966346999999999	0103000020E61000000100000005000000BAA0BE654E6544403ACB2C42B17B4A40BAA0BE654E654440868F8829917E4A404FCAA48636684440868F8829917E4A404FCAA486366844403ACB2C42B17B4A40BAA0BE654E6544403ACB2C42B17B4A40
5431	Старое Сабурово	1	14	753	40.992749000000003	41.020246999999998	52.985850999999997	52.959685999999998	0103000020E6100000010000000500000080113466127F4440EB36A8FDD67A4A4080113466127F44404CDD955D307E4A40CA6B2574978244404CDD955D307E4A40CA6B257497824440EB36A8FDD67A4A4080113466127F4440EB36A8FDD67A4A40
47876	Свобода	1	14	753	40.970965	41.029518000000003	52.838909000000001	52.816388000000003	0103000020E61000000100000005000000C347C494487C4440666CE8667F684A40C347C494487C4440F8A8BF5E616B4A405952EE3EC7834440F8A8BF5E616B4A405952EE3EC7834440666CE8667F684A40C347C494487C4440666CE8667F684A40
5437	Сабуро-Покровское	1	14	753	41.002980999999998	41.042012999999997	52.855986000000001	52.831145999999997	0103000020E6100000010000000500000033C170AE61804440C119FCFD626A4A4033C170AE61804440BCEA01F3906D4A40E08096AE60854440BCEA01F3906D4A40E08096AE60854440C119FCFD626A4A4033C170AE61804440C119FCFD626A4A40
5711	Машково-Сурена	1	14	753	40.810310999999999	40.862178999999998	52.791193	52.768255000000003	0103000020E61000000100000005000000664B5645B867444087FE092E56624A40664B5645B86744407DE9EDCF45654A402426A8E15B6E44407DE9EDCF45654A402426A8E15B6E444087FE092E56624A40664B5645B867444087FE092E56624A40
5921	Любезная	1	14	753	40.830640000000002	40.854427000000001	52.690182999999998	52.681252000000001	0103000020E61000000100000005000000EE5F5969526A4440D42AFA4333574A40EE5F5969526A4440A9A0A2EA57584A40E2E82ADD5D6D4440A9A0A2EA57584A40E2E82ADD5D6D4440D42AFA4333574A40EE5F5969526A4440D42AFA4333574A40
47735	Екатеринино	1	14	753	40.819087000000003	40.862188000000003	53.010666999999998	52.966656	0103000020E6100000010000000500000015CAC2D7D7684440B83D4162BB7B4A4015CAC2D7D7684440BE1248895D814A407880272D5C6E4440BE1248895D814A407880272D5C6E4440B83D4162BB7B4A4015CAC2D7D7684440B83D4162BB7B4A40
48103	Дмитриевка	1	14	753	40.759089000000003	40.828240999999998	52.899014000000001	52.869436999999998	0103000020E610000001000000050000006EE00ED42961444057772CB6496F4A406EE00ED429614440B55208E412734A40691A14CD036A4440B55208E412734A40691A14CD036A444057772CB6496F4A406EE00ED42961444057772CB6496F4A40
51187	Дмитриевка	1	14	753	40.759089000000003	40.828240999999998	52.899014000000001	52.869436999999998	0103000020E610000001000000050000006EE00ED42961444057772CB6496F4A406EE00ED429614440B55208E412734A40691A14CD036A4440B55208E412734A40691A14CD036A444057772CB6496F4A406EE00ED42961444057772CB6496F4A40
5319	Гомзяки	1	14	753	40.880532000000002	40.890422000000001	53.092981000000002	53.081314999999996	0103000020E610000001000000050000006E8AC745B57044404DD6A887688A4A406E8AC745B57044401F1329CDE68B4A40C8D11C59F97144401F1329CDE68B4A40C8D11C59F97144404DD6A887688A4A406E8AC745B57044404DD6A887688A4A40
48071	Голицыно	1	14	753	40.645038999999997	40.675995	52.646051	52.631475999999999	0103000020E6100000010000000500000080D250A390524440BD1AA034D4504A4080D250A390524440284696CCB1524A4038A1100187564440284696CCB1524A4038A1100187564440BD1AA034D4504A4080D250A390524440BD1AA034D4504A40
47774	Вырубово	1	14	753	40.920865999999997	40.950240999999998	53.105189000000003	53.082234	0103000020E61000000100000005000000C9FFE4EFDE754440444FCAA4868A4A40C9FFE4EFDE754440117349D5768D4A40BF28417FA1794440117349D5768D4A40BF28417FA1794440444FCAA4868A4A40C9FFE4EFDE754440444FCAA4868A4A40
5671	Восточная Старинка	1	14	753	40.744680000000002	40.765448999999997	52.864570999999998	52.849634999999999	0103000020E610000001000000050000001EFE9AAC515F4440BB44F5D6C06C4A401EFE9AAC515F4440F6083543AA6E4A40C1E09A3BFA614440F6083543AA6E4A40C1E09A3BFA614440BB44F5D6C06C4A401EFE9AAC515F4440BB44F5D6C06C4A40
47830	Богородицкое	1	14	753	40.958289999999998	40.977370000000001	53.023131999999997	53.011670000000002	0103000020E61000000100000005000000BB0A293FA97A4440132C0E677E814A40BB0A293FA97A4440DBBE47FDF5824A40B70BCD751A7D4440DBBE47FDF5824A40B70BCD751A7D4440132C0E677E814A40BB0A293FA97A4440132C0E677E814A40
47568	Шапкино	1	14	558	42.359563000000001	42.426937000000002	51.726678999999997	51.689565999999999	0103000020E6100000010000000500000003ED0E29062E45407E37DDB243D8494003ED0E29062E454051D845D103DD4940E73922DFA536454051D845D103DD4940E73922DFA53645407E37DDB243D8494003ED0E29062E45407E37DDB243D84940
47250	Чащино	1	14	558	42.360982	42.413085000000002	51.829214999999998	51.808478000000001	0103000020E61000000100000005000000EB387EA8342E45408BC404357CE74940EB387EA8342E4540232D95B723EA4940EDBB22F8DF344540232D95B723EA4940EDBB22F8DF3445408BC404357CE74940EB387EA8342E45408BC404357CE74940
47475	Троицкое	1	14	558	42.589818999999999	42.608674999999998	51.915705000000003	51.900781000000002	0103000020E610000001000000050000009BC761307F4B4540D9EDB3CA4CF349409BC761307F4B454050E449D235F549404772F90FE94D454050E449D235F549404772F90FE94D4540D9EDB3CA4CF349409BC761307F4B4540D9EDB3CA4CF34940
6879	Степанищево	1	14	558	42.484527999999997	42.506760999999997	51.663584999999998	51.649951999999999	0103000020E6100000010000000500000086FF7403053E454022FC8BA031D3494086FF7403053E4540DE8E705AF0D44940B2F1608BDD404540DE8E705AF0D44940B2F1608BDD40454022FC8BA031D3494086FF7403053E454022FC8BA031D34940
47283	Прудки	1	14	558	42.30968	42.328814000000001	51.806835	51.790481999999997	0103000020E61000000100000005000000D61C2098A3274540D009A1832EE54940D61C2098A32745405322895E46E74940C53BC093162A45405322895E46E74940C53BC093162A4540D009A1832EE54940D61C2098A3274540D009A1832EE54940
47481	Покровка	1	14	558	42.660561999999999	42.681914999999996	51.871212999999997	51.853270999999999	0103000020E610000001000000050000007C7DAD4B8D54454007D0EFFB37ED49407C7DAD4B8D544540CE6C57E883EF49406FD39FFD48574540CE6C57E883EF49406FD39FFD4857454007D0EFFB37ED49407C7DAD4B8D54454007D0EFFB37ED4940
47326	Новосельцы	1	14	558	42.180861	42.193266999999999	51.751759999999997	51.740071999999998	0103000020E61000000100000005000000990F087426174540B857E6ADBADE4940990F0874261745407138F3AB39E04940B1321AF9BC1845407138F3AB39E04940B1321AF9BC184540B857E6ADBADE4940990F087426174540B857E6ADBADE4940
4048	Нижнее Чуево	1	14	558	42.374330999999998	42.436521999999997	51.912987999999999	51.873871000000001	0103000020E6100000010000000500000082700514EA2F45401FF64201DBEF494082700514EA2F4540FAD170CADCF4494004FEF0F3DF374540FAD170CADCF4494004FEF0F3DF3745401FF64201DBEF494082700514EA2F45401FF64201DBEF4940
3472	Мучкапский	1	14	558	42.413597000000003	42.509070000000001	51.874020999999999	51.829638000000003	0103000020E61000000100000005000000A35C1ABFF03445406AC2F69331EA4940A35C1ABFF034454034828DEBDFEF4940F7AFAC342941454034828DEBDFEF4940F7AFAC34294145406AC2F69331EA4940A35C1ABFF03445406AC2F69331EA4940
4436	Кулябовка	1	14	558	42.337176999999997	42.390286000000003	51.790917	51.771315000000001	0103000020E6100000010000000500000050FBAD9D282B454006F52D73BAE2494050FBAD9D282B4540DB6CACC43CE54940180B43E4F4314540DB6CACC43CE54940180B43E4F431454006F52D73BAE2494050FBAD9D282B454006F52D73BAE24940
47247	Коростелево	1	14	558	42.403768999999997	42.433647000000001	51.840206999999999	51.825614000000002	0103000020E61000000100000005000000BE11DDB3AE334540548F34B8ADE94940BE11DDB3AE334540656F29E78BEB49401781B1BE81374540656F29E78BEB49401781B1BE81374540548F34B8ADE94940BE11DDB3AE334540548F34B8ADE94940
47445	Владимировка	1	14	558	42.587529000000004	42.606994999999998	51.949294999999999	51.934776999999997	0103000020E61000000100000005000000CE397826344B4540C806D2C5A6F74940CE397826344B4540CFA0A17F82F94940F2EA1C03B24D4540CFA0A17F82F94940F2EA1C03B24D4540C806D2C5A6F74940CE397826344B4540C806D2C5A6F74940
47540	Варварино	1	14	558	42.426892000000002	42.454093	51.741410000000002	51.725402000000003	0103000020E610000001000000050000004776A565A4364540FC3905F9D9DC49404776A565A4364540B476DB85E6DE4940D82B2CB81F3A4540B476DB85E6DE4940D82B2CB81F3A4540FC3905F9D9DC49404776A565A4364540FC3905F9D9DC4940
51211	Березовка 1-я	1	14	558	42.418097000000003	42.457200999999998	51.799194	51.784002999999998	0103000020E6100000010000000500000022C7D63384354540A27BD6355AE4494022C7D6338435454068942EFD4BE649406859F78F853A454068942EFD4BE649406859F78F853A4540A27BD6355AE4494022C7D63384354540A27BD6355AE44940
4091	Арбеньевка	1	14	558	42.684061999999997	42.702711000000001	52.065919000000001	52.054240999999998	0103000020E61000000100000005000000DA37F7578F574540198D7C5EF1064A40DA37F7578F574540AF97A60870084A400DC51D6FF2594540AF97A60870084A400DC51D6FF2594540198D7C5EF1064A40DA37F7578F574540198D7C5EF1064A40
47304	Андриановка	1	14	558	42.276288999999998	42.307640999999997	51.759146999999999	51.734695000000002	0103000020E610000001000000050000004D9F1D705D23454072C45A7C0ADE49404D9F1D705D234540A2ED98BA2BE1494051F4C0C760274540A2ED98BA2BE1494051F4C0C76027454072C45A7C0ADE49404D9F1D705D23454072C45A7C0ADE4940
47764	Андреевка	1	14	558	42.178077000000002	42.187562999999997	51.734845999999997	51.725864999999999	0103000020E61000000100000005000000BC95253ACB164540D027F224E9DC4940BC95253ACB16454057CC086F0FDE494046787B100218454057CC086F0FDE494046787B1002184540D027F224E9DC4940BC95253ACB164540D027F224E9DC4940
46287	Центральный	1	14	127	41.543559999999999	41.577022999999997	53.514015999999998	53.506309999999999	0103000020E61000000100000005000000F6B4C35F93C54440A2D11DC4CEC04A40F6B4C35F93C5444074CFBA46CBC14A401805C1E3DBC9444074CFBA46CBC14A401805C1E3DBC94440A2D11DC4CEC04A40F6B4C35F93C54440A2D11DC4CEC04A40
46422	Хлыстово	1	14	127	41.640588000000001	41.660009000000002	53.609675000000003	53.583463000000002	0103000020E61000000100000005000000E31A9FC9FED1444089B663EAAECA4A40E31A9FC9FED144402B1895D409CE4A406808C72C7BD444402B1895D409CE4A406808C72C7BD4444089B663EAAECA4A40E31A9FC9FED1444089B663EAAECA4A40
1815	Устьи	1	14	127	41.805069000000003	41.862876	53.492389000000003	53.461441000000001	0103000020E61000000100000005000000000341800CE744404B04AA7F10BB4A40000341800CE7444080F44D9A06BF4A406C4084B872EE444080F44D9A06BF4A406C4084B872EE44404B04AA7F10BB4A40000341800CE744404B04AA7F10BB4A40
1697	Старотомниково	1	14	127	41.878380999999997	41.906542999999999	53.771875999999999	53.722782000000002	0103000020E61000000100000005000000C136E2C96EF044409911DE1E84DC4A40C136E2C96EF044409D4830D5CCE24A4078B5DC9909F444409D4830D5CCE24A4078B5DC9909F444409911DE1E84DC4A40C136E2C96EF044409911DE1E84DC4A40
51228	Совхоз Базевский	1	14	127	41.65249	41.668148000000002	53.466875999999999	53.455908000000001	0103000020E61000000100000005000000C87BD5CA84D344400DFE7E315BBA4A40C87BD5CA84D34440C6A4BF97C2BB4A40A471A8DF85D54440C6A4BF97C2BB4A40A471A8DF85D544400DFE7E315BBA4A40C87BD5CA84D344400DFE7E315BBA4A40
1638	Серповое	1	14	127	41.810495000000003	41.871985000000002	53.630583999999999	53.607441999999999	0103000020E610000001000000050000002849D74CBEE74440C11BD2A8C0CD4A402849D74CBEE74440C0B0FCF9B6D04A4021CD58349DEF4440C0B0FCF9B6D04A4021CD58349DEF4440C11BD2A8C0CD4A402849D74CBEE74440C11BD2A8C0CD4A40
32359	Рысли	1	14	127	41.773215	41.791063999999999	53.710541999999997	53.676254999999998	0103000020E6100000010000000500000069E388B5F8E24440D4601A868FD64A4069E388B5F8E244409B374E0AF3DA4A407F85CC9541E544409B374E0AF3DA4A407F85CC9541E54440D4601A868FD64A4069E388B5F8E24440D4601A868FD64A40
45767	Рыбное	1	14	127	41.667492000000003	41.698627999999999	53.662998999999999	53.641257000000003	0103000020E61000000100000005000000BB2BBB6070D5444061AA99B514D24A40BB2BBB6070D54440EE23B726DDD44A40F2086EA46CD94440EE23B726DDD44A40F2086EA46CD9444061AA99B514D24A40BB2BBB6070D5444061AA99B514D24A40
1984	Ракша	1	14	127	41.593362999999997	41.643901999999997	53.583105000000003	53.533029999999997	0103000020E6100000010000000500000006D49B51F3CB4440B8E4B8533AC44A4006D49B51F3CB44402A91442FA3CA4A401CEA77616BD244402A91442FA3CA4A401CEA77616BD24440B8E4B8533AC44A4006D49B51F3CB4440B8E4B8533AC44A40
46537	Раево	1	14	127	42.041829	42.064915999999997	53.744743	53.720432000000002	0103000020E610000001000000050000001F8315A75A054540F67EA31D37DC4A401F8315A75A054540647616BD53DF4A405A7EE02A4F084540647616BD53DF4A405A7EE02A4F084540F67EA31D37DC4A401F8315A75A054540F67EA31D37DC4A40
45914	Пригородный	1	14	127	41.762058000000003	41.791738000000002	53.414549000000001	53.396597999999997	0103000020E61000000100000005000000DDD3D51D8BE144405AD427B9C3B24A40DDD3D51D8BE1444075CB0EF10FB54A400F80B8AB57E5444075CB0EF10FB54A400F80B8AB57E544405AD427B9C3B24A40DDD3D51D8BE144405AD427B9C3B24A40
45814	Погореловка	1	14	127	41.438915999999999	41.523223000000002	53.693308999999999	53.536839999999998	0103000020E6100000010000000500000077D844662EB84440A297512CB7C44A4077D844662EB84440E0826C59BED84A40ECC1A4F8F8C24440E0826C59BED84A40ECC1A4F8F8C24440A297512CB7C44A4077D844662EB84440A297512CB7C44A40
694	Питерское	1	14	127	41.735207000000003	41.780481999999999	53.380260999999997	53.345640000000003	0103000020E61000000100000005000000286552431BDE4440401878EE3DAC4A40286552431BDE4440DD787764ACB04A40EF8E8CD5E6E34440DD787764ACB04A40EF8E8CD5E6E34440401878EE3DAC4A40286552431BDE4440401878EE3DAC4A40
40376	Петровка	1	14	127	41.416322999999998	41.440443000000002	53.542042000000002	53.514744	0103000020E610000001000000050000004BC972124AB54440F7E7A221E3C14A404BC972124AB544407B87DBA161C54A404660AC6F60B844407B87DBA161C54A404660AC6F60B84440F7E7A221E3C14A404BC972124AB54440F7E7A221E3C14A40
46478	Пеньки	1	14	127	41.783895999999999	41.835675000000002	53.628779000000002	53.608446000000001	0103000020E610000001000000050000008CBB41B456E44440E6B0FB8EE1CD4A408CBB41B456E44440AFB48CD47BD04A40DB8AFD65F7EA4440AFB48CD47BD04A40DB8AFD65F7EA4440E6B0FB8EE1CD4A408CBB41B456E44440E6B0FB8EE1CD4A40
262	Парский Угол	1	14	127	41.243639999999999	41.287145000000002	53.511285000000001	53.45091	0103000020E61000000100000005000000ACFF73982F9F44403DB83B6BB7B94A40ACFF73982F9F4440BAF770C971C14A40DF1AD82AC1A44440BAF770C971C14A40DF1AD82AC1A444403DB83B6BB7B94A40ACFF73982F9F44403DB83B6BB7B94A40
1298	Носины	1	14	127	41.777912999999998	41.814959999999999	53.802090999999997	53.783969999999997	0103000020E610000001000000050000000E1137A792E34440C685032159E44A400E1137A792E344403DB5FAEAAAE64A402AC6F99B50E844403DB5FAEAAAE64A402AC6F99B50E84440C685032159E44A400E1137A792E34440C685032159E44A40
1248	Новотомниково	1	14	127	41.766612000000002	41.811546	53.785943000000003	53.766430999999997	0103000020E610000001000000050000004F5C8E5720E24440FED137691AE24A404F5C8E5720E2444094C2BCC799E44A408D9944BDE0E7444094C2BCC799E44A408D9944BDE0E74440FED137691AE24A404F5C8E5720E24440FED137691AE24A40
45973	Новоалександровка	1	14	127	41.492607999999997	41.536400999999998	53.517811999999999	53.494638999999999	0103000020E61000000100000005000000BDDF68C70DBF4440BF29AC5450BF4A40BDDF68C70DBF4440F9BCE2A947C24A405645B8C9A8C44440F9BCE2A947C24A405645B8C9A8C44440BF29AC5450BF4A40BDDF68C70DBF4440BF29AC5450BF4A40
32492	Мутасьево	1	14	127	41.846580000000003	41.869540999999998	53.561101999999998	53.544561999999999	0103000020E610000001000000050000004EB9C2BB5CEC44407A522635B4C54A404EB9C2BB5CEC44402FDCB930D2C74A40FCC3961E4DEF44402FDCB930D2C74A40FCC3961E4DEF44407A522635B4C54A404EB9C2BB5CEC44407A522635B4C54A40
51250	Молодежный	1	14	127	41.182392999999998	42.319102999999998	53.823213000000003	53.187396999999997	0103000020E61000000100000005000000790261A7589744402B2FF99FFC974A40790261A7589744402F52280B5FE94A401A87FA5DD82845402F52280B5FE94A401A87FA5DD82845402B2FF99FFC974A40790261A7589744402B2FF99FFC974A40
46697	Марусино	1	14	127	41.932962000000003	41.971778	53.396205999999999	53.377952000000001	0103000020E6100000010000000500000094347F4C6BF7444099BA2BBB60B04A4094347F4C6BF744404F3DD2E0B6B24A40747CB43863FC44404F3DD2E0B6B24A40747CB43863FC444099BA2BBB60B04A4094347F4C6BF7444099BA2BBB60B04A40
1002	Малые Кулики	1	14	127	41.491996999999998	41.571193000000001	53.468049999999998	53.438226	0103000020E61000000100000005000000745DF8C1F9BE4440E22021CA17B84A40745DF8C1F9BE44404772F90FE9BB4A40215A2BDA1CC944404772F90FE9BB4A40215A2BDA1CC94440E22021CA17B84A40745DF8C1F9BE4440E22021CA17B84A40
392	Маломоршевка	1	14	127	42.233286999999997	42.265158999999997	53.448920999999999	53.435581999999997	0103000020E610000001000000050000007DCA3159DC1D4540F65CA626C1B74A407DCA3159DC1D45406ABE4A3E76B94A40BA9EE8BAF02145406ABE4A3E76B94A40BA9EE8BAF0214540F65CA626C1B74A407DCA3159DC1D4540F65CA626C1B74A40
46329	Левино	1	14	127	41.749274999999997	41.784641000000001	53.299044000000002	53.279089999999997	0103000020E61000000100000005000000EE5A423EE8DF444000529B38B9A34A40EE5A423EE8DF44405308E41247A64A40E50CC51D6FE444405308E41247A64A40E50CC51D6FE4444000529B38B9A34A40EE5A423EE8DF444000529B38B9A34A40
46194	Крюково	1	14	127	41.740929000000001	41.793219999999998	53.401473000000003	53.379708000000001	0103000020E6100000010000000500000039D4EFC2D6DE4440C90391459AB04A4039D4EFC2D6DE44400F9D9E7763B34A403D44A33B88E544400F9D9E7763B34A403D44A33B88E54440C90391459AB04A4039D4EFC2D6DE4440C90391459AB04A40
49176	Коршуновка	1	14	127	41.836931999999997	41.869244999999999	53.468935000000002	53.442768999999998	0103000020E61000000100000005000000E97C789620EB4440605793A7ACB84A40E97C789620EB44409279E40F06BC4A40139B8F6B43EF44409279E40F06BC4A40139B8F6B43EF4440605793A7ACB84A40E97C789620EB4440605793A7ACB84A40
49479	Княжево	1	14	127	41.780895000000001	41.806443000000002	53.759895	53.742345999999998	0103000020E61000000100000005000000124E0B5EF4E344408028983105DF4A40124E0B5EF4E344406CB2463D44E14A40488B338639E744406CB2463D44E14A40488B338639E744408028983105DF4A40124E0B5EF4E344408028983105DF4A40
1133	Кершинские Борки	1	14	127	41.713459	41.759956000000003	53.287945999999998	53.259951000000001	0103000020E61000000100000005000000B804E09F52DB444000C8091346A14A40B804E09F52DB4440CB811E6ADBA44A401233FB3C46E14440CB811E6ADBA44A401233FB3C46E1444000C8091346A14A40B804E09F52DB444000C8091346A14A40
774	Карели	1	14	127	41.824553999999999	41.880203999999999	53.519674999999999	53.489618999999998	0103000020E610000001000000050000009BE447FC8AE944400740DCD5ABBE4A409BE447FC8AE944403FC6DCB584C24A4079E75086AAF044403FC6DCB584C24A4079E75086AAF044400740DCD5ABBE4A409BE447FC8AE944400740DCD5ABBE4A40
653	Ивенье	1	14	127	41.746634	41.795250000000003	53.347988999999998	53.304952999999998	0103000020E61000000100000005000000740AF2B391DF444096E82CB308A74A40740AF2B391DF4440122F4FE78AAC4A406F1283C0CAE54440122F4FE78AAC4A406F1283C0CAE5444096E82CB308A74A40740AF2B391DF444096E82CB308A74A40
51255	Зеленый Луг	1	14	127	41.893884999999997	41.906596999999998	53.674298	53.671598000000003	0103000020E6100000010000000500000046B1DCD26AF244408E075BECF6D54A4046B1DCD26AF244400DE198654FD64A406BD3D85E0BF444400DE198654FD64A406BD3D85E0BF444408E075BECF6D54A4046B1DCD26AF244408E075BECF6D54A40
51180	Зеленый Бор	1	14	127	41.854619999999997	41.884228999999998	53.684286999999998	53.671652000000002	0103000020E61000000100000005000000F6402B3064ED4440812557B1F8D54A40F6402B3064ED4440FA0967B796D74A405F96766A2EF14440FA0967B796D74A405F96766A2EF14440812557B1F8D54A40F6402B3064ED4440812557B1F8D54A40
51197	Дьячи	1	14	127	41.452364000000003	41.481746999999999	53.724625000000003	53.713425000000001	0103000020E61000000100000005000000A2F14410E7B944400C93A98251DB4A40A2F14410E7B94440986E1283C0DC4A401AF9BCE2A9BD4440986E1283C0DC4A401AF9BCE2A9BD44400C93A98251DB4A40A2F14410E7B944400C93A98251DB4A40
46437	Давыдово	1	14	127	41.739249000000001	41.781928000000001	53.641246000000002	53.620944999999999	0103000020E61000000100000005000000E44C13B69FDE4440AFCE31207BCF4A40E44C13B69FDE44406D58535914D24A40D1E9793716E444406D58535914D24A40D1E9793716E44440AFCE31207BCF4A40E44C13B69FDE4440AFCE31207BCF4A40
46006	Вяжли	1	14	127	42.041721000000003	42.063577000000002	53.418370000000003	53.403615000000002	0103000020E6100000010000000500000039471D1D57054540689604A8A9B34A4039471D1D5705454053D0ED258DB54A408FE3874A2308454053D0ED258DB54A408FE3874A23084540689604A8A9B34A4039471D1D57054540689604A8A9B34A40
45952	Веселое	1	14	127	41.411706000000002	41.493685999999997	53.492384000000001	53.459296000000002	0103000020E6100000010000000500000093C83EC8B2B4444081971936CABA4A4093C83EC8B2B444406E895C7006BF4A401C3F541A31BF44406E895C7006BF4A401C3F541A31BF444081971936CABA4A4093C83EC8B2B4444081971936CABA4A40
45926	Ваново	1	14	127	41.594208000000002	41.625737999999998	53.780904999999997	53.745344000000003	0103000020E61000000100000005000000C382FB010FCC44408A22A46E67DF4A40C382FB010FCC44403524EEB1F4E34A40A6EECA2E18D044403524EEB1F4E34A40A6EECA2E18D044408A22A46E67DF4A40C382FB010FCC44408A22A46E67DF4A40
46236	Быковка	1	14	127	41.501322000000002	41.538907000000002	53.407522999999998	53.373578999999999	0103000020E61000000100000005000000F661BD512BC0444077BCC96FD1AF4A40F661BD512BC0444014AFB2B629B44A40F14A92E7FAC4444014AFB2B629B44A40F14A92E7FAC4444077BCC96FD1AF4A40F661BD512BC0444077BCC96FD1AF4A40
32451	Алкужинские Борки	1	14	127	41.831524000000002	41.858823999999998	53.610145000000003	53.587519999999998	0103000020E6100000010000000500000068EBE0606FEA44407ADFF8DA33CB4A4068EBE0606FEA4440B2683A3B19CE4A408C82E0F1EDED4440B2683A3B19CE4A408C82E0F1EDED44407ADFF8DA33CB4A4068EBE0606FEA44407ADFF8DA33CB4A40
32361	Алкужи	1	14	127	41.841369999999998	41.871184999999997	53.586435000000002	53.568621	0103000020E61000000100000005000000F2EA1C03B2EB4440CF68AB92C8C84A40F2EA1C03B2EB4440691D554D10CB4A4004E275FD82EF4440691D554D10CB4A4004E275FD82EF4440CF68AB92C8C84A40F2EA1C03B2EB4440CF68AB92C8C84A40
32108	Алгасово	1	14	127	41.633662000000001	41.724229999999999	53.700986	53.663905999999997	0103000020E61000000100000005000000E65B1FD61BD1444020CF2EDFFAD44A40E65B1FD61BD14440187AC4E8B9D94A401B649291B3DC4440187AC4E8B9D94A401B649291B3DC444020CF2EDFFAD44A40E65B1FD61BD1444020CF2EDFFAD44A40
45711	Шульгино	1	14	217	40.808765999999999	40.856825000000001	52.226933000000002	52.190961999999999	0103000020E61000000100000005000000F10EF0A485674440AE635C7171184A40F10EF0A4856744400CB1FA230C1D4A4096B20C71AC6D44400CB1FA230C1D4A4096B20C71AC6D4440AE635C7171184A40F10EF0A485674440AE635C7171184A40
1758	Шмаровка	1	14	217	40.613553000000003	40.647644	52.035142	52.020929000000002	0103000020E610000001000000050000006DAE9AE7884E4440DD442DCDAD024A406DAE9AE7884E4440A75B76887F044A40AEB9A3FFE5524440A75B76887F044A40AEB9A3FFE5524440DD442DCDAD024A406DAE9AE7884E4440DD442DCDAD024A40
1059	Центральное отделение совхоза имени Ленина	1	14	217	40.838876999999997	40.854202000000001	52.194676999999999	52.184359000000001	0103000020E61000000100000005000000EC2E5052606B444094DC611399174A40EC2E5052606B444046240A2DEB184A40C216BB7D566D444046240A2DEB184A40C216BB7D566D444094DC611399174A40EC2E5052606B444094DC611399174A40
827	Хоперка	1	14	217	40.854616	40.873947000000001	52.297199999999997	52.280127999999998	0103000020E61000000100000005000000B5519D0E646D4440D158FB3BDB234A40B5519D0E646D4440832F4CA60A264A40FAB7CB7EDD6F4440832F4CA60A264A40FAB7CB7EDD6F4440D158FB3BDB234A40B5519D0E646D4440D158FB3BDB234A40
46307	Плоское	1	14	217	40.568618999999998	40.578302999999998	52.337299000000002	52.328136000000001	0103000020E610000001000000050000002E71E481C8484440F451465C002A4A402E71E481C84844409CFC169D2C2B4A40DF162CD5054A44409CFC169D2C2B4A40DF162CD5054A4440F451465C002A4A402E71E481C8484440F451465C002A4A40
40479	Отрада	1	14	217	40.789236000000002	40.816042000000003	51.971626999999998	51.959091999999998	0103000020E61000000100000005000000B6696CAF0565444078EDD286C3FA4940B6696CAF056544408E7406465EFC4940CB147310746844408E7406465EFC4940CB1473107468444078EDD286C3FA4940B6696CAF0565444078EDD286C3FA4940
45577	Новопокровка	1	14	217	40.843530000000001	40.922133000000002	52.166139000000001	52.120122000000002	0103000020E61000000100000005000000F29881CAF86B4440DBC35E28600F4A40F29881CAF86B44408ACBF10A44154A40FCC74274087644408ACBF10A44154A40FCC7427408764440DBC35E28600F4A40F29881CAF86B4440DBC35E28600F4A40
51164	Николо-Сергеевка	1	14	217	40.677782000000001	40.708351999999998	51.963970000000003	51.950150000000001	0103000020E61000000100000005000000A3E8818FC1564440AF25E4839EF94940A3E8818FC15644409E29745E63FB494031074147AB5A44409E29745E63FB494031074147AB5A4440AF25E4839EF94940A3E8818FC1564440AF25E4839EF94940
1250	Мордово	1	14	217	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
49579	Лаврово	1	14	217	40.926616000000003	40.962656000000003	52.347648	52.335742000000003	0103000020E61000000100000005000000A5F9635A9B76444063F20698F92A4A40A5F9635A9B7644408942CBBA7F2C4A402BA6D24F387B44408942CBBA7F2C4A402BA6D24F387B444063F20698F92A4A40A5F9635A9B76444063F20698F92A4A40
45677	Лавровка	1	14	217	40.759062	40.788660999999998	52.249797999999998	52.234754000000002	0103000020E6100000010000000500000074D190F128614440774D486B0C1E4A4074D190F128614440984D8061F91F4A40B950F9D7F2644440984D8061F91F4A40B950F9D7F2644440774D486B0C1E4A4074D190F128614440774D486B0C1E4A40
3585	Кужное	1	14	217	40.545307999999999	40.575572000000001	52.010947000000002	51.985030000000002	0103000020E61000000100000005000000A31F0DA7CC45444019CA897615FE4940A31F0DA7CC454440A27E17B666014A40253FE257AC494440A27E17B666014A40253FE257AC49444019CA897615FE4940A31F0DA7CC45444019CA897615FE4940
3013	Карпели	1	14	217	40.791536000000001	40.833820000000003	52.030327999999997	52.018811999999997	0103000020E61000000100000005000000A7CD380D51654440DC627E6E68024A40A7CD380D516544409813B4C9E1034A4018601F9DBA6A44409813B4C9E1034A4018601F9DBA6A4440DC627E6E68024A40A7CD380D51654440DC627E6E68024A40
49543	Борисовка	1	14	217	40.731537000000003	40.756717000000002	52.028737	52.011778	0103000020E6100000010000000500000030682101A35D4440F96706F181014A4030682101A35D4440B3976DA7AD034A40E3A9471ADC604440B3976DA7AD034A40E3A9471ADC604440F96706F181014A4030682101A35D4440F96706F181014A40
2781	Большая Даниловка	1	14	217	40.931942999999997	40.944806	52.055415000000004	52.036543999999999	0103000020E61000000100000005000000395E81E849774440B96E4A79AD044A40395E81E8497744409B5AB6D617074A4044882B67EF7844409B5AB6D617074A4044882B67EF784440B96E4A79AD044A40395E81E849774440B96E4A79AD044A40
45503	Ахматово	1	14	217	40.992623999999999	41.020848999999998	52.143788000000001	52.128504	0103000020E61000000100000005000000C39CA04D0E7F4440DDB3AED172104A40C39CA04D0E7F444054C72AA567124A40C093162EAB82444054C72AA567124A40C093162EAB824440DDB3AED172104A40C39CA04D0E7F4440DDB3AED172104A40
48438	Ярок	1	14	1811	40.084812999999997	40.143391999999999	52.871149000000003	52.853538999999998	0103000020E6100000010000000500000048A30227DB0A4440266E15C4406D4A4048A30227DB0A4440B87878CF816F4A40074147AB5A124440B87878CF816F4A40074147AB5A124440266E15C4406D4A4048A30227DB0A4440266E15C4406D4A40
48803	Центральное отделение совхоза имени Мичурина	1	14	1811	40.530638000000003	40.541938999999999	52.938682999999997	52.929161999999998	0103000020E61000000100000005000000E7012CF2EB434440CD57C9C7EE764A40E7012CF2EB434440D427B9C326784A40A6B6D4415E454440D427B9C326784A40A6B6D4415E454440CD57C9C7EE764A40E7012CF2EB434440CD57C9C7EE764A40
48332	Устье	1	14	1811	40.426991000000001	40.488731999999999	52.838048999999998	52.812350000000002	0103000020E61000000100000005000000DA571EA4A7364440EB73B515FB674A40DA571EA4A736444006B98B30456B4A401C412AC58E3E444006B98B30456B4A401C412AC58E3E4440EB73B515FB674A40DA571EA4A7364440EB73B515FB674A40
28510	Турмасово	1	14	1811	40.536594000000001	40.563085000000001	52.956301000000003	52.936169999999997	0103000020E610000001000000050000006B9DB81CAF44444087BF266BD4774A406B9DB81CAF444440E9103812687A4A4020EF552B13484440E9103812687A4A4020EF552B1348444087BF266BD4774A406B9DB81CAF44444087BF266BD4774A40
48255	Терское	1	14	1811	40.621512000000003	40.656187000000003	52.788916	52.772390000000001	0103000020E61000000100000005000000290989B48D4F4440F4E0EEACDD624A40290989B48D4F444044A51133FB644A40BA8784EFFD53444044A51133FB644A40BA8784EFFD534440F4E0EEACDD624A40290989B48D4F4440F4E0EEACDD624A40
48556	Терновое	1	14	1811	40.352817000000002	40.379029000000003	53.012839999999997	53.001151999999998	0103000020E61000000100000005000000863C821B292D44409929ADBF25804A40863C821B292D4440520ABABDA4814A40289EB30584304440520ABABDA4814A40289EB305843044409929ADBF25804A40863C821B292D44409929ADBF25804A40
27279	Старое Хмелевое	1	14	1811	40.501190999999999	40.542703000000003	52.806781000000001	52.781613	0103000020E610000001000000050000005706D50627404440719010E50B644A405706D5062740444060048D9944674A407638BA4A7745444060048D9944674A407638BA4A77454440719010E50B644A405706D50627404440719010E50B644A40
27575	Старое Тарбеево	1	14	1811	40.304307999999999	40.333727000000003	52.876708999999998	52.847605999999999	0103000020E61000000100000005000000A1F48590F32644405AF2785A7E6C4A40A1F48590F3264440EF8D210038704A406765FB90B72A4440EF8D210038704A406765FB90B72A44405AF2785A7E6C4A40A1F48590F32644405AF2785A7E6C4A40
27670	Старая Казинка	1	14	1811	40.147210000000001	40.175120999999997	52.865572	52.849226999999999	0103000020E6100000010000000500000074D2FBC6D7124440AAF06778B36C4A4074D2FBC6D7124440AA2A3410CB6E4A40E1EB6B5D6A164440AA2A3410CB6E4A40E1EB6B5D6A164440AAF06778B36C4A4074D2FBC6D7124440AAF06778B36C4A40
46966	Стаево	1	14	1811	40.407093000000003	40.429371000000003	52.862456000000002	52.835863000000003	0103000020E610000001000000050000001CB7989F1B344440DE770C8FFD6A4A401CB7989F1B344440971E4DF5646E4A40E86C01A1F5364440971E4DF5646E4A40E86C01A1F5364440DE770C8FFD6A4A401CB7989F1B344440DE770C8FFD6A4A40
48491	Совхоз Зеленый Гай	1	14	1811	40.377088999999998	40.400615999999999	52.961275000000001	52.949236999999997	0103000020E610000001000000050000003657CD73443044409A93179980794A403657CD734430444030BB270F0B7B4A408E2095624733444030BB270F0B7B4A408E209562473344409A93179980794A403657CD73443044409A93179980794A40
51215	Совхоз Глазковский	1	14	1811	40.690359000000001	40.713974999999998	53.138365	53.130639000000002	0103000020E61000000100000005000000E8BF07AF5D584440844A5CC7B8904A40E8BF07AF5D5844409DF4BEF1B5914A40AF946588635B44409DF4BEF1B5914A40AF946588635B4440844A5CC7B8904A40E8BF07AF5D584440844A5CC7B8904A40
27849	Ранино	1	14	1811	40.232298999999998	40.277600999999997	52.983486999999997	52.964334000000001	0103000020E610000001000000050000005EF23FF9BB1D4440DF35E84B6F7B4A405EF23FF9BB1D44404485EAE6E27D4A401F2BF86D882344404485EAE6E27D4A401F2BF86D88234440DF35E84B6F7B4A405EF23FF9BB1D4440DF35E84B6F7B4A40
48110	Панское	1	14	1811	40.549332	40.584699000000001	52.904173999999998	52.882432000000001	0103000020E61000000100000005000000B952CF8250464440D1782288F3704A40B952CF82504644405EF23FF9BB734A408080B56AD74A44405EF23FF9BB734A408080B56AD74A4440D1782288F3704A40B952CF8250464440D1782288F3704A40
28650	Отделение Садострой	1	14	1811	40.510120999999998	40.526802000000004	52.977502000000001	52.969057999999997	0103000020E610000001000000050000005C001AA54B414440ADF6B0170A7C4A405C001AA54B41444026E318C91E7D4A40D4BB783F6E43444026E318C91E7D4A40D4BB783F6E434440ADF6B0170A7C4A405C001AA54B414440ADF6B0170A7C4A40
28697	Отделение Коммунар	1	14	1811	40.548164	40.559465000000003	52.916035000000001	52.909028999999997	0103000020E610000001000000050000001A6CEA3C2A464440CB0EF10F5B744A401A6CEA3C2A464440E57E87A240754A40DA20938C9C474440E57E87A240754A40DA20938C9C474440CB0EF10F5B744A401A6CEA3C2A464440CB0EF10F5B744A40
27987	Остролучье	1	14	1811	40.373631000000003	40.401918999999999	53.031900999999998	53.010337	0103000020E61000000100000005000000CAE2FE23D32F444029780AB952814A40CAE2FE23D32F4440D7DAFB5415844A400D52F01472334440D7DAFB5415844A400D52F0147233444029780AB952814A40CAE2FE23D32F444029780AB952814A40
45526	Новоникольское	1	14	1811	40.378014	40.430584000000003	52.837972999999998	52.812474999999999	0103000020E610000001000000050000000FB743C362304440A7E8482EFF674A400FB743C3623044402BF702B3426B4A40271763601D3744402BF702B3426B4A40271763601D374440A7E8482EFF674A400FB743C362304440A7E8482EFF674A40
27282	Новое Хмелевое	1	14	1811	40.476298999999997	40.500822999999997	52.788094000000001	52.771546000000001	0103000020E610000001000000050000000A0F9A5DF73C444008AEF204C2624A400A0F9A5DF73C44404016A243E0644A40D40AD3F71A4044404016A243E0644A40D40AD3F71A40444008AEF204C2624A400A0F9A5DF73C444008AEF204C2624A40
27716	Новое Тарбеево	1	14	1811	40.219552	40.286026999999997	52.845723999999997	52.833447	0103000020E61000000100000005000000BDE2A9471A1C444083F92B64AE6A4A40BDE2A9471A1C44409DB81CAF406C4A40F16261889C2444409DB81CAF406C4A40F16261889C24444083F92B64AE6A4A40BDE2A9471A1C444083F92B64AE6A4A40
27933	Мичуринский лесоучасток	1	14	1811	40.192306000000002	40.211663999999999	53.000999999999998	52.988605	0103000020E610000001000000050000008C69A67B9D184440BFD4CF9B8A7E4A408C69A67B9D184440E3A59BC420804A40CADE52CE171B4440E3A59BC420804A40CADE52CE171B4440BFD4CF9B8A7E4A408C69A67B9D184440BFD4CF9B8A7E4A40
51249	Липовка	1	14	1811	40.306176000000001	40.328724000000001	52.932429999999997	52.90419	0103000020E61000000100000005000000F96871C63027444064AF777FBC734A40F96871C63027444096E7C1DD59774A4085B4C6A0132A444096E7C1DD59774A4085B4C6A0132A444064AF777FBC734A40F96871C63027444064AF777FBC734A40
48281	Крюковка	1	14	1811	40.546826000000003	40.608728999999997	52.770640999999998	52.755710999999998	0103000020E610000001000000050000001F4DF564FE4544401D1D5723BB604A401F4DF564FE45444076FA415DA4624A403A90F5D4EA4D444076FA415DA4624A403A90F5D4EA4D44401D1D5723BB604A401F4DF564FE4544401D1D5723BB604A40
46727	Круглое	1	14	1811	40.583359999999999	40.623299000000003	52.995603000000003	52.967593999999998	0103000020E61000000100000005000000B4E55C8AAB4A444025E7C41EDA7B4A40B4E55C8AAB4A444056664AEB6F7F4A409450FA42C84F444056664AEB6F7F4A409450FA42C84F444025E7C41EDA7B4A40B4E55C8AAB4A444025E7C41EDA7B4A40
48702	Красивое	1	14	1811	40.585282999999997	40.630935000000001	53.058140999999999	53.026707000000002	0103000020E61000000100000005000000CFF3A78DEA4A444082C98D226B834A40CFF3A78DEA4A444043C70E2A71874A406D73637AC250444043C70E2A71874A406D73637AC250444082C98D226B834A40CFF3A78DEA4A444082C98D226B834A40
46977	Кочетовка	1	14	1811	40.471142999999998	40.537582	53.059640000000002	52.947132000000003	0103000020E61000000100000005000000A25EF0694E3C44405F7F129F3B794A40A25EF0694E3C444048C49448A2874A408A75AA7CCF44444048C49448A2874A408A75AA7CCF4444405F7F129F3B794A40A25EF0694E3C44405F7F129F3B794A40
48134	Коминтерн	1	14	1811	40.579363000000001	40.595118999999997	52.910451999999999	52.900024000000002	0103000020E6100000010000000500000098C11891284A4440BCCE86FC33734A4098C11891284A4440F549EEB089744A40361D01DC2C4C4440F549EEB089744A40361D01DC2C4C4440BCCE86FC33734A4098C11891284A4440BCCE86FC33734A40
48240	Имени Калинина	1	14	1811	40.663274000000001	40.690314000000001	52.855203000000003	52.841166000000001	0103000020E61000000100000005000000C0249529E6544440EA40D653AB6B4A40C0249529E65444407638BA4A776D4A4048FC8A355C5844407638BA4A776D4A4048FC8A355C584440EA40D653AB6B4A40C0249529E6544440EA40D653AB6B4A40
48836	Изосимово	1	14	1811	40.555351000000002	40.595846999999999	52.985211	52.957889999999999	0103000020E610000001000000050000008466D7BD154744402D95B7239C7A4A408466D7BD154744406954E0641B7E4A40B935E9B6444C44406954E0641B7E4A40B935E9B6444C44402D95B7239C7A4A408466D7BD154744402D95B7239C7A4A40
26945	Заворонежское	1	14	1811	40.530315000000002	40.572184999999998	52.888908999999998	52.869126999999999	0103000020E6100000010000000500000004CAA65CE14344400989B48D3F6F4A4004CAA65CE14344405E0F26C5C7714A408121AB5B3D4944405E0F26C5C7714A408121AB5B3D4944400989B48D3F6F4A4004CAA65CE14344400989B48D3F6F4A40
48515	Жидиловка	1	14	1811	40.309643999999999	40.347659999999998	52.963174000000002	52.931339000000001	0103000020E6100000010000000500000089B3226AA2274440A33EC91D36774A4089B3226AA2274440C32D1F49497B4A404D10751F802C4440C32D1F49497B4A404D10751F802C4440A33EC91D36774A4089B3226AA2274440A33EC91D36774A40
28105	Гостеевка	1	14	1811	40.504479000000003	40.525931	53.019379000000001	53.004106	0103000020E61000000100000005000000684293C492404440D3DB9F8B86804A40684293C492404440569DD5027B824A40EE79FEB451434440569DD5027B824A40EE79FEB451434440D3DB9F8B86804A40684293C492404440D3DB9F8B86804A40
48413	Гололобовка	1	14	1811	40.642837999999998	40.667001999999997	53.143988	53.118653999999999	0103000020E610000001000000050000002250FD834852444011C5E40D308F4A402250FD83485244401B82E3326E924A40EC2E5052605544401B82E3326E924A40EC2E50526055444011C5E40D308F4A402250FD834852444011C5E40D308F4A40
28371	Глазок	1	14	1811	40.677368999999999	40.723399000000001	53.125393000000003	53.082115000000002	0103000020E6100000010000000500000080290307B45644406AC18BBE828A4A4080290307B4564440DC12B9E00C904A40C47AA356985C4440DC12B9E00C904A40C47AA356985C44406AC18BBE828A4A4080290307B45644406AC18BBE828A4A40
48357	Борщевое	1	14	1811	40.483970999999997	40.522858999999997	52.856029999999997	52.833556000000002	0103000020E61000000100000005000000309B00C3F23D44403AB187F6B16A4A40309B00C3F23D44408B321B64926D4A40AAB5300BED4244408B321B64926D4A40AAB5300BED4244403AB187F6B16A4A40309B00C3F23D44403AB187F6B16A4A40
51184	Большая Сосновка	1	14	1811	40.382505999999999	40.396996000000001	52.722610000000003	52.715961	0103000020E610000001000000050000000B43E4F4F5304440111B2C9CA45B4A400B43E4F4F53044409CE1067C7E5C4A404852D2C3D03244409CE1067C7E5C4A404852D2C3D0324440111B2C9CA45B4A400B43E4F4F5304440111B2C9CA45B4A40
47996	Александровка	1	14	1811	40.528401000000002	40.553176999999998	53.121448000000001	53.109048999999999	0103000020E610000001000000050000003C16DBA4A2434440AC545051F58D4A403C16DBA4A24344401215AA9B8B8F4A401FF30181CE4644401215AA9B8B8F4A401FF30181CE464440AC545051F58D4A403C16DBA4A2434440AC545051F58D4A40
48618	2-я Пятилетка	1	14	1811	40.458880999999998	40.478572	53.009849000000003	52.988469000000002	0103000020E61000000100000005000000BDE0D39CBC3A44400F0EF626867E4A40BDE0D39CBC3A4440FC7266BB42814A400264E8D8413D4440FC7266BB42814A400264E8D8413D44400F0EF626867E4A40BDE0D39CBC3A44400F0EF626867E4A40
48770	Лесная Опушка	1	14	6963	41.475315000000002	41.487766000000001	52.611778999999999	52.600994	0103000020E610000001000000050000002D26361FD7BC4440CE8B135FED4C4A402D26361FD7BC444096B036C64E4E4A40E50CC51D6FBE444096B036C64E4E4A40E50CC51D6FBE4440CE8B135FED4C4A402D26361FD7BC4440CE8B135FED4C4A40
3975	Шиновка	1	14	407	42.662312999999997	42.707265	52.654229999999998	52.638979999999997	0103000020E610000001000000050000009A5B21ACC65445402766BD18CA514A409A5B21ACC6544540F20703CFBD534A407F4DD6A8875A4540F20703CFBD534A407F4DD6A8875A45402766BD18CA514A409A5B21ACC65445402766BD18CA514A40
2172	Чутановка	1	14	407	42.724485999999999	42.778492	52.608853000000003	52.593522	0103000020E6100000010000000500000076340EF5BB5C45406FBA6587F84B4A4076340EF5BB5C4540278925E5EE4D4A404C1938A0A5634540278925E5EE4D4A404C1938A0A56345406FBA6587F84B4A4076340EF5BB5C45406FBA6587F84B4A40
46786	Федоровка	1	14	407	42.463057999999997	42.478096000000001	52.597351000000003	52.592680000000001	0103000020E6100000010000000500000059130B7C453B4540247F30F0DC4B4A4059130B7C453B4540D09D60FF754C4A40992CEE3F323D4540D09D60FF754C4A40992CEE3F323D4540247F30F0DC4B4A4059130B7C453B4540247F30F0DC4B4A40
2737	Тоновка	1	14	407	42.753051999999997	42.774621000000003	52.649428	52.641520999999997	0103000020E61000000100000005000000FC170802646045403E59315C1D524A40FC17080264604540A88DEA7420534A40BDE5EAC726634540A88DEA7420534A40BDE5EAC7266345403E59315C1D524A40FC170802646045403E59315C1D524A40
47164	Сурки	1	14	407	42.510848000000003	42.535974000000003	52.692563	52.680700999999999	0103000020E610000001000000050000000F9D9E776341454060ADDA3521574A400F9D9E7763414540B7B585E7A5584A40CFC0C8CB9A444540B7B585E7A5584A40CFC0C8CB9A44454060ADDA3521574A400F9D9E776341454060ADDA3521574A40
46153	Соколово	1	14	407	42.412725000000002	42.450059000000003	52.817214999999997	52.798712999999999	0103000020E61000000100000005000000ED9E3C2CD4344540EDF1423A3C664A40ED9E3C2CD43445407B6649809A684A409F2287889B3945407B6649809A684A409F2287889B394540EDF1423A3C664A40ED9E3C2CD4344540EDF1423A3C664A40
47220	Свищевка	1	14	407	42.445649000000003	42.468663999999997	52.599862000000002	52.583334999999998	0103000020E61000000100000005000000603FC4060B3945405BCEA5B8AA4A4A40603FC4060B3945407C0E2C47C84C4A400168942EFD3B45407C0E2C47C84C4A400168942EFD3B45405BCEA5B8AA4A4A40603FC4060B3945405BCEA5B8AA4A4A40
51182	Садовый	1	14	407	42.383988000000002	42.393475000000002	52.799725000000002	52.793076999999997	0103000020E610000001000000050000003A07CF8426314540DA1A118C83654A403A07CF8426314540956588635D664A40956588635D324540956588635D664A40956588635D324540DA1A118C83654A403A07CF8426314540DA1A118C83654A40
46083	Рамза	1	14	407	42.621502999999997	42.665053	52.494743999999997	52.471594000000003	0103000020E61000000100000005000000D5AE09698D4F4540B37E33315D3C4A40D5AE09698D4F454034F279C5533F4A40A88DEA742055454034F279C5533F4A40A88DEA7420554540B37E33315D3C4A40D5AE09698D4F4540B37E33315D3C4A40
25548	Прямица	1	14	407	42.837511999999997	42.849297999999997	52.646914000000002	52.638815999999998	0103000020E61000000100000005000000F700DD97336B4540AD1402B9C4514A40F700DD97336B45408BA9F413CE524A407347FFCBB56C45408BA9F413CE524A407347FFCBB56C4540AD1402B9C4514A40F700DD97336B4540AD1402B9C4514A40
2557	Полевой	1	14	407	42.480899000000001	42.496609999999997	52.821916999999999	52.814908000000003	0103000020E61000000100000005000000EDD632198E3D4540D89FC4E74E684A40EDD632198E3D45406283859334694A40EB6E9EEA903F45406283859334694A40EB6E9EEA903F4540D89FC4E74E684A40EDD632198E3D4540D89FC4E74E684A40
46086	Подвигаловка	1	14	407	42.268303000000003	42.295828	52.830269999999999	52.811549999999997	0103000020E610000001000000050000009835B1C057224540CE88D2DEE0674A409835B1C057224540CA6C9049466A4A40DC9E20B1DD254540CA6C9049466A4A40DC9E20B1DD254540CE88D2DEE0674A409835B1C057224540CE88D2DEE0674A40
60589	Петровка	1	14	407	42.285271999999999	42.294130000000003	52.631011999999998	52.627065000000002	0103000020E61000000100000005000000753BFBCA83244540AEBB79AA43504A40753BFBCA8324454018B14F00C5504A40E162450DA625454018B14F00C5504A40E162450DA6254540AEBB79AA43504A40753BFBCA83244540AEBB79AA43504A40
46007	Орловка	1	14	407	42.390250000000002	42.436368999999999	52.676665999999997	52.668627999999998	0103000020E61000000100000005000000CBA145B6F33145404E98309A95554A40CBA145B6F33145405628D2FD9C564A407EFE7BF0DA3745405628D2FD9C564A407EFE7BF0DA3745404E98309A95554A40CBA145B6F33145404E98309A95554A40
51201	Ольшановка	1	14	407	42.237509000000003	42.245854000000001	52.808430000000001	52.799093999999997	0103000020E61000000100000005000000BAC0E5B1661E4540043752B648664A40BAC0E5B1661E45407A8D5DA27A674A409FCBD424781F45407A8D5DA27A674A409FCBD424781F4540043752B648664A40BAC0E5B1661E4540043752B648664A40
24835	Овсяновка	1	14	407	42.795974000000001	42.810149000000003	52.711143	52.700361999999998	0103000020E61000000100000005000000B03BDD79E26545403AAE4676A5594A40B03BDD79E2654540C1E3DBBB065B4A408DF161F6B2674540C1E3DBBB065B4A408DF161F6B26745403AAE4676A5594A40B03BDD79E26545403AAE4676A5594A40
24434	Молоканщина	1	14	407	42.715197000000003	42.742964000000001	52.642482999999999	52.629885999999999	0103000020E61000000100000005000000429946938B5B4540A81ABD1AA0504A40429946938B5B4540349E08E23C524A407C0DC171195F4540349E08E23C524A407C0DC171195F4540A81ABD1AA0504A40429946938B5B4540A81ABD1AA0504A40
60592	Михайловка	1	14	407	42.318268000000003	42.342289000000001	52.781644999999997	52.770532000000003	0103000020E6100000010000000500000082AE7D01BD284540C042E6CAA0624A4082AE7D01BD2845407C0A80F10C644A40E9633E20D02B45407C0A80F10C644A40E9633E20D02B4540C042E6CAA0624A4082AE7D01BD284540C042E6CAA0624A40
51170	Мирный	1	14	407	42.363137999999999	42.376137	52.661102	52.650683999999998	0103000020E61000000100000005000000A9F7544E7B2E4540E603029D49534A40A9F7544E7B2E4540FCA886FD9E544A4064E8D84125304540FCA886FD9E544A4064E8D84125304540E603029D49534A40A9F7544E7B2E4540E603029D49534A40
47379	Марьинка	1	14	407	42.678223000000003	42.730710999999999	52.552489999999999	52.534565000000001	0103000020E610000001000000050000009032E202D05645400A4B3CA06C444A409032E202D0564540FBAE08FEB7464A40EAE923F0875D4540FBAE08FEB7464A40EAE923F0875D45400A4B3CA06C444A409032E202D05645400A4B3CA06C444A40
46733	Ленинское	1	14	407	42.814442999999997	42.842011999999997	52.769879000000003	52.762599000000002	0103000020E6100000010000000500000062BA10AB3F6845402D7B12D89C614A4062BA10AB3F684540487023658B624A40766B990CC76B4540487023658B624A40766B990CC76B45402D7B12D89C614A4062BA10AB3F6845402D7B12D89C614A40
4952	Краснослободский	1	14	407	42.365240999999997	42.396583	52.649062000000001	52.631509000000001	0103000020E6100000010000000500000044149337C02E454099107349D5504A4044149337C02E4540C689AF7614534A402593533BC3324540C689AF7614534A402593533BC332454099107349D5504A4044149337C02E454099107349D5504A40
25367	Компрессорная	1	14	407	42.760643000000002	42.770676999999999	52.683736000000003	52.676191000000003	0103000020E610000001000000050000003677F4BF5C614540BE6C3B6D8D564A403677F4BF5C614540878C47A984574A40C3633F8BA5624540878C47A984574A40C3633F8BA5624540BE6C3B6D8D564A403677F4BF5C614540BE6C3B6D8D564A40
47132	Кобяки	1	14	407	42.553742999999997	42.598649999999999	52.718775000000001	52.683889000000001	0103000020E61000000100000005000000C8B1F50CE14645400D8CBCAC89574A40C8B1F50CE14645405917B7D1005C4A400DE02D90A04C45405917B7D1005C4A400DE02D90A04C45400D8CBCAC89574A40C8B1F50CE14645400D8CBCAC89574A40
3087	Кирсанов	1	14	407	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
24327	Калаис	1	14	407	42.598542000000002	42.661020000000001	52.635783000000004	52.604325000000003	0103000020E6100000010000000500000027A435069D4C4540DE9387855A4D4A4027A435069D4C4540282D5C5661514A403F00A94D9C544540282D5C5661514A403F00A94D9C544540DE9387855A4D4A4027A435069D4C4540DE9387855A4D4A40
24129	Иноковка 2-я	1	14	407	42.468663999999997	42.530898999999998	52.594298999999999	52.530177000000002	0103000020E610000001000000050000000168942EFD3B4540B30B06D7DC434A400168942EFD3B4540D38558FD114C4A40533D997FF4434540D38558FD114C4A40533D997FF4434540B30B06D7DC434A400168942EFD3B4540B30B06D7DC434A40
24123	Иноковка 1-я	1	14	407	42.533549000000001	42.595461	52.556224	52.528554999999997	0103000020E6100000010000000500000021E868554B4445409291B3B0A7434A4021E868554B4445400AA0185932474A409085E810384C45400AA0185932474A409085E810384C45409291B3B0A7434A4021E868554B4445409291B3B0A7434A40
24031	Голынщина	1	14	407	42.699153000000003	42.734861000000002	52.686732999999997	52.666454000000002	0103000020E610000001000000050000003DF372D87D594540EA245B5D4E554A403DF372D87D594540BF0AF0DDE6574A408D0DDDEC0F5E4540BF0AF0DDE6574A408D0DDDEC0F5E4540EA245B5D4E554A403DF372D87D594540EA245B5D4E554A40
3936	Вячка	1	14	407	42.562511000000001	42.594374000000002	52.603816000000002	52.586748999999998	0103000020E61000000100000005000000F451465C00484540F8FA5A971A4B4A40F451465C004845409966BAD7494D4A40DECB7D72144C45409966BAD7494D4A40DECB7D72144C4540F8FA5A971A4B4A40F451465C00484540F8FA5A971A4B4A40
2674	Большая Уваровщина	1	14	407	42.746305999999997	42.772303000000001	52.658583999999998	52.648542999999997	0103000020E610000001000000050000007F677BF4865F45405D86FF7403534A407F677BF4865F45409DD5027B4C544A4025CD1FD3DA6245409DD5027B4C544A4025CD1FD3DA6245405D86FF7403534A407F677BF4865F45405D86FF7403534A40
23607	Юбилейный	1	14	512	42.736432999999998	42.763418999999999	52.281185999999998	52.265436999999999	0103000020E61000000100000005000000FB58C16F435E4540FD12F1D6F9214A40FB58C16F435E4540E90B21E7FD234A409012BBB6B7614540E90B21E7FD234A409012BBB6B7614540FD12F1D6F9214A40FB58C16F435E4540FD12F1D6F9214A40
23271	Чернавка	1	14	512	42.402943	42.474530000000001	52.184843999999998	52.153083000000002	0103000020E610000001000000050000007993DFA2933345406B49473998134A407993DFA293334540506EDBF7A8174A40467C2766BD3C4540506EDBF7A8174A40467C2766BD3C45406B49473998134A407993DFA2933345406B49473998134A40
23177	Хорошавка	1	14	512	42.444336999999997	42.474789999999999	52.250630000000001	52.212178999999999	0103000020E610000001000000050000008DB3E908E0384540F1F274AE281B4A408DB3E908E0384540C0B2D2A414204A40E23B31EBC53C4540C0B2D2A414204A40E23B31EBC53C4540F1F274AE281B4A408DB3E908E0384540F1F274AE281B4A40
23449	Филатовский	1	14	512	42.565134	42.591185000000003	52.187742999999998	52.171574	0103000020E61000000100000005000000C8ED974F56484540056C0723F6154A40C8ED974F56484540C6866EF607184A40617138F3AB4B4540C6866EF607184A40617138F3AB4B4540056C0723F6154A40C8ED974F56484540056C0723F6154A40
22896	Соболевка	1	14	512	42.266516000000003	42.283503000000003	52.340781999999997	52.335737000000002	0103000020E610000001000000050000002DEE3F321D2245405187156EF92A4A402DEE3F321D22454061889CBE9E2B4A40B1A888D34924454061889CBE9E2B4A40B1A888D3492445405187156EF92A4A402DEE3F321D2245405187156EF92A4A40
22453	Семеновка	1	14	512	42.485866000000001	42.497311000000003	52.373156000000002	52.366514000000002	0103000020E61000000100000005000000821E6ADB303E454059C345EEE92E4A40821E6ADB303E454031276893C32F4A40757808E3A73F454031276893C32F4A40757808E3A73F454059C345EEE92E4A40821E6ADB303E454059C345EEE92E4A40
23318	Сатино	1	14	512	42.602691999999998	42.616723999999998	52.112611999999999	52.098959999999998	0103000020E61000000100000005000000C9C7EE02254D45405BCEA5B8AA0C4A40C9C7EE02254D45408E91EC116A0E4A404354E1CFF04E45408E91EC116A0E4A404354E1CFF04E45405BCEA5B8AA0C4A40C9C7EE02254D45405BCEA5B8AA0C4A40
23100	Плодопитомник	1	14	512	42.580531000000001	42.593133999999999	52.276502999999998	52.269492999999997	0103000020E6100000010000000500000037A8FDD64E4A45401EC022BF7E224A4037A8FDD64E4A4540791F477364234A40A5129ED0EB4B4540791F477364234A40A5129ED0EB4B45401EC022BF7E224A4037A8FDD64E4A45401EC022BF7E224A40
22573	Паревка	1	14	512	42.549951999999998	42.591974999999998	52.447350999999998	52.413581999999998	0103000020E61000000100000005000000552FBFD3644645406D1B4641F0344A40552FBFD3644645409C6A2DCC42394A40598638D6C54B45409C6A2DCC42394A40598638D6C54B45406D1B4641F0344A40552FBFD3644645406D1B4641F0344A40
23838	Павловка	1	14	512	42.772374999999997	42.816409999999998	52.411439999999999	52.392209000000001	0103000020E61000000100000005000000BE9F1A2FDD62454033198EE733324A40BE9F1A2FDD6245401422E010AA344A404D10751F806845401422E010AA344A404D10751F8068454033198EE733324A40BE9F1A2FDD62454033198EE733324A40
22517	Ольховка	1	14	512	42.507893000000003	42.552602	52.462085999999999	52.436580999999997	0103000020E61000000100000005000000056F48A3024145400987DEE2E1374A40056F48A30241454040F850A2253B4A4023DA8EA9BB46454040F850A2253B4A4023DA8EA9BB4645400987DEE2E1374A40056F48A3024145400987DEE2E1374A40
46030	Новая Жизнь	1	14	512	42.762484999999998	42.773372000000002	52.176262999999999	52.159022999999998	0103000020E610000001000000050000006458C51B99614540E9279CDD5A144A406458C51B99614540573F36C98F164A4031D28BDAFD624540573F36C98F164A4031D28BDAFD624540E9279CDD5A144A406458C51B99614540E9279CDD5A144A40
23552	Николино	1	14	512	42.747123000000002	42.788041999999997	52.193319000000002	52.181128000000001	0103000020E61000000100000005000000728BF9B9A15F4540E831CA332F174A40728BF9B9A15F454004594FADBE184A40EDEF6C8FDE64454004594FADBE184A40EDEF6C8FDE644540E831CA332F174A40728BF9B9A15F4540E831CA332F174A40
22467	Никитино	1	14	512	42.428823000000001	42.459994999999999	52.438892000000003	52.421294000000003	0103000020E61000000100000005000000E5620CACE3364540220038F6EC354A40E5620CACE3364540EF3CF19C2D384A4069A9BC1DE13A4540EF3CF19C2D384A4069A9BC1DE13A4540220038F6EC354A40E5620CACE3364540220038F6EC354A40
23875	Михайловка	1	14	512	42.814343999999998	42.827539999999999	52.361438	52.355130000000003	0103000020E61000000100000005000000CFD8976C3C6845400CEA5BE6742D4A40CFD8976C3C6845400DC4B299432E4A40E010AAD4EC6945400DC4B299432E4A40E010AAD4EC6945400CEA5BE6742D4A40CFD8976C3C6845400CEA5BE6742D4A40
22904	Лопатино	1	14	512	42.389899	42.411341999999998	52.37077	52.356934000000003	0103000020E610000001000000050000001EDFDE35E83145404D6A6803B02D4A401EDFDE35E8314540412B3064752F4A4051BCCADAA6344540412B3064752F4A4051BCCADAA63445404D6A6803B02D4A401EDFDE35E83145404D6A6803B02D4A40
23376	Ломовка	1	14	512	42.702404999999999	42.725681000000002	52.126446999999999	52.103225000000002	0103000020E6100000010000000500000000C63368E859454097900F7A360D4A4000C63368E8594540B2D6506A2F104A400F2A711DE35C4540B2D6506A2F104A400F2A711DE35C454097900F7A360D4A4000C63368E859454097900F7A360D4A40
23932	Леонтьевка	1	14	512	42.841203999999998	42.893889999999999	52.344116999999997	52.326557000000001	0103000020E61000000100000005000000D7A19A92AC6B4540D3A3A99ECC294A40D7A19A92AC6B4540B27F9E060C2C4A40581CCEFC6A724540B27F9E060C2C4A40581CCEFC6A724540D3A3A99ECC294A40D7A19A92AC6B4540D3A3A99ECC294A40
22778	Лебедевка	1	14	512	42.218096000000003	42.236736999999998	52.386310999999999	52.360458999999999	0103000020E61000000100000005000000B8B1D991EA1B454041464085232E4A40B8B1D991EA1B4540E38A8BA372314A406760E4654D1E4540E38A8BA372314A406760E4654D1E454041464085232E4A40B8B1D991EA1B454041464085232E4A40
22732	Курдюки	1	14	512	42.229325000000003	42.260299000000003	52.519125000000003	52.495998999999998	0103000020E61000000100000005000000DE9387855A1D4540A2EC2DE57C3F4A40DE9387855A1D45409CC420B072424A403C17467A512145409CC420B072424A403C17467A51214540A2EC2DE57C3F4A40DE9387855A1D4540A2EC2DE57C3F4A40
23455	Кулевча	1	14	512	42.634636	42.652225000000001	52.246445000000001	52.221100999999997	0103000020E61000000100000005000000A06EA0C03B514540730E9E094D1C4A40A06EA0C03B514540A1A17F828B1F4A401A51DA1B7C534540A1A17F828B1F4A401A51DA1B7C534540730E9E094D1C4A40A06EA0C03B514540730E9E094D1C4A40
23038	Красивка	1	14	512	42.477412999999999	42.521044000000003	52.268424000000003	52.247762999999999	0103000020E61000000100000005000000B6D782DE1B3D45405514AFB2B61F4A40B6D782DE1B3D454013BBB6B75B224A4076E3DD91B142454013BBB6B75B224A4076E3DD91B14245405514AFB2B61F4A40B6D782DE1B3D45405514AFB2B61F4A40
22992	Кишкино	1	14	512	42.378813999999998	42.395262000000002	52.346328	52.335731000000003	0103000020E610000001000000050000002BA226FA7C3045406FA0C03BF92A4A402BA226FA7C30454034D8D479542C4A4000ADF9F19732454034D8D479542C4A4000ADF9F1973245406FA0C03BF92A4A402BA226FA7C3045406FA0C03BF92A4A40
23262	Караул	1	14	512	42.343392999999999	42.371771000000003	52.249985000000002	52.231102999999997	0103000020E610000001000000050000007156444DF42B4540F58079C8941D4A407156444DF42B4540CBBE2B82FF1F4A40F54C2F31962F4540CBBE2B82FF1F4A40F54C2F31962F4540F58079C8941D4A407156444DF42B4540F58079C8941D4A40
23004	Карандеевка	1	14	512	42.411206999999997	42.426416000000003	52.298212999999997	52.271621000000003	0103000020E610000001000000050000007171546EA234454013F4177AC4224A407171546EA2344540FB1EF5D72B264A40DE3EABCC94364540FB1EF5D72B264A40DE3EABCC9436454013F4177AC4224A407171546EA234454013F4177AC4224A40
23739	Карай-Салтыково	1	14	512	42.606223	42.645029999999998	52.380155000000002	52.348709999999997	0103000020E61000000100000005000000A08A1BB7984D4540E2E47E87A22C4A40A08A1BB7984D4540983446EBA8304A402D78D15790524540983446EBA8304A402D78D15790524540E2E47E87A22C4A40A08A1BB7984D4540E2E47E87A22C4A40
23825	Карай-Пущино	1	14	512	42.617469	42.653329999999997	52.409962	52.387706999999999	0103000020E610000001000000050000009CA56439094F454013B70A62A0314A409CA56439094F4540274D83A279344A4072BF4351A0534540274D83A279344A4072BF4351A053454013B70A62A0314A409CA56439094F454013B70A62A0314A40
22744	Караваино	1	14	512	42.186979000000001	42.221347999999999	52.432298000000003	52.412505000000003	0103000020E61000000100000005000000F70489EDEE174540DF37BEF6CC344A40F70489EDEE1745402810768A55374A407B849A21551C45402810768A55374A407B849A21551C4540DF37BEF6CC344A40F70489EDEE174540DF37BEF6CC344A40
22827	Калугино	1	14	512	42.274923999999999	42.308135	52.425072	52.388784999999999	0103000020E610000001000000050000005871AAB5302345407216F6B4C3314A405871AAB530234540003961C268364A4061E0B9F770274540003961C268364A4061E0B9F7702745407216F6B4C3314A405871AAB5302345407216F6B4C3314A40
3143	Инжавино	1	14	512	42.451577999999998	42.502889000000003	52.362560000000002	52.289439000000002	0103000020E61000000100000005000000EACBD24ECD394540EE974F560C254A40EACBD24ECD3945403C6BB75D682E4A405342B0AA5E4045403C6BB75D682E4A405342B0AA5E404540EE974F560C254A40EACBD24ECD394540EE974F560C254A40
22656	Ивановка	1	14	512	42.337707000000002	42.355080999999998	52.516807	52.503148000000003	0103000020E61000000100000005000000AD50A4FB392B45401F86562767404A40AD50A4FB392B454004AC55BB26424A402A37514B732D454004AC55BB26424A402A37514B732D45401F86562767404A40AD50A4FB392B45401F86562767404A40
22653	Землянский	1	14	512	42.374654999999997	42.395837	52.469751000000002	52.456462000000002	0103000020E610000001000000050000003524EEB1F42F4540F2EEC8586D3A4A403524EEB1F42F4540B421FFCC203C4A40FCC56CC9AA324540B421FFCC203C4A40FCC56CC9AA324540F2EEC8586D3A4A403524EEB1F42F4540F2EEC8586D3A4A40
23566	Екатеринополье	1	14	512	42.802343	42.832517000000003	52.275565999999998	52.248932000000003	0103000020E610000001000000050000005796E82CB3664540C576F700DD1F4A405796E82CB3664540DCF126BF45234A40992EC4EA8F6A4540DCF126BF45234A40992EC4EA8F6A4540C576F700DD1F4A405796E82CB3664540C576F700DD1F4A40
23180	Грушевка	1	14	512	42.295172000000001	42.313084000000003	52.300659000000003	52.277048000000001	0103000020E61000000100000005000000F3583332C82545400BB6114F76234A40F3583332C8254540C11F7EFE7B264A405073F22213284540C11F7EFE7B264A405073F222132845400BB6114F76234A40F3583332C82545400BB6114F76234A40
23664	Балыклей	1	14	512	42.546880000000002	42.617353000000001	52.350883000000003	52.291592999999999	0103000020E61000000100000005000000126BF129004645400B5F5FEB52254A40126BF1290046454077DCF0BBE92C4A40338B506C054F454077DCF0BBE92C4A40338B506C054F45400B5F5FEB52254A40126BF129004645400B5F5FEB52254A40
45484	Алексеевка	1	14	512	42.465581999999998	42.480566000000003	52.414472000000004	52.406210000000002	0103000020E610000001000000050000009ACDE330983B454072A774B0FE334A409ACDE330983B4540CA8D226B0D354A40E7C8CA2F833D4540CA8D226B0D354A40E7C8CA2F833D454072A774B0FE334A409ACDE330983B454072A774B0FE334A40
45946	Сухотинка	1	14	1673	41.557555999999998	41.650595000000003	52.525142000000002	52.499420999999998	0103000020E6100000010000000500000023D8B8FE5DC74440C2F7FE06ED3F4A4023D8B8FE5DC74440C6E061DA37434A4077F86BB246D34440C6E061DA37434A4077F86BB246D34440C2F7FE06ED3F4A4023D8B8FE5DC74440C2F7FE06ED3F4A40
45832	Совхоз Кузьминский	1	14	1673	41.226472999999999	41.257689999999997	52.422842000000003	52.407241999999997	0103000020E61000000100000005000000A8363811FD9C444060C77F8120344A40A8363811FD9C444008B0C8AF1F364A40CC4065FCFBA0444008B0C8AF1F364A40CC4065FCFBA0444060C77F8120344A40A8363811FD9C444060C77F8120344A40
21736	Покрово-Марфино	1	14	1673	41.014597000000002	41.042434999999998	52.421272000000002	52.393521999999997	0103000020E6100000010000000500000053CF8250DE814440D520CCED5E324A4053CF8250DE8144403A5CAB3DEC354A40569A94826E8544403A5CAB3DEC354A40569A94826E854440D520CCED5E324A4053CF8250DE814440D520CCED5E324A40
45784	Первомайское	1	14	1673	41.466880000000003	41.479232000000003	52.452939000000001	52.445945999999999	0103000020E6100000010000000500000008944DB9C2BB444019E42EC214394A4008944DB9C2BB44409E0AB8E7F9394A402D99637957BD44409E0AB8E7F9394A402D99637957BD444019E42EC214394A4008944DB9C2BB444019E42EC214394A40
21823	Новознаменка	1	14	1673	41.081843999999997	41.116151000000002	52.366656999999996	52.352594000000003	0103000020E61000000100000005000000D9AF3BDD798A44400762D9CC212D4A40D9AF3BDD798A4440BBECD79DEE2E4A40E8323509DE8E4440BBECD79DEE2E4A40E8323509DE8E44400762D9CC212D4A40D9AF3BDD798A44400762D9CC212D4A40
45850	Михайловка	1	14	1673	41.308920999999998	41.347394999999999	52.471814000000002	52.456226000000001	0103000020E6100000010000000500000018062CB98AA74440DECA129D653A4A4018062CB98AA74440C1E5B166643C4A409FE5797077AC4440C1E5B166643C4A409FE5797077AC4440DECA129D653A4A4018062CB98AA74440DECA129D653A4A40
21621	Кариан	1	14	1673	41.198481999999998	41.260438000000001	52.279874999999997	52.256920999999998	0103000020E610000001000000050000001E6CB1DB67994440EB538EC9E2204A401E6CB1DB67994440E7FBA9F1D2234A405D514A0856A14440E7FBA9F1D2234A405D514A0856A14440EB538EC9E2204A401E6CB1DB67994440EB538EC9E2204A40
45727	Измайловка	1	14	1673	41.380965000000003	41.418622999999997	52.353181999999997	52.307195	0103000020E61000000100000005000000D8F50B76C3B04440533F6F2A52274A40D8F50B76C3B0444097C45911352D4A403C2D3F7095B5444097C45911352D4A403C2D3F7095B54440533F6F2A52274A40D8F50B76C3B04440533F6F2A52274A40
51203	Знаменка	1	14	1673	41.413088999999999	41.461894999999998	52.437618999999998	52.401017000000003	0103000020E610000001000000050000002EABB019E0B44440ED116A8654334A402EABB019E0B44440DA8D3EE603384A40CC9717601FBB4440DA8D3EE603384A40CC9717601FBB4440ED116A8654334A402EABB019E0B44440ED116A8654334A40
51176	Дуплятово-Маслово	1	14	1673	41.20035	41.243819999999999	52.392110000000002	52.364100000000001	0103000020E6100000010000000500000076E09C11A59944409F3C2CD49A2E4A4076E09C11A5994440A03715A930324A402C0E677E359F4440A03715A930324A402C0E677E359F44409F3C2CD49A2E4A4076E09C11A59944409F3C2CD49A2E4A40
45771	Даниловка	1	14	1673	41.371110999999999	41.409379000000001	52.526747	52.516834000000003	0103000020E61000000100000005000000CA17B49080AF4440FEBAD39D27424A40CA17B49080AF4440102219726C434A40A855F48766B44440102219726C434A40A855F48766B44440FEBAD39D27424A40CA17B49080AF4440FEBAD39D27424A40
45753	Воронцовка	1	14	1673	41.404519000000001	41.428325000000001	52.469104000000002	52.439473999999997	0103000020E6100000010000000500000029CE5147C7B344409DB81CAF40384A4029CE5147C7B344401E3691990B3C4A409487855AD3B644401E3691990B3C4A409487855AD3B644409DB81CAF40384A4029CE5147C7B344409DB81CAF40384A40
46833	Александровка	1	14	1673	41.318694000000001	41.379995000000001	52.301687999999999	52.259202999999999	0103000020E6100000010000000500000039B709F7CAA8444036035C902D214A4039B709F7CAA844403ECC5EB69D264A405FD218ADA3B044403ECC5EB69D264A405FD218ADA3B0444036035C902D214A4039B709F7CAA8444036035C902D214A40
11384	Шпикулово	1	14	1070	41.855410999999997	41.887588000000001	51.752021999999997	51.739742999999997	0103000020E61000000100000005000000BFD18E1B7EED4440F3380CE6AFDE4940BFD18E1B7EED4440AEEFC34142E049403929CC7B9CF14440AEEFC34142E049403929CC7B9CF14440F3380CE6AFDE4940BFD18E1B7EED4440F3380CE6AFDE4940
20807	Чикаревка	1	14	1070	41.569817999999998	41.606416000000003	51.935426999999997	51.915759999999999	0103000020E610000001000000050000000856D5CBEFC84440137EA99F37F549400856D5CBEFC84440CF656A12BCF74940B5E21B0A9FCD4440CF656A12BCF74940B5E21B0A9FCD4440137EA99F37F549400856D5CBEFC84440137EA99F37F54940
20285	Цветовка	1	14	1070	41.290253999999997	41.317517000000002	51.856447000000003	51.844240999999997	0103000020E610000001000000050000003FC4060B27A544409E78CE1610EC49403FC4060B27A54440F0E0270EA0ED49404776A565A4A84440F0E0270EA0ED49404776A565A4A844409E78CE1610EC49403FC4060B27A544409E78CE1610EC4940
20647	Туголуково	1	14	1070	41.622334000000002	41.701574000000001	51.961545000000001	51.923476000000001	0103000020E610000001000000050000002D98F8A3A8CF44400952297634F649402D98F8A3A8CF4440F05014E813FB4940A9DC442DCDD94440F05014E813FB4940A9DC442DCDD944400952297634F649402D98F8A3A8CF44400952297634F64940
45433	Сукмановка	1	14	1070	41.542312000000003	41.603200000000001	51.810727	51.772106000000001	0103000020E610000001000000050000003B1DC87A6AC54440CF85915ED4E249403B1DC87A6AC54440FA7DFFE6C5E749403E7958A835CD4440FA7DFFE6C5E749403E7958A835CD4440CF85915ED4E249403B1DC87A6AC54440CF85915ED4E24940
51206	Степной	1	14	1070	41.767752999999999	41.797263000000001	51.873437000000003	51.855490000000003	0103000020E61000000100000005000000F433F5BA45E244400C0742B280ED4940F433F5BA45E24440E50E9BC8CCEF4940CAA7C7B60CE64440E50E9BC8CCEF4940CAA7C7B60CE644400C0742B280ED4940F433F5BA45E244400C0742B280ED4940
46797	Садовый	1	14	1070	41.372126000000002	41.388950999999999	51.836590000000001	51.828336	0103000020E61000000100000005000000E3FE23D3A1AF4440BB0CFFE906EA4940E3FE23D3A1AF44409014916115EB49408D5F7825C9B144409014916115EB49408D5F7825C9B14440BB0CFFE906EA4940E3FE23D3A1AF4440BB0CFFE906EA4940
20057	Рымарево	1	14	1070	41.306835999999997	41.325440999999998	51.920986999999997	51.911648999999997	0103000020E61000000100000005000000239EEC6646A744402E3718EAB0F44940239EEC6646A744404485EAE6E2F5494086E3F90CA8A944404485EAE6E2F5494086E3F90CA8A944402E3718EAB0F44940239EEC6646A744402E3718EAB0F44940
9479	Пичаево	1	14	1070	41.21078	41.243558999999998	51.805615000000003	51.778503000000001	0103000020E610000001000000050000005053CBD6FA9A4440406B7EFCA5E349405053CBD6FA9A444062156F641EE74940BFD2F9F02C9F444062156F641EE74940BFD2F9F02C9F4440406B7EFCA5E349405053CBD6FA9A4440406B7EFCA5E34940
51226	Питим	1	14	1070	41.208722000000002	41.235078999999999	51.760708000000001	51.744522000000003	0103000020E6100000010000000500000055FA0967B79A44408693347F4CDF494055FA0967B79A44401DE736E15EE14940FA7C9411179E44401DE736E15EE14940FA7C9411179E44408693347F4CDF494055FA0967B79A44408693347F4CDF4940
51234	Петровское	1	14	1070	41.736320999999997	41.762157000000002	51.931201000000001	51.914138000000001	0103000020E61000000100000005000000D32D3BC43FDE4440F303577902F54940D32D3BC43FDE44405280289831F7494070B54E5C8EE144405280289831F7494070B54E5C8EE14440F303577902F54940D32D3BC43FDE4440F303577902F54940
45540	Павлодар	1	14	1070	41.582870999999997	41.628478000000001	52.042405000000002	52.024360000000001	0103000020E61000000100000005000000B66455849BCA444050AA7D3A1E034A40B66455849BCA4440EC17EC866D054A40B42094F771D04440EC17EC866D054A40B42094F771D0444050AA7D3A1E034A40B66455849BCA444050AA7D3A1E034A40
21071	Новый Свет 1-й	1	14	1070	41.822487000000002	41.850712000000001	51.879904000000003	51.85895	0103000020E610000001000000050000004D31074147E944401973D712F2ED49404D31074147E944404FCFBBB1A0F049404A287D21E4EC44404FCFBBB1A0F049404A287D21E4EC44401973D712F2ED49404D31074147E944401973D712F2ED4940
20181	Новорусаново	1	14	1070	41.422063000000001	41.454807000000002	51.798175000000001	51.781467999999997	0103000020E6100000010000000500000003ED0E2906B644406D6FB72407E4494003ED0E2906B644400EBE30992AE64940F67EA31D37BA44400EBE30992AE64940F67EA31D37BA44406D6FB72407E4494003ED0E2906B644406D6FB72407E44940
45585	Максим Горький	1	14	1070	41.87379	41.912768	51.895440000000001	51.869093999999997	0103000020E6100000010000000500000032C9C859D8EF44402D93E1783EEF494032C9C859D8EF4440DFC325C79DF24940EC6AF294D5F44440DFC325C79DF24940EC6AF294D5F444402D93E1783EEF494032C9C859D8EF44402D93E1783EEF4940
45495	Искра	1	14	1070	41.728073999999999	41.750487	51.863298999999998	51.846077000000001	0103000020E61000000100000005000000B188618731DD4440EB724A404CEC4940B188618731DD4440B2D5E59480EE49405D8940F50FE04440B2D5E59480EE49405D8940F50FE04440EB724A404CEC4940B188618731DD4440EB724A404CEC4940
10689	Жердевка	1	14	1070	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
21123	Демьян Бедный	1	14	1070	41.817520000000002	41.845959999999998	51.831453000000003	51.819752000000001	0103000020E61000000100000005000000B8E9CF7EA4E84440516A2FA2EDE84940B8E9CF7EA4E844409F94490D6DEA4940B1DCD26A48EC44409F94490D6DEA4940B1DCD26A48EC4440516A2FA2EDE84940B8E9CF7EA4E84440516A2FA2EDE84940
51230	Григорьевка	1	14	1070	41.948816999999998	41.973439999999997	51.684345	51.664439999999999	0103000020E61000000100000005000000C571E0D572F94440BE13B35E0CD54940C571E0D572F944402F17F19D98D74940224F92AE99FC44402F17F19D98D74940224F92AE99FC4440BE13B35E0CD54940C571E0D572F94440BE13B35E0CD54940
45538	Вязовое	1	14	1070	41.514876999999998	41.532251000000002	51.922704000000003	51.901142	0103000020E61000000100000005000000363B527DE7C14440A986FD9E58F34940363B527DE7C14440B7F1272A1BF64940B421FFCC20C44440B7F1272A1BF64940B421FFCC20C44440A986FD9E58F34940363B527DE7C14440A986FD9E58F34940
49523	Бурнак	1	14	1070	41.421371999999998	41.506433000000001	51.894678999999996	51.846884000000003	0103000020E610000001000000050000009DB98784EFB54440BAC0E5B166EC49409DB98784EFB5444080B56AD784F24940BE4EEACBD2C0444080B56AD784F24940BE4EEACBD2C04440BAC0E5B166EC49409DB98784EFB54440BAC0E5B166EC4940
49219	Булгаково	1	14	1070	41.871400999999999	41.886744	51.687193000000001	51.676399000000004	0103000020E61000000100000005000000D15966118AEF44400806103E94D64940D15966118AEF44402385B2F0F5D749404DF6CFD380F144402385B2F0F5D749404DF6CFD380F144400806103E94D64940D15966118AEF44400806103E94D64940
60484	д.Синявка-1	1	14	169	42.287391999999997	43.012098999999999	53.130591000000003	52.753694000000003	0103000020E61000000100000005000000E690D442C92445408198840B79604A40E690D442C92445407313B534B7904A403BA8C4758C8145407313B534B7904A403BA8C4758C8145408198840B79604A40E690D442C92445408198840B79604A40
525	Чуповка	1	14	169	42.619912999999997	42.649251999999997	52.797575000000002	52.782091999999999	0103000020E61000000100000005000000C0AE264F594F45404B3B35971B644A40C0AE264F594F4540B98D06F016664A40696E85B01A534540B98D06F016664A40696E85B01A5345404B3B35971B644A40C0AE264F594F45404B3B35971B644A40
51236	Станция Рожковка	1	14	169	42.678024999999998	42.710517000000003	53.040239999999997	53.034489000000001	0103000020E61000000100000005000000696FF085C95645402F89B3226A844A40696FF085C9564540DAFE959526854A4043209738F25A4540DAFE959526854A4043209738F25A45402F89B3226A844A40696FF085C95645402F89B3226A844A40
51210	Пересыпкино 2-е	1	14	169	42.877890999999998	42.955703	52.933222999999998	52.884317000000003	0103000020E61000000100000005000000F33977BB5E704540FF25A94C31714A40F33977BB5E7045400070ECD973774A4034D8D479547A45400070ECD973774A4034D8D479547A4540FF25A94C31714A40F33977BB5E704540FF25A94C31714A40
45428	Пересыпкино 1-е	1	14	169	42.877890999999998	42.955703	52.933222999999998	52.884317000000003	0103000020E61000000100000005000000F33977BB5E704540FF25A94C31714A40F33977BB5E7045400070ECD973774A4034D8D479547A45400070ECD973774A4034D8D479547A4540FF25A94C31714A40F33977BB5E704540FF25A94C31714A40
575	Осино-Гай	1	14	169	42.390402000000002	42.431275999999997	53.043005999999998	53.016252999999999	0103000020E61000000100000005000000812557B1F83145401FBB0B9414824A40812557B1F831454011C4793881854A405CC64D0D3437454011C4793881854A405CC64D0D343745401FBB0B9414824A40812557B1F83145401FBB0B9414824A40
46637	Ольшанка	1	14	169	42.536450000000002	42.651426000000001	53.050434000000003	52.825558000000001	0103000020E6100000010000000500000038F8C264AA444540C07971E2AB694A4038F8C264AA444540A14D0E9F74864A40CEE15AED61534540A14D0E9F74864A40CEE15AED61534540C07971E2AB694A4038F8C264AA444540C07971E2AB694A40
19114	Кондаурово	1	14	169	42.517963000000002	42.534869	52.835203999999997	52.81832	0103000020E61000000100000005000000DFC4909C4C424540D4D4B2B5BE684A40DFC4909C4C42454083BEF4F6E76A4A4076525F967644454083BEF4F6E76A4A4076525F9676444540D4D4B2B5BE684A40DFC4909C4C424540D4D4B2B5BE684A40
51166	Гусевка	1	14	169	42.472786999999997	42.503706999999999	52.928983000000002	52.911386	0103000020E61000000100000005000000AA7CCF48843C45402104E44BA8744A40AA7CCF48843C45401EC539EAE8764A4015E29178794045401EC539EAE8764A4015E29178794045402104E44BA8744A40AA7CCF48843C45402104E44BA8744A40
45520	Глуховка	1	14	169	42.5732	42.610174999999998	53.123171999999997	53.083992000000002	0103000020E610000001000000050000009A081B9E5E4945401590F63FC08A4A409A081B9E5E49454036E49F19C48F4A401CEBE2361A4E454036E49F19C48F4A401CEBE2361A4E45401590F63FC08A4A409A081B9E5E4945401590F63FC08A4A40
18682	Гавриловка 2-я	1	14	169	42.734169999999999	42.791662000000002	52.890197000000001	52.855131999999998	0103000020E6100000010000000500000027DA5548F95D4540ACE122F7746D4A4027DA5548F95D4540A8FFACF9F1714A4034BE2F2E55654540A8FFACF9F1714A4034BE2F2E55654540ACE122F7746D4A4027DA5548F95D4540ACE122F7746D4A40
12809	Гавриловка 1-я	1	14	169	42.793647	42.825150999999998	52.861744000000002	52.832794	0103000020E61000000100000005000000C5C89239966545400B2769FE986A4A40C5C89239966545401AC39CA04D6E4A407FA1478C9E6945401AC39CA04D6E4A407FA1478C9E6945400B2769FE986A4A40C5C89239966545400B2769FE986A4A40
49333	Анненка	1	14	169	42.545082999999998	42.570388999999999	53.026170999999998	53.005682	0103000020E61000000100000005000000834D9D47C545454083161230BA804A40834D9D47C5454540438D429259834A40C37FBA8102494540438D429259834A40C37FBA810249454083161230BA804A40834D9D47C545454083161230BA804A40
3658	Шача Молоканская	1	14	230	42.184904000000003	42.200606000000001	53.079275000000003	53.058427999999999	0103000020E6100000010000000500000026732CEFAA174540D99596917A874A4026732CEFAA174540F931E6AE258A4A40D1B01875AD194540F931E6AE258A4A40D1B01875AD194540D99596917A874A4026732CEFAA174540D99596917A874A40
48917	Строительный	1	14	230	42.062347000000003	42.070611	52.929623999999997	52.922431000000003	0103000020E610000001000000050000007A008BFCFA07454086E8103812764A407A008BFCFA074540D1C952EBFD764A4072DEFFC709094540D1C952EBFD764A4072DEFFC70909454086E8103812764A407A008BFCFA07454086E8103812764A40
51223	Совхоз Бондарский	1	14	230	42.035325	42.048727999999997	52.949845000000003	52.945309000000002	0103000020E6100000010000000500000098DD938785044540A7CEA3E2FF784A4098DD93878504454073A25D8594794A40223317B83C06454073A25D8594794A40223317B83C064540A7CEA3E2FF784A4098DD938785044540A7CEA3E2FF784A40
49171	Прибытки	1	14	230	42.060459999999999	42.071832999999998	52.909871000000003	52.888843999999999	0103000020E61000000100000005000000AB5B3D27BD074540779FE3A3C5714A40AB5B3D27BD074540174A26A776744A4004E3E0D231094540174A26A776744A4004E3E0D231094540779FE3A3C5714A40AB5B3D27BD074540779FE3A3C5714A40
18416	Пахотный Угол	1	14	230	41.879781999999999	41.932656999999999	52.995370000000001	52.95176	0103000020E6100000010000000500000003CE52B29CF044400BD28C45D3794A4003CE52B29CF04440B3B5BE48687F4A4057B1F84D61F74440B3B5BE48687F4A4057B1F84D61F744400BD28C45D3794A4003CE52B29CF044400BD28C45D3794A40
47049	Павловка	1	14	230	41.923180000000002	41.938451000000001	52.915790000000001	52.908909999999999	0103000020E61000000100000005000000202922C32AF64440F180B22957744A40202922C32AF644407E00529B38754A4002F390291FF844407E00529B38754A4002F390291FF84440F180B22957744A40202922C32AF64440F180B22957744A40
49109	Озерный	1	14	230	42.160955000000001	42.175776999999997	52.861842000000003	52.854109999999999	0103000020E610000001000000050000005890662C9A144540E197FA79536D4A405890662C9A144540DD28B2D6506E4A40CA3159DC7F164540DD28B2D6506E4A40CA3159DC7F164540E197FA79536D4A405890662C9A144540E197FA79536D4A40
49059	Митрополье	1	14	230	42.043221000000003	42.059885000000001	53.020288999999998	52.978976000000003	0103000020E610000001000000050000000EC0064488054540D2C8E7154F7D4A400EC0064488054540F9BB77D498824A40AF42CA4FAA074540F9BB77D498824A40AF42CA4FAA074540D2C8E7154F7D4A400EC0064488054540D2C8E7154F7D4A40
18120	Малое Гагарино	1	14	230	42.035918000000002	42.047246000000001	53.067487	53.045031000000002	0103000020E610000001000000050000003BAB05F69804454031276893C3854A403BAB05F698044540DCF3FC69A3884A40F46E2C280C064540DCF3FC69A3884A40F46E2C280C06454031276893C3854A403BAB05F69804454031276893C3854A40
60620	Максимовка	1	14	230	42.170126000000003	42.199708000000001	52.975923999999999	52.952069000000002	0103000020E61000000100000005000000831953B0C61545408944A165DD794A40831953B0C6154540D5B0DF13EB7C4A40F25F200890194540D5B0DF13EB7C4A40F25F2008901945408944A165DD794A40831953B0C61545408944A165DD794A40
48997	Куровщина	1	14	230	42.417855000000003	42.430934000000001	52.899475000000002	52.887979999999999	0103000020E610000001000000050000002CBCCB457C35454044C02154A9714A402CBCCB457C354540E9482EFF21734A40035E66D828374540E9482EFF21734A40035E66D82837454044C02154A9714A402CBCCB457C35454044C02154A9714A40
17966	Кривополянье	1	14	230	41.889285999999998	41.912139000000003	53.059618999999998	53.037153000000004	0103000020E610000001000000050000003465A71FD4F1444062F9F36DC1844A403465A71FD4F14440309C6B98A1874A40FD3383F8C0F44440309C6B98A1874A40FD3383F8C0F4444062F9F36DC1844A403465A71FD4F1444062F9F36DC1844A40
49086	Коровино	1	14	230	42.089106999999998	42.107747000000003	53.046320000000001	53.008229	0103000020E610000001000000050000001E6CB1DB670B45407CF0DAA50D814A401E6CB1DB670B45404B9352D0ED854A40FE9E58A7CA0D45404B9352D0ED854A40FE9E58A7CA0D45407CF0DAA50D814A401E6CB1DB670B45407CF0DAA50D814A40
17871	Керша	1	14	230	41.870196999999997	41.903658999999998	52.897247999999998	52.871403999999998	0103000020E61000000100000005000000E509849D62EF444042CD902A8A6F4A40E509849D62EF44406133C005D9724A4037DE1D19ABF344406133C005D9724A4037DE1D19ABF3444042CD902A8A6F4A40E509849D62EF444042CD902A8A6F4A40
48925	Граждановка	1	14	230	42.271349000000001	42.298181	52.963921999999997	52.941656999999999	0103000020E61000000100000005000000B2666490BB2245405586713788784A40B2666490BB2245408CF2CCCB617B4A40F0A485CB2A2645408CF2CCCB617B4A40F0A485CB2A2645405586713788784A40B2666490BB2245405586713788784A40
48979	Городище	1	14	230	41.905994999999997	41.921211999999997	53.025001000000003	53.012135999999998	0103000020E6100000010000000500000075ABE7A4F7F34440588D25AC8D814A4075ABE7A4F7F3444004AF963B33834A4064575A46EAF5444004AF963B33834A4064575A46EAF54440588D25AC8D814A4075ABE7A4F7F34440588D25AC8D814A40
46360	Волхонщино	1	14	230	42.406078000000001	42.423873999999998	52.863363999999997	52.850777000000001	0103000020E6100000010000000500000003D0285DFA3345403198BF42E66C4A4003D0285DFA334540994528B6826E4A40F6CFD38041364540994528B6826E4A40F6CFD380413645403198BF42E66C4A4003D0285DFA3345403198BF42E66C4A40
18351	Верхнее Нащекино	1	14	230	42.094371000000002	42.109805000000001	52.878013000000003	52.855905	0103000020E610000001000000050000006D585359140C4540CFBD874B8E6D4A406D585359140C45403F3BE0BA62704A40F9F719170E0E45403F3BE0BA62704A40F9F719170E0E4540CFBD874B8E6D4A406D585359140C4540CFBD874B8E6D4A40
18574	Вердеревщино	1	14	230	42.085424000000003	42.093437000000002	52.93421	52.901159	0103000020E610000001000000050000009225732CEF0A45407FBF982D59734A409225732CEF0A45404FCC7A3194774A40419E5DBEF50B45404FCC7A3194774A40419E5DBEF50B45407FBF982D59734A409225732CEF0A45407FBF982D59734A40
895	Бондари	1	14	230	42.034399999999998	42.077869	52.964964000000002	52.941141000000002	0103000020E61000000100000005000000BF7D1D38670445405EF6EB4E77784A40BF7D1D38670445409FE8BAF0837B4A40A52F849CF70945409FE8BAF0837B4A40A52F849CF70945405EF6EB4E77784A40BF7D1D38670445405EF6EB4E77784A40
40435	1-й участок Пахотно-Угловского лесничества	1	14	230	41.822082999999999	41.827150000000003	52.988506999999998	52.985622999999997	0103000020E610000001000000050000007DCC07043AE94440BB97FBE4287E4A407DCC07043AE94440FC6EBA65877E4A4076711B0DE0E94440FC6EBA65877E4A4076711B0DE0E94440BB97FBE4287E4A407DCC07043AE94440BB97FBE4287E4A40
54805	Ярцево	1	13	\N	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
54804	Сычевка	1	13	\N	34.252681000000003	34.313172999999999	55.853763999999998	55.813324000000001	0103000020E6100000010000000500000009A9DBD957204140A58636001BE84B4009A9DBD9572041404640852348ED4B40BF7E880D162841404640852348ED4B40BF7E880D16284140A58636001BE84B4009A9DBD957204140A58636001BE84B40
54885	Станички	1	13	\N	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
6	Смоленск	1	13	\N	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
54800	Сафоново	1	13	\N	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
54806	Рудня	1	13	\N	31.023651000000001	31.115459000000001	54.957949999999997	54.932994999999998	0103000020E610000001000000050000008884EFFD0D063F406F2A52616C774B408884EFFD0D063F40029A081B9E7A4B40640795B88E1D3F40029A081B9E7A4B40640795B88E1D3F406F2A52616C774B408884EFFD0D063F406F2A52616C774B40
54794	Рославль	1	13	\N	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
54803	Починок	1	13	\N	32.415751999999998	32.473100000000002	54.425702000000001	54.391337999999998	0103000020E61000000100000005000000909F8D5C373540404DD7135D17324B40909F8D5C37354040C0EB33677D364B406ADE718A8E3C4040C0EB33677D364B406ADE718A8E3C40404DD7135D17324B40909F8D5C373540404DD7135D17324B40
7627	Новые Батеки	1	13	\N	31.831443	31.874507999999999	54.792354000000003	54.783814	0103000020E61000000100000005000000F67CCD72D9D43F40CF12640454644B40F67CCD72D9D43F406A6D1ADB6B654B4022179CC1DFDF3F406A6D1ADB6B654B4022179CC1DFDF3F40CF12640454644B40F67CCD72D9D43F40CF12640454644B40
45893	Михновка	1	13	\N	31.947945000000001	31.970637	54.761789	54.750151000000002	0103000020E610000001000000050000001F680586ACF23F40E607AEF204604B401F680586ACF23F40EDB94C4D82614B409D499BAA7BF83F40EDB94C4D82614B409D499BAA7BF83F40E607AEF204604B401F680586ACF23F40E607AEF204604B40
54828	Красный Бор	1	13	\N	31.883707000000001	31.918866999999999	54.814745000000002	54.797263999999998	0103000020E610000001000000050000000C3F389F3AE23F409A232BBF0C664B400C3F389F3AE23F402ECA6C9049684B40A65F22DE3AEB3F402ECA6C9049684B40A65F22DE3AEB3F409A232BBF0C664B400C3F389F3AE23F409A232BBF0C664B40
52446	Заозерье	1	13	\N	31.565200000000001	31.583328000000002	55.666212999999999	55.652191999999999	0103000020E61000000100000005000000FFB27BF2B0903F403E5B07077BD34B40FFB27BF2B0903F40C495B37746D54B4052D7DAFB54953F40C495B37746D54B4052D7DAFB54953F403E5B07077BD34B40FFB27BF2B0903F403E5B07077BD34B40
54797	Ельня	1	13	\N	33.15193	33.210760999999998	54.592832000000001	54.561107999999997	0103000020E6100000010000000500000001A436717293404011C30E63D2474B4001A4367172934040DA0242EBE14B4B40D9226937FA9A4040DA0242EBE14B4B40D9226937FA9A404011C30E63D2474B4001A436717293404011C30E63D2474B40
54802	Духовщина	1	13	\N	32.377214000000002	32.429011000000003	55.208348000000001	55.182479999999998	0103000020E61000000100000005000000F3CB608C48304040481630815B974B40F3CB608C48304040F017B325AB9A4B40E84F1BD5E9364040F017B325AB9A4B40E84F1BD5E9364040481630815B974B40F3CB608C48304040481630815B974B40
54798	Дорогобуж	1	13	\N	33.256799999999998	33.376553999999999	54.936776000000002	54.887393000000003	0103000020E6100000010000000500000070CE88D2DEA0404084D9041896714B4070CE88D2DEA04040BFD6A546E8774B40C896E5EB32B04040BFD6A546E8774B40C896E5EB32B0404084D9041896714B4070CE88D2DEA0404084D9041896714B40
54795	Десногорск	1	13	\N	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
54796	Демидов	1	13	\N	31.476869000000001	31.578458999999999	55.292028000000002	55.240820999999997	0103000020E61000000100000005000000EA793716147A3F405298F738D39E4B40EA793716147A3F4016C26A2C61A54B40AD1397E315943F4016C26A2C61A54B40AD1397E315943F405298F738D39E4B40EA793716147A3F405298F738D39E4B40
54812	Гедеоновка	1	13	\N	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
54801	Гагарин	1	13	\N	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
54793	Вязьма	1	13	\N	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
54799	Велиж	1	13	\N	31.135608000000001	31.230784	55.627763000000002	55.590353	0103000020E610000001000000050000007313B534B7223F40390CE6AF90CB4B407313B534B7223F40C651B9895AD04B40A87004A9143B3F40C651B9895AD04B40A87004A9143B3F40390CE6AF90CB4B407313B534B7223F40390CE6AF90CB4B40
54841	Алексино	1	13	\N	31.976268999999998	31.992933000000001	54.743926000000002	54.738047999999999	0103000020E610000001000000050000003F19E3C3ECF93F4069705B5B785E4B403F19E3C3ECF93F40725298F7385F4B40821E6ADB30FE3F40725298F7385F4B40821E6ADB30FE3F4069705B5B785E4B403F19E3C3ECF93F4069705B5B785E4B40
13395	Ярцево	1	13	987	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
15281	Суетово	1	13	987	32.888472	32.920155999999999	55.103538	55.085033000000003	0103000020E61000000100000005000000B3B45373B9714040570A815CE28A4B40B3B45373B971404056F2B1BB408D4B40ED9BFBABC775404056F2B1BB408D4B40ED9BFBABC7754040570A815CE28A4B40B3B45373B9714040570A815CE28A4B40
13017	Самуйлово	1	13	987	32.624789999999997	32.635694999999998	55.113467	55.106994	0103000020E61000000100000005000000156F641EF94F4040226FB9FAB18D4B40156F641EF94F40406E162F16868E4B40889D29745E5140406E162F16868E4B40889D29745E514040226FB9FAB18D4B40156F641EF94F4040226FB9FAB18D4B40
40398	Репино	1	13	987	32.866166999999997	32.887574000000001	55.412252000000002	55.399299999999997	0103000020E61000000100000005000000EDEF6C8FDE6E40407AA52C431CB34B40EDEF6C8FDE6E4040F5DA6CACC4B44B40D4635B069C714040F5DA6CACC4B44B40D4635B069C7140407AA52C431CB34B40EDEF6C8FDE6E40407AA52C431CB34B40
48887	Потапово	1	13	987	32.600696999999997	32.609492000000003	55.160555000000002	55.149774000000001	0103000020E6100000010000000500000014E7A8A3E34C404043E55FCB2B934B4014E7A8A3E34C4040CA1AF5108D944B403A9677D5034E4040CA1AF5108D944B403A9677D5034E404043E55FCB2B934B4014E7A8A3E34C404043E55FCB2B934B40
15152	Подроща	1	13	987	32.607506000000001	32.633108	54.999046	54.983581999999998	0103000020E61000000100000005000000D80FB1C1C24D40409677D503E67D4B40D80FB1C1C24D40408D9944BDE07F4B40016BD5AE095140408D9944BDE07F4B40016BD5AE095140409677D503E67D4B40D80FB1C1C24D40409677D503E67D4B40
54879	Петрово	1	13	987	32.832723000000001	32.870559999999998	55.032031000000003	55.011118000000003	0103000020E6100000010000000500000042D0D1AA966A4040CF328B506C814B4042D0D1AA966A4040A6BA809719844B40569A94826E6F4040A6BA809719844B40569A94826E6F4040CF328B506C814B4042D0D1AA966A4040CF328B506C814B40
49055	Ольхово	1	13	987	32.776550999999998	32.794696999999999	55.049436	55.035947	0103000020E610000001000000050000008A56EE0566634040D5B14AE999844B408A56EE05666340405E9F39EB53864B405A9D9CA1B86540405E9F39EB53864B405A9D9CA1B8654040D5B14AE999844B408A56EE0566634040D5B14AE999844B40
15015	Мушковичи	1	13	987	32.499053000000004	32.522219999999997	55.063766999999999	55.056043000000003	0103000020E6100000010000000500000040FCFCF7E03F4040BA15C26A2C874B4040FCFCF7E03F404032C85D8429884B4097A8DE1AD842404032C85D8429884B4097A8DE1AD8424040BA15C26A2C874B4040FCFCF7E03F4040BA15C26A2C874B40
54813	Михейково	1	13	987	32.661926000000001	32.688552000000001	55.098691000000002	55.080348999999998	0103000020E61000000100000005000000A12FBDFDB954404016A243E0488A4B40A12FBDFDB95440406CB41CE8A18C4B4036CCD078225840406CB41CE8A18C4B4036CCD0782258404016A243E0488A4B40A12FBDFDB954404016A243E0488A4B40
14927	Мирополье	1	13	987	32.923884000000001	32.965108000000001	55.402526000000002	55.383025000000004	0103000020E610000001000000050000001AA6B6D441764040744694F606B14B401AA6B6D44176404015E5D2F885B34B40D28DB0A8887B404015E5D2F885B34B40D28DB0A8887B4040744694F606B14B401AA6B6D441764040744694F606B14B40
48958	Львово	1	13	987	32.735416999999998	32.763229000000003	55.420265000000001	55.407181999999999	0103000020E6100000010000000500000012F6ED24225E40408BC22E8A1EB44B4012F6ED24225E4040A453573ECBB54B40ED2DE57CB1614040A453573ECBB54B40ED2DE57CB16140408BC22E8A1EB44B4012F6ED24225E40408BC22E8A1EB44B40
48953	Кротово	1	13	987	32.641939000000001	32.672499000000002	55.295062999999999	55.286450000000002	0103000020E610000001000000050000007383A10E2B52404038F8C264AAA44B407383A10E2B5240403CA1D79FC4A54B40DECB7D72145640403CA1D79FC4A54B40DECB7D721456404038F8C264AAA44B407383A10E2B52404038F8C264AAA44B40
14822	Капыревщина	1	13	987	32.852145	32.876632999999998	55.243761999999997	55.204002000000003	0103000020E6100000010000000500000097395D16136D4040C828CFBC1C9A4B4097395D16136D4040F700DD97339F4B4014CC988235704040F700DD97339F4B4014CC988235704040C828CFBC1C9A4B4097395D16136D4040C828CFBC1C9A4B40
47460	Вышегор	1	13	987	32.809457000000002	32.824646999999999	55.078045000000003	55.068716000000002	0103000020E61000000100000005000000574277499C674040215B96AFCB884B40574277499C674040E44EE960FD894B404CDF6B088E694040E44EE960FD894B404CDF6B088E694040215B96AFCB884B40574277499C674040215B96AFCB884B40
25558	Яново	1	13	1216	32.474339999999998	32.486502999999999	53.933486000000002	53.923333999999997	0103000020E61000000100000005000000A297512CB73C404076A4FACE2FF64A40A297512CB73C40400EA320787CF74A40F433F5BA453E40400EA320787CF74A40F433F5BA453E404076A4FACE2FF64A40A297512CB73C404076A4FACE2FF64A40
12734	Шумячи	1	13	1216	32.405808	32.447031000000003	53.877496999999998	53.836970999999998	0103000020E61000000100000005000000433A3C84F1334040A759A0DD21EB4A40433A3C84F133404047AB5AD251F04A402BA6D24F3839404047AB5AD251F04A402BA6D24F38394040A759A0DD21EB4A40433A3C84F1334040A759A0DD21EB4A40
48347	Студенец	1	13	1216	32.066271	32.097316999999997	53.885213999999998	53.869793999999999	0103000020E610000001000000050000002CD670917B084040E620E86855EF4A402CD670917B0840400DFB3DB14EF14A40232C2AE2740C40400DFB3DB14EF14A40232C2AE2740C4040E620E86855EF4A402CD670917B084040E620E86855EF4A40
48229	Снегиревка	1	13	1216	32.357999	32.391514999999998	53.938723000000003	53.924612000000003	0103000020E61000000100000005000000178046E9D22D40409DBE9EAF59F64A40178046E9D22D40406380441328F84A405C72DC291D3240406380441328F84A405C72DC291D3240409DBE9EAF59F64A40178046E9D22D40409DBE9EAF59F64A40
48298	Русское	1	13	1216	32.242485000000002	32.282890999999999	53.872571000000001	53.845641999999998	0103000020E61000000100000005000000A2629CBF091F4040E00F3FFF3DEC4A40A2629CBF091F404011381268B0EF4A4097AAB4C53524404011381268B0EF4A4097AAB4C535244040E00F3FFF3DEC4A40A2629CBF091F4040E00F3FFF3DEC4A40
54852	Руссковский	1	13	1216	32.381417999999996	32.402681000000001	53.848599999999998	53.839010999999999	0103000020E61000000100000005000000880D164ED2304040FCFD62B664EB4A40880D164ED23040405BB1BFEC9EEC4A403CDC0E0D8B3340405BB1BFEC9EEC4A403CDC0E0D8B334040FCFD62B664EB4A40880D164ED2304040FCFD62B664EB4A40
13018	Починичи	1	13	1216	32.246276000000002	32.270305999999998	53.998018000000002	53.977809999999998	0103000020E6100000010000000500000015E5D2F8851F4040D3D9C9E028FD4A4015E5D2F8851F4040E068C70DBFFF4A40CFF4126399224040E068C70DBFFF4A40CFF4126399224040D3D9C9E028FD4A4015E5D2F8851F4040D3D9C9E028FD4A40
54834	Понятовка	1	13	1216	32.432380000000002	32.472597	53.817323000000002	53.796889999999998	0103000020E61000000100000005000000E5B8533A583740403541D47D00E64A40E5B8533A5837404062A2410A9EE84A400798F90E7E3C404062A2410A9EE84A400798F90E7E3C40403541D47D00E64A40E5B8533A583740403541D47D00E64A40
13119	Петровичи	1	13	1216	32.143320000000003	32.168886000000001	53.985731000000001	53.969707999999997	0103000020E610000001000000050000006E6E4C4F58124040B45549641FFC4A406E6E4C4F58124040A2D3F36E2CFE4A404A60730E9E154040A2D3F36E2CFE4A404A60730E9E154040B45549641FFC4A406E6E4C4F58124040B45549641FFC4A40
12935	Новое Заселье	1	13	1216	32.376207999999998	32.390860000000004	53.968738999999999	53.957593000000003	0103000020E610000001000000050000002D3F70952730404074F04C6892FA4A402D3F7095273040400CAEB9A3FFFB4A4044A852B3073240400CAEB9A3FFFB4A4044A852B30732404074F04C6892FA4A402D3F70952730404074F04C6892FA4A40
13302	Надейковичи	1	13	1216	31.915794999999999	31.934722000000001	53.864469	53.850661000000002	0103000020E610000001000000050000001FD7868A71EA3F40C87DAB75E2EC4A401FD7868A71EA3F40F2B391EBA6EE4A400ADAE4F049EF3F40F2B391EBA6EE4A400ADAE4F049EF3F40C87DAB75E2EC4A401FD7868A71EA3F40C87DAB75E2EC4A40
24634	Лысовка	1	13	1216	32.447633000000003	32.460704	53.860900999999998	53.856482	0103000020E6100000010000000500000021CEC3094C3940406CCEC133A1ED4A4021CEC3094C394040FE0B040132EE4A4075914259F83A4040FE0B040132EE4A4075914259F83A40406CCEC133A1ED4A4021CEC3094C3940406CCEC133A1ED4A40
12113	Криволес	1	13	1216	32.561610999999999	32.582596000000002	53.866354000000001	53.853592999999996	0103000020E61000000100000005000000740987DEE2474040198C118942ED4A40740987DEE2474040206118B0E4EE4A40E5637781924A4040206118B0E4EE4A40E5637781924A4040198C118942ED4A40740987DEE2474040198C118942ED4A40
13309	Зимонино	1	13	1216	31.861815	31.894521999999998	53.798032999999997	53.786098000000003	0103000020E61000000100000005000000C63368E89FDC3F40BBB9F8DB9EE44A40C63368E89FDC3F407B1002F225E64A40718DCF64FFE43F407B1002F225E64A40718DCF64FFE43F40BBB9F8DB9EE44A40C63368E89FDC3F40BBB9F8DB9EE44A40
47527	Зимницы	1	13	1216	32.417692000000002	32.430115999999998	53.792140000000003	53.784644999999998	0103000020E6100000010000000500000082E673EE7635404026FC523F6FE44A4082E673EE763540403EEDF0D764E54A4040BE840A0E3740403EEDF0D764E54A4040BE840A0E37404026FC523F6FE44A4082E673EE7635404026FC523F6FE44A40
15291	Гневково	1	13	1216	32.498683999999997	32.526387999999997	53.911116	53.897100999999999	0103000020E61000000100000005000000EC8497E0D43F4040BD1AA034D4F24A40EC8497E0D43F4040616EF7729FF44A40E08096AE60434040616EF7729FF44A40E08096AE60434040BD1AA034D4F24A40EC8497E0D43F4040BD1AA034D4F24A40
48196	Балахоновка	1	13	1216	32.313460999999997	32.334445000000002	53.963495000000002	53.947484000000003	0103000020E6100000010000000500000025C9737D1F284040DCBDDC2747F94A4025C9737D1F284040056EDDCD53FB4A40C6A70018CF2A4040056EDDCD53FB4A40C6A70018CF2A4040DCBDDC2747F94A4025C9737D1F284040DCBDDC2747F94A40
52876	Малое Павлово	1	13	7242	46.561585999999998	46.577871999999999	57.743259999999999	57.735280000000003	0103000020E610000001000000050000001BF2CF0CE247474092B3B0A71DDE4C401BF2CF0CE24747406536C82423DF4C4016A3AEB5F74947406536C82423DF4C4016A3AEB5F749474092B3B0A71DDE4C401BF2CF0CE247474092B3B0A71DDE4C40
48477	Юшково	1	13	1213	33.314444999999999	33.319510999999999	55.637402999999999	55.631503000000002	0103000020E6100000010000000500000003B2D7BB3FA84040B7291E17D5D04B4003B2D7BB3FA84040A7AFE76B96D14B402BDB87BCE5A84040A7AFE76B96D14B402BDB87BCE5A84040B7291E17D5D04B4003B2D7BB3FA84040B7291E17D5D04B40
12603	Холм-Жирковский	1	13	1213	33.462532000000003	33.503998000000003	55.525446000000002	55.494909999999997	0103000020E610000001000000050000003FADA23F34BB40404F3BFC3559BF4B403FADA23F34BB404032E884D041C34B40ED9FA70183C0404032E884D041C34B40ED9FA70183C040404F3BFC3559BF4B403FADA23F34BB40404F3BFC3559BF4B40
48013	Стешино	1	13	1213	33.563699999999997	33.579528000000003	55.457169	55.436861999999998	0103000020E61000000100000005000000AA60545227C84040BD6E1118EBB74B40AA60545227C840405DDF878384BA4B40E38E37F92DCA40405DDF878384BA4B40E38E37F92DCA4040BD6E1118EBB74B40AA60545227C84040BD6E1118EBB74B40
12400	Пигулино	1	13	1213	33.726080000000003	33.754196999999998	55.438434999999998	55.425863999999997	0103000020E61000000100000005000000CD237F30F0DC4040994528B682B64B40CD237F30F0DC4040FC3559A31EB84B40E3DEFC8689E04040FC3559A31EB84B40E3DEFC8689E04040994528B682B64B40CD237F30F0DC4040994528B682B64B40
12353	Печатники	1	13	1213	33.379465000000003	33.406844999999997	55.638027999999998	55.626533000000002	0103000020E61000000100000005000000037D224F92B04040B16EBC3B32D04B40037D224F92B0404055F7C8E6AAD14B4043C5387F13B4404055F7C8E6AAD14B4043C5387F13B44040B16EBC3B32D04B40037D224F92B04040B16EBC3B32D04B40
60524	Новоспасское	1	13	1213	33.471443000000001	33.479042999999997	55.437770999999998	55.434353999999999	0103000020E61000000100000005000000CD76853E58BC4040827170E998B74B40CD76853E58BC4040901150E108B84B405930F14751BD4040901150E108B84B405930F14751BD4040827170E998B74B40CD76853E58BC4040827170E998B74B40
54864	Никитинка	1	13	1213	33.293306999999999	33.313285999999998	55.612772	55.600928000000003	0103000020E610000001000000050000000C5872158BA5404017A06D35EBCC4B400C5872158BA54040C7F319506FCE4B40B72572C119A84040C7F319506FCE4B40B72572C119A8404017A06D35EBCC4B400C5872158BA5404017A06D35EBCC4B40
47941	Нахимовское	1	13	1213	33.754196999999998	33.779187999999998	55.534137999999999	55.522989000000003	0103000020E61000000100000005000000E3DEFC8689E040407995B54DF1C24B40E3DEFC8689E0404082C64CA25EC44B40C3B7B06EBCE3404082C64CA25EC44B40C3B7B06EBCE340407995B54DF1C24B40E3DEFC8689E040407995B54DF1C24B40
12256	Лехмино	1	13	1213	33.38993	33.401975999999998	55.551088999999997	55.543011999999997	0103000020E6100000010000000500000059DDEA39E9B14040F3AACE6A81C54B4059DDEA39E9B14040B91798158AC64B4071E316F373B34040B91798158AC64B4071E316F373B34040F3AACE6A81C54B4059DDEA39E9B14040F3AACE6A81C54B40
40461	Караваево	1	13	1213	33.419564999999999	33.430354000000001	55.630862999999998	55.625124999999997	0103000020E61000000100000005000000EBC5504EB4B54040BC74931804D04B40EBC5504EB4B54040D3A0681EC0D04B40F5D901D715B74040D3A0681EC0D04B40F5D901D715B74040BC74931804D04B40EBC5504EB4B54040BC74931804D04B40
54882	Канютино	1	13	1213	33.250996999999998	33.269044000000001	55.524849000000003	55.517856999999999	0103000020E61000000100000005000000723271AB20A0404099805F2349C24B40723271AB20A040404E2B85402EC34B40AF97A60870A240404E2B85402EC34B40AF97A60870A2404099805F2349C24B40723271AB20A0404099805F2349C24B40
54825	Игоревская	1	13	1213	33.266331000000001	33.308632000000003	55.472648	55.436371999999999	0103000020E610000001000000050000009B745B2217A24040EF71A609DBB74B409B745B2217A240408942CBBA7FBC4B40E23FDD4081A740408942CBBA7FBC4B40E23FDD4081A74040EF71A609DBB74B409B745B2217A24040EF71A609DBB74B40
40324	Ивашково	1	13	1213	33.451689000000002	33.463762000000003	55.571967999999998	55.566398999999997	0103000020E61000000100000005000000427BF5F1D0B9404059BE2EC37FC84B40427BF5F1D0B94040E42D573F36C94B4054909F8D5CBB4040E42D573F36C94B4054909F8D5CBB404059BE2EC37FC84B40427BF5F1D0B9404059BE2EC37FC84B40
48920	Зайцево	1	13	1213	33.711167000000003	33.720348000000001	55.594585000000002	55.589385999999998	0103000020E610000001000000050000004A7F2F8507DB4040315C1D0071CB4B404A7F2F8507DB404099D87C5C1BCC4B4098DEFE5C34DC404099D87C5C1BCC4B4098DEFE5C34DC4040315C1D0071CB4B404A7F2F8507DB4040315C1D0071CB4B40
54849	Владимирский Тупик	1	13	1213	33.316538000000001	33.318361000000003	55.695990999999999	55.694794000000002	0103000020E610000001000000050000007BF8325184A8404080BA8102EFD84B407BF8325184A84040B9A7AB3B16D94B4033A9A10DC0A84040B9A7AB3B16D94B4033A9A10DC0A8404080BA8102EFD84B407BF8325184A8404080BA8102EFD84B40
60530	Верховье	1	13	1213	33.023282999999999	33.038167999999999	55.507126999999997	55.495638999999997	0103000020E61000000100000005000000C1C6F5EFFA824040A2CF471971BF4B40C1C6F5EFFA82404094F59B89E9C04B407AE063B0E284404094F59B89E9C04B407AE063B0E2844040A2CF471971BF4B40C1C6F5EFFA824040A2CF471971BF4B40
12056	Болышево	1	13	1213	33.581055999999997	33.602319000000001	55.581459000000002	55.570680000000003	0103000020E610000001000000050000008192020B60CA40409B3DD00A0CC94B408192020B60CA4040817B9E3F6DCA4B403561FBC918CD4040817B9E3F6DCA4B403561FBC918CD40409B3DD00A0CC94B408192020B60CA40409B3DD00A0CC94B40
47823	Боголюбово	1	13	1213	32.936703000000001	32.975949999999997	55.510455999999998	55.495154999999997	0103000020E61000000100000005000000558847E2E5774040B6B9313D61BF4B40558847E2E57740400306499F56C14B40FE43FAEDEB7C40400306499F56C14B40FE43FAEDEB7C4040B6B9313D61BF4B40558847E2E5774040B6B9313D61BF4B40
47802	Батурино	1	13	1213	32.783900000000003	32.818018000000002	55.631737000000001	55.554546999999999	0103000020E61000000100000005000000CEAACFD556644040268C6665FBC64B40CEAACFD5566440402A560DC2DCD04B4009C556D0B46840402A560DC2DCD04B4009C556D0B4684040268C6665FBC64B40CEAACFD556644040268C6665FBC64B40
11896	Агибалово	1	13	1213	33.503979999999999	33.526401999999997	55.415686000000001	55.404116000000002	0103000020E6100000010000000500000046EBA86A82C040402AE5B512BAB34B4046EBA86A82C04040D9B3E73235B54B404546072461C34040D9B3E73235B54B404546072461C340402AE5B512BAB34B4046EBA86A82C040402AE5B512BAB34B40
11780	Черепово	1	13	883	32.243383000000001	32.262436000000001	54.256796999999999	54.245849999999997	0103000020E6100000010000000500000081B3942C271F40405DDC4603781F4B4081B3942C271F4040FF5A5EB9DE204B4083A5BA8097214040FF5A5EB9DE204B4083A5BA80972140405DDC4603781F4B4081B3942C271F40405DDC4603781F4B40
10876	Хиславичи	1	13	883	32.132351	32.183563999999997	54.218336000000001	54.172730999999999	0103000020E61000000100000005000000E44BA8E0F0104040B000A60C1C164B40E44BA8E0F01040400DC51D6FF21B4B40895C70067F1740400DC51D6FF21B4B40895C70067F174040B000A60C1C164B40E44BA8E0F0104040B000A60C1C164B40
11721	Упино	1	13	883	32.068409000000003	32.102420000000002	54.260272999999998	54.247743999999997	0103000020E6100000010000000500000044E048A0C1084040DEE34C13B61F4B4044E048A0C108404012842BA050214B40693A3B191C0D404012842BA050214B40693A3B191C0D4040DEE34C13B61F4B4044E048A0C1084040DEE34C13B61F4B40
11714	Соино	1	13	883	31.986681000000001	32.004584000000001	53.981887999999998	53.961095	0103000020E61000000100000005000000A795422097FC3F40B0AC342905FB4A40A795422097FC3F40DC2A8881AEFD4A40DD0A613596004040DC2A8881AEFD4A40DD0A613596004040B0AC342905FB4A40A795422097FC3F40B0AC342905FB4A40
11566	Печерская Буда	1	13	883	32.282119000000002	32.303776999999997	54.126995999999998	54.112726000000002	0103000020E61000000100000005000000454AB3791C24404057B439CE6D0E4B40454AB3791C244040855CA96741104B4074232C2AE2264040855CA96741104B4074232C2AE226404057B439CE6D0E4B40454AB3791C24404057B439CE6D0E4B40
6702	Печерск	1	13	883	32.254747000000002	32.267189000000002	54.159089000000002	54.146982000000001	0103000020E6100000010000000500000087E0B88C9B204040E38C614ED0124B4087E0B88C9B204040A11342075D144B40EC6CC83F33224040A11342075D144B40EC6CC83F33224040E38C614ED0124B4087E0B88C9B204040E38C614ED0124B40
11572	Петрополье	1	13	883	32.379361000000003	32.407055999999997	54.085842	54.076059000000001	0103000020E610000001000000050000005E30B8E68E30404082C8224DBC094B405E30B8E68E304040C64FE3DEFC0A4B40FED137691A344040C64FE3DEFC0A4B40FED137691A34404082C8224DBC094B405E30B8E68E30404082C8224DBC094B40
11839	Новая Рудня	1	13	883	32.336835000000001	32.362220999999998	54.214345999999999	54.199711999999998	0103000020E61000000100000005000000F792C6681D2B4040334FAE2990194B40F792C6681D2B4040A30392B06F1B4B405376FA415D2E4040A30392B06F1B4B405376FA415D2E4040334FAE2990194B40F792C6681D2B4040334FAE2990194B40
47822	Николаевка	1	13	883	32.236016999999997	32.251989000000002	54.209907000000001	54.204915	0103000020E61000000100000005000000672618CE351E4040DCBA9BA73A1A4B40672618CE351E4040CA198A3BDE1A4B40D3F9F02C41204040CA198A3BDE1A4B40D3F9F02C41204040DCBA9BA73A1A4B40672618CE351E4040DCBA9BA73A1A4B40
11475	Микшино	1	13	883	32.169756999999997	32.181866999999997	54.064366999999997	54.053654000000002	0103000020E610000001000000050000002FA2ED98BA15404059A65F22DE064B402FA2ED98BA15404087F8872D3D084B405E9CF86A4717404087F8872D3D084B405E9CF86A4717404059A65F22DE064B402FA2ED98BA15404059A65F22DE064B40
24423	Красиловка	1	13	883	32.424484	32.435865	54.184370999999999	54.174864999999997	0103000020E610000001000000050000006FD6E07D55364040861BF0F961164B406FD6E07D5536404058AA0B7899174B404B3CA06CCA37404058AA0B7899174B404B3CA06CCA374040861BF0F961164B406FD6E07D55364040861BF0F961164B40
11471	Корзово	1	13	883	32.114421	32.138351999999998	54.199817000000003	54.190103999999998	0103000020E61000000100000005000000E17CEA58A50E40405D6BEF5355184B40E17CEA58A50E4040A9177C9A93194B4008ABB184B5114040A9177C9A93194B4008ABB184B51140405D6BEF5355184B40E17CEA58A50E40405D6BEF5355184B40
11655	Козловка	1	13	883	32.388900999999997	32.426369999999999	54.173743000000002	54.158439999999999	0103000020E61000000100000005000000DB300A82C73140406A300DC347144B40DB300A82C73140405874EB353D164B406DFFCA4A933640405874EB353D164B406DFFCA4A933640406A300DC347144B40DB300A82C73140406A300DC347144B40
11322	Клюкино	1	13	883	31.945062	31.966334	54.090843	54.072629999999997	0103000020E610000001000000050000003EB14E95EFF13F40AF5A99F04B094B403EB14E95EFF13F40070951BEA00B4B404B033FAA61F73F40070951BEA00B4B404B033FAA61F73F40AF5A99F04B094B403EB14E95EFF13F40AF5A99F04B094B40
11226	Йозефовка	1	13	883	32.070870999999997	32.090705999999997	54.089913000000003	54.076597999999997	0103000020E610000001000000050000000E9E094D12094040317898F6CD094B400E9E094D120940401D3EE944820B4B4086C613419C0B40401D3EE944820B4B4086C613419C0B4040317898F6CD094B400E9E094D12094040317898F6CD094B40
11148	Жанвиль	1	13	883	31.887595999999998	31.906524000000001	54.026508999999997	54.013395000000003	0103000020E61000000100000005000000770FD07D39E33F40087767EDB6014B40770FD07D39E33F405B069CA564034B40030AF5F411E83F405B069CA564034B40030AF5F411E83F40087767EDB6014B40770FD07D39E33F40087767EDB6014B40
11140	Городище	1	13	883	31.985620999999998	32.008626	54.087062000000003	54.065497999999998	0103000020E61000000100000005000000354069A851FC3F4009FA0B3D62084B40354069A851FC3F40B85CFDD8240B4B4099F221A81A014040B85CFDD8240B4B4099F221A81A01404009FA0B3D62084B40354069A851FC3F4009FA0B3D62084B40
11055	Владимировка	1	13	883	32.218105000000001	32.243822999999999	54.184066000000001	54.173405000000002	0103000020E610000001000000050000000B0C59DDEA1B404040FB912232164B400B0C59DDEA1B40401C2785798F174B409D819197351F40401C2785798F174B409D819197351F404040FB912232164B400B0C59DDEA1B404040FB912232164B40
11233	Братковая	1	13	883	32.022829000000002	32.040112000000001	54.156610999999998	54.138871000000002	0103000020E610000001000000050000004033880FEC02404071AE6186C6114B404033880FEC024040D09849D40B144B40AD16D86322054040D09849D40B144B40AD16D8632205404071AE6186C6114B404033880FEC02404071AE6186C6114B40
11340	Большая Хутора	1	13	883	31.851305	31.887084000000002	54.131385000000002	54.117739999999998	0103000020E61000000100000005000000D9EBDD1FEFD93F402CB7B41A120F4B40D9EBDD1FEFD93F40AD174339D1104B400CCEE0EF17E33F40AD174339D1104B400CCEE0EF17E33F402CB7B41A120F4B40D9EBDD1FEFD93F402CB7B41A120F4B40
46322	Шилово	1	13	1127	33.841872000000002	33.854250999999998	54.598799	54.592143	0103000020E6100000010000000500000085B53176C2EB404015C78157CB4B4B4085B53176C2EB404052F01472A54C4B40A3C9C51858ED404052F01472A54C4B40A3C9C51858ED404015C78157CB4B4B4085B53176C2EB404015C78157CB4B4B40
60514	Холмы	1	13	1127	33.864375000000003	33.887605999999998	54.595398000000003	54.581620000000001	0103000020E61000000100000005000000713D0AD7A3EE40408A592F86724A4B40713D0AD7A3EE40404A0D6D00364C4B40DFDDCA129DF140404A0D6D00364C4B40DFDDCA129DF140408A592F86724A4B40713D0AD7A3EE40408A592F86724A4B40
47370	Угра	1	13	1127	34.299339000000003	34.364215999999999	54.792155999999999	54.763809999999999	0103000020E610000001000000050000006CB587BD50264140CB2DAD86C4614B406CB587BD5026414043AA285E65654B40085740A19E2E414043AA285E65654B40085740A19E2E4140CB2DAD86C4614B406CB587BD50264140CB2DAD86C4614B40
54872	Слободка	1	13	1127	34.836252999999999	34.865188000000003	54.867092999999997	54.855558000000002	0103000020E6100000010000000500000048179B560A6B414064EAAEEC826D4B4048179B560A6B414096CB46E7FC6E4B402272FA7ABE6E414096CB46E7FC6E4B402272FA7ABE6E414064EAAEEC826D4B4048179B560A6B414064EAAEEC826D4B40
52725	Полднево	1	13	1127	34.052284999999998	34.066944999999997	54.744751999999998	54.734684000000001	0103000020E6100000010000000500000022895E46B10641407E7214200A5E4B4022895E46B1064140B7D09508545F4B40BBD05CA791084140B7D09508545F4B40BBD05CA7910841407E7214200A5E4B4022895E46B10641407E7214200A5E4B40
52719	Подсосонки	1	13	1127	34.703186000000002	34.717793	54.782246000000001	54.767150000000001	0103000020E61000000100000005000000A680B4FF015A41402E90A0F831624B40A680B4FF015A4140A2B60DA320644B401C261AA4E05B4140A2B60DA320644B401C261AA4E05B41402E90A0F831624B40A680B4FF015A41402E90A0F831624B40
54863	Новомилятино	1	13	1127	34.305385000000001	34.333582999999997	54.592404000000002	54.577168999999998	0103000020E6100000010000000500000030D80DDB16274140ECA17DACE0494B4030D80DDB162741408202EFE4D34B4B4033C005D9B22A41408202EFE4D34B4B4033C005D9B22A4140ECA17DACE0494B4030D80DDB16274140ECA17DACE0494B40
54867	Мытыщино	1	13	1127	34.001843999999998	34.020377000000003	54.805473999999997	54.795582000000003	0103000020E61000000100000005000000CFD8976C3C004140A5A487A1D5654B40CFD8976C3C0041409FE3A3C519674B40994BAAB69B0241409FE3A3C519674B40994BAAB69B024140A5A487A1D5654B40CFD8976C3C004140A5A487A1D5654B40
54881	Михали	1	13	1127	34.343482999999999	34.361584000000001	54.916159999999998	54.905203	0103000020E61000000100000005000000B1DD3D40F72B4140DC9E20B1DD734B40B1DD3D40F72B4140A1F31ABB44754B40E1606F62482E4140A1F31ABB44754B40E1606F62482E4140DC9E20B1DD734B40B1DD3D40F72B4140DC9E20B1DD734B40
47131	Знаменка	1	13	1127	34.563588000000003	34.599466999999997	54.919108999999999	54.901155000000003	0103000020E610000001000000050000008335CEA6234841403ED00A0C59734B408335CEA623484140C93A1C5DA5754B40FF03AC55BB4C4140C93A1C5DA5754B40FF03AC55BB4C41403ED00A0C59734B408335CEA6234841403ED00A0C59734B40
52697	Желанья	1	13	1127	34.499375999999998	34.528320000000001	54.856082000000001	54.839733000000003	0103000020E610000001000000050000002234828DEB3F41409D2FF65E7C6B4B402234828DEB3F4140DE585018946D4B404FE960FD9F434140DE585018946D4B404FE960FD9F4341409D2FF65E7C6B4B402234828DEB3F41409D2FF65E7C6B4B40
52695	Дрожжино	1	13	1127	34.614072999999998	34.636271000000001	55.010710000000003	55.001375000000003	0103000020E61000000100000005000000A52DAEF1994E41401904560E2D804B40A52DAEF1994E4140BEDEFDF15E814B405532005471514140BEDEFDF15E814B4055320054715141401904560E2D804B40A52DAEF1994E41401904560E2D804B40
47062	Всходы	1	13	1127	34.082244000000003	34.115983999999997	54.680348000000002	54.661985000000001	0103000020E610000001000000050000006825ADF8860A4140A6B8AAECBB544B406825ADF8860A414013F3ACA415574B40FC6D4F90D80E414013F3ACA415574B40FC6D4F90D80E4140A6B8AAECBB544B406825ADF8860A4140A6B8AAECBB544B40
60486	Вешки	1	13	1127	34.431347000000002	34.46913	54.955226000000003	54.942557999999998	0103000020E61000000100000005000000261DE56036374140A54A94BDA5784B40261DE56036374140FB2477D8447A4B4047C9AB730C3C4140FB2477D8447A4B4047C9AB730C3C4140A54A94BDA5784B40261DE56036374140A54A94BDA5784B40
52688	Великополье	1	13	1127	34.471015999999999	34.486908	54.888232000000002	54.877634999999998	0103000020E6100000010000000500000045F295404A3C41409869FB5756704B4045F295404A3C41405EA10F96B1714B4094145800533E41405EA10F96B1714B4094145800533E41409869FB5756704B4045F295404A3C41409869FB5756704B40
54862	Большое Захарьевское	1	13	1127	33.835341999999997	33.871319	54.698732999999997	54.694294999999997	0103000020E61000000100000005000000D47C957CECEA40405E6397A8DE584B40D47C957CECEA404067D13B1570594B4014B1886187EF404067D13B1570594B4014B1886187EF40405E6397A8DE584B40D47C957CECEA40405E6397A8DE584B40
10342	Баскаковка	1	13	1127	34.331902999999997	34.357793000000001	54.623528999999998	54.605035999999998	0103000020E61000000100000005000000DE3829CC7B2A41408A73D4D1714D4B40DE3829CC7B2A4140C58D5BCCCF4F4B406EDE3829CC2D4140C58D5BCCCF4F4B406EDE3829CC2D41408A73D4D1714D4B40DE3829CC7B2A41408A73D4D1714D4B40
52680	Арнишицы	1	13	1127	34.061959999999999	34.083545999999998	54.594861000000002	54.58175	0103000020E6100000010000000500000080D4264EEE0741405839B4C8764A4B4080D4264EEE0741403B55BE67244C4B4016DBA4A2B10A41403B55BE67244C4B4016DBA4A2B10A41405839B4C8764A4B4080D4264EEE0741405839B4C8764A4B40
52623	Соколино	1	13	3320	34.409562999999999	34.4345	55.851787999999999	55.844410000000003	0103000020E610000001000000050000006953758F6C3441402B357BA015EC4B406953758F6C3441400890A16307ED4B40560E2DB29D3741400890A16307ED4B40560E2DB29D3741402B357BA015EC4B406953758F6C3441402B357BA015EC4B40
9576	Темкино	1	13	1064	34.984799000000002	35.028179000000002	55.115378	55.066968000000003	0103000020E610000001000000050000001711C5E40D7E414074F04C6892884B401711C5E40D7E4140C556D0B4C48E4B408DB7955E9B834140C556D0B4C48E4B408DB7955E9B83414074F04C6892884B401711C5E40D7E414074F04C6892884B40
9809	Селенки	1	13	1064	34.864829	34.893261000000003	55.125869999999999	55.108457000000001	0103000020E61000000100000005000000F2D077B7B26E4140DA0242EBE18D4B40F2D077B7B26E414015C616821C904B4069E55E605672414015C616821C904B4069E55E6056724140DA0242EBE18D4B40F2D077B7B26E4140DA0242EBE18D4B40
49129	Прудки	1	13	1064	34.813957000000002	34.821475999999997	54.996366000000002	54.992575000000002	0103000020E61000000100000005000000D6AC33BE2F684140E2E995B20C7F4B40D6AC33BE2F684140556CCCEB887F4B407539252026694140556CCCEB887F4B407539252026694140E2E995B20C7F4B40D6AC33BE2F684140E2E995B20C7F4B40
46638	Понизовье	1	13	1064	34.805298000000001	34.813445000000002	55.046681999999997	55.042895999999999	0103000020E6100000010000000500000061C43E01146741408A90BA9D7D854B4061C43E0114674140EBA7FFACF9854B40200C3CF71E684140EBA7FFACF9854B40200C3CF71E6841408A90BA9D7D854B4061C43E01146741408A90BA9D7D854B40
9361	Нарытка	1	13	1064	34.792892000000002	34.814272000000003	55.232263000000003	55.221322000000001	0103000020E6100000010000000500000049A12C7C7D65414052F17F47549C4B4049A12C7C7D654140128942CBBA9D4B4036069D103A684140128942CBBA9D4B4036069D103A68414052F17F47549C4B4049A12C7C7D65414052F17F47549C4B40
15584	Кикино	1	13	1064	34.772616999999997	34.801758	55.111964	55.102229999999999	0103000020E61000000100000005000000B4AA251DE5624140C55565DF158D4B40B4AA251DE5624140282A1BD6548E4B4037A79201A0664140282A1BD6548E4B4037A79201A0664140C55565DF158D4B40B4AA251DE5624140C55565DF158D4B40
15506	Замыцкое	1	13	1064	34.970874999999999	34.994923	54.985612000000003	54.972990000000003	0103000020E6100000010000000500000083C0CAA1457C4140E3AAB2EF8A7C4B4083C0CAA1457C4140C845B588287E4B40E48409A3597F4140C845B588287E4B40E48409A3597F4140E3AAB2EF8A7C4B4083C0CAA1457C4140E3AAB2EF8A7C4B40
15390	Горки	1	13	1064	35.241168999999999	35.263824999999997	55.244751999999998	55.233449	0103000020E610000001000000050000008EE733A0DE9E4140572426A8E19D4B408EE733A0DE9E4140B7D09508549F4B40006F8104C5A14140B7D09508549F4B40006F8104C5A14140572426A8E19D4B408EE733A0DE9E4140572426A8E19D4B40
9732	Власово	1	13	1064	34.923974000000001	34.948371999999999	55.061951999999998	55.049337999999999	0103000020E610000001000000050000005A2DB0C7447641409B3924B550864B405A2DB0C744764140FDF50A0BEE874B409738F24064794140FDF50A0BEE874B409738F240647941409B3924B550864B405A2DB0C7447641409B3924B550864B40
9476	Васильевское	1	13	1064	35.117398999999999	35.130586000000001	55.192435000000003	55.184514999999998	0103000020E61000000100000005000000A3CA30EE068F41408B4F01309E974B40A3CA30EE068F41408ACDC7B5A1984B4061A8C30AB79041408ACDC7B5A1984B4061A8C30AB79041408B4F01309E974B40A3CA30EE068F41408B4F01309E974B40
9743	Булгаково	1	13	1064	35.074782999999996	35.095830999999997	55.088481000000002	55.080772000000003	0103000020E61000000100000005000000FCA5457D928941405D37A5BC568A4B40FCA5457D92894140A0A86C58538B4B40B378B130448C4140A0A86C58538B4B40B378B130448C41405D37A5BC568A4B40FCA5457D928941405D37A5BC568A4B40
15446	Бекрино	1	13	1064	35.022815999999999	35.039425000000001	55.229301	55.218662000000002	0103000020E61000000100000005000000ABE97AA2EB8241406170CD1DFD9B4B40ABE97AA2EB82414055F833BC599D4B4089D2DEE00B85414055F833BC599D4B4089D2DEE00B8541406170CD1DFD9B4B40ABE97AA2EB8241406170CD1DFD9B4B40
52629	Сутормино	1	13	7207	34.382496000000003	34.407955000000001	55.725138000000001	55.716518999999998	0103000020E61000000100000005000000E86C01A1F530414037FB03E5B6DB4B40E86C01A1F53041401E8B6D52D1DC4B40AE9E93DE373441401E8B6D52D1DC4B40AE9E93DE3734414037FB03E5B6DB4B40E86C01A1F530414037FB03E5B6DB4B40
52637	Хлепень	1	13	1051	34.453850000000003	34.468572999999999	55.967646999999999	55.948774999999998	0103000020E6100000010000000500000012A5BDC1173A414096218E7571F94B4012A5BDC1173A414048895DDBDBFB4B40F1643733FA3B414048895DDBDBFB4B40F1643733FA3B414096218E7571F94B4012A5BDC1173A414096218E7571F94B40
60541	Софьино	1	13	1051	34.532389000000002	34.558827000000001	55.748331	55.739168999999997	0103000020E6100000010000000500000005E09F5225444140C79BFC169DDE4B4005E09F52254441409FCA694FC9DF4B40978FA4A4874741409FCA694FC9DF4B40978FA4A487474140C79BFC169DDE4B4005E09F5225444140C79BFC169DDE4B40
54880	Середа	1	13	1051	34.121355999999999	34.137264999999999	55.956522	55.939363	0103000020E610000001000000050000003196E997880F41404609FA0B3DF84B403196E997880F4140C7F319506FFA4B4056F146E691114140C7F319506FFA4B4056F146E6911141404609FA0B3DF84B403196E997880F41404609FA0B3DF84B40
47845	Павлово	1	13	1051	33.730975000000001	33.740309000000003	55.944293999999999	55.939086000000003	0103000020E61000000100000005000000C898BB9690DD4040D41055F833F84B40C898BB9690DD40408EE733A0DEF84B409DF7FF71C2DE40408EE733A0DEF84B409DF7FF71C2DE4040D41055F833F84B40C898BB9690DD4040D41055F833F84B40
54886	Никитье	1	13	1051	34.171850999999997	34.201009999999997	55.915239999999997	55.900112999999997	0103000020E610000001000000050000007764AC36FF1541402BDA1CE736F34B407764AC36FF154140DAFE959526F54B40A01518B2BA194140DAFE959526F54B40A01518B2BA1941402BDA1CE736F34B407764AC36FF1541402BDA1CE736F34B40
46515	Мальцево	1	13	1051	34.267746000000002	34.299644999999998	55.816192000000001	55.803832999999997	0103000020E6100000010000000500000042D13C80452241400839EFFFE3E64B4042D13C8045224140E0A0BDFA78E84B4078B471C45A264140E0A0BDFA78E84B4078B471C45A2641400839EFFFE3E64B4042D13C80452241400839EFFFE3E64B40
53063	Лукино	1	13	1051	34.185676000000001	34.227986000000001	55.792411999999999	55.776359999999997	0103000020E6100000010000000500000078D32D3BC417414016F6B4C35FE34B4078D32D3BC41741409E7AA4C16DE54B4012F92EA52E1D41409E7AA4C16DE54B4012F92EA52E1D414016F6B4C35FE34B4078D32D3BC417414016F6B4C35FE34B40
52609	Елманово	1	13	1051	34.297893000000002	34.313963999999999	55.821491999999999	55.809443999999999	0103000020E610000001000000050000008A5A9A5B21264140C2F869DC9BE74B408A5A9A5B212641407BF65CA626E94B40880FECF82F2841407BF65CA626E94B40880FECF82F284140C2F869DC9BE74B408A5A9A5B21264140C2F869DC9BE74B40
54836	Дугино	1	13	1051	34.179701999999999	34.225147999999997	55.70008	55.684209000000003	0103000020E610000001000000050000004D83A279001741407F50172994D74B404D83A27900174140B64AB0389CD94B40416150A6D11C4140B64AB0389CD94B40416150A6D11C41407F50172994D74B404D83A279001741407F50172994D74B40
47496	Дроздово	1	13	1051	34.362257	34.368634999999998	55.873823999999999	55.871136999999997	0103000020E61000000100000005000000A0DFF76F5E2E4140F3AACE6A81EF4B40A0DFF76F5E2E4140DE3AFF76D9EF4B409A94826E2F2F4140DE3AFF76D9EF4B409A94826E2F2F4140F3AACE6A81EF4B40A0DFF76F5E2E4140F3AACE6A81EF4B40
60544	Вараксино	1	13	1051	34.262813999999999	34.285541000000002	56.018735	56.003135	0103000020E6100000010000000500000029779FE3A32141408A3C49BA66004C4029779FE3A3214140312592E865024C406555849B8C244140312592E865024C406555849B8C2441408A3C49BA66004C4029779FE3A32141408A3C49BA66004C40
52600	Большая Моховатка	1	13	1051	34.103622999999999	34.114179	55.828024999999997	55.819408000000003	0103000020E61000000100000005000000840EBA84430D4140570A815CE2E84B40840EBA84430D41409CA223B9FCE94B40EB71DF6A9D0E41409CA223B9FCE94B40EB71DF6A9D0E4140570A815CE2E84B40840EBA84430D4140570A815CE2E84B40
52597	Бехтеево	1	13	1051	33.963343000000002	33.991056	55.785907999999999	55.775838999999998	0103000020E610000001000000050000004FEACBD24EFB40400DFB3DB14EE34B404FEACBD24EFB404017D522A298E44B4096404AECDAFE404017D522A298E44B4096404AECDAFE40400DFB3DB14EE34B404FEACBD24EFB40400DFB3DB14EE34B40
52620	Субботники	1	13	7204	34.306418000000001	34.319498000000003	54.838850999999998	54.833292999999998	0103000020E61000000100000005000000EF737CB4382741402C7E5358A96A4B40EF737CB438274140C39B35785F6B4B4097917A4FE5284140C39B35785F6B4B4097917A4FE52841402C7E5358A96A4B40EF737CB4382741402C7E5358A96A4B40
52636	Ромоданово	1	13	7210	39.798681999999999	39.837336000000001	54.308629000000003	54.29457	0103000020E61000000100000005000000B2F336363BE64340FD304278B4254B40B2F336363BE6434071CCB22781274B40B9E177D32DEB434071CCB22781274B40B9E177D32DEB4340FD304278B4254B40B2F336363BE64340FD304278B4254B40
7565	Чекулино	1	13	452	31.722287999999999	31.740632000000002	54.755425000000002	54.745921000000003	0103000020E61000000100000005000000124BCADDE7B83F402733DE567A5F4B40124BCADDE7B83F4058CA32C4B1604B40FF5E0A0F9ABD3F4058CA32C4B1604B40FF5E0A0F9ABD3F402733DE567A5F4B40124BCADDE7B83F402733DE567A5F4B40
54843	Хохлово	1	13	452	31.815712999999999	31.848258999999999	54.706516000000001	54.694986999999998	0103000020E610000001000000050000000BEC3191D2D03F4094128255F5584B400BEC3191D2D03F40E50CC51D6F5A4B40A489778027D93F40E50CC51D6F5A4B40A489778027D93F4094128255F5584B400BEC3191D2D03F4094128255F5584B40
7321	Талашкино	1	13	452	32.170862	32.196662000000003	54.662447999999998	54.644119000000003	0103000020E61000000100000005000000881057CEDE154040BADDCB7D72524B40881057CEDE1540407AA69718CB544B40D82E6D382C1940407AA69718CB544B40D82E6D382C194040BADDCB7D72524B40881057CEDE154040BADDCB7D72524B40
46102	Сметанино	1	13	452	31.625503999999999	31.655328000000001	54.788978999999998	54.776741999999999	0103000020E610000001000000050000006684B70721A03F40FEB627486C634B406684B70721A03F408A1D8D43FD644B4031276893C3A73F408A1D8D43FD644B4031276893C3A73F40FEB627486C634B406684B70721A03F40FEB627486C634B40
60508	Санники	1	13	452	31.880759999999999	31.904575000000001	54.551876999999998	54.538753	0103000020E61000000100000005000000FD9FC37C79E13F409ACFB9DBF5444B40FD9FC37C79E13F401135D1E7A3464B407AC7293A92E73F401135D1E7A3464B407AC7293A92E73F409ACFB9DBF5444B40FD9FC37C79E13F409ACFB9DBF5444B40
54842	Санаторий Борок	1	13	452	31.341079000000001	32.323754999999998	55.207715999999998	54.509616999999999	0103000020E61000000100000005000000365A0EF450573F40293E3E213B414B40365A0EF450573F408F6D1970969A4B404F75C8CD702940408F6D1970969A4B404F75C8CD70294040293E3E213B414B40365A0EF450573F40293E3E213B414B40
45823	Русилово	1	13	452	31.941009999999999	31.961402	54.63523	54.618138999999999	0103000020E610000001000000050000007E350708E6F03F40EAB0C22D1F4F4B407E350708E6F03F4013B875374F514B401A4F04711EF63F4013B875374F514B401A4F04711EF63F40EAB0C22D1F4F4B407E350708E6F03F40EAB0C22D1F4F4B40
45653	Рогачево	1	13	452	32.153803000000003	32.298675000000003	54.849317999999997	54.763207000000001	0103000020E610000001000000050000006B8313D1AF134040058A58C4B0614B406B8313D1AF134040BAF3C473B66C4B4000917EFB3A264040BAF3C473B66C4B4000917EFB3A264040058A58C4B0614B406B8313D1AF134040058A58C4B0614B40
7028	Пригорское	1	13	452	32.134076	32.170735999999998	54.697526000000003	54.677447999999998	0103000020E61000000100000005000000D996016729114040CC5EB69DB6564B40D9960167291140400B0E2F8848594B40FB1F60ADDA1540400B0E2F8848594B40FB1F60ADDA154040CC5EB69DB6564B40D996016729114040CC5EB69DB6564B40
46126	Почаево	1	13	452	31.555292000000001	31.576733999999998	54.807907	54.796759999999999	0103000020E61000000100000005000000FEBAD39D278E3F4067614F3BFC654B40FEBAD39D278E3F40D09A1F7F69674B40C37DE4D6A4933F40D09A1F7F69674B40C37DE4D6A4933F4067614F3BFC654B40FEBAD39D278E3F4067614F3BFC654B40
3690	Печерск	1	13	452	32.020808000000002	32.041882000000001	54.859138999999999	54.845455999999999	0103000020E6100000010000000500000062BF27D6A90240407E1AF7E6376C4B4062BF27D6A9024040ECDB4944F86D4B404225AE635C054040ECDB4944F86D4B404225AE635C0540407E1AF7E6376C4B4062BF27D6A90240407E1AF7E6376C4B40
48429	Ольша	1	13	452	31.842357	31.854870999999999	54.851433	54.840656000000003	0103000020E61000000100000005000000828E56B5A4D73F40D597A59D9A6B4B40828E56B5A4D73F401ADEACC1FB6C4B407F4C6BD3D8DA3F401ADEACC1FB6C4B407F4C6BD3D8DA3F40D597A59D9A6B4B40828E56B5A4D73F40D597A59D9A6B4B40
16248	Озерище	1	13	452	31.641134999999998	31.648869000000001	55.093643	55.084826999999997	0103000020E610000001000000050000002A52616C21A43F40AD68739CDB8A4B402A52616C21A43F40EA3F6B7EFC8B4B4063635E471CA63F40EA3F6B7EFC8B4B4063635E471CA63F40AD68739CDB8A4B402A52616C21A43F40AD68739CDB8A4B40
46217	Новосельский	1	13	452	31.633616	31.648878	54.973987000000001	54.962318000000003	0103000020E61000000100000005000000EB387EA834A23F40132D793C2D7B4B40EB387EA834A23F4055DD239BAB7C4B4009185DDE1CA63F4055DD239BAB7C4B4009185DDE1CA63F40132D793C2D7B4B40EB387EA834A23F40132D793C2D7B4B40
46017	Новоселки	1	13	452	31.955787999999998	31.965479999999999	54.968200000000003	54.963020999999998	0103000020E61000000100000005000000C4E8B985AEF43F403C2EAA45447B4B40C4E8B985AEF43F405DFE43FAED7B4B402CF180B229F73F405DFE43FAED7B4B402CF180B229F73F403C2EAA45447B4B40C4E8B985AEF43F403C2EAA45447B4B40
7634	Новое Куприно	1	13	452	31.685314000000002	31.714248999999999	54.817281999999999	54.803978999999998	0103000020E61000000100000005000000AF7D01BD70AF3F40DCD5ABC8E8664B40AF7D01BD70AF3F4003CE52B29C684B406133C005D9B63F4003CE52B29C684B406133C005D9B63F40DCD5ABC8E8664B40AF7D01BD70AF3F40DCD5ABC8E8664B40
45998	Нивищи	1	13	452	31.789176999999999	31.809388999999999	54.810974000000002	54.805027000000003	0103000020E6100000010000000500000061C1FD8007CA3F40D1B2EE1F0B674B4061C1FD8007CA3F4002F4FBFECD674B40FDBD141E34CF3F4002F4FBFECD674B40FDBD141E34CF3F40D1B2EE1F0B674B4061C1FD8007CA3F40D1B2EE1F0B674B40
6147	Мощинки	1	13	452	32.057001	32.076638000000003	54.964720999999997	54.953034000000002	0103000020E610000001000000050000006E6B0BCF4B074040F0FCA204FD794B406E6B0BCF4B074040D8614CFA7B7B4B40C0D02346CF094040D8614CFA7B7B4B40C0D02346CF094040F0FCA204FD794B406E6B0BCF4B074040F0FCA204FD794B40
7229	Моготово	1	13	452	32.011259000000003	32.025829000000002	54.602485999999999	54.593097999999998	0103000020E61000000100000005000000916456EF7001404058A9A0A2EA4B4B40916456EF700140402026E1421E4D4B40EA245B5D4E0340402026E1421E4D4B40EA245B5D4E03404058A9A0A2EA4B4B40916456EF7001404058A9A0A2EA4B4B40
6690	Мазальцево	1	13	452	32.071589000000003	32.092528999999999	55.031787999999999	55.016874000000001	0103000020E610000001000000050000006EE00ED4290940408C135FED28824B406EE00ED429094040DF3312A111844B403E7782FDD70B4040DF3312A111844B403E7782FDD70B40408C135FED28824B406EE00ED4290940408C135FED28824B40
6876	Магалинщина	1	13	452	32.094504999999998	32.113900000000001	54.831347999999998	54.819527999999998	0103000020E610000001000000050000007C2766BD180C40400114234BE6684B407C2766BD180C404029CC7B9C696A4B40D8817346940E404029CC7B9C696A4B40D8817346940E40400114234BE6684B407C2766BD180C40400114234BE6684B40
7506	Лубня	1	13	452	31.877257	31.895330999999999	54.722695999999999	54.710650999999999	0103000020E61000000100000005000000E42F2DEA93E03F4052EFA99CF65A4B40E42F2DEA93E03F409A79724D815C4B405018946934E53F409A79724D815C4B405018946934E53F4052EFA99CF65A4B40E42F2DEA93E03F4052EFA99CF65A4B40
46318	Лойно	1	13	452	31.465819	31.486148	55.043407000000002	55.025219	0103000020E61000000100000005000000FDDAFAE93F773F40711E4E603A834B40FDDAFAE93F773F4070B54E5C8E854B400C040132747C3F4070B54E5C8E854B400C040132747C3F40711E4E603A834B40FDDAFAE93F773F40711E4E603A834B40
45546	Кузино	1	13	452	31.512649	31.534648000000001	54.685223999999998	54.673001999999997	0103000020E61000000100000005000000BD5301F73C833F404012F6ED24564B40BD5301F73C833F409737876BB5574B402FDFFAB0DE883F409737876BB5574B402FDFFAB0DE883F404012F6ED24564B40BD5301F73C833F404012F6ED24564B40
7215	Кощино	1	13	452	32.173412999999996	32.194415999999997	54.603873	54.591298000000002	0103000020E61000000100000005000000C2D9AD6532164040591822A7AF4B4B40C2D9AD6532164040FDF7E0B54B4D4B40D9E89C9FE2184040FDF7E0B54B4D4B40D9E89C9FE2184040591822A7AF4B4B40C2D9AD6532164040591822A7AF4B4B40
7759	Катынь	1	13	452	31.673932000000001	31.738593000000002	54.781903	54.758313999999999	0103000020E6100000010000000500000056BABBCE86AC3F40AA0CE36E10614B4056BABBCE86AC3F4078D2C26515644B40F60D4C6E14BD3F4078D2C26515644B40F60D4C6E14BD3F40AA0CE36E10614B4056BABBCE86AC3F40AA0CE36E10614B40
8219	Каспля	1	13	452	31.605822	31.648627000000001	54.999521000000001	54.977248000000003	0103000020E6100000010000000500000083328D26179B3F406C0A6476167D4B4083328D26179B3F402655DB4DF07F4B40774D486B0CA63F402655DB4DF07F4B40774D486B0CA63F406C0A6476167D4B4083328D26179B3F406C0A6476167D4B40
54896	Замощье	1	13	452	31.501483	31.535420999999999	54.862886000000003	54.853361	0103000020E61000000100000005000000FE7F9C3061803F404757E9EE3A6D4B40FE7F9C3061803F409016670C736E4B407497C45911893F409016670C736E4B407497C45911893F404757E9EE3A6D4B40FE7F9C3061803F404757E9EE3A6D4B40
49303	Жуково	1	13	452	32.006974	32.039115000000002	54.919061999999997	54.881194000000001	0103000020E610000001000000050000000EF62686E400404039B709F7CA704B400EF62686E4004040887FD8D2A3754B403BE466B801054040887FD8D2A3754B403BE466B80105404039B709F7CA704B400EF62686E400404039B709F7CA704B40
7126	Дрюцк	1	13	452	32.045763000000001	32.058177999999998	54.687638999999997	54.679592999999997	0103000020E61000000100000005000000F52EDE8FDB05404096CB46E7FC564B40F52EDE8FDB054040213A048E04584B4060AC6F6072074040213A048E04584B4060AC6F607207404096CB46E7FC564B40F52EDE8FDB05404096CB46E7FC564B40
2561	Дивасы	1	13	452	31.970196999999999	31.984452999999998	54.863394	54.854579000000001	0103000020E6100000010000000500000064ADA1D45EF83F40986C3CD8626D4B4064ADA1D45EF83F4004C8D0B1836E4B40F7729F1C05FC3F4004C8D0B1836E4B40F7729F1C05FC3F40986C3CD8626D4B4064ADA1D45EF83F40986C3CD8626D4B40
49323	Горяны	1	13	452	32.114851999999999	32.184831000000003	54.724348999999997	54.604353000000003	0103000020E61000000100000005000000AAF06778B30E4040A81E69705B4D4B40AAF06778B30E4040F5F1D077B75C4B40BC24CE8AA8174040F5F1D077B75C4B40BC24CE8AA8174040A81E69705B4D4B40AAF06778B30E4040A81E69705B4D4B40
8044	Вязгино	1	13	452	31.921032	31.948906000000001	55.054166000000002	55.043303999999999	0103000020E61000000100000005000000C991CEC0C8EB3F409BE447FC8A854B40C991CEC0C8EB3F400F4757E9EE864B406AFAEC80EBF23F400F4757E9EE864B406AFAEC80EBF23F409BE447FC8A854B40C991CEC0C8EB3F409BE447FC8A854B40
46062	Высокий Холм	1	13	452	31.441592	31.462999	54.718083	54.709454999999998	0103000020E61000000100000005000000DC2C5E2C0C713F40E97DE36BCF5A4B40DC2C5E2C0C713F402368CC24EA5B4B40A9143B1A87763F402368CC24EA5B4B40A9143B1A87763F40E97DE36BCF5A4B40DC2C5E2C0C713F40E97DE36BCF5A4B40
8305	Волоковая	1	13	452	31.552938000000001	31.577245999999999	54.925044	54.913893000000002	0103000020E6100000010000000500000035B742588D8D3F408C852172FA744B4035B742588D8D3F4036AE7FD767764B402FBFD364C6933F4036AE7FD767764B402FBFD364C6933F408C852172FA744B4035B742588D8D3F408C852172FA744B40
60502	Верховье	1	13	452	31.742842	31.770258999999999	54.918297000000003	54.903939999999999	0103000020E610000001000000050000006118B0E42ABE3F40EBC5504EB4734B406118B0E42ABE3F40E9818FC18A754B401D739EB12FC53F40E9818FC18A754B401D739EB12FC53F40EBC5504EB4734B406118B0E42ABE3F40EBC5504EB4734B40
45688	Бубново	1	13	452	32.235433	32.256517000000002	54.709750999999997	54.696084999999997	0103000020E6100000010000000500000018B325AB221E40403A1E335019594B4018B325AB221E4040D2A6EA1ED95A4B401CEF8E8CD5204040D2A6EA1ED95A4B401CEF8E8CD52040403A1E335019594B4018B325AB221E40403A1E335019594B40
8428	Бабны	1	13	452	31.546578	31.579474000000001	55.123600000000003	55.113106999999999	0103000020E610000001000000050000008DB62A89EC8B3F406EF9484A7A8E4B408DB62A89EC8B3F408FE4F21FD28F4B40DFE1766858943F408FE4F21FD28F4B40DFE1766858943F406EF9484A7A8E4B408DB62A89EC8B3F406EF9484A7A8E4B40
8039	Аполье	1	13	452	31.856954999999999	31.886465000000001	55.065648000000003	55.050597000000003	0103000020E61000000100000005000000C824236761DB3F404B2366F679864B40C824236761DB3F401F86562767884B40740CC85EEFE23F401F86562767884B40740CC85EEFE23F404B2366F679864B40C824236761DB3F404B2366F679864B40
54815	Авторемзавод	1	13	452	31.341079000000001	32.323754999999998	55.207715999999998	54.509616999999999	0103000020E61000000100000005000000365A0EF450573F40293E3E213B414B40365A0EF450573F408F6D1970969A4B404F75C8CD702940408F6D1970969A4B404F75C8CD70294040293E3E213B414B40365A0EF450573F40293E3E213B414B40
60470	Холм	1	13	1173	33.041086999999997	33.053331	55.098547000000003	55.095388999999997	0103000020E6100000010000000500000037A5BC5642854040F6B2EDB4358C4B4037A5BC5642854040390F27309D8C4B40766EDA8CD3864040390F27309D8C4B40766EDA8CD3864040F6B2EDB4358C4B4037A5BC5642854040F6B2EDB4358C4B40
53056	Уварово	1	13	1173	33.731020000000001	33.737290999999999	55.167580000000001	55.162714999999999	0103000020E61000000100000005000000685C381092DD4040C9C859D8D3944B40685C381092DD40405ABBED4273954B404C512E8D5FDE40405ABBED4273954B404C512E8D5FDE4040C9C859D8D3944B40685C381092DD4040C9C859D8D3944B40
48611	Татарка	1	13	1173	33.621353999999997	33.632646000000001	55.120474999999999	55.116711000000002	0103000020E61000000100000005000000909E228788CF4040AF0AD462F08E4B40909E228788CF4040287E8CB96B8F4B40FDF84B8BFAD04040287E8CB96B8F4B40FDF84B8BFAD04040AF0AD462F08E4B40909E228788CF4040AF0AD462F08E4B40
60535	Старое Село	1	13	1173	33.803173000000001	33.829636999999998	55.327233999999997	55.313977000000001	0103000020E61000000100000005000000DE03745FCEE640401D59F96530A84B40DE03745FCEE64040D311C0CDE2A94B409946938B31EA4040D311C0CDE2A94B409946938B31EA40401D59F96530A84B40DE03745FCEE640401D59F96530A84B40
45598	Синьково	1	13	1173	33.787478999999998	33.795959000000003	55.293360999999997	55.287086000000002	0103000020E61000000100000005000000B5A4A31CCCE44040DA91EA3BBFA44B40B5A4A31CCCE44040FF756EDA8CA54B407BFA08FCE1E54040FF756EDA8CA54B407BFA08FCE1E54040DA91EA3BBFA44B40B5A4A31CCCE44040DA91EA3BBFA44B40
16147	Сафоново	1	13	1173	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
32164	Рыбки	1	13	1173	32.966141	32.996943999999999	55.156399	55.142215999999998	0103000020E6100000010000000500000091291F82AA7B4040E57B462234924B4091291F82AA7B40404510E7E104944B40C2F869DC9B7F40404510E7E104944B40C2F869DC9B7F4040E57B462234924B4091291F82AA7B4040E57B462234924B40
11147	Путьково	1	13	1173	33.658194000000002	33.680444999999999	55.086109999999998	55.080008999999997	0103000020E61000000100000005000000333674B33FD440405D3123BC3D8A4B40333674B33FD44040E5ED08A7058B4B4005DD5ED218D74040E5ED08A7058B4B4005DD5ED218D740405D3123BC3D8A4B40333674B33FD440405D3123BC3D8A4B40
31946	Николо-Погорелое	1	13	1173	33.479950000000002	33.51202	55.245942999999997	55.229424000000002	0103000020E610000001000000050000008CDB68006FBD4040717500C45D9D4B408CDB68006FBD40400ED76A0F7B9F4B40EF7211DF89C140400ED76A0F7B9F4B40EF7211DF89C14040717500C45D9D4B408CDB68006FBD4040717500C45D9D4B40
22902	Монастырщина	1	13	1173	33.463726999999999	33.476258000000001	55.090912000000003	55.088217999999998	0103000020E61000000100000005000000D7A205685BBB4040927538BA4A8B4B40D7A205685BBB404030682101A38B4B40AC3AAB05F6BC404030682101A38B4B40AC3AAB05F6BC4040927538BA4A8B4B40D7A205685BBB4040927538BA4A8B4B40
47341	Мишенино	1	13	1173	33.271980999999997	33.288941000000001	55.156826000000002	55.148940000000003	0103000020E610000001000000050000001211FE45D0A240407B88467710934B401211FE45D0A24040CD94D6DF12944B409DBCC804FCA44040CD94D6DF12944B409DBCC804FCA440407B88467710934B401211FE45D0A240407B88467710934B40
49066	Мальцево	1	13	1173	33.756892000000001	33.772019	55.333005999999997	55.328831999999998	0103000020E61000000100000005000000514D49D6E1E040406BF0BE2A17AA4B40514D49D6E1E0404096AFCBF09FAA4B400072C284D1E2404096AFCBF09FAA4B400072C284D1E240406BF0BE2A17AA4B40514D49D6E1E040406BF0BE2A17AA4B40
47423	Лесное	1	13	1173	33.145211000000003	33.174846000000002	55.268814999999996	55.254204999999999	0103000020E610000001000000050000007E0228469692404066BD18CA89A04B407E022846969240404DD6A88768A24B4010EB8D5A619640404DD6A88768A24B4010EB8D5A6196404066BD18CA89A04B407E0228469692404066BD18CA89A04B40
31888	Казулино	1	13	1173	33.517418999999997	33.546084	55.341853	55.324621999999998	0103000020E610000001000000050000001DAA29C93AC24040F3C7B4368DA94B401DAA29C93AC240400E85CFD6C1AB4B40376F9C14E6C540400E85CFD6C1AB4B40376F9C14E6C54040F3C7B4368DA94B401DAA29C93AC24040F3C7B4368DA94B40
31164	Издешково	1	13	1173	33.599803000000001	33.648744000000001	55.156770000000002	55.13111	0103000020E6100000010000000500000077853E58C6CC4040DB166536C8904B4077853E58C6CC4040397F130A11944B40F5BC1B0B0AD34040397F130A11944B40F5BC1B0B0AD34040DB166536C8904B4077853E58C6CC4040DB166536C8904B40
47567	Игнатково	1	13	1173	33.643766999999997	33.662568999999998	55.080044999999998	55.070041000000003	0103000020E610000001000000050000003C9F01F566D2404088307E1AF7884B403C9F01F566D24040AA9A20EA3E8A4B40F52B9D0FCFD44040AA9A20EA3E8A4B40F52B9D0FCFD4404088307E1AF7884B403C9F01F566D2404088307E1AF7884B40
31750	Дурово	1	13	1173	33.271469000000003	33.376815000000001	55.187902000000001	55.131253999999998	0103000020E610000001000000050000005D70067FBFA240400EBC5AEECC904B405D70067FBFA240402F6D382C0D984B4035D252793BB040402F6D382C0D984B4035D252793BB040400EBC5AEECC904B405D70067FBFA240400EBC5AEECC904B40
60476	Высокое	1	13	1173	33.268711000000003	33.284188999999998	55.070050999999999	55.060904999999998	0103000020E61000000100000005000000A9893E1F65A24040D9942BBCCB874B40A9893E1F65A24040AB06616EF7884B4004711E4E60A44040AB06616EF7884B4004711E4E60A44040D9942BBCCB874B40A9893E1F65A24040D9942BBCCB874B40
31474	Вадино	1	13	1173	33.228943000000001	33.275466999999999	55.267287000000003	55.251280000000001	0103000020E61000000100000005000000F6D214014E9D4040C7116BF129A04B40F6D214014E9D4040AFD2DD7536A24B404910AE8042A34040AFD2DD7536A24B404910AE8042A34040C7116BF129A04B40F6D214014E9D4040C7116BF129A04B40
47401	Богдановщина	1	13	1173	33.656154999999998	33.677571	55.282640999999998	55.267204999999997	0103000020E61000000100000005000000AE0D15E3FCD34040F12900C633A24B40AE0D15E3FCD340401EC18D942DA44B40E8DB82A5BAD640401EC18D942DA44B40E8DB82A5BAD64040F12900C633A24B40AE0D15E3FCD34040F12900C633A24B40
31312	Беленино	1	13	1173	33.320633999999998	33.337558000000001	55.228757000000002	55.210988	0103000020E610000001000000050000002AFEEF880AA940409AEC9FA7019B4B402AFEEF880AA9404094DDCCE8479D4B406840BD1935AB404094DDCCE8479D4B406840BD1935AB40409AEC9FA7019B4B402AFEEF880AA940409AEC9FA7019B4B40
47543	Алферово	1	13	1173	33.762065999999997	33.79242	55.164597999999998	55.144283999999999	0103000020E610000001000000050000005FB2F1608BE1404004ABEAE577924B405FB2F1608BE14040567E198C11954B402159C0046EE54040567E198C11954B402159C0046EE5404004ABEAE577924B405FB2F1608BE1404004ABEAE577924B40
29114	Шубки	1	13	170	31.046675	31.060400999999999	54.877510999999998	54.870305000000002	0103000020E61000000100000005000000728A8EE4F20B3F40CC457C27666F4B40728A8EE4F20B3F40AC70CB4752704B404CA59F70760F3F40AC70CB4752704B404CA59F70760F3F40CC457C27666F4B40728A8EE4F20B3F40CC457C27666F4B40
29554	Чистик	1	13	170	31.187170999999999	31.208407000000001	54.954135000000001	54.944941999999998	0103000020E6100000010000000500000076C24B70EA2F3F40F44E05DCF3784B4076C24B70EA2F3F40077C7E18217A4B40EA4141295A353F40077C7E18217A4B40EA4141295A353F40F44E05DCF3784B4076C24B70EA2F3F40F44E05DCF3784B40
46693	Узгорки	1	13	170	30.991743	31.012125000000001	55.212677999999997	55.197023999999999	0103000020E61000000100000005000000740987DEE2FD3E4078431A1538994B40740987DEE2FD3E40124A5F08399B4B40C976BE9F1A033F40124A5F08399B4B40C976BE9F1A033F4078431A1538994B40740987DEE2FD3E4078431A1538994B40
28843	Суфляново	1	13	170	31.306629000000001	31.319420999999998	54.904592000000001	54.899571000000002	0103000020E610000001000000050000005401F73C7F4E3F400BB77C2425734B405401F73C7F4E3F40931CB0ABC9734B40D6A71C93C5513F40931CB0ABC9734B40D6A71C93C5513F400BB77C2425734B405401F73C7F4E3F400BB77C2425734B40
28748	Сташки	1	13	170	31.2545	31.271288999999999	54.870362	54.863176000000003	0103000020E61000000100000005000000FED478E926413F409758198D7C6E4B40FED478E926413F4030D7A205686F4B40B9C3263273453F4030D7A205686F4B40B9C3263273453F409758198D7C6E4B40FED478E926413F409758198D7C6E4B40
46487	Стаи	1	13	170	30.935462999999999	30.968942999999999	55.020795999999997	55.003740000000001	0103000020E61000000100000005000000389ECF807AEF3E40F1D7648D7A804B40389ECF807AEF3E409DF17D71A9824B4029B000A60CF83E409DF17D71A9824B4029B000A60CF83E40F1D7648D7A804B40389ECF807AEF3E40F1D7648D7A804B40
28854	Смолиговка	1	13	170	31.346209000000002	31.36917	54.849519999999998	54.825612999999997	0103000020E61000000100000005000000B4942C27A1583F408313D1AFAD694B40B4942C27A1583F4022A64412BD6C4B4011AAD4EC815E3F4022A64412BD6C4B4011AAD4EC815E3F408313D1AFAD694B40B4942C27A1583F408313D1AFAD694B40
46293	Приволье	1	13	170	31.23939	31.258075000000002	54.796703000000001	54.783740999999999	0103000020E610000001000000050000004CFDBCA9483D3F4065C405A051644B404CFDBCA9483D3F4003D0285DFA654B404BEA043411423F4003D0285DFA654B404BEA043411423F4065C405A051644B404CFDBCA9483D3F4065C405A051644B40
29369	Переволочье	1	13	170	31.110544999999998	31.136424999999999	55.008536999999997	54.992373999999998	0103000020E610000001000000050000007FBC57AD4C1C3F404AB3791C067F4B407FBC57AD4C1C3F4029E78BBD17814B40575BB1BFEC223F4029E78BBD17814B40575BB1BFEC223F404AB3791C067F4B407FBC57AD4C1C3F404AB3791C067F4B40
29651	Никонцы	1	13	170	31.243594000000002	31.263797	55.384681999999998	55.372656999999997	0103000020E610000001000000050000007880272D5C3E3F400FD07D39B3AF4B407880272D5C3E3F4010AE80423DB14B406DC83F3388433F4010AE80423DB14B406DC83F3388433F400FD07D39B3AF4B407880272D5C3E3F400FD07D39B3AF4B40
29205	Могильно	1	13	170	30.887125000000001	30.901164999999999	54.933366999999997	54.926336999999997	0103000020E61000000100000005000000C976BE9F1AE33E409109F83592764B40C976BE9F1AE33E403315E29178774B40C24CDBBFB2E63E403315E29178774B40C24CDBBFB2E63E409109F83592764B40C976BE9F1AE33E409109F83592764B40
52027	Любавичи	1	13	170	30.94415	30.967533	54.840282000000002	54.82443	0103000020E61000000100000005000000B6847CD0B3F13E40AFEB17EC86694B40B6847CD0B3F13E4070B54E5C8E6B4B40FFCC203EB0F73E4070B54E5C8E6B4B40FFCC203EB0F73E40AFEB17EC86694B40B6847CD0B3F13E40AFEB17EC86694B40
29559	Лешно	1	13	170	31.257149999999999	31.284602	54.955354999999997	54.936816999999998	0103000020E61000000100000005000000992A1895D4413F401DAB949EE9774B40992A1895D4413F40F8889812497A4B404E603AADDB483F40F8889812497A4B404E603AADDB483F401DAB949EE9774B40992A1895D4413F401DAB949EE9774B40
29289	Кругловка	1	13	170	30.998964999999998	31.027432999999998	54.977159999999998	54.964467999999997	0103000020E6100000010000000500000040D9942BBCFF3E40EE04FBAF737B4B4040D9942BBCFF3E40CC7A3194137D4B40C7D45DD905073F40CC7A3194137D4B40C7D45DD905073F40EE04FBAF737B4B4040D9942BBCFF3E40EE04FBAF737B4B40
40472	Красный Двор	1	13	170	31.089981999999999	31.112126	54.969268999999997	54.957934000000002	0103000020E610000001000000050000008A3A730F09173F40FDDCD0949D7A4B408A3A730F09173F406803B001117C4B4003081F4AB41C3F406803B001117C4B4003081F4AB41C3F40FDDCD0949D7A4B408A3A730F09173F40FDDCD0949D7A4B40
29923	Кляриново	1	13	170	31.075403000000001	31.094815000000001	55.163913999999998	55.150292999999998	0103000020E6100000010000000500000032056B9C4D133F40ABE80FCD3C934B4032056B9C4D133F40A3AD4A22FB944B40952BBCCB45183F40A3AD4A22FB944B40952BBCCB45183F40ABE80FCD3C934B4032056B9C4D133F40ABE80FCD3C934B40
29417	Карташевичи	1	13	170	31.170273999999999	31.188707000000001	55.078906000000003	55.063993000000004	0103000020E61000000100000005000000EE5BAD13972B3F40231631EC30884B40EE5BAD13972B3F40A6BA8097198A4B40BA86191A4F303F40A6BA8097198A4B40BA86191A4F303F40231631EC30884B40EE5BAD13972B3F40231631EC30884B40
29122	Казимирово	1	13	170	31.083110000000001	31.125412000000001	54.818697999999998	54.804015	0103000020E6100000010000000500000077F86BB246153F40293FA9F6E9664B4077F86BB246153F407AA69718CB684B40A58636001B203F407AA69718CB684B40A58636001B203F40293FA9F6E9664B4077F86BB246153F40293FA9F6E9664B40
49508	Заборье	1	13	170	31.031987000000001	31.065773	55.043097000000003	55.029637000000001	0103000020E61000000100000005000000ACE5CE4C30083F4033E02C25CB834B40ACE5CE4C30083F4022C7D63384854B40B6F5D37FD6103F4022C7D63384854B40B6F5D37FD6103F4033E02C25CB834B40ACE5CE4C30083F4033E02C25CB834B40
48056	Ефремово	1	13	170	30.968081000000002	30.983872999999999	54.807341999999998	54.799385999999998	0103000020E6100000010000000500000005E10A28D4F73E40AC70CB4752664B4005E10A28D4F73E40F7578FFB56674B40DB6AD619DFFB3E40F7578FFB56674B40DB6AD619DFFB3E40AC70CB4752664B4005E10A28D4F73E40AC70CB4752664B40
54871	Гранки	1	13	170	30.749521000000001	31.581792	55.454197999999998	54.725098000000003	0103000020E610000001000000050000004CAAB69BE0BF3E409032E202D05C4B404CAAB69BE0BF3E404DF4F92823BA4B400E130D52F0943F404DF4F92823BA4B400E130D52F0943F409032E202D05C4B404CAAB69BE0BF3E409032E202D05C4B40
28566	Голынки	1	13	170	31.347978000000001	31.451975999999998	54.874875000000003	54.842734999999998	0103000020E610000001000000050000003DBA111615593F40E71890BDDE6B4B403DBA111615593F40448B6CE7FB6F4B40AF93FAB2B4733F40448B6CE7FB6F4B40AF93FAB2B4733F40E71890BDDE6B4B403DBA111615593F40E71890BDDE6B4B40
47482	Волково	1	13	170	30.899692000000002	30.931996000000002	54.786524	54.770313000000002	0103000020E610000001000000050000000C79043752E63E408257CB9D99624B400C79043752E63E4072C284D1AC644B40B900344A97EE3E4072C284D1AC644B40B900344A97EE3E408257CB9D99624B400C79043752E63E408257CB9D99624B40
29743	Верхнии Кошевичи	1	13	170	30.948201000000001	30.977495000000001	55.304569999999998	55.293596999999998	0103000020E61000000100000005000000D508FD4CBDF23E40139A249694A54B40D508FD4CBDF23E40DEAB5626FCA64B40E700C11C3DFA3E40DEAB5626FCA64B40E700C11C3DFA3E40139A249694A54B40D508FD4CBDF23E40139A249694A54B40
29935	Братышки	1	13	170	31.176607000000001	31.190504000000001	55.176450000000003	55.157238	0103000020E61000000100000005000000A33EC91D362D3F401FD8F15F20944B40A33EC91D362D3F408AB0E1E995964B40D7C1C1DEC4303F408AB0E1E995964B40D7C1C1DEC4303F401FD8F15F20944B40A33EC91D362D3F401FD8F15F20944B40
14636	Боярщина	1	13	170	30.922294000000001	31.089649999999999	55.323551000000002	55.202680999999998	0103000020E610000001000000050000000A4CA7751BEC3E40A2427573F1994B400A4CA7751BEC3E4047CB811E6AA94B401E166A4DF3163F4047CB811E6AA94B401E166A4DF3163F40A2427573F1994B400A4CA7751BEC3E40A2427573F1994B40
54840	Чижовка	1	13	1164	33.161695000000002	33.206277999999998	54.087367999999998	54.072032999999998	0103000020E610000001000000050000009F76F86BB2944040CB9D996038094B409F76F86BB2944040C45BE7DF2E0B4B4030F14751679A4040C45BE7DF2E0B4B4030F14751679A4040CB9D996038094B409F76F86BB2944040CB9D996038094B40
46043	Хорошево	1	13	1164	32.689756000000003	32.709411000000003	54.006998000000003	53.994852000000002	0103000020E61000000100000005000000221CB3EC495840401B2E724F57FF4A40221CB3EC4958404097917A4FE5004B401A36CAFACD5A404097917A4FE5004B401A36CAFACD5A40401B2E724F57FF4A40221CB3EC495840401B2E724F57FF4A40
54858	Слобода	1	13	1164	32.657237000000002	32.690869999999997	53.896565000000002	53.876297000000001	0103000020E610000001000000050000004F5C8E57205440409D4A06802AF04A404F5C8E57205440407FDE54A4C2F24A40CDE49B6D6E5840407FDE54A4C2F24A40CDE49B6D6E5840409D4A06802AF04A404F5C8E57205440409D4A06802AF04A40
28286	Савеево	1	13	1164	33.316231999999999	33.337387	54.236043000000002	54.224732000000003	0103000020E610000001000000050000006EF9484A7AA84040AE2EA704C41C4B406EF9484A7AA8404091B932A8361E4B403B8C497F2FAB404091B932A8361E4B403B8C497F2FAB4040AE2EA704C41C4B406EF9484A7AA84040AE2EA704C41C4B40
16009	Рославль	1	13	1164	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
28113	Пригоры	1	13	1164	33.106476000000001	33.148957000000003	53.814633999999998	53.801260999999997	0103000020E610000001000000050000008AE76C01A18D4040B6476FB88FE64A408AE76C01A18D4040D61A4AED45E84A4051C1E10511934040D61A4AED45E84A4051C1E10511934040B6476FB88FE64A408AE76C01A18D4040B6476FB88FE64A40
28064	Перенка	1	13	1164	32.913606999999999	32.932893999999997	53.920248000000001	53.912886999999998	0103000020E61000000100000005000000C632FD12F1744040C6F8307BD9F44A40C632FD12F1744040CE1ABCAFCAF54A403B51121269774040CE1ABCAFCAF54A403B51121269774040C6F8307BD9F44A40C632FD12F1744040C6F8307BD9F44A40
28019	Остер	1	13	1164	32.790260000000004	32.815106999999998	54.028672	54.002659000000001	0103000020E6100000010000000500000022AB5B3D2765404021054F2157004B4022AB5B3D27654040CC272B86AB034B40CEDE196D55684040CC272B86AB034B40CEDE196D5568404021054F2157004B4022AB5B3D2765404021054F2157004B40
27533	Малые Кириллы	1	13	1164	32.877181	32.922077999999999	53.990358000000001	53.968828999999999	0103000020E6100000010000000500000017D68D77477040404C35B39602FC4A4017D68D77477040407EAA0A0DC4FE4A40382EE3A6067640407EAA0A0DC4FE4A40382EE3A6067640404C35B39602FC4A4017D68D77477040404C35B39602FC4A40
45760	Липовка	1	13	1164	33.070650999999998	33.083775000000003	54.110920999999998	54.103535999999998	0103000020E6100000010000000500000000378B170B894040B5FAEAAA400D4B4000378B170B89404045B8C9A8320E4B40789CA223B98A404045B8C9A8320E4B40789CA223B98A4040B5FAEAAA400D4B4000378B170B894040B5FAEAAA400D4B40
27856	Лесники	1	13	1164	32.636423000000001	32.661656999999998	53.957380999999998	53.943545999999998	0103000020E610000001000000050000000BB6114F76514040C422861DC6F84A400BB6114F76514040E867EA758BFA4A40B115342DB1544040E867EA758BFA4A40B115342DB1544040C422861DC6F84A400BB6114F76514040C422861DC6F84A40
28194	Лахи	1	13	1164	33.201149000000001	33.217875999999997	53.859934000000003	53.850396000000003	0103000020E61000000100000005000000C24F1C40BF9940401A53B0C6D9EC4A40C24F1C40BF994040F75B3B5112EE4A40A94A5B5CE39B4040F75B3B5112EE4A40A94A5B5CE39B40401A53B0C6D9EC4A40C24F1C40BF9940401A53B0C6D9EC4A40
41362	Красный	1	13	1164	33.082777999999998	33.097465	54.057929999999999	54.048240999999997	0103000020E61000000100000005000000056A3178988A4040C5A9D6C22C064B40056A3178988A404088BA0F406A074B4098C0ADBB798C404088BA0F406A074B4098C0ADBB798C4040C5A9D6C22C064B40056A3178988A4040C5A9D6C22C064B40
45710	Крапивна	1	13	1164	33.558166	33.575944	54.199500999999998	54.191051999999999	0103000020E610000001000000050000009CDEC5FB71C74040EEEA556474184B409CDEC5FB71C740407842AF3F89194B40E9297288B8C940407842AF3F89194B40E9297288B8C94040EEEA556474184B409CDEC5FB71C74040EEEA556474184B40
28197	Крапивенский 1-й	1	13	1164	32.724853000000003	32.742801999999998	54.099454999999999	54.091090999999999	0103000020E6100000010000000500000029B4ACFBC75C4040DFFAB0DEA80B4B4029B4ACFBC75C40403B3602F1BA0C4B40A2B3CC22145F40403B3602F1BA0C4B40A2B3CC22145F4040DFFAB0DEA80B4B4029B4ACFBC75C4040DFFAB0DEA80B4B40
27754	Коханы	1	13	1164	33.622477000000003	33.635106999999998	54.303654000000002	54.288021999999998	0103000020E6100000010000000500000090C18A53ADCF4040A643A7E7DD244B4090C18A53ADCF404059A65F22DE264B40F73AA92F4BD1404059A65F22DE264B40F73AA92F4BD14040A643A7E7DD244B4090C18A53ADCF4040A643A7E7DD244B40
27587	Костыри	1	13	1164	33.038508999999998	33.059080000000002	54.166516999999999	54.151226999999999	0103000020E6100000010000000500000003CDE7DCED844040D7A205685B134B4003CDE7DCED844040309DD66D50154B4081ECF5EE8F874040309DD66D50154B4081ECF5EE8F874040D7A205685B134B4003CDE7DCED844040D7A205685B134B40
27943	Коски	1	13	1164	33.034151999999999	33.060921999999998	54.049320000000002	54.036434999999997	0103000020E61000000100000005000000E78BBD175F84404002B7EEE6A9044B40E78BBD175F844040F584251E50064B40AFCDC64ACC874040F584251E50064B40AFCDC64ACC87404002B7EEE6A9044B40E78BBD175F84404002B7EEE6A9044B40
54807	Козловка	1	13	1164	32.806446999999999	32.813462999999999	54.002521000000002	54.000362000000003	0103000020E61000000100000005000000897AC1A739674040A114ADDC0B004B40897AC1A739674040D046AE9B52004B40C6C03A8E1F684040D046AE9B52004B40C6C03A8E1F684040A114ADDC0B004B40897AC1A739674040A114ADDC0B004B40
27384	Жарынь	1	13	1164	33.038069	33.075789	53.798900000000003	53.783071	0103000020E61000000100000005000000E7FEEA71DF84404017B9A7AB3BE44A40E7FEEA71DF8440402063EE5A42E64A40C2323674B38940402063EE5A42E64A40C2323674B389404017B9A7AB3BE44A40E7FEEA71DF84404017B9A7AB3BE44A40
54893	Епишево	1	13	1164	33.082085999999997	33.109602000000002	53.735796000000001	53.715456000000003	0103000020E61000000100000005000000CFBA46CB818A40400EDDEC0F94DB4A40CFBA46CB818A4040894336902EDE4A40C1C93670078E4040894336902EDE4A40C1C93670078E40400EDDEC0F94DB4A40CFBA46CB818A40400EDDEC0F94DB4A40
27286	Екимовичи	1	13	1164	33.260607999999998	33.318559	54.124268000000001	54.099983000000002	0103000020E61000000100000005000000B9895A9A5BA14040F793313ECC0C4B40B9895A9A5BA140403CF88903E80F4B40596C938AC6A840403CF88903E80F4B40596C938AC6A84040F793313ECC0C4B40B9895A9A5BA14040F793313ECC0C4B40
28273	Доротовка	1	13	1164	32.834707999999999	32.857337000000001	54.131264000000002	54.119433999999998	0103000020E61000000100000005000000D3DA34B6D76A4040E603029D490F4B40D3DA34B6D76A404032923D42CD104B404C530438BD6D404032923D42CD104B404C530438BD6D4040E603029D490F4B40D3DA34B6D76A4040E603029D490F4B40
15391	Десногорск	1	13	1164	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
27241	Грязенять	1	13	1164	32.808926999999997	32.820937000000001	53.807758999999997	53.799629000000003	0103000020E61000000100000005000000FAEC80EB8A67404073F7393E5AE64A40FAEC80EB8A6740405B069CA564E74A40C689AF76146940405B069CA564E74A40C689AF761469404073F7393E5AE64A40FAEC80EB8A67404073F7393E5AE64A40
27469	Волконщина	1	13	1164	32.936559000000003	32.970182999999999	53.765436000000001	53.747224000000003	0103000020E6100000010000000500000022E3512AE1774040A6643909A5DF4A4022E3512AE17740402D978DCEF9E14A404D11E0F42E7C40402D978DCEF9E14A404D11E0F42E7C4040A6643909A5DF4A4022E3512AE1774040A6643909A5DF4A40
27201	Волковичи	1	13	1164	33.027154000000003	33.047618	53.902098000000002	53.887793000000002	0103000020E6100000010000000500000051FA42C879834040124F7633A3F14A4051FA42C879834040BDE47FF277F34A40B859BC5818864040BDE47FF277F34A40B859BC5818864040124F7633A3F14A4051FA42C879834040124F7633A3F14A40
45501	Богданово	1	13	1164	33.145516000000001	33.168944000000003	54.256497000000003	54.227817000000002	0103000020E61000000100000005000000BA85AE44A0924040863C821B291D4B40BA85AE44A0924040D542C9E4D4204B407F6DFDF49F954040D542C9E4D4204B407F6DFDF49F954040863C821B291D4B40BA85AE44A0924040863C821B291D4B40
60517	Барсуки	1	13	1164	32.998992000000001	33.020794000000002	54.141101999999997	54.127893	0103000020E610000001000000050000009A7B48F8DE7F404094313ECC5E104B409A7B48F8DE7F404039B35DA10F124B40FDF9B660A982404039B35DA10F124B40FDF9B660A982404094313ECC5E104B409A7B48F8DE7F404094313ECC5E104B40
27109	Астапковичи	1	13	1164	32.723011999999997	32.744481	53.916642000000003	53.900767000000002	0103000020E61000000100000005000000CA4E3FA88B5C4040742843554CF34A40CA4E3FA88B5C4040ED116A8654F54A4027BF45274B5F4040ED116A8654F54A4027BF45274B5F4040742843554CF34A40CA4E3FA88B5C4040742843554CF34A40
24477	Шмаково	1	13	1740	33.011021	33.028080000000003	54.334570999999997	54.321654000000002	0103000020E61000000100000005000000DC48D92269814040555051F52B294B40DC48D922698140405298F738D32A4B40FAD51C20988340405298F738D32A4B40FAD51C2098834040555051F52B294B40DC48D92269814040555051F52B294B40
49075	Шаталово	1	13	1740	32.433951999999998	32.496375999999998	54.342737999999997	54.317075000000003	0103000020E61000000100000005000000530438BD8B3740408AB0E1E995284B40530438BD8B374040588CBAD6DE2B4B407842AF3F893F4040588CBAD6DE2B4B407842AF3F893F40408AB0E1E995284B40530438BD8B3740408AB0E1E995284B40
24912	Шанталово	1	13	1740	32.550679000000002	32.571331000000001	54.213051	54.203693000000001	0103000020E6100000010000000500000008CC43A67C4640404AB6BA9C121A4B4008CC43A67C464040A7B05241451B4B407218CC5F21494040A7B05241451B4B407218CC5F214940404AB6BA9C121A4B4008CC43A67C4640404AB6BA9C121A4B40
48823	Стригино	1	13	1740	32.638319000000003	32.667397000000001	54.454894000000003	54.440517999999997	0103000020E610000001000000050000002DB5DE6FB451404050A6D1E462384B402DB5DE6FB4514040C59272F7393A4B406939D0436D554040C59272F7393A4B406939D0436D55404050A6D1E462384B402DB5DE6FB451404050A6D1E462384B40
24779	Стодолище	1	13	1740	32.626434000000003	32.670847000000002	54.205551999999997	54.162379000000001	0103000020E610000001000000050000001E8D43FD2E5040405247C7D5C8144B401E8D43FD2E5040404ED026874F1A4B4053CF8250DE5540404ED026874F1A4B4053CF8250DE5540405247C7D5C8144B401E8D43FD2E5040405247C7D5C8144B40
49203	Старинки	1	13	1740	32.328885	32.351306999999998	54.559657000000001	54.492981	0103000020E610000001000000050000008E9257E7182A404052465C001A3F4B408E9257E7182A40401EFD2FD7A2474B408DEDB5A0F72C40401EFD2FD7A2474B408DEDB5A0F72C404052465C001A3F4B408E9257E7182A404052465C001A3F4B40
49244	Рябцево	1	13	1740	32.313972999999997	32.361440000000002	54.650568	54.632786000000003	0103000020E61000000100000005000000DB696B4430284040EFAEB321FF504B40DB696B44302840407DE9EDCF45534B40AEBB79AA432E40407DE9EDCF45534B40AEBB79AA432E4040EFAEB321FF504B40DB696B4430284040EFAEB321FF504B40
25941	Прилепово	1	13	1740	32.204594	32.241748000000001	54.319958	54.307136999999997	0103000020E610000001000000050000009A7ADD22301A40401E32E54350274B409A7ADD22301A4040FA0B3D62F4284B40CCEF3499F11E4040FA0B3D62F4284B40CCEF3499F11E40401E32E54350274B409A7ADD22301A40401E32E54350274B40
49162	Плоское	1	13	1740	32.336691000000002	32.362158000000001	54.445627999999999	54.426766000000001	0103000020E61000000100000005000000C4EDD0B0182B4040BA85AE44A0364B40C4EDD0B0182B404048179B560A394B400DFE7E315B2E404048179B560A394B400DFE7E315B2E4040BA85AE44A0364B40C4EDD0B0182B4040BA85AE44A0364B40
25661	Пересна	1	13	1740	32.397371999999997	32.423018999999996	54.525576999999998	54.511384	0103000020E610000001000000050000004D2CF015DD3240404DD9E90775414B404D2CF015DD324040D0436D1B46434B40164B917C25364040D0436D1B46434B40164B917C253640404DD9E90775414B404D2CF015DD3240404DD9E90775414B40
54859	Новые Головачи	1	13	1740	32.848236999999997	32.875114000000004	54.214151000000001	54.201833999999998	0103000020E61000000100000005000000EA20AF07936C4040459C4EB2D5194B40EA20AF07936C4040EEB3CA4C691B4B40C9224DBC03704040EEB3CA4C691B4B40C9224DBC03704040459C4EB2D5194B40EA20AF07936C4040459C4EB2D5194B40
54832	Мурыгино	1	13	1740	32.299582000000001	32.325857999999997	54.501021999999999	54.477677	0103000020E61000000100000005000000323CF6B35826404094861A85243D4B40323CF6B358264040CB49287D21404B40EA9106B7B5294040CB49287D21404B40EA9106B7B529404094861A85243D4B40323CF6B35826404094861A85243D4B40
25092	Мачулы	1	13	1740	32.544463	32.575239000000003	54.341724999999997	54.327976999999997	0103000020E61000000100000005000000E770ADF6B04540408B6B7C26FB294B40E770ADF6B0454040E09C11A5BD2B4B401F317A6EA1494040E09C11A5BD2B4B401F317A6EA14940408B6B7C26FB294B40E770ADF6B04540408B6B7C26FB294B40
49187	Макшеево	1	13	1740	32.206543000000003	32.22822	54.555475000000001	54.545062000000001	0103000020E61000000100000005000000DF1B4300701A40406C257497C4454B40DF1B4300701A4040705F07CE19474B4085251E50361D4040705F07CE19474B4085251E50361D40406C257497C4454B40DF1B4300701A40406C257497C4454B40
24242	Лучеса	1	13	1740	32.472498999999999	32.499205000000003	54.420144999999998	54.402717000000003	0103000020E610000001000000050000004432E4D87A3C404089450C3B8C334B404432E4D87A3C4040F949B54FC7354B40F67F0EF3E53F4040F949B54FC7354B40F67F0EF3E53F404089450C3B8C334B404432E4D87A3C404089450C3B8C334B40
25555	Лосня	1	13	1740	32.305276999999997	32.344129000000002	54.602511999999997	54.590848999999999	0103000020E61000000100000005000000499C155113274040E9EFA5F0A04B4B40499C15511327404049B9FB1C1F4D4B40774D486B0C2C404049B9FB1C1F4D4B40774D486B0C2C4040E9EFA5F0A04B4B40499C155113274040E9EFA5F0A04B4B40
49290	Ламоново	1	13	1740	32.176827000000003	32.200533999999998	54.507421000000001	54.494759000000002	0103000020E6100000010000000500000060066344A21640406A334E43543F4B4060066344A2164040DD26DC2BF3404B4037DE1D19AB194040DD26DC2BF3404B4037DE1D19AB1940406A334E43543F4B4060066344A21640406A334E43543F4B40
48964	Красное Знамя	1	13	1740	32.528356000000002	32.548549999999999	54.132297999999999	54.115406999999998	0103000020E610000001000000050000009C525E2BA14340405F5D15A8C50E4B409C525E2BA1434040C1A90F24EF104B40431CEBE236464040C1A90F24EF104B40431CEBE2364640405F5D15A8C50E4B409C525E2BA14340405F5D15A8C50E4B40
49316	Княжое 1-е	1	13	1740	32.195638000000002	32.221832999999997	54.389256000000003	54.372450000000001	0103000020E610000001000000050000006CED7DAA0A19404096B20C71AC2F4B406CED7DAA0A194040CAE2FE23D3314B4037161406651C4040CAE2FE23D3314B4037161406651C404096B20C71AC2F4B406CED7DAA0A19404096B20C71AC2F4B40
24433	Климщина	1	13	1740	32.693268000000003	32.714325000000002	54.364026000000003	54.350546999999999	0103000020E6100000010000000500000082AE7D01BD584040FF5A5EB9DE2C4B4082AE7D01BD58404065726A67982E4B408CDB68006F5B404065726A67982E4B408CDB68006F5B4040FF5A5EB9DE2C4B4082AE7D01BD584040FF5A5EB9DE2C4B40
60534	Клемятино	1	13	1740	32.121194000000003	32.145215	54.467934999999997	54.453710999999998	0103000020E61000000100000005000000583CF548830F4040F06AB933133A4B40583CF548830F4040AED3484BE53B4B40BFF1B56796124040AED3484BE53B4B40BFF1B56796124040F06AB933133A4B40583CF548830F4040F06AB933133A4B40
60482	Доброселье	1	13	1740	32.919167999999999	32.932246999999997	54.217199000000001	54.212649999999996	0103000020E61000000100000005000000CEC3094CA775404048BF7D1D381B4B40CEC3094CA7754040A9DC442DCD1B4B40A565A4DE53774040A9DC442DCD1B4B40A565A4DE5377404048BF7D1D381B4B40CEC3094CA775404048BF7D1D381B4B40
24725	Деребуж 1-й	1	13	1740	32.584581	32.607030000000002	54.081167000000001	54.072229	0103000020E61000000100000005000000766EDA8CD34A40405169C4CC3E094B40766EDA8CD34A4040D94125AE630A4B406FD8B628B34D4040D94125AE630A4B406FD8B628B34D40405169C4CC3E094B40766EDA8CD34A40405169C4CC3E094B40
25157	Даньково	1	13	1740	32.408898000000001	32.439692000000001	54.371622000000002	54.353422999999999	0103000020E610000001000000050000002DB308C556344040BD5301F73C2D4B402DB308C556344040B03C484F912F4B400B28D4D347384040B03C484F912F4B400B28D4D347384040BD5301F73C2D4B402DB308C556344040BD5301F73C2D4B40
49019	Ворошилово	1	13	1740	32.693061999999998	32.709859999999999	54.243319999999997	54.232559000000002	0103000020E61000000100000005000000D80C7041B6584040FBB1497EC41D4B40D80C7041B65840403A3B191C251F4B40895E46B1DC5A40403A3B191C251F4B40895E46B1DC5A4040FBB1497EC41D4B40D80C7041B6584040FBB1497EC41D4B40
49044	Васьково	1	13	1740	32.550759999999997	32.582290999999998	54.273971000000003	54.264218	0103000020E61000000100000005000000F4F8BD4D7F464040DC813AE5D1214B40F4F8BD4D7F464040B686527B11234B40A8E0F082884A4040B686527B11234B40A8E0F082884A4040DC813AE5D1214B40F4F8BD4D7F464040DC813AE5D1214B40
25260	Бояды 1-е	1	13	1740	32.433169999999997	32.447507000000002	54.436905000000003	54.425676000000003	0103000020E61000000100000005000000DDCD531D723740409758198D7C364B40DDCD531D72374040BD3AC780EC374B4094DDCCE847394040BD3AC780EC374B4094DDCCE8473940409758198D7C364B40DDCD531D723740409758198D7C364B40
24541	Белик	1	13	1740	32.856025000000002	32.888849999999998	54.308723999999998	54.292420999999997	0103000020E610000001000000050000007AC7293A926D4040F1D4230D6E254B407AC7293A926D4040C2BE9D4484274B40598638D6C5714040C2BE9D4484274B40598638D6C5714040F1D4230D6E254B407AC7293A926D4040F1D4230D6E254B40
24321	Бабыново	1	13	1740	32.530358999999997	32.548056000000003	54.470759999999999	54.459128	0103000020E61000000100000005000000D311C0CDE2434040C556D0B4C43A4B40D311C0CDE2434040EA211ADD413C4B403430F2B226464040EA211ADD413C4B403430F2B226464040C556D0B4C43A4B40D311C0CDE2434040C556D0B4C43A4B40
48665	Хвощеватое	1	13	1419	33.700046	33.720976999999998	55.655681000000001	55.643098999999999	0103000020E610000001000000050000000AD9791B9BD940408F8B6A1151D24B400AD9791B9BD94040E6CDE15AEDD34B4087156EF948DC4040E6CDE15AEDD34B4087156EF948DC40408F8B6A1151D24B400AD9791B9BD940408F8B6A1151D24B40
48626	Торбеево	1	13	1419	34.233232000000001	34.268967000000004	55.489254000000003	55.472938999999997	0103000020E61000000100000005000000BA30D28BDA1D41406000E14389BC4B40BA30D28BDA1D4140F6B704E09FBE4B40045ABA826D224140F6B704E09FBE4B40045ABA826D2241406000E14389BC4B40BA30D28BDA1D41406000E14389BC4B40
23737	Тесово	1	13	1419	34.476388	34.510047999999998	55.622075000000002	55.605362999999997	0103000020E610000001000000050000007A1A3048FA3C4140AE9AE7887CCD4B407A1A3048FA3C414061545227A0CF4B40F2B1BB404941414061545227A0CF4B40F2B1BB4049414140AE9AE7887CCD4B407A1A3048FA3C4140AE9AE7887CCD4B40
60521	Селище	1	13	1419	34.348638999999999	34.358826000000001	55.667625000000001	55.660992999999998	0103000020E61000000100000005000000198EE733A02C414045F12A6B9BD44B40198EE733A02C4140FA7E6ABC74D54B402D7AA702EE2D4140FA7E6ABC74D54B402D7AA702EE2D414045F12A6B9BD44B40198EE733A02C414045F12A6B9BD44B40
46008	Савино	1	13	1419	33.857349999999997	33.863396000000002	55.658383000000001	55.654964999999997	0103000020E61000000100000005000000E09C11A5BDED40402783A3E4D5D34B40E09C11A5BDED4040069FE6E445D44B40A5BF97C283EE4040069FE6E445D44B40A5BF97C283EE40402783A3E4D5D34B40E09C11A5BDED40402783A3E4D5D34B40
48558	Рябинки	1	13	1419	34.209301000000004	34.225802999999999	55.654985000000003	55.645643999999997	0103000020E6100000010000000500000093020B60CA1A4140E76D6C76A4D24B4093020B60CA1A41406F2F698CD6D34B405A2BDA1CE71C41406F2F698CD6D34B405A2BDA1CE71C4140E76D6C76A4D24B4093020B60CA1A4140E76D6C76A4D24B40
23562	Печеничено	1	13	1419	33.968113000000002	33.990704999999998	55.651134999999996	55.642906000000004	0103000020E610000001000000050000008EEA7420EBFB40407B336ABE4AD24B408EEA7420EBFB4040F623456458D34B40E97DE36BCFFE4040F623456458D34B40E97DE36BCFFE40407B336ABE4AD24B408EEA7420EBFB40407B336ABE4AD24B40
23443	Новодугино	1	13	1419	34.263675999999997	34.326082	55.643616999999999	55.587809	0103000020E61000000100000005000000BB5E9A22C0214140B1A547533DCB4B40BB5E9A22C02141402713B70A62D24B403AE8120EBD2941402713B70A62D24B403AE8120EBD294140B1A547533DCB4B40BB5E9A22C0214140B1A547533DCB4B40
49077	Никольское	1	13	1419	34.308484	34.315427999999997	55.496383999999999	55.489198000000002	0103000020E610000001000000050000006DAB59677C27414062A2410A9EBE4B406DAB59677C274140FB20CB8289BF4B40101FD8F15F284140FB20CB8289BF4B40101FD8F15F28414062A2410A9EBE4B406DAB59677C27414062A2410A9EBE4B40
47713	Малеево	1	13	1419	34.451056000000001	34.458978999999999	55.580747000000002	55.576797999999997	0103000020E610000001000000050000001155F833BC394140F8325184D4C94B401155F833BC3941400420EEEA55CA4B408046E9D2BF3A41400420EEEA55CA4B408046E9D2BF3A4140F8325184D4C94B401155F833BC394140F8325184D4C94B40
15869	Липецы	1	13	1419	34.163235999999998	34.182001	55.613931000000001	55.602083	0103000020E61000000100000005000000D2C3D0EAE4144140213D450E11CD4B40D2C3D0EAE414414013807F4A95CE4B406E6B0BCF4B17414013807F4A95CE4B406E6B0BCF4B174140213D450E11CD4B40D2C3D0EAE4144140213D450E11CD4B40
15862	Извеково	1	13	1419	33.970286999999999	33.993077	55.569968000000003	55.557184999999997	0103000020E61000000100000005000000F25D4A5D32FC40402F698CD651C74B40F25D4A5D32FC40401EE21FB6F4C84B4074B4AA251DFF40401EE21FB6F4C84B4074B4AA251DFF40402F698CD651C74B40F25D4A5D32FC40402F698CD651C74B40
15777	Днепровское	1	13	1419	33.887435000000004	33.933608	55.667589	55.646599000000002	0103000020E61000000100000005000000B329577897F140402B508BC1C3D24B40B329577897F14040AD156D8E73D54B4059A4897780F74040AD156D8E73D54B4059A4897780F740402B508BC1C3D24B40B329577897F140402B508BC1C3D24B40
48394	Григорьевское	1	13	1419	33.895214000000003	33.916108999999999	55.452359999999999	55.437837000000002	0103000020E61000000100000005000000EF75525F96F2404048FDF50A0BB84B40EF75525F96F240406002B7EEE6B94B401F49490F43F540406002B7EEE6B94B401F49490F43F5404048FDF50A0BB84B40EF75525F96F2404048FDF50A0BB84B40
60478	Бурцево	1	13	1419	34.364665000000002	34.379604	55.627758	55.615354000000004	0103000020E61000000100000005000000787FBC57AD2E41403DBB7CEBC3CE4B40787FBC57AD2E4140B4E6C75F5AD04B4024B726DD96304140B4E6C75F5AD04B4024B726DD963041403DBB7CEBC3CE4B40787FBC57AD2E41403DBB7CEBC3CE4B40
48341	Болшево	1	13	1419	33.818255999999998	33.846210999999997	55.735905000000002	55.725245000000001	0103000020E61000000100000005000000BDE0D39CBCE84040344B02D4D4DC4B40BDE0D39CBCE8404040FB912232DE4B40FA415DA450EC404040FB912232DE4B40FA415DA450EC4040344B02D4D4DC4B40BDE0D39CBCE84040344B02D4D4DC4B40
47293	Бараново	1	13	1419	33.923008000000003	33.933760999999997	55.418700999999999	55.413151999999997	0103000020E6100000010000000500000023F94A2025F6404074232C2AE2B44B4023F94A2025F64040B8E68EFE97B54B40DFA3FE7A85F74040B8E68EFE97B54B40DFA3FE7A85F7404074232C2AE2B44B4023F94A2025F6404074232C2AE2B44B40
53064	Татарск	1	13	1859	31.551375	31.574363000000002	54.259462999999997	54.245998	0103000020E61000000100000005000000FED478E9268D3F40D270CADC7C1F4B40FED478E9268D3F40D2C2651536214B404F081D7409933F40D2C2651536214B404F081D7409933F40D270CADC7C1F4B40FED478E9268D3F40D270CADC7C1F4B40
51969	Стегримово	1	13	1859	31.893668999999999	31.914608999999999	54.476578000000003	54.463430000000002	0103000020E61000000100000005000000F372D87DC7E43F401EFE9AAC513B4B40F372D87DC7E43F401EFF0582003D4B4094A0BFD023EA3F401EFF0582003D4B4094A0BFD023EA3F401EFE9AAC513B4B40F372D87DC7E43F401EFE9AAC513B4B40
54857	Соболево	1	13	1859	31.891135999999999	31.908149999999999	54.435778999999997	54.423408000000002	0103000020E61000000100000005000000CB49287D21E43F40B16EBC3B32364B40CB49287D21E43F404CA4349BC7374B40C6DCB5847CE83F404CA4349BC7374B40C6DCB5847CE83F40B16EBC3B32364B40CB49287D21E43F40B16EBC3B32364B40
54877	Раевка	1	13	1859	31.558641999999999	31.578261999999999	54.202145000000002	54.18347	0103000020E610000001000000050000000A2C8029038F3F4008E6E8F17B174B400A2C8029038F3F4064062AE3DF194B4001857AFA08943F4064062AE3DF194B4001857AFA08943F4008E6E8F17B174B400A2C8029038F3F4008E6E8F17B174B40
54895	Октябрьское	1	13	1859	31.831578	31.854143000000001	54.380431999999999	54.370587999999998	0103000020E61000000100000005000000B612BA4BE2D43F402025766D6F2F4B40B612BA4BE2D43F400A2DEBFEB1304B407A1B9B1DA9DA3F400A2DEBFEB1304B407A1B9B1DA9DA3F402025766D6F2F4B40B612BA4BE2D43F402025766D6F2F4B40
51957	Носково 2-е	1	13	1859	31.776142	31.784883000000001	54.394728999999998	54.387264000000002	0103000020E61000000100000005000000520DFB3DB1C63F408675E3DD91314B40520DFB3DB1C63F4032E4D87A86324B40B62FA017EEC83F4032E4D87A86324B40B62FA017EEC83F408675E3DD91314B40520DFB3DB1C63F408675E3DD91314B40
45564	Новомихайловское	1	13	1859	31.607780000000002	31.62501	54.370274000000002	54.358601999999998	0103000020E61000000100000005000000B3295778979B3F40DD239BABE62D4B40B3295778979B3F4091477023652F4B4047ACC5A700A03F4091477023652F4B4047ACC5A700A03F40DD239BABE62D4B40B3295778979B3F40DD239BABE62D4B40
48243	Новое Село	1	13	1859	31.732951	31.741	54.419338000000003	54.407308	0103000020E610000001000000050000000C923EADA2BB3F4018B325AB22344B400C923EADA2BB3F402BFC19DEAC354B4004560E2DB2BD3F402BFC19DEAC354B4004560E2DB2BD3F4018B325AB22344B400C923EADA2BB3F4018B325AB22344B40
60499	Михайловка	1	13	1859	31.680705	31.68685	54.368585000000003	54.363439	0103000020E610000001000000050000004339D1AE42AE3F40A48B4D2B852E4B404339D1AE42AE3F40E96514CB2D2F4B40F241CF66D5AF3F40E96514CB2D2F4B40F241CF66D5AF3F40A48B4D2B852E4B404339D1AE42AE3F40A48B4D2B852E4B40
29028	Любавичи	1	13	1859	31.697091	31.715496999999999	54.196246000000002	54.178812000000001	0103000020E610000001000000050000000056478E74B23F40F110C64FE3164B400056478E74B23F4044FCC3961E194B40D862B7CF2AB73F4044FCC3961E194B40D862B7CF2AB73F40F110C64FE3164B400056478E74B23F40F110C64FE3164B40
52003	Лыза	1	13	1859	31.886527000000001	31.900703	54.246817999999998	54.229405999999997	0103000020E610000001000000050000006005F86EF3E23F40CAC0012D5D1D4B406005F86EF3E23F40350873BB971F4B40BA68C87894E63F40350873BB971F4B40BA68C87894E63F40CAC0012D5D1D4B406005F86EF3E23F40CAC0012D5D1D4B40
54876	Кадино	1	13	1859	31.457744000000002	31.474613999999999	54.306716999999999	54.293939000000002	0103000020E61000000100000005000000B3F0F5B52E753F406D020CCB9F254B40B3F0F5B52E753F404910AE8042274B404739984D80793F404910AE8042274B404739984D80793F406D020CCB9F254B40B3F0F5B52E753F406D020CCB9F254B40
54891	Железняк	1	13	1859	31.734748	31.754663999999998	54.240552000000001	54.230837999999999	0103000020E6100000010000000500000029CDE67118BC3F4047567E198C1D4B4029CDE67118BC3F40637E6E68CA1E4B40F277EFA831C13F40637E6E68CA1E4B40F277EFA831C13F4047567E198C1D4B4029CDE67118BC3F4047567E198C1D4B40
51959	Досугово	1	13	1859	31.689876999999999	31.716646999999998	54.427304999999997	54.407895000000003	0103000020E61000000100000005000000394371C79BB03F40D99942E735344B40394371C79BB03F40693524EEB1364B40C9C6832D76B73F40693524EEB1364B40C9C6832D76B73F40D99942E735344B40394371C79BB03F40D99942E735344B40
51981	Долгие Нивы	1	13	1859	32.034731999999998	32.054737000000003	54.450732000000002	54.439208999999998	0103000020E61000000100000005000000F50F221972044040EF8D210038384B40F50F2219720440405EA10F96B1394B40CA703C9F010740405EA10F96B1394B40CA703C9F01074040EF8D210038384B40F50F221972044040EF8D210038384B40
51974	Дмыничи	1	13	1859	31.943840000000002	31.961680999999999	54.433489999999999	54.424287999999997	0103000020E610000001000000050000001AA88C7F9FF13F40E90AB6114F364B401AA88C7F9FF13F404F92AE997C374B40402FDCB930F63F404F92AE997C374B40402FDCB930F63F40E90AB6114F364B401AA88C7F9FF13F40E90AB6114F364B40
54861	Гоголевка	1	13	1859	31.949634	31.976934	54.291454000000002	54.271878999999998	0103000020E610000001000000050000006F2BBD361BF33F400EBC5AEECC224B406F2BBD361BF33F40EA245B5D4E254B40B859BC5818FA3F40EA245B5D4E254B40B859BC5818FA3F400EBC5AEECC224B406F2BBD361BF33F400EBC5AEECC224B40
60461	Барсуки	1	13	1859	32.041128	32.068840999999999	54.375287999999998	54.359141999999999	0103000020E610000001000000050000009679ABAE430540405D4F745DF82D4B409679ABAE43054040664AEB6F09304B40DDCF29C8CF084040664AEB6F09304B40DDCF29C8CF0840405D4F745DF82D4B409679ABAE430540405D4F745DF82D4B40
52014	Багрецы	1	13	1859	31.864294000000001	31.882224999999998	54.332039999999999	54.319474999999997	0103000020E610000001000000050000000821205F42DD3F40DE718A8EE4284B400821205F42DD3F405F7B6649802A4B40AEB6627FD9E13F405F7B6649802A4B40AEB6627FD9E13F40DE718A8EE4284B400821205F42DD3F40DE718A8EE4284B40
29474	Шеровичи	1	13	382	31.356179999999998	31.370131000000001	54.745151999999997	54.737054999999998	0103000020E61000000100000005000000417DCB9C2E5B3F40382D78D1575E4B40417DCB9C2E5B3F4045460724615F4B405C3CBCE7C05E3F4045460724615F4B405C3CBCE7C05E3F40382D78D1575E4B40417DCB9C2E5B3F40382D78D1575E4B40
21623	Сырокоренье	1	13	382	31.483013	31.525153	54.663521000000003	54.647889999999997	0103000020E61000000100000005000000F88A6EBDA67B3F40E5B33C0FEE524B40F88A6EBDA67B3F40C89A9141EE544B407365506D70863F40C89A9141EE544B407365506D70863F40E5B33C0FEE524B40F88A6EBDA67B3F40E5B33C0FEE524B40
20974	Рогайлово	1	13	382	31.764562999999999	31.789625999999998	54.602888	54.589368	0103000020E610000001000000050000004DBB9866BAC33F408BA71E69704B4B404DBB9866BAC33F404F93196F2B4D4B404012F6ED24CA3F404F93196F2B4D4B404012F6ED24CA3F408BA71E69704B4B404DBB9866BAC33F408BA71E69704B4B40
21175	Миганово	1	13	382	31.373401000000001	31.392014	54.696126999999997	54.689298999999998	0103000020E61000000100000005000000304B3B35975F3F402F151BF33A584B40304B3B35975F3F40696E85B01A594B40FB928D075B643F40696E85B01A594B40FB928D075B643F402F151BF33A584B40304B3B35975F3F402F151BF33A584B40
47767	Мерлино	1	13	382	31.576491999999998	31.594457999999999	54.609603999999997	54.595053999999998	0103000020E61000000100000005000000D767CEFA94933F404FADBEBA2A4C4B40D767CEFA94933F4061C1FD80074E4B4077D844662E983F4061C1FD80074E4B4077D844662E983F404FADBEBA2A4C4B40D767CEFA94933F404FADBEBA2A4C4B40
47734	Маньково	1	13	382	31.455803	31.490774999999999	54.609431999999998	54.589863000000001	0103000020E610000001000000050000002F6B6281AF743F406B0F7BA1804B4B402F6B6281AF743F40649126DE014E4B40C4B12E6EA37D3F40649126DE014E4B40C4B12E6EA37D3F406B0F7BA1804B4B402F6B6281AF743F406B0F7BA1804B4B40
21447	Лонница	1	13	382	31.049683999999999	31.072735000000002	54.692276	54.674205000000001	0103000020E610000001000000050000006C223317B80C3F405CE674594C564B406C223317B80C3F4021E7FD7F9C584B404A46CEC29E123F4021E7FD7F9C584B404A46CEC29E123F405CE674594C564B406C223317B80C3F405CE674594C564B40
54853	Красное	1	13	382	31.026461999999999	31.048507000000001	54.690033	54.677677000000003	0103000020E610000001000000050000003596B036C6063F402E20B41EBE564B403596B036C6063F409414580053584B4088A06AF46A0C3F409414580053584B4088A06AF46A0C3F402E20B41EBE564B403596B036C6063F402E20B41EBE564B40
47641	Комиссарово	1	13	382	31.318289	31.332321	54.743296999999998	54.729657000000003	0103000020E6100000010000000500000032AD4D637B513F4014268C66655D4B4032AD4D637B513F40821B295B245F4B4026C632FD12553F40821B295B245F4B4026C632FD12553F4014268C66655D4B4032AD4D637B513F4014268C66655D4B40
21930	Зверовичи	1	13	382	31.267012999999999	31.283999999999999	54.514352000000002	54.503233999999999	0103000020E610000001000000050000005A9BC6F65A443F401D1EC2F869404B405A9BC6F65A443F40EC504D49D6414B4062105839B4483F40EC504D49D6414B4062105839B4483F401D1EC2F869404B405A9BC6F65A443F401D1EC2F869404B40
21072	Двуполяны	1	13	382	31.221737999999998	31.245623999999999	54.622960999999997	54.611528	0103000020E61000000100000005000000CB4752D2C3383F404D4BAC8C464E4B40CB4752D2C3383F407BD7A02FBD4F4B40DA1CE736E13E3F407BD7A02FBD4F4B40DA1CE736E13E3F404D4BAC8C464E4B40CB4752D2C3383F404D4BAC8C464E4B40
47589	Гусино	1	13	382	31.342544	31.414929999999998	54.733317	54.703508999999997	0103000020E61000000100000005000000E770ADF6B0573F4088B839950C5A4B40E770ADF6B0573F40E84CDA54DD5D4B4018213CDA386A3F40E84CDA54DD5D4B4018213CDA386A3F4088B839950C5A4B40E770ADF6B0573F4088B839950C5A4B40
21735	Гребени	1	13	382	31.241681	31.262450000000001	54.557254999999998	54.546666000000002	0103000020E61000000100000005000000881057CEDE3D3F40E6EAC726F9454B40881057CEDE3D3F402844C02154474B40D0D556EC2F433F402844C02154474B40D0D556EC2F433F40E6EAC726F9454B40881057CEDE3D3F40E6EAC726F9454B40
20867	Викторово	1	13	382	31.463169000000001	31.489633999999999	54.402622999999998	54.387385000000002	0103000020E6100000010000000500000062855B3E92763F4001FBE8D495314B4062855B3E92763F4007CF842689334B40790261A7587D3F4007CF842689334B40790261A7587D3F4001FBE8D495314B4062855B3E92763F4001FBE8D495314B40
49133	Болтутино	1	13	382	31.380479999999999	31.391565	54.457762000000002	54.449486	0103000020E6100000010000000500000036C8242367613F404301DBC188394B4036C8242367613F4000ADF9F1973A4B401C42959A3D643F4000ADF9F1973A4B401C42959A3D643F404301DBC188394B4036C8242367613F404301DBC188394B40
54833	Березино	1	13	382	31.322438999999999	31.334540000000001	54.713855000000002	54.709584999999997	0103000020E6100000010000000500000077F4BF5C8B523F40B75D68AED35A4B4077F4BF5C8B523F40058BC3995F5B4B402F34D769A4553F40058BC3995F5B4B402F34D769A4553F40B75D68AED35A4B4077F4BF5C8B523F40B75D68AED35A4B40
21396	Белеи	1	13	382	31.174828000000002	31.188222	54.707259999999998	54.696683	0103000020E61000000100000005000000D36C1E87C12C3F40EF5696E82C594B40D36C1E87C12C3F406DE2E47E875A4B40416326512F303F406DE2E47E875A4B40416326512F303F40EF5696E82C594B40D36C1E87C12C3F40EF5696E82C594B40
47538	Алушково	1	13	382	31.52721	31.544162	54.445062	54.435715999999999	0103000020E61000000100000005000000C91F0C3CF7863F40062CB98AC5374B40C91F0C3CF7863F409F58A7CAF7384B40D8B969334E8B3F409F58A7CAF7384B40D8B969334E8B3F40062CB98AC5374B40C91F0C3CF7863F40062CB98AC5374B40
20645	Шутовка	1	13	1378	32.489477000000001	32.511502999999998	54.714157	54.698478000000001	0103000020E610000001000000050000007592AD2EA73E4040DD7C23BA67594B407592AD2EA73E4040D09A1F7F695B4B40276728EE78414040D09A1F7F695B4B40276728EE78414040DD7C23BA67594B407592AD2EA73E4040DD7C23BA67594B40
47388	Шокино	1	13	1378	32.409112999999998	32.436304999999997	54.982869000000001	54.968355000000003	0103000020E6100000010000000500000029AF95D05D34404084F57F0EF37B4B4029AF95D05D34404049A0C1A6CE7D4B40670A9DD7D837404049A0C1A6CE7D4B40670A9DD7D837404084F57F0EF37B4B4029AF95D05D34404084F57F0EF37B4B40
47420	Шестаково	1	13	1378	32.509993999999999	32.532470000000004	54.970995000000002	54.958311999999999	0103000020E61000000100000005000000FF93BF7B47414040A3AEB5F7A97A4B40FF93BF7B474140402ECA6C90497C4B40F20C1AFA274440402ECA6C90497C4B40F20C1AFA27444040A3AEB5F7A97A4B40FF93BF7B47414040A3AEB5F7A97A4B40
47346	Тюшино	1	13	1378	32.466138000000001	32.481831999999997	54.787810999999998	54.778829000000002	0103000020E6100000010000000500000020B6F468AA3B404094162EABB0634B4020B6F468AA3B4040EB36A8FDD6644B404815C5ABAC3D4040EB36A8FDD6644B404815C5ABAC3D404094162EABB0634B4020B6F468AA3B404094162EABB0634B40
20431	Титково	1	13	1378	32.580323	32.601163999999997	54.841858000000002	54.821733000000002	0103000020E61000000100000005000000ED0E2906484A4040A185048C2E694B40ED0E2906484A404020F0C000C26B4B402AC423F1F24C404020F0C000C26B4B402AC423F1F24C4040A185048C2E694B40ED0E2906484A4040A185048C2E694B40
20112	Тверицы	1	13	1378	32.435102000000001	32.450400000000002	54.949497000000001	54.932068999999998	0103000020E610000001000000050000004C361E6CB1374040C64E78094E774B404C361E6CB13740403753211E89794B40280F0BB5A63940403753211E89794B40280F0BB5A6394040C64E78094E774B404C361E6CB1374040C64E78094E774B40
47315	Соловьево	1	13	1378	32.699368	32.723407000000002	54.938177000000003	54.921121999999997	0103000020E6100000010000000500000039EFFFE38459404024D06053E7754B4039EFFFE384594040016E162F16784B404759BF99985C4040016E162F16784B404759BF99985C404024D06053E7754B4039EFFFE38459404024D06053E7754B40
60489	Русаново	1	13	1378	32.530566	32.540239999999997	54.927402999999998	54.917349999999999	0103000020E610000001000000050000004D2F3196E9434040287E8CB96B754B404D2F3196E94340402C9B3924B5764B40DAFE9595264540402C9B3924B5764B40DAFE959526454040287E8CB96B754B404D2F3196E9434040287E8CB96B754B40
20058	Пищулино	1	13	1378	32.459508999999997	32.475706000000002	54.888423000000003	54.877992999999996	0103000020E61000000100000005000000DC9BDF30D13A4040F78E1A1362704B40DC9BDF30D13A4040D20149D8B7714B40684128EFE33C4040D20149D8B7714B40684128EFE33C4040F78E1A1362704B40DC9BDF30D13A4040F78E1A1362704B40
20290	Нетризово	1	13	1378	32.342387000000002	32.367530000000002	54.716320000000003	54.701314000000004	0103000020E61000000100000005000000ACC95356D32B40400D1D3BA8C4594B40ACC95356D32B404041BCAE5FB05B4B40422619390B2F404041BCAE5FB05B4B40422619390B2F40400D1D3BA8C4594B40ACC95356D32B40400D1D3BA8C4594B40
47240	Мольково	1	13	1378	32.379145999999999	32.400345999999999	54.872999	54.859456000000002	0103000020E6100000010000000500000061342BDB87304040ED2C7AA7026E4B4061342BDB873040406938656EBE6F4B40CE8AA8893E3340406938656EBE6F4B40CE8AA8893E334040ED2C7AA7026E4B4061342BDB87304040ED2C7AA7026E4B40
19927	Кардымово	1	13	1378	32.399987000000003	32.479441999999999	54.902237	54.876372000000003	0103000020E610000001000000050000009FE925C632334040A8902BF52C704B409FE925C632334040DE1E84807C734B40172AFF5A5E3D4040DE1E84807C734B40172AFF5A5E3D4040A8902BF52C704B409FE925C632334040A8902BF52C704B40
47221	Каменка	1	13	1378	32.297083999999998	32.319884000000002	55.030203999999998	55.009543000000001	0103000020E610000001000000050000001A1538D906264040EF737CB438814B401A1538D906264040AC1A84B9DD834B40C0417BF5F1284040AC1A84B9DD834B40C0417BF5F1284040EF737CB438814B401A1538D906264040EF737CB438814B40
20420	Вачково	1	13	1378	32.542352000000001	32.561971	54.853023999999998	54.842241999999999	0103000020E61000000100000005000000C97553CA6B454040A8A8FA95CE6B4B40C97553CA6B454040FF59F3E32F6D4B4074266DAAEE474040FF59F3E32F6D4B4074266DAAEE474040A8A8FA95CE6B4B40C97553CA6B454040A8A8FA95CE6B4B40
20040	Варваровщина	1	13	1378	32.371133	32.394542999999999	54.943344000000003	54.929327000000001	0103000020E61000000100000005000000B2BB4049812F40401825E82FF4764B40B2BB4049812F40405D70067FBF784B40D0EE9062803240405D70067FBF784B40D0EE9062803240401825E82FF4764B40B2BB4049812F40401825E82FF4764B40
49120	Березкино	1	13	1378	32.482551000000001	32.504685000000002	54.908366000000001	54.895071999999999	0103000020E6100000010000000500000078D32D3BC43D40405CC823B891724B4078D32D3BC43D404030664B5645744B4011E4A0849940404030664B5645744B4011E4A084994040405CC823B891724B4078D32D3BC43D40405CC823B891724B40
46908	Сукромля	1	13	1586	32.929057999999998	32.959708999999997	53.636963999999999	53.608595999999999	0103000020E61000000100000005000000280B5F5FEB764040FB3C4679E6CD4A40280B5F5FEB7640405B5D4E0988D14A40A35698BED77A40405B5D4E0988D14A40A35698BED77A4040FB3C4679E6CD4A40280B5F5FEB764040FB3C4679E6CD4A40
19721	Рухань	1	13	1586	32.829766999999997	32.871189000000001	53.538440000000001	53.515445	0103000020E61000000100000005000000672618CE356A404080F10C1AFAC14A40672618CE356A4040DB6D179AEBC44A4046D1031F836F4040DB6D179AEBC44A4046D1031F836F404080F10C1AFAC14A40672618CE356A404080F10C1AFAC14A40
54856	Поселки	1	13	1586	32.413083999999998	33.087198000000001	53.803398999999999	53.412863000000002	0103000020E610000001000000050000001C40BFEFDF3440403E5DDDB1D8B44A401C40BFEFDF344040CE5147C7D5E64A406823D74D298B4040CE5147C7D5E64A406823D74D298B40403E5DDDB1D8B44A401C40BFEFDF3440403E5DDDB1D8B44A40
48278	Первомайский	1	13	1586	32.853411000000001	32.866481999999998	53.550114999999998	53.540489999999998	0103000020E61000000100000005000000F98557923C6D404053E8BCC62EC54A40F98557923C6D4040FF04172B6AC64A404D49D6E1E86E4040FF04172B6AC64A404D49D6E1E86E404053E8BCC62EC54A40F98557923C6D404053E8BCC62EC54A40
19623	Малая Язовка	1	13	1586	32.672077000000002	32.692225999999998	53.525205	53.506839999999997	0103000020E6100000010000000500000068B27F9E06564040FE261422E0C04A4068B27F9E065640400C59DDEA39C34A406FB88FDC9A5840400C59DDEA39C34A406FB88FDC9A584040FE261422E0C04A4068B27F9E06564040FE261422E0C04A40
47105	Лужная	1	13	1586	32.531014999999996	32.559688999999999	53.577246000000002	53.560701000000002	0103000020E61000000100000005000000BC57AD4CF8434040D1EAE40CC5C74A40BC57AD4CF843404098DF6932E3C94A4029779FE3A347404098DF6932E3C94A4029779FE3A3474040D1EAE40CC5C74A40BC57AD4CF8434040D1EAE40CC5C74A40
46947	Литвиновка	1	13	1586	32.575203000000002	32.593896999999998	53.622872999999998	53.606864999999999	0103000020E61000000100000005000000D2C77C40A0494040240B98C0ADCD4A40D2C77C40A0494040DC476E4DBACF4A40A41820D1044C4040DC476E4DBACF4A40A41820D1044C4040240B98C0ADCD4A40D2C77C40A0494040240B98C0ADCD4A40
46981	Кузьмичи	1	13	1586	32.557837999999997	32.616048999999997	53.554651	53.535342	0103000020E61000000100000005000000A73B4F3C674740406E162F1686C44A40A73B4F3C67474040CBD8D0CDFEC64A40E3DD91B1DA4E4040CBD8D0CDFEC64A40E3DD91B1DA4E40406E162F1686C44A40A73B4F3C674740406E162F1686C44A40
19790	Корсики	1	13	1586	32.855890000000002	32.884276999999997	53.472113	53.457681999999998	0103000020E610000001000000050000009A7CB3CD8D6D4040E3FBE25295BA4A409A7CB3CD8D6D40401B82E3326EBC4A4070CD1DFD2F7140401B82E3326EBC4A4070CD1DFD2F714040E3FBE25295BA4A409A7CB3CD8D6D4040E3FBE25295BA4A40
19744	Карды	1	13	1586	32.745488000000002	32.793143000000001	53.496760000000002	53.476084	0103000020E61000000100000005000000BDC799266C5F40400E130D52F0BC4A40BDC799266C5F404001FBE8D495BF4A409206B7B58565404001FBE8D495BF4A409206B7B5856540400E130D52F0BC4A40BDC799266C5F40400E130D52F0BC4A40
19208	Ершичи	1	13	1586	32.734959000000003	32.775391999999997	53.691800000000001	53.654082000000002	0103000020E610000001000000050000005073F222135E40407E737FF5B8D34A405073F222135E4040B8AF03E78CD84A403ECA880B40634040B8AF03E78CD84A403ECA880B406340407E737FF5B8D34A405073F222135E40407E737FF5B8D34A40
46901	Егоровка	1	13	1586	32.800150000000002	32.831232	53.658633999999999	53.648173999999997	0103000020E610000001000000050000007CF2B0506B6640400A0F9A5DF7D24A407CF2B0506B6640404F04711E4ED44A40C0B167CF656A40404F04711E4ED44A40C0B167CF656A40400A0F9A5DF7D24A407CF2B0506B6640400A0F9A5DF7D24A40
19416	Ворга	1	13	1586	32.733387	32.783082	53.770082000000002	53.735258000000002	0103000020E61000000100000005000000E1270EA0DF5D4040AA0F24EF1CDE4A40E1270EA0DF5D4040809E060C92E24A400B0BEE073C644040809E060C92E24A400B0BEE073C644040AA0F24EF1CDE4A40E1270EA0DF5D4040AA0F24EF1CDE4A40
19260	Блинные Кучи	1	13	1586	32.756528000000003	32.791814000000002	53.623497999999998	53.607799999999997	0103000020E610000001000000050000001041D5E8D56040402041F163CCCD4A401041D5E8D56040408A8F4FC8CECF4A40EA4141295A6540408A8F4FC8CECF4A40EA4141295A6540402041F163CCCD4A401041D5E8D56040402041F163CCCD4A40
60513	Шарапово	1	13	1248	33.120876000000003	33.147106000000001	54.574325000000002	54.561008999999999	0103000020E61000000100000005000000876F61DD788F40407EE19524CF474B40876F61DD788F40403A234A7B83494B40CF85915ED49240403A234A7B83494B40CF85915ED49240407EE19524CF474B40876F61DD788F40407EE19524CF474B40
54873	Фенино	1	13	1248	33.187010000000001	33.277039000000002	54.750270999999998	54.691329000000003	0103000020E61000000100000005000000320395F1EF97404061E3FA777D584B40320395F1EF974040901150E108604B40B85B920376A34040901150E108604B40B85B920376A3404061E3FA777D584B40320395F1EF97404061E3FA777D584B40
46824	Теренино	1	13	1248	33.579878999999998	33.616934000000001	54.512121	54.493231999999999	0103000020E610000001000000050000008F519E7939CA40409BABE639223F4B408F519E7939CA4040234C512E8D414B402EE57CB1F7CE4040234C512E8D414B402EE57CB1F7CE40409BABE639223F4B408F519E7939CA40409BABE639223F4B40
54874	Старое Устиново	1	13	1248	33.170921	33.182042000000003	54.658515999999999	54.652541999999997	0103000020E610000001000000050000008D9944BDE09540401AA20A7F86534B408D9944BDE095404045F295404A544B40CD3FFA264D97404045F295404A544B40CD3FFA264D9740401AA20A7F86534B408D9944BDE09540401AA20A7F86534B40
52877	Старое Мутище	1	13	1248	33.275547000000003	33.307617	54.447648999999998	54.430059999999997	0103000020E6100000010000000500000066C1C41F45A34040ACA8C1340C374B4066C1C41F45A34040268BFB8F4C394B40C9586DFE5FA74040268BFB8F4C394B40C9586DFE5FA74040ACA8C1340C374B4066C1C41F45A34040ACA8C1340C374B40
54889	Пронино	1	13	1248	33.307653000000002	33.344420999999997	54.574016999999998	54.558007000000003	0103000020E6100000010000000500000016C26A2C61A7404034F8FBC56C474B4016C26A2C61A740408C2C996379494B401E87C1FC15AC40408C2C996379494B401E87C1FC15AC404034F8FBC56C474B4016C26A2C61A7404034F8FBC56C474B40
54888	Мазово	1	13	1248	33.558183999999997	33.598734	54.645437000000001	54.623685999999999	0103000020E610000001000000050000004293C49272C740408D7C5EF1D44F4B404293C49272C740406E50FBAD9D524B406B80D250A3CC40406E50FBAD9D524B406B80D250A3CC40408D7C5EF1D44F4B404293C49272C740408D7C5EF1D44F4B40
60546	Леоново	1	13	1248	33.030945000000003	33.057462999999998	54.516542000000001	54.506261000000002	0103000020E61000000100000005000000C47C7901F6834040C11E1329CD404B40C47C7901F683404056815A0C1E424B4072DD94F25A87404056815A0C1E424B4072DD94F25A874040C11E1329CD404B40C47C7901F6834040C11E1329CD404B40
54887	Лапино	1	13	1248	33.125259	33.153350000000003	54.424613000000001	54.409917	0103000020E61000000100000005000000CC43A67C089040408789062978344B40CC43A67C089040406D3A02B859364B40BA6B09F9A09340406D3A02B859364B40BA6B09F9A09340408789062978344B40CC43A67C089040408789062978344B40
18411	Коробец	1	13	1248	33.449604999999998	33.495311000000001	54.524548000000003	54.50658	0103000020E610000001000000050000001D8F19A88CB9404062670A9DD7404B401D8F19A88CB9404053978C6324434B40AE2CD15966BF404053978C6324434B40AE2CD15966BF404062670A9DD7404B401D8F19A88CB9404062670A9DD7404B40
52849	Ивано-Гудино	1	13	1248	33.402622999999998	33.420949	54.653381000000003	54.640576000000003	0103000020E6100000010000000500000007CF842689B340401F4DF564FE514B4007CF842689B34040F56915FDA1534B40572426A8E1B54040F56915FDA1534B40572426A8E1B540401F4DF564FE514B4007CF842689B340401F4DF564FE514B40
52872	Демщино	1	13	1248	33.089002999999998	33.109126000000003	54.604368999999998	54.591234999999998	0103000020E61000000100000005000000791F4773648B404012A0A696AD4B4B40791F4773648B4040ADDBA0F65B4D4B4058923CD7F78D4040ADDBA0F65B4D4B4058923CD7F78D404012A0A696AD4B4B40791F4773648B404012A0A696AD4B4B40
52846	Гаристово	1	13	1248	33.247816	33.267668999999998	54.708004000000003	54.695252000000004	0103000020E6100000010000000500000078B6476FB89F4040433D7D04FE584B4078B6476FB89F4040F6B704E09F5A4B40969350FA42A24040F6B704E09F5A4B40969350FA42A24040433D7D04FE584B4078B6476FB89F4040433D7D04FE584B40
60529	Волково	1	13	1248	33.219645	33.228358999999998	54.743161999999998	54.736499000000002	0103000020E610000001000000050000006EDDCD531D9C4040B3446799455E4B406EDDCD531D9C4040A2D0B2EE1F5F4B40A65F22DE3A9D4040A2D0B2EE1F5F4B40A65F22DE3A9D4040B3446799455E4B406EDDCD531D9C4040B3446799455E4B40
45681	Богородицкое	1	13	1248	33.283946999999998	33.304454999999997	54.665160999999998	54.650520999999998	0103000020E610000001000000050000000E66136058A440403C2EAA4544534B400E66136058A440408EC9E2FE23554B40450DA661F8A640408EC9E2FE23554B40450DA661F8A640403C2EAA4544534B400E66136058A440403C2EAA4544534B40
17819	Шиловичи	1	13	1480	32.535227999999996	32.565223000000003	55.425184999999999	55.404167000000001	0103000020E61000000100000005000000A5F3E15982444040AC8F87BEBBB34B40A5F3E15982444040F8DF4A766CB64B4038F92D3A59484040F8DF4A766CB64B4038F92D3A59484040AC8F87BEBBB34B40A5F3E15982444040AC8F87BEBBB34B40
54854	Третьяково	1	13	1480	32.457946	32.492145000000001	55.165801000000002	55.145149000000004	0103000020E61000000100000005000000C1AA7AF99D3A40400806103E94924B40C1AA7AF99D3A4040725298F738954B40E9F17B9BFE3E4040725298F738954B40E9F17B9BFE3E40400806103E94924B40C1AA7AF99D3A40400806103E94924B40
17972	Спас-Углы	1	13	1480	32.474744000000001	32.494633	55.339145000000002	55.320124999999997	0103000020E6100000010000000500000072FC5069C43C4040E5D022DBF9A84B4072FC5069C43C40400CCD751A69AB4B40DD425722503F40400CCD751A69AB4B40DD425722503F4040E5D022DBF9A84B4072FC5069C43C4040E5D022DBF9A84B40
46240	Пречистое	1	13	1480	32.335918999999997	32.388433999999997	55.521780999999997	55.495699999999999	0103000020E61000000100000005000000718DCF64FF2A40404850FC1873BF4B40718DCF64FF2A40404B5645B8C9C24B40C5538F34B83140404B5645B8C9C24B40C5538F34B83140404850FC1873BF4B40718DCF64FF2A40404850FC1873BF4B40
46025	Петрищево	1	13	1480	32.010548999999997	32.042852000000003	55.136899999999997	55.123928999999997	0103000020E61000000100000005000000B4006DAB590140405303CDE7DC8F4B40B4006DAB5901404044696FF085914B40BB48A12C7C05404044696FF085914B40BB48A12C7C0540405303CDE7DC8F4B40B4006DAB590140405303CDE7DC8F4B40
45951	Озерный	1	13	1480	32.402807000000003	32.437069000000001	55.615938999999997	55.572299000000001	0103000020E61000000100000005000000C9CC052E8F3340404A44F81741C94B40C9CC052E8F3340405CAAD216D7CE4B40378C82E0F13740405CAAD216D7CE4B40378C82E0F13740404A44F81741C94B40C9CC052E8F3340404A44F81741C94B40
46078	Митяево	1	13	1480	32.357064999999999	32.376612000000002	55.284292000000001	55.272435999999999	0103000020E61000000100000005000000EBC5504EB42D40406420CF2EDFA24B40EBC5504EB42D4040D94125AE63A44B40FDA36FD234304040D94125AE63A44B40FDA36FD2343040406420CF2EDFA24B40EBC5504EB42D40406420CF2EDFA24B40
49128	Липки	1	13	1480	32.535057000000002	32.542037000000001	55.578420999999999	55.575012000000001	0103000020E61000000100000005000000793F6EBF7C4440405E6743FE99C94B40793F6EBF7C444040E92807B309CA4B40691CEA7761454040E92807B309CA4B40691CEA77614540405E6743FE99C94B40793F6EBF7C4440405E6743FE99C94B40
17519	Зимец	1	13	1480	32.384014000000001	32.405394000000001	55.228634	55.211208999999997	0103000020E61000000100000005000000639AE95E2731404078CF81E5089B4B40639AE95E27314040786000E1439D4B4050FF59F3E3334040786000E1439D4B4050FF59F3E333404078CF81E5089B4B40639AE95E2731404078CF81E5089B4B40
17468	Ерыши	1	13	1480	32.231462999999998	32.253453	55.255184999999997	55.242063000000002	0103000020E61000000100000005000000F59D5F94A01D40402C499EEBFB9E4B40F59D5F94A01D404002B7EEE6A9A04B405B09DD257120404002B7EEE6A9A04B405B09DD25712040402C499EEBFB9E4B40F59D5F94A01D40402C499EEBFB9E4B40
16976	Духовщина	1	13	1480	32.377214000000002	32.429011000000003	55.208348000000001	55.182479999999998	0103000020E61000000100000005000000F3CB608C48304040481630815B974B40F3CB608C48304040F017B325AB9A4B40E84F1BD5E9364040F017B325AB9A4B40E84F1BD5E9364040481630815B974B40F3CB608C48304040481630815B974B40
54944	Добрино	1	13	1480	32.428131	32.440500999999998	55.620981999999998	55.606791999999999	0103000020E61000000100000005000000AFB321FFCC364040BABC395CABCD4B40AFB321FFCC364040CCB392567CCF4B407A6D365662384040CCB392567CCF4B407A6D365662384040BABC395CABCD4B40AFB321FFCC364040BABC395CABCD4B40
54890	Воронцово	1	13	1480	32.510641	32.537914000000001	55.587769000000002	55.578065000000002	0103000020E61000000100000005000000957F2DAF5C4140402BFBAE08FEC94B40957F2DAF5C414040234DBC033CCB4B40C007AF5DDA444040234DBC033CCB4B40C007AF5DDA4440402BFBAE08FEC94B40957F2DAF5C4140402BFBAE08FEC94B40
17779	Верешковичи 1-е	1	13	1480	32.421419999999998	32.433124999999997	55.479602	55.474215000000001	0103000020E61000000100000005000000AEF02E17F1354040E622BE13B3BC4B40AEF02E17F1354040508C2C9963BD4B403D0AD7A370374040508C2C9963BD4B403D0AD7A370374040E622BE13B3BC4B40AEF02E17F1354040E622BE13B3BC4B40
17581	Велисто	1	13	1480	32.206229	32.220233999999998	55.663953999999997	55.645634000000001	0103000020E610000001000000050000004F3E3DB6651A4040C4978922A4D24B404F3E3DB6651A40403106D671FCD44B40CFBBB1A0301C40403106D671FCD44B40CFBBB1A0301C4040C4978922A4D24B404F3E3DB6651A4040C4978922A4D24B40
17359	Большое Береснево	1	13	1480	32.308475000000001	32.324536999999999	55.359318000000002	55.349066000000001	0103000020E610000001000000050000001A51DA1B7C274040A112D731AEAC4B401A51DA1B7C2740409C6ED921FEAD4B40C5ABAC6D8A2940409C6ED921FEAD4B40C5ABAC6D8A294040A112D731AEAC4B401A51DA1B7C274040A112D731AEAC4B40
45984	Бабино	1	13	1480	32.378867	32.400517000000001	55.170918	55.158745000000003	0103000020E610000001000000050000004E44BFB67E304040A7B393C151944B404E44BFB67E3040401C261AA4E0954B40FB3E1C24443340401C261AA4E0954B40FB3E1C2444334040A7B393C151944B404E44BFB67E304040A7B393C151944B40
21825	нежилой населенный пункт Марково	1	13	303	33.112234000000001	33.124082999999999	55.033914000000003	55.029420000000002	0103000020E61000000100000005000000E8BF07AF5D8E404096ECD808C4834B40E8BF07AF5D8E40403370404B57844B40AA7EA5F3E18F40403370404B57844B40AA7EA5F3E18F404096ECD808C4834B40E8BF07AF5D8E404096ECD808C4834B40
45603	Шаломино	1	13	303	33.305084000000001	33.327900999999997	54.991790000000002	54.982982999999997	0103000020E61000000100000005000000354415FE0CA7404011C30E63D27D4B40354415FE0CA74040FB3F87F9F27E4B40B0A9F3A8F8A94040FB3F87F9F27E4B40B0A9F3A8F8A9404011C30E63D27D4B40354415FE0CA7404011C30E63D27D4B40
45705	Ушаково	1	13	303	33.450988000000002	33.481405000000002	54.743639999999999	54.736623000000002	0103000020E61000000100000005000000B9718BF9B9B940409F3D97A9495E4B40B9718BF9B9B94040ACFF73982F5F4B40C190D5AD9EBD4040ACFF73982F5F4B40C190D5AD9EBD40409F3D97A9495E4B40B9718BF9B9B940409F3D97A9495E4B40
16460	Усвятье	1	13	303	33.098427000000001	33.120587999999998	54.945500000000003	54.932187999999996	0103000020E610000001000000050000008E058541998C4040A0DCB6EF51774B408E058541998C40401B2FDD2406794B402025766D6F8F40401B2FDD2406794B402025766D6F8F4040A0DCB6EF51774B408E058541998C4040A0DCB6EF51774B40
54894	Слоиково	1	13	303	33.145831000000001	33.173005000000003	54.946193000000001	54.935969	0103000020E610000001000000050000001ADF1797AA924040F0880AD5CD774B401ADF1797AA924040215A2BDA1C794B40B285200725964040215A2BDA1C794B40B285200725964040F0880AD5CD774B401ADF1797AA924040F0880AD5CD774B40
54845	Садовая	1	13	303	33.264417000000002	33.285356999999998	54.951472000000003	54.936393000000002	0103000020E61000000100000005000000D3C08F6AD8A14040079ACFB9DB774B40D3C08F6AD8A14040A587A1D5C9794B40A357039486A44040A587A1D5C9794B40A357039486A44040079ACFB9DB774B40D3C08F6AD8A14040079ACFB9DB774B40
45650	Полибино	1	13	303	33.423876999999997	33.447933999999997	54.955438000000001	54.931722000000001	0103000020E610000001000000050000006743FE9941B640405B7B9FAA42774B406743FE9941B6404086ADD9CA4B7A4B401B62BCE655B9404086ADD9CA4B7A4B401B62BCE655B940405B7B9FAA42774B406743FE9941B640405B7B9FAA42774B40
16559	Мархоткино	1	13	303	33.523913999999998	33.543030000000002	54.677520999999999	54.662886	0103000020E6100000010000000500000051F52B9D0FC34040F67CCD72D9544B4051F52B9D0FC3404036AD1402B9564B409A5FCD0182C5404036AD1402B9564B409A5FCD0182C54040F67CCD72D9544B4051F52B9D0FC34040F67CCD72D9544B40
45524	Княщина	1	13	303	33.344745000000003	33.377110999999999	54.839328000000002	54.825851	0103000020E61000000100000005000000D23AAA9A20AC4040382F4E7CB5694B40D23AAA9A20AC4040FD4E93196F6B4B401EFB592C45B04040FD4E93196F6B4B401EFB592C45B04040382F4E7CB5694B40D23AAA9A20AC4040382F4E7CB5694B40
45636	Каськово	1	13	303	33.093926000000003	33.116563999999997	54.811476999999996	54.791486999999996	0103000020E610000001000000050000003F1F65C4058C4040C51A2E724F654B403F1F65C4058C4040643A747ADE674B400AF2B391EB8E4040643A747ADE674B400AF2B391EB8E4040C51A2E724F654B403F1F65C4058C4040C51A2E724F654B40
49192	Ивонино	1	13	303	33.311003999999997	33.318182	54.927475000000001	54.923523000000003	0103000020E610000001000000050000006C76A4FACEA740404A0D6D0036764B406C76A4FACEA74040C66D3480B7764B4083161230BAA84040C66D3480B7764B4083161230BAA840404A0D6D0036764B406C76A4FACEA740404A0D6D0036764B40
1355	Дорогобуж	1	13	303	33.256799999999998	33.376553999999999	54.936776000000002	54.887393000000003	0103000020E6100000010000000500000070CE88D2DEA0404084D9041896714B4070CE88D2DEA04040BFD6A546E8774B40C896E5EB32B04040BFD6A546E8774B40C896E5EB32B0404084D9041896714B4070CE88D2DEA0404084D9041896714B40
16780	Верхнеднепровский	1	13	303	33.329545000000003	33.379761000000002	54.993974999999999	54.971192000000002	0103000020E61000000100000005000000B9C7D2872EAA40408411FB04507C4B40B9C7D2872EAA40405305A3923A7F4B40ECA529029CB040405305A3923A7F4B40ECA529029CB040408411FB04507C4B40B9C7D2872EAA40408411FB04507C4B40
60532	Васино	1	13	303	33.608049999999999	33.625216999999999	54.960611999999998	54.947212	0103000020E61000000100000005000000992A1895D4CD40407B30293E3E794B40992A1895D4CD404094128255F57A4B409DF3531C07D0404094128255F57A4B409DF3531C07D040407B30293E3E794B40992A1895D4CD40407B30293E3E794B40
45498	Быково	1	13	303	33.000231999999997	33.021135999999998	54.914772999999997	54.896988	0103000020E61000000100000005000000D234289A07804040C573B680D0724B40D234289A07804040C4211B4817754B4056629E95B4824040C4211B4817754B4056629E95B4824040C573B680D0724B40D234289A07804040C573B680D0724B40
14877	Шапы	1	13	1341	31.806721	31.829654999999999	55.330081	55.320529000000001	0103000020E6100000010000000500000015FF774485CE3F40B535221807A94B4015FF774485CE3F40F7031E1840AA4B407FF6234564D43F40F7031E1840AA4B407FF6234564D43F40B535221807A94B4015FF774485CE3F40B535221807A94B40
54899	Центральная Усадьба	1	13	1341	31.171396999999999	32.147298999999997	55.787385999999998	55.035699000000001	0103000020E61000000100000005000000ECA17DACE02B3F40FDBFEAC891844B40ECA17DACE02B3F4004AA7F10C9E44B40E3DD91B1DA12404004AA7F10C9E44B40E3DD91B1DA124040FDBFEAC891844B40ECA17DACE02B3F40FDBFEAC891844B40
46340	Троицкое	1	13	1341	31.489041	31.496632000000002	55.407034000000003	55.402909000000001	0103000020E6100000010000000500000034677DCA317D3F40CD21A98592B34B4034677DCA317D3F40172EABB019B44B40A7255646237F3F40172EABB019B44B40A7255646237F3F40CD21A98592B34B4034677DCA317D3F40CD21A98592B34B40
14821	Титовщина	1	13	1341	31.480982999999998	31.496596	55.248016	55.234189000000001	0103000020E6100000010000000500000095EEAEB3217B3F409E0AB8E7F99D4B4095EEAEB3217B3F403F7100FDBE9F4B400D535BEA207F3F403F7100FDBE9F4B400D535BEA207F3F409E0AB8E7F99D4B4095EEAEB3217B3F409E0AB8E7F99D4B40
14926	Пржевальское	1	13	1341	31.823969000000002	31.909192000000001	55.514890999999999	55.486891999999997	0103000020E61000000100000005000000F7EAE3A1EFD23F408E57207A52BE4B40F7EAE3A1EFD23F409B00C3F2E7C14B40EBC891CEC0E83F409B00C3F2E7C14B40EBC891CEC0E83F408E57207A52BE4B40F7EAE3A1EFD23F408E57207A52BE4B40
49534	Подосинки	1	13	1341	31.883177	31.897387999999999	55.687710000000003	55.672504000000004	0103000020E6100000010000000500000053944BE317E23F40F0366F9C14D64B4053944BE317E23F40EB909BE106D84B40A6D24F38BBE53F40EB909BE106D84B40A6D24F38BBE53F40F0366F9C14D64B4053944BE317E23F40F0366F9C14D64B40
15092	Корево	1	13	1341	31.914518999999999	31.936941000000001	55.372171000000002	55.365540000000003	0103000020E610000001000000050000001492CCEA1DEA3F409FB0C403CAAE4B401492CCEA1DEA3F4083C2A04CA3AF4B401348895DDBEF3F4083C2A04CA3AF4B401348895DDBEF3F409FB0C403CAAE4B401492CCEA1DEA3F409FB0C403CAAE4B40
15290	Закрутье	1	13	1341	31.385940999999999	31.405173999999999	55.374288	55.360894000000002	0103000020E610000001000000050000007F2F8507CD623F404CA94BC631AE4B407F2F8507CD623F4083A44FABE8AF4B408330B77BB9673F4083A44FABE8AF4B408330B77BB9673F404CA94BC631AE4B407F2F8507CD623F404CA94BC631AE4B40
60515	Жуково	1	13	1341	31.925163999999999	31.938234000000001	55.688634	55.681995999999998	0103000020E61000000100000005000000C16F438CD7EC3F405C001AA54BD74B40C16F438CD7EC3F40F374AE2825D84B40CAFE791A30F03F40F374AE2825D84B40CAFE791A30F03F405C001AA54BD74B40C16F438CD7EC3F405C001AA54BD74B40
14722	Жичицы	1	13	1341	31.267714000000002	31.303718	55.114913999999999	55.098156000000003	0103000020E610000001000000050000006DAE9AE788443F40FEF33460908C4B406DAE9AE788443F4020ED7F80B58E4B40DF347D76C04D3F4020ED7F80B58E4B40DF347D76C04D3F40FEF33460908C4B406DAE9AE788443F40FEF33460908C4B40
54941	Дубровка	1	13	1341	31.344179	31.368342999999999	55.189371999999999	55.177970999999999	0103000020E6100000010000000500000051F86C1D1C583F407651F4C0C7964B4051F86C1D1C583F40996379573D984B40E5B512BA4B5E3F40996379573D984B40E5B512BA4B5E3F407651F4C0C7964B4051F86C1D1C583F407651F4C0C7964B40
54898	Верхнии Моховичи	1	13	1341	31.518380000000001	31.547063000000001	55.349736999999998	55.334643999999997	0103000020E6100000010000000500000086E63A8DB4843F40BCE6559DD5AA4B4086E63A8DB4843F40BF99982EC4AC4B4006DA1D520C8C3F40BF99982EC4AC4B4006DA1D520C8C3F40BCE6559DD5AA4B4086E63A8DB4843F40BCE6559DD5AA4B40
14580	Борода	1	13	1341	31.297152000000001	31.316780000000001	55.339514000000001	55.323106000000003	0103000020E61000000100000005000000E5F04927124C3F40199293895BA94B40E5F04927124C3F405F44DB3175AB4B40E2067C7E18513F405F44DB3175AB4B40E2067C7E18513F40199293895BA94B40E5F04927124C3F40199293895BA94B40
46666	Борки	1	13	1341	31.895394	31.906838	55.703839000000002	55.695753000000003	0103000020E61000000100000005000000DD088B8A38E53F40058C2E6F0ED94B40DD088B8A38E53F401E53776517DA4B4022C5008926E83F401E53776517DA4B4022C5008926E83F40058C2E6F0ED94B40DD088B8A38E53F40058C2E6F0ED94B40
54897	Бакланово	1	13	1341	31.643802999999998	31.684937000000001	55.515946	55.505719999999997	0103000020E610000001000000050000001211FE45D0A43F407077D66EBBC04B401211FE45D0A43F404240BE840AC24B4003D2FE0758AF3F404240BE840AC24B4003D2FE0758AF3F407077D66EBBC04B401211FE45D0A43F407077D66EBBC04B40
60472	Ханино	1	13	1311	32.780459	32.805576000000002	54.484105999999997	54.465988000000003	0103000020E61000000100000005000000376F9C14E66340400B2AAA7EA53B4B40376F9C14E663404010E6762FF73D4B40A438471D1D67404010E6762FF73D4B40A438471D1D6740400B2AAA7EA53B4B40376F9C14E66340400B2AAA7EA53B4B40
49238	Петропавловка	1	13	1311	32.851236999999998	32.870362	54.644202	54.634422000000001	0103000020E6100000010000000500000094128255F56C404074EE76BD34514B4094128255F56C404047020D3675524B4030D7A205686F404047020D3675524B4030D7A205686F404074EE76BD34514B4094128255F56C404074EE76BD34514B40
14152	Новобрыкино	1	13	1311	32.990215999999997	33.012	54.684443999999999	54.670580999999999	0103000020E61000000100000005000000EBFCDB65BF7E4040D4282499D5554B40EBFCDB65BF7E4040C2F869DC9B574B40A8C64B3789814040C2F869DC9B574B40A8C64B3789814040D4282499D5554B40EBFCDB65BF7E4040D4282499D5554B40
14075	Дубосище	1	13	1311	32.702233999999997	32.740259000000002	54.657131	54.636240999999998	0103000020E61000000100000005000000D311C0CDE2594040EAAF575870514B40D311C0CDE259404009185DDE1C544B40EBC891CEC05E404009185DDE1C544B40EBC891CEC05E4040EAAF575870514B40D311C0CDE2594040EAAF575870514B40
14014	Добромино	1	13	1311	32.671269000000002	32.726443000000003	54.715249	54.693322000000002	0103000020E61000000100000005000000C9E88024EC55404075CC79C6BE584B40C9E88024EC55404094BF7B478D5B4B403EB48F15FC5C404094BF7B478D5B4B403EB48F15FC5C404075CC79C6BE584B40C9E88024EC55404075CC79C6BE584B40
49147	Глинка	1	13	1311	32.856816000000002	32.893566	54.654766000000002	54.622044000000002	0103000020E6100000010000000500000043588D25AC6D4040265646239F4F4B4043588D25AC6D404031444E5FCF534B40A568E55E6072404031444E5FCF534B40A568E55E60724040265646239F4F4B4043588D25AC6D4040265646239F4F4B40
13855	Белый  Холм	1	13	1311	32.604819999999997	32.629604999999998	54.616998000000002	54.600478000000003	0103000020E61000000100000005000000BDFBE3BD6A4D4040D7FB8D76DC4C4B40BDFBE3BD6A4D404045D95BCAF94E4B40F4328AE59650404045D95BCAF94E4B40F4328AE596504040D7FB8D76DC4C4B40BDFBE3BD6A4D4040D7FB8D76DC4C4B40
12810	Черногубцево	1	13	1219	34.933019999999999	34.952981000000001	55.557699	55.549083000000003	0103000020E61000000100000005000000C84109336D77414011E50B5A48C64B40C84109336D77414086014BAE62C74B40CD5A0A48FB79414086014BAE62C74B40CD5A0A48FB79414011E50B5A48C64B40C84109336D77414011E50B5A48C64B40
48974	Токарево	1	13	1219	35.094150999999997	35.133640999999997	55.328043000000001	55.309868000000002	0103000020E610000001000000050000005EF1D4230D8C4140D9092FC1A9A74B405EF1D4230D8C414043572250FDA94B40CE33F6251B91414043572250FDA94B40CE33F6251B914140D9092FC1A9A74B405EF1D4230D8C4140D9092FC1A9A74B40
13398	Серго-Ивановское	1	13	1219	34.751649999999998	34.765951000000001	55.494281999999998	55.479005000000001	0103000020E61000000100000005000000EA043411366041406CCF2C0950BD4B40EA043411366041403080F0A144BF4B4054ABAFAE0A6241403080F0A144BF4B4054ABAFAE0A6241406CCF2C0950BD4B40EA043411366041406CCF2C0950BD4B40
13307	Родоманово	1	13	1219	34.78248	34.814819999999997	55.640604000000003	55.628317000000003	0103000020E6100000010000000500000015E3FC4D28644140AB4203B16CD04B4015E3FC4D28644140E9D7D64FFFD14B40381092054C684140E9D7D64FFFD14B40381092054C684140AB4203B16CD04B4015E3FC4D28644140AB4203B16CD04B40
40431	Пышково	1	13	1219	35.291097000000001	35.324730000000002	55.632992000000002	55.621135000000002	0103000020E610000001000000050000005B7B9FAA42A5414053B3075A81CF4B405B7B9FAA42A541409850C1E105D14B40DA03ADC090A941409850C1E105D14B40DA03ADC090A9414053B3075A81CF4B405B7B9FAA42A5414053B3075A81CF4B40
49322	Покров	1	13	1219	35.027495999999999	35.059286999999998	55.370865999999999	55.354328000000002	0103000020E61000000100000005000000AA622AFD848341404F07B29E5AAD4B40AA622AFD8483414063997E8978AF4B40FA0967B79687414063997E8978AF4B40FA0967B7968741404F07B29E5AAD4B40AA622AFD848341404F07B29E5AAD4B40
48827	Петушки	1	13	1219	35.139856999999999	35.164991999999998	55.864212000000002	55.847306000000003	0103000020E61000000100000005000000EF8E8CD5E691414030DAE38574EC4B40EF8E8CD5E6914140C767B27F9EEE4B40020D36751E954140C767B27F9EEE4B40020D36751E95414030DAE38574EC4B40EF8E8CD5E691414030DAE38574EC4B40
60547	Никольское	1	13	1219	35.036811	35.071638999999998	55.442010000000003	55.420684000000001	0103000020E6100000010000000500000008910C39B6844140A9F92AF9D8B54B4008910C39B6844140A3409FC893B84B401F0F7D772B894140A3409FC893B84B401F0F7D772B894140A9F92AF9D8B54B4008910C39B6844140A9F92AF9D8B54B40
13156	Молоченево	1	13	1219	34.971063999999998	34.983657999999998	55.374881999999999	55.364807999999996	0103000020E6100000010000000500000056293DD34B7C4140DAA84E07B2AE4B4056293DD34B7C4140F6ED2422FCAF4B4071395E81E87D4140F6ED2422FCAF4B4071395E81E87D4140DAA84E07B2AE4B4056293DD34B7C4140DAA84E07B2AE4B40
48796	Липцы	1	13	1219	34.855665999999999	34.862484000000002	55.740076000000002	55.731470000000002	0103000020E610000001000000050000004A26A776866D4140A80018CFA0DD4B404A26A776866D4140FA4674CFBADE4B4061A92EE0656E4140FA4674CFBADE4B4061A92EE0656E4140A80018CFA0DD4B404A26A776866D4140A80018CFA0DD4B40
60488	Колокольня	1	13	1219	34.945146999999999	34.964129	55.506428	55.498184000000002	0103000020E61000000100000005000000CD74AF93FA784140FBB1497EC4BF4B40CD74AF93FA784140ACE3F8A1D2C04B4006103E94687B4140ACE3F8A1D2C04B4006103E94687B4140FBB1497EC4BF4B40CD74AF93FA784140FBB1497EC4BF4B40
49051	Клушино	1	13	1219	35.038518000000003	35.064210000000003	55.674807999999999	55.662922999999999	0103000020E6100000010000000500000057276728EE84414013622EA9DAD44B4057276728EE844140228AC91B60D64B40C009850838884140228AC91B60D64B40C00985083888414013622EA9DAD44B4057276728EE84414013622EA9DAD44B40
48754	Карманово	1	13	1219	34.847518000000001	34.885354999999997	55.860205999999998	55.823782999999999	0103000020E61000000100000005000000BB6246787B6C41401900AAB871E94B40BB6246787B6C414057E9EE3A1BEE4B40CF2C09505371414057E9EE3A1BEE4B40CF2C0950537141401900AAB871E94B40BB6246787B6C41401900AAB871E94B40
40430	Ивино	1	13	1219	34.686163000000001	34.711325000000002	55.752673000000001	55.739705999999998	0103000020E61000000100000005000000D55C6E30D4574140D653ABAFAEDE4B40D55C6E30D457414086CABF9657E04B40E2E995B20C5B414086CABF9657E04B40E2E995B20C5B4140D653ABAFAEDE4B40D55C6E30D4574140D653ABAFAEDE4B40
45646	Ивановское	1	13	1219	35.174658000000001	35.190513000000003	55.423856999999998	55.414368000000003	0103000020E610000001000000050000000DFE7E315B9641402541B8020AB54B400DFE7E315B964140209738F240B64B403F3BE0BA62984140209738F240B64B403F3BE0BA629841402541B8020AB54B400DFE7E315B9641402541B8020AB54B40
12155	Гагарин	1	13	1219	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
54839	Баскаково	1	13	1219	34.742891999999998	34.770757000000003	55.55444	55.544218999999998	0103000020E61000000100000005000000E23AC615175F4140506EDBF7A8C54B40E23AC615175F414010CCD1E3F7C64B40E014562AA862414010CCD1E3F7C64B40E014562AA8624140506EDBF7A8C54B40E23AC615175F4140506EDBF7A8C54B40
40427	Ашково	1	13	1219	34.975833999999999	34.990924999999997	55.609101000000003	55.589829000000002	0103000020E610000001000000050000009529E620E87C4140BF9D44847FCB4B409529E620E87C4140FF7A8505F7CD4B40F7E461A1D67E4140FF7A8505F7CD4B40F7E461A1D67E4140BF9D44847FCB4B409529E620E87C4140BF9D44847FCB4B40
40429	Астахово	1	13	1219	34.912061999999999	34.937241999999998	55.437398000000002	55.417271	0103000020E6100000010000000500000051F69672BE744140DC48D92269B54B4051F69672BE744140FCAA5CA8FCB74B400438BD8BF7774140FCAA5CA8FCB74B400438BD8BF7774140DC48D92269B54B4051F69672BE744140DC48D92269B54B40
54855	Акатово	1	13	1219	35.182419000000003	35.205308000000002	55.600476	55.586095	0103000020E61000000100000005000000A3957B8159974140B0AC342905CB4B40A3957B81599741403604C765DCCC4B40B8CD5488479A41403604C765DCCC4B40B8CD5488479A4140B0AC342905CB4B40A3957B8159974140B0AC342905CB4B40
12060	Шуйское	1	13	291	34.514755000000001	34.534680000000002	55.487167999999997	55.473939000000001	0103000020E61000000100000005000000EB39E97DE341414044A67C08AABC4B40EB39E97DE341414030D461855BBE4B40A3E9EC647044414030D461855BBE4B40A3E9EC647044414044A67C08AABC4B40EB39E97DE341414044A67C08AABC4B40
48292	Черное	1	13	291	33.984273000000002	34.001367999999999	55.198431999999997	55.185482	0103000020E61000000100000005000000FCAA5CA8FCFD404093FFC9DFBD974B40FCAA5CA8FCFD40406C3D433866994B4066A19DD32C0041406C3D433866994B4066A19DD32C00414093FFC9DFBD974B40FCAA5CA8FCFD404093FFC9DFBD974B40
48325	Черемушки	1	13	291	34.265635000000003	34.296104999999997	55.183759999999999	55.162205999999998	0103000020E6100000010000000500000024D6E25300224140849B8C2AC3944B4024D6E253002241400F289B7285974B404E97C5C4E62541400F289B7285974B404E97C5C4E6254140849B8C2AC3944B4024D6E25300224140849B8C2AC3944B40
12052	Царево-Займище	1	13	291	34.806213999999997	34.828043000000001	55.431443000000002	55.420679	0103000020E61000000100000005000000E6C9350532674140978E39CFD8B54B40E6C9350532674140488B338639B74B4043572250FD694140488B338639B74B4043572250FD694140978E39CFD8B54B40E6C9350532674140978E39CFD8B54B40
11993	Хмелита	1	13	291	33.876807999999997	33.901457999999998	55.412370000000003	55.395681000000003	0103000020E61000000100000005000000826F9A3E3BF040400553CDACA5B24B40826F9A3E3BF04040FFEC478AC8B44B40D95BCAF962F34040FFEC478AC8B44B40D95BCAF962F340400553CDACA5B24B40826F9A3E3BF040400553CDACA5B24B40
11145	Хватов Завод	1	13	291	34.222057	34.243563000000002	54.899073999999999	54.885227999999998	0103000020E61000000100000005000000876C205D6C1C414072C0AE264F714B40876C205D6C1C41408A5759DB14734B4001C287122D1F41408A5759DB14734B4001C287122D1F414072C0AE264F714B40876C205D6C1C414072C0AE264F714B40
48028	Успенское	1	13	291	34.658431999999998	34.679550999999996	55.352905	55.338689000000002	0103000020E61000000100000005000000E751F17F47544140EA4141295AAB4B40E751F17F4754414025CCB4FD2BAD4B40677BF486FB56414025CCB4FD2BAD4B40677BF486FB564140EA4141295AAB4B40E751F17F47544140EA4141295AAB4B40
48405	Туманово	1	13	291	34.635030999999998	34.661855000000003	55.430871000000003	55.410203000000003	0103000020E610000001000000050000001C7920B2485141404DDC2A8881B44B401C7920B248514140BDE5EAC726B74B40D8D825AAB7544140BDE5EAC726B74B40D8D825AAB75441404DDC2A8881B44B401C7920B2485141404DDC2A8881B44B40
11777	Семлево	1	13	291	33.947775	34.012084999999999	55.155628	55.037520999999998	0103000020E61000000100000005000000B37BF2B050F94040E4F4F57CCD844B40B37BF2B050F94040C32B499EEB934B40D6E253008C014140C32B499EEB934B40D6E253008C014140E4F4F57CCD844B40B37BF2B050F94040E4F4F57CCD844B40
47635	Пушкино	1	13	291	34.678482000000002	34.687268000000003	55.152746999999998	55.148071000000002	0103000020E610000001000000050000005C76887FD8564140363E93FDF3924B405C76887FD8564140F3C7B4368D934B402ECBD765F8574140F3C7B4368D934B402ECBD765F8574140363E93FDF3924B405C76887FD8564140363E93FDF3924B40
11661	Поляново	1	13	291	34.040984000000002	34.060243999999997	55.087527000000001	55.071226000000003	0103000020E6100000010000000500000063D4B5F63E054140FD4FFEEE1D894B4063D4B5F63E0541402D42B115348B4B40DEE34C13B60741402D42B115348B4B40DEE34C13B6074140FD4FFEEE1D894B4063D4B5F63E054140FD4FFEEE1D894B40
11568	Относово	1	13	291	34.129693000000003	34.158321999999998	55.223334999999999	55.206992	0103000020E6100000010000000500000094C2BCC7991041404E44BFB67E9A4B4094C2BCC799104140AD86C43D969C4B40601E32E543144140AD86C43D969C4B40601E32E5431441404E44BFB67E9A4B4094C2BCC7991041404E44BFB67E9A4B40
54846	Новый	1	13	291	34.516992000000002	34.559330000000003	55.170299999999997	55.155740999999999	0103000020E6100000010000000500000096253ACB2C424140BBD23252EF934B4096253ACB2C4241402041F163CC954B40FAD51C20984741402041F163CC954B40FAD51C2098474140BBD23252EF934B4096253ACB2C424140BBD23252EF934B40
60474	Новоникольское	1	13	291	34.428742	34.687106	55.344070000000002	55.227063000000001	0103000020E61000000100000005000000F8359204E1364140DA907F66109D4B40F8359204E136414072C45A7C0AAC4B405471E316F357414072C45A7C0AAC4B405471E316F3574140DA907F66109D4B40F8359204E1364140DA907F66109D4B40
11323	Малая Калпита	1	13	291	33.858409999999999	33.883966999999998	54.959563000000003	54.948928000000002	0103000020E610000001000000050000009947FE60E0ED40401D21037976794B409947FE60E0ED4040D0B9DBF5D27A4B4022DFA5D425F14040D0B9DBF5D27A4B4022DFA5D425F140401D21037976794B409947FE60E0ED40401D21037976794B40
52449	Крутое	1	13	291	34.809061	34.81915	55.323146999999999	55.317937000000001	0103000020E610000001000000050000000ABC934F8F6741401C98DC28B2A84B400ABC934F8F674140776682E15CA94B405B423EE8D9684140776682E15CA94B405B423EE8D96841401C98DC28B2A84B400ABC934F8F6741401C98DC28B2A84B40
11341	Касня	1	13	291	34.305456999999997	34.341541999999997	55.406931999999998	55.391381000000003	0103000020E61000000100000005000000C9AA0837192741404DA3C9C518B24B40C9AA08371927414012D9075916B44B40EF1AF4A5B72B414012D9075916B44B40EF1AF4A5B72B41404DA3C9C518B24B40C9AA0837192741404DA3C9C518B24B40
60493	Капустино	1	13	291	34.092305000000003	34.100442999999999	55.058250000000001	55.054623999999997	0103000020E61000000100000005000000EF2076A6D00B4140D1C952EBFD864B40EF2076A6D00B4140FA7E6ABC74874B405A0EF450DB0C4140FA7E6ABC74874B405A0EF450DB0C4140D1C952EBFD864B40EF2076A6D00B4140D1C952EBFD864B40
11236	Кайдаково	1	13	291	34.284498999999997	34.318662000000003	55.113019000000001	55.096666999999997	0103000020E61000000100000005000000525F96766A2441401CCD91955F8C4B40525F96766A244140CF691668778E4B402E3D9AEAC9284140CF691668778E4B402E3D9AEAC92841401CCD91955F8C4B40525F96766A2441401CCD91955F8C4B40
54878	Исаково	1	13	291	34.637824999999999	34.672994000000003	55.186725000000003	55.169657999999998	0103000020E610000001000000050000001DC9E53FA45141409CC0745AB7954B401DC9E53FA45141403D2CD49AE6974B40BE33DAAA245641403D2CD49AE6974B40BE33DAAA245641409CC0745AB7954B401DC9E53FA45141409CC0745AB7954B40
40424	Дмитровка	1	13	291	34.428652	34.467100000000002	55.360531000000002	55.344617999999997	0103000020E61000000100000005000000B8AE9811DE36414074CE4F711CAC4B40B8AE9811DE364140DB183BE125AE4B4016FBCBEEC93B4140DB183BE125AE4B4016FBCBEEC93B414074CE4F711CAC4B40B8AE9811DE36414074CE4F711CAC4B40
54838	Денисово	1	13	291	34.397804000000001	34.407865000000001	55.302847999999997	55.295847000000002	0103000020E61000000100000005000000E71BD13DEB32414053CF8250DEA54B40E71BD13DEB3241405AD427B9C3A64B406E179AEB343441405AD427B9C3A64B406E179AEB3434414053CF8250DEA54B40E71BD13DEB32414053CF8250DEA54B40
10964	Вязьма Брянская	1	13	291	34.350076000000001	34.388075000000001	55.177067000000001	55.154783999999999	0103000020E61000000100000005000000A88E554ACF2C4140D7F84CF6CF934B40A88E554ACF2C4140B519A721AA964B4096B20C71AC314140B519A721AA964B4096B20C71AC314140D7F84CF6CF934B40A88E554ACF2C4140D7F84CF6CF934B40
1259	Вязьма	1	13	291	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
60475	Богородицкое	1	13	291	34.058976999999999	34.084147999999999	55.317799000000001	55.307336999999997	0103000020E61000000100000005000000AC1BEF8E8C074140E5EC9DD156A74B40AC1BEF8E8C074140CBD93BA3ADA84B400C03965CC50A4140CBD93BA3ADA84B400C03965CC50A4140E5EC9DD156A74B40AC1BEF8E8C074140E5EC9DD156A74B40
47987	Андрейково	1	13	291	34.242341000000003	34.270997999999999	55.244079999999997	55.228592999999996	0103000020E610000001000000050000006FBDA607051F4140198C1189429D4B406FBDA607051F4140C8CD70033E9F4B4005A4FD0FB0224140C8CD70033E9F4B4005A4FD0FB0224140198C1189429D4B406FBDA607051F4140198C1189429D4B40
54844	Ситьково	1	13	1097	31.309459	31.334890000000001	55.667335000000001	55.650109	0103000020E61000000100000005000000EF737CB4384F3F40EAEA8EC536D34B40EF737CB4384F3F40F33CB83B6BD54B40E8C1DD59BB553F40F33CB83B6BD54B40E8C1DD59BB553F40EAEA8EC536D34B40EF737CB4384F3F40EAEA8EC536D34B40
52458	Селезни	1	13	1097	31.459738000000002	31.490227000000001	55.656336000000003	55.638018000000002	0103000020E610000001000000050000007CBABA63B1753F403221E692AAD14B407CBABA63B1753F40FF976BD102D44B40BF9D44847F7D3F40FF976BD102D44B40BF9D44847F7D3F403221E692AAD14B407CBABA63B1753F403221E692AAD14B40
52456	Погорелье	1	13	1097	31.393245	31.428422999999999	55.581947999999997	55.570283000000003	0103000020E61000000100000005000000C6504EB4AB643F407E3B8908FFC84B40C6504EB4AB643F407EFCA5457DCA4B40ADDA3521AD6D3F407EFCA5457DCA4B40ADDA3521AD6D3F407E3B8908FFC84B40C6504EB4AB643F407E3B8908FFC84B40
52452	Печенки	1	13	1097	31.337585000000001	31.356611000000001	55.545951000000002	55.531407000000002	0103000020E61000000100000005000000C39E76F86B563F40C8EE022505C44B40C39E76F86B563F40F81BEDB8E1C54B40D464C6DB4A5B3F40F81BEDB8E1C54B40D464C6DB4A5B3F40C8EE022505C44B40C39E76F86B563F40C8EE022505C44B40
9728	Велиж	1	13	1097	31.135608000000001	31.230784	55.627763000000002	55.590353	0103000020E610000001000000050000007313B534B7223F40390CE6AF90CB4B407313B534B7223F40C651B9895AD04B40A87004A9143B3F40C651B9895AD04B40A87004A9143B3F40390CE6AF90CB4B407313B534B7223F40390CE6AF90CB4B40
54869	Будница	1	13	1097	31.040054000000001	31.074513	55.614953	55.600327999999998	0103000020E61000000100000005000000F1129CFA400A3F40C16F438CD7CC4B40F1129CFA400A3F40DEC9A7C7B6CE4B407920B24813133F40DEC9A7C7B6CE4B407920B24813133F40C16F438CD7CC4B40F1129CFA400A3F40C16F438CD7CC4B40
53067	Беляево	1	13	1097	31.080729999999999	31.106386000000001	55.514854999999997	55.503869000000002	0103000020E610000001000000050000005BCEA5B8AA143F40EF3B86C77EC04B405BCEA5B8AA143F404E97C5C4E6C14B4094C0E61C3C1B3F404E97C5C4E6C14B4094C0E61C3C1B3F40EF3B86C77EC04B405BCEA5B8AA143F40EF3B86C77EC04B40
54631	Шацк	1	12	\N	41.675010999999998	41.770519999999998	54.042203999999998	54.016188999999997	0103000020E610000001000000050000005AB8ACC266D6444008C72C7B12024B405AB8ACC266D6444054E1CFF066054B40FB743C66A0E2444054E1CFF066054B40FB743C66A0E2444008C72C7B12024B405AB8ACC266D6444008C72C7B12024B40
29992	Хирино	1	12	\N	39.547666	39.568237000000003	54.668733000000003	54.659084	0103000020E61000000100000005000000C99063EB19C643408FA850DD5C544B40C99063EB19C64340C460FE0A99554B4047B071FDBBC84340C460FE0A99554B4047B071FDBBC843408FA850DD5C544B40C99063EB19C643408FA850DD5C544B40
23653	Турлатово	1	12	\N	39.811366	39.837839000000002	54.557198	54.543751999999998	0103000020E610000001000000050000000D8B51D7DAE743403A9160AA99454B400D8B51D7DAE74340C4B2994352474B401C28F04E3EEB4340C4B2994352474B401C28F04E3EEB43403A9160AA99454B400D8B51D7DAE743403A9160AA99454B40
54626	Спасск-Рязанский	1	12	\N	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
7320	Скопин	1	12	\N	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
29173	Секиотово	1	12	\N	39.624974999999999	39.638890000000004	54.588945000000002	54.578786000000001	0103000020E61000000100000005000000A7E8482EFFCF4340FBB0DEA8154A4B40A7E8482EFFCF43404512BD8C624B4B40E8DEC325C7D143404512BD8C624B4B40E8DEC325C7D14340FBB0DEA8154A4B40A7E8482EFFCF4340FBB0DEA8154A4B40
4031	Сасово	1	12	\N	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
1114	Рязань	1	12	\N	39.537227000000001	39.853074999999997	54.705835	54.528880000000001	0103000020E610000001000000050000009CC3B5DAC3C4434016C1FF56B2434B409CC3B5DAC3C44340A3AF20CD585A4B408104C58F31ED4340A3AF20CD585A4B408104C58F31ED434016C1FF56B2434B409CC3B5DAC3C4434016C1FF56B2434B40
54596	Ряжск	1	12	\N	40.019083999999999	40.165374	53.731876	53.686233000000001	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
54589	Рыбное	1	12	\N	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
54646	Новоселки	1	12	\N	39.888702000000002	39.920098000000003	54.609358999999998	54.598652999999999	0103000020E61000000100000005000000E5F1B4FCC0F143407E5358A9A04C4B40E5F1B4FCC0F14340FA42C879FF4D4B40B98E71C5C5F54340FA42C879FF4D4B40B98E71C5C5F543407E5358A9A04C4B40E5F1B4FCC0F143407E5358A9A04C4B40
54591	Михайлов	1	12	\N	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
54625	Кораблино	1	12	\N	39.991568000000001	40.068823000000002	53.945242	53.899371000000002	0103000020E610000001000000050000004CE141B3EBFE434044FCC3961EF34A404CE141B3EBFE43401F679AB0FDF84A40371B2B31CF0844401F679AB0FDF84A40371B2B31CF08444044FCC3961EF34A404CE141B3EBFE434044FCC3961EF34A40
8703	Касимов	1	12	\N	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
19327	Дядьково	1	12	\N	39.830886	39.873817000000003	54.615955	54.598387000000002	0103000020E61000000100000005000000255AF2785AEA434000ADF9F1974C4B40255AF2785AEA434062670A9DD74E4B402CD8463CD9EF434062670A9DD74E4B402CD8463CD9EF434000ADF9F1974C4B40255AF2785AEA434000ADF9F1974C4B40
19821	Юшта	1	12	114	40.817641000000002	40.858083000000001	54.398991000000002	54.374988999999999	0103000020E61000000100000005000000336FD575A86844400CAEB9A3FF2F4B40336FD575A8684440FD32182312334B407520EBA9D56D4440FD32182312334B407520EBA9D56D44400CAEB9A3FF2F4B40336FD575A86844400CAEB9A3FF2F4B40
20535	Шилово	1	12	114	40.830325000000002	40.915917	54.332171000000002	54.286003999999998	0103000020E610000001000000050000008E06F016486A4440394371C79B244B408E06F016486A4440FED64E94842A4B40DB6CACC43C754440FED64E94842A4B40DB6CACC43C754440394371C79B244B408E06F016486A4440394371C79B244B40
52418	Фролово	1	12	114	40.515357999999999	40.544857999999998	54.312258999999997	54.298788999999999	0103000020E61000000100000005000000B1DD3D40F7414440C8B3CBB73E264B40B1DD3D40F7414440DA70581AF8274B40637B2DE8BD454440DA70581AF8274B40637B2DE8BD454440C8B3CBB73E264B40B1DD3D40F7414440C8B3CBB73E264B40
20165	Тырново	1	12	114	41.016896000000003	41.048436000000002	54.476050000000001	54.456448000000002	0103000020E6100000010000000500000074B7EBA5298244408D2958E36C3A4B4074B7EBA52982444062A1D634EF3C4B407BF99D263386444062A1D634EF3C4B407BF99D26338644408D2958E36C3A4B4074B7EBA5298244408D2958E36C3A4B40
19990	Тимошкино	1	12	114	40.914757999999999	40.951678999999999	54.292904	54.272661999999997	0103000020E610000001000000050000008FE046CA16754440546EA296E6224B408FE046CA167544400D6FD6E07D254B401EA5129ED07944400D6FD6E07D254B401EA5129ED0794440546EA296E6224B408FE046CA16754440546EA296E6224B40
19829	Терехово	1	12	114	40.930272000000002	40.946648000000003	54.417383999999998	54.396045000000001	0103000020E610000001000000050000003831242713774440465F419AB1324B403831242713774440D4EFC2D66C354B407369FCC22B794440D4EFC2D66C354B407369FCC22B794440465F419AB1324B403831242713774440465F419AB1324B40
4595	Сельцо-Сергиевка	1	12	114	41.121245000000002	41.132976999999997	54.482301	54.465114999999997	0103000020E61000000100000005000000DAE6C6F4848F444084F068E3883B4B40DAE6C6F4848F4440FFE9060ABC3D4B40620FED6305914440FFE9060ABC3D4B40620FED630591444084F068E3883B4B40DAE6C6F4848F444084F068E3883B4B40
17672	Свинчус	1	12	114	41.074272000000001	41.092516000000003	54.581342999999997	54.566057000000001	0103000020E610000001000000050000001781B1BE818944400056478E74484B401781B1BE8189444017618A72694A4B40AA2D7590D78B444017618A72694A4B40AA2D7590D78B44400056478E74484B401781B1BE818944400056478E74484B40
54660	Саськино	1	12	114	40.795119999999997	40.844392999999997	54.266258000000001	54.235464	0103000020E61000000100000005000000A032FE7DC665444053B131AF231E4B40A032FE7DC66544403126FDBD14224B4054FCDF11156C44403126FDBD14224B4054FCDF11156C444053B131AF231E4B40A032FE7DC665444053B131AF231E4B40
19513	Санское	1	12	114	40.755253000000003	40.791167999999999	54.389330000000001	54.370614000000003	0103000020E610000001000000050000005B9A5B21AC6044404AB89047702F4B405B9A5B21AC60444004ADC090D5314B4024D236FE4465444004ADC090D5314B4024D236FE446544404AB89047702F4B405B9A5B21AC6044404AB89047702F4B40
198	Сановка	1	12	114	40.847833000000001	40.865476000000001	54.236232000000001	54.215361999999999	0103000020E610000001000000050000001BBCAFCA856C44408C6665FB901B4B401BBCAFCA856C44406422A5D93C1E4B4088BCE5EAC76E44406422A5D93C1E4B4088BCE5EAC76E44408C6665FB901B4B401BBCAFCA856C44408C6665FB901B4B40
18464	Пустополье	1	12	114	40.650446000000002	40.676569000000001	54.356712999999999	54.340696000000001	0103000020E6100000010000000500000032E884D04153444063F030ED9B2B4B4032E884D0415344406E8786C5A82D4B40643E20D0995644406E8786C5A82D4B40643E20D09956444063F030ED9B2B4B4032E884D04153444063F030ED9B2B4B40
20853	Прибрежный	1	12	114	40.893171000000002	40.921405	54.359630000000003	54.347802999999999	0103000020E61000000100000005000000295E656D53724440B03907CF842C4B40295E656D537244408B54185B082E4B4079AF5A99F07544408B54185B082E4B4079AF5A99F0754440B03907CF842C4B40295E656D53724440B03907CF842C4B40
17780	Нармушадь	1	12	114	41.098553000000003	41.130228000000002	54.680492999999998	54.653979999999997	0103000020E610000001000000050000001BF67B629D8C4440791EDC9DB5534B401BF67B629D8C4440161406651A574B400283A44FAB904440161406651A574B400283A44FAB904440791EDC9DB5534B401BF67B629D8C4440791EDC9DB5534B40
19622	Муратово	1	12	114	40.542819000000001	40.561593999999999	54.387169999999998	54.376027000000001	0103000020E61000000100000005000000DF52CE177B454440DDB419A721304B40DF52CE177B45444004FF5BC98E314B409ED0EB4FE247444004FF5BC98E314B409ED0EB4FE2474440DDB419A721304B40DF52CE177B454440DDB419A721304B40
19303	Мосолово	1	12	114	40.508890000000001	40.542074	54.29663	54.275616999999997	0103000020E6100000010000000500000077A1B94E234144405E9CF86A47234B4077A1B94E234144409981CAF8F7254B4086014BAE624544409981CAF8F7254B4086014BAE624544405E9CF86A47234B4077A1B94E234144405E9CF86A47234B40
20301	Лесной	1	12	114	40.457641000000002	40.478490999999998	54.219068	54.202123999999998	0103000020E610000001000000050000008527F4FA933A44404CDE0033DF194B408527F4FA933A4440D1CC936B0A1C4B4015376E313F3D4440D1CC936B0A1C4B4015376E313F3D44404CDE0033DF194B408527F4FA933A44404CDE0033DF194B40
52386	Ладышкино	1	12	114	41.138483000000001	41.154842000000002	54.801234000000001	54.794834999999999	0103000020E61000000100000005000000A7069ACFB9914440AB5B3D27BD654B40A7069ACFB9914440BD38F1D58E664B400C06D7DCD1934440BD38F1D58E664B400C06D7DCD1934440AB5B3D27BD654B40A7069ACFB9914440AB5B3D27BD654B40
17862	Куземкино	1	12	114	41.172016999999997	41.187584999999999	54.748415999999999	54.723272999999999	0103000020E6100000010000000500000092AD2EA704964440378AAC35945C4B4092AD2EA704964440CDE67118CC5F4B402E1C08C902984440CDE67118CC5F4B402E1C08C902984440378AAC35945C4B4092AD2EA704964440378AAC35945C4B40
19207	Красный Холм	1	12	114	40.685993000000003	40.745415999999999	54.199527000000003	54.167012	0103000020E6100000010000000500000079245E9ECE574440100533A660154B4079245E9ECE574440A2D5C9198A194B4023F59ECA695F4440A2D5C9198A194B4023F59ECA695F4440100533A660154B4079245E9ECE574440100533A660154B40
19357	Красногвардейский	1	12	114	40.530656	40.569310999999999	54.257828000000003	54.241478000000001	0103000020E610000001000000050000008DB62A89EC4344400C5A48C0E81E4B408DB62A89EC4344401EFF058200214B406420CF2EDF4844401EFF058200214B406420CF2EDF4844400C5A48C0E81E4B408DB62A89EC4344400C5A48C0E81E4B40
18568	Константиново	1	12	114	40.710292000000003	40.742199999999997	54.331583000000002	54.306544000000002	0103000020E61000000100000005000000234E27D9EA5A44407C6473D53C274B40234E27D9EA5A44406D74CE4F712A4B40AC8BDB68005F44406D74CE4F712A4B40AC8BDB68005F44407C6473D53C274B40234E27D9EA5A44407C6473D53C274B40
19735	Ирицы	1	12	114	41.000134000000003	41.02084	54.388306999999998	54.362079999999999	0103000020E6100000010000000500000010CF12640480444091442FA3582E4B4010CF12640480444068E7340BB4314B406D3997E2AA82444068E7340BB4314B406D3997E2AA82444091442FA3582E4B4010CF12640480444091442FA3582E4B40
377	Инякино	1	12	114	41.101562000000001	41.131449000000003	54.457134000000003	54.416530000000002	0103000020E610000001000000050000001842CEFBFF8C4440C5E6E3DA50354B401842CEFBFF8C4440E1F1ED5D833A4B40C40B2252D3904440E1F1ED5D833A4B40C40B2252D3904440C5E6E3DA50354B401842CEFBFF8C4440C5E6E3DA50354B40
52407	Ибредь	1	12	114	40.8506	40.876992999999999	54.286859999999997	54.269644	0103000020E6100000010000000500000022FDF675E06C444004C8D0B183224B4022FDF675E06C4440E94317D4B7244B4014E97E4E41704440E94317D4B7244B4014E97E4E4170444004C8D0B183224B4022FDF675E06C444004C8D0B183224B40
19509	Заполье	1	12	114	40.567917999999999	40.612160000000003	54.319437999999998	54.292845999999997	0103000020E61000000100000005000000A5677A89B1484440D8614CFA7B254B40A5677A89B1484440C18C2958E3284B40AEF545425B4E4440C18C2958E3284B40AEF545425B4E4440D8614CFA7B254B40A5677A89B1484440D8614CFA7B254B40
18468	Занино-Починки	1	12	114	41.259028000000001	41.289912000000001	54.613447000000001	54.598142000000003	0103000020E61000000100000005000000C85F5AD427A14440992EC4EA8F4C4B40C85F5AD427A14440276A696E854E4B40E65B1FD61BA54440276A696E854E4B40E65B1FD61BA54440992EC4EA8F4C4B40C85F5AD427A14440992EC4EA8F4C4B40
18255	Задубровье	1	12	114	40.665871000000003	40.705261999999998	54.304673999999999	54.279406999999999	0103000020E610000001000000050000006B2DCC423B55444001A3CB9BC3234B406B2DCC423B55444083F8C08EFF264B40478E7406465A444083F8C08EFF264B40478E7406465A444001A3CB9BC3234B406B2DCC423B55444001A3CB9BC3234B40
18018	Желудево	1	12	114	40.862512000000002	40.901139000000001	54.271752999999997	54.257117999999998	0103000020E610000001000000050000002B3410CB666E4440419B1C3EE9204B402B3410CB666E444081CB63CDC8224B403813D3855873444081CB63CDC8224B403813D38558734440419B1C3EE9204B402B3410CB666E4440419B1C3EE9204B40
17726	Ерахтур	1	12	114	41.117175000000003	41.158228000000001	54.717033000000001	54.692915999999997	0103000020E6100000010000000500000054742497FF8E44400470B378B1584B4054742497FF8E44408E93C2BCC75B4B40DFA7AAD0409444408E93C2BCC75B4B40DFA7AAD0409444400470B378B1584B4054742497FF8E44400470B378B1584B40
20168	Дубровка	1	12	114	41.060608000000002	41.096378999999999	54.527458000000003	54.511242000000003	0103000020E6100000010000000500000020F0C000C2874440BB2BBB6070414B4020F0C000C2874440BD0166BE83434B40B682A625568C4440BD0166BE83434B40B682A625568C4440BB2BBB6070414B4020F0C000C2874440BB2BBB6070414B40
20860	Борок	1	12	114	40.940899000000002	40.965809	54.345697999999999	54.325887000000002	0103000020E6100000010000000500000068EBE0606F78444085984BAAB6294B4068EBE0606F784440742502D53F2C4B405B971AA19F7B4440742502D53F2C4B405B971AA19F7B444085984BAAB6294B4068EBE0606F78444085984BAAB6294B40
17680	Боровое	1	12	114	41.107536000000003	41.146182000000003	54.329441000000003	54.312364000000002	0103000020E61000000100000005000000439259BDC38D44405039268BFB274B40439259BDC38D4440147B681F2B2A4B40C7A17E17B6924440147B681F2B2A4B40C7A17E17B69244405039268BFB274B40439259BDC38D44405039268BFB274B40
17571	Борки	1	12	114	41.139139	41.174675999999998	54.630623	54.613498999999997	0103000020E61000000100000005000000904C874ECF91444079909E22874E4B40904C874ECF9144407E8D2441B8504B40B3B27DC85B9644407E8D2441B8504B40B3B27DC85B96444079909E22874E4B40904C874ECF91444079909E22874E4B40
54680	Большые Пекселы	1	12	114	41.268416000000002	41.296892	54.648671999999998	54.640534000000002	0103000020E6100000010000000500000090DC9A745BA24440F0FCA204FD514B4090DC9A745BA244405BEA20AF07534B40D6389B8E00A644405BEA20AF07534B40D6389B8E00A64440F0FCA204FD514B4090DC9A745BA24440F0FCA204FD514B40
20067	Березово	1	12	114	40.992552000000003	41.024999000000001	54.319679999999998	54.303564999999999	0103000020E610000001000000050000002ACAA5F10B7F4440E99AC937DB264B402ACAA5F10B7F4440B7973446EB284B4063B7CF2A33834440B7973446EB284B4063B7CF2A33834440E99AC937DB264B402ACAA5F10B7F4440E99AC937DB264B40
17466	Аделино	1	12	114	41.261346000000003	41.297044999999997	54.475495000000002	54.453375999999999	0103000020E61000000100000005000000607825C973A1444049658A39083A4B40607825C973A14440AD342905DD3C4B405C38109205A64440AD342905DD3C4B405C38109205A6444049658A39083A4B40607825C973A1444049658A39083A4B40
51975	Авдотьинка	1	12	114	40.891553999999999	40.910032999999999	54.257139000000002	54.225121999999999	0103000020E610000001000000050000001A4F04711E72444018CE35CCD01C4B401A4F04711E72444059C345EEE9204B40F0A31AF67B74444059C345EEE9204B40F0A31AF67B74444018CE35CCD01C4B401A4F04711E72444018CE35CCD01C4B40
17361	Ямбирно	1	12	1207	42.074249000000002	42.099375000000002	54.131653999999997	54.112631	0103000020E610000001000000050000005F61C1FD8009454005C24EB16A0E4B405F61C1FD800945409C31CC09DA104B401F85EB51B80C45409C31CC09DA104B401F85EB51B80C454005C24EB16A0E4B405F61C1FD8009454005C24EB16A0E4B40
16841	Шевырляй	1	12	1207	41.575063999999998	41.598312999999997	54.104512999999997	54.096271000000002	0103000020E61000000100000005000000B08D78B29BC94440D046AE9B520C4B40B08D78B29BC94440E08096AE600D4B40C5E2378595CC4440E08096AE600D4B40C5E2378595CC4440D046AE9B520C4B40B08D78B29BC94440D046AE9B520C4B40
17113	Шацк	1	12	1207	41.675010999999998	41.770519999999998	54.042203999999998	54.016188999999997	0103000020E610000001000000050000005AB8ACC266D6444008C72C7B12024B405AB8ACC266D6444054E1CFF066054B40FB743C66A0E2444054E1CFF066054B40FB743C66A0E2444008C72C7B12024B405AB8ACC266D6444008C72C7B12024B40
15099	Шарик	1	12	1207	42.090679000000002	42.124428999999999	53.893428999999998	53.886085000000001	0103000020E610000001000000050000008DB7955E9B0B4540F33CB83B6BF14A408DB7955E9B0B45402426A8E15BF24A4045D61A4AED0F45402426A8E15BF24A4045D61A4AED0F4540F33CB83B6BF14A408DB7955E9B0B4540F33CB83B6BF14A40
54604	Черная Слобода	1	12	1207	41.712471000000001	41.762524999999997	54.022055000000002	54.006807999999999	0103000020E61000000100000005000000992CEE3F32DB4440F3ACA415DF004B40992CEE3F32DB44404DDBBFB2D2024B40F2B0506B9AE144404DDBBFB2D2024B40F2B0506B9AE14440F3ACA415DF004B40992CEE3F32DB4440F3ACA415DF004B40
14619	Федяево	1	12	1207	41.632224000000001	41.660260999999998	54.195529000000001	54.182754000000003	0103000020E6100000010000000500000087DF4DB7ECD044404A9BAA7B64174B4087DF4DB7ECD04440B535221807194B4081E9B46E83D44440B535221807194B4081E9B46E83D444404A9BAA7B64174B4087DF4DB7ECD044404A9BAA7B64174B40
16210	Федосово	1	12	1207	41.390065	41.413519999999998	53.967737	53.953726000000003	0103000020E61000000100000005000000392861A6EDB1444026AC8DB113FA4A40392861A6EDB14440881057CEDEFB4A40F71E2E39EEB44440881057CEDEFB4A40F71E2E39EEB4444026AC8DB113FA4A40392861A6EDB1444026AC8DB113FA4A40
15498	Темешево	1	12	1207	41.945979000000001	41.966380000000001	54.068646999999999	54.052638999999999	0103000020E61000000100000005000000F5D901D715F9444040BFEFDFBC064B40F5D901D715F94440F8FBC56CC9084B4016C1FF56B2FB4440F8FBC56CC9084B4016C1FF56B2FB444040BFEFDFBC064B40F5D901D715F9444040BFEFDFBC064B40
16775	Тарадей	1	12	1207	41.577705000000002	41.616432000000003	53.960343000000002	53.934641999999997	0103000020E610000001000000050000002BDEC83CF2C94440E8BB5B59A2F74A402BDEC83CF2C94440A5F8F884ECFA4A409C1A683EE7CE4440A5F8F884ECFA4A409C1A683EE7CE4440E8BB5B59A2F74A402BDEC83CF2C94440E8BB5B59A2F74A40
16153	Сявель	1	12	1207	41.924993999999998	41.951126000000002	53.906024000000002	53.886414000000002	0103000020E61000000100000005000000847F113466F64440B85B920376F14A40847F113466F6444010B22C98F8F34A400A302C7FBEF9444010B22C98F8F34A400A302C7FBEF94440B85B920376F14A40847F113466F64440B85B920376F14A40
15930	Старочернеево	1	12	1207	41.841613000000002	41.869883000000002	53.864660000000001	53.848823000000003	0103000020E61000000100000005000000B9718BF9B9EB4440DB8B683BA6EC4A40B9718BF9B9EB44406614CB2DADEE4A40562C7E5358EF44406614CB2DADEE4A40562C7E5358EF4440DB8B683BA6EC4A40B9718BF9B9EB4440DB8B683BA6EC4A40
15598	Сново-Здорово	1	12	1207	41.842475	41.878641000000002	54.110055000000003	54.094867000000001	0103000020E610000001000000050000004B598638D6EB44401D3C139A240C4B404B598638D6EB444072E14048160E4B405EF6EB4E77F0444072E14048160E4B405EF6EB4E77F044401D3C139A240C4B404B598638D6EB44401D3C139A240C4B40
54669	Свеженькая	1	12	1207	41.262692999999999	42.445981000000003	54.241294000000003	53.772956000000001	0103000020E61000000100000005000000AEF199EC9FA144409D9FE238F0E24A40AEF199EC9FA144404B5CC7B8E21E4B4096D1C8E7153945404B5CC7B8E21E4B4096D1C8E7153945409D9FE238F0E24A40AEF199EC9FA144409D9FE238F0E24A40
15866	Садовый	1	12	1207	41.604664	41.629897999999997	53.901594000000003	53.886690000000002	0103000020E61000000100000005000000C68844A165CD44405AD8D30E7FF14A40C68844A165CD44408A22A46E67F34A406CE8667FA0D044408A22A46E67F34A406CE8667FA0D044405AD8D30E7FF14A40C68844A165CD44405AD8D30E7FF14A40
16518	Польное Ялтуново	1	12	1207	41.840400000000002	41.871419000000003	54.006855000000002	53.972169999999998	0103000020E610000001000000050000007AC7293A92EB44407F130A1170FC4A407AC7293A92EB44403468E89FE0004B40780E65A88AEF44403468E89FE0004B40780E65A88AEF44407F130A1170FC4A407AC7293A92EB44407F130A1170FC4A40
15686	Польное Конобеево	1	12	1207	41.896678999999999	41.931651000000002	54.064615000000003	54.039946	0103000020E610000001000000050000004701A260C6F2444092CD55F31C054B404701A260C6F2444060EAE74D45084B409224085740F7444060EAE74D45084B409224085740F7444092CD55F31C054B404701A260C6F2444092CD55F31C054B40
16463	Печины	1	12	1207	41.752104000000003	41.788181000000002	53.838144999999997	53.807164	0103000020E610000001000000050000006C98A1F144E044401841632651E74A406C98A1F144E044402827DA5548EB4A400F2A711DE3E444402827DA5548EB4A400F2A711DE3E444401841632651E74A406C98A1F144E044401841632651E74A40
16065	Парсаты	1	12	1207	41.873251000000003	41.903101999999997	53.872587000000003	53.860793999999999	0103000020E61000000100000005000000831953B0C6EF4440E84B6F7F2EEE4A40831953B0C6EF444017F549EEB0EF4A40E179A9D898F3444017F549EEB0EF4A40E179A9D898F34440E84B6F7F2EEE4A40831953B0C6EF4440E84B6F7F2EEE4A40
16163	Ольхи	1	12	1207	41.451644999999999	41.532556	53.893051999999997	53.868074	0103000020E610000001000000050000007233DC80CFB944400341800C1DEF4A407233DC80CFB944404ED026874FF24A40F0A485CB2AC444404ED026874FF24A40F0A485CB2AC444400341800C1DEF4A407233DC80CFB944400341800C1DEF4A40
15976	Новочернеево	1	12	1207	41.792115000000003	41.829906999999999	53.904119000000001	53.866917000000001	0103000020E61000000100000005000000E5D5390664E5444058ACE122F7EE4A40E5D5390664E544409B58E02BBAF34A4059DC7F643AEA44409B58E02BBAF34A4059DC7F643AEA444058ACE122F7EE4A40E5D5390664E5444058ACE122F7EE4A40
14732	Новософьино	1	12	1207	41.712983000000001	41.750478000000001	53.923121999999999	53.899652000000003	0103000020E610000001000000050000004FCDE50643DB4440F8E3F6CB27F34A404FCDE50643DB4440EB1B98DC28F64A400A2FC1A90FE04440EB1B98DC28F64A400A2FC1A90FE04440F8E3F6CB27F34A404FCDE50643DB4440F8E3F6CB27F34A40
15345	Новоселки	1	12	1207	42.065615999999999	42.108367000000001	54.077036	54.067827999999999	0103000020E61000000100000005000000130CE71A6608454065E08096AE084B40130CE71A66084540AD4ECE50DC094B409A7B48F8DE0D4540AD4ECE50DC094B409A7B48F8DE0D454065E08096AE084B40130CE71A6608454065E08096AE084B40
15587	Лесное-Конобеево	1	12	1207	41.905141	41.934516000000002	54.050587999999998	54.025848000000003	0103000020E6100000010000000500000066A208A9DBF344406155BDFC4E034B4066A208A9DBF34440F7C8E6AA79064B405CCB64389EF74440F7C8E6AA79064B405CCB64389EF744406155BDFC4E034B4066A208A9DBF344406155BDFC4E034B40
16677	Лесное Ялтуново	1	12	1207	41.888280000000002	41.920268999999998	54.010976999999997	53.994159000000003	0103000020E610000001000000050000006FD8B628B3F144401503249A40FF4A406FD8B628B3F144400C01C0B167014B40E542E55FCBF544400C01C0B167014B40E542E55FCBF544401503249A40FF4A406FD8B628B3F144401503249A40FF4A40
15772	Лесная Поляна	1	12	1207	41.654431000000002	41.678756999999997	53.874741999999998	53.859323000000003	0103000020E610000001000000050000008A3E1F65C4D34440AED9CA4BFEED4A408A3E1F65C4D344400438BD8BF7EF4A402D776682E1D644400438BD8BF7EF4A402D776682E1D64440AED9CA4BFEED4A408A3E1F65C4D34440AED9CA4BFEED4A40
15490	Кучасьево	1	12	1207	41.977257999999999	42.002302999999998	54.106988999999999	54.093815999999997	0103000020E610000001000000050000008FE046CA16FD4440B7EBA529020C4B408FE046CA16FD44401004C8D0B10D4B4062D7F6764B0045401004C8D0B10D4B4062D7F6764B004540B7EBA529020C4B408FE046CA16FD4440B7EBA529020C4B40
15201	Купля	1	12	1207	42.066811000000001	42.117755000000002	54.049658000000001	54.040073	0103000020E61000000100000005000000AC014A438D084540EF39B01C21054B40AC014A438D0845400DFE7E315B064B4062F88898120F45400DFE7E315B064B4062F88898120F4540EF39B01C21054B40AC014A438D084540EF39B01C21054B40
16679	Кулики	1	12	1207	41.505822000000002	41.539625999999998	53.950515000000003	53.930587000000003	0103000020E6100000010000000500000075CC79C6BEC04440988A8D791DF74A4075CC79C6BEC04440C1ADBB79AAF94A402009FB7612C54440C1ADBB79AAF94A402009FB7612C54440988A8D791DF74A4075CC79C6BEC04440988A8D791DF74A40
14343	Кривая Лука	1	12	1207	41.571461999999997	41.607961000000003	53.883488999999997	53.869990999999999	0103000020E610000001000000050000001074B4AA25C944403C6876DD5BEF4A401074B4AA25C9444018B0E42A16F14A402A1F82AAD1CD444018B0E42A16F14A402A1F82AAD1CD44403C6876DD5BEF4A401074B4AA25C944403C6876DD5BEF4A40
17417	Красный Холм	1	12	1207	42.179701999999999	42.213918999999997	54.093899999999998	54.083069000000002	0103000020E610000001000000050000004D83A27900174540DD274701A20A4B404D83A27900174540158C4AEA040C4B401B7FA2B2611B4540158C4AEA040C4B401B7FA2B2611B4540DD274701A20A4B404D83A27900174540DD274701A20A4B40
15054	Кермись	1	12	1207	42.065814000000003	42.095008999999997	53.864288000000002	53.842559999999999	0103000020E610000001000000050000003ACFD8976C08454079758E01D9EB4A403ACFD8976C084540A2293BFDA0EE4A40AFE94141290C4540A2293BFDA0EE4A40AFE94141290C454079758E01D9EB4A403ACFD8976C08454079758E01D9EB4A40
14630	Карнаухово	1	12	1207	41.727831999999999	41.751340999999996	54.091931000000002	54.082006999999997	0103000020E61000000100000005000000BB7D569929DD4440838593347F0A4B40BB7D569929DD44408A3E1F65C40B4B406C921FF12BE044408A3E1F65C40B4B406C921FF12BE04440838593347F0A4B40BB7D569929DD4440838593347F0A4B40
54633	Казачья-Слобода	1	12	1207	41.685602000000003	41.719298000000002	54.021203999999997	53.991422	0103000020E610000001000000050000003E096CCEC1D74440784485EAE6FE4A403E096CCEC1D74440AE450BD0B6024B40030AF5F411DC4440AE450BD0B6024B40030AF5F411DC4440784485EAE6FE4A403E096CCEC1D74440784485EAE6FE4A40
16885	Казачий Дюк	1	12	1207	41.540559999999999	41.555984000000002	54.019759999999998	54.005215	0103000020E610000001000000050000004CC3F01131C544406D3997E2AA004B404CC3F01131C544406DE2E47E87024B40B58CD47B2AC744406DE2E47E87024B40B58CD47B2AC744406D3997E2AA004B404CC3F01131C544406D3997E2AA004B40
14921	Каверино	1	12	1207	41.755274999999997	41.789743999999999	54.174280000000003	54.151074000000001	0103000020E61000000100000005000000423EE8D9ACE0444051A3906456134B40423EE8D9ACE04440672C9ACE4E164B402A1BD65416E54440672C9ACE4E164B402A1BD65416E5444051A3906456134B40423EE8D9ACE0444051A3906456134B40
14778	Завидное	1	12	1207	42.046905000000002	42.076908000000003	53.971535000000003	53.954901999999997	0103000020E610000001000000050000006B82A8FB0006454047718E3A3AFA4A406B82A8FB00064540AEF545425BFC4A408066101FD8094540AEF545425BFC4A408066101FD809454047718E3A3AFA4A406B82A8FB0006454047718E3A3AFA4A40
14914	Желанное	1	12	1207	42.069325999999997	42.106903000000003	53.954754000000001	53.935823999999997	0103000020E610000001000000050000009961A3ACDF084540EC67B114C9F74A409961A3ACDF084540D3DC0A6135FA4A40126C5CFFAE0D4540D3DC0A6135FA4A40126C5CFFAE0D4540EC67B114C9F74A409961A3ACDF084540EC67B114C9F74A40
15282	Выша	1	12	1207	42.099249	42.112796000000003	54.035632	54.021262	0103000020E610000001000000050000009294F430B40C4540E35295B6B8024B409294F430B40C45407558E1968F044B40508F6D19700E45407558E1968F044B40508F6D19700E4540E35295B6B8024B409294F430B40C4540E35295B6B8024B40
16480	Высокое	1	12	1207	41.777158	41.812804	53.867266999999998	53.852260000000001	0103000020E6100000010000000500000092E9D0E979E3444030D80DDB16ED4A4092E9D0E979E3444034F3E49A02EF4A406C0723F609E8444034F3E49A02EF4A406C0723F609E8444030D80DDB16ED4A4092E9D0E979E3444030D80DDB16ED4A40
14445	Вачкас	1	12	1207	41.710808999999998	41.733652999999997	53.952596999999997	53.939141999999997	0103000020E61000000100000005000000EA5910CAFBDA4440672618CE35F84A40EA5910CAFBDA444044A2D0B2EEF94A405FCE6C57E8DD444044A2D0B2EEF94A405FCE6C57E8DD4440672618CE35F84A40EA5910CAFBDA4440672618CE35F84A40
15296	Важная	1	12	1207	42.091074999999996	42.104306999999999	54.031644	54.016919000000001	0103000020E61000000100000005000000D93D7958A80B45402CD7DB662A024B40D93D7958A80B4540AC8E1CE90C044B4037DF88EE590D4540AC8E1CE90C044B4037DF88EE590D45402CD7DB662A024B40D93D7958A80B45402CD7DB662A024B40
14720	Борки	1	12	1207	41.802095999999999	41.853982000000002	53.965629	53.931376	0103000020E610000001000000050000004F20EC14ABE64440C0232A5437F74A404F20EC14ABE64440DB8827BB99FB4A40B4AF3C484FED4440DB8827BB99FB4A40B4AF3C484FED4440C0232A5437F74A404F20EC14ABE64440C0232A5437F74A40
14535	Большое Агишево	1	12	1207	41.710287999999998	41.758878000000003	54.134318	54.112752999999998	0103000020E61000000100000005000000E15E99B7EADA444050C3B7B06E0E4B40E15E99B7EADA4440CFA10C5531114B40B3D30FEA22E14440CFA10C5531114B40B3D30FEA22E1444050C3B7B06E0E4B40E15E99B7EADA444050C3B7B06E0E4B40
14334	Апушка	1	12	1207	41.477822000000003	41.529107000000003	53.818137	53.802160000000001	0103000020E6100000010000000500000098A7734529BD44406614CB2DADE64A4098A7734529BD4440E35295B6B8E84A40D78A36C7B9C34440E35295B6B8E84A40D78A36C7B9C344406614CB2DADE64A4098A7734529BD44406614CB2DADE64A40
14251	Шеметово	1	12	363	41.528782999999997	41.548752999999998	54.303033999999997	54.289383000000001	0103000020E6100000010000000500000023D74D29AFC344405A828C800A254B4023D74D29AFC34440BCC96FD1C9264B407B4ACE893DC64440BCC96FD1C9264B407B4ACE893DC644405A828C800A254B4023D74D29AFC344405A828C800A254B40
14145	Чучково	1	12	363	41.421928999999999	41.498690000000003	54.286681999999999	54.244487999999997	0103000020E61000000100000005000000F31DFCC401B64440D921FE614B1F4B40F31DFCC401B644400A2DEBFEB1244B40CF6BEC12D5BF44400A2DEBFEB1244B40CF6BEC12D5BF4440D921FE614B1F4B40F31DFCC401B64440D921FE614B1F4B40
14062	Церлево	1	12	363	41.541845000000002	41.576636000000001	54.419589000000002	54.397502000000003	0103000020E6100000010000000500000025404D2D5BC544401C0C7558E1324B4025404D2D5BC544407461A417B5354B401FD95C35CFC944407461A417B5354B401FD95C35CFC944401C0C7558E1324B4025404D2D5BC544401C0C7558E1324B40
14056	Протасьев Угол	1	12	363	41.282105999999999	41.294125000000001	54.252394000000002	54.233531999999997	0103000020E61000000100000005000000B000A60C1CA44440E4486760E41D4B40B000A60C1CA4444073DA53724E204B40CFF753E3A5A5444073DA53724E204B40CFF753E3A5A54440E4486760E41D4B40B000A60C1CA44440E4486760E41D4B40
13974	Пертово	1	12	363	41.499040000000001	41.534379999999999	54.371118000000003	54.348841999999998	0103000020E61000000100000005000000ABB2EF8AE0BF444051BCCADAA62C4B40ABB2EF8AE0BF44407D7A6CCB802F4B4078D1579066C444407D7A6CCB802F4B4078D1579066C4444051BCCADAA62C4B40ABB2EF8AE0BF444051BCCADAA62C4B40
1864	Остро-Пластиково	1	12	363	41.356217000000001	41.382555000000004	54.208300999999999	54.185504000000002	0103000020E61000000100000005000000BEA3C68498AD44407BA35698BE174B40BEA3C68498AD4440AF5C6F9BA91A4B40EDF5EE8FF7B04440AF5C6F9BA91A4B40EDF5EE8FF7B044407BA35698BE174B40BEA3C68498AD44407BA35698BE174B40
13876	Назаровка	1	12	363	41.280597	41.323033000000002	54.310068000000001	54.288358000000002	0103000020E61000000100000005000000882D3D9AEAA344401EC539EAE8244B40882D3D9AEAA34440A0C4E74EB0274B40AF43352559A94440A0C4E74EB0274B40AF43352559A944401EC539EAE8244B40882D3D9AEAA344401EC539EAE8244B40
13854	Мелехово	1	12	363	41.356388000000003	41.393695000000001	54.435538000000001	54.414344999999997	0103000020E61000000100000005000000EB573A1F9EAD44406C21C84109354B40EB573A1F9EAD444027158DB5BF374B40A3CC069964B2444027158DB5BF374B40A3CC069964B244406C21C84109354B40EB573A1F9EAD44406C21C84109354B40
47060	Красное Озеро	1	12	363	41.644072999999999	41.668695999999997	54.338140000000003	54.327005	0103000020E61000000100000005000000499EEBFB70D244407250C24CDB294B40499EEBFB70D2444017BCE82B482B4B40A67B9DD497D5444017BCE82B482B4B40A67B9DD497D544407250C24CDB294B40499EEBFB70D244407250C24CDB294B40
13591	Кистенево	1	12	363	41.505426999999997	41.539482	54.257581000000002	54.234948000000003	0103000020E61000000100000005000000F8C1F9D4B1C044405C21ACC6121E4B40F8C1F9D4B1C044401689096AF8204B40ED6305BF0DC544401689096AF8204B40ED6305BF0DC544405C21ACC6121E4B40F8C1F9D4B1C044405C21ACC6121E4B40
13579	Завидово	1	12	363	41.300978999999998	41.324587000000001	54.293225	54.280988999999998	0103000020E6100000010000000500000032E4D87A86A6444093C49272F7234B4032E4D87A86A644404FAF946588254B4077DA1A118CA944404FAF946588254B4077DA1A118CA9444093C49272F7234B4032E4D87A86A6444093C49272F7234B40
13492	Дудкино	1	12	363	41.499578999999997	41.519809000000002	54.198137000000003	54.185921	0103000020E610000001000000050000005A626534F2BF4440DF516342CC174B405A626534F2BF444054909F8D5C194B404F95EF1989C2444054909F8D5C194B404F95EF1989C24440DF516342CC174B405A626534F2BF4440DF516342CC174B40
13488	Дубровка	1	12	363	41.308408999999997	41.314256999999998	54.339547000000003	54.333258000000001	0103000020E61000000100000005000000626534F279A74440B090B932A82A4B40626534F279A744403B3AAE46762B4B4000C5C89239A844403B3AAE46762B4B4000C5C89239A84440B090B932A82A4B40626534F279A74440B090B932A82A4B40
13349	Алеево	1	12	363	41.402732	41.431674999999998	54.150689999999997	54.137414999999997	0103000020E61000000100000005000000BE86E0B88CB344406B7D91D096114B40BE86E0B88CB34440C8EA56CF49134B401AC05B2041B74440C8EA56CF49134B401AC05B2041B744406B7D91D096114B40BE86E0B88CB344406B7D91D096114B40
13311	Аладьино	1	12	363	41.654618999999997	41.697065000000002	54.280273999999999	54.270932000000002	0103000020E610000001000000050000008C2B2E8ECAD344404EB857E6AD224B408C2B2E8ECAD34440A5F5B704E0234B40D717096D39D94440A5F5B704E0234B40D717096D39D944404EB857E6AD224B408C2B2E8ECAD344404EB857E6AD224B40
13301	Авангард	1	12	363	41.557619000000003	41.575099999999999	54.272661999999997	54.265658000000002	0103000020E610000001000000050000006A50340F60C74440DCF5D21401224B406A50340F60C74440546EA296E6224B40FDF675E09CC94440546EA296E6224B40FDF675E09CC94440DCF5D21401224B406A50340F60C74440DCF5D21401224B40
13030	Ясенок	1	12	1014	40.366103000000003	40.391928999999998	53.830801999999998	53.812655999999997	0103000020E61000000100000005000000D7FB8D76DC2E4440F7729F1C05E84A40D7FB8D76DC2E4440C7B94DB857EA4A404FADBEBA2A324440C7B94DB857EA4A404FADBEBA2A324440F7729F1C05E84A40D7FB8D76DC2E4440F7729F1C05E84A40
13016	Чуриловка	1	12	1014	40.406697999999999	40.432174000000003	53.732168999999999	53.712978	0103000020E610000001000000050000009FAC18AE0E3444403D62F4DC42DB4A409FAC18AE0E3444409012BBB6B7DD4A403C17467A513744409012BBB6B7DD4A403C17467A513744403D62F4DC42DB4A409FAC18AE0E3444403D62F4DC42DB4A40
13067	Ухолово	1	12	1014	40.448118999999998	40.512177999999999	53.819879999999998	53.779820000000001	0103000020E61000000100000005000000ADDBA0F65B39444024624A24D1E34A40ADDBA0F65B3944407E52EDD3F1E84A4087DD770C8F4144407E52EDD3F1E84A4087DD770C8F41444024624A24D1E34A40ADDBA0F65B39444024624A24D1E34A40
12856	Соловачево	1	12	1014	40.491219999999998	40.507947000000001	53.880251999999999	53.860841999999998	0103000020E610000001000000050000001092054CE03E4440F982161230EE4A401092054CE03E44408A1EF818ACF04A40F88C4468044144408A1EF818ACF04A40F88C446804414440F982161230EE4A401092054CE03E4440F982161230EE4A40
12813	Смолеевка	1	12	1014	40.500948999999999	40.567253000000001	53.706336999999998	53.685113000000001	0103000020E6100000010000000500000061FBC9181F404440408864C8B1D74A4061FBC9181F404440357A354069DA4A4069C70DBF9B484440357A354069DA4A4069C70DBF9B484440408864C8B1D74A4061FBC9181F404440408864C8B1D74A40
12808	Покровское	1	12	1014	40.406939999999999	40.460946999999997	53.920667000000002	53.869635000000002	0103000020E6100000010000000500000095B7239C163444407E3A1E3350EF4A4095B7239C16344440D3C08F6AD8F54A403B18B14F003B4440D3C08F6AD8F54A403B18B14F003B44407E3A1E3350EF4A4095B7239C163444407E3A1E3350EF4A40
12481	Погореловка	1	12	1014	40.444839999999999	40.483656000000003	53.782874	53.770476000000002	0103000020E61000000100000005000000F0F96184F03844402C2D23F59EE24A40F0F96184F0384440C171193735E44A40D1419770E83D4440C171193735E44A40D1419770E83D44402C2D23F59EE24A40F0F96184F03844402C2D23F59EE24A40
12651	Ольхи	1	12	1014	40.414064000000003	40.453572000000001	53.84646	53.815382999999997	0103000020E61000000100000005000000B939950C00354440705B5B785EE84A40B939950C00354440A3AF20CD58EC4A40CF30B5A50E3A4440A3AF20CD58EC4A40CF30B5A50E3A4440705B5B785EE84A40B939950C00354440705B5B785EE84A40
12250	Мостье	1	12	1014	40.535201999999998	40.572499999999998	53.765425	53.750306999999999	0103000020E610000001000000050000007C60C77F81444440DD7A4D0F0AE04A407C60C77F8144444039454772F9E14A40E17A14AE4749444039454772F9E14A40E17A14AE47494440DD7A4D0F0AE04A407C60C77F81444440DD7A4D0F0AE04A40
12587	Лубянки	1	12	1014	40.393428999999998	40.418376000000002	53.662129	53.641278	0103000020E610000001000000050000002426A8E15B32444078D2C26515D24A402426A8E15B324440D95DA0A4C0D44A4035B742588D354440D95DA0A4C0D44A4035B742588D35444078D2C26515D24A402426A8E15B32444078D2C26515D24A40
12106	Красный	1	12	1014	40.677028	40.702072999999999	53.818440000000002	53.801712999999999	0103000020E61000000100000005000000F73C7FDAA856444097E315889EE64A40F73C7FDAA85644407FDE54A4C2E84A40CA332F87DD5944407FDE54A4C2E84A40CA332F87DD59444097E315889EE64A40F73C7FDAA856444097E315889EE64A40
12342	Коноплино	1	12	1014	40.605781999999998	40.632722999999999	53.621639000000002	53.599741999999999	0103000020E61000000100000005000000B340BB438A4D4440D1048A58C4CC4A40B340BB438A4D44408675E3DD91CF4A40A8363811FD5044408675E3DD91CF4A40A8363811FD504440D1048A58C4CC4A40B340BB438A4D4440D1048A58C4CC4A40
12583	Кобылино	1	12	1014	40.447400000000002	40.46799	53.666097999999998	53.64723	0103000020E610000001000000050000007E1D386744394440BB7EC16ED8D24A407E1D3867443944402BF702B342D54A40726DA818E73B44402BF702B342D54A40726DA818E73B4440BB7EC16ED8D24A407E1D386744394440BB7EC16ED8D24A40
8776	Кензино	1	12	1014	40.366605999999997	40.391776999999998	53.777633000000002	53.757680999999998	0103000020E61000000100000005000000394206F2EC2E444079E6E5B0FBE04A40394206F2EC2E44402BA5677A89E34A409929ADBF253244402BA5677A89E34A409929ADBF2532444079E6E5B0FBE04A40394206F2EC2E444079E6E5B0FBE04A40
12096	Калинин	1	12	1014	40.647382999999998	40.677098999999998	53.759911000000002	53.742842000000003	0103000020E61000000100000005000000417E3672DD524440310C587215DF4A40417E3672DD524440726F7EC344E14A40C093162EAB564440726F7EC344E14A40C093162EAB564440310C587215DF4A40417E3672DD524440310C587215DF4A40
12013	Дегтяные Борки	1	12	1014	40.714128000000002	40.744346999999998	53.797507000000003	53.760539000000001	0103000020E610000001000000050000003694DA8B685B4440912A8A5759E14A403694DA8B685B444061AA99B514E64A4017F032C3465F444061AA99B514E64A4017F032C3465F4440912A8A5759E14A403694DA8B685B4440912A8A5759E14A40
11988	Волынщино	1	12	1014	40.527538999999997	40.545074	53.628005000000002	53.604641999999998	0103000020E61000000100000005000000A92EE06586434440DEE4B7E864CD4A40A92EE06586434440BC5CC47762D04A4030F31DFCC4454440BC5CC47762D04A4030F31DFCC4454440DEE4B7E864CD4A40A92EE06586434440DEE4B7E864CD4A40
11899	Богородицкое	1	12	1014	40.568942	40.592055999999999	53.560476000000001	53.541195999999999	0103000020E6100000010000000500000011A96917D3484440EE5C18E945C54A4011A96917D3484440B11875ADBDC74A4046B3B27DC84B4440B11875ADBDC74A4046B3B27DC84B4440EE5C18E945C54A4011A96917D3484440EE5C18E945C54A40
11337	Чернобаево	1	12	885	39.953498000000003	39.972416000000003	54.312075	54.292819999999999	0103000020E610000001000000050000009566F3380CFA4340AFCE31207B254B409566F3380CFA43401973D712F2274B40B70DA32078FC43401973D712F2274B40B70DA32078FC4340AFCE31207B254B409566F3380CFA4340AFCE31207B254B40
10978	Старожилово	1	12	885	39.882432000000001	39.928452	54.247948999999998	54.212729000000003	0103000020E61000000100000005000000D1782288F3F0434095F430B43A1B4B40D1782288F3F04340B709F7CABC1F4B40F1F3DF83D7F64340B709F7CABC1F4B40F1F3DF83D7F6434095F430B43A1B4B40D1782288F3F0434095F430B43A1B4B40
11219	Соха	1	12	885	39.801844000000003	39.837318000000003	54.155735999999997	54.139882999999998	0103000020E61000000100000005000000363FFED2A2E643401822A7AFE7114B40363FFED2A2E64340A9674128EF134B40132D793C2DEB4340A9674128EF134B40132D793C2DEB43401822A7AFE7114B40363FFED2A2E643401822A7AFE7114B40
9578	Совхоз Имени Ленина	1	12	885	39.978937999999999	39.997272000000002	54.171512999999997	54.159948	0103000020E61000000100000005000000E46723D74DFD4340C287122D79144B40E46723D74DFD43405FEB5223F4154B40B79BE09BA6FF43405FEB5223F4154B40B79BE09BA6FF4340C287122D79144B40E46723D74DFD4340C287122D79144B40
6746	Рязанские Сады	1	12	885	39.954019000000002	39.968086	54.269697000000001	54.258184999999997	0103000020E610000001000000050000009E616A4B1DFA4340ACA8C1340C214B409E616A4B1DFA4340276A696E85224B4094DBF63DEAFB4340276A696E85224B4094DBF63DEAFB4340ACA8C1340C214B409E616A4B1DFA4340ACA8C1340C214B40
11102	Панинская Слобода	1	12	885	39.740524999999998	39.766872999999997	54.243188000000004	54.230569000000003	0103000020E61000000100000005000000696FF085C9DE4340583CF548831D4B40696FF085C9DE4340CC63CDC8201F4B40BB97FBE428E24340CC63CDC8201F4B40BB97FBE428E24340583CF548831D4B40696FF085C9DE4340583CF548831D4B40
11682	Мелекшино	1	12	885	40.181283000000001	40.208556000000002	54.165246000000003	54.149608999999998	0103000020E610000001000000050000000F29064834174440F817416326134B400F29064834174440BDE5EAC726154B403AB187F6B11A4440BDE5EAC726154B403AB187F6B11A4440F817416326134B400F29064834174440F817416326134B40
11151	Киселево	1	12	885	39.747577	39.765982999999999	54.341462999999997	54.331384	0103000020E61000000100000005000000F31E679AB0DF4340763579CA6A2A4B40F31E679AB0DF4340A3E5400FB52B4B405F251FBB0BE24340A3E5400FB52B4B405F251FBB0BE24340763579CA6A2A4B40F31E679AB0DF4340763579CA6A2A4B40
11470	Истье	1	12	885	40.092745000000001	40.127392999999998	54.305719000000003	54.289315000000002	0103000020E610000001000000050000000BEF7211DF0B4440029F1F4608254B400BEF7211DF0B44400762D9CC21274B40A25EF0694E1044400762D9CC21274B40A25EF0694E104440029F1F4608254B400BEF7211DF0B4440029F1F4608254B40
11238	Ивановское	1	12	885	39.822074000000001	40.041612999999998	54.404755999999999	54.226733000000003	0103000020E610000001000000050000002A7288B839E9434045F64196051D4B402A7288B839E943400D6E6B0BCF334B40520B2593530544400D6E6B0BCF334B40520B25935305444045F64196051D4B402A7288B839E9434045F64196051D4B40
11732	Ершово	1	12	885	40.191972999999997	40.208438999999998	54.225631999999997	54.211255000000001	0103000020E61000000100000005000000855B3E9292184440E90E62670A1B4B40855B3E92921844402D776682E11C4B40001B1021AE1A44402D776682E11C4B40001B1021AE1A4440E90E62670A1B4B40855B3E9292184440E90E62670A1B4B40
11328	Гребнево	1	12	885	39.948323000000002	39.974131999999997	54.369413000000002	54.354483000000002	0103000020E61000000100000005000000B685E7A562F9434076FEEDB25F2D4B40B685E7A562F94340CFDBD8EC482F4B4058FE7C5BB0FC4340CFDBD8EC482F4B4058FE7C5BB0FC434076FEEDB25F2D4B40B685E7A562F9434076FEEDB25F2D4B40
11567	Большие Поляны	1	12	885	39.931883999999997	39.972622999999999	54.181657999999999	54.166606000000002	0103000020E6100000010000000500000034D593F947F74340A0A86C5853154B4034D593F947F743404487C09140174B40302B14E97EFC43404487C09140174B40302B14E97EFC4340A0A86C5853154B4034D593F947F74340A0A86C5853154B40
11653	Аристово	1	12	885	40.203246999999998	40.218096000000003	54.152683000000003	54.139018	0103000020E610000001000000050000004B0169FF031A444015C78157CB114B404B0169FF031A4440DDD3D51D8B134B40B8B1D991EA1B4440DDD3D51D8B134B40B8B1D991EA1B444015C78157CB114B404B0169FF031A444015C78157CB114B40
10930	Федотьево	1	12	124	40.309247999999997	40.354118999999997	54.566009999999999	54.548943000000001	0103000020E610000001000000050000003C2D3F70952744401F2FA4C343464B403C2D3F7095274440BF9A030473484B4034F279C5532D4440BF9A030473484B4034F279C5532D44401F2FA4C343464B403C2D3F70952744401F2FA4C343464B40
9792	Фатьяновка	1	12	124	40.427025999999998	40.445819	54.426676999999998	54.407083	0103000020E610000001000000050000005645B8C9A8364440F8E0B54B1B344B405645B8C9A83644404A7A185A9D364B40BC77D498103944404A7A185A9D364B40BC77D49810394440F8E0B54B1B344B405645B8C9A8364440F8E0B54B1B344B40
257	Ухорское	1	12	124	40.247686999999999	40.283268999999997	54.216940999999998	54.202950999999999	0103000020E610000001000000050000007A522635B41F444062D8614CFA194B407A522635B41F4440AD1402B9C41B4B403D7C992842244440AD1402B9C41B4B403D7C99284224444062D8614CFA194B407A522635B41F444062D8614CFA194B40
9740	Устрань	1	12	124	40.471080000000001	40.502521000000002	54.444670000000002	54.434066999999999	0103000020E610000001000000050000005CE674594C3C4440ECA2E8818F374B405CE674594C3C444094C151F2EA384B40D046AE9B5240444094C151F2EA384B40D046AE9B52404440ECA2E8818F374B405CE674594C3C4440ECA2E8818F374B40
10743	Троица	1	12	124	40.211143	40.242207000000001	54.407029999999999	54.388150000000003	0103000020E61000000100000005000000C1E3DBBB061B4440A1F831E6AE314B40C1E3DBBB061B4440D53E1D8F19344B405FEE93A3001F4440D53E1D8F19344B405FEE93A3001F4440A1F831E6AE314B40C1E3DBBB061B4440A1F831E6AE314B40
9354	Сушки	1	12	124	40.356751000000003	40.392504000000002	54.291207	54.269928	0103000020E610000001000000050000005CE84A04AA2D444029232E008D224B405CE84A04AA2D4440E2AE5E4546254B404CC631923D324440E2AE5E4546254B404CC631923D32444029232E008D224B405CE84A04AA2D444029232E008D224B40
54692	Старый Киструсс	1	12	124	40.559339000000001	40.587133000000001	54.496557000000003	54.473471000000004	0103000020E610000001000000050000004D309C6B984744405E4D9EB29A3C4B404D309C6B98474440C9CC052E8F3F4B4081B3942C274B4440C9CC052E8F3F4B4081B3942C274B44405E4D9EB29A3C4B404D309C6B984744405E4D9EB29A3C4B40
10187	Старое Тонино	1	12	124	40.527323000000003	40.544930000000001	54.557291999999997	54.537526	0103000020E61000000100000005000000DDB6EF517F434440F65FE7A6CD444B40DDB6EF517F4344404529215855474B40FD4D2844C04544404529215855474B40FD4D2844C0454440F65FE7A6CD444B40DDB6EF517F434440F65FE7A6CD444B40
8865	Спиртзаводской	1	12	124	40.251693000000003	40.284301999999997	54.308954999999997	54.298563000000001	0103000020E61000000100000005000000EAD0E97937204440D865F84F37264B40EAD0E97937204440C47762D68B274B40FC17080264244440C47762D68B274B40FC17080264244440D865F84F37264B40EAD0E97937204440D865F84F37264B40
8266	Спасск-Рязанский	1	12	124	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
10499	Собчаково	1	12	124	40.119290999999997	40.137588999999998	54.414974000000001	54.394153000000003	0103000020E6100000010000000500000083DA6FED440F4440664F029B73324B4083DA6FED440F44405C5837DE1D354B4009A52F849C1144405C5837DE1D354B4009A52F849C114440664F029B73324B4083DA6FED440F4440664F029B73324B40
9405	Разбердеево	1	12	124	40.437887000000003	40.456643999999997	54.347278000000003	54.336129999999997	0103000020E61000000100000005000000FA2B64AE0C3844402C9ACE4E062B4B40FA2B64AE0C384440664F029B732C4B4012F5824F733A4440664F029B732C4B4012F5824F733A44402C9ACE4E062B4B40FA2B64AE0C3844402C9ACE4E062B4B40
10560	Половское	1	12	124	40.189664999999998	40.220692	54.474496000000002	54.441837	0103000020E61000000100000005000000111956F146184440D594641D8E384B40111956F1461844409A0AF148BC3C4B40923EADA23F1C44409A0AF148BC3C4B40923EADA23F1C4440D594641D8E384B40111956F146184440D594641D8E384B40
10402	Перкино	1	12	124	40.219110999999998	40.254029000000003	54.338937999999999	54.308666000000002	0103000020E61000000100000005000000D09849D40B1C44408EB1135E82274B40D09849D40B1C444092AF0452622B4B40289EB3058420444092AF0452622B4B40289EB305842044408EB1135E82274B40D09849D40B1C44408EB1135E82274B40
10101	Панино	1	12	124	40.261215	40.288991000000003	54.474286999999997	54.449674999999999	0103000020E61000000100000005000000C11C3D7E6F214440166A4DF38E394B40C11C3D7E6F2144407FF5B86FB53C4B404FEB36A8FD2444407FF5B86FB53C4B404FEB36A8FD244440166A4DF38E394B40C11C3D7E6F214440166A4DF38E394B40
10341	Огородниково	1	12	124	40.168716000000003	40.203741000000001	54.357877999999999	54.335200999999998	0103000020E61000000100000005000000EE27637C98154440124BCADDE72A4B40EE27637C981544409CFA40F2CE2D4B405BED612F141A44409CFA40F2CE2D4B405BED612F141A4440124BCADDE72A4B40EE27637C98154440124BCADDE72A4B40
54651	Новый Киструсс	1	12	124	40.559311999999998	40.599691999999997	54.474282000000002	54.460813000000002	0103000020E6100000010000000500000053211E89974744402C499EEBFB3A4B4053211E89974744406E8AC745B53C4B401FD61BB5C24C44406E8AC745B53C4B401FD61BB5C24C44402C499EEBFB3A4B4053211E89974744402C499EEBFB3A4B40
10191	Новики	1	12	124	40.225687000000001	40.255394000000003	54.589596999999998	54.563541000000001	0103000020E61000000100000005000000F110C64FE31C4440427A8A1C22484B40F110C64FE31C4440EC681CEA774B4B401DCC26C0B0204440EC681CEA774B4B401DCC26C0B0204440427A8A1C22484B40F110C64FE31C4440427A8A1C22484B40
10048	Михали	1	12	124	40.416713999999999	40.435550999999997	54.526732000000003	54.507866	0103000020E6100000010000000500000086E464E2563544400B60CAC001414B4086E464E256354440DBE044F46B434B40BB5E9A22C0374440DBE044F46B434B40BB5E9A22C03744400B60CAC001414B4086E464E2563544400B60CAC001414B40
9939	Лакаш	1	12	124	40.873175000000003	40.899971000000001	54.679161000000001	54.666775000000001	0103000020E61000000100000005000000A857CA32C46F44402C6519E258554B40A857CA32C46F4440FDDB65BFEE564B40992CEE3F32734440FDDB65BFEE564B40992CEE3F327344402C6519E258554B40A857CA32C46F44402C6519E258554B40
9724	Кутуково	1	12	124	40.491112000000001	40.521628	54.439816	54.413584999999998	0103000020E610000001000000050000002A560DC2DC3E4440DE8E705AF0344B402A560DC2DC3E4440F72004E44B384B40C556D0B4C4424440F72004E44B384B40C556D0B4C4424440DE8E705AF0344B402A560DC2DC3E4440DE8E705AF0344B40
10687	Красильниково	1	12	124	40.215589999999999	40.231597999999998	54.433940999999997	54.408423999999997	0103000020E610000001000000050000001DACFF73981B44406473D53C47344B401DACFF73981B44405FB2F1608B374B40D5E8D500A51D44405FB2F1608B374B40D5E8D500A51D44406473D53C47344B401DACFF73981B44406473D53C47344B40
9267	Кирицы	1	12	124	40.334122999999998	40.387770000000003	54.333347000000003	54.281393999999999	0103000020E61000000100000005000000B3EBDE8AC42A444033A5F5B704244B40B3EBDE8AC42A4440209C4F1DAB2A4B405A2F8672A2314440209C4F1DAB2A4B405A2F8672A231444033A5F5B704244B40B3EBDE8AC42A444033A5F5B704244B40
9220	Исады	1	12	124	40.517432999999997	40.549017999999997	54.418432000000003	54.399934000000002	0103000020E61000000100000005000000826F9A3E3B4244407C478D0931334B40826F9A3E3B424440C9CC052E8F354B402975C93846464440C9CC052E8F354B402975C938464644407C478D0931334B40826F9A3E3B4244407C478D0931334B40
8964	Ижевское	1	12	124	40.844213000000003	40.887467000000001	54.576954999999998	54.525624999999998	0103000020E61000000100000005000000D5EDEC2B0F6C4440E17A14AE47434B40D5EDEC2B0F6C4440C02154A9D9494B40BEA3C68498714440C02154A9D9494B40BEA3C68498714440E17A14AE47434B40D5EDEC2B0F6C4440E17A14AE47434B40
8704	Иванково	1	12	124	40.827567000000002	40.849235	54.512721999999997	54.499448999999998	0103000020E61000000100000005000000DA1F28B7ED6944408C82E0F1ED3F4B40DA1F28B7ED69444048F8DEDFA0414B402DCF83BBB36C444048F8DEDFA0414B402DCF83BBB36C44408C82E0F1ED3F4B40DA1F28B7ED6944408C82E0F1ED3F4B40
8825	Заречье	1	12	124	40.221375000000002	40.235137000000002	54.304226999999997	54.290543999999997	0103000020E6100000010000000500000075931804561C44404606B98B30254B4075931804561C4440B4C70BE9F0264B402F8A1EF8181E4440B4C70BE9F0264B402F8A1EF8181E44404606B98B30254B4075931804561C44404606B98B30254B40
10002	Жолобова-Слобода	1	12	124	40.421402999999998	40.442379000000003	54.486130000000003	54.470132999999997	0103000020E61000000100000005000000D8B79388F03544409BE271512D3C4B40D8B79388F035444060CD0182393E4B40F6B704E09F38444060CD0182393E4B40F6B704E09F3844409BE271512D3C4B40D8B79388F03544409BE271512D3C4B40
10498	Дубовичье	1	12	124	40.126396	40.147075000000001	54.446288000000003	54.437103999999998	0103000020E61000000100000005000000302C7FBE2D104440B3791C06F3374B40302C7FBE2D104440734C16F71F394B409487855AD3124440734C16F71F394B409487855AD3124440B3791C06F3374B40302C7FBE2D104440B3791C06F3374B40
9577	Деревенское	1	12	124	40.667001999999997	40.715834999999998	54.510579	54.491751999999998	0103000020E61000000100000005000000EC2E5052605544400DDFC2BAF13E4B40EC2E5052605544401F8315A75A414B40842A357BA05B44401F8315A75A414B40842A357BA05B44400DDFC2BAF13E4B40EC2E5052605544400DDFC2BAF13E4B40
8649	Дегтяное	1	12	124	40.635364000000003	40.669257000000002	54.448506999999999	54.430211999999997	0103000020E610000001000000050000002387889B53514440622CD32F11374B402387889B53514440778368AD68394B403ECF9F36AA554440778368AD68394B403ECF9F36AA554440622CD32F11374B402387889B53514440622CD32F11374B40
8778	Гавриловское	1	12	124	40.078040000000001	40.39705	54.460577000000001	54.419955999999999	0103000020E61000000100000005000000D2E3F736FD09444026E1421EC1354B40D2E3F736FD0944401825E82FF43A4B403B70CE88D23244401825E82FF43A4B403B70CE88D232444026E1421EC1354B40D2E3F736FD09444026E1421EC1354B40
8598	Выжелес	1	12	124	40.756582000000002	40.791077999999999	54.463676	54.447465999999999	0103000020E61000000100000005000000035FD1ADD76044403509DE9046394B40035FD1ADD760444055F833BC593B4B40E44A3D0B4265444055F833BC593B4B40E44A3D0B426544403509DE9046394B40035FD1ADD76044403509DE9046394B40
10926	Веретье	1	12	124	40.465474	40.501730000000002	54.669570999999998	54.648744999999998	0103000020E61000000100000005000000B491EBA6943B4440C5387F130A534B40B491EBA6943B4440CDACA580B4554B4007B64AB038404440CDACA580B4554B4007B64AB038404440C5387F130A534B40B491EBA6943B4440C5387F130A534B40
54659	Брыкин Бор	1	12	124	40.847985999999999	40.862699999999997	54.711457000000003	54.706173	0103000020E61000000100000005000000A1BB24CE8A6C4440BB287AE0635A4B40A1BB24CE8A6C444051C1E105115B4B402D211FF46C6E444051C1E105115B4B402D211FF46C6E4440BB287AE0635A4B40A1BB24CE8A6C4440BB287AE0635A4B40
10789	Бельское	1	12	124	40.353552999999998	40.391741000000003	54.749777000000002	54.727998999999997	0103000020E610000001000000050000008B338639412D4440A6423C122F5D4B408B338639412D4440812557B1F85F4B404DC0AF9124324440812557B1F85F4B404DC0AF9124324440A6423C122F5D4B408B338639412D4440A6423C122F5D4B40
9144	Аргамаково	1	12	124	40.512374999999999	40.531474000000003	54.425083999999998	54.408937999999999	0103000020E61000000100000005000000DD24068195414440BB0B941458344B40DD24068195414440C4060B2769364B4050560C5707444440C4060B2769364B4050560C5707444440BB0B941458344B40DD24068195414440BB0B941458344B40
7023	Шелемишево	1	12	712	39.811006999999996	39.847371000000003	53.705542999999999	53.696725999999998	0103000020E61000000100000005000000DDE9CE13CFE74340EE224C512ED94A40DDE9CE13CFE74340FB75A73B4FDA4A40174A26A776EC4340FB75A73B4FDA4A40174A26A776EC4340EE224C512ED94A40DDE9CE13CFE74340EE224C512ED94A40
5435	Чулково	1	12	712	39.556415000000001	39.593389999999999	53.752702999999997	53.729872999999998	0103000020E610000001000000050000007E00529B38C74340E09D7C7A6CDD4A407E00529B38C74340F04C689258E04A4000E31934F4CB4340F04C689258E04A4000E31934F4CB4340E09D7C7A6CDD4A407E00529B38C74340E09D7C7A6CDD4A40
6747	Совхоз Желтухинский	1	12	712	39.798986999999997	39.816873000000001	53.758611999999999	53.751770999999998	0103000020E61000000100000005000000EE76BD3445E64340658A39083AE04A40EE76BD3445E64340342DB1321AE14A4022FE614B8FE84340342DB1321AE14A4022FE614B8FE84340658A39083AE04A40EE76BD3445E64340658A39083AE04A40
54587	Скопин	1	12	712	39.661949	39.697584999999997	53.931212000000002	53.913252999999997	0103000020E61000000100000005000000594FADBEBAD44340A8FC6B79E5F44A40594FADBEBAD4434046D26EF431F74A400F971C774AD9434046D26EF431F74A400F971C774AD94340A8FC6B79E5F44A40594FADBEBAD44340A8FC6B79E5F44A40
5428	Секирино	1	12	712	39.479115	39.556711999999997	53.754151	53.734927999999996	0103000020E61000000100000005000000F302ECA353BD43401475E61E12DE4A40F302ECA353BD4340739F1C0588E04A4037A5BC5642C74340739F1C0588E04A4037A5BC5642C743401475E61E12DE4A40F302ECA353BD43401475E61E12DE4A40
6696	Свинушки	1	12	712	39.586095999999998	39.623367000000002	53.744599000000001	53.730389000000002	0103000020E610000001000000050000008028983105CB4340D82D02637DDD4A408028983105CB434031D120054FDF4A40EC33677DCACF434031D120054FDF4A40EC33677DCACF4340D82D02637DDD4A408028983105CB4340D82D02637DDD4A40
5960	Рудинка	1	12	712	38.956907000000001	38.993684000000002	53.817701	53.798119	0103000020E610000001000000050000002028B7ED7B7A43407AA86DC328E64A402028B7ED7B7A43400874266DAAE84A407C478D09317F43400874266DAAE84A407C478D09317F43407AA86DC328E64A402028B7ED7B7A43407AA86DC328E64A40
7232	Рождествено	1	12	712	39.608364999999999	39.641207000000001	53.918705000000003	53.897658	0103000020E61000000100000005000000F98381E7DECD4340137F1475E6F24A40F98381E7DECD4340FAD51C2098F54A40AF7B2B1213D24340FAD51C2098F54A40AF7B2B1213D24340137F1475E6F24A40F98381E7DECD4340137F1475E6F24A40
6345	Пупки	1	12	712	39.455129999999997	39.478397000000001	53.785411000000003	53.767798999999997	0103000020E61000000100000005000000D8B628B341BA43406473D53C47E24A40D8B628B341BA43409775FF5888E44A4094C0E61C3CBD43409775FF5888E44A4094C0E61C3CBD43406473D53C47E24A40D8B628B341BA43406473D53C47E24A40
6557	Поляны	1	12	712	39.647145000000002	39.672243999999999	53.692968	53.671939999999999	0103000020E610000001000000050000008D62B9A5D5D24340E76F422102D64A408D62B9A5D5D243405796E82CB3D84A40537765170CD643405796E82CB3D84A40537765170CD64340E76F422102D64A408D62B9A5D5D24340E76F422102D64A40
5282	Побединка	1	12	712	39.552444999999999	39.573025000000001	53.718561999999999	53.709209999999999	0103000020E610000001000000050000005BEB8B84B6C6434082FFAD64C7DA4A405BEB8B84B6C64340FD12F1D6F9DB4A402C6519E258C94340FD12F1D6F9DB4A402C6519E258C9434082FFAD64C7DA4A405BEB8B84B6C6434082FFAD64C7DA4A40
6496	Петрушино	1	12	712	38.971890000000002	39.407860999999997	53.910283	53.745829000000001	0103000020E610000001000000050000009CA73AE4667C434046B41D5377DF4A409CA73AE4667C4340698D412784F44A402C280CCA34B44340698D412784F44A402C280CCA34B4434046B41D5377DF4A409CA73AE4667C434046B41D5377DF4A40
5055	Павелец	1	12	712	39.237172000000001	39.302236999999998	53.846066999999998	53.832858999999999	0103000020E6100000010000000500000072C3EFA65B9E4340F296AB1F9BEA4A4072C3EFA65B9E4340C79C67EC4BEC4A401152B7B3AFA64340C79C67EC4BEC4A401152B7B3AFA64340F296AB1F9BEA4A4072C3EFA65B9E4340F296AB1F9BEA4A40
6500	Новые Кельцы	1	12	712	39.387729999999998	39.446919999999999	53.810200000000002	53.795836999999999	0103000020E61000000100000005000000CBD6FA22A1B143402FF99FFCDDE54A40CBD6FA22A1B143400F9C33A2B4E74A40D3F6AFAC34B943400F9C33A2B4E74A40D3F6AFAC34B943402FF99FFCDDE54A40CBD6FA22A1B143402FF99FFCDDE54A40
54693	Новое	1	12	712	39.690685999999999	39.724983999999999	53.810434000000001	53.806063000000002	0103000020E610000001000000050000000CE71A6668D8434001C287122DE74A400CE71A6668D8434082C8224DBCE74A40C70F9546CCDC434082C8224DBCE74A40C70F9546CCDC434001C287122DE74A400CE71A6668D8434001C287122DE74A40
6075	Нагиши	1	12	712	38.894689	38.941068999999999	53.856732000000001	53.832880000000003	0103000020E61000000100000005000000A48B4D2B857243400ABFD4CF9BEA4A40A48B4D2B85724340E5B7E864A9ED4A40C423F1F274784340E5B7E864A9ED4A40C423F1F2747843400ABFD4CF9BEA4A40A48B4D2B857243400ABFD4CF9BEA4A40
7220	Моховое	1	12	712	39.586545000000001	39.612442999999999	53.960045999999998	53.949613999999997	0103000020E61000000100000005000000F05014E813CB434070E998F38CF94A40F05014E813CB4340EB538EC9E2FA4A4002D53F8864CE4340EB538EC9E2FA4A4002D53F8864CE434070E998F38CF94A40F05014E813CB434070E998F38CF94A40
7139	Лопатино	1	12	712	39.433174999999999	39.486975000000001	53.854405999999997	53.834834999999998	0103000020E61000000100000005000000EF38454772B7434030478FDFDBEA4A40EF38454772B74340CAC0012D5DED4A401C7C613255BE4340CAC0012D5DED4A401C7C613255BE434030478FDFDBEA4A40EF38454772B7434030478FDFDBEA4A40
5114	Кремлево	1	12	712	39.187719999999999	39.311551999999999	53.838208999999999	53.786161	0103000020E610000001000000050000000E677E3507984340013274ECA0E44A400E677E35079843403F1BB96E4AEB4A406F8099EFE0A743403F1BB96E4AEB4A406F8099EFE0A74340013274ECA0E44A400E677E3507984340013274ECA0E44A40
6288	Корневое	1	12	712	39.476078999999999	39.523994999999999	53.785240999999999	53.766010999999999	0103000020E61000000100000005000000FCA71B28F0BC434029B000A60CE24A40FCA71B28F0BC43403A3DEFC682E44A403E22A64412C343403A3DEFC682E44A403E22A64412C3434029B000A60CE24A40FCA71B28F0BC434029B000A60CE24A40
6393	Князево	1	12	712	39.355462000000003	39.386957000000002	53.750146999999998	53.728434	0103000020E61000000100000005000000427C60C77FAD4340B1A547533DDD4A40427C60C77FAD4340A41820D104E04A40A9FA95CE87B14340A41820D104E04A40A9FA95CE87B14340B1A547533DDD4A40427C60C77FAD4340B1A547533DDD4A40
5971	Клекотки	1	12	712	38.847582000000003	38.894249000000002	53.897095	53.871392	0103000020E61000000100000005000000D25625917D6C43407EFFE6C589EF4A40D25625917D6C4340DB334B02D4F24A4088BD50C076724340DB334B02D4F24A4088BD50C0767243407EFFE6C589EF4A40D25625917D6C43407EFFE6C589EF4A40
5919	Катино	1	12	712	39.154041999999997	39.213816000000001	53.940043000000003	53.921213000000002	0103000020E61000000100000005000000EF1AF4A5B793434035D3BD4EEAF54A40EF1AF4A5B7934340B8EA3A5453F84A4047AE9B525E9B4340B8EA3A5453F84A4047AE9B525E9B434035D3BD4EEAF54A40EF1AF4A5B793434035D3BD4EEAF54A40
6186	Казинка	1	12	712	39.367364999999999	39.430641999999999	53.914042999999999	53.889237000000001	0103000020E61000000100000005000000F758FAD005AF434053B29C84D2F14A40F758FAD005AF4340A1116C5CFFF44A405B24ED461FB74340A1116C5CFFF44A405B24ED461FB7434053B29C84D2F14A40F758FAD005AF434053B29C84D2F14A40
6140	Ильинка	1	12	712	39.423321000000001	39.473239999999997	53.930242	53.911921999999997	0103000020E61000000100000005000000E25AED612FB643405F402FDCB9F44A40E25AED612FB64340CDAE7B2B12F74A405B94D92093BC4340CDAE7B2B12F74A405B94D92093BC43405F402FDCB9F44A40E25AED612FB643405F402FDCB9F44A40
5728	Затворное	1	12	712	39.056663999999998	39.089381000000003	53.773694999999996	53.753028	0103000020E61000000100000005000000266E15C440874340747CB43863E04A40266E15C440874340130A117008E34A4020F12BD6708B4340130A117008E34A4020F12BD6708B4340747CB43863E04A40266E15C440874340747CB43863E04A40
6615	Ермолово	1	12	712	39.627004999999997	39.662785	53.742393999999997	53.728360000000002	0103000020E61000000100000005000000D8B628B341D0434077DB85E63ADD4A40D8B628B341D04340915F3FC406DF4A40C2A38D23D6D44340915F3FC406DF4A40C2A38D23D6D4434077DB85E63ADD4A40D8B628B341D0434077DB85E63ADD4A40
4974	Делехово	1	12	712	39.163500999999997	39.192624000000002	53.797767999999998	53.780506000000003	0103000020E6100000010000000500000080EECB99ED944340782AE09EE7E34A4080EECB99ED944340CDE506431DE64A405D363AE7A7984340CDE506431DE64A405D363AE7A7984340782AE09EE7E34A4080EECB99ED944340782AE09EE7E34A40
7079	Гремячка	1	12	712	39.489994000000003	39.540219	53.933131000000003	53.908867000000001	0103000020E610000001000000050000003D9E961FB8BE4340F2B4FCC055F44A403D9E961FB8BE434020F12BD670F74A40C3D66CE525C5434020F12BD670F74A40C3D66CE525C54340F2B4FCC055F44A403D9E961FB8BE4340F2B4FCC055F44A40
6881	Городецкое	1	12	712	39.748727000000002	39.787506999999998	53.721145999999997	53.706235999999997	0103000020E61000000100000005000000EC504D49D6DF434001A1F5F065DA4A40EC504D49D6DF434013D21A834EDC4A407F2F8507CDE4434013D21A834EDC4A407F2F8507CDE4434001A1F5F065DA4A40EC504D49D6DF434001A1F5F065DA4A40
5810	Горлово	1	12	712	39.017696000000001	39.060482	53.848658999999998	53.819381	0103000020E6100000010000000500000090A2CEDC438243405DFB027AE1E84A4090A2CEDC43824340603AADDBA0EC4A4093FFC9DFBD874340603AADDBA0EC4A4093FFC9DFBD8743405DFB027AE1E84A4090A2CEDC438243405DFB027AE1E84A40
5491	Вослебово	1	12	712	39.585079999999998	39.643076000000001	53.848452000000002	53.824334	0103000020E6100000010000000500000097C5C4E6E3CA43408D7DC9C683E94A4097C5C4E6E3CA4340E71C3C139AEC4A40D76B7A5050D24340E71C3C139AEC4A40D76B7A5050D243408D7DC9C683E94A4097C5C4E6E3CA43408D7DC9C683E94A40
5593	Вердерево	1	12	712	39.635027000000001	39.666691999999998	53.886132000000003	53.871228000000002	0103000020E61000000100000005000000DB89929048D1434004AE2B6684EF4A40DB89929048D1434034F8FBC56CF14A409E40D82956D5434034F8FBC56CF14A409E40D82956D5434004AE2B6684EF4A40DB89929048D1434004AE2B6684EF4A40
5654	Богослово	1	12	712	39.046360999999997	39.071559000000001	53.912219	53.891008999999997	0103000020E61000000100000005000000A9674128EF85434088B839950CF24A40A9674128EF85434019E59997C3F44A40035E66D82889434019E59997C3F44A40035E66D82889434088B839950CF24A40A9674128EF85434088B839950CF24A40
6283	Березняги	1	12	712	39.292552999999998	39.320256999999998	53.895249	53.875999999999998	0103000020E6100000010000000500000060AC6F6072A54340E3A59BC420F04A4060AC6F6072A543406B63EC8497F24A4054A86E2EFEA843406B63EC8497F24A4054A86E2EFEA84340E3A59BC420F04A4060AC6F6072A54340E3A59BC420F04A40
2729	Чубарово	1	12	281	41.625298000000001	41.656578000000003	54.413229000000001	54.398949000000002	0103000020E610000001000000050000008A20CEC309D04440CEE2C5C210334B408A20CEC309D04440206118B0E4344B40F5A276BF0AD44440206118B0E4344B40F5A276BF0AD44440CEE2C5C210334B408A20CEC309D04440CEE2C5C210334B40
1921	Фроловское	1	12	281	41.856929000000001	41.878478999999999	54.391357999999997	54.378968999999998	0103000020E610000001000000050000003BFF76D9AFED44405299620E82304B403BFF76D9AFED44409483D90418324B40849CF7FF71F044409483D90418324B40849CF7FF71F044405299620E82304B403BFF76D9AFED44405299620E82304B40
2269	Устье	1	12	281	41.991739000000003	42.026206999999999	54.465663999999997	54.437758000000002	0103000020E610000001000000050000007995B54DF1FE4440FCC7427408384B407995B54DF1FE44405776C1E09A3B4B4090F63FC05A0345405776C1E09A3B4B4090F63FC05A034540FCC7427408384B407995B54DF1FE4440FCC7427408384B40
1244	Усады	1	12	281	42.057746999999999	42.072749000000002	54.152957000000001	54.145589999999999	0103000020E610000001000000050000009738F24064074540F44F70B1A2124B409738F24064074540DE58501894134B408AE8D7D64F094540DE58501894134B408AE8D7D64F094540F44F70B1A2124B409738F24064074540F44F70B1A2124B40
3986	Трудолюбовка	1	12	281	42.120207000000001	42.142978999999997	54.342055999999999	54.331893000000001	0103000020E6100000010000000500000009E066F1620F4540BB6246787B2A4B4009E066F1620F454046B3B27DC82B4B40E481C8224D12454046B3B27DC82B4B40E481C8224D124540BB6246787B2A4B4009E066F1620F4540BB6246787B2A4B40
2230	Темгенево	1	12	281	41.919119000000002	41.955088000000003	54.391520999999997	54.375649000000003	0103000020E61000000100000005000000ED10FFB0A5F5444037E3344415304B40ED10FFB0A5F544403E59315C1D324B40AA66D65240FA44403E59315C1D324B40AA66D65240FA444037E3344415304B40ED10FFB0A5F5444037E3344415304B40
3740	Сотницыно	1	12	281	41.780455000000003	41.829206999999997	54.293824000000001	54.262971	0103000020E61000000100000005000000F67F0EF3E5E34440F165A208A9214B40F67F0EF3E5E34440D4635B069C254B40A04E797423EA4440D4635B069C254B40A04E797423EA4440F165A208A9214B40F67F0EF3E5E34440F165A208A9214B40
3530	Салтыково	1	12	281	42.334383000000003	42.375355999999996	54.154221999999997	54.134587000000003	0103000020E6100000010000000500000050ABE80FCD2A4540BFBB95253A114B4050ABE80FCD2A45406F29E78BBD134B40BE2D58AA0B3045406F29E78BBD134B40BE2D58AA0B304540BFBB95253A114B4050ABE80FCD2A4540BFBB95253A114B40
1415	Саблино	1	12	281	41.865085999999998	41.888477999999999	54.307620999999997	54.291111999999998	0103000020E610000001000000050000001D1D5723BBEE444090BC732843254B401D1D5723BBEE44400A48FB1F60274B40959BA8A5B9F144400A48FB1F60274B40959BA8A5B9F1444090BC732843254B401D1D5723BBEE444090BC732843254B40
3426	Придорожный	1	12	281	42.409581000000003	42.441723000000003	54.168292999999998	54.159694999999999	0103000020E61000000100000005000000100874266D344540D82AC1E270144B40100874266D344540A79201A08A154B400D7217618A384540A79201A08A154B400D7217618A384540D82AC1E270144B40100874266D344540D82AC1E270144B40
3321	Пичкиряево	1	12	281	42.428804999999997	42.473199999999999	54.213571999999999	54.181263000000001	0103000020E610000001000000050000003EAE0D15E3364540C87C40A033174B403EAE0D15E3364540B0ABC953561B4B40CD3B4ED1913C4540B0ABC953561B4B40CD3B4ED1913C4540C87C40A033174B403EAE0D15E3364540C87C40A033174B40
2170	Огарево-Почково	1	12	281	41.939197	41.956462000000002	54.4816	54.468300999999997	0103000020E610000001000000050000002BC0779B37F8444090D78349F13B4B402BC0779B37F8444076E09C11A53D4B40F2EEC8586DFA444076E09C11A53D4B40F2EEC8586DFA444090D78349F13B4B402BC0779B37F8444090D78349F13B4B40
3024	Новое Березово	1	12	281	41.961357999999997	41.992179	54.224964	54.193227999999998	0103000020E61000000100000005000000BDDF68C70DFB4440F355F2B1BB184B40BDDF68C70DFB44408063CF9ECB1C4B409563B2B8FFFE44408063CF9ECB1C4B409563B2B8FFFE4440F355F2B1BB184B40BDDF68C70DFB4440F355F2B1BB184B40
2963	Нижнее Мальцево	1	12	281	41.701745000000003	41.732458000000001	54.263508000000002	54.244281999999998	0103000020E61000000100000005000000D690B8C7D2D944403080F0A1441F4B40D690B8C7D2D94440001E51A1BA214B40C7D8092FC1DD4440001E51A1BA214B40C7D8092FC1DD44403080F0A1441F4B40D690B8C7D2D944403080F0A1441F4B40
2115	Мыс Доброй Надежды	1	12	281	42.063046999999997	42.077114999999999	54.532845000000002	54.505707000000001	0103000020E61000000100000005000000328E91EC11084540DC2DC901BB404B40328E91EC11084540276BD44334444B40F98381E7DE094540276BD44334444B40F98381E7DE094540DC2DC901BB404B40328E91EC11084540DC2DC901BB404B40
2625	Мокрое	1	12	281	41.664132000000002	41.691916999999997	54.432312000000003	54.415508000000003	0103000020E61000000100000005000000111D024702D54440FA9CBB5D2F354B40111D024702D544408DD5E6FF55374B40F1457BBC90D844408DD5E6FF55374B40F1457BBC90D84440FA9CBB5D2F354B40111D024702D54440FA9CBB5D2F354B40
3206	Матвеевское	1	12	281	42.494382000000002	42.538120999999997	54.118954000000002	54.104042999999997	0103000020E6100000010000000500000094DDCCE8473F45405930F147510D4B4094DDCCE8473F45403CDD79E2390F4B4039252026E14445403CDD79E2390F4B4039252026E14445405930F147510D4B4094DDCCE8473F45405930F147510D4B40
2920	Малый Студенец	1	12	281	41.915112999999998	41.956524999999999	54.226821999999999	54.207622000000001	0103000020E610000001000000050000007D923B6C22F544400EF7915B931A4B407D923B6C22F54440B401D880081D4B40386744696FFA4440B401D880081D4B40386744696FFA44400EF7915B931A4B407D923B6C22F544400EF7915B931A4B40
1861	Любовниково	1	12	281	41.779134999999997	41.800505999999999	54.456389999999999	54.435778999999997	0103000020E61000000100000005000000A01518B2BAE344404CA4349BC7374B40A01518B2BAE34440581CCEFC6A3A4B403A2009FB76E64440581CCEFC6A3A4B403A2009FB76E644404CA4349BC7374B40A01518B2BAE344404CA4349BC7374B40
2855	Кустаревка	1	12	281	42.249752999999998	42.284168000000001	54.276169000000003	54.252999000000003	0103000020E61000000100000005000000F88903E8F71F4540DA756F4562204B40F88903E8F71F4540A3957B8159234B40ED48F59D5F244540A3957B8159234B40ED48F59D5F244540DA756F4562204B40F88903E8F71F4540DA756F4562204B40
2463	Кошибеево	1	12	281	42.052824000000001	42.071185999999997	54.440513000000003	54.415334999999999	0103000020E61000000100000005000000D238D4EFC20645402CF180B229354B40D238D4EFC20645403F3BE0BA62384B406EF7729F1C0945403F3BE0BA62384B406EF7729F1C0945402CF180B229354B40D238D4EFC20645402CF180B229354B40
1653	Ключи	1	12	281	42.158026	42.180385000000001	54.275764000000002	54.260688999999999	0103000020E6100000010000000500000077F52A323A144540A6B6D4415E214B4077F52A323A14454003B5183C4C234B4030D80DDB1617454003B5183C4C234B4030D80DDB16174540A6B6D4415E214B4077F52A323A144540A6B6D4415E214B40
2567	Каргашино	1	12	281	41.721912000000003	41.749040999999998	54.411971000000001	54.389361000000001	0103000020E61000000100000005000000844BC79C67DC44403FABCC94D6314B40844BC79C67DC444041F33977BB344B407B2E5393E0DF444041F33977BB344B407B2E5393E0DF44403FABCC94D6314B40844BC79C67DC44403FABCC94D6314B40
2402	Демушкино	1	12	281	42.119947000000003	42.144426000000003	54.434061	54.413983000000002	0103000020E610000001000000050000006D205D6C5A0F4540CC0C1B65FD344B406D205D6C5A0F45400ABC934F8F374B409758198D7C1245400ABC934F8F374B409758198D7C124540CC0C1B65FD344B406D205D6C5A0F4540CC0C1B65FD344B40
1996	Глядково	1	12	281	41.942430000000002	41.982962000000001	54.425482000000002	54.404735000000002	0103000020E610000001000000050000007862D68BA1F84440F645425BCE334B407862D68BA1F84440B284B53176364B40FA9AE5B2D1FD4440B284B53176364B40FA9AE5B2D1FD4440F645425BCE334B407862D68BA1F84440F645425BCE334B40
1800	Гавриловское	1	12	281	41.828273000000003	41.851305000000004	54.423754000000002	54.406323	0103000020E61000000100000005000000759483D904EA44406A4E5E6402344B40759483D904EA44404CC631923D364B40EDF5EE8FF7EC44404CC631923D364B40EDF5EE8FF7EC44406A4E5E6402344B40759483D904EA44406A4E5E6402344B40
1533	Вялсы	1	12	281	41.989772000000002	42.018931000000002	54.279359999999997	54.266226000000003	0103000020E610000001000000050000008E3F51D9B0FE444026AC8DB113224B408E3F51D9B0FE4440C0E78711C2234B40B7F0BC546C024540C0E78711C2234B40B7F0BC546C02454026AC8DB113224B408E3F51D9B0FE444026AC8DB113224B40
3631	Верхнее Мальцево	1	12	281	41.782234000000003	41.810845	54.319349000000003	54.305177999999998	0103000020E61000000100000005000000DEE8633E20E44440B6BA9C1210274B40DEE8633E20E444405281936DE0284B400490DAC4C9E744405281936DE0284B400490DAC4C9E74440B6BA9C1210274B40DEE8633E20E44440B6BA9C1210274B40
3084	Боковой Майдан	1	12	281	42.498334999999997	42.524368000000003	54.170859999999998	54.157386000000002	0103000020E61000000100000005000000E0B9F770C93F4540946C753925144B40E0B9F770C93F4540E71890BDDE154B40D388997D1E434540E71890BDDE154B40D388997D1E434540946C753925144B40E0B9F770C93F4540946C753925144B40
1763	Берестянки	1	12	281	41.967582999999998	42.01558	54.340843	54.321795999999999	0103000020E6100000010000000500000031957EC2D9FB4440E7FD7F9C30294B4031957EC2D9FB4440070951BEA02B4B40603C8386FE014540070951BEA02B4B40603C8386FE014540E7FD7F9C30294B4031957EC2D9FB4440E7FD7F9C30294B40
1457	Батьки	1	12	281	42.042988000000001	42.058619	54.271999999999998	54.259390000000003	0103000020E610000001000000050000006B0F7BA180054540697407B133214B406B0F7BA180054540894160E5D0224B404DF6CFD380074540894160E5D0224B404DF6CFD380074540697407B133214B406B0F7BA180054540697407B133214B40
2341	Бастаново	1	12	281	42.001333000000002	42.037920999999997	54.392155000000002	54.377856999999999	0103000020E61000000100000005000000EAB303AE2B00454047C8409E5D304B40EAB303AE2B00454040FB912232324B40726A6798DA04454040FB912232324B40726A6798DA04454047C8409E5D304B40EAB303AE2B00454047C8409E5D304B40
1345	Алешино	1	12	281	41.853909999999999	41.889474999999997	54.290050000000001	54.262892000000001	0103000020E610000001000000050000001ADD41EC4CED4440A530EF71A6214B401ADD41EC4CED4440371AC05B20254B4007CE1951DAF14440371AC05B20254B4007CE1951DAF14440A530EF71A6214B401ADD41EC4CED4440A530EF71A6214B40
1190	Агломазово	1	12	281	42.037121999999997	42.057603	54.169231000000003	54.157755000000002	0103000020E6100000010000000500000026FBE769C0044540E7E3DA5031144B4026FBE769C0044540153C855CA9154B406493FC885F074540153C855CA9154B406493FC885F074540E7E3DA5031144B4026FBE769C0044540E7E3DA5031144B40
761	Ягодное	1	12	75	41.237208000000003	41.264113000000002	53.633099000000001	53.587803000000001	0103000020E61000000100000005000000BF2CEDD45C9E4440CFBEF2203DCB4A40BF2CEDD45C9E4440AE10566309D14A4067B96C74CEA14440AE10566309D14A4067B96C74CEA14440CFBEF2203DCB4A40BF2CEDD45C9E4440CFBEF2203DCB4A40
31463	Троицкое	1	12	75	41.116196000000002	41.147871000000002	53.466748000000003	53.441465999999998	0103000020E6100000010000000500000088F6B182DF8E4440E12538F581B84A4088F6B182DF8E444099BC0166BEBB4A406F83DA6FED92444099BC0166BEBB4A406F83DA6FED924440E12538F581B84A4088F6B182DF8E4440E12538F581B84A40
456	Телятники	1	12	75	40.942326999999999	41.009458000000002	53.650896000000003	53.616309000000001	0103000020E61000000100000005000000A391CF2B9E784440809D9B36E3CE4A40A391CF2B9E784440728C648F50D34A40C15774EB35814440728C648F50D34A40C15774EB35814440809D9B36E3CE4A40A391CF2B9E784440809D9B36E3CE4A40
31892	Таптыково	1	12	75	41.250996999999998	41.270482000000001	53.762604000000003	53.726863000000002	0103000020E61000000100000005000000723271AB20A0444013D6C6D809DD4A40723271AB20A044403FE603029DE14A400E1478279FA244403FE603029DE14A400E1478279FA2444013D6C6D809DD4A40723271AB20A0444013D6C6D809DD4A40
327	Сысои	1	12	75	41.045301000000002	41.096972000000001	53.839001000000003	53.813709000000003	0103000020E61000000100000005000000F1BC546CCC854440FEBAD39D27E84A40F1BC546CCC854440D927806264EB4A4059501894698C4440D927806264EB4A4059501894698C4440FEBAD39D27E84A40F1BC546CCC854440FEBAD39D27E84A40
27065	Старобокино	1	12	75	40.751579	40.798676999999998	53.589219999999997	53.572834999999998	0103000020E6100000010000000500000021AE9CBD33604440888043A852C94A4021AE9CBD3360444016139B8F6BCB4A40A088450C3B66444016139B8F6BCB4A40A088450C3B664440888043A852C94A4021AE9CBD33604440888043A852C94A40
881	Сараи	1	12	75	40.950071000000001	41.039937999999999	53.759799000000001	53.698948999999999	0103000020E6100000010000000500000063F030ED9B79444034492C2977D94A4063F030ED9B7944404A44F81741E14A400FEF39B01C8544404A44F81741E14A400FEF39B01C85444034492C2977D94A4063F030ED9B79444034492C2977D94A40
32481	Ремизово 1-е	1	12	75	41.067076	41.083461	53.595927000000003	53.580165000000001	0103000020E610000001000000050000005A2C45F29588444055A4C2D842CA4A405A2C45F295884440D6E6FF5547CC4A40E8BE9CD9AE8A4440D6E6FF5547CC4A40E8BE9CD9AE8A444055A4C2D842CA4A405A2C45F29588444055A4C2D842CA4A40
379	Паники	1	12	75	41.020085000000002	41.045858000000003	53.779947999999997	53.764488999999998	0103000020E61000000100000005000000F1113125928244406C938AC6DAE14A40F111312592824440514A0856D5E34A404721C9ACDE854440514A0856D5E34A404721C9ACDE8544406C938AC6DAE14A40F1113125928244406C938AC6DAE14A40
9314	Павловка	1	12	75	40.850447000000003	40.868017999999999	53.499862	53.487825000000001	0103000020E610000001000000050000009CFD8172DB6C4440EA95B20C71BE4A409CFD8172DB6C4440AF415F7AFBBF4A406F2BBD361B6F4440AF415F7AFBBF4A406F2BBD361B6F4440EA95B20C71BE4A409CFD8172DB6C4440EA95B20C71BE4A40
32040	Островка	1	12	75	41.396766999999997	41.414670000000001	53.805542000000003	53.794038999999998	0103000020E61000000100000005000000E690D442C9B24440D05FE811A3E54A40E690D442C9B24440F8C610001CE74A40F05014E813B54440F8C610001CE74A40F05014E813B54440D05FE811A3E54A40E690D442C9B24440D05FE811A3E54A40
31676	Озерки	1	12	75	40.800249999999998	40.833666999999998	53.650950000000002	53.633654	0103000020E61000000100000005000000DF4F8D976E664440637D03931BD14A40DF4F8D976E66444065AA605452D34A409160AA99B56A444065AA605452D34A409160AA99B56A4440637D03931BD14A40DF4F8D976E664440637D03931BD14A40
108	Новобокино	1	12	75	40.819464000000004	40.858953999999997	53.575626	53.536230000000003	0103000020E61000000100000005000000EB1F4432E46844402A91442FA3C44A40EB1F4432E4684440185DDE1CAEC94A405A626534F26D4440185DDE1CAEC94A405A626534F26D44402A91442FA3C44A40EB1F4432E46844402A91442FA3C44A40
189	Низовка	1	12	75	40.844724999999997	40.858055999999998	53.534939999999999	53.524493	0103000020E610000001000000050000008A8EE4F21F6C44408FFD2C9622C34A408A8EE4F21F6C44403FA9F6E978C44A407B116DC7D46D44403FA9F6E978C44A407B116DC7D46D44408FFD2C9622C34A408A8EE4F21F6C44408FFD2C9622C34A40
32430	Напольное	1	12	75	41.073283000000004	41.115378999999997	53.547305999999999	53.528438000000001	0103000020E61000000100000005000000282D5C566189444059FB3BDBA3C34A40282D5C5661894440C9737D1F0EC64A4095D233BDC48E4440C9737D1F0EC64A4095D233BDC48E444059FB3BDBA3C34A40282D5C566189444059FB3BDBA3C34A40
31807	Назарьево	1	12	75	41.177883000000001	41.218792999999998	53.778266000000002	53.762428999999997	0103000020E61000000100000005000000D7C1C1DEC4964440D042024697E14A40D7C1C1DEC49644405CCB64389EE34A40FFCBB568019C44405CCB64389EE34A40FFCBB568019C4440D042024697E14A40D7C1C1DEC4964440D042024697E14A40
32322	Муравлянка	1	12	75	41.172708999999998	41.209845000000001	53.656323	53.631053999999999	0103000020E61000000100000005000000C85C19541B9644404701A260C6D04A40C85C19541B9644406A4E5E6402D44A40541D7233DC9A44406A4E5E6402D44A40541D7233DC9A44404701A260C6D04A40C85C19541B9644404701A260C6D04A40
838	Мордово	1	12	75	41.266295	41.289516999999996	53.626370999999999	53.606352000000001	0103000020E610000001000000050000004E0B5EF415A244409EEE3CF19CCD4A404E0B5EF415A24440D714C8EC2CD04A4069519FE40EA54440D714C8EC2CD04A4069519FE40EA544409EEE3CF19CCD4A404E0B5EF415A244409EEE3CF19CCD4A40
5807	Меньшие Можары	1	12	75	40.999198999999997	41.059170999999999	53.912123000000001	53.857778000000003	0103000020E610000001000000050000001399B9C0E57F4440399D64ABCBED4A401399B9C0E57F4440F7764B72C0F44A4091EF52EA92874440F7764B72C0F44A4091EF52EA92874440399D64ABCBED4A401399B9C0E57F4440399D64ABCBED4A40
520	Малая Витуша	1	12	75	40.975707999999997	40.980874	53.513823000000002	53.505989	0103000020E610000001000000050000000839EFFFE37C444060915F3FC4C04A400839EFFFE37C44406077BAF3C4C14A4094BF7B478D7D44406077BAF3C4C14A4094BF7B478D7D444060915F3FC4C04A400839EFFFE37C444060915F3FC4C04A40
5956	Максы	1	12	75	41.274335000000001	41.306702000000001	53.721898000000003	53.692583999999997	0103000020E61000000100000005000000F792C6681DA34440CEDDAE97A6D84A40F792C6681DA344401F86562767DC4A4014CFD90242A744401F86562767DC4A4014CFD90242A74440CEDDAE97A6D84A40F792C6681DA34440CEDDAE97A6D84A40
32177	Кривское	1	12	75	41.003844000000001	41.040441000000001	53.720235000000002	53.700164999999998	0103000020E610000001000000050000009624CFF57D804440E466B8019FD94A409624CFF57D804440A03715A930DC4A407235B22B2D854440A03715A930DC4A407235B22B2D854440E466B8019FD94A409624CFF57D804440E466B8019FD94A40
5658	Красная Вершина	1	12	75	40.741014999999997	40.757364000000003	53.696534	53.688819000000002	0103000020E61000000100000005000000376C5B94D95E444085EE92382BD84A40376C5B94D95E4440AA46AF0628D94A407995B54DF1604440AA46AF0628D94A407995B54DF160444085EE92382BD84A40376C5B94D95E444085EE92382BD84A40
31377	Калиновка	1	12	75	41.235097000000003	41.248697	53.526173	53.516291000000002	0103000020E61000000100000005000000A13193A8179E44400D1CD0D215C24A40A13193A8179E4440E48409A359C34A4081CEA44DD59F4440E48409A359C34A4081CEA44DD59F44400D1CD0D215C24A40A13193A8179E44400D1CD0D215C24A40
638	Ивановка	1	12	75	41.012998000000003	41.120714999999997	53.673864999999999	53.631027000000003	0103000020E61000000100000005000000EB7420EBA98144404EF2237EC5D04A40EB7420EBA9814440A375543541D64A407D91D096738F4440A375543541D64A407D91D096738F44404EF2237EC5D04A40EB7420EBA98144404EF2237EC5D04A40
54670	Зеркальные Пруды	1	12	75	41.156216000000001	41.168962999999998	53.820784000000003	53.814666000000003	0103000020E61000000100000005000000548EC9E2FE934440E294B9F946E84A40548EC9E2FE934440408A3A730FE94A40F59D5F94A0954440408A3A730FE94A40F59D5F94A0954440E294B9F946E84A40548EC9E2FE934440E294B9F946E84A40
4692	Желобово	1	12	75	40.731482999999997	40.777557999999999	53.750568000000001	53.715418	0103000020E610000001000000050000003C4A253CA15D4440207C28D192DB4A403C4A253CA15D44404AB6BA9C12E04A40205F4205876344404AB6BA9C12E04A40205F420587634440207C28D192DB4A403C4A253CA15D4440207C28D192DB4A40
31871	Высокое	1	12	75	41.211840000000002	41.25468	53.765760999999998	53.741931000000001	0103000020E6100000010000000500000009FEB7921D9B4440BD715298F7DE4A4009FEB7921D9B4440B0C6D97404E24A40FF78AF5A99A04440B0C6D97404E24A40FF78AF5A99A04440BD715298F7DE4A4009FEB7921D9B4440BD715298F7DE4A40
32318	Веселый	1	12	75	41.039991999999998	41.054158000000001	53.910955999999999	53.90231	0103000020E61000000100000005000000020D36751E854440486DE2E47EF34A40020D36751E854440280CCA349AF44A408C683BA6EE864440280CCA349AF44A408C683BA6EE864440486DE2E47EF34A40020D36751E854440486DE2E47EF34A40
31654	Бычки	1	12	75	40.885176000000001	40.940683	53.637829000000004	53.607318999999997	0103000020E61000000100000005000000209A79724D714440A59E05A1BCCD4A40209A79724D7144405FB87361A4D14A409B73F04C687844405FB87361A4D14A409B73F04C68784440A59E05A1BCCD4A40209A79724D714440A59E05A1BCCD4A40
31565	Борец	1	12	75	41.116483000000002	41.165557999999997	53.820300000000003	53.786288999999996	0103000020E610000001000000050000001EC539EAE88E44402E1A321EA5E44A401EC539EAE88E444054742497FFE84A40ABCB29013195444054742497FFE84A40ABCB2901319544402E1A321EA5E44A401EC539EAE88E44402E1A321EA5E44A40
27194	Большие Можары	1	12	75	40.999890999999998	41.051347	53.895769000000001	53.857539000000003	0103000020E610000001000000050000004948A46DFC7F4440B40584D6C3ED4A404948A46DFC7F4440A4E2FF8EA8F24A40B5DFDA8992864440A4E2FF8EA8F24A40B5DFDA8992864440B40584D6C3ED4A404948A46DFC7F4440B40584D6C3ED4A40
32018	Белоречье	1	12	75	41.320365000000002	41.361068000000003	53.866571999999998	53.850911000000004	0103000020E610000001000000050000003BE466B801A944404167D2A6EAEC4A403BE466B801A944408DD0CFD4EBEE4A40EAD0E97937AE44408DD0CFD4EBEE4A40EAD0E97937AE44404167D2A6EAEC4A403BE466B801A944404167D2A6EAEC4A40
31356	Алексеевка	1	12	75	41.252183000000002	41.272143999999997	53.540934	53.522796	0103000020E61000000100000005000000B8CD548847A04440643DB5FAEAC24A40B8CD548847A04440B1A547533DC54A40BCE6559DD5A24440B1A547533DC54A40BCE6559DD5A24440643DB5FAEAC24A40B8CD548847A04440643DB5FAEAC24A40
54656	Черная Речка	1	12	637	40.714640000000003	40.760525999999999	53.875692000000001	53.841901999999997	0103000020E61000000100000005000000EC34D252795B4440EF37DA71C3EB4A40EC34D252795B444036AFEAAC16F04A40FCE07CEA5861444036AFEAAC16F04A40FCE07CEA58614440EF37DA71C3EB4A40EC34D252795B4440EF37DA71C3EB4A40
4308	Собчаково	1	12	637	40.937728	40.98603	53.950822000000002	53.930115000000001	0103000020E6100000010000000500000091459A7807784440704221020EF74A4091459A78077844409E280989B4F94A40FC6F253B367E44409E280989B4F94A40FC6F253B367E4440704221020EF74A4091459A7807784440704221020EF74A40
30086	Сапожок	1	12	637	40.653213000000001	40.716876999999997	53.966836999999998	53.931811000000003	0103000020E610000001000000050000003929CC7B9C534440CB86359545F74A403929CC7B9C53444008C89750C1FB4A40962023A0C25B444008C89750C1FB4A40962023A0C25B4440CB86359545F74A403929CC7B9C534440CB86359545F74A40
26456	Парышка	1	12	637	40.404712000000004	40.428714999999997	54.002490000000002	53.983533999999999	0103000020E610000001000000050000003E26529ACD33444085402E71E4FD4A403E26529ACD3344409548A29751004B40FE261422E03644409548A29751004B40FE261422E036444085402E71E4FD4A403E26529ACD33444085402E71E4FD4A40
30762	Новокрасное	1	12	637	40.508125999999997	40.546916000000003	54.059299000000003	54.025894999999998	0103000020E61000000100000005000000A71FD4450A414440A110018750034B40A71FD4450A414440BFD7101C97074B405FD4EE5701464440BFD7101C97074B405FD4EE5701464440A110018750034B40A71FD4450A414440A110018750034B40
27020	Морозовы-Борки	1	12	637	40.874279999999999	40.943621	53.969973000000003	53.949115999999997	0103000020E6100000010000000500000000C63368E86F44401F0E12A27CF94A4000C63368E86F44406380441328FC4A40CF68AB92C87844406380441328FC4A40CF68AB92C87844401F0E12A27CF94A4000C63368E86F44401F0E12A27CF94A40
4164	Михей	1	12	637	40.752450000000003	40.771889999999999	54.023916999999997	54.001266999999999	0103000020E6100000010000000500000007F016485060444032C85D8429004B4007F0164850604440C26856B60F034B40020EA14ACD624440C26856B60F034B40020EA14ACD62444032C85D8429004B4007F016485060444032C85D8429004B40
30870	Малый Сапожок	1	12	637	40.590978	40.631383999999997	53.972180999999999	53.952024999999999	0103000020E61000000100000005000000E753C72AA54B4440B9FC87F4DBF94A40E753C72AA54B44407365506D70FC4A40DC9BDF30D15044407365506D70FC4A40DC9BDF30D1504440B9FC87F4DBF94A40E753C72AA54B4440B9FC87F4DBF94A40
31151	Лукмос	1	12	637	40.584851	40.614271000000002	54.113892999999997	54.074542999999998	0103000020E610000001000000050000003604C765DC4A4440A79201A08A094B403604C765DC4A4440251FBB0B940E4B40CCF09F6EA04E4440251FBB0B940E4B40CCF09F6EA04E4440A79201A08A094B403604C765DC4A4440A79201A08A094B40
30587	Красный Угол	1	12	637	40.862602000000003	40.899621000000003	54.052152999999997	54.023662999999999	0103000020E610000001000000050000006BBB09BE696E44400890A16307034B406BBB09BE696E4440B3B112F3AC064B40BDE5EAC726734440B3B112F3AC064B40BDE5EAC7267344400890A16307034B406BBB09BE696E44400890A16307034B40
30539	Красное	1	12	637	40.8688	40.891294000000002	54.002955	53.974272999999997	0103000020E61000000100000005000000E561A1D6346F44401A3048FAB4FC4A40E561A1D6346F44400A2E56D460004B407E8FFAEB157244400A2E56D460004B407E8FFAEB157244401A3048FAB4FC4A40E561A1D6346F44401A3048FAB4FC4A40
4216	Коровка	1	12	637	40.660265000000003	40.705378000000003	54.022637000000003	54.003739000000003	0103000020E61000000100000005000000C3D8429083544440215C01857A004B40C3D8429083544440FC56EBC4E5024B40B1A888D3495A4440FC56EBC4E5024B40B1A888D3495A4440215C01857A004B40C3D8429083544440215C01857A004B40
30682	Канино	1	12	637	40.474763000000003	40.507658999999997	53.954625999999998	53.929122999999997	0103000020E61000000100000005000000E92CB308C53C44400F7BA180EDF64A40E92CB308C53C4440A5F44C2F31FA4A40914259F8FA404440A5F44C2F31FA4A40914259F8FA4044400F7BA180EDF64A40E92CB308C53C44400F7BA180EDF64A40
31016	Васильевка	1	12	637	40.79609	40.807167	54.082202000000002	54.066760000000002	0103000020E610000001000000050000001956F146E66544402A5778978B084B401956F146E665444039D55A98850A4B4089B48D3F5167444039D55A98850A4B4089B48D3F516744402A5778978B084B401956F146E66544402A5778978B084B40
30505	Березники	1	12	637	40.739531999999997	40.769131999999999	53.976210999999999	53.953609	0103000020E61000000100000005000000382C0DFCA85E4440EC1516DC0FFA4A40382C0DFCA85E44406B7F677BF4FC4A404E27D9EA726244406B7F677BF4FC4A404E27D9EA72624440EC1516DC0FFA4A40382C0DFCA85E4440EC1516DC0FFA4A40
54686	Александровка	1	12	637	40.520136999999998	40.529586999999999	53.932527	53.929288	0103000020E61000000100000005000000433866D9934244405A48C0E8F2F64A40433866D99342444089D1730B5DF74A4081B1BE81C943444089D1730B5DF74A4081B1BE81C94344405A48C0E8F2F64A40433866D9934244405A48C0E8F2F64A40
29508	Шумашь	1	12	1339	39.798969	39.828668	54.672742	54.661296999999998	0103000020E6100000010000000500000048C2BE9D44E64340B1F84D61A5544B4048C2BE9D44E64340A452EC681C564B40F19E03CB11EA4340A452EC681C564B40F19E03CB11EA4340B1F84D61A5544B4048C2BE9D44E64340B1F84D61A5544B40
23650	Шевцово	1	12	1339	39.849004999999998	39.871571000000003	54.382660999999999	54.366303000000002	0103000020E61000000100000005000000FB912232ACEC43409EB64604E32E4B40FB912232ACEC4340323A2009FB304B402E9276A38FEF4340323A2009FB304B402E9276A38FEF43409EB64604E32E4B40FB912232ACEC43409EB64604E32E4B40
29938	Тюшево	1	12	1339	39.513717999999997	39.533920999999999	54.678505000000001	54.668441000000001	0103000020E61000000100000005000000EAAEEC82C1C143401C2785798F554B40EAAEEC82C1C1434014967840D9564B40E5D2F88557C4434014967840D9564B40E5D2F88557C443401C2785798F554B40EAAEEC82C1C143401C2785798F554B40
29773	Стенькино	1	12	1339	39.485852999999999	39.731802000000002	54.542983999999997	54.513672999999997	0103000020E61000000100000005000000EDD45C6E30BE43404AEB6F09C0414B40EDD45C6E30BE43402920ED7F80454B40DE921CB0ABDD43402920ED7F80454B40DE921CB0ABDD43404AEB6F09C0414B40EDD45C6E30BE43404AEB6F09C0414B40
54621	Солотча	1	12	1339	39.803505999999999	39.861842000000003	54.811476999999996	54.770749000000002	0103000020E61000000100000005000000E411DC48D9E643405D363AE7A7624B40E411DC48D9E64340643A747ADE674B40DD28B2D650EE4340643A747ADE674B40DD28B2D650EE43405D363AE7A7624B40E411DC48D9E643405D363AE7A7624B40
27681	Сажнево	1	12	1339	39.741261999999999	39.751134	54.469943999999998	54.46311	0103000020E610000001000000050000003FE257ACE1DE4340AC394030473B4B403FE257ACE1DE4340C879FF1F273C4B40F374AE2825E04340C879FF1F273C4B40F374AE2825E04340AC394030473B4B403FE257ACE1DE4340AC394030473B4B40
28135	Рожок	1	12	1339	39.573241000000003	39.588062999999998	54.517598	54.503349	0103000020E61000000100000005000000F9DC09F65FC94340B6BC72BD6D404B40F9DC09F65FC94340CD3CB9A640424B406B7EFCA545CB4340CD3CB9A640424B406B7EFCA545CB4340B6BC72BD6D404B40F9DC09F65FC94340B6BC72BD6D404B40
29688	Ровное	1	12	1339	39.703918999999999	39.721220000000002	54.527673	54.517074999999998	0103000020E610000001000000050000003A048E041ADA4340234A7B832F424B403A048E041ADA4340B9FDF2C98A434B404E9CDCEF50DC4340B9FDF2C98A434B404E9CDCEF50DC4340234A7B832F424B403A048E041ADA4340234A7B832F424B40
54648	Реткино	1	12	1339	39.353898999999998	40.449835	54.975015999999997	54.337452999999996	0103000020E61000000100000005000000268BFB8F4CAD4340F277EFA8312B4B40268BFB8F4CAD4340D2890453CD7C4B404FCC7A3194394440D2890453CD7C4B404FCC7A3194394440F277EFA8312B4B40268BFB8F4CAD4340F277EFA8312B4B40
54667	Приозерный	1	12	1339	39.353898999999998	40.449835	54.975015999999997	54.337452999999996	0103000020E61000000100000005000000268BFB8F4CAD4340F277EFA8312B4B40268BFB8F4CAD4340D2890453CD7C4B404FCC7A3194394440D2890453CD7C4B404FCC7A3194394440F277EFA8312B4B40268BFB8F4CAD4340F277EFA8312B4B40
29413	Поляны	1	12	1339	39.810737000000003	39.846814000000002	54.730156999999998	54.705517	0103000020E610000001000000050000001E54E23AC6E74340D2E28C614E5A4B401E54E23AC6E7434005F9D9C8755D4B40C1E5B16664EC434005F9D9C8755D4B40C1E5B16664EC4340D2E28C614E5A4B401E54E23AC6E74340D2E28C614E5A4B40
28607	Полково	1	12	1339	39.862884000000001	39.888306999999998	54.783465999999997	54.771486000000003	0103000020E61000000100000005000000EF1EA0FB72EE434033A9A10DC0624B40EF1EA0FB72EE434093C3279D48644B4068E7340BB4F1434093C3279D48644B4068E7340BB4F1434033A9A10DC0624B40EF1EA0FB72EE434033A9A10DC0624B40
29268	Подвязье	1	12	1339	39.517698000000003	39.566583999999999	54.600087000000002	54.579960999999997	0103000020E61000000100000005000000319A95ED43C243404CFA7B293C4A4B40319A95ED43C243409CE09BA6CF4C4B40EB3713D385C843409CE09BA6CF4C4B40EB3713D385C843404CFA7B293C4A4B40319A95ED43C243404CFA7B293C4A4B40
54629	Окский	1	12	1339	39.353898999999998	40.449835	54.975015999999997	54.337452999999996	0103000020E61000000100000005000000268BFB8F4CAD4340F277EFA8312B4B40268BFB8F4CAD4340D2890453CD7C4B404FCC7A3194394440D2890453CD7C4B404FCC7A3194394440F277EFA8312B4B40268BFB8F4CAD4340F277EFA8312B4B40
29070	Наумово	1	12	1339	40.043446000000003	40.069280999999997	54.490183000000002	54.473638000000001	0103000020E610000001000000050000002E9276A38F0544404912842BA03C4B402E9276A38F05444010070951BE3E4B40F99D2633DE08444010070951BE3E4B40F99D2633DE0844404912842BA03C4B402E9276A38F0544404912842BA03C4B40
29329	Насурово	1	12	1339	39.394916000000002	39.409765	54.577230999999998	54.567534000000002	0103000020E610000001000000050000006555849B8CB243401DAF40F4A4484B406555849B8CB24340629E95B4E2494B40D105F52D73B44340629E95B4E2494B40D105F52D73B443401DAF40F4A4484B406555849B8CB243401DAF40F4A4484B40
22814	Мушковатово	1	12	1339	39.568776	39.588206999999997	54.620725	54.604081999999998	0103000020E61000000100000005000000F65FE7A6CDC84340170D198F524D4B40F65FE7A6CDC84340A167B3EA734F4B409E23F25D4ACB4340A167B3EA734F4B409E23F25D4ACB4340170D198F524D4B40F65FE7A6CDC84340170D198F524D4B40
14339	Мурмино	1	12	1339	40.008636000000003	40.075839000000002	54.614896000000002	54.595857000000002	0103000020E61000000100000005000000BDC804FC1A014440DD0BCC0A454C4B40BDC804FC1A0144407A3881E9B44E4B407461A417B50944407A3881E9B44E4B407461A417B5094440DD0BCC0A454C4B40BDC804FC1A014440DD0BCC0A454C4B40
29074	Льгово	1	12	1339	39.931040000000003	39.968966999999999	54.596958000000001	54.579428	0103000020E6100000010000000500000049A297512CF743407F315BB22A4A4B4049A297512CF74340F48AA71E694C4B409DF3531C07FC4340F48AA71E694C4B409DF3531C07FC43407F315BB22A4A4B4049A297512CF743407F315BB22A4A4B40
28865	Листвянка	1	12	1339	39.972164999999997	39.991630999999998	54.514837999999997	54.508372999999999	0103000020E610000001000000050000006DA818E76FFC4340AF95D05D12414B406DA818E76FFC4340785E2A36E6414B409259BDC3EDFE4340785E2A36E6414B409259BDC3EDFE4340AF95D05D12414B406DA818E76FFC4340AF95D05D12414B40
54676	Ласково	1	12	1339	39.923799000000002	39.936321999999997	54.838971000000001	54.832701999999998	0103000020E61000000100000005000000EC89AE0B3FF643402AA8A8FA956A4B40EC89AE0B3FF643406EA5D766636B4B403D433866D9F743406EA5D766636B4B403D433866D9F743402AA8A8FA956A4B40EC89AE0B3FF643402AA8A8FA956A4B40
28838	Коростово	1	12	1339	39.686095999999999	39.703477999999997	54.737808000000001	54.722721999999997	0103000020E610000001000000050000004DF564FED1D74340C30C8D27825C4B404DF564FED1D74340145D177E705E4B404DBA2D910BDA4340145D177E705E4B404DBA2D910BDA4340C30C8D27825C4B404DF564FED1D74340C30C8D27825C4B40
27156	Казарь	1	12	1339	40.075578999999998	40.104818999999999	54.578859999999999	54.558231999999997	0103000020E61000000100000005000000D7A19A92AC09444053CA6B2574474B40D7A19A92AC094440357BA015184A4B40ED7F80B56A0D4440357BA015184A4B40ED7F80B56A0D444053CA6B2574474B40D7A19A92AC09444053CA6B2574474B40
29595	Искра	1	12	1339	39.875847	39.901674	54.452846999999998	54.436647999999998	0103000020E610000001000000050000005DA626C11BF0434091EEE714E4374B405DA626C11BF04340BD8BF7E3F6394B40A6D3BA0D6AF34340BD8BF7E3F6394B40A6D3BA0D6AF3434091EEE714E4374B405DA626C11BF0434091EEE714E4374B40
28673	Заокское	1	12	1339	39.724670000000003	39.759101999999999	54.702339000000002	54.686182000000002	0103000020E6100000010000000500000038328FFCC1DC43404C8DD0CFD4574B4038328FFCC1DC434049DA8D3EE6594B40022A1C412AE1434049DA8D3EE6594B40022A1C412AE143404C8DD0CFD4574B4038328FFCC1DC43404C8DD0CFD4574B40
28154	Заборье	1	12	1339	39.857584000000003	39.893445	54.822594000000002	54.806558000000003	0103000020E6100000010000000500000054C90050C5ED4340E129E44A3D674B4054C90050C5ED434063F19BC24A694B402AE3DF675CF2434063F19BC24A694B402AE3DF675CF24340E129E44A3D674B4054C90050C5ED4340E129E44A3D674B40
19418	Екимовка	1	12	1339	39.595078999999998	39.615443999999997	54.481825000000001	54.474454000000001	0103000020E61000000100000005000000A8C4758C2BCC43406BBA9EE8BA3C4B40A8C4758C2BCC434096B20C71AC3D4B407C4276DEC6CE434096B20C71AC3D4B407C4276DEC6CE43406BBA9EE8BA3C4B40A8C4758C2BCC43406BBA9EE8BA3C4B40
27815	Дубровичи	1	12	1339	39.908833000000001	39.947164000000001	54.665598000000003	54.645999000000003	0103000020E610000001000000050000004643C6A354F44340D61F6118B0524B404643C6A354F443403A24B55032554B406AF981AB3CF943403A24B55032554B406AF981AB3CF94340D61F6118B0524B404643C6A354F44340D61F6118B0524B40
27274	Долгинино	1	12	1339	40.130294999999997	40.169632	54.640711000000003	54.618102999999998	0103000020E6100000010000000500000089EAAD81AD1044409D47C5FF1D4F4B4089EAAD81AD104440FF976BD102524B40732D5A80B6154440FF976BD102524B40732D5A80B61544409D47C5FF1D4F4B4089EAAD81AD1044409D47C5FF1D4F4B40
28538	Деулино	1	12	1339	40.313640999999997	40.335183000000001	54.828719	54.813827000000003	0103000020E61000000100000005000000A5D766632528444008CDAE7B2B684B40A5D76663252844407349D576136A4B406C96CB46E72A44407349D576136A4B406C96CB46E72A444008CDAE7B2B684B40A5D766632528444008CDAE7B2B684B40
16060	Дашки 2-е	1	12	1339	39.690246000000002	39.705660999999999	54.452956999999998	54.439481000000001	0103000020E61000000100000005000000F0181EFB59D84340501BD5E940384B40F0181EFB59D8434044BFB67EFA394B400588821953DA434044BFB67EFA394B400588821953DA4340501BD5E940384B40F0181EFB59D84340501BD5E940384B40
27530	Гавердово	1	12	1339	40.113523000000001	40.142853000000002	54.510008999999997	54.499479999999998	0103000020E61000000100000005000000022CF2EB870E4440C780ECF5EE3F4B40022CF2EB870E444034D593F947414B405891D1014912444034D593F947414B405891D10149124440C780ECF5EE3F4B40022CF2EB870E4440C780ECF5EE3F4B40
22157	Вышетравино	1	12	1339	39.742268000000003	39.760117000000001	54.440460000000002	54.423738	0103000020E61000000100000005000000056F48A302DF43404609FA0B3D364B40056F48A302DF43401C9947FE60384B401B118C834BE143401C9947FE60384B401B118C834BE143404609FA0B3D364B40056F48A302DF43404609FA0B3D364B40
27516	Вышгород	1	12	1339	40.027348000000003	40.073225000000001	54.526037000000002	54.508566000000002	0103000020E6100000010000000500000036CEA62380034440C4EDD0B018414B4036CEA6238003444034BE2F2E55434B40F31FD26F5F09444034BE2F2E55434B40F31FD26F5F094440C4EDD0B018414B4036CEA62380034440C4EDD0B018414B40
27425	Высокое	1	12	1339	39.394143999999997	39.440756999999998	54.528194999999997	54.509318999999998	0103000020E6100000010000000500000012F5824F73B243409F1D705D31414B4012F5824F73B243409274CDE49B434B40D53DB2B96AB843409274CDE49B434B40D53DB2B96AB843409F1D705D31414B4012F5824F73B243409F1D705D31414B40
54592	Варские	1	12	1339	39.353898999999998	40.449835	54.975015999999997	54.337452999999996	0103000020E61000000100000005000000268BFB8F4CAD4340F277EFA8312B4B40268BFB8F4CAD4340D2890453CD7C4B404FCC7A3194394440D2890453CD7C4B404FCC7A3194394440F277EFA8312B4B40268BFB8F4CAD4340F277EFA8312B4B40
28460	Борисково	1	12	1339	40.193635	40.223126999999998	54.785921999999999	54.768276999999998	0103000020E61000000100000005000000342E1C08C91844406EA296E656624B40342E1C08C91844407C9A931799644B4063EDEF6C8F1C44407C9A931799644B4063EDEF6C8F1C44406EA296E656624B40342E1C08C91844406EA296E656624B40
28955	Болошнево	1	12	1339	40.007145000000001	40.032702	54.503003999999997	54.490741999999997	0103000020E610000001000000050000003BAA9A20EA004440066344A2D03E4B403BAA9A20EA004440EBE0606F62404B40C44142942F044440EBE0606F62404B40C44142942F044440066344A2D03E4B403BAA9A20EA004440066344A2D03E4B40
28922	Александрово	1	12	1339	39.882970999999998	39.908914000000003	54.518042000000001	54.511253000000004	0103000020E610000001000000050000008028983105F14340AF7D01BD70414B408028983105F143402BFA43334F424B403370404B57F443402BFA43334F424B403370404B57F44340AF7D01BD70414B408028983105F14340AF7D01BD70414B40
27976	Алеканово	1	12	1339	39.956488999999998	39.996032999999997	54.630279000000002	54.614735000000003	0103000020E61000000100000005000000EBFD463B6EFA4340715AF0A2AF4E4B40EBFD463B6EFA4340842D76FBAC504B404E5E64027EFF4340842D76FBAC504B404E5E64027EFF4340715AF0A2AF4E4B40EBFD463B6EFA4340715AF0A2AF4E4B40
19620	Агро-Пустынь	1	12	1339	39.777903999999999	39.804808000000001	54.769575000000003	54.742989999999999	0103000020E61000000100000005000000BBB6B75B92E34340A5A0DB4B1A5F4B40BBB6B75B92E34340DC68006F81624B4093C7D3F203E74340DC68006F81624B4093C7D3F203E74340A5A0DB4B1A5F4B40BBB6B75B92E34340A5A0DB4B1A5F4B40
54682	Шереметьево	1	12	757	40.058788999999997	40.09995	53.585659999999997	53.558444000000001	0103000020E61000000100000005000000A92EE06586074440DF52CE177BC74A40A92EE06586074440A54929E8F6CA4A401B9E5E29CB0C4440A54929E8F6CA4A401B9E5E29CB0C4440DF52CE177BC74A40A92EE06586074440DF52CE177BC74A40
27054	Чирково	1	12	757	39.944837999999997	39.951872000000002	53.791778999999998	53.781533000000003	0103000020E610000001000000050000004F029B73F0F8434055DFF94509E44A404F029B73F0F843406D54A70359E54A4033FD12F1D6F943406D54A70359E54A4033FD12F1D6F9434055DFF94509E44A404F029B73F0F8434055DFF94509E44A40
26407	Турово	1	12	757	40.279558999999999	40.313442999999999	53.655704	53.643317000000003	0103000020E61000000100000005000000B726DD96C8234440FDFA213658D24A40B726DD96C82344409EEDD11BEED34A407F1475E61E2844409EEDD11BEED34A407F1475E61E284440FDFA213658D24A40B726DD96C8234440FDFA213658D24A40
26421	Свет	1	12	757	40.092008999999997	40.112338000000001	53.687049000000002	53.672483999999997	0103000020E6100000010000000500000005F86EF3C60B4440A88AA9F413D64A4005F86EF3C60B4440F0DFBC38F1D74A408D0C7217610E4440F0DFBC38F1D74A408D0C7217610E4440A88AA9F413D64A4005F86EF3C60B4440A88AA9F413D64A40
26888	Салтыки	1	12	757	39.906866000000001	39.948934000000001	53.597620999999997	53.567402000000001	0103000020E610000001000000050000005BED612F14F44340AED7F4A0A0C84A405BED612F14F443408F334DD87ECC4A40FF0758AB76F943408F334DD87ECC4A40FF0758AB76F94340AED7F4A0A0C84A405BED612F14F44340AED7F4A0A0C84A40
5337	Ряжск	1	12	757	40.019083999999999	40.165374	53.731876	53.686233000000001	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
26347	Ратманово	1	12	757	40.148485999999998	40.169974000000003	53.597402000000002	53.581384	0103000020E61000000100000005000000F9F4D89601134440763579CA6ACA4A40F9F4D89601134440524832AB77CC4A40CD9541B5C1154440524832AB77CC4A40CD9541B5C1154440763579CA6ACA4A40F9F4D89601134440763579CA6ACA4A40
26968	Поплевино	1	12	757	40.076718999999997	40.099986000000001	53.811433000000001	53.775260000000003	0103000020E61000000100000005000000ACFD9DEDD1094440D0F23CB83BE34A40ACFD9DEDD109444095F25A09DDE74A4068075C57CC0C444095F25A09DDE74A4068075C57CC0C4440D0F23CB83BE34A40ACFD9DEDD1094440D0F23CB83BE34A40
14257	Подвислово	1	12	757	40.074509999999997	40.105924000000002	53.838486000000003	53.805925000000002	0103000020E61000000100000005000000CB9C2E8B89094440B003E78C28E74A40CB9C2E8B89094440B2135E8253EB4A4046EEE9EA8E0D4440B2135E8253EB4A4046EEE9EA8E0D4440B003E78C28E74A40CB9C2E8B89094440B003E78C28E74A40
26895	Петрово	1	12	757	40.123818	40.186430999999999	53.771726999999998	53.747304	0103000020E61000000100000005000000FC53AA44D90F4440C21550A8A7DF4A40FC53AA44D90F4440583849F3C7E24A40F4FA93F8DC174440583849F3C7E24A40F4FA93F8DC174440C21550A8A7DF4A40FC53AA44D90F4440C21550A8A7DF4A40
10501	Новое Еголдаево	1	12	757	40.287303000000001	40.335433999999999	53.751164000000003	53.722329000000002	0103000020E6100000010000000500000077853E58C6244440E8F9D34675DC4A4077853E58C62444405EF7562426E04A40B5FB5580EF2A44405EF7562426E04A40B5FB5580EF2A4440E8F9D34675DC4A4077853E58C6244440E8F9D34675DC4A40
54673	Марчуки 2-е	1	12	757	40.173827000000003	40.208942	53.643264000000002	53.610208999999998	0103000020E61000000100000005000000B61490F63F164440C85C19541BCE4A40B61490F63F164440DA58897956D24A406361889CBE1A4440DA58897956D24A406361889CBE1A4440C85C19541BCE4A40B61490F63F164440C85C19541BCE4A40
13917	Марчуки 1-е	1	12	757	40.173827000000003	40.208942	53.643264000000002	53.610208999999998	0103000020E61000000100000005000000B61490F63F164440C85C19541BCE4A40B61490F63F164440DA58897956D24A406361889CBE1A4440DA58897956D24A406361889CBE1A4440C85C19541BCE4A40B61490F63F164440C85C19541BCE4A40
10561	Журавинка	1	12	757	39.915705000000003	39.974544999999999	53.650485000000003	53.622056000000001	0103000020E6100000010000000500000050E449D235F54340EA23F0879FCF4A4050E449D235F54340F0C4AC1743D34A407BBDFBE3BDFC4340F0C4AC1743D34A407BBDFBE3BDFC4340EA23F0879FCF4A4050E449D235F54340EA23F0879FCF4A40
26682	Дегтяное	1	12	757	40.181103999999998	40.227384999999998	53.739764000000001	53.708489999999998	0103000020E610000001000000050000005F96766A2E17444082C5E1CCAFDA4A405F96766A2E1744400B613596B0DE4A40EC4CA1F31A1D44400B613596B0DE4A40EC4CA1F31A1D444082C5E1CCAFDA4A405F96766A2E17444082C5E1CCAFDA4A40
26524	Введеновка	1	12	757	40.043176000000003	40.072183000000003	53.671854000000003	53.655262	0103000020E610000001000000050000006EFC89CA86054440E1270EA0DFD34A406EFC89CA86054440E9D7D64FFFD54A40E129E44A3D094440E9D7D64FFFD54A40E129E44A3D094440E1270EA0DFD34A406EFC89CA86054440E1270EA0DFD34A40
26263	Большая Алешня	1	12	757	40.114457999999999	40.147165000000001	53.646706000000002	53.635389000000004	0103000020E61000000100000005000000FE614B8FA60E44407C9E3F6D54D14A40FE614B8FA60E444041102043C7D24A40D40E7F4DD612444041102043C7D24A40D40E7F4DD61244407C9E3F6D54D14A40FE614B8FA60E44407C9E3F6D54D14A40
25116	Шехмино	1	12	703	39.742654000000002	39.762084999999999	54.959408000000003	54.946435999999999	0103000020E610000001000000050000002E1F49490FDF4340E7E099D024794B402E1F49490FDF4340A9C29FE1CD7A4B40D6E253008CE14340A9C29FE1CD7A4B40D6E253008CE14340E7E099D024794B402E1F49490FDF4340E7E099D024794B40
25052	Чурилково	1	12	703	39.416449	39.436121999999997	54.817717999999999	54.806584000000001	0103000020E61000000100000005000000D8B969334EB543400ABDFE243E674B40D8B969334EB54340DEACC1FBAA684B4076887FD8D2B74340DEACC1FBAA684B4076887FD8D2B743400ABDFE243E674B40D8B969334EB543400ABDFE243E674B40
24954	Ходынино	1	12	703	39.536140000000003	39.569369000000002	54.735624999999999	54.721063000000001	0103000020E61000000100000005000000EA094B3CA0C4434086ADD9CA4B5C4B40EA094B3CA0C443405C8FC2F5285E4B40992D5915E1C843405C8FC2F5285E4B40992D5915E1C8434086ADD9CA4B5C4B40EA094B3CA0C4434086ADD9CA4B5C4B40
24818	Федякино	1	12	703	39.521318000000001	39.573329999999999	54.869114000000003	54.858154999999996	0103000020E610000001000000050000007768588CBAC243400EF3E505D86D4B407768588CBAC24340753FA7203F6F4B4068E89FE062C94340753FA7203F6F4B4068E89FE062C943400EF3E505D86D4B407768588CBAC243400EF3E505D86D4B40
24760	Сельцы	1	12	703	39.501078999999997	39.550037000000003	54.915833999999997	54.902003999999998	0103000020E610000001000000050000002FDB4E5B23C043403B6EF8DD74734B402FDB4E5B23C043404D486B0C3A754B40844BC79C67C643404D486B0C3A754B40844BC79C67C643403B6EF8DD74734B402FDB4E5B23C043403B6EF8DD74734B40
4913	Рыбное	1	12	703	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
24682	Пощупово	1	12	703	39.701143000000002	39.737839000000001	54.827589000000003	54.813567999999997	0103000020E61000000100000005000000E068C70DBFD943403B8908FF22684B40E068C70DBFD94340C2C3B46FEE694B404F5B238271DE4340C2C3B46FEE694B404F5B238271DE43403B8908FF22684B40E068C70DBFD943403B8908FF22684B40
60422	Поселок завода Ветзоотехника	1	12	703	38.832993000000002	39.884929	54.991790000000002	54.454773000000003	0103000020E610000001000000050000000266BE839F6A43404A0D6D00363A4B400266BE839F6A4340FB3F87F9F27E4B4018247D5A45F14340FB3F87F9F27E4B4018247D5A45F143404A0D6D00363A4B400266BE839F6A43404A0D6D00363A4B40
24586	Пионерский	1	12	703	39.100690999999998	39.118648	54.587812999999997	54.579709999999999	0103000020E6100000010000000500000032005471E38C43400395F1EF334A4B4032005471E38C4340F294D5743D4B4B402FDE8FDB2F8F4340F294D5743D4B4B402FDE8FDB2F8F43400395F1EF334A4B4032005471E38C43400395F1EF334A4B40
24950	Перекаль	1	12	703	39.591709999999999	39.612200999999999	54.730198000000001	54.714838	0103000020E61000000100000005000000AB5B3D27BDCB434012F8C3CF7F5B4B40AB5B3D27BDCB434064CDC820775D4B400CCA349A5CCE434064CDC820775D4B400CCA349A5CCE434012F8C3CF7F5B4B40AB5B3D27BDCB434012F8C3CF7F5B4B40
24524	Пальные	1	12	703	39.261687000000002	39.295454999999997	54.620553000000001	54.606203999999998	0103000020E61000000100000005000000E964A9F57EA14340295AB917984D4B40E964A9F57EA14340A437DC476E4F4B4047382D78D1A54340A437DC476E4F4B4047382D78D1A54340295AB917984D4B40E964A9F57EA14340295AB917984D4B40
23651	Ногино	1	12	703	39.379815000000001	39.399659	54.691037999999999	54.682836000000002	0103000020E61000000100000005000000DFC325C79DB043400744882B67574B40DFC325C79DB043408925E5EE73584B40AA46AF0628B343408925E5EE73584B40AA46AF0628B343400744882B67574B40DFC325C79DB043400744882B67574B40
24472	Новоселки	1	12	703	39.733221999999998	39.785342	54.855241999999997	54.828600000000002	0103000020E61000000100000005000000965AEF37DADD434099BB96900F6A4B40965AEF37DADD43403315E291786D4B406E162F1686E443403315E291786D4B406E162F1686E4434099BB96900F6A4B40965AEF37DADD434099BB96900F6A4B40
23786	Новое Батурино	1	12	703	39.448231	39.458804000000001	54.780994999999997	54.770665999999999	0103000020E61000000100000005000000D50627A25FB94340CF11F92EA5624B40D50627A25FB9434075ABE7A4F7634B4012A3E716BABA434075ABE7A4F7634B4012A3E716BABA4340CF11F92EA5624B40D50627A25FB94340CF11F92EA5624B40
24385	Марково	1	12	703	39.604807000000001	39.630868	54.784925000000001	54.771101999999999	0103000020E6100000010000000500000029B2D6506ACD4340AAF06778B3624B4029B2D6506ACD43400A68226C78644B40E50B5A48C0D043400A68226C78644B40E50B5A48C0D04340AAF06778B3624B4029B2D6506ACD4340AAF06778B3624B40
23733	Мантурово	1	12	703	39.434783000000003	39.447423000000001	54.687358000000003	54.676251000000001	0103000020E61000000100000005000000ABED26F8A6B7434093718C648F564B40ABED26F8A6B743406E52D158FB574B40363D282845B943406E52D158FB574B40363D282845B9434093718C648F564B40ABED26F8A6B7434093718C648F564B40
24151	Летово	1	12	703	39.514131999999996	39.532474999999998	54.805359000000003	54.791688999999998	0103000020E61000000100000005000000DDE9CE13CFC143402DCDAD1056654B40DDE9CE13CFC143400745F30016674B4003780B2428C443400745F30016674B4003780B2428C443402DCDAD1056654B40DDE9CE13CFC143402DCDAD1056654B40
24370	Кузьминское	1	12	703	39.640309000000002	39.666494999999998	54.872253000000001	54.861502000000002	0103000020E61000000100000005000000D02A33A5F5D1434024B891B2456E4B40D02A33A5F5D14340406B7EFCA56F4B4048F949B54FD54340406B7EFCA56F4B4048F949B54FD5434024B891B2456E4B40D02A33A5F5D1434024B891B2456E4B40
24671	Костино	1	12	703	39.658121999999999	39.681775000000002	54.812581999999999	54.800553999999998	0103000020E61000000100000005000000996379573DD443404B57B08D78664B40996379573DD44340BDA8DDAF02684B407E1D386744D74340BDA8DDAF02684B407E1D386744D743404B57B08D78664B40996379573DD443404B57B08D78664B40
24292	Константиново	1	12	703	39.582377000000001	39.648564	54.866757	54.857574	0103000020E61000000100000005000000A7785C548BCA434030F31DFCC46D4B40A7785C548BCA43401F4AB4E4F16E4B4075AE282504D343401F4AB4E4F16E4B4075AE282504D3434030F31DFCC46D4B40A7785C548BCA434030F31DFCC46D4B40
24251	Комсомольский	1	12	703	39.024945000000002	39.040368999999998	54.533628999999998	54.526240999999999	0103000020E610000001000000050000007099D365318343403C6876DD5B434B407099D365318343403D997FF44D444B40D862B7CF2A8543403D997FF44D444B40D862B7CF2A8543403C6876DD5B434B407099D365318343403C6876DD5B434B40
24117	Истобники	1	12	703	39.491314000000003	39.511850000000003	54.766002	54.758636000000003	0103000020E6100000010000000500000092088D60E3BE4340BDC804FC1A614B4092088D60E3BE4340D655815A0C624B40933A014D84C14340D655815A0C624B40933A014D84C14340BDC804FC1A614B4092088D60E3BE4340BDC804FC1A614B40
24211	Житово	1	12	703	39.341538	39.379384000000002	54.727848000000002	54.714162000000002	0103000020E61000000100000005000000AE2B6684B7AB4340E20511A9695B4B40AE2B6684B7AB4340C13A8E1F2A5D4B401650A8A78FB04340C13A8E1F2A5D4B401650A8A78FB04340E20511A9695B4B40AE2B6684B7AB4340E20511A9695B4B40
24891	Глебово-Городище	1	12	703	39.232159000000003	39.253827000000001	54.639012999999998	54.634875000000001	0103000020E610000001000000050000006D3CD862B79D43402506819543514B406D3CD862B79D4340035C902DCB514B40C0EB33677DA04340035C902DCB514B40C0EB33677DA043402506819543514B406D3CD862B79D43402506819543514B40
23840	Высокое	1	12	703	39.395086999999997	39.430337000000002	54.766199	54.744596000000001	0103000020E610000001000000050000009109F83592B24340C05DF6EB4E5F4B409109F83592B243402C9D0FCF12624B401FA1664815B743402C9D0FCF12624B401FA1664815B74340C05DF6EB4E5F4B409109F83592B24340C05DF6EB4E5F4B40
23921	Вакино	1	12	703	39.467742999999999	39.497332999999998	54.878827000000001	54.865347	0103000020E610000001000000050000006AF7AB00DFBB43408A58C4B0C36E4B406AF7AB00DFBB4340C0EB33677D704B405C1C959BA8BF4340C0EB33677D704B405C1C959BA8BF43408A58C4B0C36E4B406AF7AB00DFBB43408A58C4B0C36E4B40
4905	Большое Жоково	1	12	703	38.948749999999997	38.960715	54.576442999999998	54.565995000000001	0103000020E610000001000000050000003D0AD7A3707943408A592F8672484B403D0AD7A3707943400A815CE2C8494B4069E388B5F87A43400A815CE2C8494B4069E388B5F87A43408A592F8672484B403D0AD7A3707943408A592F8672484B40
23658	Баграмово	1	12	703	39.441780999999999	39.456989999999998	54.729157999999998	54.719279	0103000020E61000000100000005000000417FA1478CB843408CD99255115C4B40417FA1478CB84340F2CEA10C555D4B40AD4CF8A57EBA4340F2CEA10C555D4B40AD4CF8A57EBA43408CD99255115C4B40417FA1478CB843408CD99255115C4B40
23571	Алешня	1	12	703	39.329051999999997	39.37518	54.661479	54.645619000000003	0103000020E6100000010000000500000079573D601EAA43408F56B5A4A3524B4079573D601EAA4340D2FE0758AB544B40800EF3E505B04340D2FE0758AB544B40800EF3E505B043408F56B5A4A3524B4079573D601EAA43408F56B5A4A3524B40
54622	Глебково	1	12	7324	38.832993000000002	39.884929	54.991790000000002	54.454773000000003	0103000020E610000001000000050000000266BE839F6A43404A0D6D00363A4B400266BE839F6A4340FB3F87F9F27E4B4018247D5A45F14340FB3F87F9F27E4B4018247D5A45F143404A0D6D00363A4B400266BE839F6A43404A0D6D00363A4B40
6498	Унгор	1	12	507	41.088788000000001	41.122053000000001	54.044266	54.023240000000001	0103000020E610000001000000050000007D23BA675D8B4440C2FA3F87F9024B407D23BA675D8B444091291F82AA054B4079B0C56E9F8F444091291F82AA054B4079B0C56E9F8F4440C2FA3F87F9024B407D23BA675D8B4440C2FA3F87F9024B40
22657	Строевское	1	12	507	41.192373000000003	41.228791000000001	54.197293999999999	54.176968000000002	0103000020E6100000010000000500000014D1AFAD9F98444022382EE3A6164B4014D1AFAD9F98444038D906EE40194B40404F0306499D444038D906EE40194B40404F0306499D444022382EE3A6164B4014D1AFAD9F98444022382EE3A6164B40
23359	Романовы Дарки	1	12	507	41.275440000000003	41.305003999999997	54.080840000000002	54.047623000000002	0103000020E610000001000000050000005001309E41A34440CAC4AD8218064B405001309E41A34440B51A12F7580A4B401893FE5E0AA74440B51A12F7580A4B401893FE5E0AA74440CAC4AD8218064B405001309E41A34440CAC4AD8218064B40
23178	Путятино	1	12	507	41.094096999999998	41.135007000000002	54.173479	54.134630000000001	0103000020E610000001000000050000006BD3D85E0B8C4440BE874B8E3B114B406BD3D85E0B8C44407AC5538F34164B4094DDCCE8479144407AC5538F34164B4094DDCCE847914440BE874B8E3B114B406BD3D85E0B8C4440BE874B8E3B114B40
23090	Поляки	1	12	507	40.841931000000002	40.863912999999997	54.217714999999998	54.185761999999997	0103000020E610000001000000050000008A3E1F65C46B4440766B990CC7174B408A3E1F65C46B4440A06CCA15DE1B4B406CCB80B3946E4440A06CCA15DE1B4B406CCB80B3946E4440766B990CC7174B408A3E1F65C46B4440766B990CC7174B40
23094	Песочня	1	12	507	40.796683000000002	40.856340000000003	54.121006999999999	54.097639000000001	0103000020E61000000100000005000000BC2363B5F965444036E84B6F7F0C4B40BC2363B5F965444025CB49287D0F4B40DA20938C9C6D444025CB49287D0F4B40DA20938C9C6D444036E84B6F7F0C4B40BC2363B5F965444036E84B6F7F0C4B40
22382	Отрада	1	12	507	40.924000999999997	40.95158	54.134476999999997	54.119888000000003	0103000020E61000000100000005000000533C2EAA4576444068976F7D580F4B40533C2EAA457644403788D68A36114B408BC3995FCD7944403788D68A36114B408BC3995FCD79444068976F7D580F4B40533C2EAA4576444068976F7D580F4B40
54675	Новая Деревня	1	12	507	41.427883999999999	41.451016000000003	54.088735999999997	54.076523999999999	0103000020E61000000100000005000000A73D25E7C4B64440F7ADD689CB094B40A73D25E7C4B644402AFD84B35B0B4B4083FC6CE4BAB944402AFD84B35B0B4B4083FC6CE4BAB94440F7ADD689CB094B40A73D25E7C4B64440F7ADD689CB094B40
22819	Макеево	1	12	507	41.205722000000002	41.225943000000001	54.128810999999999	54.103689000000003	0103000020E61000000100000005000000AB083719559A44403CFA5FAE450D4B40AB083719559A4440BA2EFCE07C104B404CE141B3EB9C4440BA2EFCE07C104B404CE141B3EB9C44403CFA5FAE450D4B40AB083719559A44403CFA5FAE450D4B40
22898	Летники	1	12	507	40.882517	40.911254	54.177363	54.159548000000001	0103000020E61000000100000005000000FF942A51F67044403412A1116C144B40FF942A51F67044409E42AED4B3164B40B22C98F8A37444409E42AED4B3164B40B22C98F8A37444403412A1116C144B40FF942A51F67044403412A1116C144B40
23275	Караулово	1	12	507	41.377336	41.393883000000002	54.093541000000002	54.075045000000003	0103000020E610000001000000050000003ECDC98B4CB044403A5D16139B094B403ECDC98B4CB04440E6EAC726F90B4B40A6B915C26AB24440E6EAC726F90B4B40A6B915C26AB244403A5D16139B094B403ECDC98B4CB044403A5D16139B094B40
3203	Карабухино	1	12	507	41.245193999999998	41.273283999999997	54.126589000000003	54.104539000000003	0103000020E6100000010000000500000074965984629F44400A14B188610D4B4074965984629F444045847F1134104B40914259F8FAA2444045847F1134104B40914259F8FAA244400A14B188610D4B4074965984629F44400A14B188610D4B40
22745	Екатериновка	1	12	507	41.034970000000001	41.058002999999999	54.223927000000003	54.201628999999997	0103000020E61000000100000005000000AA2B9FE5798444406C76A4FACE194B40AA2B9FE57984444080D8D2A3A91C4B40F2086EA46C87444080D8D2A3A91C4B40F2086EA46C8744406C76A4FACE194B40AA2B9FE5798444406C76A4FACE194B40
23228	Глебово	1	12	507	41.157643999999998	41.183165000000002	54.150115	54.118822000000002	0103000020E610000001000000050000008F34B8AD2D944440CD052E8F350F4B408F34B8AD2D944440CCD1E3F736134B40CC6262F371974440CCD1E3F736134B40CC6262F371974440CD052E8F350F4B408F34B8AD2D944440CD052E8F350F4B40
3086	Воршево	1	12	507	41.114148	41.143180999999998	54.221668999999999	54.192737999999999	0103000020E61000000100000005000000B073D3669C8E4440255987A3AB184B40B073D3669C8E4440BDC458A65F1C4B404C3448C153924440BDC458A65F1C4B404C3448C153924440255987A3AB184B40B073D3669C8E4440255987A3AB184B40
22476	Большая Екатериновка	1	12	507	41.398240000000001	41.411983999999997	54.041110000000003	54.029243000000001	0103000020E61000000100000005000000C2FA3F87F9B244408751103CBE034B40C2FA3F87F9B24440F0C4AC1743054B40D53C47E4BBB44440F0C4AC1743054B40D53C47E4BBB444408751103CBE034B40C2FA3F87F9B244408751103CBE034B40
22375	Береговое	1	12	507	40.930056	40.940072000000001	54.182074	54.169848000000002	0103000020E610000001000000050000006BB933130C77444040A54A94BD154B406BB933130C774440D8B969334E174B4052F17F4754784440D8B969334E174B4052F17F475478444040A54A94BD154B406BB933130C77444040A54A94BD154B40
20966	Тырново	1	12	415	39.563907	39.603558999999997	54.296954999999997	54.275295999999997	0103000020E61000000100000005000000247EC51A2EC843401C5C3AE63C234B40247EC51A2EC843401CB1169F02264B406D1ADB6B41CD43401CB1169F02264B406D1ADB6B41CD43401C5C3AE63C234B40247EC51A2EC843401C5C3AE63C234B40
2223	Совхоз Орловский	1	12	415	39.497287999999998	39.511651999999998	54.089818000000001	54.080115999999997	0103000020E61000000100000005000000BC581822A7BF434073F1B73D410A4B40BC581822A7BF4340CB4BFE277F0B4B406C770FD07DC14340CB4BFE277F0B4B406C770FD07DC1434073F1B73D410A4B40BC581822A7BF434073F1B73D410A4B40
2499	Совхоз .Погореловский	1	12	415	39.700190999999997	39.726771999999997	54.087822000000003	54.077216	0103000020E610000001000000050000000DFAD2DB9FD943402D5DC136E2094B400DFAD2DB9FD9434046EF54C03D0B4B4002D369DD06DD434046EF54C03D0B4B4002D369DD06DD43402D5DC136E2094B400DFAD2DB9FD943402D5DC136E2094B40
2460	Синь	1	12	415	39.478988999999999	39.513142999999999	53.995488000000002	53.984158999999998	0103000020E610000001000000050000006612F5824FBD434033880FECF8FD4A406612F5824FBD4340BDC799266CFF4A40EE9579ABAEC14340BDC799266CFF4A40EE9579ABAEC1434033880FECF8FD4A406612F5824FBD434033880FECF8FD4A40
2335	Семенск	1	12	415	39.398473000000003	39.440254000000003	54.012528000000003	53.996001	0103000020E6100000010000000500000065ABCB2901B3434043E4F4F57CFF4A4065ABCB2901B3434064247B849A014B4073F7393E5AB8434064247B849A014B4073F7393E5AB8434043E4F4F57CFF4A4065ABCB2901B3434043E4F4F57CFF4A40
2627	Пронск	1	12	415	39.561490999999997	39.641961999999999	54.132719999999999	54.080613	0103000020E61000000100000005000000C9FFE4EFDEC74340F450DB86510A4B40C9FFE4EFDEC7434037C30DF8FC104B402BA391CF2BD2434037C30DF8FC104B402BA391CF2BD24340F450DB86510A4B40C9FFE4EFDEC74340F450DB86510A4B40
2270	Октябрьское	1	12	415	39.398608000000003	39.454214	54.079292000000002	54.056745999999997	0103000020E6100000010000000500000045F6419605B34340E316F37343074B4045F6419605B34340CF6A813D260A4B4053B131AF23BA4340CF6A813D260A4B4053B131AF23BA4340E316F37343074B4045F6419605B34340E316F37343074B40
2792	Новомичуринск	1	12	415	39.730849999999997	39.757063000000002	54.051307000000001	54.026144000000002	0103000020E610000001000000050000000B24287E8CDD43404A7EC4AF58034B400B24287E8CDD434027874F3A91064B407E01BD70E7E0434027874F3A91064B407E01BD70E7E043404A7EC4AF58034B400B24287E8CDD43404A7EC4AF58034B40
21435	Мамоново	1	12	415	39.554304000000002	39.582368000000002	53.999775	53.983068000000003	0103000020E610000001000000050000006005F86EF3C6434040DF162CD5FD4A406005F86EF3C64340E02D90A0F8FF4A40541EDD088BCA4340E02D90A0F8FF4A40541EDD088BCA434040DF162CD5FD4A406005F86EF3C6434040DF162CD5FD4A40
19209	Малинищи	1	12	415	39.588045000000001	39.620348	54.367021000000001	54.356057	0103000020E61000000100000005000000C5C9FD0E45CB434085419946932D4B40C5C9FD0E45CB4340FDF84B8BFA2E4B40CB11329067CF4340FDF84B8BFA2E4B40CB11329067CF434085419946932D4B40C5C9FD0E45CB434085419946932D4B40
2570	Маклаково	1	12	415	39.742294999999999	39.791674999999998	54.022689999999997	54.003436999999998	0103000020E61000000100000005000000FE7DC68503DF4340554CA59F70004B40FE7DC68503DF43401EF98381E7024B40C8073D9B55E543401EF98381E7024B40C8073D9B55E54340554CA59F70004B40FE7DC68503DF4340554CA59F70004B40
21636	Кисьва	1	12	415	39.784300000000002	39.817573000000003	54.100791000000001	54.083137000000001	0103000020E610000001000000050000005C2041F163E44340350BB43BA40A4B405C2041F163E44340965D30B8E60C4B40DB8B683BA6E84340965D30B8E60C4B40DB8B683BA6E84340350BB43BA40A4B405C2041F163E44340350BB43BA40A4B40
21078	Елшино	1	12	415	39.591907999999997	39.609056000000002	54.178001000000002	54.165419999999997	0103000020E61000000100000005000000D11E2FA4C3CB43405A0D897B2C154B40D11E2FA4C3CB4340E1D39CBCC8164B405FB7088CF5CD4340E1D39CBCC8164B405FB7088CF5CD43405A0D897B2C154B40D11E2FA4C3CB43405A0D897B2C154B40
21718	Денисово	1	12	415	39.795717000000003	39.814061000000002	54.068582999999997	54.059953999999998	0103000020E6100000010000000500000085EFFD0DDAE54340D7A19A92AC074B4085EFFD0DDAE54340E107E753C7084B407BF99D2633E84340E107E753C7084B407BF99D2633E84340D7A19A92AC074B4085EFFD0DDAE54340D7A19A92AC074B40
20859	Гремяки	1	12	415	39.604869999999998	39.632565	54.340403000000002	54.323886000000002	0103000020E610000001000000050000006F2A52616CCD4340EED0B01875294B406F2A52616CCD4340EB3A5453922B4B4010CCD1E3F7D04340EB3A5453922B4B4010CCD1E3F7D04340EED0B01875294B406F2A52616CCD4340EED0B01875294B40
2396	Восточный	1	12	415	39.346021	39.363421000000002	53.999346000000003	53.990544	0103000020E61000000100000005000000575D876A4AAC4340E09F5225CAFE4A40575D876A4AAC4340B8B1D991EAFF4A40FED64E9484AE4340B8B1D991EAFF4A40FED64E9484AE4340E09F5225CAFE4A40575D876A4AAC4340E09F5225CAFE4A40
54655	Большое Село	1	12	415	39.726215000000003	39.766271000000003	54.149419000000002	54.137388000000001	0103000020E61000000100000005000000AD6EF59CF4DC4340726E13EE95114B40AD6EF59CF4DC434055336B2920134B40C66F0A2B15E2434055336B2920134B40C66F0A2B15E24340726E13EE95114B40AD6EF59CF4DC4340726E13EE95114B40
21165	Березово	1	12	415	39.434216999999997	39.462389000000002	54.169041	54.155208000000002	0103000020E61000000100000005000000012F336C94B74340EE0912DBDD134B40012F336C94B743407157AF22A3154B40DC8310902FBB43407157AF22A3154B40DC8310902FBB4340EE0912DBDD134B40012F336C94B74340EE0912DBDD134B40
21533	Береговая Погореловка	1	12	415	39.708481999999997	39.723770999999999	54.101593000000001	54.088535	0103000020E61000000100000005000000FFE6C589AFDA434093C6681D550B4B40FFE6C589AFDA43405340DAFF000D4B4088653387A4DC43405340DAFF000D4B4088653387A4DC434093C6681D550B4B40FFE6C589AFDA434093C6681D550B4B40
21019	Альютово	1	12	415	39.517499999999998	39.548133	54.192053000000001	54.179476000000001	0103000020E610000001000000050000000AD7A3703DC243405D35CF11F9164B400AD7A3703DC24340A20C553195184B40DF6DDE3829C64340A20C553195184B40DF6DDE3829C643405D35CF11F9164B400AD7A3703DC243405D35CF11F9164B40
20977	Абакумово	1	12	415	39.572450000000003	39.607745000000001	54.263897	54.248812000000001	0103000020E61000000100000005000000304CA60A46C943401A6D5512D91F4B40304CA60A46C943409A417C60C7214B405DA79196CACD43409A417C60C7214B405DA79196CACD43401A6D5512D91F4B40304CA60A46C943401A6D5512D91F4B40
20287	Юрьево	1	12	1568	41.954486000000003	41.970430999999998	54.556415000000001	54.535023000000002	0103000020E61000000100000005000000B43EE5982CFA4440CDCD37A27B444B40B43EE5982CFA44407E00529B38474B402503401537FC44407E00529B38474B402503401537FC4440CDCD37A27B444B40B43EE5982CFA4440CDCD37A27B444B40
19021	Темирево	1	12	1568	41.839942000000001	41.875138	54.629038999999999	54.611007000000001	0103000020E61000000100000005000000B7442E3883EB44404450357A354E4B40B7442E3883EB44404B74965984504B4051BEA08504F044404B74965984504B4051BEA08504F044404450357A354E4B40B7442E3883EB44404450357A354E4B40
19107	Потапьево	1	12	1568	41.737003999999999	41.765498000000001	54.613655999999999	54.595362000000002	0103000020E61000000100000005000000B682A62556DE4440FDA36FD2344C4B40B682A62556DE4440417FA1478C4E4B40A393A5D6FBE14440417FA1478C4E4B40A393A5D6FBE14440FDA36FD2344C4B40B682A62556DE4440FDA36FD2344C4B40
19102	Подболотье	1	12	1568	41.910162999999997	41.922443000000001	54.509898999999997	54.496786999999998	0103000020E61000000100000005000000BE839F3880F44440FA0967B7963F4B40BE839F3880F44440ADA1D45E44414B404AB6BA9C12F64440ADA1D45E44414B404AB6BA9C12F64440FA0967B7963F4B40BE839F3880F44440FA0967B7963F4B40
19205	Пителино	1	12	1568	41.784847999999997	41.838000999999998	54.593781	54.568871000000001	0103000020E610000001000000050000005E2A36E675E444404852D2C3D0484B405E2A36E675E444403BFE0B04014C4B40F581E49D43EB44403BFE0B04014C4B40F581E49D43EB44404852D2C3D0484B405E2A36E675E444404852D2C3D0484B40
20533	Пет	1	12	1568	41.654853000000003	41.697226000000001	54.631973000000002	54.620282000000003	0103000020E6100000010000000500000000581D39D2D3444014268C66654F4B4000581D39D2D344403E7AC37DE4504B40E0F599B33ED944403E7AC37DE4504B40E0F599B33ED9444014268C66654F4B4000581D39D2D3444014268C66654F4B40
20365	Пеньки	1	12	1568	41.837192999999999	41.872146000000001	54.606198999999997	54.590254999999999	0103000020E6100000010000000500000056B8E52329EB444076A6D0798D4B4B4056B8E52329EB444017EFC7ED974D4B402AABE97AA2EF444017EFC7ED974D4B402AABE97AA2EF444076A6D0798D4B4B4056B8E52329EB444076A6D0798D4B4B40
20065	Новый Ункор	1	12	1568	41.569360000000003	41.604556000000002	54.487113000000001	54.466104000000001	0103000020E6100000010000000500000046D3D9C9E0C844407444BE4BA93B4B4046D3D9C9E0C844406D3A02B8593E4B40E04C4C1762CD44406D3A02B8593E4B40E04C4C1762CD44407444BE4BA93B4B4046D3D9C9E0C844407444BE4BA93B4B40
18902	Нестерово	1	12	1568	41.800074000000002	41.823214999999998	54.528545000000001	54.501420000000003	0103000020E61000000100000005000000A13028D368E64440B9C7D2872E404B40A13028D368E644406FBBD05CA7434B40CF49EF1B5FE944406FBBD05CA7434B40CF49EF1B5FE94440B9C7D2872E404B40A13028D368E64440B9C7D2872E404B40
18891	Краснопартизанский	1	12	1568	41.745241	41.755752000000001	54.720453999999997	54.713012999999997	0103000020E61000000100000005000000B5519D0E64DF4440B94F8E02445B4B40B5519D0E64DF4440DD2230D6375C4B407CF1457BBCE04440DD2230D6375C4B407CF1457BBCE04440B94F8E02445B4B40B5519D0E64DF4440B94F8E02445B4B40
19938	Ермо-Николаевка	1	12	1568	41.742421	41.770142999999997	54.708565	54.692224000000003	0103000020E610000001000000050000008B6EBDA607DF4440CFC0C8CB9A584B408B6EBDA607DF44408D0B0742B25A4B40251FBB0B94E244408D0B0742B25A4B40251FBB0B94E24440CFC0C8CB9A584B408B6EBDA607DF4440CFC0C8CB9A584B40
18945	Гридино	1	12	1568	41.607278000000001	41.650495999999997	54.565389000000003	54.537886	0103000020E6100000010000000500000047CA1649BBCD4440F67CCD72D9444B4047CA1649BBCD44405342B0AA5E484B40E316F37343D344405342B0AA5E484B40E316F37343D34440F67CCD72D9444B4047CA1649BBCD4440F67CCD72D9444B40
19825	Высокие Поляны	1	12	1568	41.733832999999997	41.759273	54.746887999999998	54.728160000000003	0103000020E61000000100000005000000DFDC5F3DEEDD4440B020CD58345D4B40DFDC5F3DEEDD44402EE3A6069A5F4B402FDE8FDB2FE144402EE3A6069A5F4B402FDE8FDB2FE14440B020CD58345D4B40DFDC5F3DEEDD4440B020CD58345D4B40
20539	Веряево	1	12	1568	41.585700000000003	41.611958000000001	54.596671000000001	54.572775	0103000020E6100000010000000500000034A2B437F8CA4440B37BF2B050494B4034A2B437F8CA44405EBC1FB75F4C4B404643C6A354CE44405EBC1FB75F4C4B404643C6A354CE4440B37BF2B050494B4034A2B437F8CA4440B37BF2B050494B40
18888	Чернышевка	1	12	1538	40.122425999999997	40.145547999999998	53.410792000000001	53.396946999999997	0103000020E610000001000000050000000D17B9A7AB0F4440669FC728CFB24A400D17B9A7AB0F4440AEBA0ED594B44A40C5FF1D51A1124440AEBA0ED594B44A40C5FF1D51A1124440669FC728CFB24A400D17B9A7AB0F4440669FC728CFB24A40
18697	Студенки	1	12	1538	40.359499999999997	40.392944	53.451709000000001	53.429622000000002	0103000020E61000000100000005000000BC749318042E444031D28BDAFDB64A40BC749318042E44408927BB99D1B94A4068942EFD4B3244408927BB99D1B94A4068942EFD4B32444031D28BDAFDB64A40BC749318042E444031D28BDAFDB64A40
18788	Спешнево	1	12	1538	40.473838000000001	40.518430000000002	53.498832999999998	53.477628000000003	0103000020E6100000010000000500000010CD3CB9A63C4440B3D30FEA22BD4A4010CD3CB9A63C444031957EC2D9BF4A40F5A10BEA5B42444031957EC2D9BF4A40F5A10BEA5B424440B3D30FEA22BD4A4010CD3CB9A63C4440B3D30FEA22BD4A40
18587	Сергиевский-Боровок	1	12	1538	40.220396000000001	40.272497999999999	53.511375999999998	53.494579999999999	0103000020E61000000100000005000000A915A6EF351C4440BAA0BE654EBF4A40A915A6EF351C4440CAFACDC474C14A40DA1CE736E1224440CAFACDC474C14A40DA1CE736E1224440BAA0BE654EBF4A40A915A6EF351C4440BAA0BE654EBF4A40
18784	Просечье	1	12	1538	40.353346999999999	40.400948	53.505073000000003	53.479031999999997	0103000020E61000000100000005000000E29178793A2D444065DEAAEB50BD4A40E29178793A2D4440DB8B683BA6C04A40C4B2994352334440DB8B683BA6C04A40C4B299435233444065DEAAEB50BD4A40E29178793A2D444065DEAAEB50BD4A40
18785	Павловка	1	12	1538	40.331257000000001	40.361134999999997	53.369231999999997	53.354475999999998	0103000020E6100000010000000500000019C91EA1662A4440C39B35785FAD4A4019C91EA1662A44407E5182FE42AF4A407138F3AB392E44407E5182FE42AF4A407138F3AB392E4440C39B35785FAD4A4019C91EA1662A4440C39B35785FAD4A40
18470	Ольховка	1	12	1538	40.222012999999997	40.244551999999999	53.453623	53.438023000000001	0103000020E61000000100000005000000B72407EC6A1C4440AAF23D2311B84A40B72407EC6A1C444051DB865110BA4A40F015DD7A4D1F444051DB865110BA4A40F015DD7A4D1F4440AAF23D2311B84A40B72407EC6A1C4440AAF23D2311B84A40
54688	Новотишевое	1	12	1538	40.103273999999999	40.133088999999998	53.498421	53.476331000000002	0103000020E6100000010000000500000078431A15380D44401689096AF8BC4A4078431A15380D4440DF516342CCBF4A408A3A730F09114440DF516342CCBF4A408A3A730F091144401689096AF8BC4A4078431A15380D44401689096AF8BC4A40
19204	Новосергиевка	1	12	1538	40.166325999999998	40.179369999999999	53.549810000000001	53.530037999999998	0103000020E61000000100000005000000BC3C9D2B4A15444091D10149D8C34A40BC3C9D2B4A154440C381902C60C64A4017F19D98F5164440C381902C60C64A4017F19D98F516444091D10149D8C34A40BC3C9D2B4A15444091D10149D8C34A40
18636	Нижний Якимец	1	12	1538	40.164745000000003	40.175615000000001	53.490343000000003	53.481153999999997	0103000020E61000000100000005000000FB96395D16154440772B4B7496BD4A40FB96395D161544404969368FC3BE4A40F1D7648D7A1644404969368FC3BE4A40F1D7648D7A164440772B4B7496BD4A40FB96395D16154440772B4B7496BD4A40
19822	Михалково	1	12	1538	40.488283000000003	40.508800000000001	53.568359000000001	53.548954000000002	0103000020E61000000100000005000000AD18AE0E803E44401381EA1F44C64A40AD18AE0E803E444092B1DAFCBFC84A40371AC05B2041444092B1DAFCBFC84A40371AC05B204144401381EA1F44C64A40AD18AE0E803E44401381EA1F44C64A40
45853	Луговой	1	12	1538	40.276020000000003	40.283529999999999	53.469909999999999	53.463794	0103000020E610000001000000050000005E85949F542344405F0A0F9A5DBB4A405E85949F542344401C08C90226BC4A40AAB706B64A2444401C08C90226BC4A40AAB706B64A2444405F0A0F9A5DBB4A405E85949F542344405F0A0F9A5DBB4A40
19307	Ленино	1	12	1538	40.009228999999998	40.056660000000001	53.437635999999998	53.414135000000002	0103000020E610000001000000050000005F96766A2E01444082902C6002B54A405F96766A2E014440B0C6D97404B84A40E57E87A240074440B0C6D97404B84A40E57E87A24007444082902C6002B54A405F96766A2E01444082902C6002B54A40
19510	Красное Знамя	1	12	1538	40.021931000000002	40.059939	53.484459999999999	53.477837000000001	0103000020E6100000010000000500000061E28FA2CE024440CDE847C329BD4A4061E28FA2CE0244402E1C08C902BE4A40A260C614AC0744402E1C08C902BE4A40A260C614AC074440CDE847C329BD4A4061E28FA2CE024440CDE847C329BD4A40
18575	Каширин	1	12	1538	40.206812999999997	40.220413999999998	53.499952999999998	53.485729999999997	0103000020E610000001000000050000009EB12FD9781A4440D15790662CBE4A409EB12FD9781A4440BF44BC75FEBF4A404FCAA486361C4440BF44BC75FEBF4A404FCAA486361C4440D15790662CBE4A409EB12FD9781A4440D15790662CBE4A40
19618	Калинино	1	12	1538	40.102015999999999	40.131822	53.541168999999996	53.508296999999999	0103000020E6100000010000000500000099D53BDC0E0D4440D4D347E00FC14A4099D53BDC0E0D4440F44D9A0645C54A405872158BDF104440F44D9A0645C54A405872158BDF104440D4D347E00FC14A4099D53BDC0E0D4440D4D347E00FC14A40
18467	Зимарово	1	12	1538	40.183385000000001	40.222425999999999	53.376002	53.357093999999996	0103000020E61000000100000005000000DAC9E0287917444085CC9541B5AD4A40DAC9E02879174440849D62D520B04A40DAE38574781C4440849D62D520B04A40DAE38574781C444085CC9541B5AD4A40DAC9E0287917444085CC9541B5AD4A40
18469	Бурминка	1	12	1538	40.219884	40.270404999999997	53.586488000000003	53.570813999999999	0103000020E61000000100000005000000F374AE28251C4440AA0CE36E10C94A40F374AE28251C44408CBFED0912CB4A4062D68BA19C2244408CBFED0912CB4A4062D68BA19C224440AA0CE36E10C94A40F374AE28251C4440AA0CE36E10C94A40
18789	Борисовка	1	12	1538	40.163972999999999	40.182011000000003	53.449001000000003	53.424019999999999	0103000020E61000000100000005000000A8363811FD144440CA6C904946B64A40A8363811FD144440876F61DD78B94A409241EE224C174440876F61DD78B94A409241EE224C174440CA6C904946B64A40A8363811FD144440CA6C904946B64A40
18465	Благие	1	12	1538	40.263291000000002	40.289521000000001	53.426761999999997	53.401446	0103000020E61000000100000005000000632AFD84B3214440158E209562B34A40632AFD84B321444078962023A0B64A40AB402D060F25444078962023A0B64A40AB402D060F254440158E209562B34A40632AFD84B3214440158E209562B34A40
18582	Бахметьево	1	12	1538	40.244534000000002	40.267341999999999	53.405177000000002	53.392038999999997	0103000020E610000001000000050000004A61DEE34C1F4440D6E07D552EB24A404A61DEE34C1F4440B30B06D7DCB34A40726C3D4338224440B30B06D7DCB34A40726C3D4338224440D6E07D552EB24A404A61DEE34C1F4440D6E07D552EB24A40
18263	Александро-Невский	1	12	1538	40.18891	40.222695999999999	53.490085999999998	53.46255	0103000020E6100000010000000500000095F1EF332E184440E561A1D634BB4A4095F1EF332E1844401D1D5723BBBE4A409A79724D811C44401D1D5723BBBE4A409A79724D811C4440E561A1D634BB4A4095F1EF332E184440E561A1D634BB4A40
18019	Щетиновка	1	12	1071	38.996468	39.023319000000001	54.229137999999999	54.214646000000002	0103000020E6100000010000000500000059C16F438C7F4340CE1B2785791B4B4059C16F438C7F4340AB22DC64541D4B400E30F31DFC824340AB22DC64541D4B400E30F31DFC824340CE1B2785791B4B4059C16F438C7F4340CE1B2785791B4B40
16888	Щеголево	1	12	1071	39.019267999999997	39.041545999999997	54.012341999999997	54.001033999999997	0103000020E61000000100000005000000FEEDB25F778243408F17D2E121004B40FEEDB25F77824340012F336C94014B40CAA31B6151854340012F336C94014B40CAA31B61518543408F17D2E121004B40FEEDB25F778243408F17D2E121004B40
15491	Чурики	1	12	1071	39.223005999999998	39.256782000000001	53.986192000000003	53.949401999999999	0103000020E61000000100000005000000E867EA758B9C4340E560360186F94A40E867EA758B9C4340D6C9198A3BFE4A40CA198A3BDEA04340D6C9198A3BFE4A40CA198A3BDEA04340E560360186F94A40E867EA758B9C4340E560360186F94A40
9480	Фирюлевка	1	12	1071	39.293173000000003	39.318900999999997	54.145558000000001	54.132598999999999	0103000020E61000000100000005000000FD885FB186A54340BC3D0801F9104B40FD885FB186A54340E9D500A5A1124B40B2D47ABFD1A84340E9D500A5A1124B40B2D47ABFD1A84340BC3D0801F9104B40FD885FB186A54340BC3D0801F9104B40
17970	Трепольский	1	12	1071	38.819671	38.844141	54.351118999999997	54.334361000000001	0103000020E61000000100000005000000643DB5FAEA68434068075C57CC2A4B40643DB5FAEA6843408A00A777F12C4B403B1BF2CF0C6C43408A00A777F12C4B403B1BF2CF0C6C434068075C57CC2A4B40643DB5FAEA68434068075C57CC2A4B40
17364	Стубле	1	12	1071	39.031404000000002	39.049604000000002	54.326312000000001	54.305131000000003	0103000020E61000000100000005000000577BD80B0584434076FF58880E274B40577BD80B058443406C257497C4294B401AE0826C598643406C257497C4294B401AE0826C5986434076FF58880E274B40577BD80B0584434076FF58880E274B40
17856	Стрелецкие Выселки	1	12	1071	38.933163999999998	38.97728	54.214261999999998	54.190699000000002	0103000020E61000000100000005000000FBE6FEEA71774340A13028D368184B40FBE6FEEA717743404563EDEF6C1B4B407784D382177D43404563EDEF6C1B4B407784D382177D4340A13028D368184B40FBE6FEEA71774340A13028D368184B40
54684	Совхоз им. Ильича	1	12	1071	39.149371000000002	39.160679999999999	54.066136999999998	54.059690000000003	0103000020E6100000010000000500000044FCC3961E934340FAF202ECA3074B4044FCC3961E9343401C075E2D77084B40868F8829919443401C075E2D77084B40868F882991944340FAF202ECA3074B4044FCC3961E934340FAF202ECA3074B40
54672	Совхоз Фрунзенский	1	12	1071	38.809950999999998	38.820110999999997	54.343094999999998	54.337888	0103000020E61000000100000005000000662E7079AC674340FDDAFAE93F2B4B40662E7079AC674340E7357689EA2B4B40800BB265F9684340E7357689EA2B4B40800BB265F9684340FDDAFAE93F2B4B40662E7079AC674340FDDAFAE93F2B4B40
54677	Слободка	1	12	1071	39.251922	39.291708999999997	54.189540000000001	54.173152999999999	0103000020E610000001000000050000004B92E7FA3EA04340261AA4E029164B404B92E7FA3EA0434055A4C2D842184B40747973B856A5434055A4C2D842184B40747973B856A54340261AA4E029164B404B92E7FA3EA04340261AA4E029164B40
16668	Садовый Поселок	1	12	1071	38.807166000000002	38.820030000000003	54.135947999999999	54.128583999999996	0103000020E61000000100000005000000B9382A3751674340F964C57075104B40B9382A375167434072FA7ABE66114B4094DE37BEF668434072FA7ABE66114B4094DE37BEF6684340F964C57075104B40B9382A3751674340F964C57075104B40
17568	Рачатники	1	12	1071	39.107087	39.154283999999997	54.210965000000002	54.205621000000001	0103000020E61000000100000005000000D369DD06B58D4340772FF7C9511A4B40D369DD06B58D4340E2CCAFE6001B4B40E525FF93BF934340E2CCAFE6001B4B40E525FF93BF934340772FF7C9511A4B40D369DD06B58D4340772FF7C9511A4B40
18254	Пушкари	1	12	1071	39.074827999999997	39.100304999999999	54.279969999999999	54.270217000000002	0103000020E610000001000000050000009C69C2F69389434060E97C7896224B409C69C2F69389434039EE940ED6234B40095053CBD68C434039EE940ED6234B40095053CBD68C434060E97C7896224B409C69C2F69389434060E97C7896224B40
18078	Прудские Выселки	1	12	1071	39.071306999999997	39.07985	54.205336000000003	54.198500000000003	0103000020E61000000100000005000000E97C789620894340C520B07268194B40E97C78962089434082583673481A4B40F54A5986388A434082583673481A4B40F54A5986388A4340C520B07268194B40E97C789620894340C520B07268194B40
17471	Поярково	1	12	1071	39.166024999999998	39.184629000000001	54.295132000000002	54.272646000000002	0103000020E61000000100000005000000C1A8A44E409543404FB16A10E6224B40C1A8A44E409543406500A8E2C6254B4054724EECA19743406500A8E2C6254B4054724EECA19743404FB16A10E6224B40C1A8A44E409543404FB16A10E6224B40
15487	Помозово	1	12	1071	38.969805999999998	38.994016000000002	54.153142000000003	54.143453999999998	0103000020E6100000010000000500000077BB5E9A227C43407D3D5FB35C124B4077BB5E9A227C434070D234289A134B40B2D991EA3B7F434070D234289A134B40B2D991EA3B7F43407D3D5FB35C124B4077BB5E9A227C43407D3D5FB35C124B40
17412	Печерники	1	12	1071	39.242409000000002	39.281925999999999	54.138966000000003	54.119033000000002	0103000020E61000000100000005000000C7A01342079F434088122D793C0F4B40C7A01342079F4340C3A04CA3C9114B4030F2B22616A44340C3A04CA3C9114B4030F2B22616A4434088122D793C0F4B40C7A01342079F434088122D793C0F4B40
15591	Первомайский	1	12	1071	38.958038000000002	38.978968999999999	54.224159	54.217747000000003	0103000020E61000000100000005000000A2293BFDA07A4340ACE63922DF1B4B40A2293BFDA07A4340520DFB3DB11C4B401F662FDB4E7D4340520DFB3DB11C4B401F662FDB4E7D4340ACE63922DF1B4B40A2293BFDA07A4340ACE63922DF1B4B40
16358	Павелково	1	12	1071	39.131439999999998	39.162944000000003	54.090747999999998	54.076714000000003	0103000020E6100000010000000500000070B1A206D39043409B92ACC3D1094B4070B1A206D3904340B51666A19D0B4B402B8A5759DB944340B51666A19D0B4B402B8A5759DB9443409B92ACC3D1094B4070B1A206D39043409B92ACC3D1094B40
54685	Отделение совхоза Возрождение	1	12	1071	39.104337999999998	39.110159000000003	53.980829	53.977767999999998	0103000020E6100000010000000500000072DD94F25A8D4340A489778027FD4A4072DD94F25A8D4340F4FBFECD8BFD4A40172EABB0198E4340F4FBFECD8BFD4A40172EABB0198E4340A489778027FD4A4072DD94F25A8D4340A489778027FD4A40
15769	Октябрьский	1	12	1071	38.875078999999999	38.910473000000003	54.249470000000002	54.218525999999997	0103000020E610000001000000050000004C35B39602704340B0A9F3A8F81B4B404C35B39602704340A4AA09A2EE1F4B400D7217618A744340A4AA09A2EE1F4B400D7217618A744340B0A9F3A8F81B4B404C35B39602704340B0A9F3A8F81B4B40
17266	Новопанское	1	12	1071	38.982221000000003	39.073399999999999	54.372382000000002	54.327083999999999	0103000020E61000000100000005000000E338F06AB97D4340BE8575E3DD294B40E338F06AB97D43403ECF9F36AA2F4B4061C3D32B658943403ECF9F36AA2F4B4061C3D32B65894340BE8575E3DD294B40E338F06AB97D4340BE8575E3DD294B40
17730	Некрасово	1	12	1071	38.897114999999999	38.923121000000002	54.196119000000003	54.187027	0103000020E6100000010000000500000022E010AAD4724340083C3080F0174B4022E010AAD4724340E78F696D1A194B401BA034D428764340E78F696D1A194B401BA034D428764340083C3080F0174B4022E010AAD4724340083C3080F0174B40
54662	Мишино	1	12	1071	39.295166999999999	39.307141999999999	54.172125000000001	54.162430999999998	0103000020E61000000100000005000000E1ED4108C8A54340A46DFC89CA144B40E1ED4108C8A5434079E9263108164B40309DD66D50A7434079E9263108164B40309DD66D50A74340A46DFC89CA144B40E1ED4108C8A54340A46DFC89CA144B40
15018	Михайлов	1	12	1071	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
16516	Малинки	1	12	1071	38.973084999999998	39.004652	54.091513999999997	54.067104	0103000020E61000000100000005000000349D9D0C8E7C434024B726DD96084B40349D9D0C8E7C4340259012BBB60B4B4035EECD6F98804340259012BBB60B4B4035EECD6F9880434024B726DD96084B40349D9D0C8E7C434024B726DD96084B40
17260	Красное	1	12	1071	38.813023000000001	39.206314999999996	54.181626000000001	53.939858000000001	0103000020E61000000100000005000000AAF23D2311684340267156444DF84A40AAF23D2311684340390D51853F174B404DD6A887689A4340390D51853F174B404DD6A887689A4340267156444DF84A40AAF23D2311684340267156444DF84A40
54689	Коровинский спирт. завод	1	12	1071	39.174883000000001	39.194125	54.089575000000004	54.080148000000001	0103000020E610000001000000050000002DD0EE90629643407F6B274A420A4B402DD0EE906296434005C58F31770B4B40022B8716D998434005C58F31770B4B40022B8716D99843407F6B274A420A4B402DD0EE90629643407F6B274A420A4B40
15640	Козловка	1	12	1071	39.000996000000001	39.024163000000001	54.258448000000001	54.235464	0103000020E61000000100000005000000A2B60DA32080434053B131AF231E4B40A2B60DA320804340BADBF5D214214B40FA62EFC517834340BADBF5D214214B40FA62EFC51783434053B131AF231E4B40A2B60DA32080434053B131AF231E4B40
17116	Каморино	1	12	1071	38.735228999999997	38.758513999999998	54.284331999999999	54.273014000000003	0103000020E610000001000000050000000F09DFFB1B5E4340D2AC6C1FF2224B400F09DFFB1B5E4340679AB0FD64244B4071C79BFC16614340679AB0FD64244B4071C79BFC16614340D2AC6C1FF2224B400F09DFFB1B5E4340D2AC6C1FF2224B40
17564	Ижеславль	1	12	1071	39.237513	39.308641999999999	54.249144000000001	54.230232999999998	0103000020E61000000100000005000000FBAF73D3669E4340E0BA6246781D4B40FBAF73D3669E434050FF59F3E31F4B400516C09481A7434050FF59F3E31F4B400516C09481A74340E0BA6246781D4B40FBAF73D3669E4340E0BA6246781D4B40
16778	Иваньково	1	12	1071	38.713751000000002	38.728169000000001	54.234789999999997	54.228143000000003	0103000020E61000000100000005000000603E59315C5B4340DAE731CA331D4B40603E59315C5B4340C3B645990D1E4B40037B4CA4345D4340C3B645990D1E4B40037B4CA4345D4340DAE731CA331D4B40603E59315C5B4340DAE731CA331D4B40
15972	Змеинка	1	12	1071	38.927244000000002	38.941357000000004	54.239393999999997	54.229695999999997	0103000020E61000000100000005000000C4B46FEEAF764340D102B4AD661D4B40C4B46FEEAF764340E76D6C76A41E4B402B6EDC627E784340E76D6C76A41E4B402B6EDC627E784340D102B4AD661D4B40C4B46FEEAF764340D102B4AD661D4B40
16579	Заря	1	12	1071	38.803277000000001	38.822231000000002	54.102786000000002	54.096414000000003	0103000020E610000001000000050000008350DEC7D16643403370404B570C4B408350DEC7D16643404B3E7617280D4B40F2608BDD3E6943404B3E7617280D4B40F2608BDD3E6943403370404B570C4B408350DEC7D16643403370404B570C4B40
17175	Завидовка	1	12	1071	38.805045999999997	38.825347999999998	54.273218999999997	54.256501999999998	0103000020E6100000010000000500000047E350BF0B674340E6ADBA0ED5204B4047E350BF0B674340AAD216D7F8224B40D5E8D500A5694340AAD216D7F8224B40D5E8D500A5694340E6ADBA0ED5204B4047E350BF0B674340E6ADBA0ED5204B40
16968	Жмурово	1	12	1071	38.895507000000002	38.912762999999998	53.977190999999998	53.959012999999999	0103000020E61000000100000005000000672B2FF99F7243402CB81FF0C0FA4A40672B2FF99F72434007793D9814FD4A40DAFF006BD574434007793D9814FD4A40DAFF006BD57443402CB81FF0C0FA4A40672B2FF99F7243402CB81FF0C0FA4A40
16832	Грязное	1	12	1071	39.094006999999998	39.132752000000004	54.049467999999997	54.032950999999997	0103000020E610000001000000050000002B4CDF6B088C43406CAF05BD37044B402B4CDF6B088C43406919A9F754064B40433D7D04FE9043406919A9F754064B40433D7D04FE9043406CAF05BD37044B402B4CDF6B088C43406CAF05BD37044B40
15858	Горенка	1	12	1071	38.852513000000002	38.86544	54.251925999999997	54.246865999999997	0103000020E610000001000000050000001A355F251F6D4340463F1A4E991F4B401A355F251F6D43408C81751C3F204B403B53E8BCC66E43408C81751C3F204B403B53E8BCC66E4340463F1A4E991F4B401A355F251F6D4340463F1A4E991F4B40
16269	Голдино	1	12	1071	39.073697000000003	39.104194	54.128456999999997	54.106023	0103000020E610000001000000050000001B683EE76E894340D9CF6229920D4B401B683EE76E8943409CF86A4771104B403F389F3A568D43409CF86A4771104B403F389F3A568D4340D9CF6229920D4B401B683EE76E894340D9CF6229920D4B40
16156	Виленка	1	12	1071	38.884619000000001	38.947456000000003	54.28049	54.253777999999997	0103000020E61000000100000005000000CA3505323B714340DE3829CC7B204B40CA3505323B714340726DA818E7234B401233FB3C46794340726DA818E7234B401233FB3C46794340DE3829CC7B204B40CA3505323B714340DE3829CC7B204B40
16674	Бычки	1	12	1071	38.766508999999999	38.785167000000001	54.185625000000002	54.175598000000001	0103000020E610000001000000050000007A8B87F71C6243401B9FC9FE79164B407A8B87F71C624340F6285C8FC2174B4000732D5A80644340F6285C8FC2174B4000732D5A806443401B9FC9FE79164B407A8B87F71C6243401B9FC9FE79164B40
14333	Южный	1	12	759	39.440308000000002	39.462622000000003	53.551617999999998	53.537964000000002	0103000020E61000000100000005000000661536035CB8434072361D01DCC44A40661536035CB8434045F12A6B9BC64A407F349C3237BB434045F12A6B9BC64A407F349C3237BB434072361D01DCC44A40661536035CB8434072361D01DCC44A40
14734	Чернава	1	12	759	39.115952999999998	39.168837000000003	53.628518	53.595061000000001	0103000020E61000000100000005000000C16F438CD78E4340021077F52ACC4A40C16F438CD78E434042791F4773D04A4069AD68739C95434042791F4773D04A4069AD68739C954340021077F52ACC4A40C16F438CD78E4340021077F52ACC4A40
15008	Центральный	1	12	759	39.619567000000004	39.636212999999998	53.682932000000001	53.670526000000002	0103000020E610000001000000050000002657B1F84DCF4340118FC4CBD3D54A402657B1F84DCF434029B2D6506AD74A402025766D6FD1434029B2D6506AD74A402025766D6FD14340118FC4CBD3D54A402657B1F84DCF4340118FC4CBD3D54A40
54683	Топилы	1	12	759	39.325727999999998	39.353019000000003	53.748289	53.734267000000003	0103000020E610000001000000050000001CB28174B1A943401AC40776FCDD4A401CB28174B1A94340707A17EFC7DF4A40EEEE01BA2FAD4340707A17EFC7DF4A40EEEE01BA2FAD43401AC40776FCDD4A401CB28174B1A943401AC40776FCDD4A40
13316	Спасское	1	12	759	39.356082000000001	39.387836999999998	53.654184000000001	53.636558999999998	0103000020E61000000100000005000000DE58501894AD4340BB7CEBC37AD14A40DE58501894AD434082C8224DBCD34A40E1968FA4A4B1434082C8224DBCD34A40E1968FA4A4B14340BB7CEBC37AD14A40DE58501894AD4340BB7CEBC37AD14A40
54652	Совхоз Большевик	1	12	759	39.234521999999998	39.256602000000001	53.695489000000002	53.686121	0103000020E61000000100000005000000A41820D1049E4340A60C1CD0D2D74A40A41820D1049E434027DD96C805D94A404A0B9755D8A0434027DD96C805D94A404A0B9755D8A04340A60C1CD0D2D74A40A41820D1049E4340A60C1CD0D2D74A40
13859	Роговое	1	12	759	39.552705000000003	39.573276999999997	53.684238999999998	53.673811999999998	0103000020E61000000100000005000000F8AA9509BFC6434080D3BB783FD64A40F8AA9509BFC64340E9D2BF2495D74A404546072461C94340E9D2BF2495D74A404546072461C9434080D3BB783FD64A40F8AA9509BFC6434080D3BB783FD64A40
14431	Пролетарский	1	12	759	39.312019999999997	39.333148000000001	53.565331999999998	53.555978000000003	0103000020E6100000010000000500000055D97745F0A74340D3A57F492AC74A4055D97745F0A74340EEB089CC5CC84A40295DFA97A4AA4340EEB089CC5CC84A40295DFA97A4AA4340D3A57F492AC74A4055D97745F0A74340D3A57F492AC74A40
14782	Потапово	1	12	759	39.100628	39.117812999999998	53.542197000000002	53.534823000000003	0103000020E61000000100000005000000EC87D860E18C434006137F1475C44A40EC87D860E18C4340A27E17B666C54A409605137F148F4340A27E17B666C54A409605137F148F434006137F1475C44A40EC87D860E18C434006137F1475C44A40
5341	Поплевинский	1	12	759	39.534838000000001	39.551788999999999	53.689273	53.678308000000001	0103000020E610000001000000050000003B54539275C44340BE4EEACBD2D64A403B54539275C44340068200193AD84A4072A59E05A1C64340068200193AD84A4072A59E05A1C64340BE4EEACBD2D64A403B54539275C44340BE4EEACBD2D64A40
54691	Новоалександрово	1	12	759	39.176383000000001	39.213366999999998	53.745471999999999	53.724497	0103000020E610000001000000050000000249D8B7939643406A865451BCDC4A400249D8B793964340B70A62A06BDF4A40D7851F9C4F9B4340B70A62A06BDF4A40D7851F9C4F9B43406A865451BCDC4A400249D8B7939643406A865451BCDC4A40
14340	Мураевня	1	12	759	39.470815000000002	39.497934999999998	53.500590000000003	53.486389000000003	0103000020E61000000100000005000000AEBB79AA43BC43402C11A8FE41BE4A40AEBB79AA43BC4340325A475513C04A4052448655BCBF4340325A475513C04A4052448655BCBF43402C11A8FE41BE4A40AEBB79AA43BC43402C11A8FE41BE4A40
13915	Молодежный	1	12	759	39.489139999999999	39.497908000000002	53.663404	53.654957000000003	0103000020E610000001000000050000002D95B7239CBE4340A5A487A1D5D34A402D95B7239CBE43408E041A6CEAD44A4059350873BBBF43408E041A6CEAD44A4059350873BBBF4340A5A487A1D5D34A402D95B7239CBE4340A5A487A1D5D34A40
14911	Милославское	1	12	759	39.408848999999996	39.467742999999999	53.591518000000001	53.569578	0103000020E610000001000000050000004B00FE2955B44340B34291EEE7C84A404B00FE2955B44340677FA0DCB6CB4A406AF7AB00DFBB4340677FA0DCB6CB4A406AF7AB00DFBB4340B34291EEE7C84A404B00FE2955B44340B34291EEE7C84A40
14157	Липяги	1	12	759	39.031224000000002	39.056682000000002	53.714267	53.682644000000003	0103000020E61000000100000005000000D76CE525FF834340C367EBE060D74A40D76CE525FF83434057CEDE196DDB4A40CD22145B4187434057CEDE196DDB4A40CD22145B41874340C367EBE060D74A40D76CE525FF834340C367EBE060D74A40
13972	Кочуры	1	12	759	39.348967000000002	39.386876000000001	53.446786000000003	53.436343999999998	0103000020E610000001000000050000000E315EF3AAAC434025E7C41EDAB74A400E315EF3AAAC4340C4279D4830B94A40BCCD1B2785B14340C4279D4830B94A40BCCD1B2785B1434025E7C41EDAB74A400E315EF3AAAC434025E7C41EDAB74A40
13679	Казначеевка	1	12	759	39.465856000000002	39.481288999999997	53.642735000000002	53.624518000000002	0103000020E610000001000000050000009C525E2BA1BB4340B5E1B034F0CF4A409C525E2BA1BB43404E7FF62345D24A405776C1E09ABD43404E7FF62345D24A405776C1E09ABD4340B5E1B034F0CF4A409C525E2BA1BB4340B5E1B034F0CF4A40
14829	Змеевка	1	12	759	39.214677999999999	39.240639000000002	53.548253000000003	53.533185000000003	0103000020E61000000100000005000000D99596917A9B4340E0DBF4673FC44A40D99596917A9B43408A7780272DC64A4032923D42CD9E43408A7780272DC64A4032923D42CD9E4340E0DBF4673FC44A40D99596917A9B4340E0DBF4673FC44A40
13772	Зеленый	1	12	759	39.588099	39.602598	53.676138000000002	53.663367000000001	0103000020E61000000100000005000000B8E7F9D346CB4340711FB935E9D44A40B8E7F9D346CB43409BCAA2B08BD64A40485167EE21CD43409BCAA2B08BD64A40485167EE21CD4340711FB935E9D44A40B8E7F9D346CB4340711FB935E9D44A40
13493	Дегтярка	1	12	759	39.557977999999999	39.588773000000003	53.568862000000003	53.559161000000003	0103000020E6100000010000000500000099F1B6D26BC743406E19709692C74A4099F1B6D26BC74340F5F75278D0C84A4048E2E5E95CCB4340F5F75278D0C84A4048E2E5E95CCB43406E19709692C74A4099F1B6D26BC743406E19709692C74A40
13582	Горняк	1	12	759	39.481001999999997	39.496074999999998	53.607522000000003	53.600197000000001	0103000020E61000000100000005000000C1A7397991BD434023145B41D3CC4A40C1A7397991BD4340DECCE847C3CD4A407DAEB6627FBF4340DECCE847C3CD4A407DAEB6627FBF434023145B41D3CC4A40C1A7397991BD434023145B41D3CC4A40
13354	Воскресенское 1-е	1	12	759	39.316206000000001	39.341278000000003	53.646402000000002	53.633628000000002	0103000020E6100000010000000500000045662E7079A843403AEAE8B81AD14A4045662E7079A84340D508FD4CBDD24A40126C5CFFAEAB4340D508FD4CBDD24A40126C5CFFAEAB43403AEAE8B81AD14A4045662E7079A843403AEAE8B81AD14A40
14055	Воейково	1	12	759	39.151750999999997	39.189785999999998	53.451425	53.433109000000002	0103000020E610000001000000050000005111A7936C934340384D9F1D70B74A405111A7936C93434064CC5D4BC8B94A408C9E5BE84A98434064CC5D4BC8B94A408C9E5BE84A984340384D9F1D70B74A405111A7936C934340384D9F1D70B74A40
14255	Бугровка	1	12	759	39.049433000000001	39.065899000000002	53.673347999999997	53.658825999999998	0103000020E61000000100000005000000ED2B0FD25386434093E00D6954D44A40ED2B0FD253864340DB696B4430D64A4068EBE0606F884340DB696B4430D64A4068EBE0606F88434093E00D6954D44A40ED2B0FD25386434093E00D6954D44A40
14621	Боршевое	1	12	759	39.130865	39.169583000000003	53.720959999999998	53.701183	0103000020E6100000010000000500000074982F2FC09043406EC1525DC0D94A4074982F2FC0904340B1DCD26A48DC4A40927A4FE5B4954340B1DCD26A48DC4A40927A4FE5B49543406EC1525DC0D94A4074982F2FC09043406EC1525DC0D94A40
13486	Большое Подовечье	1	12	759	39.670959000000003	39.683069000000003	53.595526	53.584938000000001	0103000020E610000001000000050000007BFA08FCE1D543400518963FDFCA4A407BFA08FCE1D5434077F52A323ACC4A40AAF413CE6ED7434077F52A323ACC4A40AAF413CE6ED743400518963FDFCA4A407BFA08FCE1D543400518963FDFCA4A40
13207	Богородицкое	1	12	759	39.191538000000001	39.224756999999997	53.657817999999999	53.638576999999998	0103000020E610000001000000050000007BF8325184984340287D21E4BCD14A407BF83251849843402D5C566133D44A4006465ED6C49C43402D5C566133D44A4006465ED6C49C4340287D21E4BCD14A407BF8325184984340287D21E4BCD14A40
60465	Арцыбашевский	1	12	759	39.532691	39.548105999999997	53.645964999999997	53.637338	0103000020E61000000100000005000000D0EFFB372FC44340C03FA54A94D14A40D0EFFB372FC4434029AE2AFBAED24A40E55E605628C6434029AE2AFBAED24A40E55E605628C64340C03FA54A94D14A40D0EFFB372FC44340C03FA54A94D14A40
14146	Архангельское	1	12	759	39.271073999999999	39.294592000000002	53.431187999999999	53.416651999999999	0103000020E61000000100000005000000E065868DB2A2434010E84CDA54B54A40E065868DB2A24340BD361B2B31B74A40E5D4CE30B5A54340BD361B2B31B74A40E5D4CE30B5A5434010E84CDA54B54A40E065868DB2A2434010E84CDA54B54A40
13206	Яблонево	1	12	1174	39.754179000000001	39.778433999999997	53.869422999999998	53.854835999999999	0103000020E610000001000000050000003D2AFEEF88E04340C3B81B446BED4A403D2AFEEF88E04340F2B1BB4049EF4A40170CAEB9A3E34340F2B1BB4049EF4A40170CAEB9A3E34340C3B81B446BED4A403D2AFEEF88E04340C3B81B446BED4A40
13022	Юраково	1	12	1174	39.937533999999999	39.954647000000001	54.021230000000003	54.011533	0103000020E61000000100000005000000AC71361D01F8434092E9D0E979014B40AC71361D01F84340D8D825AAB7024B40BD1C76DF31FA4340D8D825AAB7024B40BD1C76DF31FA434092E9D0E979014B40AC71361D01F8434092E9D0E979014B40
12928	Чижово	1	12	1174	39.732135	39.755696999999998	53.966652000000003	53.947462999999999	0103000020E61000000100000005000000E4A08499B6DD4340C495B37746F94A40E4A08499B6DD4340774EB340BBFB4A40B857E6ADBAE04340774EB340BBFB4A40B857E6ADBAE04340C495B37746F94A40E4A08499B6DD4340C495B37746F94A40
12247	Совхоз Быковская Степь	1	12	1174	40.197642000000002	40.213695000000001	53.953963999999999	53.939948000000001	0103000020E61000000100000005000000742843554C19444066F84F3750F84A40742843554C194440DAC70A7E1BFA4A40CC28965B5A1B4440DAC70A7E1BFA4A40CC28965B5A1B444066F84F3750F84A40742843554C19444066F84F3750F84A40
12812	Семион	1	12	1174	40.142108	40.168626000000003	54.076180999999998	54.051186000000001	0103000020E61000000100000005000000FF3F4E9830124440AC014A438D064B40FF3F4E9830124440CDC98B4CC0094B40AEA0698995154440CDC98B4CC0094B40AEA0698995154440AC014A438D064B40FF3F4E9830124440AC014A438D064B40
12726	Пустотино	1	12	1174	40.294713999999999	40.329577	54.066074	54.053184000000002	0103000020E6100000010000000500000030D63730B9254440D255BABBCE064B4030D63730B9254440D68EE21C75084B40C44142942F2A4440D68EE21C75084B40C44142942F2A4440D255BABBCE064B4030D63730B9254440D255BABBCE064B40
12589	Пехлец	1	12	1174	40.090266	40.115706000000003	53.953169000000003	53.922415999999998	0103000020E610000001000000050000006AF816D68D0B444050A73CBA11F64A406AF816D68D0B4440D047197101FA4A40BAF94674CF0E4440D047197101FA4A40BAF94674CF0E444050A73CBA11F64A406AF816D68D0B444050A73CBA11F64A40
12497	Никитино	1	12	1174	40.021428	40.05021	54.089416999999997	54.065703999999997	0103000020E61000000100000005000000FE9B1727BE024440B29B19FD68084B40FE9B1727BE0244406C5A2904720B4B4051F701486D0644406C5A2904720B4B4051F701486D064440B29B19FD68084B40FE9B1727BE024440B29B19FD68084B40
12479	Незнаново	1	12	1174	40.080753000000001	40.128346000000001	54.036203	54.013506	0103000020E61000000100000005000000E606431D560A44405F268A90BA014B40E606431D560A44403082C64CA2044B40454948A46D1044403082C64CA2044B40454948A46D1044405F268A90BA014B40E606431D560A44405F268A90BA014B40
12392	Моловка	1	12	1174	39.835997999999996	39.859588000000002	53.964230999999998	53.941988000000002	0103000020E61000000100000005000000BDC282FB01EB4340BB9C121093F84A40BDC282FB01EB43400A65E1EB6BFB4A405C04C6FA06EE43400A65E1EB6BFB4A405C04C6FA06EE4340BB9C121093F84A40BDC282FB01EB4340BB9C121093F84A40
22014	Молвина Слобода	1	12	1174	39.913316000000002	39.935566999999999	53.980531999999997	53.968128999999998	0103000020E61000000100000005000000EF74E789E7F4434093A7ACA6EBFB4A40EF74E789E7F443403A57941282FD4A40C11BD2A8C0F743403A57941282FD4A40C11BD2A8C0F7434093A7ACA6EBFB4A40EF74E789E7F4434093A7ACA6EBFB4A40
12860	Лесуново	1	12	1174	40.253382000000002	40.268680000000003	54.026820999999998	54.013537999999997	0103000020E6100000010000000500000092B245D26E2044406AA0F99CBB014B4092B245D26E2044404AECDADE6E034B406E8B321B642244404AECDADE6E034B406E8B321B642244406AA0F99CBB014B4092B245D26E2044406AA0F99CBB014B40
12338	Курбатово	1	12	1174	40.221474000000001	40.248145000000001	54.101514000000002	54.079265999999997	0103000020E6100000010000000500000008759142591C4440A5D76663250A4B4008759142591C4440070B2769FE0C4B403DD52137C31F4440070B2769FE0C4B403DD52137C31F4440A5D76663250A4B4008759142591C4440A5D76663250A4B40
11153	Кораблино	1	12	1174	39.991568000000001	40.068823000000002	53.945242	53.899371000000002	0103000020E610000001000000050000004CE141B3EBFE434044FCC3961EF34A404CE141B3EBFE43401F679AB0FDF84A40371B2B31CF0844401F679AB0FDF84A40371B2B31CF08444044FCC3961EF34A404CE141B3EBFE434044FCC3961EF34A40
11338	Ковалинка	1	12	1174	40.008187	40.033195999999997	53.863917000000001	53.851160999999998	0103000020E610000001000000050000004DA088450C014440B950F9D7F2EC4A404DA088450C014440AEBA0ED594EE4A40D32D3BC43F044440AEBA0ED594EE4A40D32D3BC43F044440B950F9D7F2EC4A404DA088450C014440B950F9D7F2EC4A40
12099	Княжое	1	12	1174	40.163325999999998	40.186691000000003	53.901414000000003	53.885787000000001	0103000020E61000000100000005000000124BCADDE7144440691CEA7761F14A40124BCADDE71444400A14B18861F34A4091BA9D7DE51744400A14B18861F34A4091BA9D7DE5174440691CEA7761F14A40124BCADDE7144440691CEA7761F14A40
12159	Ключ	1	12	1174	40.191192000000001	40.221429000000001	53.988781000000003	53.974463999999998	0103000020E61000000100000005000000E0A0BDFA781844408E90813CBBFC4A40E0A0BDFA78184440FEF3346090FE4A4068B114C9571C4440FEF3346090FE4A4068B114C9571C44408E90813CBBFC4A40E0A0BDFA781844408E90813CBBFC4A40
11900	Кипчаково	1	12	1174	40.125435000000003	40.159508000000002	53.885500999999998	53.865955999999997	0103000020E610000001000000050000000B630B410E10444032E36DA5D7EE4A400B630B410E104440A3C9C51858F14A40A6B915C26A144440A3C9C51858F14A40A6B915C26A14444032E36DA5D7EE4A400B630B410E10444032E36DA5D7EE4A40
12011	Ибердский	1	12	1174	40.217987999999998	40.248081999999997	53.867792999999999	53.848737999999997	0103000020E61000000100000005000000D175E107E71B4440AC6F6072A3EC4A40D175E107E71B44404F594DD713EF4A40F65CA626C11F44404F594DD713EF4A40F65CA626C11F4440AC6F6072A3EC4A40D175E107E71B4440AC6F6072A3EC4A40
11768	Ерлино	1	12	1174	39.725236000000002	39.745671999999999	53.921038000000003	53.904702999999998	0103000020E61000000100000005000000E1F08288D4DC4340EACBD24ECDF34A40E1F08288D4DC4340C72FBC92E4F54A407EC51A2E72DF4340C72FBC92E4F54A407EC51A2E72DF4340EACBD24ECDF34A40E1F08288D4DC4340EACBD24ECDF34A40
54696	Газопровода	1	12	1174	40.099787999999997	40.112625000000001	53.918678	53.911645999999998	0103000020E6100000010000000500000041446ADAC50C4440BDC3EDD0B0F44A4041446ADAC50C444000C79E3D97F54A4023DBF97E6A0E444000C79E3D97F54A4023DBF97E6A0E4440BDC3EDD0B0F44A4041446ADAC50C4440BDC3EDD0B0F44A40
11672	Великая Лука	1	12	1174	39.831460999999997	39.870376	53.844583999999998	53.834919999999997	0103000020E61000000100000005000000217365506DEA43405E6397A8DEEA4A40217365506DEA4340C85C19541BEC4A40959C137B68EF4340C85C19541BEC4A40959C137B68EF43405E6397A8DEEA4A40217365506DEA43405E6397A8DEEA4A40
11652	Бобровинки	1	12	1174	39.974302999999999	39.994101000000001	53.934997000000003	53.919139000000001	0103000020E6100000010000000500000085B2F0F5B5FC434034BDC458A6F54A4085B2F0F5B5FC4340D76D50FBADF74A40E0F599B33EFF4340D76D50FBADF74A40E0F599B33EFF434034BDC458A6F54A4085B2F0F5B5FC434034BDC458A6F54A40
13069	Бестужево	1	12	1174	39.856444000000003	39.877006000000002	54.043087	54.020446999999997	0103000020E610000001000000050000007F6DFDF49FED43409126DE019E024B407F6DFDF49FED4340FEF0F3DF83054B40A9328CBB41F04340FEF0F3DF83054B40A9328CBB41F043409126DE019E024B407F6DFDF49FED43409126DE019E024B40
11571	Аманово	1	12	1174	39.853776000000003	39.877212999999998	53.92774	53.919987999999996	0103000020E610000001000000050000000B0E2F8848ED4340315BB22AC2F54A400B0E2F8848ED434074982F2FC0F64A402250FD8348F0434074982F2FC0F64A402250FD8348F04340315BB22AC2F54A400B0E2F8848ED4340315BB22AC2F54A40
54687	1-е отделение совхоза Красное (Проницы)	1	12	1174	40.007863999999998	40.027670999999998	54.001029000000003	53.991109999999999	0103000020E610000001000000050000006A6803B001014440895E46B1DCFE4A406A6803B0010144407EACE0B721004B4018062CB98A0344407EACE0B721004B4018062CB98A034440895E46B1DCFE4A406A6803B001014440895E46B1DCFE4A40
10979	Шопино	1	12	478	40.516165999999998	40.533737000000002	55.164561999999997	55.158092000000003	0103000020E6100000010000000500000050A73CBA114244402FE1D05B3C944B4050A73CBA1142444009151C5E10954B4024D5777E5144444009151C5E10954B4024D5777E514444402FE1D05B3C944B4050A73CBA114244402FE1D05B3C944B40
10686	Уткино	1	12	478	40.534016000000001	40.547814000000002	55.131326000000001	55.120547000000002	0103000020E6100000010000000500000037C5E3A25A444440C25087156E8F4B4037C5E3A25A444440A88E554ACF904B403E25E7C41E464440A88E554ACF904B403E25E7C41E464440C25087156E8F4B4037C5E3A25A444440C25087156E8F4B40
10105	Тюково	1	12	478	39.954926	39.967233	55.115608999999999	55.109904	0103000020E61000000100000005000000D00CE2033BFA43408CD99255118E4B40D00CE2033BFA4340C70F9546CC8E4B40554E7B4ACEFB4340C70F9546CC8E4B40554E7B4ACEFB43408CD99255118E4B40D00CE2033BFA43408CD99255118E4B40
9795	Тума	1	12	478	40.505502999999997	40.583278999999997	55.161130999999997	55.134003	0103000020E61000000100000005000000D3838252B44044406F48A30227914B40D3838252B440444096AFCBF09F944B40C7B8E2E2A84A444096AFCBF09F944B40C7B8E2E2A84A44406F48A30227914B40D3838252B44044406F48A30227914B40
10744	Спирино	1	12	478	40.484492000000003	40.514575999999998	55.111763000000003	55.107272000000002	0103000020E610000001000000050000003A9677D5033E444065E3C116BB8D4B403A9677D5033E444091F3FE3F4E8E4B403BA759A0DD41444091F3FE3F4E8E4B403BA759A0DD41444065E3C116BB8D4B403A9677D5033E444065E3C116BB8D4B40
9580	Спас-Клепики	1	12	478	40.164906999999999	40.189628999999996	55.141742000000001	55.126097000000001	0103000020E61000000100000005000000D4F02DAC1B154440D68F4DF223904B40D4F02DAC1B1544401D3C139A24924B40C4AF58C3451844401D3C139A24924B40C4AF58C345184440D68F4DF223904B40D4F02DAC1B154440D68F4DF223904B40
10261	Прудки	1	12	478	40.242063000000002	40.255287000000003	55.273907999999999	55.269426000000003	0103000020E610000001000000050000002C499EEBFB1E44409758198D7CA24B402C499EEBFB1E44406F0ED76A0FA34B40070C923EAD2044406F0ED76A0FA34B40070C923EAD2044409758198D7CA24B402C499EEBFB1E44409758198D7CA24B40
10346	Первушкино	1	12	478	40.152482999999997	40.163136999999999	55.122303000000002	55.117803000000002	0103000020E6100000010000000500000015191D9084134440732F302B148F4B4015191D9084134440F299EC9FA78F4B403FE257ACE1144440F299EC9FA78F4B403FE257ACE1144440732F302B148F4B4015191D9084134440732F302B148F4B40
10599	Оськино	1	12	478	40.321599999999997	40.339494999999999	55.152799000000002	55.146521999999997	0103000020E61000000100000005000000613255302A2944407F129F3BC1924B40613255302A29444046EEE9EA8E934B40E8137992742B444046EEE9EA8E934B40E8137992742B44407F129F3BC1924B40613255302A2944407F129F3BC1924B40
10920	Норино	1	12	478	40.854283000000002	40.878653999999997	55.016568999999997	55.012490999999997	0103000020E61000000100000005000000AF433525596D4440463F1A4E99814B40AF433525596D44404F90D8EE1E824B40F23FF9BB777044404F90D8EE1E824B40F23FF9BB77704440463F1A4E99814B40AF433525596D4440463F1A4E99814B40
10197	Ненашкино	1	12	478	40.138865000000003	40.160083	55.174892	55.145643	0103000020E610000001000000050000008FC70C54C611444017F2086EA4924B408FC70C54C6114440802A6EDC62964B40A2D288997D144440802A6EDC62964B40A2D288997D14444017F2086EA4924B408FC70C54C611444017F2086EA4924B40
11094	Мягково	1	12	478	40.965575000000001	40.984251	55.100149000000002	55.089939000000001	0103000020E61000000100000005000000E86A2BF6977B444046D1031F838B4B40E86A2BF6977B444012DDB3AED18C4B401407D0EFFB7D444012DDB3AED18C4B401407D0EFFB7D444046D1031F838B4B40E86A2BF6977B444046D1031F838B4B40
10924	Молькино	1	12	478	40.558216000000002	40.572966999999998	55.168849999999999	55.165425999999997	0103000020E610000001000000050000004E0D349F734744403CF4DDAD2C954B404E0D349F73474440FDF675E09C954B40F7578FFB56494440FDF675E09C954B40F7578FFB564944403CF4DDAD2C954B404E0D349F734744403CF4DDAD2C954B40
10787	Малахово	1	12	478	40.754587999999998	40.763570999999999	55.007680000000001	54.987729999999999	0103000020E610000001000000050000001EFAEE569660444098A3C7EF6D7E4B401EFAEE5696604440A96A82A8FB804B404696CCB1BC614440A96A82A8FB804B404696CCB1BC61444098A3C7EF6D7E4B401EFAEE569660444098A3C7EF6D7E4B40
10007	Криуша	1	12	478	39.938504999999999	39.986493000000003	54.967993	54.934345	0103000020E61000000100000005000000F5108DEE20F843402F17F19D98774B40F5108DEE20F84340E3E0D231E77B4B40D15D126745FE4340E3E0D231E77B4B40D15D126745FE43402F17F19D98774B40F5108DEE20F843402F17F19D98774B40
10188	Колычево	1	12	478	39.881228	39.892879000000001	55.179960999999999	55.174984000000002	0103000020E61000000100000005000000E5284014CCF0434061A92EE065964B40E5284014CCF0434019C748F608974B408124ECDB49F2434019C748F608974B408124ECDB49F2434061A92EE065964B40E5284014CCF0434061A92EE065964B40
10872	Колесниково	1	12	478	40.823839	40.838400999999998	54.998370000000001	54.982728999999999	0103000020E61000000100000005000000AD156D8E7369444057EA5910CA7D4B40AD156D8E736944405DA79196CA7F4B4083F755B9506B44405DA79196CA7F4B4083F755B9506B444057EA5910CA7D4B40AD156D8E7369444057EA5910CA7D4B40
10183	Калдево	1	12	478	40.094704	40.124778999999997	55.137748999999999	55.131670999999997	0103000020E610000001000000050000007366BB421F0C4440726A6798DA904B407366BB421F0C444042075DC2A1914B40211D1EC2F80F444042075DC2A1914B40211D1EC2F80F4440726A6798DA904B407366BB421F0C4440726A6798DA904B40
54690	Заднепилево	1	12	478	40.173566999999998	40.197049	55.075479000000001	55.063786999999998	0103000020E6100000010000000500000019558671371644407974232C2A884B4019558671371644407444BE4BA9894B40D15AD1E6381944407444BE4BA9894B40D15AD1E6381944407974232C2A884B4019558671371644407974232C2A884B40
10257	Екшур	1	12	478	40.195673999999997	40.224043000000002	55.125433000000001	55.097816000000002	0103000020E61000000100000005000000B8567BD80B1944404583143C858C4B40B8567BD80B1944406A6B44300E904B40E9F2E670AD1C44406A6B44300E904B40E9F2E670AD1C44404583143C858C4B40B8567BD80B1944404583143C858C4B40
11100	Давыдово	1	12	478	40.663291999999998	40.692515	55.154378000000001	55.140754000000001	0103000020E6100000010000000500000066D993C0E6544440FE63213A04924B4066D993C0E6544440679C86A8C2934B40A67EDE54A4584440679C86A8C2934B40A67EDE54A4584440FE63213A04924B4066D993C0E6544440FE63213A04924B40
10682	Гуреево	1	12	478	40.446824999999997	40.451540999999999	55.143008000000002	55.134388999999999	0103000020E610000001000000050000008104C58F3139444098F8A3A833914B408104C58F313944407F880D164E924B40CDE67118CC3944407F880D164E924B40CDE67118CC39444098F8A3A833914B408104C58F3139444098F8A3A833914B40
10557	Гришино	1	12	478	40.298307000000001	40.309562999999997	55.049117000000003	55.034739999999999	0103000020E610000001000000050000007D957CEC2E26444078EE3D5C72844B407D957CEC2E264440BD56427749864B409C86A8C29F274440BD56427749864B409C86A8C29F27444078EE3D5C72844B407D957CEC2E26444078EE3D5C72844B40
10503	Бусаево	1	12	478	40.393949999999997	40.410237000000002	55.090010999999997	55.074742000000001	0103000020E610000001000000050000002D211FF46C3244409ED1562591894B402D211FF46C324440DFA3FE7A858B4B40F94D61A582344440DFA3FE7A858B4B40F94D61A5823444409ED1562591894B402D211FF46C3244409ED1562591894B40
9944	Болонь	1	12	478	40.075147000000001	40.095835999999998	55.060254999999998	55.048966999999998	0103000020E610000001000000050000003EB2B96A9E094440A7CAF78C44864B403EB2B96A9E094440D235936FB6874B40C5E3A25A440C4440D235936FB6874B40C5E3A25A440C4440A7CAF78C44864B403EB2B96A9E094440A7CAF78C44864B40
11039	Алексеево	1	12	478	40.872815000000003	40.917264000000003	55.122751000000001	55.115651	0103000020E61000000100000005000000A83AE466B86F4440F65FE7A6CD8E4B40A83AE466B86F44409146054EB68F4B402AE620E8687544409146054EB68F4B402AE620E868754440F65FE7A6CD8E4B40A83AE466B86F4440F65FE7A6CD8E4B40
7628	Щербатовка	1	12	780	41.743156999999997	41.762920000000001	54.81832	54.800238	0103000020E610000001000000050000009065C1C41FDF44401B82E3326E664B409065C1C41FDF4440D4D4B2B5BE684B406FBBD05CA7E14440D4D4B2B5BE684B406FBBD05CA7E144401B82E3326E664B409065C1C41FDF44401B82E3326E664B40
7025	Шостье	1	12	780	41.289661000000002	41.322673999999999	54.747979000000001	54.727843	0103000020E610000001000000050000009DF6949C13A54440AFCF9CF5295D4B409DF6949C13A54440228C9FC6BD5F4B407FA2B2614DA94440228C9FC6BD5F4B407FA2B2614DA94440AFCF9CF5295D4B409DF6949C13A54440AFCF9CF5295D4B40
7072	Чаур	1	12	780	41.155884	41.179186000000001	55.148620999999999	55.138263999999999	0103000020E610000001000000050000001EFCC401F4934440691B7FA2B2914B401EFCC401F4934440D93F4F0306934B4056F31C91EF964440D93F4F0306934B4056F31C91EF964440691B7FA2B2914B401EFCC401F4934440691B7FA2B2914B40
8099	Торбаево	1	12	780	41.454501999999998	41.472791000000001	55.026623000000001	55.020986999999998	0103000020E61000000100000005000000B9FB1C1F2DBA44401152B7B3AF824B40B9FB1C1F2DBA44402429E96168834B40EC6B5D6A84BC44402429E96168834B40EC6B5D6A84BC44401152B7B3AF824B40B9FB1C1F2DBA44401152B7B3AF824B40
7962	Токарево	1	12	780	41.243541	41.271118999999999	54.840583000000002	54.823858999999999	0103000020E61000000100000005000000191EFB592C9F4440F4C1323674694B40191EFB592C9F44406B494739986B4B4080290307B4A244406B494739986B4B4080290307B4A24440F4C1323674694B40191EFB592C9F4440F4C1323674694B40
7751	Ташенка	1	12	780	41.370635	41.399552	54.867964000000001	54.842495999999997	0103000020E6100000010000000500000061E0B9F770AF44406281AFE8D66B4B4061E0B9F770AF44407C0DC171196F4B4094861A8524B344407C0DC171196F4B4094861A8524B344406281AFE8D66B4B4061E0B9F770AF44406281AFE8D66B4B40
8651	Сынтул	1	12	780	41.283337000000003	41.308588	55.011674999999997	54.992637000000002	0103000020E61000000100000005000000965F066344A4444058E6ADBA0E7F4B40965F066344A444402497FF907E814B4012F8C3CF7FA744402497FF907E814B4012F8C3CF7FA7444058E6ADBA0E7F4B40965F066344A4444058E6ADBA0E7F4B40
54671	Сосновка	1	12	780	41.645816000000003	41.661572	54.826562000000003	54.819916999999997	0103000020E61000000100000005000000E59D4319AAD244409B374E0AF3684B40E59D4319AAD24440E50E9BC8CC694B4083F92B64AED44440E50E9BC8CC694B4083F92B64AED444409B374E0AF3684B40E59D4319AAD244409B374E0AF3684B40
8205	Сиверка	1	12	780	41.373562999999997	41.395285000000001	54.714967999999999	54.703696000000001	0103000020E6100000010000000500000071FF91E9D0AF4440BB29E5B5125A4B4071FF91E9D0AF4440E0D74812845B4B40B8CCE9B298B24440E0D74812845B4B40B8CCE9B298B24440BB29E5B5125A4B4071FF91E9D0AF4440BB29E5B5125A4B40
7632	Селизово	1	12	780	41.301257999999997	41.315370000000001	54.917918999999998	54.907950999999997	0103000020E6100000010000000500000045D4449F8FA644406CAF05BD37744B4045D4449F8FA6444042B0AA5E7E754B40DC114E0B5EA8444042B0AA5E7E754B40DC114E0B5EA844406CAF05BD37744B4045D4449F8FA644406CAF05BD37744B40
7500	Самылово	1	12	780	41.256754999999998	41.286695999999999	54.955928999999998	54.941203000000002	0103000020E61000000100000005000000D00A0C59DDA04440D4F2035779784B40D00A0C59DDA044402426A8E15B7A4B406FF25B74B2A444402426A8E15B7A4B406FF25B74B2A44440D4F2035779784B40D00A0C59DDA04440D4F2035779784B40
7905	Савостьяново	1	12	780	41.674706	41.687047999999997	55.028599999999997	55.014107000000003	0103000020E610000001000000050000001E3526C45CD6444085D21742CE814B401E3526C45CD644403255302AA9834B401F645930F1D744403255302AA9834B401F645930F1D7444085D21742CE814B401E3526C45CD6444085D21742CE814B40
6740	Пустынь	1	12	780	41.745978000000001	41.765489000000002	54.938896	54.920169999999999	0103000020E610000001000000050000008BC404357CDF444052616C21C8754B408BC404357CDF4440302C7FBE2D784B405039268BFBE14440302C7FBE2D784B405039268BFBE1444052616C21C8754B408BC404357CDF444052616C21C8754B40
6289	Поповка	1	12	780	41.407924000000001	41.430013000000002	54.898634000000001	54.8857	0103000020E6100000010000000500000073A087DA36B444409A081B9E5E714B4073A087DA36B444406E895C7006734B406CED7DAA0AB744406E895C7006734B406CED7DAA0AB744409A081B9E5E714B4073A087DA36B444409A081B9E5E714B40
8048	Подлипки	1	12	780	41.520231000000003	41.540317999999999	55.031545999999999	55.020353	0103000020E61000000100000005000000C5AEEDED96C2444010B056ED9A824B40C5AEEDED96C24440E92807B309844B4056B8E52329C54440E92807B309844B4056B8E52329C5444010B056ED9A824B40C5AEEDED96C2444010B056ED9A824B40
7811	Погост	1	12	780	41.148508	41.169249999999998	55.013854000000002	55.001654000000002	0103000020E61000000100000005000000E198654F029344402CF4C13236804B40E198654F029344409B75C6F7C5814B408B6CE7FBA99544409B75C6F7C5814B408B6CE7FBA99544402CF4C13236804B40E198654F029344402CF4C13236804B40
7767	Перво	1	12	780	41.434424	41.451608999999998	54.836503	54.826624000000002	0103000020E610000001000000050000007B4CA4349BB744405B0BB3D0CE694B407B4CA4349BB74440C100C287126B4B4025CADE52CEB94440C100C287126B4B4025CADE52CEB944405B0BB3D0CE694B407B4CA4349BB744405B0BB3D0CE694B40
5646	Озерный	1	12	780	41.309280000000001	41.323267000000001	55.090268000000002	55.083832999999998	0103000020E6100000010000000500000048A7AE7C96A74440ACA92C0ABB8A4B4048A7AE7C96A744400BF0DDE68D8B4B40227024D060A944400BF0DDE68D8B4B40227024D060A94440ACA92C0ABB8A4B4048A7AE7C96A74440ACA92C0ABB8A4B40
54641	Новая Деревня	1	12	780	41.652203	41.684308999999999	54.898054000000002	54.881328000000003	0103000020E6100000010000000500000032AD4D637BD3444049861C5BCF704B4032AD4D637BD344406005F86EF3724B40E2ADF36F97D744406005F86EF3724B40E2ADF36F97D7444049861C5BCF704B4032AD4D637BD3444049861C5BCF704B40
7902	Мишуково	1	12	780	41.694854999999997	41.716765000000002	54.982579999999999	54.973052000000003	0103000020E61000000100000005000000253B3602F1D8444059A7CAF78C7C4B40253B3602F1D8444012DA722EC57D4B406FF59CF4BEDB444012DA722EC57D4B406FF59CF4BEDB444059A7CAF78C7C4B40253B3602F1D8444059A7CAF78C7C4B40
7369	Малеево	1	12	780	41.213852000000003	41.255668	54.933014999999997	54.916009000000003	0103000020E61000000100000005000000941799805F9B4440BCEB6CC83F754B40941799805F9B4440B6D617096D774B401E51A1BAB9A04440B6D617096D774B401E51A1BAB9A04440BCEB6CC83F754B40941799805F9B4440BCEB6CC83F754B40
7071	Любовниково	1	12	780	41.659497000000002	41.674131000000003	54.967910000000003	54.952635000000001	0103000020E61000000100000005000000B267CF656AD44440320395F1EF794B40B267CF656AD4444056BC9179E47B4B40221CB3EC49D6444056BC9179E47B4B40221CB3EC49D64440320395F1EF794B40B267CF656AD44440320395F1EF794B40
7018	Лубяники	1	12	780	40.815277999999999	40.851695999999997	54.803807999999997	54.789639000000001	0103000020E61000000100000005000000FB928D075B684440B55208E412654B40FB928D075B684440AF21382EE3664B402711E15F046D4440AF21382EE3664B402711E15F046D4440B55208E412654B40FB928D075B684440B55208E412654B40
7423	Лощинино	1	12	780	41.289462999999998	41.335987000000003	54.967590000000001	54.947128999999997	0103000020E610000001000000050000007633A31F0DA54440ED0BE8853B794B407633A31F0DA54440E4F736FDD97B4B40CA703C9F01AB4440E4F736FDD97B4B40CA703C9F01AB4440ED0BE8853B794B407633A31F0DA54440ED0BE8853B794B40
8601	Лашма	1	12	780	41.116627000000001	41.163465000000002	54.948467999999998	54.910162	0103000020E61000000100000005000000516A2FA2ED8E4440EE073C3080744B40516A2FA2ED8E4440B9A6406667794B403485CE6BEC944440B9A6406667794B403485CE6BEC944440EE073C3080744B40516A2FA2ED8E4440EE073C3080744B40
7222	Крюково	1	12	780	41.614545	41.632916000000002	54.916584	54.903644999999997	0103000020E61000000100000005000000CD751A69A9CE4440D218ADA3AA734B40CD751A69A9CE4440B804E09F52754B40BD8E386403D14440B804E09F52754B40BD8E386403D14440D218ADA3AA734B40CD751A69A9CE4440D218ADA3AA734B40
7231	Крутоярский	1	12	780	41.265397	41.274776000000003	54.909939000000001	54.901507000000002	0103000020E610000001000000050000006FBA6587F8A14440BB0ED59464734B406FBA6587F8A144406F2D93E178744B40E4DC26DC2BA344406F2D93E178744B40E4DC26DC2BA34440BB0ED59464734B406FBA6587F8A14440BB0ED59464734B40
6942	Кочемары	1	12	780	40.947761999999997	40.977837000000001	54.846648999999999	54.822468999999998	0103000020E610000001000000050000001E32E54350794440A67C08AA46694B401E32E54350794440761893FE5E6C4B40CDE847C3297D4440761893FE5E6C4B40CDE847C3297D4440A67C08AA46694B401E32E54350794440A67C08AA46694B40
7134	Которово	1	12	780	41.558517000000002	41.596362999999997	54.909427000000001	54.887352	0103000020E6100000010000000500000049A12C7C7DC74440250516C094714B4049A12C7C7DC74440B98C9B1A68744B40B0C56E9F55CC4440B98C9B1A68744B40B0C56E9F55CC4440250516C094714B4049A12C7C7DC74440250516C094714B40
8036	Кольдюки	1	12	780	41.591369	41.607314000000002	55.009182000000003	54.998364000000002	0103000020E61000000100000005000000226FB9FAB1CB44407BC03C64CA7F4B40226FB9FAB1CB44401FDB32E02C814B4094331477BCCD44401FDB32E02C814B4094331477BCCD44407BC03C64CA7F4B40226FB9FAB1CB44407BC03C64CA7F4B40
7065	Клетино	1	12	780	41.187783000000003	41.219880000000003	55.007323	54.994428999999997	0103000020E6100000010000000500000055DFF94509984440D4981073497F4B4055DFF945099844401AC1C6F5EF804B40B2852007259C44401AC1C6F5EF804B40B2852007259C4440D4981073497F4B4055DFF94509984440D4981073497F4B40
6883	Китово	1	12	780	40.908281000000002	40.928474999999999	54.883285999999998	54.847726999999999	0103000020E61000000100000005000000024A438D42744440D5777E51826C4B40024A438D42744440E08101840F714B40A913D044D8764440E08101840F714B40A913D044D8764440D5777E51826C4B40024A438D42744440D5777E51826C4B40
6807	Квасьево	1	12	780	41.746938999999998	41.761949999999999	54.908655000000003	54.896282999999997	0103000020E61000000100000005000000B08D78B29BDF4440FA7ABE66B9724B40B08D78B29BDF4440672C9ACE4E744B40F697DD9387E14440672C9ACE4E744B40F697DD9387E14440FA7ABE66B9724B40B08D78B29BDF4440FA7ABE66B9724B40
6870	Ибердус	1	12	780	41.019114999999999	41.069159999999997	54.913193999999997	54.898287000000003	0103000020E6100000010000000500000078EE3D5C7282444003B68311FB724B4078EE3D5C72824440A3737E8AE3744B407E18213CDA884440A3737E8AE3744B407E18213CDA88444003B68311FB724B4078EE3D5C7282444003B68311FB724B40
6755	Ермолово	1	12	780	41.690525000000001	41.722118999999999	54.926327000000001	54.906185999999998	0103000020E6100000010000000500000003098A1F63D84440E90B21E7FD734B4003098A1F63D844406E3315E291764B40FD6838656EDC44406E3315E291764B40FD6838656EDC4440E90B21E7FD734B4003098A1F63D84440E90B21E7FD734B40
7133	Елатьма	1	12	780	41.728928000000003	41.764761999999997	54.980863999999997	54.948715999999997	0103000020E61000000100000005000000C19140834DDD44409198A0866F794B40C19140834DDD444070E998F38C7D4B409D9CA1B8E3E1444070E998F38C7D4B409D9CA1B8E3E144409198A0866F794B40C19140834DDD44409198A0866F794B40
6610	Дмитриево	1	12	780	41.576124	41.596893000000001	55.075654	55.057800999999998	0103000020E610000001000000050000006938656EBEC944408A56EE0566874B406938656EBEC94440E2E7BF07AF894B400D1B65FD66CC4440E2E7BF07AF894B400D1B65FD66CC44408A56EE0566874B406938656EBEC944408A56EE0566874B40
6697	Данево	1	12	780	41.536473000000001	41.551250000000003	55.077824	55.065838999999997	0103000020E61000000100000005000000F017B325ABC4444092E68F696D884B40F017B325ABC44440056C0723F6894B40C3F5285C8FC64440056C0723F6894B40C3F5285C8FC6444092E68F696D884B40F017B325ABC4444092E68F696D884B40
7067	Гусь-Железный	1	12	780	41.130308999999997	41.175027	55.072257	55.044649999999997	0103000020E61000000100000005000000EEAF1EF7AD90444019E25817B7854B40EEAF1EF7AD9044401BF4A5B73F894B406075E448679644401BF4A5B73F894B406075E4486796444019E25817B7854B40EEAF1EF7AD90444019E25817B7854B40
6550	Гиблицы	1	12	780	41.074567999999999	41.106458000000003	54.975982000000002	54.958481999999997	0103000020E6100000010000000500000000AAB8718B894440FFE6C589AF7A4B4000AAB8718B8944400ABE69FAEC7C4B40E4326E6AA08D44400ABE69FAEC7C4B40E4326E6AA08D4440FFE6C589AF7A4B4000AAB8718B894440FFE6C589AF7A4B40
6491	Булгаково	1	12	780	41.338233000000002	41.358345999999997	55.026226000000001	55.010472999999998	0103000020E61000000100000005000000C8B60C384BAB4440D93EE42D57814B40C8B60C384BAB44400727A25F5B834B4082531F48DEAD44400727A25F5B834B4082531F48DEAD4440D93EE42D57814B40C8B60C384BAB4440D93EE42D57814B40
5492	Балушево-Починки	1	12	780	41.611733999999998	41.633994000000001	54.780065	54.755097999999997	0103000020E61000000100000005000000F6ECB94C4DCE444033A31F0DA7604B40F6ECB94C4DCE44408BE07F2BD9634B401CEE23B726D144408BE07F2BD9634B401CEE23B726D1444033A31F0DA7604B40F6ECB94C4DCE444033A31F0DA7604B40
6279	Ахматово	1	12	780	41.524462	41.530697000000004	54.921132	54.913479000000002	0103000020E6100000010000000500000054FF209221C34440994A3FE1EC744B4054FF209221C3444048A643A7E7754B40EC8A19E1EDC3444048A643A7E7754B40EC8A19E1EDC34440994A3FE1EC744B4054FF209221C34440994A3FE1EC744B40
6183	Ардабьево	1	12	780	41.649014000000001	41.670240999999997	55.078885	55.048105999999997	0103000020E61000000100000005000000B55208E412D34440E55E605628864B40B55208E412D344408E9257E7188A4B401BB80375CAD544408E9257E7188A4B401BB80375CAD54440E55E605628864B40B55208E412D34440E55E605628864B40
6391	Алешино	1	12	780	41.383606	41.397351	55.010874999999999	55.002975999999997	0103000020E6100000010000000500000052465C001AB1444021567F8461804B4052465C001AB1444008AC1C5A64814B403604C765DCB2444008AC1C5A64814B403604C765DCB2444021567F8461804B4052465C001AB1444021567F8461804B40
5268	Четово	1	12	725	42.428373999999998	42.452843999999999	54.654110000000003	54.643520000000002	0103000020E61000000100000005000000753A90F5D4364540352905DD5E524B40753A90F5D436454048FE60E0B9534B404C18CDCAF639454048FE60E0B9534B404C18CDCAF6394540352905DD5E524B40753A90F5D4364540352905DD5E524B40
5336	Чермные	1	12	725	42.473253999999997	42.498218000000001	54.435046	54.419243999999999	0103000020E61000000100000005000000C0594A96933C4540A98592C9A9354B40C0594A96933C4540B8205B96AF374B40A723809BC53F4540B8205B96AF374B40A723809BC53F4540A98592C9A9354B40C0594A96933C4540A98592C9A9354B40
5591	Сумерки	1	12	725	42.564926999999997	42.593699999999998	54.586607999999998	54.572763999999999	0103000020E610000001000000050000004ED026874F484540BF29AC5450494B404ED026874F48454036C98FF8154B4B404ED1915CFE4B454036C98FF8154B4B404ED1915CFE4B4540BF29AC5450494B404ED026874F484540BF29AC5450494B40
5276	Старый Кадом	1	12	725	42.456321000000003	42.481059999999999	54.628464999999998	54.611575000000002	0103000020E6100000010000000500000030BDFDB9683A45408E06F016484E4B4030BDFDB9683A45401FD7868A71504B40F6B4C35F933D45401FD7868A71504B40F6B4C35F933D45408E06F016484E4B4030BDFDB9683A45408E06F016484E4B40
5109	Новоселки	1	12	725	42.269084999999997	42.293841999999998	54.625708000000003	54.613118999999998	0103000020E610000001000000050000000D6C95607122454032C7F2AE7A4E4B400D6C9560712245403C6C223317504B407A185A9D9C2545403C6C223317504B407A185A9D9C25454032C7F2AE7A4E4B400D6C95607122454032C7F2AE7A4E4B40
5115	Никиткино	1	12	725	42.320118000000001	42.339621000000001	54.629362	54.622179000000003	0103000020E61000000100000005000000336E6AA0F928454006A1BC8FA34F4B40336E6AA0F92845402EAC1BEF8E504B40750470B3782B45402EAC1BEF8E504B40750470B3782B454006A1BC8FA34F4B40336E6AA0F928454006A1BC8FA34F4B40
5496	Кущапино	1	12	725	42.510786000000003	42.525328999999999	54.613394999999997	54.597405999999999	0103000020E6100000010000000500000099A0866F614145409337C0CC774C4B4099A0866F61414540D44334BA834E4B40F8510DFB3D434540D44334BA834E4B40F8510DFB3D4345409337C0CC774C4B4099A0866F614145409337C0CC774C4B40
5653	Кочемирово	1	12	725	42.568682000000003	42.592855999999998	54.630071000000001	54.611935000000003	0103000020E6100000010000000500000075E95F92CA4845408E23D6E2534E4B4075E95F92CA4845403A94A12AA6504B40629E95B4E24B45403A94A12AA6504B40629E95B4E24B45408E23D6E2534E4B4075E95F92CA4845408E23D6E2534E4B40
5424	Котелино	1	12	725	42.375742000000002	42.424359000000003	54.408230000000003	54.393109000000003	0103000020E61000000100000005000000E8DD585018304540B3614D6551324B40E8DD585018304540809F71E140344B40B3614D6551364540809F71E140344B40B3614D6551364540B3614D6551324B40E8DD585018304540B3614D6551324B40
5724	Кадом	1	12	725	42.43318	42.496592	54.589649000000001	54.539208000000002	0103000020E6100000010000000500000001A4367172374540ECDE8AC404454B4001A43671723745403F8F519E794B4B4045BA9F53903F45403F8F519E794B4B4045BA9F53903F4540ECDE8AC404454B4001A4367172374540ECDE8AC404454B40
5650	Заулки	1	12	725	42.569913	42.596331999999997	54.671722000000003	54.658093999999998	0103000020E610000001000000050000005A48C0E8F2484540CFD8976C3C544B405A48C0E8F24845407A008BFCFA554B4075C7629B544C45407A008BFCFA554B4075C7629B544C4540CFD8976C3C544B405A48C0E8F2484540CFD8976C3C544B40
5214	Енкаево	1	12	725	42.423388000000003	42.440438	54.668909999999997	54.654468999999999	0103000020E610000001000000050000006AC2F69331364540779FE3A3C5534B406AC2F69331364540D2FBC6D79E554B4034F5BA4560384540D2FBC6D79E554B4034F5BA4560384540779FE3A3C5534B406AC2F69331364540779FE3A3C5534B40
5434	Дарьино	1	12	725	42.350211999999999	42.372661000000001	54.398482000000001	54.387694000000003	0103000020E6100000010000000500000058552FBFD32C45407F6DFDF49F314B4058552FBFD32C4540B8054B7501334B4051BF0B5BB32F4540B8054B7501334B4051BF0B5BB32F45407F6DFDF49F314B4058552FBFD32C45407F6DFDF49F314B40
5053	Восход	1	12	725	42.097147	42.126873000000003	54.591704999999997	54.562789000000002	0103000020E61000000100000005000000C7F319506F0C454037C64E7809484B40C7F319506F0C454099F04BFDBC4B4B406ADFDC5F3D10454099F04BFDBC4B4B406ADFDC5F3D10454037C64E7809484B40C7F319506F0C454037C64E7809484B40
3932	Федоровское	1	12	401	39.43817	39.483733000000001	54.401732000000003	54.384118000000001	0103000020E610000001000000050000004E0B5EF415B8434008E753C72A314B404E0B5EF415B84340DBE044F46B334B407C7F83F6EABD4340DBE044F46B334B407C7F83F6EABD434008E753C72A314B404E0B5EF415B8434008E753C72A314B40
4311	Субботино	1	12	401	39.153359000000002	39.175511999999998	54.437035999999999	54.427525000000003	0103000020E610000001000000050000000DC68844A1934340789CA223B9364B400DC68844A19343405B96AFCBF0374B401C075E2D779643405B96AFCBF0374B401C075E2D77964340789CA223B9364B400DC68844A1934340789CA223B9364B40
4757	Старое Зимино	1	12	401	39.217598000000002	39.243622000000002	54.549312999999998	54.534061999999999	0103000020E6100000010000000500000067D65240DA9B4340A704C4245C444B4067D65240DA9B434042226DE34F464B40064B75012F9F434042226DE34F464B40064B75012F9F4340A704C4245C444B4067D65240DA9B4340A704C4245C444B40
54643	Совхоз Смена	1	12	401	39.272430999999997	39.298211999999999	54.304358000000001	54.292478000000003	0103000020E6100000010000000500000052B5DD04DFA2434056664AEB6F254B4052B5DD04DFA243405323F433F5264B402BA391CF2BA643405323F433F5264B402BA391CF2BA6434056664AEB6F254B4052B5DD04DFA2434056664AEB6F254B40
4753	Пупкино	1	12	401	39.297699999999999	39.318720999999996	54.48603	54.467877000000001	0103000020E6100000010000000500000075029A081BA643407AC6BE64E33B4B4075029A081BA64340FC6F253B363E4B4032C687D9CBA84340FC6F253B363E4B4032C687D9CBA843407AC6BE64E33B4B4075029A081BA643407AC6BE64E33B4B40
4161	Поливаново	1	12	401	38.907131	38.929004999999997	54.474286999999997	54.458289999999998	0103000020E6100000010000000500000009185DDE1C744340BB0A293FA93A4B4009185DDE1C7443407FF5B86FB53C4B400569C6A2E97643407FF5B86FB53C4B400569C6A2E9764340BB0A293FA93A4B4009185DDE1C744340BB0A293FA93A4B40
4689	Плахино	1	12	401	39.318128000000002	39.355741000000002	54.473689999999998	54.45158	0103000020E6100000010000000500000090F8156BB8A843408BC3995FCD394B4090F8156BB8A843409B38B9DFA13C4B40556CCCEB88AD43409B38B9DFA13C4B40556CCCEB88AD43408BC3995FCD394B4090F8156BB8A843408BC3995FCD394B40
4307	Остроухово	1	12	401	39.071216999999997	39.097977999999998	54.423895000000002	54.409818000000001	0103000020E61000000100000005000000A9F57EA31D894340F4A78DEA74344B40A9F57EA31D8943400EF8FC3042364B401EDD088B8A8C43400EF8FC3042364B401EDD088B8A8C4340F4A78DEA74344B40A9F57EA31D894340F4A78DEA74344B40
4037	Осово	1	12	401	38.821935000000003	38.841876999999997	54.505848	54.494700999999999	0103000020E610000001000000050000000938842A356943403526C45C523F4B400938842A356943409E5F94A0BF404B40962023A0C26B43409E5F94A0BF404B40962023A0C26B43403526C45C523F4B400938842A356943403526C45C523F4B40
4101	Окуньково	1	12	401	38.894680000000001	38.914406999999997	54.522165000000001	54.511211000000003	0103000020E610000001000000050000005131CEDF84724340802DAF5C6F414B405131CEDF84724340D40E7F4DD6424B40E21DE0490B754340D40E7F4DD6424B40E21DE0490B754340802DAF5C6F414B405131CEDF84724340802DAF5C6F414B40
4533	Катагоща	1	12	401	39.226500000000001	39.252048000000002	54.378109000000002	54.365186000000001	0103000020E61000000100000005000000A245B6F3FD9C4340817A336ABE2E4B40A245B6F3FD9C434061A92EE065304B40D882DE1B43A0434061A92EE065304B40D882DE1B43A04340817A336ABE2E4B40A245B6F3FD9C4340817A336ABE2E4B40
4419	Захарово	1	12	401	39.260717	39.299703999999998	54.384118000000001	54.352825000000003	0103000020E610000001000000050000007041B62C5FA14340091B9E5E292D4B407041B62C5FA1434008E753C72A314B407D3D5FB35CA6434008E753C72A314B407D3D5FB35CA64340091B9E5E292D4B407041B62C5FA14340091B9E5E292D4B40
54681	Жонино	1	12	401	39.180371000000001	39.208874999999999	54.338324	54.323340000000002	0103000020E61000000100000005000000CB129D65169743408CBE823463294B40CB129D6516974340D8B969334E2B4B40DBF97E6ABC9A4340D8B969334E2B4B40DBF97E6ABC9A43408CBE823463294B40CB129D65169743408CBE823463294B40
4367	Елино	1	12	401	39.363610000000001	39.406100000000002	54.417870999999998	54.400227999999998	0103000020E61000000100000005000000D13FC1C58AAE4340C478CDAB3A334B40D13FC1C58AAE4340317903CC7C354B40EB73B515FBB34340317903CC7C354B40EB73B515FBB34340C478CDAB3A334B40D13FC1C58AAE4340C478CDAB3A334B40
4213	Добрые Пчелы	1	12	401	39.247259999999997	39.286624000000003	54.405678000000002	54.388375000000003	0103000020E61000000100000005000000F2CD3637A69F4340C1CAA145B6314B40F2CD3637A69F4340755AB741ED334B40D61F6118B0A44340755AB741ED334B40D61F6118B0A44340C1CAA145B6314B40F2CD3637A69F4340C1CAA145B6314B40
3991	Большое Коровино	1	12	401	39.012683000000003	39.037233999999998	54.520623999999998	54.498711999999998	0103000020E610000001000000050000008B1BB7989F814340B60F79CBD53F4B408B1BB7989F814340A0C1A6CEA3424B404E266E15C4844340A0C1A6CEA3424B404E266E15C4844340B60F79CBD53F4B408B1BB7989F814340B60F79CBD53F4B40
2112	Безлычное 3-е	1	12	401	39.449201000000002	39.479097000000003	54.444313999999999	54.429043999999998	0103000020E610000001000000050000004E2A1A6B7FB94340C345EEE9EA364B404E2A1A6B7FB94340D593F947DF384B404D4EED0C53BD4340D593F947DF384B404D4EED0C53BD4340C345EEE9EA364B404E2A1A6B7FB94340C345EEE9EA364B40
4856	Альяшево	1	12	401	39.311219999999999	39.324829999999999	54.551982000000002	54.542467000000002	0103000020E6100000010000000500000039EE940ED6A743406214048F6F454B4039EE940ED6A7434087FD9E58A7464B403D61890794A9434087FD9E58A7464B403D61890794A943406214048F6F454B4039EE940ED6A743406214048F6F454B40
3829	Царево	1	12	388	42.205269000000001	42.229827999999998	54.71696	54.696672999999997	0103000020E61000000100000005000000FAF02C41461A4540CB80B3942C594B40FAF02C41461A454024456458C55B4B4040DAFF006B1D454024456458C55B4B4040DAFF006B1D4540CB80B3942C594B40FAF02C41461A4540CB80B3942C594B40
2004	Турмадеево	1	12	388	42.359400999999998	42.375211999999998	54.722638000000003	54.710957999999998	0103000020E6100000010000000500000029931ADA002E45402F6AF7AB005B4B4029931ADA002E4540666CE8667F5C4B408B8862F206304540666CE8667F5C4B408B8862F2063045402F6AF7AB005B4B4029931ADA002E45402F6AF7AB005B4B40
3742	Торопово	1	12	388	42.089134000000001	42.117502999999999	54.625103000000003	54.605646	0103000020E61000000100000005000000187B2FBE680B4540037AE1CE854D4B40187B2FBE680B4540D5D0066003504B4048179B560A0F4540D5D0066003504B4048179B560A0F4540037AE1CE854D4B40187B2FBE680B4540037AE1CE854D4B40
54679	Спас-Раменье	1	12	388	42.228185000000003	42.245423000000002	54.898933999999997	54.876143999999996	0103000020E610000001000000050000000938842A351D4540164B917C25704B400938842A351D454098A1F14410734B40D65757056A1F454098A1F14410734B40D65757056A1F4540164B917C25704B400938842A351D4540164B917C25704B40
3596	Свестур	1	12	388	42.151316000000001	42.171194999999997	54.833775000000003	54.817402000000001	0103000020E6100000010000000500000047AE9B525E134540AED7F4A0A0684B4047AE9B525E134540789CA223B96A4B408E1EBFB7E9154540789CA223B96A4B408E1EBFB7E9154540AED7F4A0A0684B4047AE9B525E134540AED7F4A0A0684B40
3603	Савватьма	1	12	388	42.150516000000003	42.193860000000001	54.709038999999997	54.698706999999999	0103000020E610000001000000050000002BC3B81B441345403E3E213B6F594B402BC3B81B44134540554B3ACAC15A4B4054008C67D0184540554B3ACAC15A4B4054008C67D01845403E3E213B6F594B402BC3B81B441345403E3E213B6F594B40
3539	Нарма	1	12	388	41.986376	42.022677000000002	54.762380999999998	54.745790999999997	0103000020E6100000010000000500000097C79A9141FE444058535914765F4B4097C79A9141FE4440BF0B5BB395614B408AAF7614E7024540BF0B5BB395614B408AAF7614E702454058535914765F4B4097C79A9141FE444058535914765F4B40
3484	Надежка	1	12	388	42.267395999999998	42.302520000000001	54.752817	54.736514	0103000020E61000000100000005000000658A39083A224540E8853B17465E4B40658A39083A224540B96FB54E5C604B406631B1F9B8264540B96FB54E5C604B406631B1F9B8264540E8853B17465E4B40658A39083A224540E8853B17465E4B40
3425	Мердушь	1	12	388	42.281356000000002	42.307181999999997	54.877853000000002	54.855221999999998	0103000020E610000001000000050000004644317903244540EC681CEA776D4B40464431790324454006D9B27C5D704B40BEF561BD5127454006D9B27C5D704B40BEF561BD51274540EC681CEA776D4B404644317903244540EC681CEA776D4B40
3378	Кафтейка	1	12	388	42.386566999999999	42.397418000000002	54.769891999999999	54.758952999999998	0103000020E610000001000000050000003E5B07077B314540BD19355F25614B403E5B07077B314540DCB930D28B624B40BE6BD097DE324540DCB930D28B624B40BE6BD097DE324540BD19355F25614B403E5B07077B314540BD19355F25614B40
3320	Игошино	1	12	388	41.933582000000001	41.949168	54.817644999999999	54.808487999999997	0103000020E6100000010000000500000030116F9D7FF74440AE9AE7887C674B4030116F9D7FF74440745E6397A8684B40723447567EF94440745E6397A8684B40723447567EF94440AE9AE7887C674B4030116F9D7FF74440AE9AE7887C674B40
3159	Ермишь	1	12	388	42.225022000000003	42.295864000000002	54.783726000000001	54.756745000000002	0103000020E61000000100000005000000B5705985CD1C4540AD342905DD604B40B5705985CD1C45403083312251644B4029081EDFDE2545403083312251644B4029081EDFDE254540AD342905DD604B40B5705985CD1C4540AD342905DD604B40
3089	Гремячий Ключ	1	12	388	42.020879999999998	42.044846999999997	54.728783999999997	54.716985999999999	0103000020E61000000100000005000000FB912232AC0245404DD87E32C65B4B40FB912232AC0245408DEC4ACB485D4B406F29E78BBD0545408DEC4ACB485D4B406F29E78BBD0545404DD87E32C65B4B40FB912232AC0245404DD87E32C65B4B40
3029	Власово	1	12	388	42.149617999999997	42.184714999999997	54.733905	54.721156000000001	0103000020E610000001000000050000004B72C0AE2613454037A8FDD64E5C4B404B72C0AE2613454079AF5A99F05D4B40520ABABDA417454079AF5A99F05D4B40520ABABDA417454037A8FDD64E5C4B404B72C0AE2613454037A8FDD64E5C4B40
2967	Большое Ляхово	1	12	388	42.095854000000003	42.122470999999997	54.655828999999997	54.639648000000001	0103000020E610000001000000050000006C98A1F1440C4540D57954FCDF514B406C98A1F1440C45405A626534F2534B40ADDA3521AD0F45405A626534F2534B40ADDA3521AD0F4540D57954FCDF514B406C98A1F1440C4540D57954FCDF514B40
2918	Азеево	1	12	388	42.011915000000002	42.045071999999998	54.684157999999996	54.654843999999997	0103000020E610000001000000050000007AAA436E86014540ACFD9DEDD1534B407AAA436E86014540FCA5457D92574B408FFB56EBC4054540FCA5457D92574B408FFB56EBC4054540ACFD9DEDD1534B407AAA436E86014540ACFD9DEDD1534B40
54364	с.Отрадинское	1	11	\N	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
54569	железнодорожная станция Стальной Конь	1	11	\N	36.068579999999997	36.200381	53.077339000000002	52.997895	0103000020E610000001000000050000007094BC3AC7084240C4EBFA05BB7F4A407094BC3AC708424049DA8D3EE6894A40B1DEA815A619424049DA8D3EE6894A40B1DEA815A6194240C4EBFA05BB7F4A407094BC3AC7084240C4EBFA05BB7F4A40
54562	Хардикова	1	11	\N	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
39304	Старцево	1	11	\N	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
9161	Орел	1	11	\N	35.973565999999998	36.192557000000001	53.040787000000002	52.895389999999999	0103000020E61000000100000005000000AF3F89CF9DFC41402D95B7239C724A40AF3F89CF9DFC41400D8D278238854A40D5CE30B5A51842400D8D278238854A40D5CE30B5A51842402D95B7239C724A40AF3F89CF9DFC41402D95B7239C724A40
54594	Нижняя Лужна	1	11	\N	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
36621	Нижегородка	1	11	\N	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
54574	Нагорный	1	11	\N	37.577696000000003	37.588566	52.448146999999999	52.437508999999999	0103000020E61000000100000005000000D88349F1F1C94240535A7F4B00384A40D88349F1F1C94240776682E15C394A40CEC4742156CB4240776682E15C394A40CEC4742156CB4240535A7F4B00384A40D88349F1F1C94240535A7F4B00384A40
1325	Мценск	1	11	\N	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
54560	Малоархангельск	1	11	\N	36.472292000000003	36.518259	52.411242000000001	52.389994000000002	0103000020E61000000100000005000000CB147310743C424070D1C952EB314A40CB147310743C4240EE5EEE93A3344A40C8ED974F56424240EE5EEE93A3344A40C8ED974F5642424070D1C952EB314A40CB147310743C424070D1C952EB314A40
92	Ливны	1	11	\N	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
21308	Куликовский	1	11	\N	36.121544999999998	36.149869000000002	52.949877000000001	52.936061000000002	0103000020E6100000010000000500000004FF5BC98E0F4240D107CBD8D0774A4004FF5BC98E0F42407E1CCD9195794A4095D74AE82E1342407E1CCD9195794A4095D74AE82E134240D107CBD8D0774A4004FF5BC98E0F4240D107CBD8D0774A40
22250	Жилина	1	11	\N	36.055194999999998	36.080024999999999	53.009718999999997	52.992826999999998	0103000020E610000001000000050000008CF337A110074240FBCA83F4147F4A408CF337A1100742402D93E1783E814A4063EE5A423E0A42402D93E1783E814A4063EE5A423E0A4240FBCA83F4147F4A408CF337A110074240FBCA83F4147F4A40
60462	Биофабрика	1	11	\N	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
33719	Капитановка	1	11	2131	36.841895000000001	36.872501	52.100879999999997	52.090997999999999	0103000020E610000001000000050000003DD52137C36B42402E008DD2A50B4A403DD52137C36B42400569C6A2E90C4A40185DDE1CAE6F42400569C6A2E90C4A40185DDE1CAE6F42402E008DD2A50B4A403DD52137C36B42402E008DD2A50B4A40
27538	Шаблыкино	1	11	1822	35.173974999999999	35.268540999999999	52.885035000000002	52.841557999999999	0103000020E610000001000000050000002AA913D044964140F5D72B2CB86B4A402AA913D0449641405E68AED348714A404C512E8D5FA241405E68AED348714A404C512E8D5FA24140F5D72B2CB86B4A402AA913D044964140F5D72B2CB86B4A40
46037	Хотьково	1	11	1822	35.365243999999997	35.391402999999997	52.915177	52.901214000000003	0103000020E61000000100000005000000B587BD50C0AE41404359F8FA5A734A40B587BD50C0AE414094861A8524754A403447567E19B2414094861A8524754A403447567E19B241404359F8FA5A734A40B587BD50C0AE41404359F8FA5A734A40
46105	Титово	1	11	1822	35.167768000000002	35.192084999999999	52.770037000000002	52.761170999999997	0103000020E610000001000000050000005DA8FC6B79954140F1D4230D6E614A405DA8FC6B79954140E0DA899290624A40AD86C43D96984140E0DA899290624A40AD86C43D96984140F1D4230D6E614A405DA8FC6B79954140F1D4230D6E614A40
49193	Сомово	1	11	1822	34.926031000000002	34.988455000000002	52.865288999999997	52.843874999999997	0103000020E61000000100000005000000850A0E2F88764140BC749318046C4A40850A0E2F88764140554B3ACAC16E4A40AA4885B1857E4140554B3ACAC16E4A40AA4885B1857E4140BC749318046C4A40850A0E2F88764140BC749318046C4A40
27913	Сельстрой	1	11	1822	35.349730999999998	35.364300999999998	52.934019999999997	52.924857000000003	0103000020E61000000100000005000000DDB243FCC3AC4140043DD4B661764A40DDB243FCC3AC4140ABE7A4F78D774A403673486AA1AE4140ABE7A4F78D774A403673486AA1AE4140043DD4B661764A40DDB243FCC3AC4140043DD4B661764A40
45945	Рядовичи	1	11	1822	34.888832000000001	34.914515000000002	52.861618999999997	52.837466999999997	0103000020E61000000100000005000000B3D1393FC5714140573D601E326B4A40B3D1393FC57141405D4E0988496E4A40C959D8D30E7541405D4E0988496E4A40C959D8D30E754140573D601E326B4A40B3D1393FC5714140573D601E326B4A40
28054	Робье	1	11	1822	35.224730000000001	35.246172999999999	52.796360999999997	52.787047999999999	0103000020E610000001000000050000000D37E0F3C39C4140EC3026FDBD644A400D37E0F3C39C4140A9674128EF654A404014CC98829F4140A9674128EF654A404014CC98829F4140EC3026FDBD644A400D37E0F3C39C4140EC3026FDBD644A40
27872	Навля	1	11	1822	35.156018000000003	35.167740999999999	52.943350000000002	52.925547000000002	0103000020E610000001000000050000002ECBD765F893414099F4F75278764A402ECBD765F89341403F575BB1BF784A4063997E89789541403F575BB1BF784A4063997E897895414099F4F75278764A402ECBD765F893414099F4F75278764A40
28018	Молодовое	1	11	1822	35.267975	35.298544999999997	52.876840000000001	52.859357000000003	0103000020E61000000100000005000000A3923A014DA241405A4B0169FF6D4A40A3923A014DA241408EE9094B3C704A4031B1F9B836A641408EE9094B3C704A4031B1F9B836A641405A4B0169FF6D4A40A3923A014DA241405A4B0169FF6D4A40
27703	Косуличи	1	11	1822	35.027379000000003	35.058864999999997	52.858221	52.845517999999998	0103000020E6100000010000000500000071CCB22781834140F4160FEF396C4A4071CCB22781834140C6DE8B2FDA6D4A4084F068E388874140C6DE8B2FDA6D4A4084F068E388874140F4160FEF396C4A4071CCB22781834140F4160FEF396C4A40
46132	Герасимово	1	11	1822	35.105901000000003	35.137602000000001	52.808827999999998	52.792810000000003	0103000020E610000001000000050000008ECEF9298E8D41408CF84ECC7A654A408ECEF9298E8D4140670B08AD87674A409EEE3CF19C914140670B08AD87674A409EEE3CF19C9141408CF84ECC7A654A408ECEF9298E8D41408CF84ECC7A654A40
54637	Высокое	1	11	1822	35.092695999999997	35.116689999999998	52.854022999999998	52.841493	0103000020E61000000100000005000000293C6876DD8B41400E68E90AB66B4A40293C6876DD8B414012842BA0506D4A4097E2AAB2EF8E414012842BA0506D4A4097E2AAB2EF8E41400E68E90AB66B4A40293C6876DD8B41400E68E90AB66B4A40
27121	Хотынец	1	11	570	35.375081000000002	35.407626999999998	53.144970999999998	53.114075999999997	0103000020E61000000100000005000000ED2C7AA702B0414016A1D80A9A8E4A40ED2C7AA702B0414028EFE3688E924A40B9FB1C1F2DB4414028EFE3688E924A40B9FB1C1F2DB4414016A1D80A9A8E4A40ED2C7AA702B0414016A1D80A9A8E4A40
54578	Хотимль Кузьменово	1	11	570	35.304032999999997	35.325817000000001	53.204535999999997	53.194648000000001	0103000020E61000000100000005000000CFF3A78DEAA64140AC1DC539EA984A40CFF3A78DEAA64140656D533C2E9A4A408CBD175FB4A94140656D533C2E9A4A408CBD175FB4A94140AC1DC539EA984A40CFF3A78DEAA64140AC1DC539EA984A40
49390	Мощеное	1	11	570	35.449964999999999	35.478118000000002	53.171061000000002	53.156506	0103000020E610000001000000050000001DACFF7398B941405BD07B6308944A401DACFF7398B941407F4FAC53E5954A4081D07AF832BD41407F4FAC53E5954A4081D07AF832BD41405BD07B6308944A401DACFF7398B941405BD07B6308944A40
45557	Льгов	1	11	570	35.399264000000002	35.437047	53.289065999999998	53.278298999999997	0103000020E610000001000000050000002E3C2F151BB3414037C1374D9FA34A402E3C2F151BB3414059315C1D00A54A404FE8F527F1B7414059315C1D00A54A404FE8F527F1B7414037C1374D9FA34A402E3C2F151BB3414037C1374D9FA34A40
60451	Кукуевка	1	11	570	35.367975000000001	35.388924000000003	53.115687000000001	53.103459000000001	0103000020E61000000100000005000000705F07CE19AF41400ABDFE243E8D4A40705F07CE19AF414043C9E4D4CE8E4A409450FA42C8B1414043C9E4D4CE8E4A409450FA42C8B141400ABDFE243E8D4A40705F07CE19AF41400ABDFE243E8D4A40
26921	Красные Рябинки	1	11	570	35.527380999999998	35.556944999999999	53.107444000000001	53.096494999999997	0103000020E6100000010000000500000011C4793881C341401F9DBAF2598C4A4011C4793881C34140621399B9C08D4A40DA5548F949C74140621399B9C08D4A40DA5548F949C741401F9DBAF2598C4A4011C4793881C341401F9DBAF2598C4A40
47187	Клейменово	1	11	570	35.359135999999999	35.391134000000001	53.169753999999998	53.161856999999998	0103000020E610000001000000050000007B681F2BF8AD414078D0ECBAB7944A407B681F2BF8AD4140BE2EC37FBA954A40452DCDAD10B24140BE2EC37FBA954A40452DCDAD10B2414078D0ECBAB7944A407B681F2BF8AD414078D0ECBAB7944A40
45586	Звезда	1	11	570	35.322332000000003	35.340235	53.103940999999999	53.092278	0103000020E61000000100000005000000263ACB2C42A94140F511F8C3CF8B4A40263ACB2C42A9414055DB4DF04D8D4A402FFA0AD28CAB414055DB4DF04D8D4A402FFA0AD28CAB4140F511F8C3CF8B4A40263ACB2C42A94140F511F8C3CF8B4A40
27098	Жудерский	1	11	570	35.283076000000001	35.295651999999997	53.260382	53.253734000000001	0103000020E61000000100000005000000292499D53BA441400FF10F5B7AA04A40292499D53BA44140C93B873254A14A409D7FBBECD7A54140C93B873254A14A409D7FBBECD7A541400FF10F5B7AA04A40292499D53BA441400FF10F5B7AA04A40
45441	Воейково	1	11	570	35.349649999999997	35.375045	53.144755000000004	53.137230000000002	0103000020E61000000100000005000000F085C954C1AC4140DA03ADC090914A40F085C954C1AC41405C77F35487924A40A0C37C7901B041405C77F35487924A40A0C37C7901B04140DA03ADC090914A40F085C954C1AC4140DA03ADC090914A40
3545	Верховье	1	11	570	35.300314	35.310051999999999	53.314647999999998	53.310634999999998	0103000020E61000000100000005000000F6436CB070A6414019FF3EE3C2A74A40F6436CB070A641403BE0BA6246A84A409A07B0C8AFA741403BE0BA6246A84A409A07B0C8AFA7414019FF3EE3C2A74A40F6436CB070A6414019FF3EE3C2A74A40
54582	Большое Юрьево	1	11	570	35.224406999999999	35.244698999999997	53.156441000000001	53.148319000000001	0103000020E610000001000000050000002AFF5A5EB99C41400E30F31DFC924A402AFF5A5EB99C41407460394206944A40942EFD4B529F41407460394206944A40942EFD4B529F41400E30F31DFC924A402AFF5A5EB99C41400E30F31DFC924A40
45489	Богородицкое	1	11	570	35.346631000000002	35.370769000000003	53.069673000000002	53.046486999999999	0103000020E61000000100000005000000D06394675EAC414036583849F3854A40D06394675EAC414005357C0BEB884A4071AFCC5B75AF414005357C0BEB884A4071AFCC5B75AF414036583849F3854A40D06394675EAC414036583849F3854A40
26638	Алехино	1	11	570	35.214390000000002	35.239336999999999	53.230049999999999	53.216605000000001	0103000020E61000000100000005000000734BAB21719B414036936FB6B99B4A40734BAB21719B4140EF384547729D4A4083DC4598A29E4140EF384547729D4A4083DC4598A29E414036936FB6B99B4A40734BAB21719B414036936FB6B99B4A40
49594	Ясная Поляна	1	11	509	35.782144000000002	35.797441999999997	52.905841000000002	52.903055000000002	0103000020E610000001000000050000009E616A4B1DE44140A1BE654E97734A409E616A4B1DE441401F300F99F2734A40793A579412E641401F300F99F2734A40793A579412E64140A1BE654E97734A409E616A4B1DE44140A1BE654E97734A40
60419	Юшково	1	11	509	35.719467999999999	35.741252000000003	53.133459000000002	53.121929000000002	0103000020E610000001000000050000005F42058717DC41408DB7955E9B8F4A405F42058717DC4140AE2D3C2F15914A401C0C7558E1DE4140AE2D3C2F15914A401C0C7558E1DE41408DB7955E9B8F4A405F42058717DC41408DB7955E9B8F4A40
25734	Юшино	1	11	509	35.607483999999999	35.621730999999997	53.019188999999997	53.007199999999997	0103000020E61000000100000005000000F06B2409C2CD4140FE43FAEDEB804A40F06B2409C2CD4140B2B8FFC874824A4066F4A3E194CF4140B2B8FFC874824A4066F4A3E194CF4140FE43FAEDEB804A40F06B2409C2CD4140FE43FAEDEB804A40
3107	Черногрязка	1	11	509	35.654888	35.669755000000002	53.119005000000001	53.111828000000003	0103000020E610000001000000050000007C45B75ED3D3414078634161508E4A407C45B75ED3D34140BE874B8E3B8F4A408FAA2688BAD54140BE874B8E3B8F4A408FAA2688BAD5414078634161508E4A407C45B75ED3D3414078634161508E4A40
49123	Совхозный	1	11	509	35.620204000000001	35.641987999999998	53.022227999999998	53.010731999999997	0103000020E61000000100000005000000986C3CD862CF4140A5828AAA5F814A40986C3CD862CF41401A87FA5DD8824A405436ACA92CD241401A87FA5DD8824A405436ACA92CD24140A5828AAA5F814A40986C3CD862CF4140A5828AAA5F814A40
26355	Себякино	1	11	509	35.725262000000001	35.773169000000003	52.831189000000002	52.821373000000001	0103000020E610000001000000050000000A849D62D5DC4140A1681EC022694A400A849D62D5DC4140C1E5B166646A4A40F9A3A833F7E24140C1E5B166646A4A40F9A3A833F7E24140A1681EC022694A400A849D62D5DC4140A1681EC022694A40
49519	Прогресс	1	11	509	35.750064999999999	35.754547000000002	52.861255	52.856741999999997	0103000020E61000000100000005000000E76F422102E04140088ECBB8A96D4A40E76F422102E041401C42959A3D6E4A40C02500FF94E041401C42959A3D6E4A40C02500FF94E04140088ECBB8A96D4A40E76F422102E04140088ECBB8A96D4A40
26374	Подзавалово	1	11	509	35.669781999999998	35.681182	53.058275999999999	53.050812999999998	0103000020E6100000010000000500000088B9A46ABBD54140179B560A81864A4088B9A46ABBD541402312859675874A40DB4FC6F830D741402312859675874A40DB4FC6F830D74140179B560A81864A4088B9A46ABBD54140179B560A81864A40
49484	Парамоново	1	11	509	35.694225000000003	35.741405	53.169474000000001	53.15211	0103000020E610000001000000050000006688635DDCD8414081B2295778934A406688635DDCD84140DBC2F352B1954A40A20BEA5BE6DE4140DBC2F352B1954A40A20BEA5BE6DE414081B2295778934A406688635DDCD8414081B2295778934A40
26081	Муравлево	1	11	509	35.451994999999997	35.476680000000002	52.941319999999997	52.933016000000002	0103000020E610000001000000050000004E7ADFF8DAB9414087527B116D774A404E7ADFF8DAB941400D897B2C7D784A402254A9D903BD41400D897B2C7D784A402254A9D903BD414087527B116D774A404E7ADFF8DAB9414087527B116D774A40
26260	Максимовский	1	11	509	35.808050999999999	35.834426000000001	52.942405000000001	52.936934999999998	0103000020E61000000100000005000000034015376EE7414027BD6F7CED774A40034015376EE741401F4B1FBAA0784A404F779E78CEEA41401F4B1FBAA0784A404F779E78CEEA414027BD6F7CED774A40034015376EE7414027BD6F7CED774A40
54668	Лески	1	11	509	35.601123999999999	35.608849999999997	52.879606000000003	52.876193000000001	0103000020E610000001000000050000009C6B98A1F1CC4140F8FD9B1727704A409C6B98A1F1CC4140C5AEEDED96704A40B515FBCBEECD4140C5AEEDED96704A40B515FBCBEECD4140F8FD9B1727704A409C6B98A1F1CC4140F8FD9B1727704A40
26197	Ледно	1	11	509	35.786096000000001	35.816701999999999	52.962626	52.951797999999997	0103000020E610000001000000050000001AC231CB9EE44140F8325184D4794A401AC231CB9EE44140C0232A54377B4A40F549EEB089E84140C0232A54377B4A40F549EEB089E84140F8325184D4794A401AC231CB9EE44140F8325184D4794A40
48817	Кошелево	1	11	509	35.679727	35.717554999999997	52.995742999999997	52.988154999999999	0103000020E61000000100000005000000A69A594B01D741407F30F0DC7B7E4A40A69A594B01D74140471CB281747F4A40670A9DD7D8DB4140471CB281747F4A40670A9DD7D8DB41407F30F0DC7B7E4A40A69A594B01D741407F30F0DC7B7E4A40
49512	Городище	1	11	509	35.549551999999998	35.592590000000001	52.953572000000001	52.942590000000003	0103000020E61000000100000005000000C7B94DB857C64140B1C403CAA6784A40C7B94DB857C64140CF30B5A50E7A4A40E4F736FDD9CB4140CF30B5A50E7A4A40E4F736FDD9CB4140B1C403CAA6784A40C7B94DB857C64140B1C403CAA6784A40
25795	Бунинский	1	11	509	35.512757000000001	35.526088000000001	52.986144000000003	52.976959000000001	0103000020E61000000100000005000000C5E57805A2C14140354415FE0C7D4A40C5E57805A2C14140C59272F7397E4A40B66801DA56C34140C59272F7397E4A40B66801DA56C34140354415FE0C7D4A40C5E57805A2C14140354415FE0C7D4A40
49470	Бунино	1	11	509	35.519233999999997	35.649894000000003	53.138790999999998	52.967686	0103000020E61000000100000005000000527C7C4276C2414006668522DD7B4A40527C7C4276C2414054FD4AE7C3914A40EEEE01BA2FD3414054FD4AE7C3914A40EEEE01BA2FD3414006668522DD7B4A40527C7C4276C2414006668522DD7B4A40
26177	Большое Сотниково	1	11	509	35.811725000000003	35.824814000000003	53.044803999999999	53.025613	0103000020E610000001000000050000003D2CD49AE6E741401DAD6A4947834A403D2CD49AE6E74140705D3123BC854A4038A4518193E94140705D3123BC854A4038A4518193E941401DAD6A4947834A403D2CD49AE6E741401DAD6A4947834A40
25297	Чермошное	1	11	1495	35.795617999999997	35.810279000000001	52.331009000000002	52.314996999999998	0103000020E61000000100000005000000F10D85CFD6E5414047AB5AD251284A40F10D85CFD6E5414041D7BE805E2A4A405BD1E638B7E7414041D7BE805E2A4A405BD1E638B7E7414047AB5AD251284A40F10D85CFD6E5414047AB5AD251284A40
49317	Турейка	1	11	1495	35.940354999999997	35.971229999999998	52.392114999999997	52.37276	0103000020E61000000100000005000000A6D0798D5DF84140E4A08499B62F4A40A6D0798D5DF84140B1A206D330324A407172BF4351FC4140B1A206D330324A407172BF4351FC4140E4A08499B62F4A40A6D0798D5DF84140E4A08499B62F4A40
54567	Тросна	1	11	1495	35.759928000000002	35.797936	52.461109999999998	52.432358999999998	0103000020E6100000010000000500000048A8195245E14140CD902A8A57374A4048A8195245E14140E5ED08A7053B4A40892650C422E64140E5ED08A7053B4A40892650C422E64140CD902A8A57374A4048A8195245E14140CD902A8A57374A40
25019	Нижнее Муханово	1	11	1495	35.770555000000002	35.786805999999999	52.500649000000003	52.481428999999999	0103000020E610000001000000050000007862D68BA1E24140492C29779F3D4A407862D68BA1E2414037E3344415404A40F6251B0FB6E4414037E3344415404A40F6251B0FB6E44140492C29779F3D4A407862D68BA1E24140492C29779F3D4A40
25309	Муравль	1	11	1495	35.879449000000001	35.895950999999997	52.368279000000001	52.350701999999998	0103000020E61000000100000005000000FDBFEAC891F0414026529ACDE32C4A40FDBFEAC891F04140DC662AC4232F4A40C4E8B985AEF24140DC662AC4232F4A40C4E8B985AEF2414026529ACDE32C4A40FDBFEAC891F0414026529ACDE32C4A40
25121	Ломовец	1	11	1495	35.642823999999997	35.715273000000003	52.508640999999997	52.491311000000003	0103000020E61000000100000005000000BD8A8C0E48D2414021956247E33E4A40BD8A8C0E48D24140CE33F6251B414A401D5BCF108EDB4140CE33F6251B414A401D5BCF108EDB414021956247E33E4A40BD8A8C0E48D2414021956247E33E4A40
24927	Ладарево	1	11	1495	35.650351999999998	35.662030000000001	52.441071999999998	52.436042999999998	0103000020E61000000100000005000000B071FDBB3ED341402A53CC41D0374A40B071FDBB3ED3414035971B0C75384A40467C2766BDD4414035971B0C75384A40467C2766BDD441402A53CC41D0374A40B071FDBB3ED341402A53CC41D0374A40
49280	Красноармейский	1	11	1495	35.807502999999997	35.830176000000002	52.362367999999996	52.349848999999999	0103000020E61000000100000005000000003620425CE74140E7C41EDAC72C4A40003620425CE74140F78E1A13622E4A4049F6083543EA4140F78E1A13622E4A4049F6083543EA4140E7C41EDAC72C4A40003620425CE74140E7C41EDAC72C4A40
25465	Красавка	1	11	1495	35.996229999999997	36.007162999999998	52.318685000000002	52.303952000000002	0103000020E61000000100000005000000A4A5F27684FF4140E3C62DE6E7264A40A4A5F27684FF4140E65C8AABCA284A40E15E99B7EA004240E65C8AABCA284A40E15E99B7EA004240E3C62DE6E7264A40A4A5F27684FF4140E3C62DE6E7264A40
25196	Колычевский	1	11	1495	35.711347000000004	35.724831000000002	52.308489000000002	52.301544999999997	0103000020E61000000100000005000000CA8D226B0DDB4140DBA2CC0699264A40CA8D226B0DDB41407F164B917C274A4041102043C7DC41407F164B917C274A4041102043C7DC4140DBA2CC0699264A40CA8D226B0DDB4140DBA2CC0699264A40
25626	Каменец	1	11	1495	35.914608999999999	35.949446000000002	52.490110999999999	52.471111999999998	0103000020E610000001000000050000004AD05FE811F541406760E4654D3C4A404AD05FE811F5414076340EF5BB3E4A40B5A84F7287F9414076340EF5BB3E4A40B5A84F7287F941406760E4654D3C4A404AD05FE811F541406760E4654D3C4A40
25070	Жизло-Павлово	1	11	1495	35.807153	35.837561000000001	52.519196000000001	52.502901999999999	0103000020E6100000010000000500000024EF1CCA50E74140E78BBD175F404A4024EF1CCA50E74140651BB80375424A40D9B3E73235EB4140651BB80375424A40D9B3E73235EB4140E78BBD175F404A4024EF1CCA50E74140E78BBD175F404A40
25523	Гнилец	1	11	1495	35.992502000000002	36.033492000000003	52.374107000000002	52.350856	0103000020E61000000100000005000000789B374E0AFF41407DCD72D9E82C4A40789B374E0AFF4140331AF9BCE22F4A40BD56427749044240331AF9BCE22F4A40BD564277490442407DCD72D9E82C4A40789B374E0AFF41407DCD72D9E82C4A40
49367	Воронец	1	11	1495	35.982081999999998	35.996383000000002	52.436883000000002	52.418025999999998	0103000020E61000000100000005000000C1FEEBDCB4FD414058703FE081354A40C1FEEBDCB4FD4140D5963AC8EB374A402BA5677A89FF4140D5963AC8EB374A402BA5677A89FF414058703FE081354A40C1FEEBDCB4FD414058703FE081354A40
17353	Бобрик	1	11	1495	36.052697999999999	36.079000999999998	52.342576000000001	52.338146999999999	0103000020E610000001000000050000004548DDCEBE064240C91EA166482B4A404548DDCEBE0642407F32C687D92B4A40F7AC6BB41C0A42407F32C687D92B4A40F7AC6BB41C0A4240C91EA166482B4A404548DDCEBE064240C91EA166482B4A40
60458	Хмелевая	1	11	1493	35.435690000000001	35.485053000000001	52.75159	52.731259999999999	0103000020E61000000100000005000000DD989EB0C4B74140BD6F7CED995D4A40DD989EB0C4B741401500E31934604A40D1E9793716BE41401500E31934604A40D1E9793716BE4140BD6F7CED995D4A40DD989EB0C4B74140BD6F7CED995D4A40
46399	Сосково	1	11	1493	35.368963000000001	35.398311	52.757978000000001	52.739657000000001	0103000020E610000001000000050000008F37F92D3AAF4140F5A0A014AD5E4A408F37F92D3AAF4140338B506C05614A408B51D7DAFBB24140338B506C05614A408B51D7DAFBB24140F5A0A014AD5E4A408F37F92D3AAF4140F5A0A014AD5E4A40
28241	Сковородовка	1	11	1493	35.499569000000001	35.518065999999997	52.856127999999998	52.841928000000003	0103000020E61000000100000005000000378C82E0F1BF414019CBF44BC46B4A40378C82E0F1BF41404E98309A956D4A40B39597FC4FC241404E98309A956D4A40B39597FC4FC2414019CBF44BC46B4A40378C82E0F1BF414019CBF44BC46B4A40
28552	Новогнездилово	1	11	1493	35.397700999999998	35.429850999999999	52.629114999999999	52.607371000000001	0103000020E61000000100000005000000124BCADDE7B24140F8C43A55BE4D4A40124BCADDE7B2414026361FD786504A409293895B05B7414026361FD786504A409293895B05B74140F8C43A55BE4D4A40124BCADDE7B24140F8C43A55BE4D4A40
28799	Мыцкое	1	11	1493	35.322933999999997	35.354348000000002	52.802491000000003	52.781281	0103000020E610000001000000050000001B62BCE655A941403BFE0B0401644A401B62BCE655A94140CC2A6C06B8664A4096B377465BAD4140CC2A6C06B8664A4096B377465BAD41403BFE0B0401644A401B62BCE655A941403BFE0B0401644A40
17299	Мураевка	1	11	1493	35.510492999999997	35.529690000000002	52.700896	52.692442999999997	0103000020E6100000010000000500000020EBA9D557C141400CACE3F8A1584A4020EBA9D557C14140D8F2CAF5B6594A405682C5E1CCC34140D8F2CAF5B6594A405682C5E1CCC341400CACE3F8A1584A4020EBA9D557C141400CACE3F8A1584A40
28502	Кирово	1	11	1493	35.415019999999998	35.444583999999999	52.673738999999998	52.664597000000001	0103000020E61000000100000005000000CC9717601FB541408602B68311554A40CC9717601FB5414016855D143D564A409529E620E8B8414016855D143D564A409529E620E8B841408602B68311554A40CC9717601FB541408602B68311554A40
54605	Гнилое Болото	1	11	1493	35.413303999999997	35.463726999999999	52.806176999999998	52.794133000000002	0103000020E610000001000000050000002AA73D25E7B4414052D66F26A6654A402AA73D25E7B44140C9E4D4CE30674A40D7A205685BBB4140C9E4D4CE30674A40D7A205685BBB414052D66F26A6654A402AA73D25E7B4414052D66F26A6654A40
46355	Волчьи Ямы	1	11	1493	35.350413000000003	35.371074	52.638773	52.633569999999999	0103000020E61000000100000005000000F08B4B55DAAC414005DD5ED218514A40F08B4B55DAAC4140AE484C50C3514A40AD32535A7FAF4140AE484C50C3514A40AD32535A7FAF414005DD5ED218514A40F08B4B55DAAC414005DD5ED218514A40
46137	Алмазово	1	11	1493	35.593308999999998	35.615524000000001	52.836134999999999	52.813851999999997	0103000020E6100000010000000500000013B69F8CF1CB414060E4654D2C684A4013B69F8CF1CB41403E05C078066B4A4099F38C7DC9CE41403E05C078066B4A4099F38C7DC9CE414060E4654D2C684A4013B69F8CF1CB414060E4654D2C684A40
24344	Хотетово	1	11	1212	36.289394999999999	36.309859000000003	52.793261999999999	52.766140999999998	0103000020E610000001000000050000001E5036E50A254240F78F85E810624A401E5036E50A2542406C94F59B89654A4086AFAF75A92742406C94F59B89654A4086AFAF75A9274240F78F85E810624A401E5036E50A254240F78F85E810624A40
45523	Троицкое	1	11	1212	36.160845999999999	36.185927	52.679259000000002	52.667945000000003	0103000020E61000000100000005000000A1D80A9A961442406C43C5387F554A40A1D80A9A96144240C0417BF5F1564A40C138B874CC174240C0417BF5F1564A40C138B874CC1742406C43C5387F554A40A1D80A9A961442406C43C5387F554A40
40293	Столбецкое	1	11	1212	36.568592000000002	36.614567000000001	52.635258999999998	52.608645000000003	0103000020E610000001000000050000003562669FC7484240DDEF5014E84D4A403562669FC7484240ADBEBA2A50514A40B519A721AA4E4240ADBEBA2A50514A40B519A721AA4E4240DDEF5014E84D4A403562669FC7484240DDEF5014E84D4A40
49113	Степановка	1	11	1212	36.485039	36.499053000000004	52.633082999999999	52.612062999999999	0103000020E610000001000000050000006C2409C2153E4240BB0B9414584E4A406C2409C2153E4240A8531EDD08514A4040FCFCF7E03F4240A8531EDD08514A4040FCFCF7E03F4240BB0B9414584E4A406C2409C2153E4240BB0B9414584E4A40
29243	Разбегаевка	1	11	1212	36.374366999999999	36.390940999999998	52.703018999999998	52.687551999999997	0103000020E61000000100000005000000CFD90242EB2F4240522635B401584A40CFD90242EB2F4240BABBCE86FC594A4030D5CC5A0A324240BABBCE86FC594A4030D5CC5A0A324240522635B401584A40CFD90242EB2F4240522635B401584A40
49026	Новопетровка	1	11	1212	36.415959000000001	36.442889999999998	52.758772999999998	52.736642000000003	0103000020E610000001000000050000000ABDFE243E354240166EF9484A5E4A400ABDFE243E3542403D0B42791F614A40DBDC989EB03842403D0B42791F614A40DBDC989EB0384240166EF9484A5E4A400ABDFE243E354240166EF9484A5E4A40
48913	Никольское	1	11	1212	36.048898000000001	36.080869	52.663378999999999	52.632865000000002	0103000020E610000001000000050000007F6B274A420642403BE466B801514A407F6B274A4206424035ED629AE9544A404F2157EA590A424035ED629AE9544A404F2157EA590A42403BE466B801514A407F6B274A420642403BE466B801514A40
23796	Нахлестово	1	11	1212	36.347372999999997	36.365689000000003	52.662078999999999	52.646439000000001	0103000020E61000000100000005000000B741EDB7762C4240F2ED5D83BE524A40B741EDB7762C4240272F3201BF544A40E4C0ABE5CE2E4240272F3201BF544A40E4C0ABE5CE2E4240F2ED5D83BE524A40B741EDB7762C4240F2ED5D83BE524A40
11892	Морозовский	1	11	1212	36.382119000000003	36.408934000000002	52.688507000000001	52.669288999999999	0103000020E6100000010000000500000012178046E930424049490F43AB554A4012178046E9304240960854FF20584A407A1C06F357344240960854FF20584A407A1C06F35734424049490F43AB554A4012178046E930424049490F43AB554A40
46230	Михайловка	1	11	1212	36.583019	36.603355999999998	52.673149000000002	52.667088	0103000020E610000001000000050000002BF9D85DA04A4240EBC6BB2363554A402BF9D85DA04A4240E52A16BF29564A4035ECF7C43A4D4240E52A16BF29564A4035ECF7C43A4D4240EBC6BB2363554A402BF9D85DA04A4240EBC6BB2363554A40
49137	Куракинский	1	11	1212	36.465913999999998	36.479182000000002	52.579543000000001	52.572707000000001	0103000020E61000000100000005000000D05FE811A33B42405B9885764E494A40D05FE811A33B424018D00B772E4A4A407B6AF5D5553D424018D00B772E4A4A407B6AF5D5553D42405B9885764E494A40D05FE811A33B42405B9885764E494A40
23942	Красная Рыбница	1	11	1212	36.246760999999999	36.273944	52.589374999999997	52.576582000000002	0103000020E61000000100000005000000D1764CDD951F42402CBB6070CD494A40D1764CDD951F42403D0AD7A3704B4A40BC77D498102342403D0AD7A3704B4A40BC77D498102342402CBB6070CD494A40D1764CDD951F42402CBB6070CD494A40
48788	Котовка	1	11	1212	36.388686	36.410325999999998	52.671424000000002	52.651203000000002	0103000020E61000000100000005000000DF347D76C03142404F07B29E5A534A40DF347D76C0314240F0DFBC38F1554A406859F78F85344240F0DFBC38F1554A406859F78F853442404F07B29E5A534A40DF347D76C03142404F07B29E5A534A40
23915	Козьминское	1	11	1212	36.161304000000001	36.188667000000002	52.656874000000002	52.640504999999997	0103000020E61000000100000005000000645B069CA514424055F65D11FC514A40645B069CA5144240DECB7D7214544A40CF6A813D26184240DECB7D7214544A40CF6A813D2618424055F65D11FC514A40645B069CA514424055F65D11FC514A40
49355	Знаменское	1	11	1212	36.025874000000002	36.064700000000002	52.598604000000002	52.587772000000001	0103000020E610000001000000050000008AE8D7D64F03424094C0E61C3C4B4A408AE8D7D64F0342409DA04D0E9F4C4A408E06F016480842409DA04D0E9F4C4A408E06F0164808424094C0E61C3C4B4A408AE8D7D64F03424094C0E61C3C4B4A40
24223	Змиево	1	11	1212	36.144362000000001	36.160406000000002	52.738185000000001	52.727043999999999	0103000020E6100000010000000500000080643A747A12424063601DC70F5D4A4080643A747A124240EAB298D87C5E4A40850A0E2F88144240EAB298D87C5E4A40850A0E2F8814424063601DC70F5D4A4080643A747A12424063601DC70F5D4A40
23615	Змиевка	1	11	1212	36.355915000000003	36.390419999999999	52.681480999999998	52.656426000000003	0103000020E61000000100000005000000F3936A9F8E2D42403F1F65C405544A40F3936A9F8E2D424035ECF7C43A574A4027DA5548F931424035ECF7C43A574A4027DA5548F93142403F1F65C405544A40F3936A9F8E2D42403F1F65C405544A40
24308	Еропкино-Большак	1	11	1212	36.290815000000002	36.309247999999997	52.756424000000003	52.742807999999997	0103000020E61000000100000005000000D717096D39254240849A2155145F4A40D717096D392542406BF46A80D2604A403C2D3F70952742406BF46A80D2604A403C2D3F7095274240849A2155145F4A40D717096D39254240849A2155145F4A40
24403	Гостиново	1	11	1212	36.325012999999998	36.343645000000002	52.768996000000001	52.750734000000001	0103000020E610000001000000050000002EE3A6069A29424065FF3C0D18604A402EE3A6069A2942409E60FF756E624A408B37328FFC2B42409E60FF756E624A408B37328FFC2B424065FF3C0D18604A402EE3A6069A29424065FF3C0D18604A40
24770	Борисоглебское	1	11	1212	36.371259000000002	36.398665999999999	52.588549	52.565109999999997	0103000020E610000001000000050000003FAC376A852F42403F52448655484A403FAC376A852F4240F88BD992554B4A407903CC7C07334240F88BD992554B4A407903CC7C073342403F52448655484A403FAC376A852F42403F52448655484A40
24681	Богодухово	1	11	1212	36.499152000000002	36.530521	52.696404999999999	52.677174000000001	0103000020E61000000100000005000000D3DD7536E43F4240CBD93BA3AD564A40D3DD7536E43F4240ACE28DCC23594A40AD6BB41CE8434240ACE28DCC23594A40AD6BB41CE8434240CBD93BA3AD564A40D3DD7536E43F4240CBD93BA3AD564A40
23255	Шалимовка	1	11	1470	36.914164999999997	37.179554000000003	52.542430000000003	52.506436999999998	0103000020E61000000100000005000000EC12D55B03754240FF3D78EDD2404A40EC12D55B03754240452FA3586E454A40D9EE1EA0FB964240452FA3586E454A40D9EE1EA0FB964240FF3D78EDD2404A40EC12D55B03754240FF3D78EDD2404A40
48359	Хаустово	1	11	1470	36.947671999999997	36.959879999999998	52.593653000000003	52.586480999999999	0103000020E61000000100000005000000DEAAEB504D794240D95C35CF114B4A40DEAAEB504D7942400E164ED2FC4B4A40D00A0C59DD7A42400E164ED2FC4B4A40D00A0C59DD7A4240D95C35CF114B4A40DEAAEB504D794240D95C35CF114B4A40
54654	Федоровка	1	11	1470	36.771116999999997	36.794319999999999	52.533261000000003	52.515300000000003	0103000020E61000000100000005000000DF313CF6B36242407DD0B359F5414A40DF313CF6B3624240BB9D7DE541444A4084471B47AC654240BB9D7DE541444A4084471B47AC6542407DD0B359F5414A40DF313CF6B36242407DD0B359F5414A40
49166	Успенское	1	11	1470	36.797815	36.826524999999997	52.713985999999998	52.691983999999998	0103000020E610000001000000050000000EA14ACD1E66424079AD84EE92584A400EA14ACD1E664240A3E6ABE4635B4A40C7293A92CB694240A3E6ABE4635B4A40C7293A92CB69424079AD84EE92584A400EA14ACD1E66424079AD84EE92584A40
60418	Троицкое	1	11	1470	36.681555000000003	36.691831999999998	52.580134000000001	52.576549	0103000020E6100000010000000500000070B6B9313D57424050C58D5BCC494A4070B6B9313D5742401AA6B6D4414A4A40C32973F38D5842401AA6B6D4414A4A40C32973F38D58424050C58D5BCC494A4070B6B9313D57424050C58D5BCC494A40
54658	Топки	1	11	1470	36.844248999999998	36.876130000000003	52.415213000000001	52.391274000000003	0103000020E610000001000000050000002157EA59106C424037E3344415324A402157EA59106C4240E1EF17B325354A40B285200725704240E1EF17B325354A40B28520072570424037E3344415324A402157EA59106C424037E3344415324A40
48488	Тимирязево	1	11	1470	36.683450000000001	36.719391999999999	52.629727000000003	52.609366999999999	0103000020E61000000100000005000000C139234A7B5742407D21E4BCFF4D4A40C139234A7B5742404034F3E49A504A4084807C09155C42404034F3E49A504A4084807C09155C42407D21E4BCFF4D4A40C139234A7B5742407D21E4BCFF4D4A40
48329	Тетерье	1	11	1470	36.845354	36.870336000000002	52.654536	52.622337000000002	0103000020E610000001000000050000007AC5538F346C42409E0B23BDA84F4A407AC5538F346C4240FF06EDD5C7534A400744882B676F4240FF06EDD5C7534A400744882B676F42409E0B23BDA84F4A407AC5538F346C42409E0B23BDA84F4A40
23507	Смирные	1	11	1470	36.940412999999999	36.970506999999998	52.434049999999999	52.416817000000002	0103000020E61000000100000005000000DBDD03745F7842405BB56B425A354A40DBDD03745F784240166A4DF38E374A4000C5C892397C4240166A4DF38E374A4000C5C892397C42405BB56B425A354A40DBDD03745F7842405BB56B425A354A40
54617	Сетенева	1	11	1470	37.106834999999997	37.135643999999999	52.493285	52.467962999999997	0103000020E61000000100000005000000B988EFC4AC8D4240785E2A36E63B4A40B988EFC4AC8D4240BE4D7FF6233F4A4006F357C85C914240BE4D7FF6233F4A4006F357C85C914240785E2A36E63B4A40B988EFC4AC8D4240785E2A36E63B4A40
54640	Протасово	1	11	1470	36.661720000000003	36.936442999999997	52.692601000000003	52.578043000000001	0103000020E61000000100000005000000F88DAF3DB354424043572250FD494A40F88DAF3DB3544240A5164A26A7584A40B8C83D5DDD774240A5164A26A7584A40B8C83D5DDD77424043572250FD494A40F88DAF3DB354424043572250FD494A40
54566	Покровское	1	11	1470	36.821620000000003	36.885508000000002	52.616596000000001	52.598008	0103000020E61000000100000005000000A9DE1AD82A694240895FB1868B4C4A40A9DE1AD82A694240166C239EEC4E4A40562C7E5358714240166C239EEC4E4A40562C7E5358714240895FB1868B4C4A40A9DE1AD82A694240895FB1868B4C4A40
48525	Озерное	1	11	1470	36.677045	36.696250999999997	52.683556000000003	52.671484	0103000020E61000000100000005000000CD751A69A9564240C5E40D30F3554A40CD751A69A9564240077E54C37E574A405567B5C01E594240077E54C37E574A405567B5C01E594240C5E40D30F3554A40CD751A69A9564240C5E40D30F3554A40
22770	Нижний Туровец	1	11	1470	37.023857999999997	37.039192	52.666393999999997	52.655966999999997	0103000020E61000000100000005000000BDDF68C70D834240AB2006BAF6534A40BDDF68C70D83424014200A664C554A40E621533E0485424014200A664C554A40E621533E04854240AB2006BAF6534A40BDDF68C70D834240AB2006BAF6534A40
48302	Малая Казинка	1	11	1470	36.879508000000001	36.900455999999998	52.560702999999997	52.545634	0103000020E610000001000000050000000249D8B793704240F7CABC55D7454A400249D8B79370424071E2AB1DC5474A4055BE67244273424071E2AB1DC5474A4055BE672442734240F7CABC55D7454A400249D8B793704240F7CABC55D7454A40
46567	Дубки	1	11	1470	36.607551999999998	36.628509000000001	52.616525000000003	52.610405999999998	0103000020E61000000100000005000000484F9143C44D42401EA4A7C8214E4A40484F9143C44D42404D158C4AEA4E4A40EF1EA0FB725042404D158C4AEA4E4A40EF1EA0FB725042401EA4A7C8214E4A40484F9143C44D42401EA4A7C8214E4A40
17600	Дросково	1	11	1470	37.060985000000002	37.094016000000003	52.497995000000003	52.479152999999997	0103000020E61000000100000005000000F645425BCE874240E063B0E2543D4A40F645425BCE8742402849D74CBE3F4A407FA65EB7088C42402849D74CBE3F4A407FA65EB7088C4240E063B0E2543D4A40F645425BCE874240E063B0E2543D4A40
54628	Даниловка	1	11	1470	36.767020000000002	36.796854000000003	52.636854	52.624960999999999	0103000020E6100000010000000500000060B01BB62D6242404223D8B8FE4F4A4060B01BB62D624240D4298F6E84514A40E9D7D64FFF654240D4298F6E84514A40E9D7D64FFF6542404223D8B8FE4F4A4060B01BB62D6242404223D8B8FE4F4A40
40410	Внуково	1	11	1470	37.129527000000003	37.161318000000001	52.444321000000002	52.430843000000003	0103000020E6100000010000000500000079793A5794904240F35A09DD25374A4079793A579490424088F6B182DF384A40C9207711A694424088F6B182DF384A40C9207711A6944240F35A09DD25374A4079793A5794904240F35A09DD25374A40
54612	Верхососенье Средина 1-я	1	11	1470	36.786020000000001	36.810768000000003	52.459173	52.439782000000001	0103000020E610000001000000050000003F00A94D9C6442404BAFCDC64A384A403F00A94D9C644240651A4D2EC63A4A405952EE3EC7674240651A4D2EC63A4A405952EE3EC76742404BAFCDC64A384A403F00A94D9C6442404BAFCDC64A384A40
23311	Вепринец	1	11	1470	37.060975999999997	37.091222000000002	52.539389999999997	52.530056000000002	0103000020E61000000100000005000000A2EBC20FCE874240388600E0D8434A40A2EBC20FCE8742400CE544BB0A454A407E569929AD8B42400CE544BB0A454A407E569929AD8B4240388600E0D8434A40A2EBC20FCE874240388600E0D8434A40
54632	Алексеевка	1	11	1470	36.603931000000003	36.646503000000003	52.584265000000002	52.568010999999998	0103000020E6100000010000000500000032056B9C4D4D424056629E95B4484A4032056B9C4D4D424046990D32C94A4A4009E23C9CC052424046990D32C94A4A4009E23C9CC052424056629E95B4484A4032056B9C4D4D424056629E95B4484A40
49336	Щербово	1	11	1598	35.881776000000002	35.887444000000002	53.178562999999997	53.173247000000003	0103000020E61000000100000005000000E8323509DEF04140A8902BF52C964A40E8323509DEF0414048A30227DB964A400684D6C397F1414048A30227DB964A400684D6C397F14140A8902BF52C964A40E8323509DEF04140A8902BF52C964A40
47472	Шиловский	1	11	1598	35.947082999999999	36.002589999999998	52.997461999999999	52.974812	0103000020E610000001000000050000007DCC07043AF94140CADFBDA3C67C4A407DCC07043AF941405A80B6D5AC7F4A40F8A57EDE540042405A80B6D5AC7F4A40F8A57EDE54004240CADFBDA3C67C4A407DCC07043AF94140CADFBDA3C67C4A40
22059	Шепино	1	11	1598	36.270971000000003	36.296213000000002	53.133572999999998	53.115994999999998	0103000020E610000001000000050000000C957F2DAF224240F0BF95ECD88E4A400C957F2DAF224240765089EB18914A4035D3BD4EEA254240765089EB18914A4035D3BD4EEA254240F0BF95ECD88E4A400C957F2DAF224240F0BF95ECD88E4A40
20572	Усть-Рыбница	1	11	1598	36.025255000000001	36.037292000000001	52.895124000000003	52.889375999999999	0103000020E61000000100000005000000BE874B8E3B03424074ECA012D7714A40BE874B8E3B034240AFEE586C93724A408333F8FBC5044240AFEE586C93724A408333F8FBC504424074ECA012D7714A40BE874B8E3B03424074ECA012D7714A40
47286	Тайное	1	11	1598	36.104422999999997	36.155141999999998	53.059721000000003	53.047094000000001	0103000020E61000000100000005000000A0F99CBB5D0D42403EEB1A2D07864A40A0F99CBB5D0D424035F10EF0A4874A40361E6CB1DB13424035F10EF0A4874A40361E6CB1DB1342403EEB1A2D07864A40A0F99CBB5D0D42403EEB1A2D07864A40
54585	Ступишено	1	11	1598	36.278409000000003	36.293581000000003	52.965701000000003	52.952790999999998	0103000020E61000000100000005000000BFF4F6E7A22342402976340EF5794A40BFF4F6E7A2234240755B22179C7B4A400EDDEC0F94254240755B22179C7B4A400EDDEC0F942542402976340EF5794A40BFF4F6E7A22342402976340EF5794A40
47316	Стрелецкий	1	11	1598	35.963666000000003	35.986500999999997	53.015765000000002	53.004446999999999	0103000020E610000001000000050000003222516859FB41405CC823B891804A403222516859FB4140F2B5679604824A40533C2EAA45FE4140F2B5679604824A40533C2EAA45FE41405CC823B891804A403222516859FB41405CC823B891804A40
21106	Становой Колодезь	1	11	1598	36.201566999999997	36.284669999999998	52.855153999999999	52.801146000000003	0103000020E61000000100000005000000F6798CF2CC1942401EA9BEF38B664A40F6798CF2CC1942409485AFAF756D4A407F130A11702442409485AFAF756D4A407F130A11702442401EA9BEF38B664A40F6798CF2CC1942401EA9BEF38B664A40
21029	Путимец	1	11	1598	36.038477999999998	36.118229999999997	52.767977000000002	52.754047999999997	0103000020E61000000100000005000000C8CEDBD8EC0442409ECE15A584604A40C8CEDBD8EC044240448A01124D624A40FAB31F29220F4240448A01124D624A40FAB31F29220F42409ECE15A584604A40C8CEDBD8EC0442409ECE15A584604A40
54571	Пугачевка	1	11	1598	35.665847999999997	36.453805000000003	53.265433999999999	52.720973999999998	0103000020E61000000100000005000000B20DDC813AD5414016A243E0485C4A40B20DDC813AD541408C9FC6BDF9A14A4072E14048163A42408C9FC6BDF9A14A4072E14048163A424016A243E0485C4A40B20DDC813AD5414016A243E0485C4A40
19504	Полозовские Дворы	1	11	1598	36.075496999999999	36.101827	53.222130999999997	53.189970000000002	0103000020E610000001000000050000001AF9BCE2A90942404E9CDCEF50984A401AF9BCE2A9094240C136E2C96E9C4A40C66CC9AA080D4240C136E2C96E9C4A40C66CC9AA080D42404E9CDCEF50984A401AF9BCE2A90942404E9CDCEF50984A40
48163	Плещеево	1	11	1598	36.069882999999997	36.092044000000001	53.038122999999999	53.016128000000002	0103000020E61000000100000005000000EFC517EDF10842406346787B10824A40EFC517EDF1084240DA1CE736E1844A4082E50819C80B4240DA1CE736E1844A4082E50819C80B42406346787B10824A40EFC517EDF10842406346787B10824A40
19679	Паюсово	1	11	1598	35.987301000000002	36.001916000000001	53.173949	53.166229000000001	0103000020E61000000100000005000000702711E15FFE4140CA52EBFD46954A40702711E15FFE41400116F9F543964A4069AB92C83E0042400116F9F543964A4069AB92C83E004240CA52EBFD46954A40702711E15FFE4140CA52EBFD46954A40
54590	Новотроицкое	1	11	1598	35.895583000000002	35.900154999999998	53.033265999999998	53.026626	0103000020E6100000010000000500000042EDB776A2F24140959C137B68834A4042EDB776A2F24140CC086F0F42844A405A2A6F4738F34140CC086F0F42844A405A2A6F4738F34140959C137B68834A4042EDB776A2F24140959C137B68834A40
48203	Новоселово	1	11	1598	36.078884000000002	36.113118999999998	53.109535999999999	53.096890000000002	0103000020E61000000100000005000000BE16F4DE180A42409CA73AE4668C4A40BE16F4DE180A424009DE9046058E4A4032C7F2AE7A0E424009DE9046058E4A4032C7F2AE7A0E42409CA73AE4668C4A40BE16F4DE180A42409CA73AE4668C4A40
21204	Новодмитровка	1	11	1598	36.304513999999998	36.321410999999998	52.851826000000003	52.84301	0103000020E610000001000000050000004A969350FA264240B9196EC0E76B4A404A969350FA264240F6F065A2086D4A408EC9E2FE23294240F6F065A2086D4A408EC9E2FE23294240B9196EC0E76B4A404A969350FA264240B9196EC0E76B4A40
21878	Нижняя Калиновка	1	11	1598	36.212328999999997	36.219164999999997	53.058477000000003	53.053421999999998	0103000020E61000000100000005000000067FBF982D1B424086713788D6864A40067FBF982D1B4240BB48A12C7C874A40C3B645990D1C4240BB48A12C7C874A40C3B645990D1C424086713788D6864A40067FBF982D1B424086713788D6864A40
40403	Некрасовка	1	11	1598	36.005312000000004	36.019874000000002	52.989407	52.981448999999998	0103000020E6100000010000000500000060234910AE00424090D8EE1EA07D4A4060234910AE0042407CB779E3A47E4A403605323B8B0242407CB779E3A47E4A403605323B8B02424090D8EE1EA07D4A4060234910AE00424090D8EE1EA07D4A40
19661	Моховица	1	11	1598	35.931372000000003	35.972506000000003	53.231364999999997	53.21331	0103000020E610000001000000050000007F349C3237F7414073F4F8BD4D9B4A407F349C3237F7414032384A5E9D9D4A40F7949C137BFC414032384A5E9D9D4A40F7949C137BFC414073F4F8BD4D9B4A407F349C3237F7414073F4F8BD4D9B4A40
60409	Михайловка	1	11	1598	36.150426000000003	36.178362999999997	52.887256999999998	52.858013999999997	0103000020E61000000100000005000000EB3BBF28411342404CC11A67D36D4A40EB3BBF2841134240D3122BA391714A4081E84999D4164240D3122BA391714A4081E84999D41642404CC11A67D36D4A40EB3BBF28411342404CC11A67D36D4A40
54576	Малое Рябцево	1	11	1598	36.257424	36.269021000000002	52.99447	52.987943000000001	0103000020E610000001000000050000004E9A0645F3204240F4A78DEA747E4A404E9A0645F3204240336DFFCA4A7F4A40F777B6476F224240336DFFCA4A7F4A40F777B6476F224240F4A78DEA747E4A404E9A0645F3204240F4A78DEA747E4A40
47798	Лаврово	1	11	1598	35.987381999999997	36.027788000000001	52.851706999999998	52.825274999999998	0103000020E610000001000000050000005C548B8862FE41406B9A779CA2694A405C548B8862FE41401B6327BC046D4A40529CA38E8E0342401B6327BC046D4A40529CA38E8E0342406B9A779CA2694A405C548B8862FE41406B9A779CA2694A40
60417	Красная Звезда	1	11	1598	36.336376999999999	36.361897999999997	52.893076000000001	52.879106	0103000020E610000001000000050000003410CB660E2B4240D3DB9F8B86704A403410CB660E2B4240D76B7A5050724A40703E75AC522E4240D76B7A5050724A40703E75AC522E4240D3DB9F8B86704A403410CB660E2B4240D3DB9F8B86704A40
47951	Карпова	1	11	1598	36.312804999999997	36.350355	53.047229000000002	53.038372000000003	0103000020E610000001000000050000003C8386FE09284240838AAA5FE9844A403C8386FE092842401E3691990B864A40BB7EC16ED82C42401E3691990B864A40BB7EC16ED82C4240838AAA5FE9844A403C8386FE09284240838AAA5FE9844A40
47373	Истомино	1	11	1598	35.904719	35.922110000000004	53.029242000000004	53.021545000000003	0103000020E61000000100000005000000F0880AD5CDF3414038328FFCC1824A40F0880AD5CDF34140B7D5AC33BE834A4044A852B307F64140B7D5AC33BE834A4044A852B307F6414038328FFCC1824A40F0880AD5CDF3414038328FFCC1824A40
48078	Ивановское	1	11	1598	36.230339999999998	36.258780999999999	53.090308999999998	53.070647000000001	0103000020E61000000100000005000000F67AF7C77B1D4240BF47FDF50A894A40F67AF7C77B1D424069C4CC3E8F8B4A40C0E95DBC1F21424069C4CC3E8F8B4A40C0E95DBC1F214240BF47FDF50A894A40F67AF7C77B1D4240BF47FDF50A894A40
48867	Знаменское	1	11	1598	36.271805999999998	36.286107000000001	52.931952000000003	52.924200999999996	0103000020E61000000100000005000000A46DFC89CA2242401AF7E6374C764A40A46DFC89CA2242408DB800344A774A400E1478279F2442408DB800344A774A400E1478279F2442401AF7E6374C764A40A46DFC89CA2242401AF7E6374C764A40
20743	Знаменка	1	11	1598	35.960898999999998	35.997335	52.907052999999998	52.885430999999997	0103000020E610000001000000050000002AE109BDFEFA4140AAEE91CD55714A402AE109BDFEFA41408D5E0D501A744A40FD135CACA8FF41408D5E0D501A744A40FD135CACA8FF4140AAEE91CD55714A402AE109BDFEFA4140AAEE91CD55714A40
20477	Звягинки	1	11	1598	35.906604999999999	35.938684000000002	52.966233000000003	52.950685999999997	0103000020E61000000100000005000000EEB1F4A10BF44140ED612F14B0794A40EEB1F4A10BF4414072A8DF85AD7B4A40A5A31CCC26F8414072A8DF85AD7B4A40A5A31CCC26F84140ED612F14B0794A40EEB1F4A10BF44140ED612F14B0794A40
49589	Дубовик	1	11	1598	36.085666000000003	36.115040999999998	52.820278999999999	52.811424000000002	0103000020E6100000010000000500000088307E1AF70A42404298DBBDDC674A4088307E1AF70A42403C4CFBE6FE684A407D59DAA9B90E42403C4CFBE6FE684A407D59DAA9B90E42404298DBBDDC674A4088307E1AF70A42404298DBBDDC674A40
47178	Дубовая Роща	1	11	1598	36.052194999999998	36.070242	53.168416000000001	53.151090000000003	0103000020E61000000100000005000000E2016553AE0642405760C8EA56934A40E2016553AE064240C30FCEA78E954A401F679AB0FD084240C30FCEA78E954A401F679AB0FD0842405760C8EA56934A40E2016553AE0642405760C8EA56934A40
49065	Домнино	1	11	1598	36.285792999999998	36.296419999999998	52.933022000000001	52.922784	0103000020E610000001000000050000007E3672DD94244240D3A23EC91D764A407E3672DD942442406939D0436D774A40AEF02E17F12542406939D0436D774A40AEF02E17F1254240D3A23EC91D764A407E3672DD94244240D3A23EC91D764A40
20958	Добрый	1	11	1598	35.860709999999997	35.869379000000002	52.823729999999998	52.814233000000002	0103000020E610000001000000050000008AABCABE2BEE4140782975C938684A408AABCABE2BEE4140F65D11FC6F694A40236AA2CF47EF4140F65D11FC6F694A40236AA2CF47EF4140782975C938684A408AABCABE2BEE4140782975C938684A40
48654	Грачевка	1	11	1598	36.148449999999997	36.177636	52.930214999999997	52.908872000000002	0103000020E61000000100000005000000AC8BDB68001342400420EEEA55744A40AC8BDB6800134240D39FFD4811774A40CF4BC5C6BC164240D39FFD4811774A40CF4BC5C6BC1642400420EEEA55744A40AC8BDB68001342400420EEEA55744A40
21866	Вязки	1	11	1598	36.16187	36.199420000000003	53.077685000000002	53.055050999999999	0103000020E610000001000000050000000D1AFA27B8144240594E42E90B874A400D1AFA27B8144240E4310395F1894A408C15359886194240E4310395F1894A408C15359886194240594E42E90B874A400D1AFA27B8144240594E42E90B874A40
21384	Большая Куликовка	1	11	1598	36.193418999999999	36.248621	52.931289999999997	52.9011	0103000020E6100000010000000500000067B62BF4C11842407A36AB3E57734A4067B62BF4C1184240C18BBE8234774A40A60C1CD0D21F4240C18BBE8234774A40A60C1CD0D21F42407A36AB3E57734A4067B62BF4C11842407A36AB3E57734A40
19977	Болотовские Дворы	1	11	1598	35.895510999999999	35.912740999999997	53.051051000000001	53.040959999999998	0103000020E61000000100000005000000A81ABD1AA0F24140DA38622D3E854A40A81ABD1AA0F24140CCB6D3D688864A40F25B74B2D4F44140CCB6D3D688864A40F25B74B2D4F44140DA38622D3E854A40A81ABD1AA0F24140DA38622D3E854A40
22076	Белоберезовский	1	11	1598	36.043868000000003	36.065337	53.063510000000001	53.053254000000003	0103000020E61000000100000005000000A4AB74779D054240CB30EE06D1864A40A4AB74779D054240077C7E1821884A40001C7BF65C084240077C7E1821884A40001C7BF65C084240CB30EE06D1864A40A4AB74779D054240CB30EE06D1864A40
47291	Бакланово	1	11	1598	35.878784000000003	35.906821000000001	53.114697999999997	53.105848999999999	0103000020E61000000100000005000000C11F7EFE7BF041403BA8C4758C8D4A40C11F7EFE7BF0414053758F6CAE8E4A40BB29E5B512F4414053758F6CAE8E4A40BB29E5B512F441403BA8C4758C8D4A40C11F7EFE7BF041403BA8C4758C8D4A40
20879	Альшань	1	11	1598	35.931372000000003	35.945565000000002	52.861054000000003	52.846535000000003	0103000020E610000001000000050000007F349C3237F74140AEF545425B6C4A407F349C3237F74140850B7904376E4A40029F1F4608F94140850B7904376E4A40029F1F4608F94140AEF545425B6C4A407F349C3237F74140AEF545425B6C4A40
18389	Чулково	1	11	1532	36.926839999999999	36.955855	53.081077000000001	53.065804	0103000020E61000000100000005000000F44F70B1A276424016F9F5436C884A40F44F70B1A276424099BA2BBB608A4A40EA5BE674597A424099BA2BBB608A4A40EA5BE674597A424016F9F5436C884A40F44F70B1A276424016F9F5436C884A40
54619	Хутор (деревня Михалево)	1	11	1532	37.088428999999998	37.112341999999998	52.929738	52.911966999999997	0103000020E610000001000000050000004D8237A4518B4240FF03AC55BB744A404D8237A4518B42409AEC9FA701774A40CEFBFF38618E42409AEC9FA701774A40CEFBFF38618E4240FF03AC55BB744A404D8237A4518B4240FF03AC55BB744A40
18829	Хворостянка	1	11	1532	37.100420999999997	37.119807000000002	53.140531000000003	53.131400999999997	0103000020E61000000100000005000000726A6798DA8C4240B2D47ABFD1904A40726A6798DA8C42407F8978EBFC914A407B6AF5D5558F42407F8978EBFC914A407B6AF5D5558F4240B2D47ABFD1904A40726A6798DA8C4240B2D47ABFD1904A40
18857	Селезнево	1	11	1532	37.124622000000002	37.149783999999997	53.137754000000001	53.121777999999999	0103000020E610000001000000050000005A2E1B9DF38F4240A7AFE76B968F4A405A2E1B9DF38F424054724EECA1914A4066BB421F2C93424054724EECA1914A4066BB421F2C934240A7AFE76B968F4A405A2E1B9DF38F4240A7AFE76B968F4A40
18519	Ржавка	1	11	1532	37.218809999999998	37.235805999999997	53.040239999999997	53.033244000000003	0103000020E61000000100000005000000D50451F7019C4240E564E25641844A40D50451F7019C4240DAFE959526854A40AC1919E42E9E4240DAFE959526854A40AC1919E42E9E4240E564E25641844A40D50451F7019C4240E564E25641844A40
18350	Одинок	1	11	1532	36.879705000000001	36.900312999999997	53.068531	53.053561999999999	0103000020E610000001000000050000005890662C9A70424078279F1EDB864A405890662C9A7042408FE1B19FC5884A40F294D5743D7342408FE1B19FC5884A40F294D5743D73424078279F1EDB864A405890662C9A70424078279F1EDB864A40
18127	Новосиль	1	11	1532	37.028672999999998	37.060617000000001	52.985059	52.963689000000002	0103000020E610000001000000050000009CA38E8EAB834240EA4141295A7B4A409CA38E8EAB834240B3D0CE69167E4A40734A404CC2874240B3D0CE69167E4A40734A404CC2874240EA4141295A7B4A409CA38E8EAB834240EA4141295A7B4A40
18729	Мужиково	1	11	1532	37.110948999999998	37.145561999999998	53.036211000000002	53.021827000000002	0103000020E610000001000000050000000F43AB93338E4240BC95253ACB824A400F43AB93338E4240B360E28FA2844A402AC58EC6A1924240B360E28FA2844A402AC58EC6A1924240BC95253ACB824A400F43AB93338E4240BC95253ACB824A40
47254	Маслово	1	11	1532	37.133740000000003	37.155864999999999	53.162045999999997	53.142977999999999	0103000020E6100000010000000500000062156F641E9142401406651A4D924A4062156F641E9142404B395FECBD944A40A7CB6262F39342404B395FECBD944A40A7CB6262F39342401406651A4D924A4062156F641E9142401406651A4D924A40
18562	Заречье	1	11	1532	37.005899999999997	37.039003000000001	52.971145999999997	52.953023999999999	0103000020E61000000100000005000000F085C954C1804240CC26C0B0FC794A40F085C954C180424013D21A834E7C4A4013B9E00CFE84424013D21A834E7C4A4013B9E00CFE844240CC26C0B0FC794A40F085C954C1804240CC26C0B0FC794A40
18290	Задушное	1	11	1532	36.937466999999998	36.997357999999998	52.992463999999998	52.968401999999998	0103000020E61000000100000005000000240A2DEBFE774240C4B0C398F47B4A40240A2DEBFE7742408A3A730F097F4A40B5334C6DA97F42408A3A730F097F4A40B5334C6DA97F4240C4B0C398F47B4A40240A2DEBFE774240C4B0C398F47B4A40
18459	Голунь	1	11	1532	37.163778999999998	37.218755999999999	53.065631000000003	53.045431999999998	0103000020E61000000100000005000000C362D4B5F69442408F183DB7D0854A40C362D4B5F6944240494DBB9866884A40E2E65432009C4240494DBB9866884A40E2E65432009C42408F183DB7D0854A40C362D4B5F69442408F183DB7D0854A40
18215	Вяжи-Заверх	1	11	1532	36.942093	36.974217000000003	53.031809000000003	53.013635999999998	0103000020E610000001000000050000003065E080967842402D060FD3BE814A403065E08096784240F75B3B5112844A40871A8524B37C4240F75B3B5112844A40871A8524B37C42402D060FD3BE814A403065E080967842402D060FD3BE814A40
18737	Воротынцево	1	11	1532	37.109808999999998	37.140225999999998	52.997368999999999	52.979264000000001	0103000020E610000001000000050000003AE7A7380E8E42403813D385587D4A403AE7A7380E8E4240A98592C9A97F4A404206F2ECF2914240A98592C9A97F4A404206F2ECF29142403813D385587D4A403AE7A7380E8E42403813D385587D4A40
18669	Большие Пруды	1	11	1532	37.063806	37.096963000000002	53.037439999999997	53.026674999999997	0103000020E61000000100000005000000F0A485CB2A884240764F1E166A834A40F0A485CB2A884240F7C77BD5CA844A4006F69848698C4240F7C77BD5CA844A4006F69848698C4240764F1E166A834A40F0A485CB2A884240764F1E166A834A40
10761	Шатилово	1	11	1144	37.364400000000003	37.383443999999997	53.007990999999997	52.997548000000002	0103000020E61000000100000005000000CA54C1A8A4AE4240591822A7AF7F4A40CA54C1A8A4AE4240C7D45DD905814A4078EC67B114B14240C7D45DD905814A4078EC67B114B14240591822A7AF7F4A40CA54C1A8A4AE4240591822A7AF7F4A40
16981	Хомутово	1	11	1144	37.410375999999999	37.466951999999999	52.867854999999999	52.844337000000003	0103000020E610000001000000050000001A88653387B44240C1E61C3C136C4A401A88653387B44240C55565DF156F4A40A1664815C5BB4240C55565DF156F4A40A1664815C5BB4240C1E61C3C136C4A401A88653387B44240C1E61C3C136C4A40
60452	Суры	1	11	1144	37.322709000000003	37.348607999999999	52.989970999999997	52.979714000000001	0103000020E61000000100000005000000FC8F4C874EA9424078B7B244677D4A40FC8F4C874EA94240847EA65EB77E4A40DE8FDB2F9FAC4240847EA65EB77E4A40DE8FDB2F9FAC424078B7B244677D4A40FC8F4C874EA9424078B7B244677D4A40
54608	Судбищи	1	11	1144	37.616565999999999	37.650190000000002	52.964117000000002	52.946143999999997	0103000020E61000000100000005000000ABE97AA2EBCE42403FA7203F1B794A40ABE97AA2EBCE42404242942F687B4A40D717096D39D342404242942F687B4A40D717096D39D342403FA7203F1B794A40ABE97AA2EBCE42403FA7203F1B794A40
46577	Старогольское	1	11	1144	37.723537999999998	37.741467999999998	53.059916000000001	53.043568999999998	0103000020E61000000100000005000000E5B4A7E49CDC4240490F43AB93854A40E5B4A7E49CDC4240EA40D653AB874A40E883656CE8DE4240EA40D653AB874A40E883656CE8DE4240490F43AB93854A40E5B4A7E49CDC4240490F43AB93854A40
48928	Плоское	1	11	1144	37.427273	37.645977000000002	53.054682999999997	52.804178999999998	0103000020E610000001000000050000005EBBB4E1B0B64240A3906456EF664A405EBBB4E1B0B64240D65240DAFF864A40EE7BD45FAFD24240D65240DAFF864A40EE7BD45FAFD24240A3906456EF664A405EBBB4E1B0B64240A3906456EF664A40
46601	Пасынки	1	11	1144	37.801862	37.822522999999997	53.053454000000002	53.035859000000002	0103000020E61000000100000005000000DCF3FC69A3E642403622180797844A40DCF3FC69A3E6424092EBA694D7864A40999A046F48E9424092EBA694D7864A40999A046F48E942403622180797844A40DCF3FC69A3E642403622180797844A40
60405	Паньково	1	11	1144	37.519835999999998	37.553837000000001	53.062671000000002	53.037689999999998	0103000020E6100000010000000500000048A46DFC89C2424070B1A206D3844A4048A46DFC89C242402DB4739A05884A404A287D21E4C642402DB4739A05884A404A287D21E4C6424070B1A206D3844A4048A46DFC89C2424070B1A206D3844A40
46165	Новая Заря	1	11	1144	37.434936	37.599687000000003	52.850955999999996	52.829416000000002	0103000020E6100000010000000500000031ED9BFBABB74240BB63B14D2A6A4A4031ED9BFBABB74240E02A4F20EC6C4A400E6B2A8BC2CC4240E02A4F20EC6C4A400E6B2A8BC2CC4240BB63B14D2A6A4A4031ED9BFBABB74240BB63B14D2A6A4A40
46197	Никольское	1	11	1144	37.361291999999999	37.386201999999997	52.863343	52.847138000000001	0103000020E610000001000000050000003927F6D03EAE424074999A046F6C4A403927F6D03EAE4240821DFF05826E4A402CD32F116FB14240821DFF05826E4A402CD32F116FB1424074999A046F6C4A403927F6D03EAE424074999A046F6C4A40
60408	Муравьевка	1	11	1144	37.448222000000001	37.469619999999999	52.894831000000003	52.890338	0103000020E6100000010000000500000082ACA7565FB942406A317898F6714A4082ACA7565FB9424037397CD289724A4015C616821CBC424037397CD289724A4015C616821CBC42406A317898F6714A4082ACA7565FB942406A317898F6714A40
17631	Моховое	1	11	1144	37.328755000000001	37.571021999999999	53.056983000000002	52.944054999999999	0103000020E61000000100000005000000C0B2D2A414AA4240095053CBD6784A40C0B2D2A414AA4240C8B60C384B874A40F4A5B73F17C94240C8B60C384B874A40F4A5B73F17C94240095053CBD6784A40C0B2D2A414AA4240095053CBD6784A40
17383	Лазавка	1	11	1144	37.627391000000003	37.713962000000002	52.904755000000002	52.874735999999999	0103000020E61000000100000005000000026729594ED0424022516859F76F4A40026729594ED042403DF20703CF734A401B4B581B63DB42403DF20703CF734A401B4B581B63DB424022516859F76F4A40026729594ED0424022516859F76F4A40
17506	Кулеши	1	11	1144	37.383479999999999	37.406387000000002	52.997413000000002	52.968836000000003	0103000020E61000000100000005000000C55565DF15B14240FF976BD1027C4A40C55565DF15B1424079CDAB3AAB7F4A4081423D7D04B4424079CDAB3AAB7F4A4081423D7D04B44240FF976BD1027C4A40C55565DF15B14240FF976BD1027C4A40
46213	Косарево	1	11	1144	37.267643	37.338186999999998	52.948537000000002	52.918429000000003	0103000020E610000001000000050000006D00362042A242405859DB148F754A406D00362042A24240E20511A969794A4057772CB649AB4240E20511A969794A4057772CB649AB42405859DB148F754A406D00362042A242405859DB148F754A40
17957	Кологривово	1	11	1144	37.833941000000003	37.875191000000001	52.995088000000003	52.970322000000003	0103000020E6100000010000000500000093E52494BEEA42406F4BE482337C4A4093E52494BEEA42402F52280B5F7F4A407460394206F042402F52280B5F7F4A407460394206F042406F4BE482337C4A4093E52494BEEA42406F4BE482337C4A40
46473	Дементьевка	1	11	1144	37.510655	37.536850000000001	52.991337000000001	52.976596000000001	0103000020E61000000100000005000000FA449E245DC14240C4B30419017D4A40FA449E245DC142404A287D21E47E4A40C66D3480B7C442404A287D21E47E4A40C66D3480B7C44240C4B30419017D4A40FA449E245DC14240C4B30419017D4A40
46613	Благодать	1	11	1144	37.700819000000003	37.731217999999998	53.113875999999998	53.096614000000002	0103000020E610000001000000050000002DB5DE6FB4D94240FA2AF9D85D8C4A402DB5DE6FB4D942404FE61F7D938E4A408E1F2A8D98DD42404FE61F7D938E4A408E1F2A8D98DD4240FA2AF9D85D8C4A402DB5DE6FB4D94240FA2AF9D85D8C4A40
45656	Ядрино	1	11	1037	36.618169999999999	36.630961999999997	53.252440999999997	53.238922000000002	0103000020E6100000010000000500000025AFCE31204F4240C02500FF949E4A4025AFCE31204F4240B39597FC4FA04A406682E15CC3504240B39597FC4FA04A406682E15CC3504240C02500FF949E4A4025AFCE31204F4240C02500FF949E4A40
45825	Шашкино	1	11	1037	36.401747999999998	36.438623	53.427604000000002	53.415284	0103000020E61000000100000005000000E09D7C7A6C334240AA46AF0628B54A40E09D7C7A6C334240C4D155BABBB64A40FF2268CC24384240C4D155BABBB64A40FF2268CC24384240AA46AF0628B54A40E09D7C7A6C334240AA46AF0628B54A40
15700	Черемошны	1	11	1037	36.831609	36.855460000000001	53.164799000000002	53.152898999999998	0103000020E610000001000000050000009607E929726A4240A94BC63192934A409607E929726A4240EEB4352218954A40A18499B67F6D4240EEB4352218954A40A18499B67F6D4240A94BC63192934A409607E929726A4240A94BC63192934A40
16052	Чахино	1	11	1037	36.590124000000003	36.606743000000002	53.177380999999997	53.154746000000003	0103000020E61000000100000005000000D84AE82E894B4240EA9788B7CE934A40D84AE82E894B424044F7AC6BB4964A40D9092FC1A94D424044F7AC6BB4964A40D9092FC1A94D4240EA9788B7CE934A40D84AE82E894B4240EA9788B7CE934A40
54634	Фроловка	1	11	1037	36.436387000000003	36.449393999999998	53.343296000000002	53.336452000000001	0103000020E6100000010000000500000025B37A87DB3742403F56F0DB10AB4A4025B37A87DB3742407F6C921FF1AB4A4062821ABE853942407F6C921FF1AB4A4062821ABE853942403F56F0DB10AB4A4025B37A87DB3742403F56F0DB10AB4A40
45918	Фарафоново	1	11	1037	36.483637999999999	36.496932999999999	53.296165000000002	53.285345999999997	0103000020E610000001000000050000002A8D98D9E73D4240AF05BD3786A44A402A8D98D9E73D4240249C16BCE8A54A40CEA623809B3F4240249C16BCE8A54A40CEA623809B3F4240AF05BD3786A44A402A8D98D9E73D4240AF05BD3786A44A40
16380	Тельчье	1	11	1037	36.31718	36.349870000000003	53.356524	53.340015999999999	0103000020E61000000100000005000000FF78AF5A99284240F10EF0A485AB4A40FF78AF5A992842409B1E1494A2AD4A40FFEC478AC82C42409B1E1494A2AD4A40FFEC478AC82C4240F10EF0A485AB4A40FF78AF5A99284240F10EF0A485AB4A40
9082	Сычи	1	11	1037	36.533683000000003	36.557505999999997	53.077478999999997	53.063141999999999	0103000020E6100000010000000500000031B77BB94F44424084807C0915884A4031B77BB94F4442403A90F5D4EA894A4071A94A5B5C4742403A90F5D4EA894A4071A94A5B5C47424084807C0915884A4031B77BB94F44424084807C0915884A40
16135	Спасское-Лутовиново	1	11	1037	36.611459000000004	36.637528000000003	53.375872999999999	53.364348	0103000020E6100000010000000500000025ECDB49444E4240772E8CF4A2AE4A4025ECDB49444E42408639419B1CB04A4064247B849A5142408639419B1CB04A4064247B849A514240772E8CF4A2AE4A4025ECDB49444E4240772E8CF4A2AE4A40
49414	Руднево	1	11	1037	36.426845999999998	36.439242999999998	53.269705000000002	53.264104000000003	0103000020E61000000100000005000000D636C5E3A2364240145FED28CEA14A40D636C5E3A2364240AA4885B185A24A409BFF571D39384240AA4885B185A24A409BFF571D39384240145FED28CEA14A40D636C5E3A2364240145FED28CEA14A40
16608	Протасово	1	11	1037	36.485982999999997	36.506231	53.088194999999999	53.069710999999998	0103000020E61000000100000005000000BBB4E1B0343E4240F295404AEC884A40BBB4E1B0343E4240DA5548F9498B4A40569C6A2DCC404240DA5548F9498B4A40569C6A2DCC404240F295404AEC884A40BBB4E1B0343E4240F295404AEC884A40
54635	Подберезово	1	11	1037	36.613399999999999	36.643430000000002	53.269866	53.250447999999999	0103000020E61000000100000005000000E6AE25E4834E42409FAC18AE0EA04A40E6AE25E4834E4240B32616F88AA24A40F5A10BEA5B524240B32616F88AA24A40F5A10BEA5B5242409FAC18AE0EA04A40E6AE25E4834E42409FAC18AE0EA04A40
15996	Подбелевец	1	11	1037	36.660156999999998	36.691634000000001	53.189194000000001	53.164999000000002	0103000020E61000000100000005000000DC9C4A0680544240B56FEEAF1E954A40DC9C4A0680544240BA4C4D8237984A409D66817687584240BA4C4D8237984A409D66817687584240B56FEEAF1E954A40DC9C4A0680544240B56FEEAF1E954A40
40392	Петровка	1	11	1037	36.435110999999999	36.447481000000003	53.149085999999997	53.138440000000003	0103000020E610000001000000050000009F909DB7B1374240A83AE466B8914A409F909DB7B13742404E25034015934A406B4AB20E473942404E25034015934A406B4AB20E47394240A83AE466B8914A409F909DB7B1374240A83AE466B8914A40
54614	Отрадинский	1	11	1037	36.323656999999997	36.373531	53.170597000000001	53.152774999999998	0103000020E610000001000000050000008C0FB3976D294240BD5296218E934A408C0FB3976D294240DAE55B1FD6954A40668522DDCF2F4240DAE55B1FD6954A40668522DDCF2F4240BD5296218E934A408C0FB3976D294240BD5296218E934A40
16752	Нововолковский	1	11	1037	36.462204	36.483234000000003	53.232616	53.220190000000002	0103000020E610000001000000050000004A0A2C80293B42400074982F2F9C4A404A0A2C80293B42405F43705CC69D4A405B28999CDA3D42405F43705CC69D4A405B28999CDA3D42400074982F2F9C4A404A0A2C80293B42400074982F2F9C4A40
60445	Никольское	1	11	1037	36.890593000000003	36.904732000000003	53.210560000000001	53.204309000000002	0103000020E61000000100000005000000F58590F3FE714240A5A31CCC269A4A40F58590F3FE71424042EC4CA1F39A4A4085D21742CE73424042EC4CA1F39A4A4085D21742CE734240A5A31CCC269A4A40F58590F3FE714240A5A31CCC269A4A40
16194	Нижняя Зароща	1	11	1037	36.572715000000002	36.627395	53.331052999999997	53.32105	0103000020E61000000100000005000000DE76A1B94E494240BE30992A18A94A40DE76A1B94E494240101FD8F15FAA4A404356B77A4E504240101FD8F15FAA4A404356B77A4E504240BE30992A18A94A40DE76A1B94E494240BE30992A18A94A40
45394	Нарышкино	1	11	1037	36.330224000000001	36.335406999999996	53.216233000000003	53.213282999999997	0103000020E610000001000000050000005A2DB0C7442A424079E57ADB4C9B4A405A2DB0C7442A424072A8DF85AD9B4A40BBECD79DEE2A424072A8DF85AD9B4A40BBECD79DEE2A424079E57ADB4C9B4A405A2DB0C7442A424079E57ADB4C9B4A40
15912	Мелынь	1	11	1037	36.745801999999998	36.770488	53.096074000000002	53.083370000000002	0103000020E610000001000000050000004CA59F70765F4240D8BB3FDEAB8A4A404CA59F70765F42407AFF1F274C8C4A40F0FACC599F6242407AFF1F274C8C4A40F0FACC599F624240D8BB3FDEAB8A4A404CA59F70765F4240D8BB3FDEAB8A4A40
45608	Жилино	1	11	1037	36.748559999999998	36.774332999999999	53.211227999999998	53.201337000000002	0103000020E61000000100000005000000008C67D0D05F4240C53C2B69C5994A40008C67D0D05F4240EFFFE384099B4A40569BFF571D634240EFFFE384099B4A40569BFF571D634240C53C2B69C5994A40008C67D0D05F4240C53C2B69C5994A40
16664	Добрая Вода	1	11	1037	36.500374000000001	36.534806000000003	53.124738999999998	53.109876	0103000020E6100000010000000500000065E256410C404240C24EB16A108E4A4065E256410C40424093C49272F78F4A4030DAE3857444424093C49272F78F4A4030DAE38574444240C24EB16A108E4A4065E256410C404240C24EB16A108E4A40
49079	Городище	1	11	1037	36.295530999999997	36.304658000000003	53.262030000000003	53.255015999999998	0103000020E6100000010000000500000022FAB5F5D325424076FA415DA4A04A4022FAB5F5D32542401349F4328AA14A407E3B8908FF2642401349F4328AA14A407E3B8908FF26424076FA415DA4A04A4022FAB5F5D325424076FA415DA4A04A40
54586	Глазуново	1	11	1037	36.474646	36.501567999999999	53.329483000000003	53.314121	0103000020E61000000100000005000000AF963B33C13C424050FEEE1D35A84A40AF963B33C13C424043CBBA7F2CAA4A402D5C56613340424043CBBA7F2CAA4A402D5C56613340424050FEEE1D35A84A40AF963B33C13C424050FEEE1D35A84A40
45575	Гладкое	1	11	1037	36.874018999999997	36.899908000000003	53.223942999999998	53.210273999999998	0103000020E61000000100000005000000938AC6DADF6F42407C992842EA9A4A40938AC6DADF6F424085950A2AAA9C4A4053B4722F3073424085950A2AAA9C4A4053B4722F307342407C992842EA9A4A40938AC6DADF6F42407C992842EA9A4A40
45886	Высокое	1	11	1037	36.717981000000002	36.739351999999997	53.121350999999997	53.109476000000001	0103000020E610000001000000050000001F1329CDE65B424034D93F4F038E4A401F1329CDE65B42401F2BF86D888F4A40B81D1A16A35E42401F2BF86D888F4A40B81D1A16A35E424034D93F4F038E4A401F1329CDE65B424034D93F4F038E4A40
46036	Волково	1	11	1037	36.513309	36.557102	53.267733999999997	53.232523999999998	0103000020E6100000010000000500000009DFFB1BB44142407EC4AF58C39D4A4009DFFB1BB44142407D03931B45A24A40A2444B1E4F4742407D03931B45A24A40A2444B1E4F4742407EC4AF58C39D4A4009DFFB1BB44142407EC4AF58C39D4A40
16697	Воин 1-й	1	11	1037	36.395710999999999	36.418312	53.189593000000002	53.174698999999997	0103000020E610000001000000050000006FD575A8A63242406BD26D895C964A406FD575A8A632424078465B9544984A401EC3633F8B35424078465B9544984A401EC3633F8B3542406BD26D895C964A406FD575A8A63242406BD26D895C964A40
14703	Верхнее Алябьево	1	11	1037	36.813616000000003	36.842891999999999	53.275257000000003	53.252980000000001	0103000020E610000001000000050000004DC0AF912468424063450DA661A04A404DC0AF91246842405F7F129F3BA34A40AF0793E2E36B42405F7F129F3BA34A40AF0793E2E36B424063450DA661A04A404DC0AF912468424063450DA661A04A40
45880	Брагино	1	11	1037	36.310048000000002	36.338264000000002	53.335833000000001	53.323802999999998	0103000020E61000000100000005000000591822A7AF27424060AC6F6072A94A40591822A7AF27424073F56393FCAA4A4003B5183C4C2B424073F56393FCAA4A4003B5183C4C2B424060AC6F6072A94A40591822A7AF27424060AC6F6072A94A40
16075	Большая Каменка	1	11	1037	36.684322000000002	36.699108000000003	53.335866000000003	53.324761000000002	0103000020E6100000010000000500000077F700DD975742401502B9C491A94A4077F700DD975742404FEB36A8FDAA4A409D2FF65E7C5942404FEB36A8FDAA4A409D2FF65E7C5942401502B9C491A94A4077F700DD975742401502B9C491A94A40
54639	Башкатово	1	11	1037	36.237850000000002	36.261116000000001	53.172809999999998	53.157310000000003	0103000020E6100000010000000500000043AD69DE711E4240B9AAECBB22944A4043AD69DE711E4240FC3559A31E964A402E3BC43F6C214240FC3559A31E964A402E3BC43F6C214240B9AAECBB22944A4043AD69DE711E4240B9AAECBB22944A40
30248	Апальково	1	11	1037	36.214646000000002	36.228462999999998	53.241228	53.226998999999999	0103000020E61000000100000005000000CE1B2785791B4240C39CA04D0E9D4A40CE1B2785791B42409370218FE09E4A404BAC8C463E1D42409370218FE09E4A404BAC8C463E1D4240C39CA04D0E9D4A40CE1B2785791B4240C39CA04D0E9D4A40
45911	Аниканово	1	11	1037	36.395361000000001	36.414216000000003	53.282983000000002	53.271272000000003	0103000020E61000000100000005000000938E72309B3242400729780AB9A24A40938E72309B324240782975C938A44A406FBDA60705354240782975C938A44A406FBDA607053542400729780AB9A24A40938E72309B3242400729780AB9A24A40
60429	Хитрово	1	11	1381	36.746268999999998	36.781402999999997	52.386806	52.365101000000003	0103000020E6100000010000000500000062821ABE855F4240535E2BA1BB2E4A4062821ABE855F4240C3F2E7DB82314A4086FF740305644240C3F2E7DB82314A4086FF740305644240535E2BA1BB2E4A4062821ABE855F4240535E2BA1BB2E4A40
15278	Рогатый	1	11	1381	36.622391999999998	36.640825	52.286624000000003	52.271532000000001	0103000020E6100000010000000500000061A5828AAA4F4240A3E8818FC1224A4061A5828AAA4F4240D61F6118B0244A40C7BAB88D06524240D61F6118B0244A40C7BAB88D06524240A3E8818FC1224A4061A5828AAA4F4240A3E8818FC1224A40
15477	Подгородняя 2-я	1	11	1381	36.512715999999998	36.528678999999997	52.402759000000003	52.388444	0103000020E6100000010000000500000066118AADA0414240E9297288B8314A4066118AADA0414240B8955E9B8D334A407E8AE3C0AB434240B8955E9B8D334A407E8AE3C0AB434240E9297288B8314A4066118AADA0414240E9297288B8314A40
15232	Плещеевский Завод	1	11	1381	36.674951999999998	36.682578999999997	52.317480000000003	52.311990999999999	0103000020E61000000100000005000000552FBFD364564240BBD23252EF274A40552FBFD3645642402A91442FA3284A40DBF7A8BF5E5742402A91442FA3284A40DBF7A8BF5E574240BBD23252EF274A40552FBFD364564240BBD23252EF274A40
54575	Остров	1	11	1381	36.458871000000002	36.473827999999997	52.327311000000002	52.313454999999998	0103000020E610000001000000050000009A0AF148BC3A424043E21E4B1F284A409A0AF148BC3A42407F4FAC53E5294A40ECF65965A63C42407F4FAC53E5294A40ECF65965A63C424043E21E4B1F284A409A0AF148BC3A424043E21E4B1F284A40
54572	Новая Стройка	1	11	1381	36.413839000000003	36.439090999999998	52.409193000000002	52.401643999999997	0103000020E61000000100000005000000996725ADF83442403B51121269334A40996725ADF83442404660AC6F60344A40E57B4622343842404660AC6F60344A40E57B4622343842403B51121269334A40996725ADF83442403B51121269334A40
54573	Малоархангельск	1	11	1381	36.302258999999999	36.324897	52.399748000000002	52.382919999999999	0103000020E61000000100000005000000F9F5436CB0264240FE7DC68503314A40F9F5436CB02642401A5245F12A334A40C5C89239962942401A5245F12A334A40C5C8923996294240FE7DC68503314A40F9F5436CB0264240FE7DC68503314A40
15516	Малоархангельск	1	11	1381	36.472292000000003	36.518259	52.411242000000001	52.389994000000002	0103000020E61000000100000005000000CB147310743C424070D1C952EB314A40CB147310743C4240EE5EEE93A3344A40C8ED974F56424240EE5EEE93A3344A40C8ED974F5642424070D1C952EB314A40CB147310743C424070D1C952EB314A40
45401	Луковец	1	11	1381	36.669212000000002	36.689711000000003	52.301803999999997	52.287649000000002	0103000020E610000001000000050000009E0B23BDA855424012DDB3AED1244A409E0B23BDA8554240A7E67283A1264A408258367348584240A7E67283A1264A40825836734858424012DDB3AED1244A409E0B23BDA855424012DDB3AED1244A40
15303	Легостаево 1-е	1	11	1381	36.618465999999998	36.648012000000001	52.240175999999998	52.228935	0103000020E610000001000000050000000ED8D5E4294F424073F4F8BD4D1D4A400ED8D5E4294F42405DA45016BE1E4A4031B5A50EF25242405DA45016BE1E4A4031B5A50EF252424073F4F8BD4D1D4A400ED8D5E4294F424073F4F8BD4D1D4A40
49545	Костино	1	11	1381	36.478149000000002	36.548793000000003	52.304591000000002	52.294522999999998	0103000020E61000000100000005000000BCCE86FC333D4240BC75FEEDB2254A40BCCE86FC333D4240F6D37FD6FC264A400AA359D93E464240F6D37FD6FC264A400AA359D93E464240BC75FEEDB2254A40BCCE86FC333D4240BC75FEEDB2254A40
15083	Ивань 1-я	1	11	1381	36.694203000000002	36.733702000000001	52.413361999999999	52.391114999999999	0103000020E610000001000000050000007EE4D6A4DB584240CEFC6A0E10324A407EE4D6A4DB5842405FB4C70BE9344A40418177F2E95D42405FB4C70BE9344A40418177F2E95D4240CEFC6A0E10324A407EE4D6A4DB584240CEFC6A0E10324A40
45481	Губкино	1	11	1381	36.627870999999999	36.667181999999997	52.368873000000001	52.347515999999999	0103000020E61000000100000005000000AC8DB1135E5042401A6B7F677B2C4A40AC8DB1135E5042404FB0FF3A372F4A406C3D4338665542404FB0FF3A372F4A406C3D4338665542401A6B7F677B2C4A40AC8DB1135E5042401A6B7F677B2C4A40
48062	Гриневка	1	11	1381	36.427349999999997	36.441471	52.403281	52.394286000000001	0103000020E6100000010000000500000009F9A067B3364240A5A2B1F677324A4009F9A067B3364240910C39B69E334A40F390291F82384240910C39B69E334A40F390291F82384240A5A2B1F677324A4009F9A067B3364240A5A2B1F677324A40
15380	Гнилая Плота	1	11	1381	36.533943999999998	36.579586999999997	52.282012999999999	52.260978000000001	0103000020E610000001000000050000009DF2E84658444240DD7C23BA67214A409DF2E84658444240FF05820019244A40E71725E82F4A4240FF05820019244A40E71725E82F4A4240DD7C23BA67214A409DF2E84658444240DD7C23BA67214A40
49596	Архарово	1	11	1381	36.692874000000003	36.71349	52.478797	52.467753999999999	0103000020E61000000100000005000000D61F6118B05842405E49F25CDF3B4A40D61F6118B058424022365838493D4A40F302ECA3535B424022365838493D4A40F302ECA3535B42405E49F25CDF3B4A40D61F6118B05842405E49F25CDF3B4A40
40391	Беломестное	1	11	6911	37.579366999999998	37.629942	52.417735	52.393506000000002	0103000020E61000000100000005000000D9B0A6B228CA4240D06394675E324A40D9B0A6B228CA424081B2295778354A403C3080F0A1D0424081B2295778354A403C3080F0A1D04240D06394675E324A40D9B0A6B228CA4240D06394675E324A40
54627	Троицкое	1	11	1236	37.583993	37.634127999999997	52.348567000000003	52.321581000000002	0103000020E61000000100000005000000E50B5A48C0CA4240EB01F39029294A40E50B5A48C0CA424080BBECD79D2C4A402BBD361B2BD1424080BBECD79D2C4A402BBD361B2BD14240EB01F39029294A40E50B5A48C0CA4240EB01F39029294A40
12794	Теличье	1	11	1236	37.431261999999997	37.47916	52.419035999999998	52.404643999999998	0103000020E61000000100000005000000F700DD9733B74240E542E55FCB334A40F700DD9733B742405FECBDF8A2354A4093C6681D55BD42405FECBDF8A2354A4093C6681D55BD4240E542E55FCB334A40F700DD9733B74240E542E55FCB334A40
47023	Сосновка	1	11	1236	37.332805999999998	37.385357999999997	52.347020999999998	52.329825999999997	0103000020E61000000100000005000000CFF4126399AA42406CAF05BD372A4A40CFF4126399AA42403A03232F6B2C4A4040A0336953B142403A03232F6B2C4A4040A0336953B142406CAF05BD372A4A40CFF4126399AA42406CAF05BD372A4A40
54577	Совхозный	1	11	1236	37.639921999999999	37.666189000000003	52.438557000000003	52.427439	0103000020E61000000100000005000000D6FECEF6E8D1424079043752B6364A40D6FECEF6E8D142404837C2A222384A403CFA5FAE45D542404837C2A222384A403CFA5FAE45D5424079043752B6364A40D6FECEF6E8D1424079043752B6364A40
54584	Сергиевское	1	11	1236	37.670572999999997	37.701447999999999	52.373618	52.338267999999999	0103000020E61000000100000005000000514A0856D5D5424044A4A65D4C2B4A40514A0856D5D542403599F1B6D22F4A401CEC4D0CC9D942403599F1B6D22F4A401CEC4D0CC9D9424044A4A65D4C2B4A40514A0856D5D5424044A4A65D4C2B4A40
13195	Семенихино	1	11	1236	37.514750999999997	37.537154999999998	52.578465000000001	52.567683000000002	0103000020E61000000100000005000000A94A5B5CE3C1424062BF27D6A9484A40A94A5B5CE3C14240B97020240B4A4A4002F1BA7EC1C44240B97020240B4A4A4002F1BA7EC1C4424062BF27D6A9484A40A94A5B5CE3C1424062BF27D6A9484A40
14467	Свободная Дубрава	1	11	1236	37.787227999999999	37.824283999999999	52.297342999999998	52.270986999999998	0103000020E610000001000000050000006C3F19E3C3E442401152B7B3AF224A406C3F19E3C3E44240E658DE550F264A40DB4E5B2382E94240E658DE550F264A40DB4E5B2382E942401152B7B3AF224A406C3F19E3C3E442401152B7B3AF224A40
13064	Сахзаводской	1	11	1236	37.510322000000002	37.528846000000001	52.434862000000003	52.424796999999998	0103000020E61000000100000005000000F436363B52C142402E3883BF5F364A40F436363B52C14240F722DA8EA9374A406A4FC939B1C34240F722DA8EA9374A406A4FC939B1C342402E3883BF5F364A40F436363B52C142402E3883BF5F364A40
13994	Росстани	1	11	1236	37.496541999999998	37.520023999999999	52.343302000000001	52.317684	0103000020E61000000100000005000000938B31B08EBF4240323B8BDEA9284A40938B31B08EBF42406153E751F12B4A404B917C2590C242406153E751F12B4A404B917C2590C24240323B8BDEA9284A40938B31B08EBF4240323B8BDEA9284A40
48865	Речица	1	11	1236	37.367570999999998	37.413097999999998	52.399754000000001	52.381590000000003	0103000020E61000000100000005000000A0FA07910CAF4240863DEDF0D7304A40A0FA07910CAF4240FC389A232B334A4081053065E0B44240FC389A232B334A4081053065E0B44240863DEDF0D7304A40A0FA07910CAF4240863DEDF0D7304A40
12849	Покровка 1-я	1	11	1236	37.258372000000001	37.282482999999999	52.4373	52.422199999999997	0103000020E61000000100000005000000DF196D5512A14240832F4CA60A364A40DF196D5512A1424039454772F9374A408656276728A4424039454772F9374A408656276728A44240832F4CA60A364A40DF196D5512A14240832F4CA60A364A40
46226	Пешково	1	11	1236	37.630947999999997	37.719217	52.603487999999999	52.558278000000001	0103000020E6100000010000000500000001BD70E7C2D04240C4094CA775474A4001BD70E7C2D04240A4C343183F4D4A4016DD7A4D0FDC4240A4C343183F4D4A4016DD7A4D0FDC4240C4094CA775474A4001BD70E7C2D04240C4094CA775474A40
13221	Орлово	1	11	1236	37.599651000000001	37.620887000000003	52.558376000000003	52.548437999999997	0103000020E61000000100000005000000C1012D5DC1CC42401BF1643733464A40C1012D5DC1CC4240876F61DD78474A407BC1A73979CF4240876F61DD78474A407BC1A73979CF42401BF1643733464A40C1012D5DC1CC42401BF1643733464A40
47957	Овсянниково	1	11	1236	37.613790000000002	37.621498000000003	52.564042000000001	52.558107999999997	0103000020E61000000100000005000000514EB4AB90CE424067D13B1570474A40514EB4AB90CE424004C93B8732484A40C443183F8DCF424004C93B8732484A40C443183F8DCF424067D13B1570474A40514EB4AB90CE424067D13B1570474A40
49400	Норовка	1	11	1236	37.789760999999999	37.817869999999999	52.226756000000002	52.213228000000001	0103000020E61000000100000005000000005471E316E54240B64B1B0E4B1B4A40005471E316E54240FD153257061D4A409430D3F6AFE84240FD153257061D4A409430D3F6AFE84240B64B1B0E4B1B4A40005471E316E54240B64B1B0E4B1B4A40
14520	Навесное	1	11	1236	37.922362	37.980052000000001	52.292667000000002	52.268672000000002	0103000020E610000001000000050000005D8940F50FF64240EBAC16D863224A405D8940F50FF6424029CFBC1C76254A4090300C5872FD424029CFBC1C76254A4090300C5872FD4240EBAC16D863224A405D8940F50FF64240EBAC16D863224A40
48957	Набережный	1	11	1236	37.528557999999997	37.549129999999998	52.423073000000002	52.400709999999997	0103000020E610000001000000050000000305DEC9A7C342400F971C774A334A400305DEC9A7C342400A698D4127364A4051A04FE449C642400A698D4127364A4051A04FE449C642400F971C774A334A400305DEC9A7C342400F971C774A334A40
48946	Моногарово	1	11	1236	37.507978000000001	37.531298	52.475302999999997	52.454810000000002	0103000020E61000000100000005000000338B506C05C1424067F2CD36373A4A40338B506C05C1424068588CBAD63C4A401137A79201C4424068588CBAD63C4A401137A79201C4424067F2CD36373A4A40338B506C05C1424067F2CD36373A4A40
54603	Липовец	1	11	1236	37.682377000000002	37.710951999999999	52.451802999999998	52.429701000000001	0103000020E610000001000000050000007445292158D742407D073F7100374A407445292158D742400A9E42AED4394A404D83A27900DB42400A9E42AED4394A404D83A27900DB42407D073F7100374A407445292158D742407D073F7100374A40
49180	Кунач	1	11	1236	37.758975999999997	37.795465999999998	52.423879999999997	52.402946	0103000020E610000001000000050000007539252026E14240EA060ABC93334A407539252026E14240D8B628B341364A403B8A73D4D1E54240D8B628B341364A403B8A73D4D1E54240EA060ABC93334A407539252026E14240EA060ABC93334A40
54563	Крутое	1	11	1236	37.447206999999999	37.511499000000001	52.455694000000001	52.426780000000001	0103000020E6100000010000000500000069C537143EB942401F4B1FBAA0364A4069C537143EB94240E17D552E543A4A40E6779ACC78C14240E17D552E543A4A40E6779ACC78C142401F4B1FBAA0364A4069C537143EB942401F4B1FBAA0364A40
54623	Круглое	1	11	1236	37.957369	38.016396999999998	52.335163999999999	52.310273000000002	0103000020E61000000100000005000000249A40118BFA424079EA9106B7274A40249A40118BFA4240F56569A7E62A4A405260014C19024340F56569A7E62A4A405260014C1902434079EA9106B7274A40249A40118BFA424079EA9106B7274A40
49263	Коротыш	1	11	1236	37.433129999999998	37.527929	52.385773	52.341399000000003	0103000020E610000001000000050000004F75C8CD70B742408DF161F6B22B4A404F75C8CD70B742400457790261314A4014CE6E2D93C342400457790261314A4014CE6E2D93C342408DF161F6B22B4A404F75C8CD70B742408DF161F6B22B4A40
49153	Козьминка	1	11	1236	37.755437000000001	37.794837000000001	52.464796999999997	52.438706000000003	0103000020E610000001000000050000001C98DC28B2E042408D47A98427384A401C98DC28B2E04240B323D5777E3B4A404C530438BDE54240B323D5777E3B4A404C530438BDE542408D47A98427384A401C98DC28B2E042408D47A98427384A40
47768	Калинино	1	11	1236	37.901296000000002	37.933249000000004	52.392335000000003	52.376438999999998	0103000020E610000001000000050000000002D6AA5DF342402FF834272F304A400002D6AA5DF34240C009850838324A402A0307B474F74240C009850838324A402A0307B474F742402FF834272F304A400002D6AA5DF342402FF834272F304A40
49398	Казанское	1	11	1236	37.725693999999997	37.763728	52.289610000000003	52.259942000000002	0103000020E61000000100000005000000A3737E8AE3DC4240AD6D8AC745214A40A3737E8AE3DC42401B4CC3F011254A400E85CFD6C1E142401B4CC3F011254A400E85CFD6C1E14240AD6D8AC745214A40A3737E8AE3DC4240AD6D8AC745214A40
49000	Зубцово	1	11	1236	37.508085999999999	37.527723000000002	52.532456000000003	52.520587999999996	0103000020E6100000010000000500000019C748F608C142405358A9A0A2424A4019C748F608C142408D47A98427444A406B2C616D8CC342408D47A98427444A406B2C616D8CC342405358A9A0A2424A4019C748F608C142405358A9A0A2424A40
13145	Здоровецкие Выселки	1	11	1236	37.493819999999999	37.523285000000001	52.527892000000001	52.489677	0103000020E610000001000000050000002C0E677E35BF42403C4D66BCAD3E4A402C0E677E35BF4240F7E80DF791434A4062BEBC00FBC24240F7E80DF791434A4062BEBC00FBC242403C4D66BCAD3E4A402C0E677E35BF42403C4D66BCAD3E4A40
49531	Заречный	1	11	1236	37.688467000000003	37.696120999999998	52.352412000000001	52.344326000000002	0103000020E6100000010000000500000008B0C8AF1FD84240CD94D6DF122C4A4008B0C8AF1FD84240E65B1FD61B2D4A408787307E1AD94240E65B1FD61B2D4A408787307E1AD94240CD94D6DF122C4A4008B0C8AF1FD84240CD94D6DF122C4A40
47490	Зареченский	1	11	1236	37.68562	37.690021000000002	52.297057000000002	52.291488000000001	0103000020E61000000100000005000000E4BD6A65C2D742409696917A4F254A40E4BD6A65C2D742402106BAF605264A40D046AE9B52D842402106BAF605264A40D046AE9B52D842409696917A4F254A40E4BD6A65C2D742409696917A4F254A40
49330	Жерино	1	11	1236	37.765318000000001	37.797262000000003	52.350658000000003	52.332979999999999	0103000020E610000001000000050000002385B2F0F5E142406D1CB1169F2A4A402385B2F0F5E14240570A815CE22C4A40FA2B64AE0CE64240570A815CE22C4A40FA2B64AE0CE642406D1CB1169F2A4A402385B2F0F5E142406D1CB1169F2A4A40
49376	Екатериновка	1	11	1236	37.681083000000001	37.695976999999999	52.259323999999999	52.237566999999999	0103000020E61000000100000005000000486E4DBA2DD74240EECD6F98681E4A40486E4DBA2DD74240B188618731214A4054E23AC615D94240B188618731214A4054E23AC615D94240EECD6F98681E4A40486E4DBA2DD74240EECD6F98681E4A40
13281	Гремячий Колодезь	1	11	1236	37.633885999999997	37.649472000000003	52.558627999999999	52.534187000000003	0103000020E6100000010000000500000035B22B2D23D142406479573D60444A4035B22B2D23D14240A0504F1F81474A4078D503E621D34240A0504F1F81474A4078D503E621D342406479573D60444A4035B22B2D23D142406479573D60444A40
49252	Горностаевка	1	11	1236	37.541412999999999	37.562190999999999	52.535682000000001	52.383805000000002	0103000020E610000001000000050000008B506C054DC542404985B18520314A408B506C054DC5424027874F3A91444A40828DEBDFF5C7424027874F3A91444A40828DEBDFF5C742404985B18520314A408B506C054DC542404985B18520314A40
14570	Вязовая Дубрава	1	11	1236	37.857728000000002	37.887569999999997	52.310707999999998	52.289417	0103000020E61000000100000005000000876EF607CAED424006F4C29D0B254A40876EF607CAED4240834D9D47C5274A409274CDE49BF14240834D9D47C5274A409274CDE49BF1424006F4C29D0B254A40876EF607CAED424006F4C29D0B254A40
13339	Воротынск	1	11	1236	37.608401000000001	37.654682000000001	52.520527999999999	52.490718999999999	0103000020E6100000010000000500000046ED7E15E0CD42404E4354E1CF3E4A4046ED7E15E0CD42407E5358A9A0424A40D3A3A99ECCD342407E5358A9A0424A40D3A3A99ECCD342404E4354E1CF3E4A4046ED7E15E0CD42404E4354E1CF3E4A40
13632	Викторовка	1	11	1236	37.858384000000001	37.879862000000003	52.389961	52.376311999999999	0103000020E6100000010000000500000070B4E386DFED4240D28BDAFD2A304A4070B4E386DFED424094DBF63DEA314A40207F69519FF0424094DBF63DEA314A40207F69519FF04240D28BDAFD2A304A4070B4E386DFED4240D28BDAFD2A304A40
49306	Введенское	1	11	1236	37.407780000000002	37.427992000000003	52.286189	52.266604999999998	0103000020E6100000010000000500000040FB912232B442409CF9D51C20224A4040FB912232B44240CBBC55D7A1244A408E791D71C8B64240CBBC55D7A1244A408E791D71C8B642409CF9D51C20224A4040FB912232B442409CF9D51C20224A40
54616	Вахново	1	11	1236	37.442365000000002	37.481918	52.292324999999998	52.264285000000001	0103000020E6100000010000000500000091F2936A9FB8424064E94317D4214A4091F2936A9FB84240CF66D5E76A254A4047AD307DAFBD4240CF66D5E76A254A4047AD307DAFBD424064E94317D4214A4091F2936A9FB8424064E94317D4214A40
12684	Важжова	1	11	1236	37.307734000000004	37.322602000000003	52.313918000000001	52.301523000000003	0103000020E6100000010000000500000003EFE4D363A74240F4FE3F4E98264A4003EFE4D363A7424018D00B772E284A40E6CFB7054BA9424018D00B772E284A40E6CFB7054BA94240F4FE3F4E98264A4003EFE4D363A74240F4FE3F4E98264A40
54653	Барково	1	11	1236	37.552624000000002	37.577866999999998	52.382513000000003	52.367635999999997	0103000020E610000001000000050000000B7E1B62BCC64240876A4AB20E2F4A400B7E1B62BCC64240BEA59C2FF6304A400438BD8BF7C94240BEA59C2FF6304A400438BD8BF7C94240876A4AB20E2F4A400B7E1B62BCC64240876A4AB20E2F4A40
49318	Бараново	1	11	1236	37.466116	37.511507999999999	52.271301000000001	52.241587000000003	0103000020E61000000100000005000000381268B0A9BB4240C311A452EC1E4A40381268B0A9BB4240A12FBDFDB9224A4039D2191879C14240A12FBDFDB9224A4039D2191879C14240C311A452EC1E4A40381268B0A9BB4240C311A452EC1E4A40
48965	Яковлево	1	11	1180	35.927266000000003	35.937291999999999	52.624665999999998	52.616700000000002	0103000020E61000000100000005000000AC58FCA6B0F64140BBB88D06F04E4A40AC58FCA6B0F641402976340EF54F4A40B6662B2FF9F741402976340EF54F4A40B6662B2FF9F74140BBB88D06F04E4A40AC58FCA6B0F64140BBB88D06F04E4A40
54606	Шоссе	1	11	1180	35.750917999999999	35.764384	52.556218999999999	52.550649999999997	0103000020E6100000010000000500000026FDBD141EE041406DC5FEB27B464A4026FDBD141EE04140F834272F32474A40F7CABC55D7E14140F834272F32474A40F7CABC55D7E141406DC5FEB27B464A4026FDBD141EE041406DC5FEB27B464A40
54638	Шахово	1	11	1180	35.846364000000001	35.863754999999998	52.765236000000002	52.751721000000003	0103000020E610000001000000050000008141D2A755EC4140B45BCB6438604A408141D2A755EC414066DCD440F3614A40D4601A868FEE414066DCD440F3614A40D4601A868FEE4140B45BCB6438604A408141D2A755EC4140B45BCB6438604A40
11314	Черкасская	1	11	1180	35.789042999999999	35.806479000000003	52.699962999999997	52.691721999999999	0103000020E61000000100000005000000A1116C5CFFE441403CF6B3588A584A40A1116C5CFFE441407CB4386398594A4095F430B43AE741407CB4386398594A4095F430B43AE741403CF6B3588A584A40A1116C5CFFE441403CF6B3588A584A40
11223	Стрелецкая	1	11	1180	35.763387000000002	35.776646	52.714171	52.696993999999997	0103000020E6100000010000000500000085984BAAB6E141400DC1711937594A4085984BAAB6E14140356090F4695B4A40DC48D92269E34140356090F4695B4A40DC48D92269E341400DC1711937594A4085984BAAB6E141400DC1711937594A40
48513	Семенково	1	11	1180	35.938423	35.959614999999999	52.591399000000003	52.558705000000003	0103000020E610000001000000050000003868AF3E1EF841404C8E3BA583474A403868AF3E1EF841408DF161F6B24B4A4022E010AAD4FA41408DF161F6B24B4A4022E010AAD4FA41404C8E3BA583474A403868AF3E1EF841404C8E3BA583474A40
46375	Рыжково	1	11	1180	35.567473	35.579878999999998	52.645975	52.643101000000001	0103000020E61000000100000005000000772E8CF4A2C841403083312251524A40772E8CF4A2C841404D840D4FAF524A408F519E7939CA41404D840D4FAF524A408F519E7939CA41403083312251524A40772E8CF4A2C841403083312251524A40
48467	Родина	1	11	1180	35.891424000000001	35.901916	52.679920000000003	52.671495	0103000020E610000001000000050000004C6F7F2E1AF24140B936548CF3554A404C6F7F2E1AF24140BBF2599E07574A409CDEC5FB71F34140BBF2599E07574A409CDEC5FB71F34140B936548CF3554A404C6F7F2E1AF24140B936548CF3554A40
48731	Ржава	1	11	1180	35.683031999999997	35.707529000000001	52.603406	52.588883000000003	0103000020E610000001000000050000008C0FB3976DD74140CF15A584604B4A408C0FB3976DD74140E71A66683C4D4A405DFC6D4F90DA4140E71A66683C4D4A405DFC6D4F90DA4140CF15A584604B4A408C0FB3976DD74140CF15A584604B4A40
11701	Ретяжи	1	11	1180	35.920816000000002	35.937964999999998	52.601830999999997	52.594659999999998	0103000020E6100000010000000500000018D1764CDDF54140A31EA2D11D4C4A4018D1764CDDF54140075C57CC084D4A4075E5B33C0FF84140075C57CC084D4A4075E5B33C0FF84140A31EA2D11D4C4A4018D1764CDDF54140A31EA2D11D4C4A40
60468	Рассыльная	1	11	1180	35.468595999999998	36.094892000000002	52.845196999999999	52.487198999999997	0103000020E61000000100000005000000A98427F4FABB41406BD26D895C3E4A40A98427F4FABB4140B2D6506A2F6C4A407653CA6B250C4240B2D6506A2F6C4A407653CA6B250C42406BD26D895C3E4A40A98427F4FABB41406BD26D895C3E4A40
12494	Рассоховец	1	11	1180	35.635052999999999	35.653658	52.555348000000002	52.541702000000001	0103000020E61000000100000005000000041DAD6A49D14140C216BB7D56454A40041DAD6A49D1414013F3ACA415474A406762BA10ABD3414013F3ACA415474A406762BA10ABD34140C216BB7D56454A40041DAD6A49D14140C216BB7D56454A40
11344	Пушкарная	1	11	1180	35.731712000000002	35.767178000000001	52.702457000000003	52.696666999999998	0103000020E610000001000000050000009E0B23BDA8DD4140E9995E622C594A409E0B23BDA8DD414053EC681CEA594A40F81A82E332E2414053EC681CEA594A40F81A82E332E24140E9995E622C594A409E0B23BDA8DD4140E9995E622C594A40
47343	Моховое	1	11	1180	35.812848000000002	35.860719000000003	52.560194000000003	52.535091000000001	0103000020E610000001000000050000003C4F3C670BE8414025B1A4DC7D444A403C4F3C670BE841402DB5DE6FB4474A40DE054A0A2CEE41402DB5DE6FB4474A40DE054A0A2CEE414025B1A4DC7D444A403C4F3C670BE8414025B1A4DC7D444A40
12188	Малая Драгунская	1	11	1180	35.681559	35.715021	52.677889	52.662543999999997	0103000020E61000000100000005000000B1A547533DD741409C14E63DCE544A40B1A547533DD74140B9A81611C5564A40037AE1CE85DB4140B9A81611C5564A40037AE1CE85DB41409C14E63DCE544A40B1A547533DD741409C14E63DCE544A40
48816	Макеево	1	11	1180	35.956640999999998	36.018751000000002	52.539095000000003	52.527042999999999	0103000020E61000000100000005000000A181583673FA4140F94A202576434A40A181583673FA4140F437A11001454A4037E2C96E66024240F437A11001454A4037E2C96E66024240F94A202576434A40A181583673FA4140F94A202576434A40
12284	Кутафино	1	11	1180	35.580767999999999	35.645124000000003	52.642679999999999	52.62818	0103000020E610000001000000050000001B48179B56CA41402A00C63368504A401B48179B56CA41408AE5965643524A40AFEE586C93D241408AE5965643524A40AFEE586C93D241402A00C63368504A401B48179B56CA41402A00C63368504A40
11969	Кромы	1	11	1180	35.735458000000001	35.808903999999998	52.710571000000002	52.676397999999999	0103000020E6100000010000000500000071CADC7C23DE4140378AAC3594564A4071CADC7C23DE4140363E93FDF35A4A4042CD902A8AE74140363E93FDF35A4A4042CD902A8AE74140378AAC3594564A4071CADC7C23DE4140378AAC3594564A40
11413	Кромской	1	11	1180	35.758786999999998	35.764679999999998	52.635592000000003	52.630760000000002	0103000020E61000000100000005000000A2D0B2EE1FE14140FFCF61BEBC504A40A2D0B2EE1FE14140B4CC22145B514A40E0F3C308E1E14140B4CC22145B514A40E0F3C308E1E14140FFCF61BEBC504A40A2D0B2EE1FE14140FFCF61BEBC504A40
54583	Кромский Мост	1	11	1180	35.711787999999999	35.736015000000002	52.679423	52.660676000000002	0103000020E61000000100000005000000B6D782DE1BDB414045A0FA0791544A40B6D782DE1BDB41403A933655F7564A40C72E51BD35DE41403A933655F7564A40C72E51BD35DE414045A0FA0791544A40B6D782DE1BDB414045A0FA0791544A40
11527	Кривчиково	1	11	1180	35.887300000000003	35.897019999999998	52.719647999999999	52.702381000000003	0103000020E61000000100000005000000D3DEE00B93F14140782AE09EE7594A40D3DEE00B93F14140DF50F86C1D5C4A40D0ED258DD1F24140DF50F86C1D5C4A40D0ED258DD1F24140782AE09EE7594A40D3DEE00B93F14140782AE09EE7594A40
46527	Красный Октябрь	1	11	1180	35.84225	35.855922	52.623156999999999	52.618110999999999	0103000020E610000001000000050000002B8716D9CEEB41402026E1421E4F4A402B8716D9CEEB414001A3CB9BC34F4A40A5F622DA8EED414001A3CB9BC34F4A40A5F622DA8EED41402026E1421E4F4A402B8716D9CEEB41402026E1421E4F4A40
60416	Красниково	1	11	1180	35.620573	35.635618999999998	52.539203999999998	52.527529999999999	0103000020E61000000100000005000000EBE3A1EF6ECF414056D4601A86434A40EBE3A1EF6ECF4140AAEFFCA204454A40ADDBA0F65BD14140AAEFFCA204454A40ADDBA0F65BD1414056D4601A86434A40EBE3A1EF6ECF414056D4601A86434A40
48797	Короськово	1	11	1180	35.935907999999998	35.949446000000002	52.556711999999997	52.536427000000003	0103000020E610000001000000050000004A0856D5CBF7414080D8D2A3A9444A404A0856D5CBF7414037A5BC5642474A40B5A84F7287F9414037A5BC5642474A40B5A84F7287F9414080D8D2A3A9444A404A0856D5CBF7414080D8D2A3A9444A40
54580	Коровье Болото	1	11	1180	35.692258000000002	35.723457000000003	52.801701999999999	52.783149000000002	0103000020E610000001000000050000007B32FFE89BD841409372F7393E644A407B32FFE89BD84140A391CF2B9E664A40F9872D3D9ADC4140A391CF2B9E664A40F9872D3D9ADC41409372F7393E644A407B32FFE89BD841409372F7393E644A40
60420	Глинки	1	11	1180	35.624220000000001	35.654125000000001	52.671719000000003	52.651646	0103000020E610000001000000050000002BC1E270E6CF4140DC48D92269534A402BC1E270E6CF4140098D60E3FA554A407D3F355EBAD34140098D60E3FA554A407D3F355EBAD34140DC48D92269534A402BC1E270E6CF4140DC48D92269534A40
12330	Бельдяжки	1	11	1180	35.677543999999997	35.722118000000002	52.632165000000001	52.617809999999999	0103000020E61000000100000005000000EECC04C3B9D641402592E865144F4A40EECC04C3B9D64140825660C8EA504A402DEDD45C6EDC4140825660C8EA504A402DEDD45C6EDC41402592E865144F4A40EECC04C3B9D641402592E865144F4A40
11435	Атяевка	1	11	1180	35.782412999999998	35.799571	52.680084000000001	52.670904999999998	0103000020E610000001000000050000008D7BF31B26E4414087DC0C37E0554A408D7BF31B26E44140354415FE0C574A403EEAAF5758E64140354415FE0C574A403EEAAF5758E6414087DC0C37E0554A408D7BF31B26E4414087DC0C37E0554A40
48453	Арбузово	1	11	1180	35.929215999999997	35.947406999999998	52.640838000000002	52.623550000000002	0103000020E61000000100000005000000C075C58CF0F64140DDB5847CD04F4A40C075C58CF0F641405C04C6FA06524A403080F0A144F941405C04C6FA06524A403080F0A144F94140DDB5847CD04F4A40C075C58CF0F64140DDB5847CD04F4A40
54649	Шатилово	1	11	1135	37.770690000000002	37.815651000000003	52.767961	52.747256	0103000020E6100000010000000500000058AD4CF8A5E24240B1DEA815A65F4A4058AD4CF8A5E242403ECDC98B4C624A4090F9804067E842403ECDC98B4C624A4090F9804067E84240B1DEA815A65F4A4058AD4CF8A5E24240B1DEA815A65F4A40
10611	Россошенский	1	11	1135	37.656416	37.682808000000001	52.777695999999999	52.762261000000002	0103000020E610000001000000050000001B49827005D442401502B9C491614A401B49827005D44240711DE38A8B634A403DB9A64066D74240711DE38A8B634A403DB9A64066D742401502B9C491614A401B49827005D442401502B9C491614A40
54663	Протасово	1	11	1135	37.553198999999999	37.572702	52.679177000000003	52.669108000000001	0103000020E6100000010000000500000007978E39CFC64240F9BEB854A5554A4007978E39CFC6424003999D45EF564A40492D944C4EC9424003999D45EF564A40492D944C4EC94240F9BEB854A5554A4007978E39CFC64240F9BEB854A5554A40
10837	Пол-Успенье	1	11	1135	37.777203	37.796444999999999	52.666410999999997	52.655273000000001	0103000020E6100000010000000500000032AD4D637BE34240D57954FCDF534A4032AD4D637BE34240EA58A5F44C554A400708E6E8F1E54240EA58A5F44C554A400708E6E8F1E54240D57954FCDF534A4032AD4D637BE34240D57954FCDF534A40
54666	Покровское	1	11	1135	37.423167999999997	37.487793000000003	52.735621999999999	52.700972999999998	0103000020E610000001000000050000005B5B785E2AB642408330B77BB9594A405B5B785E2AB64240EB1B98DC285E4A40DF1B430070BE4240EB1B98DC285E4A40DF1B430070BE42408330B77BB9594A405B5B785E2AB642408330B77BB9594A40
10516	Орево	1	11	1135	37.610340999999998	37.690083999999999	52.847155000000001	52.815496000000003	0103000020E61000000100000005000000373465A71FCE42406902452C62684A40373465A71FCE42404AD235936F6C4A4016BF29AC54D842404AD235936F6C4A4016BF29AC54D842406902452C62684A40373465A71FCE42406902452C62684A40
46635	Медвежье	1	11	1135	37.633552999999999	37.647136000000003	52.668677000000002	52.654066	0103000020E610000001000000050000002FA4C34318D1424078B6476FB8534A402FA4C34318D14240304B3B3597554A403A083A5AD5D24240304B3B3597554A403A083A5AD5D2424078B6476FB8534A402FA4C34318D1424078B6476FB8534A40
48190	Малиново	1	11	1135	37.836751999999997	37.889437999999998	52.778018000000003	52.751753999999998	0103000020E61000000100000005000000696E85B01AEB42408F519E7939604A40696E85B01AEB424084D9041896634A40EAE8B81AD9F1424084D9041896634A40EAE8B81AD9F142408F519E7939604A40696E85B01AEB42408F519E7939604A40
54565	Красная Заря	1	11	1135	37.656748	37.697189999999999	52.796022999999998	52.778415000000003	0103000020E6100000010000000500000051DB865110D44240A1DB4B1AA3634A4051DB865110D4424091EEE714E4654A40938C9C853DD9424091EEE714E4654A40938C9C853DD94240A1DB4B1AA3634A4051DB865110D44240A1DB4B1AA3634A40
10901	Зверево-Бакулино	1	11	1135	37.683481999999998	37.718085000000002	52.664766999999998	52.654552000000002	0103000020E61000000100000005000000CCB392567CD7424005C4245CC8534A40CCB392567CD74240E23AC61517554A40C45F9335EADB4240E23AC61517554A40C45F9335EADB424005C4245CC8534A40CCB392567CD7424005C4245CC8534A40
10590	Верхняя Любовша	1	11	1135	37.509459999999997	37.557187999999996	52.824921000000003	52.785763000000003	0103000020E61000000100000005000000614F3BFC35C1424014B4C9E193644A40614F3BFC35C142404E64E60297694A40A0DCB6EF51C742404E64E60297694A40A0DCB6EF51C7424014B4C9E193644A40614F3BFC35C1424014B4C9E193644A40
10797	Большая Чернава	1	11	1135	37.669494999999998	37.728487000000001	52.733403000000003	52.705818000000001	0103000020E61000000100000005000000F2EA1C03B2D54240CD76853E585A4A40F2EA1C03B2D54240E7E44526E05D4A40D447E00F3FDD4240E7E44526E05D4A40D447E00F3FDD4240CD76853E585A4A40F2EA1C03B2D54240CD76853E585A4A40
48098	Бегичево	1	11	1135	37.700468999999998	37.741342000000003	52.758926000000002	52.74579	0103000020E61000000100000005000000506EDBF7A8D9424088D7F50B765F4A40506EDBF7A8D94240C40AB77C24614A405C936E4BE4DE4240C40AB77C24614A405C936E4BE4DE424088D7F50B765F4A40506EDBF7A8D9424088D7F50B765F4A40
18994	Страховка	1	11	1571	37.507699000000002	37.518388999999999	53.135269000000001	53.127543000000003	0103000020E61000000100000005000000209BE447FCC04240B8EA3A5453904A40209BE447FCC04240D1949D7E50914A4096CD1C925AC24240D1949D7E50914A4096CD1C925AC24240B8EA3A5453904A40209BE447FCC04240B8EA3A5453904A40
19084	Спешнево	1	11	1571	37.067335999999997	37.093414000000003	53.230863999999997	53.216475000000003	0103000020E61000000100000005000000F6EB4E779E88424068B3EA73B59B4A40F6EB4E779E88424070E998F38C9D4A40897E6DFDF48B424070E998F38C9D4A40897E6DFDF48B424068B3EA73B59B4A40F6EB4E779E88424068B3EA73B59B4A40
49046	Петрово	1	11	1571	37.373463999999998	37.386336999999997	53.245888999999998	53.236373	0103000020E61000000100000005000000DE1D19ABCDAF424026547078419E4A40DE1D19ABCDAF42401BB96E4A799F4A400C1EA67D73B142401BB96E4A799F4A400C1EA67D73B1424026547078419E4A40DE1D19ABCDAF424026547078419E4A40
19354	Парамоново	1	11	1571	37.370418999999998	37.388089000000001	53.169884000000003	53.159114000000002	0103000020E610000001000000050000009468C9E369AF4240FA2AF9D85D944A409468C9E369AF42408D0E48C2BE954A40FB777DE6ACB142408D0E48C2BE954A40FB777DE6ACB14240FA2AF9D85D944A409468C9E369AF4240FA2AF9D85D944A40
60411	Образцово	1	11	1571	37.119151000000002	37.136488999999997	53.251336999999999	53.241622	0103000020E6100000010000000500000092240857408F42403FFF3D78ED9E4A4092240857408F42402BA391CF2BA04A40C2A1B778789142402BA391CF2BA04A40C2A1B778789142403FFF3D78ED9E4A4092240857408F42403FFF3D78ED9E4A40
19033	Новомихайловка	1	11	1571	37.366061999999999	37.383974000000002	53.131439	53.114541000000003	0103000020E6100000010000000500000078279F1EDBAE42408C868C47A98E4A4078279F1EDBAE4240A0353FFED2904A40D5415E0F26B14240A0353FFED2904A40D5415E0F26B142408C868C47A98E4A4078279F1EDBAE42408C868C47A98E4A40
19377	Новомалиново	1	11	1571	37.287027999999999	37.302030000000002	53.216642	53.205339000000002	0103000020E61000000100000005000000A5846055BDA44240F3CB608C489A4A40A5846055BDA442405378D0ECBA9B4A40983446EBA8A642405378D0ECBA9B4A40983446EBA8A64240F3CB608C489A4A40A5846055BDA44240F3CB608C489A4A40
19458	Нечаево	1	11	1571	37.407429	37.440640000000002	53.189512000000001	53.176037000000001	0103000020E6100000010000000500000093382BA226B4424067F1626188964A4093382BA226B442408B19E1ED41984A409CA73AE466B842408B19E1ED41984A409CA73AE466B8424067F1626188964A4093382BA226B4424067F1626188964A40
19180	Мельничная Слобода	1	11	1571	37.196297999999999	37.209108000000001	53.146397	53.135420000000003	0103000020E610000001000000050000009622F94A20994240B79C4B7155914A409622F94A20994240C39D0B23BD924A407EAA0A0DC49A4240C39D0B23BD924A407EAA0A0DC49A4240B79C4B7155914A409622F94A20994240B79C4B7155914A40
19129	Малое Теплое	1	11	1571	37.030155000000001	37.055056	53.251348	53.240560000000002	0103000020E61000000100000005000000CB67791EDC834240E65C8AABCA9E4A40CB67791EDC8342401FF5D72B2CA04A406BB933130C8742401FF5D72B2CA04A406BB933130C874240E65C8AABCA9E4A40CB67791EDC834240E65C8AABCA9E4A40
19251	Корсаково	1	11	1571	37.348500000000001	37.369484999999997	53.271352999999998	53.262208000000001	0103000020E61000000100000005000000F853E3A59BAC4240F25F200890A14A40F853E3A59BAC4240F355F2B1BBA24A4068AED3484BAF4240F355F2B1BBA24A4068AED3484BAF4240F25F200890A14A40F853E3A59BAC4240F25F200890A14A40
60432	Глотово	1	11	1571	37.000295000000001	37.015583999999997	53.218524000000002	53.210456999999998	0103000020E6100000010000000500000019ADA3AA098042406D1B4641F09A4A4019ADA3AA0980424010B22C98F89B4A40A12B11A8FE81424010B22C98F89B4A40A12B11A8FE8142406D1B4641F09A4A4019ADA3AA098042406D1B4641F09A4A40
25809	Гагаринский Хутор	1	11	1571	37.203206000000002	37.226500000000001	53.137770000000003	53.130049999999997	0103000020E61000000100000005000000ED2C7AA7029A4240226C787AA5904A40ED2C7AA7029A42405A2F8672A2914A40A245B6F3FD9C42405A2F8672A2914A40A245B6F3FD9C4240226C787AA5904A40ED2C7AA7029A4240226C787AA5904A40
18928	Большие Озерки	1	11	1571	37.452272999999998	37.479807000000001	53.219360000000002	53.206957000000003	0103000020E6100000010000000500000091EEE714E4B94240D25625917D9A4A4091EEE714E4B9424079060DFD139C4A4029B2D6506ABD424079060DFD139C4A4029B2D6506ABD4240D25625917D9A4A4091EEE714E4B94240D25625917D9A4A40
10263	Ярище	1	11	1062	37.120058	37.152326000000002	52.251120999999998	52.229514000000002	0103000020E61000000100000005000000C4CF7F0F5E8F4240B1FCF9B6601D4A40C4CF7F0F5E8F42405E2BA1BB24204A404E2A1A6B7F9342405E2BA1BB24204A404E2A1A6B7F934240B1FCF9B6601D4A40C4CF7F0F5E8F4240B1FCF9B6601D4A40
9562	Яковка	1	11	1062	37.216555	37.242013999999998	52.131312999999999	52.115144999999998	0103000020E6100000010000000500000084640113B89B424022A64412BD0E4A4084640113B89B4240134548DDCE104A404A969350FA9E4240134548DDCE104A404A969350FA9E424022A64412BD0E4A4084640113B89B424022A64412BD0E4A40
10063	Хутор Лимовое	1	11	1062	37.21219	37.238779999999998	52.225520000000003	52.210357999999999	0103000020E61000000100000005000000E544BB0A299B4240DA39CD02ED1A4A40E544BB0A299B4240064CE0D6DD1C4A402D78D157909E4240064CE0D6DD1C4A402D78D157909E4240DA39CD02ED1A4A40E544BB0A299B4240DA39CD02ED1A4A40
10347	Фошня	1	11	1062	37.223346999999997	37.238303999999999	52.302227999999999	52.295051999999998	0103000020E6100000010000000500000071546EA2969C4240484F9143C4254A4071546EA2969C4240BEF73768AF264A40C440D7BE809E4240BEF73768AF264A40C440D7BE809E4240484F9143C4254A4071546EA2969C4240484F9143C4254A40
10115	Ушаково	1	11	1062	37.143684	37.185167999999997	52.399402000000002	52.364803999999999	0103000020E61000000100000005000000AF7AC03C6492424099B9C0E5B12E4A40AF7AC03C649242407FFACF9A1F334A400322C495B39742407FFACF9A1F334A400322C495B397424099B9C0E5B12E4A40AF7AC03C6492424099B9C0E5B12E4A40
60407	Ульяновка	1	11	1062	37.198399999999999	37.217364000000003	52.100548000000003	52.092061000000001	0103000020E6100000010000000500000061C3D32B65994240581EA4A7C80B4A4061C3D32B65994240D0D6C1C1DE0C4A40F4A96395D29B4240D0D6C1C1DE0C4A40F4A96395D29B4240581EA4A7C80B4A4061C3D32B65994240581EA4A7C80B4A40
10039	Тимирязево	1	11	1062	37.103107000000001	37.114739999999998	52.221167999999999	52.209139	0103000020E610000001000000050000008D7E349C328D4240B9A81611C51A4A408D7E349C328D4240FB75A73B4F1C4A4082C5E1CCAF8E4240FB75A73B4F1C4A4082C5E1CCAF8E4240B9A81611C51A4A408D7E349C328D4240B9A81611C51A4A40
48856	Струково	1	11	1062	36.944797000000001	36.957140000000003	52.266291000000002	52.260807	0103000020E61000000100000005000000F12DAC1BEF784240B0C8AF1F62214A40F12DAC1BEF7842400D1CD0D215224A40C3D84290837A42400D1CD0D215224A40C3D84290837A4240B0C8AF1F62214A40F12DAC1BEF784240B0C8AF1F62214A40
54597	Остров	1	11	1062	37.168638999999999	37.189641999999999	52.305714000000002	52.294919999999998	0103000020E6100000010000000500000042EA76F695954240D97745F0BF254A4042EA76F695954240F5F6E7A221274A4059F9653046984240F5F6E7A221274A4059F9653046984240D97745F0BF254A4042EA76F695954240D97745F0BF254A40
9893	Нетрубеж	1	11	1062	36.782184000000001	36.846926000000003	52.164476000000001	52.138924000000003	0103000020E610000001000000050000002CBAF59A1E6442409450FA42C8114A402CBAF59A1E6442400B7DB08C0D154A40E9103812686C42400B7DB08C0D154A40E9103812686C42409450FA42C8114A402CBAF59A1E6442409450FA42C8114A40
54363	Моховое	1	11	1062	36.886972999999998	37.244179000000003	52.161537000000003	52.103281000000003	0103000020E61000000100000005000000AEB7CD54887142402BA6D24F380D4A40AEB7CD5488714240070C923EAD144A405CAFE941419F4240070C923EAD144A405CAFE941419F42402BA6D24F380D4A40AEB7CD54887142402BA6D24F380D4A40
9816	Мисайлово	1	11	1062	36.738309999999998	36.777315000000002	52.286105999999997	52.269333000000003	0103000020E61000000100000005000000A6272CF1805E4240E65DF58079224A40A6272CF1805E42403D98141F9F244A405AD8D30E7F6342403D98141F9F244A405AD8D30E7F634240E65DF58079224A40A6272CF1805E4240E65DF58079224A40
10214	Маркино	1	11	1062	37.021144999999997	37.059584000000001	52.382123	52.369053999999998	0103000020E61000000100000005000000A9BC1DE1B48242409F3A56293D2F4A40A9BC1DE1B482424053060E68E9304A40B4AED172A087424053060E68E9304A40B4AED172A08742409F3A56293D2F4A40A9BC1DE1B48242409F3A56293D2F4A40
9873	Крутое	1	11	1062	36.845911000000001	37.202128000000002	52.196753000000001	52.116548999999999	0103000020E61000000100000005000000D029C8CF466C4240D5B0DF13EB0E4A40D029C8CF466C4240E831CA332F194A408ECD8E54DF994240E831CA332F194A408ECD8E54DF994240D5B0DF13EB0E4A40D029C8CF466C4240D5B0DF13EB0E4A40
9749	Красное	1	11	1062	36.824691999999999	36.855963000000003	52.263061	52.242573999999998	0103000020E61000000100000005000000ECA2E8818F694240116E32AA0C1F4A40ECA2E8818F69424031ED9BFBAB214A4004CB1132906D424031ED9BFBAB214A4004CB1132906D4240116E32AA0C1F4A40ECA2E8818F694240116E32AA0C1F4A40
54561	Колпны	1	11	1062	36.999361	37.063383999999999	52.231721	52.210087999999999	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
9662	Клевцово	1	11	1062	37.030577000000001	37.242291999999999	52.317166	52.250414999999997	0103000020E61000000100000005000000418177F2E9834240C3B645990D204A40418177F2E98342409AB33EE598284A408D0A9C6C039F42409AB33EE598284A408D0A9C6C039F4240C3B645990D204A40418177F2E9834240C3B645990D204A40
9587	Знаменское	1	11	1062	36.988742999999999	37.016896000000003	52.164878999999999	52.126308999999999	0103000020E61000000100000005000000109370218F7E42406118B0E42A104A40109370218F7E42400A664CC11A154A4074B7EBA5298242400A664CC11A154A4074B7EBA5298242406118B0E42A104A40109370218F7E42406118B0E42A104A40
9971	Дровосечное	1	11	1062	36.730961999999998	36.761082999999999	52.217184000000003	52.198210000000003	0103000020E61000000100000005000000334FAE29905D4240BEDEFDF15E194A40334FAE29905D4240749B70AFCC1B4A405245F12A6B614240749B70AFCC1B4A405245F12A6B614240BEDEFDF15E194A40334FAE29905D4240BEDEFDF15E194A40
10333	Городецкое	1	11	1062	37.242345999999998	37.268101000000001	52.26493	52.250729999999997	0103000020E6100000010000000500000080289831059F42402310AFEB17204A4080289831059F424059DDEA39E9214A403083312251A2424059DDEA39E9214A403083312251A242402310AFEB17204A4080289831059F42402310AFEB17204A40
9435	Вороново	1	11	1062	36.919302999999999	36.939909999999998	52.382519000000002	52.360151000000002	0103000020E61000000100000005000000AE0E80B8AB754240944F8F6D192E4A40AE0E80B8AB754240A08CF161F6304A4078978BF84E784240A08CF161F6304A4078978BF84E784240944F8F6D192E4A40AE0E80B8AB754240944F8F6D192E4A40
48395	Березовка	1	11	1062	36.968890000000002	36.980612999999998	52.214806000000003	52.196626000000002	0103000020E61000000100000005000000F2B56796047C42408BC56F0A2B194A40F2B56796047C4240077E54C37E1B4A4027840EBA847D4240077E54C37E1B4A4027840EBA847D42408BC56F0A2B194A40F2B56796047C42408BC56F0A2B194A40
9525	Белый Колодезь 1-й	1	11	1062	37.081341000000002	37.105334999999997	52.135221000000001	52.123671999999999	0103000020E610000001000000050000007769C361698A424028B7ED7BD40F4A407769C361698A4240C05DF6EB4E114A40E40F069E7B8D4240C05DF6EB4E114A40E40F069E7B8D424028B7ED7BD40F4A407769C361698A424028B7ED7BD40F4A40
9410	Ахтырка	1	11	1062	36.904992999999997	36.940404000000001	52.307355000000001	52.293185000000001	0103000020E61000000100000005000000F10D85CFD6734240C156091687254A40F10D85CFD67342408CA19C6857274A40888384285F7842408CA19C6857274A40888384285F784240C156091687254A40F10D85CFD6734240C156091687254A40
49569	Александровка	1	11	1062	36.955154999999998	37.051031999999999	52.307034999999999	52.160221999999997	0103000020E6100000010000000500000031CEDF84427A4240C30C8D2782144A4031CEDF84427A42401ADD41EC4C274A4055867137888642401ADD41EC4C274A405586713788864240C30C8D2782144A4031CEDF84427A4240C30C8D2782144A40
52112	Рождественский	1	11	7147	39.745223000000003	39.761087000000003	50.771712999999998	50.763641	0103000020E610000001000000050000000F9D9E7763DF43403F7100FDBE6149400F9D9E7763DF4340F372D87DC762494094347F4C6BE14340F372D87DC762494094347F4C6BE143403F7100FDBE6149400F9D9E7763DF43403F7100FDBE614940
11068	Узкое	1	11	1166	35.54983	35.580283000000001	53.340618999999997	53.330381000000003	0103000020E610000001000000050000000A2E56D460C64140221CB3EC49AA4A400A2E56D460C64140B7B2446799AB4A405FB69DB646CA4140B7B2446799AB4A405FB69DB646CA4140221CB3EC49AA4A400A2E56D460C64140221CB3EC49AA4A40
45913	Селихово	1	11	1166	35.726520000000001	35.768121000000001	53.227549000000003	53.203294999999997	0103000020E61000000100000005000000E9F17B9BFEDC41405C381092059A4A40E9F17B9BFEDC4140679E5C53209D4A40772FF7C951E24140679E5C53209D4A40772FF7C951E241405C381092059A4A40E9F17B9BFEDC41405C381092059A4A40
46202	Прилепы	1	11	1166	35.642859999999999	35.805742000000002	53.257877000000001	53.230271000000002	0103000020E610000001000000050000000AF4893C49D24140CE1B2785799D4A400AF4893C49D24140FFB1101D02A14A40BF81C98D22E74140FFB1101D02A14A40BF81C98D22E74140CE1B2785799D4A400AF4893C49D24140CE1B2785799D4A40
26780	Мымрино	1	11	1166	35.482007000000003	35.495806000000002	53.306696000000002	53.299151999999999	0103000020E61000000100000005000000B7B8C667B2BD41403944DC9C4AA64A40B7B8C667B2BD414032E884D041A74A408E942D9276BF414032E884D041A74A408E942D9276BF41403944DC9C4AA64A40B7B8C667B2BD41403944DC9C4AA64A40
45810	Локно	1	11	1166	35.772154	35.815488999999999	53.337736999999997	53.325847000000003	0103000020E61000000100000005000000E0BC38F1D5E24140F73FC05AB5A94A40E0BC38F1D5E2414017D34CF73AAB4A40B69F8CF161E8414017D34CF73AAB4A40B69F8CF161E84140F73FC05AB5A94A40E0BC38F1D5E24140F73FC05AB5A94A40
46026	Коптево	1	11	1166	35.647351	35.674301	53.380358000000001	53.364735000000003	0103000020E610000001000000050000003604C765DCD24140715AF0A2AFAE4A403604C765DCD24140D0622992AFB04A407E54C37E4FD64140D0622992AFB04A407E54C37E4FD64140715AF0A2AFAE4A403604C765DCD24140715AF0A2AFAE4A40
45786	Знаменское	1	11	1166	35.664338000000001	35.704690999999997	53.287139000000003	53.269516000000003	0103000020E61000000100000005000000BABE0F0709D54140D7DF12807FA24A40BABE0F0709D54140FD3383F8C0A44A408C648F5033DA4140FD3383F8C0A44A408C648F5033DA4140D7DF12807FA24A40BABE0F0709D54140D7DF12807FA24A40
27320	Ждимир	1	11	1166	35.617463999999998	35.663072	53.223936999999999	53.205424999999998	0103000020E610000001000000050000008A3A730F09CF4140F163CC5D4B9A4A408A3A730F09CF4140A3AEB5F7A99C4A405872158BDFD44140A3AEB5F7A99C4A405872158BDFD44140F163CC5D4B9A4A408A3A730F09CF4140F163CC5D4B9A4A40
49288	Гнездилово	1	11	1166	35.536203	35.564346999999998	53.250987000000002	53.227274000000001	0103000020E610000001000000050000003082C64CA2C44140959D7E50179D4A403082C64CA2C441404F5C8E5720A04A40404CC2853CC841404F5C8E5720A04A40404CC2853CC84140959D7E50179D4A403082C64CA2C44140959D7E50179D4A40
49321	Вязовая	1	11	1166	35.499200999999999	35.539724	53.291837999999998	53.285663999999997	0103000020E61000000100000005000000B49080D1E5BF414080D250A390A44A40B49080D1E5BF414072DD94F25AA54A40E36E10AD15C5414072DD94F25AA54A40E36E10AD15C5414080D250A390A44A40B49080D1E5BF414080D250A390A44A40
45761	Ворошилово	1	11	1166	35.715803000000001	35.741387000000003	53.300491999999998	53.279688	0103000020E6100000010000000500000079B0C56E9FDB4140B58AFED0CCA34A4079B0C56E9FDB4140D55A988576A64A40FC56EBC4E5DE4140D55A988576A64A40FC56EBC4E5DE4140B58AFED0CCA34A4079B0C56E9FDB4140B58AFED0CCA34A40
61083	хут.Сеина	1	11	973	36.301999000000002	37.044995	53.078496000000001	52.727497	0103000020E610000001000000050000005D363AE7A72642401478279F1E5D4A405D363AE7A7264240F46E2C280C8A4A40E4BD6A65C2854240F46E2C280C8A4A40E4BD6A65C28542401478279F1E5D4A405D363AE7A72642401478279F1E5D4A40
48045	Становое	1	11	973	36.413417000000003	36.436207000000003	52.997191000000001	52.983189000000003	0103000020E61000000100000005000000234E27D9EA344240BB641C23D97D4A40234E27D9EA344240CA6E66F4A37F4A40A5A487A1D5374240CA6E66F4A37F4A40A5A487A1D5374240BB641C23D97D4A40234E27D9EA344240BB641C23D97D4A40
54661	Слобода	1	11	973	36.837817000000001	36.851247000000001	52.867724000000003	52.860553000000003	0103000020E61000000100000005000000348463963D6B4240C3BCC799266E4A40348463963D6B424027FA7C94116F4A40B8E864A9F56C424027FA7C94116F4A40B8E864A9F56C4240C3BCC799266E4A40348463963D6B4240C3BCC799266E4A40
8451	Сетуха	1	11	973	36.762017	36.792442999999999	52.954549	52.937168	0103000020E610000001000000050000007EFFE6C589614240CA6DFB1EF5774A407EFFE6C589614240FAB660A92E7A4A40D978B0C56E654240FAB660A92E7A4A40D978B0C56E654240CA6DFB1EF5774A407EFFE6C589614240CA6DFB1EF5774A40
8881	Ржаное	1	11	973	36.595424000000001	36.629272999999998	52.918678999999997	52.901919999999997	0103000020E6100000010000000500000073A087DA364C4240DDCD531D72734A4073A087DA364C4240D042024697754A40BEA085048C504240D042024697754A40BEA085048C504240DDCD531D72734A4073A087DA364C4240DDCD531D72734A40
54664	Ржавец	1	11	973	36.487769999999998	36.513632999999999	52.880023999999999	52.866745999999999	0103000020E6100000010000000500000026FC523F6F3E42402BF86D88F16E4A4026FC523F6F3E4240F9D85DA0A4704A40BC92E4B9BE414240F9D85DA0A4704A40BC92E4B9BE4142402BF86D88F16E4A4026FC523F6F3E42402BF86D88F16E4A40
9093	Победное	1	11	973	36.644499000000003	36.663291999999998	53.023864000000003	53.012709999999998	0103000020E6100000010000000500000001A777F17E524240842A357BA0814A4001A777F17E524240A0C6BDF90D834A4066D993C0E6544240A0C6BDF90D834A4066D993C0E6544240842A357BA0814A4001A777F17E524240842A357BA0814A40
47272	Ольховец	1	11	973	36.768115999999999	36.804991999999999	52.773747	52.764009999999999	0103000020E6100000010000000500000065C405A05162424092E86514CB614A4065C405A051624240663046240A634A4054C554FA09674240663046240A634A4054C554FA0967424092E86514CB614A4065C405A05162424092E86514CB614A40
47434	Ломовое	1	11	973	36.545622000000002	36.587834000000001	52.864407999999997	52.844647000000002	0103000020E6100000010000000500000033FD12F1D64542400FD594641D6C4A4033FD12F1D64542404C33DDEBA46E4A400ABDFE243E4B42404C33DDEBA46E4A400ABDFE243E4B42400FD594641D6C4A4033FD12F1D64542400FD594641D6C4A40
54665	Красное	1	11	973	36.721009000000002	36.760696000000003	52.836347000000004	52.810487999999999	0103000020E61000000100000005000000938FDD054A5C424075E61E12BE674A40938FDD054A5C4240CA8D226B0D6B4A4059198D7C5E614240CA8D226B0D6B4A4059198D7C5E61424075E61E12BE674A40938FDD054A5C424075E61E12BE674A40
54618	Котлы	1	11	973	36.803268000000003	36.828375000000001	52.859884999999998	52.845137000000001	0103000020E6100000010000000500000030F65E7CD1664240DDD1FF722D6C4A4030F65E7CD166424015A930B6106E4A4079E92631086A424015A930B6106E4A4079E92631086A4240DDD1FF722D6C4A4030F65E7CD1664240DDD1FF722D6C4A40
47328	Казарь	1	11	973	36.837763000000002	36.878214	52.906340999999998	52.887464000000001	0103000020E61000000100000005000000416667D13B6B42404D309C6B98714A40416667D13B6B424010035DFB02744A40D671FC506970424010035DFB02744A40D671FC50697042404D309C6B98714A40416667D13B6B42404D309C6B98714A40
47494	Золотарево	1	11	973	36.379829000000001	36.409590000000001	52.954906999999999	52.931893000000002	0103000020E610000001000000050000004489963C9E304240882F134548774A404489963C9E30424059DC7F643A7A4A406362F3716D34424059DC7F643A7A4A406362F3716D344240882F134548774A404489963C9E304240882F134548774A40
8137	Залегощь	1	11	973	36.874513	36.908971999999999	52.919764999999998	52.882697999999998	0103000020E61000000100000005000000A376BF0AF06F42404F1F813FFC704A40A376BF0AF06F4240B28009DCBA754A40677DCA3159744240B28009DCBA754A40677DCA31597442404F1F813FFC704A40A376BF0AF06F42404F1F813FFC704A40
8619	Верхнее Скворчее	1	11	973	36.855082000000003	36.892972999999998	52.802475000000001	52.768962999999999	0103000020E61000000100000005000000FBB2B453736D4240C26A2C616D624A40FBB2B453736D4240C66D3480B7664A40029B73F04C724240C66D3480B7664A40029B73F04C724240C26A2C616D624A40FBB2B453736D4240C26A2C616D624A40
54581	Васильевка	1	11	973	36.673074999999997	36.946880999999998	52.890152999999998	52.790452000000002	0103000020E61000000100000005000000AA605452275642406687F8872D654A40AA60545227564240D8B79388F0714A40151A886533794240D8B79388F0714A40151A8865337942406687F8872D654A40AA605452275642406687F8872D654A40
46421	Бычки	1	11	973	36.480969999999999	36.490285	53.042059000000002	53.036704	0103000020E61000000100000005000000B62DCA6C903D4240F2D077B7B2844A40B62DCA6C903D424051C0763062854A40145CACA8C13E424051C0763062854A40145CACA8C13E4240F2D077B7B2844A40B62DCA6C903D4240F2D077B7B2844A40
47201	Березовец	1	11	973	36.774279	36.828169000000003	52.898204	52.869861	0103000020E61000000100000005000000637D03931B6342406E88F19A576F4A40637D03931B63424075914259F8724A40D0471971016A424075914259F8724A40D0471971016A42406E88F19A576F4A40637D03931B6342406E88F19A576F4A40
47150	Архангельское	1	11	973	36.710093999999998	36.742209000000003	52.926633000000002	52.904505	0103000020E61000000100000005000000FC8A355CE45A4240C408E1D1C6734A40FC8A355CE45A42407B32FFE89B764A4000E65AB4005F42407B32FFE89B764A4000E65AB4005F4240C408E1D1C6734A40FC8A355CE45A4240C408E1D1C6734A40
40185	Козюлькина	1	11	6867	35.551115000000003	35.564832000000003	52.143456999999998	52.136806999999997	0103000020E61000000100000005000000E3AAB2EF8AC64140936E4BE482114A40E3AAB2EF8AC64140EEB089CC5C124A40FDDD3B6A4CC84140EEB089CC5C124A40FDDD3B6A4CC84140936E4BE482114A40E3AAB2EF8AC64140936E4BE482114A40
7875	Урынок	1	11	896	37.330371999999997	37.360968999999997	52.091479999999997	52.067729999999997	0103000020E61000000100000005000000CEC133A149AA4240A27A6B60AB084A40CEC133A149AA4240791EDC9DB50B4A4056EF703B34AE4240791EDC9DB50B4A4056EF703B34AE4240A27A6B60AB084A40CEC133A149AA4240A27A6B60AB084A40
6968	Тим	1	11	896	37.303234000000003	37.345427999999998	52.190438	52.173938	0103000020E610000001000000050000008484285FD0A642400DC4B29943164A408484285FD0A6424034F5BA4560184A40B48F15FC36AC424034F5BA4560184A40B48F15FC36AC42400DC4B29943164A408484285FD0A642400DC4B29943164A40
7218	Студеное	1	11	896	37.587505999999998	37.644818000000001	52.180692000000001	52.159111000000003	0103000020E61000000100000005000000151A886533CB424089B7CEBF5D144A40151A886533CB42400D535BEA20174A40A2EF6E6589D242400D535BEA20174A40A2EF6E6589D2424089B7CEBF5D144A40151A886533CB424089B7CEBF5D144A40
7400	Рогатик	1	11	896	37.722765000000003	37.770960000000002	52.104055000000002	52.079808	0103000020E61000000100000005000000C3D8429083DC4240C6FA0626370A4A40C3D8429083DC42401EFE9AAC510D4A40184339D1AEE242401EFE9AAC510D4A40184339D1AEE24240C6FA0626370A4A40C3D8429083DC4240C6FA0626370A4A40
52405	Петровка	1	11	896	37.218091999999999	37.245499000000002	52.026698000000003	52.019022999999997	0103000020E6100000010000000500000076C24B70EA9B4240976F7D586F024A4076C24B70EA9B42402F6F0ED76A034A40B119E0826C9F42402F6F0ED76A034A40B119E0826C9F4240976F7D586F024A4076C24B70EA9B4240976F7D586F024A40
7099	Никольское	1	11	896	37.493406999999998	37.530759000000003	52.121045000000002	52.091253000000002	0103000020E61000000100000005000000094FE8F527BF4240B954A52DAE0B4A40094FE8F527BF4240132C0E677E0F4A40628731E9EFC34240132C0E677E0F4A40628731E9EFC34240B954A52DAE0B4A40094FE8F527BF4240B954A52DAE0B4A40
7505	Нижнее Ольшаное	1	11	896	37.694665999999998	37.769477000000002	52.151043999999999	52.134486000000003	0103000020E6100000010000000500000052D2C3D0EAD842408BE255D636114A4052D2C3D0EAD84240E620E86855134A401903EB387EE24240E620E86855134A401903EB387EE242408BE255D636114A4052D2C3D0EAD842408BE255D636114A40
7146	Кривцово-Плота	1	11	896	37.486992999999998	37.525809000000002	52.170833999999999	52.148547000000001	0103000020E61000000100000005000000C23060C955BE42409F758D9603134A40C23060C955BE4240BE8575E3DD154A40A37895B54DC34240BE8575E3DD154A40A37895B54DC342409F758D9603134A40C23060C955BE42409F758D9603134A40
7501	Козьма-Демьяновское	1	11	896	37.593955999999999	37.635610999999997	52.035795999999998	51.997314000000003	0103000020E61000000100000005000000A9A10DC006CC4240E6EB32FCA7FF4940A9A10DC006CC4240EFA99CF694044A402AFD84B35BD14240EFA99CF694044A402AFD84B35BD14240E6EB32FCA7FF4940A9A10DC006CC4240E6EB32FCA7FF4940
52385	Калиновка	1	11	896	37.570653	37.603900000000003	52.057752000000001	52.026831000000001	0103000020E61000000100000005000000A12E52280BC942406EC2BD326F034A40A12E52280BC94240A9A3E36A64074A40F7065F984CCD4240A9A3E36A64074A40F7065F984CCD42406EC2BD326F034A40A12E52280BC942406EC2BD326F034A40
7427	Знаменское	1	11	896	37.678137	37.725037999999998	52.031058999999999	52.016612000000002	0103000020E61000000100000005000000919A7631CDD642404F5C8E5720024A40919A7631CDD642408C9FC6BDF9034A40BA2D910BCEDC42408C9FC6BDF9034A40BA2D910BCEDC42404F5C8E5720024A40919A7631CDD642404F5C8E5720024A40
52375	Евланово	1	11	896	37.382770999999998	37.424326999999998	52.231886000000003	52.210523999999999	0103000020E61000000100000005000000B96DDFA3FEB04240F5824F73F21A4A40B96DDFA3FEB042403C33C170AE1D4A40A7E7DD5850B642403C33C170AE1D4A40A7E7DD5850B64240F5824F73F21A4A40B96DDFA3FEB04240F5824F73F21A4A40
46479	Дубровка	1	11	896	37.301985000000002	37.331746000000003	52.100785999999999	52.090344999999999	0103000020E61000000100000005000000F870C971A7A64240B62DCA6C900B4A40F870C971A7A6424084F23E8EE60C4A40174A26A776AA424084F23E8EE60C4A40174A26A776AA4240B62DCA6C900B4A40F870C971A7A64240B62DCA6C900B4A40
7581	Долгое	1	11	896	37.504204999999999	37.544440999999999	52.068742999999998	52.047922	0103000020E6100000010000000500000066BD18CA89C042402461DF4E22064A4066BD18CA89C042401A6A1492CC084A40FFCC203EB0C542401A6A1492CC084A40FFCC203EB0C542402461DF4E22064A4066BD18CA89C042402461DF4E22064A40
52395	Гремячка	1	11	896	37.439221000000003	37.474775999999999	52.043213999999999	52.029735000000002	0103000020E61000000100000005000000B45BCB6438B84240F645425BCE034A40B45BCB6438B842405B5D4E0988054A407D76C075C5BC42405B5D4E0988054A407D76C075C5BC4240F645425BCE034A40B45BCB6438B84240F645425BCE034A40
8069	Вышняя Замарайка 1-я	1	11	896	37.268836999999998	37.300789999999999	52.072645999999999	52.052191999999998	0103000020E61000000100000005000000357A354069A24240718E3A3AAE064A40357A354069A24240B517D1764C094A405F7B664980A64240B517D1764C094A405F7B664980A64240718E3A3AAE064A40357A354069A24240718E3A3AAE064A40
52380	Вышнее Ольшаное	1	11	896	37.617508999999998	37.682071000000001	52.145412999999998	52.105327000000003	0103000020E610000001000000050000002AFEEF880ACF42406231EA5A7B0D4A402AFEEF880ACF4240E5B4A7E49C124A4067463F1A4ED74240E5B4A7E49C124A4067463F1A4ED742406231EA5A7B0D4A402AFEEF880ACF42406231EA5A7B0D4A40
7842	Вышнее Долгое	1	11	896	37.366582999999999	37.384379000000003	52.064540999999998	52.055205000000001	0103000020E6100000010000000500000081221631ECAE4240B0C91AF510074A4081221631ECAE4240252026E142084A407522C15433B14240252026E142084A407522C15433B14240B0C91AF510074A4081221631ECAE4240B0C91AF510074A40
52390	Выгон	1	11	896	37.402856999999997	37.423833000000002	51.999254000000001	51.985422999999997	0103000020E610000001000000050000007AFB73D190B34240F4DC425722FE49407AFB73D190B34240D732198EE7FF494098FBE42840B64240D732198EE7FF494098FBE42840B64240F4DC425722FE49407AFB73D190B34240F4DC425722FE4940
54600	Быстра	1	11	896	37.309809999999999	37.332833000000001	52.047412999999999	52.033712999999999	0103000020E61000000100000005000000A4FCA4DAA7A742409B3924B550044A40A4FCA4DAA7A74240DF3312A111064A40C90391459AAA4240DF3312A111064A40C90391459AAA42409B3924B550044A40A4FCA4DAA7A742409B3924B550044A40
7242	Баранчик	1	11	896	37.583733000000002	37.633741999999998	52.202244999999998	52.181769000000003	0103000020E61000000100000005000000494C50C3B7CA42409C36E33444174A40494C50C3B7CA4240C763062AE3194A40020D36751ED14240C763062AE3194A40020D36751ED142409C36E33444174A40494C50C3B7CA42409C36E33444174A40
52392	Алексеевка	1	11	896	37.337918000000002	37.367615999999998	52.021721999999997	52.000534999999999	0103000020E61000000100000005000000685DA3E540AB42406EC0E78711004A40685DA3E540AB424046CD57C9C7024A4040BE840A0EAF424046CD57C9C7024A4040BE840A0EAF42406EC0E78711004A40685DA3E540AB42406EC0E78711004A40
54620	пос.Занеруссовский	1	11	832	34.848739999999999	35.592095999999998	52.717095	52.319968000000003	0103000020E610000001000000050000004D672783A36C41401EE21FB6F4284A404D672783A36C41400490DAC4C95B4A40D40B3ECDC9CB41400490DAC4C95B4A40D40B3ECDC9CB41401EE21FB6F4284A404D672783A36C41401EE21FB6F4284A40
6567	Хальзево	1	11	832	35.380955999999998	35.403306000000001	52.465032999999998	52.451945000000002	0103000020E61000000100000005000000849B8C2AC3B041409D4B7155D9394A40849B8C2AC3B04140C7478B33863B4A40EA23F0879FB34140C7478B33863B4A40EA23F0879FB341409D4B7155D9394A40849B8C2AC3B041409D4B7155D9394A40
46077	Упорой	1	11	832	34.890045000000001	34.919742999999997	52.417009999999998	52.397995000000002	0103000020E61000000100000005000000F27B9BFEEC7141405B7C0A80F1324A40F27B9BFEEC7141406F0D6C9560354A40CADC7C23BA7541406F0D6C9560354A40CADC7C23BA7541405B7C0A80F1324A40F27B9BFEEC7141405B7C0A80F1324A40
54588	Труд	1	11	832	35.346666999999997	35.352012000000002	52.399979000000002	52.395840999999997	0103000020E610000001000000050000001CCD91955FAC41403DB5FAEAAA324A401CCD91955FAC41401C0B0A8332334A4058E6ADBA0EAD41401C0B0A8332334A4058E6ADBA0EAD41403DB5FAEAAA324A401CCD91955FAC41403DB5FAEAAA324A40
6085	Сторожище	1	11	832	35.072636000000003	35.103529000000002	52.497073999999998	52.482674000000003	0103000020E610000001000000050000009241EE224C8941409450FA42C83D4A409241EE224C89414090D8EE1EA03F4A4003983270408D414090D8EE1EA03F4A4003983270408D41409450FA42C83D4A409241EE224C8941409450FA42C83D4A40
6004	Рублино	1	11	832	35.073867	35.098624000000001	52.593975999999998	52.579394999999998	0103000020E6100000010000000500000077A04E7974894140A33B889D294A4A4077A04E7974894140F04DD367074C4A40E44C13B69F8C4140F04DD367074C4A40E44C13B69F8C4140A33B889D294A4A4077A04E7974894140A33B889D294A4A40
6775	Работьково	1	11	832	35.140621000000003	35.171702000000003	52.691209000000001	52.672542999999997	0103000020E61000000100000005000000BF1072DEFF914140AD1397E315564A40BF1072DEFF914140B6D9588979584A403354C554FA954140B6D9588979584A403354C554FA954140AD1397E315564A40BF1072DEFF914140AD1397E315564A40
46365	Плоское	1	11	832	35.478009999999998	35.506234999999997	52.448027000000003	52.423408000000002	0103000020E610000001000000050000009A94826E2FBD4140B16EBC3B32364A409A94826E2FBD4140CD5CE0F258394A40978BF84ECCC04140CD5CE0F258394A40978BF84ECCC04140B16EBC3B32364A409A94826E2FBD4140B16EBC3B32364A40
54579	Малое Боброво	1	11	832	35.175350000000002	35.195067999999999	52.421562999999999	52.410615999999997	0103000020E6100000010000000500000043AD69DE719641406F9BA9108F344A4043AD69DE71964140111AC1C6F5354A40813FFCFCF7984140111AC1C6F5354A40813FFCFCF79841406F9BA9108F344A4043AD69DE719641406F9BA9108F344A40
46291	Лубянки	1	11	832	35.401688999999998	35.418424999999999	52.569997999999998	52.550556999999998	0103000020E61000000100000005000000DB148F8B6AB34140BCCADAA678464A40DB148F8B6AB341408864C8B1F5484A40166A4DF38EB541408864C8B1F5484A40166A4DF38EB54140BCCADAA678464A40DB148F8B6AB34140BCCADAA678464A40
6392	Крупышино	1	11	832	35.472377000000002	35.504078999999997	52.573616000000001	52.564802999999998	0103000020E61000000100000005000000F9307BD976BC414062D7F6764B484A40F9307BD976BC41402E3BC43F6C494A40D9CC21A985C041402E3BC43F6C494A40D9CC21A985C0414062D7F6764B484A40F9307BD976BC414062D7F6764B484A40
46445	Красное Знамя	1	11	832	35.264857999999997	35.284899000000003	52.626978000000001	52.617077000000002	0103000020E61000000100000005000000BF0AF0DDE6A14140910E0F61FC4E4A40BF0AF0DDE6A14140DFA7AAD040504A40E1D4079277A44140DFA7AAD040504A40E1D4079277A44140910E0F61FC4E4A40BF0AF0DDE6A14140910E0F61FC4E4A40
6628	Дружно	1	11	832	35.173481000000002	35.190899000000002	52.559021999999999	52.550426000000002	0103000020E610000001000000050000001BBD1AA0349641401E6FF25B74464A401BBD1AA0349641404CDF6B088E474A4068EBE0606F9841404CDF6B088E474A4068EBE0606F9841401E6FF25B74464A401BBD1AA0349641401E6FF25B74464A40
6316	Домаха	1	11	832	34.938175999999999	34.970866000000001	52.476711999999999	52.458953000000001	0103000020E6100000010000000500000030F2B2261678414057B3CEF8BE3A4A4030F2B226167841402DCE18E6043D4A4030664B56457C41402DCE18E6043D4A4030664B56457C414057B3CEF8BE3A4A4030F2B2261678414057B3CEF8BE3A4A40
6843	Дмитровск-Орловский	1	11	832	35.114632	35.170605999999999	52.518320000000003	52.497281999999998	0103000020E610000001000000050000009C89E942AC8E4140DA71C3EFA63F4A409C89E942AC8E41406E6E4C4F58424A402D40DB6AD69541406E6E4C4F58424A402D40DB6AD6954140DA71C3EFA63F4A409C89E942AC8E4140DA71C3EFA63F4A40
46050	Девятино	1	11	832	35.006537999999999	35.031871000000002	52.401831000000001	52.393191999999999	0103000020E610000001000000050000003317B83CD680414040868E1D54324A403317B83CD68041406EC2BD326F334A406D585359148441406EC2BD326F334A406D5853591484414040868E1D54324A403317B83CD680414040868E1D54324A40
46145	Горбуновка	1	11	832	35.166437999999999	35.18347	52.520395999999998	52.510669	0103000020E61000000100000005000000E46723D74D9541405F0A0F9A5D414A40E46723D74D9541400F7C0C569C424A4008E6E8F17B9741400F7C0C569C424A4008E6E8F17B9741405F0A0F9A5D414A40E46723D74D9541405F0A0F9A5D414A40
6472	Брусовец	1	11	832	35.446165000000001	35.462378999999999	52.550612000000001	52.541088000000002	0103000020E6100000010000000500000057CF49EF1BB941400821205F42454A4057CF49EF1BB9414080643A747A464A40B8AD2D3C2FBB414080643A747A464A40B8AD2D3C2FBB41400821205F42454A4057CF49EF1BB941400821205F42454A40
46101	Бородино	1	11	832	35.097096999999998	35.130172999999999	52.629584999999999	52.620691000000001	0103000020E6100000010000000500000015C5ABAC6D8C4140F5F57CCD724F4A4015C5ABAC6D8C4140AD86C43D96504A403EE94482A9904140AD86C43D96504A403EE94482A9904140F5F57CCD724F4A4015C5ABAC6D8C4140F5F57CCD724F4A40
46015	Алешинка	1	11	832	35.061236999999998	35.080748	52.492381000000002	52.477353999999998	0103000020E610000001000000050000000F27309DD6874140B14E95EF193D4A400F27309DD6874140FD153257063F4A40D49B51F3558A4140FD153257063F4A40D49B51F3558A4140B14E95EF193D4A400F27309DD6874140B14E95EF193D4A40
4999	Техникумовский	1	11	691	36.345432000000002	36.382810999999997	52.475884000000001	52.464660000000002	0103000020E61000000100000005000000F67EA31D372C424033E197FA793B4A40F67EA31D372C4240475854C4E93C4A4047C66AF3FF304240475854C4E93C4A4047C66AF3FF30424033E197FA793B4A40F67EA31D372C424033E197FA793B4A40
5682	Тагинский	1	11	691	36.085845999999997	36.109713999999997	52.434753000000001	52.414850999999999	0103000020E61000000100000005000000073F7100FD0A424040DB6AD619354A40073F7100FD0A4240406B7EFCA5374A40E8F4BC1B0B0E4240406B7EFCA5374A40E8F4BC1B0B0E424040DB6AD619354A40073F7100FD0A424040DB6AD619354A40
5645	Тагино	1	11	691	36.044964	36.105753	52.438299000000001	52.396011999999999	0103000020E61000000100000005000000A9BF5E61C10542406A696E85B0324A40A9BF5E61C10542404C6F7F2E1A384A40193A7650890D42404C6F7F2E1A384A40193A7650890D42406A696E85B0324A40A9BF5E61C10542406A696E85B0324A40
54613	Степная	1	11	691	36.135711000000001	36.187122000000002	52.369180999999998	52.355767999999998	0103000020E610000001000000050000008E5A61FA5E1142404E7B4ACE892D4A408E5A61FA5E114240FCA6B052412F4A405A2E1B9DF3174240FCA6B052412F4A405A2E1B9DF31742404E7B4ACE892D4A408E5A61FA5E1142404E7B4ACE892D4A40
54607	Сеньково	1	11	691	36.134984000000003	36.178075999999997	52.430112999999999	52.411549000000001	0103000020E61000000100000005000000DCBDDC2747114240CBD93BA3AD344A40DCBDDC2747114240CF4A5AF10D374A40EB19C231CB164240CF4A5AF10D374A40EB19C231CB164240CBD93BA3AD344A40DCBDDC2747114240CBD93BA3AD344A40
47618	Сабурово	1	11	691	36.397830999999996	36.406058999999999	52.463068999999997	52.454624000000003	0103000020E61000000100000005000000E02A4F20EC32424005FD851E313A4A40E02A4F20EC3242404D6551D8453B4A408C9FC6BDF93342404D6551D8453B4A408C9FC6BDF933424005FD851E313A4A40E02A4F20EC32424005FD851E313A4A40
60481	Отрада	1	11	691	36.306966000000003	36.325282999999999	52.520631999999999	52.510033	0103000020E61000000100000005000000F27D71A94A274240BD70E7C248414A40F27D71A94A27424023A0C211A4424A40EE7893DFA229424023A0C211A4424A40EE7893DFA2294240BD70E7C248414A40F27D71A94A274240BD70E7C248414A40
52328	Новополево	1	11	691	36.326127	36.349448000000002	52.539659	52.522342000000002	0103000020E61000000100000005000000DAAB8F87BE294240E3A9471ADC424A40DAAB8F87BE294240FCFECD8B13454A4089D349B6BA2C4240FCFECD8B13454A4089D349B6BA2C4240E3A9471ADC424A40DAAB8F87BE294240E3A9471ADC424A40
60459	Никольское	1	11	691	36.224645000000002	36.251325000000001	52.390757999999998	52.378418000000003	0103000020E61000000100000005000000DF1AD82AC11C4240DF1B430070304A40DF1AD82AC11C42403F53AF5B04324A4067D5E76A2B2042403F53AF5B04324A4067D5E76A2B204240DF1B430070304A40DF1AD82AC11C4240DF1B430070304A40
52322	Ловчиково	1	11	691	36.226638999999999	36.249051999999999	52.507154999999997	52.491897999999999	0103000020E61000000100000005000000C37FBA81021D4240E17B7F83F63E4A40C37FBA81021D42405E807D74EA404A406F8099EFE01F42405E807D74EA404A406F8099EFE01F4240E17B7F83F63E4A40C37FBA81021D4240E17B7F83F63E4A40
54611	Красная Слободка	1	11	691	36.417485999999997	36.447192999999999	52.496093000000002	52.472636999999999	0103000020E61000000100000005000000D844662E7035424095F0845E7F3C4A40D844662E703542402463B5F97F3F4A400400C79E3D3942402463B5F97F3F4A400400C79E3D39424095F0845E7F3C4A40D844662E7035424095F0845E7F3C4A40
45534	Ильинское	1	11	691	36.262768999999999	36.274205000000002	52.424067000000001	52.408906999999999	0103000020E6100000010000000500000089B3226AA2214240800D881057344A4089B3226AA22142400B28D4D347364A4029B34126192342400B28D4D347364A4029B3412619234240800D881057344A4089B3226AA2214240800D881057344A40
48622	Ивановка	1	11	691	36.336126	36.358708999999998	52.550508000000001	52.53875	0103000020E61000000100000005000000EBAA402D062B4240295C8FC2F5444A40EBAA402D062B4240DB17D00B77464A40F3E32F2DEA2D4240DB17D00B77464A40F3E32F2DEA2D4240295C8FC2F5444A40EBAA402D062B4240295C8FC2F5444A40
54610	Гремячево	1	11	691	36.148342	36.179063999999997	52.492797000000003	52.478417999999998	0103000020E61000000100000005000000C64FE3DEFC124240ABE80FCD3C3D4A40C64FE3DEFC1242409148DBF8133F4A400AF2B391EB1642409148DBF8133F4A400AF2B391EB164240ABE80FCD3C3D4A40C64FE3DEFC124240ABE80FCD3C3D4A40
54595	Гнилуша	1	11	691	36.094208999999999	36.122047999999999	52.522258999999998	52.497233000000001	0103000020E6100000010000000500000093FE5E0A0F0C4240F9BEB854A53F4A4093FE5E0A0F0C424055850662D9424A406745D4449F0F424055850662D9424A406745D4449F0F4240F9BEB854A53F4A4093FE5E0A0F0C4240F9BEB854A53F4A40
4828	Глазуновка	1	11	691	36.29439	36.365321000000002	52.509880000000003	52.485230000000001	0103000020E610000001000000050000007D224F92AE254240E08442041C3E4A407D224F92AE254240377172BF43414A4061C5A9D6C22E4240377172BF43414A4061C5A9D6C22E4240E08442041C3E4A407D224F92AE254240E08442041C3E4A40
45747	Богородское	1	11	691	36.025658999999997	36.065643000000001	52.537232000000003	52.483974000000003	0103000020E610000001000000050000008DEC4ACB48034240A20E2BDCF23D4A408DEC4ACB48034240AE2EA704C4444A400D1B65FD66084240AE2EA704C4444A400D1B65FD66084240A20E2BDCF23D4A408DEC4ACB48034240A20E2BDCF23D4A40
22425	Юдинка	1	11	603	37.191744	37.209494999999997	52.617542	52.605429999999998	0103000020E61000000100000005000000249A40118B9842403602F1BA7E4D4A40249A40118B98424006F4C29D0B4F4A4077D66EBBD09A424006F4C29D0B4F4A4077D66EBBD09A42403602F1BA7E4D4A40249A40118B9842403602F1BA7E4D4A40
49535	Туровка	1	11	603	37.082203	37.135078	52.839191999999997	52.813938999999998	0103000020E610000001000000050000000951BEA0858A42402FF834272F684A400951BEA0858A42404C88B9A46A6B4A405D34643C4A9142404C88B9A46A6B4A405D34643C4A9142402FF834272F684A400951BEA0858A42402FF834272F684A40
4511	Теляжье	1	11	603	37.261310000000002	37.304679999999998	52.659287999999997	52.610723	0103000020E61000000100000005000000130F289B72A142401FF5D72B2C4E4A40130F289B72A142409752978C63544A4065DF15C1FFA642409752978C63544A4065DF15C1FFA642401FF5D72B2C4E4A40130F289B72A142401FF5D72B2C4E4A40
3806	Сухотиновка	1	11	603	37.238016000000002	37.323355999999997	52.918804000000002	52.767825000000002	0103000020E610000001000000050000005EF6EB4E779E42408E06F01648624A405EF6EB4E779E42408DB7955E9B754A40917BBABA63A942408DB7955E9B754A40917BBABA63A942408E06F01648624A405EF6EB4E779E42408E06F01648624A40
54602	Суровцев	1	11	603	36.897294000000002	37.564796000000001	52.971499000000001	52.459299000000001	0103000020E61000000100000005000000D272A087DA724240F20A444FCA3A4A40D272A087DA724240618C48145A7C4A40B0743E3C4BC84240618C48145A7C4A40B0743E3C4BC84240F20A444FCA3A4A40D272A087DA724240F20A444FCA3A4A40
4246	Скорятино	1	11	603	37.310572999999998	37.333067	52.724524000000002	52.711781999999999	0103000020E61000000100000005000000A30227DBC0A74240D4F02DAC1B5B4A40A30227DBC0A742406495D233BD5C4A403C3080F0A1AA42406495D233BD5C4A403C3080F0A1AA4240D4F02DAC1B5B4A40A30227DBC0A74240D4F02DAC1B5B4A40
45430	Скородное	1	11	603	37.067928999999999	37.140531000000003	52.787821999999998	52.752445999999999	0103000020E6100000010000000500000099B9C0E5B1884240C500892650604A4099B9C0E5B1884240DF88EE59D7644A407F8978EBFC914240DF88EE59D7644A407F8978EBFC914240C500892650604A4099B9C0E5B1884240C500892650604A40
4545	Русский Брод	1	11	603	37.345266000000002	37.382241	52.618592	52.586809000000002	0103000020E61000000100000005000000DB3521AD31AC4240CEFFAB8E1C4B4A40DB3521AD31AC42409BC8CC052E4F4A405D18E945EDB042409BC8CC052E4F4A405D18E945EDB04240CEFFAB8E1C4B4A40DB3521AD31AC4240CEFFAB8E1C4B4A40
4656	Прусынок	1	11	603	37.461103999999999	37.492060000000002	52.559393999999998	52.542150999999997	0103000020E610000001000000050000000307B47405BB4240313F373465454A400307B47405BB424010CAFB389A474A40BBD573D2FBBE424010CAFB389A474A40BBD573D2FBBE4240313F373465454A400307B47405BB4240313F373465454A40
49572	Песочное	1	11	603	37.193962999999997	37.220086000000002	52.886360000000003	52.877594999999999	0103000020E6100000010000000500000028D192C7D39842400A11700855704A4028D192C7D3984240C53D963E74714A405B272EC72B9C4240C53D963E74714A405B272EC72B9C42400A11700855704A4028D192C7D39842400A11700855704A40
4746	Пеньшино	1	11	603	37.309244	37.341987000000003	52.561064000000002	52.545611999999998	0103000020E61000000100000005000000FB3DB14E95A742400F27309DD6454A40FB3DB14E95A74240427BF5F1D0474A401E54E23AC6AB4240427BF5F1D0474A401E54E23AC6AB42400F27309DD6454A40FB3DB14E95A742400F27309DD6454A40
60415	Круглое	1	11	603	37.165837000000003	37.19876	52.802273	52.790751999999998	0103000020E61000000100000005000000BFBB95253A954240909F8D5C37654A40BFBB95253A9542405EBBB4E1B0664A4061E0B9F7709942405EBBB4E1B0664A4061E0B9F770994240909F8D5C37654A40BFBB95253A954240909F8D5C37654A40
4013	Корсунь	1	11	603	36.989550999999999	37.018666000000003	52.729247000000001	52.711022999999997	0103000020E61000000100000005000000AF5C6F9BA97E424016DA39CD025B4A40AF5C6F9BA97E424062DA37F7575D4A4009C6C1A56382424062DA37F7575D4A4009C6C1A56382424016DA39CD025B4A40AF5C6F9BA97E424016DA39CD025B4A40
45515	Коньшино	1	11	603	37.358786000000002	37.370392000000002	52.666300999999997	52.656350000000003	0103000020E610000001000000050000009F211CB3ECAD4240645DDC4603544A409F211CB3ECAD42406325E65949554A409B594B0169AF42406325E65949554A409B594B0169AF4240645DDC4603544A409F211CB3ECAD4240645DDC4603544A40
48215	Ключики	1	11	603	37.080801999999998	37.096541000000002	52.765633999999999	52.756647999999998	0103000020E61000000100000005000000C7B94DB8578A4240BA4A77D7D9604A40C7B94DB8578A4240535A7F4B00624A4090DC9A745B8C4240535A7F4B00624A4090DC9A745B8C4240BA4A77D7D9604A40C7B94DB8578A4240BA4A77D7D9604A40
45375	Карповка	1	11	603	37.341143000000002	37.354779000000001	52.764457	52.757269000000001	0103000020E610000001000000050000003221E692AAAB424027A3CA30EE604A403221E692AAAB424061191BBAD9614A405F27F56569AD424061191BBAD9614A405F27F56569AD424027A3CA30EE604A403221E692AAAB424027A3CA30EE604A40
54609	Долгое	1	11	603	37.200251000000002	37.235760999999997	52.807195	52.789749999999998	0103000020E61000000100000005000000E3FE23D3A19942400C022B8716654A40E3FE23D3A1994240533F6F2A52674A400C569C6A2D9E4240533F6F2A52674A400C569C6A2D9E42400C022B8716654A40E3FE23D3A19942400C022B8716654A40
49500	Верховье	1	11	603	37.199883	37.267167000000001	52.828930999999997	52.799773999999999	0103000020E61000000100000005000000600322C495994240761893FE5E664A40600322C495994240FED137691A6A4A4004C93B8732A24240FED137691A6A4A4004C93B8732A24240761893FE5E664A40600322C495994240761893FE5E664A40
4073	Верхняя Залегощь	1	11	603	36.964075000000001	37.027926999999998	52.817411	52.771687	0103000020E6100000010000000500000013F241CF667B4240CADFBDA3C6624A4013F241CF667B4240013274ECA0684A4073D6A71C93834240013274ECA0684A4073D6A71C93834240CADFBDA3C6624A4013F241CF667B4240CADFBDA3C6624A40
4351	Большой Синковец	1	11	603	37.207904999999997	37.256297000000004	52.689124	52.667065999999998	0103000020E6100000010000000500000062D68BA19C9A424003232F6B62554A4062D68BA19C9A4240C171193735584A400E881057CEA04240C171193735584A400E881057CEA0424003232F6B62554A4062D68BA19C9A424003232F6B62554A40
48291	Ямские Выселки	1	11	434	36.044190999999998	36.047739	53.474953999999997	53.470725000000002	0103000020E6100000010000000500000086E3F90CA80542406E3480B740BC4A4086E3F90CA80542405C8DEC4ACBBC4A4033DFC14F1C0642405C8DEC4ACBBC4A4033DFC14F1C0642406E3480B740BC4A4086E3F90CA80542406E3480B740BC4A40
2426	Фатнево	1	11	434	36.22204	36.246913999999997	53.480693000000002	53.464094000000003	0103000020E61000000100000005000000B13385CE6B1C42408A22A46E67BB4A40B13385CE6B1C42404435255987BD4A405776C1E09A1F42404435255987BD4A405776C1E09A1F42408A22A46E67BB4A40B13385CE6B1C42408A22A46E67BB4A40
10840	Середичи	1	11	434	35.835898999999998	35.861159000000001	53.587477	53.570397	0103000020E610000001000000050000002AE109BDFEEA4140465ED6C402C94A402AE109BDFEEA41407B13437232CB4A40FAD346753AEE41407B13437232CB4A40FAD346753AEE4140465ED6C402C94A402AE109BDFEEA4140465ED6C402C94A40
2958	Репнино	1	11	434	36.113083000000003	36.172156000000001	53.529555999999999	53.506588000000001	0103000020E61000000100000005000000E65DF580790E4240E54526E0D7C04A40E65DF580790E424046B3B27DC8C34A40B4E732350916424046B3B27DC8C34A40B4E7323509164240E54526E0D7C04A40E65DF580790E4240E54526E0D7C04A40
2386	Пальчикова	1	11	434	36.218949000000002	36.237329000000003	53.534495999999997	53.522072999999999	0103000020E61000000100000005000000F73E5585061C4240F38FBE49D3C24A40F73E5585061C4240E1EB6B5D6AC44A403AB2F2CB601E4240E1EB6B5D6AC44A403AB2F2CB601E4240F38FBE49D3C24A40F73E5585061C4240F38FBE49D3C24A40
3178	Однолуки	1	11	434	36.099446	36.121068999999999	53.422967999999997	53.413361999999999	0103000020E61000000100000005000000E8DB82A5BA0C42405FB4C70BE9B44A40E8DB82A5BA0C424094A0BFD023B64A409BC761307F0F424094A0BFD023B64A409BC761307F0F42405FB4C70BE9B44A40E8DB82A5BA0C42405FB4C70BE9B44A40
3062	Новый Синец	1	11	434	36.119964000000003	36.141928	53.312216999999997	53.300541000000003	0103000020E610000001000000050000004359F8FA5A0F4240B70DA32078A64A404359F8FA5A0F4240AB2006BAF6A74A407F315BB22A124240AB2006BAF6A74A407F315BB22A124240B70DA32078A64A404359F8FA5A0F4240B70DA32078A64A40
14061	Кривчее	1	11	434	35.984076000000002	35.989825000000003	53.481828999999998	53.476303999999999	0103000020E61000000100000005000000A663CE33F6FD41401C7A8B87F7BC4A40A663CE33F6FD4140D7A19A92ACBD4A40B1E1E995B2FE4140D7A19A92ACBD4A40B1E1E995B2FE41401C7A8B87F7BC4A40A663CE33F6FD41401C7A8B87F7BC4A40
49553	Каменка	1	11	434	36.088324999999998	36.102375000000002	53.241050000000001	53.234147	0103000020E61000000100000005000000A835CD3B4E0B42406FBA6587F89D4A40A835CD3B4E0B4240B459F5B9DA9E4A40C976BE9F1A0D4240B459F5B9DA9E4A40C976BE9F1A0D42406FBA6587F89D4A40A835CD3B4E0B42406FBA6587F89D4A40
2755	Злынь	1	11	434	35.892114999999997	35.927509000000001	53.289797999999998	53.264265000000002	0103000020E61000000100000005000000B1A206D330F241401D3D7E6FD3A14A40B1A206D330F241401D39D21918A54A4072DF6A9DB8F641401D39D21918A54A4072DF6A9DB8F641401D3D7E6FD3A14A40B1A206D330F241401D3D7E6FD3A14A40
49274	Герасимова	1	11	434	35.940075999999998	35.954036000000002	53.597876999999997	53.586953999999999	0103000020E6100000010000000500000093E00D6954F84140D120054F21CB4A4093E00D6954F84140EA03C93B87CC4A40749A05DA1DFA4140EA03C93B87CC4A40749A05DA1DFA4140D120054F21CB4A4093E00D6954F84140D120054F21CB4A40
45485	Васильевский	1	11	434	36.048538999999998	36.064008000000001	53.342672	53.338698999999998	0103000020E610000001000000050000004FCAA486360642400D18247D5AAB4A404FCAA48636064240A1A014ADDCAB4A405857056A31084240A1A014ADDCAB4A405857056A310842400D18247D5AAB4A404FCAA486360642400D18247D5AAB4A40
60516	Васильевка	1	11	434	35.736671000000001	35.755616000000003	53.450090000000003	53.439363999999998	0103000020E61000000100000005000000B0743E3C4BDE414016855D143DB84A40B0743E3C4BDE4140DA20938C9CB94A40CC2A6C06B8E04140DA20938C9CB94A40CC2A6C06B8E0414016855D143DB84A40B0743E3C4BDE414016855D143DB84A40
49256	Борилово	1	11	434	35.931820999999999	35.993068000000001	53.390627000000002	53.342914	0103000020E61000000100000005000000EE5C18E945F7414097AB1F9BE4AB4A40EE5C18E945F74140A1F7C61000B24A40215A2BDA1CFF4140A1F7C61000B24A40215A2BDA1CFF414097AB1F9BE4AB4A40EE5C18E945F7414097AB1F9BE4AB4A40
2716	Большая Чернь	1	11	434	35.827508000000002	35.861320999999997	53.354826000000003	53.339827999999997	0103000020E61000000100000005000000D5963AC8EBE94140EE21E17B7FAB4A40D5963AC8EBE94140A0E238F06AAD4A40D32D3BC43FEE4140A0E238F06AAD4A40D32D3BC43FEE4140EE21E17B7FAB4A40D5963AC8EBE94140EE21E17B7FAB4A40
3310	Болхов	1	11	434	35.977473000000003	36.035774000000004	53.472349000000001	53.420344	0103000020E610000001000000050000008CDCD3D51DFD4140F0880AD5CDB54A408CDCD3D51DFD41402FA699EE75BC4A400806103E940442402FA699EE75BC4A400806103E94044240F0880AD5CDB54A408CDCD3D51DFD4140F0880AD5CDB54A40
8948	Алешня	1	11	434	35.924688000000003	35.958168000000001	53.569572999999998	53.554411000000002	0103000020E610000001000000050000007880272D5CF6414076C58CF0F6C64A407880272D5CF64140A1D79FC4E7C84A407009C03FA5FA4140A1D79FC4E7C84A407009C03FA5FA414076C58CF0F6C64A407880272D5CF6414076C58CF0F6C64A40
62013	Яхрома	1	10	\N	37.445554000000001	37.519027000000001	56.312660000000001	56.274559000000004	0103000020E610000001000000050000000E4DD9E907B9424047E9D2BF24234C400E4DD9E907B9424039622D3E05284C40D95E0B7A6FC2424039622D3E05284C40D95E0B7A6FC2424047E9D2BF24234C400E4DD9E907B9424047E9D2BF24234C40
62016	Яковлево	1	10	\N	37.449291000000002	37.463368000000003	55.966256999999999	55.957197000000001	0103000020E610000001000000050000008EB1135E82B94240276A696E85FA4B408EB1135E82B94240FA43334FAEFB4B40A80183A44FBB4240FA43334FAEFB4B40A80183A44FBB4240276A696E85FA4B408EB1135E82B94240276A696E85FA4B40
11204	Юбилейный	1	10	\N	37.812829999999998	37.865462000000001	55.945292000000002	55.925884000000003	0103000020E61000000100000005000000959A3DD00AE84240E1F1ED5D83F64B40959A3DD00AE84240D1950854FFF84B4023F77475C7EE4240D1950854FFF84B4023F77475C7EE4240E1F1ED5D83F64B40959A3DD00AE84240E1F1ED5D83F64B40
61947	Электроугли	1	10	\N	38.114224	38.234850000000002	55.778359999999999	55.703378000000001	0103000020E610000001000000050000008B355CE49E0E4340EA5C514A08DA4B408B355CE49E0E4340DD41EC4CA1E34B4099BB96900F1E4340DD41EC4CA1E34B4099BB96900F1E4340EA5C514A08DA4B408B355CE49E0E4340EA5C514A08DA4B40
13377	Электросталь	1	10	\N	38.412770000000002	38.507416999999997	55.817360000000001	55.749983	0103000020E610000001000000050000008D62B9A5D53443402AC76471FFDF4B408D62B9A5D53443407F87A2409FE84B409B374E0AF34043407F87A2409FE84B409B374E0AF34043402AC76471FFDF4B408D62B9A5D53443402AC76471FFDF4B40
13129	Электрогорск	1	10	\N	38.76632	38.807049999999997	55.901353999999998	55.857638999999999	0103000020E61000000100000005000000A72215C6166243401763601DC7ED4B40A72215C616624340340F60915FF34B404F1E166A4D674340340F60915FF34B404F1E166A4D6743401763601DC7ED4B40A72215C6166243401763601DC7ED4B40
618	Щербинка	1	10	\N	37.505192999999998	37.584802000000003	55.523167999999998	55.486891999999997	0103000020E6100000010000000500000085950A2AAAC042408E57207A52BE4B4085950A2AAAC042402828452BF7C24B405551BCCADACA42402828452BF7C24B405551BCCADACA42408E57207A52BE4B4085950A2AAAC042408E57207A52BE4B40
60268	Щелково	1	10	\N	37.939331000000003	38.095278	55.955806000000003	55.863965	0103000020E610000001000000050000003B8F8AFF3BF84240BFF1B56796EE4B403B8F8AFF3BF8424009A9DBD957FA4B409F03CB11320C434009A9DBD957FA4B409F03CB11320C4340BFF1B56796EE4B403B8F8AFF3BF84240BFF1B56796EE4B40
59533	Шатура	1	10	\N	39.497000999999997	39.586948999999997	55.615333999999997	55.557388000000003	0103000020E61000000100000005000000268A90BA9DBF434068976F7D58C74B40268A90BA9DBF4340F50EB743C3CE4B40BFB5132521CB4340F50EB743C3CE4B40BFB5132521CB434068976F7D58C74B40268A90BA9DBF434068976F7D58C74B40
61885	Чехов	1	10	\N	37.408112000000003	37.496974000000002	55.175888999999998	55.120294999999999	0103000020E61000000100000005000000768D96033DB44240A86F99D3658F4B40768D96033DB44240F25CDF8783964B402D7B12D89CBF4240F25CDF8783964B402D7B12D89CBF4240A86F99D3658F4B40768D96033DB44240A86F99D3658F4B40
3200	Черноголовка	1	10	\N	38.349789000000001	38.42116	56.030451999999997	55.986243999999999	0103000020E6100000010000000500000012C0CDE2C52C434028F04E3E3DFE4B4012C0CDE2C52C4340840CE4D9E5034C4012312592E8354340840CE4D9E5034C4012312592E835434028F04E3E3DFE4B4012C0CDE2C52C434028F04E3E3DFE4B40
96	Химки	1	10	\N	37.228116999999997	37.507071000000003	55.997613000000001	55.877414999999999	0103000020E61000000100000005000000B05417F0329D42408A027D224FF04B40B05417F0329D4240408864C8B1FF4B4001E0D8B3E7C04240408864C8B1FF4B4001E0D8B3E7C042408A027D224FF04B40B05417F0329D42408A027D224FF04B40
11769	Фрязино	1	10	\N	38.010171999999997	38.132002	55.979056999999997	55.910240999999999	0103000020E61000000100000005000000DEAAEB504D0143403A3DEFC682F44B40DEAAEB504D014340BEF561BD51FD4B40D8800871E5104340BEF561BD51FD4B40D8800871E51043403A3DEFC682F44B40DEAAEB504D0143403A3DEFC682F44B40
61953	Тучково	1	10	\N	36.438830000000003	36.504900999999997	55.622604000000003	55.571775000000002	0103000020E610000001000000050000007940D9942B384240D0D556EC2FC94B407940D9942B384240ED2DE57CB1CF4B40DD5B9198A0404240ED2DE57CB1CF4B40DD5B9198A0404240D0D556EC2FC94B407940D9942B384240D0D556EC2FC94B40
31250	Троицк	1	10	\N	37.249901000000001	37.328583999999999	55.509217	55.449812000000001	0103000020E610000001000000050000006D1E87C1FC9F424097AC8A7093B94B406D1E87C1FC9F42409BC8CC052EC14B4093FE5E0A0FAA42409BC8CC052EC14B4093FE5E0A0FAA424097AC8A7093B94B406D1E87C1FC9F424097AC8A7093B94B40
61868	Талдом	1	10	\N	37.500773000000002	37.562766000000003	56.746070000000003	56.711373999999999	0103000020E6100000010000000500000023DC645419C04240C39CA04D0E5B4C4023DC645419C042406C43C5387F5F4C407FA65EB708C842406C43C5387F5F4C407FA65EB708C84240C39CA04D0E5B4C4023DC645419C04240C39CA04D0E5B4C40
59517	Ступино	1	10	\N	38.028892999999997	38.167225000000002	54.920506000000003	54.853205000000003	0103000020E61000000100000005000000AA0A0DC4B203434050E449D2356D4B40AA0A0DC4B2034340CAE2FE23D3754B406C09F9A067154340CAE2FE23D3754B406C09F9A06715434050E449D2356D4B40AA0A0DC4B203434050E449D2356D4B40
61948	Старая Купавна	1	10	\N	38.139699999999998	38.210118999999999	55.822184999999998	55.784126000000001	0103000020E6100000010000000500000027A089B0E1114340BEF8A23D5EE44B4027A089B0E11143408121AB5B3DE94B4055A2EC2DE51A43408121AB5B3DE94B4055A2EC2DE51A4340BEF8A23D5EE44B4027A089B0E1114340BEF8A23D5EE44B40
59505	Спартак	1	10	\N	38.041038	38.057909000000002	55.605342999999998	55.597312000000002	0103000020E6100000010000000500000056F2B1BB4005434012C138B874CC4B4056F2B1BB4005434067EE21E17BCD4B407192E68F6907434067EE21E17BCD4B407192E68F6907434012C138B874CC4B4056F2B1BB4005434012C138B874CC4B40
61911	Солнечногорск	1	10	\N	36.941724999999998	37.031340999999998	56.218722	56.160485999999999	0103000020E61000000100000005000000AD69DE718A784240A1BB24CE8A144C40AD69DE718A78424036751E15FF1B4C4010035DFB0284424036751E15FF1B4C4010035DFB02844240A1BB24CE8A144C40AD69DE718A784240A1BB24CE8A144C40
12304	Серпухов	1	10	\N	37.348346999999997	37.489517999999997	54.957971000000001	54.892271000000001	0103000020E6100000010000000500000071546EA296AC4240A915A6EF35724B4071546EA296AC42401AC231CB9E7A4B40D3669C86A8BE42401AC231CB9E7A4B40D3669C86A8BE4240A915A6EF35724B4071546EA296AC4240A915A6EF35724B40
59528	Сергиев Посад	1	10	\N	38.047946000000003	38.200777000000002	56.345668000000003	56.266376999999999	0103000020E61000000100000005000000ADFC3218230643400BB43BA418224C40ADFC3218230643400AA359D93E2C4C40FE648C0FB31943400AA359D93E2C4C40FE648C0FB31943400BB43BA418224C40ADFC3218230643400BB43BA418224C40
61950	Руза	1	10	\N	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
13222	Рошаль	1	10	\N	39.806767000000001	39.909219999999998	55.687040000000003	55.639369000000002	0103000020E61000000100000005000000FB3E1C2444E74340C289E8D7D6D14B40FB3E1C2444E743409D853DEDF0D74B403F6F2A5261F443409D853DEDF0D74B403F6F2A5261F44340C289E8D7D6D14B40FB3E1C2444E74340C289E8D7D6D14B40
52779	Реутов	1	10	\N	37.842367000000003	37.886581999999997	55.782760000000003	55.744343000000001	0103000020E61000000100000005000000651D8EAED2EB4240D600A5A146DF4B40651D8EAED2EB4240F94ECC7A31E44B40739CDB847BF14240F94ECC7A31E44B40739CDB847BF14240D600A5A146DF4B40651D8EAED2EB4240D600A5A146DF4B40
59541	Раменское	1	10	\N	38.163891999999997	38.288882999999998	55.596584999999997	55.542797999999998	0103000020E61000000100000005000000BB09BE69FA144340C72AA5677AC54B40BB09BE69FA1443405F24B4E55CCC4B4068AF3E1EFA2443405F24B4E55CCC4B4068AF3E1EFA244340C72AA5677AC54B40BB09BE69FA144340C72AA5677AC54B40
4258	Пущино	1	10	\N	37.590443	37.647441000000001	54.845539000000002	54.822997999999998	0103000020E610000001000000050000007993DFA293CB424032569BFF57694B407993DFA293CB42400C3F389F3A6C4B40768BC058DFD242400C3F389F3A6C4B40768BC058DFD2424032569BFF57694B407993DFA293CB424032569BFF57694B40
59520	Пушкино	1	10	\N	37.772252999999999	37.885055000000001	56.065483999999998	55.961505000000002	0103000020E61000000100000005000000739EB12FD9E2424062F8889812FB4B40739EB12FD9E24240A4349BC761084C40A514747B49F14240A4349BC761084C40A514747B49F1424062F8889812FB4B40739EB12FD9E2424062F8889812FB4B40
4116	Протвино	1	10	\N	37.165647999999997	37.262881999999998	54.911366999999998	54.848852000000001	0103000020E61000000100000005000000EB5223F4339542407592AD2EA76C4B40EB5223F433954240AAD381ACA7744B40815A0C1EA6A14240AAD381ACA7744B40815A0C1EA6A142407592AD2EA76C4B40EB5223F4339542407592AD2EA76C4B40
204	Подольск	1	10	\N	37.482897000000001	37.611868000000001	55.490288999999997	55.387304999999998	0103000020E61000000100000005000000132BA391CFBD4240E449D23593B14B40132BA391CFBD4240554B3ACAC1BE4B4006BCCCB051CE4240554B3ACAC1BE4B4006BCCCB051CE4240E449D23593B14B40132BA391CFBD4240E449D23593B14B40
61915	Пересвет	1	10	\N	38.150669000000001	38.197695000000003	56.423720000000003	56.406480999999999	0103000020E61000000100000005000000B1C22D1F4913434002B9C49107344C40B1C22D1F49134340A054FB743C364C4097CADB114E194340A054FB743C364C4097CADB114E19434002B9C49107344C40B1C22D1F4913434002B9C49107344C40
61875	Павловский Посад	1	10	\N	38.586396000000001	38.726982999999997	55.801895000000002	55.752693000000001	0103000020E61000000100000005000000AB402D060F4B4340CD76853E58E04B40AB402D060F4B4340B8E9CF7EA4E64B40BDDF68C70D5D4340B8E9CF7EA4E64B40BDDF68C70D5D4340CD76853E58E04B40AB402D060F4B4340CD76853E58E04B40
62020	Осеево	1	10	\N	38.170000000000002	38.191550999999997	55.886090000000003	55.878233000000002	0103000020E61000000100000005000000F6285C8FC21543404DA25EF069F04B40F6285C8FC215434005A8A9656BF14B400F4240BE8418434005A8A9656BF14B400F4240BE841843404DA25EF069F04B40F6285C8FC21543404DA25EF069F04B40
18912	Орехово-Зуево	1	10	\N	38.917093000000001	39.044618	55.840088000000002	55.760964999999999	0103000020E61000000100000005000000FD31AD4D637543404833164D67E14B40FD31AD4D637543408BE1EA0088EB4B400E68E90AB68543408BE1EA0088EB4B400E68E90AB68543404833164D67E14B40FD31AD4D637543404833164D67E14B40
60229	Озеры	1	10	\N	38.472588999999999	38.610982999999997	54.874392999999998	54.844051	0103000020E6100000010000000500000084B9DDCB7D3C4340FB93F8DC096C4B4084B9DDCB7D3C4340F86C1D1CEC6F4B40BBB4E1B0344E4340F86C1D1CEC6F4B40BBB4E1B0344E4340FB93F8DC096C4B4084B9DDCB7D3C4340FB93F8DC096C4B40
62063	Ожерелье	1	10	\N	38.235272000000002	38.289969999999997	54.814605	54.779328	0103000020E610000001000000050000000FD594641D1E4340B56D1805C1634B400FD594641D1E43403C1405FA44684B401A69A9BC1D2543403C1405FA44684B401A69A9BC1D254340B56D1805C1634B400FD594641D1E4340B56D1805C1634B40
61912	Одинцово	1	10	\N	37.190567000000001	37.356997999999997	55.706451999999999	55.648057000000001	0103000020E610000001000000050000003259DC7F64984240D1782288F3D24B403259DC7F64984240CE18E6046DDA4B40635E471CB2AD4240CE18E6046DDA4B40635E471CB2AD4240D1782288F3D24B403259DC7F64984240D1782288F3D24B40
60231	Ногинск	1	10	\N	38.365141000000001	38.514989	55.900011999999997	55.823656	0103000020E61000000100000005000000E1B6B6F0BC2E4340BC934F8F6DE94B40E1B6B6F0BC2E4340F700DD9733F34B405E66D828EB414340F700DD9733F34B405E66D828EB414340BC934F8F6DE94B40E1B6B6F0BC2E4340BC934F8F6DE94B40
61934	Нахабино	1	10	\N	37.129975999999999	37.214229000000003	55.865004999999996	55.827641	0103000020E61000000100000005000000E8A1B60DA390424014EAE923F0E94B40E8A1B60DA390424030F0DC7BB8EE4B406A6D1ADB6B9B424030F0DC7BB8EE4B406A6D1ADB6B9B424014EAE923F0E94B40E8A1B60DA390424014EAE923F0E94B40
59557	Нахабино	1	10	\N	37.129975999999999	37.214229000000003	55.865004999999996	55.827641	0103000020E61000000100000005000000E8A1B60DA390424014EAE923F0E94B40E8A1B60DA390424030F0DC7BB8EE4B406A6D1ADB6B9B424030F0DC7BB8EE4B406A6D1ADB6B9B424014EAE923F0E94B40E8A1B60DA390424014EAE923F0E94B40
59539	Наро-Фоминск	1	10	\N	36.674799	36.779893000000001	55.423707999999998	55.357925999999999	0103000020E61000000100000005000000CF2F4AD05F564240AD31E884D0AD4B40CF2F4AD05F564240DB8651103CB64B408EB0A888D3634240DB8651103CB64B408EB0A888D3634240AD31E884D0AD4B40CF2F4AD05F564240AD31E884D0AD4B40
60249	Мытищи	1	10	\N	37.662210000000002	37.813172000000002	55.961545999999998	55.878152	0103000020E61000000100000005000000C68A1A4CC3D442406075E44867F04B40C68A1A4CC3D44240C0CC77F013FB4B40EF02250516E84240C0CC77F013FB4B40EF02250516E842406075E44867F04B40C68A1A4CC3D442406075E44867F04B40
61942	Монино	1	10	\N	38.152895999999998	38.221590999999997	55.854987000000001	55.824860000000001	0103000020E6100000010000000500000038D89B1892134340A8E3310395E94B4038D89B1892134340A9C0C93670ED4B40410B09185D1C4340A9C0C93670ED4B40410B09185D1C4340A8E3310395E94B4038D89B1892134340A8E3310395E94B40
61930	Можайск	1	10	\N	35.978273000000002	36.064556000000003	55.522454000000003	55.483974000000003	0103000020E61000000100000005000000A8C7B60C38FD4140A20E2BDCF2BD4B40A8C7B60C38FD41400BD5CDC5DFC24B405B61FA5E430842400BD5CDC5DFC24B405B61FA5E43084240A20E2BDCF2BD4B40A8C7B60C38FD4140A20E2BDCF2BD4B40
61954	Митрополье	1	10	\N	37.849032000000001	37.872630999999998	56.147004000000003	56.131225000000001	0103000020E61000000100000005000000F5A0A014ADEC424074B515FBCB104C40F5A0A014ADEC4240CB30EE06D1124C40E63C635FB2EF4240CB30EE06D1124C40E63C635FB2EF424074B515FBCB104C40F5A0A014ADEC424074B515FBCB104C40
59512	Менделеево	1	10	\N	37.217948	37.246901000000001	56.042703000000003	56.022554	0103000020E61000000100000005000000431D56B8E59B42406E32AA0CE3024C40431D56B8E59B42407638BA4A77054C40C32CB4739A9F42407638BA4A77054C40C32CB4739A9F42406E32AA0CE3024C40431D56B8E59B42406E32AA0CE3024C40
59538	Малаховка	1	10	\N	37.963298000000002	38.052743	55.665562999999999	55.614195000000002	0103000020E61000000100000005000000AF264F594DFB4240F12E17F19DCE4B40AF264F594DFB4240BD361B2B31D54B40E50B5A48C0064340BD361B2B31D54B40E50B5A48C0064340F12E17F19DCE4B40AF264F594DFB4240F12E17F19DCE4B40
61892	Люберцы	1	10	\N	37.856901999999998	37.961888000000002	55.707050000000002	55.652059999999999	0103000020E6100000010000000500000041F0F8F6AEED4240CF83BBB376D34B4041F0F8F6AEED42408351499D80DA4B401A355F251FFB42408351499D80DA4B401A355F251FFB4240CF83BBB376D34B4041F0F8F6AEED4240CF83BBB376D34B40
211	Лыткарино	1	10	\N	37.875649000000003	37.969946	55.600282	55.553339999999999	0103000020E6100000010000000500000037E3344415F04240C9C859D8D3C64B4037E3344415F042405130630AD6CC4B406971C63027FC42405130630AD6CC4B406971C63027FC4240C9C859D8D3C64B4037E3344415F04240C9C859D8D3C64B40
61945	Луховицы	1	10	\N	38.990234000000001	39.070328000000003	54.987228999999999	54.922564999999999	0103000020E6100000010000000500000092B1DAFCBF7E434095B7239C16764B4092B1DAFCBF7E4340D65416855D7E4B401EFF058200894340D65416855D7E4B401EFF05820089434095B7239C16764B4092B1DAFCBF7E434095B7239C16764B40
22625	Лосино-Петровский	1	10	\N	38.178148	38.225867000000001	55.892178000000001	55.855583000000003	0103000020E6100000010000000500000085ECBC8DCD164340BD0166BE83ED4B4085ECBC8DCD164340F81A82E332F24B40711FB935E91C4340F81A82E332F24B40711FB935E91C4340BD0166BE83ED4B4085ECBC8DCD164340BD0166BE83ED4B40
29102	Лобня	1	10	\N	37.409027999999999	37.533363999999999	56.067756000000003	55.999499999999998	0103000020E61000000100000005000000FB928D075BB442400E2DB29DEFFF4B40FB928D075BB44240CC0D863AAC084C408F6E844545C44240CC0D863AAC084C408F6E844545C442400E2DB29DEFFF4B40FB928D075BB442400E2DB29DEFFF4B40
61867	Ликино-Дулево	1	10	\N	38.933154999999999	38.974620999999999	55.744708000000003	55.688491999999997	0103000020E61000000100000005000000A88C7F9F7177434060C77F8120D84B40A88C7F9F71774340E8887C9752DF4B40567F8461C07C4340E8887C9752DF4B40567F8461C07C434060C77F8120D84B40A88C7F9F7177434060C77F8120D84B40
61936	Куровское	1	10	\N	38.863382999999999	38.964694999999999	55.603785999999999	55.567148000000003	0103000020E6100000010000000500000010768A55836E4340F4FE3F4E98C84B4010768A55836E43402EE411DC48CD4B40AFCE31207B7B43402EE411DC48CD4B40AFCE31207B7B4340F4FE3F4E98C84B4010768A55836E4340F4FE3F4E98C84B40
61968	Кратово	1	10	\N	38.121087000000003	38.204746999999998	55.623086999999998	55.571820000000002	0103000020E61000000100000005000000427C60C77F0F43407099D36531C94B40427C60C77F0F434008C89750C1CF4B40207A5226351A434008C89750C1CF4B40207A5226351A43407099D36531C94B40427C60C77F0F43407099D36531C94B40
59506	Краснознаменск	1	10	\N	37.024388000000002	37.068001000000002	55.606914000000003	55.580986000000003	0103000020E610000001000000050000001A355F251F83424089B7CEBF5DCA4B401A355F251F83424006BEA25BAFCD4B40338CBB41B488424006BEA25BAFCD4B40338CBB41B488424089B7CEBF5DCA4B401A355F251F83424089B7CEBF5DCA4B40
61932	Краснозаводск	1	10	\N	38.206471999999998	38.287993999999998	56.459446999999997	56.410519999999998	0103000020E6100000010000000500000015C5ABAC6D1A43404D2D5BEB8B344C4015C5ABAC6D1A4340669FC728CF3A4C40DCB8C5FCDC244340669FC728CF3A4C40DCB8C5FCDC2443404D2D5BEB8B344C4015C5ABAC6D1A43404D2D5BEB8B344C40
59550	Красногорск	1	10	\N	37.229140999999998	37.394089000000001	55.851278000000001	55.799886999999998	0103000020E610000001000000050000001C96067E549D42406EBF7CB262E64B401C96067E549D4240F3E670ADF6EC4B404F5B238271B24240F3E670ADF6EC4B404F5B238271B242406EBF7CB262E64B401C96067E549D42406EBF7CB262E64B40
15725	Красноармейск	1	10	\N	38.097219000000003	38.18723	56.135323	56.091124999999998	0103000020E6100000010000000500000061C614AC710C43408B6CE7FBA90B4C4061C614AC710C4340C4B2994352114C40406A1327F7174340C4B2994352114C40406A1327F71743408B6CE7FBA90B4C4061C614AC710C43408B6CE7FBA90B4C40
1202	Котельники	1	10	\N	37.832718999999997	37.89808	55.676357000000003	55.638404000000001	0103000020E6100000010000000500000000E1438996EA42405BD1E638B7D14B4000E1438996EA4240D9B5BDDD92D64B4089981249F4F24240D9B5BDDD92D64B4089981249F4F242405BD1E638B7D14B4000E1438996EA42405BD1E638B7D14B40
722	Королев	1	10	\N	37.788404999999997	37.947631000000001	55.960099999999997	55.876379999999997	0103000020E610000001000000050000005E807D74EAE442402A6F47382DF04B405E807D74EAE44240DE718A8EE4FA4B4080D6FCF84BF94240DE718A8EE4FA4B4080D6FCF84BF942402A6F47382DF04B405E807D74EAE442402A6F47382DF04B40
5426	Коломна	1	10	\N	38.690564999999999	38.90484	55.132747000000002	55.028032000000003	0103000020E610000001000000050000009161156F64584340E99E758D96834B409161156F6458434031D28BDAFD904B406B0E10CCD173434031D28BDAFD904B406B0E10CCD1734340E99E758D96834B409161156F64584340E99E758D96834B40
59548	Клин	1	10	\N	36.671332	36.780566999999998	56.380259000000002	56.311810999999999	0103000020E610000001000000050000000F61FC34EE5542403BC43F6CE9274C400F61FC34EE5542403D81B053AC304C401DAB949EE96342403D81B053AC304C401DAB949EE96342403BC43F6CE9274C400F61FC34EE5542403BC43F6CE9274C40
13220	Климовск	1	10	\N	37.484900000000003	37.568102000000003	55.389615999999997	55.342488000000003	0103000020E610000001000000050000004BEA043411BE4240E0A293A5D6AB4B404BEA043411BE4240C9FFE4EFDEB14B406765FB90B7C84240C9FFE4EFDEB14B406765FB90B7C84240E0A293A5D6AB4B404BEA043411BE4240E0A293A5D6AB4B40
61929	Кашира	1	10	\N	38.131382000000002	38.261448999999999	54.860570000000003	54.816240000000001	0103000020E610000001000000050000003CA41820D1104340F1D7648D7A684B403CA41820D110434099F56228276E4B4034492C297721434099F56228276E4B4034492C2977214340F1D7648D7A684B403CA41820D1104340F1D7648D7A684B40
60277	Истра	1	10	\N	36.817075000000003	36.901139000000001	55.932395	55.890295000000002	0103000020E610000001000000050000008AB0E1E9956842406B65C22FF5F14B408AB0E1E9956842401AFA27B858F74B403813D385587342401AFA27B858F74B403813D385587342406B65C22FF5F14B408AB0E1E9956842406B65C22FF5F14B40
61889	Икша	1	10	\N	37.481090999999999	37.516530000000003	56.187475999999997	56.160516000000001	0103000020E6100000010000000500000031B3CF6394BD42400C3ECDC98B144C4031B3CF6394BD42407764AC36FF174C4092B3B0A71DC242407764AC36FF174C4092B3B0A71DC242400C3ECDC98B144C4031B3CF6394BD42400C3ECDC98B144C40
7706	Ивантеевка	1	10	\N	37.871867000000002	37.972389	55.993499	55.954732999999997	0103000020E6100000010000000500000017BB7D5699EF4240BBB4E1B034FA4B4017BB7D5699EF4240EACDA8F92AFF4B40BDFE243E77FC4240EACDA8F92AFF4B40BDFE243E77FC4240BBB4E1B034FA4B4017BB7D5699EF4240BBB4E1B034FA4B40
5833	Звенигород	1	10	\N	36.806851999999999	36.904445000000003	55.748649999999998	55.699142000000002	0103000020E61000000100000005000000295B24ED4667424049A12C7C7DD94B40295B24ED46674240401361C3D3DF4B40EF0390DAC4734240401361C3D3DF4B40EF0390DAC473424049A12C7C7DD94B40295B24ED4667424049A12C7C7DD94B40
61931	Звездный городок	1	10	\N	35.144106000000001	40.204334000000003	56.961320000000001	54.256076	0103000020E610000001000000050000002594BE10729241402FA52E19C7204B402594BE1072924140D07EA4880C7B4C40FEBAD39D271A4440D07EA4880C7B4C40FEBAD39D271A44402FA52E19C7204B402594BE10729241402FA52E19C7204B40
60232	Зарайск	1	10	\N	38.853051999999998	38.908281000000002	54.798473000000001	54.744134000000003	0103000020E61000000100000005000000C9E4D4CE306D4340BCEB6CC83F5F4B40C9E4D4CE306D434098DEFE5C34664B40024A438D4274434098DEFE5C34664B40024A438D42744340BCEB6CC83F5F4B40C9E4D4CE306D4340BCEB6CC83F5F4B40
5694	Жуковский	1	10	\N	38.067943	38.185667000000002	55.614199999999997	55.533929000000001	0103000020E61000000100000005000000FE7E315BB208434068B114C957C44B40FE7E315BB2084340029A081B9ECE4B402579AEEFC3174340029A081B9ECE4B402579AEEFC317434068B114C957C44B40FE7E315BB208434068B114C957C44B40
2581	Железнодорожный	1	10	\N	37.942932999999996	38.145009000000002	55.766921000000004	55.715743000000003	0103000020E61000000100000005000000DAA84E07B2F84240A4AB74779DDB4B40DAA84E07B2F84240CDCEA2772AE24B401650A8A78F124340CDCEA2772AE24B401650A8A78F124340A4AB74779DDB4B40DAA84E07B2F84240A4AB74779DDB4B40
61924	Егорьевск	1	10	\N	38.992182999999997	39.090989	55.405898999999998	55.355786999999999	0103000020E61000000100000005000000D65240DAFF7E4340C5ABAC6D8AAD4B40D65240DAFF7E4340533D997FF4B34B40DBA50D87A58B4340533D997FF4B34B40DBA50D87A58B4340C5ABAC6D8AAD4B40D65240DAFF7E4340C5ABAC6D8AAD4B40
1343	Дубна	1	10	\N	37.101832000000002	37.256377999999998	56.783060999999996	56.698245	0103000020E61000000100000005000000D8D7BAD4088D42403ACC971760594C40D8D7BAD4088D4240F3E2C4573B644C40FAB48AFED0A04240F3E2C4573B644C40FAB48AFED0A042403ACC971760594C40D8D7BAD4088D42403ACC971760594C40
4639	Домодедово	1	10	\N	37.636814000000001	38.164124999999999	55.564027000000003	55.264054999999999	0103000020E6100000010000000500000046D1031F83D1424032ACE28DCCA14B4046D1031F83D14240CF87670932C84B405EBA490C02154340CF87670932C84B405EBA490C0215434032ACE28DCCA14B4046D1031F83D1424032ACE28DCCA14B40
10881	Долгопрудный	1	10	\N	37.451447000000002	37.536526000000002	55.996535000000002	55.897058999999999	0103000020E610000001000000050000004C70EA03C9B942408ECA4DD4D2F24B404C70EA03C9B94240E12879758EFF4B4013BA4BE2ACC44240E12879758EFF4B4013BA4BE2ACC442408ECA4DD4D2F24B404C70EA03C9B942408ECA4DD4D2F24B40
60253	Дмитров	1	10	\N	37.489356000000001	37.570483000000003	56.401713999999998	56.317926999999997	0103000020E61000000100000005000000FA0CA837A3BE4240F8C1F9D4B1284C40FA0CA837A3BE4240342C465D6B334C4045F6419605C94240342C465D6B334C4045F6419605C94240F8C1F9D4B1284C40FA0CA837A3BE4240F8C1F9D4B1284C40
22061	Дзержинский	1	10	\N	37.796427000000001	37.887138999999998	55.648721999999999	55.607233999999998	0103000020E610000001000000050000006153E751F1E542407782FDD7B9CD4B406153E751F1E542400D198F5209D34B40C90050C58DF142400D198F5209D34B40C90050C58DF142407782FDD7B9CD4B406153E751F1E542407782FDD7B9CD4B40
61926	Дедовск	1	10	\N	37.092274000000003	37.148212000000001	55.895221999999997	55.847769999999997	0103000020E61000000100000005000000B4226AA2CF8B4240D44334BA83EC4B40B4226AA2CF8B424071546EA296F24B40F86F5E9CF892424071546EA296F24B40F86F5E9CF8924240D44334BA83EC4B40B4226AA2CF8B4240D44334BA83EC4B40
61956	Городна	1	10	\N	38.793314000000002	38.823498000000001	54.966566	54.948090999999998	0103000020E61000000100000005000000BFBA2A508B654340E350BF0B5B794B40BFBA2A508B65434078B6476FB87B4B402429E9616869434078B6476FB87B4B402429E96168694340E350BF0B5B794B40BFBA2A508B654340E350BF0B5B794B40
61895	Воскресенск	1	10	\N	38.635804	38.784080000000003	55.360202999999998	55.236519000000001	0103000020E610000001000000050000003F55850662514340FAF02C41469E4B403F55850662514340E675C4211BAE4B404EB9C2BB5C644340E675C4211BAE4B404EB9C2BB5C644340FAF02C41469E4B403F55850662514340FAF02C41469E4B40
61890	Волоколамск	1	10	\N	35.908932	35.997461000000001	56.081792999999998	55.979339000000003	0103000020E61000000100000005000000D9243FE257F441404359F8FA5AFD4B40D9243FE257F4414057056A31780A4C408A0453CDACFF414057056A31780A4C408A0453CDACFF41404359F8FA5AFD4B40D9243FE257F441404359F8FA5AFD4B40
60269	Власиха	1	10	\N	37.171827999999998	37.210994999999997	55.693007999999999	55.677447999999998	0103000020E61000000100000005000000BF44BC75FE954240CC5EB69DB6D64B40BF44BC75FE954240E5EE737CB4D84B404C4F58E2019B4240E5EE737CB4D84B404C4F58E2019B4240CC5EB69DB6D64B40BF44BC75FE954240CC5EB69DB6D64B40
59566	Власиха	1	10	\N	37.171827999999998	37.210994999999997	55.693007999999999	55.677447999999998	0103000020E61000000100000005000000BF44BC75FE954240CC5EB69DB6D64B40BF44BC75FE954240E5EE737CB4D84B404C4F58E2019B4240E5EE737CB4D84B404C4F58E2019B4240CC5EB69DB6D64B40BF44BC75FE954240CC5EB69DB6D64B40
61935	Видное	1	10	\N	37.644117999999999	37.777329000000002	55.573540999999999	55.528345000000002	0103000020E61000000100000005000000E961687572D24240A80018CFA0C34B40E961687572D2424023F59ECA69C94B40BF9D44847FE3424023F59ECA69C94B40BF9D44847FE34240A80018CFA0C34B40E961687572D24240A80018CFA0C34B40
61946	Верея	1	10	\N	36.159695999999997	36.213524	55.362270000000002	55.329298000000001	0103000020E61000000100000005000000A8A624EB70144240B151D66F26AA4B40A8A624EB70144240352905DD5EAE4B409F7422C1541B4240352905DD5EAE4B409F7422C1541B4240B151D66F26AA4B40A8A624EB70144240B151D66F26AA4B40
13981	Бронницы	1	10	\N	38.196986000000003	38.304792999999997	55.442678999999998	55.396237999999997	0103000020E610000001000000050000008BE255D6361943405AB741EDB7B24B408BE255D63619434020D099B4A9B84B405D86FF740327434020D099B4A9B84B405D86FF74032743405AB741EDB7B24B408BE255D6361943405AB741EDB7B24B40
3929	Балашиха	1	10	\N	37.82741	38.059587999999998	55.846406000000002	55.738104999999997	0103000020E6100000010000000500000012312592E8E94240CD0182397ADE4B4012312592E8E94240B091240857EC4B40F59D5F94A0074340B091240857EC4B40F59D5F94A0074340CD0182397ADE4B4012312592E8E94240CD0182397ADE4B40
61951	Ашукино	1	10	\N	37.918759999999999	37.983609000000001	56.186379000000002	56.148327999999999	0103000020E61000000100000005000000BD6F7CED99F54240618A7269FC124C40BD6F7CED99F54240A2D45E44DB174C40908653E6E6FD4240A2D45E44DB174C40908653E6E6FD4240618A7269FC124C40BD6F7CED99F54240618A7269FC124C40
61944	Апрелевка	1	10	\N	37.007427999999997	37.110239999999997	55.572803	55.524844000000002	0103000020E610000001000000050000008F899466F38042403CC093162EC34B408F899466F38042407D06D49B51C94B40035B25581C8E42407D06D49B51C94B40035B25581C8E42403CC093162EC34B408F899466F38042403CC093162EC34B40
62034	Ботово	1	10	490	38.413632	38.432792999999997	56.054482	56.046272999999999	0103000020E610000001000000050000001F4AB4E4F13443400AD80E46EC054C401F4AB4E4F13443403F1C2444F9064C400778D2C2653743403F1C2444F9064C400778D2C2653743400AD80E46EC054C401F4AB4E4F13443400AD80E46EC054C40
61962	Мирный	1	10	1692	37.461202999999998	37.479447	54.898038999999997	54.891981000000001	0103000020E6100000010000000500000096E82CB308BB4240A2D3F36E2C724B4096E82CB308BB42402AC423F1F2724B402995F0845EBD42402AC423F1F2724B402995F0845EBD4240A2D3F36E2C724B4096E82CB308BB4240A2D3F36E2C724B40
2295	Кузнечики	1	10	89	37.464958000000003	37.494332	55.421287	55.407116000000002	0103000020E61000000100000005000000BD0166BE83BB4240D4D688601CB44B40BD0166BE83BB42406F9D7FBBECB54B40E2AE5E4546BF42406F9D7FBBECB54B40E2AE5E4546BF4240D4D688601CB44B40BD0166BE83BB4240D4D688601CB44B40
25140	Краснознаменск	1	10	1767	37.024388000000002	37.068001000000002	55.606914000000003	55.580986000000003	0103000020E610000001000000050000001A355F251F83424089B7CEBF5DCA4B401A355F251F83424006BEA25BAFCD4B40338CBB41B488424006BEA25BAFCD4B40338CBB41B488424089B7CEBF5DCA4B401A355F251F83424089B7CEBF5DCA4B40
18301	Радужный	1	10	1433	38.716976000000003	38.736378999999999	55.146188000000002	55.130240000000001	0103000020E610000001000000050000002A029CDEC55B4340C6504EB4AB904B402A029CDEC55B4340A988D349B6924B40083BC5AA415E4340A988D349B6924B40083BC5AA415E4340C6504EB4AB904B402A029CDEC55B4340C6504EB4AB904B40
59553	Подольской машинно-испытательной станции	1	10	7481	37.531028999999997	37.562702999999999	55.357377999999997	55.340086999999997	0103000020E61000000100000005000000211D1EC2F8C34240BA6587F887AB4B40211D1EC2F8C34240AA27F38FBEAD4B40382EE3A606C84240AA27F38FBEAD4B40382EE3A606C84240BA6587F887AB4B40211D1EC2F8C34240BA6587F887AB4B40
59514	Ям	1	10	344	37.604996	38.120728	55.523214000000003	55.124428999999999	0103000020E61000000100000005000000FC1A498270CD424045D61A4AED8F4B40FC1A498270CD4240996725ADF8C24B4012DBDD03740F4340996725ADF8C24B4012DBDD03740F434045D61A4AED8F4B40FC1A498270CD424045D61A4AED8F4B40
30238	Чурилково	1	10	344	37.822577000000003	37.843615	55.502201999999997	55.489116000000003	0103000020E610000001000000050000008DB800344AE94240A5F9635A9BBE4B408DB800344AE942402EFEB62748C04B4020B58993FBEB42402EFEB62748C04B4020B58993FBEB4240A5F9635A9BBE4B408DB800344AE94240A5F9635A9BBE4B40
22988	Сосны	1	10	344	37.880445999999999	37.891702000000002	55.35962	55.353673000000001	0103000020E610000001000000050000006FF25B74B2F04240363D282845AD4B406FF25B74B2F04240677E350708AE4B408FE3874A23F24240677E350708AE4B408FE3874A23F24240363D282845AD4B406FF25B74B2F04240363D282845AD4B40
30786	Санатория Подмосковье	1	10	344	37.746741	37.776007999999997	55.383192999999999	55.370399999999997	0103000020E610000001000000050000008ACA863595DF42401D38674469AF4B408ACA863595DF42402F87DD770CB14B4099B7EA3A54E342402F87DD770CB14B4099B7EA3A54E342401D38674469AF4B408ACA863595DF42401D38674469AF4B40
30955	Растуново	1	10	344	37.827311000000002	37.855285000000002	55.282640999999998	55.264845000000001	0103000020E610000001000000050000007F4FAC53E5E942402BC1E270E6A14B407F4FAC53E5E942401EC18D942DA44B4033E197FA79ED42401EC18D942DA44B4033E197FA79ED42402BC1E270E6A14B407F4FAC53E5E942402BC1E270E6A14B40
30144	Повадино	1	10	344	37.734847000000002	37.753416000000001	55.196823999999999	55.186684	0103000020E6100000010000000500000028486C770FDE4240DE57E542E5974B4028486C770FDE4240B188618731994B403E247CEF6FE04240B188618731994B403E247CEF6FE04240DE57E542E5974B4028486C770FDE4240DE57E542E5974B40
31058	Павловское	1	10	344	37.710763999999998	37.736122999999999	55.493946000000001	55.477822000000003	0103000020E610000001000000050000004A969350FADA424098A7734529BD4B404A969350FADA4240B9FE5D9F39BF4B40AD6A494739DE4240B9FE5D9F39BF4B40AD6A494739DE424098A7734529BD4B404A969350FADA424098A7734529BD4B40
60233	ОПК БОР	1	10	344	37.604996	38.120728	55.523214000000003	55.124428999999999	0103000020E61000000100000005000000FC1A498270CD424045D61A4AED8F4B40FC1A498270CD4240996725ADF8C24B4012DBDD03740F4340996725ADF8C24B4012DBDD03740F434045D61A4AED8F4B40FC1A498270CD424045D61A4AED8F4B40
30363	Лямцино	1	10	344	37.869559000000002	37.889994999999999	55.388843999999999	55.375342000000003	0103000020E61000000100000005000000A37895B54DEF42405A68E7340BB04B40A37895B54DEF4240779FE3A3C5B14B40404D2D5BEBF14240779FE3A3C5B14B40404D2D5BEBF142405A68E7340BB04B40A37895B54DEF42405A68E7340BB04B40
30560	Лобаново	1	10	344	37.935099999999998	37.956803000000001	55.305610000000001	55.290920999999997	0103000020E61000000100000005000000AB3E575BB1F742401C5C3AE63CA54B40AB3E575BB1F7424050AA7D3A1EA74B407BDB4C8578FA424050AA7D3A1EA74B407BDB4C8578FA42401C5C3AE63CA54B40AB3E575BB1F742401C5C3AE63CA54B40
30282	Красный Путь	1	10	344	37.914968999999999	37.934227999999997	55.348241999999999	55.342779999999998	0103000020E610000001000000050000004AED45B41DF5424087DC0C37E0AB4B404AED45B41DF54240FC8BA03193AC4B40F58079C894F74240FC8BA03193AC4B40F58079C894F7424087DC0C37E0AB4B404AED45B41DF5424087DC0C37E0AB4B40
30605	Ильинское	1	10	344	37.949392000000003	37.975192	55.251736999999999	55.231862999999997	0103000020E61000000100000005000000C28A53AD85F942408313D1AFAD9D4B40C28A53AD85F94240B91803EB38A04B4011A96917D3FC4240B91803EB38A04B4011A96917D3FC42408313D1AFAD9D4B40C28A53AD85F942408313D1AFAD9D4B40
49289	Ивановка	1	10	344	37.688378	37.712336000000001	55.356968999999999	55.348334000000001	0103000020E6100000010000000500000098A432C51CD84240DD0A613596AC4B4098A432C51CD84240C9570229B1AD4B40B9E177D32DDB4240C9570229B1AD4B40B9E177D32DDB4240DD0A613596AC4B4098A432C51CD84240DD0A613596AC4B40
30629	Заболотье	1	10	344	37.667824000000003	37.680777999999997	55.454130999999997	55.441678000000003	0103000020E61000000100000005000000F1BDBF417BD542406DAE9AE788B84B40F1BDBF417BD54240C58CF0F620BA4B400BEBC6BB23D74240C58CF0F620BA4B400BEBC6BB23D742406DAE9AE788B84B40F1BDBF417BD542406DAE9AE788B84B40
59562	Житнево	1	10	344	37.903776000000001	37.932234000000001	55.345821000000001	55.336595000000003	0103000020E61000000100000005000000717495EEAEF34240A27F828B15AB4B40717495EEAEF3424090A2CEDC43AC4B40111C977153F7424090A2CEDC43AC4B40111C977153F74240A27F828B15AB4B40717495EEAEF34240A27F828B15AB4B40
30987	Добрыниха	1	10	344	37.688692000000003	37.716799999999999	55.187069999999999	55.178767999999998	0103000020E610000001000000050000002882380F27D8424021C9ACDEE1964B402882380F27D842400708E6E8F1974B40EBE2361AC0DB42400708E6E8F1974B40EBE2361AC0DB424021C9ACDEE1964B402882380F27D8424021C9ACDEE1964B40
30191	Голубино	1	10	344	37.795079000000001	37.812632999999998	55.23424	55.224403000000002	0103000020E61000000100000005000000425E0F26C5E54240E90FCD3CB99C4B40425E0F26C5E5424020B58993FB9D4B403F53AF5B04E8424020B58993FB9D4B403F53AF5B04E84240E90FCD3CB99C4B40425E0F26C5E54240E90FCD3CB99C4B40
30466	Гальчино	1	10	344	37.893166999999998	37.927706999999998	55.282727999999999	55.262070000000001	0103000020E61000000100000005000000E76ED74B53F24240A1A17F828BA14B40E76ED74B53F24240EDD45C6E30A44B4098A25C1ABFF64240EDD45C6E30A44B4098A25C1ABFF64240A1A17F828BA14B40E76ED74B53F24240A1A17F828BA14B40
30104	Вельяминово	1	10	344	37.844990000000003	37.891629999999999	55.203786000000001	55.179718999999999	0103000020E6100000010000000500000039B9DFA128EC424023BC3D0801974B4039B9DFA128EC4240FBB0DEA8159A4B40F5108DEE20F24240FBB0DEA8159A4B40F5108DEE20F2424023BC3D0801974B4039B9DFA128EC424023BC3D0801974B40
7280	Черное	1	10	915	38.043131000000002	38.095826000000002	55.773342999999997	55.740715000000002	0103000020E61000000100000005000000CE380D51850543400D54C6BFCFDE4B40CE380D518505434096CB46E7FCE24B40A20DC006440C434096CB46E7FCE24B40A20DC006440C43400D54C6BFCFDE4B40CE380D51850543400D54C6BFCFDE4B40
16550	Федурново	1	10	915	38.040875999999997	38.055456	55.761167999999998	55.753261000000002	0103000020E610000001000000050000007C98BD6C3B054340172D40DB6AE04B407C98BD6C3B0543408061F9F36DE14B40F92EA52E190743408061F9F36DE14B40F92EA52E19074340172D40DB6AE04B407C98BD6C3B054340172D40DB6AE04B40
16586	Соболиха	1	10	915	38.034723	38.051935	55.737892000000002	55.721873000000002	0103000020E61000000100000005000000A2B5A2CD71044340C66E9F5566DC4B40A2B5A2CD7104434072FDBB3E73DE4B4046425BCEA506434072FDBB3E73DE4B4046425BCEA5064340C66E9F5566DC4B40A2B5A2CD71044340C66E9F5566DC4B40
15718	Новый Милет	1	10	915	38.047344000000002	38.065275	55.713512000000001	55.702022999999997	0103000020E61000000100000005000000B7D4415E0F0643401805C1E3DBD94B40B7D4415E0F064340DBA6785C54DB4B408A1F63EE5A084340DBA6785C54DB4B408A1F63EE5A0843401805C1E3DBD94B40B7D4415E0F0643401805C1E3DBD94B40
60260	Молодежный	1	10	930	36.779220000000002	36.792783999999997	55.332298999999999	55.321835	0103000020E61000000100000005000000CF31207BBD634240A5DAA7E331A94B40CF31207BBD6342402BBF0CC688AA4B40626534F2796542402BBF0CC688AA4B40626534F279654240A5DAA7E331A94B40CF31207BBD634240A5DAA7E331A94B40
61919	поселение Монино	1	10	78	38.152895999999998	38.221590999999997	55.854987000000001	55.824860000000001	0103000020E6100000010000000500000038D89B1892134340A8E3310395E94B4038D89B1892134340A9C0C93670ED4B40410B09185D1C4340A9C0C93670ED4B40410B09185D1C4340A8E3310395E94B4038D89B1892134340A8E3310395E94B40
11406	Юность	1	10	78	38.124625999999999	38.134839999999997	55.922777000000004	55.917178	0103000020E610000001000000050000009B1DA9BEF30F43402B4EB51666F54B409B1DA9BEF30F43402140868E1DF64B40A818E76F421143402140868E1DF64B40A818E76F421143402B4EB51666F54B409B1DA9BEF30F43402B4EB51666F54B40
271	Щелково	1	10	78	37.939331000000003	38.095278	55.955806000000003	55.863965	0103000020E610000001000000050000003B8F8AFF3BF84240BFF1B56796EE4B403B8F8AFF3BF8424009A9DBD957FA4B409F03CB11320C434009A9DBD957FA4B409F03CB11320C4340BFF1B56796EE4B403B8F8AFF3BF84240BFF1B56796EE4B40
61943	Фряново	1	10	78	38.403202999999998	38.458297000000002	56.146858999999999	56.113360999999998	0103000020E610000001000000050000001553E9279C33434028D2FD9C820E4C401553E9279C334340C70F9546CC124C406E6DE179A93A4340C70F9546CC124C406E6DE179A93A434028D2FD9C820E4C401553E9279C33434028D2FD9C820E4C40
61941	Фряново	1	10	78	38.403202999999998	38.458297000000002	56.146858999999999	56.113360999999998	0103000020E610000001000000050000001553E9279C33434028D2FD9C820E4C401553E9279C334340C70F9546CC124C406E6DE179A93A4340C70F9546CC124C406E6DE179A93A434028D2FD9C820E4C401553E9279C33434028D2FD9C820E4C40
12116	Трубино	1	10	78	38.117565999999997	38.139699999999998	55.998237000000003	55.981735999999998	0103000020E610000001000000050000008E8F16670C0F434026A77686A9FD4B408E8F16670C0F43401E54E23AC6FF4B4027A089B0E11143401E54E23AC6FF4B4027A089B0E111434026A77686A9FD4B408E8F16670C0F434026A77686A9FD4B40
9861	Серково	1	10	78	37.955176999999999	37.977626000000001	55.900798999999999	55.892086999999997	0103000020E6100000010000000500000019726C3D43FA4240E71725E82FF24B4019726C3D43FA42407FA2B2614DF34B4012DC48D922FD42407FA2B2614DF34B4012DC48D922FD4240E71725E82FF24B4019726C3D43FA4240E71725E82FF24B40
61937	Свердловский	1	10	78	38.120530000000002	38.164808000000001	55.917617	55.890329999999999	0103000020E61000000100000005000000EC17EC866D0F4340E7525C55F6F14B40EC17EC866D0F434077A04E7974F54B40410FB56D1815434077A04E7974F54B40410FB56D18154340E7525C55F6F14B40EC17EC866D0F4340E7525C55F6F14B40
9552	Свердловский	1	10	78	38.120530000000002	38.164808000000001	55.917617	55.890329999999999	0103000020E61000000100000005000000EC17EC866D0F4340E7525C55F6F14B40EC17EC866D0F434077A04E7974F54B40410FB56D1815434077A04E7974F54B40410FB56D18154340E7525C55F6F14B40EC17EC866D0F4340E7525C55F6F14B40
12068	Петровское	1	10	78	38.213693999999997	38.239807999999996	56.100363999999999	56.077734	0103000020E61000000100000005000000FBAC32535A1B4340C5E40D30F3094C40FBAC32535A1B43400ED940BAD80C4C40DAA84E07B21E43400ED940BAD80C4C40DAA84E07B21E4340C5E40D30F3094C40FBAC32535A1B4340C5E40D30F3094C40
11823	Первая Алексеевка	1	10	78	38.218688999999998	38.234786999999997	56.013452000000001	56.007368	0103000020E610000001000000050000005A7F4B00FE1B4340BA84436FF1004C405A7F4B00FE1B43406C088ECBB8014C4052431B800D1E43406C088ECBB8014C4052431B800D1E4340BA84436FF1004C405A7F4B00FE1B4340BA84436FF1004C40
11944	Огуднево	1	10	78	38.239511999999998	38.280932999999997	56.069831000000001	56.058653999999997	0103000020E61000000100000005000000F17F4754A81E4340C9E369F981074C40F17F4754A81E43409D9FE238F0084C40FFAECF9CF52343409D9FE238F0084C40FFAECF9CF5234340C9E369F981074C40F17F4754A81E4340C9E369F981074C40
10819	Оболдино	1	10	78	37.920529000000002	37.940103000000001	55.897306	55.876829000000001	0103000020E610000001000000050000008202EFE4D3F542409A97C3EE3BF04B408202EFE4D3F5424096404AECDAF24B408DEF8B4B55F8424096404AECDAF24B408DEF8B4B55F842409A97C3EE3BF04B408202EFE4D3F542409A97C3EE3BF04B40
31977	Новофрязино	1	10	78	38.060414999999999	38.081642000000002	55.970095999999998	55.957368000000002	0103000020E610000001000000050000000B98C0ADBB074340541EDD088BFA4B400B98C0ADBB0743407EFD101B2CFC4B4072FDBB3E730A43407EFD101B2CFC4B4072FDBB3E730A4340541EDD088BFA4B400B98C0ADBB074340541EDD088BFA4B40
11152	Никифорово	1	10	78	38.064672999999999	38.094819999999999	55.849918000000002	55.839213000000001	0103000020E6100000010000000500000094F771344708434064B0E2546BEB4B4094F77134470843401024EF1CCAEC4B40DC80CF0F230C43401024EF1CCAEC4B40DC80CF0F230C434064B0E2546BEB4B4094F771344708434064B0E2546BEB4B40
61873	Монино	1	10	78	38.152895999999998	38.221590999999997	55.854987000000001	55.824860000000001	0103000020E6100000010000000500000038D89B1892134340A8E3310395E94B4038D89B1892134340A9C0C93670ED4B40410B09185D1C4340A9C0C93670ED4B40410B09185D1C4340A8E3310395E94B4038D89B1892134340A8E3310395E94B40
12204	Мишнево	1	10	78	38.187023000000003	38.210990000000002	55.997763999999997	55.981746999999999	0103000020E61000000100000005000000C74CA25EF01743401AF9BCE2A9FD4B40C74CA25EF0174340259012BBB6FF4B403BE466B8011B4340259012BBB6FF4B403BE466B8011B43401AF9BCE2A9FD4B40C74CA25EF01743401AF9BCE2A9FD4B40
11461	Мизиново	1	10	78	38.197443999999997	38.224024999999997	55.957061000000003	55.946173999999999	0103000020E610000001000000050000004D6551D845194340AA29C93A1CF94B404D6551D84519434077A38FF980FA4B40423EE8D9AC1C434077A38FF980FA4B40423EE8D9AC1C4340AA29C93A1CF94B404D6551D845194340AA29C93A1CF94B40
11520	Медное-Власово	1	10	78	38.192287999999998	38.204090999999998	55.941501000000002	55.936756000000003	0103000020E61000000100000005000000E5B4A7E49C184340782AE09EE7F74B40E5B4A7E49C1843405E13D21A83F84B40373465A71F1A43405E13D21A83F84B40373465A71F1A4340782AE09EE7F74B40E5B4A7E49C184340782AE09EE7F74B40
11138	Медвежьи Озера	1	10	78	37.980240000000002	38.002868999999997	55.873641999999997	55.856400999999998	0103000020E61000000100000005000000931D1B8178FD42407FA1478C9EED4B40931D1B8178FD4240BD344580D3EF4B400B96EA025E004340BD344580D3EF4B400B96EA025E0043407FA1478C9EED4B40931D1B8178FD42407FA1478C9EED4B40
12201	Литвиново	1	10	78	38.114538000000003	38.146068999999997	56.023218	56.004615000000001	0103000020E610000001000000050000001B13622EA90E434018096D3997004C401B13622EA90E4340DA56B3CEF8024C40CEFA9463B2124340DA56B3CEF8024C40CEFA9463B212434018096D3997004C401B13622EA90E434018096D3997004C40
10517	Краснознаменский	1	10	78	37.924768999999998	37.954261000000002	55.939303000000002	55.931643000000001	0103000020E6100000010000000500000064ADA1D45EF642400F46EC1340F74B4064ADA1D45EF642407104A9143BF84B40946C753925FA42407104A9143BF84B40946C753925FA42400F46EC1340F74B4064ADA1D45EF642400F46EC1340F74B40
11677	Корпуса	1	10	78	38.213721	38.234383000000001	55.878171999999999	55.869213000000002	0103000020E61000000100000005000000F5BBB0355B1B43400821205F42EF4B40F5BBB0355B1B4340A721AAF067F04B4083DE1B43001E4340A721AAF067F04B4083DE1B43001E43400821205F42EF4B40F5BBB0355B1B43400821205F42EF4B40
60271	Загорянский	1	10	78	37.896957	37.959668999999998	55.935743000000002	55.896175999999997	0103000020E610000001000000050000008A75AA7CCFF24240E4BA29E5B5F24B408A75AA7CCFF24240003B376DC6F74B4015FE0C6FD6FA4240003B376DC6F74B4015FE0C6FD6FA4240E4BA29E5B5F24B408A75AA7CCFF24240E4BA29E5B5F24B40
94	Загорянский	1	10	78	37.896957	37.959668999999998	55.935743000000002	55.896175999999997	0103000020E610000001000000050000008A75AA7CCFF24240E4BA29E5B5F24B408A75AA7CCFF24240003B376DC6F74B4015FE0C6FD6FA4240003B376DC6F74B4015FE0C6FD6FA4240E4BA29E5B5F24B408A75AA7CCFF24240E4BA29E5B5F24B40
12596	Еремино	1	10	78	38.497453999999998	38.514404999999996	56.119559000000002	56.107146999999998	0103000020E61000000100000005000000D7A19A92AC3F4340A86E2EFEB60D4C40D7A19A92AC3F4340A37895B54D0F4C400EF3E505D8414340A37895B54D0F4C400EF3E505D8414340A86E2EFEB60D4C40D7A19A92AC3F4340A86E2EFEB60D4C40
12018	Душоново	1	10	78	38.292126000000003	38.310217999999999	56.064565000000002	56.054501999999999	0103000020E61000000100000005000000D92780626425434086C8E9EBF9064C40D927806264254340AEBB79AA43084C40B5503239B5274340AEBB79AA43084C40B5503239B527434086C8E9EBF9064C40D92780626425434086C8E9EBF9064C40
11072	Долгое Ледово	1	10	78	37.967188	37.984614999999998	55.861266999999998	55.848210000000002	0103000020E61000000100000005000000B58AFED0CCFB4240F111312592EC4B40B58AFED0CCFB4240E00F3FFF3DEE4B40551344DD07FE4240E00F3FFF3DEE4B40551344DD07FE4240F111312592EC4B40B58AFED0CCFB4240F111312592EC4B40
12584	Головино	1	10	78	38.400480999999999	38.42266	56.136361000000001	56.127633000000003	0103000020E61000000100000005000000AED51EF642334340F871344756104C40AED51EF64233434095B9F94674114C40E7A90EB91936434095B9F94674114C40E7A90EB919364340F871344756104C40AED51EF642334340F871344756104C40
49658	Воря-Богородское	1	10	78	38.145288000000001	38.169981999999997	56.061781000000003	56.044638999999997	0103000020E61000000100000005000000294014CC98124340259012BBB6054C40294014CC98124340D1419770E8074C404F745DF8C1154340D1419770E8074C404F745DF8C1154340259012BBB6054C40294014CC98124340259012BBB6054C40
12679	Булаково	1	10	78	38.368169000000002	38.381194000000001	56.187655999999997	56.180267000000001	0103000020E6100000010000000500000055336B29202F434026C632FD12174C4055336B29202F4340F7729F1C05184C4039B709F7CA304340F7729F1C05184C4039B709F7CA30434026C632FD12174C4055336B29202F434026C632FD12174C40
11771	Богослово	1	10	78	38.055241000000002	38.078730999999998	56.020994000000002	56.005445000000002	0103000020E61000000100000005000000FD321823120743409F76F86BB2004C40FD32182312074340C4B46FEEAF024C4037177FDB130A4340C4B46FEEAF024C4037177FDB130A43409F76F86BB2004C40FD321823120743409F76F86BB2004C40
11316	Биокомбината	1	10	78	38.097065999999998	38.118751000000003	55.922046000000002	55.912737999999997	0103000020E61000000100000005000000DAC69FA86C0C434081E84999D4F44B40DAC69FA86C0C43402DB4739A05F64B4004AF963B330F43402DB4739A05F64B4004AF963B330F434081E84999D4F44B40DAC69FA86C0C434081E84999D4F44B40
62012	Анискино	1	10	78	38.078722999999997	38.109831	55.911118000000002	55.902555	0103000020E61000000100000005000000B4386398130A4340AFEB17EC86F34B40B4386398130A43400266BE839FF44B40228B34F10E0E43400266BE839FF44B40228B34F10E0E4340AFEB17EC86F34B40B4386398130A4340AFEB17EC86F34B40
49227	Шестаково	1	10	957	35.508642000000002	35.528675	56.065198000000002	56.054648	0103000020E610000001000000050000009FAF592E1BC141405A65A6B4FE064C409FAF592E1BC14140DFE1766858084C403D9B559FABC34140DFE1766858084C403D9B559FABC341405A65A6B4FE064C409FAF592E1BC141405A65A6B4FE064C40
60263	Шаховская	1	10	957	35.456449999999997	35.542113999999998	56.040948	56.012082999999997	0103000020E610000001000000050000002D211FF46CBA414035EB8CEF8B014C402D211FF46CBA4140166BB8C83D054C40145AD6FD63C54140166BB8C83D054C40145AD6FD63C5414035EB8CEF8B014C402D211FF46CBA414035EB8CEF8B014C40
7863	Шаховская	1	10	957	35.456449999999997	35.542113999999998	56.040948	56.012082999999997	0103000020E610000001000000050000002D211FF46CBA414035EB8CEF8B014C402D211FF46CBA4140166BB8C83D054C40145AD6FD63C54140166BB8C83D054C40145AD6FD63C5414035EB8CEF8B014C402D211FF46CBA414035EB8CEF8B014C40
8163	Степаньково	1	10	957	35.637982000000001	35.657808000000003	56.010542999999998	55.996544999999998	0103000020E61000000100000005000000E5B7E864A9D1414004FF5BC98EFF4B40E5B7E864A9D14140D219187959014C400A86730D33D44140D219187959014C400A86730D33D4414004FF5BC98EFF4B40E5B7E864A9D1414004FF5BC98EFF4B40
8303	Середа	1	10	957	35.483165999999997	35.521354000000002	55.907960000000003	55.885671000000002	0103000020E6100000010000000500000002452C62D8BD41400002D6AA5DF14B4002452C62D8BD4140C009850838F44B40C4D155BABBC24140C009850838F44B40C4D155BABBC241400002D6AA5DF14B4002452C62D8BD41400002D6AA5DF14B40
7945	Раменье	1	10	957	35.480300999999997	35.519216	56.158616000000002	56.146025999999999	0103000020E61000000100000005000000389ECF807ABD4140CF2EDFFAB0124C40389ECF807ABD4140A94F72874D144C40ACC77DAB75C24140A94F72874D144C40ACC77DAB75C24140CF2EDFFAB0124C40389ECF807ABD4140CF2EDFFAB0124C40
8009	Новоникольское	1	10	957	35.561813999999998	35.577238000000001	56.119745000000002	56.105710999999999	0103000020E61000000100000005000000AC376A85E9C74140EAE923F0870D4C40AC376A85E9C74140056EDDCD530F4C4015014EEFE2C94140056EDDCD530F4C4015014EEFE2C94140EAE923F0870D4C40AC376A85E9C74140EAE923F0870D4C40
8246	Муриково	1	10	957	35.355058	35.382204999999999	56.003064000000002	55.987698999999999	0103000020E610000001000000050000007217618A72AD41405DA5BBEB6CFE4B407217618A72AD4140C1E5B16664004C4010AFEB17ECB04140C1E5B16664004C4010AFEB17ECB041405DA5BBEB6CFE4B407217618A72AD41405DA5BBEB6CFE4B40
7991	Ивашково	1	10	957	35.345283999999999	35.367634000000002	56.227285000000002	56.216459	0103000020E6100000010000000500000081EA1F4432AC414062F6B2EDB41B4C4081EA1F4432AC414089EFC4AC171D4C40E77283A10EAF414089EFC4AC171D4C40E77283A10EAF414062F6B2EDB41B4C4081EA1F4432AC414062F6B2EDB41B4C40
8317	Дубранивка	1	10	957	35.334862999999999	35.354222	55.880096000000002	55.865935	0103000020E61000000100000005000000FAD170CADCAA41401BBB44F5D6EE4B40FAD170CADCAA414093AB58FCA6F04B4009C3802557AD414093AB58FCA6F04B4009C3802557AD41401BBB44F5D6EE4B40FAD170CADCAA41401BBB44F5D6EE4B40
62018	Дор	1	10	957	35.143180999999998	35.752149000000003	56.243063999999997	55.757485000000003	0103000020E610000001000000050000004C3448C153924140F41ABB44F5E04B404C3448C153924140DF6A9DB81C1F4C400C5C1E6B46E04140DF6A9DB81C1F4C400C5C1E6B46E04140F41ABB44F5E04B404C3448C153924140F41ABB44F5E04B40
8140	Белая Колпь	1	10	957	35.648913999999998	35.673437999999997	56.097065999999998	56.084133999999999	0103000020E6100000010000000500000051F52B9D0FD34140A73D25E7C40A4C4051F52B9D0FD34140DAC69FA86C0C4C401BF1643733D64140DAC69FA86C0C4C401BF1643733D64140A73D25E7C40A4C4051F52B9D0FD34140A73D25E7C40A4C40
59537	пос. санатория Озеро Белое	1	10	794	39.977742999999997	39.995206000000003	55.260772000000003	55.251136000000002	0103000020E610000001000000050000004B72C0AE26FD4340946C753925A04B404B72C0AE26FD434034DB15FA60A14B40396403E962FF434034DB15FA60A14B40396403E962FF4340946C753925A04B404B72C0AE26FD4340946C753925A04B40
7717	Шеино	1	10	794	40.081795	40.097506000000003	55.356805000000001	55.347991	0103000020E61000000100000005000000F8FC3042780A4440B32616F88AAC4B40F8FC3042780A44404F0647C9ABAD4B40F7949C137B0C44404F0647C9ABAD4B40F7949C137B0C4440B32616F88AAC4B40F8FC3042780A4440B32616F88AAC4B40
6454	Шатурторф	1	10	794	39.400224999999999	39.436526000000001	55.576421000000003	55.552881999999997	0103000020E610000001000000050000005305A3923AB3434006465ED6C4C64B405305A3923AB3434023DDCF29C8C94B4046ED7E15E0B7434023DDCF29C8C94B4046ED7E15E0B7434006465ED6C4C64B405305A3923AB3434006465ED6C4C64B40
5601	Шатура	1	10	794	39.497000999999997	39.586948999999997	55.615333999999997	55.557388000000003	0103000020E61000000100000005000000268A90BA9DBF434068976F7D58C74B40268A90BA9DBF4340F50EB743C3CE4B40BFB5132521CB4340F50EB743C3CE4B40BFB5132521CB434068976F7D58C74B40268A90BA9DBF434068976F7D58C74B40
7586	Шарапово	1	10	794	39.534263000000003	39.555974999999997	55.295724	55.279922999999997	0103000020E610000001000000050000003F3BE0BA62C44340F8325184D4A34B403F3BE0BA62C443403752B648DAA54B40613255302AC743403752B648DAA54B40613255302AC74340F8325184D4A34B403F3BE0BA62C44340F8325184D4A34B40
62055	Черусти	1	10	794	39.972991	40.040266000000003	55.566414999999999	55.529964999999997	0103000020E61000000100000005000000B32616F88AFC43402783A3E4D5C34B40B32616F88AFC43405F7B664980C84B400492B06F270544405F7B664980C84B400492B06F270544402783A3E4D5C34B40B32616F88AFC43402783A3E4D5C34B40
6872	Черусти	1	10	794	39.972991	40.040266000000003	55.566414999999999	55.529964999999997	0103000020E61000000100000005000000B32616F88AFC43402783A3E4D5C34B40B32616F88AFC43405F7B664980C84B400492B06F270544405F7B664980C84B400492B06F270544402783A3E4D5C34B40B32616F88AFC43402783A3E4D5C34B40
59535	Центральной усадьбы совхоза "Мир"	1	10	794	39.681919000000001	39.705723999999996	55.554506000000003	55.542980999999997	0103000020E61000000100000005000000B1C22D1F49D74340B8ACC26680C54B40B1C22D1F49D74340C8B7770DFAC64B404B00FE2955DA4340C8B7770DFAC64B404B00FE2955DA4340B8ACC26680C54B40B1C22D1F49D74340B8ACC26680C54B40
7276	Туголесский Бор	1	10	794	39.77599	39.816972	55.569651999999998	55.550051000000003	0103000020E61000000100000005000000F302ECA353E34340E910381268C64B40F302ECA353E34340ED0C535BEAC84B40B5DFDA8992E84340ED0C535BEAC84B40B5DFDA8992E84340E910381268C64B40F302ECA353E34340E910381268C64B40
7410	Середниково	1	10	794	39.650640000000003	39.689554999999999	55.265557999999999	55.247923999999998	0103000020E6100000010000000500000017BCE82B48D343405EF23FF9BB9F4B4017BCE82B48D343407898F6CDFDA14B408AE5965643D843407898F6CDFDA14B408AE5965643D843405EF23FF9BB9F4B4017BCE82B48D343405EF23FF9BB9F4B40
6376	Северная Грива	1	10	794	39.577939000000001	39.601412000000003	55.714288000000003	55.704721999999997	0103000020E610000001000000050000009E0AB8E7F9C94340C7629B5434DA4B409E0AB8E7F9C943406FF607CA6DDB4B4003B68311FBCC43406FF607CA6DDB4B4003B68311FBCC4340C7629B5434DA4B409E0AB8E7F9C94340C7629B5434DA4B40
7846	Радовицкий	1	10	794	39.779888999999997	39.80903	55.137548000000002	55.120980000000003	0103000020E610000001000000050000004CC11A67D3E343402CBCCB457C8F4B404CC11A67D3E34340ABD0402C9B914B40CFBD874B8EE74340ABD0402C9B914B40CFBD874B8EE743402CBCCB457C8F4B404CC11A67D3E343402CBCCB457C8F4B40
7669	Пышлицы	1	10	794	40.062435999999998	40.079953000000003	55.293514999999999	55.282702999999998	0103000020E61000000100000005000000E90B21E7FD07444094BDA59C2FA44B40E90B21E7FD07444056F146E691A54B40CA1B60E63B0A444056F146E691A54B40CA1B60E63B0A444094BDA59C2FA44B40E90B21E7FD07444094BDA59C2FA44B40
6955	Пустоши	1	10	794	39.936995000000003	39.954853999999997	55.606389999999998	55.598613999999998	0103000020E61000000100000005000000FDC1C073EFF74340C07630629FCC4B40FDC1C073EFF743408B4F01309ECD4B40363AE7A738FA43408B4F01309ECD4B40363AE7A738FA4340C07630629FCC4B40FDC1C073EFF74340C07630629FCC4B40
7012	Пустоша	1	10	794	40.010683999999998	40.046042	55.601858999999997	55.584150999999999	0103000020E61000000100000005000000944BE3175E0144407D76C075C5CA4B40944BE3175E014440D1E638B709CD4B40081F4AB4E4054440D1E638B709CD4B40081F4AB4E40544407D76C075C5CA4B40944BE3175E0144407D76C075C5CA4B40
7335	Пестовская	1	10	794	39.826036000000002	39.838431999999997	55.361615	55.351579000000001	0103000020E61000000100000005000000CAA8328CBBE94340EE7A698A00AD4B40CAA8328CBBE943401C5F7B6649AE4B40BEF561BD51EB43401C5F7B6649AE4B40BEF561BD51EB4340EE7A698A00AD4B40CAA8328CBBE94340EE7A698A00AD4B40
7201	Осаново-Дубовое	1	10	794	39.651519999999998	39.672953999999997	55.483351999999996	55.472943999999998	0103000020E610000001000000050000004F58E20165D34340726BD26D89BC4B404F58E20165D34340643A747ADEBD4B402FDB4E5B23D64340643A747ADEBD4B402FDB4E5B23D64340726BD26D89BC4B404F58E20165D34340726BD26D89BC4B40
6436	Новосидориха	1	10	794	39.605274999999999	39.624606	55.563848999999998	55.557530999999997	0103000020E610000001000000050000000F0BB5A679CD4340CAC0012D5DC74B400F0BB5A679CD4340EF703B342CC84B405471E316F3CF4340EF703B342CC84B405471E316F3CF4340CAC0012D5DC74B400F0BB5A679CD4340CAC0012D5DC74B40
6609	Мишеронский	1	10	794	39.715722	39.759363	55.726446000000003	55.709986999999998	0103000020E610000001000000050000008C834BC79CDB4340E6CAA0DAE0DA4B408C834BC79CDB4340AF27BA2EFCDC4B406F6589CE32E14340AF27BA2EFCDC4B406F6589CE32E14340E6CAA0DAE0DA4B408C834BC79CDB4340E6CAA0DAE0DA4B40
7122	Лузгарино	1	10	794	39.70523	39.719405999999999	55.527799999999999	55.516094000000002	0103000020E610000001000000050000003C1405FA44DA4340B7D4415E0FC24B403C1405FA44DA4340166A4DF38EC34B40E945ED7E15DC4340166A4DF38EC34B40E945ED7E15DC4340B7D4415E0FC24B403C1405FA44DA4340B7D4415E0FC24B40
6597	Левошево	1	10	794	39.479115	39.500872000000001	55.584038999999997	55.574705999999999	0103000020E61000000100000005000000F302ECA353BD4340516859F78FC94B40F302ECA353BD4340554B3ACAC1CA4B40B6BDDD921CC04340554B3ACAC1CA4B40B6BDDD921CC04340516859F78FC94B40F302ECA353BD4340516859F78FC94B40
7037	Кривандино	1	10	794	39.655085999999997	39.702804999999998	55.569997999999998	55.548324000000001	0103000020E61000000100000005000000A208A9DBD9D3434053CE177B2FC64B40A208A9DBD9D343408864C8B1F5C84B408E3BA583F5D943408864C8B1F5C84B408E3BA583F5D9434053CE177B2FC64B40A208A9DBD9D3434053CE177B2FC64B40
7416	Дубровка	1	10	794	39.751564999999999	39.776268999999999	55.253461000000001	55.246974000000002	0103000020E61000000100000005000000BCE82B4833E043402D7B12D89C9F4B40BCE82B4833E04340DEE7F86871A04B4006F357C85CE34340DEE7F86871A04B4006F357C85CE343402D7B12D89C9F4B40BCE82B4833E043402D7B12D89C9F4B40
7285	Дмитровский Погост	1	10	794	39.808428999999997	39.841540000000002	55.329358999999997	55.309012000000003	0103000020E61000000100000005000000A911FA997AE74340290989B48DA74B40A911FA997AE7434056D28A6F28AA4B404F232D95B7EB434056D28A6F28AA4B404F232D95B7EB4340290989B48DA74B40A911FA997AE74340290989B48DA74B40
7546	Дерзсковская	1	10	794	39.896723999999999	39.918301999999997	55.237488999999997	55.228684999999999	0103000020E61000000100000005000000E7C41EDAC7F24340FA0AD28C459D4B40E7C41EDAC7F243407214200A669E4B40FAEC80EB8AF543407214200A669E4B40FAEC80EB8AF54340FA0AD28C459D4B40E7C41EDAC7F24340FA0AD28C459D4B40
7480	Губино	1	10	794	39.761581	39.774867999999998	55.352485000000001	55.347945000000003	0103000020E61000000100000005000000A320787C7BE1434043E7357689AC4B40A320787C7BE1434050AA7D3A1EAD4B40C45BE7DF2EE3434050AA7D3A1EAD4B40C45BE7DF2EE3434043E7357689AC4B40A320787C7BE1434043E7357689AC4B40
6830	Власово	1	10	794	39.744351999999999	39.760053999999997	55.670295000000003	55.643805	0103000020E61000000100000005000000295B24ED46DF43402A00C63368D24B40295B24ED46DF43400FD6FF39CCD54B40D498107349E143400FD6FF39CCD54B40D498107349E143402A00C63368D24B40295B24ED46DF43402A00C63368D24B40
6757	Бордуки	1	10	794	39.694935000000001	39.718741000000001	55.606816999999999	55.583748999999997	0103000020E6100000010000000500000042EC4CA1F3D843404E098849B8CA4B4042EC4CA1F3D8434013D4F02DACCD4B40ADA580B4FFDB434013D4F02DACCD4B40ADA580B4FFDB43404E098849B8CA4B4042EC4CA1F3D843404E098849B8CA4B40
6743	Бакшеево	1	10	794	39.855221999999998	39.887391000000001	55.719631999999997	55.704641000000002	0103000020E61000000100000005000000EC681CEA77ED4340DB3521AD31DA4B40EC681CEA77ED4340D993C0E61CDC4B40E3E13D0796F14340D993C0E61CDC4B40E3E13D0796F14340DB3521AD31DA4B40EC681CEA77ED4340DB3521AD31DA4B40
49697	Шарапово	1	10	565	37.245489999999997	37.267580000000002	55.199885999999999	55.181524000000003	0103000020E610000001000000050000005DBF60376C9F424035B8AD2D3C974B405DBF60376C9F4240D1764CDD95994B402788BA0F40A24240D1764CDD95994B402788BA0F40A2424035B8AD2D3C974B405DBF60376C9F424035B8AD2D3C974B40
3514	Чехов	1	10	565	37.408112000000003	37.496974000000002	55.175888999999998	55.120294999999999	0103000020E61000000100000005000000768D96033DB44240A86F99D3658F4B40768D96033DB44240F25CDF8783964B402D7B12D89CBF4240F25CDF8783964B402D7B12D89CBF4240A86F99D3658F4B40768D96033DB44240A86F99D3658F4B40
5021	Чепелево	1	10	565	37.475135000000002	37.507268000000003	55.194650000000003	55.173051000000001	0103000020E61000000100000005000000AD174339D1BC424022C5008926964B40AD174339D1BC42404D158C4AEA984B4057276728EEC042404D158C4AEA984B4057276728EEC0424022C5008926964B40AD174339D1BC424022C5008926964B40
45811	Талалихино	1	10	565	37.662514999999999	37.694315000000003	55.220540999999997	55.203195000000001	0103000020E61000000100000005000000020EA14ACDD44240F9DA334B029A4B40020EA14ACDD44240AC36FFAF3A9C4B40A60F5D50DFD84240AC36FFAF3A9C4B40A60F5D50DFD84240F9DA334B029A4B40020EA14ACDD44240F9DA334B029A4B40
5255	Стремилово	1	10	565	37.137754999999999	37.166213999999997	55.153441999999998	55.136400999999999	0103000020E6100000010000000500000024EEB1F4A19142402312859675914B4024EEB1F4A19142409AEAC9FCA3934B4094111780469542409AEAC9FCA3934B4094111780469542402312859675914B4024EEB1F4A19142402312859675914B40
4438	Столбовая	1	10	565	37.473905000000002	37.504860999999998	55.263111000000002	55.237074	0103000020E61000000100000005000000983446EBA8BC4240AF5DDA70589E4B40983446EBA8BC4240E31B0A9FADA14B404F0306499FC04240E31B0A9FADA14B404F0306499FC04240AF5DDA70589E4B40983446EBA8BC4240AF5DDA70589E4B40
59155	Новый Быт	1	10	565	37.592267	37.617688999999999	55.065066000000002	55.054743000000002	0103000020E6100000010000000500000001C0B167CFCB4240AC5791D101874B4001C0B167CFCB4240700A2B1554884B40AA0CE36E10CF4240700A2B1554884B40AA0CE36E10CF4240AC5791D101874B4001C0B167CFCB4240AC5791D101874B40
4863	Молоди	1	10	565	37.502704999999999	37.522908000000001	55.288065000000003	55.263582999999997	0103000020E6100000010000000500000091442FA358C042400A647616BDA14B4091442FA358C04240A60F5D50DFA44B408C683BA6EEC24240A60F5D50DFA44B408C683BA6EEC242400A647616BDA14B4091442FA358C042400A647616BDA14B40
4732	Мещерское	1	10	565	37.598564000000003	37.638683	55.289141999999998	55.269728000000001	0103000020E610000001000000050000000F48C2BE9DCC42406268757286A24B400F48C2BE9DCC424034F3E49A02A54B406EC1525DC0D1424034F3E49A02A54B406EC1525DC0D142406268757286A24B400F48C2BE9DCC42406268757286A24B40
5131	Манушкино	1	10	565	37.446182999999998	37.473562999999999	55.124006999999999	55.108173999999998	0103000020E61000000100000005000000FD8348861CB94240852348A5D88D4B40FD8348861CB94240CFBC1C76DF8F4B403ECC5EB69DBC4240CFBC1C76DF8F4B403ECC5EB69DBC4240852348A5D88D4B40FD8348861CB94240852348A5D88D4B40
61920	Любучаны	1	10	565	37.527894000000003	37.562730000000002	55.256247000000002	55.232351000000001	0103000020E6100000010000000500000098E0D40792C34240B11875ADBD9D4B4098E0D40792C342405C59A2B3CCA04B40323D618907C842405C59A2B3CCA04B40323D618907C84240B11875ADBD9D4B4098E0D40792C34240B11875ADBD9D4B40
59523	Дубна	1	10	565	37.334108999999998	37.350969999999997	55.125309000000001	55.119064000000002	0103000020E610000001000000050000004E266E15C4AA4240C310397D3D8F4B404E266E15C4AA42407E7214200A904B4045F0BF95ECAC42407E7214200A904B4045F0BF95ECAC4240C310397D3D8F4B404E266E15C4AA4240C310397D3D8F4B40
61972	Гришенки	1	10	565	37.421030000000002	37.438052999999996	55.105161000000003	55.089582999999998	0103000020E610000001000000050000004451A04FE4B5424087A3AB74778B4B404451A04FE4B5424047E867EA758D4B401475E61E12B8424047E867EA758D4B401475E61E12B8424087A3AB74778B4B404451A04FE4B5424087A3AB74778B4B40
45682	Васькино	1	10	565	37.579053000000002	37.614885999999998	55.140295999999999	55.125689999999999	0103000020E610000001000000050000004AD3A0681ECA424095B7239C16904B404AD3A0681ECA42403BE12538F5914B4056629E95B4CE42403BE12538F5914B4056629E95B4CE424095B7239C16904B404AD3A0681ECA424095B7239C16904B40
30746	Темпы	1	10	1865	37.284970999999999	37.308480000000003	56.647004000000003	56.624054000000001	0103000020E610000001000000050000007AA702EE79A4424010786000E14F4C407AA702EE79A44240CB30EE06D1524C402CBCCB457CA74240CB30EE06D1524C402CBCCB457CA7424010786000E14F4C407AA702EE79A4424010786000E14F4C40
29255	Талдом	1	10	1865	37.500773000000002	37.562766000000003	56.746070000000003	56.711373999999999	0103000020E6100000010000000500000023DC645419C04240C39CA04D0E5B4C4023DC645419C042406C43C5387F5F4C407FA65EB708C842406C43C5387F5F4C407FA65EB708C84240C39CA04D0E5B4C4023DC645419C04240C39CA04D0E5B4C40
60241	Северный	1	10	1865	37.611759999999997	37.632888999999999	56.733426999999999	56.720933000000002	0103000020E610000001000000050000001F80D4264ECE4240B8CD5488475C4C401F80D4264ECE42406F8099EFE05D4C40C37FBA8102D142406F8099EFE05D4C40C37FBA8102D14240B8CD5488475C4C401F80D4264ECE4240B8CD5488475C4C40
30377	Павловичи	1	10	1865	37.698421000000003	37.713962000000002	56.568708999999998	56.559131999999998	0103000020E6100000010000000500000079EBFCDB65D94240D3122BA391474C4079EBFCDB65D942406EF8DD74CB484C401B4B581B63DB42406EF8DD74CB484C401B4B581B63DB4240D3122BA391474C4079EBFCDB65D94240D3122BA391474C40
61976	Новоникольское	1	10	1865	37.521749	37.540182000000001	56.571913000000002	56.560853000000002	0103000020E6100000010000000500000040DCD5ABC8C24240876EF607CA474C4040DCD5ABC8C242402194F77134494C40A6F10BAF24C542402194F77134494C40A6F10BAF24C54240876EF607CA474C4040DCD5ABC8C24240876EF607CA474C40
30352	Новогуслево	1	10	1865	37.611148999999997	37.628397	56.557032999999997	56.548166999999999	0103000020E61000000100000005000000D6FD63213ACE42408BDF14562A464C40D6FD63213ACE424079E57ADB4C474C40C7F319506FD0424079E57ADB4C474C40C7F319506FD042408BDF14562A464C40D6FD63213ACE42408BDF14562A464C40
30465	Николо-Кропотки	1	10	1865	37.912813	37.942700000000002	56.741208	56.731299	0103000020E610000001000000050000008C2E6F0ED7F442407B4CA4349B5D4C408C2E6F0ED7F442404CC45BE7DF5E4C4038F8C264AAF842404CC45BE7DF5E4C4038F8C264AAF842407B4CA4349B5D4C408C2E6F0ED7F442407B4CA4349B5D4C40
30641	Кошелево	1	10	1865	37.737219000000003	37.751762999999997	56.850171000000003	56.844599000000002	0103000020E61000000100000005000000B37E33315DDE4240FE9DEDD11B6C4C40B37E33315DDE4240FA804067D26C4C40E2AB1DC539E04240FA804067D26C4C40E2AB1DC539E04240FE9DEDD11B6C4C40B37E33315DDE4240FE9DEDD11B6C4C40
30613	Квашенки	1	10	1865	37.544890000000002	37.567177000000001	56.817310999999997	56.798876999999997	0103000020E610000001000000050000006FF59CF4BEC542406743FE9941664C406FF59CF4BEC542409DD497A59D684C408E05854199C842409DD497A59D684C408E05854199C842406743FE9941664C406FF59CF4BEC542406743FE9941664C40
29869	Запрудня	1	10	1865	37.385159999999999	37.475611999999998	56.580857999999999	56.523488	0103000020E610000001000000050000001ADD41EC4CB142409AEC9FA701434C401ADD41EC4CB142405BCF108E594A4C40E6CAA0DAE0BC42405BCF108E594A4C40E6CAA0DAE0BC42409AEC9FA701434C401ADD41EC4CB142409AEC9FA701434C40
62054	Запрудня	1	10	1865	37.385159999999999	37.475611999999998	56.580857999999999	56.523488	0103000020E610000001000000050000001ADD41EC4CB142409AEC9FA701434C401ADD41EC4CB142405BCF108E594A4C40E6CAA0DAE0BC42405BCF108E594A4C40E6CAA0DAE0BC42409AEC9FA701434C401ADD41EC4CB142409AEC9FA701434C40
61966	Ермолино	1	10	1865	37.80603	37.831218999999997	56.817666000000003	56.801572999999998	0103000020E6100000010000000500000025CCB4FD2BE74240A52DAEF199664C4025CCB4FD2BE742408C868C47A9684C402B685A6265EA42408C868C47A9684C402B685A6265EA4240A52DAEF199664C4025CCB4FD2BE74240A52DAEF199664C40
29625	Вербилки	1	10	1865	37.554789	37.630293000000002	56.550821999999997	56.518746	0103000020E610000001000000050000001C97715303C742402577D84466424C401C97715303C742406AF5D55581464C40E9F2E670ADD042406AF5D55581464C40E9F2E670ADD042402577D84466424C401C97715303C742402577D84466424C40
47962	Великий Двор	1	10	1865	37.402731000000003	37.422511999999998	56.770632999999997	56.759591999999998	0103000020E61000000100000005000000EE0A7DB08CB34240D026874F3A614C40EE0A7DB08CB34240F31B261AA4624C4072158BDF14B64240F31B261AA4624C4072158BDF14B64240D026874F3A614C40EE0A7DB08CB34240D026874F3A614C40
28328	Шугарово	1	10	675	37.974032999999999	38.000416000000001	55.059120999999998	55.044592999999999	0103000020E61000000100000005000000C51C041DADFC4240B5503239B5854B40C51C041DADFC4240DFC0E44691874B409432A9A10D004340DFC0E44691874B409432A9A10D004340B5503239B5854B40C51C041DADFC4240B5503239B5854B40
29241	Хатунь	1	10	675	37.813189000000001	37.844189999999998	55.015082999999997	54.990664000000002	0103000020E61000000100000005000000C53BC09316E842408BA9F413CE7E4B40C53BC09316E84240DFDC5F3DEE814B401CCEFC6A0EEC4240DFDC5F3DEE814B401CCEFC6A0EEC42408BA9F413CE7E4B40C53BC09316E842408BA9F413CE7E4B40
28793	Усады	1	10	675	37.878632000000003	37.912641999999998	55.148637000000001	55.136164000000001	0103000020E610000001000000050000000B9C6C0377F042403F726BD26D914B400B9C6C0377F04240DFFC868906934B405F7AFB73D1F44240DFFC868906934B405F7AFB73D1F442403F726BD26D914B400B9C6C0377F042403F726BD26D914B40
28801	Татариново	1	10	675	37.928614000000003	37.946356000000002	55.221418999999997	55.209519	0103000020E61000000100000005000000CB4DD4D2DCF642400072C284D19A4B40CB4DD4D2DCF6424044DB3175579C4B40CB2F833122F9424044DB3175579C4B40CB2F833122F942400072C284D19A4B40CB4DD4D2DCF642400072C284D19A4B40
13685	Ступино	1	10	675	38.028892999999997	38.167225000000002	54.920506000000003	54.853205000000003	0103000020E61000000100000005000000AA0A0DC4B203434050E449D2356D4B40AA0A0DC4B2034340CAE2FE23D3754B406C09F9A067154340CAE2FE23D3754B406C09F9A06715434050E449D2356D4B40AA0A0DC4B203434050E449D2356D4B40
28219	Старая Ситня	1	10	675	38.130294999999997	38.153596999999998	54.959784999999997	54.934040000000003	0103000020E6100000010000000500000089EAAD81AD104340F3936A9F8E774B4089EAAD81AD1043407E18213CDA7A4B40C1E10511A91343407E18213CDA7A4B40C1E10511A9134340F3936A9F8E774B4089EAAD81AD104340F3936A9F8E774B40
28272	Ситне-Щелканово	1	10	675	37.949221000000001	37.975776000000003	54.984734000000003	54.964509	0103000020E6100000010000000500000095D6DF1280F942404DD9E907757B4B4095D6DF1280F9424030A182C30B7E4B40611C5C3AE6FC424030A182C30B7E4B40611C5C3AE6FC42404DD9E907757B4B4095D6DF1280F942404DD9E907757B4B40
29187	Семеновское	1	10	675	37.746713999999997	37.784390000000002	55.071061	55.053438	0103000020E6100000010000000500000090BB085394DF42408C2E6F0ED7864B4090BB085394DF4240B282DF8618894B409CA73AE466E44240B282DF8618894B409CA73AE466E442408C2E6F0ED7864B4090BB085394DF42408C2E6F0ED7864B40
28599	Михнево	1	10	675	37.915678	37.995781000000001	55.142890000000001	55.101385000000001	0103000020E6100000010000000500000056D5CBEF34F5424009A7052FFA8C4B4056D5CBEF34F54240757632384A924B40357D76C075FF4240757632384A924B40357D76C075FF424009A7052FFA8C4B4056D5CBEF34F5424009A7052FFA8C4B40
28975	Мещерино	1	10	675	38.348801000000002	38.371051999999999	55.204037999999997	55.189957999999997	0103000020E61000000100000005000000F3E7DB82A52C434089CE328B50984B40F3E7DB82A52C43401492CCEA1D9A4B40C58EC6A17E2F43401492CCEA1D9A4B40C58EC6A17E2F434089CE328B50984B40F3E7DB82A52C434089CE328B50984B40
60254	Малино	1	10	675	38.143248	38.212283999999997	55.127007999999996	55.089733000000003	0103000020E61000000100000005000000D49B51F3551243409D2FF65E7C8B4B40D49B51F355124340492A53CC41904B4066BB421F2C1B4340492A53CC41904B4066BB421F2C1B43409D2FF65E7C8B4B40D49B51F3551243409D2FF65E7C8B4B40
28185	Лужники	1	10	675	38.085315999999999	38.108843	54.848312999999997	54.839598000000002	0103000020E61000000100000005000000ABE97AA2EB0A4340BDE47FF2776B4B40ABE97AA2EB0A4340C5E23785956C4B4003B34291EE0D4340C5E23785956C4B4003B34291EE0D4340BDE47FF2776B4B40ABE97AA2EB0A4340BDE47FF2776B4B40
29110	Леонтьево	1	10	675	38.274473999999998	38.294685999999999	55.068525000000001	55.053128999999998	0103000020E6100000010000000500000018CDCAF6212343400EBC5AEECC864B4018CDCAF621234340ADFA5C6DC5884B40664B5645B8254340ADFA5C6DC5884B40664B5645B82543400EBC5AEECC864B4018CDCAF6212343400EBC5AEECC864B40
29131	Ивановское	1	10	675	37.824302000000003	37.857745999999999	55.083486999999998	55.070298000000001	0103000020E6100000010000000500000082035ABA82E94240B37C5D86FF884B4082035ABA82E942401152B7B3AF8A4B402D23F59ECAED42401152B7B3AF8A4B402D23F59ECAED4240B37C5D86FF884B4082035ABA82E94240B37C5D86FF884B40
28315	Жилево	1	10	675	38.007252999999999	38.037939000000001	54.991692	54.976664	0103000020E6100000010000000500000021E692AAED0043401C977153037D4B4021E692AAED00434038DA71C3EF7E4B40191F662FDB04434038DA71C3EF7E4B40191F662FDB0443401C977153037D4B4021E692AAED0043401C977153037D4B40
28529	Дубнево	1	10	675	38.101152999999996	38.131624000000002	55.111685999999999	55.097996000000002	0103000020E610000001000000050000003672DD94F20C4340C59107228B8C4B403672DD94F20C4340E5B512BA4B8E4B4032AF230ED9104340E5B512BA4B8E4B4032AF230ED9104340C59107228B8C4B403672DD94F20C4340C59107228B8C4B40
28143	Городище	1	10	675	38.215302000000001	38.236260000000001	54.891727000000003	54.876175000000003	0103000020E61000000100000005000000B76114048F1B434052499D8026704B40B76114048F1B4340E8FA3E1C24724B402EAD86C43D1E4340E8FA3E1C24724B402EAD86C43D1E434052499D8026704B40B76114048F1B434052499D8026704B40
28488	Березнецово	1	10	675	38.139223999999999	38.151729000000003	55.110455000000002	55.104768999999997	0103000020E61000000100000005000000BE688F17D21143403B511212698D4B40BE688F17D21143400057B263238E4B406A6D1ADB6B1343400057B263238E4B406A6D1ADB6B1343403B511212698D4B40BE688F17D21143403B511212698D4B40
29063	Алфимово	1	10	675	38.317422999999998	38.346060999999999	55.120942999999997	55.101942000000001	0103000020E61000000100000005000000C5FF1D51A12843405F0B7A6F0C8D4B40C5FF1D51A12843400ED76A0F7B8F4B40E5B512BA4B2C43400ED76A0F7B8F4B40E5B512BA4B2C43405F0B7A6F0C8D4B40C5FF1D51A12843405F0B7A6F0C8D4B40
28880	Аксиньино	1	10	675	38.277951000000002	38.297255999999997	55.154860999999997	55.141305000000003	0103000020E61000000100000005000000FC71FBE59323434072E1404816924B40FC71FBE5932343408236397CD2934B4017450F7C0C2643408236397CD2934B4017450F7C0C26434072E1404816924B40FC71FBE59323434072E1404816924B40
59507	сельское поселение Кривцовское	1	10	143	36.709896999999998	37.427757999999997	56.365741999999997	55.884878	0103000020E61000000100000005000000A643A7E7DD5A42409679ABAE43F14B40A643A7E7DD5A4240066344A2D02E4C401A4D2EC6C0B64240066344A2D02E4C401A4D2EC6C0B642409679ABAE43F14B40A643A7E7DD5A42409679ABAE43F14B40
49690	Черная Грязь	1	10	143	37.30274	37.324649999999998	55.981217999999998	55.967809000000003	0103000020E6100000010000000500000074982F2FC0A6424022E3512AE1FB4B4074982F2FC0A642408E1F2A8D98FD4B40BD5296218EA942408E1F2A8D98FD4B40BD5296218EA9424022E3512AE1FB4B4074982F2FC0A6424022E3512AE1FB4B40
49694	Чашниково	1	10	143	37.157105000000001	37.184728	56.038997000000002	56.024687	0103000020E61000000100000005000000E08442041C94424074D190F128034C40E08442041C94424031D28BDAFD044C40E753C72AA597424031D28BDAFD044C40E753C72AA597424074D190F128034C40E08442041C94424074D190F128034C40
62067	Тимоново	1	10	143	37.023372999999999	37.039192	56.230397000000004	56.219571999999999	0103000020E61000000100000005000000014EEFE2FD824240048F6FEF1A1C4C40014EEFE2FD8242405B0C1EA67D1D4C40E621533E048542405B0C1EA67D1D4C40E621533E04854240048F6FEF1A1C4C40014EEFE2FD824240048F6FEF1A1C4C40
60242	Солнечногорск-7	1	10	143	36.709896999999998	37.427757999999997	56.365741999999997	55.884878	0103000020E61000000100000005000000A643A7E7DD5A42409679ABAE43F14B40A643A7E7DD5A4240066344A2D02E4C401A4D2EC6C0B64240066344A2D02E4C401A4D2EC6C0B642409679ABAE43F14B40A643A7E7DD5A42409679ABAE43F14B40
11017	Солнечногорск	1	10	143	36.941724999999998	37.031340999999998	56.218722	56.160485999999999	0103000020E61000000100000005000000AD69DE718A784240A1BB24CE8A144C40AD69DE718A78424036751E15FF1B4C4010035DFB0284424036751E15FF1B4C4010035DFB02844240A1BB24CE8A144C40AD69DE718A784240A1BB24CE8A144C40
62058	Соколово	1	10	143	36.891553999999999	36.914226999999997	56.044125999999999	56.033831999999997	0103000020E610000001000000050000001A4F04711E72424075C7629B54044C401A4F04711E7242409F73B7EBA5054C40620FED63057542409F73B7EBA5054C40620FED630575424075C7629B54044C401A4F04711E72424075C7629B54044C40
60248	Смирновка	1	10	143	36.926732000000001	36.957365000000003	56.22777	56.217370000000003	0103000020E610000001000000050000000E1478279F764240D690B8C7D21B4C400E1478279F76424045813E91271D4C40E3AAB2EF8A7A424045813E91271D4C40E3AAB2EF8A7A4240D690B8C7D21B4C400E1478279F764240D690B8C7D21B4C40
26442	Середниково	1	10	143	37.221747999999998	37.228782000000002	55.935082000000001	55.930669999999999	0103000020E6100000010000000500000009FA0B3D629C424025AFCE3120F74B4009FA0B3D629C4240058A58C4B0F74B40EDF483BA489D4240058A58C4B0F74B40EDF483BA489D424025AFCE3120F74B4009FA0B3D629C424025AFCE3120F74B40
61909	Ржавки	1	10	143	37.216141999999998	37.267122000000001	56.022402999999997	55.993847000000002	0103000020E6100000010000000500000061A5828AAA9B4240261DE56036FF4B4061A5828AAA9B4240882AFC19DE024C406405BF0D31A24240882AFC19DE024C406405BF0D31A24240261DE56036FF4B4061A5828AAA9B4240261DE56036FF4B40
25094	Ржавки	1	10	143	37.216141999999998	37.267122000000001	56.022402999999997	55.993847000000002	0103000020E6100000010000000500000061A5828AAA9B4240261DE56036FF4B4061A5828AAA9B4240882AFC19DE024C406405BF0D31A24240882AFC19DE024C406405BF0D31A24240261DE56036FF4B4061A5828AAA9B4240261DE56036FF4B40
49692	Радумля	1	10	143	37.112206999999998	37.156224999999999	56.079718999999997	56.066654999999997	0103000020E61000000100000005000000EEB089CC5C8E4240B48EAA2688084C40EEB089CC5C8E424056EF703B340A4C40A7E8482EFF93424056EF703B340A4C40A7E8482EFF934240B48EAA2688084C40EEB089CC5C8E4240B48EAA2688084C40
60237	Поярково	1	10	143	37.312415000000001	37.345247999999998	56.014152000000003	56.003073999999998	0103000020E61000000100000005000000D2E3F736FDA74240E4BB94BA64004C40D2E3F736FDA74240259694BBCF014C403481221631AC4240259694BBCF014C403481221631AC4240E4BB94BA64004C40D2E3F736FDA74240E4BB94BA64004C40
24931	Поварово	1	10	143	37.039721999999998	37.083596	56.092801999999999	56.058869999999999	0103000020E610000001000000050000004277499C15854240965B5A0D89074C404277499C158542406F8099EFE00B4C40C8091346B38A42406F8099EFE00B4C40C8091346B38A4240965B5A0D89074C404277499C15854240965B5A0D89074C40
61965	Новая	1	10	143	36.904023000000002	36.926614999999998	56.085268999999997	56.074714999999998	0103000020E6100000010000000500000079EA9106B7734240A4C2D84290094C4079EA9106B77342406A2E3718EA0A4C40D47D00529B7642406A2E3718EA0A4C40D47D00529B764240A4C2D84290094C4079EA9106B7734240A4C2D84290094C40
45782	Никольское	1	10	143	37.186245999999997	37.199353000000002	56.067610000000002	56.059815	0103000020E610000001000000050000006281AFE8D6974240B6679604A8074C406281AFE8D6974240F870C971A7084C4004AE2B6684994240F870C971A7084C4004AE2B6684994240B6679604A8074C406281AFE8D6974240B6679604A8074C40
24762	Менделеево	1	10	143	37.217948	37.246901000000001	56.042703000000003	56.022554	0103000020E61000000100000005000000431D56B8E59B42406E32AA0CE3024C40431D56B8E59B42407638BA4A77054C40C32CB4739A9F42407638BA4A77054C40C32CB4739A9F42406E32AA0CE3024C40431D56B8E59B42406E32AA0CE3024C40
60223	Малеевка	1	10	143	36.709896999999998	37.427757999999997	56.365741999999997	55.884878	0103000020E61000000100000005000000A643A7E7DD5A42409679ABAE43F14B40A643A7E7DD5A4240066344A2D02E4C401A4D2EC6C0B64240066344A2D02E4C401A4D2EC6C0B642409679ABAE43F14B40A643A7E7DD5A42409679ABAE43F14B40
49693	Майдарово	1	10	143	37.148113000000002	37.157482000000002	56.099079000000003	56.087418999999997	0103000020E61000000100000005000000658EE55DF59242404606B98B300B4C40658EE55DF5924240365CE49EAE0C4C40B6DAC35E28944240365CE49EAE0C4C40B6DAC35E289442404606B98B300B4C40658EE55DF59242404606B98B300B4C40
24805	Льялово	1	10	143	37.211596999999998	37.239876000000002	56.057125999999997	56.045735000000001	0103000020E610000001000000050000004277499C159B42402BA4FCA4DA054C404277499C159B42402AE09EE74F074C40338CBB41B49E42402AE09EE74F074C40338CBB41B49E42402BA4FCA4DA054C404277499C159B42402BA4FCA4DA054C40
49695	Лыткино	1	10	143	36.985661	37.008693999999998	56.026829999999997	56.017367	0103000020E61000000100000005000000A9F8BF232A7E4240CB83F41439024C40A9F8BF232A7E42409D465A2A6F034C40F1D58EE21C8142409D465A2A6F034C40F1D58EE21C814240CB83F41439024C40A9F8BF232A7E4240CB83F41439024C40
59432	Лунево	1	10	143	37.333039999999997	37.364255999999997	56.003340999999999	55.989381000000002	0103000020E610000001000000050000004221020EA1AA424053245F09A4FE4B404221020EA1AA424033DE567A6D004C4096AFCBF09FAE424033DE567A6D004C4096AFCBF09FAE424053245F09A4FE4B404221020EA1AA424053245F09A4FE4B40
49691	Ложки	1	10	143	37.096037000000003	37.124541000000001	56.101027000000002	56.087277999999998	0103000020E610000001000000050000005D1ABFF04A8C424084D4EDEC2B0B4C405D1ABFF04A8C4240AA81E673EE0C4C406D01A1F5F08F4240AA81E673EE0C4C406D01A1F5F08F424084D4EDEC2B0B4C405D1ABFF04A8C424084D4EDEC2B0B4C40
59433	Кривцово	1	10	143	36.874729000000002	36.892173999999997	56.143819999999998	56.138964999999999	0103000020E6100000010000000500000070EEAF1EF76F4240F224E99AC9114C4070EEAF1EF76F42405F419AB168124C40B62BF4C1327242405F419AB168124C40B62BF4C132724240F224E99AC9114C4070EEAF1EF76F4240F224E99AC9114C40
26321	Замятино	1	10	143	36.810903000000003	36.820030000000003	56.201970000000003	56.187561000000002	0103000020E61000000100000005000000399D64ABCB674240A680B4FF01184C40399D64ABCB674240F6622827DA194C4094DE37BEF6684240F6622827DA194C4094DE37BEF6684240A680B4FF01184C40399D64ABCB674240A680B4FF01184C40
61969	Жуково	1	10	143	37.031951999999997	37.067318	56.121952999999998	56.103146000000002	0103000020E610000001000000050000005985CD00178442404B5B5CE3330D4C405985CD00178442401553E9279C0F4C40503750E09D8842401553E9279C0F4C40503750E09D8842404B5B5CE3330D4C405985CD00178442404B5B5CE3330D4C40
45346	Голубое	1	10	143	37.091591000000001	37.115028000000002	55.990338000000001	55.977924000000002	0103000020E61000000100000005000000D1CDFE40B98B42409CFC169D2CFD4B40D1CDFE40B98B424037FE4465C3FE4B40E90FCD3CB98E424037FE4465C3FE4B40E90FCD3CB98E42409CFC169D2CFD4B40D1CDFE40B98B42409CFC169D2CFD4B40
26383	Брехово	1	10	143	37.173265999999998	37.205784999999999	55.939978000000004	55.914988000000001	0103000020E610000001000000050000001EC18D942D964240C11DA8531EF54B401EC18D942D964240D17AF83251F84B40F180B229579A4240D17AF83251F84B40F180B229579A4240C11DA8531EF54B401EC18D942D964240C11DA8531EF54B40
62015	Благовещенка	1	10	143	37.224065000000003	37.236784999999998	55.915488000000003	55.907328999999997	0103000020E61000000100000005000000D1967329AE9C42402FDB4E5B23F44B40D1967329AE9C4240B3F0F5B52EF54B4078978BF84E9E4240B3F0F5B52EF54B4078978BF84E9E42402FDB4E5B23F44B40D1967329AE9C42402FDB4E5B23F44B40
1689	Андреевка	1	10	143	37.112602000000003	37.148688	55.992013999999998	55.970877000000002	0103000020E610000001000000050000006BBB09BE698E424024B891B245FC4B406BBB09BE698E42404A969350FAFE4B4061A75835089342404A969350FAFE4B4061A758350893424024B891B245FC4B406BBB09BE698E424024B891B245FC4B40
341	Алабушево	1	10	143	37.106808000000001	37.150511000000002	56.018388000000002	55.997663000000003	0103000020E61000000100000005000000C07971E2AB8D4240F2B6D26BB3FF4B40C07971E2AB8D4240C651B9895A024C401958C7F143934240C651B9895A024C401958C7F143934240F2B6D26BB3FF4B40C07971E2AB8D4240F2B6D26BB3FF4B40
61981	сельское поселение Данковское	1	10	532	37.081969999999998	37.898152000000003	55.062838999999997	54.718364000000001	0103000020E6100000010000000500000066A032FE7D8A4240D74FFF59F35B4B4066A032FE7D8A4240E8F4BC1B0B884B40236B0DA5F6F24240E8F4BC1B0B884B40236B0DA5F6F24240D74FFF59F35B4B4066A032FE7D8A4240D74FFF59F35B4B40
61963	кирпичного завода	1	10	532	37.421416000000001	37.443855999999997	54.865617	54.848007000000003	0103000020E610000001000000050000006D01A1F5F0B54240B9E34D7E8B6C4B406D01A1F5F0B542404AEEB089CC6E4B401211FE45D0B842404AEEB089CC6E4B401211FE45D0B84240B9E34D7E8B6C4B406D01A1F5F0B54240B9E34D7E8B6C4B40
61959	дома отдыха Авангард	1	10	532	37.441564999999997	37.465738999999999	54.969853000000001	54.958441000000001	0103000020E610000001000000050000007407B13385B84240A112D731AE7A4B407407B13385B84240B876A224247C4B4062BCE6559DBB4240B876A224247C4B4062BCE6559DBB4240A112D731AE7A4B407407B13385B84240A112D731AE7A4B40
22944	Шарапова Охота	1	10	532	37.464958000000003	37.486364000000002	55.043669999999999	55.0304	0103000020E61000000100000005000000BD0166BE83BB424032E6AE25E4834B40BD0166BE83BB42407DE882FA96854B40D3F9F02C41BE42407DE882FA96854B40D3F9F02C41BE424032E6AE25E4834B40BD0166BE83BB424032E6AE25E4834B40
62050	Фенино	1	10	532	37.468164999999999	37.491045	55.023155000000003	55.009791	0103000020E61000000100000005000000E010AAD4ECBB4240C765DCD440814B40E010AAD4ECBB424094DE37BEF6824B40A2EE0390DABE424094DE37BEF6824B40A2EE0390DABE4240C765DCD440814B40E010AAD4ECBB4240C765DCD440814B40
23154	Турово	1	10	532	37.806255	37.849643	54.885838999999997	54.867750999999998	0103000020E61000000100000005000000459E245D33E742402009FB76126F4B40459E245D33E74240BB421F2C63714B403E23111AC1EC4240BB421F2C63714B403E23111AC1EC42402009FB76126F4B40459E245D33E742402009FB76126F4B40
23497	Съяново-2	1	10	532	37.218819000000003	37.260393000000001	55.039816000000002	55.028646000000002	0103000020E61000000100000005000000295FD042029C4240A39410ACAA834B40295FD042029C4240C4EDD0B018854B40BD8DCD8E54A14240C4EDD0B018854B40BD8DCD8E54A14240A39410ACAA834B40295FD042029C4240A39410ACAA834B40
52786	Старые Кузьменки	1	10	532	37.401546000000003	37.415173000000003	55.046805999999997	55.030839	0103000020E6100000010000000500000079EBFCDB65B342407E384888F2834B4079EBFCDB65B34240D7A02FBDFD854B4053978C6324B54240D7A02FBDFD854B4053978C6324B542407E384888F2834B4079EBFCDB65B342407E384888F2834B40
60227	Рогово	1	10	532	37.558444999999999	37.572575999999998	54.765669000000003	54.754007000000001	0103000020E61000000100000005000000AFCE31207BC7424040FA264D83604B40AFCE31207BC74240D047197101624B40BC3C9D2B4AC94240D047197101624B40BC3C9D2B4AC9424040FA264D83604B40AFCE31207BC7424040FA264D83604B40
23411	Райсеменовское	1	10	532	37.325682999999998	37.348292999999998	55.015107999999998	54.998472999999997	0103000020E610000001000000050000007CEE04FBAFA94240317898F6CD7F4B407CEE04FBAFA9424038F4160FEF814B407E3672DD94AC424038F4160FEF814B407E3672DD94AC4240317898F6CD7F4B407CEE04FBAFA94240317898F6CD7F4B40
56686	Пущино	1	10	532	37.340136999999999	37.364669999999997	54.950437999999998	54.931339000000001	0103000020E610000001000000050000006C94F59B89AB4240A33EC91D36774B406C94F59B89AB42401570CFF3A7794B4089EAAD81ADAE42401570CFF3A7794B4089EAAD81ADAE4240A33EC91D36774B406C94F59B89AB4240A33EC91D36774B40
52829	Прончищево	1	10	532	37.719701999999998	37.738557	54.808762999999999	54.795893	0103000020E61000000100000005000000D26EF4311FDC4240C30E63D2DF654B40D26EF4311FDC4240809BC58B85674B40AE9D280989DE4240809BC58B85674B40AE9D280989DE4240C30E63D2DF654B40D26EF4311FDC4240C30E63D2DF654B40
24366	Пролетарский	1	10	532	37.366664	37.413026000000002	55.029172000000003	55.014293000000002	0103000020E610000001000000050000006E4F90D8EEAE4240E7C75F5AD4814B406E4F90D8EEAE4240BEFA78E8BB834B40E8323509DEB44240BEFA78E8BB834B40E8323509DEB44240E7C75F5AD4814B406E4F90D8EEAE4240E7C75F5AD4814B40
52838	Подмоклово	1	10	532	37.325386000000002	37.359037000000001	54.871549000000002	54.856698999999999	0103000020E61000000100000005000000C3499A3FA6A9424009C21550A86D4B40C3499A3FA6A9424046EEE9EA8E6F4B40E886A6ECF4AD424046EEE9EA8E6F4B40E886A6ECF4AD424009C21550A86D4B40C3499A3FA6A9424009C21550A86D4B40
15310	Оболенск	1	10	532	37.208407999999999	37.289282999999998	54.986148999999997	54.968355000000003	0103000020E61000000100000005000000C51C041DAD9A424084F57F0EF37B4B40C51C041DAD9A4240D6FD63213A7E4B40F624B03907A54240D6FD63213A7E4B40F624B03907A5424084F57F0EF37B4B40C51C041DAD9A424084F57F0EF37B4B40
52774	Нефедово	1	10	532	37.451186	37.474595999999998	54.951596000000002	54.939185999999999	0103000020E61000000100000005000000DF347D76C0B94240376E313F37784B40DF347D76C0B942409180D1E5CD794B40FD67CD8FBFBC42409180D1E5CD794B40FD67CD8FBFBC4240376E313F37784B40DF347D76C0B94240376E313F37784B40
56687	Лукьяново	1	10	532	37.419187999999998	37.439104	54.875973000000002	54.867606000000002	0103000020E610000001000000050000001570CFF3A7B542401DE8A1B60D6F4B401570CFF3A7B54240EA961DE21F704B407AC5538F34B84240EA961DE21F704B407AC5538F34B842401DE8A1B60D6F4B401570CFF3A7B542401DE8A1B60D6F4B40
23994	Липицы	1	10	532	37.465226999999999	37.498230999999997	54.857362000000002	54.837063000000001	0103000020E61000000100000005000000AC1BEF8E8CBB424088D860E1246B4B40AC1BEF8E8CBB4240A56ABB09BE6D4B403B6D8D08C6BF4240A56ABB09BE6D4B403B6D8D08C6BF424088D860E1246B4B40AC1BEF8E8CBB424088D860E1246B4B40
52816	Калиново	1	10	532	37.277757999999999	37.299416000000001	54.903474000000003	54.889366000000003	0103000020E61000000100000005000000E719FB928DA342405116BEBED6714B40E719FB928DA34240A6643909A5734B4017F3734353A64240A6643909A5734B4017F3734353A642405116BEBED6714B40E719FB928DA342405116BEBED6714B40
57915	Ивановское	1	10	532	37.427570000000003	37.451582000000002	54.950681000000003	54.938890999999998	0103000020E6100000010000000500000018601F9DBAB642401EC18D942D784B4018601F9DBAB64240DCF63DEAAF794B402CBB6070CDB94240DCF63DEAAF794B402CBB6070CDB942401EC18D942D784B4018601F9DBAB642401EC18D942D784B40
23699	Дракино	1	10	532	37.259576000000003	37.305065999999997	54.873517	54.85051	0103000020E61000000100000005000000CB694FC939A14240E275FD82DD6C4B40CB694FC939A1424001C0B167CF6F4B408E8F16670CA7424001C0B167CF6F4B408E8F16670CA74240E275FD82DD6C4B40CB694FC939A14240E275FD82DD6C4B40
23216	Данки	1	10	532	37.554698999999999	37.576546	54.921478999999998	54.908785000000002	0103000020E61000000100000005000000DC0F786000C74240350C1F1153744B40DC0F786000C74240B3791C06F3754B40DF516342CCC94240B3791C06F3754B40DF516342CCC94240350C1F1153744B40DC0F786000C74240350C1F1153744B40
61961	Глазово	1	10	532	37.356772999999997	37.374425000000002	54.958565	54.942143999999999	0103000020E61000000100000005000000438CD7BCAAAD4240B20FB22C98784B40438CD7BCAAAD42408D0B0742B27A4B4004E78C28EDAF42408D0B0742B27A4B4004E78C28EDAF4240B20FB22C98784B40438CD7BCAAAD4240B20FB22C98784B40
62052	Гавшино	1	10	532	37.324407000000001	37.349559999999997	54.961775000000003	54.951104999999998	0103000020E61000000100000005000000F7CB272B86A94240F20703CFBD794B40F7CB272B86A94240228E75711B7B4B40B0FECF61BEAC4240228E75711B7B4B40B0FECF61BEAC4240F20703CFBD794B40F7CB272B86A94240F20703CFBD794B40
52788	Васильевское	1	10	532	37.397942999999998	37.433650999999998	55.010317999999998	54.995142000000001	0103000020E610000001000000050000000856D5CBEFB24240227024D0607F4B400856D5CBEFB24240B247A81952814B4058703FE081B74240B247A81952814B4058703FE081B74240227024D0607F4B400856D5CBEFB24240227024D0607F4B40
52795	Бутурлино	1	10	532	37.472727999999996	37.504824999999997	54.935715000000002	54.922524000000003	0103000020E61000000100000005000000A5F3E15982BC424037E3344415764B40A5F3E15982BC424036B05582C5774B40029A081B9EC0424036B05582C5774B40029A081B9EC0424037E3344415764B40A5F3E15982BC424037E3344415764B40
52824	Большое Грызлово	1	10	532	37.611688000000001	37.646112000000002	54.810481000000003	54.793002000000001	0103000020E6100000010000000500000086ADD9CA4BCE4240D0D4EB1681654B4086ADD9CA4BCE4240C38366D7BD674B40CEC64ACCB3D24240C38366D7BD674B40CEC64ACCB3D24240D0D4EB1681654B4086ADD9CA4BCE4240D0D4EB1681654B40
3247	Большевик	1	10	532	37.343091999999999	37.373213	54.913457999999999	54.896070999999999	0103000020E6100000010000000500000076C24B70EAAB42406FF25B74B2724B4076C24B70EAAB424081221631EC744B4095B88E71C5AF424081221631EC744B4095B88E71C5AF42406FF25B74B2724B4076C24B70EAAB42406FF25B74B2724B40
52832	Большая Городня	1	10	532	37.572881000000002	37.587856000000002	54.757263999999999	54.745629999999998	0103000020E61000000100000005000000F9BF232A54C942404F75C8CD705F4B40F9BF232A54C942401538D906EE604B40F2608BDD3ECB42401538D906EE604B40F2608BDD3ECB42404F75C8CD705F4B40F9BF232A54C942404F75C8CD705F4B40
52827	Балково	1	10	532	37.660386000000003	37.682223999999998	54.841858000000002	54.830679000000003	0103000020E610000001000000050000003E5E488787D44240AC3C81B0536A4B403E5E488787D4424020F0C000C26B4B40ED45B41D53D7424020F0C000C26B4B40ED45B41D53D74240AC3C81B0536A4B403E5E488787D44240AC3C81B0536A4B40
52789	Арнеево	1	10	532	37.558284	37.587586999999999	54.975031000000001	54.965538000000002	0103000020E61000000100000005000000A6F0A0D975C74240CB85CABF967B4B40A6F0A0D975C7424008CBD8D0CD7C4B400247020D36CB424008CBD8D0CD7C4B400247020D36CB4240CB85CABF967B4B40A6F0A0D975C74240CB85CABF967B4B40
48300	Успенский	1	10	560	38.692298999999998	38.724252	54.443480999999998	54.423020999999999	0103000020E61000000100000005000000D906EE409D584340B742588D25364B40D906EE409D584340DDB243FCC3384B4003081F4AB45C4340DDB243FCC3384B4003081F4AB45C4340B742588D25364B40D906EE409D584340B742588D25364B40
46759	Узуново	1	10	560	38.596564999999998	38.62912	54.556837999999999	54.527312000000002	0103000020E610000001000000050000001878EE3D5C4C4340E964A9F57E434B401878EE3D5C4C4340C495B37746474B4038A1100187504340C495B37746474B4038A1100187504340E964A9F57E434B401878EE3D5C4C4340E964A9F57E434B40
59148	Серебряные Пруды	1	10	560	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
61914	Серебряные Пруды	1	10	560	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
5274	Подхожее	1	10	560	38.550328999999998	38.588048999999998	54.345556999999999	54.310141999999999	0103000020E610000001000000050000002B85402E71464340DA8EA9BBB2274B402B85402E71464340B2F336363B2C4B4006B98B30454B4340B2F336363B2C4B4006B98B30454B4340DA8EA9BBB2274B402B85402E71464340DA8EA9BBB2274B40
61977	Петрово	1	10	560	38.415312	38.442953000000003	54.521261000000003	54.512203999999997	0103000020E6100000010000000500000074D190F128354340B07092E68F414B4074D190F12835434013D731AEB8424B40225514AFB238434013D731AEB8424B40225514AFB2384340B07092E68F414B4074D190F128354340B07092E68F414B40
20808	Новоклемово	1	10	560	38.788831999999999	38.814667	54.540858	54.531095000000001	0103000020E61000000100000005000000E6046D72F8644340D908C4EBFA434B40E6046D72F8644340D6E3BED53A454B40B2101D0247684340D6E3BED53A454B40B2101D0247684340D908C4EBFA434B40E6046D72F8644340D908C4EBFA434B40
19341	Мягкое	1	10	560	38.617074000000002	38.650635000000001	54.498241	54.491197	0103000020E61000000100000005000000209BE447FC4E43405872158BDF3E4B40209BE447FC4E43405F43705CC63F4B400551F701485343405F43705CC63F4B400551F701485343405872158BDF3E4B40209BE447FC4E43405872158BDF3E4B40
3492	Мочилы	1	10	560	38.661828	38.693142999999999	54.340533999999998	54.322510000000001	0103000020E61000000100000005000000DEC9A7C7B65443400551F70148294B40DEC9A7C7B654434089963C9E962B4B40C539EAE8B858434089963C9E962B4B40C539EAE8B85843400551F70148294B40DEC9A7C7B65443400551F70148294B40
9815	Крутое	1	10	560	38.557471	38.577117000000001	54.633707999999999	54.620750999999998	0103000020E61000000100000005000000F5BBB0355B474340CAFACDC4744F4B40F5BBB0355B474340569BFF571D514B409A7B48F8DE494340569BFF571D514B409A7B48F8DE494340CAFACDC4744F4B40F5BBB0355B474340CAFACDC4744F4B40
20797	Дудино	1	10	560	38.653095999999998	38.684950999999998	54.483677	54.474983000000002	0103000020E61000000100000005000000FF9254A698534340F793313ECC3C4B40FF9254A698534340E869C020E93D4B40662E7079AC574340E869C020E93D4B40662E7079AC574340F793313ECC3C4B40FF9254A698534340F793313ECC3C4B40
20993	Дмитриевский	1	10	560	38.803590999999997	38.837628000000002	54.428311000000001	54.413893999999999	0103000020E61000000100000005000000122EE411DC6643405C01857AFA344B40122EE411DC6643402FC214E5D2364B40611BF164376B43402FC214E5D2364B40611BF164376B43405C01857AFA344B40122EE411DC6643405C01857AFA344B40
48067	Глубокое	1	10	560	38.524088999999996	38.553195000000002	54.550024000000001	54.533873999999997	0103000020E61000000100000005000000BF982D5915434340A417B5FB55444B40BF982D5915434340EF01BA2F67464B40C6A70018CF464340EF01BA2F67464B40C6A70018CF464340A417B5FB55444B40BF982D5915434340A417B5FB55444B40
59547	Шеметово	1	10	506	38.061816	38.099105000000002	56.531922999999999	56.511539999999997	0103000020E610000001000000050000004D2F3196E9074340444C89247A414C404D2F3196E9074340BF7E880D16444C405FEFFE78AF0C4340BF7E880D16444C405FEFFE78AF0C4340444C89247A414C404D2F3196E9074340444C89247A414C40
20283	Шабурново	1	10	506	37.916145	37.935783000000001	56.552582999999998	56.543666999999999	0103000020E610000001000000050000006CB2463D44F542400C7558E196454C406CB2463D44F54240ACA92C0ABB464C408E93C2BCC7F74240ACA92C0ABB464C408E93C2BCC7F742400C7558E196454C406CB2463D44F542400C7558E196454C40
3067	Хотьково	1	10	506	37.953505999999997	38.021895000000001	56.273789999999998	56.228861000000002	0103000020E6100000010000000500000017450F7C0CFA4240392A37514B1D4C4017450F7C0CFA424065FCFB8C0B234C4014799274CD02434065FCFB8C0B234C4014799274CD024340392A37514B1D4C4017450F7C0CFA4240392A37514B1D4C40
19783	Федорцово	1	10	506	38.135694000000001	38.152681000000001	56.679648	56.666888999999998	0103000020E61000000100000005000000B821C66B5E114340F487669E5C554C40B821C66B5E1143405A65A6B4FE564C403CDC0E0D8B1343405A65A6B4FE564C403CDC0E0D8B134340F487669E5C554C40B821C66B5E114340F487669E5C554C40
16195	Тураково	1	10	506	38.187669999999997	38.204647999999999	56.279896999999998	56.267811999999999	0103000020E610000001000000050000005C38109205184340F9BCE2A947224C405C38109205184340CF9F36AAD3234C408D98D9E7311A4340CF9F36AAD3234C408D98D9E7311A4340F9BCE2A947224C405C38109205184340F9BCE2A947224C40
19776	Торгашино	1	10	506	38.187491000000001	38.213937000000001	56.639386999999999	56.623187000000001	0103000020E61000000100000005000000ADA580B4FF1743406C257497C44F4C40ADA580B4FF174340683EE76ED7514C40C233A149621B4340683EE76ED7514C40C233A149621B43406C257497C44F4C40ADA580B4FF1743406C257497C44F4C40
48407	Судниково	1	10	506	37.918256	37.929637999999997	56.621523000000003	56.61289	0103000020E610000001000000050000008AADA06989F54240D105F52D734E4C408AADA06989F542401D5BCF108E4F4C40368FC360FEF642401D5BCF108E4F4C40368FC360FEF64240D105F52D734E4C408AADA06989F54240D105F52D734E4C40
59580	Скоропусковский	1	10	506	38.135899999999999	38.167898000000001	56.375084999999999	56.364804999999997	0103000020E6100000010000000500000061C3D32B65114340693524EEB12E4C4061C3D32B651143402E1C08C902304C402B8881AE7D1543402E1C08C902304C402B8881AE7D154340693524EEB12E4C4061C3D32B65114340693524EEB12E4C40
15436	Сергиев Посад	1	10	506	38.047946000000003	38.200777000000002	56.345668000000003	56.266376999999999	0103000020E61000000100000005000000ADFC3218230643400BB43BA418224C40ADFC3218230643400AA359D93E2C4C40FE648C0FB31943400AA359D93E2C4C40FE648C0FB31943400BB43BA418224C40ADFC3218230643400BB43BA418224C40
18176	Семенково	1	10	506	38.249861000000003	38.265321	56.430604000000002	56.418253	0103000020E61000000100000005000000DFC5FB71FB1F4340193A765089354C40DFC5FB71FB1F43406EC328081E374C4094F8DC09F62143406EC328081E374C4094F8DC09F6214340193A765089354C40DFC5FB71FB1F4340193A765089354C40
19172	Сватково	1	10	506	38.208080000000002	38.229773999999999	56.396273999999998	56.383119000000001	0103000020E61000000100000005000000D1798D5DA21A4340F5BC1B0B0A314C40D1798D5DA21A4340A7203F1BB9324C404DBC033C691D4340A7203F1BB9324C404DBC033C691D4340F5BC1B0B0A314C40D1798D5DA21A4340F5BC1B0B0A314C40
20114	Самотовино	1	10	506	37.806325999999999	37.826448999999997	56.649146999999999	56.642476000000002	0103000020E610000001000000050000000EF5BBB035E74240823B50A73C524C400EF5BBB035E74240F4A5B73F17534C40EC67B114C9E94240F4A5B73F17534C40EC67B114C9E94240823B50A73C524C400EF5BBB035E74240823B50A73C524C40
18540	Репихово	1	10	506	37.986268000000003	38.000138	56.229576000000002	56.214796999999997	0103000020E61000000100000005000000B18BA2073EFE4240B323D5777E1B4C40B18BA2073EFE424027F911BF621D4C4051BEA0850400434027F911BF621D4C4051BEA08504004340B323D5777E1B4C40B18BA2073EFE4240B323D5777E1B4C40
17824	Реммаш	1	10	506	38.049446000000003	38.105806999999999	56.463003	56.440387999999999	0103000020E6100000010000000500000082751C3F5406434082C64CA25E384C4082751C3F540643409679ABAE433B4C400C5872158B0D43409679ABAE433B4C400C5872158B0D434082C64CA25E384C4082751C3F5406434082C64CA25E384C40
30164	Поселок Северный	1	10	506	37.891505000000002	37.900666999999999	56.334032999999998	56.330165999999998	0103000020E61000000100000005000000399CF9D51CF24240252026E1422A4C40399CF9D51CF242407364E597C12A4C4010CB660E49F342407364E597C12A4C4010CB660E49F34240252026E1422A4C40399CF9D51CF24240252026E1422A4C40
61913	Пересвет	1	10	506	38.150669000000001	38.197695000000003	56.423720000000003	56.406480999999999	0103000020E61000000100000005000000B1C22D1F4913434002B9C49107344C40B1C22D1F49134340A054FB743C364C4097CADB114E194340A054FB743C364C4097CADB114E19434002B9C49107344C40B1C22D1F4913434002B9C49107344C40
61983	ОРГРЭС	1	10	506	37.741998000000002	38.447758999999998	56.795504999999999	56.168576000000002	0103000020E6100000010000000500000045D95BCAF9DE4240FC71FBE593154C4045D95BCAF9DE4240F9669B1BD3654C40ADBEBA2A50394340F9669B1BD3654C40ADBEBA2A50394340FC71FBE593154C4045D95BCAF9DE4240FC71FBE593154C40
17718	НИИРП	1	10	506	38.221294	38.234158000000001	56.325324000000002	56.317373000000003	0103000020E6100000010000000500000088669E5C531C434014D1AFAD9F284C4088669E5C531C43404D4D8237A4294C40630CACE3F81D43404D4D8237A4294C40630CACE3F81D434014D1AFAD9F284C4088669E5C531C434014D1AFAD9F284C40
18889	Муханово	1	10	506	38.303013999999997	38.338200999999998	56.515037	56.502310999999999	0103000020E61000000100000005000000751DAA29C9264340E5B512BA4B404C40751DAA29C92643406F9D7FBBEC414C40BC3C9D2B4A2B43406F9D7FBBEC414C40BC3C9D2B4A2B4340E5B512BA4B404C40751DAA29C9264340E5B512BA4B404C40
19649	Мостовик	1	10	506	37.920555999999998	37.945188000000002	56.311601000000003	56.298582000000003	0103000020E610000001000000050000007B116DC7D4F542404F965AEF37264C407B116DC7D4F542405133A48AE2274C402C499EEBFBF842405133A48AE2274C402C499EEBFBF842404F965AEF37264C407B116DC7D4F542404F965AEF37264C40
18621	Морозово	1	10	506	38.046877000000002	38.061484	56.251916999999999	56.242654000000002	0103000020E61000000100000005000000A1F7C610000643402E1F49490F1F4C40A1F7C610000643403927F6D03E204C40179D2CB5DE0743403927F6D03E204C40179D2CB5DE0743402E1F49490F1F4C40A1F7C610000643402E1F49490F1F4C40
17159	Мишутино	1	10	506	38.089393999999999	38.111258999999997	56.392367999999998	56.375050000000002	0103000020E61000000100000005000000B43A3943710B4340B22E6EA301304C40B43A3943710B43409BFF571D39324C405D3123BC3D0E43409BFF571D39324C405D3123BC3D0E4340B22E6EA301304C40B43A3943710B4340B22E6EA301304C40
20207	Марьино	1	10	506	37.841189999999997	37.860692	56.504710000000003	56.492617000000003	0103000020E6100000010000000500000072DC291DACEB4240113AE8120E3F4C4072DC291DACEB42406AFB57569A404C40E4F6CB272BEE42406AFB57569A404C40E4F6CB272BEE4240113AE8120E3F4C4072DC291DACEB4240113AE8120E3F4C40
59563	Лоза	1	10	506	38.20552	38.223495	56.265242000000001	56.252797000000001	0103000020E610000001000000050000004356B77A4E1A434072C3EFA65B204C404356B77A4E1A434048C32973F3214C40E6E8F17B9B1C434048C32973F3214C40E6E8F17B9B1C434072C3EFA65B204C404356B77A4E1A434072C3EFA65B204C40
16553	Лесхоз	1	10	506	38.152527999999997	38.174329999999998	56.354776999999999	56.342416	0103000020E61000000100000005000000B5DC99098613434046D09849D42B4C40B5DC990986134340BE2F2E55692D4C40185B087250164340BE2F2E55692D4C40185B08725016434046D09849D42B4C40B5DC99098613434046D09849D42B4C40
61979	Кузьмино	1	10	506	37.916083	37.943013999999998	56.599702000000001	56.589230000000001	0103000020E61000000100000005000000F6B52E3542F542403AE97DE36B4B4C40F6B52E3542F5424043ACFE08C34C4C40C7D5C8AEB4F8424043ACFE08C34C4C40C7D5C8AEB4F842403AE97DE36B4B4C40F6B52E3542F542403AE97DE36B4B4C40
16736	Краснозаводск	1	10	506	38.206471999999998	38.287993999999998	56.459446999999997	56.410519999999998	0103000020E6100000010000000500000015C5ABAC6D1A43404D2D5BEB8B344C4015C5ABAC6D1A4340669FC728CF3A4C40DCB8C5FCDC244340669FC728CF3A4C40DCB8C5FCDC2443404D2D5BEB8B344C4015C5ABAC6D1A43404D2D5BEB8B344C40
20012	Константиново	1	10	506	38.004890000000003	38.050426000000002	56.558571000000001	56.543776000000001	0103000020E61000000100000005000000EA094B3CA0004340C32CB4739A454C40EA094B3CA00043403CBF28417F474C401E6FF25B740643403CBF28417F474C401E6FF25B74064340C32CB4739A454C40EA094B3CA0004340C32CB4739A454C40
19477	Зубцово	1	10	506	38.137706000000001	38.155681000000001	56.202156000000002	56.194513999999998	0103000020E61000000100000005000000433BA759A01143409C4EB2D5E5184C40433BA759A01143405858703FE0194C40E6CDE15AED1343405858703FE0194C40E6CDE15AED1343409C4EB2D5E5184C40433BA759A01143409C4EB2D5E5184C40
19438	Заречный	1	10	506	38.0291	38.040202999999998	56.194372999999999	56.188994000000001	0103000020E6100000010000000500000024287E8CB9034340F39194F430184C4024287E8CB9034340DA1CE736E1184C40BD19355F25054340DA1CE736E1184C40BD19355F25054340F39194F430184C4024287E8CB9034340F39194F430184C40
18507	Жучки	1	10	506	37.934750000000001	37.948943	56.250537000000001	56.242114000000001	0103000020E61000000100000005000000CFF753E3A5F74240AEF36F97FD1E4C40CFF753E3A5F742400FB8AE9811204C405262D7F676F942400FB8AE9811204C405262D7F676F94240AEF36F97FD1E4C40CFF753E3A5F74240AEF36F97FD1E4C40
17656	Глинково	1	10	506	38.179054999999998	38.202843000000001	56.298971000000002	56.288910999999999	0103000020E61000000100000005000000B7973446EB164340323A2009FB244C40B7973446EB164340E9B985AE44264C407C9C69C2F6194340E9B985AE44264C407C9C69C2F6194340323A2009FB244C40B7973446EB164340323A2009FB244C40
52599	Васильевское	1	10	506	37.888666000000001	37.904881000000003	56.343783000000002	56.337836000000003	0103000020E610000001000000050000009888B7CEBFF14240ABB4C5353E2B4C409888B7CEBFF14240DCF5D214012C4C40CAE2FE23D3F34240DCF5D214012C4C40CAE2FE23D3F34240ABB4C5353E2B4C409888B7CEBFF14240ABB4C5353E2B4C40
19148	Бужаниново	1	10	506	38.285280999999998	38.315285000000003	56.399248	56.385581000000002	0103000020E61000000100000005000000C8957A1684244340C07ADCB75A314C40C8957A1684244340287FF78E1A334C40AEF545425B284340287FF78E1A334C40AEF545425B284340C07ADCB75A314C40C8957A1684244340C07ADCB75A314C40
17897	Ботово	1	10	506	38.371276999999999	38.383557000000003	56.272295	56.267676999999999	0103000020E61000000100000005000000E5603601862F434019726C3D43224C40E5603601862F4340A2EE0390DA224C407193516518314340A2EE0390DA224C40719351651831434019726C3D43224C40E5603601862F434019726C3D43224C40
59529	Богородское	1	10	506	38.161098000000003	38.198621000000003	56.506777	56.489238	0103000020E61000000100000005000000BBB9F8DB9E144340F0FACC599F3E4C40BBB9F8DB9E144340B8AE9811DE404C4040A6B5696C194340B8AE9811DE404C4040A6B5696C194340F0FACC599F3E4C40BBB9F8DB9E144340F0FACC599F3E4C40
59581	Березняки	1	10	506	38.232837000000004	38.259723999999999	56.347729000000001	56.336708000000002	0103000020E610000001000000050000003E26529ACD1D43409A266C3F192B4C403E26529ACD1D4340766F4562822C4C403FFED2A23E214340766F4562822C4C403FFED2A23E2143409A266C3F192B4C403E26529ACD1D43409A266C3F192B4C40
59543	санатория "имени Герцена"	1	10	792	36.588318999999998	36.614153999999999	55.612755999999997	55.595196000000001	0103000020E61000000100000005000000C64E78094E4B4240E25AED612FCC4B40C64E78094E4B4240C136E2C96ECE4B40925A28999C4E4240C136E2C96ECE4B40925A28999C4E4240E25AED612FCC4B40C64E78094E4B4240E25AED612FCC4B40
45676	Тучково	1	10	792	36.438830000000003	36.504900999999997	55.622604000000003	55.571775000000002	0103000020E610000001000000050000007940D9942B384240D0D556EC2FC94B407940D9942B384240ED2DE57CB1CF4B40DD5B9198A0404240ED2DE57CB1CF4B40DD5B9198A0404240D0D556EC2FC94B407940D9942B384240D0D556EC2FC94B40
48542	Сычево	1	10	792	36.216343999999999	36.234687999999998	55.967899000000003	55.953764999999997	0103000020E61000000100000005000000C9570229B11B4240E388B5F814FA4B40C9570229B11B4240626A4B1DE4FB4B40BF61A2410A1E4240626A4B1DE4FB4B40BF61A2410A1E4240E388B5F814FA4B40C9570229B11B4240E388B5F814FA4B40
15215	Сытьково	1	10	792	36.145009000000002	36.164332000000002	55.703443999999998	55.695093	0103000020E610000001000000050000001650A8A78F124240DA56B3CEF8D84B401650A8A78F124240A148F7730ADA4B40D8D7BAD408154240A148F7730ADA4B40D8D7BAD408154240DA56B3CEF8D84B401650A8A78F124240DA56B3CEF8D84B40
14993	Старониколаево	1	10	792	36.261287000000003	36.283197000000001	55.6233	55.615425999999999	0103000020E610000001000000050000005BEF37DA71214240D68D7747C6CE4B405BEF37DA7121424064CC5D4BC8CF4B40A4A99ECC3F24424064CC5D4BC8CF4B40A4A99ECC3F244240D68D7747C6CE4B405BEF37DA71214240D68D7747C6CE4B40
15084	Старая Руза	1	10	792	36.318016	36.339709999999997	55.653908000000001	55.635716000000002	0103000020E6100000010000000500000068CD8FBFB4284240A0C552245FD14B4068CD8FBFB4284240E04BE141B3D34B40E40F069E7B2B4240E04BE141B3D34B40E40F069E7B2B4240A0C552245FD14B4068CD8FBFB4284240A0C552245FD14B40
13943	Руза	1	10	792	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
61986	Орешки	1	10	792	36.345765	36.364279000000003	55.729649999999999	55.717548000000001	0103000020E61000000100000005000000FC8C0B07422C4240B5A7E49CD8DB4B40FC8C0B07422C424061C3D32B65DD4B404FCFBBB1A02E424061C3D32B65DD4B404FCFBBB1A02E4240B5A7E49CD8DB4B40FC8C0B07422C4240B5A7E49CD8DB4B40
14324	Нововолково	1	10	792	36.266111000000002	36.284401000000003	55.780304000000001	55.767797999999999	0103000020E610000001000000050000008D0DDDEC0F22424094F7713447E24B408D0DDDEC0F22424010786000E1E34B4090F980406724424010786000E1E34B4090F980406724424094F7713447E24B408D0DDDEC0F22424094F7713447E24B40
14939	Лыщиково	1	10	792	36.301045999999999	36.324376000000001	55.582452000000004	55.572929999999999	0103000020E61000000100000005000000BA4BE2AC88264240DA722EC555C94B40BA4BE2AC88264240B2BE81C98DCA4B40BCCD1B2785294240B2BE81C98DCA4B40BCCD1B2785294240DA722EC555C94B40BA4BE2AC88264240DA722EC555C94B40
14801	Космодемьянский	1	10	792	36.356158000000001	36.366515999999997	55.478087000000002	55.469631999999997	0103000020E61000000100000005000000B91AD995962D4240D993C0E61CBC4B40B91AD995962D424046D26EF431BD4B40F9BA0CFFE92E424046D26EF431BD4B40F9BA0CFFE92E4240D993C0E61CBC4B40B91AD995962D4240D993C0E61CBC4B40
15268	Колюбакино	1	10	792	36.511046	36.546914999999998	55.678057000000003	55.656128000000002	0103000020E61000000100000005000000356090F469414240B5FE9600FCD34B40356090F46941424075E95F92CAD64B408E588B4F0146424075E95F92CAD64B408E588B4F01464240B5FE9600FCD34B40356090F469414240B5FE9600FCD34B40
45766	Ивойлово	1	10	792	36.260433999999997	36.284211999999997	55.924864999999997	55.912258999999999	0103000020E610000001000000050000001B62BCE655214240A73D25E7C4F44B401B62BCE655214240861BF0F961F64B40BC900E0F61244240861BF0F961F64B40BC900E0F61244240A73D25E7C4F44B401B62BCE655214240A73D25E7C4F44B40
14842	Дорохово	1	10	792	36.351083000000003	36.397112	55.568548	55.535488000000001	0103000020E610000001000000050000003E97A949F02C424042B3EBDE8AC44B403E97A949F02C4240651A4D2EC6C84B40B16CE690D4324240651A4D2EC6C84B40B16CE690D432424042B3EBDE8AC44B403E97A949F02C424042B3EBDE8AC44B40
15175	Воробьево	1	10	792	36.26294	36.278767999999999	55.667634999999997	55.657798999999997	0103000020E61000000100000005000000B6679604A8214240B62BF4C132D44B40B6679604A82142401D554D1075D54B40EE9579ABAE2342401D554D1075D54B40EE9579ABAE234240B62BF4C132D44B40B6679604A8214240B62BF4C132D44B40
14522	Брикет	1	10	792	36.433359000000003	36.443277000000002	55.912666999999999	55.903039999999997	0103000020E61000000100000005000000B136C64E783742406B7D91D096F34B40B136C64E78374240B891B245D2F44B40D508FD4CBD384240B891B245D2F44B40D508FD4CBD3842406B7D91D096F34B40B136C64E783742406B7D91D096F34B40
14646	Беляная Гора	1	10	792	36.090561999999998	36.100740000000002	55.799278999999999	55.789248999999998	0103000020E6100000010000000500000053211E89970B42404AB3791C06E54B4053211E89970B424096B036C64EE64B4014B35E0CE50C424096B036C64EE64B4014B35E0CE50C42404AB3791C06E54B4053211E89970B42404AB3791C06E54B40
12029	Юрово	1	10	443	38.363335999999997	38.385362000000001	55.513688000000002	55.494522000000003	0103000020E61000000100000005000000CFBA46CB812E43408693347F4CBF4B40CFBA46CB812E4340802C4487C0C14B40828FC18A53314340802C4487C0C14B40828FC18A533143408693347F4CBF4B40CFBA46CB812E43408693347F4CBF4B40
12448	Электроизолятор	1	10	443	38.489719999999998	38.517342999999997	55.591420999999997	55.583958000000003	0103000020E610000001000000050000003B191C25AF3E4340691EC022BFCA4B403B191C25AF3E43407495EEAEB3CB4B4042E8A04B384243407495EEAEB3CB4B4042E8A04B38424340691EC022BFCA4B403B191C25AF3E4340691EC022BFCA4B40
9244	Хрипань	1	10	443	38.136924	38.179909000000002	55.643337000000002	55.611840999999998	0103000020E61000000100000005000000CD04C3B9861143400CAD4ECE50CE4B40CD04C3B98611434044A7E7DD58D24B40C7A013420717434044A7E7DD58D24B40C7A01342071743400CAD4ECE50CE4B40CD04C3B9861143400CAD4ECE50CE4B40
12118	Фенино	1	10	443	38.389584999999997	38.415824000000001	55.587397000000003	55.571693000000003	0103000020E610000001000000050000008E01D9EBDD314340132D793C2DC94B408E01D9EBDD3143405F622CD32FCB4B402A7288B8393543405F622CD32FCB4B402A7288B839354340132D793C2DC94B408E01D9EBDD314340132D793C2DC94B40
11317	Ульянино	1	10	443	38.412329999999997	38.444066999999997	55.356836000000001	55.342053	0103000020E610000001000000050000007094BC3AC7344340D53F8864C8AB4B407094BC3AC73443408A0453CDACAD4B40CD1DFD2FD73843408A0453CDACAD4B40CD1DFD2FD7384340D53F8864C8AB4B407094BC3AC7344340D53F8864C8AB4B40
9807	Удельная	1	10	443	38.016460000000002	38.06673	55.646213000000003	55.621789999999997	0103000020E6100000010000000500000099D87C5C1B0243406B7D91D096CF4B4099D87C5C1B02434002A08A1BB7D24B40BFD4CF9B8A08434002A08A1BB7D24B40BFD4CF9B8A0843406B7D91D096CF4B4099D87C5C1B0243406B7D91D096CF4B40
10867	Тимонино	1	10	443	38.173180000000002	38.202699000000003	55.489742999999997	55.469096	0103000020E61000000100000005000000202922C32A1643409B5775560BBC4B40202922C32A164340F3380CE6AFBE4B4049F7730AF2194340F3380CE6AFBE4B4049F7730AF21943409B5775560BBC4B40202922C32A1643409B5775560BBC4B40
10697	Тельмана	1	10	443	38.032800999999999	38.050713000000002	55.566246999999997	55.556431000000003	0103000020E610000001000000050000005723BBD23204434084BD892139C74B405723BBD232044340A33A1DC87AC84B40B43D7AC37D064340A33A1DC87AC84B40B43D7AC37D06434084BD892139C74B405723BBD23204434084BD892139C74B40
9695	Строкино	1	10	443	38.177528000000002	38.191668	55.679473000000002	55.671300000000002	0103000020E61000000100000005000000E90FCD3CB916434004E78C28EDD54B40E90FCD3CB9164340ECC1A4F8F8D64B4049D8B79388184340ECC1A4F8F8D64B4049D8B7938818434004E78C28EDD54B40E90FCD3CB916434004E78C28EDD54B40
10818	Софьино	1	10	443	38.160739	38.191515000000003	55.510854000000002	55.487279999999998	0103000020E610000001000000050000008B1876189314434058FFE7305FBE4B408B18761893144340F183F3A963C14B40C3D8429083184340F183F3A963C14B40C3D842908318434058FFE7305FBE4B408B1876189314434058FFE7305FBE4B40
59554	Совхоза Раменское	1	10	443	38.292180000000002	38.304783999999998	55.547260000000001	55.537647999999997	0103000020E61000000100000005000000CC457C2766254340416150A6D1C44B40CC457C276625434059349D9D0CC64B400A2C80290327434059349D9D0CC64B400A2C802903274340416150A6D1C44B40CC457C2766254340416150A6D1C44B40
11065	Рылеево	1	10	443	38.088379000000003	38.121599000000003	55.350714000000004	55.331572000000001	0103000020E610000001000000050000009C53C900500B4340792288F370AA4B409C53C900500B4340EB1F4432E4AC4B40F81C588E900F4340EB1F4432E4AC4B40F81C588E900F4340792288F370AA4B409C53C900500B4340792288F370AA4B40
11457	Рыболово	1	10	443	38.353194000000002	38.400993	55.406072999999999	55.392116999999999	0103000020E610000001000000050000005C920376352D4340529ACDE330B24B405C920376352D4340F1643733FAB34B40647616BD53334340F1643733FAB34B40647616BD53334340529ACDE330B24B405C920376352D4340529ACDE330B24B40
11828	Рыбаки	1	10	443	38.223889999999997	38.243977000000001	55.486632	55.473643000000003	0103000020E6100000010000000500000062F3716DA81C43405B7D7555A0BC4B4062F3716DA81C4340F29716F549BE4B40F4FC69A33A1F4340F29716F549BE4B40F4FC69A33A1F43405B7D7555A0BC4B4062F3716DA81C43405B7D7555A0BC4B40
9648	Родники	1	10	443	38.041936999999997	38.100228000000001	55.656773000000001	55.643942000000003	0103000020E6100000010000000500000005BF0D315E054340AB4203B16CD24B4005BF0D315E054340AAF23D2311D44B405E126745D40C4340AAF23D2311D44B405E126745D40C4340AB4203B16CD24B4005BF0D315E054340AB4203B16CD24B40
61910	Родники	1	10	443	38.041936999999997	38.100228000000001	55.656773000000001	55.643942000000003	0103000020E6100000010000000500000005BF0D315E054340AB4203B16CD24B4005BF0D315E054340AAF23D2311D44B405E126745D40C4340AAF23D2311D44B405E126745D40C4340AB4203B16CD24B4005BF0D315E054340AB4203B16CD24B40
12365	Речицы	1	10	443	38.437778999999999	38.489108999999999	55.607416999999998	55.590311999999997	0103000020E6100000010000000500000013F06B2409384340DA37F7578FCB4B4013F06B240938434068041BD7BFCD4B40F296AB1F9B3E434068041BD7BFCD4B40F296AB1F9B3E4340DA37F7578FCB4B4013F06B2409384340DA37F7578FCB4B40
8168	Раменское	1	10	443	38.163891999999997	38.288882999999998	55.596584999999997	55.542797999999998	0103000020E61000000100000005000000BB09BE69FA144340C72AA5677AC54B40BB09BE69FA1443405F24B4E55CCC4B4068AF3E1EFA2443405F24B4E55CCC4B4068AF3E1EFA244340C72AA5677AC54B40BB09BE69FA144340C72AA5677AC54B40
61964	РАОС	1	10	443	37.905850999999998	38.645837999999998	55.709555999999999	55.239927999999999	0103000020E610000001000000050000004206F2ECF2F3424085B2F0F5B59E4B404206F2ECF2F342401D5723BBD2DA4B40CC41D0D1AA5243401D5723BBD2DA4B40CC41D0D1AA52434085B2F0F5B59E4B404206F2ECF2F3424085B2F0F5B59E4B40
48034	Починки	1	10	443	38.109561999999997	38.141272000000001	55.372374999999998	55.361773999999997	0103000020E610000001000000050000003271AB20060E43408445459C4EAE4B403271AB20060E43408B6CE7FBA9AF4B4096EB6D33151243408B6CE7FBA9AF4B4096EB6D33151243408445459C4EAE4B403271AB20060E43408445459C4EAE4B40
12067	Пласкинино	1	10	443	38.411000000000001	38.443860999999998	55.546154000000001	55.533791999999998	0103000020E61000000100000005000000F853E3A59B344340E76ED74B53C44B40F853E3A59B344340304AD05FE8C54B40247CEF6FD0384340304AD05FE8C54B40247CEF6FD0384340E76ED74B53C44B40F853E3A59B344340E76ED74B53C44B40
47785	Петровское	1	10	443	38.325749999999999	38.362051000000001	55.472602000000002	55.459148999999996	0103000020E6100000010000000500000004560E2DB2294340DC7EF964C5BA4B4004560E2DB22943401903EB387EBC4B40F73DEAAF572E43401903EB387EBC4B40F73DEAAF572E4340DC7EF964C5BA4B4004560E2DB2294340DC7EF964C5BA4B40
11015	Панино	1	10	443	38.176926000000002	38.193060000000003	55.394142000000002	55.382973	0103000020E61000000100000005000000F3E7DB82A516434021205F4205B14B40F3E7DB82A516434072FDBB3E73B24B403815A930B618434072FDBB3E73B24B403815A930B618434021205F4205B14B40F3E7DB82A516434021205F4205B14B40
10584	Островцы	1	10	443	37.962867000000003	38.013469000000001	55.603700000000003	55.579631999999997	0103000020E61000000100000005000000E6B2D1393FFB424087DBA16131CA4B40E6B2D1393FFB4240304CA60A46CD4B404241295AB9014340304CA60A46CD4B404241295AB901434087DBA16131CA4B40E6B2D1393FFB424087DBA16131CA4B40
61974	Опытное поле	1	10	443	37.905850999999998	38.645837999999998	55.709555999999999	55.239927999999999	0103000020E610000001000000050000004206F2ECF2F3424085B2F0F5B59E4B404206F2ECF2F342401D5723BBD2DA4B40CC41D0D1AA5243401D5723BBD2DA4B40CC41D0D1AA52434085B2F0F5B59E4B404206F2ECF2F3424085B2F0F5B59E4B40
11666	Новое	1	10	443	38.182074	38.207738999999997	55.562367999999999	55.549613000000001	0103000020E61000000100000005000000D8B969334E1743406D3A02B859C64B40D8B969334E1743409128B4ACFBC74B40478D0931971A43409128B4ACFBC74B40478D0931971A43406D3A02B859C64B40D8B969334E1743406D3A02B859C64B40
11518	Никулино	1	10	443	38.354308000000003	38.374339999999997	55.42615	55.414479999999998	0103000020E61000000100000005000000085BECF6592D43404C6C3EAE0DB54B40085BECF6592D43405F984C158CB64B40D5CA845FEA2F43405F984C158CB64B40D5CA845FEA2F43404C6C3EAE0DB54B40085BECF6592D43404C6C3EAE0DB54B40
11137	Никоновское	1	10	443	38.141506	38.173917000000003	55.289397999999998	55.275021000000002	0103000020E6100000010000000500000009185DDE1C1243404B5B5CE333A34B4009185DDE1C1243408FC360FE0AA54B40F69B89E9421643408FC360FE0AA54B40F69B89E9421643404B5B5CE333A34B4009185DDE1C1243404B5B5CE333A34B40
11278	Никитское	1	10	443	38.449097999999999	38.481617	55.309913999999999	55.289352000000001	0103000020E610000001000000050000007959130B7C3943401F84807C09A54B407959130B7C39434049490F43ABA74B404C1938A0A53D434049490F43ABA74B404C1938A0A53D43401F84807C09A54B407959130B7C3943401F84807C09A54B40
10676	Нижнее Мячково	1	10	443	37.962085000000002	37.990436000000003	55.546613000000001	55.533831999999997	0103000020E61000000100000005000000707CED9925FB424075C7629B54C44B40707CED9925FB4240C3482F6AF7C54B40FA635A9BC6FE4240C3482F6AF7C54B40FA635A9BC6FE424075C7629B54C44B40707CED9925FB424075C7629B54C44B40
11401	Морозово	1	10	443	38.339494000000002	38.368636000000002	55.393349000000001	55.380001999999998	0103000020E610000001000000050000001898158A742B43401135D1E7A3B04B401898158A742B43400875914259B24B406B10E6762F2F43400875914259B24B406B10E6762F2F43401135D1E7A3B04B401898158A742B43401135D1E7A3B04B40
12203	Минино	1	10	443	38.385326999999997	38.420189999999998	55.653379999999999	55.637524999999997	0103000020E6100000010000000500000005A2276552314340F2B0506B9AD14B4005A227655231434024EEB1F4A1D34B40990D32C9C835434024EEB1F4A1D34B40990D32C9C8354340F2B0506B9AD14B4005A2276552314340F2B0506B9AD14B40
12585	Кузяевского фарфорового завода	1	10	443	38.522615999999999	38.551515000000002	55.622283000000003	55.606019000000003	0103000020E61000000100000005000000E42EC214E542434098E0D40792CD4B40E42EC214E5424340ABED26F8A6CF4B407120240B98464340ABED26F8A6CF4B407120240B9846434098E0D40792CD4B40E42EC214E542434098E0D40792CD4B40
11598	Кузнецово	1	10	443	38.322400000000002	38.355097999999998	55.509742000000003	55.490116	0103000020E610000001000000050000007E1D386744294340889FFF1EBCBE4B407E1D386744294340E6B2D1393FC14B400070ECD9732D4340E6B2D1393FC14B400070ECD9732D4340889FFF1EBCBE4B407E1D386744294340889FFF1EBCBE4B40
9286	Кратово	1	10	443	38.121087000000003	38.204746999999998	55.623086999999998	55.571820000000002	0103000020E61000000100000005000000427C60C77F0F43407099D36531C94B40427C60C77F0F434008C89750C1CF4B40207A5226351A434008C89750C1CF4B40207A5226351A43407099D36531C94B40427C60C77F0F43407099D36531C94B40
61905	Кратово	1	10	443	38.121087000000003	38.204746999999998	55.623086999999998	55.571820000000002	0103000020E61000000100000005000000427C60C77F0F43407099D36531C94B40427C60C77F0F434008C89750C1CF4B40207A5226351A434008C89750C1CF4B40207A5226351A43407099D36531C94B40427C60C77F0F43407099D36531C94B40
10884	Константиново	1	10	443	37.958329999999997	38.005501000000002	55.496333	55.480342	0103000020E610000001000000050000004963B48EAAFA42409772BED87BBD4B404963B48EAAFA42407976F9D687BF4B40338CBB41B40043407976F9D687BF4B40338CBB41B40043409772BED87BBD4B404963B48EAAFA42409772BED87BBD4B40
11203	Клишева	1	10	443	38.224150999999999	38.266668000000003	55.558086000000003	55.540159000000003	0103000020E61000000100000005000000CF2EDFFAB01C4340EED11BEE23C54B40CF2EDFFAB01C4340802DAF5C6FC74B40E371512D22224340802DAF5C6FC74B40E371512D22224340EED11BEE23C54B40CF2EDFFAB01C4340EED11BEE23C54B40
61872	Ильинский	1	10	443	38.079109000000003	38.140391999999999	55.642950999999996	55.608021999999998	0103000020E61000000100000005000000DEE8633E200A4340CF9F36AAD3CD4B40DEE8633E200A43401AF7E6374CD24B405D4F745DF81143401AF7E6374CD24B405D4F745DF8114340CF9F36AAD3CD4B40DEE8633E200A4340CF9F36AAD3CD4B40
9407	Ильинский	1	10	443	38.079109000000003	38.140391999999999	55.642950999999996	55.608021999999998	0103000020E61000000100000005000000DEE8633E200A4340CF9F36AAD3CD4B40DEE8633E200A43401AF7E6374CD24B405D4F745DF81143401AF7E6374CD24B405D4F745DF8114340CF9F36AAD3CD4B40DEE8633E200A4340CF9F36AAD3CD4B40
15908	Захарово	1	10	443	38.297310000000003	38.326891000000003	55.665325000000003	55.647640000000003	0103000020E610000001000000050000000B630B410E2643406DCA15DEE5D24B400B630B410E264340091B9E5E29D54B40AA2D7590D7294340091B9E5E29D54B40AA2D7590D72943406DCA15DEE5D24B400B630B410E2643406DCA15DEE5D24B40
11146	Заворово	1	10	443	38.217818000000001	38.240544999999997	55.349536999999998	55.338755999999997	0103000020E61000000100000005000000753DD175E11B434071A94A5B5CAB4B40753DD175E11B4340F8DEDFA0BDAC4B40B01BB62DCA1E4340F8DEDFA0BDAC4B40B01BB62DCA1E434071A94A5B5CAB4B40753DD175E11B434071A94A5B5CAB4B40
11749	Заболотье	1	10	443	38.187544000000003	38.207127999999997	55.552754999999998	55.539110000000001	0103000020E61000000100000005000000D0471971011843402979758E01C54B40D047197101184340A9D903ADC0C64B40FE0A992B831A4340A9D903ADC0C64B40FE0A992B831A43402979758E01C54B40D0471971011843402979758E01C54B40
61876	Жуковский	1	10	443	37.905850999999998	38.645837999999998	55.709555999999999	55.239927999999999	0103000020E610000001000000050000004206F2ECF2F3424085B2F0F5B59E4B404206F2ECF2F342401D5723BBD2DA4B40CC41D0D1AA5243401D5723BBD2DA4B40CC41D0D1AA52434085B2F0F5B59E4B404206F2ECF2F3424085B2F0F5B59E4B40
11852	Дубовая Роща	1	10	443	38.306004999999999	38.314027000000003	55.545440999999997	55.53857	0103000020E61000000100000005000000CCB4FD2B2B274340A94D9CDCEFC44B40CCB4FD2B2B274340E272BC02D1C54B40CF87670932284340E272BC02D1C54B40CF87670932284340A94D9CDCEFC44B40CCB4FD2B2B274340A94D9CDCEFC44B40
11649	Дружба	1	10	443	38.323405999999999	38.34545	55.514288999999998	55.504067999999997	0103000020E6100000010000000500000043AA285E65294340E57ADB4C85C04B4043AA285E65294340A5D8D138D4C14B409C33A2B4372C4340A5D8D138D4C14B409C33A2B4372C4340E57ADB4C85C04B4043AA285E65294340E57ADB4C85C04B40
9127	Дергаево	1	10	443	38.236808000000003	38.272309	55.591152000000001	55.570664999999998	0103000020E6100000010000000500000031B77BB94F1E434065FCFB8C0BC94B4031B77BB94F1E4340857B65DEAACB4B4007B47405DB224340857B65DEAACB4B4007B47405DB22434065FCFB8C0BC94B4031B77BB94F1E434065FCFB8C0BC94B40
11009	Денежниково	1	10	443	38.098511999999999	38.116757	55.444257	55.436616999999998	0103000020E61000000100000005000000BC218D0A9C0C434056F0DB10E3B74B40BC218D0A9C0C43407102D369DDB84B401F4AB4E4F10E43407102D369DDB84B401F4AB4E4F10E434056F0DB10E3B74B40BC218D0A9C0C434056F0DB10E3B74B40
9155	Дементьево	1	10	443	38.278678999999997	38.306742	55.614516000000002	55.605032000000001	0103000020E610000001000000050000007E8AE3C0AB234340498446B071CD4B407E8AE3C0AB234340336FD575A8CE4B40A227655243274340336FD575A8CE4B40A227655243274340498446B071CD4B407E8AE3C0AB234340498446B071CD4B40
12288	Гжельского кирпичного завода	1	10	443	38.406661	38.443807	55.621062999999999	55.610289999999999	0103000020E6100000010000000500000082C7B7770D344340B58993FB1DCE4B4082C7B7770D344340B9E00CFE7ECF4B40315EF3AACE384340B9E00CFE7ECF4B40315EF3AACE384340B58993FB1DCE4B4082C7B7770D344340B58993FB1DCE4B40
12200	Гжель	1	10	443	38.381211999999998	38.407685999999998	55.619273999999997	55.597062999999999	0103000020E61000000100000005000000DF6B088ECB3043406953758F6CCC4B40DF6B088ECB304340ADA1D45E44CF4B40BE840A0E2F344340ADA1D45E44CF4B40BE840A0E2F3443406953758F6CCC4B40DF6B088ECB3043406953758F6CCC4B40
11917	Гжелка	1	10	443	38.312472999999997	38.323369999999997	55.559364000000002	55.554994999999998	0103000020E6100000010000000500000006F1811DFF274340C5387F130AC74B4006F1811DFF274340A647533D99C74B40F6402B3064294340A647533D99C74B40F6402B3064294340C5387F130AC74B4006F1811DFF274340C5387F130AC74B40
9763	Вялки	1	10	443	38.071328999999999	38.101297000000002	55.658484000000001	55.649779000000002	0103000020E61000000100000005000000D120054F21094340555051F52BD34B40D120054F210943403A78263449D44B406A17D34CF70C43403A78263449D44B406A17D34CF70C4340555051F52BD34B40D120054F21094340555051F52BD34B40
11353	Вохринка	1	10	443	38.284678999999997	38.342998000000001	55.414485999999997	55.389197000000003	0103000020E61000000100000005000000D26D895C70244340C5591135D1B14B40D26D895C702443402E5393E00DB54B40F54BC45BE72B43402E5393E00DB54B40F54BC45BE72B4340C5591135D1B14B40D26D895C70244340C5591135D1B14B40
10504	Верхнее Мячково	1	10	443	37.96584	37.992384999999999	55.558768000000001	55.543092999999999	0103000020E61000000100000005000000969526A5A0FB4240E0D7481284C54B40969526A5A0FB42409206B7B585C74B403E05C07806FF42409206B7B585C74B403E05C07806FF4240E0D7481284C54B40969526A5A0FB4240E0D7481284C54B40
2489	Быково	1	10	443	38.033105999999997	38.105015999999999	55.649576000000003	55.611789999999999	0103000020E6100000010000000500000093A641D13C0443408A027D224FCE4B4093A641D13C0443401D226E4E25D34B4043C70E2A710D43401D226E4E25D34B4043C70E2A710D43408A027D224FCE4B4093A641D13C0443408A027D224FCE4B40
61874	Быково	1	10	443	38.033105999999997	38.105015999999999	55.649576000000003	55.611789999999999	0103000020E6100000010000000500000093A641D13C0443408A027D224FCE4B4093A641D13C0443401D226E4E25D34B4043C70E2A710D43401D226E4E25D34B4043C70E2A710D43408A027D224FCE4B4093A641D13C0443408A027D224FCE4B40
10368	Быково	1	10	443	38.043607000000002	38.071337999999997	55.614911999999997	55.607340999999998	0103000020E61000000100000005000000377007EA940543408D429259BDCD4B40377007EA940543407FF5B86FB5CE4B40247B849A210943407FF5B86FB5CE4B40247B849A210943408D429259BDCD4B40377007EA940543408D429259BDCD4B40
11529	Бояркино	1	10	443	38.287581000000003	38.324322000000002	55.462420999999999	55.447851	0103000020E61000000100000005000000BAF94674CF2443408E3D7B2E53B94B40BAF94674CF244340E7FD7F9C30BB4B40C9AF1F6283294340E7FD7F9C30BB4B40C9AF1F62832943408E3D7B2E53B94B40BAF94674CF2443408E3D7B2E53B94B40
12590	Антоново	1	10	443	38.568879000000003	38.586638999999998	55.580472	55.575256000000003	0103000020E61000000100000005000000CB30EE06D1484340F56915FDA1C94B40CB30EE06D1484340321F10E84CCA4B4071C79BFC164B4340321F10E84CCA4B4071C79BFC164B4340F56915FDA1C94B40CB30EE06D1484340F56915FDA1C94B40
62048	Аксеново	1	10	443	38.231839999999998	38.253103000000003	55.682234000000001	55.670996000000002	0103000020E61000000100000005000000CBF3E0EEAC1D434098DF6932E3D54B40CBF3E0EEAC1D4340111C977153D74B407FC2D9AD65204340111C977153D74B407FC2D9AD6520434098DF6932E3D54B40CBF3E0EEAC1D434098DF6932E3D54B40
61949	поселение Черкизово	1	10	367	37.768858000000002	37.812928999999997	55.983826000000001	55.950463999999997	0103000020E610000001000000050000004DA25EF069E242403E03EACDA8F94B404DA25EF069E242402D7AA702EEFD4B40287CB60E0EE842402D7AA702EEFD4B40287CB60E0EE842403E03EACDA8F94B404DA25EF069E242403E03EACDA8F94B40
61901	поселение Софрино	1	10	367	37.959910999999998	37.977787999999997	56.155092000000003	56.150759999999998	0103000020E610000001000000050000000B09185DDEFA4240C1C58A1A4C134C400B09185DDEFA424085EFFD0DDA134C40EB353D2828FD424085EFFD0DDA134C40EB353D2828FD4240C1C58A1A4C134C400B09185DDEFA4240C1C58A1A4C134C40
59472	городское поселение Правдинский	1	10	367	37.689267000000001	38.187525999999998	56.230736999999998	55.942810999999999	0103000020E61000000100000005000000249BABE639D842408FA7E507AEF84B40249BABE639D84240137D3ECA881D4C4029931ADA00184340137D3ECA881D4C4029931ADA001843408FA7E507AEF84B40249BABE639D842408FA7E507AEF84B40
1881	Черкизово	1	10	367	37.768858000000002	37.812928999999997	55.983826000000001	55.950463999999997	0103000020E610000001000000050000004DA25EF069E242403E03EACDA8F94B404DA25EF069E242402D7AA702EEFD4B40287CB60E0EE842402D7AA702EEFD4B40287CB60E0EE842403E03EACDA8F94B404DA25EF069E242403E03EACDA8F94B40
7840	Царево	1	10	367	38.082163000000001	38.102240000000002	56.087363000000003	56.077845000000003	0103000020E610000001000000050000007BF83251840A43401D9430D3F6094C407BF83251840A4340B3F0F5B52E0B4C40E92B4833160D4340B3F0F5B52E0B4C40E92B4833160D43401D9430D3F6094C407BF83251840A43401D9430D3F6094C40
7411	Тишково	1	10	367	37.732377	37.745491999999999	56.093505	56.086087999999997	0103000020E61000000100000005000000DAAB8F87BEDD4240FD497CEE040B4C40DAAB8F87BEDD42409981CAF8F70B4C40FEB627486CDF42409981CAF8F70B4C40FEB627486CDF4240FD497CEE040B4C40DAAB8F87BEDD4240FD497CEE040B4C40
60276	Тарасовка	1	10	367	37.805903999999998	37.843319000000001	55.971476000000003	55.953997000000001	0103000020E6100000010000000500000098DBBDDC27E74240B6BDDD921CFA4B4098DBBDDC27E74240A96C585359FC4B40378C82E0F1EB4240A96C585359FC4B40378C82E0F1EB4240B6BDDD921CFA4B4098DBBDDC27E74240B6BDDD921CFA4B40
7417	Степаньково	1	10	367	37.801789999999997	37.823025999999999	56.068297999999999	56.063741	0103000020E610000001000000050000004221020EA1E64240093543AA28084C404221020EA1E64240EC3026FDBD084C40FCE07CEA58E94240EC3026FDBD084C40FCE07CEA58E94240093543AA28084C404221020EA1E64240093543AA28084C40
59551	Софрино-1	1	10	367	37.689267000000001	38.187525999999998	56.230736999999998	55.942810999999999	0103000020E61000000100000005000000249BABE639D842408FA7E507AEF84B40249BABE639D84240137D3ECA881D4C4029931ADA00184340137D3ECA881D4C4029931ADA001843408FA7E507AEF84B40249BABE639D842408FA7E507AEF84B40
59138	Софрино	1	10	367	37.893704999999997	37.965310000000002	56.152540000000002	56.126382999999997	0103000020E61000000100000005000000C6A2E9EC64F242409BE271512D104C40C6A2E9EC64F242407AAA436E86134C403A4030478FFB42407AAA436E86134C403A4030478FFB42409BE271512D104C40C6A2E9EC64F242409BE271512D104C40
61906	Софрино	1	10	367	37.893704999999997	37.965310000000002	56.152540000000002	56.126382999999997	0103000020E61000000100000005000000C6A2E9EC64F242409BE271512D104C40C6A2E9EC64F242407AAA436E86134C403A4030478FFB42407AAA436E86134C403A4030478FFB42409BE271512D104C40C6A2E9EC64F242409BE271512D104C40
4327	Пушкино	1	10	367	37.772252999999999	37.885055000000001	56.065483999999998	55.961505000000002	0103000020E61000000100000005000000739EB12FD9E2424062F8889812FB4B40739EB12FD9E24240A4349BC761084C40A514747B49F14240A4349BC761084C40A514747B49F1424062F8889812FB4B40739EB12FD9E2424062F8889812FB4B40
61861	Правдинский	1	10	367	37.845258999999999	37.886994999999999	56.079918999999997	56.050823000000001	0103000020E6100000010000000500000028D3687231EC42403B71395E81064C4028D3687231EC42401DAA29C93A0A4C40965B5A0D89F142401DAA29C93A0A4C40965B5A0D89F142403B71395E81064C4028D3687231EC42403B71395E81064C40
61870	Правдинский	1	10	367	37.845258999999999	37.886994999999999	56.079918999999997	56.050823000000001	0103000020E6100000010000000500000028D3687231EC42403B71395E81064C4028D3687231EC42401DAA29C93A0A4C40965B5A0D89F142401DAA29C93A0A4C40965B5A0D89F142403B71395E81064C4028D3687231EC42403B71395E81064C40
6026	Мураново	1	10	367	37.880105	37.913440999999999	56.182831999999998	56.173622999999999	0103000020E61000000100000005000000E605D847A7F04240AD6A494739164C40E605D847A7F04240C554FA0967174C40ABE97AA2EBF44240C554FA0967174C40ABE97AA2EBF44240AD6A494739164C40E605D847A7F04240AD6A494739164C40
2890	Лесные Поляны	1	10	367	37.835926000000001	37.876717999999997	55.963676999999997	55.951718999999997	0103000020E6100000010000000500000024F0879FFFEA4240ACFD9DEDD1F94B4024F0879FFFEA4240257497C459FB4B4042E8A04B38F04240257497C459FB4B4042E8A04B38F04240ACFD9DEDD1F94B4024F0879FFFEA4240ACFD9DEDD1F94B40
6433	Лесной	1	10	367	37.901035999999998	37.958303000000001	56.090100999999997	56.054281000000003	0103000020E610000001000000050000006342CC2555F34240A8E507AEF2064C406342CC2555F342401F2BF86D880B4C40505436ACA9FA42401F2BF86D880B4C40505436ACA9FA4240A8E507AEF2064C406342CC2555F34240A8E507AEF2064C40
61869	Лесной	1	10	367	37.901035999999998	37.958303000000001	56.090100999999997	56.054281000000003	0103000020E610000001000000050000006342CC2555F34240A8E507AEF2064C406342CC2555F342401F2BF86D880B4C40505436ACA9FA42401F2BF86D880B4C40505436ACA9FA4240A8E507AEF2064C406342CC2555F34240A8E507AEF2064C40
7942	Левково	1	10	367	37.935485999999997	37.960971000000001	56.016168999999998	56.008037000000002	0103000020E61000000100000005000000D4EE5701BEF7424038143E5B07014C40D4EE5701BEF74240C11A67D311024C40C4B3041901FB4240C11A67D311024C40C4B3041901FB424038143E5B07014C40D4EE5701BEF7424038143E5B07014C40
59545	Зеленоградский	1	10	367	37.878478999999999	37.937812999999998	56.129348	56.080367000000003	0103000020E61000000100000005000000849CF7FF71F04240BD564277490A4C40849CF7FF71F04240C9E6AA798E104C40BF61A2410AF84240C9E6AA798E104C40BF61A2410AF84240BD564277490A4C40849CF7FF71F04240BD564277490A4C40
61925	Зверосовхоза	1	10	367	37.968311	37.985900000000001	56.047483999999997	56.039428999999998	0103000020E61000000100000005000000B4AD669DF1FB4240CAC16C020C054C40B4AD669DF1FB4240A88AA9F413064C402E90A0F831FE4240A88AA9F413064C402E90A0F831FE4240CAC16C020C054C40B4AD669DF1FB4240CAC16C020C054C40
7334	Ельдигино	1	10	367	37.795304000000002	37.831676999999999	56.123925	56.108024999999998	0103000020E6100000010000000500000062307F85CCE54240401361C3D30D4C4062307F85CCE5424012143FC6DC0F4C40EEEA556474EA424012143FC6DC0F4C40EEEA556474EA4240401361C3D30D4C4062307F85CCE54240401361C3D30D4C40
6744	Братовщина	1	10	367	37.867581999999999	37.89349	56.060167	56.042712999999999	0103000020E61000000100000005000000944C4EED0CEF4240990E9D9E77054C40944C4EED0CEF424033A6608DB3074C40CAA65CE15DF2424033A6608DB3074C40CAA65CE15DF24240990E9D9E77054C40944C4EED0CEF4240990E9D9E77054C40
7867	Барково	1	10	367	38.083689999999997	38.102401999999998	56.165813999999997	56.151783000000002	0103000020E6100000010000000500000049809A5AB60A43405D8B16A06D134C4049809A5AB60A4340069CA56439154C40C2853C821B0D4340069CA56439154C40C2853C821B0D43405D8B16A06D134C4049809A5AB60A43405D8B16A06D134C40
61988	Ашукино	1	10	367	37.918759999999999	37.983609000000001	56.186379000000002	56.148327999999999	0103000020E61000000100000005000000BD6F7CED99F54240618A7269FC124C40BD6F7CED99F54240A2D45E44DB174C40908653E6E6FD4240A2D45E44DB174C40908653E6E6FD4240618A7269FC124C40BD6F7CED99F54240618A7269FC124C40
7551	Алешино	1	10	367	37.739249000000001	37.760269999999998	56.154535000000003	56.140239000000001	0103000020E61000000100000005000000E44C13B69FDE4240D74FFF59F3114C40E44C13B69FDE42402F8B89CDC7134C40A110018750E142402F8B89CDC7134C40A110018750E14240D74FFF59F3114C40E44C13B69FDE4240D74FFF59F3114C40
61940	Пушкино	1	10	7541	37.772252999999999	37.885055000000001	56.065483999999998	55.961505000000002	0103000020E61000000100000005000000739EB12FD9E2424062F8889812FB4B40739EB12FD9E24240A4349BC761084C40A514747B49F14240A4349BC761084C40A514747B49F1424062F8889812FB4B40739EB12FD9E2424062F8889812FB4B40
3282	фабрики имени 1 Мая	1	10	377	37.628694000000003	37.637407000000003	55.464931999999997	55.461936000000001	0103000020E610000001000000050000008198840B79D042402B6C06B820BB4B408198840B79D04240936E4BE482BB4B40E99E758D96D14240936E4BE482BB4B40E99E758D96D142402B6C06B820BB4B408198840B79D042402B6C06B820BB4B40
62000	санатория Родина	1	10	377	37.398868999999998	37.405920000000002	55.444257	55.440406000000003	0103000020E61000000100000005000000B131AF230EB34240297B4B395FB84B40B131AF230EB342407102D369DDB84B406B65C22FF5B342407102D369DDB84B406B65C22FF5B34240297B4B395FB84B40B131AF230EB34240297B4B395FB84B40
61957	радиоцентра Романцево	1	10	377	37.574705000000002	37.594872000000002	55.318936000000001	55.307470000000002	0103000020E6100000010000000500000081ECF5EE8FC9424025404D2D5BA74B4081ECF5EE8FC942402FC214E5D2A84B402FA704C424CC42402FC214E5D2A84B402FA704C424CC424025404D2D5BA74B4081ECF5EE8FC9424025404D2D5BA74B40
57500	п.Молодёжный	1	10	377	36.943458999999997	37.727345999999997	55.521434999999997	55.135134999999998	0103000020E61000000100000005000000F50EB743C3784240C1C58A1A4C914B40F50EB743C3784240B0FECF61BEC24B402E7079AC19DD4240B0FECF61BEC24B402E7079AC19DD4240C1C58A1A4C914B40F50EB743C3784240C1C58A1A4C914B40
58934	п. дома отдыха Вороново	1	10	377	37.133147000000001	37.141976999999997	55.318024000000001	55.314073999999998	0103000020E61000000100000005000000BF47FDF50A9142400F43AB9333A84B40BF47FDF50A914240EBABAB02B5A84B4060E4654D2C924240EBABAB02B5A84B4060E4654D2C9242400F43AB9333A84B40BF47FDF50A9142400F43AB9333A84B40
59521	п. Львовский	1	10	377	37.506782999999999	37.537694000000002	55.332667999999998	55.304656999999999	0103000020E610000001000000050000009A95ED43DEC04240ADBF2500FFA64B409A95ED43DEC042407E3672DD94AA4B40B2A03028D3C442407E3672DD94AA4B40B2A03028D3C44240ADBF2500FFA64B409A95ED43DEC04240ADBF2500FFA64B40
3735	Щапово	1	10	377	37.390379000000003	37.419224	55.424531000000002	55.411169000000001	0103000020E61000000100000005000000C90567F0F7B142408410902FA1B44B40C90567F0F7B14240B091240857B64B4062D9CC21A9B54240B091240857B64B4062D9CC21A9B542408410902FA1B44B40C90567F0F7B142408410902FA1B44B40
59264	Шишкин Лес	1	10	377	37.18074	37.195732	55.420357000000003	55.406236999999997	0103000020E610000001000000050000001E8A027D229742406BB6F292FFB34B401E8A027D2297424085D21742CEB54B40ED6305BF0D99424085D21742CEB54B40ED6305BF0D9942406BB6F292FFB34B401E8A027D229742406BB6F292FFB34B40
56688	Троицкое	1	10	377	37.405031000000001	37.425566000000003	55.390357999999999	55.382671999999999	0103000020E61000000100000005000000DF6E490ED8B34240268C6665FBB04B40DF6E490ED8B34240B1DD3D40F7B14B4010255AF278B64240B1DD3D40F7B14B4010255AF278B64240268C6665FBB04B40DF6E490ED8B34240268C6665FBB04B40
2987	Сынково	1	10	377	37.617643999999999	37.649048999999998	55.356769	55.344751000000002	0103000020E610000001000000050000000A4966F50ECF4240B421FFCC20AC4B400A4966F50ECF4240029D499BAAAD4B403140A20914D34240029D499BAAAD4B403140A20914D34240B421FFCC20AC4B400A4966F50ECF4240B421FFCC20AC4B40
45757	Покровское	1	10	377	37.201554000000002	37.212037000000002	55.330449999999999	55.323709999999998	0103000020E6100000010000000500000062307F85CC994240AFB14B546FA94B4062307F85CC9942404A7B832F4CAA4B405F454607249B42404A7B832F4CAA4B405F454607249B4240AFB14B546FA94B4062307F85CC994240AFB14B546FA94B40
3330	Остафьево	1	10	377	37.477974000000003	37.491629000000003	55.503701	55.495944999999999	0103000020E610000001000000050000004E2B85402EBD4240AFCE31207BBF4B404E2B85402EBD424033FB3C4679C04B40F261F6B2EDBE424033FB3C4679C04B40F261F6B2EDBE4240AFCE31207BBF4B404E2B85402EBD4240AFCE31207BBF4B40
1945	Львовский	1	10	377	37.506782999999999	37.537694000000002	55.332667999999998	55.304656999999999	0103000020E610000001000000050000009A95ED43DEC04240ADBF2500FFA64B409A95ED43DEC042407E3672DD94AA4B40B2A03028D3C442407E3672DD94AA4B40B2A03028D3C44240ADBF2500FFA64B409A95ED43DEC04240ADBF2500FFA64B40
2237	ЛМС	1	10	377	37.173805000000002	37.203197000000003	55.324074000000003	55.298512000000002	0103000020E61000000100000005000000CE70033E3F96424056BB26A435A64B40CE70033E3F964240F1BDBF417BA94B409AD2FA5B029A4240F1BDBF417BA94B409AD2FA5B029A424056BB26A435A64B40CE70033E3F96424056BB26A435A64B40
46031	Курилово	1	10	377	37.364265000000003	37.389175999999999	55.379767000000001	55.367565999999997	0103000020E61000000100000005000000EA094B3CA0AE42408E8F16670CAF4B40EA094B3CA0AE4240CE8C7E349CB04B40AD31E884D0B14240CE8C7E349CB04B40AD31E884D0B142408E8F16670CAF4B40EA094B3CA0AE42408E8F16670CAF4B40
2717	Красная Пахра	1	10	377	37.256062999999997	37.290199000000001	55.438578	55.421889999999998	0103000020E610000001000000050000009A5B21ACC6A042403541D47D00B64B409A5B21ACC6A042405F5FEB5223B84B407C2AA73D25A542405F5FEB5223B84B407C2AA73D25A542403541D47D00B64B409A5B21ACC6A042403541D47D00B64B40
62059	Климовск	1	10	377	36.943458999999997	37.727345999999997	55.521434999999997	55.135134999999998	0103000020E61000000100000005000000F50EB743C3784240C1C58A1A4C914B40F50EB743C3784240B0FECF61BEC24B402E7079AC19DD4240B0FECF61BEC24B402E7079AC19DD4240C1C58A1A4C914B40F50EB743C3784240C1C58A1A4C914B40
45544	Кленово	1	10	377	37.335438000000003	37.373195000000003	55.328488999999998	55.315294000000002	0103000020E61000000100000005000000F7EAE3A1EFAA42400150C58D5BA84B40F7EAE3A1EFAA4240410C74ED0BAA4B40EF0390DAC4AF4240410C74ED0BAA4B40EF0390DAC4AF42400150C58D5BA84B40F7EAE3A1EFAA42400150C58D5BA84B40
3416	Знамя Октября	1	10	377	37.524534000000003	37.545222000000003	55.482438999999999	55.472199000000003	0103000020E61000000100000005000000EED11BEE23C342401A1A4F0471BC4B40EED11BEE23C3424050A8A78FC0BD4B40A587A1D5C9C5424050A8A78FC0BD4B40A587A1D5C9C542401A1A4F0471BC4B40EED11BEE23C342401A1A4F0471BC4B40
2834	Железнодорожный	1	10	377	37.533867000000001	37.546056999999998	55.391820000000003	55.382911999999997	0103000020E61000000100000005000000F2B4FCC055C442407B9FAA4203B14B40F2B4FCC055C4424099F5622827B24B403D601E32E5C5424099F5622827B24B403D601E32E5C542407B9FAA4203B14B40F2B4FCC055C442407B9FAA4203B14B40
3569	Ерино	1	10	377	37.499426	37.527363999999999	55.456648000000001	55.438904999999998	0103000020E61000000100000005000000D462F030EDBF42408386FE092EB84B40D462F030EDBF424054E4107173BA4B403B8BDEA980C3424054E4107173BA4B403B8BDEA980C342408386FE092EB84B40D462F030EDBF42408386FE092EB84B40
2383	Дубровицы	1	10	377	37.464032000000003	37.500197999999997	55.453028000000003	55.435478000000003	0103000020E6100000010000000500000014268C6665BB424052103CBEBDB74B4014268C6665BB42400E164ED2FCB94B4026C3F17C06C042400E164ED2FCB94B4026C3F17C06C0424052103CBEBDB74B4014268C6665BB424052103CBEBDB74B40
2585	Былово	1	10	377	37.23357	37.252389000000001	55.449955000000003	55.437351999999997	0103000020E61000000100000005000000D2A92B9FE59D42408B6B7C26FBB74B40D2A92B9FE59D4240FAD51C2098B94B40616F62484EA04240FAD51C2098B94B40616F62484EA042408B6B7C26FBB74B40D2A92B9FE59D42408B6B7C26FBB74B40
45896	Богородское	1	10	377	37.031646000000002	37.045938	55.223509	55.217080000000003	0103000020E610000001000000050000004D86E3F90C844240CF4E0647C99B4B404D86E3F90C8442404BAE62F19B9C4B4063D2DF4BE18542404BAE62F19B9C4B4063D2DF4BE1854240CF4E0647C99B4B404D86E3F90C844240CF4E0647C99B4B40
45975	Александровка	1	10	377	37.607044000000002	37.624732000000002	55.418446000000003	55.406227000000001	0103000020E61000000100000005000000D49D279EB3CD424048E00F3FFFB34B40D49D279EB3CD42402E9276A38FB54B40E161DA37F7CF42402E9276A38FB54B40E161DA37F7CF424048E00F3FFFB34B40D49D279EB3CD424048E00F3FFFB34B40
48593	Семеново	1	10	273	38.632525000000001	38.641902999999999	55.706111999999997	55.689664	0103000020E6100000010000000500000082734694F6504340419DF2E846D84B4082734694F650434015A8C5E061DA4B40261AA4E02952434015A8C5E061DA4B40261AA4E029524340419DF2E846D84B4082734694F6504340419DF2E846D84B40
25772	Саурово	1	10	273	38.740431000000001	38.762745000000002	55.779741999999999	55.767842999999999	0103000020E61000000100000005000000E8F86871C65E434034BBEEAD48E24B40E8F86871C65E4340A8A8FA95CEE34B400118CFA0A1614340A8A8FA95CEE34B400118CFA0A161434034BBEEAD48E24B40E8F86871C65E434034BBEEAD48E24B40
31168	Рахманово	1	10	273	38.598083000000003	38.632911	55.749389999999998	55.741307999999997	0103000020E6100000010000000500000094A5D6FB8D4C4340AF21382EE3DE4B4094A5D6FB8D4C434087F9F202ECDF4B40AB23473A0351434087F9F202ECDF4B40AB23473A03514340AF21382EE3DE4B4094A5D6FB8D4C4340AF21382EE3DE4B40
1147	Павловский Посад	1	10	273	38.586396000000001	38.726982999999997	55.801895000000002	55.752693000000001	0103000020E61000000100000005000000AB402D060F4B4340CD76853E58E04B40AB402D060F4B4340B8E9CF7EA4E64B40BDDF68C70D5D4340B8E9CF7EA4E64B40BDDF68C70D5D4340CD76853E58E04B40AB402D060F4B4340CD76853E58E04B40
30994	Ново-Загарье	1	10	273	38.746332000000002	38.768179000000003	55.652267999999999	55.638648000000003	0103000020E61000000100000005000000A9FA95CE875F4340F2D3B837BFD14B40A9FA95CE875F4340191D90847DD34B40AC3C81B053624340191D90847DD34B40AC3C81B053624340F2D3B837BFD14B40A9FA95CE875F4340F2D3B837BFD14B40
48763	Логиново	1	10	273	38.717118999999997	38.744481999999998	55.714013999999999	55.703417999999999	0103000020E610000001000000050000008C2B2E8ECA5B434078B5DC9909DA4B408C2B2E8ECA5B43406D718DCF64DB4B40F73AA92F4B5F43406D718DCF64DB4B40F73AA92F4B5F434078B5DC9909DA4B408C2B2E8ECA5B434078B5DC9909DA4B40
60235	Кузнецы	1	10	273	38.652360000000002	38.676245999999999	55.855289999999997	55.842666000000001	0103000020E61000000100000005000000FA9B508880534340BFB9BF7ADCEB4B40FA9B508880534340444C89247AED4B4081069B3A8F564340444C89247AED4B4081069B3A8F564340BFB9BF7ADCEB4B40FA9B508880534340BFB9BF7ADCEB4B40
31054	Крупино	1	10	273	38.721969999999999	38.748156000000002	55.636341000000002	55.625064000000002	0103000020E61000000100000005000000B8585183695C434017F4DE1802D04B40B8585183695C43404E0D349F73D14B4031276893C35F43404E0D349F73D14B4031276893C35F434017F4DE1802D04B40B8585183695C434017F4DE1802D04B40
31246	Казанское	1	10	273	38.545414999999998	38.571340999999997	55.745443000000002	55.738109999999999	0103000020E61000000100000005000000B9DFA128D0454340DF6C73637ADE4B40B9DFA128D04543401D041DAD6ADF4B4095EEAEB3214943401D041DAD6ADF4B4095EEAEB321494340DF6C73637ADE4B40B9DFA128D0454340DF6C73637ADE4B40
31384	Ефимово	1	10	273	38.751327000000003	38.765655000000002	55.717137000000001	55.706690000000002	0103000020E6100000010000000500000008CDAE7B2B604340833463D174DA4B4008CDAE7B2B60434033E02C25CBDB4B406B82A8FB0062434033E02C25CBDB4B406B82A8FB00624340833463D174DA4B4008CDAE7B2B604340833463D174DA4B40
31307	Евсеево	1	10	273	38.694634000000001	38.721701000000003	55.760489	55.747819	0103000020E61000000100000005000000475854C4E9584340E9297288B8DF4B40475854C4E9584340DFFB1BB457E14B40C93EC8B2605C4340DFFB1BB457E14B40C93EC8B2605C4340E9297288B8DF4B40475854C4E9584340E9297288B8DF4B40
31158	Васютино	1	10	273	38.733226000000002	38.754497999999998	55.930801000000002	55.919049000000001	0103000020E61000000100000005000000D8497D59DA5D4340F435CB65A3F54B40D8497D59DA5D4340C40AB77C24F74B40DE72F56393604340C40AB77C24F74B40DE72F56393604340F435CB65A3F54B40D8497D59DA5D4340F435CB65A3F54B40
21386	Большие дворы	1	10	273	38.627881000000002	38.663795	55.830043000000003	55.803454000000002	0103000020E61000000100000005000000D06394675E50434092EBA694D7E64B40D06394675E5043400AA359D93EEA4B40C91F0C3CF75443400AA359D93EEA4B40C91F0C3CF754434092EBA694D7E64B40D06394675E50434092EBA694D7E64B40
48608	Алферово	1	10	273	38.687026000000003	38.723120000000002	55.690567000000001	55.674225	0103000020E6100000010000000500000038C0CC77F0574340A3923A014DD64B4038C0CC77F05743403259DC7F64D84B40B18A37328F5C43403259DC7F64D84B40B18A37328F5C4340A3923A014DD64B4038C0CC77F0574340A3923A014DD64B40
27446	Яковлево	1	10	554	39.225358999999997	39.247726999999998	55.702505000000002	55.692779999999999	0103000020E61000000100000005000000FC6D4F90D89C434054A9D903ADD84B40FC6D4F90D89C4340642310AFEBD94B4008ABB184B59F4340642310AFEBD94B4008ABB184B59F434054A9D903ADD84B40FC6D4F90D89C434054A9D903ADD84B40
28017	Юркино	1	10	554	38.841796000000002	38.853186999999998	55.713597999999998	55.691851	0103000020E61000000100000005000000AAF3A8F8BF6B43403A5AD5928ED84B40AAF3A8F8BF6B4340D93EE42D57DB4B40A92F4B3B356D4340D93EE42D57DB4B40A92F4B3B356D43403A5AD5928ED84B40AAF3A8F8BF6B43403A5AD5928ED84B40
29020	Цаплино	1	10	554	38.905836999999998	38.936748000000001	55.498235000000001	55.486514999999997	0103000020E61000000100000005000000DD408177F2734340B8019F1F46BE4B40DD408177F27343407D5C1B2AC6BF4B40F54BC45BE77743407D5C1B2AC6BF4B40F54BC45BE7774340B8019F1F46BE4B40DD408177F2734340B8019F1F46BE4B40
29506	Хотеичи	1	10	554	38.755819000000002	38.804651	55.509487	55.496887999999998	0103000020E6100000010000000500000004594FADBE6043402EE3A6069ABF4B4004594FADBE6043405B5EB9DE36C14B40CBD8D0CDFE6643405B5EB9DE36C14B40CBD8D0CDFE6643402EE3A6069ABF4B4004594FADBE6043402EE3A6069ABF4B40
28398	Федорово	1	10	554	38.812592000000002	38.845084	55.821258999999998	55.807096000000001	0103000020E61000000100000005000000E17EC00303684340C05DF6EB4EE74B40E17EC00303684340D845D1031FE94B40BA2F67B62B6C4340D845D1031FE94B40BA2F67B62B6C4340C05DF6EB4EE74B40E17EC00303684340C05DF6EB4EE74B40
28978	Степановка	1	10	554	39.025483999999999	39.067112000000002	55.540613	55.53051	0103000020E610000001000000050000001F49490F43834340B9196EC0E7C34B401F49490F438343406F6589CE32C54B40A7954220978843406F6589CE32C54B40A795422097884340B9196EC0E7C34B401F49490F43834340B9196EC0E7C34B40
29553	Соболево	1	10	554	38.685713999999997	38.729740999999997	55.525373999999999	55.511975	0103000020E610000001000000050000006534F279C55743404FAF946588C14B406534F279C557434098158A743FC34B4071C63027685D434098158A743FC34B4071C63027685D43404FAF946588C14B406534F279C55743404FAF946588C14B40
27892	Снопок Новый	1	10	554	39.152937000000001	39.166564000000001	55.775782999999997	55.768526999999999	0103000020E6100000010000000500000097AC8A7093934340E78BBD175FE24B4097AC8A709393434079E57ADB4CE34B4071581AF85195434079E57ADB4CE34B4071581AF851954340E78BBD175FE24B4097AC8A7093934340E78BBD175FE24B40
29309	Смолево	1	10	554	38.944833000000003	38.967480000000002	55.634801000000003	55.616356000000003	0103000020E610000001000000050000003E97A949F0784340C158DFC0E4CE4B403E97A949F0784340EB3BBF2841D14B405DC47762D67B4340EB3BBF2841D14B405DC47762D67B4340C158DFC0E4CE4B403E97A949F0784340C158DFC0E4CE4B40
29103	Слободище	1	10	554	38.841554000000002	38.872087999999998	55.516196000000001	55.497613000000001	0103000020E61000000100000005000000B4E89D0AB86B4340408864C8B1BF4B40B4E89D0AB86B4340BB29E5B512C24B40F59D5F94A06F4340BB29E5B512C24B40F59D5F94A06F4340408864C8B1BF4B40B4E89D0AB86B4340408864C8B1BF4B40
27982	Савостьяново	1	10	554	38.804794999999999	38.839118999999997	55.745249999999999	55.734304000000002	0103000020E61000000100000005000000FE7DC6850367434037A968ACFDDD4B40FE7DC6850367434008AC1C5A64DF4B40E2395B40686B434008AC1C5A64DF4B40E2395B40686B434037A968ACFDDD4B40FE7DC6850367434037A968ACFDDD4B40
27414	Савинская	1	10	554	39.292687999999998	39.318765999999997	55.695514000000003	55.687410999999997	0103000020E6100000010000000500000040F7E5CC76A5434090F46915FDD74B4040F7E5CC76A5434080F44D9A06D94B40D2890453CDA8434080F44D9A06D94B40D2890453CDA8434090F46915FDD74B4040F7E5CC76A5434090F46915FDD74B40
28482	Понарино	1	10	554	39.095373000000002	39.119484	55.591752	55.582949999999997	0103000020E61000000100000005000000F1F5B52E358C4340029A081B9ECA4B40F1F5B52E358C4340DAAB8F87BECB4B40983270404B8F4340DAAB8F87BECB4B40983270404B8F4340029A081B9ECA4B40F1F5B52E358C4340029A081B9ECA4B40
28813	Петрушино	1	10	554	39.166834000000001	39.199002999999998	55.614353000000001	55.603644000000003	0103000020E6100000010000000500000031EE06D15A9543409C36E33444CD4B4031EE06D15A95434089997D1EA3CE4B40276728EE7899434089997D1EA3CE4B40276728EE789943409C36E33444CD4B4031EE06D15A9543409C36E33444CD4B40
27809	Озерецкий	1	10	554	39.061999999999998	39.082042000000001	55.826492999999999	55.821860999999998	0103000020E610000001000000050000000E2DB29DEF874340CE6DC2BD32E94B400E2DB29DEF874340BCAFCA85CAE94B4000732D5A808A4340BCAFCA85CAE94B4000732D5A808A4340CE6DC2BD32E94B400E2DB29DEF874340CE6DC2BD32E94B40
62011	Новое	1	10	554	38.902639000000001	38.941240000000001	55.634993999999999	55.625166	0103000020E610000001000000050000000D8CBCAC897343401B49827005D04B400D8CBCAC89734340FF93BF7B47D14B40F1D7648D7A784340FF93BF7B47D14B40F1D7648D7A7843401B49827005D04B400D8CBCAC897343401B49827005D04B40
29415	Мисцево	1	10	554	39.074190999999999	39.090854	55.645496999999999	55.635747000000002	0103000020E610000001000000050000002A5437177F894340DBC35E2860D14B402A5437177F89434043554CA59FD24B40FB5A971AA18B434043554CA59FD24B40FB5A971AA18B4340DBC35E2860D14B402A5437177F894340DBC35E2860D14B40
28765	Мисцево	1	10	554	39.112468	39.152172999999998	55.603141000000001	55.593786999999999	0103000020E610000001000000050000005BECF659658E43401DE5603601CC4B405BECF659658E434039F06AB933CD4B40C72AA5677A93434039F06AB933CD4B40C72AA5677A9343401DE5603601CC4B405BECF659658E43401DE5603601CC4B40
29576	Минино	1	10	554	38.623900999999996	38.661451	55.598211999999997	55.580680999999998	0103000020E610000001000000050000008978EBFCDB4F43404C3448C153CA4B408978EBFCDB4F43409109F83592CC4B400874266DAA5443409109F83592CC4B400874266DAA5443404C3448C153CA4B408978EBFCDB4F43404C3448C153CA4B40
29172	Малая Дубна	1	10	554	38.943001000000002	38.975833999999999	55.883232	55.870545999999997	0103000020E61000000100000005000000338CBB41B4784340F1D4230D6EEF4B40338CBB41B4784340ED6305BF0DF14B409529E620E87C4340ED6305BF0DF14B409529E620E87C4340F1D4230D6EEF4B40338CBB41B4784340F1D4230D6EEF4B40
5501	Ликино-Дулево	1	10	554	38.933154999999999	38.974620999999999	55.744708000000003	55.688491999999997	0103000020E61000000100000005000000A88C7F9F7177434060C77F8120D84B40A88C7F9F71774340E8887C9752DF4B40567F8461C07C4340E8887C9752DF4B40567F8461C07C434060C77F8120D84B40A88C7F9F7177434060C77F8120D84B40
22533	Куровское	1	10	554	38.863382999999999	38.964694999999999	55.603785999999999	55.567148000000003	0103000020E6100000010000000500000010768A55836E4340F4FE3F4E98C84B4010768A55836E43402EE411DC48CD4B40AFCE31207B7B43402EE411DC48CD4B40AFCE31207B7B4340F4FE3F4E98C84B4010768A55836E4340F4FE3F4E98C84B40
28353	Красная Дубрава	1	10	554	38.802216999999999	38.835220999999997	55.789239000000002	55.775682000000003	0103000020E61000000100000005000000CAA5F10BAF664340460C3B8C49E34B40CAA5F10BAF66434027DD96C805E54B4059F78F85E86A434027DD96C805E54B4059F78F85E86A4340460C3B8C49E34B40CAA5F10BAF664340460C3B8C49E34B40
15377	Кабаново	1	10	554	38.915593000000001	38.9529	55.759526999999999	55.74033	0103000020E6100000010000000500000028B9C32632754340B41F2922C3DE4B4028B9C32632754340E9B6442E38E14B40E02D90A0F8794340E9B6442E38E14B40E02D90A0F8794340B41F2922C3DE4B4028B9C32632754340B41F2922C3DE4B40
29129	Ильинский Погост	1	10	554	38.895066999999997	38.925528	55.486938000000002	55.468862000000001	0103000020E610000001000000050000004A5D328E91724340282B86AB03BC4B404A5D328E91724340FF9600FC53BE4B4022C495B377764340FF9600FC53BE4B4022C495B377764340282B86AB03BC4B404A5D328E91724340282B86AB03BC4B40
28709	Запутное	1	10	554	39.281432000000002	39.309567000000001	55.585560000000001	55.574370000000002	0103000020E610000001000000050000002106BAF605A44340DAE6C6F484C94B402106BAF605A4434042EC4CA1F3CA4B40DE7536E49FA7434042EC4CA1F3CA4B40DE7536E49FA74340DAE6C6F484C94B402106BAF605A44340DAE6C6F484C94B40
28631	Заполицы	1	10	554	39.193837000000002	39.219430000000003	55.563181999999998	55.553609999999999	0103000020E610000001000000050000009CE09BA6CF984340895E46B1DCC64B409CE09BA6CF98434012D9075916C84B4072E14048169C434012D9075916C84B4072E14048169C4340895E46B1DCC64B409CE09BA6CF984340895E46B1DCC64B40
29423	Заволенье	1	10	554	38.936774999999997	38.976669000000001	55.591701	55.576126000000002	0103000020E61000000100000005000000EE5A423EE87743400A302C7FBEC94B40EE5A423EE87743405801BEDBBCCB4B402E02637D037D43405801BEDBBCCB4B402E02637D037D43400A302C7FBEC94B40EE5A423EE87743400A302C7FBEC94B40
29355	Дуброво	1	10	554	38.971549000000003	38.987189000000001	55.671472999999999	55.657178999999999	0103000020E6100000010000000500000013BBB6B75B7C43401A4F04711ED44B4013BBB6B75B7C4340D192C7D3F2D54B4048FC8A355C7E4340D192C7D3F2D54B4048FC8A355C7E43401A4F04711ED44B4013BBB6B75B7C43401A4F04711ED44B40
27709	Дровосеки	1	10	554	38.978251	39.00714	55.785513000000002	55.777296999999997	0103000020E61000000100000005000000C0232A54377D4340B323D5777EE34B40C0232A54377D43409BCAA2B08BE44B40293FA9F6E98043409BCAA2B08BE44B40293FA9F6E9804340B323D5777EE34B40C0232A54377D4340B323D5777EE34B40
21773	Дрезна	1	10	554	38.828358000000001	38.868602000000003	55.751244	55.730243000000002	0103000020E61000000100000005000000A3B08BA2076A43400491459A78DD4B40A3B08BA2076A43407AA86DC328E04B40BF9EAF592E6F43407AA86DC328E04B40BF9EAF592E6F43400491459A78DD4B40A3B08BA2076A43400491459A78DD4B40
28293	Демихово	1	10	554	38.865656000000001	38.895614000000002	55.807141999999999	55.791992	0103000020E6100000010000000500000008CBD8D0CD6E4340C9586DFE5FE54B4008CBD8D0CD6E4340309DD66D50E74B407DEBC37AA3724340309DD66D50E74B407DEBC37AA3724340C9586DFE5FE54B4008CBD8D0CD6E4340C9586DFE5FE54B40
28133	Давыдово	1	10	554	38.839596	38.877361000000001	55.617967999999998	55.598847999999997	0103000020E610000001000000050000001CEDB8E1776B434033A31F0DA7CC4B401CEDB8E1776B4340BDFC4E9319CF4B4097E4805D4D704340BDFC4E9319CF4B4097E4805D4D70434033A31F0DA7CC4B401CEDB8E1776B434033A31F0DA7CC4B40
27560	Губино	1	10	554	39.093629999999997	39.147269000000001	55.708317999999998	55.685386000000001	0103000020E6100000010000000500000055F65D11FC8B434071917BBABAD74B4055F65D11FC8B434085950A2AAADA4B40795BE9B5D992434085950A2AAADA4B40795BE9B5D992434071917BBABAD74B4055F65D11FC8B434071917BBABAD74B40
28040	Гора	1	10	554	38.990485999999997	39.000861	55.741464999999998	55.735069000000003	0103000020E61000000100000005000000AB92C83EC87E4340D7A6B1BD16DE4B40AB92C83EC87E434077103B53E8DE4B40C26B97361C80434077103B53E8DE4B40C26B97361C804340D7A6B1BD16DE4B40AB92C83EC87E4340D7A6B1BD16DE4B40
27792	Войново-Гора	1	10	554	39.051158000000001	39.068809999999999	55.852742999999997	55.835194999999999	0103000020E61000000100000005000000E27668588C864340306475ABE7EA4B40E27668588C8643404B72C0AE26ED4B40A2D11DC4CE8843404B72C0AE26ED4B40A2D11DC4CE884340306475ABE7EA4B40E27668588C864340306475ABE7EA4B40
27644	Верея	1	10	554	39.090729000000003	39.105415999999998	55.777839	55.766815000000001	0103000020E610000001000000050000003FE603029D8B4340878A71FE26E24B403FE603029D8B4340D446753A90E34B40D13C80457E8D4340D446753A90E34B40D13C80457E8D4340878A71FE26E24B403FE603029D8B4340878A71FE26E24B40
28669	Велино	1	10	554	39.376797000000003	39.393217999999997	55.591141999999998	55.575932999999999	0103000020E610000001000000050000008F1D54E23AB04340F5D72B2CB8C94B408F1D54E23AB0434061A5828AAACB4B406919A9F754B2434061A5828AAACB4B406919A9F754B24340F5D72B2CB8C94B408F1D54E23AB04340F5D72B2CB8C94B40
14746	Богородское	1	10	554	39.078457999999998	39.100960000000001	55.536487000000001	55.519136000000003	0103000020E61000000100000005000000060E68E90A8A43409016670C73C24B40060E68E90A8A434055DD239BABC44B40221ADD41EC8C434055DD239BABC44B40221ADD41EC8C43409016670C73C24B40060E68E90A8A43409016670C73C24B40
27511	Белавино	1	10	554	39.378287999999998	39.402642	55.671128000000003	55.662638000000001	0103000020E61000000100000005000000103CBEBD6BB043401E8B6D52D1D44B40103CBEBD6BB0434007B7B585E7D54B407EFFE6C589B3434007B7B585E7D54B407EFFE6C589B343401E8B6D52D1D44B40103CBEBD6BB043401E8B6D52D1D44B40
29044	Беззубово	1	10	554	38.920299999999997	38.943745999999997	55.452522999999999	55.442872999999999	0103000020E610000001000000050000002041F163CC75434005A4FD0FB0B84B402041F163CC7543400AD80E46ECB94B408BDD3EABCC7843400AD80E46ECB94B408BDD3EABCC78434005A4FD0FB0B84B402041F163CC75434005A4FD0FB0B84B40
28276	Анциферово	1	10	554	38.798048000000001	38.829264999999999	55.564256	55.544255	0103000020E61000000100000005000000B151D66F266643409DD7D825AAC54B40B151D66F266643403049658A39C84B40D55B035B256A43403049658A39C84B40D55B035B256A43409DD7D825AAC54B40B151D66F266643409DD7D825AAC54B40
28457	Авсюнино	1	10	554	39.053395000000002	39.146667000000001	55.575760000000002	55.548161	0103000020E610000001000000050000008D62B9A5D5864340A9F8BF232AC64B408D62B9A5D5864340282CF180B2C94B408333F8FBC5924340282CF180B2C94B408333F8FBC5924340A9F8BF232AC64B408D62B9A5D5864340A9F8BF232AC64B40
28877	Абрамовка	1	10	554	38.992398999999999	39.012988	55.523885999999997	55.501528999999998	0103000020E61000000100000005000000A3CA30EE067F43406F7F2E1A32C04B40A3CA30EE067F4340876A4AB20EC34B40C79E3D97A9814340876A4AB20EC34B40C79E3D97A98143406F7F2E1A32C04B40A3CA30EE067F43406F7F2E1A32C04B40
62004	с. Горы	1	10	1241	38.591427000000003	38.622050999999999	54.908214999999998	54.88138	0103000020E61000000100000005000000577C43E1B34B43409BAC510FD1704B40577C43E1B34B43404A5E9D6340744B40D8B8FE5D9F4F43404A5E9D6340744B40D8B8FE5D9F4F43409BAC510FD1704B40577C43E1B34B43409BAC510FD1704B40
23214	Тарбушево	1	10	1241	38.393061000000003	38.420279999999998	54.877428000000002	54.868383000000001	0103000020E61000000100000005000000A22AA6D24F32434081B3942C276F4B40A22AA6D24F3243401F4C8A8F4F704B40D9942BBCCB3543401F4C8A8F4F704B40D9942BBCCB35434081B3942C276F4B40A22AA6D24F32434081B3942C276F4B40
24271	Сосновка	1	10	1241	38.654587999999997	38.712851999999998	54.907381999999998	54.890163000000001	0103000020E61000000100000005000000512D228AC9534340FC8D76DCF0714B40512D228AC9534340527DE71725744B40B071FDBB3E5B4340527DE71725744B40B071FDBB3E5B4340FC8D76DCF0714B40512D228AC9534340FC8D76DCF0714B40
24363	Редькино	1	10	1241	38.486260999999999	38.509959000000002	54.840333999999999	54.833137000000001	0103000020E61000000100000005000000FE28EACC3D3E4340350BB43BA46A4B40FE28EACC3D3E4340C2DB8310906B4B4083A6255646414340C2DB8310906B4B4083A6255646414340350BB43BA46A4B40FE28EACC3D3E4340350BB43BA46A4B40
16867	Озеры	1	10	1241	38.568807	38.578294	54.854916000000003	54.852708	0103000020E61000000100000005000000315EF3AACE484340CF842689256D4B40315EF3AACE484340E06932E36D6D4B408CBCAC89054A4340E06932E36D6D4B408CBCAC89054A4340CF842689256D4B40315EF3AACE484340CF842689256D4B40
52586	Емельяновка	1	10	1241	38.525491000000002	38.546008	54.821047999999998	54.809427999999997	0103000020E61000000100000005000000D2AB014A43434340BC3B32569B674B40D2AB014A434343401D39D21918694B405CAD1397E34543401D39D21918694B405CAD1397E3454340BC3B32569B674B40D2AB014A43434340BC3B32569B674B40
24142	Бояркино	1	10	1241	38.504505999999999	38.535713000000001	54.962043999999999	54.949703999999997	0103000020E61000000100000005000000615111A793404340B07092E68F794B40615111A79340434011A8FE41247B4B4062855B3E9244434011A8FE41247B4B4062855B3E92444340B07092E68F794B40615111A793404340B07092E68F794B40
24203	Белые Колодези	1	10	1241	38.676389999999998	38.709052	54.926358	54.911574000000002	0103000020E61000000100000005000000B4AB90F29356434024F1F274AE744B40B4AB90F293564340A93121E692764B40EA944737C25A4340A93121E692764B40EA944737C25A434024F1F274AE744B40B4AB90F29356434024F1F274AE744B40
62006	коттеджный поселок Ромашково	1	10	108	37.311785999999998	37.325952000000001	55.729671000000003	55.721649999999997	0103000020E61000000100000005000000E2AC889AE8A742404694F6065FDC4B40E2AC889AE8A7424079EBFCDB65DD4B406C088ECBB8A9424079EBFCDB65DD4B406C088ECBB8A942404694F6065FDC4B40E2AC889AE8A742404694F6065FDC4B40
59420	Юдино	1	10	108	37.169547000000001	37.192174999999999	55.667085999999998	55.653528000000001	0103000020E61000000100000005000000451152B7B3954240998235CEA6D34B40451152B7B39542404ACFF41263D54B40ED0DBE30999842404ACFF41263D54B40ED0DBE3099984240998235CEA6D34B40451152B7B3954240998235CEA6D34B40
23010	Часцы	1	10	108	36.839936999999999	36.884825999999997	55.626787	55.610442999999997	0103000020E61000000100000005000000A5D93C0E836B42403B8908FF22CE4B40A5D93C0E836B42406B47718E3AD04B40435376FA417142406B47718E3AD04B40435376FA417142403B8908FF22CE4B40A5D93C0E836B42403B8908FF22CE4B40
22630	Хлюпино	1	10	108	36.959907000000001	36.971854	55.667442000000001	55.658529999999999	0103000020E61000000100000005000000CA198A3BDE7A4240AAB706B64AD44B40CA198A3BDE7A424009FD4CBD6ED54B404F3E3DB6657C424009FD4CBD6ED54B404F3E3DB6657C4240AAB706B64AD44B40CA198A3BDE7A4240AAB706B64AD44B40
49520	Успенское	1	10	108	37.058982	37.078943000000002	55.722735	55.709490000000002	0103000020E61000000100000005000000BE86E0B88C874240666B7D91D0DA4B40BE86E0B88C87424058569A9482DC4B40C39FE1CD1A8A424058569A9482DC4B40C39FE1CD1A8A4240666B7D91D0DA4B40BE86E0B88C874240666B7D91D0DA4B40
59234	Усово	1	10	108	37.197465999999999	37.216951000000002	55.740617999999998	55.727961999999998	0103000020E610000001000000050000003509DE9046994240895DDBDB2DDD4B403509DE90469942401A6A1492CCDE4B40D1EAE40CC59B42401A6A1492CCDE4B40D1EAE40CC59B4240895DDBDB2DDD4B403509DE9046994240895DDBDB2DDD4B40
53053	Старый Городок	1	10	108	36.683208	36.702153000000003	55.608739	55.593221999999997	0103000020E61000000100000005000000CB2E185C7357424044A2D0B2EECB4B40CB2E185C735742405E66D828EBCD4B40E7E44526E05942405E66D828EBCD4B40E7E44526E059424044A2D0B2EECB4B40CB2E185C7357424044A2D0B2EECB4B40
61897	Саввинская Слобода	1	10	108	36.784421000000002	36.814109999999999	55.731347999999997	55.718800999999999	0103000020E61000000100000005000000D7A546E86764424082AAD1AB01DC4B40D7A546E8676442405CFFAECF9CDD4B405CACA8C1346842405CFFAECF9CDD4B405CACA8C13468424082AAD1AB01DC4B40D7A546E86764424082AAD1AB01DC4B40
60224	Покровское	1	10	108	36.821575000000003	36.845964000000002	55.653247999999998	55.641793	0103000020E61000000100000005000000091B9E5E296942409FE6E44526D24B40091B9E5E29694240B51666A19DD34B40F3CB608C486C4240B51666A19DD34B40F3CB608C486C42409FE6E44526D24B40091B9E5E296942409FE6E44526D24B40
22475	Перхушково	1	10	108	37.121963000000001	37.162512999999997	55.659820000000003	55.650058000000001	0103000020E610000001000000050000003929CC7B9C8F42406840BD1935D34B403929CC7B9C8F4240959F54FB74D44B406116DA39CD944240959F54FB74D44B406116DA39CD9442406840BD1935D34B403929CC7B9C8F42406840BD1935D34B40
1096	Одинцово	1	10	108	37.190567000000001	37.356997999999997	55.706451999999999	55.648057000000001	0103000020E610000001000000050000003259DC7F64984240D1782288F3D24B403259DC7F64984240CE18E6046DDA4B40635E471CB2AD4240CE18E6046DDA4B40635E471CB2AD4240D1782288F3D24B403259DC7F64984240D1782288F3D24B40
60258	Новый Городок	1	10	108	36.608548999999996	36.655952999999997	55.622456	55.600323000000003	0103000020E61000000100000005000000BA8102EFE44D4240B0045262D7CC4B40BA8102EFE44D4240789961A3ACCF4B40465B9544F6534240789961A3ACCF4B40465B9544F6534240B0045262D7CC4B40BA8102EFE44D4240B0045262D7CC4B40
61893	Новоивановское	1	10	108	37.345500000000001	37.392913	55.714972000000003	55.697147999999999	0103000020E610000001000000050000004E62105839AC4240643C4A253CD94B404E62105839AC424022C7D63384DB4B402D9622F94AB2424022C7D63384DB4B402D9622F94AB24240643C4A253CD94B404E62105839AC4240643C4A253CD94B40
21669	Новоивановское	1	10	108	37.345500000000001	37.392913	55.714972000000003	55.697147999999999	0103000020E610000001000000050000004E62105839AC4240643C4A253CD94B404E62105839AC424022C7D63384DB4B402D9622F94AB2424022C7D63384DB4B402D9622F94AB24240643C4A253CD94B404E62105839AC4240643C4A253CD94B40
1576	Немчиновка	1	10	108	37.334108999999998	37.384469000000003	55.730111999999998	55.706487000000003	0103000020E610000001000000050000004E266E15C4AA42404B06802A6EDA4B404E266E15C4AA424065355D4F74DD4B40B5A9BA4736B1424065355D4F74DD4B40B5A9BA4736B142404B06802A6EDA4B404E266E15C4AA42404B06802A6EDA4B40
40459	Назарьево	1	10	108	37.032167000000001	37.046064000000001	55.676488999999997	55.672001000000002	0103000020E6100000010000000500000056815A0C1E8442408DF0F62004D64B4056815A0C1E844240478D093197D64B40F0C2D66CE5854240478D093197D64B40F0C2D66CE58542408DF0F62004D64B4056815A0C1E8442408DF0F62004D64B40
20282	Малые Вяземы	1	10	108	37.011201	37.048112000000003	55.643113999999997	55.622903999999998	0103000020E610000001000000050000005C57CC086F81424017467A51BBCF4B405C57CC086F814240C4CC3E8F51D24B40C845B58828864240C4CC3E8F51D24B40C845B5882886424017467A51BBCF4B405C57CC086F81424017467A51BBCF4B40
22571	Летний Отдых	1	10	108	36.951445	36.979104	55.643886000000002	55.629598000000001	0103000020E61000000100000005000000AB7823F3C879424042D0D1AA96D04B40AB7823F3C8794240172D40DB6AD24B40FFB0A547537D4240172D40DB6AD24B40FFB0A547537D424042D0D1AA96D04B40AB7823F3C879424042D0D1AA96D04B40
21381	Лесной городок	1	10	108	37.186579000000002	37.225636999999999	55.648589999999999	55.622979999999998	0103000020E61000000100000005000000698F17D2E1974240F20703CFBDCF4B40698F17D2E19742409E4143FF04D34B403FE257ACE19C42409E4143FF04D34B403FE257ACE19C4240F20703CFBDCF4B40698F17D2E1974240F20703CFBDCF4B40
61938	Лесной городок	1	10	108	37.186579000000002	37.225636999999999	55.648589999999999	55.622979999999998	0103000020E61000000100000005000000698F17D2E1974240F20703CFBDCF4B40698F17D2E19742409E4143FF04D34B403FE257ACE19C42409E4143FF04D34B403FE257ACE19C4240F20703CFBDCF4B40698F17D2E1974240F20703CFBDCF4B40
20908	Кубинка	1	10	108	36.672347000000002	36.736674999999998	55.599311	55.546638000000002	0103000020E6100000010000000500000028486C770F5642401C60E63BF8C54B4028486C770F56424008910C39B6CC4B40F163CC5D4B5E424008910C39B6CC4B40F163CC5D4B5E42401C60E63BF8C54B4028486C770F5642401C60E63BF8C54B40
22251	Каринское	1	10	108	36.675797000000003	36.701965000000001	55.717553000000002	55.705458	0103000020E6100000010000000500000012DE1E8480564240CD599F724CDA4B4012DE1E8480564240C712D6C6D8DB4B40E4F736FDD9594240C712D6C6D8DB4B40E4F736FDD9594240CD599F724CDA4B4012DE1E8480564240CD599F724CDA4B40
61904	Заречье	1	10	108	37.379733999999999	37.409827999999997	55.697341000000002	55.678438	0103000020E61000000100000005000000F296AB1F9BB042408C2E6F0ED7D64B40F296AB1F9BB0424079944A7842D94B40177E703E75B4424079944A7842D94B40177E703E75B442408C2E6F0ED7D64B40F296AB1F9BB042408C2E6F0ED7D64B40
49174	Жуковка	1	10	108	37.235985999999997	37.270381999999998	55.744717999999999	55.731769	0103000020E610000001000000050000002C280CCA349E4240029D499BAADD4B402C280CCA349E42400B5F5FEB52DF4B40AAB69BE09BA242400B5F5FEB52DF4B40AAB69BE09BA24240029D499BAADD4B402C280CCA349E4240029D499BAADD4B40
22339	Жаворонки	1	10	108	37.056431000000003	37.131340999999999	55.658290999999998	55.631853999999997	0103000020E6100000010000000500000084BD89213987424063EC8497E0D04B4084BD892139874240252026E142D44B40DDCF29C8CF904240252026E142D44B40DDCF29C8CF90424063EC8497E0D04B4084BD89213987424063EC8497E0D04B40
22093	Ершово	1	10	108	36.845021000000003	36.871080999999997	55.775174999999997	55.754902000000001	0103000020E6100000010000000500000074B7EBA5296C4240AED7F4A0A0E04B4074B7EBA5296C4240A1D634EF38E34B405F950B957F6F4240A1D634EF38E34B405F950B957F6F4240AED7F4A0A0E04B4074B7EBA5296C4240AED7F4A0A0E04B40
49025	Дубки	1	10	108	36.502735999999999	36.51746	55.573560999999998	55.566822000000002	0103000020E61000000100000005000000CC423BA759404240A053909F8DC84B40CC423BA7594042406AA164726AC94B407C7E18213C4242406AA164726AC94B407C7E18213C424240A053909F8DC84B40CC423BA759404240A053909F8DC84B40
59549	Горки-23	1	10	108	36.383924999999998	37.417706000000003	55.848165000000002	55.492241999999997	0103000020E61000000100000005000000F38E537424314240DBDB2DC901BF4B40F38E537424314240514EB4AB90EC4B40E7ABE46377B54240514EB4AB90EC4B40E7ABE46377B54240DBDB2DC901BF4B40F38E537424314240DBDB2DC901BF4B40
22855	Горки-10	1	10	108	37.009278000000002	37.042264000000003	55.714125000000003	55.697868999999997	0103000020E61000000100000005000000414981053081424034F279C553D94B404149810530814240C520B07268DB4B402AE620E868854240C520B07268DB4B402AE620E86885424034F279C553D94B40414981053081424034F279C553D94B40
61967	Горбольницы № 45	1	10	108	36.907409000000001	36.938265999999999	55.718912000000003	55.711503	0103000020E610000001000000050000004C8C65FA25744240C100C28712DB4B404C8C65FA25744240DA59F44E05DC4B407079AC1919784240DA59F44E05DC4B407079AC1919784240C100C28712DB4B404C8C65FA25744240C100C28712DB4B40
152	Голицыно	1	10	108	36.953574000000003	37.008515000000003	55.635497999999998	55.601278999999998	0103000020E6100000010000000500000070287CB60E7A4240C362D4B5F6CC4B4070287CB60E7A424032569BFF57D14B404243FF041781424032569BFF57D14B404243FF0417814240C362D4B5F6CC4B4070287CB60E7A4240C362D4B5F6CC4B40
20810	Гигирево	1	10	108	36.685175000000001	36.694122	55.697122999999998	55.692135	0103000020E61000000100000005000000B6847CD0B35742405FB532E197D84B40B6847CD0B35742400B2593533BD94B4091B75CFDD85842400B2593533BD94B4091B75CFDD85842405FB532E197D84B40B6847CD0B35742405FB532E197D84B40
23054	Гарь-Покровское	1	10	108	36.800662000000003	36.823677000000004	55.615568000000003	55.605677999999997	0103000020E610000001000000050000003293A8177C6642400EF450DB86CD4B403293A8177C664240693BA6EECACE4B40D4BB783F6E694240693BA6EECACE4B40D4BB783F6E6942400EF450DB86CD4B403293A8177C6642400EF450DB86CD4B40
48771	Введенское	1	10	108	36.880432999999996	36.897618000000001	55.700460999999997	55.690170999999999	0103000020E61000000100000005000000DAA84E07B2704240E5D2F88557D84B40DAA84E07B2704240CD8FBFB4A8D94B4085268925E5724240CD8FBFB4A8D94B4085268925E5724240E5D2F88557D84B40DAA84E07B2704240E5D2F88557D84B40
62064	ВНИИССОК	1	10	108	37.190567000000001	37.230147000000002	55.661262000000001	55.650404000000002	0103000020E610000001000000050000003259DC7F649842400398327040D34B403259DC7F64984240350BB43BA4D44B40E222F774759D4240350BB43BA4D44B40E222F774759D42400398327040D34B403259DC7F649842400398327040D34B40
20319	Большие Вяземы	1	10	108	36.974972000000001	37.019573000000001	55.648133000000001	55.619456999999997	0103000020E610000001000000050000000342EBE1CB7C42409E23F25D4ACF4B400342EBE1CB7C4240AC3AAB05F6D24B403B71395E81824240AC3AAB05F6D24B403B71395E818242409E23F25D4ACF4B400342EBE1CB7C42409E23F25D4ACF4B40
21838	Барвиха	1	10	108	37.264282999999999	37.297494	55.729061999999999	55.717396000000001	0103000020E61000000100000005000000C3F17C06D4A14240FF23D3A1D3DB4B40C3F17C06D4A14240D06053E751DD4B40CC608C4814A64240D06053E751DD4B40CC608C4814A64240FF23D3A1D3DB4B40C3F17C06D4A14240FF23D3A1D3DB4B40
16961	имени Воровского	1	10	152	38.248593999999997	38.370207999999998	55.746426	55.704447999999999	0103000020E61000000100000005000000ACFD9DEDD11F4340C6DD205A2BDA4B40ACFD9DEDD11F43402A711DE38ADF4B40D95BCAF9622F43402A711DE38ADF4B40D95BCAF9622F4340C6DD205A2BDA4B40ACFD9DEDD11F4340C6DD205A2BDA4B40
18299	Ямкино	1	10	152	38.385147000000003	38.421393999999999	55.940784999999998	55.914175999999998	0103000020E610000001000000050000008693347F4C314340E0641BB803F54B408693347F4C3143409FC893A46BF84B40855D143DF03543409FC893A46BF84B40855D143DF0354340E0641BB803F54B408693347F4C314340E0641BB803F54B40
15982	Электроугли	1	10	152	38.114224	38.234850000000002	55.778359999999999	55.703378000000001	0103000020E610000001000000050000008B355CE49E0E4340EA5C514A08DA4B408B355CE49E0E4340DD41EC4CA1E34B4099BB96900F1E4340DD41EC4CA1E34B4099BB96900F1E4340EA5C514A08DA4B408B355CE49E0E4340EA5C514A08DA4B40
61916	Фрязино	1	10	152	38.051853999999999	38.646816999999999	56.080758000000003	55.674081999999999	0103000020E610000001000000050000005915E126A30643404069A85148D64B405915E126A3064340F8713447560A4C4098BF42E6CA524340F8713447560A4C4098BF42E6CA5243404069A85148D64B405915E126A30643404069A85148D64B40
17999	Фрязево	1	10	152	38.458297000000002	38.477879999999999	55.739037000000003	55.728966	0103000020E610000001000000050000006E6DE179A93A4340AEF204C24EDD4B406E6DE179A93A434059C4B0C398DE4B40CCB4FD2B2B3D434059C4B0C398DE4B40CCB4FD2B2B3D4340AEF204C24EDD4B406E6DE179A93A4340AEF204C24EDD4B40
47555	Тимохово	1	10	152	38.255231999999999	38.300049000000001	55.778725000000001	55.764268000000001	0103000020E6100000010000000500000043723271AB2043408EB0A888D3E14B4043723271AB204340EFC9C342ADE34B404819710168264340EFC9C342ADE34B4048197101682643408EB0A888D3E14B4043723271AB2043408EB0A888D3E14B40
62024	Тимково	1	10	152	38.605477	38.638418000000001	55.937669	55.926231999999999	0103000020E6100000010000000500000077BD3445804D43401C412AC58EF64B4077BD3445804D43408CBCAC8905F84B40C09657AEB75143408CBCAC8905F84B40C09657AEB75143401C412AC58EF64B4077BD3445804D43401C412AC58EF64B40
17900	Стромынь	1	10	152	38.470792000000003	38.492908999999997	56.048772	56.035677999999997	0103000020E61000000100000005000000F69B89E9423C4340E597C11891044C40F69B89E9423C4340F27A30293E064C40B87361A4173F4340F27A30293E064C40B87361A4173F4340E597C11891044C40F69B89E9423C4340E597C11891044C40
17156	Старые Псарьки	1	10	152	38.330987	38.354343999999998	55.825623	55.818989000000002	0103000020E61000000100000005000000593332C85D2A43405264ADA1D4E84B40593332C85D2A4340A7E9B303AEE94B4054C4E9245B2D4340A7E9B303AEE94B4054C4E9245B2D43405264ADA1D4E84B40593332C85D2A43405264ADA1D4E84B40
402	Старая Купавна	1	10	152	38.139699999999998	38.210118999999999	55.822184999999998	55.784126000000001	0103000020E6100000010000000500000027A089B0E1114340BEF8A23D5EE44B4027A089B0E11143408121AB5B3DE94B4055A2EC2DE51A43408121AB5B3DE94B4055A2EC2DE51A4340BEF8A23D5EE44B4027A089B0E1114340BEF8A23D5EE44B40
62039	Радиоцентра	1	10	152	38.345396000000001	38.356040999999998	55.839703999999998	55.832909000000001	0103000020E61000000100000005000000A915A6EF352C4340A4C519C39CEA4B40A915A6EF352C43400229B16B7BEB4B407F8461C0922D43400229B16B7BEB4B407F8461C0922D4340A4C519C39CEA4B40A915A6EF352C4340A4C519C39CEA4B40
48099	Пятково	1	10	152	38.237319999999997	38.245458999999997	55.916168999999996	55.902914000000003	0103000020E61000000100000005000000E6577380601E4340DF8C9AAF92F34B40E6577380601E4340F44D9A0645F54B4022C154336B1F4340F44D9A0645F54B4022C154336B1F4340DF8C9AAF92F34B40E6577380601E4340DF8C9AAF92F34B40
21126	Пешково	1	10	152	38.388227999999998	38.413345	55.858038000000001	55.851762999999998	0103000020E610000001000000050000001CB28174B1314340AF78EA9106ED4B401CB28174B1314340D55C6E30D4ED4B40897B2C7DE8344340D55C6E30D4ED4B40897B2C7DE8344340AF78EA9106ED4B401CB28174B1314340AF78EA9106ED4B40
16719	Обухово	1	10	152	38.249896	38.316173999999997	55.841377000000001	55.818092999999998	0103000020E610000001000000050000005BB39597FC1F4340130B7C45B7E84B405BB39597FC1F4340A54DD53DB2EB4B4039ECBE6378284340A54DD53DB2EB4B4039ECBE6378284340130B7C45B7E84B405BB39597FC1F4340130B7C45B7E84B40
3079	Ногинск	1	10	152	38.365141000000001	38.514989	55.900011999999997	55.823656	0103000020E61000000100000005000000E1B6B6F0BC2E4340BC934F8F6DE94B40E1B6B6F0BC2E4340F700DD9733F34B405E66D828EB414340F700DD9733F34B405E66D828EB414340BC934F8F6DE94B40E1B6B6F0BC2E4340BC934F8F6DE94B40
18094	Новые Дома	1	10	152	38.453094999999998	38.468007	55.716361999999997	55.705781999999999	0103000020E61000000100000005000000957D5704FF394340800D881057DA4B40957D5704FF3943406F0C01C0B1DB4B4048A643A7E73B43406F0C01C0B1DB4B4048A643A7E73B4340800D881057DA4B40957D5704FF394340800D881057DA4B40
61900	Новостройка	1	10	152	38.051853999999999	38.646816999999999	56.080758000000003	55.674081999999999	0103000020E610000001000000050000005915E126A30643404069A85148D64B405915E126A3064340F8713447560A4C4098BF42E6CA524340F8713447560A4C4098BF42E6CA5243404069A85148D64B405915E126A30643404069A85148D64B40
15914	Молзино	1	10	152	38.366633	38.407183000000003	55.899572999999997	55.883741999999998	0103000020E61000000100000005000000335184D4ED2E4340020D36751EF14B40335184D4ED2E4340ABAE433525F34B405C3E92921E344340ABAE433525F34B405C3E92921E344340020D36751EF14B40335184D4ED2E4340020D36751EF14B40
17660	Мамонтово	1	10	152	38.544023000000003	38.567414999999997	55.956556999999997	55.942312000000001	0103000020E61000000100000005000000CBA2B08BA24543406E50FBAD9DF84B40CBA2B08BA245434043E1B37570FA4B404221020EA148434043E1B37570FA4B404221020EA14843406E50FBAD9DF84B40CBA2B08BA24543406E50FBAD9DF84B40
17013	Кудиново	1	10	152	38.196851000000002	38.238855999999998	55.775272000000001	55.751199	0103000020E61000000100000005000000AB97DF6932194340DAE4F04927E04B40AB97DF693219434094C0E61C3CE34B40083A5AD5921E434094C0E61C3CE34B40083A5AD5921E4340DAE4F04927E04B40AB97DF6932194340DAE4F04927E04B40
17184	Колонтаево	1	10	152	38.250615000000003	38.269713000000003	55.798808999999999	55.780946999999998	0103000020E610000001000000050000008B71FE261420434064744012F6E34B408B71FE26142043400F60915F3FE64B402D27A1F4852243400F60915F3FE64B402D27A1F48522434064744012F6E34B408B71FE261420434064744012F6E34B40
59544	Караваево	1	10	152	38.573155	38.605998	55.869905000000003	55.857286000000002	0103000020E61000000100000005000000FA449E245D494340CAA8328CBBED4B40FA449E245D4943403ED00A0C59EF4B4080B8AB57914D43403ED00A0C59EF4B4080B8AB57914D4340CAA8328CBBED4B40FA449E245D494340CAA8328CBBED4B40
18189	Иванисово	1	10	152	38.453536	38.468896999999998	55.745477999999999	55.739159000000001	0103000020E6100000010000000500000082C7B7770D3A4340A4C519C39CDE4B4082C7B7770D3A434099F1B6D26BDF4B40A41820D1043C434099F1B6D26BDF4B40A41820D1043C4340A4C519C39CDE4B4082C7B7770D3A4340A4C519C39CDE4B40
47393	Зеленый	1	10	152	38.080860999999999	38.110945000000001	55.813383999999999	55.806252000000001	0103000020E61000000100000005000000CC423BA7590A4340D42AFA4333E74B40CC423BA7590A43407A8B87F71CE84B40CE531D72330E43407A8B87F71CE84B40CE531D72330E4340D42AFA4333E74B40CC423BA7590A4340D42AFA4333E74B40
17954	Есино	1	10	152	38.357982	38.390608999999998	55.719779000000003	55.711700999999998	0103000020E610000001000000050000004147AB5AD22D4340E7C3B30419DB4B404147AB5AD22D43407EACE0B721DC4B40FA42C879FF3143407EACE0B721DC4B40FA42C879FF314340E7C3B30419DB4B404147AB5AD22D4340E7C3B30419DB4B40
62040	Ельня	1	10	152	38.329146000000001	38.348945000000001	55.850473999999998	55.840992999999997	0103000020E61000000100000005000000FBCDC474212A43401C959BA8A5EB4B40FBCDC474212A4340950C0055DCEC4B40268DD13AAA2C4340950C0055DCEC4B40268DD13AAA2C43401C959BA8A5EB4B40FBCDC474212A43401C959BA8A5EB4B40
47906	Елизаветино	1	10	152	38.502332000000003	38.513300000000001	55.731627000000003	55.723506	0103000020E61000000100000005000000FDDD3B6A4C404340DA3A38D89BDC4B40FDDD3B6A4C40434070EF1AF4A5DD4B40B6847CD0B341434070EF1AF4A5DD4B40B6847CD0B3414340DA3A38D89BDC4B40FDDD3B6A4C404340DA3A38D89BDC4B40
62053	Горбуша	1	10	152	38.051853999999999	38.646816999999999	56.080758000000003	55.674081999999999	0103000020E610000001000000050000005915E126A30643404069A85148D64B405915E126A3064340F8713447560A4C4098BF42E6CA524340F8713447560A4C4098BF42E6CA5243404069A85148D64B405915E126A30643404069A85148D64B40
16279	Вишняково	1	10	152	38.151046000000001	38.184876000000003	55.749085999999998	55.736007000000001	0103000020E610000001000000050000008718AF79551343404450357A35DE4B408718AF79551343401BF2CF0CE2DF4B405CE84A04AA1743401BF2CF0CE2DF4B405CE84A04AA1743404450357A35DE4B408718AF79551343404450357A35DE4B40
17801	Боровково	1	10	152	38.532029999999999	38.549799	55.998764999999999	55.984647000000002	0103000020E61000000100000005000000D53E1D8F19444340618DB3E908FE4B40D53E1D8F19444340D9B11188D7FF4B40CF2F4AD05F464340D9B11188D7FF4B40CF2F4AD05F464340618DB3E908FE4B40D53E1D8F19444340618DB3E908FE4B40
17446	Большое Буньково	1	10	152	38.590626999999998	38.632947000000001	55.856043	55.840477	0103000020E610000001000000050000003A9160AA994B4340250516C094EB4B403A9160AA994B4340207C28D192ED4B40F88C446804514340207C28D192ED4B40F88C446804514340250516C094EB4B403A9160AA994B4340250516C094EB4B40
59519	совхоза Архангельский	1	10	260	36.396897000000003	36.415734	55.364015000000002	55.351539000000002	0103000020E61000000100000005000000B5705985CD3242406022DE3AFFAC4B40B5705985CD3242407120240B98AE4B40EAEA8EC5363542407120240B98AE4B40EAEA8EC5363542406022DE3AFFAC4B40B5705985CD3242406022DE3AFFAC4B40
49696	коттеджный поселок Лесное озеро	1	10	260	37.156979	37.164777000000001	55.529567999999998	55.525174999999997	0103000020E6100000010000000500000053944BE317944240A1D634EF38C34B4053944BE3179442400A815CE2C8C34B400611A969179542400A815CE2C8C34B400611A96917954240A1D634EF38C34B4053944BE317944240A1D634EF38C34B40
14046	Яковлевское	1	10	260	36.927360999999998	36.950349000000003	55.468891999999997	55.462023000000002	0103000020E61000000100000005000000FD4AE7C3B3764240FA7FD59123BB4B40FD4AE7C3B376424092AD2EA704BC4B40A6643909A579424092AD2EA704BC4B40A6643909A5794240FA7FD59123BB4B40FD4AE7C3B3764240FA7FD59123BB4B40
13690	Шустиково	1	10	260	35.958052000000002	35.979152999999997	55.276226000000001	55.260798000000001	0103000020E6100000010000000500000007EFAB72A1FA41405D6E30D461A14B4007EFAB72A1FA41400727A25F5BA34B40E063B0E254FD41400727A25F5BA34B40E063B0E254FD41405D6E30D461A14B4007EFAB72A1FA41405D6E30D461A14B40
49464	Шарапово	1	10	260	37.163034000000003	37.188851	55.586348999999998	55.579531000000003	0103000020E610000001000000050000006B11514CDE944240540262122ECA4B406B11514CDE9442406A85E97B0DCB4B40906802452C9842406A85E97B0DCB4B40906802452C984240540262122ECA4B406B11514CDE944240540262122ECA4B40
13781	Устье	1	10	260	36.325758999999998	36.341622999999998	55.281512999999997	55.270431000000002	0103000020E6100000010000000500000057B08D78B22942408C69A67B9DA24B4057B08D78B22942400D33349E08A44B40DC476E4DBA2B42400D33349E08A44B40DC476E4DBA2B42408C69A67B9DA24B4057B08D78B22942408C69A67B9DA24B40
14268	Таширово	1	10	260	36.645145999999997	36.684798000000001	55.434196	55.415706999999998	0103000020E610000001000000050000009692E52494524240F0DB10E335B54B409692E52494524240EA060ABC93B74B40E02EFB75A7574240EA060ABC93B74B40E02EFB75A7574240F0DB10E335B54B409692E52494524240F0DB10E335B54B40
13327	Софьино	1	10	260	36.998229000000002	37.022042999999996	55.52384	55.506698999999998	0103000020E610000001000000050000009B75C6F7C57F42403CF54883DBC04B409B75C6F7C57F4240172B6A300DC34B40880D164ED2824240172B6A300DC34B40880D164ED28242403CF54883DBC04B409B75C6F7C57F42403CF54883DBC04B40
13939	Совхоза Крекшино	1	10	260	37.094959000000003	37.125591999999997	55.594788999999999	55.576726999999998	0103000020E61000000100000005000000FEBAD39D278C42402FDCB930D2C94B40FEBAD39D278C4240A182C30B22CC4B40D2510E6613904240A182C30B22CC4B40D2510E66139042402FDCB930D2C94B40FEBAD39D278C42402FDCB930D2C94B40
12454	Симбухово	1	10	260	36.296151000000002	36.325651000000001	55.390588000000001	55.379404000000001	0103000020E61000000100000005000000BFD6A546E82542405DFC6D4F90B04B40BFD6A546E8254240E31A9FC9FEB14B40717495EEAE294240E31A9FC9FEB14B40717495EEAE2942405DFC6D4F90B04B40BFD6A546E82542405DFC6D4F90B04B40
60222	Селятино	1	10	260	36.963203999999998	36.992992000000001	55.523722999999997	55.505209999999998	0103000020E610000001000000050000002DB0C7444A7B42405BCEA5B8AAC04B402DB0C7444A7B4240DD94F25A09C34B404698A25C1A7F4240DD94F25A09C34B404698A25C1A7F42405BCEA5B8AAC04B402DB0C7444A7B42405BCEA5B8AAC04B40
13133	Селятино	1	10	260	36.963203999999998	36.992992000000001	55.523722999999997	55.505209999999998	0103000020E610000001000000050000002DB0C7444A7B42405BCEA5B8AAC04B402DB0C7444A7B4240DD94F25A09C34B404698A25C1A7F4240DD94F25A09C34B404698A25C1A7F42405BCEA5B8AAC04B402DB0C7444A7B42405BCEA5B8AAC04B40
12509	Рождествено	1	10	260	36.163811000000003	36.179594000000002	55.385029000000003	55.373899999999999	0103000020E61000000100000005000000CFDC43C2F7144240B9FC87F4DBAF4B40CFDC43C2F71442407C8159A148B14B406747AAEFFC1642407C8159A148B14B406747AAEFFC164240B9FC87F4DBAF4B40CFDC43C2F7144240B9FC87F4DBAF4B40
62042	Рассудово	1	10	260	36.911163999999999	36.935814000000001	55.485264999999998	55.475250000000003	0103000020E6100000010000000500000072A59E05A174424046B6F3FDD4BC4B4072A59E05A17442405C72DC291DBE4B40C991CEC0C87742405C72DC291DBE4B40C991CEC0C877424046B6F3FDD4BC4B4072A59E05A174424046B6F3FDD4BC4B40
14117	Птичное	1	10	260	37.209755000000001	37.239966000000003	55.528111000000003	55.509503000000002	0103000020E6100000010000000500000014967840D99A4240611BF16437C14B4014967840D99A424035D4282499C34B407313B534B79E424035D4282499C34B407313B534B79E4240611BF16437C14B4014967840D99A4240611BF16437C14B40
12582	Пионерский	1	10	260	36.154108999999998	36.168329	55.340491	55.323366999999998	0103000020E610000001000000050000007782FDD7B913424085CD001764A94B407782FDD7B91342408ACA863595AB4B40F4FBFECD8B1542408ACA863595AB4B40F4FBFECD8B15424085CD001764A94B407782FDD7B913424085CD001764A94B40
14104	Первомайское	1	10	260	37.151823	37.180461000000001	55.543627999999998	55.531131999999999	0103000020E61000000100000005000000EBE3A1EF6E934240F6ED2422FCC34B40EBE3A1EF6E9342404E98309A95C54B400B9A9658199742404E98309A95C54B400B9A965819974240F6ED2422FCC34B40EBE3A1EF6E934240F6ED2422FCC34B40
13518	Новая Ольховка	1	10	260	36.633315000000003	36.656294000000003	55.315668000000002	55.291863999999997	0103000020E610000001000000050000007B884677105142409B70AFCC5BA54B407B8846771051424066321CCF67A84B40D04719710154424066321CCF67A84B40D0471971015442409B70AFCC5BA54B407B884677105142409B70AFCC5BA54B40
1095	Наро-Фоминск	1	10	260	36.674799	36.779893000000001	55.423707999999998	55.357925999999999	0103000020E61000000100000005000000CF2F4AD05F564240AD31E884D0AD4B40CF2F4AD05F564240DB8651103CB64B408EB0A888D3634240DB8651103CB64B408EB0A888D3634240AD31E884D0AD4B40CF2F4AD05F564240AD31E884D0AD4B40
40475	Назарьево	1	10	260	36.389575000000001	36.414306000000003	55.378641000000002	55.367002999999997	0103000020E610000001000000050000006B2BF697DD31424056444DF4F9AE4B406B2BF697DD3142405EF6EB4E77B04B40AF44A0FA073542405EF6EB4E77B04B40AF44A0FA0735424056444DF4F9AE4B406B2BF697DD31424056444DF4F9AE4B40
13891	Марушкино	1	10	260	37.191313000000001	37.222259999999999	55.602581000000001	55.587803999999998	0103000020E610000001000000050000005B26C3F17C9842409F3A56293DCB4B405B26C3F17C9842407218CC5F21CD4B40BF9A0304739C42407218CC5F21CD4B40BF9A0304739C42409F3A56293DCB4B405B26C3F17C9842409F3A56293DCB4B40
61989	Мартемьяново	1	10	260	37.054130999999998	37.082256999999998	55.527244000000003	55.517367999999998	0103000020E610000001000000050000009259BDC3ED8642409BFF571D39C24B409259BDC3ED86424091813CBB7CC34B40FC6EBA65878A424091813CBB7CC34B40FC6EBA65878A42409BFF571D39C24B409259BDC3ED8642409BFF571D39C24B40
14389	Любаново	1	10	260	36.60942	36.619498999999998	55.452981999999999	55.443418999999999	0103000020E61000000100000005000000A0C37C79014E424067B62BF4C1B84B40A0C37C79014E42409DD66D50FBB94B40CD7344BE4B4F42409DD66D50FBB94B40CD7344BE4B4F424067B62BF4C1B84B40A0C37C79014E424067B62BF4C1B84B40
4480	Крюково	1	10	260	35.912229000000004	35.937452999999998	55.271523000000002	55.258602000000003	0103000020E610000001000000050000003DBB7CEBC3F441401157CEDE19A14B403DBB7CEBC3F44140508E0244C1A24B40BF44BC75FEF74140508E0244C1A24B40BF44BC75FEF741401157CEDE19A14B403DBB7CEBC3F441401157CEDE19A14B40
13041	Кокошкино	1	10	260	37.152092000000003	37.193576999999998	55.61298	55.586461	0103000020E61000000100000005000000DBFD2AC07793424092B06F2711CB4B40DBFD2AC077934240118DEE2076CE4B40FF209221C7984240118DEE2076CE4B40FF209221C798424092B06F2711CB4B40DBFD2AC07793424092B06F2711CB4B40
61923	Кокошкино	1	10	260	37.152092000000003	37.193576999999998	55.61298	55.586461	0103000020E61000000100000005000000DBFD2AC07793424092B06F2711CB4B40DBFD2AC077934240118DEE2076CE4B40FF209221C7984240118DEE2076CE4B40FF209221C798424092B06F2711CB4B40DBFD2AC07793424092B06F2711CB4B40
28906	Ковригино	1	10	260	36.198306000000002	36.211483999999999	55.327567000000002	55.318213999999998	0103000020E61000000100000005000000E04C4C17621942408E90813CBBA84B40E04C4C1762194240DA1F28B7EDA94B404AD05FE8111B4240DA1F28B7EDA94B404AD05FE8111B42408E90813CBBA84B40E04C4C17621942408E90813CBBA84B40
12922	Киевский	1	10	260	36.861164000000002	36.873049000000002	55.434849999999997	55.426447000000003	0103000020E610000001000000050000000C3F389F3A6E4240193DB7D095B64B400C3F389F3A6E42403255302AA9B74B401B67D311C06F42403255302AA9B74B401B67D311C06F4240193DB7D095B64B400C3F389F3A6E4240193DB7D095B64B40
13569	Каменское	1	10	260	36.801775999999997	36.840879999999999	55.276564999999998	55.262255000000003	0103000020E61000000100000005000000DD5B9198A0664240331B649291A14B40DD5B9198A0664240EF1B5F7B66A34B4024EEB1F4A16B4240EF1B5F7B66A34B4024EEB1F4A16B4240331B649291A14B40DD5B9198A0664240331B649291A14B40
12600	Калининец	1	10	260	36.963265999999997	36.998156999999999	55.570735999999997	55.521807000000003	0103000020E61000000100000005000000A3ACDF4C4C7B424075E95F92CAC24B40A3ACDF4C4C7B42402E5393E00DC94B4001A3CB9BC37F42402E5393E00DC94B4001A3CB9BC37F424075E95F92CAC24B40A3ACDF4C4C7B424075E95F92CAC24B40
59527	Ильичёвка	1	10	260	37.268720999999999	37.278376999999999	55.511200000000002	55.503543000000001	0103000020E61000000100000005000000CC5F217365A242409B90D61874C04B40CC5F217365A242408CDB68006FC14B40B37A87DBA1A342408CDB68006FC14B40B37A87DBA1A342409B90D61874C04B40CC5F217365A242409B90D61874C04B40
11319	Ивановка	1	10	260	36.791103999999997	36.808190000000003	55.378349999999998	55.372287999999998	0103000020E610000001000000050000000DDE57E542654240BC581822A7AF4B400DDE57E5426542408638D6C56DB04B40257A19C5726742408638D6C56DB04B40257A19C572674240BC581822A7AF4B400DDE57E542654240BC581822A7AF4B40
28167	Десна	1	10	260	37.188473999999999	37.207580999999998	55.503914999999999	55.497725000000003	0103000020E61000000100000005000000BA1281EA1F98424068B3EA73B5BF4B40BA1281EA1F9842405F7B664980C04B40AF22A303929A42405F7B664980C04B40AF22A303929A424068B3EA73B5BF4B40BA1281EA1F98424068B3EA73B5BF4B40
14400	Головково	1	10	260	36.504325999999999	36.526648999999999	55.495466	55.484147999999998	0103000020E61000000100000005000000E1421EC18D4042403F36C98FF8BD4B40E1421EC18D404240D5230D6E6BBF4B404DBC033C69434240D5230D6E6BBF4B404DBC033C694342403F36C98FF8BD4B40E1421EC18D4042403F36C98FF8BD4B40
59560	Восток (Наро-Фоминск-10)	1	10	260	36.526353	36.533673999999998	55.369228999999997	55.363948999999998	0103000020E610000001000000050000006493FC885F434240B9347EE195AE4B406493FC885F4342400DDE57E542AF4B40DD5CFC6D4F4442400DDE57E542AF4B40DD5CFC6D4F444240B9347EE195AE4B406493FC885F434240B9347EE195AE4B40
13746	Волченки	1	10	260	36.224941000000001	36.262112999999999	55.326763	55.310637	0103000020E61000000100000005000000C843DFDDCA1C4240BAF605F4C2A74B40C843DFDDCA1C42407C45B75ED3A94B40A06D35EB8C2142407C45B75ED3A94B40A06D35EB8C214240BAF605F4C2A74B40C843DFDDCA1C4240BAF605F4C2A74B40
13660	Веселево	1	10	260	36.074185999999997	36.104585	55.313952	55.296984999999999	0103000020E6100000010000000500000018E945ED7E0942408733BF9A03A64B4018E945ED7E094240C44142942FA84B407A53910A630D4240C44142942FA84B407A53910A630D42408733BF9A03A64B4018E945ED7E0942408733BF9A03A64B40
12366	Верея	1	10	260	36.159695999999997	36.213524	55.362270000000002	55.329298000000001	0103000020E61000000100000005000000A8A624EB70144240B151D66F26AA4B40A8A624EB70144240352905DD5EAE4B409F7422C1541B4240352905DD5EAE4B409F7422C1541B4240B151D66F26AA4B40A8A624EB70144240B151D66F26AA4B40
61984	Бекасово	1	10	260	36.789774999999999	36.816239000000003	55.432474999999997	55.416288999999999	0103000020E610000001000000050000006519E258176542409F573CF548B54B406519E2581765424036AB3E575BB74B40215C01857A68424036AB3E575BB74B40215C01857A6842409F573CF548B54B406519E258176542409F573CF548B54B40
58932	Балашиха	1	10	260	35.868256000000002	37.351689	55.623544000000003	55.170650000000002	0103000020E6100000010000000500000024473A0323EF4140FD87F4DBD7954B4024473A0323EF4140FBCE2F4AD0CF4B4075AE282504AD4240FBCE2F4AD0CF4B4075AE282504AD4240FD87F4DBD7954B4024473A0323EF4140FD87F4DBD7954B40
13409	Атепцево	1	10	260	36.738562000000002	36.767200000000003	55.341341	55.320231999999997	0103000020E61000000100000005000000C0081A33895E4240FB90B75CFDA84B40C0081A33895E424058E4D70FB1AB4B40E0BE0E9C3362424058E4D70FB1AB4B40E0BE0E9C33624240FB90B75CFDA84B40C0081A33895E4240FB90B75CFDA84B40
2721	Апрелевка	1	10	260	37.007427999999997	37.110239999999997	55.572803	55.524844000000002	0103000020E610000001000000050000008F899466F38042403CC093162EC34B408F899466F38042407D06D49B51C94B40035B25581C8E42407D06D49B51C94B40035B25581C8E42403CC093162EC34B408F899466F38042403CC093162EC34B40
13293	Алабино	1	10	260	36.982841000000001	37.020282999999999	55.531900999999998	55.519722999999999	0103000020E610000001000000050000007F15E0BBCD7D424050FD834886C24B407F15E0BBCD7D4240D7DAFB5415C44B4017D522A298824240D7DAFB5415C44B4017D522A29882424050FD834886C24B407F15E0BBCD7D424050FD834886C24B40
22526	Юдино	1	10	464	37.722693	37.739311999999998	56.007145999999999	55.996338999999999	0103000020E610000001000000050000002906483481DC42405B5D4E0988FF4B402906483481DC42400B26FE28EA004C402AC58EC6A1DE42400B26FE28EA004C402AC58EC6A1DE42405B5D4E0988FF4B402906483481DC42405B5D4E0988FF4B40
10414	Федоскино	1	10	464	37.566457999999997	37.584200000000003	56.055200999999997	56.048022000000003	0103000020E610000001000000050000005E471CB281C8424088BEBB9525064C405E471CB281C842406EDA8CD310074C405F29CB10C7CA42406EDA8CD310074C405F29CB10C7CA424088BEBB9525064C405E471CB281C8424088BEBB9525064C40
59366	Туристический пансионат Клязьменское водохранилище	1	10	464	37.666207	37.675280000000001	55.996927999999997	55.992260999999999	0103000020E61000000100000005000000E2AE5E4546D54240520C906802FF4B40E2AE5E4546D54240BC3B32569BFF4B404AD235936FD64240BC3B32569BFF4B404AD235936FD64240520C906802FF4B40E2AE5E4546D54240520C906802FF4B40
9806	Троицкое	1	10	464	37.562882999999999	37.583041000000001	55.988641000000001	55.982230000000001	0103000020E61000000100000005000000B83CD68C0CC8424036936FB6B9FD4B40B83CD68C0CC842400C3ECDC98BFE4B40139D6516A1CA42400C3ECDC98BFE4B40139D6516A1CA424036936FB6B9FD4B40B83CD68C0CC8424036936FB6B9FD4B40
10586	Сухарево	1	10	464	37.506711000000003	37.523429	56.085464999999999	56.069237999999999	0103000020E6100000010000000500000001C3F2E7DBC04240FAD170CADC084C4001C3F2E7DBC04240F0F96184F00A4C409563B2B8FFC24240F0F96184F00A4C409563B2B8FFC24240FAD170CADC084C4001C3F2E7DBC04240FAD170CADC084C40
9866	Поведники	1	10	464	37.596857	37.612352999999999	55.981731000000003	55.972887	0103000020E61000000100000005000000C0B167CF65CC42400EDAAB8F87FC4B40C0B167CF65CC4240153C855CA9FD4B40C24D469561CE4240153C855CA9FD4B40C24D469561CE42400EDAAB8F87FC4B40C0B167CF65CC42400EDAAB8F87FC4B40
10013	Пироговский	1	10	464	37.735062999999997	37.752265999999999	55.984873999999998	55.975152999999999	0103000020E61000000100000005000000F4BF5C8B16DE424053CC41D0D1FC4B40F4BF5C8B16DE42402157EA5910FE4B4045F295404AE042402157EA5910FE4B4045F295404AE0424053CC41D0D1FC4B40F4BF5C8B16DE424053CC41D0D1FC4B40
10103	Пирогово	1	10	464	37.723393999999999	37.740955999999997	55.990125999999997	55.977279000000003	0103000020E61000000100000005000000B20FB22C98DC4240A708707A17FD4B40B20FB22C98DC4240AB75E272BCFE4B4032E36DA5D7DE4240AB75E272BCFE4B4032E36DA5D7DE4240A708707A17FD4B40B20FB22C98DC4240A708707A17FD4B40
2720	Мытищи	1	10	464	37.662210000000002	37.813172000000002	55.961545999999998	55.878152	0103000020E61000000100000005000000C68A1A4CC3D442406075E44867F04B40C68A1A4CC3D44240C0CC77F013FB4B40EF02250516E84240C0CC77F013FB4B40EF02250516E842406075E44867F04B40C68A1A4CC3D442406075E44867F04B40
10511	Марфино	1	10	464	37.544449	37.570689000000002	56.080818999999998	56.067123000000002	0103000020E6100000010000000500000082AB3C81B0C542409BE7887C97084C4082AB3C81B0C542409DF2E846580A4C40EE974F560CC942409DF2E846580A4C40EE974F560CC942409BE7887C97084C4082AB3C81B0C542409BE7887C97084C40
10313	Манюхино	1	10	464	37.710484999999998	37.736275999999997	56.021306000000003	56.008732000000002	0103000020E6100000010000000500000037A6272CF1DA4240DF3653211E014C4037A6272CF1DA4240B39AAE27BA024C40336ABE4A3EDE4240B39AAE27BA024C40336ABE4A3EDE4240DF3653211E014C4037A6272CF1DA4240DF3653211E014C40
10364	Красная Горка	1	10	464	37.510601000000001	37.533974999999998	55.995618999999998	55.982044000000002	0103000020E610000001000000050000000727A25F5BC14240D49D279EB3FD4B400727A25F5BC142405B23827170FF4B40D8F0F44A59C442405B23827170FF4B40D8F0F44A59C44240D49D279EB3FD4B400727A25F5BC14240D49D279EB3FD4B40
10157	Здравница	1	10	464	37.727238999999997	37.741109000000002	55.963335000000001	55.956431000000002	0103000020E6100000010000000500000018B0E42A16DD4240B7F0BC546CFA4B4018B0E42A16DD4240CC0BB08F4EFB4B40B9E2E2A8DCDE4240CC0BB08F4EFB4B40B9E2E2A8DCDE4240B7F0BC546CFA4B4018B0E42A16DD4240B7F0BC546CFA4B40
10219	Жостово	1	10	464	37.638556999999999	37.663009000000002	56.017879999999998	55.997487	0103000020E61000000100000005000000E1D05B3CBCD14240B3976DA7ADFF4B40E1D05B3CBCD1424051A04FE449024C4012FA997ADDD4424051A04FE449024C4012FA997ADDD44240B3976DA7ADFF4B40E1D05B3CBCD14240B3976DA7ADFF4B40
62061	Виноградово	1	10	464	37.436678999999998	37.857323999999998	56.165337999999998	55.868445000000001	0103000020E61000000100000005000000CCECF318E5B74240F7AFAC3429EF4B40CCECF318E5B742409D64ABCB29154C40B709F7CABCED42409D64ABCB29154C40B709F7CABCED4240F7AFAC3429EF4B40CCECF318E5B74240F7AFAC3429EF4B40
9701	Вешки	1	10	464	37.604035000000003	37.616	55.929848	55.923009	0103000020E61000000100000005000000D751D50451CD4240F374AE2825F64B40D751D50451CD424021205F4205F74B40022B8716D9CE424021205F4205F74B40022B8716D9CE4240F374AE2825F64B40D751D50451CD4240F374AE2825F64B40
9644	Бородино	1	10	464	37.651403000000002	37.671435000000002	55.928117999999998	55.919670000000004	0103000020E6100000010000000500000016C26A2C61D34240618E1EBFB7F54B4016C26A2C61D342401A6A1492CCF64B40E4310395F1D542401A6A1492CCF64B40E4310395F1D54240618E1EBFB7F54B4016C26A2C61D34240618E1EBFB7F54B40
10691	Большое Ивановское	1	10	464	37.552058000000002	37.571066999999999	56.139130000000002	56.133101000000003	0103000020E6100000010000000500000062BF27D6A9C642404F081D7409114C4062BF27D6A9C642403DF20703CF114C40946934B918C942403DF20703CF114C40946934B918C942404F081D7409114C4062BF27D6A9C642404F081D7409114C40
9913	Болтино	1	10	464	37.659874000000002	37.689456	55.973818999999999	55.962457999999998	0103000020E6100000010000000500000088BD50C076D4424004E3E0D231FB4B4088BD50C076D44240999CDA19A6FC4B40F7031E1840D84240999CDA19A6FC4B40F7031E1840D8424004E3E0D231FB4B4088BD50C076D4424004E3E0D231FB4B40
9969	Беляниново	1	10	464	37.637973000000002	37.650927000000003	55.955322000000002	55.944414999999999	0103000020E61000000100000005000000925D6919A9D14240096D3997E2F84B40925D6919A9D142401D93C5FD47FA4B40AD8A709351D342401D93C5FD47FA4B40AD8A709351D34240096D3997E2F84B40925D6919A9D14240096D3997E2F84B40
10483	Аксаково	1	10	464	37.607736000000003	37.626429999999999	56.044497999999997	56.041168999999996	0103000020E610000001000000050000000A4D124BCACD4240F44D9A0645054C400A4D124BCACD4240635E471CB2054C40DC9DB5DB2ED04240635E471CB2054C40DC9DB5DB2ED04240F44D9A0645054C400A4D124BCACD4240F44D9A0645054C40
60426	Коломна	1	10	7507	38.690564999999999	38.90484	55.132747000000002	55.028032000000003	0103000020E610000001000000050000009161156F64584340E99E758D96834B409161156F6458434031D28BDAFD904B406B0E10CCD173434031D28BDAFD904B406B0E10CCD1734340E99E758D96834B409161156F64584340E99E758D96834B40
61960	сельское поселение Порецкое	1	10	670	35.257680000000001	36.268329999999999	55.820936000000003	55.229500999999999	0103000020E61000000100000005000000A96A82A8FBA041401CB3EC49609D4B40A96A82A8FBA04140F60D4C6E14E94B4091442FA358224240F60D4C6E14E94B4091442FA3582242401CB3EC49609D4B40A96A82A8FBA041401CB3EC49609D4B40
5747	имени Дзержинского	1	10	670	36.054845	36.069012000000001	55.51773	55.503833	0103000020E61000000100000005000000B0AC342905074240A2D288997DC04B40B0AC3429050742403C1405FA44C24B400A849D62D50842403C1405FA44C24B400A849D62D5084240A2D288997DC04B40B0AC342905074240A2D288997DC04B40
5350	Ямская	1	10	670	36.016827999999997	36.027670999999998	55.493879999999997	55.477072	0103000020E610000001000000050000001BD47E6B270242402DEBFEB110BD4B401BD47E6B270242400113B87537BF4B4018062CB98A0342400113B87537BF4B4018062CB98A0342402DEBFEB110BD4B401BD47E6B270242402DEBFEB110BD4B40
5872	Шохово	1	10	670	35.617761000000002	35.649991999999997	55.509461999999999	55.499678000000003	0103000020E6100000010000000500000044DFDDCA12CF4140EE43DE72F5BF4B4044DFDDCA12CF41400247020D36C14B40B05417F032D341400247020D36C14B40B05417F032D34140EE43DE72F5BF4B4044DFDDCA12CF4140EE43DE72F5BF4B40
7021	Шаликово	1	10	670	36.202896000000003	36.228471999999996	55.519365999999998	55.502012999999998	0103000020E610000001000000050000009F3E027FF81942405B9544F641C04B409F3E027FF8194240C153C8957AC24B409E060C923E1D4240C153C8957AC24B409E060C923E1D42405B9544F641C04B409F3E027FF81942405B9544F641C04B40
6532	Цветковский	1	10	670	35.395113000000002	35.416350000000001	55.532462000000002	55.522647999999997	0103000020E61000000100000005000000BB9C121093B24140EFA83121E6C24B40BB9C121093B241406F2EFEB627C44B4045D8F0F44AB541406F2EFEB627C44B4045D8F0F44AB54140EFA83121E6C24B40BB9C121093B24140EFA83121E6C24B40
5763	Уваровка	1	10	670	35.581162999999997	35.640020999999997	55.543781000000003	55.510232000000002	0103000020E610000001000000050000009752978C63CA4140B4AF3C484FC14B409752978C63CA4140D597A59D9AC54B4069E04735ECD14140D597A59D9AC54B4069E04735ECD14140B4AF3C484FC14B409752978C63CA4140B4AF3C484FC14B40
7203	Тропарево	1	10	670	35.893166000000001	35.909748999999998	55.385663999999998	55.362803	0103000020E6100000010000000500000017F3734353F2414002F2255470AE4B4017F3734353F241404D9F1D705DB14B40CB48BDA772F441404D9F1D705DB14B40CB48BDA772F4414002F2255470AE4B4017F3734353F2414002F2255470AE4B40
6379	Троица	1	10	670	35.772657000000002	35.790678	55.598832999999999	55.589534	0103000020E610000001000000050000004303B16CE6E24140A6F0A0D975CB4B404303B16CE6E24140FE614B8FA6CC4B4056D5CBEF34E54140FE614B8FA6CC4B4056D5CBEF34E54140A6F0A0D975CB4B404303B16CE6E24140A6F0A0D975CB4B40
5603	Строитель	1	10	670	36.055959000000001	36.067655000000002	55.500835000000002	55.494174999999998	0103000020E610000001000000050000005C751DAA290742401AC05B2041BF4B405C751DAA2907424099D87C5C1BC04B40983446EBA808424099D87C5C1BC04B40983446EBA80842401AC05B2041BF4B405C751DAA290742401AC05B2041BF4B40
6957	Спутник	1	10	670	36.096428000000003	36.109893999999997	55.517046999999998	55.508794000000002	0103000020E610000001000000050000009835B1C0570C424055336B2920C14B409835B1C0570C424059BF99982EC24B406803B001110E424059BF99982EC24B406803B001110E424055336B2920C14B409835B1C0570C424055336B2920C14B40
7290	Сокольниково	1	10	670	35.799911999999999	35.825415	55.355356999999998	55.333737999999997	0103000020E61000000100000005000000C7D6338463E641405AB741EDB7AA4B40C7D6338463E64140CCB392567CAD4B405D50DF32A7E94140CCB392567CAD4B405D50DF32A7E941405AB741EDB7AA4B40C7D6338463E641405AB741EDB7AA4B40
6611	Семеновское	1	10	670	35.824921000000003	35.844127	55.514763000000002	55.505153999999997	0103000020E610000001000000050000004E64E60297E94140C7B8E2E2A8C04B404E64E60297E941406E1805C1E3C14B40D655815A0CEC41406E1805C1E3C14B40D655815A0CEC4140C7B8E2E2A8C04B404E64E60297E94140C7B8E2E2A8C04B40
6829	Поречье	1	10	670	35.528882000000003	35.565658999999997	55.725884000000001	55.702921000000003	0103000020E61000000100000005000000B7B8C667B2C34140F855B950F9D94B40B7B8C667B2C34140475854C4E9DC4B4012D89C8367C84140475854C4E9DC4B4012D89C8367C84140F855B950F9D94B40B7B8C667B2C34140F855B950F9D94B40
6756	Павлищево	1	10	670	35.988791999999997	36.011752999999999	55.575358000000001	55.561472000000002	0103000020E61000000100000005000000F1457BBC90FE414053CF8250DEC74B40F1457BBC90FE4140F9BEB854A5C94B40A0504F1F81014240F9BEB854A5C94B40A0504F1F8101424053CF8250DEC74B40F1457BBC90FE414053CF8250DEC74B40
6675	Мокрое	1	10	670	35.500405000000001	35.519629000000002	55.453968000000003	55.436188000000001	0103000020E61000000100000005000000A0E062450DC041402E742502D5B74B40A0E062450DC041401CB7989F1BBA4B40CF86FC3383C241401CB7989F1BBA4B40CF86FC3383C241402E742502D5B74B40A0E062450DC041402E742502D5B74B40
4563	Можайск	1	10	670	35.978273000000002	36.064556000000003	55.522454000000003	55.483974000000003	0103000020E61000000100000005000000A8C7B60C38FD4140A20E2BDCF2BD4B40A8C7B60C38FD41400BD5CDC5DFC24B405B61FA5E430842400BD5CDC5DFC24B405B61FA5E43084240A20E2BDCF2BD4B40A8C7B60C38FD4140A20E2BDCF2BD4B40
13784	Мира	1	10	670	35.341161	35.352398999999998	55.358248000000003	55.352890000000002	0103000020E61000000100000005000000D8D5E429ABAB4140F08AE07F2BAD4B40D8D5E429ABAB4140C0ED0912DBAD4B40511212691BAD4140C0ED0912DBAD4B40511212691BAD4140F08AE07F2BAD4B40D8D5E429ABAB4140F08AE07F2BAD4B40
5438	Красный Балтиец	1	10	670	35.973233	35.986429000000001	55.491956999999999	55.482030999999999	0103000020E61000000100000005000000A93121E692FC41403F541A31B3BD4B40A93121E692FC4140E6046D72F8BE4B40BA69334E43FE4140E6046D72F8BE4B40BA69334E43FE41403F541A31B3BD4B40A93121E692FC41403F541A31B3BD4B40
5427	Колычево	1	10	670	35.993580000000001	36.018329000000001	55.475582000000003	55.464590000000001	0103000020E61000000100000005000000D7FA22A12DFF41403A0664AF77BB4B40D7FA22A12DFF41407C48F8DEDFBC4B40C1C8CB9A580242407C48F8DEDFBC4B40C1C8CB9A580242403A0664AF77BB4B40D7FA22A12DFF41403A0664AF77BB4B40
6741	Клементьево	1	10	670	36.009498000000001	36.047424999999997	55.661059000000002	55.627453000000003	0103000020E610000001000000050000004FB0FF3A370142407863416150D04B404FB0FF3A37014240FDDCD0949DD44B40A301BC0512064240FDDCD0949DD44B40A301BC05120642407863416150D04B404FB0FF3A370142407863416150D04B40
4658	Исавицы	1	10	670	35.996814000000001	36.008752999999999	55.526862000000001	55.519559000000001	0103000020E61000000100000005000000F418E59997FF4140D6ABC8E880C24B40F418E59997FF4140A9C0C93670C34B40F65E7CD11E014240A9C0C93670C34B40F65E7CD11E014240D6ABC8E880C24B40F418E59997FF4140D6ABC8E880C24B40
7131	Ивакино	1	10	670	35.602831000000002	35.628360999999998	55.331806999999998	55.319432999999997	0103000020E61000000100000005000000EB01F39029CD4140AF21382EE3A84B40EB01F39029CD4140BCCADAA678AA4B407A8A1C226ED04140BCCADAA678AA4B407A8A1C226ED04140AF21382EE3A84B40EB01F39029CD4140AF21382EE3A84B40
6598	Дровнино	1	10	670	35.367876000000003	35.382311999999999	55.539349999999999	55.528207000000002	0103000020E61000000100000005000000DD7D8E8F16AF4140574277499CC34B40DD7D8E8F16AF41407E8CB96B09C54B40266F8099EFB041407E8CB96B09C54B40266F8099EFB04140574277499CC34B40DD7D8E8F16AF4140574277499CC34B40
6185	Горки	1	10	670	35.833382999999998	35.854117000000002	55.535738000000002	55.528619999999997	0103000020E610000001000000050000006C054D4BACEA41407901F6D1A9C34B406C054D4BACEA4140BB9C121093C44B4094FAB2B453ED4140BB9C121093C44B4094FAB2B453ED41407901F6D1A9C34B406C054D4BACEA41407901F6D1A9C34B40
6429	Горетово	1	10	670	35.792636000000002	35.828488	55.616396999999999	55.602305999999999	0103000020E61000000100000005000000EED0B01875E54140A017EE5C18CD4B40EED0B01875E541401F2DCE18E6CE4B40719010E50BEA41401F2DCE18E6CE4B40719010E50BEA4140A017EE5C18CD4B40EED0B01875E54140A017EE5C18CD4B40
6178	Бородинское Поле	1	10	670	35.895429999999998	35.917617999999997	55.518596000000002	55.512408000000001	0103000020E61000000100000005000000BBED42739DF24140B91AD99596C14B40BBED42739DF2414010EB8D5A61C24B40471CB28174F5414010EB8D5A61C24B40471CB28174F54140B91AD99596C14B40BBED42739DF24140B91AD99596C14B40
62044	Бородино	1	10	670	35.796039999999998	35.826044000000003	55.530662999999997	55.518554999999999	0103000020E61000000100000005000000672783A3E4E54140B1169F0260C24B40672783A3E4E541403F19E3C3ECC34B404D874ECFBBE941403F19E3C3ECC34B404D874ECFBBE94140B1169F0260C24B40672783A3E4E54140B1169F0260C24B40
5947	Борисово	1	10	670	36.034982999999997	36.076791	55.427897999999999	55.410590999999997	0103000020E610000001000000050000003E75AC527A0442401684F23E8EB44B403E75AC527A0442400C03965CC5B64B4046D09849D40942400C03965CC5B64B4046D09849D40942401684F23E8EB44B403E75AC527A0442401684F23E8EB44B40
7033	Большое Тесово	1	10	670	36.077500999999998	36.101548999999999	55.569611000000002	55.559806999999999	0103000020E610000001000000050000002234828DEB09424033897AC1A7C74B402234828DEB0942408F386403E9C84B4083F8C08EFF0C42408F386403E9C84B4083F8C08EFF0C424033897AC1A7C74B402234828DEB09424033897AC1A7C74B40
8087	Барыши	1	10	670	35.348571999999997	35.359341999999998	55.516134000000001	55.512368000000002	0103000020E610000001000000050000009126DE019EAC41402BC24D4695C14B409126DE019EAC4140452DCDAD10C24B40240A2DEBFEAD4140452DCDAD10C24B40240A2DEBFEAD41402BC24D4695C14B409126DE019EAC41402BC24D4695C14B40
6869	Астафьево	1	10	670	35.430067000000001	35.456172000000002	55.733649999999997	55.723267999999997	0103000020E610000001000000050000005F0B7A6F0CB74140251FBB0B94DC4B405F0B7A6F0CB74140EE5A423EE8DD4B40EBAC16D863BA4140EE5A423EE8DD4B40EBAC16D863BA4140251FBB0B94DC4B405F0B7A6F0CB74140251FBB0B94DC4B40
6112	Андреевское	1	10	670	35.984830000000002	36.004413999999997	55.393906000000001	55.385392000000003	0103000020E61000000100000005000000520FD1E80EFE4140ED116A8654B14B40520FD1E80EFE41405ED905836BB24B4080D250A3900042405ED905836BB24B4080D250A390004240ED116A8654B14B40520FD1E80EFE4140ED116A8654B14B40
6297	Александрово	1	10	670	36.106848999999997	36.117511999999998	55.521307999999998	55.515925000000003	0103000020E610000001000000050000001E4E603AAD0D42402B1895D409C24B401E4E603AAD0D424053927538BAC24B409B711AA20A0F424053927538BAC24B409B711AA20A0F42402B1895D409C24B401E4E603AAD0D42402B1895D409C24B40
62022	поселение Малаховка	1	10	227	37.963298000000002	38.052743	55.665562999999999	55.614195000000002	0103000020E61000000100000005000000AF264F594DFB4240F12E17F19DCE4B40AF264F594DFB4240BD361B2B31D54B40E50B5A48C0064340BD361B2B31D54B40E50B5A48C0064340F12E17F19DCE4B40AF264F594DFB4240F12E17F19DCE4B40
3237	Томилино	1	10	227	37.903111000000003	37.970637000000004	55.672372000000003	55.616777999999996	0103000020E6100000010000000500000035D4282499F342403672DD94F2CE4B4035D4282499F34240815F234910D64B40CFA44DD53DFC4240815F234910D64B40CFA44DD53DFC42403672DD94F2CE4B4035D4282499F342403672DD94F2CE4B40
2591	Октябрьский	1	10	227	37.959812999999997	37.991784000000003	55.622033999999999	55.601666000000002	0103000020E6100000010000000500000048A30227DBFA4240BD8E386403CD4B4048A30227DBFA4240028063CF9ECF4B40195932C7F2FE4240028063CF9ECF4B40195932C7F2FE4240BD8E386403CD4B4048A30227DBFA4240BD8E386403CD4B40
62005	Октябрьский	1	10	227	37.959812999999997	37.991784000000003	55.622033999999999	55.601666000000002	0103000020E6100000010000000500000048A30227DBFA4240BD8E386403CD4B4048A30227DBFA4240028063CF9ECF4B40195932C7F2FE4240028063CF9ECF4B40195932C7F2FE4240BD8E386403CD4B4048A30227DBFA4240BD8E386403CD4B40
4477	Марусино	1	10	227	37.969226999999997	37.980913999999999	55.698020999999997	55.68976	0103000020E6100000010000000500000039B35DA10FFC4240630B410E4AD84B4039B35DA10FFC4240EA758BC058D94B40221807978EFD4240EA758BC058D94B40221807978EFD4240630B410E4AD84B4039B35DA10FFC4240630B410E4AD84B40
2042	Малаховка	1	10	227	37.963298000000002	38.052743	55.665562999999999	55.614195000000002	0103000020E61000000100000005000000AF264F594DFB4240F12E17F19DCE4B40AF264F594DFB4240BD361B2B31D54B40E50B5A48C0064340BD361B2B31D54B40E50B5A48C0064340F12E17F19DCE4B40AF264F594DFB4240F12E17F19DCE4B40
61928	Малаховка	1	10	227	37.963298000000002	38.052743	55.665562999999999	55.614195000000002	0103000020E61000000100000005000000AF264F594DFB4240F12E17F19DCE4B40AF264F594DFB4240BD361B2B31D54B40E50B5A48C0064340BD361B2B31D54B40E50B5A48C0064340F12E17F19DCE4B40AF264F594DFB4240F12E17F19DCE4B40
877	Люберцы	1	10	227	37.856901999999998	37.961888000000002	55.707050000000002	55.652059999999999	0103000020E6100000010000000500000041F0F8F6AEED4240CF83BBB376D34B4041F0F8F6AEED42408351499D80DA4B401A355F251FFB42408351499D80DA4B401A355F251FFB4240CF83BBB376D34B4041F0F8F6AEED4240CF83BBB376D34B40
2491	Красково	1	10	227	37.965113000000002	38.023277999999998	55.680052000000003	55.646005000000002	0103000020E61000000100000005000000E4F8A1D288FB4240B806B64AB0D24B40E4F8A1D288FB42402ACAA5F10BD74B40AF5B04C6FA0243402ACAA5F10BD74B40AF5B04C6FA024340B806B64AB0D24B40E4F8A1D288FB4240B806B64AB0D24B40
61922	Красково	1	10	227	37.965113000000002	38.023277999999998	55.680052000000003	55.646005000000002	0103000020E61000000100000005000000E4F8A1D288FB4240B806B64AB0D24B40E4F8A1D288FB42402ACAA5F10BD74B40AF5B04C6FA0243402ACAA5F10BD74B40AF5B04C6FA024340B806B64AB0D24B40E4F8A1D288FB4240B806B64AB0D24B40
59213	совхоза Астапово	1	10	109	38.956654999999998	38.975403	54.888635999999998	54.874651999999998	0103000020E610000001000000050000000647C9AB737A4340C4B0C398F46F4B400647C9AB737A43402D060FD3BE714B40CCB56801DA7C43402D060FD3BE714B40CCB56801DA7C4340C4B0C398F46F4B400647C9AB737A4340C4B0C398F46F4B40
32372	Фруктовая	1	10	109	39.255650000000003	39.270104000000003	54.910668999999999	54.899937999999999	0103000020E61000000100000005000000789CA223B9A04340BD361B2B31734B40789CA223B9A04340923D42CD90744B40684293C492A24340923D42CD90744B40684293C492A24340BD361B2B31734B40789CA223B9A04340BD361B2B31734B40
61998	Сельхозтехника	1	10	109	39.169682000000002	39.193541000000003	54.960622000000001	54.951616999999999	0103000020E61000000100000005000000255CC823B8954340A8A8FA95CE794B40255CC823B8954340B8E864A9F57A4B40B3B794F3C5984340B8E864A9F57A4B40B3B794F3C5984340A8A8FA95CE794B40255CC823B8954340A8A8FA95CE794B40
24473	Протасово	1	10	109	39.148643	39.154491	54.861336999999999	54.856481000000002	0103000020E61000000100000005000000C1E3DBBB069343409C525E2BA16D4B40C1E3DBBB06934340D9EA724A406E4B405F43705CC6934340D9EA724A406E4B405F43705CC69343409C525E2BA16D4B40C1E3DBBB069343409C525E2BA16D4B40
62019	Подлесная Слобода	1	10	109	39.054473000000002	39.083272999999998	54.966777999999998	54.950055999999996	0103000020E61000000100000005000000ECC1A4F8F88643402DAF5C6F9B794B40ECC1A4F8F8864340033FAA61BF7B4B40E5D18DB0A88A4340033FAA61BF7B4B40E5D18DB0A88A43402DAF5C6F9B794B40ECC1A4F8F88643402DAF5C6F9B794B40
49279	Орешково	1	10	109	39.286093999999999	39.306260999999999	54.852443999999998	54.847285999999997	0103000020E6100000010000000500000079CA6ABA9EA44340E82D1EDE736C4B4079CA6ABA9EA44340F1D58EE21C6D4B402785798F33A74340F1D58EE21C6D4B402785798F33A74340E82D1EDE736C4B4079CA6ABA9EA44340E82D1EDE736C4B40
49566	Озерицы	1	10	109	39.218854999999998	39.243442000000002	54.950029999999998	54.933883999999999	0103000020E6100000010000000500000075C8CD70039C4340FB20CB8289774B4075C8CD70039C4340041C42959A794B40863C821B299F4340041C42959A794B40863C821B299F4340FB20CB8289774B4075C8CD70039C4340FB20CB8289774B40
31710	Нижне-Маслово	1	10	109	39.346496999999999	39.384936000000003	54.843330999999999	54.824714999999998	0103000020E61000000100000005000000C09481035AAC4340A4C2D84290694B40C09481035AAC4340FB592C45F26B4B40CB86359545B14340FB592C45F26B4B40CB86359545B14340A4C2D84290694B40C09481035AAC4340A4C2D84290694B40
31335	Матыра	1	10	109	38.880513999999998	38.910482000000002	54.959733	54.941662999999998	0103000020E61000000100000005000000C7D5C8AEB4704340376DC66988784B40C7D5C8AEB47043402CF2EB87D87A4B4060CC96AC8A7443402CF2EB87D87A4B4060CC96AC8A744340376DC66988784B40C7D5C8AEB4704340376DC66988784B40
31571	Марьина Гора	1	10	109	39.309145000000001	39.321793	54.777805999999998	54.767356999999997	0103000020E61000000100000005000000685C381092A74340A7AD11C138624B40685C381092A74340F850A2258F634B40768A558330A94340F850A2258F634B40768A558330A94340A7AD11C138624B40685C381092A74340A7AD11C138624B40
32071	Любичи	1	10	109	39.200097999999997	39.238618000000002	55.034291000000003	55.027036000000003	0103000020E610000001000000050000005CFFAECF9C99434047E867EA75834B405CFFAECF9C99434009C6C1A563844B40541EDD088B9E434009C6C1A563844B40541EDD088B9E434047E867EA75834B405CFFAECF9C99434047E867EA75834B40
158	Луховицы	1	10	109	38.990234000000001	39.070328000000003	54.987228999999999	54.922564999999999	0103000020E6100000010000000500000092B1DAFCBF7E434095B7239C16764B4092B1DAFCBF7E4340D65416855D7E4B401EFF058200894340D65416855D7E4B401EFF05820089434095B7239C16764B4092B1DAFCBF7E434095B7239C16764B40
32165	Ловцы	1	10	109	39.231513	39.269286999999998	55.013295999999997	54.999191000000003	0103000020E61000000100000005000000A7CCCD37A29D434091BA9D7DE57F4B40A7CCCD37A29D43407495EEAEB3814B40751E15FF77A243407495EEAEB3814B40751E15FF77A2434091BA9D7DE57F4B40A7CCCD37A29D434091BA9D7DE57F4B40
32051	Лисьи Норы	1	10	109	39.143765000000002	39.166744000000001	55.109214000000001	55.102426000000001	0103000020E610000001000000050000009CA73AE4669243404B21904B1C8D4B409CA73AE466924340F7216FB9FA8D4B40F1660DDE57954340F7216FB9FA8D4B40F1660DDE579543404B21904B1C8D4B409CA73AE4669243404B21904B1C8D4B40
32244	Красная Пойма	1	10	109	39.058632000000003	39.098086000000002	55.019398000000002	54.988515	0103000020E61000000100000005000000E23FDD40818743407F4DD6A8877E4B40E23FDD4081874340CDCD37A27B824B40051901158E8C4340CDCD37A27B824B40051901158E8C43407F4DD6A8877E4B40E23FDD40818743407F4DD6A8877E4B40
31974	Дединово	1	10	109	39.082867999999998	39.162306000000001	55.066972999999997	55.039940000000001	0103000020E6100000010000000500000045F12A6B9B8A4340B0E600C11C854B4045F12A6B9B8A4340855B3E9292884B40E8F86871C6944340855B3E9292884B40E8F86871C6944340B0E600C11C854B4045F12A6B9B8A4340B0E600C11C854B40
31558	Григорьевское	1	10	109	39.242930000000001	39.271963999999997	54.810585000000003	54.790635000000002	0103000020E61000000100000005000000D09B8A54189F43405709168733654B40D09B8A54189F434068D0D03FC1674B403CD862B7CFA2434068D0D03FC1674B403CD862B7CFA243405709168733654B40D09B8A54189F43405709168733654B40
49371	Головачево	1	10	109	39.105649999999997	39.153458000000001	54.940572000000003	54.926124999999999	0103000020E6100000010000000500000044696FF0858D4340068195438B764B4044696FF0858D434044C4CDA964784B40A0A70183A493434044C4CDA964784B40A0A70183A4934340068195438B764B4044696FF0858D4340068195438B764B40
31479	Газопроводск	1	10	109	39.223301999999997	39.241574	54.843445000000003	54.831581999999997	0103000020E61000000100000005000000D190F128959C43409CF86A47716A4B40D190F128959C4340C47C7901F66B4B402EC896E5EB9E4340C47C7901F66B4B402EC896E5EB9E43409CF86A47716A4B40D190F128959C43409CF86A47716A4B40
31767	Выкопанка	1	10	109	39.169178000000002	39.190548999999997	54.982728999999999	54.969709000000002	0103000020E61000000100000005000000F299EC9FA795434085D1AC6C1F7C4B40F299EC9FA795434057EA5910CA7D4B408BA4DDE86398434057EA5910CA7D4B408BA4DDE86398434085D1AC6C1F7C4B40F299EC9FA795434085D1AC6C1F7C4B40
32440	Врачово-Горки	1	10	109	39.209817999999999	39.233578999999999	54.919150000000002	54.906765999999998	0103000020E610000001000000050000005A0EF450DB9A4340F78F85E810744B405A0EF450DB9A4340280F0BB5A6754B402504ABEAE59D4340280F0BB5A6754B402504ABEAE59D4340F78F85E810744B405A0EF450DB9A4340F78F85E810744B40
30864	Белоомут	1	10	109	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
61952	Белоомут	1	10	109	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
31471	Алпатьево	1	10	109	39.302487999999997	39.344600999999997	54.890205000000002	54.875656999999997	0103000020E610000001000000050000005AB741EDB7A64340B9C1508715704B405AB741EDB7A643402BDEC83CF2714B409E95B4E21BAC43402BDEC83CF2714B409E95B4E21BAC4340B9C1508715704B405AB741EDB7A64340B9C1508715704B40
59531	п. Новолотошино	1	10	993	35.406477000000002	36.128785000000001	56.478113999999998	56.111899999999999	0103000020E61000000100000005000000C1C9367007B4414011363CBD520E4C40C1C9367007B441403FE1ECD6323D4C40919BE1067C1042403FE1ECD6323D4C40919BE1067C10424011363CBD520E4C40C1C9367007B4414011363CBD520E4C40
61898	п. Лотошино	1	10	993	35.621048999999999	35.660080000000001	56.249707000000001	56.217841	0103000020E61000000100000005000000541B9C887ECF41402D5DC136E21B4C40541B9C887ECF4140884A2366F61F4C40315F5E807DD44140884A2366F61F4C40315F5E807DD441402D5DC136E21B4C40541B9C887ECF41402D5DC136E21B4C40
29978	Ушаково	1	10	993	35.655597999999998	35.680185000000002	56.200178000000001	56.188707999999998	0103000020E6100000010000000500000058A9A0A2EAD341402D3F709527184C4058A9A0A2EAD3414079B0C56E9F194C40691D554D10D7414079B0C56E9F194C40691D554D10D741402D3F709527184C4058A9A0A2EAD341402D3F709527184C40
29974	Савостино	1	10	993	35.704501999999998	35.728631	56.362127000000001	56.350397000000001	0103000020E61000000100000005000000B9FB1C1F2DDA4140EACE13CFD92C4C40B9FB1C1F2DDA4140D2FF722D5A2E4C4007EDD5C743DD4140D2FF722D5A2E4C4007EDD5C743DD4140EACE13CFD92C4C40B9FB1C1F2DDA4140EACE13CFD92C4C40
59518	Пешки	1	10	993	35.570033000000002	35.578854999999997	56.309807999999997	56.305923	0103000020E61000000100000005000000055262D7F6C841400F0C207C28274C40055262D7F6C841400305DEC9A7274C402310AFEB17CA41400305DEC9A7274C402310AFEB17CA41400F0C207C28274C40055262D7F6C841400F0C207C28274C40
61982	Монасеино	1	10	993	35.491835000000002	35.51538	56.252336999999997	56.240333	0103000020E610000001000000050000009B030473F4BE41402593533BC31E4C409B030473F4BE41400E492D944C204C409981CAF8F7C141400E492D944C204C409981CAF8F7C141402593533BC31E4C409B030473F4BE41402593533BC31E4C40
29821	Михалево	1	10	993	35.545158999999998	35.564678999999998	56.190426000000002	56.176929999999999	0103000020E610000001000000050000005E0F26C5C7C5414034D769A4A5164C405E0F26C5C7C54140702711E15F184C4076DEC66647C84140702711E15F184C4076DEC66647C8414034D769A4A5164C405E0F26C5C7C5414034D769A4A5164C40
29853	Микулино	1	10	993	35.584847000000003	35.617941000000002	56.456806	56.435825000000001	0103000020E61000000100000005000000F5143944DCCA4140BDE3141DC9374C40F5143944DCCA4140EC4E779E783A4C40C4EDD0B018CF4140EC4E779E783A4C40C4EDD0B018CF4140BDE3141DC9374C40F5143944DCCA4140BDE3141DC9374C40
8402	Лотошино	1	10	993	35.621048999999999	35.660080000000001	56.249707000000001	56.217841	0103000020E61000000100000005000000541B9C887ECF41402D5DC136E21B4C40541B9C887ECF4140884A2366F61F4C40315F5E807DD44140884A2366F61F4C40315F5E807DD441402D5DC136E21B4C40541B9C887ECF41402D5DC136E21B4C40
61908	Лотошино	1	10	993	35.621048999999999	35.660080000000001	56.249707000000001	56.217841	0103000020E61000000100000005000000541B9C887ECF41402D5DC136E21B4C40541B9C887ECF4140884A2366F61F4C40315F5E807DD44140884A2366F61F4C40315F5E807DD441402D5DC136E21B4C40541B9C887ECF41402D5DC136E21B4C40
29771	Кульпино	1	10	993	35.635061999999998	35.653396999999998	56.167738999999997	56.156635999999999	0103000020E6100000010000000500000057772CB649D1414029B000A60C144C4057772CB649D14140C2A1B77878154C40FA264D83A2D34140C2A1B77878154C40FA264D83A2D3414029B000A60C144C4057772CB649D1414029B000A60C144C40
29616	Кировский	1	10	993	35.641556999999999	35.671345000000002	56.234025000000003	56.211263000000002	0103000020E610000001000000050000008BC22E8A1ED241406CED7DAA0A1B4C408BC22E8A1ED2414024B9FC87F41D4C40A4AA09A2EED5414024B9FC87F41D4C40A4AA09A2EED541406CED7DAA0A1B4C408BC22E8A1ED241406CED7DAA0A1B4C40
30067	Доры	1	10	993	35.904234000000002	35.923546999999999	56.272350000000003	56.263497000000001	0103000020E6100000010000000500000034F790F0BDF341400CCC0A45BA214C4034F790F0BDF341406688635DDC224C40D2A8C0C936F641406688635DDC224C40D2A8C0C936F641400CCC0A45BA214C4034F790F0BDF341400CCC0A45BA214C40
29916	Введенское	1	10	993	35.616098999999998	35.642077999999998	56.383896999999997	56.362206999999998	0103000020E61000000100000005000000950C0055DCCE4140EEB089CC5C2E4C40950C0055DCCE41402904728923314C4094BDA59C2FD241402904728923314C4094BDA59C2FD24140EEB089CC5C2E4C40950C0055DCCE4140EEB089CC5C2E4C40
30113	Большая Сестра	1	10	993	35.923664000000002	35.934685999999999	56.220914	56.214592000000003	0103000020E610000001000000050000000C3F389F3AF64140DBFD2AC0771B4C400C3F389F3AF64140419DF2E8461C4C40B80375CAA3F74140419DF2E8461C4C40B80375CAA3F74140DBFD2AC0771B4C400C3F389F3AF64140DBFD2AC0771B4C40
60246	подсобного хозяйства Воскресенское	1	10	150	37.434370000000001	37.471874999999997	55.534692999999997	55.516638999999998	0103000020E61000000100000005000000882EA86F99B74240486B0C3A21C24B40882EA86F99B742403733FAD170C44B406666666666BC42403733FAD170C44B406666666666BC4240486B0C3A21C24B40882EA86F99B74240486B0C3A21C24B40
397	Совхоза им.Ленина	1	10	150	37.712425000000003	37.745941999999999	55.590164999999999	55.580711000000001	0103000020E6100000010000000500000029ED0DBE30DB4240B7B6F0BC54CA4B4029ED0DBE30DB4240361FD7868ACB4B403E5B07077BDF4240361FD7868ACB4B403E5B07077BDF4240B7B6F0BC54CA4B4029ED0DBE30DB4240B7B6F0BC54CA4B40
28574	Развилка	1	10	150	37.731999999999999	37.771867	55.599305999999999	55.575586999999999	0103000020E6100000010000000500000004560E2DB2DD42405A80B6D5ACC94B4004560E2DB2DD4240F6251B0FB6CC4B404AEEB089CCE24240F6251B0FB6CC4B404AEEB089CCE242405A80B6D5ACC94B4004560E2DB2DD42405A80B6D5ACC94B40
48219	Остров	1	10	150	37.830283999999999	37.854799	55.591554000000002	55.577942999999998	0103000020E610000001000000050000002F3201BF46EA4240DFF94509FAC94B402F3201BF46EA4240B4E89D0AB8CB4B40A6D3BA0D6AED4240B4E89D0AB8CB4B40A6D3BA0D6AED4240DFF94509FAC94B402F3201BF46EA4240DFF94509FAC94B40
27812	Новодрожжино	1	10	150	37.582951000000001	37.589194999999997	55.536354000000003	55.531713000000003	0103000020E61000000100000005000000D3156C239ECA4240D5EDEC2B0FC44B40D3156C239ECA4240168A743FA7C44B40BDFBE3BD6ACB4240168A743FA7C44B40BDFBE3BD6ACB4240D5EDEC2B0FC44B40D3156C239ECA4240D5EDEC2B0FC44B40
2202	Московский	1	10	150	37.330641	37.382843000000001	55.613838999999999	55.579093	0103000020E61000000100000005000000BEDBBC7152AA4240D82B2CB81FCA4B40BEDBBC7152AA42403201BF4692CE4B405340DAFF00B142403201BF4692CE4B405340DAFF00B14240D82B2CB81FCA4B40BEDBBC7152AA4240D82B2CB81FCA4B40
28351	Молоково	1	10	150	37.843786000000001	37.881731000000002	55.568863	55.555387000000003	0103000020E610000001000000050000004D69FD2D01EC4240D1CFD4EB16C74B404D69FD2D01EC4240C573B680D0C84B40486FB88FDCF04240C573B680D0C84B40486FB88FDCF04240D1CFD4EB16C74B404D69FD2D01EC4240D1CFD4EB16C74B40
48443	Марьино	1	10	150	37.318820000000002	37.336345999999999	55.553004000000001	55.543073	0103000020E61000000100000005000000C6A70018CFA84240992B836A83C54B40C6A70018CFA842405247C7D5C8C64B40F911BF620DAB42405247C7D5C8C64B40F911BF620DAB4240992B836A83C54B40C6A70018CFA84240992B836A83C54B40
28770	Коммунарка	1	10	150	37.468093000000003	37.497692000000001	55.577694000000001	55.552850999999997	0103000020E61000000100000005000000473EAF78EABB4240CB4752D2C3C64B40473EAF78EABB4240378C82E0F1C94B408CBD175FB4BF4240378C82E0F1C94B408CBD175FB4BF4240CB4752D2C3C64B40473EAF78EABB4240CB4752D2C3C64B40
46739	Калиновка	1	10	150	37.711976	37.730023000000003	55.523865999999998	55.513911999999998	0103000020E61000000100000005000000B9C4910722DB4240CF8250DEC7C14B40B9C4910722DB424040BE840A0EC34B40F629C76471DD424040BE840A0EC34B40F629C76471DD4240CF8250DEC7C14B40B9C4910722DB4240CF8250DEC7C14B40
49532	Измайлово	1	10	150	37.636589999999998	37.659711999999999	55.567362000000003	55.556165999999997	0103000020E61000000100000005000000F67AF7C77BD14240D5928E7230C74B40F67AF7C77BD14240207F69519FC84B40AE635C7171D44240207F69519FC84B40AE635C7171D44240D5928E7230C74B40F67AF7C77BD14240D5928E7230C74B40
28484	Завода Мосрентген	1	10	150	37.454438000000003	37.489302000000002	55.624256000000003	55.603974999999998	0103000020E61000000100000005000000A3073E062BBA4240014D840D4FCD4B40A3073E062BBA4240782AE09EE7CF4B4007EFAB72A1BE4240782AE09EE7CF4B4007EFAB72A1BE4240014D840D4FCD4B40A3073E062BBA4240014D840D4FCD4B40
47817	Дроздово	1	10	150	37.791018999999999	37.811661999999998	55.608927999999999	55.600968999999999	0103000020E61000000100000005000000DFC14F1C40E5424075745C8DECCC4B40DFC14F1C40E5424031CF4A5AF1CD4B40F6B3588AE4E7424031CF4A5AF1CD4B40F6B3588AE4E7424075745C8DECCC4B40DFC14F1C40E5424075745C8DECCC4B40
27898	ДСК Мичуринец	1	10	150	37.311579000000002	37.334082000000002	55.651668999999998	55.646289000000003	0103000020E61000000100000005000000698F17D2E1A74240DD611399B9D24B40698F17D2E1A742409468C9E369D34B405517F032C3AA42409468C9E369D34B405517F032C3AA4240DD611399B9D24B40698F17D2E1A74240DD611399B9D24B40
29022	Горки Ленинские	1	10	150	37.761508999999997	37.793453999999997	55.517372999999999	55.493757000000002	0103000020E61000000100000005000000094E7D2079E14240E695EB6D33BF4B40094E7D2079E14240AD6A494739C24B40B07092E68FE54240AD6A494739C24B40B07092E68FE54240E695EB6D33BF4B40094E7D2079E14240E695EB6D33BF4B40
61978	Горки	1	10	150	37.746445000000001	37.766387000000002	55.517831999999999	55.498632000000001	0103000020E61000000100000005000000A1A17F828BDF42409A5E622CD3BF4B40A1A17F828BDF42404069A85148C24B402F8A1EF818E242404069A85148C24B402F8A1EF818E242409A5E622CD3BF4B40A1A17F828BDF42409A5E622CD3BF4B40
28812	Газопровод	1	10	150	37.466943000000001	37.487738999999998	55.585774000000001	55.577280999999999	0103000020E610000001000000050000004E0CC9C9C4BB424014CD0358E4C94B404E0CC9C9C4BB42406E6C76A4FACA4B40EBFD463B6EBE42406E6C76A4FACA4B40EBFD463B6EBE424014CD0358E4C94B404E0CC9C9C4BB424014CD0358E4C94B40
20107	Вырубово	1	10	150	37.616647	37.626950999999998	55.569656999999999	55.564160000000001	0103000020E610000001000000050000009816F549EECE42400EDB166536C84B409816F549EECE4240FF774485EAC84B40E5982CEE3FD04240FF774485EAC84B40E5982CEE3FD042400EDB166536C84B409816F549EECE42400EDB166536C84B40
24806	Володарского	1	10	150	37.928865999999999	37.965848999999999	55.509757	55.497903000000001	0103000020E61000000100000005000000E42EC214E5F6424047CA1649BBBF4B40E42EC214E5F642401BF4A5B73FC14B40E9EFA5F0A0FB42401BF4A5B73FC14B40E9EFA5F0A0FB424047CA1649BBBF4B40E42EC214E5F6424047CA1649BBBF4B40
40399	Внуково	1	10	150	37.252254000000001	37.280425999999999	55.651643	55.640979999999999	0103000020E610000001000000050000008124ECDB49A04240EEB1F4A10BD24B408124ECDB49A042406BD5AE0969D34B405B79C9FFE4A342406BD5AE0969D34B405B79C9FFE4A34240EEB1F4A10BD24B408124ECDB49A04240EEB1F4A10BD24B40
5502	Видное	1	10	150	37.644117999999999	37.777329000000002	55.573540999999999	55.528345000000002	0103000020E61000000100000005000000E961687572D24240A80018CFA0C34B40E961687572D2424023F59ECA69C94B40BF9D44847FE3424023F59ECA69C94B40BF9D44847FE34240A80018CFA0C34B40E961687572D24240A80018CFA0C34B40
28229	Ватутинки	1	10	150	37.321272	37.343648999999999	55.513657000000002	55.489376	0103000020E610000001000000050000006D8FDE701FA9424041B96DDFA3BE4B406D8FDE701FA94240452E3883BFC14B40CC26C0B0FCAB4240452E3883BFC14B40CC26C0B0FCAB424041B96DDFA3BE4B406D8FDE701FA9424041B96DDFA3BE4B40
48409	Валуево	1	10	150	37.348436999999997	37.359476999999998	55.575530999999998	55.566327999999999	0103000020E61000000100000005000000B1DB679599AC42409067976F7DC84B40B1DB679599AC4240C66AF3FFAAC94B400455A35703AE4240C66AF3FFAAC94B400455A35703AE42409067976F7DC84B40B1DB679599AC42409067976F7DC84B40
26906	Светлые Горы	1	10	292	37.296461000000001	37.311084999999999	55.900011999999997	55.893065999999997	0103000020E610000001000000050000000DC51D6FF2A54240B39597FC4FF24B400DC51D6FF2A54240F700DD9733F34B4059A31EA2D1A74240F700DD9733F34B4059A31EA2D1A74240B39597FC4FF24B400DC51D6FF2A54240B39597FC4FF24B40
27016	Путилково	1	10	292	37.374811999999999	37.411085999999997	55.875318999999998	55.853461000000003	0103000020E61000000100000005000000FD12F1D6F9AF4240ABB4C5353EED4B40FD12F1D6F9AF4240A148F7730AF04B40F6EB4E779EB44240A148F7730AF04B40F6EB4E779EB44240ABB4C5353EED4B40FD12F1D6F9AF4240ABB4C5353EED4B40
26603	Петрово-Дальнее	1	10	292	37.140979999999999	37.191259000000002	55.762014000000001	55.741880000000002	0103000020E61000000100000005000000EEB1F4A10B9242403BC780ECF5DE4B40EEB1F4A10B9242400D8CBCAC89E14B406808C72C7B9842400D8CBCAC89E14B406808C72C7B9842403BC780ECF5DE4B40EEB1F4A10B9242403BC780ECF5DE4B40
26874	Отрадное	1	10	292	37.293891000000002	37.336561000000003	55.882120999999998	55.867494999999998	0103000020E610000001000000050000005CCB64389EA54240C5387F130AEF4B405CCB64389EA54240B20E4757E9F04B40F60D4C6E14AB4240B20E4757E9F04B40F60D4C6E14AB4240C5387F130AEF4B405CCB64389EA54240C5387F130AEF4B40
26461	Новый	1	10	292	37.27252	37.301347	55.812378000000002	55.802881999999997	0103000020E61000000100000005000000C2C073EFE1A2424006465ED6C4E64B40C2C073EFE1A24240B5FE9600FCE74B40B5DFDA8992A64240B5FE9600FCE74B40B5DFDA8992A6424006465ED6C4E64B40C2C073EFE1A2424006465ED6C4E64B40
26476	Николо-Урюпино	1	10	292	37.197457	37.224038	55.809358000000003	55.793571	0103000020E61000000100000005000000E2AE5E4546994240EA060ABC93E54B40E2AE5E4546994240C460FE0A99E74B40D787F546AD9C4240C460FE0A99E74B40D787F546AD9C4240EA060ABC93E54B40E2AE5E4546994240EA060ABC93E54B40
25032	Нахабино	1	10	292	37.129975999999999	37.214229000000003	55.865004999999996	55.827641	0103000020E61000000100000005000000E8A1B60DA390424014EAE923F0E94B40E8A1B60DA390424030F0DC7BB8EE4B406A6D1ADB6B9B424030F0DC7BB8EE4B406A6D1ADB6B9B424014EAE923F0E94B40E8A1B60DA390424014EAE923F0E94B40
1264	Красногорск	1	10	292	37.229140999999998	37.394089000000001	55.851278000000001	55.799886999999998	0103000020E610000001000000050000001C96067E549D42406EBF7CB262E64B401C96067E549D4240F3E670ADF6EC4B404F5B238271B24240F3E670ADF6EC4B404F5B238271B242406EBF7CB262E64B401C96067E549D42406EBF7CB262E64B40
25932	Козино	1	10	292	37.166915000000003	37.191169000000002	55.896245999999998	55.886477999999997	0103000020E610000001000000050000001E1B81785D954240CE4F711C78F14B401E1B81785D954240DD955D30B8F24B402881CD3978984240DD955D30B8F24B402881CD3978984240CE4F711C78F14B401E1B81785D954240CE4F711C78F14B40
26777	Истра	1	10	292	37.142606000000001	37.157851000000001	55.777236000000002	55.771059000000001	0103000020E61000000100000005000000501BD5E940924240AB24B20FB2E24B40501BD5E9409242400EA320787CE34B4009522976349442400EA320787CE34B400952297634944240AB24B20FB2E24B40501BD5E940924240AB24B20FB2E24B40
26545	Ильинское	1	10	292	37.226140000000001	37.251922	55.763893000000003	55.751427	0103000020E61000000100000005000000A228D027F29C42406B2A8BC22EE04B40A228D027F29C42405952EE3EC7E14B404B92E7FA3EA042405952EE3EC7E14B404B92E7FA3EA042406B2A8BC22EE04B40A228D027F29C42406B2A8BC22EE04B40
60273	Ильинка	1	10	292	37.242319000000002	37.253934000000001	55.761319999999998	55.755454	0103000020E6100000010000000500000087191A4F049F4240F2D077B7B2E04B4087191A4F049F424036E50AEF72E14B40D6ABC8E880A0424036E50AEF72E14B40D6ABC8E880A04240F2D077B7B2E04B4087191A4F049F4240F2D077B7B2E04B40
62014	Дмитровское	1	10	292	37.106628999999998	37.132517999999997	55.759217999999997	55.743831	0103000020E6100000010000000500000010E7E104A68D42402060ADDA35DF4B4010E7E104A68D42406B44300E2EE14B40CF108E59F69042406B44300E2EE14B40CF108E59F69042402060ADDA35DF4B4010E7E104A68D42402060ADDA35DF4B40
25704	Гольево	1	10	292	37.301921999999998	37.319422000000003	55.803852999999997	55.795641000000003	0103000020E61000000100000005000000B1F84D61A5A64240AA2D7590D7E54B40B1F84D61A5A642404FE5B4A7E4E64B40BCCFF1D1E2A842404FE5B4A7E4E64B40BCCFF1D1E2A84240AA2D7590D7E54B40B1F84D61A5A64240AA2D7590D7E54B40
25492	Архангельское	1	10	292	37.286749999999998	37.314444999999999	55.799168000000002	55.779707000000002	0103000020E6100000010000000500000062105839B4A442402CBB6070CDE34B4062105839B4A442403F0114234BE64B4003B2D7BB3FA842403F0114234BE64B4003B2D7BB3FA842402CBB6070CDE34B4062105839B4A442402CBB6070CDE34B40
26794	Ангелово	1	10	292	37.309126999999997	37.341583	55.864434000000003	55.853698000000001	0103000020E61000000100000005000000C1A7397991A742408F54DFF945ED4B40C1A7397991A7424076C6F7C5A5EE4B404EEFE2FDB8AB424076C6F7C5A5EE4B404EEFE2FDB8AB42408F54DFF945ED4B40C1A7397991A742408F54DFF945ED4B40
14464	Шеметово	1	10	1350	38.605153000000001	38.641714999999998	55.168906999999997	55.151682000000001	0103000020E61000000100000005000000C4094CA7754D434029B2D6506A934B40C4094CA7754D434061889CBE9E954B40232D95B72352434061889CBE9E954B40232D95B72352434029B2D6506A934B40C4094CA7754D434029B2D6506A934B40
18393	Черкизово	1	10	1350	38.729281999999998	38.748255	55.214480999999999	55.190353999999999	0103000020E61000000100000005000000DEC7D11C595D4340D65416855D984B40DEC7D11C595D4340834E081D749B4B40C408E1D1C65F4340834E081D749B4B40C408E1D1C65F4340D65416855D984B40DEC7D11C595D4340D65416855D984B40
18623	Чанки	1	10	1350	38.805469000000002	38.853070000000002	55.138475	55.121572	0103000020E610000001000000050000008E78B29B19674340FE0DDAAB8F8F4B408E78B29B1967434024287E8CB9914B407099D365316D434024287E8CB9914B407099D365316D4340FE0DDAAB8F8F4B408E78B29B19674340FE0DDAAB8F8F4B40
60236	Сосновый Бор	1	10	1350	38.391570000000002	39.326438000000003	55.264716999999997	54.936062	0103000020E61000000100000005000000200C3CF71E324340A1832EE1D0774B40200C3CF71E324340FDD8243FE2A14B40F9156BB8C8A94340FDD8243FE2A14B40F9156BB8C8A94340A1832EE1D0774B40200C3CF71E324340A1832EE1D0774B40
18042	Сергиевское	1	10	1350	38.829524999999997	38.858342999999998	55.093786999999999	55.085743999999998	0103000020E61000000100000005000000711B0DE02D6A434003EACDA8F98A4B40711B0DE02D6A43401DE56036018C4B4011E0F42EDE6D43401DE56036018C4B4011E0F42EDE6D434003EACDA8F98A4B40711B0DE02D6A434003EACDA8F98A4B40
17960	Сергиевский поселок	1	10	1350	38.841473000000001	38.875016000000002	55.105676000000003	55.089500999999998	0103000020E61000000100000005000000C7BB2363B56B4340CAFACDC4748B4B40C7BB2363B56B43406EFC89CA868D4B4006BD3786007043406EFC89CA868D4B4006BD378600704340CAFACDC4748B4B40C7BB2363B56B4340CAFACDC4748B4B40
17385	Сельниково	1	10	1350	39.147044000000001	39.168396999999999	55.140991	55.131712	0103000020E6100000010000000500000059897956D2924340D13E56F0DB904B4059897956D2924340E2033BFE0B924B404CDF6B088E954340E2033BFE0B924B404CDF6B088E954340D13E56F0DB904B4059897956D2924340D13E56F0DB904B40
18180	Проводник	1	10	1350	38.57188	38.596862000000002	55.143619999999999	55.130673000000002	0103000020E61000000100000005000000459E245D3349434030BC92E4B9904B40459E245D334943409886E12362924B40D21C59F9654C43409886E12362924B40D21C59F9654C434030BC92E4B9904B40459E245D3349434030BC92E4B9904B40
17553	Пирочи	1	10	1350	38.922753	38.987305999999997	55.078189999999999	55.067478999999999	0103000020E6100000010000000500000098A432C51C7643405915E126A3884B4098A432C51C764340E76F4221028A4B408192020B607E4340E76F4221028A4B408192020B607E43405915E126A3884B4098A432C51C7643405915E126A3884B40
62002	Пестриково	1	10	1350	38.855038	38.902557999999999	55.097490999999998	55.084302000000001	0103000020E610000001000000050000002B6B9BE2716D4340637E6E68CA8A4B402B6B9BE2716D4340C153C8957A8C4B40205F420587734340C153C8957A8C4B40205F420587734340637E6E68CA8A4B402B6B9BE2716D4340637E6E68CA8A4B40
16953	Пески	1	10	1350	38.748874999999998	38.803204999999998	55.225681000000002	55.195478000000001	0103000020E6100000010000000500000060E5D022DB5F4340338B506C05994B4060E5D022DB5F43400F2A711DE39C4B40E97DE36BCF6643400F2A711DE39C4B40E97DE36BCF664340338B506C05994B4060E5D022DB5F4340338B506C05994B40
17282	Первомайский	1	10	1350	38.649081000000002	38.671503000000001	55.071112999999997	55.054315000000003	0103000020E610000001000000050000003DBA11161553434054573ECBF3864B403DBA11161553434004A9143B1A894B403C1570CFF355434004A9143B1A894B403C1570CFF355434054573ECBF3864B403DBA11161553434054573ECBF3864B40
17898	Парфентьево	1	10	1350	38.802647999999998	38.831313000000002	55.112278000000003	55.097614999999998	0103000020E6100000010000000500000093196F2BBD664340AD4CF8A57E8C4B4093196F2BBD664340B80721205F8E4B40ADDEE176686A4340B80721205F8E4B40ADDEE176686A4340AD4CF8A57E8C4B4093196F2BBD664340AD4CF8A57E8C4B40
17482	Октябрьское	1	10	1350	38.978375999999997	39.004517	55.106499999999997	55.097181999999997	0103000020E610000001000000050000007C98BD6C3B7D434043E1B375708C4B407C98BD6C3B7D43401283C0CAA18D4B4055A35703948043401283C0CAA18D4B4055A357039480434043E1B375708C4B407C98BD6C3B7D434043E1B375708C4B40
18506	Новая	1	10	1350	38.883944999999997	38.902746999999998	55.219324	55.209642000000002	0103000020E610000001000000050000003A3B191C257143401CEF8E8CD59A4B403A3B191C257143402C9D0FCF129C4B40F3C7B4368D7343402C9D0FCF129C4B40F3C7B4368D7343401CEF8E8CD59A4B403A3B191C257143401CEF8E8CD59A4B40
18538	Нижнее Хорошово	1	10	1350	38.777332999999999	38.810158000000001	55.154336999999998	55.134368000000002	0103000020E61000000100000005000000008DD2A57F63434081D07AF832914B40008DD2A57F63434008C89750C1934B40E04BE141B367434008C89750C1934B40E04BE141B367434081D07AF832914B40008DD2A57F63434081D07AF832914B40
17645	Непецино	1	10	1350	38.574475999999997	38.624853000000002	55.212842000000002	55.189588000000001	0103000020E610000001000000050000001F2BF86D8849434066DB696B44984B401F2BF86D884943408D9B1A683E9B4B405CE7DF2EFB4F43408D9B1A683E9B4B405CE7DF2EFB4F434066DB696B44984B401F2BF86D8849434066DB696B44984B40
17343	Малое Карасево	1	10	1350	38.623721000000003	38.644787000000001	55.012889000000001	55.004255999999998	0103000020E610000001000000050000000A6AF816D64F4340E867EA758B804B400A6AF816D64F434034BDC458A6814B4067F162618852434034BDC458A6814B4067F1626188524340E867EA758B804B400A6AF816D64F4340E867EA758B804B40
18151	Лукерьино	1	10	1350	38.639873000000001	38.668151999999999	55.107782	55.093364999999999	0103000020E61000000100000005000000F54BC45BE7514340A7CB6262F38B4B40F54BC45BE75143407A8CF2CCCB8D4B40E5603601865543407A8CF2CCCB8D4B40E560360186554340A7CB6262F38B4B40F54BC45BE7514340A7CB6262F38B4B40
17237	Лесной	1	10	1350	38.610928999999999	38.626559999999998	55.045845999999997	55.022607999999998	0103000020E61000000100000005000000C896E5EB324E43406150A6D1E4824B40C896E5EB324E434082531F48DE854B40AA7D3A1E3350434082531F48DE854B40AA7D3A1E335043406150A6D1E4824B40C896E5EB324E43406150A6D1E4824B40
17724	Индустрия	1	10	1350	38.514539999999997	38.541283	55.201726000000001	55.190235999999999	0103000020E61000000100000005000000EE3D5C72DC414340CC423BA759984B40EE3D5C72DC4143405F605628D2994B40BD70E7C2484543405F605628D2994B40BD70E7C248454340CC423BA759984B40EE3D5C72DC414340CC423BA759984B40
17442	Зарудня	1	10	1350	39.062387000000001	39.088070000000002	55.128593000000002	55.112761999999996	0103000020E610000001000000050000000859164CFC874340A31D37FC6E8E4B400859164CFC8743404DBF44BC75904B401EE1B4E0458B43404DBF44BC75904B401EE1B4E0458B4340A31D37FC6E8E4B400859164CFC874340A31D37FC6E8E4B40
17094	Заречный	1	10	1350	38.548774999999999	38.559114999999998	55.055976000000001	55.045738	0103000020E6100000010000000500000063EE5A423E4643409C1727BEDA854B4063EE5A423E46434032AEB8382A874B40FDD98F149147434032AEB8382A874B40FDD98F14914743409C1727BEDA854B4063EE5A423E4643409C1727BEDA854B40
18436	Губастово	1	10	1350	38.787636999999997	38.804848999999997	55.227037000000003	55.217326	0103000020E610000001000000050000004D0F0A4AD164434006499F56D19B4B404D0F0A4AD1644340B1FD648C0F9D4B40F19BC24A05674340B1FD648C0F9D4B40F19BC24A0567434006499F56D19B4B404D0F0A4AD164434006499F56D19B4B40
17828	Возрождение	1	10	1350	38.643718	38.661369999999998	55.178542	55.162649000000002	0103000020E610000001000000050000005BECF6596552434012DDB3AED1944B405BECF65965524340317BD976DA964B401B47ACC5A7544340317BD976DA964B401B47ACC5A754434012DDB3AED1944B405BECF6596552434012DDB3AED1944B40
18246	Богдановка	1	10	1350	38.448694000000003	38.462752000000002	55.142868999999997	55.134847000000001	0103000020E61000000100000005000000AAF413CE6E3943405B7B9FAA42914B40AAF413CE6E3943405D4E098849924B404D1421753B3B43405D4E098849924B404D1421753B3B43405B7B9FAA42914B40AAF413CE6E3943405B7B9FAA42914B40
17158	Биорки	1	10	1350	38.599933999999998	38.621583000000001	55.061570000000003	55.046495999999998	0103000020E6100000010000000500000015E126A3CA4C434089B2B794F3854B4015E126A3CA4C434016359886E1874B40F25F2008904F434016359886E1874B40F25F2008904F434089B2B794F3854B4015E126A3CA4C434089B2B794F3854B40
17016	Акатьево	1	10	1350	38.748911	38.761577000000003	54.991103000000003	54.964463000000002	0103000020E61000000100000005000000AD4ECE50DC5F4340DD990986737B4B40AD4ECE50DC5F4340D7FB8D76DC7E4B406231EA5A7B614340D7FB8D76DC7E4B406231EA5A7B614340DD990986737B4B40AD4ECE50DC5F4340DD990986737B4B40
15378	Ямуга	1	10	205	36.653194999999997	36.678185999999997	56.404617999999999	56.380243999999998	0103000020E610000001000000050000009274CDE49B5342400740DCD5AB304C409274CDE49B534240BCAFCA85CA334C40724D81CCCE564240BCAFCA85CA334C40724D81CCCE5642400740DCD5AB304C409274CDE49B5342400740DCD5AB304C40
16118	Шевляково	1	10	205	36.855217000000003	36.869401000000003	56.402037999999997	56.395093000000003	0103000020E61000000100000005000000DBFD2AC0776D424074F04C6892324C40DBFD2AC0776D4240E7DF2EFB75334C400B0E2F88486F4240E7DF2EFB75334C400B0E2F88486F424074F04C6892324C40DBFD2AC0776D424074F04C6892324C40
15660	Чайковского	1	10	205	36.782201999999998	36.798174000000003	56.291738000000002	56.283565000000003	0103000020E61000000100000005000000D26EF4311F64424027A5A0DB4B244C40D26EF4311F6442400F80B8AB57254C403E42CD902A6642400F80B8AB57254C403E42CD902A66424027A5A0DB4B244C40D26EF4311F64424027A5A0DB4B244C40
16185	Струбково	1	10	205	36.911065000000001	36.927737999999998	56.377527000000001	56.371375999999998	0103000020E61000000100000005000000DFC325C79D7442407842AF3F892F4C40DFC325C79D744240B22D03CE52304C40D3A0681EC0764240B22D03CE52304C40D3A0681EC07642407842AF3F892F4C40DFC325C79D7442407842AF3F892F4C40
15532	Стреглово	1	10	205	36.722689000000003	36.738382000000001	56.304200999999999	56.293985999999997	0103000020E61000000100000005000000E816BA12815C4240ADBD4F55A1254C40E816BA12815C42408B34F10EF0264C4040FA264D835E42408B34F10EF0264C4040FA264D835E4240ADBD4F55A1254C40E816BA12815C4240ADBD4F55A1254C40
15219	Спас-Заулок	1	10	205	36.55968	36.597256999999999	56.490231000000001	56.464227000000001	0103000020E61000000100000005000000D61C2098A3474240C97553CA6B3B4C40D61C2098A3474240213EB0E3BF3E4C404E27D9EA724C4240213EB0E3BF3E4C404E27D9EA724C4240C97553CA6B3B4C40D61C2098A3474240C97553CA6B3B4C40
60286	Слобода	1	10	205	36.862862	36.888482000000003	56.480733000000001	56.466748000000003	0103000020E61000000100000005000000077B1343726E424099BC0166BE3B4C40077B1343726E4240D28DB0A8883D4C40D78A36C7B9714240D28DB0A8883D4C40D78A36C7B971424099BC0166BE3B4C40077B1343726E424099BC0166BE3B4C40
15735	Селинское	1	10	205	36.621664000000003	36.645595	56.314861000000001	56.303252000000001	0103000020E61000000100000005000000DF8C9AAF924F42402A3927F6D0264C40DF8C9AAF924F424097E4805D4D284C4006BB61DBA252424097E4805D4D284C4006BB61DBA25242402A3927F6D0264C40DF8C9AAF924F42402A3927F6D0264C40
15721	Решоткино	1	10	205	36.663966000000002	36.679983	56.291533999999999	56.279176999999997	0103000020E61000000100000005000000F6D37FD6FC544240CF656A12BC234C40F6D37FD6FC54424006D671FC50254C40016BD5AE0957424006D671FC50254C40016BD5AE09574240CF656A12BC234C40F6D37FD6FC544240CF656A12BC234C40
15906	Решетниково	1	10	205	36.545746999999999	36.574314000000001	56.459322999999998	56.431494999999998	0103000020E61000000100000005000000EF71A609DB4542409AB1683A3B374C40EF71A609DB4542407AA69718CB3A4C4046D1031F834942407AA69718CB3A4C4046D1031F834942409AB1683A3B374C40EF71A609DB4542409AB1683A3B374C40
15454	Покровка	1	10	205	36.774369	36.849970999999996	56.248125999999999	56.215673000000002	0103000020E61000000100000005000000A304FD851E634240ABD0402C9B1B4C40A304FD851E634240C6A4BF97C21F4C4032C687D9CB6C4240C6A4BF97C21F4C4032C687D9CB6C4240ABD0402C9B1B4C40A304FD851E634240ABD0402C9B1B4C40
16590	Петровское	1	10	205	36.461511999999999	36.481338000000001	56.259193000000003	56.253481999999998	0103000020E61000000100000005000000145B41D3123B4240F50F221972204C40145B41D3123B4240132D793C2D214C403929CC7B9C3D4240132D793C2D214C403929CC7B9C3D4240F50F221972204C40145B41D3123B4240F50F221972204C40
15803	Першутино	1	10	205	36.648271999999999	36.678815	56.329636999999998	56.325279999999999	0103000020E61000000100000005000000CD74AF93FA5242407D0569C6A2294C40CD74AF93FA5242409946938B312A4C406284F068E35642409946938B312A4C406284F068E35642407D0569C6A2294C40CD74AF93FA5242407D0569C6A2294C40
15441	Папивино	1	10	205	36.625967000000003	36.658549000000001	56.352378000000002	56.345683000000001	0103000020E6100000010000000500000008B0C8AF1F5042403FE42D573F2C4C4008B0C8AF1F5042403AEAE8B81A2D4C4021E868554B5442403AEAE8B81A2D4C4021E868554B5442403FE42D573F2C4C4008B0C8AF1F5042403FE42D573F2C4C40
16417	Нудоль	1	10	205	36.490366000000002	36.513615000000001	56.098733000000003	56.083053999999997	0103000020E6100000010000000500000001892650C43E4240A7E67283A10A4C4001892650C43E42409B046F48A30C4C4016DEE522BE4142409B046F48A30C4C4016DEE522BE414240A7E67283A10A4C4001892650C43E4240A7E67283A10A4C40
16249	Новощапово	1	10	205	36.790439999999997	36.807839999999999	56.376340999999996	56.367466999999998	0103000020E61000000100000005000000A1B94E232D654240FBAD9D28092F4C40A1B94E232D6542406C921FF12B304C404833164D676742406C921FF12B304C404833164D67674240FBAD9D28092F4C40A1B94E232D654240FBAD9D28092F4C40
16498	Нарынка	1	10	205	36.505251000000001	36.521762000000003	56.111739999999998	56.101754999999997	0103000020E61000000100000005000000BAA29410AC4042402C9ACE4E060D4C40BAA29410AC404240D8D30E7F4D0E4C40D525E318C9424240D8D30E7F4D0E4C40D525E318C94242402C9ACE4E060D4C40BAA29410AC4042402C9ACE4E060D4C40
15581	Мисирево	1	10	205	36.747841000000001	36.756914000000002	56.278132999999997	56.256732999999997	0103000020E61000000100000005000000D1CDFE40B95F4240E8667FA0DC204C40D1CDFE40B95F42401C78B5DC99234C4039F1D58EE26042401C78B5DC99234C4039F1D58EE2604240E8667FA0DC204C40D1CDFE40B95F4240E8667FA0DC204C40
16646	Масюгино	1	10	205	36.561639	36.573146000000001	56.341672000000003	56.332970000000003	0103000020E610000001000000050000003E9468C9E34742404A46CEC29E2A4C403E9468C9E3474240BEFA78E8BB2B4C40A7EA1ED95C494240BEFA78E8BB2B4C40A7EA1ED95C4942404A46CEC29E2A4C403E9468C9E34742404A46CEC29E2A4C40
62035	Марков Лес	1	10	205	36.089816999999996	37.113320999999999	56.595896000000003	56.064273	0103000020E61000000100000005000000FACF9A1F7F0B4240068200193A084C40FACF9A1F7F0B42409BE8F351464C4C409A79724D818E42409BE8F351464C4C409A79724D818E4240068200193A084C40FACF9A1F7F0B4240068200193A084C40
16341	Кузнецово	1	10	205	36.646979000000002	36.662717000000001	56.128385000000002	56.125118999999998	0103000020E6100000010000000500000072193735D0524240DA8D3EE603104C4072193735D0524240032670EB6E104C406AC020E9D3544240032670EB6E104C406AC020E9D3544240DA8D3EE603104C4072193735D0524240DA8D3EE603104C40
776	Клин	1	10	205	36.671332	36.780566999999998	56.380259000000002	56.311810999999999	0103000020E610000001000000050000000F61FC34EE5542403BC43F6CE9274C400F61FC34EE5542403D81B053AC304C401DAB949EE96342403D81B053AC304C401DAB949EE96342403BC43F6CE9274C400F61FC34EE5542403BC43F6CE9274C40
15273	Захарово	1	10	205	36.719220999999997	36.743277999999997	56.526964	56.517192000000001	0103000020E6100000010000000500000057CC086F0F5C42405DE0F25833424C4057CC086F0F5C4240AD156D8E73434C400BEBC6BB235F4240AD156D8E73434C400BEBC6BB235F42405DE0F25833424C4057CC086F0F5C42405DE0F25833424C40
16551	Елгозино	1	10	205	36.344022000000002	36.371268000000001	56.236680999999997	56.231028000000002	0103000020E61000000100000005000000618DB3E9082C4240EB3A5453921D4C40618DB3E9082C4240D34A21904B1E4C409206B7B5852F4240D34A21904B1E4C409206B7B5852F4240EB3A5453921D4C40618DB3E9082C4240EB3A5453921D4C40
15606	Давыдково	1	10	205	36.809798000000001	36.833945	56.290903999999998	56.275393999999999	0103000020E61000000100000005000000E02EFB75A7674240DFC14F1C40234C40E02EFB75A767424046239F573C254C40D4D4B2B5BE6A424046239F573C254C40D4D4B2B5BE6A4240DFC14F1C40234C40E02EFB75A7674240DFC14F1C40234C40
16720	Высоковск	1	10	205	36.532803000000001	36.580844999999997	56.329307	56.298917000000003	0103000020E61000000100000005000000F81A82E332444240F69B89E942264C40F81A82E33244424004AC55BB262A4C40C6850321594A424004AC55BB262A4C40C6850321594A4240F69B89E942264C40F81A82E332444240F69B89E942264C40
15981	Воздвиженское	1	10	205	36.285541000000002	36.300283	56.388759999999998	56.377467000000003	0103000020E610000001000000050000006555849B8C244240DD28B2D650304C406555849B8C24424019FF3EE3C2314C40BB4560AC6F26424019FF3EE3C2314C40BB4560AC6F264240DD28B2D650304C406555849B8C244240DD28B2D650304C40
62030	Бирево	1	10	205	36.739441999999997	36.749665	56.447389000000001	56.435854999999997	0103000020E61000000100000005000000F8A41309A65E42402766BD18CA374C40F8A41309A65E42408ACBF10A44394C4059FAD005F55F42408ACBF10A44394C4059FAD005F55F42402766BD18CA374C40F8A41309A65E42402766BD18CA374C40
12844	Яковское	1	10	484	38.255941999999997	38.278920999999997	54.755487000000002	54.741394999999997	0103000020E610000001000000050000001FD61BB5C22043407E350708E65E4B401FD61BB5C2204340CEC64ACCB3604B407495EEAEB3234340CEC64ACCB3604B407495EEAEB32343407E350708E65E4B401FD61BB5C22043407E350708E65E4B40
12926	Топканово	1	10	484	38.468483999999997	38.493150999999997	54.721249999999998	54.708590999999998	0103000020E610000001000000050000008159A148F73B4340B69E211CB35A4B408159A148F73B4340B81E85EB515C4B40AE7E6C921F3F4340B81E85EB515C4B40AE7E6C921F3F4340B69E211CB35A4B408159A148F73B4340B69E211CB35A4B40
46247	Тарасково	1	10	484	37.995097999999999	38.043320000000001	54.822935999999999	54.803528	0103000020E6100000010000000500000052280B5F5FFF4240CCB56801DA664B4052280B5F5FFF4240BC5983F755694B40A1A17F828B054340BC5983F755694B40A1A17F828B054340CCB56801DA664B4052280B5F5FFF4240CCB56801DA664B40
2897	Ожерелье	1	10	484	38.235272000000002	38.289969999999997	54.814605	54.779328	0103000020E610000001000000050000000FD594641D1E4340B56D1805C1634B400FD594641D1E43403C1405FA44684B401A69A9BC1D2543403C1405FA44684B401A69A9BC1D254340B56D1805C1634B400FD594641D1E4340B56D1805C1634B40
46121	Новоселки	1	10	484	38.270127000000002	38.301423999999997	54.839474000000003	54.819507999999999	0103000020E610000001000000050000002062838593224340BA675DA3E5684B402062838593224340D1EB4FE2736B4B40601DC70F95264340D1EB4FE2736B4B40601DC70F95264340BA675DA3E5684B402062838593224340BA675DA3E5684B40
46446	Маслово	1	10	484	38.474097999999998	38.489100000000001	54.743515000000002	54.734991000000001	0103000020E61000000100000005000000AC8C463EAF3C43405BED612F145E4B40AC8C463EAF3C4340F08AE07F2B5F4B409F3C2CD49A3E4340F08AE07F2B5F4B409F3C2CD49A3E43405BED612F145E4B40AC8C463EAF3C43405BED612F145E4B40
12682	Лиды	1	10	484	38.099797000000002	38.124491999999996	54.820976000000002	54.810268000000001	0103000020E61000000100000005000000959EE925C60C4340677FA0DCB6674B40959EE925C60C43408466D7BD15694B408B4E965AEF0F43408466D7BD15694B408B4E965AEF0F4340677FA0DCB6674B40959EE925C60C4340677FA0DCB6674B40
59526	Ледово	1	10	484	38.388964999999999	38.409356000000002	54.757289999999998	54.740349999999999	0103000020E61000000100000005000000F224E99AC9314340FBCBEEC9C35E4B40F224E99AC93143403ECBF3E0EE604B40F03504C7653443403ECBF3E0EE604B40F03504C765344340FBCBEEC9C35E4B40F224E99AC9314340FBCBEEC9C35E4B40
12586	Корыстово	1	10	484	38.082692999999999	38.129432000000001	54.810355999999999	54.794263999999998	0103000020E61000000100000005000000D74D29AF950A4340F0315871AA654B40D74D29AF950A4340060FD3BEB9674B4027874F3A91104340060FD3BEB9674B4027874F3A91104340F0315871AA654B40D74D29AF950A4340F0315871AA654B40
12446	Кокино	1	10	484	38.192314000000003	38.226773999999999	54.772368999999998	54.757820000000002	0103000020E610000001000000050000000F48C2BE9D1843409B20EA3E00614B400F48C2BE9D184340DCB8C5FCDC624B40A3CA30EE061D4340DCB8C5FCDC624B40A3CA30EE061D43409B20EA3E00614B400F48C2BE9D1843409B20EA3E00614B40
10588	Кашира	1	10	484	38.131382000000002	38.261448999999999	54.860570000000003	54.816240000000001	0103000020E610000001000000050000003CA41820D1104340F1D7648D7A684B403CA41820D110434099F56228276E4B4034492C297721434099F56228276E4B4034492C2977214340F1D7648D7A684B403CA41820D1104340F1D7648D7A684B40
12437	Зендиково	1	10	484	38.142772000000001	38.170350999999997	54.814869999999999	54.797086999999998	0103000020E610000001000000050000006B64575A461243408B8862F206664B406B64575A46124340EA3E00A94D684B40A2EBC20FCE154340EA3E00A94D684B40A2EBC20FCE1543408B8862F206664B406B64575A461243408B8862F206664B40
12371	Большое Руново	1	10	484	38.388236999999997	38.427143000000001	54.858739999999997	54.845751999999997	0103000020E610000001000000050000006F0C01C0B13143406743FE99416C4B406F0C01C0B13143402EE23B31EB6D4B4090DB2F9FAC3643402EE23B31EB6D4B4090DB2F9FAC3643406743FE99416C4B406F0C01C0B13143406743FE99416C4B40
46393	Богатищево	1	10	484	38.511423000000001	38.539566999999998	54.688175000000001	54.675184000000002	0103000020E610000001000000050000000BB6114F764143402864E76D6C564B400BB6114F7641434060764F1E16584B401B800D881045434060764F1E16584B401B800D88104543402864E76D6C564B400BB6114F764143402864E76D6C564B40
46210	Барабаново	1	10	484	38.156508000000002	38.182189999999999	54.724983000000002	54.707129999999999	0103000020E61000000100000005000000FCC74274081443409F02603C835A4B40FCC7427408144340F793313ECC5C4B4041D47D0052174340F793313ECC5C4B4041D47D00521743409F02603C835A4B40FCC74274081443409F02603C835A4B40
10812	станции Манихино	1	10	204	36.924675000000001	36.944222000000003	55.901733	55.885604999999998	0103000020E61000000100000005000000E3361AC05B764240481630815BF14B40E3361AC05B764240AB5CA8FC6BF34B40F5143944DC784240AB5CA8FC6BF34B40F5143944DC784240481630815BF14B40E3361AC05B764240481630815BF14B40
60251	дачный поселок Поречье	1	10	204	37.117497999999998	37.127127999999999	55.795499	55.790483999999999	0103000020E6100000010000000500000036ACA92C0A8F4240710168942EE54B4036ACA92C0A8F4240178046E9D2E54B40F433F5BA45904240178046E9D2E54B40F433F5BA45904240710168942EE54B4036ACA92C0A8F4240710168942EE54B40
60278	Снегири	1	10	204	37.009583999999997	37.070650999999998	55.896780999999997	55.869464999999998	0103000020E610000001000000050000004D486B0C3A81424021020EA14AEF4B404D486B0C3A8142404B5645B8C9F24B4000378B170B8942404B5645B8C9F24B4000378B170B89424021020EA14AEF4B404D486B0C3A81424021020EA14AEF4B40
10166	Снегири	1	10	204	37.009583999999997	37.070650999999998	55.896780999999997	55.869464999999998	0103000020E610000001000000050000004D486B0C3A81424021020EA14AEF4B404D486B0C3A8142404B5645B8C9F24B4000378B170B8942404B5645B8C9F24B4000378B170B89424021020EA14AEF4B404D486B0C3A81424021020EA14AEF4B40
11073	Северный	1	10	204	36.828825000000002	36.846566000000003	55.950338000000002	55.939937999999998	0103000020E61000000100000005000000B98D06F0166A424042226DE34FF84B40B98D06F0166A4240B212F3ACA4F94B40E9F351465C6C4240B212F3ACA4F94B40E9F351465C6C424042226DE34FF84B40B98D06F0166A424042226DE34FF84B40
11756	Савельево	1	10	204	36.592728999999999	36.611513000000002	56.010649000000001	56.000145000000003	0103000020E6100000010000000500000005323B8BDE4B4240042159C004004C4005323B8BDE4B4240185E49F25C014C40180AD80E464E4240185E49F25C014C40180AD80E464E4240042159C004004C4005323B8BDE4B4240042159C004004C40
11210	Румянцево	1	10	204	36.521484000000001	36.561126999999999	55.981968000000002	55.963107999999998	0103000020E6100000010000000500000092B1DAFCBF4242400B42791F47FB4B4092B1DAFCBF424240F9DB9E20B1FD4B4088F37002D3474240F9DB9E20B1FD4B4088F37002D34742400B42791F47FB4B4092B1DAFCBF4242400B42791F47FB4B40
60280	Рождествено	1	10	204	37.040522000000003	37.067174999999999	55.864035000000001	55.844085999999997	0103000020E610000001000000050000005F622CD32F854240778192020BEC4B405F622CD32F854240B8CCE9B298EE4B40ED0DBE3099884240B8CCE9B298EE4B40ED0DBE3099884240778192020BEC4B405F622CD32F854240778192020BEC4B40
11272	Пречистое	1	10	204	36.497373000000003	36.516300999999999	56.071353999999999	56.065036999999997	0103000020E61000000100000005000000EB7420EBA93F4240D503E62153084C40EB7420EBA93F42402A38BC2022094C4030F2B226164242402A38BC2022094C4030F2B22616424240D503E62153084C40EB7420EBA93F4240D503E62153084C40
11348	Покровское	1	10	204	37.001255999999998	37.019860000000001	55.818340999999997	55.804789	0103000020E610000001000000050000003E761728298042401C97715303E74B403E76172829804240EBFCDB65BFE84B40D13FC1C58A824240EBFCDB65BFE84B40D13FC1C58A8242401C97715303E74B403E761728298042401C97715303E74B40
11010	Первомайский	1	10	204	36.784205	36.801597000000001	55.917535999999998	55.910705	0103000020E610000001000000050000000A2E56D460644240DFA63FFB91F44B400A2E56D4606442408A73D4D171F54B402EC901BB9A6642408A73D4D171F54B402EC901BB9A664240DFA63FFB91F44B400A2E56D460644240DFA63FFB91F44B40
10780	Павловское	1	10	204	36.941445999999999	36.963876999999997	55.876899999999999	55.866171999999999	0103000020E610000001000000050000009A79724D81784240FF5A5EB9DEEE4B409A79724D8178424063EE5A423EF04B40EC2E5052607B424063EE5A423EF04B40EC2E5052607B4240FF5A5EB9DEEE4B409A79724D81784240FF5A5EB9DEEE4B40
773	Павловская Слобода	1	10	204	37.058954999999997	37.098210999999999	55.823524999999997	55.800047999999997	0103000020E61000000100000005000000C47762D68B874240779D0DF967E64B40C47762D68B8742401D38674469E94B40C18D942D928C42401D38674469E94B40C18D942D928C4240779D0DF967E64B40C47762D68B874240779D0DF967E64B40
11402	Онуфриево	1	10	204	36.497427000000002	36.522032000000003	55.857078000000001	55.845303999999999	0103000020E61000000100000005000000DE921CB0AB3F4240C896E5EB32EC4B40DE921CB0AB3F4240800F5EBBB4ED4B4095BBCFF1D1424240800F5EBBB4ED4B4095BBCFF1D1424240C896E5EB32EC4B40DE921CB0AB3F4240C896E5EB32EC4B40
11150	Новопетровское	1	10	204	36.447704999999999	36.497418000000003	56.005983999999998	55.980291000000001	0103000020E61000000100000005000000BAA0BE654E39424015C8EC2C7AFD4B40BAA0BE654E3942404E266E15C4004C408B389D64AB3F42404E266E15C4004C408B389D64AB3F424015C8EC2C7AFD4B40BAA0BE654E39424015C8EC2C7AFD4B40
18678	Новодарьино	1	10	204	36.665556000000002	36.675742999999997	55.893076000000001	55.889234999999999	0103000020E610000001000000050000000BD462F030554240B2BAD573D2F14B400BD462F030554240D76B7A5050F24B401EC022BF7E564240D76B7A5050F24B401EC022BF7E564240B2BAD573D2F14B400BD462F030554240B2BAD573D2F14B40
40338	Лучинское	1	10	204	36.812007999999999	36.832129999999999	55.914534000000003	55.902706999999999	0103000020E61000000100000005000000910BCEE0EF674240656F29E78BF34B40910BCEE0EF674240408A3A730FF54B409F02603C836A4240408A3A730FF54B409F02603C836A4240656F29E78BF34B40910BCEE0EF674240656F29E78BF34B40
11662	Курсаково	1	10	204	36.559266999999998	36.577520999999997	55.968699999999998	55.956501000000003	0103000020E61000000100000005000000B35DA10F96474240B0CBF09F6EFA4B40B35DA10F964742404ED1915CFEFB4B4069E04735EC4942404ED1915CFEFB4B4069E04735EC494240B0CBF09F6EFA4B40B35DA10F96474240B0CBF09F6EFA4B40
62008	Котово	1	10	204	36.752763999999999	36.768835000000003	55.875853999999997	55.866612000000003	0103000020E6100000010000000500000096CD1C925A6042401C295B24EDEE4B4096CD1C925A6042400F09DFFB1BF04B4095826E2F696242400F09DFFB1BF04B4095826E2F696242401C295B24EDEE4B4096CD1C925A6042401C295B24EDEE4B40
10871	Кострово	1	10	204	36.679758	36.708765	55.897098999999997	55.889836000000003	0103000020E61000000100000005000000E198654F02574240D8666325E6F14B40E198654F025742401C23D923D4F24B4054C6BFCFB85A42401C23D923D4F24B4054C6BFCFB85A4240D8666325E6F14B40E198654F02574240D8666325E6F14B40
48961	Кашино	1	10	204	36.904983999999999	36.924073	55.933624999999999	55.927145000000003	0103000020E610000001000000050000009EB30584D673424031D3F6AFACF64B409EB30584D67342402FDD240681F74B40ED0E2906487642402FDD240681F74B40ED0E29064876424031D3F6AFACF64B409EB30584D673424031D3F6AFACF64B40
9201	Истра	1	10	204	36.817075000000003	36.901139000000001	55.932395	55.890295000000002	0103000020E610000001000000050000008AB0E1E9956842406B65C22FF5F14B408AB0E1E9956842401AFA27B858F74B403813D385587342401AFA27B858F74B403813D385587342406B65C22FF5F14B408AB0E1E9956842406B65C22FF5F14B40
11320	Деньково	1	10	204	36.334606999999998	36.364620000000002	56.009864	56.003582999999999	0103000020E610000001000000050000009F01F566D42A424029E9616875004C409F01F566D42A424031B43A3943014C40D8BB3FDEAB2E424031B43A3943014C40D8BB3FDEAB2E424029E9616875004C409F01F566D42A424029E9616875004C40
875	Дедовск	1	10	204	37.092274000000003	37.148212000000001	55.895221999999997	55.847769999999997	0103000020E61000000100000005000000B4226AA2CF8B4240D44334BA83EC4B40B4226AA2CF8B424071546EA296F24B40F86F5E9CF892424071546EA296F24B40F86F5E9CF8924240D44334BA83EC4B40B4226AA2CF8B4240D44334BA83EC4B40
49687	Глебовский	1	10	204	36.678662000000003	36.716625000000001	55.948210000000003	55.929777000000001	0103000020E61000000100000005000000DC847B65DE56424058C9C7EE02F74B40DC847B65DE564240BEDEFDF15EF94B407D3F355EBA5B4240BEDEFDF15EF94B407D3F355EBA5B424058C9C7EE02F74B40DC847B65DE56424058C9C7EE02F74B40
59516	Восход	1	10	204	36.449745	36.465339	55.978619000000002	55.970911999999998	0103000020E610000001000000050000000F45813E91394240A0A52BD846FC4B400F45813E91394240431F2C6343FD4B40D446753A903B4240431F2C6343FD4B40D446753A903B4240A0A52BD846FC4B400F45813E91394240A0A52BD846FC4B40
10359	Бужарово	1	10	204	36.777090999999999	36.810130999999998	55.990991999999999	55.977449999999997	0103000020E610000001000000050000000A82C7B777634240D3BCE3141DFD4B400A82C7B7776342407F4C6BD3D8FE4B40E63C635FB26742407F4C6BD3D8FE4B40E63C635FB2674240D3BCE3141DFD4B400A82C7B777634240D3BCE3141DFD4B40
10701	Агрогородок	1	10	204	36.955792000000002	36.967156000000003	55.925859000000003	55.908817999999997	0103000020E61000000100000005000000A4E36A64577A42401002F22554F44B40A4E36A64577A424088DA368C82F64B40AA108FC4CB7B424088DA368C82F64B40AA108FC4CB7B42401002F22554F44B40A4E36A64577A42401002F22554F44B40
62021	центральной усадьбы совхоза "40 лет Октября"	1	10	886	38.630046	38.652881000000001	54.784607999999999	54.767456000000003	0103000020E61000000100000005000000E17CEA58A55043403B8F8AFF3B624B40E17CEA58A55043400917F2086E644B400397C79A915343400917F2086E644B400397C79A915343403B8F8AFF3B624B40E17CEA58A55043403B8F8AFF3B624B40
7540	Чулки-Соколово	1	10	886	38.823416999999999	38.843988000000003	54.741686000000001	54.727058	0103000020E6100000010000000500000037FC6EBA65694340C8258E3C105D4B4037FC6EBA6569434056F31C91EF5E4B40B51B7DCC076C434056F31C91EF5E4B40B51B7DCC076C4340C8258E3C105D4B4037FC6EBA65694340C8258E3C105D4B40
7860	Протекино	1	10	886	38.777351000000003	38.805289000000002	54.831094	54.819325999999997	0103000020E61000000100000005000000A741D13C806343409961A3ACDF684B40A741D13C806343406FF3C649616A4B400E6ABFB5136743406FF3C649616A4B400E6ABFB5136743409961A3ACDF684B40A741D13C806343409961A3ACDF684B40
62026	Новоселки	1	10	886	38.900807	38.918072000000002	54.831592000000001	54.812145999999998	0103000020E610000001000000050000000281CEA44D734340E2C96E66F4674B400281CEA44D734340C0CE4D9B716A4B40C9AF1F6283754340C0CE4D9B716A4B40C9AF1F6283754340E2C96E66F4674B400281CEA44D734340E2C96E66F4674B40
7845	Мендюкино	1	10	886	38.839613999999997	38.856250000000003	54.784981999999999	54.767212000000001	0103000020E61000000100000005000000C2A1B778786B4340A48CB80034624B40C2A1B778786B43406EF9484A7A644B409A999999996D43406EF9484A7A644B409A999999996D4340A48CB80034624B40C2A1B778786B4340A48CB80034624B40
7787	Масловский	1	10	886	39.075223999999999	39.093612	54.784047000000001	54.771351000000003	0103000020E61000000100000005000000E9EFA5F0A0894340535E2BA1BB624B40E9EFA5F0A089434072C3EFA65B644B40AF415F7AFB8B434072C3EFA65B644B40AF415F7AFB8B4340535E2BA1BB624B40E9EFA5F0A0894340535E2BA1BB624B40
48652	Макеево	1	10	886	39.107014999999997	39.137242999999998	54.677422	54.661766	0103000020E610000001000000050000003997E2AAB28D434068CD8FBFB4544B403997E2AAB28D4340A3CB9BC3B5564B406E4DBA2D91914340A3CB9BC3B5564B406E4DBA2D9191434068CD8FBFB4544B403997E2AAB28D434068CD8FBFB4544B40
7420	Летуново	1	10	886	39.002513999999998	39.028044000000001	54.706713999999998	54.694060999999998	0103000020E610000001000000050000001DE4F56052804340EB36A8FDD6584B401DE4F560528043400BD0B69A755A4B40AD6C1FF2968343400BD0B69A755A4B40AD6C1FF296834340EB36A8FDD6584B401DE4F56052804340EB36A8FDD6584B40
7412	Зарайский	1	10	886	38.997563999999997	39.013311999999999	54.693364000000003	54.685640999999997	0103000020E610000001000000050000005ED5592DB07F4340FBE59315C3574B405ED5592DB07F4340A41CCC26C0584B407A522635B4814340A41CCC26C0584B407A522635B4814340FBE59315C3574B405ED5592DB07F4340FBE59315C3574B40
6754	Зарайск	1	10	886	38.853051999999998	38.908281000000002	54.798473000000001	54.744134000000003	0103000020E61000000100000005000000C9E4D4CE306D4340BCEB6CC83F5F4B40C9E4D4CE306D434098DEFE5C34664B40024A438D4274434098DEFE5C34664B40024A438D42744340BCEB6CC83F5F4B40C9E4D4CE306D4340BCEB6CC83F5F4B40
7608	Журавна	1	10	886	38.578851	38.587879000000001	54.677979000000001	54.668467999999997	0103000020E61000000100000005000000E22021CA174A43401536035C90554B40E22021CA174A4340F92F1004C8564B40AA807B9E3F4B4340F92F1004C8564B40AA807B9E3F4B43401536035C90554B40E22021CA174A43401536035C90554B40
7730	Ерново	1	10	886	38.997096999999997	39.020587999999996	54.765461999999999	54.749153999999997	0103000020E6100000010000000500000048F8DEDFA07F434073D53C47E45F4B4048F8DEDFA07F4340562AA8A8FA614B405358A9A0A2824340562AA8A8FA614B405358A9A0A282434073D53C47E45F4B4048F8DEDFA07F434073D53C47E45F4B40
7664	Гололобово	1	10	886	38.909458000000001	38.931896999999999	54.768827000000002	54.758251000000001	0103000020E61000000100000005000000F48AA71E697443406494675E0E614B40F48AA71E6974434012A452EC68624B40C91EA1664877434012A452EC68624B40C91EA166487743406494675E0E614B40F48AA71E697443406494675E0E614B40
48679	Алферьево	1	10	886	38.742164000000002	38.763579999999997	54.661630000000002	54.644269999999999	0103000020E610000001000000050000006022DE3AFF5E43409FE5797077524B406022DE3AFF5E4340B806B64AB0544B4099F04BFDBC614340B806B64AB0544B4099F04BFDBC6143409FE5797077524B406022DE3AFF5E43409FE5797077524B40
11493	Авдеево	1	10	886	38.869149999999998	38.890152999999998	54.678561999999999	54.662661999999997	0103000020E61000000100000005000000C1A8A44E406F4340A626C11BD2544B40C1A8A44E406F434078279F1EDB564B40D8B79388F071434078279F1EDB564B40D8B79388F0714340A626C11BD2544B40C1A8A44E406F4340A626C11BD2544B40
2535	Юрцово	1	10	81	39.183793999999999	39.204670999999998	55.323956000000003	55.310606	0103000020E61000000100000005000000BB99D18F869743407FF8F9EFC1A74B40BB99D18F86974340E7ABE46377A94B4045B8C9A8329A4340E7ABE46377A94B4045B8C9A8329A43407FF8F9EFC1A74B40BB99D18F869743407FF8F9EFC1A74B40
60225	Шувое	1	10	81	39.051561999999997	39.116788999999997	55.479351999999999	55.457771000000001	0103000020E61000000100000005000000B1DB6795998643405307793D98BA4B40B1DB679599864340D7A205685BBD4B402AC423F1F28E4340D7A205685BBD4B402AC423F1F28E43405307793D98BA4B40B1DB6795998643405307793D98BA4B40
1879	Челохово	1	10	81	38.913302000000002	38.919787999999997	55.384287999999998	55.369725000000003	0103000020E610000001000000050000008AAF7614E7744340BEC1172653AF4B408AAF7614E7744340641F645930B14B406AA0F99CBB754340641F645930B14B406AA0F99CBB754340BEC1172653AF4B408AAF7614E7744340BEC1172653AF4B40
2982	Старое	1	10	81	39.200125	39.216807000000003	55.177303000000002	55.158358999999997	0103000020E61000000100000005000000560E2DB29D9943407D03931B45944B40560E2DB29D994340C93D5DDDB1964B409E45EF54C09B4340C93D5DDDB1964B409E45EF54C09B43407D03931B45944B40560E2DB29D9943407D03931B45944B40
391	Селиваниха	1	10	81	39.068693000000003	39.097707999999997	55.402388000000002	55.391666999999998	0103000020E61000000100000005000000693BA6EECA88434012F6ED2422B24B40693BA6EECA884340C426327381B34B405E471CB2818C4340C426327381B34B405E471CB2818C434012F6ED2422B24B40693BA6EECA88434012F6ED2422B24B40
2238	Саввино	1	10	81	39.177748000000001	39.222718	55.437438999999998	55.422538000000003	0103000020E61000000100000005000000F7764B72C09643409CA8A5B915B64B40F7764B72C09643405A7F4B00FEB74B40821DFF05829C43405A7F4B00FEB74B40821DFF05829C43409CA8A5B915B64B40F7764B72C09643409CA8A5B915B64B40
61902	Рязановский	1	10	81	39.534928000000001	39.566198	55.143332000000001	55.122771	0103000020E610000001000000050000007BDB4C8578C44340D8F2CAF5B68F4B407BDB4C8578C44340323CF6B358924B40C287122D79C84340323CF6B358924B40C287122D79C84340D8F2CAF5B68F4B407BDB4C8578C44340D8F2CAF5B68F4B40
2933	Раменки	1	10	81	39.137684	39.16086	55.178207999999998	55.164464000000002	0103000020E610000001000000050000005B971AA19F91434047AF06280D954B405B971AA19F9143405AF10D85CF964B40069E7B0F979443405AF10D85CF964B40069E7B0F9794434047AF06280D954B405B971AA19F91434047AF06280D954B40
3283	Радовицы	1	10	81	39.511868	39.550162999999998	55.107112999999998	55.087048000000003	0103000020E6100000010000000500000039EFFFE384C1434053978C63248B4B4039EFFFE384C14340FCFCF7E0B58D4B40103CBEBD6BC64340FCFCF7E0B58D4B40103CBEBD6BC6434053978C63248B4B4039EFFFE384C1434053978C63248B4B40
2635	Починки	1	10	81	39.426940999999999	39.459055999999997	55.275343999999997	55.260562	0103000020E610000001000000050000002829B000A6B64340494A7A185AA14B402829B000A6B643402D93E1783EA34B402B84D558C2BA43402D93E1783EA34B402B84D558C2BA4340494A7A185AA14B402829B000A6B64340494A7A185AA14B40
3078	Поповская	1	10	81	39.267848999999998	39.292912000000001	55.182443999999997	55.169550000000001	0103000020E6100000010000000500000016A243E048A24340B6847CD0B3954B4016A243E048A24340FBAC32535A974B40904DF2237EA54340FBAC32535A974B40904DF2237EA54340B6847CD0B3954B4016A243E048A24340B6847CD0B3954B40
2718	Полбино	1	10	81	39.288780000000003	39.314391000000001	55.266993999999997	55.251434000000003	0103000020E6100000010000000500000094DE37BEF6A443401E8D43FD2EA04B4094DE37BEF6A44340361D01DC2CA24B401094DBF63DA84340361D01DC2CA24B401094DBF63DA843401E8D43FD2EA04B4094DE37BEF6A443401E8D43FD2EA04B40
59564	Новый	1	10	81	38.985616999999998	39.005558999999998	55.419539	55.406083000000002	0103000020E61000000100000005000000D9B0A6B2287E4340153B1A87FAB34B40D9B0A6B2287E4340C2323674B3B54B4067994528B6804340C2323674B3B54B4067994528B6804340153B1A87FAB34B40D9B0A6B2287E4340153B1A87FAB34B40
3070	Никиткино	1	10	81	39.300961000000001	39.329158999999997	55.163276000000003	55.149670999999998	0103000020E610000001000000050000008C2FDAE385A643406E14596B28934B408C2FDAE385A64340611C5C3AE6944B408F17D2E121AA4340611C5C3AE6944B408F17D2E121AA43406E14596B28934B408C2FDAE385A643406E14596B28934B40
2829	Михали	1	10	81	39.064390000000003	39.108379999999997	55.308233999999999	55.279933999999997	0103000020E61000000100000005000000401878EE3D884340EC8497E0D4A34B40401878EE3D884340F4C1323674A74B402EC55565DF8D4340F4C1323674A74B402EC55565DF8D4340EC8497E0D4A34B40401878EE3D884340EC8497E0D4A34B40
3187	Лелечи	1	10	81	39.350997	39.369160999999998	55.202475999999997	55.192830999999998	0103000020E610000001000000050000003FFF3D78EDAC4340D653ABAFAE984B403FFF3D78EDAC4340C91CCBBBEA994B40B5FAEAAA40AF4340C91CCBBBEA994B40B5FAEAAA40AF4340D653ABAFAE984B403FFF3D78EDAC4340D653ABAFAE984B40
2038	Костылево	1	10	81	39.070948000000001	39.081701000000002	55.443950000000001	55.435308999999997	0103000020E61000000100000005000000BADBF5D214894340C5538F34B8B74B40BADBF5D2148943409487855AD3B84B407786A92D758A43409487855AD3B84B407786A92D758A4340C5538F34B8B74B40BADBF5D214894340C5538F34B8B74B40
2894	Колычево	1	10	81	39.037027000000002	39.056035999999999	55.235774999999997	55.221567999999998	0103000020E61000000100000005000000D508FD4CBD84434089EB18575C9C4B40D508FD4CBD844340711B0DE02D9E4B4007B309302C874340711B0DE02D9E4B4007B309302C87434089EB18575C9C4B40D508FD4CBD84434089EB18575C9C4B40
2400	Клеменово	1	10	81	39.148130999999999	39.160221999999997	55.397623000000003	55.385576999999998	0103000020E610000001000000050000000B43E4F4F59243407E8B4E965AB14B400B43E4F4F592434097917A4FE5B24B40C30C8D278294434097917A4FE5B24B40C30C8D27829443407E8B4E965AB14B400B43E4F4F59243407E8B4E965AB14B40
2500	Иваново	1	10	81	39.212468000000001	39.235267999999998	55.382134999999998	55.373429000000002	0103000020E6100000010000000500000028B9C326329B434062307F85CCAF4B4028B9C326329B434017D4B7CCE9B04B40CDE506431D9E434017D4B7CCE9B04B40CDE506431D9E434062307F85CCAF4B4028B9C326329B434062307F85CCAF4B40
2142	Захарово	1	10	81	39.059215999999999	39.076742000000003	55.347572	55.332436999999999	0103000020E6100000010000000500000031B3CF63948743407C7DAD4B8DAA4B4031B3CF6394874340AE80423D7DAC4B40651D8EAED2894340AE80423D7DAC4B40651D8EAED28943407C7DAD4B8DAA4B4031B3CF63948743407C7DAD4B8DAA4B40
98	Егорьевск	1	10	81	38.992182999999997	39.090989	55.405898999999998	55.355786999999999	0103000020E61000000100000005000000D65240DAFF7E4340C5ABAC6D8AAD4B40D65240DAFF7E4340533D997FF4B34B40DBA50D87A58B4340533D997FF4B34B40DBA50D87A58B4340C5ABAC6D8AAD4B40D65240DAFF7E4340C5ABAC6D8AAD4B40
2734	Дмитровка	1	10	81	39.244143000000001	39.276240000000001	55.272185	55.265466000000004	0103000020E610000001000000050000000F46EC13409F4340981936CAFAA14B400F46EC13409F43401BBB44F5D6A24B406CEC12D55BA343401BBB44F5D6A24B406CEC12D55BA34340981936CAFAA14B400F46EC13409F4340981936CAFAA14B40
48632	Данилово	1	10	81	39.058146999999998	39.071235000000001	55.420178	55.417321999999999	0103000020E6100000010000000500000025AE635C718743405EF3AACE6AB54B4025AE635C71874340D53F8864C8B54B4050AA7D3A1E894340D53F8864C8B54B4050AA7D3A1E8943405EF3AACE6AB54B4025AE635C718743405EF3AACE6AB54B40
2292	Верейка	1	10	81	39.294026000000002	39.313214000000002	55.436059999999998	55.428581999999999	0103000020E610000001000000050000003C16DBA4A2A54340BFD364C6DBB64B403C16DBA4A2A54340008C67D0D0B74B401E53776517A84340008C67D0D0B74B401E53776517A84340BFD364C6DBB64B403C16DBA4A2A54340BFD364C6DBB64B40
2389	Большое Гридино	1	10	81	39.393892000000001	39.433059	55.438991999999999	55.425010999999998	0103000020E61000000100000005000000F913950D6BB243405AB8ACC266B64B40F913950D6BB24340529ACDE330B84B40861E317A6EB74340529ACDE330B84B40861E317A6EB743405AB8ACC266B64B40F913950D6BB243405AB8ACC266B64B40
2050	Бережки	1	10	81	39.084144000000002	39.102901000000003	55.368307999999999	55.358058999999997	0103000020E61000000100000005000000CB13083BC58A4340EC8497E0D4AD4B40CB13083BC58A4340766D6FB724AF4B40E4DC26DC2B8D4340766D6FB724AF4B40E4DC26DC2B8D4340EC8497E0D4AD4B40CB13083BC58A4340EC8497E0D4AD4B40
3336	Алферово	1	10	81	39.465406999999999	39.493273000000002	55.174850999999997	55.157156000000001	0103000020E610000001000000050000002C2AE27492BB4340622F14B01D944B402C2AE27492BB434021567F8461964B40FA7FD59123BF434021567F8461964B40FA7FD59123BF4340622F14B01D944B402C2AE27492BB4340622F14B01D944B40
59565	совхоза Останкино	1	10	749	37.392373999999997	37.429178	56.063122	56.042395999999997	0103000020E610000001000000050000007DE6AC4F39B2424098BD6C3B6D054C407DE6AC4F39B242403DD4B66114084C40D314014EEFB642403DD4B66114084C40D314014EEFB6424098BD6C3B6D054C407DE6AC4F39B2424098BD6C3B6D054C40
62060	совхоза Буденновец	1	10	749	37.610709	37.647801000000001	56.388770000000001	56.372821999999999	0103000020E61000000100000005000000BA2F67B62BCE42405A9D9CA1B82F4C40BA2F67B62BCE42403DD52137C3314C4076A8A624EBD242403DD52137C3314C4076A8A624EBD242405A9D9CA1B82F4C40BA2F67B62BCE42405A9D9CA1B82F4C40
59558	сельское поселение Габовское	1	10	749	36.97428	37.879781999999999	56.696613999999997	56.032881000000003	0103000020E61000000100000005000000CD920035B57C424074D4D17135044C40CD920035B57C4240C6F7C5A52A594C4003CE52B29CF04240C6F7C5A52A594C4003CE52B29CF0424074D4D17135044C40CD920035B57C424074D4D17135044C40
58955	п. Горшково	1	10	749	37.399766999999997	37.431629999999998	56.383842000000001	56.370927000000002	0103000020E610000001000000050000009082A7902BB34240091A33897A2F4C409082A7902BB34240666A12BC21314C407AFCDEA63FB74240666A12BC21314C407AFCDEA63FB74240091A33897A2F4C409082A7902BB34240091A33897A2F4C40
59515	г. Дмитров	1	10	749	37.489356000000001	37.570483000000003	56.401713999999998	56.317926999999997	0103000020E61000000100000005000000FA0CA837A3BE4240F8C1F9D4B1284C40FA0CA837A3BE4240342C465D6B334C4045F6419605C94240342C465D6B334C4045F6419605C94240F8C1F9D4B1284C40FA0CA837A3BE4240F8C1F9D4B1284C40
24478	Яхрома	1	10	749	37.445554000000001	37.519027000000001	56.312660000000001	56.274559000000004	0103000020E610000001000000050000000E4DD9E907B9424047E9D2BF24234C400E4DD9E907B9424039622D3E05284C40D95E0B7A6FC2424039622D3E05284C40D95E0B7A6FC2424047E9D2BF24234C400E4DD9E907B9424047E9D2BF24234C40
26798	Якоть	1	10	749	37.711095999999998	37.724220000000003	56.404268999999999	56.394824	0103000020E610000001000000050000008028983105DB424084D6C39789324C408028983105DB4240B0E42A16BF334C40F88DAF3DB3DC4240B0E42A16BF334C40F88DAF3DB3DC424084D6C39789324C408028983105DB424084D6C39789324C40
61991	Целеево	1	10	749	37.486787	37.511625000000002	56.245060000000002	56.232944000000003	0103000020E61000000100000005000000198F52094FBE424054E6E61BD11D4C40198F52094FBE424065C746205E1F4C40736891ED7CC1424065C746205E1F4C40736891ED7CC1424054E6E61BD11D4C40198F52094FBE424054E6E61BD11D4C40
20896	Тютьково	1	10	749	37.214596999999998	37.223356000000003	56.350647000000002	56.347025000000002	0103000020E61000000100000005000000EC681CEA779B42407CF2B0506B2C4C40EC681CEA779B424063B83A00E22C4C40C5AEEDED969C424063B83A00E22C4C40C5AEEDED969C42407CF2B0506B2C4C40EC681CEA779B42407CF2B0506B2C4C40
62038	Татищево	1	10	749	37.493927999999997	37.519385999999997	56.402048000000001	56.386374000000004	0103000020E61000000100000005000000124A5F0839BF42402A0307B474314C40124A5F0839BF42400BB6114F76334C4008008E3D7BC242400BB6114F76334C4008008E3D7BC242402A0307B474314C40124A5F0839BF42402A0307B474314C40
60240	Синьково	1	10	749	37.291834000000001	37.314526000000001	56.393219999999999	56.384779000000002	0103000020E6100000010000000500000031EE06D15AA542400398327040314C4031EE06D15AA542400A11700855324C40F0DE516342A842400A11700855324C40F0DE516342A842400398327040314C4031EE06D15AA542400398327040314C40
25929	Семеновское	1	10	749	37.116115000000001	37.135258	56.328898000000002	56.317168000000002	0103000020E610000001000000050000009BC937DBDC8E42403BAB05F698284C409BC937DBDC8E424023DC6454192A4C40DD4257225091424023DC6454192A4C40DD425722509142403BAB05F698284C409BC937DBDC8E42403BAB05F698284C40
26148	Рогачево	1	10	749	37.139524999999999	37.195372999999996	56.440542999999998	56.422165999999997	0103000020E61000000100000005000000B9FC87F4DB914240D7BD158909364C40B9FC87F4DB914240A9BD88B663384C40BDC282FB01994240A9BD88B663384C40BDC282FB01994240D7BD158909364C40B9FC87F4DB914240D7BD158909364C40
27717	Приозерье	1	10	749	37.366591999999997	37.374012	56.092536000000003	56.084581	0103000020E61000000100000005000000D47C957CECAE4240766EDA8CD30A4C40D47C957CECAE4240F1D93A38D80B4C40E1270EA0DFAF4240F1D93A38D80B4C40E1270EA0DFAF4240766EDA8CD30A4C40D47C957CECAE4240766EDA8CD30A4C40
26301	Покровское	1	10	749	37.037872	37.064470999999998	56.416381000000001	56.408219000000003	0103000020E6100000010000000500000091B75CFDD88442408C4D2B8540344C4091B75CFDD884424080D6FCF84B354C402C45F2954088424080D6FCF84B354C402C45F295408842408C4D2B8540344C4091B75CFDD88442408C4D2B8540344C40
25036	Подъячево	1	10	749	37.240163000000003	37.260258	56.267757000000003	56.258248000000002	0103000020E61000000100000005000000C95A43A9BD9E4240F3203D450E214C40C95A43A9BD9E4240362383DC45224C40DD42572250A14240362383DC45224C40DD42572250A14240F3203D450E214C40C95A43A9BD9E4240F3203D450E214C40
59504	Подосинки	1	10	749	37.534568	37.563142999999997	56.210667000000001	56.194954000000003	0103000020E610000001000000050000007BBE66B96CC44240B91CAF40F4184C407BBE66B96CC4424058ACE122F71A4C4054FCDF1115C8424058ACE122F71A4C4054FCDF1115C84240B91CAF40F4184C407BBE66B96CC44240B91CAF40F4184C40
59588	Орудьево	1	10	749	37.507987	37.533768999999999	56.448951000000001	56.421563999999996	0103000020E6100000010000000500000086E5CFB705C14240E19524CFF5354C4086E5CFB705C14240D540F33977394C402F4FE78A52C44240D540F33977394C402F4FE78A52C44240E19524CFF5354C4086E5CFB705C14240E19524CFF5354C40
61993	Орево	1	10	749	37.455677999999999	37.475351000000003	56.437421999999998	56.425930000000001	0103000020E61000000100000005000000DBC01DA853BA42405131CEDF84364C40DBC01DA853BA42408446B071FD374C407A8F334DD8BC42408446B071FD374C407A8F334DD8BC42405131CEDF84364C40DBC01DA853BA42405131CEDF84364C40
26715	Ольявидово	1	10	749	37.750757	37.763441	56.508118000000003	56.499617999999998	0103000020E610000001000000050000001D1F2DCE18E04240183F8D7BF33F4C401D1F2DCE18E042402541B8020A414C4078B6476FB8E142402541B8020A414C4078B6476FB8E14240183F8D7BF33F4C401D1F2DCE18E04240183F8D7BF33F4C40
25042	Ольгово	1	10	749	37.332357000000002	37.349874	56.276608000000003	56.263907000000003	0103000020E6100000010000000500000060CC96AC8AAA4240BE175FB4C7214C4060CC96AC8AAA4240EFE714E467234C4040DCD5ABC8AC4240EFE714E467234C4040DCD5ABC8AC4240BE175FB4C7214C4060CC96AC8AAA4240BE175FB4C7214C40
25636	Новосиньково	1	10	749	37.310276999999999	37.338017000000001	56.392297999999997	56.367556999999998	0103000020E61000000100000005000000BAD91F28B7A742403B35971B0C2F4C40BAD91F28B7A74240A22424D236324C40FB3E1C2444AB4240A22424D236324C40FB3E1C2444AB42403B35971B0C2F4C40BAD91F28B7A742403B35971B0C2F4C40
26605	Новое Гришино	1	10	749	37.633913	37.654412000000001	56.201974999999997	56.191212999999998	0103000020E610000001000000050000002FC1A90F24D14240F7C8E6AA79184C402FC1A90F24D1424007CE1951DA194C40130EBDC5C3D3424007CE1951DA194C40130EBDC5C3D34240F7C8E6AA79184C402FC1A90F24D14240F7C8E6AA79184C40
46306	Никулино	1	10	749	37.698779999999999	37.711841999999997	56.231772999999997	56.228110000000001	0103000020E61000000100000005000000A88C7F9F71D94240FEF15EB5321D4C40A88C7F9F71D94240438CD7BCAA1D4C40A9F57EA31DDB4240438CD7BCAA1D4C40A9F57EA31DDB4240FEF15EB5321D4C40A88C7F9F71D94240FEF15EB5321D4C40
25396	Некрасовский	1	10	749	37.481755999999997	37.518281999999999	56.101238000000002	56.067103000000003	0103000020E610000001000000050000006D533C2EAABD4240543BC3D496084C406D533C2EAABD4240658EE55DF50C4C40800D881057C24240658EE55DF50C4C40800D881057C24240543BC3D496084C406D533C2EAABD4240543BC3D496084C40
60239	Некрасовский	1	10	749	37.481755999999997	37.518281999999999	56.101238000000002	56.067103000000003	0103000020E610000001000000050000006D533C2EAABD4240543BC3D496084C406D533C2EAABD4240658EE55DF50C4C40800D881057C24240658EE55DF50C4C40800D881057C24240543BC3D496084C406D533C2EAABD4240543BC3D496084C40
62017	Настасьино	1	10	749	37.449066000000002	37.458390999999999	56.358307000000003	56.344121999999999	0103000020E610000001000000050000006EDFA3FE7AB94240C4EA8F300C2C4C406EDFA3FE7AB94240C576F700DD2D4C40EFE3688EACBA4240C576F700DD2D4C40EFE3688EACBA4240C4EA8F300C2C4C406EDFA3FE7AB94240C4EA8F300C2C4C40
26334	Насадкино	1	10	749	37.340136999999999	37.357599999999998	56.49042	56.475687999999998	0103000020E610000001000000050000006C94F59B89AB4240C18C2958E33C4C406C94F59B89AB4240F4A62215C63E4C40598638D6C5AD4240F4A62215C63E4C40598638D6C5AD4240C18C2958E33C4C406C94F59B89AB4240C18C2958E33C4C40
61990	Митькино	1	10	749	37.558067999999999	37.574561000000003	56.339810999999997	56.331128999999997	0103000020E61000000100000005000000D978B0C56EC74240EBE0606F622A4C40D978B0C56EC7424018E945ED7E2B4C404E4700378BC9424018E945ED7E2B4C404E4700378BC94240EBE0606F622A4C40D978B0C56EC74240EBE0606F622A4C40
26556	Мельчевка	1	10	749	37.389688	37.403917	56.470711000000001	56.462819000000003	0103000020E6100000010000000500000063D2DF4BE1B14240D57B2AA73D3B4C4063D2DF4BE1B14240096F0F42403C4C4033A6608DB3B34240096F0F42403C4C4033A6608DB3B34240D57B2AA73D3B4C4063D2DF4BE1B14240D57B2AA73D3B4C40
26471	Луговой	1	10	749	37.228009	37.238025	56.461903999999997	56.453493000000002	0103000020E61000000100000005000000CA181F662F9D424083FB010F0C3A4C40CA181F662F9D42401FF296AB1F3B4C40B1506B9A779E42401FF296AB1F3B4C40B1506B9A779E424083FB010F0C3A4C40CA181F662F9D424083FB010F0C3A4C40
26392	Липино	1	10	749	37.131430999999999	37.142327999999999	56.648493999999999	56.643054999999997	0103000020E610000001000000050000001D5723BBD2904240BF4351A04F524C401D5723BBD29042407CD3F4D901534C400DA7CCCD379242407CD3F4D901534C400DA7CCCD37924240BF4351A04F524C401D5723BBD2904240BF4351A04F524C40
26699	Костино	1	10	749	37.710062999999998	37.726520000000001	56.316094999999997	56.295454999999997	0103000020E61000000100000005000000C18C2958E3DA424047382D78D1254C40C18C2958E3DA4240EDB60BCD75284C40E9F17B9BFEDC4240EDB60BCD75284C40E9F17B9BFEDC424047382D78D1254C40C18C2958E3DA424047382D78D1254C40
61997	Княжево	1	10	749	37.491970000000002	37.506244000000002	56.473300999999999	56.467737	0103000020E610000001000000050000007B4E7ADFF8BE4240881057CEDE3B4C407B4E7ADFF8BE424001158E20953C4C40EBE5779ACCC0424001158E20953C4C40EBE5779ACCC04240881057CEDE3B4C407B4E7ADFF8BE4240881057CEDE3B4C40
62003	Каменка	1	10	749	37.292050000000003	37.310456000000002	56.186219000000001	56.174464999999998	0103000020E61000000100000005000000FE65F7E461A54240F8A57EDE54164C40FE65F7E461A5424069723106D6174C406A6CAF05BDA7424069723106D6174C406A6CAF05BDA74240F8A57EDE54164C40FE65F7E461A54240F8A57EDE54164C40
62029	Ильинское	1	10	749	37.58446	37.597045999999999	56.281266000000002	56.267766999999999	0103000020E61000000100000005000000FBE8D495CFCA424059F9653046224C40FBE8D495CFCA424006BD378600244C40931ADA006CCC424006BD378600244C40931ADA006CCC424059F9653046224C40FBE8D495CFCA424059F9653046224C40
25306	Икша	1	10	749	37.481090999999999	37.516530000000003	56.187475999999997	56.160516000000001	0103000020E6100000010000000500000031B3CF6394BD42400C3ECDC98B144C4031B3CF6394BD42407764AC36FF174C4092B3B0A71DC242407764AC36FF174C4092B3B0A71DC242400C3ECDC98B144C4031B3CF6394BD42400C3ECDC98B144C40
62023	Дубровки	1	10	749	37.577561000000003	37.587119000000001	56.205554999999997	56.200172999999999	0103000020E61000000100000005000000F838D384EDC942406745D4449F194C40F838D384EDC94240BF4351A04F1A4C401CEE23B726CB4240BF4351A04F1A4C401CEE23B726CB42406745D4449F194C40F838D384EDC942406745D4449F194C40
15109	Дмитров	1	10	749	37.489356000000001	37.570483000000003	56.401713999999998	56.317926999999997	0103000020E61000000100000005000000FA0CA837A3BE4240F8C1F9D4B1284C40FA0CA837A3BE4240342C465D6B334C4045F6419605C94240342C465D6B334C4045F6419605C94240F8C1F9D4B1284C40FA0CA837A3BE4240F8C1F9D4B1284C40
25110	Деденево	1	10	749	37.499695000000003	37.530687	56.258133000000001	56.228731000000003	0103000020E61000000100000005000000C47C7901F6BF42406B4AB20E471D4C40C47C7901F6BF42405A828C800A214C40C8B4368DEDC342405A828C800A214C40C8B4368DEDC342406B4AB20E471D4C40C47C7901F6BF42406B4AB20E471D4C40
60214	Деденево	1	10	749	37.499695000000003	37.530687	56.258133000000001	56.228731000000003	0103000020E61000000100000005000000C47C7901F6BF42406B4AB20E471D4C40C47C7901F6BF42405A828C800A214C40C8B4368DEDC342405A828C800A214C40C8B4368DEDC342406B4AB20E471D4C40C47C7901F6BF42406B4AB20E471D4C40
62032	Гришино	1	10	749	37.657286999999997	37.665345000000002	56.220022999999998	56.214367000000003	0103000020E61000000100000005000000008BFCFA21D44240BB2BBB60701B4C40008BFCFA21D4424014AFB2B6291C4C4050C763062AD5424014AFB2B6291C4C4050C763062AD54240BB2BBB60701B4C40008BFCFA21D44240BB2BBB60701B4C40
26133	Горки	1	10	749	37.583975000000002	37.593794000000003	56.212784999999997	56.207177999999999	0103000020E610000001000000050000003F575BB1BFCA4240B03907CF841A4C403F575BB1BFCA4240280AF4893C1B4C40D047197101CC4240280AF4893C1B4C40D047197101CC4240B03907CF841A4C403F575BB1BFCA4240B03907CF841A4C40
61995	Внуково	1	10	749	37.572629999999997	37.594251999999997	56.368091	56.360715999999996	0103000020E61000000100000005000000AF5A99F04BC942406C921FF12B2E4C40AF5A99F04BC94240D9791B9B1D2F4C4092CA147310CC4240D9791B9B1D2F4C4092CA147310CC42406C921FF12B2E4C40AF5A99F04BC942406C921FF12B2E4C40
25946	Бунятино	1	10	749	37.245911999999997	37.255012000000001	56.407924999999999	56.399084000000002	0103000020E61000000100000005000000D3D85E0B7A9F4240AE2D3C2F15334C40D3D85E0B7A9F4240431CEBE236344C40350BB43BA4A04240431CEBE236344C40350BB43BA4A04240AE2D3C2F15334C40D3D85E0B7A9F4240AE2D3C2F15334C40
24986	Астрецово	1	10	749	37.414185000000003	37.433830999999998	56.309614000000003	56.301059000000002	0103000020E6100000010000000500000034BF9A0304B542404F95EF1989264C4034BF9A0304B542401F317A6EA1274C40D87E32C687B742401F317A6EA1274C40D87E32C687B742404F95EF1989264C4034BF9A0304B542404F95EF1989264C40
25780	Автополигон	1	10	749	37.306513000000002	37.332681000000001	56.353020999999998	56.345323999999998	0103000020E61000000100000005000000416667D13BA742400F43AB93332C4C40416667D13BA742408EE6C8CA2F2D4C4013807F4A95AA42408EE6C8CA2F2D4C4013807F4A95AA42400F43AB93332C4C40416667D13BA742400F43AB93332C4C40
61896	поселение им. Цюрупы	1	10	1242	38.62744	38.687995999999998	55.502110000000002	55.476270999999997	0103000020E61000000100000005000000E31934F44F5043404084B872F6BC4B40E31934F44F5043404E7FF62345C04B40B0E3BF40105843404E7FF62345C04B40B0E3BF40105843404084B872F6BC4B40E31934F44F5043404084B872F6BC4B40
60266	имени Цюрупы	1	10	1242	38.62744	38.687995999999998	55.502110000000002	55.476270999999997	0103000020E61000000100000005000000E31934F44F5043404084B872F6BC4B40E31934F44F5043404E7FF62345C04B40B0E3BF40105843404E7FF62345C04B40B0E3BF40105843404084B872F6BC4B40E31934F44F5043404084B872F6BC4B40
59174	городское поселение им. Цюрупы	1	10	1242	38.363551000000001	38.930720999999998	55.566837	55.208686999999998	0103000020E61000000100000005000000CCB6D3D6882E4340D80C7041B69A4B40CCB6D3D6882E4340D594641D8EC84B40A759A0DD21774340D594641D8EC84B40A759A0DD21774340D80C7041B69A4B40CCB6D3D6882E4340D80C7041B69A4B40
18806	Чемодурово	1	10	1242	38.648757000000003	38.684142000000001	55.363625999999996	55.346338000000003	0103000020E610000001000000050000008A0629780A53434058AEB7CD54AC4B408A0629780A534340D6FCF84B8BAE4B40F7E80DF791574340D6FCF84B8BAE4B40F7E80DF79157434058AEB7CD54AC4B408A0629780A53434058AEB7CD54AC4B40
61891	Хорлово	1	10	1242	38.797806000000001	38.904463	55.344090999999999	55.315359999999998	0103000020E61000000100000005000000BB46CB811E664340B83B6BB75DA84B40BB46CB811E66434089EC832C0BAC4B4095B88E71C573434089EC832C0BAC4B4095B88E71C5734340B83B6BB75DA84B40BB46CB811E664340B83B6BB75DA84B40
21135	Федино	1	10	1242	38.592199999999998	38.641804	55.315308999999999	55.301813000000003	0103000020E610000001000000050000007958A835CD4B4340FB40F2CEA1A64B407958A835CD4B43403691990B5CA84B4093382BA2265243403691990B5CA84B4093382BA226524340FB40F2CEA1A64B407958A835CD4B4340FB40F2CEA1A64B40
21477	Степанщино	1	10	1242	38.515906000000001	38.541291999999999	55.256714000000002	55.239522000000001	0103000020E61000000100000005000000B4E732350942434015562AA8A89E4B40B4E732350942434072361D01DCA04B4010CB660E4945434072361D01DCA04B4010CB660E4945434015562AA8A89E4B40B4E732350942434015562AA8A89E4B40
20557	Старая	1	10	1242	38.670146000000003	38.701686000000002	55.399248999999998	55.386405000000003	0103000020E61000000100000005000000CAC51858C7554340650113B875B14B40CAC51858C7554340F8FA5A971AB34B40D107CBD8D0594340F8FA5A971AB34B40D107CBD8D0594340650113B875B14B40CAC51858C7554340650113B875B14B40
21425	Ратчино	1	10	1242	38.636181000000001	38.66375	55.281174999999998	55.263275	0103000020E6100000010000000500000015AB06616E5143405D6DC5FEB2A14B4015AB06616E514340F5B9DA8AFDA34B40295C8FC2F5544340F5B9DA8AFDA34B40295C8FC2F55443405D6DC5FEB2A14B4015AB06616E5143405D6DC5FEB2A14B40
21234	Невское	1	10	1242	38.536118000000002	38.546790000000001	55.283701999999998	55.275857000000002	0103000020E610000001000000050000000266BE839F444340B4AF3C484FA34B400266BE839F444340A7E7DD5850A44B40D2E3F736FD454340A7E7DD5850A44B40D2E3F736FD454340B4AF3C484FA34B400266BE839F444340B4AF3C484FA34B40
18554	Маришкино	1	10	1242	38.604461999999998	38.641257000000003	55.362510999999998	55.335182000000003	0103000020E610000001000000050000005ED6C4025F4D43409C1A683EE7AA4B405ED6C4025F4D43405AB8ACC266AE4B4061AA99B5145243405AB8ACC266AE4B4061AA99B5145243409C1A683EE7AA4B405ED6C4025F4D43409C1A683EE7AA4B40
14704	Лидино	1	10	1242	38.738965999999998	38.762619000000001	55.443511000000001	55.434655999999997	0103000020E610000001000000050000008F6D1970965E43404D81CCCEA2B74B408F6D1970965E43404835ECF7C4B84B407427D87F9D6143404835ECF7C4B84B407427D87F9D6143404D81CCCEA2B74B408F6D1970965E43404D81CCCEA2B74B40
21385	Косяково	1	10	1242	38.483027	38.509248999999997	55.360233999999998	55.349353000000001	0103000020E61000000100000005000000E10A28D4D33D434037E15E99B7AC4B40E10A28D4D33D43402174D0251CAE4B40A6423C122F4143402174D0251CAE4B40A6423C122F41434037E15E99B7AC4B40E10A28D4D33D434037E15E99B7AC4B40
15658	Конобеево	1	10	1242	38.648316999999999	38.680252000000003	55.416586000000002	55.397674000000002	0103000020E610000001000000050000006D382C0DFC524340193C4CFBE6B24B406D382C0DFC52434059FCA6B052B54B40F1845E7F1257434059FCA6B052B54B40F1845E7F12574340193C4CFBE6B24B406D382C0DFC524340193C4CFBE6B24B40
19971	Золотово	1	10	1242	38.493250000000003	38.542163000000002	55.436464000000001	55.423698000000002	0103000020E610000001000000050000004260E5D0223F4340B8B06EBC3BB64B404260E5D0223F4340D0F0660DDEB74B40F60CE19865454340D0F0660DDEB74B40F60CE19865454340B8B06EBC3BB64B404260E5D0223F4340B8B06EBC3BB64B40
21864	Елкино	1	10	1242	38.815494000000001	38.854660000000003	55.319653000000002	55.306711999999997	0103000020E61000000100000005000000C80A7E1B6268434037A5BC5642A74B40C80A7E1B62684340BE88B663EAA84B408599B67F656D4340BE88B663EAA84B408599B67F656D434037A5BC5642A74B40C80A7E1B6268434037A5BC5642A74B40
21603	Дворниково	1	10	1242	38.617325000000001	38.633729000000002	55.508386000000002	55.501385999999997	0103000020E6100000010000000500000069006F81044F43400C569C6A2DC04B4069006F81044F434044DFDDCA12C14B406EC328081E51434044DFDDCA12C14B406EC328081E5143400C569C6A2DC04B4069006F81044F43400C569C6A2DC04B40
20208	Губино	1	10	1242	38.556787999999997	38.610560999999997	55.466605999999999	55.442449000000003	0103000020E61000000100000005000000126745D444474340EF92382BA2B84B40126745D444474340060FD3BEB9BB4B40459BE3DC264E4340060FD3BEB9BB4B40459BE3DC264E4340EF92382BA2B84B40126745D444474340EF92382BA2B84B40
21199	Городище	1	10	1242	38.561863000000002	38.593663999999997	55.352469999999997	55.340229999999998	0103000020E610000001000000050000008EEA7420EB4743401D8F19A88CAB4B408EEA7420EB4743401A69A9BC1DAD4B400168942EFD4B43401A69A9BC1DAD4B400168942EFD4B43401D8F19A88CAB4B408EEA7420EB4743401D8F19A88CAB4B40
12774	Воскресенск	1	10	1242	38.635804	38.784080000000003	55.360202999999998	55.236519000000001	0103000020E610000001000000050000003F55850662514340FAF02C41469E4B403F55850662514340E675C4211BAE4B404EB9C2BB5C644340E675C4211BAE4B404EB9C2BB5C644340FAF02C41469E4B403F55850662514340FAF02C41469E4B40
20018	Виноградово	1	10	1242	38.537545999999999	38.578392000000001	55.434849999999997	55.418005999999998	0103000020E610000001000000050000003D0CAD4ECE44434011C4793881B54B403D0CAD4ECE4443403255302AA9B74B404F22C2BF084A43403255302AA9B74B404F22C2BF084A434011C4793881B54B403D0CAD4ECE44434011C4793881B54B40
59555	Белоозерский	1	10	1242	38.428418999999998	38.486558000000002	55.466239000000002	55.442444000000002	0103000020E6100000010000000500000015FE0C6FD6364340DD274701A2B84B4015FE0C6FD6364340548F34B8ADBB4B40B8CD5488473E4340548F34B8ADBB4B40B8CD5488473E4340DD274701A2B84B4015FE0C6FD6364340DD274701A2B84B40
60262	Белоозерский	1	10	1242	38.428418999999998	38.486558000000002	55.466239000000002	55.442444000000002	0103000020E6100000010000000500000015FE0C6FD6364340DD274701A2B84B4015FE0C6FD6364340548F34B8ADBB4B40B8CD5488473E4340548F34B8ADBB4B40B8CD5488473E4340DD274701A2B84B4015FE0C6FD6364340DD274701A2B84B40
20692	Барановское	1	10	1242	38.737555999999998	38.778841999999997	55.409773999999999	55.391202	0103000020E61000000100000005000000FA7B293C685E43409D103AE812B24B40FA7B293C685E43402460747973B44B4028603B18B16343402460747973B44B4028603B18B16343409D103AE812B24B40FA7B293C685E43409D103AE812B24B40
20255	Ашитково	1	10	1242	38.570990000000002	38.610705000000003	55.443603000000003	55.421337999999999	0103000020E61000000100000005000000E92B483316494340F1475167EEB54B40E92B48331649434029B4ACFBC7B84B407940D9942B4E434029B4ACFBC7B84B407940D9942B4E4340F1475167EEB54B40E92B483316494340F1475167EEB54B40
21295	Ачкасово	1	10	1242	38.715152000000003	38.729956000000001	55.264989	55.251085000000003	0103000020E61000000100000005000000A2D5C9198A5B434012C2A38D23A04B40A2D5C9198A5B43405E66D828EBA14B406EC2BD326F5D43405E66D828EBA14B406EC2BD326F5D434012C2A38D23A04B40A2D5C9198A5B434012C2A38D23A04B40
13797	Ярополец	1	10	584	35.806488000000002	35.842528000000001	56.140745000000003	56.122534999999999	0103000020E61000000100000005000000E84EB0FF3AE74140C4CE143AAF0F4C40E84EB0FF3AE74140AB09A2EE03124C406EFB1EF5D7EB4140AB09A2EE03124C406EFB1EF5D7EB4140C4CE143AAF0F4C40E84EB0FF3AE74140C4CE143AAF0F4C40
48808	Ченцы	1	10	584	36.003363	36.024284000000002	56.049298999999998	56.040787000000002	0103000020E610000001000000050000001B82E3326E0042400D8D278238054C401B82E3326E004240DD5CFC6D4F064C4075E8F4BC1B034240DD5CFC6D4F064C4075E8F4BC1B0342400D8D278238054C401B82E3326E0042400D8D278238054C40
3661	Федюково	1	10	584	36.260541000000003	36.270656000000002	56.002732000000002	55.997959999999999	0103000020E610000001000000050000003222516859214240AB5B3D27BDFF4B4032225168592142408B53AD8559004C40AC3B16DBA42242408B53AD8559004C40AC3B16DBA4224240AB5B3D27BDFF4B403222516859214240AB5B3D27BDFF4B40
47877	Тимонино	1	10	584	35.824013999999998	35.833060000000003	56.045825000000001	56.039906999999999	0103000020E610000001000000050000001BB96E4A79E94140D4F02DAC1B054C401BB96E4A79E941406B2BF697DD054C408ACDC7B5A1EA41406B2BF697DD054C408ACDC7B5A1EA4140D4F02DAC1B054C401BB96E4A79E94140D4F02DAC1B054C40
6106	Теряево	1	10	584	36.107953999999999	36.146509000000002	56.178637999999999	56.163944999999998	0103000020E6100000010000000500000077BCC96FD10D4240DEAB5626FC144C4077BCC96FD10D424053E9279CDD164C40EBC891CEC012424053E9279CDD164C40EBC891CEC0124240DEAB5626FC144C4077BCC96FD10D4240DEAB5626FC144C40
18088	Спасс	1	10	584	35.894370000000002	35.922344000000002	55.930377	55.910997000000002	0103000020E61000000100000005000000034356B77AF2414087E0B88C9BF44B40034356B77AF24140ADF9F19716F74B40B7D4415E0FF64140ADF9F19716F74B40B7D4415E0FF6414087E0B88C9BF44B40034356B77AF2414087E0B88C9BF44B40
17990	Осташево	1	10	584	35.823312999999999	35.883032999999998	55.871429999999997	55.851500000000001	0103000020E6100000010000000500000092AF045262E94140A245B6F3FDEC4B4092AF045262E941406B60AB048BEF4B40F624B03907F141406B60AB048BEF4B40F624B03907F14140A245B6F3FDEC4B4092AF045262E94140A245B6F3FDEC4B40
12447	Нелидово	1	10	584	36.007593999999997	36.028354	55.987971000000002	55.978569	0103000020E61000000100000005000000AAD216D7F800424091F0BDBF41FD4B40AAD216D7F8004240BE326FD575FE4B40FB5A971AA1034240BE326FD575FE4B40FB5A971AA103424091F0BDBF41FD4B40AAD216D7F800424091F0BDBF41FD4B40
47920	Курьяново	1	10	584	35.72007	35.740586999999998	56.030402000000002	56.02102	0103000020E61000000100000005000000556AF6402BDC4140ED478AC8B0024C40556AF6402BDC4140D3DD7536E4034C40DF6B088ECBDE4140D3DD7536E4034C40DF6B088ECBDE4140ED478AC8B0024C40556AF6402BDC4140ED478AC8B0024C40
5005	Клишино	1	10	584	35.834938000000001	35.849311	55.915694000000002	55.902495000000002	0103000020E610000001000000050000000518963FDFEA4140DAE6C6F484F34B400518963FDFEA41405C92037635F54B4008910C39B6EC41405C92037635F54B4008910C39B6EC4140DAE6C6F484F34B400518963FDFEA4140DAE6C6F484F34B40
17961	Калистово	1	10	584	35.983231000000004	35.993732999999999	56.081442000000003	56.071389000000003	0103000020E61000000100000005000000EAB46E83DAFD4140A725564623094C40EAB46E83DAFD4140AB4203B16C0A4C405DFA97A432FF4140AB4203B16C0A4C405DFA97A432FF4140A725564623094C40EAB46E83DAFD4140A725564623094C40
49481	Ильинское	1	10	584	35.748313000000003	35.769773999999998	56.075342999999997	56.056835	0103000020E61000000100000005000000F9156BB8C8DF41405322895E46074C40F9156BB8C8DF4140C37DE4D6A4094C40D2A755F487E24140C37DE4D6A4094C40D2A755F487E241405322895E46074C40F9156BB8C8DF41405322895E46074C40
13136	Гряды	1	10	584	36.223979999999997	36.239412999999999	56.017588000000003	56.008958	0103000020E61000000100000005000000A27A6B60AB1C4240CF84268925014C40A27A6B60AB1C4240AA66D65240024C405E9ECE15A51E4240AA66D65240024C405E9ECE15A51E4240CF84268925014C40A27A6B60AB1C4240CF84268925014C40
4726	Волоколамск	1	10	584	35.908932	35.997461000000001	56.081792999999998	55.979339000000003	0103000020E61000000100000005000000D9243FE257F441404359F8FA5AFD4B40D9243FE257F4414057056A31780A4C408A0453CDACFF414057056A31780A4C408A0453CDACFF41404359F8FA5AFD4B40D9243FE257F441404359F8FA5AFD4B40
18043	Болычево	1	10	584	35.709657999999997	35.731020000000001	55.765458000000002	55.756081999999999	0103000020E6100000010000000500000021ACC612D6DA4140118C834BC7E04B4021ACC612D6DA4140153B1A87FAE14B40685C381092DD4140153B1A87FAE14B40685C381092DD4140118C834BC7E04B4021ACC612D6DA4140118C834BC7E04B40
54699	Чаплыгин	1	9	\N	39.916550000000001	39.997397999999997	53.256546	53.223835000000001	0103000020E610000001000000050000000C93A98251F543409F5912A0A69C4A400C93A98251F54340B6F5D37FD6A04A40438CD7BCAAFF4340B6F5D37FD6A04A40438CD7BCAAFF43409F5912A0A69C4A400C93A98251F543409F5912A0A69C4A40
54735	Усмань	1	9	\N	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
19463	Подгорное	1	9	\N	39.484793000000003	39.530785999999999	52.564639	52.534728999999999	0103000020E61000000100000005000000352A70B20DBE4340849CF7FF71444A40352A70B20DBE4340E8853B1746484A405B96AFCBF0C34340E8853B1746484A405B96AFCBF0C34340849CF7FF71444A40352A70B20DBE4340849CF7FF71444A40
54758	Молодежный	1	9	\N	37.722244000000003	40.763570999999999	53.587829999999997	51.887303000000003	0103000020E61000000100000005000000BADDCB7D72DC424044520B2593F14940BADDCB7D72DC4240C8CD70033ECB4A404696CCB1BC614440C8CD70033ECB4A404696CCB1BC61444044520B2593F14940BADDCB7D72DC424044520B2593F14940
3727	Липецк	1	9	\N	39.380229	39.814968	52.714798999999999	52.492085000000003	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
18875	Ленино	1	9	\N	39.460357999999999	39.526437999999999	52.539900000000003	52.506453999999998	0103000020E61000000100000005000000DA39CD02EDBA4340D576137CD3404A40DA39CD02EDBA4340228E75711B454A4092AF045262C34340228E75711B454A4092AF045262C34340D576137CD3404A40DA39CD02EDBA4340D576137CD3404A40
54697	Лебедянь	1	9	\N	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
54743	Задонск	1	9	\N	38.906412000000003	38.948416999999999	52.402214999999998	52.375751000000001	0103000020E61000000100000005000000DA59F44E057443403B38D89B18304A40DA59F44E05744340F67AF7C77B334A4037FC6EBA65794340F67AF7C77B334A4037FC6EBA657943403B38D89B18304A40DA59F44E057443403B38D89B18304A40
4018	Елец	1	9	\N	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
54756	Данков	1	9	\N	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
54694	Грязи	1	9	\N	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
27712	Юсово	1	9	1793	39.963800999999997	39.997596000000001	53.225296	53.213115999999999	0103000020E61000000100000005000000116DC7D45DFB43408E209562479B4A40116DC7D45DFB4340B6F5D37FD69C4A406A4FC939B1FF4340B6F5D37FD69C4A406A4FC939B1FF43408E209562479B4A40116DC7D45DFB43408E209562479B4A40
27600	Шишкино	1	9	1793	39.866244000000002	39.880724999999998	53.512779000000002	53.502561	0103000020E61000000100000005000000992D5915E1EE43405E9F39EB53C04A40992D5915E1EE4340AD8905BEA2C14A4082E2C798BBF04340AD8905BEA2C14A4082E2C798BBF043405E9F39EB53C04A40992D5915E1EE43405E9F39EB53C04A40
26779	Чечеры	1	9	1793	39.818041000000001	39.837184000000001	53.144208999999996	53.132536000000002	0103000020E61000000100000005000000C1E44691B5E8434076C58CF0F6904A40C1E44691B5E84340F964C57075924A40035E66D828EB4340F964C57075924A40035E66D828EB434076C58CF0F6904A40C1E44691B5E8434076C58CF0F6904A40
26134	Чаплыгин	1	9	1793	39.916550000000001	39.997397999999997	53.256546	53.223835000000001	0103000020E610000001000000050000000C93A98251F543409F5912A0A69C4A400C93A98251F54340B6F5D37FD6A04A40438CD7BCAAFF4340B6F5D37FD6A04A40438CD7BCAAFF43409F5912A0A69C4A400C93A98251F543409F5912A0A69C4A40
27555	Урусово	1	9	1793	39.588970000000003	39.608877	53.524450000000002	53.508645000000001	0103000020E610000001000000050000009E29745E63CB4340102384471BC14A409E29745E63CB43409031772D21C34A40AF2479AEEFCD43409031772D21C34A40AF2479AEEFCD4340102384471BC14A409E29745E63CB4340102384471BC14A40
27507	Троекурово	1	9	1793	39.691594000000002	39.765219999999999	53.454165000000003	53.398181999999998	0103000020E610000001000000050000000F0EF62686D843408DEDB5A0F7B24A400F0EF62686D8434072FE261422BA4A40601F9DBAF2E1434072FE261422BA4A40601F9DBAF2E143408DEDB5A0F7B24A400F0EF62686D843408DEDB5A0F7B24A40
27172	Топтыково	1	9	1793	39.822980999999999	39.856929000000001	53.408467000000002	53.397509999999997	0103000020E610000001000000050000005C1D007157E943409EEA909BE1B24A405C1D007157E94340643F8BA548B44A403BFF76D9AFED4340643F8BA548B44A403BFF76D9AFED43409EEA909BE1B24A405C1D007157E943409EEA909BE1B24A40
27415	Соловое	1	9	1793	40.074832999999998	40.108519999999999	53.377484000000003	53.343086	0103000020E61000000100000005000000AED4B3209409444094DBF63DEAAB4A40AED4B32094094440B3614D6551B04A40207BBDFBE30D4440B3614D6551B04A40207BBDFBE30D444094DBF63DEAAB4A40AED4B3209409444094DBF63DEAAB4A40
27448	Солнцево	1	9	1793	40.111583000000003	40.149383999999998	53.344822999999998	53.322685	0103000020E6100000010000000500000011E50B5A480E444073F4F8BD4DA94A4011E50B5A480E44404DF4F92823AC4A40D845D1031F1344404DF4F92823AC4A40D845D1031F13444073F4F8BD4DA94A4011E50B5A480E444073F4F8BD4DA94A40
27652	Рощинский	1	9	1793	39.995502999999999	40.009984000000003	53.269392000000003	53.257527000000003	0103000020E61000000100000005000000F2086EA46CFF4340236B0DA5F6A04A40F2086EA46CFF4340EBE6E26F7BA24A40DCBDDC2747014440EBE6E26F7BA24A40DCBDDC2747014440236B0DA5F6A04A40F2086EA46CFF4340236B0DA5F6A04A40
27335	Пиково	1	9	1793	39.821328000000001	39.856991999999998	53.303063999999999	53.283430000000003	0103000020E6100000010000000500000001A5A14621E94340475A2A6F47A44A4001A5A14621E94340274C18CDCAA64A408177F2E9B1ED4340274C18CDCAA64A408177F2E9B1ED4340475A2A6F47A44A4001A5A14621E94340475A2A6F47A44A40
27266	Новополянье	1	9	1793	39.787542999999999	39.836042999999997	53.189318	53.171211999999997	0103000020E61000000100000005000000CC988235CEE4434064575A46EA954A40CC988235CEE44340A6457D923B984A405D86FF7403EB4340A6457D923B984A405D86FF7403EB434064575A46EA954A40CC988235CEE4434064575A46EA954A40
27313	Новое Петелино	1	9	1793	39.667375	39.714474000000003	53.533292000000003	53.517195999999998	0103000020E610000001000000050000008195438B6CD543409ECF807A33C24A408195438B6CD54340F69B89E942C44A40D1EB4FE273DB4340F69B89E942C44A40D1EB4FE273DB43409ECF807A33C24A408195438B6CD543409ECF807A33C24A40
27128	Ломовое	1	9	1793	39.854404000000002	39.896076999999998	53.306944000000001	53.265875999999999	0103000020E610000001000000050000002AC93A1C5DED434049658A3908A24A402AC93A1C5DED43400ADAE4F049A74A4051D9B0A6B2F243400ADAE4F049A74A4051D9B0A6B2F2434049658A3908A24A402AC93A1C5DED434049658A3908A24A40
27101	Лозовка	1	9	1793	39.908239999999999	39.922317	53.393853999999997	53.380755000000001	0103000020E61000000100000005000000A375543541F44340ED647094BCB04A40A375543541F443400BB3D0CE69B24A40BDC5C37B0EF643400BB3D0CE69B24A40BDC5C37B0EF64340ED647094BCB04A40A375543541F44340ED647094BCB04A40
26901	Кривополянье	1	9	1793	39.902104999999999	39.965831000000001	53.240113000000001	53.199545999999998	0103000020E610000001000000050000006F47382D78F3434018062CB98A994A406F47382D78F34340172CD505BC9E4A40433BA759A0FB4340172CD505BC9E4A40433BA759A0FB434018062CB98A994A406F47382D78F3434018062CB98A994A40
26877	Конюшки	1	9	1793	39.709156	39.769953999999998	53.437953	53.426654999999997	0103000020E610000001000000050000008FE1B19FC5DA434062D68BA19CB64A408FE1B19FC5DA4340B1170AD80EB84A4052B648DA8DE24340B1170AD80EB84A4052B648DA8DE2434062D68BA19CB64A408FE1B19FC5DA434062D68BA19CB64A40
27040	Колыбельское	1	9	1793	39.921104	39.953218999999997	53.115648999999998	53.084175999999999	0103000020E610000001000000050000007E1B62BCE6F54340D68D7747C68A4A407E1B62BCE6F5434055682096CD8E4A408176871403FA434055682096CD8E4A408176871403FA4340D68D7747C68A4A407E1B62BCE6F54340D68D7747C68A4A40
26789	Истобное	1	9	1793	39.932215999999997	39.997695	53.168264999999998	53.132725000000001	0103000020E610000001000000050000006A6798DA52F74340492EFF21FD904A406A6798DA52F74340DD0720B589954A40FD304278B4FF4340DD0720B589954A40FD304278B4FF4340492EFF21FD904A406A6798DA52F74340492EFF21FD904A40
26714	Зенкино	1	9	1793	39.696632999999999	39.789914000000003	53.144089999999998	53.120058999999998	0103000020E610000001000000050000003D2828452BD94340944BE3175E8F4A403D2828452BD943401FD7868A71924A408753E6E61BE543401FD7868A71924A408753E6E61BE54340944BE3175E8F4A403D2828452BD94340944BE3175E8F4A40
26705	Жабино	1	9	1793	39.865057999999998	39.898045000000003	53.258927	53.250991999999997	0103000020E6100000010000000500000053927538BAEE434060C77F8120A04A4053927538BAEE434094861A8524A14A400DAB7823F3F2434094861A8524A14A400DAB7823F3F2434060C77F8120A04A4053927538BAEE434060C77F8120A04A40
27216	Дуровщино	1	9	1793	39.839976999999998	39.875388999999998	53.449789000000003	53.418165999999999	0103000020E610000001000000050000003332C85D84EB43404A26A77686B54A403332C85D84EB4340DF8C9AAF92B94A409A232BBF0CF04340DF8C9AAF92B94A409A232BBF0CF043404A26A77686B54A403332C85D84EB43404A26A77686B54A40
26600	Дубовое	1	9	1793	40.028004000000003	40.113883000000001	53.146056000000002	53.108060000000002	0103000020E610000001000000050000001F1494A295034440BD00FBE8D48D4A401F1494A2950344403AB187F6B1924A400249D8B7930E44403AB187F6B1924A400249D8B7930E4440BD00FBE8D48D4A401F1494A295034440BD00FBE8D48D4A40
26543	Демкино	1	9	1793	39.893095000000002	39.943570999999999	53.098669000000001	53.069260999999997	0103000020E610000001000000050000004E9CDCEF50F24340B2F1608BDD884A404E9CDCEF50F243408410902FA18C4A401D3A3DEFC6F843408410902FA18C4A401D3A3DEFC6F84340B2F1608BDD884A404E9CDCEF50F24340B2F1608BDD884A40
26475	Выселки	1	9	1793	39.881011999999998	39.887354999999999	53.513651000000003	53.505025000000003	0103000020E6100000010000000500000018B14F00C5F04340CA54C1A8A4C04A4018B14F00C5F043406347E350BFC14A40967840D994F143406347E350BFC14A40967840D994F14340CA54C1A8A4C04A4018B14F00C5F04340CA54C1A8A4C04A40
26331	Воскресенское	1	9	1793	39.931857000000001	39.965822000000003	53.345999999999997	53.313431999999999	0103000020E610000001000000050000003BC6151747F743408BC22E8A1EA84A403BC6151747F743403F355EBA49AC4A40F0E0270EA0FB43403F355EBA49AC4A40F0E0270EA0FB43408BC22E8A1EA84A403BC6151747F743408BC22E8A1EA84A40
26459	Ведное	1	9	1793	39.778748	39.794702000000001	53.494334000000002	53.484090000000002	0103000020E61000000100000005000000A7E9B303AEE343400B293FA9F6BD4A40A7E9B303AEE3434083A6255646BF4A406C088ECBB8E5434083A6255646BF4A406C088ECBB8E543400B293FA9F6BD4A40A7E9B303AEE343400B293FA9F6BD4A40
26393	Буховое	1	9	1793	39.947003000000002	40.017305	53.087491	53.052858999999998	0103000020E61000000100000005000000611BF16437F943404E266E15C4864A40611BF16437F94340E0D8B3E7328B4A405587DC0C37024440E0D8B3E7328B4A405587DC0C370244404E266E15C4864A40611BF16437F943404E266E15C4864A40
60438	Братовка	1	9	1793	39.941702999999997	39.997838000000002	53.351998999999999	53.324185	0103000020E61000000100000005000000C5C551B989F84340486DE2E47EA94A40C5C551B989F84340C39CA04D0EAD4A40605AD427B9FF4340C39CA04D0EAD4A40605AD427B9FF4340486DE2E47EA94A40C5C551B989F84340486DE2E47EA94A40
27720	Большой Снежеток	1	9	1793	40.036169000000001	40.081623999999998	53.252096000000002	53.225769999999997	0103000020E610000001000000050000008410902FA10444407E350708E69C4A408410902FA1044440E9B985AE44A04A40CB48BDA7720A4440E9B985AE44A04A40CB48BDA7720A44407E350708E69C4A408410902FA10444407E350708E69C4A40
25952	Хлевное	1	9	1681	39.055810999999999	39.128646000000003	52.217464999999997	52.185125999999997	0103000020E61000000100000005000000E7E099D024874340D4D17135B2174A40E7E099D0248743402783A3E4D51B4A407061DD78779043402783A3E4D51B4A407061DD7877904340D4D17135B2174A40E7E099D024874340D4D17135B2174A40
54767	Фомина-Негачевка	1	9	1681	39.034449000000002	39.085706999999999	52.049444999999999	52.026476000000002	0103000020E61000000100000005000000A13028D3688443408010C99063034A40A13028D368844340B1F9B83654064A40E6046D72F88A4340B1F9B83654064A40E6046D72F88A43408010C99063034A40A13028D3688443408010C99063034A40
54785	Старо Дубовое	1	9	1681	39.019967999999999	39.054248000000001	52.252681000000003	52.239502999999999	0103000020E61000000100000005000000B77BB94F8E8243409E25C808A81E4A40B77BB94F8E82434009A9DBD957204A40CCEF3499F186434009A9DBD957204A40CCEF3499F18643409E25C808A81E4A40B77BB94F8E8243409E25C808A81E4A40
25801	Синдякино	1	9	1681	39.328800000000001	39.342472000000001	52.118839000000001	52.107506999999998	0103000020E6100000010000000500000060764F1E16AA4340A88B14CAC20D4A4060764F1E16AA4340A33EC91D360F4A40DAE55B1FD6AB4340A33EC91D360F4A40DAE55B1FD6AB4340A88B14CAC20D4A4060764F1E16AA4340A88B14CAC20D4A40
25881	Подгорное	1	9	1681	39.349936999999997	39.370671000000002	52.181072999999998	52.161647000000002	0103000020E61000000100000005000000865451BCCAAC43408E3F51D9B0144A40865451BCCAAC434024986A662D174A40AE49B72572AF434024986A662D174A40AE49B72572AF43408E3F51D9B0144A40865451BCCAAC43408E3F51D9B0144A40
25781	Отскочное	1	9	1681	39.117831000000002	39.139076000000003	52.112091999999997	52.084225000000004	0103000020E610000001000000050000003DBA1116158F4340B84082E2C70A4A403DBA1116158F43405512D907590E4A404AD40B3ECD9143405512D907590E4A404AD40B3ECD914340B84082E2C70A4A403DBA1116158F4340B84082E2C70A4A40
25710	Новое Дубовое	1	9	1681	39.182535999999999	39.264102999999999	52.322561	52.295988000000001	0103000020E61000000100000005000000DC2BF3565D97434015014EEFE2254A40DC2BF3565D97434087FBC8AD49294A4043E38920CEA1434087FBC8AD49294A4043E38920CEA1434015014EEFE2254A40DC2BF3565D97434015014EEFE2254A40
25703	Нижняя Колыбелька	1	9	1681	38.979472000000001	39.013176999999999	52.199567999999999	52.184651000000002	0103000020E6100000010000000500000082ACA7565F7D43403C16DBA4A2174A4082ACA7565F7D434000AAB8718B194A409A07B0C8AF81434000AAB8718B194A409A07B0C8AF8143403C16DBA4A2174A4082ACA7565F7D43403C16DBA4A2174A40
25399	Муравьевка	1	9	1681	38.876103000000001	38.900042999999997	52.110399000000001	52.103209	0103000020E61000000100000005000000B876A2242470434091D3D7F3350D4A40B876A224247043406C41EF8D210E4A4032FFE89B347343406C41EF8D210E4A4032FFE89B3473434091D3D7F3350D4A40B876A2242470434091D3D7F3350D4A40
25641	Малый Мечек	1	9	1681	39.310716999999997	39.337083	52.254534	52.240506000000003	0103000020E61000000100000005000000D6A71C93C5A74340F33E8EE6C81E4A40D6A71C93C5A743402BDCF29194204A40CF84268925AB43402BDCF29194204A40CF84268925AB4340F33E8EE6C81E4A40D6A71C93C5A74340F33E8EE6C81E4A40
22065	Малинино	1	9	1681	39.328781999999997	39.366852999999999	52.280287999999999	52.261026999999999	0103000020E61000000100000005000000B9C1508715AA4340BE2F2E5569214A40B9C1508715AA43400ABB287AE0234A4041B8020AF5AE43400ABB287AE0234A4041B8020AF5AE4340BE2F2E5569214A40B9C1508715AA4340BE2F2E5569214A40
25598	Конь-Колодезь	1	9	1681	39.136066999999997	39.180613999999998	52.155282999999997	52.115957999999999	0103000020E610000001000000050000004C88B9A46A914340D3DA34B6D70E4A404C88B9A46A914340F84F3750E0134A4091990B5C1E974340F84F3750E0134A4091990B5C1E974340D3DA34B6D70E4A404C88B9A46A914340D3DA34B6D70E4A40
54770	Елецко-Маланинский	1	9	1681	39.071379	39.082912999999998	52.230699999999999	52.212383000000003	0103000020E61000000100000005000000834F73F222894340FA9CBB5D2F1B4A40834F73F222894340F697DD93871D4A40E5B4A7E49C8A4340F697DD93871D4A40E5B4A7E49C8A4340FA9CBB5D2F1B4A40834F73F222894340FA9CBB5D2F1B4A40
54760	Елецкая Лозовка	1	9	1681	39.147205999999997	39.198140000000002	52.269295	52.246115000000003	0103000020E6100000010000000500000032E36DA5D79243400C0742B2801F4A4032E36DA5D7924340F8FC304278224A40C503CAA65C994340F8FC304278224A40C503CAA65C9943400C0742B2801F4A4032E36DA5D79243400C0742B2801F4A40
25314	Дмитряшевка	1	9	1681	39.044339999999998	39.113329999999998	52.164299	52.137985	0103000020E61000000100000005000000CBF3E0EEAC854340562B137EA9114A40CBF3E0EEAC854340FCE1E7BF07154A40EDD3F198818E4340FCE1E7BF07154A40EDD3F198818E4340562B137EA9114A40CBF3E0EEAC854340562B137EA9114A40
54784	Воронежская Лозовка	1	9	1681	39.255003000000002	39.291888	52.214165999999999	52.200529000000003	0103000020E61000000100000005000000E2B034F0A3A0434026732CEFAA194A40E2B034F0A3A0434023F59ECA691B4A40240C03965CA5434023F59ECA691B4A40240C03965CA5434026732CEFAA194A40E2B034F0A3A0434026732CEFAA194A40
25238	Воробьевка	1	9	1681	39.167993000000003	39.220022999999998	52.242998999999998	52.213636000000001	0103000020E610000001000000050000007D7A6CCB80954340C79FA86C581B4A407D7A6CCB80954340F8FA5A971A1F4A4014AFB2B6299C4340F8FA5A971A1F4A4014AFB2B6299C4340C79FA86C581B4A407D7A6CCB80954340C79FA86C581B4A40
25193	Верхняя Колыбелька	1	9	1681	38.886181999999998	38.947294999999997	52.200380000000003	52.178516000000002	0103000020E61000000100000005000000E5266A696E71434008E8BE9CD9164A40E5266A696E714340E162450DA6194A4008556AF640794340E162450DA6194A4008556AF64079434008E8BE9CD9164A40E5266A696E71434008E8BE9CD9164A40
25137	Введенка	1	9	1681	39.012574999999998	39.087179999999996	52.305053000000001	52.278095	0103000020E61000000100000005000000A4DFBE0E9C8143402F17F19D98234A40A4DFBE0E9C814340FA4509FA0B274A40C16ED8B6288B4340FA4509FA0B274A40C16ED8B6288B43402F17F19D98234A40A4DFBE0E9C8143402F17F19D98234A40
54700	станция Дрязги	1	9	1726	39.780346999999999	39.780518000000001	52.287576999999999	52.285775999999998	0103000020E610000001000000050000000F441669E2E34340A8FDD64E94244A400F441669E2E34340780AB952CF244A403CF88903E8E34340780AB952CF244A403CF88903E8E34340A8FDD64E94244A400F441669E2E34340A8FDD64E94244A40
54783	совхоза Ударник	1	9	1726	39.348095999999998	40.151494999999997	52.353298000000002	51.919525999999998	0103000020E6100000010000000500000028EFE3688EAC43402DE92807B3F5494028EFE3688EAC434001DF6DDE382D4A40F6402B306413444001DF6DDE382D4A40F6402B30641344402DE92807B3F5494028EFE3688EAC43402DE92807B3F54940
24577	Усмань	1	9	1726	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
25051	Студенки	1	9	1726	39.575603000000001	39.621057999999998	52.021844000000002	52.005496999999998	0103000020E61000000100000005000000603DEE5BADC94340F19C2D20B4004A40603DEE5BADC9434092CEC0C8CB024A40A7751BD47ECF434092CEC0C8CB024A40A7751BD47ECF4340F19C2D20B4004A40603DEE5BADC94340F19C2D20B4004A40
54757	Стрелецкие Хутора	1	9	1726	39.683427999999999	39.725127999999998	52.099392000000002	52.080632999999999	0103000020E61000000100000005000000D99596917AD743403BFDA02E520A4A40D99596917AD74340F5BD86E0B80C4A40FAB48AFED0DC4340F5BD86E0B80C4A40FAB48AFED0DC43403BFDA02E520A4A40D99596917AD743403BFDA02E520A4A40
24982	Сторожевские Хутора	1	9	1726	39.871561999999997	39.945449000000004	52.208889999999997	52.133567999999997	0103000020E61000000100000005000000DA37F7578FEF434064E597C118114A40DA37F7578FEF4340103B53E8BC1A4A4099840B7904F94340103B53E8BC1A4A4099840B7904F9434064E597C118114A40DA37F7578FEF434064E597C118114A40
24844	Сторожевое	1	9	1726	39.766252999999999	39.810315000000003	52.121996000000003	52.078358000000001	0103000020E610000001000000050000001FBB0B9414E24340A3B08BA2070A4A401FBB0B9414E24340151F9F909D0F4A40A83AE466B8E74340151F9F909D0F4A40A83AE466B8E74340A3B08BA2070A4A401FBB0B9414E24340A3B08BA2070A4A40
24566	Поддубровка	1	9	1726	39.520913999999998	39.580212000000003	52.139786999999998	52.117683	0103000020E61000000100000005000000A703594FADC24340C8258E3C100F4A40A703594FADC24340F6B3588AE4114A40965F066344CA4340F6B3588AE4114A40965F066344CA4340C8258E3C100F4A40A703594FADC24340C8258E3C100F4A40
54766	Пластинка	1	9	1726	39.990302	40.021957999999998	52.277791999999998	52.241731000000001	0103000020E61000000100000005000000EA944737C2FE4340F6B6990AF11E4A40EA944737C2FE4340938B31B08E234A405AF10D85CF024440938B31B08E234A405AF10D85CF024440F6B6990AF11E4A40EA944737C2FE4340F6B6990AF11E4A40
24480	Пашково	1	9	1726	39.956066999999997	40.008006999999999	52.035763000000003	52.006262	0103000020E6100000010000000500000075E4486760FA4340919A7631CD004A4075E4486760FA434014B4C9E193044A40CD91955F0601444014B4C9E193044A40CD91955F06014440919A7631CD004A4075E4486760FA4340919A7631CD004A40
24365	Октябрьское	1	9	1726	39.693390000000001	39.762856999999997	52.315696000000003	52.286993000000002	0103000020E61000000100000005000000CDAFE600C1D843402997C62FBC244A40CDAFE600C1D8434030BDFDB968284A402843554CA5E1434030BDFDB968284A402843554CA5E143402997C62FBC244A40CDAFE600C1D843402997C62FBC244A40
23711	Новоуглянка	1	9	1726	39.726170000000003	39.774571000000002	52.033320000000003	52.003633999999998	0103000020E610000001000000050000000DAB7823F3DC4340AB93331477004A400DAB7823F3DC4340C0266BD443044A400BB77C2425E34340C0266BD443044A400BB77C2425E34340AB93331477004A400DAB7823F3DC4340AB93331477004A40
24270	Никольское	1	9	1726	39.631675999999999	39.696247	52.180835999999999	52.131025000000001	0103000020E6100000010000000500000084D558C2DAD04340ADFA5C6DC5104A4084D558C2DAD0434040F850A225174A401478279F1ED9434040F850A225174A401478279F1ED94340ADFA5C6DC5104A4084D558C2DAD04340ADFA5C6DC5104A40
25033	Никольские Выселки	1	9	1726	39.777518000000001	39.79269	51.959274999999998	51.942545000000003	0103000020E610000001000000050000009206B7B585E3434011018750A5F849409206B7B585E34340696FF085C9FA4940E1EEACDD76E54340696FF085C9FA4940E1EEACDD76E5434011018750A5F849409206B7B585E3434011018750A5F84940
23843	Московка	1	9	1726	39.817923999999998	39.853596000000003	52.263513000000003	52.239221000000001	0103000020E61000000100000005000000874ECFBBB1E843401AC231CB9E1E4A40874ECFBBB1E84340128942CBBA214A408BFF3BA242ED4340128942CBBA214A408BFF3BA242ED43401AC231CB9E1E4A40874ECFBBB1E843401AC231CB9E1E4A40
24721	Медовка	1	9	1726	39.571040000000004	39.599355000000003	52.081884000000002	52.066982000000003	0103000020E610000001000000050000009B5AB6D617C94340D9B5BDDD92084A409B5AB6D617C943406808C72C7B0A4A40D8D825AAB7CC43406808C72C7B0A4A40D8D825AAB7CC4340D9B5BDDD92084A409B5AB6D617C94340D9B5BDDD92084A40
24807	Куриловка	1	9	1726	39.803452	39.823385999999999	52.213272000000003	52.193843999999999	0103000020E61000000100000005000000F1F3DF83D7E643404E4354E1CF184A40F1F3DF83D7E643408693347F4C1B4A40FCFD62B664E943408693347F4C1B4A40FCFD62B664E943404E4354E1CF184A40F1F3DF83D7E643404E4354E1CF184A40
24164	Куликово	1	9	1726	39.502813000000003	39.663854000000001	52.251522999999999	52.202179000000001	0103000020E610000001000000050000007880272D5CC0434010786000E1194A407880272D5CC043408D98D9E731204A40CEA8F92AF9D443408D98D9E731204A40CEA8F92AF9D4434010786000E1194A407880272D5CC0434010786000E1194A40
24078	Крутченская Байгора	1	9	1726	39.929853999999999	39.990983999999997	52.003169	51.972160000000002	0103000020E610000001000000050000000307B47405F743405C3D27BD6FFC49400307B47405F7434036AE7FD767004A40FC6D4F90D8FE434036AE7FD767004A40FC6D4F90D8FE43405C3D27BD6FFC49400307B47405F743405C3D27BD6FFC4940
24066	Кривка	1	9	1726	39.648034000000003	39.731973000000004	52.344864999999999	52.314985999999998	0103000020E61000000100000005000000195932C7F2D243405359147651284A40195932C7F2D243407C444C89242C4A400B47904AB1DD43407C444C89242C4A400B47904AB1DD43405359147651284A40195932C7F2D243405359147651284A40
24926	Красное	1	9	1726	39.762506999999999	39.789293999999998	52.133434999999999	52.092232000000003	0103000020E610000001000000050000004CFC51D499E1434085D21742CE0B4A404CFC51D499E143402592E86514114A40EA76F69507E543402592E86514114A40EA76F69507E5434085D21742CE0B4A404CFC51D499E1434085D21742CE0B4A40
23982	Излегоще	1	9	1726	39.358885000000001	39.38711	52.147972000000003	52.091740000000001	0103000020E61000000100000005000000320395F1EFAD434016DEE522BE0B4A40320395F1EFAD4340A35C1ABFF0124A402FFA0AD28CB14340A35C1ABFF0124A402FFA0AD28CB1434016DEE522BE0B4A40320395F1EFAD434016DEE522BE0B4A40
23910	Завальное	1	9	1726	39.801403999999998	39.904575000000001	52.070177000000001	52.041879000000002	0103000020E610000001000000050000001971016894E64340D1B1834A5C054A401971016894E6434038F7578FFB084A40BDE3141DC9F3434038F7578FFB084A40BDE3141DC9F34340D1B1834A5C054A401971016894E64340D1B1834A5C054A40
23773	Дмитриевка	1	9	1726	39.854683000000001	39.878497000000003	52.295282999999998	52.269933999999999	0103000020E610000001000000050000003DB9A64066ED43400B0A83328D224A403DB9A64066ED43404A0856D5CB254A402B51F69672F043404A0856D5CB254A402B51F69672F043400B0A83328D224A403DB9A64066ED43400B0A83328D224A40
23669	Девица	1	9	1726	39.772531999999998	39.825235999999997	52.014738000000001	51.963765000000002	0103000020E61000000100000005000000868E1D54E2E24340C503CAA65CFB4940868E1D54E2E2434015014EEFE2014A40ADBD4F55A1E9434015014EEFE2014A40ADBD4F55A1E94340C503CAA65CFB4940868E1D54E2E24340C503CAA65CFB4940
23639	Грачевка	1	9	1726	39.965867000000003	40.05348	52.127243999999997	52.070264999999999	0103000020E6100000010000000500000090A4A487A1FB4340D7868A71FE084A4090A4A487A1FB43405D4E098849104A40BB7EC16ED80644405D4E098849104A40BB7EC16ED8064440D7868A71FE084A4090A4A487A1FB4340D7868A71FE084A40
23581	Верхняя Мосоловка	1	9	1726	40.062238999999998	40.090643	52.067352999999997	52.042582000000003	0103000020E6100000010000000500000093C49272F7074440FBB2B45373054A4093C49272F7074440CC24EA059F084A40404E98309A0B4440CC24EA059F084A40404E98309A0B4440FBB2B45373054A4093C49272F7074440FBB2B45373054A40
23548	Бреславка	1	9	1726	39.912103000000002	39.946868000000002	52.240451	52.216329000000002	0103000020E61000000100000005000000B0CA85CABFF4434094162EABB01B4A40B0CA85CABFF443402FA52E19C71E4A4081D07AF832F943402FA52E19C71E4A4081D07AF832F9434094162EABB01B4A40B0CA85CABFF4434094162EABB01B4A40
24673	Бочиновка	1	9	1726	39.748682000000002	39.768256000000001	52.087031000000003	52.070686000000002	0103000020E610000001000000050000004C8DD0CFD4DF43407D24253D0C094A404C8DD0CFD4DF43407D5EF1D4230B4A40577A6D3656E243407D5EF1D4230B4A40577A6D3656E243407D24253D0C094A404C8DD0CFD4DF43407D24253D0C094A40
23493	Боровое	1	9	1726	39.495213	39.518901999999997	52.203972999999998	52.188152000000002	0103000020E61000000100000005000000EBC6BB2363BF4340A8565F5D15184A40EBC6BB2363BF43402D228AC91B1A4A401CEA77616BC243402D228AC91B1A4A401CEA77616BC24340A8565F5D15184A40EBC6BB2363BF4340A8565F5D15184A40
23412	Березняговка	1	9	1726	40.043472999999999	40.085926999999998	52.183700999999999	52.129803000000003	0103000020E6100000010000000500000027A1F485900544401BF67B629D104A4027A1F485900544400A9FAD8383174A40F46BEBA7FF0A44400A9FAD8383174A40F46BEBA7FF0A44401BF67B629D104A4027A1F485900544401BF67B629D104A40
25115	Беляево	1	9	1726	39.505094	39.682214999999999	51.995843999999998	51.960368000000003	0103000020E61000000100000005000000F2B391EBA6C04340FE0FB056EDFA4940F2B391EBA6C043407BF5F1D077FF49409AEB34D252D743407BF5F1D077FF49409AEB34D252D74340FE0FB056EDFA4940F2B391EBA6C04340FE0FB056EDFA4940
60436	Яковлево	1	9	1665	38.574691000000001	38.608980000000003	52.143363000000001	52.109752	0103000020E610000001000000050000001C2785798F494340D655815A0C0E4A401C2785798F4943406D3A02B859124A4084F57F0EF34D43406D3A02B859124A4084F57F0EF34D4340D655815A0C0E4A401C2785798F494340D655815A0C0E4A40
60430	Урицкое	1	9	1665	38.156373000000002	38.217333000000004	52.044454999999999	52.011738999999999	0103000020E610000001000000050000001C7DCC07041443403B8BDEA980014A401C7DCC0704144340649291B3B0054A40B9AB5791D11B4340649291B3B0054A40B9AB5791D11B43403B8BDEA980014A401C7DCC07041443403B8BDEA980014A40
60427	Тербуны	1	9	1665	38.255107000000002	38.307082999999999	52.162481999999997	52.127332000000003	0103000020E6100000010000000500000087FD9E58A7204340FDDD3B6A4C104A4087FD9E58A72043402618CE35CC144A402B14E97E4E2743402618CE35CC144A402B14E97E4E274340FDDD3B6A4C104A4087FD9E58A7204340FDDD3B6A4C104A40
60453	Солдатское	1	9	1665	38.298009999999998	38.376477999999999	52.146165000000003	52.098329	0103000020E61000000100000005000000C3F0113125264340CB9F6F0B960C4A40C3F0113125264340F168E388B5124A40EDD45C6E30304340F168E388B5124A40EDD45C6E30304340CB9F6F0B960C4A40C3F0113125264340CB9F6F0B960C4A40
60440	Петропавловка	1	9	1665	38.183511000000003	38.205492999999997	52.200699999999998	52.185971000000002	0103000020E6100000010000000500000067BAD7497D1743409180D1E5CD174A4067BAD7497D1743405227A089B0194A40494739984D1A43405227A089B0194A40494739984D1A43409180D1E5CD174A4067BAD7497D1743409180D1E5CD174A40
60439	Михайловка	1	9	1665	38.420746999999999	38.456310999999999	52.035547000000001	52.020985000000003	0103000020E61000000100000005000000EF71A609DB354340715AF0A2AF024A40EF71A609DB354340473CD9CD8C044A400CE71A66683A4340473CD9CD8C044A400CE71A66683A4340715AF0A2AF024A40EF71A609DB354340715AF0A2AF024A40
21292	Березовка	1	9	1665	38.283538	38.338327	52.031973000000001	51.994996	0103000020E610000001000000050000002D9622F94A2443404ED367075CFF49402D9622F94A24434071ADF6B017044A40492D944C4E2B434071ADF6B017044A40492D944C4E2B43404ED367075CFF49402D9622F94A2443404ED367075CFF4940
60434	Барышниково	1	9	1665	38.196688999999999	38.234867999999999	52.020524999999999	52.007154999999997	0103000020E61000000100000005000000D13DEB1A2D1943405E807D74EA004A40D13DEB1A2D1943400DE02D90A0024A403F709527101E43400DE02D90A0024A403F709527101E43405E807D74EA004A40D13DEB1A2D1943405E807D74EA004A40
21238	Яркино	1	9	1606	38.313093000000002	38.331471999999998	52.830030000000001	52.815452000000001	0103000020E61000000100000005000000A3CD716E1328434099BA2BBB60684A40A3CD716E1328434075594C6C3E6A4A4015C5ABAC6D2A434075594C6C3E6A4A4015C5ABAC6D2A434099BA2BBB60684A40A3CD716E1328434099BA2BBB60684A40
21136	Чернолес	1	9	1606	38.449402999999997	38.480826	52.935974000000002	52.919618	0103000020E61000000100000005000000B5DC9909863943400E68E90AB6754A40B5DC99098639434002F4FBFECD774A408388D4B48B3D434002F4FBFECD774A408388D4B48B3D43400E68E90AB6754A40B5DC9909863943400E68E90AB6754A40
20530	Чемоданово	1	9	1606	37.979458999999999	38.004333000000003	53.033796000000002	53.022596	0103000020E61000000100000005000000ED629AE95EFD42409D82FC6CE4824A40ED629AE95EFD4240295E656D53844A4094A5D6FB8D004340295E656D53844A4094A5D6FB8D0043409D82FC6CE4824A40ED629AE95EFD42409D82FC6CE4824A40
21192	Успенское	1	9	1606	38.420836999999999	38.447265000000002	52.988627000000001	52.973900999999998	0103000020E610000001000000050000002FF99FFCDD3543405645B8C9A87C4A402FF99FFCDD354340A7785C548B7E4A409ED2C1FA3F394340A7785C548B7E4A409ED2C1FA3F3943405645B8C9A87C4A402FF99FFCDD3543405645B8C9A87C4A40
21035	Тростное	1	9	1606	38.366847999999997	38.395262000000002	52.717052000000002	52.695303000000003	0103000020E610000001000000050000002F4D11E0F42E4340C5E74EB0FF584A402F4D11E0F42E434005C4245CC85B4A4000ADF9F19732434005C4245CC85B4A4000ADF9F197324340C5E74EB0FF584A402F4D11E0F42E4340C5E74EB0FF584A40
20335	Толстая Дубрава	1	9	1606	38.134041000000003	38.159408999999997	52.987532000000002	52.973396999999999	0103000020E610000001000000050000005DA96741281143402383DC45987C4A405DA967412811434072E0D572677E4A4012D89C836714434072E0D572677E4A4012D89C83671443402383DC45987C4A405DA96741281143402383DC45987C4A40
21097	Телегино	1	9	1606	38.346806999999998	38.379055999999999	52.704127	52.682065000000001	0103000020E610000001000000050000000E83F92B642C4340855FEAE74D574A400E83F92B642C4340849D62D5205A4A4021AD31E884304340849D62D5205A4A4021AD31E884304340855FEAE74D574A400E83F92B642C4340855FEAE74D574A40
54746	Становая	1	9	1606	38.314951999999998	38.335020999999998	52.742137999999997	52.727229999999999	0103000020E61000000100000005000000A7E7DD5850284340C55565DF155D4A40A7E7DD5850284340368FC360FE5E4A40923CD7F7E12A4340368FC360FE5E4A40923CD7F7E12A4340C55565DF155D4A40A7E7DD5850284340C55565DF155D4A40
21007	Соловьево	1	9	1606	38.435704000000001	38.471870000000003	52.790239999999997	52.777794	0103000020E61000000100000005000000425E0F26C53743403483F8C08E634A40425E0F26C5374340DAFE959526654A4055FB743C663C4340DAFE959526654A4055FB743C663C43403483F8C08E634A40425E0F26C53743403483F8C08E634A40
20387	Семенек	1	9	1606	38.067610000000002	38.093696999999999	53.033011000000002	53.007671000000002	0103000020E61000000100000005000000F870C971A70843405610035DFB804A40F870C971A708434042B456B439844A40DD5D6743FE0B434042B456B439844A40DD5D6743FE0B43405610035DFB804A40F870C971A70843405610035DFB804A40
20203	Плоты	1	9	1606	38.227088000000002	38.248809999999999	52.913758999999999	52.897058000000001	0103000020E6100000010000000500000033A83638111D4340BE4EEACBD2724A4033A83638111D43407CB60E0EF6744A4079758E01D91F43407CB60E0EF6744A4079758E01D91F4340BE4EEACBD2724A4033A83638111D4340BE4EEACBD2724A40
20777	Пальна-Михайловка	1	9	1606	38.537052000000003	38.556905	52.758245000000002	52.745299000000003	0103000020E610000001000000050000002E20B41EBE444340EA5E27F5655F4A402E20B41EBE44434082AD122C0E614A404CFDBCA94847434082AD122C0E614A404CFDBCA948474340EA5E27F5655F4A402E20B41EBE444340EA5E27F5655F4A40
20920	Паленка	1	9	1606	38.356130999999998	38.378489999999999	52.912005000000001	52.898020000000002	0103000020E61000000100000005000000BF0B5BB3952D4340B493C151F2724A40BF0B5BB3952D4340ED647094BC744A4078EE3D5C72304340ED647094BC744A4078EE3D5C72304340B493C151F2724A40BF0B5BB3952D4340B493C151F2724A40
20082	Озерки	1	9	1606	38.293329999999997	38.308179000000003	52.864305000000002	52.858198999999999	0103000020E61000000100000005000000C47762D68B254340DE3AFF76D96D4A40C47762D68B2543407862D68BA16E4A403128D368722743407862D68BA16E4A403128D36872274340DE3AFF76D96D4A40C47762D68B254340DE3AFF76D96D4A40
20257	Лукьяновка	1	9	1606	38.239476000000003	38.263641	52.975060999999997	52.957109000000003	0103000020E61000000100000005000000A5164A26A71E434088DA368C827A4A40A5164A26A71E4340724D81CCCE7C4A403F7100FDBE214340724D81CCCE7C4A403F7100FDBE21434088DA368C827A4A40A5164A26A71E434088DA368C827A4A40
20476	Ламское	1	9	1606	38.033016000000003	38.054063999999997	52.972681000000001	52.960200999999998	0103000020E61000000100000005000000541F48DE39044340124BCADDE77A4A40541F48DE3904434065389ECF807C4A400AF2B391EB06434065389ECF807C4A400AF2B391EB064340124BCADDE77A4A40541F48DE39044340124BCADDE77A4A40
20904	Красная Пальна	1	9	1606	38.478301999999999	38.503284000000001	52.895026000000001	52.880470000000003	0103000020E6100000010000000500000042CEFBFF383D4340F88DAF3DB3704A4042CEFBFF383D4340EC88433690724A40CF4C309C6B404340EC88433690724A40CF4C309C6B404340F88DAF3DB3704A4042CEFBFF383D4340F88DAF3DB3704A40
20742	Кличено	1	9	1606	38.001306	38.027769999999997	52.960526999999999	52.950035	0103000020E61000000100000005000000F0A485CB2A004340168733BF9A794A40F0A485CB2A00434066F6798CF27A4A40ABE7A4F78D03434066F6798CF27A4A40ABE7A4F78D034340168733BF9A794A40F0A485CB2A004340168733BF9A794A40
19882	Кириллово	1	9	1606	38.218446	38.235937	52.736756	52.731194000000002	0103000020E6100000010000000500000094F8DC09F61B43400684D6C3975D4A4094F8DC09F61B4340DE9046054E5E4A404B75012F331E4340DE9046054E5E4A404B75012F331E43400684D6C3975D4A4094F8DC09F61B43400684D6C3975D4A40
19975	Злобино	1	9	1606	38.226728999999999	38.257810999999997	52.802017999999997	52.770380000000003	0103000020E610000001000000050000000307B474051D43400ABFD4CF9B624A400307B474051D4340D3669C86A8664A4047C66AF3FF204340D3669C86A8664A4047C66AF3FF2043400ABFD4CF9B624A400307B474051D43400ABFD4CF9B624A40
19879	Дружба	1	9	1606	38.305357999999998	38.332037999999997	52.766303999999998	52.744835999999999	0103000020E6100000010000000500000036C98FF81527434015713AC9565F4A4036C98FF815274340A165DD3F16624A40BE839F38802A4340A165DD3F16624A40BE839F38802A434015713AC9565F4A4036C98FF81527434015713AC9565F4A40
20027	Дмитриевка	1	9	1606	38.132621	38.255780000000001	52.834552000000002	52.728423999999997	0103000020E61000000100000005000000A4E194B9F91043408DCF64FF3C5D4A40A4E194B9F9104340DC679599D26A4A40467C2766BD204340DC679599D26A4A40467C2766BD2043408DCF64FF3C5D4A40A4E194B9F91043408DCF64FF3C5D4A40
20132	Грунин Воргол	1	9	1606	38.238182000000002	38.277304000000001	52.864952000000002	52.834752999999999	0103000020E61000000100000005000000793F6EBF7C1E4340739EB12FD96A4A40793F6EBF7C1E43400E4E44BFB66E4A4066868DB27E2343400E4E44BFB66E4A4066868DB27E234340739EB12FD96A4A40793F6EBF7C1E4340739EB12FD96A4A40
20834	Бродки	1	9	1606	38.459643999999997	38.477142999999998	52.828702999999997	52.821334999999998	0103000020E61000000100000005000000BCE6559DD53A4340B3075A8121694A40BCE6559DD53A43406D8C9DF0126A4A40F6419605133D43406D8C9DF0126A4A40F6419605133D4340B3075A8121694A40BCE6559DD53A4340B3075A8121694A40
20625	Березовка	1	9	1606	38.000909999999998	38.030627000000003	52.916339000000001	52.905667999999999	0103000020E61000000100000005000000A31EA2D11D0043405184D4EDEC734A40A31EA2D11D0043405186AA984A754A40F3AFE595EB0343405186AA984A754A40F3AFE595EB0343405184D4EDEC734A40A31EA2D11D0043405184D4EDEC734A40
20696	Барсуково	1	9	1606	37.888846000000001	37.911788999999999	52.969611	52.954906999999999	0103000020E610000001000000050000001897AAB4C5F1424059DC7F643A7A4A401897AAB4C5F14240C26B97361C7C4A4020ED7F80B5F44240C26B97361C7C4A4020ED7F80B5F4424059DC7F643A7A4A401897AAB4C5F1424059DC7F643A7A4A40
19664	Частая Дубрава	1	9	1512	39.254320999999997	39.287647999999997	52.556767000000001	52.535704000000003	0103000020E61000000100000005000000CFD72C978DA043400F2BDCF291444A40CFD72C978DA04340FB3E1C2444474A40416150A6D1A44340FB3E1C2444474A40416150A6D1A443400F2BDCF291444A40CFD72C978DA043400F2BDCF291444A40
54701	Хрущевка	1	9	1512	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
18781	Тюшевка	1	9	1512	39.536786999999997	39.572648000000001	52.766184000000003	52.755235999999996	0103000020E610000001000000050000007FF5B86FB5C443408461C092AB604A407FF5B86FB5C44340F75B3B5112624A40560F98874CC94340F75B3B5112624A40560F98874CC943408461C092AB604A407FF5B86FB5C443408461C092AB604A40
18808	Троицкое	1	9	1512	39.492527000000003	39.550217000000004	52.499273000000002	52.480035999999998	0103000020E61000000100000005000000D1B2EE1F0BBF43408A73D4D1713D4A40D1B2EE1F0BBF43404E637B2DE83F4A40045ABA826DC643404E637B2DE83F4A40045ABA826DC643408A73D4D1713D4A40D1B2EE1F0BBF43408A73D4D1713D4A40
19582	Тележенка	1	9	1512	39.480777000000003	39.515774999999998	52.830542000000001	52.812218999999999	0103000020E61000000100000005000000A2D5C9198ABD43404C18CDCAF6674A40A2D5C9198ABD43402BFA43334F6A4A40158C4AEA04C243402BFA43334F6A4A40158C4AEA04C243404C18CDCAF6674A40A2D5C9198ABD43404C18CDCAF6674A40
54744	Сырское	1	9	1512	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
18950	Сухая Лубна	1	9	1512	39.320050999999999	39.361930000000001	52.810853000000002	52.780141999999998	0103000020E61000000100000005000000AB06616EF7A84340361E6CB1DB634A40AB06616EF7A84340876EF607CA674A407CB8E4B853AE4340876EF607CA674A407CB8E4B853AE4340361E6CB1DB634A40AB06616EF7A84340361E6CB1DB634A40
18457	Студеные Хутора	1	9	1512	39.359253000000002	39.393452000000003	52.564819999999997	52.541992	0103000020E61000000100000005000000B5FE9600FCAD4340C9586DFE5F454A40B5FE9600FCAD4340381092054C484A40DD4598A25CB24340381092054C484A40DD4598A25CB24340C9586DFE5F454A40B5FE9600FCAD4340C9586DFE5F454A40
18601	Студеные Выселки	1	9	1512	39.492060000000002	39.523437999999999	52.739961999999998	52.711208999999997	0103000020E61000000100000005000000BBD573D2FBBE434078CF81E5085B4A40BBD573D2FBBE434031242713B75E4A40E8BD310400C3434031242713B75E4A40E8BD310400C3434078CF81E5085B4A40BBD573D2FBBE434078CF81E5085B4A40
17754	Стебаево	1	9	1512	39.252963999999999	39.282662999999999	52.425176	52.412796	0103000020E610000001000000050000005D88D51F61A04340B6F5D37FD6344A405D88D51F61A04340A585CB2A6C364A4006651A4D2EA44340A585CB2A6C364A4006651A4D2EA44340B6F5D37FD6344A405D88D51F61A04340B6F5D37FD6344A40
54698	Ситовка	1	9	1512	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
19228	Сенцово	1	9	1512	39.338628	39.378225	52.659315999999997	52.623583000000004	0103000020E6100000010000000500000044C18C2958AB4340B9AB5791D14F4A4044C18C2958AB434061DD787764544A40CAC342AD69B0434061DD787764544A40CAC342AD69B04340B9AB5791D14F4A4044C18C2958AB4340B9AB5791D14F4A40
19182	Пружинки	1	9	1512	39.166384999999998	39.212414000000003	52.744208999999998	52.710625	0103000020E61000000100000005000000C1C58A1A4C954340295C8FC2F55A4A40C1C58A1A4C954340C631923D425F4A40359BC761309B4340C631923D425F4A40359BC761309B4340295C8FC2F55A4A40C1C58A1A4C954340295C8FC2F55A4A40
54778	Пады	1	9	1512	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
19097	Новодмитриевка	1	9	1512	39.218288999999999	39.242562	52.655709999999999	52.640259	0103000020E61000000100000005000000CC09DAE4F09B43401EFCC401F4514A40CC09DAE4F09B434080D4264EEE534A404DA088450C9F434080D4264EEE534A404DA088450C9F43401EFCC401F4514A40CC09DAE4F09B43401EFCC401F4514A40
54753	Новая Деревня	1	9	1512	39.370724000000003	39.410933	52.736516000000002	52.710794	0103000020E61000000100000005000000D1EB4FE273AF4340B5183C4CFB5A4A40D1EB4FE273AF4340897D0228465E4A4070ECD97399B44340897D0228465E4A4070ECD97399B44340B5183C4CFB5A4A40D1EB4FE273AF4340B5183C4CFB5A4A40
54752	Кузьминские Отвержки	1	9	1512	39.458041000000001	39.491771999999997	52.705632999999999	52.682453000000002	0103000020E61000000100000005000000139D6516A1BA43404F07B29E5A574A40139D6516A1BA43403BFDA02E525A4A40548B8862F2BE43403BFDA02E525A4A40548B8862F2BE43404F07B29E5A574A40139D6516A1BA43404F07B29E5A574A40
18408	Крутые Хутора	1	9	1512	39.331091000000001	39.380910999999998	52.514094	52.495258999999997	0103000020E61000000100000005000000FE7F9C3061AA43405B069CA5643F4A40FE7F9C3061AA4340F0880AD5CD414A40E4D70FB1C1B04340F0880AD5CD414A40E4D70FB1C1B043405B069CA5643F4A40FE7F9C3061AA43405B069CA5643F4A40
19134	Крутогорье	1	9	1512	39.418774999999997	39.464247999999998	52.432941	52.389626	0103000020E61000000100000005000000F2B0506B9AB54340EDD5C743DF314A40F2B0506B9AB543407C0C569C6A374A40E09D7C7A6CBB43407C0C569C6A374A40E09D7C7A6CBB4340EDD5C743DF314A40F2B0506B9AB54340EDD5C743DF314A40
54748	Косырёвка	1	9	1512	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
18503	Копцевы Хутора	1	9	1512	39.443280999999999	39.470779	52.684604	52.670408000000002	0103000020E6100000010000000500000016F88A6EBDB84340077DE9EDCF554A4016F88A6EBDB84340FB5A971AA1574A4061527C7C42BC4340FB5A971AA1574A4061527C7C42BC4340077DE9EDCF554A4016F88A6EBDB84340077DE9EDCF554A40
18009	Ильино	1	9	1512	39.649543999999999	39.682709000000003	52.732655999999999	52.714689999999997	0103000020E6100000010000000500000011A8FE4124D343409D6340F67A5B4A4011A8FE4124D34340ED9BFBABC75D4A40AAD72D0263D74340ED9BFBABC75D4A40AAD72D0263D743409D6340F67A5B4A4011A8FE4124D343409D6340F67A5B4A40
18230	Ивово	1	9	1512	39.061138	39.105739	52.700628999999999	52.684232999999999	0103000020E610000001000000050000007C45B75ED387434007EC6AF294574A407C45B75ED387434089D00836AE594A40B47405DB888D434089D00836AE594A40B47405DB888D434007EC6AF294574A407C45B75ED387434007EC6AF294574A40
18194	Грязное	1	9	1512	39.364023000000003	39.407384999999998	52.375207000000003	52.337629	0103000020E61000000100000005000000F4FE3F4E98AE43403197546D372B4A40F4FE3F4E98AE43407A1D71C806304A40C3F0113125B443407A1D71C806304A40C3F0113125B443403197546D372B4A40F4FE3F4E98AE43403197546D372B4A40
19041	Вешаловка	1	9	1512	39.256557999999998	39.310501000000002	52.766897999999998	52.745010999999998	0103000020E610000001000000050000007AC37DE4D6A0434083143C855C5F4A407AC37DE4D6A0434014AFB2B629624A400A302C7FBEA7434014AFB2B629624A400A302C7FBEA7434083143C855C5F4A407AC37DE4D6A0434083143C855C5F4A40
18144	Вербилово	1	9	1512	39.395823	39.429223	52.314683000000002	52.285181000000001	0103000020E610000001000000050000009700FC53AAB2434065389ECF80244A409700FC53AAB24340B8CD548847284A4073D87DC7F0B64340B8CD548847284A4073D87DC7F0B6434065389ECF80244A409700FC53AAB2434065389ECF80244A40
17952	Васильевка	1	9	1512	39.197969000000001	39.239516999999999	52.511485999999998	52.501252000000001	0103000020E61000000100000005000000984F560C57994340FD86890629404A40984F560C57994340512E8D5F78414A4003EB387EA89E4340512E8D5F78414A4003EB387EA89E4340FD86890629404A40984F560C57994340FD86890629404A40
18328	Бруслановка	1	9	1512	39.274963999999997	39.297708999999998	52.609247000000003	52.59722	0103000020E61000000100000005000000E6C9350532A34340314278B4714C4A40E6C9350532A34340D31742CEFB4D4A40C85C19541BA64340D31742CEFB4D4A40C85C19541BA64340314278B4714C4A40E6C9350532A34340314278B4714C4A40
17697	Боринское	1	9	1512	39.331871999999997	39.404446999999998	52.473531000000001	52.446199	0103000020E61000000100000005000000A33A1DC87AAA43400341800C1D394A40A33A1DC87AAA43403352EFA99C3C4A408FFB56EBC4B343403352EFA99C3C4A408FFB56EBC4B343400341800C1D394A40A33A1DC87AAA43400341800C1D394A40
17887	Большая Кузьминка	1	9	1512	39.701456999999998	39.736393	52.760801000000001	52.743172999999999	0103000020E610000001000000050000006F46CD57C9D943409622F94A205F4A406F46CD57C9D94340CEE15AED61614A406D00362042DE4340CEE15AED61614A406D00362042DE43409622F94A205F4A406F46CD57C9D943409622F94A205F4A40
54759	совхоз имени Льва Толстого	1	9	1442	39.227497	39.847101000000002	53.434846999999998	53.043098000000001	0103000020E610000001000000050000001478279F1E9D4340F2423A3C84854A401478279F1E9D4340C1E10511A9B74A4057B439CE6DEC4340C1E10511A9B74A4057B439CE6DEC4340F2423A3C84854A401478279F1E9D4340F2423A3C84854A40
17613	Троицкое	1	9	1442	39.58623	39.623635999999998	53.193159000000001	53.179335000000002	0103000020E6100000010000000500000090F7AA9509CB43409B030473F4964A4090F7AA9509CB4340CBF6216FB9984A40DB4DF04DD3CF4340CBF6216FB9984A40DB4DF04DD3CF43409B030473F4964A4090F7AA9509CB43409B030473F4964A40
16996	Топки	1	9	1442	39.564292999999999	39.616539000000003	53.341526999999999	53.331353999999997	0103000020E610000001000000050000004D2EC6C03AC843400BB3D0CE69AA4A404D2EC6C03AC84340BAD91F28B7AB4A40B2DAFCBFEACE4340BAD91F28B7AB4A40B2DAFCBFEACE43400BB3D0CE69AA4A404D2EC6C03AC843400BB3D0CE69AA4A40
16703	Свищевка	1	9	1442	39.435600999999998	39.465299000000002	53.29222	53.281793	0103000020E610000001000000050000006D8D08C6C1B74340F19E03CB11A44A406D8D08C6C1B743405A9E077767A54A4046EEE9EA8EBB43405A9E077767A54A4046EEE9EA8EBB4340F19E03CB11A44A406D8D08C6C1B74340F19E03CB11A44A40
17485	Первомайское	1	9	1442	39.594082	39.63747	53.093397000000003	53.072032	0103000020E61000000100000005000000369204E10ACC4340FB21365838894A40369204E10ACC4340B345D26EF48B4A402F17F19D98D14340B345D26EF48B4A402F17F19D98D14340FB21365838894A40369204E10ACC4340FB21365838894A40
16848	Острый Камень	1	9	1442	39.361193	39.388134000000001	53.206260999999998	53.198720999999999	0103000020E61000000100000005000000A6457D923BAE4340A30392B06F994A40A6457D923BAE43405AB8ACC2669A4A409B3BFA5FAEB143405AB8ACC2669A4A409B3BFA5FAEB14340A30392B06F994A40A6457D923BAE4340A30392B06F994A40
16604	Орловка	1	9	1442	39.418506000000001	39.438412999999997	53.405687	53.391620000000003	0103000020E610000001000000050000000397C79A91B54340D23AAA9A20B24A400397C79A91B54340C8B4368DEDB34A401492CCEA1DB84340C8B4368DEDB34A401492CCEA1DB84340D23AAA9A20B24A400397C79A91B54340D23AAA9A20B24A40
17292	Новочемоданово	1	9	1442	39.693928999999997	39.721786000000002	53.258561	53.246186000000002	0103000020E610000001000000050000007C5F5CAAD2D84340D55DD905839F4A407C5F5CAAD2D84340B282DF8618A14A40F75AD07B63DC4340B282DF8618A14A40F75AD07B63DC4340D55DD905839F4A407C5F5CAAD2D84340D55DD905839F4A40
17323	Митягино	1	9	1442	39.696821999999997	39.752400999999999	53.213600999999997	53.198014000000001	0103000020E6100000010000000500000010919A7631D943403813D38558994A4010919A7631D943404AB20E47579B4A40253D0CAD4EE043404AB20E47579B4A40253D0CAD4EE043403813D38558994A4010919A7631D943403813D38558994A40
16295	Лев Толстой	1	9	1442	39.428531	39.482115999999998	53.223748000000001	53.196795000000002	0103000020E610000001000000050000003D29931ADAB6434017821C9430994A403D29931ADAB64340D04543C6A39C4A406D7022FAB5BD4340D04543C6A39C4A406D7022FAB5BD434017821C9430994A403D29931ADAB6434017821C9430994A40
17551	Кузовлево	1	9	1442	39.598941000000003	39.627346000000003	53.131866000000002	53.110664999999997	0103000020E61000000100000005000000E59D4319AACC4340EAE74D452A8E4A40E59D4319AACC434028BA2EFCE0904A4062A3ACDF4CD0434028BA2EFCE0904A4062A3ACDF4CD04340EAE74D452A8E4A40E59D4319AACC4340EAE74D452A8E4A40
16945	Круглое	1	9	1442	39.317965999999998	39.352694999999997	53.157521000000003	53.136560000000003	0103000020E61000000100000005000000B69E211CB3A843408CF84ECC7A914A40B69E211CB3A8434074B7EBA529944A403A3B191C25AD434074B7EBA529944A403A3B191C25AD43408CF84ECC7A914A40B69E211CB3A843408CF84ECC7A914A40
16745	Красный	1	9	1442	39.434460000000001	39.445833	53.256272000000003	53.248900999999996	0103000020E61000000100000005000000C8B5A1629CB743408978EBFCDB9F4A40C8B5A1629CB74340B5705985CDA04A40213D450E11B94340B5705985CDA04A40213D450E11B943408978EBFCDB9F4A40C8B5A1629CB743408978EBFCDB9F4A40
16815	Котовка	1	9	1442	39.275117000000002	39.312828000000003	53.251638	53.233263000000001	0103000020E610000001000000050000006DC9AA0837A34340F52EDE8FDB9D4A406DC9AA0837A3434026378AAC35A04A40F5A276BF0AA8434026378AAC35A04A40F5A276BF0AA84340F52EDE8FDB9D4A406DC9AA0837A34340F52EDE8FDB9D4A40
17240	Ильинка	1	9	1442	39.606721	39.627077	53.243648	53.233764000000001	0103000020E61000000100000005000000F165A208A9CD4340B77D8FFAEB9D4A40F165A208A9CD43402FDE8FDB2F9F4A407289230F44D043402FDE8FDB2F9F4A407289230F44D04340B77D8FFAEB9D4A40F165A208A9CD4340B77D8FFAEB9D4A40
16900	Золотуха	1	9	1442	39.251482000000003	39.284154000000001	53.179868999999997	53.165134000000002	0103000020E610000001000000050000002FC4EA8F30A0434095BA641C23954A402FC4EA8F30A04340384888F205974A40888384285FA44340384888F205974A40888384285FA4434095BA641C23954A402FC4EA8F30A0434095BA641C23954A40
16642	Знаменское	1	9	1442	39.390182000000003	39.40654	53.291283999999997	53.277098000000002	0103000020E6100000010000000500000073BED87BF1B14340BDE47FF277A34A4073BED87BF1B143408DEC4ACB48A54A400742B28009B443408DEC4ACB48A54A400742B28009B44340BDE47FF277A34A4073BED87BF1B14340BDE47FF277A34A40
17095	Загрядчино	1	9	1442	39.563735999999999	39.583266000000002	53.370103	53.357346	0103000020E61000000100000005000000F7C9518028C843409FAD8383BDAD4A40F7C9518028C843406493FC885FAF4A40336FD575A8CA43406493FC885FAF4A40336FD575A8CA43409FAD8383BDAD4A40F7C9518028C843409FAD8383BDAD4A40
16537	Домачи	1	9	1442	39.436993000000001	39.467626000000003	53.354126999999998	53.324927000000002	0103000020E610000001000000050000005CCAF962EFB74340304B3B3597A94A405CCAF962EFB74340B7D0950854AD4A403161342BDBBB4340B7D0950854AD4A403161342BDBBB4340304B3B3597A94A405CCAF962EFB74340304B3B3597A94A40
17666	Головинщино	1	9	1442	39.619441000000002	39.679341000000001	53.203488999999998	53.184159000000001	0103000020E610000001000000050000009966BAD749CF4340CD21A98592974A409966BAD749CF4340410C74ED0B9A4A407DEA58A5F4D64340410C74ED0B9A4A407DEA58A5F4D64340CD21A98592974A409966BAD749CF4340CD21A98592974A40
17039	Гагино	1	9	1442	39.630347	39.657969999999999	53.342371	53.333908000000001	0103000020E61000000100000005000000DC10E335AFD04340B7EF517FBDAA4A40DC10E335AFD04340A60C1CD0D2AB4A40E3DF675C38D44340A60C1CD0D2AB4A40E3DF675C38D44340B7EF517FBDAA4A40DC10E335AFD04340B7EF517FBDAA4A40
17131	Гагарино	1	9	1442	39.673887999999998	39.723483999999999	53.353766999999998	53.330283999999999	0103000020E610000001000000050000005B9544F641D643402F3201BF46AA4A405B9544F641D64340B7B3AF3C48AD4A40F296AB1F9BDC4340B7B3AF3C48AD4A40F296AB1F9BDC43402F3201BF46AA4A405B9544F641D643402F3201BF46AA4A40
17190	Бычки	1	9	1442	39.764778999999997	39.787336000000003	53.379148999999998	53.372729999999997	0103000020E6100000010000000500000073D53C47E4E14340791EDC9DB5AF4A4073D53C47E4E14340D2A755F487B04A40537B116DC7E44340D2A755F487B04A40537B116DC7E44340791EDC9DB5AF4A4073D53C47E4E14340791EDC9DB5AF4A40
17454	Астапово	1	9	1442	39.513539000000002	39.538080999999998	53.216033000000003	53.199767000000001	0103000020E610000001000000050000003B1C5DA5BBC14340F7E80DF791994A403B1C5DA5BBC14340ABED26F8A69B4A40ABCC94D6DFC44340ABED26F8A69B4A40ABCC94D6DFC44340F7E80DF791994A403B1C5DA5BBC14340F7E80DF791994A40
16190	Яблонево	1	9	1315	38.704236999999999	38.723928000000001	53.106000000000002	53.092320999999998	0103000020E610000001000000050000000BD12170245A4340F4DDAD2CD18B4A400BD12170245A434021B07268918D4A40505436ACA95C434021B07268918D4A40505436ACA95C4340F4DDAD2CD18B4A400BD12170245A4340F4DDAD2CD18B4A40
16035	Шовское	1	9	1315	39.396273000000001	39.434756	53.057167	53.035215000000001	0103000020E61000000100000005000000D7A4DB12B9B2434011AAD4EC81844A40D7A4DB12B9B2434089B48D3F51874A40B1DEA815A6B7434089B48D3F51874A40B1DEA815A6B7434011AAD4EC81844A40D7A4DB12B9B2434011AAD4EC81844A40
14983	Черепянь	1	9	1315	39.091833999999999	39.115485999999997	52.983021000000001	52.963098000000002	0103000020E6100000010000000500000097546D37C18B4340E86B96CB467B4A4097546D37C18B4340FF23D3A1D37D4A40AB92C83EC88E4340FF23D3A1D37D4A40AB92C83EC88E4340E86B96CB467B4A4097546D37C18B4340E86B96CB467B4A40
15231	Хорошовка	1	9	1315	39.009718999999997	39.040467999999997	53.086615000000002	53.074953000000001	0103000020E610000001000000050000002D93E1783E81434059DE550F98894A402D93E1783E814340E92B4833168B4A406B44300E2E854340E92B4833168B4A406B44300E2E85434059DE550F98894A402D93E1783E81434059DE550F98894A40
15939	Троекурово	1	9	1315	38.938921999999998	38.994698999999997	52.985298	52.971286999999997	0103000020E6100000010000000500000059BF99982E784340D503E621537C4A4059BF99982E7843403868AF3E1E7E4A40942EFD4B527F43403868AF3E1E7E4A40942EFD4B527F4340D503E621537C4A4059BF99982E784340D503E621537C4A40
14892	Теплое	1	9	1315	39.186371999999999	39.222960999999998	52.920226	52.908177000000002	0103000020E61000000100000005000000EF71A609DB9743405DFDD8243F744A40EF71A609DB974340E6762FF7C9754A4048A46DFC899C4340E6762FF7C9754A4048A46DFC899C43405DFDD8243F744A40EF71A609DB9743405DFDD8243F744A40
15067	Сурки	1	9	1315	39.362181	39.411121999999999	53.088572999999997	53.078139	0103000020E61000000100000005000000C51D6FF25BAE434065C57075008A4A40C51D6FF25BAE434080272D5C568B4A4043554CA59FB4434080272D5C568B4A4043554CA59FB4434065C57075008A4A40C51D6FF25BAE434065C57075008A4A40
54782	Старо Копыл	1	9	1315	38.898884000000002	38.916815	53.038274000000001	53.028039999999997	0103000020E61000000100000005000000E77283A10E7343406B7D91D096834A40E77283A10E734340C0249529E6844A40BABDA4315A754340C0249529E6844A40BABDA4315A7543406B7D91D096834A40E77283A10E7343406B7D91D096834A40
54776	Слободка	1	9	1315	38.856403	38.880631000000001	53.056496000000003	53.041074000000002	0103000020E6100000010000000500000020990E9D9E6D4340A35BAFE941854A4020990E9D9E6D43406B2DCC423B874A40016C4084B87043406B2DCC423B874A40016C4084B8704340A35BAFE941854A4020990E9D9E6D4340A35BAFE941854A40
14854	Сахарного Завода	1	9	1315	39.060985000000002	39.071244	52.912613999999998	52.902907999999996	0103000020E61000000100000005000000F645425BCE874340FCA5457D92734A40F645425BCE87434095EF1989D0744A40A304FD851E89434095EF1989D0744A40A304FD851E894340FCA5457D92734A40F645425BCE874340FCA5457D92734A40
15530	Романово	1	9	1315	39.139668999999998	39.187835999999997	53.140644000000002	53.112783999999998	0103000020E61000000100000005000000ECA17DACE09143408BC1C3B46F8E4A40ECA17DACE09143407730629F00924A40778192020B9843407730629F00924A40778192020B9843408BC1C3B46F8E4A40ECA17DACE09143408BC1C3B46F8E4A40
15751	Покрово-Казацкая	1	9	1315	39.146729999999998	39.182769999999998	53.011800000000001	52.972788999999999	0103000020E61000000100000005000000C9AB730CC89243404B749659847C4A40C9AB730CC8924340E10B93A982814A404F58E20165974340E10B93A982814A404F58E201659743404B749659847C4A40C9AB730CC89243404B749659847C4A40
15645	Павловское	1	9	1315	39.192704999999997	39.230938000000002	52.873742	52.853017000000001	0103000020E610000001000000050000004963B48EAA9843404DF73AA92F6D4A404963B48EAA984340219221C7D66F4A40ABB35A608F9D4340219221C7D66F4A40ABB35A608F9D43404DF73AA92F6D4A404963B48EAA9843404DF73AA92F6D4A40
15315	Павелка	1	9	1315	39.293981000000002	39.320805	52.925274999999999	52.905532000000001	0103000020E610000001000000050000009C525E2BA1A54340A1BDFA78E8734A409C525E2BA1A54340386744696F764A4057B2632310A94340386744696F764A4057B2632310A94340A1BDFA78E8734A409C525E2BA1A54340A1BDFA78E8734A40
15464	Ольховец	1	9	1315	39.169924000000002	39.197052999999997	53.110146	53.064300000000003	0103000020E610000001000000050000001B67D311C095434000917EFB3A884A401B67D311C095434082E49D43198E4A40124A5F083999434082E49D43198E4A40124A5F083999434000917EFB3A884A401B67D311C095434000917EFB3A884A40
15568	Новое Ракитино	1	9	1315	39.165945000000001	39.189264999999999	53.058368000000002	53.041924000000002	0103000020E61000000100000005000000A5F78DAF3D954340717500C45D854A40A5F78DAF3D9543400491459A78874A4083A3E4D5399843400491459A78874A4083A3E4D539984340717500C45D854A40A5F78DAF3D954340717500C45D854A40
14754	Мокрое	1	9	1315	39.405822000000001	39.435851999999997	52.911918999999997	52.899714000000003	0103000020E61000000100000005000000A8FFACF9F1B343406EE00ED429734A40A8FFACF9F1B34340EECC04C3B9744A40B6F292FFC9B74340EECC04C3B9744A40B6F292FFC9B743406EE00ED429734A40A8FFACF9F1B343406EE00ED429734A40
14691	Михайловка	1	9	1315	39.456054999999999	39.481333999999997	52.925069000000001	52.913749000000003	0103000020E61000000100000005000000B1169F0260BA434059E02BBAF5744A40B1169F0260BA43408FC536A968764A40F7393E5A9CBD43408FC536A968764A40F7393E5A9CBD434059E02BBAF5744A40B1169F0260BA434059E02BBAF5744A40
13900	Лебедянь	1	9	1315	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
15989	Курапово	1	9	1315	38.991815000000003	39.025331000000001	52.968749000000003	52.959831999999999	0103000020E6100000010000000500000054573ECBF37E4340BFD364C6DB7A4A4054573ECBF37E434030849CF7FF7B4A409949D40B3E83434030849CF7FF7B4A409949D40B3E834340BFD364C6DB7A4A4054573ECBF37E4340BFD364C6DB7A4A40
16099	Культура	1	9	1315	39.468640999999998	39.486643000000001	53.059873000000003	53.048360000000002	0103000020E610000001000000050000004948A46DFCBB4340A03715A930864A404948A46DFCBB4340EB7420EBA9874A40E6E95C514ABE4340EB7420EBA9874A40E6E95C514ABE4340A03715A930864A404948A46DFCBB4340A03715A930864A40
15357	Куликовка 2-я	1	9	1315	39.018377999999998	39.044851999999999	52.895271000000001	52.886111	0103000020E61000000100000005000000A27BD6355A8243401CD0D2156C714A40A27BD6355A8243405307793D98724A408194D8B5BD8543405307793D98724A408194D8B5BD8543401CD0D2156C714A40A27BD6355A8243401CD0D2156C714A40
15255	Куймань	1	9	1315	39.259135999999998	39.306288000000002	52.878692999999998	52.845458000000001	0103000020E61000000100000005000000AE9B525E2BA143401F12BEF7376C4A40AE9B525E2BA14340B01C210379704A402194F77134A74340B01C210379704A402194F77134A743401F12BEF7376C4A40AE9B525E2BA143401F12BEF7376C4A40
15167	Каменная Лубна	1	9	1315	39.108345	39.143279999999997	52.779124000000003	52.763612999999999	0103000020E61000000100000005000000B2D7BB3FDE8D434075E61E12BE614A40B2D7BB3FDE8D4340ADC3D155BA634A40DF15C1FF56924340ADC3D155BA634A40DF15C1FF5692434075E61E12BE614A40B2D7BB3FDE8D434075E61E12BE614A40
16133	Инициатор	1	9	1315	39.508122	39.515003	53.088616000000002	53.083585999999997	0103000020E61000000100000005000000663046240AC14340A43330F2B28A4A40663046240AC1434080F3E2C4578B4A40C32B499EEBC1434080F3E2C4578B4A40C32B499EEBC14340A43330F2B28A4A40663046240AC14340A43330F2B28A4A40
15434	Донские Избищи	1	9	1315	39.020066999999997	39.046505000000003	52.859808999999998	52.838794999999998	0103000020E610000001000000050000004A5D328E918243402F8672A25D6B4A404A5D328E918243403AE7A7380E6E4A40DD0C37E0F38543403AE7A7380E6E4A40DD0C37E0F38543402F8672A25D6B4A404A5D328E918243402F8672A25D6B4A40
15119	Докторово	1	9	1315	39.021512999999999	39.063034000000002	52.799807000000001	52.790855000000001	0103000020E610000001000000050000002CB81FF0C0824340657094BC3A654A402CB81FF0C0824340520E661360664A409E44847F11884340520E661360664A409E44847F11884340657094BC3A654A402CB81FF0C0824340657094BC3A654A40
15704	Грязновка	1	9	1315	39.220077000000003	39.253529999999998	52.819322	52.792053000000003	0103000020E6100000010000000500000008CDAE7B2B9C43406FD921FE61654A4008CDAE7B2B9C43405872158BDF684A400647C9AB73A043405872158BDF684A400647C9AB73A043406FD921FE61654A4008CDAE7B2B9C43406FD921FE61654A40
15034	Вязово	1	9	1315	39.284585	39.323033000000002	53.029004	53.017662000000001	0103000020E6100000010000000500000051F701486DA44340E43098BF42824A4051F701486DA4434002BA2F67B6834A40AF43352559A9434002BA2F67B6834A40AF43352559A94340E43098BF42824A4051F701486DA44340E43098BF42824A40
14953	Волотово	1	9	1315	39.074351999999998	39.118810000000003	52.974860999999997	52.953854	0103000020E610000001000000050000003332C85D8489434053944BE3177A4A403332C85D84894340AB92C83EC87C4A400938842A358F4340AB92C83EC87C4A400938842A358F434053944BE3177A4A403332C85D8489434053944BE3177A4A40
16230	Большой Верх	1	9	1315	38.735588999999997	38.754983000000003	53.106098000000003	53.091526000000002	0103000020E610000001000000050000000F26C5C7275E4340EA5DBC1FB78B4A400F26C5C7275E4340E415889E948D4A409B046F48A3604340E415889E948D4A409B046F48A3604340EA5DBC1FB78B4A400F26C5C7275E4340EA5DBC1FB78B4A40
14795	Большое Попово	1	9	1315	39.059987999999997	39.099155000000003	52.931984999999997	52.910516999999999	0103000020E610000001000000050000008313D1AFAD874340DCB930D28B744A408313D1AFAD87434068AED3484B774A40111E6D1CB18C434068AED3484B774A40111E6D1CB18C4340DCB930D28B744A408313D1AFAD874340DCB930D28B744A40
14661	Большие Избищи	1	9	1315	39.350315000000002	39.409613	52.978395999999996	52.944271999999998	0103000020E610000001000000050000002D26361FD7AC4340A643A7E7DD784A402D26361FD7AC4340C34483143C7D4A401B82E3326EB44340C34483143C7D4A401B82E3326EB44340A643A7E7DD784A402D26361FD7AC4340A643A7E7DD784A40
54764	Агроном	1	9	1315	39.001821999999997	39.026274000000001	53.043613000000001	53.036059999999999	0103000020E61000000100000005000000E7340BB43B804340CD58349D9D844A40E7340BB43B80434019575C1C95854A40185E49F25C83434019575C1C95854A40185E49F25C834340CD58349D9D844A40E7340BB43B804340CD58349D9D844A40
54751	Агроном	1	9	1315	38.965899	38.982311000000003	53.055435000000003	53.044657999999998	0103000020E610000001000000050000009B1E1494A27B43409CC0745AB7854A409B1E1494A27B4340E2067C7E18874A4023C0E95DBC7D4340E2067C7E18874A4023C0E95DBC7D43409CC0745AB7854A409B1E1494A27B43409CC0745AB7854A40
13803	Яблоново	1	9	1229	38.924405999999998	38.958353000000002	52.834752999999999	52.807206000000001	0103000020E61000000100000005000000F31C91EF527643404791B58652674A40F31C91EF52764340739EB12FD96A4A400283A44FAB7A4340739EB12FD96A4A400283A44FAB7A43404791B58652674A40F31C91EF527643404791B58652674A40
13615	Щербаково	1	9	1229	38.657443999999998	38.681564000000002	53.04063	53.027822999999998	0103000020E61000000100000005000000C879FF1F27544340CE893DB48F834A40C879FF1F27544340459E245D33854A40C310397D3D574340459E245D33854A40C310397D3D574340CE893DB48F834A40C879FF1F27544340CE893DB48F834A40
13731	Суходол	1	9	1229	38.556851000000002	38.574691000000001	52.933276999999997	52.919775999999999	0103000020E6100000010000000500000059DFC0E446474340A6D24F38BB754A4059DFC0E446474340F38DE89E75774A401C2785798F494340F38DE89E75774A401C2785798F494340A6D24F38BB754A4059DFC0E446474340A6D24F38BB754A40
13525	Сотниково	1	9	1229	38.684914999999997	38.717955000000003	52.988289999999999	52.968890000000002	0103000020E6100000010000000500000019C5724BAB574340F2B56796047C4A4019C5724BAB5743405F7B6649807E4A40F67F0EF3E55B43405F7B6649807E4A40F67F0EF3E55B4340F2B56796047C4A4019C5724BAB574340F2B56796047C4A40
54788	Сергиевское	1	9	1229	38.814784000000003	38.866779000000001	53.035843	53.004815000000001	0103000020E61000000100000005000000ECA694D74A684340DFC325C79D804A40ECA694D74A6843403065E08096844A4007EE409DF26E43403065E08096844A4007EE409DF26E4340DFC325C79D804A40ECA694D74A684340DFC325C79D804A40
13652	Решетово-Дуброво	1	9	1229	38.617109999999997	38.639074000000001	52.892446	52.878062	0103000020E610000001000000050000006C04E275FD4E434020EEEA5564704A406C04E275FD4E434017B9A7AB3B724A40A9DC442DCD51434017B9A7AB3B724A40A9DC442DCD51434020EEEA5564704A406C04E275FD4E434020EEEA5564704A40
12506	Пятницкое	1	9	1229	38.667352999999999	38.678697999999997	53.062736000000001	53.056793999999996	0103000020E6100000010000000500000099F1B6D26B554340F44D9A0645874A4099F1B6D26B5543401424B6BB07884A4028EE7893DF5643401424B6BB07884A4028EE7893DF564340F44D9A0645874A4099F1B6D26B554340F44D9A0645874A40
13557	Половнево	1	9	1229	38.610238000000003	38.629345000000001	53.019238000000001	53.005661000000003	0103000020E6100000010000000500000063635E471C4E43406CEEE87FB9804A4063635E471C4E4340946B0A6476824A40587380608E504340946B0A6476824A40587380608E5043406CEEE87FB9804A4063635E471C4E43406CEEE87FB9804A40
12991	Морево	1	9	1229	38.595756999999999	38.616202999999999	52.784647	52.771501999999998	0103000020E6100000010000000500000079AEEFC3414C43403866D993C0624A4079AEEFC3414C4340C7F319506F644A403A596ABDDF4E4340C7F319506F644A403A596ABDDF4E43403866D993C0624A4079AEEFC3414C43403866D993C0624A40
13834	Лески	1	9	1229	38.985759999999999	39.003456999999997	52.883941999999998	52.873350000000002	0103000020E610000001000000050000003CDA38622D7E434016FBCBEEC96F4A403CDA38622D7E4340C9C7EE0225714A409CF86A4771804340C9C7EE0225714A409CF86A477180434016FBCBEEC96F4A403CDA38622D7E434016FBCBEEC96F4A40
12951	Лаухино	1	9	1229	38.581617000000001	38.605961999999998	52.829737000000002	52.820236000000001	0103000020E6100000010000000500000019E6046D724A43403D80457EFD684A4019E6046D724A4340FDA36FD2346A4A40334FAE29904D4340FDA36FD2346A4A40334FAE29904D43403D80457EFD684A4019E6046D724A43403D80457EFD684A40
13273	Красное	1	9	1229	38.771782000000002	38.810679	52.876170999999999	52.856883000000003	0103000020E610000001000000050000001CD2A8C0C9624340CBBF9657AE6D4A401CD2A8C0C9624340105A0F5F26704A40E9465854C4674340105A0F5F26704A40E9465854C4674340CBBF9657AE6D4A401CD2A8C0C9624340CBBF9657AE6D4A40
54750	Краснинский	1	9	1229	38.500292999999999	39.027495999999999	53.092818000000001	52.697698000000003	0103000020E6100000010000000500000078B5DC9909404340083E062B4E594A4078B5DC9909404340753DD175E18B4A40AA622AFD84834340753DD175E18B4A40AA622AFD84834340083E062B4E594A4078B5DC9909404340083E062B4E594A40
13081	Корытное	1	9	1229	38.745102000000003	38.765555999999997	52.775571999999997	52.763928999999997	0103000020E61000000100000005000000941799805F5F4340A5BBEB6CC8614A40941799805F5F4340BED87BF145634A40D7A02FBDFD614340BED87BF145634A40D7A02FBDFD614340A5BBEB6CC8614A40941799805F5F4340A5BBEB6CC8614A40
13142	Ищеино	1	9	1229	38.790241999999999	38.827072999999999	52.970267999999997	52.948872999999999	0103000020E610000001000000050000007BF65CA6266543405987A3AB74794A407BF65CA6266543407B2DE8BD317C4A40CA332F87DD6943407B2DE8BD317C4A40CA332F87DD6943405987A3AB74794A407BF65CA6266543405987A3AB74794A40
12875	Знаменка	1	9	1229	38.723433999999997	38.742424999999997	52.831336	52.819848999999998	0103000020E6100000010000000500000040683D7C995C43404354E1CFF0684A4040683D7C995C434065FED137696A4A40CC5D4BC8075F434065FED137696A4A40CC5D4BC8075F43404354E1CFF0684A4040683D7C995C43404354E1CFF0684A40
13459	Епанчино	1	9	1229	38.875196000000003	38.894221999999999	52.887740999999998	52.875186999999997	0103000020E6100000010000000500000086CB2A6C067043403271AB2006704A4086CB2A6C06704340BF28417FA1714A408EAED2DD75724340BF28417FA1714A408EAED2DD757243403271AB2006704A4086CB2A6C067043403271AB2006704A40
13417	Дегтевая	1	9	1229	38.688004999999997	38.706994999999999	52.870773999999997	52.861347000000002	0103000020E61000000100000005000000033E3F8C10584340FDC0559E406E4A40033E3F8C10584340821ABE85756F4A40BFB7E9CF7E5A4340821ABE85756F4A40BFB7E9CF7E5A4340FDC0559E406E4A40033E3F8C10584340FDC0559E406E4A40
13179	Верхнее Брусланово	1	9	1229	38.922069999999998	38.958973	52.936250999999999	52.924342000000003	0103000020E61000000100000005000000B54FC76306764340DD28B2D650764A40B54FC7630676434074ECA012D7774A409E5F94A0BF7A434074ECA012D7774A409E5F94A0BF7A4340DD28B2D650764A40B54FC76306764340DD28B2D650764A40
13048	Верхнедрезгалово	1	9	1229	38.796342000000003	38.817335	52.781945	52.758059000000003	0103000020E610000001000000050000003337DF88EE65434020B8CA1308614A403337DF88EE654340A72215C616644A402670EB6E9E684340A72215C616644A402670EB6E9E68434020B8CA1308614A403337DF88EE65434020B8CA1308614A40
12903	Бредихино	1	9	1229	38.821880999999998	38.868647000000003	52.875323000000002	52.835928000000003	0103000020E61000000100000005000000151A886533694340C5E74EB0FF6A4A40151A886533694340E33785950A704A405F622CD32F6F4340E33785950A704A405F622CD32F6F4340C5E74EB0FF6A4A40151A886533694340C5E74EB0FF6A4A40
12081	Ясенок	1	9	1081	38.038128	38.059066999999999	52.629815000000001	52.620314	0103000020E61000000100000005000000EC87D860E10443401FA0FB72664F4A40EC87D860E1044340DFC325C79D504A40ECA2E8818F074340DFC325C79D504A40ECA2E8818F0743401FA0FB72664F4A40EC87D860E10443401FA0FB72664F4A40
12224	Черник	1	9	1081	37.973170000000003	38.006112000000002	52.586672	52.572203999999999	0103000020E6100000010000000500000063B9A5D590FC4240F8510DFB3D494A4063B9A5D590FC42404DBD6E11184B4A407C0E2C47C80043404DBD6E11184B4A407C0E2C47C8004340F8510DFB3D494A4063B9A5D590FC4240F8510DFB3D494A40
12755	Чернава	1	9	1081	38.013747000000002	38.082711000000003	52.502732000000002	52.469954000000001	0103000020E6100000010000000500000085B53176C2014340EC4FE273273C4A4085B53176C20143408B53AD8559404A407E022846960A43408B53AD8559404A407E022846960A4340EC4FE273273C4A4085B53176C2014340EC4FE273273C4A40
12697	Чермошное	1	9	1081	37.850181999999997	37.877355999999999	52.664428000000001	52.647685000000003	0103000020E61000000100000005000000EDD286C3D2EC42400D8E9257E7524A40EDD286C3D2EC4240FA4509FA0B554A4085798F334DF04240FA4509FA0B554A4085798F334DF042400D8E9257E7524A40EDD286C3D2EC42400D8E9257E7524A40
11636	Сухой Семенек	1	9	1081	37.892716999999998	37.930087	52.735638000000002	52.721300999999997	0103000020E61000000100000005000000A7CAF78C44F242403AC95697535C4A40A7CAF78C44F24240F1D8CF62295E4A40A6B73F170DF74240F1D8CF62295E4A40A6B73F170DF742403AC95697535C4A40A7CAF78C44F242403AC95697535C4A40
54789	Слобода	1	9	1081	37.889412	37.918318999999997	52.716816999999999	52.696109999999997	0103000020E61000000100000005000000C1559E40D8F142409335EA211A594A40C1559E40D8F14240C11BD2A8C05B4A40D0251C7A8BF54240C11BD2A8C05B4A40D0251C7A8BF542409335EA211A594A40C1559E40D8F142409335EA211A594A40
12608	Ровенка	1	9	1081	37.924545000000002	37.955706999999997	52.425967	52.413455999999996	0103000020E610000001000000050000001557957D57F64240E02A4F20EC344A401557957D57F642406E162F1686364A4075C7629B54FA42406E162F1686364A4075C7629B54FA4240E02A4F20EC344A401557957D57F64240E02A4F20EC344A40
12317	Преображение	1	9	1081	37.845565000000001	37.870196999999997	52.586629000000002	52.565733999999999	0103000020E6100000010000000500000035D252793BEC42401D1EC2F869484A4035D252793BEC42404EF1B8A8164B4A40E509849D62EF42404EF1B8A8164B4A40E509849D62EF42401D1EC2F869484A4035D252793BEC42401D1EC2F869484A40
11925	Предтечево	1	9	1081	38.053165	38.083627	52.713129000000002	52.703722999999997	0103000020E610000001000000050000005B25581CCE064340B4386398135A4A405B25581CCE064340236AA2CF475B4A4003081F4AB40A4340236AA2CF475B4A4003081F4AB40A4340B4386398135A4A405B25581CCE064340B4386398135A4A40
12024	Полевые Локотцы	1	9	1081	37.870161000000003	37.889204999999997	52.866354000000001	52.860090999999997	0103000020E6100000010000000500000099A0866F61EF4240BE4A3E76176E4A4099A0866F61EF4240206118B0E46E4A4047382D78D1F14240206118B0E46E4A4047382D78D1F14240BE4A3E76176E4A4099A0866F61EF4240BE4A3E76176E4A40
12114	Панкратовка	1	9	1081	38.102733999999998	38.122722000000003	52.639378999999998	52.628219000000001	0103000020E61000000100000005000000F8174163260D4340E8DCED7A69504A40F8174163260D4340E55FCB2BD7514A40F73FC05AB50F4340E55FCB2BD7514A40F73FC05AB50F4340E8DCED7A69504A40F8174163260D4340E8DCED7A69504A40
12180	Недоходовка	1	9	1081	37.956085000000002	37.968508	52.639811000000002	52.629387999999999	0103000020E610000001000000050000001C9947FE60FA4240573F36C98F504A401C9947FE60FA42407F4FAC53E5514A400AF5F411F8FB42407F4FAC53E5514A400AF5F411F8FB4240573F36C98F504A401C9947FE60FA4240573F36C98F504A40
11683	Мягкое	1	9	1081	38.179118000000003	38.201431999999997	52.692273	52.682906000000003	0103000020E61000000100000005000000FE0FB056ED164340001FBC7669574A40FE0FB056ED164340B073D3669C584A40162F1686C8194340B073D3669C584A40162F1686C8194340001FBC7669574A40FE0FB056ED164340001FBC7669574A40
11867	Мульгино	1	9	1081	37.922128000000001	37.950560000000003	52.679853999999999	52.668725999999999	0103000020E61000000100000005000000EA5C514A08F6424011FE45D098554A40EA5C514A08F642400307B47405574A40617138F3ABF942400307B47405574A40617138F3ABF9424011FE45D098554A40EA5C514A08F6424011FE45D098554A40
11953	Лебяжье	1	9	1081	37.957818000000003	37.997371000000001	52.892929000000002	52.861842000000003	0103000020E6100000010000000500000094C2BCC799FA4240DD28B2D6506E4A4094C2BCC799FA424033535A7F4B724A404A7D59DAA9FF424033535A7F4B724A404A7D59DAA9FF4240DD28B2D6506E4A4094C2BCC799FA4240DD28B2D6506E4A40
11755	Измалково	1	9	1081	37.945134000000003	38.001818	52.704121000000001	52.674280000000003	0103000020E61000000100000005000000392BA226FAF84240672C9ACE4E564A40392BA226FAF84240A2B60DA3205A4A40A6457D923B004340A2B60DA3205A4A40A6457D923B004340672C9ACE4E564A40392BA226FAF84240672C9ACE4E564A40
11546	Иваницкое-Троицкое	1	9	1081	38.245350999999999	38.269874999999999	52.599150999999999	52.587634999999999	0103000020E610000001000000050000003C855CA9671F4340137EA99F374B4A403C855CA9671F4340CF2EDFFAB04C4A40068195438B224340CF2EDFFAB04C4A40068195438B224340137EA99F374B4A403C855CA9671F4340137EA99F374B4A40
11506	Денисово	1	9	1081	38.144111000000002	38.163334999999996	52.523941999999998	52.508882	0103000020E6100000010000000500000037FFAF3A72124340F4C29D0B23414A4037FFAF3A721243401B800D8810434A4065A54929E81443401B800D8810434A4065A54929E8144340F4C29D0B23414A4037FFAF3A72124340F4C29D0B23414A40
12452	Гниловоды	1	9	1081	37.856264000000003	37.889879000000001	52.536920000000002	52.518988	0103000020E61000000100000005000000FF5E0A0F9AED42401B82E3326E424A40FF5E0A0F9AED4240BF4868CBB9444A40D732198EE7F14240BF4868CBB9444A40D732198EE7F142401B82E3326E424A40FF5E0A0F9AED42401B82E3326E424A40
11452	Власово	1	9	1081	38.170009	38.195162000000003	52.536619000000002	52.522950000000002	0103000020E610000001000000050000004983DBDAC2154340BBB88D06F0424A404983DBDAC2154340C4B46FEEAF444A4003B68311FB184340C4B46FEEAF444A4003B68311FB184340BBB88D06F0424A404983DBDAC2154340BBB88D06F0424A40
11588	Васильевка	1	9	1081	37.973063000000003	38.066595	52.781891000000002	52.582425999999998	0103000020E610000001000000050000004DF910548DFC4240882B67EF8C4A4A404DF910548DFC4240B404190115644A40DF89592F86084340B404190115644A40DF89592F86084340882B67EF8C4A4A404DF910548DFC4240882B67EF8C4A4A40
12432	Быково	1	9	1081	37.933878	37.951960999999997	52.518380000000001	52.505462000000001	0103000020E61000000100000005000000193A765089F7424075AF93FAB2404A40193A765089F7424043739D465A424A40A208A9DBD9F9424043739D465A424A40A208A9DBD9F9424075AF93FAB2404A40193A765089F7424075AF93FAB2404A40
11359	Афанасьево	1	9	1081	38.173242999999999	38.207720999999999	52.580145000000002	52.563763000000002	0103000020E6100000010000000500000066A19DD32C164340F1D8CF6229484A4066A19DD32C1643400EF8FC30424A4A40A1D80A9A961A43400EF8FC30424A4A40A1D80A9A961A4340F1D8CF6229484A4066A19DD32C164340F1D8CF6229484A40
11255	Яблоново	1	9	1012	38.734439000000002	38.756186999999997	52.367635999999997	52.351483000000002	0103000020E6100000010000000500000017F4DE18025E4340CC0C1B65FD2C4A4017F4DE18025E4340876A4AB20E2F4A40865451BCCA604340876A4AB20E2F4A40865451BCCA604340CC0C1B65FD2C4A4017F4DE18025E4340CC0C1B65FD2C4A40
11299	Юрьево	1	9	1012	38.762224000000003	38.785966000000002	52.350504000000001	52.334856000000002	0103000020E61000000100000005000000F81C588E90614340486FB88FDC2A4A40F81C588E90614340008FA850DD2C4A404CE2AC889A644340008FA850DD2C4A404CE2AC889A644340486FB88FDC2A4A40F81C588E90614340486FB88FDC2A4A40
10711	Черниговка	1	9	1012	39.069330999999998	39.117013	52.504331999999998	52.488477000000003	0103000020E61000000100000005000000ABCC94D6DF88434092EC116A863E4A40ABCC94D6DF884340C32973F38D404A407A1A3048FA8E4340C32973F38D404A407A1A3048FA8E434092EC116A863E4A40ABCC94D6DF88434092EC116A863E4A40
11075	Хмелинец	1	9	1012	38.873641999999997	38.899827999999999	52.475275000000003	52.462668000000001	0103000020E61000000100000005000000BD344580D36F4340EF737CB4383B4A40BD344580D36F43409FCDAACFD53C4A4036035C902D7343409FCDAACFD53C4A4036035C902D734340EF737CB4383B4A40BD344580D36F4340EF737CB4383B4A40
9255	Уткино	1	9	1012	38.940530000000003	38.989524000000003	52.369148000000003	52.342371999999997	0103000020E6100000010000000500000015747B496378434076887FD8D22B4A4015747B496378434021B1DD3D402F4A40B64DF1B8A87E434021B1DD3D402F4A40B64DF1B8A87E434076887FD8D22B4A4015747B496378434076887FD8D22B4A40
10022	Успеновка	1	9	1012	38.678213	38.698515	52.4071	52.396873999999997	0103000020E610000001000000050000006C5CFFAECF564340FC5069C4CC324A406C5CFFAECF564340CE1951DA1B344A40FA6184F068594340CE1951DA1B344A40FA6184F068594340FC5069C4CC324A406C5CFFAECF564340FC5069C4CC324A40
9312	Тюнино	1	9	1012	38.913958000000001	38.939120000000003	52.427855999999998	52.400067	0103000020E6100000010000000500000073F56393FC744340BB9A3C6535334A4073F56393FC744340DDB243FCC3364A4080828B1535784340DDB243FCC3364A4080828B1535784340BB9A3C6535334A4073F56393FC744340BB9A3C6535334A40
10846	Тростяное	1	9	1012	38.987161999999998	39.013078	52.706057999999999	52.696120999999998	0103000020E610000001000000050000004EED0C535B7E43408787307E1A594A404EED0C535B7E4340228AC91B605A4A400726378AAC814340228AC91B605A4A400726378AAC8143408787307E1A594A404EED0C535B7E43408787307E1A594A40
54791	Тимирязев	1	9	1012	38.757409000000003	38.773784999999997	52.507989000000002	52.500435000000003	0103000020E61000000100000005000000195932C7F26043400B630B410E404A40195932C7F260434027DD96C805414A4053910A630B63434027DD96C805414A4053910A630B6343400B630B410E404A40195932C7F26043400B630B410E404A40
9296	Тешевка	1	9	1012	38.936048	38.963903999999999	52.381276	52.365518999999999	0103000020E610000001000000050000003CBEBD6BD077434087889B53C92E4A403CBEBD6BD0774340F65FE7A6CD304A40E63DCE34617B4340F65FE7A6CD304A40E63DCE34617B434087889B53C92E4A403CBEBD6BD077434087889B53C92E4A40
10587	Сцепное	1	9	1012	38.893441000000003	38.924531000000002	52.255383000000002	52.239773	0103000020E61000000100000005000000E9F351465C7243405EBBB4E1B01E4A40E9F351465C724340297AE063B0204A40B091240857764340297AE063B0204A40B0912408577643405EBBB4E1B01E4A40E9F351465C7243405EBBB4E1B01E4A40
54772	Старо Воскресеновка	1	9	1012	39.021064000000003	39.039453000000002	52.343620999999999	52.331350999999998	0103000020E61000000100000005000000BD8FA339B28243409A3FA6B5692A4A40BD8FA339B2824340029CDEC5FB2B4A40535DC0CB0C854340029CDEC5FB2B4A40535DC0CB0C8543409A3FA6B5692A4A40BD8FA339B28243409A3FA6B5692A4A40
10775	Скорняково	1	9	1012	38.912574999999997	38.937385999999996	52.679335999999999	52.654688999999998	0103000020E61000000100000005000000D712F241CF744340850662D9CC534A40D712F241CF7443406B7F677BF4564A4037DDB243FC7743406B7F677BF4564A4037DDB243FC774340850662D9CC534A40D712F241CF744340850662D9CC534A40
10655	Рогожино	1	9	1012	39.038662000000002	39.078709000000003	52.569133000000001	52.553761000000002	0103000020E610000001000000050000008ACC5CE0F28443406F66F4A3E1464A408ACC5CE0F28443408509A359D9484A405073F222138A43408509A359D9484A405073F222138A43406F66F4A3E1464A408ACC5CE0F28443406F66F4A3E1464A40
10241	Репец	1	9	1012	39.022069999999999	39.056798999999998	52.404170999999998	52.391768999999996	0103000020E61000000100000005000000821C9430D3824340164B917C25324A40821C9430D3824340ED7E15E0BB334A4006B98B3045874340ED7E15E0BB334A4006B98B3045874340164B917C25324A40821C9430D3824340164B917C25324A40
10089	Паниковец	1	9	1012	38.804768000000003	38.858550000000001	52.392955999999998	52.376613999999996	0103000020E61000000100000005000000056F48A3026743409D9B36E334304A40056F48A3026743402C62D8614C324A408BFD65F7E46D43402C62D8614C324A408BFD65F7E46D43409D9B36E334304A40056F48A3026743409D9B36E334304A40
10469	Освобождение	1	9	1012	38.789326000000003	38.804822000000001	52.274794999999997	52.264158000000002	0103000020E61000000100000005000000F6F065A208654340077DE9EDCF214A40F6F065A2086543405A0D897B2C234A40F88C4468046743405A0D897B2C234A40F88C446804674340077DE9EDCF214A40F6F065A208654340077DE9EDCF214A40
9182	Нижняя Казачье	1	9	1012	38.797887000000003	38.827989000000002	52.368378	52.342289999999998	0103000020E61000000100000005000000A873452921664340B9DFA128D02B4A40A8734529216643406F48A302272F4A405039268BFB6943406F48A302272F4A405039268BFB694340B9DFA128D02B4A40A873452921664340B9DFA128D02B4A40
54790	Мирное	1	9	1012	38.631698	39.251095999999997	52.794297	52.135596999999997	0103000020E610000001000000050000006C79E57ADB504340C537143E5B114A406C79E57ADB504340CC272B86AB654A400514EAE923A04340CC272B86AB654A400514EAE923A04340C537143E5B114A406C79E57ADB504340C537143E5B114A40
9087	Ливенская	1	9	1012	38.815009000000003	38.842120000000001	52.466661999999999	52.459139999999998	0103000020E610000001000000050000000C7904375268434089247A19C53A4A400C790437526843409A249694BB3B4A405DA79196CA6B43409A249694BB3B4A405DA79196CA6B434089247A19C53A4A400C7904375268434089247A19C53A4A40
10375	Ксизово	1	9	1012	38.928080000000001	38.958640000000003	52.301644000000003	52.278106000000001	0103000020E610000001000000050000002D095053CB764340236937FA98234A402D095053CB7643406F8445459C264A4098512CB7B47A43406F8445459C264A4098512CB7B47A4340236937FA98234A402D095053CB764340236937FA98234A40
9013	Колодезная	1	9	1012	38.865969999999997	38.893943999999998	52.435949999999998	52.422502000000001	0103000020E6100000010000000500000097A8DE1AD86E43404F3FA88B14364A4097A8DE1AD86E43407958A835CD374A404B3ACAC16C7243407958A835CD374A404B3ACAC16C7243404F3FA88B14364A4097A8DE1AD86E43404F3FA88B14364A40
11157	Колесово 1-е	1	9	1012	38.847186000000001	38.864102000000003	52.475943999999998	52.467995999999999	0103000020E6100000010000000500000085D04197706C43405454FD4AE73B4A4085D04197706C43401C5DA5BBEB3C4A404034F3E49A6E43401C5DA5BBEB3C4A404034F3E49A6E43405454FD4AE73B4A4085D04197706C43405454FD4AE73B4A40
10247	Кашары	1	9	1012	38.949747000000002	38.971854999999998	52.488838000000001	52.475769	0103000020E61000000100000005000000B03C484F91794340AEB9A3FFE53C4A40B03C484F9179434062855B3E923E4A401FBAA0BE657C434062855B3E923E4A401FBAA0BE657C4340AEB9A3FFE53C4A40B03C484F91794340AEB9A3FFE53C4A40
10165	Камышевка	1	9	1012	39.067103000000003	39.111730999999999	52.403886	52.392263999999997	0103000020E61000000100000005000000543BC3D496884340F6B2EDB435324A40543BC3D496884340F8A75489B2334A4085798F334D8E4340F8A75489B2334A4085798F334D8E4340F6B2EDB435324A40543BC3D496884340F6B2EDB435324A40
9951	Каменка	1	9	1012	38.755656999999999	38.775914	52.386189999999999	52.371187999999997	0103000020E610000001000000050000002AFF5A5EB96043407555A016832F4A402AFF5A5EB9604340680586AC6E314A401841632651634340680586AC6E314A4018416326516343407555A016832F4A402AFF5A5EB96043407555A016832F4A40
9935	Калабино	1	9	1012	38.731150999999997	38.782147999999999	52.302933000000003	52.274343000000002	0103000020E6100000010000000500000006B8205B965D43407A71E2AB1D234A4006B8205B965D434089F02F82C6264A40DF50F86C1D64434089F02F82C6264A40DF50F86C1D6443407A71E2AB1D234A4006B8205B965D43407A71E2AB1D234A40
9448	Казино	1	9	1012	39.114705000000001	39.152639999999998	52.602410999999996	52.573999000000001	0103000020E6100000010000000500000006D847A7AE8E4340E6779ACC78494A4006D847A7AE8E434015E0BBCD1B4D4A40DD0720B58993434015E0BBCD1B4D4A40DD0720B589934340E6779ACC78494A4006D847A7AE8E4340E6779ACC78494A40
54739	Задонск	1	9	1012	38.906412000000003	38.948416999999999	52.402214999999998	52.375751000000001	0103000020E61000000100000005000000DA59F44E057443403B38D89B18304A40DA59F44E05744340F67AF7C77B334A4037FC6EBA65794340F67AF7C77B334A4037FC6EBA657943403B38D89B18304A40DA59F44E057443403B38D89B18304A40
9868	Донской Рудник	1	9	1012	39.012036000000002	39.020274000000001	52.631821000000002	52.621571000000003	0103000020E61000000100000005000000F52F49658A8143402E9276A38F4F4A40F52F49658A81434088F6B182DF504A40C47AA3569882434088F6B182DF504A40C47AA356988243402E9276A38F4F4A40F52F49658A8143402E9276A38F4F4A40
9633	Донское	1	9	1012	38.935085999999998	39.013050999999997	52.633335000000002	52.598877000000002	0103000020E610000001000000050000004679E6E5B0774340CEA96400A84C4A404679E6E5B0774340C2340C1F11514A400D17B9A7AB814340C2340C1F11514A400D17B9A7AB814340CEA96400A84C4A404679E6E5B0774340CEA96400A84C4A40
10530	Дегтевое	1	9	1012	38.861801999999997	38.887169999999998	52.264786999999998	52.244900999999999	0103000020E610000001000000050000004ED026874F6E4340FCE07CEA581F4A404ED026874F6E4340F6B3588AE4214A4004FF5BC98E714340F6B3588AE4214A4004FF5BC98E714340FCE07CEA581F4A404ED026874F6E4340FCE07CEA581F4A40
9511	Гнилуша	1	9	1012	39.062565999999997	39.131207000000003	52.338031000000001	52.312074000000003	0103000020E61000000100000005000000B7EBA5290288434049F7730AF2274A40B7EBA5290288434060048D99442B4A40CE001764CB90434060048D99442B4A40CE001764CB90434049F7730AF2274A40B7EBA5290288434049F7730AF2274A40
54777	Галичья Гора	1	9	1012	38.891643999999999	38.908774999999999	52.603788999999999	52.595649999999999	0103000020E610000001000000050000005AD6FD632172434063EE5A423E4C4A405AD6FD63217243409F573CF5484D4A4011363CBD527443409F573CF5484D4A4011363CBD5274434063EE5A423E4C4A405AD6FD632172434063EE5A423E4C4A40
10801	Гагарино	1	9	1012	38.952010999999999	38.957940000000001	52.750897999999999	52.747850999999997	0103000020E610000001000000050000005437177FDB794340F4A3E194B95F4A405437177FDB794340DF50F86C1D604A40DFC325C79D7A4340DF50F86C1D604A40DFC325C79D7A4340F4A3E194B95F4A405437177FDB794340F4A3E194B95F4A40
9376	Верхний Студенец	1	9	1012	39.038257999999999	39.073104000000001	52.610931000000001	52.59263	0103000020E61000000100000005000000BA675DA3E58443407250C24CDB4B4A40BA675DA3E5844340698EACFC324E4A40789ACC785B894340698EACFC324E4A40789ACC785B8943407250C24CDB4B4A40BA675DA3E58443407250C24CDB4B4A40
9166	Верхние Казачье	1	9	1012	38.87003	38.912503000000001	52.356873	52.336325000000002	0103000020E61000000100000005000000FA449E245D6F4340E2E995B20C2B4A40FA449E245D6F4340A7E9B303AE2D4A403E40F7E5CC744340A7E9B303AE2D4A403E40F7E5CC744340E2E995B20C2B4A40FA449E245D6F4340E2E995B20C2B4A40
9133	Бутырки	1	9	1012	38.954796000000002	38.979598000000003	52.554482999999998	52.539878000000002	0103000020E61000000100000005000000022D5DC1367A43403AEAE8B81A454A40022D5DC1367A43400F98874CF9464A400F9D9E77637D43400F98874CF9464A400F9D9E77637D43403AEAE8B81A454A40022D5DC1367A43403AEAE8B81A454A40
8996	Болховское	1	9	1012	38.844698000000001	38.879902999999999	52.421661999999998	52.406896000000003	0103000020E61000000100000005000000917F66101F6C4340C66F0A2B15344A40917F66101F6C4340A4FB3905F9354A407E5358A9A0704340A4FB3905F9354A407E5358A9A0704340C66F0A2B15344A40917F66101F6C4340C66F0A2B15344A40
54771	Болальшое Панарино	1	9	1012	38.890816999999998	38.901732000000003	52.386277999999997	52.377115000000003	0103000020E6100000010000000500000044DC9C4A0672434060EAE74D45304A4044DC9C4A067243400795B88E71314A40DBE044F46B7343400795B88E71314A40DBE044F46B73434060EAE74D45304A4044DC9C4A0672434060EAE74D45304A40
10406	Балахна	1	9	1012	38.840440000000001	38.873327000000003	52.303373999999998	52.283251999999997	0103000020E610000001000000050000000820B589936B43406743FE9941244A400820B589936B4340753A90F5D4264A405EDBDB2DC96F4340753A90F5D4264A405EDBDB2DC96F43406743FE9941244A400820B589936B43406743FE9941244A40
10616	Алексеевка	1	9	1012	38.770128999999997	39.035787999999997	52.389862000000001	52.206501000000003	0103000020E61000000100000005000000C0594A9693624340B0CBF09F6E1A4A40C0594A969362434001FA7DFFE6314A406CCB80B39484434001FA7DFFE6314A406CCB80B394844340B0CBF09F6E1A4A40C0594A9693624340B0CBF09F6E1A4A40
7655	Чернышевка	1	9	914	38.400525999999999	38.451416000000002	52.527853999999998	52.512723999999999	0103000020E610000001000000050000004E999B6F44334340E9EFA5F0A0414A404E999B6F44334340098849B890434A401172DEFFC7394340098849B890434A401172DEFFC7394340E9EFA5F0A0414A404E999B6F44334340E9EFA5F0A0414A40
8682	Черкассы	1	9	914	38.693727000000003	38.740223999999998	52.704290999999998	52.681345	0103000020E6100000010000000500000015ADDC0BCC58434085251E5036574A4015ADDC0BCC584340FEEE1D35265A4A406EDBF7A8BF5E4340FEEE1D35265A4A406EDBF7A8BF5E434085251E5036574A4015ADDC0BCC58434085251E5036574A40
8431	Хмелинец	1	9	914	38.428904000000003	38.463200999999998	52.657060000000001	52.647734	0103000020E61000000100000005000000D28F8653E6364340EE409DF2E8524A40D28F8653E636434040C1C58A1A544A40BC3C9D2B4A3B434040C1C58A1A544A40BC3C9D2B4A3B4340EE409DF2E8524A40D28F8653E6364340EE409DF2E8524A40
54779	Улусарка	1	9	914	38.674081000000001	38.691194000000003	52.548580000000001	52.537610000000001	0103000020E6100000010000000500000070ED44494856434054008C67D0444A4070ED444948564340AE9E93DE37464A408198840B79584340AE9E93DE37464A408198840B7958434054008C67D0444A4070ED44494856434054008C67D0444A40
7827	Трубицино	1	9	914	38.632570000000001	38.656725999999999	52.675136999999999	52.666710999999999	0103000020E610000001000000050000002237C30DF850434015713AC956554A402237C30DF8504340E7A8A3E36A564A406937FA980F544340E7A8A3E36A564A406937FA980F54434015713AC956554A402237C30DF850434015713AC956554A40
8013	Талица	1	9	914	38.704166000000001	38.745955000000002	52.719779000000003	52.700378000000001	0103000020E61000000100000005000000427A8A1C225A4340406B7EFCA5594A40427A8A1C225A43407EACE0B7215C4A40D3A414747B5F43407EACE0B7215C4A40D3A414747B5F4340406B7EFCA5594A40427A8A1C225A4340406B7EFCA5594A40
7252	Солидарность	1	9	914	38.559752000000003	38.591652000000003	52.598505000000003	52.586246000000003	0103000020E6100000010000000500000070EF1AF4A547434096B4E21B0A4B4A4070EF1AF4A54743400ABFD4CF9B4C4A40774EB340BB4B43400ABFD4CF9B4C4A40774EB340BB4B434096B4E21B0A4B4A4070EF1AF4A547434096B4E21B0A4B4A40
8526	Соколье	1	9	914	38.720182999999999	38.737321999999999	52.624730999999997	52.611756999999997	0103000020E610000001000000050000004D11E0F42E5C4340AE0CAA0D4E4E4A404D11E0F42E5C434010E6762FF74F4A40874F3A91605E434010E6762FF74F4A40874F3A91605E4340AE0CAA0D4E4E4A404D11E0F42E5C4340AE0CAA0D4E4E4A40
7690	Паниковец	1	9	914	38.344372	38.387680000000003	52.479438000000002	52.455534999999998	0103000020E610000001000000050000003DD4B661142C434078978BF84E3A4A403DD4B661142C4340D63A71395E3D4A401AA88C7F9F314340D63A71395E3D4A401AA88C7F9F31434078978BF84E3A4A403DD4B661142C434078978BF84E3A4A40
8324	Ольховец	1	9	914	38.346967999999997	38.392404999999997	52.591804000000003	52.574365999999998	0103000020E6100000010000000500000017618A72692C434098F738D384494A4017618A72692C43402DD2C43BC04B4A40B8E4B8533A3243402DD2C43BC04B4A40B8E4B8533A32434098F738D384494A4017618A72692C434098F738D384494A40
8397	Нижний Воргол	1	9	914	38.390106000000003	38.427278000000001	52.577610999999997	52.552802	0103000020E6100000010000000500000098FC4FFEEE314340EA944737C2464A4098FC4FFEEE314340A9674128EF494A407026A60BB1364340A9674128EF494A407026A60BB1364340EA944737C2464A4098FC4FFEEE314340EA944737C2464A40
7424	Маяк	1	9	914	38.251252999999998	38.266551	52.497633	52.490116	0103000020E61000000100000005000000CD02ED0E29204340889FFF1EBC3E4A40CD02ED0E2920434087342A70B23F4A40A9DBD9571E22434087342A70B23F4A40A9DBD9571E224340889FFF1EBC3E4A40CD02ED0E29204340889FFF1EBC3E4A40
8235	Малая Боевка	1	9	914	38.551012	38.573658000000002	52.448405000000001	52.441713999999997	0103000020E610000001000000050000000EDAAB8F87464340B91798158A384A400EDAAB8F87464340732EC55565394A405D8B16A06D494340732EC55565394A405D8B16A06D494340B91798158A384A400EDAAB8F87464340B91798158A384A40
8179	Лавы	1	9	914	38.484482999999997	38.507218999999999	52.584122999999998	52.568755000000003	0103000020E61000000100000005000000E63BF889033E4340DF37BEF6CC484A40E63BF889033E4340B3EBDE8AC44A4A4075745C8DEC404340B3EBDE8AC44A4A4075745C8DEC404340DF37BEF6CC484A40E63BF889033E4340DF37BEF6CC484A40
7569	Крутое	1	9	914	38.344479999999997	38.378374000000001	52.542715000000001	52.526516999999998	0103000020E610000001000000050000002310AFEB172C4340DEE4B7E864434A402310AFEB172C43403A0664AF77454A400FD4298F6E3043403A0664AF77454A400FD4298F6E304340DEE4B7E864434A402310AFEB172C4340DEE4B7E864434A40
54774	Капани	1	9	914	38.129091000000003	38.935796000000003	52.785943000000003	52.389899999999997	0103000020E610000001000000050000009E9ACB0D86104340EE5A423EE8314A409E9ACB0D8610434094C2BCC799644A4023DDCF29C877434094C2BCC799644A4023DDCF29C8774340EE5A423EE8314A409E9ACB0D86104340EE5A423EE8314A40
8570	Каменское	1	9	914	38.606338999999998	38.647733000000002	52.463282999999997	52.451413000000002	0103000020E6100000010000000500000009A52F849C4D4340A0FEB3E6C7394A4009A52F849C4D434079E57ADB4C3B4A401EC539EAE852434079E57ADB4C3B4A401EC539EAE8524340A0FEB3E6C7394A4009A52F849C4D4340A0FEB3E6C7394A40
8120	Казинка	1	9	914	38.519022999999997	38.550607999999997	52.595945	52.576028999999998	0103000020E61000000100000005000000976F7D586F42434017467A51BB494A40976F7D586F4243407C9BFEEC474C4A403E75AC527A4643407C9BFEEC474C4A403E75AC527A46434017467A51BB494A40976F7D586F42434017467A51BB494A40
7929	Казаки	1	9	914	38.231571000000002	38.295163000000002	52.642319000000001	52.599206000000002	0103000020E61000000100000005000000DCD9571EA41D434093C83EC8B24C4A40DCD9571EA41D4340BA4C4D8237524A40A0FEB3E6C7254340BA4C4D8237524A40A0FEB3E6C725434093C83EC8B24C4A40DCD9571EA41D434093C83EC8B24C4A40
8072	Ивановка	1	9	914	38.460721999999997	38.665852000000001	52.477978999999998	52.401511999999997	0103000020E610000001000000050000001B4641F0F83A4340CC79C6BE64334A401B4641F0F83A43405F96766A2E3D4A40F4FC69A33A5543405F96766A2E3D4A40F4FC69A33A554340CC79C6BE64334A401B4641F0F83A4340CC79C6BE64334A40
8701	Ериловка	1	9	914	38.756492000000001	38.781888000000002	52.696677999999999	52.676862	0103000020E61000000100000005000000C3D7D7BAD4604340DCF3FC69A3564A40C3D7D7BAD4604340DDEBA4BE2C594A404391EEE714644340DDEBA4BE2C594A404391EEE714644340DCF3FC69A3564A40C3D7D7BAD4604340DCF3FC69A3564A40
7788	Елецкий	1	9	914	38.562770999999998	38.580790999999998	52.639094999999998	52.627595999999997	0103000020E61000000100000005000000901150E108484340DA8CD31055504A40901150E108484340C0046EDDCD514A40D367075C574A4340C0046EDDCD514A40D367075C574A4340DA8CD31055504A40901150E108484340DA8CD31055504A40
7403	Екатериновка	1	9	914	38.682389999999998	38.712457000000001	52.56673	52.548290000000001	0103000020E61000000100000005000000088F368E58574340A75CE15D2E464A40088F368E58574340BFD4CF9B8A484A4034677DCA315B4340BFD4CF9B8A484A4034677DCA315B4340A75CE15D2E464A40088F368E58574340A75CE15D2E464A40
7732	Голиково	1	9	914	38.816239000000003	38.863050999999999	52.708655999999998	52.678936999999998	0103000020E61000000100000005000000215C01857A684340AD855968E7564A40215C01857A6843409D0E643DB55A4A40DAE38574786E43409D0E643DB55A4A40DAE38574786E4340AD855968E7564A40215C01857A684340AD855968E7564A40
54734	Газопровод	1	9	914	38.129091000000003	38.935796000000003	52.785943000000003	52.389899999999997	0103000020E610000001000000050000009E9ACB0D86104340EE5A423EE8314A409E9ACB0D8610434094C2BCC799644A4023DDCF29C877434094C2BCC799644A4023DDCF29C8774340EE5A423EE8314A409E9ACB0D86104340EE5A423EE8314A40
7612	Воронец	1	9	914	38.474178999999999	38.508971000000003	52.539181999999997	52.516002	0103000020E6100000010000000500000099B9C0E5B13C4340D655815A0C424A4099B9C0E5B13C4340C24B70EA03454A4064CE33F625414340C24B70EA03454A4064CE33F625414340D655815A0C424A4099B9C0E5B13C4340D655815A0C424A40
7535	Волчье	1	9	914	38.276127000000002	38.298217000000001	52.533442000000001	52.517634999999999	0103000020E610000001000000050000007445292158234340EA211ADD41424A4074452921582343400B28D4D347444A403D0E83F92B2643400B28D4D347444A403D0E83F92B264340EA211ADD41424A407445292158234340EA211ADD41424A40
7339	Большие Извалы	1	9	914	38.741624999999999	38.774369	52.556372000000003	52.536422000000002	0103000020E61000000100000005000000B0726891ED5E43406E6DE179A9444A40B0726891ED5E43407F349C3237474A40A304FD851E6343407F349C3237474A40A304FD851E6343406E6DE179A9444A40B0726891ED5E43406E6DE179A9444A40
7298	Архангельское	1	9	914	38.594822999999998	38.624997	52.571136000000003	52.554597999999999	0103000020E610000001000000050000004DF4F928234C4340A8363811FD464A404DF4F928234C4340BDC804FC1A494A408F8CD5E6FF4F4340BDC804FC1A494A408F8CD5E6FF4F4340A8363811FD464A404DF4F928234C4340A8363811FD464A40
7878	Аргамач-Пальна	1	9	914	38.579300000000003	38.602629	52.694603999999998	52.672691	0103000020E6100000010000000500000052499D80264A434022A81ABD1A564A4052499D80264A4340DCD5ABC8E8584A40834F73F2224D4340DCD5ABC8E8584A40834F73F2224D434022A81ABD1A564A4052499D80264A434022A81ABD1A564A40
54773	Тимирязевский	1	9	492	37.977096000000003	38.720497000000002	52.502101000000003	52.180697000000002	0103000020E61000000100000005000000B686527B11FD42401FBE4C1421174A40B686527B11FD4240FB2477D844404A40DDEEE53E395C4340FB2477D844404A40DDEEE53E395C43401FBE4C1421174A40B686527B11FD42401FBE4C1421174A40
3746	Тепленькая 1-я	1	9	492	38.552027000000002	38.569867000000002	52.308214	52.298329000000003	0103000020E6100000010000000500000027C11BD2A8464340653909A52F264A4027C11BD2A8464340AD156D8E73274A40EA08E066F1484340AD156D8E73274A40EA08E066F1484340653909A52F264A4027C11BD2A8464340653909A52F264A40
4387	Стрелец	1	9	492	38.202635999999998	38.241928000000001	52.424413000000001	52.393977999999997	0103000020E61000000100000005000000027FF8F9EF194340F7AB00DF6D324A40027FF8F9EF194340A67F492A53364A404CFE277FF71E4340A67F492A53364A404CFE277FF71E4340F7AB00DF6D324A40027FF8F9EF194340F7AB00DF6D324A40
4559	Стегаловка	1	9	492	38.293447	38.342872	52.425643000000001	52.396720000000002	0103000020E61000000100000005000000FE0DDAAB8F254340A6D590B8C7324A40FE0DDAAB8F254340BB6246787B364A40685BCD3AE32B4340BB6246787B364A40685BCD3AE32B4340A6D590B8C7324A40FE0DDAAB8F254340A6D590B8C7324A40
3543	Слепуха	1	9	492	38.613084999999998	38.652997999999997	52.346272999999997	52.321993999999997	0103000020E610000001000000050000008655BC91794E43400DC1711937294A408655BC91794E4340703E75AC522C4A403C2D3F7095534340703E75AC522C4A403C2D3F70955343400DC1711937294A408655BC91794E43400DC1711937294A40
4494	Свишни	1	9	492	38.240850000000002	38.269992000000002	52.461488000000003	52.449782999999996	0103000020E61000000100000005000000ED9E3C2CD41E4340FCA5457D92394A40ED9E3C2CD41E43408CBFED09123B4A4040170D198F2243408CBFED09123B4A4040170D198F224340FCA5457D92394A40ED9E3C2CD41E4340FCA5457D92394A40
3448	Пашинино	1	9	492	38.462212999999998	38.469849000000004	52.373106999999997	52.368076000000002	0103000020E610000001000000050000009D64ABCB293B4340A438471D1D2F4A409D64ABCB293B43404F745DF8C12F4A4077871403243C43404F745DF8C12F4A4077871403243C4340A438471D1D2F4A409D64ABCB293B4340A438471D1D2F4A40
3839	Нижний Ломовец	1	9	492	38.622526999999998	38.661935999999997	52.263210000000001	52.247835000000002	0103000020E6100000010000000500000041F0F8F6AE4F4340EFE6A90EB91F4A4041F0F8F6AE4F434076FD82DDB0214A40C405A051BA54434076FD82DDB0214A40C405A051BA544340EFE6A90EB91F4A4041F0F8F6AE4F4340EFE6A90EB91F4A40
3916	Меньшой Колодезь	1	9	492	38.406041999999999	38.439441000000002	52.258584999999997	52.250861999999998	0103000020E61000000100000005000000B6662B2FF933434092E7FA3E1C204A40B6662B2FF93343403A1E335019214A40C2C2499A3F3843403A1E335019214A40C2C2499A3F38434092E7FA3E1C204A40B6662B2FF933434092E7FA3E1C204A40
4127	Красотыновка	1	9	492	38.157899999999998	38.182378999999997	52.330503	52.314627999999999	0103000020E61000000100000005000000EA04341136144340F433F5BA45284A40EA043411361443406D1D1CEC4D2A4A40143DF031581743406D1D1CEC4D2A4A40143DF03158174340F433F5BA45284A40EA04341136144340F433F5BA45284A40
3409	Красное	1	9	492	38.303246999999999	38.328094999999998	52.370818999999997	52.352473000000003	0103000020E6100000010000000500000018CE35CCD02643408CDCD3D51D2D4A4018CE35CCD026434022DE3AFF762F4A40957D5704FF29434022DE3AFF762F4A40957D5704FF2943408CDCD3D51D2D4A4018CE35CCD02643408CDCD3D51D2D4A40
54775	Карташевка	1	9	492	38.569867000000002	38.607712999999997	52.304954000000002	52.290585	0103000020E61000000100000005000000EA08E066F1484340A5DAA7E331254A40EA08E066F1484340676490BB08274A40512D228AC94D4340676490BB08274A40512D228AC94D4340A5DAA7E331254A40EA08E066F1484340A5DAA7E331254A40
4270	Казинка Войсковая	1	9	492	38.035063999999998	38.084076000000003	52.423067000000003	52.407083	0103000020E610000001000000050000002BA226FA7C044340F8E0B54B1B344A402BA226FA7C0443402882380F27364A4073309B00C30A43402882380F27364A4073309B00C30A4340F8E0B54B1B344A402BA226FA7C044340F8E0B54B1B344A40
54769	Жерновое	1	9	492	38.45579	38.488973999999999	52.320991999999997	52.305422	0103000020E6100000010000000500000003ECA353573A43404DBD6E1118274A4003ECA353573A434089230F4416294A40124C35B3963E434089230F4416294A40124C35B3963E43404DBD6E1118274A4003ECA353573A43404DBD6E1118274A40
3326	Екатериновка	1	9	492	38.372463000000003	38.402673	52.335675999999999	52.323106000000003	0103000020E610000001000000050000002BFC19DEAC2F4340199293895B294A402BFC19DEAC2F4340AB06616EF72A4A40B9FDF2C98A334340AB06616EF72A4A40B9FDF2C98A334340199293895B294A402BFC19DEAC2F4340199293895B294A40
4060	Дубовец	1	9	492	38.163919	38.215643999999998	52.292011000000002	52.254148000000001	0103000020E61000000100000005000000B5183C4CFB144340022CF2EB87204A40B5183C4CFB1443404089CF9D60254A4010CAFB389A1B43404089CF9D60254A4010CAFB389A1B4340022CF2EB87204A40B5183C4CFB144340022CF2EB87204A40
3626	Долгуша	1	9	492	38.648138000000003	38.697698000000003	52.307904999999998	52.285285000000002	0103000020E61000000100000005000000BEA59C2FF65243400A85083884244A40BEA59C2FF65243402FA3586E69274A40083E062B4E5943402FA3586E69274A40083E062B4E5943400A85083884244A40BEA59C2FF65243400A85083884244A40
2943	Долгоруково	1	9	492	38.325544000000001	38.369515999999997	52.331845999999999	52.312299000000003	0103000020E610000001000000050000005BB4006DAB29434069C9E369F9274A405BB4006DAB2943407AA702EE792A4A40A3ACDF4C4C2F43407AA702EE792A4A40A3ACDF4C4C2F434069C9E369F9274A405BB4006DAB29434069C9E369F9274A40
4329	Грызлово	1	9	492	38.181544000000002	38.210946	52.447505	52.431145000000001	0103000020E610000001000000050000007C6473D53C174340BE6A65C22F374A407C6473D53C174340F3E505D847394A406B9C4D47001B4340F3E505D847394A406B9C4D47001B4340BE6A65C22F374A407C6473D53C174340BE6A65C22F374A40
4241	Вязовое	1	9	492	38.154082000000002	38.183143000000001	52.383118000000003	52.364390999999998	0103000020E610000001000000050000007E737FF5B813434076FA415DA42E4A407E737FF5B81343402541B8020A314A40E4BED53A711743402541B8020A314A40E4BED53A7117434076FA415DA42E4A407E737FF5B813434076FA415DA42E4A40
4174	Веселая	1	9	492	38.067269000000003	38.086834000000003	52.361207	52.335368000000003	0103000020E610000001000000050000006F8445459C084340FE0FB056ED2A4A406F8445459C0843400B0BEE073C2E4A40271763601D0B43400B0BEE073C2E4A40271763601D0B4340FE0FB056ED2A4A406F8445459C084340FE0FB056ED2A4A40
3821	Верхний Ломовец	1	9	492	38.587052	38.630414000000002	52.249929999999999	52.224980000000002	0103000020E6100000010000000500000094861A85244B434086200725CC1C4A4094861A85244B43400725CCB4FD1F4A406478EC67B15043400725CCB4FD1F4A406478EC67B150434086200725CC1C4A4094861A85244B434086200725CC1C4A40
3185	Братовщина	1	9	492	38.310299000000001	38.349905999999997	52.317089000000003	52.296081999999998	0103000020E61000000100000005000000A27DACE0B72743409677D503E6254A40A27DACE0B7274340EF75525F96284A404B5645B8C92C4340EF75525F96284A404B5645B8C92C43409677D503E6254A40A27DACE0B72743409677D503E6254A40
3939	Большой Колодезь	1	9	492	38.461790999999998	38.480457999999999	52.237406999999997	52.220517000000001	0103000020E61000000100000005000000274BADF71B3B4340249BABE6391C4A40274BADF71B3B4340B56B425A631E4A40008DD2A57F3D4340B56B425A631E4A40008DD2A57F3D4340249BABE6391C4A40274BADF71B3B4340249BABE6391C4A40
3513	Большая Боевка	1	9	492	38.533593000000003	38.559465000000003	52.398626999999998	52.383172999999999	0103000020E61000000100000005000000F12F82C64C444340E8DA17D00B314A40F12F82C64C444340BB26A43506334A40DA20938C9C474340BB26A43506334A40DA20938C9C474340E8DA17D00B314A40F12F82C64C444340E8DA17D00B314A40
32509	2-я Набережная	1	9	492	38.175938000000002	38.185262999999999	52.496366999999999	52.491853999999996	0103000020E61000000100000005000000D40FEA228516434011346612F53E4A40D40FEA228516434025E82FF4883F4A405514AFB2B617434025E82FF4883F4A405514AFB2B617434011346612F53E4A40D40FEA228516434011346612F53E4A40
1359	Чечеры	1	9	286	39.927239999999998	39.958016000000001	52.794514999999997	52.781677999999999	0103000020E6100000010000000500000082C5E1CCAFF64340580053060E644A4082C5E1CCAFF643403997E2AAB2654A40BA85AE44A0FA43403997E2AAB2654A40BA85AE44A0FA4340580053060E644A4082C5E1CCAFF64340580053060E644A40
1943	Трубетчино	1	9	286	39.526806999999998	39.572566999999999	52.902957000000001	52.875464000000001	0103000020E61000000100000005000000E5266A696EC34340A56950340F704A40E5266A696EC34340DE58501894734A4069E21DE049C94340DE58501894734A4069E21DE049C94340A56950340F704A40E5266A696EC34340A56950340F704A40
2486	Ратчино	1	9	286	39.884076	39.942987000000002	53.055911000000002	53.019249000000002	0103000020E61000000100000005000000D996016729F1434088BD50C076824A40D996016729F143404B3E761728874A40CEC64ACCB3F843404B3E761728874A40CEC64ACCB3F8434088BD50C076824A40D996016729F1434088BD50C076824A40
2528	Путятино	1	9	286	39.722828	39.789034000000001	53.053297000000001	53.036585000000002	0103000020E610000001000000050000000951BEA085DC4340184339D1AE844A400951BEA085DC4340CAFCA36FD2864A404EB7EC10FFE44340CAFCA36FD2864A404EB7EC10FFE44340184339D1AE844A400951BEA085DC4340184339D1AE844A40
1215	Преображеновка	1	9	286	40.064250999999999	40.092215000000003	52.969172	52.944358999999999	0103000020E610000001000000050000001EDE736039084440755776C1E0784A401EDE7360390844407619FED30D7C4A40AF997CB3CD0B44407619FED30D7C4A40AF997CB3CD0B4440755776C1E0784A401EDE736039084440755776C1E0784A40
2035	Порой	1	9	286	39.435887999999998	39.490551000000004	52.892538000000002	52.863782999999998	0103000020E61000000100000005000000035C902DCBB743409EEBFB70906E4A40035C902DCBB74340F83768AF3E724A4093020B60CABE4340F83768AF3E724A4093020B60CABE43409EEBFB70906E4A40035C902DCBB743409EEBFB70906E4A40
1709	Панино	1	9	286	39.739375000000003	39.782099000000002	52.814515999999998	52.795200999999999	0103000020E61000000100000005000000713D0AD7A3DE43408D5F7825C9654A40713D0AD7A3DE4340CC086F0F42684A40FE9DEDD11BE44340CC086F0F42684A40FE9DEDD11BE443408D5F7825C9654A40713D0AD7A3DE43408D5F7825C9654A40
1818	Махоново	1	9	286	39.743578999999997	39.790992000000003	52.919927999999999	52.894336000000003	0103000020E61000000100000005000000067FBF982DDF434057D11F9A79724A40067FBF982DDF43405C566133C0754A40E6B2D1393FE543405C566133C0754A40E6B2D1393FE5434057D11F9A79724A40067FBF982DDF434057D11F9A79724A40
1438	Лебяжье	1	9	286	39.900955000000003	39.908051999999998	52.800553000000001	52.796595000000003	0103000020E610000001000000050000007715527E52F343401D9430D3F6654A407715527E52F343407BDB4C8578664A40A088450C3BF443407BDB4C8578664A40A088450C3BF443401D9430D3F6654A407715527E52F343401D9430D3F6654A40
2378	Крутое	1	9	286	39.800074000000002	39.829403999999997	53.024718999999997	52.998534999999997	0103000020E61000000100000005000000A13028D368E64340A774B0FECF7F4A40A13028D368E643407F4B00FE29834A40F69507E929EA43407F4B00FE29834A40F69507E929EA4340A774B0FECF7F4A40A13028D368E64340A774B0FECF7F4A40
1257	Кривец	1	9	286	40.019173000000002	40.081274000000001	52.893489000000002	52.858618	0103000020E61000000100000005000000ADFBC74274024440E3E0D231E76D4A40ADFBC74274024440FA2AF9D85D724A40EF01BA2F670A4440FA2AF9D85D724A40EF01BA2F670A4440E3E0D231E76D4A40ADFBC74274024440E3E0D231E76D4A40
54755	Кореневщина	1	9	286	39.827517999999998	39.855105000000002	52.745561000000002	52.72531	0103000020E61000000100000005000000F86C1D1CECE943401BBB44F5D65C4A40F86C1D1CECE943402716F88A6E5F4A40B3D2A41474ED43402716F88A6E5F4A40B3D2A41474ED43401BBB44F5D65C4A40F86C1D1CECE943401BBB44F5D65C4A40
2188	Каликино	1	9	286	39.765740999999998	39.843077000000001	52.968825000000002	52.929856999999998	0103000020E61000000100000005000000691A14CD03E24340747ADE8D05774A40691A14CD03E243400B462575027C4A40418177F2E9EB43400B462575027C4A40418177F2E9EB4340747ADE8D05774A40691A14CD03E24340747ADE8D05774A40
60447	Зарницы	1	9	286	39.383094	40.125669000000002	53.104199999999999	52.706592999999998	0103000020E610000001000000050000009CA5643909B14340904AB1A3715A4A409CA5643909B14340211FF46C568D4A407E8FFAEB15104440211FF46C568D4A407E8FFAEB15104440904AB1A3715A4A409CA5643909B14340904AB1A3715A4A40
1899	Замартынье	1	9	286	39.664563000000001	39.701852000000002	52.880893999999998	52.829481000000001	0103000020E61000000100000005000000DA907F6610D54340A2D3F36E2C6A4A40DA907F6610D543400E9F7422C1704A40EC504D49D6D943400E9F7422C1704A40EC504D49D6D94340A2D3F36E2C6A4A40DA907F6610D54340A2D3F36E2C6A4A40
2069	Екатериновка	1	9	286	39.535170000000001	39.574741000000003	52.943745999999997	52.932245999999999	0103000020E6100000010000000500000071E6577380C44340D5E940D653774A4071E6577380C443408BDD3EABCC784A40CE55F31C91C943408BDD3EABCC784A40CE55F31C91C94340D5E940D653774A4071E6577380C44340D5E940D653774A40
2640	Доброе	1	9	286	39.774382000000003	39.836258000000001	52.888534	52.840192999999999	0103000020E61000000100000005000000384E0AF31EE3434000AAB8718B6B4A40384E0AF31EE3434029B16B7BBB714A405A828C800AEB434029B16B7BBB714A405A828C800AEB434000AAB8718B6B4A40384E0AF31EE3434000AAB8718B6B4A40
2252	Гудово	1	9	286	39.789250000000003	39.817798000000003	52.998902999999999	52.978928000000003	0103000020E610000001000000050000001B2FDD2406E54340C19140834D7D4A401B2FDD2406E543402A70B20DDC7F4A40FB5DD89AADE843402A70B20DDC7F4A40FB5DD89AADE84340C19140834D7D4A401B2FDD2406E54340C19140834D7D4A40
1593	Горицы	1	9	286	39.794029000000002	39.849975999999998	52.776350999999998	52.753900999999999	0103000020E61000000100000005000000AD8905BEA2E54340FAB5F5D37F604A40AD8905BEA2E54340C39B35785F634A4044317903CCEC4340C39B35785F634A4044317903CCEC4340FAB5F5D37F604A40AD8905BEA2E54340FAB5F5D37F604A40
2147	Волчье	1	9	286	39.609155000000001	39.653281	53.037495	53.017017000000003	0103000020E61000000100000005000000F29881CAF8CD4340EF3CF19C2D824A40F29881CAF8CD4340BB61DBA2CC844A40910C39B69ED34340BB61DBA2CC844A40910C39B69ED34340EF3CF19C2D824A40F29881CAF8CD4340EF3CF19C2D824A40
1327	Борисовка	1	9	286	39.950937000000003	40.017933999999997	52.862554000000003	52.832925000000003	0103000020E6100000010000000500000037C7B94DB8F94340AA8251499D6A4A4037C7B94DB8F943405A84622B686E4A4044BE4BA94B0244405A84622B686E4A4044BE4BA94B024440AA8251499D6A4A4037C7B94DB8F94340AA8251499D6A4A40
1472	Большой Хомутец	1	9	286	39.825524000000001	39.903407000000001	52.818297999999999	52.767656000000002	0103000020E6100000010000000500000014083BC5AAE94340024A438D42624A4014083BC5AAE94340EC3026FDBD684A401EFD2FD7A2F34340EC3026FDBD684A401EFD2FD7A2F34340024A438D42624A4014083BC5AAE94340024A438D42624A40
129	имени Ильича	1	9	70	40.543591999999997	40.566974999999999	52.260713000000003	52.252135000000003	0103000020E61000000100000005000000012F336C94454440A796ADF545204A40012F336C944544402F52280B5F214A40265305A3924844402F52280B5F214A40265305A392484440A796ADF545204A40012F336C94454440A796ADF545204A40
29358	Ярлуково	1	9	70	40.330016999999998	40.342359999999999	52.023445000000002	52.010691999999999	0103000020E61000000100000005000000E00F3FFF3D2A4440172AFF5A5E014A40E00F3FFF3D2A44409B20EA3E00034A40B2BAD573D22B44409B20EA3E00034A40B2BAD573D22B4440172AFF5A5E014A40E00F3FFF3D2A4440172AFF5A5E014A40
54765	Чалмык-Никольское	1	9	70	40.565556000000001	40.604560999999997	52.059646000000001	52.031613	0103000020E610000001000000050000003E07962364484440719010E50B044A403E079623644844402AABE97AA2074A40F1B73D41624D44402AABE97AA2074A40F1B73D41624D4440719010E50B044A403E07962364484440719010E50B044A40
1131	Хворостянка	1	9	70	40.216344999999997	40.256346999999998	52.365315000000002	52.313433000000003	0103000020E6100000010000000500000099D36531B11B44405C3E92921E284A4099D36531B11B44407FDE54A4C22E4A40BFB67EFACF2044407FDE54A4C22E4A40BFB67EFACF2044405C3E92921E284A4099D36531B11B44405C3E92921E284A40
351	Тихвинка	1	9	70	40.329577	40.344982999999999	52.184838999999997	52.167043999999997	0103000020E61000000100000005000000C44142942F2A44401B7FA2B261154A40C44142942F2A44403E03EACDA8174A4086562767282C44403E03EACDA8174A4086562767282C44401B7FA2B261154A40C44142942F2A44401B7FA2B261154A40
32209	Талицкий Чамлык	1	9	70	40.518295000000002	40.569265999999999	52.055714000000002	52.024991	0103000020E610000001000000050000001557957D57424440E0D8B3E732034A401557957D57424440F5F6E7A221074A40C45C52B5DD484440F5F6E7A221074A40C45C52B5DD484440E0D8B3E732034A401557957D57424440E0D8B3E732034A40
494	Средняя Матренка	1	9	70	40.181319000000002	40.209516999999998	52.119314000000003	52.095413999999998	0103000020E610000001000000050000005C920376351744404FCAA486360C4A405C920376351744403CFA5FAE450F4A405F7AFB73D11A44403CFA5FAE450F4A405F7AFB73D11A44404FCAA486360C4A405C920376351744404FCAA486360C4A40
617	Салтычки	1	9	70	40.156813	40.174303000000002	52.293080000000003	52.274954000000001	0103000020E61000000100000005000000384BC97212144440C3F352B131234A40384BC972121444404C8E3BA583254A401F4C8A8F4F1644404C8E3BA583254A401F4C8A8F4F164440C3F352B131234A40384BC97212144440C3F352B131234A40
32190	Ровенка	1	9	70	40.501299000000003	40.533594000000001	51.964036	51.940857000000001	0103000020E610000001000000050000003E42CD902A404440399B8E006EF849403E42CD902A40444055151A8865FB4940C1ABE5CE4C44444055151A8865FB4940C1ABE5CE4C444440399B8E006EF849403E42CD902A404440399B8E006EF84940
648	Пушкино	1	9	70	40.353876999999997	40.390518999999998	52.346631000000002	52.322879999999998	0103000020E610000001000000050000003EE76ED74B2D44402844C02154294A403EE76ED74B2D4440D06394675E2C4A40BABBCE86FC314440D06394675E2C4A40BABBCE86FC3144402844C02154294A403EE76ED74B2D44402844C02154294A40
54737	Плавица	1	9	70	40.340688999999998	40.341470999999999	52.240374000000003	52.239033999999997	0103000020E61000000100000005000000B08D78B29B2B4440E75086AA981E4A40B08D78B29B2B444084674293C41E4A4026C45C52B52B444084674293C41E4A4026C45C52B52B4440E75086AA981E4A40B08D78B29B2B4440E75086AA981E4A40
32384	Петровский	1	9	70	40.639297999999997	40.668591999999997	52.246108999999997	52.238179000000002	0103000020E61000000100000005000000F8325184D451444008CC43A67C1E4A40F8325184D45144402920ED7F801F4A40012F336C945544402920ED7F801F4A40012F336C9455444008CC43A67C1E4A40F8325184D451444008CC43A67C1E4A40
32146	Паршиновка	1	9	70	40.503625999999997	40.541175000000003	52.008994999999999	51.977857	0103000020E6100000010000000500000028B517D17640444014950D6B2AFD494028B517D176404440EC6987BF26014A40D734EF3845454440EC6987BF26014A40D734EF384545444014950D6B2AFD494028B517D17640444014950D6B2AFD4940
85	Павловка	1	9	70	40.450194000000003	40.465716999999998	52.233817000000002	52.222662999999997	0103000020E610000001000000050000007F6DFDF49F394440BE839F38801C4A407F6DFDF49F394440DA1F28B7ED1D4A407A185A9D9C3B4440DA1F28B7ED1D4A407A185A9D9C3B4440BE839F38801C4A407F6DFDF49F394440BE839F38801C4A40
900	Отскочное	1	9	70	40.190994000000003	40.208959999999998	52.195372999999996	52.154929000000003	0103000020E61000000100000005000000BADDCB7D72184440DB19A6B6D4134A40BADDCB7D72184440BDC282FB01194A4009168733BF1A4440BDC282FB01194A4009168733BF1A4440DB19A6B6D4134A40BADDCB7D72184440DB19A6B6D4134A40
1014	Ольховка	1	9	70	40.088073999999999	40.108547000000002	52.222375999999997	52.185546000000002	0103000020E610000001000000050000005FD04202460B4440AAF3A8F8BF174A405FD04202460B444028B517D1761C4A401A8A3BDEE40D444028B517D1761C4A401A8A3BDEE40D4440AAF3A8F8BF174A405FD04202460B4440AAF3A8F8BF174A40
225	Новочеркутино	1	9	70	40.387348000000003	40.406427999999998	52.31879	52.299011999999998	0103000020E61000000100000005000000E415889E94314440478E740646264A40E415889E943144405B25581CCE284A40DF162CD5053444405B25581CCE284A40DF162CD505344440478E740646264A40E415889E94314440478E740646264A40
32465	Новопетровка	1	9	70	40.633674999999997	40.657876000000002	52.204397999999998	52.192210000000003	0103000020E610000001000000050000007AA52C431C5144406AFB57569A184A407AA52C431C51444014AFB2B6291A4A406269E0473554444014AFB2B6291A4A406269E047355444406AFB57569A184A407AA52C431C5144406AFB57569A184A40
32435	Николаевка	1	9	70	40.588957000000001	40.607408	52.251198000000002	52.235393999999999	0103000020E6100000010000000500000009E066F1624B44405AD6FD63211E4A4009E066F1624B44400A698D4127204A4015AA9B8BBF4D44400A698D4127204A4015AA9B8BBF4D44405AD6FD63211E4A4009E066F1624B44405AD6FD63211E4A40
974	Нижняя Матренка	1	9	70	40.066558999999998	40.156975000000003	52.270302999999998	52.243335000000002	0103000020E6100000010000000500000092205C0185084440707CED99251F4A4092205C01850844405E81E84999224A4012A5BDC1171444405E81E84999224A4012A5BDC117144440707CED99251F4A4092205C0185084440707CED99251F4A40
32075	Матвеевка	1	9	70	40.277664000000001	40.302664	51.979616	51.970229000000003	0103000020E6100000010000000500000066A3737E8A234440BE50C07630FC494066A3737E8A234440B5519D0E64FD494099D6A6B1BD264440B5519D0E64FD494099D6A6B1BD264440BE50C07630FC494066A3737E8A234440BE50C07630FC4940
32306	Мазейка	1	9	70	40.394911999999998	40.427880000000002	52.091279999999998	52.084074999999999	0103000020E610000001000000050000002366F6798C324440A2B437F8C20A4A402366F6798C324440B2632310AF0B4A40664E97C5C4364440B2632310AF0B4A40664E97C5C4364440A2B437F8C20A4A402366F6798C324440A2B437F8C20A4A40
32052	Лебедянка	1	9	70	40.328651999999998	40.344723000000002	52.01088	51.994656999999997	0103000020E61000000100000005000000EBE1CB44112A444065DEAAEB50FF4940EBE1CB44112A44401A170E8464014A40EA961DE21F2C44401A170E8464014A40EA961DE21F2C444065DEAAEB50FF4940EBE1CB44112A444065DEAAEB50FF4940
54754	Кооператор	1	9	70	40.612186999999999	40.636442000000002	52.169922	52.162404000000002	0103000020E61000000100000005000000A704C4245C4E4440AB5E7EA7C9144A40A704C4245C4E44407A6F0C01C0154A4082E673EE765144407A6F0C01C0154A4082E673EE76514440AB5E7EA7C9144A40A704C4245C4E4440AB5E7EA7C9144A40
32358	Заря	1	9	70	40.372301	40.380232999999997	52.358485000000002	52.345188999999998	0103000020E6100000010000000500000051A2258FA72F44402FF834272F2C4A4051A2258FA72F4440A48D23D6E22D4A4013EE9579AB304440A48D23D6E22D4A4013EE9579AB3044402FF834272F2C4A4051A2258FA72F44402FF834272F2C4A40
865	Дурово	1	9	70	40.205969000000003	40.233654999999999	52.230440999999999	52.202934999999997	0103000020E61000000100000005000000B37E33315D1A44405C1B2AC6F9194A40B37E33315D1A44402A5437177F1D4A4000C63368E81D44402A5437177F1D4A4000C63368E81D44405C1B2AC6F9194A40B37E33315D1A44405C1B2AC6F9194A40
1098	Дубовое	1	9	70	40.297831000000002	40.322921000000001	52.386437999999998	52.367657999999999	0103000020E61000000100000005000000145E82531F2644406F0ED76A0F2F4A40145E82531F26444040F7E5CC76314A408718AF795529444040F7E5CC76314A408718AF79552944406F0ED76A0F2F4A40145E82531F2644406F0ED76A0F2F4A40
31620	Добринка	1	9	70	40.421125000000004	40.503813999999998	52.193783000000003	52.149121000000001	0103000020E6100000010000000500000096438B6CE7354440CB129D6516134A4096438B6CE7354440A9C29FE1CD184A402BA226FA7C404440A9C29FE1CD184A402BA226FA7C404440CB129D6516134A4096438B6CE7354440CB129D6516134A40
31927	Демшинка	1	9	70	40.310218999999996	40.335901	52.126601999999998	52.101975000000003	0103000020E6100000010000000500000085CC9541B52744403B014D840D0D4A4085CC9541B5274440D9CD8C7E34104A40CBD8D0CDFE2A4440D9CD8C7E34104A40CBD8D0CDFE2A44403B014D840D0D4A4085CC9541B52744403B014D840D0D4A40
18032	Воскресеновка	1	9	70	40.504703999999997	40.516840000000002	52.120773999999997	52.109741	0103000020E61000000100000005000000871403249A404440E2033BFE0B0E4A40871403249A404440821ABE85750F4A40E0A128D027424440821ABE85750F4A40E0A128D027424440E2033BFE0B0E4A40871403249A404440E2033BFE0B0E4A40
31949	Верхняя Матренка	1	9	70	40.162714999999999	40.202475	52.070653	52.039158999999998	0103000020E61000000100000005000000C9C859D8D31444400A2C802903054A40C9C859D8D3144440A12E52280B094A40F9A067B3EA194440A12E52280B094A40F9A067B3EA1944400A2C802903054A40C9C859D8D31444400A2C802903054A40
400	Большая Плавица	1	9	70	40.331805000000003	40.361234000000003	52.227181000000002	52.184545999999997	0103000020E610000001000000050000001CD31396782A4440C64D0D349F174A401CD31396782A4440E4A25A44141D4A40051A6CEA3C2E4440E4A25A44141D4A40051A6CEA3C2E4440C64D0D349F174A401CD31396782A4440C64D0D349F174A40
725	Богородицкое	1	9	70	40.332425000000001	40.366928999999999	52.293591999999997	52.234098000000003	0103000020E61000000100000005000000B8AF03E78C2A44408E075BECF61D4A40B8AF03E78C2A4440012F336C94254A401C7A8B87F72E4440012F336C94254A401C7A8B87F72E44408E075BECF61D4A40B8AF03E78C2A44408E075BECF61D4A40
32000	Березнеговатка	1	9	70	40.306994000000003	40.342171999999998	52.081851	52.040455000000001	0103000020E61000000100000005000000BC0853944B274440D7FA22A12D054A40BC0853944B2744408C12F4177A0A4A40AFCDC64ACC2B44408C12F4177A0A4A40AFCDC64ACC2B4440D7FA22A12D054A40BC0853944B274440D7FA22A12D054A40
269	Александровка	1	9	70	40.189520999999999	40.484132000000002	52.311633	52.126879000000002	0103000020E61000000100000005000000DE736039421844404CC631923D104A40DE736039421844405CAD1397E3274A403A799109F83D44405CAD1397E3274A403A799109F83D44404CC631923D104A40DE736039421844404CC631923D104A40
31063	Ярославы	1	9	1695	38.855629999999998	38.882724000000003	53.294598999999998	53.274686000000003	0103000020E61000000100000005000000FDBCA948856D4340A4552DE928A34A40FDBCA948856D43409737876BB5A54A4079B29B19FD7043409737876BB5A54A4079B29B19FD704340A4552DE928A34A40FDBCA948856D4340A4552DE928A34A40
31596	Ягодное	1	9	1695	39.294269	39.309683999999997	53.345511000000002	53.333838	0103000020E61000000100000005000000029D499BAAA54340BE141E34BBAA4A40029D499BAAA5434042B456B439AC4A40170CAEB9A3A7434042B456B439AC4A40170CAEB9A3A74340BE141E34BBAA4A40029D499BAAA54340BE141E34BBAA4A40
31556	Хрущево-Подлесное	1	9	1695	38.981969999999997	39.014111	53.142076000000003	53.119599999999998	0103000020E6100000010000000500000099D36531B17D4340014D840D4F8F4A4099D36531B17D4340F4C5DE8B2F924A40C6C1A563CE814340F4C5DE8B2F924A40C6C1A563CE814340014D840D4F8F4A4099D36531B17D4340014D840D4F8F4A40
31476	Требунки	1	9	1695	39.118433000000003	39.136426	53.323647000000001	53.289485999999997	0103000020E6100000010000000500000033E202D0288F43402E5393E00DA54A4033E202D0288F43406939D0436DA94A407C293C68769143406939D0436DA94A407C293C68769143402E5393E00DA54A4033E202D0288F43402E5393E00DA54A40
31462	Теплое	1	9	1695	38.860157999999998	38.916015000000002	53.231251999999998	53.209378999999998	0103000020E6100000010000000500000046B247A8196E43400EBC5AEECC9A4A4046B247A8196E43403A9160AA999D4A409ED2C1FA3F7543403A9160AA999D4A409ED2C1FA3F7543400EBC5AEECC9A4A4046B247A8196E43400EBC5AEECC9A4A40
31375	Телепнево	1	9	1695	38.880001999999998	38.914622999999999	53.128494000000003	53.109968000000002	0103000020E610000001000000050000001135D1E7A3704340A3CD716E138E4A401135D1E7A3704340BADDCB7D72904A40AF95D05D12754340BADDCB7D72904A40AF95D05D12754340A3CD716E138E4A401135D1E7A3704340A3CD716E138E4A40
31357	Спешнево-Ивановское	1	9	1695	38.999433000000003	39.010939999999998	53.262842999999997	53.257441	0103000020E6100000010000000500000087C5A86BED7F434024D3A1D3F3A04A4087C5A86BED7F4340C37DE4D6A4A14A40EF1B5F7B66814340C37DE4D6A4A14A40EF1B5F7B6681434024D3A1D3F3A04A4087C5A86BED7F434024D3A1D3F3A04A40
54761	Политово	1	9	1695	38.955010999999999	38.974406000000002	53.350149999999999	53.336129	0103000020E61000000100000005000000FE28EACC3D7A43405C1E6B4606AB4A40FE28EACC3D7A4340E25817B7D1AC4A405A83F755B97C4340E25817B7D1AC4A405A83F755B97C43405C1E6B4606AB4A40FE28EACC3D7A43405C1E6B4606AB4A40
31266	Полибино	1	9	1695	38.974172000000003	38.995578999999999	53.517426	53.497836999999997	0103000020E61000000100000005000000E75608ABB17C43408FDE701FB9BF4A40E75608ABB17C4340D00CE2033BC24A40CDCAF6216F7F4340D00CE2033BC24A40CDCAF6216F7F43408FDE701FB9BF4A40E75608ABB17C43408FDE701FB9BF4A40
31251	Плахово	1	9	1695	38.680711000000002	38.698945999999999	53.264350999999998	53.248567000000001	0103000020E610000001000000050000008483BD8921574340B3EE1F0BD19F4A408483BD89215743401BD5E940D6A14A40C3D50110775943401BD5E940D6A14A40C3D5011077594340B3EE1F0BD19F4A408483BD8921574340B3EE1F0BD19F4A40
31171	Перехваль	1	9	1695	39.068863999999998	39.123167000000002	53.151035999999998	53.125684	0103000020E6100000010000000500000095EF1989D0884340B3D0CE6916904A4095EF1989D08843406342CC2555934A402579AEEFC38F43406342CC2555934A402579AEEFC38F4340B3D0CE6916904A4095EF1989D0884340B3D0CE6916904A40
30972	Новоникольское	1	9	1695	39.136102000000001	39.174442999999997	53.209933999999997	53.195436000000001	0103000020E61000000100000005000000C97553CA6B914340043BFE0B04994A40C97553CA6B914340C328081EDF9A4A401002F22554964340C328081EDF9A4A401002F22554964340043BFE0B04994A40C97553CA6B914340043BFE0B04994A40
30915	Кудрявщино	1	9	1695	38.987251999999998	39.023014000000003	53.394219	53.383124000000002	0103000020E610000001000000050000008E7406465E7E434007280D350AB14A408E7406465E7E43401D3BA8C475B24A40D2AC6C1FF28243401D3BA8C475B24A40D2AC6C1FF282434007280D350AB14A408E7406465E7E434007280D350AB14A40
22514	Красный Луч	1	9	1695	39.146352	39.160150000000002	53.196482000000003	53.190385999999997	0103000020E6100000010000000500000023DA8EA9BB924340E1CE85915E984A4023DA8EA9BB92434058207A5226994A402A3A92CB7F94434058207A5226994A402A3A92CB7F944340E1CE85915E984A4023DA8EA9BB924340E1CE85915E984A40
30879	Ивановка	1	9	1695	38.784824999999998	38.808954	53.474359	53.453885999999997	0103000020E61000000100000005000000A60A4625756443405E0EBBEF18BA4A40A60A46257564434019C8B3CBB7BC4A40F4FBFECD8B67434019C8B3CBB7BC4A40F4FBFECD8B6743405E0EBBEF18BA4A40A60A4625756443405E0EBBEF18BA4A40
30771	Долгое	1	9	1695	39.086030000000001	39.130325999999997	53.470891000000002	53.444195999999998	0103000020E61000000100000005000000C93CF207038B4340CB811E6ADBB84A40C93CF207038B4340897D022846BC4A40C4E8B985AE904340897D022846BC4A40C4E8B985AE904340CB811E6ADBB84A40C93CF207038B4340CB811E6ADBB84A40
30768	Воскресенское	1	9	1695	38.703842000000002	38.738562000000002	53.207684999999998	53.192214999999997	0103000020E610000001000000050000008FC6A17E175A43407B6649809A984A408FC6A17E175A4340546F0D6C959A4A40C0081A33895E4340546F0D6C959A4A40C0081A33895E43407B6649809A984A408FC6A17E175A43407B6649809A984A40
30705	Бигильдино	1	9	1695	39.128861999999998	39.164524999999998	53.363332999999997	53.326912	0103000020E610000001000000050000003CD9CD8C7E904340C1559E40D8A94A403CD9CD8C7E9043405E471CB281AE4A40EC2FBB270F9543405E471CB281AE4A40EC2FBB270F954340C1559E40D8A94A403CD9CD8C7E904340C1559E40D8A94A40
30638	Березовка	1	9	1695	38.866481999999998	38.899881000000001	53.446936999999998	53.422051000000003	0103000020E610000001000000050000004D49D6E1E86E43403F1F65C405B64A404D49D6E1E86E4340A92F4B3B35B94A4059A5F44C2F734340A92F4B3B35B94A4059A5F44C2F7343403F1F65C405B64A404D49D6E1E86E43403F1F65C405B64A40
30591	Барятино	1	9	1695	38.745075	38.766643000000002	53.356034999999999	53.330488000000003	0103000020E610000001000000050000009A081B9E5E5F434038DC476E4DAA4A409A081B9E5E5F43409D9D0C8E92AD4A408A5A9A5B216243409D9D0C8E92AD4A408A5A9A5B2162434038DC476E4DAA4A409A081B9E5E5F434038DC476E4DAA4A40
30545	Баловнево	1	9	1695	39.025924000000003	39.056063000000002	53.219683000000003	53.201990000000002	0103000020E610000001000000050000003C17467A518343403D0FEECEDA994A403C17467A518343405C3E92921E9C4A4001C287122D8743405C3E92921E9C4A4001C287122D8743403D0FEECEDA994A403C17467A518343403D0FEECEDA994A40
30491	Авдулово	1	9	1695	38.622076999999997	38.636800999999998	53.305011999999998	53.293866999999999	0103000020E61000000100000005000000014C1938A04F4340D32F116F9DA54A40014C1938A04F43409B711AA20AA74A40B187F6B1825143409B711AA20AA74A40B187F6B182514340D32F116F9DA54A40014C1938A04F4340D32F116F9DA54A40
54787	совхоза Красная Дубрава	1	9	1823	39.437344000000003	40.234239000000002	52.721736999999997	52.280304999999998	0103000020E61000000100000005000000098D60E3FAB74340E0F3C308E1234A40098D60E3FAB7434015A8C5E0615C4A405039268BFB1D444015A8C5E0615C4A405039268BFB1D4440E0F3C308E1234A40098D60E3FAB74340E0F3C308E1234A40
29094	Ямань	1	9	1823	39.576852000000002	39.607394999999997	52.392840999999997	52.381512999999998	0103000020E61000000100000005000000EC504D49D6C94340DAFF006BD5304A40EC504D49D6C9434093C3279D48324A4080608E1EBFCD434093C3279D48324A4080608E1EBFCD4340DAFF006BD5304A40EC504D49D6C94340DAFF006BD5304A40
29307	Фащевка	1	9	1823	39.688485999999997	39.756298999999999	52.485706999999998	52.441460999999997	0103000020E610000001000000050000007EE02A4F20D84340CFBA46CB81384A407EE02A4F20D843401938A0A52B3E4A40AE7FD767CEE043401938A0A52B3E4A40AE7FD767CEE04340CFBA46CB81384A407EE02A4F20D84340CFBA46CB81384A40
29814	Сошки	1	9	1823	39.601142000000003	39.699812999999999	52.373700999999997	52.339759000000001	0103000020E6100000010000000500000043209738F2CC4340C6C210397D2B4A4043209738F2CC4340C2BD326FD52F4A406728EE7893D94340C2BD326FD52F4A406728EE7893D94340C6C210397D2B4A4043209738F2CC4340C6C210397D2B4A40
29718	Синявка	1	9	1823	39.995054000000003	40.015517000000003	52.438135000000003	52.413922999999997	0103000020E6100000010000000500000083E0F1ED5DFF4340F607CA6DFB344A4083E0F1ED5DFF4340D21DC4CE14384A401AC40776FC014440D21DC4CE14384A401AC40776FC014440F607CA6DFB344A4083E0F1ED5DFF4340F607CA6DFB344A40
29754	Светлая Поляна	1	9	1823	39.899158	39.961123999999998	52.469630000000002	52.425922999999997	0103000020E61000000100000005000000E8F7FD9B17F343409ECE15A584364A40E8F7FD9B17F34340399CF9D51C3C4A404AB3791C06FB4340399CF9D51C3C4A404AB3791C06FB43409ECE15A584364A40E8F7FD9B17F343409ECE15A584364A40
54768	Прибытковский	1	9	1823	39.817357999999999	39.842367000000003	52.426032999999997	52.413401	0103000020E61000000100000005000000DE8FDB2F9FE843401D91EF52EA344A40DE8FDB2F9FE843402502D53F88364A40651D8EAED2EB43402502D53F88364A40651D8EAED2EB43401D91EF52EA344A40DE8FDB2F9FE843401D91EF52EA344A40
29167	Плеханово	1	9	1823	39.823987000000002	39.871777999999999	52.651335000000003	52.618454999999997	0103000020E6100000010000000500000022AAF06778E943401A868F88294F4A4022AAF06778E94340BEDEFDF15E534A40A7AFE76B96EF4340BEDEFDF15E534A40A7AFE76B96EF43401A868F88294F4A4022AAF06778E943401A868F88294F4A40
28981	Петровка	1	9	1823	40.111628000000003	40.134318999999998	52.495303	52.473235000000003	0103000020E61000000100000005000000B1A888D3490E44404A29E8F6923C4A40B1A888D3490E44402B4EB516663F4A409F1D705D311144402B4EB516663F4A409F1D705D311144404A29E8F6923C4A40B1A888D3490E44404A29E8F6923C4A40
54762	Песковатский	1	9	1823	40.017862000000001	40.040903999999998	52.541006000000003	52.523229000000001	0103000020E61000000100000005000000ABEB504D49024440CEA8F92AF9424A40ABEB504D490244404B7842AF3F454A4046239F573C0544404B7842AF3F454A4046239F573C054440CEA8F92AF9424A40ABEB504D49024440CEA8F92AF9424A40
29286	Падворки	1	9	1823	40.006157000000002	40.042780999999998	52.346080999999998	52.321525999999999	0103000020E610000001000000050000001CD2A8C0C9004440276893C327294A401CD2A8C0C90044402C62D8614C2C4A40F1F109D9790544402C62D8614C2C4A40F1F109D979054440276893C327294A401CD2A8C0C9004440276893C327294A40
29602	Кубань	1	9	1823	40.108519999999999	40.136744999999998	52.410818999999996	52.397556000000002	0103000020E61000000100000005000000207BBDFBE30D44400F2A711DE3324A40207BBDFBE30D4440A7C98CB795344A401D7233DC80114440A7C98CB795344A401D7233DC801144400F2A711DE3324A40207BBDFBE30D44400F2A711DE3324A40
29611	Коробовка	1	9	1823	40.042476000000001	40.071725000000001	52.341920999999999	52.311776000000002	0103000020E61000000100000005000000B56E83DA6F054440BFD6A546E8274A40B56E83DA6F05444066683C11C42B4A401EA7E8482E09444066683C11C42B4A401EA7E8482E094440BFD6A546E8274A40B56E83DA6F054440BFD6A546E8274A40
54763	Княжая Байгора	1	9	1823	39.998764000000001	40.069057000000001	52.408670999999998	52.362493999999998	0103000020E610000001000000050000000936AE7FD7FF4340847F1134662E4A400936AE7FD7FF43406CE9D1544F344A40AA471ADCD60844406CE9D1544F344A40AA471ADCD6084440847F1134662E4A400936AE7FD7FF4340847F1134662E4A40
29427	Карамышево	1	9	1823	39.437344000000003	39.534838000000001	52.382623000000002	52.362130999999998	0103000020E61000000100000005000000098D60E3FAB7434013EF004F5A2E4A40098D60E3FAB7434045D95BCAF9304A403B54539275C4434045D95BCAF9304A403B54539275C4434013EF004F5A2E4A40098D60E3FAB7434013EF004F5A2E4A40
54741	Казинка	1	9	1823	39.437344000000003	40.234239000000002	52.721736999999997	52.280304999999998	0103000020E61000000100000005000000098D60E3FAB74340E0F3C308E1234A40098D60E3FAB7434015A8C5E0615C4A405039268BFB1D444015A8C5E0615C4A405039268BFB1D4440E0F3C308E1234A40098D60E3FAB74340E0F3C308E1234A40
29233	Гудаловка	1	9	1823	39.809004000000002	39.831434000000002	52.657895000000003	52.640422999999998	0103000020E61000000100000005000000A62A6D718DE74340984D8061F9514A40A62A6D718DE74340D99942E735544A402864E76D6CEA4340D99942E735544A402864E76D6CEA4340984D8061F9514A40A62A6D718DE74340984D8061F9514A40
54494	Грязи	1	9	1823	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
29149	Головщино	1	9	1823	39.860702000000003	39.909740999999997	52.627437	52.607880000000002	0103000020E6100000010000000500000008CDAE7B2BEE43403DF20703CF4D4A4008CDAE7B2BEE434072A609DB4F504A40486AA16472F4434072A609DB4F504A40486AA16472F443403DF20703CF4D4A4008CDAE7B2BEE43403DF20703CF4D4A40
29409	Верхний Телелюй	1	9	1823	39.855572000000002	39.910243999999999	52.359864999999999	52.324266999999999	0103000020E61000000100000005000000C9AF1F6283ED43400516C09481294A40C9AF1F6283ED4340CEFC6A0E102E4A40ABB019E082F44340CEFC6A0E102E4A40ABB019E082F443400516C09481294A40C9AF1F6283ED43400516C09481294A40
28788	Бутырки	1	9	1823	39.807926000000002	39.885413999999997	52.704323000000002	52.668863000000002	0103000020E6100000010000000500000047CB811E6AE743409240834D9D554A4047CB811E6AE743400A698D41275A4A40D4B5F63E55F143400A698D41275A4A40D4B5F63E55F143409240834D9D554A4047CB811E6AE743409240834D9D554A40
28706	Большой Самовец	1	9	1823	39.928057000000003	39.962561999999998	52.552737	52.518532999999998	0103000020E6100000010000000500000075E95F92CAF64340C972124A5F424A4075E95F92CAF6434003250516C0464A40A92F4B3B35FB434003250516C0464A40A92F4B3B35FB4340C972124A5F424A4075E95F92CAF64340C972124A5F424A40
28995	Аннино	1	9	1823	39.984650999999999	40.068373999999999	52.492550999999999	52.471204999999998	0103000020E61000000100000005000000A27C410B09FE4340185B0872503C4A40A27C410B09FE4340594E42E90B3F4A40C7F2AE7AC0084440594E42E90B3F4A40C7F2AE7AC0084440185B0872503C4A40A27C410B09FE4340185B0872503C4A40
27521	Юрское	1	9	1804	37.85718	37.879098999999997	52.20102	52.184297999999998	0103000020E6100000010000000500000084640113B8ED4240EE5BAD1397174A4084640113B8ED4240C4EBFA05BB194A402079E75086F04240C4EBFA05BB194A402079E75086F04240EE5BAD1397174A4084640113B8ED4240EE5BAD1397174A40
27023	Пикалово	1	9	1804	37.980339000000001	38.012238000000004	52.226441999999999	52.208018000000003	0103000020E6100000010000000500000026FF93BF7BFD42405B7D7555A01A4A4026FF93BF7BFD42406D382C0DFC1C4A405DE2C803910143406D382C0DFC1C4A405DE2C803910143405B7D7555A01A4A4026FF93BF7BFD42405B7D7555A01A4A40
27237	Новопавловка	1	9	1804	37.944290000000002	37.996724	52.009428	52.003307	0103000020E610000001000000050000004DF8A57EDEF84240876C205D6C004A404DF8A57EDEF8424056D5CBEF34014A40B491EBA694FF424056D5CBEF34014A40B491EBA694FF4240876C205D6C004A404DF8A57EDEF84240876C205D6C004A40
26619	Нижнее Большое	1	9	1804	37.897002000000001	37.920358999999998	52.003169	51.989151	0103000020E610000001000000050000002A3927F6D0F2424021E7FD7F9CFE49402A3927F6D0F2424036AE7FD767004A4025CADE52CEF5424036AE7FD767004A4025CADE52CEF5424021E7FD7F9CFE49402A3927F6D0F2424021E7FD7F9CFE4940
27306	Набережное	1	9	1804	38.098655999999998	38.136088999999998	51.999676000000001	51.952615000000002	0103000020E61000000100000005000000EFC682C2A00C4340EB56CF49EFF94940EFC682C2A00C43404D4C1762F5FF4940342C465D6B1143404D4C1762F5FF4940342C465D6B114340EB56CF49EFF94940EFC682C2A00C4340EB56CF49EFF94940
27245	Мишино	1	9	1804	37.846265000000002	37.857934999999998	52.142842999999999	52.136625000000002	0103000020E61000000100000005000000EE5F596952EC4240736891ED7C114A40EE5F596952EC424034BBEEAD48124A40008C67D0D0ED424034BBEEAD48124A40008C67D0D0ED4240736891ED7C114A40EE5F596952EC4240736891ED7C114A40
27340	Княжная	1	9	1804	38.177528000000002	38.194704000000002	51.956206000000002	51.950639000000002	0103000020E61000000100000005000000E90FCD3CB9164340ADA6EB89AEF94940E90FCD3CB9164340971E4DF564FA49404033880FEC184340971E4DF564FA49404033880FEC184340ADA6EB89AEF94940E90FCD3CB9164340ADA6EB89AEF94940
27436	Казаково	1	9	1804	37.934291000000002	37.954979999999999	52.061312999999998	52.054988999999999	0103000020E610000001000000050000003CF9F4D896F74240E3512AE109074A403CF9F4D896F74240EAE8B81AD9074A40C32ADEC83CFA4240EAE8B81AD9074A40C32ADEC83CFA4240E3512AE109074A403CF9F4D896F74240E3512AE109074A40
27420	Ивановка	1	9	1804	38.086691000000002	38.123144000000003	52.040793000000001	52.032615999999997	0103000020E61000000100000005000000C4EDD0B0180B4340C5A9D6C22C044A40C4EDD0B0180B4340EF737CB438054A406D59BE2EC30F4340EF737CB438054A406D59BE2EC30F4340C5A9D6C22C044A40C4EDD0B0180B4340C5A9D6C22C044A40
27083	Захаровка	1	9	1804	37.944369999999999	37.984515999999999	52.111218000000001	52.089376999999999	0103000020E6100000010000000500000069A9BC1DE1F84240DE019EB4700B4A4069A9BC1DE1F84240FF5C34643C0E4A40C231CB9E04FE4240FF5C34643C0E4A40C231CB9E04FE4240DE019EB4700B4A4069A9BC1DE1F84240DE019EB4700B4A40
27051	Замарайка	1	9	1804	37.766423000000003	37.823366999999998	52.079431999999997	52.059890000000003	0103000020E610000001000000050000007CF31B261AE24240C1ADBB79AA074A407CF31B261AE24240C020E9D32A0A4A4085CD001764E94240C020E9D32A0A4A4085CD001764E94240C1ADBB79AA074A407CF31B261AE24240C1ADBB79AA074A40
26975	Гатище	1	9	1804	37.925272	37.978155999999998	52.223452000000002	52.203448999999999	0103000020E61000000100000005000000C7F319506FF64240B3B3E89D0A1A4A40C7F319506FF64240E71C3C139A1C4A406E313F3734FD4240E71C3C139A1C4A406E313F3734FD4240B3B3E89D0A1A4A40C7F319506FF64240B3B3E89D0A1A4A40
26577	Вышнее Большое	1	9	1804	37.833339000000002	37.915562000000001	51.995655999999997	51.948645999999997	0103000020E610000001000000050000009DBD33DAAAEA424098BD6C3B6DF949409DBD33DAAAEA42407808E3A771FF4940EDBAB72231F542407808E3A771FF4940EDBAB72231F5424098BD6C3B6DF949409DBD33DAAAEA424098BD6C3B6DF94940
26897	Воловчик	1	9	1804	37.787802999999997	37.833779	52.030389	52.008839999999999	0103000020E6100000010000000500000068588CBAD6E44240C5724BAB21014A4068588CBAD6E442403E9468C9E3034A40B98B3045B9EA42403E9468C9E3034A40B98B3045B9EA4240C5724BAB21014A4068588CBAD6E44240C5724BAB21014A40
26770	Волово	1	9	1804	37.844881999999998	37.908878000000001	52.042465999999997	52.008679000000001	0103000020E61000000100000005000000527DE71725EC4240BC94BA641C014A40527DE71725EC42409198A0866F054A40E606431D56F442409198A0866F054A40E606431D56F44240BC94BA641C014A40527DE71725EC4240BC94BA641C014A40
26734	Верхнее Чесночное	1	9	1804	37.964753000000002	38.020879999999998	51.930706999999998	51.921447999999998	0103000020E61000000100000005000000E4DBBB067DFB4240787B1002F2F54940E4DBBB067DFB424042942F6821F74940FB912232AC02434042942F6821F74940FB912232AC024340787B1002F2F54940E4DBBB067DFB4240787B1002F2F54940
26667	Васильевка	1	9	1804	38.004513000000003	38.053552000000003	51.985035000000003	51.969974000000001	0103000020E6100000010000000500000014B4C9E19300434033FCA71B28FC494014B4C9E1930043402B357BA015FE49405551BCCADA0643402B357BA015FE49405551BCCADA06434033FCA71B28FC494014B4C9E19300434033FCA71B28FC4940
26547	Большая Ивановка	1	9	1804	37.999132000000003	38.029279000000002	52.152652000000003	52.142980999999999	0103000020E610000001000000050000008C31B08EE3FF424085798F334D124A408C31B08EE3FF4240A2D5C9198A134A40D4BA0D6ABF034340A2D5C9198A134A40D4BA0D6ABF03434085798F334D124A408C31B08EE3FF424085798F334D124A40
27159	Алексеевка	1	9	1804	37.885064	37.916683999999997	52.110460000000003	52.098140999999998	0103000020E61000000100000005000000F86EF3C649F14240C8B260E28F0C4A40F86EF3C649F1424012C2A38D230E4A401B62BCE655F5424012C2A38D230E4A401B62BCE655F54240C8B260E28F0C4A40F86EF3C649F14240C8B260E28F0C4A40
27165	Александровка	1	9	1804	38.029494999999997	38.058942000000002	52.105559999999997	52.094351000000003	0103000020E61000000100000005000000A032FE7DC603434026AC8DB1130C4A40A032FE7DC603434004E275FD820D4A40302E55698B07434004E275FD820D4A40302E55698B07434026AC8DB1130C4A40A032FE7DC603434026AC8DB1130C4A40
54500	п.Маршала Жукова	1	8	\N	34.081434999999999	38.518420999999996	52.444595999999997	50.903858	0103000020E61000000100000005000000F8DF4A766C0A41402E1D739EB1734940F8DF4A766C0A414059F78F85E8384A40A1478C9E5B42434059F78F85E8384A40A1478C9E5B4243402E1D739EB1734940F8DF4A766C0A41402E1D739EB1734940
54481	Юбилейный	1	8	\N	36.241030000000002	36.285325999999998	51.782364999999999	51.764904999999999	0103000020E610000001000000050000006DAD2F12DA1E424000C63368E8E149406DAD2F12DA1E42407C444C8924E449406859F78F852442407C444C8924E449406859F78F8524424000C63368E8E149406DAD2F12DA1E424000C63368E8E14940
1787	Щигры	1	8	\N	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
54508	Щетинка	1	8	\N	36.219560000000001	36.237786999999997	51.790253999999997	51.782086	0103000020E6100000010000000500000040C1C58A1A1C42406954E0641BE4494040C1C58A1A1C42403FC4060B27E54940FC34EECD6F1E42403FC4060B27E54940FC34EECD6F1E42406954E0641BE4494040C1C58A1A1C42406954E0641BE44940
9704	Цветово 1-е	1	8	\N	36.088639999999998	36.117511999999998	51.639518000000002	51.621633000000003	0103000020E61000000100000005000000088F368E580B4240A48E8EAB91CF4940088F368E580B4240079ACFB9DBD149409B711AA20A0F4240079ACFB9DBD149409B711AA20A0F4240A48E8EAB91CF4940088F368E580B4240A48E8EAB91CF4940
54478	Суджа	1	8	\N	35.227856000000003	35.291635999999997	51.209104000000004	51.185765000000004	0103000020E610000001000000050000004419AA622A9D4140E8DEC325C79749404419AA622A9D41403DBB7CEBC39A49400A2B155454A541403DBB7CEBC39A49400A2B155454A54140E8DEC325C79749404419AA622A9D4140E8DEC325C7974940
54502	Рыльск	1	8	\N	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
54463	Рыльск	1	8	\N	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
54486	Обоянь	1	8	\N	36.222462	36.314188999999999	51.225825	51.197563000000002	0103000020E61000000100000005000000274D83A2791C424028F38FBE49994940274D83A2791C424042CF66D5E79C4940A8E15B583728424042CF66D5E79C4940A8E15B583728424028F38FBE49994940274D83A2791C424028F38FBE49994940
54484	Льгов	1	8	\N	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
24756	Курчатов	1	8	\N	35.640991	35.664239999999999	51.664451	51.655343999999999	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
4134	Курск	1	8	\N	36.060343000000003	36.303086	51.817112999999999	51.617047999999997	0103000020E6100000010000000500000072C5C551B9074240F607CA6DFBCE494072C5C551B90742407711A62897E849400FF0A485CB2642407711A62897E849400FF0A485CB264240F607CA6DFBCE494072C5C551B9074240F607CA6DFBCE4940
54503	Курск	1	8	\N	36.060343000000003	36.303086	51.817112999999999	51.617047999999997	0103000020E6100000010000000500000072C5C551B9074240F607CA6DFBCE494072C5C551B90742407711A62897E849400FF0A485CB2642407711A62897E849400FF0A485CB264240F607CA6DFBCE494072C5C551B9074240F607CA6DFBCE4940
54489	Железногорск	1	8	\N	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
4934	Железногорск	1	8	\N	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
54549	Духовец	1	8	\N	36.054737000000003	36.072254000000001	51.642139	51.639505999999997	0103000020E61000000100000005000000CA703C9F0107424042CC2555DBD14940CA703C9F010742403A3E5A9C31D24940AA807B9E3F0942403A3E5A9C31D24940AA807B9E3F09424042CC2555DBD14940CA703C9F0107424042CC2555DBD14940
54551	Гремячка	1	8	\N	36.077491999999999	36.105510000000002	51.765067000000002	51.749039000000003	0103000020E61000000100000005000000CFD90242EB094240DB368C82E0DF4940CFD90242EB094240DA1F28B7EDE1494053B3075A810D4240DA1F28B7EDE1494053B3075A810D4240DB368C82E0DF4940CFD90242EB094240DB368C82E0DF4940
21688	Голубицкое	1	8	\N	36.172497	36.207315999999999	51.678443000000001	51.660958999999998	0103000020E610000001000000050000003DD4B66114164240997FF44D9AD449403DD4B661141642409E996038D7D6494001F8A754891A42409E996038D7D6494001F8A754891A4240997FF44D9AD449403DD4B66114164240997FF44D9AD44940
54499	1-я Моква	1	8	\N	36.078992	36.104827	51.730885999999998	51.7121	0103000020E61000000100000005000000A452EC681C0A4240A5BDC11726DB4940A452EC681C0A4240588D25AC8DDD4940705E9CF86A0D4240588D25AC8DDD4940705E9CF86A0D4240A5BDC11726DB4940A452EC681C0A4240A5BDC11726DB4940
4335	Хитровка	1	8	525	36.639594000000002	36.660552000000003	51.870283999999998	51.853026	0103000020E61000000100000005000000E25B5837DE514240A051BAF42FED4940E25B5837DE514240B41D537765EF494059A7CAF78C544240B41D537765EF494059A7CAF78C544240A051BAF42FED4940E25B5837DE514240A051BAF42FED4940
3331	Сидоровка	1	8	525	36.602808000000003	36.621448999999998	51.943832999999998	51.929985000000002	0103000020E6100000010000000500000033E202D0284D4240A2629CBF09F7494033E202D0284D42405AF10D85CFF84940E2900DA48B4F42405AF10D85CFF84940E2900DA48B4F4240A2629CBF09F7494033E202D0284D4240A2629CBF09F74940
3517	Сергеевка	1	8	525	36.999073000000003	37.021127	51.833913000000003	51.803342999999998	0103000020E6100000010000000500000087A8C29FE17F42403A3C84F1D3E6494087A8C29FE17F4240C95A43A9BDEA494003081F4AB4824240C95A43A9BDEA494003081F4AB48242403A3C84F1D3E6494087A8C29FE17F42403A3C84F1D3E64940
4244	Семеновка 1-я	1	8	525	36.716059000000001	36.752692000000003	51.889476000000002	51.877412999999997	0103000020E61000000100000005000000D48041D2A75B4240E90AB6114FF04940D48041D2A75B4240D8497D59DAF14940FDFA213658604240D8497D59DAF14940FDFA213658604240E90AB6114FF04940D48041D2A75B4240E90AB6114FF04940
54514	Пригородняя	1	8	525	36.886477999999997	36.898453000000003	51.858071000000002	51.843178000000002	0103000020E61000000100000005000000CE4F711C78714240755AB741EDEB4940CE4F711C78714240B1524145D5ED49401EFF058200734240B1524145D5ED49401EFF058200734240755AB741EDEB4940CE4F711C78714240755AB741EDEB4940
3722	Пожидаевка	1	8	525	36.693007999999999	36.712815999999997	51.999116000000001	51.985861999999997	0103000020E61000000100000005000000E5EE737CB4584240402FDCB930FE4940E5EE737CB458424086747808E3FF49406308008E3D5B424086747808E3FF49406308008E3D5B4240402FDCB930FE4940E5EE737CB4584240402FDCB930FE4940
4052	Плодовый	1	8	525	36.835597999999997	36.851013000000002	51.797322000000001	51.784939000000001	0103000020E610000001000000050000002F4D11E0F46A42406F2D93E178E449402F4D11E0F46A4240CF30B5A50EE6494045BC75FEED6C4240CF30B5A50EE6494045BC75FEED6C42406F2D93E178E449402F4D11E0F46A42406F2D93E178E44940
3298	Новосергиевка	1	8	525	36.605466999999997	36.628670999999997	51.802708000000003	51.797578999999999	0103000020E6100000010000000500000053E751F17F4D4240FA7C941117E6494053E751F17F4D4240691EC022BFE64940C878944A78504240691EC022BFE64940C878944A78504240FA7C941117E6494053E751F17F4D4240FA7C941117E64940
3188	Нижний Теребуж	1	8	525	36.6937	36.712204999999997	52.054025000000003	52.037790999999999	0103000020E610000001000000050000001B9E5E29CB584240A48AE255D6044A401B9E5E29CB5842404D158C4AEA064A401A868F88295B42404D158C4AEA064A401A868F88295B4240A48AE255D6044A401B9E5E29CB584240A48AE255D6044A40
4437	Куликовка	1	8	525	36.935445999999999	36.962476000000002	51.819701999999999	51.8063	0103000020E610000001000000050000004696CCB1BC774240E561A1D634E749404696CCB1BC7742409F3BC1FEEBE84940AB97DF69327B42409F3BC1FEEBE84940AB97DF69327B4240E561A1D634E749404696CCB1BC774240E561A1D634E74940
3914	Крутое	1	8	525	36.786918	36.815485000000002	51.858344000000002	51.832332000000001	0103000020E610000001000000050000001E51A1BAB964424007B5DFDA89EA49401E51A1BAB9644240E25B5837DEED494075B0FECF61684240E25B5837DEED494075B0FECF6168424007B5DFDA89EA49401E51A1BAB964424007B5DFDA89EA4940
3846	Кривцовка	1	8	525	36.821987999999997	36.850968000000002	51.952137	51.938580999999999	0103000020E610000001000000050000002BDA1CE736694240D0D2156C23F849402BDA1CE736694240E1270EA0DFF94940A5F8F884EC6C4240E1270EA0DFF94940A5F8F884EC6C4240D0D2156C23F849402BDA1CE736694240D0D2156C23F84940
3819	Косоржа	1	8	525	36.737941999999997	36.787878999999997	52.106406	52.085044000000003	0103000020E61000000100000005000000232C2AE2745E42404B5CC7B8E20A4A40232C2AE2745E4240910C39B69E0D4A40431A1538D9644240910C39B69E0D4A40431A1538D96442404B5CC7B8E20A4A40232C2AE2745E42404B5CC7B8E20A4A40
4499	Козловка	1	8	525	36.877495000000003	36.892111	51.862059000000002	51.841030000000003	0103000020E61000000100000005000000A7B393C1517042403A7AFCDEA6EB4940A7B393C1517042407A1C06F357EE494070B378B1307242407A1C06F357EE494070B378B1307242403A7AFCDEA6EB4940A7B393C1517042403A7AFCDEA6EB4940
3756	Касиновка	1	8	525	36.794975999999998	36.830001000000003	52.040522000000003	52.024248999999998	0103000020E610000001000000050000006D8D08C6C1654240F8FA5A971A034A406D8D08C6C16542405F622CD32F054A40DB5207793D6A42405F622CD32F054A40DB5207793D6A4240F8FA5A971A034A406D8D08C6C1654240F8FA5A971A034A40
54513	Зеленая Роща	1	8	525	36.752907999999998	36.774737000000002	51.884706999999999	51.868170999999997	0103000020E61000000100000005000000C972124A5F604240F52A323A20EF4940C972124A5F60424069C537143EF149402600FF942A63424069C537143EF149402600FF942A634240F52A323A20EF4940C972124A5F604240F52A323A20EF4940
3655	Защитное	1	8	525	36.725634999999997	36.756816000000001	51.710397999999998	51.693848000000003	0103000020E610000001000000050000009EEA909BE15C42409032E202D0D849409EEA909BE15C424068925852EEDA4940768BC058DF60424068925852EEDA4940768BC058DF6042409032E202D0D849409EEA909BE15C42409032E202D0D84940
4020	Длинная	1	8	525	36.910561999999999	36.974243999999999	52.076841999999999	52.058638000000002	0103000020E610000001000000050000007C7DAD4B8D744240C426327381074A407C7DAD4B8D744240C87A6AF5D5094A4080290307B47C4240C87A6AF5D5094A4080290307B47C4240C426327381074A407C7DAD4B8D744240C426327381074A40
3616	Вязовое	1	8	525	36.933793000000001	36.989345	51.917721	51.883940000000003	0103000020E61000000100000005000000EB1D6E878677424029D027F224F14940EB1D6E87867742401CEDB8E177F5494006BB61DBA27E42401CEDB8E177F5494006BB61DBA27E424029D027F224F14940EB1D6E878677424029D027F224F14940
3444	Вишневка	1	8	525	36.971477	36.988239999999998	51.849626999999998	51.837496999999999	0103000020E6100000010000000500000079E8BB5B597C4240C2BF081A33EB494079E8BB5B597C42403866D993C0EC4940AD4CF8A57E7E42403866D993C0EC4940AD4CF8A57E7E4240C2BF081A33EB494079E8BB5B597C4240C2BF081A33EB4940
4171	Верхняя Гремячка	1	8	525	36.726937999999997	36.761882	51.921570000000003	51.905076000000001	0103000020E610000001000000050000001D1CEC4D0C5D42407F32C687D9F349401D1CEC4D0C5D4240C47C7901F6F549409EB4705985614240C47C7901F6F549409EB47059856142407F32C687D9F349401D1CEC4D0C5D42407F32C687D9F34940
3407	Большой Змеинец	1	8	525	36.834583000000002	36.884923999999998	52.094217999999998	52.082332000000001	0103000020E610000001000000050000001766A19DD36A424007B5DFDA890A4A401766A19DD36A4240E658DE550F0C4A4006B98B3045714240E658DE550F0C4A4006B98B304571424007B5DFDA890A4A401766A19DD36A424007B5DFDA890A4A40
3229	Басово	1	8	525	36.644238999999999	36.685093999999999	51.775734	51.759909999999998	0103000020E6100000010000000500000064E76D6C76524240A1F31ABB44E1494064E76D6C76524240983270404BE34940C9570229B1574240983270404BE34940C9570229B1574240A1F31ABB44E1494064E76D6C76524240A1F31ABB44E14940
3549	Апухтина	1	8	525	36.915430999999998	36.957076999999998	51.981934000000003	51.973719000000003	0103000020E610000001000000050000004E5FCFD72C754240363FFED2A2FC49404E5FCFD72C7542404D6A6803B0FD49407C60C77F817A42404D6A6803B0FD49407C60C77F817A4240363FFED2A2FC49404E5FCFD72C754240363FFED2A2FC4940
54546	2-е Мелехино	1	8	525	36.697634999999998	36.742109999999997	51.812136000000002	51.782532000000003	0103000020E61000000100000005000000C1C58A1A4C594240680932022AE44940C1C58A1A4C594240BFF38B12F4E749406C04E275FD5E4240BFF38B12F4E749406C04E275FD5E4240680932022AE44940C1C58A1A4C594240680932022AE44940
2637	Юдинка	1	8	304	37.088994999999997	37.125124999999997	52.033242000000001	52.002470000000002	0103000020E61000000100000005000000F6402B30648B42404E9CDCEF50004A40F6402B30648B4240446D1B4641044A40BC74931804904240446D1B4641044A40BC749318049042404E9CDCEF50004A40F6402B30648B42404E9CDCEF50004A40
1360	Черемисиново	1	8	304	37.239930000000001	37.309305999999999	51.903903999999997	51.873370999999999	0103000020E6100000010000000500000026AAB706B69E42402D23F59ECAEF494026AAB706B69E42409E5C5320B3F34940713AC95697A742409E5C5320B3F34940713AC95697A742402D23F59ECAEF494026AAB706B69E42402D23F59ECAEF4940
1468	Хмелевская	1	8	304	37.270859000000002	37.308641999999999	51.911921	51.898052	0103000020E61000000100000005000000E469F981ABA24240BF0D315EF3F24940E469F981ABA242408FC4CBD3B9F449400516C09481A742408FC4CBD3B9F449400516C09481A74240BF0D315EF3F24940E469F981ABA24240BF0D315EF3F24940
2745	Удерево	1	8	304	37.186534000000002	37.2136	51.999215	51.990287000000002	0103000020E61000000100000005000000C9CB9A58E0974240B55373B9C1FE4940C9CB9A58E09742401956F146E6FF49407A36AB3E579B42401956F146E6FF49407A36AB3E579B4240B55373B9C1FE4940C9CB9A58E0974240B55373B9C1FE4940
1936	Толстый Колодезь	1	8	304	37.204400999999997	37.224657999999998	51.863439	51.846494	0103000020E610000001000000050000008522DDCF299A42404F2157EA59EC49408522DDCF299A4240A48B4D2B85EE49407364E597C19C4240A48B4D2B85EE49407364E597C19C42404F2157EA59EC49408522DDCF299A42404F2157EA59EC4940
2027	Теплое	1	8	304	37.321711999999998	37.339095	51.855378999999999	51.838838000000003	0103000020E61000000100000005000000895DDBDB2DA942402F52280B5FEB4940895DDBDB2DA94240B4571F0F7DED49405A9E077767AB4240B4571F0F7DED49405A9E077767AB42402F52280B5FEB4940895DDBDB2DA942402F52280B5FEB4940
1821	Старые Савины	1	8	304	37.244951	37.309468000000003	51.942655999999999	51.910204999999998	0103000020E61000000100000005000000AE0FEB8D5A9F4240EDD3F19881F44940AE0FEB8D5A9F424068B0A9F3A8F849404B94BDA59CA7424068B0A9F3A8F849404B94BDA59CA74240EDD3F19881F44940AE0FEB8D5A9F4240EDD3F19881F44940
2599	Стаканово	1	8	304	37.055765999999998	37.081502999999998	52.036793000000003	52.021045999999998	0103000020E61000000100000005000000471D1D572387424016DBA4A2B1024A40471D1D572387424062DC0DA2B5044A4050C3B7B06E8A424062DC0DA2B5044A4050C3B7B06E8A424016DBA4A2B1024A40471D1D572387424016DBA4A2B1024A40
1675	Серединка	1	8	304	37.315828000000003	37.320768999999999	51.989932000000003	51.988174000000001	0103000020E610000001000000050000009F94490D6DA84240F660527C7CFE49409F94490D6DA84240C7A17E17B6FE49400A4966F50EA94240C7A17E17B6FE49400A4966F50EA94240F660527C7CFE49409F94490D6DA84240F660527C7CFE4940
2254	Сельский Рогачик	1	8	304	37.246029	37.275188	51.805576000000002	51.793807999999999	0103000020E610000001000000050000000D6FD6E07D9F4240CEA623809BE549400D6FD6E07D9F4240A438471D1DE749403620425C39A34240A438471D1DE749403620425C39A34240CEA623809BE549400D6FD6E07D9F4240CEA623809BE54940
2374	Русаново	1	8	304	37.062773	37.084296000000002	51.926752999999998	51.912537999999998	0103000020E61000000100000005000000310917F208884240BA2D910BCEF44940310917F208884240253CA1D79FF6494081971936CA8A4240253CA1D79FF6494081971936CA8A4240BA2D910BCEF44940310917F208884240BA2D910BCEF44940
2179	Петрово-Хутарь	1	8	304	37.181942999999997	37.242364000000002	51.910921000000002	51.896607000000003	0103000020E61000000100000005000000395E81E849974240AE2EA704C4F24940395E81E849974240AC1E300F99F4494027DD96C8059F4240AC1E300F99F4494027DD96C8059F4240AE2EA704C4F24940395E81E849974240AE2EA704C4F24940
2291	Огневка	1	8	304	37.207284999999999	37.230713000000002	51.780036000000003	51.762954000000001	0103000020E61000000100000005000000C6F99B50889A42401B2D077AA8E14940C6F99B50889A4240F1D93A38D8E349408BE1EA00889D4240F1D93A38D8E349408BE1EA00889D42401B2D077AA8E14940C6F99B50889A42401B2D077AA8E14940
2490	Никитское	1	8	304	37.047150999999999	37.124757000000002	51.957177000000001	51.933760999999997	0103000020E61000000100000005000000A27C410B09864240DFA3FE7A85F74940A27C410B09864240E0BDA3C684FA49403A799109F88F4240E0BDA3C684FA49403A799109F88F4240DFA3FE7A85F74940A27C410B09864240DFA3FE7A85F74940
2519	Нижнеольховатое	1	8	304	37.019959	37.058371000000001	52.008214000000002	51.992162	0103000020E6100000010000000500000064213A048E824240BF2A172AFFFE494064213A048E82424047AF06280D014A40750470B37887424047AF06280D014A40750470B378874240BF2A172AFFFE494064213A048E824240BF2A172AFFFE4940
2150	Ниженка	1	8	304	37.295462999999998	37.316592	51.826410000000003	51.808444000000001	0103000020E61000000100000005000000CA1649BBD1A54240DF52CE177BE74940CA1649BBD1A542402F8B89CDC7E949406E162F1686A842402F8B89CDC7E949406E162F1686A84240DF52CE177BE74940CA1649BBD1A54240DF52CE177BE74940
1901	Михайловка	1	8	304	37.087189000000002	37.149092000000003	51.836072000000001	51.813951000000003	0103000020E6100000010000000500000015C95702298B4240F4C5DE8B2FE8494015C95702298B4240F88C446804EB4940310C587215934240F88C446804EB4940310C587215934240F4C5DE8B2FE8494015C95702298B4240F4C5DE8B2FE84940
2843	Крюково	1	8	304	37.202865000000003	37.217489999999998	51.980730999999999	51.973480000000002	0103000020E610000001000000050000006440F67AF7994240B1A71DFE9AFC49406440F67AF79942403196E99788FD4940809A5AB6D69B42403196E99788FD4940809A5AB6D69B4240B1A71DFE9AFC49406440F67AF7994240B1A71DFE9AFC4940
1595	Карасевка	1	8	304	37.290092000000001	37.305722000000003	51.955250999999997	51.948774	0103000020E61000000100000005000000666A12BC21A54240C6A52A6D71F94940666A12BC21A54240533C2EAA45FA494078D503E621A74240533C2EAA45FA494078D503E621A74240C6A52A6D71F94940666A12BC21A54240C6A52A6D71F94940
1705	Исаково	1	8	304	37.10821	37.287343	52.076194000000001	51.921436999999997	0103000020E61000000100000005000000D28C45D3D98D42408429CAA5F1F54940D28C45D3D98D4240621399B9C0094A4005DEC9A7C7A44240621399B9C0094A4005DEC9A7C7A442408429CAA5F1F54940D28C45D3D98D42408429CAA5F1F54940
1565	Ефремовка	1	8	304	37.309271000000003	37.336283000000002	51.905692999999999	51.886640999999997	0103000020E61000000100000005000000F54C2F3196A742407825C9737DF14940F54C2F3196A74240AA9B8BBFEDF34940B39943520BAB4240AA9B8BBFEDF34940B39943520BAB42407825C9737DF14940F54C2F3196A742407825C9737DF14940
1143	Ярославка	1	8	77	34.479407000000002	34.505602000000003	51.991103000000003	51.986604999999997	0103000020E610000001000000050000009B3C65355D3D4140F888981249FE49409B3C65355D3D4140D7FB8D76DCFE49406765FB90B7404140D7FB8D76DCFE49406765FB90B7404140F888981249FE49409B3C65355D3D4140F888981249FE4940
32148	Хомутовка	1	8	77	34.533458000000003	34.584015999999998	51.940207000000001	51.910555000000002	0103000020E6100000010000000500000011E50B5A48444140CA1AF5108DF4494011E50B5A48444140323CF6B358F849409D2B4A09C14A4140323CF6B358F849409D2B4A09C14A4140CA1AF5108DF4494011E50B5A48444140CA1AF5108DF44940
32311	Стрекалово	1	8	77	34.595882000000003	34.630423	51.902048000000001	51.893616999999999	0103000020E61000000100000005000000362383DC454C41402713B70A62F24940362383DC454C41400BB6114F76F34940B7D26BB3B15041400BB6114F76F34940B7D26BB3B15041402713B70A62F24940362383DC454C41402713B70A62F24940
896	Старшее	1	8	77	34.576073999999998	34.605755000000002	52.023417999999999	52.003273999999998	0103000020E61000000100000005000000B709F7CABC494140AB764D486B004A40B709F7CABC494140A1116C5CFF024A40BA313D61894D4140A1116C5CFF024A40BA313D61894D4140AB764D486B004A40B709F7CABC494140AB764D486B004A40
1221	Сковороднево	1	8	77	34.874763999999999	34.906123999999998	51.867598000000001	51.854962	0103000020E61000000100000005000000ECDB4944F86F414050A912656FED4940ECDB4944F86F41409A0986730DEF4940730F09DFFB7341409A0986730DEF4940730F09DFFB73414050A912656FED4940ECDB4944F86F414050A912656FED4940
1012	Сальное	1	8	77	34.419488999999999	34.441597000000002	51.969856999999998	51.955644999999997	0103000020E610000001000000050000001004C8D0B1354140FFCA4A9352FA49401004C8D0B1354140F965304624FC49408081204086384140F965304624FC49408081204086384140FFCA4A9352FA49401004C8D0B1354140FFCA4A9352FA4940
775	Романово	1	8	77	34.625121999999998	34.642792	51.968170000000001	51.949834000000003	0103000020E610000001000000050000004B0169FF035041407F50172994F949404B0169FF03504140F27B9BFEECFB4940B2101D0247524140F27B9BFEECFB4940B2101D02475241407F50172994F949404B0169FF035041407F50172994F94940
137	Приходьково	1	8	77	34.474170000000001	34.496502	51.842092999999998	51.821967999999998	0103000020E61000000100000005000000465F419AB13C4140E42D573F36E94940465F419AB13C4140639813B4C9EB49400533A6608D3F4140639813B4C9EB49400533A6608D3F4140E42D573F36E94940465F419AB13C4140E42D573F36E94940
1099	Прилепы	1	8	77	34.470612000000003	34.496250000000003	52.034942999999998	52.022286999999999	0103000020E61000000100000005000000768D96033D3C41401F10E84CDA024A40768D96033D3C4140B01C210379044A40EC51B81E853F4140B01C210379044A40EC51B81E853F41401F10E84CDA024A40768D96033D3C41401F10E84CDA024A40
654	Поды	1	8	77	34.705261	34.729973999999999	51.835877000000004	51.822223999999999	0103000020E61000000100000005000000771211FE455A41403FFED2A23EE94940771211FE455A4140433D7D04FEEA49401477BCC96F5D4140433D7D04FEEA49401477BCC96F5D41403FFED2A23EE94940771211FE455A41403FFED2A23EE94940
534	Петровское	1	8	77	34.802925999999999	34.837133999999999	51.811729	51.801110000000001	0103000020E61000000100000005000000D68D7747C6664140D13FC1C58AE64940D68D7747C66641407E1B62BCE6E74940512FF834276B41407E1B62BCE6E74940512FF834276B4140D13FC1C58AE64940D68D7747C6664140D13FC1C58AE64940
626	Переступлено	1	8	77	34.729146999999998	34.759006999999997	51.799872999999998	51.778151999999999	0103000020E61000000100000005000000FE7C5BB0545D414093A8177C9AE34940FE7C5BB0545D414009FA0B3D62E64940B03731242761414009FA0B3D62E64940B03731242761414093A8177C9AE34940FE7C5BB0545D414093A8177C9AE34940
234	Ольховка	1	8	77	34.594552999999998	34.625311000000004	51.846350000000001	51.825324999999999	0103000020E610000001000000050000008D5E0D501A4C41401DC9E53FA4E949408D5E0D501A4C41401C7C613255EC49401F6ADB300A5041401C7C613255EC49401F6ADB300A5041401DC9E53FA4E949408D5E0D501A4C41401DC9E53FA4E94940
364	Нижняя Туранка	1	8	77	34.669625000000003	34.682938	51.761048000000002	51.755946999999999	0103000020E61000000100000005000000C1CAA145B655414031410DDFC2E04940C1CAA145B6554140D65757056AE149400B992B836A574140D65757056AE149400B992B836A57414031410DDFC2E04940C1CAA145B655414031410DDFC2E04940
498	Нижнее Чупахино	1	8	77	34.772545000000001	34.791939999999997	51.744979000000001	51.716380000000001	0103000020E610000001000000050000001BD82AC1E262414016C1FF56B2DB49401BD82AC1E2624140789ACC785BDF49407632384A5E654140789ACC785BDF49407632384A5E65414016C1FF56B2DB49401BD82AC1E262414016C1FF56B2DB4940
405	Надейка	1	8	77	34.571745	34.620972000000002	51.757207000000001	51.742843000000001	0103000020E610000001000000050000006553AEF02E4941400188BB7A15DF49406553AEF02E494140B1A6B228ECE04940A9DDAF027C4F4140B1A6B228ECE04940A9DDAF027C4F41400188BB7A15DF49406553AEF02E4941400188BB7A15DF4940
1268	Меньшиково	1	8	77	34.879983000000003	34.912906999999997	51.941184999999997	51.921064999999999	0103000020E610000001000000050000009B046F48A3704140C03E3A75E5F549409B046F48A37041402D3E05C078F849400DA5F622DA7441402D3E05C078F849400DA5F622DA744140C03E3A75E5F549409B046F48A3704140C03E3A75E5F54940
32256	Малеевка	1	8	77	34.765977999999997	34.787205	51.888392000000003	51.881027000000003	0103000020E610000001000000050000004DBA2D910B6241404EF2237EC5F049404DBA2D910B62414097033DD4B6F14940B41F2922C364414097033DD4B6F14940B41F2922C36441404EF2237EC5F049404DBA2D910B6241404EF2237EC5F04940
736	Луговое	1	8	77	34.877898999999999	34.920408000000002	51.760773999999998	51.738253999999998	0103000020E61000000100000005000000761893FE5E7041401212691B7FDE4940761893FE5E704140D4D2DC0A61E14940077DE9EDCF754140D4D2DC0A61E14940077DE9EDCF7541401212691B7FDE4940761893FE5E7041401212691B7FDE4940
268	Красная Поляна	1	8	77	34.601433999999998	34.634734000000002	51.809323999999997	51.795596000000003	0103000020E61000000100000005000000EA5910CAFB4C41400A6AF816D6E54940EA5910CAFB4C414017EFC7ED97E7494063D4B5F63E51414017EFC7ED97E7494063D4B5F63E5141400A6AF816D6E54940EA5910CAFB4C41400A6AF816D6E54940
93	Клевень	1	8	77	34.400722999999999	34.432667000000002	51.874755	51.855122999999999	0103000020E61000000100000005000000A4E029E44A3341405987A3AB74ED4940A4E029E44A3341409981CAF8F7EF49407B87DBA1613741409981CAF8F7EF49407B87DBA1613741405987A3AB74ED4940A4E029E44A3341405987A3AB74ED4940
32373	Калиновка	1	8	77	34.489854000000001	34.519480999999999	51.913637999999999	51.889015000000001	0103000020E610000001000000050000004BE82E89B33E4140A453573ECBF149404BE82E89B33E414001310917F2F449405AF2785A7E42414001310917F2F449405AF2785A7E424140A453573ECBF149404BE82E89B33E4140A453573ECBF14940
1337	Звенячка	1	8	77	34.823264000000002	34.857650999999997	51.974500999999997	51.964564000000003	0103000020E61000000100000005000000B1FCF9B660694140117349D576FB4940B1FCF9B660694140AB75E272BCFC4940DB300A82C76D4140AB75E272BCFC4940DB300A82C76D4140117349D576FB4940B1FCF9B660694140117349D576FB4940
32441	Жеденовка	1	8	77	34.536566999999998	34.565600000000003	51.869033000000002	51.849988000000003	0103000020E61000000100000005000000718E3A3AAE44414009FF2268CCEC4940718E3A3AAE44414088122D793CEF49400E4FAF946548414088122D793CEF49400E4FAF946548414009FF2268CCEC4940718E3A3AAE44414009FF2268CCEC4940
31355	Дубовица	1	8	77	34.516641999999997	34.542828	51.970956000000001	51.954247000000002	0103000020E61000000100000005000000B9DE3653214241402FA704C424FA4940B9DE36532142414070ED444948FC494032AD4D637B45414070ED444948FC494032AD4D637B4541402FA704C424FA4940B9DE3653214241402FA704C424FA4940
982	Деменино	1	8	77	34.658279	34.685642000000001	52.041119999999999	52.020791000000003	0103000020E6100000010000000500000061527C7C425441408C868C47A9024A4061527C7C42544140139B8F6B43054A40CC61F71DC3574140139B8F6B43054A40CC61F71DC35741408C868C47A9024A4061527C7C425441408C868C47A9024A40
32206	Гламаздино	1	8	77	34.66216	34.713614999999997	51.936625999999997	51.923281000000003	0103000020E61000000100000005000000145CACA8C1544140540262122EF64940145CACA8C1544140A94A5B5CE3F74940AF777FBC575B4140A94A5B5CE3F74940AF777FBC575B4140540262122EF64940145CACA8C1544140540262122EF64940
876	Веть	1	8	77	34.678662000000003	34.722310999999998	51.988728999999999	51.975799000000002	0103000020E61000000100000005000000DC847B65DE564140193C4CFBE6FC4940DC847B65DE564140ABCDFFAB8EFE49404145D5AF745C4140ABCDFFAB8EFE49404145D5AF745C4140193C4CFBE6FC4940DC847B65DE564140193C4CFBE6FC4940
32473	Амонь	1	8	77	34.503436999999998	34.538497999999997	51.802011999999998	51.776496999999999	0103000020E61000000100000005000000554CA59F704041409738F24064E34940554CA59F70404140F17F4754A8E649400F7BA180ED444140F17F4754A8E649400F7BA180ED4441409738F24064E34940554CA59F704041409738F24064E34940
31380	Ясенок	1	8	1895	35.777436000000002	35.796418000000003	52.284337999999998	52.273344999999999	0103000020E61000000100000005000000D55DD90583E3414037C30DF8FC224A40D55DD90583E341404981053065244A400EF96706F1E541404981053065244A400EF96706F1E5414037C30DF8FC224A40D55DD90583E3414037C30DF8FC224A40
31699	Хмелевое	1	8	1895	35.990256000000002	36.039610000000003	52.218812	52.179195	0103000020E610000001000000050000007A5567B5C0FE4140A94D9CDCEF164A407A5567B5C0FE414076FC1708021C4A401B4CC3F01105424076FC1708021C4A401B4CC3F011054240A94D9CDCEF164A407A5567B5C0FE4140A94D9CDCEF164A40
30548	Фатеж	1	8	1895	35.832557000000001	35.871858000000003	52.100923999999999	52.081468999999998	0103000020E6100000010000000500000027874F3A91EA4140A45181936D0A4A4027874F3A91EA4140D5B0DF13EB0C4A40C460FE0A99EF4140D5B0DF13EB0C4A40C460FE0A99EF4140A45181936D0A4A4027874F3A91EA4140A45181936D0A4A40
31780	Сухочево	1	8	1895	35.776215000000001	35.802166999999997	52.089770000000001	52.081867000000003	0103000020E6100000010000000500000013D55B035BE3414092CF2B9E7A0A4A4013D55B035BE34140BA1457957D0B4A4018778368ADE64140BA1457957D0B4A4018778368ADE6414092CF2B9E7A0A4A4013D55B035BE3414092CF2B9E7A0A4A40
30971	Сотниково	1	8	1895	35.935763999999999	35.997874000000003	52.189321999999997	52.148038	0103000020E610000001000000050000001763601DC7F741405A48C0E8F2124A401763601DC7F74140E7340BB43B184A40ADC3D155BAFF4140E7340BB43B184A40ADC3D155BAFF41405A48C0E8F2124A401763601DC7F741405A48C0E8F2124A40
54515	Солдатское	1	8	1895	35.722765000000003	35.756594999999997	52.081220000000002	52.056783000000003	0103000020E61000000100000005000000C3D8429083DC414001FC53AA44074A40C3D8429083DC4140FCE3BD6A650A4A4097A8DE1AD8E04140FCE3BD6A650A4A4097A8DE1AD8E0414001FC53AA44074A40C3D8429083DC414001FC53AA44074A40
31726	Русановка	1	8	1895	35.852266	35.869073999999998	52.081479999999999	52.072108999999998	0103000020E6100000010000000500000012BF620D17ED4140A65F22DE3A094A4012BF620D17ED414098A3C7EF6D0A4A40E6E61BD13DEF414098A3C7EF6D0A4A40E6E61BD13DEF4140A65F22DE3A094A4012BF620D17ED4140A65F22DE3A094A40
30920	Ржава	1	8	1895	35.843192999999999	35.872784000000003	52.166614000000003	52.143644999999999	0103000020E61000000100000005000000AA9B8BBFEDEB4140F19D98F562124A40AA9B8BBFEDEB41402387889B53154A406D3CD862B7EF41402387889B53154A406D3CD862B7EF4140F19D98F562124A40AA9B8BBFEDEB4140F19D98F562124A40
32004	Репринка	1	8	1895	35.732106999999999	35.743777000000001	52.023916	52.016911	0103000020E610000001000000050000001A16A3AEB5DD4140A9F8BF232A024A401A16A3AEB5DD4140F2ECF2AD0F034A402D42B11534DF4140F2ECF2AD0F034A402D42B11534DF4140A9F8BF232A024A401A16A3AEB5DD4140A9F8BF232A024A40
32080	Поздняково	1	8	1895	35.630822000000002	35.651780000000002	51.962155000000003	51.937542000000001	0103000020E6100000010000000500000075CC79C6BED041402F50526001F8494075CC79C6BED04140695721E527FB4940EC17EC866DD34140695721E527FB4940EC17EC866DD341402F50526001F8494075CC79C6BED041402F50526001F84940
31868	Нижний Реут	1	8	1895	35.732897999999999	35.754061999999998	52.195113999999997	52.164586	0103000020E61000000100000005000000E3A6069ACFDD414092B06F2711154A40E3A6069ACFDD4140F17EDC7EF9184A400394861A85E04140F17EDC7EF9184A400394861A85E0414092B06F2711154A40E3A6069ACFDD414092B06F2711154A40
54536	Нижние Халчи	1	8	1895	35.526797000000002	36.156300999999999	52.300058	51.853799000000002	0103000020E61000000100000005000000C25087156EC34140C32D1F4949ED4940C25087156EC341409B73F04C68264A4082AAD1AB011442409B73F04C68264A4082AAD1AB01144240C32D1F4949ED4940C25087156EC34140C32D1F4949ED4940
31616	Молотычи	1	8	1895	35.925685000000001	36.011797999999999	52.271465999999997	52.238356000000003	0103000020E61000000100000005000000EAB298D87CF6414017670C73821E4A40EAB298D87CF64140EBFCDB65BF224A404014CC9882014240EBFCDB65BF224A404014CC988201424017670C73821E4A40EAB298D87CF6414017670C73821E4A40
31475	Миролюбово	1	8	1895	35.816001	35.858463999999998	52.063777000000002	52.043185999999999	0103000020E610000001000000050000006C4084B872E8414091D26C1E87054A406C4084B872E84140569E40D829084A408C65FA25E2ED4140569E40D829084A408C65FA25E2ED414091D26C1E87054A406C4084B872E8414091D26C1E87054A40
31603	Миленино	1	8	1895	35.912686999999998	35.958132999999997	52.089753000000002	52.084085999999999	0103000020E61000000100000005000000FF3D78EDD2F4414096067E54C30A4A40FF3D78EDD2F44140E4DBBB067D0B4A40F31B261AA4FA4140E4DBBB067D0B4A40F31B261AA4FA414096067E54C30A4A40FF3D78EDD2F4414096067E54C30A4A40
54557	Мелешинка	1	8	1895	35.743713999999997	35.754708999999998	51.917048999999999	51.907527000000002	0103000020E61000000100000005000000E6C9350532DF4140569E40D829F44940E6C9350532DF41402DEA93DC61F54940997FF44D9AE041402DEA93DC61F54940997FF44D9AE04140569E40D829F44940E6C9350532DF4140569E40D829F44940
54553	Кукуевка	1	8	1895	35.799399999999999	35.821148000000001	51.938963999999999	51.931089999999998	0103000020E6100000010000000500000011363CBD52E64140FAD005F52DF7494011363CBD52E64140880FECF82FF849408196AE601BE94140880FECF82FF849408196AE601BE94140FAD005F52DF7494011363CBD52E64140FAD005F52DF74940
31270	Игино	1	8	1895	35.689338999999997	35.722037	52.239955000000002	52.216323000000003	0103000020E61000000100000005000000BD6DA6423CD84140B22FD978B01B4A40BD6DA6423CD841407FC16ED8B61E4A4040C05AB56BDC41407FC16ED8B61E4A4040C05AB56BDC4140B22FD978B01B4A40BD6DA6423CD84140B22FD978B01B4A40
31569	Зыковка	1	8	1895	35.958132999999997	35.984470999999999	52.092387000000002	52.082110999999998	0103000020E61000000100000005000000F31B261AA4FA414028D2FD9C820A4A40F31B261AA4FA4140ACC95356D30B4A40226E4E2503FE4140ACC95356D30B4A40226E4E2503FE414028D2FD9C820A4A40F31B261AA4FA414028D2FD9C820A4A40
30876	Жердево	1	8	1895	35.875585999999998	35.907054000000002	52.212691999999997	52.184877999999998	0103000020E61000000100000005000000F06AB93313F04140FCDF1115AA174A40F06AB93313F04140770FD07D391B4A405EDA70581AF44140770FD07D391B4A405EDA70581AF44140FCDF1115AA174A40F06AB93313F04140FCDF1115AA174A40
30772	Горки	1	8	1895	35.740974000000001	35.818030999999998	51.991624000000002	51.940967999999998	0103000020E61000000100000005000000D9976C3CD8DE4140904AB1A371F84940D9976C3CD8DE4140E0F60489EDFE49409D0E643DB5E84140E0F60489EDFE49409D0E643DB5E84140904AB1A371F84940D9976C3CD8DE4140904AB1A371F84940
31468	Верхняя Хотемль	1	8	1895	35.877634	35.895842999999999	52.011163000000003	52.000230000000002	0103000020E61000000100000005000000C8ED974F56F04140323D618907004A40C8ED974F56F041406FF607CA6D014A40DEACC1FBAAF241406FF607CA6D014A40DEACC1FBAAF24140323D618907004A40C8ED974F56F04140323D618907004A40
31174	Верхний Любаж	1	8	1895	35.800640000000001	35.867438999999997	52.230170999999999	52.204442	0103000020E610000001000000050000004AEF1B5F7BE64140E4F6CB272B1A4A404AEF1B5F7BE641406ABE4A3E761D4A403123BC3D08EF41406ABE4A3E761D4A403123BC3D08EF4140E4F6CB272B1A4A404AEF1B5F7BE64140E4F6CB272B1A4A40
30703	Бычки	1	8	1895	35.805931000000001	36.085594	52.189200999999997	52.079410000000003	0103000020E6100000010000000500000092EA3BBF28E74140D97C5C1B2A0A4A4092EA3BBF28E741406CAF05BD37184A40EE5D83BEF40A42406CAF05BD37184A40EE5D83BEF40A4240D97C5C1B2A0A4A4092EA3BBF28E74140D97C5C1B2A0A4A40
31066	Большое Жирово	1	8	1895	35.957206999999997	35.980967999999997	51.967731999999998	51.948141	0103000020E610000001000000050000004A404CC285FA4140957F2DAF5CF949404A404CC285FA414076A565A4DEFB49401536035C90FD414076A565A4DEFB49401536035C90FD4140957F2DAF5CF949404A404CC285FA4140957F2DAF5CF94940
30984	Большое Анненково	1	8	1895	36.038809999999998	36.077384000000002	52.129404999999998	52.114603000000002	0103000020E61000000100000005000000FE60E0B9F70442400283A44FAB0E4A40FE60E0B9F70442402D78D15790104A40E99D0AB8E70942402D78D15790104A40E99D0AB8E70942400283A44FAB0E4A40FE60E0B9F70442400283A44FAB0E4A40
54545	Басовка	1	8	1895	35.526797000000002	36.156300999999999	52.300058	51.853799000000002	0103000020E61000000100000005000000C25087156EC34140C32D1F4949ED4940C25087156EC341409B73F04C68264A4082AAD1AB011442409B73F04C68264A4082AAD1AB01144240C32D1F4949ED4940C25087156EC34140C32D1F4949ED4940
31956	Алисово-Покровское	1	8	1895	35.745581999999999	35.772846000000001	51.985878	51.967837000000003	0103000020E610000001000000050000003E3E213B6FDF4140EC6D3315E2FB49403E3E213B6FDF414046EC134031FE4940166C239EECE2414046EC134031FE4940166C239EECE24140EC6D3315E2FB49403E3E213B6FDF4140EC6D3315E2FB4940
54517	1-е Шемякино	1	8	1895	36.018346999999999	36.039420999999997	51.947958	51.928373999999998	0103000020E61000000100000005000000677DCA3159024240753A90F5D4F64940677DCA3159024240A4FD0FB056F9494047E350BF0B054240A4FD0FB056F9494047E350BF0B054240753A90F5D4F64940677DCA3159024240753A90F5D4F64940
30635	1-е Банино	1	8	1895	35.919199999999996	35.932017999999999	52.14575	52.115730999999997	0103000020E61000000100000005000000D93D7958A8F541401211FE45D00E4A40D93D7958A8F541402DB29DEFA7124A4044A4A65D4CF741402DB29DEFA7124A4044A4A65D4CF741401211FE45D00E4A40D93D7958A8F541401211FE45D00E4A40
30301	Шабановка	1	8	876	37.075088999999998	37.149999000000001	51.700329000000004	51.660283	0103000020E6100000010000000500000009A52F849C894240698D412784D4494009A52F849C8942405FB87361A4D9494063B7CF2A339342405FB87361A4D9494063B7CF2A33934240698D412784D4494009A52F849C894240698D412784D44940
30331	Успенка	1	8	876	37.158577999999999	37.187745999999997	51.745046000000002	51.728006999999998	0103000020E61000000100000005000000BBEEAD484C944240292158552FDD4940BBEEAD484C9442400002D6AA5DDF494037FA980F089842400002D6AA5DDF494037FA980F08984240292158552FDD4940BBEEAD484C944240292158552FDD4940
6585	Тим	1	8	876	37.111694999999997	37.144168999999998	51.633419000000004	51.608646999999998	0103000020E61000000100000005000000381092054C8E42407DE71725E8CD4940381092054C8E424020D5B0DF13D149406B0C3A217492424020D5B0DF13D149406B0C3A21749242407DE71725E8CD4940381092054C8E42407DE71725E8CD4940
29980	Становое	1	8	876	37.022078999999998	37.077567999999999	51.653846999999999	51.628968999999998	0103000020E61000000100000005000000D576137CD38242405299620E82D04940D576137CD38242403ACB2C42B1D34940AA9B8BBFED8942403ACB2C42B1D34940AA9B8BBFED8942405299620E82D04940D576137CD38242405299620E82D04940
27991	Соколье	1	8	876	36.954273999999998	37.008012000000001	51.739916000000001	51.690325000000001	0103000020E6100000010000000500000028B682A6257A42403C4ED1915CD8494028B682A6257A4240C1E44691B5DE4940DFFC868906814240C1E44691B5DE4940DFFC8689068142403C4ED1915CD8494028B682A6257A42403C4ED1915CD84940
29497	Рождественка	1	8	876	36.892882999999998	36.927917999999998	51.630887000000001	51.590107000000003	0103000020E61000000100000005000000C2137AFD4972424002124DA088CB4940C2137AFD497242405C3CBCE7C0D0494053AF5B04C67642405C3CBCE7C0D0494053AF5B04C676424002124DA088CB4940C2137AFD4972424002124DA088CB4940
29617	Рогозцы	1	8	876	37.464436999999997	37.514634000000001	51.602829999999997	51.569040999999999	0103000020E61000000100000005000000B306EFAB72BB4240A48AE255D6C84940B306EFAB72BB42401A868F8829CD494070B4E386DFC142401A868F8829CD494070B4E386DFC14240A48AE255D6C84940B306EFAB72BB4240A48AE255D6C84940
54559	Рогозецкий Колодезь	1	8	876	37.415703000000001	37.458831000000004	51.700139	51.671478	0103000020E61000000100000005000000AFEC82C135B54240E3FDB8FDF2D54940AFEC82C135B54240BBD39D279ED949400CB265F9BABA4240BBD39D279ED949400CB265F9BABA4240E3FDB8FDF2D54940AFEC82C135B54240E3FDB8FDF2D54940
29813	Постояновка	1	8	876	37.368056000000003	37.400432000000002	51.689554999999999	51.659199000000001	0103000020E610000001000000050000005D8C81751CAF4240284701A260D449405D8C81751CAF42408AE5965643D84940CD22145B41B342408AE5965643D84940CD22145B41B34240284701A260D449405D8C81751CAF4240284701A260D44940
29898	Погожее	1	8	876	37.224263000000001	37.302695	51.615654999999997	51.573295000000002	0103000020E61000000100000005000000F75965A6B49C4240ECFA05BB61C94940F75965A6B49C4240374F75C8CDCE4940D4D4B2B5BEA64240374F75C8CDCE4940D4D4B2B5BEA64240ECFA05BB61C94940F75965A6B49C4240ECFA05BB61C94940
29543	Пахонок	1	8	876	36.837798999999997	36.860301999999997	51.627471	51.609850000000002	0103000020E610000001000000050000008DCF64FF3C6B424099BB96900FCE49408DCF64FF3C6B42401E1840F850D0494079573D601E6E42401E1840F850D0494079573D601E6E424099BB96900FCE49408DCF64FF3C6B424099BB96900FCE4940
29969	Лисий Колодезь	1	8	876	37.314354999999999	37.334989	51.598646000000002	51.584063999999998	0103000020E61000000100000005000000C32ADEC83CA84240AE62F19BC2CA4940C32ADEC83CA84240CCF09F6EA0CC494087C267EBE0AA4240CCF09F6EA0CC494087C267EBE0AA4240AE62F19BC2CA4940C32ADEC83CA84240AE62F19BC2CA4940
30482	Леженьки	1	8	876	37.027738999999997	37.074711000000001	51.766075000000001	51.738180999999997	0103000020E6100000010000000500000070E998F38C834240A8C30AB77CDE494070E998F38C83424040A4DFBE0EE2494063D34A219089424040A4DFBE0EE2494063D34A2190894240A8C30AB77CDE494070E998F38C834240A8C30AB77CDE4940
29721	Кировка	1	8	876	37.016905000000001	37.041697999999997	51.564120000000003	51.549191	0103000020E61000000100000005000000C7116BF129824240F72004E44BC64940C7116BF12982424080828B1535C8494080272D5C5685424080828B1535C8494080272D5C56854240F72004E44BC64940C7116BF129824240F72004E44BC64940
30455	Канищево	1	8	876	37.203924999999998	37.252668	51.751424999999998	51.730322000000001	0103000020E610000001000000050000001CEBE2361A9A424050C6F8307BDD49401CEBE2361A9A4240CA32C4B12EE04940745FCE6C57A04240CA32C4B12EE04940745FCE6C57A0424050C6F8307BDD49401CEBE2361A9A424050C6F8307BDD4940
30371	Заречье	1	8	876	37.186093999999997	37.212117999999997	51.742252000000001	51.728208000000002	0103000020E61000000100000005000000ACFD9DEDD1974240C15774EB35DD4940ACFD9DEDD1974240FFB1101D02DF49404B72C0AE269B4240FFB1101D02DF49404B72C0AE269B4240C15774EB35DD4940ACFD9DEDD1974240C15774EB35DD4940
30069	Гнилуши	1	8	876	37.028869999999998	37.092120999999999	51.691397000000002	51.678409000000002	0103000020E61000000100000005000000F2EA1C03B2834240F2272A1BD6D64940F2EA1C03B2834240B9C667B27FD849402D23F59ECA8B4240B9C667B27FD849402D23F59ECA8B4240F2272A1BD6D64940F2EA1C03B2834240F2272A1BD6D64940
30074	Гнилое	1	8	876	36.97551	37.003833999999998	51.678845000000003	51.651572000000002	0103000020E61000000100000005000000E275FD82DD7C4240A27E17B666D34940E275FD82DD7C4240CD069964E4D64940724EECA17D804240CD069964E4D64940724EECA17D804240A27E17B666D34940E275FD82DD7C4240A27E17B666D34940
30158	Выгорное 3-е	1	8	876	37.076839999999997	37.133344000000001	51.659238999999999	51.631405999999998	0103000020E610000001000000050000002783A3E4D5894240C43F6CE9D1D049402783A3E4D5894240B69F8CF161D44940158F8B6A11914240B69F8CF161D44940158F8B6A11914240C43F6CE9D1D049402783A3E4D5894240C43F6CE9D1D04940
29681	Выгорное 2-е	1	8	876	37.076839999999997	37.133344000000001	51.659238999999999	51.631405999999998	0103000020E610000001000000050000002783A3E4D5894240C43F6CE9D1D049402783A3E4D5894240B69F8CF161D44940158F8B6A11914240B69F8CF161D44940158F8B6A11914240C43F6CE9D1D049402783A3E4D5894240C43F6CE9D1D04940
30209	Выгорное 1-е	1	8	876	37.076839999999997	37.133344000000001	51.659238999999999	51.631405999999998	0103000020E610000001000000050000002783A3E4D5894240C43F6CE9D1D049402783A3E4D5894240B69F8CF161D44940158F8B6A11914240B69F8CF161D44940158F8B6A11914240C43F6CE9D1D049402783A3E4D5894240C43F6CE9D1D04940
29747	Волобуевка	1	8	876	37.318917999999996	37.367435999999998	51.690984	51.665764000000003	0103000020E61000000100000005000000880D164ED2A84240556D37C137D54940880D164ED2A842409607E92972D84940C0AF912408AF42409607E92972D84940C0AF912408AF4240556D37C137D54940880D164ED2A84240556D37C137D54940
30225	Введенка	1	8	876	37.149442000000001	37.184009000000003	51.684786000000003	51.653232000000003	0103000020E610000001000000050000000D535BEA20934240B0592E1B9DD349400D535BEA209342401C615111A7D74940B8955E9B8D9742401C615111A7D74940B8955E9B8D974240B0592E1B9DD349400D535BEA20934240B0592E1B9DD34940
29608	Быстрецы	1	8	876	37.415595000000003	37.447080999999997	51.623477999999999	51.597805999999999	0103000020E61000000100000005000000C9B08A3732B5424021AD31E884CC4940C9B08A3732B5424043E38920CECF4940DCD440F339B9424043E38920CECF4940DCD440F339B9424021AD31E884CC4940C9B08A3732B5424021AD31E884CC4940
29432	Барковка	1	8	876	36.880595	36.895381	51.703220999999999	51.693702999999999	0103000020E61000000100000005000000B4024356B77042408C118942CBD84940B4024356B7704240226E4E2503DA4940DA3A38D89B724240226E4E2503DA4940DA3A38D89B7242408C118942CBD84940B4024356B77042408C118942CBD84940
28060	Черный Олех	1	8	740	35.51361	35.532483999999997	51.199582999999997	51.179470000000002	0103000020E610000001000000050000000473F4F8BDC141407B4E7ADFF89649400473F4F8BDC1414035EB8CEF8B99494056D28A6F28C4414035EB8CEF8B99494056D28A6F28C441407B4E7ADFF89649400473F4F8BDC141407B4E7ADFF8964940
28430	Черкасское-Поречное	1	8	740	35.315621	35.354869000000001	51.310479999999998	51.280946	0103000020E610000001000000050000002577D84466A8414094F8DC09F6A349402577D84466A84140F20703CFBDA749409FAEEE586CAD4140F20703CFBDA749409FAEEE586CAD414094F8DC09F6A349402577D84466A8414094F8DC09F6A34940
28123	Уланок	1	8	740	35.388133000000003	35.421388999999998	51.147280000000002	51.124442000000002	0103000020E61000000100000005000000CBBF9657AEB14140DA1F28B7ED8F4940CBBF9657AEB141406DAD2F12DA92494073F22213F0B541406DAD2F12DA92494073F22213F0B54140DA1F28B7ED8F4940CBBF9657AEB14140DA1F28B7ED8F4940
29061	Толстый Луг	1	8	740	35.022132999999997	35.078862000000001	51.306251000000003	51.289485999999997	0103000020E61000000100000005000000C8940F41D58241402E5393E00DA54940C8940F41D582414004AF963B33A74940D6726726188A414004AF963B33A74940D6726726188A41402E5393E00DA54940C8940F41D58241402E5393E00DA54940
6248	Суджа	1	8	740	35.227856000000003	35.291635999999997	51.209104000000004	51.185765000000004	0103000020E610000001000000050000004419AA622A9D4140E8DEC325C79749404419AA622A9D41403DBB7CEBC39A49400A2B155454A541403DBB7CEBC39A49400A2B155454A54140E8DEC325C79749404419AA622A9D4140E8DEC325C7974940
28423	Спальное	1	8	740	35.437640000000002	35.470329	51.094816000000002	51.075913	0103000020E61000000100000005000000F2B5679604B84140AE2B6684B7894940F2B5679604B841409B9141EE228C494021AE9CBD33BC41409B9141EE228C494021AE9CBD33BC4140AE2B6684B7894940F2B5679604B84140AE2B6684B7894940
28873	Свердликово	1	8	740	35.107337999999999	35.137369	51.259993999999999	51.231917000000003	0103000020E610000001000000050000001CCF6740BD8D41407731CD74AF9D49401CCF6740BD8D4140FF93BF7B47A14940FB3DB14E95914140FF93BF7B47A14940FB3DB14E959141407731CD74AF9D49401CCF6740BD8D41407731CD74AF9D4940
28491	Русское-Поречное	1	8	740	35.321289999999998	35.346784	51.332774999999998	51.311639999999997	0103000020E610000001000000050000001344DD0720A941400E10CCD1E3A749401344DD0720A9414094F6065F98AA49405663096B63AC414094F6065F98AA49405663096B63AC41400E10CCD1E3A749401344DD0720A941400E10CCD1E3A74940
28263	Русская-Конопелька	1	8	740	35.392660999999997	35.415810999999998	51.195259999999998	51.178007999999998	0103000020E6100000010000000500000013B534B742B24140933655F7C896494013B534B742B24140C51B9947FE98494095287B4B39B54140C51B9947FE98494095287B4B39B54140933655F7C896494013B534B742B24140933655F7C8964940
26802	Розгребли	1	8	740	35.378216000000002	35.425089999999997	51.337282999999999	51.321784000000001	0103000020E610000001000000050000007769C36169B041402330D63730A949407769C36169B04140963FDF162CAB4940A6ED5F5969B64140963FDF162CAB4940A6ED5F5969B641402330D63730A949407769C36169B041402330D63730A94940
29310	Пушкарное	1	8	740	35.406359999999999	35.432060999999997	51.227980000000002	51.196705000000001	0103000020E610000001000000050000008733BF9A03B44140D7FA22A12D9949408733BF9A03B441403012DA722E9D494043705CC64DB741403012DA722E9D494043705CC64DB74140D7FA22A12D9949408733BF9A03B44140D7FA22A12D994940
29160	Погребки	1	8	740	35.213527999999997	35.243701999999999	51.389515000000003	51.370638	0103000020E61000000100000005000000E063B0E2549B4140D253E41071AF4940E063B0E2549B41409626A5A0DBB1494022FC8BA0319F41409626A5A0DBB1494022FC8BA0319F4140D253E41071AF4940E063B0E2549B4140D253E41071AF4940
28291	Плехово	1	8	740	35.312280000000001	35.359414000000001	51.111607999999997	51.093814999999999	0103000020E61000000100000005000000F29881CAF8A74140E76F4221028C4940F29881CAF8A7414069FCC22B498E4940BEDC274701AE414069FCC22B498E4940BEDC274701AE4140E76F4221028C4940F29881CAF8A74140E76F4221028C4940
28989	Новоивановка	1	8	740	35.083641	35.125762999999999	51.327857000000002	51.316249999999997	0103000020E6100000010000000500000068CD8FBFB48A414014AE47E17AA8494068CD8FBFB48A4140E161DA37F7A94940FF05820019904140E161DA37F7A94940FF0582001990414014AE47E17AA8494068CD8FBFB48A414014AE47E17AA84940
6378	Нижнемахово	1	8	740	35.477021999999998	35.489023000000003	51.131124	51.110470999999997	0103000020E610000001000000050000007BBC900E0FBD41400514EAE9238E49407BBC900E0FBD414040DCD5ABC8904940F4FE3F4E98BE414040DCD5ABC8904940F4FE3F4E98BE41400514EAE9238E49407BBC900E0FBD41400514EAE9238E4940
28212	Махновка	1	8	740	35.286048999999998	35.324765999999997	51.181660999999998	51.155433000000002	0103000020E61000000100000005000000D906EE409DA441400EDC813AE5934940D906EE409DA44140B5FAEAAA40974940266DAAEE91A94140B5FAEAAA40974940266DAAEE91A941400EDC813AE5934940D906EE409DA441400EDC813AE5934940
28169	Мартыновка	1	8	740	35.350458000000003	35.378504	51.255794999999999	51.234048999999999	0103000020E61000000100000005000000904FC8CEDBAC4140AC545051F59D4940904FC8CEDBAC41407BBDFBE3BDA04940DDB3AED172B041407BBDFBE3BDA04940DDB3AED172B04140AC545051F59D4940904FC8CEDBAC4140AC545051F59D4940
29152	Малая Локня	1	8	740	35.217903	35.240073000000002	51.344788000000001	51.324052000000002	0103000020E61000000100000005000000A359D93EE49B4140091A33897AA94940A359D93EE49B4140D106600322AC494089D349B6BA9E4140D106600322AC494089D349B6BA9E4140091A33897AA94940A359D93EE49B4140091A33897AA94940
28983	Лебедевка	1	8	740	35.152172999999998	35.198382000000002	51.271818000000003	51.247407000000003	0103000020E61000000100000005000000C72AA5677A93414097E65608AB9F4940C72AA5677A934140693BA6EECAA24940BB0ED59464994140693BA6EECAA24940BB0ED5946499414097E65608AB9F4940C72AA5677A93414097E65608AB9F4940
28523	Киреевка	1	8	740	35.333542999999999	35.357698999999997	51.389290000000003	51.369776999999999	0103000020E61000000100000005000000A5677A89B1AA414010E84CDA54AF4940A5677A89B1AA414076543541D4B14940EC67B114C9AD414076543541D4B14940EC67B114C9AD414010E84CDA54AF4940A5677A89B1AA414010E84CDA54AF4940
29101	Казачья Локня	1	8	740	35.230758000000002	35.266295	51.251995999999998	51.229768	0103000020E610000001000000050000002BA5677A899D41406BD5AE09699D49402BA5677A899D4140855CA96741A049404E0B5EF415A24140855CA96741A049404E0B5EF415A241406BD5AE09699D49402BA5677A899D41406BD5AE09699D4940
29238	Ивница	1	8	740	35.291429999999998	35.303781999999998	51.422342999999998	51.416609000000001	0103000020E61000000100000005000000618907944DA54140111C977153B54940618907944DA54140E658DE550FB64940868E1D54E2A64140E658DE550FB64940868E1D54E2A64140111C977153B54940618907944DA54140111C977153B54940
28702	Заолешенка	1	8	740	35.248975000000002	35.271540999999999	51.221685000000001	51.207822999999998	0103000020E61000000100000005000000C442AD69DE9F4140A52DAEF1999A4940C442AD69DE9F4140C381902C609C4940F64201DBC1A24140C381902C609C4940F64201DBC1A24140A52DAEF1999A4940C442AD69DE9F4140A52DAEF1999A4940
54466	Замостье	1	8	740	35.277740000000001	35.322555999999999	51.207371000000002	51.174292000000001	0103000020E610000001000000050000004165FCFB8CA341402BFA43334F9649404165FCFB8CA34140C59107228B9A49407590D78349A94140C59107228B9A49407590D78349A941402BFA43334F9649404165FCFB8CA341402BFA43334F964940
28918	Дарьино	1	8	740	35.020408000000003	35.041060000000002	51.264142999999997	51.251719999999999	0103000020E61000000100000005000000D449B6BA9C824140E3DF675C38A04940D449B6BA9C824140D13B1570CFA149403E963E7441854140D13B1570CFA149403E963E7441854140E3DF675C38A04940D449B6BA9C824140E3DF675C38A04940
28598	Гуево	1	8	740	35.236730999999999	35.279842000000002	51.100026	51.084203000000002	0103000020E6100000010000000500000085798F334D9E4140D09CF529C78A494085798F334D9E4140F65FE7A6CD8C49400C06D7DCD1A34140F65FE7A6CD8C49400C06D7DCD1A34140D09CF529C78A494085798F334D9E4140D09CF529C78A4940
28620	Гончаровка	1	8	740	35.240729000000002	35.263069999999999	51.197946999999999	51.182841000000003	0103000020E6100000010000000500000072193735D09E414019AF79556797494072193735D09E4140B0ABC9535699494084471B47ACA14140B0ABC9535699494084471B47ACA1414019AF79556797494072193735D09E414019AF795567974940
28842	Гоголевка	1	8	740	35.167668999999997	35.187899000000002	51.189157999999999	51.173484999999999	0103000020E61000000100000005000000C9C6832D769541405CACA8C134964940C9C6832D769541406DE34F5436984940BEF90D130D9841406DE34F5436984940BEF90D130D9841405CACA8C134964940C9C6832D769541405CACA8C134964940
27980	Воробжа	1	8	740	35.478431999999998	35.495598999999999	51.165996	51.157060000000001	0103000020E6100000010000000500000010AE80423DBD414040C1C58A1A94494010AE80423DBD414027A25F5B3F9549401477BCC96FBF414027A25F5B3F9549401477BCC96FBF414040C1C58A1A94494010AE80423DBD414040C1C58A1A944940
5197	Борки	1	8	740	35.394798999999999	35.432510000000001	51.112766999999998	51.085278000000002	0103000020E610000001000000050000002BBF0CC688B24140BE88B663EA8A49402BBF0CC688B24140B58828266F8E4940B398D87C5CB74140B58828266F8E4940B398D87C5CB74140BE88B663EA8A49402BBF0CC688B24140BE88B663EA8A4940
27740	Шумаково	1	8	1660	36.625042000000001	36.698056999999999	51.527348000000003	51.494259999999997	0103000020E610000001000000050000002F5052600150424048DC63E943BF49402F5052600150424036CEA62380C3494037DF88EE5959424036CEA62380C3494037DF88EE5959424048DC63E943BF49402F5052600150424048DC63E943BF4940
54558	Шлях	1	8	1660	36.58963	36.597921999999997	51.339708000000002	51.328234000000002	0103000020E61000000100000005000000C85EEFFE784B4240B7B75B9203AA4940C85EEFFE784B424044183F8D7BAB49408AC745B5884C424044183F8D7BAB49408AC745B5884C4240B7B75B9203AA4940C85EEFFE784B4240B7B75B9203AA4940
27236	Чермошное	1	8	1660	36.539450000000002	36.605207	51.399883000000003	51.353366999999999	0103000020E61000000100000005000000E2E995B20C454240293E3E213BAD4940E2E995B20C454240FA9CBB5D2FB34940B727486C774D4240FA9CBB5D2FB34940B727486C774D4240293E3E213BAD4940E2E995B20C454240293E3E213BAD4940
26283	Хахилево	1	8	1660	36.703321000000003	36.714855	51.582653999999998	51.572578999999998	0103000020E6100000010000000500000086CB2A6C065A42402DB0C7444AC9494086CB2A6C065A42401971016894CA4940E8305F5E805B42401971016894CA4940E8305F5E805B42402DB0C7444AC9494086CB2A6C065A42402DB0C7444AC94940
26774	Толмачевка	1	8	1660	36.771701	36.814155	51.585675999999999	51.572965000000003	0103000020E610000001000000050000002FA52E19C76242405760C8EA56C949402FA52E19C7624240AB06616EF7CA4940FC6F253B36684240AB06616EF7CA4940FC6F253B366842405760C8EA56C949402FA52E19C76242405760C8EA56C94940
27427	Субботино	1	8	1660	36.865772	36.884780999999997	51.441721000000001	51.406491000000003	0103000020E6100000010000000500000071E5EC9DD16E4240268FA7E507B4494071E5EC9DD16E42406C7A50508AB84940A38FF980407142406C7A50508AB84940A38FF98040714240268FA7E507B4494071E5EC9DD16E4240268FA7E507B44940
26665	Солнцево	1	8	1660	36.720928000000001	36.782992999999998	51.431956999999997	51.389684000000003	0103000020E61000000100000005000000A662635E475C424022E3512AE1B14940A662635E475C42409E23F25D4AB749409BFF571D396442409E23F25D4AB749409BFF571D3964424022E3512AE1B14940A662635E475C424022E3512AE1B14940
27512	Сеймица	1	8	1660	36.861514	36.895336	51.374887999999999	51.359357000000003	0103000020E61000000100000005000000E8853B17466E42405A4B0169FFAD4940E8853B17466E4240D8D47954FCAF49403A77BB5E9A724240D8D47954FCAF49403A77BB5E9A7242405A4B0169FFAD4940E8853B17466E42405A4B0169FFAD4940
26972	Сараевка	1	8	1660	36.819840999999997	36.852504000000003	51.320489000000002	51.283498000000002	0103000020E61000000100000005000000C075C58CF06842409F3D97A949A44940C075C58CF068424027DD96C805A94940C7DADFD91E6D424027DD96C805A94940C7DADFD91E6D42409F3D97A949A44940C075C58CF06842409F3D97A949A44940
54522	Ржаво-Плота	1	8	1660	36.758603000000001	36.77948	51.355336000000001	51.330322000000002	0103000020E61000000100000005000000E1D231E7196142401D93C5FD47AA4940E1D231E719614240B58B69A67BAD49406BF12900C6634240B58B69A67BAD49406BF12900C66342401D93C5FD47AA4940E1D231E7196142401D93C5FD47AA4940
27691	Плоское	1	8	1660	36.576991	36.624538999999999	51.554181	51.525835999999998	0103000020E610000001000000050000000D8B51D7DA4942409C8713984EC349400D8B51D7DA49424044882B67EFC64940CC09DAE4F04F424044882B67EFC64940CC09DAE4F04F42409C8713984EC349400D8B51D7DA4942409C8713984EC34940
27566	Орлянка	1	8	1660	36.903807	36.991607999999999	51.372374999999998	51.359323000000003	0103000020E61000000100000005000000AC72A1F2AF734240AED9CA4BFEAD4940AC72A1F2AF7342408B6CE7FBA9AF4940DA39CD02ED7E42408B6CE7FBA9AF4940DA39CD02ED7E4240AED9CA4BFEAD4940AC72A1F2AF734240AED9CA4BFEAD4940
54552	Малиновка	1	8	1660	36.521079999999998	36.829039999999999	51.469109000000003	51.333793999999997	0103000020E61000000100000005000000C24CDBBFB2424240EECC04C3B9AA4940C24CDBBFB242424030A182C30BBC4940B58993FB1D6A424030A182C30BBC4940B58993FB1D6A4240EECC04C3B9AA4940C24CDBBFB2424240EECC04C3B9AA4940
27092	Княжая	1	8	1660	36.799396000000002	36.823920000000001	51.409356000000002	51.393853999999997	0103000020E61000000100000005000000D046AE9B526642400BB3D0CE69B24940D046AE9B52664240F03504C765B449409A42E73576694240F03504C765B449409A42E735766942400BB3D0CE69B24940D046AE9B526642400BB3D0CE69B24940
27146	Ивановка	1	8	1660	36.701146999999999	36.742055999999998	51.446936000000001	51.416580000000003	0103000020E610000001000000050000002158552FBF5942407715527E52B549402158552FBF594240D9B3E73235B9494079E6E5B0FB5E4240D9B3E73235B9494079E6E5B0FB5E42407715527E52B549402158552FBF5942407715527E52B54940
27017	Зуевка	1	8	1660	36.754426000000002	36.781807000000001	51.404766000000002	51.378515	0103000020E6100000010000000500000045A0FA0791604240D105F52D73B0494045A0FA079160424031444E5FCFB34940566474401264424031444E5FCFB349405664744012644240D105F52D73B0494045A0FA0791604240D105F52D73B04940
27342	Ефросимовка	1	8	1660	36.875293999999997	36.889460999999997	51.552601000000003	51.542206	0103000020E61000000100000005000000483140A209704240F5D8960167C54940483140A209704240535E2BA1BBC64940A208A9DBD9714240535E2BA1BBC64940A208A9DBD9714240F5D8960167C54940483140A209704240F5D8960167C54940
27154	Дорохо-Доренское	1	8	1660	36.693340999999997	36.707444000000002	51.478231000000001	51.467453999999996	0103000020E61000000100000005000000EBFCDB65BF58424033315D88D5BB4940EBFCDB65BF584240797764AC36BD49402FE065868D5A4240797764AC36BD49402FE065868D5A424033315D88D5BB4940EBFCDB65BF58424033315D88D5BB4940
21233	Доброе	1	8	1660	36.702441	36.719796000000002	51.640160000000002	51.624524000000001	0103000020E610000001000000050000004D2F3196E959424097C80567F0CF49404D2F3196E95942408B1A4CC3F0D1494054E57B46225C42408B1A4CC3F0D1494054E57B46225C424097C80567F0CF49404D2F3196E959424097C80567F0CF4940
26896	Дежевка	1	8	1660	36.798174000000003	36.826193000000004	51.360818999999999	51.345936000000002	0103000020E610000001000000050000003E42CD902A66424029417FA147AC49403E42CD902A664240416326512FAE4940929735B1C0694240416326512FAE4940929735B1C069424029417FA147AC49403E42CD902A66424029417FA147AC4940
26879	Гридасово	1	8	1660	36.713337000000003	36.761432999999997	51.500315000000001	51.448497000000003	0103000020E610000001000000050000006D0377A04E5B424054AD855968B949406D0377A04E5B4240605969520AC049402E8CF4A276614240605969520AC049402E8CF4A27661424054AD855968B949406D0377A04E5B424054AD855968B94940
27315	Гололобовка	1	8	1660	36.907966000000002	36.961244999999998	51.54965	51.518555999999997	0103000020E61000000100000005000000A2F0D93A387442408192020B60C24940A2F0D93A387442408A1F63EE5AC64940C5387F130A7B42408A1F63EE5AC64940C5387F130A7B42408192020B60C24940A2F0D93A387442408192020B60C24940
22851	Выползово	1	8	1660	36.720253999999997	36.743502999999997	51.501565999999997	51.480682000000002	0103000020E6100000010000000500000016687748315C424050E3DEFC86BD494016687748315C42408C648F5033C049402BBD361B2B5F42408C648F5033C049402BBD361B2B5F424050E3DEFC86BD494016687748315C424050E3DEFC86BD4940
27589	Воробьевка	1	8	1660	36.452925	36.474474999999998	51.457785000000001	51.436225	0103000020E6100000010000000500000039454772F93942404B598638D6B7494039454772F9394240B8CCE9B298BA494082E2C798BB3C4240B8CCE9B298BA494082E2C798BB3C42404B598638D6B7494039454772F93942404B598638D6B74940
25290	Бунино	1	8	1660	36.653869	36.715986999999998	51.569879999999998	51.522832000000001	0103000020E61000000100000005000000226FB9FAB1534240B1A6B228ECC24940226FB9FAB15342407E52EDD3F1C849403AAE4676A55B42407E52EDD3F1C849403AAE4676A55B4240B1A6B228ECC24940226FB9FAB1534240B1A6B228ECC24940
27424	Большая Козьмодемьяновка	1	8	1660	36.881932999999997	36.907004999999998	51.482483000000002	51.439368999999999	0103000020E61000000100000005000000AF21382EE370424028F04E3E3DB84940AF21382EE370424020F0C000C2BD49407C2766BD1874424020F0C000C2BD49407C2766BD1874424028F04E3E3DB84940AF21382EE370424028F04E3E3DB84940
26724	Афанасьевка	1	8	1660	36.790546999999997	36.832093999999998	51.597324999999998	51.585535999999998	0103000020E61000000100000005000000B779E3A430654240B950F9D7F2CA4940B779E3A430654240A60A462575CC49405299620E826A4240A60A462575CC49405299620E826A4240B950F9D7F2CA4940B779E3A430654240B950F9D7F2CA4940
25616	имени Пушкина	1	8	737	37.700252999999996	37.722234999999998	51.802714000000002	51.789785999999999	0103000020E6100000010000000500000083F6EAE3A1D94240596B28B517E5494083F6EAE3A1D942404B051555BFE6494066834C3272DC42404B051555BFE6494066834C3272DC4240596B28B517E5494083F6EAE3A1D94240596B28B517E54940
26348	Садовый	1	8	737	37.784587000000002	37.805635000000002	51.965007999999997	51.955151000000001	0103000020E61000000100000005000000F2EEC8586DE44240F0DE516342FA4940F2EEC8586DE442406E30D46185FB4940A9C1340C1FE742406E30D46185FB4940A9C1340C1FE74240F0DE516342FA4940F2EEC8586DE44240F0DE516342FA4940
26063	Расховецкий	1	8	737	37.404555000000002	37.433022000000001	51.901676000000002	51.887931000000002	0103000020E6100000010000000500000076374F75C8B34240630D17B9A7F1494076374F75C8B3424047CB811E6AF349406939D0436DB7424047CB811E6AF349406939D0436DB74240630D17B9A7F1494076374F75C8B34240630D17B9A7F14940
26014	Расховец	1	8	737	37.446945999999997	37.487684999999999	51.91536	51.900931	0103000020E61000000100000005000000FC89CA8635B94240EE79FEB451F34940FC89CA8635B94240850838842AF54940F8DF4A766CBE4240850838842AF54940F8DF4A766CBE4240EE79FEB451F34940FC89CA8635B94240EE79FEB451F34940
25069	Подгородище 1-е	1	8	737	37.568713000000002	37.587811000000002	51.692681	51.651349000000003	0103000020E61000000100000005000000B0E76B96CBC8424023A46E675FD34940B0E76B96CBC84240C1C760C5A9D84940529D0E643DCB4240C1C760C5A9D84940529D0E643DCB424023A46E675FD34940B0E76B96CBC8424023A46E675FD34940
26627	Петрово-Карцево	1	8	737	37.746346000000003	37.791935000000002	51.917248999999998	51.903587000000002	0103000020E610000001000000050000000EC0064488DF42409E0B23BDA8F349400EC0064488DF4240F4A44C6A68F5494065C746205EE54240F4A44C6A68F5494065C746205EE542409E0B23BDA8F349400EC0064488DF42409E0B23BDA8F34940
25876	Перцевка	1	8	737	37.542985000000002	37.586328999999999	51.911838000000003	51.896140000000003	0103000020E61000000100000005000000FA9B508880C5424098512CB7B4F24940FA9B508880C5424002A08A1BB7F4494023D923D40CCB424002A08A1BB7F4494023D923D40CCB424098512CB7B4F24940FA9B508880C5424098512CB7B4F24940
25955	Переволочное	1	8	737	37.444412999999997	37.504500999999998	51.857675999999998	51.836295	0103000020E6100000010000000500000068757286E2B842407767EDB60BEB494068757286E2B842403448C153C8ED49404FE61F7D93C042403448C153C8ED49404FE61F7D93C042407767EDB60BEB494068757286E2B842407767EDB60BEB4940
25696	Октябрьское	1	8	737	37.567140999999999	37.611499999999999	51.809089999999998	51.796926999999997	0103000020E61000000100000005000000419C871398C84240522635B401E64940419C871398C84240A4C2D84290E7494083C0CAA145CE4240A4C2D84290E7494083C0CAA145CE4240522635B401E64940419C871398C84240522635B401E64940
26470	Нижняя Грайворонка	1	8	737	37.756461000000002	37.789707999999997	51.814824999999999	51.777500000000003	0103000020E6100000010000000500000088D9CBB6D3E04240EC51B81E85E3494088D9CBB6D3E042404A7B832F4CE84940DDB1D82615E542404A7B832F4CE84940DDB1D82615E54240EC51B81E85E3494088D9CBB6D3E04240EC51B81E85E34940
25517	Нижнее Гурово	1	8	737	37.600054999999998	37.701017	51.945720000000001	51.918421000000002	0103000020E6100000010000000500000090662C9ACECC4240D57ABFD18EF5494090662C9ACECC424029965B5A0DF949405378D0ECBAD9424029965B5A0DF949405378D0ECBAD94240D57ABFD18EF5494090662C9ACECC4240D57ABFD18EF54940
26369	Натальино	1	8	737	37.79101	37.815911	51.775606000000003	51.752918999999999	0103000020E610000001000000050000008C67D0D03FE54240BDC458A65FE049408C67D0D03FE542406B4AB20E47E349402CB98AC56FE842406B4AB20E47E349402CB98AC56FE84240BDC458A65FE049408C67D0D03FE54240BDC458A65FE04940
25397	Моздовка	1	8	737	37.713872000000002	37.738844999999998	51.941434000000001	51.923209	0103000020E61000000100000005000000DBC35E2860DB4240BA2F67B62BF64940DBC35E2860DB4240D6ABC8E880F8494014E8137992DE4240D6ABC8E880F8494014E8137992DE4240BA2F67B62BF64940DBC35E2860DB4240BA2F67B62BF64940
54535	Михайло-Анненка	1	8	737	37.722971999999999	37.759757999999998	51.964269000000002	51.917149000000002	0103000020E610000001000000050000003CF6B3588ADC42409147702365F549403CF6B3588ADC4240F8C5A52A6DFB4940EB6F09C03FE14240F8C5A52A6DFB4940EB6F09C03FE142409147702365F549403CF6B3588ADC42409147702365F54940
25503	Мелехово	1	8	737	37.636750999999997	37.685153	51.888897999999998	51.870868000000002	0103000020E61000000100000005000000FF58880E81D142400491459A78EF4940FF58880E81D142406ABDDF68C7F14940CEE0EF17B3D742406ABDDF68C7F14940CEE0EF17B3D742400491459A78EF4940FF58880E81D142400491459A78EF4940
26108	Мансурово	1	8	737	37.428018999999999	37.460178999999997	51.782443000000001	51.761342999999997	0103000020E6100000010000000500000087889B53C9B64240EE04FBAF73E1494087889B53C9B64240F8FD9B1727E449402AA73D25E7BA4240F8FD9B1727E449402AA73D25E7BA4240EE04FBAF73E1494087889B53C9B64240EE04FBAF73E14940
25447	Липовчик	1	8	737	37.662334999999999	37.698897000000002	51.848101999999997	51.828698000000003	0103000020E6100000010000000500000082FFAD64C7D442405C21ACC612EA494082FFAD64C7D442400AD6389B8EEC4940E222F77475D942400AD6389B8EEC4940E222F77475D942405C21ACC612EA494082FFAD64C7D442405C21ACC612EA4940
25757	Ледовское	1	8	737	37.545222000000003	37.600485999999997	51.993009999999998	51.959024999999997	0103000020E61000000100000005000000A587A1D5C9C54240F085C954C1FA4940A587A1D5C9C54240EC4CA1F31AFF494059DAA9B9DCCC4240EC4CA1F31AFF494059DAA9B9DCCC4240F085C954C1FA4940A587A1D5C9C54240F085C954C1FA4940
5153	Кшенский	1	8	737	37.690758000000002	37.739652999999997	51.864879000000002	51.824278	0103000020E61000000100000005000000A6B915C26AD84240F96706F181E94940A6B915C26AD84240A4FFE55AB4EE4940B3B112F3ACDE4240A4FFE55AB4EE4940B3B112F3ACDE4240F96706F181E94940A6B915C26AD84240F96706F181E94940
26172	Крестище	1	8	737	37.535781	37.585368000000003	51.786315000000002	51.745536999999999	0103000020E61000000100000005000000BA68C87894C442409E7AA4C16DDF4940BA68C87894C4424058AD4CF8A5E44940FE0FB056EDCA424058AD4CF8A5E44940FE0FB056EDCA42409E7AA4C16DDF4940BA68C87894C442409E7AA4C16DDF4940
25600	Красная Долина	1	8	737	37.656056	37.699354999999997	51.803995	51.758740000000003	0103000020E610000001000000050000001B2C9CA4F9D3424062156F641EE149401B2C9CA4F9D34240E292E34EE9E64940A4A5F27684D94240E292E34EE9E64940A4A5F27684D9424062156F641EE149401B2C9CA4F9D3424062156F641EE14940
26581	Коммунар	1	8	737	37.745770999999998	37.751277999999999	51.863222	51.860697000000002	0103000020E6100000010000000500000011A7936C75DF4240F661BD512BEE494011A7936C75DF42400798F90E7EEE4940261AA4E029E042400798F90E7EEE4940261AA4E029E04240F661BD512BEE494011A7936C75DF4240F661BD512BEE4940
26261	Кирилловка	1	8	737	37.726852000000001	37.763314999999999	51.977746000000003	51.971204999999998	0103000020E610000001000000050000001F84807C09DD4240185B087250FC49401F84807C09DD4240BDE5EAC726FD4940EBC5504EB4E14240BDE5EAC726FD4940EBC5504EB4E14240185B087250FC49401F84807C09DD4240185B087250FC4940
25100	Каменогорка	1	8	737	37.501913999999999	37.527121000000001	51.722534000000003	51.694859000000001	0103000020E61000000100000005000000C8B3CBB73EC04240672AC423F1D84940C8B3CBB73EC04240C11F7EFE7BDC4940750470B378C34240C11F7EFE7BDC4940750470B378C34240672AC423F1D84940C8B3CBB73EC04240672AC423F1D84940
25919	Имени Ленина	1	8	737	37.535564999999998	37.569538999999999	51.878780999999996	51.857142000000003	0103000020E61000000100000005000000EDF0D7648DC4424097033DD4B6ED4940EDF0D7648DC442404FAC53E57BF04940F56569A7E6C842404FAC53E57BF04940F56569A7E6C8424097033DD4B6ED4940EDF0D7648DC4424097033DD4B6ED4940
6529	Ефросимовка	1	8	737	37.510582999999997	37.553612000000001	51.617573999999998	51.594019000000003	0103000020E610000001000000050000006072A3C85AC14240F01989D008CC49406072A3C85AC14240116E32AA0CCF49402A560DC2DCC64240116E32AA0CCF49402A560DC2DCC64240F01989D008CC49406072A3C85AC14240F01989D008CC4940
26550	Дицево	1	8	737	37.728541	37.746993000000003	51.875622999999997	51.870435000000001	0103000020E61000000100000005000000C765DCD440DD42409A25016A6AEF4940C765DCD440DD42400D501A6A14F04940A4AB74779DDF42400D501A6A14F04940A4AB74779DDF42409A25016A6AEF4940C765DCD440DD42409A25016A6AEF4940
24989	Грязное	1	8	737	37.631208999999998	37.666691999999998	51.707372999999997	51.664389	0103000020E610000001000000050000006EF8DD74CBD042403C69E1B20AD549406EF8DD74CBD042406589CE328BDA49409E40D82956D542406589CE328BDA49409E40D82956D542403C69E1B20AD549406EF8DD74CBD042403C69E1B20AD54940
25011	Городище	1	8	737	37.575684000000003	37.61591	51.716563999999998	51.694473000000002	0103000020E610000001000000050000004D6A6803B0C942403E7AC37DE4D849404D6A6803B0C94240D7BE805EB8DB4940C2A38D23D6CE4240D7BE805EB8DB4940C2A38D23D6CE42403E7AC37DE4D849404D6A6803B0C942403E7AC37DE4D84940
25329	Голощаповка	1	8	737	37.696229000000002	37.723779999999998	51.889726000000003	51.869745000000002	0103000020E610000001000000050000006EC328081ED94240056EDDCD53EF49406EC328081ED942405133A48AE2F14940DBBFB2D2A4DC42405133A48AE2F14940DBBFB2D2A4DC4240056EDDCD53EF49406EC328081ED94240056EDDCD53EF4940
25232	Волжанец	1	8	737	37.682467000000003	37.721938999999999	51.868671999999997	51.847279	0103000020E61000000100000005000000B4CC22145BD7424036CB65A373EC4940B4CC22145BD74240B779E3A430EF49407D5A457F68DC4240B779E3A430EF49407D5A457F68DC424036CB65A373EC4940B4CC22145BD7424036CB65A373EC4940
25186	Верхние Апочки	1	8	737	37.592249000000002	37.638098999999997	51.609811000000001	51.562092999999997	0103000020E610000001000000050000005B0BB3D0CECB4240BF27D6A9F2C749405B0BB3D0CECB4240DBDE6E490ECE49401E4E603AADD14240DBDE6E490ECE49401E4E603AADD14240BF27D6A9F2C749405B0BB3D0CECB4240BF27D6A9F2C74940
26449	Васильевка 2-я	1	8	737	37.734631999999998	37.770726000000003	51.847056000000002	51.815041999999998	0103000020E610000001000000050000002B4CDF6B08DE4240E76ED74B53E849402B4CDF6B08DE4240B7F0BC546CEC4940A5164A26A7E24240B7F0BC546CEC4940A5164A26A7E24240E76ED74B53E849402B4CDF6B08DE4240E76ED74B53E84940
26104	Бородаевка	1	8	737	37.383012999999998	37.424596000000001	51.748190999999998	51.701439999999998	0103000020E61000000100000005000000AF78EA9106B14240990D32C9C8D94940AF78EA9106B14240AD1402B9C4DF49409701672959B64240AD1402B9C4DF49409701672959B64240990D32C9C8D94940AF78EA9106B14240990D32C9C8D94940
25738	Березовчик	1	8	737	37.641458999999998	37.676186999999999	51.830807	51.811551000000001	0103000020E61000000100000005000000C85C19541BD242409F0436E7E0E74940C85C19541BD24240D9243FE257EA49407C7DAD4B8DD64240D9243FE257EA49407C7DAD4B8DD642409F0436E7E0E74940C85C19541BD242409F0436E7E0E74940
24944	Александровка	1	8	737	37.739797000000003	37.765821000000003	52.005065000000002	51.997064000000002	0103000020E61000000100000005000000E75608ABB1DE42406D020CCB9FFF4940E75608ABB1DE424058AD4CF8A5004A4086CB2A6C06E2424058AD4CF8A5004A4086CB2A6C06E242406D020CCB9FFF4940E75608ABB1DE42406D020CCB9FFF4940
24750	Щекино	1	8	720	34.481409999999997	34.508800000000001	51.557383999999999	51.545510999999998	0103000020E61000000100000005000000D2FBC6D79E3D4140DB4DF04DD3C54940D2FBC6D79E3D414026A8E15B58C74940371AC05B2041414026A8E15B58C74940371AC05B20414140DB4DF04DD3C54940D2FBC6D79E3D4140DB4DF04DD3C54940
23225	Учительский	1	8	720	34.976975000000003	34.993414000000001	51.568179000000001	51.558267999999998	0103000020E610000001000000050000003B014D840D7D4140A033695375C749403B014D840D7D414012A3E716BAC84940BCB1A030287F414012A3E716BAC84940BCB1A030287F4140A033695375C749403B014D840D7D4140A033695375C74940
23940	Сухая	1	8	720	34.610004000000004	34.630988000000002	51.450527999999998	51.406311000000002	0103000020E61000000100000005000000F0366F9C144E4140A680B4FF01B44940F0366F9C144E414055F7C8E6AAB949409015FC36C450414055F7C8E6AAB949409015FC36C4504140A680B4FF01B44940F0366F9C144E4140A680B4FF01B44940
24601	Студенок	1	8	720	34.127904999999998	34.362077999999997	51.689337000000002	51.551425000000002	0103000020E6100000010000000500000058FFE7305F10414031992A1895C6494058FFE7305F1041401D76DF313CD84940F04C6892582E41401D76DF313CD84940F04C6892582E414031992A1895C6494058FFE7305F10414031992A1895C64940
24392	Степановка	1	8	720	34.861100999999998	34.907570999999997	51.585966999999997	51.572338000000002	0103000020E61000000100000005000000C5C6BC8E386E41400821205F42C94940C5C6BC8E386E414082C476F700CB494025E659492B74414082C476F700CB494025E659492B7441400821205F42C94940C5C6BC8E386E41400821205F42C94940
5088	Семеново	1	8	720	34.695388999999999	34.719777999999998	51.497287999999998	51.484848999999997	0103000020E61000000100000005000000C37FBA8102594140C83F33880FBE4940C37FBA8102594140BC581822A7BF4940AD307DAF215C4140BC581822A7BF4940AD307DAF215C4140C83F33880FBE4940C37FBA8102594140C83F33880FBE4940
23633	Свобода	1	8	720	34.454774999999998	34.488892999999997	51.453301000000003	51.436163000000001	0103000020E61000000100000005000000EA043411363A4140D55C6E30D4B74940EA043411363A41403F1F65C405BA4940251FBB0B943E41403F1F65C405BA4940251FBB0B943E4140D55C6E30D4B74940EA043411363A4140D55C6E30D4B74940
22418	Рыльск	1	8	720	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
40354	Рыльск	1	8	720	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
23410	Рыжевка	1	8	720	34.305134000000002	34.335298999999999	51.669120999999997	51.629779999999997	0103000020E61000000100000005000000E77283A10E27414062D68BA19CD04940E77283A10E2741408D08C6C1A5D54940D5B0DF13EB2A41408D08C6C1A5D54940D5B0DF13EB2A414062D68BA19CD04940E77283A10E27414062D68BA19CD04940
24293	Поповка	1	8	720	34.424987000000002	34.673065999999999	51.739435999999998	51.51558	0103000020E61000000100000005000000D21C59F965364140603C8386FEC14940D21C59F96536414016BEBED6A5DE49405706D5062756414016BEBED6A5DE49405706D50627564140603C8386FEC14940D21C59F965364140603C8386FEC14940
24362	Октябрьское	1	8	720	34.782587999999997	34.814639999999997	51.58708	51.569521999999999	0103000020E61000000100000005000000FB1EF5D72B6441401F2DCE18E6C84940FB1EF5D72B6441405E11FC6F25CB4940B8019F1F466841405E11FC6F25CB4940B8019F1F466841401F2DCE18E6C84940FB1EF5D72B6441401F2DCE18E6C84940
24076	Нехаевка	1	8	720	34.436602000000001	34.462617000000002	51.691603999999998	51.668427999999999	0103000020E6100000010000000500000021AF0793E237414087DD770C8FD5494021AF0793E237414032E4D87A86D849406DC9AA08373B414032E4D87A86D849406DC9AA08373B414087DD770C8FD5494021AF0793E237414087DD770C8FD54940
23780	Михайловка	1	8	720	34.437806000000002	34.482855999999998	51.628701	51.605342	0103000020E610000001000000050000000DFFE9060A3841409772BED87BCD49400DFFE9060A38414033FB3C4679D04940B456B439CE3D414033FB3C4679D04940B456B439CE3D41409772BED87BCD49400DFFE9060A3841409772BED87BCD4940
24168	Макеево	1	8	720	34.527377000000001	34.550490000000003	51.686618000000003	51.663423000000002	0103000020E61000000100000005000000D0D4EB168143414005357C0BEBD44940D0D4EB1681434140276C3F19E3D749403563D17476464140276C3F19E3D749403563D1747646414005357C0BEBD44940D0D4EB168143414005357C0BEBD44940
24468	Мазеповка	1	8	720	34.822679999999998	34.850447000000003	51.618473999999999	51.607847999999997	0103000020E61000000100000005000000618907944D694140317898F6CDCD4940618907944D69414091B6F1272ACF49409CFD8172DB6C414091B6F1272ACF49409CFD8172DB6C4140317898F6CDCD4940618907944D694140317898F6CDCD4940
23402	Локоть	1	8	720	34.187499000000003	34.260936000000001	51.678497999999998	51.656266000000002	0103000020E6100000010000000500000030849CF7FF17414006BD378600D4494030849CF7FF1741406133C005D9D64940AE2CD159662141406133C005D9D64940AE2CD1596621414006BD378600D4494030849CF7FF17414006BD378600D44940
23035	Кулига	1	8	720	34.559266999999998	34.576864999999998	51.576413000000002	51.563470000000002	0103000020E61000000100000005000000B35DA10F964741407923F3C81FC84940B35DA10F96474140A0FEB3E6C7C94940809A5AB6D6494140A0FEB3E6C7C94940809A5AB6D64941407923F3C81FC84940B35DA10F964741407923F3C81FC84940
22940	Кострова	1	8	720	34.669257000000002	34.692622	51.663451000000002	51.650638999999998	0103000020E610000001000000050000003ECF9F36AA5541404640852348D349403ECF9F36AA554140CFBF5DF6EBD44940BC3E73D6A7584140CFBF5DF6EBD44940BC3E73D6A75841404640852348D349403ECF9F36AA5541404640852348D34940
23324	Козино	1	8	720	34.184821999999997	34.220089999999999	51.645547999999998	51.619849000000002	0103000020E6100000010000000500000068CA4E3FA8174140AABA473657CF494068CA4E3FA8174140C5FF1D51A1D249409C16BCE82B1C4140C5FF1D51A1D249409C16BCE82B1C4140AABA473657CF494068CA4E3FA8174140AABA473657CF4940
22951	Капыстичи	1	8	720	34.815961000000001	34.873480000000001	51.712372999999999	51.674934999999998	0103000020E61000000100000005000000DEE7F868716841407FF6234564D64940DEE7F86871684140D6C6D8092FDB4940E4DA5031CE6F4140D6C6D8092FDB4940E4DA5031CE6F41407FF6234564D64940DEE7F868716841407FF6234564D64940
23701	Имени Куйбышева	1	8	720	34.708100000000002	34.746125999999997	51.510361000000003	51.498851999999999	0103000020E6100000010000000500000018265305A35A4140A8C5E061DABF494018265305A35A4140B2135E8253C14940FF58880E815F4140B2135E8253C14940FF58880E815F4140A8C5E061DABF494018265305A35A4140A8C5E061DABF4940
54534	Ивановское	1	8	720	34.893287999999998	34.979624999999999	51.635173999999999	51.592933000000002	0103000020E6100000010000000500000062F4DC42577241400EDC813AE5CB494062F4DC42577241407FA2B2614DD1494008AC1C5A647D41407FA2B2614DD1494008AC1C5A647D41400EDC813AE5CB494062F4DC42577241400EDC813AE5CB4940
23129	Ивановское	1	8	720	34.893287999999998	34.979624999999999	51.635173999999999	51.592933000000002	0103000020E6100000010000000500000062F4DC42577241400EDC813AE5CB494062F4DC42577241407FA2B2614DD1494008AC1C5A647D41407FA2B2614DD1494008AC1C5A647D41400EDC813AE5CB494062F4DC42577241400EDC813AE5CB4940
23049	Дурово	1	8	720	34.516255999999998	34.548802000000002	51.513226000000003	51.494281999999998	0103000020E61000000100000005000000902E36AD144241403080F0A144BF4940902E36AD144241407CBABA63B1C149405DFDD8243F4641407CBABA63B1C149405DFDD8243F4641403080F0A144BF4940902E36AD144241403080F0A144BF4940
23495	Воронок	1	8	720	34.275075999999999	34.319327000000001	51.618848999999997	51.604177999999997	0103000020E610000001000000050000000EF5BBB035234140397B67B455CD49400EF5BBB035234140C614AC7136CF49406ADD06B5DF284140C614AC7136CF49406ADD06B5DF284140397B67B455CD49400EF5BBB035234140397B67B455CD4940
23905	Большенизовцево	1	8	720	34.600006	34.634878	51.496395999999997	51.470506	0103000020E61000000100000005000000AFB321FFCC4C41403049658A39BC4940AFB321FFCC4C4140BFEE74E789BF49409679ABAE43514140BFEE74E789BF49409679ABAE435141403049658A39BC4940AFB321FFCC4C41403049658A39BC4940
24263	Большегнеушево	1	8	720	34.52655	34.561844999999998	51.725434999999997	51.706921000000001	0103000020E61000000100000005000000BADA8AFD6543414085ED27637CDA4940BADA8AFD65434140D72FD80DDBDC4940E7357689EA474140D72FD80DDBDC4940E7357689EA47414085ED27637CDA4940BADA8AFD6543414085ED27637CDA4940
22867	Березники	1	8	720	34.780225999999999	34.794105000000002	51.618769999999998	51.611404999999998	0103000020E6100000010000000500000094BE1072DE63414031CEDF8442CE494094BE1072DE6341407ADFF8DA33CF4940884B8E3BA56541407ADFF8DA33CF4940884B8E3BA565414031CEDF8442CE494094BE1072DE63414031CEDF8442CE4940
24087	Бегоща	1	8	720	34.338290000000001	34.382218000000002	51.694350999999997	51.671495	0103000020E610000001000000050000002C4833164D2B4140B936548CF3D549402C4833164D2B4140F2785A7EE0D84940A5F8F884EC304140F2785A7EE0D84940A5F8F884EC304140B936548CF3D549402C4833164D2B4140B936548CF3D54940
23853	Артюшково	1	8	720	34.775779	34.804507000000001	51.457926	51.443303999999998	0103000020E6100000010000000500000038F6ECB94C634140CE177B2FBEB8494038F6ECB94C6341407AFEB4519DBA49409833DB15FA6641407AFEB4519DBA49409833DB15FA664140CE177B2FBEB8494038F6ECB94C634140CE177B2FBEB84940
24722	Анатольевка	1	8	720	34.317126000000002	34.340150000000001	51.496245000000002	51.485095999999999	0103000020E610000001000000050000000C5BB39597284140D0B52FA017BE49400C5BB39597284140DAE6C6F484BF494001DE02098A2B4140DAE6C6F484BF494001DE02098A2B4140D0B52FA017BE49400C5BB39597284140D0B52FA017BE4940
54518	Александровка	1	8	720	34.361744999999999	34.381022999999999	51.599429000000001	51.572819000000003	0103000020E61000000100000005000000EA3E00A94D2E414083C30B2252C94940EA3E00A94D2E414012A3E716BACC49400C03965CC530414012A3E716BACC49400C03965CC530414083C30B2252C94940EA3E00A94D2E414083C30B2252C94940
24669	Акимовка	1	8	720	34.362544999999997	34.426667000000002	51.523156999999998	51.495049999999999	0103000020E61000000100000005000000062AE3DF672E414041F163CC5DBF4940062AE3DF672E414034D6FECEF6C2494027A435069D36414034D6FECEF6C2494027A435069D36414041F163CC5DBF4940062AE3DF672E414041F163CC5DBF4940
24181	1-е Яньково	1	8	720	34.583342000000002	34.605279000000003	51.634464000000001	51.620793999999997	0103000020E610000001000000050000000E315EF3AA4A4140C9C6832D76CF49400E315EF3AA4A4140A33EC91D36D1494051FA42C8794D4140A33EC91D36D1494051FA42C8794D4140C9C6832D76CF49400E315EF3AA4A4140C9C6832D76CF4940
21994	Ярыгино	1	8	859	36.691597999999999	36.732813	51.215237000000002	51.195473999999997	0103000020E6100000010000000500000050FD834886584240F19BC24A0599494050FD834886584240D0F1D1E28C9B4940B58AFED0CC5D4240D0F1D1E28C9B4940B58AFED0CC5D4240F19BC24A0599494050FD834886584240F19BC24A05994940
21667	Черновец	1	8	859	36.943413999999997	36.959600999999999	51.276111999999998	51.236372000000003	0103000020E61000000100000005000000554B3ACAC178424056D80C70419E4940554B3ACAC17842403E0455A357A34940BD1AA034D47A42403E0455A357A34940BD1AA034D47A424056D80C70419E4940554B3ACAC178424056D80C70419E4940
21025	Троицкое	1	8	859	36.472740999999999	37.014183000000003	51.245010999999998	51.186121	0103000020E610000001000000050000003A3DEFC6823C4240A60C1CD0D29749403A3DEFC6823C424083143C855C9F49406094A0BFD081424083143C855C9F49406094A0BFD0814240A60C1CD0D29749403A3DEFC6823C4240A60C1CD0D2974940
21959	Средняя Ольшанка	1	8	859	36.565358000000003	36.614280000000001	51.167973000000003	51.127529000000003	0103000020E610000001000000050000001844A4A65D4842405325CADE529049401844A4A65D48424036CEA623809549401F4B1FBAA04E424036CEA623809549401F4B1FBAA04E42405325CADE529049401844A4A65D4842405325CADE52904940
21162	Сазановка	1	8	859	36.917264000000003	36.970022	51.355319000000001	51.327975000000002	0103000020E610000001000000050000002AE620E868754240EB73B515FBA949402AE620E868754240DF52CE177BAD494044334FAE297C4240DF52CE177BAD494044334FAE297C4240EB73B515FBA949402AE620E868754240EB73B515FBA94940
21109	Ракитинка	1	8	859	36.486790999999997	36.518214	51.169955000000002	51.143720999999999	0103000020E610000001000000050000005A7EE02A4F3E4240CC5F2173659249405A7EE02A4F3E42405665DF15C1954940282A1BD6544242405665DF15C1954940282A1BD654424240CC5F2173659249405A7EE02A4F3E4240CC5F217365924940
21470	Пселец	1	8	859	36.509042000000001	36.587555000000002	51.300603000000002	51.270949999999999	0103000020E610000001000000050000002D25CB4928414240F46C567DAEA249402D25CB49284142402D0ABB287AA64940F7CC9200354B42402D0ABB287AA64940F7CC9200354B4240F46C567DAEA249402D25CB4928414240F46C567DAEA24940
22244	Пристень	1	8	859	36.675643999999998	36.720154999999998	51.252464000000003	51.219963999999997	0103000020E610000001000000050000008BDEA9807B5642400F26C5C7279C49408BDEA9807B5642406CB587BD50A049408386FE092E5C42406CB587BD50A049408386FE092E5C42400F26C5C7279C49408BDEA9807B5642400F26C5C7279C4940
20680	Пристенное	1	8	859	36.806142000000001	36.837142999999998	51.229221000000003	51.193261999999997	0103000020E610000001000000050000004DF73AA92F6742409FC728CFBC9849404DF73AA92F67424039471D1D579D4940A4897780276B424039471D1D579D4940A4897780276B42409FC728CFBC9849404DF73AA92F6742409FC728CFBC984940
21858	Прилепы	1	8	859	36.833531999999998	36.851956000000001	51.270341999999999	51.219631	0103000020E61000000100000005000000B115342DB16A424009185DDE1C9C4940B115342DB16A42401C5E10919AA24940C4D0EAE40C6D42401C5E10919AA24940C4D0EAE40C6D424009185DDE1C9C4940B115342DB16A424009185DDE1C9C4940
21563	Нагольное	1	8	859	36.527233000000003	36.600329000000002	51.231324999999998	51.209311999999997	0103000020E610000001000000050000009D2FF65E7C434240865451BCCA9A49409D2FF65E7C434240A4DFBE0E9C9D494092EBA694D74C4240A4DFBE0E9C9D494092EBA694D74C4240865451BCCA9A49409D2FF65E7C434240865451BCCA9A4940
21590	Луг	1	8	859	36.634006999999997	36.668942000000001	51.281813	51.248956999999997	0103000020E61000000100000005000000B0373124275142401D8EAED2DD9F4940B037312427514240384BC97212A44940DE7536E49F554240384BC97212A44940DE7536E49F5542401D8EAED2DD9F4940B0373124275142401D8EAED2DD9F4940
21411	Красниково	1	8	859	36.388255000000001	36.429442999999999	51.25761	51.228645	0103000020E6100000010000000500000016C1FF56B23142406CB2463D449D494016C1FF56B2314240B08F4E5DF9A04940813FFCFCF7364240B08F4E5DF9A04940813FFCFCF73642406CB2463D449D494016C1FF56B23142406CB2463D449D4940
21371	Котово	1	8	859	36.413632	36.444578999999997	51.278112	51.263365	0103000020E610000001000000050000001F4AB4E4F13442409DF4BEF1B5A149401F4AB4E4F134424005508C2C99A3494083BEF4F6E738424005508C2C99A3494083BEF4F6E73842409DF4BEF1B5A149401F4AB4E4F13442409DF4BEF1B5A14940
21323	Колбасовка	1	8	859	36.763095	36.793151999999999	51.266188	51.251792999999999	0103000020E61000000100000005000000DD5ED218AD6142404D2EC6C03AA04940DD5ED218AD614240384BC97212A24940E560360186654240384BC97212A24940E5603601866542404D2EC6C03AA04940DD5ED218AD6142404D2EC6C03AA04940
22145	Кировский	1	8	859	36.643897000000003	36.783855000000003	51.332669000000003	51.273513999999999	0103000020E610000001000000050000000B7F86376B524240C37FBA8102A349400B7F86376B5242404FB2D5E594AA49402EE7525C556442404FB2D5E594AA49402EE7525C55644240C37FBA8102A349400B7F86376B524240C37FBA8102A34940
21182	Ильинка	1	8	859	36.850968000000002	36.880442000000002	51.331840999999997	51.308368000000002	0103000020E61000000100000005000000A5F8F884EC6C42400491459A78A74940A5F8F884EC6C4240683C11C479AA49402E03CE52B2704240683C11C479AA49402E03CE52B27042400491459A78A74940A5F8F884EC6C42400491459A78A74940
6432	Еринка	1	8	859	36.452350000000003	36.513624	51.260885000000002	51.245472999999997	0103000020E610000001000000050000003D2CD49AE63942408786C5A86B9F49403D2CD49AE63942402C82FFAD64A149406938656EBE4142402C82FFAD64A149406938656EBE4142408786C5A86B9F49403D2CD49AE63942408786C5A86B9F4940
21767	Владимировка	1	8	859	37.056106999999997	37.075375999999999	51.284776999999998	51.273847000000004	0103000020E61000000100000005000000D009A1832E874240CA8D226B0DA34940D009A1832E87424095D39E9273A449409F73B7EBA589424095D39E9273A449409F73B7EBA5894240CA8D226B0DA34940D009A1832E874240CA8D226B0DA34940
22089	Вихровский	1	8	859	36.670684999999999	36.688490000000002	51.222507999999998	51.216375999999997	0103000020E6100000010000000500000079758E01D9554240D4D17135B29B494079758E01D9554240978C63247B9C4940C0CFB87020584240978C63247B9C4940C0CFB87020584240D4D17135B29B494079758E01D9554240D4D17135B29B4940
22060	Вихровка	1	8	859	36.725535999999998	36.749926000000002	51.205317000000001	51.183230000000002	0103000020E610000001000000050000000B09185DDE5C4240B3D2A414749749400B09185DDE5C42400B28D4D3479A4940C6353E93FD5F42400B28D4D3479A4940C6353E93FD5F4240B3D2A414749749400B09185DDE5C4240B3D2A41474974940
21891	Верхняя Ольшанка	1	8	859	36.610525000000003	36.712484000000003	51.171275999999999	51.144998000000001	0103000020E61000000100000005000000F931E6AE254E424022FE614B8F924940F931E6AE254E42407B4B395FEC9549402E76FBAC325B42407B4B395FEC9549402E76FBAC325B424022FE614B8F924940F931E6AE254E424022FE614B8F924940
21286	Большие Сети	1	8	859	36.883164000000001	36.926067000000003	51.211213999999998	51.189405999999998	0103000020E61000000100000005000000958098840B71424045D5AF743E984940958098840B7142408A3A730F099B4940D2730B5D897642408A3A730F099B4940D2730B5D8976424045D5AF743E984940958098840B71424045D5AF743E984940
21504	Большие Крюки	1	8	859	36.429811000000001	36.451397	51.342036999999998	51.316571000000003	0103000020E61000000100000005000000043BFE0B0437424057EE056685A84940043BFE0B04374240CF8250DEC7AB49409A417C60C7394240CF8250DEC7AB49409A417C60C739424057EE056685A84940043BFE0B0437424057EE056685A84940
20938	Бобрышево	1	8	859	36.401730000000001	36.465591000000003	51.225250000000003	51.194203999999999	0103000020E610000001000000050000003AE97DE36B3342404E603AADDB9849403AE97DE36B33424046B6F3FDD49C4940EE27637C983B424046B6F3FDD49C4940EE27637C983B42404E603AADDB9849403AE97DE36B3342404E603AADDB984940
20616	Становое	1	8	681	36.085135999999999	36.147514999999999	52.202218000000002	52.175897999999997	0103000020E610000001000000050000002BDB87BCE50A424045B75ED383164A402BDB87BCE50A4240CE548847E2194A40B05582C5E1124240CE548847E2194A40B05582C5E112424045B75ED383164A402BDB87BCE50A424045B75ED383164A40
19867	Поныри	1	8	681	36.278911999999998	36.322192999999999	52.336463000000002	52.300317	0103000020E61000000100000005000000213B6F63B323424067B796C970264A40213B6F63B323424033A83638112B4A400400C79E3D29424033A83638112B4A400400C79E3D29424067B796C970264A40213B6F63B323424067B796C970264A40
20010	Первомайское	1	8	681	36.410846999999997	36.438443999999997	52.300156999999999	52.253332	0103000020E6100000010000000500000071546EA296344240E083D72E6D204A4071546EA2963442402E55698B6B264A404F90D8EE1E3842402E55698B6B264A404F90D8EE1E384240E083D72E6D204A4071546EA296344240E083D72E6D204A40
20574	Ольховатка	1	8	681	36.089457000000003	36.160747999999998	52.276072999999997	52.22974	0103000020E61000000100000005000000FBB2B453730B4240A14ACD1E681D4A40FBB2B453730B424080272D5C56234A40DE72F5639314424080272D5C56234A40DE72F56393144240A14ACD1E681D4A40FBB2B453730B4240A14ACD1E681D4A40
20514	Нижнесмородино	1	8	681	36.154235	36.261377000000003	52.190559	52.167679999999997	0103000020E610000001000000050000000473F4F8BD134240BD18CA8976154A400473F4F8BD134240AF7AC03C64184A409B7631CD74214240AF7AC03C64184A409B7631CD74214240BD18CA8976154A400473F4F8BD134240BD18CA8976154A40
20724	Игишево	1	8	681	35.995762999999997	36.062184000000002	52.306880999999997	52.289031000000001	0103000020E610000001000000050000008EC8772975FF4140DD43C2F7FE244A408EC8772975FF4140C36169E047274A40D02A33A5F5074240C36169E047274A40D02A33A5F5074240DD43C2F7FE244A408EC8772975FF4140DD43C2F7FE244A40
4738	Горяйново	1	8	681	36.405304999999998	36.436252000000003	52.177809000000003	52.154806999999998	0103000020E61000000100000005000000E0F3C308E13342408F183DB7D0134A40E0F3C308E13342409DF7FF71C2164A404568041BD73742409DF7FF71C2164A404568041BD73742408F183DB7D0134A40E0F3C308E13342408F183DB7D0134A40
20349	Возы	1	8	681	36.268490999999997	36.289161999999997	52.193379999999998	52.177053000000001	0103000020E610000001000000050000009A22C0E95D224240505436ACA9164A409A22C0E95D224240A9D903ADC0184A407B9FAA4203254240A9D903ADC0184A407B9FAA4203254240505436ACA9164A409A22C0E95D224240505436ACA9164A40
20462	Верхнесмородино	1	8	681	36.175004000000001	36.221941000000001	52.219932	52.192546	0103000020E61000000100000005000000A855F48766164240E17CEA58A5184A40A855F4876616424004AC55BB261C4A401E520C90681C424004AC55BB261C4A401E520C90681C4240E17CEA58A5184A40A855F48766164240E17CEA58A5184A40
20375	Брусовое	1	8	681	36.302034999999997	36.343788000000004	52.232460000000003	52.198056000000001	0103000020E61000000100000005000000A99F3715A9264240676325E659194A40A99F3715A926424068D0D03FC11D4A40EE60C43E012C424068D0D03FC11D4A40EE60C43E012C4240676325E659194A40A99F3715A9264240676325E659194A40
20281	Бобровка	1	8	681	36.411611000000001	36.440007000000001	52.218746000000003	52.205618000000001	0103000020E6100000010000000500000041D653ABAF34424006BCCCB0511A4A4041D653ABAF344240BF1072DEFF1B4A406B813D2652384240BF1072DEFF1B4A406B813D265238424006BCCCB0511A4A4041D653ABAF34424006BCCCB0511A4A40
20146	Березовец	1	8	681	36.325687000000002	36.38494	52.273257000000001	52.225707999999997	0103000020E61000000100000005000000BEDD921CB02942400839EFFFE31C4A40BEDD921CB02942409833DB15FA224A400C76C3B6453142409833DB15FA224A400C76C3B6453142400839EFFFE31C4A40BEDD921CB02942400839EFFFE31C4A40
20784	2-е Поныри	1	8	681	36.188037999999999	36.230860999999997	52.285361999999999	52.251142999999999	0103000020E61000000100000005000000DF3312A11118424046CF2D7425204A40DF3312A111184240B5C2F4BD86244A40FF756EDA8C1D4240B5C2F4BD86244A40FF756EDA8C1D424046CF2D7425204A40DF3312A11118424046CF2D7425204A40
20828	1-е Поныри	1	8	681	36.225299999999997	36.303435999999998	52.347726000000002	52.295724	0103000020E61000000100000005000000F7E461A1D61C42403752B648DA254A40F7E461A1D61C424005FC1A49822C4A40EB36A8FDD626424005FC1A49822C4A40EB36A8FDD62642403752B648DA254A40F7E461A1D61C42403752B648DA254A40
18723	Черницыно	1	8	1552	35.971274999999999	35.996437	51.655467000000002	51.643022000000002	0103000020E6100000010000000500000011363CBD52FC4140E44D7E8B4ED2494011363CBD52FC4140BA4DB857E6D349401EC3633F8BFF4140BA4DB857E6D349401EC3633F8BFF4140E44D7E8B4ED2494011363CBD52FC4140E44D7E8B4ED24940
19632	Старково	1	8	1552	35.851125000000003	35.867860999999998	51.767291	51.753247999999999	0103000020E610000001000000050000006DE7FBA9F1EC414082E3326E6AE049406DE7FBA9F1EC4140F0C16B9736E24940A73CBA1116EF4140F0C16B9736E24940A73CBA1116EF414082E3326E6AE049406DE7FBA9F1EC414082E3326E6AE04940
18505	Прямицыно	1	8	1552	35.909802999999997	35.971921999999999	51.662824999999998	51.642094	0103000020E61000000100000005000000BE66B96C74F441409A7ADD2230D24940BE66B96C74F4414050FC1873D7D44940A721AAF067FC414050FC1873D7D44940A721AAF067FC41409A7ADD2230D24940BE66B96C74F441409A7ADD2230D24940
19756	Провоторова	1	8	1552	35.713341999999997	35.728397000000001	51.831598	51.819378999999998	0103000020E610000001000000050000007E6E68CA4EDB4140BC033C69E1E849407E6E68CA4EDB4140A2B5A2CD71EA494094C0E61C3CDD4140A2B5A2CD71EA494094C0E61C3CDD4140BC033C69E1E849407E6E68CA4EDB4140BC033C69E1E84940
19165	Плотава	1	8	1552	35.901736	35.924266000000003	51.537663000000002	51.525717999999998	0103000020E610000001000000050000001CD0D2156CF34140927538BA4AC349401CD0D2156CF3414077A22424D2C44940026729594EF6414077A22424D2C44940026729594EF64140927538BA4AC349401CD0D2156CF34140927538BA4AC34940
19561	Нижняя Горбулина	1	8	1552	35.814070000000001	35.832782000000002	51.724826999999998	51.705928	0103000020E61000000100000005000000CE531D7233E8414054AA44D95BDA4940CE531D7233E84140FF209221C7DC49404759BF9998EA4140FF209221C7DC49404759BF9998EA414054AA44D95BDA4940CE531D7233E8414054AA44D95BDA4940
18762	Нижняя Ворожба	1	8	1552	35.909623000000003	35.925524000000003	51.646157000000002	51.62912	0103000020E610000001000000050000003F58C6866EF4414038A1100187D049403F58C6866EF441406E8AC745B5D24940E1D4079277F641406E8AC745B5D24940E1D4079277F6414038A1100187D049403F58C6866EF4414038A1100187D04940
19279	Митрофанова	1	8	1552	35.793354999999998	35.86027	51.655160000000002	51.635995999999999	0103000020E610000001000000050000001D8F19A88CE541408331225168D149401D8F19A88CE54140DDD26A48DCD349406EDDCD531DEE4140DDD26A48DCD349406EDDCD531DEE41408331225168D149401D8F19A88CE541408331225168D14940
19467	Липина	1	8	1552	35.798411999999999	35.824697	51.675991000000003	51.668222	0103000020E61000000100000005000000F25D4A5D32E64140DE3B6A4C88D54940F25D4A5D32E64140F7B182DF86D64940FE0DDAAB8FE94140F7B182DF86D64940FE0DDAAB8FE94140DE3B6A4C88D54940F25D4A5D32E64140DE3B6A4C88D54940
19073	Журавлино	1	8	1552	35.935693000000001	35.987067000000003	51.568800000000003	51.557825999999999	0103000020E610000001000000050000004E0CC9C9C4F74140E36DA5D766C749404E0CC9C9C4F741407FFB3A70CEC84940FDFA213658FE41407FFB3A70CEC84940FDFA213658FE4140E36DA5D766C749404E0CC9C9C4F74140E36DA5D766C74940
32508	Дюмина	1	8	1552	35.739877999999997	35.755239000000003	51.806567000000001	51.798485999999997	0103000020E61000000100000005000000D3838252B4DE41402C280CCA34E64940D3838252B4DE4140348463963DE74940F6D4EAABABE04140348463963DE74940F6D4EAABABE041402C280CCA34E64940D3838252B4DE41402C280CCA34E64940
18924	Дьяконово	1	8	1552	35.889780000000002	35.905878000000001	51.654864000000003	51.632143999999997	0103000020E610000001000000050000004451A04FE4F141406A2E3718EAD049404451A04FE4F14140F4A96395D2D349403C1570CFF3F34140F4A96395D2D349403C1570CFF3F341406A2E3718EAD049404451A04FE4F141406A2E3718EAD04940
54523	Волобуево	1	8	1552	35.802813999999998	35.814914000000002	51.768500000000003	51.755740000000003	0103000020E61000000100000005000000AE62F19BC2E64140B8239C16BCE04940AE62F19BC2E64140EE7C3F355EE24940BA86191A4FE84140EE7C3F355EE24940BA86191A4FE84140B8239C16BCE04940AE62F19BC2E64140B8239C16BCE04940
19249	Верхние Постоялые Дворы	1	8	1552	35.820608999999997	35.836410999999998	51.547488000000001	51.532922999999997	0103000020E61000000100000005000000D1E638B709E94140A22424D236C44940D1E638B709E94140EA79371614C64940E08101840FEB4140EA79371614C64940E08101840FEB4140A22424D236C44940D1E638B709E94140A22424D236C44940
19462	Ванина	1	8	1552	35.898178999999999	35.947657999999997	51.687305000000002	51.677672000000001	0103000020E610000001000000050000001C7A8B87F7F241401CB5C2F4BDD649401C7A8B87F7F241404BB0389CF9D7494079E57ADB4CF941404BB0389CF9D7494079E57ADB4CF941401CB5C2F4BDD649401C7A8B87F7F241401CB5C2F4BDD64940
19398	Большое Долженково	1	8	1552	35.831533	35.851520000000001	51.727103	51.691085000000001	0103000020E61000000100000005000000BB4560AC6FEA4140CAE0287975D84940BB4560AC6FEA414068E90AB611DD4940E9F17B9BFEEC414068E90AB611DD4940E9F17B9BFEEC4140CAE0287975D84940BB4560AC6FEA4140CAE0287975D84940
19150	Артюховка	1	8	1552	35.748097000000001	35.765965000000001	51.570115999999999	51.552869999999999	0103000020E610000001000000050000002C9E7AA4C1DF41404278B471C4C649402C9E7AA4C1DF41409276A38FF9C84940B97020240BE241409276A38FF9C84940B97020240BE241404278B471C4C649402C9E7AA4C1DF41404278B471C4C64940
54496	Анахина	1	8	1552	35.687694999999998	36.027149999999999	51.870162000000001	51.504772000000003	0103000020E61000000100000005000000B54FC76306D84140E0F76F5E9CC04940B54FC76306D84140691CEA7761EF49400F0BB5A679034240691CEA7761EF49400F0BB5A679034240E0F76F5E9CC04940B54FC76306D84140E0F76F5E9CC04940
19798	Алябьева	1	8	1552	35.817231999999997	35.838701	51.841397999999998	51.828285999999999	0103000020E61000000100000005000000519FE40E9BE8414009DE904605EA4940519FE40E9BE84140BC75FEEDB2EB4940AE0FEB8D5AEB4140BC75FEEDB2EB4940AE0FEB8D5AEB414009DE904605EA4940519FE40E9BE8414009DE904605EA4940
19353	Авдеева	1	8	1552	35.785764	35.812703999999997	51.693278999999997	51.684489999999997	0103000020E61000000100000005000000E42F2DEA93E4414032384A5E9DD74940E42F2DEA93E441407500C45DBDD8494008AA46AF06E841407500C45DBDD8494008AA46AF06E8414032384A5E9DD74940E42F2DEA93E4414032384A5E9DD74940
16991	Шипы	1	8	817	36.393303000000003	36.435119999999998	51.142510999999999	51.123555000000003	0103000020E610000001000000050000009835B1C057324240EF2076A6D08F49409835B1C057324240FE28EACC3D924940F2EA1C03B2374240FE28EACC3D924940F2EA1C03B2374240EF2076A6D08F49409835B1C057324240EF2076A6D08F4940
18007	Шевелево	1	8	817	35.999464000000003	36.030887	51.250953000000003	51.220996999999997	0103000020E61000000100000005000000C2C3B46FEEFF4140CEC133A1499C4940C2C3B46FEEFF4140A3EA573A1FA049408F6FEF1AF4034240A3EA573A1FA049408F6FEF1AF4034240CEC133A1499C4940C2C3B46FEEFF4140CEC133A1499C4940
16859	Чекмаревка	1	8	817	36.085926999999998	36.105699000000001	51.287278000000001	51.265140000000002	0103000020E61000000100000005000000F46BEBA7FF0A4240446E861BF0A14940F46BEBA7FF0A42401E6E8786C5A44940261C7A8B870D42401E6E8786C5A44940261C7A8B870D4240446E861BF0A14940F46BEBA7FF0A4240446E861BF0A14940
17808	Филатово	1	8	817	35.847684999999998	35.874930999999997	51.23997	51.229441000000001	0103000020E61000000100000005000000A6272CF180EC414047AE9B525E9D4940A6272CF180EC4140B4024356B79E4940D7A02FBDFDEF4140B4024356B79E4940D7A02FBDFDEF414047AE9B525E9D4940A6272CF180EC414047AE9B525E9D4940
17838	Усланка	1	8	817	36.118661000000003	36.150435000000002	51.196502000000002	51.182586999999998	0103000020E61000000100000005000000C4279D48300F42405ED6C4025F974940C4279D48300F42409FCC3FFA269949403E963E74411342409FCC3FFA269949403E963E74411342405ED6C4025F974940C4279D48300F42405ED6C4025F974940
17949	Трубеж	1	8	817	36.201549	36.221375000000002	51.206744999999998	51.191488999999997	0103000020E6100000010000000500000050C58D5BCC194240994528B68298494050C58D5BCC19424046CEC29E769A494075931804561C424046CEC29E769A494075931804561C4240994528B68298494050C58D5BCC194240994528B682984940
17608	Стрелецкое	1	8	817	36.284948999999997	36.303821999999997	51.234955999999997	51.224003000000003	0103000020E6100000010000000500000092037635792442405B9A5B21AC9C49409203763579244240DEFFC709139E494014E7A8A3E3264240DEFFC709139E494014E7A8A3E32642405B9A5B21AC9C494092037635792442405B9A5B21AC9C4940
17711	Рыбинские Буды	1	8	817	35.938620999999998	35.968364000000001	51.215434000000002	51.194453000000003	0103000020E610000001000000050000005E2BA1BB24F84140F7CDFDD5E39849405E2BA1BB24F8414026396057939B4940D74FFF59F3FB414026396057939B4940D74FFF59F3FB4140F7CDFDD5E39849405E2BA1BB24F84140F7CDFDD5E3984940
17550	Рудавский	1	8	817	36.302599999999998	36.315778999999999	51.254589000000003	51.245404999999998	0103000020E6100000010000000500000082E2C798BB2642402FA3586E699F494082E2C798BB264240EF75525F96A04940BDE13E726B284240EF75525F96A04940BDE13E726B2842402FA3586E699F494082E2C798BB2642402FA3586E699F4940
17504	Рудавец	1	8	817	36.330348999999998	36.363875	51.271338999999998	51.246217000000001	0103000020E6100000010000000500000016A243E0482A4240105CE509849F494016A243E0482A42408E90813CBBA249407F6ABC74932E42408E90813CBBA249407F6ABC74932E4240105CE509849F494016A243E0482A4240105CE509849F4940
17641	Пушкарное	1	8	817	36.257818999999998	36.284697000000001	51.229908999999999	51.213526999999999	0103000020E61000000100000005000000CAA486360021424010E84CDA549B4940CAA48636002142402D077AA86D9D4940792288F3702442402D077AA86D9D4940792288F37024424010E84CDA549B4940CAA486360021424010E84CDA549B4940
16962	Пригородный	1	8	817	36.283977999999998	36.308565000000002	51.204239000000001	51.195095999999999	0103000020E6100000010000000500000049641F64592442404BCADDE7F898494049641F6459244240ACC8E880249A49405AD8D30E7F274240ACC8E880249A49405AD8D30E7F2742404BCADDE7F898494049641F64592442404BCADDE7F8984940
17435	Потопахино	1	8	817	36.290706999999998	36.308861999999998	51.363013000000002	51.340922999999997	0103000020E61000000100000005000000F0DB10E33525424023BA675DA3AB4940F0DB10E335254240ED82C13577AE4940137D3ECA88274240ED82C13577AE4940137D3ECA8827424023BA675DA3AB4940F0DB10E33525424023BA675DA3AB4940
17054	Пересыпь	1	8	817	36.453724000000001	36.486503999999996	51.096445000000003	51.078935000000001	0103000020E6100000010000000500000085B4C6A0133A424040C1C58A1A8A494085B4C6A0133A42406E6E4C4F588C4940C4AF58C3453E42406E6E4C4F588C4940C4AF58C3453E424040C1C58A1A8A494085B4C6A0133A424040C1C58A1A8A4940
16769	Пасечный	1	8	817	36.218634999999999	36.22663	51.267162999999996	51.262287999999998	0103000020E6100000010000000500000067614F3BFC1B42400E1137A792A1494067614F3BFC1B4240C2D9AD6532A2494070253B36021D4240C2D9AD6532A2494070253B36021D42400E1137A792A1494067614F3BFC1B42400E1137A792A14940
17902	Павловка	1	8	817	36.088514000000004	36.136502	51.164656999999998	51.147432999999999	0103000020E610000001000000050000007C9E3F6D540B4240F3ACA415DF9249407C9E3F6D540B42405B07077B1395494057EBC4E5781142405B07077B1395494057EBC4E578114240F3ACA415DF9249407C9E3F6D540B4240F3ACA415DF924940
5830	Обоянь	1	8	817	36.222462	36.314188999999999	51.225825	51.197563000000002	0103000020E61000000100000005000000274D83A2791C424028F38FBE49994940274D83A2791C424042CF66D5E79C4940A8E15B583728424042CF66D5E79C4940A8E15B583728424028F38FBE49994940274D83A2791C424028F38FBE49994940
16291	Нижнее Солотино	1	8	817	36.229154000000001	36.248342000000001	51.188293999999999	51.169803000000002	0103000020E61000000100000005000000B1DF13EB541D4240A0E1CD1ABC954940B1DF13EB541D42403A048E041A984940931CB0ABC91F42403A048E041A984940931CB0ABC91F4240A0E1CD1ABC954940B1DF13EB541D4240A0E1CD1ABC954940
16496	Нижнее Бабино	1	8	817	35.798960000000001	35.833266999999999	51.276608000000003	51.256934000000001	0103000020E61000000100000005000000F5673F5244E64140809D9B36E3A04940F5673F5244E64140EFE714E467A3494003EB387EA8EA4140EFE714E467A3494003EB387EA8EA4140809D9B36E3A04940F5673F5244E64140809D9B36E3A04940
17403	Малые Крюки	1	8	817	36.369076	36.388623000000003	51.327114000000002	51.302669999999999	0103000020E6100000010000000500000087DEE2E13D2F42407BBDFBE3BDA6494087DEE2E13D2F424029081EDFDEA9494099BC0166BE31424029081EDFDEA9494099BC0166BE3142407BBDFBE3BDA6494087DEE2E13D2F42407BBDFBE3BDA64940
17245	Котельниково	1	8	817	36.281525999999999	36.317799999999998	51.362456000000002	51.292431999999998	0103000020E61000000100000005000000A27C410B09244240E5266A696EA54940A27C410B09244240971E4DF564AE49409B559FABAD284240971E4DF564AE49409B559FABAD284240E5266A696EA54940A27C410B09244240E5266A696EA54940
16660	Косиново	1	8	817	35.921553000000003	35.938890999999998	51.274923000000001	51.252091999999998	0103000020E61000000100000005000000EE43DE72F5F54140A7CAF78C44A04940EE43DE72F5F5414088F546AD30A349401EC18D942DF8414088F546AD30A349401EC18D942DF84140A7CAF78C44A04940EE43DE72F5F54140A7CAF78C44A04940
16342	Камынино	1	8	817	36.340204	36.359661000000003	51.168757999999997	51.146309000000002	0103000020E61000000100000005000000F4FBFECD8B2B4240240ED940BA924940F4FBFECD8B2B42401C78B5DC99954940C652245F092E42401C78B5DC99954940C652245F092E4240240ED940BA924940F4FBFECD8B2B4240240ED940BA924940
17087	Каменка	1	8	817	36.025855999999997	36.065247999999997	51.184387999999998	51.160815999999997	0103000020E61000000100000005000000E333D93F4F0342403656629E95944940E333D93F4F0342402EE3A6069A9749409010E50B5A0842402EE3A6069A9749409010E50B5A0842403656629E95944940E333D93F4F0342403656629E95944940
16384	Зорино	1	8	817	36.341830000000002	36.378121999999998	51.190517999999997	51.159444000000001	0103000020E610000001000000050000005665DF15C12B42408FC536A9689449405665DF15C12B424050A6D1E462984940F5F23B4D6630424050A6D1E462984940F5F23B4D663042408FC536A9689449405665DF15C12B42408FC536A968944940
16443	Знобиловка	1	8	817	36.346304000000003	36.390546000000001	51.146127999999997	51.121502	0103000020E61000000100000005000000AC3C81B0532C42400533A6608D8F4940AC3C81B0532C4240D3838252B4924940B4CA4C69FD314240D3838252B4924940B4CA4C69FD3142400533A6608D8F4940AC3C81B0532C42400533A6608D8F4940
17312	Дрозды	1	8	817	36.179037000000001	36.188757000000003	51.319831000000001	51.311430999999999	0103000020E6100000010000000500000011E335AFEA164240F4FA93F8DCA7494011E335AFEA1642409D9FE238F0A849400FF27A30291842409D9FE238F0A849400FF27A3029184240F4FA93F8DCA7494011E335AFEA164240F4FA93F8DCA74940
17748	Долженково	1	8	817	35.838476999999997	35.892178000000001	51.233417000000003	51.199086999999999	0103000020E610000001000000050000005EB9DE3653EB41408507CDAE7B9949405EB9DE3653EB41404CAAB69BE09D4940F81A82E332F241404CAAB69BE09D4940F81A82E332F241408507CDAE7B9949405EB9DE3653EB41408507CDAE7B994940
16805	Гридасово	1	8	817	36.075470000000003	36.095430999999998	51.237471999999997	51.211044999999999	0103000020E6100000010000000500000021EA3E00A9094240FE7DC685039B494021EA3E00A90942409CDB847B659E494025034015370C42409CDB847B659E494025034015370C4240FE7DC685039B494021EA3E00A9094240FE7DC685039B4940
16696	Быканово	1	8	817	36.123997000000003	36.164664000000002	51.281345999999999	51.248759999999997	0103000020E61000000100000005000000ACE63922DF0F4240C746205ED79F4940ACE63922DF0F4240226E4E2503A449400E6ABFB513154240226E4E2503A449400E6ABFB513154240C746205ED79F4940ACE63922DF0F4240C746205ED79F4940
17153	Бушмено	1	8	817	35.901618999999997	35.923467000000002	51.170023	51.153523999999997	0103000020E61000000100000005000000E2395B4068F341405793A7ACA6934940E2395B4068F34140AE484C50C3954940B6F7A92A34F64140AE484C50C3954940B6F7A92A34F641405793A7ACA6934940E2395B4068F341405793A7ACA6934940
17189	Бегичево	1	8	817	35.871948000000003	35.897962999999997	51.197450000000003	51.183072000000003	0103000020E6100000010000000500000004E8F7FD9BEF41401B683EE76E97494004E8F7FD9BEF4140304CA60A469949404F029B73F0F24140304CA60A469949404F029B73F0F241401B683EE76E97494004E8F7FD9BEF41401B683EE76E974940
16591	Башкатово	1	8	817	35.967933000000002	35.997729999999997	51.279874999999997	51.254058999999998	0103000020E610000001000000050000000EDC813AE5FB414092205C0185A049400EDC813AE5FB4140E7FBA9F1D2A34940791EDC9DB5FF4140E7FBA9F1D2A34940791EDC9DB5FF414092205C0185A049400EDC813AE5FB414092205C0185A04940
16179	Афанасьево	1	8	817	36.277852000000003	36.308655000000002	51.182507999999999	51.162019999999998	0103000020E61000000100000005000000699082A79023424022A64412BD944940699082A79023424012A1116C5C9749409A5FCD018227424012A1116C5C9749409A5FCD018227424022A64412BD944940699082A79023424022A64412BD944940
16139	Чермошное	1	8	760	36.174976999999998	36.205789000000003	51.457993000000002	51.444218999999997	0103000020E61000000100000005000000AE4676A56516424083A10E2BDCB84940AE4676A5651642400266BE839FBA49403370404B571A42400266BE839FBA49403370404B571A424083A10E2BDCB84940AE4676A56516424083A10E2BDCB84940
15544	Тарасово	1	8	760	35.726556000000002	35.773671999999998	51.480856000000003	51.453161000000001	0103000020E61000000100000005000000365B79C9FFDC41404D69FD2D01BA4940365B79C9FFDC4140EE0A7DB08CBD49405BEA20AF07E34140EE0A7DB08CBD49405BEA20AF07E341404D69FD2D01BA4940365B79C9FFDC41404D69FD2D01BA4940
15335	Спасское	1	8	760	35.890650999999998	35.919423999999999	51.450186000000002	51.444101000000003	0103000020E6100000010000000500000029931ADA00F241407A8F334DD8B8494029931ADA00F24140FC8EE1B19FB94940299485AFAFF54140FC8EE1B19FB94940299485AFAFF541407A8F334DD8B8494029931ADA00F241407A8F334DD8B84940
15905	Паники	1	8	760	36.165526999999997	36.252141999999999	51.381247000000002	51.360245999999997	0103000020E6100000010000000500000070CD1DFD2F154240E5417A8A1CAE494070CD1DFD2F1542405C59A2B3CCB0494059F96530462042405C59A2B3CCB0494059F9653046204240E5417A8A1CAE494070CD1DFD2F154240E5417A8A1CAE4940
15867	Нижний Реутец	1	8	760	36.020780999999999	36.047784	51.38458	51.352635999999997	0103000020E6100000010000000500000068B0A9F3A802424035B22B2D23AD494068B0A9F3A80242400C59DDEA39B14940D3A23EC91D0642400C59DDEA39B14940D3A23EC91D06424035B22B2D23AD494068B0A9F3A802424035B22B2D23AD4940
16081	Нижний Дубовец	1	8	760	36.341056999999999	36.351998999999999	51.417574999999999	51.414349999999999	0103000020E6100000010000000500000033897AC1A72B42407E8CB96B09B5494033897AC1A72B42404850FC1873B54940C39CA04D0E2D42404850FC1873B54940C39CA04D0E2D42407E8CB96B09B5494033897AC1A72B42407E8CB96B09B54940
15111	Медвенка	1	8	760	36.087615999999997	36.151145	51.431738000000003	51.408935	0103000020E610000001000000050000009C4D4700370B42404A9869FB57B449409C4D4700370B42406138D73043B749401AFA27B8581342406138D73043B749401AFA27B8581342404A9869FB57B449409C4D4700370B42404A9869FB57B44940
5343	Любицкое	1	8	760	36.393160000000002	36.420566999999998	51.543118999999997	51.521363999999998	0103000020E61000000100000005000000350C1F1153324240E7A7380EBCC24940350C1F1153324240096B63EC84C549406F63B323D5354240096B63EC84C549406F63B323D5354240E7A7380EBCC24940350C1F1153324240E7A7380EBCC24940
15764	Любач	1	8	760	35.868364	35.878712	51.367494999999998	51.359948000000003	0103000020E610000001000000050000000A83328D26EF41405C21ACC612AE49400A83328D26EF4140C5387F130AAF4940274D83A279F04140C5387F130AAF4940274D83A279F041405C21ACC612AE49400A83328D26EF41405C21ACC612AE4940
15556	Денисовка	1	8	760	36.425041	36.438129000000004	51.529108000000001	51.513837000000002	0103000020E61000000100000005000000C53A55BE67364240C53C2B69C5C14940C53A55BE67364240A7069ACFB9C34940F0366F9C14384240A7069ACFB9C34940F0366F9C14384240C53C2B69C5C14940C53A55BE67364240C53C2B69C5C14940
15711	Губановка	1	8	760	36.266713000000003	36.306364000000002	51.464759999999998	51.446559999999998	0103000020E610000001000000050000008335CEA623224240D3D9C9E028B949408335CEA623224240963E74417DBB4940FC5580EF36274240963E74417DBB4940FC5580EF36274240D3D9C9E028B949408335CEA623224240D3D9C9E028B94940
16039	Вышний Дубовец	1	8	760	36.353561999999997	36.381948999999999	51.419406000000002	51.404519000000001	0103000020E61000000100000005000000DE8D0585412D424029CE5147C7B34940DE8D0585412D424083DF8618AFB54940B5DE6FB4E330424083DF8618AFB54940B5DE6FB4E330424029CE5147C7B34940DE8D0585412D424029CE5147C7B34940
15987	Высоконские Дворы	1	8	760	36.062677999999998	36.074095999999997	51.491259999999997	51.478870000000001	0103000020E61000000100000005000000DF162CD5050842408C84B69C4BBD4940DF162CD5050842409EEA909BE1BE4940D8614CFA7B0942409EEA909BE1BE4940D8614CFA7B0942408C84B69C4BBD4940DF162CD5050842408C84B69C4BBD4940
15257	Высокое	1	8	760	35.967277000000003	36.021220999999997	51.442883000000002	51.423523000000003	0103000020E61000000100000005000000259694BBCFFB41404A0D6D0036B64940259694BBCFFB4140297AE063B0B84940847EA65EB7024240297AE063B0B84940847EA65EB70242404A0D6D0036B64940259694BBCFFB41404A0D6D0036B64940
15428	Верхний Реутец	1	8	760	35.988720000000001	36.023144000000002	51.356285999999997	51.330249000000002	0103000020E61000000100000005000000587380608EFE4140B344679945AA4940587380608EFE4140E60297C79AAD4940A08CF161F6024240E60297C79AAD4940A08CF161F6024240B344679945AA4940587380608EFE4140B344679945AA4940
15243	Амосовка	1	8	760	36.166604999999997	36.202178000000004	51.521963	51.5047	0103000020E61000000100000005000000CF2C095053154240462575029AC04940CF2C0950531542406C5CFFAECFC2494040FCFCF7E01942406C5CFFAECFC2494040FCFCF7E0194240462575029AC04940CF2C095053154240462575029AC04940
6193	2-я Китаевка	1	8	760	36.324654000000002	36.343995	51.496082000000001	51.481361	0103000020E61000000100000005000000FF4124438E294240F148BC3C9DBD4940FF4124438E29424030116F9D7FBF4940677E3507082C424030116F9D7FBF4940677E3507082C4240F148BC3C9DBD4940FF4124438E294240F148BC3C9DBD4940
15944	2-е Панино	1	8	760	36.109301000000002	36.138658	51.542475000000003	51.533450000000002	0103000020E61000000100000005000000C6353E93FD0D42408E06F01648C44940C6353E93FD0D4240E5F21FD26FC5494015AA9B8BBF114240E5F21FD26FC5494015AA9B8BBF1142408E06F01648C44940C6353E93FD0D42408E06F01648C44940
15475	1-я Гостомля	1	8	760	35.831982000000004	35.856667999999999	51.454884	51.439610000000002	0103000020E610000001000000050000002B6EDC627EEA41404E7FF62345B849402B6EDC627EEA4140A1BC8FA339BA4940CEC3094CA7ED4140A1BC8FA339BA4940CEC3094CA7ED41404E7FF62345B849402B6EDC627EEA41404E7FF62345B84940
15811	1-й Липовец	1	8	760	35.877966999999998	35.910522	51.340833000000003	51.324846000000001	0103000020E61000000100000005000000CEFBFF3861F04140431EC18D94A94940CEFBFF3861F04140E4326E6AA0AB4940EE2422FC8BF44140E4326E6AA0AB4940EE2422FC8BF44140431EC18D94A94940CEFBFF3861F04140431EC18D94A94940
5564	Ястребовка	1	8	786	37.510565	37.599462000000003	51.467312999999997	51.431727000000002	0103000020E61000000100000005000000BABDA4315AC142406DE690D442B74940BABDA4315AC1424071FF91E9D0BB4940EE98BA2BBBCC424071FF91E9D0BB4940EE98BA2BBBCC42406DE690D442B74940BABDA4315AC142406DE690D442B74940
15038	Стужень	1	8	786	37.481549000000001	37.540129	51.512424000000003	51.461562000000001	0103000020E61000000100000005000000F435CB65A3BD4240C689AF7614BB4940F435CB65A3BD4240BFD7101C97C14940834F73F222C54240BFD7101C97C14940834F73F222C54240C689AF7614BB4940F435CB65A3BD4240C689AF7614BB4940
14978	Сейм	1	8	786	37.018197999999998	37.074854999999999	51.362535000000001	51.332065999999998	0103000020E61000000100000005000000226DE34F54824240880E812381AA4940226DE34F54824240E353008C67AE4940967840D994894240E353008C67AE4940967840D994894240880E812381AA4940226DE34F54824240880E812381AA4940
14963	Свинец	1	8	786	37.018953000000003	37.054265999999998	51.4604	51.418208999999997	0103000020E610000001000000050000009F94490D6D82424049F25CDF87B549409F94490D6D824240098A1F63EEBA494072A43330F2864240098A1F63EEBA494072A43330F286424049F25CDF87B549409F94490D6D82424049F25CDF87B54940
14903	Роговое	1	8	786	37.136533999999997	37.181683	51.540677000000002	51.517301000000003	0103000020E61000000100000005000000626534F27991424014984EEB36C24940626534F279914240865968E734C549409D9E776341974240865968E734C549409D9E77634197424014984EEB36C24940626534F27991424014984EEB36C24940
14765	Репецкая Плата	1	8	786	37.272843999999999	37.316861000000003	51.483874	51.460990000000002	0103000020E6100000010000000500000075745C8DECA242403BE466B801BB494075745C8DECA242403EB14E95EFBD49405E30B8E68EA842403EB14E95EFBD49405E30B8E68EA842403BE466B801BB494075745C8DECA242403BE466B801BB4940
14676	Пузачи	1	8	786	37.159979999999997	37.212198999999998	51.527107999999998	51.476407999999999	0103000020E61000000100000005000000CD0182397A944240C1C6F5EFFABC4940CD0182397A944240E0BA624678C34940389F3A56299B4240E0BA624678C34940389F3A56299B4240C1C6F5EFFABC4940CD0182397A944240C1C6F5EFFABC4940
14670	Останино	1	8	786	37.227604999999997	37.265135999999998	51.431581000000001	51.396956000000003	0103000020E61000000100000005000000FAB31F29229D4240BAF94674CFB24940FAB31F29229D42409949D40B3EB74940027FF8F9EFA142409949D40B3EB74940027FF8F9EFA14240BAF94674CFB24940FAB31F29229D4240BAF94674CFB24940
14608	Мяснянка	1	8	786	37.146864000000001	37.163043000000002	51.414321999999999	51.396877000000003	0103000020E61000000100000005000000D97A8670CC9242406EC493DDCCB24940D97A8670CC924240B401D88008B54940BE6BD097DE944240B401D88008B54940BE6BD097DE9442406EC493DDCCB24940D97A8670CC9242406EC493DDCCB24940
14548	Мантурово	1	8	786	37.103448999999998	37.150286999999999	51.468688	51.437947999999999	0103000020E61000000100000005000000E6E61BD13D8D42409FAC18AE0EB84940E6E61BD13D8D42408A03E8F7FDBB4940C901BB9A3C9342408A03E8F7FDBB4940C901BB9A3C9342409FAC18AE0EB84940E6E61BD13D8D42409FAC18AE0EB84940
14517	Куськино	1	8	786	37.203924999999998	37.28145	51.540872999999998	51.529657	0103000020E610000001000000050000001CEBE2361A9A42407A8CF2CCCBC349401CEBE2361A9A42400B2593533BC54940C7BAB88D06A442400B2593533BC54940C7BAB88D06A442407A8CF2CCCBC349401CEBE2361A9A42407A8CF2CCCBC34940
14465	Крутые Верхи	1	8	786	37.380955999999998	37.423445999999998	51.429896999999997	51.400562999999998	0103000020E61000000100000005000000849B8C2AC3B042406B7EFCA545B34940849B8C2AC3B0424002D369DD06B749409ECF807A33B6424002D369DD06B749409ECF807A33B642406B7EFCA545B34940849B8C2AC3B042406B7EFCA545B34940
14414	Кривец	1	8	786	37.081178999999999	37.133766999999999	51.360593999999999	51.334845999999999	0103000020E610000001000000050000009D0FCF12648A42402499D53BDCAA49409D0FCF12648A42402191B6F127AE49405B24ED461F9142402191B6F127AE49405B24ED461F9142402499D53BDCAA49409D0FCF12648A42402499D53BDCAA4940
14371	Засеймье 2-е	1	8	786	37.094295000000002	37.126112999999997	51.499462999999999	51.470371	0103000020E610000001000000050000009296CADB118C424050FEEE1D35BC49409296CADB118C4240F1475167EEBF4940DB4C857824904240F1475167EEBF4940DB4C85782490424050FEEE1D35BC49409296CADB118C424050FEEE1D35BC4940
14321	Засеймье 1-е	1	8	786	37.094295000000002	37.126112999999997	51.499462999999999	51.470371	0103000020E610000001000000050000009296CADB118C424050FEEE1D35BC49409296CADB118C4240F1475167EEBF4940DB4C857824904240F1475167EEBF4940DB4C85782490424050FEEE1D35BC49409296CADB118C424050FEEE1D35BC4940
54544	Заречное	1	8	786	37.300063000000002	37.371039000000003	51.563828000000001	51.541387999999998	0103000020E61000000100000005000000ADDEE17668A642403239B5334CC54940ADDEE17668A64240D84812842BC849403145B9347EAF4240D84812842BC849403145B9347EAF42403239B5334CC54940ADDEE17668A642403239B5334CC54940
14808	Заосколье	1	8	786	37.442239000000001	37.459944999999998	51.518555999999997	51.508634999999998	0103000020E6100000010000000500000004029D499BB84240EC4CA1F31AC1494004029D499BB842408192020B60C24940B77A4E7ADFBA42408192020B60C24940B77A4E7ADFBA4240EC4CA1F31AC1494004029D499BB84240EC4CA1F31AC14940
14239	Гущино	1	8	786	37.186121	37.247034999999997	51.346701000000003	51.329573000000003	0103000020E61000000100000005000000A60C1CD0D29742408352B4722FAA4940A60C1CD0D2974240C93EC8B260AC4940D2FBC6D79E9F4240C93EC8B260AC4940D2FBC6D79E9F42408352B4722FAA4940A60C1CD0D29742408352B4722FAA4940
14175	Большие Бутырки	1	8	786	37.363205000000001	37.416834999999999	51.486891	51.471195999999999	0103000020E61000000100000005000000315F5E807DAE4240C500892650BC4940315F5E807DAE4240BEDBBC7152BE4940016A6AD95AB54240BEDBBC7152BE4940016A6AD95AB54240C500892650BC4940315F5E807DAE4240C500892650BC4940
14841	Безлепкино	1	8	786	37.427821000000002	37.443111000000002	51.559914999999997	51.551139999999997	0103000020E6100000010000000500000061C5A9D6C2B642403BC269C18BC6494061C5A9D6C2B6424019C5724BABC74940BABF7ADCB7B8424019C5724BABC74940BABF7ADCB7B842403BC269C18BC6494061C5A9D6C2B642403BC269C18BC64940
12229	Эммануиловка	1	8	811	35.428072999999998	35.454276	51.568430999999997	51.548115000000003	0103000020E610000001000000050000007AA69718CBB6414039B9DFA128C649407AA69718CBB641402B84D558C2C84940C9AD49B725BA41402B84D558C2C84940C9AD49B725BA414039B9DFA128C649407AA69718CBB6414039B9DFA128C64940
14040	Шерекино	1	8	811	35.208300000000001	35.240181	51.668205	51.656528999999999	0103000020E61000000100000005000000DFE00B93A99A414013F06B2409D44940DFE00B93A99A41400803CFBD87D549406F0F4240BE9E41400803CFBD87D549406F0F4240BE9E414013F06B2409D44940DFE00B93A99A414013F06B2409D44940
12493	Черемошки	1	8	811	35.242381999999999	35.289507	51.530856	51.505097999999997	0103000020E61000000100000005000000CD91955F069F414033A31F0DA7C04940CD91955F069F41405471E316F3C34940467BBC900EA541405471E316F3C34940467BBC900EA5414033A31F0DA7C04940CD91955F069F414033A31F0DA7C04940
12581	Цуканово Бобрик	1	8	811	35.354483000000002	35.384405000000001	51.492555000000003	51.481389	0103000020E6100000010000000500000076FEEDB25FAD4140BBD39D279EBD494076FEEDB25FAD41409B3DD00A0CBF49409EB5DB2E34B141409B3DD00A0CBF49409EB5DB2E34B14140BBD39D279EBD494076FEEDB25FAD4140BBD39D279EBD4940
13983	Фитиж	1	8	811	35.102998999999997	35.160851000000001	51.685769000000001	51.666406000000002	0103000020E61000000100000005000000A6423C122F8D4140D9EDB3CA4CD54940A6423C122F8D414029CE5147C7D74940B343FCC39694414029CE5147C7D74940B343FCC396944140D9EDB3CA4CD54940A6423C122F8D4140D9EDB3CA4CD54940
13540	Телятниково	1	8	811	35.292292000000003	35.310015999999997	51.752707999999998	51.730919	0103000020E61000000100000005000000F47002D369A541403483F8C08EDD4940F47002D369A5414002B859BC58E049404D9EB29AAEA7414002B859BC58E049404D9EB29AAEA741403483F8C08EDD4940F47002D369A541403483F8C08EDD4940
12320	Сугрово	1	8	811	35.306001000000002	35.347394999999999	51.650170000000003	51.621834999999997	0103000020E610000001000000050000008BC56F0A2BA741400B410E4A98CF49408BC56F0A2BA74140906B43C538D349409FE5797077AC4140906B43C538D349409FE5797077AC41400B410E4A98CF49408BC56F0A2BA741400B410E4A98CF4940
12595	Стремоухово-Бобрик	1	8	811	35.419296000000003	35.494942999999999	51.516509999999997	51.496884000000001	0103000020E61000000100000005000000FCABC77DABB54140EDF318E599BF4940FCABC77DABB541404A07EBFF1CC249402B31CF4A5ABF41404A07EBFF1CC249402B31CF4A5ABF4140EDF318E599BF4940FCABC77DABB54140EDF318E599BF4940
13342	Стремоуховка	1	8	811	35.066240000000001	35.092246000000003	51.618161000000001	51.596307000000003	0103000020E61000000100000005000000F1D7648D7A8841401DB0ABC953CC4940F1D7648D7A884140D2544FE61FCF4940EA9788B7CE8B4140D2544FE61FCF4940EA9788B7CE8B41401DB0ABC953CC4940F1D7648D7A8841401DB0ABC953CC4940
13691	Сергеевка	1	8	811	35.184018000000002	35.217650999999996	51.707110999999998	51.689208999999998	0103000020E610000001000000050000000BF0DDE68D974140EF8D210038D849400BF0DDE68D97414028D2FD9C82DA49408978EBFCDB9B414028D2FD9C82DA49408978EBFCDB9B4140EF8D210038D849400BF0DDE68D974140EF8D210038D84940
13955	Селекционный	1	8	811	35.157581	35.174092000000002	51.638779999999997	51.629773999999998	0103000020E6100000010000000500000049BC3C9D2B94414080EF366F9CD0494049BC3C9D2B94414060AB048BC3D14940643F8BA54896414060AB048BC3D14940643F8BA54896414080EF366F9CD0494049BC3C9D2B94414080EF366F9CD04940
13060	Речица	1	8	811	35.408211000000001	35.452444	51.705162999999999	51.688628000000001	0103000020E61000000100000005000000096F0F4240B44140118E59F624D84940096F0F4240B44140B4ACFBC742DA4940BEA25BAFE9B94140B4ACFBC742DA4940BEA25BAFE9B94140118E59F624D84940096F0F4240B44140118E59F624D84940
54511	Пригородная Слобода	1	8	811	35.296847	35.327857000000002	51.701428999999997	51.684395000000002	0103000020E6100000010000000500000036751E15FFA54140E1455F419AD7494036751E15FFA54140A5BBEB6CC8D94940E161DA37F7A94140A5BBEB6CC8D94940E161DA37F7A94140E1455F419AD7494036751E15FFA54140E1455F419AD74940
13532	Полячково	1	8	811	35.339139000000003	35.390675999999999	51.780225000000002	51.765635000000003	0103000020E610000001000000050000002AE620E868AB414024D6E25300E249402AE620E868AB4140C442AD69DEE3494082AAD1AB01B24140C442AD69DEE3494082AAD1AB01B2414024D6E25300E249402AE620E868AB414024D6E25300E24940
13132	Погореловка	1	8	811	35.454214	35.481369999999998	51.654690000000002	51.642279000000002	0103000020E6100000010000000500000053B131AF23BA41402CF4C13236D2494053B131AF23BA41405682C5E1CCD3494044A33B889DBD41405682C5E1CCD3494044A33B889DBD41402CF4C13236D2494053B131AF23BA41402CF4C13236D24940
13617	Ольшанка	1	8	811	35.408346000000002	35.449497000000001	51.789060999999997	51.757624999999997	0103000020E61000000100000005000000E9B985AE44B44140E5D022DBF9E04940E9B985AE44B4414047C66AF3FFE449403753211E89B9414047C66AF3FFE449403753211E89B94140E5D022DBF9E04940E9B985AE44B44140E5D022DBF9E04940
12261	Нижние Деревеньки	1	8	811	35.252837999999997	35.316932999999999	51.669618	51.639769000000001	0103000020E61000000100000005000000D097DEFE5CA0414050FF59F3E3D14940D097DEFE5CA041400E68E90AB6D54940F702B34291A841400E68E90AB6D54940F702B34291A8414050FF59F3E3D14940D097DEFE5CA0414050FF59F3E3D14940
13811	Марица	1	8	811	35.216070000000002	35.282195000000002	51.767240000000001	51.741622	0103000020E61000000100000005000000C8D2872EA89B41403FFF3D78EDDE4940C8D2872EA89B41406E179AEB34E24940200C3CF71EA441406E179AEB34E24940200C3CF71EA441403FFF3D78EDDE4940C8D2872EA89B41403FFF3D78EDDE4940
12175	Малые Угоны	1	8	811	35.381073000000001	35.419601	51.624267000000003	51.614766000000003	0103000020E61000000100000005000000BE310400C7B04140AC58FCA6B0CE4940BE310400C7B041406C7C26FBE7CF4940382F4E7CB5B541406C7C26FBE7CF4940382F4E7CB5B54140AC58FCA6B0CE4940BE310400C7B04140AC58FCA6B0CE4940
12876	Малеевка	1	8	811	35.209682999999998	35.248302000000002	51.587739999999997	51.571016999999998	0103000020E610000001000000050000007AC37DE4D69A4140E23AC61517C949407AC37DE4D69A4140884677103BCB494005C4245CC89F4140884677103BCB494005C4245CC89F4140E23AC61517C949407AC37DE4D69A4140E23AC61517C94940
5951	Льгов	1	8	811	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
12743	Левшинка	1	8	811	35.208201000000003	35.259988999999997	51.548250000000003	51.436112000000001	0103000020E610000001000000050000004CFF9254A69A414053B29C84D2B749404CFF9254A69A41401904560E2DC64940ED28CE5147A141401904560E2DC64940ED28CE5147A1414053B29C84D2B749404CFF9254A69A414053B29C84D2B74940
13672	Кудинцево	1	8	811	35.154257000000001	35.204670999999998	51.740099999999998	51.712300999999997	0103000020E61000000100000005000000EC1681B1BE9341403CF4DDAD2CDB4940EC1681B1BE93414082E2C798BBDE494045B8C9A8329A414082E2C798BBDE494045B8C9A8329A41403CF4DDAD2CDB4940EC1681B1BE9341403CF4DDAD2CDB4940
5776	Кромские Быки	1	8	811	35.269779999999997	35.288564000000001	51.497791999999997	51.477485000000001	0103000020E61000000100000005000000B48EAA2688A2414050AA7D3A1EBD4940B48EAA2688A24140EF1AF4A5B7BF4940C76647AAEFA44140EF1AF4A5B7BF4940C76647AAEFA4414050AA7D3A1EBD4940B48EAA2688A2414050AA7D3A1EBD4940
54528	Красная Дубрава	1	8	811	35.306575000000002	35.314695999999998	51.795963	51.786799999999999	0103000020E61000000100000005000000B7627FD93DA74140143FC6DCB5E44940B7627FD93DA74140BCE9961DE2E549404C1762F547A84140BCE9961DE2E549404C1762F547A84140143FC6DCB5E44940B7627FD93DA74140143FC6DCB5E44940
13266	Колонтаевка	1	8	811	35.114353999999999	35.141088000000003	51.572181	51.556885000000001	0103000020E610000001000000050000005915E126A38E41400551F70148C749405915E126A38E414040321D3A3DC94940D5EDEC2B0F92414040321D3A3DC94940D5EDEC2B0F9241400551F70148C749405915E126A38E41400551F70148C74940
12126	Клишино	1	8	811	35.344233000000003	35.362738	51.622970000000002	51.612574000000002	0103000020E610000001000000050000001C9AB2D30FAC4140A13028D368CE49401C9AB2D30FAC4140CF31207BBDCF49401B82E3326EAE4140CF31207BBDCF49401B82E3326EAE4140A13028D368CE49401C9AB2D30FAC4140A13028D368CE4940
13253	Износково	1	8	811	35.078574000000003	35.110689000000001	51.596446999999998	51.560558999999998	0103000020E6100000010000000500000070287CB60E8A41403E3DB665C0C7494070287CB60E8A41400E66136058CC49407383A10E2B8E41400E66136058CC49407383A10E2B8E41403E3DB665C0C7494070287CB60E8A41403E3DB665C0C74940
13468	Иванчиково	1	8	811	35.326805999999998	35.346128	51.772813999999997	51.748386000000004	0103000020E610000001000000050000007B116DC7D4A941406364C91CCBDF49407B116DC7D4A941400AF2B391EBE249406D1D1CEC4DAC41400AF2B391EBE249406D1D1CEC4DAC41406364C91CCBDF49407B116DC7D4A941406364C91CCBDF4940
54543	Деревеньки	1	8	811	35.336497999999999	35.353476000000001	51.527203	51.518343000000002	0103000020E61000000100000005000000AF95D05D12AB4140268E3C1059C24940AF95D05D12AB414032AD4D637BC34940E0F599B33EAD414032AD4D637BC34940E0F599B33EAD4140268E3C1059C24940AF95D05D12AB4140268E3C1059C24940
13182	Густомой	1	8	811	35.014201	35.077621999999998	51.653187000000003	51.619149999999998	0103000020E6100000010000000500000006499F56D1814140C1A8A44E40CF494006499F56D18141401096B1A19BD349409DB98784EF8941401096B1A19BD349409DB98784EF894140C1A8A44E40CF494006499F56D1814140C1A8A44E40CF4940
12900	Городенск	1	8	811	35.346074000000002	35.401392999999999	51.691274	51.649794999999997	0103000020E610000001000000050000007AFF1F274CAC41405A0D897B2CD349407AFF1F274CAC41409D499BAA7BD84940F2EB87D860B341409D499BAA7BD84940F2EB87D860B341405A0D897B2CD349407AFF1F274CAC41405A0D897B2CD34940
13897	Глиница	1	8	811	35.151257000000001	35.182068999999998	51.611131	51.592933000000002	0103000020E610000001000000050000004225AE635C9341400EDC813AE5CB49404225AE635C9341403049658A39CE4940C64E78094E9741403049658A39CE4940C64E78094E9741400EDC813AE5CB49404225AE635C9341400EDC813AE5CB4940
12384	Вышние Деревеньки	1	8	811	35.283991999999998	35.314058000000003	51.567383999999997	51.529819000000003	0103000020E61000000100000005000000AE2990D959A4414054E6E61BD1C34940AE2990D959A441400723F609A0C849400A86730D33A841400723F609A0C849400A86730D33A8414054E6E61BD1C34940AE2990D959A4414054E6E61BD1C34940
13753	Воронино	1	8	811	35.217067	35.252048000000002	51.701506999999999	51.686182000000002	0103000020E610000001000000050000003A05F9D9C89B41404C8DD0CFD4D749403A05F9D9C89B414021753BFBCAD94940D882DE1B43A0414021753BFBCAD94940D882DE1B43A041404C8DD0CFD4D749403A05F9D9C89B41404C8DD0CFD4D74940
13106	Борисовка	1	8	811	35.436839999999997	35.462873000000002	51.680191000000001	51.657004000000001	0103000020E61000000100000005000000D5CA845FEAB74140ACAB02B518D44940D5CA845FEAB741404B04AA7F10D74940C899266C3FBB41404B04AA7F10D74940C899266C3FBB4140ACAB02B518D44940D5CA845FEAB74140ACAB02B518D44940
12010	Большие Угоны	1	8	811	35.380668	35.440289999999997	51.608105000000002	51.580269000000001	0103000020E610000001000000050000001E51A1BAB9B04140FAF02C4146CA49401E51A1BAB9B041405DC47762D6CD4940BF60376C5BB841405DC47762D6CD4940BF60376C5BB84140FAF02C4146CA49401E51A1BAB9B04140FAF02C4146CA4940
6047	Большая Орловка	1	8	811	35.273670000000003	35.300871000000001	51.590947	51.564292999999999	0103000020E61000000100000005000000BBF2599E07A341404D2EC6C03AC84940BBF2599E07A34140AC55BB26A4CB49404CA8E0F082A64140AC55BB26A4CB49404CA8E0F082A641404D2EC6C03AC84940BBF2599E07A341404D2EC6C03AC84940
13393	Банищи	1	8	811	35.028447999999997	35.109332000000002	51.709321000000003	51.674689999999998	0103000020E610000001000000050000007CD11E2FA48341401878EE3D5CD649407CD11E2FA4834140DAAED007CBDA494001344A97FE8D4140DAAED007CBDA494001344A97FE8D41401878EE3D5CD649407CD11E2FA48341401878EE3D5CD64940
12783	Арсеньевка	1	8	811	35.226239	35.249344000000001	51.614122999999999	51.602131	0103000020E61000000100000005000000350A4966F59C41403274ECA012CD4940350A4966F59C4140575C1C959BCE494017BA1281EA9F4140575C1C959BCE494017BA1281EA9F41403274ECA012CD4940350A4966F59C41403274ECA012CD4940
11938	Чапли	1	8	770	35.527256000000001	35.549157000000001	51.628768000000001	51.580829000000001	0103000020E61000000100000005000000554FE61F7DC34140C1C8CB9A58CA4940554FE61F7DC34140BB6246787BD049404BAFCDC64AC64140BB6246787BD049404BAFCDC64AC64140C1C8CB9A58CA4940554FE61F7DC34140C1C8CB9A58CA4940
11372	Сопеловка	1	8	770	35.571047999999998	35.596677	51.544155000000003	51.533366000000001	0103000020E610000001000000050000001D39D21918C9414030664B5645C449401D39D21918C941403A7AFCDEA6C5494040A374E95FCC41403A7AFCDEA6C5494040A374E95FCC414030664B5645C449401D39D21918C9414030664B5645C44940
11392	Новосергеевка	1	8	770	35.487748000000003	35.573860000000003	51.515405999999999	51.471066999999998	0103000020E610000001000000050000003F58C6866EBE4140C79C67EC4BBC49403F58C6866EBE4140C214E5D2F8C14940C53D963E74C94140C214E5D2F8C14940C53D963E74C94140C79C67EC4BBC49403F58C6866EBE4140C79C67EC4BBC4940
11447	Никольский	1	8	770	35.610691000000003	35.622495000000001	51.507109999999997	51.499524999999998	0103000020E61000000100000005000000147B681F2BCE41406744696FF0BF4940147B681F2BCE4140BEBC00FBE8C04940367689EAADCF4140BEBC00FBE8C04940367689EAADCF41406744696FF0BF4940147B681F2BCE41406744696FF0BF4940
11487	Николаевка	1	8	770	35.637757000000001	35.644413999999998	51.855634999999999	51.853293000000001	0103000020E61000000100000005000000C5E57805A2D14140EF737CB438ED4940C5E57805A2D141400F289B7285ED4940D28A6F287CD241400F289B7285ED4940D28A6F287CD24140EF737CB438ED4940C5E57805A2D14140EF737CB438ED4940
11711	Нижнее Сосково	1	8	770	35.694826999999997	35.729205999999998	51.768282999999997	51.754514	0103000020E610000001000000050000005BB05417F0D84140E42F2DEA93E049405BB05417F0D841405089EB1857E249400306499F56DD41405089EB1857E249400306499F56DD4140E42F2DEA93E049405BB05417F0D84140E42F2DEA93E04940
11889	Мосолово	1	8	770	35.665838999999998	35.684344000000003	51.701774999999998	51.690995000000001	0103000020E610000001000000050000005FB35C363AD541408A592F8672D849405FB35C363AD54140401361C3D3D949405F9B8D9598D74140401361C3D3D949405F9B8D9598D741408A592F8672D849405FB35C363AD541408A592F8672D84940
11581	Мармыжи	1	8	770	35.483085000000003	35.512262999999997	51.820698999999998	51.790103000000002	0103000020E610000001000000050000001618B2BAD5BD41405ABC581822E549401618B2BAD5BD4140116E32AA0CE94940B5F97FD591C14140116E32AA0CE94940B5F97FD591C141405ABC581822E549401618B2BAD5BD41405ABC581822E54940
5993	Макаровка	1	8	770	35.507097000000002	35.544485000000002	51.709488	51.680005999999999	0103000020E610000001000000050000002A73F38DE8C04140B98AC56F0AD749402A73F38DE8C04140C573B680D0DA4940CF143AAFB1C54140C573B680D0DA4940CF143AAFB1C54140B98AC56F0AD749402A73F38DE8C04140B98AC56F0AD74940
11307	Любицкое	1	8	770	35.564732999999997	35.590685999999998	51.587992	51.567776000000002	0103000020E6100000010000000500000069FCC22B49C8414013BA4BE2ACC8494069FCC22B49C84140A227655243CB49403F1A4E999BCB4140A227655243CB49403F1A4E999BCB414013BA4BE2ACC8494069FCC22B49C8414013BA4BE2ACC84940
11558	Костельцево	1	8	770	35.545734000000003	35.574426000000003	51.835766	51.815097999999999	0103000020E610000001000000050000005B28999CDAC541407B849A2155E849405B28999CDAC54140EB8D5A61FAEA49406EFC89CA86C94140EB8D5A61FAEA49406EFC89CA86C941407B849A2155E849405B28999CDAC541407B849A2155E84940
10785	Имени Карла Либкнехта	1	8	770	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
11067	Иванино	1	8	770	35.562820000000002	35.600693	51.660563000000003	51.624653000000002	0103000020E6100000010000000500000072C45A7C0AC84140952C27A1F4CF494072C45A7C0AC841404DF910548DD44940D3F71A82E3CC41404DF910548DD44940D3F71A82E3CC4140952C27A1F4CF494072C45A7C0AC84140952C27A1F4CF4940
11641	Жмакино	1	8	770	35.599533999999998	35.615200999999999	51.783723999999999	51.767274	0103000020E61000000100000005000000876BB587BDCC41401A89D00836E24940876BB587BDCC41408F8B6A1151E44940B6BB07E8BECE41408F8B6A1151E44940B6BB07E8BECE41401A89D00836E24940876BB587BDCC41401A89D00836E24940
11259	Дружная	1	8	770	35.569414000000002	35.585287000000001	51.624462999999999	51.605598999999998	0103000020E6100000010000000500000039F1D58EE2C84140C2BE9D4484CD494039F1D58EE2C84140F1475167EECF494011E335AFEACA4140F1475167EECF494011E335AFEACA4140C2BE9D4484CD494039F1D58EE2C84140C2BE9D4484CD4940
5414	Дроняево	1	8	770	35.599085000000002	35.636940000000003	51.722529000000002	51.699871000000002	0103000020E61000000100000005000000184339D1AECC41409C35785F95D94940184339D1AECC4140AFB48CD47BDC4940D3C1FA3F87D14140AFB48CD47BDC4940D3C1FA3F87D141409C35785F95D94940184339D1AECC41409C35785F95D94940
5463	Дичня	1	8	770	35.707610000000003	35.753459999999997	51.671322000000004	51.650460000000002	0103000020E610000001000000050000004A29E8F692DA414097ADF54542D349404A29E8F692DA4140EC8A19E1EDD549400D6C956071E04140EC8A19E1EDD549400D6C956071E0414097ADF54542D349404A29E8F692DA414097ADF54542D34940
11991	Быки	1	8	770	35.489463000000001	35.526446999999997	51.672823999999999	51.652164999999997	0103000020E6100000010000000500000010CD3CB9A6BE4140444C89247AD3494010CD3CB9A6BE414061FBC9181FD64940E509849D62C3414061FBC9181FD64940E509849D62C34140444C89247AD3494010CD3CB9A6BE4140444C89247AD34940
54506	Имени Карла Либкнехта	1	8	7322	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
2066	Мяснянкино	1	8	395	35.645769999999999	35.676385000000003	51.667512000000002	51.653986000000003	0103000020E61000000100000005000000745E6397A8D241405C0531D0B5D34940745E6397A8D2414002D8800871D54940A3409FC893D6414002D8800871D54940A3409FC893D641405C0531D0B5D34940745E6397A8D241405C0531D0B5D34940
54527	Шумаков	1	8	269	35.951583999999997	35.974184999999999	51.822412999999997	51.812331	0103000020E61000000100000005000000CCB22781CDF9414074435376FAE74940CCB22781CDF94140126745D444E949407BA01518B2FC4140126745D444E949407BA01518B2FC414074435376FAE74940CCB22781CDF9414074435376FAE74940
8125	Шеховцово	1	8	269	36.466408000000001	36.488695	51.723928999999998	51.717457000000003	0103000020E61000000100000005000000E04BE141B33B4240A5A487A1D5DB4940E04BE141B33B424020D099B4A9DC4940FF5BC98E8D3E424020D099B4A9DC4940FF5BC98E8D3E4240A5A487A1D5DB4940E04BE141B33B4240A5A487A1D5DB4940
9195	Черемушки	1	8	269	36.242888999999998	36.265653	51.606231000000001	51.595440000000004	0103000020E6100000010000000500000071C79BFC161F4240795DBF6037CC494071C79BFC161F4240236937FA98CD4940CA8AE1EA00224240236937FA98CD4940CA8AE1EA00224240795DBF6037CC494071C79BFC161F4240795DBF6037CC4940
54472	Ушаково	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
40320	Троица	1	8	269	36.566265000000001	36.584797000000002	51.763779	51.748866	0103000020E610000001000000050000004AEF1B5F7B4842400D8B51D7DADF49404AEF1B5F7B484240902FA182C3E1494043E6CAA0DA4A4240902FA182C3E1494043E6CAA0DA4A42400D8B51D7DADF49404AEF1B5F7B4842400D8B51D7DADF4940
9637	Селиховы Дворы	1	8	269	36.076953000000003	36.087310000000002	51.583840000000002	51.576911000000003	0103000020E61000000100000005000000202A8D98D9094240F1D93A38D8C94940202A8D98D90942405F0CE544BBCA4940904E5DF92C0B42405F0CE544BBCA4940904E5DF92C0B4240F1D93A38D8C94940202A8D98D9094240F1D93A38D8C94940
54504	Сахаровка	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
54521	Сапогово	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
54464	Рышково	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
54540	Разиньково	1	8	269	35.902966999999997	35.935288	51.861603000000002	51.836906999999997	0103000020E61000000100000005000000012F336C94F341409065C1C41FEB4940012F336C94F341405891D10149EE4940AE2B6684B7F741405891D10149EE4940AE2B6684B7F741409065C1C41FEB4940012F336C94F341409065C1C41FEB4940
10229	Полянское	1	8	269	35.974096000000003	35.996876999999998	51.763004000000002	51.727800999999999	0103000020E610000001000000050000000C957F2DAFFC4140807F4A9528DD49400C957F2DAFFC4140CD5B751DAAE149403A9160AA99FF4140CD5B751DAAE149403A9160AA99FF4140807F4A9528DD49400C957F2DAFFC4140807F4A9528DD4940
10140	Полевая	1	8	269	36.481256999999999	36.544373	51.619351999999999	51.584885999999997	0103000020E610000001000000050000004CFC51D4993D4240B2F1608BDDCA49404CFC51D4993D4240295B24ED46CF4940A7E9B303AE454240295B24ED46CF4940A7E9B303AE454240B2F1608BDDCA49404CFC51D4993D4240B2F1608BDDCA4940
54547	Подлесный	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
8177	Петровское	1	8	269	36.546852000000001	36.583620000000003	51.747616999999998	51.729112000000001	0103000020E6100000010000000500000048E00F3FFF454240828FC18A53DD494048E00F3FFF4542408177F2E9B1DF494051A5660FB44A42408177F2E9B1DF494051A5660FB44A4240828FC18A53DD494048E00F3FFF454240828FC18A53DD4940
9261	Петрин	1	8	269	36.223647999999997	36.239232999999999	51.588937999999999	51.579250999999999	0103000020E610000001000000050000006CE8667FA01C4240709692E524CA49406CE8667FA01C424092AF045262CB4940DE8FDB2F9F1E424092AF045262CB4940DE8FDB2F9F1E4240709692E524CA49406CE8667FA01C4240709692E524CA4940
9543	Ноздрачево	1	8	269	36.334392000000001	36.372615000000003	51.83005	51.814574999999998	0103000020E61000000100000005000000A305685BCD2A4240D1915CFE43E84940A305685BCD2A4240BC0512143FEA4940E17F2BD9B12F4240BC0512143FEA4940E17F2BD9B12F4240D1915CFE43E84940A305685BCD2A4240D1915CFE43E84940
54520	Михайлово	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
8523	Малиновый	1	8	269	36.432685999999997	36.441668999999997	51.803866999999997	51.796292000000001	0103000020E61000000100000005000000F1B73D4162374240810871E5ECE54940F1B73D4162374240B4AA251DE5E6494019541B9C88384240B4AA251DE5E6494019541B9C88384240810871E5ECE54940F1B73D4162374240810871E5ECE54940
52648	Лисово	1	8	269	36.594670000000001	36.604497000000002	51.607204000000003	51.591735999999997	0103000020E61000000100000005000000C7F484251E4C4240D4EE5701BECB4940C7F484251E4C42400D0055DCB8CD4940DBC35E28604D42400D0055DCB8CD4940DBC35E28604D4240D4EE5701BECB4940C7F484251E4C4240D4EE5701BECB4940
54532	Лебяжье	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
10125	Колодное	1	8	269	36.391668000000003	36.470855	51.648778	51.622394	0103000020E61000000100000005000000E371512D22324240029D499BAACF4940E371512D22324240A12E52280BD349403C1405FA443C4240A12E52280BD349403C1405FA443C4240029D499BAACF4940E371512D22324240029D499BAACF4940
8840	Клюква	1	8	269	36.340589999999999	36.366605	51.727789999999999	51.703499999999998	0103000020E610000001000000050000001DACFF73982B4240355EBA490CDA49401DACFF73982B42408C2D043928DD494069C6A2E9EC2E42408C2D043928DD494069C6A2E9EC2E4240355EBA490CDA49401DACFF73982B4240355EBA490CDA4940
10079	Кизилово	1	8	269	36.483324000000003	36.554560000000002	51.587147000000002	51.552320999999999	0103000020E610000001000000050000009BAF928FDD3D42406FF25B74B2C649409BAF928FDD3D4240E67805A227CB4940BBD573D2FB464240E67805A227CB4940BBD573D2FB4642406FF25B74B2C649409BAF928FDD3D42406FF25B74B2C64940
54505	Касиновский	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
54473	Камыши	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
54487	Искра	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
54495	Зорино	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
10293	Жеребцово	1	8	269	35.973835000000001	35.997425	51.723711000000002	51.696891000000001	0103000020E610000001000000050000009F5912A0A6FC414039F06AB933D949409F5912A0A6FC4140B360E28FA2DC49403D9B559FABFF4140B360E28FA2DC49403D9B559FABFF414039F06AB933D949409F5912A0A6FC414039F06AB933D94940
8441	Дроняево	1	8	269	35.990912000000002	36.013782999999997	51.875489000000002	51.857849000000002	0103000020E61000000100000005000000639B5434D6FE414002F4FBFECDED4940639B5434D6FE4140FE80070610F04940D11E2FA4C3014240FE80070610F04940D11E2FA4C301424002F4FBFECDED4940639B5434D6FE414002F4FBFECDED4940
1129	Гнездилово	1	8	269	35.969757000000001	35.987768000000003	51.815510000000003	51.802218000000003	0103000020E61000000100000005000000960854FF20FC41409B215514AFE64940960854FF20FC4140CEC7B5A162E8494086048C2E6FFE4140CEC7B5A162E8494086048C2E6FFE41409B215514AFE64940960854FF20FC41409B215514AFE64940
9776	Глебово	1	8	269	36.185056000000003	36.196041999999998	51.869160999999998	51.861235999999998	0103000020E61000000100000005000000DCF63DEAAF174240A51133FB3CEE4940DCF63DEAAF174240B5FAEAAA40EF49403B527DE717194240B5FAEAAA40EF49403B527DE717194240A51133FB3CEE4940DCF63DEAAF174240A51133FB3CEE4940
54479	Ворошнево	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
52592	Волобуево	1	8	269	36.163685000000001	36.285344000000002	51.903454000000004	51.872058000000003	0103000020E6100000010000000500000042EC4CA1F31442408B1BB7989FEF494042EC4CA1F31442405FB87361A4F349400F0EF626862442405FB87361A4F349400F0EF626862442408B1BB7989FEF494042EC4CA1F31442408B1BB7989FEF4940
54501	Военный городок	1	8	269	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
9616	Виногробль	1	8	269	36.402133999999997	36.461917	51.882199999999997	51.833523	0103000020E61000000100000005000000094E7D20793342405EBBB4E1B0EA4940094E7D2079334240FE43FAEDEBF04940B43BA418203B4240FE43FAEDEBF04940B43BA418203B42405EBBB4E1B0EA4940094E7D20793342405EBBB4E1B0EA4940
9428	Верхняя Медведица	1	8	269	36.086601000000002	36.107657000000003	51.855896000000001	51.839506	0103000020E610000001000000050000008466D7BD150B4240DC65BFEE74EB49408466D7BD150B42407C6308008EED4940BE175FB4C70D42407C6308008EED4940BE175FB4C70D4240DC65BFEE74EB49408466D7BD150B4240DC65BFEE74EB4940
8408	Верхнекасиново	1	8	269	36.031551999999998	36.067646000000003	51.838298000000002	51.825391000000003	0103000020E61000000100000005000000CB0F5CE509044240D5B48B69A6E94940CB0F5CE509044240AF264F594DEB494045DAC69FA8084240AF264F594DEB494045DAC69FA8084240D5B48B69A6E94940CB0F5CE509044240D5B48B69A6E94940
10005	Верхнее Гуторово	1	8	269	36.551389	36.604990999999998	51.610146	51.559399999999997	0103000020E61000000100000005000000E42F2DEA93464240F2B0506B9AC74940E42F2DEA9346424082E49D4319CE4940EAAF5758704D424082E49D4319CE4940EAAF5758704D4240F2B0506B9AC74940E42F2DEA93464240F2B0506B9AC74940
10525	Введенское	1	8	269	36.329388000000002	36.385900999999997	51.695601000000003	51.634743999999998	0103000020E61000000100000005000000F1D8CF62292A424086AA984A3FD14940F1D8CF62292A42404F081D7409D94940313F3734653142404F081D7409D94940313F37346531424086AA984A3FD14940F1D8CF62292A424086AA984A3FD14940
8075	Букреево	1	8	269	36.301153999999997	36.546556000000002	51.725892999999999	51.664411999999999	0103000020E61000000100000005000000A087DA368C264240F488D1730BD54940A087DA368C2642409AB2D30FEADC49405FB7088CF54542409AB2D30FEADC49405FB7088CF5454240F488D1730BD54940A087DA368C264240F488D1730BD54940
9139	Букреевка	1	8	269	36.230699000000001	36.277645	51.857692999999998	51.838397999999998	0103000020E61000000100000005000000261C7A8B871D424012842BA050EB4940261C7A8B871D42400A815CE2C8ED4940EF7211DF892342400A815CE2C8ED4940EF7211DF8923424012842BA050EB4940261C7A8B871D424012842BA050EB4940
10449	Большое Шумаково	1	8	269	36.352770999999997	36.374358000000001	51.678553999999998	51.617272	0103000020E6100000010000000500000015FDA199272D4240465ED6C402CF494015FDA199272D4240F54883DBDAD649407C7F83F6EA2F4240F54883DBDAD649407C7F83F6EA2F4240465ED6C402CF494015FDA199272D4240465ED6C402CF4940
5879	Большое Лукино	1	8	269	35.973295999999998	35.988135999999997	51.794153000000001	51.775823000000003	0103000020E61000000100000005000000EFA99CF694FC4140083E062B4EE34940EFA99CF694FC4140998235CEA6E5494008008E3D7BFE4140998235CEA6E5494008008E3D7BFE4140083E062B4EE34940EFA99CF694FC4140083E062B4EE34940
8021	Беседино	1	8	269	36.449655	36.493626999999996	51.716017000000001	51.701456999999998	0103000020E61000000100000005000000CFBD874B8E3942406F46CD57C9D94940CFBD874B8E394240A530EF71A6DB494017B6662B2F3F4240A530EF71A6DB494017B6662B2F3F42406F46CD57C9D94940CFBD874B8E3942406F46CD57C9D94940
54556	Безлесное 2-е	1	8	269	36.301746999999999	36.325966000000001	51.606237	51.597738999999997	0103000020E6100000010000000500000043554CA59F264240994528B682CC494043554CA59F26424005508C2C99CD4940D1CDFE40B929424005508C2C99CD4940D1CDFE40B9294240994528B682CC494043554CA59F264240994528B682CC4940
9986	Барышниково	1	8	269	36.500588999999998	36.543618000000002	51.635162999999999	51.620939999999997	0103000020E6100000010000000500000061DEE34C134042409D6340F67ACF494061DEE34C134042408B506C054DD149402BC24D46954542408B506C054DD149402BC24D46954542409D6340F67ACF494061DEE34C134042409D6340F67ACF4940
7969	Алябьево	1	8	269	36.18573	36.444201999999997	51.889454000000001	51.666941999999999	0103000020E610000001000000050000006BF12900C6174240172AFF5A5ED549406BF12900C6174240F0A5F0A0D9F14940AD68739CDB384240F0A5F0A0D9F14940AD68739CDB384240172AFF5A5ED549406BF12900C6174240172AFF5A5ED54940
9834	1-е Курасово	1	8	269	36.135694000000001	36.156903	51.905875999999999	51.894700999999998	0103000020E61000000100000005000000B821C66B5E1142406859F78F85F24940B821C66B5E1142409B1DA9BEF3F3494078D2C265151442409B1DA9BEF3F3494078D2C265151442406859F78F85F24940B821C66B5E1142406859F78F85F24940
40205	1-е Винниково	1	8	269	36.465420000000002	36.501666999999998	51.823481999999998	51.809824999999996	0103000020E61000000100000005000000C173EFE1923B4240D93D7958A8E74940C173EFE1923B42401E6CB1DB67E94940C03DCF9F364042401E6CB1DB67E94940C03DCF9F36404240D93D7958A8E74940C173EFE1923B4240D93D7958A8E74940
7932	Шептуховка	1	8	752	35.137557000000001	35.189793999999999	51.450467000000003	51.423617999999998	0103000020E61000000100000005000000FE2AC0779B9141409BFF571D39B64940FE2AC0779B914140B07614E7A8B949400F7D772B4B984140B07614E7A8B949400F7D772B4B9841409BFF571D39B64940FE2AC0779B9141409BFF571D39B64940
6998	Троицкое	1	8	752	34.805458999999999	34.832678000000001	51.200819000000003	51.184669999999997	0103000020E610000001000000050000006AA2CF4719674140B2463D44A39749406AA2CF47196741402DB5DE6FB4994940A20C5531956A41402DB5DE6FB4994940A20C5531956A4140B2463D44A39749406AA2CF4719674140B2463D44A3974940
7736	Толпино	1	8	752	34.875850999999997	34.911262999999998	51.454670999999998	51.438594000000002	0103000020E610000001000000050000009E95B4E21B704140651C23D923B849409E95B4E21B70414045B8C9A832BA494005871744A474414045B8C9A832BA494005871744A4744140651C23D923B849409E95B4E21B704140651C23D923B84940
7609	Снагость	1	8	752	34.863194	34.939172999999997	51.335661999999999	51.293033999999999	0103000020E610000001000000050000003D0D18247D6E4140DB4E5B2382A549403D0D18247D6E41404641F0F8F6AA4940A22424D2367841404641F0F8F6AA4940A22424D236784140DB4E5B2382A549403D0D18247D6E4140DB4E5B2382A54940
7876	Сафоновка	1	8	752	35.131413000000002	35.156117000000002	51.501936000000001	51.476788999999997	0103000020E6100000010000000500000077A22424D2904140D80B056C07BD494077A22424D2904140B05758703FC04940C1AC50A4FB934140B05758703FC04940C1AC50A4FB934140D80B056C07BD494077A22424D2904140D80B056C07BD4940
7568	Пушкарное	1	8	752	34.803708	34.830351999999998	51.507088000000003	51.475408999999999	0103000020E610000001000000050000004CC45BE7DF664140AE9CBD33DABC49404CC45BE7DF664140D7187442E8C0494087156EF9486A4140D7187442E8C0494087156EF9486A4140AE9CBD33DABC49404CC45BE7DF664140AE9CBD33DABC4940
7476	Ольговка	1	8	752	34.992272999999997	35.040396000000001	51.410361999999999	51.395276000000003	0103000020E6100000010000000500000016DA39CD027F414065726A6798B2494016DA39CD027F4140B5C2F4BD86B44940D27135B22B854140B5C2F4BD86B44940D27135B22B85414065726A6798B2494016DA39CD027F414065726A6798B24940
7333	Обуховка	1	8	752	34.922742999999997	34.986272	51.288511	51.275227000000001	0103000020E6100000010000000500000074CE4F711C764140F4FC69A33AA3494074CE4F711C764140A4C4AEEDEDA44940F27A30293E7E4140A4C4AEEDEDA44940F27A30293E7E4140F4FC69A33AA3494074CE4F711C764140F4FC69A33AA34940
7688	Нижняя Груня	1	8	752	34.940610999999997	34.99248	51.537500999999999	51.531483999999999	0103000020E6100000010000000500000001A1F5F065784140732CEFAA07C4494001A1F5F0657841409D4830D5CCC4494090F7AA95097F41409D4830D5CCC4494090F7AA95097F4140732CEFAA07C4494001A1F5F065784140732CEFAA07C44940
7293	Любимовка	1	8	752	35.004364000000002	35.065215999999999	51.323011000000001	51.292324999999998	0103000020E61000000100000005000000CFA3E2FF8E804140CF66D5E76AA54940CFA3E2FF8E804140C79FA86C58A94940859675FF58884140C79FA86C58A94940859675FF58884140CF66D5E76AA54940CFA3E2FF8E804140CF66D5E76AA54940
7405	Кремяное	1	8	752	35.048327999999998	35.102891	51.403855999999998	51.381307999999997	0103000020E6100000010000000500000094BDA59C2F86414001DA56B3CEB0494094BDA59C2F8641408D25AC8DB1B34940C00644882B8D41408D25AC8DB1B34940C00644882B8D414001DA56B3CEB0494094BDA59C2F86414001DA56B3CEB04940
29051	Краснооктябрьское	1	8	752	34.786890999999997	34.838095000000003	51.357118999999997	51.340659000000002	0103000020E61000000100000005000000244223D8B8644140460BD0B69AAB4940244223D8B8644140DEE34C13B6AD494077F86BB2466B4140DEE34C13B6AD494077F86BB2466B4140460BD0B69AAB4940244223D8B8644140460BD0B69AAB4940
6769	Коренево	1	8	752	34.874198	34.924225999999997	51.434074000000003	51.393442999999998	0103000020E61000000100000005000000431D56B8E56F414089EB18575CB24940431D56B8E56F41409F05A1BC8FB74940730E9E094D7641409F05A1BC8FB74940730E9E094D76414089EB18575CB24940431D56B8E56F414089EB18575CB24940
7050	Комаровка	1	8	752	34.763562	34.810687000000001	51.329033000000003	51.305548000000002	0103000020E61000000100000005000000F33B4D66BC614140DAAD65321CA74940F33B4D66BC6141400327DBC01DAA49406C257497C46741400327DBC01DAA49406C257497C4674140DAAD65321CA74940F33B4D66BC614140DAAD65321CA74940
7821	Каучук	1	8	752	35.184502999999999	35.204608	51.473322000000003	51.461965999999997	0103000020E61000000100000005000000C78157CB9D97414095EEAEB321BB4940C78157CB9D974140193DB7D095BC4940FF3F4E98309A4140193DB7D095BC4940FF3F4E98309A414095EEAEB321BB4940C78157CB9D97414095EEAEB321BB4940
54537	Журавли	1	8	752	35.082455000000003	35.115817999999997	51.423298000000003	51.409132	0103000020E610000001000000050000002332ACE28D8A4140A0DFF76F5EB449402332ACE28D8A41402A3BFDA02EB64940E124CD1FD38E41402A3BFDA02EB64940E124CD1FD38E4140A0DFF76F5EB449402332ACE28D8A4140A0DFF76F5EB44940
6950	Гордеевка	1	8	752	34.863633999999998	34.884798000000004	51.219005000000003	51.197268999999999	0103000020E6100000010000000500000059DB148F8B6E4140DFC14F1C4099494059DB148F8B6E41408B54185B089C49407AC8940F417141408B54185B089C49407AC8940F41714140DFC14F1C4099494059DB148F8B6E4140DFC14F1C40994940
6905	Внезапное	1	8	752	34.866481999999998	34.884574000000001	51.270054000000002	51.229429000000003	0103000020E610000001000000050000004D49D6E1E86E414083E0F1ED5D9D49404D49D6E1E86E4140B613252191A249402A7288B839714140B613252191A249402A7288B83971414083E0F1ED5D9D49404D49D6E1E86E414083E0F1ED5D9D4940
7666	Верхняя Груня	1	8	752	34.991033000000002	35.057985000000002	51.540582000000001	51.525835999999998	0103000020E61000000100000005000000DE205A2BDA7E41409C8713984EC34940DE205A2BDA7E414034677DCA31C549404C546F0D6C87414034677DCA31C549404C546F0D6C8741409C8713984EC34940DE205A2BDA7E41409C8713984EC34940
7526	Благодатное	1	8	752	34.857813	34.921216000000001	51.529595	51.520550999999998	0103000020E61000000100000005000000B58AFED0CC6D41403673486AA1C24940B58AFED0CC6D41400490DAC4C9C34940A646E867EA7541400490DAC4C9C34940A646E867EA7541403673486AA1C24940B58AFED0CC6D41403673486AA1C24940
7111	Апанасовка	1	8	752	34.837969000000001	34.872366	51.302112999999999	51.278934	0103000020E61000000100000005000000EA077591426B414009DFFB1BB4A34940EA077591426B4140255987A3ABA64940381268B0A96F4140255987A3ABA64940381268B0A96F414009DFFB1BB4A34940EA077591426B414009DFFB1BB4A34940
7786	Александровка	1	8	752	34.966113999999997	34.995784999999998	51.476160999999998	51.457622999999998	0103000020E61000000100000005000000971AA19FA97B4140DE72F56393BA4940971AA19FA97B4140B950F9D7F2BC4940766C04E2757F4140B950F9D7F2BC4940766C04E2757F4140DE72F56393BA4940971AA19FA97B4140DE72F56393BA4940
5840	Яцено	1	8	721	35.323202999999999	35.372349999999997	51.944071999999998	51.923963999999998	0103000020E610000001000000050000000B7C45B75EA941403657CD7344F649400B7C45B75EA94140DF88EE59D7F849403255302AA9AF4140DF88EE59D7F849403255302AA9AF41403657CD7344F649400B7C45B75EA941403657CD7344F64940
5886	Яндовище	1	8	721	35.327353000000002	35.351851000000003	52.004305000000002	51.993543000000003	0103000020E61000000100000005000000AE9FFEB3E6A94140BA15C26A2CFF4940AE9FFEB3E6A94140CA1AF5108D004A404F081D7409AD4140CA1AF5108D004A404F081D7409AD4140BA15C26A2CFF4940AE9FFEB3E6A94140BA15C26A2CFF4940
6405	Шустово	1	8	721	35.037359000000002	35.093826999999997	51.805292000000001	51.775188	0103000020E610000001000000050000000B9B012EC88441403620425C39E349400B9B012EC88441407FDDE9CE13E74940AB3DEC85028C41407FDDE9CE13E74940AB3DEC85028C41403620425C39E349400B9B012EC88441403620425C39E34940
6617	Ширково	1	8	721	35.174863999999999	35.261175000000001	51.782794000000003	51.771057999999996	0103000020E61000000100000005000000B69F8CF161964140DAA84E07B2E24940B69F8CF161964140A5C0029832E4494033C4B12E6EA14140A5C0029832E4494033C4B12E6EA14140DAA84E07B2E24940B69F8CF161964140DAA84E07B2E24940
5304	Черничено	1	8	721	35.158937000000002	35.196289	51.870462000000003	51.856836000000001	0103000020E61000000100000005000000EB8F300C589441408A0453CDACED4940EB8F300C5894414094347F4C6BEF494043C879FF1F99414094347F4C6BEF494043C879FF1F9941408A0453CDACED4940EB8F300C589441408A0453CDACED4940
6593	Толкачевка	1	8	721	35.228789999999996	35.247591999999997	51.830356000000002	51.815761000000002	0103000020E610000001000000050000006FD39FFD489D4140172D40DB6AE849406FD39FFD489D4140C904FC1A49EA494028603B18B19F4140C904FC1A49EA494028603B18B19F4140172D40DB6AE849406FD39FFD489D4140172D40DB6AE84940
6677	Старая Белица	1	8	721	35.145677999999997	35.224361999999999	51.998151	51.979976000000001	0103000020E6100000010000000500000093DFA293A5924140B56E83DA6FFD494093DFA293A59241401FBC7669C3FF49408A3BDEE4B79C41401FBC7669C3FF49408A3BDEE4B79C4140B56E83DA6FFD494093DFA293A5924140B56E83DA6FFD4940
5621	Севенки	1	8	721	35.320984000000003	35.357931999999998	51.900547000000003	51.876851000000002	0103000020E610000001000000050000000745F30016A94140823B50A73CF049400745F30016A9414066C1C41F45F349408F183DB7D0AD414066C1C41F45F349408F183DB7D0AD4140823B50A73CF049400745F30016A94140823B50A73CF04940
5403	Рыжково	1	8	721	35.469996999999999	35.513447999999997	51.978439999999999	51.956704999999999	0103000020E61000000100000005000000EB1B98DC28BC4140B875374F75FA4940EB1B98DC28BC4140938C9C853DFD49402A1900AAB8C14140938C9C853DFD49402A1900AAB8C14140B875374F75FA4940EB1B98DC28BC4140B875374F75FA4940
6533	Прилепы	1	8	721	35.233128999999998	35.298445999999998	51.871040999999998	51.828175000000002	0103000020E61000000100000005000000E55FCB2BD79D4140B22E6EA301EA4940E55FCB2BD79D4140D13C80457EEF49409ECF807A33A64140D13C80457EEF49409ECF807A33A64140B22E6EA301EA4940E55FCB2BD79D4140B22E6EA301EA4940
6306	Платава	1	8	721	35.076939000000003	35.147708000000002	51.821289	51.799878999999997	0103000020E61000000100000005000000BB641C23D9894140EBE0606F62E64940BB641C23D989414043C879FF1FE94940C5AD8218E892414043C879FF1FE94940C5AD8218E8924140EBE0606F62E64940BB641C23D9894140EBE0606F62E64940
5240	Нижнее Песочное	1	8	721	34.929310000000001	34.969895999999999	51.885013000000001	51.873370999999999	0103000020E6100000010000000500000042EC4CA1F37641402D23F59ECAEF494042EC4CA1F376414076C4211B48F14940B742588D257C414076C4211B48F14940B742588D257C41402D23F59ECAEF494042EC4CA1F37641402D23F59ECAEF4940
6035	Наумовка	1	8	721	35.156584000000002	35.188267000000003	51.943555000000003	51.933700000000002	0103000020E61000000100000005000000D789CBF10A9441403A234A7B83F74940D789CBF10A944140187D0569C6F8494041F50F2219984140187D0569C6F8494041F50F22199841403A234A7B83F74940D789CBF10A9441403A234A7B83F74940
5777	Машкино	1	8	721	35.290208	35.328997000000001	51.975622000000001	51.936309999999999	0103000020E61000000100000005000000CF84268925A5414079758E01D9F74940CF84268925A541400AA1832EE1FC4940B6BDDD921CAA41400AA1832EE1FC4940B6BDDD921CAA414079758E01D9F74940CF84268925A5414079758E01D9F74940
5983	Мармыжи	1	8	721	35.331359999999997	35.361040000000003	52.041679999999999	52.027285999999997	0103000020E61000000100000005000000ED9925016AAA4140BFD18E1B7E034A40ED9925016AAA4140DA722EC555054A402046088F36AE4140DA722EC555054A402046088F36AE4140BFD18E1B7E034A40ED9925016AAA4140BFD18E1B7E034A40
5693	Малое Городьково	1	8	721	35.524327	35.550207999999998	51.911777000000001	51.888430999999997	0103000020E6100000010000000500000074B4AA251DC3414054E0641BB8F1494074B4AA251DC341405C1FD61BB5F44940B0FF3A376DC641405C1FD61BB5F44940B0FF3A376DC6414054E0641BB8F1494074B4AA251DC3414054E0641BB8F14940
5186	Малахово	1	8	721	35.066634999999998	35.125501999999997	51.901336999999998	51.883862000000001	0103000020E610000001000000050000006DE2E47E87884140AD16D86322F149406DE2E47E878841405ED6C4025FF3494092CA1473109041405ED6C4025FF3494092CA147310904140AD16D86322F149406DE2E47E87884140AD16D86322F14940
54531	Макарово-Петровское	1	8	721	35.051606999999997	35.083111000000002	51.966954999999999	51.938858000000003	0103000020E61000000100000005000000519FE40E9B86414043CBBA7F2CF84940519FE40E9B86414012DA722EC5FB49400C789961A38A414012DA722EC5FB49400C789961A38A414043CBBA7F2CF84940519FE40E9B86414043CBBA7F2CF84940
54461	Конышевка	1	8	721	35.272951999999997	35.309863	51.854506000000001	51.824483999999998	0103000020E610000001000000050000005BB05417F0A24140A20914B188E949405BB05417F0A241402E1EDE7360ED4940C79E3D97A9A741402E1EDE7360ED4940C79E3D97A9A74140A20914B188E949405BB05417F0A24140A20914B188E94940
6257	Кашара	1	8	721	35.065323999999997	35.107436999999997	51.844185000000003	51.831553	0103000020E610000001000000050000006BD26D895C88414002F2255470EA49406BD26D895C8841400B630B410EEC4940AFB0E07EC08D41400B630B410EEC4940AFB0E07EC08D414002F2255470EA49406BD26D895C88414002F2255470EA4940
5512	Захарково	1	8	721	35.346811000000002	35.372638000000002	51.816490000000002	51.801416000000003	0103000020E610000001000000050000005072874D64AC4140DE3EABCC94E649405072874D64AC41406AC18BBE82E84940999F1B9AB2AF41406AC18BBE82E84940999F1B9AB2AF4140DE3EABCC94E649405072874D64AC4140DE3EABCC94E64940
5452	Жигаево	1	8	721	35.418398000000003	35.502642000000002	52.066378999999998	52.013207999999999	0103000020E610000001000000050000001D5BCF108EB54140D505BCCCB0014A401D5BCF108EB541401212691B7F084A404BCCB39256C041401212691B7F084A404BCCB39256C04140D505BCCCB0014A401D5BCF108EB54140D505BCCCB0014A40
5575	Дремово-Черемошки	1	8	721	35.349218	35.378638000000002	51.862870999999998	51.832509999999999	0103000020E610000001000000050000005796E82CB3AC4140E6CB0BB08FEA49405796E82CB3AC41405AD5928E72EE4940ED82C13577B041405AD5928E72EE4940ED82C13577B04140E6CB0BB08FEA49405796E82CB3AC4140E6CB0BB08FEA4940
6370	Гряды	1	8	721	34.975042999999999	34.996521999999999	51.817731000000002	51.802157000000001	0103000020E61000000100000005000000CC988235CE7C4140F5A0A014ADE64940CC988235CE7C414073F6CE68ABE849404CDF6B088E7F414073F6CE68ABE849404CDF6B088E7F4140F5A0A014ADE64940CC988235CE7C4140F5A0A014ADE64940
5736	Глазово	1	8	721	35.441547	35.470886	51.910716000000001	51.895079000000003	0103000020E61000000100000005000000CE52B29C84B841400F2BDCF291F24940CE52B29C84B84140D3F8855792F44940771211FE45BC4140D3F8855792F44940771211FE45BC41400F2BDCF291F24940CE52B29C84B841400F2BDCF291F24940
54548	Верхняя Соковинка	1	8	721	35.215882000000001	35.252595999999997	51.943871999999999	51.923425999999999	0103000020E61000000100000005000000C5E57805A29B41405723BBD232F64940C5E57805A29B414018CE35CCD0F84940DA8CD31055A0414018CE35CCD0F84940DA8CD31055A041405723BBD232F64940C5E57805A29B41405723BBD232F64940
6108	Васильевка	1	8	721	35.086084	35.136893000000001	51.934987999999997	51.917416000000003	0103000020E61000000100000005000000BC5AEECC048B4140E06932E36DF54940BC5AEECC048B41408313D1AFADF749409206B7B5859141408313D1AFADF749409206B7B585914140E06932E36DF54940BC5AEECC048B4140E06932E36DF54940
5352	Вабля	1	8	721	35.437137	35.454312000000002	51.960113	51.929212999999997	0103000020E610000001000000050000008F6FEF1AF4B741404F029B73F0F649408F6FEF1AF4B7414073BB97FBE4FA4940161747E526BA414073BB97FBE4FA4940161747E526BA41404F029B73F0F649408F6FEF1AF4B741404F029B73F0F64940
5144	Беляево	1	8	721	35.079886000000002	35.127766000000001	51.873849	51.861542	0103000020E6100000010000000500000042B456B4398A4140B2101D0247EE494042B456B4398A41403752B648DAEF494037C5E3A25A9041403752B648DAEF494037C5E3A25A904140B2101D0247EE494042B456B4398A4140B2101D0247EE4940
6732	Арбузово	1	8	721	35.108856000000003	35.121972	52.024985999999998	52.015636000000001	0103000020E6100000010000000500000098FC4FFEEE8D4140F451465C00024A4098FC4FFEEE8D4140CE6DC2BD32034A408C834BC79C8F4140CE6DC2BD32034A408C834BC79C8F4140F451465C00024A4098FC4FFEEE8D4140F451465C00024A40
4493	Успено-Раевка	1	8	231	37.899588999999999	37.952716000000002	51.833629000000002	51.821300000000001	0103000020E61000000100000005000000B16B7BBB25F34240371AC05B20E94940B16B7BBB25F34240A4FFE55AB4EA49401F300F99F2F94240A4FFE55AB4EA49401F300F99F2F94240371AC05B20E94940B16B7BBB25F34240371AC05B20E94940
4978	Успенка	1	8	231	38.220835999999998	38.239502999999999	51.824584000000002	51.806634000000003	0103000020E61000000100000005000000C5E3A25A441C4340BCEB6CC83FE74940C5E3A25A441C43400667F0F78BE949409E25C808A81E43400667F0F78BE949409E25C808A81E4340BCEB6CC83FE74940C5E3A25A441C4340BCEB6CC83FE74940
4392	Суковкино	1	8	231	38.128380999999997	38.140805	51.679637999999997	51.666702000000001	0103000020E61000000100000005000000C136E2C96E104340C216BB7D56D54940C136E2C96E104340368FC360FED64940800EF3E505124340368FC360FED64940800EF3E505124340C216BB7D56D54940C136E2C96E104340C216BB7D56D54940
3721	Семеновский	1	8	231	38.284688000000003	38.310865	51.938474999999997	51.930607000000002	0103000020E6100000010000000500000026C808A870244340DF3653211EF7494026C808A8702443408A8EE4F21FF849404B3CA06CCA2743408A8EE4F21FF849404B3CA06CCA274340DF3653211EF7494026C808A870244340DF3653211EF74940
4799	Семеновка	1	8	231	38.267270000000003	38.307344000000001	51.874305	51.859740000000002	0103000020E61000000100000005000000D99942E7352243401288D7F50BEE4940D99942E73522434059DDEA39E9EF4940984F560C5727434059DDEA39E9EF4940984F560C572743401288D7F50BEE4940D99942E7352243401288D7F50BEE4940
899	Раздолье	1	8	231	37.965589000000001	38.017654999999998	51.755873999999999	51.746825000000001	0103000020E610000001000000050000004D309C6B98FB4240E86A2BF697DF49404D309C6B98FB4240C7F2AE7AC0E0494031CEDF8442024340C7F2AE7AC0E0494031CEDF8442024340E86A2BF697DF49404D309C6B98FB4240E86A2BF697DF4940
4023	Погожево	1	8	231	38.236691	38.298684000000002	51.744857000000003	51.732424999999999	0103000020E61000000100000005000000F72004E44B1E4340EBE2361AC0DD4940F72004E44B1E43402D99637957DF494053EBFD463B2643402D99637957DF494053EBFD463B264340EBE2361AC0DD4940F72004E44B1E4340EBE2361AC0DD4940
4667	Орехово	1	8	231	38.355646	38.397364000000003	51.777211000000001	51.737651	0103000020E61000000100000005000000037AE1CE852D43404C6E14596BDE4940037AE1CE852D4340B58B69A67BE34940CB4DD4D2DC324340B58B69A67BE34940CB4DD4D2DC3243404C6E14596BDE4940037AE1CE852D43404C6E14596BDE4940
3515	Олымский	1	8	231	38.118347	38.174528000000002	51.790514999999999	51.76117	0103000020E61000000100000005000000344A97FE250F43402159C0046EE14940344A97FE250F4340ACFF73982FE549403F1EFAEE56164340ACFF73982FE549403F1EFAEE561643402159C0046EE14940344A97FE250F43402159C0046EE14940
4331	Олым	1	8	231	38.162121999999997	38.224069999999998	51.689449000000003	51.672333000000002	0103000020E6100000010000000500000026FBE769C0144340C382FB010FD6494026FBE769C014434045A165DD3FD84940E2016553AE1C434045A165DD3FD84940E2016553AE1C4340C382FB010FD6494026FBE769C0144340C382FB010FD64940
3410	Новокасторное	1	8	231	38.103569999999998	38.127420000000001	51.793016999999999	51.760117000000001	0103000020E61000000100000005000000616C21C8410D43401B118C834BE14940616C21C8410D43400516C09481E549409C6D6E4C4F1043400516C09481E549409C6D6E4C4F1043401B118C834BE14940616C21C8410D43401B118C834BE14940
4272	Новодворский	1	8	231	38.078453000000003	38.110225999999997	51.763683999999998	51.746930999999996	0103000020E61000000100000005000000F5A276BF0A0A43402DAF5C6F9BDF4940F5A276BF0A0A43403E3DB665C0E149409E95B4E21B0E43403E3DB665C0E149409E95B4E21B0E43402DAF5C6F9BDF4940F5A276BF0A0A43402DAF5C6F9BDF4940
4632	Никольско-Ключевская	1	8	231	38.061978000000003	38.097434	51.822513999999998	51.814579999999999	0103000020E61000000100000005000000278925E5EE074340E3FC4D2844E84940278925E5EE0743404640852348E949405DC2A1B7780C43404640852348E949405DC2A1B7780C4340E3FC4D2844E84940278925E5EE074340E3FC4D2844E84940
4946	Мелавка	1	8	231	38.306697	38.347759000000003	51.869078000000002	51.826588000000001	0103000020E610000001000000050000000264E8D8412743400EA2B5A2CDE949400264E8D84127434028D6A9F23DEF4940E1F1ED5D832C434028D6A9F23DEF4940E1F1ED5D832C43400EA2B5A2CDE949400264E8D8412743400EA2B5A2CDE94940
6107	Марьино	1	8	231	37.885179999999998	37.941783000000001	51.872103000000003	51.861680999999997	0103000020E61000000100000005000000618907944DF14240D34A21904BEE4940618907944DF142402BDF3312A1EF4940E27668588CF842402BDF3312A1EF4940E27668588CF84240D34A21904BEE4940618907944DF14240D34A21904BEE4940
4562	Ленинский	1	8	231	38.109023000000001	38.130761999999997	51.842270999999997	51.837285000000001	0103000020E6100000010000000500000083C13577F40D43403737A6272CEB494083C13577F40D434042AF3F89CFEB49409FC728CFBC10434042AF3F89CFEB49409FC728CFBC1043403737A6272CEB494083C13577F40D43403737A6272CEB4940
4439	Лачиново	1	8	231	37.909624000000001	37.935423	51.809708000000001	51.796621000000002	0103000020E610000001000000050000000FD4298F6EF4424046274BADF7E549400FD4298F6EF44240A0A70183A4E749408E76DCF0BBF74240A0A70183A4E749408E76DCF0BBF7424046274BADF7E549400FD4298F6EF4424046274BADF7E54940
4135	Красная Долина	1	8	231	38.060603	38.104979999999998	51.730879999999999	51.710101999999999	0103000020E610000001000000050000000E85CFD6C10743407F69519FE4DA49400E85CFD6C107434076A6D0798DDD4940F65D11FC6F0D434076A6D0798DDD4940F65D11FC6F0D43407F69519FE4DA49400E85CFD6C10743407F69519FE4DA4940
3940	Котовка	1	8	231	38.156005	38.208385	51.788103	51.730210999999997	0103000020E610000001000000050000009981CAF8F7134340F816D68D77DD49409981CAF8F71343409370218FE0E449400DFD135CAC1A43409370218FE0E449400DFD135CAC1A4340F816D68D77DD49409981CAF8F7134340F816D68D77DD4940
3231	Касторное	1	8	231	38.085935999999997	38.170386999999998	51.839956000000001	51.815449000000001	0103000020E6100000010000000500000047C66AF3FF0A4340284701A260E8494047C66AF3FF0A43401C0A9FAD83EB4940EF54C03DCF1543401C0A9FAD83EB4940EF54C03DCF154340284701A260E8494047C66AF3FF0A4340284701A260E84940
3915	Жерновец	1	8	231	37.846310000000003	37.886240000000001	51.706932000000002	51.669110000000003	0103000020E610000001000000050000008E23D6E253EC42409AB67F65A5D549408E23D6E253EC4240793F6EBF7CDA49401A34F44F70F14240793F6EBF7CDA49401A34F44F70F142409AB67F65A5D549408E23D6E253EC42409AB67F65A5D54940
3820	Егорьевка	1	8	231	37.990687999999999	38.039107000000001	51.837636000000003	51.820081000000002	0103000020E61000000100000005000000134548DDCEFE42401689096AF8E84940134548DDCEFE4240E4F90CA837EB4940B8054B7501054340E4F90CA837EB4940B8054B75010543401689096AF8E84940134548DDCEFE42401689096AF8E84940
54564	Горяиново	1	8	231	38.382658999999997	38.413668000000001	51.866396999999999	51.798614999999998	0103000020E61000000100000005000000914259F8FA3043402A8C2D0439E64940914259F8FA3043401F2DCE18E6EE49406CB3B112F33443401F2DCE18E6EE49406CB3B112F33443402A8C2D0439E64940914259F8FA3043402A8C2D0439E64940
3843	Вознесеновка	1	8	231	37.958329999999997	38.012138999999998	51.868611000000001	51.854377999999997	0103000020E610000001000000050000004963B48EAAFA4240003620425CED49404963B48EAAFA424012F92EA52EEF4940C90050C58D01434012F92EA52EEF4940C90050C58D014340003620425CED49404963B48EAAFA4240003620425CED4940
4832	Верхотопье	1	8	231	38.389423000000001	38.421996	51.918481999999997	51.899275000000003	0103000020E61000000100000005000000B5A7E49CD8314340228E75711BF34940B5A7E49CD83143407AFB73D190F549407B8505F7033643407AFB73D190F549407B8505F703364340228E75711BF34940B5A7E49CD8314340228E75711BF34940
3755	Верхняя Грайворонка	1	8	231	37.752876999999998	37.818184000000002	51.703645000000002	51.661819999999999	0103000020E610000001000000050000008E7406465EE042405BEB8B84B6D449408E7406465EE04240397F130A11DA4940240ED940BAE84240397F130A11DA4940240ED940BAE842405BEB8B84B6D449408E7406465EE042405BEB8B84B6D44940
4170	Бычок	1	8	231	37.970134000000002	38.005519	51.676639000000002	51.647370000000002	0103000020E610000001000000050000006C5ED5592DFC4240AD342905DDD249406C5ED5592DFC42405D19541B9CD64940D940BAD8B40043405D19541B9CD64940D940BAD8B4004340AD342905DDD249406C5ED5592DFC4240AD342905DDD24940
4055	Белогорье	1	8	231	38.213200000000001	38.241326999999998	51.742632	51.724995	0103000020E61000000100000005000000ECC039234A1B4340BB61DBA2CCDC4940ECC039234A1B4340467BBC900EDF494026529ACDE31E4340467BBC900EDF494026529ACDE31E4340BB61DBA2CCDC4940ECC039234A1B4340BB61DBA2CCDC4940
2978	Андреевка	1	8	231	38.160522999999998	38.187347000000003	51.862554000000003	51.850172000000001	0103000020E61000000100000005000000BEA085048C144340CAFCA36FD2EC4940BEA085048C1443405A84622B68EE49407A008BFCFA1743405A84622B68EE49407A008BFCFA174340CAFCA36FD2EC4940BEA085048C144340CAFCA36FD2EC4940
3619	Александровский	1	8	231	37.882646999999999	37.897523	51.752851999999997	51.733623999999999	0103000020E61000000100000005000000CD74AF93FAF04240C5C72764E7DD4940CD74AF93FAF04240355D4F745DE0494033349E08E2F24240355D4F745DE0494033349E08E2F24240C5C72764E7DD4940CD74AF93FAF04240C5C72764E7DD4940
2419	Фентисово	1	8	302	36.381121999999998	36.413533000000001	52.147281	52.133209000000001	0103000020E610000001000000050000009FE40E9BC8304240354415FE0C114A409FE40E9BC83042403D29931ADA124A408C683BA6EE3442403D29931ADA124A408C683BA6EE344240354415FE0C114A409FE40E9BC8304240354415FE0C114A40
3095	Тазово	1	8	302	36.282218	36.329315999999999	51.937376	51.923670000000001	0103000020E61000000100000005000000D82B2CB81F244240EE258DD13AF64940D82B2CB81F2442401407D0EFFBF749405706D506272A42401407D0EFFBF749405706D506272A4240EE258DD13AF64940D82B2CB81F244240EE258DD13AF64940
2868	Солнечный	1	8	302	36.336018000000003	36.356642999999998	52.034166999999997	52.014555000000001	0103000020E61000000100000005000000056F48A3022B4240247F30F0DC014A40056F48A3022B42401CCD91955F044A4075AC527AA62D42401CCD91955F044A4075AC527AA62D4240247F30F0DC014A40056F48A3022B4240247F30F0DC014A40
54525	Сергеевское	1	8	302	36.163856000000003	36.187832	52.073559000000003	52.050491999999998	0103000020E610000001000000050000006FA0C03BF9144240D55A988576064A406FA0C03BF9144240CAA99D616A094A40369204E10A184240CAA99D616A094A40369204E10A184240D55A988576064A406FA0C03BF9144240D55A988576064A40
1443	Сергеевка	1	8	302	36.464404999999999	36.491515999999997	52.074489	52.061445999999997	0103000020E61000000100000005000000A88C7F9F713B4240293C6876DD074A40A88C7F9F713B4240B47405DB88094A40F9BA0CFFE93E4240B47405DB88094A40F9BA0CFFE93E4240293C6876DD074A40A88C7F9F713B4240293C6876DD074A40
1564	Седмиховка	1	8	302	36.580053999999997	36.590851999999998	52.188941	52.172673000000003	0103000020E61000000100000005000000FDF49F353F4A42407CF31B261A164A40FDF49F353F4A4240D0EFFB372F184A405A63D009A14B4240D0EFFB372F184A405A63D009A14B42407CF31B261A164A40FDF49F353F4A42407CF31B261A164A40
54509	Свобода	1	8	302	36.289259999999999	36.337257000000001	51.983170999999999	51.963414999999998	0103000020E610000001000000050000003E05C07806254240E8BCC62E51FB49403E05C0780625424014B01D8CD8FD49406DACC43C2B2B424014B01D8CD8FD49406DACC43C2B2B4240E8BCC62E51FB49403E05C07806254240E8BCC62E51FB4940
2708	Свобода	1	8	302	36.289259999999999	36.337257000000001	51.983170999999999	51.963414999999998	0103000020E610000001000000050000003E05C07806254240E8BCC62E51FB49403E05C0780625424014B01D8CD8FD49406DACC43C2B2B424014B01D8CD8FD49406DACC43C2B2B4240E8BCC62E51FB49403E05C07806254240E8BCC62E51FB4940
2379	Революционное	1	8	302	36.471905999999997	36.495586000000003	52.116903000000001	52.103186999999998	0103000020E61000000100000005000000A164726A673C4240A92F4B3B350D4A40A164726A673C4240F3E670ADF60E4A40802DAF5C6F3F4240F3E670ADF60E4A40802DAF5C6F3F4240A92F4B3B350D4A40A164726A673C4240A92F4B3B350D4A40
2832	Никулино	1	8	302	36.344766999999997	36.375660000000003	52.036676999999997	52.009006999999997	0103000020E61000000100000005000000B9DE3653212C4240B037312427014A40B9DE3653212C4240F8C1F9D4B1044A402B357BA015304240F8C1F9D4B1044A402B357BA015304240B037312427014A40B9DE3653212C4240B037312427014A40
3184	Никольское	1	8	302	36.248953	36.275103000000001	51.901870000000002	51.891238000000001	0103000020E61000000100000005000000DC9E20B1DD1F4240EA79371614F24940DC9E20B1DD1F42402C9FE57970F3494008043A93362342402C9FE57970F3494008043A9336234240EA79371614F24940DC9E20B1DD1F4240EA79371614F24940
1715	Кузьминка	1	8	302	36.361700999999996	36.397993	51.982067999999998	51.965141000000003	0103000020E610000001000000050000001AF7E6374C2E4240AE8383BD89FB49401AF7E6374C2E42405C397B67B4FD4940BA84436FF13242405C397B67B4FD4940BA84436FF1324240AE8383BD89FB49401AF7E6374C2E4240AE8383BD89FB4940
2146	Конево 2-е	1	8	302	36.109014000000002	36.142753999999996	52.043152999999997	52.034078999999998	0103000020E610000001000000050000003067B62BF40D42407D3D5FB35C044A403067B62BF40D4240B5DC990986054A40C4AF58C345124240B5DC990986054A40C4AF58C3451242407D3D5FB35C044A403067B62BF40D42407D3D5FB35C044A40
1333	Казанка 2-я	1	8	302	36.632246000000002	36.666212000000002	52.165128000000003	52.138908000000001	0103000020E610000001000000050000006F83DA6FED5042408E93C2BCC7114A406F83DA6FED504240B3D30FEA22154A40F419506F46554240B3D30FEA22154A40F419506F465542408E93C2BCC7114A406F83DA6FED5042408E93C2BCC7114A40
2258	Золотухино	1	8	302	36.356481000000002	36.400821999999998	52.096364999999999	52.072817000000001	0103000020E610000001000000050000009C525E2BA12D4240E2CB441152094A409C525E2BA12D424051BD35B0550C4A4037C2A2224E33424051BD35B0550C4A4037C2A2224E334240E2CB441152094A409C525E2BA12D4240E2CB441152094A40
2033	Зиборово	1	8	302	36.137571000000001	36.153947000000002	51.954529999999998	51.941966999999998	0103000020E6100000010000000500000063F030ED9B114240A374E95F92F8494063F030ED9B1142408386FE092EFA49409E280989B41342408386FE092EFA49409E280989B4134240A374E95F92F8494063F030ED9B114240A374E95F92F84940
3059	Жерновец	1	8	302	36.291587	36.324699000000003	51.923903000000003	51.883212	0103000020E6100000010000000500000029780AB952254240A6B73F170DF1494029780AB95225424091D6187442F649409F05A1BC8F29424091D6187442F649409F05A1BC8F294240A6B73F170DF1494029780AB952254240A6B73F170DF14940
2297	Донское	1	8	302	36.341228000000001	36.363622999999997	52.047806000000001	52.034505000000003	0103000020E61000000100000005000000603DEE5BAD2B42403546EBA86A044A40603DEE5BAD2B4240BB46CB811E064A406589CE328B2E4240BB46CB811E064A406589CE328B2E42403546EBA86A044A40603DEE5BAD2B42403546EBA86A044A40
1941	Дмитриевка	1	8	302	36.189269000000003	36.215805000000003	52.023451000000001	52.008923000000003	0103000020E61000000100000005000000C59272F73918424053978C6324014A40C59272F7391842407D073F7100034A401AA88C7F9F1B42407D073F7100034A401AA88C7F9F1B424053978C6324014A40C59272F73918424053978C6324014A40
2648	Дерлово	1	8	302	36.263263000000002	36.326352	52.086378000000003	52.073742000000003	0103000020E61000000100000005000000999F1B9AB2214240BB2BBB6070094A40999F1B9AB2214240058C2E6F0E0B4A40FA7DFFE6C5294240058C2E6F0E0B4A40FA7DFFE6C5294240BB2BBB6070094A40999F1B9AB2214240BB2BBB6070094A40
1908	Демякино	1	8	302	36.537940999999996	36.571987	51.986105999999999	51.972259999999999	0103000020E61000000100000005000000B9162D40DB444240BF9A030473FC4940B9162D40DB444240D731AEB838FE49405B5EB9DE36494240D731AEB838FE49405B5EB9DE36494240BF9A030473FC4940B9162D40DB444240BF9A030473FC4940
1820	Гремячка	1	8	302	36.508315000000003	36.566678000000003	51.896957	51.863717000000001	0103000020E610000001000000050000007B88467710414240E7FF55478EEE49407B884677104142408A75AA7CCFF249406DAE9AE7884842408A75AA7CCFF249406DAE9AE788484240E7FF55478EEE49407B88467710414240E7FF55478EEE4940
1794	Воробьевка 1-я	1	8	302	36.463740000000001	36.516992000000002	51.983409999999999	51.972354000000003	0103000020E610000001000000050000006CEC12D55B3B424041118B1876FC49406CEC12D55B3B42409947FE60E0FD494096253ACB2C4242409947FE60E0FD494096253ACB2C42424041118B1876FC49406CEC12D55B3B424041118B1876FC4940
54542	Верентиново 1-е	1	8	302	36.608691999999998	36.62594	52.073537000000002	52.055929999999996	0103000020E610000001000000050000001DAB949EE94D4240C16ED8B628074A401DAB949EE94D4240E20511A969094A400EA14ACD1E504240E20511A969094A400EA14ACD1E504240C16ED8B628074A401DAB949EE94D4240C16ED8B628074A40
1672	Будановка	1	8	302	36.321905000000001	36.384580999999997	51.969397000000001	51.938020000000002	0103000020E610000001000000050000009EB5DB2E34294240397F130A11F849409EB5DB2E3429424096EB6D3315FC4940DCD440F33931424096EB6D3315FC4940DCD440F339314240397F130A11F849409EB5DB2E34294240397F130A11F84940
2190	Боево	1	8	302	36.382407000000001	36.413282000000002	52.129969000000003	52.093311	0103000020E6100000010000000500000078616BB6F2304240B4AD669DF10B4A4078616BB6F2304240363FFED2A2104A404303B16CE6344240363FFED2A2104A404303B16CE6344240B4AD669DF10B4A4078616BB6F2304240B4AD669DF10B4A40
1356	Белый Колодезь	1	8	302	36.547176	36.565178000000003	52.069274	52.039453000000002	0103000020E61000000100000005000000FB93F8DC09464240535DC0CB0C054A40FB93F8DC09464240473B6EF8DD084A409835B1C057484240473B6EF8DD084A409835B1C057484240535DC0CB0C054A40FB93F8DC09464240535DC0CB0C054A40
1590	Апальково	1	8	302	36.259239000000001	36.271239999999999	51.983986999999999	51.966749999999998	0103000020E61000000100000005000000836C59BE2E21424039B4C876BEFB4940836C59BE2E21424036583849F3FD4940FBAE08FEB722424036583849F3FD4940FBAE08FEB722424039B4C876BEFB4940836C59BE2E21424039B4C876BEFB4940
2601	1-е Новоспасское	1	8	302	36.295440999999997	36.331328999999997	52.120126999999997	52.101671000000003	0103000020E61000000100000005000000E272BC02D1254240CFF9298E030D4A40E272BC02D1254240EC2E5052600F4A40B29B19FD682A4240EC2E5052600F4A40B29B19FD682A4240CFF9298E030D4A40E272BC02D1254240CFF9298E030D4A40
31169	Фоминка	1	8	84	35.494171000000001	35.523392999999999	52.154443000000001	52.138078999999998	0103000020E61000000100000005000000D9D0CDFE40BF4140D7A19A92AC114A40D9D0CDFE40BF41404E0CC9C9C4134A4048FAB48AFEC241404E0CC9C9C4134A4048FAB48AFEC24140D7A19A92AC114A40D9D0CDFE40BF4140D7A19A92AC114A40
1265	Трояново	1	8	84	35.223616	35.245643000000001	52.367261999999997	52.347499999999997	0103000020E61000000100000005000000616EF7729F9C414014AE47E17A2C4A40616EF7729F9C41402288F370022F4A40E4BED53A719F41402288F370022F4A40E4BED53A719F414014AE47E17A2C4A40616EF7729F9C414014AE47E17A2C4A40
1092	Троицкое	1	8	84	35.587443	35.619323999999999	52.213591999999998	52.186732999999997	0103000020E61000000100000005000000CFA10C5531CB4140BF0AF0DDE6174A40CFA10C5531CB4140F7578FFB561B4A405FD0420246CF4140F7578FFB561B4A405FD0420246CF4140BF0AF0DDE6174A40CFA10C5531CB4140BF0AF0DDE6174A40
54512	Тепличный	1	8	84	35.111550999999999	35.708796	52.444803999999998	52.025295999999997	0103000020E61000000100000005000000056B9C4D478E41401C5C3AE63C034A40056B9C4D478E4140A3906456EF384A408FC4CBD3B9DA4140A3906456EF384A408FC4CBD3B9DA41401C5C3AE63C034A40056B9C4D478E41401C5C3AE63C034A40
1011	Студенок	1	8	84	35.296855999999998	35.307859999999998	52.358049999999999	52.349238	0103000020E6100000010000000500000089CF9D60FFA541409E42AED4B32C4A4089CF9D60FFA54140992A1895D42D4A408FDFDBF467A74140992A1895D42D4A408FDFDBF467A741409E42AED4B32C4A4089CF9D60FFA541409E42AED4B32C4A40
1220	Старый Бузец	1	8	84	35.526626999999998	35.553522000000001	52.212918999999999	52.187494999999998	0103000020E610000001000000050000006518778368C34140EE940ED6FF174A406518778368C3414038D906EE401B4A40EACE13CFD9C6414038D906EE401B4A40EACE13CFD9C64140EE940ED6FF174A406518778368C34140EE940ED6FF174A40
976	Снецкое	1	8	84	35.280541999999997	35.315882000000002	52.118513	52.104691000000003	0103000020E61000000100000005000000C493DDCCE8A34140C097C283660D4A40C493DDCCE8A341404F93196F2B0F4A4092B245D26EA841404F93196F2B0F4A4092B245D26EA84140C097C283660D4A40C493DDCCE8A34140C097C283660D4A40
873	Рышково	1	8	84	35.449488000000002	35.470410000000001	52.160007	52.149403	0103000020E61000000100000005000000E4F8A1D288B941404F7633A31F134A40E4F8A1D288B94140C710001C7B144A400EDB166536BC4140C710001C7B144A400EDB166536BC41404F7633A31F134A40E4F8A1D288B941404F7633A31F134A40
650	Разветье	1	8	84	35.312091000000002	35.347853000000001	52.324486999999998	52.307772999999997	0103000020E610000001000000050000001F300F99F2A74140C0CB0C1B65274A401F300F99F2A74140137D3ECA88294A406268757286AC4140137D3ECA88294A406268757286AC4140C0CB0C1B65274A401F300F99F2A74140C0CB0C1B65274A40
54533	Пасерково	1	8	84	35.475673999999998	35.489480999999998	52.386757000000003	52.371479000000001	0103000020E610000001000000050000005CC7B8E2E2BC41404D13B69F8C2F4A405CC7B8E2E2BC4140E23FDD4081314A40B6813B50A7BE4140E23FDD4081314A40B6813B50A7BE41404D13B69F8C2F4A405CC7B8E2E2BC41404D13B69F8C2F4A40
32350	Остапово	1	8	84	35.419404	35.451625999999997	52.276755999999999	52.252532000000002	0103000020E61000000100000005000000E2E7BF07AFB54140C498F4F752204A40E2E7BF07AFB54140637C98BD6C234A40FB027AE1CEB94140637C98BD6C234A40FB027AE1CEB94140C498F4F752204A40E2E7BF07AFB54140C498F4F752204A40
54510	Новоандросово	1	8	84	35.111550999999999	35.708796	52.444803999999998	52.025295999999997	0103000020E61000000100000005000000056B9C4D478E41401C5C3AE63C034A40056B9C4D478E4140A3906456EF384A408FC4CBD3B9DA4140A3906456EF384A408FC4CBD3B9DA41401C5C3AE63C034A40056B9C4D478E41401C5C3AE63C034A40
535	Нижнее Жданово	1	8	84	35.645069999999997	35.651474999999998	52.117865999999999	52.114624999999997	0103000020E61000000100000005000000BBD05CA791D24140E9263108AC0E4A40BBD05CA791D24140B9A7AB3B160F4A40AF94658863D34140B9A7AB3B160F4A40AF94658863D34140E9263108AC0E4A40BBD05CA791D24140E9263108AC0E4A40
52364	Михайловка	1	8	84	35.345993999999997	35.390630999999999	52.241863000000002	52.224086	0103000020E610000001000000050000005D4E098849AC4140E8BE9CD9AE1C4A405D4E098849AC4140658EE55DF51E4A40E2E6543200B24140658EE55DF51E4A40E2E6543200B24140E8BE9CD9AE1C4A405D4E098849AC4140E8BE9CD9AE1C4A40
32254	Магнитный	1	8	84	35.547970999999997	35.554690000000001	52.436816999999998	52.434345999999998	0103000020E610000001000000050000000514EAE923C64140FF9254A698374A400514EAE923C641401DAB949EE9374A4089B5F81400C741401DAB949EE9374A4089B5F81400C74140FF9254A698374A400514EAE923C64140FF9254A698374A40
395	Линец	1	8	84	35.515191000000002	35.546686000000001	52.100349000000001	52.079869000000002	0103000020E61000000100000005000000C61858C7F1C141406C7BBB25390A4A40C61858C7F1C14140D9976C3CD80C4A402D978DCEF9C54140D9976C3CD80C4A402D978DCEF9C541406C7BBB25390A4A40C61858C7F1C141406C7BBB25390A4A40
360	Копенки	1	8	84	35.590201	35.628846000000003	52.260730000000002	52.243853999999999	0103000020E610000001000000050000008388D4B48BCB4140D87F9D9B361F4A408388D4B48BCB4140058BC3995F214A40371C96067ED04140058BC3995F214A40371C96067ED04140D87F9D9B361F4A408388D4B48BCB4140D87F9D9B361F4A40
781	Клишино	1	8	84	35.203116000000001	35.232923	52.272624	52.259390000000003	0103000020E61000000100000005000000ADA580B4FF994140697407B133214A40ADA580B4FF994140670DDE57E5224A403CBEBD6BD09D4140670DDE57E5224A403CBEBD6BD09D4140697407B133214A40ADA580B4FF994140697407B133214A40
235	Карманово	1	8	84	35.334099999999999	35.370922	52.161178	52.132247	0103000020E61000000100000005000000FBCBEEC9C3AA41403FFF3D78ED104A40FBCBEEC9C3AA4140D76A0F7BA1144A40F7AE415F7AAF4140D76A0F7BA1144A40F7AE415F7AAF41403FFF3D78ED104A40FBCBEEC9C3AA41403FFF3D78ED104A40
275	Злобино	1	8	84	35.424712999999997	35.446038999999999	52.132860999999998	52.107323999999998	0103000020E61000000100000005000000D097DEFE5CB64140B709F7CABC0D4A40D097DEFE5CB64140F9F4D89601114A40CADE52CE17B94140F9F4D89601114A40CADE52CE17B94140B709F7CABC0D4A40D097DEFE5CB64140B709F7CABC0D4A40
54357	Железногорск	1	8	84	35.111550999999999	35.708796	52.444803999999998	52.025295999999997	0103000020E61000000100000005000000056B9C4D478E41401C5C3AE63C034A40056B9C4D478E4140A3906456EF384A408FC4CBD3B9DA4140A3906456EF384A408FC4CBD3B9DA41401C5C3AE63C034A40056B9C4D478E41401C5C3AE63C034A40
133	Городное	1	8	84	35.619432000000003	35.644665000000003	52.352528	52.342652999999999	0103000020E61000000100000005000000460C3B8C49CF41402A70B20DDC2B4A40460C3B8C49CF41404F7633A31F2D4A401CF0F96184D241404F7633A31F2D4A401CF0F96184D241402A70B20DDC2B4A40460C3B8C49CF41402A70B20DDC2B4A40
32468	Волково	1	8	84	35.477435	35.505786000000001	52.410423000000002	52.389449999999997	0103000020E610000001000000050000009E7B0F971CBD4140AEB6627FD9314A409E7B0F971CBD41405B43A9BD88344A4028637C98BDC041405B43A9BD88344A4028637C98BDC04140AEB6627FD9314A409E7B0F971CBD4140AEB6627FD9314A40
32446	Веретенино	1	8	84	35.374048000000002	35.406557999999997	52.302267000000001	52.285378999999999	0103000020E610000001000000050000002E910BCEE0AF41408BFB8F4C87244A402E910BCEE0AF41407CD45FAFB0264A40ADF6B0170AB441407CD45FAFB0264A40ADF6B0170AB441408BFB8F4C87244A402E910BCEE0AF41408BFB8F4C87244A40
32385	Басово Заречье	1	8	84	35.568821	35.599587999999997	52.150823000000003	52.132938000000003	0103000020E6100000010000000500000096236420CFC84140A532C51C04114A4096236420CFC84140083E062B4E134A407A89B14CBFCC4140083E062B4E134A407A89B14CBFCC4140A532C51C04114A4096236420CFC84140A532C51C04114A40
32317	Андросово	1	8	84	35.494764000000004	35.519376999999999	52.298890999999998	52.277681999999999	0103000020E610000001000000050000007C9E3F6D54BF41400C5872158B234A407C9E3F6D54BF4140CC086F0F42264A40B5A50EF27AC24140CC086F0F42264A40B5A50EF27AC241400C5872158B234A407C9E3F6D54BF41400C5872158B234A40
31725	Черневка	1	8	1902	35.072951000000003	35.100897000000003	52.308774999999997	52.292876	0103000020E61000000100000005000000F29A57755689414043E4F4F57C254A40F29A57755689414044696FF085274A40DCA16131EA8C414044696FF085274A40DCA16131EA8C414043E4F4F57C254A40F29A57755689414043E4F4F57C254A40
32210	Харасея	1	8	1902	34.999639000000002	35.028286000000001	52.031740999999997	51.993293000000001	0103000020E610000001000000050000003067B62BF47F4140412C9B3924FF49403067B62BF47F41409E78CE1610044A40A3772AE09E8341409E78CE1610044A40A3772AE09E834140412C9B3924FF49403067B62BF47F4140412C9B3924FF4940
31249	Фокино	1	8	1902	35.036217999999998	35.066994999999999	52.147066000000002	52.132976999999997	0103000020E6100000010000000500000065C39ACAA2844140620FED6305114A4065C39ACAA2844140412D060FD3124A406DFFCA4A93884140412D060FD3124A406DFFCA4A93884140620FED6305114A4065C39ACAA2844140620FED6305114A40
32048	Фатеевка	1	8	1902	34.874225000000003	34.903312999999997	52.069384999999997	52.046681	0103000020E610000001000000050000003D2CD49AE66F41401B2C9CA4F9054A403D2CD49AE66F41409EEA909BE1084A409C86A8C29F7341409EEA909BE1084A409C86A8C29F7341401B2C9CA4F9054A403D2CD49AE66F41401B2C9CA4F9054A40
32084	Старый Город	1	8	1902	35.057886000000003	35.081619000000003	52.114514	52.086649000000001	0103000020E61000000100000005000000B972F6CE68874140959D7E50170B4A40B972F6CE6887414092770E65A80E4A40BADDCB7D728A414092770E65A80E4A40BADDCB7D728A4140959D7E50170B4A40B972F6CE68874140959D7E50170B4A40
31485	Снижа	1	8	1902	35.166052000000001	35.206116999999999	52.128123000000002	52.109360000000002	0103000020E61000000100000005000000BBB7223141954140CBBE2B82FF0D4A40BBB7223141954140C66E9F5566104A402713B70A629A4140C66E9F5566104A402713B70A629A4140CBBE2B82FF0D4A40BBB7223141954140CBBE2B82FF0D4A40
31999	Селино	1	8	1902	34.729596999999998	34.766922000000001	52.031601999999999	52.004483	0103000020E610000001000000050000003E213B6F635D4140A93121E692004A403E213B6F635D41407D3ECA880B044A409D4A06802A6241407D3ECA880B044A409D4A06802A624140A93121E692004A403E213B6F635D4140A93121E692004A40
31952	Почепное	1	8	1902	34.811667	34.862313999999998	52.014212000000001	52.000906999999998	0103000020E61000000100000005000000081F4AB4E467414032AB77B81D004A40081F4AB4E4674140FA9AE5B2D1014A4004711E4E606E4140FA9AE5B2D1014A4004711E4E606E414032AB77B81D004A40081F4AB4E467414032AB77B81D004A40
31787	Поповкино	1	8	1902	34.791086	34.826228	52.134287	52.111843	0103000020E610000001000000050000006729594E42654140ADA415DF500E4A406729594E4265414094A3005130114A400E85CFD6C169414094A3005130114A400E85CFD6C1694140ADA415DF500E4A406729594E42654140ADA415DF500E4A40
31933	Погодино	1	8	1902	34.845559999999999	34.879876000000003	52.191608000000002	52.165785	0103000020E610000001000000050000002367614F3B6C41406C95607138154A402367614F3B6C414074D3669C86184A408544DAC69F70414074D3669C86184A408544DAC69F7041406C95607138154A402367614F3B6C41406C95607138154A40
31473	Петраковка	1	8	1902	35.328035999999997	35.372942999999999	52.063626999999997	52.047080000000001	0103000020E6100000010000000500000090F46915FDA94140D925AAB706064A4090F46915FDA941404012F6ED24084A40D522A298BCAF41404012F6ED24084A40D522A298BCAF4140D925AAB706064A4090F46915FDA94140D925AAB706064A40
31560	Первоавгустовский	1	8	1902	35.030082999999998	35.099828000000002	52.237887000000001	52.215401999999997	0103000020E6100000010000000500000031957EC2D98341401ABFF04A921B4A4031957EC2D98341406092CA14731E4A40D09CF529C78C41406092CA14731E4A40D09CF529C78C41401ABFF04A921B4A4031957EC2D98341401ABFF04A921B4A40
31093	Пальцево	1	8	1902	35.184233999999996	35.222529000000002	52.212560000000003	52.196080000000002	0103000020E61000000100000005000000D767CEFA9497414029B3412619194A40D767CEFA949741400938842A351B4A40AFB48CD47B9C41400938842A351B4A40AFB48CD47B9C414029B3412619194A40D767CEFA9497414029B3412619194A40
31705	Неварь	1	8	1902	34.943556999999998	34.989299000000003	52.332313999999997	52.312882999999999	0103000020E61000000100000005000000B874CC79C6784140B83CD68C0C284A40B874CC79C67841406000E143892A4A40967B8159A17E41406000E143892A4A40967B8159A17E4140B83CD68C0C284A40B874CC79C6784140B83CD68C0C284A40
31073	Моршнево	1	8	1902	35.197870000000002	35.222700000000003	52.175097999999998	52.154443000000001	0103000020E61000000100000005000000056EDDCD539941404E0CC9C9C4134A40056EDDCD5399414029CC7B9C69164A40DC68006F819C414029CC7B9C69164A40DC68006F819C41404E0CC9C9C4134A40056EDDCD539941404E0CC9C9C4134A40
31877	Меловое	1	8	1902	34.908631	34.936118999999998	52.133606999999998	52.123322999999999	0103000020E61000000100000005000000DE9046054E7441401CEC4D0CC90F4A40DE9046054E74414022C2BF081A114A40051555BFD277414022C2BF081A114A40051555BFD27741401CEC4D0CC90F4A40DE9046054E7441401CEC4D0CC90F4A40
31265	Куток	1	8	1902	35.160967999999997	35.183433999999998	52.066383999999999	52.061827999999998	0103000020E61000000100000005000000ECD973999A94414011FDDAFAE9074A40ECD973999A944140247D5A457F084A40BB7CEBC37A974140247D5A457F084A40BB7CEBC37A97414011FDDAFAE9074A40ECD973999A94414011FDDAFAE9074A40
31161	Крупец	1	8	1902	35.052864	35.089129	52.146773000000003	52.133589999999998	0103000020E6100000010000000500000060915F3FC48641404C89247A19114A4060915F3FC4864140C9772975C9124A4006103E94688B4140C9772975C9124A4006103E94688B41404C89247A19114A4060915F3FC48641404C89247A19114A40
31372	Красная Дубрава	1	8	1902	35.089739999999999	35.111927999999999	52.110101	52.101847999999997	0103000020E610000001000000050000004F92AE997C8B4140DD94F25A090D4A404F92AE997C8B4140E22021CA170E4A40DBC01DA8538E4140E22021CA170E4A40DBC01DA8538E4140DD94F25A090D4A404F92AE997C8B4140DD94F25A090D4A40
31814	Коробкино	1	8	1902	34.737169000000002	34.768368000000002	52.186914999999999	52.168171000000001	0103000020E610000001000000050000000150C58D5B5E41405C9198A086154A400150C58D5B5E4140E010AAD4EC174A407FA5F3E159624140E010AAD4EC174A407FA5F3E1596241405C9198A086154A400150C58D5B5E41405C9198A086154A40
30785	Дмитриев-Льговский	1	8	1902	35.045983	35.095094000000003	52.135553000000002	52.113380999999997	0103000020E6100000010000000500000003965CC5E28541406F7EC344830E4A4003965CC5E2854140F6EFFACC59114A40DE054A0A2C8C4140F6EFFACC59114A40DE054A0A2C8C41406F7EC344830E4A4003965CC5E28541406F7EC344830E4A40
54483	Дмитриев	1	8	1902	35.045983	35.095094000000003	52.135553000000002	52.113380999999997	0103000020E6100000010000000500000003965CC5E28541406F7EC344830E4A4003965CC5E2854140F6EFFACC59114A40DE054A0A2C8C4140F6EFFACC59114A40DE054A0A2C8C41406F7EC344830E4A4003965CC5E28541406F7EC344830E4A40
30982	Дерюгино	1	8	1902	35.040484999999997	35.115073000000002	52.219434999999997	52.205551	0103000020E61000000100000005000000417DCB9C2E8541407E54C37E4F1A4A40417DCB9C2E854140834C3272161C4A4089D349B6BA8E4140834C3272161C4A4089D349B6BA8E41407E54C37E4F1A4A40417DCB9C2E8541407E54C37E4F1A4A40
31360	Генеральшино	1	8	1902	35.253197999999998	35.308183	52.099386000000003	52.061174000000001	0103000020E61000000100000005000000D0B4C4CA68A04140C9AEB48CD4074A40D0B4C4CA68A0414013D731AEB80C4A407217618A72A7414013D731AEB80C4A407217618A72A74140C9AEB48CD4074A40D0B4C4CA68A04140C9AEB48CD4074A40
31627	Бычки	1	8	1902	34.983953999999997	35.030667000000001	52.238604000000002	52.224654000000001	0103000020E610000001000000050000005A626534F27D414032755776C11C4A405A626534F27D4140EF586C938A1E4A40810871E5EC834140EF586C938A1E4A40810871E5EC83414032755776C11C4A405A626534F27D414032755776C11C4A40
32145	Береза	1	8	1902	34.960346999999999	34.980155000000003	51.963603999999997	51.951160000000002	0103000020E61000000100000005000000E6E786A6EC7A4140B6A1629CBFF94940E6E786A6EC7A4140BB25396057FB4940650113B8757D4140BB25396057FB4940650113B8757D4140B6A1629CBFF94940E6E786A6EC7A4140B6A1629CBFF94940
30697	Ясенки	1	8	688	38.182909000000002	38.254351999999997	51.550091999999999	51.524945000000002	0103000020E610000001000000050000007192E68F691743407099D36531C349407192E68F6917434047E5266A69C649400AD6389B8E20434047E5266A69C649400AD6389B8E2043407099D36531C349407192E68F691743407099D36531C34940
54529	Улобное	1	8	688	38.077671000000002	38.113990000000001	51.603898999999998	51.586174	0103000020E610000001000000050000007F6C921FF1094340FCE1E7BF07CB49407F6C921FF1094340268BFB8F4CCD494018096D39970E4340268BFB8F4CCD494018096D39970E4340FCE1E7BF07CB49407F6C921FF1094340FCE1E7BF07CB4940
29975	Старомеловое	1	8	688	38.180618000000003	38.297587999999998	51.408378999999996	51.342419999999997	0103000020E61000000100000005000000D388997D1E17434087BF266BD4AB4940D388997D1E174340C4AF58C345B449404DD7135D17264340C4AF58C345B449404DD7135D1726434087BF266BD4AB4940D388997D1E17434087BF266BD4AB4940
30388	Средние Апочки	1	8	688	37.664194999999999	37.735494000000003	51.536951999999999	51.486336000000001	0103000020E6100000010000000500000057957D5704D54240096F0F4240BE494057957D5704D54240CAC2D7D7BAC44940BE33DAAA24DE4240CAC2D7D7BAC44940BE33DAAA24DE4240096F0F4240BE494057957D5704D54240096F0F4240BE4940
4798	Среднедорожное	1	8	688	37.569935000000001	37.599525	51.520859000000002	51.471246000000001	0103000020E6100000010000000500000042EC4CA1F3C84240772FF7C951BC494042EC4CA1F3C84240E469F981ABC249403411363CBDCC4240E469F981ABC249403411363CBDCC4240772FF7C951BC494042EC4CA1F3C84240772FF7C951BC4940
29984	Сосновка	1	8	688	38.150587999999999	38.191963999999999	51.478966	51.423450000000003	0103000020E61000000100000005000000C495B37746134340E0BE0E9C33B64940C495B37746134340AEF204C24EBD49403201BF4692184340AEF204C24EBD49403201BF4692184340E0BE0E9C33B64940C495B37746134340E0BE0E9C33B64940
30083	Солдатское	1	8	688	37.869244000000002	37.928327000000003	51.491892999999997	51.465305000000001	0103000020E61000000100000005000000431F2C6343EF424028D53E1D8FBB4940431F2C6343EF4240CF108E59F6BE4940357F4C6BD3F64240CF108E59F6BE4940357F4C6BD3F6424028D53E1D8FBB4940431F2C6343EF424028D53E1D8FBB4940
29609	Ржавец	1	8	688	37.593685999999998	37.627884999999999	51.441929000000002	51.422342999999998	0103000020E61000000100000005000000E90B21E7FDCB4240E658DE550FB64940E90B21E7FDCB4240B613252191B84940115322895ED04240B613252191B84940115322895ED04240E658DE550FB64940E90B21E7FDCB4240E658DE550FB64940
30065	Петровка	1	8	688	38.211798999999999	38.247416999999999	51.437645000000003	51.425730000000001	0103000020E61000000100000005000000AA29C93A1C1B43408A7615527EB64940AA29C93A1C1B4340042159C004B84940BABC395CAB1F4340042159C004B84940BABC395CAB1F43408A7615527EB64940AA29C93A1C1B43408A7615527EB64940
29345	Отрада	1	8	688	37.851754	37.911096999999998	51.640780999999997	51.504362999999998	0103000020E610000001000000050000005C1E6B4606ED4240FE277FF78EC049405C1E6B4606ED4240F7729F1C05D24940EA3D95D39EF44240F7729F1C05D24940EA3D95D39EF44240FE277FF78EC049405C1E6B4606ED4240FE277FF78EC04940
29903	Новомеловое	1	8	688	38.193303	38.261386000000002	51.395466999999996	51.348686999999998	0103000020E61000000100000005000000FE9B1727BE1843402AC58EC6A1AC4940FE9B1727BE184340D8D2A3A99EB24940EED0B01875214340D8D2A3A99EB24940EED0B018752143402AC58EC6A1AC4940FE9B1727BE1843402AC58EC6A1AC4940
29865	Никольское	1	8	688	37.622765000000001	37.676231999999999	51.449002	51.429487000000002	0103000020E61000000100000005000000F60B76C3B6CF42405187156EF9B64940F60B76C3B6CF424057EBC4E578B949401C412AC58ED6424057EBC4E578B949401C412AC58ED642405187156EF9B64940F60B76C3B6CF42405187156EF9B64940
29682	Нижние Борки	1	8	688	38.087032000000001	38.124212999999997	51.426268999999998	51.392628999999999	0103000020E610000001000000050000004DDA54DD230B4340083BC5AA41B249404DDA54DD230B434039268BFB8FB64940785E2A36E60F434039268BFB8FB64940785E2A36E60F4340083BC5AA41B249404DDA54DD230B4340083BC5AA41B24940
29726	Мокрец	1	8	688	38.113712	38.142798999999997	51.368287000000002	51.355386000000003	0103000020E61000000100000005000000D594641D8E0E434067BAD7497DAD4940D594641D8E0E43405F45460724AF49406473D53C471243405F45460724AF49406473D53C4712434067BAD7497DAD4940D594641D8E0E434067BAD7497DAD4940
30210	Максимовка	1	8	688	37.860934999999998	37.892564999999998	51.502833000000003	51.477614000000003	0103000020E61000000100000005000000AA7D3A1E33EE42404E0E9F7422BD4940AA7D3A1E33EE4240BF2CEDD45CC04940F146E6913FF24240BF2CEDD45CC04940F146E6913FF242404E0E9F7422BD4940AA7D3A1E33EE42404E0E9F7422BD4940
29507	Кунье	1	8	688	37.647199000000001	37.684488000000002	51.422006000000003	51.410423999999999	0103000020E610000001000000050000008080B56AD7D242402BBF0CC688B449408080B56AD7D242409F5BE84A04B649409240834D9DD742409F5BE84A04B649409240834D9DD742402BBF0CC688B449408080B56AD7D242402BBF0CC688B44940
30773	Кулевка	1	8	688	38.170737000000003	38.217278999999998	51.58023	51.552036000000001	0103000020E61000000100000005000000CC9BC3B5DA1543407A1B9B1DA9C64940CC9BC3B5DA1543403C1405FA44CA4940C58D5BCCCF1B43403C1405FA44CA4940C58D5BCCCF1B43407A1B9B1DA9C64940CC9BC3B5DA1543407A1B9B1DA9C64940
29435	Ключ	1	8	688	37.917752999999998	37.970592000000003	51.548681000000002	51.528604000000001	0103000020E61000000100000005000000276728EE78F542407444BE4BA9C34940276728EE78F54240E277D32D3BC649402FE1D05B3CFC4240E277D32D3BC649402FE1D05B3CFC42407444BE4BA9C34940276728EE78F542407444BE4BA9C34940
30642	Ивановка	1	8	688	38.106966	38.134903000000001	51.633391000000003	51.602103	0103000020E6100000010000000500000058E4D70FB10D434068E90AB611CD494058E4D70FB10D4340564ACFF412D14940EF90628044114340564ACFF412D14940EF9062804411434068E90AB611CD494058E4D70FB10D434068E90AB611CD4940
29410	Знаменка	1	8	688	37.740785000000002	37.765515999999998	51.491512	51.455378000000003	0103000020E61000000100000005000000062FFA0AD2DE4240B1A888D349BA4940062FFA0AD2DE4240B8CB7EDDE9BE49404948A46DFCE14240B8CB7EDDE9BE49404948A46DFCE14240B1A888D349BA4940062FFA0AD2DE4240B1A888D349BA4940
30552	Залесье	1	8	688	37.950280999999997	37.997720999999999	51.442849000000002	51.425820000000002	0103000020E610000001000000050000004D81CCCEA2F94240CAFD0E4581B649404D81CCCEA2F942407D08AA46AFB8494026C45C52B5FF42407D08AA46AFB8494026C45C52B5FF4240CAFD0E4581B649404D81CCCEA2F94240CAFD0E4581B64940
28986	Горшечное	1	8	688	38.000928000000002	38.071392000000003	51.546838000000001	51.504201000000002	0103000020E610000001000000050000004AD3A0681E00434025CE8AA889C049404AD3A0681E004340E31A9FC9FEC549401899805F23094340E31A9FC9FEC549401899805F2309434025CE8AA889C049404AD3A0681E00434025CE8AA889C04940
30326	Головище	1	8	688	37.553522000000001	37.586697000000001	51.555905000000003	51.522663999999999	0103000020E61000000100000005000000EACE13CFD9C64240F56569A7E6C24940EACE13CFD9C64240695721E527C74940A6D425E318CB4240695721E527C74940A6D425E318CB4240F56569A7E6C24940EACE13CFD9C64240F56569A7E6C24940
29820	Вислое	1	8	688	38.044756999999997	38.072892000000003	51.386924	51.367882999999999	0103000020E610000001000000050000002FA2ED98BA0543408FE046CA16AF49402FA2ED98BA054340CD04C3B986B14940ED116A8654094340CD04C3B986B14940ED116A86540943408FE046CA16AF49402FA2ED98BA0543408FE046CA16AF4940
29304	Быково	1	8	688	37.856084000000003	37.901440000000001	51.607249000000003	51.581606999999998	0103000020E610000001000000050000007F50172994ED4240F50F221972CA49407F50172994ED4240ADC3D155BACD494033A7CB6262F34240ADC3D155BACD494033A7CB6262F34240F50F221972CA49407F50172994ED4240F50F221972CA4940
30224	Боровка	1	8	688	37.785026999999999	37.800874	51.543377	51.518740999999999	0103000020E610000001000000050000000EBDC5C37BE44240130CE71A66C249400EBDC5C37BE442400533A6608DC54940BD1B0B0A83E642400533A6608DC54940BD1B0B0A83E64240130CE71A66C249400EBDC5C37BE44240130CE71A66C24940
29762	Болото	1	8	688	38.098396000000001	38.156660000000002	51.421568000000001	51.383871999999997	0103000020E610000001000000050000005307793D980C4340D0ECBAB722B149405307793D980C43402385B2F0F5B54940B24B546F0D1443402385B2F0F5B54940B24B546F0D144340D0ECBAB722B149405307793D980C4340D0ECBAB722B14940
29234	Богородицкое	1	8	688	38.097659	38.132972000000002	51.494808999999997	51.460557999999999	0103000020E610000001000000050000007D941117800C4340A1F48590F3BA49407D941117800C43401B62BCE655BF494051A4FB39051143401B62BCE655BF494051A4FB3905114340A1F48590F3BA49407D941117800C4340A1F48590F3BA4940
29283	Богатырево	1	8	688	37.771974999999998	37.811878	51.594918999999997	51.560704000000001	0103000020E61000000100000005000000302AA913D0E24240425E0F26C5C74940302AA913D0E242406F62484E26CC4940C32B499EEBE742406F62484E26CC4940C32B499EEBE74240425E0F26C5C74940302AA913D0E24240425E0F26C5C74940
30456	Белгородка	1	8	688	37.731082999999998	37.762093	51.568295999999997	51.510216	0103000020E61000000100000005000000AED4B32094DD4240AEF204C24EC14940AED4B32094DD42404B395FECBDC8494059C16F438CE142404B395FECBDC8494059C16F438CE14240AEF204C24EC14940AED4B32094DD4240AEF204C24EC14940
30156	Бекетовский	1	8	688	37.851512	37.859586999999998	51.456752999999999	51.450265000000002	0103000020E6100000010000000500000066136058FEEC424048C49448A2B9494066136058FEEC4240C9ACDEE176BA49408B8862F206EE4240C9ACDEE176BA49408B8862F206EE424048C49448A2B9494066136058FEEC424048C49448A2B94940
29545	Бараново	1	8	688	37.708590000000001	37.754852999999997	51.405053000000002	51.389122	0103000020E61000000100000005000000E622BE13B3DA4240BA13ECBFCEB14940E622BE13B3DA4240C712D6C6D8B34940CC24EA059FE04240C712D6C6D8B34940CC24EA059FE04240BA13ECBFCEB14940E622BE13B3DA4240BA13ECBFCEB14940
28984	Ходяковка	1	8	682	34.476829000000002	34.514423000000001	51.350673	51.335211999999999	0103000020E61000000100000005000000676490BB083D4140069D103AE8AA4940676490BB083D41408C4B55DAE2AC4940B5A7E49CD84141408C4B55DAE2AC4940B5A7E49CD8414140069D103AE8AA4940676490BB083D4140069D103AE8AA4940
26971	Теткино	1	8	682	34.241253999999998	34.321159999999999	51.282974000000003	51.253793999999999	0103000020E61000000100000005000000BC033C69E11E4140E4F560527CA04940BC033C69E11E414025CFF57D38A44940456458C51B29414025CFF57D38A44940456458C51B294140E4F560527CA04940BC033C69E11E4140E4F560527CA04940
28930	Сухиновка	1	8	682	34.508592999999998	34.557650000000002	51.332887999999997	51.302686999999999	0103000020E61000000100000005000000BDFC4E931941414051F69672BEA64940BDFC4E93194141408C9DF0129CAA4940A54E4013614741408C9DF0129CAA4940A54E40136147414051F69672BEA64940BDFC4E931941414051F69672BEA64940
4739	Ржава	1	8	682	34.636037000000002	34.673155000000001	51.412883999999998	51.391841999999997	0103000020E61000000100000005000000E20511A9695141408099EFE027B24940E20511A96951414055850662D9B44940C7116BF12956414055850662D9B44940C7116BF1295641408099EFE027B24940E20511A9695141408099EFE027B24940
28869	Попово-Лежачи	1	8	682	34.274428999999998	34.346851000000001	51.307107000000002	51.273755999999999	0103000020E6100000010000000500000078094E7D20234140B98AC56F0AA3494078094E7D20234140B4AF3C484FA74940DECA129D652C4140B4AF3C484FA74940DECA129D652C4140B98AC56F0AA3494078094E7D20234140B98AC56F0AA34940
54554	Политотдельский	1	8	682	34.219048000000001	34.847293999999998	51.484428999999999	51.17109	0103000020E610000001000000050000008A20CEC3091C41401956F146E69549408A20CEC3091C4140F31DFCC401BE49406B0C3A21746C4140F31DFCC401BE49406B0C3A21746C41401956F146E69549408A20CEC3091C41401956F146E6954940
28688	Нижний Мордок	1	8	682	34.698954999999998	34.724800000000002	51.387087000000001	51.369283000000003	0103000020E610000001000000050000001630815B7759414001FC53AA44AF49401630815B7759414077DA1A118CB149400612143FC65C414077DA1A118CB149400612143FC65C414001FC53AA44AF49401630815B7759414001FC53AA44AF4940
28592	Марково	1	8	682	34.373693000000003	34.425660999999998	51.419601999999998	51.397877000000001	0103000020E6100000010000000500000040DF162CD52F4140516A2FA2EDB2494040DF162CD52F414008ABB184B5B549406117450F7C36414008ABB184B5B549406117450F7C364140516A2FA2EDB2494040DF162CD52F4140516A2FA2EDB24940
28275	Лещиновка	1	8	682	34.512456	34.559868999999999	51.417878000000002	51.403317000000001	0103000020E61000000100000005000000CA51802898414140DE7536E49FB34940CA51802898414140E4DBBB067DB54940A98592C9A9474140E4DBBB067DB54940A98592C9A9474140DE7536E49FB34940CA51802898414140DE7536E49FB34940
28438	Кульбаки	1	8	682	34.757148000000001	34.802278999999999	51.261713999999998	51.223388	0103000020E61000000100000005000000AC1DC539EA604140D0285DFA979C4940AC1DC539EA604140E27327D87FA1494040A20914B1664140E27327D87FA1494040A20914B1664140D0285DFA979C4940AC1DC539EA604140D0285DFA979C4940
28421	Коровяковка	1	8	682	34.345359999999999	34.411349999999999	51.342104999999997	51.324401000000002	0103000020E610000001000000050000005CACA8C1342C414015E5D2F885A949405CACA8C1342C41402766BD18CAAB4940D49AE61DA73441402766BD18CAAB4940D49AE61DA734414015E5D2F885A949405CACA8C1342C414015E5D2F885A94940
28360	Кобылки	1	8	682	34.654038999999997	34.703617000000001	51.337367	51.310766999999998	0103000020E610000001000000050000007EA7C98CB753414088D68A36C7A749407EA7C98CB7534140F4DF83D72EAB49406FF4311F105A4140F4DF83D72EAB49406FF4311F105A414088D68A36C7A749407EA7C98CB753414088D68A36C7A74940
28297	Карыж	1	8	682	34.421959000000001	34.468491999999998	51.386592	51.366616999999998	0103000020E610000001000000050000005EA0A4C0023641402D944C4EEDAE49405EA0A4C0023641409772BED87BB149400438BD8BF73B41409772BED87BB149400438BD8BF73B41402D944C4EEDAE49405EA0A4C0023641402D944C4EEDAE4940
28221	Званное	1	8	682	34.522767999999999	34.572426999999998	51.386958	51.364649	0103000020E610000001000000050000009AB2D30FEA42414072C284D1ACAE49409AB2D30FEA4241407976F9D687B14940772CB649454941407976F9D687B14940772CB6494549414072C284D1ACAE49409AB2D30FEA42414072C284D1ACAE4940
28517	Елизаветовка	1	8	682	34.721412999999998	34.745164000000003	51.205182000000001	51.189548000000002	0103000020E6100000010000000500000062F4DC42575C4140D882DE1B4398494062F4DC42575C41402BDD5D67439A49400A14B188615F41402BDD5D67439A49400A14B188615F4140D882DE1B4398494062F4DC42575C4140D882DE1B43984940
28617	Дроновка	1	8	682	34.286034999999998	34.316550999999997	51.432018999999997	51.421253999999998	0103000020E6100000010000000500000074417DCB9C24414093A7ACA6EBB5494074417DCB9C24414014200A664CB749400F4240BE8428414014200A664CB749400F4240BE8428414093A7ACA6EBB5494074417DCB9C24414093A7ACA6EBB54940
27888	Глушково	1	8	682	34.605134999999997	34.656922999999999	51.352383000000003	51.319324000000002	0103000020E610000001000000050000001D554D10754D4140F969DC9BDFA849401D554D10754D41404C55DAE21AAD4940BF7E880D165441404C55DAE21AAD4940BF7E880D16544140F969DC9BDFA849401D554D10754D4140F969DC9BDFA84940
28840	Высокое	1	8	682	34.728023999999998	34.753231	51.420972999999996	51.383034000000002	0103000020E61000000100000005000000FF59F3E32F5D4140C7A0134207B14940FF59F3E32F5D4140DFBF7971E2B54940ACAA97DF69604140DFBF7971E2B54940ACAA97DF69604140C7A0134207B14940FF59F3E32F5D4140C7A0134207B14940
28124	Веселое	1	8	682	34.531804999999999	34.567630000000001	51.297832999999997	51.278410000000001	0103000020E61000000100000005000000B56CAD2F124441408F705AF0A2A34940B56CAD2F12444140B45549641FA649403F1D8F19A8484140B45549641FA649403F1D8F19A84841408F705AF0A2A34940B56CAD2F124441408F705AF0A2A34940
5737	Алексеевка	1	8	682	34.324159999999999	34.359437	51.397399999999998	51.378728000000002	0103000020E61000000100000005000000EF552B137E2941402D0ABB287AB04940EF552B137E29414017B7D100DEB2494076FC1708022E414017B7D100DEB2494076FC1708022E41402D0ABB287AB04940EF552B137E2941402D0ABB287AB04940
54555	Шербачевка	1	8	713	35.456747	35.504133000000003	51.401878000000004	51.388570999999999	0103000020E61000000100000005000000E7C589AF76BA41404696CCB1BCB14940E7C589AF76BA4140AF7D01BD70B34940CDEA1D6E87C04140AF7D01BD70B34940CDEA1D6E87C041404696CCB1BCB14940E7C589AF76BA41404696CCB1BCB14940
27805	Шелеповка	1	8	713	35.693767000000001	35.717500999999999	51.251336000000002	51.239620000000002	0103000020E61000000100000005000000A305685BCDD84140D8BB3FDEAB9E4940A305685BCDD841405B272EC72BA0494074ECA012D7DB41405B272EC72BA0494074ECA012D7DB4140D8BB3FDEAB9E4940A305685BCDD84140D8BB3FDEAB9E4940
27742	Сторожевое	1	8	713	35.632331999999998	35.655005000000003	51.291497	51.274596000000003	0103000020E610000001000000050000006D1B4641F0D0414064CE33F625A349406D1B4641F0D04140E9F010C64FA54940B6DB2E34D7D34140E9F010C64FA54940B6DB2E34D7D3414064CE33F625A349406D1B4641F0D0414064CE33F625A34940
27423	Скородное	1	8	713	35.579357999999999	35.646749	51.368062000000002	51.345025	0103000020E610000001000000050000008656276728CA4140B5A679C729AC49408656276728CA41403F73D6A71CAF494040DCD5ABC8D241403F73D6A71CAF494040DCD5ABC8D24140B5A679C729AC49408656276728CA4140B5A679C729AC4940
27602	Саморядово	1	8	713	35.544279000000003	35.559747999999999	51.245941000000002	51.226891000000002	0103000020E6100000010000000500000026732CEFAAC54140DD60A8C30A9D494026732CEFAAC541406EDFA3FE7A9F49402E008DD2A5C741406EDFA3FE7A9F49402E008DD2A5C74140DD60A8C30A9D494026732CEFAAC54140DD60A8C30A9D4940
4983	Первомайская	1	8	713	35.454752999999997	35.484909000000002	51.361910000000002	51.351370000000003	0103000020E610000001000000050000000261A75835BA4140D46531B1F9AC49400261A75835BA4140350C1F1153AE49409E44847F11BE4140350C1F1153AE49409E44847F11BE4140D46531B1F9AC49400261A75835BA4140D46531B1F9AC4940
27432	Нижнее Гридино	1	8	713	35.683562000000002	35.728586	51.419674999999998	51.391672999999997	0103000020E61000000100000005000000E964A9F57ED74140F4DC425722B24940E964A9F57ED7414072F90FE9B7B549406729594E42DD414072F90FE9B7B549406729594E42DD4140F4DC425722B24940E964A9F57ED74140F4DC425722B24940
26775	Махов Колодезь	1	8	713	35.538519999999998	35.567267000000001	51.283678000000002	51.265354000000002	0103000020E61000000100000005000000F71E2E39EEC4414070EEAF1EF7A14940F71E2E39EEC441401F4C8A8F4FA44940CE8C7E349CC841401F4C8A8F4FA44940CE8C7E349CC8414070EEAF1EF7A14940F71E2E39EEC4414070EEAF1EF7A14940
27796	Малый Каменец	1	8	713	35.649076000000001	35.673385000000003	51.238993999999998	51.225171000000003	0103000020E610000001000000050000002B4F20EC14D34140FA804067D29C49402B4F20EC14D3414059F8FA5A979E4940F94ECC7A31D6414059F8FA5A979E4940F94ECC7A31D64140FA804067D29C49402B4F20EC14D34140FA804067D29C4940
27311	Любостань	1	8	713	35.720033999999998	35.766216	51.349868000000001	51.297134	0103000020E610000001000000050000000801F9122ADC4140CC43A67C08A649400801F9122ADC41405EF58079C8AC494002D6AA5D13E241405EF58079C8AC494002D6AA5D13E24140CC43A67C08A649400801F9122ADC4140CC43A67C08A64940
27166	Любимовка	1	8	713	35.621633000000003	35.672863999999997	51.509224000000003	51.496794000000001	0103000020E61000000100000005000000A48E8EAB91CF4140AD6C1FF296BF4940A48E8EAB91CF41404E2B85402EC14940EF53556820D641404E2B85402EC14940EF53556820D64140AD6C1FF296BF4940A48E8EAB91CF4140AD6C1FF296BF4940
27348	Леоновка	1	8	713	35.763845000000003	35.800306999999997	51.289965000000002	51.267355000000002	0103000020E61000000100000005000000481B47ACC5E1414007B64AB038A24940481B47ACC5E1414009FEB7921DA5494043E1B37570E6414009FEB7921DA5494043E1B37570E6414007B64AB038A24940481B47ACC5E1414007B64AB038A24940
27565	Извеково	1	8	713	35.653207999999999	35.687334999999997	51.390892000000001	51.378048	0103000020E6100000010000000500000027BEDA519CD34140BB287AE063B0494027BEDA519CD341404F22C2BF08B24940B532E197FAD741404F22C2BF08B24940B532E197FAD74140BB287AE063B0494027BEDA519CD34140BB287AE063B04940
27243	Долгий	1	8	713	35.630749999999999	35.689239999999998	51.568519999999999	51.555900000000001	0103000020E61000000100000005000000DBF97E6ABCD0414057EC2FBB27C74940DBF97E6ABCD041409B8F6B43C5C849402A8C2D0439D841409B8F6B43C5C849402A8C2D0439D8414057EC2FBB27C74940DBF97E6ABCD0414057EC2FBB27C74940
16547	Вышнее Бабино	1	8	713	35.756317000000003	35.793067000000001	51.298440999999997	51.282201999999998	0103000020E610000001000000050000005534D6FECEE04140D26EF4311FA449405534D6FECEE041408C648F5033A64940B7442E3883E541408C648F5033A64940B7442E3883E54140D26EF4311FA449405534D6FECEE04140D26EF4311FA44940
27035	Волоконск	1	8	713	35.406091000000004	35.439166999999998	51.439953000000003	51.428986999999999	0103000020E61000000100000005000000981936CAFAB341405FB4C70BE9B64940981936CAFAB341407863416150B84940C03DCF9F36B841407863416150B84940C03DCF9F36B841405FB4C70BE9B64940981936CAFAB341405FB4C70BE9B64940
27693	Будище	1	8	713	35.517060000000001	35.545411000000001	51.225825	51.205334000000001	0103000020E61000000100000005000000EE08A7052FC24140E1606F62489A4940EE08A7052FC2414042CF66D5E79C494078F01307D0C5414042CF66D5E79C494078F01307D0C54140E1606F62489A4940EE08A7052FC24140E1606F62489A4940
27097	Борщень	1	8	713	35.553908999999997	35.590460999999998	51.476239	51.453251000000002	0103000020E61000000100000005000000E3FA777DE6C641408DF0F62004BA4940E3FA777DE6C64140350A4966F5BC49401F48DE3994CB4140350A4966F5BC49401F48DE3994CB41408DF0F62004BA4940E3FA777DE6C641408DF0F62004BA4940
26678	Большое Солдатское	1	8	713	35.494951999999998	35.550980000000003	51.347793000000003	51.315322000000002	0103000020E610000001000000050000007E8B4E965ABF4140CBDAA6785CA849407E8B4E965ABF41408D63247B84AC494003603C8386C641408D63247B84AC494003603C8386C64140CBDAA6785CA849407E8B4E965ABF4140CBDAA6785CA84940
40243	Большесолдатский сельсовет,  деревня Ржава	1	8	713	35.417130999999998	35.434361000000003	51.375613999999999	51.365588000000002	0103000020E61000000100000005000000EA92718C64B54140B0E76B96CBAE4940EA92718C64B54140BAF59A1E14B0494035D4282499B74140BAF59A1E14B0494035D4282499B74140B0E76B96CBAE4940EA92718C64B54140B0E76B96CBAE4940
27651	Бирюковка	1	8	713	35.475287999999999	35.503081999999999	51.281188	51.260151999999998	0103000020E610000001000000050000003317B83CD6BC414097FE25A94CA149403317B83CD6BC41408A03E8F7FDA34940679AB0FD64C041408A03E8F7FDA34940679AB0FD64C0414097FE25A94CA149403317B83CD6BC414097FE25A94CA14940
54524	1-я Касторная	1	8	713	35.664212999999997	35.688960999999999	51.499844000000003	51.487985000000002	0103000020E61000000100000005000000FD497CEE04D5414023F8DF4A76BE4940FD497CEE04D54140098D60E3FABF4940179CC1DF2FD84140098D60E3FABF4940179CC1DF2FD8414023F8DF4A76BE4940FD497CEE04D5414023F8DF4A76BE4940
26628	Щеголек	1	8	1772	35.609684999999999	35.640856999999997	51.191240999999998	51.174371000000001	0103000020E610000001000000050000004EEE77280ACE4140772FF7C9519649404EEE77280ACE4140C153C8957A984940D234289A07D24140C153C8957A984940D234289A07D24140772FF7C9519649404EEE77280ACE4140772FF7C951964940
25502	Суходол	1	8	1772	35.631999	35.659362000000002	51.098131000000002	51.089486999999998	0103000020E61000000100000005000000670DDE57E5D0414065355D4F748B4940670DDE57E5D04140A5DC7D8E8F8C4940D21C59F965D44140A5DC7D8E8F8C4940D21C59F965D4414065355D4F748B4940670DDE57E5D0414065355D4F748B4940
26452	Слободка-Корочка	1	8	1772	35.705787000000001	35.721812999999997	51.140053000000002	51.131253999999998	0103000020E610000001000000050000009278793A57DA41400EBC5AEECC9049409278793A57DA4140755AB741ED914940F0694E5E64DC4140755AB741ED914940F0694E5E64DC41400EBC5AEECC9049409278793A57DA41400EBC5AEECC904940
26057	Петровы Буды	1	8	1772	35.706361999999999	35.724066999999998	51.201343999999999	51.180503000000002	0103000020E610000001000000050000008E91EC116ADA41403AEAE8B81A9749408E91EC116ADA4140779FE3A3C5994940718E3A3AAEDC4140779FE3A3C5994940718E3A3AAEDC41403AEAE8B81A9749408E91EC116ADA41403AEAE8B81A974940
26573	Песчаное	1	8	1772	35.637900999999999	35.684694	51.081418999999997	51.064864999999998	0103000020E61000000100000005000000F88A6EBDA6D14140D8D30E7F4D884940F88A6EBDA6D14140F22213F06B8A49403BE2900DA4D74140F22213F06B8A49403BE2900DA4D74140D8D30E7F4D884940F88A6EBDA6D14140D8D30E7F4D884940
26557	Пены	1	8	1772	35.891370000000002	35.955258000000001	51.096263999999998	51.032617999999999	0103000020E610000001000000050000005951836918F2414066A19DD32C8449405951836918F241401DE4F560528C4940069FE6E445FA41401DE4F560528C4940069FE6E445FA414066A19DD32C8449405951836918F2414066A19DD32C844940
25398	Пенский	1	8	1772	35.808734000000001	35.846893999999999	51.025270999999996	50.985273999999997	0103000020E61000000100000005000000E694809884E74140AFCC5B751D7E4940E694809884E74140C34483143C834940DD96C80567EC4140C34483143C834940DD96C80567EC4140AFCC5B751D7E4940E694809884E74140AFCC5B751D7E4940
26203	Озерки	1	8	1772	35.506819	35.534028999999997	51.031570000000002	51.014131999999996	0103000020E61000000100000005000000E7FEEA71DFC04140DDE9CE13CF814940E7FEEA71DFC0414072C45A7C0A844940CB0EF10F5BC4414072C45A7C0A844940CB0EF10F5BC44140DDE9CE13CF814940E7FEEA71DFC04140DDE9CE13CF814940
25957	Мокрушино	1	8	1772	35.634433999999999	35.656694000000002	50.984554000000003	50.963006999999998	0103000020E6100000010000000500000038BC202235D14140D76839D0437B494038BC202235D14140B0928FDD057E49405EBD8A8C0ED44140B0928FDD057E49405EBD8A8C0ED44140D76839D0437B494038BC202235D14140D76839D0437B4940
54516	Малое Солдатское	1	8	1772	35.662587000000002	35.704816999999998	51.047547000000002	51.021900000000002	0103000020E610000001000000050000009CE09BA6CFD4414026E4839ECD8249409CE09BA6CFD44140EF022505168649401955867137DA4140EF022505168649401955867137DA414026E4839ECD8249409CE09BA6CFD4414026E4839ECD824940
25328	Лошаковка	1	8	1772	35.704385000000002	35.748869999999997	51.082867999999998	51.068911999999997	0103000020E610000001000000050000008065A54929DA4140A626C11BD28849408065A54929DA414045F12A6B9B8A49404E7ADFF8DADF414045F12A6B9B8A49404E7ADFF8DADF4140A626C11BD28849408065A54929DA4140A626C11BD2884940
54538	Кучеров	1	8	1772	35.398401	35.413223000000002	51.021838000000002	51.009614999999997	0103000020E61000000100000005000000CBD8D0CDFEB24140884677103B814940CBD8D0CDFEB24140B0E76B96CB8249403E7AC37DE4B44140B0E76B96CB8249403E7AC37DE4B44140884677103B814940CBD8D0CDFEB24140884677103B814940
25754	Крупец	1	8	1772	35.477597000000003	35.509559000000003	51.095545999999999	51.076138999999998	0103000020E6100000010000000500000078D503E621BD41409E7939ECBE89494078D503E621BD4140BEA1F0D93A8C4940F530B43A39C14140BEA1F0D93A8C4940F530B43A39C141409E7939ECBE89494078D503E621BD41409E7939ECBE894940
25868	Кривицкие Буды	1	8	1772	35.763961999999999	35.799337000000001	51.224736999999998	51.194690000000001	0103000020E6100000010000000500000081B1BE81C9E14140DB6D179AEB98494081B1BE81C9E14140BF99982EC49C4940CBBDC0AC50E64140BF99982EC49C4940CBBDC0AC50E64140DB6D179AEB98494081B1BE81C9E14140DB6D179AEB984940
26284	Корочка	1	8	1772	35.702148999999999	35.731011000000002	51.098537999999998	51.084814000000001	0103000020E61000000100000005000000A5F5B704E0D94140191F662FDB8A4940A5F5B704E0D94140E5B4A7E49C8C49401502B9C491DD4140E5B4A7E49C8C49401502B9C491DD4140191F662FDB8A4940A5F5B704E0D94140191F662FDB8A4940
26103	Кондратовка	1	8	1772	35.438034999999999	35.461373000000002	51.011797000000001	50.987535999999999	0103000020E610000001000000050000006EC0E78711B84140B3CF6394677E49406EC0E78711B841407098689082814940F3203D450EBB41407098689082814940F3203D450EBB4140B3CF6394677E49406EC0E78711B84140B3CF6394677E4940
26016	Коммунар	1	8	1772	35.697899999999997	35.718165999999997	51.167572	51.147070999999997	0103000020E610000001000000050000006FF085C954D941405298F738D39249406FF085C954D94140D7DCD1FF72954940B08C0DDDECDB4140D7DCD1FF72954940B08C0DDDECDB41405298F738D39249406FF085C954D941405298F738D3924940
25744	Камышное	1	8	1772	35.511839999999999	35.552650999999997	51.101461999999998	51.083132999999997	0103000020E610000001000000050000006F641EF983C14140F31B261AA48A49406F641EF983C14140B4E4F1B4FC8C4940048D9944BDC64140B4E4F1B4FC8C4940048D9944BDC64140F31B261AA48A49406F641EF983C14140F31B261AA48A4940
25925	Илек	1	8	1772	35.587470000000003	35.630749999999999	50.975605000000002	50.928911999999997	0103000020E61000000100000005000000C9B08A3732CB4140546EA296E6764940C9B08A3732CB41403468E89FE07C4940DBF97E6ABCD041403468E89FE07C4940DBF97E6ABCD04140546EA296E6764940C9B08A3732CB4140546EA296E6764940
26257	Забужевка	1	8	1772	35.469934000000002	35.501240000000003	50.977125000000001	50.955188999999997	0103000020E61000000100000005000000A5A31CCC26BC4140DD3F16A2437A4940A5A31CCC26BC4140508D976E127D494039B9DFA128C04140508D976E127D494039B9DFA128C04140DD3F16A2437A4940A5A31CCC26BC4140DD3F16A2437A4940
26346	Долгий Колодезь	1	8	1772	35.759030000000003	35.772342999999999	51.110934999999998	51.087116999999999	0103000020E61000000100000005000000695721E527E141407BF65CA6268B4940695721E527E14140AA7D3A1E338E4940B325AB22DCE24140AA7D3A1E338E4940B325AB22DCE241407BF65CA6268B4940695721E527E141407BF65CA6268B4940
25822	Долгие Буды	1	8	1772	35.734254	35.755077	51.174681999999997	51.153992000000002	0103000020E61000000100000005000000857AFA08FCDD41403EEC8502B6934940857AFA08FCDD41409599D2FA5B9649401C7BF65CA6E041409599D2FA5B9649401C7BF65CA6E041403EEC8502B6934940857AFA08FCDD41403EEC8502B6934940
25607	Гочево	1	8	1772	35.864744000000002	35.883589999999998	51.127952000000001	51.114299000000003	0103000020E61000000100000005000000C4B46FEEAFEE4140967B8159A18E4940C4B46FEEAFEE414099BA2BBB609049404C89247A19F1414099BA2BBB609049404C89247A19F14140967B8159A18E4940C4B46FEEAFEE4140967B8159A18E4940
54519	Гоптаровка	1	8	1772	35.386543000000003	35.413294999999998	50.990008000000003	50.969172999999998	0103000020E61000000100000005000000B6BFB33D7AB14140469561DC0D7C4940B6BFB33D7AB14140A2630795B87E4940D74CBED9E6B44140A2630795B87E4940D74CBED9E6B44140469561DC0D7C4940B6BFB33D7AB14140469561DC0D7C4940
25698	Гирьи	1	8	1772	35.562055999999998	35.600262000000001	51.106845999999997	51.070456999999998	0103000020E61000000100000005000000A2427573F1C741401B6327BC04894940A2427573F1C74140ADDA3521AD8D49400A849D62D5CC4140ADDA3521AD8D49400A849D62D5CC41401B6327BC04894940A2427573F1C741401B6327BC04894940
25610	Вишнево	1	8	1772	35.615138000000002	35.656514000000001	51.026975999999998	50.983510000000003	0103000020E6100000010000000500000070438CD7BCCE4140FDA4DAA7E37D494070438CD7BCCE414071E316F373834940DEAE97A608D4414071E316F373834940DEAE97A608D44140FDA4DAA7E37D494070438CD7BCCE4140FDA4DAA7E37D4940
25507	Бобрава	1	8	1772	35.795096999999998	35.833463999999999	51.098458999999998	51.061853999999997	0103000020E61000000100000005000000E8120EBDC5E541403A90F5D4EA874940E8120EBDC5E54140997FF44D9A8C49405932C7F2AEEA4140997FF44D9A8C49405932C7F2AEEA41403A90F5D4EA874940E8120EBDC5E541403A90F5D4EA874940
25438	Белица	1	8	1772	35.522700999999998	35.607205999999998	51.137566999999997	51.107349999999997	0103000020E61000000100000005000000124BCADDE7C24140E09C11A5BD8D4940124BCADDE7C241402101A3CB9B914940ADF71BEDB8CD41402101A3CB9B914940ADF71BEDB8CD4140E09C11A5BD8D4940124BCADDE7C24140E09C11A5BD8D4940
25234	Белая	1	8	1772	35.701402999999999	35.737344999999998	51.068018000000002	51.044981999999997	0103000020E610000001000000050000007C28D192C7D941404F745DF8C18549407C28D192C7D9414009C556D0B48849403F6F2A5261DE414009C556D0B48849403F6F2A5261DE41404F745DF8C18549407C28D192C7D941404F745DF8C1854940
31594	Шарья	1	7	\N	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
53332	Нея	1	7	\N	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
26418	Нерехта	1	7	\N	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
53334	Мантурово	1	7	\N	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
4664	Мантурово	1	7	\N	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
53324	Макарьев	1	7	\N	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
53341	Лаврово	1	7	\N	44.023144000000002	44.02919	58.643967000000004	58.640548000000003	0103000020E61000000100000005000000A08CF161F602464055C2137AFD514D40A08CF161F6024640045ABA826D524D4064AF777FBC034640045ABA826D524D4064AF777FBC03464055C2137AFD514D40A08CF161F602464055C2137AFD514D40
886	Кострома	1	7	\N	40.803635999999997	41.050547000000002	57.837164000000001	57.707574999999999	0103000020E61000000100000005000000B2F1608BDD664440CD3B4ED191DA4C40B2F1608BDD664440BCB1A03028EB4C4099F4F75278864440BCB1A03028EB4C4099F4F75278864440CD3B4ED191DA4C40B2F1608BDD664440CD3B4ED191DA4C40
53351	Кологрив	1	7	\N	44.293644999999998	44.358035999999998	58.835416000000002	58.806310000000003	0103000020E6100000010000000500000024D1CB28962546400938842A35674D4024D1CB28962546400F4757E9EE6A4D403465A71FD42D46400F4757E9EE6A4D403465A71FD42D46400938842A35674D4024D1CB28962546400938842A35674D40
29631	Волгореченск	1	7	\N	41.139929000000002	41.194718000000002	57.469189	57.423183999999999	0103000020E6100000010000000500000089618731E99144406118B0E42AB64C4089618731E99144404C5299620EBC4C40A5F8F884EC9844404C5299620EBC4C40A5F8F884EC9844406118B0E42AB64C4089618731E99144406118B0E42AB64C40
3522	Буй	1	7	\N	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
53317	Шарья	1	7	7281	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
25316	Шекшема	1	7	1104	45.151319999999998	45.198391999999998	58.352508999999998	58.330222999999997	0103000020E61000000100000005000000889D29745E93464089B14CBF442A4D40889D29745E934640D845D1031F2D4D40DEE4B7E864994640D845D1031F2D4D40DEE4B7E86499464089B14CBF442A4D40889D29745E93464089B14CBF442A4D40
25716	Троицкое	1	7	1104	45.746149000000003	45.764879000000001	58.20937	58.204698999999998	0103000020E61000000100000005000000B87878CF81DF46400F43AB93331A4D40B87878CF81DF4640BB61DBA2CC1A4D40D732198EE7E14640BB61DBA2CC1A4D40D732198EE7E146400F43AB93331A4D40B87878CF81DF46400F43AB93331A4D40
25516	Сергеево	1	7	1104	45.636589999999998	45.659677000000002	58.119754	58.104664	0103000020E61000000100000005000000F67AF7C77BD14640C68844A1650D4D40F67AF7C77BD1464058C85C19540F4D403276C24B70D4464058C85C19540F4D403276C24B70D44640C68844A1650D4D40F67AF7C77BD14640C68844A1650D4D40
25381	Рождественское	1	7	1104	45.55903	45.600047000000004	58.158420999999997	58.143698000000001	0103000020E61000000100000005000000CFBD874B8EC74640144031B264124D40CFBD874B8EC74640F3FFAA2347144D400E881057CECC4640F3FFAA2347144D400E881057CECC4640144031B264124D40CFBD874B8EC74640144031B264124D40
25014	Пищевка	1	7	1104	45.456558999999999	45.465505999999998	58.59243	58.580576999999998	0103000020E61000000100000005000000E4D87A8670BA4640A7E7DD58504A4D40E4D87A8670BA4640AB9509BFD44B4D40BF0B5BB395BB4640AB9509BFD44B4D40BF0B5BB395BB4640A7E7DD58504A4D40E4D87A8670BA4640A7E7DD58504A4D40
25694	Печенкино	1	7	1104	45.668641999999998	45.685530999999997	57.955514000000001	57.948326999999999	0103000020E61000000100000005000000B35DA10F96D54640F77475C762F94C40B35DA10F96D54640616F62484EFA4C4074B2D47ABFD74640616F62484EFA4C4074B2D47ABFD74640F77475C762F94C40B35DA10F96D54640F77475C762F94C40
25802	Одоевское	1	7	1104	45.864016999999997	45.878641000000002	58.166500999999997	58.156278999999998	0103000020E610000001000000050000001118EB1B98EE46409A0645F300144D401118EB1B98EE46402AE09EE74F154D405EF6EB4E77F046402AE09EE74F154D405EF6EB4E77F046409A0645F300144D401118EB1B98EE46409A0645F300144D40
24955	Николо-Шанга	1	7	1104	45.531326	45.550908999999997	58.459198999999998	58.446528000000001	0103000020E61000000100000005000000DBC1887D02C44640C85F5AD427394D40DBC1887D02C446408EAD6708C73A4D403909A52F84C646408EAD6708C73A4D403909A52F84C64640C85F5AD427394D40DBC1887D02C44640C85F5AD427394D40
46262	Медведица	1	7	1104	45.727086999999997	45.931130000000003	58.205993999999997	58.103689000000003	0103000020E61000000100000005000000622CD32F11DD46403CFA5FAE450D4D40622CD32F11DD46400B96EA025E1A4D40892991442FF746400B96EA025E1A4D40892991442FF746403CFA5FAE450D4D40622CD32F11DD46403CFA5FAE450D4D40
25489	Майтиха	1	7	1104	45.460898	45.482241999999999	58.066687000000002	58.055911999999999	0103000020E610000001000000050000005A65A6B4FEBA46401BBAD91F28074D405A65A6B4FEBA4640C0081A3389084D40FA60191BBABD4640C0081A3389084D40FA60191BBABD46401BBAD91F28074D405A65A6B4FEBA46401BBAD91F28074D40
25071	Кривячка	1	7	1104	45.436436999999998	45.460960999999998	58.668708000000002	58.656623000000003	0103000020E61000000100000005000000D6E1E82ADDB746409566F3380C544D40D6E1E82ADDB746406B49473998554D40A0DD21C500BB46406B49473998554D40A0DD21C500BB46409566F3380C544D40D6E1E82ADDB746409566F3380C544D40
25878	Конево	1	7	1104	45.912337000000001	45.938622000000002	58.097169000000001	58.077824	0103000020E6100000010000000500000023F77475C7F44640056C0723F6094D4023F77475C7F44640AF97A608700C4D402FA704C424F84640AF97A608700C4D402FA704C424F84640056C0723F6094D4023F77475C7F44640056C0723F6094D40
25620	Катунино	1	7	1104	45.622701999999997	45.640624000000003	58.021014000000001	58.007728	0103000020E61000000100000005000000AF93FAB2B4CF4640BAA1293BFD004D40AF93FAB2B4CF46400B613596B0024D4030849CF7FFD146400B613596B0024D4030849CF7FFD14640BAA1293BFD004D40AF93FAB2B4CF4640BAA1293BFD004D40
25228	Зебляки	1	7	1104	45.727958000000001	45.776063000000001	58.382435000000001	58.364156999999999	0103000020E61000000100000005000000486E4DBA2DDD464003CE52B29C2E4D40486E4DBA2DDD464042EC4CA1F3304D405D514A0856E3464042EC4CA1F3304D405D514A0856E3464003CE52B29C2E4D40486E4DBA2DDD464003CE52B29C2E4D40
25167	Заболотье	1	7	1104	45.820394999999998	45.834964999999997	58.297184000000001	58.278444999999998	0103000020E61000000100000005000000A5660FB402E946400B5EF415A4234D40A5660FB402E946407E7214200A264D40FE261422E0EA46407E7214200A264D40FE261422E0EA46400B5EF415A4234D40A5660FB402E946400B5EF415A4234D40
25087	Головино	1	7	1104	45.685108	45.701627999999999	58.629446999999999	58.622048999999997	0103000020E610000001000000050000002E1D739EB1D7464037C1374D9F4F4D402E1D739EB1D746405CC823B891504D409CFA40F2CED946405CC823B891504D409CFA40F2CED9464037C1374D9F4F4D402E1D739EB1D7464037C1374D9F4F4D40
53298	Ветлужский	1	7	1104	45.420222000000003	45.500216999999999	58.411980999999997	58.376947000000001	0103000020E61000000100000005000000A587A1D5C9B54640A4A99ECC3F304D40A587A1D5C9B5464064C91CCBBB344D409DF3531C07C0464064C91CCBBB344D409DF3531C07C04640A4A99ECC3F304D40A587A1D5C9B54640A4A99ECC3F304D40
25287	Варакинский	1	7	1104	45.329331000000003	45.353881999999999	58.375262999999997	58.355871	0103000020E610000001000000050000008D47A98427AA4640234C512E8D2D4D408D47A98427AA46400D33349E08304D40505260014CAD46400D33349E08304D40505260014CAD4640234C512E8D2D4D408D47A98427AA4640234C512E8D2D4D40
25584	Быниха	1	7	1104	45.565246000000002	45.592329999999997	58.063611000000002	58.049959000000001	0103000020E61000000100000005000000F0181EFB59C846400892770E65064D40F0181EFB59C846403B55BE6724084D4047382D78D1CB46403B55BE6724084D4047382D78D1CB46400892770E65064D40F0181EFB59C846400892770E65064D40
9862	Боровской	1	7	1104	45.620258999999997	45.636743000000003	58.501229000000002	58.493079000000002	0103000020E610000001000000050000005B069CA564CF464015AC71361D3F4D405B069CA564CF46404567994528404D407D7A6CCB80D146404567994528404D407D7A6CCB80D1464015AC71361D3F4D405B069CA564CF464015AC71361D3F4D40
25412	Берзиха	1	7	1104	45.493417000000001	45.525647999999997	58.114449	58.101706	0103000020E610000001000000050000002D25CB4928BF46404BE7C3B3040D4D402D25CB4928BF4640AB07CC43A60E4D40999A046F48C34640AB07CC43A60E4D40999A046F48C346404BE7C3B3040D4D402D25CB4928BF46404BE7C3B3040D4D40
3313	Якша	1	7	494	43.033138000000001	43.051814	58.765875000000001	58.755485999999998	0103000020E610000001000000050000009F20B1DD3D844540FD4AE7C3B3604D409F20B1DD3D84454079E9263108624D40CBBC55D7A186454079E9263108624D40CBBC55D7A1864540FD4AE7C3B3604D409F20B1DD3D844540FD4AE7C3B3604D40
3724	Шартаново	1	7	494	43.270175999999999	43.281657000000003	59.073881999999998	59.066490000000002	0103000020E6100000010000000500000001158E2095A245406AC18BBE82884D4001158E2095A24540ACE122F774894D4041D829560DA44540ACE122F774894D4041D829560DA445406AC18BBE82884D4001158E2095A245406AC18BBE82884D40
2951	Чухлома	1	7	494	42.655377999999999	42.713310999999997	58.767321000000003	58.743744	0103000020E610000001000000050000004A42226DE3534540514CDE00335F4D404A42226DE35345405B44149337624D4043705CC64D5B45405B44149337624D4043705CC64D5B4540514CDE00335F4D404A42226DE3534540514CDE00335F4D40
3077	Федоровское	1	7	494	42.532362999999997	42.550707000000003	58.827399999999997	58.819270000000003	0103000020E61000000100000005000000DB4C857824444540064CE0D6DD684D40DB4C857824444540EE5A423EE8694D40D25625917D464540EE5A423EE8694D40D25625917D464540064CE0D6DD684D40DB4C857824444540064CE0D6DD684D40
9597	Тимофеевское	1	7	494	42.66075	42.672159000000001	58.745578999999999	58.740372000000001	0103000020E610000001000000050000007F6ABC7493544540E36F7B82C45E4D407F6ABC7493544540CDCAF6216F5F4D40255B5D4E09564540CDCAF6216F5F4D40255B5D4E09564540E36F7B82C45E4D407F6ABC7493544540E36F7B82C45E4D40
3525	Судай	1	7	494	43.111902000000001	43.150044999999999	58.992724000000003	58.956090000000003	0103000020E61000000100000005000000B22D03CE528E45402E043928617A4D40B22D03CE528E454027FA7C94117F4D40D3F6AFAC3493454027FA7C94117F4D40D3F6AFAC349345402E043928617A4D40B22D03CE528E45402E043928617A4D40
53364	Сенная	1	7	494	42.459716	42.482551000000001	58.779839000000003	58.773676000000002	0103000020E6100000010000000500000056B950F9D73A45409DD9AED007634D4056B950F9D73A45409B92ACC3D1634D4078D32D3BC43D45409B92ACC3D1634D4078D32D3BC43D45409DD9AED007634D4056B950F9D73A45409DD9AED007634D40
3404	Повалихино	1	7	494	42.841096	42.858407	58.894502000000003	58.886662000000001	0103000020E61000000100000005000000F165A208A96B4540904DF2237E714D40F165A208A96B4540721AA20A7F724D4028D4D347E06D4540721AA20A7F724D4028D4D347E06D4540904DF2237E714D40F165A208A96B4540904DF2237E714D40
3198	Панкратово	1	7	494	43.470877999999999	43.496121000000002	59.170470999999999	59.160530999999999	0103000020E61000000100000005000000F433F5BA45BC4540417FA1478C944D40F433F5BA45BC45404DF564FED1954D40EEED96E480BF45404DF564FED1954D40EEED96E480BF4540417FA1478C944D40F433F5BA45BC4540417FA1478C944D40
3061	Ножкино	1	7	494	42.600535999999998	42.628573000000003	58.824641999999997	58.813231000000002	0103000020E610000001000000050000000B09185DDE4C4540F48B12F417684D400B09185DDE4C45403A747ADE8D694D4006137F14755045403A747ADE8D694D4006137F1475504540F48B12F417684D400B09185DDE4C4540F48B12F417684D40
15295	Некрасово	1	7	494	42.542586	42.550877	58.680591999999997	58.675488000000001	0103000020E610000001000000050000003CA2427573454540946B0A6476564D403CA2427573454540A9F57EA31D574D402E8F352383464540A9F57EA31D574D402E8F352383464540946B0A6476564D403CA2427573454540946B0A6476564D40
3643	Куливертово	1	7	494	42.918711000000002	42.930937	59.121993000000003	59.116219999999998	0103000020E61000000100000005000000DCBC7152987545401092054CE08E4D40DCBC715298754540A4AB74779D8F4D4074D190F128774540A4AB74779D8F4D4074D190F1287745401092054CE08E4D40DCBC7152987545401092054CE08E4D40
3201	Коровье	1	7	494	42.857706	42.872869000000001	58.689334000000002	58.679839000000001	0103000020E610000001000000050000009FCA694FC96D4540CEC5DFF604574D409FCA694FC96D4540AC02B5183C584D409B58E02BBA6F4540AC02B5183C584D409B58E02BBA6F4540CEC5DFF604574D409FCA694FC96D4540CEC5DFF604574D40
3427	Георгий	1	7	494	42.79813	42.811703000000001	59.024340000000002	59.017110000000002	0103000020E610000001000000050000006EFAB31F29664540A03715A930824D406EFAB31F2966454009FEB7921D834D40558847E2E567454009FEB7921D834D40558847E2E5674540A03715A930824D406EFAB31F29664540A03715A930824D40
3745	Вига	1	7	494	43.278342000000002	43.303117999999998	59.101152999999996	59.077294999999999	0103000020E61000000100000005000000378DEDB5A0A34540799274CDE4894D40378DEDB5A0A345403672DD94F28C4D401A6A1492CCA645403672DD94F28C4D401A6A1492CCA64540799274CDE4894D40378DEDB5A0A34540799274CDE4894D40
3296	Введенское	1	7	494	43.024585999999999	43.043908999999999	58.759934000000001	58.748978000000001	0103000020E6100000010000000500000040F850A22583454035B6D782DE5F4D4040F850A2258345402A8F6E8445614D40028063CF9E8545402A8F6E8445614D40028063CF9E85454035B6D782DE5F4D4040F850A22583454035B6D782DE5F4D40
9508	Белово	1	7	494	42.513506999999997	42.527206999999997	58.765959000000002	58.758150999999998	0103000020E610000001000000050000002FA2ED98BA41454000378B170B614D402FA2ED98BA414540D789CBF10A624D40739CDB847B434540D789CBF10A624D40739CDB847B43454000378B170B614D402FA2ED98BA41454000378B170B614D40
9572	Анфимово	1	7	494	42.697671	42.710723999999999	58.730625000000003	58.724038	0103000020E610000001000000050000000E2F88484D594540D787F546AD5C4D400E2F88484D594540EC51B81E855D4D40BC3D0801F95A4540EC51B81E855D4D40BC3D0801F95A4540D787F546AD5C4D400E2F88484D594540D787F546AD5C4D40
2283	Ченцово	1	7	405	41.573852000000002	41.584712000000003	58.110356000000003	58.104425999999997	0103000020E61000000100000005000000425F7AFB73C94440116DC7D45D0D4D40425F7AFB73C944406D753925200E4D4015CAC2D7D7CA44406D753925200E4D4015CAC2D7D7CA4440116DC7D45D0D4D40425F7AFB73C94440116DC7D45D0D4D40
2149	Сусанино	1	7	405	41.567833	41.614733999999999	58.157766000000002	58.132624	0103000020E61000000100000005000000774B72C0AEC844401555BFD2F9104D40774B72C0AEC84440DB3521AD31144D40A0DE8C9AAFCE4440DB3521AD31144D40A0DE8C9AAFCE44401555BFD2F9104D40774B72C0AEC844401555BFD2F9104D40
2255	Сумароково	1	7	405	41.78642	41.809480000000001	58.211123999999998	58.197823	0103000020E61000000100000005000000CD751A69A9E44440C4B2994352194D40CD751A69A9E444404AB3791C061B4D400F62670A9DE744404AB3791C061B4D400F62670A9DE74440C4B2994352194D40CD751A69A9E44440C4B2994352194D40
2849	Сокирино	1	7	405	41.625926999999997	41.634425	58.147342000000002	58.142130999999999	0103000020E6100000010000000500000079573D601ED04440B75F3E5931124D4079573D601ED04440E3A9471ADC124D40E561A1D634D14440E3A9471ADC124D40E561A1D634D14440B75F3E5931124D4079573D601ED04440B75F3E5931124D40
2723	Попадьино	1	7	405	41.883096999999999	41.915022999999998	58.186225	58.174210000000002	0103000020E610000001000000050000000D198F5209F144406E5166834C164D400D198F5209F144404B598638D6174D403D0B42791FF544404B598638D6174D403D0B42791FF544406E5166834C164D400D198F5209F144406E5166834C164D40
2710	Меленки	1	7	405	41.785549000000003	41.805931000000001	58.108611000000003	58.097678000000002	0103000020E61000000100000005000000E833A0DE8CE44440F4C473B6800C4D40E833A0DE8CE44440317E1AF7E60D4D4092EA3BBF28E74440317E1AF7E60D4D4092EA3BBF28E74440F4C473B6800C4D40E833A0DE8CE44440F4C473B6800C4D40
2626	Медведки	1	7	405	41.495168	41.507367000000002	58.079300000000003	58.071218000000002	0103000020E610000001000000050000004B033FAA61BF44407A71E2AB1D094D404B033FAA61BF444052499D80260A4D40EA08E066F1C0444052499D80260A4D40EA08E066F1C044407A71E2AB1D094D404B033FAA61BF44407A71E2AB1D094D40
7592	Малинино	1	7	405	41.503343000000001	41.509802000000001	58.173744999999997	58.170332000000002	0103000020E61000000100000005000000D4D51D8B6DC044402CBB6070CD154D40D4D51D8B6DC04440F86BB2463D164D40BBB7223141C14440F86BB2463D164D40BBB7223141C144402CBB6070CD154D40D4D51D8B6DC044402CBB6070CD154D40
2603	Ломышки	1	7	405	41.391323	41.413367999999998	58.142406000000001	58.134329999999999	0103000020E6100000010000000500000018963FDF16B24440936FB6B931114D4018963FDF16B2444089601C5C3A124D40419B1C3EE9B4444089601C5C3A124D40419B1C3EE9B44440936FB6B931114D4018963FDF16B24440936FB6B931114D40
2836	Запрудня	1	7	405	41.419674000000001	41.437272	58.030431999999998	58.026834000000001	0103000020E61000000100000005000000A27DACE0B7B54440DF35E84B6F034D40A27DACE0B7B544403D601E32E5034D406FBA6587F8B744403D601E32E5034D406FBA6587F8B74440DF35E84B6F034D40A27DACE0B7B54440DF35E84B6F034D40
53345	Григорово	1	7	405	41.148795999999997	42.027096999999998	58.288400000000003	57.968797000000002	0103000020E6100000010000000500000047E350BF0B93444041BB438A01FC4C4047E350BF0B9344404D158C4AEA244D40EC681CEA770345404D158C4AEA244D40EC681CEA7703454041BB438A01FC4C4047E350BF0B93444041BB438A01FC4C40
2488	Головинское	1	7	405	41.660719	41.680112999999999	58.251958999999999	58.239539999999998	0103000020E61000000100000005000000446CB07092D44440BB0A293FA91E4D40446CB07092D444406877483140204D40CF4A5AF10DD744406877483140204D40CF4A5AF10DD74440BB0A293FA91E4D40446CB07092D44440BB0A293FA91E4D40
2392	Буяково	1	7	405	41.312280000000001	41.330309	58.215437999999999	58.209332000000003	0103000020E61000000100000005000000F29881CAF8A74440CE001764CB1A4D40F29881CAF8A744406728EE78931B4D408849B89047AA44406728EE78931B4D408849B89047AA4440CE001764CB1A4D40F29881CAF8A74440CE001764CB1A4D40
2382	Андреевское	1	7	405	41.282977000000002	41.308138999999997	58.168913000000003	58.156891999999999	0103000020E610000001000000050000009642209738A4444084807C0915144D409642209738A44440446FF1F09E154D40A2CF471971A74440446FF1F09E154D40A2CF471971A7444084807C0915144D409642209738A4444084807C0915144D40
31296	Шахово	1	7	247	41.514060000000001	41.533651999999996	57.950194000000003	57.938524999999998	0103000020E610000001000000050000004417D4B7CCC144403CBD529621F84C404417D4B7CCC144407F6DFDF49FF94C40F5B86FB54EC444407F6DFDF49FF94C40F5B86FB54EC444403CBD529621F84C404417D4B7CCC144403CBD529621F84C40
2051	Фадеево	1	7	247	41.575091	41.607151999999999	57.914065000000001	57.902191999999999	0103000020E61000000100000005000000AA9CF6949CC944403E5B07077BF34C40AA9CF6949CC9444089B5F81400F54C40BAD91F28B7CD444089B5F81400F54C40BAD91F28B7CD44403E5B07077BF34C40AA9CF6949CC944403E5B07077BF34C40
978	Судиславль	1	7	247	41.658985000000001	41.730517999999996	57.894817000000003	57.865051000000001	0103000020E61000000100000005000000FCC6D79E59D44440A12FBDFDB9EE4C40FCC6D79E59D44440D2730B5D89F24C40D591239D81DD4440D2730B5D89F24C40D591239D81DD4440A12FBDFDB9EE4C40FCC6D79E59D44440A12FBDFDB9EE4C40
2036	Сорож	1	7	247	41.883347999999998	41.898547999999998	57.836962	57.827790999999998	0103000020E61000000100000005000000567E198C11F144402976340EF5E94C40567E198C11F1444054FF209221EB4C406FF1F09E03F3444054FF209221EB4C406FF1F09E03F344402976340EF5E94C40567E198C11F144402976340EF5E94C40
1334	Свозово	1	7	247	41.932423	41.953093000000003	58.078200000000002	58.067295999999999	0103000020E61000000100000005000000E48409A359F744406893C3279D084D40E48409A359F744400B462575020A4D40F58590F3FEF944400B462575020A4D40F58590F3FEF944406893C3279D084D40E48409A359F744406893C3279D084D40
1599	Раслово	1	7	247	41.417445999999998	41.449407999999998	57.830838999999997	57.815764999999999	0103000020E610000001000000050000004AECDADE6EB54440581CCEFC6AE84C404AECDADE6EB54440E49EAEEE58EA4C40C7478B3386B94440E49EAEEE58EA4C40C7478B3386B94440581CCEFC6AE84C404AECDADE6EB54440581CCEFC6AE84C40
1242	Первушино	1	7	247	41.926538999999998	41.955052000000002	58.050173999999998	58.033566999999998	0103000020E61000000100000005000000F9BB77D498F64440C79C67EC4B044D40F9BB77D498F64440048E041A6C064D405DFDD8243FFA4440048E041A6C064D405DFDD8243FFA4440C79C67EC4B044D40F9BB77D498F64440C79C67EC4B044D40
1541	Михайловское	1	7	247	41.371192000000001	41.390478999999999	57.900297999999999	57.890602000000001	0103000020E61000000100000005000000B7442E3883AF444048E00F3FFFF14C40B7442E3883AF4440BD5301F73CF34C402C634337FBB14440BD5301F73CF34C402C634337FBB1444048E00F3FFFF14C40B7442E3883AF444048E00F3FFFF14C40
1917	Мирный	1	7	247	41.631515	41.647621000000001	57.901240000000001	57.893697000000003	0103000020E610000001000000050000007BF7C77BD5D0444044C4CDA964F24C407BF7C77BD5D044406CEC12D55BF34C40F699B33EE5D244406CEC12D55BF34C40F699B33EE5D2444044C4CDA964F24C407BF7C77BD5D0444044C4CDA964F24C40
1432	Кобякино	1	7	247	41.448428999999997	41.469647000000002	57.756174000000001	57.744509000000001	0103000020E61000000100000005000000FBC9181F66B94440F14927124CDF4C40FBC9181F66B94440F20A444FCAE04C400FD594641DBC4440F20A444FCAE04C400FD594641DBC4440F14927124CDF4C40FBC9181F66B94440F14927124CDF4C40
1495	Калинки	1	7	247	41.284090999999997	41.318730000000002	57.807782000000003	57.798031999999999	0103000020E61000000100000005000000410B09185DA44440AB949EE925E64C40410B09185DA4444014268C6665E74C4086200725CCA8444014268C6665E74C4086200725CCA84440AB949EE925E64C40410B09185DA44440AB949EE925E64C40
1900	Западный	1	7	247	41.643470999999998	41.658966999999997	57.874113000000001	57.869095999999999	0103000020E610000001000000050000005376FA415DD24440CE8AA8893EEF4C405376FA415DD2444015014EEFE2EF4C405512D90759D4444015014EEFE2EF4C405512D90759D44440CE8AA8893EEF4C405376FA415DD24440CE8AA8893EEF4C40
1231	Завражье	1	7	247	41.879871999999999	41.900488000000003	57.949674000000002	57.939619	0103000020E6100000010000000500000043554CA59FF04440A1D9756F45F84C4043554CA59FF0444046EEE9EA8EF94C406138D73043F3444046EEE9EA8EF94C406138D73043F34440A1D9756F45F84C4043554CA59FF04440A1D9756F45F84C40
1801	Жвалово	1	7	247	41.73659	41.752077	57.843420000000002	57.835510999999997	0103000020E61000000100000005000000C347C49448DE444060394206F2EA4C40C347C49448DE44406B65C22FF5EB4C407289230F44E044406B65C22FF5EB4C407289230F44E0444060394206F2EA4C40C347C49448DE444060394206F2EA4C40
1793	Дружба	1	7	247	41.723143	41.737659000000001	57.896577000000001	57.890132999999999	0103000020E6100000010000000500000069AA27F38FDC4440910BCEE0EFF14C4069AA27F38FDC444043ACFE08C3F24C40CF4C309C6BDE444043ACFE08C3F24C40CF4C309C6BDE4440910BCEE0EFF14C4069AA27F38FDC4440910BCEE0EFF14C40
1384	Грудки	1	7	247	41.532843999999997	41.555732999999996	57.830627999999997	57.820928000000002	0103000020E6100000010000000500000056EF703B34C44440732F302B14E94C4056EF703B34C444402992AF0452EA4C406B274A4222C744402992AF0452EA4C406B274A4222C74440732F302B14E94C4056EF703B34C44440732F302B14E94C40
1699	Глебово	1	7	247	41.670385000000003	41.707844000000001	57.933450000000001	57.905315000000002	0103000020E610000001000000050000004F5DF92CCFD5444004CAA65CE1F34C404F5DF92CCFD54440C139234A7BF74C40BD55D7A19ADA4440C139234A7BF74C40BD55D7A19ADA444004CAA65CE1F34C404F5DF92CCFD5444004CAA65CE1F34C40
1157	Воронье	1	7	247	41.984391000000002	42.019587000000001	58.011102999999999	57.991159000000003	0103000020E6100000010000000500000006BD378600FE44406B11514CDEFE4C4006BD378600FE444099F1B6D26B014D40A036AAD38102454099F1B6D26B014D40A036AAD3810245406B11514CDEFE4C4006BD378600FE44406B11514CDEFE4C40
1680	Березовая Роща	1	7	247	41.395949000000002	41.410718000000003	57.826535	57.815759999999997	0103000020E6100000010000000500000024F1F274AEB2444046B1DCD26AE84C4024F1F274AEB24440EBFF1CE6CBE94C4074F04C6892B44440EBFF1CE6CBE94C4074F04C6892B4444046B1DCD26AE84C4024F1F274AEB2444046B1DCD26AE84C40
53329	д. Великово	1	7	90	42.119236999999998	42.140993999999999	59.305487999999997	59.295785000000002	0103000020E6100000010000000500000090BC7328430F4540DDD26A48DCA54D4090BC7328430F454004A9143B1AA74D40537765170C12454004A9143B1AA74D40537765170C124540DDD26A48DCA54D4090BC7328430F4540DDD26A48DCA54D40
770	Солигалич	1	7	90	42.254379	42.318133000000003	59.091216000000003	59.064644000000001	0103000020E6100000010000000500000004E5B67D8F204540FAF02C4146884D4004E5B67D8F2045409C6F44F7AC8B4D40A2630795B82845409C6F44F7AC8B4D40A2630795B8284540FAF02C4146884D4004E5B67D8F204540FAF02C4146884D40
52355	Песлиново	1	7	90	42.091020999999998	42.104163	58.859926999999999	58.853085	0103000020E61000000100000005000000E61F7D93A60B4540A5DAA7E3316D4D40E61F7D93A60B454044F98216126E4D40043A9336550D454044F98216126E4D40043A9336550D4540A5DAA7E3316D4D40E61F7D93A60B4540A5DAA7E3316D4D40
52358	Лосево	1	7	90	42.324843000000001	42.341183999999998	58.930973999999999	58.922376	0103000020E61000000100000005000000D2AA967494294540C24EB16A10764D40D2AA96749429454091B6F1272A774D4090F5D4EAAB2B454091B6F1272A774D4090F5D4EAAB2B4540C24EB16A10764D40D2AA967494294540C24EB16A10764D40
52348	Куземино	1	7	90	42.492019999999997	42.515475000000002	59.229424999999999	59.221522999999998	0103000020E610000001000000050000002C7DE882FA3E4540E9279CDD5A9C4D402C7DE882FA3E454041F163CC5D9D4D40EB73B515FB41454041F163CC5D9D4D40EB73B515FB414540E9279CDD5A9C4D402C7DE882FA3E4540E9279CDD5A9C4D40
112	Корцово	1	7	90	42.193528000000001	42.219802999999999	58.874048000000002	58.859302999999997	0103000020E610000001000000050000001E6E8786C5184540662D05A4FD6D4D401E6E8786C51845402E910BCEE06F4D4006483481221C45402E910BCEE06F4D4006483481221C4540662D05A4FD6D4D401E6E8786C5184540662D05A4FD6D4D40
52361	Коровново	1	7	90	42.358089999999997	42.382713000000003	58.980381000000001	58.967829000000002	0103000020E610000001000000050000002783A3E4D52D4540698F17D2E17B4D402783A3E4D52D4540554FE61F7D7D4D40856055BDFC304540554FE61F7D7D4D40856055BDFC304540698F17D2E17B4D402783A3E4D52D4540698F17D2E17B4D40
52363	Калинино	1	7	90	41.872011999999998	41.888764999999999	58.992330000000003	58.982644000000001	0103000020E610000001000000050000001ADCD6169EEF444029CE5147C77D4D401ADCD6169EEF44407B6B60AB047F4D402B6A300DC3F144407B6B60AB047F4D402B6A300DC3F1444029CE5147C77D4D401ADCD6169EEF444029CE5147C77D4D40
40330	Заяцкое	1	7	90	42.192844999999998	42.204028999999998	59.092815999999999	59.085099999999997	0103000020E610000001000000050000003B191C25AF184540DE718A8EE48A4D403B191C25AF184540D4450A65E18B4D40C1374D9F1D1A4540D4450A65E18B4D40C1374D9F1D1A4540DE718A8EE48A4D403B191C25AF184540DE718A8EE48A4D40
52347	Зашугомье	1	7	90	42.547823000000001	42.562313000000003	59.169646	59.156171000000001	0103000020E61000000100000005000000917F66101F464540B4CA4C69FD934D40917F66101F464540D8F2CAF5B6954D40CE8E54DFF9474540D8F2CAF5B6954D40CE8E54DFF9474540B4CA4C69FD934D40917F66101F464540B4CA4C69FD934D40
52357	Жилино	1	7	90	41.991092000000002	42.000667999999997	58.900683999999998	58.895510000000002	0103000020E61000000100000005000000E3A9471ADCFE4440D89E5912A0724D40E3A9471ADCFE4440E603029D49734D40AD1397E315004540E603029D49734D40AD1397E315004540D89E5912A0724D40E3A9471ADCFE4440D89E5912A0724D40
606	Гнездниково	1	7	90	42.292746000000001	42.304622000000002	59.063764999999997	59.059620000000002	0103000020E61000000100000005000000750470B3782545400118CFA0A1874D40750470B37825454091D0967329884D4031D28BDAFD26454091D0967329884D4031D28BDAFD2645400118CFA0A1874D40750470B3782545400118CFA0A1874D40
32327	Высоковский	1	7	90	42.698946999999997	42.714208999999997	59.084063999999998	59.076878000000001	0103000020E61000000100000005000000935165187759454015E46723D7894D409351651877594540AE62F19BC28A4D4022C154336B5B4540AE62F19BC28A4D4022C154336B5B454015E46723D7894D40935165187759454015E46723D7894D40
32312	Бурдуково	1	7	90	42.571933999999999	42.589703	59.073242999999998	59.062294000000001	0103000020E6100000010000000500000038BC202235494540575EF23FF9874D4038BC20223549454099D4D00660894D4032AD4D637B4B454099D4D00660894D4032AD4D637B4B4540575EF23FF9874D4038BC202235494540575EF23FF9874D40
52350	Большой Починок	1	7	90	42.208961000000002	42.225633000000002	58.925041999999998	58.913381000000001	0103000020E61000000100000005000000DA91EA3BBF1A4540D6E429ABE9744D40DA91EA3BBF1A454095B6B8C667764D40FEF2C98AE11C454095B6B8C667764D40FEF2C98AE11C4540D6E429ABE9744D40DA91EA3BBF1A4540D6E429ABE9744D40
9785	Сергеевица	1	7	643	45.853417	45.877195	58.874951000000003	58.864711	0103000020E61000000100000005000000DB6CACC43CED4640E8BE9CD9AE6E4D40DB6CACC43CED46401F4DF564FE6F4D407C9BFEEC47F046401F4DF564FE6F4D407C9BFEEC47F04640E8BE9CD9AE6E4D40DB6CACC43CED4640E8BE9CD9AE6E4D40
4230	Пыщуг	1	7	643	45.682493999999998	45.744208999999998	58.900917	58.872889999999998	0103000020E61000000100000005000000ADDBA0F65BD74640B28009DCBA6F4D40ADDBA0F65BD7464089B48D3F51734D40C631923D42DF464089B48D3F51734D40C631923D42DF4640B28009DCBA6F4D40ADDBA0F65BD74640B28009DCBA6F4D40
10110	Носково	1	7	643	45.596328	45.620536999999999	59.078774000000003	59.061141999999997	0103000020E6100000010000000500000034D8D47954CC4640BD344580D3874D4034D8D47954CC464037E33444158A4D409E7AA4C16DCF464037E33444158A4D409E7AA4C16DCF4640BD344580D3874D4034D8D47954CC4640BD344580D3874D40
9820	Михайловица	1	7	643	45.643138999999998	45.680877000000002	58.778075999999999	58.759658999999999	0103000020E610000001000000050000001DE4F56052D24640588E90813C614D401DE4F56052D24640B8E68EFE97634D409FCC3FFA26D74640B8E68EFE97634D409FCC3FFA26D74640588E90813C614D401DE4F56052D24640588E90813C614D40
10068	Крутая	1	7	643	45.420644000000003	45.436176000000003	58.738359000000003	58.727584	0103000020E610000001000000050000001BA19FA9D7B54640E38BF678215D4D401BA19FA9D7B5464088DA368C825E4D406AA67B9DD4B7464088DA368C825E4D406AA67B9DD4B74640E38BF678215D4D401BA19FA9D7B54640E38BF678215D4D40
9962	Колпашница	1	7	643	45.561059999999998	45.580122000000003	58.866213999999999	58.856859999999998	0103000020E61000000100000005000000008C67D0D0C7464012A0A696AD6D4D40008C67D0D0C746402EABB019E06E4D4056D80C7041CA46402EABB019E06E4D4056D80C7041CA464012A0A696AD6D4D40008C67D0D0C7464012A0A696AD6D4D40
9928	Головино	1	7	643	45.517007	45.536014999999999	58.799779000000001	58.787885000000003	0103000020E61000000100000005000000CB660E492DC2464026016A6AD9644D40CB660E492DC24640888384285F664D402D95B7239CC44640888384285F664D402D95B7239CC4464026016A6AD9644D40CB660E492DC2464026016A6AD9644D40
10037	Верхнеспасское	1	7	643	45.478667000000002	45.507655	58.729554999999998	58.711981000000002	0103000020E610000001000000050000005456D3F544BD4640CB2F8331225B4D405456D3F544BD46400FD1E80E625D4D405053CBD6FAC046400FD1E80E625D4D405053CBD6FAC04640CB2F8331225B4D405456D3F544BD4640CB2F8331225B4D40
31217	Якшанга	1	7	805	45.891711999999998	45.942591999999998	58.370704000000003	58.341434	0103000020E61000000100000005000000B2B96A9E23F2464009DFFB1BB42B4D40B2B96A9E23F246408A3F8A3A732F4D4051BCCADAA6F846408A3F8A3A732F4D4051BCCADAA6F8464009DFFB1BB42B4D40B2B96A9E23F2464009DFFB1BB42B4D40
30916	Хмелевка	1	7	805	46.391686999999997	46.421889	58.411222000000002	58.400250999999997	0103000020E6100000010000000500000059A2B3CC223247407C98BD6C3B334D4059A2B3CC22324740A7B228ECA2344D4065C5707500364740A7B228ECA2344D4065C57075003647407C98BD6C3B334D4059A2B3CC223247407C98BD6C3B334D40
5704	Поназырево	1	7	805	46.288857	46.337941000000001	58.372497000000003	58.343404	0103000020E610000001000000050000003F1C2444F924474065A88AA9F42B4D403F1C2444F9244740D76D50FBAD2F4D40207D93A6412B4740D76D50FBAD2F4D40207D93A6412B474065A88AA9F42B4D403F1C2444F924474065A88AA9F42B4D40
12953	Полдневица	1	7	805	46.588633999999999	46.629292	58.624972	58.60398	0103000020E6100000010000000500000026A8E15B584B474013B875374F4D4D4026A8E15B584B474036751E15FF4F4D4035D1E7A38C50474036751E15FF4F4D4035D1E7A38C50474013B875374F4D4D4026A8E15B584B474013B875374F4D4D40
31020	Клюкино	1	7	805	46.495001999999999	46.517792999999998	58.562595000000002	58.554003999999999	0103000020E6100000010000000500000030BABC395C3F474035ED629AE9464D4030BABC395C3F474052F2EA1C03484D40828C800A4742474052F2EA1C03484D40828C800A4742474035ED629AE9464D4030BABC395C3F474035ED629AE9464D40
31193	Гудково	1	7	805	46.456716	46.474196999999997	58.483220000000003	58.474260999999998	0103000020E61000000100000005000000ACC77DAB753A474056629E95B43C4D40ACC77DAB753A4740F6622827DA3D4D403F6EBF7CB23C4740F6622827DA3D4D403F6EBF7CB23C474056629E95B43C4D40ACC77DAB753A474056629E95B43C4D40
30943	Горлово	1	7	805	46.443080000000002	46.461306999999998	58.423985999999999	58.414290999999999	0103000020E610000001000000050000007FC16ED8B63847407903CC7C07354D407FC16ED8B63847401EFB592C45364D403B35971B0C3B47401EFB592C45364D403B35971B0C3B47407903CC7C07354D407FC16ED8B63847407903CC7C07354D40
30309	Успенье	1	7	638	43.441834999999998	43.460304999999998	58.457340000000002	58.447282000000001	0103000020E61000000100000005000000349D9D0C8EB84540740B5D8940394D40349D9D0C8EB845408A93FB1D8A3A4D40B7973446EBBA45408A93FB1D8A3A4D40B7973446EBBA4540740B5D8940394D40349D9D0C8EB84540740B5D8940394D40
25978	Тотомица	1	7	638	43.779800000000002	43.805500000000002	58.450032	58.427779999999998	0103000020E61000000100000005000000DDB5847CD0E3454002F1BA7EC1364D40DDB5847CD0E34540A51309A69A394D40C976BE9F1AE74540A51309A69A394D40C976BE9F1AE7454002F1BA7EC1364D40DDB5847CD0E3454002F1BA7EC1364D40
30395	Савино	1	7	638	43.532359	43.539921999999997	58.617133000000003	58.614082000000003	0103000020E610000001000000050000009A5DF75624C44540F9872D3D9A4E4D409A5DF75624C445402524D236FE4E4D400932022A1CC545402524D236FE4E4D400932022A1CC54540F9872D3D9A4E4D409A5DF75624C44540F9872D3D9A4E4D40
30317	Потрусово	1	7	638	43.669271000000002	43.694487000000002	58.451124999999998	58.44285	0103000020E61000000100000005000000A39410ACAAD545404D840D4FAF384D40A39410ACAAD5454039B4C876BE394D40A33F34F3E4D8454039B4C876BE394D40A33F34F3E4D845404D840D4FAF384D40A39410ACAAD545404D840D4FAF384D40
30775	Парфеньево	1	7	638	43.390262999999997	43.420518000000001	58.491540999999998	58.476340999999998	0103000020E610000001000000050000005FEB5223F4B14540395FECBDF83C4D405FEB5223F4B1454052D2C3D0EA3E4D408EB0A888D3B5454052D2C3D0EA3E4D408EB0A888D3B54540395FECBDF83C4D405FEB5223F4B14540395FECBDF83C4D40
30444	Николо-Ширь	1	7	638	43.531613	43.552948000000001	58.579559000000003	58.569277999999997	0103000020E61000000100000005000000719010E50BC44540882AFC19DE484D40719010E50BC445401E8D43FD2E4A4D40BE310400C7C645401E8D43FD2E4A4D40BE310400C7C64540882AFC19DE484D40719010E50BC44540882AFC19DE484D40
4182	Николо-Полома	1	7	638	43.310887999999998	43.339894999999999	58.351838999999998	58.344835000000003	0103000020E61000000100000005000000035C902DCBA7454012C2A38D232C4D40035C902DCBA745408A3A730F092D4D407689EAAD81AB45408A3A730F092D4D407689EAAD81AB454012C2A38D232C4D40035C902DCBA7454012C2A38D232C4D40
30752	Матвеево	1	7	638	43.474623999999999	43.495176999999998	58.649267999999999	58.637779999999999	0103000020E61000000100000005000000C7F2AE7AC0BC45407D0569C6A2514D40C7F2AE7AC0BC45406F2BBD361B534D409E5DBEF561BF45406F2BBD361B534D409E5DBEF561BF45407D0569C6A2514D40C7F2AE7AC0BC45407D0569C6A2514D40
30715	Вохтома	1	7	638	43.428548999999997	43.452373000000001	58.706195000000001	58.694347	0103000020E61000000100000005000000E3DD91B1DAB64540B189CC5CE0584D40E3DD91B1DAB64540A3CC0699645A4D40F54BC45BE7B94540A3CC0699645A4D40F54BC45BE7B94540B189CC5CE0584D40E3DD91B1DAB64540B189CC5CE0584D40
30624	Бор	1	7	638	43.362971999999999	43.386634000000001	58.274526999999999	58.263924000000003	0103000020E610000001000000050000008EAED2DD75AE45409450FA42C8214D408EAED2DD75AE45403B6F63B323234D40C6C210397DB145403B6F63B323234D40C6C210397DB145409450FA42C8214D408EAED2DD75AE45409450FA42C8214D40
30471	Аносово	1	7	638	43.239857999999998	43.264912000000002	58.530693999999997	58.522627	0103000020E610000001000000050000008CD7BCAAB39E4540D8800871E5424D408CD7BCAAB39E45407A17EFC7ED434D40B328ECA2E8A145407A17EFC7ED434D40B328ECA2E8A14540D8800871E5424D408CD7BCAAB39E4540D8800871E5424D40
30103	Шумково	1	7	1877	46.279811000000002	46.308619999999998	59.115315000000002	59.109313	0103000020E61000000100000005000000D107CBD8D02347408A03E8F7FD8D4D40D107CBD8D02347407FDE54A4C28E4D401D7233DC802747407FDE54A4C28E4D401D7233DC802747408A03E8F7FD8D4D40D107CBD8D02347408A03E8F7FD8D4D40
29846	Фурово	1	7	1877	46.148971000000003	46.180807999999999	59.111767	59.096147999999999	0103000020E61000000100000005000000B686527B11134740B4C9E1934E8C4D40B686527B11134740D2E28C614E8E4D40766D6FB724174740D2E28C614E8E4D40766D6FB724174740B4C9E1934E8C4D40B686527B11134740B4C9E1934E8C4D40
29822	Павино	1	7	1877	46.114646999999998	46.194929000000002	59.128787000000003	59.093088000000002	0103000020E61000000100000005000000D1CABDC0AC0E474035D3BD4EEA8B4D40D1CABDC0AC0E47403293A8177C904D406005F86EF31847403293A8177C904D406005F86EF318474035D3BD4EEA8B4D40D1CABDC0AC0E474035D3BD4EEA8B4D40
30173	Медведица	1	7	1877	45.939475000000002	45.963307999999998	59.139045000000003	59.130721000000001	0103000020E610000001000000050000006E3480B740F8464041F33977BB904D406E3480B740F846400FD6FF39CC914D40D2FC31AD4DFB46400FD6FF39CC914D40D2FC31AD4DFB464041F33977BB904D406E3480B740F8464041F33977BB904D40
30246	Леденгск	1	7	1877	45.967205999999997	45.989421999999998	58.941778999999997	58.925080000000001	0103000020E610000001000000050000005B3FFD67CDFB464083177D0569764D405B3FFD67CDFB4640A087DA368C784D40B1F84D61A5FE4640A087DA368C784D40B1F84D61A5FE464083177D0569764D405B3FFD67CDFB464083177D0569764D40
29928	Карпово	1	7	1877	46.431356999999998	46.449440000000003	59.115355999999998	59.106226999999997	0103000020E6100000010000000500000049F3C7B436374740E179A9D8988D4D4049F3C7B436374740DDB243FCC38E4D40D3C1FA3F87394740DDB243FCC38E4D40D3C1FA3F87394740E179A9D8988D4D4049F3C7B436374740E179A9D8988D4D40
30274	Доброумово	1	7	1877	46.239458999999997	46.264727999999998	59.192919000000003	59.183579999999999	0103000020E61000000100000005000000CEDDAE97A61E47408F19A88C7F974D40CEDDAE97A61E474076E3DD91B1984D40F12A6B9BE221474076E3DD91B1984D40F12A6B9BE22147408F19A88C7F974D40CEDDAE97A61E47408F19A88C7F974D40
29912	Березовка	1	7	1877	46.349269	46.360812000000003	59.118907999999998	59.112265999999998	0103000020E61000000100000005000000D940BAD8B42C4740F33977BB5E8E4D40D940BAD8B42C4740CB9D9960388F4D408F006E162F2E4740CB9D9960388F4D408F006E162F2E4740F33977BB5E8E4D40D940BAD8B42C4740F33977BB5E8E4D40
29706	Юрьево	1	7	1847	42.106112000000003	42.123683999999997	57.884205000000001	57.877668999999997	0103000020E6100000010000000500000049DBF813950D454044DB317557F04C4049DBF813950D4540D7FA22A12DF14C40EC8497E0D40F4540D7FA22A12DF14C40EC8497E0D40F454044DB317557F04C4049DBF813950D454044DB317557F04C40
53312	Щелыково	1	7	1847	42.159032000000003	42.178975000000001	57.611626000000001	57.603338000000001	0103000020E610000001000000050000003D821B295B1445408F37F92D3ACD4C403D821B295B14454010B1C1C249CE4C409BE61DA7E816454010B1C1C249CE4C409BE61DA7E81645408F37F92D3ACD4C403D821B295B1445408F37F92D3ACD4C40
52247	Хомутово	1	7	1847	42.258521000000002	42.279110000000003	57.888171999999997	57.872748999999999	0103000020E61000000100000005000000242A543717214540F04E3E3DB6EF4C40242A543717214540889CBE9EAFF14C4048FE60E0B9234540889CBE9EAFF14C4048FE60E0B9234540F04E3E3DB6EF4C40242A543717214540F04E3E3DB6EF4C40
53354	Парфеньево	1	7	1847	42.254441999999997	42.263021000000002	57.817245999999997	57.813574000000003	0103000020E610000001000000050000004A5D328E912045401E705D3123E84C404A5D328E91204540B66455849BE84C40A39410ACAA214540B66455849BE84C40A39410ACAA2145401E705D3123E84C404A5D328E912045401E705D3123E84C40
28678	Островское	1	7	1847	42.223692999999997	42.264781999999997	57.818981999999998	57.775579	0103000020E610000001000000050000000CACE3F8A11C4540713B342C46E34C400CACE3F8A11C45409F01F566D4E84C40E4486760E42145409F01F566D4E84C40E4486760E4214540713B342C46E34C400CACE3F8A11C4540713B342C46E34C40
53316	Марково	1	7	1847	42.124833000000002	42.136888999999996	57.622511000000003	57.610126999999999	0103000020E61000000100000005000000153B1A87FA0F45400BB43BA418CE4C40153B1A87FA0F45403C33C170AECF4C4050172994851145403C33C170AECF4C4050172994851145400BB43BA418CE4C40153B1A87FA0F45400BB43BA418CE4C40
53336	Малое Березово	1	7	1847	42.244615000000003	42.254308000000002	57.717061000000001	57.707354000000002	0103000020E61000000100000005000000378E588B4F1F4540EF586C938ADA4C40378E588B4F1F4540581EA4A7C8DB4C403B8E1F2A8D204540581EA4A7C8DB4C403B8E1F2A8D204540EF586C938ADA4C40378E588B4F1F4540EF586C938ADA4C40
53350	Ломки	1	7	1847	42.543511000000002	42.577620000000003	57.955599999999997	57.943216	0103000020E610000001000000050000001502B9C4914545402F88484DBBF84C401502B9C4914545405F07CE1951FA4C40FDC1C073EF4945405F07CE1951FA4C40FDC1C073EF4945402F88484DBBF84C401502B9C4914545402F88484DBBF84C40
28589	Красная Поляна	1	7	1847	42.145997999999999	42.178731999999997	57.877716999999997	57.865031999999999	0103000020E6100000010000000500000005A4FD0FB01245402AFF5A5EB9EE4C4005A4FD0FB01245405512D90759F04C40D45FAFB0E01645405512D90759F04C40D45FAFB0E01645402AFF5A5EB9EE4C4005A4FD0FB01245402AFF5A5EB9EE4C40
53369	Козловка	1	7	1847	42.349806999999998	42.364576	57.815323999999997	57.805087	0103000020E61000000100000005000000B874CC79C62C4540A6B73F170DE74C40B874CC79C62C45406BD26D895CE84C400874266DAA2E45406BD26D895CE84C400874266DAA2E4540A6B73F170DE74C40B874CC79C62C4540A6B73F170DE74C40
53359	Климово	1	7	1847	42.245404999999998	42.265635000000003	57.981425000000002	57.966743999999998	0103000020E610000001000000050000002FA3586E691F454057CD7344BEFB4C402FA3586E691F4540083D9B559FFD4C4024D6E25300224540083D9B559FFD4C4024D6E2530022454057CD7344BEFB4C402FA3586E691F454057CD7344BEFB4C40
53342	Клеванцово	1	7	1847	41.765894000000003	42.790593000000001	58.157598999999998	57.555652000000002	0103000020E61000000100000005000000F01989D008E244407FFACF9A1FC74C40F01989D008E24440EF703B342C144D4028B9C32632654540EF703B342C144D4028B9C326326545407FFACF9A1FC74C40F01989D008E244407FFACF9A1FC74C40
29128	Игодово	1	7	1847	42.338965000000002	42.370756	58.020600000000002	58.007669999999997	0103000020E610000001000000050000008CBE8234632B454085949F54FB004D408CBE8234632B454018265305A3024D40DC65BFEE742F454018265305A3024D40DC65BFEE742F454085949F54FB004D408CBE8234632B454085949F54FB004D40
29029	Ивашево	1	7	1847	42.207928000000003	42.225695999999999	57.649655000000003	57.633887999999999	0103000020E610000001000000050000001BF67B629D1A4540D6A9F23D23D14C401BF67B629D1A4540695721E527D34C40446B459BE31C4540695721E527D34C40446B459BE31C4540D6A9F23D23D14C401BF67B629D1A4540D6A9F23D23D14C40
28964	Заборье	1	7	1847	42.407972999999998	42.426397999999999	57.694935999999998	57.678958999999999	0103000020E6100000010000000500000054539275383445409529E620E8D64C4054539275383445401268B0A9F3D84C40378AAC35943645401268B0A9F3D84C40378AAC35943645409529E620E8D64C4054539275383445409529E620E8D64C40
29204	Дымница	1	7	1847	42.674027000000002	42.718395000000001	57.818722999999999	57.803221999999998	0103000020E610000001000000050000007DCF488446564540BFB67EFACFE64C407DCF488446564540D3BD4EEACBE84C40124E0B5EF45B4540D3BD4EEACBE84C40124E0B5EF45B4540BFB67EFACFE64C407DCF488446564540BFB67EFACFE64C40
53363	Дубяны	1	7	1847	42.332155999999998	42.355277999999998	58.081879000000001	58.071646999999999	0103000020E61000000100000005000000C8957A16842A4540A2ED98BA2B094D40C8957A16842A4540569DD5027B0A4D40807EDFBF792D4540569DD5027B0A4D40807EDFBF792D4540A2ED98BA2B094D40C8957A16842A4540A2ED98BA2B094D40
28528	Гуляевка	1	7	1847	42.168393000000002	42.201737999999999	57.828173999999997	57.815308999999999	0103000020E610000001000000050000000BF0DDE68D1545403691990B5CE84C400BF0DDE68D154540E1B20A9B01EA4C40232E008DD2194540E1B20A9B01EA4C40232E008DD21945403691990B5CE84C400BF0DDE68D1545403691990B5CE84C40
53346	Воскресенское	1	7	1847	42.414720000000003	42.444291999999997	57.783251999999997	57.772492	0103000020E61000000100000005000000A27F828B15354540F8359204E1E24C40A27F828B153545406743FE9941E44C40EDEF6C8FDE3845406743FE9941E44C40EDEF6C8FDE384540F8359204E1E24C40A27F828B15354540F8359204E1E24C40
53366	Александровское	1	7	1847	42.308844000000001	42.333331999999999	57.678102000000003	57.667340000000003	0103000020E610000001000000050000006DC83F338827454005A8A9656BD54C406DC83F338827454015ADDC0BCCD64C40EA5A7B9FAA2A454015ADDC0BCCD64C40EA5A7B9FAA2A454005A8A9656BD54C406DC83F338827454005A8A9656BD54C40
28815	Адищево	1	7	1847	42.123027999999998	42.156157999999998	57.671233999999998	57.655535	0103000020E61000000100000005000000033FAA61BF0F454012312592E8D34C40033FAA61BF0F45404CFBE6FEEAD54C401F813FFCFC1345404CFBE6FEEAD54C401F813FFCFC13454012312592E8D34C40033FAA61BF0F454012312592E8D34C40
28255	Соловецкое	1	7	630	47.275629000000002	47.301231000000001	59.067960999999997	59.056316000000002	0103000020E61000000100000005000000236AA2CF47A34740EB1ED95C35874D40236AA2CF47A34740A43330F2B2884D404CC5C6BC8EA64740A43330F2B2884D404CC5C6BC8EA64740EB1ED95C35874D40236AA2CF47A34740EB1ED95C35874D40
28126	Луптюг	1	7	630	47.103763999999998	47.142966000000001	58.810887000000001	58.795265999999998	0103000020E6100000010000000500000046408523488D474074CFBA46CB654D4046408523488D474033E02C25CB674D405038BBB54C92474033E02C25CB674D405038BBB54C92474074CFBA46CB654D4046408523488D474074CFBA46CB654D40
28165	Лебеди	1	7	630	47.229554999999998	47.251401999999999	58.891252000000001	58.881756000000003	0103000020E610000001000000050000000FD1E80E629D4740A1866F61DD704D400FD1E80E629D47404F3FA88B14724D401213D4F02DA047404F3FA88B14724D401213D4F02DA04740A1866F61DD704D400FD1E80E629D4740A1866F61DD704D40
28225	Кузьмины	1	7	630	47.097655000000003	47.109350999999997	58.901674	58.893604000000003	0103000020E610000001000000050000003CA583F57F8C474093C9A99D61724D403CA583F57F8C4740A6D3BA0D6A734D407764AC36FF8D4740A6D3BA0D6A734D407764AC36FF8D474093C9A99D61724D403CA583F57F8C474093C9A99D61724D40
28399	Ильинское	1	7	630	47.374372000000001	47.387873999999996	58.938491999999997	58.932014000000002	0103000020E61000000100000005000000E144F46BEBAF474003B5183C4C774D40E144F46BEBAF474060C77F8120784D40FE7BF0DAA5B1474060C77F8120784D40FE7BF0DAA5B1474003B5183C4C774D40E144F46BEBAF474003B5183C4C774D40
28485	Забегаево	1	7	630	46.945804000000003	46.973624999999998	58.881328000000003	58.868442000000002	0103000020E610000001000000050000008736001B10794740863C821B296F4D408736001B1079474049861C5BCF704D40B4C876BE9F7C474049861C5BCF704D40B4C876BE9F7C4740863C821B296F4D408736001B10794740863C821B296F4D40
28437	Веденье	1	7	630	46.880946000000002	46.899298000000002	58.809759	58.802241000000002	0103000020E6100000010000000500000061C5A9D6C2704740534145D5AF664D4061C5A9D6C27047402252D32EA6674D40DAAD65321C7347402252D32EA6674D40DAAD65321C734740534145D5AF664D4061C5A9D6C2704740534145D5AF664D40
28340	Боговарово	1	7	630	46.999828999999998	47.040460000000003	58.985973000000001	58.967253999999997	0103000020E61000000100000005000000D34B8C65FA7F47406C76A4FACE7B4D40D34B8C65FA7F474098DEFE5C347E4D40E96514CB2D85474098DEFE5C347E4D40E96514CB2D8547406C76A4FACE7B4D40D34B8C65FA7F47406C76A4FACE7B4D40
28308	Андреево	1	7	630	46.982850999999997	46.995409000000002	58.995055999999998	58.986252	0103000020E61000000100000005000000A2EBC20FCE7D4740ABCE6A813D7E4D40A2EBC20FCE7D474023D8B8FE5D7F4D407192E68F697F474023D8B8FE5D7F4D407192E68F697F4740ABCE6A813D7E4D40A2EBC20FCE7D4740ABCE6A813D7E4D40
53335	Нея	1	7	7283	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
27993	Якушовка	1	7	690	40.605764000000001	40.620964000000001	57.485947000000003	57.482081000000001	0103000020E610000001000000050000000D8CBCAC894D4440F18288D4B4BD4C400D8CBCAC894D44406F4BE48233BE4C4026FF93BF7B4F44406F4BE48233BE4C4026FF93BF7B4F4440F18288D4B4BD4C400D8CBCAC894D4440F18288D4B4BD4C40
28037	Хомутово	1	7	690	40.820542000000003	40.836846999999999	57.470641000000001	57.466667999999999	0103000020E610000001000000050000004A7F2F85076944407C0BEBC6BBBB4C404A7F2F85076944401094DBF63DBC4C40BB6070CD1D6B44401094DBF63DBC4C40BB6070CD1D6B44407C0BEBC6BBBB4C404A7F2F85076944407C0BEBC6BBBB4C40
27901	Федоровское	1	7	690	40.551192	40.573146000000001	57.419127000000003	57.410711999999997	0103000020E610000001000000050000008EE89E758D4644409109F83592B44C408EE89E758D46444070EF1AF4A5B54C40A7EA1ED95C49444070EF1AF4A5B54C40A7EA1ED95C4944409109F83592B44C408EE89E758D4644409109F83592B44C40
27969	Тетеринское	1	7	690	40.578330000000001	40.603689000000003	57.508011000000003	57.498503999999997	0103000020E61000000100000005000000D925AAB7064A44406C76A4FACEBF4C40D925AAB7064A44400F81238106C14C403CFA5FAE454D44400F81238106C14C403CFA5FAE454D44406C76A4FACEBF4C40D925AAB7064A44406C76A4FACEBF4C40
4826	Татарское	1	7	690	40.888993999999997	40.910679000000002	57.519415000000002	57.510491000000002	0103000020E610000001000000050000008C2B2E8ECA71444080F3E2C457C14C408C2B2E8ECA714440A306D3307CC24C40B613252191744440A306D3307CC24C40B61325219174444080F3E2C457C14C408C2B2E8ECA71444080F3E2C457C14C40
27333	Спас	1	7	690	41.015566999999997	41.038896000000001	57.457625	57.447746000000002	0103000020E61000000100000005000000CBF27519FE8144401975ADBD4FB94C40CBF27519FE8144407F6ABC7493BA4C40FDF84B8BFA8444407F6ABC7493BA4C40FDF84B8BFA8444401975ADBD4FB94C40CBF27519FE8144401975ADBD4FB94C40
28077	Рудино	1	7	690	40.892938000000001	40.919716000000001	57.451222999999999	57.44314	0103000020E6100000010000000500000086ADD9CA4B72444054C6BFCFB8B84C4086ADD9CA4B724440FC19DEACC1B94C40D1CDFE40B9754440FC19DEACC1B94C40D1CDFE40B975444054C6BFCFB8B84C4086ADD9CA4B72444054C6BFCFB8B84C40
27785	Марьинское	1	7	690	40.707614999999997	40.720289999999999	57.480750999999998	57.476444000000001	0103000020E610000001000000050000005B94D920935A44400E30F31DFCBC4C405B94D920935A44407842AF3F89BD4C4063D17476325C44407842AF3F89BD4C4063D17476325C44400E30F31DFCBC4C405B94D920935A44400E30F31DFCBC4C40
27725	Лужки	1	7	690	40.728223	40.747526999999998	57.369554999999998	57.361899999999999	0103000020E61000000100000005000000F6984869365D444011363CBD52AE4C40F6984869365D4440618907944DAF4C4041F0F8F6AE5F4440618907944DAF4C4041F0F8F6AE5F444011363CBD52AE4C40F6984869365D444011363CBD52AE4C40
27611	Лаврово	1	7	690	40.521278000000002	40.573272000000003	57.489193	57.463690999999997	0103000020E61000000100000005000000E90FCD3CB94244408A39083A5ABB4C40E90FCD3CB9424440503750E09DBE4C4034DB15FA60494440503750E09DBE4C4034DB15FA604944408A39083A5ABB4C40E90FCD3CB94244408A39083A5ABB4C40
26691	Космынино	1	7	690	40.750689000000001	40.791831999999999	57.601182000000001	57.571525000000001	0103000020E61000000100000005000000C53BC0931660444057EC2FBB27C94C40C53BC09316604440D1782288F3CC4C4090F63FC05A654440D1782288F3CC4C4090F63FC05A65444057EC2FBB27C94C40C53BC0931660444057EC2FBB27C94C40
27536	Клементьево	1	7	690	40.816761	40.834699999999998	57.347630000000002	57.340646	0103000020E61000000100000005000000FAD2DB9F8B684440B1C1C2499AAB4C40FAD2DB9F8B684440E38DCC237FAC4C4050FC1873D76A4440E38DCC237FAC4C4050FC1873D76A4440B1C1C2499AAB4C40FAD2DB9F8B684440B1C1C2499AAB4C40
27700	Иголкино	1	7	690	40.513013000000001	40.528095999999998	57.444127999999999	57.441071999999998	0103000020E6100000010000000500000020B6F468AA41444035971B0C75B84C4020B6F468AA414440739EB12FD9B84C40FF9254A698434440739EB12FD9B84C40FF9254A69843444035971B0C75B84C4020B6F468AA41444035971B0C75B84C40
27499	Емсна	1	7	690	40.710723000000002	40.731105999999997	57.403900999999998	57.395623000000001	0103000020E61000000100000005000000ECC1A4F8F85A4440D04543C6A3B24C40ECC1A4F8F85A44402DE92807B3B34C4066F4A3E1945D44402DE92807B3B34C4066F4A3E1945D4440D04543C6A3B24C40ECC1A4F8F85A4440D04543C6A3B24C40
27445	Григорцево	1	7	690	40.46631	40.477997000000002	57.375509000000001	57.366554999999998	0103000020E610000001000000050000001DE6CB0BB03B4440B7973446EBAE4C401DE6CB0BB03B4440452DCDAD10B04C40064B75012F3D4440452DCDAD10B04C40064B75012F3D4440B7973446EBAE4C401DE6CB0BB03B4440B7973446EBAE4C40
27310	Владычное	1	7	690	41.056476000000004	41.073104000000001	57.439250999999999	57.428640000000001	0103000020E610000001000000050000002481069B3A874440F4E0EEACDDB64C402481069B3A8744401EDE736039B84C40789ACC785B8944401EDE736039B84C40789ACC785B894440F4E0EEACDDB64C402481069B3A874440F4E0EEACDDB64C40
27399	Бабаево	1	7	690	40.705647999999997	40.720343999999997	57.546838999999999	57.540380999999996	0103000020E61000000100000005000000703E75AC525A44409C3061342BC54C40703E75AC525A4440B39602D2FEC54C4056EF703B345C4440B39602D2FEC54C4056EF703B345C44409C3061342BC54C40703E75AC525A44409C3061342BC54C40
27247	Арменки	1	7	690	40.923507000000001	40.945804000000003	57.364784	57.355739	0103000020E610000001000000050000004450357A35764440B47405DB88AD4C404450357A35764440520DFB3DB1AE4C408736001B10794440520DFB3DB1AE4C408736001B10794440B47405DB88AD4C404450357A35764440B47405DB88AD4C40
26230	Солтаново	1	7	679	43.761519	43.776206000000002	58.187041000000001	58.180213000000002	0103000020E610000001000000050000002D24607479E1454033A8363811174D402D24607479E145406D01A1F5F0174D40C07ADCB75AE345406D01A1F5F0174D40C07ADCB75AE3454033A8363811174D402D24607479E1454033A8363811174D40
26152	Номжа	1	7	679	43.564535999999997	43.599677999999997	58.313113999999999	58.299326000000001	0103000020E6100000010000000500000013B534B742C84540D76B7A5050264D4013B534B742C84540BAF59A1E14284D40BA10AB3FC2CC4540BAF59A1E14284D40BA10AB3FC2CC4540D76B7A5050264D4013B534B742C84540D76B7A5050264D40
26129	Михали	1	7	679	44.022883999999998	44.041981999999997	58.389015999999998	58.380023999999999	0103000020E6100000010000000500000003CDE7DCED024640F9D85DA0A4304D4003CDE7DCED02464074CFBA46CB314D40A5828AAA5F05464074CFBA46CB314D40A5828AAA5F054640F9D85DA0A4304D4003CDE7DCED024640F9D85DA0A4304D40
26061	Кужбал	1	7	679	44.121501000000002	44.131417999999996	58.438544999999998	58.431713999999999	0103000020E6100000010000000500000035B742588D0F4640D89C836742374D4035B742588D0F46408369183E22384D40880D164ED21046408369183E22384D40880D164ED2104640D89C836742374D4035B742588D0F4640D89C836742374D40
26299	Коткишево	1	7	679	43.760342000000001	43.771248	58.262996000000001	58.257252999999999	0103000020E610000001000000050000003BE3FBE252E1454021E692AAED204D403BE3FBE252E145404A7D59DAA9214D407E8D2441B8E245404A7D59DAA9214D407E8D2441B8E2454021E692AAED204D403BE3FBE252E1454021E692AAED204D40
25897	Еленский	1	7	679	43.728892000000002	43.750757	58.311346	58.294280000000001	0103000020E61000000100000005000000742843554CDD4540F6EE8FF7AA254D40742843554CDD4540C6DE8B2FDA274D401D1F2DCE18E04540C6DE8B2FDA274D401D1F2DCE18E04540F6EE8FF7AA254D40742843554CDD4540F6EE8FF7AA254D40
26207	Дьяконово	1	7	679	43.702697000000001	43.719315999999999	58.068534	58.063972999999997	0103000020E61000000100000005000000A8FFACF9F1D94540DB696B4430084D40A8FFACF9F1D945400055DCB8C5084D40A9BEF38B12DC45400055DCB8C5084D40A9BEF38B12DC4540DB696B4430084D40A8FFACF9F1D94540DB696B4430084D40
25994	Вожерово	1	7	679	44.033520000000003	44.047559999999997	58.641869	58.634694000000003	0103000020E6100000010000000500000087E123624A044640D57B2AA73D514D4087E123624A0446407AA86DC328524D40834C3272160646407AA86DC328524D40834C327216064640D57B2AA73D514D4087E123624A044640D57B2AA73D514D40
26091	Абросимово	1	7	679	44.104379000000002	44.128526000000001	58.320739000000003	58.311024000000003	0103000020E61000000100000005000000D1B1834A5C0D4640B4226AA2CF274D40D1B1834A5C0D4640A0C6BDF90D294D40C5573B8A73104640A0C6BDF90D294D40C5573B8A73104640B4226AA2CF274D40D1B1834A5C0D4640B4226AA2CF274D40
10416	Центральный	1	7	710	45.062278999999997	45.075412999999998	59.020972999999998	59.011842000000001	0103000020E61000000100000005000000211D1EC2F8874640105CE50984814D40211D1EC2F8874640AC8C463EAF824D40BC581822A7894640AC8C463EAF824D40BC581822A7894640105CE50984814D40211D1EC2F8874640105CE50984814D40
10471	Средняя	1	7	710	44.956763000000002	44.985607999999999	58.820202000000002	58.808449000000003	0103000020E61000000100000005000000ED82C135777A4640F1BDBF417B674D40ED82C135777A4640910E0F61FC684D4086562767287E4640910E0F61FC684D4086562767287E4640F1BDBF417B674D40ED82C135777A4640F1BDBF417B674D40
10377	Петушиха	1	7	710	45.072017000000002	45.082788000000001	58.542738999999997	58.536091999999996	0103000020E61000000100000005000000C6E061DA37894640D8D2A3A99E444D40C6E061DA37894640C2A1B77878454D40294014CC988A4640C2A1B77878454D40294014CC988A4640D8D2A3A99E444D40C6E061DA37894640D8D2A3A99E444D40
10314	Первомайский	1	7	710	44.986685999999999	45.003124999999997	58.780631999999997	58.772098999999997	0103000020E61000000100000005000000E5B512BA4B7E46401C23D923D4624D40E5B512BA4B7E4640041BD7BFEB634D406666666666804640041BD7BFEB634D4066666666668046401C23D923D4624D40E5B512BA4B7E46401C23D923D4624D40
10270	Никола	1	7	710	44.906539000000002	44.941868999999997	58.869470999999997	58.85868	0103000020E6100000010000000500000037C64E780974464059DDEA39E96D4D4037C64E780974464003E962D34A6F4D40E00ED4298F78464003E962D34A6F4D40E00ED4298F78464059DDEA39E96D4D4037C64E780974464059DDEA39E96D4D40
10231	Козлиха	1	7	710	45.049649000000002	45.069339999999997	58.773237999999999	58.765062999999998	0103000020E61000000100000005000000BAA3FFE55A86464098309A95ED614D40BAA3FFE55A86464021037976F9624D40FE261422E088464021037976F9624D40FE261422E088464098309A95ED614D40BAA3FFE55A86464098309A95ED614D40
10179	Георгиевское	1	7	710	45.010168	45.055641000000001	58.744183	58.723281	0103000020E610000001000000050000009DBB5D2F4D814640BA68C878945C4D409DBB5D2F4D8146409D9E7763415F4D408BA8893E1F8746409D9E7763415F4D408BA8893E1F874640BA68C878945C4D409DBB5D2F4D814640BA68C878945C4D40
23927	Угоры	1	7	605	44.349798999999997	44.382677000000001	58.143475000000002	58.124845000000001	0103000020E610000001000000050000003596B036C62C4640D908C4EBFA0F4D403596B036C62C4640956588635D124D4038F7578FFB304640956588635D124D4038F7578FFB304640D908C4EBFA0F4D403596B036C62C4640D908C4EBFA0F4D40
24350	Самылово	1	7	605	44.652917000000002	44.680692999999998	58.254919000000001	58.240938	0103000020E610000001000000050000005000C5C8925346408C2E6F0ED71E4D405000C5C8925346408410902FA1204D40DDCEBEF2205746408410902FA1204D40DDCEBEF2205746408C2E6F0ED71E4D405000C5C8925346408C2E6F0ED71E4D40
23909	Рогово	1	7	605	44.602691999999998	44.628663000000003	58.377446999999997	58.369188999999999	0103000020E61000000100000005000000C9C7EE02254D46407F85CC95412F4D40C9C7EE02254D4640957CEC2E50304D40469A780778504640957CEC2E50304D40469A7807785046407F85CC95412F4D40C9C7EE02254D46407F85CC95412F4D40
24084	Подвигалиха	1	7	605	44.751283000000001	44.786136999999997	58.459843999999997	58.445798000000003	0103000020E610000001000000050000003885950A2A604640A54FABE80F394D403885950A2A60464083A10E2BDC3A4D4078962023A064464083A10E2BDC3A4D4078962023A0644640A54FABE80F394D403885950A2A604640A54FABE80F394D40
23852	Октябрьский	1	7	605	44.297445000000003	44.359383999999999	58.330337	58.306806999999999	0103000020E61000000100000005000000EBAD81AD122646408997A77345274D40EBAD81AD1226464052D4997B482A4D40535A7F4B002E464052D4997B482A4D40535A7F4B002E46408997A77345274D40EBAD81AD122646408997A77345274D40
53325	Лесобазы	1	7	605	44.806457000000002	44.846082000000003	58.346322999999998	58.341174000000002	0103000020E61000000100000005000000AD50A4FB396746406D1FF296AB2B4D40AD50A4FB39674640226DE34F542C4D40FDDD3B6A4C6C4640226DE34F542C4D40FDDD3B6A4C6C46406D1FF296AB2B4D40AD50A4FB396746406D1FF296AB2B4D40
23792	Леонтьево	1	7	605	44.491328000000003	44.509338999999997	58.177323000000001	58.170104000000002	0103000020E61000000100000005000000F7CDFDD5E33E46409B75C6F7C5154D40F7CDFDD5E33E464010EA2285B2164D40E6C935053241464010EA2285B2164D40E6C93505324146409B75C6F7C5154D40F7CDFDD5E33E46409B75C6F7C5154D40
24391	Карьково	1	7	605	44.626551999999997	44.642712000000003	58.209896000000001	58.197695000000003	0103000020E61000000100000005000000279F1EDB3250464097CADB114E194D40279F1EDB32504640D6C743DFDD1A4D40965F066344524640D6C743DFDD1A4D40965F06634452464097CADB114E194D40279F1EDB3250464097CADB114E194D40
24006	Знаменка	1	7	605	44.836855999999997	44.849217000000003	58.395879000000001	58.383676000000001	0103000020E610000001000000050000000EBBEF181E6B46404B21904B1C314D400EBBEF181E6B46402B16BF29AC324D40871A8524B36C46402B16BF29AC324D40871A8524B36C46404B21904B1C314D400EBBEF181E6B46404B21904B1C314D40
24286	Ефимово	1	7	605	44.732427000000001	44.755738000000001	58.315123	58.296653999999997	0103000020E610000001000000050000008CDAFD2AC05D4640211D1EC2F8254D408CDAFD2AC05D4640D49B51F355284D40172CD505BC604640D49B51F355284D40172CD505BC604640211D1EC2F8254D408CDAFD2AC05D4640211D1EC2F8254D40
33159	Елизарово	1	7	605	44.808154999999999	44.824945	58.543199000000001	58.534570000000002	0103000020E61000000100000005000000A88C7F9F716746401CB62DCA6C444D40A88C7F9F71674640261C7A8B87454D40D6FF39CC97694640261C7A8B87454D40D6FF39CC976946401CB62DCA6C444D40A88C7F9F716746401CB62DCA6C444D40
24149	Гусево	1	7	605	44.698524999999997	44.723579000000001	58.530853999999998	58.517212999999998	0103000020E610000001000000050000001D3867446959464074081C0934424D401D38674469594640B3791C06F3434D404489963C9E5C4640B3791C06F3434D404489963C9E5C464074081C0934424D401D3867446959464074081C0934424D40
53352	Мантурово	1	7	7280	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
23284	Якимово	1	7	1697	43.628793000000002	43.647998999999999	57.852922999999997	57.846989000000001	0103000020E61000000100000005000000147AFD497CD045402F89B3226AEC4C40147AFD497CD04540CB80B3942CED4C409C6B98A1F1D24540CB80B3942CED4C409C6B98A1F1D245402F89B3226AEC4C40147AFD497CD045402F89B3226AEC4C40
23489	Юрово	1	7	1697	43.813485999999997	43.847110000000001	57.514305	57.496676000000001	0103000020E610000001000000050000007EE02A4F20E84540A35A441493BF4C407EE02A4F20E84540AB9509BFD4C14C40AA0EB9196EEC4540AB9509BFD4C14C40AA0EB9196EEC4540A35A441493BF4C407EE02A4F20E84540A35A441493BF4C40
23393	Юркино	1	7	1697	43.681792999999999	43.691198999999997	57.805816	57.788755000000002	0103000020E6100000010000000500000024D236FE44D745403BC780ECF5E44C4024D236FE44D74540F94B8BFA24E74C409203763579D84540F94B8BFA24E74C409203763579D845403BC780ECF5E44C4024D236FE44D745403BC780ECF5E44C40
22963	Шемятино	1	7	1697	44.098269999999999	44.154074000000001	58.082025999999999	58.062497	0103000020E61000000100000005000000C616821C940C46408F8CD5E6FF074D40C616821C940C4640FAB5F5D37F0A4D40FB9463B2B8134640FAB5F5D37F0A4D40FB9463B2B81346408F8CD5E6FF074D40C616821C940C46408F8CD5E6FF074D40
23018	Унжа	1	7	1697	43.998674000000001	44.027079000000001	58.026229000000001	58.0122	0103000020E61000000100000005000000C9AEB48CD4FF45406F8104C58F014D40C9AEB48CD4FF4540789ACC785B034D4046B41D5377034640789ACC785B034D4046B41D53770346406F8104C58F014D40C9AEB48CD4FF45406F8104C58F014D40
23046	Тимошино	1	7	1697	44.397688000000002	44.443134000000001	57.842644	57.823089000000003	0103000020E610000001000000050000007E01BD70E73246404359F8FA5AE94C407E01BD70E7324640D71533C2DBEB4C4072DF6A9DB8384640D71533C2DBEB4C4072DF6A9DB83846404359F8FA5AE94C407E01BD70E73246404359F8FA5AE94C40
23217	Стариково	1	7	1697	43.642761999999998	43.651896999999998	57.987026999999998	57.981631	0103000020E61000000100000005000000478E740646D24540B1DEA815A6FD4C40478E740646D245406EA296E656FE4C4025AE635C71D345406EA296E656FE4C4025AE635C71D34540B1DEA815A6FD4C40478E740646D24540B1DEA815A6FD4C40
23704	Соловатово	1	7	1697	43.444746000000002	43.461112999999997	57.585099999999997	57.572529000000003	0103000020E610000001000000050000006F83DA6FEDB845407C8159A148C94C406F83DA6FEDB84540DE718A8EE4CA4C40566133C005BB4540DE718A8EE4CA4C40566133C005BB45407C8159A148C94C406F83DA6FEDB845407C8159A148C94C40
23575	Первомайка	1	7	1697	43.648574000000004	43.679403999999998	57.658034000000001	57.645156	0103000020E6100000010000000500000099840B7904D34540BA68C87894D24C4099840B7904D34540FAD346753AD44C40C362D4B5F6D64540FAD346753AD44C40C362D4B5F6D64540BA68C87894D24C4099840B7904D34540BA68C87894D24C40
22937	Никулино	1	7	1697	44.222453000000002	44.246510000000001	58.097710999999997	58.089744000000003	0103000020E61000000100000005000000D4F20357791C464091813CBB7C0B4D40D4F20357791C4640CFBA46CB810C4D408811C2A38D1F4640CFBA46CB810C4D408811C2A38D1F464091813CBB7C0B4D40D4F20357791C464091813CBB7C0B4D40
23620	Николо-Макарово	1	7	1697	43.549084999999998	43.567860000000003	57.651350000000001	57.635371999999997	0103000020E61000000100000005000000B1DCD26A48C64540A565A4DE53D14C40B1DCD26A48C64540F31FD26F5FD34C40715AF0A2AFC84540F31FD26F5FD34C40715AF0A2AFC84540A565A4DE53D14C40B1DCD26A48C64540A565A4DE53D14C40
23770	Нежитино	1	7	1697	43.28022	43.312522999999999	57.491404000000003	57.466973000000003	0103000020E61000000100000005000000B2D7BB3FDEA34540B98E71C5C5BB4C40B2D7BB3FDEA34540D28F8653E6BE4C40B81FF0C000A84540D28F8653E6BE4C40B81FF0C000A84540B98E71C5C5BB4C40B2D7BB3FDEA34540B98E71C5C5BB4C40
22592	Макарьев	1	7	1697	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
23238	Лопаты	1	7	1697	43.613216000000001	43.633141000000002	57.937764999999999	57.929780999999998	0103000020E6100000010000000500000025B1A4DC7DCE454099B8551003F74C4025B1A4DC7DCE4540AE2AFBAE08F84C40DD60A8C30AD14540AE2AFBAE08F84C40DD60A8C30AD1454099B8551003F74C4025B1A4DC7DCE454099B8551003F74C40
53355	Лопалово	1	7	1697	43.202075000000001	44.879292999999997	58.187595999999999	57.410716999999998	0103000020E610000001000000050000006B2BF697DD994540A374E95F92B44C406B2BF697DD994540226E4E2503184D40054D4BAC8C704640226E4E2503184D40054D4BAC8C704640A374E95F92B44C406B2BF697DD994540A374E95F92B44C40
53320	Комсомолка	1	7	1697	43.202075000000001	44.879292999999997	58.187595999999999	57.410716999999998	0103000020E610000001000000050000006B2BF697DD994540A374E95F92B44C406B2BF697DD994540226E4E2503184D40054D4BAC8C704640226E4E2503184D40054D4BAC8C704640A374E95F92B44C406B2BF697DD994540A374E95F92B44C40
23123	Ильинское	1	7	1697	43.857387000000003	43.872596000000001	57.918888000000003	57.910125000000001	0103000020E61000000100000005000000FE8172DBBEED4540D122DBF97EF44C40FE8172DBBEED4540EB573A1F9EF54C406A4FC939B1EF4540EB573A1F9EF54C406A4FC939B1EF4540D122DBF97EF44C40FE8172DBBEED4540D122DBF97EF44C40
23326	Заречье	1	7	1697	43.700442000000002	43.724741999999999	57.845078000000001	57.830565999999997	0103000020E61000000100000005000000575F5D15A8D94540B39597FC4FEA4C40575F5D15A8D94540D84812842BEC4C40D1048A58C4DC4540D84812842BEC4C40D1048A58C4DC4540B39597FC4FEA4C40575F5D15A8D94540B39597FC4FEA4C40
23409	Ефино	1	7	1697	43.667411000000001	43.680517999999999	57.752333	57.744787000000002	0103000020E61000000100000005000000CEFE40B96DD5454034BE2F2E55DF4C40CEFE40B96DD54540CD599F724CE04C406F2BBD361BD74540CD599F724CE04C406F2BBD361BD7454034BE2F2E55DF4C40CEFE40B96DD5454034BE2F2E55DF4C40
23680	Дорогиня	1	7	1697	43.543686000000001	43.557403999999998	57.599102999999999	57.589770000000001	0103000020E6100000010000000500000083A5BA8097C54540BA1457957DCB4C4083A5BA8097C54540BEF73768AFCC4C406D54A70359C74540BEF73768AFCC4C406D54A70359C74540BA1457957DCB4C4083A5BA8097C54540BA1457957DCB4C40
23511	Горчуха	1	7	1697	43.710161999999997	43.737344999999998	57.714565999999998	57.698403999999996	0103000020E61000000100000005000000546EA296E6DA4540A2B2614D65D94C40546EA296E6DA4540B16A10E676DB4C403F6F2A5261DE4540B16A10E676DB4C403F6F2A5261DE4540A2B2614D65D94C40546EA296E6DA4540A2B2614D65D94C40
22872	Выгорки	1	7	1697	44.255395	44.271295000000002	58.040247000000001	58.031933000000002	0103000020E61000000100000005000000ED478AC8B0204640E3546B6116044D40ED478AC8B02046408D614ED026054D40BF4868CBB92246408D614ED026054D40BF4868CBB9224640E3546B6116044D40ED478AC8B0204640E3546B6116044D40
21744	Шолохово	1	7	1670	41.196846999999998	41.226149999999997	57.558698999999997	57.546756999999999	0103000020E6100000010000000500000069A8514832994440F6ED2422FCC54C4069A851483299444069A7E67283C74C40C5FEB27BF29C444069A7E67283C74C40C5FEB27BF29C4440F6ED2422FCC54C4069A8514832994440F6ED2422FCC54C40
21987	Ченцы	1	7	1670	41.308939000000002	41.322997000000001	57.675272	57.669342999999998	0103000020E61000000100000005000000BFBA2A508BA744403C670B08ADD54C40BFBA2A508BA74440C7F319506FD64C4062DA37F757A94440C7F319506FD64C4062DA37F757A944403C670B08ADD54C40BFBA2A508BA744403C670B08ADD54C40
33158	Харитоново	1	7	1670	41.216788999999999	41.240279999999998	57.628231	57.616909999999997	0103000020E61000000100000005000000F790F0BDBF9B4440A54929E8F6CE4C40F790F0BDBF9B4440ACAA97DF69D04C4002F1BA7EC19E4440ACAA97DF69D04C4002F1BA7EC19E4440A54929E8F6CE4C40F790F0BDBF9B4440A54929E8F6CE4C40
22516	Халипино	1	7	1670	41.167095000000003	41.182501000000002	57.611930000000001	57.600256000000002	0103000020E610000001000000050000009E29745E63954440289D4830D5CC4C409E29745E639544407CB8E4B853CE4C40603E59315C9744407CB8E4B853CE4C40603E59315C974440289D4830D5CC4C409E29745E63954440289D4830D5CC4C40
21574	Сухара	1	7	1670	41.432887999999998	41.444215999999997	57.490673000000001	57.485463000000003	0103000020E61000000100000005000000596ABDDF68B744408335CEA623BE4C40596ABDDF68B74440DE03745FCEBE4C40122EE411DCB84440DE03745FCEBE4C40122EE411DCB844408335CEA623BE4C40596ABDDF68B744408335CEA623BE4C40
21813	Сопырево	1	7	1670	41.338124999999998	41.362881999999999	57.579836	57.572177000000003	0103000020E61000000100000005000000E17A14AE47AB4440FF428F183DC94C40E17A14AE47AB44409085E81038CA4C404E27D9EA72AE44409085E81038CA4C404E27D9EA72AE4440FF428F183DC94C40E17A14AE47AB4440FF428F183DC94C40
22073	Синцово	1	7	1670	41.475386999999998	41.499516	57.695321	57.687244	0103000020E61000000100000005000000C6F8307BD9BC4440A52F849CF7D74C40C6F8307BD9BC44406B9C4D4700D94C4014EAE923F0BF44406B9C4D4700D94C4014EAE923F0BF4440A52F849CF7D74C40C6F8307BD9BC4440A52F849CF7D74C40
22430	Сидоровское	1	7	1670	41.203080999999997	41.236452999999997	57.461230999999998	57.441445000000002	0103000020E6100000010000000500000030B8E68EFE994440CAFD0E4581B84C4030B8E68EFE99444060730E9E09BB4C4042058717449E444060730E9E09BB4C4042058717449E4440CAFD0E4581B84C4030B8E68EFE994440CAFD0E4581B84C40
22403	Светочева Гора	1	7	1670	41.328369000000002	41.347026999999997	57.448549999999997	57.440252999999998	0103000020E610000001000000050000009702D2FE07AA4440A27BD6355AB84C409702D2FE07AA4440764F1E166AB94C401CEA77616BAC4440764F1E166AB94C401CEA77616BAC4440A27BD6355AB84C409702D2FE07AA4440A27BD6355AB84C40
22302	Подольское	1	7	1670	41.321111000000002	41.343488000000001	57.509737000000001	57.491625999999997	0103000020E6100000010000000500000064B14D2A1AA9444080EECB99EDBE4C4064B14D2A1AA94440D447E00F3FC14C40C3482F6AF7AB4440D447E00F3FC14C40C3482F6AF7AB444080EECB99EDBE4C4064B14D2A1AA9444080EECB99EDBE4C40
26611	Красное-на-Волге	1	7	1670	41.212674999999997	41.264713999999998	57.522866	57.503770000000003	0103000020E61000000100000005000000A1D634EF389B44405C5A0D897BC04C40A1D634EF389B44405D18E945EDC24C408C65FA25E2A144405D18E945EDC24C408C65FA25E2A144405C5A0D897BC04C40A1D634EF389B44405C5A0D897BC04C40
22041	Имени Чапаева	1	7	1670	41.369970000000002	41.397108000000003	57.654378999999999	57.639659999999999	0103000020E6100000010000000500000025404D2D5BAF44409947FE60E0D14C4025404D2D5BAF44403718EAB0C2D34C40707D586FD4B244403718EAB0C2D34C40707D586FD4B244409947FE60E0D14C4025404D2D5BAF44409947FE60E0D14C40
22370	Здемирово	1	7	1670	41.275233999999998	41.290675999999998	57.519516000000003	57.511679999999998	0103000020E61000000100000005000000A65F22DE3AA344403602F1BA7EC14C40A65F22DE3AA34440D7DF12807FC24C40B5DD04DF34A54440D7DF12807FC24C40B5DD04DF34A544403602F1BA7EC14C40A65F22DE3AA344403602F1BA7EC14C40
22150	Захарово	1	7	1670	41.448419999999999	41.469448999999997	57.579720000000002	57.570202999999999	0103000020E61000000100000005000000A86F99D365B94440618A7269FCC84C40A86F99D365B94440276BD44334CA4C40E811A3E716BC4440276BD44334CA4C40E811A3E716BC4440618A7269FCC84C40A86F99D365B94440618A7269FCC84C40
22496	Густомесово	1	7	1670	41.116591	41.140360999999999	57.520753999999997	57.499040999999998	0103000020E6100000010000000500000004013274EC8E44407B2E5393E0BF4C4004013274EC8E44406EA12B11A8C24C4022516859F79144406EA12B11A8C24C4022516859F79144407B2E5393E0BF4C4004013274EC8E44407B2E5393E0BF4C40
21927	Гридино	1	7	1670	41.141312999999997	41.165837000000003	57.719949999999997	57.710296999999997	0103000020E61000000100000005000000F4BF5C8B1692444034B91803EBDA4C40F4BF5C8B16924440AA60545227DC4C40BFBB95253A954440AA60545227DC4C40BFBB95253A95444034B91803EBDA4C40F4BF5C8B1692444034B91803EBDA4C40
53356	Гравкарьера	1	7	1670	41.506532	41.544854000000001	57.472726999999999	57.463549999999998	0103000020E610000001000000050000005130630AD6C04440C8073D9B55BB4C405130630AD6C04440D5777E5182BC4C40228C9FC6BDC54440D5777E5182BC4C40228C9FC6BDC54440C8073D9B55BB4C405130630AD6C04440C8073D9B55BB4C40
22224	Веселово	1	7	1670	41.461148999999999	41.482833999999997	57.541482000000002	57.526586999999999	0103000020E61000000100000005000000A3CA30EE06BB4440D7BFEB3367C34C40A3CA30EE06BB4440B4AF3C484FC54C40CCB22781CDBD4440B4AF3C484FC54C40CCB22781CDBD4440D7BFEB3367C34C40A3CA30EE06BB4440D7BFEB3367C34C40
21907	Боровиково	1	7	1670	41.119044000000002	41.152487999999998	57.662058999999999	57.638933000000002	0103000020E610000001000000050000007C6473D53C8F4440E7AA798EC8D14C407C6473D53C8F4440E0826C59BED44C4027840EBA84934440E0826C59BED44C4027840EBA84934440E7AA798EC8D14C407C6473D53C8F4440E7AA798EC8D14C40
22172	Афанасово	1	7	1670	41.548959000000004	41.560054000000001	57.592775000000003	57.589196000000001	0103000020E6100000010000000500000025ECDB4944C644408E7747C66ACB4C4025ECDB4944C6444076711B0DE0CB4C403BFF76D9AFC7444076711B0DE0CB4C403BFF76D9AFC744408E7747C66ACB4C4025ECDB4944C644408E7747C66ACB4C40
53331	п.Паточного завода	1	7	197	40.603842	41.763979999999997	58.637991	57.536496999999997	0103000020E61000000100000005000000C2F9D4B14A4D444078B306EFABC44C40C2F9D4B14A4D4440381268B0A9514D402766BD18CAE14440381268B0A9514D402766BD18CAE1444078B306EFABC44C40C2F9D4B14A4D444078B306EFABC44C40
15276	Яковлевское	1	7	197	40.823309000000002	40.836883	57.822543000000003	57.815559	0103000020E6100000010000000500000051C0763062694440AF7AC03C64E84C4051C0763062694440E146CA1649E94C4008CA6DFB1E6B4440E146CA1649E94C4008CA6DFB1E6B4440AF7AC03C64E84C4051C0763062694440AF7AC03C64E84C40
16140	Щетниково	1	7	197	41.029831999999999	41.042624000000004	57.804161999999998	57.797542999999997	0103000020E61000000100000005000000E82FF488D1834440AD1397E315E64C40E82FF488D1834440CD57C9C7EEE64C402A0307B474854440CD57C9C7EEE64C402A0307B474854440AD1397E315E64C40E82FF488D1834440AD1397E315E64C40
16837	Шунга	1	7	197	40.794285000000002	40.830649000000001	57.815981000000001	57.803950999999998	0103000020E61000000100000005000000085A8121AB654440124BCADDE7E64C40085A8121AB6544402594BE1072E84C4041BAD8B4526A44402594BE1072E84C4041BAD8B4526A4440124BCADDE7E64C40085A8121AB654440124BCADDE7E64C40
16282	Шувалово	1	7	197	41.023445000000002	41.050808000000004	57.907581	57.896089000000003	0103000020E610000001000000050000009B20EA3E0083444016A75A0BB3F24C409B20EA3E0083444049BC3C9D2BF44C40063065E08086444049BC3C9D2BF44C40063065E08086444016A75A0BB3F24C409B20EA3E0083444016A75A0BB3F24C40
16096	Фанерник	1	7	197	41.024270999999999	41.043225999999997	57.789273000000001	57.784748999999998	0103000020E61000000100000005000000E09EE74F1B834440CB48BDA772E44C40E09EE74F1B834440D34ECDE506E54C401F2BF86D88854440D34ECDE506E54C401F2BF86D88854440CB48BDA772E44C40E09EE74F1B834440CB48BDA772E44C40
16495	Тихий Уголок	1	7	197	41.008578	41.024675999999999	57.654161999999999	57.648802000000003	0103000020E6100000010000000500000088BB7A15198144402ACAA5F10BD34C4088BB7A15198144409A249694BBD34C40807F4A95288344409A249694BBD34C40807F4A95288344402ACAA5F10BD34C4088BB7A15198144402ACAA5F10BD34C40
16164	Сущево	1	7	197	40.940018000000002	40.973174999999998	57.927715999999997	57.917448999999998	0103000020E610000001000000050000005FD3838252784440BB5F05F86EF54C405FD3838252784440EBFCDB65BFF64C40742497FF907C4440EBFCDB65BFF64C40742497FF907C4440BB5F05F86EF54C405FD3838252784440BB5F05F86EF54C40
16757	Сухоногово	1	7	197	41.031816999999997	41.066420000000001	57.601635000000002	57.574266999999999	0103000020E61000000100000005000000793A5794128444400516C09481C94C40793A57941284444082902C6002CD4C4071E657738088444082902C6002CD4C4071E65773808844400516C09481C94C40793A5794128444400516C09481C94C40
16598	Середняя	1	7	197	40.958478999999997	40.974235	57.709532000000003	57.700929000000002	0103000020E610000001000000050000008E739B70AF7A4440B4E89D0AB8D94C408E739B70AF7A444095BBCFF1D1DA4C402DCF83BBB37C444095BBCFF1D1DA4C402DCF83BBB37C4440B4E89D0AB8D94C408E739B70AF7A4440B4E89D0AB8D94C40
16813	Саметь	1	7	197	40.715322999999998	40.734743999999999	57.809080999999999	57.802843000000003	0103000020E61000000100000005000000CE893DB48F5B44404969368FC3E64C40CE893DB48F5B4440516859F78FE74C40537765170C5E4440516859F78FE74C40537765170C5E44404969368FC3E64C40CE893DB48F5B44404969368FC3E64C40
16316	Прибрежный	1	7	197	40.873201999999999	40.886451999999998	57.895820999999998	57.891162000000001	0103000020E61000000100000005000000A1664815C56F44400FB8AE9811F24C40A1664815C56F4440F6083543AAF24C40A5BC564277714440F6083543AAF24C40A5BC5642777144400FB8AE9811F24C40A1664815C56F44400FB8AE9811F24C40
15935	Петрилово	1	7	197	40.645757000000003	40.680889999999998	57.839419999999997	57.826276999999997	0103000020E61000000100000005000000E014562AA8524440EF37DA71C3E94C40E014562AA8524440DDCD531D72EB4C4033164D6727574440DDCD531D72EB4C4033164D6727574440EF37DA71C3E94C40E014562AA8524440EF37DA71C3E94C40
16420	Обломихино	1	7	197	40.814954999999998	40.828429999999997	57.672933	57.666713999999999	0103000020E61000000100000005000000185B08725068444086E464E256D54C40185B08725068444018B325AB22D64C403C8386FE096A444018B325AB22D64C403C8386FE096A444086E464E256D54C40185B08725068444086E464E256D54C40
16028	Никольское	1	7	197	41.090395999999998	41.270606999999998	57.985056999999998	57.796104	0103000020E6100000010000000500000038D89B18928B44407E1B62BCE6E54C4038D89B18928B444012D9075916FE4C40CA880B40A3A2444012D9075916FE4C40CA880B40A3A244407E1B62BCE6E54C4038D89B18928B44407E1B62BCE6E54C40
33157	Мисково	1	7	197	41.054814	41.081341000000002	58.098182000000001	58.086218000000002	0103000020E6100000010000000500000075AE282504874440CC290131090B4D4075AE28250487444027874F3A910C4D407769C361698A444027874F3A910C4D407769C361698A4440CC290131090B4D4075AE282504874440CC290131090B4D40
15825	Минское	1	7	197	41.005290000000002	41.050339999999998	57.703800000000001	57.682384999999996	0103000020E61000000100000005000000787FBC57AD804440F623456458D74C40787FBC57AD80444060764F1E16DA4C401FD7868A7186444060764F1E16DA4C401FD7868A71864440F623456458D74C40787FBC57AD804440F623456458D74C40
15789	Кузьмищи	1	7	197	41.123247999999997	41.155264000000003	57.883688999999997	57.871068999999999	0103000020E6100000010000000500000011A62897C68F44409BC761307FEF4C4011A62897C68F4440DF6A9DB81CF14C40821FD5B0DF934440DF6A9DB81CF14C40821FD5B0DF9344409BC761307FEF4C4011A62897C68F44409BC761307FEF4C40
749	Кузнецово	1	7	197	41.229671000000003	41.266089000000001	57.949831000000003	57.934908	0103000020E6100000010000000500000079EBFCDB659D44406762BA10ABF74C4079EBFCDB659D44400EDDEC0F94F94C40A56950340FA244400EDDEC0F94F94C40A56950340FA244406762BA10ABF74C4079EBFCDB659D44406762BA10ABF74C40
16243	Крутик	1	7	197	40.995668999999999	41.008361999999998	57.975689000000003	57.967618000000002	0103000020E610000001000000050000000D52F014727F4440AE8218E8DAFB4C400D52F014727F444092088D60E3FC4C40BB438A011281444092088D60E3FC4C40BB438A0112814440AE8218E8DAFB4C400D52F014727F4440AE8218E8DAFB4C40
15386	Коряково	1	7	197	40.785660999999998	40.822043000000001	57.744892999999998	57.733919999999998	0103000020E610000001000000050000000F5F268A90644440AEF02E17F1DD4C400F5F268A90644440790261A758DF4C40EF737CB438694440790261A758DF4C40EF737CB438694440AEF02E17F1DD4C400F5F268A90644440AEF02E17F1DD4C40
15521	Караваево	1	7	197	41.041699000000001	41.095768	57.748649	57.726557999999997	0103000020E6100000010000000500000051A3906456854440D65240DAFFDC4C4051A39064568544407097FDBAD3DF4C406D003620428C44407097FDBAD3DF4C406D003620428C4440D65240DAFFDC4C4051A3906456854440D65240DAFFDC4C40
16395	Ильинское	1	7	197	40.914048000000001	40.932949000000001	57.652949	57.645570999999997	0103000020E61000000100000005000000B37C5D86FF7444407D1F0E12A2D24C40B37C5D86FF7444405B7A34D593D34C40FFEA71DF6A7744405B7A34D593D34C40FFEA71DF6A7744407D1F0E12A2D24C40B37C5D86FF7444407D1F0E12A2D24C40
15422	Зарубино	1	7	197	40.724781999999998	40.740233000000003	57.720655999999998	57.715829999999997	0103000020E610000001000000050000005F5D15A8C55C444072BF4351A0DB4C405F5D15A8C55C444045D5AF743EDC4C40C23577F4BF5E444045D5AF743EDC4C40C23577F4BF5E444072BF4351A0DB4C405F5D15A8C55C444072BF4351A0DB4C40
15900	Губачево	1	7	197	41.056072	41.077190999999999	57.782383000000003	57.76943	0103000020E61000000100000005000000541C075E2D874440D847A7AE7CE24C40541C075E2D87444023F94A2025E44C40D4450A65E189444023F94A2025E44C40D4450A65E1894440D847A7AE7CE24C40541C075E2D874440D847A7AE7CE24C40
15652	Василево	1	7	197	41.239291999999999	41.279150000000001	58.024379000000003	58.009977999999997	0103000020E61000000100000005000000E318C91EA19E4440F9D687F546014D40E318C91EA19E4440C7DADFD91E034D40D656EC2FBBA34440C7DADFD91E034D40D656EC2FBBA34440F9D687F546014D40E318C91EA19E4440F9D687F546014D40
15695	Бычиха	1	7	197	41.116402999999998	41.129904000000003	57.955618999999999	57.946302000000003	0103000020E610000001000000050000000114234BE68E4440D811876C20F94C400114234BE68E4440D63730B951FA4C404FCFBBB1A0904440D63730B951FA4C404FCFBBB1A0904440D811876C20F94C400114234BE68E4440D811876C20F94C40
16656	Большая Сандогора	1	7	197	40.940539000000001	40.975645999999998	58.212271000000001	58.179310999999998	0103000020E6100000010000000500000068CEFA94637844401268B0A9F3164D4068CEFA9463784440D27135B22B1B4D40923CD7F7E17C4440D27135B22B1B4D40923CD7F7E17C44401268B0A9F3164D4068CEFA94637844401268B0A9F3164D40
15165	Аферово	1	7	197	40.851075999999999	40.861612999999998	57.805940999999997	57.797677999999998	0103000020E610000001000000050000008B34F10EF06C44408D5E0D501AE64C408B34F10EF06C4440B5C01E1329E74C407B67B455496E4440B5C01E1329E74C407B67B455496E44408D5E0D501AE64C408B34F10EF06C44408D5E0D501AE64C40
15218	Апраксино	1	7	197	40.961928	41.006717999999999	57.845168999999999	57.837485000000001	0103000020E61000000100000005000000A88DEA74207B4440FEF15EB532EB4C40A88DEA74207B4440E84B6F7F2EEC4C40B325AB22DC804440E84B6F7F2EEC4C40B325AB22DC804440FEF15EB532EB4C40A88DEA74207B4440FEF15EB532EB4C40
14885	Ужуга	1	7	1137	44.158906999999999	44.198405999999999	58.948	58.934767999999998	0103000020E61000000100000005000000800D88105714464075AC527AA6774D40800D881057144640D34D621058794D4043AA285E65194640D34D621058794D4043AA285E6519464075AC527AA6774D40800D88105714464075AC527AA6774D40
14855	Суховерхово	1	7	1137	44.260883	44.287806000000003	58.825420000000001	58.808169999999997	0103000020E610000001000000050000008B8A389D64214640DDCD531D72674D408B8A389D642146406FBBD05CA7694D40DACBB6D3D62446406FBBD05CA7694D40DACBB6D3D6244640DDCD531D72674D408B8A389D64214640DDCD531D72674D40
14362	Судилово	1	7	1137	44.328949000000001	44.359411000000001	58.838647999999999	58.828918000000002	0103000020E61000000100000005000000A58636001B2A46406A882AFC196A4D40A58636001B2A46408B6D52D1586B4D404D69FD2D012E46408B6D52D1586B4D404D69FD2D012E46406A882AFC196A4D40A58636001B2A46406A882AFC196A4D40
10537	Советский	1	7	1137	44.581941	44.597563000000001	58.922376	58.912308000000003	0103000020E61000000100000005000000CC99ED0A7D4A464089F02F82C6744D40CC99ED0A7D4A4640C24EB16A10764D405B26C3F17C4C4640C24EB16A10764D405B26C3F17C4C464089F02F82C6744D40CC99ED0A7D4A464089F02F82C6744D40
15128	Октябрьский	1	7	1137	44.024078000000003	44.039358999999997	59.050077999999999	59.042935999999997	0103000020E61000000100000005000000CC46E7FC1403464018E945ED7E854D40CC46E7FC14034640E21FB6F468864D40D1E638B709054640E21FB6F468864D40D1E638B70905464018E945ED7E854D40CC46E7FC1403464018E945ED7E854D40
53360	Овсянниково	1	7	1137	44.098019000000001	44.122013000000003	58.951954999999998	58.945131000000003	0103000020E610000001000000050000007DB1F7E28B0C4640C8B7770DFA784D407DB1F7E28B0C4640C02154A9D9794D40EB573A1F9E0F4640C02154A9D9794D40EB573A1F9E0F4640C8B7770DFA784D407DB1F7E28B0C4640C8B7770DFA784D40
14729	Маракино	1	7	1137	44.527638000000003	44.544625000000003	58.782349000000004	58.775888000000002	0103000020E610000001000000050000003D1059A489434640EFAD484C50634D403D1059A4894346407787140324644D40C1CAA145B64546407787140324644D40C1CAA145B6454640EFAD484C50634D403D1059A489434640EFAD484C50634D40
53358	Лисицино	1	7	1137	43.469889999999999	44.797600000000003	59.266415000000002	58.554098000000003	0103000020E61000000100000005000000D55B035B25BC4540B763EAAEEC464D40D55B035B25BC4540F91400E319A24D4012A5BDC117664640F91400E319A24D4012A5BDC117664640B763EAAEEC464D40D55B035B25BC4540B763EAAEEC464D40
14601	Колохта	1	7	1137	44.076396000000003	44.092179999999999	59.042532999999999	59.036464000000002	0103000020E61000000100000005000000CAC51858C70946409DBD33DAAA844D40CAC51858C70946401900AAB871854D4032ACE28DCC0B46401900AAB871854D4032ACE28DCC0B46409DBD33DAAA844D40CAC51858C70946409DBD33DAAA844D40
14309	Кологрив	1	7	1137	44.293644999999998	44.358035999999998	58.835416000000002	58.806310000000003	0103000020E6100000010000000500000024D1CB28962546400938842A35674D4024D1CB28962546400F4757E9EE6A4D403465A71FD42D46400F4757E9EE6A4D403465A71FD42D46400938842A35674D4024D1CB28962546400938842A35674D40
14532	Ильинское	1	7	1137	44.574297000000001	44.599916999999998	58.772627	58.763294000000002	0103000020E610000001000000050000007098689082494640D49D279EB3614D407098689082494640D8800871E5624D403FA88B14CA4C4640D8800871E5624D403FA88B14CA4C4640D49D279EB3614D407098689082494640D49D279EB3614D40
14802	Даравка	1	7	1137	43.743004999999997	43.770986999999998	59.144986000000003	59.135568999999997	0103000020E61000000100000005000000DAE1AFC91ADF4540FBAC32535A914D40DAE1AFC91ADF45405E30B8E68E924D401152B7B3AFE245405E30B8E68E924D401152B7B3AFE24540FBAC32535A914D40DAE1AFC91ADF4540FBAC32535A914D40
14512	Высоково-Полома	1	7	1137	44.680208	44.702513000000003	58.630721000000001	58.616869999999999	0103000020E61000000100000005000000213D450E1157464017F19D98F54E4D40213D450E1157464041F33977BB504D40E7012CF2EB59464041F33977BB504D40E7012CF2EB59464017F19D98F54E4D40213D450E1157464017F19D98F54E4D40
14466	Воймас	1	7	1137	44.644697999999998	44.658549999999998	58.737200999999999	58.728037	0103000020E61000000100000005000000F7E5CC768552464094A30051305D4D40F7E5CC76855246400CCA349A5C5E4D40F163CC5D4B5446400CCA349A5C5E4D40F163CC5D4B54464094A30051305D4D40F7E5CC768552464094A30051305D4D40
15012	Верхняя Унжа	1	7	1137	44.282138000000003	44.293564000000003	58.844662999999997	58.839272000000001	0103000020E61000000100000005000000BC7A15191D2446406939D0436D6B4D40BC7A15191D2446401492CCEA1D6C4D4038A45181932546401492CCEA1D6C4D4038A45181932546406939D0436D6B4D40BC7A15191D2446406939D0436D6B4D40
14396	Варзенга	1	7	1137	44.166514999999997	44.189602000000001	58.892372000000002	58.878221000000003	0103000020E610000001000000050000008FA50F5D5015464089D4B48B69704D408FA50F5D50154640DDEEE53E39724D40CBA0DAE044184640DDEEE53E39724D40CBA0DAE04418464089D4B48B69704D408FA50F5D5015464089D4B48B69704D40
14276	Большая Чежма	1	7	1137	44.456527000000001	44.482075999999999	58.726331000000002	58.708378000000003	0103000020E61000000100000005000000D95E0B7A6F3A46405B9A5B21AC5A4D40D95E0B7A6F3A46401689096AF85C4D40DF1797AAB43D46401689096AF85C4D40DF1797AAB43D46405B9A5B21AC5A4D40D95E0B7A6F3A46405B9A5B21AC5A4D40
13931	Чернышево	1	7	1272	43.132733999999999	43.153376999999999	57.545983999999997	57.533444000000003	0103000020E610000001000000050000009C887E6DFD904540AC1F9BE447C44C409C887E6DFD904540D311C0CDE2C54C40B37A87DBA1934540D311C0CDE2C54C40B37A87DBA1934540AC1F9BE447C44C409C887E6DFD904540AC1F9BE447C44C40
13896	Текун	1	7	1272	43.172449	43.198571999999999	57.649371000000002	57.630684000000002	0103000020E610000001000000050000002C9D0FCF12964540240ED940BAD04C402C9D0FCF1296454044FCC3961ED34C405EF3AACE6A99454044FCC3961ED34C405EF3AACE6A994540240ED940BAD04C402C9D0FCF12964540240ED940BAD04C40
14181	Столпино	1	7	1272	42.869329999999998	42.897196000000001	57.392194000000003	57.377290000000002	0103000020E6100000010000000500000041B79734466F4540CE8DE9094BB04C4041B79734466F4540FED7B96933B24C400F0D8B51D7724540FED7B96933B24C400F0D8B51D7724540CE8DE9094BB04C4041B79734466F4540CE8DE9094BB04C40
53368	Селище	1	7	1272	43.264355000000002	43.277811999999997	57.812576999999997	57.801437999999997	0103000020E610000001000000050000005DC47762D6A14540C5E2378595E64C405DC47762D6A14540AB3DEC8502E84C40DA37F7578FA34540AB3DEC8502E84C40DA37F7578FA34540C5E2378595E64C405DC47762D6A14540C5E2378595E64C40
13790	Паньково	1	7	1272	43.233426000000001	43.249237000000001	57.725977	57.712335000000003	0103000020E610000001000000050000009F0436E7E09D4540E96514CB2DDB4C409F0436E7E09D4540F85278D0ECDC4C4001FA7DFFE69F4540F85278D0ECDC4C4001FA7DFFE69F4540E96514CB2DDB4C409F0436E7E09D4540E96514CB2DDB4C40
14215	Новый Курдюм	1	7	1272	42.845461999999998	42.863123000000002	57.467660000000002	57.461042999999997	0103000020E6100000010000000500000060014C19386C45405D86FF7403BB4C4060014C19386C4540DDD26A48DCBB4C4074B680D07A6E4540DDD26A48DCBB4C4074B680D07A6E45405D86FF7403BB4C4060014C19386C45405D86FF7403BB4C40
13418	Низкусь	1	7	1272	43.020184	43.040612000000003	58.005830000000003	57.996296000000001	0103000020E6100000010000000500000084F3A963958245405C9198A086FF4C4084F3A96395824540F8AA9509BF004D409FE925C632854540F8AA9509BF004D409FE925C6328545405C9198A086FF4C4084F3A963958245405C9198A086FF4C40
13689	Марьино	1	7	1272	43.317301999999998	43.333120999999998	57.848402	57.840316000000001	0103000020E610000001000000050000004A7A185A9DA845401C2785798FEB4C404A7A185A9DA8454035EECD6F98EC4C402F4E7CB5A3AA454035EECD6F98EC4C402F4E7CB5A3AA45401C2785798FEB4C404A7A185A9DA845401C2785798FEB4C40
14021	Лубяны	1	7	1272	43.174253999999998	43.188662999999998	57.478766999999998	57.467993999999997	0103000020E610000001000000050000003D997FF44D964540B35C363AE7BB4C403D997FF44D964540B7B3AF3C48BD4C408D7BF31B26984540B7B3AF3C48BD4C408D7BF31B26984540B35C363AE7BB4C403D997FF44D964540B35C363AE7BB4C40
13512	Котлово	1	7	1272	42.876130000000003	42.912619999999997	57.814782000000001	57.798876999999997	0103000020E61000000100000005000000B2852007257045406743FE9941E64C40B2852007257045404BAFCDC64AE84C4077D66EBBD07445404BAFCDC64AE84C4077D66EBBD07445406743FE9941E64C40B2852007257045406743FE9941E64C40
13331	Кадый	1	7	1272	43.163052	43.217832000000001	57.795355999999998	57.768239999999999	0103000020E6100000010000000500000011C64FE3DE94454051BD35B055E24C4011C64FE3DE944540B456B439CEE54C40DA0242EBE19B4540B456B439CEE54C40DA0242EBE19B454051BD35B055E24C4011C64FE3DE94454051BD35B055E24C40
13449	Иваньково	1	7	1272	43.181037000000003	43.197619000000003	57.983514999999997	57.974009000000002	0103000020E61000000100000005000000D82E6D382C9745403D81B053ACFC4C40D82E6D382C9745400E10CCD1E3FD4C40BC0853944B9945400E10CCD1E3FD4C40BC0853944B9945403D81B053ACFC4C40D82E6D382C9745403D81B053ACFC4C40
14086	Завражье	1	7	1272	43.138187000000002	43.164569999999998	57.420872000000003	57.403987999999998	0103000020E61000000100000005000000BEDD921CB0914540FCFCF7E0B5B34C40BEDD921CB0914540ACE63922DFB54C408CF337A110954540ACE63922DFB54C408CF337A110954540FCFCF7E0B5B34C40BEDD921CB0914540FCFCF7E0B5B34C40
13554	Екатеринкино	1	7	1272	43.162585	43.185223000000001	57.936064000000002	57.925120999999997	0103000020E61000000100000005000000FBE8D495CF944540E1EB6B5D6AF64C40FBE8D495CF944540427BF5F1D0F74C40C7BB2363B5974540427BF5F1D0F74C40C7BB2363B5974540E1EB6B5D6AF64C40FBE8D495CF944540E1EB6B5D6AF64C40
13735	Дубки	1	7	1272	43.261417999999999	43.271155999999998	57.748821999999997	57.739854000000001	0103000020E61000000100000005000000F94A202576A145404BE82E89B3DE4C40F94A202576A145403D433866D9DF4C409D0E643DB5A245403D433866D9DF4C409D0E643DB5A245404BE82E89B3DE4C40F94A202576A145404BE82E89B3DE4C40
13364	Вешка	1	7	1272	42.987170999999996	43.021613000000002	57.804237999999998	57.792817999999997	0103000020E61000000100000005000000A1478C9E5B7E45400ED76A0F7BE54C40A1478C9E5B7E4540A8195245F1E64C409015FC36C4824540A8195245F1E64C409015FC36C48245400ED76A0F7BE54C40A1478C9E5B7E45400ED76A0F7BE54C40
13264	Ведрово	1	7	1272	42.835822999999998	42.856986999999997	57.522629000000002	57.515242999999998	0103000020E610000001000000050000004F1F813FFC6A4540183F8D7BF3C14C404F1F813FFC6A45407978CF81E5C24C406F0C01C0B16D45407978CF81E5C24C406F0C01C0B16D4540183F8D7BF3C14C404F1F813FFC6A4540183F8D7BF3C14C40
14115	Борисоглебское	1	7	1272	43.038922999999997	43.053206000000003	57.411042000000002	57.398435999999997	0103000020E61000000100000005000000F607CA6DFB84454047C66AF3FFB24C40F607CA6DFB84454027A435069DB44C40BAF94674CF86454027A435069DB44C40BAF94674CF86454047C66AF3FFB24C40F607CA6DFB84454047C66AF3FFB24C40
12225	Челсма	1	7	444	42.260775000000002	42.284005999999998	58.371426	58.365828	0103000020E61000000100000005000000A54E40136121454005FBAF73D32E4D40A54E4013612145402A711DE38A2F4D4013EF004F5A2445402A711DE38A2F4D4013EF004F5A24454005FBAF73D32E4D40A54E40136121454005FBAF73D32E4D40
12575	Унорож	1	7	444	42.077133000000003	42.098010000000002	58.482565999999998	58.468434999999999	0103000020E61000000100000005000000A038807EDF094540A0A696ADF53B4D40A038807EDF094540AD1402B9C43D4D402A5778978B0C4540AD1402B9C43D4D402A5778978B0C4540A0A696ADF53B4D40A038807EDF094540A0A696ADF53B4D40
12164	Углево	1	7	444	42.094506000000003	42.110191	58.186095999999999	58.176952999999997	0103000020E610000001000000050000004DA3C9C5180C4540ECF65965A6164D404DA3C9C5180C45404DF564FED1174D4022A81ABD1A0E45404DF564FED1174D4022A81ABD1A0E4540ECF65965A6164D404DA3C9C5180C4540ECF65965A6164D40
12736	Толтуново	1	7	444	42.297246999999999	42.312994000000003	58.447535999999999	58.436444000000002	0103000020E61000000100000005000000C4EA8F300C2645408944A165DD374D40C4EA8F300C2645402EE411DC48394D4010ECF82F102845402EE411DC48394D4010ECF82F102845408944A165DD374D40C4EA8F300C2645408944A165DD374D40
12615	Степаново	1	7	444	42.499206000000001	42.511566999999999	58.459774000000003	58.450794999999999	0103000020E61000000100000005000000C6FB71FBE53F4540A4198BA6B3394D40C6FB71FBE53F45408BC6DADFD93A4D403E5B07077B4145408BC6DADFD93A4D403E5B07077B414540A4198BA6B3394D40C6FB71FBE53F4540A4198BA6B3394D40
12421	Россолово	1	7	444	41.989052999999998	42.026251999999999	58.449278999999997	58.425221000000001	0103000020E610000001000000050000005E81E84999FE4440454948A46D364D405E81E84999FE4440C9E369F981394D4030BABC395C034540C9E369F981394D4030BABC395C034540454948A46D364D405E81E84999FE4440454948A46D364D40
12070	Пронино	1	7	444	42.177573000000002	42.201801000000003	58.204301000000001	58.192433999999999	0103000020E6100000010000000500000089D349B6BA164540B95164ADA1184D4089D349B6BA16454022C50089261A4D406AA67B9DD419454022C50089261A4D406AA67B9DD4194540B95164ADA1184D4089D349B6BA164540B95164ADA1184D40
12385	Орехово	1	7	444	41.980232000000001	42.007783000000003	58.464725999999999	58.442830999999998	0103000020E61000000100000005000000103FFF3D78FD4440D653ABAFAE384D40103FFF3D78FD4440EACC3D247C3B4D407E3B8908FF004540EACC3D247C3B4D407E3B8908FF004540D653ABAFAE384D40103FFF3D78FD4440D653ABAFAE384D40
12785	Олешь	1	7	444	42.288488000000001	42.303930000000001	58.530135000000001	58.520252999999997	0103000020E61000000100000005000000ECA4BE2CED244540AC527AA697424D40ECA4BE2CED24454084BBB376DB434D40FB22A12DE726454084BBB376DB434D40FB22A12DE7264540AC527AA697424D40ECA4BE2CED244540AC527AA697424D40
12294	Нагатино	1	7	444	42.094487999999998	42.107747000000003	58.394134000000001	58.389449999999997	0103000020E61000000100000005000000A6EECA2E180C4540AEB6627FD9314D40A6EECA2E180C4540EF1EA0FB72324D40FE9E58A7CA0D4540EF1EA0FB72324D40FE9E58A7CA0D4540AEB6627FD9314D40A6EECA2E180C4540AEB6627FD9314D40
11904	Михайловское	1	7	444	42.399448	42.416193	58.381825999999997	58.373204999999999	0103000020E61000000100000005000000EF39B01C2133454012DA722EC52F4D40EF39B01C213345409961A3ACDF304D407DE9EDCF453545409961A3ACDF304D407DE9EDCF4535454012DA722EC52F4D40EF39B01C2133454012DA722EC52F4D40
12148	Митино	1	7	444	42.157685000000001	42.181814000000003	58.152742000000003	58.143721999999997	0103000020E61000000100000005000000EE08A7052F1445409CDB847B65124D40EE08A7052F144540E25CC30C8D134D403CFA5FAE45174540E25CC30C8D134D403CFA5FAE451745409CDB847B65124D40EE08A7052F1445409CDB847B65124D40
12649	Мелешино	1	7	444	42.533791000000001	42.551596000000004	58.439661000000001	58.435172000000001	0103000020E6100000010000000500000017F3734353444540451152B7B3374D4017F3734353444540D029C8CF46384D405E4D9EB29A464540D029C8CF46384D405E4D9EB29A464540451152B7B3374D4017F3734353444540451152B7B3374D40
11869	Малышево	1	7	444	42.327772000000003	42.343114999999997	58.298692000000003	58.291455999999997	0103000020E61000000100000005000000B345D26EF42945408A1C226E4E254D40B345D26EF4294540D6C9198A3B264D402EE23B31EB2B4540D6C9198A3B264D402EE23B31EB2B45408A1C226E4E254D40B345D26EF42945408A1C226E4E254D40
12303	Лопарево	1	7	444	42.644669999999998	42.680540000000001	58.346955999999999	58.331149000000003	0103000020E610000001000000050000002D5BEB8B84524540338D2617632A4D402D5BEB8B845245405393E00D692C4D4057CF49EF1B5745405393E00D692C4D4057CF49EF1B574540338D2617632A4D402D5BEB8B84524540338D2617632A4D40
11735	Ладыгино	1	7	444	42.168751999999998	42.181814000000003	58.595196999999999	58.588552	0103000020E610000001000000050000003A9160AA9915454069FF03AC554B4D403A9160AA99154540B2D6506A2F4C4D403CFA5FAE45174540B2D6506A2F4C4D403CFA5FAE4517454069FF03AC554B4D403A9160AA9915454069FF03AC554B4D40
12716	Курьяново	1	7	444	42.603634999999997	42.623910000000002	58.580722999999999	58.572831000000001	0103000020E6100000010000000500000048DC63E9434D45404791B58652494D4048DC63E9434D45407B849A21554A4D40DDD26A48DC4F45407B849A21554A4D40DDD26A48DC4F45404791B58652494D4048DC63E9434D45404791B58652494D40
11970	Красильниково	1	7	444	42.548828999999998	42.557983	58.353312000000003	58.349544000000002	0103000020E61000000100000005000000560C570740464540AB4198DBBD2C4D40560C57074046454066A4DE53392D4D40AB5CA8FC6B47454066A4DE53392D4D40AB5CA8FC6B474540AB4198DBBD2C4D40560C570740464540AB4198DBBD2C4D40
12528	Костома	1	7	444	41.879935000000003	41.920817	58.333658	58.321911	0103000020E610000001000000050000008ACDC7B5A1F04440809C306134294D408ACDC7B5A1F044403E062B4EB52A4D40E84CDA54DDF544403E062B4EB52A4D40E84CDA54DDF54440809C306134294D408ACDC7B5A1F04440809C306134294D40
53362	Кабаново	1	7	444	41.682000000000002	42.787790000000001	58.731493	58.0792	0103000020E610000001000000050000009EEFA7C64BD74440EEEBC039230A4D409EEFA7C64BD7444060200890A15D4D40D40E7F4DD664454060200890A15D4D40D40E7F4DD6644540EEEBC039230A4D409EEFA7C64BD74440EEEBC039230A4D40
11817	Дмитриевское	1	7	444	42.349043999999999	42.363677000000003	58.345685000000003	58.334372000000002	0103000020E61000000100000005000000B96E4A79AD2C45405C59A2B3CC2A4D40B96E4A79AD2C4540E0DBF4673F2C4D4059A7CAF78C2E4540E0DBF4673F2C4D4059A7CAF78C2E45405C59A2B3CC2A4D40B96E4A79AD2C45405C59A2B3CC2A4D40
5814	Галич	1	7	444	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
11687	Березовец	1	7	444	42.257505999999999	42.284922000000002	58.638502000000003	58.626753000000001	0103000020E610000001000000050000000B43E4F4F5204540BFD53A7139504D400B43E4F4F52045401E37FC6EBA514D4099F4F752782445401E37FC6EBA514D4099F4F75278244540BFD53A7139504D400B43E4F4F5204540BFD53A7139504D40
53330	Галич	1	7	7282	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
29768	Шайменский	1	7	165	46.216847999999999	46.239773	58.873606000000002	58.863686999999999	0103000020E61000000100000005000000FC19DEACC11B47407C7DAD4B8D6E4D40FC19DEACC11B474071CB4752D26F4D405EBBB4E1B01E474071CB4752D26F4D405EBBB4E1B01E47407C7DAD4B8D6E4D40FC19DEACC11B47407C7DAD4B8D6E4D40
11194	Троица	1	7	165	46.836047999999998	46.851993	58.982765000000001	58.977575000000002	0103000020E610000001000000050000006FF1F09E036B47409031772D217D4D406FF1F09E036B4740A453573ECB7D4D40E1B54B1B0E6D4740A453573ECB7D4D40E1B54B1B0E6D47409031772D217D4D406FF1F09E036B47409031772D217D4D40
11642	Тихон	1	7	165	46.656312999999997	46.670245999999999	59.380701999999999	59.372804000000002	0103000020E6100000010000000500000046787B1002544740B4E89D0AB8AF4D4046787B1002544740CAC2D7D7BAB04D402D23F59ECA554740CAC2D7D7BAB04D402D23F59ECA554740B4E89D0AB8AF4D4046787B1002544740B4E89D0AB8AF4D40
11551	Талица	1	7	165	46.720731000000001	46.738678999999998	59.409112	59.399448	0103000020E61000000100000005000000501BD5E9405C4740EF39B01C21B34D40501BD5E9405C4740593332C85DB44D40F99E91088D5E4740593332C85DB44D40F99E91088D5E4740EF39B01C21B34D40501BD5E9405C4740EF39B01C21B34D40
11419	Спас	1	7	165	46.713023999999997	46.728762000000003	59.171563999999996	59.162233000000001	0103000020E61000000100000005000000ADA1D45E445B47407EAA0A0DC4944D40ADA1D45E445B4740E19524CFF5954D40A648BE12485D4740E19524CFF5954D40A648BE12485D47407EAA0A0DC4944D40ADA1D45E445B47407EAA0A0DC4944D40
11121	Согра	1	7	165	46.524431	46.544094999999999	59.001748999999997	58.990971999999999	0103000020E610000001000000050000001901158E2043474038A0A52BD87E4D401901158E204347407DE6AC4F39804D406475ABE7A44547407DE6AC4F39804D406475ABE7A445474038A0A52BD87E4D401901158E2043474038A0A52BD87E4D40
11270	Поспехово	1	7	165	46.760570999999999	46.781106999999999	58.992446000000001	58.985639999999997	0103000020E610000001000000050000009CA4F9635A61474091D09673297E4D409CA4F9635A614740E4857478087F4D409DD66D50FB634740E4857478087F4D409DD66D50FB63474091D09673297E4D409CA4F9635A61474091D09673297E4D40
11285	Покров	1	7	165	46.604273999999997	46.619590000000002	59.050725999999997	59.044237000000003	0103000020E610000001000000050000005BE9B5D9584D4740F722DA8EA9854D405BE9B5D9584D4740488787307E864D40DE76A1B94E4F4740488787307E864D40DE76A1B94E4F4740F722DA8EA9854D405BE9B5D9584D4740F722DA8EA9854D40
11578	Песочный	1	7	165	46.656457000000003	46.678789000000002	59.331588000000004	59.320270999999998	0103000020E610000001000000050000007A1D71C806544740B96DDFA3FEA84D407A1D71C8065447407FDFBF7971AA4D4039F1D58EE25647407FDFBF7971AA4D4039F1D58EE2564740B96DDFA3FEA84D407A1D71C806544740B96DDFA3FEA84D40
10989	Осипино	1	7	165	46.645291	46.651184000000001	58.947090000000003	58.944569000000001	0103000020E610000001000000050000009AB33EE59852474060E811A3E7784D409AB33EE598524740302FC03E3A794D40D8D64FFF59534740302FC03E3A794D40D8D64FFF5953474060E811A3E7784D409AB33EE59852474060E811A3E7784D40
508	Оглоблино	1	7	165	46.708092000000001	46.715045000000003	59.047884000000003	59.044657999999998	0103000020E61000000100000005000000954737C2A25A47409CC0745AB7854D40954737C2A25A474037001B1021864D408C153598865B474037001B1021864D408C153598865B47409CC0745AB7854D40954737C2A25A47409CC0745AB7854D40
10756	Никола	1	7	165	46.688651999999998	46.709843999999997	58.827995999999999	58.817942000000002	0103000020E610000001000000050000009929ADBF255847402E03CE52B2684D409929ADBF25584740029CDEC5FB694D4083A10E2BDC5A4740029CDEC5FB694D4083A10E2BDC5A47402E03CE52B2684D409929ADBF255847402E03CE52B2684D40
10897	Марково	1	7	165	46.483117999999997	46.668053999999998	58.916424999999997	58.764228000000003	0103000020E61000000100000005000000F10D85CFD63D474000581D39D2614D40F10D85CFD63D47404F1E166A4D754D4022FB20CB825547404F1E166A4D754D4022FB20CB8255474000581D39D2614D40F10D85CFD63D474000581D39D2614D40
10813	Малое Раменье	1	7	165	46.547041999999998	46.573658999999999	58.763503999999998	58.754168999999997	0103000020E61000000100000005000000EBC4E5780546474019541B9C88604D40EBC4E57805464740BE2EC37FBA614D402D077AA86D494740BE2EC37FBA614D402D077AA86D49474019541B9C88604D40EBC4E5780546474019541B9C88604D40
11172	Макарята	1	7	165	46.627324000000002	46.652180999999999	59.155807000000003	59.148502000000001	0103000020E610000001000000050000007AFF1F274C504740FFB1101D02934D407AFF1F274C50474073BED87BF1934D404A09C1AA7A53474073BED87BF1934D404A09C1AA7A534740FFB1101D02934D407AFF1F274C504740FFB1101D02934D40
10694	Латышово	1	7	165	46.766078	46.791662000000002	58.883862999999998	58.873783000000003	0103000020E61000000100000005000000B1170AD80E6247408066101FD86F4D40B1170AD80E6247407D923B6C22714D4034BE2F2E556547407D923B6C22714D4034BE2F2E556547408066101FD86F4D40B1170AD80E6247408066101FD86F4D40
11437	Лажборовица	1	7	165	46.857157999999998	46.874944999999997	59.211773000000001	59.200454000000001	0103000020E610000001000000050000009CC0745AB76D47401B2D077AA8994D409CC0745AB76D47408196AE601B9B4D403C66A032FE6F47408196AE601B9B4D403C66A032FE6F47401B2D077AA8994D409CC0745AB76D47401B2D077AA8994D40
10945	Конница	1	7	165	46.493474999999997	46.508037000000002	58.890084999999999	58.885421000000001	0103000020E61000000100000005000000613255302A3F47408718AF7955714D40613255302A3F474080D4264EEE714D4038143E5B0741474080D4264EEE714D4038143E5B074147408718AF7955714D40613255302A3F47408718AF7955714D40
10848	Заветлужье	1	7	165	46.277403999999997	46.317118000000001	58.791555000000002	58.777338999999998	0103000020E61000000100000005000000C9E369F981234740E27327D87F634D40C9E369F9812347401EFE9AAC51654D40897C9752972847401EFE9AAC51654D40897C975297284740E27327D87F634D40C9E369F981234740E27327D87F634D40
10551	Вохма	1	7	165	46.728430000000003	46.774422999999999	58.943868000000002	58.918728999999999	0103000020E6100000010000000500000070B6B9313D5D4740827170E998754D4070B6B9313D5D4740D7DEA7AAD0784D409622F94A20634740D7DEA7AAD0784D409622F94A20634740827170E998754D4070B6B9313D5D4740827170E998754D40
11485	Воробьевица	1	7	165	46.674242999999997	46.712583000000002	59.237470999999999	59.227251000000003	0103000020E61000000100000005000000494739984D564740DD7D8E8F169D4D40494739984D564740CC5F2173659E4D40C15774EB355B4740CC5F2173659E4D40C15774EB355B4740DD7D8E8F169D4D40494739984D564740DD7D8E8F169D4D40
10672	Бережок	1	7	165	46.816752000000001	46.836281	58.943868000000002	58.934874999999998	0103000020E61000000100000005000000A7785C548B6847408B6CE7FBA9774D40A7785C548B684740D7DEA7AAD0784D4012A27C410B6B4740D7DEA7AAD0784D4012A27C410B6B47408B6CE7FBA9774D40A7785C548B6847408B6CE7FBA9774D40
11030	Андрианово	1	7	165	46.529974000000003	46.547302000000002	58.939810999999999	58.933703999999999	0103000020E610000001000000050000007BDD2230D64347407B12D89C83774D407BDD2230D6434740E5B512BA4B784D408884EFFD0D464740E5B512BA4B784D408884EFFD0D4647407B12D89C83774D407BDD2230D64347407B12D89C83774D40
40368	Лапшино	1	7	6909	46.758290000000002	46.781385	59.076642999999997	59.067323000000002	0103000020E6100000010000000500000022718FA50F61474062A2410A9E884D4022718FA50F614740D13B1570CF894D40E04A766C04644740D13B1570CF894D40E04A766C0464474062A2410A9E884D4022718FA50F61474062A2410A9E884D40
8341	Шушкодом	1	7	956	41.280299999999997	41.320922000000003	58.662599999999998	58.643897000000003	0103000020E61000000100000005000000CE88D2DEE0A344400B7F86376B524D40CE88D2DEE0A34440302AA913D0544D409148DBF813A94440302AA913D0544D409148DBF813A944400B7F86376B524D40CE88D2DEE0A344400B7F86376B524D40
53339	Чистые Боры	1	7	956	40.929696999999997	42.231895000000002	59.023015999999998	58.241695999999997	0103000020E610000001000000050000003B18B14F0077444079C9FFE4EF1E4D403B18B14F0077444072A43330F2824D408F8D40BCAE1D454072A43330F2824D408F8D40BCAE1D454079C9FFE4EF1E4D403B18B14F0077444079C9FFE4EF1E4D40
7855	Талица	1	7	956	41.538547999999999	41.568587999999998	58.732123999999999	58.721715000000003	0103000020E61000000100000005000000C1A90F24EFC444402E043928615C4D40C1A90F24EFC44440F04E3E3DB65D4D40F372D87DC7C84440F04E3E3DB65D4D40F372D87DC7C844402E043928615C4D40C1A90F24EFC444402E043928615C4D40
9051	Романцево	1	7	956	41.676879	41.696894	58.684283000000001	58.674064999999999	0103000020E61000000100000005000000B22C98F8A3D644406A300DC347564D40B22C98F8A3D64440B91AD99596574D40AA6395D233D94440B91AD99596574D40AA6395D233D944406A300DC347564D40B22C98F8A3D644406A300DC347564D40
53361	Махрово	1	7	956	41.665326999999998	41.700100999999997	58.471088999999999	58.420479999999998	0103000020E61000000100000005000000A912656F29D54440A04FE449D2354D40A912656F29D54440AF40F4A44C3C4D40CD72D9E89CD94440AF40F4A44C3C4D40CD72D9E89CD94440A04FE449D2354D40A912656F29D54440A04FE449D2354D40
8971	Лужок	1	7	956	41.486705999999998	41.504807	58.352580000000003	58.342165999999999	0103000020E610000001000000050000002C62D8614CBE4440CDE67118CC2B4D402C62D8614CBE4440A29C6857212D4D405CE509849DC04440A29C6857212D4D405CE509849DC04440CDE67118CC2B4D402C62D8614CBE4440CDE67118CC2B4D40
8942	Ликурга	1	7	956	41.812928999999997	41.854503000000001	58.589934999999997	58.577734	0103000020E61000000100000005000000287CB60E0EE84440C5E40D30F3494D40287CB60E0EE8444004E275FD824B4D40BDAAB35A60ED444004E275FD824B4D40BDAAB35A60ED4440C5E40D30F3494D40287CB60E0EE84440C5E40D30F3494D40
8901	Курилово	1	7	956	41.318631000000003	41.329374999999999	58.770662000000002	58.762766999999997	0103000020E61000000100000005000000F33E8EE6C8A84440E8BB5B59A2614D40F33E8EE6C8A844408E226B0DA5624D405C8FC2F528AA44408E226B0DA5624D405C8FC2F528AA4440E8BB5B59A2614D40F33E8EE6C8A84440E8BB5B59A2614D40
33156	Куребрино	1	7	956	41.21078	41.248635	58.321210999999998	58.309015000000002	0103000020E610000001000000050000005053CBD6FA9A44409A7CB3CD8D274D405053CBD6FA9A4440C70E2A711D294D400BD28C45D39F4440C70E2A711D294D400BD28C45D39F44409A7CB3CD8D274D405053CBD6FA9A44409A7CB3CD8D274D40
8820	Кренево	1	7	956	41.339615999999999	41.363726999999997	58.559407	58.548825000000001	0103000020E6100000010000000500000063997E8978AB4440151DC9E53F464D4063997E8978AB4440A51309A69A474D400AD6389B8EAE4440A51309A69A474D400AD6389B8EAE4440151DC9E53F464D4063997E8978AB4440151DC9E53F464D40
8807	Корега	1	7	956	41.409658	41.461041000000002	58.471592999999999	58.461483000000001	0103000020E61000000100000005000000BB4560AC6FB444407A54FCDF113B4D40BB4560AC6FB44440E202D0285D3C4D40BD8E386403BB4440E202D0285D3C4D40BD8E386403BB44407A54FCDF113B4D40BB4560AC6FB444407A54FCDF113B4D40
8764	Контеево	1	7	956	41.384360999999998	41.402982999999999	58.442340999999999	58.433410000000002	0103000020E61000000100000005000000CE6DC2BD32B1444033E197FA79374D40CE6DC2BD32B14440085740A19E384D4007EC6AF294B34440085740A19E384D4007EC6AF294B3444033E197FA79374D40CE6DC2BD32B1444033E197FA79374D40
8240	Ильино	1	7	956	41.742860999999998	41.75479	58.311923	58.305633999999998	0103000020E61000000100000005000000A73CBA1116DF4440D845D1031F274D40A73CBA1116DF444063EFC517ED274D4086AC6EF59CE0444063EFC517ED274D4086AC6EF59CE04440D845D1031F274D40A73CBA1116DF4440D845D1031F274D40
8375	Игумново	1	7	956	41.422989000000001	41.444234000000002	58.489345	58.478929000000001	0103000020E61000000100000005000000ACC8E88024B64440910DA48B4D3D4D40ACC8E88024B6444006BB61DBA23E4D40B9E2E2A8DCB8444006BB61DBA23E4D40B9E2E2A8DCB84440910DA48B4D3D4D40ACC8E88024B64440910DA48B4D3D4D40
8671	Елегино	1	7	956	41.905653000000001	41.931561000000002	58.717001000000003	58.710555999999997	0103000020E610000001000000050000001C430070ECF3444000FDBE7FF35A4D401C430070ECF34440831953B0C65B4D40529D0E643DF74440831953B0C65B4D40529D0E643DF7444000FDBE7FF35A4D401C430070ECF3444000FDBE7FF35A4D40
8607	Дьяконово	1	7	956	41.400754999999997	41.420878000000002	58.854584000000003	58.844524	0103000020E61000000100000005000000AF5A99F04BB34440F357C85C196C4D40AF5A99F04BB34440AAD72D02636D4D408ECD8E54DFB54440AAD72D02636D4D408ECD8E54DFB54440F357C85C196C4D40AF5A99F04BB34440F357C85C196C4D40
53333	Дор	1	7	956	40.929696999999997	42.231895000000002	59.023015999999998	58.241695999999997	0103000020E610000001000000050000003B18B14F0077444079C9FFE4EF1E4D403B18B14F0077444072A43330F2824D408F8D40BCAE1D454072A43330F2824D408F8D40BCAE1D454079C9FFE4EF1E4D403B18B14F0077444079C9FFE4EF1E4D40
8458	Добрецово	1	7	956	41.478513	41.497737000000001	58.53302	58.527997999999997	0103000020E61000000100000005000000FDDAFAE93FBD44403C2D3F7095434D40FDDAFAE93FBD4440950ED6FF39444D402C8194D8B5BF4440950ED6FF39444D402C8194D8B5BF44403C2D3F7095434D40FDDAFAE93FBD44403C2D3F7095434D40
8511	Гагарино	1	7	956	41.082680000000003	41.102065000000003	58.490411999999999	58.476252000000002	0103000020E6100000010000000500000043041C42958A4440CA5356D3F53C4D4043041C42958A444071C806D2C53E4D407B884677108D444071C806D2C53E4D407B884677108D4440CA5356D3F53C4D4043041C42958A4440CA5356D3F53C4D40
8270	Воскресенье	1	7	956	41.323051	41.342958000000003	58.503914000000002	58.497453	0103000020E6100000010000000500000055F833BC59A944400726378AAC3F4D4055F833BC59A944408FFF024180404D4067F3380CE6AB44408FFF024180404D4067F3380CE6AB44400726378AAC3F4D4055F833BC59A944400726378AAC3F4D40
8164	Борок	1	7	956	41.586123000000001	41.641072999999999	58.380566000000002	58.346274999999999	0103000020E610000001000000050000007A37161406CB444011363CBD522C4D407A37161406CB44401AFCFD62B6304D409FAC18AE0ED244401AFCFD62B6304D409FAC18AE0ED2444011363CBD522C4D407A37161406CB444011363CBD522C4D40
8030	Бараново	1	7	956	41.587173999999997	41.615595999999996	58.490985999999999	58.481648	0103000020E61000000100000005000000DF87838428CB4440871744A4A63D4D40DF87838428CB44409D6516A1D83E4D4032C687D9CBCE44409D6516A1D83E4D4032C687D9CBCE4440871744A4A63D4D40DF87838428CB4440871744A4A63D4D40
8055	Афонино	1	7	956	41.576286000000003	41.598564000000003	58.515413000000002	58.508051000000002	0103000020E61000000100000005000000439259BDC3C944409DD9AED007414D40439259BDC3C9444075779D0DF9414D400F48C2BE9DCC444075779D0DF9414D400F48C2BE9DCC44409DD9AED007414D40439259BDC3C944409DD9AED007414D40
7477	Трифон	1	7	813	42.610804000000002	42.631492000000001	58.092964000000002	58.083995999999999	0103000020E610000001000000050000000C2252D32E4E4540567F8461C00A4D400C2252D32E4E454049DA8D3EE60B4D40C3D7D7BAD450454049DA8D3EE60B4D40C3D7D7BAD4504540567F8461C00A4D400C2252D32E4E4540567F8461C00A4D40
7199	Словинка	1	7	813	43.107787999999999	43.131718999999997	58.035926000000003	58.024746	0103000020E610000001000000050000005C7347FFCB8D4540795A7EE02A034D405C7347FFCB8D4540BE89213999044D4083A10E2BDC904540BE89213999044D4083A10E2BDC904540795A7EE02A034D405C7347FFCB8D4540795A7EE02A034D40
7315	Просек	1	7	813	42.944491999999997	42.968890000000002	58.434596999999997	58.426149000000002	0103000020E61000000100000005000000B4AA251DE57845408F1CE90C8C364D40B4AA251DE578454048F8DEDFA0374D40F2B56796047C454048F8DEDFA0374D40F2B56796047C45408F1CE90C8C364D40B4AA251DE57845408F1CE90C8C364D40
7770	Понизье	1	7	813	43.164695999999999	43.173239000000002	58.318125000000002	58.312547000000002	0103000020E6100000010000000500000019E42EC21495454041BB438A01284D4019E42EC2149545401F85EB51B8284D4025B20FB22C9645401F85EB51B8284D4025B20FB22C96454041BB438A01284D4019E42EC21495454041BB438A01284D40
7644	Помчище	1	7	813	42.976787000000002	42.986407999999997	58.284246000000003	58.274025000000002	0103000020E6100000010000000500000038143E5B077D4540A9A44E4013234D4038143E5B077D45406902452C62244D40A2410A9E427E45406902452C62244D40A2410A9E427E4540A9A44E4013234D4038143E5B077D4540A9A44E4013234D40
7750	Пеньки	1	7	813	42.710382000000003	42.727980000000002	58.017786999999998	58.010959999999997	0103000020E6100000010000000500000063D520CCED5A454036C8242367014D4063D520CCED5A4540A0A52BD846024D403012DA722E5D4540A0A52BD846024D403012DA722E5D454036C8242367014D4063D520CCED5A454036C8242367014D40
7622	Палкино	1	7	813	42.91677	42.949379	58.251192000000003	58.231096999999998	0103000020E610000001000000050000001AFA27B858754540139A2496941D4D401AFA27B8587545402882380F27204D402D414640857945402882380F27204D402D41464085794540139A2496941D4D401AFA27B858754540139A2496941D4D40
53348	Михайловское	1	7	813	42.477296000000003	43.531396999999998	58.581501000000003	57.868895000000002	0103000020E610000001000000050000007D410B09183D454037548CF337EF4C407D410B09183D4540B0CBF09F6E4A4D40A41820D104C44540B0CBF09F6E4A4D40A41820D104C4454037548CF337EF4C407D410B09183D454037548CF337EF4C40
7233	Курново	1	7	813	42.983280999999998	42.990971000000002	58.373078	58.364283999999998	0103000020E610000001000000050000009BE3DC26DC7D4540603AADDBA02E4D409BE3DC26DC7D4540B56D1805C12F4D4068244223D87E4540B56D1805C12F4D4068244223D87E4540603AADDBA02E4D409BE3DC26DC7D4540603AADDBA02E4D40
7509	Курилово	1	7	813	43.034126000000001	43.054563000000002	58.128495000000001	58.119911000000002	0103000020E61000000100000005000000BEF8A23D5E84454020B75F3E590F4D40BEF8A23D5E8445408A592F8672104D402C499EEBFB8645408A592F8672104D402C499EEBFB86454020B75F3E590F4D40BEF8A23D5E84454020B75F3E590F4D40
7391	Котельниково	1	7	813	42.874028000000003	42.890234	58.115547999999997	58.103907999999997	0103000020E61000000100000005000000E7E44526E06F454079E57ADB4C0D4D40E7E44526E06F4540218FE046CA0E4D40C5E40D30F3714540218FE046CA0E4D40C5E40D30F371454079E57ADB4C0D4D40E7E44526E06F454079E57ADB4C0D4D40
7888	Иваньково	1	7	813	42.944070000000004	42.952936000000001	58.113256	58.108544000000002	0103000020E610000001000000050000003F912749D7784540A91611C5E40D4D403F912749D7784540B309302C7F0E4D402D978DCEF9794540B309302C7F0E4D402D978DCEF9794540A91611C5E40D4D403F912749D7784540A91611C5E40D4D40
7336	Бедрино	1	7	813	42.887439999999998	42.906188	58.309860999999998	58.300958000000001	0103000020E61000000100000005000000C49448A2977145401BBCAFCA85264D40C49448A29771454026A77686A9274D408A03E8F7FD73454026A77686A9274D408A03E8F7FD7345401BBCAFCA85264D40C49448A2977145401BBCAFCA85264D40
7108	Антропово	1	7	813	42.981718000000001	43.034961000000003	58.410732000000003	58.386676000000001	0103000020E6100000010000000500000080F277EFA87D4540F51263997E314D4080F277EFA87D4540D9B5BDDD92344D4057D11F9A79844540D9B5BDDD92344D4057D11F9A79844540F51263997E314D4080F277EFA87D4540F51263997E314D40
54182	Юхнов	1	6	\N	35.210509999999999	35.261102999999999	54.753607000000002	54.728544999999997	0103000020E6100000010000000500000090BDDEFDF19A414008556AF6405D4B4090BDDEFDF19A4140B284B53176604B4099F1B6D26BA14140B284B53176604B4099F1B6D26BA1414008556AF6405D4B4090BDDEFDF19A414008556AF6405D4B40
54204	Шопино	1	6	\N	36.144298999999997	36.170377000000002	54.503318	54.488588	0103000020E6100000010000000500000039ECBE6378124240E99B340D8A3E4B4039ECBE63781242407BBE66B96C404B40CC7EDDE9CE1542407BBE66B96C404B40CC7EDDE9CE154240E99B340D8A3E4B4039ECBE6378124240E99B340D8A3E4B40
25542	Тимашово	1	6	\N	36.466344999999997	36.487634999999997	55.146718	55.134954999999998	0103000020E6100000010000000500000099D36531B13B424041B7973446914B4099D36531B13B424005DEC9A7C7924B4046B1DCD26A3E424005DEC9A7C7924B4046B1DCD26A3E424041B7973446914B4099D36531B13B424041B7973446914B40
54197	Таруса	1	6	\N	37.144590999999998	37.198293	54.748764000000001	54.714115	0103000020E61000000100000005000000E12538F581924240A14ACD1E685B4B40E12538F5819242400936AE7FD75F4B404B033FAA619942400936AE7FD75F4B404B033FAA61994240A14ACD1E685B4B40E12538F581924240A14ACD1E685B4B40
11545	Спас-Загорье	1	6	\N	36.572544000000001	36.611961999999998	55.057115000000003	55.045645	0103000020E61000000100000005000000B1C22D1F49494240EB1C03B2D7854B40B1C22D1F49494240378E588B4F874B40873254C5544E4240378E588B4F874B40873254C5544E4240EB1C03B2D7854B40B1C22D1F49494240EB1C03B2D7854B40
54180	Спас-Деменск	1	6	\N	33.994002000000002	34.052509000000001	54.427190000000003	54.400646999999999	0103000020E610000001000000050000004D1421753BFF4040C91EA16648334B404D1421753BFF4040D1967329AE364B4072DF6A9DB8064140D1967329AE364B4072DF6A9DB8064140C91EA16648334B404D1421753BFF4040C91EA16648334B40
1634	Обнинск	1	6	\N	36.533152999999999	36.676228000000002	55.144638999999998	55.069664000000003	0103000020E61000000100000005000000D461855B3E444240B2DAFCBFEA884B40D461855B3E444240F25CDF8783924B40DB519CA38E564240F25CDF8783924B40DB519CA38E564240B2DAFCBFEA884B40D461855B3E444240B2DAFCBFEA884B40
45961	Митинка	1	6	\N	36.577044999999998	36.611190000000001	55.034661999999997	55.022675	0103000020E6100000010000000500000000A94D9CDC494240E9B7AF03E7824B4000A94D9CDC494240FC34EECD6F844B4035D252793B4E4240FC34EECD6F844B4035D252793B4E4240E9B7AF03E7824B4000A94D9CDC494240E9B7AF03E7824B40
10625	Малоярославец	1	6	\N	36.412824000000001	36.510182999999998	55.046357	54.990043999999997	0103000020E610000001000000050000008080B56AD7344240EECC04C3B97E4B408080B56AD73442406878B306EF854B40D2FC31AD4D4142406878B306EF854B40D2FC31AD4D414240EECC04C3B97E4B408080B56AD7344240EECC04C3B97E4B40
10054	Маклино	1	6	\N	36.459392000000001	36.484653000000002	54.998792999999999	54.983716000000001	0103000020E61000000100000005000000A305685BCD3A4240A646E867EA7D4B40A305685BCD3A4240A33CF372D87F4B404374081C093E4240A33CF372D87F4B404374081C093E4240A646E867EA7D4B40A305685BCD3A4240A646E867EA7D4B40
54185	Людиново	1	6	\N	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
25613	Коряково	1	6	\N	36.671188000000001	36.687483999999998	55.254404999999998	55.244393000000002	0103000020E61000000100000005000000DCBB067DE9554240882F1345489F4B40DCBB067DE95542402D78D15790A04B40FA42C879FF5742402D78D15790A04B40FA42C879FF574240882F1345489F4B40DCBB067DE9554240882F1345489F4B40
54183	Кондрово	1	6	\N	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
9958	Коллонтай	1	6	\N	36.520325	36.542710999999997	55.040492	55.024166999999998	0103000020E61000000100000005000000462575029A4242403B527DE717834B40462575029A424240F4DF83D72E854B40F816D68D77454240F4DF83D72E854B40F816D68D774542403B527DE717834B40462575029A4242403B527DE717834B40
54187	Козельск	1	6	\N	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
36210	Киров	1	6	\N	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
60378	Картышово	1	6	\N	33.443434000000003	37.275906999999997	55.341996999999999	53.276775000000001	0103000020E610000001000000050000009DF7FF71C2B84040DAACFA5C6DA34A409DF7FF71C2B84040412AC58EC6AB4B4065DEAAEB50A34240412AC58EC6AB4B4065DEAAEB50A34240DAACFA5C6DA34A409DF7FF71C2B84040DAACFA5C6DA34A40
54193	Канищево	1	6	\N	36.276774000000003	36.299771	54.601255000000002	54.586717	0103000020E610000001000000050000000A3197546D234240ED80EB8A194B4B400A3197546D2342403BC780ECF54C4B4005A568E55E2642403BC780ECF54C4B4005A568E55E264240ED80EB8A194B4B400A3197546D234240ED80EB8A194B4B40
40	Калуга	1	6	\N	36.085127	36.388956	54.610413000000001	54.457101999999999	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
54233	Истья	1	6	\N	36.697229999999998	36.705818000000001	55.156131999999999	55.151991000000002	0103000020E6100000010000000500000021E527D53E594240A724EB7074934B4021E527D53E594240F6ED2422FC934B40CD76853E585A4240F6ED2422FC934B40CD76853E585A4240A724EB7074934B4021E527D53E594240A724EB7074934B40
36109	Захарово	1	6	\N	36.054656000000001	36.068004999999999	54.665613999999998	54.653776999999998	0103000020E61000000100000005000000DD43C2F7FE06424041F0F8F6AE534B40DD43C2F7FE0642403FE1ECD632554B40747B4963B40842403FE1ECD632554B40747B4963B408424041F0F8F6AE534B40DD43C2F7FE06424041F0F8F6AE534B40
30672	Жуков	1	6	\N	36.689442	36.781976999999998	55.044206000000003	55.005412999999997	0103000020E61000000100000005000000923EADA23F58424093FC885FB1804B40923EADA23F584240BC24CE8AA8854B40B29C84D217644240BC24CE8AA8854B40B29C84D21764424093FC885FB1804B40923EADA23F58424093FC885FB1804B40
26155	Ермолино	1	6	\N	36.583486000000001	36.631068999999997	55.239789000000002	55.185172999999999	0103000020E6100000010000000500000041D653ABAF4A4240158DB5BFB3974B4041D653ABAF4A42406478EC67B19E4B407C4276DEC65042406478EC67B19E4B407C4276DEC6504240158DB5BFB3974B4041D653ABAF4A4240158DB5BFB3974B40
49017	Дубровка	1	6	\N	36.663057999999999	36.672724000000002	55.009497000000003	55.004514999999998	0103000020E61000000100000005000000F3ACA415DF544240B4AB90F293804B40F3ACA415DF5442407F349C3237814B40FE9DEDD11B5642407F349C3237814B40FE9DEDD11B564240B4AB90F293804B40F3ACA415DF544240B4AB90F293804B40
20188	Грабцево	1	6	\N	36.364378000000002	36.380645999999999	54.571714999999998	54.560366999999999	0103000020E61000000100000005000000E2B034F0A32E4240FA60191BBA474B40E2B034F0A32E4240FAD005F52D494B4036AD1402B9304240FAD005F52D494B4036AD1402B9304240FA60191BBA474B40E2B034F0A32E4240FA60191BBA474B40
25664	Ворсино	1	6	\N	36.637016000000003	36.683782999999998	55.242159999999998	55.219518999999998	0103000020E61000000100000005000000AE8383BD89514240E1ECD632199C4B40AE8383BD895142401E335019FF9E4B40C7478B33865742401E335019FF9E4B40C7478B3386574240E1ECD632199C4B40AE8383BD89514240E1ECD632199C4B40
24875	Боровск	1	6	\N	36.445478000000001	36.548504999999999	55.225983999999997	55.186098000000001	0103000020E61000000100000005000000338B506C05394240EEEC2B0FD2974B40338B506C05394240AAB5300BED9C4B40A3586E6935464240AAB5300BED9C4B40A3586E6935464240EEEC2B0FD2974B40338B506C05394240EEEC2B0FD2974B40
30198	Белоусово	1	6	\N	36.646970000000003	36.693978000000001	55.103580000000001	55.082189	0103000020E610000001000000050000001FBFB7E9CF524240A48B4D2B858A4B401FBFB7E9CF5242408542041C428D4B405E126745D45842408542041C428D4B405E126745D4584240A48B4D2B858A4B401FBFB7E9CF524240A48B4D2B858A4B40
25742	Балабаново	1	6	\N	36.635219999999997	36.678455999999997	55.196058000000001	55.161974999999998	0103000020E61000000100000005000000EFE192E34E51424082E2C798BB944B40EFE192E34E514240410FB56D18994B4032E36DA5D7564240410FB56D18994B4032E36DA5D756424082E2C798BB944B40EFE192E34E51424082E2C798BB944B40
49452	Аристово	1	6	\N	36.744652000000002	36.755495000000003	55.225568000000003	55.219627000000003	0103000020E610000001000000050000005473B9C1505F4240C828CFBC1C9C4B405473B9C1505F424017838769DF9C4B4051A5660FB460424017838769DF9C4B4051A5660FB4604240C828CFBC1C9C4B405473B9C1505F4240C828CFBC1C9C4B40
60388	Заречье	1	6	7506	35.166798	36.085701999999998	53.910494999999997	53.50797	0103000020E61000000100000005000000E48409A359954140B0AC342905C14A40E48409A359954140F415A4198BF44A40D4997B48F80A4240F415A4198BF44A40D4997B48F80A4240B0AC342905C14A40E48409A359954140B0AC342905C14A40
21631	Юхнов	1	6	1425	35.210509999999999	35.261102999999999	54.753607000000002	54.728544999999997	0103000020E6100000010000000500000090BDDEFDF19A414008556AF6405D4B4090BDDEFDF19A4140B284B53176604B4099F1B6D26BA14140B284B53176604B4099F1B6D26BA1414008556AF6405D4B4090BDDEFDF19A414008556AF6405D4B40
45734	Щелканово	1	6	1425	35.420867999999999	35.450557000000003	54.583744000000003	54.569459999999999	0103000020E610000001000000050000006AF7AB00DFB54140A930B610E4484B406AF7AB00DFB541403D9E961FB84A4B40F0FD0DDAABB941403D9E961FB84A4B40F0FD0DDAABB94140A930B610E4484B406AF7AB00DFB54140A930B610E4484B40
22207	Чемоданово	1	6	1425	35.521129000000002	35.544656000000003	54.637163000000001	54.626640999999999	0103000020E61000000100000005000000A4FFE55AB4C2414097AAB4C535504B40A4FFE55AB4C24140529CA38E8E514B40FCC8AD49B7C54140529CA38E8E514B40FCC8AD49B7C5414097AAB4C535504B40A4FFE55AB4C2414097AAB4C535504B40
22187	Упрямово	1	6	1425	35.445247999999999	35.464463000000002	54.665739000000002	54.656402	0103000020E61000000100000005000000014EEFE2FDB84140B68311FB04544B40014EEFE2FDB84140FC5580EF36554B40DD99098673BB4140FC5580EF36554B40DD99098673BB4140B68311FB04544B40014EEFE2FDB84140B68311FB04544B40
22127	Рыляки	1	6	1425	35.101920999999997	35.124577000000002	54.716965000000002	54.700631999999999	0103000020E6100000010000000500000047E350BF0B8D4140FA43334FAE594B4047E350BF0B8D414036B05582C55B4B40BA6A9E23F28F414036B05582C55B4B40BA6A9E23F28F4140FA43334FAE594B4047E350BF0B8D4140FA43334FAE594B40
22103	Порослицы	1	6	1425	35.585690999999997	35.604222999999998	54.587004	54.574074000000003	0103000020E61000000100000005000000E04735ECF7CA4140F1BDBF417B494B40E04735ECF7CA4140834F73F2224B4B40D93EE42D57CD4140834F73F2224B4B40D93EE42D57CD4140F1BDBF417B494B40E04735ECF7CA4140F1BDBF417B494B40
15883	Погореловка	1	6	1425	35.404743000000003	35.425252	54.803279000000003	54.793771	0103000020E6100000010000000500000079245E9ECEB34140B1C1C2499A654B4079245E9ECEB341402448A5D8D1664B40804754A86EB641402448A5D8D1664B40804754A86EB64140B1C1C2499A654B4079245E9ECEB34140B1C1C2499A654B40
45634	Плоское	1	6	1425	35.332321	35.351275999999999	54.652579000000003	54.639100999999997	0103000020E610000001000000050000001363997E89AA4140A2EBC20FCE514B401363997E89AA414038876BB587534B4052EFA99CF6AC414038876BB587534B4052EFA99CF6AC4140A2EBC20FCE514B401363997E89AA4140A2EBC20FCE514B40
54254	Озеро	1	6	1425	35.198929999999997	35.213726000000001	54.639971000000003	54.627918000000001	0103000020E61000000100000005000000BD18CA8976994140ED48F59D5F504B40BD18CA8976994140B8B1D991EA514B400727A25F5B9B4140B8B1D991EA514B400727A25F5B9B4140ED48F59D5F504B40BD18CA8976994140ED48F59D5F504B40
45597	Куркино	1	6	1425	35.276885999999998	35.294789999999999	54.599701000000003	54.590364000000001	0103000020E61000000100000005000000315C1D0071A341402D5E2C0C914B4B40315C1D0071A3414073309B00C34C4B400B98C0ADBBA5414073309B00C34C4B400B98C0ADBBA541402D5E2C0C914B4B40315C1D0071A341402D5E2C0C914B4B40
45954	Кудиново	1	6	1425	35.448680000000003	35.457653999999998	54.618499	54.612217000000001	0103000020E61000000100000005000000452FA3586EB9414012876C205D4E4B40452FA3586EB94140EACDA8F92A4F4B401971016894BA4140EACDA8F92A4F4B401971016894BA414012876C205D4E4B40452FA3586EB9414012876C205D4E4B40
21846	Колыхманово	1	6	1425	35.274092000000003	35.297367999999999	54.766069000000002	54.755097999999997	0103000020E61000000100000005000000310C587215A3414033A31F0DA7604B40310C587215A341405EBD8A8C0E624B403F70952710A641405EBD8A8C0E624B403F70952710A6414033A31F0DA7604B40310C587215A3414033A31F0DA7604B40
21805	Климов Завод	1	6	1425	34.895848000000001	34.935777999999999	54.844465999999997	54.820306000000002	0103000020E61000000100000005000000F017B325AB724140365B79C9FF684B40F017B325AB724140BE4A3E76176C4B407C28D192C7774140BE4A3E76176C4B407C28D192C7774140365B79C9FF684B40F017B325AB724140365B79C9FF684B40
60398	Зубово	1	6	1425	35.468496999999999	35.487667000000002	54.563780999999999	54.553496000000003	0103000020E6100000010000000500000016A3AEB5F7BB4140C13BF9F4D8464B4016A3AEB5F7BB4140978DCEF929484B40522B4CDF6BBE4140978DCEF929484B40522B4CDF6BBE4140C13BF9F4D8464B4016A3AEB5F7BB4140C13BF9F4D8464B40
60395	Емельяновка	1	6	1425	35.220165999999999	35.238438000000002	54.700730999999998	54.690308999999999	0103000020E6100000010000000500000077D844662E9C41403691990B5C584B4077D844662E9C41408D25AC8DB1594B40D40FEA22859E41408D25AC8DB1594B40D40FEA22859E41403691990B5C584B4077D844662E9C41403691990B5C584B40
48068	Выползово	1	6	1425	35.604878999999997	35.614159000000001	54.595429000000003	54.591481000000002	0103000020E61000000100000005000000C284D1AC6CCD41404A9A3FA6B54B4B40C284D1AC6CCD4140850B7904374C4B40A4C519C39CCE4140850B7904374C4B40A4C519C39CCE41404A9A3FA6B54B4B40C284D1AC6CCD41404A9A3FA6B54B4B40
45510	Беляево	1	6	1425	35.08267	35.097304000000001	54.806345	54.798437	0103000020E610000001000000050000001F2E39EE948A41404B75012F33664B401F2E39EE948A414085251E5036674B408FE21C75748C414085251E5036674B408FE21C75748C41404B75012F33664B401F2E39EE948A41404B75012F33664B40
21485	Хвастовичи	1	6	1649	35.069932000000001	35.110258000000002	53.482799	53.451177999999999	0103000020E61000000100000005000000D1782288F38841405C566133C0B94A40D1782288F388414050C58D5BCCBD4A40AA0F24EF1C8E414050C58D5BCCBD4A40AA0F24EF1C8E41405C566133C0B94A40D1782288F38841405C566133C0B94A40
48721	Фролово	1	6	1649	35.062430999999997	35.085509000000002	53.583109999999998	53.563605000000003	0103000020E61000000100000005000000D7A02FBDFD874140596E693524C84A40D7A02FBDFD8741403BFC3559A3CA4A40C0417BF5F18A41403BFC3559A3CA4A40C0417BF5F18A4140596E693524C84A40D7A02FBDFD874140596E693524C84A40
49549	Теребень	1	6	1649	35.253494000000003	35.274163999999999	53.437078	53.422496000000002	0103000020E61000000100000005000000BADDCB7D72A041406D58535914B64A40BADDCB7D72A041408AE6012CF2B74A40CADE52CE17A341408AE6012CF2B74A40CADE52CE17A341406D58535914B64A40BADDCB7D72A041406D58535914B64A40
54231	Стайки	1	6	1649	35.107365000000001	35.128160999999999	53.416057000000002	53.395136999999998	0103000020E6100000010000000500000016DEE522BE8D4140433866D993B24A4016DEE522BE8D4140CD22145B41B54A40B3CF639467904140CD22145B41B54A40B3CF639467904140433866D993B24A4016DEE522BE8D4140433866D993B24A40
21368	Подбужье	1	6	1649	34.904857999999997	34.955863999999998	53.510787000000001	53.488618000000002	0103000020E6100000010000000500000011C30E63D2734140541EDD088BBE4A4011C30E63D2734140691CEA7761C14A403DB665C0597A4140691CEA7761C14A403DB665C0597A4140541EDD088BBE4A4011C30E63D2734140541EDD088BBE4A40
21315	Пеневичи	1	6	1649	34.960419000000002	34.992983000000002	53.460245	53.446057000000003	0103000020E6100000010000000500000080BA8102EF7A41407193516518B94A4080BA8102EF7A4140E292E34EE9BA4A40F33D23111A7F4140E292E34EE9BA4A40F33D23111A7F41407193516518B94A4080BA8102EF7A41407193516518B94A40
21258	Нехочи	1	6	1649	34.908002000000003	34.946800000000003	53.433290999999997	53.412326999999998	0103000020E61000000100000005000000EF59D76839744140FF209221C7B44A40EF59D768397441405853591476B74A4029ED0DBE307941405853591476B74A4029ED0DBE30794140FF209221C7B44A40EF59D76839744140FF209221C7B44A40
21399	Милеево	1	6	1649	35.163266999999998	35.201265999999997	53.509689000000002	53.485387000000003	0103000020E610000001000000050000000DC2DCEEE5944140A873452921BE4A400DC2DCEEE5944140C310397D3DC14A40FBE59315C3994140C310397D3DC14A40FBE59315C3994140A873452921BE4A400DC2DCEEE5944140A873452921BE4A40
21172	Ловать	1	6	1649	35.002890999999998	35.033406999999997	53.642394000000003	53.617654999999999	0103000020E61000000100000005000000F33977BB5E804140FE9AAC510FCF4A40F33977BB5E804140C59272F739D24A408E3A3AAE46844140C59272F739D24A408E3A3AAE46844140FE9AAC510FCF4A40F33977BB5E804140FE9AAC510FCF4A40
21086	Кудрявец	1	6	1649	35.263852	35.286399000000003	53.406357999999997	53.386082999999999	0103000020E61000000100000005000000FA7DFFE6C5A141405245F12A6BB14A40FA7DFFE6C5A14140E63BF88903B44A40B64DF1B8A8A44140E63BF88903B44A40B64DF1B8A8A441405245F12A6BB14A40FA7DFFE6C5A141405245F12A6BB14A40
60414	Красное	1	6	1649	35.148606999999998	35.181215999999999	53.458877999999999	53.437899000000002	0103000020E61000000100000005000000747ADE8D05934140BEF90D130DB84A40747ADE8D059341404C6DA983BCBA4A4087C1FC15329741404C6DA983BCBA4A4087C1FC1532974140BEF90D130DB84A40747ADE8D05934140BEF90D130DB84A40
20995	Колодяссы	1	6	1649	35.190081999999997	35.213869000000003	53.56606	53.545791999999999	0103000020E6100000010000000500000075C7629B549841408F352383DCC54A4075C7629B5498414071C971A774C84A406A50340F609B414071C971A774C84A406A50340F609B41408F352383DCC54A4075C7629B549841408F352383DCC54A40
54195	Еленский	1	6	1649	35.355156000000001	35.392257000000001	53.493819000000002	53.470103000000002	0103000020E61000000100000005000000357D76C075AD41403160C9552CBC4A40357D76C075AD41405C92037635BF4A404450357A35B241405C92037635BF4A404450357A35B241403160C9552CBC4A40357D76C075AD41403160C9552CBC4A40
20923	Воткино	1	6	1649	34.961488000000003	34.997132999999998	53.553736999999998	53.537118999999997	0103000020E610000001000000050000008CBFED09127B4140B587BD50C0C44A408CBFED09127B4140E6CAA0DAE0C64A409561DC0DA27F4140E6CAA0DAE0C64A409561DC0DA27F4140B587BD50C0C44A408CBFED09127B4140B587BD50C0C44A40
48139	Буда	1	6	1649	35.063698000000002	35.073965999999999	53.517206999999999	53.508949999999999	0103000020E610000001000000050000000A698D41278841404CA60A4625C14A400A698D41278841409221C7D633C24A400A82C7B7778941409221C7D633C24A400A82C7B7778941404CA60A4625C14A400A698D41278841404CA60A4625C14A40
20895	Бояновичи	1	6	1649	34.822913999999997	34.872132000000001	53.422941999999999	53.401209999999999	0103000020E61000000100000005000000D4B5F63E55694140016A6AD95AB34A40D4B5F63E556941406B0DA5F622B64A40C5E57805A26F41406B0DA5F622B64A40C5E57805A26F4140016A6AD95AB34A40D4B5F63E55694140016A6AD95AB34A40
45772	Барановка	1	6	1649	35.073858000000001	35.087135000000004	53.622697000000002	53.610674000000003	0103000020E610000001000000050000002446CF2D748941403E42CD902ACE4A402446CF2D748941409E280989B4CF4A4022AB5B3D278B41409E280989B4CF4A4022AB5B3D278B41403E42CD902ACE4A402446CF2D748941403E42CD902ACE4A40
49457	Авдеевка	1	6	1649	34.721018000000001	34.747194999999998	53.436332999999998	53.424841000000001	0103000020E61000000100000005000000E6E95C514A5C4140FE7F9C3061B64A40E6E95C514A5C414031957EC2D9B74A400B5EF415A45F414031957EC2D9B74A400B5EF415A45F4140FE7F9C3061B64A40E6E95C514A5C4140FE7F9C3061B64A40
49217	Ястребовка	1	6	1067	36.378292999999999	36.405484999999999	54.612513999999997	54.599383000000003	0103000020E6100000010000000500000022A7AFE76B304240A2630795B84C4B4022A7AFE76B304240CB2BD7DB664E4B406002B7EEE6334240CB2BD7DB664E4B406002B7EEE6334240A2630795B84C4B4022A7AFE76B304240A2630795B84C4B40
20605	Ферзиково	1	6	1067	36.732695999999997	36.756160000000001	54.553500999999997	54.533002000000003	0103000020E610000001000000050000007BF486FBC85D4240EF59D76839444B407BF486FBC85D4240D2A6EA1ED9464B408D45D3D9C9604240D2A6EA1ED9464B408D45D3D9C9604240EF59D76839444B407BF486FBC85D4240EF59D76839444B40
9419	Сугоново	1	6	1067	36.670001999999997	36.689782999999998	54.692489000000002	54.679895000000002	0103000020E61000000100000005000000962023A0C255424062DBA2CC06574B40962023A0C25542407DEBC37AA3584B401B2B31CF4A5842407DEBC37AA3584B401B2B31CF4A58424062DBA2CC06574B40962023A0C255424062DBA2CC06574B40
20553	Сашкино	1	6	1067	36.833640000000003	36.858415000000001	54.580368	54.568187000000002	0103000020E6100000010000000500000098512CB7B46A42409581035ABA484B4098512CB7B46A42408DD2A57F494A4B40ABB2EF8AE06D42408DD2A57F494A4B40ABB2EF8AE06D42409581035ABA484B4098512CB7B46A42409581035ABA484B40
47885	Покровское	1	6	1067	36.518735	36.535435	54.570926999999998	54.565894999999998	0103000020E61000000100000005000000312592E86542424026FC523F6F484B40312592E865424240A2B3CC2214494B401F11532289444240A2B3CC2214494B401F1153228944424026FC523F6F484B40312592E86542424026FC523F6F484B40
40421	Плюсково	1	6	1067	36.818494000000001	36.831403000000002	54.330911	54.323014999999998	0103000020E6100000010000000500000072FC5069C4684240088F368E58294B4072FC5069C46842407E71A94A5B2A4B40ED65DB696B6A42407E71A94A5B2A4B40ED65DB696B6A4240088F368E58294B4072FC5069C4684240088F368E58294B40
49213	Октябрьский	1	6	1067	36.767037999999999	36.779651000000001	54.358156000000001	54.349544999999999	0103000020E6100000010000000500000006651A4D2E6242407BBDFBE3BD2C4B4006651A4D2E624240DF6E490ED82D4B4098A59D9ACB634240DF6E490ED82D4B4098A59D9ACB6342407BBDFBE3BD2C4B4006651A4D2E6242407BBDFBE3BD2C4B40
41364	Красный Городок	1	6	1067	36.401980999999999	36.419902	54.544817000000002	54.531534000000001	0103000020E61000000100000005000000834E081D74334240255B5D4E09444B40834E081D7433424005A73E90BC454B4033C34659BF35424005A73E90BC454B4033C34659BF354240255B5D4E09444B40834E081D74334240255B5D4E09444B40
49356	Кольцово	1	6	1067	36.662483999999999	36.711379000000001	54.484932000000001	54.439335	0103000020E61000000100000005000000C70F9546CC5442407C7E18213C384B40C70F9546CC54424056647440123E4B40D50792770E5B424056647440123E4B40D50792770E5B42407C7E18213C384B40C70F9546CC5442407C7E18213C384B40
20393	Зудна	1	6	1067	36.774279	36.80077	54.389927	54.376120999999998	0103000020E61000000100000005000000637D03931B6342405E2BA1BB24304B40637D03931B634240E869C020E9314B4018CFA0A17F664240E869C020E9314B4018CFA0A17F6642405E2BA1BB24304B40637D03931B6342405E2BA1BB24304B40
19816	Желябужский	1	6	1067	36.513776	36.540078999999999	54.599842000000002	54.589064999999998	0103000020E610000001000000050000001FBC7669C3414240EF1B5F7B664B4B401FBC7669C34142403562669FC74C4B40D120054F214542403562669FC74C4B40D120054F21454240EF1B5F7B664B4B401FBC7669C3414240EF1B5F7B664B4B40
20300	Дугна	1	6	1067	36.838185000000003	36.861730000000001	54.427315999999998	54.406883000000001	0103000020E61000000100000005000000B77F65A5496B42403126FDBD14344B40B77F65A5496B42405D876A4AB2364B40B5FD2B2B4D6E42405D876A4AB2364B40B5FD2B2B4D6E42403126FDBD14344B40B77F65A5496B42403126FDBD14344B40
20740	Бронцы	1	6	1067	36.772993999999997	36.791184999999999	54.467557999999997	54.457127999999997	0103000020E610000001000000050000008A00A777F1624240FE0A992B833A4B408A00A777F1624240D87DC7F0D83B4B40FA0AD28C45654240D87DC7F0D83B4B40FA0AD28C45654240FE0A992B833A4B408A00A777F1624240FE0A992B833A4B40
20279	Богданино	1	6	1067	36.844329999999999	36.870038999999998	54.414391999999999	54.388128999999999	0103000020E610000001000000050000000E846401136C424089D00836AE314B400E846401136C4240ADDC0BCC0A354B404D9F1D705D6F4240ADDC0BCC0A354B404D9F1D705D6F424089D00836AE314B400E846401136C424089D00836AE314B40
16482	Бебелево	1	6	1067	36.48415	36.516579	54.535545999999997	54.524949999999997	0103000020E61000000100000005000000E02D90A0F83D42408104C58F31434B40E02D90A0F83D424076C075C58C444B407366BB421F42424076C075C58C444B407366BB421F4242408104C58F31434B40E02D90A0F83D42408104C58F31434B40
22399	Авчурино	1	6	1067	36.413021000000001	36.448442	54.469425999999999	54.452528000000001	0103000020E61000000100000005000000D6C743DFDD3442401C430070EC394B40D6C743DFDD34424030F2B226163C4B409013268C6639424030F2B226163C4B409013268C663942401C430070EC394B40D6C743DFDD3442401C430070EC394B40
54181	Ульяново	1	6	1589	35.513430999999997	35.574992000000002	53.729159000000003	53.705815000000001	0103000020E6100000010000000500000054E0641BB8C141405C035B2558DA4A4054E0641BB8C14140C34A051555DD4A4017BB7D5699C94140C34A051555DD4A4017BB7D5699C941405C035B2558DA4A4054E0641BB8C141405C035B2558DA4A40
54217	Поздняково	1	6	1589	35.869621000000002	35.903945999999998	53.683396000000002	53.670724	0103000020E610000001000000050000001975ADBD4FEF41403752B648DAD54A401975ADBD4FEF4140CE1B278579D74A40CDACA580B4F34140CE1B278579D74A40CDACA580B4F341403752B648DAD54A401975ADBD4FEF41403752B648DAD54A40
48973	Новый Свет	1	6	1589	35.846643	35.851546999999997	53.689464999999998	53.683359000000003	0103000020E6100000010000000500000094313ECC5EEC4140B136C64E78D74A4094313ECC5EEC41404A5E9D6340D84A40E200FA7DFFEC41404A5E9D6340D84A40E200FA7DFFEC4140B136C64E78D74A4094313ECC5EEC4140B136C64E78D74A40
54220	Мелехово	1	6	1589	35.590128999999997	35.608293000000003	53.608798999999998	53.593153000000001	0103000020E61000000100000005000000E9B5D95889CB41401C430070ECCB4A40E9B5D95889CB4140336B2920EDCD4A4060B1868BDCCD4140336B2920EDCD4A4060B1868BDCCD41401C430070ECCB4A40E9B5D95889CB41401C430070ECCB4A40
54250	Заречье	1	6	1589	35.166798	36.085701999999998	53.910494999999997	53.50797	0103000020E61000000100000005000000E48409A359954140B0AC342905C14A40E48409A359954140F415A4198BF44A40D4997B48F80A4240F415A4198BF44A40D4997B48F80A4240B0AC342905C14A40E48409A359954140B0AC342905C14A40
54207	Дудоровский	1	6	1589	35.335231999999998	35.388322000000002	53.673476000000001	53.642707999999999	0103000020E610000001000000050000004D49D6E1E8AA41405470784144D24A404D49D6E1E8AA41400952297634D64A409E280989B4B141400952297634D64A409E280989B4B141405470784144D24A404D49D6E1E8AA41405470784144D24A40
60389	Долгое	1	6	1589	35.573770000000003	35.592086999999999	53.735418000000003	53.725194999999999	0103000020E6100000010000000500000085B69C4B71C94140821C9430D3DC4A4085B69C4B71C94140E371512D22DE4A4081B1BE81C9CB4140E371512D22DE4A4081B1BE81C9CB4140821C9430D3DC4A4085B69C4B71C94140821C9430D3DC4A40
23567	Вязовна	1	6	1589	35.352345	35.377363000000003	53.771523999999999	53.763263999999999	0103000020E610000001000000050000005EF415A419AD4140691B7FA2B2E14A405EF415A419AD4140200A664CC1E24A4038DC476E4DB04140200A664CC1E24A4038DC476E4DB04140691B7FA2B2E14A405EF415A419AD4140691B7FA2B2E14A40
54218	Волосово-Дудино	1	6	1589	35.587946000000002	35.608966000000002	53.834781999999997	53.824886999999997	0103000020E6100000010000000500000032E884D041CB4140A1F2AFE595E94A4032E884D041CB41400DA5F622DAEA4A401F300F99F2CD41400DA5F622DAEA4A401F300F99F2CD4140A1F2AFE595E94A4032E884D041CB4140A1F2AFE595E94A40
51921	Чуриково	1	6	7129	34.931125000000002	34.941958	56.915421000000002	56.910581000000001	0103000020E6100000010000000500000077BE9F1A2F774140F3AD0FEB8D744C4077BE9F1A2F7741402B89EC832C754C40501A6A14927841402B89EC832C754C40501A6A1492784140F3AD0FEB8D744C4077BE9F1A2F774140F3AD0FEB8D744C40
54176	Таруса	1	6	1547	37.144590999999998	37.198293	54.748764000000001	54.714115	0103000020E61000000100000005000000E12538F581924240A14ACD1E685B4B40E12538F5819242400936AE7FD75F4B404B033FAA619942400936AE7FD75F4B404B033FAA61994240A14ACD1E685B4B40E12538F581924240A14ACD1E685B4B40
54239	Роща	1	6	1547	36.828249999999997	36.853797999999998	54.785012999999999	54.773335000000003	0103000020E61000000100000005000000BC749318046A424014ED2AA4FC624B40BC749318046A4240A9F7544E7B644B40F2B1BB40496D4240A9F7544E7B644B40F2B1BB40496D424014ED2AA4FC624B40BC749318046A424014ED2AA4FC624B40
54238	Похвиснево	1	6	1547	37.072816000000003	37.100133999999997	54.743656000000001	54.733426000000001	0103000020E610000001000000050000001250E108528942409F0436E7E05D4B401250E10852894240B2BCAB1E305F4B40DC9BDF30D18C4240B2BCAB1E305F4B40DC9BDF30D18C42409F0436E7E05D4B401250E108528942409F0436E7E05D4B40
54236	Петрищево	1	6	1547	36.937646999999998	36.958083000000002	54.622289000000002	54.612231999999999	0103000020E61000000100000005000000A41820D10478424047C8409E5D4E4B40A41820D1047842408DD47B2AA74F4B4042EDB776A27A42408DD47B2AA74F4B4042EDB776A27A424047C8409E5D4E4B40A41820D10478424047C8409E5D4E4B40
54225	Некрасово	1	6	1547	37.127847000000003	37.14893	54.834553	54.823056000000001	0103000020E6100000010000000500000024F25D4A5D904240676325E659694B4024F25D4A5D904240ACE3F8A1D26A4B4057B2632310934240ACE3F8A1D26A4B4057B2632310934240676325E659694B4024F25D4A5D904240676325E659694B40
47812	Макарово	1	6	1547	37.050348999999997	37.060572000000001	54.59592	54.590161000000002	0103000020E61000000100000005000000723106D671864240F52F49658A4B4B40723106D6718642402384471B474C4B40D386C3D2C08742402384471B474C4B40D386C3D2C0874240F52F49658A4B4B40723106D671864240F52F49658A4B4B40
54214	Лопатино	1	6	1547	36.983936999999997	37.013527000000003	54.744653	54.730645000000003	0103000020E610000001000000050000008429CAA5F17D424033FE7DC6855D4B408429CAA5F17D424024EF1CCA505F4B40774EB340BB81424024EF1CCA505F4B40774EB340BB81424033FE7DC6855D4B408429CAA5F17D424033FE7DC6855D4B40
54213	Кузьмищево	1	6	1547	37.187423000000003	37.211641999999998	54.772010999999999	54.759596999999999	0103000020E6100000010000000500000055C2137AFD974240E29178793A614B4055C2137AFD9742407D93A641D1624B40E23AC615179B42407D93A641D1624B40E23AC615179B4240E29178793A614B4055C2137AFD974240E29178793A614B40
28356	Кочуково	1	6	1547	36.807983999999998	36.815125000000002	54.771070999999999	54.767471999999998	0103000020E610000001000000050000007BD80B056C674240404CC2853C624B407BD80B056C6742406FF25B74B2624B4075931804566842406FF25B74B2624B407593180456684240404CC2853C624B407BD80B056C674240404CC2853C624B40
54234	Волковское	1	6	1547	37.197583000000002	37.216169000000001	54.832588000000001	54.812446999999999	0103000020E610000001000000050000006F9F55664A994240DD5D6743FE674B406F9F55664A99424062855B3E926A4B405BB4006DAB9B424062855B3E926A4B405BB4006DAB9B4240DD5D6743FE674B406F9F55664A994240DD5D6743FE674B40
54242	Вознесение	1	6	1547	37.067534000000002	37.083362000000001	54.608921000000002	54.598517000000001	0103000020E610000001000000050000001DAF40F4A4884240CE8C7E349C4C4B401DAF40F4A48842407F6C921FF14D4B4055DD239BAB8A42407F6C921FF14D4B4055DD239BAB8A4240CE8C7E349C4C4B401DAF40F4A4884240CE8C7E349C4C4B40
54240	Барятино	1	6	1547	36.814784000000003	36.841194000000002	54.739216999999996	54.719996999999999	0103000020E61000000100000005000000ECA694D74A684240EB1B98DC285C4B40ECA694D74A684240D8D2A3A99E5E4B40B4CBB73EAC6B4240D8D2A3A99E5E4B40B4CBB73EAC6B4240EB1B98DC285C4B40ECA694D74A684240EB1B98DC285C4B40
54241	Алекино	1	6	1547	37.166052000000001	37.182788000000002	54.668087	54.657724999999999	0103000020E61000000100000005000000BBB72231419542407C61325530544B40BBB7223141954240FEF0F3DF83554B40F60CE19865974240FEF0F3DF83554B40F60CE198659742407C61325530544B40BBB72231419542407C61325530544B40
48733	Юрьево	1	6	1456	35.475943999999998	35.498005999999997	54.180103000000003	54.169252	0103000020E610000001000000050000001C5DA5BBEBBC41402C64AE0CAA154B401C5DA5BBEBBC4140AC74779D0D174B401B9B1DA9BEBF4140AC74779D0D174B401B9B1DA9BEBF41402C64AE0CAA154B401C5DA5BBEBBC41402C64AE0CAA154B40
40253	Шлипово	1	6	1456	35.109484999999999	35.129958000000002	54.174275000000002	54.165584000000003	0103000020E610000001000000050000008733BF9A038E4140D55E44DB31154B408733BF9A038E414055C1A8A44E164B4042EDB776A290414055C1A8A44E164B4042EDB776A2904140D55E44DB31154B408733BF9A038E4140D55E44DB31154B40
17684	Хотень	1	6	1456	35.440137	35.462181999999999	54.152239999999999	54.137161999999996	0103000020E610000001000000050000003961C26856B84140812040868E114B403961C26856B841404F92AE997C134B4062669FC728BB41404F92AE997C134B4062669FC728BB4140812040868E114B403961C26856B84140812040868E114B40
40455	Уруга	1	6	1456	34.999988999999999	35.021656999999998	54.140168000000003	54.131301000000001	0103000020E610000001000000050000000CAEB9A3FF7F41404F779E78CE104B400CAEB9A3FF7F41400EF96706F1114B405F5D15A8C58241400EF96706F1114B405F5D15A8C58241404F779E78CE104B400CAEB9A3FF7F41404F779E78CE104B40
17941	Татаринцы	1	6	1456	35.396208999999999	35.421855999999998	54.090938000000001	54.076042999999999	0103000020E61000000100000005000000C0B0FCF9B6B241407C0BEBC6BB094B40C0B0FCF9B6B2414059FB3BDBA30B4B4089CF9D60FFB5414059FB3BDBA30B4B4089CF9D60FFB541407C0BEBC6BB094B40C0B0FCF9B6B241407C0BEBC6BB094B40
17092	Сухиничи	1	6	1456	35.312216999999997	35.362594000000001	54.131247999999999	54.077517	0103000020E61000000100000005000000AB2006BAF6A7414028F1B913EC094B40AB2006BAF6A741402CD505BCCC104B40E8DCED7A69AE41402CD505BCCC104B40E8DCED7A69AE414028F1B913EC094B40AB2006BAF6A7414028F1B913EC094B40
48621	Субботники	1	6	1456	35.423824000000003	35.442022999999999	53.988421000000002	53.975977999999998	0103000020E6100000010000000500000045A165DD3FB64140C8CEDBD8ECFC4A4045A165DD3FB64140FED64E9484FE4A40378AAC3594B84140FED64E9484FE4A40378AAC3594B84140C8CEDBD8ECFC4A4045A165DD3FB64140C8CEDBD8ECFC4A40
48590	Соболевка	1	6	1456	34.899872000000002	34.922519000000001	54.243693	54.222842999999997	0103000020E61000000100000005000000064B75012F7341403E92921E861C4B40064B75012F734140CFA10C55311F4B402578431A15764140CFA10C55311F4B402578431A157641403E92921E861C4B40064B75012F7341403E92921E861C4B40
17250	Середейский	1	6	1456	35.224451000000002	35.241222999999998	54.055968999999997	54.045904999999998	0103000020E61000000100000005000000FA4674CFBA9C414087DC0C37E0054B40FA4674CFBA9C41407F4B00FE29074B4081053065E09E41407F4B00FE29074B4081053065E09E414087DC0C37E0054B40FA4674CFBA9C414087DC0C37E0054B40
17775	Радождево	1	6	1456	35.301535999999999	35.321389000000003	54.030448999999997	54.014997999999999	0103000020E6100000010000000500000088484DBB98A64140B1C05774EB014B4088484DBB98A641401399B9C0E5034B40A725564623A941401399B9C0E5034B40A725564623A94140B1C05774EB014B4088484DBB98A64140B1C05774EB014B40
54219	Ермолово	1	6	1456	35.233829999999998	35.248184999999999	54.067379000000003	54.056708999999998	0103000020E610000001000000050000006E693524EE9D4140C631923D42074B406E693524EE9D4140F6B704E09F084B40CB2DAD86C49F4140F6B704E09F084B40CB2DAD86C49F4140C631923D42074B406E693524EE9D4140C631923D42074B40
17572	Дабужа	1	6	1456	34.739064999999997	34.834107000000003	54.234085	54.215229999999998	0103000020E61000000100000005000000224F92AE995E41401D8F19A88C1B4B40224F92AE995E4140F9BD4D7FF61D4B40AE2EA704C46A4140F9BD4D7FF61D4B40AE2EA704C46A41401D8F19A88C1B4B40224F92AE995E41401D8F19A88C1B4B40
48473	Глазково	1	6	1456	35.369394999999997	35.390765999999999	54.179634	54.169569000000003	0103000020E610000001000000050000002827DA5548AF41402DB5DE6FB4154B402827DA5548AF4140F59F353FFE164B40C231CB9E04B24140F59F353FFE164B40C231CB9E04B241402DB5DE6FB4154B402827DA5548AF41402DB5DE6FB4154B40
48656	Володино	1	6	1456	35.074361000000003	35.095516000000003	54.223784999999999	54.208322000000003	0103000020E61000000100000005000000878C47A984894140C784984BAA1A4B40878C47A984894140ED2AA4FCA41C4B40541F48DE398C4140ED2AA4FCA41C4B40541F48DE398C4140C784984BAA1A4B40878C47A984894140C784984BAA1A4B40
17758	Брынь	1	6	1456	35.163105999999999	35.189686999999999	54.092875999999997	54.083227000000001	0103000020E6100000010000000500000004E44BA8E09441407592AD2EA70A4B4004E44BA8E0944140A94A5B5CE30B4B40F9BCE2A947984140A94A5B5CE30B4B40F9BCE2A9479841407592AD2EA70A4B4004E44BA8E09441407592AD2EA70A4B40
48423	Бордуково	1	6	1456	35.303845000000003	35.317607000000002	54.118642000000001	54.113613000000001	0103000020E61000000100000005000000CD069964E4A6414042B3EBDE8A0E4B40CD069964E4A641404DF73AA92F0F4B4087FD9E58A7A841404DF73AA92F0F4B4087FD9E58A7A8414042B3EBDE8A0E4B40CD069964E4A6414042B3EBDE8A0E4B40
17647	Богданово-Колодези	1	6	1456	35.386822000000002	35.400485000000003	53.908644000000002	53.900337	0103000020E61000000100000005000000C9AF1F6283B141407B30293E3EF34A40C9AF1F6283B1414073DA53724EF44A40F0C4AC1743B3414073DA53724EF44A40F0C4AC1743B341407B30293E3EF34A40C9AF1F6283B141407B30293E3EF34A40
17271	Алнеры	1	6	1456	35.315055999999998	35.322997000000001	54.147578000000003	54.138590999999998	0103000020E610000001000000050000004C3448C153A841408D429259BD114B404C3448C153A84140F7CDFDD5E3124B4062DA37F757A94140F7CDFDD5E3124B4062DA37F757A941408D429259BD114B404C3448C153A841408D429259BD114B40
17044	Чипляево	1	6	1441	34.183824999999999	34.207917999999999	54.395966000000001	54.380195999999998	0103000020E61000000100000005000000F697DD9387174140F6083543AA304B40F697DD9387174140FA298E03AF324B40F71F990E9D1A4140FA298E03AF324B40F71F990E9D1A4140F6083543AA304B40F697DD9387174140F6083543AA304B40
46366	Терпилово	1	6	1441	33.737577999999999	33.744351000000002	54.385413	54.380574000000003	0103000020E61000000100000005000000E21FB6F468DE40409DDA19A6B6304B40E21FB6F468DE4040043A933655314B4059DFC0E446DF4040043A933655314B4059DFC0E446DF40409DDA19A6B6304B40E21FB6F468DE40409DDA19A6B6304B40
48200	Теплово	1	6	1441	34.069380000000002	34.085028000000001	54.422628000000003	54.410688	0103000020E610000001000000050000008D7F9F71E1084140096EA46C91344B408D7F9F71E1084140DC2F9FAC18364B40459F8F32E20A4140DC2F9FAC18364B40459F8F32E20A4140096EA46C91344B408D7F9F71E1084140096EA46C91344B40
45416	Стайки	1	6	1441	34.181229000000002	34.198152999999998	54.306049999999999	54.285840999999998	0103000020E610000001000000050000001C0B0A83321741408F6D197096244B401C0B0A83321741406C787AA52C274B40594DD7135D1941406C787AA52C274B40594DD7135D1941408F6D197096244B401C0B0A83321741408F6D197096244B40
16847	Снопот	1	6	1441	33.752246999999997	33.768507	54.360968	54.352311	0103000020E61000000100000005000000CEC133A149E04040B282DF86182D4B40CEC133A149E0404086730D33342E4B40A0DFF76F5EE2404086730D33342E4B40A0DFF76F5EE24040B282DF86182D4B40CEC133A149E04040B282DF86182D4B40
48153	Понизовье	1	6	1441	34.054962000000003	34.073512000000001	54.273009000000002	54.255808000000002	0103000020E61000000100000005000000EA42ACFE0807414010070951BE204B40EA42ACFE08074140C0417BF5F1224B4089EE59D768094140C0417BF5F1224B4089EE59D76809414010070951BE204B40EA42ACFE0807414010070951BE204B40
16693	Павлиново	1	6	1441	33.740614000000001	33.773986999999998	54.488461999999998	54.472911000000003	0103000020E61000000100000005000000D97A8670CCDE40409775FF58883C4B40D97A8670CCDE40405CAB3DEC853E4B40BB438A0112E340405CAB3DEC853E4B40BB438A0112E340409775FF58883C4B40D97A8670CCDE40409775FF58883C4B40
54252	Новоалександровский	1	6	1441	34.059040000000003	34.088845999999997	54.350715000000001	54.336854000000002	0103000020E61000000100000005000000F3936A9F8E0741406EC328081E2B4B40F3936A9F8E074140BB9BA73AE42C4B40B130444E5F0B4140BB9BA73AE42C4B40B130444E5F0B41406EC328081E2B4B40F3936A9F8E0741406EC328081E2B4B40
16535	Нестеры	1	6	1441	33.685718000000001	33.699615000000001	54.428274000000002	54.418928999999999	0103000020E61000000100000005000000A723809BC5D74040492C29779F354B40A723809BC5D7404012DDB3AED1364B404165FCFB8CD9404012DDB3AED1364B404165FCFB8CD94040492C29779F354B40A723809BC5D74040492C29779F354B40
16335	Любунь	1	6	1441	33.831066	33.856614	54.340029999999999	54.322642000000002	0103000020E61000000100000005000000A568E55E60EA4040742843554C294B40A568E55E60EA404056D4601A862B4B40DBA50D87A5ED404056D4601A862B4B40DBA50D87A5ED4040742843554C294B40A568E55E60EA4040742843554C294B40
16985	Буднянский	1	6	1441	33.937480000000001	33.953775999999998	54.313687000000002	54.302005000000001	0103000020E61000000100000005000000B9533A58FFF740403F1D8F19A8264B40B9533A58FFF74040161747E526284B40D7DAFB5415FA4040161747E526284B40D7DAFB5415FA40403F1D8F19A8264B40B9533A58FFF740403F1D8F19A8264B40
16268	Болва	1	6	1441	33.951081000000002	33.972684999999998	54.405242999999999	54.395741000000001	0103000020E610000001000000050000006A6CAF05BDF94040DA571EA4A7324B406A6CAF05BDF940406AF7AB00DF334B40A6272CF180FC40406AF7AB00DF334B40A6272CF180FC4040DA571EA4A7324B406A6CAF05BDF94040DA571EA4A7324B40
16030	Сильково	1	6	1412	36.061933000000003	36.085549999999998	54.353921	54.343316000000002	0103000020E6100000010000000500000087C5A86BED074240C61858C7F12B4B4087C5A86BED0742400E2F88484D2D4B401E166A4DF30A42400E2F88484D2D4B401E166A4DF30A4240C61858C7F12B4B4087C5A86BED074240C61858C7F12B4B40
15835	Перемышль	1	6	1412	36.148836000000003	36.174483000000002	54.273335000000003	54.253925000000002	0103000020E61000000100000005000000D63BDC0E0D1342408351499D80204B40D63BDC0E0D13424014ED2AA4FC224B409F5A7D755516424014ED2AA4FC224B409F5A7D75551642408351499D80204B40D63BDC0E0D1342408351499D80204B40
15687	Корекозево	1	6	1412	36.174528000000002	36.197209999999998	54.347042000000002	54.309821999999997	0103000020E610000001000000050000003F1EFAEE5616424068CA4E3FA8274B403F1EFAEE56164240522B4CDF6B2C4B40DA38622D3E194240522B4CDF6B2C4B40DA38622D3E19424068CA4E3FA8274B403F1EFAEE5616424068CA4E3FA8274B40
54199	Калужской опытной сельскохозяйственой станции	1	6	1412	36.078085000000002	36.101531000000001	54.424309000000001	54.414324000000001	0103000020E6100000010000000500000072A774B0FE09424055F99E9108354B4072A774B0FE0942400133DFC14F364B40DD43C2F7FE0C42400133DFC14F364B40DD43C2F7FE0C424055F99E9108354B4072A774B0FE09424055F99E9108354B40
16222	Григоровское	1	6	1412	36.335478999999999	36.357298999999998	54.292929999999998	54.279643999999998	0103000020E6100000010000000500000055BFD2F9F02A4240E542E55FCB234B4055BFD2F9F02A42403602F1BA7E254B405EF23FF9BB2D42403602F1BA7E254B405EF23FF9BB2D4240E542E55FCB234B4055BFD2F9F02A4240E542E55FCB234B40
47743	Гремячево	1	6	1412	36.232056	36.271608999999998	54.247501999999997	54.235064000000001	0103000020E61000000100000005000000986BD102B41D4240C53BC093161E4B40986BD102B41D4240E8D84125AE1F4B404E266E15C4224240E8D84125AE1F4B404E266E15C4224240C53BC093161E4B40986BD102B41D4240C53BC093161E4B40
16167	Борищево	1	6	1412	35.999464000000003	36.021706000000002	54.386011000000003	54.366796000000001	0103000020E61000000100000005000000C2C3B46FEEFF4140DD26DC2BF32E4B40C2C3B46FEEFF4140B972F6CE68314B4041102043C7024240B972F6CE68314B4041102043C7024240DD26DC2BF32E4B40C2C3B46FEEFF4140DD26DC2BF32E4B40
15649	Большие Козлы	1	6	1412	36.317036000000002	36.336485000000003	54.429746000000002	54.403556000000002	0103000020E61000000100000005000000CCD3B9A294284240630D17B9A7334B40CCD3B9A2942842401DCBBBEA01374B401B4CC3F0112B42401DCBBBEA01374B401B4CC3F0112B4240630D17B9A7334B40CCD3B9A294284240630D17B9A7334B40
47960	Ахлебинино	1	6	1412	36.427233000000001	36.468834000000001	54.446246000000002	54.437291999999999	0103000020E61000000100000005000000D0622992AF364240B6662B2FF9374B40D0622992AF36424044FCC3961E394B405EA0A4C0023C424044FCC3961E394B405EA0A4C0023C4240B6662B2FF9374B40D0622992AF364240B6662B2FF9374B40
52455	Михали	1	6	7188	29.949742000000001	29.956164999999999	56.373275	56.370583000000003	0103000020E610000001000000050000003CA3AD4A22F33D400FBA84436F2F4C403CA3AD4A22F33D400BB5A679C72F4C407094BC3AC7F43D400BB5A679C72F4C407094BC3AC7F43D400FBA84436F2F4C403CA3AD4A22F33D400FBA84436F2F4C40
12873	Шаховский	1	6	1252	34.816419000000003	34.833765	54.638466000000001	54.629497000000001	0103000020E61000000100000005000000A16AF46A806841400EF7915B93504B40A16AF46A80684140D1CDFE40B9514B4054C6BFCFB86A4140D1CDFE40B9514B4054C6BFCFB86A41400EF7915B93504B40A16AF46A806841400EF7915B93504B40
13740	Устоша	1	6	1252	34.908118999999999	34.927855000000001	54.461210999999999	54.451554000000002	0103000020E6100000010000000500000028F04E3E3D74414062307F85CC394B4028F04E3E3D74414019C748F6083B4B400D37E0F3C376414019C748F6083B4B400D37E0F3C376414062307F85CC394B4028F04E3E3D74414062307F85CC394B40
46809	Тарасково	1	6	1252	35.043323999999998	35.060141000000002	54.483576999999997	54.476928999999998	0103000020E61000000100000005000000E2900DA48B854140CAC16C020C3D4B40E2900DA48B854140840CE4D9E53D4B400A1346B3B2874140840CE4D9E53D4B400A1346B3B2874140CAC16C020C3D4B40E2900DA48B854140CAC16C020C3D4B40
54243	Раменский	1	6	1252	34.886235999999997	34.907912000000003	54.596060999999999	54.582751999999999	0103000020E61000000100000005000000D844662E70714140DCD6169E974A4B40D844662E70714140E5B512BA4B4C4B40AFD2DD7536744140E5B512BA4B4C4B40AFD2DD7536744140DCD6169E974A4B40D844662E70714140DCD6169E974A4B40
13373	Рамено	1	6	1252	34.788975000000001	34.810372999999998	54.623091000000002	54.609530999999997	0103000020E61000000100000005000000492EFF21FD644140F7729F1C054E4B40492EFF21FD6441404AB72572C14F4B40DC476E4DBA6741404AB72572C14F4B40DC476E4DBA674140F7729F1C054E4B40492EFF21FD644140F7729F1C054E4B40
13180	Путогино	1	6	1252	35.075035	35.092013000000001	54.550362999999997	54.543678	0103000020E61000000100000005000000168733BF9A89414000C79E3D97454B40168733BF9A894140D7F6764B72464B4047E7FC14C78B4140D7F6764B72464B4047E7FC14C78B414000C79E3D97454B40168733BF9A89414000C79E3D97454B40
13033	Посконь	1	6	1252	34.736522999999998	34.760587999999998	54.479334999999999	54.471927000000001	0103000020E610000001000000050000003BE0BA62465E4140B98C9B1A683C4B403BE0BA62465E4140016A6AD95A3D4B4072DD94F25A614140016A6AD95A3D4B4072DD94F25A614140B98C9B1A683C4B403BE0BA62465E4140B98C9B1A683C4B40
46704	Передовик	1	6	1252	34.954659999999997	34.972914000000003	54.573709000000001	54.563279999999999	0103000020E610000001000000050000005166834C327A4140D53E1D8F19484B405166834C327A4140DF35E84B6F494B4008E92972887C4140DF35E84B6F494B4008E92972887C4140D53E1D8F19484B405166834C327A4140D53E1D8F19484B40
13454	Мосальск	1	6	1252	34.9544	34.994644000000001	54.504306	54.474601	0103000020E61000000100000005000000B5A679C7297A41400FD3BEB9BF3C4B40B5A679C7297A41409A9658198D404B40D1949D7E507F41409A9658198D404B40D1949D7E507F41400FD3BEB9BF3C4B40B5A679C7297A41400FD3BEB9BF3C4B40
12994	Людково	1	6	1252	34.707847999999998	34.731375	54.607987999999999	54.597405999999999	0103000020E61000000100000005000000FE4465C39A5A41409337C0CC774C4B40FE4465C39A5A4140232E008DD24D4B40560E2DB29D5D4140232E008DD24D4B40560E2DB29D5D41409337C0CC774C4B40FE4465C39A5A41409337C0CC774C4B40
40420	Каменка	1	6	1252	34.896827000000002	34.908819000000001	54.437396999999997	54.431485000000002	0103000020E61000000100000005000000BC95253ACB72414077DB85E63A374B40BC95253ACB7241402B2FF99FFC374B40E17D552E547441402B2FF99FFC374B40E17D552E5474414077DB85E63A374B40BC95253ACB72414077DB85E63A374B40
54249	Калуговский	1	6	1252	34.435937000000003	35.300997000000002	54.758485	54.353098000000003	0103000020E61000000100000005000000E50E9BC8CC3741403A24B550322D4B40E50E9BC8CC374140D7C0560916614B40D998D71187A64140D7C0560916614B40D998D71187A641403A24B550322D4B40E50E9BC8CC3741403A24B550322D4B40
46975	Дашино	1	6	1252	34.835158	34.856034000000001	54.434711	54.424739000000002	0103000020E61000000100000005000000137F1475E66A4140FA2AF9D85D364B40137F1475E66A4140111B2C9CA4374B40CD21A985926D4140111B2C9CA4374B40CD21A985926D4140FA2AF9D85D364B40137F1475E66A4140FA2AF9D85D364B40
46958	Горбачи	1	6	1252	35.155182000000003	35.16845	54.536585000000002	54.523999000000003	0103000020E61000000100000005000000C576F700DD9341408011346612434B40C576F700DD934140184339D1AE444B406F8104C58F954140184339D1AE444B406F8104C58F9541408011346612434B40C576F700DD9341408011346612434B40
46929	Гачки	1	6	1252	34.981439000000002	34.993180000000002	54.507525999999999	54.501409000000002	0103000020E610000001000000050000006D020CCB9F7D4140C5758C2B2E404B406D020CCB9F7D414052EFA99CF6404B404985B185207F414052EFA99CF6404B404985B185207F4140C5758C2B2E404B406D020CCB9F7D4140C5758C2B2E404B40
46061	Высокое	1	6	1252	34.962673000000002	34.981161	54.537782	54.529642000000003	0103000020E6100000010000000500000001DF6DDE387B4140454B1E4FCB434B4001DF6DDE387B41405130630AD6444B402A8E03AF967D41405130630AD6444B402A8E03AF967D4140454B1E4FCB434B4001DF6DDE387B4140454B1E4FCB434B40
13413	Боровенск	1	6	1252	35.140754999999999	35.167301000000002	54.485726999999997	54.478734000000003	0103000020E61000000100000005000000CEDF844204924140DCBDDC27473D4B40CEDF84420492414060E4654D2C3E4B4047CB811E6A95414060E4654D2C3E4B4047CB811E6A954140DCBDDC27473D4B40CEDF844204924140DCBDDC27473D4B40
12205	Торкотино	1	6	1215	35.416206000000003	35.439903000000001	54.384092000000003	54.371695000000003	0103000020E610000001000000050000001233FB3C46B541401A8BA6B3932F4B401233FB3C46B54140DF5339ED29314B40C634D3BD4EB84140DF5339ED29314B40C634D3BD4EB841401A8BA6B3932F4B401233FB3C46B541401A8BA6B3932F4B40
12283	Серпейск	1	6	1215	34.972079000000001	35.005549999999999	54.345289000000001	54.327336000000003	0103000020E610000001000000050000006F10AD156D7C4140D8666325E6294B406F10AD156D7C41409355116E322C4B40143FC6DCB58041409355116E322C4B40143FC6DCB5804140D8666325E6294B406F10AD156D7C4140D8666325E6294B40
12704	Серебряно	1	6	1215	35.229832000000002	35.250781000000003	54.350431999999998	54.336984999999999	0103000020E6100000010000000500000082C98D226B9D41400C1F1153222B4B4082C98D226B9D414066BCADF4DA2C4B40A6BA809719A0414066BCADF4DA2C4B40A6BA809719A041400C1F1153222B4B4082C98D226B9D41400C1F1153222B4B40
46483	Растворово	1	6	1215	35.181547999999999	35.202720999999997	54.321401999999999	54.307431000000001	0103000020E61000000100000005000000BD5301F73C974140676325E659274B40BD5301F73C9741403B6F63B323294B40309B00C3F29941403B6F63B323294B40309B00C3F2994140676325E659274B40BD5301F73C974140676325E659274B40
12034	Поповка	1	6	1215	35.517347000000001	35.544035999999998	54.253010000000003	54.243124999999999	0103000020E6100000010000000500000084D72E6D38C2414085EB51B81E1F4B4084D72E6D38C24140CEC7B5A162204B405FECBDF8A2C54140CEC7B5A162204B405FECBDF8A2C5414085EB51B81E1F4B4084D72E6D38C2414085EB51B81E1F4B40
46603	Подкопаево	1	6	1215	35.410195999999999	35.433650999999998	54.480355000000003	54.468139000000001	0103000020E610000001000000050000009A79724D81B44140B77D8FFAEB3B4B409A79724D81B441402CBCCB457C3D4B4058703FE081B741402CBCCB457C3D4B4058703FE081B74140B77D8FFAEB3B4B409A79724D81B44140B77D8FFAEB3B4B40
46514	Нестеровка	1	6	1215	35.380676999999999	35.396641000000002	54.312359000000001	54.303192000000003	0103000020E6100000010000000500000071AB2006BAB041405534D6FECE264B4071AB2006BAB041403ECE3461FB274B405AA0DD21C5B241403ECE3461FB274B405AA0DD21C5B241405534D6FECE264B4071AB2006BAB041405534D6FECE264B40
12087	Мошонки	1	6	1215	35.610691000000003	35.636499999999998	54.290266000000003	54.274833000000001	0103000020E61000000100000005000000147B681F2BCE4140486E4DBA2D234B40147B681F2BCE41400492B06F27254B40B6F3FDD478D141400492B06F27254B40B6F3FDD478D14140486E4DBA2D234B40147B681F2BCE4140486E4DBA2D234B40
12501	Мещовск	1	6	1215	35.261353999999997	35.295471999999997	54.329867	54.308276999999997	0103000020E61000000100000005000000E256410C74A14140F38DE89E75274B40E256410C74A14140CB83F414392A4B401D71C806D2A54140CB83F414392A4B401D71C806D2A54140F38DE89E75274B40E256410C74A14140F38DE89E75274B40
46280	Мармыжи	1	6	1215	35.500844999999998	35.523311999999997	54.383405000000003	54.370120999999997	0103000020E61000000100000005000000BCAE5FB01BC041400A48FB1F602F4B40BCAE5FB01BC04140BB0F406A13314B405BCD3AE3FBC24140BB0F406A13314B405BCD3AE3FBC241400A48FB1F602F4B40BCAE5FB01BC041400A48FB1F602F4B40
46382	Казаковка	1	6	1215	35.173921	35.190162999999998	54.234459000000001	54.221499999999999	0103000020E61000000100000005000000378B170B439641403108AC1C5A1C4B40378B170B439641405EA0A4C0021E4B4062F4DC42579841405EA0A4C0021E4B4062F4DC42579841403108AC1C5A1C4B40378B170B439641403108AC1C5A1C4B40
46572	Гаврики	1	6	1215	35.326985000000001	35.347000000000001	54.446513000000003	54.429442000000002	0103000020E610000001000000050000002BA4FCA4DAA94140B1C398F4F7364B402BA4FCA4DAA94140931E865627394B4023DBF97E6AAC4140931E865627394B4023DBF97E6AAC4140B1C398F4F7364B402BA4FCA4DAA94140B1C398F4F7364B40
46539	Большое Алешино	1	6	1215	35.284719000000003	35.295211999999999	54.383232	54.375675999999999	0103000020E6100000010000000500000061C614AC71A4414030F2B22616304B4061C614AC71A44140ED6305BF0D314B4081B1BE81C9A54140ED6305BF0D314B4081B1BE81C9A5414030F2B22616304B4061C614AC71A4414030F2B22616304B40
45666	Хвощи	1	6	1049	35.839196000000001	35.850478000000003	55.067798000000003	55.061869000000002	0103000020E610000001000000050000008E7747C66AEB414070D1C952EB874B408E7747C66AEB4140FB5DD89AAD884B40D7FB8D76DCEC4140FB5DD89AAD884B40D7FB8D76DCEC414070D1C952EB874B408E7747C66AEB414070D1C952EB874B40
49183	Романово	1	6	1049	35.740676999999998	35.757862000000003	54.977888	54.968018999999998	0103000020E610000001000000050000001FF30181CEDE41400C74ED0BE87B4B401FF30181CEDE41404F93196F2B7D4B40CA703C9F01E141404F93196F2B7D4B40CA703C9F01E141400C74ED0BE87B4B401FF30181CEDE41400C74ED0BE87B4B40
48304	Редькино	1	6	1049	36.064520000000002	36.070467000000001	55.040481999999997	55.037964000000002	0103000020E610000001000000050000000EF8FC304208424072361D01DC844B400EF8FC3042084240D009A1832E854B403F390A1005094240D009A1832E854B403F390A100509424072361D01DC844B400EF8FC304208424072361D01DC844B40
49482	Передел	1	6	1049	35.667599000000003	35.700577000000003	55.207222999999999	55.197862000000001	0103000020E61000000100000005000000D1EB4FE273D54140828FC18A53994B40D1EB4FE273D5414050FD8348869A4B4037AAD381ACD9414050FD8348869A4B4037AAD381ACD94140828FC18A53994B40D1EB4FE273D54140828FC18A53994B40
40292	Обухово	1	6	1049	35.716782000000002	35.731461000000003	55.000616000000001	54.995555000000003	0103000020E61000000100000005000000452E3883BFDB4140452FA3586E7F4B40452E3883BFDB41405BED612F14804B4055A69883A0DD41405BED612F14804B4055A69883A0DD4140452FA3586E7F4B40452E3883BFDB4140452FA3586E7F4B40
47783	Никитское	1	6	1049	35.753694000000003	35.87856	55.225634999999997	55.204155999999998	0103000020E610000001000000050000008198840B79E041401EA4A7C8219A4B408198840B79E041409EEA909BE19C4B4071C971A774F041409EEA909BE19C4B4071C971A774F041401EA4A7C8219A4B408198840B79E041401EA4A7C8219A4B40
11861	Михальчуково	1	6	1049	35.729314000000002	35.746777000000002	54.950809999999997	54.943266000000001	0103000020E61000000100000005000000EA4141295ADD4140E1B6B6F0BC784B40EA4141295ADD4140D95A5F24B4794B40D733846396DF4140D95A5F24B4794B40D733846396DF4140E1B6B6F0BC784B40EA4141295ADD4140E1B6B6F0BC784B40
11707	Медынь	1	6	1049	35.833041999999999	35.903596	54.982982999999997	54.950785000000003	0103000020E61000000100000005000000E318C91EA1EA41408143A852B3794B40E318C91EA1EA414011C30E63D27D4B40F165A208A9F3414011C30E63D27D4B40F165A208A9F341408143A852B3794B40E318C91EA1EA41408143A852B3794B40
11835	Кременское	1	6	1049	35.941369999999999	35.970942000000001	55.118817	55.095322000000003	0103000020E61000000100000005000000BFB7E9CF7EF841406F4BE482338C4B40BFB7E9CF7EF84140BB9A3C65358F4B400B28D4D347FC4140BB9A3C65358F4B400B28D4D347FC41406F4BE482338C4B40BFB7E9CF7EF841406F4BE482338C4B40
46040	Гусево	1	6	1049	35.658256999999999	35.681730000000002	55.067895999999998	55.051220999999998	0103000020E6100000010000000500000079AEEFC341D4414028EFE3688E864B4079AEEFC341D44140BDC3EDD0B0884B40DE59BBED42D74140BDC3EDD0B0884B40DE59BBED42D7414028EFE3688E864B4079AEEFC341D4414028EFE3688E864B40
54224	Глухово	1	6	1049	36.029027999999997	36.050964	55.057259999999999	55.045949999999998	0103000020E610000001000000050000008A558330B703424027A089B0E1854B408A558330B70342403AAFB14B54874B40FDA204FD850642403AAFB14B54874B40FDA204FD8506424027A089B0E1854B408A558330B703424027A089B0E1854B40
46099	Варваровка	1	6	1049	35.865741	35.882278999999997	55.023898000000003	55.012920000000001	0103000020E6100000010000000500000036E7E099D0EE41406FBBD05CA7814B4036E7E099D0EE41404C38F4160F834B404A79AD84EEF041404C38F4160F834B404A79AD84EEF041406FBBD05CA7814B4036E7E099D0EE41406FBBD05CA7814B40
47124	Брюхово	1	6	1049	35.891782999999997	35.905634999999997	55.197512000000003	55.184756999999998	0103000020E610000001000000050000007B1002F225F24140815A0C1EA6974B407B1002F225F24140A648BE1248994B40758E01D9EBF34140A648BE1248994B40758E01D9EBF34140815A0C1EA6974B407B1002F225F24140815A0C1EA6974B40
9192	Адуево	1	6	1049	35.972532000000001	36.002580999999999	54.992440999999999	54.978988999999999	0103000020E610000001000000050000002028B7ED7BFC41406612F5824F7D4B402028B7ED7BFC4140D21A834E087F4B40A54BFF9254004240D21A834E087F4B40A54BFF92540042406612F5824F7D4B402028B7ED7BFC41406612F5824F7D4B40
45496	Юбилейный	1	6	1120	36.274977	36.286754000000002	54.770358999999999	54.762411999999998	0103000020E610000001000000050000007B13437232234240FA0967B796614B407B13437232234240F296AB1F9B624B40A4FFE55AB4244240F296AB1F9B624B40A4FFE55AB4244240FA0967B796614B407B13437232234240FA0967B796614B40
45508	Шумятино	1	6	1120	36.330807999999998	36.347067000000003	54.996561999999997	54.987043	0103000020E61000000100000005000000A9A0A2EA572A4240745FCE6C577E4B40A9A0A2EA572A4240DA37F7578F7F4B40AB4203B16C2C4240DA37F7578F7F4B40AB4203B16C2C4240745FCE6C577E4B40A9A0A2EA572A4240745FCE6C577E4B40
60392	Село Головтеево	1	6	1120	35.970601000000002	36.739820000000002	55.099572000000002	54.692489000000002	0103000020E61000000100000005000000823B50A73CFC41407DEBC37AA3584B40823B50A73CFC414075CC79C6BE8C4B409F76F86BB25E424075CC79C6BE8C4B409F76F86BB25E42407DEBC37AA3584B40823B50A73CFC41407DEBC37AA3584B40
45478	Рябцево	1	6	1120	36.178938000000002	36.207846000000004	54.856941999999997	54.845415000000003	0103000020E610000001000000050000007E01BD70E71642402046088F366C4B407E01BD70E7164240CF488446B06D4B405E4D9EB29A1A4240CF488446B06D4B405E4D9EB29A1A42402046088F366C4B407E01BD70E71642402046088F366C4B40
45443	Поречье	1	6	1120	36.561790999999999	36.575482000000001	54.877133000000001	54.866776999999999	0103000020E61000000100000005000000F4177AC4E847424066F6798CF26E4B40F4177AC4E8474240069FE6E445704B40E5B7E864A9494240069FE6E445704B40E5B7E864A949424066F6798CF26E4B40F4177AC4E847424066F6798CF26E4B40
45530	Панское	1	6	1120	36.376396999999997	36.401954000000003	55.037737	55.028770000000002	0103000020E6100000010000000500000000A8E2C62D3042408F8D40BCAE834B4000A8E2C62D304240B16CE690D4844B408A3F8A3A73334240B16CE690D4844B408A3F8A3A733342408F8D40BCAE834B4000A8E2C62D3042408F8D40BCAE834B40
10160	Недельное	1	6	1120	36.633584999999997	36.660066999999998	54.843440000000001	54.832872999999999	0103000020E610000001000000050000003A1E335019514240575C1C959B6A4B403A1E335019514240B21188D7F56B4B409C1551137D544240B21188D7F56B4B409C1551137D544240575C1C959B6A4B403A1E335019514240575C1C959B6A4B40
45412	Михеево	1	6	1120	36.324447999999997	36.338676999999997	54.844071999999997	54.831150999999998	0103000020E6100000010000000500000055A0168387294240D384ED27636A4B4055A016838729424012BC218D0A6C4B40257497C4592B424012BC218D0A6C4B40257497C4592B4240D384ED27636A4B4055A0168387294240D384ED27636A4B40
45883	Ерденево	1	6	1120	36.384445999999997	36.471465999999999	54.930905000000003	54.913401	0103000020E61000000100000005000000FC89CA86353142401D91EF52EA744B40FC89CA8635314240695721E527774B40859675FF583C4240695721E527774B40859675FF583C42401D91EF52EA744B40FC89CA86353142401D91EF52EA744B40
10558	Детчино	1	6	1120	36.288756999999997	36.321931999999997	54.823760999999998	54.798670000000001	0103000020E61000000100000005000000DBBE47FDF5244240EE258DD13A664B40DBBE47FDF5244240315C1D0071694B4097C4591135294240315C1D0071694B4097C4591135294240EE258DD13A664B40DBBE47FDF5244240EE258DD13A664B40
54208	Воробьево	1	6	1120	36.377116000000001	36.392684000000003	54.879888999999999	54.872340999999999	0103000020E6100000010000000500000030664B5645304240DFFAB0DEA86F4B4030664B5645304240198EE733A0704B40CCD4247843324240198EE733A0704B40CCD4247843324240DFFAB0DEA86F4B4030664B5645304240DFFAB0DEA86F4B40
45830	Воробьево	1	6	1120	36.365940999999999	36.384912999999997	54.874481000000003	54.863705000000003	0103000020E61000000100000005000000FDA19927D72E42402332ACE28D6E4B40FDA19927D72E424098FC4FFEEE6F4B40126745D44431424098FC4FFEEE6F4B40126745D4443142402332ACE28D6E4B40FDA19927D72E42402332ACE28D6E4B40
46791	Савино	1	6	1001	34.327537999999997	34.353966	53.895901000000002	53.879896000000002	0103000020E610000001000000050000003F19E3C3EC294140CCF09F6EA0F04A403F19E3C3EC29414013BA4BE2ACF24A40AEF204C24E2D414013BA4BE2ACF24A40AEF204C24E2D4140CCF09F6EA0F04A403F19E3C3EC294140CCF09F6EA0F04A40
9758	Манино	1	6	1001	34.327142000000002	34.358862000000002	53.981622999999999	53.968626999999998	0103000020E61000000100000005000000F392FFC9DF294140E48233F8FBFB4A40F392FFC9DF2941402E008DD2A5FD4A407AE3A430EF2D41402E008DD2A5FD4A407AE3A430EF2D4140E48233F8FBFB4A40F392FFC9DF294140E48233F8FBFB4A40
8615	Людиново	1	6	1001	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
9673	Куява	1	6	1001	34.370486	34.390203999999997	53.759017	53.744120000000002	0103000020E610000001000000050000001CD0D2156C2F41405726FC523FDF4A401CD0D2156C2F4140D40D147827E14A405A626534F2314140D40D147827E14A405A626534F23141405726FC523FDF4A401CD0D2156C2F41405726FC523FDF4A40
54230	Космачово	1	6	1001	34.622687999999997	34.651138000000003	54.029798999999997	54.016674999999999	0103000020E610000001000000050000004ACE893DB44F414095D4096822024B404ACE893DB44F41400C3A2174D0034B4068976F7D585341400C3A2174D0034B4068976F7D5853414095D4096822024B404ACE893DB44F414095D4096822024B40
9700	Колчино	1	6	1001	34.279487000000003	34.301343000000003	53.909852999999998	53.905695000000001	0103000020E610000001000000050000001E54E23AC62341404B9352D0EDF34A401E54E23AC62341407095271076F44A4074F04C68922641407095271076F44A4074F04C68922641404B9352D0EDF34A401E54E23AC62341404B9352D0EDF34A40
9442	Игнатовка	1	6	1001	34.539558	34.566659999999999	53.937100999999998	53.922708	0103000020E61000000100000005000000C8258E3C10454140F8E0B54B1BF64A40C8258E3C104541404206F2ECF2F74A40C6F99B50884841404206F2ECF2F74A40C6F99B5088484140F8E0B54B1BF64A40C8258E3C10454140F8E0B54B1BF64A40
9909	Заболотье	1	6	1001	34.617243999999999	34.635793999999997	53.854570000000002	53.846502000000001	0103000020E610000001000000050000007CD3F4D9014F4140D2FF722D5AEC4A407CD3F4D9014F41404512BD8C62ED4A401B7FA2B2615141404512BD8C62ED4A401B7FA2B261514140D2FF722D5AEC4A407CD3F4D9014F4140D2FF722D5AEC4A40
9859	Войлово	1	6	1001	34.531554	34.555816999999998	53.820151000000003	53.807578999999997	0103000020E610000001000000050000006C0723F609444140DBF7A8BF5EE74A406C0723F6094441400F643DB5FAE84A40C9C7EE02254741400F643DB5FAE84A40C9C7EE0225474140DBF7A8BF5EE74A406C0723F609444140DBF7A8BF5EE74A40
9606	Вербежичи	1	6	1001	34.353749999999998	34.385702999999999	53.865186000000001	53.848860999999999	0103000020E61000000100000005000000E17A14AE472D4140C8EC2C7AA7EC4A40E17A14AE472D4140817A336ABEEE4A400B7C45B75E314140817A336ABEEE4A400B7C45B75E314140C8EC2C7AA7EC4A40E17A14AE472D4140C8EC2C7AA7EC4A40
9830	Букань	1	6	1001	34.690789000000002	34.723075000000001	53.920423	53.909790000000001	0103000020E61000000100000005000000E1B721C66B5841402A1DACFF73F44A40E1B721C66B5841403CBEBD6BD0F54A4011C7BAB88D5C41403CBEBD6BD0F54A4011C7BAB88D5C41402A1DACFF73F44A40E1B721C66B5841402A1DACFF73F44A40
13124	Суборово	1	6	241	33.853344	33.878442999999997	54.141851000000003	54.133051999999999	0103000020E61000000100000005000000711E4E603AED40406D5512D907114B40711E4E603AED4040D4F36E2C28124B403733FAD170F04040D4F36E2C28124B403733FAD170F040406D5512D907114B40711E4E603AED40406D5512D907114B40
48707	Новосельский	1	6	241	33.986060999999999	33.996409999999997	54.210543999999999	54.202266000000002	0103000020E61000000100000005000000376E313F37FE4040DF8B2FDAE3194B40376E313F37FE40403C2F151BF31A4B4024B4E55C8AFF40403C2F151BF31A4B4024B4E55C8AFF4040DF8B2FDAE3194B40376E313F37FE4040DF8B2FDAE3194B40
54226	Новодяглево	1	6	241	33.769081999999997	33.782592999999999	54.168635999999999	54.160691999999997	0103000020E610000001000000050000009CF86A4771E240404A5D328E91144B409CF86A4771E24040D1764CDD95154B400D8AE6012CE44040D1764CDD95154B400D8AE6012CE440404A5D328E91144B409CF86A4771E240404A5D328E91144B40
47253	Мокрое	1	6	241	33.888378000000003	33.908625999999998	54.066358999999999	54.050455999999997	0103000020E61000000100000005000000323ECC5EB6F1404088F19A5775064B40323ECC5EB6F14040CB65A3737E084B40CC2555DB4DF44040CB65A3737E084B40CC2555DB4DF4404088F19A5775064B40323ECC5EB6F1404088F19A5775064B40
3592	Лужница	1	6	241	34.028838999999998	34.061411999999997	53.950519999999997	53.935490000000001	0103000020E61000000100000005000000B7EC10FFB003414016DEE522BEF74A40B7EC10FFB0034140D218ADA3AAF94A407DCA3159DC074140D218ADA3AAF94A407DCA3159DC07414016DEE522BEF74A40B7EC10FFB003414016DEE522BEF74A40
29633	Кузьминичи	1	6	241	33.696281999999997	33.729601000000002	54.246608000000002	54.230943000000003	0103000020E610000001000000050000009065C1C41FD94040BD1E4C8A8F1D4B409065C1C41FD940404B77D7D9901F4B408010C99063DD40404B77D7D9901F4B408010C99063DD4040BD1E4C8A8F1D4B409065C1C41FD94040BD1E4C8A8F1D4B40
49191	Зимницы	1	6	241	33.821831000000003	34.070565000000002	54.061597999999996	53.964533000000003	0103000020E6100000010000000500000064EB19C231E94040D6743DD175FB4A4064EB19C231E94040DFBF7971E2074B40029F1F4608094140DFBF7971E2074B40029F1F4608094140D6743DD175FB4A4064EB19C231E94040D6743DD175FB4A40
16691	Закрутое	1	6	241	33.933303000000002	33.977257000000002	54.165225	54.134360999999998	0103000020E610000001000000050000001D21037976F74040CE6DC2BD32114B401D21037976F74040A5BDC11726154B40BF64E3C116FD4040A5BDC11726154B40BF64E3C116FD4040CE6DC2BD32114B401D21037976F74040CE6DC2BD32114B40
7705	Жерелево	1	6	241	33.705247999999997	33.738	54.199696000000003	54.187975000000002	0103000020E61000000100000005000000E2C8039145DA404099BB96900F184B40E2C8039145DA40402E9276A38F194B405839B4C876DE40402E9276A38F194B405839B4C876DE404099BB96900F184B40E2C8039145DA404099BB96900F184B40
46469	Желны	1	6	241	33.841396000000003	33.855131999999998	54.215013999999996	54.200811999999999	0103000020E610000001000000050000001C7E37DDB2EB40407A522635B4194B401C7E37DDB2EB404050172994851B4B40ACE122F774ED404050172994851B4B40ACE122F774ED40407A522635B4194B401C7E37DDB2EB40407A522635B4194B40
958	Емельяновичи	1	6	241	33.600440999999996	33.631613000000002	54.075304000000003	54.067399999999999	0103000020E61000000100000005000000B9162D40DBCC40400DE02D90A0084B40B9162D40DBCC404006A1BC8FA3094B403E5DDDB1D8D0404006A1BC8FA3094B403E5DDDB1D8D040400DE02D90A0084B40B9162D40DBCC40400DE02D90A0084B40
22323	Дегонка	1	6	241	33.625100000000003	33.631056000000001	54.240783999999998	54.237000000000002	0103000020E61000000100000005000000645DDC4603D0404075931804561E4B40645DDC4603D0404035B39602D21E4B40E8F86871C6D0404035B39602D21E4B40E8F86871C6D0404075931804561E4B40645DDC4603D0404075931804561E4B40
45364	Высокое	1	6	241	33.761499999999998	34.009856999999997	54.119877000000002	54.024388000000002	0103000020E61000000100000005000000B6F3FDD478E140401A355F251F034B40B6F3FDD478E1404074452921580F4B407E5182FE4201414074452921580F4B407E5182FE420141401A355F251F034B40B6F3FDD478E140401A355F251F034B40
54247	Ветмица	1	6	241	33.937542999999998	33.970843000000002	53.965094000000001	53.947118000000003	0103000020E61000000100000005000000FFCBB56801F84040FAB9A1293BF94A40FFCBB56801F840406DC83F3388FB4A4078465B9544FC40406DC83F3388FB4A4078465B9544FC4040FAB9A1293BF94A40FFCBB56801F84040FAB9A1293BF94A40
8489	Бутчино	1	6	241	34.038684000000003	34.058698999999997	53.922866999999997	53.904491	0103000020E610000001000000050000007270E998F30441405F43705CC6F34A407270E998F304414060C77F8120F64A4069A7E6728307414060C77F8120F64A4069A7E672830741405F43705CC6F34A407270E998F30441405F43705CC6F34A40
8370	Бетлица	1	6	241	33.928927999999999	33.971570999999997	54.023493999999999	54.003028999999998	0103000020E610000001000000050000005A2BDA1CE7F6404044F8174163004B405A2BDA1CE7F640407CD3F4D901034B40FA5E43705CFC40407CD3F4D901034B40FA5E43705CFC404044F8174163004B405A2BDA1CE7F6404044F8174163004B40
28671	Чернышено	1	6	893	35.849319999999999	35.880051000000002	53.833337	53.817520000000002	0103000020E610000001000000050000005BEB8B84B6EC4140B8E9CF7EA4E84A405BEB8B84B6EC4140FCC56CC9AAEA4A40F3E7DB82A5F04140FCC56CC9AAEA4A40F3E7DB82A5F04140B8E9CF7EA4E84A405BEB8B84B6EC4140B8E9CF7EA4E84A40
7430	Сосенский	1	6	893	35.948619000000001	35.981119999999997	54.066153	54.042124999999999	0103000020E610000001000000050000009FAEEE586CF9414008AC1C5A64054B409FAEEE586CF9414022C495B377084B40CBB9145795FD414022C495B377084B40CBB9145795FD414008AC1C5A64054B409FAEEE586CF9414008AC1C5A64054B40
48630	Сенино 1-е	1	6	893	36.004468000000003	36.035612	53.993946999999999	53.979695	0103000020E6100000010000000500000074F04C6892004240018750A566FD4A4074F04C6892004240897AC1A739FF4A402EAC1BEF8E044240897AC1A739FF4A402EAC1BEF8E044240018750A566FD4A4074F04C6892004240018750A566FD4A40
6903	Попелево	1	6	893	35.702724000000003	35.725047000000004	54.099904000000002	54.091656	0103000020E61000000100000005000000A20E2BDCF2D94140B83D4162BB0B4B40A20E2BDCF2D94140AB5E7EA7C90C4B400E881057CEDC4140AB5E7EA7C90C4B400E881057CEDC4140B83D4162BB0B4B40A20E2BDCF2D94140B83D4162BB0B4B40
49125	Покровск	1	6	893	35.611705999999998	35.623320999999997	54.115713	54.110314000000002	0103000020E610000001000000050000002C62D8614CCE41403E25E7C41E0E4B402C62D8614CCE41406C5CFFAECF0E4B407BF486FBC8CF41406C5CFFAECF0E4B407BF486FBC8CF41403E25E7C41E0E4B402C62D8614CCE41403E25E7C41E0E4B40
40423	Подборки	1	6	893	35.919846	35.941056000000003	54.181061999999997	54.167628999999998	0103000020E610000001000000050000009FAD8383BDF541403B6EF8DD74154B409FAD8383BDF541403046240A2D174B4030DAE38574F841403046240A2D174B4030DAE38574F841403B6EF8DD74154B409FAD8383BDF541403B6EF8DD74154B40
8153	Нижние Прыски	1	6	893	35.830033	35.870725999999998	54.093688999999998	54.077190000000002	0103000020E61000000100000005000000E6CC76853EEA414004CAA65CE1094B40E6CC76853EEA41405A7F4B00FE0B4B4071E316F373EF41405A7F4B00FE0B4B4071E316F373EF414004CAA65CE1094B40E6CC76853EEA414004CAA65CE1094B40
46584	Маслово	1	6	893	35.834201	35.842798000000002	54.150646999999999	54.142204	0103000020E610000001000000050000002FA52E19C7EA414021AE9CBD33124B402FA52E19C7EA4140C91EA16648134B402E910BCEE0EB4140C91EA16648134B402E910BCEE0EB414021AE9CBD33124B402FA52E19C7EA414021AE9CBD33124B40
8150	Лавровск	1	6	893	35.669710000000002	35.692573000000003	54.022039999999997	54.014104000000003	0103000020E61000000100000005000000EFE6A90EB9D54140145FED28CE014B40EFE6A90EB9D54140179AEB34D2024B40DB8B683BA6D84140179AEB34D2024B40DB8B683BA6D84140145FED28CE014B40EFE6A90EB9D54140145FED28CE014B40
7036	Козельск	1	6	893	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
8065	Киреевское 1-е	1	6	893	35.904988000000003	35.922370999999998	53.894585999999997	53.885399999999997	0103000020E61000000100000005000000E0A293A5D6F341406FF085C954F14A40E0A293A5D6F34140CFBA46CB81F24A40B0E3BF4010F64140CFBA46CB81F24A40B0E3BF4010F641406FF085C954F14A40E0A293A5D6F341406FF085C954F14A40
45920	Ильинское	1	6	893	35.675863999999997	35.689059999999998	54.243293000000001	54.236127000000003	0103000020E61000000100000005000000994528B682D64140EF59D768391E4B40994528B682D64140412C9B39241F4B40AA7D3A1E33D84140412C9B39241F4B40AA7D3A1E33D84140EF59D768391E4B40994528B682D64140EF59D768391E4B40
54210	Заречье	1	6	893	35.629116000000003	35.663620000000002	54.098224999999999	54.015104000000001	0103000020E61000000100000005000000F7B182DF86D04140F70489EDEE014B40F7B182DF86D04140265305A3920C4B405B7C0A80F1D44140265305A3920C4B405B7C0A80F1D44140F70489EDEE014B40F7B182DF86D04140F70489EDEE014B40
40419	Дешовки	1	6	893	35.773277	35.796615000000003	54.007781000000001	53.988024000000003	0103000020E61000000100000005000000DFDFA0BDFAE24140E1D4079277FE4A40DFDFA0BDFAE24140DD43C2F7FE004B406440F67AF7E54140DD43C2F7FE004B406440F67AF7E54140E1D4079277FE4A40DFDFA0BDFAE24140E1D4079277FE4A40
7852	Волконское	1	6	893	35.652777	35.678666999999997	53.943190999999999	53.928412999999999	0103000020E610000001000000050000005E4A5D328ED341403317B83CD6F64A405E4A5D328ED34140D670917BBAF84A40EDEF6C8FDED64140D670917BBAF84A40EDEF6C8FDED641403317B83CD6F64A405E4A5D328ED341403317B83CD6F64A40
48942	Бурнашево	1	6	893	35.79083	35.802436	54.155234999999998	54.148760000000003	0103000020E610000001000000050000000C59DDEA39E54140FB7953910A134B400C59DDEA39E54140E71890BDDE134B4008910C39B6E64140E71890BDDE134B4008910C39B6E64140FB7953910A134B400C59DDEA39E54140FB7953910A134B40
7919	Березичи	1	6	893	35.776628000000002	35.799993000000001	53.988425999999997	53.966472000000003	0103000020E610000001000000050000003694DA8B68E34140F73FC05AB5FB4A403694DA8B68E341400F4240BE84FE4A40B403AE2B66E641400F4240BE84FE4A40B403AE2B66E64140F73FC05AB5FB4A403694DA8B68E34140F73FC05AB5FB4A40
54191	Березический стеклозавод	1	6	893	35.843606000000001	35.853648999999997	53.967726999999996	53.964908999999999	0103000020E61000000100000005000000CD5A0A48FBEB4140DB4E5B2382FB4A40CD5A0A48FBEB4140643A747ADEFB4A40ADA1D45E44ED4140643A747ADEFB4A40ADA1D45E44ED4140DB4E5B2382FB4A40CD5A0A48FBEB4140DB4E5B2382FB4A40
48306	Якимово	1	6	764	34.322955999999998	34.344380999999998	54.200712000000003	54.186036000000001	0103000020E610000001000000050000000306499F5629414078F01307D0174B400306499F5629414017F549EEB0194B40902E36AD142C414017F549EEB0194B40902E36AD142C414078F01307D0174B400306499F5629414078F01307D0174B40
5440	Шайковка	1	6	764	34.369326999999998	34.388981999999999	54.253309999999999	54.234074	0103000020E61000000100000005000000D0436D1B462F4140056C0723F61D4B40D0436D1B462F4140F8DF4A766C204B40C85D8429CA314140F8DF4A766C204B40C85D8429CA314140056C0723F61D4B40D0436D1B462F4140056C0723F61D4B40
5761	Фоминичи	1	6	764	34.673065999999999	34.698802000000001	54.128225	54.103045000000002	0103000020E610000001000000050000005706D5062756414017821C94300D4B405706D50627564140CAC342AD69104B4090300C5872594140CAC342AD69104B4090300C587259414017821C94300D4B405706D5062756414017821C94300D4B40
5361	Тягаево	1	6	764	34.094451999999997	34.115445000000001	54.190182999999998	54.179386999999998	0103000020E610000001000000050000005985CD00170C4140ED293927F6164B405985CD00170C4140A9A0A2EA57184B404DBED9E6C60E4140A9A0A2EA57184B404DBED9E6C60E4140ED293927F6164B405985CD00170C4140ED293927F6164B40
45465	Прудки	1	6	764	34.498469	34.515293999999997	54.146828999999997	54.131185000000002	0103000020E61000000100000005000000F0880AD5CD3F4140E65C8AABCA104B40F0880AD5CD3F41405C8DEC4ACB124B409AE95E27F54141405C8DEC4ACB124B409AE95E27F5414140E65C8AABCA104B40F0880AD5CD3F4140E65C8AABCA104B40
6232	Малые Савки	1	6	764	34.214250999999997	34.244388999999998	54.075355999999999	54.063468	0103000020E610000001000000050000005111A7936C1B4140D82B2CB81F084B405111A7936C1B414058C7F143A5094B4046408523481F414058C7F143A5094B4046408523481F4140D82B2CB81F084B405111A7936C1B4140D82B2CB81F084B40
52706	Малые Зимницы	1	6	764	34.746943000000002	34.766202999999997	54.098250999999998	54.086201000000003	0103000020E61000000100000005000000F27C06D49B5F4140F6F065A2080B4B40F27C06D49B5F41404FE61F7D930C4B406D8C9DF0126241404FE61F7D930C4B406D8C9DF012624140F6F065A2080B4B40F27C06D49B5F4140F6F065A2080B4B40
6132	Малая Песочня	1	6	764	34.267009000000002	34.288648999999999	54.023874999999997	54.009422000000001	0103000020E610000001000000050000006C5ED5592D22414074EE76BD34014B406C5ED5592D224140931804560E034B40F5824F73F2244140931804560E034B40F5824F73F224414074EE76BD34014B406C5ED5592D22414074EE76BD34014B40
16379	Лазинки	1	6	764	34.216093000000001	34.224787999999997	54.229312	54.223016000000001	0103000020E6100000010000000500000080F277EFA81B41400C3ECDC98B1C4B4080F277EFA81B4140494A7A185A1D4B4041446ADAC51C4140494A7A185A1D4B4041446ADAC51C41400C3ECDC98B1C4B4080F277EFA81B41400C3ECDC98B1C4B40
45938	Киров	1	6	764	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
48285	Дуброво	1	6	764	34.249375000000001	34.276944	54.210365000000003	54.192552999999997	0103000020E6100000010000000500000052B81E85EB1F414093DFA293A5184B4052B81E85EB1F41408D9C853DED1A4B406669A7E6722341408D9C853DED1A4B406669A7E67223414093DFA293A5184B4052B81E85EB1F414093DFA293A5184B40
48251	Гавриловка	1	6	764	34.544004999999999	34.565995000000001	54.074764999999999	54.058067000000001	0103000020E6100000010000000500000024EEB1F4A145414009FD4CBD6E074B4024EEB1F4A145414056F146E691094B408A592F867248414056F146E691094B408A592F867248414009FD4CBD6E074B4024EEB1F4A145414009FD4CBD6E074B40
48161	Воскресенск	1	6	764	34.324429000000002	34.348315999999997	54.136270000000003	54.121962000000003	0103000020E61000000100000005000000DF6FB4E38629414069AD68739C0F4B40DF6FB4E38629414085B69C4B71114B403656629E952C414085B69C4B71114B403656629E952C414069AD68739C0F4B40DF6FB4E38629414069AD68739C0F4B40
5755	Волое	1	6	764	34.554461000000003	34.588749999999997	54.153632000000002	54.132978000000001	0103000020E6100000010000000500000028F4FA93F8464140338B506C05114B4028F4FA93F84641403ECF9F36AA134B408FC2F5285C4B41403ECF9F36AA134B408FC2F5285C4B4140338B506C05114B4028F4FA93F8464140338B506C05114B40
6022	Верхняя Песочня	1	6	764	34.161304000000001	34.195538999999997	54.149101999999999	54.133420999999998	0103000020E61000000100000005000000645B069CA5144140C0CC77F013114B40645B069CA514414054E23AC615134B40D80B056C0719414054E23AC615134B40D80B056C07194140C0CC77F013114B40645B069CA5144140C0CC77F013114B40
6224	Большие Савки	1	6	764	34.184660999999998	34.210917999999999	54.060028000000003	54.044725999999997	0103000020E610000001000000050000005FECBDF8A2174140F4A3E194B9054B405FECBDF8A2174140126C5CFFAE074B40A1116C5CFF1A4140126C5CFFAE074B40A1116C5CFF1A4140F4A3E194B9054B405FECBDF8A2174140F4A3E194B9054B40
48179	Бережки	1	6	764	34.415303000000002	34.476163999999997	54.125967000000003	54.113159000000003	0103000020E61000000100000005000000217711A628354140C11F7EFE7B0E4B40217711A62835414008B0C8AF1F104B402AC423F1F23C414008B0C8AF1F104B402AC423F1F23C4140C11F7EFE7B0E4B40217711A628354140C11F7EFE7B0E4B40
6113	Анновка	1	6	764	34.058940999999997	34.080033999999998	54.136496999999999	54.124657999999997	0103000020E610000001000000050000005FB2F1608B074140A69718CBF40F4B405FB2F1608B0741404580D3BB78114B40B648DA8D3E0A41404580D3BB78114B40B648DA8D3E0A4140A69718CBF40F4B405FB2F1608B074140A69718CBF40F4B40
3105	Росва	1	6	508	36.049294000000003	36.067816999999998	54.517425000000003	54.510108000000002	0103000020E61000000100000005000000CCF10A444F064240C8B60C384B414B40CCF10A444F06424000917EFB3A424B40718E3A3AAE08424000917EFB3A424B40718E3A3AAE084240C8B60C384B414B40CCF10A444F064240C8B60C384B414B40
54196	Мирный	1	6	508	36.164655000000003	36.184409000000002	54.633978999999997	54.624999000000003	0103000020E61000000100000005000000BB0F406A1315424030849CF7FF4F4B40BB0F406A13154240E6AC4F3926514B40460BD0B69A174240E6AC4F3926514B40460BD0B69A17424030849CF7FF4F4B40BB0F406A1315424030849CF7FF4F4B40
54222	Лихун	1	6	508	36.252555000000001	36.276333999999999	54.637605999999998	54.624332000000003	0103000020E610000001000000050000007CB8E4B85320424053EC681CEA4F4B407CB8E4B853204240DFDDCA129D514B40ED629AE95E234240DFDDCA129D514B40ED629AE95E23424053EC681CEA4F4B407CB8E4B85320424053EC681CEA4F4B40
54206	Колюпаново	1	6	508	36.220835999999998	36.241506000000001	54.441229999999997	54.425414000000004	0103000020E61000000100000005000000C5E3A25A441C42405AA148F773364B40C5E3A25A441C4240CD0182397A384B40D6E429ABE91E4240CD0182397A384B40D6E429ABE91E42405AA148F773364B40C5E3A25A441C42405AA148F773364B40
54235	Ильинка	1	6	508	36.300130000000003	36.323630000000001	54.657110000000003	54.640028999999998	0103000020E610000001000000050000003546EBA86A264240ECBE6378EC514B403546EBA86A264240F2EF332E1C544B40930035B56C294240F2EF332E1C544B40930035B56C294240ECBE6378EC514B403546EBA86A264240ECBE6378EC514B40
54227	Андреевское	1	6	508	36.186754000000001	36.208618999999999	54.386539999999997	54.377034000000002	0103000020E61000000100000005000000D732198EE717424073BD6DA642304B40D732198EE7174240444C89247A314B4080290307B41A4240444C89247A314B4080290307B41A424073BD6DA642304B40D732198EE717424073BD6DA642304B40
31097	Шанский Завод	1	6	1892	35.590192000000002	35.609901000000001	55.107370000000003	55.098211999999997	0103000020E61000000100000005000000302E55698BCB41409109F835928C4B40302E55698BCB41402849D74CBE8D4B401B66683C11CE41402849D74CBE8D4B401B66683C11CE41409109F835928C4B40302E55698BCB41409109F835928C4B40
30979	Ореховня	1	6	1892	35.253036000000002	35.279958000000001	55.091546000000001	55.077561000000003	0103000020E61000000100000005000000F75AD07B63A04140F838D384ED894B40F75AD07B63A04140310A82C7B78B4B407520EBA9D5A34140310A82C7B78B4B407520EBA9D5A34140F838D384ED894B40F75AD07B63A04140F838D384ED894B40
30473	Мятлево	1	6	1892	35.654528999999997	35.699677999999999	54.909829999999999	54.884633000000001	0103000020E610000001000000050000004CA4349BC7D341402FFB75A73B714B404CA4349BC7D34140B875374F75744B4087DD770C8FD94140B875374F75744B4087DD770C8FD941402FFB75A73B714B404CA4349BC7D341402FFB75A73B714B40
45638	Льнозавод	1	6	1892	35.427838999999999	35.445616999999999	54.953100999999997	54.943752000000003	0103000020E61000000100000005000000077AA86DC3B641406EC493DDCC784B40077AA86DC3B641407764AC36FF794B4054C554FA09B941407764AC36FF794B4054C554FA09B941406EC493DDCC784B40077AA86DC3B641406EC493DDCC784B40
31328	Износки	1	6	1892	35.299433999999998	35.345652000000001	54.996113000000001	54.981515000000002	0103000020E61000000100000005000000BDA772DA53A6414048C49448A27D4B40BDA772DA53A641406B0F7BA1807F4B4004E621533EAC41406B0F7BA1807F4B4004E621533EAC414048C49448A27D4B40BDA772DA53A6414048C49448A27D4B40
31227	Извольск	1	6	1892	35.203313999999999	35.244824999999999	54.938586000000001	54.926549000000001	0103000020E61000000100000005000000D3687231069A41401D925A2899764B40D3687231069A4140E23D079623784B40211FF46C569F4140E23D079623784B40211FF46C569F41401D925A2899764B40D3687231069A41401D925A2899764B40
60413	Ивановское	1	6	1892	35.120668999999999	35.146189999999997	55.023991000000002	54.996108	0103000020E610000001000000050000000D52F014728F414059A48977807F4B400D52F014728F4140FD32182312834B4049809A5AB6924140FD32182312834B4049809A5AB692414059A48977807F4B400D52F014728F414059A48977807F4B40
53074	Алексеевка	1	6	1892	35.589967000000001	35.604933000000003	54.907662000000002	54.901553999999997	0103000020E61000000100000005000000105CE50984CB4140FBC9181F66734B40105CE50984CB414036E9B6442E744B40B6A2CD716ECD414036E9B6442E744B40B6A2CD716ECD4140FBC9181F66734B40105CE50984CB4140FBC9181F66734B40
29740	Чубарово	1	6	1868	36.906682000000004	36.926237999999998	55.202182999999998	55.190375000000003	0103000020E610000001000000050000009AEFE0270E744240EE7C3F355E984B409AEFE0270E7442405167EE21E1994B40FE277FF78E7642405167EE21E1994B40FE277FF78E764240EE7C3F355E984B409AEFE0270E744240EE7C3F355E984B40
54215	Чаусово	1	6	1868	36.917577999999999	36.924154000000001	54.846581	54.841189999999997	0103000020E61000000100000005000000B9C326327375424072DC291DAC6B4B40B9C32632737542401E3526C45C6C4B40DA3BA3AD4A7642401E3526C45C6C4B40DA3BA3AD4A76424072DC291DAC6B4B40B9C326327375424072DC291DAC6B4B40
29951	Трубино	1	6	1868	36.688668999999997	36.713984000000004	54.985798000000003	54.966591999999999	0103000020E610000001000000050000006F62484E26584240A1496249B97B4B406F62484E265842402A3BFDA02E7E4B4003EFE4D3635B42402A3BFDA02E7E4B4003EFE4D3635B4240A1496249B97B4B406F62484E26584240A1496249B97B4B40
30109	Тростье	1	6	1868	36.934035000000002	36.954984000000003	55.019438999999998	55.009404000000004	0103000020E61000000100000005000000E12879758E774240CE39782634814B40E12879758E7742402BA226FA7C824B40051A6CEA3C7A42402BA226FA7C824B40051A6CEA3C7A4240CE39782634814B40E12879758E774240CE39782634814B40
29987	Троицкое	1	6	1868	37.099110000000003	37.122726	54.878309000000002	54.867325999999998	0103000020E61000000100000005000000715AF0A2AF8C4240397CD289046F4B40715AF0A2AF8C42402864E76D6C704B40382F4E7CB58F42402864E76D6C704B40382F4E7CB58F4240397CD289046F4B40715AF0A2AF8C4240397CD289046F4B40
29650	Тарутино	1	6	1868	36.924737999999998	36.951515999999998	55.130606	55.109651999999997	0103000020E6100000010000000500000029AF95D05D76424072F8A413098E4B4029AF95D05D764240A85489B2B7904B4074CFBA46CB794240A85489B2B7904B4074CFBA46CB79424072F8A413098E4B4029AF95D05D76424072F8A413098E4B40
54228	Совхоз Победа	1	6	1868	36.669580000000003	37.182464000000003	55.234814999999998	54.798499	0103000020E61000000100000005000000210725CCB4554240C171193735664B40210725CCB45542401CCEFC6A0E9E4B404359F8FA5A9742401CCEFC6A0E9E4B404359F8FA5A974240C171193735664B40210725CCB4554240C171193735664B40
54223	Курилово	1	6	1868	37.008541999999998	37.035984999999997	55.107973000000001	55.08155	0103000020E610000001000000050000003B527DE717814240917EFB3A708A4B403B527DE717814240EEEC2B0FD28D4B40C2120F289B844240EEEC2B0FD28D4B40C2120F289B844240917EFB3A708A4B403B527DE717814240917EFB3A708A4B40
30439	Кременки	1	6	1868	37.102091999999999	37.137638000000003	54.888755000000003	54.876910000000002	0103000020E610000001000000050000007497C459118D424087C43D963E704B407497C459118D424008944DB9C2714B40EB573A1F9E91424008944DB9C2714B40EB573A1F9E91424087C43D963E704B407497C459118D424087C43D963E704B40
29811	Корсаково	1	6	1868	36.973461999999998	36.985401000000003	55.157041999999997	55.149330999999997	0103000020E610000001000000050000000AF31E679A7C4240B5A338471D934B400AF31E679A7C4240990CC7F319944B400D39B69E217E4240990CC7F319944B400D39B69E217E4240B5A338471D934B400AF31E679A7C4240B5A338471D934B40
60400	Грибовка	1	6	1868	36.856088	36.861406000000002	54.938569999999999	54.935327999999998	0103000020E61000000100000005000000C03FA54A946D42403C84F1D3B8774B40C03FA54A946D4240DC80CF0F23784B40024A438D426E4240DC80CF0F23784B40024A438D426E42403C84F1D3B8774B40C03FA54A946D42403C84F1D3B8774B40
29504	Грачевка	1	6	1868	36.797320999999997	36.819274999999998	55.103960999999998	55.096218999999998	0103000020E61000000100000005000000FEB4519D0E6642407D2079E7508C4B40FEB4519D0E6642409C8713984E8D4B4017B7D100DE6842409C8713984E8D4B4017B7D100DE6842407D2079E7508C4B40FEB4519D0E6642407D2079E7508C4B40
29871	Высокиничи	1	6	1868	36.896531000000003	36.941321000000002	54.921205	54.904882000000001	0103000020E61000000100000005000000D36C1E87C17242409A5E622CD3734B40D36C1E87C1724240B2F4A10BEA754B40DE04DF347D784240B2F4A10BEA754B40DE04DF347D7842409A5E622CD3734B40D36C1E87C17242409A5E622CD3734B40
29449	Восход	1	6	1868	36.787906	36.797607999999997	54.968736999999997	54.962255999999996	0103000020E610000001000000050000003D29931ADA6442409C3061342B7B4B403D29931ADA6442406BB6F292FF7B4B409483D904186642406BB6F292FF7B4B409483D904186642409C3061342B7B4B403D29931ADA6442409C3061342B7B4B40
29520	Воробьи	1	6	1868	36.786658000000003	36.81747	55.153168999999998	55.141089000000001	0103000020E6100000010000000500000082919735B1644240A56950340F924B4082919735B164424069E1B20A9B934B4006BB61DBA268424069E1B20A9B934B4006BB61DBA2684240A56950340F924B4082919735B1644240A56950340F924B40
54202	Верховье	1	6	1868	36.669580000000003	37.182464000000003	55.234814999999998	54.798499	0103000020E61000000100000005000000210725CCB4554240C171193735664B40210725CCB45542401CCEFC6A0E9E4B404359F8FA5A9742401CCEFC6A0E9E4B404359F8FA5A974240C171193735664B40210725CCB4554240C171193735664B40
30950	Величково	1	6	1868	36.753985999999998	36.771799999999999	54.992162	54.983891999999997	0103000020E6100000010000000500000028D2FD9C82604240E4654D2CF07D4B4028D2FD9C82604240BF2A172AFF7E4B40C286A757CA624240BF2A172AFF7E4B40C286A757CA624240E4654D2CF07D4B4028D2FD9C82604240E4654D2CF07D4B40
54186	Белоусово	1	6	1868	36.669580000000003	37.182464000000003	55.234814999999998	54.798499	0103000020E61000000100000005000000210725CCB4554240C171193735664B40210725CCB45542401CCEFC6A0E9E4B404359F8FA5A9742401CCEFC6A0E9E4B404359F8FA5A974240C171193735664B40210725CCB4554240C171193735664B40
60396	Барсуки	1	6	1868	36.961388999999997	36.968935000000002	55.060316999999998	55.05547	0103000020E61000000100000005000000F8DD74CB0E7B42405EF415A419874B40F8DD74CB0E7B42404832AB77B8874B409279E40F067C42404832AB77B8874B409279E40F067C42405EF415A419874B40F8DD74CB0E7B42405EF415A419874B40
46403	Баранцево	1	6	1868	36.943944000000002	36.951112000000002	54.806418000000001	54.802843000000003	0103000020E61000000100000005000000B2A03028D37842404969368FC3664B40B2A03028D3784240EF737CB438674B40A56ABB09BE794240EF737CB438674B40A56ABB09BE7942404969368FC3664B40B2A03028D37842404969368FC3664B40
28942	Яровщина	1	6	1852	34.689666000000003	34.707417	53.659545999999999	53.641406000000003	0103000020E61000000100000005000000E294B9F946584140A6BA809719D24A40E294B9F946584140931ADA006CD44A4035D1E7A38C5A4140931ADA006CD44A4035D1E7A38C5A4140A6BA809719D24A40E294B9F946584140A6BA809719D24A40
28927	Улемец	1	6	1852	34.624619000000003	34.650382999999998	53.551453000000002	53.537889	0103000020E61000000100000005000000E9BAF083F34F414067F0F78BD9C44A40E9BAF083F34F4140FB230C0396C64A40EB6F09C03F534140FB230C0396C64A40EB6F09C03F53414067F0F78BD9C44A40E9BAF083F34F414067F0F78BD9C44A40
46154	Студенец	1	6	1852	34.900410999999998	34.921297000000003	53.756163000000001	53.748618999999998	0103000020E61000000100000005000000B5FAEAAA40734140051555BFD2DF4A40B5FAEAAA40734140FEB8FDF2C9E04A409373620FED754140FEB8FDF2C9E04A409373620FED754140051555BFD2DF4A40B5FAEAAA40734140051555BFD2DF4A40
60403	Разъезд Березовский	1	6	1852	34.712888	34.721125000000001	53.504916999999999	53.497151000000002	0103000020E61000000100000005000000FDDAFAE93F5B41403C16DBA4A2BF4A40FDDAFAE93F5B4140E318C91EA1C04A40FCA9F1D24D5C4140E318C91EA1C04A40FCA9F1D24D5C41403C16DBA4A2BF4A40FDDAFAE93F5B41403C16DBA4A2BF4A40
47907	Поляна	1	6	1852	34.915807999999998	34.930504999999997	53.639344999999999	53.628790000000002	0103000020E6100000010000000500000024B5503239754140A306D3307CD04A4024B550323975414039EE940ED6D14A40DAE1AFC91A77414039EE940ED6D14A40DAE1AFC91A774140A306D3307CD04A4024B5503239754140A306D3307CD04A40
49248	Полюдово	1	6	1852	34.980181999999999	35.009224000000003	53.771141	53.755358999999999	0103000020E610000001000000050000005E10919A767D4140A0DE8C9AAFE04A405E10919A767D414068CD8FBFB4E24A404E2B85402E81414068CD8FBFB4E24A404E2B85402E814140A0DE8C9AAFE04A405E10919A767D4140A0DE8C9AAFE04A40
60402	Песочня	1	6	1852	34.697778	34.713849000000003	53.673172000000001	53.657556	0103000020E6100000010000000500000024EF1CCA50594140F0A485CB2AD44A4024EF1CCA505941409D4A06802AD64A4023A46E675F5B41409D4A06802AD64A4023A46E675F5B4140F0A485CB2AD44A4024EF1CCA50594140F0A485CB2AD44A40
29047	Огорь	1	6	1852	34.624664000000003	34.653869	53.499374000000003	53.476362999999999	0103000020E61000000100000005000000897E6DFDF44F414021037976F9BC4A40897E6DFDF44F4140823CBB7CEBBF4A40226FB9FAB1534140823CBB7CEBBF4A40226FB9FAB153414021037976F9BC4A40897E6DFDF44F414021037976F9BC4A40
28850	Овсорок	1	6	1852	34.688372999999999	34.716929999999998	53.579234999999997	53.560727999999997	0103000020E610000001000000050000008639419B1C584140CAF962EFC5C74A408639419B1C5841406AD95A5F24CA4A40B9C2BB5CC45B41406AD95A5F24CA4A40B9C2BB5CC45B4140CAF962EFC5C74A408639419B1C584140CAF962EFC5C74A40
29247	Мужитино	1	6	1852	34.657291000000001	34.686512999999998	53.768858000000002	53.751398000000002	0103000020E61000000100000005000000427A8A1C22544140D12346CF2DE04A40427A8A1C225441404DA25EF069E24A40B1A371A8DF5741404DA25EF069E24A40B1A371A8DF574140D12346CF2DE04A40427A8A1C22544140D12346CF2DE04A40
28832	Младенск	1	6	1852	34.809780000000003	34.831313000000002	53.615811999999998	53.599871	0103000020E610000001000000050000003A7AFCDEA6674140CF68AB92C8CC4A403A7AFCDEA6674140FF3D78EDD2CE4A40ADDEE176686A4140FF3D78EDD2CE4A40ADDEE176686A4140CF68AB92C8CC4A403A7AFCDEA6674140CF68AB92C8CC4A40
49285	Коренево	1	6	1852	34.590088000000002	34.62426	53.684995999999998	53.664135000000002	0103000020E610000001000000050000008BE1EA00884B414082902C6002D54A408BE1EA00884B414006F2ECF2ADD74A40B9196EC0E74F414006F2ECF2ADD74A40B9196EC0E74F414082902C6002D54A408BE1EA00884B414082902C6002D54A40
54244	Коллективизатор	1	6	1852	34.693106999999998	34.715960000000003	53.730496000000002	53.719057999999997	0103000020E6100000010000000500000078D0ECBAB7584140ADF6B0170ADC4A4078D0ECBAB7584140EEED96E480DD4A40419FC893A45B4140EEED96E480DD4A40419FC893A45B4140ADF6B0170ADC4A4078D0ECBAB7584140ADF6B0170ADC4A40
47363	Зикеево	1	6	1852	34.848668000000004	34.896026999999997	53.742590999999997	53.713138000000001	0103000020E61000000100000005000000B4942C27A16C414076C4211B48DB4A40B4942C27A16C4140E7A6CD380DDF4A409FAA4203B1724140E7A6CD380DDF4A409FAA4203B172414076C4211B48DB4A40B4942C27A16C414076C4211B48DB4A40
29075	Жиздра	1	6	1852	34.709356999999997	34.762968999999998	53.760992000000002	53.727204	0103000020E610000001000000050000002618CE35CC5A41409CC24A0515DD4A402618CE35CC5A41404242942F68E14A40506EDBF7A86141404242942F68E14A40506EDBF7A86141409CC24A0515DD4A402618CE35CC5A41409CC24A0515DD4A40
29222	Верхняя Акимовка	1	6	1852	34.714585999999997	34.738920999999998	53.821353000000002	53.801969	0103000020E61000000100000005000000F816D68D775B4140F2B391EBA6E64A40F816D68D775B41405ABC581822E94A40EFA99CF6945E41405ABC581822E94A40EFA99CF6945E4140F2B391EBA6E64A40F816D68D775B4140F2B391EBA6E64A40
45556	Березовка	1	6	1852	34.729543	34.749225000000003	53.501227	53.495854999999999	0103000020E610000001000000050000004B033FAA615D41406F47382D78BF4A404B033FAA615D4140A46FD23428C04A403D2CD49AE65F4140A46FD23428C04A403D2CD49AE65F41406F47382D78BF4A404B033FAA615D41406F47382D78BF4A40
49049	Чернышено	1	6	324	35.250484999999998	35.292040999999998	53.849912000000003	53.833640000000003	0103000020E61000000100000005000000BC9179E40FA0414098512CB7B4EA4A40BC9179E40FA041402E3D9AEAC9EC4A40AA0B789961A541402E3D9AEAC9EC4A40AA0B789961A5414098512CB7B4EA4A40BC9179E40FA0414098512CB7B4EA4A40
49020	Хотьково	1	6	324	35.203530000000001	35.241518999999997	53.775818999999998	53.755662999999998	0103000020E61000000100000005000000A0E062450D9A41400CE6AF90B9E04A40A0E062450D9A4140C64E78094EE34A406A2E3718EA9E4140C64E78094EE34A406A2E3718EA9E41400CE6AF90B9E04A40A0E062450D9A41400CE6AF90B9E04A40
16082	Хотисино	1	6	324	35.024909000000001	35.036138000000001	53.944977000000002	53.941257	0103000020E610000001000000050000002330D63730834140C710001C7BF84A402330D63730834140713C9F01F5F84A404912842BA0844140713C9F01F5F84A404912842BA0844140C710001C7BF84A402330D63730834140C710001C7BF84A40
1491	Пыренка	1	6	324	34.831662999999999	34.849234000000003	53.878936000000003	53.865265000000001	0103000020E610000001000000050000008925E5EE736A4140CDAFE600C1EE4A408925E5EE736A414077A38FF980F04A405D5320B3B36C414077A38FF980F04A405D5320B3B36C4140CDAFE600C1EE4A408925E5EE736A4140CDAFE600C1EE4A40
60464	Палики	1	6	324	34.925069999999998	34.944986	53.830643000000002	53.821151	0103000020E610000001000000050000005F419AB168764140F209D9791BE94A405F419AB1687641405FD3838252EA4A40C4961E4DF57841405FD3838252EA4A40C4961E4DF5784140F209D9791BE94A405F419AB168764140F209D9791BE94A40
4190	Новослободск	1	6	324	34.804983	34.825105000000001	53.970999999999997	53.963082	0103000020E61000000100000005000000016BD5AE09674140E2AE5E4546FB4A40016BD5AE096741403F355EBA49FC4A400F62670A9D6941403F355EBA49FC4A400F62670A9D694140E2AE5E4546FB4A40016BD5AE09674140E2AE5E4546FB4A40
45790	Маклаки	1	6	324	34.853338999999998	34.887160999999999	54.042093000000001	54.020484000000003	0103000020E610000001000000050000005FB35C363A6D4140AF0B3F389F024B405FB35C363A6D4140FD31AD4D63054B40B1A4DC7D8E714140FD31AD4D63054B40B1A4DC7D8E714140AF0B3F389F024B405FB35C363A6D4140AF0B3F389F024B40
28379	Которь	1	6	324	34.930145000000003	34.949539999999999	54.053167999999999	54.034647999999997	0103000020E61000000100000005000000DBC4C9FD0E774140976F7D586F044B40DBC4C9FD0E774140CC988235CE064B40361FD7868A794140CC988235CE064B40361FD7868A794140976F7D586F044B40DBC4C9FD0E774140976F7D586F044B40
28093	Думиничи	1	6	324	35.088158999999997	35.160131999999997	53.944378	53.884656999999997	0103000020E610000001000000050000008DEC4ACB488B4140B796C9703CF14A408DEC4ACB488B4140EC87D860E1F84A40838593347F944140EC87D860E1F84A40838593347F944140B796C9703CF14A408DEC4ACB488B4140B796C9703CF14A40
28283	Верхнее Гульцево	1	6	324	35.020498000000003	35.039695000000002	54.061185999999999	54.048425999999999	0103000020E6100000010000000500000014D1AFAD9F8241405723BBD232064B4014D1AFAD9F8241408D7C5EF1D4074B404968CBB9148541408D7C5EF1D4074B404968CBB9148541405723BBD232064B4014D1AFAD9F8241405723BBD232064B40
28537	Вертное	1	6	324	35.178314	35.206637999999998	53.955759999999998	53.945999999999998	0103000020E61000000100000005000000A0353FFED29641400C022B8716F94A40A0353FFED29641409869FB5756FA4A40300E2E1D739A41409869FB5756FA4A40300E2E1D739A41400C022B8716F94A40A0353FFED29641400C022B8716F94A40
27497	имени Ленина	1	6	1701	36.070377000000001	36.089447999999997	54.716709999999999	54.697811999999999	0103000020E61000000100000005000000FFB1101D02094240D06053E751594B40FFB1101D02094240AB5B3D27BD5B4B40A7583508730B4240AB5B3D27BD5B4B40A7583508730B4240D06053E751594B40FFB1101D02094240D06053E751594B40
22639	Якшуново	1	6	1701	35.933239999999998	35.944972	54.590707999999999	54.583002999999998	0103000020E61000000100000005000000D6A8876874F74140253CA1D79F4A4B40D6A8876874F7414027BEDA519C4B4B405FD1ADD7F4F8414027BEDA519C4B4B405FD1ADD7F4F84140253CA1D79F4A4B40D6A8876874F74140253CA1D79F4A4B40
54178	Товарково	1	6	1701	35.930500000000002	35.954619999999998	54.684297999999998	54.670414999999998	0103000020E61000000100000005000000C976BE9F1AF74140B9DFA128D0554B40C976BE9F1AF74140EE5BAD1397574B40C30DF8FC30FA4140EE5BAD1397574B40C30DF8FC30FA4140B9DFA128D0554B40C976BE9F1AF74140B9DFA128D0554B40
48315	Старки	1	6	1701	35.989078999999997	36.012462999999997	54.758972999999997	54.745677000000001	0103000020E61000000100000005000000871403249AFE414090300C58725F4B40871403249AFE414004C6FA0626614B407CB438639801424004C6FA0626614B407CB438639801424090300C58725F4B40871403249AFE414090300C58725F4B40
54237	Совхоз им. Ленина	1	6	1701	35.531424000000001	36.143545000000003	54.906486999999998	54.456871999999997	0103000020E610000001000000050000009E279EB305C44140A33A1DC87A3A4B409E279EB305C44140E49F19C407744B408E40BCAE5F124240E49F19C407744B408E40BCAE5F124240A33A1DC87A3A4B409E279EB305C44140A33A1DC87A3A4B40
54216	Совхоз им. Ленина	1	6	1701	35.531424000000001	36.143545000000003	54.906486999999998	54.456871999999997	0103000020E610000001000000050000009E279EB305C44140A33A1DC87A3A4B409E279EB305C44140E49F19C407744B408E40BCAE5F124240E49F19C407744B408E40BCAE5F124240A33A1DC87A3A4B409E279EB305C44140A33A1DC87A3A4B40
48220	Рудня	1	6	1701	35.867770999999998	35.888252999999999	54.672080999999999	54.655365000000003	0103000020E6100000010000000500000067B5C01E13EF4140B6F81400E3534B4067B5C01E13EF4140A9A10DC006564B4075C93846B2F14140A9A10DC006564B4075C93846B2F14140B6F81400E3534B4067B5C01E13EF4140B6F81400E3534B40
28025	Пятовский	1	6	1701	36.051602000000003	36.093688	54.696007000000002	54.685879999999997	0103000020E610000001000000050000004034F3E49A064240807D74EACA574B404034F3E49A064240BF64E3C116594B408A03E8F7FD0B4240BF64E3C116594B408A03E8F7FD0B4240807D74EACA574B404034F3E49A064240807D74EACA574B40
54205	Поселок Товарково	1	6	1701	35.531424000000001	36.143545000000003	54.906486999999998	54.456871999999997	0103000020E610000001000000050000009E279EB305C44140A33A1DC87A3A4B409E279EB305C44140E49F19C407744B408E40BCAE5F124240E49F19C407744B408E40BCAE5F124240A33A1DC87A3A4B409E279EB305C44140A33A1DC87A3A4B40
27349	Полотняный Завод	1	6	1701	35.950460999999997	36.012183999999998	54.750546	54.707718	0103000020E61000000100000005000000CD8FBFB4A8F941403065E080965A4B40CD8FBFB4A8F9414062122EE411604B4069C4CC3E8F01424062122EE411604B4069C4CC3E8F0142403065E080965A4B40CD8FBFB4A8F941403065E080965A4B40
46425	Покров	1	6	1701	35.706982000000004	35.717851000000003	54.724027	54.717911999999998	0103000020E610000001000000050000002B6EDC627EDA4140F6B3588AE45B4B402B6EDC627EDA4140E335AFEAAC5C4B405133A48AE2DB4140E335AFEAAC5C4B405133A48AE2DB4140F6B3588AE45B4B402B6EDC627EDA4140F6B3588AE45B4B40
27865	Острожное	1	6	1701	35.726035000000003	35.747171999999999	54.806215999999999	54.801935	0103000020E610000001000000050000002D6002B7EEDC414046425BCEA5664B402D6002B7EEDC414087C1FC1532674B40533E0455A3DF414087C1FC1532674B40533E0455A3DF414046425BCEA5664B402D6002B7EEDC414046425BCEA5664B40
27818	Маковцы	1	6	1701	35.998835	36.027985000000001	54.857621000000002	54.838394999999998	0103000020E61000000100000005000000D28C45D3D9FF4140A1100187506B4B40D28C45D3D9FF414071AE6186C66D4B40A8E331039503424071AE6186C66D4B40A8E3310395034240A1100187506B4B40D28C45D3D9FF4140A1100187506B4B40
46550	Льва Толстого	1	6	1701	36.019748	36.053443999999999	54.614364999999999	54.601396000000001	0103000020E61000000100000005000000A9143B1A87024240FDF84B8BFA4C4B40A9143B1A870242404D672783A34E4B406E15C440D70642404D672783A34E4B406E15C440D7064240FDF84B8BFA4C4B40A9143B1A87024240FDF84B8BFA4C4B40
48244	Лужное	1	6	1701	35.731721	35.748779999999996	54.712279000000002	54.700246999999997	0103000020E61000000100000005000000F165A208A9DD4140A10F96B1A1594B40F165A208A9DD4140555051F52B5B4B400EF3E505D8DF4140555051F52B5B4B400EF3E505D8DF4140A10F96B1A1594B40F165A208A9DD4140A10F96B1A1594B40
28009	Куровской	1	6	1701	36.012597	36.030284999999999	54.537942999999999	54.527191999999999	0103000020E610000001000000050000008C834BC79C0142403E5B07077B434B408C834BC79C0142405A0EF450DB444B409947FE60E00342405A0EF450DB444B409947FE60E00342403E5B07077B434B408C834BC79C0142403E5B07077B434B40
26997	Кондрово	1	6	1701	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
46736	Кожухово	1	6	1701	35.905842	35.929952	54.573217999999997	54.562987999999997	0103000020E61000000100000005000000EFAB72A1F2F341402D05A4FD0F484B40EFAB72A1F2F3414040BD19355F494B40C66CC9AA08F7414040BD19355F494B40C66CC9AA08F741402D05A4FD0F484B40EFAB72A1F2F341402D05A4FD0F484B40
26845	Карцово	1	6	1701	36.021678999999999	36.045448999999998	54.799354999999998	54.779384999999998	0103000020E610000001000000050000004701A260C602424019FF3EE3C2634B404701A260C60242407172BF4351664B406551D845D10542407172BF4351664B406551D845D105424019FF3EE3C2634B404701A260C602424019FF3EE3C2634B40
27923	Звизжи	1	6	1701	35.636239000000003	35.656756999999999	54.749341000000001	54.737828999999998	0103000020E610000001000000050000004AB8904770D141402B85402E715E4B404AB8904770D14140A646E867EA5F4B40A435069D10D44140A646E867EA5F4B40A435069D10D441402B85402E715E4B404AB8904770D141402B85402E715E4B40
26935	Жилетово	1	6	1701	36.008699	36.031722000000002	54.704258000000003	54.691333999999998	0103000020E610000001000000050000000341800C1D014240724EECA17D584B400341800C1D01424023F94A20255A4B4028486C770F04424023F94A20255A4B4028486C770F044240724EECA17D584B400341800C1D014240724EECA17D584B40
48256	Дубинино	1	6	1701	35.873781000000001	35.902293	54.782640000000001	54.765264000000002	0103000020E61000000100000005000000DF6E490ED8EF41403067B62BF4614B40DF6E490ED8EF41404E452A8C2D644B40723447567EF341404E452A8C2D644B40723447567EF341403067B62BF4614B40DF6E490ED8EF41403067B62BF4614B40
46673	Дворцы	1	6	1701	35.986069999999998	36.022190999999999	54.623742999999997	54.606914000000003	0103000020E610000001000000050000008AC8B08A37FE414006BEA25BAF4D4B408AC8B08A37FE4140F10D85CFD64F4B40FDA19927D7024240F10D85CFD64F4B40FDA19927D702424006BEA25BAF4D4B408AC8B08A37FE414006BEA25BAF4D4B40
47719	Горки	1	6	1701	35.691656000000002	35.699399999999997	54.632640000000002	54.628146999999998	0103000020E61000000100000005000000850A0E2F88D841404E0AF31E67504B40850A0E2F88D841401B12F758FA504B4044696FF085D941401B12F758FA504B4044696FF085D941404E0AF31E67504B40850A0E2F88D841404E0AF31E67504B40
48336	Бели	1	6	1701	35.902949	35.917546999999999	54.718853000000003	54.707000000000001	0103000020E610000001000000050000005B7A34D593F34140D122DBF97E5A4B405B7A34D593F34140D5D00660035C4B407EC51A2E72F54140D5D00660035C4B407EC51A2E72F54140D122DBF97E5A4B405B7A34D593F34140D122DBF97E5A4B40
26406	Совьяки	1	6	1770	36.422831000000002	36.435721999999998	55.232156000000003	55.225876	0103000020E61000000100000005000000145E82531F364240C4793881E99C4B40145E82531F364240FCC8AD49B79D4B40E8120EBDC5374240FCC8AD49B79D4B40E8120EBDC5374240C4793881E99C4B40145E82531F364240C4793881E99C4B40
54201	Совхоз Боровской	1	6	1770	36.031184000000003	36.668889	55.286270999999999	55.072788000000003	0103000020E6100000010000000500000049145AD6FD03424048C5FF1D51894B4049145AD6FD03424088653387A4A44B40BBD39D279E55424088653387A4A44B40BBD39D279E55424048C5FF1D51894B4049145AD6FD03424048C5FF1D51894B40
25278	Серединское	1	6	1770	36.164808000000001	36.177905000000003	55.162740999999997	55.151764999999997	0103000020E61000000100000005000000410FB56D18154240B6D617096D934B40410FB56D18154240F25B74B2D4944B40BF654E97C5164240F25B74B2D4944B40BF654E97C5164240B6D617096D934B40410FB56D18154240B6D617096D934B40
26415	Митяево	1	6	1770	36.525913000000003	36.563668999999997	55.286270999999999	55.263649999999998	0103000020E6100000010000000500000048C5FF1D5143424092CB7F48BFA14B4048C5FF1D5143424088653387A4A44B406F62484E2648424088653387A4A44B406F62484E2648424092CB7F48BFA14B4048C5FF1D5143424092CB7F48BFA14B40
54194	Кривское	1	6	1770	36.031184000000003	36.668889	55.286270999999999	55.072788000000003	0103000020E6100000010000000500000049145AD6FD03424048C5FF1D51894B4049145AD6FD03424088653387A4A44B40BBD39D279E55424088653387A4A44B40BBD39D279E55424048C5FF1D51894B4049145AD6FD03424048C5FF1D51894B40
25315	Коростелево	1	6	1770	36.134337000000002	36.158205000000002	55.133225000000003	55.118873999999998	0103000020E6100000010000000500000046D26EF4311142401F2C6343378F4B4046D26EF4311142403B014D840D914B402788BA0F401442403B014D840D914B402788BA0F401442401F2C6343378F4B4046D26EF4311142401F2C6343378F4B40
54232	Комлево	1	6	1770	36.031184000000003	36.668889	55.286270999999999	55.072788000000003	0103000020E6100000010000000500000049145AD6FD03424048C5FF1D51894B4049145AD6FD03424088653387A4A44B40BBD39D279E55424088653387A4A44B40BBD39D279E55424048C5FF1D51894B4049145AD6FD03424048C5FF1D51894B40
25369	Борисово	1	6	1770	36.073385999999999	36.086888000000002	55.180813999999998	55.170366999999999	0103000020E61000000100000005000000FCFD62B664094240A8A8FA95CE954B40FCFD62B6640942405854C4E924974B401A355F251F0B42405854C4E924974B401A355F251F0B4240A8A8FA95CE954B40FCFD62B664094240A8A8FA95CE954B40
25212	Асеньевское	1	6	1770	36.301054999999998	36.313901000000001	55.130147999999998	55.121160000000003	0103000020E610000001000000050000000DA661F888264240ACCABE2B828F4B400DA661F888264240E5D18DB0A8904B40429770E82D284240E5D18DB0A8904B40429770E82D284240ACCABE2B828F4B400DA661F888264240ACCABE2B828F4B40
47529	Шершнево	1	6	514	34.511045000000003	34.528858999999997	54.353439000000002	54.339426000000003	0103000020E6100000010000000500000065E42CEC69414140C0B4A84F722B4B4065E42CEC69414140C310397D3D2D4B40FE98D6A6B1434140C310397D3D2D4B40FE98D6A6B1434140C0B4A84F722B4B4065E42CEC69414140C0B4A84F722B4B40
47505	Цветовка	1	6	514	34.397857999999999	34.429496	54.486538000000003	54.467306999999998	0103000020E61000000100000005000000DA39CD02ED3241408F183DB7D03B4B40DA39CD02ED32414071218FE0463E4B40A4E194B9F936414071218FE0463E4B40A4E194B9F93641408F183DB7D03B4B40DA39CD02ED3241408F183DB7D03B4B40
47456	Плетни	1	6	514	34.677287999999997	34.703465000000001	54.403236	54.395175000000002	0103000020E6100000010000000500000093FC885FB156414031992A1895324B4093FC885FB1564140F148BC3C9D334B40B97020240B5A4140F148BC3C9D334B40B97020240B5A414031992A1895324B4093FC885FB156414031992A1895324B40
24613	Перенежье	1	6	514	34.454873999999997	34.483108000000001	54.264254000000001	54.250664	0103000020E610000001000000050000007DE6AC4F393A41406C2409C215204B407DE6AC4F393A414029EB3713D3214B40CE37A27BD63D414029EB3713D3214B40CE37A27BD63D41406C2409C215204B407DE6AC4F393A41406C2409C215204B40
24536	Милотичи	1	6	514	34.473936000000002	34.508889000000003	54.230553999999998	54.221026999999999	0103000020E61000000100000005000000D33252EFA93C41403944DC9C4A1C4B40D33252EFA93C414022FB20CB821D4B40A72556462341414022FB20CB821D4B40A7255646234141403944DC9C4A1C4B40D33252EFA93C41403944DC9C4A1C4B40
24511	Крисаново-Пятница	1	6	514	34.619041000000003	34.635651000000003	54.377091999999998	54.358936999999997	0103000020E610000001000000050000000BF148BC3C4F41408429CAA5F12D4B400BF148BC3C4F4140A7CAF78C44304B40B95510035D514140A7CAF78C44304B40B95510035D5141408429CAA5F12D4B400BF148BC3C4F41408429CAA5F12D4B40
9565	Заречный	1	6	514	34.603231000000001	34.609347999999997	54.191699999999997	54.188116999999998	0103000020E61000000100000005000000797764AC364D41402B69C53714184B40797764AC364D4140545227A089184B4006F1811DFF4D4140545227A089184B4006F1811DFF4D41402B69C53714184B40797764AC364D41402B69C53714184B40
60401	Жданово	1	6	514	34.666651999999999	34.678707000000003	54.275900999999998	54.268877000000003	0103000020E6100000010000000500000010E84CDA54554140C4D2C08F6A224B4010E84CDA5455414083F755B950234B407C48F8DEDF56414083F755B950234B407C48F8DEDF564140C4D2C08F6A224B4010E84CDA54554140C4D2C08F6A224B40
48262	Добрая	1	6	514	34.581913	34.60933	54.434249999999999	54.419877	0103000020E61000000100000005000000020F0C207C4A4140DAAB8F87BE354B40020F0C207C4A4140DD24068195374B40603C8386FE4D4140DD24068195374B40603C8386FE4D4140DAAB8F87BE354B40020F0C207C4A4140DAAB8F87BE354B40
60383	Глазово	1	6	514	34.540025	34.560488999999997	54.451884	54.439642999999997	0103000020E61000000100000005000000DE02098A1F4541402975C93846384B40DE02098A1F454140F7CABC55D7394B404562821ABE474140F7CABC55D7394B404562821ABE4741402975C93846384B40DE02098A1F4541402975C93846384B40
47084	Бахмутово	1	6	514	34.296680000000002	34.316406999999998	54.355615999999998	54.341588999999999	0103000020E610000001000000050000004BB0389CF925414030D63730B92B4B404BB0389CF925414098F738D3842D4B40DC9C4A068028414098F738D3842D4B40DC9C4A068028414030D63730B92B4B404BB0389CF925414030D63730B92B4B40
46873	Барятино	1	6	514	34.489530999999999	34.547714999999997	54.318640000000002	54.288406000000002	0103000020E6100000010000000500000068B0A9F3A83E41402FFCE07CEA244B4068B0A9F3A83E414046990D32C9284B40AA436E861B46414046990D32C9284B40AA436E861B4641402FFCE07CEA244B4068B0A9F3A83E41402FFCE07CEA244B40
47375	Асмолово	1	6	514	34.646169999999998	34.662770999999999	54.227584999999998	54.212324000000002	0103000020E6100000010000000500000002D4D4B2B5524140F513CE6E2D1B4B4002D4D4B2B5524140B3075A81211D4B405DDE1CAED5544140B3075A81211D4B405DDE1CAED5544140F513CE6E2D1B4B4002D4D4B2B5524140F513CE6E2D1B4B40
24083	Утешево	1	6	1269	35.662667999999996	35.703432999999997	54.521856999999997	54.509276999999997	0103000020E61000000100000005000000880D164ED2D4414070CD1DFD2F414B40880D164ED2D441402618CE35CC424B40ADF6B0170ADA41402618CE35CC424B40ADF6B0170ADA414070CD1DFD2F414B40880D164ED2D4414070CD1DFD2F414B40
45391	Слобода	1	6	1269	35.714410999999998	35.721822000000003	54.394263000000002	54.387264000000002	0103000020E610000001000000050000008A73D4D171DB41408675E3DD91314B408A73D4D171DB4140ED82C13577324B4044C4CDA964DC4140ED82C13577324B4044C4CDA964DC41408675E3DD91314B408A73D4D171DB41408675E3DD91314B40
23991	Садовый	1	6	1269	35.872684999999997	35.890022000000002	54.475406	54.463566	0103000020E61000000100000005000000D95A5F24B4EF4140CEC47421563B4B40D95A5F24B4EF41403D29931ADA3C4B403A5CAB3DECF141403D29931ADA3C4B403A5CAB3DECF14140CEC47421563B4B40D95A5F24B4EF4140CEC47421563B4B40
54229	Сабуровщина	1	6	1269	35.643165000000003	35.663808000000003	54.432490000000001	54.422773999999997	0103000020E610000001000000050000004777103B53D24140AFCC5B751D364B404777103B53D241406CEC12D55B374B405E6919A9F7D441406CEC12D55B374B405E6919A9F7D44140AFCC5B751D364B404777103B53D24140AFCC5B751D364B40
23884	Пятницкое	1	6	1269	35.867806999999999	35.901646	54.348788999999996	54.336623000000003	0103000020E61000000100000005000000B41EBE4C14EF41406C0A6476162B4B40B41EBE4C14EF41402E1A321EA52C4B40DC48D92269F341402E1A321EA52C4B40DC48D92269F341406C0A6476162B4B40B41EBE4C14EF41406C0A6476162B4B40
24140	Поповские Хутора	1	6	1269	35.921678999999997	35.938611999999999	54.438454999999998	54.429285	0103000020E610000001000000050000007A34D593F9F54140E9D495CFF2364B407A34D593F9F5414043E21E4B1F384B400BD1217024F8414043E21E4B1F384B400BD1217024F84140E9D495CFF2364B407A34D593F9F54140E9D495CFF2364B40
23850	Никольское	1	6	1269	35.865867000000001	35.896203	54.297117999999998	54.285373	0103000020E61000000100000005000000C3D7D7BAD4EE4140A9143B1A87244B40C3D7D7BAD4EE4140C6866EF607264B40DEC9A7C7B6F24140C6866EF607264B40DEC9A7C7B6F24140A9143B1A87244B40C3D7D7BAD4EE4140A9143B1A87244B40
23813	Муромцево	1	6	1269	35.937874999999998	35.957369	54.512377000000001	54.502873000000001	0103000020E61000000100000005000000355EBA490CF841404D8578245E404B40355EBA490CF841407E1CCD9195414B40249A40118BFA41407E1CCD9195414B40249A40118BFA41404D8578245E404B40355EBA490CF841404D8578245E404B40
13224	Ленское	1	6	1269	35.885961999999999	35.899220999999997	54.441094	54.433002999999999	0103000020E61000000100000005000000D7BFEB3367F14140F2086EA46C374B40D7BFEB3367F141401D3BA8C475384B402E7079AC19F341401D3BA8C475384B402E7079AC19F34140F2086EA46C374B40D7BFEB3367F14140F2086EA46C374B40
23705	Лапино	1	6	1269	35.838028000000001	35.860188999999998	54.381030000000003	54.367215999999999	0103000020E61000000100000005000000EF90628044EB4140B24813EF002F4B40EF90628044EB4140BF654E97C5304B4081B053AC1AEE4140BF654E97C5304B4081B053AC1AEE4140B24813EF002F4B40EF90628044EB4140B24813EF002F4B40
23685	Куракино	1	6	1269	35.791567000000001	35.811348000000002	54.505268000000001	54.494486999999999	0103000020E61000000100000005000000E2CB441152E5414009A69A594B3F4B40E2CB441152E5414090DB2F9FAC404B4067D65240DAE7414090DB2F9FAC404B4067D65240DAE7414009A69A594B3F4B40E2CB441152E5414009A69A594B3F4B40
24210	Кумовское	1	6	1269	35.958438000000001	35.975352999999998	54.473334999999999	54.462577000000003	0103000020E61000000100000005000000309FAC18AEFA4140DF701FB9353B4B40309FAC18AEFA4140AD86C43D963C4B401A87FA5DD8FC4140AD86C43D963C4B401A87FA5DD8FC4140DF701FB9353B4B40309FAC18AEFA4140DF701FB9353B4B40
54209	Газопровода	1	6	1269	35.571748999999997	35.596704000000003	54.444419000000003	54.434365	0103000020E61000000100000005000000A6423C122FC9414076C3B64599374B40A6423C122FC941404B5CC7B8E2384B403AB2F2CB60CC41404B5CC7B8E2384B403AB2F2CB60CC414076C3B64599374B40A6423C122FC9414076C3B64599374B40
24227	Воротынск	1	6	1269	36.029179999999997	36.067304999999998	54.482976000000001	54.458452999999999	0103000020E6100000010000000500000040D9942BBC03424065E08096AE3A4B4040D9942BBC0342405F605628D23D4B40BBED42739D0842405F605628D23D4B40BBED42739D08424065E08096AE3A4B4040D9942BBC03424065E08096AE3A4B40
23549	Воронино	1	6	1269	35.590488000000001	35.630149000000003	54.534526999999997	54.522514999999999	0103000020E6100000010000000500000019575C1C95CB4140B05582C5E1424B4019575C1C95CB41401CEA77616B444B40B64DF1B8A8D041401CEA77616B444B40B64DF1B8A8D04140B05582C5E1424B4019575C1C95CB4140B05582C5E1424B40
54221	Бабынинское отделение	1	6	1269	35.453494999999997	36.080196000000001	54.573698	54.224800999999999	0103000020E6100000010000000500000023F3C81F0CBA4140D68D7747C61C4B4023F3C81F0CBA4140EBE3A1EF6E494B4090A2CEDC430A4240EBE3A1EF6E494B4090A2CEDC430A4240D68D7747C61C4B4023F3C81F0CBA4140D68D7747C61C4B40
23389	Бабынино	1	6	1269	35.757511999999998	35.776637000000001	54.398828000000002	54.384469000000003	0103000020E61000000100000005000000ED293927F6E04140B5A9BA4736314B40ED293927F6E04140535DC0CB0C334B4089EE59D768E34140535DC0CB0C334B4089EE59D768E34140B5A9BA4736314B40ED293927F6E04140B5A9BA4736314B40
23340	Антопьево	1	6	1269	35.751573999999998	35.769396	54.333646999999999	54.317847	0103000020E610000001000000050000000F43AB9333E04140DC10E335AF284B400F43AB9333E041404AB4E4F1B42A4B402CD670917BE241404AB4E4F1B42A4B402CD670917BE24140DC10E335AF284B400F43AB9333E04140DC10E335AF284B40
54128	с. Пригородное	1	5	\N	39.376123	43.324883999999997	57.739004000000001	56.350422000000002	0103000020E61000000100000005000000FF2268CC24B0434043E6CAA0DA2C4C40FF2268CC24B043407DCEDDAE97DE4C40307F85CC95A945407DCEDDAE97DE4C40307F85CC95A9454043E6CAA0DA2C4C40FF2268CC24B0434043E6CAA0DA2C4C40
54107	Юрьевец	1	5	\N	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
54083	Шуя	1	5	\N	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
54100	Фурманов	1	5	\N	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
54076	Тейково	1	5	\N	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
54104	Родники	1	5	\N	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
54105	Пучеж	1	5	\N	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
54094	Приволжск	1	5	\N	41.264113000000002	41.316457	57.399667000000001	57.364691000000001	0103000020E6100000010000000500000067B96C74CEA14440A112D731AEAE4C4067B96C74CEA144402D25CB4928B34C408ECBB8A981A844402D25CB4928B34C408ECBB8A981A84440A112D731AEAE4C4067B96C74CEA14440A112D731AEAE4C40
54109	Плес	1	5	\N	41.485214999999997	41.532862000000002	57.465733	57.448134000000003	0103000020E61000000100000005000000AA436E861BBE4440E31C75745CB94C40AA436E861BBE444080D591239DBB4C40FDA36FD234C4444080D591239DBB4C40FDA36FD234C44440E31C75745CB94C40AA436E861BBE4440E31C75745CB94C40
54103	Наволоки	1	5	\N	41.925775999999999	41.996284000000003	57.480649	57.455585999999997	0103000020E61000000100000005000000FAB5F5D37FF64440FA415DA450BA4C40FAB5F5D37FF6444074ED0BE885BD4C4098C3EE3B86FF444074ED0BE885BD4C4098C3EE3B86FF4440FA415DA450BA4C40FAB5F5D37FF64440FA415DA450BA4C40
54092	Кохма	1	5	\N	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
54095	Комсомольск	1	5	\N	40.356338000000001	40.391829999999999	57.042841000000003	57.014111	0103000020E610000001000000050000003929CC7B9C2D4440C6C1A563CE814C403929CC7B9C2D4440C7F65AD07B854C40BCCB457C27324440C7F65AD07B854C40BCCB457C27324440C6C1A563CE814C403929CC7B9C2D4440C6C1A563CE814C40
21279	Коляново	1	5	\N	40.955595000000002	40.981403999999998	56.953968000000003	56.941600999999999	0103000020E610000001000000050000004E9CDCEF507A4440C170AE6186784C404E9CDCEF507A44401CB7989F1B7A4C40F01472A59E7D44401CB7989F1B7A4C40F01472A59E7D4440C170AE6186784C404E9CDCEF507A4440C170AE6186784C40
6105	Кинешма	1	5	\N	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
429	Иваново	1	5	\N	40.867938000000002	41.125475999999999	57.07038	56.946736999999999	0103000020E61000000100000005000000537AA697186F4440E27492AD2E794C40537AA697186F444070253B3602894C406937FA980F90444070253B3602894C406937FA980F904440E27492AD2E794C40537AA697186F4440E27492AD2E794C40
54096	Заволжск	1	5	\N	42.105114999999998	42.193752000000003	57.502479000000001	57.454109000000003	0103000020E61000000100000005000000D6A88768740D4540DEE8633E20BA4C40D6A88768740D4540A1F65B3B51C04C406EC493DDCC184540A1F65B3B51C04C406EC493DDCC184540DEE8633E20BA4C40D6A88768740D4540DEE8633E20BA4C40
54123	Железнодорожный	1	5	\N	39.376123	43.324883999999997	57.739004000000001	56.350422000000002	0103000020E61000000100000005000000FF2268CC24B0434043E6CAA0DA2C4C40FF2268CC24B043407DCEDDAE97DE4C40307F85CC95A945407DCEDDAE97DE4C40307F85CC95A9454043E6CAA0DA2C4C40FF2268CC24B0434043E6CAA0DA2C4C40
54075	Вичуга	1	5	\N	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
46088	Ямская	1	5	557	43.081215999999998	43.093567999999998	57.300815	57.292524	0103000020E61000000100000005000000BAF42F49658A4540C6A52A6D71A54C40BAF42F49658A4540B8921D1B81A64C40DFF94509FA8B4540B8921D1B81A64C40DFF94509FA8B4540C6A52A6D71A54C40BAF42F49658A4540C6A52A6D71A54C40
3460	Юрьевец	1	5	557	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
4328	Щекотиха	1	5	557	42.960535999999998	42.985159000000003	57.245068000000003	57.235872000000001	0103000020E61000000100000005000000B950F9D7F27A45406405BF0D319E4C40B950F9D7F27A4540E8A562635E9F4C40172EABB0197E4540E8A562635E9F4C40172EABB0197E45406405BF0D319E4C40B950F9D7F27A45406405BF0D319E4C40
3862	Тихон-Воля	1	5	557	43.013159000000002	43.027540999999999	57.306590999999997	57.299337000000001	0103000020E61000000100000005000000F452B131AF814540CBBDC0AC50A64C40F452B131AF814540BC1FB75F3EA74C404A26A77686834540BC1FB75F3EA74C404A26A77686834540CBBDC0AC50A64C40F452B131AF814540CBBDC0AC50A64C40
47709	Соболево	1	5	557	43.015009999999997	43.044133000000002	57.267915000000002	57.257283999999999	0103000020E61000000100000005000000758E01D9EB8145405CE49EAEEEA04C40758E01D9EB814540CE8DE9094BA24C4052D66F26A6854540CE8DE9094BA24C4052D66F26A68545405CE49EAEEEA04C40758E01D9EB8145405CE49EAEEEA04C40
46012	Пелевино	1	5	557	42.941806	42.963571999999999	57.322519999999997	57.316124000000002	0103000020E610000001000000050000009A9658198D78454088BD50C076A84C409A9658198D7845402827DA5548A94C40B0ABC953567B45402827DA5548A94C40B0ABC953567B454088BD50C076A84C409A9658198D78454088BD50C076A84C40
4452	Обжериха	1	5	557	42.952272000000001	42.972195999999997	57.183661000000001	57.173009999999998	0103000020E61000000100000005000000C172840CE4794540C3F0113125964C40C172840CE47945407C46223482974C40A8A624EB707C45407C46223482974C40A8A624EB707C4540C3F0113125964C40C172840CE4794540C3F0113125964C40
37443	Новленское	1	5	557	42.985294000000003	43.003008000000001	57.148527000000001	57.140675000000002	0103000020E61000000100000005000000F778211D1E7E4540B22E6EA301924C40F778211D1E7E454058C9C7EE02934C402DD0EE906280454058C9C7EE02934C402DD0EE9062804540B22E6EA301924C40F778211D1E7E4540B22E6EA301924C40
46076	Михайлово	1	5	557	42.751283000000001	42.783163999999999	57.342230000000001	57.333938000000003	0103000020E610000001000000050000003885950A2A6045402272FA7ABEAA4C403885950A2A604540E4DA5031CEAB4C40C8B3CBB73E644540E4DA5031CEAB4C40C8B3CBB73E6445402272FA7ABEAA4C403885950A2A6045402272FA7ABEAA4C40
3887	Лобаны	1	5	557	43.039920000000002	43.055883000000001	57.350675000000003	57.340651000000001	0103000020E61000000100000005000000693A3B191C854540C32CB4739AAB4C40693A3B191C8545402D431CEBE2AC4C4081B3942C278745402D431CEBE2AC4C4081B3942C27874540C32CB4739AAB4C40693A3B191C854540C32CB4739AAB4C40
4388	Костяево-Большое	1	5	557	42.720632000000002	42.737169999999999	57.264882999999998	57.254109999999997	0103000020E61000000100000005000000BD395CAB3D5C454014CB2DAD86A04C40BD395CAB3D5C45401822A7AFE7A14C40D1CB28965B5E45401822A7AFE7A14C40D1CB28965B5E454014CB2DAD86A04C40BD395CAB3D5C454014CB2DAD86A04C40
46264	Жуковка	1	5	557	42.881627999999999	42.899324999999997	57.225597999999998	57.221187999999998	0103000020E61000000100000005000000739EB12FD970454042226DE34F9C4C40739EB12FD970454081053065E09C4C40D3BCE3141D73454081053065E09C4C40D3BCE3141D73454042226DE34F9C4C40739EB12FD970454042226DE34F9C4C40
4081	Елнать	1	5	557	42.807751000000003	42.842426000000003	57.346203000000003	57.330032000000003	0103000020E61000000100000005000000D9278062646745401651137D3EAA4C40D9278062646745407863416150AC4C406AA67B9DD46B45407863416150AC4C406AA67B9DD46B45401651137D3EAA4C40D9278062646745401651137D3EAA4C40
46028	Дорки	1	5	557	42.831547	42.854086000000002	57.293399000000001	57.283884999999998	0103000020E61000000100000005000000200BD121706A45409869FB5756A44C40200BD121706A4540EDD632198EA54C4059FCA6B0526D4540EDD632198EA54C4059FCA6B0526D45409869FB5756A44C40200BD121706A45409869FB5756A44C40
46128	Ваньково	1	5	557	42.698300000000003	42.714055999999999	57.280707999999997	57.271447999999999	0103000020E61000000100000005000000FE65F7E4615945404548DDCEBEA24C40FE65F7E461594540DFDC5F3DEEA34C409CC1DF2F665B4540DFDC5F3DEEA34C409CC1DF2F665B45404548DDCEBEA24C40FE65F7E4615945404548DDCEBEA24C40
2087	Южа	1	5	399	41.969631	42.053533999999999	56.601534999999998	56.568371999999997	0103000020E6100000010000000500000009185DDE1CFC444026FBE769C0484C4009185DDE1CFC44401E335019FF4C4C40AE9CBD33DA0645401E335019FF4C4C40AE9CBD33DA06454026FBE769C0484C4009185DDE1CFC444026FBE769C0484C40
3347	Хотимль	1	5	399	41.692428999999997	41.71848	56.660407999999997	56.650686	0103000020E61000000100000005000000A7E67283A1D8444087FBC8AD49534C40A7E67283A1D844402502D53F88544C40406A1327F7DB44402502D53F88544C40406A1327F7DB444087FBC8AD49534C40A7E67283A1D8444087FBC8AD49534C40
54111	Холуй	1	5	399	41.845852999999998	41.883356999999997	56.584094999999998	56.570554000000001	0103000020E610000001000000050000009B1C3EE944EC44400E4DD9E907494C409B1C3EE944EC4440E960FD9FC34A4C40A9D898D711F14440E960FD9FC34A4C40A9D898D711F144400E4DD9E907494C409B1C3EE944EC44400E4DD9E907494C40
2656	Талицы	1	5	399	42.316040000000001	42.346969000000001	56.536957000000001	56.518557999999999	0103000020E610000001000000050000002A1DACFF73284540228AC91B60424C402A1DACFF73284540DC2DC901BB444C40E8DCED7A692C4540DC2DC901BB444C40E8DCED7A692C4540228AC91B60424C402A1DACFF73284540228AC91B60424C40
3027	Селищи	1	5	399	41.818409000000003	41.841549999999998	56.607872	56.598165999999999	0103000020E6100000010000000500000044E048A0C1E8444021CA17B4904C4C4044E048A0C1E84440BA13ECBFCE4D4C4072F90FE9B7EB4440BA13ECBFCE4D4C4072F90FE9B7EB444021CA17B4904C4C4044E048A0C1E8444021CA17B4904C4C40
3277	Преображенское	1	5	399	41.816217000000002	41.846850000000003	56.655633999999999	56.644464999999997	0103000020E6100000010000000500000039B874CC79E84440543541D47D524C4039B874CC79E84440A5129ED0EB534C400E4FAF9465EC4440A5129ED0EB534C400E4FAF9465EC4440543541D47D524C4039B874CC79E84440543541D47D524C40
2892	Новоклязьминское	1	5	399	41.999077999999997	42.026350999999998	56.437328000000001	56.423575	0103000020E610000001000000050000009813B4C9E1FF44409C33A2B437364C409813B4C9E1FF444003D0285DFA374C40C39B35785F03454003D0285DFA374C40C39B35785F0345409C33A2B437364C409813B4C9E1FF44409C33A2B437364C40
2464	Нефедово	1	5	399	41.998987999999997	42.016981999999999	56.60915	56.596198000000001	0103000020E61000000100000005000000588CBAD6DEFF444066F84F37504C4C40588CBAD6DEFF4440E02D90A0F84D4C40724F57772C024540E02D90A0F84D4C40724F57772C02454066F84F37504C4C40588CBAD6DEFF444066F84F37504C4C40
2688	Мугреевский	1	5	399	42.340797000000002	42.373694	56.604483000000002	56.591068999999997	0103000020E6100000010000000500000097C9703C9F2B4540F7562426A84B4C4097C9703C9F2B454076FEEDB25F4D4C40105B7A34D52F454076FEEDB25F4D4C40105B7A34D52F4540F7562426A84B4C4097C9703C9F2B4540F7562426A84B4C40
2568	Мугреево-Никольское	1	5	399	42.214539000000002	42.252034999999999	56.639668999999998	56.623068000000004	0103000020E61000000100000005000000B85B9203761B4540929735B1C04F4C40B85B9203761B4540ECA17DACE0514C404339D1AE42204540ECA17DACE0514C404339D1AE42204540929735B1C04F4C40B85B9203761B4540929735B1C04F4C40
2768	Моста	1	5	399	42.151001000000001	42.173872000000003	56.537939000000001	56.522570000000002	0103000020E61000000100000005000000E75432005413454074EFE192E3424C40E754320054134540191F662FDB444C4056D80C7041164540191F662FDB444C4056D80C704116454074EFE192E3424C40E75432005413454074EFE192E3424C40
3157	Мордовское	1	5	399	41.855375000000002	41.875165000000003	56.558323000000001	56.549576999999999	0103000020E61000000100000005000000736891ED7CED444020D1048A58464C40736891ED7CED444064CDC82077474C404BCD1E6805F0444064CDC82077474C404BCD1E6805F0444020D1048A58464C40736891ED7CED444020D1048A58464C40
3238	Изотино	1	5	399	41.685979000000003	41.710369	56.552667999999997	56.542267000000002	0103000020E61000000100000005000000145FED28CED744409B594B0169454C40145FED28CED74440DAC534D3BD464C40CE8B135FEDDA4440DAC534D3BD464C40CE8B135FEDDA44409B594B0169454C40145FED28CED744409B594B0169454C40
2544	Груздево	1	5	399	42.059157999999996	42.069749000000002	56.709038	56.700775999999998	0103000020E61000000100000005000000FCA5457D920745402DE92807B3594C40FCA5457D9207454085CFD6C1C15A4C40E0F60489ED08454085CFD6C1C15A4C40E0F60489ED0845402DE92807B3594C40FCA5457D920745402DE92807B3594C40
54093	Шуя	1	5	1438	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
1164	Чижово	1	5	177	41.467697999999999	41.485413000000001	56.892758000000001	56.880189000000001	0103000020E61000000100000005000000CA332F87DDBB444044A67C08AA704C40CA332F87DDBB4440069FE6E445724C40D106600322BE4440069FE6E445724C40D106600322BE444044A67C08AA704C40CA332F87DDBB444044A67C08AA704C40
1039	Чечкино-Богородское	1	5	177	41.622135999999998	41.650092000000001	56.985799999999998	56.976661999999997	0103000020E6100000010000000500000006D50627A2CF44407B9FAA42037D4C4006D50627A2CF4440CA32C4B12E7E4C4014B2F33636D34440CA32C4B12E7E4C4014B2F33636D344407B9FAA42037D4C4006D50627A2CF44407B9FAA42037D4C40
1305	Чернцы	1	5	177	41.332861000000001	41.352651000000002	56.948307999999997	56.930193000000003	0103000020E61000000100000005000000938E72309BAA4440ECFB709010774C40938E72309BAA44408044132862794C406BF3FFAA23AD44408044132862794C406BF3FFAA23AD4440ECFB709010774C40938E72309BAA4440ECFB709010774C40
585	Центральный	1	5	177	41.368084000000003	41.388717999999997	56.751947999999999	56.733086	0103000020E61000000100000005000000271763601DAF4440E69315C3D55D4C40271763601DAF4440742502D53F604C40EAAEEC82C1B14440742502D53F604C40EAAEEC82C1B14440E69315C3D55D4C40271763601DAF4440E69315C3D55D4C40
1664	Харитоново	1	5	177	41.577067999999997	41.597988999999998	56.797753	56.787863999999999	0103000020E61000000100000005000000B8C83D5DDDC944400ED940BAD8644C40B8C83D5DDDC9444098A432C51C664C40122F4FE78ACC444098A432C51C664C40122F4FE78ACC44400ED940BAD8644C40B8C83D5DDDC944400ED940BAD8644C40
1876	Филино	1	5	177	41.323194999999998	41.347467000000002	56.830128000000002	56.826399000000002	0103000020E61000000100000005000000889D29745EA944403B394371C7694C40889D29745EA9444038BF61A2416A4C4039B874CC79AC444038BF61A2416A4C4039B874CC79AC44403B394371C7694C40889D29745EA944403B394371C7694C40
1531	Сергеево	1	5	177	41.406981000000002	41.418416000000001	56.766257000000003	56.757010999999999	0103000020E61000000100000005000000F48B12F417B444402BDB87BCE5604C40F48B12F417B4444061AA99B514624C40C30FCEA78EB5444061AA99B514624C40C30FCEA78EB544402BDB87BCE5604C40F48B12F417B444402BDB87BCE5604C40
2009	Семейкино	1	5	177	41.321981999999998	41.353440999999997	56.813108999999997	56.802332	0103000020E6100000010000000500000049F3C7B436A944406344A2D0B2664C4049F3C7B436A94440A88AA9F413684C406308008E3DAD4440A88AA9F413684C406308008E3DAD44406344A2D0B2664C4049F3C7B436A944406344A2D0B2664C40
712	Пустошь	1	5	177	41.610906999999997	41.641046000000003	56.852051000000003	56.843471999999998	0103000020E61000000100000005000000E0F2583332CE4440BD8BF7E3F66B4C40E0F2583332CE444016C3D501106D4C40A69D9ACB0DD2444016C3D501106D4C40A69D9ACB0DD24440BD8BF7E3F66B4C40E0F2583332CE4440BD8BF7E3F66B4C40
1734	Прилив	1	5	177	41.395572000000001	41.409962999999998	56.881965000000001	56.875678999999998	0103000020E610000001000000050000004E9B711AA2B24440A165DD3F16704C404E9B711AA2B24440BB9BA73AE4704C40F7C8E6AA79B44440BB9BA73AE4704C40F7C8E6AA79B44440A165DD3F16704C404E9B711AA2B24440A165DD3F16704C40
1416	Остапово	1	5	177	41.395994000000002	41.416009000000003	56.826483000000003	56.820917000000001	0103000020E61000000100000005000000C4B46FEEAFB244407FDDE9CE13694C40C4B46FEEAFB2444099D9E731CA694C40BCEB6CC83FB5444099D9E731CA694C40BCEB6CC83FB544407FDDE9CE13694C40C4B46FEEAFB244407FDDE9CE13694C40
54115	Никитское	1	5	177	41.700972	41.72166	56.970112999999998	56.962187999999998	0103000020E61000000100000005000000B3B45373B9D94440444DF4F9287B4C40B3B45373B9D944405436ACA92C7C4C406A6AD95A5FDC44405436ACA92C7C4C406A6AD95A5FDC4440444DF4F9287B4C40B3B45373B9D94440444DF4F9287B4C40
1065	Михалково	1	5	177	41.518875000000001	41.545769999999997	56.897596	56.888795000000002	0103000020E6100000010000000500000023DBF97E6AC2444096ECD808C4714C4023DBF97E6AC244409D82FC6CE4724C40A79196CADBC544409D82FC6CE4724C40A79196CADBC5444096ECD808C4714C4023DBF97E6AC2444096ECD808C4714C40
951	Михалево	1	5	177	41.198948999999999	41.228943999999998	56.774594	56.758398	0103000020E6100000010000000500000034492C297799444008AD872F13614C4034492C2977994440C3D66CE525634C40C64E78094E9D4440C3D66CE525634C40C64E78094E9D444008AD872F13614C4034492C297799444008AD872F13614C40
1492	Милюковка	1	5	177	41.477283	41.497252000000003	56.799413999999999	56.791694	0103000020E61000000100000005000000E8F7FD9B17BD44403F389F3A56654C40E8F7FD9B17BD444076FBAC3253664C4070EF1AF4A5BF444076FBAC3253664C4070EF1AF4A5BF44403F389F3A56654C40E8F7FD9B17BD44403F389F3A56654C40
556	Колобово	1	5	177	41.314616000000001	41.377730999999997	56.721120999999997	56.697547999999998	0103000020E6100000010000000500000030664B5645A84440F2B1BB4049594C4030664B5645A84440BABA63B14D5C4C40BAD7497D59B04440BABA63B14D5C4C40BAD7497D59B04440F2B1BB4049594C4030664B5645A84440F2B1BB4049594C40
1624	Клочково	1	5	177	41.509343999999999	41.533831999999997	56.723472000000001	56.710904999999997	0103000020E61000000100000005000000F834272F32C144400CC85EEFFE5A4C40F834272F32C144402EC901BB9A5C4C4075C7629B54C444402EC901BB9A5C4C4075C7629B54C444400CC85EEFFE5A4C40F834272F32C144400CC85EEFFE5A4C40
1386	Китово	1	5	177	41.279752000000002	41.30424	56.872264999999999	56.861593999999997	0103000020E61000000100000005000000CC7EDDE9CEA34440043752B6486E4C40CC7EDDE9CEA3444004392861A66F4C4049111956F1A6444004392861A66F4C4049111956F1A64440043752B6486E4C40CC7EDDE9CEA34440043752B6486E4C40
1846	Качалово	1	5	177	41.439050000000002	41.449902000000002	56.943368999999997	56.938724000000001	0103000020E6100000010000000500000087A757CA32B8444033FCA71B28784C4087A757CA32B84440B587BD50C0784C40D733846396B94440B587BD50C0784C40D733846396B9444033FCA71B28784C4087A757CA32B8444033FCA71B28784C40
48810	Иванцево	1	5	177	41.453288999999998	41.469360000000002	56.869776000000002	56.862056000000003	0103000020E610000001000000050000007A51BB5F05BA444009A9DBD9576E4C407A51BB5F05BA4440406CE9D1546F4C4079060DFD13BC4440406CE9D1546F4C4079060DFD13BC444009A9DBD9576E4C407A51BB5F05BA444009A9DBD9576E4C40
46808	Запрудново	1	5	177	41.267850000000003	41.287469000000002	56.722127999999998	56.709364000000001	0103000020E61000000100000005000000E71DA7E848A24440D97A8670CC5A4C40E71DA7E848A2444050C3B7B06E5C4C4092CEC0C8CBA4444050C3B7B06E5C4C4092CEC0C8CBA44440D97A8670CC5A4C40E71DA7E848A24440D97A8670CC5A4C40
1283	Дунилово	1	5	177	41.401142	41.425477000000001	57.007807999999997	56.986089	0103000020E61000000100000005000000A986FD9E58B3444001F9122A387E4C40A986FD9E58B34440D65240DAFF804C40A019C40776B64440D65240DAFF804C40A019C40776B6444001F9122A387E4C40A986FD9E58B3444001F9122A387E4C40
1187	Введенье	1	5	177	41.322592999999998	41.345194999999997	56.972535999999998	56.959254000000001	0103000020E61000000100000005000000927538BA4AA944405247C7D5C87A4C40927538BA4AA944406117450F7C7C4C4011DF89592FAC44406117450F7C7C4C4011DF89592FAC44405247C7D5C87A4C40927538BA4AA944405247C7D5C87A4C40
839	Васильевское	1	5	177	41.640084000000002	41.682099000000001	56.944307000000002	56.922269999999997	0103000020E61000000100000005000000B058C345EED144407C0A80F10C764C40B058C345EED144402331410DDF784C4031D120054FD744402331410DDF784C4031D120054FD744407C0A80F10C764C40B058C345EED144407C0A80F10C764C40
677	Афанасьевское	1	5	177	41.534621999999999	41.558642999999996	56.862395999999997	56.844096999999998	0103000020E610000001000000050000006EDC627E6EC444406BD3D85E0B6C4C406EDC627E6EC44440C119FCFD626E4C40D591239D81C74440C119FCFD626E4C40D591239D81C744406BD3D85E0B6C4C406EDC627E6EC444406BD3D85E0B6C4C40
804	Арефино	1	5	177	41.515900999999999	41.540461000000001	56.830458	56.820587000000003	0103000020E61000000100000005000000A27C410B09C24440EA42ACFE08694C40A27C410B09C24440CD599F724C6A4C40B9E177D32DC54440CD599F724C6A4C40B9E177D32DC54440EA42ACFE08694C40A27C410B09C24440EA42ACFE08694C40
15936	Широково	1	5	1365	41.109180000000002	41.118397000000002	57.202198000000003	57.195376000000003	0103000020E610000001000000050000004BB0389CF98D44402F36AD1402994C404BB0389CF98D444087A8C29FE1994C40E67805A2278F444087A8C29FE1994C40E67805A2278F44402F36AD1402994C404BB0389CF98D44402F36AD1402994C40
15784	Хромцово	1	5	1365	40.954355	40.973975000000003	57.225856	57.212263999999998	0103000020E6100000010000000500000015E3FC4D287A44401F0F7D772B9B4C4015E3FC4D287A44407DCD72D9E89C4C40910F7A36AB7C44407DCD72D9E89C4C40910F7A36AB7C44401F0F7D772B9B4C4015E3FC4D287A44401F0F7D772B9B4C40
14742	Фурманов	1	5	1365	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
15691	Снетиново	1	5	1365	41.294969999999999	41.317086000000003	57.164949	57.153097000000002	0103000020E610000001000000050000008BA6B393C1A54440D00EB8AE98934C408BA6B393C1A544400341800C1D954C407E02284696A844400341800C1D954C407E02284696A84440D00EB8AE98934C408BA6B393C1A54440D00EB8AE98934C40
54118	Погост	1	5	1365	40.649197999999998	41.434595000000002	57.362195999999997	57.086601999999999	0103000020E61000000100000005000000765089EB1853444054E23AC6158B4C40765089EB18534440FA5E43705CAE4C40A80018CFA0B74440FA5E43705CAE4C40A80018CFA0B7444054E23AC6158B4C40765089EB1853444054E23AC6158B4C40
15752	Панино	1	5	1365	41.097304000000001	41.111587999999998	57.292133999999997	57.28407	0103000020E610000001000000050000008FE21C75748C44402AE3DF675CA44C408FE21C75748C44405B069CA564A54C402250FD83488E44405B069CA564A54C402250FD83488E44402AE3DF675CA44C408FE21C75748C44402AE3DF675CA44C40
48509	Никульское	1	5	1365	41.316242000000003	41.334063999999998	57.137870999999997	57.127994000000001	0103000020E6100000010000000500000092CF2B9E7AA84440C80A7E1B62904C4092CF2B9E7AA844408D08C6C1A5914C40AE62F19BC2AA44408D08C6C1A5914C40AE62F19BC2AA4440C80A7E1B62904C4092CF2B9E7AA84440C80A7E1B62904C40
48547	Михайловское	1	5	1365	41.150458	41.165073	57.319949000000001	57.315463000000001	0103000020E61000000100000005000000F6B52E35429344408D0C721761A84C40F6B52E3542934440A7B1BD16F4A84C40EF39B01C21954440A7B1BD16F4A84C40EF39B01C219544408D0C721761A84C40F6B52E35429344408D0C721761A84C40
15913	Марьинское	1	5	1365	40.877774000000002	40.900123999999998	57.317149000000001	57.307029	0103000020E61000000100000005000000BAA3FFE55A70444038F6ECB94CA74C40BAA3FFE55A704440C47AA35698A84C401F2C634337734440C47AA35698A84C401F2C63433773444038F6ECB94CA74C40BAA3FFE55A70444038F6ECB94CA74C40
54116	Котово	1	5	1365	41.234054999999998	41.244287	57.17201	57.168404000000002	0103000020E610000001000000050000008E3BA583F59D4440FF4124438E954C408E3BA583F59D4440E04A766C04964C4042EBE1CB449F4440E04A766C04964C4042EBE1CB449F4440FF4124438E954C408E3BA583F59D4440FF4124438E954C40
49529	Игрищи	1	5	1365	40.815125999999999	40.825051999999999	57.303556999999998	57.296190000000003	0103000020E61000000100000005000000450F7C0C566844407DB3CD8DE9A54C40450F7C0C5668444066BCADF4DAA64C40ECBFCE4D9B69444066BCADF4DAA64C40ECBFCE4D9B6944407DB3CD8DE9A54C40450F7C0C566844407DB3CD8DE9A54C40
15605	Иванково	1	5	1365	41.146855000000002	41.168101	57.239652	57.229267	0103000020E6100000010000000500000086200725CC924440A986FD9E589D4C4086200725CC924440E335AFEAAC9E4C4063B6645584954440E335AFEAAC9E4C4063B6645584954440A986FD9E589D4C4086200725CC924440A986FD9E589D4C40
16033	Земляничный	1	5	1365	41.048794999999998	41.060482	57.272582	57.260638	0103000020E61000000100000005000000AA9A20EA3E864440240C03965CA14C40AA9A20EA3E86444038BD8BF7E3A24C4093FFC9DFBD87444038BD8BF7E3A24C4093FFC9DFBD874440240C03965CA14C40AA9A20EA3E864440240C03965CA14C40
40387	Захарьино	1	5	1365	41.308858000000001	41.338932999999997	57.164256000000002	57.152247000000003	0103000020E61000000100000005000000D28DB0A888A7444002F566D47C934C40D28DB0A888A74440FD15325706954C408044132862AB4440FD15325706954C408044132862AB444002F566D47C934C40D28DB0A888A7444002F566D47C934C40
15510	Дуляпино	1	5	1365	40.796503999999999	40.829282999999997	57.266449999999999	57.241644000000001	0103000020E610000001000000050000000C91D3D7F365444027A3CA30EE9E4C400C91D3D7F365444075029A081BA24C407B1002F2256A444075029A081BA24C407B1002F2256A444027A3CA30EE9E4C400C91D3D7F365444027A3CA30EE9E4C40
54081	Иваново	1	5	7311	40.867938000000002	40.986156000000001	57.02346	56.953045000000003	0103000020E61000000100000005000000537AA697186F4440E44EE960FD794C40537AA697186F4440D061BEBC00834C4089601C5C3A7E4440D061BEBC00834C4089601C5C3A7E4440E44EE960FD794C40537AA697186F4440E44EE960FD794C40
45376	Хлебницы	1	5	4	40.366354000000001	40.377152000000002	56.627108999999997	56.619914000000001	0103000020E61000000100000005000000206118B0E42E4440912A8A57594F4C40206118B0E42E44407D03931B45504C407DCF4884463044407D03931B45504C407DCF488446304440912A8A57594F4C40206118B0E42E4440912A8A57594F4C40
54108	Харино	1	5	4	40.397894000000001	40.407380000000003	56.666800000000002	56.662367000000003	0103000020E6100000010000000500000027A3CA30EE3244408E791D71C8544C4027A3CA30EE324440857CD0B359554C40B285200725344440857CD0B359554C40B2852007253444408E791D71C8544C4027A3CA30EE3244408E791D71C8544C40
296	Сокатово	1	5	4	40.474907000000002	40.495199999999997	56.602015999999999	56.591267000000002	0103000020E610000001000000050000001CD2A8C0C93C44401E1A16A3AE4B4C401CD2A8C0C93C444099D53BDC0E4D4C40567DAEB6623F444099D53BDC0E4D4C40567DAEB6623F44401E1A16A3AE4B4C401CD2A8C0C93C44401E1A16A3AE4B4C40
32484	Сахтыш	1	5	4	40.406849999999999	40.427556000000003	56.800434000000003	56.788884000000003	0103000020E6100000010000000500000055302AA913344440392BA226FA644C4055302AA913344440A14D0E9F74664C40B39AAE27BA364440A14D0E9F74664C40B39AAE27BA364440392BA226FA644C4055302AA913344440392BA226FA644C40
333	Новое Леушино	1	5	4	40.504460999999999	40.527692000000002	56.814646000000003	56.802075000000002	0103000020E61000000100000005000000C18D942D9240444038F8C264AA664C40C18D942D924044409BE8F35146684C40302E55698B4344409BE8F35146684C40302E55698B43444038F8C264AA664C40C18D942D9240444038F8C264AA664C40
32166	Нерль	1	5	4	40.368986	40.402349999999998	56.672438	56.649206	0103000020E610000001000000050000004757E9EE3A2F4440F92EA52E19534C404757E9EE3A2F4440384BC97212564C40D6C56D3480334440384BC97212564C40D6C56D3480334440F92EA52E19534C404757E9EE3A2F4440F92EA52E19534C40
32128	Москвино	1	5	4	40.201073000000001	40.233449	56.757568999999997	56.748424	0103000020E61000000100000005000000E78D93C2BC19444050C58D5BCC5F4C40E78D93C2BC19444051BB5F05F8604C40572426A8E11D444051BB5F05F8604C40572426A8E11D444050C58D5BCC5F4C40E78D93C2BC19444050C58D5BCC5F4C40
7	Морозово	1	5	4	40.505234000000002	40.541606999999999	56.734247000000003	56.721145	0103000020E61000000100000005000000E469F981AB4044404356B77A4E5C4C40E469F981AB404440D31742CEFB5D4C407024D06053454440D31742CEFB5D4C407024D060534544404356B77A4E5C4C40E469F981AB4044404356B77A4E5C4C40
32426	Крапивново	1	5	4	40.192135	40.363489000000001	56.87623	56.675944000000001	0103000020E610000001000000050000005FB532E197184440B6F63E5585564C405FB532E19718444015E3FC4D28704C4056BABBCE862E444015E3FC4D28704C4056BABBCE862E4440B6F63E5585564C405FB532E197184440B6F63E5585564C40
200	Елховка	1	5	4	40.492486999999997	40.518222999999999	56.630569999999999	56.617863	0103000020E61000000100000005000000425A63D0093F444048348122164F4C40425A63D0093F44405BEB8B84B6504C407B849A21554244405BEB8B84B6504C407B849A215542444048348122164F4C40425A63D0093F444048348122164F4C40
54079	Грозилово	1	5	4	40.556617000000003	40.562851999999999	56.875689000000001	56.869942999999999	0103000020E61000000100000005000000E6B2D1393F4744402B31CF4A5A6F4C40E6B2D1393F474440C53BC09316704C407D3ECA880B484440C53BC09316704C407D3ECA880B4844402B31CF4A5A6F4C40E6B2D1393F4744402B31CF4A5A6F4C40
60371	Быково	1	5	4	40.545971999999999	40.554451999999998	56.738630999999998	56.734696	0103000020E610000001000000050000000F441669E24544404240BE840A5E4C400F441669E2454440E867EA758B5E4C40D4997B48F8464440E867EA758B5E4C40D4997B48F84644404240BE840A5E4C400F441669E24544404240BE840A5E4C40
32294	Большое Клочково	1	5	4	40.597481999999999	40.622571999999998	56.888401999999999	56.879303999999998	0103000020E610000001000000050000006EF9484A7A4C4440F99E91088D704C406EF9484A7A4C4440BAD91F28B7714C40E1B37570B04F4440BAD91F28B7714C40E1B37570B04F4440F99E91088D704C406EF9484A7A4C4440F99E91088D704C40
36659	Беляницы	1	5	4490	36.958460000000002	36.986614000000003	57.702261	57.690083000000001	0103000020E61000000100000005000000184339D1AE7A42404643C6A354D84C40184339D1AE7A4240CD203EB0E3D94C404CE3175E497E4240CD203EB0E3D94C404CE3175E497E42404643C6A354D84C40184339D1AE7A42404643C6A354D84C40
31947	Шестуниха	1	5	1916	41.224569000000002	41.242167000000002	56.607283000000002	56.598497999999999	0103000020E6100000010000000500000004594FADBE9C4440575C1C959B4C4C4004594FADBE9C444059350873BB4D4C40D1950854FF9E444059350873BB4D4C40D1950854FF9E4440575C1C959B4C4C4004594FADBE9C4440575C1C959B4C4C40
31291	Савино	1	5	1916	41.191510999999998	41.237540000000003	56.609943000000001	56.577412000000002	0103000020E6100000010000000500000081E9B46E83984440B328ECA2E8494C4081E9B46E839844404AB6BA9C124E4C40F5BEF1B5679E44404AB6BA9C124E4C40F5BEF1B5679E4440B328ECA2E8494C4081E9B46E83984440B328ECA2E8494C40
48853	Польки	1	5	1916	41.051049999999996	41.091375999999997	56.591400999999998	56.575814999999999	0103000020E61000000100000005000000FB3A70CE88864440EBC5504EB4494C40FB3A70CE888644402DE92807B34B4C40D4D17135B28B44402DE92807B34B4C40D4D17135B28B4440EBC5504EB4494C40FB3A70CE88864440EBC5504EB4494C40
48963	Полома	1	5	1916	41.155569	41.190297999999999	56.571615000000001	56.559944999999999	0103000020E61000000100000005000000BEA25BAFE993444084471B47AC474C40BEA25BAFE9934440977329AE2A494C40423F53AF5B984440977329AE2A494C40423F53AF5B98444084471B47AC474C40BEA25BAFE993444084471B47AC474C40
48889	Покровское	1	5	1916	41.354762000000001	41.382069999999999	56.610711000000002	56.596876999999999	0103000020E6100000010000000500000089EE59D768AD4440075E2D77664C4C4089EE59D768AD44405B272EC72B4E4C40306475ABE7B044405B272EC72B4E4C40306475ABE7B04440075E2D77664C4C4089EE59D768AD4440075E2D77664C4C40
48992	Панфилово	1	5	1916	41.142256000000003	41.160877999999997	56.675331	56.664558999999997	0103000020E6100000010000000500000074D4D1713592444098A1F14410554C4074D4D17135924440CC7C073F71564C40AC527AA697944440CC7C073F71564C40AC527AA69794444098A1F14410554C4074D4D1713592444098A1F14410554C40
49190	Михалево	1	5	1916	41.614356999999998	41.631019999999999	56.647969000000003	56.638367000000002	0103000020E61000000100000005000000CA880B40A3CE44403EEC8502B6514C40CA880B40A3CE444032E9EFA5F0524C409B8F6B43C5D0444032E9EFA5F0524C409B8F6B43C5D044403EEC8502B6514C40CA880B40A3CE44403EEC8502B6514C40
48317	Лычево	1	5	1916	41.430058000000002	41.444673999999999	56.503722000000003	56.499766999999999	0103000020E610000001000000050000000CB1FA230CB744405D4F745DF83F4C400CB1FA230CB744404B2366F679404C40D5B0DF13EBB844404B2366F679404C40D5B0DF13EBB844405D4F745DF83F4C400CB1FA230CB744405D4F745DF83F4C40
48921	Горячево	1	5	1916	41.541494	41.575972	56.553595000000001	56.541885000000001	0103000020E61000000100000005000000787DE6AC4FC54440B398D87C5C454C40787DE6AC4FC54440541D7233DC464C40B3B45373B9C94440541D7233DC464C40B3B45373B9C94440B398D87C5C454C40787DE6AC4FC54440B398D87C5C454C40
48799	Вознесенье	1	5	1916	40.998812999999998	41.024909000000001	56.600727999999997	56.589418000000002	0103000020E61000000100000005000000EAE8B81AD97F44403DD68C0C724B4C40EAE8B81AD97F44404FE5B4A7E44C4C402330D637308344404FE5B4A7E44C4C402330D637308344403DD68C0C724B4C40EAE8B81AD97F44403DD68C0C724B4C40
48786	Архиповка	1	5	1916	41.231028000000002	41.267158000000002	56.66677	56.654015999999999	0103000020E61000000100000005000000EB3A5453929D4440C687D9CBB6534C40EB3A5453929D44401AFA27B858554C40B16EBC3B32A244401AFA27B858554C40B16EBC3B32A24440C687D9CBB6534C40EB3A5453929D4440C687D9CBB6534C40
31687	Агрофенино	1	5	1916	40.992193	41.017606000000001	56.582811	56.570103000000003	0103000020E61000000100000005000000FA28232E007F4440FE2C9622F9484C40FA28232E007F4440E15F048D994A4C40501BD5E940824440E15F048D994A4C40501BD5E940824440FE2C9622F9484C40FA28232E007F4440FE2C9622F9484C40
30684	Тайманиха	1	5	1849	41.530535	41.552318999999997	57.123724000000003	57.111736999999998	0103000020E6100000010000000500000012312592E8C344406760E4654D8E4C4012312592E8C344407BDD2230D68F4C40CEFA9463B2C644407BDD2230D68F4C40CEFA9463B2C644406760E4654D8E4C4012312592E8C344406760E4654D8E4C40
48589	Сосновец	1	5	1849	41.764797999999999	41.787633	56.96208	56.947718999999999	0103000020E61000000100000005000000EA059FE6E4E144401F662FDB4E794C40EA059FE6E4E144405E11FC6F257B4C400C207C28D1E444405E11FC6F257B4C400C207C28D1E444401F662FDB4E794C40EA059FE6E4E144401F662FDB4E794C40
48523	Ситьково	1	5	1849	41.408445	41.424937999999997	57.100434999999997	57.086973	0103000020E610000001000000050000007C9BFEEC47B44440485167EE218B4C407C9BFEEC47B44440D72FD80DDB8C4C40F0694E5E64B64440D72FD80DDB8C4C40F0694E5E64B64440485167EE218B4C407C9BFEEC47B44440485167EE218B4C40
28577	Родники	1	5	1849	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
31139	Постнинский	1	5	1849	41.675199999999997	41.690058000000001	57.144840000000002	57.132810999999997	0103000020E610000001000000050000002D211FF46CD6444047C66AF3FF904C402D211FF46CD644408A93FB1D8A924C40ED2B0FD253D844408A93FB1D8A924C40ED2B0FD253D8444047C66AF3FF904C402D211FF46CD6444047C66AF3FF904C40
30897	Парское	1	5	1849	41.695608999999997	41.718786000000001	57.016302000000003	57.006328000000003	0103000020E61000000100000005000000D1E638B709D9444049861C5BCF804C40D1E638B709D94440016E162F16824C404D69FD2D01DC4440016E162F16824C404D69FD2D01DC444049861C5BCF804C40D1E638B709D9444049861C5BCF804C40
48468	Острецово	1	5	1849	41.540875	41.568317999999998	57.210859999999997	57.196634000000003	0103000020E61000000100000005000000AC1C5A643BC544400EA48B4D2B994C40AC1C5A643BC544406C04E275FD9A4C4033DDEBA4BEC844406C04E275FD9A4C4033DDEBA4BEC844400EA48B4D2B994C40AC1C5A643BC544400EA48B4D2B994C40
31226	Куделино	1	5	1849	41.962282999999999	41.996319999999997	57.055804999999999	57.043399999999998	0103000020E61000000100000005000000963FDF162CFB4440BD5296218E854C40963FDF162CFB444005FA449E24874C40E42CEC6987FF444005FA449E24874C40E42CEC6987FF4440BD5296218E854C40963FDF162CFB4440BD5296218E854C40
48575	Котиха	1	5	1849	41.738988999999997	41.753127999999997	57.005229999999997	56.993375999999998	0103000020E61000000100000005000000478D093197DE4440CE50DCF1267F4C40478D093197DE4440A27A6B60AB804C40D7D9907F66E04440A27A6B60AB804C40D7D9907F66E04440CE50DCF1267F4C40478D093197DE4440CE50DCF1267F4C40
54106	Каминский	1	5	1849	41.459110000000003	41.481676	57.163347999999999	57.146037	0103000020E610000001000000050000001FA2D11DC4BA4440C3802557B1924C401FA2D11DC4BA4440FAEE5696E8944C4051A2258FA7BD4440FAEE5696E8944C4051A2258FA7BD4440C3802557B1924C401FA2D11DC4BA4440C3802557B1924C40
29212	Болотново	1	5	1849	41.867232000000001	41.891855	56.968803000000001	56.958404999999999	0103000020E61000000100000005000000B8054B7501EF444054A9D903AD7A4C40B8054B7501EF444023A298BC017C4C4015E3FC4D28F2444023A298BC017C4C4015E3FC4D28F2444054A9D903AD7A4C40B8054B7501EF444054A9D903AD7A4C40
29914	Сеготь	1	5	1857	43.008794000000002	43.021971999999998	57.094397000000001	57.078242000000003	0103000020E6100000010000000500000055336B29208145403A9677D5038A4C4055336B292081454096EB6D33158C4C40BFB67EFACF82454096EB6D33158C4C40BFB67EFACF8245403A9677D5038A4C4055336B29208145403A9677D5038A4C40
28910	Пучеж	1	5	1857	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
29664	Привалово	1	5	1857	42.949181000000003	42.960284999999999	56.871079999999999	56.866228999999997	0103000020E61000000100000005000000077E54C37E79454063EC8497E06E4C40077E54C37E7945408F19A88C7F6F4C4070EB6E9EEA7A45408F19A88C7F6F4C4070EB6E9EEA7A454063EC8497E06E4C40077E54C37E79454063EC8497E06E4C40
29931	Петрово	1	5	1857	42.926192999999998	42.949038000000002	57.091760999999998	57.077145999999999	0103000020E610000001000000050000005E64027E8D76454034828DEBDF894C405E64027E8D7645402D060FD3BE8B4C40A454C2137A7945402D060FD3BE8B4C40A454C2137A79454034828DEBDF894C405E64027E8D76454034828DEBDF894C40
29778	Мортки	1	5	1857	43.101301999999997	43.122826000000003	56.866169999999997	56.855536000000001	0103000020E610000001000000050000007B82C476F78C45407C462234826D4C407B82C476F78C45405E6397A8DE6E4C409C8C2AC3B88F45405E6397A8DE6E4C409C8C2AC3B88F45407C462234826D4C407B82C476F78C45407C462234826D4C40
30004	Марищи	1	5	1857	42.754705000000001	42.771009999999997	57.088157000000002	57.077478999999997	0103000020E610000001000000050000005890662C9A6045403A90F5D4EA894C405890662C9A604540EDF483BA488B4C40C971A774B0624540EDF483BA488B4C40C971A774B06245403A90F5D4EA894C405890662C9A6045403A90F5D4EA894C40
29380	Лужинки	1	5	1857	42.919178000000002	42.929938999999997	56.919685999999999	56.915156000000003	0103000020E61000000100000005000000F299EC9FA77545407D5EF1D423754C40F299EC9FA7754540664B5645B8754C403123BC3D08774540664B5645B8754C403123BC3D087745407D5EF1D423754C40F299EC9FA77545407D5EF1D423754C40
29857	Летнево	1	5	1857	43.040135999999997	43.061551999999999	57.031851000000003	57.021073999999999	0103000020E6100000010000000500000035B22B2D23854540E065868DB2824C4035B22B2D2385454026AC8DB113844C406F8099EFE087454026AC8DB113844C406F8099EFE0874540E065868DB2824C4035B22B2D23854540E065868DB2824C40
29572	Кораблево	1	5	1857	42.973022999999998	42.986460999999998	56.927014999999997	56.923164	0103000020E61000000100000005000000BEA085048C7C45401A6CEA3C2A764C40BEA085048C7C454062F3716DA8764C40C5E3A25A447E454062F3716DA8764C40C5E3A25A447E45401A6CEA3C2A764C40BEA085048C7C45401A6CEA3C2A764C40
29716	Кандаурово	1	5	1857	43.010005999999997	43.033757999999999	56.894365999999998	56.879967999999998	0103000020E61000000100000005000000C36169E04781454065C39ACAA2704C40C36169E047814540C153C8957A724C403BFDA02E52844540C153C8957A724C403BFDA02E5284454065C39ACAA2704C40C36169E04781454065C39ACAA2704C40
52400	Илья-Высоково	1	5	1857	43.032024	43.061399000000002	56.944758	56.928066999999999	0103000020E61000000100000005000000F357C85C1984454098BF42E6CA764C40F357C85C19844540335184D4ED784C40E98024ECDB874540335184D4ED784C40E98024ECDB87454098BF42E6CA764C40F357C85C1984454098BF42E6CA764C40
29303	Затеиха	1	5	1857	42.857230000000001	42.884179000000003	56.962148999999997	56.950859999999999	0103000020E6100000010000000500000036936FB6B96D45408B89CDC7B5794C4036936FB6B96D45408670CCB2277B4C40AE6708C72C7145408670CCB2277B4C40AE6708C72C7145408B89CDC7B5794C4036936FB6B96D45408B89CDC7B5794C40
29350	Зарайское	1	5	1857	42.934674000000001	42.947069999999997	56.981327	56.974415	0103000020E61000000100000005000000F435CB65A3774540ADDD76A1B97C4C40F435CB65A377454045D7851F9C7D4C40E882FA963979454045D7851F9C7D4C40E882FA9639794540ADDD76A1B97C4C40F435CB65A3774540ADDD76A1B97C4C40
29481	Дубново	1	5	1857	43.158534000000003	43.184091000000002	56.949480999999999	56.939210000000003	0103000020E61000000100000005000000ECA694D74A944540C009850838784C40ECA694D74A9445403196E99788794C40753E3C4B909745403196E99788794C40753E3C4B90974540C009850838784C40ECA694D74A944540C009850838784C40
30059	Дроздиха	1	5	1857	42.999307000000002	43.010815000000001	57.130462000000001	57.119883999999999	0103000020E61000000100000005000000FAD4B14AE97F454026A8E15B588F4C40FAD4B14AE97F454075AF93FAB2904C4033A7CB626281454075AF93FAB2904C4033A7CB626281454026A8E15B588F4C40FAD4B14AE97F454026A8E15B588F4C40
29536	Губинская	1	5	1857	43.002281000000004	43.022860999999999	56.934922999999998	56.926858000000003	0103000020E610000001000000050000007B336ABE4A8045409B046F48A3764C407B336ABE4A8045409CA38E8EAB774C404BADF71BED8245409CA38E8EAB774C404BADF71BED8245409B046F48A3764C407B336ABE4A8045409B046F48A3764C40
29802	Большое Дмитриево	1	5	1857	43.174658999999998	43.188806999999997	56.896362000000003	56.891308000000002	0103000020E61000000100000005000000DD79E2395B964540E3546B6116724C40DD79E2395B96454047B071FDBB724C40C020E9D32A98454047B071FDBB724C40C020E9D32A984540E3546B6116724C40DD79E2395B964540E3546B6116724C40
28347	Филисово	1	5	1826	41.376474000000002	41.386471999999998	57.406784999999999	57.403716000000003	0103000020E61000000100000005000000ACE5CE4C30B044409C6F44F7ACB34C40ACE5CE4C30B044406EC0E78711B44C40EC681CEA77B144406EC0E78711B44C40EC681CEA77B144409C6F44F7ACB34C40ACE5CE4C30B044409C6F44F7ACB34C40
28853	Федорище	1	5	1826	41.324002999999998	41.344915999999998	57.326028000000001	57.318655999999997	0103000020E61000000100000005000000276728EE78A944404B5645B8C9A84C40276728EE78A9444047CA1649BBA94C40FEEE1D3526AC444047CA1649BBA94C40FEEE1D3526AC44404B5645B8C9A84C40276728EE78A944404B5645B8C9A84C40
28387	Утес	1	5	1826	41.588107999999998	41.614060000000002	57.433864	57.424545999999999	0103000020E610000001000000050000000B42791F47CB4440E5D2F88557B64C400B42791F47CB4440B47405DB88B74C4011E4A08499CE4440B47405DB88B74C4011E4A08499CE4440E5D2F88557B64C400B42791F47CB4440E5D2F88557B64C40
28497	Толпыгино	1	5	1826	41.222700000000003	41.241619	57.333098	57.324424999999998	0103000020E61000000100000005000000DC68006F819C44409D8026C286A94C40DC68006F819C4440772E8CF4A2AA4C40CE8B135FED9E4440772E8CF4A2AA4C40CE8B135FED9E44409D8026C286A94C40DC68006F819C44409D8026C286A94C40
28290	Северцево	1	5	1826	41.480229000000001	41.497197999999997	57.457653999999998	57.446153000000002	0103000020E610000001000000050000009FCBD42478BD44409301A08A1BB94C409FCBD42478BD44401971016894BA4C407CD11E2FA4BF44401971016894BA4C407CD11E2FA4BF44409301A08A1BB94C409FCBD42478BD44409301A08A1BB94C40
28835	Рождествено	1	5	1826	41.363700000000001	41.377282000000001	57.258380000000002	57.246859999999998	0103000020E6100000010000000500000011C7BAB88DAE44406458C51B999F4C4011C7BAB88DAE444062F8889812A14C404BAFCDC64AB0444062F8889812A14C404BAFCDC64AB044406458C51B999F4C4011C7BAB88DAE44406458C51B999F4C40
27821	Приволжск	1	5	1826	41.264113000000002	41.316457	57.399667000000001	57.364691000000001	0103000020E6100000010000000500000067B96C74CEA14440A112D731AEAE4C4067B96C74CEA144402D25CB4928B34C408ECBB8A981A844402D25CB4928B34C408ECBB8A981A84440A112D731AEAE4C4067B96C74CEA14440A112D731AEAE4C40
28215	Плес	1	5	1826	41.485214999999997	41.532862000000002	57.465733	57.448134000000003	0103000020E61000000100000005000000AA436E861BBE4440E31C75745CB94C40AA436E861BBE444080D591239DBB4C40FDA36FD234C4444080D591239DBB4C40FDA36FD234C44440E31C75745CB94C40AA436E861BBE4440E31C75745CB94C40
28719	Парушево	1	5	1826	41.361570999999998	41.372557	57.385601000000001	57.381070000000001	0103000020E610000001000000050000004C1762F547AE44404DBED9E6C6B04C404C1762F547AE44400727A25F5BB14C40AC72A1F2AFAF44400727A25F5BB14C40AC72A1F2AFAF44404DBED9E6C6B04C404C1762F547AE44404DBED9E6C6B04C40
54113	Новое	1	5	1826	41.447423000000001	41.468677	57.367167000000002	57.353166000000002	0103000020E61000000100000005000000363D282845B944409207228B34AD4C40363D282845B94440D1950854FFAE4C4096B1A19BFDBB4440D1950854FFAE4C4096B1A19BFDBB44409207228B34AD4C40363D282845B944409207228B34AD4C40
28515	Кунестино	1	5	1826	41.157167999999999	41.175431000000003	57.382792000000002	57.374194000000003	0103000020E6100000010000000500000026FDBD141E944440022EC896E5AF4C4026FDBD141E944440D1950854FFB04C4030DAE38574964440D1950854FFB04C4030DAE38574964440022EC896E5AF4C4026FDBD141E944440022EC896E5AF4C40
28644	Красинское	1	5	1826	41.270696999999998	41.361041	57.357691000000003	57.343862000000001	0103000020E610000001000000050000000A100533A6A24440282B86AB03AC4C400A100533A6A244406A8995D1C8AD4C40F0C16B9736AE44406A8995D1C8AD4C40F0C16B9736AE4440282B86AB03AC4C400A100533A6A24440282B86AB03AC4C40
28452	Ингарь	1	5	1826	41.293990999999998	41.320284000000001	57.399638000000003	57.391558000000003	0103000020E61000000100000005000000BF28417FA1A544405C3E92921EB24C40BF28417FA1A54440931E865627B34C404EB7EC10FFA84440931E865627B34C404EB7EC10FFA844405C3E92921EB24C40BF28417FA1A544405C3E92921EB24C40
28747	Горки-Чириковы	1	5	1826	41.485942999999999	41.494574999999998	57.316741	57.308301999999998	0103000020E610000001000000050000002D5C566133BE44404CA59F7076A74C402D5C566133BE4440B32616F88AA84C40A835CD3B4EBF4440B32616F88AA84C40A835CD3B4EBF44404CA59F7076A74C402D5C566133BE44404CA59F7076A74C40
27687	Шалаево	1	5	1816	42.745452	42.769114000000002	56.688116999999998	56.677303999999999	0103000020E61000000100000005000000705E9CF86A5F454099B9C0E5B1564C40705E9CF86A5F45402B69C53714584C40A872DA53726245402B69C53714584C40A872DA537262454099B9C0E5B1564C40705E9CF86A5F454099B9C0E5B1564C40
47237	Филята	1	5	1816	42.575904000000001	42.600132000000002	56.729897000000001	56.722790000000003	0103000020E610000001000000050000005BD1E638B74945401CF0F961845C4C405BD1E638B74945406939D0436D5D4C403CA41820D14C45406939D0436D5D4C403CA41820D14C45401CF0F961845C4C405BD1E638B74945401CF0F961845C4C40
27747	Пестяки	1	5	1816	42.652521999999998	42.691750999999996	56.719248999999998	56.689388000000001	0103000020E61000000100000005000000D3F544D7855345409F20B1DD3D584C40D3F544D7855345402157EA59105C4C40D6FCF84B8B5845402157EA59105C4C40D6FCF84B8B5845409F20B1DD3D584C40D3F544D7855345409F20B1DD3D584C40
27473	Нижний Ландех	1	5	1816	42.409734	42.443547000000002	56.670943999999999	56.648474	0103000020E610000001000000050000009607E9297234454035272F3201534C409607E9297234454045B9347EE1554C40959EE925C638454045B9347EE1554C40959EE925C638454035272F3201534C409607E9297234454035272F3201534C40
27387	Неверово-Слобода	1	5	1816	42.659393999999999	42.688014000000003	56.586410000000001	56.574705000000002	0103000020E61000000100000005000000DD96C8056754454081ECF5EE8F494C40DD96C8056754454010069E7B0F4B4C405798BED71058454010069E7B0F4B4C405798BED71058454081ECF5EE8F494C40DD96C8056754454081ECF5EE8F494C40
27554	Галашово	1	5	1816	42.597760000000001	42.604596999999998	56.687869999999997	56.684009000000003	0103000020E61000000100000005000000B16D5166834C4540B8955E9B8D574C40B16D5166834C454023F3C81F0C584C403E213B6F634D454023F3C81F0C584C403E213B6F634D4540B8955E9B8D574C40B16D5166834C4540B8955E9B8D574C40
27617	Вербино	1	5	1816	42.720866000000001	42.744320999999999	56.636986	56.629773	0103000020E6100000010000000500000030664B56455C4540B073D3669C504C4030664B56455C45404301DBC188514C40EE5C18E9455F45404301DBC188514C40EE5C18E9455F4540B073D3669C504C4030664B56455C4540B073D3669C504C40
27362	Беклемищи	1	5	1816	42.707337000000003	42.729363999999997	56.780476999999998	56.769252000000002	0103000020E610000001000000050000001920D1048A5A4540F9307BD976624C401920D1048A5A4540DD239BABE6634C409B70AFCC5B5D4540DD239BABE6634C409B70AFCC5B5D4540F9307BD976624C401920D1048A5A4540F9307BD976624C40
47061	Алехино	1	5	1816	42.578769999999999	42.597876999999997	56.618065999999999	56.609096000000001	0103000020E61000000100000005000000F5F3A622154A4540ED0F94DBF64D4C40F5F3A622154A4540806264C91C4F4C40EA03C93B874C4540806264C91C4F4C40EA03C93B874C4540ED0F94DBF64D4C40F5F3A622154A4540ED0F94DBF64D4C40
46931	Тименка	1	5	1810	41.802714999999999	41.826314000000004	56.752087000000003	56.740749000000001	0103000020E610000001000000050000001B81785DBFE64440B9C5FCDCD05E4C401B81785DBFE64440965F066344604C400D1D3BA8C4E94440965F066344604C400D1D3BA8C4E94440B9C5FCDCD05E4C401B81785DBFE64440B9C5FCDCD05E4C40
45754	Сакулино	1	5	1810	42.081291999999998	42.095134999999999	56.802410000000002	56.798211000000002	0103000020E6100000010000000500000095B6B8C6670A45405B272EC72B664C4095B6B8C6670A4540DFFDF15EB5664C403CDA38622D0C4540DFFDF15EB5664C403CDA38622D0C45405B272EC72B664C4095B6B8C6670A45405B272EC72B664C40
46900	Подолино	1	5	1810	41.899230000000003	41.916972000000001	56.830624999999998	56.820562000000002	0103000020E6100000010000000500000082CAF8F719F34440912BF52C08694C4082CAF8F719F34440B81E85EB516A4C4082ACA7565FF54440B81E85EB516A4C4082ACA7565FF54440912BF52C08694C4082CAF8F719F34440912BF52C08694C40
46845	Пеньки	1	5	1810	42.209428000000003	42.226047000000001	56.827488000000002	56.814807999999999	0103000020E61000000100000005000000F06E6589CE1A45407442E8A04B684C40F06E6589CE1A45408EEA7420EB694C40F12DAC1BEF1C45408EEA7420EB694C40F12DAC1BEF1C45407442E8A04B684C40F06E6589CE1A45407442E8A04B684C40
46853	Паново	1	5	1810	42.091614	42.103003999999999	56.852642000000003	56.847459000000001	0103000020E6100000010000000500000089EDEE01BA0B4540B6D95889796C4C4089EDEE01BA0B45401899805F236D4C40B8AD2D3C2F0D45401899805F236D4C40B8AD2D3C2F0D4540B6D95889796C4C4089EDEE01BA0B4540B6D95889796C4C40
27113	Палех	1	5	1810	41.837336999999998	41.895107000000003	56.813907	56.782341000000002	0103000020E61000000100000005000000895DDBDB2DEB4440F4A8F8BF23644C40895DDBDB2DEB4440247EC51A2E684C40D9B5BDDD92F24440247EC51A2E684C40D9B5BDDD92F24440F4A8F8BF23644C40895DDBDB2DEB4440F4A8F8BF23644C40
27084	Майдаково	1	5	1810	41.798422000000002	41.838388000000002	56.904353999999998	56.890422999999998	0103000020E6100000010000000500000016342DB132E64440984D8061F9714C4016342DB132E64440DE0033DFC1734C40EFAD484C50EB4440DE0033DFC1734C40EFAD484C50EB4440984D8061F9714C4016342DB132E64440984D8061F9714C40
26900	Клетино	1	5	1810	41.641961999999999	41.676789999999997	56.794376	56.783441000000003	0103000020E610000001000000050000002BA391CF2BD244403BAC70CB47644C402BA391CF2BD24440185DDE1CAE654C404221020EA1D64440185DDE1CAE654C404221020EA1D644403BAC70CB47644C402BA391CF2BD244403BAC70CB47644C40
26606	Худынское	1	5	1789	42.257685000000002	42.273935999999999	56.968370999999998	56.956265000000002	0103000020E61000000100000005000000BBD573D2FB2045409CA73AE4667A4C40BBD573D2FB20454089B2B794F37B4C403999B8551023454089B2B794F37B4C403999B855102345409CA73AE4667A4C40BBD573D2FB2045409CA73AE4667A4C40
47737	Тимирязево	1	5	1789	42.224519000000001	42.241228	57.052079999999997	57.040647999999997	0103000020E61000000100000005000000522AE109BD1C4540EB5223F433854C40522AE109BD1C45404963B48EAA864C409370218FE01E45404963B48EAA864C409370218FE01E4540EB5223F433854C40522AE109BD1C4540EB5223F433854C40
33155	Слободки	1	5	1789	42.320379000000003	42.354182000000002	56.927688000000003	56.916212000000002	0103000020E61000000100000005000000A0A9D72D02294540F419506F46754C40A0A9D72D022945402272FA7ABE764C407B6AF5D5552D45402272FA7ABE764C407B6AF5D5552D4540F419506F46754C40A0A9D72D02294540F419506F46754C40
46700	Рябово	1	5	1789	42.205205999999997	42.225974999999998	56.927418000000003	56.918792000000003	0103000020E61000000100000005000000B378B130441A4540C9E9EBF99A754C40B378B130441A454062DC0DA2B5764C40575BB1BFEC1C454062DC0DA2B5764C40575BB1BFEC1C4540C9E9EBF99A754C40B378B130441A4540C9E9EBF99A754C40
26323	Порздни	1	5	1789	42.542676	42.565170000000002	57.010787999999998	57.000877000000003	0103000020E610000001000000050000007C293C6876454540C828CFBC1C804C407C293C687645454039984D8061814C401557957D5748454039984D8061814C401557957D57484540C828CFBC1C804C407C293C6876454540C828CFBC1C804C40
26052	Лух	1	5	1789	42.246223000000001	42.274915	57.018590000000003	57.002651999999998	0103000020E61000000100000005000000F2423A3C841F45406EA296E656804C40F2423A3C841F45402E04392861824C4005172B6A302345402E04392861824C4005172B6A302345406EA296E656804C40F2423A3C841F45406EA296E656804C40
26292	Воскресенское-Новое	1	5	1789	42.496673000000001	42.509312000000001	57.072890000000001	57.065345000000001	0103000020E6100000010000000500000032E719FB923F454083FA96395D884C4032E719FB923F45404C1AA37554894C40EDBAB722314145404C1AA37554894C40EDBAB7223141454083FA96395D884C4032E719FB923F454083FA96395D884C40
45673	Благовещенье	1	5	1789	42.398477999999997	42.423326000000003	57.021427000000003	57.011318000000003	0103000020E610000001000000050000007616BD530133454096ED43DE72814C407616BD53013345402E20B41EBE824C40F4C5DE8B2F3645402E20B41EBE824C40F4C5DE8B2F36454096ED43DE72814C407616BD530133454096ED43DE72814C40
25951	Шилыково	1	5	1331	40.726821000000001	40.754741000000003	56.927998000000002	56.914772999999997	0103000020E61000000100000005000000E4857478085D4440C4211B4817754C40E4857478085D4440706072A3C8764C40A5F9635A9B604440706072A3C8764C40A5F9635A9B604440C4211B4817754C40E4857478085D4440C4211B4817754C40
25922	Чернцы	1	5	1331	40.749746000000002	40.777621000000003	56.868428000000002	56.856800999999997	0103000020E6100000010000000500000046274BADF75F44400D17B9A7AB6D4C4046274BADF75F4440217711A6286F4C4067D7BD1589634440217711A6286F4C4067D7BD15896344400D17B9A7AB6D4C4046274BADF75F44400D17B9A7AB6D4C40
25866	Хозниково	1	5	1331	41.104059999999997	41.122717999999999	56.809517	56.800916999999998	0103000020E610000001000000050000002F698CD6518D4440BCE7C07284664C402F698CD6518D44402C47C8409E674C40B5503239B58F44402C47C8409E674C40B5503239B58F4440BCE7C07284664C402F698CD6518D4440BCE7C07284664C40
60490	Ухтохма	1	5	1331	40.658298000000002	41.161093999999999	56.969695999999999	56.553897999999997	0103000020E61000000100000005000000D882DE1B43544440EFA83121E6464C40D882DE1B43544440F0879FFF1E7C4C4079CA6ABA9E944440F0879FFF1E7C4C4079CA6ABA9E944440EFA83121E6464C40D882DE1B43544440EFA83121E6464C40
25643	Телегино	1	5	1331	40.767631999999999	40.786352999999998	56.800690000000003	56.791167000000002	0103000020E6100000010000000500000079AEEFC3416244405456D3F544654C4079AEEFC341624440FC1D8A027D664C40450E1137A7644440FC1D8A027D664C40450E1137A76444405456D3F544654C4079AEEFC3416244405456D3F544654C40
25806	Сабиново	1	5	1331	40.933326000000001	40.948084999999999	56.827886999999997	56.818750000000001	0103000020E61000000100000005000000D540F33977774440CDCCCCCCCC684C40D540F339777744404BE48233F8694C40016A6AD95A7944404BE48233F8694C40016A6AD95A794440CDCCCCCCCC684C40D540F33977774440CDCCCCCCCC684C40
25660	Новые Горки	1	5	1331	41.050673000000003	41.09796	56.737273000000002	56.724784999999997	0103000020E6100000010000000500000026E5EE737C864440D0D03FC1C55C4C4026E5EE737C864440A69C2FF65E5E4C4078280AF4898C4440A69C2FF65E5E4C4078280AF4898C4440D0D03FC1C55C4C4026E5EE737C864440D0D03FC1C55C4C40
25491	Малое Растилково	1	5	1331	40.980685000000001	40.996791999999999	56.623727000000002	56.616287999999997	0103000020E61000000100000005000000C1560916877D444068757286E24E4C40C1560916877D4440EC504D49D64F4C400C7558E1967F4440EC504D49D64F4C400C7558E1967F444068757286E24E4C40C1560916877D444068757286E24E4C40
25190	Лежнево	1	5	1331	40.865206999999998	40.916896000000001	56.790979999999998	56.761048000000002	0103000020E6100000010000000500000098A25C1ABF6E4440D65757056A614C4098A25C1ABF6E444021E527D53E654C40A7EA1ED95C75444021E527D53E654C40A7EA1ED95C754440D65757056A614C4098A25C1ABF6E4440D65757056A614C40
25515	Воскресенское	1	5	1331	40.947789	40.979553000000003	56.706152000000003	56.694133000000001	0103000020E6100000010000000500000018416326517944408509A359D9584C401841632651794440A4005130635A4C406FD921FE617D4440A4005130635A4C406FD921FE617D44408509A359D9584C4018416326517944408509A359D9584C40
25059	Седельницы	1	5	1019	40.527017999999998	40.563355000000001	57.146920999999999	57.135361000000003	0103000020E61000000100000005000000A033695375434440B2135E8253914C40A0336953754344403D0CAD4ECE924C40E08442041C4844403D0CAD4ECE924C40E08442041C484440B2135E8253914C40A033695375434440B2135E8253914C40
8878	Светиково	1	5	1019	40.184966000000003	40.200389999999999	57.013097000000002	56.999755	0103000020E610000001000000050000009C6F44F7AC1744409981CAF8F77F4C409C6F44F7AC1744407E569929AD814C4004392861A61944407E569929AD814C4004392861A61944409981CAF8F77F4C409C6F44F7AC1744409981CAF8F77F4C40
48762	Савино	1	5	1019	40.096553999999998	40.107756000000002	57.023077999999998	57.016154999999998	0103000020E610000001000000050000002426A8E15B0C44405C55F65D11824C402426A8E15B0C4440E8A04B38F4824C4051F9D7F2CA0D4440E8A04B38F4824C4051F9D7F2CA0D44405C55F65D11824C402426A8E15B0C44405C55F65D11824C40
25131	Подозерский	1	5	1019	40.326819	40.346060999999999	57.220959000000001	57.210357999999999	0103000020E61000000100000005000000105B7A34D5294440DA39CD02ED9A4C40105B7A34D5294440E1606F62489C4C40E5B512BA4B2C4440E1606F62489C4C40E5B512BA4B2C4440DA39CD02ED9A4C40105B7A34D5294440DA39CD02ED9A4C40
24900	Писцово	1	5	1019	40.502907	40.547823000000001	57.193021000000002	57.166978999999998	0103000020E61000000100000005000000F9F6AE415F404440340F60915F954C40F9F6AE415F4044407A3881E9B4984C40917F66101F4644407A3881E9B4984C40917F66101F464440340F60915F954C40F9F6AE415F404440340F60915F954C40
45955	Октябрьский	1	5	1019	40.317934999999999	40.346348999999996	57.146945000000002	57.131144999999997	0103000020E610000001000000050000007BA01518B22844405704FF5BC9904C407BA01518B2284440C6A70018CF924C404B00FE29552C4440C6A70018CF924C404B00FE29552C44405704FF5BC9904C407BA01518B22844405704FF5BC9904C40
24759	Новая Усадьба	1	5	1019	40.358656000000003	40.375194	57.021824000000002	57.015428999999997	0103000020E61000000100000005000000D1419770E82D44407A34D593F9814C40D1419770E82D44404B22FB20CB824C40E5D3635B063044404B22FB20CB824C40E5D3635B063044407A34D593F9814C40D1419770E82D44407A34D593F9814C40
47162	Никулино	1	5	1019	40.567146000000001	40.574584000000002	57.175576999999997	57.170268	0103000020E610000001000000050000005307793D9848444015C78157CB954C405307793D984844400377A04E79964C400667F0F78B4944400377A04E79964C400667F0F78B49444015C78157CB954C405307793D9848444015C78157CB954C40
46068	Михеево	1	5	1019	40.589998999999999	40.612627000000003	57.167301000000002	57.158124999999998	0103000020E610000001000000050000001BD65416854B44400AD7A3703D944C401BD65416854B444047CB811E6A954C40C4D2C08F6A4E444047CB811E6A954C40C4D2C08F6A4E44400AD7A3703D944C401BD65416854B44400AD7A3703D944C40
54084	Марково	1	5	1019	40.460731000000003	40.523936999999997	57.033996999999999	57.007337999999997	0103000020E610000001000000050000006FA0C03BF93A44404F029B73F0804C406FA0C03BF93A4440C09481035A844C4009151C5E10434440C09481035A844C4009151C5E104344404F029B73F0804C406FA0C03BF93A44404F029B73F0804C40
24523	Комсомольск	1	5	1019	40.356338000000001	40.391829999999999	57.042841000000003	57.014111	0103000020E610000001000000050000003929CC7B9C2D4440C6C1A563CE814C403929CC7B9C2D4440C7F65AD07B854C40BCCB457C27324440C7F65AD07B854C40BCCB457C27324440C6C1A563CE814C403929CC7B9C2D4440C6C1A563CE814C40
54071	Кинешма	1	5	7296	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
23654	Шумовская	1	5	1639	42.431994000000003	42.442469000000003	57.183022000000001	57.177953000000002	0103000020E61000000100000005000000BC0853944B374540D09CF529C7964C40BC0853944B3745406939D0436D974C40363FFED2A23845406939D0436D974C40363FFED2A2384540D09CF529C7964C40BC0853944B374540D09CF529C7964C40
23720	Шилекша	1	5	1639	42.520181999999998	42.550257999999999	57.183011999999998	57.172561999999999	0103000020E61000000100000005000000E3FBE252954245402444F98216964C40E3FBE252954245404563EDEF6C974C40622EA9DA6E4645404563EDEF6C974C40622EA9DA6E4645402444F98216964C40E3FBE252954245402444F98216964C40
23878	Стиберское	1	5	1639	42.743934000000003	42.766562999999998	57.439391000000001	57.430739000000003	0103000020E61000000100000005000000F530B43A395F45404E0E9F7422B74C40F530B43A395F45401094DBF63DB84C406DA983BC1E6245401094DBF63DB84C406DA983BC1E6245404E0E9F7422B74C40F530B43A395F45404E0E9F7422B74C40
20655	Станко	1	5	1639	41.925936999999998	41.934956	57.457189	57.447664000000003	0103000020E610000001000000050000000394861A85F644405CCCCF0D4DB94C400394861A85F64440A48B4D2B85BA4C40789961A3ACF74440A48B4D2B85BA4C40789961A3ACF744405CCCCF0D4DB94C400394861A85F644405CCCCF0D4DB94C40
24012	Решма	1	5	1639	42.537483000000002	42.575428000000002	57.412951999999997	57.400550000000003	0103000020E61000000100000005000000F793313ECC444540D734EF3845B34C40F793313ECC444540AD68739CDBB44C40F299EC9FA7494540AD68739CDBB44C40F299EC9FA7494540D734EF3845B34C40F793313ECC444540D734EF3845B34C40
24135	Первомайский	1	5	1639	42.067205999999999	42.084893999999998	57.486629000000001	57.477310000000003	0103000020E61000000100000005000000280CCA349A084540E2067C7E18BD4C40280CCA349A0845408124ECDB49BE4C4035D07CCEDD0A45408124ECDB49BE4C4035D07CCEDD0A4540E2067C7E18BD4C40280CCA349A084540E2067C7E18BD4C40
20632	Наволоки	1	5	1639	41.925775999999999	41.996284000000003	57.480649	57.455585999999997	0103000020E61000000100000005000000FAB5F5D37FF64440FA415DA450BA4C40FAB5F5D37FF6444074ED0BE885BD4C4098C3EE3B86FF444074ED0BE885BD4C4098C3EE3B86FF4440FA415DA450BA4C40FAB5F5D37FF64440FA415DA450BA4C40
23960	Луговое	1	5	1639	42.218411000000003	42.226064999999998	57.422781999999998	57.416916999999998	0103000020E61000000100000005000000180B43E4F41B4540BE1248895DB54C40180B43E4F41B454032AB77B81DB64C4097E2AAB2EF1C454032AB77B81DB64C4097E2AAB2EF1C4540BE1248895DB54C40180B43E4F41B4540BE1248895DB54C40
23592	Лагуниха	1	5	1639	42.280754000000002	42.292064000000003	57.223356000000003	57.214584000000002	0103000020E61000000100000005000000501C40BFEF234540581F0F7D779B4C40501C40BFEF234540C5AEEDED969C4C40632B685A62254540C5AEEDED969C4C40632B685A62254540581F0F7D779B4C40501C40BFEF234540581F0F7D779B4C40
23842	Красногорский	1	5	1639	42.809871000000001	42.842523999999997	57.519680999999999	57.505147999999998	0103000020E610000001000000050000004A7D59DAA9674540E5D18DB0A8C04C404A7D59DAA967454021AD31E884C24C402C0C91D3D76B454021AD31E884C24C402C0C91D3D76B4540E5D18DB0A8C04C404A7D59DAA9674540E5D18DB0A8C04C40
23794	Ильинское	1	5	1639	42.591113	42.612385000000003	57.440897999999997	57.429046999999997	0103000020E61000000100000005000000C79E3D97A94B454034B91803EBB64C40C79E3D97A94B4540976F7D586FB84C40CEC7B5A1624E4540976F7D586FB84C40CEC7B5A1624E454034B91803EBB64C40C79E3D97A94B454034B91803EBB64C40
23763	Зобнино	1	5	1639	42.595945999999998	42.614899999999999	57.205556999999999	57.196395000000003	0103000020E610000001000000050000004C1762F5474C4540890CAB7823994C404C1762F5474C4540603B18B14F9A4C40BB270F0BB54E4540603B18B14F9A4C40BB270F0BB54E4540890CAB7823994C404C1762F5474C4540890CAB7823994C40
23512	Закусихино	1	5	1639	42.364082000000003	42.395693000000001	57.304164999999998	57.290908999999999	0103000020E61000000100000005000000F9872D3D9A2E4540588E90813CA54C40F9872D3D9A2E45403ECBF3E0EEA64C40C9207711A63245403ECBF3E0EEA64C40C9207711A6324540588E90813CA54C40F9872D3D9A2E4540588E90813CA54C40
24106	Журихино	1	5	1639	42.520164000000001	42.541696999999999	57.26388	57.250692000000001	0103000020E610000001000000050000003D47E4BB9442454036AFEAAC16A04C403D47E4BB94424540C408E1D1C6A14C40B0ABC95356454540C408E1D1C6A14C40B0ABC9535645454036AFEAAC16A04C403D47E4BB9442454036AFEAAC16A04C40
24030	Дьячево	1	5	1639	42.457991999999997	42.484546000000002	57.412598000000003	57.405059000000001	0103000020E6100000010000000500000031EA5A7B9F3A4540A9F92AF9D8B34C4031EA5A7B9F3A45409032E202D0B44C402DB4739A053E45409032E202D0B44C402DB4739A053E4540A9F92AF9D8B34C4031EA5A7B9F3A4540A9F92AF9D8B34C40
23648	Горки	1	5	1639	42.097749	42.232649000000002	57.429445000000001	57.365788000000002	0103000020E61000000100000005000000BD1B0B0A830C454077A22424D2AE4C40BD1B0B0A830C45402237C30DF8B64C403B394371C71D45402237C30DF8B64C403B394371C71D454077A22424D2AE4C40BD1B0B0A830C454077A22424D2AE4C40
23485	Большие Горки	1	5	1639	42.223126999999998	42.251289	57.270353	57.256428	0103000020E6100000010000000500000063EDEF6C8F1C4540ACE3F8A1D2A04C4063EDEF6C8F1C454010B056ED9AA24C401A6CEA3C2A20454010B056ED9AA24C401A6CEA3C2A204540ACE3F8A1D2A04C4063EDEF6C8F1C4540ACE3F8A1D2A04C40
23438	Батманы	1	5	1639	42.293519000000003	42.31427	57.269584000000002	57.258316000000001	0103000020E6100000010000000500000098E0D407922545404B04AA7F10A14C4098E0D407922545402FC37FBA81A24C40950ED6FF392845402FC37FBA81A24C40950ED6FF392845404B04AA7F10A14C4098E0D407922545404B04AA7F10A14C40
23341	Щенниково	1	5	234	39.588054	39.615290999999999	56.861868999999999	56.853808000000001	0103000020E6100000010000000500000018247D5A45CB434016889E94496D4C4018247D5A45CB4340D63730B9516E4C40F64201DBC1CE4340D63730B9516E4C40F64201DBC1CE434016889E94496D4C4018247D5A45CB434016889E94496D4C40
48915	Савино	1	5	234	40.128650999999998	40.133097999999997	56.941572000000001	56.938670000000002	0103000020E6100000010000000500000081CCCEA27710444040DEAB5626784C4081CCCEA277104440276A696E85784C40DD94F25A09114440276A696E85784C40DD94F25A0911444040DEAB5626784C4081CCCEA27710444040DEAB5626784C40
48337	Новоселка	1	5	234	39.959623999999998	39.981920000000002	56.955311999999999	56.946638999999998	0103000020E61000000100000005000000753A90F5D4FA43401F0F7D772B794C40753A90F5D4FA4340F9BCE2A9477A4C40E8A4F78DAFFD4340F9BCE2A9477A4C40E8A4F78DAFFD43401F0F7D772B794C40753A90F5D4FA43401F0F7D772B794C40
45935	Никольское	1	5	234	39.721803999999999	39.748026000000003	56.848537	56.836844999999997	0103000020E610000001000000050000009D0FCF1264DC43401A69A9BC1D6B4C409D0FCF1264DC4340153944DC9C6C4C406347E350BFDF4340153944DC9C6C4C406347E350BFDF43401A69A9BC1D6B4C409D0FCF1264DC43401A69A9BC1D6B4C40
23272	Нажерово	1	5	234	39.917358	39.936186999999997	57.118682	57.107201000000003	0103000020E61000000100000005000000AB5CA8FC6BF543409C8C2AC3B88D4C40AB5CA8FC6BF54340DB4FC6F8308F4C405DF8C1F9D4F74340DB4FC6F8308F4C405DF8C1F9D4F743409C8C2AC3B88D4C40AB5CA8FC6BF543409C8C2AC3B88D4C40
49565	Кулачево	1	5	234	39.640290999999998	39.668947000000003	56.982106999999999	56.972276000000001	0103000020E610000001000000050000002976340EF5D14340C5573B8A737C4C402976340EF5D143401A16A3AEB57D4C40F0E0270EA0D543401A16A3AEB57D4C40F0E0270EA0D54340C5573B8A737C4C402976340EF5D14340C5573B8A737C4C40
23001	Коварчино	1	5	234	40.048862999999997	40.068041999999998	56.986001000000002	56.977673000000003	0103000020E61000000100000005000000027E8D244106444053978C63247D4C40027E8D24410644406269E047357E4C409160AA99B50844406269E047357E4C409160AA99B508444053978C63247D4C40027E8D244106444053978C63247D4C40
49555	Исаевское	1	5	234	39.683590000000002	39.709460999999997	57.020457	57.007559000000001	0103000020E61000000100000005000000B3EF8AE07FD743402EE57CB1F7804C40B3EF8AE07FD74340B5FCC0559E824C40CB64389ECFDA4340B5FCC0559E824C40CB64389ECFDA43402EE57CB1F7804C40B3EF8AE07FD743402EE57CB1F7804C40
22722	Ильинское-Хованское	1	5	234	39.739339000000001	39.787255000000002	56.983127000000003	56.962409000000001	0103000020E6100000010000000500000024D40CA9A2DE43402330D637307B4C4024D40CA9A2DE43404568041BD77D4C40664E97C5C4E443404568041BD77D4C40664E97C5C4E443402330D637307B4C4024D40CA9A2DE43402330D637307B4C40
48873	Воскресенское	1	5	234	39.879511999999998	39.891342999999999	56.926613000000003	56.919082000000003	0103000020E61000000100000005000000433866D993F04340D02B9E7AA4754C40433866D993F04340348639419B764C405F42058717F24340348639419B764C405F42058717F24340D02B9E7AA4754C40433866D993F04340D02B9E7AA4754C40
22918	Аньково	1	5	234	39.935108999999997	39.972461000000003	56.950133999999998	56.927624000000002	0103000020E61000000100000005000000FE98D6A6B1F743400B7E1B62BC764C40FE98D6A6B1F74340A968ACFD9D794C4057D11F9A79FC4340A968ACFD9D794C4057D11F9A79FC43400B7E1B62BC764C40FE98D6A6B1F743400B7E1B62BC764C40
54082	с. Богородское	1	5	1299	40.618322999999997	41.427318	57.194682999999998	56.813631000000001	0103000020E61000000100000005000000ABAE4335254F44408201840F25684C40ABAE4335254F4440280B5F5FEB984C40FE7E315BB2B64440280B5F5FEB984C40FE7E315BB2B644408201840F25684C40ABAE4335254F44408201840F25684C40
54098	городской округ Кохма	1	5	1299	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
49352	Чернореченский	1	5	1299	40.847186000000001	40.880774000000002	56.983587999999997	56.968381000000001	0103000020E6100000010000000500000085D04197706C4440AD889AE8F37B4C4085D04197706C4440785E2A36E67D4C406495D233BD704440785E2A36E67D4C406495D233BD704440AD889AE8F37B4C4085D04197706C4440AD889AE8F37B4C40
46985	Теплово	1	5	1299	41.192822	41.204644000000002	56.912827	56.909210000000002	0103000020E6100000010000000500000083F92B64AE9844401C9947FE60744C4083F92B64AE984440F1F3DF83D7744C404CA94BC6319A4440F1F3DF83D7744C404CA94BC6319A44401C9947FE60744C4083F92B64AE9844401C9947FE60744C40
18584	Стромихино	1	5	1299	41.062162000000001	41.074550000000002	56.872039000000001	56.860185999999999	0103000020E61000000100000005000000E886A6ECF4874440103D29931A6E4C40E886A6ECF487444014EB54F99E6F4C405AF5B9DA8A89444014EB54F99E6F4C405AF5B9DA8A894440103D29931A6E4C40E886A6ECF4874440103D29931A6E4C40
54117	Светлый Луч	1	5	1299	40.618322999999997	41.427318	57.194682999999998	56.813631000000001	0103000020E61000000100000005000000ABAE4335254F44408201840F25684C40ABAE4335254F4440280B5F5FEB984C40FE7E315BB2B64440280B5F5FEB984C40FE7E315BB2B644408201840F25684C40ABAE4335254F44408201840F25684C40
22262	Подвязновский	1	5	1299	41.112540000000003	41.127262999999999	56.972026	56.963940000000001	0103000020E61000000100000005000000F5BEF1B5678E444033A7CB62627B4C40F5BEF1B5678E44404C6E14596B7C4C40D47E6B274A9044404C6E14596B7C4C40D47E6B274A90444033A7CB62627B4C40F5BEF1B5678E444033A7CB62627B4C40
21400	Панеево	1	5	1299	40.891384000000002	40.909979	56.891877999999998	56.882962999999997	0103000020E61000000100000005000000BE16F4DE18724440FD497CEE04714C40BE16F4DE18724440CD02ED0E29724C40FD851E317A744440CD02ED0E29724C40FD851E317A744440FD497CEE04714C40BE16F4DE18724440FD497CEE04714C40
49204	Озерный	1	5	1299	40.969231999999998	40.996881999999999	57.164627000000003	57.149118000000001	0103000020E610000001000000050000004B1E4FCB0F7C44405A9F724C16934C404B1E4FCB0F7C4440F1845E7F12954C404CFC51D4997F4440F1845E7F12954C404CFC51D4997F44405A9F724C16934C404B1E4FCB0F7C44405A9F724C16934C40
54099	Новоталицы	1	5	1299	40.816589999999998	40.875151000000002	57.019942	56.998696000000002	0103000020E61000000100000005000000CD1E680586684440B1524145D57F4C40CD1E6805866844408EE89E758D824C40E607AEF2047044408EE89E758D824C40E607AEF204704440B1524145D57F4C40CD1E680586684440B1524145D57F4C40
54102	Михалево	1	5	1299	40.776012999999999	40.800618	56.997750000000003	56.983853000000003	0103000020E61000000100000005000000AB22DC6454634440278925E5EE7D4C40AB22DC6454634440C1CAA145B67F4C40624B8FA67A664440C1CAA145B67F4C40624B8FA67A664440278925E5EE7D4C40AB22DC6454634440278925E5EE7D4C40
49037	Куликово	1	5	1299	41.202542000000001	41.218766000000002	57.000838000000002	56.994351999999999	0103000020E61000000100000005000000810871E5EC994440295B24ED467F4C40810871E5EC9944400A4CA7751B804C4006BD3786009C44400A4CA7751B804C4006BD3786009C4440295B24ED467F4C40810871E5EC994440295B24ED467F4C40
20887	Кочорский	1	5	1299	41.074280999999999	41.083758000000003	56.924702000000003	56.918751999999998	0103000020E610000001000000050000006ADB300A828944403A9160AA99754C406ADB300A82894440DD4598A25C764C40A2630795B88A4440DD4598A25C764C40A2630795B88A44403A9160AA99754C406ADB300A828944403A9160AA99754C40
21532	Котцыно	1	5	1299	41.200035999999997	41.222754000000002	57.044637999999999	57.031880999999998	0103000020E61000000100000005000000E60297C79A994440902E36AD14844C40E60297C79A9944405514AFB2B6854C40CF86FC33839C44405514AFB2B6854C40CF86FC33839C4440902E36AD14844C40E60297C79A994440902E36AD14844C40
22441	Колбацкое	1	5	1299	41.400664999999996	41.416798999999997	57.047840000000001	57.039942000000003	0103000020E610000001000000050000006FD39FFD48B3444051DEC7D11C854C406FD39FFD48B3444067B8019F1F864C40B4006DAB59B5444067B8019F1F864C40B4006DAB59B5444051DEC7D11C854C406FD39FFD48B3444051DEC7D11C854C40
49040	Кожевниково	1	5	1299	41.303063999999999	41.307295000000003	57.003897000000002	56.996538999999999	0103000020E61000000100000005000000274C18CDCAA64440221807978E7F4C40274C18CDCAA64440B9C667B27F804C40B79C4B7155A74440B9C667B27F804C40B79C4B7155A74440221807978E7F4C40274C18CDCAA64440221807978E7F4C40
49087	Калачево	1	5	1299	41.202146999999997	41.214013999999999	57.066343000000003	57.061508000000003	0103000020E6100000010000000500000004FEF0F3DF994440A038807EDF874C4004FEF0F3DF994440C6A86BED7D884C406D718DCF649B4440C6A86BED7D884C406D718DCF649B4440A038807EDF874C4004FEF0F3DF994440A038807EDF874C40
49170	Залесье	1	5	1299	40.747751999999998	40.764955	57.026114999999997	57.018917999999999	0103000020E6100000010000000500000061C26856B65F444022A7AFE76B824C4061C26856B65F4440AF777FBC57834C40B2F4A10BEA614440AF777FBC57834C40B2F4A10BEA61444022A7AFE76B824C4061C26856B65F444022A7AFE76B824C40
54114	Ермолино	1	5	1299	41.237900000000003	41.260950999999999	57.098430999999998	57.089427999999998	0103000020E61000000100000005000000F5DBD781739E444060AC6F60728B4C40F5DBD781739E4440CFF41263998C4C40E36DA5D766A14440CFF41263998C4C40E36DA5D766A1444060AC6F60728B4C40F5DBD781739E444060AC6F60728B4C40
21306	Дегтярево	1	5	1299	40.899388000000002	40.916607999999997	56.926887999999998	56.918497000000002	0103000020E610000001000000050000001A355F251F734440B03C484F91754C401A355F251F73444005871744A4764C4040A033695375444005871744A4764C4040A0336953754440B03C484F91754C401A355F251F734440B03C484F91754C40
21239	Бяково	1	5	1299	41.06174	41.075592	57.068300000000001	57.059153000000002	0103000020E61000000100000005000000726DA818E7874440EB3A545392874C40726DA818E78744408D28ED0DBE884C406CEBA7FFAC8944408D28ED0DBE884C406CEBA7FFAC894440EB3A545392874C40726DA818E7874440EB3A545392874C40
48779	Буньково	1	5	1299	40.694930999999997	40.722976000000003	57.071098999999997	57.059251000000003	0103000020E6100000010000000500000000FDBE7FF3584440AEA0698995874C4000FDBE7FF35844409FE3A3C519894C407EE5417A8A5C44409FE3A3C519894C407EE5417A8A5C4440AEA0698995874C4000FDBE7FF3584440AEA0698995874C40
47035	Богданиха	1	5	1299	41.115324999999999	41.145525999999997	56.922151999999997	56.911161	0103000020E61000000100000005000000A2B437F8C28E4440013274ECA0744C40A2B437F8C28E444072F8A41309764C40DD5B9198A092444072F8A41309764C40DD5B9198A0924440013274ECA0744C40A2B437F8C28E4440013274ECA0744C40
49239	Бибирево	1	5	1299	41.029266	41.051113000000001	57.143799999999999	57.132288000000003	0103000020E610000001000000050000003F7100FDBE8344409ED32CD0EE904C403F7100FDBE8344401895D40968924C4042B3EBDE8A8644401895D40968924C4042B3EBDE8A8644409ED32CD0EE904C403F7100FDBE8344409ED32CD0EE904C40
20565	Балахонки	1	5	1299	40.744185999999999	40.778277000000003	57.098807000000001	57.086762999999998	0103000020E610000001000000050000000E12A27C415F44405DC0CB0C1B8B4C400E12A27C415F4440D5CE30B5A58C4C40501DAB949E634440D5CE30B5A58C4C40501DAB949E6344405DC0CB0C1B8B4C400E12A27C415F44405DC0CB0C1B8B4C40
19994	Новлянское	1	5	1597	41.714742999999999	41.736096000000003	57.462015999999998	57.448013000000003	0103000020E61000000100000005000000C005D9B27CDB444068976F7D58B94C40C005D9B27CDB4440471D1D5723BB4C40B45BCB6438DE4440471D1D5723BB4C40B45BCB6438DE444068976F7D58B94C40C005D9B27CDB444068976F7D58B94C40
20085	Коротиха	1	5	1597	42.210425000000001	42.236404	57.459401	57.451324999999997	0103000020E6100000010000000500000062A1D634EF1A4540006F8104C5B94C4062A1D634EF1A4540F65FE7A6CDBA4C4061527C7C421E4540F65FE7A6CDBA4C4061527C7C421E4540006F8104C5B94C4062A1D634EF1A4540006F8104C5B94C40
20383	Корнилово	1	5	1597	41.883654	41.904656000000003	57.586517999999998	57.573765000000002	0103000020E61000000100000005000000637D03931BF14440734BAB2171C94C40637D03931BF14440F641960513CB4C40AA108FC4CBF34440F641960513CB4C40AA108FC4CBF34440734BAB2171C94C40637D03931BF14440734BAB2171C94C40
20265	Колшево	1	5	1597	41.638944000000002	41.683903999999998	57.682533999999997	57.671095000000001	0103000020E61000000100000005000000DBFCBFEAC8D144402BC1E270E6D54C40DBFCBFEAC8D144403B342C465DD74C4042CD902A8AD744403B342C465DD74C4042CD902A8AD744402BC1E270E6D54C40DBFCBFEAC8D144402BC1E270E6D54C40
20173	Заречный	1	5	1597	42.264333000000001	42.300283	57.474798999999997	57.460776000000003	0103000020E610000001000000050000007520EBA9D52145400F643DB5FABA4C407520EBA9D52145403596B036C6BC4C40BB4560AC6F2645403596B036C6BC4C40BB4560AC6F2645400F643DB5FABA4C407520EBA9D52145400F643DB5FABA4C40
19473	Заволжск	1	5	1597	42.105114999999998	42.193752000000003	57.502479000000001	57.454109000000003	0103000020E61000000100000005000000D6A88768740D4540DEE8633E20BA4C40D6A88768740D4540A1F65B3B51C04C406EC493DDCC184540A1F65B3B51C04C406EC493DDCC184540DEE8633E20BA4C40D6A88768740D4540DEE8633E20BA4C40
20468	Жажлево	1	5	1597	42.393312999999999	42.438955999999997	57.466057999999997	57.450085000000001	0103000020E61000000100000005000000BB0B941458324540C8B5A1629CB94C40BB0B9414583245400305DEC9A7BB4C400531D0B52F3845400305DEC9A7BB4C400531D0B52F384540C8B5A1629CB94C40BB0B941458324540C8B5A1629CB94C40
19892	Есиплево	1	5	1597	41.819020000000002	41.860756000000002	57.542158999999998	57.520448999999999	0103000020E610000001000000050000008D62B9A5D5E84440321EA5129EC24C408D62B9A5D5E84440B41D537765C54C40FBEAAA402DEE4440B41D537765C54C40FBEAAA402DEE4440321EA5129EC24C408D62B9A5D5E84440321EA5129EC24C40
20494	Долматовский	1	5	1597	42.321123999999998	42.350104000000002	57.511254999999998	57.492429000000001	0103000020E61000000100000005000000F8FA5A971A2945400E4DD9E907BF4C40F8FA5A971A2945404F75C8CD70C14C4072193735D02C45404F75C8CD70C14C4072193735D02C45400E4DD9E907BF4C40F8FA5A971A2945400E4DD9E907BF4C40
19962	Гольцовка	1	5	1597	41.889204999999997	41.914205000000003	57.480246999999999	57.469475000000003	0103000020E6100000010000000500000047382D78D1F1444012A5BDC117BC4C4047382D78D1F144404580D3BB78BD4C407B6B60AB04F544404580D3BB78BD4C407B6B60AB04F5444012A5BDC117BC4C4047382D78D1F1444012A5BDC117BC4C40
19866	Воздвиженье	1	5	1597	42.004621	42.025309	57.502251999999999	57.495742	0103000020E61000000100000005000000FAEFC16B9700454077A04E7974BF4C40FAEFC16B97004540E02C25CB49C04C40B1A547533D034540E02C25CB49C04C40B1A547533D03454077A04E7974BF4C40FAEFC16B9700454077A04E7974BF4C40
18913	Шекшово	1	5	1548	40.164566000000001	40.196061	56.533918999999997	56.521219000000002	0103000020E610000001000000050000004B04AA7F10154440E486DF4DB7424C404B04AA7F1015444044DB317557444C40B282DF861819444044DB317557444C40B282DF8618194440E486DF4DB7424C404B04AA7F10154440E486DF4DB7424C40
19163	Скомово	1	5	1548	39.851709	39.884515999999998	56.613990000000001	56.602595999999998	0103000020E61000000100000005000000BC5AEECC04ED4340A759A0DD214D4C40BC5AEECC04ED434018096D39974E4C40F564FED137F1434018096D39974E4C40F564FED137F14340A759A0DD214D4C40BC5AEECC04ED4340A759A0DD214D4C40
19071	Ратницкое	1	5	1548	40.244615000000003	40.25985	56.521517000000003	56.511797999999999	0103000020E61000000100000005000000378E588B4F1F44404014CC9882414C40378E588B4F1F44406EA7AD11C1424C40CCEEC9C3422144406EA7AD11C1424C40CCEEC9C3422144404014CC9882414C40378E588B4F1F44404014CC9882414C40
45589	Петровский	1	5	1548	40.295127000000001	40.321024999999999	56.649236000000002	56.634743999999998	0103000020E610000001000000050000005395B6B8C625444086AA984A3F514C405395B6B8C625444064B14D2A1A534C406519E2581729444064B14D2A1A534C406519E2581729444086AA984A3F514C405395B6B8C625444086AA984A3F514C40
19130	Осановец	1	5	1548	39.955869	39.997452000000003	56.566577000000002	56.556789999999999	0103000020E610000001000000050000004F2157EA59FA4340B35E0CE544474C404F2157EA59FA434039D55A9885484C4037AAD381ACFF434039D55A9885484C4037AAD381ACFF4340B35E0CE544474C404F2157EA59FA4340B35E0CE544474C40
60367	Непотягово	1	5	1548	40.123099000000003	40.147857000000002	56.482999999999997	56.468259000000003	0103000020E61000000100000005000000CD9541B5C10F4440628731E9EF3B4C40CD9541B5C10F4440E7FBA9F1D23D4C400ABE69FAEC124440E7FBA9F1D23D4C400ABE69FAEC124440628731E9EF3B4C40CD9541B5C10F4440628731E9EF3B4C40
18851	Лобцово	1	5	1548	40.080852	40.101998000000002	56.758313999999999	56.746429999999997	0103000020E6100000010000000500000079E8BB5B590A44406B60AB048B5F4C4079E8BB5B590A4440AA0CE36E10614C40F3203D450E0D4440AA0CE36E10614C40F3203D450E0D44406B60AB048B5F4C4079E8BB5B590A44406B60AB048B5F4C40
60466	Липовая Роща	1	5	1548	39.822280999999997	40.417988999999999	56.837893000000001	56.435366999999999	0103000020E61000000100000005000000A38FF98040E94340FA60191BBA374C40A38FF98040E943400F46EC13406B4C403B8BDEA9803544400F46EC13406B4C403B8BDEA980354440FA60191BBA374C40A38FF98040E94340FA60191BBA374C40
48376	Иваньковский	1	5	1548	40.096086999999997	40.125371999999999	56.684235999999999	56.669659000000003	0103000020E610000001000000050000000E492D944C0C44406D3CD862B7554C400E492D944C0C4440785F950B95574C40C4EA8F300C104440785F950B95574C40C4EA8F300C1044406D3CD862B7554C400E492D944C0C44406D3CD862B7554C40
48303	Загорье	1	5	1548	39.948745000000002	39.971715000000003	56.511014000000003	56.497177999999998	0103000020E610000001000000050000002C9FE57970F9434035255987A33F4C402C9FE57970F943402AE620E868414C402E04392861FC43402AE620E868414C402E04392861FC434035255987A33F4C402C9FE57970F9434035255987A33F4C40
18475	Гаврилов Посад	1	5	1548	40.092053999999997	40.148378000000001	56.575279999999999	56.544158000000003	0103000020E61000000100000005000000A5BBEB6CC80B4440ABED26F8A6454C40A5BBEB6CC80B44407D0569C6A2494C4013B9E00CFE1244407D0569C6A2494C4013B9E00CFE124440ABED26F8A6454C40A5BBEB6CC80B4440ABED26F8A6454C40
48212	Бородино	1	5	1548	40.238622999999997	40.265635000000003	56.557242000000002	56.546112999999998	0103000020E610000001000000050000006589CE328B1E4440D175E107E7454C406589CE328B1E444094FAB2B453474C4024D6E2530022444094FAB2B453474C4024D6E25300224440D175E107E7454C406589CE328B1E4440D175E107E7454C40
48361	Бережок	1	5	1548	39.917852000000003	39.941927	56.661619999999999	56.647573000000001	0103000020E61000000100000005000000BB48A12C7CF54340E5620CACE3524C40BB48A12C7CF543409430D3F6AF544C40151C5E1091F843409430D3F6AF544C40151C5E1091F84340E5620CACE3524C40BB48A12C7CF54340E5620CACE3524C40
18334	Чертовищи	1	5	1515	41.864789000000002	41.887965999999999	57.307806999999997	57.293253	0103000020E610000001000000050000006478EC67B1EE4440193A765089A54C406478EC67B1EE44406C3D433866A74C40DFFAB0DEA8F144406C3D433866A74C40DFFAB0DEA8F14440193A765089A54C406478EC67B1EE4440193A765089A54C40
17870	Старая Вичуга	1	5	1515	41.856757999999999	41.902734000000002	57.286935	57.255532000000002	0103000020E610000001000000050000000E4B033FAAED44406E8AC745B5A04C400E4B033FAAED4440F4893C49BAA44C405F7EA7C98CF34440F4893C49BAA44C405F7EA7C98CF344406E8AC745B5A04C400E4B033FAAED44406E8AC745B5A04C40
47896	Сошники	1	5	1515	41.993876999999998	42.012166999999998	57.237074999999997	57.225558999999997	0103000020E61000000100000005000000909F8D5C37FF4440C328081EDF9C4C40909F8D5C37FF44407FD93D79589E4C40938B31B08E0145407FD93D79589E4C40938B31B08E014540C328081EDF9C4C40909F8D5C37FF4440C328081EDF9C4C40
46779	Сорокино	1	5	1515	42.047263999999998	42.063631000000001	57.128708000000003	57.120226000000002	0103000020E610000001000000050000009A232BBF0C0645408010C990638F4C409A232BBF0C064540E65DF58079904C408201840F25084540E65DF58079904C408201840F250845408010C990638F4C409A232BBF0C0645408010C990638F4C40
18356	Семигорье	1	5	1515	41.808770000000003	41.833770000000001	57.395384999999997	57.381774	0103000020E6100000010000000500000033FE7DC685E74440473B6EF8DDB04C4033FE7DC685E744401B2AC6F99BB24C406631B1F9B8EA44401B2AC6F99BB24C406631B1F9B8EA4440473B6EF8DDB04C4033FE7DC685E74440473B6EF8DDB04C40
40307	Семеновское	1	5	1515	42.202142000000002	42.210838000000003	57.195995000000003	57.191215999999997	0103000020E61000000100000005000000F392FFC9DF194540683C11C479984C40F392FFC9DF194540FB96395D16994C40856055BDFC1A4540FB96395D16994C40856055BDFC1A4540683C11C479984C40F392FFC9DF194540683C11C479984C40
46959	Раменье	1	5	1515	41.632125000000002	41.642420000000001	57.364885999999998	57.360041000000002	0103000020E61000000100000005000000F4FDD478E9D044400D1CD0D215AE4C40F4FDD478E9D0444056629E95B4AE4C40EE258DD13AD2444056629E95B4AE4C40EE258DD13AD244400D1CD0D215AE4C40F4FDD478E9D044400D1CD0D215AE4C40
47945	Раздолье	1	5	1515	42.075830000000003	42.088272000000003	57.150207000000002	57.146022000000002	0103000020E61000000100000005000000210725CCB40945408E3F51D9B0924C40210725CCB4094540AD50A4FB39934C408693347F4C0B4540AD50A4FB39934C408693347F4C0B45408E3F51D9B0924C40210725CCB40945408E3F51D9B0924C40
48930	Панино	1	5	1515	41.912588	41.919541000000002	57.13729	57.134594	0103000020E610000001000000050000006C5CFFAECFF44440711E4E603A914C406C5CFFAECFF44440AF08FEB792914C40632AFD84B3F54440AF08FEB792914C40632AFD84B3F54440711E4E603A914C406C5CFFAECFF44440711E4E603A914C40
17769	Новописцово	1	5	1515	41.818857999999999	41.869613000000001	57.331242000000003	57.312809000000001	0103000020E61000000100000005000000B308C556D0E844407E7214200AA84C40B308C556D0E84440E4874A2366AA4C409696917A4FEF4440E4874A2366AA4C409696917A4FEF44407E7214200AA84C40B308C556D0E844407E7214200AA84C40
48049	Малышево	1	5	1515	42.200533999999998	42.212850000000003	57.170135999999999	57.163679999999999	0103000020E6100000010000000500000037DE1D19AB19454030815B77F3944C4037DE1D19AB194540A6EF3504C7954C40107A36AB3E1B4540A6EF3504C7954C40107A36AB3E1B454030815B77F3944C4037DE1D19AB19454030815B77F3944C40
47887	Красный Октябрь	1	5	1515	41.846023000000002	41.879646999999999	57.191293999999999	57.181089999999998	0103000020E61000000100000005000000F8544E7B4AEC4440FAD005F52D974C40F8544E7B4AEC4440E4F560527C984C402383DC4598F04440E4F560527C984C402383DC4598F04440FAD005F52D974C40F8544E7B4AEC4440FAD005F52D974C40
47723	Каменка	1	5	1515	41.778542000000002	41.814473999999997	57.404400000000003	57.377668999999997	0103000020E61000000100000005000000FE47A643A7E3444044DB317557B04C40FE47A643A7E344404F401361C3B34C409DB81CAF40E844404F401361C3B34C409DB81CAF40E8444044DB317557B04C40FE47A643A7E3444044DB317557B04C40
49584	Ивашево	1	5	1515	41.766666000000001	41.775640000000003	57.315609000000002	57.309144000000003	0103000020E61000000100000005000000427A8A1C22E2444098E0D40792A74C40427A8A1C22E2444061A92EE065A84C4017BCE82B48E3444061A92EE065A84C4017BCE82B48E3444098E0D40792A74C40427A8A1C22E2444098E0D40792A74C40
47843	Золотилово	1	5	1515	41.630670000000002	41.643614999999997	57.325682999999998	57.317247000000002	0103000020E61000000100000005000000BF4868CBB9D0444087E0B88C9BA84C40BF4868CBB9D044407CEE04FBAFA94C40861BF0F961D244407CEE04FBAFA94C40861BF0F961D2444087E0B88C9BA84C40BF4868CBB9D0444087E0B88C9BA84C40
47076	Демидово	1	5	1515	41.852536000000001	41.864168999999997	57.278407000000001	57.271949999999997	0103000020E61000000100000005000000D2544FE61FED4440D712F241CFA24C40D2544FE61FED44401EFD2FD7A2A34C40C79BFC169DEE44401EFD2FD7A2A34C40C79BFC169DEE4440D712F241CFA24C40D2544FE61FED4440D712F241CFA24C40
49446	Гари	1	5	1515	41.640155999999998	41.649121999999998	57.29372	57.289411000000001	0103000020E61000000100000005000000492BBEA1F0D14440240D6E6B0BA54C40492BBEA1F0D144402F17F19D98A54C409B8E006E16D344402F17F19D98A54C409B8E006E16D34440240D6E6B0BA54C40492BBEA1F0D14440240D6E6B0BA54C40
47866	Гаврилково	1	5	1515	41.692042999999998	41.719199000000003	57.260433999999997	57.251291000000002	0103000020E610000001000000050000007E3672DD94D84440BB63B14D2AA04C407E3672DD94D844401B62BCE655A14C4070287CB60EDC44401B62BCE655A14C4070287CB60EDC4440BB63B14D2AA04C407E3672DD94D84440BB63B14D2AA04C40
45582	Симаково	1	5	1222	42.754750000000001	42.771026999999997	56.882235000000001	56.870524000000003	0103000020E61000000100000005000000F853E3A59B6045400A3197546D6F4C40F853E3A59B6045407B319413ED704C409FAA4203B16245407B319413ED704C409FAA4203B16245400A3197546D6F4C40F853E3A59B6045400A3197546D6F4C40
12285	Мыт	1	5	1222	42.299501999999997	42.335397999999998	56.827221999999999	56.802405999999998	0103000020E61000000100000005000000158BDF14562645409D0E643DB5664C40158BDF14562645400F441669E2694C4068925852EE2A45400F441669E2694C4068925852EE2A45409D0E643DB5664C40158BDF14562645409D0E643DB5664C40
49118	Кромы	1	5	1222	42.499124999999999	42.524431	56.885496000000003	56.875895	0103000020E61000000100000005000000D9CEF753E33F45406EDDCD531D704C40D9CEF753E33F4540925ED4EE57714C401901158E20434540925ED4EE57714C401901158E204345406EDDCD531D704C40D9CEF753E33F45406EDDCD531D704C40
49215	Иваньково	1	5	1222	42.303525999999998	42.316381	56.888342999999999	56.880400999999999	0103000020E610000001000000050000002BBEA1F0D9264540CF2EDFFAB0704C402BBEA1F0D9264540B5503239B5714C40B309302C7F284540B5503239B5714C40B309302C7F284540CF2EDFFAB0704C402BBEA1F0D9264540CF2EDFFAB0704C40
47705	Засека	1	5	1222	42.789712000000002	42.807732999999999	56.844062000000001	56.837076000000003	0103000020E610000001000000050000001FA16648156545401D226E4E256B4C401FA1664815654540EFE53E390A6C4C40327381CB63674540EFE53E390A6C4C40327381CB636745401D226E4E256B4C401FA16648156545401D226E4E256B4C40
17545	Верхний Ландех	1	5	1222	42.575176999999996	42.616211999999997	56.845976999999998	56.831088000000001	0103000020E61000000100000005000000A83462669F4945408D0C7217616A4C40A83462669F49454087156EF9486C4C408DB3E908E04E454087156EF9486C4C408DB3E908E04E45408D0C7217616A4C40A83462669F4945408D0C7217616A4C40
47364	Бараново	1	5	1222	42.631383999999997	42.637366999999998	56.906458000000001	56.903233999999998	0103000020E61000000100000005000000DC9BDF30D15045405051F52B9D734C40DC9BDF30D15045404A99D4D006744C405A46EA3D955145404A99D4D006744C405A46EA3D955145405051F52B9D734C40DC9BDF30D15045405051F52B9D734C40
60404	с.Новогремяченское	1	4	\N	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
54257	Эртиль	1	4	\N	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
54284	Семилуки	1	4	\N	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
2019	Россошь	1	4	\N	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
54278	Поворино	1	4	\N	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
54255	Павловск	1	4	\N	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
54258	Острогожск	1	4	\N	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
54270	Новохоперск	1	4	\N	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
54253	Нововоронеж	1	4	\N	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
54281	Лиски	1	4	\N	39.450800000000001	39.514518000000002	50.963075000000003	50.922620999999999	0103000020E61000000100000005000000B6847CD0B3B9434029CDE67118764940B6847CD0B3B94340304CA60A467B4940079ACFB9DBC14340304CA60A467B4940079ACFB9DBC1434029CDE67118764940B6847CD0B3B9434029CDE67118764940
54251	Лиски	1	4	\N	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
54271	Калач	1	4	\N	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
54277	Грибановский	1	4	\N	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
19	Воронеж	1	4	\N	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
54256	Бутурлиновка	1	4	\N	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
11742	Борисоглебск	1	4	\N	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
54328	Богучар	1	4	\N	40.520775	40.579551000000002	49.950671999999997	49.918503000000001	0103000020E6100000010000000500000086C954C1A842444092239D8191F5484086C954C1A8424440889CBE9EAFF948409BAE27BA2E4A4440889CBE9EAFF948409BAE27BA2E4A444092239D8191F5484086C954C1A842444092239D8191F54840
54290	Бобяково	1	4	\N	40.794141000000003	40.818925	51.527337000000003	51.508595999999997	0103000020E61000000100000005000000D5B48B69A66544402E7079AC19C14940D5B48B69A6654440427C60C77FC349403B70CE88D2684440427C60C77FC349403B70CE88D26844402E7079AC19C14940D5B48B69A66544402E7079AC19C14940
54259	Бобров	1	4	\N	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
14491	Ячейка	1	4	1280	40.583368999999998	40.617604	51.856135000000002	51.834758999999998	0103000020E610000001000000050000000740DCD5AB4A444055850662D9EA49400740DCD5AB4A444001FBE8D495ED49407CF0DAA50D4F444001FBE8D495ED49407CF0DAA50D4F444055850662D9EA49400740DCD5AB4A444055850662D9EA4940
14627	Эртиль	1	4	1280	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
49160	Щучье	1	4	1280	40.471080000000001	40.916195000000002	51.875833999999998	51.738103000000002	0103000020E610000001000000050000005CE674594C3C44402D0ABB287ADE49405CE674594C3C4440C85C19541BF049401EE1B4E045754440C85C19541BF049401EE1B4E0457544402D0ABB287ADE49405CE674594C3C44402D0ABB287ADE4940
54345	Щученские Пески	1	4	1280	40.510184000000002	40.550418999999998	51.779879999999999	51.737555999999998	0103000020E61000000100000005000000A37895B54D414440FA7B293C68DE4940A37895B54D414440F9669B1BD3E349406B0C3A2174464440F9669B1BD3E349406B0C3A2174464440FA7B293C68DE4940A37895B54D414440FA7B293C68DE4940
48004	Сергеевка	1	4	1280	40.713831999999996	40.744481999999998	51.670774000000002	51.650297999999999	0103000020E610000001000000050000004C6BD3D85E5B4440BD5301F73CD349404C6BD3D85E5B4440E98024ECDBD54940F73AA92F4B5F4440E98024ECDBD54940F73AA92F4B5F4440BD5301F73CD349404C6BD3D85E5B4440BD5301F73CD34940
48949	Ростоши	1	4	1280	40.899163000000001	40.971415	51.624267000000003	51.570954999999998	0103000020E61000000100000005000000FA62EFC5177344406C3EAE0D15C94940FA62EFC5177344406C7C26FBE7CF494003ECA353577C44406C7C26FBE7CF494003ECA353577C44406C3EAE0D15C94940FA62EFC5177344406C3EAE0D15C94940
54433	Первоэртиль	1	4	1280	40.813696999999998	40.830136000000003	51.749054999999998	51.717272999999999	0103000020E6100000010000000500000039ED293927684440E3A6069ACFDB494039ED293927684440E0F3C308E1DF4940BB9D7DE5416A4440E0F3C308E1DF4940BB9D7DE5416A4440E3A6069ACFDB494039ED293927684440E3A6069ACFDB4940
49453	Мичуринский	1	4	1280	40.814720999999999	40.828043000000001	51.824367000000002	51.808020999999997	0103000020E61000000100000005000000A52E19C74868444098BD6C3B6DE74940A52E19C74868444069739CDB84E9494043572250FD69444069739CDB84E9494043572250FD69444098BD6C3B6DE74940A52E19C74868444098BD6C3B6DE74940
46394	Марьевка	1	4	1280	40.702306	40.724926000000004	51.918492999999998	51.904265000000002	0103000020E610000001000000050000006DE4BA29E55944406FF59CF4BEF349406DE4BA29E55944406E4DBA2D91F5494093020B60CA5C44406E4DBA2D91F5494093020B60CA5C44406FF59CF4BEF349406DE4BA29E55944406FF59CF4BEF34940
15180	МТФ	1	4	1280	40.749530999999998	40.766356000000002	51.847017000000001	51.831741999999998	0103000020E61000000100000005000000492BBEA1F05F4440D55A988576EA4940492BBEA1F05F4440F913950D6BEC4940F48B12F417624440F913950D6BEC4940F48B12F417624440D55A988576EA4940492BBEA1F05F4440D55A988576EA4940
46183	Красноармейский	1	4	1280	40.777594000000001	40.797033999999996	51.830044999999998	51.817107999999998	0103000020E610000001000000050000006DC83F338863444065A6B4FE96E849406DC83F3388634440AA9A20EA3EEA494068E6C93505664440AA9A20EA3EEA494068E6C9350566444065A6B4FE96E849406DC83F338863444065A6B4FE96E84940
13384	Копыл	1	4	1280	41.010725000000001	41.061363	51.670501000000002	51.636755999999998	0103000020E61000000100000005000000F31FD26F5F81444011C4793881D14940F31FD26F5F814440B8770DFAD2D549409C1727BEDA874440B8770DFAD2D549409C1727BEDA87444011C4793881D14940F31FD26F5F81444011C4793881D14940
15226	Колодеевка	1	4	1280	40.427942999999999	40.455385999999997	51.887247000000002	51.868544	0103000020E61000000100000005000000ACC612D6C63644408A9125732CEF4940ACC612D6C6364440B03C484F91F149403387A4164A3A4440B03C484F91F149403387A4164A3A44408A9125732CEF4940ACC612D6C63644408A9125732CEF4940
49052	Дмитриевка	1	4	1280	40.800744000000002	40.824404999999999	51.756447999999999	51.713875000000002	0103000020E61000000100000005000000EF3B86C77E6644404C37894160DB4940EF3B86C77E664440F38FBE49D3E0494056D4601A86694440F38FBE49D3E0494056D4601A866944404C37894160DB4940EF3B86C77E6644404C37894160DB4940
13671	Дзержинский	1	4	1280	40.864694999999998	40.881843000000003	51.702350000000003	51.684384000000001	0103000020E61000000100000005000000E2016553AE6E4440EDF318E599D74940E2016553AE6E44403D2CD49AE6D94940709A3E3BE07044403D2CD49AE6D94940709A3E3BE0704440EDF318E599D74940E2016553AE6E4440EDF318E599D74940
49262	Грязцы	1	4	1280	40.410992	40.432758	51.867103999999998	51.857008999999998	0103000020E610000001000000050000007575C7629B34444057B08D78B2ED49407575C7629B3444408A1D8D43FDEE49408B8A389D643744408A1D8D43FDEE49408B8A389D6437444057B08D78B2ED49407575C7629B34444057B08D78B2ED4940
14325	Вязковка	1	4	1280	40.503616999999998	40.539665999999997	51.938692000000003	51.920904	0103000020E61000000100000005000000D55A988576404440B760A92EE0F54940D55A9885764044402882380F27F84940AE6186C6134544402882380F27F84940AE6186C613454440B760A92EE0F54940D55A988576404440B760A92EE0F54940
47185	Вознесеновка	1	4	1280	40.797977000000003	40.824323999999997	51.793166999999997	51.783439999999999	0103000020E61000000100000005000000E8FA3E1C246644406A300DC347E44940E8FA3E1C246644401AA20A7F86E5494069A7E672836944401AA20A7F86E5494069A7E672836944406A300DC347E44940E8FA3E1C246644406A300DC347E44940
54406	Владимировка	1	4	1280	40.732686999999999	40.751758000000002	51.784681999999997	51.771186	0103000020E61000000100000005000000289A07B0C85D444008910C39B6E24940289A07B0C85D444043E1B37570E44940D1402C9B3960444043E1B37570E44940D1402C9B3960444008910C39B6E24940289A07B0C85D444008910C39B6E24940
48998	Введенка	1	4	1280	40.824036999999997	40.858344000000002	51.729402	51.704655000000002	0103000020E61000000100000005000000D3D85E0B7A69444040FB912232DA4940D3D85E0B7A69444089D1730B5DDD4940E25B5837DE6D444089D1730B5DDD4940E25B5837DE6D444040FB912232DA4940D3D85E0B7A69444040FB912232DA4940
13491	Буравцовка	1	4	1280	40.942695000000001	40.966878000000001	51.699548	51.674219999999998	0103000020E61000000100000005000000268DD13AAA784440912749D74CD64940268DD13AAA784440B9FDF2C98AD94940679C86A8C27B4440B9FDF2C98AD94940679C86A8C27B4440912749D74CD64940268DD13AAA784440912749D74CD64940
14041	Борщевские Пески	1	4	1280	40.525463999999999	40.564253000000001	51.724615	51.680039999999998	0103000020E61000000100000005000000D89C83674243444065FCFB8C0BD74940D89C83674243444074982F2FC0DC4940BFD53A713948444074982F2FC0DC4940BFD53A713948444065FCFB8C0BD74940D89C83674243444065FCFB8C0BD74940
49243	Большой Самовец	1	4	1280	40.456249	40.490240999999997	51.92342	51.887636000000001	0103000020E6100000010000000500000096EA025E663A44404A60730E9EF1494096EA025E663A4440753C66A032F6494044149337C03E4440753C66A032F6494044149337C03E44404A60730E9EF1494096EA025E663A44404A60730E9EF14940
14615	Большая Добринка	1	4	1280	40.830207999999999	40.862026999999998	51.894162000000001	51.863337999999999	0103000020E6100000010000000500000054707841446A444070B20DDC81EE494054707841446A4440B9A981E673F249406EA296E6566E4440B9A981E673F249406EA296E6566E444070B20DDC81EE494054707841446A444070B20DDC81EE4940
14253	Битюг-Матреновка	1	4	1280	40.470486999999999	40.503292999999999	51.881360000000001	51.847023	0103000020E61000000100000005000000B91803EB383C4440DBFAE93F6BEC4940B91803EB383C444054008C67D0F0494022A7AFE76B40444054008C67D0F0494022A7AFE76B404440DBFAE93F6BEC4940B91803EB383C4440DBFAE93F6BEC4940
47160	Александровка	1	4	1280	41.003079999999997	41.042354000000003	51.702795999999999	51.669533999999999	0103000020E61000000100000005000000C6A2E9EC64804440B0C7444AB3D54940C6A2E9EC648044403BE12538F5D949406A6D1ADB6B8544403BE12538F5D949406A6D1ADB6B854440B0C7444AB3D54940C6A2E9EC64804440B0C7444AB3D54940
13032	Яблочное	1	4	986	38.983666999999997	39.033999999999999	51.311909999999997	51.289762000000003	0103000020E61000000100000005000000C493DDCCE87D4340D1CFD4EB16A54940C493DDCCE87D4340CEA5B8AAECA749403108AC1C5A844340CEA5B8AAECA749403108AC1C5A844340D1CFD4EB16A54940C493DDCCE87D4340D1CFD4EB16A54940
11827	Хохольский	1	4	986	38.761676000000001	38.808343000000001	51.598461	51.553682000000002	0103000020E61000000100000005000000F51263997E6143402331410DDFC64940F51263997E6143403A77BB5E9ACC4940AB798EC8776743403A77BB5E9ACC4940AB798EC8776743402331410DDFC64940F51263997E6143402331410DDFC64940
12028	Хохол	1	4	986	38.676946999999998	38.898471000000001	51.628236999999999	51.529953999999996	0103000020E610000001000000050000000A100533A656434033315D88D5C349400A100533A65643408E91EC116AD04940C4B30419017343408E91EC116AD04940C4B304190173434033315D88D5C349400A100533A656434033315D88D5C34940
48564	Староникольское	1	4	986	38.680081999999999	38.817129000000001	51.478186000000001	51.430627000000001	0103000020E61000000100000005000000944C4EED0C57434026E318C91EB74940944C4EED0C574340D9B3E73235BD49407DCEDDAE97684340D9B3E73235BD49407DCEDDAE9768434026E318C91EB74940944C4EED0C57434026E318C91EB74940
12629	Семидесятное	1	4	986	38.682246999999997	38.812987	51.364018999999999	51.278382000000001	0103000020E61000000100000005000000A565A4DE53574340C5E57805A2A34940A565A4DE53574340B20FB22C98AE49405D8940F50F684340B20FB22C98AE49405D8940F50F684340C5E57805A2A34940A565A4DE53574340C5E57805A2A34940
12938	Рудкино	1	4	986	39.014856999999999	39.046486999999999	51.449035000000002	51.415934	0103000020E61000000100000005000000EF8E8CD5E6814340B1A547533DB54940EF8E8CD5E681434033E197FA79B9494036583849F385434033E197FA79B9494036583849F3854340B1A547533DB54940EF8E8CD5E6814340B1A547533DB54940
54408	Петино	1	4	986	38.607120999999999	39.17597	51.677475999999999	51.230365999999997	0103000020E610000001000000050000007FDB1324B64D43401F0E12A27C9D49407FDB1324B64D434096E99788B7D64940DF89592F8696434096E99788B7D64940DF89592F869643401F0E12A27C9D49407FDB1324B64D43401F0E12A27C9D4940
48828	Оськино	1	4	986	39.008003000000002	39.054994000000001	51.262011999999999	51.230365999999997	0103000020E610000001000000050000008CA2073E068143401F0E12A27C9D49408CA2073E068143406C94F59B89A14940F5BC1B0B0A8743406C94F59B89A14940F5BC1B0B0A8743401F0E12A27C9D49408CA2073E068143401F0E12A27C9D4940
54318	Опытная станция ВНИИК	1	4	986	38.970416999999998	38.987521000000001	51.609603999999997	51.597800999999997	0103000020E61000000100000005000000C03DCF9F367C43400F4240BE84CC4940C03DCF9F367C434061C1FD8007CE49407E8E8F16677E434061C1FD8007CE49407E8E8F16677E43400F4240BE84CC4940C03DCF9F367C43400F4240BE84CC4940
12356	Никольское-на-Еманче	1	4	986	38.812466000000001	38.896495000000002	51.477052999999998	51.461753000000002	0103000020E61000000100000005000000548EC9E2FE6743403AEAE8B81ABB4940548EC9E2FE674340B6BA9C1210BD494086032159C0724340B6BA9C1210BD494086032159C07243403AEAE8B81ABB4940548EC9E2FE6743403AEAE8B81ABB4940
48610	Кочетовка	1	4	986	38.773318000000003	38.827207999999999	51.365847000000002	51.341323000000003	0103000020E610000001000000050000003EB48F15FC624340B22FD978B0AB49403EB48F15FC6243407C2B1213D4AE4940AA7EA5F3E16943407C2B1213D4AE4940AA7EA5F3E1694340B22FD978B0AB49403EB48F15FC624340B22FD978B0AB4940
12995	Костенки	1	4	986	39.006233000000002	39.082751999999999	51.417501999999999	51.349074999999999	0103000020E61000000100000005000000F793313ECC804340F46C567DAEAC4940F793313ECC804340DE019EB470B54940DCD6169E978A4340DE019EB470B54940DCD6169E978A4340F46C567DAEAC4940F793313ECC804340F46C567DAEAC4940
12309	Еманча 1-я	1	4	986	38.891258000000001	38.922258999999997	51.574207999999999	51.540531000000001	0103000020E610000001000000050000003126FDBD14724340B2BCAB1E30C549403126FDBD14724340008DD2A57FC9494088B839950C764340008DD2A57FC9494088B839950C764340B2BCAB1E30C549403126FDBD14724340B2BCAB1E30C54940
48758	Дмитриевка	1	4	986	38.919176999999998	38.943269999999998	51.513309999999997	51.491943999999997	0103000020E61000000100000005000000211E8997A775434051BB5F05F8BE4940211E8997A7754340D95A5F24B4C1494022A64412BD784340D95A5F24B4C1494022A64412BD78434051BB5F05F8BE4940211E8997A775434051BB5F05F8BE4940
48729	Гремячье	1	4	986	38.982939999999999	39.035707000000002	51.513091000000003	51.441547	0103000020E6100000010000000500000012F758FAD07D4340CE52B29C84B8494012F758FAD07D43409C6F44F7ACC14940809E060C928443409C6F44F7ACC14940809E060C92844340CE52B29C84B8494012F758FAD07D4340CE52B29C84B84940
45990	Верхненикольское	1	4	986	38.607120999999999	38.646780999999997	51.520606999999998	51.480418	0103000020E610000001000000050000007FDB1324B64D4340723447567EBD49407FDB1324B64D4340CA880B40A3C249404B5645B8C9524340CA880B40A3C249404B5645B8C9524340723447567EBD49407FDB1324B64D4340723447567EBD4940
45878	Борщево	1	4	986	39.068916999999999	39.167929999999998	51.365645000000001	51.317303000000003	0103000020E61000000100000005000000B891B245D28843401BF67B629DA84940B891B245D288434014799274CDAE49403602F1BA7E95434014799274CDAE49403602F1BA7E9543401BF67B629DA84940B891B245D28843401BF67B629DA84940
8349	Бахчеево	1	4	986	38.807211000000002	38.882911999999997	51.596916999999998	51.579323000000002	0103000020E6100000010000000500000059FCA6B0526743400A698D4127CA494059FCA6B05267434095B6B8C667CC49407B9FAA420371434095B6B8C667CC49407B9FAA42037143400A698D4127CA494059FCA6B0526743400A698D4127CA4940
48858	Архангельское	1	4	986	39.110616999999998	39.168126999999998	51.288437999999999	51.235863999999999	0103000020E61000000100000005000000D9B0A6B2288E4340E126A3CA309E4940D9B0A6B2288E43403A765089EBA449408C497F2F859543403A765089EBA449408C497F2F85954340E126A3CA309E4940D9B0A6B2288E4340E126A3CA309E4940
10639	Чубровка	1	4	1131	41.558481999999998	41.584820000000001	51.757005999999997	51.744070000000001	0103000020E61000000100000005000000CCB392567CC74440A5F78DAF3DDF4940CCB392567CC7444019709692E5E04940FB05BB61DBCA444019709692E5E04940FB05BB61DBCA4440A5F78DAF3DDF4940CCB392567CC74440A5F78DAF3DDF4940
45846	Терновка	1	4	1131	41.567338999999997	41.655464000000002	51.702556000000001	51.647683000000001	0103000020E61000000100000005000000675F79909EC844406C96CB46E7D24940675F79909EC84440E6CDE15AEDD9494049DA8D3EE6D34440E6CDE15AEDD9494049DA8D3EE6D344406C96CB46E7D24940675F79909EC844406C96CB46E7D24940
48217	Тамбовка	1	4	1131	41.087997999999999	41.110537000000001	51.696393999999998	51.681083999999998	0103000020E61000000100000005000000840EBA84438B444018EAB0C22DD74940840EBA84438B4440B890477023D94940BDFF8F13268E4440B890477023D94940BDFF8F13268E444018EAB0C22DD74940840EBA84438B444018EAB0C22DD74940
45490	Русаново	1	4	1131	41.437199999999997	41.514743000000003	51.735655000000001	51.688578	0103000020E61000000100000005000000D5E76A2BF6B744405F5FEB5223D84940D5E76A2BF6B74440C7116BF129DE4940276C3F19E3C14440C7116BF129DE4940276C3F19E3C144405F5FEB5223D84940D5E76A2BF6B744405F5FEB5223D84940
47846	Ржавец	1	4	1131	41.614868999999999	41.646552	51.526955999999998	51.513826000000002	0103000020E6100000010000000500000080290307B4CE4440D1EAE40CC5C1494080290307B4CE44402A37514B73C34940EA944737C2D244402A37514B73C34940EA944737C2D24440D1EAE40CC5C1494080290307B4CE4440D1EAE40CC5C14940
54394	Поляна	1	4	1131	41.440649000000001	41.476545999999999	51.761342999999997	51.736730999999999	0103000020E61000000100000005000000EF01BA2F67B8444085798F334DDE4940EF01BA2F67B84440EE04FBAF73E1494012859675FFBC4440EE04FBAF73E1494012859675FFBC444085798F334DDE4940EF01BA2F67B8444085798F334DDE4940
46835	Новотроицкое	1	4	1131	41.416826	41.446227999999998	51.677247999999999	51.642921000000001	0103000020E61000000100000005000000AE0FEB8D5AB54440B0743E3C4BD24940AE0FEB8D5AB5444005A4FD0FB0D649409D47C5FF1DB9444005A4FD0FB0D649409D47C5FF1DB94440B0743E3C4BD24940AE0FEB8D5AB54440B0743E3C4BD24940
11179	Новокирсановка	1	4	1131	41.614967999999998	41.646687	51.570613999999999	51.545869000000003	0103000020E61000000100000005000000130B7C45B7CE44403B730F09DFC54940130B7C45B7CE4440E3512AE109C94940CADFBDA3C6D24440E3512AE109C94940CADFBDA3C6D244403B730F09DFC54940130B7C45B7CE44403B730F09DFC54940
49564	Николаевка	1	4	1131	41.216411999999998	41.251455	51.736105999999999	51.718125999999998	0103000020E61000000100000005000000213B6F63B39B44402234828DEBDB4940213B6F63B39B4440D731AEB838DE494035B56CAD2FA04440D731AEB838DE494035B56CAD2FA044402234828DEBDB4940213B6F63B39B44402234828DEBDB4940
10479	Никитская	1	4	1131	41.776654999999998	41.790804000000001	51.696655999999997	51.682994000000001	0103000020E610000001000000050000002FA3586E69E344409FAEEE586CD749402FA3586E69E34440F54718062CD94940E3C5C21039E54440F54718062CD94940E3C5C21039E544409FAEEE586CD749402FA3586E69E344409FAEEE586CD74940
11031	Народное	1	4	1131	41.751251000000003	41.838118000000001	51.602387999999998	51.559618	0103000020E610000001000000050000002D0B26FE28E0444060200890A1C749402D0B26FE28E044405DC0CB0C1BCD49402F185C7347EB44405DC0CB0C1BCD49402F185C7347EB444060200890A1C749402D0B26FE28E0444060200890A1C74940
10822	Луначаровка	1	4	1131	41.064560999999998	41.085949999999997	51.598247999999998	51.587203000000002	0103000020E610000001000000050000006CCCEB88438844407A8EC87729CB49406CCCEB8843884440DE72F56393CC4940AC8BDB68008B4440DE72F56393CC4940AC8BDB68008B44407A8EC87729CB49406CCCEB88438844407A8EC87729CB4940
48039	Липяги	1	4	1131	41.824382999999997	41.846480999999997	51.584567	51.562266000000001	0103000020E610000001000000050000006E30D46185E944408DD31055F8C749406E30D46185E9444011A96917D3CA4940BAD7497D59EC444011A96917D3CA4940BAD7497D59EC44408DD31055F8C749406E30D46185E944408DD31055F8C74940
10949	Костино-Отделец	1	4	1131	41.433939000000002	41.476025	51.560273000000002	51.516779	0103000020E61000000100000005000000BFBA2A508BB744403A2174D025C24940BFBA2A508BB7444079EA9106B7C74940098A1F63EEBC444079EA9106B7C74940098A1F63EEBC44403A2174D025C24940BFBA2A508BB744403A2174D025C24940
47946	Козловка	1	4	1131	41.254393	41.334108999999998	51.684294999999999	51.640635000000003	0103000020E6100000010000000500000069AA27F38FA0444024D6E25300D2494069AA27F38FA044407DE882FA96D749404E266E15C4AA44407DE882FA96D749404E266E15C4AA444024D6E25300D2494069AA27F38FA0444024D6E25300D24940
47407	Кисельное	1	4	1131	41.131799999999998	41.160142	51.598399000000001	51.569997999999998	0103000020E6100000010000000500000070CE88D2DE9044408864C8B1F5C8494070CE88D2DE904440C47AA35698CC4940A75B76887F944440C47AA35698CC4940A75B76887F9444408864C8B1F5C8494070CE88D2DE9044408864C8B1F5C84940
47739	Есипово	1	4	1131	41.503478000000001	41.540236999999998	51.782559999999997	51.738169999999997	0103000020E61000000100000005000000B42094F771C04440B471C45A7CDE4940B42094F771C04440319413ED2AE44940698B6B7C26C54440319413ED2AE44940698B6B7C26C54440B471C45A7CDE4940B42094F771C04440B471C45A7CDE4940
47403	Дубровка	1	4	1131	41.129598999999999	41.166258999999997	51.627006999999999	51.608272999999997	0103000020E61000000100000005000000124C35B3969044401805C1E3DBCD4940124C35B39690444079AEEFC341D0494034D593F94795444079AEEFC341D0494034D593F9479544401805C1E3DBCD4940124C35B3969044401805C1E3DBCD4940
16029	Долина	1	4	1131	41.546723	41.584569000000002	51.637332000000001	51.618955	0103000020E610000001000000050000004A7CEE04FBC544400C59DDEA39CF49404A7CEE04FBC54440DE58501894D14940B2A03028D3CA4440DE58501894D14940B2A03028D3CA44400C59DDEA39CF49404A7CEE04FBC544400C59DDEA39CF4940
10570	Братки	1	4	1131	41.461877000000001	41.524462	51.615627000000003	51.567104	0103000020E6100000010000000500000026E318C91EBB444024B726DD96C8494026E318C91EBB44406EC493DDCCCE494054FF209221C344406EC493DDCCCE494054FF209221C3444024B726DD96C8494026E318C91EBB444024B726DD96C84940
45871	Бабино	1	4	1131	41.611939999999997	41.634452000000003	51.619889000000001	51.607270999999997	0103000020E610000001000000050000009F8EC70C54CE444094675E0EBBCD49409F8EC70C54CE44403813D38558CF4940DF701FB935D144403813D38558CF4940DF701FB935D1444094675E0EBBCD49409F8EC70C54CE444094675E0EBBCD4940
10441	Алешки	1	4	1131	41.740983	41.798206	51.643312999999999	51.601219	0103000020E610000001000000050000002CF2EB87D8DE4440EE5D83BEF4CC49402CF2EB87D8DE4440BB0B941458D2494049BC3C9D2BE64440BB0B941458D2494049BC3C9D2BE64440EE5D83BEF4CC49402CF2EB87D8DE4440EE5D83BEF4CC4940
54367	Александровка	1	4	1131	41.884067000000002	41.939529	51.642747999999997	51.614888999999998	0103000020E61000000100000005000000863C821B29F14440C7D5C8AEB4CE4940863C821B29F14440E2C8039145D2494061527C7C42F84440E2C8039145D2494061527C7C42F84440C7D5C8AEB4CE4940863C821B29F14440C7D5C8AEB4CE4940
60397	Участок N4	1	4	1006	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
54338	Участок N26	1	4	1006	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
60382	Участок N2 сельскохозяйственного НИИ имени Докучаева	1	4	1006	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
54451	Участок N12	1	4	1006	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
9542	Утиновка	1	4	1006	40.861919	40.892983000000001	51.070932999999997	51.045575999999997	0103000020E6100000010000000500000088669E5C536E4440C2BD326FD585494088669E5C536E4440849A215514894940267156444D724440849A215514894940267156444D724440C2BD326FD585494088669E5C536E4440C2BD326FD5854940
40379	Терехово	1	4	1006	40.768628999999997	40.791733000000001	50.985795000000003	50.955438999999998	0103000020E61000000100000005000000EBE0606F6262444056293DD34B7A4940EBE0606F62624440B9C7D2872E7E4940FD14C78157654440B9C7D2872E7E4940FD14C7815765444056293DD34B7A4940EBE0606F6262444056293DD34B7A4940
46932	Таловая	1	4	1006	40.698963999999997	40.768773000000003	51.132694999999998	51.101478999999998	0103000020E61000000100000005000000698A00A7775944408A1D8D43FD8C4940698A00A777594440DEAB5626FC9049401F86562767624440DEAB5626FC9049401F865627676244408A1D8D43FD8C4940698A00A7775944408A1D8D43FD8C4940
10050	Синявка	1	4	1006	40.958578000000003	41.016230999999998	51.274788000000001	51.243747999999997	0103000020E61000000100000005000000225514AFB27A4440923B6C22339F4940225514AFB27A4440A8AAD0402CA3494037177FDB13824440A8AAD0402CA3494037177FDB13824440923B6C22339F4940225514AFB27A4440923B6C22339F4940
46021	Орловка	1	4	1006	40.509106000000003	40.567002000000002	51.055416999999998	50.988765999999998	0103000020E610000001000000050000004419AA622A414440C8B260E28F7E49404419AA622A4144403B527DE71787494020628385934844403B527DE7178749402062838593484440C8B260E28F7E49404419AA622A414440C8B260E28F7E4940
9326	Новотроицкий	1	4	1006	40.702953000000001	40.734456999999999	51.191020999999999	51.169673000000003	0103000020E6100000010000000500000003D0285DFA594440D20149D8B795494003D0285DFA594440B3EC496073984940BDA8DDAF025E4440B3EC496073984940BDA8DDAF025E4440D20149D8B795494003D0285DFA594440D20149D8B7954940
54490	Новенький	1	4	1006	40.744267000000001	40.759655000000002	51.151789000000001	51.142415	0103000020E61000000100000005000000FB3E1C24445F4440DCBA9BA73A924940FB3E1C24445F44403F726BD26D934940179F02603C6144403F726BD26D934940179F02603C614440DCBA9BA73A924940FB3E1C24445F4440DCBA9BA73A924940
9021	Новая Чигла	1	4	1006	40.425319999999999	40.530351000000003	51.250991999999997	51.191144999999999	0103000020E61000000100000005000000D82AC1E2703644409FE5797077984940D82AC1E27036444060C77F8120A049405133A48AE243444060C77F8120A049405133A48AE24344409FE5797077984940D82AC1E2703644409FE5797077984940
47182	Никольское	1	4	1006	40.427224000000002	40.465214000000003	51.120117	51.100535000000001	0103000020E610000001000000050000007D08AA46AF3644403B8DB454DE8C49407D08AA46AF364440C9586DFE5F8F494018D2E1218C3B4440C9586DFE5F8F494018D2E1218C3B44403B8DB454DE8C49407D08AA46AF3644403B8DB454DE8C4940
47448	Нижняя Каменка	1	4	1006	40.814388999999998	40.852702000000001	51.130721999999999	51.120168	0103000020E610000001000000050000006F9C14E63D6844404B033FAA618F49406F9C14E63D684440116F9D7FBB904940ED9DD156256D4440116F9D7FBB904940ED9DD156256D44404B033FAA618F49406F9C14E63D6844404B033FAA618F4940
47391	Михинский	1	4	1006	40.690286999999998	40.724611000000003	51.007019	50.989209000000002	0103000020E610000001000000050000004EED0C535B58444056F487669E7E49404EED0C535B584440AEB9A3FFE580494033A9A10DC05C4440AEB9A3FFE580494033A9A10DC05C444056F487669E7E49404EED0C535B58444056F487669E7E4940
46251	Михайловский	1	4	1006	40.556877999999998	40.560848	51.115752000000001	51.110945999999998	0103000020E6100000010000000500000052EE3EC7474744409ECF807A338E494052EE3EC7474744402A3927F6D08E4940750305DEC94744402A3927F6D08E4940750305DEC94744409ECF807A338E494052EE3EC7474744409ECF807A338E4940
47059	Коминтерн	1	4	1006	40.62621	40.653896000000003	51.121813000000003	51.117007999999998	0103000020E61000000100000005000000CE3637A62750444068AF3E1EFA8E4940CE3637A627504440249D8191978F49401C7E37DDB2534440249D8191978F49401C7E37DDB253444068AF3E1EFA8E4940CE3637A62750444068AF3E1EFA8E4940
47695	Козловский	1	4	1006	40.953043999999998	40.997546	51.136260999999998	51.125013000000003	0103000020E6100000010000000500000013D38558FD79444095490D6D0090494013D38558FD794440315C1D0071914940B8205B96AF7F4440315C1D0071914940B8205B96AF7F444095490D6D0090494013D38558FD79444095490D6D00904940
9780	Казанка	1	4	1006	40.788670000000003	40.800114999999998	51.258456000000002	51.240290999999999	0103000020E610000001000000050000000DAB7823F3644440F64201DBC19E49400DAB7823F36444403DBA111615A14940FF04172B6A6644403DBA111615A14940FF04172B6A664440F64201DBC19E49400DAB7823F3644440F64201DBC19E4940
54387	Еланка	1	4	1006	41.055712	41.071863999999998	51.309747999999999	51.287131000000002	0103000020E6100000010000000500000054FF2092218744407A5567B5C0A4494054FF2092218744402E008DD2A5A749403FE1ECD6328944402E008DD2A5A749403FE1ECD6328944407A5567B5C0A4494054FF2092218744407A5567B5C0A44940
47656	Вязовка	1	4	1006	41.015251999999997	41.040863000000002	51.324711000000001	51.309899999999999	0103000020E610000001000000050000006B990CC7F3814440E4839ECDAAA749406B990CC7F381444063D34A2190A94940E84EB0FF3A85444063D34A2190A94940E84EB0FF3A854440E4839ECDAAA749406B990CC7F3814440E4839ECDAAA74940
54302	Высокий	1	4	1006	40.706726000000003	40.736342999999998	51.080863999999998	51.061802999999998	0103000020E61000000100000005000000D09D60FF755A4440B8E52329E9874940D09D60FF755A44403DB665C0598A4940BBD1C77C405E44403DB665C0598A4940BBD1C77C405E4440B8E52329E9874940D09D60FF755A4440B8E52329E9874940
8728	Вознесенский	1	4	1006	40.652863000000004	40.685093999999999	51.078454000000001	51.061016000000002	0103000020E610000001000000050000005DE2C8039153444031444E5FCF8749405DE2C80391534440C51EDAC70A8A4940C9570229B1574440C51EDAC70A8A4940C9570229B157444031444E5FCF8749405DE2C8039153444031444E5FCF874940
9098	Верхняя Тишанка	1	4	1006	40.467460000000003	40.621952	51.341040999999997	51.307068000000001	0103000020E610000001000000050000001618B2BAD53B4440F6D214014EA749401618B2BAD53B44402DCC423BA7AB494045D7851F9C4F44402DCC423BA7AB494045D7851F9C4F4440F6D214014EA749401618B2BAD53B4440F6D214014EA74940
9434	Верхнеозерский	1	4	1006	40.686667	40.759053000000002	51.046720000000001	51.032273000000004	0103000020E61000000100000005000000081F4AB4E45744409CC58B8521844940081F4AB4E4574440D908C4EBFA854940217711A628614440D908C4EBFA854940217711A6286144409CC58B8521844940081F4AB4E45744409CC58B8521844940
47309	Бирюч	1	4	1006	40.697707000000001	40.731527999999997	51.355713000000002	51.334986999999998	0103000020E610000001000000050000005B9885764E594440E6CAA0DAE0AA49405B9885764E5944408BE1EA0088AD4940DC0DA2B5A25D44408BE1EA0088AD4940DC0DA2B5A25D4440E6CAA0DAE0AA49405B9885764E594440E6CAA0DAE0AA4940
46904	Березовка	1	4	1006	40.773111	40.789057	51.103560999999999	51.090952000000001	0103000020E61000000100000005000000C4961E4DF5624440BEC0AC50A48B4940C4961E4DF56244400E12A27C418D494006D7DCD1FF6444400E12A27C418D494006D7DCD1FF644440BEC0AC50A48B4940C4961E4DF5624440BEC0AC50A48B4940
10176	Анохинка	1	4	1006	40.958514999999998	40.990628999999998	51.044471999999999	51.022506	0103000020E61000000100000005000000DBDC989EB07A44405DFB027AE1824940DBDC989EB07A44403ACB2C42B18549400EBC5AEECC7E44403ACB2C42B18549400EBC5AEECC7E44405DFB027AE1824940DBDC989EB07A44405DFB027AE1824940
47352	Александровка	1	4	1006	40.657929000000003	40.703735000000002	51.230122999999999	51.204087000000001	0103000020E61000000100000005000000850B790437544440F644D7851F9A4940850B7904375444405987A3AB749D494079060DFD135A44405987A3AB749D494079060DFD135A4440F644D7851F9A4940850B790437544440F644D7851F9A4940
47623	Абрамовка	1	4	1006	40.992829999999998	41.109171000000003	51.232661	51.173490000000001	0103000020E610000001000000050000006C3EAE0D157F44406E179AEB349649406C3EAE0D157F4440FF06EDD5C79D4940F855B950F98D4440FF06EDD5C79D4940F855B950F98D44406E179AEB349649406C3EAE0D157F44406E179AEB34964940
48696	Устье	1	4	867	38.627412999999997	38.643386	51.797533999999999	51.789585000000002	0103000020E61000000100000005000000E90AB6114F504340C2340C1F11E54940E90AB6114F5043405AB9179815E64940255AF2785A5243405AB9179815E64940255AF2785A524340C2340C1F11E54940E90AB6114F504340C2340C1F11E54940
46179	Терновое	1	4	867	39.012818000000003	39.036731000000003	51.752786	51.738554999999998	0103000020E610000001000000050000006B662D05A48143400DA661F888DE49406B662D05A48143407E71A94A5BE04940ECDFF599B38443407E71A94A5BE04940ECDFF599B38443400DA661F888DE49406B662D05A48143400DA661F888DE4940
46387	Стрелица	1	4	867	38.873542999999998	38.927396999999999	51.631278000000002	51.592171999999998	0103000020E610000001000000050000002A53CC41D06F4340AFCDC64ACCCB49402A53CC41D06F43409757AEB7CDD049404AB4E4F1B47643409757AEB7CDD049404AB4E4F1B4764340AFCDC64ACCCB49402A53CC41D06F4340AFCDC64ACCCB4940
8079	Старая Ольшанка	1	4	867	38.523432999999997	38.627189000000001	51.874665999999998	51.807034999999999	0103000020E61000000100000005000000D65240DAFF4243401ADD41EC4CE74940D65240DAFF4243402976340EF5EF49409AB4A9BA475043402976340EF5EF49409AB4A9BA475043401ADD41EC4CE74940D65240DAFF4243401ADD41EC4CE74940
7990	Старая Ведуга	1	4	867	38.451712000000001	38.630647000000003	51.843217000000003	51.782404	0103000020E61000000100000005000000FA9AE5B2D13943403A2174D025E44940FA9AE5B2D13943403337DF88EEEB49400729780AB95043403337DF88EEEB49400729780AB95043403A2174D025E44940FA9AE5B2D13943403A2174D025E44940
46728	Стадница	1	4	867	38.740322999999997	38.762044000000003	51.848008	51.792805000000001	0103000020E6100000010000000500000001BD70E7C25E43407A8D5DA27AE5494001BD70E7C25E4340895FB1868BEC4940780E65A88A614340895FB1868BEC4940780E65A88A6143407A8D5DA27AE5494001BD70E7C25E43407A8D5DA27AE54940
46305	Серебрянка	1	4	867	38.725149999999999	38.759196000000003	51.894945999999997	51.820113999999997	0103000020E61000000100000005000000E25817B7D15C4340F17EDC7EF9E84940E25817B7D15C4340CFD72C978DF2494084A0A3552D614340CFD72C978DF2494084A0A3552D614340F17EDC7EF9E84940E25817B7D15C4340F17EDC7EF9E84940
54425	Раздолье	1	4	867	38.982894999999999	39.028447999999997	51.808638999999999	51.788314999999997	0103000020E610000001000000050000007233DC80CF7D43401EF98381E7E449407233DC80CF7D434094A2957B81E749407CD11E2FA483434094A2957B81E749407CD11E2FA48343401EF98381E7E449407233DC80CF7D43401EF98381E7E44940
46634	Перлевка	1	4	867	38.824368999999997	38.926462999999998	51.874065999999999	51.816817999999998	0103000020E61000000100000005000000096B63EC846943405E64027E8DE84940096B63EC84694340D4450A65E1EF49401EFAEE5696764340D4450A65E1EF49401EFAEE56967643405E64027E8DE84940096B63EC846943405E64027E8DE84940
7363	Перекоповка	1	4	867	38.685623999999997	38.705728999999998	52.085476	52.064956000000002	0103000020E6100000010000000500000025ADF886C2574340E9D66B7A50084A4025ADF886C2574340E44BA8E0F00A4A405D6BEF53555A4340E44BA8E0F00A4A405D6BEF53555A4340E9D66B7A50084A4025ADF886C2574340E9D66B7A50084A40
6828	Орлов Лог	1	4	867	38.984763000000001	38.998094000000002	51.654533999999998	51.643228999999998	0103000020E61000000100000005000000CAA7C7B60C7E43405D6BEF5355D24940CAA7C7B60C7E43405E0F26C5C7D34940BB2A508BC17F43405E0F26C5C7D34940BB2A508BC17F43405D6BEF5355D24940CAA7C7B60C7E43405D6BEF5355D24940
7604	Новосильское	1	4	867	38.483297	38.541445000000003	51.954307999999997	51.901052999999997	0103000020E61000000100000005000000A1A014ADDC3D4340397B67B455F34940A1A014ADDC3D4340D427B9C326FA494097CADB114E454340D427B9C326FA494097CADB114E454340397B67B455F34940A1A014ADDC3D4340397B67B455F34940
47285	Никольское	1	4	867	38.591839999999998	38.634456	51.829883000000002	51.816367	0103000020E61000000100000005000000793BC269C14B43404E44BFB67EE84940793BC269C14B4340D1402C9B39EA49402060ADDA35514340D1402C9B39EA49402060ADDA355143404E44BFB67EE84940793BC269C14B43404E44BFB67EE84940
7534	Нижняя Ведуга	1	4	867	38.639127999999999	38.681483	51.775348999999999	51.687651000000002	0103000020E610000001000000050000009CFA40F2CE514340E607AEF204D849409CFA40F2CE5143403FFED2A23EE34940D6E3BED53A5743403FFED2A23EE34940D6E3BED53A574340E607AEF204D849409CFA40F2CE514340E607AEF204D84940
46535	Меловатка	1	4	867	38.648496999999999	38.678742999999997	51.879426000000002	51.798169000000001	0103000020E61000000100000005000000ED461FF3015343402CD7DB662AE64940ED461FF30153434045A0FA0791F04940C8B1F50CE156434045A0FA0791F04940C8B1F50CE15643402CD7DB662AE64940ED461FF3015343402CD7DB662AE64940
46533	Медвежье	1	4	867	38.969248999999998	38.991033999999999	51.861474999999999	51.841698000000001	0103000020E610000001000000050000002157EA59107C4340E78D93C2BCEB49402157EA59107C43402AA913D044EE4940AE9CBD33DA7E43402AA913D044EE4940AE9CBD33DA7E4340E78D93C2BCEB49402157EA59107C4340E78D93C2BCEB4940
7296	Малая Покровка	1	4	867	38.633144999999999	38.660857999999998	52.017122000000001	52.000951000000001	0103000020E610000001000000050000001E5036E50A51434002F390291F004A401E5036E50A5143406405BF0D31024A4065A6B4FE965443406405BF0D31024A4065A6B4FE9654434002F390291F004A401E5036E50A51434002F390291F004A40
45426	Лосево	1	4	867	38.820399000000002	38.85069	51.744148000000003	51.725909999999999	0103000020E61000000100000005000000E7559DD50269434070EB6E9EEADC4940E7559DD50269434021B1DD3D40DF49406284F068E36C434021B1DD3D40DF49406284F068E36C434070EB6E9EEADC4940E7559DD50269434070EB6E9EEADC4940
7051	Латное	1	4	867	38.876354999999997	38.969859999999997	51.714286999999999	51.682313000000001	0103000020E61000000100000005000000D15790662C7043405D514A0856D74940D15790662C7043409E7AA4C16DDB49406AD95A5F247C43409E7AA4C16DDB49406AD95A5F247C43405D514A0856D74940D15790662C7043405D514A0856D74940
8196	Латная	1	4	867	38.858811000000003	38.923623999999997	51.676918000000001	51.644396999999998	0103000020E61000000100000005000000F838D384ED6D4340FC51D4997BD24940F838D384ED6D43407009C03FA5D649407DE6AC4F397643407009C03FA5D649407DE6AC4F39764340FC51D4997BD24940F838D384ED6D4340FC51D4997BD24940
54444	Кондрашевка	1	4	867	38.712285999999999	38.781232000000003	51.806038000000001	51.757033999999997	0103000020E6100000010000000500000007B309302C5B4340E3FA777DE6E0494007B309302C5B4340A8AAD0402CE749405A4B0169FF634340A8AAD0402CE749405A4B0169FF634340E3FA777DE6E0494007B309302C5B4340E3FA777DE6E04940
46345	Казинка	1	4	867	38.602781999999998	38.622787000000002	51.9343	51.903143	0103000020E61000000100000005000000094FE8F5274D4340404E98309AF34940094FE8F5274D43408F53742497F74940DEAF027CB74F43408F53742497F74940DEAF027CB74F4340404E98309AF34940094FE8F5274D4340404E98309AF34940
49091	Ивановка	1	4	867	38.573973000000002	38.623533000000002	52.053471999999999	52.03481	0103000020E61000000100000005000000BDE47FF27749434071C971A774044A40BDE47FF27749434038A0A52BD8064A40077DE9EDCF4F434038A0A52BD8064A40077DE9EDCF4F434071C971A774044A40BDE47FF27749434071C971A774044A40
6846	Землянск	1	4	867	38.699745999999998	38.762915	51.920965000000002	51.885784999999998	0103000020E61000000100000005000000DFC0E44691594340C824236761F14940DFC0E446915943405DE15D2EE2F549405D50DF32A76143405DE15D2EE2F549405D50DF32A7614340C824236761F14940DFC0E44691594340C824236761F14940
7784	Ендовище	1	4	867	38.968567	39.030982000000002	51.741739000000003	51.686227000000002	0103000020E610000001000000050000000F7EE200FA7B4340EC504D49D6D749400F7EE200FA7B43407995B54DF1DE4940E161DA37F78343407995B54DF1DE4940E161DA37F7834340EC504D49D6D749400F7EE200FA7B4340EC504D49D6D74940
45956	Дмитриевка	1	4	867	38.719140000000003	38.727530999999999	52.015746999999998	52.006407000000003	0103000020E610000001000000050000006B9F8EC70C5C434095BBCFF1D1004A406B9F8EC70C5C43404B0169FF03024A40C0E95DBC1F5D43404B0169FF03024A40C0E95DBC1F5D434095BBCFF1D1004A406B9F8EC70C5C434095BBCFF1D1004A40
46198	Девица	1	4	867	38.901957000000003	38.988976000000001	51.669137999999997	51.593744000000001	0103000020E61000000100000005000000FBB2B453737343401E19ABCDFFCB4940FBB2B4537373434063416150A6D54940B343FCC3967E434063416150A6D54940B343FCC3967E43401E19ABCDFFCB4940FBB2B453737343401E19ABCDFFCB4940
48844	Губарево	1	4	867	39.022106000000001	39.056009000000003	51.778140999999998	51.756414999999997	0103000020E61000000100000005000000CF85915ED4824340179AEB34D2E04940CF85915ED48243409F56D11F9AE349400EA48B4D2B8743409F56D11F9AE349400EA48B4D2B874340179AEB34D2E04940CF85915ED4824340179AEB34D2E04940
46407	Гремячий Колодезь	1	4	867	38.750393000000003	38.806204999999999	51.760986000000003	51.733199999999997	0103000020E61000000100000005000000DC12B9E00C604340AEB6627FD9DD4940DC12B9E00C604340605B3FFD67E14940936FB6B931674340605B3FFD67E14940936FB6B931674340AEB6627FD9DD4940DC12B9E00C604340AEB6627FD9DD4940
6535	Голосновка	1	4	867	38.550714999999997	38.582165000000003	52.035713000000001	51.994900999999999	0103000020E61000000100000005000000543541D47D464340FCE07CEA58FF4940543541D47D46434062855B3E92044A401CF0F961844A434062855B3E92044A401CF0F961844A4340FCE07CEA58FF4940543541D47D464340FCE07CEA58FF4940
49210	Гнилуша	1	4	867	38.48283	38.634267999999999	51.757848000000003	51.723165000000002	0103000020E610000001000000050000008BC3995FCD3D4340514EB4AB90DC49408BC3995FCD3D434065ABCB2901E149401D739EB12F51434065ABCB2901E149401D739EB12F514340514EB4AB90DC49408BC3995FCD3D4340514EB4AB90DC4940
54397	Березовка	1	4	867	38.305439	38.359023999999998	51.980575000000002	51.956173	0103000020E6100000010000000500000023F609A018274340BB287AE063FA494023F609A0182743403A234A7B83FD4940533D997FF42D43403A234A7B83FD4940533D997FF42D4340BB287AE063FA494023F609A018274340BB287AE063FA4940
54404	п. Опытной Плодово-ягодной станции	1	4	538	39.179445999999999	40.214494000000002	50.381196000000003	49.854396999999999	0103000020E61000000100000005000000F2B22616F8964340776682E15CED4840F2B22616F8964340DAAED007CB3049401898158A741B4440DAAED007CB3049401898158A741B4440776682E15CED4840F2B22616F8964340776682E15CED4840
5730	Шрамовка	1	4	538	39.546444000000001	39.57987	49.931337999999997	49.911009	0103000020E61000000100000005000000378C82E0F1C543404BAE62F19BF44840378C82E0F1C54340D2C2651536F748403CF71E2E39CA4340D2C2651536F748403CF71E2E39CA43404BAE62F19BF44840378C82E0F1C543404BAE62F19BF44840
5689	Шекаловка	1	4	538	39.298211999999999	39.321550999999999	50.052370000000003	50.039667000000001	0103000020E610000001000000050000002BA391CF2BA643407FDDE9CE130549402BA391CF2BA6434051A5660FB4064940807F4A9528A9434051A5660FB4064940807F4A9528A943407FDDE9CE130549402BA391CF2BA643407FDDE9CE13054940
54423	Чернышовка	1	4	538	39.511733	39.557043999999998	50.151133999999999	50.130108	0103000020E6100000010000000500000059A4897780C1434057790261A710494059A4897780C1434026A8E15B581349406D37C1374DC7434026A8E15B581349406D37C1374DC7434057790261A710494059A4897780C1434057790261A7104940
54459	Чагары	1	4	538	39.446505999999999	39.468704000000002	50.063214000000002	50.049363	0103000020E61000000100000005000000E0BBCD1B27B94340F450DB8651064940E0BBCD1B27B943401E5377651708494090C01F7EFEBB43401E5377651708494090C01F7EFEBB4340F450DB8651064940E0BBCD1B27B94340F450DB8651064940
4915	Цапково	1	4	538	40.144443000000003	40.173782000000003	50.035941000000001	50.018324999999997	0103000020E610000001000000050000006D91B41B7D1244407FD93D79580249406D91B41B7D124440F3CAF5B6990449401651137D3E164440F3CAF5B6990449401651137D3E1644407FD93D79580249406D91B41B7D1244407FD93D7958024940
54390	Украинский	1	4	538	39.709074999999999	39.727274999999999	50.228985999999999	50.217286999999999	0103000020E61000000100000005000000A2B437F8C2DA4340486C770FD01B4940A2B437F8C2DA4340F59ECA694F1D49406519E25817DD4340F59ECA694F1D49406519E25817DD4340486C770FD01B4940A2B437F8C2DA4340486C770FD01B4940
5577	Терновка	1	4	538	39.819153999999997	39.859147	50.138219999999997	50.124535000000002	0103000020E610000001000000050000009C31CC09DAE843408B1A4CC3F00F49409C31CC09DAE8434099D36531B11149406FBA6587F8ED434099D36531B11149406FBA6587F8ED43408B1A4CC3F00F49409C31CC09DAE843408B1A4CC3F00F4940
4889	Стеценково	1	4	538	40.111960000000003	40.136502	49.969743999999999	49.950868999999997	0103000020E61000000100000005000000E73A8DB4540E4440DEE34C13B6F94840E73A8DB4540E444001BF469220FC484057EBC4E57811444001BF469220FC484057EBC4E578114440DEE34C13B6F94840E73A8DB4540E4440DEE34C13B6F94840
5472	Старая Калитва	1	4	538	39.945025999999999	40.017107000000003	50.158591000000001	50.125661000000001	0103000020E6100000010000000500000052EFA99CF6F84340FBB0DEA81510494052EFA99CF6F843405038BBB54C1449402FC4EA8F300244405038BBB54C1449402FC4EA8F30024440FBB0DEA81510494052EFA99CF6F84340FBB0DEA815104940
54436	Совхоз Россошанский	1	4	538	39.453809999999997	39.475073000000002	50.203457	50.192489999999999	0103000020E61000000100000005000000834C327216BA43404D672783A3184940834C327216BA4340369204E10A1A4940371B2B31CFBC4340369204E10A1A4940371B2B31CFBC43404D672783A3184940834C327216BA43404D672783A3184940
47939	Сагуны	1	4	538	39.383569999999999	39.409244000000001	50.039394999999999	50.029344999999999	0103000020E6100000010000000500000005DD5ED218B143408BA6B393C103494005DD5ED218B143401E5036E50A054940C80A7E1B62B443401E5036E50A054940C80A7E1B62B443408BA6B393C103494005DD5ED218B143408BA6B393C1034940
5369	Поповка	1	4	538	39.587029999999999	39.635395000000003	50.335802000000001	50.28378	0103000020E61000000100000005000000ACE28DCC23CB434023A12DE752244940ACE28DCC23CB434038F7578FFB2A49405E85949F54D1434038F7578FFB2A49405E85949F54D1434023A12DE752244940ACE28DCC23CB434023A12DE752244940
3997	Поддубное	1	4	538	39.348948999999998	39.394665000000003	49.910800000000002	49.877884999999999	0103000020E61000000100000005000000677C5F5CAAAC4340115322895EF04840677C5F5CAAAC434031992A1895F448401CF0F96184B2434031992A1895F448401CF0F96184B24340115322895EF04840677C5F5CAAAC4340115322895EF04840
5279	Подгорное	1	4	538	39.479537000000001	39.562415999999999	50.195010000000003	50.157603999999999	0103000020E61000000100000005000000691CEA7761BD434001DC2C5E2C144940691CEA7761BD43404D327216F6184940A25F5B3FFDC743404D327216F6184940A25F5B3FFDC7434001DC2C5E2C144940691CEA7761BD434001DC2C5E2C144940
4204	Первомайское	1	4	538	39.936231999999997	39.972119999999997	49.976388999999998	49.956938000000001	0103000020E61000000100000005000000FDBB3E73D6F743405B26C3F17CFA4840FDBB3E73D6F743404A969350FAFC4840CDE49B6D6EFC43404A969350FAFC4840CDE49B6D6EFC43405B26C3F17CFA4840FDBB3E73D6F743405B26C3F17CFA4840
54393	Новопостояловка	1	4	538	39.455497999999999	39.472746000000001	50.338664999999999	50.3277	0103000020E610000001000000050000005BB22AC24DBA43401973D712F22949405BB22AC24DBA434061A6ED5F592B49404CA8E0F082BC434061A6ED5F592B49404CA8E0F082BC43401973D712F22949405BB22AC24DBA43401973D712F2294940
4645	Новая Калитва	1	4	538	39.988694000000002	40.032001000000001	50.088709000000001	50.067441000000002	0103000020E610000001000000050000002FE065868DFE43406CB41CE8A10849402FE065868DFE434031EE06D15A0B49403B38D89B1804444031EE06D15A0B49403B38D89B180444406CB41CE8A10849402FE065868DFE43406CB41CE8A1084940
3691	Нижний Карабут	1	4	538	39.947155000000002	39.983573	50.271720000000002	50.260041999999999	0103000020E61000000100000005000000179F02603CF9434010CB660E49214940179F02603CF94340A6D590B8C7224940431D56B8E5FD4340A6D590B8C7224940431D56B8E5FD434010CB660E49214940179F02603CF9434010CB660E49214940
5008	Начало	1	4	538	39.557727	39.595033999999998	50.243355999999999	50.219090999999999	0103000020E61000000100000005000000508C2C9963C7434089EC832C0B1C4940508C2C9963C7434087A4164A261F49400801F9122ACC434087A4164A261F49400801F9122ACC434089EC832C0B1C4940508C2C9963C7434089EC832C0B1C4940
4475	Морозовка	1	4	538	39.62086	39.653315999999997	50.155214000000001	50.121572	0103000020E6100000010000000500000081B2295778CF4340FE0DDAAB8F0F494081B2295778CF4340D0F0660DDE1349400DFAD2DB9FD34340D0F0660DDE1349400DFAD2DB9FD34340FE0DDAAB8F0F494081B2295778CF4340FE0DDAAB8F0F4940
54455	Молодежный	1	4	538	39.622171999999999	39.634227000000003	50.218676000000002	50.210951999999999	0103000020E61000000100000005000000533E0455A3CF43404D83A279001B4940533E0455A3CF4340C6353E93FD1B4940BF9EAF592ED14340C6353E93FD1B4940BF9EAF592ED143404D83A279001B4940533E0455A3CF43404D83A279001B4940
54422	Лощина	1	4	538	39.863675000000001	39.914717000000003	50.141891999999999	50.125447000000001	0103000020E61000000100000005000000B8AF03E78CEE4340CF30B5A50E104940B8AF03E78CEE434032C85D8429124940310C587215F5434032C85D8429124940310C587215F54340CF30B5A50E104940B8AF03E78CEE4340CF30B5A50E104940
4277	Лизиновка	1	4	538	39.414974999999998	39.507258999999998	50.134062999999998	50.109521999999998	0103000020E610000001000000050000002CD49AE61DB54340A41820D1040E49402CD49AE61DB54340444DF4F92811494003CDE7DCEDC04340444DF4F92811494003CDE7DCEDC04340A41820D1040E49402CD49AE61DB54340A41820D1040E4940
4623	Лебедь-Сергеевка	1	4	538	39.729835000000001	39.803784	50.074356000000002	50.051462000000001	0103000020E61000000100000005000000F33CB83B6BDD43404E7E8B4E96064940F33CB83B6BDD43407521567F840949402786E464E2E643407521567F840949402786E464E2E643404E7E8B4E96064940F33CB83B6BDD43404E7E8B4E96064940
4199	Криничное	1	4	538	39.828280999999997	39.859938	50.035570999999997	49.995381000000002	0103000020E61000000100000005000000F7729F1C05EA4340A70705A568FF4840F7729F1C05EA4340CFD72C978D044940384BC97212EE4340CFD72C978D044940384BC97212EE4340A70705A568FF4840F7729F1C05EA4340A70705A568FF4840
4109	Кривоносово	1	4	538	39.230417000000003	39.288483999999997	49.940086999999998	49.903483999999999	0103000020E61000000100000005000000A2B8E34D7E9D4340C93A1C5DA5F34840A2B8E34D7E9D4340873254C554F84840AAB5300BEDA44340873254C554F84840AAB5300BEDA44340C93A1C5DA5F34840A2B8E34D7E9D4340C93A1C5DA5F34840
4058	Копенкина	1	4	538	39.543551000000001	39.563665	50.061582999999999	50.046841000000001	0103000020E61000000100000005000000A35A441493C54340548EC9E2FE054940A35A441493C54340AA7EA5F3E10749402E73BA2C26C84340AA7EA5F3E10749402E73BA2C26C84340548EC9E2FE054940A35A441493C54340548EC9E2FE054940
54400	Копанки	1	4	538	39.505355000000002	39.517949000000002	50.289408999999999	50.275922000000001	0103000020E610000001000000050000005FEFFE78AFC043409B1F7F69512349405FEFFE78AFC043408315A75A0B2549407AFF1F274CC243408315A75A0B2549407AFF1F274CC243409B1F7F69512349405FEFFE78AFC043409B1F7F6951234940
54450	Комаровка	1	4	538	39.746156999999997	39.766432000000002	50.311245	50.295883000000003	0103000020E610000001000000050000003A57941282DF4340A038807EDF2549403A57941282DF434092054CE0D6274940CF4D9B711AE2434092054CE0D6274940CF4D9B711AE24340A038807EDF2549403A57941282DF4340A038807EDF254940
54424	Кокаревка	1	4	538	39.580212000000003	39.596974000000003	50.268881	50.252744999999997	0103000020E61000000100000005000000965F066344CA43401F9DBAF259204940965F066344CA434005C24EB16A224940FA47DFA469CC434005C24EB16A224940FA47DFA469CC43401F9DBAF259204940965F066344CA43401F9DBAF259204940
4845	Ивановка	1	4	538	40.012652000000003	40.047272999999997	50.015998000000003	49.994947000000003	0103000020E61000000100000005000000501DAB949E0144406D205D6C5AFF4840501DAB949E0144409566F3380C024940ED7DAA0A0D0644409566F3380C024940ED7DAA0A0D0644406D205D6C5AFF4840501DAB949E0144406D205D6C5AFF4840
3964	Жилино	1	4	538	39.402183000000001	39.435295000000004	49.922336999999999	49.883121000000003	0103000020E61000000100000005000000EB0088BB7AB3434096B4E21B0AF14840EB0088BB7AB34340047289230FF64840618E1EBFB7B74340047289230FF64840618E1EBFB7B7434096B4E21B0AF14840EB0088BB7AB3434096B4E21B0AF14840
5793	Еленовка	1	4	538	39.439957999999997	39.498491999999999	49.971446999999998	49.940503999999997	0103000020E6100000010000000500000089CE328B50B84340EBE0606F62F8484089CE328B50B843400E66136058FC4840A8A8FA95CEBF43400E66136058FC4840A8A8FA95CEBF4340EBE0606F62F8484089CE328B50B84340EBE0606F62F84840
4466	Екатериновка	1	4	538	39.292284000000002	39.393172999999997	50.124834999999997	50.099048000000003	0103000020E610000001000000050000007192E68F69A54340FB5DD89AAD0C49407192E68F69A54340B532E197FA0F4940C9552C7E53B24340B532E197FA0F4940C9552C7E53B24340FB5DD89AAD0C49407192E68F69A54340FB5DD89AAD0C4940
3884	Евстратовка	1	4	538	39.698878999999998	39.759632000000003	50.142059000000003	50.120862000000002	0103000020E610000001000000050000003B6EF8DD74D9434022AAF067780F49403B6EF8DD74D943401E8D43FD2E1249405F7F129F3BE143401E8D43FD2E1249405F7F129F3BE1434022AAF067780F49403B6EF8DD74D9434022AAF067780F4940
54449	Голубая Криница	1	4	538	39.885226000000003	39.907198000000001	50.081553	50.065088000000003	0103000020E61000000100000005000000D2C8E7154FF1434058AEB7CD54084940D2C8E7154FF1434002F22554700A4940917F66101FF4434002F22554700A4940917F66101FF4434058AEB7CD54084940D2C8E7154FF1434058AEB7CD54084940
3271	Ворошиловский	1	4	538	39.603864000000002	39.620753000000001	50.049328000000003	50.034407999999999	0103000020E61000000100000005000000AA9D616A4BCD4340425C397B67044940AA9D616A4BCD434078634161500649406BF294D574CF434078634161500649406BF294D574CF4340425C397B67044940AA9D616A4BCD4340425C397B67044940
3788	Архиповка	1	4	538	39.398544999999999	39.445922000000003	50.226813999999997	50.201110999999997	0103000020E61000000100000005000000FE7DC68503B34340D4EE5701BE194940FE7DC68503B343403123BC3D081D49409148DBF813B943403123BC3D081D49409148DBF813B94340D4EE5701BE194940FE7DC68503B34340D4EE5701BE194940
54326	Анцеловича	1	4	538	39.576923999999998	39.611364999999999	50.151277999999998	50.137435000000004	0103000020E61000000100000005000000852348A5D8C94340B329577897114940852348A5D8C94340594DD7135D134940A375543541CE4340594DD7135D134940A375543541CE4340B329577897114940852348A5D8C94340B329577897114940
3778	Александровка	1	4	538	39.344591999999999	39.430444000000001	50.007002	49.963689000000002	0103000020E610000001000000050000004B3B35971BAC4340EA4141295AFB48404B3B35971BAC4340D8800871E50049403561FBC918B74340D8800871E50049403561FBC918B74340EA4141295AFB48404B3B35971BAC4340EA4141295AFB4840
3595	Алейниково	1	4	538	39.793894000000002	39.810971000000002	50.251863999999998	50.231862	0103000020E61000000100000005000000CD3E8F519EE54340B3976DA7AD1D4940CD3E8F519EE5434016855D143D2049409180D1E5CDE7434016855D143D2049409180D1E5CDE74340B3976DA7AD1D4940CD3E8F519EE54340B3976DA7AD1D4940
1847	Фабрицкое	1	4	332	38.768368000000002	38.799737	51.106931000000003	51.088960999999998	0103000020E610000001000000050000007FA5F3E1596243404ACFF412638B49407FA5F3E159624340DCF63DEAAF8D4940593332C85D664340DCF63DEAAF8D4940593332C85D6643404ACFF412638B49407FA5F3E1596243404ACFF412638B4940
1750	Усть-Муравлянка	1	4	332	38.836334999999998	38.863912999999997	51.060398999999997	51.038440999999999	0103000020E6100000010000000500000005C078060D6B4340ABE97AA2EB84494005C078060D6B434005DB8827BB8749406CCB80B3946E434005DB8827BB8749406CCB80B3946E4340ABE97AA2EB84494005C078060D6B4340ABE97AA2EB844940
1737	Россошки	1	4	332	38.880586000000001	38.931474999999999	51.244954	51.221921999999999	0103000020E6100000010000000500000061A8C30AB7704340A721AAF0679C494061A8C30AB77043401F8315A75A9F49405305A3923A7743401F8315A75A9F49405305A3923A774340A721AAF0679C494061A8C30AB7704340A721AAF0679C4940
48699	Репьевка	1	4	332	38.598182000000001	38.706564	51.089934	51.06109	0103000020E6100000010000000500000027874F3A914C43406B0E10CCD187494027874F3A914C4340346612F5828B4940F6436CB0705A4340346612F5828B4940F6436CB0705A43406B0E10CCD187494027874F3A914C43406B0E10CCD1874940
48939	Платава	1	4	332	38.884143000000002	38.937376999999998	51.194577000000002	51.166108999999999	0103000020E6100000010000000500000061FE0A992B7143401F49490F4395494061FE0A992B714340E3C62DE6E7984940E48233F8FB774340E3C62DE6E7984940E48233F8FB7743401F49490F4395494061FE0A992B7143401F49490F43954940
48772	Одинцовка	1	4	332	38.422355000000003	38.456608000000003	51.105195000000002	51.087308999999998	0103000020E61000000100000005000000AB2688BA0F364340BFD2F9F02C8B4940AB2688BA0F364340F3599E07778D4940C68B8521723A4340F3599E07778D4940C68B8521723A4340BFD2F9F02C8B4940AB2688BA0F364340BFD2F9F02C8B4940
45442	Новосолдатка	1	4	332	38.782668999999999	38.824809000000002	51.258257999999998	51.232593000000001	0103000020E61000000100000005000000E84B6F7F2E644340A723809BC59D4940E84B6F7F2E64434016F71F990EA14940263960579369434016F71F990EA149402639605793694340A723809BC59D4940E84B6F7F2E644340A723809BC59D4940
1559	Краснолипье	1	4	332	38.750087000000001	38.795524	51.227697999999997	51.186228	0103000020E61000000100000005000000CF13CFD902604340BCCCB051D6974940CF13CFD902604340ABAE4335259D49407097FDBAD3654340ABAE4335259D49407097FDBAD3654340BCCCB051D6974940CF13CFD902604340BCCCB051D6974940
47276	Колбино	1	4	332	38.896872000000002	38.928044	51.047767999999998	51.032522	0103000020E610000001000000050000005C59A2B3CC72434044334FAE298449405C59A2B3CC724340CDE506431D864940E09F5225CA764340CDE506431D864940E09F5225CA76434044334FAE298449405C59A2B3CC72434044334FAE29844940
47157	Истобное	1	4	332	38.631483000000003	38.686549999999997	51.289541999999997	51.234465999999998	0103000020E61000000100000005000000707D586FD450434010035DFB029E4940707D586FD4504340C26856B60FA54940CE88D2DEE0574340C26856B60FA54940CE88D2DEE057434010035DFB029E4940707D586FD450434010035DFB029E4940
47808	Заречье	1	4	332	38.811442	38.819814999999998	51.055790999999999	51.046810999999998	0103000020E61000000100000005000000E84CDA54DD674340E90B21E7FD854940E84CDA54DD674340A034D4282487494097E2AAB2EF684340A034D4282487494097E2AAB2EF684340E90B21E7FD854940E84CDA54DD674340E90B21E7FD854940
48746	Бутырки	1	4	332	38.578617000000001	38.636674999999997	51.074537999999997	51.054177000000003	0103000020E610000001000000050000006FF4311F104A434003999D45EF8649406FF4311F104A4340952710768A8949402497FF907E514340952710768A8949402497FF907E51434003999D45EF8649406FF4311F104A434003999D45EF864940
54295	Ямное	1	4	17	38.707633000000001	40.088352999999998	52.092751999999997	50.452804	0103000020E610000001000000050000000249D8B7935A4340BEBF417BF53949400249D8B7935A4340BD512B4CDF0B4A4072C0AE264F0B4440BD512B4CDF0B4A4072C0AE264F0B4440BEBF417BF53949400249D8B7935A4340BEBF417BF5394940
858	Чистая Поляна	1	4	17	38.807436000000003	38.858854999999998	51.905121000000001	51.870162000000001	0103000020E6100000010000000500000079CE16105A674340691CEA7761EF494079CE16105A6743401FF64201DBF34940C780ECF5EE6D43401FF64201DBF34940C780ECF5EE6D4340691CEA7761EF494079CE16105A674340691CEA7761EF4940
54298	Чертовицы	1	4	17	38.707633000000001	40.088352999999998	52.092751999999997	50.452804	0103000020E610000001000000050000000249D8B7935A4340BEBF417BF53949400249D8B7935A4340BD512B4CDF0B4A4072C0AE264F0B4440BD512B4CDF0B4A4072C0AE264F0B4440BEBF417BF53949400249D8B7935A4340BEBF417BF5394940
54378	Ступино	1	4	17	39.367939999999997	39.419853000000003	51.982339000000003	51.942439	0103000020E61000000100000005000000F3716DA818AF4340CBBC55D7A1F84940F3716DA818AF4340ED4ACB48BDFD494052103CBEBDB54340ED4ACB48BDFD494052103CBEBDB54340CBBC55D7A1F84940F3716DA818AF4340CBBC55D7A1F84940
48568	Сомово	1	4	17	38.788049999999998	38.813400999999999	51.949218000000002	51.933250000000001	0103000020E6100000010000000500000070CE88D2DE644340FA7E6ABC74F7494070CE88D2DE6443402463B5F97FF9494050C422861D6843402463B5F97FF9494050C422861D684340FA7E6ABC74F7494070CE88D2DE644340FA7E6ABC74F74940
46600	Солнце Дубрава	1	4	17	39.198832000000003	39.218046999999999	51.971494	51.960318000000001	0103000020E61000000100000005000000FBB2B453739943404CE141B3EBFA4940FBB2B453739943404F2157EA59FC4940D6FECEF6E89B43404F2157EA59FC4940D6FECEF6E89B43404CE141B3EBFA4940FBB2B453739943404CE141B3EBFA4940
687	Скляево	1	4	17	39.016339000000002	39.049765000000001	51.961955000000003	51.946958000000002	0103000020E610000001000000050000001E53776517824340C15774EB35F949401E53776517824340A29C685721FB494023BE13B35E864340A29C685721FB494023BE13B35E864340C15774EB35F949401E53776517824340C15774EB35F94940
609	Русская Гвоздевка	1	4	17	39.056080999999999	39.094141999999998	51.839399999999998	51.792487000000001	0103000020E61000000100000005000000A77686A92D874340A9C0C93670E54940A77686A92D87434096218E7571EB49400B9755D80C8C434096218E7571EB49400B9755D80C8C4340A9C0C93670E54940A77686A92D874340A9C0C93670E54940
1023	Рамонь	1	4	17	39.307681000000002	39.381531000000003	51.927129999999998	51.883088999999998	0103000020E61000000100000005000000E04C4C1762A743408A3A730F09F14940E04C4C1762A74340FB912232ACF6494081B4FF01D6B04340FB912232ACF6494081B4FF01D6B043408A3A730F09F14940E04C4C1762A743408A3A730F09F14940
490	Новоживотинное	1	4	17	39.159638000000001	39.196190999999999	51.893166999999998	51.874138000000002	0103000020E6100000010000000500000074999A046F9443406E1805C1E3EF494074999A046F944340E76ED74B53F24940806264C91C994340E76ED74B53F24940806264C91C9943406E1805C1E3EF494074999A046F9443406E1805C1E3EF4940
7268	Малая Верейка	1	4	17	38.865592999999997	38.886567999999997	52.005446999999997	52.000430000000001	0103000020E61000000100000005000000C1525DC0CB6E4340F9F719170E004A40C1525DC0CB6E43403F6EBF7CB2004A400ED76A0F7B7143403F6EBF7CB2004A400ED76A0F7B714340F9F719170E004A40C1525DC0CB6E4340F9F719170E004A40
48289	Лопатки	1	4	17	39.321883	39.349578000000001	51.999569999999999	51.972436999999999	0103000020E61000000100000005000000B6114F7633A94340CE35CCD078FC4940B6114F7633A943400708E6E8F1FF494057B3CEF8BEAC43400708E6E8F1FF494057B3CEF8BEAC4340CE35CCD078FC4940B6114F7633A94340CE35CCD078FC4940
48485	Ломово	1	4	17	38.798983	38.876606000000002	52.072696000000001	52.044227999999997	0103000020E61000000100000005000000AD872F1345664340A3C85A43A9054A40AD872F134566434067463F1A4E094A401BBD1AA03470434067463F1A4E094A401BBD1AA034704340A3C85A43A9054A40AD872F1345664340A3C85A43A9054A40
48021	Кулешовка	1	4	17	39.173499	39.186039999999998	51.930228999999997	51.919438	0103000020E61000000100000005000000C1711937359643408E59F624B0F54940C17119373596434038656EBE11F74940B9DFA128D097434038656EBE11F74940B9DFA128D09743408E59F624B0F54940C1711937359643408E59F624B0F54940
32485	Кривоборье	1	4	17	39.143414999999997	39.168190000000003	52.046177	52.035735000000003	0103000020E61000000100000005000000BF60376C5B9243404A29E8F692044A40BF60376C5B924340E869C020E9054A40D3C1FA3F87954340E869C020E9054A40D3C1FA3F879543404A29E8F692044A40BF60376C5B9243404A29E8F692044A40
54386	Комсомольский	1	4	17	39.215307000000003	39.234206999999998	51.991663000000003	51.976742000000002	0103000020E61000000100000005000000C9CC052E8F9B43409850C1E105FD4940C9CC052E8F9B43409ED32CD0EEFE494044BFB67EFA9D43409ED32CD0EEFE494044BFB67EFA9D43409850C1E105FD4940C9CC052E8F9B43409850C1E105FD4940
45960	Князево	1	4	17	39.181952000000003	39.196289999999998	52.072701000000002	52.058233999999999	0103000020E610000001000000050000008DB800344A974340F4C1323674074A408DB800344A97434079B130444E094A401344DD072099434079B130444E094A401344DD0720994340F4C1323674074A408DB800344A974340F4C1323674074A40
21	Карачун	1	4	17	39.339939000000001	39.367319999999999	52.022891000000001	52.001488999999999	0103000020E6100000010000000500000046D1031F83AB4340E126A3CA30004A4046D1031F83AB4340B62FA017EE024A4057957D5704AF4340B62FA017EE024A4057957D5704AF4340E126A3CA30004A4046D1031F83AB4340E126A3CA30004A40
46498	Каверье	1	4	17	38.943790999999997	38.980362	51.968164999999999	51.952858999999997	0103000020E610000001000000050000002BA1BB24CE7843408159A148F7F949402BA1BB24CE784340E010AAD4ECFB4940DE1E84807C7D4340E010AAD4ECFB4940DE1E84807C7D43408159A148F7F949402BA1BB24CE7843408159A148F7F94940
47378	Гремячье	1	4	17	38.778663000000002	38.818027000000001	51.98554	51.968093000000003	0103000020E6100000010000000500000079CDAB3AAB634340473EAF78EAFB494079CDAB3AAB6343402E73BA2C26FE49405C1FD61BB56843402E73BA2C26FE49405C1FD61BB5684340473EAF78EAFB494079CDAB3AAB634340473EAF78EAFB4940
32434	Горожанка	1	4	17	39.107824000000001	39.125672999999999	52.009017999999998	51.985179000000002	0103000020E61000000100000005000000A9DC442DCD8D43405EDA70581AFE4940A9DC442DCD8D4340A489778027014A40BF7E880D16904340A489778027014A40BF7E880D169043405EDA70581AFE4940A9DC442DCD8D43405EDA70581AFE4940
176	Глушицы	1	4	17	39.330829999999999	39.360843000000003	52.054147	52.035961999999998	0103000020E6100000010000000500000091442FA358AA43400AF31E679A044A4091442FA358AA43409816F549EE064A40CAFE791A30AE43409816F549EE064A40CAFE791A30AE43400AF31E679A044A4091442FA358AA43400AF31E679A044A40
32114	Вниисс	1	4	17	39.291933	39.304402000000003	51.921669999999999	51.909993	0103000020E61000000100000005000000C4CF7F0F5EA54340624B8FA67AF44940C4CF7F0F5EA5434027DA5548F9F54940236B0DA5F6A6434027DA5548F9F54940236B0DA5F6A64340624B8FA67AF44940C4CF7F0F5EA54340624B8FA67AF44940
48192	Бор	1	4	17	39.452480000000001	39.485332	51.904715000000003	51.887642	0103000020E610000001000000050000000B0C59DDEAB943402C47C8409EF149400B0C59DDEAB94340AF997CB3CDF34940E4D9E55B1FBE4340AF997CB3CDF34940E4D9E55B1FBE43402C47C8409EF149400B0C59DDEAB943402C47C8409EF14940
32352	Большая Верейка	1	4	17	38.873148	38.956052999999997	52.045358	52.004022999999997	0103000020E61000000100000005000000AE484C50C36F434045B75ED383004A40AE484C50C36F4340554E7B4ACE054A40101FD8F15F7A4340554E7B4ACE054A40101FD8F15F7A434045B75ED383004A40AE484C50C36F434045B75ED383004A40
48356	Богданово	1	4	17	39.192363999999998	39.212693000000002	51.944693000000001	51.932428000000002	0103000020E61000000100000005000000C07630629F984340F6EFFACC59F74940C07630629F9843404CE141B3EBF84940488B3386399B43404CE141B3EBF84940488B3386399B4340F6EFFACC59F74940C07630629F984340F6EFFACC59F74940
47673	Березово	1	4	17	39.329338999999997	39.37068	51.945653999999998	51.922275999999997	0103000020E610000001000000050000000F26C5C727AA43405EF1D4230DF649400F26C5C727AA434071AAB5300BF9494001A4367172AF434071AAB5300BF9494001A4367172AF43405EF1D4230DF649400F26C5C727AA43405EF1D4230DF64940
40341	Архангельское	1	4	17	38.888337999999997	38.951957	52.014344999999999	51.983643000000001	0103000020E61000000100000005000000A3E5400FB57143403CF88903E8FD4940A3E5400FB571434039EE940ED6014A4061191BBAD979434039EE940ED6014A4061191BBAD97943403CF88903E8FD4940A3E5400FB57143403CF88903E8FD4940
48228	Айдарово	1	4	17	39.271918999999997	39.303314999999998	51.911420999999997	51.894162000000001	0103000020E610000001000000050000009C14E63DCEA24340B9A981E673F249409C14E63DCEA243409DF17D71A9F4494070B1A206D3A643409DF17D71A9F4494070B1A206D3A64340B9A981E673F249409C14E63DCEA24340B9A981E673F24940
54369	Солнечный	1	4	4439	39.165792000000003	39.166142000000001	51.697153	51.694501000000002	0103000020E610000001000000050000001FF818AC389543400805A568E5D849401FF818AC3895434076A73B4F3CD94940FB3E1C244495434076A73B4F3CD94940FB3E1C24449543400805A568E5D849401FF818AC389543400805A568E5D84940
48080	Юдино	1	4	1436	39.697001999999998	39.728136999999997	50.699502000000003	50.687451000000003	0103000020E61000000100000005000000909F8D5C37D943401F4DF564FE574940909F8D5C37D9434049BE124889594940F700DD9733DD434049BE124889594940F700DD9733DD43401F4DF564FE574940909F8D5C37D943401F4DF564FE574940
54314	Терновое	1	4	1436	39.313276999999999	39.326841999999999	50.528036999999998	50.518690999999997	0103000020E6100000010000000500000064CBF27519A8434061DD78776442494064CBF27519A84340FA0967B796434940C87A6AF5D5A94340FA0967B796434940C87A6AF5D5A9434061DD78776442494064CBF27519A8434061DD787764424940
54343	Суд-Николаевка	1	4	1436	39.604556000000002	39.630957000000002	50.363076	50.334836000000003	0103000020E61000000100000005000000E04C4C1762CD434001C3F2E7DB2A4940E04C4C1762CD434033FB3C46792E49405517F032C3D0434033FB3C46792E49405517F032C3D0434001C3F2E7DB2A4940E04C4C1762CD434001C3F2E7DB2A4940
47901	Совхоз Пробуждение	1	4	1436	39.587550999999998	39.631765999999999	50.547176	50.522911999999998	0103000020E61000000100000005000000B5DD04DF34CB4340CD57C9C7EE424940B5DD04DF34CB4340FB93F8DC09464940C45C52B5DDD04340FB93F8DC09464940C45C52B5DDD04340CD57C9C7EE424940B5DD04DF34CB4340CD57C9C7EE424940
31033	Совхоз Опыт	1	4	1436	39.546156000000003	39.571651000000003	50.440809999999999	50.430402000000001	0103000020E61000000100000005000000D1419770E8C543400611A96917374940D1419770E8C54340F8DF4A766C384940E4DC26DC2BC94340F8DF4A766C384940E4DC26DC2BC943400611A96917374940D1419770E8C543400611A96917374940
46477	Сергеевка	1	4	1436	39.776062000000003	39.840831000000001	50.432594000000002	50.411726999999999	0103000020E610000001000000050000008DD5E6FF55E34340AAF06778B33449408DD5E6FF55E3434011397D3D5F374940433BA759A0EB434011397D3D5F374940433BA759A0EB4340AAF06778B33449408DD5E6FF55E34340AAF06778B3344940
47973	Семейка	1	4	1436	39.931173999999999	39.984794999999998	50.339637000000003	50.323144999999997	0103000020E610000001000000050000005871AAB530F74340D66EBBD05C2949405871AAB530F743407BC1A739792B4940D52137C30DFE43407BC1A739792B4940D52137C30DFE4340D66EBBD05C2949405871AAB530F74340D66EBBD05C294940
30961	Саприно	1	4	1436	39.871310999999999	39.901268999999999	50.39011	50.370182999999997	0103000020E6100000010000000500000091D26C1E87EF434080441328622F494091D26C1E87EF4340D9EBDD1FEF31494006F357C85CF34340D9EBDD1FEF31494006F357C85CF3434080441328622F494091D26C1E87EF434080441328622F4940
16435	Подгоренский	1	4	1436	39.624696	39.659227000000001	50.432468	50.393422999999999	0103000020E6100000010000000500000094F8DC09F6CF4340423F53AF5B32494094F8DC09F6CF43408448861C5B374940F2D1E28C61D443408448861C5B374940F2D1E28C61D44340423F53AF5B32494094F8DC09F6CF4340423F53AF5B324940
54458	Перевальная	1	4	1436	39.494081000000001	39.527453999999999	50.556739	50.531061000000001	0103000020E610000001000000050000009949D40B3EBF43402D978DCEF94349409949D40B3EBF434031B43A39434749407B12D89C83C3434031B43A39434749407B12D89C83C343402D978DCEF94349409949D40B3EBF43402D978DCEF9434940
47839	Лыково	1	4	1436	39.759892999999998	39.791485999999999	50.553562999999997	50.536682999999996	0103000020E61000000100000005000000CBBA7F2C44E14340DAA84E07B2444940CBBA7F2C44E1434048A30227DB464940F59ECA694FE5434048A30227DB464940F59ECA694FE54340DAA84E07B2444940CBBA7F2C44E14340DAA84E07B2444940
54414	Красюковский	1	4	1436	39.648034000000003	39.654519999999998	50.516131000000001	50.501064999999997	0103000020E61000000100000005000000195932C7F2D24340CA15DEE522404940195932C7F2D24340D4B9A29410424940F949B54FC7D34340D4B9A29410424940F949B54FC7D34340CA15DEE522404940195932C7F2D24340CA15DEE522404940
30815	Красный Восход	1	4	1436	39.609909999999999	39.625720000000001	50.612805000000002	50.592464	0103000020E610000001000000050000006EC0E78711CE4340570740DCD54B49406EC0E78711CE4340A3E9EC64704E4940003ACC9717D04340A3E9EC64704E4940003ACC9717D04340570740DCD54B49406EC0E78711CE4340570740DCD54B4940
48104	Костомарово	1	4	1436	39.751241999999998	39.773439000000003	50.723492	50.674717000000001	0103000020E61000000100000005000000D9B0A6B228E0434012876C205D564940D9B0A6B228E043407575C7629B5C4940B939950C00E343407575C7629B5C4940B939950C00E3434012876C205D564940D9B0A6B228E0434012876C205D564940
31150	Колодежное	1	4	1436	39.815786000000003	39.879108000000002	50.642718000000002	50.623880999999997	0103000020E610000001000000050000007044F7AC6BE8434042CC2555DB4F49407044F7AC6BE8434078465B954452494074D3669C86F0434078465B954452494074D3669C86F0434042CC2555DB4F49407044F7AC6BE8434042CC2555DB4F4940
47770	Гончаровка	1	4	1436	39.418173000000003	39.50761	50.559967	50.472614999999998	0103000020E61000000100000005000000FD885FB186B54340AD4CF8A57E3C4940FD885FB186B543406CEBA7FFAC474940B08F4E5DF9C043406CEBA7FFAC474940B08F4E5DF9C04340AD4CF8A57E3C4940FD885FB186B54340AD4CF8A57E3C4940
54447	Витебск	1	4	1436	39.921616	39.945340999999999	50.437815000000001	50.415934	0103000020E6100000010000000500000034BC5983F7F54340B1A547533D35494034BC5983F7F54340605969520A384940B24813EF00F94340605969520A384940B24813EF00F94340B1A547533D35494034BC5983F7F54340B1A547533D354940
30710	Верхний Карабут	1	4	1436	39.904476000000003	39.927833	50.563800999999998	50.543066000000003	0103000020E610000001000000050000002A029CDEC5F34340E7C8CA2F834549402A029CDEC5F34340DE3994A12A4849402593533BC3F64340DE3994A12A4849402593533BC3F64340E7C8CA2F834549402A029CDEC5F34340E7C8CA2F83454940
54399	Большой Скорорыб	1	4	1436	39.479753000000002	39.506756000000003	50.414544999999997	50.399268999999997	0103000020E610000001000000050000003694DA8B68BD43403FA7203F1B3349403694DA8B68BD434033DC80CF0F354940A1866F61DDC0434033DC80CF0F354940A1866F61DDC043403FA7203F1B3349403694DA8B68BD43403FA7203F1B334940
54398	Большая Хвощеватка	1	4	1436	39.710988	39.736707000000003	50.654729000000003	50.635297000000001	0103000020E610000001000000050000009AEC9FA701DB43409B1F7F69515149409AEC9FA701DB4340145FED28CE534940FDDD3B6A4CDE4340145FED28CE534940FDDD3B6A4CDE43409B1F7F69515149409AEC9FA701DB43409B1F7F6951514940
45525	Березово	1	4	1436	39.526304000000003	39.562164000000003	50.616629000000003	50.593435999999997	0103000020E6100000010000000500000083E0F1ED5DC343407022FAB5F54B494083E0F1ED5DC34340F261F6B2ED4E4940897E6DFDF4C74340F261F6B2ED4E4940897E6DFDF4C743407022FAB5F54B494083E0F1ED5DC343407022FAB5F54B4940
47625	Белогорье	1	4	1436	39.960666000000003	40.020377000000003	50.509784000000003	50.467972000000003	0103000020E6100000010000000500000088307E1AF7FA4340CCB8A981E63B494088307E1AF7FA43401503249A40414940994BAAB69B0244401503249A40414940994BAAB69B024440CCB8A981E63B494088307E1AF7FA4340CCB8A981E63B4940
45369	Андреевка	1	4	1436	39.790075999999999	39.815722999999998	50.513044000000001	50.497059999999998	0103000020E6100000010000000500000060ADDA3521E543402B137EA99F3F494060ADDA3521E543405BB4006DAB41494029CC7B9C69E843405BB4006DAB41494029CC7B9C69E843402B137EA99F3F494060ADDA3521E543402B137EA99F3F4940
29590	Самодуровка	1	4	1294	42.346690000000002	42.380467000000003	51.210706000000002	51.187899000000002	0103000020E61000000100000005000000D5EC8156602C4540BEF90D130D984940D5EC8156602C45401689096AF89A4940871A8524B33045401689096AF89A4940871A8524B3304540BEF90D130D984940D5EC8156602C4540BEF90D130D984940
47203	Рождественское	1	4	1294	42.124115000000003	42.220934999999997	51.252288999999998	51.224246000000001	0103000020E61000000100000005000000B6F81400E30F45402121CA17B49C4940B6F81400E30F4540FD1186014BA0494058C51B99471C4540FD1186014BA0494058C51B99471C45402121CA17B49C4940B6F81400E30F45402121CA17B49C4940
29206	Поворино	1	4	1294	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
45522	Пески	1	4	1294	42.415537	42.516579999999998	51.282162999999997	51.215293000000003	0103000020E6100000010000000500000094A3005130354540640795B88E9B494094A30051303545401492CCEA1DA4494043E21E4B1F4245401492CCEA1DA4494043E21E4B1F424540640795B88E9B494094A3005130354540640795B88E9B4940
47167	Октябрьское	1	4	1294	41.926457999999997	41.968473000000003	51.260067999999997	51.206648999999999	0103000020E610000001000000050000000C8FFD2C96F6444024607479739A49400C8FFD2C96F64440395E81E849A149408E075BECF6FB4440395E81E849A149408E075BECF6FB444024607479739A49400C8FFD2C96F6444024607479739A4940
47441	Октябрьский	1	4	1294	42.811729999999997	42.839865000000003	51.380859000000001	51.370446999999999	0103000020E610000001000000050000004E97C5C4E66745405EF3AACE6AAF49404E97C5C4E667454092B1DAFCBFB049400C0742B2806B454092B1DAFCBFB049400C0742B2806B45405EF3AACE6AAF49404E97C5C4E66745405EF3AACE6AAF4940
29826	Мазурка	1	4	1294	42.519733000000002	42.592514000000001	51.295997	51.264367999999997	0103000020E6100000010000000500000074D3669C86424540F10D85CFD6A1494074D3669C86424540685BCD3AE3A549400936AE7FD74B4540685BCD3AE3A549400936AE7FD74B4540F10D85CFD6A1494074D3669C86424540F10D85CFD6A14940
29057	Кардаиловка	1	4	1294	42.667479	42.686649000000003	51.252051999999999	51.237493999999998	0103000020E6100000010000000500000026E2ADF36F554540847F1134669E494026E2ADF36F55454019726C3D43A04940626A4B1DE457454019726C3D43A04940626A4B1DE4574540847F1134669E494026E2ADF36F554540847F1134669E4940
47336	Ильмень	1	4	1294	42.546394999999997	42.578221999999997	51.314504999999997	51.295642000000001	0103000020E6100000010000000500000055D97745F04545407AA9D898D7A5494055D97745F0454540D8B628B341A84940F2E9B12D034A4540D8B628B341A84940F2E9B12D034A45407AA9D898D7A5494055D97745F04545407AA9D898D7A54940
47451	Вихляевка	1	4	1294	42.837142999999998	42.870353999999999	51.273277999999998	51.255789999999998	0103000020E61000000100000005000000A4897780276B454069520ABABDA04940A4897780276B4540AF5B04C6FAA24940ADF886C2676F4540AF5B04C6FAA24940ADF886C2676F454069520ABABDA04940A4897780276B454069520ABABDA04940
29959	Байчурово	1	4	1294	42.668331999999999	42.699674000000002	51.352933999999998	51.329675000000002	0103000020E61000000100000005000000656F29E78B55454087A757CA32AA4940656F29E78B554540BFD2F9F02CAD494046EEE9EA8E594540BFD2F9F02CAD494046EEE9EA8E59454087A757CA32AA4940656F29E78B55454087A757CA32AA4940
46878	Фоменково	1	4	1845	41.026938999999999	41.073552999999997	50.104098	50.075391000000003	0103000020E6100000010000000500000054FEB5BC72834440D5B48B69A609494054FEB5BC728344401DCA5015530D4940E7C2482F6A8944401DCA5015530D4940E7C2482F6A894440D5B48B69A609494054FEB5BC72834440D5B48B69A6094940
54377	Старомеловая	1	4	1845	40.837952000000001	40.88841	50.306314999999998	50.254375000000003	0103000020E6100000010000000500000014CFD902426B4440C3F5285C8F20494014CFD902426B44401AA37554352749403DB83B6BB77144401AA37554352749403DB83B6BB7714440C3F5285C8F20494014CFD902426B4440C3F5285C8F204940
29088	Старая Криуша	1	4	1845	41.091726000000001	41.201563	50.226202999999998	50.163473000000003	0103000020E61000000100000005000000B11875ADBD8B4440B763EAAEEC144940B11875ADBD8B4440E8A04B38F41C4940B58AFED0CC994440E8A04B38F41C4940B58AFED0CC994440B763EAAEEC144940B11875ADBD8B4440B763EAAEEC144940
54283	Петропавловка	1	4	1845	40.859555999999998	40.91827	50.123772000000002	50.069065999999999	0103000020E61000000100000005000000508A56EE056E4440FDA19927D7084940508A56EE056E44408C14CAC2D70F4940EF7211DF897544408C14CAC2D70F4940EF7211DF89754440FDA19927D7084940508A56EE056E4440FDA19927D7084940
46662	Пески	1	4	1845	40.853026	40.912018000000003	50.286180000000002	50.249664000000003	0103000020E61000000100000005000000A051BAF42F6D4440897E6DFDF41F4940A051BAF42F6D44407862D68BA124494082AE7D01BD7444407862D68BA124494082AE7D01BD744440897E6DFDF41F4940A051BAF42F6D4440897E6DFDF41F4940
54448	Огарев	1	4	1845	41.306244	41.343415999999998	50.115045000000002	50.096372000000002	0103000020E61000000100000005000000514CDE0033A744400420EEEA550C4940514CDE0033A74440BF4868CBB90E49402976340EF5AB4440BF4868CBB90E49402976340EF5AB44400420EEEA550C4940514CDE0033A744400420EEEA550C4940
54336	Новый Лиман	1	4	1845	40.898147999999999	40.930838000000001	49.966307999999998	49.934666	0103000020E61000000100000005000000E17B7F83F67244407157AF22A3F74840E17B7F83F67244407CEE04FBAFFB4840E1EF17B3257744407CEE04FBAFFB4840E1EF17B3257744407157AF22A3F74840E17B7F83F67244407157AF22A3F74840
54362	Новотроицкое	1	4	1845	41.059745999999997	41.126176000000001	50.151468999999999	50.116911000000002	0103000020E610000001000000050000008D08C6C1A587444076C58CF0F60E49408D08C6C1A5874440CDAD10566313494022C5008926904440CDAD10566313494022C500892690444076C58CF0F60E49408D08C6C1A587444076C58CF0F60E4940
28720	Новобогородицкое	1	4	1845	40.950609999999998	41.008856000000002	50.050508000000001	50.022660000000002	0103000020E6100000010000000500000012A0A696AD794440B476DB85E602494012A0A696AD794440DB17D00B77064940CB2F833122814440DB17D00B77064940CB2F833122814440B476DB85E602494012A0A696AD794440B476DB85E6024940
46917	Краснофлотское	1	4	1845	41.162135999999997	41.284216999999998	50.095384000000003	50.040165000000002	0103000020E610000001000000050000008BC058DFC0944440D0B87020240549408BC058DFC0944440E547FC8A350C4940CEFBFF3861A44440E547FC8A350C4940CEFBFF3861A44440D0B87020240549408BC058DFC0944440D0B8702024054940
28393	Красноселовка	1	4	1845	40.823371999999999	40.872016000000002	50.206114999999997	50.151192000000002	0103000020E610000001000000050000009738F240646944405BB56B425A1349409738F24064694440861BF0F9611A49405CCB64389E6F4440861BF0F9611A49405CCB64389E6F44405BB56B425A1349409738F240646944405BB56B425A134940
54420	Индычий	1	4	1845	40.819023999999999	40.848416999999998	50.251201999999999	50.224912000000003	0103000020E61000000100000005000000CE5147C7D56844402E3D9AEAC91C4940CE5147C7D56844404B581B63272049406A2FA2ED986C44404B581B63272049406A2FA2ED986C44402E3D9AEAC91C4940CE5147C7D56844402E3D9AEAC91C4940
46756	Замостье	1	4	1845	40.806933000000001	40.842928000000001	50.033326000000002	50.004356000000001	0103000020E6100000010000000500000016889E94496744404CC5C6BC8E00494016889E9449674440A20DC00644044940FC709010E56B4440A20DC00644044940FC709010E56B44404CC5C6BC8E00494016889E94496744404CC5C6BC8E004940
46801	Глубокое	1	4	1845	40.928896999999999	40.962494	49.915306999999999	49.866883000000001	0103000020E610000001000000050000001F2DCE18E6764440AC3AAB05F6EE48401F2DCE18E676444062669FC728F54840514CDE00337B444062669FC728F54840514CDE00337B4440AC3AAB05F6EE48401F2DCE18E6764440AC3AAB05F6EE4840
28567	Бычок	1	4	1845	40.748632000000001	40.790063000000004	50.047314999999998	50.009278000000002	0103000020E610000001000000050000009A5E622CD35F444041498105300149409A5E622CD35F44401CCEFC6A0E064940CC63CDC8206544401CCEFC6A0E064940CC63CDC82065444041498105300149409A5E622CD35F44404149810530014940
27179	Щербачевка	1	4	1484	40.289746000000001	40.323639	51.757424	51.747756000000003	0103000020E61000000100000005000000CB129D6516254440A3B1F677B6DF4940CB129D65162544404E9A0645F3E04940E65AB4006D2944404E9A0645F3E04940E65AB4006D294440A3B1F677B6DF4940CB129D6516254440A3B1F677B6DF4940
46595	Чернавка	1	4	1484	40.360039	40.407173999999998	51.701439999999998	51.685250000000003	0103000020E610000001000000050000006C2409C2152E4440C1CAA145B6D749406C2409C2152E4440990D32C9C8D9494008E412471E344440990D32C9C8D9494008E412471E344440C1CAA145B6D749406C2409C2152E4440C1CAA145B6D74940
17078	Тойда	1	4	1484	40.162526999999997	40.198467999999998	51.590218999999998	51.575831000000001	0103000020E61000000100000005000000C6DB4AAFCD144440F18288D4B4C94940C6DB4AAFCD144440293DD34B8CCB4940B9A6406667194440293DD34B8CCB4940B9A6406667194440F18288D4B4C94940C6DB4AAFCD144440F18288D4B4C94940
46972	Софьинка	1	4	1484	40.120350999999999	40.144936999999999	51.623013999999998	51.610247000000001	0103000020E610000001000000050000003C855CA9670F4440B6BDDD921CCE49403C855CA9670F44409E7939ECBECF49407C7DAD4B8D1244409E7939ECBECF49407C7DAD4B8D124440B6BDDD921CCE49403C855CA9670F4440B6BDDD921CCE4940
49096	Сергеевка	1	4	1484	40.175651000000002	40.220647999999997	51.567259999999997	51.548580000000001	0103000020E610000001000000050000003E4162BB7B164440AE9E93DE37C649403E4162BB7B1644401B2AC6F99BC84940C2F693313E1C44401B2AC6F99BC84940C2F693313E1C4440AE9E93DE37C649403E4162BB7B164440AE9E93DE37C64940
26554	Перелешинский	1	4	1484	40.170476999999998	40.215527000000002	51.731973000000004	51.704766999999997	0103000020E610000001000000050000002FDCB930D2154440672618CE35DA49402FDCB930D21544400B47904AB1DD4940D7338463961B44400B47904AB1DD4940D7338463961B4440672618CE35DA49402FDCB930D2154440672618CE35DA4940
27028	Перелешино	1	4	1484	40.113838000000001	40.154027999999997	51.749217000000002	51.728900000000003	0103000020E6100000010000000500000062855B3E920E4440F7065F984CDD494062855B3E920E4440BA4DB857E6DF49408A558330B7134440BA4DB857E6DF49408A558330B7134440F7065F984CDD494062855B3E920E4440F7065F984CDD4940
26296	Панино	1	4	1484	40.107415000000003	40.158493	51.672992000000001	51.628069000000004	0103000020E61000000100000005000000C80C54C6BF0D4440D350A39064D04940C80C54C6BF0D44401D3C139A24D649408DD2A57F491444401D3C139A24D649408DD2A57F49144440D350A39064D04940C80C54C6BF0D4440D350A39064D04940
45902	Пады	1	4	1484	40.438732000000002	40.462716999999998	51.669953	51.648544000000001	0103000020E61000000100000005000000B6DAC35E283844402E02637D03D34940B6DAC35E28384440B56D1805C1D54940D026874F3A3B4440B56D1805C1D54940D026874F3A3B44402E02637D03D34940B6DAC35E283844402E02637D03D34940
46147	Павловка	1	4	1484	39.765678000000001	39.778640000000003	51.484115000000003	51.478712999999999	0103000020E6100000010000000500000023A298BC01E24340C495B37746BD494023A298BC01E243406440F67AF7BD4940C1ADBB79AAE343406440F67AF7BD4940C1ADBB79AAE34340C495B37746BD494023A298BC01E24340C495B37746BD4940
54416	Отдел Первомайского завода N11	1	4	1484	39.665092999999999	40.539199000000004	51.792197999999999	51.326500000000003	0103000020E6100000010000000500000036E675C421D543406F1283C0CAA9494036E675C421D5434072FA7ABE66E5494099840B790445444072FA7ABE66E5494099840B79044544406F1283C0CAA9494036E675C421D543406F1283C0CAA94940
46311	Октябрьский	1	4	1484	40.057136	40.081803999999998	51.539074999999997	51.522126	0103000020E610000001000000050000004EB6813B5007444016325706D5C249404EB6813B50074440AC8BDB6800C549404B57B08D780A4440AC8BDB6800C549404B57B08D780A444016325706D5C249404EB6813B5007444016325706D5C24940
27631	Новохреновое	1	4	1484	39.854036000000001	39.946958000000002	51.590935999999999	51.537444999999998	0103000020E61000000100000005000000A7CD380D51ED434009336DFFCAC44940A7CD380D51ED4340B80375CAA3CB4940C15774EB35F94340B80375CAA3CB4940C15774EB35F9434009336DFFCAC44940A7CD380D51ED434009336DFFCAC44940
45932	Михайловка 2-я	1	4	1484	39.975802999999999	40.005842000000001	51.746585000000003	51.732045999999997	0103000020E610000001000000050000005A2BDA1CE7FC43407495EEAEB3DD49405A2BDA1CE7FC43409357E71890DF4940BC783F6EBF0044409357E71890DF4940BC783F6EBF0044407495EEAEB3DD49405A2BDA1CE7FC43407495EEAEB3DD4940
46386	Михайловка 1-я	1	4	1484	40.362231000000001	40.397767999999999	51.648392999999999	51.629365999999997	0103000020E61000000100000005000000774CDD955D2E44406F9BA9108FD04940774CDD955D2E444048FAB48AFED249409AB2D30FEA32444048FAB48AFED249409AB2D30FEA3244406F9BA9108FD04940774CDD955D2E44406F9BA9108FD04940
54475	Марьевка	1	4	1484	40.307164	40.337141000000003	51.628951999999998	51.612578999999997	0103000020E610000001000000050000001841632651274440B29B19FD68CE494018416326512744407C60C77F81D049400492B06F272B44407C60C77F81D049400492B06F272B4440B29B19FD68CE49401841632651274440B29B19FD68CE4940
46184	Криуша	1	4	1484	40.020026999999999	40.072659000000002	51.475465	51.455052000000002	0103000020E61000000100000005000000BC04A73E900244405DFDD8243FBA4940BC04A73E9002444042B28009DCBC49404A61DEE34C09444042B28009DCBC49404A61DEE34C0944405DFDD8243FBA4940BC04A73E900244405DFDD8243FBA4940
54321	Красный Лиман	1	4	1484	39.833896000000003	39.884920000000001	51.550595999999999	51.497416999999999	0103000020E61000000100000005000000F321A81ABDEA4340BABC395CABBF4940F321A81ABDEA43407AA702EE79C64940C5C9FD0E45F143407AA702EE79C64940C5C9FD0E45F14340BABC395CABBF4940F321A81ABDEA4340BABC395CABBF4940
46020	Красные Холмы	1	4	1484	39.911231999999998	39.936852000000002	51.635067999999997	51.609498000000002	0103000020E61000000100000005000000CA880B40A3F443401C7DCC0704CE4940CA880B40A3F44340395E81E849D149409A982EC4EAF74340395E81E849D149409A982EC4EAF743401C7DCC0704CE4940CA880B40A3F443401C7DCC0704CE4940
40462	Красное	1	4	1484	40.193976999999997	40.230744999999999	51.748491999999999	51.740568000000003	0103000020E610000001000000050000008D96033DD4184440693BA6EECADE49408D96033DD4184440A8A8FA95CEDF4940965B5A0D891D4440A8A8FA95CEDF4940965B5A0D891D4440693BA6EECADE49408D96033DD4184440693BA6EECADE4940
26899	Ивановка 1-я	1	4	1484	39.929036000000004	39.973359000000002	51.652298999999999	51.638612000000002	0103000020E610000001000000050000004167D2A6EAF64340A56ABB09BED149404167D2A6EAF64340541B9C887ED349403622180797FC4340541B9C887ED349403622180797FC4340A56ABB09BED149404167D2A6EAF64340A56ABB09BED14940
46138	Дмитриевка	1	4	1484	40.073242999999998	40.106876	51.754631000000003	51.733775000000001	0103000020E6100000010000000500000099D4D00660094440ABCFD556ECDD494099D4D006600944401EC6A4BF97E04940185DDE1CAE0D44401EC6A4BF97E04940185DDE1CAE0D4440ABCFD556ECDD494099D4D00660094440ABCFD556ECDD4940
26943	Верхняя Катуховка	1	4	1484	39.921967000000002	39.966037999999998	51.687694999999998	51.656534000000001	0103000020E61000000100000005000000E17EC00303F64340255B5D4E09D44940E17EC00303F64340B54FC76306D84940BC581822A7FB4340B54FC76306D84940BC581822A7FB4340255B5D4E09D44940E17EC00303F64340255B5D4E09D44940
27385	Большой Мартын	1	4	1484	40.002375000000001	40.047379999999997	51.416496000000002	51.383754000000003	0103000020E61000000100000005000000FCA9F1D24D004440C7DADFD91EB14940FCA9F1D24D0044401975ADBD4FB54940033E3F8C100644401975ADBD4FB54940033E3F8C10064440C7DADFD91EB14940FCA9F1D24D004440C7DADFD91EB14940
54385	Березняги	1	4	1484	40.040095000000001	40.066065000000002	51.653143	51.643374000000001	0103000020E61000000100000005000000D7DD3CD521054440618C48145AD24940D7DD3CD521054440404E98309AD34940833463D174084440404E98309AD34940833463D174084440618C48145AD24940D7DD3CD521054440618C48145AD24940
27826	Алое Поле	1	4	1484	40.039546999999999	40.065067999999997	51.619866000000002	51.600313	0103000020E61000000100000005000000D4D347E00F0544408C2E6F0ED7CC4940D4D347E00F05444080F3E2C457CF49401002F2255408444080F3E2C457CF49401002F225540844408C2E6F0ED7CC4940D4D347E00F0544408C2E6F0ED7CC4940
49431	Алексеевка	1	4	1484	40.222740999999999	40.339243000000003	51.769168999999998	51.673014000000002	0103000020E610000001000000050000003A3DEFC6821C444005E09F5225D649403A3DEFC6821C44406B0C3A2174E24940CF328B506C2B44406B0C3A2174E24940CF328B506C2B444005E09F5225D649403A3DEFC6821C444005E09F5225D64940
54383	с.Лосево	1	4	1757	40.012014000000001	40.141424999999998	50.701206999999997	50.648389000000002	0103000020E610000001000000050000000D8CBCAC89014440070B2769FE5249400D8CBCAC89014440F65CA626C15949401CEBE2361A124440F65CA626C15949401CEBE2361A124440070B2769FE5249400D8CBCAC89014440070B2769FE524940
25490	Шувалов	1	4	1757	40.466507	40.506545000000003	50.523781999999997	50.504949000000003	0103000020E61000000100000005000000732D5A80B63B4440EF92382BA2404940732D5A80B63B4440E21DE0490B434940E6797077D6404440E21DE0490B434940E6797077D6404440EF92382BA2404940732D5A80B63B4440EF92382BA2404940
54441	Шкурлат	1	4	1757	40.222389999999997	40.260254000000003	50.373480999999998	50.355437999999999	0103000020E610000001000000050000008D7A8846771C4440B9E00CFE7E2D49408D7A8846771C4440B456B439CE2F49409C53C90050214440B456B439CE2F49409C53C90050214440B9E00CFE7E2D49408D7A8846771C4440B9E00CFE7E2D4940
45645	Черкасское	1	4	1757	39.906201000000003	39.948332000000001	50.673563999999999	50.657212999999999	0103000020E610000001000000050000001F4DF564FEF34340C6C03A8E1F5449401F4DF564FEF34340A8E15B583756494009E066F162F94340A8E15B583756494009E066F162F94340C6C03A8E1F5449401F4DF564FEF34340C6C03A8E1F544940
26183	Русская Буйловка	1	4	1757	40.031714000000001	40.099877999999997	50.389771000000003	50.341051	0103000020E61000000100000005000000A56950340F04444051A2258FA72B4940A56950340F044440F1F62004E431494081CB63CDC80C4440F1F62004E431494081CB63CDC80C444051A2258FA72B4940A56950340F04444051A2258FA72B4940
49073	Покровка	1	4	1757	39.814106000000002	39.88015	50.685761999999997	50.653781000000002	0103000020E610000001000000050000001BBD1AA034E8434083DF8618AF5349401BBD1AA034E84340766B990CC757494086C954C1A8F04340766B990CC757494086C954C1A8F0434083DF8618AF5349401BBD1AA034E8434083DF8618AF534940
54317	Петровка	1	4	1757	40.238433999999998	40.298738	50.543723999999997	50.507990999999997	0103000020E6100000010000000500000092205C01851E4440C7D45DD90541494092205C01851E444070067FBF984549404609FA0B3D26444070067FBF984549404609FA0B3D264440C7D45DD90541494092205C01851E4440C7D45DD905414940
54325	Пески	1	4	1757	39.953524000000002	39.994765999999998	50.703043999999998	50.687393999999998	0103000020E61000000100000005000000BEF90D130DFA4340BABBCE86FC574940BEF90D130DFA434013D38558FD5949401C96067E54FF434013D38558FD5949401C96067E54FF4340BABBCE86FC574940BEF90D130DFA4340BABBCE86FC574940
54419	Переездной	1	4	1757	40.623972999999999	40.654434999999999	50.569401999999997	50.555903999999998	0103000020E61000000100000005000000234BE658DE4F444098DBBDDC27474940234BE658DE4F444074232C2AE2484940CB2DAD86C453444074232C2AE2484940CB2DAD86C453444098DBBDDC27474940234BE658DE4F444098DBBDDC27474940
40402	Павловск	1	4	1757	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
54381	Николаевка	1	4	1757	39.983815999999997	40.019190999999999	50.289484000000002	50.269837000000003	0103000020E6100000010000000500000009A4C4AEEDFD43401920D1048A22494009A4C4AEEDFD43408E5BCCCF0D25494053B0C6D9740244408E5BCCCF0D25494053B0C6D9740244401920D1048A22494009A4C4AEEDFD43401920D1048A224940
25357	Момотов	1	4	1757	40.523757000000003	40.541246999999998	50.545281000000003	50.534782	0103000020E610000001000000050000008A0629780A434440A73E90BC734449408A0629780A434440AA108FC4CB4549407007EA9447454440AA108FC4CB4549407007EA9447454440A73E90BC734449408A0629780A434440A73E90BC73444940
45568	Михайловка	1	4	1757	40.223154000000001	40.255718000000002	50.550198000000002	50.516520999999997	0103000020E610000001000000050000005DFC6D4F901C44403E59315C1D4249405DFC6D4F901C44408D2958E36C464940D07F0F5EBB2044408D2958E36C464940D07F0F5EBB2044403E59315C1D4249405DFC6D4F901C44403E59315C1D424940
54389	Лосево	1	4	1757	40.012014000000001	40.141424999999998	50.701206999999997	50.648389000000002	0103000020E610000001000000050000000D8CBCAC89014440070B2769FE5249400D8CBCAC89014440F65CA626C15949401CEBE2361A124440F65CA626C15949401CEBE2361A124440070B2769FE5249400D8CBCAC89014440070B2769FE524940
45423	Ливенка	1	4	1757	40.207047000000003	40.252412	50.752547	50.714252999999999	0103000020E6100000010000000500000012DE1E84801A4440F2086EA46C5B494012DE1E84801A4440F9D9C87553604940198F52094F204440F9D9C87553604940198F52094F204440F2086EA46C5B494012DE1E84801A4440F2086EA46C5B4940
49517	Каменск	1	4	1757	40.405144	40.424115999999998	50.465088000000002	50.454410000000003	0103000020E61000000100000005000000D71533C2DB334440D97C5C1B2A3A4940D71533C2DB3344408BE1EA00883B4940ECDADE6E493644408BE1EA00883B4940ECDADE6E49364440D97C5C1B2A3A4940D71533C2DB334440D97C5C1B2A3A4940
49561	Ерышевка	1	4	1757	40.190418999999999	40.228211000000002	50.706285000000001	50.675727999999999	0103000020E61000000100000005000000BDC458A65F184440E97E4E417E564940BDC458A65F184440E353008C675A494032CB9E04361D4440E353008C675A494032CB9E04361D4440E97E4E417E564940BDC458A65F184440E97E4E417E564940
49540	Елизаветовка	1	4	1757	40.177303999999999	40.209409999999998	50.474542	50.450648000000001	0103000020E6100000010000000500000099B9C0E5B116444000016BD5AE39494099B9C0E5B11644400A4AD1CABD3C494049BA66F2CD1A44400A4AD1CABD3C494049BA66F2CD1A444000016BD5AE39494099B9C0E5B116444000016BD5AE394940
54331	Данило	1	4	1757	40.436827000000001	40.467602999999997	50.595986000000003	50.575592	0103000020E61000000100000005000000418177F2E93744406CEBA7FFAC494940418177F2E9374440DB6FED44494C49407841446ADA3B4440DB6FED44494C49407841446ADA3B44406CEBA7FFAC494940418177F2E93744406CEBA7FFAC494940
26058	Грань	1	4	1757	39.776808000000003	39.793776999999999	50.746465999999998	50.715530999999999	0103000020E61000000100000005000000B6A2CD716EE3434018231285965B4940B6A2CD716EE34340B8C9A8328C5F494093A8177C9AE54340B8C9A8328C5F494093A8177C9AE5434018231285965B4940B6A2CD716EE3434018231285965B4940
25101	Гаврильск	1	4	1757	40.331194000000004	40.376182	50.443230999999997	50.415320000000001	0103000020E61000000100000005000000D350A390642A4440F7AFAC3429354940D350A390642A444064C91CCBBB38494004AC55BB2630444064C91CCBBB38494004AC55BB26304440F7AFAC3429354940D350A390642A4440F7AFAC3429354940
49449	Воронцовка	1	4	1757	40.302869999999999	40.38053	50.641604000000001	50.587854	0103000020E610000001000000050000004278B471C42644405169C4CC3E4B49404278B471C4264440CC7D721420524940CD920035B5304440CC7D721420524940CD920035B53044405169C4CC3E4B49404278B471C42644405169C4CC3E4B4940
25343	Большая Казинка	1	4	1757	40.046464	40.117054000000003	50.266289999999998	50.237952	0103000020E610000001000000050000007E384888F205444047020D36751E49407E384888F20544403CA06CCA15224940D9EE1EA0FB0E44403CA06CCA15224940D9EE1EA0FB0E444047020D36751E49407E384888F205444047020D36751E4940
49419	Березки	1	4	1757	40.110388	40.134678999999998	50.594276000000001	50.584909000000003	0103000020E6100000010000000500000078EFA831210E44406B11514CDE4A494078EFA831210E44401B66683C114C49409F3A56293D1144401B66683C114C49409F3A56293D1144406B11514CDE4A494078EFA831210E44406B11514CDE4A4940
49406	Бабка	1	4	1757	39.956291	39.990220999999998	50.571838999999997	50.550055	0103000020E61000000100000005000000C53A55BE67FA43402A00C63368464940C53A55BE67FA4340E6C9350532494940FD67CD8FBFFE4340E6C9350532494940FD67CD8FBFFE43402A00C63368464940C53A55BE67FA43402A00C63368464940
24761	Александровка-Донская	1	4	1757	40.050317999999997	40.087947999999997	50.527613000000002	50.510323	0103000020E610000001000000050000003733FAD170064440C4B29943524149403733FAD170064440E4F8A1D288434940D2DF4BE1410B4440E4F8A1D288434940D2DF4BE1410B4440C4B29943524149403733FAD170064440C4B2994352414940
22669	Шубное	1	4	887	38.848165000000002	38.884906999999998	50.867415999999999	50.846958000000001	0103000020E61000000100000005000000514EB4AB906C4340F48AA71E696C4940514EB4AB906C43407903CC7C076F49403080F0A1447143407903CC7C076F49403080F0A144714340F48AA71E696C4940514EB4AB906C4340F48AA71E696C4940
60384	Шинкин	1	4	887	38.875762000000002	38.898955999999998	50.721490000000003	50.702103000000001	0103000020E610000001000000050000002F8A1EF81870434035B6D782DE5949402F8A1EF8187043400E32C9C8595C494080457EFD107343400E32C9C8595C494080457EFD1073434035B6D782DE5949402F8A1EF81870434035B6D782DE594940
22543	Хохол-Тростянка	1	4	887	38.750743	38.811765999999999	50.839785999999997	50.787342000000002	0103000020E61000000100000005000000B859BC58186043403562669FC7644940B859BC5818604340BFD18E1B7E6B49409B00C3F2E7674340BFD18E1B7E6B49409B00C3F2E76743403562669FC7644940B859BC58186043403562669FC7644940
24009	Урыв-Покровка	1	4	887	39.118108999999997	39.199514999999998	51.138922999999998	51.098996	0103000020E610000001000000050000007F2E1A321E8F4340A837A3E6AB8C49407F2E1A321E8F4340C3D4963AC8914940DD0720B589994340C3D4963AC8914940DD0720B589994340A837A3E6AB8C49407F2E1A321E8F4340A837A3E6AB8C4940
49099	Терновое	1	4	887	38.951256000000001	38.988509000000001	50.980845000000002	50.961208999999997	0103000020E61000000100000005000000D80FB1C1C279434078CF81E5087B4940D80FB1C1C2794340FAB836548C7D49409D668176877E4340FAB836548C7D49409D668176877E434078CF81E5087B4940D80FB1C1C279434078CF81E5087B4940
49201	Сторожевое	1	4	887	39.149362000000004	39.19726	51.223958000000003	51.194763000000002	0103000020E61000000100000005000000F1A1444B1E93434045BC75FEED984940F1A1444B1E934340BBD6DEA7AA9C49408C67D0D03F994340BBD6DEA7AA9C49408C67D0D03F99434045BC75FEED984940F1A1444B1E93434045BC75FEED984940
45762	Солдатское	1	4	887	38.944626999999997	39.033316999999997	51.058236999999998	51.037393000000002	0103000020E6100000010000000500000094F59B89E9784340B70C384BC984494094F59B89E978434065355D4F748749404EB340BB4384434065355D4F748749404EB340BB43844340B70C384BC984494094F59B89E9784340B70C384BC9844940
48861	Сельхозтехника	1	4	887	39.09937	39.107626000000003	50.841607000000003	50.836550000000003	0103000020E610000001000000050000000D1AFA27B88C434002BC0512146B49400D1AFA27B88C4340D78A36C7B96B4940831953B0C68D4340D78A36C7B96B4940831953B0C68D434002BC0512146B49400D1AFA27B88C434002BC0512146B4940
48977	Рыбное	1	4	887	39.154643999999998	39.169950999999998	50.899858999999999	50.883495000000003	0103000020E61000000100000005000000E542E55FCB934340FB96395D16714940E542E55FCB934340710168942E734940147651F4C0954340710168942E734940147651F4C0954340FB96395D16714940E542E55FCB934340FB96395D16714940
22587	Русская Тростянка	1	4	887	38.757551999999997	38.780486000000003	50.899512000000001	50.853656999999998	0103000020E610000001000000050000007B82C476F76043403080F0A1446D49407B82C476F7604340062E8F3523734940317E1AF7E6634340062E8F3523734940317E1AF7E66343403080F0A1446D49407B82C476F76043403080F0A1446D4940
54355	Петропавловка	1	4	887	39.181565999999997	39.237343000000003	51.014448999999999	50.997667	0103000020E610000001000000050000006308008E3D97434033A6608DB37F49406308008E3D974340DE3AFF76D98149409F776341619E4340DE3AFF76D98149409F776341619E434033A6608DB37F49406308008E3D97434033A6608DB37F4940
23247	Петренково	1	4	887	39.107410000000002	39.156252000000002	50.793149999999997	50.779505	0103000020E61000000100000005000000B6A1629CBF8D4340C408E1D1C6634940B6A1629CBF8D434044696FF085654940A1F7C6100094434044696FF085654940A1F7C61000944340C408E1D1C6634940B6A1629CBF8D4340C408E1D1C6634940
54354	Отдел N1 совхоза Острогожский	1	4	887	38.706240999999999	39.350493999999998	51.261994999999999	50.620697999999997	0103000020E61000000100000005000000130CE71A665A4340A7583508734F4940130CE71A665A4340965B5A0D89A14940DCB8C5FCDCAC4340965B5A0D89A14940DCB8C5FCDCAC4340A7583508734F4940130CE71A665A4340A7583508734F4940
54372	Острогожский	1	4	887	38.84901	38.876596999999997	50.892246	50.880591000000003	0103000020E610000001000000050000000DFD135CAC6C43407313B534B77049400DFD135CAC6C434050FEEE1D35724940C7629B543470434050FEEE1D35724940C7629B54347043407313B534B77049400DFD135CAC6C43407313B534B7704940
20882	Острогожск	1	4	887	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
54431	Новоуспенка	1	4	887	39.078825999999999	39.094537000000003	51.181153000000002	51.165098	0103000020E6100000010000000500000089096AF8168A4340485167EE2195494089096AF8168A4340414981053097494088A1D5C9198C4340414981053097494088A1D5C9198C4340485167EE2195494089096AF8168A4340485167EE21954940
48625	Новая Осиновка	1	4	887	38.914802999999999	38.968288000000001	50.801968000000002	50.773018	0103000020E610000001000000050000002FA4C34318754340139CFA40F26249402FA4C3431875434022382EE3A6664940FC8D76DCF07B434022382EE3A6664940FC8D76DCF07B4340139CFA40F26249402FA4C34318754340139CFA40F2624940
48601	Новая Мельница	1	4	887	39.012278999999999	39.041168999999996	50.812060000000002	50.800311999999998	0103000020E61000000100000005000000BBB6B75B92814340554CA59F70664940BBB6B75B92814340E4310395F1674940F44D9A0645854340E4310395F1674940F44D9A0645854340554CA59F70664940BBB6B75B92814340554CA59F70664940
22793	Нижний Ольшан	1	4	887	38.891140999999998	38.946109	50.767743000000003	50.741917999999998	0103000020E61000000100000005000000F78F85E8107243402828452BF75E4940F78F85E810724340D15D126745624940C3B986191A794340D15D126745624940C3B986191A7943402828452BF75E4940F78F85E8107243402828452BF75E4940
23885	Мастюгино	1	4	887	39.027334000000003	39.051948000000003	51.205418999999999	51.190682000000002	0103000020E61000000100000005000000D10836AE7F834340CBF78C4468984940D10836AE7F8343400F7D772B4B9A4940DB8B683BA68643400F7D772B4B9A4940DB8B683BA6864340CBF78C4468984940D10836AE7F834340CBF78C4468984940
49012	Луки	1	4	887	39.232850999999997	39.253844999999998	50.948618000000003	50.932772	0103000020E61000000100000005000000A2EBC20FCE9D4340F04FA91265774940A2EBC20FCE9D4340CF328B506C79494066A032FE7DA04340CF328B506C79494066A032FE7DA04340F04FA91265774940A2EBC20FCE9D4340F04FA91265774940
46738	Криница	1	4	887	39.223976	39.254725000000001	50.896960999999997	50.867353999999999	0103000020E61000000100000005000000618BDD3EAB9C43400307B474056F4940618BDD3EAB9C4340CB64389ECF7249409F3C2CD49AA04340CB64389ECF7249409F3C2CD49AA043400307B474056F4940618BDD3EAB9C43400307B474056F4940
23137	Кривая Поляна	1	4	887	39.131754999999998	39.154491	50.653843000000002	50.641775000000003	0103000020E61000000100000005000000D00A0C59DD904340F931E6AE25524940D00A0C59DD904340F9DB9E20B15349405F43705CC6934340F9DB9E20B15349405F43705CC6934340F931E6AE25524940D00A0C59DD904340F931E6AE25524940
23514	Коротояк	1	4	887	39.121146000000003	39.204931000000002	51.002315000000003	50.974476000000003	0103000020E6100000010000000500000047054EB6818F4340535E2BA1BB7C494047054EB6818F434027A5A0DB4B804940E277D32D3B9A434027A5A0DB4B804940E277D32D3B9A4340535E2BA1BB7C494047054EB6818F4340535E2BA1BB7C4940
23718	Ездочное	1	4	887	38.960113999999997	38.987180000000002	51.031677999999999	51.023440999999998	0103000020E610000001000000050000004337FB03E57A434059315C1D008349404337FB03E57A4340580053060E844940F5A10BEA5B7E4340580053060E844940F5A10BEA5B7E434059315C1D008349404337FB03E57A434059315C1D00834940
60406	Должик	1	4	887	39.203952000000001	39.223526999999997	50.834724000000001	50.823863000000003	0103000020E6100000010000000500000016FA60191B9A434036B1C0577469494016FA60191B9A4340D9976C3CD86A4940F16261889C9C4340D9976C3CD86A4940F16261889C9C434036B1C0577469494016FA60191B9A434036B1C05774694940
6788	Девица	1	4	887	39.101292999999998	39.135384000000002	51.096173999999998	51.060806999999997	0103000020E610000001000000050000002828452BF78C4340162F1686C88749402828452BF78C4340DD5CFC6D4F8C49406A334E4354914340DD5CFC6D4F8C49406A334E4354914340162F1686C88749402828452BF78C4340162F1686C8874940
23081	Дальняя Полубянка	1	4	887	39.015926	39.044896999999999	50.744266000000003	50.708486000000001	0103000020E61000000100000005000000FB93F8DC0982434041D653ABAF5A4940FB93F8DC098243402BC3B81B445F49402158552FBF8543402BC3B81B445F49402158552FBF85434041D653ABAF5A4940FB93F8DC0982434041D653ABAF5A4940
22723	Грушевая Поляна	1	4	887	38.932149000000003	38.946916999999999	50.846992999999998	50.836590000000001	0103000020E61000000100000005000000E3FF8EA85077434090149161156B4940E3FF8EA850774340707841446A6C49406283859334794340707841446A6C4940628385933479434090149161156B4940E3FF8EA85077434090149161156B4940
48812	Гнилое	1	4	887	39.056556999999998	39.081187999999997	50.818986000000002	50.80153	0103000020E6100000010000000500000010AE80423D874340A661F8889866494010AE80423D874340E1F08288D4684940F0694E5E648A4340E1F08288D4684940F0694E5E648A4340A661F8889866494010AE80423D874340A661F88898664940
48582	Волошино	1	4	887	38.913967	38.958801999999999	50.881756000000003	50.861510000000003	0103000020E61000000100000005000000C64FE3DEFC744340A796ADF5456E4940C64FE3DEFC744340A1866F61DD70494071AB2006BA7A4340A1866F61DD70494071AB2006BA7A4340A796ADF5456E4940C64FE3DEFC744340A796ADF5456E4940
60425	Владимировка	1	4	887	38.966006	38.993710999999998	50.682343000000003	50.667422000000002	0103000020E61000000100000005000000B1DEA815A67B4340C25087156E554940B1DEA815A67B4340C8D3F2035757494075560BEC317F4340C8D3F2035757494075560BEC317F4340C25087156E554940B1DEA815A67B4340C25087156E554940
47480	Веретье	1	4	887	38.852513000000002	38.915072000000002	50.790216999999998	50.767487000000003	0103000020E610000001000000050000001A355F251F6D4340768D96033D6249401A355F251F6D434022DFA5D4256549401FBE4C142175434022DFA5D4256549401FBE4C1421754340768D96033D6249401A355F251F6D4340768D96033D624940
49154	Болдыревка	1	4	887	39.038536000000001	39.068584999999999	51.139805000000003	51.120440000000002	0103000020E61000000100000005000000FDDB65BFEE844340AC90F2936A8F4940FDDB65BFEE8443409D685721E591494082FFAD64C78843409D685721E591494082FFAD64C7884340AC90F2936A8F4940FDDB65BFEE844340AC90F2936A8F4940
54339	Ближняя Стояново	1	4	887	39.082535999999998	39.093953999999997	50.821223000000003	50.806870000000004	0103000020E610000001000000050000000F5F268A908A4340D00F2384476749400F5F268A908A43408CDCD3D51D69494008AA46AF068C43408CDCD3D51D69494008AA46AF068C4340D00F2384476749400F5F268A908A4340D00F238447674940
23195	Ближняя Полубянка	1	4	887	39.186615000000003	39.216591999999999	50.765658000000002	50.733834000000002	0103000020E61000000100000005000000B6F81400E3974340B058C345EE5D4940B6F81400E3974340DCF5D21401624940A1496249B99B4340DCF5D21401624940A1496249B99B4340B058C345EE5D4940B6F81400E3974340B058C345EE5D4940
49081	Березово	1	4	887	38.889226999999998	38.922311999999998	50.952835	50.936456	0103000020E610000001000000050000002FDCB930D27143404D124BCADD7749402FDCB930D2714340F9BD4D7FF6794940AB5AD2510E764340F9BD4D7FF6794940AB5AD2510E7643404D124BCADD7749402FDCB930D27143404D124BCADD774940
54352	Юрасовка	1	4	1636	39.163905	39.198067999999999	50.513857000000002	50.464886999999997	0103000020E610000001000000050000005053CBD6FA944340F3AACE6A813B49405053CBD6FA9443400CE9F010C64149402B31CF4A5A9943400CE9F010C64149402B31CF4A5A994340F3AACE6A813B49405053CBD6FA944340F3AACE6A813B4940
54299	Шапошниковка	1	4	1636	39.347825999999998	39.395176999999997	50.251035000000002	50.222468999999997	0103000020E610000001000000050000006859F78F85AC4340D9AF3BDD791C49406859F78F85AC4340609335EA21204940D190F12895B24340609335EA21204940D190F12895B24340D9AF3BDD791C49406859F78F85AC4340D9AF3BDD791C4940
54452	Постоялый	1	4	1636	39.391933999999999	39.417572	50.418453999999997	50.405923000000001	0103000020E610000001000000050000006118B0E42AB24340DCD8EC48F53349406118B0E42AB24340B07092E68F354940D7DCD1FF72B54340B07092E68F354940D7DCD1FF72B54340DCD8EC48F53349406118B0E42AB24340DCD8EC48F5334940
21517	Ольховатка	1	4	1636	39.244107	39.307492000000003	50.292695000000002	50.271622000000001	0103000020E61000000100000005000000C2DCEEE53E9F4340E36F7B82C4224940C2DCEEE53E9F4340F3599E07772549400DE4D9E55BA74340F3599E07772549400DE4D9E55BA74340E36F7B82C4224940C2DCEEE53E9F4340E36F7B82C4224940
54330	Новохарьковка	1	4	1636	39.251455	39.28154	50.391649000000001	50.355708	0103000020E6100000010000000500000035B56CAD2FA043407976F9D6872D494035B56CAD2FA043406C41EF8D213249400742B28009A443406C41EF8D213249400742B28009A443407976F9D6872D494035B56CAD2FA043407976F9D6872D4940
21278	Новокулишовка	1	4	1636	39.265917999999999	39.283884	50.358770999999997	50.348685000000003	0103000020E6100000010000000500000078B5DC9909A243408ACDC7B5A12C494078B5DC9909A2434069E04735EC2D4940C8ED974F56A4434069E04735EC2D4940C8ED974F56A443408ACDC7B5A12C494078B5DC9909A243408ACDC7B5A12C4940
54443	Новокараяшник	1	4	1636	39.226590000000002	39.256396000000002	50.410677	50.390321999999998	0103000020E61000000100000005000000E2CCAFE6009D434064744012F6314940E2CCAFE6009D4340151C5E1091344940A1698995D1A04340151C5E1091344940A1698995D1A0434064744012F6314940E2CCAFE6009D434064744012F6314940
54418	Неровновка	1	4	1636	39.229590000000002	39.255983000000001	50.158192	50.142584999999997	0103000020E610000001000000050000008CBE8234639D434038F3AB39401249408CBE8234639D4340923EADA23F1449407EAA0A0DC4A04340923EADA23F1449407EAA0A0DC4A0434038F3AB39401249408CBE8234639D434038F3AB3940124940
54344	Назаровка	1	4	1636	39.078386000000002	39.121684999999999	50.306781000000001	50.290582999999998	0103000020E610000001000000050000006D3B6D8D088A434004E3E0D2312549406D3B6D8D088A434060048D9944274940F6B4C35F938F434060048D9944274940F6B4C35F938F434004E3E0D2312549406D3B6D8D088A434004E3E0D231254940
47681	Марьевка	1	4	1636	39.133541999999998	39.174523000000001	50.323777999999997	50.301682999999997	0103000020E610000001000000050000003B527DE7179143402C616D8C9D2649403B527DE7179143400795B88E712949402DB308C5569643400795B88E712949402DB308C5569643402C616D8C9D2649403B527DE7179143402C616D8C9D264940
54427	Марченковка	1	4	1636	39.195875999999998	39.235115	50.280447000000002	50.262022999999999	0103000020E610000001000000050000002009FB761299434060E63BF8892149402009FB761299434073A1F2AFE523494047E6913F189E434073A1F2AFE523494047E6913F189E434060E63BF8892149402009FB761299434060E63BF889214940
20568	Малые Базы	1	4	1636	39.290773999999999	39.349659000000003	50.272151000000001	50.249197000000002	0103000020E6100000010000000500000078431A1538A5434073A1F2AFE51F494078431A1538A543406F490ED8D522494044E048A0C1AC43406F490ED8D522494044E048A0C1AC434073A1F2AFE51F494078431A1538A5434073A1F2AFE51F4940
54403	Лимарев	1	4	1636	39.073067999999999	39.090684000000003	50.396731000000003	50.383108999999997	0103000020E610000001000000050000002B31CF4A5A894340D1E638B7093149402B31CF4A5A8943409A27D714C83249409F2287889B8B43409A27D714C83249409F2287889B8B4340D1E638B7093149402B31CF4A5A894340D1E638B709314940
20658	Костово	1	4	1636	39.156440000000003	39.174281000000001	50.194693000000001	50.179403000000001	0103000020E61000000100000005000000A4E4D53906944340F3E670ADF6164940A4E4D539069443404CE141B3EB18494037A8FDD64E9643404CE141B3EB18494037A8FDD64E964340F3E670ADF6164940A4E4D53906944340F3E670ADF6164940
54347	Копаная 1-я	1	4	1636	39.055442999999997	39.121513999999998	50.461314999999999	50.443528999999998	0103000020E6100000010000000500000064E597C118874340EEE9EA8EC538494064E597C118874340BE13B35E0C3B4940C90050C58D8F4340BE13B35E0C3B4940C90050C58D8F4340EEE9EA8EC538494064E597C118874340EEE9EA8EC5384940
54333	Караяшник	1	4	1636	39.190764999999999	39.232661999999998	50.438096000000002	50.410418	0103000020E61000000100000005000000581CCEFC6A98434049D8B79388344940581CCEFC6A98434014419C8713384940CF8250DEC79D434014419C8713384940CF8250DEC79D434049D8B79388344940581CCEFC6A98434049D8B79388344940
47833	Заболотовка	1	4	1636	39.305847999999997	39.353971000000001	50.282611000000003	50.264822000000002	0103000020E6100000010000000500000004C6FA0626A7434073A1F2AFE521494004C6FA0626A74340B43EE5982C244940C05DF6EB4EAD4340B43EE5982C244940C05DF6EB4EAD434073A1F2AFE521494004C6FA0626A7434073A1F2AFE5214940
54428	Дроздово	1	4	1636	39.382465000000003	39.401131999999997	50.339193999999999	50.327108000000003	0103000020E61000000100000005000000AD6EF59CF4B043404721C9ACDE294940AD6EF59CF4B04340ED7F80B56A2B494085B01A4B58B34340ED7F80B56A2B494085B01A4B58B343404721C9ACDE294940AD6EF59CF4B043404721C9ACDE294940
54430	Гвоздовка	1	4	1636	39.144717	39.191240999999998	50.307274999999997	50.287641999999998	0103000020E610000001000000050000006E162F16869243405F7AFB73D12449406E162F16869243406FF085C954274940C153C8957A9843406FF085C954274940C153C8957A9843405F7AFB73D12449406E162F16869243405F7AFB73D1244940
47145	Бугаевка	1	4	1636	39.296595000000003	39.331243999999998	50.315674000000001	50.281160999999997	0103000020E610000001000000050000001D9430D3F6A5434090F46915FD2349401D9430D3F6A543404819710168284940847F113466AA43404819710168284940847F113466AA434090F46915FD2349401D9430D3F6A5434090F46915FD234940
54287	Болшие Базы	1	4	1636	39.260043000000003	39.300530000000002	50.275323999999998	50.258648999999998	0103000020E61000000100000005000000E146CA1649A14340511212691B214940E146CA1649A14340E6E61BD13D234940C3BB5CC477A64340E6E61BD13D234940C3BB5CC477A64340511212691B214940E146CA1649A14340511212691B214940
38561	Заброды	1	4	5817	33.663296000000003	33.671182999999999	56.090322	56.078643	0103000020E61000000100000005000000A8C821E2E6D4404098874CF9100A4C40A8C821E2E6D44040FE0DDAAB8F0B4C40CA501553E9D54040FE0DDAAB8F0B4C40CA501553E9D5404098874CF9100A4C40A8C821E2E6D4404098874CF9100A4C40
9177	Ярки	1	4	1046	41.112791000000001	41.171784000000002	51.371671999999997	51.315945999999997	0103000020E610000001000000050000003E247CEF6F8E4440A8A624EB70A849403E247CEF6F8E4440616BB6F292AF4940F0FCA204FD954440616BB6F292AF4940F0FCA204FD954440A8A624EB70A849403E247CEF6F8E4440A8A624EB70A84940
15793	Централь	1	4	1046	41.316986999999997	41.347951999999999	50.936830999999998	50.917845999999997	0103000020E61000000100000005000000EA20AF0793A84440D8614CFA7B754940EA20AF0793A8444082700514EA774940F549EEB089AC444082700514EA774940F549EEB089AC4440D8614CFA7B754940EA20AF0793A84440D8614CFA7B754940
20083	Тулучеевка	1	4	1046	41.091546000000001	41.104320000000001	50.916226999999999	50.907100999999997	0103000020E61000000100000005000000310A82C7B78B44409E95B4E21B744940310A82C7B78B4440295B24ED46754940CC28965B5A8D4440295B24ED46754940CC28965B5A8D44409E95B4E21B744940310A82C7B78B44409E95B4E21B744940
46830	Троицкое	1	4	1046	41.407069999999997	41.519351	51.326883000000002	51.226146999999997	0103000020E610000001000000050000006397A8DE1AB44440548B8862F29C49406397A8DE1AB44440274F594DD7A949408C12F4177AC24440274F594DD7A949408C12F4177AC24440548B8862F29C49406397A8DE1AB44440548B8862F29C4940
19958	Терновский	1	4	1046	41.068468000000003	41.110007000000003	51.093452999999997	51.060841000000003	0103000020E610000001000000050000004969368FC3884440C3A04CA3C98749404969368FC3884440465B9544F68B494061AA99B5148E4440465B9544F68B494061AA99B5148E4440C3A04CA3C98749404969368FC3884440C3A04CA3C9874940
61069	Совхоз имени ХХII Партсъезда	1	4	1046	41.079096	41.107796999999998	50.990892000000002	50.973280000000003	0103000020E61000000100000005000000499F56D11F8A4440EAEC6470947C4940499F56D11F8A44401CEF8E8CD57E4940AFCDC64ACC8D44401CEF8E8CD57E4940AFCDC64ACC8D4440EAEC6470947C4940499F56D11F8A4440EAEC6470947C4940
47173	Русаново	1	4	1046	41.453989	41.499749999999999	51.112490000000001	51.085957000000001	0103000020E6100000010000000500000033DFC14F1CBA44405FEE93A3008B494033DFC14F1CBA444043908312668E49408716D9CEF7BF444043908312668E49408716D9CEF7BF44405FEE93A3008B494033DFC14F1CBA44405FEE93A3008B4940
18594	Пыховка	1	4	1046	41.473061000000001	41.535331999999997	51.047434000000003	51.000512999999998	0103000020E61000000100000005000000AC014A438DBC4440861C5BCF10804940AC014A438DBC4440F75B3B51128649404A404CC285C44440F75B3B51128649404A404CC285C44440861C5BCF10804940AC014A438DBC4440861C5BCF10804940
18816	Половцево	1	4	1046	41.747577	41.766979999999997	51.082991999999997	51.073123000000002	0103000020E61000000100000005000000F31E679AB0DF4440EFCA2E185C894940F31E679AB0DF444031EA5A7B9F8A4940D15790662CE2444031EA5A7B9F8A4940D15790662CE24440EFCA2E185C894940F31E679AB0DF4440EFCA2E185C894940
19731	Полежаевский	1	4	1046	41.149523000000002	41.171864999999997	50.892138000000003	50.868934000000003	0103000020E61000000100000005000000FA7FD59123934440F530B43A396F4940FA7FD591239344406AC2F69331724940DC291DACFF9544406AC2F69331724940DC291DACFF954440F530B43A396F4940FA7FD59123934440F530B43A396F4940
47500	Подосиновка	1	4	1046	41.295014999999999	41.369107999999997	51.150647999999997	51.130783999999998	0103000020E610000001000000050000002B6A300DC3A54440876BB587BD9049402B6A300DC3A54440999A046F48934940925852EE3EAF4440999A046F48934940925852EE3EAF4440876BB587BD9049402B6A300DC3A54440876BB587BD904940
54282	Подгорное	1	4	1046	41.122034999999997	41.159045999999996	51.385626000000002	51.366376000000002	0103000020E61000000100000005000000D2FBC6D79E8F44400805A568E5AE4940D2FBC6D79E8F4440603E59315CB14940A1478C9E5B944440603E59315CB14940A1478C9E5B9444400805A568E5AE4940D2FBC6D79E8F44400805A568E5AE4940
47263	Озерный	1	4	1046	41.808275999999999	41.835441000000003	51.197535000000002	51.182310000000001	0103000020E610000001000000050000002312859675E74440ECDD1FEF559749402312859675E744405E68AED348994940685E0EBBEFEA44405E68AED348994940685E0EBBEFEA4440ECDD1FEF559749402312859675E74440ECDD1FEF55974940
18049	Новохоперск	1	4	1046	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
47428	Новопокровский	1	4	1046	41.290703000000001	41.324173999999999	51.262096999999997	51.235289000000002	0103000020E61000000100000005000000AFEC82C135A54440E50D30F31D9E4940AFEC82C135A544409AB0FD648CA14940541B9C887EA944409AB0FD648CA14940541B9C887EA94440E50D30F31D9E4940AFEC82C135A54440E50D30F31D9E4940
19076	Некрылово	1	4	1046	41.437128000000001	41.491880000000002	51.151466999999997	51.116453999999997	0103000020E610000001000000050000003C1570CFF3B7444083BEF4F6E78E49403C1570CFF3B744402CB64945639349403BC780ECF5BE44402CB64945639349403BC780ECF5BE444083BEF4F6E78E49403C1570CFF3B7444083BEF4F6E78E4940
47446	Ленинский	1	4	1046	41.250808999999997	41.281432000000002	51.291817999999999	51.276190999999997	0103000020E610000001000000050000006F4562821AA044408A39083A5AA349406F4562821AA044402B31CF4A5AA549402106BAF605A444402B31CF4A5AA549402106BAF605A444408A39083A5AA349406F4562821AA044408A39083A5AA34940
47385	Красное	1	4	1046	41.425773	41.506936000000003	51.193516000000002	51.151394000000003	0103000020E610000001000000050000008942CBBA7FB64440C367EBE0609349408942CBBA7FB644405AA0DD21C598494021956247E3C044405AA0DD21C598494021956247E3C04440C367EBE0609349408942CBBA7FB64440C367EBE060934940
54360	Камено-Садовка	1	4	1046	41.614294000000001	41.665551999999998	51.040723	51.020574000000003	0103000020E610000001000000050000008410902FA1CE4440EF92382BA28249408410902FA1CE4440F698486936854940C9E4D4CE30D54440F698486936854940C9E4D4CE30D54440EF92382BA28249408410902FA1CE4440EF92382BA2824940
54392	Замельничный	1	4	1046	41.647602999999997	41.670996000000002	51.117013	51.107320999999999	0103000020E610000001000000050000004FE5B4A7E4D244404696CCB1BC8D49404FE5B4A7E4D244407A1A3048FA8E494098DF6932E3D544407A1A3048FA8E494098DF6932E3D544404696CCB1BC8D49404FE5B4A7E4D244404696CCB1BC8D4940
19864	Елань-Коленовский	1	4	1046	41.113850999999997	41.166249999999998	51.171536000000003	51.142201	0103000020E61000000100000005000000F6CE68AB928E4440B03A72A433924940F6CE68AB928E4440180B43E4F4954940E17A14AE47954440180B43E4F4954940E17A14AE47954440B03A72A433924940F6CE68AB928E4440B03A72A433924940
19376	Елань-Колено	1	4	1046	41.171002000000001	41.275288000000003	51.164504999999998	51.106896999999996	0103000020E610000001000000050000007AC6BE64E39544402F8507CDAE8D49407AC6BE64E3954440A583F57F0E9549409A7D1EA33CA34440A583F57F0E9549409A7D1EA33CA344402F8507CDAE8D49407AC6BE64E39544402F8507CDAE8D4940
19555	Димитровский	1	4	1046	41.120139999999999	41.144053	51.126103999999998	51.112377000000002	0103000020E6100000010000000500000081785DBF608F44404BE9995E628E494081785DBF608F444088F2052D2490494002F225547092444088F2052D2490494002F22554709244404BE9995E628E494081785DBF608F44404BE9995E628E4940
47266	Варварино	1	4	1046	41.713171000000003	41.733383000000003	51.219495999999999	51.196987	0103000020E6100000010000000500000052BAF42F49DB44405B5EB9DE3699494052BAF42F49DB444029CDE671189C4940A038807EDFDD444029CDE671189C4940A038807EDFDD44405B5EB9DE3699494052BAF42F49DB44405B5EB9DE36994940
19653	Бурляевка	1	4	1046	41.280929	41.324703999999997	51.015321	50.988880000000002	0103000020E61000000100000005000000BEBF417BF5A3444091D5AD9E937E4940BEBF417BF5A3444094F8DC09F6814940B07092E68FA9444094F8DC09F6814940B07092E68FA9444091D5AD9E937E4940BEBF417BF5A3444091D5AD9E937E4940
19256	Бороздиновский	1	4	1046	41.330471000000003	41.356476999999998	51.224330000000002	51.209074999999999	0103000020E6100000010000000500000062A3ACDF4CAA4440A2B437F8C29A494062A3ACDF4CAA44407FC16ED8B69C49405A63D009A1AD44407FC16ED8B69C49405A63D009A1AD4440A2B437F8C29A494062A3ACDF4CAA4440A2B437F8C29A4940
54462	Березовка	1	4	1046	41.168846000000002	41.176841000000003	51.040219	51.037092999999999	0103000020E61000000100000005000000BC07E8BE9C9544408CF4A276BF844940BC07E8BE9C954440C3D66CE525854940C5CBD3B9A2964440C3D66CE525854940C5CBD3B9A29644408CF4A276BF844940BC07E8BE9C9544408CF4A276BF844940
47330	Алферовка	1	4	1046	41.640444000000002	41.685063	51.216619000000001	51.190489999999997	0103000020E61000000100000005000000B075A911FAD14440861BF0F961984940B075A911FAD144409B58E02BBA9B49408E59F624B0D744409B58E02BBA9B49408E59F624B0D74440861BF0F961984940B075A911FAD14440861BF0F961984940
54371	Шуберское	1	4	1427	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
54337	Хреновое	1	4	1427	39.554124999999999	39.608778000000001	51.679074	51.634531000000003	0103000020E61000000100000005000000B0726891EDC643402BA6D24F38D14940B0726891EDC643402EC896E5EBD649401C430070ECCD43402EC896E5EBD649401C430070ECCD43402BA6D24F38D14940B0726891EDC643402BA6D24F38D14940
17575	Хлебное	1	4	1427	39.79101	39.826538999999997	51.622953000000003	51.602299000000002	0103000020E610000001000000050000008C67D0D03FE54340EEB4352218CD49408C67D0D03FE54340F9F884ECBCCF49402CEFAA07CCE94340F9F884ECBCCF49402CEFAA07CCE94340EEB4352218CD49408C67D0D03FE54340EEB4352218CD4940
46794	Трудовое	1	4	1427	39.704287000000001	39.747369999999997	51.778381000000003	51.750461000000001	0103000020E61000000100000005000000BDFF8F1326DA434034F6251B0FE04940BDFF8F1326DA4340F56915FDA1E349407901F6D1A9DF4340F56915FDA1E349407901F6D1A9DF434034F6251B0FE04940BDFF8F1326DA434034F6251B0FE04940
46726	Тимирязево	1	4	1427	39.625235000000004	39.668768	51.581937000000003	51.571190000000001	0103000020E6100000010000000500000044A852B307D04340B0E600C11CC9494044A852B307D043408BAA5FE97CCA4940404E98309AD543408BAA5FE97CCA4940404E98309AD54340B0E600C11CC9494044A852B307D04340B0E600C11CC94940
54401	Совхоз Лекраспром	1	4	1427	39.586759999999998	39.626168999999997	51.502194000000003	51.491427999999999	0103000020E61000000100000005000000EC4CA1F31ACB43405A2BDA1CE7BE4940EC4CA1F31ACB4340AC1F9BE447C049406F62484E26D04340AC1F9BE447C049406F62484E26D043405A2BDA1CE7BE4940EC4CA1F31ACB43405A2BDA1CE7BE4940
54305	Совхоз Воронежский	1	4	1427	39.282043000000002	39.307690000000001	51.513903999999997	51.495016999999997	0103000020E610000001000000050000006A882AFC19A4434065FB90B75CBF49406A882AFC19A443404CA4349BC7C1494033A7CB6262A743404CA4349BC7C1494033A7CB6262A7434065FB90B75CBF49406A882AFC19A4434065FB90B75CBF4940
17706	Рыкань	1	4	1427	39.507933000000001	39.587865000000001	51.634537000000002	51.602550000000001	0103000020E6100000010000000500000093C7D3F203C14340371AC05B20CD494093C7D3F203C143400D8D278238D1494045BB0A293FCB43400D8D278238D1494045BB0A293FCB4340371AC05B20CD494093C7D3F203C14340371AC05B20CD4940
17023	Рождественская Хава	1	4	1427	39.657997000000002	39.723933000000002	51.675995999999998	51.618372999999998	0103000020E61000000100000005000000DDEEE53E39D443405DDDB1D826CF4940DDEEE53E39D44340081D740987D6494062BF27D6A9DC4340081D740987D6494062BF27D6A9DC43405DDDB1D826CF4940DDEEE53E39D443405DDDB1D826CF4940
19575	Рогачевка	1	4	1427	39.522880999999998	39.598860999999999	51.542161	51.491287999999997	0103000020E610000001000000050000009259BDC3EDC2434068757286E2BE49409259BDC3EDC2434055151A8865C54940C8EC2C7AA7CC434055151A8865C54940C8EC2C7AA7CC434068757286E2BE49409259BDC3EDC2434068757286E2BE4940
46249	Парусное	1	4	1427	39.507061999999998	39.537909999999997	51.597532000000001	51.573988999999997	0103000020E61000000100000005000000AD855968E7C04340C2A1B77878C94940AD855968E7C043402028B7ED7BCC49407E18213CDAC443402028B7ED7BCC49407E18213CDAC44340C2A1B77878C94940AD855968E7C04340C2A1B77878C94940
54446	Отдел N2 совхоза Масловский	1	4	1427	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
54294	Отдел N1 совхоза Новоусманский	1	4	1427	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
54303	Отдел N1 совхоза Масловский	1	4	1427	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
46497	Орлово	1	4	1427	39.564365000000002	39.621920000000003	51.785685000000001	51.724553999999998	0103000020E61000000100000005000000E700C11C3DC84340CE177B2FBEDC4940E700C11C3DC8434098FA795391E449403A5D16139BCF434098FA795391E449403A5D16139BCF4340CE177B2FBEDC4940E700C11C3DC84340CE177B2FBEDC4940
15894	Новая Усмань	1	4	1427	39.356594000000001	39.460852000000003	51.663440000000001	51.601089999999999	0103000020E6100000010000000500000094F947DFA4AD4340F0F96184F0CC494094F947DFA4AD4340DB6D179AEBD44940EA25C632FDBA4340DB6D179AEBD44940EA25C632FDBA4340F0F96184F0CC494094F947DFA4AD4340F0F96184F0CC4940
16795	Нижняя Катуховка	1	4	1427	39.849868000000001	39.892995999999997	51.691871999999996	51.677436999999998	0103000020E610000001000000050000005EF58079C8EC4340D80C7041B6D649405EF58079C8EC43405182FE428FD84940BABA63B14DF243405182FE428FD84940BABA63B14DF24340D80C7041B6D649405EF58079C8EC4340D80C7041B6D64940
46563	Макарье	1	4	1427	39.637667999999998	39.675306999999997	51.781500999999999	51.769258000000001	0103000020E6100000010000000500000055DAE21A9FD14340DB17D00B77E2494055DAE21A9FD1434049658A3908E4494043E1B37570D6434049658A3908E4494043E1B37570D64340DB17D00B77E2494055DAE21A9FD14340DB17D00B77E24940
46761	Крыловка	1	4	1427	39.640884	39.686698	51.523862999999999	51.501044	0103000020E61000000100000005000000CC43A67C08D24340B3EDB43522C04940CC43A67C08D24340CF4A5AF10DC34940431D56B8E5D74340CF4A5AF10DC34940431D56B8E5D74340B3EDB43522C04940CC43A67C08D24340B3EDB43522C04940
17420	Горенские Выселки	1	4	1427	39.719414999999998	39.764097	51.562590999999998	51.537585	0103000020E610000001000000050000003CA06CCA15DC4340FBE8D495CFC449403CA06CCA15DC434010035DFB02C8494061FC34EECDE1434010035DFB02C8494061FC34EECDE14340FBE8D495CFC449403CA06CCA15DC4340FBE8D495CFC44940
17851	Воля	1	4	1427	39.469152999999999	39.553127000000003	51.779249999999998	51.738638000000002	0103000020E61000000100000005000000FFE89B340DBC43409BCAA2B08BDE4940FFE89B340DBC434039B4C876BEE349406EC493DDCCC6434039B4C876BEE349406EC493DDCCC643409BCAA2B08BDE4940FFE89B340DBC43409BCAA2B08BDE4940
54454	Сычевка	1	4	1307	38.392558000000001	38.416561000000002	51.437869999999997	51.422415999999998	0103000020E610000001000000050000003FE42D573F32434050A73CBA11B649403FE42D573F32434023F3C81F0CB8494000E5EFDE5135434023F3C81F0CB8494000E5EFDE5135434050A73CBA11B649403FE42D573F32434050A73CBA11B64940
54342	Совхоз Кучугуровский	1	4	1307	38.309705999999998	38.335200999999998	51.429873999999998	51.415137000000001	0103000020E61000000100000005000000FFAF3A72A4274340062E8F3523B54940FFAF3A72A42743404AB3791C06B74940124BCADDE72A43404AB3791C06B74940124BCADDE72A4340062E8F3523B54940FFAF3A72A4274340062E8F3523B54940
15103	Скупая Потудань	1	4	1307	38.481931000000003	38.538642000000003	51.286360000000002	51.201497000000003	0103000020E61000000100000005000000DCF63DEAAF3D4340FE9E58A7CA994940DCF63DEAAF3D4340F870C971A7A4494043209738F2444340F870C971A7A4494043209738F2444340FE9E58A7CA994940DCF63DEAAF3D4340FE9E58A7CA994940
14899	Синие Липяги	1	4	1307	38.433861999999998	38.521808	51.409429000000003	51.351449000000002	0103000020E61000000100000005000000137D3ECA88374340209BE447FCAC4940137D3ECA883743405A84622B68B449404565C39ACA4243405A84622B68B449404565C39ACA424340209BE447FCAC4940137D3ECA88374340209BE447FCAC4940
45521	Першино	1	4	1307	38.313982000000003	38.400866999999998	51.517238999999996	51.467426000000003	0103000020E610000001000000050000002FC4EA8F302843406AA67B9DD4BB49402FC4EA8F302843409D9B36E334C24940D7851F9C4F3343409D9B36E334C24940D7851F9C4F3343406AA67B9DD4BB49402FC4EA8F302843406AA67B9DD4BB4940
15021	Острянка	1	4	1307	38.391345000000001	38.432614000000001	51.299990000000001	51.287035000000003	0103000020E61000000100000005000000003ACC971732434058E71890BDA44940003ACC97173243404390831266A6494058E542E55F3743404390831266A6494058E542E55F37434058E71890BDA44940003ACC971732434058E71890BDA44940
14249	Новая Ольшанка	1	4	1307	38.362113999999998	38.447615999999996	51.670394000000002	51.603265999999998	0103000020E610000001000000050000003DB665C0592E4340F564FED137CD49403DB665C0592E4340A2B77878CFD549404A95287B4B394340A2B77878CFD549404A95287B4B394340F564FED137CD49403DB665C0592E4340F564FED137CD4940
14629	Нижнее Турово	1	4	1307	38.501379999999997	38.687637000000002	51.577537999999997	51.509794999999997	0103000020E610000001000000050000002A6F47382D40434008556AF640C149402A6F47382D4043403F19E3C3ECC9494081423D7D045843403F19E3C3ECC9494081423D7D0458434008556AF640C149402A6F47382D40434008556AF640C14940
54329	Нижнедевицкий	1	4	1307	38.249240999999998	38.282702999999998	51.637873999999996	51.619928000000002	0103000020E6100000010000000500000042E90B21E71F4340F6EFFACC59CF494042E90B21E71F4340FE7BF0DAA5D1494094BDA59C2F244340FE7BF0DAA5D1494094BDA59C2F244340F6EFFACC59CF494042E90B21E71F4340F6EFFACC59CF4940
13762	Нижнедевицк	1	4	1307	38.302106999999999	38.445324999999997	51.693418000000001	51.495420000000003	0103000020E6100000010000000500000043723271AB26434065E42CEC69BF494043723271AB264340973AC8EBC1D84940AC8BDB6800394340973AC8EBC1D84940AC8BDB680039434065E42CEC69BF494043723271AB26434065E42CEC69BF4940
45587	Михнево	1	4	1307	38.532749000000003	38.577044999999998	51.496490999999999	51.445425999999998	0103000020E6100000010000000500000005FD851E31444340E0641BB803B9494005FD851E3144434011E15F048DBF494000A94D9CDC49434011E15F048DBF494000A94D9CDC494340E0641BB803B9494005FD851E31444340E0641BB803B94940
46263	Лебяжье	1	4	1307	38.330170000000003	38.361961000000001	51.341822999999998	51.325077	0103000020E61000000100000005000000670FB402432A434045D7851F9CA94940670FB402432A4340A30227DBC0AB4940B7B6F0BC542E4340A30227DBC0AB4940B7B6F0BC542E434045D7851F9CA94940670FB402432A434045D7851F9CA94940
19644	Кучугуры	1	4	1307	38.236449	38.359338000000001	51.616466000000003	51.578456000000003	0103000020E610000001000000050000000116F9F5431E43406616A1D80ACA49400116F9F5431E4340488C9E5BE8CE4940E31A9FC9FE2D4340488C9E5BE8CE4940E31A9FC9FE2D43406616A1D80ACA49400116F9F5431E43406616A1D80ACA4940
45349	Курбатово	1	4	1307	38.555152999999997	38.608288000000002	51.656618000000002	51.636153	0103000020E610000001000000050000005DA3E5400F4743404B2025766DD149405DA3E5400F47434083FB010F0CD449404E469561DC4D434083FB010F0CD449404E469561DC4D43404B2025766DD149405DA3E5400F4743404B2025766DD14940
45431	Глазово	1	4	1307	38.445324999999997	38.576873999999997	51.514845999999999	51.491658000000001	0103000020E61000000100000005000000AC8BDB68003943408C683BA6EEBE4940AC8BDB6800394340FB3C4679E6C14940D3F4D901D7494340FB3C4679E6C14940D3F4D901D74943408C683BA6EEBE4940AC8BDB68003943408C683BA6EEBE4940
13870	Вязноватовка	1	4	1307	38.437510000000003	38.490681000000002	51.609738	51.524366999999998	0103000020E6100000010000000500000024D6E25300384340020D36751EC3494024D6E25300384340719010E50BCE494061E28FA2CE3E4340719010E50BCE494061E28FA2CE3E4340020D36751EC3494024D6E25300384340020D36751EC34940
54412	Верхнетурово	1	4	1307	38.534877999999999	38.630772999999998	51.651980000000002	51.577537999999997	0103000020E61000000100000005000000C9ACDEE1764443403F19E3C3ECC94940C9ACDEE176444340B3D2A41474D3494093196F2BBD504340B3D2A41474D3494093196F2BBD5043403F19E3C3ECC94940C9ACDEE1764443403F19E3C3ECC94940
48978	Щучье	1	4	1011	39.721696000000001	39.752355999999999	50.948470999999998	50.927219999999998	0103000020E61000000100000005000000B7D3D68860DC43403B191C25AF764940B7D3D68860DC43402A1A6B7F6779494085798F334DE043402A1A6B7F6779494085798F334DE043403B191C25AF764940B7D3D68860DC43403B191C25AF764940
54388	Троицкое	1	4	1011	39.214300999999999	39.251930999999999	51.093594000000003	51.071176000000001	0103000020E61000000100000005000000034015376E9B43404B21904B1C894940034015376E9B4340098D60E3FA8B49409EEC66463FA04340098D60E3FA8B49409EEC66463FA043404B21904B1C894940034015376E9B43404B21904B1C894940
13499	Тресоруково	1	4	1011	39.496586999999998	39.535511	51.223022	51.198397999999997	0103000020E61000000100000005000000334FAE2990BF4340C0CB0C1B65994940334FAE2990BF4340EE2422FC8B9C4940FAD2DB9F8BC44340EE2422FC8B9C4940FAD2DB9F8BC44340C0CB0C1B65994940334FAE2990BF4340C0CB0C1B65994940
12624	Сторожевое 2-е	1	4	1011	39.649687	39.671039999999998	51.134656	51.095806000000003	0103000020E6100000010000000500000074D190F128D343405B61FA5E438C494074D190F128D34340E71A66683C914940672783A3E4D54340E71A66683C914940672783A3E4D543405B61FA5E438C494074D190F128D343405B61FA5E438C4940
13118	Старая Хворостань	1	4	1011	39.278574999999996	39.332473999999998	51.199651000000003	51.161071	0103000020E61000000100000005000000D93D7958A8A34340C1AA7AF99D944940D93D7958A8A343408ECEF9298E99494099620E828EAA43408ECEF9298E99494099620E828EAA4340C1AA7AF99D944940D93D7958A8A34340C1AA7AF99D944940
12427	Средний Икорец	1	4	1011	39.735098999999998	39.784002999999998	51.114835999999997	51.050203000000003	0103000020E6100000010000000500000041295AB917DE43409F94490D6D86494041295AB917DE4340A43330F2B28E4940A27BD6355AE44340A43330F2B28E4940A27BD6355AE443409F94490D6D86494041295AB917DE43409F94490D6D864940
48282	Солонцы	1	4	1011	39.762802999999998	39.775604000000001	51.019226000000003	51.013089000000001	0103000020E6100000010000000500000035255987A3E14340FB777DE6AC81494035255987A3E14340D09D60FF75824940CA52EBFD46E34340D09D60FF75824940CA52EBFD46E34340FB777DE6AC81494035255987A3E14340FB777DE6AC814940
11685	Селявное	1	4	1011	39.216214000000001	39.367849999999997	51.154235	50.978440999999997	0103000020E61000000100000005000000FB777DE6AC9B43406308008E3D7D4940FB777DE6AC9B43400473F4F8BD934940B3EA73B515AF43400473F4F8BD934940B3EA73B515AF43406308008E3D7D4940FB777DE6AC9B43406308008E3D7D4940
49078	Пухово	1	4	1011	39.410870000000003	39.442858999999999	50.863447999999998	50.849432	0103000020E610000001000000050000002A745E6397B4434083161230BA6C49402A745E6397B44340F7E5CC76856E4940A0DE8C9AAFB84340F7E5CC76856E4940A0DE8C9AAFB8434083161230BA6C49402A745E6397B4434083161230BA6C4940
54429	Прияр	1	4	1011	39.841971999999998	39.871049999999997	50.797505000000001	50.778139000000003	0103000020E61000000100000005000000E8120EBDC5EB4340FF5E0A0F9A634940E8120EBDC5EB4340C0B2D2A4146649402497FF907EEF4340C0B2D2A4146649402497FF907EEF4340FF5E0A0F9A634940E8120EBDC5EB4340FF5E0A0F9A634940
13467	Почепское	1	4	1011	39.453684000000003	39.506891000000003	51.200198999999998	51.180734999999999	0103000020E61000000100000005000000F75B3B5112BA43400C1F115322974940F75B3B5112BA434090D8EE1EA099494081D1E5CDE1C0434090D8EE1EA099494081D1E5CDE1C043400C1F115322974940F75B3B5112BA43400C1F115322974940
46694	Петропавловка	1	4	1011	39.823349999999998	39.868445000000001	50.874890999999998	50.850557999999999	0103000020E61000000100000005000000AF94658863E94340F3ACA415DF6C4940AF94658863E943404948A46DFC6F4940F7AFAC3429EF43404948A46DFC6F4940F7AFAC3429EF4340F3ACA415DF6C4940AF94658863E94340F3ACA415DF6C4940
54327	Петровское	1	4	1011	39.144995999999999	39.979692	51.280698000000001	50.769896000000003	0103000020E6100000010000000500000081069B3A8F9243401EA9BEF38B62494081069B3A8F924340BC067DE9EDA349409013268C66FD4340BC067DE9EDA349409013268C66FD43401EA9BEF38B62494081069B3A8F9243401EA9BEF38B624940
12120	Переезжее	1	4	1011	39.753407000000003	39.770707999999999	50.922342999999998	50.908118000000002	0103000020E61000000100000005000000EBC9FCA36FE043405874EB353D744940EBC9FCA36FE04340E658DE550F764940FE614B8FA6E24340E658DE550F764940FE614B8FA6E243405874EB353D744940EBC9FCA36FE043405874EB353D744940
54426	Новозадонский	1	4	1011	39.30433	39.321756999999998	51.128145000000004	51.116996	0103000020E6100000010000000500000089981249F4A64340A4E194B9F98E494089981249F4A64340AE122C0E67904940292158552FA94340AE122C0E67904940292158552FA94340A4E194B9F98E494089981249F4A64340A4E194B9F98E4940
54437	Никольский	1	4	1011	39.540703999999998	39.585664000000001	50.951745000000003	50.939867	0103000020E610000001000000050000007F68E6C935C5434079CBD58F4D7849407F68E6C935C54340D690B8C7D2794940E738B709F7CA4340D690B8C7D2794940E738B709F7CA434079CBD58F4D7849407F68E6C935C5434079CBD58F4D784940
11784	Нижний Икорец	1	4	1011	39.693677999999998	39.737470999999999	51.010317999999998	50.968232	0103000020E6100000010000000500000033FAD170CAD843406878B306EF7B494033FAD170CAD84340B247A81952814940CC5F217365DE4340B247A81952814940CC5F217365DE43406878B306EF7B494033FAD170CAD843406878B306EF7B4940
54334	Нижнемарьино	1	4	1011	39.466538999999997	39.523797000000002	51.249273000000002	51.207208000000001	0103000020E610000001000000050000007EA7C98CB7BB43401BBCAFCA859A49407EA7C98CB7BB43404E637B2DE89F4940185FB4C70BC343404E637B2DE89F4940185FB4C70BC343401BBCAFCA859A49407EA7C98CB7BB43401BBCAFCA859A4940
10206	Лиски	1	4	1011	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
12272	Копанище	1	4	1011	39.313941999999997	39.358677999999998	51.012199000000003	51.001441999999997	0103000020E61000000100000005000000A06B5F402FA84340A06B5F402F804940A06B5F402FA843409F05A1BC8F814940B8E52329E9AD43409F05A1BC8F814940B8E52329E9AD4340A06B5F402F804940A06B5F402FA84340A06B5F402F804940
12026	Колыбелка	1	4	1011	39.778587000000002	39.833644	50.853071999999997	50.820984000000003	0103000020E610000001000000050000009E0B23BDA8E343400745F300166949409E0B23BDA8E3434010919A76316D4940D940BAD8B4EA434010919A76316D4940D940BAD8B4EA43400745F300166949409E0B23BDA8E343400745F30016694940
49237	Коломыцево	1	4	1011	39.515065999999997	39.540928000000001	50.887030000000003	50.866711000000002	0103000020E6100000010000000500000009A4C4AEEDC14340AF0AD462F06E494009A4C4AEEDC143401349F4328A714940CFBEF2203DC543401349F4328A714940CFBEF2203DC54340AF0AD462F06E494009A4C4AEEDC14340AF0AD462F06E4940
49068	Ковалево	1	4	1011	39.385213999999998	39.407645000000002	50.903522000000002	50.868831999999998	0103000020E610000001000000050000000DFB3DB14EB14340F0DB10E3356F49400DFB3DB14EB14340B79BE09BA673494060B01BB62DB44340B79BE09BA673494060B01BB62DB44340F0DB10E3356F49400DFB3DB14EB14340F0DB10E3356F4940
12714	Залужное	1	4	1011	39.504277000000002	39.541845000000002	50.954802999999998	50.942041000000003	0103000020E61000000100000005000000009013268CC04340DE3EABCC94784940009013268CC04340B48F15FC367A494025404D2D5BC54340B48F15FC367A494025404D2D5BC54340DE3EABCC94784940009013268CC04340DE3EABCC94784940
49389	Ермоловка	1	4	1011	39.415649000000002	39.449668000000003	51.200367999999997	51.175907000000002	0103000020E61000000100000005000000BCCE86FC33B543409911DE1E84964940BCCE86FC33B543401C959BA8A5994940640795B88EB943401C959BA8A5994940640795B88EB943409911DE1E84964940BCCE86FC33B543409911DE1E84964940
54276	Дракино	1	4	1011	39.376285000000003	39.431728999999997	51.158099	51.130400000000002	0103000020E61000000100000005000000D97C5C1B2AB04340FFB27BF2B0904940D97C5C1B2AB04340E14389963C9449400DDE57E542B74340E14389963C9449400DDE57E542B74340FFB27BF2B0904940D97C5C1B2AB04340FFB27BF2B0904940
49426	Добрино	1	4	1011	39.511194000000003	39.543255000000002	51.239331999999997	51.223382999999998	0103000020E61000000100000005000000AAF413CE6EC14340BEBD6BD0979C4940AAF413CE6EC143407171546EA29E4940BA313D6189C543407171546EA29E4940BA313D6189C54340BEBD6BD0979C4940AAF413CE6EC14340BEBD6BD0979C4940
54440	Дивногорье	1	4	1011	39.256117000000003	39.305579000000002	50.964703	50.943430999999997	0103000020E610000001000000050000008E791D71C8A043402B84D558C27849408E791D71C8A0434032AD4D637B7B494015AC71361DA7434032AD4D637B7B494015AC71361DA743402B84D558C27849408E791D71C8A043402B84D558C2784940
45408	Давыдовка	1	4	1011	39.415109999999999	39.446857000000001	51.172536000000001	51.137081000000002	0103000020E610000001000000050000000C1F115322B5434095F3C5DE8B9149400C1F115322B54340FBB0DEA8159649408D7E349C32B94340FBB0DEA8159649408D7E349C32B9434095F3C5DE8B9149400C1F115322B5434095F3C5DE8B914940
13386	Бодеевка	1	4	1011	39.270670000000003	39.297215000000001	51.127189000000001	51.110460000000003	0103000020E6100000010000000500000011018750A5A2434012C2A38D238E494011018750A5A243409AB4A9BA47904940B97020240BA643409AB4A9BA47904940B97020240BA6434012C2A38D238E494011018750A5A2434012C2A38D238E4940
13183	Аношкино	1	4	1011	39.231225000000002	39.354258000000002	51.244154000000002	51.196575000000003	0103000020E610000001000000050000004182E2C7989D4340091B9E5E299949404182E2C7989D434003983270409F4940562C7E5358AD434003983270409F4940562C7E5358AD4340091B9E5E299949404182E2C7989D4340091B9E5E29994940
54315	Лиски	1	4	7318	39.431334	39.605606999999999	51.004072000000001	50.958905000000001	0103000020E6100000010000000500000091D3D7F335B74340467C2766BD7A494091D3D7F335B74340276A696E85804940459DB98784CD4340276A696E85804940459DB98784CD4340467C2766BD7A494091D3D7F335B74340467C2766BD7A4940
48252	Старина	1	4	1039	39.458731999999998	39.516089999999998	51.312545999999998	51.287024000000002	0103000020E6100000010000000500000078D0ECBAB7BA43406495D233BDA4494078D0ECBAB7BA4340703FE08101A8494075E5B33C0FC24340703FE08101A8494075E5B33C0FC243406495D233BDA4494078D0ECBAB7BA43406495D233BDA44940
45728	Отдел N1 совхоза Степной	1	4	1039	39.113796999999998	39.797272	51.474426999999999	51.142415	0103000020E6100000010000000500000003B16CE6908E4340DCBA9BA73A92494003B16CE6908E434071AB2006BABC49401D0247020DE6434071AB2006BABC49401D0247020DE64340DCBA9BA73A92494003B16CE6908E4340DCBA9BA73A924940
9546	Олень-Колодезь	1	4	1039	39.224640000000001	39.262881999999998	51.388103999999998	51.352539999999998	0103000020E61000000100000005000000CDAFE600C19C43401344DD0720AD4940CDAFE600C19C434030B95164ADB14940815A0C1EA6A1434030B95164ADB14940815A0C1EA6A143401344DD0720AD4940CDAFE600C19C43401344DD0720AD4940
15316	Нововоронеж	1	4	1039	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
48183	Мосальское	1	4	1039	39.502443999999997	39.556649	51.359727999999997	51.321001000000003	0103000020E610000001000000050000002409C21550C04340DD7D8E8F16A949402409C21550C043404DBA2D910BAE4940F12C414640C743404DBA2D910BAE4940F12C414640C74340DD7D8E8F16A949402409C21550C04340DD7D8E8F16A94940
48186	Можайское	1	4	1039	39.638593	39.681874000000001	51.338307	51.296486999999999	0103000020E610000001000000050000002E3A596ABDD1434036583849F3A549402E3A596ABDD143400281CEA44DAB494011FFB0A547D743400281CEA44DAB494011FFB0A547D7434036583849F3A549402E3A596ABDD1434036583849F3A54940
27475	Михайловский	1	4	1039	39.721983999999999	39.738315	51.302444999999999	51.29589	0103000020E610000001000000050000001D1EC2F869DC4340529B38B9DFA549401D1EC2F869DC43405BEB8B84B6A64940B8921D1B81DE43405BEB8B84B6A64940B8921D1B81DE4340529B38B9DFA549401D1EC2F869DC4340529B38B9DFA54940
9875	Левая Россошь	1	4	1039	39.389912000000002	39.423707	51.363788999999997	51.308205000000001	0103000020E61000000100000005000000B328ECA2E8B143405ABBED4273A74940B328ECA2E8B1434080D250A390AE49400B0BEE073CB6434080D250A390AE49400B0BEE073CB643405ABBED4273A74940B328ECA2E8B143405ABBED4273A74940
48117	Круглое	1	4	1039	39.284567000000003	39.315837000000002	51.332870999999997	51.314183999999997	0103000020E61000000100000005000000AB4203B16CA4434096766A2E37A84940AB4203B16CA44340B66455849BAA4940F2EEC8586DA84340B66455849BAA4940F2EEC8586DA8434096766A2E37A84940AB4203B16CA4434096766A2E37A84940
9694	Красный Лог	1	4	1039	39.748367000000002	39.797272	51.416665000000002	51.366898999999997	0103000020E61000000100000005000000EC33677DCADF4340B1F7E28BF6AE4940EC33677DCADF4340A5315A4755B549401D0247020DE64340A5315A4755B549401D0247020DE64340B1F7E28BF6AE4940EC33677DCADF4340B1F7E28BF6AE4940
9626	Кондрашкино	1	4	1039	39.664914000000003	39.699624999999997	51.403193000000002	51.382669	0103000020E610000001000000050000008753E6E61BD54340B5183C4CFBB049408753E6E61BD54340F27C06D49BB34940643BDF4F8DD94340F27C06D49BB34940643BDF4F8DD94340B5183C4CFBB049408753E6E61BD54340B5183C4CFBB04940
9656	Коломенское	1	4	1039	39.657286999999997	39.684066000000001	51.447266999999997	51.428043000000002	0103000020E61000000100000005000000008BFCFA21D443401024EF1CCAB64940008BFCFA21D443403ECA880B40B949401C2785798FD743403ECA880B40B949401C2785798FD743401024EF1CCAB64940008BFCFA21D443401024EF1CCAB64940
54308	Колодезный	1	4	1039	39.113796999999998	39.797272	51.474426999999999	51.142415	0103000020E6100000010000000500000003B16CE6908E4340DCBA9BA73A92494003B16CE6908E434071AB2006BABC49401D0247020DE6434071AB2006BABC49401D0247020DE64340DCBA9BA73A92494003B16CE6908E4340DCBA9BA73A924940
54300	Колодезная	1	4	1039	39.265352	39.328781999999997	51.366123000000002	51.333883999999998	0103000020E61000000100000005000000CFF6E80DF7A143402E54FEB5BCAA4940CFF6E80DF7A143401EA8531EDDAE4940B9C1508715AA43401EA8531EDDAE4940B9C1508715AA43402E54FEB5BCAA4940CFF6E80DF7A143402E54FEB5BCAA4940
47797	Каширское	1	4	1039	39.562766000000003	39.652113	51.436017	51.392938000000001	0103000020E610000001000000050000007FA65EB708C8434086ADD9CA4BB249407FA65EB708C8434001C0B167CFB74940F225547078D3434001C0B167CFB74940F225547078D3434086ADD9CA4BB249407FA65EB708C8434086ADD9CA4BB24940
54439	Камено-Верховка	1	4	1039	39.125897999999999	39.174576999999999	51.375326999999999	51.345345000000002	0103000020E61000000100000005000000DF50F86C1D904340276BD44334AC4940DF50F86C1D904340242713B70AB0494020D1048A58964340242713B70AB0494020D1048A58964340276BD44334AC4940DF50F86C1D904340276BD44334AC4940
47934	Имени Дзержинского	1	4	1039	39.21987	39.255830000000003	51.463974999999998	51.423000000000002	0103000020E610000001000000050000008EAF3DB3249C4340A01A2FDD24B649408EAF3DB3249C4340AF94658863BB4940F8AA9509BFA04340AF94658863BB4940F8AA9509BFA04340A01A2FDD24B649408EAF3DB3249C4340A01A2FDD24B64940
48224	Ильича	1	4	1039	39.683202999999999	39.713540000000002	51.221966999999999	51.208291000000003	0103000020E61000000100000005000000B9C3263273D743408C868C47A99A4940B9C3263273D7434047E5266A699C4940A5315A4755DB434047E5266A699C4940A5315A4755DB43408C868C47A99A4940B9C3263273D743408C868C47A99A4940
9332	Запрудское	1	4	1039	39.712057000000001	39.768614999999997	51.363709999999998	51.334778999999997	0103000020E61000000100000005000000A6F10BAF24DB43409C31CC09DAAA4940A6F10BAF24DB4340349D9D0C8EAE4940861BF0F961E24340349D9D0C8EAE4940861BF0F961E243409C31CC09DAAA4940A6F10BAF24DB43409C31CC09DAAA4940
9185	Данково	1	4	1039	39.512362000000003	39.549470999999997	51.321176000000001	51.275328999999999	0103000020E6100000010000000500000049DBF81395C14340F8510DFB3DA3494049DBF81395C143404B21904B1CA94940DA8CD31055C643404B21904B1CA94940DA8CD31055C64340F8510DFB3DA3494049DBF81395C14340F8510DFB3DA34940
47857	Боево	1	4	1039	39.301769999999998	39.352893000000002	51.431114999999998	51.381646000000003	0103000020E61000000100000005000000FB743C66A0A643401A53B0C6D9B04940FB743C66A0A6434053E8BCC62EB7494061FE0A992BAD434053E8BCC62EB7494061FE0A992BAD43401A53B0C6D9B04940FB743C66A0A643401A53B0C6D9B04940
9105	Бирюченское	1	4	1039	39.515084000000002	39.545833000000002	51.433591	51.409514000000001	0103000020E61000000100000005000000B058C345EEC1434088A06AF46AB44940B058C345EEC14340836BEEE87FB74940EE0912DBDDC54340836BEEE87FB74940EE0912DBDDC5434088A06AF46AB44940B058C345EEC1434088A06AF46AB44940
8490	Шевченково	1	4	872	39.734416000000003	39.823889000000001	50.027377000000001	49.839899000000003	0103000020E610000001000000050000005FD4EE5701DE4340B87878CF81EB48405FD4EE5701DE4340D0D4EB16810349405F44DB3175E94340D0D4EB16810349405F44DB3175E94340B87878CF81EB48405FD4EE5701DE4340B87878CF81EB4840
8791	Фисенково	1	4	872	39.807881000000002	39.849570999999997	49.912168999999999	49.887996000000001	0103000020E61000000100000005000000A70705A568E743404A7D59DAA9F14840A70705A568E7434067B62BF4C1F44840A45016BEBEEC434067B62BF4C1F44840A45016BEBEEC43404A7D59DAA9F14840A70705A568E743404A7D59DAA9F14840
8727	Титаревка	1	4	872	40.129460000000002	40.185504999999999	49.750165000000003	49.728530999999997	0103000020E61000000100000005000000F111312592104440A38FF98040DD4840F1113125921044404BCD1E6805E048404B1FBAA0BE1744404BCD1E6805E048404B1FBAA0BE174440A38FF98040DD4840F111312592104440A38FF98040DD4840
8633	Талы	1	4	872	40.023961	40.120342000000001	49.886823999999997	49.835779000000002	0103000020E6100000010000000500000092B06F271103444080D767CEFAEA484092B06F271103444069A7E67283F14840E92ADD5D670F444069A7E67283F14840E92ADD5D670F444080D767CEFAEA484092B06F271103444080D767CEFAEA4840
48832	Софиевка	1	4	872	39.594647999999999	39.612515000000002	49.973348000000001	49.947640999999997	0103000020E61000000100000005000000DF50F86C1DCC4340A3ACDF4C4CF94840DF50F86C1DCC434042D0D1AA96FC48409CA73AE466CE434042D0D1AA96FC48409CA73AE466CE4340A3ACDF4C4CF94840DF50F86C1DCC4340A3ACDF4C4CF94840
54402	Соленый	1	4	872	39.641674000000002	39.664177000000002	49.844203	49.826225999999998	0103000020E61000000100000005000000C558A65F22D243406D8D08C6C1E94840C558A65F22D24340B1170AD80EEC4840B1E07EC003D54340B1170AD80EEC4840B1E07EC003D543406D8D08C6C1E94840C558A65F22D243406D8D08C6C1E94840
8517	Смаглеевка	1	4	872	39.872407000000003	39.913648000000002	49.819251999999999	49.783552	0103000020E6100000010000000500000097E65608ABEF4340925B936E4BE4484097E65608ABEF43405F97E13FDDE848402507EC6AF2F443405F97E13FDDE848402507EC6AF2F44340925B936E4BE4484097E65608ABEF4340925B936E4BE44840
8584	Скнаровка	1	4	872	39.920403999999998	39.960675000000002	49.832793000000002	49.805928999999999	0103000020E61000000100000005000000C58D5BCCCFF54340F1F274AE28E74840C58D5BCCCFF543403BAB05F698EA4840DB8AFD65F7FA43403BAB05F698EA4840DB8AFD65F7FA4340F1F274AE28E74840C58D5BCCCFF54340F1F274AE28E74840
8765	Рудаевка	1	4	872	40.086502000000003	40.118113999999998	49.787030000000001	49.757474999999999	0103000020E61000000100000005000000F1845E7F120B4440D044D8F0F4E04840F1845E7F120B4440467C2766BDE4484091990B5C1E0F4440467C2766BDE4484091990B5C1E0F4440D044D8F0F4E04840F1845E7F120B4440D044D8F0F4E04840
54316	Писаревка	1	4	872	40.144317999999998	40.210191000000002	49.919373	49.872770000000003	0103000020E61000000100000005000000B01C210379124440087767EDB6EF4840B01C210379124440A7E9B303AEF54840EF74E789E71A4440A7E9B303AEF54840EF74E789E71A4440087767EDB6EF4840B01C210379124440087767EDB6EF4840
7593	Пасюковка	1	4	872	39.692762000000002	39.713332999999999	49.819665000000001	49.809237000000003	0103000020E61000000100000005000000AEF4DA6CACD8434049DBF81395E74840AEF4DA6CACD84340825660C8EAE848402B14E97E4EDB4340825660C8EAE848402B14E97E4EDB434049DBF81395E74840AEF4DA6CACD8434049DBF81395E74840
47565	Пасеково	1	4	872	39.711590000000001	39.734110999999999	49.870342999999998	49.858643000000001	0103000020E610000001000000050000009014916115DB43403CF88903E8ED48409014916115DB4340B9A6406667EF484022516859F7DD4340B9A6406667EF484022516859F7DD43403CF88903E8ED48409014916115DB43403CF88903E8ED4840
54346	Охровый Завод	1	4	872	39.812533999999999	39.856712999999999	49.774698999999998	49.767164000000001	0103000020E61000000100000005000000AC71361D01E843409355116E32E24840AC71361D01E84340389F3A5629E348406E8786C5A8ED4340389F3A5629E348406E8786C5A8ED43409355116E32E24840AC71361D01E843409355116E32E24840
6561	Осиковка	1	4	872	40.260505999999999	40.280700000000003	49.676409	49.661011000000002	0103000020E61000000100000005000000B534B74258214440ECA529029CD44840B534B742582144402BDCF29194D648405DFE43FAED2344402BDCF29194D648405DFE43FAED234440ECA529029CD44840B534B74258214440ECA529029CD44840
47296	Новопавловка	1	4	872	39.999006000000001	40.019855999999997	49.746493000000001	49.731431000000001	0103000020E61000000100000005000000FF40B96DDFFF4340EA23F0879FDD4840FF40B96DDFFF4340B2D826158DDF48408F5033A48A024440B2D826158DDF48408F5033A48A024440EA23F0879FDD4840FF40B96DDFFF4340EA23F0879FDD4840
8255	Новомарковка	1	4	872	39.702356000000002	39.771237999999997	49.738948000000001	49.707039000000002	0103000020E610000001000000050000001F1329CDE6D943408FFF024180DA48401F1329CDE6D94340E9B81AD995DE48405AB741EDB7E24340E9B81AD995DE48405AB741EDB7E243408FFF024180DA48401F1329CDE6D943408FFF024180DA4840
54293	Новобелая	1	4	872	39.253467000000001	39.339230000000001	49.860472000000001	49.801707999999998	0103000020E61000000100000005000000C0CE4D9B71A043408578245E9EE64840C0CE4D9B71A04340D68F4DF223EE48403AE97DE36BAB4340D68F4DF223EE48403AE97DE36BAB43408578245E9EE64840C0CE4D9B71A043408578245E9EE64840
54376	Михайловка	1	4	872	39.590640999999998	39.654592000000001	49.908769999999997	49.874656999999999	0103000020E610000001000000050000009F56D11F9ACB4340D61BB5C2F4EF48409F56D11F9ACB4340FFCA4A9352F44840931CB0ABC9D34340FFCA4A9352F44840931CB0ABC9D34340D61BB5C2F4EF48409F56D11F9ACB4340D61BB5C2F4EF4840
47324	Митрофановка	1	4	872	39.666890000000002	39.714545999999999	49.986885000000001	49.949326999999997	0103000020E61000000100000005000000C503CAA65CD54340DA1A118C83F94840C503CAA65CD54340DCF4673F52FE48406ABE4A3E76DB4340DCF4673F52FE48406ABE4A3E76DB4340DA1A118C83F94840C503CAA65CD54340DA1A118C83F94840
47463	Куликовка	1	4	872	39.482627999999998	39.552264999999998	49.859600999999998	49.824181000000003	0103000020E6100000010000000500000023111AC1C6BD4340077E54C37EE9484023111AC1C6BD4340F04DD36707EE4840DBDC989EB0C64340F04DD36707EE4840DBDC989EB0C64340077E54C37EE9484023111AC1C6BD4340077E54C37EE94840
47547	Кузнецовский	1	4	872	40.294974000000003	40.307712000000002	49.709090000000003	49.691645000000001	0103000020E61000000100000005000000CD9541B5C125444091B8C7D287D84840CD9541B5C1254440D8F50B76C3DA48401B4B581B63274440D8F50B76C3DA48401B4B581B6327444091B8C7D287D84840CD9541B5C125444091B8C7D287D84840
7431	Колещатовка	1	4	872	39.870573999999998	39.910530999999999	49.593023000000002	49.569239000000003	0103000020E61000000100000005000000BB5F05F86EEF4340CB4DD4D2DCC84840BB5F05F86EEF43404E637B2DE8CB4840417FA1478CF443404E637B2DE8CB4840417FA1478CF44340CB4DD4D2DCC84840BB5F05F86EEF4340CB4DD4D2DCC84840
47234	Касьяновка	1	4	872	39.715497999999997	39.821283000000001	49.762393000000003	49.735478000000001	0103000020E610000001000000050000003C2D3F7095DB4340B876A22424DE48403C2D3F7095DB434084D9041896E1484061E124CD1FE9434084D9041896E1484061E124CD1FE94340B876A22424DE48403C2D3F7095DB4340B876A22424DE4840
6847	Кантемировка	1	4	872	39.821652	39.933734999999999	49.740537000000003	49.662813	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
47126	Зайцевка	1	4	872	39.963980999999997	40.025281999999997	49.696266000000001	49.673419000000003	0103000020E61000000100000005000000917BBABA63FB4340A5C0029832D64840917BBABA63FB43408BA8893E1FD94840B796C9703C0344408BA8893E1FD94840B796C9703C034440A5C0029832D64840917BBABA63FB4340A5C0029832D64840
7995	Евдокиевка	1	4	872	39.709505999999998	39.750495999999998	49.971905	49.963799000000002	0103000020E610000001000000050000006B28B517D1DA4340717500C45DFB48406B28B517D1DA4340D1E80E6267FC4840B0E3BF4010E04340D1E80E6267FC4840B0E3BF4010E04340717500C45DFB48406B28B517D1DA4340717500C45DFB4840
54374	Гартмашевка	1	4	872	39.972217999999998	39.979117000000002	49.605074999999999	49.601804999999999	0103000020E61000000100000005000000904AB1A371FC4340DEC83CF207CD4840904AB1A371FC43404850FC1873CD484094FAB2B453FD43404850FC1873CD484094FAB2B453FD4340DEC83CF207CD4840904AB1A371FC4340DEC83CF207CD4840
7710	Гармашевка	1	4	872	40.051360000000003	40.100282	49.667799000000002	49.639809999999997	0103000020E610000001000000050000004A29E8F692064440AED3484BE5D148404A29E8F69206444098A608707AD548405130630AD60C444098A608707AD548405130630AD60C4440AED3484BE5D148404A29E8F692064440AED3484BE5D14840
47117	Волоконовка	1	4	872	39.362234999999998	39.424776000000001	49.861365999999997	49.830781999999999	0103000020E61000000100000005000000B83B6BB75DAE4340800D881057EA4840B83B6BB75DAE434073F1B73D41EE484017105A0F5FB6434073F1B73D41EE484017105A0F5FB64340800D881057EA4840B83B6BB75DAE4340800D881057EA4840
46887	Валентиновка	1	4	872	39.736429000000001	39.751762999999997	49.945067000000002	49.9208	0103000020E61000000100000005000000BA69334E43DE434012143FC6DCF54840BA69334E43DE4340B1C398F4F7F84840E2AB1DC539E04340B1C398F4F7F84840E2AB1DC539E0434012143FC6DCF54840BA69334E43DE434012143FC6DCF54840
7399	Бугаевка	1	4	872	39.724167000000001	39.984831	49.844163000000002	49.631326999999999	0103000020E61000000100000005000000D5EB1681B1DC4340780AB952CFD04840D5EB1681B1DC434023BF7E880DEC4840228B34F10EFE434023BF7E880DEC4840228B34F10EFE4340780AB952CFD04840D5EB1681B1DC4340780AB952CFD04840
47106	Бондарево	1	4	872	39.426276000000001	39.457662999999997	49.818776	49.758854999999997	0103000020E61000000100000005000000EC88433690B64340FAB31F2922E14840EC88433690B64340F65FE7A6CDE848406CCB80B394BA4340F65FE7A6CDE848406CCB80B394BA4340FAB31F2922E14840EC88433690B64340FAB31F2922E14840
6545	Ярки	1	4	801	39.250683000000002	39.276778999999998	50.746723000000003	50.727848000000002	0103000020E61000000100000005000000E3546B6116A04340C13A8E1F2A5D4940E3546B6116A04340E415889E945F49401B9C887E6DA34340E415889E945F49401B9C887E6DA34340C13A8E1F2A5D4940E3546B6116A04340C13A8E1F2A5D4940
5908	Щербаково	1	4	801	39.328907999999998	39.362676	50.813226999999998	50.799748000000001	0103000020E6100000010000000500000046B247A819AA43404D8578245E66494046B247A819AA4340B29C84D217684940A585CB2A6CAE4340B29C84D217684940A585CB2A6CAE43404D8578245E66494046B247A819AA43404D8578245E664940
6485	Тхоревка	1	4	801	39.318522999999999	39.346012000000002	50.715029000000001	50.695822	0103000020E610000001000000050000000C03965CC5A843402DEBFEB1105949400C03965CC5A843408658FD11865B49400403081F4AAC43408658FD11865B49400403081F4AAC43402DEBFEB1105949400C03965CC5A843402DEBFEB110594940
6371	Трехстенки	1	4	801	39.422809000000001	39.458157	50.666057000000002	50.648983000000001	0103000020E610000001000000050000002CBAF59A1EB643407A54FCDF115349402CBAF59A1EB64340CD22145B415549407CB779E3A4BA4340CD22145B415549407CB779E3A4BA43407A54FCDF115349402CBAF59A1EB643407A54FCDF11534940
6551	Тимирязево	1	4	801	39.364624999999997	39.393236000000002	50.724085000000002	50.710608000000001	0103000020E61000000100000005000000E9263108ACAE43405323F433F55A4940E9263108ACAE4340184339D1AE5C494010CEA78E55B24340184339D1AE5C494010CEA78E55B243405323F433F55A4940E9263108ACAE43405323F433F55A4940
6324	Татарино	1	4	801	39.097771000000002	39.155676999999997	50.598878999999997	50.572536999999997	0103000020E61000000100000005000000A5BF97C2838C4340FE5F75E448494940A5BF97C2838C43406EA12B11A84C4940A4DE5339ED9343406EA12B11A84C4940A4DE5339ED934340FE5F75E448494940A5BF97C2838C4340FE5F75E448494940
6228	Сончино	1	4	801	39.485852999999999	39.524624000000003	50.698622999999998	50.684061	0103000020E61000000100000005000000EDD45C6E30BE43400ABC934F8F574940EDD45C6E30BE4340E09D7C7A6C5949402E5915E126C34340E09D7C7A6C5949402E5915E126C343400ABC934F8F574940EDD45C6E30BE43400ABC934F8F574940
6425	Пилипы	1	4	801	39.483058999999997	39.518408000000001	50.651336000000001	50.632097000000002	0103000020E61000000100000005000000EC8497E0D4BD43402A73F38DE8504940EC8497E0D4BD43408E5A61FA5E5349400DFE7E315BC243408E5A61FA5E5349400DFE7E315BC243402A73F38DE8504940EC8497E0D4BD43402A73F38DE8504940
6013	Ольхов Лог	1	4	801	39.247107	39.276949000000002	50.586711000000001	50.557231000000002	0103000020E610000001000000050000006CCEC133A19F4340A0A86C58534749406CCEC133A19F43400B9A9658194B494078D4981073A343400B9A9658194B494078D4981073A34340A0A86C58534749406CCEC133A19F4340A0A86C5853474940
54456	Новиковское	1	4	801	39.583499000000003	39.602885000000001	50.707574000000001	50.686532	0103000020E61000000100000005000000D61F6118B0CA434028D4D347E0574940D61F6118B0CA4340FDBFEAC8915A4940DE1FEF552BCD4340FDBFEAC8915A4940DE1FEF552BCD434028D4D347E0574940D61F6118B0CA434028D4D347E0574940
6092	Марки	1	4	801	39.628163999999998	39.742410999999997	50.791117	50.765453000000001	0103000020E6100000010000000500000024438EAD67D0434003D0285DFA61494024438EAD67D04340A2276552436549406798DA5207DF4340A2276552436549406798DA5207DF434003D0285DFA61494024438EAD67D0434003D0285DFA614940
54379	Крутец	1	4	801	39.465685000000001	39.486382999999996	50.809106	50.780776000000003	0103000020E610000001000000050000006F9EEA909BBB434038C0CC77F06349406F9EEA909BBB4340AA7F10C990674940492A53CC41BE4340AA7F10C990674940492A53CC41BE434038C0CC77F06349406F9EEA909BBB434038C0CC77F0634940
6063	Коденцово	1	4	801	39.410420999999999	39.479430000000001	50.620738000000003	50.580654000000003	0103000020E61000000100000005000000BA4BE2AC88B443405325CADE524A4940BA4BE2AC88B4434036B1C057744F4940535C55F65DBD434036B1C057744F4940535C55F65DBD43405325CADE524A4940BA4BE2AC88B443405325CADE524A4940
5933	Карпенково	1	4	801	39.31908	39.362136999999997	50.628024000000003	50.603938999999997	0103000020E6100000010000000500000062670A9DD7A84340B4E386DF4D4D494062670A9DD7A84340338D261763504940F5D555815AAE4340338D261763504940F5D555815AAE4340B4E386DF4D4D494062670A9DD7A84340B4E386DF4D4D4940
47411	Каменка	1	4	801	39.399785000000001	39.452157	50.728257999999997	50.693750000000001	0103000020E610000001000000050000003737A6272CB34340CDCCCCCCCC5849403737A6272CB343407286E28E375D494028D4D347E0B943407286E28E375D494028D4D347E0B94340CDCCCCCCCC5849403737A6272CB34340CDCCCCCCCC584940
5815	Евдаково	1	4	801	39.372467	39.411588999999999	50.759703999999999	50.742618999999998	0103000020E610000001000000050000006CEBA7FFACAF4340B131AF230E5F49406CEBA7FFACAF4340F8510DFB3D6149405932C7F2AEB44340F8510DFB3D6149405932C7F2AEB44340B131AF230E5F49406CEBA7FFACAF4340B131AF230E5F4940
5787	Дегтярное	1	4	801	39.255155999999999	39.281737	50.653992000000002	50.632617000000003	0103000020E6100000010000000500000068B0A9F3A8A0434063F20698F950494068B0A9F3A8A043403EEC8502B65349405D8940F50FA443403EEC8502B65349405D8940F50FA4434063F20698F950494068B0A9F3A8A0434063F20698F9504940
5677	Волчанское	1	4	801	39.517302999999998	39.547063999999999	50.784545999999999	50.766751999999997	0103000020E61000000100000005000000B48F15FC36C243404012F6ED24624940B48F15FC36C24340931ADA006C644940D368723106C64340931ADA006C644940D368723106C643404012F6ED24624940B48F15FC36C243404012F6ED24624940
6166	Верхние Марки	1	4	801	39.574831000000003	39.641790999999998	50.783748000000003	50.751976999999997	0103000020E610000001000000050000000EDDEC0F94C943400E2C47C8406049400EDDEC0F94C943401827BEDA51644940FEEE1D3526D243401827BEDA51644940FEEE1D3526D243400E2C47C8406049400EDDEC0F94C943400E2C47C840604940
46395	Ясеновка	1	4	561	40.786146000000002	40.818485000000003	50.547668000000002	50.508792999999997	0103000020E61000000100000005000000CCF09F6EA064444084B7072120414940CCF09F6EA06444406A882AFC194649401FA2D11DC46844406A882AFC194649401FA2D11DC468444084B7072120414940CCF09F6EA064444084B7072120414940
4619	Юнаково	1	4	561	40.576174000000002	40.60942	50.516584000000002	50.498240000000003	0103000020E610000001000000050000001B67D311C04944408FC70C54C63F49401B67D311C049444085D1AC6C1F424940A0C37C79014E444085D1AC6C1F424940A0C37C79014E44408FC70C54C63F49401B67D311C04944408FC70C54C63F4940
46359	Ширяево	1	4	561	40.909717999999998	40.997042999999998	50.349944000000001	50.304318000000002	0103000020E61000000100000005000000904AB1A371744440C5CA68E4F3264940904AB1A37174444039B709F7CA2C494055DAE21A9F7F444039B709F7CA2C494055DAE21A9F7F4440C5CA68E4F3264940904AB1A371744440C5CA68E4F3264940
46339	Четвериково	1	4	561	40.820632000000003	40.837575000000001	50.378777999999997	50.355604999999997	0103000020E610000001000000050000008A0629780A694440A4A5F276842D49408A0629780A694440DE3829CC7B3049403E7958A8356B4440DE3829CC7B3049403E7958A8356B4440A4A5F276842D49408A0629780A694440A4A5F276842D4940
5263	Хрещатое	1	4	561	40.684339999999999	40.718943000000003	50.371361	50.346041	0103000020E610000001000000050000001DACFF73985744409E094D124B2C49401DACFF73985744404301DBC1882F494015580053065C44404301DBC1882F494015580053065C44409E094D124B2C49401DACFF73985744409E094D124B2C4940
54407	Хвощеватое	1	4	561	40.740278000000004	40.763948999999997	50.582135000000001	50.548332000000002	0103000020E6100000010000000500000062F9F36DC15E4440D6AC33BE2F46494062F9F36DC15E4440B16D5166834A4940EC67B114C9614440B16D5166834A4940EC67B114C9614440D6AC33BE2F46494062F9F36DC15E4440D6AC33BE2F464940
54368	Советское	1	4	561	41.367086	41.427183999999997	50.363914999999999	50.343753	0103000020E61000000100000005000000E4688EACFCAE444071732A19002C4940E4688EACFCAE44400DC347C4942E4940EEAF1EF7ADB644400DC347C4942E4940EEAF1EF7ADB6444071732A19002C4940E4688EACFCAE444071732A19002C4940
5148	Скрипниково	1	4	561	41.359746999999999	41.418604999999999	50.274580999999998	50.250458999999999	0103000020E61000000100000005000000C4EA8F300CAE444093FE5E0A0F204940C4EA8F300CAE44402E8D5F7825234940967840D994B544402E8D5F7825234940967840D994B5444093FE5E0A0F204940C4EA8F300CAE444093FE5E0A0F204940
46173	Семеновка	1	4	561	40.572921999999998	40.610894000000002	50.432834999999997	50.411256000000002	0103000020E61000000100000005000000579412825549444053245F09A4344940579412825549444036C82423673749404CA94BC6314E444036C82423673749404CA94BC6314E444053245F09A4344940579412825549444053245F09A4344940
45868	Пришиб	1	4	561	40.993738	41.021532000000001	50.471519999999998	50.447631000000001	0103000020E610000001000000050000006F6589CE327F444080D6FCF84B3949406F6589CE327F444078B471C45A3C4940A3E8818FC182444078B471C45A3C4940A3E8818FC182444080D6FCF84B3949406F6589CE327F444080D6FCF84B394940
46084	Пригородный	1	4	561	40.999226	41.035032999999999	50.383333	50.356150999999997	0103000020E610000001000000050000000DA837A3E67F444006B8205B962D49400DA837A3E67F4440213D450E11314940F0A31AF67B844440213D450E11314940F0A31AF67B84444006B8205B962D49400DA837A3E67F444006B8205B962D4940
54467	Попасное	1	4	561	40.645316999999999	40.686279999999996	50.495134999999998	50.478209999999997	0103000020E61000000100000005000000C34659BF99524440614F3BFC353D4940C34659BF995244406F0D6C95603F49400EF3E505D85744406F0D6C95603F49400EF3E505D8574440614F3BFC353D4940C34659BF99524440614F3BFC353D4940
46192	Пирогово	1	4	561	40.593510999999999	40.625599000000001	50.460844000000002	50.437654999999999	0103000020E610000001000000050000007B681F2BF84B444027F73B14053849407B681F2BF84B44406747AAEFFC3A494085B4C6A0135044406747AAEFFC3A494085B4C6A01350444027F73B14053849407B681F2BF84B444027F73B1405384940
54434	Перевалочное	1	4	561	40.690573999999998	40.733612000000001	50.323548000000002	50.296056	0103000020E61000000100000005000000E4BB94BA645844406DE4BA29E5254940E4BB94BA64584440D65757056A29494001FA7DFFE65D4440D65757056A29494001FA7DFFE65D44406DE4BA29E5254940E4BB94BA645844406DE4BA29E5254940
54285	Отдел N1 совозах Забродненский	1	4	561	40.502692000000003	41.537973000000001	50.635987999999998	50.176997	0103000020E61000000100000005000000FDFA213658404440BC3E73D6A7164940FDFA2136584044400053060E68514940C5909C4CDCC444400053060E68514940C5909C4CDCC44440BC3E73D6A7164940FDFA213658404440BC3E73D6A7164940
4488	Новомеловатка	1	4	561	40.748748999999997	40.818458	50.477488000000001	50.420233000000003	0103000020E61000000100000005000000D3F4D901D75F444099D9E731CA354940D3F4D901D75F4440C11DA8531E3D49402593533BC3684440C11DA8531E3D49402593533BC368444099D9E731CA354940D3F4D901D75F444099D9E731CA354940
4661	Новая Криуша	1	4	561	41.242068000000003	41.349291000000001	50.273907000000001	50.238407000000002	0103000020E610000001000000050000003EB48F15FC9E44409911DE1E841E49403EB48F15FC9E44409F9273620F234940C1E44691B5AC44409F9273620F234940C1E44691B5AC44409911DE1E841E49403EB48F15FC9E44409911DE1E841E4940
46140	Медвежье	1	4	561	40.683469000000002	40.713095000000003	50.562289999999997	50.539636999999999	0103000020E61000000100000005000000386A85E97B574440145B41D312454940386A85E97B574440156F641EF947494077F86BB2465B4440156F641EF947494077F86BB2465B4440145B41D312454940386A85E97B574440145B41D312454940
45895	Манино	1	4	561	41.344780999999998	41.417464000000002	50.529589000000001	50.463276	0103000020E610000001000000050000001EA4A7C821AC4440C782C2A04C3B49401EA4A7C821AC444022A98592C9434940F1A0D9756FB5444022A98592C9434940F1A0D9756FB54440C782C2A04C3B49401EA4A7C821AC4440C782C2A04C3B4940
54348	Лесково	1	4	561	40.71199	40.742578000000002	50.384641999999999	50.355483999999997	0103000020E610000001000000050000001E8A027D225B44402920ED7F802D49401E8A027D225B44408255F5F23B314940535DC0CB0C5F44408255F5F23B314940535DC0CB0C5F44402920ED7F802D49401E8A027D225B44402920ED7F802D4940
4295	Коренное	1	4	561	41.419297	41.461365000000001	50.589112999999998	50.557293999999999	0103000020E61000000100000005000000CC272B86ABB54440E620E86855474940CC272B86ABB544400053060E684B4940704221020EBB44400053060E684B4940704221020EBB4440E620E86855474940CC272B86ABB54440E620E86855474940
4202	Калачеевский	1	4	561	41.128377	41.173859	50.349415	50.331133000000001	0103000020E61000000100000005000000804754A86E9044402DD0EE90622A4940804754A86E904440ADDD76A1B92C4940C18EFF0241964440ADDD76A1B92C4940C18EFF02419644402DD0EE90622A4940804754A86E9044402DD0EE90622A4940
3503	Калач	1	4	561	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
53581	Ильинка	1	4	561	41.105524000000003	41.142867000000003	50.465505999999998	50.432369999999999	0103000020E61000000100000005000000B87878CF818D4440C1E270E657374940B87878CF818D4440BF0B5BB3953B4940BD56427749924440BF0B5BB3953B4940BD56427749924440C1E270E657374940B87878CF818D4440C1E270E657374940
54411	Залесный	1	4	561	40.905369999999998	40.918934999999998	50.416991000000003	50.402276999999998	0103000020E61000000100000005000000C763062AE37344406C770FD07D334940C763062AE3734440F9DC09F65F3549402B137EA99F754440F9DC09F65F3549402B137EA99F7544406C770FD07D334940C763062AE37344406C770FD07D334940
54307	Заброды	1	4	561	40.502692000000003	41.537973000000001	50.635987999999998	50.176997	0103000020E61000000100000005000000FDFA213658404440BC3E73D6A7164940FDFA2136584044400053060E68514940C5909C4CDCC444400053060E68514940C5909C4CDCC44440BC3E73D6A7164940FDFA213658404440BC3E73D6A7164940
45488	Хомутовка	1	4	297	41.246012	41.273096000000002	51.553390999999998	51.536515000000001	0103000020E6100000010000000500000037363B527D9F44401F680586ACC4494037363B527D9F44404B732B84D5C649408F554ACFF4A244404B732B84D5C649408F554ACFF4A244401F680586ACC4494037363B527D9F44401F680586ACC44940
45421	Тихвинка	1	4	297	41.497225	41.521462	51.371414000000001	51.360415000000003	0103000020E6100000010000000500000076E09C11A5BF444072FE261422AE494076E09C11A5BF444066A3737E8AAF4940AA0D4E44BFC2444066A3737E8AAF4940AA0D4E44BFC2444072FE261422AE494076E09C11A5BF444072FE261422AE4940
2642	Старогольское	1	4	297	41.470014999999997	41.505400000000002	51.475819000000001	51.458565	0103000020E6100000010000000500000091D0967329BC44408D0B0742B2BA494091D0967329BC444060E811A3E7BC4940FFB27BF2B0C0444060E811A3E7BC4940FFB27BF2B0C044408D0B0742B2BA494091D0967329BC44408D0B0742B2BA4940
2304	Средний Карачан	1	4	297	41.753982000000001	41.793660000000003	51.394972000000003	51.358857	0103000020E61000000100000005000000E7E26F7B82E044406878B306EFAD4940E7E26F7B82E04440F96A47718EB249405A12A0A696E54440F96A47718EB249405A12A0A696E544406878B306EFAD4940E7E26F7B82E044406878B306EFAD4940
2455	Савельевский	1	4	297	41.587048000000003	41.596732000000003	51.447239000000003	51.437505000000002	0103000020E6100000010000000500000053978C6324CB4440126BF12900B8494053978C6324CB4440753FA7203FB94940043DD4B661CC4440753FA7203FB94940043DD4B661CC4440126BF12900B8494053978C6324CB4440126BF12900B84940
2097	Посевкино	1	4	297	42.230232999999998	42.253337000000002	51.675511	51.653942000000001	0103000020E61000000100000005000000E0BA6246781D45408CBD175FB4D34940E0BA6246781D45404C8BFA2477D64940F2EEC8586D2045404C8BFA2477D64940F2EEC8586D2045408CBD175FB4D34940E0BA6246781D45408CBD175FB4D34940
54477	Поляна	1	4	297	41.127191000000003	42.372633999999998	51.732514000000002	51.245291999999999	0103000020E610000001000000050000003BAC70CB4790444037FC6EBA659F49403BAC70CB479044405BEECC04C3DD494057B08D78B22F45405BEECC04C3DD494057B08D78B22F454037FC6EBA659F49403BAC70CB4790444037FC6EBA659F4940
3166	Новомакарово	1	4	297	41.219861999999999	41.252811999999999	51.473737	51.439031999999997	0103000020E610000001000000050000000BD12170249C4440E0F2583332B849400BD12170249C4440DCF3FC69A3BC4940A704C4245CA04440DCF3FC69A3BC4940A704C4245CA04440E0F2583332B849400BD12170249C4440E0F2583332B84940
54457	Новогольско	1	4	297	41.435484000000002	41.495905	51.507249999999999	51.473300000000002	0103000020E6100000010000000500000034F790F0BDB7444031992A1895BC494034F790F0BDB74440B0726891EDC049402176A6D079BF4440B0726891EDC049402176A6D079BF444031992A1895BC494034F790F0BDB7444031992A1895BC4940
54335	Новоголь-Елань	1	4	297	41.244646000000003	41.271236000000002	51.529141000000003	51.494444999999999	0103000020E61000000100000005000000728C648F509F4440DA5548F949BF4940728C648F509F444083FC6CE4BAC34940BABF7ADCB7A2444083FC6CE4BAC34940BABF7ADCB7A24440DA5548F949BF4940728C648F509F4440DA5548F949BF4940
47371	Новая Жизнь	1	4	297	41.200988000000002	41.225135000000002	51.428049000000001	51.421180999999997	0103000020E61000000100000005000000B9718BF9B999444029594E42E9B54940B9718BF9B9994440F20A444FCAB64940AD174339D19C4440F20A444FCAB64940AD174339D19C444029594E42E9B54940B9718BF9B999444029594E42E9B54940
2368	Нижний Карачан	1	4	297	41.722056000000002	41.794541000000002	51.371526000000003	51.313339999999997	0103000020E61000000100000005000000B7F0BC546CDC4440AA436E861BA84940B7F0BC546CDC44408ECEF9298EAF4940632AFD84B3E544408ECEF9298EAF4940632AFD84B3E54440AA436E861BA84940B7F0BC546CDC4440AA436E861BA84940
54373	Малые Алабухи 2-е	1	4	297	42.138675999999997	42.172201999999999	51.576279	51.526155000000003	0103000020E61000000100000005000000BB5E9A22C01145403ED00A0C59C34940BB5E9A22C0114540902FA182C3C94940242713B70A164540902FA182C3C94940242713B70A1645403ED00A0C59C34940BB5E9A22C01145403ED00A0C59C34940
1754	Малые Алабухи 1-е	1	4	297	42.138675999999997	42.172201999999999	51.576279	51.526155000000003	0103000020E61000000100000005000000BB5E9A22C01145403ED00A0C59C34940BB5E9A22C0114540902FA182C3C94940242713B70A164540902FA182C3C94940242713B70A1645403ED00A0C59C34940BB5E9A22C01145403ED00A0C59C34940
1741	Малая Грибановка	1	4	297	42.045512000000002	42.100704999999998	51.526434999999999	51.495482000000003	0103000020E61000000100000005000000ACC95356D3054540DBE044F46BBF4940ACC95356D3054540213CDA3862C3494097C5C4E6E30C4540213CDA3862C3494097C5C4E6E30C4540DBE044F46BBF4940ACC95356D3054540DBE044F46BBF4940
45350	Листопадовка	1	4	297	41.413654999999999	41.478180999999999	51.452992000000002	51.398546000000003	0103000020E61000000100000005000000D769A4A5F2B44440CFF9298E03B34940D769A4A5F2B44440C1AC50A4FBB94940C748F60835BD4440C1AC50A4FBB94940C748F60835BD4440CFF9298E03B34940D769A4A5F2B44440CFF9298E03B34940
45388	Лавровка	1	4	297	41.508257	41.539985000000001	51.396028999999999	51.387407000000003	0103000020E61000000100000005000000467BBC900EC14440E99E758D96B14940467BBC900EC1444040A20914B1B2494050AA7D3A1EC5444040A20914B1B2494050AA7D3A1EC54440E99E758D96B14940467BBC900EC14440E99E758D96B14940
3025	Кутки	1	4	297	41.534362000000002	41.556164000000003	51.361162	51.333844999999997	0103000020E61000000100000005000000D21C59F965C444407077D66EBBAA4940D21C59F965C444406B47718E3AAE4940359BC76130C744406B47718E3AAE4940359BC76130C744407077D66EBBAA4940D21C59F965C444407077D66EBBAA4940
49604	Красовка	1	4	297	41.479807000000001	41.499363000000002	51.451022000000002	51.427121999999997	0103000020E6100000010000000500000029B2D6506ABD444078B306EFABB6494029B2D6506ABD444065E3C116BBB949408EEA7420EBBF444065E3C116BBB949408EEA7420EBBF444078B306EFABB6494029B2D6506ABD444078B306EFABB64940
3131	Краснореченка	1	4	297	41.255766999999999	41.297189000000003	51.397050999999998	51.363114000000003	0103000020E61000000100000005000000B1321AF9BCA04440215C01857AAE4940B1321AF9BCA044400BEC3191D2B2494090DD054A0AA644400BEC3191D2B2494090DD054A0AA64440215C01857AAE4940B1321AF9BCA04440215C01857AAE4940
49451	Кирсановка	1	4	297	41.763027999999998	41.807971000000002	51.483032000000001	51.430008999999998	0103000020E6100000010000000500000055F7C8E6AAE144402AFEEF880AB7494055F7C8E6AAE14440F37519FED3BD4940E78EFE976BE74440F37519FED3BD4940E78EFE976BE744402AFEEF880AB7494055F7C8E6AAE144402AFEEF880AB74940
1289	Грибановский	1	4	297	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
48003	Власовка	1	4	297	42.292845	42.317647999999998	51.568379999999998	51.557048000000002	0103000020E6100000010000000500000008E6E8F17B254540AF264F594DC7494008E6E8F17B254540A9D903ADC0C84940E5D18DB0A8284540A9D903ADC0C84940E5D18DB0A8284540AF264F594DC7494008E6E8F17B254540AF264F594DC74940
2249	Верхний Карачан	1	4	297	41.739311999999998	41.799678999999998	51.428100000000001	51.390155999999998	0103000020E610000001000000050000002AC58EC6A1DE4440492BBEA1F0B149402AC58EC6A1DE444074B515FBCBB649402426A8E15BE6444074B515FBCBB649402426A8E15BE64440492BBEA1F0B149402AC58EC6A1DE4440492BBEA1F0B14940
54351	Болшие Алабухи	1	4	297	42.231589	42.265033000000003	51.593940000000003	51.569907999999998	0103000020E61000000100000005000000828E56B5A41D454048DDCEBEF2C84940828E56B5A41D4540A4E4D53906CC49402EAEF199EC214540A4E4D53906CC49402EAEF199EC21454048DDCEBEF2C84940828E56B5A41D454048DDCEBEF2C84940
54309	Семилуки	1	4	7319	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
19578	Солонцы	1	4	1550	40.681825000000003	40.714928	50.625926	50.609186999999999	0103000020E61000000100000005000000304CA60A46574440FD12F1D6F94D4940304CA60A46574440A9DBD9571E504940527FBDC2825B4440A9DBD9571E504940527FBDC2825B4440FD12F1D6F94D4940304CA60A46574440FD12F1D6F94D4940
54323	Совхоз Краснопольский	1	4	1550	41.236328	41.259208000000001	50.653461	50.644424999999998	0103000020E610000001000000050000008690F3FE3F9E4440C6DCB5847C5249408690F3FE3F9E4440111B2C9CA4534940486E4DBA2DA14440111B2C9CA4534940486E4DBA2DA14440C6DCB5847C5249408690F3FE3F9E4440C6DCB5847C524940
54324	Совхоз Воробьевский	1	4	1550	40.810580000000002	40.835498999999999	50.698469000000003	50.680498999999998	0103000020E610000001000000050000005665DF15C1674440F8FA5A971A5749405665DF15C16744408A22A46E675949409C6B98A1F16A44408A22A46E675949409C6B98A1F16A4440F8FA5A971A5749405665DF15C1674440F8FA5A971A574940
19453	Рудня	1	4	1550	40.93965	40.988294000000003	50.578383000000002	50.519950999999999	0103000020E61000000100000005000000DCD7817346784440E1421EC18D424940DCD7817346784440FCC74274084A4940A16AF46A807E4440FCC74274084A4940A16AF46A807E4440E1421EC18D424940DCD7817346784440E1421EC18D424940
18987	Первомайский	1	4	1550	40.848390000000002	40.874693000000001	50.657304000000003	50.636896	0103000020E610000001000000050000007120240B986C4440037AE1CE855149407120240B986C4440D7C39789225449402385B2F0F56F4440D7C39789225449402385B2F0F56F4440037AE1CE855149407120240B986C4440037AE1CE85514940
54350	Новотулучеево	1	4	1550	40.951562000000003	40.959412999999998	50.581316999999999	50.557043	0103000020E61000000100000005000000E50E9BC8CC7944409DBB5D2F4D474940E50E9BC8CC794440EECD6F98684A4940BA2D910BCE7A4440EECD6F98684A4940BA2D910BCE7A44409DBB5D2F4D474940E50E9BC8CC7944409DBB5D2F4D474940
19294	Никольское	1	4	1550	41.119788999999997	41.180408	50.635348	50.539248000000001	0103000020E61000000100000005000000D4B5F63E558F44407A37161406454940D4B5F63E558F44401DCA501553514940E8F7FD9B179744401DCA501553514940E8F7FD9B179744407A37161406454940D4B5F63E558F44407A37161406454940
18685	Нижний Бык	1	4	1550	41.122034999999997	41.136318000000003	50.704470999999998	50.676955	0103000020E61000000100000005000000D2FBC6D79E8F44408DEE2076A6564940D2FBC6D79E8F44407EFD101B2C5A494096ED43DE729144407EFD101B2C5A494096ED43DE729144408DEE2076A6564940D2FBC6D79E8F44408DEE2076A6564940
19162	Мужичье	1	4	1550	41.040647999999997	41.081502999999998	50.777915999999998	50.721724000000002	0103000020E61000000100000005000000EB5223F433854440815EB873615C4940EB5223F4338544407F8461C09263494050C3B7B06E8A44407F8461C09263494050C3B7B06E8A4440815EB873615C4940EB5223F433854440815EB873615C4940
19128	Лещаное	1	4	1550	40.877620999999998	40.905945000000003	50.610900999999998	50.585715999999998	0103000020E6100000010000000500000033A48AE255704440395FECBDF84A494033A48AE255704440FE0B0401324E4940C47C7901F6734440FE0B0401324E4940C47C7901F6734440395FECBDF84A494033A48AE255704440395FECBDF84A4940
19008	Краснополье	1	4	1550	41.270347000000001	41.312764999999999	50.632846000000001	50.611804999999997	0103000020E610000001000000050000002EC901BB9AA24440BF4351A04F4E49402EC901BB9AA24440C4B3041901514940AE2AFBAE08A84440C4B3041901514940AE2AFBAE08A84440BF4351A04F4E49402EC901BB9AA24440BF4351A04F4E4940
18922	Квашино	1	4	1550	40.811146000000001	40.846215999999998	50.662489000000001	50.641838	0103000020E61000000100000005000000FF23D3A1D36744403FAA61BF27524940FF23D3A1D3674440D97A8670CC5449400CAD4ECE506C4440D97A8670CC5449400CAD4ECE506C44403FAA61BF27524940FF23D3A1D36744403FAA61BF27524940
19659	Каменка	1	4	1550	40.636575999999998	40.670316999999997	50.629783000000003	50.612335999999999	0103000020E6100000010000000500000091B586527B514440EC14AB06614E494091B586527B514440D449B6BA9C504940F6798CF2CC554440D449B6BA9C504940F6798CF2CC554440EC14AB06614E494091B586527B514440EC14AB06614E4940
54332	Затон	1	4	1550	40.718386000000002	40.758262000000002	50.661844000000002	50.649532000000001	0103000020E61000000100000005000000BFF38B12F45B44404DDA54DD23534940BFF38B12F45B4440E486DF4DB754494058E6ADBA0E614440E486DF4DB754494058E6ADBA0E6144404DDA54DD23534940BFF38B12F45B44404DDA54DD23534940
18591	Елизаветовка	1	4	1550	40.873992000000001	40.948211000000001	50.768175999999997	50.729033999999999	0103000020E610000001000000050000009A7B48F8DE6F444006D671FC505D49409A7B48F8DE6F44403AC95697536249408E5A61FA5E7944403AC95697536249408E5A61FA5E79444006D671FC505D49409A7B48F8DE6F444006D671FC505D4940
54438	Гринев	1	4	1550	40.742766000000003	40.767901000000002	50.616622999999997	50.607134000000002	0103000020E61000000100000005000000564ACFF4125F444014252191B64D4940564ACFF4125F44400F7BA180ED4E494069C878944A6244400F7BA180ED4E494069C878944A62444014252191B64D4940564ACFF4125F444014252191B64D4940
49004	Высокое	1	4	1550	41.121712000000002	41.130873999999999	50.787917	50.772863999999998	0103000020E61000000100000005000000F0C34142948F4440BC202235ED624940F0C34142948F4440317BD976DA644940C7F2AE7AC0904440317BD976DA644940C7F2AE7AC0904440BC202235ED624940F0C34142948F4440BC202235ED624940
18777	Воробьевка	1	4	1550	40.902577000000001	40.974603999999999	50.675561999999999	50.616410999999999	0103000020E61000000100000005000000978FA4A48773444084F23E8EE64E4940978FA4A487734440CE35CCD0785649408046E9D2BF7C4440CE35CCD0785649408046E9D2BF7C444084F23E8EE64E4940978FA4A48773444084F23E8EE64E4940
18672	Верхний Бык	1	4	1550	41.144942	41.221001999999999	50.727631000000002	50.704783999999997	0103000020E610000001000000050000008EE89E758D9244403D5FB35C365A49408EE89E758D92444024473A03235D4940E02C25CB499C444024473A03235D4940E02C25CB499C44403D5FB35C365A49408EE89E758D9244403D5FB35C365A4940
18531	Верхнетолучеево	1	4	1550	41.025224000000001	41.041249999999998	50.770603000000001	50.740172999999999	0103000020E6100000010000000500000083893F8A3A834440EC3026FDBD5E494083893F8A3A83444089997D1EA3624940E17A14AE4785444089997D1EA3624940E17A14AE47854440EC3026FDBD5E494083893F8A3A834440EC3026FDBD5E4940
18489	Березовка	1	4	1550	40.956744999999998	40.998175000000003	50.723878999999997	50.696170000000002	0103000020E6100000010000000500000046CEC29E767A4440693A3B191C59494046CEC29E767A44406EA12B11A85C4940A857CA32C47F44406EA12B11A85C4940A857CA32C47F4440693A3B191C59494046CEC29E767A4440693A3B191C594940
19253	Банное	1	4	1550	41.133955999999998	41.154060000000001	50.813898999999999	50.795211000000002	0103000020E610000001000000050000002E8D5F7825914440B1355B79C96549402E8D5F7825914440A19FA9D72D68494096CFF23CB8934440A19FA9D72D68494096CFF23CB8934440B1355B79C96549402E8D5F7825914440B1355B79C9654940
18289	Шукавка	1	4	1102	40.153840000000002	40.213738999999997	51.888648000000003	51.865546000000002	0103000020E6100000010000000500000088687407B113444081971936CAEE494088687407B1134440F2D3B837BFF149409B70AFCC5B1B4440F2D3B837BFF149409B70AFCC5B1B444081971936CAEE494088687407B113444081971936CAEE4940
18321	Углянец	1	4	1102	39.574911999999998	39.615200999999999	51.831158000000002	51.809769000000003	0103000020E61000000100000005000000FA0967B796C943404628B682A6E74940FA0967B796C9434086E7A56263EA4940B6BB07E8BECE434086E7A56263EA4940B6BB07E8BECE43404628B682A6E74940FA0967B796C943404628B682A6E74940
18164	Сухие Гаи	1	4	1102	39.868256000000002	39.905724999999997	51.784159000000002	51.759058000000003	0103000020E6100000010000000500000024473A0323EF434033E202D028E1494024473A0323EF43409AEE75525FE44940B515FBCBEEF343409AEE75525FE44940B515FBCBEEF3434033E202D028E1494024473A0323EF434033E202D028E14940
18069	Правая Хава	1	4	1102	39.752867999999999	39.800379999999997	51.736369000000003	51.709957000000003	0103000020E610000001000000050000003B1A87FA5DE043407C48F8DEDFDA49403B1A87FA5DE04340E564E25641DE4940AD2F12DA72E64340E564E25641DE4940AD2F12DA72E643407C48F8DEDFDA49403B1A87FA5DE043407C48F8DEDFDA4940
45616	Покровка	1	4	1102	40.08475	40.116173000000003	51.921798000000003	51.907465000000002	0103000020E61000000100000005000000022B8716D90A4440E0A128D027F44940022B8716D90A444055C2137AFDF54940D0D6C1C1DE0E444055C2137AFDF54940D0D6C1C1DE0E4440E0A128D027F44940022B8716D90A4440E0A128D027F44940
47235	Подлесный	1	4	1102	39.558086000000003	39.573753000000004	51.820754000000001	51.799906999999997	0103000020E61000000100000005000000802DAF5C6FC74340B56B425A63E64940802DAF5C6FC74340D50792770EE94940AF7D01BD70C94340D50792770EE94940AF7D01BD70C94340B56B425A63E64940802DAF5C6FC74340B56B425A63E64940
17866	Плясоватка	1	4	1102	40.096060000000001	40.120908	51.905498999999999	51.884628999999997	0103000020E61000000100000005000000153AAFB14B0C4440ED0BE8853BF14940153AAFB14B0C4440C5C72764E7F3494092E9D0E9790F4440C5C72764E7F3494092E9D0E9790F4440ED0BE8853BF14940153AAFB14B0C4440ED0BE8853BF14940
45581	Парижская Коммуна	1	4	1102	39.613987999999999	39.648493000000002	51.809925	51.791952999999999	0103000020E610000001000000050000007711A62897CE43400B7C45B75EE549407711A62897CE43403D9B559FABE74940AC5791D101D343403D9B559FABE74940AC5791D101D343400B7C45B75EE549407711A62897CE43400B7C45B75EE54940
47550	Никоново	1	4	1102	39.574283000000001	39.602103999999997	51.808337999999999	51.783718999999998	0103000020E610000001000000050000000BD3F71A82C943407D2079E750E449400BD3F71A82C94340990E9D9E77E7494038656EBE11CD4340990E9D9E77E7494038656EBE11CD43407D2079E750E449400BD3F71A82C943407D2079E750E44940
47279	Нижняя Маза	1	4	1102	40.241380999999997	40.267431999999999	51.816155999999999	51.80444	0103000020E6100000010000000500000019709692E51E444010CCD1E3F7E6494019709692E51E44409337C0CC77E84940B2F336363B2244409337C0CC77E84940B2F336363B22444010CCD1E3F7E6494019709692E51E444010CCD1E3F7E64940
16938	Нижняя Байгора	1	4	1102	39.893571000000001	39.958618000000001	51.964530000000003	51.922559	0103000020E61000000100000005000000B7D3D68860F24340B3D0CE6916F64940B7D3D68860F24340650113B875FB4940B0AD9FFEB3FA4340650113B875FB4940B0AD9FFEB3FA4340B3D0CE6916F64940B7D3D68860F24340B3D0CE6916F64940
17732	Малый Самовец	1	4	1102	40.316785000000003	40.341264000000002	51.944603999999998	51.913331999999997	0103000020E61000000100000005000000836E2F698C284440F4311F10E8F44940836E2F698C284440DCD5ABC8E8F84940ADA6EB89AE2B4440DCD5ABC8E8F84940ADA6EB89AE2B4440F4311F10E8F44940836E2F698C284440F4311F10E8F44940
17579	Малая Приваловка	1	4	1102	39.663485000000001	39.682915999999999	51.866357999999998	51.856090999999999	0103000020E610000001000000050000007B319413EDD4434031B3CF6394ED49407B319413EDD443406150A6D1E4EE494023F59ECA69D743406150A6D1E4EE494023F59ECA69D7434031B3CF6394ED49407B319413EDD4434031B3CF6394ED4940
54279	Краснолесный	1	4	1102	39.570959000000002	39.601447999999998	51.893006	51.862081000000003	0103000020E61000000100000005000000AE2D3C2F15C9434062C092AB58EE4940AE2D3C2F15C94340DE9046054EF249404F1F813FFCCC4340DE9046054EF249404F1F813FFCCC434062C092AB58EE4940AE2D3C2F15C9434062C092AB58EE4940
47638	Вишневка	1	4	1102	39.827832000000001	39.863683999999999	51.851534999999998	51.822446999999997	0103000020E61000000100000005000000884A2366F6E94340BED87BF145E94940884A2366F6E943401E335019FFEC49400B0A83328DEE43401E335019FFEC49400B0A83328DEE4340BED87BF145E94940884A2366F6E94340BED87BF145E94940
17272	Верхняя Хава	1	4	1102	39.884614999999997	39.979117000000002	51.868459999999999	51.818516000000002	0103000020E61000000100000005000000884677103BF143405AA0DD21C5E84940884677103BF143402CF180B229EF494094FAB2B453FD43402CF180B229EF494094FAB2B453FD43405AA0DD21C5E84940884677103BF143405AA0DD21C5E84940
17251	Верхняя Плавица	1	4	1102	40.186512	40.232092000000002	51.960002000000003	51.916137999999997	0103000020E61000000100000005000000E1270EA0DF174440B94F8E0244F54940E1270EA0DF1744401C0C7558E1FA4940E5D4CE30B51D44401C0C7558E1FA4940E5D4CE30B51D4440B94F8E0244F54940E1270EA0DF174440B94F8E0244F54940
17148	Верхняя Маза	1	4	1102	40.125166	40.171483000000002	51.828502999999998	51.801192999999998	0103000020E610000001000000050000001B498270051044405E64027E8DE649401B49827005104440A6D1E4620CEA4940F568AA27F3154440A6D1E4620CEA4940F568AA27F31544405E64027E8DE649401B498270051044405E64027E8DE64940
18054	Верхняя Луговатка	1	4	1102	40.082019000000003	40.111080000000001	51.979849000000002	51.924109000000001	0103000020E6100000010000000500000048533D997F0A44403A78263449F6494048533D997F0A4440580229B16BFD4940AE9E93DE370E4440580229B16BFD4940AE9E93DE370E44403A78263449F6494048533D997F0A44403A78263449F64940
47189	Верхняя Байгора	1	4	1102	39.845061999999999	39.897838	51.938758	51.905098000000002	0103000020E61000000100000005000000D28BDAFD2AEC434067D65240DAF34940D28BDAFD2AEC4340DF6DDE3829F84940938D075BECF24340DF6DDE3829F84940938D075BECF2434067D65240DAF34940D28BDAFD2AEC434067D65240DAF34940
17557	Васильевка 1-я	1	4	1102	40.081561000000001	40.112031999999999	51.792743999999999	51.767803000000001	0103000020E6100000010000000500000085D04197700A4440A662635E47E2494085D04197700A4440D40CA9A278E54940800D8810570E4440D40CA9A278E54940800D8810570E4440A662635E47E2494085D04197700A4440A662635E47E24940
17029	Большая Приваловка	1	4	1102	39.721741000000002	39.817672000000002	51.914555	51.884400999999997	0103000020E610000001000000050000005797530262DC43405CC64D0D34F149405797530262DC434057B2632310F549406E6DE179A9E8434057B2632310F549406E6DE179A9E843405CC64D0D34F149405797530262DC43405CC64D0D34F14940
47408	Богословка	1	4	1102	40.012697000000003	40.076216000000002	51.836171999999998	51.816656999999999	0103000020E61000000100000005000000F0E0270EA00144405586713788E84940F0E0270EA00144405BEA20AF07EB49404AB72572C10944405BEA20AF07EB49404AB72572C10944405586713788E84940F0E0270EA00144405586713788E84940
16793	Русская Журавка	1	4	1430	40.529237000000002	40.575868	50.373159000000001	50.338107000000001	0103000020E61000000100000005000000A56ABB09BE4344403BC61517472B4940A56ABB09BE434440A29A92ACC32F49400E68E90AB6494440A29A92ACC32F49400E68E90AB64944403BC61517472B4940A56ABB09BE4344403BC61517472B4940
47034	Приречное	1	4	1430	40.438344999999998	40.499169999999999	50.231071999999998	50.196815000000001	0103000020E61000000100000005000000BCAE5FB01B3844405E2EE23B31194940BCAE5FB01B384440BA826DC4931D4940799274CDE43F4440BA826DC4931D4940799274CDE43F44405E2EE23B31194940BCAE5FB01B3844405E2EE23B31194940
46903	Осетровка	1	4	1430	40.447113000000002	40.484338999999999	50.156720999999997	50.127063999999997	0103000020E61000000100000005000000E84EB0FF3A394440DD3F16A243104940E84EB0FF3A39444057CC086F0F144940B39602D2FE3D444057CC086F0F144940B39602D2FE3D4440DD3F16A243104940E84EB0FF3A394440DD3F16A243104940
54410	Оробинский	1	4	1430	40.216963999999997	40.241092999999999	50.042952999999997	50.031982999999997	0103000020E610000001000000050000006534F279C51B44409483D904180449406534F279C51B4440EE21E17B7F054940B325AB22DC1E4440EE21E17B7F054940B325AB22DC1E44409483D904180449406534F279C51B44409483D90418044940
46976	Ольховатка	1	4	1430	40.078803999999998	40.118409999999997	50.196002	50.157274999999998	0103000020E61000000100000005000000A165DD3F160A44403CBD529621144940A165DD3F160A4440ADF9F197161949407AC2120F280F4440ADF9F197161949407AC2120F280F44403CBD529621144940A165DD3F160A44403CBD529621144940
16629	Нижний Мамон	1	4	1430	40.489711	40.572508999999997	50.235325000000003	50.112133999999998	0103000020E61000000100000005000000E8BE9CD9AE3E444084622B685A0E4940E8BE9CD9AE3E444032772D211F1E494034D593F94749444032772D211F1E494034D593F94749444084622B685A0E4940E8BE9CD9AE3E444084622B685A0E4940
47130	Мамоновка	1	4	1430	40.487375	40.515501999999998	50.406612000000003	50.384141999999997	0103000020E61000000100000005000000AAF1D24D623E44409082A7902B314940AAF1D24D623E4440A114ADDC0B344940E48233F8FB414440A114ADDC0B344940E48233F8FB4144409082A7902B314940AAF1D24D623E44409082A7902B314940
47004	Лозовое	1	4	1430	40.322723000000003	40.396286000000003	50.320959999999999	50.237036000000003	0103000020E610000001000000050000006155BDFC4E294440C2FC1532571E49406155BDFC4E2944407EA99F37152949406CEEE87FB93244407EA99F37152949406CEEE87FB9324440C2FC1532571E49406155BDFC4E294440C2FC1532571E4940
37645	Дерезовка	1	4	1430	40.276198999999998	40.324367000000002	50.091448	50.065804999999997	0103000020E610000001000000050000000D18247D5A234440E674594C6C0849400D18247D5A2344406EA46C91B40B494069739CDB842944406EA46C91B40B494069739CDB84294440E674594C6C0849400D18247D5A234440E674594C6C084940
46954	Гороховка	1	4	1430	40.106569999999998	40.257344000000003	50.119926	50.094061000000004	0103000020E610000001000000050000000B5EF415A40D44401F6ADB300A0C49400B5EF415A40D444055F833BC590F494032E9EFA5F020444055F833BC590F494032E9EFA5F02044401F6ADB300A0C49400B5EF415A40D44401F6ADB300A0C4940
15955	Верхний Мамон	1	4	1430	40.334257000000001	40.461091000000003	50.184218999999999	50.123413999999997	0103000020E61000000100000005000000C3BAF1EEC82A44402CEFAA07CC0F4940C3BAF1EEC82A4440A226FA7C941749406FBDA607053B4440A226FA7C941749406FBDA607053B44402CEFAA07CC0F4940C3BAF1EEC82A44402CEFAA07CC0F4940
54471	хут.Петропавловка	1	4	1313	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
54421	хут.Луговой	1	4	1313	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
54485	х.Варваровка	1	4	1313	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
54417	пос.Черноземный	1	4	1313	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
54413	пос.Колос	1	4	1313	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
15820	Чулок	1	4	1313	40.625365000000002	40.670901000000001	50.951217	50.923563999999999	0103000020E610000001000000050000001288D7F50B504440A8E15B58377649401288D7F50B5044401A33897AC179494046ED7E15E05544401A33897AC179494046ED7E15E0554440A8E15B58377649401288D7F50B504440A8E15B5837764940
15669	Филиппенково	1	4	1313	40.733010999999998	40.765304999999998	50.756154000000002	50.732796999999998	0103000020E61000000100000005000000DB4DF04DD35D4440AFCDC64ACC5D4940DB4DF04DD35D4440AB5E7EA7C96049408E3BA583F5614440AB5E7EA7C96049408E3BA583F5614440AFCDC64ACC5D4940DB4DF04DD35D4440AFCDC64ACC5D4940
46755	Совхоз Ударник	1	4	1313	40.706079000000003	40.735652000000002	50.930943999999997	50.914268	0103000020E610000001000000050000003AB2F2CB605A4440C1E3DBBB067549403AB2F2CB605A44402634492C29774940569E40D8295E44402634492C29774940569E40D8295E4440C1E3DBBB067549403AB2F2CB605A4440C1E3DBBB06754940
15562	Сериково	1	4	1313	40.853608999999999	40.883487000000002	50.960799999999999	50.94661	0103000020E610000001000000050000001F49490F436D4440850838842A7949401F49490F436D444097FF907EFB7A494078B81D1A1671444097FF907EFB7A494078B81D1A16714440850838842A7949401F49490F436D4440850838842A794940
46540	Пузево	1	4	1313	40.360371000000001	40.425480999999998	50.682805000000002	50.655928000000003	0103000020E61000000100000005000000A2B60DA3202E4440EE43DE72F5534940A2B60DA3202E4440CC457C2766574940E108522976364440CC457C2766574940E108522976364440EE43DE72F5534940A2B60DA3202E4440EE43DE72F5534940
46659	Патокино	1	4	1313	40.769303000000001	40.804220000000001	50.808213000000002	50.794168999999997	0103000020E610000001000000050000007BDB4C85786244409E3F6D54A76549407BDB4C8578624440DD99098673674940026553AEF0664440DD99098673674940026553AEF06644409E3F6D54A76549407BDB4C85786244409E3F6D54A7654940
46397	Отрадное	1	4	1313	40.558782000000001	40.578904999999999	50.892552999999999	50.878346999999998	0103000020E61000000100000005000000F7CB272B8647444015C5ABAC6D704940F7CB272B864744402D793C2D3F724940D53E1D8F194A44402D793C2D3F724940D53E1D8F194A444015C5ABAC6D704940F7CB272B8647444015C5ABAC6D704940
46507	Озерки	1	4	1313	40.451388999999999	40.501694000000001	50.995938000000002	50.973103999999999	0103000020E610000001000000050000001763601DC7394440ABCDFFAB8E7C49401763601DC7394440FD6B79E57A7F4940BA4C4D8237404440FD6B79E57A7F4940BA4C4D8237404440ABCDFFAB8E7C49401763601DC7394440ABCDFFAB8E7C4940
14904	Нижний Кисляй	1	4	1313	40.149303000000003	40.221662999999999	50.868535999999999	50.818058999999998	0103000020E61000000100000005000000EC18575C1C13444067994528B6684940EC18575C1C13444007B309302C6F4940DBDD03745F1C444007B309302C6F4940DBDD03745F1C444067994528B6684940EC18575C1C13444067994528B6684940
15615	Макогоново	1	4	1313	40.803061	40.825043000000001	50.936967000000003	50.922808000000003	0103000020E61000000100000005000000B6D8EDB3CA6644405C3E92921E764940B6D8EDB3CA6644403337DF88EE77494099654F029B6944403337DF88EE77494099654F029B6944405C3E92921E764940B6D8EDB3CA6644405C3E92921E764940
15256	Кучеряевка	1	4	1313	40.889451999999999	40.933478999999998	50.896262999999998	50.870952000000003	0103000020E610000001000000050000004FAE2990D97144406231EA5A7B6F49404FAE2990D9714440B3CEF8BEB87249405B40683D7C774440B3CEF8BEB87249405B40683D7C7744406231EA5A7B6F49404FAE2990D97144406231EA5A7B6F4940
48455	Комсомольский	1	4	1313	40.284157999999998	40.305475000000001	50.850296999999998	50.839706999999997	0103000020E61000000100000005000000C972124A5F244440739CDB847B6B4940C972124A5F24444086713788D66C4940705F07CE1927444086713788D66C4940705F07CE19274440739CDB847B6B4940C972124A5F244440739CDB847B6B4940
46429	Козловка	1	4	1313	40.405358999999997	40.513300999999998	50.885393000000001	50.841481000000002	0103000020E61000000100000005000000D311C0CDE23344404A9A3FA6B56B4940D311C0CDE2334440BD8DCD8E547149408600E0D8B3414440BD8DCD8E547149408600E0D8B34144404A9A3FA6B56B4940D311C0CDE23344404A9A3FA6B56B4940
15022	Клеповка	1	4	1313	40.403103999999999	40.522275	50.770175000000002	50.677782999999998	0103000020E61000000100000005000000827170E9983344407364E597C1564940827170E99833444031992A18956249405B423EE8D942444031992A18956249405B423EE8D94244407364E597C1564940827170E9983344407364E597C1564940
14981	Карайчевка	1	4	1313	40.266317999999998	40.305008000000001	50.897001000000003	50.875078999999999	0103000020E61000000100000005000000062B4EB5162244404C35B39602704940062B4EB5162244405ABDC3EDD07249405A828C800A2744405ABDC3EDD07249405A828C800A2744404C35B39602704940062B4EB5162244404C35B39602704940
14609	Зеленый Гай	1	4	1313	40.516939000000001	40.534914000000001	50.815105000000003	50.806840999999999	0103000020E610000001000000050000007383A10E2B4244403509DE90466749407383A10E2B4244402EE7525C556849401616DC0F784444402EE7525C556849401616DC0F784444403509DE90466749407383A10E2B4244403509DE9046674940
46203	Зеленый	1	4	1313	40.642865	40.677143999999998	50.808126999999999	50.781697999999999	0103000020E610000001000000050000001C5F7B66495244409FAC18AE0E6449401C5F7B6649524440DE019EB470674940605793A7AC564440DE019EB470674940605793A7AC5644409FAC18AE0E6449401C5F7B66495244409FAC18AE0E644940
46676	Елизаветино	1	4	1313	40.793171000000001	40.822195000000001	50.774157000000002	50.752256000000003	0103000020E610000001000000050000005C9198A086654440221CB3EC496049405C9198A086654440187C9A9317634940A5F78DAF3D694440187C9A9317634940A5F78DAF3D694440221CB3EC496049405C9198A086654440221CB3EC49604940
54465	Дмитриевка	1	4	1313	40.513795000000002	40.534483000000002	50.786385000000003	50.774926000000001	0103000020E6100000010000000500000096ECD808C4414440F96871C63063494096ECD808C441444051888043A86449404DA25EF06944444051888043A86449404DA25EF069444440F96871C63063494096ECD808C4414440F96871C630634940
14807	Гвазда	1	4	1313	40.405611	40.499341000000001	50.780383	50.700744999999998	0103000020E61000000100000005000000EDF2AD0FEB334440F2EA1C03B2594940EDF2AD0FEB3344405CAD1397E3634940A646E867EA3F44405CAD1397E3634940A646E867EA3F4440F2EA1C03B2594940EDF2AD0FEB334440F2EA1C03B2594940
14706	Великоархангельское	1	4	1313	40.714028999999996	40.800294000000001	50.869059	50.832391000000001	0103000020E61000000100000005000000A2B2614D655B44400C3ECDC98B6A4940A2B2614D655B4440B1A547533D6F4940AF97A60870664440B1A547533D6F4940AF97A608706644400C3ECDC98B6A4940A2B2614D655B44400C3ECDC98B6A4940
46950	Васильевка	1	4	1313	40.944744	41.008173999999997	50.931165	50.909855	0103000020E61000000100000005000000CE8B135FED784440118DEE2076744940CE8B135FED78444005172B6A30774940B8567BD80B81444005172B6A30774940B8567BD80B814440118DEE2076744940CE8B135FED784440118DEE2076744940
13865	Бутурлиновка	1	4	1313	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
13280	Чигорак	1	4	1273	42.120502999999999	42.174213999999999	51.440767000000001	51.414850000000001	0103000020E61000000100000005000000F2086EA46C0F4540705F07CE19B54940F2086EA46C0F4540F913950D6BB84940AF40F4A44C164540F913950D6BB84940AF40F4A44C164540705F07CE19B54940F2086EA46C0F4540705F07CE19B54940
45640	Ульяновка	1	4	1273	42.000236999999998	42.022281999999997	51.290387000000003	51.278894999999999	0103000020E61000000100000005000000E49F19C4070045404B02D4D4B2A34940E49F19C4070045407F17B6662BA549400DA5F622DA0245407F17B6662BA549400DA5F622DA0245404B02D4D4B2A34940E49F19C4070045404B02D4D4B2A34940
13747	Тюковка	1	4	1273	42.596798999999997	42.632705000000001	51.458004000000003	51.429592999999997	0103000020E610000001000000050000008BA4DDE8634C454096CB46E7FCB649408BA4DDE8634C4540F6B704E09FBA49400282397AFC504540F6B704E09FBA49400282397AFC50454096CB46E7FCB649408BA4DDE8634C454096CB46E7FCB64940
45737	Третьяки	1	4	1273	42.450508999999997	42.502189000000001	51.377715999999999	51.345587000000002	0103000020E61000000100000005000000DEC66647AA3945401D76DF313CAC4940DEC66647AA394540859675FF58B049409AB4A9BA47404540859675FF58B049409AB4A9BA474045401D76DF313CAC4940DEC66647AA3945401D76DF313CAC4940
13830	Танцырей	1	4	1273	42.343060999999999	42.381104999999998	51.349789999999999	51.319954000000003	0103000020E610000001000000050000003BC43F6CE92B4540B91CAF40F4A849403BC43F6CE92B4540E23B31EBC5AC4940C9AB730CC8304540E23B31EBC5AC4940C9AB730CC8304540B91CAF40F4A849403BC43F6CE92B4540B91CAF40F4A84940
54453	Старая Воскресеновка	1	4	1273	42.523434000000002	42.559654000000002	51.410946000000003	51.393521999999997	0103000020E61000000100000005000000A7CEA3E2FF424540D520CCED5EB24940A7CEA3E2FF4245400536E7E099B44940AD8905BEA24745400536E7E099B44940AD8905BEA2474540D520CCED5EB24940A7CEA3E2FF424540D520CCED5EB24940
45809	Петровское	1	4	1273	42.276774000000003	42.307955	51.289338999999998	51.270983999999999	0103000020E610000001000000050000000A3197546D234540A0DE8C9AAFA249400A3197546D2345408A3A730F09A54940E1D1C6116B2745408A3A730F09A54940E1D1C6116B274540A0DE8C9AAFA249400A3197546D234540A0DE8C9AAFA24940
13404	Миролюбие	1	4	1273	42.292350999999996	42.333449000000002	51.503549999999997	51.484479	0103000020E61000000100000005000000F8F9EFC16B254540A54C6A6803BE4940F8F9EFC16B2545404DF38E5374C0494024F1F274AE2A45404DF38E5374C0494024F1F274AE2A4540A54C6A6803BE4940F8F9EFC16B254540A54C6A6803BE4940
13469	Махровка	1	4	1273	42.371250000000003	42.407919	51.574582999999997	51.516387000000002	0103000020E61000000100000005000000EC51B81E852F45402F8A1EF818C24940EC51B81E852F454035EB8CEF8BC94940613596B03634454035EB8CEF8BC94940613596B0363445402F8A1EF818C24940EC51B81E852F45402F8A1EF818C24940
54380	Макашевка	1	4	1273	42.590268000000002	42.631419999999999	51.507452000000001	51.473619999999997	0103000020E610000001000000050000000BF0DDE68D4B4540A25D85949FBC49400BF0DDE68D4B45401825E82FF4C049402905DD5ED25045401825E82FF4C049402905DD5ED2504540A25D85949FBC49400BF0DDE68D4B4540A25D85949FBC4940
45695	Губари	1	4	1273	42.534995000000002	42.568412000000002	51.527572999999997	51.490020000000001	0103000020E61000000100000005000000034356B77A4445406631B1F9B8BE4940034356B77A44454055A0168387C34940B55373B9C148454055A0168387C34940B55373B9C14845406631B1F9B8BE4940034356B77A4445406631B1F9B8BE4940
13586	Горелка	1	4	1273	42.618287000000002	42.667470000000002	51.443747999999999	51.412154000000001	0103000020E610000001000000050000005F454607244F454032755776C1B449405F454607244F45402CD505BCCCB84940D3872EA86F5545402CD505BCCCB84940D3872EA86F55454032755776C1B449405F454607244F454032755776C1B44940
29588	Богана	1	4	1273	42.145341999999999	42.216191999999999	51.489437000000002	51.465663999999997	0103000020E610000001000000050000001C5E10919A1245405776C1E09ABB49401C5E10919A124540E73922DFA5BE494013D4F02DAC1B4540E73922DFA5BE494013D4F02DAC1B45405776C1E09ABB49401C5E10919A1245405776C1E09ABB4940
10327	Шуриновка	1	4	1073	40.377223999999998	40.399430000000002	49.746586000000001	49.728076999999999	0103000020E6100000010000000500000016A243E04830444022FC8BA031DD484016A243E04830444063D34A2190DF48404985B1852033444063D34A2190DF48404985B1852033444022FC8BA031DD484016A243E04830444022FC8BA031DD4840
49319	Филоново	1	4	1073	40.469723000000002	40.502789999999997	50.052132999999998	50.033394999999999	0103000020E61000000100000005000000EA961DE21F3C4440CA6C904946044940EA961DE21F3C44406C054D4BAC064940BF60376C5B4044406C054D4BAC064940BF60376C5B404440CA6C904946044940EA961DE21F3C4440CA6C904946044940
60412	Травкино	1	4	1073	40.188496999999998	41.04663	50.127197000000002	49.578563000000003	0103000020E61000000100000005000000723271AB201844407CD6355A0ECA4840723271AB201844401D93C5FD471049409981CAF8F78544401D93C5FD471049409981CAF8F78544407CD6355A0ECA4840723271AB201844407CD6355A0ECA4840
9974	Терешково	1	4	1073	40.646647000000002	40.674188999999998	49.932242000000002	49.911543000000002	0103000020E610000001000000050000003C873254C5524440E9F2E670ADF448403C873254C552444094FAB2B453F7484056293DD34B56444094FAB2B453F7484056293DD34B564440E9F2E670ADF448403C873254C5524440E9F2E670ADF44840
11552	Твердохлебовка	1	4	1073	40.326604000000003	40.367333000000002	49.956543000000003	49.923305999999997	0103000020E61000000100000005000000145FED28CE294440AC1919E42EF64840145FED28CE294440DF1B430070FA4840ECDE8AC4042F4440DF1B430070FA4840ECDE8AC4042F4440AC1919E42EF64840145FED28CE294440AC1919E42EF64840
11459	Сухой Донец	1	4	1073	40.880316000000001	40.933182000000002	49.817037999999997	49.789287000000002	0103000020E61000000100000005000000A112D731AE70444038143E5B07E54840A112D731AE7044406CCB80B394E84840A29BFD81727744406CCB80B394E84840A29BFD817277444038143E5B07E54840A112D731AE70444038143E5B07E54840
10972	Старотолучеево	1	4	1073	40.750185999999999	40.772554	49.979470999999997	49.958300000000001	0103000020E6100000010000000500000062F5471806604440DFE00B93A9FA484062F5471806604440B130444E5FFD48406E32AA0CE3624440B130444E5FFD48406E32AA0CE3624440DFE00B93A9FA484062F5471806604440DFE00B93A9FA4840
48943	Совхоз Южный	1	4	1073	40.767515000000003	40.791508999999998	49.760652999999998	49.747377	0103000020E61000000100000005000000401878EE3D6244402C64AE0CAADF4840401878EE3D624440594DD7135DE14840ADBEBA2A50654440594DD7135DE14840ADBEBA2A506544402C64AE0CAADF4840401878EE3D6244402C64AE0CAADF4840
49304	Свобода	1	4	1073	40.434688999999999	40.461486000000001	50.038423000000002	50.020085000000002	0103000020E6100000010000000500000029779FE3A3374440F11131259202494029779FE3A337444005357C0BEB044940EBC726F9113B444005357C0BEB044940EBC726F9113B4440F11131259202494029779FE3A3374440F111312592024940
11312	Радченское	1	4	1073	40.469301000000002	40.523001999999998	49.818555000000003	49.776845000000002	0103000020E61000000100000005000000747D1F0E123C4440D3872EA86FE34840747D1F0E123C4440187D0569C6E848400DDFC2BAF1424440187D0569C6E848400DDFC2BAF1424440D3872EA86FE34840747D1F0E123C4440D3872EA86FE34840
48133	Поповка	1	4	1073	40.477978999999998	40.516587999999999	49.919773999999997	49.906292000000001	0103000020E610000001000000050000005F96766A2E3D44402F50526001F448405F96766A2E3D444005DB8827BBF54840C6C03A8E1F42444005DB8827BBF54840C6C03A8E1F4244402F50526001F448405F96766A2E3D44402F50526001F44840
48726	Полтавка	1	4	1073	40.535741000000002	40.564711000000003	49.894402999999997	49.852521000000003	0103000020E610000001000000050000002C103D29934444409D137B681FED48402C103D2993444440DE3829CC7BF248408258367348484440DE3829CC7BF2484082583673484844409D137B681FED48402C103D29934444409D137B681FED4840
10906	Плесновка	1	4	1073	40.487645000000001	40.504255000000001	49.657103999999997	49.635708999999999	0103000020E610000001000000050000006A87BF266B3E4440ED629AE95ED148406A87BF266B3E44400F09DFFB1BD4484018EC866D8B4044400F09DFFB1BD4484018EC866D8B404440ED629AE95ED148406A87BF266B3E4440ED629AE95ED14840
54435	Перещепное	1	4	1073	40.499071000000001	40.521107000000001	49.999237999999998	49.989531999999997	0103000020E61000000100000005000000E6B0FB8EE13F4440382C0DFCA8FE4840E6B0FB8EE13F4440D175E107E7FF4840BC5B59A2B3424440D175E107E7FF4840BC5B59A2B3424440382C0DFCA8FE4840E6B0FB8EE13F4440382C0DFCA8FE4840
49259	Отдел N1 совхоза Вишневый	1	4	1073	40.188496999999998	41.04663	50.127197000000002	49.578563000000003	0103000020E61000000100000005000000723271AB201844407CD6355A0ECA4840723271AB201844401D93C5FD471049409981CAF8F78544401D93C5FD471049409981CAF8F78544407CD6355A0ECA4840723271AB201844407CD6355A0ECA4840
60385	Новоникольск	1	4	1073	40.371932999999999	40.392440999999998	49.636361999999998	49.620199	0103000020E61000000100000005000000CEA623809B2F444086014BAE62CF4840CEA623809B2F444065355D4F74D14840054EB6813B32444065355D4F74D14840054EB6813B32444086014BAE62CF4840CEA623809B2F444086014BAE62CF4840
49016	Монастырщина	1	4	1073	40.888238999999999	40.929831	49.860211	49.808301	0103000020E610000001000000050000001004C8D0B17144407C293C6876E748401004C8D0B17144406954E0641BEE48404BE7C3B3047744406954E0641BEE48404BE7C3B3047744407C293C6876E748401004C8D0B17144407C293C6876E74840
48991	Медово	1	4	1073	40.690466000000001	40.733172000000003	49.755961999999997	49.742255	0103000020E61000000100000005000000FE7F9C306158444070253B3602DF4840FE7F9C30615844406682E15CC3E04840E52B8194D85D44406682E15CC3E04840E52B8194D85D444070253B3602DF4840FE7F9C306158444070253B3602DF4840
54409	Малеваный	1	4	1073	40.712600999999999	40.732894000000002	49.806986999999999	49.791711999999997	0103000020E61000000100000005000000670C7382365B4440E5EC9DD156E54840670C7382365B444009A69A594BE74840A2B77878CF5D444009A69A594BE74840A2B77878CF5D4440E5EC9DD156E54840670C7382365B4440E5EC9DD156E54840
48896	Луговое	1	4	1073	40.315339000000002	40.353419000000002	49.922575000000002	49.899509999999999	0103000020E61000000100000005000000A11342075D2844406536C82423F34840A11342075D284440B98D06F016F648407C6473D53C2D4440B98D06F016F648407C6473D53C2D44406536C82423F34840A11342075D2844406536C82423F34840
11114	Лофицкое	1	4	1073	40.432245999999999	40.473154999999998	49.915672999999998	49.890282999999997	0103000020E61000000100000005000000D5E940D653374440A69718CBF4F14840D5E940D653374440446ADAC534F548402D78D157903C4440446ADAC534F548402D78D157903C4440A69718CBF4F14840D5E940D653374440A69718CBF4F14840
10209	Липчанка	1	4	1073	40.454883000000002	40.483745999999996	49.801475000000003	49.761561	0103000020E61000000100000005000000D1402C9B393A44405C74B2D47AE14840D1402C9B393A4440E3C798BB96E6484010C99063EB3D4440E3C798BB96E6484010C99063EB3D44405C74B2D47AE14840D1402C9B393A44405C74B2D47AE14840
10836	Лебединка	1	4	1073	40.401811000000002	40.443061	49.663017000000004	49.642155000000002	0103000020E610000001000000050000002716F88A6E33444040FB912232D248402716F88A6E33444095D8B5BDDDD4484008910C39B638444095D8B5BDDDD4484008910C39B638444040FB912232D248402716F88A6E33444040FB912232D24840
11083	Купянка	1	4	1073	40.532443999999998	40.558621000000002	49.913828000000002	49.883713	0103000020E61000000100000005000000C879FF1F274444406806F1811DF14840C879FF1F27444440A515DF50F8F44840EEED96E480474440A515DF50F8F44840EEED96E4804744406806F1811DF14840C879FF1F274444406806F1811DF14840
46558	Красногоровка	1	4	1073	40.754390999999998	40.774683000000003	49.930942999999999	49.914565000000003	0103000020E61000000100000005000000C8B260E28F6044407B88467710F54840C8B260E28F60444056B8E52329F7484033E202D02863444056B8E52329F7484033E202D0286344407B88467710F54840C8B260E28F6044407B88467710F54840
10567	Каразеево	1	4	1073	40.770381	40.796413999999999	49.707056999999999	49.696429000000002	0103000020E61000000100000005000000DA3A38D89B624440357EE19524D94840DA3A38D89B62444035B401D880DA4840CC09DAE4F065444035B401D880DA4840CC09DAE4F0654440357EE19524D94840DA3A38D89B624440357EE19524D94840
10174	Залиман	1	4	1073	40.564711000000003	40.596879999999999	49.959823999999998	49.936463000000003	0103000020E61000000100000005000000825836734848444000750305DEF7484082583673484844403CF54883DBFA484078D15790664C44403CF54883DBFA484078D15790664C444000750305DEF74840825836734848444000750305DEF74840
47193	Журавка	1	4	1073	40.564523000000001	40.615574000000002	50.072749000000002	50.029384999999998	0103000020E610000001000000050000007F6B274A4248444019FF3EE3C20349407F6B274A424844408AE8D7D64F0949404B22FB20CB4E44408AE8D7D64F0949404B22FB20CB4E444019FF3EE3C20349407F6B274A4248444019FF3EE3C2034940
54405	Дядин	1	4	1073	40.508476999999999	40.541013999999997	49.846231000000003	49.813561999999997	0103000020E6100000010000000500000054E23AC61541444059A2B3CC22E8484054E23AC61541444042EE224C51EC4840CD565EF23F45444042EE224C51EC4840CD565EF23F45444059A2B3CC22E8484054E23AC61541444059A2B3CC22E84840
9770	Дьяченково	1	4	1073	40.575868	40.621538999999999	49.920267000000003	49.896335999999998	0103000020E610000001000000050000000E68E90AB64944401D1D5723BBF248400E68E90AB6494440454B1E4FCBF54840221807978E4F4440454B1E4FCBF54840221807978E4F44401D1D5723BBF248400E68E90AB64944401D1D5723BBF24840
10438	Данцевка	1	4	1073	40.213999999999999	40.284669999999998	49.915064000000001	49.897902999999999	0103000020E6100000010000000500000008AC1C5A641B44407AFD497CEEF2484008AC1C5A641B44409CDF30D120F548407F130A11702444409CDF30D120F548407F130A11702444407AFD497CEEF2484008AC1C5A641B44407AFD497CEEF24840
10130	Грушовое	1	4	1073	40.589692999999997	40.616041000000003	50.020774000000003	50.003684999999997	0103000020E610000001000000050000000ED76A0F7B4B44402D3E05C0780049400ED76A0F7B4B4440B64DF1B8A802494061FF756EDA4E4440B64DF1B8A802494061FF756EDA4E44402D3E05C0780049400ED76A0F7B4B44402D3E05C078004940
52290	Галиевка	1	4	1073	40.619256999999998	40.639577000000003	49.992502999999999	49.972906999999999	0103000020E61000000100000005000000D76839D0434F44405586713788FC4840D76839D0434F444048179B560AFF48400C23BDA8DD51444048179B560AFF48400C23BDA8DD5144405586713788FC4840D76839D0434F44405586713788FC4840
11026	Вервековка	1	4	1073	40.441687000000002	40.512976999999999	49.929476000000001	49.918509	0103000020E61000000100000005000000C0081A3389384440740AF2B391F54840C0081A33893844405D35CF11F9F64840D34CF73AA94144405D35CF11F9F64840D34CF73AA9414440740AF2B391F54840C0081A3389384440740AF2B391F54840
54460	Ботовка	1	4	1073	40.532192000000002	40.546565000000001	49.606212999999997	49.593986999999998	0103000020E61000000100000005000000AF9811DE1E444440E49F19C407CC4840AF9811DE1E4444407CB4386398CD4840B21188D7F54544407CB4386398CD4840B21188D7F5454440E49F19C407CC4840AF9811DE1E444440E49F19C407CC4840
9513	Богучар	1	4	1073	40.520775	40.579551000000002	49.950671999999997	49.918503000000001	0103000020E6100000010000000500000086C954C1A842444092239D8191F5484086C954C1A8424440889CBE9EAFF948409BAE27BA2E4A4440889CBE9EAFF948409BAE27BA2E4A444092239D8191F5484086C954C1A842444092239D8191F54840
11416	Белая Горка 1-я	1	4	1073	40.931170000000002	40.949756000000001	49.799881999999997	49.788198999999999	0103000020E6100000010000000500000017821C9430774440B5DE6FB4E3E4484017821C94307744405C548B8862E648400397C79A917944405C548B8862E648400397C79A91794440B5DE6FB4E3E4484017821C9430774440B5DE6FB4E3E44840
9176	Ясенки	1	4	922	39.952616999999996	39.985235000000003	51.059522000000001	51.034118999999997	0103000020E610000001000000050000008B4E965AEFF943400B96EA025E8449408B4E965AEFF943403EB2B96A9E874940F2EF332E1CFE43403EB2B96A9E874940F2EF332E1CFE43400B96EA025E8449408B4E965AEFF943400B96EA025E844940
8636	Юдановка	1	4	922	39.824382999999997	39.851709	51.295512000000002	51.255586999999998	0103000020E610000001000000050000006E30D46185E9434031242713B7A049406E30D46185E94340ACC95356D3A54940BC5AEECC04ED4340ACC95356D3A54940BC5AEECC04ED434031242713B7A049406E30D46185E9434031242713B7A04940
8943	Шишовка	1	4	922	40.176440999999997	40.214449000000002	51.257733999999999	51.232137000000002	0103000020E610000001000000050000003656629E9516444085984BAAB69D49403656629E951644409C887E6DFDA0494078D49810731B44409C887E6DFDA0494078D49810731B444085984BAAB69D49403656629E9516444085984BAAB69D4940
7994	Шестаково	1	4	922	40.015832000000003	40.117386000000003	50.823931000000002	50.765338999999997	0103000020E610000001000000050000007A1D71C8060244403AADDBA0F66149407A1D71C8060244408E942D92766949400F812381060F44408E942D92766949400F812381060F44403AADDBA0F66149407A1D71C8060244403AADDBA0F6614940
8884	Чесменка	1	4	922	40.139341000000002	40.201019000000002	51.307766000000001	51.276708999999997	0103000020E61000000100000005000000F8FE06EDD511444022C154336BA34940F8FE06EDD51144400E6954E064A74940F46F97FDBA1944400E6954E064A74940F46F97FDBA19444022C154336BA34940F8FE06EDD511444022C154336BA34940
8735	Хреновое	1	4	922	40.247883999999999	40.323549999999997	51.140991	51.098973999999998	0103000020E61000000100000005000000D099B4A9BA1F4440C093162EAB8C4940D099B4A9BA1F4440E2033BFE0B924940764F1E166A294440E2033BFE0B924940764F1E166A294440C093162EAB8C4940D099B4A9BA1F4440C093162EAB8C4940
8391	Тройня	1	4	922	40.411054	40.442990000000002	51.046607000000002	51.034215000000003	0103000020E61000000100000005000000EB71DF6A9D3444402E04392861844940EB71DF6A9D344440E161DA37F78549403F3A75E5B3384440E161DA37F78549403F3A75E5B33844402E04392861844940EB71DF6A9D3444402E04392861844940
8578	Сухая Березовка	1	4	922	39.968516999999999	40.032378999999999	51.196326999999997	51.157789000000001	0103000020E610000001000000050000005D4F745DF8FB43409355116E329449405D4F745DF8FB434030293E3E21994940E109BDFE2404444030293E3E21994940E109BDFE240444409355116E329449405D4F745DF8FB43409355116E32944940
54275	Слобода	1	4	922	40.272542999999999	40.314261000000002	51.159376000000002	51.129500999999998	0103000020E610000001000000050000007AE063B0E22244404FE61F7D939049407AE063B0E222444037E2C96E6694494042B456B43928444037E2C96E6694494042B456B4392844404FE61F7D939049407AE063B0E22244404FE61F7D93904940
8351	Семено-Александровка	1	4	922	40.182459999999999	40.237698000000002	51.061751999999998	51.015146000000001	0103000020E61000000100000005000000016A6AD95A1744402655DB4DF0814940016A6AD95A174440363B527DE78749408D2958E36C1E4440363B527DE78749408D2958E36C1E44402655DB4DF0814940016A6AD95A1744402655DB4DF0814940
54358	Пятилетка 2-я	1	4	922	39.943930000000002	39.951692000000001	51.332729999999998	51.328769000000001	0103000020E610000001000000050000004DDBBFB2D2F843402578431A15AA49404DDBBFB2D2F84340F4328AE596AA4940B3EE1F0BD1F94340F4328AE596AA4940B3EE1F0BD1F943402578431A15AA49404DDBBFB2D2F843402578431A15AA4940
7862	Пчелиновка	1	4	922	39.980365999999997	40.01267	50.951098000000002	50.931285000000003	0103000020E610000001000000050000001F0E12A27CFD4340B020CD58347749401F0E12A27CFD434040A54A94BD794940F6D1A92B9F01444040A54A94BD794940F6D1A92B9F014440B020CD58347749401F0E12A27CFD4340B020CD5834774940
8646	Песковатка	1	4	922	39.916728999999997	39.966217999999998	51.273857999999997	51.250045	0103000020E61000000100000005000000BB25396057F54340A0C37C7901A04940BB25396057F54340BDDF68C70DA349403C670B08ADFB4340BDDF68C70DA349403C670B08ADFB4340A0C37C7901A04940BB25396057F54340A0C37C7901A04940
46653	Павловка	1	4	922	40.068302000000003	40.106983999999997	50.988092000000002	50.971997999999999	0103000020E610000001000000050000002E20B41EBE08444082E3326E6A7C49402E20B41EBE08444039B874CC797E4940FE98D6A6B10D444039B874CC797E4940FE98D6A6B10D444082E3326E6A7C49402E20B41EBE08444082E3326E6A7C4940
8279	Новый Буравль	1	4	922	40.192872000000001	40.215302999999999	50.975071999999997	50.960154000000003	0103000020E6100000010000000500000035289A07B0184440D28F8653E67A494035289A07B0184440669FC728CF7C494087DD770C8F1B4440669FC728CF7C494087DD770C8F1B4440D28F8653E67A494035289A07B0184440D28F8653E67A4940
54340	Никольское 2-е	1	4	922	39.806604999999998	39.825982000000003	51.133814000000001	51.116058000000002	0103000020E6100000010000000500000021E527D53EE74340373811FDDA8E494021E527D53EE743409CDF30D120914940D78A36C7B9E943409CDF30D120914940D78A36C7B9E94340373811FDDA8E494021E527D53EE74340373811FDDA8E4940
7936	Николо-Варваринка	1	4	922	39.969901	39.991999	51.017611000000002	50.989933999999998	0103000020E61000000100000005000000C9AD49B725FC434067994528B67E4940C9AD49B725FC43406286C613418249401555BFD2F9FE43406286C613418249401555BFD2F9FE434067994528B67E4940C9AD49B725FC434067994528B67E4940
9025	Нескучный	1	4	922	39.773798999999997	39.794065000000003	51.14528	51.131439999999998	0103000020E61000000100000005000000B8567BD80BE3434070B1A206D3904940B8567BD80BE34340A661F88898924940FAF202ECA3E54340A661F88898924940FAF202ECA3E5434070B1A206D3904940B8567BD80BE3434070B1A206D3904940
8128	Митрофановка	1	4	922	40.353580000000001	40.379479000000003	51.011049	50.993307999999999	0103000020E610000001000000050000008542041C422D4440766D6FB7247F49408542041C422D4440A6D3BA0D6A814940684293C492304440A6D3BA0D6A814940684293C492304440766D6FB7247F49408542041C422D4440766D6FB7247F4940
8192	Мечетка	1	4	922	40.047946000000003	40.155295000000002	50.955807999999998	50.891745999999998	0103000020E61000000100000005000000ADFC3218230644405E2BA1BB24724940ADFC321823064440A9A0A2EA577A4940BD1DE1B4E0134440A9A0A2EA577A4940BD1DE1B4E01344405E2BA1BB24724940ADFC3218230644405E2BA1BB24724940
7856	Липовка	1	4	922	39.989061999999997	40.062184999999999	50.873766000000003	50.844859999999997	0103000020E61000000100000005000000B1DB679599FE43406AD95A5F246C4940B1DB679599FE4340AA2D7590D76F4940A0A696ADF5074440AA2D7590D76F4940A0A696ADF50744406AD95A5F246C4940B1DB679599FE43406AD95A5F246C4940
8254	Красный	1	4	922	40.190050999999997	40.229891000000002	50.910530999999999	50.897585999999997	0103000020E610000001000000050000003AC956975318444079AC1919E47249403AC9569753184440417FA1478C74494087527B116D1D4440417FA1478C74494087527B116D1D444079AC1919E47249403AC956975318444079AC1919E4724940
8507	Коршево	1	4	922	40.077356999999999	40.145629	51.204690999999997	51.167318000000002	0103000020E61000000100000005000000EF8E8CD5E60944401D041DAD6A954940EF8E8CD5E60944408C648F50339A4940B22C98F8A31244408C648F50339A4940B22C98F8A31244401D041DAD6A954940EF8E8CD5E60944401D041DAD6A954940
8994	Верхний Икорец	1	4	922	39.776924999999999	39.818534999999997	51.238582999999998	51.150032000000003	0103000020E61000000100000005000000EF38454772E343403FADA23F34934940EF38454772E34340D73043E3899E4940D0D03FC1C5E84340D73043E3899E4940D0D03FC1C5E843403FADA23F34934940EF38454772E343403FADA23F34934940
7352	Бобров	1	4	922	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
8067	Анновка	1	4	922	40.294794000000003	40.338974	50.997745999999999	50.973495	0103000020E610000001000000050000004D874ECFBB254440E6E8F17B9B7C49404D874ECFBB2544407FDB1324B67F4940DF180280632B44407FDB1324B67F4940DF180280632B4440E6E8F17B9B7C49404D874ECFBB254440E6E8F17B9B7C4940
7283	Хлебородное	1	4	485	40.653348000000001	40.705494999999999	51.482802	51.454237999999997	0103000020E61000000100000005000000197442E8A0534440DB4C857824BA4940197442E8A0534440C138B874CCBD4940EA3E00A94D5A4440C138B874CCBD4940EA3E00A94D5A4440DB4C857824BA4940197442E8A0534440DB4C857824BA4940
6681	Суровский	1	4	485	41.018217	41.044213999999997	51.394888000000002	51.382736000000001	0103000020E61000000100000005000000999D45EF548244403D80457EFDB04940999D45EF548244409BCAA2B08BB249403E03EACDA88544409BCAA2B08BB249403E03EACDA88544403D80457EFDB04940999D45EF548244403D80457EFDB04940
47198	Студеное	1	4	485	40.182800999999998	40.214629000000002	51.417001999999997	51.388739000000001	0103000020E610000001000000050000008A56EE056617444002D71533C2B149408A56EE0566174440EC2E505260B54940F8E28BF6781B4440EC2E505260B54940F8E28BF6781B444002D71533C2B149408A56EE056617444002D71533C2B14940
47317	Старый Курлак	1	4	485	40.499619000000003	40.557389999999998	51.423893	51.403215000000003	0103000020E61000000100000005000000E9BAF083F33F4440DA20938C9CB34940E9BAF083F33F44406D00362042B64940088F368E584744406D00362042B64940088F368E58474440DA20938C9CB34940E9BAF083F33F4440DA20938C9CB34940
7204	Старая Чигла	1	4	485	40.354495999999997	40.403500000000001	51.310288	51.266227999999998	0103000020E610000001000000050000000A48FB1F602D4440C6A354C213A249400A48FB1F602D4440AE2B6684B7A74940CFF753E3A5334440AE2B6684B7A74940CFF753E3A5334440C6A354C213A249400A48FB1F602D4440C6A354C213A24940
7148	Старая Тойда	1	4	485	40.349240999999999	40.4482	51.388925	51.358080000000001	0103000020E610000001000000050000000FB6D8EDB32C444004ADC090D5AD49400FB6D8EDB32C444064CC5D4BC8B149409A081B9E5E39444064CC5D4BC8B149409A081B9E5E39444004ADC090D5AD49400FB6D8EDB32C444004ADC090D5AD4940
53058	Садовое	1	4	485	40.453536	40.528464	51.555988999999997	51.501739000000001	0103000020E6100000010000000500000082C7B7770D3A44405A10CAFB38C0494082C7B7770D3A4440C6F7C5A52AC74940828E56B5A4434440C6F7C5A52AC74940828E56B5A44344405A10CAFB38C0494082C7B7770D3A44405A10CAFB38C04940
47128	Сабуровка	1	4	485	40.355161000000003	40.387464999999999	51.590688999999998	51.580840000000002	0103000020E6100000010000000500000047E867EA752D4440B51A12F758CA494047E867EA752D4440B08D78B29BCB49401DACFF7398314440B08D78B29BCB49401DACFF7398314440B51A12F758CA494047E867EA752D4440B51A12F758CA4940
6844	Рубашевка	1	4	485	40.623289999999997	40.663975000000001	51.629282000000003	51.606225999999999	0103000020E6100000010000000500000040F67AF7C74F444011FE45D098CD494040F67AF7C74F444012FB04508CD04940492EFF21FD54444012FB04508CD04940492EFF21FD54444011FE45D098CD494040F67AF7C74F444011FE45D098CD4940
47222	Романовка	1	4	485	40.115886000000003	40.155096999999998	51.375810000000001	51.345857000000002	0103000020E610000001000000050000003A083A5AD50E4440DD0BCC0A45AC49403A083A5AD50E444040C1C58A1AB04940965AEF37DA13444040C1C58A1AB04940965AEF37DA134440DD0BCC0A45AC49403A083A5AD50E4440DD0BCC0A45AC4940
6832	Рамонье	1	4	485	41.086039999999997	41.129302000000003	51.420316	51.388300999999998	0103000020E61000000100000005000000EC12D55B038B44408600E0D8B3B14940EC12D55B038B444026FE28EACCB5494059A7CAF78C90444026FE28EACCB5494059A7CAF78C9044408600E0D8B3B14940EC12D55B038B44408600E0D8B3B14940
6792	Пугачевский	1	4	485	40.657732000000003	40.678797000000003	51.575080999999997	51.562328000000001	0103000020E610000001000000050000002FC4EA8F3054444003D0285DFAC749402FC4EA8F3054444086C613419CC94940BCCFF1D1E256444086C613419CC94940BCCFF1D1E256444003D0285DFAC749402FC4EA8F3054444003D0285DFAC74940
47439	Петровка	1	4	485	40.841661999999999	40.867192000000003	51.300530000000002	51.287785	0103000020E610000001000000050000009A249694BB6B4440C2A38D23D6A449409A249694BB6B4440C3BB5CC477A649402AADBF25006F4440C3BB5CC477A649402AADBF25006F4440C2A38D23D6A449409A249694BB6B4440C2A38D23D6A44940
47450	Островки	1	4	485	40.909987999999998	40.962845000000002	51.448557999999998	51.396664000000001	0103000020E6100000010000000500000050E09D7C7A74444012C0CDE2C5B2494050E09D7C7A744440F92D3A596AB94940FE0E45813E7B4440F92D3A596AB94940FE0E45813E7B444012C0CDE2C5B2494050E09D7C7A74444012C0CDE2C5B24940
54370	Новый Курлак	1	4	485	40.501649999999998	40.575544999999998	51.47298	51.421894000000002	0103000020E61000000100000005000000EA043411364044407730629F00B64940EA04341136404440BFD4CF9B8ABC49402B306475AB494440BFD4CF9B8ABC49402B306475AB4944407730629F00B64940EA043411364044407730629F00B64940
5470	Новонадеждинский	1	4	485	40.212715000000003	40.224815999999997	51.452621999999998	51.439138999999997	0103000020E61000000100000005000000302FC03E3A1B4440F6B2EDB435B84940302FC03E3A1B44409DB98784EFB949400BCF4BC5C61C44409DB98784EFB949400BCF4BC5C61C4440F6B2EDB435B84940302FC03E3A1B4440F6B2EDB435B84940
54312	Никольское	1	4	485	40.939345000000003	40.974972000000001	51.496856000000001	51.446357999999996	0103000020E61000000100000005000000A054FB743C7844406B274A4222B94940A054FB743C784440236937FA98BF49400342EBE1CB7C4440236937FA98BF49400342EBE1CB7C44406B274A4222B94940A054FB743C7844406B274A4222B94940
54322	Николаевка	1	4	485	40.248846	40.288910000000001	51.535601	51.508063	0103000020E61000000100000005000000C6DE8B2FDA1F444061A7583508C14940C6DE8B2FDA1F44403A5AD5928EC4494062BEBC00FB2444403A5AD5928EC4494062BEBC00FB24444061A7583508C14940C6DE8B2FDA1F444061A7583508C14940
47172	Нащекино	1	4	485	40.122525000000003	40.149769999999997	51.413626000000001	51.387171000000002	0103000020E61000000100000005000000A1F831E6AE0F4440D57ABFD18EB14940A1F831E6AE0F44403D635FB2F1B4494001F6D1A92B1344403D635FB2F1B4494001F6D1A92B134440D57ABFD18EB14940A1F831E6AE0F4440D57ABFD18EB14940
47354	Моховое	1	4	485	40.582669000000003	40.613759000000002	51.424404000000003	51.413052999999998	0103000020E610000001000000050000004FB2D5E5944A4440E141B3EBDEB449404FB2D5E5944A44405325CADE52B649401650A8A78F4E44405325CADE52B649401650A8A78F4E4440E141B3EBDEB449404FB2D5E5944A4440E141B3EBDEB44940
47104	Мосоловка	1	4	485	40.414019000000003	40.440545999999998	51.578971000000003	51.562232999999999	0103000020E6100000010000000500000019761893FE344440B1DD3D40F7C7494019761893FE3444408D2AC3B81BCA49401A31B3CF633844408D2AC3B81BCA49401A31B3CF63384440B1DD3D40F7C7494019761893FE344440B1DD3D40F7C74940
54445	Левашевка	1	4	485	40.321581999999999	40.347183999999999	51.491467	51.472239000000002	0103000020E61000000100000005000000BB7D569929294440A872DA5372BC4940BB7D56992929444018080264E8BE4940E4D87A86702C444018080264E8BE4940E4D87A86702C4440A872DA5372BC4940BB7D569929294440A872DA5372BC4940
6164	Круглоподпольное	1	4	485	40.287652999999999	40.351028999999997	51.541612000000001	51.524659	0103000020E6100000010000000500000053CC41D0D1244440AA46AF0628C3494053CC41D0D1244440828FC18A53C549404A79AD84EE2C4440828FC18A53C549404A79AD84EE2C4440AA46AF0628C3494053CC41D0D1244440AA46AF0628C34940
6709	Кругловский	1	4	485	41.043477000000003	41.070219999999999	51.433664	51.418422999999997	0103000020E61000000100000005000000699082A790854440757286E28EB54940699082A790854440EDB94C4D82B7494037C30DF8FC884440EDB94C4D82B7494037C30DF8FC884440757286E28EB54940699082A790854440757286E28EB54940
5675	Красный Лог	1	4	485	41.059610999999997	41.089112	51.539707999999997	51.521033000000003	0103000020E61000000100000005000000ADBD4F55A187444082919735B1C24940ADBD4F55A1874440DDB1D82615C5494030D7A205688B4440DDB1D82615C5494030D7A205688B444082919735B1C24940ADBD4F55A187444082919735B1C24940
46327	Желанное	1	4	485	40.410029999999999	40.439126999999999	51.539965000000002	51.522877000000001	0103000020E610000001000000050000007F30F0DC7B344440516A2FA2EDC249407F30F0DC7B34444009FEB7921DC5494032E543503538444009FEB7921DC5494032E5435035384440516A2FA2EDC249407F30F0DC7B344440516A2FA2EDC24940
47055	Дерябкино	1	4	485	40.914380000000001	40.959350000000001	51.545409999999997	51.517569999999999	0103000020E61000000100000005000000E90E62670A75444003B2D7BB3FC24940E90E62670A754440A774B0FECFC5494074B515FBCB7A4440A774B0FECFC5494074B515FBCB7A444003B2D7BB3FC24940E90E62670A75444003B2D7BB3FC24940
47406	Гусевка	1	4	485	41.093953999999997	41.118963000000001	51.440845000000003	51.430962999999998	0103000020E6100000010000000500000008AA46AF068C44409D64ABCB29B7494008AA46AF068C444075CDE49B6DB849408F37F92D3A8F444075CDE49B6DB849408F37F92D3A8F44409D64ABCB29B7494008AA46AF068C44409D64ABCB29B74940
5516	Верхняя Тойда	1	4	485	40.285856000000003	40.323791999999997	51.445414999999997	51.398865999999998	0103000020E61000000100000005000000C5AEEDED9624444040BE840A0EB34940C5AEEDED96244440EC12D55B03B949406C5A290472294440EC12D55B03B949406C5A29047229444040BE840A0EB34940C5AEEDED9624444040BE840A0EB34940
54468	Васильевка	1	4	485	40.174644999999998	40.226900000000001	51.500523000000001	51.474018000000001	0103000020E6100000010000000500000078B471C45A16444090DB2F9FACBC494078B471C45A164440AAF23D2311C0494030BB270F0B1D4440AAF23D2311C0494030BB270F0B1D444090DB2F9FACBC494078B471C45A16444090DB2F9FACBC4940
46942	Бродовое	1	4	485	40.481788000000002	40.529569000000002	51.499048000000002	51.47298	0103000020E6100000010000000500000079CDAB3AAB3D4440BFD4CF9B8ABC494079CDAB3AAB3D44402E910BCEE0BF4940DBFCBFEAC84344402E910BCEE0BF4940DBFCBFEAC8434440BFD4CF9B8ABC494079CDAB3AAB3D4440BFD4CF9B8ABC4940
46840	Большая Алексеевка	1	4	485	40.758532000000002	40.813122	51.555512999999998	51.532795	0103000020E61000000100000005000000187C9A9317614440753C66A032C44940187C9A93176144405DC0CB0C1BC749403DD4B661146844405DC0CB0C1BC749403DD4B66114684440753C66A032C44940187C9A9317614440753C66A032C44940
54382	Болшие Ясырки	1	4	485	40.464756000000001	40.496799000000003	51.631697000000003	51.609940000000002	0103000020E61000000100000005000000554FE61F7D3B4440D942908312CE4940554FE61F7D3B44409CFD8172DBD04940BFD7101C973F44409CFD8172DBD04940BFD7101C973F4440D942908312CE4940554FE61F7D3B4440D942908312CE4940
54353	Бобяково	1	4	485	40.794141000000003	40.818925	51.527337000000003	51.508595999999997	0103000020E61000000100000005000000D5B48B69A66544402E7079AC19C14940D5B48B69A6654440427C60C77FC349403B70CE88D2684440427C60C77FC349403B70CE88D26844402E7079AC19C14940D5B48B69A66544402E7079AC19C14940
48878	Березовка	1	4	485	40.173206999999998	40.231031999999999	51.349063999999998	51.298282999999998	0103000020E610000001000000050000001938A0A52B164440F4F928232EA649401938A0A52B164440001B1021AEAC49402C2AE274921D4440001B1021AEAC49402C2AE274921D4440F4F928232EA649401938A0A52B164440F4F928232EA64940
54273	Архангельское	1	4	485	40.900924000000003	40.951633999999999	51.482897999999999	51.432248999999999	0103000020E610000001000000050000003C17467A51734440465D6BEF53B749403C17467A51734440E3A6069ACFBD49407EE19524CF794440E3A6069ACFBD49407EE19524CF794440465D6BEF53B749403C17467A51734440465D6BEF53B74940
46872	Артюшкино	1	4	485	40.939956000000002	40.987682999999997	51.371644000000003	51.333956999999998	0103000020E61000000100000005000000E9D66B7A5078444098A25C1ABFAA4940E9D66B7A5078444098E0D40792AF494057E883656C7E444098E0D40792AF494057E883656C7E444098A25C1ABFAA4940E9D66B7A5078444098A25C1ABFAA4940
2900	Анна	1	4	485	40.378473	40.459913999999998	51.512273	51.462690000000002	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
46242	Александровка	1	4	485	40.826605999999998	40.875717000000002	51.346071000000002	51.329253000000001	0103000020E61000000100000005000000B456B439CE694440118E59F624AA4940B456B439CE694440098CF50D4CAC49408FC6A17E17704440098CF50D4CAC49408FC6A17E17704440118E59F624AA4940B456B439CE694440118E59F624AA4940
38741	Верхний Ольшан	1	4	5947	38.841123000000003	38.893763999999997	50.780810000000002	50.759151000000003	0103000020E61000000100000005000000EB7420EBA96B4340E4DC26DC2B614940EB7420EBA96B4340E4310395F1634940CB2BD7DB66724340E4310395F1634940CB2BD7DB66724340E4DC26DC2B614940EB7420EBA96B4340E4DC26DC2B614940
60374	п. Сушнево-2	1	3	\N	38.276963000000002	42.972842999999997	56.810733999999997	55.104182000000002	0103000020E61000000100000005000000DD990986732343407B6AF5D5558D4B40DD99098673234340ACE0B721C6674C403E92921E867C4540ACE0B721C6674C403E92921E867C45407B6AF5D5558D4B40DD990986732343407B6AF5D5558D4B40
54153	имени Воровского	1	3	\N	41.100745000000003	41.135131999999999	55.732118999999997	55.712685	0103000020E61000000100000005000000261E5036E58C4440C5AC174339DB4B40261E5036E58C4440DEE34C13B6DD4B40505260014C914440DEE34C13B6DD4B40505260014C914440C5AC174339DB4B40261E5036E58C4440C5AC174339DB4B40
54133	Юрьев-Польский	1	3	\N	39.646013000000004	39.72034	56.520761999999998	56.477691	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
54130	Суздаль	1	3	\N	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
54145	Струнино	1	3	\N	38.5565	38.598236	56.389009999999999	56.359713999999997	0103000020E61000000100000005000000AC1C5A643B474340E8F4BC1B0B2E4C40AC1C5A643B47434092E86514CB314C401AA54BFF924C434092E86514CB314C401AA54BFF924C4340E8F4BC1B0B2E4C40AC1C5A643B474340E8F4BC1B0B2E4C40
54136	Собинка	1	3	\N	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
54157	Сновицы	1	3	\N	38.276963000000002	42.972842999999997	56.810733999999997	55.104182000000002	0103000020E61000000100000005000000DD990986732343407B6AF5D5558D4B40DD99098673234340ACE0B721C6674C403E92921E867C4540ACE0B721C6674C403E92921E867C45407B6AF5D5558D4B40DD990986732343407B6AF5D5558D4B40
60372	Рукав	1	3	\N	38.276963000000002	42.972842999999997	56.810733999999997	55.104182000000002	0103000020E61000000100000005000000DD990986732343407B6AF5D5558D4B40DD99098673234340ACE0B721C6674C403E92921E867C4540ACE0B721C6674C403E92921E867C45407B6AF5D5558D4B40DD990986732343407B6AF5D5558D4B40
54142	Радужный ЗАТО	1	3	\N	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
54132	Радужный	1	3	\N	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
60428	Пригородный	1	3	\N	38.276963000000002	42.972842999999997	56.810733999999997	55.104182000000002	0103000020E61000000100000005000000DD990986732343407B6AF5D5558D4B40DD99098673234340ACE0B721C6674C403E92921E867C4540ACE0B721C6674C403E92921E867C45407B6AF5D5558D4B40DD990986732343407B6AF5D5558D4B40
54134	Покров	1	3	\N	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
54138	Петушки	1	3	\N	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
41177	Муром	1	3	\N	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
54140	Меленки	1	3	\N	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
54127	Кольчугино	1	3	\N	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
8940	Ковров	1	3	\N	41.264885	41.406225999999997	56.408289000000003	56.286268	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
54126	Киржач	1	3	\N	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
54125	Карабаново	1	3	\N	38.673749000000001	38.727072999999997	56.330140999999998	56.292777000000001	0103000020E610000001000000050000003A5B40683D564340B0027CB779254C403A5B40683D564340CC086F0F422A4C40FD6662BA105D4340CC086F0F422A4C40FD6662BA105D4340B0027CB779254C403A5B40683D564340B0027CB779254C40
54144	Камешково	1	3	\N	40.962251999999999	41.032895000000003	56.363498999999997	56.337924999999998	0103000020E610000001000000050000005B41D3122B7B44401AC05B20412B4C405B41D3122B7B444079909E22872E4C40D99942E73584444079909E22872E4C40D99942E7358444401AC05B20412B4C405B41D3122B7B44401AC05B20412B4C40
54156	Заклязьменский	1	3	\N	38.276963000000002	42.972842999999997	56.810733999999997	55.104182000000002	0103000020E61000000100000005000000DD990986732343407B6AF5D5558D4B40DD99098673234340ACE0B721C6674C403E92921E867C4540ACE0B721C6674C403E92921E867C45407B6AF5D5558D4B40DD990986732343407B6AF5D5558D4B40
11724	Гусь-Хрустальный	1	3	\N	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
54137	Гороховец	1	3	\N	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
54135	Вязники	1	3	\N	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
3510	Владимир	1	3	\N	40.165337999999998	40.517271000000001	56.187385999999996	56.051913999999996	0103000020E610000001000000050000009D64ABCB291544402E1A321EA5064C409D64ABCB2915444037DDB243FC174C40A915A6EF3542444037DDB243FC174C40A915A6EF354244402E1A321EA5064C409D64ABCB291544402E1A321EA5064C40
54129	Александров	1	3	\N	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
10146	Юрьев-Польский	1	3	1118	39.646013000000004	39.72034	56.520761999999998	56.477691	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
47757	Энтузиаст	1	3	1118	39.760646999999999	39.791198999999999	56.592996999999997	56.576270999999998	0103000020E61000000100000005000000776682E15CE143400D51853FC3494C40776682E15CE1434024D06053E74B4C405FD0420246E5434024D06053E74B4C405FD0420246E543400D51853FC3494C40776682E15CE143400D51853FC3494C40
11622	Шихобалово	1	3	1118	40.079827999999999	40.102069999999998	56.437188999999996	56.418909999999997	0103000020E610000001000000050000000DA7CCCD370A4440D2FBC6D79E354C400DA7CCCD370A4440E19524CFF5374C408CF337A1100D4440E19524CFF5374C408CF337A1100D4440D2FBC6D79E354C400DA7CCCD370A4440D2FBC6D79E354C40
11214	Шипилово	1	3	1118	39.888477000000002	39.920304999999999	56.528695999999997	56.517346000000003	0103000020E61000000100000005000000C51F459DB9F14340B45BCB6438424C40C51F459DB9F1434054C37E4FAC434C4032ACE28DCCF5434054C37E4FAC434C4032ACE28DCCF54340B45BCB6438424C40C51F459DB9F14340B45BCB6438424C40
48036	Чеково	1	3	1118	39.942968999999998	39.975569	56.299675999999998	56.285817999999999	0103000020E6100000010000000500000027124C35B3F84340D74D29AF95244C4027124C35B3F84340B3B27DC85B264C40E7FEEA71DFFC4340B3B27DC85B264C40E7FEEA71DFFC4340D74D29AF95244C4027124C35B3F84340D74D29AF95244C40
54166	Сосновый Бор	1	3	1118	39.652661000000002	39.674041000000003	56.451647999999999	56.440503	0103000020E61000000100000005000000F52F49658AD343401B65FD6662384C40F52F49658AD34340E3A6069ACF394C40E294B9F946D64340E3A6069ACF394C40E294B9F946D643401B65FD6662384C40F52F49658AD343401B65FD6662384C40
10708	Сима	1	3	1118	39.534118999999997	39.570016000000003	56.693283000000001	56.671187000000003	0103000020E610000001000000050000000B96EA025EC443400C40A374E9554C400B96EA025EC44340B7EF517FBD584C402F19C748F6C84340B7EF517FBD584C402F19C748F6C843400C40A374E9554C400B96EA025EC443400C40A374E9554C40
11606	Семьинское	1	3	1118	39.754260000000002	39.783042000000002	56.371720000000003	56.358396999999997	0103000020E610000001000000050000002A5778978BE0434004FEF0F3DF2D4C402A5778978BE0434073A25D85942F4C407DB262B83AE4434073A25D85942F4C407DB262B83AE4434004FEF0F3DF2D4C402A5778978BE0434004FEF0F3DF2D4C40
47772	Подолец	1	3	1118	39.795645999999998	39.819513999999998	56.693891000000001	56.682248999999999	0103000020E61000000100000005000000BB9866BAD7E54340465D6BEF53574C40BB9866BAD7E543408FFE976BD1584C409C4EB2D5E5E843408FFE976BD1584C409C4EB2D5E5E84340465D6BEF53574C40BB9866BAD7E54340465D6BEF53574C40
48457	Павловское	1	3	1118	39.991576999999999	40.007199	56.285668000000001	56.277943	0103000020E610000001000000050000009F3BC1FEEBFE43407993DFA293234C409F3BC1FEEBFE4340C2C1DEC490244C402EC896E5EB004440C2C1DEC490244C402EC896E5EB0044407993DFA293234C409F3BC1FEEBFE43407993DFA293234C40
47902	Ополье	1	3	1118	39.617626000000001	39.651646	56.557028000000003	56.542917000000003	0103000020E610000001000000050000006494675E0ECF4340A2B8E34D7E454C406494675E0ECF4340687A89B14C474C40DC48D92269D34340687A89B14C474C40DC48D92269D34340A2B8E34D7E454C406494675E0ECF4340A2B8E34D7E454C40
11730	Небылое	1	3	1118	39.975200999999998	40.010541000000003	56.376280999999999	56.357165000000002	0103000020E610000001000000050000006403E962D3FC43404F232D95B72D4C406403E962D3FC4340978DCEF929304C403222516859014440978DCEF929304C4032225168590144404F232D95B72D4C406403E962D3FC43404F232D95B72D4C40
10768	Матвейщево	1	3	1118	39.463664000000001	39.484209	56.66583	56.648766000000002	0103000020E61000000100000005000000912A8A5759BB4340DD60A8C30A534C40912A8A5759BB43400C59DDEA39554C40E5B67D8FFABD43400C59DDEA39554C40E5B67D8FFABD4340DD60A8C30A534C40912A8A5759BB4340DD60A8C30A534C40
54170	Лучки	1	3	1118	39.520778999999997	39.543677000000002	56.771945000000002	56.760632999999999	0103000020E61000000100000005000000C7B8E2E2A8C2434012A1116C5C614C40C7B8E2E2A8C24340C6A70018CF624C40304B3B3597C54340C6A70018CF624C40304B3B3597C5434012A1116C5C614C40C7B8E2E2A8C2434012A1116C5C614C40
11167	Кузьмадино	1	3	1118	39.669674999999998	39.692411	56.487011000000003	56.473191999999997	0103000020E6100000010000000500000072F90FE9B7D543404A5D328E913C4C4072F90FE9B7D5434069E55E60563E4C40013274ECA0D8434069E55E60563E4C40013274ECA0D843404A5D328E913C4C4072F90FE9B7D543404A5D328E913C4C40
48123	Красное Заречье	1	3	1118	39.860979999999998	39.887849000000003	56.337297	56.322778999999997	0103000020E610000001000000050000004A41B79734EE4340F46A80D250294C404A41B79734EE4340FB04508C2C2B4C40A6643909A5F14340FB04508C2C2B4C40A6643909A5F14340F46A80D250294C404A41B79734EE4340F46A80D250294C40
40411	Красное	1	3	1118	39.664059999999999	39.689069000000003	56.533914000000003	56.518994999999997	0103000020E61000000100000005000000774A07EBFFD44340CDE49B6D6E424C40774A07EBFFD443403370404B57444C40FED7B96933D843403370404B57444C40FED7B96933D84340CDE49B6D6E424C40774A07EBFFD44340CDE49B6D6E424C40
47949	Косинское	1	3	1118	39.550854999999999	39.588216000000003	56.516015000000003	56.503816	0103000020E6100000010000000500000046EBA86A82C64340CC99ED0A7D404C4046EBA86A82C643406B9F8EC70C424C40F27D71A94ACB43406B9F8EC70C424C40F27D71A94ACB4340CC99ED0A7D404C4046EBA86A82C64340CC99ED0A7D404C40
48177	Добрынское	1	3	1118	39.528846000000001	39.549048999999997	56.628287	56.617333000000002	0103000020E610000001000000050000006A4FC939B1C34340ECDE8AC4044F4C406A4FC939B1C3434040C05AB56B504C406473D53C47C6434040C05AB56B504C406473D53C47C64340ECDE8AC4044F4C406A4FC939B1C34340ECDE8AC4044F4C40
47880	Городище	1	3	1118	39.699534999999997	39.721390999999997	56.605355000000003	56.591351000000003	0103000020E6100000010000000500000024B4E55C8AD943407CBABA63B14B4C4024B4E55C8AD943402CBCCB457C4D4C407A50508A56DC43402CBCCB457C4D4C407A50508A56DC43407CBABA63B14B4C4024B4E55C8AD943407CBABA63B14B4C40
47955	Горки	1	3	1118	39.374623	39.393487999999998	56.590018000000001	56.575294999999997	0103000020E610000001000000050000002AAA7EA5F3AF4340B2463D44A3494C402AAA7EA5F3AF43409206B7B5854B4C4029AF95D05DB243409206B7B5854B4C4029AF95D05DB24340B2463D44A3494C402AAA7EA5F3AF4340B2463D44A3494C40
10893	Веска	1	3	1118	39.644998000000001	39.661599000000002	56.641005	56.627885999999997	0103000020E6100000010000000500000022FE614B8FD24340E1CE85915E504C4022FE614B8FD2434047C9AB730C524C407D08AA46AFD4434047C9AB730C524C407D08AA46AFD44340E1CE85915E504C4022FE614B8FD24340E1CE85915E504C40
13424	Черниж	1	3	1017	40.421717000000001	40.440052000000001	56.37679	56.364037000000003	0103000020E61000000100000005000000689599D2FA35444059C4B0C3982E4C40689599D2FA354440DCBA9BA73A304C400B45BA9F53384440DCBA9BA73A304C400B45BA9F5338444059C4B0C3982E4C40689599D2FA35444059C4B0C3982E4C40
48444	Цибеево	1	3	1017	40.180366999999997	40.208215000000003	56.348132999999997	56.338354000000002	0103000020E6100000010000000500000089230F4416174440433C122F4F2B4C4089230F441617444045D4449F8F2C4C40B1C403CAA61A444045D4449F8F2C4C40B1C403CAA61A4440433C122F4F2B4C4089230F4416174440433C122F4F2B4C40
48097	Федоровское	1	3	1017	40.352941999999999	40.371502	56.333395000000003	56.325907999999998	0103000020E6100000010000000500000042B115342D2D44409CC0745AB7294C4042B115342D2D444031D3F6AFAC2A4C400533A6608D2F444031D3F6AFAC2A4C400533A6608D2F44409CC0745AB7294C4042B115342D2D44409CC0745AB7294C40
13494	Туртино	1	3	1017	40.324286000000001	40.340797000000002	56.349429999999998	56.336118999999997	0103000020E610000001000000050000007C46223482294440384888F2052B4C407C46223482294440E21E4B1FBA2C4C4097C9703C9F2B4440E21E4B1FBA2C4C4097C9703C9F2B4440384888F2052B4C407C46223482294440384888F2052B4C40
12619	Торчино	1	3	1017	40.536710999999997	40.562969000000002	56.565069000000001	56.547046000000002	0103000020E61000000100000005000000A43330F2B24444402DB4739A05464C40A43330F2B2444440E17D552E54484C40B7D4415E0F484440E17D552E54484C40B7D4415E0F4844402DB4739A05464C40A43330F2B24444402DB4739A05464C40
48561	Суходол	1	3	1017	40.427061999999999	40.447094999999997	56.199821999999998	56.190325999999999	0103000020E61000000100000005000000A3AEB5F7A93644400CCA349A5C184C40A3AEB5F7A9364440BA826DC493194C40419AB1683A394440BA826DC493194C40419AB1683A3944400CCA349A5C184C40A3AEB5F7A93644400CCA349A5C184C40
12222	Суромна	1	3	1017	40.481212999999997	40.508270000000003	56.195230000000002	56.186067999999999	0103000020E610000001000000050000007CB43863983D4440836A8313D1174C407CB43863983D44405B99F04BFD184C40DBC4C9FD0E4144405B99F04BFD184C40DBC4C9FD0E414440836A8313D1174C407CB43863983D4440836A8313D1174C40
8829	Суздаль	1	3	1017	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
48425	Старый Двор	1	3	1017	40.169227999999997	40.196500999999998	56.29027	56.278702000000003	0103000020E61000000100000005000000A3C85A43A915444037AAD381AC234C40A3C85A43A915444045813E9127254C40CE50DCF12619444045813E9127254C40CE50DCF12619444037AAD381AC234C40A3C85A43A915444037AAD381AC234C40
12796	Спасское-Городище	1	3	1017	40.517162999999996	40.534860000000002	56.369934999999998	56.355249999999998	0103000020E61000000100000005000000C2D9AD6532424440B6F3FDD4782D4C40C2D9AD6532424440A852B3075A2F4C4023F8DF4A76444440A852B3075A2F4C4023F8DF4A76444440B6F3FDD4782D4C40C2D9AD6532424440B6F3FDD4782D4C40
47678	Спасское	1	3	1017	40.262526999999999	40.278067999999998	56.138328000000001	56.129097999999999	0103000020E6100000010000000500000093A8177C9A21444050FD834886104C4093A8177C9A214440800F5EBBB4114C40350873BB97234440800F5EBBB4114C40350873BB9723444050FD834886104C4093A8177C9A21444050FD834886104C40
47168	Сокол	1	3	1017	40.547975999999998	40.563426999999997	56.255021999999997	56.249817	0103000020E61000000100000005000000177FDB13244644400F7EE200FA1F4C40177FDB132446444058E1968FA4204C4079573D601E48444058E1968FA4204C4079573D601E4844400F7EE200FA1F4C40177FDB13244644400F7EE200FA1F4C40
12617	Содышка	1	3	1017	40.380063	40.391345000000001	56.195720999999999	56.189435000000003	0103000020E61000000100000005000000B7B585E7A5304440E0DBF4673F184C40B7B585E7A5304440F911BF620D194C40003ACC9717324440F911BF620D194C40003ACC9717324440E0DBF4673F184C40B7B585E7A5304440E0DBF4673F184C40
48534	Садовый	1	3	1017	40.395792	40.415762000000001	56.228600999999998	56.214587000000002	0103000020E610000001000000050000005C02F04FA9324440C9923996771B4C405C02F04FA93244409C6A2DCC421D4C40B47570B0373544409C6A2DCC421D4C40B47570B037354440C9923996771B4C405C02F04FA9324440C9923996771B4C40
48213	Раменье	1	3	1017	40.582022000000002	40.602387	56.295054999999998	56.286388000000002	0103000020E61000000100000005000000B9C667B27F4A4440C2FBAA5CA8244C40B9C667B27F4A4440B9C2BB5CC4254C408D4468041B4D4440B9C2BB5CC4254C408D4468041B4D4440C2FBAA5CA8244C40B9C667B27F4A4440C2FBAA5CA8244C40
48490	Порецкое	1	3	1017	40.515726000000001	40.534761000000003	56.279451999999999	56.257548	0103000020E6100000010000000500000034D93F4F034244403A933655F7204C4034D93F4F03424440A1664815C5234C409016670C73444440A1664815C5234C409016670C734444403A933655F7204C4034D93F4F034244403A933655F7204C40
12277	Ославское	1	3	1017	40.528599	40.543106999999999	56.237126000000004	56.223061000000001	0103000020E6100000010000000500000062D9CC21A9434440AC014A438D1C4C4062D9CC21A943444002840F255A1E4C40459DB9878445444002840F255A1E4C40459DB98784454440AC014A438D1C4C4062D9CC21A9434440AC014A438D1C4C40
13214	Омутское	1	3	1017	40.419445000000003	40.442495000000001	56.496433000000003	56.477367999999998	0103000020E6100000010000000500000041BCAE5FB0354440161406651A3D4C4041BCAE5FB0354440DDD3D51D8B3F4C405FD218ADA3384440DDD3D51D8B3F4C405FD218ADA3384440161406651A3D4C4041BCAE5FB0354440161406651A3D4C40
54154	Новое Село	1	3	1017	40.500624999999999	40.532974000000003	56.220553000000002	56.206181000000001	0103000020E61000000100000005000000AE47E17A144044403E079623641A4C40AE47E17A144044407104A9143B1C4C4025CFF57D384444407104A9143B1C4C4025CFF57D384444403E079623641A4C40AE47E17A144044403E079623641A4C40
48311	Новоалександрово	1	3	1017	40.248423000000003	40.278965999999997	56.230567000000001	56.217120000000001	0103000020E6100000010000000500000080492A53CC1F44405DA79196CA1B4C4080492A53CC1F4440B7442E38831D4C4014596B28B5234440B7442E38831D4C4014596B28B52344405DA79196CA1B4C4080492A53CC1F44405DA79196CA1B4C40
12917	Мордыш	1	3	1017	40.595540999999997	40.627225000000003	56.314791	56.304206000000001	0103000020E61000000100000005000000AC36FFAF3A4C44409D9FE238F0264C40AC36FFAF3A4C44409E094D124B284C40E71DA7E8485044409E094D124B284C40E71DA7E8485044409D9FE238F0264C40AC36FFAF3A4C44409D9FE238F0264C40
13135	Ляховицы	1	3	1017	40.613650999999997	40.636639000000002	56.418053999999998	56.408875999999999	0103000020E610000001000000050000002F14B01D8C4E4440450F7C0C56344C402F14B01D8C4E444022FB20CB82354C40D82D02637D51444022FB20CB82354C40D82D02637D514440450F7C0C56344C402F14B01D8C4E4440450F7C0C56344C40
12063	Лемешки	1	3	1017	40.563704999999999	40.595289999999999	56.211723999999997	56.203392000000001	0103000020E61000000100000005000000BCCB457C274844404F22C2BF081A4C40BCCB457C274844409FE3A3C5191B4C4063D17476324C44409FE3A3C5191B4C4063D17476324C44404F22C2BF081A4C40BCCB457C274844404F22C2BF081A4C40
48333	Кутуково	1	3	1017	40.213819999999998	40.235073999999997	56.264046999999998	56.255653000000002	0103000020E61000000100000005000000889D29745E1B4440E90FCD3CB9204C40889D29745E1B4440AFCDC64ACC214C40E811A3E7161E4440AFCDC64ACC214C40E811A3E7161E4440E90FCD3CB9204C40889D29745E1B4440E90FCD3CB9204C40
47921	Красное	1	3	1017	40.489558000000002	40.508037000000002	56.437685999999999	56.429966999999998	0103000020E6100000010000000500000062BF27D6A93E4440FBAD9D2809374C4062BF27D6A93E444062F5471806384C4038143E5B0741444062F5471806384C4038143E5B07414440FBAD9D2809374C4062BF27D6A93E4440FBAD9D2809374C40
48595	Красногвардейский	1	3	1017	40.530467000000002	40.551586999999998	56.508614999999999	56.494525000000003	0103000020E61000000100000005000000BA4DB857E6434440F7065F984C3F4C40BA4DB857E6434440A5A0DB4B1A414C400AF31E679A464440A5A0DB4B1A414C400AF31E679A464440F7065F984C3F4C40BA4DB857E6434440F7065F984C3F4C40
48305	Клементьево	1	3	1017	40.116452000000002	40.139915999999999	56.282344999999999	56.266857000000002	0103000020E61000000100000005000000E3C62DE6E70E4440B6DAC35E28224C40E3C62DE6E70E4440359886E123244C40F4177AC4E8114440359886E123244C40F4177AC4E8114440B6DAC35E28224C40E3C62DE6E70E4440B6DAC35E28224C40
48391	Зелени	1	3	1017	40.304577000000002	40.323639	56.206422000000003	56.198779999999999	0103000020E61000000100000005000000910E0F61FC264440A88C7F9F71194C40910E0F61FC26444064963D096C1A4C40E65AB4006D29444064963D096C1A4C40E65AB4006D294440A88C7F9F71194C40910E0F61FC264440A88C7F9F71194C40
48046	Гридино	1	3	1017	40.603158999999998	40.608603000000002	56.470208999999997	56.464485000000003	0103000020E61000000100000005000000DFA46950344D4440C53D963E743B4C40DFA46950344D444076A4FACE2F3C4C40AE9FFEB3E64D444076A4FACE2F3C4C40AE9FFEB3E64D4440C53D963E743B4C40DFA46950344D4440C53D963E743B4C40
48697	Глебовское	1	3	1017	40.496690999999998	40.507057000000003	56.416316000000002	56.402048000000001	0103000020E61000000100000005000000D89B1892933F44400BB6114F76334C40D89B1892933F44409966BAD749354C409C1A683EE74044409966BAD749354C409C1A683EE74044400BB6114F76334C40D89B1892933F44400BB6114F76334C40
48567	Гавриловское	1	3	1017	40.268706999999999	40.295253000000002	56.403576999999999	56.385261999999997	0103000020E61000000100000005000000679AB0FD642244401E32E54350314C40679AB0FD642244407A354069A8334C40E085ADD9CA2544407A354069A8334C40E085ADD9CA2544401E32E54350314C40679AB0FD642244401E32E54350314C40
13199	Весь	1	3	1017	40.335928000000003	40.371150999999998	56.493447000000003	56.480772999999999	0103000020E61000000100000005000000C5E74EB0FF2A444060E63BF8893D4C40C5E74EB0FF2A444098A77345293F4C4058703FE0812F444098A77345293F4C4058703FE0812F444060E63BF8893D4C40C5E74EB0FF2A444060E63BF8893D4C40
48499	Борисовское	1	3	1017	40.467702000000003	40.489899999999999	56.279822000000003	56.259887999999997	0103000020E610000001000000050000000C23BDA8DD3B4440B94F8E0244214C400C23BDA8DD3B4440C5591135D1234C40BB270F0BB53E4440C5591135D1234C40BB270F0BB53E4440B94F8E0244214C400C23BDA8DD3B4440B94F8E0244214C40
48370	Богослово	1	3	1017	40.311942999999999	40.335120000000003	56.164216000000003	56.151271000000001	0103000020E61000000100000005000000AA9B8BBFED274440A7EA1ED95C134C40AA9B8BBFED2744406FBDA60705154C40261E5036E52A44406FBDA60705154C40261E5036E52A4440A7EA1ED95C134C40AA9B8BBFED274440A7EA1ED95C134C40
11927	Боголюбово	1	3	1017	40.511046	40.547392000000002	56.208514999999998	56.182296000000001	0103000020E61000000100000005000000356090F4694144408718AF7955174C40356090F469414440DBDC989EB01A4C40C80BE9F010464440DBDC989EB01A4C40C80BE9F0104644408718AF7955174C40356090F4694144408718AF7955174C40
23432	Чамерево	1	3	1045	40.782147999999999	40.803941999999999	56.076152	56.062086999999998	0103000020E61000000100000005000000DF50F86C1D644440DD408177F2074C40DF50F86C1D64444033C34659BF094C40BFF04A92E766444033C34659BF094C40BFF04A92E7664440DD408177F2074C40DF50F86C1D644440DD408177F2074C40
48081	Улыбышево	1	3	1045	40.318420000000003	40.340814999999999	56.024124	56.016571999999996	0103000020E6100000010000000500000038328FFCC1284440C00303081F024C4038328FFCC12844403C86C77E16034C403D7E6FD39F2B44403C86C77E16034C403D7E6FD39F2B4440C00303081F024C4038328FFCC1284440C00303081F024C40
9169	Тюрмеровка	1	3	1045	41.112755	41.131628999999997	55.933675000000001	55.920940999999999	0103000020E61000000100000005000000F1BA7EC16E8E4440D4450A65E1F54B40F1BA7EC16E8E4440E10B93A982F74B40431A1538D9904440E10B93A982F74B40431A1538D9904440D4450A65E1F54B40F1BA7EC16E8E4440D4450A65E1F54B40
22285	Судогда	1	3	1045	40.845272999999999	40.878888000000003	55.973047999999999	55.942701	0103000020E610000001000000050000008D98D9E7316C44400874266DAAF84B408D98D9E7316C444017B83CD68CFC4B40666CE8667F70444017B83CD68CFC4B40666CE8667F7044400874266DAAF84B408D98D9E7316C44400874266DAAF84B40
46719	Станки	1	3	1045	40.678330000000003	40.681879000000002	56.054285999999998	56.051054000000001	0103000020E61000000100000005000000A6F27684D35644403D2AFEEF88064C40A6F27684D3564440B950F9D7F2064C40236AA2CF47574440B950F9D7F2064C40236AA2CF475744403D2AFEEF88064C40A6F27684D35644403D2AFEEF88064C40
23295	Сойма	1	3	1045	40.714784000000002	40.739801999999997	55.979076999999997	55.968694999999997	0103000020E610000001000000050000001FDAC70A7E5B44403C66A032FEFB4B401FDAC70A7E5B444005A2276552FD4B40F8C1F9D4B15E444005A2276552FD4B40F8C1F9D4B15E44403C66A032FEFB4B401FDAC70A7E5B44403C66A032FEFB4B40
23829	Передел	1	3	1045	40.978960000000001	41.009683000000003	55.919327000000003	55.899006999999997	0103000020E61000000100000005000000CC0BB08F4E7D444002F04FA912F34B40CC0BB08F4E7D444037AAD381ACF54B40E129E44A3D81444037AAD381ACF54B40E129E44A3D81444002F04FA912F34B40CC0BB08F4E7D444002F04FA912F34B40
49580	Павловка	1	3	1045	41.368650000000002	41.374983	55.895130999999999	55.893045999999998	0103000020E61000000100000005000000D0D556EC2FAF44406CE9D1544FF24B40D0D556EC2FAF4440615111A793F24B402AC76471FFAF4440615111A793F24B402AC76471FFAF44406CE9D1544FF24B40D0D556EC2FAF44406CE9D1544FF24B40
54172	Овцино	1	3	1045	40.760750999999999	40.782921000000002	56.004891000000001	55.995367000000002	0103000020E610000001000000050000001CB3EC49606144404242942F68FF4B401CB3EC4960614440BA85AE44A0004C40022D5DC136644440BA85AE44A0004C40022D5DC1366444404242942F68FF4B401CB3EC49606144404242942F68FF4B40
48135	Овсянниково	1	3	1045	40.898803999999998	40.923067000000003	55.844439999999999	55.834057000000001	0103000020E61000000100000005000000CAC16C020C734440FCFF3861C2EA4B40CAC16C020C73444095B7239C16EC4B402882380F2776444095B7239C16EC4B402882380F27764440FCFF3861C2EA4B40CAC16C020C734440FCFF3861C2EA4B40
54171	Новопетрово	1	3	1045	40.668934	40.688760000000002	56.038910999999999	56.030043999999997	0103000020E610000001000000050000005B971AA19F55444073B8567BD8034C405B971AA19F554440323A2009FB044C408065A54929584440323A2009FB044C408065A5492958444073B8567BD8034C405B971AA19F55444073B8567BD8034C40
23812	Муромцево	1	3	1045	40.887512000000001	40.925905999999998	55.939523999999999	55.920129000000003	0103000020E610000001000000050000005E6743FE99714440F48C7DC9C6F54B405E6743FE997144404FE78A5242F84B40C8957A16847644404FE78A5242F84B40C8957A1684764440F48C7DC9C6F54B405E6743FE99714440F48C7DC9C6F54B40
23541	Мошок	1	3	1045	41.214651000000003	41.244089000000002	55.810400000000001	55.794224	0103000020E61000000100000005000000E08618AF799B444062D9CC21A9E54B40E08618AF799B4440D656EC2FBBE74B401C28F04E3E9F4440D656EC2FBBE74B401C28F04E3E9F444062D9CC21A9E54B40E08618AF799B444062D9CC21A9E54B40
48320	Красный Куст	1	3	1045	41.269196999999998	41.286427000000003	55.868127000000001	55.854658000000001	0103000020E6100000010000000500000035971B0C75A24440E4A1EF6E65ED4B4035971B0C75A2444026E318C91EEF4B4080D8D2A3A9A4444026E318C91EEF4B4080D8D2A3A9A44440E4A1EF6E65ED4B4035971B0C75A24440E4A1EF6E65ED4B40
47915	Красный Богатырь	1	3	1045	41.118999000000002	41.141762	56.023319000000001	56.010770000000001	0103000020E61000000100000005000000DCA0F65B3B8F444093E34EE960014C40DCA0F65B3B8F44400E30F31DFC024C4064E8D841259244400E30F31DFC024C4064E8D8412592444093E34EE960014C40DCA0F65B3B8F444093E34EE960014C40
23559	Кондряево	1	3	1045	41.037126000000001	41.074576999999998	55.836872999999997	55.818407000000001	0103000020E6100000010000000500000068EA758BC0844440A3E8818FC1E84B4068EA758BC0844440E4F38AA71EEB4B40530438BD8B894440E4F38AA71EEB4B40530438BD8B894440A3E8818FC1E84B4068EA758BC0844440A3E8818FC1E84B40
47953	Картмазово	1	3	1045	41.088006999999998	41.118765000000003	56.069780999999999	56.057121000000002	0103000020E61000000100000005000000D76839D0438B44401975ADBD4F074C40D76839D0438B4440EB707495EE084C40697407B1338F4440EB707495EE084C40697407B1338F44401975ADBD4F074C40D76839D0438B44401975ADBD4F074C40
46836	Ильино	1	3	1045	40.600572	40.612411999999999	55.921318999999997	55.910361999999999	0103000020E610000001000000050000005872158BDF4C4440B5C2F4BD86F44B405872158BDF4C44407A17EFC7EDF54B40C7D63384634E44407A17EFC7EDF54B40C7D63384634E4440B5C2F4BD86F44B405872158BDF4C4440B5C2F4BD86F44B40
23912	Дворишнево	1	3	1045	40.904938999999999	40.915494000000002	55.855061999999997	55.846446	0103000020E61000000100000005000000FEEF880AD57344403EEAAF5758EC4B40FEEF880AD5734440B306EFAB72ED4B4095D74AE82E754440B306EFAB72ED4B4095D74AE82E7544403EEAAF5758EC4B40FEEF880AD57344403EEAAF5758EC4B40
23660	Гонобилово	1	3	1045	41.320490999999997	41.336741000000004	55.817421000000003	55.808225	0103000020E61000000100000005000000C7D45DD905A94440A167B3EA73E74B40C7D45DD905A9444025085740A1E84B40761C3F541AAB444025085740A1E84B40761C3F541AAB4440A167B3EA73E74B40C7D45DD905A94440A167B3EA73E74B40
46523	Головино	1	3	1045	40.420800999999997	40.458252000000002	55.966996999999999	55.935929000000002	0103000020E61000000100000005000000E28FA2CEDC35444062307F85CCF74B40E28FA2CEDC354440412AC58EC6FB4B40CEA96400A83A4440412AC58EC6FB4B40CEA96400A83A444062307F85CCF74B40E28FA2CEDC35444062307F85CCF74B40
48020	Вяткино	1	3	1045	40.474843999999997	40.494112999999999	56.075614000000002	56.058252000000003	0103000020E61000000100000005000000D5592DB0C73C44409B7631CD74074C40D5592DB0C73C4440548F34B8AD094C40A4C343183F3F4440548F34B8AD094C40A4C343183F3F44409B7631CD74074C40D5592DB0C73C44409B7631CD74074C40
24002	Вольная Артемовка	1	3	1045	40.772464999999997	40.787439999999997	55.855234000000003	55.846077000000001	0103000020E61000000100000005000000FE261422E0624440EB724A404CEC4B40FE261422E0624440B136C64E78ED4B40F7C77BD5CA644440B136C64E78ED4B40F7C77BD5CA644440EB724A404CEC4B40FE261422E0624440EB724A404CEC4B40
23715	Вежки	1	3	1045	41.318218000000002	41.331028000000003	55.896241000000003	55.887948000000002	0103000020E61000000100000005000000D07F0F5EBBA844403946B247A8F14B40D07F0F5EBBA84440CC2A6C06B8F24B40B80721205FAA4440CC2A6C06B8F24B40B80721205FAA44403946B247A8F14B40D07F0F5EBBA844403946B247A8F14B40
23922	Бег	1	3	1045	40.830728999999998	40.849881000000003	55.943643000000002	55.932051999999999	0103000020E610000001000000050000005D6BEF53556A4440F015DD7A4DF74B405D6BEF53556A4440B70C384BC9F84B40F33E8EE6C86C4440B70C384BC9F84B40F33E8EE6C86C4440F015DD7A4DF74B405D6BEF53556A4440F015DD7A4DF74B40
48043	Бараки	1	3	1045	40.523955000000001	40.558010000000003	56.053516999999999	56.034295	0103000020E61000000100000005000000B0C91AF5104344404AB54FC763044C40B0C91AF510434440D86322A5D9064C40A56B26DF6C474440D86322A5D9064C40A56B26DF6C4744404AB54FC763044C40B0C91AF5104344404AB54FC763044C40
22522	Андреево	1	3	1045	41.131503000000002	41.169196999999997	55.954434999999997	55.933948000000001	0103000020E61000000100000005000000B7291E17D59044401215AA9B8BF74B40B7291E17D5904440319413ED2AFA4B4068CA4E3FA8954440319413ED2AFA4B4068CA4E3FA89544401215AA9B8BF74B40B7291E17D59044401215AA9B8BF74B40
9372	Черкутино	1	3	858	39.741791999999997	39.781379999999999	56.197989	56.182912000000002	0103000020E610000001000000050000009B374E0AF3DE4340E20511A969174C409B374E0AF3DE4340DFFB1BB457194C40CEDF844204E44340DFFB1BB457194C40CEDF844204E44340E20511A969174C409B374E0AF3DE4340E20511A969174C40
9472	Фетинино	1	3	858	39.846426999999998	39.862085	56.284109000000001	56.272889999999997	0103000020E61000000100000005000000C7B94DB857EC4340E5B33C0FEE224C40C7B94DB857EC4340E8BF07AF5D244C40A3AF20CD58EE4340E8BF07AF5D244C40A3AF20CD58EE4340E5B33C0FEE224C40C7B94DB857EC4340E5B33C0FEE224C40
48849	Степаньково	1	3	858	39.874364999999997	39.885908000000001	56.083289999999998	56.073047000000003	0103000020E610000001000000050000002EE23B31EBEF43401409A69A59094C402EE23B31EBEF4340BB0A293FA90A4C40E4A1EF6E65F14340BB0A293FA90A4C40E4A1EF6E65F143401409A69A59094C402EE23B31EBEF43401409A69A59094C40
9085	Ставрово	1	3	858	39.993257	40.041226999999999	56.138558000000003	56.121682	0103000020E61000000100000005000000F4C29D0B23FF434085419946930F4C40F4C29D0B23FF4340B24CBF44BC114C40295B24ED46054440B24CBF44BC114C40295B24ED4605444085419946930F4C40F4C29D0B23FF434085419946930F4C40
6413	Собинка	1	3	858	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
9282	Рождествено	1	3	858	39.872945999999999	39.896732999999998	56.201118999999998	56.186408999999998	0103000020E610000001000000050000004696CCB1BCEF43400C570740DC174C404696CCB1BCEF434057CD7344BE194C403A1F9E25C8F2434057CD7344BE194C403A1F9E25C8F243400C570740DC174C404696CCB1BCEF43400C570740DC174C40
46392	Никулино	1	3	858	40.163029999999999	40.170997999999997	56.002243999999997	55.993243	0103000020E610000001000000050000002922C32ADE1444408FFD2C9622FF4B402922C32ADE1444405D4E098849004C4038D73043E31544405D4E098849004C4038D73043E31544408FFD2C9622FF4B402922C32ADE1444408FFD2C9622FF4B40
9853	Лакинск	1	3	858	39.911205000000002	40.009444999999999	56.035657999999998	56.001066000000002	0103000020E61000000100000005000000D1798D5DA2F443409B9141EE22004C40D1798D5DA2F443409EEBFB7090044C402C0E677E350144409EEBFB7090044C402C0E677E350144409B9141EE22004C40D1798D5DA2F443409B9141EE22004C40
8922	Курилово	1	3	858	39.963523000000002	39.988154999999999	56.098612000000003	56.087394000000003	0103000020E61000000100000005000000CFF8BEB854FB4340EEEE01BA2F0B4C40CFF8BEB854FB4340207F69519F0C4C407F30F0DC7BFE4340207F69519F0C4C407F30F0DC7BFE4340EEEE01BA2F0B4C40CFF8BEB854FB4340EEEE01BA2F0B4C40
8618	Копнино	1	3	858	39.874535999999999	39.894953999999998	55.907590999999996	55.894278	0103000020E610000001000000050000005B96AFCBF0EF434022C495B377F24B405B96AFCBF0EF43406C921FF12BF44B4052B648DA8DF243406C921FF12BF44B4052B648DA8DF2434022C495B377F24B405B96AFCBF0EF434022C495B377F24B40
8741	Колокша	1	3	858	40.137903999999999	40.152537000000002	56.082822999999998	56.074925999999998	0103000020E6100000010000000500000069FE98D6A61144405FCFD72C97094C4069FE98D6A6114440A52DAEF1990A4C400937195586134440A52DAEF1990A4C4009371955861344405FCFD72C97094C4069FE98D6A61144405FCFD72C97094C40
9412	Кишлеево	1	3	858	40.012481000000001	40.037382000000001	56.249296000000001	56.227530000000002	0103000020E61000000100000005000000236937FA98014440F06DFAB31F1D4C40236937FA9801444006836BEEE81F4C40C3BAF1EEC804444006836BEEE81F4C40C3BAF1EEC8044440F06DFAB31F1D4C40236937FA98014440F06DFAB31F1D4C40
8648	Заречное	1	3	858	39.913567	39.927545000000002	55.937461999999996	55.926141000000001	0103000020E6100000010000000500000038DA71C3EFF443400C3ECDC98BF64B4038DA71C3EFF44340129F3BC1FEF74B40BF4868CBB9F64340129F3BC1FEF74B40BF4868CBB9F643400C3ECDC98BF64B4038DA71C3EFF443400C3ECDC98BF64B40
9338	Ельтесуново	1	3	858	39.876888999999998	39.899078000000003	56.239902999999998	56.230176999999998	0103000020E610000001000000050000006F9C14E63DF043404CA59F70761D4C406F9C14E63DF043402C9B3924B51E4C40CC46E7FC14F343402C9B3924B51E4C40CC46E7FC14F343404CA59F70761D4C406F9C14E63DF043404CA59F70761D4C40
46553	Демидово	1	3	858	40.007747000000002	40.029961999999998	56.035657999999998	56.027045999999999	0103000020E6100000010000000500000031D28BDAFD0044406ABE4A3E76034C4031D28BDAFD0044409EEBFB7090044C40B60F79CBD50344409EEBFB7090044C40B60F79CBD50344406ABE4A3E76034C4031D28BDAFD0044406ABE4A3E76034C40
9030	Глухово	1	3	858	39.835585000000002	39.854287999999997	56.134394999999998	56.124139999999997	0103000020E610000001000000050000009B030473F4EA43400E10CCD1E30F4C409B030473F4EA43407ADFF8DA33114C40C0AE264F59ED43407ADFF8DA33114C40C0AE264F59ED43400E10CCD1E30F4C409B030473F4EA43400E10CCD1E30F4C40
8561	Вышманово	1	3	858	40.189323000000002	40.218159	55.999682	55.990977000000001	0103000020E61000000100000005000000B8B06EBC3B1844404A0B9755D8FE4B40B8B06EBC3B1844402F336C94F5FF4B40FE2955A2EC1B44402F336C94F5FF4B40FE2955A2EC1B44404A0B9755D8FE4B40B8B06EBC3B1844404A0B9755D8FE4B40
9253	Волосово	1	3	858	40.152061000000003	40.173118000000002	56.176394000000002	56.166029999999999	0103000020E61000000100000005000000A0FF1EBC76134440D313967840154C40A0FF1EBC76134440F69A1E1494164C40AA2C0ABB28164440F69A1E1494164C40AA2C0ABB28164440D313967840154C40A0FF1EBC76134440D313967840154C40
8998	Васильевка	1	3	858	39.965400000000002	39.983410999999997	56.048470000000002	56.034300000000002	0103000020E610000001000000050000007AC7293A92FB43405C2041F163044C407AC7293A92FB4340276BD44334064C4069C36169E0FD4340276BD44334064C4069C36169E0FD43405C2041F163044C407AC7293A92FB43405C2041F163044C40
8485	Березники	1	3	858	40.087094999999998	40.122605	55.879697	55.863778000000003	0103000020E610000001000000050000009352D0ED250B44408D800A4790EE4B409352D0ED250B4440D5B14AE999F04B40BDA94885B10F4440D5B14AE999F04B40BDA94885B10F44408D800A4790EE4B409352D0ED250B44408D800A4790EE4B40
8910	Бабаево	1	3	858	40.067349999999998	40.084156999999998	56.107398000000003	56.097161	0103000020E610000001000000050000005BB1BFEC9E0844402CB98AC56F0C4C405BB1BFEC9E084440F2D3B837BF0D4C405F5D15A8C50A4440F2D3B837BF0D4C405F5D15A8C50A44402CB98AC56F0C4C405BB1BFEC9E0844402CB98AC56F0C4C40
8540	Асерхово	1	3	858	40.240921999999998	40.256265999999997	55.951729	55.939514000000003	0103000020E6100000010000000500000086713788D61E44402C11A8FE41F84B4086713788D61E4440D0D38041D2F94B40D2890453CD204440D0D38041D2F94B40D2890453CD2044402C11A8FE41F84B4086713788D61E44402C11A8FE41F84B40
5906	Чертково	1	3	707	42.001001000000002	42.030807000000003	55.941606999999998	55.925677	0103000020E61000000100000005000000B421FFCC2000454067D47C957CF64B40B421FFCC20004540A357039486F84B4073BED87BF1034540A357039486F84B4073BED87BF103454067D47C957CF64B40B421FFCC2000454067D47C957CF64B40
5082	Переложниково	1	3	707	41.599677999999997	41.630220999999999	55.757621999999998	55.737856000000001	0103000020E61000000100000005000000BA10AB3FC2CC44402594BE1072DE4B40BA10AB3FC2CC4440745DF8C1F9E04B404F20EC14ABD04440745DF8C1F9E04B404F20EC14ABD044402594BE1072DE4B40BA10AB3FC2CC44402594BE1072DE4B40
5506	Первомайский	1	3	707	41.357978000000003	41.379573000000001	55.681843999999998	55.668827999999998	0103000020E6100000010000000500000000581D39D2AD44401553E9279CD54B4000581D39D2AD4440A67C08AA46D74B40E9B81AD995B04440A67C08AA46D74B40E9B81AD995B044401553E9279CD54B4000581D39D2AD44401553E9279CD54B40
5683	Новый Быт	1	3	707	41.597810000000003	41.638638	55.990684999999999	55.963102999999997	0103000020E61000000100000005000000639CBF0985CC4440F9D687F546FB4B40639CBF0985CC4440A2D11DC4CEFE4B40CEFDD5E3BED14440A2D11DC4CEFE4B40CEFDD5E3BED14440F9D687F546FB4B40639CBF0985CC4440F9D687F546FB4B40
5013	Новлянка	1	3	707	41.711078000000001	41.756945999999999	55.812913999999999	55.794953	0103000020E61000000100000005000000DA73999A04DB4440B56D1805C1E54B40DA73999A04DB4440F33AE2900DE84B40446B459BE3E04440F33AE2900DE84B40446B459BE3E04440B56D1805C1E54B40DA73999A04DB4440B56D1805C1E54B40
46994	Неклюдово	1	3	707	41.543604999999999	41.551879	55.742584999999998	55.735230999999999	0103000020E61000000100000005000000967840D994C54440B000A60C1CDE4B40967840D994C5444005C078060DDF4B40B22C98F8A3C6444005C078060DDF4B40B22C98F8A3C64440B000A60C1CDE4B40967840D994C54440B000A60C1CDE4B40
5813	Надеждино	1	3	707	41.891432999999999	41.906992000000002	55.953231000000002	55.935823999999997	0103000020E610000001000000050000009FC9FE791AF24440EC67B114C9F74B409FC9FE791AF244404644317903FA4B40E8DD585018F444404644317903FA4B40E8DD585018F44440EC67B114C9F74B409FC9FE791AF24440EC67B114C9F74B40
5152	Малышево	1	3	707	41.521633000000001	41.553783000000003	55.732711999999999	55.718344000000002	0103000020E61000000100000005000000D7C1C1DEC4C2444090A339B2F2DB4B40D7C1C1DEC4C2444081B1BE81C9DD4B40570A815CE2C6444081B1BE81C9DD4B40570A815CE2C6444090A339B2F2DB4B40D7C1C1DEC4C2444090A339B2F2DB4B40
5269	Красная Ушна	1	3	707	41.547513000000002	41.572693000000001	55.805785999999998	55.791232999999998	0103000020E610000001000000050000004391EEE714C644400B42791F47E54B404391EEE714C644408EC9E2FE23E74B40F6D214014EC944408EC9E2FE23E74B40F6D214014EC944400B42791F47E54B404391EEE714C644400B42791F47E54B40
5925	Красная Горбатка	1	3	707	41.720177999999997	41.793723	55.897841	55.856592999999997	0103000020E610000001000000050000003BA6EECA2EDC4440C37DE4D6A4ED4B403BA6EECA2EDC444004013274ECF24B40A08A1BB798E5444004013274ECF24B40A08A1BB798E54440C37DE4D6A4ED4B403BA6EECA2EDC4440C37DE4D6A4ED4B40
5464	Кочергино	1	3	707	41.390937000000001	41.414256999999999	55.710417999999997	55.699883	0103000020E61000000100000005000000EFE53E390AB24440600322C495D94B40EFE53E390AB24440AF3E1EFAEEDA4B40CD91955F06B54440AF3E1EFAEEDA4B40CD91955F06B54440600322C495D94B40EFE53E390AB24440600322C495D94B40
5167	Костенец	1	3	707	41.418398000000003	41.431010999999998	55.808847	55.798479999999998	0103000020E610000001000000050000001D5BCF108EB544404A41B79734E64B401D5BCF108EB54440DE3B6A4C88E74B40AE9B525E2BB74440DE3B6A4C88E74B40AE9B525E2BB744404A41B79734E64B401D5BCF108EB544404A41B79734E64B40
5612	Копнино	1	3	707	41.602086	41.634748000000002	55.930539000000003	55.921536000000003	0103000020E6100000010000000500000092B06F2711CD4440180B43E4F4F54B4092B06F2711CD44408753E6E61BF74B40C899266C3FD144408753E6E61BF74B40C899266C3FD14440180B43E4F4F54B4092B06F2711CD4440180B43E4F4F54B40
5731	Ильинское	1	3	707	41.702840999999999	41.721094999999998	55.991625999999997	55.984228999999999	0103000020E61000000100000005000000DBA4A2B1F6D944402C634337FBFD4B40DBA4A2B1F6D9444080EECB99EDFE4B40912749D74CDC444080EECB99EDFE4B40912749D74CDC44402C634337FBFD4B40DBA4A2B1F6D944402C634337FBFD4B40
54167	Ивановское	1	3	707	41.332385000000002	41.354922999999999	55.638174999999997	55.630650000000003	0103000020E610000001000000050000002A5778978BAA4440789CA223B9D04B402A5778978BAA4440F90FE9B7AFD14B4092CCEA1D6EAD4440F90FE9B7AFD14B4092CCEA1D6EAD4440789CA223B9D04B402A5778978BAA4440789CA223B9D04B40
5272	Драчево	1	3	707	41.617320999999997	41.644657000000002	55.701931999999999	55.692242	0103000020E610000001000000050000002711E15F04CF44407575C7629BD84B402711E15F04CF4440080264E8D8D94B409911DE1E84D24440080264E8D8D94B409911DE1E84D244407575C7629BD84B402711E15F04CF44407575C7629BD84B40
5389	Губино	1	3	707	41.667824000000003	41.690731	55.694311999999996	55.682842999999998	0103000020E61000000100000005000000F1BDBF417BD54440B9A6406667D74B40F1BDBF417BD54440349C3237DFD84B40ACAA97DF69D84440349C3237DFD84B40ACAA97DF69D84440B9A6406667D74B40F1BDBF417BD54440B9A6406667D74B40
4919	Высоково	1	3	707	41.758420000000001	41.782710000000002	55.847659	55.830275	0103000020E61000000100000005000000F05014E813E14440DCD7817346EA4B40F05014E813E144407D94111780EC4B4047205ED72FE444407D94111780EC4B4047205ED72FE44440DCD7817346EA4B40F05014E813E14440DCD7817346EA4B40
5780	Вощиха	1	3	707	41.789402000000003	41.808249000000004	55.922873000000003	55.914776000000003	0103000020E61000000100000005000000D1B2EE1F0BE544403695456117F54B40D1B2EE1F0BE5444043AED4B320F64B402A0307B474E7444043AED4B320F64B402A0307B474E744403695456117F54B40D1B2EE1F0BE544403695456117F54B40
54143	ЗАТО город Радужный	1	3	1338	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
60377	п. Сушнево-1	1	3	751	38.864792999999999	39.803460999999999	56.516204000000002	55.758493000000001	0103000020E61000000100000005000000A5677A89B16E43405A9F724C16E14B40A5677A89B16E43403E0801F912424C40444E5FCFD7E643403E0801F912424C40444E5FCFD7E643405A9F724C16E14B40A5677A89B16E43405A9F724C16E14B40
6554	Труд	1	3	751	39.610332	39.636231000000002	55.970030000000001	55.961948999999997	0103000020E61000000100000005000000E4D9E55B1FCE4340BFB5132521FB4B40E4D9E55B1FCE4340C7116BF129FC4B40C7D9740470D14340C7116BF129FC4B40C7D9740470D14340BFB5132521FB4B40E4D9E55B1FCE4340BFB5132521FB4B40
6054	Старые Петушки	1	3	751	39.451177999999999	39.498860000000001	55.949213999999998	55.933413000000002	0103000020E610000001000000050000005C566133C0B94340A454C2137AF74B405C566133C0B94340E27327D87FF94B402BA4FCA4DABF4340E27327D87FF94B402BA4FCA4DABF4340A454C2137AF74B405C566133C0B94340A454C2137AF74B40
6167	Старые Омутищи	1	3	751	39.311228999999997	39.334909000000003	55.910518000000003	55.897216	0103000020E610000001000000050000008C48145AD6A7434056B950F9D7F24B408C48145AD6A74340AD3594DA8BF44B406B11514CDEAA4340AD3594DA8BF44B406B11514CDEAA434056B950F9D7F24B408C48145AD6A7434056B950F9D7F24B40
7998	Старое Перепечино	1	3	751	39.192974999999997	39.222448999999997	55.900970999999998	55.884625	0103000020E6100000010000000500000009F9A067B3984340AC1C5A643BF14B4009F9A067B39843407CD2890453F34B4092037635799C43407CD2890453F34B4092037635799C4340AC1C5A643BF14B4009F9A067B3984340AC1C5A643BF14B40
8249	Санинского ДОКа	1	3	751	38.904777000000003	38.918512999999997	56.009441000000002	56.000900000000001	0103000020E61000000100000005000000259694BBCF7343408048BF7D1D004C40259694BBCF734340EB1ED95C35014C40B5F97FD591754340EB1ED95C35014C40B5F97FD5917543408048BF7D1D004C40259694BBCF7343408048BF7D1D004C40
7350	Покров	1	3	751	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
5290	Петушки	1	3	751	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
6652	Пекша	1	3	751	39.689725000000003	39.711815000000001	55.969053000000002	55.956839000000002	0103000020E61000000100000005000000E71DA7E848D84340C8444AB379FA4B40E71DA7E848D843409C8BBFED09FC4B40B0E600C11CDB43409C8BBFED09FC4B40B0E600C11CDB4340C8444AB379FA4B40E71DA7E848D84340C8444AB379FA4B40
6908	Пахомово	1	3	751	39.698231999999997	39.710144	56.066786	56.059609000000002	0103000020E61000000100000005000000A5828AAA5FD943400DC68844A1074C40A5828AAA5FD9434053EA92718C084C40AEB9A3FFE5DA434053EA92718C084C40AEB9A3FFE5DA43400DC68844A1074C40A5828AAA5FD943400DC68844A1074C40
8172	Панфилово	1	3	751	39.075232999999997	39.096953999999997	56.006683000000002	55.993333	0103000020E610000001000000050000003C4A253CA1894340CF84268925FF4B403C4A253CA1894340373811FDDA004C40B29B19FD688C4340373811FDDA004C40B29B19FD688C4340CF84268925FF4B403C4A253CA1894340CF84268925FF4B40
6245	Новое Аннино	1	3	751	39.386777000000002	39.395473000000003	55.937306	55.932243	0103000020E6100000010000000500000029ECA2E881B14340647616BD53F74B4029ECA2E881B143401B2C9CA4F9F74B40BBB9F8DB9EB243401B2C9CA4F9F74B40BBB9F8DB9EB24340647616BD53F74B4029ECA2E881B14340647616BD53F74B40
60380	Новая	1	3	751	39.582053000000002	39.611463999999998	55.931068000000003	55.920830000000002	0103000020E61000000100000005000000F4C473B680CA43407D96E7C1DDF54B40F4C473B680CA4340132D793C2DF74B403657CD7344CE4340132D793C2DF74B403657CD7344CE43407D96E7C1DDF54B40F4C473B680CA43407D96E7C1DDF54B40
6725	Метенино	1	3	751	39.722701999999998	39.745457000000002	55.921919000000003	55.910266	0103000020E610000001000000050000007C60C77F81DC43409354A69883F44B407C60C77F81DC4340D047197101F64B4082C98D226BDF4340D047197101F64B4082C98D226BDF43409354A69883F44B407C60C77F81DC43409354A69883F44B40
8093	Марково	1	3	751	39.274084000000002	39.306648000000003	55.870747999999999	55.858362	0103000020E61000000100000005000000AE2D3C2F15A34340881057CEDEED4B40AE2D3C2F15A343405987A3AB74EF4B4021B1DD3D40A743405987A3AB74EF4B4021B1DD3D40A74340881057CEDEED4B40AE2D3C2F15A34340881057CEDEED4B40
6540	Липна	1	3	751	39.611894999999997	39.649939000000003	55.962311999999997	55.940930999999999	0103000020E61000000100000005000000FFCA4A9352CE43407365506D70F84B40FFCA4A9352CE43403046240A2DFB4B408EB27E3331D343403046240A2DFB4B408EB27E3331D343407365506D70F84B40FFCA4A9352CE43407365506D70F84B40
6839	Ларионово	1	3	751	39.627516999999997	39.642555000000002	56.031357	56.021456999999998	0103000020E610000001000000050000008E57207A52D0434098A25C1ABF024C408E57207A52D0434016C0948103044C40CE70033E3FD2434016C0948103044C40CE70033E3FD2434098A25C1ABF024C408E57207A52D0434098A25C1ABF024C40
6373	Крутово	1	3	751	39.418622999999997	39.444817999999998	55.903216	55.887034	0103000020E610000001000000050000003C2D3F7095B54340543882548AF14B403C2D3F7095B54340AA9CF6949CF34B400856D5CBEFB84340AA9CF6949CF34B400856D5CBEFB84340543882548AF14B403C2D3F7095B54340543882548AF14B40
6318	Костино	1	3	751	39.334854999999997	39.367023000000003	55.995165999999998	55.978448	0103000020E6100000010000000500000077F35487DCAA4340166BB8C83DFD4B4077F35487DCAA4340AA0B789961FF4B409EF0129CFAAE4340AA0B789961FF4B409EF0129CFAAE4340166BB8C83DFD4B4077F35487DCAA4340166BB8C83DFD4B40
54141	Костерево-1	1	3	751	38.864792999999999	39.803460999999999	56.516204000000002	55.758493000000001	0103000020E61000000100000005000000A5677A89B16E43405A9F724C16E14B40A5677A89B16E43403E0801F912424C40444E5FCFD7E643403E0801F912424C40444E5FCFD7E643405A9F724C16E14B40A5677A89B16E43405A9F724C16E14B40
7053	Костерево	1	3	751	39.609883000000004	39.641243000000003	55.943452000000001	55.922984	0103000020E6100000010000000500000075B169A510CE43409A5DF75624F64B4075B169A510CE434043ACFE08C3F84B40FCE4284014D2434043ACFE08C3F84B40FCE4284014D243409A5DF75624F64B4075B169A510CE43409A5DF75624F64B40
6087	Кибирево	1	3	751	39.441242000000003	39.461095	55.968076000000003	55.953876000000001	0103000020E6100000010000000500000092CF2B9E7AB843403B38D89B18FA4B4092CF2B9E7AB84340710514EAE9FB4B40B0AC342905BB4340710514EAE9FB4B40B0AC342905BB43403B38D89B18FA4B4092CF2B9E7AB843403B38D89B18FA4B40
6992	Караваево	1	3	751	39.506289000000002	39.528486999999998	56.137084000000002	56.127206000000001	0103000020E610000001000000050000008BA9F413CEC0434070ED444948104C408BA9F413CEC043400667F0F78B114C403AAE4676A5C343400667F0F78B114C403AAE4676A5C3434070ED444948104C408BA9F413CEC0434070ED444948104C40
8290	Городищи	1	3	751	39.101239	39.105362	55.870187999999999	55.867303999999997	0103000020E61000000100000005000000350A4966F58C434051D845D103EF4B40350A4966F58C434092AF045262EF4B40DE1E84807C8D434092AF045262EF4B40DE1E84807C8D434051D845D103EF4B40350A4966F58C434051D845D103EF4B40
8156	Головино	1	3	751	39.171469000000002	39.198121999999998	56.027262999999998	56.015495000000001	0103000020E6100000010000000500000090A339B2F295434032207BBDFB014C4090A339B2F295434007B29E5A7D034C401E4FCB0F5C99434007B29E5A7D034C401E4FCB0F5C99434032207BBDFB014C4090A339B2F295434032207BBDFB014C40
7891	Глубоково	1	3	751	39.154401	39.172618999999997	55.889048000000003	55.883262000000002	0103000020E610000001000000050000001FBC7669C393434058E6ADBA0EF14B401FBC7669C393434080492A53CCF14B4088D51F611896434080492A53CCF14B4088D51F611896434058E6ADBA0EF14B401FBC7669C393434058E6ADBA0EF14B40
6479	Воспушка	1	3	751	39.431486999999997	39.452021999999999	56.083195000000003	56.06559	0103000020E6100000010000000500000017D34CF73AB74340EA78CC4065084C4017D34CF73AB743406A183E22A60A4C4048895DDBDBB943406A183E22A60A4C4048895DDBDBB94340EA78CC4065084C4017D34CF73AB74340EA78CC4065084C40
7711	Вольгинский	1	3	751	39.212989	39.242840000000001	55.959384	55.945780999999997	0103000020E6100000010000000500000031B43A39439B4340CE16105A0FF94B4031B43A39439B434020274C18CDFA4B4090149161159F434020274C18CDFA4B4090149161159F4340CE16105A0FF94B4031B43A39439B4340CE16105A0FF94B40
54169	Введенский	1	3	751	38.864792999999999	39.803460999999999	56.516204000000002	55.758493000000001	0103000020E61000000100000005000000A5677A89B16E43405A9F724C16E14B40A5677A89B16E43403E0801F912424C40444E5FCFD7E643403E0801F912424C40444E5FCFD7E643405A9F724C16E14B40A5677A89B16E43405A9F724C16E14B40
6689	Болдино	1	3	751	39.721031000000004	39.783580999999998	55.967834000000003	55.947631000000001	0103000020E610000001000000050000007B336ABE4ADC434080D6FCF84BF94B407B336ABE4ADC43407BFA08FCE1FB4B402C62D8614CE443407BFA08FCE1FB4B402C62D8614CE4434080D6FCF84BF94B407B336ABE4ADC434080D6FCF84BF94B40
6986	Анкудиново	1	3	751	39.575684000000003	39.589176999999999	56.088543999999999	56.074001000000003	0103000020E610000001000000050000004D6A6803B0C94340876F61DD78094C404D6A6803B0C94340E620E868550B4C401747E5266ACB4340E620E868550B4C401747E5266ACB4340876F61DD78094C404D6A6803B0C94340876F61DD78094C40
54146	Якиманская Слобода	1	3	190	42.029440999999998	42.057451	55.606710999999997	55.591025000000002	0103000020E61000000100000005000000AD1402B9C4034540280F0BB5A6CB4B40AD1402B9C4034540CD8FBFB4A8CD4B40AE0FEB8D5A074540CD8FBFB4A8CD4B40AE0FEB8D5A074540280F0BB5A6CB4B40AD1402B9C4034540280F0BB5A6CB4B40
48841	Чаадаево	1	3	190	42.017313999999999	42.043581000000003	55.677204000000003	55.658687999999998	0103000020E61000000100000005000000A8E15B583702454042226DE34FD44B40A8E15B5837024540365CE49EAED64B400EDDEC0F94054540365CE49EAED64B400EDDEC0F9405454042226DE34FD44B40A8E15B583702454042226DE34FD44B40
48712	Татарово	1	3	190	42.120170999999999	42.154927000000001	55.896326999999999	55.882928999999997	0103000020E61000000100000005000000BC7669C3610F454051D845D103F14B40BC7669C3610F4540CAC2D7D7BAF24B403A22DFA5D4134540CAC2D7D7BAF24B403A22DFA5D413454051D845D103F14B40BC7669C3610F454051D845D103F14B40
48737	Талызино	1	3	190	41.867941999999999	41.889240999999998	55.781123999999998	55.770487000000003	0103000020E61000000100000005000000946934B918EF4440207F69519FE24B40946934B918EF4440730F09DFFBE34B4094A12AA6D2F14440730F09DFFBE34B4094A12AA6D2F14440207F69519FE24B40946934B918EF4440207F69519FE24B40
49002	Стригино	1	3	190	41.867736000000001	41.893732999999997	55.565106	55.550910999999999	0103000020E61000000100000005000000EBC726F911EF4440DA006C4084C64B40EBC726F911EF4440FE62B66455C84B40902DCBD765F24440FE62B66455C84B40902DCBD765F24440DA006C4084C64B40EBC726F911EF4440DA006C4084C64B40
4771	Старое Ратово	1	3	190	41.899563000000001	41.914510999999997	55.516134000000001	55.509068999999997	0103000020E6100000010000000500000088D860E124F344402634492C29C14B4088D860E124F34440452DCDAD10C24B40876A4AB20EF54440452DCDAD10C24B40876A4AB20EF544402634492C29C14B4088D860E124F344402634492C29C14B40
3469	Саксино	1	3	190	41.924168000000002	41.957307	55.658586	55.640680000000003	0103000020E610000001000000050000003F0114234BF64440C4995FCD01D24B403F0114234BF644403ECDC98B4CD44B40AE9D280989FA44403ECDC98B4CD44B40AE9D280989FA4440C4995FCD01D24B403F0114234BF64440C4995FCD01D24B40
48765	Прудищи	1	3	190	41.875191999999998	41.895232999999998	55.738185999999999	55.724713000000001	0103000020E6100000010000000500000044DC9C4A06F0444037FE4465C3DC4B4044DC9C4A06F04440BA2EFCE07CDE4B4065A6B4FE96F24440BA2EFCE07CDE4B4065A6B4FE96F2444037FE4465C3DC4B4044DC9C4A06F0444037FE4465C3DC4B40
48694	Польцо	1	3	190	42.212176999999997	42.236798999999998	55.773691999999997	55.767052999999997	0103000020E6100000010000000500000050FBAD9D281B45403BA6EECA2EE24B4050FBAD9D281B4540A296E65608E34B40DD5CFC6D4F1E4540A296E65608E34B40DD5CFC6D4F1E45403BA6EECA2EE24B4050FBAD9D281B45403BA6EECA2EE24B40
4478	Пестенькино	1	3	190	41.852446	41.883474	55.616875	55.600347999999997	0103000020E6100000010000000500000092CD55F31CED4440081C0934D8CC4B4092CD55F31CED4440295C8FC2F5CE4B40E36E10AD15F14440295C8FC2F5CE4B40E36E10AD15F14440081C0934D8CC4B4092CD55F31CED4440081C0934D8CC4B40
2360	Орлово	1	3	190	42.009174999999999	42.040284	55.551155999999999	55.530684000000001	0103000020E610000001000000050000006C787AA52C01454057410C74EDC34B406C787AA52C014540417FA1478CC64B40AA46AF0628054540417FA1478CC64B40AA46AF062805454057410C74EDC34B406C787AA52C01454057410C74EDC34B40
2441	Муромский	1	3	190	42.018571999999999	42.035693999999999	55.560488999999997	55.554403999999998	0103000020E61000000100000005000000874F3A9160024540C362D4B5F6C64B40874F3A91600245404562821ABEC74B40EB54F99E910445404562821ABEC74B40EB54F99E91044540C362D4B5F6C64B40874F3A9160024540C362D4B5F6C64B40
701	Муром	1	3	190	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
3790	Молотицы	1	3	190	41.92671	41.975541999999997	55.763351	55.738449000000003	0103000020E610000001000000050000002670EB6E9EF64440C861307F85DE4B402670EB6E9EF64440382F4E7CB5E14B40EDEF6C8FDEFC4440382F4E7CB5E14B40EDEF6C8FDEFC4440C861307F85DE4B402670EB6E9EF64440C861307F85DE4B40
49084	Мишино	1	3	190	41.972712999999999	42.002797000000001	55.511964999999996	55.496858000000003	0103000020E6100000010000000500000070B20DDC81FC4440C460FE0A99BF4B4070B20DDC81FC44402BD9B11188C14B4072C3EFA65B0045402BD9B11188C14B4072C3EFA65B004540C460FE0A99BF4B4070B20DDC81FC4440C460FE0A99BF4B40
48952	Михалево	1	3	190	41.849769000000002	41.884723000000001	55.674655999999999	55.661237	0103000020E61000000100000005000000CB13083BC5EC4440DCF3FC69A3D44B40CB13083BC5EC44406C06B8205BD64B406F826F9A3EF144406C06B8205BD64B406F826F9A3EF14440DCF3FC69A3D44B40CB13083BC5EC4440DCF3FC69A3D44B40
4196	Межищи	1	3	190	41.785539999999997	41.819918000000001	55.710545000000003	55.699289	0103000020E6100000010000000500000094D920938CE44440EDB94C4D82D94B4094D920938CE444400DAB7823F3DA4B406CB3B112F3E844400DAB7823F3DA4B406CB3B112F3E84440EDB94C4D82D94B4094D920938CE44440EDB94C4D82D94B40
49001	Макаровка	1	3	190	41.934319000000002	41.954261000000002	55.588740000000001	55.579433999999999	0103000020E610000001000000050000000684D6C397F744406118B0E42ACA4B400684D6C397F744406CEC12D55BCB4B40946C753925FA44406CEC12D55BCB4B40946C753925FA44406118B0E42ACA4B400684D6C397F744406118B0E42ACA4B40
46962	Лесниково	1	3	190	41.921436999999997	41.944280999999997	55.685608999999999	55.675910000000002	0103000020E610000001000000050000008429CAA5F1F544400A85083884D64B408429CAA5F1F54440F06B2409C2D74B40F99D2633DEF84440F06B2409C2D74B40F99D2633DEF844400A85083884D64B408429CAA5F1F544400A85083884D64B40
49041	Лазарево	1	3	190	41.943221000000001	41.966540999999999	55.564459999999997	55.549031999999997	0103000020E6100000010000000500000041F33977BBF844408E3A3AAE46C64B4041F33977BBF8444038F3AB3940C84B401F9F909DB7FB444038F3AB3940C84B401F9F909DB7FB44408E3A3AAE46C64B4041F33977BBF844408E3A3AAE46C64B40
48730	Кондраково	1	3	190	41.900767000000002	41.917546999999999	55.807592	55.791804999999997	0103000020E61000000100000005000000742843554CF3444096E7C1DD59E54B40742843554CF344407041B62C5FE74B407EC51A2E72F544407041B62C5FE74B407EC51A2E72F5444096E7C1DD59E54B40742843554CF3444096E7C1DD59E54B40
4464	Ковардицы	1	3	190	41.934876000000003	41.970681999999996	55.630609	55.600724999999997	0103000020E610000001000000050000005CE84A04AAF74440DE718A8EE4CC4B405CE84A04AAF7444019C8B3CBB7D04B406E68CA4E3FFC444019C8B3CBB7D04B406E68CA4E3FFC4440DE718A8EE4CC4B405CE84A04AAF74440DE718A8EE4CC4B40
54147	Имени Войкова	1	3	190	42.027338999999998	42.039439999999999	55.619045	55.613650999999997	0103000020E61000000100000005000000E27327D87F0345402F14B01D8CCE4B40E27327D87F0345404CE0D6DD3CCF4B40BE13B35E0C0545404CE0D6DD3CCF4B40BE13B35E0C0545402F14B01D8CCE4B40E27327D87F0345402F14B01D8CCE4B40
49032	Иваньково	1	3	190	41.903129	41.936439	55.555072000000003	55.542924999999997	0103000020E61000000100000005000000DB8827BB99F344402497FF907EC54B40DB8827BB99F3444071766B990CC74B4077D9AF3BDDF7444071766B990CC74B4077D9AF3BDDF744402497FF907EC54B40DB8827BB99F344402497FF907EC54B40
46979	Иванищи	1	3	190	41.831237000000002	41.839402999999997	55.719171000000003	55.711762	0103000020E61000000100000005000000D21C59F965EA44408D4468041BDB4B40D21C59F965EA4440A69D9ACB0DDC4B400795B88E71EB4440A69D9ACB0DDC4B400795B88E71EB44408D4468041BDB4B40D21C59F965EA44408D4468041BDB4B40
54155	Дмитриева Слобода	1	3	190	42.027160000000002	42.045870999999998	55.614404	55.605820999999999	0103000020E6100000010000000500000033E197FA79034540711DE38A8BCD4B4033E197FA790345400B444FCAA4CE4B40DB6AD619DF0545400B444FCAA4CE4B40DB6AD619DF054540711DE38A8BCD4B4033E197FA79034540711DE38A8BCD4B40
48898	Булатниково	1	3	190	41.742168999999997	41.774616000000002	55.695529999999998	55.677286000000002	0103000020E61000000100000005000000718DCF64FFDE4440F304C24EB1D64B40718DCF64FFDE444085B1852007D94B40AB7AF99D26E3444085B1852007D94B40AB7AF99D26E34440F304C24EB1D64B40718DCF64FFDE4440F304C24EB1D64B40
48660	Боровицы	1	3	190	42.352466	42.374457	55.808259999999997	55.799987999999999	0103000020E61000000100000005000000D9791B9B1D2D4540A298BC0166E64B40D9791B9B1D2D45401D554D1075E74B400F61FC34EE2F45401D554D1075E74B400F61FC34EE2F4540A298BC0166E64B40D9791B9B1D2D4540A298BC0166E64B40
48790	Борисоглеб	1	3	190	42.003058000000003	42.024526999999999	55.720250999999998	55.705879000000003	0103000020E61000000100000005000000DFFE5C346400454073F7393E5ADA4B40DFFE5C3464004540A5F44C2F31DC4B403B6F63B323034540A5F44C2F31DC4B403B6F63B32303454073F7393E5ADA4B40DFFE5C346400454073F7393E5ADA4B40
3180	Александровка	1	3	190	41.959211000000003	41.993563000000002	55.585917000000002	55.566063	0103000020E61000000100000005000000537B116DC7FA4440E23C9CC074C84B40537B116DC7FA4440D1950854FFCA4B4001C287122DFF4440D1950854FFCA4B4001C287122DFF4440E23C9CC074C84B40537B116DC7FA4440E23C9CC074C84B40
46024	Усад	1	3	649	41.989646	42.017467000000003	55.423233000000003	55.411537000000003	0103000020E61000000100000005000000014F5AB8ACFE4440070C923EADB44B40014F5AB8ACFE444043CBBA7F2CB64B402FE1D05B3C02454043CBBA7F2CB64B402FE1D05B3C024540070C923EADB44B40014F5AB8ACFE4440070C923EADB44B40
46023	Урваново	1	3	649	42.008375999999998	42.031471000000003	55.444654999999997	55.424725000000002	0103000020E610000001000000050000002009FB7612014540956588635DB64B402009FB76120145405E807D74EAB84B40DFE2E13D070445405E807D74EAB84B40DFE2E13D07044540956588635DB64B402009FB7612014540956588635DB64B40
46129	Тургенево	1	3	649	41.853667999999999	41.892313000000001	55.459006000000002	55.424545999999999	0103000020E6100000010000000500000024D236FE44ED4440E5D2F88557B64B4024D236FE44ED44407A5567B5C0BA4B40D865F84F37F244407A5567B5C0BA4B40D865F84F37F24440E5D2F88557B64B4024D236FE44ED4440E5D2F88557B64B40
45529	Софроново	1	3	649	41.362378999999997	41.400889999999997	55.415339000000003	55.403855	0103000020E61000000100000005000000EBE0606F62AE4440BDA94885B1B34B40EBE0606F62AE44406EE00ED429B54B408FA50F5D50B344406EE00ED429B54B408FA50F5D50B34440BDA94885B1B34B40EBE0606F62AE4440BDA94885B1B34B40
45419	Скрипино	1	3	649	41.490084000000003	41.514572000000001	55.608947999999998	55.593482000000002	0103000020E610000001000000050000007D259012BBBE4440E161DA37F7CB4B407D259012BBBE4440787B1002F2CD4B40FAB7CB7EDDC14440787B1002F2CD4B40FAB7CB7EDDC14440E161DA37F7CB4B407D259012BBBE4440E161DA37F7CB4B40
7262	Синжаны	1	3	649	41.401446999999997	41.432420999999998	55.445559000000003	55.424725000000002	0103000020E61000000100000005000000E509849D62B34440956588635DB64B40E509849D62B3444020B8CA1308B94B40438D429259B7444020B8CA1308B94B40438D429259B74440956588635DB64B40E509849D62B34440956588635DB64B40
46069	Селино	1	3	649	41.828460999999997	41.848286999999999	55.432909000000002	55.413417000000003	0103000020E61000000100000005000000778192020BEA4440234E27D9EAB44B40778192020BEA44407192E68F69B74B409C4F1DAB94EC44407192E68F69B74B409C4F1DAB94EC4440234E27D9EAB44B40778192020BEA4440234E27D9EAB44B40
4319	Савково	1	3	649	41.817447999999999	41.836905000000002	55.408158999999998	55.389642000000002	0103000020E610000001000000050000001E17D522A2E84440F392FFC9DFB14B401E17D522A2E84440B648DA8D3EB44B40F06DFAB31FEB4440B648DA8D3EB44B40F06DFAB31FEB4440F392FFC9DFB14B401E17D522A2E84440F392FFC9DFB14B40
45610	Прудня	1	3	649	41.670627000000003	41.681874000000001	55.441147000000001	55.426420999999998	0103000020E610000001000000050000004568041BD7D54440EFA99CF694B64B404568041BD7D5444040DD408177B84B4011FFB0A547D7444040DD408177B84B4011FFB0A547D74440EFA99CF694B64B404568041BD7D54440EFA99CF694B64B40
45600	Папулино	1	3	649	41.734470000000002	41.771785999999999	55.568877999999998	55.554673999999999	0103000020E6100000010000000500000052F2EA1C03DE444083F8C08EFFC64B4052F2EA1C03DE4440FAB48AFED0C84B405DC136E2C9E24440FAB48AFED0C84B405DC136E2C9E2444083F8C08EFFC64B4052F2EA1C03DE444083F8C08EFFC64B40
45964	Паново	1	3	649	41.796166999999997	41.817869999999999	55.342703	55.332340000000002	0103000020E61000000100000005000000C493DDCCE8E544408A93FB1D8AAA4B40C493DDCCE8E54440DC9E20B1DDAB4B409430D3F6AFE84440DC9E20B1DDAB4B409430D3F6AFE844408A93FB1D8AAA4B40C493DDCCE8E544408A93FB1D8AAA4B40
45835	Осинки	1	3	649	41.614626000000001	41.635063000000002	55.241416000000001	55.227941000000001	0103000020E61000000100000005000000BAA29410ACCE44407235B22B2D9D4B40BAA29410ACCE4440965D30B8E69E4B4028F38FBE49D14440965D30B8E69E4B4028F38FBE49D144407235B22B2D9D4B40BAA29410ACCE44407235B22B2D9D4B40
7708	Окшово	1	3	649	41.699013999999998	41.708347000000003	55.144238000000001	55.132911	0103000020E610000001000000050000001BB96E4A79D94440AB23473A03914B401BB96E4A79D94440946B0A6476924B40209C4F1DABDA4440946B0A6476924B40209C4F1DABDA4440AB23473A03914B401BB96E4A79D94440AB23473A03914B40
45396	Новониколаевское	1	3	649	41.387191000000001	41.417921999999997	55.562469	55.553584999999998	0103000020E610000001000000050000001C2785798FB1444030478FDFDBC64B401C2785798FB14440C501F4FBFEC74B40B323D5777EB54440C501F4FBFEC74B40B323D5777EB5444030478FDFDBC64B401C2785798FB1444030478FDFDBC64B40
5375	Меленки	1	3	649	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
7665	Малый Санчур	1	3	649	41.737085	41.762200999999997	55.179518999999999	55.170568000000003	0103000020E61000000100000005000000A3AF20CD58DE444040DF162CD5954B40A3AF20CD58DE44405C01857AFA964B403FFD67CD8FE144405C01857AFA964B403FFD67CD8FE1444040DF162CD5954B40A3AF20CD58DE444040DF162CD5954B40
7157	Малый Приклон	1	3	649	41.567338999999997	41.596786000000002	55.342298999999997	55.329363999999998	0103000020E61000000100000005000000675F79909EC84440683D7C9928AA4B40675F79909EC844400C3A2174D0AB4B40F75AD07B63CC44400C3A2174D0AB4B40F75AD07B63CC4440683D7C9928AA4B40675F79909EC84440683D7C9928AA4B40
45385	Максимово	1	3	649	41.400655999999998	41.432637	55.504103999999998	55.488309999999998	0103000020E610000001000000050000001C7920B248B34440A6272CF180BE4B401C7920B248B3444032E4D87A86C04B40100533A660B7444032E4D87A86C04B40100533A660B74440A6272CF180BE4B401C7920B248B34440A6272CF180BE4B40
8247	Ляхи	1	3	649	41.914600999999998	41.936421000000003	55.345677999999999	55.314611999999997	0103000020E61000000100000005000000C7F143A511F54440EE76BD3445A84B40C7F143A511F544402D793C2D3FAC4B40D124B1A4DCF744402D793C2D3FAC4B40D124B1A4DCF74440EE76BD3445A84B40C7F143A511F54440EE76BD3445A84B40
7987	Лехтово	1	3	649	41.610314000000002	41.625559000000003	55.308956000000002	55.290171999999998	0103000020E610000001000000050000003E25E7C41ECE4440821B295B24A54B403E25E7C41ECE444095F3C5DE8BA74B40F75B3B5112D0444095F3C5DE8BA74B40F75B3B5112D04440821B295B24A54B403E25E7C41ECE4440821B295B24A54B40
45558	Левино	1	3	649	41.607286999999999	41.639339	55.536731000000003	55.518596000000002	0103000020E610000001000000050000009A249694BBCD444010EB8D5A61C24B409A249694BBCD4440ECDFF599B3C44B40570740DCD5D14440ECDFF599B3C44B40570740DCD5D1444010EB8D5A61C24B409A249694BBCD444010EB8D5A61C24B40
8185	Левенда	1	3	649	41.779234000000002	41.809435000000001	55.321871000000002	55.313454999999998	0103000020E6100000010000000500000034F790F0BDE3444043E21E4B1FA84B4034F790F0BDE34440F243A51133A94B406F9EEA909BE74440F243A51133A94B406F9EEA909BE7444043E21E4B1FA84B4034F790F0BDE3444043E21E4B1FA84B40
7947	Кулаки	1	3	649	41.627265999999999	41.640911000000003	55.210664999999999	55.193412000000002	0103000020E6100000010000000500000045F295404AD04440B55373B9C1984B4045F295404AD04440B7B41A12F79A4B40C652245F09D24440B7B41A12F79A4B40C652245F09D24440B55373B9C1984B4045F295404AD04440B55373B9C1984B40
45779	Крутцы	1	3	649	41.596102999999999	41.616872000000001	55.275457000000003	55.256205999999999	0103000020E610000001000000050000001406651A4DCC4440FD84B35BCBA04B401406651A4DCC4440263ACB2C42A34B40B8E864A9F5CE4440263ACB2C42A34B40B8E864A9F5CE4440FD84B35BCBA04B401406651A4DCC4440FD84B35BCBA04B40
45459	Коровино	1	3	649	41.491475999999999	41.516385999999997	55.388665000000003	55.371245000000002	0103000020E610000001000000050000006B6281AFE8BE4440DAE6C6F484AF4B406B6281AFE8BE4440C80C54C6BFB14B405E0EBBEF18C24440C80C54C6BFB14B405E0EBBEF18C24440DAE6C6F484AF4B406B6281AFE8BE4440DAE6C6F484AF4B40
45671	Кононово	1	3	649	41.767097	41.801000000000002	55.249339999999997	55.237730999999997	0103000020E610000001000000050000000BEE073C30E24440681F2BF86D9E4B400BEE073C30E24440D5CA845FEA9F4B404A0C022B87E64440D5CA845FEA9F4B404A0C022B87E64440681F2BF86D9E4B400BEE073C30E24440681F2BF86D9E4B40
45775	Илькино	1	3	649	41.593597000000003	41.615848	55.234983999999997	55.208280999999999	0103000020E610000001000000050000007A008BFCFACB444068B0A9F3A89A4B407A008BFCFACB4440A88AA9F4139E4B404CA7751BD4CE4440A88AA9F4139E4B404CA7751BD4CE444068B0A9F3A89A4B407A008BFCFACB444068B0A9F3A89A4B40
45448	Иватино	1	3	649	41.576627000000002	41.594898999999998	55.382880999999998	55.363124999999997	0103000020E61000000100000005000000CC7EDDE9CEC9444014AE47E17AAE4B40CC7EDDE9CEC9444040A19E3E02B14B4028B682A625CC444040A19E3E02B14B4028B682A625CC444014AE47E17AAE4B40CC7EDDE9CEC9444014AE47E17AAE4B40
45352	Злобино	1	3	649	41.548923000000002	41.573196000000003	55.420248999999998	55.399413000000003	0103000020E61000000100000005000000D882DE1B43C64440734C16F71FB34B40D882DE1B43C644409E961FB8CAB54B4059198D7C5EC944409E961FB8CAB54B4059198D7C5EC94440734C16F71FB34B40D882DE1B43C64440734C16F71FB34B40
45874	Елино	1	3	649	42.071420000000003	42.084004999999998	55.428179	55.418998000000002	0103000020E61000000100000005000000E223624A24094540728BF9B9A1B54B40E223624A24094540C0EAC891CEB64B40A9D903ADC00A4540C0EAC891CEB64B40A9D903ADC00A4540728BF9B9A1B54B40E223624A24094540728BF9B9A1B54B40
7589	Дмитриевы Горы	1	3	649	41.771265	41.803919	55.215411000000003	55.197502	0103000020E6100000010000000500000054C6BFCFB8E244408272DBBE47994B4054C6BFCFB8E244406E197096929B4B4007D15AD1E6E644406E197096929B4B4007D15AD1E6E644408272DBBE47994B4054C6BFCFB8E244408272DBBE47994B40
46475	Дмитриево	1	3	649	41.178933999999998	41.198481999999998	55.278267	55.271154000000003	0103000020E610000001000000050000003C122F4FE7964440FD169D2CB5A24B403C122F4FE79644402C47C8409EA34B401E6CB1DB679944402C47C8409EA34B401E6CB1DB67994440FD169D2CB5A24B403C122F4FE7964440FD169D2CB5A24B40
7366	Денятино	1	3	649	41.649005000000002	41.686940999999997	55.515472000000003	55.495899000000001	0103000020E6100000010000000500000062F8889812D344403F8F519E79BF4B4062F8889812D344407A008BFCFAC14B4009A4C4AEEDD744407A008BFCFAC14B4009A4C4AEEDD744403F8F519E79BF4B4062F8889812D344403F8F519E79BF4B40
7780	Двойново	1	3	649	41.517446	41.539428000000001	55.206349000000003	55.192357999999999	0103000020E6100000010000000500000017B9A7AB3BC24440DE8FDB2F9F984B4017B9A7AB3BC24440FA47DFA4699A4B40FA4509FA0BC54440FA47DFA4699A4B40FA4509FA0BC54440DE8FDB2F9F984B4017B9A7AB3BC24440DE8FDB2F9F984B40
45856	Высоково	1	3	649	41.918886000000001	41.935333999999997	55.363298999999998	55.348565000000001	0103000020E610000001000000050000004A60730E9EF54440DFC325C79DAC4B404A60730E9EF54440B2D5E59480AE4B401E6B4606B9F74440B2D5E59480AE4B401E6B4606B9F74440DFC325C79DAC4B404A60730E9EF54440DFC325C79DAC4B40
45649	Воютино	1	3	649	41.821463000000001	41.845089000000002	55.257765999999997	55.238022999999998	0103000020E61000000100000005000000E1EF17B325E944401059A489779E4B40E1EF17B325E94440A702EE79FEA04B40CC9A58E02BEC4440A702EE79FEA04B40CC9A58E02BEC44401059A489779E4B40E1EF17B325E944401059A489779E4B40
45729	Войново	1	3	649	41.621022000000004	41.637039000000001	55.279184999999998	55.265183999999998	0103000020E610000001000000050000005B0C1EA67DCF444013B69F8CF1A14B405B0C1EA67DCF444052448655BCA34B4066A3737E8AD1444052448655BCA34B4066A3737E8AD1444013B69F8CF1A14B405B0C1EA67DCF444013B69F8CF1A14B40
6783	Верхоунжа	1	3	649	41.513575000000003	41.536006	55.457796000000002	55.448096	0103000020E6100000010000000500000088855AD3BCC14440F5BBB0355BB94B4088855AD3BCC14440AC1E300F99BA4B40DA3A38D89BC44440AC1E300F99BA4B40DA3A38D89BC44440F5BBB0355BB94B4088855AD3BCC14440F5BBB0355BB94B40
6719	Бутылицы	1	3	649	41.484217999999998	41.515191999999999	55.525934999999997	55.504261999999997	0103000020E610000001000000050000003811FDDAFABD4440CA4E3FA88BC04B403811FDDAFABD44402F698CD651C34B409694BBCFF1C144402F698CD651C34B409694BBCFF1C14440CA4E3FA88BC04B403811FDDAFABD4440CA4E3FA88BC04B40
6990	Большой Приклон	1	3	649	41.554842999999998	41.582780999999997	55.358110000000003	55.345539000000002	0103000020E610000001000000050000000FB56D1805C744400C3F389F3AAC4B400FB56D1805C744406F2F698CD6AD4B4076DD5B9198CA44406F2F698CD6AD4B4076DD5B9198CA44400C3F389F3AAC4B400FB56D1805C744400C3F389F3AAC4B40
49568	Архангел	1	3	649	41.540047999999999	41.570034	55.458174	55.446412000000002	0103000020E610000001000000050000009622F94A20C544405F45460724B94B409622F94A20C5444052F01472A5BA4B40D5CDC5DFF6C8444052F01472A5BA4B40D5CDC5DFF6C844405F45460724B94B409622F94A20C544405F45460724B94B40
8509	Адино	1	3	649	41.758662000000001	41.793301	55.390884999999997	55.379404000000001	0103000020E61000000100000005000000E65B1FD61BE144405DFC6D4F90B04B40E65B1FD61BE144409CBF098508B24B402A711DE38AE544409CBF098508B24B402A711DE38AE544405DFC6D4F90B04B40E65B1FD61BE144405DFC6D4F90B04B40
37527	Красногорск	1	3	5097	37.229140999999998	37.394089000000001	55.851278000000001	55.799886999999998	0103000020E610000001000000050000001C96067E549D42406EBF7CB262E64B401C96067E549D4240F3E670ADF6EC4B404F5B238271B24240F3E670ADF6EC4B404F5B238271B242406EBF7CB262E64B401C96067E549D42406EBF7CB262E64B40
47766	Раздолье	1	3	539	39.449182999999998	39.466611	56.280231999999998	56.269095999999998	0103000020E61000000100000005000000A7751BD47EB9434001BEDBBC71224C40A7751BD47EB9434076A565A4DE234C40187AC4E8B9BB434076A565A4DE234C40187AC4E8B9BB434001BEDBBC71224C40A7751BD47EB9434001BEDBBC71224C40
5177	Новобусино	1	3	539	39.665201000000003	39.687838999999997	56.291753	56.280605999999999	0103000020E610000001000000050000001D226E4E25D54340DB87BCE5EA234C401D226E4E25D5434044C18C2958254C40E8F4BC1B0BD8434044C18C2958254C40E8F4BC1B0BD84340DB87BCE5EA234C401D226E4E25D54340DB87BCE5EA234C40
5256	Металлист	1	3	539	39.220678999999997	39.244655000000002	56.367950999999998	56.358612000000001	0103000020E61000000100000005000000FDF49F353F9C434001FA7DFFE62D4C40FDF49F353F9C4340E7C3B304192F4C40C5E6E3DA509F4340E7C3B304192F4C40C5E6E3DA509F434001FA7DFFE62D4C40FDF49F353F9C434001FA7DFFE62D4C40
4657	Литвиново	1	3	539	39.394511999999999	39.415846999999999	56.328169000000003	56.312004999999999	0103000020E6100000010000000500000095F0845E7FB243402098A3C7EF274C4095F0845E7FB24340D0471971012A4C40E29178793AB54340D0471971012A4C40E29178793AB543402098A3C7EF274C4095F0845E7FB243402098A3C7EF274C40
54160	Лаврово	1	3	539	39.593497999999997	39.597684000000001	56.148693999999999	56.146894000000003	0103000020E61000000100000005000000E61E12BEF7CB434044FD2E6CCD124C40E61E12BEF7CB4340438EAD6708134C40D6ABC8E880CC4340438EAD6708134C40D6ABC8E880CC434044FD2E6CCD124C40E61E12BEF7CB434044FD2E6CCD124C40
3272	Кольчугино	1	3	539	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
49518	Ильинское	1	3	539	39.346111000000001	39.369385999999999	56.399093999999998	56.388297000000001	0103000020E6100000010000000500000097E4805D4DAC4340451152B7B3314C4097E4805D4DAC4340D1031F8315334C40D5CC5A0A48AF4340D1031F8315334C40D5CC5A0A48AF4340451152B7B3314C4097E4805D4DAC4340451152B7B3314C40
49536	Золотуха	1	3	539	39.342103999999999	39.361210999999997	56.429957000000002	56.421892	0103000020E6100000010000000500000057EA5910CAAB4340D6389B8E00364C4057EA5910CAAB4340D8D7BAD408374C404CFA7B293CAE4340D8D7BAD408374C404CFA7B293CAE4340D6389B8E00364C4057EA5910CAAB4340D6389B8E00364C40
5155	Есиплево	1	3	539	39.533453999999999	39.547027999999997	56.308419999999998	56.296559000000002	0103000020E61000000100000005000000CFF57D3848C44340D02A33A5F5254C40CFF57D3848C4434056B77A4E7A274C4086FF740305C6434056B77A4E7A274C4086FF740305C64340D02A33A5F5254C40CFF57D3848C44340D02A33A5F5254C40
5044	Ельцино	1	3	539	39.605902999999998	39.623303999999997	56.214927000000003	56.201824999999999	0103000020E610000001000000050000002EC6C03A8ECD4340F241CF66D5194C402EC6C03A8ECD434082035ABA821B4C40A5BBEB6CC8CF434082035ABA821B4C40A5BBEB6CC8CF4340F241CF66D5194C402EC6C03A8ECD4340F241CF66D5194C40
47607	Вишневый	1	3	539	39.456046000000001	39.471829999999997	56.207312999999999	56.196891999999998	0103000020E610000001000000050000005EBC1FB75FBA4340096CCEC133194C405EBC1FB75FBA434090847D3B891A4C40C6A2E9EC64BC434090847D3B891A4C40C6A2E9EC64BC4340096CCEC133194C405EBC1FB75FBA4340096CCEC133194C40
49550	Ваулово	1	3	539	39.275728000000001	39.292408999999999	56.136136	56.126964999999998	0103000020E61000000100000005000000B64B1B0E4BA343404A5E9D6340104C40B64B1B0E4BA3434075E789E76C114C402D077AA86DA5434075E789E76C114C402D077AA86DA543404A5E9D6340104C40B64B1B0E4BA343404A5E9D6340104C40
4762	Большое Кузьминское	1	3	539	39.522333000000003	39.549444000000001	56.426054000000001	56.410075999999997	0103000020E61000000100000005000000904FC8CEDBC24340EF6FD05E7D344C40904FC8CEDBC243403D2AFEEF88364C40E17D552E54C643403D2AFEEF88364C40E17D552E54C64340EF6FD05E7D344C40904FC8CEDBC24340EF6FD05E7D344C40
49506	Большевик	1	3	539	39.406315999999997	39.420876999999997	56.396244000000003	56.384031	0103000020E61000000100000005000000B7EBA52902B4434039D384ED27314C40B7EBA52902B443403D9E961FB8324C40BD512B4CDFB543403D9E961FB8324C40BD512B4CDFB5434039D384ED27314C40B7EBA52902B4434039D384ED27314C40
22885	Беречино	1	3	539	39.389184999999998	39.409523	56.267462000000002	56.257043000000003	0103000020E61000000100000005000000008C67D0D0B143403755F7C8E6204C40008C67D0D0B143401D76DF313C224C40DBFAE93F6BB443401D76DF313C224C40DBFAE93F6BB443403755F7C8E6204C40008C67D0D0B143403755F7C8E6204C40
54151	Белая Речка	1	3	539	39.389445000000002	39.414409999999997	56.292966999999997	56.270516000000001	0103000020E610000001000000050000009D4B7155D9B14340BA85AE44A0224C409D4B7155D9B1434053E751F17F254C4053910A630BB5434053E751F17F254C4053910A630BB54340BA85AE44A0224C409D4B7155D9B14340BA85AE44A0224C40
4743	Бавлены	1	3	539	39.549129999999998	39.579214	56.405206	56.388148000000001	0103000020E6100000010000000500000051A04FE449C6434000016BD5AE314C4051A04FE449C643404D124BCADD334C4053B131AF23CA43404D124BCADD334C4053B131AF23CA434000016BD5AE314C4051A04FE449C6434000016BD5AE314C40
47978	Авдотьино	1	3	539	39.298158999999998	39.305911000000002	56.270181000000001	56.267122000000001	0103000020E610000001000000050000000801F9122AA643406405BF0D31224C400801F9122AA6434013807F4A95224C404B3E761728A7434013807F4A95224C404B3E761728A743406405BF0D31224C400801F9122AA643406405BF0D31224C40
25712	Юдиха	1	3	1063	41.769405999999996	41.784354	56.492531999999997	56.486190999999998	0103000020E610000001000000050000004FAC53E57BE24440054EB6813B3E4C404FAC53E57BE24440E21DE0490B3F4C404F3E3DB665E44440E21DE0490B3F4C404F3E3DB665E44440054EB6813B3E4C404FAC53E57BE24440054EB6813B3E4C40
26761	Шевинская	1	3	1063	41.633310999999999	41.657665000000001	56.038162	56.023862000000001	0103000020E610000001000000050000003999B85510D14440FFCEF6E80D034C403999B85510D1444098F90E7EE2044C40A75CE15D2ED4444098F90E7EE2044C40A75CE15D2ED44440FFCEF6E80D034C403999B85510D14440FFCEF6E80D034C40
9337	Филино	1	3	1063	41.576582999999999	41.595033999999998	56.377960999999999	56.370035000000001	0103000020E61000000100000005000000FC36C478CDC944400CB08F4E5D2F4C40FC36C478CDC94440EC14AB0661304C400801F9122ACC4440EC14AB0661304C400801F9122ACC44400CB08F4E5D2F4C40FC36C478CDC944400CB08F4E5D2F4C40
25847	Старая	1	3	1063	41.471040000000002	41.496938	56.409104999999997	56.399586999999997	0103000020E61000000100000005000000CE8DE9094BBC44401074B4AA25334C40CE8DE9094BBC4440A6D0798D5D344C40E01115AA9BBF4440A6D0798D5D344C40E01115AA9BBF44401074B4AA25334C40CE8DE9094BBC44401074B4AA25334C40
26591	Смолино	1	3	1063	41.398724999999999	41.417051000000001	56.085504999999998	56.065927000000002	0103000020E610000001000000050000007E8CB96B09B344403276C24B70084C407E8CB96B09B344407E52EDD3F10A4C40CEE15AED61B544407E52EDD3F10A4C40CEE15AED61B544403276C24B70084C407E8CB96B09B344403276C24B70084C40
54162	Серково	1	3	1063	41.633265999999999	41.642913999999998	56.201014000000001	56.195630000000001	0103000020E6100000010000000500000099D53BDC0ED14440E90E62670A194C4099D53BDC0ED14440E204A6D3BA194C40FD1186014BD24440E204A6D3BA194C40FD1186014BD24440E90E62670A194C4099D53BDC0ED14440E90E62670A194C40
25787	Санниково	1	3	1063	41.647657000000002	41.658634999999997	56.412695999999997	56.399940999999998	0103000020E610000001000000050000004303B16CE6D244402EAA454431334C404303B16CE6D244405298F738D3344C401F80D4264ED444405298F738D3344C401F80D4264ED444402EAA454431334C404303B16CE6D244402EAA454431334C40
54152	Ручей	1	3	1063	41.227893000000002	41.268082999999997	56.404339	56.384410000000003	0103000020E6100000010000000500000061FE0A992B9D4440B020CD5834314C4061FE0A992B9D4440A9BF5E61C1334C4089CE328B50A24440A9BF5E61C1334C4089CE328B50A24440B020CD5834314C4061FE0A992B9D4440B020CD5834314C40
26228	Первомайский	1	3	1063	41.278288000000003	41.307205000000003	56.306387999999998	56.297212999999999	0103000020E61000000100000005000000446FF1F09EA34440187959130B264C40446FF1F09EA3444084F1D3B837274C407715527E52A7444084F1D3B837274C407715527E52A74440187959130B264C40446FF1F09EA34440187959130B264C40
25676	Пантелеево	1	3	1063	41.828865	41.849544999999999	56.467424000000001	56.452528000000001	0103000020E6100000010000000500000047E6913F18EA44401C430070EC394C4047E6913F18EA4440C9AEB48CD43B4C407BBDFBE3BDEC4440C9AEB48CD43B4C407BBDFBE3BDEC44401C430070EC394C4047E6913F18EA44401C430070EC394C40
10849	Пакино	1	3	1063	41.223643000000003	41.253746	56.373793999999997	56.355863999999997	0103000020E610000001000000050000005B7D7555A09C444070E998F38C2D4C405B7D7555A09C444073B8567BD82F4C40D3BEB9BF7AA0444073B8567BD82F4C40D3BEB9BF7AA0444070E998F38C2D4C405B7D7555A09C444070E998F38C2D4C40
26450	Павловское	1	3	1063	41.469566	41.491027000000003	56.227395000000001	56.210697000000003	0103000020E6100000010000000500000022A81ABD1ABC4440C32E8A1EF81A4C4022A81ABD1ABC4440102384471B1D4C40FC3905F9D9BE4440102384471B1D4C40FC3905F9D9BE4440C32E8A1EF81A4C4022A81ABD1ABC4440C32E8A1EF81A4C40
54165	Новый	1	3	1063	41.236013	41.258965000000003	56.300364999999999	56.289414999999998	0103000020E6100000010000000500000026378AAC359E444065FCFB8C0B254C4026378AAC359E444078EE3D5C72264C4082E7DEC325A1444078EE3D5C72264C4082E7DEC325A1444065FCFB8C0B254C4026378AAC359E444065FCFB8C0B254C40
26356	Нерехта	1	3	1063	41.327165000000001	41.343460999999998	56.208599999999997	56.198765000000002	0103000020E61000000100000005000000ABB2EF8AE0A94440734BAB2171194C40ABB2EF8AE0A9444009F9A067B31A4C40C939B187F6AB444009F9A067B31A4C40C939B187F6AB4440734BAB2171194C40ABB2EF8AE0A94440734BAB2171194C40
26839	Мелехово	1	3	1063	41.279347999999999	41.329186999999997	56.296754	56.239438	0103000020E61000000100000005000000FC19DEACC1A34440B7B585E7A51E4C40FC19DEACC1A34440857AFA08FC254C4059A2B3CC22AA4440857AFA08FC254C4059A2B3CC22AA4440B7B585E7A51E4C40FC19DEACC1A34440B7B585E7A51E4C40
25537	Малыгино	1	3	1063	41.14911	41.167265	56.417845	56.402380999999998	0103000020E61000000100000005000000D7C056091693444011C4793881334C40D7C056091693444008E6E8F17B354C40FA6184F06895444008E6E8F17B354C40FA6184F06895444011C4793881334C40D7C056091693444011C4793881334C40
26384	Крутово	1	3	1063	41.333641999999998	41.357537000000001	56.193711999999998	56.182932000000001	0103000020E610000001000000050000003849F3C7B4AA444029B2D6506A174C403849F3C7B4AA4440DF6B088ECB184C40130EBDC5C3AD4440DF6B088ECB184C40130EBDC5C3AD444029B2D6506A174C403849F3C7B4AA444029B2D6506A174C40
26099	Крестниково	1	3	1063	41.593004000000001	41.643714000000003	56.341822000000001	56.310378	0103000020E61000000100000005000000D732198EE7CB4440EEB25F77BA274C40D732198EE7CB4440D386C3D2C02B4C401AFD683865D24440D386C3D2C02B4C401AFD683865D24440EEB25F77BA274C40D732198EE7CB4440EEB25F77BA274C40
9355	Красный Октябрь	1	3	1063	41.367482000000003	41.399299999999997	56.111598999999998	56.094450000000002	0103000020E6100000010000000500000031EF71A609AF4440B98D06F0160C4C4031EF71A609AF444016A243E0480E4C407AA52C431CB3444016A243E0480E4C407AA52C431CB34440B98D06F0160C4C4031EF71A609AF4440B98D06F0160C4C40
26663	Красный Маяк	1	3	1063	41.354519000000003	41.377946999999999	56.056528	56.041431000000003	0103000020E61000000100000005000000C367EBE060AD444032056B9C4D054C40C367EBE060AD444076A73B4F3C074C40874F3A9160B0444076A73B4F3C074C40874F3A9160B0444032056B9C4D054C40C367EBE060AD444032056B9C4D054C40
54164	Клязьминский Городок	1	3	1063	41.495967999999998	41.517195000000001	56.455781000000002	56.437114000000001	0103000020E6100000010000000500000067EE21E17BBF4440D74FFF59F3374C4067EE21E17BBF4440B0912408573A4C40CE531D7233C24440B0912408573A4C40CE531D7233C24440D74FFF59F3374C4067EE21E17BBF4440D74FFF59F3374C40
25473	Ильино	1	3	1063	41.449902000000002	41.473258000000001	56.478769999999997	56.467995999999999	0103000020E61000000100000005000000D733846396B944405454FD4AE73B4C40D733846396B944402827DA55483D4C400249D8B793BC44402827DA55483D4C400249D8B793BC44405454FD4AE73B4C40D733846396B944405454FD4AE73B4C40
26491	Иваново	1	3	1063	41.455435999999999	41.489229999999999	56.194893999999998	56.168461000000001	0103000020E61000000100000005000000E5B512BA4BBA444063D34A2190154C40E5B512BA4BBA4440E3175E49F2184C406D1CB1169FBE4440E3175E49F2184C406D1CB1169FBE444063D34A2190154C40E5B512BA4BBA444063D34A2190154C40
25996	Достижение	1	3	1063	41.456037999999999	41.484127999999998	56.389169000000003	56.377502	0103000020E61000000100000005000000DBDD03745FBA444059164CFC51304C40DBDD03745FBA4440FBCE2F4AD0314C40F88903E8F7BD4440FBCE2F4AD0314C40F88903E8F7BD444059164CFC51304C40DBDD03745FBA444059164CFC51304C40
9619	Глебово	1	3	1063	41.455795000000002	41.473025	56.427596999999999	56.418202999999998	0103000020E610000001000000050000001557957D57BA4440670B08AD87354C401557957D57BA4440116F9D7FBB364C405F984C158CBC4440116F9D7FBB364C405F984C158CBC4440670B08AD87354C401557957D57BA4440670B08AD87354C40
25388	Гигант	1	3	1063	41.287505000000003	41.309638999999997	56.450612999999997	56.438955	0103000020E61000000100000005000000DF37BEF6CCA4444035B56CAD2F384C40DF37BEF6CCA444408313D1AFAD394C4077483140A2A744408313D1AFAD394C4077483140A2A7444035B56CAD2F384C40DF37BEF6CCA4444035B56CAD2F384C40
26739	Восход	1	3	1063	41.524515999999998	41.542087000000002	56.100244000000004	56.083190000000002	0103000020E61000000100000005000000471D1D5723C3444058AD4CF8A50A4C40471D1D5723C3444064CF9ECBD40C4C401B4B581B63C5444064CF9ECBD40C4C401B4B581B63C5444058AD4CF8A50A4C40471D1D5723C3444058AD4CF8A50A4C40
26288	Великово	1	3	1063	41.276949999999999	41.304034000000001	56.249101000000003	56.238301999999997	0103000020E610000001000000050000004850FC1873A34440234910AE801E4C404850FC1873A344405133A48AE21F4C40A06F0B96EAA644405133A48AE21F4C40A06F0B96EAA64440234910AE801E4C404850FC1873A34440234910AE801E4C40
47917	Болотский	1	3	1063	41.298572	41.315280999999999	56.005571000000003	56.000793999999999	0103000020E610000001000000050000002BC0779B37A644403A048E041A004C402BC0779B37A644402C67EF8CB6004C406C06B8205BA844402C67EF8CB6004C406C06B8205BA844403A048E041A004C402BC0779B37A644403A048E041A004C40
25416	Бол. Всегодичи	1	3	1063	41.318765999999997	41.336643000000002	56.450305	56.441369000000002	0103000020E61000000100000005000000D2890453CDA84440EF3B86C77E384C40D2890453CDA84440D61C2098A3394C40B3B6291E17AB4440D61C2098A3394C40B3B6291E17AB4440EF3B86C77E384C40D2890453CDA84440EF3B86C77E384C40
26178	Бельково	1	3	1063	41.194358000000001	41.215684000000003	56.306902000000001	56.294891	0103000020E61000000100000005000000A5DB12B9E09844403F7100FDBE254C40A5DB12B9E0984440DB89929048274C409F2287889B9B4440DB89929048274C409F2287889B9B44403F7100FDBE254C40A5DB12B9E09844403F7100FDBE254C40
3604	Филипповское	1	3	378	38.596898000000003	38.626156000000002	56.110348999999999	56.091656999999998	0103000020E610000001000000050000001F865627674C434088B9A46ABB0B4C401F865627674C4340BA1281EA1F0E4C40DB183BE125504340BA1281EA1F0E4C40DB183BE12550434088B9A46ABB0B4C401F865627674C434088B9A46ABB0B4C40
3368	Федоровское	1	3	378	38.846369000000003	38.866329	56.119810000000001	56.105420000000002	0103000020E6100000010000000500000093ACC3D1556C4340132C0E677E0D4C4093ACC3D1556C4340ECDD1FEF550F4C40C74961DEE36E4340ECDD1FEF550F4C40C74961DEE36E4340132C0E677E0D4C4093ACC3D1556C4340132C0E677E0D4C40
3683	Песьяне	1	3	378	38.791364999999999	38.810319	56.028132999999997	56.015374000000001	0103000020E610000001000000050000007A19C5724B654340B79A75C6F7014C407A19C5724B6543401C78B5DC99034C40E9297288B86743401C78B5DC99034C40E9297288B8674340B79A75C6F7014C407A19C5724B654340B79A75C6F7014C40
54149	Першино	1	3	378	38.722436999999999	38.743080999999997	56.141804	56.132108000000002	0103000020E61000000100000005000000CE35CCD0785C43401EC539EAE8104C40CE35CCD0785C434093382BA226124C40B5A338471D5F434093382BA226124C40B5A338471D5F43401EC539EAE8104C40CE35CCD0785C43401EC539EAE8104C40
3358	Новоселово	1	3	378	39.043917	39.073264999999999	56.072484000000003	56.056317	0103000020E61000000100000005000000855E7F129F854340BB9A3C6535074C40855E7F129F854340DCBDDC2747094C4081785DBF60894340DCBDDC2747094C4081785DBF60894340BB9A3C6535074C40855E7F129F854340BB9A3C6535074C40
1947	Киржач	1	3	378	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
3170	Кипрево	1	3	378	38.972366999999998	38.997563999999997	56.243279000000001	56.234290000000001	0103000020E61000000100000005000000D55A9885767C4340D2E3F736FD1D4C40D55A9885767C4340DC662AC4231F4C405ED5592DB07F4340DC662AC4231F4C405ED5592DB07F4340D2E3F736FD1D4C40D55A9885767C4340D2E3F736FD1D4C40
3018	Илькино	1	3	378	38.840826	38.860894999999999	56.223821999999998	56.213746	0103000020E6100000010000000500000031D0B52FA06B43404ED367075C1B4C4031D0B52FA06B43400A100533A61C4C401C25AFCE316E43400A100533A61C4C401C25AFCE316E43404ED367075C1B4C4031D0B52FA06B43404ED367075C1B4C40
3686	Заречье	1	3	378	38.595675999999997	38.62771	56.006959999999999	55.994627000000001	0103000020E610000001000000050000008C81751C3F4C4340FB5B02F04FFF4B408C81751C3F4C4340A930B610E4004C40A3AF20CD58504340A930B610E4004C40A3AF20CD58504340FB5B02F04FFF4B408C81751C3F4C4340FB5B02F04FFF4B40
3127	Ефремово	1	3	378	38.971764999999998	39.005693999999998	56.226184000000003	56.216909999999999	0103000020E61000000100000005000000DF32A7CB627C43407216F6B4C31B4C40DF32A7CB627C43407270E998F31C4C4047E4BB94BA8043407270E998F31C4C4047E4BB94BA8043407216F6B4C31B4C40DF32A7CB627C43407216F6B4C31B4C40
2939	Ельцы	1	3	378	38.766103999999999	38.786110000000001	56.179651	56.167624000000004	0103000020E61000000100000005000000DAAA24B20F6243402A0307B474154C40DAAA24B20F624340CBD8D0CDFE164C407F87A2409F644340CBD8D0CDFE164C407F87A2409F6443402A0307B474154C40DAAA24B20F6243402A0307B474154C40
3014	Горка	1	3	378	38.775339000000002	38.796674000000003	56.248941000000002	56.237287000000002	0103000020E610000001000000050000001C28F04E3E6343400B62A06B5F1E4C401C28F04E3E63434018D1764CDD1F4C4069C9E369F965434018D1764CDD1F4C4069C9E369F96543400B62A06B5F1E4C401C28F04E3E6343400B62A06B5F1E4C40
3222	Афанасово	1	3	378	39.069924	39.089615000000002	56.277118000000002	56.265642	0103000020E610000001000000050000004E9A0645F3884340D6389B8E00224C404E9A0645F38843400491459A78234C40931D1B81788B43400491459A78234C40931D1B81788B4340D6389B8E00224C404E9A0645F3884340D6389B8E00224C40
3550	Аленино	1	3	378	38.617505000000001	38.644517	56.123823999999999	56.108342	0103000020E61000000100000005000000E90E62670A4F434041649126DE0D4C40E90E62670A4F4340DE3AFF76D90F4C40A75B76887F524340DE3AFF76D90F4C40A75B76887F52434041649126DE0D4C40E90E62670A4F434041649126DE0D4C40
24921	Сергеиха	1	3	788	40.745542	40.762377000000001	56.419457999999999	56.407068000000002	0103000020E61000000100000005000000B0E595EB6D5F4440C39FE1CD1A344C40B0E595EB6D5F4440D505BCCCB0354C407E1CCD9195614440D505BCCCB0354C407E1CCD9195614440C39FE1CD1A344C40B0E595EB6D5F4440C39FE1CD1A344C40
25258	Пенкино	1	3	788	40.896306000000003	40.923713999999997	56.194904000000001	56.179665999999997	0103000020E61000000100000005000000B39AAE27BA724440001AA54BFF164C40B39AAE27BA72444007EE409DF2184C40BD6DA6423C76444007EE409DF2184C40BD6DA6423C764440001AA54BFF164C40B39AAE27BA724440001AA54BFF164C40
9512	Новки	1	3	788	41.061551000000001	41.092497999999999	56.370049999999999	56.355080999999998	0103000020E610000001000000050000009F0436E7E08744402A37514B732D4C409F0436E7E087444041F163CC5D2F4C40037976F9D68B444041F163CC5D2F4C40037976F9D68B44402A37514B732D4C409F0436E7E08744402A37514B732D4C40
25102	Мирный	1	3	788	40.769689	40.789434	56.299090999999997	56.278117999999999	0103000020E61000000100000005000000A48B4D2B85624440E736E15E99234C40A48B4D2B8562444093C3279D48264C40DC2C5E2C0C65444093C3279D48264C40DC2C5E2C0C654440E736E15E99234C40A48B4D2B85624440E736E15E99234C40
24976	Лубенцы	1	3	788	40.736685000000001	40.752575999999998	56.411565000000003	56.400064999999998	0103000020E61000000100000005000000153AAFB14B5E44401AA3755435334C40153AAFB14B5E4440D1967329AE344C4093E00D6954604440D1967329AE344C4093E00D69546044401AA3755435334C40153AAFB14B5E44401AA3755435334C40
48744	Краснознаменский	1	3	788	40.998632999999998	41.007202999999997	56.459378000000001	56.453026000000001	0103000020E610000001000000050000006ADAC534D37F44406D1E87C1FC394C406ADAC534D37F44403E40F7E5CC3A4C406FB72407EC8044403E40F7E5CC3A4C406FB72407EC8044406D1E87C1FC394C406ADAC534D37F44406D1E87C1FC394C40
24896	Коверино	1	3	788	40.876849	40.909205999999998	56.365721999999998	56.356048000000001	0103000020E61000000100000005000000E14389963C70444032E719FB922D4C40E14389963C704440BFB67EFACF2E4C40DAA9B9DC60744440BFB67EFACF2E4C40DAA9B9DC6074444032E719FB922D4C40E14389963C70444032E719FB922D4C40
8993	Камешково	1	3	788	40.962251999999999	41.032895000000003	56.363498999999997	56.337924999999998	0103000020E610000001000000050000005B41D3122B7B44401AC05B20412B4C405B41D3122B7B444079909E22872E4C40D99942E73584444079909E22872E4C40D99942E7358444401AC05B20412B4C405B41D3122B7B44401AC05B20412B4C40
24745	Имени Красина	1	3	788	40.897402	40.911208999999999	56.447229999999998	56.439498	0103000020E61000000100000005000000B8AE9811DE7244402654707841384C40B8AE9811DE72444021E527D53E394C4012691B7FA274444021E527D53E394C4012691B7FA27444402654707841384C40B8AE9811DE7244402654707841384C40
24587	Имени Кирова	1	3	788	41.019069999999999	41.030406999999997	56.458443000000003	56.451692000000001	0103000020E61000000100000005000000D82AC1E270824440B3EE1F0BD1394C40D82AC1E270824440420A9E42AE3A4C40E4486760E4834440420A9E42AE3A4C40E4486760E4834440B3EE1F0BD1394C40D82AC1E270824440B3EE1F0BD1394C40
24498	Имени Карла Маркса	1	3	788	41.086938000000004	41.106997	56.418666000000002	56.409972000000003	0103000020E61000000100000005000000CC63CDC8208B44404B2366F679344C40CC63CDC8208B44403CF9F4D896354C4093E2E313B28D44403CF9F4D896354C4093E2E313B28D44404B2366F679344C40CC63CDC8208B44404B2366F679344C40
24659	Имени Горького	1	3	788	40.943503999999997	40.972411999999998	56.477899999999998	56.466116	0103000020E6100000010000000500000095D233BDC4784440381268B0A93B4C4095D233BDC47844401361C3D32B3D4C40751E15FF777C44401361C3D32B3D4C40751E15FF777C4440381268B0A93B4C4095D233BDC4784440381268B0A93B4C40
48753	Имени Артема	1	3	788	40.912674000000003	40.930109999999999	56.359000999999999	56.348227999999999	0103000020E610000001000000050000006BF46A80D274444097C62FBC922C4C406BF46A80D27444409B1DA9BEF32D4C405ED72FD80D7744409B1DA9BEF32D4C405ED72FD80D77444097C62FBC922C4C406BF46A80D274444097C62FBC922C4C40
25245	Давыдово	1	3	788	40.698551000000002	40.723649999999999	56.178899000000001	56.169879000000002	0103000020E6100000010000000500000047CB811E6A5944407BA35698BE154C4047CB811E6A594440C0249529E6164C400DE02D90A05C4440C0249529E6164C400DE02D90A05C44407BA35698BE154C4047CB811E6A5944407BA35698BE154C40
25176	Горки	1	3	788	40.747419999999998	41.018791999999998	56.306508000000001	56.175030999999997	0103000020E610000001000000050000002B306475AB5F4440A164726A67164C402B306475AB5F44402FFB75A73B274C4095B6B8C6678244402FFB75A73B274C4095B6B8C667824440A164726A67164C402B306475AB5F4440A164726A67164C40
25348	Гатиха	1	3	788	40.852207999999997	40.867102000000003	56.220377999999997	56.205950999999999	0103000020E61000000100000005000000DDB1D826156D44400CCA349A5C1A4C40DDB1D826156D44400261A758351C4C40EA25C632FD6E44400261A758351C4C40EA25C632FD6E44400CCA349A5C1A4C40DDB1D826156D44400CCA349A5C1A4C40
9094	Второво	1	3	788	40.775016000000001	40.816409999999998	56.27364	56.255913	0103000020E6100000010000000500000039F06AB93363444085CFD6C1C1204C4039F06AB9336344405070B1A206234C404D10751F806844405070B1A206234C404D10751F8068444085CFD6C1C1204C4039F06AB93363444085CFD6C1C1204C40
25130	Волковойно	1	3	788	40.999523000000003	41.027838000000003	56.335070999999999	56.310671999999997	0103000020E61000000100000005000000C74CA25EF07F444036E49F19C4274C40C74CA25EF07F4440446B459BE32A4C4004CB113290834440446B459BE32A4C4004CB11329083444036E49F19C4274C40C74CA25EF07F444036E49F19C4274C40
10803	Уршельский	1	3	1145	40.193913999999999	40.236843999999998	55.688465999999998	55.661897000000003	0103000020E61000000100000005000000471E882CD21844400729780AB9D44B40471E882CD2184440373465A71FD84B407D2079E7501E4440373465A71FD84B407D2079E7501E44400729780AB9D44B40471E882CD21844400729780AB9D44B40
19682	Уляхино	1	3	1145	40.735740999999997	40.757454000000003	55.342207000000002	55.326726999999998	0103000020E61000000100000005000000C5A9D6C22C5E44402FDCB930D2A94B40C5A9D6C22C5E44402CBB6070CDAB4B40B91CAF40F46044402CBB6070CDAB4B40B91CAF40F46044402FDCB930D2A94B40C5A9D6C22C5E44402FDCB930D2A94B40
59043	Толстиково	1	3	1145	40.972385000000003	40.986623000000002	55.757156000000002	55.747439	0103000020E610000001000000050000007C0F971C777C4440A260C614ACDF4B407C0F971C777C44402FFCE07CEAE04B409F3D97A9497E44402FFCE07CEAE04B409F3D97A9497E4440A260C614ACDF4B407C0F971C777C4440A260C614ACDF4B40
12818	Тащилово	1	3	1145	41.106960999999998	41.121487000000002	55.358443000000001	55.336528999999999	0103000020E610000001000000050000004679E6E5B08D4440EA93DC6113AB4B404679E6E5B08D4440753DD175E1AD4B40D0F1D1E28C8F4440753DD175E1AD4B40D0F1D1E28C8F4440EA93DC6113AB4B404679E6E5B08D4440EA93DC6113AB4B40
20951	Тасинский Бор	1	3	1145	40.141343999999997	40.173729000000002	55.629962999999996	55.584567999999997	0103000020E610000001000000050000002FBE688F17124440E124CD1FD3CA4B402FBE688F171244405358A9A0A2D04B40F3AE7AC03C1644405358A9A0A2D04B40F3AE7AC03C164440E124CD1FD3CA4B402FBE688F17124440E124CD1FD3CA4B40
21002	Тасинский	1	3	1145	40.172587999999998	40.193778999999999	55.582630000000002	55.566434999999998	0103000020E610000001000000050000004DD7135D17164440A6272CF180C84B404DD7135D1716444091D5AD9E93CA4B4067D311C0CD18444091D5AD9E93CA4B4067D311C0CD184440A6272CF180C84B404DD7135D17164440A6272CF180C84B40
32997	Таланово	1	3	1145	41.037027000000002	41.051329000000003	55.270805000000003	55.248041999999998	0103000020E61000000100000005000000D508FD4CBD84444068041BD7BF9F4B40D508FD4CBD844440F14BFDBCA9A24B400F2BDCF291864440F14BFDBCA9A24B400F2BDCF29186444068041BD7BF9F4B40D508FD4CBD84444068041BD7BF9F4B40
19105	Разъезд Вековка	1	3	1145	40.757264999999997	40.772796999999997	55.502727	55.494276999999997	0103000020E61000000100000005000000E5B33C0FEE6044401E15FF7744BF4B40E5B33C0FEE60444079E8BB5B59C04B4034B91803EB62444079E8BB5B59C04B4034B91803EB6244401E15FF7744BF4B40E5B33C0FEE6044401E15FF7744BF4B40
46578	Перово	1	3	1145	40.365428999999999	40.392234999999999	55.441045000000003	55.429158999999999	0103000020E610000001000000050000004701A260C62E44405CE49EAEEEB64B404701A260C62E44403C889D2974B84B405CACA8C1343244403C889D2974B84B405CACA8C1343244405CE49EAEEEB64B404701A260C62E44405CE49EAEEEB64B40
46758	Парахино 1-е	1	3	1145	40.791814000000002	40.804993000000003	55.265563	55.249201999999997	0103000020E61000000100000005000000EA4141295A654440840CE4D9E59F4B40EA4141295A6544408A03E8F7FDA14B402541B8020A6744408A03E8F7FDA14B402541B8020A674440840CE4D9E59F4B40EA4141295A654440840CE4D9E59F4B40
49089	Панфилово	1	3	1145	40.553517999999997	40.578968000000003	55.726325000000003	55.716802999999999	0103000020E61000000100000005000000A8DF85ADD94644405C566133C0DB4B40A8DF85ADD946444034A2B437F8DC4B401CB7989F1B4A444034A2B437F8DC4B401CB7989F1B4A44405C566133C0DB4B40A8DF85ADD94644405C566133C0DB4B40
54168	Новодурово	1	3	1145	41.102801999999997	41.118108999999997	55.295738999999998	55.280456999999998	0103000020E6100000010000000500000050FBAD9D288D44409677D503E6A34B4050FBAD9D288D44406C938AC6DAA54B407F2E1A321E8F44406C938AC6DAA54B407F2E1A321E8F44409677D503E6A34B4050FBAD9D288D44409677D503E6A34B40
47120	Нечаевская	1	3	1145	40.586979999999997	40.616444999999999	55.513458	55.500518999999997	0103000020E61000000100000005000000FAB31F29224B44406803B00111C04B40FAB31F29224B44404EEFE2FDB8C14B40306475ABE74E44404EEFE2FDB8C14B40306475ABE74E44406803B00111C04B40FAB31F29224B44406803B00111C04B40
54163	Нагорный Поселок	1	3	1145	40.748767000000001	40.759798000000004	55.407733999999998	55.403252000000002	0103000020E610000001000000050000007AA9D898D75F4440F705F4C29DB34B407AA9D898D75F4440CFBBB1A030B44B407AC8940F41614440CFBBB1A030B44B407AC8940F41614440F705F4C29DB34B407AA9D898D75F4440F705F4C29DB34B40
46602	Мокрое	1	3	1145	40.251029000000003	40.274357999999999	55.462457000000001	55.450358000000001	0103000020E610000001000000050000007EACE0B721204440F9BEB854A5B94B407EACE0B72120444034677DCA31BB4B40AFB2B6291E23444034677DCA31BB4B40AFB2B6291E234440F9BEB854A5B94B407EACE0B721204440F9BEB854A5B94B40
20657	Мезиновский	1	3	1145	40.349403000000002	40.432299999999998	55.509258000000003	55.466596000000003	0103000020E61000000100000005000000E90FCD3CB92C4440E338F06AB9BB4B40E90FCD3CB92C4440FA9CBB5D2FC14B40C8073D9B55374440FA9CBB5D2FC14B40C8073D9B55374440E338F06AB9BB4B40E90FCD3CB92C4440E338F06AB9BB4B40
20640	Курлово	1	3	1145	40.474017000000003	40.488543	55.435039000000003	55.430900999999999	0103000020E61000000100000005000000C05FCC96AC3C4440276893C327B74B40C05FCC96AC3C444006BEA25BAFB74B4049D8B793883E444006BEA25BAFB74B4049D8B793883E4440276893C327B74B40C05FCC96AC3C4440276893C327B74B40
19448	Купреево	1	3	1145	41.004022999999997	41.048571000000003	55.336641	55.325626	0103000020E6100000010000000500000045B75ED383804440185DDE1CAEA94B4045B75ED38380444012BF620D17AB4B405B4414933786444012BF620D17AB4B405B44149337864440185DDE1CAEA94B4045B75ED383804440185DDE1CAEA94B40
46632	Красный Октябрь	1	3	1145	40.899557999999999	40.918683000000001	55.413775000000001	55.396917999999999	0103000020E61000000100000005000000766D6FB724734440CC988235CEB24B40766D6FB72473444082734694F6B44B40123290679775444082734694F6B44B401232906797754440CC988235CEB24B40766D6FB724734440CC988235CEB24B40
20433	Красное Эхо	1	3	1145	40.685633000000003	40.720075000000001	55.800646	55.781975000000003	0103000020E61000000100000005000000790778D2C257444012A5BDC117E44B40790778D2C25744402CD670917BE64B4067D5E76A2B5C44402CD670917BE64B4067D5E76A2B5C444012A5BDC117E44B40790778D2C257444012A5BDC117E44B40
19521	Колпь	1	3	1145	41.026203000000002	41.057042000000003	55.248092999999997	55.229793999999998	0103000020E610000001000000050000004F07B29E5A8344409468C9E3699D4B404F07B29E5A834440EAAEEC82C19F4B40CD3FFA264D874440EAAEEC82C19F4B40CD3FFA264D8744409468C9E3699D4B404F07B29E5A8344409468C9E3699D4B40
20194	Икшево	1	3	1145	41.102612999999998	41.128520999999999	55.44753	55.430447000000001	0103000020E610000001000000050000007D923B6C228D4440A6D425E318B74B407D923B6C228D44404CFDBCA948B94B40B3EC4960739044404CFDBCA948B94B40B3EC496073904440A6D425E318B74B407D923B6C228D4440A6D425E318B74B40
20117	Золотковский	1	3	1145	41.062027999999998	41.090792	55.517383000000002	55.507559999999998	0103000020E61000000100000005000000D8B79388F0874440FE60E0B9F7C04B40D8B79388F0874440D1402C9B39C24B40855E7F129F8B4440D1402C9B39C24B40855E7F129F8B4440FE60E0B9F7C04B40D8B79388F0874440FE60E0B9F7C04B40
46877	Золотково	1	3	1145	41.080137999999998	41.119267999999998	55.539822999999998	55.519702000000002	0103000020E610000001000000050000005B9544F6418A444039D55A9885C24B405B9544F6418A4440765089EB18C54B40CBBA7F2C448F4440765089EB18C54B40CBBA7F2C448F444039D55A9885C24B405B9544F6418A444039D55A9885C24B40
19095	Заколпье	1	3	1145	40.951174999999999	41.014201	55.530754999999999	55.500590000000003	0103000020E61000000100000005000000EBE2361AC0794440325A475513C04B40EBE2361AC07944402098A3C7EFC34B4006499F56D18144402098A3C7EFC34B4006499F56D1814440325A475513C04B40EBE2361AC0794440325A475513C04B40
47064	Дубасово	1	3	1145	40.830604000000001	40.846826999999998	55.783943999999998	55.777348000000003	0103000020E61000000100000005000000A1F65B3B516A444036CEA62380E34B40A1F65B3B516A44409DF2E84658E44B40552FBFD3646C44409DF2E84658E44B40552FBFD3646C444036CEA62380E34B40A1F65B3B516A444036CEA62380E34B40
19917	Добрятино	1	3	1145	41.298769999999998	41.342112999999998	55.514767999999997	55.497377999999998	0103000020E61000000100000005000000518369183EA64440FCDF1115AABF4B40518369183EA644407F83F6EAE3C14B40AA44D95BCAAB44407F83F6EAE3C14B40AA44D95BCAAB4440FCDF1115AABF4B40518369183EA64440FCDF1115AABF4B40
47657	Гусевский	1	3	1145	40.463498000000001	40.591830999999999	55.667243999999997	55.609786999999997	0103000020E6100000010000000500000076E107E7533B444052431B800DCE4B4076E107E7533B4440E2395B4068D54B4026E1421EC14B4440E2395B4068D54B4026E1421EC14B444052431B800DCE4B4076E107E7533B444052431B800DCE4B40
46472	Григорьево	1	3	1145	40.944555000000001	40.990161999999998	55.512199000000003	55.503129999999999	0103000020E61000000100000005000000FB22A12DE778444078D1579066C04B40FB22A12DE77844409F05A1BC8FC14B40F8DEDFA0BD7E44409F05A1BC8FC14B40F8DEDFA0BD7E444078D1579066C04B40FB22A12DE778444078D1579066C04B40
19865	Великодворский	1	3	1145	40.647114000000002	40.698999999999998	55.256262	55.231478000000003	0103000020E610000001000000050000005264ADA1D45244402BDF3312A19D4B405264ADA1D4524440919A7631CDA04B40B6F3FDD478594440919A7631CDA04B40B6F3FDD4785944402BDF3312A19D4B405264ADA1D45244402BDF3312A19D4B40
47928	Вашутино	1	3	1145	40.724359999999997	40.741822999999997	55.709718000000002	55.699461999999997	0103000020E61000000100000005000000E94317D4B75C4440BA6587F887D94B40E94317D4B75C4440F7B0170AD8DA4B40D6355A0EF45E4440F7B0170AD8DA4B40D6355A0EF45E4440BA6587F887D94B40E94317D4B75C4440BA6587F887D94B40
48824	Борисово	1	3	1145	41.219349999999999	41.238475000000001	55.587009999999999	55.578192000000001	0103000020E6100000010000000500000055302AA9139C44408867093202CA4B4055302AA9139C44406536C82423CB4B40F1F44A59869E44406536C82423CB4B40F1F44A59869E44408867093202CA4B4055302AA9139C44408867093202CA4B40
19789	Анопино	1	3	1145	40.645091999999998	40.678167999999999	55.706806999999998	55.693306999999997	0103000020E61000000100000005000000A374E95F925244403F8BA548BED84B40A374E95F92524440BCCADAA678DA4B40CC988235CE564440BCCADAA678DA4B40CC988235CE5644403F8BA548BED84B40A374E95F925244403F8BA548BED84B40
54177	Аббакумово	1	3	1145	40.372714000000002	40.389845000000001	55.642026999999999	55.633927	0103000020E610000001000000050000007461A417B52F444094861A8524D14B407461A417B52F44401213D4F02DD24B402BC1E270E63144401213D4F02DD24B402BC1E270E631444094861A8524D14B407461A417B52F444094861A8524D14B40
689	Чулково	1	3	14	42.498497	42.508459000000002	56.126553999999999	56.121471	0103000020E61000000100000005000000BA13ECBFCE3F4540CA349A5C8C0F4C40BA13ECBFCE3F4540C896E5EB32104C40AE2D3C2F15414540C896E5EB32104C40AE2D3C2F15414540CA349A5C8C0F4C40BA13ECBFCE3F4540CA349A5C8C0F4C40
600	Фоминки	1	3	14	42.351810999999998	42.394174999999997	55.974004999999998	55.951366	0103000020E61000000100000005000000C0AF9124082D45405F43705CC6F94B40C0AF9124082D4540FB912232ACFC4B404DF38E5374324540FB912232ACFC4B404DF38E53743245405F43705CC6F94B40C0AF9124082D45405F43705CC6F94B40
47025	Семеновка	1	3	14	42.830559000000001	42.842201000000003	56.167639000000001	56.161372999999998	0103000020E610000001000000050000000133DFC14F6A45408CBAD6DEA7144C400133DFC14F6A45405F44DB3175154C404AD40B3ECD6B45405F44DB3175154C404AD40B3ECD6B45408CBAD6DEA7144C400133DFC14F6A45408CBAD6DEA7144C40
355	Пролетарский	1	3	14	42.320073000000001	42.353931000000003	56.111272999999997	56.089537999999997	0103000020E6100000010000000500000093AAED26F8284540E7DF2EFB750B4C4093AAED26F8284540C2F693313E0E4C4032056B9C4D2D4540C2F693313E0E4C4032056B9C4D2D4540E7DF2EFB750B4C4093AAED26F8284540E7DF2EFB750B4C40
46860	Осинки	1	3	14	42.419490000000003	42.429065999999999	55.913021000000001	55.903120000000001	0103000020E61000000100000005000000E17F2BD9B1354540882EA86F99F34B40E17F2BD9B1354540D6C743DFDDF44B40ABE97AA2EB364540D6C743DFDDF44B40ABE97AA2EB364540882EA86F99F34B40E17F2BD9B1354540882EA86F99F34B40
421	Крутово	1	3	14	42.412860000000002	42.433458999999999	56.177230999999999	56.168616	0103000020E61000000100000005000000CDE9B298D83445408ACA863595154C40CDE9B298D83445402F6B6281AF164C401494A2957B3745402F6B6281AF164C401494A2957B3745408ACA863595154C40CDE9B298D83445408ACA863595154C40
4284	Зименки	1	3	14	42.316434999999998	42.327987	55.875289000000002	55.866546	0103000020E61000000100000005000000A6272CF180284540643DB5FAEAEE4B40A6272CF18028454037C64E7809F04B40AF415F7AFB29454037C64E7809F04B40AF415F7AFB294540643DB5FAEAEE4B40A6272CF180284540643DB5FAEAEE4B40
308	Гришино	1	3	14	42.283126000000003	42.305897999999999	56.012228999999998	56.000456999999997	0103000020E61000000100000005000000DB5207793D244540F20698F90E004C40DB5207793D244540098849B890014C40B6F468AA27274540098849B890014C40B6F468AA27274540F20698F90E004C40DB5207793D244540F20698F90E004C40
32092	Гороховец	1	3	14	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
181	Галицы	1	3	14	42.831637000000001	42.859368000000003	56.187660999999999	56.170876	0103000020E610000001000000050000006092CA14736A4540EDD5C743DF154C406092CA14736A454009DE904605184C404E9D47C5FF6D454009DE904605184C404E9D47C5FF6D4540EDD5C743DF154C406092CA14736A4540EDD5C743DF154C40
54158	Выезд	1	3	14	42.145899	42.972968999999999	56.407178000000002	55.801298000000003	0103000020E6100000010000000500000072C284D1AC124540D42CD0EE90E64B4072C284D1AC1245404AD3A0681E344C40CB82893F8A7C45404AD3A0681E344C40CB82893F8A7C4540D42CD0EE90E64B4072C284D1AC124540D42CD0EE90E64B40
171	Великово	1	3	14	42.79813	42.825726000000003	56.164079999999998	56.149321	0103000020E610000001000000050000006EFAB31F2966454092CD55F31C134C406EFAB31F29664540BEF6CC9200154C407CBABA63B1694540BEF6CC9200154C407CBABA63B169454092CD55F31C134C406EFAB31F2966454092CD55F31C134C40
533	Быкасово	1	3	14	42.567891000000003	42.595433999999997	55.970115999999997	55.962760000000003	0103000020E61000000100000005000000AC58FCA6B0484540D0F23CB83BFB4B40AC58FCA6B0484540C5A9D6C22CFC4B4096766A2E374C4540C5A9D6C22CFC4B4096766A2E374C4540D0F23CB83BFB4B40AC58FCA6B0484540D0F23CB83BFB4B40
18	Арефино	1	3	14	42.626613999999996	42.637222999999999	56.178632999999998	56.172173999999998	0103000020E610000001000000050000009D9B36E3345045405A9C31CC09164C409D9B36E334504540417E3672DD164C4027A1F48590514540417E3672DD164C4027A1F485905145405A9C31CC09164C409D9B36E3345045405A9C31CC09164C40
54173	станции Сарыево	1	3	1160	41.549992000000003	42.594616000000002	56.450741999999998	55.904497999999997	0103000020E61000000100000005000000E4874A2366C6444011A62897C6F34B40E4874A2366C644408177F2E9B1394C40D4D688601C4C45408177F2E9B1394C40D4D688601C4C454011A62897C6F34B40E4874A2366C6444011A62897C6F34B40
31148	Эдон	1	3	1160	41.742168999999997	41.766567000000002	56.099983000000002	56.087705	0103000020E61000000100000005000000718DCF64FFDE44400C59DDEA390B4C40718DCF64FFDE4440F793313ECC0C4C40AF9811DE1EE24440F793313ECC0C4C40AF9811DE1EE244400C59DDEA390B4C40718DCF64FFDE44400C59DDEA390B4C40
31300	Шатнево	1	3	1160	41.924168000000002	41.944316999999998	56.102156999999998	56.086530000000003	0103000020E610000001000000050000003F0114234BF64440BB0F406A130B4C403F0114234BF644405B07077B130D4C4046072461DFF844405B07077B130D4C4046072461DFF84440BB0F406A130B4C403F0114234BF64440BB0F406A130B4C40
46519	Чудиново	1	3	1160	42.053210999999997	42.082360999999999	56.246326000000003	56.236266000000001	0103000020E61000000100000005000000CB64389ECF0645401094DBF63D1E4C40CB64389ECF064540C713419C871F4C40A1BB24CE8A0A4540C713419C871F4C40A1BB24CE8A0A45401094DBF63D1E4C40CB64389ECF0645401094DBF63D1E4C40
54159	Центральный	1	3	1160	42.117288000000002	42.141255000000001	56.211328000000002	56.196432000000001	0103000020E610000001000000050000004C1B0E4B030F4540A6F10BAF24194C404C1B0E4B030F4540535DC0CB0C1B4C40C0B2D2A414124540535DC0CB0C1B4C40C0B2D2A414124540A6F10BAF24194C404C1B0E4B030F4540A6F10BAF24194C40
46943	Степанцево	1	3	1160	41.68403	41.728226999999997	56.139857999999997	56.123027	0103000020E61000000100000005000000CFBD874B8ED7444033C34659BF0F4C40CFBD874B8ED74440BF0AF0DDE6114C403788D68A36DD4440BF0AF0DDE6114C403788D68A36DD444033C34659BF0F4C40CFBD874B8ED7444033C34659BF0F4C40
31819	Сергиевы-Горки	1	3	1160	42.090338000000003	42.119748999999999	55.992800000000003	55.978240999999997	0103000020E6100000010000000500000004CB1132900B45409C4D470037FD4B4004CB1132900B454002BC051214FF4B40465D6BEF530F454002BC051214FF4B40465D6BEF530F45409C4D470037FD4B4004CB1132900B45409C4D470037FD4B40
54175	Сергеево	1	3	1160	42.125875000000001	42.143914000000002	56.197949000000001	56.181043000000003	0103000020E61000000100000005000000273108AC1C104540BA15C26A2C174C40273108AC1C10454051A3906456194C40E1B721C66B12454051A3906456194C40E1B721C66B124540BA15C26A2C174C40273108AC1C104540BA15C26A2C174C40
31009	Сарыево	1	3	1160	41.693722999999999	41.774552999999997	56.305933000000003	56.263272000000001	0103000020E61000000100000005000000D3BD4EEACBD84440ECF99AE5B2214C40D3BD4EEACBD8444033E202D028274C4064027E8D24E3444033E202D028274C4064027E8D24E34440ECF99AE5B2214C40D3BD4EEACBD84440ECF99AE5B2214C40
47075	Приозерный	1	3	1160	41.960028000000001	41.973188999999998	56.144742000000001	56.138288000000003	0103000020E61000000100000005000000459F8F32E2FA4440F2B6D26BB3114C40459F8F32E2FA4440C72DE6E786124C40D9E9077591FC4440C72DE6E786124C40D9E9077591FC4440F2B6D26BB3114C40459F8F32E2FA4440F2B6D26BB3114C40
12752	Пировы Городищи	1	3	1160	42.244228	42.265096	56.234115000000003	56.223700999999998	0103000020E610000001000000050000003D62F4DC421F45408F8AFF3BA21C4C403D62F4DC421F45406440F67AF71D4C4074266DAAEE2145406440F67AF71D4C4074266DAAEE2145408F8AFF3BA21C4C403D62F4DC421F45408F8AFF3BA21C4C40
54161	Пески	1	3	1160	42.241525000000003	42.262104999999998	56.204478999999999	56.184916000000001	0103000020E610000001000000050000004D158C4AEA1E4540EA40D653AB174C404D158C4AEA1E454001DC2C5E2C1A4C401D8F19A88C21454001DC2C5E2C1A4C401D8F19A88C214540EA40D653AB174C404D158C4AEA1E4540EA40D653AB174C40
31913	Паустово	1	3	1160	42.149447000000002	42.180295000000001	56.127516999999997	56.111634000000002	0103000020E610000001000000050000001FBE4C1421134540938FDD054A0E4C401FBE4C14211345408E57207A52104C40F05014E8131745408E57207A52104C40F05014E813174540938FDD054A0E4C401FBE4C1421134540938FDD054A0E4C40
54150	Октябрьский	1	3	1160	42.005932000000001	42.059579999999997	56.230511999999997	56.20872	0103000020E61000000100000005000000FCFF3861C2004540B4024356B71A4C40FCFF3861C2004540F3AACE6A811D4C4072BF4351A0074540F3AACE6A811D4C4072BF4351A0074540B4024356B71A4C40FCFF3861C2004540B4024356B71A4C40
54139	Октябрьская	1	3	1160	42.109274999999997	42.130906000000003	56.078729000000003	56.06653	0103000020E610000001000000050000009CA223B9FC0D4540F819170E84084C409CA223B9FC0D4540971FB8CA130A4C40D36C1E87C1104540971FB8CA130A4C40D36C1E87C1104540F819170E84084C409CA223B9FC0D4540F819170E84084C40
31447	Никологоры	1	3	1160	41.969991	42.020080999999998	56.155056999999999	56.123649	0103000020E61000000100000005000000093543AA28FC44407097FDBAD30F4C40093543AA28FC4440080264E8D8134C40AF22A30392024540080264E8D8134C40AF22A303920245407097FDBAD30F4C40093543AA28FC44407097FDBAD30F4C40
30700	Мстера	1	3	1160	41.908347999999997	41.953173999999997	56.389035	56.366829000000003	0103000020E6100000010000000500000089B14CBF44F44440B91CAF40F42E4C4089B14CBF44F44440EBFF1CE6CB314C40E1B20A9B01FA4440EBFF1CE6CB314C40E1B20A9B01FA4440B91CAF40F42E4C4089B14CBF44F44440B91CAF40F42E4C40
46675	Малые Удолы	1	3	1160	42.221877999999997	42.255862	56.275584000000002	56.266057000000004	0103000020E61000000100000005000000D7D9907F661C45409AEFE0270E224C40D7D9907F661C454083A6255646234C4003250516C020454083A6255646234C4003250516C02045409AEFE0270E224C40D7D9907F661C45409AEFE0270E224C40
47048	Маловская	1	3	1160	41.957621000000003	41.979889999999997	56.120994000000003	56.110976999999998	0103000020E610000001000000050000003E7B2E5393FA4440D9CD8C7E340E4C403E7B2E5393FA444091813CBB7C0F4C40B6D617096DFD444091813CBB7C0F4C40B6D617096DFD4440D9CD8C7E340E4C403E7B2E5393FA4440D9CD8C7E340E4C40
31575	Лукново	1	3	1160	42.029952999999999	42.054873000000001	56.196457000000002	56.172269999999997	0103000020E6100000010000000500000063B5F97FD50345407C0A80F10C164C4063B5F97FD5034540FF08C38025194C407A37161406074540FF08C38025194C407A371614060745407C0A80F10C164C4063B5F97FD50345407C0A80F10C164C40
29990	Коурково	1	3	1160	41.982441000000001	42.001899000000002	56.242119000000002	56.233744000000002	0103000020E61000000100000005000000F19F6EA0C0FD444070D1C952EB1D4C40F19F6EA0C0FD4440C05E61C1FD1E4C409372F7393E004540C05E61C1FD1E4C409372F7393E00454070D1C952EB1D4C40F19F6EA0C0FD444070D1C952EB1D4C40
46701	Козлово	1	3	1160	42.099285000000002	42.120638	56.332630999999999	56.326402999999999	0103000020E61000000100000005000000DFFDF15EB50C45407C28D192C7294C40DFFDF15EB50C4540615111A7932A4C40D253E410710F4540615111A7932A4C40D253E410710F45407C28D192C7294C40DFFDF15EB50C45407C28D192C7294C40
46742	Заречный	1	3	1160	41.934964999999998	41.952688999999999	56.366574999999997	56.354343	0103000020E61000000100000005000000CBF3E0EEACF744408448861C5B2D4C40CBF3E0EEACF74440FE43FAEDEB2E4C40252191B6F1F94440FE43FAEDEB2E4C40252191B6F1F944408448861C5B2D4C40CBF3E0EEACF744408448861C5B2D4C40
47011	Галкино	1	3	1160	41.813611999999999	41.838405999999999	56.121831999999998	56.112738999999998	0103000020E610000001000000050000000BD1217024E84440EBFD463B6E0E4C400BD1217024E844409ACDE330980F4C40956247E350EB44409ACDE330980F4C40956247E350EB4440EBFD463B6E0E4C400BD1217024E84440EBFD463B6E0E4C40
11032	Вязники	1	3	1160	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
47333	Воробьевка	1	3	1160	42.137535999999997	42.166182999999997	56.165353000000003	56.151240999999999	0103000020E61000000100000005000000E60297C79A1145403C6876DD5B134C40E60297C79A114540D3A57F492A154C4059130B7C45154540D3A57F492A154C4059130B7C451545403C6876DD5B134C40E60297C79A1145403C6876DD5B134C40
31173	Буторлино	1	3	1160	41.814349	41.838611999999998	56.050545999999997	56.037433	0103000020E61000000100000005000000E14389963CE844404565C39ACA044C40E14389963CE84440C878944A78064C403E0455A357EB4440C878944A78064C403E0455A357EB44404565C39ACA044C40E14389963CE844404565C39ACA044C40
31703	Большевысоково	1	3	1160	41.856820999999997	41.878345000000003	56.174655000000001	56.166235	0103000020E6100000010000000500000054C37E4FACED4440AC39403047154C4054C37E4FACED44409C8A54185B164C4075CDE49B6DF044409C8A54185B164C4075CDE49B6DF04440AC39403047154C4054C37E4FACED4440AC39403047154C40
30649	Барское Татарово	1	3	1160	41.901234000000002	41.925991000000003	56.394494999999999	56.382989999999999	0103000020E610000001000000050000008A05BEA25BF34440F758FAD005314C408A05BEA25BF34440BFB7E9CF7E324C40F7B182DF86F64440BFB7E9CF7E324C40F7B182DF86F64440F758FAD005314C408A05BEA25BF34440F758FAD005314C40
46611	Аксеново	1	3	1160	42.403455000000001	42.417307000000001	56.200257999999998	56.195185000000002	0103000020E610000001000000050000002F34D769A4334540BBD573D2FB184C402F34D769A43345409561DC0DA2194C4029B2D6506A3545409561DC0DA2194C4029B2D6506A354540BBD573D2FB184C402F34D769A4334540BBD573D2FB184C40
46091	Тургенево	1	3	12	38.369840000000003	38.379272	56.517578999999998	56.511287000000003	0103000020E610000001000000050000005760C8EA562F43405BEF37DA71414C405760C8EA562F4340560C570740424C40EE2422FC8B304340560C570740424C40EE2422FC8B3043405BEF37DA71414C405760C8EA562F43405BEF37DA71414C40
1608	Струнино	1	3	12	38.5565	38.598236	56.389009999999999	56.359713999999997	0103000020E61000000100000005000000AC1C5A643B474340E8F4BC1B0B2E4C40AC1C5A643B47434092E86514CB314C401AA54BFF924C434092E86514CB314C401AA54BFF924C4340E8F4BC1B0B2E4C40AC1C5A643B474340E8F4BC1B0B2E4C40
177	Следнево	1	3	12	38.592531999999999	38.6081	56.422575000000002	56.411071999999997	0103000020E61000000100000005000000AFEAAC16D84B43409126DE019E344C40AFEAAC16D84B4340B98D06F016364C404B598638D64D4340B98D06F016364C404B598638D64D43409126DE019E344C40AFEAAC16D84B43409126DE019E344C40
812	Светлый	1	3	12	38.769832000000001	38.782120999999997	56.415543999999997	56.409413999999998	0103000020E6100000010000000500000007B5DFDA8962434024438EAD67344C4007B5DFDA896243404606B98B30354C40E5417A8A1C6443404606B98B30354C40E5417A8A1C64434024438EAD67344C4007B5DFDA8962434024438EAD67344C40
541	Обашево	1	3	12	38.474744999999999	38.498209000000003	56.631515999999998	56.619838999999999	0103000020E610000001000000050000004278B471C43C434086E464E2564F4C404278B471C43C43404B732B84D5504C4054C90050C53F43404B732B84D5504C4054C90050C53F434086E464E2564F4C404278B471C43C434086E464E2564F4C40
32443	Мошнино	1	3	12	38.833128000000002	38.848281999999998	56.467812000000002	56.455582	0103000020E61000000100000005000000E2B034F0A36A4340B952CF82503A4C40E2B034F0A36A434093567C43E13B4C408AE42B81946C434093567C43E13B4C408AE42B81946C4340B952CF82503A4C40E2B034F0A36A4340B952CF82503A4C40
1026	Маяк	1	3	12	38.806789000000002	38.822285000000001	56.383263999999997	56.372866999999999	0103000020E61000000100000005000000E3E2A8DC44674340FA60191BBA2F4C40E3E2A8DC44674340F8DD74CB0E314C40E57E87A240694340F8DD74CB0E314C40E57E87A240694340FA60191BBA2F4C40E3E2A8DC44674340FA60191BBA2F4C40
1288	Махра	1	3	12	38.670307999999999	38.686746999999997	56.272885000000002	56.263522000000002	0103000020E61000000100000005000000A31F0DA7CC55434065E3C116BB214C40A31F0DA7CC554340D4484BE5ED224C4024D06053E7574340D4484BE5ED224C4024D06053E757434065E3C116BB214C40A31F0DA7CC55434065E3C116BB214C40
698	Майский	1	3	12	38.870336000000002	38.891320999999998	56.428902000000001	56.421753000000002	0103000020E610000001000000050000000744882B676F4340B5FE9600FC354C400744882B676F43403198BF42E6364C40779E78CE167243403198BF42E6364C40779E78CE16724340B5FE9600FC354C400744882B676F4340B5FE9600FC354C40
409	Лобково	1	3	12	38.336440000000003	38.354666999999999	56.502291	56.490076999999999	0103000020E610000001000000050000007B884677102B4340CAC2D7D7BA3E4C407B884677102B43409E094D124B404C4037FC6EBA652D43409E094D124B404C4037FC6EBA652D4340CAC2D7D7BA3E4C407B884677102B4340CAC2D7D7BA3E4C40
310	Лисавы	1	3	12	38.522275	38.548290000000001	56.551228999999999	56.540902000000003	0103000020E610000001000000050000005B423EE8D9424340A62BD8463C454C405B423EE8D9424340ABCDFFAB8E464C40A75CE15D2E464340ABCDFFAB8E464C40A75CE15D2E464340A62BD8463C454C405B423EE8D9424340A62BD8463C454C40
1300	Лизуново	1	3	12	38.483701000000003	38.503078000000002	56.303032000000002	56.288480999999997	0103000020E61000000100000005000000710514EAE93D4340394206F2EC244C40710514EAE93D43401CD2A8C0C9264C4026AB22DC644043401CD2A8C0C9264C4026AB22DC64404340394206F2EC244C40710514EAE93D4340394206F2EC244C40
909	Легково	1	3	12	38.883899999999997	38.893998000000003	56.397523999999997	56.389871999999997	0103000020E610000001000000050000009A779CA22371434024D06053E7314C409A779CA22371434003B00111E2324C403F58C6866E72434003B00111E2324C403F58C6866E72434024D06053E7314C409A779CA22371434024D06053E7314C40
340	Красное Пламя	1	3	12	38.529119999999999	38.547338000000003	56.568471000000002	56.551640999999996	0103000020E610000001000000050000006BD44334BA434340FD101B2C9C464C406BD44334BA434340BADC60A8C3484C40D5EDEC2B0F464340BADC60A8C3484C40D5EDEC2B0F464340FD101B2C9C464C406BD44334BA434340FD101B2C9C464C40
15	Карабаново	1	3	12	38.673749000000001	38.727072999999997	56.330140999999998	56.292777000000001	0103000020E610000001000000050000003A5B40683D564340B0027CB779254C403A5B40683D564340CC086F0F422A4C40FD6662BA105D4340CC086F0F422A4C40FD6662BA105D4340B0027CB779254C403A5B40683D564340B0027CB779254C40
488	Искра	1	3	12	38.372731999999999	38.394840000000002	56.532851999999998	56.521715999999998	0103000020E610000001000000050000001A16A3AEB52F434064E60297C7424C401A16A3AEB52F4340D9CD8C7E34444C408A93FB1D8A324340D9CD8C7E34444C408A93FB1D8A32434064E60297C7424C401A16A3AEB52F434064E60297C7424C40
1198	Зеленцино	1	3	12	38.72983	38.749827000000003	56.292183000000001	56.281561000000004	0103000020E61000000100000005000000E1D1C6116B5D43401F6ADB300A244C40E1D1C6116B5D43403DB9A64066254C403354C554FA5F43403DB9A64066254C403354C554FA5F43401F6ADB300A244C40E1D1C6116B5D43401F6ADB300A244C40
846	Елькино	1	3	12	38.813706000000003	38.832453999999998	56.397424999999998	56.386477999999997	0103000020E610000001000000050000008D47A98427684340CE4F711C78314C408D47A9842768434070CE88D2DE324C4052B648DA8D6A434070CE88D2DE324C4052B648DA8D6A4340CE4F711C78314C408D47A98427684340CE4F711C78314C40
601	Долгополье	1	3	12	39.222079999999998	39.229905000000002	56.534275999999998	56.529600000000002	0103000020E610000001000000050000003F8C101E6D9C434016FBCBEEC9434C403F8C101E6D9C4340D384ED2763444C40EC17EC866D9D4340D384ED2763444C40EC17EC866D9D434016FBCBEEC9434C403F8C101E6D9C434016FBCBEEC9434C40
693	Годуново	1	3	12	39.023327999999999	39.052847	56.492283999999998	56.478675000000003	0103000020E61000000100000005000000618A7269FC824340D734EF38453D4C40618A7269FC8243400A2C8029033F4C408A58C4B0C38643400A2C8029033F4C408A58C4B0C3864340D734EF38453D4C40618A7269FC824340D734EF38453D4C40
1151	Большое Каринское	1	3	12	38.638390999999999	38.659779999999998	56.372951	56.364516000000002	0103000020E61000000100000005000000C687D9CBB6514340336FD575A82E4C40C687D9CBB65143405801BEDBBC2F4C400647C9AB735443405801BEDBBC2F4C400647C9AB73544340336FD575A82E4C40C687D9CBB6514340336FD575A82E4C40
32289	Балакирево	1	3	12	38.820497000000003	38.863382999999999	56.517763000000002	56.491349999999997	0103000020E61000000100000005000000AABBB20B06694340DE718A8EE43E4C40AABBB20B06694340180AD80E46424C4010768A55836E4340180AD80E46424C4010768A55836E4340DE718A8EE43E4C40AABBB20B06694340DE718A8EE43E4C40
32488	Бакшеево	1	3	12	38.692874000000003	38.713337000000003	56.456254000000001	56.444394000000003	0103000020E61000000100000005000000D61F6118B0584340F24410E7E1384C40D61F6118B0584340A855F487663A4C406D0377A04E5B4340A855F487663A4C406D0377A04E5B4340F24410E7E1384C40D61F6118B0584340F24410E7E1384C40
1091	Бакино	1	3	12	38.967084	38.988670999999997	56.337831000000001	56.326931999999999	0103000020E61000000100000005000000103E9468C97B4340080264E8D8294C40103E9468C97B43409949D40B3E2B4C4076C075C58C7E43409949D40B3E2B4C4076C075C58C7E4340080264E8D8294C40103E9468C97B4340080264E8D8294C40
197	Арсаки	1	3	12	38.453859000000001	38.484302999999997	56.389592999999998	56.380578	0103000020E6100000010000000500000065FF3C0D183A4340DEC9A7C7B6304C4065FF3C0D183A434011E0F42EDE314C40662D05A4FD3D434011E0F42EDE314C40662D05A4FD3D4340DEC9A7C7B6304C4065FF3C0D183A4340DEC9A7C7B6304C40
969	Андреевское	1	3	12	38.986659000000003	39.022744000000003	56.413522999999998	56.394838999999997	0103000020E61000000100000005000000ECA694D74A7E4340B91798158A324C40ECA694D74A7E434068925852EE344C4012178046E982434068925852EE344C4012178046E9824340B91798158A324C40ECA694D74A7E4340B91798158A324C40
9113	Александров	1	3	12	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
12390	Супонево	1	2	\N	34.304989999999997	34.362229999999997	53.225037	53.202513000000003	0103000020E61000000100000005000000B3CD8DE909274140E7012CF2EB994A40B3CD8DE909274140EAB12D03CE9C4A40A6D0798D5D2E4140EAB12D03CE9C4A40A6D0798D5D2E4140E7012CF2EB994A40B3CD8DE909274140E7012CF2EB994A40
10879	Сельцо	1	2	\N	34.005122999999998	34.147469999999998	53.402729000000001	53.340634999999999	0103000020E610000001000000050000008CBAD6DEA7004140BD6F7CED99AB4A408CBAD6DEA70041404D13B69F8CB34A401092054CE01241404D13B69F8CB34A401092054CE0124140BD6F7CED99AB4A408CBAD6DEA7004140BD6F7CED99AB4A40
51076	Почеп	1	2	\N	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
51030	Новые дарковичи	1	2	\N	31.259520999999999	35.325978999999997	54.034362999999999	51.843729000000003	0103000020E610000001000000050000000EA0DFF76F423F40E9D7D64FFFEB49400EA0DFF76F423F40A298BC0166044B4065170CAEB9A94140A298BC0166044B4065170CAEB9A94140E9D7D64FFFEB49400EA0DFF76F423F40E9D7D64FFFEB4940
1088	Новозыбков	1	2	\N	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
51061	Мглин	1	2	\N	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
22579	Клинцы	1	2	\N	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
51057	Карачев	1	2	\N	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
1655	Брянск	1	2	\N	34.183151000000002	34.569310000000002	53.382426000000002	53.179409999999997	0103000020E61000000100000005000000679DF17D71174140A54929E8F6964A40679DF17D71174140EF91CD55F3B04A4094A46B26DF484140EF91CD55F3B04A4094A46B26DF484140A54929E8F6964A40679DF17D71174140A54929E8F6964A40
51135	Шулаковка	1	2	1139	32.758710999999998	32.790233000000001	52.898775000000001	52.880633000000003	0103000020E61000000100000005000000C70E2A711D614040A2630795B8704A40C70E2A711D61404030BB270F0B734A40289CDD5A2665404030BB270F0B734A40289CDD5A26654040A2630795B8704A40C70E2A711D614040A2630795B8704A40
16687	Унеча	1	2	1139	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
21250	Староселье	1	2	1139	33.114739999999998	33.146566999999997	52.869844000000001	52.852038	0103000020E6100000010000000500000082C5E1CCAF8E40408179C8940F6D4A4082C5E1CCAF8E4040984F560C576F4A401FD61BB5C2924040984F560C576F4A401FD61BB5C29240408179C8940F6D4A4082C5E1CCAF8E40408179C8940F6D4A40
21095	Старая Гута	1	2	1139	32.507936999999998	32.551245000000002	52.823974	52.806901000000003	0103000020E61000000100000005000000D4B66114044140400B0E2F8848674A40D4B66114044140408D60E3FA77694A40B18A37328F4640408D60E3FA77694A40B18A37328F4640400B0E2F8848674A40D4B66114044140400B0E2F8848674A40
19911	Слобода-Селецкая	1	2	1139	32.608198000000002	32.626612999999999	52.825350999999998	52.811528000000003	0103000020E610000001000000050000000EBF9B6ED94D4040E7E44526E0674A400EBF9B6ED94D4040465C001AA5694A40CD1FD3DA34504040465C001AA5694A40CD1FD3DA34504040E7E44526E0674A400EBF9B6ED94D4040E7E44526E0674A40
51153	Рюхово	1	2	1139	32.760741000000003	32.781438000000001	52.782347999999999	52.762005000000002	0103000020E61000000100000005000000F9DC09F65F614040BA313D6189614A40F9DC09F65F614040A60BB1FA23644A4003ED0E2906644040A60BB1FA23644A4003ED0E2906644040BA313D6189614A40F9DC09F65F614040BA313D6189614A40
20209	Рохманово	1	2	1139	32.866320000000002	32.885480999999999	52.761187999999997	52.741073999999998	0103000020E6100000010000000500000074EFE192E36E40403CF54883DB5E4A4074EFE192E36E4040C70DBF9B6E614A405C1D007157714040C70DBF9B6E614A405C1D0071577140403CF54883DB5E4A4074EFE192E36E40403CF54883DB5E4A40
21133	Робчик	1	2	1139	32.472067000000003	32.517719999999997	52.800972000000002	52.783180999999999	0103000020E61000000100000005000000AB4203B16C3C40409EEC66463F644A40AB4203B16C3C40408081204086664A40183E22A6444240408081204086664A40183E22A6444240409EEC66463F644A40AB4203B16C3C40409EEC66463F644A40
48521	Пучковка	1	2	1139	33.040512	33.056331999999998	52.899464999999999	52.884388000000001	0103000020E610000001000000050000003B8C497F2F854040C87C40A033714A403B8C497F2F854040C5724BAB21734A40F0DB10E335874040C5724BAB21734A40F0DB10E335874040C87C40A033714A403B8C497F2F854040C87C40A033714A40
48234	Писаревка	1	2	1139	32.698587000000003	32.727089999999997	52.937016	52.913097	0103000020E6100000010000000500000094347F4C6B594040B189CC5CE0744A4094347F4C6B59404014EAE923F0774A40D39FFD48115D404014EAE923F0774A40D39FFD48115D4040B189CC5CE0744A4094347F4C6B594040B189CC5CE0744A40
20328	Новые Ивайтенки	1	2	1139	33.051552999999998	33.078294999999997	52.790294000000003	52.771273000000001	0103000020E610000001000000050000005E81E84999864040D7A4DB12B9624A405E81E84999864040CE1C925A28654A405C381092058A4040CE1C925A28654A405C381092058A4040D7A4DB12B9624A405E81E84999864040D7A4DB12B9624A40
20634	Найтоповичи	1	2	1139	32.636476999999999	32.664963	52.768161999999997	52.749104000000003	0103000020E61000000100000005000000FED30D1478514040C2A6CEA3E25F4A40FED30D1478514040D503E62153624A406806F1811D554040D503E62153624A406806F1811D554040C2A6CEA3E25F4A40FED30D1478514040C2A6CEA3E25F4A40
51130	Лыщичи	1	2	1139	32.426900000000003	33.198894000000003	52.991798000000003	52.660494999999997	0103000020E61000000100000005000000CA54C1A8A4364040F415A4198B544A40CA54C1A8A43640407E1EA33CF37E4A4071AFCC5B759940407E1EA33CF37E4A4071AFCC5B75994040F415A4198B544A40CA54C1A8A4364040F415A4198B544A40
21256	Лизогубовка	1	2	1139	33.111325999999998	33.143135999999998	52.921990999999998	52.909002000000001	0103000020E61000000100000005000000E5982CEE3F8E4040D2FF722D5A744A40E5982CEE3F8E4040691A14CD03764A40AC70CB4752924040691A14CD03764A40AC70CB4752924040D2FF722D5A744A40E5982CEE3F8E4040D2FF722D5A744A40
20430	Красновичи	1	2	1139	32.584958999999998	32.626280999999999	52.918826000000003	52.904625000000003	0103000020E610000001000000050000001C40BFEFDF4A40406F1283C0CA734A401C40BFEFDF4A4040755B22179C754A40978DCEF929504040755B22179C754A40978DCEF9295040406F1283C0CA734A401C40BFEFDF4A40406F1283C0CA734A40
20858	Коробоничи	1	2	1139	32.893728000000003	32.911245000000001	52.875410000000002	52.866767000000003	0103000020E610000001000000050000007FC2D9AD6572404043209738F26E4A407FC2D9AD65724040B24B546F0D704A405FD218ADA3744040B24B546F0D704A405FD218ADA374404043209738F26E4A407FC2D9AD6572404043209738F26E4A40
47777	Займище	1	2	1139	32.654119999999999	32.664504000000001	52.801223	52.795299	0103000020E610000001000000050000006BD44334BA53404050C58D5BCC654A406BD44334BA534040C9E6AA798E664A40D50792770E554040C9E6AA798E664A40D50792770E55404050C58D5BCC654A406BD44334BA53404050C58D5BCC654A40
20400	Задубенье	1	2	1139	33.027478000000002	33.054974999999999	52.81315	52.784097000000003	0103000020E6100000010000000500000004AE2B668483404024F25D4A5D644A4004AE2B6684834040075F984C15684A407E8CB96B09874040075F984C15684A407E8CB96B0987404024F25D4A5D644A4004AE2B668483404024F25D4A5D644A40
10615	Добрик	1	2	1139	32.469614999999997	32.489530999999999	52.905928000000003	52.892625000000002	0103000020E61000000100000005000000035B25581C3C4040C74B378941724A40035B25581C3C4040EE43DE72F5734A4068B0A9F3A83E4040EE43DE72F5734A4068B0A9F3A83E4040C74B378941724A40035B25581C3C4040C74B378941724A40
48936	Высокое	1	2	1139	32.908110000000001	32.923434999999998	52.760354	52.748111999999999	0103000020E61000000100000005000000D595CFF23C74404061DF4E22C25F4A40D595CFF23C744040FFB0A54753614A40AA7D3A1E33764040FFB0A54753614A40AA7D3A1E3376404061DF4E22C25F4A40D595CFF23C74404061DF4E22C25F4A40
20649	Брянкустичи	1	2	1139	32.582183000000001	32.614423000000002	52.706937000000003	52.694718999999999	0103000020E61000000100000005000000C2A4F8F8844A404075745C8DEC584A40C2A4F8F8844A40408BAA5FE97C5A4A408274B169A54E40408BAA5FE97C5A4A408274B169A54E404075745C8DEC584A40C2A4F8F8844A404075745C8DEC584A40
51137	Бородинка	1	2	1139	32.983029000000002	32.995525000000001	52.790990999999998	52.779471999999998	0103000020E610000001000000050000008202EFE4D37D4040E8120EBDC5634A408202EFE4D37D404015376E313F654A40DAACFA5C6D7F404015376E313F654A40DAACFA5C6D7F4040E8120EBDC5634A408202EFE4D37D4040E8120EBDC5634A40
51111	Белогорщ	1	2	1139	32.721943000000003	32.739172000000003	52.909669999999998	52.890604000000003	0103000020E61000000100000005000000BF49D3A0685C4040E9D7D64FFF714A40BF49D3A0685C40407F130A1170744A40390F27309D5E40407F130A1170744A40390F27309D5E4040E9D7D64FFF714A40BF49D3A0685C4040E9D7D64FFF714A40
20020	Аленовка	1	2	1139	32.758315000000003	32.778213000000001	52.825840999999997	52.815229000000002	0103000020E610000001000000050000007B884677106140401AE0826C59684A407B8846771061404014596B28B5694A403929CC7B9C63404014596B28B5694A403929CC7B9C6340401AE0826C59684A407B884677106140401AE0826C59684A40
47165	Юрово	1	2	1482	33.872414999999997	33.901708999999997	52.742829999999998	52.728439999999999	0103000020E6100000010000000500000019C5724BABEF4040938C9C853D5D4A4019C5724BABEF40406C3EAE0D155F4A4022C154336BF340406C3EAE0D155F4A4022C154336BF34040938C9C853D5D4A4019C5724BABEF4040938C9C853D5D4A40
18502	Хотьяновка	1	2	1482	33.538691	33.556091000000002	52.553147000000003	52.539845	0103000020E6100000010000000500000024D3A1D3F3C440405EF415A419454A4024D3A1D3F3C44040B5705985CD464A40CB4C69FD2DC74040B5705985CD464A40CB4C69FD2DC740405EF415A419454A4024D3A1D3F3C440405EF415A419454A40
47382	Филипповичи	1	2	1482	33.649282999999997	33.668453	52.583399999999997	52.572975	0103000020E61000000100000005000000A46C91B41BD340407A36AB3E57494A40A46C91B41BD34040423EE8D9AC4A4A40E0F42EDE8FD54040423EE8D9AC4A4A40E0F42EDE8FD540407A36AB3E57494A40A46C91B41BD340407A36AB3E57494A40
47637	Усох	1	2	1482	33.829403999999997	33.855015000000002	52.613168000000002	52.594642999999998	0103000020E61000000100000005000000F69507E929EA4040CDE506431D4C4A40F69507E929EA4040147AFD497C4E4A40734BAB2171ED4040147AFD497C4E4A40734BAB2171ED4040CDE506431D4C4A40F69507E929EA4040CDE506431D4C4A40
16980	Трубчевск	1	2	1482	33.743389999999998	33.788646999999997	52.598205	52.533540000000002	0103000020E6100000010000000500000033164D6727DF4040CE8DE9094B444A4033164D6727DF4040DFA63FFB914C4A40548B8862F2E44040DFA63FFB914C4A40548B8862F2E44040CE8DE9094B444A4033164D6727DF4040CE8DE9094B444A40
17930	Телец	1	2	1482	33.733338000000003	33.756037999999997	52.574748999999997	52.564698999999997	0103000020E6100000010000000500000000750305DEDD4040BD8A8C0E48484A4000750305DEDD404050340F6091494A4041446ADAC5E0404050340F6091494A4041446ADAC5E04040BD8A8C0E48484A4000750305DEDD4040BD8A8C0E48484A40
47725	Семячки	1	2	1482	33.647145000000002	33.676375999999998	52.656529999999997	52.640870999999997	0103000020E610000001000000050000008D62B9A5D5D2404037FA980F08524A408D62B9A5D5D24040E36BCF2C09544A404FE61F7D93D64040E36BCF2C09544A404FE61F7D93D6404037FA980F08524A408D62B9A5D5D2404037FA980F08524A40
18219	Селец	1	2	1482	33.553674999999998	33.592275000000001	52.526342	52.501717999999997	0103000020E6100000010000000500000070CE88D2DEC6404042E8A04B38404A4070CE88D2DEC640407041B62C5F434A40849ECDAACFCB40407041B62C5F434A40849ECDAACFCB404042E8A04B38404A4070CE88D2DEC6404042E8A04B38404A40
18336	Сагутьево	1	2	1482	33.452137999999998	33.475062999999999	52.446384999999999	52.426242000000002	0103000020E61000000100000005000000B1A371A8DFB9404040170D198F364A40B1A371A8DFB940406536C82423394A40134548DDCEBC40406536C82423394A40134548DDCEBC404040170D198F364A40B1A371A8DFB9404040170D198F364A40
17879	Рябчевск	1	2	1482	33.964312999999997	33.980392999999999	52.812762999999997	52.804004999999997	0103000020E61000000100000005000000C70DBF9B6EFB40400569C6A2E9664A40C70DBF9B6EFB40400D33349E08684A40191D90847DFD40400D33349E08684A40191D90847DFD40400569C6A2E9664A40C70DBF9B6EFB40400569C6A2E9664A40
18897	Радутино	1	2	1482	33.924616	33.953533	52.636073000000003	52.618996000000003	0103000020E61000000100000005000000DEAD2CD159F640406B2DCC423B4F4A40DEAD2CD159F640402F6F0ED76A514A4011548D5E0DFA40402F6F0ED76A514A4011548D5E0DFA40406B2DCC423B4F4A40DEAD2CD159F640406B2DCC423B4F4A40
51035	Радинская	1	2	1482	33.829025999999999	33.856271999999997	52.641548999999998	52.628076999999998	0103000020E6100000010000000500000050C422861DEA4040552FBFD364504A4050C422861DEA404008E412471E524A40813D26529AED404008E412471E524A40813D26529AED4040552FBFD364504A4050C422861DEA4040552FBFD364504A40
47210	Плюсково	1	2	1482	33.802813999999998	33.833015000000003	52.774242999999998	52.750734000000001	0103000020E61000000100000005000000AE62F19BC2E6404065FF3C0D18604A40AE62F19BC2E64040161406651A634A40EA094B3CA0EA4040161406651A634A40EA094B3CA0EA404065FF3C0D18604A40AE62F19BC2E6404065FF3C0D18604A40
49396	Острая Лука	1	2	1482	33.993237999999998	34.011268000000001	52.641390000000001	52.633111	0103000020E610000001000000050000007D923B6C22FF404072DEFFC709514A407D923B6C22FF4040A0FD481119524A40E4BED53A71014140A0FD481119524A40E4BED53A7101414072DEFFC709514A407D923B6C22FF404072DEFFC709514A40
51032	Молчаново	1	2	1482	33.691592999999997	33.705787000000001	52.680171000000001	52.667039000000003	0103000020E610000001000000050000003E92921E86D840400A14B18861554A403E92921E86D840400458E4D70F574A409278793A57DA40400458E4D70F574A409278793A57DA40400A14B18861554A403E92921E86D840400A14B18861554A40
47265	Манцурово	1	2	1482	33.973987999999999	33.99004	52.808321999999997	52.794798	0103000020E61000000100000005000000255987A3ABFC40408E76DCF0BB654A40255987A3ABFC40409351651877674A40ADDD76A1B9FE40409351651877674A40ADDD76A1B9FE40408E76DCF0BB654A40255987A3ABFC40408E76DCF0BB654A40
18140	Макарзно	1	2	1482	33.64922	33.669862999999999	52.562696000000003	52.555551000000001	0103000020E610000001000000050000005EF415A419D340404B21904B1C474A405EF415A419D3404086CB2A6C06484A4075E61E12BED5404086CB2A6C06484A4075E61E12BED540404B21904B1C474A405EF415A419D340404B21904B1C474A40
17634	Любожичи	1	2	1482	34.002608000000002	34.017789	52.728102	52.719985999999999	0103000020E610000001000000050000009F5A7D7555004140F7C95180285C4A409F5A7D75550041407B134372325D4A40419DF2E8460241407B134372325D4A40419DF2E846024140F7C95180285C4A409F5A7D7555004140F7C95180285C4A40
47474	Любец	1	2	1482	33.459181000000001	33.484765000000003	52.461840000000002	52.449080000000002	0103000020E61000000100000005000000E8F86871C6BA4040D3A414747B394A40E8F86871C6BA404009FEB7921D3B4A406B9F8EC70CBE404009FEB7921D3B4A406B9F8EC70CBE4040D3A414747B394A40E8F86871C6BA4040D3A414747B394A40
45579	Ложки	1	2	1482	33.717194999999997	33.739410999999997	52.774133999999997	52.765138	0103000020E6100000010000000500000067EDB60BCDDB4040A376BF0AF0614A4067EDB60BCDDB40405F5CAAD216634A40BDA60705A5DE40405F5CAAD216634A40BDA60705A5DE4040A376BF0AF0614A4067EDB60BCDDB4040A376BF0AF0614A40
18188	Кветунь	1	2	1482	33.619152999999997	33.639778	52.554834	52.546422999999997	0103000020E61000000100000005000000321CCF6740CF40401F645930F1454A40321CCF6740CF4040BC5AEECC04474A40A359D93EE4D14040BC5AEECC04474A40A359D93EE4D140401F645930F1454A40321CCF6740CF40401F645930F1454A40
47576	Городцы	1	2	1482	33.777642999999998	33.844082	52.601776000000001	52.576095000000002	0103000020E610000001000000050000004E7B4ACE89E34040CF31207BBD494A404E7B4ACE89E3404044C2F7FE064D4A40369204E10AEC404044C2F7FE064D4A40369204E10AEC4040CF31207BBD494A404E7B4ACE89E34040CF31207BBD494A40
51097	Голубичи	1	2	1482	33.980662000000002	33.998286999999998	52.757573999999998	52.751278999999997	0103000020E610000001000000050000000937195586FD4040F69507E929604A400937195586FD40406326512FF8604A40CF8250DEC7FF40406326512FF8604A40CF8250DEC7FF4040F69507E929604A400937195586FD4040F69507E929604A40
47169	Гнилево	1	2	1482	34.003416000000001	34.008114999999997	52.655607000000003	52.650914	0103000020E610000001000000050000003E247CEF6F0041401841632651534A403E247CEF6F004140AC0320EEEA534A40B3CD8DE909014140AC0320EEEA534A40B3CD8DE9090141401841632651534A403E247CEF6F0041401841632651534A40
18453	Глыбочка	1	2	1482	33.479151000000002	33.513026000000004	52.524220999999997	52.506968999999998	0103000020E61000000100000005000000406CE9D154BD4040FC8A355CE4404A40406CE9D154BD40402E7079AC19434A40B5FF01D6AAC140402E7079AC19434A40B5FF01D6AAC14040FC8A355CE4404A40406CE9D154BD4040FC8A355CE4404A40
19263	Бобовня	1	2	1482	33.574570000000001	33.59789	52.672117	52.652498000000001	0103000020E61000000100000005000000A1A17F828BC940404B5AF10D85534A40A1A17F828BC94040F60A0BEE07564A407F4DD6A887CC4040F60A0BEE07564A407F4DD6A887CC40404B5AF10D85534A40A1A17F828BC940404B5AF10D85534A40
51116	Белая Березка	1	2	1482	33.462783000000002	33.497996999999998	52.396242000000001	52.370714999999997	0103000020E6100000010000000500000088122D793CBB40407D91D096732F4A4088122D793CBB40409CA6CF0EB8324A40C8409E5DBEBF40409CA6CF0EB8324A40C8409E5DBEBF40407D91D096732F4A4088122D793CBB40407D91D096732F4A40
18355	Алешенка	1	2	1482	33.475935	33.512127999999997	52.48648	52.473218000000003	0103000020E61000000100000005000000C9022670EBBC404074F04C68923C4A40C9022670EBBC40403C1405FA443E4A40D5AE09698DC140403C1405FA443E4A40D5AE09698DC1404074F04C68923C4A40C9022670EBBC404074F04C68923C4A40
47736	Аладьино	1	2	1482	33.689824000000002	33.704008000000002	52.618181999999997	52.608294999999998	0103000020E610000001000000050000007AFF1F274CD8404000A94D9CDC4D4A407AFF1F274CD84040E97C7896204F4A40AA0F24EF1CDA4040E97C7896204F4A40AA0F24EF1CDA404000A94D9CDC4D4A407AFF1F274CD8404000A94D9CDC4D4A40
14985	Сураж	1	2	1345	32.354469000000002	32.425120999999997	53.033628	52.998784000000001	0103000020E6100000010000000500000011397D3D5F2D404050E27327D87F4A4011397D3D5F2D40406D1D1CEC4D844A40E1EB6B5D6A3640406D1D1CEC4D844A40E1EB6B5D6A36404050E27327D87F4A4011397D3D5F2D404050E27327D87F4A40
15951	Струженка	1	2	1345	32.497813000000001	32.522975000000002	53.237855000000003	53.226357999999998	0103000020E6100000010000000500000007431D56B83F40400F98874CF99C4A4007431D56B83F404055185B08729E4A4014D044D8F042404055185B08729E4A4014D044D8F04240400F98874CF99C4A4007431D56B83F40400F98874CF99C4A40
16750	Старая Кашовка	1	2	1345	32.34845	32.367252000000001	53.043509999999998	53.034343	0103000020E61000000100000005000000462575029A2C40405BECF65965844A40462575029A2C4040448655BC91854A40FFB1101D022F4040448655BC91854A40FFB1101D022F40405BECF65965844A40462575029A2C40405BECF65965844A40
14429	Слище	1	2	1345	32.440733999999999	32.459850000000003	53.163449	53.139719999999997	0103000020E610000001000000050000001D1EC2F8693840406E4C4F58E2914A401D1EC2F8693840402EC896E5EB944A406688635DDC3A40402EC896E5EB944A406688635DDC3A40406E4C4F58E2914A401D1EC2F8693840406E4C4F58E2914A40
51118	Селище	1	2	1345	32.348835999999999	32.366999999999997	52.93459	52.923999999999999	0103000020E610000001000000050000006FD575A8A62C404083C0CAA145764A406FD575A8A62C4040969526A5A0774A40E5D022DBF92E4040969526A5A0774A40E5D022DBF92E404083C0CAA145764A406FD575A8A62C404083C0CAA145764A40
15600	Октябрьское	1	2	1345	32.175893000000002	32.200363000000003	53.036352000000001	53.021621000000003	0103000020E61000000100000005000000344C6DA98316404013F4177AC4824A40344C6DA9831640407592AD2EA7844A400B2AAA7EA51940407592AD2EA7844A400B2AAA7EA519404013F4177AC4824A40344C6DA98316404013F4177AC4824A40
16566	Овчинец	1	2	1345	32.458179000000001	32.493662999999998	53.053654000000002	53.037657000000003	0103000020E61000000100000005000000645B069CA53A404095BBCFF1D1844A40645B069CA53A404059A65F22DE864A40641F6459303F404059A65F22DE864A40641F6459303F404095BBCFF1D1844A40645B069CA53A404095BBCFF1D1844A40
16541	Новый Дроков	1	2	1345	32.517836000000003	32.553958000000002	53.099653000000004	53.085814999999997	0103000020E610000001000000050000008258367348424040CC4065FCFB8A4A40825836734842404062F9F36DC18C4A40C5AD8218E846404062F9F36DC18C4A40C5AD8218E8464040CC4065FCFB8A4A408258367348424040CC4065FCFB8A4A40
16453	Нивное	1	2	1345	32.568106	32.595343	53.200091	53.163071000000002	0103000020E61000000100000005000000A85489B2B748404088F6B182DF944A40A85489B2B7484040AA9CF6949C994A4086730D33344C4040AA9CF6949C994A4086730D33344C404088F6B182DF944A40A85489B2B748404088F6B182DF944A40
16370	Ляличи	1	2	1345	32.515419999999999	32.571734999999997	53.020403000000002	52.988225	0103000020E6100000010000000500000027DA5548F9414040780B24287E7E4A4027DA5548F9414040C2DEC4909C824A40417DCB9C2E494040C2DEC4909C824A40417DCB9C2E494040780B24287E7E4A4027DA5548F9414040780B24287E7E4A40
16260	Лопазна	1	2	1345	32.610201000000004	32.656402	53.044066999999998	53.014211000000003	0103000020E61000000100000005000000467EFD101B4E40402A1F82AAD1814A40467EFD101B4E40409AEAC9FCA3854A40B68311FB045440409AEAC9FCA3854A40B68311FB045440402A1F82AAD1814A40467EFD101B4E40402A1F82AAD1814A40
16070	Лесной	1	2	1345	32.40437	32.416595999999998	52.969507999999998	52.958193999999999	0103000020E61000000100000005000000E4BD6A65C2334040999CDA19A67A4A40E4BD6A65C2334040ED9A90D6187C4A407CD2890453354040ED9A90D6187C4A407CD2890453354040999CDA19A67A4A40E4BD6A65C2334040999CDA19A67A4A40
15963	Кулаги	1	2	1345	32.372695999999998	32.417287999999999	52.927990000000001	52.892206999999999	0103000020E61000000100000005000000CDACA580B42F40409221C7D633724A40CDACA580B42F4040ED815660C8764A40B28174B169354040ED815660C8764A40B28174B1693540409221C7D633724A40CDACA580B42F40409221C7D633724A40
16138	Красный Завод	1	2	1345	32.424852000000001	32.439458000000002	53.007091000000003	52.998100999999998	0103000020E61000000100000005000000F2D1E28C613640406D8D08C6C17F4A40F2D1E28C61364040488C9E5BE8804A4098FBE42840384040488C9E5BE8804A4098FBE428403840406D8D08C6C17F4A40F2D1E28C613640406D8D08C6C17F4A40
15473	Красная Слобода	1	2	1345	32.348567000000003	32.374789	53.015667999999998	52.996248000000001	0103000020E6100000010000000500000080BBECD79D2C40404B5AF10D857F4A4080BBECD79D2C4040FFCBB56801824A4045F30016F92F4040FFCBB56801824A4045F30016F92F40404B5AF10D857F4A4080BBECD79D2C40404B5AF10D857F4A40
16350	Костеничи	1	2	1345	32.657128999999998	32.699196999999998	53.070056999999998	53.046872	0103000020E61000000100000005000000682096CD1C5440408F8CD5E6FF854A40682096CD1C5440408DEDB5A0F7884A400C3B8C497F5940408DEDB5A0F7884A400C3B8C497F5940408F8CD5E6FF854A40682096CD1C5440408F8CD5E6FF854A40
16155	Каменск	1	2	1345	32.456437000000001	32.474609999999998	52.993803	52.984999999999999	0103000020E6100000010000000500000099D711876C3A4040AE47E17A147E4A4099D711876C3A404056D5CBEF347F4A40622D3E05C03C404056D5CBEF347F4A40622D3E05C03C4040AE47E17A147E4A4099D711876C3A4040AE47E17A147E4A40
16652	Калинки	1	2	1345	32.389018	32.425390999999998	53.042476000000001	53.028446000000002	0103000020E6100000010000000500000015C78157CB314040DCD9571EA4834A4015C78157CB314040B56E83DA6F854A40A181583673364040B56E83DA6F854A40A181583673364040DCD9571EA4834A4015C78157CB314040DCD9571EA4834A40
16038	Жемердеевка	1	2	1345	32.302788999999997	32.328391000000003	52.923017000000002	52.906509	0103000020E61000000100000005000000554B3ACAC1264040CC43A67C08744A40554B3ACAC12640407653CA6B25764A407FA65EB7082A40407653CA6B25764A407FA65EB7082A4040CC43A67C08744A40554B3ACAC1264040CC43A67C08744A40
15679	Жастково	1	2	1345	32.574852999999997	32.609042000000002	53.280042999999999	53.268557999999999	0103000020E61000000100000005000000F58079C894494040228AC91B60A24A40F58079C894494040A33CF372D8A34A40FAF19716F54D4040A33CF372D8A34A40FAF19716F54D4040228AC91B60A24A40F58079C894494040228AC91B60A24A40
51049	Душатино	1	2	1345	32.261555999999999	32.286636999999999	53.078415	53.057946000000001	0103000020E610000001000000050000004A09C1AA7A2140408E7747C66A874A404A09C1AA7A2140400742B280098A4A406A696E85B02440400742B280098A4A406A696E85B02440408E7747C66A874A404A09C1AA7A2140408E7747C66A874A40
15850	Дубровка	1	2	1345	32.442315000000001	32.466183000000001	53.097496	53.083835000000001	0103000020E61000000100000005000000DFC325C79D3840404DA1F31ABB8A4A40DFC325C79D384040D3BEB9BF7A8C4A40C07971E2AB3B4040D3BEB9BF7A8C4A40C07971E2AB3B40404DA1F31ABB8A4A40DFC325C79D3840404DA1F31ABB8A4A40
15667	Дегтяревка	1	2	1345	32.632371999999997	32.669535000000003	53.262003	53.250712	0103000020E61000000100000005000000FB73D190F15040407D5BB05417A04A40FB73D190F1504040193A765089A14A408143A852B3554040193A765089A14A408143A852B35540407D5BB05417A04A40FB73D190F15040407D5BB05417A04A40
15874	Далисичи	1	2	1345	32.370800000000003	32.392611000000002	53.150809000000002	53.134096999999997	0103000020E61000000100000005000000ACADD85F762F4040F0BE2A172A914A40ACADD85F762F4040A37895B54D934A406286C61341324040A37895B54D934A406286C61341324040F0BE2A172A914A40ACADD85F762F4040F0BE2A172A914A40
16856	Гудовка	1	2	1345	32.197370999999997	32.220018000000003	53.075234000000002	53.060105999999998	0103000020E61000000100000005000000E316F373431940408D25AC8DB1874A40E316F373431940400DC68844A1894A400344C18C291C40400DC68844A1894A400344C18C291C40408D25AC8DB1874A40E316F373431940408D25AC8DB1874A40
16229	Глуховка	1	2	1345	32.521051999999997	32.546044000000002	52.950310999999999	52.933422999999998	0103000020E61000000100000005000000F8C1F9D4B1424040C72AA5677A774A40F8C1F9D4B1424040B80375CAA3794A40A91611C5E4454040B80375CAA3794A40A91611C5E4454040C72AA5677A774A40F8C1F9D4B1424040C72AA5677A774A40
15758	Вьюково	1	2	1345	32.667541	32.689450999999998	53.295583999999998	53.284103000000002	0103000020E610000001000000050000009CDEC5FB7155404006D9B27C5DA44A409CDEC5FB71554040459C4EB2D5A54A40E5982CEE3F584040459C4EB2D5A54A40E5982CEE3F58404006D9B27C5DA44A409CDEC5FB7155404006D9B27C5DA44A40
16471	Высокоселище	1	2	1345	32.526811000000002	32.550418000000001	53.139726000000003	53.121398999999997	0103000020E610000001000000050000002716F88A6E43404030629F008A8F4A402716F88A6E4340405133A48AE2914A409B90D618744640405133A48AE2914A409B90D6187446404030629F008A8F4A402716F88A6E43404030629F008A8F4A40
15427	Влазовичи	1	2	1345	32.264197000000003	32.310423999999998	53.026864000000003	53.001888999999998	0103000020E61000000100000005000000C5591135D12140406F9C14E63D804A40C5591135D12140404AB8904770834A405EF23FF9BB2740404AB8904770834A405EF23FF9BB2740406F9C14E63D804A40C5591135D12140406F9C14E63D804A40
51089	Владимировка	1	2	1345	32.739666	32.751945999999997	53.261518000000002	53.257010000000001	0103000020E6100000010000000500000048FB1F60AD5E40405B5F24B4E5A04A4048FB1F60AD5E40405DA8FC6B79A14A40D32D3BC43F6040405DA8FC6B79A14A40D32D3BC43F6040405B5F24B4E5A04A4048FB1F60AD5E40405B5F24B4E5A04A40
31812	Беловодка	1	2	1345	32.364207	32.384149000000001	52.966970000000003	52.95852	0103000020E61000000100000005000000B5FCC0559E2E4040ED478AC8B07A4A40B5FCC0559E2E4040481B47ACC57B4A4043E55FCB2B314040481B47ACC57B4A4043E55FCB2B314040ED478AC8B07A4A40B5FCC0559E2E4040ED478AC8B07A4A40
15502	Андреевка	1	2	1345	32.219909999999999	32.236303999999997	53.009307	52.996724	0103000020E610000001000000050000001C08C902261C4040B491EBA6947F4A401C08C902261C4040DB4FC6F830814A40FDF49F353F1E4040DB4FC6F830814A40FDF49F353F1E4040B491EBA6947F4A401C08C902261C4040B491EBA6947F4A40
14794	Ямное	1	2	1308	33.909246000000003	33.927742000000002	52.412340999999998	52.400111000000003	0103000020E610000001000000050000006902452C62F440408BE255D636334A406902452C62F4404064E60297C7344A401590F63FC0F6404064E60297C7344A401590F63FC0F640408BE255D636334A406902452C62F440408BE255D636334A40
14521	Щепетлево	1	2	1308	34.186143000000001	34.210514000000003	52.261011000000003	52.238731000000001	0103000020E610000001000000050000008EB0A888D31741404CC5C6BC8E1E4A408EB0A888D3174140B972F6CE68214A40D2AC6C1FF21A4140B972F6CE68214A40D2AC6C1FF21A41404CC5C6BC8E1E4A408EB0A888D31741404CC5C6BC8E1E4A40
14886	Холмечи	1	2	1308	34.198233999999999	34.218544999999999	52.514642000000002	52.492517999999997	0103000020E61000000100000005000000467A51BB5F1941407D586FD40A3F4A40467A51BB5F194140F392FFC9DF414A4027DA5548F91B4140F392FFC9DF414A4027DA5548F91B41407D586FD40A3F4A40467A51BB5F1941407D586FD40A3F4A40
13774	Суземка	1	2	1308	34.013379	34.134039999999999	52.342883999999998	52.294412999999999	0103000020E6100000010000000500000002BA2F67B601414035423F53AF254A4002BA2F67B60141402C29779FE32B4A408C2D0439281141402C29779FE32B4A408C2D04392811414035423F53AF254A4002BA2F67B601414035423F53AF254A40
14453	Страчово	1	2	1308	34.127932000000001	34.159382000000001	52.159095000000001	52.136642000000002	0103000020E61000000100000005000000520E66136010414049A12C7C7D114A40520E66136010414083FA96395D144A4019C91EA16614414083FA96395D144A4019C91EA16614414049A12C7C7D114A40520E66136010414049A12C7C7D114A40
14655	Семеновск	1	2	1308	34.369902000000003	34.403911999999998	52.305906999999998	52.289372999999998	0103000020E61000000100000005000000CD5CE0F2582F414036ACA92C0A254A40CD5CE0F2582F4140094FE8F527274A40213B6F63B3334140094FE8F527274A40213B6F63B333414036ACA92C0A254A40CD5CE0F2582F414036ACA92C0A254A40
51063	Селичня	1	2	1308	34.345297000000002	34.389916999999997	52.400083000000002	52.370407	0103000020E6100000010000000500000016342DB1322C4140D09A1F7F692F4A4016342DB1322C4140C15774EB35334A40C493DDCCE8314140C15774EB35334A40C493DDCCE8314140D09A1F7F692F4A4016342DB1322C4140D09A1F7F692F4A40
14341	Полевые Новоселки	1	2	1308	34.175182999999997	34.207334000000003	52.197172999999999	52.180466000000003	0103000020E6100000010000000500000057E883656C1641401D05888219174A4057E883656C164140BD5301F73C194A40A8ACA6EB891A4140BD5301F73C194A40A8ACA6EB891A41401D05888219174A4057E883656C1641401D05888219174A40
14329	Павловичи	1	2	1308	34.204881999999998	34.223899000000003	52.211621999999998	52.196007999999999	0103000020E6100000010000000500000000C5C892391A41408FE046CA16194A4000C5C892391A41409B8E006E161B4A40B64DF1B8A81C41409B8E006E161B4A40B64DF1B8A81C41408FE046CA16194A4000C5C892391A41408FE046CA16194A40
14752	Новенькое	1	2	1308	33.820286000000003	33.832332000000001	52.395142999999997	52.383656000000002	0103000020E61000000100000005000000EFAEB321FFE840400475CAA31B314A40EFAEB321FFE84040251FBB0B94324A4007B5DFDA89EA4040251FBB0B94324A4007B5DFDA89EA40400475CAA31B314A40EFAEB321FFE840400475CAA31B314A40
14686	Новая Погощь	1	2	1308	33.887039999999999	33.911824000000003	52.344216000000003	52.323210000000003	0103000020E61000000100000005000000361FD7868AF14040BEDEFDF15E294A40361FD7868AF14040466117450F2C4A409DDA19A6B6F44040466117450F2C4A409DDA19A6B6F44040BEDEFDF15E294A40361FD7868AF14040BEDEFDF15E294A40
14137	Нерусса	1	2	1308	34.113253	34.133501000000003	52.388432999999999	52.383167	0103000020E61000000100000005000000429605137F0E414006F4C29D0B314A40429605137F0E4140F5D72B2CB8314A40DD7D8E8F16114140F5D72B2CB8314A40DD7D8E8F1611414006F4C29D0B314A40429605137F0E414006F4C29D0B314A40
14603	Негино	1	2	1308	34.179001	34.251683999999997	52.326832000000003	52.302453999999997	0103000020E61000000100000005000000C4793881E9164140AE450BD0B6264A40C4793881E9164140A5A487A1D5294A4096766A2E37204140A5A487A1D5294A4096766A2E37204140AE450BD0B6264A40C4793881E9164140AE450BD0B6264A40
14541	Невдольск	1	2	1308	34.264853000000002	34.301585000000003	52.315095999999997	52.289614999999998	0103000020E61000000100000005000000AE9FFEB3E62141402CB7B41A12254A40AE9FFEB3E6214140DA8CD31055284A406AFB57569A264140DA8CD31055284A406AFB57569A2641402CB7B41A12254A40AE9FFEB3E62141402CB7B41A12254A40
51087	Красная Слобода	1	2	1308	34.002374000000003	34.042977999999998	52.457801000000003	52.444842999999999	0103000020E610000001000000050000002C2E8ECA4D004140616D8C9DF0384A402C2E8ECA4D004140BE892139993A4A404739984D80054140BE892139993A4A404739984D80054140616D8C9DF0384A402C2E8ECA4D004140616D8C9DF0384A40
14176	Кокоревка	1	2	1308	34.243428000000002	34.307702999999997	52.604669999999999	52.578043000000001	0103000020E61000000100000005000000217711A6281F414043572250FD494A40217711A6281F4140A86F99D3654D4A40C7F0D8CF62274140A86F99D3654D4A40C7F0D8CF6227414043572250FD494A40217711A6281F414043572250FD494A40
14278	Зерново	1	2	1308	34.056103	34.104899000000003	52.204827999999999	52.185898999999999	0103000020E610000001000000050000008F1A13622E074140F7ADD689CB174A408F1A13622E0741400DA7CCCD371A4A400A3197546D0D41400DA7CCCD371A4A400A3197546D0D4140F7ADD689CB174A408F1A13622E074140F7ADD689CB174A40
14051	Денисовка	1	2	1308	34.013091000000003	34.064070999999998	52.416603000000002	52.396450999999999	0103000020E610000001000000050000009C6F44F7AC014140B6BB07E8BE324A409C6F44F7AC0141402F35423F53354A409ECF807A330841402F35423F53354A409ECF807A33084140B6BB07E8BE324A409C6F44F7AC014140B6BB07E8BE324A40
13991	Горожанка	1	2	1308	33.960351000000003	33.987408000000002	52.309711	52.293686000000001	0103000020E6100000010000000500000028D714C8ECFA404083A5BA8097254A4028D714C8ECFA4040111B2C9CA4274A4086E7A56263FE4040111B2C9CA4274A4086E7A56263FE404083A5BA8097254A4028D714C8ECFA404083A5BA8097254A40
14214	Алешковичи	1	2	1308	34.148845000000001	34.193885999999999	52.238895999999997	52.219754999999999	0103000020E6100000010000000500000029965B5A0D134140F5108DEE201C4A4029965B5A0D1341409692E524941E4A407D93A641D11841409692E524941E4A407D93A641D1184140F5108DEE201C4A4029965B5A0D134140F5108DEE201C4A40
13083	Шкрябино	1	2	1182	32.646690999999997	32.677629000000003	52.597926000000001	52.582788000000001	0103000020E610000001000000050000000BCF4BC5C6524040294014CC984A4A400BCF4BC5C6524040CCB6D3D6884C4A401DE90C8CBC564040CCB6D3D6884C4A401DE90C8CBC564040294014CC984A4A400BCF4BC5C6524040294014CC984A4A40
12399	Чубковичи	1	2	1182	32.586655999999998	32.630243	52.548563999999999	52.516922000000001	0103000020E610000001000000050000004700378B174B40409D4A06802A424A404700378B174B4040A8E15B5837464A4037C478CDAB504040A8E15B5837464A4037C478CDAB5040409D4A06802A424A404700378B174B40409D4A06802A424A40
12828	Тарасовка	1	2	1182	32.941913	32.991204000000003	52.462426999999998	52.447493999999999	0103000020E61000000100000005000000B056ED9A90784040FF93BF7B47394A40B056ED9A90784040C9E4D4CE303B4A400BD5CDC5DF7E4040C9E4D4CE303B4A400BD5CDC5DF7E4040FF93BF7B47394A40B056ED9A90784040FF93BF7B47394A40
12053	Стародуб	1	2	1182	32.718915000000003	32.802709999999998	52.613380999999997	52.556705999999998	0103000020E610000001000000050000004BCD1E68055C404055BE672442474A404BCD1E68055C40406F7EC344834E4A4009168733BF6640406F7EC344834E4A4009168733BF66404055BE672442474A404BCD1E68055C404055BE672442474A40
11528	Солова	1	2	1182	32.614055	32.652259999999998	52.430079999999997	52.408880000000003	0103000020E61000000100000005000000FF78AF5A994E404087FE092E56344A40FF78AF5A994E4040F35487DC0C374A40963E74417D534040F35487DC0C374A40963E74417D53404087FE092E56344A40FF78AF5A994E404087FE092E56344A40
12918	Случок	1	2	1182	32.937341000000004	32.967703999999998	52.526183000000003	52.511128999999997	0103000020E61000000100000005000000981936CAFA774040C284D1AC6C414A40981936CAFA774040085BECF659434A40AC1A84B9DD7B4040085BECF659434A40AC1A84B9DD7B4040C284D1AC6C414A40981936CAFA774040C284D1AC6C414A40
13204	Пятовск	1	2	1182	32.688858000000003	32.728411000000001	52.676054000000001	52.647433999999997	0103000020E6100000010000000500000043CBBA7F2C584040C328081EDF524A4043CBBA7F2C5840403D2AFEEF88564A40F98557923C5D40403D2AFEEF88564A40F98557923C5D4040C328081EDF524A4043CBBA7F2C584040C328081EDF524A40
51144	Пролетарское	1	2	1182	32.974504000000003	32.992775999999999	52.611094999999999	52.595098	0103000020E610000001000000050000001DE90C8CBC7C40401FF5D72B2C4C4A401DE90C8CBC7C4040E3DF675C384E4A407920B248137F4040E3DF675C384E4A407920B248137F40401FF5D72B2C4C4A401DE90C8CBC7C40401FF5D72B2C4C4A40
13291	Понуровка	1	2	1182	32.818618999999998	32.859276999999999	52.382376000000001	52.347814	0103000020E610000001000000050000002E71E481C8684040A48B4D2B852C4A402E71E481C86840403D635FB2F1304A403D9AEAC9FC6D40403D635FB2F1304A403D9AEAC9FC6D4040A48B4D2B852C4A402E71E481C8684040A48B4D2B852C4A40
11708	Пестриково	1	2	1182	33.045623999999997	33.077827999999997	52.675638999999997	52.663018999999998	0103000020E61000000100000005000000D3F4D901D785404035D07CCEDD544A40D3F4D901D78540407973B8567B564A40465B9544F68940407973B8567B564A40465B9544F689404035D07CCEDD544A40D3F4D901D785404035D07CCEDD544A40
51080	Пантусово	1	2	1182	32.781239999999997	32.801318000000002	52.642406999999999	52.623517999999997	0103000020E61000000100000005000000DC291DACFF634040D13B1570CF4F4A40DC291DACFF63404059DC7F643A524A401BD995969166404059DC7F643A524A401BD9959691664040D13B1570CF4F4A40DC291DACFF634040D13B1570CF4F4A40
13043	Остроглядово	1	2	1182	32.694561999999998	32.727288000000001	52.623693000000003	52.602679000000002	0103000020E61000000100000005000000AD855968E7584040357EE195244D4A40AD855968E758404040DF162CD54F4A40FA62EFC5175D404040DF162CD54F4A40FA62EFC5175D4040357EE195244D4A40AD855968E7584040357EE195244D4A40
49164	Осколково	1	2	1182	32.752099000000001	32.771323000000002	52.668590000000002	52.652524999999997	0103000020E610000001000000050000005A2DB0C74460404044696FF085534A405A2DB0C74460404061376C5B94554A4089D349B6BA62404061376C5B94554A4089D349B6BA62404044696FF085534A405A2DB0C74460404044696FF085534A40
13217	Новополье	1	2	1182	32.737385000000003	32.746259999999999	52.682474999999997	52.677621000000002	0103000020E61000000100000005000000CEC7B5A1625E40409A0AF148BC564A40CEC7B5A1625E404036AB3E575B574A400F289B72855F404036AB3E575B574A400F289B72855F40409A0AF148BC564A40CEC7B5A1625E40409A0AF148BC564A40
12233	Новомлынка	1	2	1182	32.739649	32.764702999999997	52.452834000000003	52.435251999999998	0103000020E6100000010000000500000072C284D1AC5E404061C26856B6374A4072C284D1AC5E40402942EA76F6394A409813B4C9E16140402942EA76F6394A409813B4C9E161404061C26856B6374A4072C284D1AC5E404061C26856B6374A40
51149	Новое Село	1	2	1182	32.793377	32.825347999999998	52.703144999999999	52.686459999999997	0103000020E610000001000000050000000533A6608D6540408E01D9EBDD574A400533A6608D65404047ACC5A7005A4A40D5E8D500A569404047ACC5A7005A4A40D5E8D500A56940408E01D9EBDD574A400533A6608D6540408E01D9EBDD574A40
51041	Нижнее	1	2	1182	32.496223000000001	32.533934000000002	52.553865000000002	52.510899000000002	0103000020E61000000100000005000000F2423A3C843F40409147702365414A40F2423A3C843F404014B35E0CE5464A407A1C06F35744404014B35E0CE5464A407A1C06F3574440409147702365414A40F2423A3C843F40409147702365414A40
12940	Мохоновка	1	2	1182	32.636181000000001	32.654515000000004	52.641969000000003	52.622554999999998	0103000020E6100000010000000500000015AB06616E5140400B7BDAE1AF4F4A4015AB06616E514040DE054A0A2C524A40E8DEC325C7534040DE054A0A2C524A40E8DEC325C75340400B7BDAE1AF4F4A4015AB06616E5140400B7BDAE1AF4F4A40
12802	Мишковка	1	2	1182	32.899396000000003	32.935561999999997	52.505285999999998	52.474359	0103000020E610000001000000050000009D137B681F73404019C8B3CBB73C4A409D137B681F73404036902E36AD404A40AFB0E07EC077404036902E36AD404A40AFB0E07EC077404019C8B3CBB73C4A409D137B681F73404019C8B3CBB73C4A40
51064	Михайловск	1	2	1182	32.410693999999999	33.188994999999998	52.777096999999998	52.244332999999997	0103000020E61000000100000005000000EB54F99E91344040B22AC24D461F4A40EB54F99E91344040EC681CEA77634A40C30DF8FC30984040EC681CEA77634A40C30DF8FC30984040B22AC24D461F4A40EB54F99E91344040B22AC24D461F4A40
51120	Мереневка	1	2	1182	32.810614999999999	32.852234000000003	52.576028999999998	52.563187999999997	0103000020E61000000100000005000000D252793BC2674040F4BF5C8B16484A40D252793BC267404017467A51BB494A400745F300166D404017467A51BB494A400745F300166D4040F4BF5C8B16484A40D252793BC2674040F4BF5C8B16484A40
12668	Меленск	1	2	1182	32.922195000000002	32.936433000000001	52.639150000000001	52.627262000000002	0103000020E6100000010000000500000072C45A7C0A7640400403081F4A504A4072C45A7C0A764040849ECDAACF514A4095F25A09DD774040849ECDAACF514A4095F25A09DD7740400403081F4A504A4072C45A7C0A7640400403081F4A504A40
12763	Меженики	1	2	1182	32.767415	32.791921000000002	52.709713999999998	52.692425999999998	0103000020E61000000100000005000000DCBA9BA73A6240403673486AA1584A40DCBA9BA73A624040B5C189E8D75A4A400002D6AA5D654040B5C189E8D75A4A400002D6AA5D6540403673486AA1584A40DCBA9BA73A6240403673486AA1584A40
11318	Лужки	1	2	1182	32.541139000000001	32.605674	52.369020999999996	52.348914000000001	0103000020E610000001000000050000008ACBF10A44454040EB8EC536A92C4A408ACBF10A44454040C34483143C2F4A40CD04C3B9864D4040C34483143C2F4A40CD04C3B9864D4040EB8EC536A92C4A408ACBF10A44454040EB8EC536A92C4A40
11434	Ломаковка	1	2	1182	32.630493999999999	32.680548000000002	52.311439999999997	52.293587000000002	0103000020E6100000010000000500000080290307B4504040F0C3414294254A4080290307B450404047551344DD274A40DAAD65321C57404047551344DD274A40DAAD65321C574040F0C3414294254A4080290307B4504040F0C3414294254A40
12504	Логоватое	1	2	1182	32.555807999999999	32.597121999999999	52.602339999999998	52.588132999999999	0103000020E61000000100000005000000766D6FB724474040645930F1474B4A40766D6FB7244740404C89247A194D4A406EDC627E6E4C40404C89247A194D4A406EDC627E6E4C4040645930F1474B4A40766D6FB724474040645930F1474B4A40
51088	Левенки	1	2	1182	32.861209000000002	32.906097000000003	52.589528000000001	52.577578000000003	0103000020E61000000100000005000000AC02B5183C6E4040CE716E13EE494A40AC02B5183C6E4040C4094CA7754B4A407A008BFCFA734040C4094CA7754B4A407A008BFCFA734040CE716E13EE494A40AC02B5183C6E4040CE716E13EE494A40
13422	Курковичи	1	2	1182	32.785255999999997	32.827233999999997	52.309672999999997	52.285021	0103000020E610000001000000050000006F7EC344836440402CD670917B244A406F7EC3448364404023BA675DA3274A40D311C0CDE269404023BA675DA3274A40D311C0CDE26940402CD670917B244A406F7EC344836440402CD670917B244A40
12466	Крюков	1	2	1182	32.592046000000003	32.624519999999997	52.589002999999998	52.569248000000002	0103000020E6100000010000000500000023DDCF29C84B40401EA8531EDD484A4023DDCF29C84B4040791F4773644B4A4055D97745F04F4040791F4773644B4A4055D97745F04F40401EA8531EDD484A4023DDCF29C84B40401EA8531EDD484A40
11430	Крутая Буда	1	2	1182	32.712671999999998	32.743169999999999	52.339120999999999	52.326915	0103000020E6100000010000000500000030630AD6385B404032C9C859D8294A4030630AD6385B404083312251682B4A4025AFCE31205F404083312251682B4A4025AFCE31205F404032C9C859D8294A4030630AD6385B404032C9C859D8294A40
12147	Красный	1	2	1182	32.736316000000002	32.759006999999997	52.536613000000003	52.528691999999999	0103000020E61000000100000005000000C2C2499A3F5E404013D4F02DAC434A40C2C2499A3F5E4040E2CD1ABCAF444A40B037312427614040E2CD1ABCAF444A40B03731242761404013D4F02DAC434A40C2C2499A3F5E404013D4F02DAC434A40
11723	Ковалево	1	2	1182	33.124316	33.147824999999997	52.704421000000004	52.692383	0103000020E610000001000000050000004D2F3196E98F404037A79201A0584A404D2F3196E98F4040CDCEA2772A5A4A40FE43FAEDEB924040CDCEA2772A5A4A40FE43FAEDEB92404037A79201A0584A404D2F3196E98F404037A79201A0584A40
51151	Картушино	1	2	1182	32.776138000000003	32.813625000000002	52.503487999999997	52.477733000000001	0103000020E6100000010000000500000068976F7D58634040289CDD5A263D4A4068976F7D58634040D7F6764B72404A40A01A2FDD24684040D7F6764B72404A40A01A2FDD24684040289CDD5A263D4A4068976F7D58634040289CDD5A263D4A40
12394	Камень	1	2	1182	32.629111000000002	32.661512999999999	52.556055000000001	52.530543999999999	0103000020E61000000100000005000000E54691B586504040658BA4DDE8434A40E54691B5865040407EE36BCF2C474A407E703E75AC5440407EE36BCF2C474A407E703E75AC544040658BA4DDE8434A40E54691B586504040658BA4DDE8434A40
11617	Ильбово	1	2	1182	32.983649	33.006197	52.707962999999999	52.697141999999999	0103000020E610000001000000050000001EDFDE35E87D40408255F5F23B594A401EDFDE35E87D404097E315889E5A4A40AA2A3410CB80404097E315889E5A4A40AA2A3410CB8040408255F5F23B594A401EDFDE35E87D40408255F5F23B594A40
12279	Запольские Халеевичи	1	2	1182	32.504666999999998	32.531571999999997	52.673192999999998	52.652535999999998	0103000020E610000001000000050000006A2FA2ED9840404038BBB54C86534A406A2FA2ED98404040B4722F302B564A4012BC218D0A444040B4722F302B564A4012BC218D0A44404038BBB54C86534A406A2FA2ED9840404038BBB54C86534A40
11509	Елионка	1	2	1182	32.583261	32.613804000000002	52.447505	52.419519999999999	0103000020E610000001000000050000002104E44BA84A40404B02D4D4B2354A402104E44BA84A4040F3E505D847394A40B6132521914E4040F3E505D847394A40B6132521914E40404B02D4D4B2354A402104E44BA84A40404B02D4D4B2354A40
12887	Дохновичи	1	2	1182	32.854705000000003	32.905504000000001	52.525798999999999	52.508822000000002	0103000020E61000000100000005000000255D33F9666D40401FBE4C1421414A40255D33F9666D40407FA2B2614D434A40D732198EE77340407FA2B2614D434A40D732198EE77340401FBE4C1421414A40255D33F9666D40401FBE4C1421414A40
11891	Десятуха	1	2	1182	32.829588000000001	32.865997	52.603237	52.579903999999999	0103000020E61000000100000005000000B89388F02F6A4040E868554B3A4A4A40B89388F02F6A40405B5EB9DE364D4A4091B75CFDD86E40405B5EB9DE364D4A4091B75CFDD86E4040E868554B3A4A4A40B89388F02F6A4040E868554B3A4A4A40
13359	Демьянки	1	2	1182	32.855584999999998	32.897050999999998	52.344144	52.318311000000001	0103000020E610000001000000050000005DF92CCF836D4040817A336ABE284A405DF92CCF836D4040AC8E1CE90C2C4A400BEC3191D2724040AC8E1CE90C2C4A400BEC3191D2724040817A336ABE284A405DF92CCF836D4040817A336ABE284A40
13007	Дареевичи	1	2	1182	32.576227000000003	32.602215000000001	52.643127999999997	52.621735000000001	0103000020E610000001000000050000003E096CCEC1494040A8E33103954F4A403E096CCEC14940402992AF0452524A4090149161154D40402992AF0452524A4090149161154D4040A8E33103954F4A403E096CCEC1494040A8E33103954F4A40
11603	Гарцево	1	2	1182	32.983792999999999	33.004589000000003	52.751415999999999	52.733381000000001	0103000020E610000001000000050000005184D4EDEC7D4040FF40B96DDF5D4A405184D4EDEC7D404077D844662E604A40EF75525F9680404077D844662E604A40EF75525F96804040FF40B96DDF5D4A405184D4EDEC7D4040FF40B96DDF5D4A40
11258	Воронок	1	2	1182	32.63212	32.69361	52.374316	52.353276000000001	0103000020E61000000100000005000000E292E34EE9504040193BE125382D4A40E292E34EE95040404D2F3196E92F4A40DB166536C85840404D2F3196E92F4A40DB166536C8584040193BE125382D4A40E292E34EE9504040193BE125382D4A40
11354	Алейниково	1	2	1182	32.653984999999999	32.692433000000001	52.334377000000003	52.322544000000001	0103000020E610000001000000050000008B89CDC7B5534040B1C22D1F49294A408B89CDC7B55340406EC493DDCC2A4A40E9D500A5A15840406EC493DDCC2A4A40E9D500A5A1584040B1C22D1F49294A408B89CDC7B5534040B1C22D1F49294A40
13332	Азаровка	1	2	1182	32.860022999999998	32.896566	52.321460000000002	52.288271000000002	0103000020E610000001000000050000006667D13B156E40404FB16A10E6244A406667D13B156E4040707CED9925294A404F5AB8ACC2724040707CED9925294A404F5AB8ACC27240404FB16A10E6244A406667D13B156E40404FB16A10E6244A40
10233	Шведчики	1	2	1072	34.556527000000003	34.593429999999998	52.237810000000003	52.217697000000001	0103000020E61000000100000005000000A62BD8463C474140FAB7CB7EDD1B4A40A62BD8463C474140B554DE8E701E4A408E3BA583F54B4140B554DE8E701E4A408E3BA583F54B4140FAB7CB7EDD1B4A40A62BD8463C474140FAB7CB7EDD1B4A40
10012	Чемлыж	1	2	1072	34.406365000000001	34.427160999999998	52.260824	52.235846000000002	0103000020E61000000100000005000000999EB0C4033441403B72A433301E4A40999EB0C40334414086014BAE62214A4036902E36AD36414086014BAE62214A4036902E36AD3641403B72A433301E4A40999EB0C4033441403B72A433301E4A40
9711	Хинель	1	2	1072	34.199832999999998	34.231282999999998	51.986204999999998	51.9666	0103000020E61000000100000005000000AED4B3209419414024287E8CB9FB4940AED4B320941941406A1327F73BFE4940758F6CAE9A1D41406A1327F73BFE4940758F6CAE9A1D414024287E8CB9FB4940AED4B3209419414024287E8CB9FB4940
51125	Треобортное	1	2	1072	34.377682	34.397461999999997	51.898425000000003	51.884200999999997	0103000020E61000000100000005000000D9243FE257304140950B957F2DF14940D9243FE25730414054742497FFF249408DB3E908E032414054742497FFF249408DB3E908E0324140950B957F2DF14940D9243FE257304140950B957F2DF14940
51108	Сенное	1	2	1072	34.570658000000002	34.602457999999999	52.099961	52.087218999999997	0103000020E61000000100000005000000B39943520B4941407F4B00FE290B4A40B39943520B4941400FF0A485CB0C4A40569BFF571D4D41400FF0A485CB0C4A40569BFF571D4D41407F4B00FE290B4A40B39943520B4941407F4B00FE290B4A40
10705	Севск	1	2	1072	34.470162999999999	34.507353000000002	52.173865999999997	52.104675	0103000020E6100000010000000500000006651A4D2E3C4140BADA8AFD650D4A4006651A4D2E3C414073F1B73D41164A4085436FF1F040414073F1B73D41164A4085436FF1F0404140BADA8AFD650D4A4006651A4D2E3C4140BADA8AFD650D4A40
48412	Рабочий	1	2	1072	34.217117000000002	34.240482	51.999153999999997	51.989772000000002	0103000020E61000000100000005000000EC33677DCA1B41408E3F51D9B0FE4940EC33677DCA1B414073D53C47E4FF49406AA33A1DC81E414073D53C47E4FF49406AA33A1DC81E41408E3F51D9B0FE4940EC33677DCA1B41408E3F51D9B0FE4940
9840	Поздняшовка	1	2	1072	34.352393999999997	34.379496000000003	51.987924999999997	51.970999999999997	0103000020E610000001000000050000003FA7203F1B2D41403F355EBA49FC49403FA7203F1B2D41404DF38E5374FE49403E7B2E53933041404DF38E5374FE49403E7B2E53933041403F355EBA49FC49403FA7203F1B2D41403F355EBA49FC4940
9503	Подывотье	1	2	1072	34.115724	34.165329	52.067242999999998	52.043945000000001	0103000020E6100000010000000500000060AE450BD00E41404FE960FD9F054A4060AE450BD00E414045F12A6B9B084A404A0A2C802915414045F12A6B9B084A404A0A2C80291541404FE960FD9F054A4060AE450BD00E41404FE960FD9F054A40
9567	Подлесные Новоселки	1	2	1072	34.224635999999997	34.255887999999999	52.097006999999998	52.074561000000003	0103000020E610000001000000050000008BC058DFC01C41404E4700378B094A408BC058DFC01C4140D53DB2B96A0C4A402CB81FF0C0204140D53DB2B96A0C4A402CB81FF0C02041404E4700378B094A408BC058DFC01C41404E4700378B094A40
10575	Погребы	1	2	1072	34.579928000000002	34.593628000000002	52.068162000000001	52.051805000000002	0103000020E610000001000000050000007104A9143B4A41407862D68BA1064A407104A9143B4A41403C6A4C88B9084A40B5FE9600FC4B41403C6A4C88B9084A40B5FE9600FC4B41407862D68BA1064A407104A9143B4A41407862D68BA1064A40
47727	Первомайское	1	2	1072	34.323225999999998	34.356777999999998	52.105111999999998	52.087119000000001	0103000020E61000000100000005000000C39B35785F2941401CEE23B7260B4A40C39B35785F29414065355D4F740D4A4055F7C8E6AA2D414065355D4F740D4A4055F7C8E6AA2D41401CEE23B7260B4A40C39B35785F2941401CEE23B7260B4A40
47495	Первомайский	1	2	1072	34.310901000000001	34.321114999999999	52.110643000000003	52.103098000000003	0103000020E6100000010000000500000098A59D9ACB2741403A24B550320D4A4098A59D9ACB2741400344C18C290E4A40A5A0DB4B1A2941400344C18C290E4A40A5A0DB4B1A2941403A24B550320D4A4098A59D9ACB2741403A24B550320D4A40
48583	Новоямское	1	2	1072	34.45234	34.511170999999997	52.236944000000001	52.199745	0103000020E610000001000000050000001956F146E63941400F45813E91194A401956F146E6394140E17D552E541E4A40F1D4230D6E414140E17D552E541E4A40F1D4230D6E4141400F45813E91194A401956F146E63941400F45813E91194A40
10370	Некислица	1	2	1072	34.359679	34.376010999999998	51.879848000000003	51.858477000000001	0103000020E610000001000000050000006C0723F6092E414021AF0793E2ED49406C0723F6092E4140BBB9F8DB9EF04940D7F7E12021304140BBB9F8DB9EF04940D7F7E1202130414021AF0793E2ED49406C0723F6092E414021AF0793E2ED4940
51065	Марицкий Хутор	1	2	1072	34.408026999999997	34.441318000000003	52.163609000000001	52.145623000000001	0103000020E6100000010000000500000047718E3A3A344140D04543C6A3124A4047718E3A3A344140672AC423F1144A406D91B41B7D384140672AC423F1144A406D91B41B7D384140D04543C6A3124A4047718E3A3A344140D04543C6A3124A40
10476	Лемешовка	1	2	1072	34.253346000000001	34.278103000000002	51.937936999999998	51.917627000000003	0103000020E61000000100000005000000454948A46D2041409B7631CD74F54940454948A46D204140AB5AD2510EF84940B2F50CE198234140AB5AD2510EF84940B2F50CE1982341409B7631CD74F54940454948A46D2041409B7631CD74F54940
48645	Кривцово	1	2	1072	34.561432000000003	34.578383000000002	52.178339000000001	52.166116000000002	0103000020E61000000100000005000000C576F700DD474140D2AB014A43154A40C576F700DD474140F94CF6CFD3164A40FCC74274084A4140F94CF6CFD3164A40FCC74274084A4140D2AB014A43154A40C576F700DD474140D2AB014A43154A40
9739	Косицы	1	2	1072	34.470306999999998	34.488667999999997	52.069268999999998	52.052197999999997	0103000020E61000000100000005000000390A1005333C414053758F6CAE064A40390A1005333C414035D07CCEDD084A40054D4BAC8C3E414035D07CCEDD084A40054D4BAC8C3E414053758F6CAE064A40390A1005333C414053758F6CAE064A40
10127	Заулье	1	2	1072	34.270530000000001	34.335515000000001	52.253160999999999	52.236060999999999	0103000020E610000001000000050000001F4B1FBAA0224140376E313F371E4A401F4B1FBAA0224140B3CF639467204A40A228D027F22A4140B3CF639467204A40A228D027F22A4140376E313F371E4A401F4B1FBAA0224140376E313F371E4A40
48778	Заречный	1	2	1072	34.469346000000002	34.48706	52.199567999999999	52.190939999999998	0103000020E6100000010000000500000014419C87133C4140C6BFCFB870184A4014419C87133C414000AAB8718B194A404A9869FB573E414000AAB8718B194A404A9869FB573E4140C6BFCFB870184A4014419C87133C4140C6BFCFB870184A40
62084	Дубрава	1	2	1072	34.060971000000002	34.744455000000002	52.330294000000002	51.843623000000001	0103000020E610000001000000050000009180D1E5CD074140A393A5D6FBEB49409180D1E5CD0741405308E412472A4A40FE2B2B4D4A5F41405308E412472A4A40FE2B2B4D4A5F4140A393A5D6FBEB49409180D1E5CD074140A393A5D6FBEB4940
10515	Доброводье	1	2	1072	34.643951000000001	34.702008999999997	52.121985000000002	52.092115999999997	0103000020E61000000100000005000000FE9C82FC6C5241401BB80375CA0B4A40FE9C82FC6C52414021CD58349D0F4A40B33F506EDB59414021CD58349D0F4A40B33F506EDB5941401BB80375CA0B4A40FE9C82FC6C5241401BB80375CA0B4A40
51121	Голышино	1	2	1072	34.530557000000002	34.562806000000002	52.319609999999997	52.301281000000003	0103000020E61000000100000005000000FAD4B14AE9434140FEF3346090264A40FAD4B14AE9434140BEBC00FBE8284A400DFFE9060A484140BEBC00FBE8284A400DFFE9060A484140FEF3346090264A40FAD4B14AE9434140FEF3346090264A40
51119	Гапоново	1	2	1072	34.644077000000003	34.683190000000003	52.163310000000003	52.139052	0103000020E610000001000000050000008B8D791D71524140C138B874CC114A408B8D791D715241400D8E9257E7144A40257A19C5725741400D8E9257E7144A40257A19C572574140C138B874CC114A408B8D791D71524140C138B874CC114A40
9248	Шаровичи	1	2	1023	33.720419999999997	33.773178000000001	53.968871	53.936973999999999	0103000020E6100000010000000500000031B1F9B836DC4040E59997C3EEF74A4031B1F9B836DC40407B8505F703FC4A404CFE277FF7E240407B8505F703FC4A404CFE277FF7E24040E59997C3EEF74A4031B1F9B836DC4040E59997C3EEF74A40
9462	Хариново	1	2	1023	33.372799000000001	33.405335999999998	53.853386	53.839925000000001	0103000020E61000000100000005000000A27DACE0B7AF4040E10B93A982EB4A40A27DACE0B7AF4040A06EA0C03BED4A401BF2CF0CE2B34040A06EA0C03BED4A401BF2CF0CE2B34040E10B93A982EB4A40A27DACE0B7AF4040E10B93A982EB4A40
48334	Тюнино	1	2	1023	33.357877999999999	33.386767999999996	53.896326000000002	53.884089000000003	0103000020E610000001000000050000009CFA40F2CEAD40406EE00ED429F14A409CFA40F2CEAD4040FA4674CFBAF24A40D591239D81B14040FA4674CFBAF24A40D591239D81B140406EE00ED429F14A409CFA40F2CEAD40406EE00ED429F14A40
9203	Старое Хотмирово	1	2	1023	33.782457999999998	33.813180000000003	53.856498000000002	53.836578000000003	0103000020E610000001000000050000002D3F709527E44040CC46E7FC14EB4A402D3F709527E44040728BF9B9A1ED4A4072E1404816E84040728BF9B9A1ED4A4072E1404816E84040CC46E7FC14EB4A402D3F709527E44040CC46E7FC14EB4A40
48209	Снопот	1	2	1023	33.659621999999999	33.694881000000002	53.898972999999998	53.882061999999998	0103000020E610000001000000050000006EDC627E6ED44040AD855968E7F04A406EDC627E6ED44040567E198C11F34A404FCE50DCF1D84040567E198C11F34A404FCE50DCF1D84040AD855968E7F04A406EDC627E6ED44040AD855968E7F04A40
8912	Рогнедино	1	2	1023	33.523904999999999	33.583013999999999	53.818381000000002	53.788921999999999	0103000020E61000000100000005000000FE9AAC510FC34040268C6665FBE44A40FE9AAC510FC340407A5567B5C0E84A40198EE733A0CA40407A5567B5C0E84A40198EE733A0CA4040268C6665FBE44A40FE9AAC510FC34040268C6665FBE44A40
10524	Пацынь	1	2	1023	33.555579000000002	33.586643000000002	53.885415999999999	53.870961999999999	0103000020E6100000010000000500000015AC71361DC740408507CDAE7BEF4A4015AC71361DC7404075ADBD4F55F14A40B3B6291E17CB404075ADBD4F55F14A40B3B6291E17CB40408507CDAE7BEF4A4015AC71361DC740408507CDAE7BEF4A40
48323	Осовик	1	2	1023	33.503287999999998	33.524020999999998	53.991269000000003	53.977429000000001	0103000020E61000000100000005000000103CBEBD6BC04040BC94BA641CFD4A40103CBEBD6BC04040F24410E7E1FE4A4067B5C01E13C34040F24410E7E1FE4A4067B5C01E13C34040BC94BA641CFD4A40103CBEBD6BC04040BC94BA641CFD4A40
9081	Лутовиновка	1	2	1023	33.628036999999999	33.653486999999998	53.713185000000003	53.694758999999998	0103000020E61000000100000005000000C7D6338463D0404003CDE7DCEDD84A40C7D6338463D04040B77F65A549DB4A403AAE4676A5D34040B77F65A549DB4A403AAE4676A5D3404003CDE7DCEDD84A40C7D6338463D0404003CDE7DCEDD84A40
51104	Летошники	1	2	1023	33.439256	33.456800999999999	53.839058999999999	53.825885999999997	0103000020E610000001000000050000003049658A39B84040B41CE8A1B6E94A403049658A39B840400D350A4966EB4A40DAE3857478BA40400D350A4966EB4A40DAE3857478BA4040B41CE8A1B6E94A403049658A39B84040B41CE8A1B6E94A40
48551	Княгинино	1	2	1023	33.603810000000003	33.617984999999997	53.835962000000002	53.827655999999998	0103000020E61000000100000005000000B77F65A549CD4040492BBEA1F0E94A40B77F65A549CD4040715985CD00EB4A409335EA211ACF4040715985CD00EB4A409335EA211ACF4040492BBEA1F0E94A40B77F65A549CD4040492BBEA1F0E94A40
9341	Гобики	1	2	1023	33.546847999999997	33.573338999999997	53.951363000000001	53.933841000000001	0103000020E6100000010000000500000006F1811DFFC54040FC54151A88F74A4006F1811DFFC54040EECF4543C6F94A40BB421F2C63C94040EECF4543C6F94A40BB421F2C63C94040FC54151A88F74A4006F1811DFFC54040FC54151A88F74A40
48137	Вороново	1	2	1023	33.673690000000001	33.729501999999997	53.769379999999998	53.748896000000002	0103000020E6100000010000000500000035D252793BD64040780DFAD2DBDF4A4035D252793BD640402619390B7BE24A40EC2E505260DD40402619390B7BE24A40EC2E505260DD4040780DFAD2DBDF4A4035D252793BD64040780DFAD2DBDF4A40
7714	Шуморово	1	2	861	33.423912999999999	33.446613999999997	53.096722999999997	53.083489	0103000020E61000000100000005000000B4ACFBC742B64040B2497EC4AF8A4A40B4ACFBC742B64040B0E2546B618C4A40C6F7C5A52AB94040B0E2546B618C4A40C6F7C5A52AB94040B2497EC4AF8A4A40B4ACFBC742B64040B2497EC4AF8A4A40
8725	Чопово	1	2	861	33.320813999999999	33.341043999999997	52.974308000000001	52.959387	0103000020E61000000100000005000000AA0CE36E10A94040919A7631CD7A4A40AA0CE36E10A94040971DE21FB67C4A409E3F6D54A7AB4040971DE21FB67C4A409E3F6D54A7AB4040919A7631CD7A4A40AA0CE36E10A94040919A7631CD7A4A40
10430	Тубольцы	1	2	861	33.254572000000003	33.273014000000003	52.880519	52.868127000000001	0103000020E61000000100000005000000193DB7D095A0404026E318C91E6F4A40193DB7D095A04040D940BAD8B4704A40D2AC6C1FF2A24040D940BAD8B4704A40D2AC6C1FF2A2404026E318C91E6F4A40193DB7D095A0404026E318C91E6F4A40
47588	Третьяки	1	2	861	33.387611999999997	33.401032999999998	53.050066000000001	53.043418000000003	0103000020E61000000100000005000000C1C41F459DB14040640795B88E854A40C1C41F459DB140401E520C9068864A40F2CEA10C55B340401E520C9068864A40F2CEA10C55B34040640795B88E854A40C1C41F459DB14040640795B88E854A40
8073	Супрягино	1	2	861	33.236848000000002	33.263554999999997	53.051943999999999	53.039769	0103000020E61000000100000005000000BF0F0709519E404083328D2617854A40BF0F0709519E4040999CDA19A6864A4040D9942BBCA14040999CDA19A6864A4040D9942BBCA1404083328D2617854A40BF0F0709519E404083328D2617854A40
51139	Старопочелье	1	2	861	33.266824999999997	33.296028999999997	52.994697000000002	52.979984999999999	0103000020E61000000100000005000000AA60545227A2404008C90226707D4A40AA60545227A24040F436363B527F4A4073D53C47E4A54040F436363B527F4A4073D53C47E4A5404008C90226707D4A40AA60545227A2404008C90226707D4A40
51136	Старокрасная Слобода	1	2	861	33.586939000000001	33.615704000000001	52.828795	52.807406999999998	0103000020E610000001000000050000009CDF30D120CB4040DEC7D11C59674A409CDF30D120CB40404E0B5EF4156A4A4019028063CFCE40404E0B5EF4156A4A4019028063CFCE4040DEC7D11C59674A409CDF30D120CB4040DEC7D11C59674A40
47507	Сотниково	1	2	861	33.250259999999997	33.272295999999997	52.907091000000001	52.895786999999999	0103000020E610000001000000050000009CBF098508A040404A97FE25A9724A409CBF098508A040407BBFD18E1B744A40726A6798DAA240407BBFD18E1B744A40726A6798DAA240404A97FE25A9724A409CBF098508A040404A97FE25A9724A40
8534	Семцы	1	2	861	33.440451000000003	33.478414000000001	52.834960000000002	52.799011999999998	0103000020E61000000100000005000000C93EC8B260B84040478E740646664A40C93EC8B260B84040EDBB22F8DF6A4A406AF981AB3CBD4040EDBB22F8DF6A4A406AF981AB3CBD4040478E740646664A40C93EC8B260B84040478E740646664A40
51150	Светолово	1	2	861	33.48516	33.514947999999997	53.002453000000003	52.969557000000002	0103000020E61000000100000005000000E7A90EB919BE4040CF4D9B711A7C4A40E7A90EB919BE40407863416150804A40FF91E9D0E9C140407863416150804A40FF91E9D0E9C14040CF4D9B711A7C4A40E7A90EB919BE4040CF4D9B711A7C4A40
47994	Рогово	1	2	861	33.352730999999999	33.388663000000001	52.869083000000003	52.84722	0103000020E6100000010000000500000087A4164A26AD4040314278B4716C4A4087A4164A26AD40403A419B1C3E6F4A4027158DB5BFB140403A419B1C3E6F4A4027158DB5BFB14040314278B4716C4A4087A4164A26AD4040314278B4716C4A40
51126	Рамасуха	1	2	861	33.527299999999997	33.555418000000003	52.748427999999997	52.732334000000002	0103000020E610000001000000050000002497FF907EC34040DBDFD91EBD5D4A402497FF907EC3404091B41B7DCC5F4A400CCEE0EF17C7404091B41B7DCC5F4A400CCEE0EF17C74040DBDFD91EBD5D4A402497FF907EC34040DBDFD91EBD5D4A40
47334	Прогресс	1	2	861	33.391736000000002	33.405667999999999	52.701932999999997	52.698140000000002	0103000020E610000001000000050000003B55BE6724B24040C503CAA65C594A403B55BE6724B24040D87DC7F0D8594A405184D4EDECB34040D87DC7F0D8594A405184D4EDECB34040C503CAA65C594A403B55BE6724B24040C503CAA65C594A40
6463	Почеп	1	2	861	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
8002	Польники	1	2	861	33.235706999999998	33.249792999999997	53.015602999999999	53.006056000000001	0103000020E610000001000000050000001938A0A52B9E4040E8F86871C6804A401938A0A52B9E4040185C7347FF814A4086E28E37F99F4040185C7347FF814A4086E28E37F99F4040E8F86871C6804A401938A0A52B9E4040E8F86871C6804A40
7451	Подбелово	1	2	861	33.163752000000002	33.197619000000003	52.955655	52.940832	0103000020E61000000100000005000000CA5356D3F5944040E083D72E6D784A40CA5356D3F594404023A12DE7527A4A40BC0853944B99404023A12DE7527A4A40BC0853944B994040E083D72E6D784A40CA5356D3F5944040E083D72E6D784A40
51110	Первомайское	1	2	861	33.565109999999997	33.637030000000003	52.911821000000003	52.889746000000002	0103000020E610000001000000050000003F52448655C8404098DF6932E3714A403F52448655C840402C67EF8CB6744A401349F4328AD140402C67EF8CB6744A401349F4328AD1404098DF6932E3714A403F52448655C8404098DF6932E3714A40
7539	Папсуевка	1	2	861	33.589796	33.614804999999997	53.051640999999996	53.036709000000002	0103000020E61000000100000005000000E3A7716F7ECB4040043C69E1B2844A40E3A7716F7ECB4040FD101B2C9C864A40693524EEB1CE4040FD101B2C9C864A40693524EEB1CE4040043C69E1B2844A40E3A7716F7ECB4040043C69E1B2844A40
47365	Октябрьский	1	2	861	33.278098999999997	33.298229999999997	52.746645999999998	52.737492000000003	0103000020E6100000010000000500000070067FBF98A34040E4874A23665E4A4070067FBF98A3404038D89B18925F4A40D15790662CA6404038D89B18925F4A40D15790662CA64040E4874A23665E4A4070067FBF98A34040E4874A23665E4A40
7837	Милечь	1	2	861	33.741790999999999	33.786321000000001	52.885708000000001	52.865696999999997	0103000020E61000000100000005000000CBBBEA01F3DE4040669FC728CF6E4A40CBBBEA01F3DE40401DE736E15E714A403A94A12AA6E440401DE736E15E714A403A94A12AA6E44040669FC728CF6E4A40CBBBEA01F3DE4040669FC728CF6E4A40
7729	Красный Рог	1	2	861	33.719521999999998	33.745465000000003	52.955145000000002	52.936984000000002	0103000020E610000001000000050000005260014C19DC404009707A17EF774A405260014C19DC40400EF8FC30427A4A4005A8A9656BDF40400EF8FC30427A4A4005A8A9656BDF404009707A17EF774A405260014C19DC404009707A17EF774A40
47312	Котляково	1	2	861	33.239884000000004	33.274343999999999	52.796159000000003	52.776999000000004	0103000020E61000000100000005000000B66AD784B49E40402A0307B474634A40B66AD784B49E404042B5C189E8654A404AED45B41DA3404042B5C189E8654A404AED45B41DA340402A0307B474634A40B66AD784B49E40402A0307B474634A40
8245	Козорезовка	1	2	861	33.394573999999999	33.413879000000001	52.889761999999997	52.874665999999998	0103000020E610000001000000050000000BED9C6681B240402976340EF56F4A400BED9C6681B240409D9CA1B8E3714A4027C0B0FCF9B440409D9CA1B8E3714A4027C0B0FCF9B440402976340EF56F4A400BED9C6681B240402976340EF56F4A40
47356	Кожемяки	1	2	861	33.177407000000002	33.191383999999999	52.780714000000003	52.771399000000002	0103000020E610000001000000050000006E8AC745B59640406495D233BD624A406E8AC745B5964040C2C3B46FEE634A40247D5A457F984040C2C3B46FEE634A40247D5A457F9840406495D233BD624A406E8AC745B59640406495D233BD624A40
47458	Калачево	1	2	861	33.327981999999999	33.363142000000003	52.801091999999997	52.788257999999999	0103000020E610000001000000050000009DD66D50FBA94040BA675DA3E5644A409DD66D50FBA940402A8BC22E8A664A40EBE6E26F7BAE40402A8BC22E8A664A40EBE6E26F7BAE4040BA675DA3E5644A409DD66D50FBA94040BA675DA3E5644A40
48074	Житня	1	2	861	33.345886	33.378908000000003	52.959116000000002	52.943257000000003	0103000020E61000000100000005000000771211FE45AC40408E5C37A5BC784A40771211FE45AC404001892650C47A4A40AD18AE0E80B0404001892650C47A4A40AD18AE0E80B040408E5C37A5BC784A40771211FE45AC40408E5C37A5BC784A40
51123	Доманичи	1	2	861	33.391888000000002	33.436884999999997	53.013765999999997	52.998491000000001	0103000020E61000000100000005000000F1D8CF6229B24040D82C978DCE7F4A40F1D8CF6229B24040FBE59315C3814A40758E01D9EBB74040FBE59315C3814A40758E01D9EBB74040D82C978DCE7F4A40F1D8CF6229B24040D82C978DCE7F4A40
47549	Дмитрово	1	2	861	33.552551999999999	33.578476999999999	53.078789	53.055430000000001	0103000020E6100000010000000500000071AB2006BAC64040D09B8A5418874A4071AB2006BAC640406C2409C2158A4A407D3ECA880BCA40406C2409C2158A4A407D3ECA880BCA4040D09B8A5418874A4071AB2006BAC64040D09B8A5418874A40
8440	Громыки	1	2	861	33.466413000000003	33.491717999999999	52.980401999999998	52.957700000000003	0103000020E61000000100000005000000F2B6D26BB3BB40408AB0E1E9957A4A40F2B6D26BB3BB40406C770FD07D7D4A40616D8C9DF0BE40406C770FD07D7D4A40616D8C9DF0BE40408AB0E1E9957A4A40F2B6D26BB3BB40408AB0E1E9957A4A40
47788	Глазово	1	2	861	33.256008999999999	33.270059000000003	53.067383999999997	53.052539000000003	0103000020E61000000100000005000000A73D25E7C4A04040DD611399B9864A40A73D25E7C4A040400723F609A0884A40C87E164B91A240400723F609A0884A40C87E164B91A24040DD611399B9864A40A73D25E7C4A04040DD611399B9864A40
32366	Вормино	1	2	861	33.18815	33.202424999999998	52.902256999999999	52.893467000000001	0103000020E61000000100000005000000075F984C1598404012876C205D724A40075F984C1598404025CB49287D734A404772F90FE999404025CB49287D734A404772F90FE999404012876C205D724A40075F984C1598404012876C205D724A40
51075	Воложино	1	2	861	33.506315999999998	33.521811999999997	53.045566999999998	53.035322999999998	0103000020E6100000010000000500000084B872F6CEC04040F7E5CC7685844A4084B872F6CEC040406F63B323D5854A40865451BCCAC240406F63B323D5854A40865451BCCAC24040F7E5CC7685844A4084B872F6CEC04040F7E5CC7685844A40
7289	Витовка	1	2	861	33.478648	33.521757999999998	52.930742000000002	52.911517000000003	0103000020E61000000100000005000000DD25715644BD4040C05FCC96AC744A40DD25715644BD4040BF81C98D22774A40933655F7C8C24040BF81C98D22774A40933655F7C8C24040C05FCC96AC744A40DD25715644BD4040C05FCC96AC744A40
8161	Верхняя Злобинка	1	2	861	33.335070000000002	33.366591999999997	52.902278000000003	52.886963999999999	0103000020E6100000010000000500000074EFE192E3AA40405B5D4E0988714A4074EFE192E3AA40403DF372D87D734A40D47C957CECAE40403DF372D87D734A40D47C957CECAE40405B5D4E0988714A4074EFE192E3AA40405B5D4E0988714A40
8745	Васьковичи	1	2	861	33.282463999999997	33.301814	52.958243000000003	52.945112999999999	0103000020E610000001000000050000000F26C5C727A4404021037976F9784A400F26C5C727A440407B4FE5B4A77A4A40CBBC55D7A1A640407B4FE5B4A77A4A40CBBC55D7A1A6404021037976F9784A400F26C5C727A4404021037976F9784A40
7179	Валуец	1	2	861	33.370894999999997	33.407321000000003	52.764664000000003	52.728499999999997	0103000020E61000000100000005000000FD9FC37C79AF40406891ED7C3F5D4A40FD9FC37C79AF4040DB368C82E0614A40ADFC321823B44040DB368C82E0614A40ADFC321823B440406891ED7C3F5D4A40FD9FC37C79AF40406891ED7C3F5D4A40
47389	Бельково	1	2	861	33.219923999999999	33.249181999999998	53.118442999999999	53.098626000000003	0103000020E6100000010000000500000081CD3978269C40408544DAC69F8C4A4081CD3978269C404056B8E523298F4A403D601E32E59F404056B8E523298F4A403D601E32E59F40408544DAC69F8C4A4081CD3978269C40408544DAC69F8C4A40
47412	Балыки	1	2	861	33.181511999999998	33.203583000000002	53.096029999999999	53.084695000000004	0103000020E6100000010000000500000070EA03C93B9740403F912749D78A4A4070EA03C93B974040AAB706B64A8C4A40C382FB010F9A4040AAB706B64A8C4A40C382FB010F9A40403F912749D78A4A4070EA03C93B9740403F912749D78A4A40
6897	Баклань	1	2	861	33.234557000000002	33.273274999999998	52.757939999999998	52.726657000000003	0103000020E610000001000000050000002106BAF6059E40406A34B918035D4A402106BAF6059E4040452A8C2D04614A403EE8D9ACFAA24040452A8C2D04614A403EE8D9ACFAA240406A34B918035D4A402106BAF6059E40406A34B918035D4A40
7636	Алексеевск	1	2	861	33.327398000000002	33.350377000000002	53.047305000000001	53.030926000000001	0103000020E610000001000000050000004E637B2DE8A940404D4C1762F5834A404E637B2DE8A94040F9F719170E864A40A3224E27D9AC4040F9F719170E864A40A3224E27D9AC40404D4C1762F5834A404E637B2DE8A940404D4C1762F5834A40
6268	Юдиново	1	2	578	33.250134000000003	33.289183999999999	52.679029999999997	52.652569	0103000020E6100000010000000500000010CF126404A0404014B1886187534A4010CF126404A040405E807D74EA564A40634337FB03A540405E807D74EA564A40634337FB03A5404014B1886187534A4010CF126404A0404014B1886187534A40
5875	Чеховка	1	2	578	33.354500000000002	33.394952000000004	52.642991000000002	52.625813999999998	0103000020E610000001000000050000004C37894160AD404081B053AC1A504A404C37894160AD4040A94F72874D524A40B2BE81C98DB24040A94F72874D524A40B2BE81C98DB2404081B053AC1A504A404C37894160AD404081B053AC1A504A40
6162	Чаусы	1	2	578	33.281511999999999	33.303987999999997	52.409269999999999	52.395989999999998	0103000020E610000001000000050000003DB7D09508A4404082C5E1CCAF324A403DB7D09508A44040F19D98F562344A402F302B14E9A64040F19D98F562344A402F302B14E9A6404082C5E1CCAF324A403DB7D09508A4404082C5E1CCAF324A40
4492	Чайкино	1	2	578	33.199173000000002	33.219484000000001	52.546624999999999	52.537616	0103000020E61000000100000005000000849F38807E99404036E7E099D0444A40849F38807E9940408716D9CEF7454A4065FF3C0D189C40408716D9CEF7454A4065FF3C0D189C404036E7E099D0444A40849F38807E99404036E7E099D0444A40
5995	Суворово	1	2	578	33.259486000000003	33.289202000000003	52.518380000000001	52.501607999999997	0103000020E610000001000000050000008BE255D636A14040BBB4E1B034404A408BE255D636A1404043739D465A424A400AF8359204A5404043739D465A424A400AF8359204A54040BBB4E1B034404A408BE255D636A14040BBB4E1B034404A40
5665	Стечна	1	2	578	33.367615999999998	33.396838000000002	52.591689000000002	52.576954000000001	0103000020E6100000010000000500000040BE840A0EAF4040F0A5F0A0D9494A4040BE840A0EAF404094331477BC4B4A40B0E76B96CBB2404094331477BC4B4A40B0E76B96CBB24040F0A5F0A0D9494A4040BE840A0EAF4040F0A5F0A0D9494A40
6212	Сопычи	1	2	578	33.331000000000003	33.346837999999998	52.379721000000004	52.363363	0103000020E61000000100000005000000EE7C3F355EAA4040C9C9C4AD822E4A40EE7C3F355EAA40405E4D9EB29A304A404981053065AC40405E4D9EB29A304A404981053065AC4040C9C9C4AD822E4A40EE7C3F355EAA4040C9C9C4AD822E4A40
51082	Синицкий	1	2	578	33.139471	33.175457000000002	52.560172000000001	52.548673000000001	0103000020E61000000100000005000000C6DE8B2FDA9140405F99B7EA3A464A40C6DE8B2FDA914040451152B7B3474A40596DFE5F75964040451152B7B3474A40596DFE5F759640405F99B7EA3A464A40C6DE8B2FDA9140405F99B7EA3A464A40
5012	Савостьяны	1	2	578	33.175528999999997	33.212189000000002	52.721634000000002	52.704360999999999	0103000020E61000000100000005000000F23FF9BB77964040F7C95180285A4A40F23FF9BB7796404041D7BE805E5C4A4015C95702299B404041D7BE805E5C4A4015C95702299B4040F7C95180285A4A40F23FF9BB77964040F7C95180285A4A40
5858	Романовка	1	2	578	33.433416999999999	33.463197000000001	52.590885	52.577742000000001	0103000020E61000000100000005000000E54350357AB7404048C32973F3494A40E54350357AB740403659A31EA24B4A407B4D0F0A4ABB40403659A31EA24B4A407B4D0F0A4ABB404048C32973F3494A40E54350357AB7404048C32973F3494A40
20238	Рассуха	1	2	578	33.079625	33.09796	52.643357000000002	52.633253000000003	0103000020E61000000100000005000000D578E926318A4040058C2E6F0E514A40D578E926318A40408B53AD8559524A4078280AF4898C40408B53AD8559524A4078280AF4898C4040058C2E6F0E514A40D578E926318A4040058C2E6F0E514A40
51078	Прирубки	1	2	578	33.121046	33.131996999999998	52.636263999999997	52.632328999999999	0103000020E61000000100000005000000E3A7716F7E8F4040FCA71B28F0504A40E3A7716F7E8F4040A2CF471971514A40C6151747E5904040A2CF471971514A40C6151747E5904040FCA71B28F0504A40E3A7716F7E8F4040FCA71B28F0504A40
5419	Посудичи	1	2	578	33.217740999999997	33.270435999999997	52.633268999999999	52.612155999999999	0103000020E61000000100000005000000C9FFE4EFDE9B40406C06B8205B4E4A40C9FFE4EFDE9B40400A4966F50E514A409DD497A59DA240400A4966F50E514A409DD497A59DA240406C06B8205B4E4A40C9FFE4EFDE9B40406C06B8205B4E4A40
51098	Погар	1	2	578	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
4017	Песчанки	1	2	578	33.025455999999998	33.051391000000002	52.489342999999998	52.474952000000002	0103000020E6100000010000000500000055BE672442834040BC95253ACB3C4A4055BE67244283404065C39ACAA23E4A408527F4FA9386404065C39ACAA23E4A408527F4FA93864040BC95253ACB3C4A4055BE672442834040BC95253ACB3C4A40
4675	Перегон	1	2	578	33.224046999999999	33.247017	52.479821999999999	52.471156000000001	0103000020E610000001000000050000002AE27492AD9C404037A8FDD64E3C4A402AE27492AD9C40405EF3AACE6A3D4A402C47C8409E9F40405EF3AACE6A3D4A402C47C8409E9F404037A8FDD64E3C4A402AE27492AD9C404037A8FDD64E3C4A40
5099	Михновка	1	2	578	33.285446999999998	33.301724	52.701540000000001	52.680700999999999	0103000020E61000000100000005000000E3DEFC8689A4404060ADDA3521574A40E3DEFC8689A44040FD6A0E10CC594A408B355CE49EA64040FD6A0E10CC594A408B355CE49EA6404060ADDA3521574A40E3DEFC8689A4404060ADDA3521574A40
5471	Мадеевка	1	2	578	33.213977	33.228745000000004	52.582053999999999	52.568558000000003	0103000020E61000000100000005000000508C2C99639B404089F02F82C6484A40508C2C99639B4040C440D7BE804A4A40D00F2384479D4040C440D7BE804A4A40D00F2384479D404089F02F82C6484A40508C2C99639B404089F02F82C6484A40
4788	Лукин	1	2	578	33.234853999999999	33.248669999999997	52.457334000000003	52.431638999999997	0103000020E61000000100000005000000DAAA24B20F9E4040CD565EF23F374A40DAAA24B20F9E4040A8ACA6EB893A4A4087BF266BD49F4040A8ACA6EB893A4A4087BF266BD49F4040CD565EF23F374A40DAAA24B20F9E4040CD565EF23F374A40
3955	Лобки	1	2	578	33.146217	33.176777999999999	52.503691000000003	52.484808000000001	0103000020E61000000100000005000000438F183DB79240406A6B44300E3E4A40438F183DB792404010255AF278404A407E5358A9A096404010255AF278404A407E5358A9A09640406A6B44300E3E4A40438F183DB79240406A6B44300E3E4A40
6055	Курово	1	2	578	33.269672	33.293514000000002	52.545338000000001	52.522154999999998	0103000020E61000000100000005000000CE52B29C84A24040B0389CF9D5424A40CE52B29C84A240400EA2B5A2CD454A408675E3DD91A540400EA2B5A2CD454A408675E3DD91A54040B0389CF9D5424A40CE52B29C84A24040B0389CF9D5424A40
4381	Красный Угол	1	2	578	33.328628999999999	33.35539	52.457548000000003	52.443151999999998	0103000020E6100000010000000500000033C2DB8310AA404018946934B9384A4033C2DB8310AA4040D42CD0EE903A4A40A8A9656B7DAD4040D42CD0EE903A4A40A8A9656B7DAD404018946934B9384A4033C2DB8310AA404018946934B9384A40
5123	Кистер	1	2	578	33.066276000000002	33.132714999999997	52.421815000000002	52.379742999999998	0103000020E610000001000000050000003E4162BB7B88404045F12A6B9B304A403E4162BB7B8840402BFBAE08FE354A4025581CCEFC9040402BFBAE08FE354A4025581CCEFC90404045F12A6B9B304A403E4162BB7B88404045F12A6B9B304A40
5953	Карбовка	1	2	578	33.424757999999997	33.459890999999999	52.657021	52.638330000000003	0103000020E61000000100000005000000705B5B785EB64040210725CCB4514A40705B5B785EB6404082E49D4319544A40C45C52B5DDBA404082E49D4319544A40C45C52B5DDBA4040210725CCB4514A40705B5B785EB64040210725CCB4514A40
6431	Казиловка	1	2	578	33.321289999999998	33.350251	52.664237	52.650224999999999	0103000020E610000001000000050000001344DD0720A940405305A3923A534A401344DD0720A9404086E5CFB705554A4016325706D5AC404086E5CFB705554A4016325706D5AC40405305A3923A534A401344DD0720A940405305A3923A534A40
4346	Исаевка	1	2	578	33.399110999999998	33.418829000000002	52.495583000000003	52.481918	0103000020E61000000100000005000000A73CBA1116B3404047AD307DAF3D4A40A73CBA1116B340400FBA84436F3F4A40E6CE4C309CB540400FBA84436F3F4A40E6CE4C309CB5404047AD307DAF3D4A40A73CBA1116B3404047AD307DAF3D4A40
6300	Заречное	1	2	578	33.214103000000001	33.243944999999997	52.654491999999998	52.644784000000001	0103000020E61000000100000005000000DD7C23BA679B4040F67D384888524A40DD7C23BA679B40402FBFD364C6534A40E882FA96399F40402FBFD364C6534A40E882FA96399F4040F67D384888524A40DD7C23BA679B4040F67D384888524A40
51117	Запесонье	1	2	578	33.402605000000001	33.415218000000003	52.378912	52.372627999999999	0103000020E61000000100000005000000611A868F88B3404075C93846B22F4A40611A868F88B34040EE073C3080304A40F35A09DD25B54040EE073C3080304A40F35A09DD25B5404075C93846B22F4A40611A868F88B3404075C93846B22F4A40
5627	Жигалки	1	2	578	33.135984999999998	33.154831999999999	52.628793000000002	52.616185999999999	0103000020E610000001000000050000008FDFDBF4679140406420CF2EDF4E4A408FDFDBF467914040147AFD497C504A40E82FF488D1934040147AFD497C504A40E82FF488D19340406420CF2EDF4E4A408FDFDBF4679140406420CF2EDF4E4A40
4178	Евдоколье	1	2	578	33.355272999999997	33.389615999999997	52.408720000000002	52.39161	0103000020E610000001000000050000006E13EE9579AD4040AE64C74620324A406E13EE9579AD40404E9CDCEF50344A40C9FFE4EFDEB140404E9CDCEF50344A40C9FFE4EFDEB14040AE64C74620324A406E13EE9579AD4040AE64C74620324A40
4925	Долботово	1	2	578	33.223562000000001	33.258470000000003	52.704869000000002	52.680013000000002	0103000020E610000001000000050000006E50FBAD9D9C40406CED7DAA0A574A406E50FBAD9D9C40406C7BBB25395A4A40A27F828B15A140406C7BBB25395A4A40A27F828B15A140406CED7DAA0A574A406E50FBAD9D9C40406CED7DAA0A574A40
4723	Дареевск	1	2	578	33.188778999999997	33.224074000000002	52.444496999999998	52.404038999999997	0103000020E61000000100000005000000F69507E9299840407EA7C98CB7334A40F69507E929984040C6151747E5384A4024F1F274AE9C4040C6151747E5384A4024F1F274AE9C40407EA7C98CB7334A40F69507E9299840407EA7C98CB7334A40
5243	Гудовка	1	2	578	33.127738999999998	33.144770999999999	52.379638	52.358781999999998	0103000020E610000001000000050000003DB665C0599040405D328E91EC2D4A403DB665C059904040D0285DFA97304A4061342BDB87924040D0285DFA97304A4061342BDB879240405D328E91EC2D4A403DB665C0599040405D328E91EC2D4A40
5760	Грязивец	1	2	578	33.403432000000002	33.428477000000001	52.548783	52.527569	0103000020E610000001000000050000007714E7A8A3B3404014B1886187434A407714E7A8A3B34040E6CC76853E464A404A0B9755D8B64040E6CC76853E464A404A0B9755D8B6404014B1886187434A407714E7A8A3B3404014B1886187434A40
4830	Гринево	1	2	578	33.024099999999997	33.084566000000002	52.562192000000003	52.540233999999998	0103000020E61000000100000005000000B3EA73B515834040F817416326454A40B3EA73B51583404053094FE8F5474A40412D060FD38A404053094FE8F5474A40412D060FD38A4040F817416326454A40B3EA73B515834040F817416326454A40
4597	Городище	1	2	578	33.188653000000002	33.230003000000004	52.486173000000001	52.464868000000003	0103000020E610000001000000050000006AA510C8259840407D7A6CCB803B4A406AA510C8259840405F99B7EA3A3E4A40AF7D01BD709D40405F99B7EA3A3E4A40AF7D01BD709D40407D7A6CCB803B4A406AA510C8259840407D7A6CCB803B4A40
4481	Гетуновка	1	2	578	33.108964	33.138249000000002	52.533622000000001	52.518698000000001	0103000020E610000001000000050000007E384888F28D4040144031B264424A407E384888F28D40408B36C7B94D444A4034DAAA24B29140408B36C7B94D444A4034DAAA24B2914040144031B264424A407E384888F28D4040144031B264424A40
4126	Витемля	1	2	578	33.408434999999997	33.427658999999998	52.404814000000002	52.381633999999998	0103000020E6100000010000000500000058C51B9947B4404055850662D9304A4058C51B9947B44040427BF5F1D0334A40876BB587BDB64040427BF5F1D0334A40876BB587BDB6404055850662D9304A4058C51B9947B4404055850662D9304A40
4265	Василевка	1	2	578	33.344718	33.372664	52.479695999999997	52.464945	0103000020E61000000100000005000000D82B2CB81FAC404028B85851833B4A40D82B2CB81FAC4040D102B4AD663D4A40C2323674B3AF4040D102B4AD663D4A40C2323674B3AF404028B85851833B4A40D82B2CB81FAC404028B85851833B4A40
4061	Вадьковка	1	2	578	33.304912999999999	33.316412	52.563538999999999	52.553826000000001	0103000020E610000001000000050000000890A16307A7404056D636C5E3464A400890A16307A74040A182C30B22484A40EE073C3080A84040A182C30B22484A40EE073C3080A8404056D636C5E3464A400890A16307A7404056D636C5E3464A40
5767	Бугаевка	1	2	578	33.355336000000001	33.373617000000003	52.563468	52.550151999999997	0103000020E61000000100000005000000B58B69A67BAD40401CEA77616B464A40B58B69A67BAD4040D82B2CB81F484A40651D8EAED2AF4040D82B2CB81F484A40651D8EAED2AF40401CEA77616B464A40B58B69A67BAD40401CEA77616B464A40
4907	Бобрик	1	2	578	33.058281000000001	33.101228999999996	52.603651999999997	52.583405999999997	0103000020E61000000100000005000000357D76C07587404024253D0CAD4A4A40357D76C0758740401E15FF77444D4A4011346612F58C40401E15FF77444D4A4011346612F58C404024253D0CAD4A4A40357D76C07587404024253D0CAD4A4A40
6368	Березовка	1	2	578	33.310581999999997	33.349370999999998	52.699308000000002	52.672308000000001	0103000020E61000000100000005000000F65CA626C1A740406A6B44300E564A40F65CA626C1A7404064EAAEEC82594A40DD955D30B8AC404064EAAEEC82594A40DD955D30B8AC40406A6B44300E564A40F65CA626C1A740406A6B44300E564A40
6086	Белевица	1	2	578	33.198749999999997	33.237656999999999	52.518917000000002	52.505127000000002	0103000020E610000001000000050000003D0AD7A370994040CEA96400A8404A403D0AD7A370994040522B4CDF6B424A402E55698B6B9E4040522B4CDF6B424A402E55698B6B9E4040CEA96400A8404A403D0AD7A370994040CEA96400A8404A40
5562	Балыкино	1	2	578	33.109889000000003	33.130685	52.659779999999998	52.648471999999998	0103000020E610000001000000050000005798BED7108E4040942F682101534A405798BED7108E40400647C9AB73544A40F4893C49BA9040400647C9AB73544A40F4893C49BA904040942F682101534A405798BED7108E4040942F682101534A40
5311	Андрейковичи	1	2	578	32.972501000000001	33.040368999999998	52.402732	52.366866000000002	0103000020E61000000100000005000000E529ABE97A7C4040D6011077F52E4A40E529ABE97A7C4040BE86E0B88C334A40D862B7CF2A854040BE86E0B88C334A40D862B7CF2A854040D6011077F52E4A40E529ABE97A7C4040D6011077F52E4A40
51084	Абарники	1	2	578	33.159745999999998	33.186793999999999	52.686886000000001	52.672893000000002	0103000020E610000001000000050000005AD5928E729440408A5A9A5B21564A405AD5928E72944040460A65E1EB574A40658BA4DDE8974040460A65E1EB574A40658BA4DDE89740408A5A9A5B21564A405AD5928E729440408A5A9A5B21564A40
23550	Шеломы	1	2	1218	31.827418000000002	31.875667	52.582436999999999	52.563127999999999	0103000020E610000001000000050000002A1F82AAD1D33F401FBB0B9414484A402A1F82AAD1D33F407C7DAD4B8D4A4A40BA2F67B62BE03F407C7DAD4B8D4A4A40BA2F67B62BE03F401FBB0B9414484A402A1F82AAD1D33F401FBB0B9414484A40
51106	Халеевичи	1	2	1218	31.496891999999999	32.266596	52.760196000000001	52.412092999999999	0103000020E61000000100000005000000DFA46950347F3F408CF4A276BF344A40DFA46950347F3F4067463F1A4E614A40499F56D11F22404067463F1A4E614A40499F56D11F2240408CF4A276BF344A40DFA46950347F3F408CF4A276BF344A40
23296	Тростань	1	2	1218	32.000684999999997	32.033760999999998	52.533819999999999	52.519047999999998	0103000020E61000000100000005000000834C327216004040F086342A70424A40834C327216004040B1F9B83654444A40AC70CB4752044040B1F9B83654444A40AC70CB4752044040F086342A70424A40834C327216004040F086342A70424A40
23186	Старый Кривец	1	2	1218	32.184175000000003	32.241630999999998	52.547632999999998	52.515103000000003	0103000020E61000000100000005000000D3DEE00B93174040278925E5EE414A40D3DEE00B93174040ED9A90D618464A409259BDC3ED1E4040ED9A90D618464A409259BDC3ED1E4040278925E5EE414A40D3DEE00B93174040278925E5EE414A40
23164	Старый Вышков	1	2	1218	31.608436000000001	31.689050999999999	52.603417	52.574266999999999	0103000020E6100000010000000500000085B53176C29B3F400516C09481494A4085B53176C29B3F40DB6CACC43C4D4A40AE4676A565B03F40DB6CACC43C4D4A40AE4676A565B03F400516C09481494A4085B53176C29B3F400516C09481494A40
23051	Старые Бобовичи	1	2	1218	31.723043000000001	31.757259999999999	52.595404000000002	52.578322	0103000020E610000001000000050000000B9A965819B93F4056478E74064A4A400B9A965819B93F402CF4C132364C4A40A79196CADBC13F402CF4C132364C4A40A79196CADBC13F4056478E74064A4A400B9A965819B93F4056478E74064A4A40
23385	Сновское	1	2	1218	32.041918000000003	32.080716000000002	52.498049999999999	52.478000999999999	0103000020E610000001000000050000008F8EAB915D054040473A03232F3D4A408F8EAB915D054040EBE2361AC03F4A40C921E2E6540A4040EBE2361AC03F4A40C921E2E6540A4040473A03232F3D4A408F8EAB915D054040473A03232F3D4A40
23024	Синий Колодец	1	2	1218	31.966504	31.995691000000001	52.633592	52.609651999999997	0103000020E6100000010000000500000004745FCE6CF73F4072F8A413094E4A4004745FCE6CF73F40ED80EB8A19514A40EAEBF99AE5FE3F40ED80EB8A19514A40EAEBF99AE5FE3F4072F8A413094E4A4004745FCE6CF73F4072F8A413094E4A40
12145	Отрадное	1	2	1218	32.220475999999998	32.241945999999999	52.583323999999998	52.570900999999999	0103000020E61000000100000005000000C5C6BC8E381C40407920B24813494A40C5C6BC8E381C4040677C5F5CAA4A4A40F2B22616F81E4040677C5F5CAA4A4A40F2B22616F81E40407920B24813494A40C5C6BC8E381C40407920B24813494A40
51083	Опытная станция	1	2	1218	31.848735000000001	31.864061	52.518791	52.511414000000002	0103000020E6100000010000000500000077F86BB246D93F40B85B920376414A4077F86BB246D93F40C53A55BE67424A40C2BF081A33DD3F40C53A55BE67424A40C2BF081A33DD3F40B85B920376414A4077F86BB246D93F40B85B920376414A40
23107	Новые Бобовичи	1	2	1218	31.705839999999998	31.744126999999999	52.641258999999998	52.607436999999997	0103000020E61000000100000005000000693524EEB1B43F40AFB0E07EC04D4A40693524EEB1B43F4001A260C614524A401212691B7FBE3F4001A260C614524A401212691B7FBE3F40AFB0E07EC04D4A40693524EEB1B43F40AFB0E07EC04D4A40
23561	Новое Место	1	2	1218	31.793112000000001	31.824767999999999	52.552326000000001	52.531616999999997	0103000020E61000000100000005000000AE10566309CB3F40B27F9E060C444A40AE10566309CB3F40815D4D9EB2464A408EC9E2FE23D33F40815D4D9EB2464A408EC9E2FE23D33F40B27F9E060C444A40AE10566309CB3F40B27F9E060C444A40
22978	Манюки	1	2	1218	32.064169	32.092556000000002	52.590628000000002	52.569752000000001	0103000020E61000000100000005000000613596B036084040516A2FA2ED484A40613596B0360840400B0DC4B2994B4A40388600E0D80B40400B0DC4B2994B4A40388600E0D80B4040516A2FA2ED484A40613596B036084040516A2FA2ED484A40
23328	Мамай	1	2	1218	31.985620999999998	32.007531	52.512017	52.502118000000003	0103000020E61000000100000005000000354069A851FC3F40D15D126745404A40354069A851FC3F407EFFE6C589414A40645A9BC6F60040407EFFE6C589414A40645A9BC6F6004040D15D126745404A40354069A851FC3F40D15D126745404A40
22894	Лесная Поляна	1	2	1218	31.766414000000001	31.787631999999999	52.588697000000003	52.577883999999997	0103000020E61000000100000005000000513239B533C43F40DA70581AF8494A40513239B533C43F406D205D6C5A4B4A4077483140A2C93F406D205D6C5A4B4A4077483140A2C93F40DA70581AF8494A40513239B533C43F40DA70581AF8494A40
22909	Крутоберезка	1	2	1218	31.980491000000001	32.003183	52.583559000000001	52.563949000000001	0103000020E61000000100000005000000B8054B7501FB3F4053CE177B2F484A40B8054B7501FB3F40AB24B20FB24A4A409B73F04C68004040AB24B20FB24A4A409B73F04C6800404053CE177B2F484A40B8054B7501FB3F4053CE177B2F484A40
22728	Катичи	1	2	1218	31.750361000000002	31.785242	52.676065000000001	52.663276000000003	0103000020E61000000100000005000000A13193A817C03F40611C5C3AE6544A40A13193A817C03F40317C444C89564A401572A59E05C93F40317C444C89564A401572A59E05C93F40611C5C3AE6544A40A13193A817C03F40611C5C3AE6544A40
23250	Каташин	1	2	1218	32.145898000000003	32.189636999999998	52.611041	52.587482000000001	0103000020E61000000100000005000000A24621C9AC1240408D7E349C324B4A40A24621C9AC124040F0C16B97364E4A40478E740646184040F0C16B97364E4A40478E7406461840408D7E349C324B4A40A24621C9AC1240408D7E349C324B4A40
22829	Замишево	1	2	1218	31.991002000000002	32.027752	52.548164	52.537402	0103000020E6100000010000000500000046459C4EB2FD3F400A67B796C9444A4046459C4EB2FD3F401A6CEA3C2A464A400533A6608D0340401A6CEA3C2A464A400533A6608D0340400A67B796C9444A4046459C4EB2FD3F400A67B796C9444A40
51085	Дубровка	1	2	1218	31.98969	32.016379000000001	52.453411000000003	52.438310000000001	0103000020E61000000100000005000000A12DE7525CFD3F4040C1C58A1A384A40A12DE7525CFD3F40C652245F093A4A40ACAB02B518024040C652245F093A4A40ACAB02B51802404040C1C58A1A384A40A12DE7525CFD3F4040C1C58A1A384A40
22758	Деменка	1	2	1218	31.847954000000001	31.870087999999999	52.502583999999999	52.482126000000001	0103000020E610000001000000050000002C836A8313D93F409146054EB63D4A402C836A8313D93F4016BF29AC54404A405DA45016BEDE3F4016BF29AC54404A405DA45016BEDE3F409146054EB63D4A402C836A8313D93F409146054EB63D4A40
22662	Верещаки	1	2	1218	31.627732000000002	31.674274	52.746569999999998	52.716527999999997	0103000020E6100000010000000500000016A75A0BB3A03F408A558330B75B4A4016A75A0BB3A03F405D16139B8F5F4A40098B8A389DAC3F405D16139B8F5F4A40098B8A389DAC3F408A558330B75B4A4016A75A0BB3A03F408A558330B75B4A40
51055	Новозыбков	1	2	7102	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
2476	Щегловка	1	2	209	34.670344	34.712465999999999	52.806579999999997	52.788034000000003	0103000020E61000000100000005000000F0880AD5CD5541406B11514CDE644A40F0880AD5CD554140C8CD70033E674A4087C1FC15325B4140C8CD70033E674A4087C1FC15325B41406B11514CDE644A40F0880AD5CD5541406B11514CDE644A40
1964	Чичково	1	2	209	34.484473000000001	34.516426000000003	53.009134000000003	52.986924000000002	0103000020E61000000100000005000000C3651536033E41409AD18F86537E4A40C3651536033E41400EA48B4D2B814A40ED66463F1A4241400EA48B4D2B814A40ED66463F1A4241409AD18F86537E4A40C3651536033E41409AD18F86537E4A40
2352	Соколово	1	2	209	34.623083000000001	34.66375	52.903315999999997	52.883442000000002	0103000020E61000000100000005000000C7D8092FC14F4140D8F4A0A014714A40C7D8092FC14F41400DFAD2DB9F734A40295C8FC2F55441400DFAD2DB9F734A40295C8FC2F5544140D8F4A0A014714A40C7D8092FC14F4140D8F4A0A014714A40
2301	Синезерки	1	2	209	34.424232000000003	34.449762	53.032811000000002	53.020099000000002	0103000020E6100000010000000500000056F5F23B4D36414056D7A19A92824A4056F5F23B4D3641407BF99D2633844A40E57D1CCD913941407BF99D2633844A40E57D1CCD9139414056D7A19A92824A4056F5F23B4D36414056D7A19A92824A40
60442	Селище	1	2	209	34.534652999999999	34.566723000000003	52.851999999999997	52.831994999999999	0103000020E61000000100000005000000A9DA6E826F444140BFB7E9CF7E6A4A40A9DA6E826F444140931804560E6D4A400D7217618A484140931804560E6D4A400D7217618A484140BFB7E9CF7E6A4A40A9DA6E826F444140BFB7E9CF7E6A4A40
2186	Салтановка	1	2	209	34.274904999999997	34.312482000000003	52.803896000000002	52.731952	0103000020E61000000100000005000000E140481630234140F31E679AB05D4A40E1404816302341404FB16A10E6664A405A4B0169FF2741404FB16A10E6664A405A4B0169FF274140F31E679AB05D4A40E140481630234140F31E679AB05D4A40
2084	Ревны	1	2	209	34.266767000000002	34.294218999999998	52.996946999999999	52.984610000000004	0103000020E610000001000000050000007653CA6B2522414044A852B3077E4A407653CA6B25224140336C94F59B7F4A40506EDBF7A8254140336C94F59B7F4A40506EDBF7A825414044A852B3077E4A407653CA6B2522414044A852B3077E4A40
2013	Пролысово	1	2	209	34.128965000000001	34.153022	52.878318	52.868729999999999	0103000020E6100000010000000500000011AAD4EC81104140EC866D8B326F4A4011AAD4EC811041407BBE66B96C704A40C5C89239961341407BBE66B96C704A40C5C8923996134140EC866D8B326F4A4011AAD4EC81104140EC866D8B326F4A40
1374	Прилепы	1	2	209	34.565528	34.587868999999998	53.021090000000001	53.013565999999997	0103000020E61000000100000005000000747CB43863484140342BDB87BC814A40747CB43863484140E622BE13B3824A4086AA984A3F4B4140E622BE13B3824A4086AA984A3F4B4140342BDB87BC814A40747CB43863484140342BDB87BC814A40
1891	Приволье	1	2	209	34.447848999999998	34.473225999999997	52.995386000000003	52.981579000000004	0103000020E61000000100000005000000ED45B41D533941405FB87361A47D4A40ED45B41D53394140B972F6CE687F4A40F6CE68AB923C4140B972F6CE687F4A40F6CE68AB923C41405FB87361A47D4A40ED45B41D533941405FB87361A47D4A40
2420	Пластовое	1	2	209	34.685021999999996	34.703716	52.900376999999999	52.874394000000002	0103000020E610000001000000050000002F8507CDAE574140C9E88024EC6F4A402F8507CDAE5741400989B48D3F734A4002D6AA5D135A41400989B48D3F734A4002D6AA5D135A4140C9E88024EC6F4A402F8507CDAE574140C9E88024EC6F4A40
798	Навля	1	2	209	34.472102999999997	34.531984999999999	52.845371	52.811408	0103000020E61000000100000005000000F7AB00DF6D3C41403CDBA337DC674A40F7AB00DF6D3C414050FEEE1D356C4A40357BA0151844414050FEEE1D356C4A40357BA015184441403CDBA337DC674A40F7AB00DF6D3C41403CDBA337DC674A40
1771	Литовня	1	2	209	34.621439000000002	34.650939999999999	52.757863	52.738380999999997	0103000020E61000000100000005000000BFBA2A508B4F41406F7EC344835E4A40BFBA2A508B4F41409AEC9FA701614A4041D47D00525341409AEC9FA701614A4041D47D00525341406F7EC344835E4A40BFBA2A508B4F41406F7EC344835E4A40
1719	Лески	1	2	209	34.798065999999999	34.836613	52.832909000000001	52.812272999999998	0103000020E610000001000000050000005706D506276641403F36C98FF8674A405706D50627664140A4C519C39C6A4A4048348122166B4140A4C519C39C6A4A4048348122166B41403F36C98FF8674A405706D506276641403F36C98FF8674A40
1666	Клюковники	1	2	209	34.450589000000001	34.456831999999999	52.932158999999999	52.921019000000001	0103000020E61000000100000005000000FB777DE6AC39414050FF59F3E3754A40FB777DE6AC39414006D671FC50774A4015E29178793A414006D671FC50774A4015E29178793A414050FF59F3E3754A40FB777DE6AC39414050FF59F3E3754A40
2143	Зубовка	1	2	209	34.384346999999998	34.410263	53.023777000000003	53.009203999999997	0103000020E6100000010000000500000069A8514832314140067FBF982D814A4069A8514832314140D1B2EE1F0B834A4022E17B7F83344140D1B2EE1F0B834A4022E17B7F83344140067FBF982D814A4069A8514832314140067FBF982D814A40
1609	Гремячее	1	2	209	34.794930999999998	34.828232	52.900137999999998	52.881447999999999	0103000020E61000000100000005000000CDC98B4CC0654140F38FBE49D3704A40CDC98B4CC065414084F1D3B837734A4016C09481036A414084F1D3B837734A4016C09481036A4140F38FBE49D3704A40CDC98B4CC0654140F38FBE49D3704A40
49258	Глинное	1	2	209	34.138827999999997	34.183466000000003	52.694102000000001	52.687224000000001	0103000020E6100000010000000500000071E2AB1DC51141405E83BEF4F6574A4071E2AB1DC51141404A0B9755D8584A40C7F65AD07B1741404A0B9755D8584A40C7F65AD07B1741405E83BEF4F6574A4071E2AB1DC51141405E83BEF4F6574A40
1558	Вздружное	1	2	209	34.021031999999998	34.051448999999998	52.782086999999997	52.760027000000001	0103000020E61000000100000005000000B115342DB1024140DB89929048614A40B115342DB102414039D0436D1B644A40B9347EE19506414039D0436D1B644A40B9347EE195064140DB89929048614A40B115342DB1024140DB89929048614A40
1439	Бяково	1	2	209	34.539144999999998	34.564387000000004	52.884236000000001	52.859726999999999	0103000020E61000000100000005000000A5660FB4024541407D3ECA880B6E4A40A5660FB40245414012F92EA52E714A40CFA44DD53D48414012F92EA52E714A40CFA44DD53D4841407D3ECA880B6E4A40A5660FB4024541407D3ECA880B6E4A40
1321	Бутре	1	2	209	34.634824000000002	34.667855000000003	52.991363999999997	52.975375999999997	0103000020E61000000100000005000000A35BAFE941514140D2A6EA1ED97C4A40A35BAFE9415141404337FB03E57E4A402CBCCB457C5541404337FB03E57E4A402CBCCB457C554140D2A6EA1ED97C4A40A35BAFE941514140D2A6EA1ED97C4A40
1825	Борщево	1	2	209	34.468581999999998	34.492235000000001	52.742944000000001	52.724612	0103000020E6100000010000000500000044BFB67EFA3B414003250516C05C4A4044BFB67EFA3B41403561FBC9185F4A402979758E013F41403561FBC9185F4A402979758E013F414003250516C05C4A4044BFB67EFA3B414003250516C05C4A40
1155	Алтухово	1	2	209	34.336395000000003	34.395871999999997	52.701141999999997	52.661183999999999	0103000020E61000000100000005000000DBC4C9FD0E2B4140B95164ADA1544A40DBC4C9FD0E2B41400FED6305BF594A4078B306EFAB3241400FED6305BF594A4078B306EFAB324140B95164ADA1544A40DBC4C9FD0E2B4140B95164ADA1544A40
51079	Алешинка	1	2	209	34.362796000000003	34.406427999999998	52.86007	52.842275999999998	0103000020E61000000100000005000000508F6D19702E4140541A31B3CF6B4A40508F6D19702E4140A72215C6166E4A40DF162CD505344140A72215C6166E4A40DF162CD505344140541A31B3CF6B4A40508F6D19702E4140541A31B3CF6B4A40
1212	Алексеевка	1	2	209	34.402538	34.421052000000003	52.834556999999997	52.805556000000003	0103000020E61000000100000005000000D9B27C5D863341405D8C81751C674A40D9B27C5D86334140EDD286C3D26A4A402CF52C08E5354140EDD286C3D26A4A402CF52C08E53541405D8C81751C674A40D9B27C5D863341405D8C81751C674A40
49131	Шумарово	1	2	104	32.902253000000002	32.927638999999999	53.119047999999999	53.101475000000001	0103000020E61000000100000005000000E4DBBB067D734040492EFF21FD8C4A40E4DBBB067D734040BD5301F73C8F4A4040BFEFDFBC764040BD5301F73C8F4A4040BFEFDFBC764040492EFF21FD8C4A40E4DBBB067D734040492EFF21FD8C4A40
31741	Шеверды	1	2	104	32.703051000000002	32.728068999999998	53.057963000000001	53.040872999999998	0103000020E61000000100000005000000C6353E93FD5940400B2593533B854A40C6353E93FD59404064B0E2546B874A409F1D705D315D404064B0E2546B874A409F1D705D315D40400B2593533B854A40C6353E93FD5940400B2593533B854A40
51152	Черновица	1	2	104	32.81747	32.827368999999997	53.171838000000001	53.158892000000002	0103000020E6100000010000000500000006BB61DBA26840404BCCB39256944A4006BB61DBA2684040E31A9FC9FE954A40B35C363AE7694040E31A9FC9FE954A40B35C363AE76940404BCCB39256944A4006BB61DBA26840404BCCB39256944A40
32112	Цинка	1	2	104	32.734842999999998	32.757883999999997	53.200392999999998	53.191433000000004	0103000020E61000000100000005000000E658DE550F5E4040063065E080984A40E658DE550F5E404075AC527AA6994A40B114C9570261404075AC527AA6994A40B114C95702614040063065E080984A40E658DE550F5E4040063065E080984A40
350	Старая Романовка	1	2	104	32.951704999999997	32.975923000000002	52.981209999999997	52.962035	0103000020E6100000010000000500000047382D78D1794040BE4D7FF6237B4A4047382D78D17940400B410E4A987D4A4005357C0BEB7C40400B410E4A987D4A4005357C0BEB7C4040BE4D7FF6237B4A4047382D78D1794040BE4D7FF6237B4A40
48902	Соколовка	1	2	104	32.835867	32.850456000000001	52.995651000000002	52.986659000000003	0103000020E610000001000000050000001F679AB0FD6A4040ECA694D74A7E4A401F679AB0FD6A4040679DF17D717F4A40EF5701BEDB6C4040679DF17D717F4A40EF5701BEDB6C4040ECA694D74A7E4A401F679AB0FD6A4040ECA694D74A7E4A40
31638	Симонтовка	1	2	104	32.760506999999997	32.784933000000002	53.049568000000001	53.031759999999998	0103000020E6100000010000000500000085B01A4B5861404015A930B610844A4085B01A4B58614040CD76853E58864A408D463EAF78644040CD76853E58864A408D463EAF7864404015A930B610844A4085B01A4B5861404015A930B610844A40
220	Семки	1	2	104	32.982013999999999	33.003906000000001	53.013641999999997	52.997993000000001	0103000020E61000000100000005000000691B7FA2B27D40408751103CBE7F4A40691B7FA2B27D40400FED6305BF814A400C21E7FD7F8040400FED6305BF814A400C21E7FD7F8040408751103CBE7F4A40691B7FA2B27D40408751103CBE7F4A40
49265	Попелевка	1	2	104	33.009124999999997	33.045192	52.990448000000001	52.968021999999998	0103000020E61000000100000005000000BA490C022B8140407DE71725E87B4A40BA490C022B814040BE310400C77E4A403A05F9D9C8854040BE310400C77E4A403A05F9D9C88540407DE71725E87B4A40BA490C022B8140407DE71725E87B4A40
31993	Новые Чешуйки	1	2	104	32.783009999999997	32.812089	53.128208000000001	53.105249000000001	0103000020E610000001000000050000007138F3AB39644040E6779ACC788D4A407138F3AB39644040F48AA71E69904A407E384888F2674040F48AA71E69904A407E384888F2674040E6779ACC788D4A407138F3AB39644040E6779ACC788D4A40
148	Новая Романовка	1	2	104	32.928958999999999	32.961163999999997	53.014595	52.998199	0103000020E610000001000000050000009529E620E876404030F31DFCC47F4A409529E620E8764040B2D7BB3FDE814A40D80B056C077B4040B2D7BB3FDE814A40D80B056C077B404030F31DFCC47F4A409529E620E876404030F31DFCC47F4A40
31848	Нетяговка	1	2	104	32.786352000000001	32.813274	53.083094000000003	53.068584999999999	0103000020E610000001000000050000007592AD2EA764404082FFAD64C7884A407592AD2EA7644040363FFED2A28A4A40F357C85C19684040363FFED2A28A4A40F357C85C1968404082FFAD64C7884A407592AD2EA764404082FFAD64C7884A40
32180	Молодьково	1	2	104	32.819535999999999	32.842846999999999	53.205582	53.192996999999998	0103000020E6100000010000000500000084F23E8EE6684040F19C2D20B4984A4084F23E8EE6684040B952CF82509A4A400F441669E26B4040B952CF82509A4A400F441669E26B4040F19C2D20B4984A4084F23E8EE6684040F19C2D20B4984A40
441	Мглин	1	2	104	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
31906	Луговец	1	2	104	32.656222	32.679219000000003	53.148966999999999	53.130634000000001	0103000020E6100000010000000500000036751E15FF53404072DF6A9DB8904A4036751E15FF5340407497C45911934A4032E9EFA5F05640407497C45911934A4032E9EFA5F056404072DF6A9DB8904A4036751E15FF53404072DF6A9DB8904A40
31969	Красные Косары	1	2	104	32.740896999999997	32.749566000000002	53.163212000000001	53.152251	0103000020E610000001000000050000002D5A80B6D55E404043E4F4F57C934A402D5A80B6D55E40404A287D21E4944A40C61858C7F15F40404A287D21E4944A40C61858C7F15F404043E4F4F57C934A402D5A80B6D55E404043E4F4F57C934A40
32102	Католино	1	2	104	32.809851999999999	32.829121000000001	53.280721999999997	53.266925999999998	0103000020E61000000100000005000000D34CF73AA9674040DE3994A12AA24A40D34CF73AA967404044A2D0B2EEA34A40A2B60DA3206A404044A2D0B2EEA34A40A2B60DA3206A4040DE3994A12AA24A40D34CF73AA9674040DE3994A12AA24A40
49225	Дивовка	1	2	104	33.024360999999999	33.052756000000002	53.048045999999999	53.021853999999998	0103000020E610000001000000050000002026E1421E834040B5A4A31CCC824A402026E1421E834040105A0F5F26864A407A5567B5C0864040105A0F5F26864A407A5567B5C0864040B5A4A31CCC824A402026E1421E834040B5A4A31CCC824A40
32464	Деремна	1	2	104	33.119976999999999	33.155127999999998	53.067238000000003	53.047592000000002	0103000020E61000000100000005000000D7A205685B8F40408FC6A17E17864A40D7A205685B8F4040348639419B884A40D158FB3BDB934040348639419B884A40D158FB3BDB9340408FC6A17E17864A40D7A205685B8F40408FC6A17E17864A40
32292	Ветлевка	1	2	104	32.930638999999999	32.953986999999998	53.067227000000003	53.054656000000001	0103000020E61000000100000005000000EAB0C22D1F774040DD43C2F7FE864A40EAB0C22D1F7740404034F3E49A884A4092E7FA3E1C7A40404034F3E49A884A4092E7FA3E1C7A4040DD43C2F7FE864A40EAB0C22D1F774040DD43C2F7FE864A40
32429	Вельжичи	1	2	104	33.089829999999999	33.125304	53.097717000000003	53.077739000000001	0103000020E610000001000000050000008F19A88C7F8B4040D74FFF59F3894A408F19A88C7F8B4040B2A19BFD818C4A406C0723F609904040B2A19BFD818C4A406C0723F609904040D74FFF59F3894A408F19A88C7F8B4040D74FFF59F3894A40
31764	Великая Дуброва	1	2	104	32.654812	32.686109000000002	53.003937999999998	52.986148999999997	0103000020E61000000100000005000000A1832EE1D0534040D6FD63213A7E4A40A1832EE1D0534040179B560A81804A40E23E726BD2574040179B560A81804A40E23E726BD2574040D6FD63213A7E4A40A1832EE1D0534040D6FD63213A7E4A40
49057	Быковка	1	2	104	32.836773999999998	32.859501999999999	53.113714000000002	53.096809	0103000020E61000000100000005000000511212691B6B4040AF7AC03C648C4A40511212691B6B4040768C2B2E8E8E4A405D6C5A29046E4040768C2B2E8E8E4A405D6C5A29046E4040AF7AC03C648C4A40511212691B6B4040AF7AC03C648C4A40
31534	Бурчак	1	2	104	32.888705999999999	32.905343000000002	52.946584000000001	52.93186	0103000020E6100000010000000500000026E1421EC1714040AC39403047774A4026E1421EC17140405C751DAA29794A40CE548847E27340405C751DAA29794A40CE548847E2734040AC39403047774A4026E1421EC1714040AC39403047774A40
31408	Яловка	1	2	1899	31.618506	31.660430000000002	52.841672000000003	52.815576999999998	0103000020E610000001000000050000003961C268569E3F40552FBFD364684A403961C268569E3F40BEFA78E8BB6B4A401B4CC3F011A93F40BEFA78E8BB6B4A401B4CC3F011A93F40552FBFD364684A403961C268569E3F40552FBFD364684A40
30861	Фошное	1	2	1899	31.348275000000001	31.377192000000001	53.070922000000003	53.055824999999999	0103000020E61000000100000005000000B003E78C28593F404CA60A4625874A40B003E78C28593F409148DBF813894A401650A8A78F603F409148DBF813894A401650A8A78F603F404CA60A4625874A40B003E78C28593F404CA60A4625874A40
31426	Увелье	1	2	1899	31.638888999999999	31.670321000000001	52.794007999999998	52.773539999999997	0103000020E610000001000000050000002EC6C03A8EA33F40EC12D55B03634A402EC6C03A8EA33F409561DC0DA2654A4070D234289AAB3F409561DC0DA2654A4070D234289AAB3F40EC12D55B03634A402EC6C03A8EA33F40EC12D55B03634A40
48576	Селец	1	2	1899	31.677786000000001	31.698392999999999	52.971656000000003	52.950105000000001	0103000020E61000000100000005000000C9AF1F6283AD3F400F62670A9D794A40C9AF1F6283AD3F40297B4B395F7C4A405DC136E2C9B23F40297B4B395F7C4A405DC136E2C9B23F400F62670A9D794A40C9AF1F6283AD3F400F62670A9D794A40
48785	Перелазы	1	2	1899	31.437487000000001	31.494700000000002	53.052360999999998	53.022688000000002	0103000020E61000000100000005000000D76CE525FF6F3F407E01BD70E7824A40D76CE525FF6F3F40FD4AE7C3B3864A40CA54C1A8A47E3F40FD4AE7C3B3864A40CA54C1A8A47E3F407E01BD70E7824A40D76CE525FF6F3F407E01BD70E7824A40
31172	Палужская Рудня	1	2	1899	31.578271000000001	31.599730999999998	53.081093000000003	53.059711	0103000020E61000000100000005000000A839799109943F40111B2C9CA4874A40A839799109943F409F776341618A4A40BA6587F887993F409F776341618A4A40BA6587F887993F40111B2C9CA4874A40A839799109943F40111B2C9CA4874A40
48776	Медведи	1	2	1899	31.674139	31.700468000000001	53.192684	53.169139000000001	0103000020E6100000010000000500000049F59D5F94AC3F4034BDC458A6954A4049F59D5F94AC3F40323B8BDEA9984A4000E5EFDE51B33F40323B8BDEA9984A4000E5EFDE51B33F4034BDC458A6954A4049F59D5F94AC3F4034BDC458A6954A40
31146	Макаричи	1	2	1899	31.622216000000002	31.657385000000001	53.101166999999997	53.076214	0103000020E61000000100000005000000460C3B8C499F3F40A9BF5E61C1894A40460C3B8C499F3F409B374E0AF38C4A4087E123624AA83F409B374E0AF38C4A4087E123624AA83F40A9BF5E61C1894A40460C3B8C499F3F40A9BF5E61C1894A40
51146	Любовша	1	2	1899	31.520913	31.557563999999999	52.994855000000001	52.976346999999997	0103000020E61000000100000005000000AE0FEB8D5A853F401B4641F0F87C4A40AE0FEB8D5A853F408CA19C68577F4A404C6DA983BC8E3F408CA19C68577F4A404C6DA983BC8E3F401B4641F0F87C4A40AE0FEB8D5A853F401B4641F0F87C4A40
30889	Лотаки	1	2	1899	31.561346	31.584047000000002	53.140574000000001	53.122242	0103000020E610000001000000050000008CBD175FB48F3F404C1938A0A58F4A408CBD175FB48F3F407E552E54FE914A40B153AC1A84953F407E552E54FE914A40B153AC1A84953F404C1938A0A58F4A408CBD175FB48F3F404C1938A0A58F4A40
31320	Летяхи	1	2	1899	31.401517999999999	31.441106999999999	52.999662000000001	52.980255999999997	0103000020E610000001000000050000005DC136E2C9663F4098DA5207797D4A405DC136E2C9663F40E886A6ECF47F4A4063096B63EC703F40E886A6ECF47F4A4063096B63EC703F4098DA5207797D4A405DC136E2C9663F4098DA5207797D4A40
31015	Ларневск	1	2	1899	31.503055	31.524875000000002	53.157127000000003	53.141492	0103000020E61000000100000005000000DB166536C8803F40A452EC681C924A40DB166536C8803F40C828CFBC1C944A40EE7C3F355E863F40C828CFBC1C944A40EE7C3F355E863F40A452EC681C924A40DB166536C8803F40A452EC681C924A40
48607	Кургановка	1	2	1899	31.417318999999999	31.434055000000001	53.134971999999998	53.119880999999999	0103000020E61000000100000005000000DAFF006BD56A3F40B534B742588F4A40DAFF006BD56A3F4017F032C346914A4050AA7D3A1E6F3F4017F032C346914A4050AA7D3A1E6F3F40B534B742588F4A40DAFF006BD56A3F40B534B742588F4A40
51102	Красное	1	2	1899	31.334288000000001	31.347386	53.060110999999999	53.050941999999999	0103000020E61000000100000005000000FC71FBE593553F4015FF774485864A40FC71FBE593553F409F909DB7B1874A409816F549EE583F409F909DB7B1874A409816F549EE583F4015FF774485864A40FC71FBE593553F4015FF774485864A40
51031	Красная Гора	1	2	1899	31.566511999999999	31.629663000000001	53.026648000000002	52.982598000000003	0103000020E61000000100000005000000A3CA30EE06913F40B98E71C5C57D4A40A3CA30EE06913F407D40A03369834A405280289831A13F407D40A03369834A405280289831A13F40B98E71C5C57D4A40A3CA30EE06913F40B98E71C5C57D4A40
30723	Колюды	1	2	1899	31.387280000000001	31.432051999999999	53.094349000000001	53.072805000000002	0103000020E61000000100000005000000176536C824633F401EFE9AAC51894A40176536C824633F4085B4C6A0138C4A40E02BBAF59A6E3F4085B4C6A0138C4A40E02BBAF59A6E3F401EFE9AAC51894A40176536C824633F401EFE9AAC51894A40
30959	Кибирщина	1	2	1899	31.588619000000001	31.608059000000001	53.196261	53.175600000000003	0103000020E61000000100000005000000E2CD1ABCAF963F40BC96900F7A964A40E2CD1ABCAF963F40793D98141F994A40D9092FC1A99B3F40793D98141F994A40D9092FC1A99B3F40BC96900F7A964A40E2CD1ABCAF963F40BC96900F7A964A40
30648	Дубенец	1	2	1899	31.705724	31.725954000000002	53.015625	53.000334000000002	0103000020E610000001000000050000009700FC53AAB43F40D789CBF10A804A409700FC53AAB43F400000000000824A408066101FD8B93F400000000000824A408066101FD8B93F40D789CBF10A804A409700FC53AAB43F40D789CBF10A804A40
31512	Городечня	1	2	1899	31.611885999999998	31.631226000000002	52.917538999999998	52.903522000000002	0103000020E6100000010000000500000058E1968FA49C3F40B79BE09BA6734A4058E1968FA49C3F40FBE6FEEA71754A408962F20698A13F40FBE6FEEA71754A408962F20698A13F40B79BE09BA6734A4058E1968FA49C3F40B79BE09BA6734A40
31116	Верхличи	1	2	1899	31.487207999999999	31.519988000000001	52.923527	52.908969999999997	0103000020E610000001000000050000007D59DAA9B97C3F40C685032159744A407D59DAA9B97C3F408BFCFA2136764A40FD4FFEEE1D853F408BFCFA2136764A40FD4FFEEE1D853F40C685032159744A407D59DAA9B97C3F40C685032159744A40
48539	Батуровка	1	2	1899	31.702390999999999	31.723815999999999	53.071350000000002	53.053004999999999	0103000020E61000000100000005000000360186E5CFB33F4022C32ADEC8864A40360186E5CFB33F40E9482EFF21894A40505260014CB93F40E9482EFF21894A40505260014CB93F4022C32ADEC8864A40360186E5CFB33F4022C32ADEC8864A40
29478	Шарово	1	2	1855	34.546807000000001	34.592334000000001	52.414487999999999	52.397939999999998	0103000020E61000000100000005000000A81C93C5FD45414097E2AAB2EF324A40A81C93C5FD454140CF4A5AF10D354A408927BB99D14B4140CF4A5AF10D354A408927BB99D14B414097E2AAB2EF324A40A81C93C5FD45414097E2AAB2EF324A40
29840	Хлебтово	1	2	1855	34.875447000000001	34.894303000000001	52.327415000000002	52.316313000000001	0103000020E61000000100000005000000CF30B5A50E7041405B26C3F17C284A40CF30B5A50E704140249C16BCE8294A407BDB4C8578724140249C16BCE8294A407BDB4C85787241405B26C3F17C284A40CF30B5A50E7041405B26C3F17C284A40
30060	Усожа	1	2	1855	34.702252000000001	34.745666999999997	52.297463999999998	52.282580000000003	0103000020E610000001000000050000007AC6BE64E35941407940D9942B244A407AC6BE64E359414061DEE34C13264A406C5A2904725F414061DEE34C13264A406C5A2904725F41407940D9942B244A407AC6BE64E35941407940D9942B244A40
30146	Угревище	1	2	1855	34.646745000000003	34.680790999999999	52.340139000000001	52.323633999999998	0103000020E61000000100000005000000FFEC478AC8524140D4EFC2D66C294A40FFEC478AC85241400D8CBCAC892B4A40A034D428245741400D8CBCAC892B4A40A034D42824574140D4EFC2D66C294A40FFEC478AC8524140D4EFC2D66C294A40
30171	Тростенчик	1	2	1855	34.658665999999997	34.677970000000002	52.231620999999997	52.219743999999999	0103000020E610000001000000050000005A7EE02A4F54414001BF4692201C4A405A7EE02A4F5441408D08C6C1A51D4A40A6D590B8C75641408D08C6C1A51D4A40A6D590B8C756414001BF4692201C4A405A7EE02A4F54414001BF4692201C4A40
29203	Радогощь	1	2	1855	34.801363000000002	34.848784999999999	52.508603000000001	52.494711000000002	0103000020E61000000100000005000000BB9C12109366414059FCA6B0523F4A40BB9C121093664140E1D231E719414A40ED2AA4FCA46C4140E1D231E719414A40ED2AA4FCA46C414059FCA6B0523F4A40BB9C12109366414059FCA6B0523F4A40
51038	Марьинка	1	2	1855	34.266596	34.959654999999998	52.528998999999999	52.187671000000002	0103000020E61000000100000005000000499F56D11F2241402DB4739A05184A40499F56D11F224140F04E3E3DB6434A40B0389CF9D57A4140F04E3E3DB6434A40B0389CF9D57A41402DB4739A05184A40499F56D11F2241402DB4739A05184A40
29189	Лопандино	1	2	1855	34.756833	34.837287000000003	52.475171000000003	52.437728	0103000020E610000001000000050000004CC45BE7DF60414091459A7807384A404CC45BE7DF604140FA804067D23C4A40D82E6D382C6B4140FA804067D23C4A40D82E6D382C6B414091459A7807384A404CC45BE7DF60414091459A7807384A40
29735	Литиж	1	2	1855	34.787573999999999	34.823487999999998	52.323557000000001	52.294088000000002	0103000020E6100000010000000500000007978E39CF644140B212F3ACA4254A4007978E39CF64414029B2D6506A294A400053060E6869414029B2D6506A294A400053060E68694140B212F3ACA4254A4007978E39CF644140B212F3ACA4254A40
48188	Лагеревка	1	2	1855	34.470388	34.504883	52.455342000000002	52.435532000000002	0103000020E6100000010000000500000026378AAC353C4140452E3883BF374A4026378AAC353C4140643F8BA5483A4A4037A79201A0404140643F8BA5483A4A4037A79201A0404140452E3883BF374A4026378AAC353C4140452E3883BF374A40
28876	Комаричи	1	2	1855	34.770209000000001	34.821306	52.429613000000003	52.399780999999997	0103000020E61000000100000005000000DD0A613596624140F54718062C334A40DD0A613596624140DE770C8FFD364A401901158E20694140DE770C8FFD364A401901158E20694140F54718062C334A40DD0A613596624140F54718062C334A40
30079	Избичня	1	2	1855	34.630467000000003	34.656824	52.300102000000003	52.277996000000002	0103000020E61000000100000005000000871A8524B35041409C35785F95234A40871A8524B35041406BBB09BE69264A402C9D0FCF125441406BBB09BE69264A402C9D0FCF125441409C35785F95234A40871A8524B35041409C35785F95234A40
29584	Игрицкое	1	2	1855	34.414898999999998	34.460721999999997	52.401743000000003	52.375503999999999	0103000020E61000000100000005000000511212691B35414033C2DB8310304A40511212691B354140CF328B506C334A401B4641F0F83A4140CF328B506C334A401B4641F0F83A414033C2DB8310304A40511212691B35414033C2DB8310304A40
48259	Евдокимовка	1	2	1855	34.806410999999997	34.838939000000003	52.229680000000002	52.212946000000002	0103000020E610000001000000050000003C11C4793867414032E884D0411B4A403C11C47938674140CC457C27661D4A40632B685A626B4140CC457C27661D4A40632B685A626B414032E884D0411B4A403C11C4793867414032E884D0411B4A40
48057	Добровольская	1	2	1855	34.561630000000001	34.599314	52.496433000000003	52.473416	0103000020E61000000100000005000000EB39E97DE34741409AB33EE5983C4A40EB39E97DE3474140DDD3D51D8B3F4A4079043752B64C4140DDD3D51D8B3F4A4079043752B64C41409AB33EE5983C4A40EB39E97DE34741409AB33EE5983C4A40
48322	Дерюгино	1	2	1855	34.799799999999998	34.829785999999999	52.378660000000004	52.361069999999998	0103000020E610000001000000050000009FABADD85F6641408AC8B08A372E4A409FABADD85F664140D5264EEE77304A40DE567A6D366A4140D5264EEE77304A40DE567A6D366A41408AC8B08A372E4A409FABADD85F6641408AC8B08A372E4A40
29394	Быхово	1	2	1855	34.659734999999998	34.681733999999999	52.437564000000002	52.412394999999997	0103000020E6100000010000000500000066834C32725441405704FF5BC9344A4066834C327254414017F4DE1802384A401F49490F4357414017F4DE1802384A401F49490F435741405704FF5BC9344A4066834C32725441405704FF5BC9344A40
48222	Бобрик	1	2	1855	34.504497000000001	34.530377000000001	52.455660999999999	52.438585000000003	0103000020E610000001000000050000000EF7915B9340414012C2A38D23384A400EF7915B9340414005888219533A4A407AC6BE64E343414005888219533A4A407AC6BE64E343414012C2A38D23384A400EF7915B9340414012C2A38D23384A40
51074	Асовицы	1	2	1855	34.513263999999999	34.542900000000003	52.339561000000003	52.318719000000002	0103000020E61000000100000005000000691B7FA2B241414092CEC0C8CB284A40691B7FA2B2414140A0FF1EBC762B4A40CC7F48BF7D454140A0FF1EBC762B4A40CC7F48BF7D45414092CEC0C8CB284A40691B7FA2B241414092CEC0C8CB284A40
29313	Аркино	1	2	1855	34.638452999999998	34.675868000000001	52.507297999999999	52.484830000000002	0103000020E610000001000000050000003C84F1D3B8514140520FD1E80E3E4A403C84F1D3B8514140C1A90F24EF404A40DB34B6D782564140C1A90F24EF404A40DB34B6D782564140520FD1E80E3E4A403C84F1D3B8514140520FD1E80E3E4A40
29546	Апажа	1	2	1855	34.637177999999999	34.671278000000001	52.382210999999998	52.363368000000001	0103000020E6100000010000000500000087DD770C8F514140DB34B6D7822E4A4087DD770C8F514140F295404AEC304A401C430070EC554140F295404AEC304A401C430070EC554140DB34B6D7822E4A4087DD770C8F514140DB34B6D7822E4A40
51036	Клинцы	1	2	7100	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
22570	Чемерна	1	2	1279	32.202142000000002	32.216766	52.800606999999999	52.789461000000003	0103000020E61000000100000005000000F392FFC9DF194040D63BDC0E0D654A40F392FFC9DF1940406EF9484A7A664A403F7100FDBE1B40406EF9484A7A664A403F7100FDBE1B4040D63BDC0E0D654A40F392FFC9DF194040D63BDC0E0D654A40
22501	Ущерпье	1	2	1279	31.868929000000001	31.897971999999999	52.728926000000001	52.703963000000002	0103000020E61000000100000005000000C68B852172DE3F400A4CA7751B5A4A40C68B852172DE3F40209A79724D5D4A4045B9347EE1E53F40209A79724D5D4A4045B9347EE1E53F400A4CA7751B5A4A40C68B852172DE3F400A4CA7751B5A4A40
21495	Туросна	1	2	1279	32.191882999999997	32.239708999999998	52.672471999999999	52.649645999999997	0103000020E6100000010000000500000045D4449F8F18404015FDA19927534A4045D4449F8F184040E4BCFF8F13564A4047C7D5C8AE1E4040E4BCFF8F13564A4047C7D5C8AE1E404015FDA19927534A4045D4449F8F18404015FDA19927534A40
21978	Сосновка	1	2	1279	32.347417	32.366731000000001	52.834307000000003	52.821204999999999	0103000020E6100000010000000500000087890629782C4040E527D53E1D694A4087890629782C404075E95F92CA6A4A40F6B6990AF12E404075E95F92CA6A4A40F6B6990AF12E4040E527D53E1D694A4087890629782C4040E527D53E1D694A40
22080	Смотрова Буда	1	2	1279	32.274914000000003	32.310082999999999	52.687213	52.662013999999999	0103000020E61000000100000005000000359BC7613023404040BFEFDFBC544A40359BC761302340406A317898F6574A40D505BCCCB02740406A317898F6574A40D505BCCCB027404040BFEFDFBC544A40359BC7613023404040BFEFDFBC544A40
22521	Смолевичи	1	2	1279	32.200794000000002	32.233474999999999	52.839072000000002	52.821840999999999	0103000020E61000000100000005000000D49D279EB319404087C1FC1532694A40D49D279EB3194040A27E17B6666B4A4080B74082E21D4040A27E17B6666B4A4080B74082E21D404087C1FC1532694A40D49D279EB319404087C1FC1532694A40
22303	Рудня-Голубовка	1	2	1279	32.145798999999997	32.168579999999999	52.704700000000003	52.693376000000001	0103000020E610000001000000050000000E65A88AA912404068EA758BC0584A400E65A88AA9124040E0BE0E9C335A4A403D61890794154040E0BE0E9C335A4A403D6189079415404068EA758BC0584A400E65A88AA912404068EA758BC0584A40
22388	Рожны	1	2	1279	32.067062	32.089556000000002	52.750079999999997	52.728532999999999	0103000020E61000000100000005000000F566D47C950840404487C091405D4A40F566D47C950840401CB1169F02604A408E942D92760B40401CB1169F02604A408E942D92760B40404487C091405D4A40F566D47C950840404487C091405D4A40
22651	Песчанка	1	2	1279	32.181938000000002	32.218184999999998	52.901985000000003	52.891131000000001	0103000020E6100000010000000500000028F38FBE49174040D4B9A29410724A4028F38FBE49174040C53D963E74734A4027BD6F7CED1B4040C53D963E74734A4027BD6F7CED1B4040D4B9A29410724A4028F38FBE49174040D4B9A29410724A40
22210	Первое Мая	1	2	1279	32.183295000000001	32.227204999999998	52.755268999999998	52.735577999999997	0103000020E610000001000000050000009A42E735761740401BD47E6B275E4A409A42E73576174040605793A7AC604A406C3EAE0D151D4040605793A7AC604A406C3EAE0D151D40401BD47E6B275E4A409A42E735761740401BD47E6B275E4A40
22184	Павличи	1	2	1279	32.495199	32.523020000000002	52.725850000000001	52.705719999999999	0103000020E6100000010000000500000086014BAE623F40400A117008555A4A4086014BAE623F40409BE61DA7E85C4A40B493C151F24240409BE61DA7E85C4A40B493C151F24240400A117008555A4A4086014BAE623F40400A117008555A4A40
22282	Ольховка	1	2	1279	32.112659999999998	32.160001999999999	52.749932999999999	52.726858999999997	0103000020E610000001000000050000009FC893A46B0E4040D1E638B7095D4A409FC893A46B0E40407898F6CDFD5F4A40B5A50EF27A1440407898F6CDFD5F4A40B5A50EF27A144040D1E638B7095D4A409FC893A46B0E4040D1E638B7095D4A40
21818	Оболешево	1	2	1279	32.311205999999999	32.327357999999997	52.633794000000002	52.627732000000002	0103000020E61000000100000005000000D4282499D52740408B53AD8559504A40D4282499D527404055336B2920514A40BF0AF0DDE629404055336B2920514A40BF0AF0DDE62940408B53AD8559504A40D4282499D52740408B53AD8559504A40
21642	Медведово	1	2	1279	32.436889000000001	32.497399999999999	52.596803999999999	52.566445000000002	0103000020E61000000100000005000000B77D8FFAEB374040CAFD0E4581484A40B77D8FFAEB3740409D0FCF12644C4A40E4839ECDAA3F40409D0FCF12644C4A40E4839ECDAA3F4040CAFD0E4581484A40B77D8FFAEB374040CAFD0E4581484A40
22133	Мартьяновка	1	2	1279	32.323557999999998	32.374789	52.720739000000002	52.696480999999999	0103000020E61000000100000005000000F92D3A596A29404087A4164A26594A40F92D3A596A294040D3F9F02C415C4A4045F30016F92F4040D3F9F02C415C4A4045F30016F92F404087A4164A26594A40F92D3A596A29404087A4164A26594A40
21424	Малая Топаль	1	2	1279	32.302276999999997	32.339494000000002	52.555993999999998	52.529989999999998	0103000020E610000001000000050000009FAA4203B1264040809A5AB6D6434A409FAA4203B1264040D862B7CF2A474A401898158A742B4040D862B7CF2A474A401898158A742B4040809A5AB6D6434A409FAA4203B1264040809A5AB6D6434A40
21556	Лопатни	1	2	1279	32.116900000000001	32.178075999999997	52.838163999999999	52.810786999999998	0103000020E6100000010000000500000082734694F60E4040CF8250DEC7674A4082734694F60E40409F573CF5486B4A40EB19C231CB1640409F573CF5486B4A40EB19C231CB164040CF8250DEC7674A4082734694F60E4040CF8250DEC7674A40
51154	Коржово-Голубовка	1	2	1279	32.331346000000003	32.377547	52.781117000000002	52.751645000000003	0103000020E6100000010000000500000089D4B48B692A4040D99942E735604A4089D4B48B692A4040C1AC50A4FB634A40F9D9C87553304040C1AC50A4FB634A40F9D9C87553304040D99942E735604A4089D4B48B692A4040D99942E735604A40
21731	Киваи	1	2	1279	32.348962	32.383754000000003	52.615578999999997	52.592762	0103000020E61000000100000005000000FCC56CC9AA2C4040E1270EA0DF4B4A40FCC56CC9AA2C40405C8DEC4ACB4E4A40C7DADFD91E3140405C8DEC4ACB4E4A40C7DADFD91E314040E1270EA0DF4B4A40FCC56CC9AA2C4040E1270EA0DF4B4A40
22368	Ивановщина	1	2	1279	32.214421999999999	32.232433	52.711857999999999	52.696235999999999	0103000020E610000001000000050000007EC51A2E721B40402026E1421E594A407EC51A2E721B4040AFB2B6291E5B4A406EC1525DC01D4040AFB2B6291E5B4A406EC1525DC01D40402026E1421E594A407EC51A2E721B40402026E1421E594A40
22044	Затишье	1	2	1279	32.310056000000003	32.318643999999999	52.828676000000002	52.823104000000001	0103000020E61000000100000005000000DCF63DEAAF274040789ACC785B694A40DCF63DEAAF274040747D1F0E126A4A4087889B53C9284040747D1F0E126A4A4087889B53C9284040789ACC785B694A40DCF63DEAAF274040789ACC785B694A40
47779	Займище	1	2	1279	32.183286000000003	32.255429999999997	52.736178000000002	52.709086999999997	0103000020E6100000010000000500000047E867EA751740406682E15CC35A4A4047E867EA751740407104A9143B5E4A40693524EEB12040407104A9143B5E4A40693524EEB12040406682E15CC35A4A4047E867EA751740406682E15CC35A4A40
21697	Душкино	1	2	1279	32.414081000000003	32.440078	52.633439000000003	52.617809999999999	0103000020E610000001000000050000008F72309B003540402592E865144F4A408F72309B003540406781768714514A4034D8D479543840406781768714514A4034D8D479543840402592E865144F4A408F72309B003540402592E865144F4A40
21580	Гута Корецкая	1	2	1279	32.023476000000002	32.046086000000003	52.851598000000003	52.839573000000001	0103000020E61000000100000005000000D61EF6420103404064CDC820776B4A40D61EF6420103404065ABCB29016D4A40D8666325E605404065ABCB29016D4A40D8666325E605404064CDC820776B4A40D61EF6420103404064CDC820776B4A40
21461	Гулевка	1	2	1279	32.212248000000002	32.245009000000003	52.621211000000002	52.600546000000001	0103000020E610000001000000050000001A5245F12A1B40402FDFFAB0DE4C4A401A5245F12A1B40402E7590D7834F4A40E31C75745C1F40402E7590D7834F4A40E31C75745C1F40402FDFFAB0DE4C4A401A5245F12A1B40402FDFFAB0DE4C4A40
21948	Вьюнка	1	2	1279	32.271006	32.289413000000003	52.803466	52.794117	0103000020E6100000010000000500000088821953B02240404C1938A0A5654A4088821953B022404056B950F9D7664A40C504357C0B25404056B950F9D7664A40C504357C0B2540404C1938A0A5654A4088821953B02240404C1938A0A5654A40
51054	Веприно	1	2	1279	31.937992000000001	31.972864999999999	52.702511999999999	52.691721999999999	0103000020E61000000100000005000000DEE8633E20F03F403CF6B3588A584A40DEE8633E20F03F401686C8E9EB594A404C6C3EAE0DF93F401686C8E9EB594A404C6C3EAE0DF93F403CF6B3588A584A40DEE8633E20F03F403CF6B3588A584A40
21347	Великая Топаль	1	2	1279	32.333008	32.391309	52.552162000000003	52.525218000000002	0103000020E6100000010000000500000037A79201A02A4040A1A2EA573A434A4037A79201A02A4040070C923EAD464A40B3D0CE6916324040070C923EAD464A40B3D0CE6916324040A1A2EA573A434A4037A79201A02A4040A1A2EA573A434A40
21833	Бутовск	1	2	1279	32.368482999999998	32.437195000000003	52.590857999999997	52.570715	0103000020E61000000100000005000000E41071732A2F4040172B6A300D494A40E41071732A2F40403C4A253CA14B4A40C47C7901F63740403C4A253CA14B4A40C47C7901F6374040172B6A300D494A40E41071732A2F4040172B6A300D494A40
28639	Ардонь	1	2	1279	32.287365000000001	32.333852999999998	52.744028999999998	52.725718999999998	0103000020E61000000100000005000000ED815660C8244040FC8A355CE45C4A40ED815660C824404046239F573C5F4A40F355F2B1BB2A404046239F573C5F4A40F355F2B1BB2A4040FC8A355CE45C4A40ED815660C8244040FC8A355CE45C4A40
27563	Шумиловка	1	2	1784	32.184210999999998	32.204332999999998	52.138542999999999	52.122345000000003	0103000020E610000001000000050000001F48DE399417404021EA3E00A90F4A401F48DE39941740407C0BEBC6BB114A402D3F7095271A40407C0BEBC6BB114A402D3F7095271A404021EA3E00A90F4A401F48DE399417404021EA3E00A90F4A40
27728	Чуровичи	1	2	1784	31.977715	32.027661999999999	52.182364999999997	52.156497999999999	0103000020E6100000010000000500000003CFBD874BFA3F40D8F15F2008144A4003CFBD874BFA3F40AF777FBC57174A40C5ABAC6D8A034040AF777FBC57174A40C5ABAC6D8A034040D8F15F2008144A4003CFBD874BFA3F40D8F15F2008144A40
51124	Чолхов	1	2	1784	32.043543999999997	32.092771999999997	52.263409000000003	52.231670999999999	0103000020E61000000100000005000000F0F78BD9920540403F373465A71D4A40F0F78BD9920540406D3CD862B7214A4004FEF0F3DF0B40406D3CD862B7214A4004FEF0F3DF0B40403F373465A71D4A40F0F78BD9920540403F373465A71D4A40
26673	Чернооково	1	2	1784	32.408341	32.449241000000001	52.423698999999999	52.377346000000003	0103000020E61000000100000005000000D74E94844434404062A3ACDF4C304A40D74E948444344040882CD2C43B364A40DC82A5BA80394040882CD2C43B364A40DC82A5BA8039404062A3ACDF4C304A40D74E94844434404062A3ACDF4C304A40
26241	Хохловка	1	2	1784	32.208367000000003	32.239224	52.440753000000001	52.428196999999997	0103000020E61000000100000005000000674815C5AB1A4040669FC728CF364A40674815C5AB1A4040944E24986A384A408B355CE49E1E4040944E24986A384A408B355CE49E1E4040669FC728CF364A40674815C5AB1A4040669FC728CF364A40
27696	Хоромное	1	2	1784	32.000596000000002	32.063468999999998	52.077699000000003	52.063195	0103000020E6100000010000000500000014419C8713004040A72215C616084A4014419C871300404049F7730AF2094A40A8A78FC01F08404049F7730AF2094A40A8A78FC01F084040A72215C616084A4014419C8713004040A72215C616084A40
27277	Фоевичи	1	2	1784	31.952850000000002	31.989177999999999	52.253067000000001	52.230677999999997	0103000020E610000001000000050000005DFE43FAEDF33F400EF450DB861D4A405DFE43FAEDF33F403259DC7F64204A4035ECF7C43AFD3F403259DC7F64204A4035ECF7C43AFD3F400EF450DB861D4A405DFE43FAEDF33F400EF450DB861D4A40
26361	Сытая Буда	1	2	1784	32.236358000000003	32.286898000000001	52.498241999999998	52.469016000000003	0103000020E61000000100000005000000F1129CFA401E40407FA65EB7083C4A40F1129CFA401E40402FBFD364C63F4A40D7A4DB12B92440402FBFD364C63F4A40D7A4DB12B92440407FA65EB7083C4A40F1129CFA401E40407FA65EB7083C4A40
27055	Сушаны	1	2	1784	32.298152999999999	32.322462000000002	52.199910000000003	52.190029000000003	0103000020E61000000100000005000000261AA4E0292640405325CADE52184A40261AA4E0292640405A12A0A696194A40F419506F462940405A12A0A696194A40F419506F462940405325CADE52184A40261AA4E0292640405325CADE52184A40
26967	Старый Ропск	1	2	1784	32.240805000000002	32.275157	52.320596000000002	52.300857000000001	0103000020E610000001000000050000004DDBBFB2D21E4040E7E26F7B82264A404DDBBFB2D21E40403D9D2B4A09294A40FB213658382340403D9D2B4A09294A40FB21365838234040E7E26F7B82264A404DDBBFB2D21E4040E7E26F7B82264A40
27835	Старые Юрковичи	1	2	1784	31.841100000000001	31.867079	52.181592000000002	52.153702000000003	0103000020E6100000010000000500000065AA605452D73F4037AAD381AC134A4065AA605452D73F408D9B1A683E174A40630CACE3F8DD3F408D9B1A683E174A40630CACE3F8DD3F4037AAD381AC134A4065AA605452D73F4037AAD381AC134A40
27480	Соловьевка	1	2	1784	32.167439999999999	32.200749000000002	52.210231	52.181460000000001	0103000020E61000000100000005000000680586AC6E1540401EC4CE143A174A40680586AC6E1540407DCD72D9E81A4A4034DAAA24B21940407DCD72D9E81A4A4034DAAA24B21940401EC4CE143A174A40680586AC6E1540401EC4CE143A174A40
27095	Сачковичи	1	2	1784	32.201844999999999	32.241810999999998	52.357066000000003	52.330938000000003	0103000020E6100000010000000500000039EE940ED61940407880272D5C2A4A4039EE940ED6194040BC41B456B42D4A401268B0A9F31E4040BC41B456B42D4A401268B0A9F31E40407880272D5C2A4A4039EE940ED61940407880272D5C2A4A40
26389	Рубежное	1	2	1784	32.278740999999997	32.313747999999997	52.497188999999999	52.469855000000003	0103000020E61000000100000005000000F486FBC8AD234040596E6935243C4A40F486FBC8AD23404029779FE3A33F4A40BB97FBE42828404029779FE3A33F4A40BB97FBE428284040596E6935243C4A40F486FBC8AD234040596E6935243C4A40
26595	Пруска	1	2	1784	32.354782999999998	32.373181000000002	52.502555999999998	52.486749000000003	0103000020E61000000100000005000000A0168387692D40402C2E8ECA4D3E4A40A0168387692D40404C3448C153404A408A3E1F65C42F40404C3448C153404A408A3E1F65C42F40402C2E8ECA4D3E4A40A0168387692D40402C2E8ECA4D3E4A40
26454	Плавна	1	2	1784	32.407955000000001	32.444156999999997	52.465575999999999	52.446714999999998	0103000020E61000000100000005000000AE9E93DE37344040FAD005F52D394A40AE9E93DE37344040B8E68EFE973B4A400DA5F622DA384040B8E68EFE973B4A400DA5F622DA384040FAD005F52D394A40AE9E93DE37344040FAD005F52D394A40
26922	Новый Ропск	1	2	1784	32.282198999999999	32.334113000000002	52.319026999999998	52.284404000000002	0103000020E6100000010000000500000061FBC9181F244040016DAB5967244A4061FBC9181F2440403FC571E0D5284A409015FC36C42A40403FC571E0D5284A409015FC36C42A4040016DAB5967244A4061FBC9181F244040016DAB5967244A40
27859	Новые Юрковичи	1	2	1784	31.849688	31.872819	52.119889999999998	52.111820999999999	0103000020E61000000100000005000000BCCD1B2785D93F40C5008926500E4A40BCCD1B2785D93F40088F368E580F4A40D253E41071DF3F40088F368E580F4A40D253E41071DF3F40C5008926500E4A40BCCD1B2785D93F40C5008926500E4A40
26762	Могилевцы	1	2	1784	32.267180000000003	32.293275999999999	52.389681000000003	52.368262999999999	0103000020E61000000100000005000000991249F432224040D6A9F23D232F4A40991249F432224040B16F2711E1314A40D15966118A254040B16F2711E1314A40D15966118A254040D6A9F23D232F4A40991249F432224040D6A9F23D232F4A40
26212	Митьковка	1	2	1784	32.135719999999999	32.177185999999999	52.438552000000001	52.424858	0103000020E61000000100000005000000E1B4E0455F114040D4B837BF61364A40E1B4E0455F11404036CCD07822384A408FA7E507AE16404036CCD07822384A408FA7E507AE164040D4B837BF61364A40E1B4E0455F114040D4B837BF61364A40
26843	Любечане	1	2	1784	32.340724999999999	32.371518999999999	52.346691	52.321708000000001	0103000020E61000000100000005000000FDF675E09C2B4040486E4DBA2D294A40FDF675E09C2B4040A568E55E602C4A40DB6B41EF8D2F4040A568E55E602C4A40DB6B41EF8D2F4040486E4DBA2D294A40FDF675E09C2B4040486E4DBA2D294A40
26744	Лобановка	1	2	1784	32.311079999999997	32.342835999999998	52.420349000000002	52.398918000000002	0103000020E6100000010000000500000047382D78D127404093E4B9BE0F334A4047382D78D127404002F4FBFECD354A401BF2CF0CE22B404002F4FBFECD354A401BF2CF0CE22B404093E4B9BE0F334A4047382D78D127404093E4B9BE0F334A40
26291	Лакомая Буда	1	2	1784	32.127321000000002	32.155338999999998	52.495342000000001	52.474836000000003	0103000020E61000000100000005000000098CF50D4C104040537B116DC73C4A40098CF50D4C104040E92ADD5D673F4A408C65FA25E2134040E92ADD5D673F4A408C65FA25E2134040537B116DC73C4A40098CF50D4C104040537B116DC73C4A40
27339	Куршановичи	1	2	1784	32.092807999999998	32.134912	52.190022999999997	52.164563999999999	0103000020E610000001000000050000005167EE21E10B4040AA0CE36E10154A405167EE21E10B4040703E75AC52184A4042EBE1CB44114040703E75AC52184A4042EBE1CB44114040AA0CE36E10154A405167EE21E10B4040AA0CE36E10154A40
26509	Курозново	1	2	1784	32.437373999999998	32.457973000000003	52.470629000000002	52.450859000000001	0103000020E61000000100000005000000730F09DFFB374040BB0D6ABFB5394A40730F09DFFB3740404CC631923D3C4A40BBB9F8DB9E3A40404CC631923D3C4A40BBB9F8DB9E3A4040BB0D6ABFB5394A40730F09DFFB374040BB0D6ABFB5394A40
51077	Красный Бор	1	2	1784	32.271222000000002	32.303939	52.155459	52.140765000000002	0103000020E6100000010000000500000055FA0967B7224040F2B5679604124A4055FA0967B7224040376F9C14E6134A404E7D2079E7264040376F9C14E6134A404E7D2079E7264040F2B5679604124A4055FA0967B7224040F2B5679604124A40
51141	Крапивна	1	2	1784	32.129531	32.160837000000001	52.265123000000003	52.247073999999998	0103000020E61000000100000005000000BA68C8789410404090D8EE1EA01F4A40BA68C878941040406E35EB8CEF214A404E7E8B4E961440406E35EB8CEF214A404E7E8B4E9614404090D8EE1EA01F4A40BA68C8789410404090D8EE1EA01F4A40
25913	Климово	1	2	1784	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
27585	Кирилловка	1	2	1784	32.146742000000003	32.175417000000003	52.117229999999999	52.093538000000002	0103000020E610000001000000050000008E791D71C812404075779D0DF90B4A408E791D71C8124040170E8464010F4A40CB14731074164040170E8464010F4A40CB1473107416404075779D0DF90B4A408E791D71C812404075779D0DF90B4A40
51048	Каменский Хутор	1	2	1784	32.227133000000002	32.291739999999997	52.149790000000003	52.123472999999997	0103000020E61000000100000005000000D36BB3B1121D4040317898F6CD0F4A40D36BB3B1121D404049A297512C134A40AF777FBC5725404049A297512C134A40AF777FBC57254040317898F6CD0F4A40D36BB3B1121D4040317898F6CD0F4A40
26523	Каменка	1	2	1784	32.345908000000001	32.369992000000003	52.472006	52.454914000000002	0103000020E610000001000000050000005FB69DB6462C40400C3F389F3A3A4A405FB69DB6462C404005C24EB16A3C4A400DE4D9E55B2F404005C24EB16A3C4A400DE4D9E55B2F40400C3F389F3A3A4A405FB69DB6462C40400C3F389F3A3A4A40
26651	Истопки	1	2	1784	32.443913999999999	32.464782	52.428032000000002	52.408983999999997	0103000020E61000000100000005000000471E882CD23840402B4B749659344A40471E882CD23840401CD2A8C0C9364A407EE200FA7D3B40401CD2A8C0C9364A407EE200FA7D3B40402B4B749659344A40471E882CD23840402B4B749659344A40
27410	Забрама	1	2	1784	32.294910999999999	32.309795999999999	52.141295999999997	52.132500999999998	0103000020E61000000100000005000000861DC6A4BF254040F9D7F2CAF5104A40861DC6A4BF2540401E87C1FC15124A403F373465A72740401E87C1FC15124A403F373465A7274040F9D7F2CAF5104A40861DC6A4BF254040F9D7F2CAF5104A40
51052	Гетманская Буда	1	2	1784	32.080582	32.109642000000001	52.301071999999998	52.281655000000001	0103000020E61000000100000005000000B952CF82500A4040A0E062450D244A40B952CF82500A4040E3DEFC8689264A404F22C2BF080E4040E3DEFC8689264A404F22C2BF080E4040A0E062450D244A40B952CF82500A4040A0E062450D244A40
27114	Воробьёвка	1	2	1784	32.039150999999997	32.066685	52.334234000000002	52.322330000000001	0103000020E61000000100000005000000874D64E6020540408542041C42294A40874D64E6020540400B9B012EC82A4A401F115322890840400B9B012EC82A4A401F115322890840408542041C42294A40874D64E6020540408542041C42294A40
27646	Вишнёвый	1	2	1784	32.063630000000003	32.089978000000002	52.144474000000002	52.127060999999998	0103000020E61000000100000005000000B2852007250840406CCCEB8843104A40B285200725084040A88FC01F7E124A4004AE2B66840B4040A88FC01F7E124A4004AE2B66840B40406CCCEB8843104A40B2852007250840406CCCEB8843104A40
26826	Брахлов	1	2	1784	32.442791	32.471294999999998	52.371952	52.348413000000001	0103000020E6100000010000000500000048FB1F60AD384040294014CC982C4A4048FB1F60AD38404045D7851F9C2F4A4058E20165533C404045D7851F9C2F4A4058E20165533C4040294014CC982C4A4048FB1F60AD384040294014CC982C4A40
25133	Ширковка	1	2	1746	32.835436000000001	32.854336000000004	53.327057000000003	53.315911999999997	0103000020E6100000010000000500000056F31C91EF6A4040FC34EECD6FA84A4056F31C91EF6A4040C576F700DDA94A40D2E5CDE15A6D4040C576F700DDA94A40D2E5CDE15A6D4040FC34EECD6FA84A4056F31C91EF6A4040FC34EECD6FA84A40
25474	Харитоновка	1	2	1746	32.999018999999997	33.013185999999997	53.408150999999997	53.392361000000001	0103000020E61000000100000005000000938AC6DADF7F4040E99C9FE238B24A40938AC6DADF7F4040336ABE4A3EB44A40ED612F14B0814040336ABE4A3EB44A40ED612F14B0814040E99C9FE238B24A40938AC6DADF7F4040E99C9FE238B24A40
24907	Строительная Слобода	1	2	1746	33.139083999999997	33.163913999999998	53.171756999999999	53.155340000000002	0103000020E61000000100000005000000CCB22781CD9140405DE15D2EE2934A40CCB22781CD914040F6ED2422FC954A40A3AD4A22FB944040F6ED2422FC954A40A3AD4A22FB9440405DE15D2EE2934A40CCB22781CD9140405DE15D2EE2934A40
25048	Старая Мармазовка	1	2	1746	33.065494000000001	33.090845000000002	53.493980000000001	53.475349999999999	0103000020E61000000100000005000000C80A7E1B62884040A913D044D8BC4A40C80A7E1B62884040657094BC3ABF4A40A80018CFA08B4040657094BC3ABF4A40A80018CFA08B4040A913D044D8BC4A40C80A7E1B62884040A913D044D8BC4A40
25786	Синицкое	1	2	1746	33.343136999999999	33.379168	53.473469000000001	53.461793999999998	0103000020E610000001000000050000001686C8E9EBAB404098BED7101CBB4A401686C8E9EBAB4040BD55D7A19ABC4A4049D8B79388B04040BD55D7A19ABC4A4049D8B79388B0404098BED7101CBB4A401686C8E9EBAB404098BED7101CBB4A40
25181	Семиричи	1	2	1746	32.869320000000002	32.880343000000003	53.420912999999999	53.390627000000002	0103000020E610000001000000050000001EE1B4E0456F4040A1F7C61000B24A401EE1B4E0456F40400ABB287AE0B54A409B215514AF7040400ABB287AE0B54A409B215514AF704040A1F7C61000B24A401EE1B4E0456F4040A1F7C61000B24A40
48489	Пушкино	1	2	1746	33.377237000000001	33.386426999999998	53.353993000000003	53.349494	0103000020E61000000100000005000000ABEB504D49B04040F9122A38BCAC4A40ABEB504D49B04040A80183A44FAD4A404CA59F7076B14040A80183A44FAD4A404CA59F7076B14040F9122A38BCAC4A40ABEB504D49B04040F9122A38BCAC4A40
25831	Павлинки	1	2	1746	33.213177000000002	33.241762000000001	53.495710000000003	53.482199000000001	0103000020E6100000010000000500000034A14962499B4040FB9463B2B8BD4A4034A14962499B40406C26DF6C73BF4A4031B5A50EF29E40406C26DF6C73BF4A4031B5A50EF29E4040FB9463B2B8BD4A4034A14962499B4040FB9463B2B8BD4A40
25692	Новотроицкое	1	2	1746	33.269348999999998	33.290379000000001	53.322533999999997	53.315305000000002	0103000020E61000000100000005000000EB1A2D077AA24040F5A10BEA5BA84A40EB1A2D077AA240408DEC4ACB48A94A40FC389A232BA540408DEC4ACB48A94A40FC389A232BA54040F5A10BEA5BA84A40EB1A2D077AA24040F5A10BEA5BA84A40
25846	Новая Осиновка	1	2	1746	33.311723000000001	33.328279000000002	53.405853	53.395422000000003	0103000020E610000001000000050000009C340D8AE6A74040390F27309DB24A409C340D8AE6A74040E3FDB8FDF2B34A40577BD80B05AA4040E3FDB8FDF2B34A40577BD80B05AA4040390F27309DB24A409C340D8AE6A74040390F27309DB24A40
25714	Николаевка	1	2	1746	33.278350000000003	33.302397999999997	53.348827	53.335177000000002	0103000020E61000000100000005000000BA6B09F9A0A340408AAF7614E7AA4A40BA6B09F9A0A340401C7BF65CA6AC4A401A3048FAB4A640401C7BF65CA6AC4A401A3048FAB4A640408AAF7614E7AA4A40BA6B09F9A0A340408AAF7614E7AA4A40
25647	Неделька	1	2	1746	33.309179999999998	33.334404999999997	53.271735	53.257015000000003	0103000020E61000000100000005000000E449D23593A740406DCA15DEE5A04A40E449D23593A74040DB166536C8A24A40374F75C8CDAA4040DB166536C8A24A40374F75C8CDAA40406DCA15DEE5A04A40E449D23593A740406DCA15DEE5A04A40
25562	Мужиново	1	2	1746	33.238284999999998	33.271163999999999	53.269446000000002	53.247188000000001	0103000020E610000001000000050000004D10751F809E404059FB3BDBA39F4A404D10751F809E4040DE04DF347DA24A4020ED7F80B5A24040DE04DF347DA24A4020ED7F80B5A2404059FB3BDBA39F4A404D10751F809E404059FB3BDBA39F4A40
25021	Лутна	1	2	1746	33.079408999999998	33.107391999999997	53.457194000000001	53.438209999999998	0103000020E610000001000000050000000801F9122A8A4040DC63E94317B84A400801F9122A8A4040B6F63E5585BA4A400FED6305BF8D4040B6F63E5585BA4A400FED6305BF8D4040DC63E94317B84A400801F9122A8A4040DC63E94317B84A40
24971	Коршево	1	2	1746	33.232123000000001	33.258164999999998	53.227575999999999	53.210295000000002	0103000020E6100000010000000500000020D3DA34B69D404094C151F2EA9A4A4020D3DA34B69D404060ADDA35219D4A4065FCFB8C0BA1404060ADDA35219D4A4065FCFB8C0BA1404094C151F2EA9A4A4020D3DA34B69D404094C151F2EA9A4A40
51100	Коммуна	1	2	1746	32.907381999999998	32.920245999999999	53.280113	53.274518999999998	0103000020E61000000100000005000000527DE71725744040B890477023A34A40527DE717257440409C1727BEDAA34A402D23F59ECA7540409C1727BEDAA34A402D23F59ECA754040B890477023A34A40527DE71725744040B890477023A34A40
51024	Клетня	1	2	1746	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
25266	Добрая Корна	1	2	1746	32.951624000000002	32.967272999999999	53.358539	53.345629000000002	0103000020E610000001000000050000005B0BB3D0CE7940404CC631923DAC4A405B0BB3D0CE79404097AB1F9BE4AD4A40E3A6069ACF7B404097AB1F9BE4AD4A40E3A6069ACF7B40404CC631923DAC4A405B0BB3D0CE7940404CC631923DAC4A40
25379	Быстрянка	1	2	1746	33.054606999999997	33.065441	53.316246	53.306539999999998	0103000020E61000000100000005000000FB90B75CFD8640403A75E5B33CA74A40FB90B75CFD864040D3BEB9BF7AA84A40A568E55E60884040D3BEB9BF7AA84A40A568E55E608840403A75E5B33CA74A40FB90B75CFD8640403A75E5B33CA74A40
25241	Болотня	1	2	1746	32.890844000000001	32.909357999999997	53.309817000000002	53.29665	0103000020E610000001000000050000003EEB1A2D07724040E02D90A0F8A54A403EEB1A2D07724040575F5D15A8A74A40902DCBD765744040575F5D15A8A74A40902DCBD765744040E02D90A0F8A54A403EEB1A2D07724040E02D90A0F8A54A40
25552	Алень	1	2	1746	33.146701999999998	33.18329	53.270836000000003	53.259121	0103000020E61000000100000005000000FF209221C7924040795A7EE02AA14A40FF209221C79240402C4A09C1AAA24A4088D7F50B769740402C4A09C1AAA24A4088D7F50B76974040795A7EE02AA14A40FF209221C7924040795A7EE02AA14A40
25111	Алексеевка	1	2	1746	32.925519000000001	32.955936000000001	53.514476000000002	53.500579000000002	0103000020E61000000100000005000000CF691668777640403E0801F912C04A40CF69166877764040D8497D59DAC14A40D788601C5C7A4040D8497D59DAC14A40D788601C5C7A40403E0801F912C04A40CF691668777640403E0801F912C04A40
51053	Акуличи	1	2	1746	33.188600000000001	33.236462000000003	53.203235999999997	53.175896999999999	0103000020E610000001000000050000004703780B24984040753BFBCA83964A404703780B2498404057AF22A3039A4A40965F0663449E404057AF22A3039A4A40965F0663449E4040753BFBCA83964A404703780B24984040753BFBCA83964A40
23388	Юрасово	1	2	1689	35.009700000000002	35.021099999999997	53.088751999999999	53.071328000000001	0103000020E61000000100000005000000B7627FD93D81414001A5A14621894A40B7627FD93D81414030BABC395C8B4A4009F9A067B382414030BABC395C8B4A4009F9A067B382414001A5A14621894A40B7627FD93D81414001A5A14621894A40
23053	Трыковка	1	2	1689	34.874108	34.950913999999997	53.130082999999999	53.104107999999997	0103000020E6100000010000000500000003965CC5E26F414040A03369538D4A4003965CC5E26F4140FE614B8FA6904A407EA7C98CB7794140FE614B8FA6904A407EA7C98CB779414040A03369538D4A4003965CC5E26F414040A03369538D4A40
23721	Теплое	1	2	1689	34.618915000000001	34.634115000000001	53.041328	53.031894999999999	0103000020E610000001000000050000007E00529B384F4140F5F3A62215844A407E00529B384F41405D34643C4A854A40977329AE2A5141405D34643C4A854A40977329AE2A514140F5F3A62215844A407E00529B384F4140F5F3A62215844A40
23196	Согласие	1	2	1689	34.935507999999999	34.965089999999996	53.099241999999997	53.091396000000003	0103000020E61000000100000005000000BC92E4B9BE7741401C7E37DDB28B4A40BC92E4B9BE774140DF313CF6B38C4A402BD9B111887B4140DF313CF6B38C4A402BD9B111887B41401C7E37DDB28B4A40BC92E4B9BE7741401C7E37DDB28B4A40
48187	Семеновка	1	2	1689	35.266078999999998	35.284844999999997	53.073335	53.061816	0103000020E6100000010000000500000081936DE00EA241404D2F3196E9874A4081936DE00EA241407A53910A63894A40EDB60BCD75A441407A53910A63894A40EDB60BCD75A441404D2F3196E9874A4081936DE00EA241404D2F3196E9874A40
24192	Ружное	1	2	1689	34.749673999999999	34.786541	52.969898999999998	52.954483000000003	0103000020E61000000100000005000000AC545051F55F414043CBBA7F2C7A4A40AC545051F55F414028B682A6257C4A4048FB1F60AD64414028B682A6257C4A4048FB1F60AD64414043CBBA7F2C7A4A40AC545051F55F414043CBBA7F2C7A4A40
23997	Песочня	1	2	1689	34.976399999999998	34.989767000000001	53.176955	53.165619	0103000020E610000001000000050000003EE8D9ACFA7C4140514CDE0033954A403EE8D9ACFA7C41408DEE2076A6964A407CD45FAFB07E41408DEE2076A6964A407CD45FAFB07E4140514CDE0033954A403EE8D9ACFA7C4140514CDE0033954A40
24035	Новгородский	1	2	1689	34.998866999999997	35.010769000000003	53.227614000000003	53.219371000000002	0103000020E61000000100000005000000DD06B5DFDA7F41406D585359149C4A40DD06B5DFDA7F41404E0E9F74229D4A40C367EBE0608141404E0E9F74229D4A40C367EBE0608141406D585359149C4A40DD06B5DFDA7F41406D585359149C4A40
23933	Мылинка	1	2	1689	34.824503999999997	34.864209000000002	53.184688000000001	53.164042999999999	0103000020E61000000100000005000000E9B5D95889694140A1116C5CFF944A40E9B5D9588969414059FB3BDBA3974A4056F487669E6E414059FB3BDBA3974A4056F487669E6E4140A1116C5CFF944A40E9B5D95889694140A1116C5CFF944A40
47700	Московский	1	2	1689	35.024531000000003	35.030253999999999	53.315353000000002	53.307816000000003	0103000020E610000001000000050000007D5EF1D423834140C097C28366A74A407D5EF1D42383414006D9B27C5DA84A405E49F25CDF83414006D9B27C5DA84A405E49F25CDF834140C097C28366A74A407D5EF1D423834140C097C28366A74A40
22980	Масловка	1	2	1689	35.01173	35.057329000000003	53.131374000000001	53.114632999999998	0103000020E61000000100000005000000E8305F5E808141406C054D4BAC8E4A40E8305F5E80814140B9C5FCDCD0904A40630E828E56874140B9C5FCDCD0904A40630E828E568741406C054D4BAC8E4A40E8305F5E808141406C054D4BAC8E4A40
51081	Мальтино	1	2	1689	34.976560999999997	34.997231999999997	53.157536999999998	53.133631999999999	0103000020E6100000010000000500000047C66AF3FF7C41407BD976DA1A914A4047C66AF3FF7C41407974232C2A944A402843554CA57F41407974232C2A944A402843554CA57F41407BD976DA1A914A4047C66AF3FF7C41407BD976DA1A914A40
51043	Мазнево	1	2	1689	34.944887000000001	34.962539	53.084695000000004	53.070371000000002	0103000020E6100000010000000500000031B5A50EF27841401DCBBBEA01894A4031B5A50EF27841403F912749D78A4A40F10F5B7A347B41403F912749D78A4A40F10F5B7A347B41401DCBBBEA01894A4031B5A50EF27841401DCBBBEA01894A40
24108	Лужецкая	1	2	1689	34.766579999999998	34.806573	53.017828999999999	53.004950999999998	0103000020E6100000010000000500000043E21E4B1F6241408F8AFF3BA2804A4043E21E4B1F624140CFF57D3848824A40166BB8C83D674140CFF57D3848824A40166BB8C83D6741408F8AFF3BA2804A4043E21E4B1F6241408F8AFF3BA2804A40
51072	Куприно	1	2	1689	34.842685000000003	34.860579999999999	52.929113000000001	52.911679999999997	0103000020E6100000010000000500000036EA211ADD6B4140693524EEB1744A4036EA211ADD6B4140ECA4BE2CED764A40BCCB457C276E4140ECA4BE2CED764A40BCCB457C276E4140693524EEB1744A4036EA211ADD6B4140693524EEB1744A40
51066	Коптилово	1	2	1689	34.773389000000002	34.798631999999998	53.093862000000001	53.084392000000001	0103000020E61000000100000005000000070B2769FE624140A305685BCD8A4A40070B2769FE624140282B86AB038C4A4000C5C89239664140282B86AB038C4A4000C5C89239664140A305685BCD8A4A40070B2769FE624140A305685BCD8A4A40
22361	Карачев	1	2	1689	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
23841	Дунаевский	1	2	1689	35.236660000000001	35.248579999999997	53.051699999999997	53.042059000000002	0103000020E61000000100000005000000BC22F8DF4A9E414051C0763062854A40BC22F8DF4A9E4140029A081B9E864A4047382D78D19F4140029A081B9E864A4047382D78D19F414051C0763062854A40BC22F8DF4A9E414051C0763062854A40
51107	Дроново	1	2	1689	35.184997000000003	35.205587000000001	53.063623	53.050519999999999	0103000020E61000000100000005000000D76D50FBAD9741409FE5797077864A40D76D50FBAD974140FF2268CC24884A40CBBDC0AC509A4140FF2268CC24884A40CBBDC0AC509A41409FE5797077864A40D76D50FBAD9741409FE5797077864A40
51068	Гощь	1	2	1689	34.640861000000001	34.663238	53.027659999999997	53.011377000000003	0103000020E610000001000000050000001424B6BB075241409B7631CD74814A401424B6BB0752414024B4E55C8A834A4073BB97FBE454414024B4E55C8A834A4073BB97FBE45441409B7631CD74814A401424B6BB075241409B7631CD74814A40
23640	Верхополье	1	2	1689	34.625571999999998	34.659357	53.080767999999999	53.062356999999999	0103000020E610000001000000050000008BA548BE125041409DD66D50FB874A408BA548BE125041401B48179B568A4A40C0B167CF655441401B48179B568A4A40C0B167CF655441409DD66D50FB874A408BA548BE125041409DD66D50FB874A40
51037	Вельяминово	1	2	1689	35.073912	35.096639000000003	53.052464000000001	53.03763	0103000020E610000001000000050000001764CBF2758941409BAC510FD1844A401764CBF275894140D21BEE23B7864A405342B0AA5E8C4140D21BEE23B7864A405342B0AA5E8C41409BAC510FD1844A401764CBF2758941409BAC510FD1844A40
23454	Бошино	1	2	1689	34.968432	34.995462000000003	53.024718999999997	53.014482000000001	0103000020E610000001000000050000002F336C94F57B4140BA30D28BDA814A402F336C94F57B41407F4B00FE29834A4094347F4C6B7F41407F4B00FE29834A4094347F4C6B7F4140BA30D28BDA814A402F336C94F57B4140BA30D28BDA814A40
23918	Березовка	1	2	1689	34.821710000000003	34.836863999999998	53.158909000000001	53.150533000000003	0103000020E61000000100000005000000E96514CB2D69414001FC53AA44934A40E96514CB2D69414021054F2157944A4091990B5C1E6B414021054F2157944A4091990B5C1E6B414001FC53AA44934A40E96514CB2D69414001FC53AA44934A40
51090	Алымово	1	2	1689	35.166528	35.194842999999999	53.110124999999996	53.092320999999998	0103000020E6100000010000000500000024EF1CCA50954140F4DDAD2CD18B4A4024EF1CCA509541406ABC7493188E4A40616D8C9DF09841406ABC7493188E4A40616D8C9DF0984140F4DDAD2CD18B4A4024EF1CCA50954140F4DDAD2CD18B4A40
51028	Алексеевка	1	2	1689	34.953690000000002	34.960832000000003	52.956974000000002	52.951580999999997	0103000020E61000000100000005000000D9429083127A41405B3FFD67CD794A40D9429083127A4140A88FC01F7E7A4A40A379008BFC7A4140A88FC01F7E7A4A40A379008BFC7A41405B3FFD67CD794A40D9429083127A41405B3FFD67CD794A40
22038	Спиридонова Буда	1	2	1672	31.757251	31.799759000000002	52.299287	52.263888000000001	0103000020E6100000010000000500000001DD9733DBC13F4047E7FC14C7214A4001DD9733DBC13F40198F52094F264A4082AE7D01BDCC3F40198F52094F264A4082AE7D01BDCC3F4047E7FC14C7214A4001DD9733DBC13F4047E7FC14C7214A40
49354	Софиевка	1	2	1672	31.929241999999999	31.950416000000001	52.379021999999999	52.367691000000001	0103000020E61000000100000005000000D311C0CDE2ED3F404B04AA7F102F4A40D311C0CDE2ED3F40753BFBCA83304A405B9885764EF33F40753BFBCA83304A405B9885764EF33F404B04AA7F102F4A40D311C0CDE2ED3F404B04AA7F102F4A40
22292	Рогов	1	2	1672	31.931677000000001	31.960692000000002	52.329909000000001	52.307850000000002	0103000020E61000000100000005000000766F456282EE3F406C09F9A067274A40766F456282EE3F40FAD346753A2A4A40628731E9EFF53F40FAD346753A2A4A40628731E9EFF53F406C09F9A067274A40766F456282EE3F406C09F9A067274A40
22137	Петрятинка	1	2	1672	31.841702000000002	31.870421	52.255443	52.242001000000002	0103000020E6100000010000000500000051FA42C879D73F40B64C86E3F91E4A4051FA42C879D73F40FE7E315BB2204A406AC020E9D3DE3F40FE7E315BB2204A406AC020E9D3DE3F40B64C86E3F91E4A4051FA42C879D73F40B64C86E3F91E4A40
22182	Малые Щербиничи	1	2	1672	31.881119999999999	31.919513999999999	52.305356000000003	52.289653999999999	0103000020E61000000100000005000000FDD98F1491E13F40EA93DC6113254A40FDD98F1491E13F4096D1C8E715274A40D236FE4465EB3F4096D1C8E715274A40D236FE4465EB3F40EA93DC6113254A40FDD98F1491E13F40EA93DC6113254A40
21895	Лысые	1	2	1672	31.624624000000001	31.655759	52.348336000000003	52.329832000000003	0103000020E61000000100000005000000F54BC45BE79F3F404F965AEF372A4A40F54BC45BE79F3F407E022846962C4A40C30E63D2DFA73F407E022846962C4A40C30E63D2DFA73F404F965AEF372A4A40F54BC45BE79F3F404F965AEF372A4A40
49297	Кожановка	1	2	1672	31.811886000000001	31.845223000000001	52.220483000000002	52.206820999999998	0103000020E610000001000000050000008C14CAC2D7CF3F4021904B1C791A4A408C14CAC2D7CF3F40782975C9381C4A40B7D3D68860D83F40782975C9381C4A40B7D3D68860D83F4021904B1C791A4A408C14CAC2D7CF3F4021904B1C791A4A40
51131	Карпиловка	1	2	1672	31.533238000000001	32.051898000000001	52.552571999999998	52.184198000000002	0103000020E6100000010000000500000005FC1A4982883F408BFED0CC93174A4005FC1A4982883F40B857E6ADBA464A40295DFA97A4064040B857E6ADBA464A40295DFA97A40640408BFED0CC93174A4005FC1A4982883F408BFED0CC93174A40
21722	Злынка	1	2	1672	31.703665999999998	31.760242000000002	52.441895000000002	52.409896000000003	0103000020E61000000100000005000000A04E797423B43F407061DD7877344A40A04E797423B43F400AA2EE0390384A40AF0B3F389FC23F400AA2EE0390384A40AF0B3F389FC23F407061DD7877344A40A04E797423B43F407061DD7877344A40
21583	Добродеевка	1	2	1672	31.619403999999999	31.657691	52.490884000000001	52.469307000000001	0103000020E61000000100000005000000F702B342919E3F4056647440123C4A40F702B342919E3F4099107349D53E4A40A0DFF76F5EA83F4099107349D53E4A40A0DFF76F5EA83F4056647440123C4A40F702B342919E3F4056647440123C4A40
21945	Денисковичи	1	2	1672	31.681756	31.728406	52.322049	52.294913999999999	0103000020E610000001000000050000000EDAAB8F87AE3F40F790F0BDBF254A400EDAAB8F87AE3F40D15AD1E638294A40CE35CCD078BA3F40D15AD1E638294A40CE35CCD078BA3F40F790F0BDBF254A400EDAAB8F87AE3F40F790F0BDBF254A40
21640	Вышков	1	2	1672	31.653009999999998	31.704259	52.488005000000001	52.464967000000001	0103000020E6100000010000000500000001F6D1A92BA73F40105CE509843B4A4001F6D1A92BA73F406AA4A5F2763E4A40E6E95C514AB43F406AA4A5F2763E4A40E6E95C514AB43F40105CE509843B4A4001F6D1A92BA73F40105CE509843B4A40
22206	Большие Щербиничи	1	2	1672	31.844873	31.885009	52.328808000000002	52.304133	0103000020E61000000100000005000000FE45D09849D83F40335184D4ED264A40FE45D09849D83F40E3546B61162A4A4069AA27F38FE23F40E3546B61162A4A4069AA27F38FE23F40335184D4ED264A40FE45D09849D83F40335184D4ED264A40
48881	Шамордино	1	2	1016	33.765956000000003	33.784416	53.391303000000001	53.381588000000001	0103000020E610000001000000050000006616A1D80AE24040E54526E0D7B04A406616A1D80AE24040D1E9793716B24A40C53A55BE67E44040D1E9793716B24A40C53A55BE67E44040E54526E0D7B04A406616A1D80AE24040E54526E0D7B04A40
49018	Тросна	1	2	1016	33.770491999999997	33.806739	53.489061999999997	53.470815999999999	0103000020E6100000010000000500000031EA5A7B9FE240407E37DDB243BC4A4031EA5A7B9FE24040B1DB679599BE4A4031B43A3943E74040B1DB679599BE4A4031B43A3943E740407E37DDB243BC4A4031EA5A7B9FE240407E37DDB243BC4A40
51091	Титовка	1	2	1016	33.792653999999999	33.803083000000001	53.629553999999999	53.621035999999997	0103000020E610000001000000050000009485AFAF75E54040BFD18E1B7ECF4A409485AFAF75E540407288B83995D04A409E7C7A6CCBE640407288B83995D04A409E7C7A6CCBE64040BFD18E1B7ECF4A409485AFAF75E54040BFD18E1B7ECF4A40
20516	Ржаница	1	2	1016	33.897756999999999	33.939824999999999	53.443756	53.418197999999997	0103000020E61000000100000005000000A6608DB3E9F2404055A0168387B54A40A6608DB3E9F24040AFB321FFCCB84A404A7B832F4CF84040AFB321FFCCB84A404A7B832F4CF8404055A0168387B54A40A6608DB3E9F2404055A0168387B54A40
47848	Речица	1	2	1016	33.904682999999999	33.937362999999998	53.381920999999998	53.362096999999999	0103000020E61000000100000005000000A31F0DA7CCF34040677DCA3159AE4A40A31F0DA7CCF34040EB538EC9E2B04A407FBDC282FBF74040EB538EC9E2B04A407FBDC282FBF74040677DCA3159AE4A40A31F0DA7CCF34040677DCA3159AE4A40
49023	Поляковка	1	2	1016	33.802140000000001	33.817509999999999	53.508372000000001	53.498351	0103000020E610000001000000050000001F680586ACE64040E6762FF7C9BF4A401F680586ACE64040DF196D5512C14A409413ED2AA4E84040DF196D5512C14A409413ED2AA4E84040E6762FF7C9BF4A401F680586ACE64040E6762FF7C9BF4A40
49100	Петуховка	1	2	1016	33.820734999999999	33.843265000000002	53.625307999999997	53.614167000000002	0103000020E610000001000000050000005ED72FD80DE9404027A435069DCE4A405ED72FD80DE94040ADF6B0170AD04A40446E861BF0EB4040ADF6B0170AD04A40446E861BF0EB404027A435069DCE4A405ED72FD80DE9404027A435069DCE4A40
21333	Олсуфьево	1	2	1016	33.662461	33.693030999999998	53.615561	53.591693999999997	0103000020E610000001000000050000000FF0A485CBD44040A59E05A1BCCB4A400FF0A485CBD44040B6D8EDB3CACE4A409D0E643DB5D84040B6D8EDB3CACE4A409D0E643DB5D84040A59E05A1BCCB4A400FF0A485CBD44040A59E05A1BCCB4A40
20626	Овстуг	1	2	1016	33.847954000000001	33.907494	53.394905999999999	53.358857	0103000020E610000001000000050000009641B5C189EC40406878B306EFAD4A409641B5C189EC4040417FA1478CB24A407AA86DC328F44040417FA1478CB24A407AA86DC328F440406878B306EFAD4A409641B5C189EC40406878B306EFAD4A40
48988	Никольская Слобода	1	2	1016	33.587046999999998	33.616269000000003	53.513587000000001	53.492925	0103000020E61000000100000005000000821B295B24CB4040BE30992A18BF4A40821B295B24CB40404C530438BDC14A40F24410E7E1CE40404C530438BDC14A40F24410E7E1CE4040BE30992A18BF4A40821B295B24CB4040BE30992A18BF4A40
20955	Леденево	1	2	1016	33.658751000000002	33.688628999999999	53.420440999999997	53.409106000000001	0103000020E61000000100000005000000899AE8F351D44040774CDD955DB44A40899AE8F351D44040E272BC02D1B54A40E109BDFE24D84040E272BC02D1B54A40E109BDFE24D84040774CDD955DB44A40899AE8F351D44040774CDD955DB44A40
48768	Латыши	1	2	1016	33.761617000000001	33.773887999999999	53.552869999999999	53.544074999999999	0103000020E61000000100000005000000F08975AA7CE140401DC9E53FA4C54A40F08975AA7CE140404278B471C4C64A40286211C30EE340404278B471C4C64A40286211C30EE340401DC9E53FA4C54A40F08975AA7CE140401DC9E53FA4C54A40
20844	Крыжино	1	2	1016	33.684100999999998	33.705167000000003	53.373493000000003	53.361978999999998	0103000020E6100000010000000500000098141F9F90D740405D6BEF5355AE4A4098141F9F90D7404079245E9ECEAF4A40F69B89E942DA404079245E9ECEAF4A40F69B89E942DA40405D6BEF5355AE4A4098141F9F90D740405D6BEF5355AE4A40
21348	Касилово	1	2	1016	33.854655000000001	33.884273	53.718152000000003	53.696357999999996	0103000020E61000000100000005000000732EC55565ED40406B274A4222D94A40732EC55565ED40404CC79C67ECDB4A402FDE8FDB2FF140404CC79C67ECDB4A402FDE8FDB2FF140406B274A4222D94A40732EC55565ED40406B274A4222D94A40
20737	Задубравье	1	2	1016	33.720374999999997	33.737882999999997	53.429316	53.415187000000003	0103000020E6100000010000000500000091ED7C3F35DC4040B85CFDD824B54A4091ED7C3F35DC404024D3A1D3F3B64A401EA33CF372DE404024D3A1D3F3B64A401EA33CF372DE4040B85CFDD824B54A4091ED7C3F35DC4040B85CFDD824B54A40
8782	Жуковка	1	2	1016	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
40348	Гришина Слобода	1	2	1016	33.788044999999997	33.829555999999997	53.592298	53.573059000000001	0103000020E610000001000000050000005E6397A8DEE44040D8D64FFF59C94A405E6397A8DEE440403CBEBD6BD0CB4A40AC1919E42EEA40403CBEBD6BD0CB4A40AC1919E42EEA4040D8D64FFF59C94A405E6397A8DEE44040D8D64FFF59C94A40
48968	Гостиловка	1	2	1016	33.678153999999999	33.697558000000001	53.487786999999997	53.479872999999998	0103000020E6100000010000000500000067D311C0CDD64040E09D7C7A6CBD4A4067D311C0CDD64040FC34EECD6FBE4A4016889E9449D94040FC34EECD6FBE4A4016889E9449D94040E09D7C7A6CBD4A4067D311C0CDD64040E09D7C7A6CBD4A40
20857	Быковичи	1	2	1016	33.600225999999999	33.630929999999999	53.363596000000001	53.350053000000003	0103000020E61000000100000005000000BD1AA034D4CC4040F06E6589CEAC4A40BD1AA034D4CC40406C7A50508AAE4A405B087250C2D040406C7A50508AAE4A405B087250C2D04040F06E6589CEAC4A40BD1AA034D4CC4040F06E6589CEAC4A40
21005	Белоголовль	1	2	1016	33.601689999999998	33.621965000000003	53.410792000000001	53.392457999999998	0103000020E61000000100000005000000452A8C2D04CD4040DB8651103CB24A40452A8C2D04CD4040AEBA0ED594B44A40DA20938C9CCF4040AEBA0ED594B44A40DA20938C9CCF4040DB8651103CB24A40452A8C2D04CD4040DB8651103CB24A40
47662	Усошки	1	2	1569	33.531433	33.543990999999998	53.155355999999998	53.151224999999997	0103000020E61000000100000005000000F1811DFF05C4404036AB3E575B934A40F1811DFF05C44040629E95B4E2934A40BF28417FA1C54040629E95B4E2934A40BF28417FA1C5404036AB3E575B934A40F1811DFF05C4404036AB3E575B934A40
18895	Страшевичи	1	2	1569	33.872900000000001	33.909362999999999	53.274093000000001	53.256072000000003	0103000020E61000000100000005000000D656EC2FBBEF4040EEB5A0F7C6A04A40D656EC2FBBEF40400188BB7A15A34A40A298BC0166F440400188BB7A15A34A40A298BC0166F44040EEB5A0F7C6A04A40D656EC2FBBEF4040EEB5A0F7C6A04A40
19364	Савлуково	1	2	1569	33.674973999999999	33.720275999999998	53.203370999999997	53.171768	0103000020E610000001000000050000003DD34B8C65D64040EA3F6B7EFC954A403DD34B8C65D6404037FA980F089A4A40FE0B040132DC404037FA980F089A4A40FE0B040132DC4040EA3F6B7EFC954A403DD34B8C65D64040EA3F6B7EFC954A40
19603	Норино	1	2	1569	33.347960999999998	33.366798000000003	53.141140999999998	53.124614999999999	0103000020E6100000010000000500000048A46DFC89AC4040A7CB6262F38F4A4048A46DFC89AC4040F78F85E810924A407E1EA33CF3AE4040F78F85E810924A407E1EA33CF3AE4040A7CB6262F38F4A4048A46DFC89AC4040A7CB6262F38F4A40
19261	Морачево	1	2	1569	33.587622000000003	33.622405000000001	53.308978000000003	53.295498000000002	0103000020E610000001000000050000007F349C3237CB40404704E3E0D2A54A407F349C3237CB40407D9752978CA74A40F6EE8FF7AACF40407D9752978CA74A40F6EE8FF7AACF40404704E3E0D2A54A407F349C3237CB40404704E3E0D2A54A40
19655	Кульнево	1	2	1569	33.531765	33.541097999999998	53.201720000000002	53.191113999999999	0103000020E61000000100000005000000271422E010C4404064E76D6C76984A40271422E010C440407D7901F6D1994A402BF702B342C540407D7901F6D1994A402BF702B342C5404064E76D6C76984A40271422E010C4404064E76D6C76984A40
18978	Комягино	1	2	1569	33.730849999999997	33.761643999999997	53.223441000000001	53.207447999999999	0103000020E610000001000000050000000B24287E8CDD404070CFF3A78D9A4A400B24287E8CDD4040F3CAF5B6999C4A40E998F38C7DE14040F3CAF5B6999C4A40E998F38C7DE1404070CFF3A78D9A4A400B24287E8CDD404070CFF3A78D9A4A40
19447	Колодня	1	2	1569	33.572324000000002	33.597414000000001	53.128554000000001	53.117784	0103000020E61000000100000005000000A35BAFE941C94040FCFECD8B138F4A40A35BAFE941C940408FE21C7574904A401616DC0F78CC40408FE21C7574904A401616DC0F78CC4040FCFECD8B138F4A40A35BAFE941C94040FCFECD8B138F4A40
19193	Княвичи	1	2	1569	33.669790999999996	33.695860000000003	53.302827999999998	53.285378000000001	0103000020E61000000100000005000000DB1324B6BBD54040BB7F2C4487A44A40DB1324B6BBD5404013286211C3A64A401B4CC3F011D9404013286211C3A64A401B4CC3F011D94040BB7F2C4487A44A40DB1324B6BBD54040BB7F2C4487A44A40
51143	Заречная	1	2	1569	33.804673000000001	33.832493999999997	53.251784000000001	53.236685000000001	0103000020E61000000100000005000000B37C5D86FFE64040153AAFB14B9E4A40B37C5D86FFE64040FAD346753AA04A40E00ED4298FEA4040FAD346753AA04A40E00ED4298FEA4040153AAFB14B9E4A40B37C5D86FFE64040153AAFB14B9E4A40
19002	Жирятино	1	2	1569	33.712649999999996	33.753343000000001	53.235903999999998	53.217030999999999	0103000020E6100000010000000500000048BF7D1D38DB4040ED9BFBABC79B4A4048BF7D1D38DB40406F7F2E1A329E4A40D4D51D8B6DE040406F7F2E1A329E4A40D4D51D8B6DE04040ED9BFBABC79B4A4048BF7D1D38DB4040ED9BFBABC79B4A40
19278	Высокое	1	2	1569	33.382078999999997	33.593237000000002	53.272058000000001	53.108828000000003	0103000020E6100000010000000500000083BEF4F6E7B04040CE716E13EE8D4A4083BEF4F6E7B04040BE4EEACBD2A24A407AE3A430EFCB4040BE4EEACBD2A24A407AE3A430EFCB4040CE716E13EE8D4A4083BEF4F6E7B04040CE716E13EE8D4A40
19486	Воробейня	1	2	1569	33.488996	33.521577999999998	53.158957000000001	53.147995000000002	0103000020E61000000100000005000000FAEFC16B97BE40405B7C0A80F1924A40FAEFC16B97BE4040323CF6B358944A4013286211C3C24040323CF6B358944A4013286211C3C240405B7C0A80F1924A40FAEFC16B97BE40405B7C0A80F1924A40
19527	Буда	1	2	1569	33.419898000000003	33.459082000000002	53.175669999999997	53.160874	0103000020E61000000100000005000000F2D3B837BFB540406B63EC8497944A40F2D3B837BFB54040B471C45A7C964A405517F032C3BA4040B471C45A7C964A405517F032C3BA40406B63EC8497944A40F2D3B837BFB540406B63EC8497944A40
18533	Чернятичи	1	2	1458	34.259588999999998	34.295216000000003	53.581555000000002	53.569685	0103000020E610000001000000050000005FB35C363A214140C9022670EBC84A405FB35C363A214140A3E9EC6470CA4A40C3A04CA3C9254140A3E9EC6470CA4A40C3A04CA3C9254140C9022670EBC84A405FB35C363A214140C9022670EBC84A40
48156	Фокино	1	2	1458	34.36842	34.449969000000003	53.485225999999997	53.410888	0103000020E610000001000000050000009E98F562282F4140D0285DFA97B44A409E98F562282F41409E95B4E21BBE4A405F9B8D95983941409E95B4E21BBE4A405F9B8D9598394140D0285DFA97B44A409E98F562282F4140D0285DFA97B44A40
18024	Старь	1	2	1458	34.056812000000001	34.179845999999998	53.640424000000003	53.608894999999997	0103000020E610000001000000050000009B02999D4507414055D97745F0CD4A409B02999D4507414069C9E369F9D14A40802898310517414069C9E369F9D14A40802898310517414055D97745F0CD4A409B02999D4507414055D97745F0CD4A40
19689	Старая Рубча	1	2	1458	34.103138000000001	34.120206000000003	53.880926000000002	53.865048000000002	0103000020E61000000100000005000000C87C40A0330D414030BC92E4B9EE4A40C87C40A0330D41401A19E42EC2F04A40396403E9620F41401A19E42EC2F04A40396403E9620F414030BC92E4B9EE4A40C87C40A0330D414030BC92E4B9EE4A40
48010	Сосновка	1	2	1458	34.353679	34.374079000000002	53.547621999999997	53.540179000000002	0103000020E6100000010000000500000018247D5A452D4140357EE19524C54A4018247D5A452D4140F9484A7A18C64A40698F17D2E12F4140F9484A7A18C64A40698F17D2E12F4140357EE19524C54A4018247D5A452D4140357EE19524C54A40
48120	Слободище	1	2	1458	34.304594999999999	34.336018000000003	53.525905999999999	53.502893	0103000020E6100000010000000500000037C30DF8FC26414094313ECC5EC04A4037C30DF8FC264140956247E350C34A40056F48A3022B4140956247E350C34A40056F48A3022B414094313ECC5EC04A4037C30DF8FC26414094313ECC5EC04A40
18179	Пупково	1	2	1458	34.434814000000003	34.460020999999998	53.520237000000002	53.50676	0103000020E61000000100000005000000E6EB32FCA7374140E275FD82DDC04A40E6EB32FCA7374140A795422097C24A40923CD7F7E13A4140A795422097C24A40923CD7F7E13A4140E275FD82DDC04A40E6EB32FCA7374140E275FD82DDC04A40
17526	Псурь	1	2	1458	34.448720000000002	34.470280000000002	53.681279000000004	53.668872999999998	0103000020E61000000100000005000000D3872EA86F394140B51666A19DD54A40D3872EA86F394140CE39782634D74A4040FB9122323C4140CE39782634D74A4040FB9122323C4140B51666A19DD54A40D3872EA86F394140B51666A19DD54A40
18447	Немеричи	1	2	1458	33.976799	34.025379999999998	53.873387999999998	53.828017000000003	0103000020E61000000100000005000000FCE1E7BF07FD40401AC40776FCE94A40FCE1E7BF07FD4040035C902DCBEF4A407AFCDEA63F034140035C902DCBEF4A407AFCDEA63F0341401AC40776FCE94A40FCE1E7BF07FD40401AC40776FCE94A40
18280	Неверь	1	2	1458	34.385613999999997	34.401918000000002	53.535046999999999	53.520794000000002	0103000020E610000001000000050000009B70AFCC5B314140FDF9B660A9C24A409B70AFCC5B31414055698B6B7CC44A403DD68C0C7233414055698B6B7CC44A403DD68C0C72334140FDF9B660A9C24A409B70AFCC5B314140FDF9B660A9C24A40
17937	Любохна	1	2	1458	34.349285999999999	34.402546999999998	53.520563000000003	53.490851999999997	0103000020E61000000100000005000000AF795567B52C41408D96033DD4BE4A40AF795567B52C4140FB40F2CEA1C24A402C0DFCA886334140FB40F2CEA1C24A402C0DFCA8863341408D96033DD4BE4A40AF795567B52C41408D96033DD4BE4A40
17733	Ивот	1	2	1458	34.156525000000002	34.248944000000002	53.700991000000002	53.661696999999997	0103000020E61000000100000005000000D200DE02091441403F6EBF7CB2D44A40D200DE02091441402AE5B512BAD94A408944A165DD1F41402AE5B512BAD94A408944A165DD1F41403F6EBF7CB2D44A40D200DE02091441403F6EBF7CB2D44A40
16658	Дятьково	1	2	1458	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
48050	Дружба	1	2	1458	34.360173000000003	34.384338	53.582569999999997	53.560487000000002	0103000020E610000001000000050000007CF31B261A2E4140A56ABB09BEC74A407CF31B261A2E4140BBD05CA791CA4A40164ED2FC31314140BBD05CA791CA4A40164ED2FC31314140A56ABB09BEC74A407CF31B261A2E4140A56ABB09BEC74A40
48072	Верхи	1	2	1458	34.467413999999998	34.510057000000003	53.441879	53.431590999999997	0103000020E61000000100000005000000A5D8D138D43B4140BC1FB75F3EB74A40A5D8D138D43B414004E5B67D8FB84A40460C3B8C4941414004E5B67D8FB84A40460C3B8C49414140BC1FB75F3EB74A40A5D8D138D43B4140BC1FB75F3EB74A40
17602	Бытошь	1	2	1458	34.045214999999999	34.204360999999999	53.843628000000002	53.766655	0103000020E61000000100000005000000F224E99AC90541404E2844C021E24A40F224E99AC9054140B5FE9600FCEB4A40F7C95180281A4140B5FE9600FCEB4A40F7C95180281A41404E2844C021E24A40F224E99AC90541404E2844C021E24A40
17707	Будочка	1	2	1458	34.146365000000003	34.175156000000001	53.848855	53.831589000000001	0103000020E61000000100000005000000B8239C16BC1241404F5B238271EA4A40B8239C16BC124140E605D847A7EC4A405ED905836B164140E605D847A7EC4A405ED905836B1641404F5B238271EA4A40B8239C16BC1241404F5B238271EA4A40
47982	Березино	1	2	1458	34.429414999999999	34.460740000000001	53.492249999999999	53.480029000000002	0103000020E61000000100000005000000B7B41A12F7364140D8101C9771BD4A40B7B41A12F73641405EBA490C02BF4A40C2FA3F87F93A41405EBA490C02BF4A40C2FA3F87F93A4140D8101C9771BD4A40B7B41A12F7364140D8101C9771BD4A40
17827	Бацкино	1	2	1458	33.957441000000003	34.020843999999997	53.737298000000003	53.712333000000001	0103000020E61000000100000005000000BE6C3B6D8DFA4040486E4DBA2DDB4A40BE6C3B6D8DFA4040FFB3E6C75FDE4A40AE282504AB024140FFB3E6C75FDE4A40AE282504AB024140486E4DBA2DDB4A40BE6C3B6D8DFA4040486E4DBA2DDB4A40
16689	Старое Колышкино	1	2	1110	33.283524999999997	33.30265	53.687305000000002	53.67051	0103000020E61000000100000005000000984C158C4AA440400BD28C45D3D54A40984C158C4AA440404BB0389CF9D74A403411363CBDA640404BB0389CF9D74A403411363CBDA640400BD28C45D3D54A40984C158C4AA440400BD28C45D3D54A40
16449	Сеща	1	2	1110	33.383318000000003	33.404204	53.723261000000001	53.712145999999997	0103000020E61000000100000005000000ECFB709010B1404015FDA19927DB4A40ECFB709010B1404073BC02D193DC4A40C974E8F4BCB3404073BC02D193DC4A40C974E8F4BCB3404015FDA19927DB4A40ECFB709010B1404015FDA19927DB4A40
16374	Серпеевский	1	2	1110	33.353782000000002	33.375520999999999	53.587862000000001	53.571407000000001	0103000020E61000000100000005000000EDF483BA48AD40404DDA54DD23C94A40EDF483BA48AD4040D447E00F3FCB4A4009FB761211B04040D447E00F3FCB4A4009FB761211B040404DDA54DD23C94A40EDF483BA48AD40404DDA54DD23C94A40
16354	Рябчи	1	2	1110	33.446810999999997	33.486956999999997	53.579042000000001	53.553341000000003	0103000020E610000001000000050000001C3F541A31B940409A44BDE0D3C64A401C3F541A31B9404056815A0C1ECA4A4075C7629B54BE404056815A0C1ECA4A4075C7629B54BE40409A44BDE0D3C64A401C3F541A31B940409A44BDE0D3C64A40
51026	Рековичи	1	2	1110	33.578288999999998	33.615496999999998	53.671550000000003	53.647705000000002	0103000020E610000001000000050000007A51BB5F05CA4040543A58FFE7D24A407A51BB5F05CA40407DD0B359F5D54A409FE40E9BC8CE40407DD0B359F5D54A409FE40E9BC8CE4040543A58FFE7D24A407A51BB5F05CA4040543A58FFE7D24A40
16574	Радичи	1	2	1110	33.351958000000003	33.372987999999999	53.775019999999998	53.758766000000001	0103000020E6100000010000000500000065C8B1F50CAD40408BA8893E1FE14A4065C8B1F50CAD40407ADFF8DA33E34A4075E61E12BEAF40407ADFF8DA33E34A4075E61E12BEAF40408BA8893E1FE14A4065C8B1F50CAD40408BA8893E1FE14A40
16152	Пеклино	1	2	1110	33.506199000000002	33.537649000000002	53.563406999999998	53.545439000000002	0103000020E610000001000000050000004B22FB20CBC04040427BF5F1D0C54A404B22FB20CBC0404032AB77B81DC84A4012DDB3AED1C4404032AB77B81DC84A4012DDB3AED1C44040427BF5F1D0C54A404B22FB20CBC04040427BF5F1D0C54A40
16165	Новая Салынь	1	2	1110	33.564697000000002	33.599606000000001	53.598882000000003	53.585836	0103000020E610000001000000050000001D93C5FD47C84040E4688EACFCCA4A401D93C5FD47C84040E014562AA8CC4A40213EB0E3BFCC4040E014562AA8CC4A40213EB0E3BFCC4040E4688EACFCCA4A401D93C5FD47C84040E4688EACFCCA4A40
15970	Немерь	1	2	1110	33.480058	33.505687000000002	53.728104000000002	53.708244999999998	0103000020E610000001000000050000007217618A72BD40401B47ACC5A7DA4A407217618A72BD40401C0B0A8332DD4A409581035ABAC040401C0B0A8332DD4A409581035ABAC040401B47ACC5A7DA4A407217618A72BD40401B47ACC5A7DA4A40
16068	Мареевка	1	2	1110	33.487586	33.509891000000003	53.509860000000003	53.496240999999998	0103000020E6100000010000000500000065FED13769BE404098F738D384BF4A4065FED13769BE4040F0C4AC1743C14A402BC3B81B44C14040F0C4AC1743C14A402BC3B81B44C1404098F738D384BF4A4065FED13769BE404098F738D384BF4A40
16265	Зимницкая Слобода	1	2	1110	33.557160000000003	33.580489999999998	53.704807000000002	53.692487999999997	0103000020E61000000100000005000000D751D50451C74040AC6F6072A3D84A40D751D50451C74040F67EA31D37DA4A40D8D30E7F4DCA4040F67EA31D37DA4A40D8D30E7F4DCA4040AC6F6072A3D84A40D751D50451C74040AC6F6072A3D84A40
15779	Дубровка	1	2	1110	33.468145999999997	33.532626999999998	53.7042	53.675364000000002	0103000020E6100000010000000500000069E04735ECBB4040A872DA5372D64A4069E04735ECBB4040EEEBC03923DA4A40B9FB1C1F2DC44040EEEBC03923DA4A40B9FB1C1F2DC44040A872DA5372D64A4069E04735ECBB4040A872DA5372D64A40
51113	Давыдчичи	1	2	1110	33.475727999999997	33.501455999999997	53.682009999999998	53.664577999999999	0103000020E610000001000000050000004FE5B4A7E4BC40400FD253E410D54A404FE5B4A7E4BC4040C1C58A1A4CD74A400531D0B52FC04040C1C58A1A4CD74A400531D0B52FC040400FD253E410D54A404FE5B4A7E4BC40400FD253E410D54A40
16565	Большая Островня	1	2	1110	33.289876	33.318953999999998	53.748161000000003	53.736306999999996	0103000020E6100000010000000500000099F221A81AA540406E68CA4E3FDE4A4099F221A81AA54040439259BDC3DF4A40D576137CD3A84040439259BDC3DF4A40D576137CD3A840406E68CA4E3FDE4A4099F221A81AA540406E68CA4E3FDE4A40
9932	Бересток	1	2	1110	33.606864000000002	33.630220000000001	53.606842999999998	53.594088999999997	0103000020E61000000100000005000000548F34B8ADCD4040E8F4BC1B0BCC4A40548F34B8ADCD40403C670B08ADCD4A407FA4880CABD040403C670B08ADCD4A407FA4880CABD04040E8F4BC1B0BCC4A40548F34B8ADCD4040E8F4BC1B0BCC4A40
16789	Афонино	1	2	1110	33.119734999999999	33.413564999999998	53.686463000000003	53.586557999999997	0103000020E61000000100000005000000E197FA79538F4040849A215514CB4A40E197FA79538F404000750305DED74A4097E2AAB2EFB4404000750305DED74A4097E2AAB2EFB44040849A215514CB4A40E197FA79538F4040849A215514CB4A40
16044	Алешня	1	2	1110	33.444287000000003	33.527659999999997	53.644550000000002	53.477145	0103000020E61000000100000005000000DC847B65DEB8404097395D1613BD4A40DC847B65DEB840408351499D80D24A4024B4E55C8AC340408351499D80D24A4024B4E55C8AC3404097395D1613BD4A40DC847B65DEB8404097395D1613BD4A40
16754	Алешинка	1	2	1110	33.154184999999998	33.279840999999998	53.649984000000003	53.627861000000003	0103000020E6100000010000000500000052448655BC93404089B7CEBF5DD04A4052448655BC9340402E76FBAC32D34A403B8A73D4D1A340402E76FBAC32D34A403B8A73D4D1A3404089B7CEBF5DD04A4052448655BC93404089B7CEBF5DD04A40
47024	Ямное	1	2	1179	31.825316000000001	31.852696999999999	52.991081999999999	52.978471999999996	0103000020E6100000010000000500000094DDCCE847D33F409E060C923E7D4A4094DDCCE847D33F40BFD364C6DB7E4A40B665C0594ADA3F40BFD364C6DB7E4A40B665C0594ADA3F409E060C923E7D4A4094DDCCE847D33F409E060C923E7D4A40
45572	Ширяевка	1	2	1179	31.897145999999999	31.917672	53.073357000000001	53.056463000000001	0103000020E61000000100000005000000BABC395CABE53F408F37F92D3A874A40BABC395CABE53F4062F71DC363894A4075745C8DECEA3F4062F71DC363894A4075745C8DECEA3F408F37F92D3A874A40BABC395CABE53F408F37F92D3A874A40
46807	Черный-Ручей	1	2	1179	32.085656999999998	32.107737999999998	52.963982000000001	52.951276999999997	0103000020E6100000010000000500000034D6FECEF60A4040EF37DA71C3794A4034D6FECEF60A404062F71DC3637B4A40AA44D95BCA0D404062F71DC3637B4A40AA44D95BCA0D4040EF37DA71C3794A4034D6FECEF60A4040EF37DA71C3794A40
51148	Хаминка	1	2	1179	31.779565000000002	31.806694	53.055311000000003	53.045448	0103000020E61000000100000005000000331B649291C73F4095D5743DD1854A40331B649291C73F40F60D4C6E14874A4022E17B7F83CE3F40F60D4C6E14874A4022E17B7F83CE3F4095D5743DD1854A40331B649291C73F4095D5743DD1854A40
15575	Уношево	1	2	1179	31.797082	31.821804	53.012537000000002	52.992784	0103000020E61000000100000005000000F33AE2900DCC3F40FCFECD8B137F4A40F33AE2900DCC3F40B77EFACF9A814A40D4B837BF61D23F40B77EFACF9A814A40D4B837BF61D23F40FCFECD8B137F4A40F33AE2900DCC3F40FCFECD8B137F4A40
15122	Творишино	1	2	1179	32.017232	32.066217000000002	52.948369	52.921709	0103000020E61000000100000005000000EB387EA834024040E5B67D8FFA754A40EB387EA83402404026C5C72764794A4039B874CC7908404026C5C72764794A4039B874CC79084040E5B67D8FFA754A40EB387EA834024040E5B67D8FFA754A40
51109	Струговская Буда	1	2	1179	31.994046999999998	32.046804999999999	53.059596999999997	53.026090000000003	0103000020E61000000100000005000000D9AF3BDD79FE3F405760C8EA56834A40D9AF3BDD79FE3F4048F8DEDFA0874A400725CCB4FD05404048F8DEDFA0874A400725CCB4FD0540405760C8EA56834A40D9AF3BDD79FE3F405760C8EA56834A40
20747	Струговка	1	2	1179	32.066352000000002	32.085118000000001	53.022855999999997	53.008488999999997	0103000020E610000001000000050000001903EB387E08404018B0E42A16814A401903EB387E084040394206F2EC824A4085268925E50A4040394206F2EC824A4085268925E50A404018B0E42A16814A401903EB387E08404018B0E42A16814A40
11217	Староновицкая	1	2	1179	31.907700999999999	31.928569	53.018182000000003	53.005585000000004	0103000020E61000000100000005000000E78BBD175FE83F40912C6002B7804A40E78BBD175FE83F401DB0ABC953824A405514AFB2B6ED3F401DB0ABC953824A405514AFB2B6ED3F40912C6002B7804A40E78BBD175FE83F40912C6002B7804A40
15324	Старая Полона	1	2	1179	31.829763	31.857135	52.950614999999999	52.936235000000003	0103000020E610000001000000050000004C6E14596BD43F406F2F698CD6774A404C6E14596BD43F40240B98C0AD794A40C84109336DDB3F40240B98C0AD794A40C84109336DDB3F406F2F698CD6774A404C6E14596BD43F406F2F698CD6774A40
15494	Смяльч	1	2	1179	31.825234999999999	31.865210000000001	52.810504000000002	52.793371	0103000020E61000000100000005000000BA83D89942D33F40234C512E8D654A40BA83D89942D33F407BA35698BE674A40132C0E677EDD3F407BA35698BE674A40132C0E677EDD3F40234C512E8D654A40BA83D89942D33F40234C512E8D654A40
15198	Рудня-Воробьевка	1	2	1179	31.945098000000002	31.969729000000001	53.000627000000001	52.986583000000003	0103000020E61000000100000005000000D88349F1F1F13F4011E50B5A487E4A40D88349F1F1F13F404F3FA88B14804A4098FBE42840F83F404F3FA88B14804A4098FBE42840F83F4011E50B5A487E4A40D88349F1F1F13F4011E50B5A487E4A40
51096	Поповка	1	2	1179	31.894504000000001	31.932601999999999	52.989477999999998	52.975164999999997	0103000020E610000001000000050000002524D236FEE43F40179AEB34D27C4A402524D236FEE43F40450E1137A77E4A40272F3201BFEE3F40450E1137A77E4A40272F3201BFEE3F40179AEB34D27C4A402524D236FEE43F40179AEB34D27C4A40
46762	Поконь	1	2	1179	31.962273	31.992671999999999	52.913525999999997	52.891457000000003	0103000020E61000000100000005000000E5D2F88557F63F40286552431B724A40E5D2F88557F63F40D905836BEE744A40A8A78FC01FFE3F40D905836BEE744A40A8A78FC01FFE3F40286552431B724A40E5D2F88557F63F40286552431B724A40
15366	Петрова Буда	1	2	1179	31.755230000000001	31.781056	52.867083000000001	52.851081000000001	0103000020E6100000010000000500000045F5D6C056C13F409D9FE238F06C4A4045F5D6C056C13F4073F56393FC6E4A4036583849F3C73F4073F56393FC6E4A4036583849F3C73F409D9FE238F06C4A4045F5D6C056C13F409D9FE238F06C4A40
15420	Перетин	1	2	1179	31.827283999999999	31.859397999999999	52.892783000000001	52.875894000000002	0103000020E610000001000000050000000A815CE2C8D33F409E616A4B1D704A400A815CE2C8D33F405FB69DB646724A40703FE08101DC3F405FB69DB646724A40703FE08101DC3F409E616A4B1D704A400A815CE2C8D33F409E616A4B1D704A40
46281	Мирный	1	2	1179	31.725629999999999	31.741368999999999	52.825100999999997	52.814324999999997	0103000020E6100000010000000500000019FF3EE3C2B93F4058A835CD3B684A4019FF3EE3C2B93F40CD72D9E89C694A40AA44D95BCABD3F40CD72D9E89C694A40AA44D95BCABD3F4058A835CD3B684A4019FF3EE3C2B93F4058A835CD3B684A40
15482	Малоудебное	1	2	1179	31.70187	31.730086	52.890369999999997	52.873474999999999	0103000020E61000000100000005000000240B98C0ADB33F40D26F5F07CE6F4A40240B98C0ADB33F4075ABE7A4F7714A40784485EAE6BA3F4075ABE7A4F7714A40784485EAE6BA3F40D26F5F07CE6F4A40240B98C0ADB33F40D26F5F07CE6F4A40
47041	Кузнецы	1	2	1179	31.709603999999999	31.733696999999999	52.955058999999999	52.943339000000002	0103000020E610000001000000050000005C1C959BA8B53F404B051555BF784A405C1C959BA8B53F400F60915F3F7A4A405E2C0C91D3BB3F400F60915F3F7A4A405E2C0C91D3BB3F404B051555BF784A405C1C959BA8B53F404B051555BF784A40
49234	Кожаны	1	2	1179	31.708580000000001	31.740416	52.806209000000003	52.774825	0103000020E610000001000000050000008599B67F65B53F40C58F31772D634A408599B67F65B53F40D55E44DB31674A40656F29E78BBD3F40D55E44DB31674A40656F29E78BBD3F40C58F31772D634A408599B67F65B53F40C58F31772D634A40
51094	Заводокорецкий	1	2	1179	31.934011999999999	31.946400000000001	52.898780000000002	52.880806999999997	0103000020E61000000100000005000000511212691BEF3F403F8BA548BE704A40511212691BEF3F40422619390B734A4035EF384547F23F40422619390B734A4035EF384547F23F403F8BA548BE704A40511212691BEF3F403F8BA548BE704A40
46715	Гордеевка	1	2	1179	31.951637000000002	31.989671999999999	52.970235000000002	52.942323999999999	0103000020E61000000100000005000000DFA9807B9EF33F40321EA5129E784A40DFA9807B9EF33F40A03715A9307C4A4054C4E9245BFD3F40A03715A9307C4A4054C4E9245BFD3F40321EA5129E784A40DFA9807B9EF33F40321EA5129E784A40
51112	Березина	1	2	1179	31.955024000000002	31.968705	53.045665	53.033282	0103000020E6100000010000000500000026E5EE737CF43F40D2C5A69542844A4026E5EE737CF43F4032C9C859D8854A40C078060DFDF73F4032C9C859D8854A40C078060DFDF73F40D2C5A69542844A4026E5EE737CF43F40D2C5A69542844A40
14942	Хутор Бор	1	2	1297	34.196095999999997	34.248333000000002	53.123100999999998	53.099296000000002	0103000020E610000001000000050000002E7079AC19194140D34F38BBB58C4A402E7079AC191941406D8D08C6C18F4A4040C23060C91F41406D8D08C6C18F4A4040C23060C91F4140D34F38BBB58C4A402E7079AC19194140D34F38BBB58C4A40
14879	Хмелево	1	2	1297	33.883276000000002	33.909246000000003	53.037170000000003	53.025516000000003	0103000020E61000000100000005000000BDAB1E300FF140402BC3B81B44834A40BDAB1E300FF1404038328FFCC1844A406902452C62F4404038328FFCC1844A406902452C62F440402BC3B81B44834A40BDAB1E300FF140402BC3B81B44834A40
14651	Уручье	1	2	1297	33.950972999999998	33.983356999999998	52.924233000000001	52.909692	0103000020E610000001000000050000008330B77BB9F9404067B796C970744A408330B77BB9F94040267156444D764A4076A565A4DEFD4040267156444D764A4076A565A4DEFD404067B796C970744A408330B77BB9F9404067B796C970744A40
51025	Сосновое Болото	1	2	1297	33.836230999999998	33.86636	52.936284000000001	52.917288999999997	0103000020E6100000010000000500000060730E9E09EB404082FDD7B969754A4060730E9E09EB404050E27327D8774A4002486DE2E4EE404050E27327D8774A4002486DE2E4EE404082FDD7B969754A4060730E9E09EB404082FDD7B969754A40
14602	Сосновка	1	2	1297	33.989142000000001	34.019640000000003	53.013506	52.995677999999998	0103000020E61000000100000005000000CE8C7E349CFE404060AC6F60727F4A40CE8C7E349CFE40405F268A90BA814A40C3D84290830241405F268A90BA814A40C3D842908302414060AC6F60727F4A40CE8C7E349CFE404060AC6F60727F4A40
13888	Скуратово	1	2	1297	34.078246	34.097847000000002	53.168481	53.160442000000003	0103000020E610000001000000050000007B8505F7030A4140D2730B5D89944A407B8505F7030A4140AA7F10C990954A4080812040860C4140AA7F10C990954A4080812040860C4140D2730B5D89944A407B8505F7030A4140D2730B5D89944A40
14516	Скрябино	1	2	1297	34.104019000000001	34.138908999999998	53.143988	53.132584000000001	0103000020E61000000100000005000000D1949D7E500D414087FC3383F8904A40D1949D7E500D41401B82E3326E924A405E0F26C5C71141401B82E3326E924A405E0F26C5C711414087FC3383F8904A40D1949D7E500D414087FC3383F8904A40
51093	Полужье	1	2	1297	34.169128999999998	34.210343000000002	53.156581000000003	53.141832999999998	0103000020E6100000010000000500000010E7E104A61541402D3F709527924A4010E7E104A61541406616A1D80A944A40A5F8F884EC1A41406616A1D80A944A40A5F8F884EC1A41402D3F709527924A4010E7E104A61541402D3F709527924A40
13990	Пильшино	1	2	1297	33.915013000000002	33.931784999999998	53.114865000000002	53.103200000000001	0103000020E610000001000000050000001A355F251FF540403E7958A8358D4A401A355F251FF540403F3A75E5B38E4A40A1F31ABB44F740403F3A75E5B38E4A40A1F31ABB44F740403E7958A8358D4A401A355F251FF540403E7958A8358D4A40
48343	Павловка	1	2	1297	33.966665999999996	33.974311	52.887560999999998	52.875872000000001	0103000020E61000000100000005000000DB1324B6BBFB4040B6BDDD921C704A40DB1324B6BBFB40403F1A4E999B714A4008910C39B6FC40403F1A4E999B714A4008910C39B6FC4040B6BDDD921C704A40DB1324B6BBFB4040B6BDDD921C704A40
14432	Орменка	1	2	1297	33.896948000000002	33.939940999999997	53.160383000000003	53.145316000000001	0103000020E61000000100000005000000371B2B31CFF24040F3CAF5B699924A40371B2B31CFF24040CDEA1D6E87944A40B39597FC4FF84040CDEA1D6E87944A40B39597FC4FF84040F3CAF5B699924A40371B2B31CFF24040F3CAF5B699924A40
14187	Мякишево	1	2	1297	34.002662000000001	34.022900999999997	53.03933	53.028104999999996	0103000020E610000001000000050000009278793A5700414052EDD3F198834A409278793A5700414037E0F3C308854A40D905836BEE02414037E0F3C308854A40D905836BEE02414052EDD3F198834A409278793A5700414052EDD3F198834A40
14353	Малфа	1	2	1297	33.759874000000003	33.787291000000003	53.126317	53.102410999999996	0103000020E61000000100000005000000558A1D8D43E1404015E0BBCD1B8D4A40558A1D8D43E14040E4F6CB272B904A40B3B794F3C5E44040E4F6CB272B904A40B3B794F3C5E4404015E0BBCD1B8D4A40558A1D8D43E1404015E0BBCD1B8D4A40
14148	Лопушь	1	2	1297	34.039375999999997	34.062201999999999	53.071480000000001	53.043559000000002	0103000020E61000000100000005000000A71FD4450A0541402639605793854A40A71FD4450A054140B728B34126894A4076DF313CF6074140B728B34126894A4076DF313CF60741402639605793854A40A71FD4450A0541402639605793854A40
14788	Красный Рог	1	2	1297	33.727930000000001	33.755913	53.015689999999999	52.996263999999996	0103000020E610000001000000050000007EE36BCF2CDD404050172994857F4A407EE36BCF2CDD4040E76F422102824A4085CFD6C1C1E04040E76F422102824A4085CFD6C1C1E0404050172994857F4A407EE36BCF2CDD404050172994857F4A40
13925	Красное	1	2	1297	33.889079000000002	33.928434000000003	53.081125	53.054769	0103000020E61000000100000005000000BB473657CDF14040D5EAABAB02874A40BB473657CDF14040AAF1D24D628A4A404B3FE1ECD6F64040AAF1D24D628A4A404B3FE1ECD6F64040D5EAABAB02874A40BB473657CDF14040D5EAABAB02874A40
51095	Кокино	1	2	1297	34.108680999999997	34.122093	53.165008999999998	53.155399000000003	0103000020E6100000010000000500000029594E42E90D4140626A4B1DE4934A4029594E42E90D4140D845D1031F954A40070951BEA00F4140D845D1031F954A40070951BEA00F4140626A4B1DE4934A4029594E42E90D4140626A4B1DE4934A40
14288	Евтиховский	1	2	1297	33.952041999999999	33.969667000000001	53.194546000000003	53.183183	0103000020E610000001000000050000008F352383DCF940407217618A72974A408F352383DCF94040A8C821E2E6984A4056815A0C1EFC4040A8C821E2E6984A4056815A0C1EFC40407217618A72974A408F352383DCF940407217618A72974A40
14685	Деснянский	1	2	1297	33.935952999999998	33.960225000000001	52.878475000000002	52.866239999999998	0103000020E61000000100000005000000EACBD24ECDF74040573ECBF3E06E4A40EACBD24ECDF7404043AD69DE71704A409BE61DA7E8FA404043AD69DE71704A409BE61DA7E8FA4040573ECBF3E06E4A40EACBD24ECDF74040573ECBF3E06E4A40
14536	Десна	1	2	1297	34.006084000000001	34.018275000000003	52.976129999999998	52.968916999999998	0103000020E61000000100000005000000B2834A5CC7004140EBC4E578057C4A40B2834A5CC70041407E52EDD3F17C4A40CEAACFD5560241407E52EDD3F17C4A40CEAACFD556024140EBC4E578057C4A40B2834A5CC7004140EBC4E578057C4A40
13755	Городец	1	2	1297	34.029099000000002	34.079369	53.133076000000003	53.124236000000003	0103000020E6100000010000000500000054AC1A84B9034140317E1AF7E68F4A4054AC1A84B9034140F6F065A208914A407AA86DC3280A4140F6F065A208914A407AA86DC3280A4140317E1AF7E68F4A4054AC1A84B9034140317E1AF7E68F4A40
13604	Выгоничи	1	2	1297	34.006048	34.086132999999997	53.113945999999999	53.073346000000001	0103000020E61000000100000005000000651A4D2EC60041406EA5D76663894A40651A4D2EC600414048C153C8958E4A409D0DF967060B414048C153C8958E4A409D0DF967060B41406EA5D76663894A40651A4D2EC60041406EA5D76663894A40
14217	Большой Крупец	1	2	1297	33.738143999999998	33.785637999999999	53.138596999999997	53.124035999999997	0103000020E610000001000000050000008BDEA9807BDE404069C36169E08F4A408BDEA9807BDE40406F29E78BBD914A40573F36C98FE440406F29E78BBD914A40573F36C98FE4404069C36169E08F4A408BDEA9807BDE404069C36169E08F4A40
14747	Алексеевский	1	2	1297	33.866979999999998	33.900649000000001	53.008960999999999	52.999899999999997	0103000020E610000001000000050000009E245D33F9EE40409CA223B9FC7F4A409E245D33F9EE404040F850A225814A406A16687748F3404040F850A225814A406A16687748F340409CA223B9FC7F4A409E245D33F9EE40409CA223B9FC7F4A40
51134	п.Путевка	1	2	1191	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
12066	Хотылево	1	2	1191	34.112758999999997	34.138945	53.341973000000003	53.334074999999999	0103000020E6100000010000000500000032AA0CE36E0E4140A2B437F8C2AA4A4032AA0CE36E0E4140B98E71C5C5AB4A40AB7823F3C8114140B98E71C5C5AB4A40AB7823F3C8114140A2B437F8C2AA4A4032AA0CE36E0E4140A2B437F8C2AA4A40
13008	Толмачево	1	2	1191	34.254621	34.291479000000002	53.266736999999999	53.234943999999999	0103000020E61000000100000005000000FAEFC16B972041401A321EA5129E4A40FAEFC16B972041400BD1217024A24A40433C122F4F2541400BD1217024A24A40433C122F4F2541401A321EA5129E4A40FAEFC16B972041401A321EA5129E4A40
13478	Толвинка	1	2	1191	34.203561000000001	34.216524	53.386696000000001	53.367932000000003	0103000020E61000000100000005000000DBDE6E490E1A41407193516518AF4A40DBDE6E490E1A41403CBF28417FB14A404966F50EB71B41403CBF28417FB14A404966F50EB71B41407193516518AF4A40DBDE6E490E1A41407193516518AF4A40
11950	Титовка	1	2	1191	34.049706999999998	34.084057999999999	53.270141000000002	53.247171999999999	0103000020E61000000100000005000000EEB089CC5C064140533E0455A39F4A40EEB089CC5C0641408527F4FA93A24A40CC7B9C69C20A41408527F4FA93A24A40CC7B9C69C20A4140533E0455A39F4A40EEB089CC5C064140533E0455A39F4A40
13219	Тиганово	1	2	1191	34.192979000000001	34.230969000000002	53.206553	53.193477000000001	0103000020E610000001000000050000004BE82E89B31841409CC3B5DAC3984A404BE82E89B318414002F22554709A4A40E6B16664901D414002F22554709A4A40E6B16664901D41409CC3B5DAC3984A404BE82E89B31841409CC3B5DAC3984A40
13295	Теменичи	1	2	1191	34.135728999999998	34.170521000000001	53.226109999999998	53.215482999999999	0103000020E61000000100000005000000340F60915F11414007EC6AF2949B4A40340F60915F11414037A6272CF19C4A40FF23D3A1D315414037A6272CF19C4A40FF23D3A1D315414007EC6AF2949B4A40340F60915F11414007EC6AF2949B4A40
51105	Супонево	1	2	1191	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
12830	Стяжное	1	2	1191	34.420611999999998	34.437787999999998	53.117950999999998	53.111010999999998	0103000020E610000001000000050000000F27309DD6354140853FC39B358E4A400F27309DD6354140E7C3B304198F4A40664AEB6F09384140E7C3B304198F4A40664AEB6F09384140853FC39B358E4A400F27309DD6354140853FC39B358E4A40
11431	Стеклянная Радица	1	2	1191	34.476784000000002	34.496295000000003	53.387141	53.360393000000002	0103000020E61000000100000005000000C7A01342073D41408A5A9A5B21AE4A40C7A01342073D41406AF816D68DB14A408C153598863F41406AF816D68DB14A408C153598863F41408A5A9A5B21AE4A40C7A01342073D41408A5A9A5B21AE4A40
12153	Староселье	1	2	1191	34.120916000000001	34.148099000000002	53.314928000000002	53.292741999999997	0103000020E6100000010000000500000015C8EC2C7A0F41403315E29178A54A4015C8EC2C7A0F41401F4C8A8F4FA84A4000C974E8F41241401F4C8A8F4FA84A4000C974E8F41241403315E29178A54A4015C8EC2C7A0F41403315E29178A54A40
51140	Свень-Транспортная	1	2	1191	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
12689	Свень	1	2	1191	34.354137000000001	34.373891	53.147551999999997	53.132455	0103000020E61000000100000005000000DBA6785C542D414089981249F4904A40DBA6785C542D4140CD3AE3FBE2924A4066A208A9DB2F4140CD3AE3FBE2924A4066A208A9DB2F414089981249F4904A40DBA6785C542D414089981249F4904A40
12791	Пятилетка	1	2	1191	34.297642000000003	34.318517999999997	53.164555999999997	53.13702	0103000020E6100000010000000500000041F50F2219264140EF7211DF89914A4041F50F2219264140272EC72B10954A40FA97A432C5284140272EC72B10954A40FA97A432C5284140EF7211DF89914A4041F50F2219264140EF7211DF89914A40
51129	Путевка	1	2	1191	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
13575	Пальцо	1	2	1191	34.912618999999999	34.936604000000003	53.292504999999998	53.280329000000002	0103000020E61000000100000005000000A75A0BB3D0744140698F17D2E1A34A40A75A0BB3D07441404F75C8CD70A54A40C2A6CEA3E27741404F75C8CD70A54A40C2A6CEA3E2774140698F17D2E1A34A40A75A0BB3D0744140698F17D2E1A34A40
51067	Новые Дарковичи	1	2	1191	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
45658	Новоселки	1	2	1191	33.767688999999997	33.792904999999998	53.330858999999997	53.308562999999999	0103000020E61000000100000005000000DD3F16A243E24040B9E00CFE7EA74A40DD3F16A243E240402B4B749659AA4A40DDEA39E97DE540402B4B749659AA4A40DDEA39E97DE54040B9E00CFE7EA74A40DD3F16A243E24040B9E00CFE7EA74A40
13340	Нетьинка	1	2	1191	34.178713999999999	34.205357999999997	53.354379999999999	53.343231000000003	0103000020E610000001000000050000002EABB019E016414098FC4FFEEEAB4A402EABB019E0164140A12DE7525CAD4A4069FCC22B491A4140A12DE7525CAD4A4069FCC22B491A414098FC4FFEEEAB4A402EABB019E016414098FC4FFEEEAB4A40
12669	Молотино	1	2	1191	33.867033999999997	33.889932000000002	53.341183000000001	53.333575000000003	0103000020E61000000100000005000000914259F8FAEE4040B1E1E995B2AA4A40914259F8FAEE4040C07971E2ABAB4A40FAD4B14AE9F14040C07971E2ABAB4A40FAD4B14AE9F14040B1E1E995B2AA4A40914259F8FAEE4040B1E1E995B2AA4A40
13046	Мичуринский	1	2	1191	34.22486	34.244964000000003	53.282519999999998	53.269333000000003	0103000020E61000000100000005000000DB166536C81C4140E65DF58079A24A40DB166536C81C4140A33B889D29A44A404359F8FA5A1F4140A33B889D29A44A404359F8FA5A1F4140E65DF58079A24A40DB166536C81C4140E65DF58079A24A40
11715	Мирный	1	2	1191	34.808701999999997	34.821961000000002	53.325373999999996	53.313965000000003	0103000020E61000000100000005000000DA1A118C83674140598B4F0130A84A40DA1A118C83674140FE7BF0DAA5A94A4032CB9E0436694140FE7BF0DAA5A94A4032CB9E0436694140598B4F0130A84A40DA1A118C83674140598B4F0130A84A40
13127	Меркульево	1	2	1191	34.144478999999997	34.171222	53.283171000000003	53.266500000000001	0103000020E61000000100000005000000B9FAB1497E124140273108AC1CA24A40B9FAB1497E1241407B1684F23EA44A40882D3D9AEA1541407B1684F23EA44A40882D3D9AEA154140273108AC1CA24A40B9FAB1497E124140273108AC1CA24A40
11628	Малое Полпино	1	2	1191	34.609482999999997	34.633288	53.284053999999998	53.264955	0103000020E61000000100000005000000E63BF889034E4140B2F4A10BEAA14A40E63BF889034E41402426A8E15BA44A408179C8940F5141402426A8E15BA44A408179C8940F514140B2F4A10BEAA14A40E63BF889034E4140B2F4A10BEAA14A40
13079	Колтово	1	2	1191	34.099257999999999	34.127070000000003	53.275531000000001	53.265115999999999	0103000020E61000000100000005000000E5EE737CB40C4140BBD23252EFA14A40E5EE737CB40C414060048D9944A34A40C0266BD44310414060048D9944A34A40C0266BD443104140BBD23252EFA14A40E5EE737CB40C4140BBD23252EFA14A40
11537	Козелкино	1	2	1191	34.479928000000001	34.50844	53.332338	53.327126999999997	0103000020E61000000100000005000000A437DC476E3D4140BD512B4CDFA94A40A437DC476E3D4140E99B340D8AAA4A4037FDD98F14414140E99B340D8AAA4A4037FDD98F14414140BD512B4CDFA94A40A437DC476E3D4140BD512B4CDFA94A40
12039	Кабаличи	1	2	1191	34.078048000000003	34.101529999999997	53.322873000000001	53.312077000000002	0103000020E6100000010000000500000055C2137AFD094140BA6A9E23F2A74A4055C2137AFD09414076E107E753A94A400CC85EEFFE0C414076E107E753A94A400CC85EEFFE0C4140BA6A9E23F2A74A4055C2137AFD094140BA6A9E23F2A74A40
11602	Журиничи	1	2	1191	34.697130999999999	34.723641000000001	53.329445	53.305033999999999	0103000020E610000001000000050000008E03AF963B5941408315A75A0BA74A408E03AF963B594140556AF6402BAA4A40BA85AE44A05C4140556AF6402BAA4A40BA85AE44A05C41408315A75A0BA74A408E03AF963B5941408315A75A0BA74A40
13505	Домашово	1	2	1191	34.040354999999998	34.068103999999998	53.468483999999997	53.453933999999997	0103000020E61000000100000005000000739D465A2A0541406F4562821ABA4A40739D465A2A0541408159A148F7BB4A40075DC2A1B70841408159A148F7BB4A40075DC2A1B70841406F4562821ABA4A40739D465A2A0541406F4562821ABA4A40
13190	Добрунь	1	2	1191	34.225031000000001	34.264834999999998	53.196945999999997	53.169857	0103000020E6100000010000000500000008CBD8D0CD1C414093FFC9DFBD954A4008CBD8D0CD1C4140FC89CA8635994A4007EBFF1CE6214140FC89CA8635994A4007EBFF1CE621414093FFC9DFBD954A4008CBD8D0CD1C414093FFC9DFBD954A40
12328	Госома	1	2	1191	33.954017999999998	33.985010000000003	53.305712	53.291030999999997	0103000020E61000000100000005000000CDE506431DFA4040A38FF98040A54A40CDE506431DFA404054FF209221A74A40D21DC4CE14FE404054FF209221A74A40D21DC4CE14FE4040A38FF98040A54A40CDE506431DFA4040A38FF98040A54A40
12280	Городец	1	2	1191	34.017924000000001	34.045844000000002	53.350982999999999	53.343924999999999	0103000020E6100000010000000500000021E868554B0241406EA301BC05AC4A4021E868554B024140DA39CD02EDAC4A40E25B5837DE054140DA39CD02EDAC4A40E25B5837DE0541406EA301BC05AC4A4021E868554B0241406EA301BC05AC4A40
11894	Глинищево	1	2	1191	34.058779999999999	34.106057999999997	53.312835	53.294049999999999	0103000020E6100000010000000500000056D4601A86074140C4B12E6EA3A54A4056D4601A86074140A7052FFA0AA84A4055BDFC4E930D4140A7052FFA0AA84A4055BDFC4E930D4140C4B12E6EA3A54A4056D4601A86074140C4B12E6EA3A54A40
13428	Глаженка	1	2	1191	34.151116999999999	34.171509	53.378779000000002	53.367663999999998	0103000020E61000000100000005000000506F46CD5713414051F52B9D0FAF4A40506F46CD57134140AFB48CD47BB04A401EFCC401F4154140AFB48CD47BB04A401EFCC401F415414051F52B9D0FAF4A40506F46CD5713414051F52B9D0FAF4A40
12228	Бетово	1	2	1191	33.999319999999997	34.021293	53.352907000000002	53.342129	0103000020E610000001000000050000008E1EBFB7E9FF4040B00111E2CAAB4A408E1EBFB7E9FF4040C6C37B0E2CAD4A401E51A1BAB9024140C6C37B0E2CAD4A401E51A1BAB9024140B00111E2CAAB4A408E1EBFB7E9FF4040B00111E2CAAB4A40
51069	Белые Берега	1	2	1191	34.644283999999999	34.693691000000001	53.221046999999999	53.199416999999997	0103000020E6100000010000000500000004ABEAE5775241401AA20A7F86994A4004ABEAE57752414080F0A1444B9C4A40C843DFDDCA58414080F0A1444B9C4A40C843DFDDCA5841401AA20A7F86994A4004ABEAE5775241401AA20A7F86994A40
51092	Белобережская	1	2	1191	34.585318000000001	34.594005000000003	53.218729000000003	53.216928000000003	0103000020E610000001000000050000004CE141B3EB4A414019CBF44BC49B4A404CE141B3EB4A4140E9D7D64FFF9B4A408B54185B084C4140E9D7D64FFF9B4A408B54185B084C414019CBF44BC49B4A404CE141B3EB4A414019CBF44BC49B4A40
11514	Батагово	1	2	1191	34.611747000000001	34.631284999999998	53.405585000000002	53.394579	0103000020E610000001000000050000008B36C7B94D4E41401D588E9081B24A408B36C7B94D4E4140C45F9335EAB34A4049BA66F2CD504140C45F9335EAB34A4049BA66F2CD5041401D588E9081B24A408B36C7B94D4E41401D588E9081B24A40
12570	Антоновка	1	2	1191	34.266478999999997	34.297049000000001	53.231693999999997	53.204448999999997	0103000020E610000001000000050000000F09DFFB1B224140965984622B9A4A400F09DFFB1B224140F7562426A89D4A409E279EB305264140F7562426A89D4A409E279EB305264140965984622B9A4A400F09DFFB1B224140965984622B9A4A40
10954	Чаянка	1	2	1116	34.906672	34.928545999999997	52.731510999999998	52.713608999999998	0103000020E610000001000000050000007619FED30D744140CD902A8A575B4A407619FED30D74414006D50627A25D4A40726A6798DA76414006D50627A25D4A40726A6798DA764140CD902A8A575B4A407619FED30D744140CD902A8A575B4A40
51045	Хотеева	1	2	1116	34.277492000000002	35.113886999999998	52.815500999999998	52.451199000000003	0103000020E6100000010000000500000069739CDB84234140747E8AE3C0394A4069739CDB842341407A6D365662684A40433866D9938E41407A6D365662684A40433866D9938E4140747E8AE3C0394A4069739CDB84234140747E8AE3C0394A40
49275	Столбово	1	2	1116	34.770190999999997	34.792361999999997	52.611275999999997	52.594025000000002	0103000020E610000001000000050000003656629E95624140D200DE02094C4A403656629E95624140336ABE4A3E4E4A40EC4B361E6C654140336ABE4A3E4E4A40EC4B361E6C654140D200DE02094C4A403656629E95624140D200DE02094C4A40
10304	Сныткино	1	2	1116	34.645603999999999	34.678077999999999	52.612583000000001	52.585287999999998	0103000020E610000001000000050000005915E126A3524140E15E99B7EA4A4A405915E126A3524140F48AA71E694E4A408C118942CB564140F48AA71E694E4A408C118942CB564140E15E99B7EA4A4A405915E126A3524140E15E99B7EA4A4A40
10378	Осотское	1	2	1116	34.700733999999997	34.733873000000003	52.665176000000002	52.643079	0103000020E61000000100000005000000FE98D6A6B159414048DFA46950524A40FE98D6A6B1594140C40AB77C24554A406E35EB8CEF5D4140C40AB77C24554A406E35EB8CEF5D414048DFA46950524A40FE98D6A6B159414048DFA46950524A40
51070	Новое	1	2	1116	34.841876999999997	34.861612999999998	52.596733	52.588827999999999	0103000020E61000000100000005000000962023A0C26B41400B7C45B75E4B4A40962023A0C26B4140D4B837BF614C4A407B67B455496E4140D4B837BF614C4A407B67B455496E41400B7C45B75E4B4A40962023A0C26B41400B7C45B75E4B4A40
10977	Локоть	1	2	1116	34.516336000000003	34.607435000000002	52.597417	52.546394999999997	0103000020E61000000100000005000000ADDF4C4C1742414055D97745F0454A40ADDF4C4C1742414087890629784C4A400FB9196EC04D414087890629784C4A400FB9196EC04D414055D97745F0454A40ADDF4C4C1742414055D97745F0454A40
10771	Летча	1	2	1116	34.927495	34.942596000000002	52.609903000000003	52.601464999999997	0103000020E610000001000000050000000D1AFA27B876414025581CCEFC4C4A400D1AFA27B8764140BC5D2F4D114E4A4093AB58FCA6784140BC5D2F4D114E4A4093AB58FCA678414025581CCEFC4C4A400D1AFA27B876414025581CCEFC4C4A40
49155	Крупец	1	2	1116	34.388478999999997	34.435882999999997	52.521223999999997	52.504322000000002	0103000020E6100000010000000500000065170CAEB9314140A053909F8D404A4065170CAEB9314140F5F1D077B7424A40F1F09E03CB374140F5F1D077B7424A40F1F09E03CB374140A053909F8D404A4065170CAEB9314140A053909F8D404A40
10134	Красный Колодец	1	2	1116	34.474744000000001	34.516938000000003	52.612183000000002	52.581108	0103000020E6100000010000000500000072FC5069C43C4140D4B837BF614A4A4072FC5069C43C4140661536035C4E4A40A3073E062B424140661536035C4E4A40A3073E062B424140D4B837BF614A4A4072FC5069C43C4140D4B837BF614A4A40
10513	Калошичье	1	2	1116	34.686953000000003	34.709735000000002	52.717024000000002	52.705387000000002	0103000020E61000000100000005000000CE716E13EE5741400403081F4A5A4A40CE716E13EE5741403B394371C75B4A40CDE9B298D85A41403B394371C75B4A40CDE9B298D85A41400403081F4A5A4A40CE716E13EE5741400403081F4A5A4A40
51040	Городище 1-е	1	2	1116	34.920299999999997	34.935040999999998	52.594140000000003	52.585666000000003	0103000020E610000001000000050000002041F163CC75414088307E1AF74A4A402041F163CC7541406B9F8EC70C4C4A40A6B5696CAF7741406B9F8EC70C4C4A40A6B5696CAF77414088307E1AF74A4A402041F163CC75414088307E1AF74A4A40
49314	Глоднево	1	2	1116	34.810938999999998	34.856735	52.654940000000003	52.635629999999999	0103000020E61000000100000005000000850662D9CC674140A12DE7525C514A40850662D9CC674140CF6BEC12D5534A40562B137EA96D4140CF6BEC12D5534A40562B137EA96D4140A12DE7525C514A40850662D9CC674140A12DE7525C514A40
10128	Воронов Лог	1	2	1116	34.475642999999998	34.509248999999997	52.554138000000002	52.533830999999999	0103000020E6100000010000000500000021C9ACDEE13C4140A54BFF9254444A4021C9ACDEE13C414045BC75FEED464A40A6423C122F41414045BC75FEED464A40A6423C122F414140A54BFF9254444A4021C9ACDEE13C4140A54BFF9254444A40
51073	Веребское	1	2	1116	34.930728999999999	34.952792000000002	52.675649999999997	52.656781000000002	0103000020E610000001000000050000002A38BC20227741402DD1596611544A402A38BC20227741406DC5FEB27B564A40FAF19716F57941406DC5FEB27B564A40FAF19716F57941402DD1596611544A402A38BC20227741402DD1596611544A40
10065	Брасово	1	2	1116	34.587187	34.634348000000003	52.604402	52.569155000000002	0103000020E6100000010000000500000074D190F1284B41406DAD2F12DA484A4074D190F1284B414089D1730B5D4D4A403A24B5503251414089D1730B5D4D4A403A24B550325141406DAD2F12DA484A4074D190F1284B41406DAD2F12DA484A40
28629	Шебекино	1	1	\N	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
21346	Старый Оскол	1	1	\N	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
930	Губкин	1	1	\N	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
11717	Белгород	1	1	\N	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
10381	Алексеевка	1	1	\N	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
344	Яковлево	1	1	46	36.424205000000001	36.460811999999997	50.879176000000001	50.843392999999999	0103000020E610000001000000050000005CE674594C3642407156444DF46B49405CE674594C364240CCB6D3D6887049405BCD3AE3FB3A4240CCB6D3D6887049405BCD3AE3FB3A42407156444DF46B49405CE674594C3642407156444DF46B4940
2690	Шопино	1	1	46	36.565088000000003	36.610093999999997	50.714880000000001	50.687040000000003	0103000020E6100000010000000500000058AEB7CD544842409D853DEDF057494058AEB7CD5448424041481630815B49402FBE688F174E424041481630815B49402FBE688F174E42409D853DEDF057494058AEB7CD544842409D853DEDF0574940
1044	Черкасское	1	1	46	36.145691999999997	36.178443999999999	50.818434000000003	50.794949000000003	0103000020E61000000100000005000000F8A41309A6124240747E8AE3C0654940F8A41309A61242409DF7FF71C26849406E15C440D71642409DF7FF71C26849406E15C440D7164240747E8AE3C0654940F8A41309A6124240747E8AE3C0654940
1604	Триречное	1	1	46	36.272902000000002	36.29589	50.794322999999999	50.780285999999997	0103000020E61000000100000005000000AA81E673EE22424069C36169E0634940AA81E673EE224240F5BA4560AC654940529B38B9DF254240F5BA4560AC654940529B38B9DF25424069C36169E0634940AA81E673EE22424069C36169E0634940
561	Томаровка	1	1	46	36.199644999999997	36.257863999999998	50.698652000000003	50.668762999999998	0103000020E61000000100000005000000ABE7A4F78D1942402EE3A6069A554940ABE7A4F78D1942407BA4C16D6D5949406A6803B0012142407BA4C16D6D5949406A6803B0012142402EE3A6069A554940ABE7A4F78D1942402EE3A6069A554940
2646	Терновка	1	1	46	36.583548999999998	36.605907999999999	50.744722000000003	50.718837999999998	0103000020E61000000100000005000000874ECFBBB14A42409F8F32E2025C4940874ECFBBB14A42404D4EED0C535F49404031B2648E4D42404D4EED0C535F49404031B2648E4D42409F8F32E2025C4940874ECFBBB14A42409F8F32E2025C4940
54	Строитель	1	1	46	36.444991999999999	36.50085	50.796868000000003	50.771172	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
53995	Строитель	1	1	46	36.444991999999999	36.50085	50.796868000000003	50.771172	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
2536	Стрелецкое	1	1	46	36.289889000000002	36.337985000000003	50.748044999999998	50.722648	0103000020E610000001000000050000002E3C2F151B2542408942CBBA7F5C49402E3C2F151B254240D97745F0BF5F4940F0C4AC17432B4240D97745F0BF5F4940F0C4AC17432B42408942CBBA7F5C49402E3C2F151B2542408942CBBA7F5C4940
455	Смородино	1	1	46	36.522984000000001	36.544822000000003	50.819516	50.808906999999998	0103000020E61000000100000005000000672AC423F1424240B340BB438A674940672AC423F14242403D4679E6E5684940171230BABC4542403D4679E6E5684940171230BABC454240B340BB438A674940672AC423F1424240B340BB438A674940
54019	Серетено	1	1	46	36.131903000000001	36.180160000000001	50.657080999999998	50.639175999999999	0103000020E61000000100000005000000459F8F32E2104240AD31E884D0514940459F8F32E210424057E9EE3A1B54494010069E7B0F17424057E9EE3A1B54494010069E7B0F174240AD31E884D0514940459F8F32E2104240AD31E884D0514940
1953	Сажное	1	1	46	36.623443000000002	36.729669000000001	50.838324999999998	50.782477999999998	0103000020E61000000100000005000000C7F5EFFACC4F424074EB353D28644940C7F5EFFACC4F4240A835CD3B4E6B4940D8F335CB655D4240A835CD3B4E6B4940D8F335CB655D424074EB353D28644940C7F5EFFACC4F424074EB353D28644940
1830	Сабынино	1	1	46	36.713957000000001	36.747706999999998	50.772579	50.756900999999999	0103000020E6100000010000000500000009E066F1625B4240A4A7C821E260494009E066F1625B4240C74961DEE3624940C1FEEBDCB45F4240C74961DEE3624940C1FEEBDCB45F4240A4A7C821E260494009E066F1625B4240A4A7C821E2604940
2428	Пушкарное	1	1	46	36.272399	36.306426999999999	50.731085999999998	50.703256000000003	0103000020E61000000100000005000000473B6EF8DD2242409F5BE84A045A4940473B6EF8DD2242401F48DE39945D494042CEFBFF382742401F48DE39945D494042CEFBFF382742409F5BE84A045A4940473B6EF8DD2242409F5BE84A045A4940
1494	Подымовка	1	1	46	36.110936000000002	36.118572	50.877789999999997	50.870241999999998	0103000020E610000001000000050000007BF99D26330E424085CD0017646F49407BF99D26330E4240BF60376C5B704940541C075E2D0F4240BF60376C5B704940541C075E2D0F424085CD0017646F49407BF99D26330E424085CD0017646F4940
1883	Озерово	1	1	46	36.652413000000003	36.686369999999997	50.846559999999997	50.805373000000003	0103000020E610000001000000050000001D3EE944825342406C0A6476166749401D3EE94482534240060DFD135C6C49404E7ADFF8DA574240060DFD135C6C49404E7ADFF8DA5742406C0A6476166749401D3EE944825342406C0A647616674940
2192	Новая Глинка	1	1	46	36.166550999999998	36.190463999999999	50.706929000000002	50.692033000000002	0103000020E61000000100000005000000DC0E0D8B511542405B608F8994584940DC0E0D8B5115424008CC43A67C5A49405D88D51F6118424008CC43A67C5A49405D88D51F611842405B608F8994584940DC0E0D8B511542405B608F8994584940
2305	Мощеное	1	1	46	36.12433	36.15719	50.694789	50.679169999999999	0103000020E61000000100000005000000B2F4A10BEA0F42405036E50AEF564940B2F4A10BEA0F42406E4F90D8EE5849400EA14ACD1E1442406E4F90D8EE5849400EA14ACD1E1442405036E50AEF564940B2F4A10BEA0F42405036E50AEF564940
934	Луханино	1	1	46	36.240186000000001	36.269694999999999	50.868701000000001	50.853924999999997	0103000020E61000000100000005000000817A336ABE1E42404F1E166A4D6D4940817A336ABE1E424052802898316F49408672A25D8522424052802898316F49408672A25D852242404F1E166A4D6D4940817A336ABE1E42404F1E166A4D6D4940
2243	Локня	1	1	46	36.079109000000003	36.096688999999998	50.718490000000003	50.706279000000002	0103000020E61000000100000005000000DEE8633E200A4240016DAB59675A4940DEE8633E200A42406440F67AF75B494004711E4E600C42406440F67AF75B494004711E4E600C4240016DAB59675A4940DEE8633E200A4240016DAB59675A4940
2137	Кустовое	1	1	46	36.157774000000003	36.202464999999997	50.666410999999997	50.653106999999999	0103000020E610000001000000050000005E143DF031144240F3E49A02995349405E143DF031144240EA58A5F44C554940D5CA845FEA194240EA58A5F44C554940D5CA845FEA194240F3E49A02995349405E143DF031144240F3E49A0299534940
1211	Крюково	1	1	46	36.625087000000001	36.643529000000001	50.811889999999998	50.804882999999997	0103000020E61000000100000005000000CF13CFD9025042409D0DF96706674940CF13CFD90250424087F9F202EC674940888384285F52424087F9F202EC674940888384285F5242409D0DF96706674940CF13CFD9025042409D0DF96706674940
1716	Кривцово	1	1	46	36.740564999999997	36.764344000000001	50.814064000000002	50.786361999999997	0103000020E61000000100000005000000F7C77BD5CA5E424098689082A7644940F7C77BD5CA5E4240EC6CC83F3368494069723106D6614240EC6CC83F3368494069723106D661424098689082A7644940F7C77BD5CA5E424098689082A7644940
54007	Красная Поляна	1	1	46	36.206372999999999	36.222093000000001	50.671041000000002	50.661968999999999	0103000020E6100000010000000500000082E3326E6A1A4240A0FB7266BB54494082E3326E6A1A424038A3E6ABE4554940D4D51D8B6D1C424038A3E6ABE4554940D4D51D8B6D1C4240A0FB7266BB54494082E3326E6A1A4240A0FB7266BB544940
2011	Калинино	1	1	46	36.211483999999999	36.246510000000001	50.623171999999997	50.613176000000003	0103000020E610000001000000050000004AD05FE8111B42409758198D7C4E49404AD05FE8111B424036E49F19C44F49408811C2A38D1F424036E49F19C44F49408811C2A38D1F42409758198D7C4E49404AD05FE8111B42409758198D7C4E4940
1553	Казацкое	1	1	46	36.228175	36.259194000000001	50.739078999999997	50.728622999999999	0103000020E61000000100000005000000E561A1D6341D4240840EBA84435D4940E561A1D6341D4240871403249A5E4940E3A8DC442D214240871403249A5E4940E3A8DC442D214240840EBA84435D4940E561A1D6341D4240840EBA84435D4940
1433	Завидовка	1	1	46	36.135441999999998	36.154747	50.863858	50.855072999999997	0103000020E610000001000000050000009E40D82956114240A7583508736D49409E40D82956114240A93121E6926E4940BA13ECBFCE134240A93121E6926E4940BA13ECBFCE134240A7583508736D49409E40D82956114240A7583508736D4940
2354	Драгунское	1	1	46	36.270037000000002	36.340204	50.767276000000003	50.734763999999998	0103000020E61000000100000005000000E0DA8992902242409A232BBF0C5E4940E0DA899290224240BB80971936624940F4FBFECD8B2B4240BB80971936624940F4FBFECD8B2B42409A232BBF0C5E4940E0DA8992902242409A232BBF0C5E4940
1366	Дмитриевка	1	1	46	36.330879000000003	36.374600000000001	50.834508	50.817791	0103000020E6100000010000000500000073F7393E5A2A424048FB1F60AD68494073F7393E5A2A42400C207C28D16A4940728A8EE4F22F42400C207C28D16A4940728A8EE4F22F424048FB1F60AD68494073F7393E5A2A424048FB1F60AD684940
1141	Гостищево	1	1	46	36.636926000000003	36.679453000000002	50.787255999999999	50.763778000000002	0103000020E610000001000000050000006EFC89CA86514240C0B33D7AC36149406EFC89CA8651424036CAFACDC4644940A515DF50F856424036CAFACDC4644940A515DF50F8564240C0B33D7AC36149406EFC89CA86514240C0B33D7AC3614940
2594	Вислое	1	1	46	36.586423000000003	36.609940999999999	50.768791	50.748843000000001	0103000020E61000000100000005000000A54FABE80F4B4240556B6116DA5F4940A54FABE80F4B4240C53A55BE67624940A9BEF38B124E4240C53A55BE67624940A9BEF38B124E4240556B6116DA5F4940A54FABE80F4B4240556B6116DA5F4940
1772	Верхний Ольшанец	1	1	46	36.812682000000002	36.841644000000002	50.793064000000001	50.770209999999999	0103000020E610000001000000050000002106BAF605684240AD86C43D966249402106BAF60568424046D1031F83654940F46F97FDBA6B424046D1031F83654940F46F97FDBA6B4240AD86C43D966249402106BAF605684240AD86C43D96624940
1078	Быковка	1	1	46	36.422587999999998	36.450938999999998	50.815185	50.800448000000003	0103000020E610000001000000050000004DD7135D1736424006137F14756649404DD7135D173642404A9869FB57684940D7BE805EB83942404A9869FB57684940D7BE805EB839424006137F14756649404DD7135D1736424006137F1475664940
938	Бутово	1	1	46	36.163936999999997	36.199986000000003	50.773381999999998	50.754956999999997	0103000020E610000001000000050000005BCD3AE3FB1442407171546EA26049405BCD3AE3FB14424054A86E2EFE62494035D428249919424054A86E2EFE62494035D42824991942407171546EA26049405BCD3AE3FB1442407171546EA2604940
860	Алексеевка	1	1	46	36.186826000000003	36.224572999999999	50.870547999999999	50.857035000000003	0103000020E61000000100000005000000710514EAE91742408143A852B36D4940710514EAE917424092CCEA1D6E6F49404548DDCEBE1C424092CCEA1D6E6F49404548DDCEBE1C42408143A852B36D4940710514EAE91742408143A852B36D4940
54038	Шебекинский	1	1	1249	36.562294000000001	37.577894000000001	50.692495000000001	50.219748000000003	0103000020E61000000100000005000000575EF23FF947424043AED4B3201C4940575EF23FF94742405FD218ADA3584940FE463B6EF8C942405FD218ADA3584940FE463B6EF8C9424043AED4B3201C4940575EF23FF947424043AED4B3201C4940
31987	Чураево	1	1	1249	36.863391999999997	36.882866999999997	50.505499	50.470998999999999	0103000020E6100000010000000500000063D009A1836E42406FB9FAB1493C494063D009A1836E42409294F430B4404940DBDB2DC9017142409294F430B4404940DBDB2DC9017142406FB9FAB1493C494063D009A1836E42406FB9FAB1493C4940
54027	Червона Дибровка	1	1	1249	37.265369999999997	37.291213999999997	50.532336999999998	50.508232	0103000020E6100000010000000500000075ABE7A4F7A14240ED6305BF0D41494075ABE7A4F7A14240B2B96A9E234449409411178046A54240B2B96A9E234449409411178046A54240ED6305BF0D41494075ABE7A4F7A14240ED6305BF0D414940
31916	Цепляево 1-е	1	1	1249	37.230812	37.267651999999998	50.509653	50.492728	0103000020E610000001000000050000001EC3633F8B9D424068E90AB6113F49401EC3633F8B9D424076A73B4F3C414940C05AB56B42A2424076A73B4F3C414940C05AB56B42A2424068E90AB6113F49401EC3633F8B9D424068E90AB6113F4940
31959	Сурково	1	1	1249	37.203843999999997	37.236220000000003	50.496268999999998	50.481167999999997	0103000020E610000001000000050000002FBE688F179A4240DCF0BBE9963D49402FBE688F179A424062821ABE853F4940A054FB743C9E424062821ABE853F4940A054FB743C9E4240DCF0BBE9963D49402FBE688F179A4240DCF0BBE9963D4940
30293	Стрелица 2-я	1	1	1249	37.087063000000001	37.115028000000002	50.671560999999997	50.645408000000003	0103000020E6100000010000000500000088D860E1248B4240D449B6BA9C52494088D860E1248B42407022FAB5F5554940E90FCD3CB98E42407022FAB5F5554940E90FCD3CB98E4240D449B6BA9C52494088D860E1248B4240D449B6BA9C524940
29806	Стрелица 1-я	1	1	1249	37.353682999999997	37.388987	50.656892999999997	50.644288000000003	0103000020E6100000010000000500000059130B7C45AD4240469A78077852494059130B7C45AD424054FCDF1115544940DAC87553CAB1424054FCDF1115544940DAC87553CAB14240469A78077852494059130B7C45AD4240469A780778524940
30320	Стариково	1	1	1249	37.031475999999998	37.053798999999998	50.589530000000003	50.578170999999998	0103000020E61000000100000005000000F04DD36707844240703FE081014A4940F04DD36707844240650113B8754B49405CC7B8E2E2864240650113B8754B49405CC7B8E2E2864240703FE081014A4940F04DD36707844240703FE081014A4940
31681	Середа	1	1	1249	36.601722000000002	36.648029999999999	50.255417999999999	50.228490999999998	0103000020E6100000010000000500000051A4FB39054D424015376E313F1D494051A4FB39054D4240A5677A89B1204940D769A4A5F2524240A5677A89B1204940D769A4A5F252424015376E313F1D494051A4FB39054D424015376E313F1D4940
30693	Ржевка	1	1	1249	36.969411000000001	36.998021999999999	50.445984000000003	50.417197000000002	0103000020E61000000100000005000000FBB0DEA8157C4240A27E17B666354940FBB0DEA8157C42400745F300163949402158552FBF7F42400745F300163949402158552FBF7F4240A27E17B666354940FBB0DEA8157C4240A27E17B666354940
31038	Репное	1	1	1249	37.004778000000002	37.038086999999997	50.563285999999998	50.534965	0103000020E61000000100000005000000C2DEC4909C80424098C0ADBB79444940C2DEC4909C804240B72572C1194849408DB3E908E0844240B72572C1194849408DB3E908E084424098C0ADBB79444940C2DEC4909C80424098C0ADBB79444940
30142	Поповка	1	1	1249	37.453315000000003	37.496470000000002	50.578057000000001	50.551977999999998	0103000020E61000000100000005000000A4E4D53906BA4240450E1137A7464940A4E4D53906BA4240A81C93C5FD494940FAB836548CBF4240A81C93C5FD494940FAB836548CBF4240450E1137A7464940A4E4D53906BA4240450E1137A7464940
31517	Поляна	1	1	1249	36.806294999999999	36.813355999999999	50.508541000000001	50.505133000000001	0103000020E61000000100000005000000D3F6AFAC34674240B090B932A8404940D3F6AFAC346742406BD619DF17414940B000A60C1C6842406BD619DF17414940B000A60C1C684240B090B932A8404940D3F6AFAC34674240B090B932A8404940
31730	Новая Таволжанка	1	1	1249	36.801775999999997	36.85201	50.368459999999999	50.31767	0103000020E61000000100000005000000DD5B9198A0664240CD751A69A9284940DD5B9198A06642402CF180B2292F4940B7EEE6A90E6D42402CF180B2292F4940B7EEE6A90E6D4240CD751A69A9284940DD5B9198A0664240CD751A69A9284940
32113	Никольское	1	1	1249	36.880710999999998	36.908523000000002	50.582346999999999	50.557718000000001	0103000020E610000001000000050000001D1D5723BB704240FD31AD4D634749401D1D5723BB7042403CF6B3588A4A4940F8544E7B4A7442403CF6B3588A4A4940F8544E7B4A744240FD31AD4D634749401D1D5723BB704240FD31AD4D63474940
29905	Нижнее Березово 2-е	1	1	1249	37.088132000000002	37.112414000000001	50.450923000000003	50.431355000000003	0103000020E6100000010000000500000094DDCCE8478B4240A9FB00A43637494094DDCCE8478B4240D20149D8B739494068CEFA94638E4240D20149D8B739494068CEFA94638E4240A9FB00A43637494094DDCCE8478B4240A9FB00A436374940
32175	Неклюдово	1	1	1249	36.901902999999997	36.927180999999997	50.602395000000001	50.574401999999999	0103000020E610000001000000050000000795B88E71734240E5603601864949400795B88E71734240102384471B4D49407D3CF4DDAD764240102384471B4D49407D3CF4DDAD764240E5603601864949400795B88E71734240E560360186494940
30628	Нежеголь	1	1	1249	36.999181	37.031951999999997	50.447659000000002	50.423217999999999	0103000020E610000001000000050000006DE4BA29E57F42400D8AE6012C3649406DE4BA29E57F42404A61DEE34C3949405985CD00178442404A61DEE34C3949405985CD00178442400D8AE6012C3649406DE4BA29E57F42400D8AE6012C364940
31593	Муром	1	1	1249	36.688625000000002	36.740448000000001	50.327246000000002	50.292298000000002	0103000020E61000000100000005000000A01A2FDD24584240D65757056A254940A01A2FDD2458424098DF6932E3294940BE310400C75E424098DF6932E3294940BE310400C75E4240D65757056A254940A01A2FDD24584240D65757056A254940
31292	Мешковое	1	1	1249	37.417634	37.433705000000003	50.488143000000001	50.477173000000001	0103000020E610000001000000050000004DD9E90775B5424061C43E01143D49404DD9E90775B54240BB6246787B3E49404C8E3BA583B74240BB6246787B3E49404C8E3BA583B7424061C43E01143D49404DD9E90775B5424061C43E01143D4940
31314	Маслова Пристань	1	1	1249	36.720371	36.753582000000002	50.465769999999999	50.443092999999998	0103000020E6100000010000000500000050FEEE1D355C4240130B7C45B738494050FEEE1D355C42409DBAF2599E3B4940596DFE5F756042409DBAF2599E3B4940596DFE5F75604240130B7C45B738494050FEEE1D355C4240130B7C45B7384940
30521	Маломихайловка	1	1	1249	37.067686999999999	37.098686999999998	50.439743	50.420876	0103000020E61000000100000005000000A3AEB5F7A9884240EDD5C743DF354940A3AEB5F7A98842408DD2A57F493849402AC58EC6A18C42408DD2A57F493849402AC58EC6A18C4240EDD5C743DF354940A3AEB5F7A9884240EDD5C743DF354940
31187	Максимовка	1	1	1249	37.312936000000001	37.371029999999998	50.531587000000002	50.518096	0103000020E61000000100000005000000DBDE6E490EA842401E1840F850424940DBDE6E490EA8424048FDF50A0B444940DDEA39E97DAF424048FDF50A0B444940DDEA39E97DAF42401E1840F850424940DBDE6E490EA842401E1840F850424940
30906	Купино	1	1	1249	36.991923	37.030352999999998	50.538691999999998	50.512259	0103000020E610000001000000050000003A933655F77E4240740AF2B3914149403A933655F77E4240F44E05DCF3444940F12A6B9BE2834240F44E05DCF3444940F12A6B9BE2834240740AF2B3914149403A933655F77E4240740AF2B391414940
30593	Красное	1	1	1249	37.137701	37.160212999999999	50.375044000000003	50.361587	0103000020E6100000010000000500000031D0B52FA091424052D4997B482E494031D0B52FA0914240D04719710130494070B20DDC81944240D04719710130494070B20DDC8194424052D4997B482E494031D0B52FA091424052D4997B482E4940
31008	Красная Поляна	1	1	1249	37.124127999999999	37.154850000000003	50.562908	50.536665999999997	0103000020E610000001000000050000004A42226DE38F42400470B378B14449404A42226DE38F424011548D5E0D4849408FE4F21FD293424011548D5E0D4849408FE4F21FD29342400470B378B14449404A42226DE38F42400470B378B1444940
32103	Крапивное	1	1	1249	36.860633999999997	36.893818000000003	50.462014000000003	50.445262	0103000020E61000000100000005000000AFE94141296E424066136058FE384940AFE94141296E4240A7255646233B4940BF49D3A068724240A7255646233B4940BF49D3A06872424066136058FE384940AFE94141296E424066136058FE384940
32038	Кошлаково	1	1	1249	36.862242000000002	36.884456999999998	50.534970999999999	50.508552999999999	0103000020E610000001000000050000006B9E23F25D6E42402FA4C343184149406B9E23F25D6E42407AA702EE79444940F0DB10E3357142407AA702EE79444940F0DB10E3357142402FA4C343184149406B9E23F25D6E42402FA4C34318414940
29994	Козьмодемьяновка	1	1	1249	37.121881999999999	37.139263999999997	50.459135000000003	50.447246	0103000020E610000001000000050000004CFC51D4998F424027A25F5B3F3949404CFC51D4998F424078B988EFC43A49404CC11A67D391424078B988EFC43A49404CC11A67D391424027A25F5B3F3949404CFC51D4998F424027A25F5B3F394940
29711	Караичное	1	1	1249	37.194474999999997	37.229779000000001	50.618423	50.608209000000002	0103000020E61000000100000005000000DE718A8EE49842400211E2CAD94D4940DE718A8EE49842400F0C207C284F49405F27F565699D42400F0C207C284F49405F27F565699D42400211E2CAD94D4940DE718A8EE49842400211E2CAD94D4940
54030	Ивановка	1	1	1249	36.717505000000003	36.736899999999999	50.442914999999999	50.428927999999999	0103000020E61000000100000005000000B6DB2E34D75B42405A2BDA1CE7364940B6DB2E34D75B424034F44F70B138494011363CBD525E424034F44F70B138494011363CBD525E42405A2BDA1CE7364940B6DB2E34D75B42405A2BDA1CE7364940
31108	Зимовное	1	1	1249	37.199244999999998	37.220911999999998	50.552298	50.528042999999997	0103000020E610000001000000050000001D7233DC80994240DCF0BBE9964349401D7233DC80994240B7D26BB3B1464940A0A52BD8469C4240B7D26BB3B1464940A0A52BD8469C4240DCF0BBE9964349401D7233DC80994240DCF0BBE996434940
29936	Зимовенька	1	1	1249	37.155738999999997	37.193972000000002	50.492161000000003	50.470534000000001	0103000020E610000001000000050000001ADB6B41EF934240FAD346753A3C49401ADB6B41EF934240EFAEB321FF3E49407C2B1213D4984240EFAEB321FF3E49407C2B1213D4984240FAD346753A3C49401ADB6B41EF934240FAD346753A3C4940
31634	Зиборовка	1	1	1249	36.656509999999997	36.681384000000001	50.383355999999999	50.361972000000002	0103000020E610000001000000050000009CBF098508544240AB083719552E49409CBF098508544240D95C35CF113149404302469737574240D95C35CF113149404302469737574240AB083719552E49409CBF098508544240AB083719552E4940
30939	Дмитриевка	1	1	1249	36.983280999999998	37.022852	50.500720999999999	50.474254999999999	0103000020E610000001000000050000009BE3DC26DC7D4240747B4963B43C49409BE3DC26DC7D4240D0B52FA017404940F85278D0EC824240D0B52FA017404940F85278D0EC824240747B4963B43C49409BE3DC26DC7D4240747B4963B43C4940
12823	Графовка	1	1	1249	36.732795000000003	36.745747999999999	50.403736000000002	50.395513999999999	0103000020E610000001000000050000000FD6FF39CC5D4240198EE733A03249400FD6FF39CC5D4240E31B0A9FAD3349405987A3AB745F4240E31B0A9FAD3349405987A3AB745F4240198EE733A03249400FD6FF39CC5D4240198EE733A0324940
30495	Вознесеновка	1	1	1249	37.000034999999997	37.045876	50.426775999999997	50.405515999999999	0103000020E610000001000000050000007CED9925018042409B00C3F2E73349407CED992501804240DD5B9198A0364940EDD5C743DF854240DD5B9198A0364940EDD5C743DF8542409B00C3F2E73349407CED9925018042409B00C3F2E7334940
54021	Верхнеберезово	1	1	1249	37.212575999999999	37.244447999999998	50.580401999999999	50.563326000000004	0103000020E610000001000000050000000EF5BBB0359B4240467EFD101B4849400EF5BBB0359B42403944DC9C4A4A49404BC972124A9F42403944DC9C4A4A49404BC972124A9F4240467EFD101B4849400EF5BBB0359B4240467EFD101B484940
30203	Булановка	1	1	1249	37.437154999999997	37.466233000000003	50.615788000000002	50.595477000000002	0103000020E610000001000000050000003524EEB1F4B7424096422097384C49403524EEB1F4B7424077A22424D24E494072A8DF85ADBB424077A22424D24E494072A8DF85ADBB424096422097384C49403524EEB1F4B7424096422097384C4940
30221	Большое Городище	1	1	1249	37.064658999999999	37.095911999999998	50.646476	50.614610999999996	0103000020E610000001000000050000002F3201BF468842408461C092AB4E49402F3201BF468842400FD3BEB9BF524940A0A52BD8468C42400FD3BEB9BF524940A0A52BD8468C42408461C092AB4E49402F3201BF468842408461C092AB4E4940
30386	Большетроицкое	1	1	1249	37.276491	37.310958999999997	50.563285999999998	50.528621000000001	0103000020E61000000100000005000000B5519D0E64A342404A7D59DAA9434940B5519D0E64A34240B72572C119484940CCB22781CDA74240B72572C119484940CCB22781CDA742404A7D59DAA9434940B5519D0E64A342404A7D59DAA9434940
30040	Бершаково	1	1	1249	37.430489000000001	37.459809999999997	50.553579999999997	50.542785000000002	0103000020E61000000100000005000000D52478431AB7424033E197FA79454940D52478431AB742401EDC9DB5DB464940D72FD80DDBBA42401EDC9DB5DB464940D72FD80DDBBA424033E197FA79454940D52478431AB7424033E197FA79454940
29854	Белянка	1	1	1249	37.157527000000002	37.207833000000001	50.477867000000003	50.454994999999997	0103000020E61000000100000005000000569E40D829944240F86BB2463D3A4940569E40D829944240386BF0BE2A3D4940C90391459A9A4240386BF0BE2A3D4940C90391459A9A4240F86BB2463D3A4940569E40D829944240F86BB2463D3A4940
29647	Белый Колодезь	1	1	1249	37.299478999999998	37.331952999999999	50.636153999999998	50.618675000000003	0103000020E610000001000000050000005D6BEF5355A6424029ED0DBE304F49405D6BEF5355A642401B9C887E6D5149409067976F7DAA42401B9C887E6D5149409067976F7DAA424029ED0DBE304F49405D6BEF5355A6424029ED0DBE304F4940
30833	Безлюдовка	1	1	1249	36.769626000000002	36.788176	50.400433999999997	50.391798000000001	0103000020E610000001000000050000005E13D21A83624240B151D66F263249405E13D21A836242406D1ADB6B41334940FDBE7FF3E26442406D1ADB6B41334940FDBE7FF3E2644240B151D66F263249405E13D21A83624240B151D66F26324940
31533	Батрацкая Дача	1	1	1249	36.814864999999998	36.836029000000003	50.571615999999999	50.564224000000003	0103000020E61000000100000005000000D8D30E7F4D68424025CFF57D38484940D8D30E7F4D68424067EF8CB62A494940F9C08EFF026B424067EF8CB62A494940F9C08EFF026B424025CFF57D38484940D8D30E7F4D68424025CFF57D38484940
31855	Архангельское	1	1	1249	36.768799000000001	36.803097000000001	50.365340000000003	50.344890999999997	0103000020E610000001000000050000004819710168624240A5D76663252C49404819710168624240D8F50B76C32E49400342EBE1CB664240D8F50B76C32E49400342EBE1CB664240A5D76663252C49404819710168624240A5D76663252C4940
29750	Артельное	1	1	1249	37.302191999999998	37.329788000000001	50.617440000000002	50.592967000000002	0103000020E61000000100000005000000718E3A3AAEA64240BA4DB857E64B4940718E3A3AAEA64240029F1F46084F49407F4E417E36AA4240029F1F46084F49407F4E417E36AA4240BA4DB857E64B4940718E3A3AAEA64240BA4DB857E64B4940
54073	Андреевка	1	1	1249	37.225341	37.232132	50.648349000000003	50.644043000000003	0103000020E6100000010000000500000056B950F9D79C4240DF1B43007052494056B950F9D79C424079B29B19FD524940732D5A80B69D424079B29B19FD524940732D5A80B69D4240DF1B43007052494056B950F9D79C4240DF1B430070524940
30094	Александровка	1	1	1249	37.509757	37.523851000000001	50.533293999999998	50.525740999999996	0103000020E610000001000000050000001BF4A5B73FC142404A95287B4B4349401BF4A5B73FC14240969350FA424449400B7DB08C0DC34240969350FA424449400B7DB08C0DC342404A95287B4B4349401BF4A5B73FC142404A95287B4B434940
54065	Яблоново	1	1	1807	37.809578000000002	37.829098999999999	51.033048999999998	51.010244	0103000020E61000000100000005000000D2C77C40A0E74240787DE6AC4F814940D2C77C40A0E742402F151BF33A844940BA1281EA1FEA42402F151BF33A844940BA1281EA1FEA4240787DE6AC4F814940D2C77C40A0E74240787DE6AC4F814940
26758	Чернянка	1	1	1807	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
27606	Холки	1	1	1807	37.688952	37.763098999999997	50.870787	50.838273000000001	0103000020E61000000100000005000000C44142942FD84240560F98874C6B4940C44142942FD842401764CBF2756F49401E4E603AADE142401764CBF2756F49401E4E603AADE14240560F98874C6B4940C44142942FD84240560F98874C6B4940
48014	Хитрово	1	1	1807	38.017035	38.036079000000001	50.987144999999998	50.973132	0103000020E6100000010000000500000095F1EF332E0243407558E1968F7C494095F1EF332E02434078B471C45A7E49404489963C9E04434078B471C45A7E49404489963C9E0443407558E1968F7C494095F1EF332E0243407558E1968F7C4940
48002	Славянка	1	1	1807	37.970726999999997	37.992438999999997	51.064328000000003	51.045656000000001	0103000020E610000001000000050000000E2C47C840FC4240DF6E490ED88549400E2C47C840FC4240CA1B60E63B8849403123BC3D08FF4240CA1B60E63B8849403123BC3D08FF4240DF6E490ED88549400E2C47C840FC4240DF6E490ED8854940
28548	Русская Халань	1	1	1807	37.707593000000003	37.746713999999997	50.955416	50.934055000000001	0103000020E6100000010000000500000074F04C6892DA424028D53E1D8F77494074F04C6892DA42409E094D124B7A494090BB085394DF42409E094D124B7A494090BB085394DF424028D53E1D8F77494074F04C6892DA424028D53E1D8F774940
48247	Прилепы	1	1	1807	37.582053000000002	37.631272000000003	50.939946999999997	50.923257	0103000020E61000000100000005000000F4C473B680CA4240CB660E492D764940F4C473B680CA4240957CEC2E50784940B5705985CDD04240957CEC2E50784940B5705985CDD04240CB660E492D764940F4C473B680CA4240CB660E492D764940
48182	Орлик	1	1	1807	37.675891	37.749040999999998	51.077537	51.047960000000003	0103000020E610000001000000050000009354A69883D6424012C2A38D238649409354A69883D642406F9D7FBBEC8949407B2E5393E0DF42406F9D7FBBEC8949407B2E5393E0DF424012C2A38D238649409354A69883D6424012C2A38D23864940
48148	Ольшанка	1	1	1807	37.646856999999997	37.710943	51.014851	51.000217999999997	0103000020E610000001000000050000002618CE35CCD242406D6FB724078049402618CE35CCD242400DA837A3E6814940FA28232E00DB42400DA837A3E6814940FA28232E00DB42406D6FB724078049402618CE35CCD242406D6FB72407804940
47836	Окуни	1	1	1807	37.828667000000003	37.870493000000003	51.032493000000002	51.011088000000001	0103000020E610000001000000050000002123A0C211EA424064B0E2546B8149402123A0C211EA4240AA2C0ABB28844940CF328B506CEF4240AA2C0ABB28844940CF328B506CEF424064B0E2546B8149402123A0C211EA424064B0E2546B814940
48087	Огибное	1	1	1807	37.545186000000001	37.590820999999998	51.076591999999998	51.051799000000003	0103000020E61000000100000005000000581EA4A7C8C54240967B8159A1864940581EA4A7C8C542404F9143C4CD8949401F65C405A0CB42404F9143C4CD8949401F65C405A0CB4240967B8159A1864940581EA4A7C8C54240967B8159A1864940
27971	Новоречье	1	1	1807	38.169488000000001	38.238703000000001	51.036684999999999	51.002586999999998	0103000020E61000000100000005000000408864C8B1154340873254C554804940408864C8B11543407BA01518B2844940823AE5D18D1E43407BA01518B2844940823AE5D18D1E4340873254C554804940408864C8B1154340873254C554804940
27569	Новая Масловка	1	1	1807	37.921598000000003	37.965237999999999	50.902597	50.877312000000003	0103000020E610000001000000050000008E075BECF6F54240B63176C24B7049408E075BECF6F54240DE3B6A4C88734940A06D35EB8CFB4240DE3B6A4C88734940A06D35EB8CFB4240B63176C24B7049408E075BECF6F54240B63176C24B704940
54059	Малый	1	1	1807	37.902985000000001	37.931910999999999	50.939287999999998	50.922542	0103000020E61000000100000005000000A8E3310395F34240DD9733DB15764940A8E3310395F342403BC3D4963A7849402EE411DC48F742403BC3D4963A7849402EE411DC48F74240DD9733DB15764940A8E3310395F34240DD9733DB15764940
27767	Малотроицкое	1	1	1807	38.011977999999999	38.059911999999997	51.05386	51.021383999999998	0103000020E61000000100000005000000C022BF7E880143402E54FEB5BC824940C022BF7E8801434002486DE2E4864940A8514832AB07434002486DE2E4864940A8514832AB0743402E54FEB5BC824940C022BF7E880143402E54FEB5BC824940
31398	Малиново	1	1	1807	38.000281999999999	38.022936999999999	50.908383999999998	50.897336000000003	0103000020E610000001000000050000008463963D0900434001C3F2E7DB7249408463963D09004340D61A4AED45744940266F8099EF024340D61A4AED45744940266F8099EF02434001C3F2E7DB7249408463963D0900434001C3F2E7DB724940
27746	Лубяное 1-е	1	1	1807	38.219110999999998	38.253849000000002	50.963728000000003	50.946103999999998	0103000020E61000000100000005000000D09849D40B1C4340B14E95EF19794940D09849D40B1C4340A81E69705B7B4940A88FC01F7E204340A81E69705B7B4940A88FC01F7E204340B14E95EF19794940D09849D40B1C4340B14E95EF19794940
47938	Лозное	1	1	1807	37.493892000000002	37.529114999999997	50.892121000000003	50.868468	0103000020E61000000100000005000000C6E061DA37BF4240AFCF9CF5296F4940C6E061DA37BF424094895B05317249405969520ABAC3424094895B05317249405969520ABAC34240AFCF9CF5296F4940C6E061DA37BF4240AFCF9CF5296F4940
27996	Ларисовка	1	1	1807	38.252529000000003	38.306652	51.046658000000001	51.018495000000001	0103000020E610000001000000050000005325CADE52204340DC114E0B5E8249405325CADE52204340630CACE3F885494062A06B5F40274340630CACE3F885494062A06B5F40274340DC114E0B5E8249405325CADE52204340DC114E0B5E824940
54022	Красный Остров	1	1	1807	37.771183999999998	37.790362999999999	50.949548999999998	50.938420000000001	0103000020E6100000010000000500000067994528B6E24240C7F484251E78494067994528B6E24240897956D28A794940F67B629D2AE54240897956D28A794940F67B629D2AE54240C7F484251E78494067994528B6E24240C7F484251E784940
27654	Кочегуры	1	1	1807	37.552624000000002	37.644871999999999	51.023220000000002	51.008963000000001	0103000020E610000001000000050000000B7E1B62BCC64240E1EF17B3258149400B7E1B62BCC642407B4E7ADFF8824940950D6B2A8BD242407B4E7ADFF8824940950D6B2A8BD24240E1EF17B3258149400B7E1B62BCC64240E1EF17B325814940
28268	Комаревцево	1	1	1807	37.740740000000002	37.759776000000002	51.104053	51.082816999999999	0103000020E61000000100000005000000666B7D91D0DE4240C34659BF998A4940666B7D91D0DE42407D06D49B518D49409224085740E142407D06D49B518D49409224085740E14240C34659BF998A4940666B7D91D0DE4240C34659BF998A4940
48253	Ковылино	1	1	1807	37.636409999999998	37.666854000000001	50.948	50.929122	0103000020E61000000100000005000000766C04E275D142403FFF3D78ED764940766C04E275D14240D34D621058794940789ACC785BD54240D34D621058794940789ACC785BD542403FFF3D78ED764940766C04E275D142403FFF3D78ED764940
48155	Захарово	1	1	1807	37.692473999999997	37.741962000000001	50.998607999999997	50.989061	0103000020E6100000010000000500000047AAEFFCA2D84240E15F048D997E494047AAEFFCA2D8424011C30E63D27F4940F86F5E9CF8DE424011C30E63D27F4940F86F5E9CF8DE4240E15F048D997E494047AAEFFCA2D84240E15F048D997E4940
27338	Завалищено	1	1	1807	37.812362999999998	37.836294000000002	51.051459999999999	51.037880000000001	0103000020E610000001000000050000007FBDC282FBE7424014967840D98449407FBDC282FBE74240AD86C43D96864940A7EB89AE0BEB4240AD86C43D96864940A7EB89AE0BEB424014967840D98449407FBDC282FBE7424014967840D9844940
47870	Ездочное	1	1	1807	37.772019999999998	37.797721000000003	50.908237	50.861294000000001	0103000020E61000000100000005000000D0ED258DD1E24240DA1EBDE13E6E4940D0ED258DD1E2424032022A1C417449408D2AC3B81BE6424032022A1C417449408D2AC3B81BE64240DA1EBDE13E6E4940D0ED258DD1E24240DA1EBDE13E6E4940
48211	Воскресеновка	1	1	1807	37.741621000000002	37.767572999999999	51.044539999999998	51.034441999999999	0103000020E610000001000000050000006F83DA6FEDDE4240EECD6F98688449406F83DA6FEDDE424092AE997CB3854940742502D53FE2424092AE997CB3854940742502D53FE24240EECD6F98688449406F83DA6FEDDE4240EECD6F9868844940
47852	Волотово	1	1	1807	38.126181000000003	38.169767	50.950065000000002	50.925238999999998	0103000020E610000001000000050000003430F2B226104340EBFD463B6E7649403430F2B2261043408109DCBA9B7949405378D0ECBA1543408109DCBA9B7949405378D0ECBA154340EBFD463B6E7649403430F2B226104340EBFD463B6E764940
27307	Волоконовка	1	1	1807	37.844881999999998	37.873474999999999	51.064520000000002	51.043939999999999	0103000020E61000000100000005000000527DE71725EC42403D7E6FD39F854940527DE71725EC42400EF8FC3042884940D26F5F07CEEF42400EF8FC3042884940D26F5F07CEEF42403D7E6FD39F854940527DE71725EC42403D7E6FD39F854940
54056	Волково	1	1	1807	37.584029000000001	37.627121000000002	51.097242999999999	51.076751000000002	0103000020E6100000010000000500000032755776C1CA4240B8770DFAD289494032755776C1CA4240E9616875728C494042D13C8045D04240E9616875728C494042D13C8045D04240B8770DFAD289494032755776C1CA4240B8770DFAD2894940
28474	Водяное	1	1	1807	37.477075999999997	37.495050999999997	50.965882999999998	50.960267000000002	0103000020E610000001000000050000006EDA8CD310BD4240CA367007EA7A49406EDA8CD310BD42409561DC0DA27B4940116DC7D45DBF42409561DC0DA27B4940116DC7D45DBF4240CA367007EA7A49406EDA8CD310BD4240CA367007EA7A4940
28463	Верхнее Кузькино	1	1	1807	37.534559000000002	37.575476999999999	50.931302000000002	50.887540999999999	0103000020E610000001000000050000002864E76D6CC44240F86D88F19A7149402864E76D6CC44240865968E734774940D34CF73AA9C94240865968E734774940D34CF73AA9C94240F86D88F19A7149402864E76D6CC44240F86D88F19A714940
27198	Бородин	1	1	1807	37.932495000000003	37.954728000000003	50.994191999999998	50.982847	0103000020E610000001000000050000007E5704FF5BF7424061FC34EECD7D49407E5704FF5BF74240F0F8F6AE417F4940AA49F08634FA4240F0F8F6AE417F4940AA49F08634FA424061FC34EECD7D49407E5704FF5BF7424061FC34EECD7D4940
54025	Большое	1	1	1807	37.94464	38.012929999999997	50.953060999999998	50.934952000000003	0103000020E61000000100000005000000293FA9F6E9F8424037AAD381AC774940293FA9F6E9F84240E90B21E7FD7949409291B3B0A7014340E90B21E7FD7949409291B3B0A701434037AAD381AC774940293FA9F6E9F8424037AAD381AC774940
48038	Баклановка	1	1	1807	38.124724999999998	38.146923000000001	51.023684000000003	51.009127999999997	0103000020E610000001000000050000002EFF21FDF60F43402BBD361B2B8149402EFF21FDF60F434020B8CA1308834940DE03745FCE12434020B8CA1308834940DE03745FCE1243402BBD361B2B8149402EFF21FDF60F43402BBD361B2B814940
54078	Александровка	1	1	1807	38.091738999999997	38.123144000000003	50.975577000000001	50.954008999999999	0103000020E610000001000000050000004562821ABE0B43407A8B87F71C7A49404562821ABE0B43406ADD06B5DF7C49406D59BE2EC30F43406ADD06B5DF7C49406D59BE2EC30F43407A8B87F71C7A49404562821ABE0B43407A8B87F71C7A4940
53986	Старый Оскол	1	1	7305	37.469853000000001	37.481926999999999	50.406187000000003	50.400433999999997	0103000020E61000000100000005000000B876A22424BC42406D1ADB6B41334940B876A22424BC4240BA8784EFFD3349409A07B0C8AFBD4240BA8784EFFD3349409A07B0C8AFBD42406D1ADB6B41334940B876A22424BC42406D1ADB6B41334940
54070	с.Верхнечуфичево	1	1	1473	37.723905999999999	37.752552999999999	51.225408000000002	51.211005	0103000020E6100000010000000500000068B0A9F3A8DC424070253B36029B494068B0A9F3A8DC4240DE205A2BDA9C4940DBC01DA853E04240DE205A2BDA9C4940DBC01DA853E0424070253B36029B494068B0A9F3A8DC424070253B36029B4940
53988	микрорайон Королева	1	1	1473	37.586598000000002	38.527251	51.432057999999998	51.020795	0103000020E6100000010000000500000013F3ACA415CB4240CD751A69A982494013F3ACA415CB4240D2FC31AD4DB7494043E4F4F57C434340D2FC31AD4DB7494043E4F4F57C434340CD751A69A982494013F3ACA415CB4240CD751A69A9824940
47069	Шмарное	1	1	1473	37.845691000000002	37.877158999999999	51.128720999999999	51.115763999999999	0103000020E61000000100000005000000C2C2499A3FEC4240EE06D15AD18E4940C2C2499A3FEC42407AA702EE799049402F3201BF46F042407AA702EE799049402F3201BF46F04240EE06D15AD18E4940C2C2499A3FEC4240EE06D15AD18E4940
47534	Шаталовка	1	1	1473	38.260263000000002	38.296232000000003	51.153669999999998	51.126862000000003	0103000020E61000000100000005000000EFAD484C50214340768D96033D904940EFAD484C502143402B306475AB934940AC0320EEEA2543402B306475AB934940AC0320EEEA254340768D96033D904940EFAD484C50214340768D96033D904940
25999	Черниково	1	1	1473	37.999338000000002	38.027104999999999	51.233744000000002	51.218870000000003	0103000020E6100000010000000500000035D3BD4EEAFF4240AB09A2EE039C494035D3BD4EEAFF424070D1C952EB9D49406F47382D7803434070D1C952EB9D49406F47382D78034340AB09A2EE039C494035D3BD4EEAFF4240AB09A2EE039C4940
47258	Хорошилово	1	1	1473	38.050632	38.100003999999998	51.279981999999997	51.257756999999998	0103000020E61000000100000005000000C710001C7B06434054A86E2EFEA04940C710001C7B064340FDBB3E73D6A349400EBC5AEECC0C4340FDBB3E73D6A349400EBC5AEECC0C434054A86E2EFEA04940C710001C7B06434054A86E2EFEA04940
26495	Федосеевка	1	1	1473	37.772162999999999	37.814329999999998	51.370294999999999	51.331660999999997	0103000020E610000001000000050000003317B83CD6E24240E82D1EDE73AA49403317B83CD6E24240A86F99D365AF49406A1327F73BE84240A86F99D365AF49406A1327F73BE84240E82D1EDE73AA49403317B83CD6E24240E82D1EDE73AA4940
40476	Терехово	1	1	1473	38.032494999999997	38.069451999999998	51.360532999999997	51.326247000000002	0103000020E610000001000000050000004A24D1CB2804434085B53176C2A949404A24D1CB280443407B1002F225AE494026529ACDE30843407B1002F225AE494026529ACDE308434085B53176C2A949404A24D1CB2804434085B53176C2A94940
54015	Старый Оскол	1	1	1473	37.586598000000002	38.527251	51.432057999999998	51.020795	0103000020E6100000010000000500000013F3ACA415CB4240CD751A69A982494013F3ACA415CB4240D2FC31AD4DB7494043E4F4F57C434340D2FC31AD4DB7494043E4F4F57C434340CD751A69A982494013F3ACA415CB4240CD751A69A9824940
26232	Роговатое	1	1	1473	38.349680999999997	38.427546999999997	51.248517	51.201276	0103000020E610000001000000050000002B84D558C22C43401FBC7669C39949402B84D558C22C434001C0B167CF9F49405F402FDCB936434001C0B167CF9F49405F402FDCB93643401FBC7669C39949402B84D558C22C43401FBC7669C3994940
47416	Преображенка	1	1	1473	38.475130999999998	38.494562000000002	51.186509999999998	51.162126999999998	0103000020E610000001000000050000006B28B517D13C43403866D993C09449406B28B517D13C43404030478FDF97494014ECBFCE4D3F43404030478FDF97494014ECBFCE4D3F43403866D993C09449406B28B517D13C43403866D993C0944940
26175	Потудань	1	1	1473	38.228912000000001	38.262554000000002	51.286050000000003	51.249070000000003	0103000020E61000000100000005000000BBD408FD4C1D434016359886E19F4940BBD408FD4C1D4340AA8251499DA449408DB7955E9B214340AA8251499DA449408DB7955E9B21434016359886E19F4940BBD408FD4C1D434016359886E19F4940
54004	Песчанка	1	1	1473	37.700792	37.757395000000002	51.308306999999999	51.292814999999997	0103000020E6100000010000000500000033A6608DB3D942409D6340F67AA5494033A6608DB3D942405E10919A76A74940B493C151F2E042405E10919A76A74940B493C151F2E042409D6340F67AA5494033A6608DB3D942409D6340F67AA54940
47217	Озерки	1	1	1473	38.004423000000003	38.034849000000001	51.258766000000001	51.237720000000003	0103000020E61000000100000005000000D42CD0EE9000434075CDE49B6D9E4940D42CD0EE900043408BA8893E1FA149402FA699EE750443408BA8893E1FA149402FA699EE7504434075CDE49B6D9E4940D42CD0EE9000434075CDE49B6D9E4940
47196	Обуховка	1	1	1473	37.962966000000002	37.985360999999997	51.185088	51.172581000000001	0103000020E6100000010000000500000079944A7842FB42409B745B221796494079944A7842FB4240E770ADF6B09749407EE02A4F20FE4240E770ADF6B09749407EE02A4F20FE42409B745B221796494079944A7842FB42409B745B2217964940
25823	Новокладовое	1	1	1473	37.907234000000003	37.936286000000003	51.393802999999998	51.371346000000003	0103000020E61000000100000005000000DEE8633E20F442400EC0064488AF4940DEE8633E20F442408908FF2268B24940F1D93A38D8F742408908FF2268B24940F1D93A38D8F742400EC0064488AF4940DEE8633E20F442400EC0064488AF4940
47251	Николаевка	1	1	1473	37.689293999999997	37.830689	51.317354000000002	51.082493999999997	0103000020E610000001000000050000001DAA29C93AD84240E00ED4298F8A49401DAA29C93AD842409DA04D0E9FA84940CF12640454EA42409DA04D0E9FA84940CF12640454EA4240E00ED4298F8A49401DAA29C93AD84240E00ED4298F8A4940
25842	Незнамово	1	1	1473	37.895178999999999	37.959642000000002	51.279243999999998	51.260688000000002	0103000020E610000001000000050000007288B83995F24240D63A71395EA149407288B83995F2424057CD7344BEA349401CEF8E8CD5FA424057CD7344BEA349401CEF8E8CD5FA4240D63A71395EA149407288B83995F24240D63A71395EA14940
47029	Монаково	1	1	1473	37.760781999999999	37.797091999999999	51.160420999999999	51.149258000000003	0103000020E6100000010000000500000057B1F84D61E142404C55DAE21A93494057B1F84D61E14240BA4BE2AC889449409DF3531C07E64240BA4BE2AC889449409DF3531C07E642404C55DAE21A93494057B1F84D61E142404C55DAE21A934940
16865	Лапыгино	1	1	1473	37.948664000000001	37.981489000000003	51.371560000000002	51.351618000000002	0103000020E610000001000000050000003F726BD26DF94240AC5791D101AD49403F726BD26DF942403A4030478FAF49401F317A6EA1FD42403A4030478FAF49401F317A6EA1FD4240AC5791D101AD49403F726BD26DF94240AC5791D101AD4940
46955	Крутое	1	1	1473	38.203606000000001	38.235388999999998	51.095393000000001	51.070439999999998	0103000020E610000001000000050000007BA2EBC20F1A4340452A8C2D048949407BA2EBC20F1A434038A27BD6358C4940486B0C3A211E434038A27BD6358C4940486B0C3A211E4340452A8C2D048949407BA2EBC20F1A4340452A8C2D04894940
47133	Котово	1	1	1473	37.976809000000003	38.039259999999999	51.328724000000001	51.287633	0103000020E6100000010000000500000020B8CA1308FD42400C207C28D1A4494020B8CA1308FD424085B4C6A013AA49403E05C0780605434085B4C6A013AA49403E05C078060543400C207C28D1A4494020B8CA1308FD42400C207C28D1A44940
47498	Каплино	1	1	1473	37.797451000000002	37.874777999999999	51.369748999999999	51.328178000000001	0103000020E61000000100000005000000CD94D6DF12E6424023A298BC01AA4940CD94D6DF12E64240465D6BEF53AF494051A1BAB9F8EF4240465D6BEF53AF494051A1BAB9F8EF424023A298BC01AA4940CD94D6DF12E6424023A298BC01AA4940
25684	Казачок	1	1	1473	37.874194000000003	37.905392999999997	51.125867	51.103645	0103000020E61000000100000005000000022EC896E5EF42406CB2463D448D4940022EC896E5EF4240A452EC681C9049407F83F6EAE3F34240A452EC681C9049407F83F6EAE3F342406CB2463D448D4940022EC896E5EF42406CB2463D448D4940
47142	Ивановка	1	1	1473	37.850918999999998	37.867708	51.105387	51.089770000000001	0103000020E61000000100000005000000C345EEE9EAEC4240BA1457957D8B4940C345EEE9EAEC424037363B527D8D4940213D450E11EF424037363B527D8D4940213D450E11EF4240BA1457957D8B4940C345EEE9EAEC4240BA1457957D8B4940
47083	Знаменка	1	1	1473	38.258763000000002	38.294218999999998	51.217663000000002	51.175556999999998	0103000020E610000001000000050000001A355F251F214340BCCADAA6789649401A355F251F2143404E469561DC9B4940506EDBF7A82543404E469561DC9B4940506EDBF7A8254340BCCADAA6789649401A355F251F214340BCCADAA678964940
46990	Долгая Поляна	1	1	1473	37.716763999999998	37.748744000000002	51.162517000000001	51.143782999999999	0103000020E610000001000000050000009E7939ECBEDB4240425C397B679249409E7939ECBEDB4240A305685BCD944940C289E8D7D6DF4240A305685BCD944940C289E8D7D6DF4240425C397B679249409E7939ECBEDB4240425C397B67924940
54001	Дмитриевка	1	1	1473	38.097731000000003	38.145646999999997	51.241509000000001	51.203935000000001	0103000020E6100000010000000500000017670C73820C434040C1C58A1A9A494017670C73820C4340475854C4E99E494058E1968FA4124340475854C4E99E494058E1968FA412434040C1C58A1A9A494017670C73820C434040C1C58A1A9A4940
46915	Городище	1	1	1473	37.999302	38.120987999999997	51.165385999999998	51.062528	0103000020E61000000100000005000000E869C020E9FF4240CA8AE1EA00884940E869C020E9FF4240AE9B525E2B954940AE9AE7887C0F4340AE9B525E2B954940AE9AE7887C0F4340CA8AE1EA00884940E869C020E9FF4240CA8AE1EA00884940
49369	Голофеевка	1	1	1473	37.896023	37.907198000000001	51.135108000000002	51.128070999999998	0103000020E610000001000000050000005EBBB4E1B0F2424073486AA1649049405EBBB4E1B0F24240C8B60C384B914940917F66101FF44240C8B60C384B914940917F66101FF4424073486AA1649049405EBBB4E1B0F2424073486AA164904940
46859	Архангельское	1	1	1473	38.089798999999999	38.133941999999998	51.267952000000001	51.244914999999999	0103000020E61000000100000005000000541B9C887E0B434061A6ED5F599F4940541B9C887E0B4340EB724A404CA24940C9C7EE0225114340EB724A404CA24940C9C7EE022511434061A6ED5F599F4940541B9C887E0B434061A6ED5F599F4940
21023	Шияны	1	1	474	38.830936000000001	38.871791000000002	49.881072000000003	49.866760999999997	0103000020E61000000100000005000000D788601C5C6A434060394206F2EE4840D788601C5C6A4340EEB5A0F7C6F048403CF9F4D8966F4340EEB5A0F7C6F048403CF9F4D8966F434060394206F2EE4840D788601C5C6A434060394206F2EE4840
21255	Харьковское	1	1	474	39.031018000000003	39.064901999999996	50.212980999999999	50.195332999999998	0103000020E610000001000000050000002ECBD765F88343402F6AF7AB001949402ECBD765F8834340AED51EF6421B4940F5B86FB54E884340AED51EF6421B4940F5B86FB54E8843402F6AF7AB001949402ECBD765F88343402F6AF7AB00194940
21243	Свистовка	1	1	474	38.938132000000003	38.979517000000001	50.091985999999999	50.077939999999998	0103000020E6100000010000000500000061AA99B5147843406E861BF0F909494061AA99B5147843404DD87E32C60B4940227024D0607D43404DD87E32C60B4940227024D0607D43406E861BF0F909494061AA99B5147843406E861BF0F9094940
49028	Саловка	1	1	474	38.834394000000003	38.845300000000002	50.076211999999998	50.069730999999997	0103000020E6100000010000000500000044FD2E6CCD6A4340394206F2EC08494044FD2E6CCD6A434008C89750C109494087A757CA326C434008C89750C109494087A757CA326C4340394206F2EC08494044FD2E6CCD6A4340394206F2EC084940
20522	Ровеньки	1	1	474	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
21087	Ржевка	1	1	474	39.049846000000002	39.077666999999998	50.073141999999997	50.049224000000002	0103000020E6100000010000000500000010EB8D5A61864340D316D7F84C06494010EB8D5A6186434065FB90B75C0949403D7D04FEF089434065FB90B75C0949403D7D04FEF0894340D316D7F84C06494010EB8D5A61864340D316D7F84C064940
19646	Пристень	1	1	474	38.836317000000001	38.888769000000003	50.110008000000001	50.084876999999999	0103000020E610000001000000050000005F0B7A6F0C6B43405F97E13FDD0A49405F0B7A6F0C6B43403126FDBD140E49406D59BE2EC37143403126FDBD140E49406D59BE2EC37143405F97E13FDD0A49405F0B7A6F0C6B43405F97E13FDD0A4940
20410	Новоалександровка	1	1	474	38.86562	38.924343	50.175559999999997	50.124327000000001	0103000020E61000000100000005000000BB61DBA2CC6E4340418177F2E90F4940BB61DBA2CC6E43402D3E05C078164940ADA415DF507643402D3E05C078164940ADA415DF50764340418177F2E90F4940BB61DBA2CC6E4340418177F2E90F4940
19752	Нижняя Серебрянка	1	1	474	38.933154999999999	38.967892999999997	49.832357000000002	49.823779999999999	0103000020E61000000100000005000000A88C7F9F71774340A88C7F9F71E94840A88C7F9F7177434060CC96AC8AEA48407F83F6EAE37B434060CC96AC8AEA48407F83F6EAE37B4340A88C7F9F71E94840A88C7F9F71774340A88C7F9F71E94840
20121	Нагорье	1	1	474	39.041069999999998	39.097932999999998	50.045053000000003	50.023406999999999	0103000020E61000000100000005000000616C21C841854340ADBF2500FF024940616C21C84185434019CBF44BC40549407E198C11898C434019CBF44BC40549407E198C11898C4340ADBF2500FF024940616C21C841854340ADBF2500FF024940
20029	Нагольное	1	1	474	38.962026999999999	39.032122000000001	49.996724999999998	49.960327999999997	0103000020E610000001000000050000003B6F63B3237B43406FB72407ECFA48403B6F63B3237B4340840D4FAF94FF4840B6BDDD921C844340840D4FAF94FF4840B6BDDD921C8443406FB72407ECFA48403B6F63B3237B43406FB72407ECFA4840
21328	Масловка	1	1	474	39.046351999999999	39.102846999999997	50.259045999999998	50.240169999999999	0103000020E61000000100000005000000560DC2DCEE8543407BBDFBE3BD1E4940560DC2DCEE8543406E14596B28214940F0BE2A172A8D43406E14596B28214940F0BE2A172A8D43407BBDFBE3BD1E4940560DC2DCEE8543407BBDFBE3BD1E4940
21180	Мартынцы	1	1	474	39.077765999999997	39.106915999999998	50.116419999999998	50.096516999999999	0103000020E61000000100000005000000D05E7D3CF4894340074147AB5A0C4940D05E7D3CF4894340D74CBED9E60E4940A6B5696CAF8D4340D74CBED9E60E4940A6B5696CAF8D4340074147AB5A0C4940D05E7D3CF4894340074147AB5A0C4940
19862	Лозовое	1	1	474	39.128413000000002	39.159269999999999	49.928646999999998	49.916443999999998	0103000020E61000000100000005000000CDB051D66F904340C64E78094EF54840CDB051D66F904340A643A7E7DDF64840F19D98F562944340A643A7E7DDF64840F19D98F562944340C64E78094EF54840CDB051D66F904340C64E78094EF54840
19791	Лозная	1	1	474	38.721234000000003	38.807507999999999	49.985055000000003	49.947571000000003	0103000020E61000000100000005000000B3614D65515C4340ABD1AB014AF94840B3614D65515C434072E1404816FE484012A1116C5C67434072E1404816FE484012A1116C5C674340ABD1AB014AF94840B3614D65515C4340ABD1AB014AF94840
20950	Лихолобов	1	1	474	38.857104	38.876632999999998	50.011107000000003	49.993516999999997	0103000020E61000000100000005000000A9A27895B56D43409082A7902BFF4840A9A27895B56D4340DBE044F46B01494014CC988235704340DBE044F46B01494014CC9882357043409082A7902BFF4840A9A27895B56D43409082A7902BFF4840
19913	Ладомировка	1	1	474	38.919176999999998	38.957732999999998	50.304571000000003	50.245493000000003	0103000020E61000000100000005000000211E8997A7754340CF328B506C1F4940211E8997A7754340AF27BA2EFC26494065A6B4FE967A4340AF27BA2EFC26494065A6B4FE967A4340CF328B506C1F4940211E8997A7754340CF328B506C1F4940
21132	Копанки	1	1	474	39.084260999999998	39.107590000000002	50.160333999999999	50.144824999999997	0103000020E6100000010000000500000004AA7F10C98A4340545227A08912494004AA7F10C98A4340EB3713D38514494036B05582C58D4340EB3713D38514494036B05582C58D4340545227A08912494004AA7F10C98A4340545227A089124940
20094	Клименково	1	1	474	39.023580000000003	39.077190999999999	49.998624	49.956004999999998	0103000020E610000001000000050000007B6B60AB04834340FFE7305F5EFA48407B6B60AB04834340178046E9D2FF4840D4450A65E1894340178046E9D2FF4840D4450A65E1894340FFE7305F5EFA48407B6B60AB04834340FFE7305F5EFA4840
20438	Калиниченково	1	1	474	38.974891	38.994537000000001	50.196370999999999	50.177250999999998	0103000020E610000001000000050000001615713AC97C434076172829B01649401615713AC97C4340007157AF22194940BBD408FD4C7F4340007157AF22194940BBD408FD4C7F434076172829B01649401615713AC97C434076172829B0164940
21001	Ивановка	1	1	474	39.065925999999997	39.082545000000003	49.901668000000001	49.894298999999997	0103000020E6100000010000000500000061FA5E437088434039ECBE6378F2484061FA5E4370884340C4EC65DB69F3484063B9A5D5908A4340C4EC65DB69F3484063B9A5D5908A434039ECBE6378F2484061FA5E437088434039ECBE6378F24840
19928	Жабское	1	1	474	38.848615000000002	38.873838999999997	50.228254999999997	50.212040999999999	0103000020E6100000010000000500000091F2936A9F6C4340A034D428241B494091F2936A9F6C43400113B875371D4940137CD3F4D96F43400113B875371D4940137CD3F4D96F4340A034D428241B494091F2936A9F6C4340A034D428241B4940
20193	Еремовка	1	1	474	39.148338000000003	39.178277999999999	50.099024	50.082166000000001	0103000020E61000000100000005000000856055BDFC924340EC6B5D6A840A4940856055BDFC92434072C284D1AC0C494053CC41D0D196434072C284D1AC0C494053CC41D0D1964340EC6B5D6A840A4940856055BDFC924340EC6B5D6A840A4940
20247	Всесвятка	1	1	474	39.081502999999998	39.120111999999999	50.028945	49.997449000000003	0103000020E6100000010000000500000050C3B7B06E8A4340C636A968ACFF484050C3B7B06E8A4340FD304278B4034940B7ED7BD45F8F4340FD304278B4034940B7ED7BD45F8F4340C636A968ACFF484050C3B7B06E8A4340C636A968ACFF4840
19691	Верхняя Серебрянка	1	1	474	39.007455	39.075097999999997	49.858834999999999	49.830416	0103000020E6100000010000000500000089981249F48043409E094D124BEA484089981249F480434080D4264EEEED48405CFFAECF9C89434080D4264EEEED48405CFFAECF9C8943409E094D124BEA484089981249F48043409E094D124BEA4840
20331	Барсучье	1	1	474	39.226734	39.249352999999999	49.999654999999997	49.985930000000003	0103000020E610000001000000050000001572A59E059D4340991249F432FE48401572A59E059D43403524EEB1F4FF48406A1492CCEA9F43403524EEB1F4FF48406A1492CCEA9F4340991249F432FE48401572A59E059D4340991249F432FE4840
19598	Айдар	1	1	474	38.856619000000002	38.938077999999997	50.079321999999998	50.018996999999999	0103000020E61000000100000005000000ED10FFB0A56D43406EDC627E6E024940ED10FFB0A56D434039ED2939270A49406D8C9DF01278434039ED2939270A49406D8C9DF0127843406EDC627E6E024940ED10FFB0A56D43406EDC627E6E024940
54005	Центральное	1	1	1531	35.542195	36.161897000000003	51.035518000000003	50.650297000000002	0103000020E61000000100000005000000018750A566C54140EDD79DEE3C534940018750A566C54140AD3594DA8B8449400729780AB9144240AD3594DA8B8449400729780AB9144240EDD79DEE3C534940018750A566C54140EDD79DEE3C534940
18977	Трефиловка	1	1	1531	35.879952000000003	35.901708999999997	50.731695999999999	50.703631999999999	0103000020E6100000010000000500000060066344A2F04140A435069D105A494060066344A2F04140984EEB36A85D494022C154336BF34140984EEB36A85D494022C154336BF34140A435069D105A494060066344A2F04140A435069D105A4940
18873	Солдатское	1	1	1531	35.747630000000001	35.816253000000003	50.746403000000001	50.707363000000001	0103000020E6100000010000000500000016C1FF56B2DF414042B3EBDE8A5A494016C1FF56B2DF414072512D228A5F4940862172FA7AE8414072512D228A5F4940862172FA7AE8414042B3EBDE8A5A494016C1FF56B2DF414042B3EBDE8A5A4940
18639	Святославка	1	1	1531	35.679619000000002	35.687542000000001	50.886552999999999	50.867342000000001	0103000020E61000000100000005000000C05E61C1FDD641403F390A10056F4940C05E61C1FDD64140D99596917A7149402F50526001D84140D99596917A7149402F50526001D841403F390A10056F4940C05E61C1FDD641403F390A10056F4940
18790	Русская Березовка	1	1	1531	35.723205	35.748654000000002	50.680362000000002	50.659931	0103000020E61000000100000005000000DFA63FFB91DC4140EC4E779E78544940DFA63FFB91DC414078B81D1A165749408202EFE4D3DF414078B81D1A165749408202EFE4D3DF4140EC4E779E78544940DFA63FFB91DC4140EC4E779E78544940
19262	Ракитное	1	1	1531	35.802759999999999	35.909407999999999	50.863987999999999	50.814233999999999	0103000020E61000000100000005000000BB44F5D6C0E6414048A5D8D138684940BB44F5D6C0E641407711A628976E4940425C397B67F441407711A628976E4940425C397B67F4414048A5D8D138684940BB44F5D6C0E6414048A5D8D138684940
18269	Псковское	1	1	1531	35.943750000000001	35.981938	50.918959000000001	50.899433000000002	0103000020E61000000100000005000000CDCCCCCCCCF84140BAF8DB9E20734940CDCCCCCCCCF84140B4AED172A07549408E59F624B0FD4140B4AED172A07549408E59F624B0FD4140BAF8DB9E20734940CDCCCCCCCCF84140BAF8DB9E20734940
19092	Пролетарский	1	1	1531	35.743363000000002	35.796930000000003	50.804859999999998	50.783912999999998	0103000020E610000001000000050000003A07CF8426DF414062F4DC42576449403A07CF8426DF4140E5ED08A705674940C4995FCD01E64140E5ED08A705674940C4995FCD01E6414062F4DC42576449403A07CF8426DF414062F4DC4257644940
18705	Нижние Пены	1	1	1531	35.932772999999997	35.960836	51.018262	50.987326000000003	0103000020E61000000100000005000000C0CB0C1B65F74140C93EC8B2607E4940C0CB0C1B65F741403961C26856824940E4688EACFCFA41403961C26856824940E4688EACFCFA4140C93EC8B2607E4940C0CB0C1B65F74140C93EC8B2607E4940
18344	Меловое	1	1	1531	36.057405000000003	36.080492	50.922955999999999	50.902828999999997	0103000020E610000001000000050000003ED00A0C59074240B07092E68F7349403ED00A0C59074240D0D2156C2376494079CBD58F4D0A4240D0D2156C2376494079CBD58F4D0A4240B07092E68F7349403ED00A0C59074240B07092E68F734940
19006	Лаптевка	1	1	1531	35.825029000000001	35.850892000000002	50.737237999999998	50.711567000000002	0103000020E6100000010000000500000034A0DE8C9AE94140D8F4A0A0145B494034A0DE8C9AE9414029AF95D05D5E4940CA367007EAEC414029AF95D05D5E4940CA367007EAEC4140D8F4A0A0145B494034A0DE8C9AE94140D8F4A0A0145B4940
19248	Криничное	1	1	1531	35.783679999999997	35.812083999999999	50.813335000000002	50.802793999999999	0103000020E61000000100000005000000BF4351A04FE4414067B62BF4C1664940BF4351A04FE4414099D87C5C1B6849406CCD565EF2E7414099D87C5C1B6849406CCD565EF2E7414067B62BF4C1664940BF4351A04FE4414067B62BF4C1664940
18603	Илек-Кошары	1	1	1531	35.595581000000003	35.625692999999998	50.908951999999999	50.893303000000003	0103000020E610000001000000050000003B8F8AFF3BCC41409835B1C0577249403B8F8AFF3BCC414020D1048A58744940062B4EB516D0414020D1048A58744940062B4EB516D041409835B1C0577249403B8F8AFF3BCC41409835B1C057724940
18536	Зинаидино	1	1	1531	35.880473000000002	35.914313	50.891553000000002	50.877409	0103000020E610000001000000050000006901DA56B3F04140A81B28F04E7049406901DA56B3F041404AD3A0681E72494061A7583508F541404AD3A0681E72494061A7583508F54140A81B28F04E7049406901DA56B3F04140A81B28F04E704940
18450	Дмитриевка	1	1	1531	35.984399000000003	36.017493000000002	50.790774999999996	50.765675000000002	0103000020E61000000100000005000000899B53C900FE4140B22E6EA301624940899B53C900FE414048BF7D1D386549405874EB353D02424048BF7D1D386549405874EB353D024240B22E6EA301624940899B53C900FE4140B22E6EA301624940
18776	Вышние Пены	1	1	1531	35.982872	36.028381000000003	50.982722000000003	50.945757999999998	0103000020E61000000100000005000000BA13ECBFCEFD414016F71F990E794940BA13ECBFCEFD4140A587A1D5C97D4940F56915FDA1034240A587A1D5C97D4940F56915FDA103424016F71F990E794940BA13ECBFCEFD414016F71F990E794940
18218	Венгеровка	1	1	1531	35.99588	36.043588999999997	50.942540000000001	50.917254999999997	0103000020E61000000100000005000000C85EEFFE78FF4140D68BA19C68754940C85EEFFE78FF4140FF959526A578494090BB085394054240FF959526A578494090BB085394054240D68BA19C68754940C85EEFFE78FF4140D68BA19C68754940
18896	Введенская Готня	1	1	1531	35.889150999999998	35.910305999999999	50.750889000000001	50.721375999999999	0103000020E61000000100000005000000541A31B3CFF14140450F7C0C565C4940541A31B3CFF141408CF678211D60494021AD31E884F441408CF678211D60494021AD31E884F44140450F7C0C565C4940541A31B3CFF14140450F7C0C565C4940
19493	Васильевка	1	1	1531	35.972819999999999	36.013764999999999	50.859662	50.819873999999999	0103000020E610000001000000050000008672A25D85FC41409C6B98A1F16849408672A25D85FC414096CE8767096E49402B6A300DC301424096CE8767096E49402B6A300DC30142409C6B98A1F16849408672A25D85FC41409C6B98A1F1684940
18123	Борисполье	1	1	1531	35.758589999999998	35.771436000000001	50.890172	50.867956	0103000020E610000001000000050000004C89247A19E14140F92EA52E196F49404C89247A19E141404FE8F527F1714940817A336ABEE241404FE8F527F1714940817A336ABEE24140F92EA52E196F49404C89247A19E14140F92EA52E196F4940
18182	Бобрава	1	1	1531	35.745465000000003	35.797828000000003	50.950530999999998	50.920940000000002	0103000020E6100000010000000500000005A8A9656BDF414004CAA65CE175494005A8A9656BDF4140C66AF3FFAA794940A3EA573A1FE64140C66AF3FFAA794940A3EA573A1FE6414004CAA65CE175494005A8A9656BDF414004CAA65CE1754940
18360	Александровка	1	1	1531	36.011249999999997	36.037849000000001	50.901983000000001	50.868695000000002	0103000020E610000001000000050000003D0AD7A3700142407099D365316F49403D0AD7A3700142402446CF2D74734940D9976C3CD80442402446CF2D74734940D9976C3CD80442407099D365316F49403D0AD7A3700142407099D365316F4940
18098	Шахово	1	1	627	36.717874000000002	36.748533000000002	50.879165	50.863152999999997	0103000020E610000001000000050000000953944BE35B4240DE3829CC7B6E49400953944BE35B4240D8648D7A88704940077DE9EDCF5F4240D8648D7A88704940077DE9EDCF5F4240DE3829CC7B6E49400953944BE35B4240DE3829CC7B6E4940
18026	Холодное	1	1	627	37.090682999999999	37.126435999999998	51.018030000000003	51.001027999999998	0103000020E61000000100000005000000CEA623809B8B4240AD307DAF21804940CEA623809B8B4240672C9ACE4E824940BE840A0E2F904240672C9ACE4E824940BE840A0E2F904240AD307DAF21804940CEA623809B8B4240AD307DAF21804940
15756	Тетеревино	1	1	627	36.605656000000003	36.621574000000003	50.878954999999998	50.864033999999997	0103000020E610000001000000050000002750C422864D4240E75086AA986E49402750C422864D4240EDD3F198817049409F05A1BC8F4F4240EDD3F198817049409F05A1BC8F4F4240E75086AA986E49402750C422864D4240E75086AA986E4940
53580	Средняя Ольшанка	1	1	627	36.671709	36.694561999999998	51.09498	51.077294000000002	0103000020E61000000100000005000000E5B67D8FFA554240A91611C5E4894940E5B67D8FFA55424015E3FC4D288C4940AD855968E758424015E3FC4D288C4940AD855968E7584240A91611C5E4894940E5B67D8FFA554240A91611C5E4894940
4051	Сергиевка	1	1	627	36.883209000000001	36.909305000000003	51.164177000000002	51.136780999999999	0103000020E61000000100000005000000354415FE0C7142406ADB300A82914940354415FE0C714240B1E07EC0039549406E8B321B64744240B1E07EC0039549406E8B321B647442406ADB300A82914940354415FE0C7142406ADB300A82914940
16142	Сеймица	1	1	627	36.847535999999998	36.897851000000003	51.171405999999998	51.132914999999997	0103000020E610000001000000050000006117450F7C6C4240EC12D55B039149406117450F7C6C4240492BBEA1F095494028D714C8EC724240492BBEA1F095494028D714C8EC724240EC12D55B039149406117450F7C6C4240EC12D55B03914940
17067	Сагайдачное	1	1	627	36.907670000000003	36.935571000000003	51.049013000000002	51.035915000000003	0103000020E61000000100000005000000B9C7D2872E744240CA37DBDC98844940B9C7D2872E744240180AD80E46864940030B60CAC0774240180AD80E46864940030B60CAC0774240CA37DBDC98844940B9C7D2872E744240CA37DBDC98844940
17873	Ржавец	1	1	627	36.825778999999997	36.850257999999997	50.87979	50.868842999999998	0103000020E610000001000000050000009E5C5320B3694240E42D573F366F49409E5C5320B369424086AC6EF59C704940C8940F41D56C424086AC6EF59C704940C8940F41D56C4240E42D573F366F49409E5C5320B3694240E42D573F366F4940
17728	Радьковка	1	1	627	36.936630999999998	37.033406999999997	51.109323000000003	51.077621999999998	0103000020E61000000100000005000000BBB54C86E37742409DB98784EF894940BBB54C86E3774240AED9CA4BFE8D49408E3A3AAE46844240AED9CA4BFE8D49408E3A3AAE468442409DB98784EF894940BBB54C86E37742409DB98784EF894940
17324	Прохоровка	1	1	627	36.690897	36.774791	51.051307000000001	51.018126000000002	0103000020E61000000100000005000000C7F319506F584240899AE8F351824940C7F319506F58424027874F3A91864940191EFB592C63424027874F3A91864940191EFB592C634240899AE8F351824940C7F319506F584240899AE8F351824940
17289	Призначное	1	1	627	36.836019999999998	36.868260999999997	51.039482999999997	51.022444	0103000020E61000000100000005000000A5660FB4026B4240E7FEEA71DF824940A5660FB4026B4240BDDF68C70D85494035B22B2D236F4240BDDF68C70D85494035B22B2D236F4240E7FEEA71DF824940A5660FB4026B4240E7FEEA71DF824940
16977	Прелестное	1	1	627	36.609985999999999	36.641669999999998	51.048408000000002	51.032623999999998	0103000020E6100000010000000500000049827005144E42404888F2052D84494049827005144E4240B16EBC3B328649408369183E22524240B16EBC3B328649408369183E225242404888F2052D84494049827005144E42404888F2052D844940
15950	Политотдельский	1	1	627	36.654704000000002	36.669516999999999	51.028250999999997	51.020330000000001	0103000020E61000000100000005000000BB473657CD5342405890662C9A824940BB473657CD534240268A90BA9D834940DA8EA9BBB2554240268A90BA9D834940DA8EA9BBB25542405890662C9A824940BB473657CD5342405890662C9A824940
16878	Подольхи	1	1	627	36.876066999999999	36.973750000000003	50.995733999999999	50.947409999999998	0103000020E610000001000000050000006B0DA5F622704240A1F31ABB447949406B0DA5F622704240F4C13236747F4940713D0AD7A37C4240F4C13236747F4940713D0AD7A37C4240A1F31ABB447949406B0DA5F622704240A1F31ABB44794940
17995	Плющины	1	1	627	37.056609999999999	37.075448000000002	51.005516999999998	50.989963000000003	0103000020E61000000100000005000000335019FF3E87424002A08A1BB77E4940335019FF3E8742403849F3C7B48049403946B247A88942403849F3C7B48049403946B247A889424002A08A1BB77E4940335019FF3E87424002A08A1BB77E4940
16681	Плота	1	1	627	36.737698999999999	36.765582999999999	50.929445000000001	50.913784999999997	0103000020E610000001000000050000005DA5BBEB6C5E4240A54929E8F67449405DA5BBEB6C5E42402237C30DF8764940D1AFAD9FFE6142402237C30DF8764940D1AFAD9FFE614240A54929E8F67449405DA5BBEB6C5E4240A54929E8F6744940
16571	Петровка	1	1	627	36.638525000000001	36.943646999999999	51.137307	51.046964000000003	0103000020E61000000100000005000000D656EC2FBB514240700B96EA02864940D656EC2FBB5142408541994693914940F8FBC56CC97842408541994693914940F8FBC56CC9784240700B96EA02864940D656EC2FBB514240700B96EA02864940
17704	Нижняя Гусынка	1	1	627	36.846755000000002	36.918512	51.120263999999999	51.097769	0103000020E61000000100000005000000BC5CC477626C424004C8D0B1838C4940BC5CC477626C42406D718DCF648F4940E57D1CCD917542406D718DCF648F4940E57D1CCD9175424004C8D0B1838C4940BC5CC477626C424004C8D0B1838C4940
16454	Масловка	1	1	627	37.088914000000003	37.143082	51.103527	51.071838	0103000020E610000001000000050000000A14B188618B4240164ED2FC318949400A14B188618B424062A06B5F408D4940B952CF825092424062A06B5F408D4940B952CF8250924240164ED2FC318949400A14B188618B4240164ED2FC31894940
54034	Малые Маяки	1	1	627	36.491740999999998	36.520189999999999	50.980181999999999	50.956102999999999	0103000020E61000000100000005000000198D7C5EF13E4240C24D4695617A4940198D7C5EF13E42405E10919A767D494066DAFE95954242405E10919A767D494066DAFE9595424240C24D4695617A4940198D7C5EF13E4240C24D4695617A4940
16655	Малояблоново	1	1	627	36.703896	36.729731000000001	50.934536999999999	50.918345000000002	0103000020E6100000010000000500000082E49D43195A4240FAB836548C75494082E49D43195A424073F38DE89E7749404EF04DD3675D424073F38DE89E7749404EF04DD3675D4240FAB836548C75494082E49D43195A4240FAB836548C754940
16465	Лучки	1	1	627	36.515051999999997	36.570155	50.883495000000003	50.866773999999999	0103000020E61000000100000005000000A4DE5339ED414240F5824F73F26E4940A4DE5339ED414240FB96395D167149405053CBD6FA484240FB96395D167149405053CBD6FA484240F5824F73F26E4940A4DE5339ED414240F5824F73F26E4940
16337	Кривые Балки	1	1	627	37.004624999999997	37.025106000000001	51.042371000000003	51.036831999999997	0103000020E610000001000000050000003BDF4F8D978042401FB935E9B68449403BDF4F8D9780424040A6B5696C854940797764AC3683424040A6B5696C854940797764AC368342401FB935E9B68449403BDF4F8D978042401FB935E9B6844940
16375	Кривошеевка	1	1	627	37.030819999999999	37.092444	51.078488	51.061582000000001	0103000020E610000001000000050000000708E6E8F1834240DA0242EBE18749400708E6E8F1834240719010E50B8A4940105B7A34D58B4240719010E50B8A4940105B7A34D58B4240DA0242EBE18749400708E6E8F1834240DA0242EBE1874940
17221	Красное	1	1	627	36.785705	36.818952000000003	51.020584999999997	50.995415999999999	0103000020E61000000100000005000000DFA63FFB9164424023F59ECA697F4940DFA63FFB91644240E2E47E87A2824940357F4C6BD3684240E2E47E87A2824940357F4C6BD368424023F59ECA697F4940DFA63FFB9164424023F59ECA697F4940
16256	Кондровка	1	1	627	37.014353999999997	37.046998000000002	51.105133000000002	51.076422000000001	0103000020E610000001000000050000008C48145AD6814240F3583332C88949408C48145AD68142407D5D86FF748D49401C7DCC07048642407D5D86FF748D49401C7DCC0704864240F3583332C88949408C48145AD6814240F3583332C8894940
20833	Комсомольский	1	1	627	36.603904	36.615617999999998	50.989849	50.980322999999999	0103000020E6100000010000000500000038F6ECB94C4D424020425C397B7D494038F6ECB94C4D4240397D3D5FB37E49401A6A1492CC4E4240397D3D5FB37E49401A6A1492CC4E424020425C397B7D494038F6ECB94C4D424020425C397B7D4940
16231	Коломыцево	1	1	627	37.086803000000003	37.119430000000001	50.958866	50.923444000000003	0103000020E61000000100000005000000EC18575C1C8B4240FED7B96933764940EC18575C1C8B4240889FFF1EBC7A4940A514747B498F4240889FFF1EBC7A4940A514747B498F4240FED7B96933764940EC18575C1C8B4240FED7B96933764940
17057	Карташевка	1	1	627	36.552458000000001	36.572167	51.10472	51.096406000000002	0103000020E61000000100000005000000F03499F1B6464240B0912408578C4940F03499F1B64642405A9E0777678D4940DB6CACC43C4942405A9E0777678D4940DB6CACC43C494240B0912408578C4940F03499F1B6464240B0912408578C4940
54035	Калинин	1	1	627	36.579039000000002	36.595531999999999	50.927674000000003	50.918163999999997	0103000020E61000000100000005000000E50D30F31D4A4240A92EE06586754940E50D30F31D4A4240BDAC8905BE76494059DC7F643A4C4240BDAC8905BE76494059DC7F643A4C4240A92EE06586754940E50D30F31D4A4240A92EE06586754940
54026	Казачье	1	1	627	36.449492999999997	37.202900999999997	51.206361000000001	50.819395999999998	0103000020E61000000100000005000000F56393FC88394240923CD7F7E1684940F56393FC88394240BE1589096A9A4940B0A9F3A8F8994240BE1589096A9A4940B0A9F3A8F8994240923CD7F7E1684940F56393FC88394240923CD7F7E1684940
16069	Журавка 1-я	1	1	627	36.877828000000001	36.924486000000002	51.134112999999999	51.112648	0103000020E61000000100000005000000ADC1FBAA5C704240DBFAE93F6B8E4940ADC1FBAA5C704240F67B629D2A91494010CEA78E55764240F67B629D2A91494010CEA78E55764240DBFAE93F6B8E4940ADC1FBAA5C704240DBFAE93F6B8E4940
16154	Донец	1	1	627	37.020533999999998	37.048121000000002	50.966988999999998	50.95722	0103000020E61000000100000005000000603AADDBA0824240DF89592F867A4940603AADDBA0824240BE4BA94BC67B49401BA034D428864240BE4BA94BC67B49401BA034D428864240DF89592F867A4940603AADDBA0824240DF89592F867A4940
17188	Гусек-Погореловка	1	1	627	36.859223999999998	36.888930999999999	51.054890999999998	51.038553999999998	0103000020E610000001000000050000001AF8510DFB6D4240A3906456EF8449401AF8510DFB6D424020EC14AB0687494046B3B27DC871424020EC14AB0687494046B3B27DC8714240A3906456EF8449401AF8510DFB6D4240A3906456EF844940
16783	Гнездиловка	1	1	627	36.850994999999998	36.870550999999999	50.930933000000003	50.900233999999998	0103000020E610000001000000050000009E077767ED6C4240A65F22DE3A7349409E077767ED6C424033E202D028774940034015376E6F424033E202D028774940034015376E6F4240A65F22DE3A7349409E077767ED6C4240A65F22DE3A734940
15966	Вязовое	1	1	627	36.982661	37.021450000000002	51.172049999999999	51.142206000000002	0103000020E61000000100000005000000FF06EDD5C77D4240C2A563CE33924940FF06EDD5C77D42406EA301BC05964940E63FA4DFBE8242406EA301BC05964940E63FA4DFBE824240C2A563CE33924940FF06EDD5C77D4240C2A563CE33924940
54055	Веселый	1	1	627	36.527323000000003	36.558692000000001	51.075245000000002	51.053140999999997	0103000020E61000000100000005000000DDB6EF517F434240D2890453CD864940DDB6EF517F4342400118CFA0A1894940B7442E38834742400118CFA0A1894940B7442E3883474240D2890453CD864940DDB6EF517F434240D2890453CD864940
16050	Верхняя Гусынка	1	1	627	36.848793999999998	36.896377999999999	51.125539000000003	51.104419999999998	0103000020E6100000010000000500000040852348A56C42402F8672A25D8D494040852348A56C4240B0AF75A9119049404C6DA983BC724240B0AF75A9119049404C6DA983BC7242402F8672A25D8D494040852348A56C42402F8672A25D8D4940
52724	Большой	1	1	627	36.961343999999997	37.002234999999999	50.946824999999997	50.933447999999999	0103000020E61000000100000005000000581AF8510D7B424020425C397B774940581AF8510D7B42408104C58F317949400AF4893C498042408104C58F317949400AF4893C4980424020425C397B774940581AF8510D7B424020425C397B774940
17155	Бехтеевка	1	1	627	36.837637000000001	36.869635000000002	51.060563000000002	51.038446	0103000020E61000000100000005000000B47570B0376B4240BD546CCCEB844940B47570B0376B4240802C4487C08749407E3A1E33506F4240802C4487C08749407E3A1E33506F4240BD546CCCEB844940B47570B0376B4240BD546CCCEB844940
15848	Береговое 1-е	1	1	627	36.675105000000002	36.699098999999997	51.083196000000001	51.072076000000003	0103000020E61000000100000005000000DC2E34D769564240CB694FC939894940DC2E34D7695642403A94A12AA68A494049D576137C5942403A94A12AA68A494049D576137C594240CB694FC939894940DC2E34D769564240CB694FC939894940
15682	Беленихино	1	1	627	36.616328000000003	36.632263999999999	50.951734000000002	50.935014000000002	0103000020E61000000100000005000000F7CDFDD5E34E4240ADA6EB89AE774940F7CDFDD5E34E4240E23E726BD27949401538D906EE504240E23E726BD27949401538D906EE504240ADA6EB89AE774940F7CDFDD5E34E4240ADA6EB89AE774940
17924	Андреевка	1	1	627	36.587446999999997	37.157752000000002	51.039380999999999	51.016272999999998	0103000020E6100000010000000500000010919A76314B42406667D13B1582494010919A76314B4240B98AC56F0A8549407670B03731944240B98AC56F0A8549407670B037319442406667D13B1582494010919A76314B42406667D13B15824940
15500	Ярское	1	1	1288	37.552911999999999	37.582402999999999	50.666131	50.649228999999998	0103000020E6100000010000000500000071C806D2C5C64240B14E95EF1953494071C806D2C5C6424007EDD5C743554940D00B772E8CCA424007EDD5C743554940D00B772E8CCA4240B14E95EF1953494071C806D2C5C64240B14E95EF19534940
15417	Яковлевка	1	1	1288	37.953093000000003	37.993347	50.733736999999998	50.700899	0103000020E61000000100000005000000F58590F3FEF942404966F50EB7594940F58590F3FEF94240BD6E1118EB5D4940344A97FE25FF4240BD6E1118EB5D4940344A97FE25FF42404966F50EB7594940F58590F3FEF942404966F50EB7594940
15352	Шараповка	1	1	1288	37.980347999999999	38.043211999999997	50.780918	50.739300999999998	0103000020E610000001000000050000007959130B7CFD42403673486AA15E49407959130B7CFD4240CA6DFB1EF5634940BA6587F887054340CA6DFB1EF5634940BA6587F8870543403673486AA15E49407959130B7CFD42403673486AA15E4940
15325	Тростенец	1	1	1288	37.622819	37.673295000000003	50.854191999999998	50.829864999999998	0103000020E61000000100000005000000E9297288B8CF42402A8C2D04396A4940E9297288B8CF42409E40D829566D4940B9C7D2872ED642409E40D829566D4940B9C7D2872ED642402A8C2D04396A4940E9297288B8CF42402A8C2D04396A4940
15267	Старая Безгинка	1	1	1288	38.137453999999998	38.191029999999998	50.863214999999997	50.836748999999998	0103000020E61000000100000005000000295AB91798114340F8FA5A971A6B4940295AB91798114340543541D47D6E49400647C9AB73184340543541D47D6E49400647C9AB73184340F8FA5A971A6B4940295AB91798114340F8FA5A971A6B4940
15185	Солонец Поляна	1	1	1288	37.707996999999999	37.752777999999999	50.791823000000001	50.776702999999998	0103000020E6100000010000000500000043554CA59FDA424040DAFF006B63494043554CA59FDA42403D9CC0745A654940FB928D075BE042403D9CC0745A654940FB928D075BE0424040DAFF006B63494043554CA59FDA424040DAFF006B634940
13999	Слоновка	1	1	1288	37.741145000000003	37.776573999999997	50.675711	50.640016000000003	0103000020E61000000100000005000000064CE0D6DDDE42405875560BEC514940064CE0D6DDDE42401346B3B27D5649404276DEC666E342401346B3B27D5649404276DEC666E342405875560BEC514940064CE0D6DDDE42405875560BEC514940
54064	Скрынников	1	1	1288	37.584280999999997	37.605733000000001	50.596198000000001	50.583959999999998	0103000020E610000001000000050000004B5645B8C9CA424009168733BF4A49404B5645B8C9CA424066F84F37504C4940D28DB0A888CD424066F84F37504C4940D28DB0A888CD424009168733BF4A49404B5645B8C9CA424009168733BF4A4940
47273	Серебрянка	1	1	1288	37.909821000000001	37.929423	50.693317	50.673032999999997	0103000020E61000000100000005000000651BB80375F442407B1002F225564940651BB80375F442406361889CBE5849403A933655F7F642406361889CBE5849403A933655F7F642407B1002F225564940651BB80375F442407B1002F225564940
14690	Севальный	1	1	1288	37.999806	38.020879999999998	50.863419999999998	50.854601000000002	0103000020E610000001000000050000001B2C9CA4F9FF42408010C990636D49401B2C9CA4F9FF42402D5BEB8B846E4940FB912232AC0243402D5BEB8B846E4940FB912232AC0243408010C990636D49401B2C9CA4F9FF42408010C990636D4940
14880	Прибрежный	1	1	1288	37.834857	37.860576000000002	50.759909	50.744101000000001	0103000020E6100000010000000500000018EB1B98DCEA4240E0F599B33E5F494018EB1B98DCEA4240D177B7B2446149407BDCB75A27EE4240D177B7B2446149407BDCB75A27EE4240E0F599B33E5F494018EB1B98DCEA4240E0F599B33E5F4940
14136	Полевой	1	1	1288	37.508642999999999	37.526780000000002	50.732562999999999	50.722129000000002	0103000020E610000001000000050000006F2BBD361BC14240213F1BB96E5C49406F2BBD361BC142403CA1D79FC45D4940EC17EC866DC342403CA1D79FC45D4940EC17EC866DC34240213F1BB96E5C49406F2BBD361BC14240213F1BB96E5C4940
14543	Покрово-Михайловка	1	1	1288	37.539275000000004	37.575558000000001	50.782876999999999	50.765259	0103000020E61000000100000005000000744694F606C542401EFCC401F4614940744694F606C5424032E5435035644940C07971E2ABC9424032E5435035644940C07971E2ABC942401EFCC401F4614940744694F606C542401EFCC401F4614940
14606	Подвислое	1	1	1288	37.610179000000002	37.651035	50.797904000000003	50.785353999999998	0103000020E610000001000000050000005EDA70581ACE424032E4D87A866449405EDA70581ACE42407EACE0B72166494093C6681D55D342407EACE0B72166494093C6681D55D3424032E4D87A866449405EDA70581ACE424032E4D87A86644940
53997	Погромец	1	1	1288	37.842151000000001	37.867959999999997	50.828772999999998	50.815606000000002	0103000020E6100000010000000500000098A59D9ACBEB4240F03504C76568494098A59D9ACBEB42406667D13B156A49403A1E335019EF42406667D13B156A49403A1E335019EF4240F03504C76568494098A59D9ACBEB4240F03504C765684940
14936	Песчанка	1	1	1288	37.799086000000003	37.818382	50.713261000000003	50.701566999999997	0103000020E610000001000000050000008258367348E64240F6798CF2CC5949408258367348E642409241EE224C5B49404AD1CABDC0E842409241EE224C5B49404AD1CABDC0E84240F6798CF2CC5949408258367348E64240F6798CF2CC594940
15592	Остаповка	1	1	1288	37.508589000000001	37.527256000000001	50.655174000000002	50.648702999999998	0103000020E610000001000000050000007C0DC17119C1424096E82CB3085349407C0DC17119C142404298DBBDDC534940554FE61F7DC342404298DBBDDC534940554FE61F7DC3424096E82CB3085349407C0DC17119C1424096E82CB308534940
15061	Оскольское	1	1	1288	37.788091000000001	37.830033	50.855113000000003	50.835661999999999	0103000020E61000000100000005000000CFA2772AE0E442404641F0F8F66A4940CFA2772AE0E4424036B1C057746D4940E6CC76853EEA424036B1C057746D4940E6CC76853EEA42404641F0F8F66A4940CFA2772AE0E442404641F0F8F66A4940
13922	Ольховатка	1	1	1288	37.730688000000001	37.775585999999997	50.738771	50.721153999999999	0103000020E6100000010000000500000032CA332F87DD424096B036C64E5C494032CA332F87DD4240DA1D520C905E4940239EEC6646E34240DA1D520C905E4940239EEC6646E3424096B036C64E5C494032CA332F87DD424096B036C64E5C4940
13498	Новый Оскол	1	1	1288	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
15026	Новая Безгинка	1	1	1288	38.083132999999997	38.13617	50.899920999999999	50.876119000000003	0103000020E61000000100000005000000F31B261AA40A4340BE33DAAA24704940F31B261AA40A4340E7FD7F9C307349402159C0046E114340E7FD7F9C307349402159C0046E114340BE33DAAA24704940F31B261AA40A4340BE33DAAA24704940
14856	Ниновка	1	1	1288	37.812263999999999	37.832853999999998	50.741821000000002	50.723320999999999	0103000020E61000000100000005000000ECDB4944F8E7424048C153C8955C4940ECDB4944F8E74240363E93FDF35E4940E02BBAF59AEA4240363E93FDF35E4940E02BBAF59AEA424048C153C8955C4940ECDB4944F8E7424048C153C8955C4940
54049	Немцев	1	1	1288	37.675486999999997	37.699812999999999	50.607958000000004	50.592497999999999	0103000020E61000000100000005000000C3EFA65B76D64240037976F9D64B4940C3EFA65B76D64240B9AB5791D14D49406728EE7893D94240B9AB5791D14D49406728EE7893D94240037976F9D64B4940C3EFA65B76D64240037976F9D64B4940
14448	Малое Городище	1	1	1288	37.516044999999998	37.541322999999998	50.826219000000002	50.805902000000003	0103000020E61000000100000005000000D52137C30DC24240F8E3F6CB27674940D52137C30DC24240BB2A508BC16949404BC972124AC54240BB2A508BC16949404BC972124AC54240F8E3F6CB27674940D52137C30DC24240F8E3F6CB27674940
14048	Макешкино	1	1	1288	37.805706999999998	37.821202	50.647452999999999	50.637371000000002	0103000020E6100000010000000500000042942F6821E742409C35785F9551494042942F6821E742403A596ABDDF52494074B4AA251DE942403A596ABDDF52494074B4AA251DE942409C35785F9551494042942F6821E742409C35785F95514940
52944	Леоновка	1	1	1288	37.811483000000003	37.841557999999999	50.836499000000003	50.818190000000001	0103000020E610000001000000050000004721C9ACDEE7424006F52D73BA6849404721C9ACDEE7424080113466126B4940F5D72B2CB8EB424080113466126B4940F5D72B2CB8EB424006F52D73BA6849404721C9ACDEE7424006F52D73BA684940
15485	Крюк	1	1	1288	38.038828000000002	38.058007000000003	50.687502000000002	50.672451000000002	0103000020E61000000100000005000000A515DF50F8044340CD94D6DF12564940A515DF50F8044340A1F7C6100058494034F8FBC56C074340A1F7C6100058494034F8FBC56C074340CD94D6DF12564940A515DF50F8044340CD94D6DF12564940
54045	Косицыно	1	1	1288	37.870798000000001	37.897272000000001	50.703341000000002	50.692568999999999	0103000020E610000001000000050000000BB6114F76EF4240999CDA19A65849400BB6114F76EF4240CD77F013075A4940EACE13CFD9F24240CD77F013075A4940EACE13CFD9F24240999CDA19A65849400BB6114F76EF4240999CDA19A6584940
15195	Киселевка	1	1	1288	37.683419000000001	37.713557000000002	50.832374000000002	50.813648000000001	0103000020E61000000100000005000000863B17467AD74240583A1F9E25684940863B17467AD742403605323B8B6A49407B6AF5D555DB42403605323B8B6A49407B6AF5D555DB4240583A1F9E25684940863B17467AD74240583A1F9E25684940
54036	Гринево	1	1	1288	37.440694000000001	38.290796999999998	50.943199	50.542700000000004	0103000020E610000001000000050000008FC536A968B8424005C58F31774549408FC536A968B84240594FADBEBA78494030630AD638254340594FADBEBA78494030630AD63825434005C58F31774549408FC536A968B8424005C58F3177454940
15125	Голубино	1	1	1288	37.761806	37.799256999999997	50.832022000000002	50.813994999999998	0103000020E61000000100000005000000C3F2E7DB82E14240C30DF8FC30684940C3F2E7DB82E14240B9C667B27F6A4940AE0CAA0D4EE64240B9C667B27F6A4940AE0CAA0D4EE64240C30DF8FC30684940C3F2E7DB82E14240C30DF8FC30684940
47225	Глинное	1	1	1288	37.942179000000003	37.964177999999997	50.842773000000001	50.829376000000003	0103000020E610000001000000050000002FFD4B5299F842402D0B26FE286A49402FFD4B5299F84240D57954FCDF6B4940E7C2482F6AFB4240D57954FCDF6B4940E7C2482F6AFB42402D0B26FE286A49402FFD4B5299F842402D0B26FE286A4940
14506	Великомихайловка	1	1	1288	37.572907999999998	37.609020000000001	50.791907999999999	50.750672000000002	0103000020E61000000100000005000000F2CEA10C55C94240EF02250516604940F2CEA10C55C942406BB8C83D5D654940124E0B5EF4CD42406BB8C83D5D654940124E0B5EF4CD4240EF02250516604940F2CEA10C55C94240EF02250516604940
54016	Васильев Дол	1	1	1288	37.559182	37.596353999999998	50.837823999999998	50.816118000000003	0103000020E610000001000000050000008541994693C74240A6D6FB8D766849408541994693C74240E6E61BD13D6B49405D6BEF5355CC4240E6E61BD13D6B49405D6BEF5355CC4240A6D6FB8D766849408541994693C74240A6D6FB8D76684940
54042	Борсук	1	1	1288	37.536383000000001	37.563242000000002	50.713489000000003	50.680962000000001	0103000020E61000000100000005000000B090B932A8C44240CDE847C329574940B090B932A8C442402387889B535B4940E8DD585018C842402387889B535B4940E8DD585018C84240CDE847C329574940B090B932A8C44240CDE847C329574940
14209	Боровое	1	1	1288	38.228211000000002	38.271501000000001	50.861213999999997	50.835752999999997	0103000020E6100000010000000500000032CB9E04361D434056444DF4F96A494032CB9E04361D4340BD6DA6423C6E494068EA758BC0224340BD6DA6423C6E494068EA758BC022434056444DF4F96A494032CB9E04361D434056444DF4F96A4940
14168	Большая Ивановка	1	1	1288	38.161681999999999	38.212598	50.871502999999997	50.857568999999998	0103000020E610000001000000050000000A2DEBFEB11443401E882CD2C46D49400A2DEBFEB1144340D5AE09698D6F4940F6984869361B4340D5AE09698D6F4940F6984869361B43401E882CD2C46D49400A2DEBFEB11443401E882CD2C46D4940
14073	Богородское	1	1	1288	37.595635999999999	37.637183	50.751213	50.711269999999999	0103000020E61000000100000005000000FE28EACC3DCC42401E5036E50A5B4940FE28EACC3DCC42403FAA61BF27604940994869368FD142403FAA61BF27604940994869368FD142401E5036E50A5B4940FE28EACC3DCC42401E5036E50A5B4940
15578	Богдановка	1	1	1288	37.530346000000002	37.551268	50.646366999999998	50.615085000000001	0103000020E610000001000000050000003FC8B260E2C342404DA1F31ABB4E49403FC8B260E2C34240581B6327BC52494069AA27F38FC64240581B6327BC52494069AA27F38FC642404DA1F31ABB4E49403FC8B260E2C342404DA1F31ABB4E4940
34518	Колесников	1	1	2913	38.372318999999997	38.376083000000001	47.416547000000001	47.410034000000003	0103000020E61000000100000005000000F7562426A82F4340C11F7EFE7BB44740F7562426A82F43409B1F7F6951B5474071CADC7C233043409B1F7F6951B5474071CADC7C23304340C11F7EFE7BB44740F7562426A82F4340C11F7EFE7BB44740
13194	Теребрено	1	1	1134	35.491691000000003	35.529240999999999	50.730373999999998	50.710014999999999	0103000020E61000000100000005000000685E0EBBEFBE4140B05582C5E15A4940685E0EBBEFBE4140A2EC2DE57C5D4940E659492BBEC34140A2EC2DE57C5D4940E659492BBEC34140B05582C5E15A4940685E0EBBEFBE4140B05582C5E15A4940
46617	Староселье	1	1	1134	35.466304999999998	35.478000999999999	50.710785000000001	50.699091000000003	0103000020E610000001000000050000000B7BDAE1AFBB4140C7F65AD07B5949400B7BDAE1AFBB414062BEBC00FB5A4940473A03232FBD414062BEBC00FB5A4940473A03232FBD4140C7F65AD07B5949400B7BDAE1AFBB4140C7F65AD07B594940
46532	Репяховка	1	1	1134	35.456612	35.511158000000002	50.879539999999999	50.850962000000003	0103000020E61000000100000005000000077B134372BA4140C311A452EC6C4940077B134372BA41400DC347C4947049405D8B16A06DC141400DC347C4947049405D8B16A06DC14140C311A452EC6C4940077B134372BA4140C311A452EC6C4940
13140	Отрадовский	1	1	1134	35.688979000000003	35.700603000000001	50.747093	50.738827999999998	0103000020E61000000100000005000000BE50C07630D841403EAF78EA915E4940BE50C07630D84140070951BEA05F4940603DEE5BADD94140070951BEA05F4940603DEE5BADD941403EAF78EA915E4940BE50C07630D841403EAF78EA915E4940
10482	Красная Яруга	1	1	1134	35.631352	35.68835	50.825671999999997	50.773569999999999	0103000020E61000000100000005000000D1217024D0D0414057957D5704634940D1217024D0D04140889CBE9EAF694940CE1951DA1BD84140889CBE9EAF694940CE1951DA1BD8414057957D5704634940D1217024D0D0414057957D5704634940
46492	Колотиловка	1	1	1134	35.422072	35.449866	50.822553999999997	50.804223	0103000020E6100000010000000500000056478E7406B6414073D87DC7F066494056478E7406B64140D4981073496949408ACA863595B94140D4981073496949408ACA863595B9414073D87DC7F066494056478E7406B6414073D87DC7F0664940
12921	Илек-Пеньковка	1	1	1134	35.533948000000002	35.570338999999997	50.773496000000002	50.750666000000002	0103000020E61000000100000005000000DFE1766858C441400D1CD0D215604940DFE1766858C441401DCBBBEA0163494011514CDE00C941401DCBBBEA0163494011514CDE00C941400D1CD0D215604940DFE1766858C441400D1CD0D215604940
46438	Демидовка	1	1	1134	35.382033999999997	35.400827	50.951920999999999	50.940060000000003	0103000020E61000000100000005000000E3FA777DE6B041408E23D6E253784940E3FA777DE6B0414014B01D8CD8794940492D944C4EB3414014B01D8CD8794940492D944C4EB341408E23D6E253784940E3FA777DE6B041408E23D6E253784940
54029	Вязовское	1	1	1134	35.572682999999998	35.603701999999998	50.855874999999997	50.812772000000002	0103000020E61000000100000005000000D2FC31AD4DC94140618DB3E908684940D2FC31AD4DC94140643BDF4F8D6D4940D0436D1B46CD4140643BDF4F8D6D4940D0436D1B46CD4140618DB3E908684940D2FC31AD4DC94140618DB3E908684940
46411	Вязовое	1	1	1134	35.474559999999997	35.530417999999997	50.801358999999998	50.775120000000001	0103000020E61000000100000005000000B0FECF61BEBC4140DE3CD52137634940B0FECF61BEBC414079AD84EE92664940D89AADBCE4C3414079AD84EE92664940D89AADBCE4C34140DE3CD52137634940B0FECF61BEBC4140DE3CD52137634940
11128	Хуторцы	1	1	468	38.436647000000001	38.466605999999999	50.657423999999999	50.638913000000002	0103000020E61000000100000005000000C172840CE4374340A0FEB3E6C7514940C172840CE437434081CD397826544940060FD3BEB93B434081CD397826544940060FD3BEB93B4340A0FEB3E6C7514940C172840CE4374340A0FEB3E6C7514940
12614	Уточка	1	1	468	38.296187000000003	38.332811	50.840679000000002	50.823816999999998	0103000020E610000001000000050000000C40A374E9254340C571E0D5726949400C40A374E92543408DB7955E9B6B4940E15F048D992A43408DB7955E9B6B4940E15F048D992A4340C571E0D5726949400C40A374E9254340C571E0D572694940
12750	Ураково	1	1	468	38.330331999999999	38.353040999999997	50.816989	50.805337999999999	0103000020E610000001000000050000004069A851482A4340EF1CCA50156749404069A851482A43408B18761893684940D5928E72302D43408B18761893684940D5928E72302D4340EF1CCA50156749404069A851482A4340EF1CCA5015674940
12398	Стрелецкое	1	1	468	38.454478999999999	38.487006999999998	50.695394	50.667335999999999	0103000020E6100000010000000500000001DC2C5E2C3A4340C3B81B446B55494001DC2C5E2C3A4340D5EAABAB0259494027F6D03E563E4340D5EAABAB0259494027F6D03E563E4340C3B81B446B55494001DC2C5E2C3A4340C3B81B446B554940
10627	Сорокино	1	1	468	38.464323999999998	38.505412999999997	50.765338999999997	50.743212	0103000020E61000000100000005000000BB5F05F86E3B434054FF2092215F4940BB5F05F86E3B43403AADDBA0F661494093FC885FB14043403AADDBA0F661494093FC885FB140434054FF2092215F4940BB5F05F86E3B434054FF2092215F4940
12044	Самарино	1	1	468	38.364646999999998	38.421590999999999	50.346575000000001	50.308304999999997	0103000020E61000000100000005000000D1CABDC0AC2E4340BD18CA8976274940D1CABDC0AC2E43403C4ED1915C2C4940DBA4A2B1F63543403C4ED1915C2C4940DBA4A2B1F6354340BD18CA8976274940D1CABDC0AC2E4340BD18CA8976274940
10235	Садки	1	1	468	38.304909000000002	38.326658000000002	50.648485999999998	50.637348000000003	0103000020E61000000100000005000000C7A0134207274340E415889E94514940C7A0134207274340F9F4D89601534940077DE9EDCF294340F9F4D89601534940077DE9EDCF294340E415889E94514940C7A0134207274340E415889E94514940
12500	Репенка	1	1	468	38.372301	38.393259	50.726080000000003	50.714041999999999	0103000020E6100000010000000500000051A2258FA72F434037FC6EBA655B494051A2258FA72F4340CD237F30F05C4940C8ED974F56324340CD237F30F05C4940C8ED974F5632434037FC6EBA655B494051A2258FA72F434037FC6EBA655B4940
11041	Раздорное	1	1	468	38.194713	38.226612000000003	50.637501999999998	50.625611999999997	0103000020E61000000100000005000000938D075BEC18434019FED30D14504940938D075BEC1843403A9160AA99514940CA703C9F011D43403A9160AA99514940CA703C9F011D434019FED30D14504940938D075BEC18434019FED30D14504940
10508	Прудки	1	1	468	38.478454999999997	38.518177999999999	50.817284999999998	50.801102999999998	0103000020E61000000100000005000000C8CD70033E3D43401EDD088B8A664940C8CD70033E3D434074417DCB9C684940DBC01DA85342434074417DCB9C684940DBC01DA8534243401EDD088B8A664940C8CD70033E3D43401EDD088B8A664940
12572	Прилепы	1	1	468	38.309005999999997	38.341363000000001	50.763761000000002	50.742203000000003	0103000020E61000000100000005000000462234828D2743401EFF0582005F4940462234828D274340EA7AA2EBC2614940408864C8B12B4340EA7AA2EBC2614940408864C8B12B43401EFF0582005F4940462234828D2743401EFF0582005F4940
11443	Попасное	1	1	468	38.478831999999997	38.498002	50.509120000000003	50.499775999999997	0103000020E610000001000000050000009E23F25D4A3D4340B0A9F3A8F83F49409E23F25D4A3D4340A9DE1AD82A414940DAAB8F87BE3F4340A9DE1AD82A414940DAAB8F87BE3F4340B0A9F3A8F83F49409E23F25D4A3D4340B0A9F3A8F83F4940
12700	Плюхино	1	1	468	38.268141	38.308160999999998	50.830241000000001	50.820711000000003	0103000020E61000000100000005000000BEDBBC7152224340D63BDC0E0D694940BEDBBC715222434030664B56456A49408A73D4D17127434030664B56456A49408A73D4D171274340D63BDC0E0D694940BEDBBC7152224340D63BDC0E0D694940
10420	Петров	1	1	468	38.435093000000002	38.453823	50.773234000000002	50.757949000000004	0103000020E61000000100000005000000F9DB9E20B137434099840B7904614940F9DB9E20B1374340E013EB54F962494018963FDF163A4340E013EB54F962494018963FDF163A434099840B7904614940F9DB9E20B137434099840B7904614940
12232	Палатово	1	1	468	38.136735999999999	38.190750999999999	50.436467	50.403328000000002	0103000020E61000000100000005000000CA17B49080114340D2C77C40A0334940CA17B4908011434041649126DE374940F3565D876A18434041649126DE374940F3565D876A184340D2C77C40A0334940CA17B49080114340D2C77C40A0334940
11496	Палатовка 2-я	1	1	468	38.415239999999997	38.442819	50.447980000000001	50.421519000000004	0103000020E61000000100000005000000DAFE95952635434042D2A755F4354940DAFE9595263543408CA19C68573949401286014BAE3843408CA19C68573949401286014BAE38434042D2A755F4354940DAFE95952635434042D2A755F4354940
10776	Остроухово	1	1	468	38.215248000000003	38.238011999999998	50.686441000000002	50.677433999999998	0103000020E61000000100000005000000C443183F8D1B434067994528B6564940C443183F8D1B434018D1764CDD5749401C075E2D771E434018D1764CDD5749401C075E2D771E434067994528B6564940C443183F8D1B434067994528B6564940
12140	Новохуторное	1	1	468	38.174850999999997	38.218823999999998	50.574528000000001	50.551296999999998	0103000020E6100000010000000500000021567F846116434003B16CE69046494021567F846116434072512D228A4949403ACAC16C021C434072512D228A4949403ACAC16C021C434003B16CE69046494021567F846116434003B16CE690464940
10957	Николаевский	1	1	468	38.032235	38.049770000000002	50.627251999999999	50.619509000000001	0103000020E61000000100000005000000AE64C74620044340F14927124C4F4940AE64C74620044340E02C25CB49504940352905DD5E064340E02C25CB49504940352905DD5E064340F14927124C4F4940AE64C74620044340F14927124C4F4940
11932	Никитовка	1	1	468	38.380609999999997	38.467936000000002	50.388765999999997	50.324967999999998	0103000020E61000000100000005000000E94317D4B73043408E1F2A8D98294940E94317D4B7304340FBE59315C33149407F4FAC53E53B4340FBE59315C33149407F4FAC53E53B43408E1F2A8D98294940E94317D4B73043408E1F2A8D98294940
54060	Нижняя Покровка	1	1	468	38.017898000000002	38.609392999999997	50.913201000000001	50.280194000000002	0103000020E61000000100000005000000F8544E7B4A0243408944A165DD234940F8544E7B4A02434056D636C5E3744940A6B4FE96004E434056D636C5E3744940A6B4FE96004E43408944A165DD234940F8544E7B4A0243408944A165DD234940
12475	Марьевка	1	1	468	38.350723000000002	38.380305	50.74259	50.723201000000003	0103000020E610000001000000050000003E7AC37DE42C43409EB7B1D9915C49403E7AC37DE42C4340172B6A300D5F4940ADC090D5AD304340172B6A300D5F4940ADC090D5AD3043409EB7B1D9915C49403E7AC37DE42C43409EB7B1D9915C4940
12380	Малобыково	1	1	468	38.467567000000003	38.523173	50.665823000000003	50.657297999999997	0103000020E610000001000000050000002CD8463CD93B4340F4DC4257225449402CD8463CD93B43405AF624B0395549403A933655F74243405AF624B0395549403A933655F7424340F4DC4257225449402CD8463CD93B4340F4DC425722544940
11719	Ливенка	1	1	468	38.234949	38.311574999999998	50.469943999999998	50.426735999999998	0103000020E610000001000000050000002C9D0FCF121E43404F0306499F3649402C9D0FCF121E4340C879FF1F273C494027A089B0E1274340C879FF1F273C494027A089B0E12743404F0306499F3649402C9D0FCF121E43404F0306499F364940
12270	Лазареново	1	1	468	38.116883000000001	38.138244999999998	50.474203000000003	50.462288999999998	0103000020E61000000100000005000000AC3AAB05F60E4340782634492C3B4940AC3AAB05F60E4340225514AFB23C4940F2EA1C03B2114340225514AFB23C4940F2EA1C03B2114340782634492C3B4940AC3AAB05F60E4340782634492C3B4940
10296	Кулешовка	1	1	468	38.316910999999998	38.359068999999998	50.396127999999997	50.384923999999998	0103000020E610000001000000050000000F5F268A9028434006B98B30453149400F5F268A90284340D3838252B4324940F30016F9F52D4340D3838252B4324940F30016F9F52D434006B98B30453149400F5F268A9028434006B98B3045314940
10986	Красное	1	1	468	38.145403999999999	38.173665	50.705731	50.678924000000002	0103000020E61000000100000005000000925A28999C124340193C4CFBE6564940925A28999C124340FE62B664555A4940DCBA9BA73A164340FE62B664555A4940DCBA9BA73A164340193C4CFBE6564940925A28999C124340193C4CFBE6564940
11521	Коломыцево	1	1	468	38.360174000000001	38.382623000000002	50.551656999999999	50.537095000000001	0103000020E610000001000000050000004C6F7F2E1A2E43402DEC6987BF4449404C6F7F2E1A2E434003CE52B29C46494045D95BCAF930434003CE52B29C46494045D95BCAF93043402DEC6987BF4449404C6F7F2E1A2E43402DEC6987BF444940
11710	Ковалев	1	1	468	38.309193999999998	38.322488999999997	50.560934000000003	50.549619999999997	0103000020E61000000100000005000000490F43AB932743401F9DBAF259464940490F43AB93274340749B70AFCC474940ED28CE5147294340749B70AFCC474940ED28CE51472943401F9DBAF259464940490F43AB932743401F9DBAF259464940
11426	Калиново	1	1	468	38.420208000000002	38.449241999999998	50.503712	50.490228999999999	0103000020E6100000010000000500000040C23060C93543408046E9D2BF3E494040C23060C9354340274D83A279404940ACFE08C380394340274D83A279404940ACFE08C3803943408046E9D2BF3E494040C23060C93543408046E9D2BF3E4940
12324	Казацкое	1	1	468	38.480494	38.516148000000001	50.708874000000002	50.678125000000001	0103000020E610000001000000050000004DF6CFD3803D4340CDCCCCCCCC5649404DF6CFD3803D43400B7E1B62BC5A4940AAF23D23114243400B7E1B62BC5A4940AAF23D2311424340CDCCCCCCCC5649404DF6CFD3803D4340CDCCCCCCCC564940
11156	Засосна	1	1	468	38.350192999999997	38.435524000000001	50.641952000000003	50.615685999999997	0103000020E61000000100000005000000E124CD1FD32C4340724D81CCCE4E4940E124CD1FD32C434008CDAE7B2B524940C24F1C40BF37434008CDAE7B2B524940C24F1C40BF374340724D81CCCE4E4940E124CD1FD32C4340724D81CCCE4E4940
10692	Завальское	1	1	468	38.218114	38.245260999999999	50.705874000000001	50.691969999999998	0103000020E610000001000000050000005E66D828EB1B434014E81379925849405E66D828EB1B4340618C48145A5A4940FCFD62B6641F4340618C48145A5A4940FCFD62B6641F434014E81379925849405E66D828EB1B434014E8137992584940
54041	Ендовицкое	1	1	468	38.487555	38.502799000000003	50.588580999999998	50.576712999999998	0103000020E610000001000000050000002A00C633683E4340CA1649BBD14949402A00C633683E43400306499F564B494013BBB6B75B4043400306499F564B494013BBB6B75B404340CA1649BBD14949402A00C633683E4340CA1649BBD1494940
11070	Гредякино	1	1	468	38.219884	38.267378000000001	50.629612000000002	50.620469	0103000020E61000000100000005000000F374AE28251C4340469737876B4F4940F374AE28251C4340A795422097504940BFD53A7139224340A795422097504940BFD53A7139224340469737876B4F4940F374AE28251C4340469737876B4F4940
12162	Горовое	1	1	468	38.228355000000001	38.270414000000002	50.586013000000001	50.577840000000002	0103000020E61000000100000005000000657094BC3A1D43400B293FA9F6494940657094BC3A1D4340F3035779024B4940B6300BED9C224340F3035779024B4940B6300BED9C2243400B293FA9F6494940657094BC3A1D43400B293FA9F6494940
10807	Веселое	1	1	468	38.115293000000001	38.184517	50.665976999999998	50.588867	0103000020E61000000100000005000000973AC8EBC10E4340C9586DFE5F4B4940973AC8EBC10E4340B071FDBB3E5549402C47C8409E174340B071FDBB3E5549402C47C8409E174340C9586DFE5F4B4940973AC8EBC10E4340C9586DFE5F4B4940
10667	Верхососна	1	1	468	38.213093000000001	38.265284999999999	50.748313000000003	50.709456000000003	0103000020E61000000100000005000000D600A5A1461B4340BAF94674CF5A4940D600A5A1461B4340F9156BB8C85F4940478FDFDBF4214340F9156BB8C85F4940478FDFDBF4214340BAF94674CF5A4940D600A5A1461B4340BAF94674CF5A4940
10395	Верхняя Покровка	1	1	468	38.397041000000002	38.495199	50.806629999999998	50.759931999999999	0103000020E61000000100000005000000E8154F3DD23243408997A77345614940E8154F3DD23243407AFCDEA63F67494086014BAE623F43407AFCDEA63F67494086014BAE623F43408997A77345614940E8154F3DD23243408997A77345614940
10284	Валуйчик	1	1	468	38.240788000000002	38.275274000000003	50.422046999999999	50.365913999999997	0103000020E6100000010000000500000077A22424D21E434003931B45D62E494077A22424D21E4340FD2FD7A20536494035B8AD2D3C234340FD2FD7A20536494035B8AD2D3C23434003931B45D62E494077A22424D21E434003931B45D62E4940
11616	Валуй	1	1	468	38.368321000000002	38.404946000000002	50.522024000000002	50.500411999999997	0103000020E610000001000000050000000BB77C24252F434052431B800D4049400BB77C24252F434012DDB3AED1424940B1524145D533434012DDB3AED1424940B1524145D533434052431B800D4049400BB77C24252F434052431B800D404940
54008	Большое Быково	1	1	468	38.375624999999999	38.415663000000002	50.877108	50.846559999999997	0103000020E61000000100000005000000AE47E17A14304340060DFD135C6C4940AE47E17A14304340AD872F13457049402194F77134354340AD872F13457049402194F77134354340060DFD135C6C4940AE47E17A14304340060DFD135C6C4940
9918	Бирюч	1	1	468	38.410569000000002	38.435381	50.540564000000003	50.518256000000001	0103000020E610000001000000050000002FE065868D344340577A6D36564249402FE065868D3443408EB27E33314549405F268A90BA3743408EB27E33314549405F268A90BA374340577A6D36564249402FE065868D344340577A6D3656424940
12059	Арнаутово	1	1	468	38.390860000000004	38.436396000000002	50.411290999999999	50.385928999999997	0103000020E6100000010000000500000044A852B307324340FBC9181F6631494044A852B307324340CF11F92EA5344940780DFAD2DB374340CF11F92EA5344940780DFAD2DB374340FBC9181F6631494044A852B307324340FBC9181F66314940
9653	Широкое	1	1	396	38.494031999999997	38.522525999999999	51.022250999999997	51.008220999999999	0103000020E61000000100000005000000B796C9703C3F4340F911BF620D814940B796C9703C3F4340D2A6EA1ED9824940A4A7C821E2424340D2A6EA1ED9824940A4A7C821E2424340F911BF620D814940B796C9703C3F4340F911BF620D814940
9846	Черемухово	1	1	396	38.435129000000003	38.452196999999998	50.95393	50.938284000000003	0103000020E6100000010000000500000046459C4EB2374340172EABB01978494046459C4EB23743402E56D4601A7A4940B62C5F97E13943402E56D4601A7A4940B62C5F97E1394340172EABB01978494046459C4EB2374340172EABB019784940
9741	Хмелевое	1	1	396	38.529308	38.565123999999997	50.913466999999997	50.892074999999998	0103000020E610000001000000050000006EC1525DC0434340234A7B832F7249406EC1525DC0434340D47C957CEC744940A417B5FB55484340D47C957CEC744940A417B5FB55484340234A7B832F7249406EC1525DC0434340234A7B832F724940
9618	Флюговка	1	1	396	38.303679000000002	38.319597000000002	51.022053	51.008623	0103000020E61000000100000005000000B2BD16F4DE264340287FF78E1A814940B2BD16F4DE264340ACE3F8A1D28249402A73F38DE8284340ACE3F8A1D28249402A73F38DE8284340287FF78E1A814940B2BD16F4DE264340287FF78E1A814940
9121	Ураково	1	1	396	38.555405	38.595486999999999	50.877113000000001	50.850143000000003	0103000020E610000001000000050000007784D3821747434030F65E7CD16C49407784D38217474340BFF2203D45704940B91803EB384C4340BFF2203D45704940B91803EB384C434030F65E7CD16C49407784D3821747434030F65E7CD16C4940
9561	Староуколово	1	1	396	38.454982000000001	38.474367999999998	51.027287999999999	51.015061000000003	0103000020E610000001000000050000006422A5D93C3A4340F838D384ED8149406422A5D93C3A434060C9552C7E8349406C223317B83C434060C9552C7E8349406C223317B83C4340F838D384ED8149406422A5D93C3A4340F838D384ED814940
9850	Сетище	1	1	396	38.620109999999997	38.662770999999999	50.957265999999997	50.934247999999997	0103000020E6100000010000000500000016F6B4C35F4F43403C2D3F709577494016F6B4C35F4F43404FC939B1877A49405DDE1CAED55443404FC939B1877A49405DDE1CAED55443403C2D3F709577494016F6B4C35F4F43403C2D3F7095774940
9262	Свистовка	1	1	396	38.744374000000001	38.762321999999998	50.996437	50.981537000000003	0103000020E6100000010000000500000011FFB0A5475F434030682101A37D494011FFB0A5475F43401EC3633F8B7F4940BA826DC4936143401EC3633F8B7F4940BA826DC49361434030682101A37D494011FFB0A5475F434030682101A37D4940
9708	Расховец	1	1	396	38.450274999999998	38.48751	50.918503999999999	50.897297000000002	0103000020E610000001000000050000006B9A779CA239434043E6CAA0DA7249406B9A779CA2394340629F008A917549408A3C49BA663E4340629F008A917549408A3C49BA663E434043E6CAA0DA7249406B9A779CA239434043E6CAA0DA724940
9207	Польниково	1	1	396	38.697795999999997	38.721215999999998	50.914364999999997	50.902209999999997	0103000020E61000000100000005000000CAA31B6151594340E40F069E7B734940CAA31B6151594340B3CD8DE9097549400CAD4ECE505C4340B3CD8DE9097549400CAD4ECE505C4340E40F069E7B734940CAA31B6151594340E40F069E7B734940
9467	Новоуколово	1	1	396	38.403112999999998	38.470351999999998	51.040213000000001	51.003878999999998	0103000020E61000000100000005000000D5CBEF34993343401212691B7F804940D5CBEF3499334340E1EF17B325854940D9CD8C7E343C4340E1EF17B325854940D9CD8C7E343C43401212691B7F804940D5CBEF34993343401212691B7F804940
9362	Новосолдатка	1	1	396	38.485498	38.512248999999997	50.962389000000002	50.943142000000002	0103000020E61000000100000005000000FF2268CC243E4340F5BD86E0B8784940FF2268CC243E4340DC8310902F7B494050340F6091414340DC8310902F7B494050340F6091414340F5BD86E0B8784940FF2268CC243E4340F5BD86E0B8784940
54006	Лесное-Уколово	1	1	396	38.813966999999998	38.847473999999998	50.924523000000001	50.894131999999999	0103000020E61000000100000005000000F9821612306843404E27D9EA72724940F9821612306843402DB308C556764940EB1A2D077A6C43402DB308C556764940EB1A2D077A6C43404E27D9EA72724940F9821612306843404E27D9EA72724940
9283	Круглое	1	1	396	38.532452999999997	38.580278999999997	50.960954000000001	50.938636000000002	0103000020E610000001000000050000001BD47E6B27444340946C7539257849401BD47E6B27444340EE7A698A007B49401DC70F95464A4340EE7A698A007B49401DC70F95464A4340946C7539257849401BD47E6B27444340946C753925784940
9156	Красное	1	1	396	38.663319000000001	38.703420000000001	50.944788000000003	50.920867000000001	0103000020E6100000010000000500000060E811A3E75443409A7B48F8DE75494060E811A3E75443409ED32CD0EE78494019ADA3AA095A43409ED32CD0EE78494019ADA3AA095A43409A7B48F8DE75494060E811A3E75443409A7B48F8DE754940
9018	Камышенка	1	1	396	38.611414000000003	38.639513999999998	50.883757000000003	50.867826000000001	0103000020E6100000010000000500000085285FD0424E43402B4F20EC146F494085285FD0424E4340384E0AF31E714940C5AA4198DB514340384E0AF31E714940C5AA4198DB5143402B4F20EC146F494085285FD0424E43402B4F20EC146F4940
9076	Камызино	1	1	396	38.578940000000003	38.628940999999998	50.859479999999998	50.828938000000001	0103000020E61000000100000005000000522CB7B41A4A4340B134F0A31A6A4940522CB7B41A4A434075C8CD70036E4940880E81238150434075C8CD70036E4940880E812381504340B134F0A31A6A4940522CB7B41A4A4340B134F0A31A6A4940
9495	Каменка	1	1	396	38.348171999999998	38.392099999999999	51.101286999999999	51.082568000000002	0103000020E6100000010000000500000003B16CE6902C43401BD99596918A494003B16CE6902C43404641F0F8F68C49407C613255303243404641F0F8F68C49407C613255303243401BD99596918A494003B16CE6902C43401BD99596918A4940
9342	Заломное	1	1	396	38.556626000000001	38.592756000000001	50.946893000000003	50.927294000000003	0103000020E61000000100000005000000390D51853F47434076E3DD91B1764940390D51853F474340DAE731CA33794940FF40B96DDF4B4340DAE731CA33794940FF40B96DDF4B434076E3DD91B1764940390D51853F47434076E3DD91B1764940
8989	Готовье	1	1	396	38.645155000000003	38.685436000000003	50.862310999999998	50.819499	0103000020E61000000100000005000000EAEC647094524340670DDE57E5684940EAEC64709452434093FDF334606E494023C0E95DBC57434093FDF334606E494023C0E95DBC574340670DDE57E5684940EAEC647094524340670DDE57E5684940
8906	Горки	1	1	396	38.711315999999997	38.778841999999997	51.048560000000002	51.030816999999999	0103000020E610000001000000050000008E8F16670C5B43409694BBCFF18349408E8F16670C5B434067F2CD363786494028603B18B163434067F2CD363786494028603B18B16343409694BBCFF18349408E8F16670C5B43409694BBCFF1834940
52406	Большое	1	1	396	38.332470000000001	38.357802	50.933697000000002	50.920394999999999	0103000020E61000000100000005000000587380608E2A43407233DC80CF754940587380608E2A4340C9AF1F6283774940C138B874CC2D4340C9AF1F6283774940C138B874CC2D43407233DC80CF754940587380608E2A43407233DC80CF754940
8918	Богословка	1	1	396	38.807381999999997	38.833289000000001	51.041601	51.022193999999999	0103000020E6100000010000000500000085B01A4B586743406E15C440D782494085B01A4B586743408E3D7B2E53854940EB8EC536A96A43408E3D7B2E53854940EB8EC536A96A43406E15C440D782494085B01A4B586743406E15C440D7824940
8747	Яблоново	1	1	483	37.325485	37.387414999999997	50.869622	50.841078000000003	0103000020E61000000100000005000000562B137EA9A942404BB1A371A86B4940562B137EA9A94240E9F010C64F6F49406B7D91D096B14240E9F010C64F6F49406B7D91D096B142404BB1A371A86B4940562B137EA9A942404BB1A371A86B4940
8722	Шляхово	1	1	483	36.799799999999998	36.832391000000001	50.720753999999999	50.712387999999997	0103000020E610000001000000050000009FABADD85F6642400B08AD872F5B49409FABADD85F664240083BC5AA415C49400C3ECDC98B6A4240083BC5AA415C49400C3ECDC98B6A42400B08AD872F5B49409FABADD85F6642400B08AD872F5B4940
8626	Шеино	1	1	483	36.862323000000004	36.907912000000003	50.690047	50.671201000000003	0103000020E6100000010000000500000058CB9D99606E4240710514EAE955494058CB9D99606E4240F9D9C87553584940AFD2DD7536744240F9D9C87553584940AFD2DD7536744240710514EAE955494058CB9D99606E4240710514EAE9554940
7573	Хмелевое	1	1	483	37.019654000000003	37.462091999999998	50.945127999999997	50.858024	0103000020E61000000100000005000000289EB305848242407097FDBAD36D4940289EB3058482424056444DF4F978494022DFA5D425BB424056444DF4F978494022DFA5D425BB42407097FDBAD36D4940289EB305848242407097FDBAD36D4940
8551	Фощеватое	1	1	483	37.306333000000002	37.325620000000001	50.752541000000001	50.739317999999997	0103000020E61000000100000005000000C15774EB35A742400CACE3F8A15E4940C15774EB35A7424017F3734353604940367689EAADA9424017F3734353604940367689EAADA942400CACE3F8A15E4940C15774EB35A742400CACE3F8A15E4940
8541	Соколовка	1	1	483	37.235995000000003	37.281233999999998	50.731081000000003	50.710008999999999	0103000020E6100000010000000500000080828B15359E4240CE6E2D93E15A494080828B15359E42400EDDEC0F945D4940FA42C879FFA342400EDDEC0F945D4940FA42C879FFA34240CE6E2D93E15A494080828B15359E4240CE6E2D93E15A4940
7295	Сетное	1	1	483	37.154473000000003	37.188195999999998	50.766255999999998	50.74344	0103000020E61000000100000005000000B98E71C5C5934240E544BB0A295F4940B98E71C5C5934240902E36AD14624940779E78CE16984240902E36AD14624940779E78CE16984240E544BB0A295F4940B98E71C5C5934240E544BB0A295F4940
8012	Самойловка	1	1	483	37.072034000000002	37.086542000000001	50.845992000000003	50.833182000000001	0103000020E610000001000000050000009C19FD6838894240D5CE30B5A56A49409C19FD6838894240BD564277496C49407FDDE9CE138B4240BD564277496C49407FDDE9CE138B4240D5CE30B5A56A49409C19FD6838894240D5CE30B5A56A4940
8448	Проходное	1	1	483	37.087502999999998	37.112234000000001	50.771599999999999	50.752307999999999	0103000020E61000000100000005000000A4A65D4C338B42407442E8A04B604940A4A65D4C338B4240FBCBEEC9C3624940E8BF07AF5D8E4240FBCBEEC9C3624940E8BF07AF5D8E42407442E8A04B604940A4A65D4C338B42407442E8A04B604940
8334	Поповка	1	1	483	37.184781999999998	37.222555999999997	50.884217	50.859439999999999	0103000020E61000000100000005000000DA71C3EFA6974240E76F4221026E4940DA71C3EFA69742409BC8CC052E714940A8C30AB77C9C42409BC8CC052E714940A8C30AB77C9C4240E76F4221026E4940DA71C3EFA6974240E76F4221026E4940
8251	Погореловка	1	1	483	37.149549999999998	37.182608000000002	50.824807	50.797511	0103000020E61000000100000005000000F38E537424934240A29927D714664940F38E537424934240854199469369494076FEEDB25F974240854199469369494076FEEDB25F974240A29927D714664940F38E537424934240A29927D714664940
8165	Плотавец	1	1	483	37.195929999999997	37.233739999999997	50.919890000000002	50.900444	0103000020E610000001000000050000001327F73B1499424091F0BDBF417349401327F73B149942406FF59CF4BE7549402EE23B31EB9D42406FF59CF4BE7549402EE23B31EB9D424091F0BDBF417349401327F73B1499424091F0BDBF41734940
8090	Плоское	1	1	483	36.991850999999997	37.020184	50.73856	50.713517000000003	0103000020E61000000100000005000000A0C03BF9F47E4240ED116A86545B4940A0C03BF9F47E42401F115322895E494084F3A963958242401F115322895E494084F3A96395824240ED116A86545B4940A0C03BF9F47E4240ED116A86545B4940
7792	Пестуново	1	1	483	36.995156999999999	37.016986000000003	50.934627999999996	50.916108000000001	0103000020E6100000010000000500000057B1F84D617F42404FCDE5064375494057B1F84D617F424083F6EAE3A1774940B43EE5982C82424083F6EAE3A1774940B43EE5982C8242404FCDE5064375494057B1F84D617F42404FCDE50643754940
7996	Новая Слободка	1	1	483	36.999037000000001	37.032868000000001	50.851252000000002	50.818137999999998	0103000020E610000001000000050000003A3FC571E07F4240B3CEF8BEB86849403A3FC571E07F4240CA5356D3F56C4940DF8AC40435844240CA5356D3F56C4940DF8AC40435844240B3CEF8BEB86849403A3FC571E07F4240B3CEF8BEB8684940
7263	Нечаево	1	1	483	37.113573000000002	37.156018000000003	50.708292999999998	50.682724999999998	0103000020E61000000100000005000000B45A608F898E4240AF94658863574940B45A608F898E42402C7E5358A95A49402ECBD765F89342402C7E5358A95A49402ECBD765F8934240AF94658863574940B45A608F898E4240AF94658863574940
7917	Мелихово	1	1	483	36.777602999999999	36.806716999999999	50.704464999999999	50.687570999999998	0103000020E61000000100000005000000C022BF7E88634240C956975302584940C022BF7E886342409C16BCE82B5A49404910AE80426742409C16BCE82B5A49404910AE8042674240C956975302584940C022BF7E88634240C956975302584940
7171	Мальцевка	1	1	483	37.413052999999998	37.430399000000001	50.796183999999997	50.778371999999997	0103000020E61000000100000005000000E141B3EBDEB44240A10F96B1A1634940E141B3EBDEB442409ACC785BE9654940959D7E5017B742409ACC785BE9654940959D7E5017B74240A10F96B1A1634940E141B3EBDEB44240A10F96B1A1634940
8655	Мазикино	1	1	483	36.862654999999997	37.031340999999998	50.799754	50.707985000000001	0103000020E610000001000000050000008D5DA27A6B6E42407F87A2409F5A49408D5DA27A6B6E42402F6CCD565E66494010035DFB028442402F6CCD565E66494010035DFB028442407F87A2409F5A49408D5DA27A6B6E42407F87A2409F5A4940
7839	Ломово	1	1	483	36.918953000000002	36.951822	50.762991999999997	50.743473999999999	0103000020E61000000100000005000000D2C77C40A075424091B6F1272A5F4940D2C77C40A0754240088ECBB8A961494081CEA44DD5794240088ECBB8A961494081CEA44DD579424091B6F1272A5F4940D2C77C40A075424091B6F1272A5F4940
7721	Кощеево	1	1	483	37.100403	37.127856000000001	50.906595000000003	50.881506000000002	0103000020E61000000100000005000000CCB56801DA8C4240289D4830D5704940CCB56801DA8C4240CBDB114E0B744940774CDD955D904240CBDB114E0B744940774CDD955D904240289D4830D5704940CCB56801DA8C4240289D4830D5704940
6804	Короча	1	1	483	37.175753999999998	37.208480000000002	50.822434999999999	50.801177000000003	0103000020E610000001000000050000001212691B7F96424059A7CAF78C6649401212691B7F964240FA0AD28C456949405FEFFE78AF9A4240FA0AD28C456949405FEFFE78AF9A424059A7CAF78C6649401212691B7F96424059A7CAF78C664940
7712	Короткое	1	1	483	37.24973	37.304878000000002	50.921081999999998	50.868729000000002	0103000020E61000000100000005000000406A1327F79F42401C0B0A83326F4940406A1327F79F42409677D503E67549408CA2073E06A742409677D503E67549408CA2073E06A742401C0B0A83326F4940406A1327F79F42401C0B0A83326F4940
7448	Клиновец	1	1	483	37.277560000000001	37.297924999999999	50.792222000000002	50.783406999999997	0103000020E61000000100000005000000C156091687A342408E3A3AAE46644940C156091687A34240FB95CE876765494095D4096822A64240FB95CE876765494095D4096822A642408E3A3AAE46644940C156091687A342408E3A3AAE46644940
8471	Ивица	1	1	483	37.184305999999999	37.248778000000001	50.709085000000002	50.690669	0103000020E61000000100000005000000713AC9569797424036AE7FD767584940713AC95697974240C68A1A4CC35A49406EFB1EF5D79F4240C68A1A4CC35A49406EFB1EF5D79F424036AE7FD767584940713AC9569797424036AE7FD767584940
7643	Заячье	1	1	483	36.962223999999999	36.997950000000003	50.787393000000002	50.757978000000001	0103000020E6100000010000000500000091B6F1272A7B4240338B506C0561494091B6F1272A7B4240B70C384BC964494088855AD3BC7F4240B70C384BC964494088855AD3BC7F4240338B506C0561494091B6F1272A7B4240338B506C05614940
7623	Жигайловка	1	1	483	37.362172000000001	37.395293000000002	50.721426999999998	50.706108	0103000020E6100000010000000500000072C3EFA65BAE4240D4B837BF615A494072C3EFA65BAE4240C7B94DB8575C49403BAB05F698B24240C7B94DB8575C49403BAB05F698B24240D4B837BF615A494072C3EFA65BAE4240D4B837BF615A4940
54010	Дальняя Игуменка	1	1	483	36.725490999999998	36.754964999999999	50.699770000000001	50.674791999999997	0103000020E610000001000000050000006B459BE3DC5C42401CCD91955F5649406B459BE3DC5C4240685C381092594940F44F70B1A2604240685C381092594940F44F70B1A26042401CCD91955F5649406B459BE3DC5C42401CCD91955F564940
8395	Городище	1	1	483	37.052765999999998	37.078206000000002	50.757852	50.742721000000003	0103000020E610000001000000050000009D2B4A09C1864240B686527B115F49409D2B4A09C1864240A69A594B01614940ED2C7AA7028A4240A69A594B01614940ED2C7AA7028A4240B686527B115F49409D2B4A09C1864240B686527B115F4940
7550	Бубново	1	1	483	37.505256000000003	37.540174	50.855164000000002	50.835025000000002	0103000020E61000000100000005000000CC0D863AACC04240D42B6519E26A4940CC0D863AACC04240B85B9203766D49402313F06B24C54240B85B9203766D49402313F06B24C54240D42B6519E26A4940CC0D863AACC04240D42B6519E26A4940
8806	Большое Песчаное	1	1	483	37.332949999999997	37.370652	50.921190000000003	50.910594000000003	0103000020E61000000100000005000000029A081B9EAA424088F71C588E744940029A081B9EAA42407DB3CD8DE97549403719558671AF42407DB3CD8DE97549403719558671AF424088F71C588E744940029A081B9EAA424088F71C588E744940
7463	Большая Халань	1	1	483	37.393470000000001	37.454070000000002	50.940337999999997	50.910150999999999	0103000020E6100000010000000500000083FA96395DB24240FAB5F5D37F74494083FA96395DB24240D097DEFE5C784940200C3CF71EBA4240D097DEFE5C784940200C3CF71EBA4240FAB5F5D37F74494083FA96395DB24240FAB5F5D37F744940
7358	Бехтеевка	1	1	483	37.195076999999998	37.239722999999998	50.823008999999999	50.782308	0103000020E61000000100000005000000D4997B48F898424018B325AB22644940D4997B48F898424026A8E15B58694940AC8C463EAF9E424026A8E15B58694940AC8C463EAF9E424018B325AB22644940D4997B48F898424018B325AB22644940
8155	Белый Колодец	1	1	483	37.249524000000001	37.279086999999997	50.950916999999997	50.930591999999997	0103000020E6100000010000000500000097C80567F09F4240A9F57EA31D77494097C80567F09F4240EF1AF4A5B77949408FDE701FB9A34240EF1AF4A5B77949408FDE701FB9A34240A9F57EA31D77494097C80567F09F4240A9F57EA31D774940
7181	Афанасово	1	1	483	37.141573000000001	37.171595000000003	50.739255999999997	50.720395000000003	0103000020E61000000100000005000000917F66101F924240D99942E7355C4940917F66101F92424096AFCBF09F5E49401D9430D3F695424096AFCBF09F5E49401D9430D3F6954240D99942E7355C4940917F66101F924240D99942E7355C4940
7082	Анновка	1	1	483	37.424165000000002	37.4925	50.780541999999997	50.765993999999999	0103000020E61000000100000005000000CE8DE9094BB64240537765170C624940CE8DE9094BB64240C493DDCCE8634940D7A3703D0ABF4240C493DDCCE8634940D7A3703D0ABF4240537765170C624940CE8DE9094BB64240537765170C624940
6995	Алексеевка	1	1	483	37.026255999999997	37.061255000000003	50.787177	50.745280999999999	0103000020E6100000010000000500000071A94A5B5C83424043AA285E655F494071A94A5B5C834240EA944737C2644940B6DB2E34D7874240EA944737C2644940B6DB2E34D787424043AA285E655F494071A94A5B5C83424043AA285E655F4940
6466	Череново	1	1	797	36.039169999999999	36.066504999999999	51.159883999999998	51.128053999999999	0103000020E61000000100000005000000FE7DC685030542409D0FCF1264904940FE7DC68503054240AB933314779449409F02603C83084240AB933314779449409F02603C830842409D0FCF1264904940FE7DC685030542409D0FCF1264904940
6772	Хомутцы	1	1	797	35.927697999999999	35.958734	51.131610000000002	51.110652000000002	0103000020E610000001000000050000004548DDCEBEF64140569E40D8298E49404548DDCEBEF64140CDE9B298D890494019C8B3CBB7FA4140CDE9B298D890494019C8B3CBB7FA4140569E40D8298E49404548DDCEBEF64140569E40D8298E4940
6209	Федчевка	1	1	797	36.068733000000002	36.086205	51.068300999999998	51.055587000000003	0103000020E61000000100000005000000F793313ECC084240988A8D791D874940F793313ECC0842405DA45016BE88494037E0F3C3080B42405DA45016BE88494037E0F3C3080B4240988A8D791D874940F793313ECC084240988A8D791D874940
6686	Сырцево	1	1	797	36.247695	36.283726999999999	50.916317999999997	50.888246000000002	0103000020E61000000100000005000000FD304278B41F4240C366800BB2714940FD304278B41F4240395E81E84975494000FF942A51244240395E81E84975494000FF942A51244240C366800BB2714940FD304278B41F4240C366800BB2714940
6635	Сухосолотино	1	1	797	36.371006999999999	36.467244000000001	51.007280000000002	50.975259000000001	0103000020E6100000010000000500000025CB49287D2F424099107349D57C494025CB49287D2F42401BF5108DEE80494049A0C1A6CE3B42401BF5108DEE80494049A0C1A6CE3B424099107349D57C494025CB49287D2F424099107349D57C4940
6571	Сафоновка	1	1	797	36.386673999999999	36.404353	51.100347999999997	51.084916	0103000020E61000000100000005000000541B9C887E3142401D740987DE8A4940541B9C887E314240081C0934D88C49400E85CFD6C1334240081C0934D88C49400E85CFD6C13342401D740987DE8A4940541B9C887E3142401D740987DE8A4940
6521	Покровка	1	1	797	36.419876000000002	36.454541999999996	50.903061999999998	50.880420999999998	0103000020E610000001000000050000000A302C7FBE35424016DBA4A2B17049400A302C7FBE35424053211E89977349404754A86E2E3A424053211E89977349404754A86E2E3A424016DBA4A2B17049400A302C7FBE35424016DBA4A2B1704940
6415	Песчаное	1	1	797	36.004665000000003	36.042960000000001	51.153066000000003	51.128258000000002	0103000020E61000000100000005000000CA37DBDC98004240A6B915C26A904940CA37DBDC980042409510ACAA97934940A18499B67F0542409510ACAA97934940A18499B67F054240A6B915C26A904940CA37DBDC98004240A6B915C26A904940
6356	Новенькое	1	1	797	36.120027	36.169255	50.988415000000003	50.954225000000001	0103000020E6100000010000000500000089D1730B5D0F42404703780B247A494089D1730B5D0F42401CF0F961847E49409DD7D825AA1542401CF0F961847E49409DD7D825AA1542404703780B247A494089D1730B5D0F42404703780B247A4940
6290	Курасовка	1	1	797	36.193382999999997	36.24447	51.085402000000002	51.027847999999999	0103000020E610000001000000050000001A4D2EC6C018424027A1F485908349401A4D2EC6C0184240AA81E673EE8A4940336DFFCA4A1F4240AA81E673EE8A4940336DFFCA4A1F424027A1F485908349401A4D2EC6C018424027A1F48590834940
6253	Кочетовка	1	1	797	36.412886999999998	36.488838999999999	51.062849999999997	51.011631999999999	0103000020E61000000100000005000000C6F8307BD934424025CB49287D814940C6F8307BD9344240DC4603780B8849403201BF46923E4240DC4603780B8849403201BF46923E424025CB49287D814940C6F8307BD934424025CB49287D814940
6145	Кировский	1	1	797	36.115589	36.132981000000001	51.023587999999997	51.01484	0103000020E610000001000000050000008063CF9ECB0E42401956F146E68149408063CF9ECB0E4240FD497CEE04834940A4FE7A8505114240FD497CEE04834940A4FE7A85051142401956F146E68149408063CF9ECB0E42401956F146E6814940
5946	Ивня	1	1	797	36.119056999999998	36.169739999999997	51.096727999999999	51.039647000000002	0103000020E6100000010000000500000010AE80423D0F4240383124271385494010AE80423D0F4240C24D4695618C49405969520ABA154240C24D4695618C49405969520ABA154240383124271385494010AE80423D0F42403831242713854940
5874	Драгунка	1	1	797	35.945735999999997	35.987839999999998	51.034056999999997	51.012551000000002	0103000020E610000001000000050000002E5393E00DF941401C446B459B8149402E5393E00DF941409599D2FA5B8449401FD7868A71FE41409599D2FA5B8449401FD7868A71FE41401C446B459B8149402E5393E00DF941401C446B459B814940
5845	Вознесеновка	1	1	797	36.20834	36.241200999999997	51.089424999999999	51.073450999999999	0103000020E610000001000000050000006D3997E2AA1A4240E36DA5D7668949406D3997E2AA1A4240EF384547728B49409961A3ACDF1E4240EF384547728B49409961A3ACDF1E4240E36DA5D7668949406D3997E2AA1A4240E36DA5D766894940
5764	Владимировка	1	1	797	36.256687999999997	36.294353999999998	51.065815999999998	51.050038000000001	0103000020E6100000010000000500000048A30227DB20424054C72AA56786494048A30227DB204240DAC69FA86C88494030B95164AD254240DAC69FA86C88494030B95164AD25424054C72AA56786494048A30227DB20424054C72AA567864940
5656	Верхопенье	1	1	797	36.264180000000003	36.358961000000001	50.972503000000003	50.919708	0103000020E61000000100000005000000EF2076A6D02142404EEFE2FDB8754940EF2076A6D0214240862172FA7A7C49400DC51D6FF22D4240862172FA7A7C49400DC51D6FF22D42404EEFE2FDB8754940EF2076A6D02142404EEFE2FDB8754940
5631	Богатое	1	1	797	36.005716	36.037022999999998	50.988987000000002	50.961061000000001	0103000020E610000001000000050000002F88484DBB004240043BFE0B047B49402F88484DBB004240A7954220977E494093196F2BBD044240A7954220977E494093196F2BBD044240043BFE0B047B49402F88484DBB004240043BFE0B047B4940
6706	Березовка	1	1	797	36.183196000000002	36.227429000000001	50.931921000000003	50.875777999999997	0103000020E6100000010000000500000007616EF7721742403447567E1970494007616EF77217424052BAF42F49774940BC94BA641C1D424052BAF42F49774940BC94BA641C1D42403447567E1970494007616EF7721742403447567E19704940
47613	Юшково	1	1	522	37.345913000000003	37.376842000000003	51.207332000000001	51.186663000000003	0103000020E6100000010000000500000071218FE046AC4240C72FBC92E497494071218FE046AC424007B5DFDA899A49402FE1D05B3CB0424007B5DFDA899A49402FE1D05B3CB04240C72FBC92E497494071218FE046AC4240C72FBC92E4974940
47970	Юрьевка	1	1	522	37.33428	37.354104999999997	51.062657999999999	51.049908000000002	0103000020E610000001000000050000007BDAE1AFC9AA424086E7A562638649407BDAE1AFC9AA4240986A662D05884940CF2C095053AD4240986A662D05884940CF2C095053AD424086E7A562638649407BDAE1AFC9AA424086E7A56263864940
4811	Чуево	1	1	522	37.093567	37.123167000000002	51.148890999999999	51.124533	0103000020E610000001000000050000000F7EE200FA8B4240EA2285B2F08F49400F7EE200FA8B424099D53BDC0E9349402579AEEFC38F424099D53BDC0E9349402579AEEFC38F4240EA2285B2F08F49400F7EE200FA8B4240EA2285B2F08F4940
3768	Чапкино	1	1	522	37.249865	37.271604000000004	51.248376	51.226993	0103000020E6100000010000000500000020B58993FB9F4240E1B54B1B0E9D494020B58993FB9F42403F8EE6C8CA9F49403DBB7CEBC3A242403F8EE6C8CA9F49403DBB7CEBC3A24240E1B54B1B0E9D494020B58993FB9F4240E1B54B1B0E9D4940
47478	Хворостянка	1	1	522	37.516089999999998	37.542077999999997	51.114752000000003	51.105550999999998	0103000020E6100000010000000500000075E5B33C0FC24240B187F6B1828D494075E5B33C0FC2424047938B31B08E4940C7F0D8CF62C5424047938B31B08E4940C7F0D8CF62C54240B187F6B1828D494075E5B33C0FC24240B187F6B1828D4940
47520	Успенка	1	1	522	37.693956	37.726959999999998	51.130020999999999	51.112026	0103000020E61000000100000005000000766EDA8CD3D842409E2633DE568E4940766EDA8CD3D8424088653387A490494005C078060DDD424088653387A490494005C078060DDD42409E2633DE568E4940766EDA8CD3D842409E2633DE568E4940
4781	Уколово	1	1	522	37.053052999999998	37.087135000000004	51.230043999999999	51.203257000000001	0103000020E6100000010000000500000033FAD170CA8642406FD74B53049A494033FAD170CA8642400D52F014729D494022AB5B3D278B42400D52F014729D494022AB5B3D278B42406FD74B53049A494033FAD170CA8642406FD74B53049A4940
47086	Троицкий	1	1	522	37.488323000000001	37.532950999999997	51.368636000000002	51.349226999999999	0103000020E610000001000000050000003B71395E81BE4240AAF06778B3AC49403B71395E81BE42406B10E6762FAF49406CAF05BD37C442406B10E6762FAF49406CAF05BD37C44240AAF06778B3AC49403B71395E81BE4240AAF06778B3AC4940
47855	Толстое	1	1	522	37.237217000000001	37.272547000000003	51.013406000000003	50.984864999999999	0103000020E6100000010000000500000012876C205D9E4240CEFC6A0E107E494012876C205D9E4240FCC8AD49B7814940BCCFF1D1E2A24240FCC8AD49B7814940BCCFF1D1E2A24240CEFC6A0E107E494012876C205D9E4240CEFC6A0E107E4940
3291	Теплый Колодезь	1	1	522	37.477111999999998	37.540784000000002	51.328977000000002	51.300226000000002	0103000020E61000000100000005000000BB438A0112BD424057B439CE6DA64940BB438A0112BD42406F1118EB1BAA49409C19FD6838C542406F1118EB1BAA49409C19FD6838C5424057B439CE6DA64940BB438A0112BD424057B439CE6DA64940
47819	Телешовка	1	1	522	37.260303	37.282043000000002	51.053905	51.035772999999999	0103000020E610000001000000050000007D06D49B51A14240378AAC35948449407D06D49B51A14240A20BEA5BE68649406A882AFC19A44240A20BEA5BE68649406A882AFC19A44240378AAC35948449407D06D49B51A14240378AAC3594844940
47308	Строкино	1	1	522	37.236417000000003	37.266618999999999	51.329945000000002	51.304972999999997	0103000020E61000000100000005000000F69B89E9429E4240DD94F25A09A74940F69B89E9429E4240473D44A33BAA494001BF469220A24240473D44A33BAA494001BF469220A24240DD94F25A09A74940F69B89E9429E4240DD94F25A09A74940
47967	Степное	1	1	522	37.345427999999998	37.361094000000001	51.011989	51.004435000000001	0103000020E61000000100000005000000B48F15FC36AC424098FA795391804940B48F15FC36AC4240B47405DB888149401364045438AE4240B47405DB888149401364045438AE424098FA795391804940B48F15FC36AC424098FA795391804940
47593	Солнцево	1	1	522	37.246344000000001	37.273257000000001	51.198562000000003	51.190320999999997	0103000020E610000001000000050000006DC83F33889F4240FA5E43705C9849406DC83F33889F42403B1DC87A6A9949409833DB15FAA242403B1DC87A6A9949409833DB15FAA24240FA5E43705C9849406DC83F33889F4240FA5E43705C984940
47773	Скородное	1	1	522	37.205146999999997	37.255363000000003	51.095205999999997	51.054420999999998	0103000020E61000000100000005000000AEEFC341429A4240999B6F44F7864940AEEFC341429A42400531D0B52F8C4940E2CD1ABCAFA042400531D0B52F8C4940E2CD1ABCAFA04240999B6F44F7864940AEEFC341429A4240999B6F44F7864940
47512	Сапрыкино	1	1	522	37.619522000000003	37.655230000000003	51.134605000000001	51.122045	0103000020E610000001000000050000008693347F4CCF4240F6D1A92B9F8F49408693347F4CCF4240657094BC3A914940D6AD9E93DED34240657094BC3A914940D6AD9E93DED34240F6D1A92B9F8F49408693347F4CCF4240F6D1A92B9F8F4940
4003	Присынки	1	1	522	37.392985000000003	37.417464000000002	51.175443999999999	51.161715000000001	0103000020E61000000100000005000000C7681D554DB24240E622BE13B3944940C7681D554DB24240C423F1F274964940F1A0D9756FB54240C423F1F274964940F1A0D9756FB54240E622BE13B3944940C7681D554DB24240E622BE13B3944940
3905	Петровки	1	1	522	37.344152000000001	37.369925000000002	51.295985999999999	51.283588000000002	0103000020E610000001000000050000002F6D382C0DAC4240DFC4909C4CA449402F6D382C0DAC4240740987DEE2A54940857CD0B359AF4240740987DEE2A54940857CD0B359AF4240DFC4909C4CA449402F6D382C0DAC4240DFC4909C4CA44940
3452	Осколец	1	1	522	37.373958000000002	37.420059999999999	51.288302999999999	51.265642	0103000020E61000000100000005000000EE0912DBDDAF4240D6389B8E00A24940EE0912DBDDAF42405A2BDA1CE7A44940CB2DAD86C4B542405A2BDA1CE7A44940CB2DAD86C4B54240D6389B8E00A24940EE0912DBDDAF4240D6389B8E00A24940
54057	Новоселовка	1	1	522	37.100546999999999	37.172474999999999	51.224054000000002	51.126426000000002	0103000020E61000000100000005000000FF5A5EB9DE8C42409BAE27BA2E904940FF5A5EB9DE8C4240DD442DCDAD9C494055302AA913964240DD442DCDAD9C494055302AA9139642409BAE27BA2E904940FF5A5EB9DE8C42409BAE27BA2E904940
47652	Никаноровка	1	1	522	37.144969000000003	37.182400999999999	51.206592000000001	51.192256999999998	0103000020E6100000010000000500000088F71C588E924240AAB69BE09B98494088F71C588E924240C0CE4D9B719A4940FCE07CEA58974240C0CE4D9B719A4940FCE07CEA58974240AAB69BE09B98494088F71C588E924240AAB69BE09B984940
47686	Морозово	1	1	522	37.195059000000001	37.222143000000003	51.182327000000001	51.158302999999997	0103000020E610000001000000050000002EE57CB1F7984240E9EDCF45439449402EE57CB1F7984240C216BB7D5697494086048C2E6F9C4240C216BB7D5697494086048C2E6F9C4240E9EDCF45439449402EE57CB1F7984240E9EDCF4543944940
4567	Мелавое	1	1	522	37.371946000000001	37.434415000000001	51.137430999999999	51.112110999999999	0103000020E6100000010000000500000063F030ED9BAF4240CC423BA7598E494063F030ED9BAF4240713AC9569791494028F224E99AB74240713AC9569791494028F224E99AB74240CC423BA7598E494063F030ED9BAF4240CC423BA7598E4940
5196	Корочка	1	1	522	37.286327999999997	37.309801	51.035789999999999	50.996243999999997	0103000020E61000000100000005000000ECF65965A6A44240096B63EC847F4940ECF65965A6A442400DC347C49484494051A2258FA7A742400DC347C49484494051A2258FA7A74240096B63EC847F4940ECF65965A6A44240096B63EC847F4940
47944	Коньшино	1	1	522	37.433418000000003	37.518650000000001	51.052348000000002	51.033830000000002	0103000020E61000000100000005000000B6BFB33D7AB74240D5CF9B8A54844940B6BFB33D7AB742406901DA56B386494003098A1F63C242406901DA56B386494003098A1F63C24240D5CF9B8A54844940B6BFB33D7AB74240D5CF9B8A54844940
4366	Кладовое	1	1	522	37.325170999999997	37.363241000000002	51.236423000000002	51.219096	0103000020E61000000100000005000000C64D0D349FA942409B5775560B9C4940C64D0D349FA94240D882DE1B439E49407EC85BAE7EAE4240D882DE1B439E49407EC85BAE7EAE42409B5775560B9C4940C64D0D349FA942409B5775560B9C4940
54067	Калинин	1	1	522	37.215252999999997	37.236417000000003	51.146206999999997	51.130744999999997	0103000020E61000000100000005000000D5AE09698D9B4240C98E8D40BC904940D5AE09698D9B42401FB935E9B6924940F69B89E9429E42401FB935E9B6924940F69B89E9429E4240C98E8D40BC904940D5AE09698D9B4240C98E8D40BC904940
3175	Казацкая Степь	1	1	522	37.599533999999998	37.618766999999998	51.358530000000002	51.344518000000001	0103000020E61000000100000005000000876BB587BDCC42401171732A19AC4940876BB587BDCC42404451A04FE4AD4940096CCEC133CF42404451A04FE4AD4940096CCEC133CF42401171732A19AC4940876BB587BDCC42401171732A19AC4940
5346	Истобное	1	1	522	37.309027999999998	37.345238999999999	51.144297000000002	51.098159000000003	0103000020E610000001000000050000002EC6C03A8EA742406F675F79908C49402EC6C03A8EA7424099F4F75278924940E126A3CA30AC424099F4F75278924940E126A3CA30AC42406F675F79908C49402EC6C03A8EA742406F675F79908C4940
47424	Заповедный	1	1	522	37.572763999999999	37.594036000000003	51.215834999999998	51.200265999999999	0103000020E61000000100000005000000BF29AC5450C942401840F850A2994940BF29AC5450C94240842A357BA09B4940C652245F09CC4240842A357BA09B4940C652245F09CC42401840F850A2994940BF29AC5450C942401840F850A2994940
47397	Заломное	1	1	522	37.312693000000003	37.344206	51.275649999999999	51.263905999999999	0103000020E610000001000000050000001558005306A84240ED9BFBABC7A149401558005306A842403A92CB7F48A34940228B34F10EAC42403A92CB7F48A34940228B34F10EAC4240ED9BFBABC7A149401558005306A84240ED9BFBABC7A14940
48162	Долгое	1	1	522	37.301940000000002	37.322268999999999	51.318778000000002	51.300209000000002	0103000020E6100000010000000500000058AD4CF8A5A64240817B9E3F6DA6494058AD4CF8A5A642409757AEB7CDA84940DFC14F1C40A942409757AEB7CDA84940DFC14F1C40A94240817B9E3F6DA6494058AD4CF8A5A64240817B9E3F6DA64940
47287	Гущино	1	1	522	37.151778	37.248742	51.344963	51.316391000000003	0103000020E610000001000000050000004B2025766D934240D7DF12807FA849404B2025766D9342403FAA61BF27AC4940219221C7D69F42403FAA61BF27AC4940219221C7D69F4240D7DF12807FA849404B2025766D934240D7DF12807FA84940
47290	Вислая Дубрава	1	1	522	37.257510000000003	37.294673000000003	51.303013999999997	51.261184	0103000020E610000001000000050000004D327216F6A04240861E317A6EA149404D327216F6A04240751DAA29C9A64940D20149D8B7A54240751DAA29C9A64940D20149D8B7A54240861E317A6EA149404D327216F6A04240861E317A6EA14940
47561	Богородицкое	1	1	522	37.332303000000003	37.360906	51.165657000000003	51.154862000000001	0103000020E610000001000000050000006DAE9AE788AA424053B29C84D29349406DAE9AE788AA42403FADA23F349549401077F52A32AE42403FADA23F349549401077F52A32AE424053B29C84D29349406DAE9AE788AA424053B29C84D2934940
4257	Бобровы Дворы	1	1	522	37.365369999999999	37.401967999999997	51.195869999999999	51.181887000000003	0103000020E610000001000000050000004278B471C4AE4240A648BE12489749404278B471C4AE42403E22A64412994940EE04FBAF73B342403E22A64412994940EE04FBAF73B34240A648BE12489749404278B471C4AE4240A648BE1248974940
47264	Архангельское	1	1	522	37.145004999999998	37.185338999999999	51.295940000000002	51.241064000000001	0103000020E61000000100000005000000D4601A868F924240191F662FDB9E4940D4601A868F92424004CAA65CE1A5494030D63730B997424004CAA65CE1A5494030D63730B9974240191F662FDB9E4940D4601A868F924240191F662FDB9E4940
47166	Аверино	1	1	522	37.430973999999999	37.452767000000001	51.298085999999998	51.280794	0103000020E6100000010000000500000091B6F1272AB74240DE74CB0EF1A3494091B6F1272AB742409EB29AAE27A64940A1DAE044F4B942409EB29AAE27A64940A1DAE044F4B94240DE74CB0EF1A3494091B6F1272AB74240DE74CB0EF1A34940
54009	Лебеди	1	1	6958	37.581181999999998	37.618766999999998	51.309010000000001	51.286726000000002	0103000020E610000001000000050000000E83F92B64CA4240DA740470B3A449400E83F92B64CA42408811C2A38DA74940096CCEC133CF42408811C2A38DA74940096CCEC133CF4240DA740470B3A449400E83F92B64CA4240DA740470B3A44940
47186	Зареченка	1	1	6958	37.476582000000001	37.525844999999997	51.266544000000003	51.256189999999997	0103000020E610000001000000050000005FEE93A300BD4240F7C77BD5CAA049405FEE93A300BD4240F778211D1EA24940EFE192E34EC34240F778211D1EA24940EFE192E34EC34240F7C77BD5CAA049405FEE93A300BD4240F7C77BD5CAA04940
54051	Хотмыжск	1	1	59	35.823484000000001	35.833365000000001	50.518977999999997	50.513415999999999	0103000020E61000000100000005000000BF6378EC67E941401F9F909DB7414940BF6378EC67E94140F7AB00DF6D424940C6504EB4ABEA4140F7AB00DF6D424940C6504EB4ABEA41401F9F909DB7414940BF6378EC67E941401F9F909DB7414940
54048	Санково	1	1	59	35.573627000000002	35.608364000000002	50.604984999999999	50.589540999999997	0103000020E61000000100000005000000228D0A9C6CC9414058535914764B4940228D0A9C6CC9414008C90226704D494029081EDFDECD414008C90226704D494029081EDFDECD414058535914764B4940228D0A9C6CC9414058535914764B4940
48310	Подгорное	1	1	59	35.516852999999998	35.531792000000003	50.567112999999999	50.549505000000003	0103000020E6100000010000000500000074EB353D28C2414087FE092E5646494074EB353D28C241407711A628974849402123A0C211C441407711A628974849402123A0C211C4414087FE092E5646494074EB353D28C2414087FE092E56464940
54039	Новостроевка 1-я	1	1	59	35.702058999999998	35.773358000000002	50.475247000000003	50.428933000000001	0103000020E61000000100000005000000656EBE11DDD941406C96CB46E7364940656EBE11DDD94140D542C9E4D43C4940CC0C1B65FDE24140D542C9E4D43C4940CC0C1B65FDE241406C96CB46E7364940656EBE11DDD941406C96CB46E7364940
54053	Мощеное	1	1	59	35.528683999999998	35.552686999999999	50.571066999999999	50.549849000000002	0103000020E6100000010000000500000090F5D4EAABC34140815EB8736146494090F5D4EAABC34140946934B91849494051F69672BEC64140946934B91849494051F69672BEC64140815EB8736146494090F5D4EAABC34140815EB87361464940
54028	Мокрая Орловка	1	1	59	35.486930000000001	35.533723000000002	50.528295	50.508180000000003	0103000020E610000001000000050000007CB8E4B853BE41409B3DD00A0C4149407CB8E4B853BE4140F6D1A92B9F434940BF0F070951C44140F6D1A92B9F434940BF0F070951C441409B3DD00A0C4149407CB8E4B853BE41409B3DD00A0C414940
31688	Луговка	1	1	59	35.699139000000002	35.733015000000002	50.517803000000001	50.501643999999999	0103000020E61000000100000005000000D82D02637DD94140081EDFDE35404940D82D02637DD94140A662635E474249401D3D7E6FD3DD4140A662635E474249401D3D7E6FD3DD4140081EDFDE35404940D82D02637DD94140081EDFDE35404940
54063	Ломное	1	1	59	35.770564	35.798178	50.583101999999997	50.565626000000002	0103000020E61000000100000005000000CBBC55D7A1E2414037E2C96E66484940CBBC55D7A1E24140B81D1A16A34A49407F315BB22AE64140B81D1A16A34A49407F315BB22AE6414037E2C96E66484940CBBC55D7A1E2414037E2C96E66484940
54002	Косилово	1	1	59	35.613816999999997	35.655355	50.677428999999997	50.626784000000001	0103000020E610000001000000050000004A5D328E91CE4140FAD346753A5049404A5D328E91CE4140552E54FEB5564940922232ACE2D34140552E54FEB5564940922232ACE2D34140FAD346753A5049404A5D328E91CE4140FAD346753A504940
53982	Козинка	1	1	59	35.575333000000001	35.627957000000002	50.478096000000001	50.430655000000002	0103000020E61000000100000005000000A0A70183A4C94140F06DFAB31F374940A0A70183A4C94140992CEE3F323D4940AB251DE560D04140992CEE3F323D4940AB251DE560D04140F06DFAB31F374940A0A70183A4C94140F06DFAB31F374940
54033	Казачья Лисица	1	1	59	35.720258999999999	35.763503999999998	50.628628999999997	50.611975999999999	0103000020E6100000010000000500000028D3687231DC4140ECF7C43A554E494028D3687231DC4140992842EA76504940BE2EC37FBAE14140992842EA76504940BE2EC37FBAE14140ECF7C43A554E494028D3687231DC4140ECF7C43A554E4940
54014	Ивановская Лисица	1	1	59	35.676906000000002	35.727508	50.605001999999999	50.580441999999998	0103000020E61000000100000005000000AC3B16DBA4D64140C79C67EC4B4A4940AC3B16DBA4D64140DE019EB4704D494008CA6DFB1EDD4140DE019EB4704D494008CA6DFB1EDD4140C79C67EC4B4A4940AC3B16DBA4D64140C79C67EC4B4A4940
54050	Дунайка	1	1	59	35.523041999999997	35.554915000000001	50.554347	50.538715000000003	0103000020E610000001000000050000009B374E0AF3C24140AD6EF59CF44449409B374E0AF3C241405FD1ADD7F4464940A987687407C741405FD1ADD7F4464940A987687407C74140AD6EF59CF44449409B374E0AF3C24140AD6EF59CF4444940
54032	Дроновка	1	1	59	35.411481000000002	35.432699	50.641689	50.629303	0103000020E6100000010000000500000073F6CE68ABB4414029232E008D50494073F6CE68ABB44140FA997ADD2252494086014BAE62B74140FA997ADD2252494086014BAE62B7414029232E008D50494073F6CE68ABB4414029232E008D504940
54011	Дорогощь	1	1	59	35.553297999999998	35.589967000000001	50.600530999999997	50.569602000000003	0103000020E610000001000000050000009A780778D2C641403CDEE4B7E84849409A780778D2C64140F99D2633DE4C4940105CE50984CB4140F99D2633DE4C4940105CE50984CB41403CDEE4B7E84849409A780778D2C641403CDEE4B7E8484940
54020	Добро-Ивановка	1	1	59	35.724668999999999	35.745286	50.544725999999997	50.532147999999999	0103000020E6100000010000000500000067B62BF4C1DC4140DF50F86C1D44494067B62BF4C1DC4140F4A3E194B945494055151A8865DF4140F4A3E194B945494055151A8865DF4140DF50F86C1D44494067B62BF4C1DC4140DF50F86C1D444940
53964	Грайворон	1	1	59	35.653683999999998	35.708050999999998	50.492986000000002	50.468992	0103000020E6100000010000000500000090F5D4EAABD34140F60A0BEE073C494090F5D4EAABD3414064B14D2A1A3F49403673486AA1DA414064B14D2A1A3F49403673486AA1DA4140F60A0BEE073C494090F5D4EAABD34140F60A0BEE073C4940
54031	Горьковское сельское поселение	1	1	59	35.392525999999997	35.912399000000001	50.716597	50.351576000000001	0103000020E61000000100000005000000336ABE4A3EB241407D073F71002D4940336ABE4A3EB24140B3B45373B95B494099F38C7DC9F44140B3B45373B95B494099F38C7DC9F441407D073F71002D4940336ABE4A3EB241407D073F71002D4940
54037	Горьковский	1	1	59	35.846049999999998	35.856991000000001	50.455098	50.439404000000003	0103000020E61000000100000005000000F163CC5D4BEC4140A5DDE8633E384940F163CC5D4BEC4140CD3CB9A6403A4940B1FB8EE1B1ED4140CD3CB9A6403A4940B1FB8EE1B1ED4140A5DDE8633E384940F163CC5D4BEC4140A5DDE8633E384940
54013	Гора-Подольское сельское поселение	1	1	59	35.392525999999997	35.912399000000001	50.716597	50.351576000000001	0103000020E61000000100000005000000336ABE4A3EB241407D073F71002D4940336ABE4A3EB24140B3B45373B95B494099F38C7DC9F44140B3B45373B95B494099F38C7DC9F441407D073F71002D4940336ABE4A3EB241407D073F71002D4940
53985	Головчино	1	1	59	35.763890000000004	35.853084000000003	50.556939999999997	50.516188	0103000020E61000000100000005000000E8DEC325C7E14140384BC97212424940E8DEC325C7E14140C8EA56CF49474940D55E44DB31ED4140C8EA56CF49474940D55E44DB31ED4140384BC97212424940E8DEC325C7E14140384BC97212424940
54003	Безымено	1	1	59	35.666665000000002	35.740102	50.416916000000001	50.363230999999999	0103000020E61000000100000005000000A5315A4755D541405AF2785A7E2E4940A5315A4755D54140EE96E4805D35494023DA8EA9BBDE4140EE96E4805D35494023DA8EA9BBDE41405AF2785A7E2E4940A5315A4755D541405AF2785A7E2E4940
53991	Антоновка	1	1	59	35.752616000000003	35.771318999999998	50.560299000000001	50.542893999999997	0103000020E61000000100000005000000223999B855E04140E998F38C7D454940223999B855E04140A27DACE0B747494047E4BB94BAE24140A27DACE0B747494047E4BB94BAE24140E998F38C7D454940223999B855E04140E998F38C7D454940
31294	Ютановка	1	1	1875	37.781146999999997	37.812893000000003	50.501351	50.481512000000002	0103000020E610000001000000050000002B2FF99FFCE34240D7506A2FA23D49402B2FF99FFCE34240906802452C404940DC12B9E00CE84240906802452C404940DC12B9E00CE84240D7506A2FA23D49402B2FF99FFCE34240D7506A2FA23D4940
31221	Шидловка	1	1	1875	37.620275999999997	37.638610999999997	50.529646	50.519046000000003	0103000020E61000000100000005000000313F373465CF4240508F6D1970424940313F373465CF4240863AAC70CB434940D4EE5701BED14240863AAC70CB434940D4EE5701BED14240508F6D1970424940313F373465CF4240508F6D1970424940
30799	Шеншиновка	1	1	1875	38.029603000000002	38.095376999999999	50.578532000000003	50.564556000000003	0103000020E61000000100000005000000876EF607CA0343405B61FA5E43484940876EF607CA03434041D829560D4A494032E54350350C434041D829560D4A494032E54350350C43405B61FA5E43484940876EF607CA0343405B61FA5E43484940
45410	Шаховка	1	1	1875	37.522441000000001	37.553944999999999	50.41357	50.400440000000003	0103000020E61000000100000005000000768BC058DFC242405001309E41334940768BC058DFC24240A94D9CDCEF344940306475ABE7C64240A94D9CDCEF344940306475ABE7C642405001309E41334940768BC058DFC242405001309E41334940
31322	Чапельное	1	1	1875	37.694118000000003	37.720087999999997	50.521090999999998	50.511572000000001	0103000020E6100000010000000500000050C8CEDBD8D8424050C6F8307B41494050C8CEDBD8D84240B69E211CB3424940FB1EF5D72BDC4240B69E211CB3424940FB1EF5D72BDC424050C6F8307B41494050C8CEDBD8D8424050C6F8307B414940
31132	Фощеватово	1	1	1875	38.037534999999998	38.102266999999998	50.451037999999997	50.406004000000003	0103000020E6100000010000000500000049BA66F2CD044340C90567F0F733494049BA66F2CD0443406AA0F99CBB394940E23AC615170D43406AA0F99CBB394940E23AC615170D4340C90567F0F733494049BA66F2CD044340C90567F0F7334940
45392	Тишанка	1	1	1875	37.490946000000001	37.531154000000001	50.406199000000001	50.383538999999999	0103000020E610000001000000050000000F0D8B51D7BE4240CADE52CE173149400F0D8B51D7BE42407E552E54FE334940DE91B1DAFCC342407E552E54FE334940DE91B1DAFCC34240CADE52CE173149400F0D8B51D7BE4240CADE52CE17314940
49582	Староивановка	1	1	1875	37.803820000000002	37.848844	50.595402999999997	50.558610999999999	0103000020E6100000010000000500000074EFE192E3E64240CA17B4908047494074EFE192E3E642405B785E2A364C4940F2B391EBA6EC42405B785E2A364C4940F2B391EBA6EC4240CA17B4908047494074EFE192E3E64240CA17B49080474940
49552	Репьевка	1	1	1875	37.968139999999998	38.012749999999997	50.582559000000003	50.567771	0103000020E6100000010000000500000087F9F202ECFB4240014F5AB8AC48494087F9F202ECFB4240C87E164B914A49401283C0CAA1014340C87E164B914A49401283C0CAA1014340014F5AB8AC48494087F9F202ECFB4240014F5AB8AC484940
49527	Пятницкое	1	1	1875	37.815049000000002	37.847639999999998	50.440792999999999	50.411911000000003	0103000020E610000001000000050000009AD18F8653E842406CEEE87FB93449409AD18F8653E8424022A7AFE76B3849400664AF777FEC424022A7AFE76B3849400664AF777FEC42406CEEE87FB93449409AD18F8653E842406CEEE87FB9344940
30214	Осколище	1	1	1875	37.812658999999996	37.830868000000002	50.406531999999999	50.386181000000001	0103000020E6100000010000000500000068E6C93505E8424015AB06616E31494068E6C93505E842408463963D093449407FA5F3E159EA42408463963D093449407FA5F3E159EA424015AB06616E31494068E6C93505E8424015AB06616E314940
30901	Новорождественка	1	1	1875	37.806865000000002	37.831316999999999	50.559714999999997	50.536310999999998	0103000020E61000000100000005000000BEA4315A47E7424016BEBED6A5444940BEA4315A47E74240520ABABDA4474940EECD6F9868EA4240520ABABDA4474940EECD6F9868EA424016BEBED6A5444940BEA4315A47E7424016BEBED6A5444940
31505	Нижние Лубянки	1	1	1875	37.813881000000002	37.837299999999999	50.472121999999999	50.452356999999999	0103000020E61000000100000005000000FBEAAA402DE84240EF8E8CD5E6394940FBEAAA402DE842406EDC627E6E3C49406C787AA52CEB42406EDC627E6E3C49406C787AA52CEB4240EF8E8CD5E6394940FBEAAA402DE84240EF8E8CD5E6394940
30523	Лазурное	1	1	1875	38.059454000000002	38.094954999999999	50.497897000000002	50.489628000000003	0103000020E61000000100000005000000E6CE4C309C0743405B9A5B21AC3E4940E6CE4C309C07434065E3C116BB3F4940BCCB457C270C434065E3C116BB3F4940BCCB457C270C43405B9A5B21AC3E4940E6CE4C309C0743405B9A5B21AC3E4940
45344	Коровино	1	1	1875	37.771192999999997	37.799885000000003	50.595402999999997	50.571249999999999	0103000020E61000000100000005000000BAF3C473B6E2424085EB51B81E494940BAF3C473B6E242405B785E2A364C4940CEC7B5A162E642405B785E2A364C4940CEC7B5A162E6424085EB51B81E494940BAF3C473B6E2424085EB51B81E494940
49463	Коновалово	1	1	1875	37.683230000000002	37.707960999999997	50.310260999999997	50.299439	0103000020E61000000100000005000000B3D2A41474D74240CF12640454264940B3D2A41474D74240B41CE8A1B6274940F6EB4E779EDA4240B41CE8A1B6274940F6EB4E779EDA4240CF12640454264940B3D2A41474D74240CF12640454264940
30381	Давыдкин	1	1	1875	37.703378999999998	37.727257000000002	50.357495999999998	50.349944000000001	0103000020E61000000100000005000000BAD8B45208DA424039B709F7CA2C4940BAD8B45208DA4240B439CE6DC22D4940BF64E3C116DD4240B439CE6DC22D4940BF64E3C116DD424039B709F7CA2C4940BAD8B45208DA424039B709F7CA2C4940
49395	Грушевка	1	1	1875	37.677975000000004	37.704403999999997	50.422964999999998	50.402455000000003	0103000020E61000000100000005000000B84082E2C7D642404C8E3BA583334940B84082E2C7D64240232D95B723364940F69507E929DA4240232D95B723364940F69507E929DA42404C8E3BA583334940B84082E2C7D642404C8E3BA583334940
30000	Волчья Александровка	1	1	1875	37.555382000000002	37.607008	50.508099999999999	50.454369999999997	0103000020E61000000100000005000000BF64E3C116C742404A24D1CB283A4940BF64E3C116C742407E8CB96B0941494087342A70B2CD42407E8CB96B0941494087342A70B2CD42404A24D1CB283A4940BF64E3C116C742404A24D1CB283A4940
29645	Волоконовка	1	1	1875	37.790461999999998	37.876241999999998	50.506720000000001	50.462179999999996	0103000020E61000000100000005000000895DDBDB2DE54240C16ED8B6283B4940895DDBDB2DE54240541D7233DC404940D9B0A6B228F04240541D7233DC404940D9B0A6B228F04240C16ED8B6283B4940895DDBDB2DE54240C16ED8B6283B4940
46891	Владимировка	1	1	1875	37.890211000000001	37.901144000000002	50.355415000000001	50.344282	0103000020E610000001000000050000000DC51D6FF2F14240FD4CBD6E112C49400DC51D6FF2F1424001C11C3D7E2D49404A7EC4AF58F3424001C11C3D7E2D49404A7EC4AF58F34240FD4CBD6E112C49400DC51D6FF2F14240FD4CBD6E112C4940
30134	Ветчининово	1	1	1875	37.852626000000001	37.871454	50.370080000000002	50.352995999999997	0103000020E6100000010000000500000012DC48D922ED424035CF11F92E2D494012DC48D922ED4240AC730CC85E2F4940F4FBFECD8BEF4240AC730CC85E2F4940F4FBFECD8BEF424035CF11F92E2D494012DC48D922ED424035CF11F92E2D4940
31422	Верхние Лубянки	1	1	1875	37.722585000000002	37.748223000000003	50.461733000000002	50.440505999999999	0103000020E6100000010000000500000043CA4FAA7DDC42408CD827806238494043CA4FAA7DDC4240F33D23111A3B4940B98E71C5C5DF4240F33D23111A3B4940B98E71C5C5DF42408CD827806238494043CA4FAA7DDC42408CD8278062384940
31002	Афоньевка	1	1	1875	37.773663999999997	37.803739	50.578149000000003	50.548428999999999	0103000020E61000000100000005000000D80B056C07E34240C896E5EB32464940D80B056C07E34240899B53C9004A494087C267EBE0E64240899B53C9004A494087C267EBE0E64240C896E5EB32464940D80B056C07E34240C896E5EB32464940
49212	Солонцы	1	1	1836	38.534931999999998	38.567279999999997	49.998762999999997	49.990673000000001	0103000020E61000000100000005000000BCCADAA678444340DE03745FCEFE4840BCCADAA67844434038BA4A77D7FF484062D68BA19C48434038BA4A77D7FF484062D68BA19C484340DE03745FCEFE4840BCCADAA678444340DE03745FCEFE4840
28771	Ромахово	1	1	1836	38.519939000000001	38.557335999999999	50.374279000000001	50.366362000000002	0103000020E610000001000000050000001D75745C8D424340A33F34F3E42E49401D75745C8D424340304AD05FE82F494015713AC956474340304AD05FE82F494015713AC956474340A33F34F3E42E49401D75745C8D424340A33F34F3E42E4940
29467	Ровны	1	1	1836	38.826740999999998	38.848650999999997	50.155566999999998	50.138075999999998	0103000020E6100000010000000500000094A12AA6D2694340662E7079AC11494094A12AA6D26943401DAB949EE9134940DD5B9198A06C43401DAB949EE9134940DD5B9198A06C4340662E7079AC11494094A12AA6D2694340662E7079AC114940
54040	Попов	1	1	1836	38.516714	38.532623000000001	50.041303999999997	50.026567	0103000020E6100000010000000500000053B131AF234243409013268C6603494053B131AF23424340D498107349054940780C8FFD2C444340D498107349054940780C8FFD2C4443409013268C6603494053B131AF234243409013268C66034940
29436	Попасный	1	1	1836	38.747833	38.772545000000001	50.201376000000003	50.186104999999998	0103000020E610000001000000050000004EEFE2FDB85F4340A04FE449D21749404EEFE2FDB85F4340831953B0C61949401BD82AC1E2624340831953B0C61949401BD82AC1E2624340A04FE449D21749404EEFE2FDB85F4340A04FE449D2174940
48886	Опытный	1	1	1836	38.467827999999997	38.478724	50.104599999999998	50.100104999999999	0103000020E610000001000000050000009813B4C9E13B434042959A3DD00C49409813B4C9E13B4340AF946588630D4940B8E7F9D3463D4340AF946588630D4940B8E7F9D3463D434042959A3DD00C49409813B4C9E13B434042959A3DD00C4940
28562	Олейники	1	1	1836	38.573155	38.591884999999998	50.084605000000003	50.074182999999998	0103000020E61000000100000005000000FA449E245D494340A7751BD47E094940FA449E245D494340FF092E56D40A494019FF3EE3C24B4340FF092E56D40A494019FF3EE3C24B4340A7751BD47E094940FA449E245D494340A7751BD47E094940
29371	Ногин	1	1	1836	38.706322	38.728760999999999	50.245344000000003	50.235112000000001	0103000020E61000000100000005000000003961C2685A4340D6726726181E4940003961C2685A43408A22A46E671F4940D5CC5A0A485D43408A22A46E671F4940D5CC5A0A485D4340D6726726181E4940003961C2685A4340D6726726181E4940
29221	Малакеево	1	1	1836	38.652512000000002	38.685623999999997	50.325617999999999	50.309795000000001	0103000020E61000000100000005000000B01F6283855343406FBBD05CA7274940B01F628385534340957EC2D9AD29494025ADF886C2574340957EC2D9AD29494025ADF886C25743406FBBD05CA7274940B01F6283855343406FBBD05CA7274940
29100	Кубраки	1	1	1836	38.700698000000003	38.730620999999999	50.175052999999998	50.154544999999999	0103000020E61000000100000005000000B22FD978B059434052616C21C8134940B22FD978B05943408908FF2268164940AA622AFD845D43408908FF2268164940AA622AFD845D434052616C21C8134940B22FD978B059434052616C21C8134940
49045	Клименки	1	1	1836	38.332712000000001	38.403131000000002	50.06326	50.041449	0103000020E610000001000000050000004E7E8B4E962A4340D8B969334E0549404E7E8B4E962A43408E9257E7180849407C80EECB993343408E9257E7180849407C80EECB99334340D8B969334E0549404E7E8B4E962A4340D8B969334E054940
49003	Зенино	1	1	1836	38.286602000000002	38.312975999999999	50.182985000000002	50.162151000000001	0103000020E61000000100000005000000EE7BD45FAF244340C1012D5DC1144940EE7BD45FAF2443404C546F0D6C1749406937FA980F2843404C546F0D6C1749406937FA980F284340C1012D5DC1144940EE7BD45FAF244340C1012D5DC1144940
28867	Закутское	1	1	1836	38.620514	38.638517	50.165838999999998	50.153962	0103000020E61000000100000005000000E65AB4006D4F4340D369DD06B5134940E65AB4006D4F43405FB35C363A1549405378D0ECBA5143405FB35C363A1549405378D0ECBA514340D369DD06B5134940E65AB4006D4F4340D369DD06B5134940
42949	Дегтярное	1	1	1836	38.662717000000001	38.684843000000001	50.285518000000003	50.266451000000004	0103000020E610000001000000050000006AC020E9D3544340467EFD101B2249406AC020E9D3544340AD3594DA8B24494080F277EFA8574340AD3594DA8B24494080F277EFA8574340467EFD101B2249406AC020E9D3544340467EFD101B224940
28542	Викторополь	1	1	1836	38.463354000000002	38.492711	50.088419999999999	50.073673999999997	0103000020E61000000100000005000000433C122F4F3B434062484E266E094940433C122F4F3B4340FA27B858510B494092B06F27113F4340FA27B858510B494092B06F27113F434062484E266E094940433C122F4F3B434062484E266E094940
28182	Вейделевка	1	1	1836	38.372427000000002	38.489342000000001	50.170938999999997	50.124136	0103000020E61000000100000005000000DE921CB0AB2F4340CD203EB0E30F4940DE921CB0AB2F4340334E4354E1154940954737C2A23E4340334E4354E1154940954737C2A23E4340CD203EB0E30F4940DE921CB0AB2F4340CD203EB0E30F4940
28923	Брянские Липяги	1	1	1836	38.356949	38.384383	50.167287000000002	50.14696	0103000020E6100000010000000500000082AB3C81B02D4340FBE8D495CF12494082AB3C81B02D4340E20511A969154940B6114F7633314340E20511A969154940B6114F7633314340FBE8D495CF12494082AB3C81B02D4340FBE8D495CF124940
28118	Большие Липяги	1	1	1836	38.405844000000002	38.443376000000001	50.210301000000001	50.189791	0103000020E6100000010000000500000090A339B2F23343409E094D124B18494090A339B2F233434076A8A624EB1A494068EA758BC038434076A8A624EB1A494068EA758BC03843409E094D124B18494090A339B2F23343409E094D124B184940
28811	Белый Плес	1	1	1836	38.554029999999997	38.636091	50.211545999999998	50.194958	0103000020E610000001000000050000005E807D74EA464340FA0B3D62F41849405E807D74EA464340C0CC77F0131B4940D5230D6E6B514340C0CC77F0131B4940D5230D6E6B514340FA0B3D62F41849405E807D74EA464340FA0B3D62F4184940
29135	Банкино	1	1	1836	38.7301	38.747715999999997	50.119250000000001	50.109470999999999	0103000020E61000000100000005000000A167B3EA735D4340226E4E25030E4940A167B3EA735D434025068195430F494014596B28B55F434025068195430F494014596B28B55F4340226E4E25030E4940A167B3EA735D4340226E4E25030E4940
48458	Шушпаново	1	1	1112	38.171680000000002	38.187356000000001	50.299433000000001	50.281961000000003	0103000020E610000001000000050000004BB0389CF9154340ADDF4C4C172449404BB0389CF9154340ED2B0FD253264940CD5A0A48FB174340ED2B0FD253264940CD5A0A48FB174340ADDF4C4C172449404BB0389CF9154340ADDF4C4C17244940
48563	Шелаево	1	1	1112	38.051071999999998	38.098835999999999	50.134743999999998	50.108384000000001	0103000020E61000000100000005000000E3DEFC868906434070B4E386DF0D4940E3DEFC868906434086AA984A3F1149406FD575A8A60C434086AA984A3F1149406FD575A8A60C434070B4E386DF0D4940E3DEFC868906434070B4E386DF0D4940
48644	Храпово	1	1	1112	38.032961999999998	38.057198999999997	50.159663999999999	50.145581	0103000020E6100000010000000500000060014C1938044340A1F5F065A212494060014C19380443409D2CB5DE6F144940942EFD4B520743409D2CB5DE6F144940942EFD4B52074340A1F5F065A212494060014C1938044340A1F5F065A2124940
48381	Хохлово	1	1	1112	37.951557000000001	37.966729999999998	50.281120000000001	50.271771000000001	0103000020E61000000100000005000000D3A3A99ECCF9424028806264C9224940D3A3A99ECCF9424032207BBDFB234940F20703CFBDFB424032207BBDFB234940F20703CFBDFB424028806264C9224940D3A3A99ECCF9424028806264C9224940
27737	Хмелевец	1	1	1112	38.027392999999996	38.056220000000003	50.393738999999997	50.365834	0103000020E61000000100000005000000D591239D81034340E7E104A6D32E4940D591239D810343407214200A66324940C9B08A37320743407214200A66324940C9B08A3732074340E7E104A6D32E4940D591239D81034340E7E104A6D32E4940
48470	Филиппово	1	1	1112	38.127321000000002	38.146788000000001	50.356690999999998	50.34442	0103000020E61000000100000005000000098CF50D4C1043404E0B5EF4152C4940098CF50D4C10434086E3F90CA82D4940FEB8FDF2C912434086E3F90CA82D4940FEB8FDF2C91243404E0B5EF4152C4940098CF50D4C1043404E0B5EF4152C4940
53979	Уразово	1	1	1112	38.024455000000003	38.060845999999998	50.104646000000002	50.065266999999999	0103000020E61000000100000005000000A29C685721034340074147AB5A084940A29C68572103434020D4450A650D4940D40B3ECDC907434020D4450A650D4940D40B3ECDC9074340074147AB5A084940A29C685721034340074147AB5A084940
27860	Ураево	1	1	1112	38.185702999999997	38.259239000000001	50.118983999999998	50.094217	0103000020E6100000010000000500000071E2AB1DC517434016DD7A4D0F0C494071E2AB1DC5174340A65F22DE3A0F4940836C59BE2E214340A65F22DE3A0F4940836C59BE2E21434016DD7A4D0F0C494071E2AB1DC517434016DD7A4D0F0C4940
48349	Углово	1	1	1112	37.986555000000003	38.006596999999999	50.325387999999997	50.315524000000003	0103000020E61000000100000005000000475A2A6F47FE4240338D261763284940475A2A6F47FE424063416150A629494038A0A52BD800434063416150A629494038A0A52BD8004340338D261763284940475A2A6F47FE4240338D261763284940
26929	Тулянка	1	1	1112	37.918706	37.943418000000001	50.250141999999997	50.236246999999999	0103000020E61000000100000005000000CA51802898F54240996379573D1E4940CA51802898F5424092AD2EA704204940973AC8EBC1F8424092AD2EA704204940973AC8EBC1F84240996379573D1E4940CA51802898F54240996379573D1E4940
48495	Тимоново	1	1	1112	38.038297999999998	38.065688000000002	50.336238999999999	50.316025000000003	0103000020E6100000010000000500000048C0E8F2E6044340F5DBD7817328494048C0E8F2E6044340E3512AE1092B4940ADDEE17668084340E3512AE1092B4940ADDEE17668084340F5DBD7817328494048C0E8F2E6044340F5DBD78173284940
47881	Сухарево	1	1	1112	37.956543000000003	37.995116000000003	50.145564	50.134841999999999	0103000020E61000000100000005000000DF1B430070FA42404910AE8042114940DF1B430070FA4240CBBC55D7A1124940F9DC09F65FFF4240CBBC55D7A1124940F9DC09F65FFF42404910AE8042114940DF1B430070FA42404910AE8042114940
54066	Старый Хутор	1	1	1112	37.642679999999999	37.671669000000001	50.247560999999997	50.218421999999997	0103000020E610000001000000050000008AE5965643D242400B5D8940F51B49408AE5965643D24240ED612F14B01F4940575EF23FF9D54240ED612F14B01F4940575EF23FF9D542400B5D8940F51B49408AE5965643D242400B5D8940F51B4940
48531	Солоти	1	1	1112	38.037005000000001	38.061689999999999	50.294674000000001	50.271845999999996	0103000020E61000000100000005000000ED647094BC04434032C687D9CB224940ED647094BC044340A27DACE0B7254940C03E3A75E5074340A27DACE0B7254940C03E3A75E507434032C687D9CB224940ED647094BC04434032C687D9CB224940
47782	Соболевка	1	1	1112	38.053282000000003	38.088290000000001	50.094442000000001	50.054614999999998	0103000020E6100000010000000500000095BBCFF1D10643407E6FD39FFD06494095BBCFF1D106434036AFEAAC160C49402C4833164D0B434036AFEAAC160C49402C4833164D0B43407E6FD39FFD06494095BBCFF1D10643407E6FD39FFD064940
48435	Селиваново	1	1	1112	38.138621999999998	38.162661	50.322892000000003	50.286766999999998	0103000020E61000000100000005000000C8409E5DBE1143403849F3C7B4244940C8409E5DBE114340ED116A8654294940D6AA5D13D2144340ED116A8654294940D6AA5D13D21443403849F3C7B4244940C8409E5DBE1143403849F3C7B4244940
52945	Рябики	1	1	1112	37.768849000000003	37.786465	50.196646999999999	50.189	0103000020E61000000100000005000000FA47DFA469E24240D578E92631184940FA47DFA469E24240A2ED98BA2B1949406D3997E2AAE44240A2ED98BA2B1949406D3997E2AAE44240D578E92631184940FA47DFA469E24240D578E92631184940
48297	Рощино	1	1	1112	38.315941000000002	38.336942999999998	50.205146999999997	50.199046000000003	0103000020E61000000100000005000000973B33C1702843402733DE567A194940973B33C170284340AEEFC341421A4940DDCEBEF2202B4340AEEFC341421A4940DDCEBEF2202B43402733DE567A194940973B33C1702843402733DE567A194940
48382	Рождествено	1	1	1112	38.165391999999997	38.199573000000001	50.244059	50.213603999999997	0103000020E610000001000000050000009082A7902B154340BB253960571B49409082A7902B154340B1A547533D1F49401215AA9B8B194340B1A547533D1F49401215AA9B8B194340BB253960571B49409082A7902B154340BB253960571B4940
48424	Ровное	1	1	1112	38.256131000000003	38.269874999999999	50.174666000000002	50.167293000000001	0103000020E61000000100000005000000F33E8EE6C8204340C4EC65DB69154940F33E8EE6C820434090DC9A745B164940068195438B22434090DC9A745B164940068195438B224340C4EC65DB69154940F33E8EE6C8204340C4EC65DB69154940
27158	Принцевка	1	1	1112	37.897748	37.945079999999997	50.316847000000003	50.295364999999997	0103000020E6100000010000000500000053060E68E9F2424007B13385CE25494053060E68E9F24240F96A47718E284940450DA661F8F84240F96A47718E284940450DA661F8F8424007B13385CE25494053060E68E9F2424007B13385CE254940
48233	Посохово	1	1	1112	37.880203999999999	37.906821000000001	50.266043000000003	50.250937	0103000020E6100000010000000500000079E75086AAF042409D2D20B41E20494079E75086AAF04240352A70B20D224940BB29E5B512F44240352A70B20D224940BB29E5B512F442409D2D20B41E20494079E75086AAF042409D2D20B41E204940
40306	Песчанка	1	1	1112	37.896616000000002	37.913378999999999	50.069302999999998	50.061594999999997	0103000020E6100000010000000500000001892650C4F242406E4C4F58E207494001892650C4F24240E141B3EBDE08494035ED629AE9F44240E141B3EBDE08494035ED629AE9F442406E4C4F58E207494001892650C4F242406E4C4F58E2074940
48635	Орехово	1	1	1112	37.970556000000002	37.989618999999998	50.212167999999998	50.195079	0103000020E61000000100000005000000E277D32D3BFC424075914259F8184940E277D32D3BFC4240FDA02E52281B49400740DCD5ABFE4240FDA02E52281B49400740DCD5ABFE424075914259F8184940E277D32D3BFC424075914259F8184940
47905	Новопетровка	1	1	1112	37.717329999999997	37.784137999999999	50.141153000000003	50.123305000000002	0103000020E6100000010000000500000047382D78D1DB424076374F75C80F494047382D78D1DB4240BC5D2F4D1112494082C64CA25EE44240BC5D2F4D1112494082C64CA25EE4424076374F75C80F494047382D78D1DB424076374F75C80F4940
27356	Новоказацкое	1	1	1112	38.134059000000001	38.153390000000002	50.214826000000002	50.207810000000002	0103000020E61000000100000005000000035E66D82811434011E4A084991A4940035E66D8281143404E2A1A6B7F1B494048C49448A21343404E2A1A6B7F1B494048C49448A213434011E4A084991A4940035E66D82811434011E4A084991A4940
48276	Насоново	1	1	1112	38.197102000000001	38.246447000000003	50.265903999999999	50.243068000000001	0103000020E61000000100000005000000F4FC69A33A194340215A2BDA1C1F4940F4FC69A33A19434013F06B2409224940429946938B1F434013F06B2409224940429946938B1F4340215A2BDA1C1F4940F4FC69A33A194340215A2BDA1C1F4940
27015	Мандрово	1	1	1112	38.242916999999998	38.270423000000001	50.308213000000002	50.284331999999999	0103000020E610000001000000050000003B527DE7171F4340679AB0FD642449403B527DE7171F4340DD99098673274940098B8A389D224340DD99098673274940098B8A389D224340679AB0FD642449403B527DE7171F4340679AB0FD64244940
47976	Логачевка	1	1	1112	37.943022999999997	37.983015999999999	50.020668999999998	49.999955999999997	0103000020E610000001000000050000001A3048FAB4F8424030B8E68EFEFF48401A3048FAB4F8424040852348A5024940EDB8E177D3FD424040852348A5024940EDB8E177D3FD424030B8E68EFEFF48401A3048FAB4F8424030B8E68EFEFF4840
48201	Лавы	1	1	1112	37.958509999999997	37.976745999999999	50.241173000000003	50.231464000000003	0103000020E61000000100000005000000C971A774B0FA4240C619C39CA01D4940C971A774B0FA4240D0D6C1C1DE1E4940D93F4F0306FD4240D0D6C1C1DE1E4940D93F4F0306FD4240C619C39CA01D4940C971A774B0FA4240C619C39CA01D4940
48141	Кукуевка	1	1	1112	37.904862999999999	37.941567999999997	50.108142000000001	50.095123999999998	0103000020E61000000100000005000000232E008DD2F342404888F2052D0C4940232E008DD2F342407AA9D898D70D4940E57ADB4C85F842407AA9D898D70D4940E57ADB4C85F842404888F2052D0C4940232E008DD2F342404888F2052D0C4940
48083	Конопляновка	1	1	1112	37.853695000000002	37.877015	50.325640999999997	50.312372000000003	0103000020E610000001000000050000001EE1B4E045ED4240D31742CEFB2749401EE1B4E045ED42404D9EB29AAE294940FC8C0B0742F042404D9EB29AAE294940FC8C0B0742F04240D31742CEFB2749401EE1B4E045ED4240D31742CEFB274940
27833	Колыхалино	1	1	1112	38.080295	38.098700999999998	50.152450000000002	50.133167999999998	0103000020E610000001000000050000002384471B470A4340D66F26A60B1149402384471B470A43403A234A7B831349408F8AFF3BA20C43403A234A7B831349408F8AFF3BA20C4340D66F26A60B1149402384471B470A4340D66F26A60B114940
48172	Колосково	1	1	1112	37.987535000000001	38.017215	50.250954	50.237324000000001	0103000020E61000000100000005000000E353008C67FE4240284701A2601E4940E353008C67FE42407366BB421F2049401500E319340243407366BB421F2049401500E31934024340284701A2601E4940E353008C67FE4240284701A2601E4940
47926	Карабаново	1	1	1112	37.810431999999999	37.838952999999997	50.138047	50.127451000000001	0103000020E61000000100000005000000E1D05B3CBCE74240D76B7A5050104940E1D05B3CBCE74240CC272B86AB114940C7F0D8CF62EB4240CC272B86AB114940C7F0D8CF62EB4240D76B7A5050104940E1D05B3CBCE74240D76B7A5050104940
48026	Казначеевка	1	1	1112	37.745905999999998	37.771408999999998	50.264108	50.253661000000001	0103000020E61000000100000005000000F1F109D979DF4240A5A2B1F677204940F1F109D979DF4240554E7B4ACE214940876BB587BDE24240554E7B4ACE214940876BB587BDE24240A5A2B1F677204940F1F109D979DF4240A5A2B1F677204940
48006	Казинка	1	1	1112	37.808383999999997	37.850918999999998	50.253166	50.224150999999999	0103000020E61000000100000005000000094E7D2079E74240CF2EDFFAB01C4940094E7D2079E74240C53A55BE67204940C345EEE9EAEC4240C53A55BE67204940C345EEE9EAEC4240CF2EDFFAB01C4940094E7D2079E74240CF2EDFFAB01C4940
47776	Знаменка	1	1	1112	38.012939000000003	38.034103000000002	50.121116000000001	50.105761000000001	0103000020E61000000100000005000000E6EB32FCA70143409C189293890D4940E6EB32FCA7014340DC82A5BA800F494006D9B27C5D044340DC82A5BA800F494006D9B27C5D0443409C189293890D4940E6EB32FCA70143409C189293890D4940
47361	Долгое	1	1	1112	37.895412	37.920844000000002	50.100261000000003	50.079779000000002	0103000020E61000000100000005000000153944DC9CF242402CF4C132360A4940153944DC9CF242403A083A5AD50C4940E25B5837DEF542403A083A5AD50C4940E25B5837DEF542402CF4C132360A4940153944DC9CF242402CF4C132360A4940
26274	Двулучное	1	1	1112	37.988208	38.046832000000002	50.071350000000002	50.019407999999999	0103000020E61000000100000005000000A2D288997DFE4240F0A31AF67B024940A2D288997DFE4240E9482EFF2109494001344A97FE054340E9482EFF2109494001344A97FE054340F0A31AF67B024940A2D288997DFE4240F0A31AF67B024940
48005	Дальний	1	1	1112	38.091793000000003	38.115589	49.956009999999999	49.938938999999998	0103000020E6100000010000000500000039807EDFBF0B43402FF834272FF8484039807EDFBF0B4340115322895EFA48408063CF9ECB0E4340115322895EFA48408063CF9ECB0E43402FF834272FF8484039807EDFBF0B43402FF834272FF84840
47952	Герасимовка	1	1	1112	38.118921999999998	38.163891999999997	50.053168999999997	50.030397999999998	0103000020E6100000010000000500000030630AD6380F434091EEE714E403494030630AD6380F43409C14E63DCE064940BB09BE69FA1443409C14E63DCE064940BB09BE69FA14434091EEE714E403494030630AD6380F434091EEE714E4034940
24814	Валуйки	1	1	1112	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
47853	Бутырки	1	1	1112	37.643076000000001	37.657871	50.185989999999997	50.169190999999998	0103000020E61000000100000005000000D76B7A5050D2424086E3F90CA8154940D76B7A5050D2424007B13385CE17494050FEEE1D35D4424007B13385CE17494050FEEE1D35D4424086E3F90CA8154940D76B7A5050D2424086E3F90CA8154940
47869	Борки	1	1	1112	37.875829000000003	37.898988000000003	50.161470000000001	50.137377000000001	0103000020E61000000100000005000000B7F1272A1BF042407E1CCD9195114940B7F1272A1BF042407FA4880CAB1449408CBFED0912F342407FA4880CAB1449408CBFED0912F342407E1CCD9195114940B7F1272A1BF042407E1CCD9195114940
9972	Бирюч	1	1	1112	37.709704000000002	37.731003000000001	50.261285999999998	50.250683000000002	0103000020E6100000010000000500000092EBA694D7DA4240E3546B611620494092EBA694D7DA42408A73D4D17121494092239D8191DD42408A73D4D17121494092239D8191DD4240E3546B611620494092EBA694D7DA4240E3546B6116204940
48500	Басово	1	1	1112	38.036653999999999	38.054611999999999	50.352381000000001	50.339976	0103000020E6100000010000000500000040A20914B104434063B66455842B494040A20914B1044340AB5D13D21A2D49400DFCA886FD064340AB5D13D21A2D49400DFCA886FD06434063B66455842B494040A20914B104434063B66455842B4940
48116	Аркатово	1	1	1112	37.854359000000002	37.868077	50.297465000000003	50.283596000000003	0103000020E610000001000000050000008A05BEA25BED424062A3ACDF4C2449408A05BEA25BED4240325A47551326494074B4AA251DEF4240325A47551326494074B4AA251DEF424062A3ACDF4C2449408A05BEA25BED424062A3ACDF4C244940
24411	Чуланово	1	1	1727	35.989618	36.028426000000003	50.690407	50.675414000000004	0103000020E6100000010000000500000037C478CDABFE41405AA148F77356494037C478CDABFE4140F9F6AE415F584940952D9276A3034240F9F6AE415F584940952D9276A30342405AA148F77356494037C478CDABFE41405AA148F773564940
24730	Хотмыжск	1	1	1727	35.838180000000001	35.918418000000003	50.610118	50.571055000000001	0103000020E61000000100000005000000A514747B49EB4140D09B8A5418494940A514747B49EB4140B859BC58184E4940640795B88EF54140B859BC58184E4940640795B88EF54140D09B8A5418494940A514747B49EB4140D09B8A5418494940
24595	Стригуны 1-е	1	1	1727	36.067169999999997	36.124420000000001	50.636851	50.611519000000001	0103000020E61000000100000005000000DBA2CC0699084240FAF02C41464E4940DBA2CC069908424063B6645584514940F27B9BFEEC0F424063B6645584514940F27B9BFEEC0F4240FAF02C41464E4940DBA2CC0699084240FAF02C41464E4940
24489	Октябрьская Готня	1	1	1727	35.887202000000002	35.909309	50.673616000000003	50.643636999999998	0103000020E610000001000000050000001079CBD58FF141406EBF7CB2625249401079CBD58FF14140FB07910C39564940AF7AC03C64F44140FB07910C39564940AF7AC03C64F441406EBF7CB2625249401079CBD58FF141406EBF7CB262524940
54044	Ново-Александровка	1	1	1727	36.089188	36.110954	50.556659000000003	50.549711000000002	0103000020E610000001000000050000000B992B836A0B424030A017EE5C4649400B992B836A0B42401503249A4047494021AE9CBD330E42401503249A4047494021AE9CBD330E424030A017EE5C4649400B992B836A0B424030A017EE5C464940
23551	Никитское	1	1	1727	35.770439000000003	35.804907	50.650308000000003	50.631920000000001	0103000020E610000001000000050000000F48C2BE9DE241401BD82AC1E25049400F48C2BE9DE24140E129E44A3D53494026A94C3107E74140E129E44A3D53494026A94C3107E741401BD82AC1E25049400F48C2BE9DE241401BD82AC1E2504940
24330	Крюково	1	1	1727	35.968040999999999	36.014403000000001	50.686776999999999	50.653244000000001	0103000020E61000000100000005000000F4177AC4E8FB41407427D87F9D534940F4177AC4E8FB41408F52094FE85749406EFB1EF5D70142408F52094FE85749406EFB1EF5D70142407427D87F9D534940F4177AC4E8FB41407427D87F9D534940
24561	Красный Куток	1	1	1727	35.892789	35.955832999999998	50.647390000000001	50.619469000000002	0103000020E61000000100000005000000419DF2E846F2414063F19BC24A4F4940419DF2E846F24140F4E0EEACDD52494002B859BC58FA4140F4E0EEACDD52494002B859BC58FA414063F19BC24A4F4940419DF2E846F2414063F19BC24A4F4940
24452	Зыбино	1	1	1727	36.023251000000002	36.059265000000003	50.714190000000002	50.682771000000002	0103000020E61000000100000005000000B64C86E3F902424020D4450A65574940B64C86E3F9024240AC90F2936A5B49401366DAFE95074240AC90F2936A5B49401366DAFE9507424020D4450A65574940B64C86E3F902424020D4450A65574940
23646	Зозули	1	1	1727	35.911940999999999	35.945008000000001	50.575842999999999	50.547685000000001	0103000020E61000000100000005000000D670917BBAF4414040C1C58A1A464940D670917BBAF44140B5503239B5494940AC3AAB05F6F84140B5503239B5494940AC3AAB05F6F8414040C1C58A1A464940D670917BBAF4414040C1C58A1A464940
24217	Грузское	1	1	1727	35.962822000000003	36.030582000000003	50.527830999999999	50.483753	0103000020E6100000010000000500000046EF54C03DFB4140C32B499EEB3D494046EF54C03DFB4140516859F78F43494053EC681CEA034240516859F78F43494053EC681CEA034240C32B499EEB3D494046EF54C03DFB4140C32B499EEB3D4940
23752	Борисовка	1	1	1727	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
23663	Березовка	1	1	1727	35.871948000000003	35.941783000000001	50.543593000000001	50.476210000000002	0103000020E6100000010000000500000004E8F7FD9BEF41409B030473F43C494004E8F7FD9BEF4140D2AA967494454940E27668588CF84140D2AA967494454940E27668588CF841409B030473F43C494004E8F7FD9BEF41409B030473F43C4940
23564	Беленькое	1	1	1727	35.900990999999998	35.949373999999999	50.600543000000002	50.575133999999998	0103000020E61000000100000005000000C37E4FAC53F34140A968ACFD9D494940C37E4FAC53F34140BE6BD097DE4C49401BD6541685F94140BE6BD097DE4C49401BD6541685F94140A968ACFD9D494940C37E4FAC53F34140A968ACFD9D494940
24300	Байцуры	1	1	1727	36.053704000000003	36.081102999999999	50.546002000000001	50.511125	0103000020E610000001000000050000000BD5CDC5DF0642408195438B6C4149400BD5CDC5DF0642407AC6BE64E3454940C24D4695610A42407AC6BE64E3454940C24D4695610A42408195438B6C4149400BD5CDC5DF0642408195438B6C414940
23462	Акулиновка	1	1	1727	35.831837999999998	35.871077	50.657657999999998	50.641986000000003	0103000020E61000000100000005000000F7C8E6AA79EA4140B43EE5982C524940F7C8E6AA79EA4140F4F928232E5449401EA67D737FEF4140F4F928232E5449401EA67D737FEF4140B43EE5982C524940F7C8E6AA79EA4140B43EE5982C524940
19374	Ястребово	1	1	1588	36.748694999999998	36.770173999999997	50.607883000000001	50.592429000000003	0103000020E61000000100000005000000E0D6DD3CD55F4240DB19A6B6D44B4940E0D6DD3CD55F4240AE65321CCF4D4940601DC70F95624240AE65321CCF4D4940601DC70F95624240DB19A6B6D44B4940E0D6DD3CD55F4240DB19A6B6D44B4940
22354	Ясные Зори	1	1	1588	36.501945999999997	36.511504000000002	50.37124	50.363869000000001	0103000020E61000000100000005000000D32D3BC43F4042409D836742932E4940D32D3BC43F404240C87BD5CA842F4940F8E28BF678414240C87BD5CA842F4940F8E28BF6784142409D836742932E4940D32D3BC43F4042409D836742932E4940
22300	Щетиновка	1	1	1588	36.152895999999998	36.192359000000003	50.463464999999999	50.432566000000001	0103000020E6100000010000000500000038D89B189213424047AE9B525E37494038D89B18921342409AEB34D2523B4940AF0B3F389F1842409AEB34D2523B4940AF0B3F389F18424047AE9B525E37494038D89B189213424047AE9B525E374940
22380	Черемошное	1	1	1588	36.477781	36.504469999999998	50.392091000000001	50.375543	0103000020E6100000010000000500000039D384ED273D4240F19E03CB1130494039D384ED273D42402907B3093032494014E81379924042402907B3093032494014E8137992404240F19E03CB1130494039D384ED273D4240F19E03CB11304940
22212	Хохлово	1	1	1588	36.671250999999998	36.703221999999997	50.723576999999999	50.700409000000001	0103000020E610000001000000050000002234828DEB5542407B698A00A75949402234828DEB554240A391CF2B9E5C4940F2E9B12D035A4240A391CF2B9E5C4940F2E9B12D035A42407B698A00A75949402234828DEB5542407B698A00A7594940
22572	Устинка	1	1	1588	36.485380999999997	36.497463000000003	50.343741000000001	50.334215	0103000020E61000000100000005000000C58CF0F6203E4240946A9F8EC72A4940C58CF0F6203E4240ADA580B4FF2B49402BFC19DEAC3F4240ADA580B4FF2B49402BFC19DEAC3F4240946A9F8EC72A4940C58CF0F6203E4240946A9F8EC72A4940
22045	Таврово	1	1	1588	36.554882999999997	36.575741999999998	50.507997000000003	50.500968	0103000020E610000001000000050000009D0DF96706474240D82B2CB81F4049409D0DF96706474240AABBB20B064149408177F2E9B1494240AABBB20B064149408177F2E9B1494240D82B2CB81F4049409D0DF96706474240D82B2CB81F404940
21897	Стрелецкое	1	1	1588	36.465977000000002	36.521089000000003	50.641534999999998	50.615313999999998	0103000020E6100000010000000500000017D86322A53B4240AE62F19BC24E494017D86322A53B4240A31EA2D11D52494016A75A0BB3424240A31EA2D11D52494016A75A0BB3424240AE62F19BC24E494017D86322A53B4240AE62F19BC24E4940
19937	Солохи	1	1	1588	36.152239999999999	36.168024000000003	50.537999999999997	50.531381000000003	0103000020E610000001000000050000004F92AE997C1342409F5BE84A044449404F92AE997C134240BE9F1A2FDD444940B87878CF81154240BE9F1A2FDD444940B87878CF811542409F5BE84A044449404F92AE997C1342409F5BE84A04444940
23298	Северный	1	1	1588	36.546080000000003	36.576946	50.684534999999997	50.669614000000003	0103000020E61000000100000005000000F67F0EF3E5454240CD785BE9B5554940F67F0EF3E5454240D2FBC6D79E5749406DC7D45DD9494240D2FBC6D79E5749406DC7D45DD9494240CD785BE9B5554940F67F0EF3E5454240CD785BE9B5554940
20630	Репное	1	1	1588	36.492306999999997	36.509805999999998	50.532451999999999	50.522030000000001	0103000020E61000000100000005000000C24B70EA033F4240F4C308E1D1424940C24B70EA033F42404B581B6327444940FCA6B052414142404B581B6327444940FCA6B05241414240F4C308E1D1424940C24B70EA033F4240F4C308E1D1424940
22834	Разумное	1	1	1588	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
21724	Пушкарное	1	1	1588	36.406948999999997	36.462581	50.635057000000003	50.614908	0103000020E61000000100000005000000E811A3E7163442403E062B4EB54E4940E811A3E716344240460C3B8C495149402060ADDA353B4240460C3B8C495149402060ADDA353B42403E062B4EB54E4940E811A3E7163442403E062B4EB54E4940
19525	Петропавловка	1	1	1588	36.631582000000002	36.663876000000002	50.704573000000003	50.687325000000001	0103000020E61000000100000005000000035FD1ADD7504240925CFE43FA574940035FD1ADD75042408352B4722F5A4940B64C86E3F95442408352B4722F5A4940B64C86E3F9544240925CFE43FA574940035FD1ADD7504240925CFE43FA574940
21501	Петровка	1	1	1588	36.398235	36.413983000000002	50.383223000000001	50.373888999999998	0103000020E61000000100000005000000B08F4E5DF9324240C5AA4198DB2F4940B08F4E5DF93242409A0986730D314940CC0C1B65FD3442409A0986730D314940CC0C1B65FD344240C5AA4198DB2F4940B08F4E5DF9324240C5AA4198DB2F4940
19923	Орловка	1	1	1588	36.230592000000001	36.262985	50.549762999999999	50.533946	0103000020E61000000100000005000000105CE509841D42403EEAAF5758444940105CE509841D424082C64CA25E464940562B137EA921424082C64CA25E464940562B137EA92142403EEAAF5758444940105CE509841D42403EEAAF5758444940
22649	Октябрьский	1	1	1588	36.340159	36.377538000000001	50.461899000000003	50.424852999999999	0103000020E61000000100000005000000543882548A2B4240C24D469561364940543882548A2B42400E87A5811F3B4940A67F492A533042400E87A5811F3B4940A67F492A53304240C24D469561364940543882548A2B4240C24D469561364940
21635	Новосадовый	1	1	1588	36.660165999999997	36.672060000000002	50.657995	50.646127999999997	0103000020E610000001000000050000002FF7C95180544240D3838252B45249402FF7C951805442403CF71E2E395449409279E40F065642403CF71E2E395449409279E40F06564240D3838252B45249402FF7C95180544240D3838252B4524940
20256	Новая Нелидовка	1	1	1588	36.507272999999998	36.537106000000001	50.451577	50.445112000000002	0103000020E6100000010000000500000068925852EE4042405187156EF938494068925852EE4042401A506F46CD394940213EB0E3BF4442401A506F46CD394940213EB0E3BF4442405187156EF938494068925852EE4042405187156EF9384940
21560	Никольское	1	1	1588	36.567495999999998	36.584654	50.444400999999999	50.421903999999998	0103000020E610000001000000050000002F4E7CB5A34842409A0645F3003649402F4E7CB5A3484240A4A7C821E2384940E0BC38F1D54A4240A4A7C821E2384940E0BC38F1D54A42409A0645F3003649402F4E7CB5A34842409A0645F300364940
19859	Николаевка	1	1	1588	36.244236999999998	36.258547	50.485255000000002	50.473911000000001	0103000020E6100000010000000500000090BC7328431F42407A1B9B1DA93C494090BC7328431F4240399CF9D51C3E49404DBD6E1118214240399CF9D51C3E49404DBD6E11182142407A1B9B1DA93C494090BC7328431F42407A1B9B1DA93C4940
21099	Нижний Ольшанец	1	1	1588	36.676003000000001	36.690097999999999	50.500532	50.477345	0103000020E61000000100000005000000BB7F2C44875642405EF415A4193D4940BB7F2C4487564240FD4CBD6E114049407B849A2155584240FD4CBD6E114049407B849A21555842405EF415A4193D4940BB7F2C44875642405EF415A4193D4940
22488	Нечаевка	1	1	1588	36.589891000000001	36.621079999999999	50.365087000000003	50.348731000000001	0103000020E61000000100000005000000359A5C8C814B4240FA0CA837A32C4940359A5C8C814B4240EE98BA2BBB2E49408F19A88C7F4F4240EE98BA2BBB2E49408F19A88C7F4F4240FA0CA837A32C4940359A5C8C814B4240FA0CA837A32C4940
20759	Нехотеевка	1	1	1588	36.291336000000001	36.305079999999997	50.348402999999998	50.336703999999997	0103000020E61000000100000005000000E012807F4A2542405837DE1D192B4940E012807F4A254240056A3178982C4940F35487DC0C274240056A3178982C4940F35487DC0C2742405837DE1D192B4940E012807F4A2542405837DE1D192B4940
19340	Мясоедово	1	1	1588	36.791473000000003	36.810993000000003	50.641198000000003	50.622548999999999	0103000020E610000001000000050000006155BDFC4E654240299485AFAF4F49406155BDFC4E6542405C21ACC61252494079245E9ECE6742405C21ACC61252494079245E9ECE674240299485AFAF4F49406155BDFC4E654240299485AFAF4F4940
53989	Малиновский	1	1	1588	36.404155000000003	36.408934000000002	50.372796999999998	50.368856000000001	0103000020E61000000100000005000000E8C1DD59BB334240797764AC362F4940E8C1DD59BB3342400186E5CFB72F49407A1C06F3573442400186E5CFB72F49407A1C06F357344240797764AC362F4940E8C1DD59BB334240797764AC362F4940
21127	Майский	1	1	1588	36.450885	36.463012999999997	50.522551	50.515535	0103000020E61000000100000005000000E4A08499B6394240C078060DFD414940E4A08499B6394240FDBE7FF3E2424940B94F8E02443B4240FDBE7FF3E2424940B94F8E02443B4240C078060DFD414940E4A08499B6394240C078060DFD414940
21032	Крутой Лог	1	1	1588	36.710192999999997	36.752800000000001	50.541755000000002	50.506777	0103000020E610000001000000050000008F6CAE9AE75A4240B8AE9811DE4049408F6CAE9AE75A4240E5B8533A58454940E3361AC05B604240E5B8533A58454940E3361AC05B604240B8AE9811DE4049408F6CAE9AE75A4240B8AE9811DE404940
20997	Красный Хутор	1	1	1588	36.242809000000001	36.271213000000003	50.380662000000001	50.363931999999998	0103000020E610000001000000050000005516855D141F4240E3FBE252952E49405516855D141F42403C6A4C88B930494002A08A1BB72242403C6A4C88B930494002A08A1BB7224240E3FBE252952E49405516855D141F4240E3FBE252952E4940
20865	Красный Октябрь	1	1	1588	36.300821999999997	36.350758999999996	50.472076999999999	50.451445	0103000020E610000001000000050000006AF5D55581264240AB7823F3C83949406AF5D55581264240CE18E6046D3C49408AE3C0ABE52C4240CE18E6046D3C49408AE3C0ABE52C4240AB7823F3C83949406AF5D55581264240AB7823F3C8394940
53984	Красное	1	1	1588	36.470306999999998	36.545631	50.587448000000002	50.529749000000002	0103000020E61000000100000005000000390A1005333C42405B0BB3D0CE434940390A1005333C4240E10CFE7E314B49408657923CD7454240E10CFE7E314B49408657923CD74542405B0BB3D0CE434940390A1005333C42405B0BB3D0CE434940
22284	Киселево	1	1	1588	36.690026000000003	36.715296000000002	50.749246999999997	50.728965000000002	0103000020E61000000100000005000000E2B19FC552584240DE76A1B94E5D4940E2B19FC55258424024D06053E75F4940D57ABFD18E5B424024D06053E75F4940D57ABFD18E5B4240DE76A1B94E5D4940E2B19FC552584240DE76A1B94E5D4940
19502	Зеленая Поляна	1	1	1588	36.619543999999998	36.643160999999999	50.640946999999997	50.623612000000001	0103000020E610000001000000050000006D37C1374D4F424053B29C84D24F49406D37C1374D4F424012BC218D0A524940058882195352424012BC218D0A524940058882195352424053B29C84D24F49406D37C1374D4F424053B29C84D24F4940
20745	Журавлевка	1	1	1588	36.302708000000003	36.343384	50.322730999999997	50.303674000000001	0103000020E61000000100000005000000691EC022BF264240A05225CADE264940691EC022BF264240E333D93F4F2949401EFCC401F42B4240E333D93F4F2949401EFCC401F42B4240A05225CADE264940691EC022BF264240A05225CADE264940
20650	Ерик	1	1	1588	36.498612999999999	36.519283000000001	50.723194999999997	50.709890000000001	0103000020E61000000100000005000000232E008DD23F4240F4E0EEACDD5A4940232E008DD23F4240BBD05CA7915C4940342F87DD77424240BBD05CA7915C4940342F87DD77424240F4E0EEACDD5A4940232E008DD23F4240F4E0EEACDD5A4940
53971	Дубовое	1	1	1588	36.576343999999999	36.590725999999997	50.539082000000001	50.531725000000002	0103000020E61000000100000005000000779FE3A3C549424099BB96900F444940779FE3A3C54942405FEE93A300454940CD72D9E89C4B42405FEE93A300454940CD72D9E89C4B424099BB96900F444940779FE3A3C549424099BB96900F444940
21829	Драгунское	1	1	1588	36.435972999999997	36.462581	50.660381999999998	50.634880000000003	0103000020E61000000100000005000000317898F6CD374240377172BF43514940317898F6CD374240FC6EBA65875449402060ADDA353B4240FC6EBA65875449402060ADDA353B4240377172BF43514940317898F6CD374240377172BF43514940
20123	Долбино	1	1	1588	36.394022	36.413137999999996	50.523237999999999	50.507778999999999	0103000020E61000000100000005000000C7F319506F3242403C4CFBE6FE404940C7F319506F32424021037976F94249400F5EBBB4E134424021037976F94249400F5EBBB4E13442403C4CFBE6FE404940C7F319506F3242403C4CFBE6FE404940
20199	Головино	1	1	1588	36.427852999999999	36.456302000000001	50.485689999999998	50.464852	0103000020E610000001000000050000006C3F19E3C336424077BD3445803B49406C3F19E3C336424043FF04172B3E4940B98C9B1A683A424043FF04172B3E4940B98C9B1A683A424077BD3445803B49406C3F19E3C336424077BD3445803B4940
22524	Вёргилевка	1	1	1588	36.567909	36.593457000000001	50.312958999999999	50.305974999999997	0103000020E61000000100000005000000520DFB3DB1484240613255302A274940520DFB3DB148424093FE5E0A0F284940884A2366F64B424093FE5E0A0F284940884A2366F64B4240613255302A274940520DFB3DB1484240613255302A274940
20025	Веселая Лопань	1	1	1588	36.365563000000002	36.399070999999999	50.503076	50.483134	0103000020E6100000010000000500000057D0B4C4CA2E4240F7CABC55D73D494057D0B4C4CA2E424085B35BCB6440494019E42EC21433424085B35BCB6440494019E42EC214334240F7CABC55D73D494057D0B4C4CA2E4240F7CABC55D73D4940
20318	Варваровка	1	1	1588	36.399807000000003	36.414450000000002	50.427802999999997	50.419182999999997	0103000020E610000001000000050000001FDB32E02C3342400305DEC9A73549401FDB32E02C334240BA10AB3FC2364940E2E995B20C354240BA10AB3FC2364940E2E995B20C3542400305DEC9A73549401FDB32E02C3342400305DEC9A7354940
22435	Бочковка	1	1	1588	36.559832999999998	36.577565999999997	50.378777999999997	50.359375	0103000020E610000001000000050000005C1C959BA847424000000000002E49405C1C959BA8474240DE3829CC7B30494009A4C4AEED494240DE3829CC7B30494009A4C4AEED49424000000000002E49405C1C959BA847424000000000002E4940
21699	Ближняя Игуменка	1	1	1588	36.697006000000002	36.728411000000001	50.622777999999997	50.609192	0103000020E61000000100000005000000D28E1B7E375942400F7EE200FA4D4940D28E1B7E375942408A558330B74F4940F98557923C5D42408A558330B74F4940F98557923C5D42400F7EE200FA4D4940D28E1B7E375942400F7EE200FA4D4940
54046	Ближний	1	1	1588	36.367835999999997	36.387869000000002	50.583765	50.570283000000003	0103000020E610000001000000050000004E250340152F42407E3B8908FF4849404E250340152F424054C6BFCFB84A4940ED10FFB0A531424054C6BFCFB84A4940ED10FFB0A53142407E3B8908FF4849404E250340152F42407E3B8908FF484940
19656	Бессоновка	1	1	1588	36.285046999999999	36.321483000000001	50.541274000000001	50.516807	0103000020E6100000010000000500000055698B6B7C24424004AC55BB2642494055698B6B7C2442406A16687748454940289CDD5A262942406A16687748454940289CDD5A2629424004AC55BB2642494055698B6B7C24424004AC55BB26424940
19450	Беломестное	1	1	1588	36.612906000000002	36.655306000000003	50.691319999999997	50.667763999999998	0103000020E61000000100000005000000D7C22CB4734E42401BB96E4A79554940D7C22CB4734E42400D897B2C7D584940B16F2711E15342400D897B2C7D584940B16F2711E15342401BB96E4A79554940D7C22CB4734E42401BB96E4A79554940
19265	Беловское	1	1	1588	36.724009000000002	36.753672000000002	50.591743000000001	50.565505999999999	0103000020E610000001000000050000003D81B053AC5C42408CD82780624849403D81B053AC5C42408751103CBE4B494099F4F752786042408751103CBE4B494099F4F752786042408CD82780624849403D81B053AC5C42408CD8278062484940
53978	Северный	1	1	7306	36.546080000000003	36.576946	50.684534999999997	50.669614000000003	0103000020E61000000100000005000000F67F0EF3E5454240CD785BE9B5554940F67F0EF3E5454240D2FBC6D79E5749406DC7D45DD9494240D2FBC6D79E5749406DC7D45DD9494240CD785BE9B5554940F67F0EF3E5454240CD785BE9B5554940
12069	Щербаково	1	1	1165	38.631411	38.646089000000003	50.538514999999997	50.520535000000002	0103000020E61000000100000005000000D6AA5D13D250434031B610E4A0424940D6AA5D13D2504340E5B33C0FEE44494016A75A0BB3524340E5B33C0FEE44494016A75A0BB352434031B610E4A0424940D6AA5D13D250434031B610E4A0424940
12920	Хрещатый	1	1	1165	38.552619999999997	38.579946999999997	50.447436000000003	50.430717999999999	0103000020E61000000100000005000000C98E8D40BC46434036E675C421374940C98E8D40BC464340CB86359545394940E7340BB43B4A4340CB86359545394940E7340BB43B4A434036E675C421374940C98E8D40BC46434036E675C421374940
12831	Хлевище	1	1	1165	38.528213000000001	38.555027000000003	50.563085000000001	50.548481000000002	0103000020E610000001000000050000003929CC7B9C4343401BBD1AA0344649403929CC7B9C43434020EF552B13484940D1B2EE1F0B47434020EF552B13484940D1B2EE1F0B4743401BBD1AA0344649403929CC7B9C4343401BBD1AA034464940
54043	Тютюнниково	1	1	1165	39.049396999999999	39.067354000000002	50.528243000000003	50.513272999999998	0103000020E61000000100000005000000A0C211A452864340BC75FEEDB2414940A0C211A452864340A4AB74779D4349409DA04D0E9F884340A4AB74779D4349409DA04D0E9F884340BC75FEEDB2414940A0C211A452864340BC75FEEDB2414940
12049	Теплинка	1	1	1165	38.631312000000001	38.644886	50.500399999999999	50.488722000000003	0103000020E6100000010000000500000043C9E4D4CE504340F96A47718E3E494043C9E4D4CE5043408E75711B0D404940FAD2DB9F8B5243408E75711B0D404940FAD2DB9F8B524340F96A47718E3E494043C9E4D4CE504340F96A47718E3E4940
12695	Студеный Колодец	1	1	1165	38.799790999999999	38.844544999999997	50.794231000000003	50.777585999999999	0103000020E610000001000000050000004C512E8D5F664340EAE923F0876349404C512E8D5F664340153C855CA96549400A80F10C1A6C4340153C855CA96549400A80F10C1A6C4340EAE923F0876349404C512E8D5F664340EAE923F087634940
12801	Советское	1	1	1165	38.991357000000001	39.033721	50.355581999999998	50.310307000000002	0103000020E6100000010000000500000091D442C9E47E4340255CC823B827494091D442C9E47E4340EC8502B6832D49401E1840F850844340EC8502B6832D49401E1840F850844340255CC823B827494091D442C9E47E4340255CC823B8274940
11125	Славгородское	1	1	1165	38.884529000000001	38.909115999999997	50.482698999999997	50.466802000000001	0103000020E610000001000000050000008AAE0B3F387143408CDAFD2AC03B49408AAE0B3F38714340EC67B114C93D49409A22C0E95D744340EC67B114C93D49409A22C0E95D7443408CDAFD2AC03B49408AAE0B3F387143408CDAFD2AC03B4940
11882	Сидоркин	1	1	1165	38.595163999999997	38.611288999999999	50.606699999999996	50.589433	0103000020E61000000100000005000000D6E07D552E4C43407217618A724B4940D6E07D552E4C4340D93D7958A84D4940C8B3CBB73E4E4340D93D7958A84D4940C8B3CBB73E4E43407217618A724B4940D6E07D552E4C43407217618A724B4940
12671	Репенка	1	1	1165	38.746395	38.803474000000001	50.789915999999998	50.768461000000002	0103000020E61000000100000005000000EF7211DF895F434030A017EE5C624940EF7211DF895F4340274BADF71B654940D9976C3CD8664340274BADF71B654940D9976C3CD866434030A017EE5C624940EF7211DF895F434030A017EE5C624940
12606	Подсереднее	1	1	1165	38.545594999999999	38.577593	50.72701	50.698422999999998	0103000020E6100000010000000500000039EE940ED645434019E3C3EC6559494039EE940ED6454340B7EEE6A90E5D494003B34291EE494340B7EEE6A90E5D494003B34291EE49434019E3C3EC6559494039EE940ED645434019E3C3EC65594940
11605	Пирогово	1	1	1165	39.010086999999999	39.030371000000002	50.619269000000003	50.603400999999998	0103000020E61000000100000005000000B08EE3874A814340D5AF743E3C4D4940B08EE3874A8143409C36E334444F494098DF6932E38343409C36E334444F494098DF6932E3834340D5AF743E3C4D4940B08EE3874A814340D5AF743E3C4D4940
12563	Мухоудеровка	1	1	1165	38.848892999999997	38.897492	50.694913999999997	50.65719	0103000020E61000000100000005000000D3669C86A86C43400EA14ACD1E544940D3669C86A86C43402AC423F1F2584940F8359204E17243402AC423F1F2584940F8359204E17243400EA14ACD1E544940D3669C86A86C43400EA14ACD1E544940
12404	Меняйлово	1	1	1165	38.741112999999999	38.761477999999997	50.533121999999999	50.513336000000002	0103000020E61000000100000005000000FAD170CADC5E434003EE79FEB4414940FAD170CADC5E4340996379573D444940CE4F711C78614340996379573D444940CE4F711C7861434003EE79FEB4414940FAD170CADC5E434003EE79FEB4414940
12327	Матрено-Гезово	1	1	1165	38.853672000000003	38.890737000000001	50.626555000000003	50.590508	0103000020E6100000010000000500000066C1C41F456D4340600322C4954B494066C1C41F456D4340991249F432504940282B86AB03724340991249F432504940282B86AB03724340600322C4954B494066C1C41F456D4340600322C4954B4940
12157	Луценково	1	1	1165	38.944311999999996	38.970866000000001	50.487175000000001	50.468493000000002	0103000020E61000000100000005000000349C3237DF784340D5B32094F73B4940349C3237DF784340E3361AC05B3E494030664B56457C4340E3361AC05B3E494030664B56457C4340D5B32094F73B4940349C3237DF784340D5B32094F73B4940
11926	Красное	1	1	1165	38.791203000000003	38.840888999999997	50.359225000000002	50.296585	0103000020E61000000100000005000000A1BFD02346654340F9BD4D7FF6254940A1BFD02346654340EB73B515FB2D494077483140A26B4340EB73B515FB2D494077483140A26B4340F9BD4D7FF6254940A1BFD02346654340F9BD4D7FF6254940
12144	Копанец	1	1	1165	38.908065000000001	38.927379000000002	50.50515	50.486412999999999	0103000020E6100000010000000500000035D252793B744340B4ACFBC7423E494035D252793B74434086C954C1A8404940A4FFE55AB476434086C954C1A8404940A4FFE55AB4764340B4ACFBC7423E494035D252793B744340B4ACFBC7423E4940
12517	Колтуновка	1	1	1165	38.773201	38.804768000000003	50.659227999999999	50.637633000000001	0103000020E61000000100000005000000041E1840F8624340D9EC48F59D514940041E1840F8624340C24D469561544940056F48A302674340C24D469561544940056F48A302674340D9EC48F59D514940041E1840F8624340D9EC48F59D514940
11345	Ковалево	1	1	1165	38.781177999999997	38.804948000000003	50.428950999999998	50.404091999999999	0103000020E61000000100000005000000662D05A4FD634340A1496249B9334940662D05A4FD634340124BCADDE7364940857D3B8908674340124BCADDE7364940857D3B8908674340A1496249B9334940662D05A4FD634340A1496249B9334940
12894	Камышеватое	1	1	1165	38.556887000000003	38.580288000000003	50.486986000000002	50.474404	0103000020E61000000100000005000000A648BE1248474340B98B3045B93C4940A648BE124847434010CEA78E553E494071218FE0464A434010CEA78E553E494071218FE0464A4340B98B3045B93C4940A648BE1248474340B98B3045B93C4940
11247	Калитва	1	1	1165	38.921720000000001	38.943800000000003	50.346150000000002	50.327401000000002	0103000020E61000000100000005000000D908C4EBFA754340BFD6A546E8294940D908C4EBFA75434055C1A8A44E2C49407FFB3A70CE78434055C1A8A44E2C49407FFB3A70CE784340BFD6A546E8294940D908C4EBFA754340BFD6A546E8294940
11810	Ильинка	1	1	1165	38.5732	38.624412999999997	50.661175999999998	50.633319999999998	0103000020E610000001000000050000009A081B9E5E4943408CF337A1105149409A081B9E5E4943403673486AA15449403F19E3C3EC4F43403673486AA15449403F19E3C3EC4F43408CF337A1105149409A081B9E5E4943408CF337A110514940
11728	Иловка	1	1	1165	38.611603000000002	38.657147999999999	50.729295999999998	50.696922999999998	0103000020E610000001000000050000005891D101494E4340446ADAC5345949405891D101494E4340438D4292595D4940DF50F86C1D544340438D4292595D4940DF50F86C1D544340446ADAC5345949405891D101494E4340446ADAC534594940
11532	Иващенково	1	1	1165	39.025357999999997	39.049351999999999	50.579956000000003	50.565264999999997	0103000020E61000000100000005000000925852EE3E8343406649809A5A484940925852EE3E8343403B8F8AFF3B4A494000FF942A518643403B8F8AFF3B4A494000FF942A518643406649809A5A484940925852EE3E8343406649809A5A484940
12753	Запольное	1	1	1165	38.986246000000001	39.005468999999998	50.388725999999998	50.359174000000003	0103000020E61000000100000005000000C9E7154F3D7E434069C9E369F92D4940C9E7154F3D7E43406D8D08C6C131494027124C35B38043406D8D08C6C131494027124C35B380434069C9E369F92D4940C9E7154F3D7E434069C9E369F92D4940
11499	Жуково	1	1	1165	38.625518	38.649692000000002	50.434446999999999	50.414993000000003	0103000020E6100000010000000500000098874CF910504340D388997D1E35494098874CF910504340336C94F59B374940863C821B29534340336C94F59B374940863C821B29534340D388997D1E35494098874CF910504340D388997D1E354940
46930	Городище	1	1	1165	38.714801999999999	38.732084999999998	50.752524000000001	50.744984000000002	0103000020E61000000100000005000000C58EC6A17E5B43408A05BEA25B5F4940C58EC6A17E5B434041BAD8B452604940327216F6B45D434041BAD8B452604940327216F6B45D43408A05BEA25B5F4940C58EC6A17E5B43408A05BEA25B5F4940
11427	Глуховка	1	1	1165	38.677053999999998	38.718997000000002	50.739963000000003	50.719135000000001	0103000020E6100000010000000500000020D099B4A956434059349D9D0C5C494020D099B4A956434002A08A1BB75E49400876FC17085C434002A08A1BB75E49400876FC17085C434059349D9D0C5C494020D099B4A956434059349D9D0C5C4940
11303	Гарбузово	1	1	1165	38.745882999999999	38.777082	50.464416999999997	50.442089000000003	0103000020E6100000010000000500000039D21918795F4340EF75525F9638494039D21918795F43406C5A2904723B4940B727486C776343406C5A2904723B4940B727486C77634340EF75525F9638494039D21918795F4340EF75525F96384940
12274	Воробьево	1	1	1165	38.948129999999999	38.976165999999999	50.596997999999999	50.581145999999997	0103000020E61000000100000005000000A12DE7525C794340C119FCFD624A4940A12DE7525C79434082E3326E6A4C4940CBBBEA01F37C434082E3326E6A4C4940CBBBEA01F37C4340C119FCFD624A4940A12DE7525C794340C119FCFD624A4940
11209	Варваровка	1	1	1165	38.807265000000001	38.861505000000001	50.386032	50.362822999999999	0103000020E610000001000000050000004C1AA37554674340499EEBFB702E49404C1AA37554674340D09A1F7F69314940952BBCCB456E4340D09A1F7F69314940952BBCCB456E4340499EEBFB702E49404C1AA37554674340499EEBFB702E4940
11436	Бубликово	1	1	1165	38.643242000000001	38.693097999999999	50.426499999999997	50.397317000000001	0103000020E61000000100000005000000F2B4FCC0555243408A929048DB324940F2B4FCC0555243403BDF4F8D9736494025766D6FB75843403BDF4F8D9736494025766D6FB75843408A929048DB324940F2B4FCC0555243408A929048DB324940
12220	Божково	1	1	1165	38.916617000000002	38.932786999999998	50.537914000000001	50.529383000000003	0103000020E6100000010000000500000094FAB2B453754340790778D2C243494094FAB2B453754340C007AF5DDA44494025917D9065774340C007AF5DDA44494025917D9065774340790778D2C243494094FAB2B453754340790778D2C2434940
12467	Ближнее Чесночное	1	1	1165	38.839587000000002	38.863391999999997	50.709245000000003	50.682115000000003	0103000020E61000000100000005000000C9923996776B4340378E588B4F574940C9923996776B4340FFEC478AC85A494063D009A1836E4340FFEC478AC85A494063D009A1836E4340378E588B4F574940C9923996776B4340378E588B4F574940
11161	Афанасьевка	1	1	1165	38.583970999999998	38.616688000000003	50.799942000000001	50.777876999999997	0103000020E61000000100000005000000FD67CD8FBF4A4340C1A7397991634940FD67CD8FBF4A43403259DC7F64664940F7EAE3A1EF4E43403259DC7F64664940F7EAE3A1EF4E4340C1A7397991634940FD67CD8FBF4A4340C1A7397991634940
12396	Алексеенково	1	1	1165	38.818089999999998	38.838158	50.526090000000003	50.514963000000002	0103000020E61000000100000005000000A297512CB768434035D3BD4EEA414940A297512CB76843405760C8EA56434940BD70E7C2486B43405760C8EA56434940BD70E7C2486B434035D3BD4EEA414940A297512CB768434035D3BD4EEA414940
54024	Алексеевка	1	1	1165	38.478895000000001	39.126579999999997	50.822702	50.250297000000003	0103000020E61000000100000005000000E59B6D6E4C3D4340BAA46ABB09204940E59B6D6E4C3D4340492D944C4E694940F12900C633904340492D944C4E694940F12900C633904340BAA46ABB09204940E59B6D6E4C3D4340BAA46ABB09204940
11060	Алейниково	1	1	1165	38.823435000000003	38.845371999999998	50.476812000000002	50.463666000000003	0103000020E61000000100000005000000DEB06D516669434032225168593B4940DEB06D5166694340912BF52C083D4940207A5226356C4340912BF52C083D4940207A5226356C434032225168593B4940DEB06D516669434032225168593B4940
1	Москва	1	\N	\N	37.182743000000002	37.964969000000004	56.010739999999998	55.490667000000002	0103000020E610000001000000050000005649641F64974240FC1C1F2DCEBE4B405649641F649742402861A6ED5F014C40B153AC1A84FB42402861A6ED5F014C40B153AC1A84FB4240FC1C1F2DCEBE4B405649641F64974240FC1C1F2DCEBE4B40
54908	Тарко-Сале	6	33	\N	77.260836999999995	78.315494999999999	65.142611000000002	64.695008999999999	0103000020E610000001000000050000008D25AC8DB15053403E5B07077B2C50408D25AC8DB15053403143E389204950404CC3F011319453403143E389204950404CC3F011319453403E5B07077B2C50408D25AC8DB15053403E5B07077B2C5040
1053	Салехард	6	33	\N	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
54907	Ноябрьск	6	33	\N	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
54905	Новый Уренгой	6	33	\N	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
54904	Надым	6	33	\N	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
24742	Лабытнанги	6	33	\N	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
54903	Губкинский	6	33	\N	62.001389000000003	86.014298999999994	73.524799999999999	62.203499999999998	0103000020E610000001000000050000007EC9C6832D004F40355EBA490C1A4F407EC9C6832D004F40363CBD529661524064575A46EA805540363CBD529661524064575A46EA805540355EBA490C1A4F407EC9C6832D004F40355EBA490C1A4F40
55011	Яр-Сале	6	33	181	70.292021000000005	71.346678999999995	67.069590000000005	66.654747	0103000020E61000000100000005000000B22FD978B0925140DD09F65FE7A95040B22FD978B09251403C889D2974C4504070CD1DFD2FD651403C889D2974C4504070CD1DFD2FD65140DD09F65FE7A95040B22FD978B0925140DD09F65FE7A95040
54999	Сюнэйсале	6	33	181	70.724020999999993	71.778678999999997	67.110986999999994	66.696854000000002	0103000020E6100000010000000500000080272D5C56AE51408E05854199AC504080272D5C56AE5140FED137691AC750403FC571E0D5F15140FED137691AC750403FC571E0D5F151408E05854199AC504080272D5C56AE51408E05854199AC5040
52202	Сеяха	6	33	181	71.983566999999994	73.038224999999997	70.341596999999993	69.983427000000006	0103000020E61000000100000005000000309B00C3F2FE514038C0CC77F07E5140309B00C3F2FE514059DAA9B9DC955140EF3845477242524059DAA9B9DC955140EF3845477242524038C0CC77F07E5140309B00C3F2FE514038C0CC77F07E5140
52189	Салемал	6	33	181	68.631529999999998	69.686188000000001	66.965356999999997	66.548730000000006	0103000020E61000000100000005000000581CCEFC6A28514062156F641EA35040581CCEFC6A285140BDFDB968C8BD504017BA1281EA6B5140BDFDB968C8BD504017BA1281EA6B514062156F641EA35040581CCEFC6A28514062156F641EA35040
686	Панаевск	6	33	181	69.573278999999999	70.627937000000003	66.959040000000002	66.542304999999999	0103000020E61000000100000005000000F31E679AB064514044DD0720B5A25040F31E679AB064514093E34EE960BD5040B2BCAB1E30A8514093E34EE960BD5040B2BCAB1E30A8514044DD0720B5A25040F31E679AB064514044DD0720B5A25040
54939	Новый порт	6	33	181	72.377585999999994	73.432243999999997	67.892730999999998	67.492026999999993	0103000020E610000001000000050000005B5B785E2A185240EF6FD05E7DDF50405B5B785E2A1852400648348122F950401AF9BCE2A95B52400648348122F950401AF9BCE2A95B5240EF6FD05E7DDF50405B5B785E2A185240EF6FD05E7DDF5040
61043	Мыс-Каменный	6	33	181	73.068983000000003	74.123641000000006	68.661891999999995	68.274473	0103000020E61000000100000005000000B83EAC376A445240A4A833F790115140B83EAC376A445240FA5E43705C2A514077DCF0BBE9875240FA5E43705C2A514077DCF0BBE9875240A4A833F790115140B83EAC376A445240A4A833F790115140
568	Шурышкары	6	33	49	64.822664000000003	65.877323000000004	66.122738999999996	65.691739999999996	0103000020E610000001000000050000002EE6E786A63450407155D977456C50402EE6E786A634504066BCADF4DA875040D5415E0F2678504066BCADF4DA875040D5415E0F267850407155D977456C50402EE6E786A63450407155D977456C5040
477	Питляр	6	33	49	65.394316000000003	66.448974000000007	66.051670000000001	65.619462999999996	0103000020E6100000010000000500000088122D793C59504040852348A567504088122D793C595040CC0BB08F4E83504047B071FDBB9C5040CC0BB08F4E83504047B071FDBB9C504040852348A567504088122D793C59504040852348A5675040
412	Овгорт	6	33	49	63.45091	64.505567999999997	65.057985000000002	64.608956000000006	0103000020E610000001000000050000003DB83B6BB7B94F40FE2C9622F92650403DB83B6BB7B94F4026AAB706B6435040DD79E2395B20504026AAB706B6435040DD79E2395B205040FE2C9622F92650403DB83B6BB7B94F40FE2C9622F9265040
329	Мужи	6	33	49	64.172769000000002	65.227427000000006	65.623081999999997	65.183603000000005	0103000020E61000000100000005000000CF30B5A50E0B5040A41CCC26C04B5040CF30B5A50E0B50407B2E5393E06750408ECEF9298E4E50407B2E5393E06750408ECEF9298E4E5040A41CCC26C04B5040CF30B5A50E0B5040A41CCC26C04B5040
281	Лопхари	6	33	49	65.201770999999994	66.256429999999995	65.216747999999995	64.770397000000003	0103000020E61000000100000005000000FF91E9D0E94C5040F0FB372F4E315040FF91E9D0E94C50404CDE0033DF4D5040A6ED5F59699050404CDE0033DF4D5040A6ED5F5969905040F0FB372F4E315040FF91E9D0E94C5040F0FB372F4E315040
57607	Катровож	6	33	49	62.001389000000003	69.060897999999995	66.868706000000003	64.023398999999998	0103000020E610000001000000050000007EC9C6832D004F4095F0845E7F0150407EC9C6832D004F40B2F50CE198B750401399B9C0E5435140B2F50CE198B750401399B9C0E543514095F0845E7F0150407EC9C6832D004F4095F0845E7F015040
230	Горки	6	33	49	64.748697000000007	65.803354999999996	65.280449000000004	64.835173999999995	0103000020E610000001000000050000004167D2A6EA2F50400C1EA67D733550404167D2A6EA2F50408ACC5CE0F2515040FF04172B6A7350408ACC5CE0F2515040FF04172B6A7350400C1EA67D733550404167D2A6EA2F50400C1EA67D73355040
168	Восяхово	6	33	49	64.058368999999999	65.113027000000002	65.790817000000004	65.354180999999997	0103000020E610000001000000050000006A865451BC03504055F7C8E6AA5650406A865451BC035040BC07E8BE9C725040292499D53B475040BC07E8BE9C725040292499D53B47504055F7C8E6AA5650406A865451BC03504055F7C8E6AA565040
57	Азовы	6	33	49	64.526157999999995	65.580815999999999	65.119459000000006	64.671467000000007	0103000020E61000000100000005000000D7A19A92AC215040F855B950F92A5040D7A19A92AC215040A08D5C37A5475040963FDF162C655040A08D5C37A5475040963FDF162C655040F855B950F92A5040D7A19A92AC215040F855B950F92A5040
32450	Тазовский	6	33	347	78.190027000000001	79.244685000000004	67.676620999999997	67.272197000000006	0103000020E61000000100000005000000D9960167298C53407044F7AC6BD15040D9960167298C53405BB22AC24DEB5040983446EBA8CF53405BB22AC24DEB5040983446EBA8CF53407044F7AC6BD15040D9960167298C53407044F7AC6BD15040
57600	Новозаполярный	6	33	347	73.005598000000006	82.877993000000004	73.524799999999999	66.321398000000002	0103000020E6100000010000000500000013BBB6B75B405240FDBFEAC89194504013BBB6B75B405240363CBD52966152407C478D0931B85440363CBD52966152407C478D0931B85440FDBFEAC89194504013BBB6B75B405240FDBFEAC891945040
52166	Находка	6	33	347	77.020915000000002	78.075573000000006	67.925881000000004	67.525746999999996	0103000020E61000000100000005000000BC3FDEAB5641534016BEBED6A5E15040BC3FDEAB5641534038BF61A241FB50407BDD2230D684534038BF61A241FB50407BDD2230D684534016BEBED6A5E15040BC3FDEAB5641534016BEBED6A5E15040
52173	Гыда	6	33	347	77.976605000000006	79.031262999999996	71.066760000000002	70.721312999999995	0103000020E610000001000000050000000C0742B2807E53407F4B00FE29AE51400C0742B2807E5340952BBCCB45C45140CAA4863600C25340952BBCCB45C45140CAA4863600C253407F4B00FE29AE51400C0742B2807E53407F4B00FE29AE5140
52165	Газсале	6	33	347	78.484179999999995	79.538837999999998	67.569817999999998	67.163556999999997	0103000020E6100000010000000500000025581CCEFC9E53400A82C7B777CA504025581CCEFC9E534004ABEAE577E45040E4F560527CE2534004ABEAE577E45040E4F560527CE253400A82C7B777CA504025581CCEFC9E53400A82C7B777CA5040
52172	Антипаюта	6	33	347	76.335779000000002	77.390437000000006	69.281743000000006	68.905079999999998	0103000020E61000000100000005000000C0EB33677D155340E010AAD4EC395140C0EB33677D15534020B8CA13085251407F8978EBFC58534020B8CA13085251407F8978EBFC585340E010AAD4EC395140C0EB33677D155340E010AAD4EC395140
52127	Харампур	6	33	279	77.573036999999999	78.627695000000003	64.508906999999994	64.050640999999999	0103000020E61000000100000005000000789961A3AC6453408DB5BFB33D035040789961A3AC645340266DAAEE912050403737A6272CA85340266DAAEE912050403737A6272CA853408DB5BFB33D035040789961A3AC6453408DB5BFB33D035040
52119	Ханымей	6	33	279	75.438846999999996	76.493504999999999	63.957341999999997	63.489837999999999	0103000020E61000000100000005000000A73CBA1116DC5240452BF702B3BE4F40A73CBA1116DC52402A8BC22E8AFA4F4066DAFE95951F53402A8BC22E8AFA4F4066DAFE95951F5340452BF702B3BE4F40A73CBA1116DC5240452BF702B3BE4F40
52130	Халясавэй	6	33	279	77.821646000000001	78.876304000000005	63.622031	63.148933	0103000020E61000000100000005000000E9B81AD995745340C8258E3C10934F40E9B81AD995745340910C39B69ECF4F40A8565F5D15B85340910C39B69ECF4F40A8565F5D15B85340C8258E3C10934F40E9B81AD995745340C8258E3C10934F40
30595	Уренгой	6	33	279	77.857164999999995	78.911822999999998	66.171627000000001	65.741459000000006	0103000020E61000000100000005000000A79196CADB765340CB147310746F5040A79196CADB7653401407D0EFFB8A5040662FDB4E5BBA53401407D0EFFB8A5040662FDB4E5BBA5340CB147310746F5040A79196CADB765340CB147310746F5040
54910	Тарко-Сале	6	33	279	77.260836999999995	78.315494999999999	65.142611000000002	64.695008999999999	0103000020E610000001000000050000008D25AC8DB15053403E5B07077B2C50408D25AC8DB15053403143E389204950404CC3F011319453403143E389204950404CC3F011319453403E5B07077B2C50408D25AC8DB15053403E5B07077B2C5040
1437	Сывдарма	6	33	279	77.234551999999994	78.289209999999997	65.489253000000005	65.047507999999993	0103000020E61000000100000005000000874D64E6024F53401893FE5E0A435040874D64E6024F5340139ED0EB4F5F504046EBA86A82925340139ED0EB4F5F504046EBA86A829253401893FE5E0A435040874D64E6024F53401893FE5E0A435040
52097	Самбург	6	33	279	77.707587000000004	78.762244999999993	67.210350000000005	66.797918999999993	0103000020E61000000100000005000000C904FC1A496D5340D976DA1A11B35040C904FC1A496D5340ACADD85F76CD504087A2409FC8B05340ACADD85F76CD504087A2409FC8B05340D976DA1A11B35040C904FC1A496D5340D976DA1A11B35040
57590	Пурпе-1	6	33	279	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
52117	Пурпе	6	33	279	76.146072000000004	77.200729999999993	64.714893000000004	64.260086999999999	0103000020E6100000010000000500000020B75F3E5909534058C7F143A510504020B75F3E59095340EBC891CEC02D5040DE54A4C2D84C5340EBC891CEC02D5040DE54A4C2D84C534058C7F143A510504020B75F3E5909534058C7F143A5105040
30813	Пуровск	6	33	279	77.257064	78.311722000000003	65.534594999999996	65.093616999999995	0103000020E61000000100000005000000A73E90BC73505340605628D2FD455040A73E90BC73505340BA66F2CD3662504066DCD440F3935340BA66F2CD3662504066DCD440F3935340605628D2FD455040A73E90BC73505340605628D2FD455040
1179	Ноябрьск	6	33	279	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
25275	Муравленко	6	33	279	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
54902	Губкинский	6	33	279	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
30445	Харсаим	6	33	295	66.774443000000005	67.829100999999994	66.803721999999993	66.384331000000003	0103000020E610000001000000050000006F675F7990B15040B2F50CE1989850406F675F7990B15040D844662E70B350402D05A4FD0FF55040D844662E70B350402D05A4FD0FF55040B2F50CE1989850406F675F7990B15040B2F50CE198985040
1281	Харп	6	33	295	65.284910999999994	66.339568999999997	67.008905999999996	66.593024999999997	0103000020E6100000010000000500000052D158FB3B525040772D211FF4A5504052D158FB3B5250403EAF78EA91C05040116F9D7FBB9550403EAF78EA91C05040116F9D7FBB955040772D211FF4A5504052D158FB3B525040772D211FF4A55040
30219	Белоярск	6	33	295	67.628309999999999	68.682968000000002	67.073307	66.658528000000004	0103000020E61000000100000005000000FC6F253B36E8504005E09F5225AA5040FC6F253B36E8504058E4D70FB1C45040BB0D6ABFB52B514058E4D70FB1C45040BB0D6ABFB52B514005E09F5225AA5040FC6F253B36E8504005E09F5225AA5040
30192	Аксарка	6	33	295	67.265722999999994	68.320380999999998	66.770247999999995	66.350285	0103000020E61000000100000005000000E1B20A9B01D15040E1D1C6116B965040E1B20A9B01D15040CD7344BE4BB15040A0504F1F81145140CD7344BE4BB15040A0504F1F81145140E1D1C6116B965040E1B20A9B01D15040E1D1C6116B965040
26767	Ямбург	6	33	276	74.327288999999993	75.381946999999997	68.102568000000005	67.705481000000006	0103000020E61000000100000005000000CBD58F4DF2945240C3BCC79926ED5040CBD58F4DF29452406F675F79900651408A73D4D171D852406F675F79900651408A73D4D171D85240C3BCC79926ED5040CBD58F4DF2945240C3BCC79926ED5040
55022	Ягельный	6	33	276	68.566294999999997	77.458393999999998	68.930599999999998	63.195298999999999	0103000020E61000000100000005000000DA38622D3E24514083F8C08EFF984F40DA38622D3E245140166A4DF38E3B5140B0ABC953565D5340166A4DF38E3B5140B0ABC953565D534083F8C08EFF984F40DA38622D3E24514083F8C08EFF984F40
41055	Стар. Надым	6	33	276	72.191608000000002	73.246266000000006	65.815297000000001	65.379075999999998	0103000020E61000000100000005000000BA69334E430C5240B4ACFBC742585040BA69334E430C5240B9E177D32D745040790778D2C24F5240B9E177D32D745040790778D2C24F5240B4ACFBC742585040BA69334E430C5240B4ACFBC742585040
52935	Приозерный	6	33	276	70.562639000000004	71.617296999999994	64.511497000000006	64.053273000000004	0103000020E61000000100000005000000111D024702A45140A13028D368035040111D024702A4514023C0E95DBC205040CFBA46CB81E7514023C0E95DBC205040CFBA46CB81E75140A13028D368035040111D024702A45140A13028D368035040
26339	Правохеттинский	6	33	276	73.001779999999997	74.056438	65.663792000000001	65.225003000000001	0103000020E610000001000000050000005C72DC291D4052401FA0FB72664E50405C72DC291D4052402CD670917B6A50401B1021AE9C8352402CD670917B6A50401B1021AE9C8352401FA0FB72664E50405C72DC291D4052401FA0FB72664E5040
52952	Пангоды	6	33	276	73.957928999999993	75.012586999999996	66.063156000000006	65.631142999999994	0103000020E61000000100000005000000F5B86FB54E7D52405B069CA564685040F5B86FB54E7D5240F5A276BF0A845040B456B439CEC05240F5A276BF0A845040B456B439CEC052405B069CA564685040F5B86FB54E7D52405B069CA564685040
52943	Ныда	6	33	276	72.411299999999997	73.465958000000001	66.833067	66.414178000000007	0103000020E6100000010000000500000011363CBD521A5240412E71E4819A504011363CBD521A52401E1840F850B55040D0D38041D25D52401E1840F850B55040D0D38041D25D5240412E71E4819A504011363CBD521A5240412E71E4819A5040
52955	Нори	6	33	276	71.895981000000006	72.950638999999995	66.363170999999994	65.936263999999994	0103000020E610000001000000050000009835B1C057F95140041BD7BFEB7B50409835B1C057F95140C2F693313E97504056D3F544D73C5240C2F693313E97504056D3F544D73C5240041BD7BFEB7B50409835B1C057F95140041BD7BFEB7B5040
54906	Новый Уренгой	6	33	276	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
54990	Надым	6	33	276	72.191608000000002	73.246266000000006	65.815297000000001	65.379075999999998	0103000020E61000000100000005000000BA69334E430C5240B4ACFBC742585040BA69334E430C5240B9E177D32D745040790778D2C24F5240B9E177D32D745040790778D2C24F5240B4ACFBC742585040BA69334E430C5240B4ACFBC742585040
52947	Лонгъюган	6	33	276	70.418181000000004	71.472838999999993	65.011184	64.561366000000007	0103000020E61000000100000005000000C0B33D7AC39A514087C5A86BED235040C0B33D7AC39A5140438F183DB74050407E5182FE42DE5140438F183DB74050407E5182FE42DE514087C5A86BED235040C0B33D7AC39A514087C5A86BED235040
59096	Лесной	6	33	276	68.566294999999997	77.458393999999998	68.930599999999998	63.195298999999999	0103000020E61000000100000005000000DA38622D3E24514083F8C08EFF984F40DA38622D3E245140166A4DF38E3B5140B0ABC953565D5340166A4DF38E3B5140B0ABC953565D534083F8C08EFF984F40DA38622D3E24514083F8C08EFF984F40
52942	Кутопьюган	6	33	276	69.857828999999995	70.912487999999996	66.539044000000004	66.115133999999998	0103000020E61000000100000005000000DD239BABE6765140172AFF5A5E875040DD239BABE6765140B9C667B27FA25040847F113466BA5140B9C667B27FA25040847F113466BA5140172AFF5A5E875040DD239BABE6765140172AFF5A5E875040
55018	Заполярный	6	33	276	68.566294999999997	77.458393999999998	68.930599999999998	63.195298999999999	0103000020E61000000100000005000000DA38622D3E24514083F8C08EFF984F40DA38622D3E245140166A4DF38E3B5140B0ABC953565D5340166A4DF38E3B5140B0ABC953565D534083F8C08EFF984F40DA38622D3E24514083F8C08EFF984F40
24655	Толька	6	33	358	79.578787000000005	80.633444999999995	63.632683999999998	63.159762999999998	0103000020E610000001000000050000006616A1D80AE55340300E2E1D73944F406616A1D80AE55340EA5910CAFBD04F4024B4E55C8A285440EA5910CAFBD04F4024B4E55C8A285440300E2E1D73944F406616A1D80AE55340300E2E1D73944F40
24708	Ратта	6	33	358	83.336826000000002	84.391484000000005	63.818736999999999	63.348919000000002	0103000020E61000000100000005000000529CA38E8ED55440FDF9B660A9AC4F40529CA38E8ED554403883BF5FCCE84F40113AE8120E1955403883BF5FCCE84F40113AE8120E195540FDF9B660A9AC4F40529CA38E8ED55440FDF9B660A9AC4F40
24608	Красноселькуп	6	33	358	81.932210999999995	82.986868999999999	65.922922999999997	65.488529	0103000020E610000001000000050000002C7E5358A97B54407289230F445F50402C7E5358A97B54407A6EA12B117B5040EB1B98DC28BF54407A6EA12B117B5040EB1B98DC28BF54407289230F445F50402C7E5358A97B54407289230F445F5040
55159	городской округ Верхний Уфалей	6	58	\N	60.173344	60.291553	56.082908000000003	56.001801	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
4212	Южноуральск	6	58	\N	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
66	Челябинск	6	58	\N	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
27323	Чебаркуль	6	58	\N	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
29076	Усть-Катав	6	58	\N	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
55144	Троицк	6	58	\N	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
55116	Трехгорный	6	58	\N	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
55123	Снежинск	6	58	\N	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
25916	Синеглазово	6	58	\N	61.432962000000003	61.453029999999998	55.036797999999997	54.996091999999997	0103000020E6100000010000000500000094347F4C6BB74E4053E751F17F7F4B4094347F4C6BB74E407347FFCBB5844B40AE0D15E3FCB94E407347FFCBB5844B40AE0D15E3FCB94E4053E751F17F7F4B4094347F4C6BB74E4053E751F17F7F4B40
48194	Сим	6	58	\N	57.664053000000003	57.731749999999998	55.060234999999999	54.978549999999998	0103000020E61000000100000005000000C5E74EB0FFD44C401AC05B20417D4B40C5E74EB0FFD44C408B89CDC7B5874B408B6CE7FBA9DD4C408B89CDC7B5874B408B6CE7FBA9DD4C401AC05B20417D4B40C5E74EB0FFD44C401AC05B20417D4B40
55105	Сатка	6	58	\N	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
55097	Роза	6	58	\N	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
13165	Пласт	6	58	\N	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
55153	Первомайский	6	58	\N	57.151249999999997	57.164634	55.082616999999999	55.070143999999999	0103000020E610000001000000050000008FC2F5285C934C405C01857AFA884B408FC2F5285C934C40FC8BA031938A4B40A3E716BA12954C40FC8BA031938A4B40A3E716BA12954C405C01857AFA884B408FC2F5285C934C405C01857AFA884B40
55134	Озеры	6	58	\N	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
55108	Озерск	6	58	\N	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
20261	Огнеупорный	6	58	\N	61.076293999999997	61.081235	53.955246000000002	53.951706999999999	0103000020E61000000100000005000000C5707500C4894E40E82FF488D1F94A40C5707500C4894E4042D13C8045FA4A40312592E8658A4E4042D13C8045FA4A40312592E8658A4E40E82FF488D1F94A40C5707500C4894E40E82FF488D1F94A40
7310	Нязепетровск	6	58	\N	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
1180	Новое Поле	6	58	\N	61.335439999999998	61.351035000000003	55.316527999999998	55.301186999999999	0103000020E6100000010000000500000097E2AAB2EFAA4E407C7DAD4B8DA64B4097E2AAB2EFAA4E40572250FD83A84B402D6002B7EEAC4E40572250FD83A84B402D6002B7EEAC4E407C7DAD4B8DA64B4097E2AAB2EFAA4E407C7DAD4B8DA64B40
55140	Миньяр	6	58	\N	57.502293000000002	57.587668999999998	55.085296	55.044299000000002	0103000020E610000001000000050000003F0114234BC04C406D1FF296AB854B403F0114234BC04C40643DB5FAEA8A4B40BFEFDFBC38CB4C40643DB5FAEA8A4B40BFEFDFBC38CB4C406D1FF296AB854B403F0114234BC04C406D1FF296AB854B40
7529	Миасс	6	58	\N	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
52522	Малая Сосновка	6	58	\N	61.279350000000001	61.294603000000002	55.065040000000003	55.056223000000003	0103000020E610000001000000050000009D11A5BDC1A34E403A24B55032874B409D11A5BDC1A34E404777103B53884B40D926158DB5A54E404777103B53884B40D926158DB5A54E403A24B55032874B409D11A5BDC1A34E403A24B55032874B40
2116	Магнитогорск	6	58	\N	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
55110	Кыштым	6	58	\N	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
3348	Кыштым	6	58	\N	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
55092	Куса	6	58	\N	59.391711000000001	59.473754	55.362485	55.314996999999998	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
16949	Круглое	6	58	\N	61.521500000000003	61.533267000000002	55.251660000000001	55.243161000000001	0103000020E61000000100000005000000986E1283C0C24E40D2544FE61F9F4B40986E1283C0C24E400EDB166536A04B409D84D21742C44E400EDB166536A04B409D84D21742C44E40D2544FE61F9F4B40986E1283C0C24E40D2544FE61F9F4B40
55152	Красное Поле	6	58	\N	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
55122	Красногорский	6	58	\N	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
26226	Коркино	6	58	\N	61.323402999999999	61.432791000000002	54.914178	54.874212	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
55095	Копейск,	6	58	\N	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
55093	Копейск	6	58	\N	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
55126	Копейск	6	58	\N	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
55151	Копейск	6	58	\N	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
35919	Киров	6	58	\N	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
55117	Катав-Ивановск	6	58	\N	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
12375	Касли	6	58	\N	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
55111	Карталы	6	58	\N	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
13447	Карабаш	6	58	\N	60.169266	60.257444	55.512672999999999	55.408766999999997	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
7465	Златоуст	6	58	\N	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
20314	Еманжелинск	6	58	\N	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
55099	Верхний Уфалей	6	58	\N	60.173344	60.291553	56.082908000000003	56.001801	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
55147	Верхнеуральск	6	58	\N	59.186903999999998	59.246569999999998	53.898066	53.852186000000003	0103000020E61000000100000005000000ECBE6378EC974D40F60D4C6E14ED4A40ECBE6378EC974D4024D3A1D3F3F24A405D16139B8F9F4D4024D3A1D3F3F24A405D16139B8F9F4D40F60D4C6E14ED4A40ECBE6378EC974D40F60D4C6E14ED4A40
34229	Березовка	6	58	\N	60.251469999999998	60.261639000000002	52.557352000000002	52.549495	0103000020E610000001000000050000006AF6402B30204E40632827DA55464A406AF6402B30204E401B2E724F57474A40D82D02637D214E401B2E724F57474A40D82D02637D214E40632827DA55464A406AF6402B30204E40632827DA55464A40
55177	Баландино	6	58	\N	60.652316999999996	60.669024999999998	53.715850000000003	53.706076000000003	0103000020E61000000100000005000000FACF9A1F7F534E40C93EC8B260DA4A40FACF9A1F7F534E40BA6B09F9A0DB4A406B9A779CA2554E40BA6B09F9A0DB4A406B9A779CA2554E40C93EC8B260DA4A40FACF9A1F7F534E40C93EC8B260DA4A40
55100	Аша	6	58	\N	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
5091	Летягино	6	58	731	61.122853999999997	61.133760000000002	54.406359000000002	54.401024	0103000020E6100000010000000500000065170CAEB98F4E409F7422C154334B4065170CAEB98F4E40B7B75B9203344B40A9C1340C1F914E40B7B75B9203344B40A9C1340C1F914E409F7422C154334B4065170CAEB98F4E409F7422C154334B40
29960	Тюбеляс	6	58	1876	58.468000000000004	58.497976999999999	54.989936	54.970933000000002	0103000020E6100000010000000500000096438B6CE73B4D40B8CD5488477C4B4096438B6CE73B4D4008910C39B67E4B408194D8B5BD3F4D4008910C39B67E4B408194D8B5BD3F4D40B8CD5488477C4B4096438B6CE73B4D40B8CD5488477C4B40
30008	Минка	6	58	1876	58.237985999999999	58.260129999999997	55.013326999999997	54.995435999999998	0103000020E61000000100000005000000F3734353761E4D406AA164726A7F4B40F3734353761E4D40AF93FAB2B4814B40AF5A99F04B214D40AF93FAB2B4814B40AF5A99F04B214D406AA164726A7F4B40F3734353761E4D406AA164726A7F4B40
29816	Малый Бердяш	6	58	1876	58.090159999999997	58.106653000000001	54.921686000000001	54.916629999999998	0103000020E6100000010000000500000024B4E55C8A0B4D402844C02154754B4024B4E55C8A0B4D402D978DCEF9754B40998235CEA60D4D402D978DCEF9754B40998235CEA60D4D402844C02154754B4024B4E55C8A0B4D402844C02154754B40
30050	Вергаза	6	58	1876	58.212716999999998	58.223272000000001	55.119985999999997	55.109960999999998	0103000020E61000000100000005000000D026874F3A1B4D40F06AB933138E4B40D026874F3A1B4D402AFD84B35B8F4B40670E492D941C4D402AFD84B35B8F4B40670E492D941C4D40F06AB933138E4B40D026874F3A1B4D40F06AB933138E4B40
20590	Чукса	6	58	1626	60.754275	60.768594999999998	54.502502	54.493910999999997	0103000020E610000001000000050000005F984C158C604E403C11C479383F4B405F984C158C604E4059164CFC51404B403F6F2A5261624E4059164CFC51404B403F6F2A5261624E403C11C479383F4B405F984C158C604E403C11C479383F4B40
20902	Новый Кумляк	6	58	1626	60.44238	60.452252999999999	54.475175999999998	54.464832000000001	0103000020E61000000100000005000000C63368E89F384E4030116F9D7F3B4B40C63368E89F384E400BEC3191D23C4B404A42226DE3394E400BEC3191D23C4B404A42226DE3394E4030116F9D7F3B4B40C63368E89F384E4030116F9D7F3B4B40
20486	Кочкарь	6	58	1626	60.789624000000003	60.814596999999999	54.444335000000002	54.435580000000002	0103000020E610000001000000050000008011346612654E405665DF15C1374B408011346612654E40EDBB22F8DF384B40B935E9B644684E40EDBB22F8DF384B40B935E9B644684E405665DF15C1374B408011346612654E405665DF15C1374B40
20703	Котлик	6	58	1626	60.578502	60.591383999999998	54.48977	54.482619999999997	0103000020E61000000100000005000000D655815A0C4A4E40A032FE7DC63D4B40D655815A0C4A4E40ED478AC8B03E4B4057B08D78B24B4E40ED478AC8B03E4B4057B08D78B24B4E40A032FE7DC63D4B40D655815A0C4A4E40A032FE7DC63D4B40
20614	Демарино	6	58	1626	60.646701999999998	60.681888999999998	54.459991000000002	54.446784999999998	0103000020E61000000100000005000000FF209221C7524E40F3AB394030394B40FF209221C7524E4028BA2EFCE03A4B404640852348574E4028BA2EFCE03A4B404640852348574E40F3AB394030394B40FF209221C7524E40F3AB394030394B40
21060	Верхняя Санарка	6	58	1626	60.539954999999999	60.570264000000002	54.212119000000001	54.194248999999999	0103000020E61000000100000005000000E527D53E1D454E40EE23B726DD184B40E527D53E1D454E401CEE23B7261B4B40070B2769FE484E401CEE23B7261B4B40070B2769FE484E40EE23B726DD184B40E527D53E1D454E40EE23B726DD184B40
21010	Борисовка	6	58	1626	60.656996999999997	60.680658000000001	54.277267999999999	54.261266999999997	0103000020E61000000100000005000000F9484A7A18544E401343723271214B40F9484A7A18544E40191D90847D234B4061E124CD1F574E40191D90847D234B4061E124CD1F574E401343723271214B40F9484A7A18544E401343723271214B40
55207	Устиново	6	58	1318	59.965150000000001	59.982532999999997	54.833691999999999	54.819040999999999	0103000020E6100000010000000500000001DE02098AFB4D40A48AE255D6684B4001DE02098AFB4D40EA77616BB66A4B40D11E2FA4C3FD4D40EA77616BB66A4B40D11E2FA4C3FD4D40A48AE255D6684B4001DE02098AFB4D40A48AE255D6684B40
55131	Нижний Атлян	6	58	1318	59.866245999999997	59.885137	55.000197999999997	54.984920000000002	0103000020E6100000010000000500000039252026E1EE4D409296CADB117E4B4039252026E1EE4D4026C3F17C06804B4062BD512B4CF14D4026C3F17C06804B4062BD512B4CF14D409296CADB117E4B4039252026E1EE4D409296CADB117E4B40
13929	Мухаметово	6	58	1318	60.262833999999998	60.270685	55.413049999999998	55.404862000000001	0103000020E610000001000000050000007023658BA4214E4053B29C84D2B34B407023658BA4214E4070CE88D2DEB44B4046425BCEA5224E4070CE88D2DEB44B4046425BCEA5224E4053B29C84D2B34B407023658BA4214E4053B29C84D2B34B40
31201	Увильды	6	58	1912	60.466033000000003	60.475079000000001	55.584792	55.575561	0103000020E61000000100000005000000ABED26F8A63B4E4031ED9BFBABC94B40ABED26F8A63B4E40317BD976DACA4B4019028063CF3C4E40317BD976DACA4B4019028063CF3C4E4031ED9BFBABC94B40ABED26F8A63B4E4031ED9BFBABC94B40
55175	Слюдорудник	6	58	1912	60.341104000000001	60.374341999999999	55.676783	55.665537999999998	0103000020E610000001000000050000007444BE4BA92B4E40641F645930D54B407444BE4BA92B4E4090BE49D3A0D64B4076C24B70EA2F4E4090BE49D3A0D64B4076C24B70EA2F4E40641F645930D54B407444BE4BA92B4E40641F645930D54B40
55203	Северный	6	58	1912	60.466858999999999	60.492398999999999	55.859408000000002	55.841746000000001	0103000020E61000000100000005000000F06B2409C23B4E40F8C43A55BEEB4B40F06B2409C23B4E40DCF5D21401EE4B40A3CA30EE063F4E40DCF5D21401EE4B40A3CA30EE063F4E40F8C43A55BEEB4B40F06B2409C23B4E40F8C43A55BEEB4B40
45733	Шумаки	6	58	6956	61.245913999999999	61.268157000000002	54.876035000000002	54.868724999999998	0103000020E6100000010000000500000074D0251C7A9F4E40DA1B7C61326F4B4074D0251C7A9F4E40609335EA21704B40C498F4F752A24E40609335EA21704B40C498F4F752A24E40DA1B7C61326F4B4074D0251C7A9F4E40DA1B7C61326F4B40
55098	Роза	6	58	6956	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
45715	Дубровка-Челябинская	6	58	6956	61.312128999999999	61.327643000000002	54.966307999999998	54.934091000000002	0103000020E610000001000000050000000C91D3D7F3A74E40753E3C4B90774B400C91D3D7F3A74E407CEE04FBAF7B4B40B5E1B034F0A94E407CEE04FBAF7B4B40B5E1B034F0A94E40753E3C4B90774B400C91D3D7F3A74E40753E3C4B90774B40
13431	Красный Камень	6	58	1282	60.423811999999998	60.444006000000002	55.533231000000001	55.525700000000001	0103000020E6100000010000000500000080D3BB783F364E40ECC039234AC34B4080D3BB783F364E40501BD5E940C44B40289D4830D5384E40501BD5E940C44B40289D4830D5384E40ECC039234AC34B4080D3BB783F364E40ECC039234AC34B40
55200	Веселовка	6	58	7347	59.550075	59.561852000000002	54.973697999999999	54.963098000000002	0103000020E6100000010000000500000071AC8BDB68C64D40E86B96CB467B4B4071AC8BDB68C64D401E17D522A27C4B409A982EC4EAC74D401E17D522A27C4B409A982EC4EAC74D40E86B96CB467B4B4071AC8BDB68C64D40E86B96CB467B4B40
47851	Красногорский	6	58	1659	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
21196	Зауральский	6	58	1659	61.220753000000002	61.258257	54.796947000000003	54.771189999999997	0103000020E6100000010000000500000038BF61A2419C4E4049809A5AB6624B4038BF61A2419C4E409AD2FA5B02664B40467BBC900EA14E409AD2FA5B02664B40467BBC900EA14E4049809A5AB6624B4038BF61A2419C4E4049809A5AB6624B40
55201	Силач	6	58	1031	60.173344	60.291553	56.082908000000003	56.001801	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
55103	Нижний Уфалей	6	58	1031	60.173344	60.291553	56.082908000000003	56.001801	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
8980	Верхний Уфалей	6	58	1031	60.173344	60.291553	56.082908000000003	56.001801	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
6222	Чесма	6	58	840	60.634323000000002	60.680416000000001	53.822569999999999	53.790858999999998	0103000020E61000000100000005000000E10CFE7E31514E40A65F22DE3AE54A40E10CFE7E31514E40DA5548F949E94A406BD619DF17574E40DA5548F949E94A406BD619DF17574E40A65F22DE3AE54A40E10CFE7E31514E40A65F22DE3AE54A40
19146	Черноборский	6	58	840	60.489623000000002	60.515673999999997	53.933788	53.921695	0103000020E61000000100000005000000492F6AF7AB3E4E4080F10C1AFAF54A40492F6AF7AB3E4E40D9B27C5D86F74A40E1B20A9B01424E40D9B27C5D86F74A40E1B20A9B01424E4080F10C1AFAF54A40492F6AF7AB3E4E4080F10C1AFAF54A40
46939	Цвиллинга	6	58	840	61.166207	61.186509000000001	53.846507000000003	53.836312	0103000020E61000000100000005000000E2AE5E4546954E404DA088450CEB4A40E2AE5E4546954E40E46A64575AEC4A4070B4E386DF974E40E46A64575AEC4A4070B4E386DF974E404DA088450CEB4A40E2AE5E4546954E404DA088450CEB4A40
19907	Углицкий	6	58	840	60.288013999999997	60.309590999999998	53.826216000000002	53.813032999999997	0103000020E6100000010000000500000023658BA4DD244E40CDC8207711E84A4023658BA4DD244E404AB72572C1E94A4066118AADA0274E404AB72572C1E94A4066118AADA0274E40CDC8207711E84A4023658BA4DD244E40CDC8207711E84A40
47419	Тарутино	6	58	840	61.014651999999998	61.048006999999998	53.806877	53.782102000000002	0103000020E610000001000000050000001669E21DE0814E406F1118EB1BE44A401669E21DE0814E408272DBBE47E74A40527DE71725864E408272DBBE47E74A40527DE71725864E406F1118EB1BE44A401669E21DE0814E406F1118EB1BE44A40
46248	Тарасовка	6	58	840	60.640773000000003	60.660679999999999	53.904814000000002	53.888795999999999	0103000020E61000000100000005000000759483D904524E4066683C11C4F14A40759483D904524E40427BF5F1D0F34A40868F882991544E40427BF5F1D0F34A40868F882991544E4066683C11C4F14A40759483D904524E4066683C11C4F14A40
47242	Светлое	6	58	840	60.358235000000001	60.382930000000002	53.702100000000002	53.683295000000001	0103000020E610000001000000050000002BA4FCA4DA2D4E409A42E73576D74A402BA4FCA4DA2D4E40C442AD69DED94A402254A9D903314E40C442AD69DED94A402254A9D903314E409A42E73576D74A402BA4FCA4DA2D4E409A42E73576D74A40
19240	Редутово	6	58	840	60.754930999999999	60.771307	53.682873999999998	53.667630000000003	0103000020E6100000010000000500000048DE3994A1604E400CEA5BE674D54A4048DE3994A1604E40F4A44C6A68D74A4083161230BA624E40F4A44C6A68D74A4083161230BA624E400CEA5BE674D54A4048DE3994A1604E400CEA5BE674D54A40
55241	Порт-Артур	6	58	840	60.314926999999997	60.327342000000002	53.500574	53.494591	0103000020E610000001000000050000004ED026874F284E40AEF204C24EBF4A404ED026874F284E402C9D0FCF12C04A40BA4DB857E6294E402C9D0FCF12C04A40BA4DB857E6294E40AEF204C24EBF4A404ED026874F284E40AEF204C24EBF4A40
47112	Новый Путь	6	58	840	60.401229000000001	60.414326000000003	53.786034000000001	53.778675999999997	0103000020E61000000100000005000000789ACC785B334E400D17B9A7ABE34A40789ACC785B334E40A4C519C39CE44A40F6F065A208354E40A4C519C39CE44A40F6F065A208354E400D17B9A7ABE34A40789ACC785B334E400D17B9A7ABE34A40
20071	Новоукраинский	6	58	840	60.871963999999998	60.887521999999997	53.760502000000002	53.745552000000004	0103000020E6100000010000000500000009A52F849C6F4E40D4BB783F6EDF4A4009A52F849C6F4E407445292158E14A40813D26529A714E407445292158E14A40813D26529A714E40D4BB783F6EDF4A4009A52F849C6F4E40D4BB783F6EDF4A40
10141	Новотемирский	6	58	840	60.140788999999998	60.151361999999999	53.685668	53.679738	0103000020E610000001000000050000007A51BB5F05124E409AEC9FA701D74A407A51BB5F05124E40F5F411F8C3D74A40B7ED7BD45F134E40F5F411F8C3D74A40B7ED7BD45F134E409AEC9FA701D74A407A51BB5F05124E409AEC9FA701D74A40
20013	Новоеткульский	6	58	840	60.870401000000001	60.903018000000003	53.869869000000001	53.855525999999998	0103000020E61000000100000005000000EEB3CA4C696F4E4058703FE081ED4A40EEB3CA4C696F4E40F1660DDE57EF4A4084D9041896734E40F1660DDE57EF4A4084D9041896734E4058703FE081ED4A40EEB3CA4C696F4E4058703FE081ED4A40
9687	Натальинский	6	58	840	60.403779999999998	60.414316999999997	53.565514	53.558824000000001	0103000020E61000000100000005000000B2632310AF334E40261C7A8B87C74A40B2632310AF334E400FB743C362C84A40A296E65608354E400FB743C362C84A40A296E65608354E40261C7A8B87C74A40B2632310AF334E40261C7A8B87C74A40
47197	Московский	6	58	840	60.575924000000001	60.589129	53.529915000000003	53.525306	0103000020E61000000100000005000000A27DACE0B7494E4040321D3A3DC34A40A27DACE0B7494E4076543541D4C34A4006103E94684B4E4076543541D4C34A4006103E94684B4E4040321D3A3DC34A40A27DACE0B7494E4040321D3A3DC34A40
47381	Луговой	6	58	840	61.111113000000003	61.122521999999996	53.775877000000001	53.767890000000001	0103000020E610000001000000050000008A9466F3388E4E40757632384AE24A408A9466F3388E4E40FB5B02F04FE34A402F8507CDAE8F4E40FB5B02F04FE34A402F8507CDAE8F4E40757632384AE24A408A9466F3388E4E40757632384AE24A40
19944	Клубовка	6	58	840	60.916421	60.932581999999996	53.684106	53.675466	0103000020E610000001000000050000000E2F88484D754E40ACC77DAB75D64A400E2F88484D754E40AA7F10C990D74A404C6BD3D85E774E40AA7F10C990D74A404C6BD3D85E774E40ACC77DAB75D64A400E2F88484D754E40ACC77DAB75D64A40
47270	Климовка	6	58	840	60.108826999999998	60.122067999999999	53.801006000000001	53.787146	0103000020E61000000100000005000000FDF50A0BEE0D4E40AF963B33C1E44A40FDF50A0BEE0D4E402CF3565D87E64A40AEF199EC9F0F4E402CF3565D87E64A40AEF199EC9F0F4E40AF963B33C1E44A40FDF50A0BEE0D4E40AF963B33C1E44A40
19054	Камышный	6	58	840	61.086311000000002	61.117401000000001	53.875245999999997	53.86844	0103000020E610000001000000050000007D24253D0C8B4E40E544BB0A29EF4A407D24253D0C8B4E4037FA980F08F04A4044C2F7FE068F4E4037FA980F08F04A4044C2F7FE068F4E40E544BB0A29EF4A407D24253D0C8B4E40E544BB0A29EF4A40
47103	Калиновский	6	58	840	60.481152000000002	60.495263999999999	53.782798999999997	53.771253000000002	0103000020E61000000100000005000000D7338463963D4E4090F8156BB8E24A40D7338463963D4E40B62BF4C132E44A406D718DCF643F4E40B62BF4C132E44A406D718DCF643F4E4090F8156BB8E24A40D7338463963D4E4090F8156BB8E24A40
47256	Зеленая Долина	6	58	840	60.138202	60.149304999999998	53.845348999999999	53.833745999999998	0103000020E61000000100000005000000F31E679AB0114E40DD955D30B8EA4A40F31E679AB0114E40685A626534EC4A408C101E6D1C134E40685A626534EC4A408C101E6D1C134E40DD955D30B8EA4A40F31E679AB0114E40DD955D30B8EA4A40
19040	Бускульский	6	58	840	61.154017000000003	61.161203	53.802059	53.790640000000003	0103000020E6100000010000000500000097033DD4B6934E40697407B133E54A4097033DD4B6934E40323B8BDEA9E64A403082C64CA2944E40323B8BDEA9E64A403082C64CA2944E40697407B133E54A4097033DD4B6934E40697407B133E54A40
22327	Березинский	6	58	840	60.291868000000001	60.316597999999999	53.660640000000001	53.650207999999999	0103000020E61000000100000005000000DD5F3DEE5B254E407DCC07043AD34A40DD5F3DEE5B254E40F836FDD98FD44A4050FD834886284E40F836FDD98FD44A4050FD834886284E407DCC07043AD34A40DD5F3DEE5B254E407DCC07043AD34A40
47077	Беловка	6	58	840	60.536307999999998	60.554831	53.761944	53.748767999999998	0103000020E61000000100000005000000A54A94BDA5444E404A253CA1D7DF4A40A54A94BDA5444E4014B1886187E14A404BE7C3B304474E4014B1886187E14A404BE7C3B304474E404A253CA1D7DF4A40A54A94BDA5444E404A253CA1D7DF4A40
47171	Баландино	6	58	840	60.652316999999996	60.669024999999998	53.715850000000003	53.706076000000003	0103000020E61000000100000005000000FACF9A1F7F534E40C93EC8B260DA4A40FACF9A1F7F534E40BA6B09F9A0DB4A406B9A779CA2554E40BA6B09F9A0DB4A406B9A779CA2554E40C93EC8B260DA4A40FACF9A1F7F534E40C93EC8B260DA4A40
55114	Чурилово	6	58	7348	61.206910000000001	61.219172	55.024692999999999	55.012852000000002	0103000020E61000000100000005000000919BE1067C9A4E4017D86322A5814B40919BE1067C9A4E4056B8E52329834B407619FED30D9C4E4056B8E52329834B407619FED30D9C4E4017D86322A5814B40919BE1067C9A4E4017D86322A5814B40
30195	Щапино	6	58	812	60.616661999999998	60.627056000000003	54.892017000000003	54.876334999999997	0103000020E61000000100000005000000CD57C9C7EE4E4E408AABCABE2B704B40CD57C9C7EE4E4E40EF3CF19C2D724B405B61FA5E43504E40EF3CF19C2D724B405B61FA5E43504E408AABCABE2B704B40CD57C9C7EE4E4E408AABCABE2B704B40
30533	Шахматово	6	58	812	60.623094000000002	60.646881999999998	54.992058999999998	54.978043	0103000020E61000000100000005000000BB2A508BC14F4E40768A5583307D4B40BB2A508BC14F4E40EA5910CAFB7E4B407F2F8507CD524E40EA5910CAFB7E4B407F2F8507CD524E40768A5583307D4B40BB2A508BC14F4E40768A5583307D4B40
53076	Шабунина	6	58	812	60.621118000000003	60.639282000000001	54.604227999999999	54.595512999999997	0103000020E610000001000000050000007D7A6CCB804F4E40E2AB1DC5394C4B407D7A6CCB804F4E40EBA9D557574D4B40F37519FED3514E40EBA9D557574D4B40F37519FED3514E40E2AB1DC5394C4B407D7A6CCB804F4E40E2AB1DC5394C4B40
30350	Филимоново	6	58	812	60.061387000000003	60.094112000000003	54.721285999999999	54.708831000000004	0103000020E6100000010000000500000025B37A87DB074E400CB265F9BA5A4B4025B37A87DB074E4005888219535C4B40A114ADDC0B0C4E4005888219535C4B40A114ADDC0B0C4E400CB265F9BA5A4B4025B37A87DB074E400CB265F9BA5A4B40
29390	Уштаганка	6	58	812	60.252324000000002	60.270702999999997	54.709007999999997	54.702578000000003	0103000020E610000001000000050000007AFF1F274C204E40CE716E13EE594B407AFF1F274C204E401A4D2EC6C05A4B40ECF65965A6224E401A4D2EC6C05A4B40ECF65965A6224E40CE716E13EE594B407AFF1F274C204E40CE716E13EE594B40
6977	Травники	6	58	812	60.534053	60.583443000000003	54.913567	54.903505000000003	0103000020E6100000010000000500000054AA44D95B444E40E162450DA6734B4054AA44D95B444E4038DA71C3EF744B40420A9E42AE4A4E4038DA71C3EF744B40420A9E42AE4A4E40E162450DA6734B4054AA44D95B444E40E162450DA6734B40
53059	Тимирязевский	6	58	812	60.751975999999999	60.792589	54.937350000000002	54.915998999999999	0103000020E610000001000000050000003EB0E3BF40604E4098158A743F754B403EB0E3BF40604E40EB73B515FB774B40AD156D8E73654E40EB73B515FB774B40AD156D8E73654E4098158A743F754B403EB0E3BF40604E4098158A743F754B40
30404	Темир	6	58	812	60.153581000000003	60.180197999999997	54.706074000000001	54.696725000000001	0103000020E61000000100000005000000BC24CE8AA8134E401EA7E8482E594B40BC24CE8AA8134E40284701A2605A4B40FD6662BA10174E40284701A2605A4B40FD6662BA10174E401EA7E8482E594B40BC24CE8AA8134E401EA7E8482E594B40
29672	Ступино	6	58	812	60.365979000000003	60.378295000000001	54.832354000000002	54.824824	0103000020E61000000100000005000000EB025E66D82E4E405B7A34D593694B40EB025E66D82E4E40EF586C938A6A4B40C39E76F86B304E40EF586C938A6A4B40C39E76F86B304E405B7A34D593694B40EB025E66D82E4E405B7A34D593694B40
55187	Спутник	6	58	812	60.520426	60.539093000000001	54.900937999999996	54.896289000000003	0103000020E610000001000000050000007AFEB4519D424E40DD611399B9724B407AFEB4519D424E40A0DCB6EF51734B405340DAFF00454E40A0DCB6EF51734B405340DAFF00454E40DD611399B9724B407AFEB4519D424E40DD611399B9724B40
29585	Сарафаново	6	58	812	60.253374999999998	60.278616999999997	54.898426999999998	54.883701000000002	0103000020E61000000100000005000000DF4F8D976E204E40A438471D1D714B40DF4F8D976E204E40F46BEBA7FF724B40088ECBB8A9234E40F46BEBA7FF724B40088ECBB8A9234E40A438471D1D714B40DF4F8D976E204E40A438471D1D714B40
29888	Самарка	6	58	812	60.902399000000003	60.913708	54.917825999999998	54.909633999999997	0103000020E61000000100000005000000B87878CF81734E4032AA0CE36E744B40B87878CF81734E4091B586527B754B40FA0B3D62F4744E4091B586527B754B40FA0B3D62F4744E4032AA0CE36E744B40B87878CF81734E4032AA0CE36E744B40
30108	Пустозерово	6	58	812	60.406331000000002	60.423434999999998	54.929290999999999	54.922725999999997	0103000020E61000000100000005000000ED2C7AA702344E409E95B4E21B764B40ED2C7AA702344E40CBBBEA01F3764B40AA7D3A1E33364E40CBBBEA01F3764B40AA7D3A1E33364E409E95B4E21B764B40ED2C7AA702344E409E95B4E21B764B40
28902	Попово	6	58	812	60.708578000000003	60.727065000000003	54.648000000000003	54.638506999999997	0103000020E61000000100000005000000225514AFB25A4E402FA2ED98BA514B40225514AFB25A4E406DE7FBA9F1524B407B884677105D4E406DE7FBA9F1524B407B884677105D4E402FA2ED98BA514B40225514AFB25A4E402FA2ED98BA514B40
53055	Половинка	6	58	812	60.37021	60.385733000000002	54.774617999999997	54.764760000000003	0103000020E610000001000000050000007A53910A632F4E40FDA4DAA7E3614B407A53910A632F4E404B72C0AE26634B4076FEEDB25F314E404B72C0AE26634B4076FEEDB25F314E40FDA4DAA7E3614B407A53910A632F4E40FDA4DAA7E3614B40
29542	Нижние Караси	6	58	812	60.541429000000001	60.556421	55.137841999999999	55.127172000000002	0103000020E61000000100000005000000910DA48B4D454E40C47B0E2C47904B40910DA48B4D454E40F30181CEA4914B4060E7A6CD38474E40F30181CEA4914B4060E7A6CD38474E40C47B0E2C47904B40910DA48B4D454E40C47B0E2C47904B40
29444	Непряхино	6	58	812	60.398775999999998	60.433289000000002	55.089340999999997	55.071731	0103000020E6100000010000000500000000378B170B334E40008E3D7B2E894B4000378B170B334E409198A0866F8B4B40B85B920376374E409198A0866F8B4B40B85B920376374E40008E3D7B2E894B4000378B170B334E40008E3D7B2E894B40
28764	Мирный	6	58	812	60.902982999999999	60.918244999999999	55.017065000000002	55.000487	0103000020E6100000010000000500000007EC6AF294734E405D8940F50F804B4007EC6AF294734E400074982F2F824B40965B5A0D89754E400074982F2F824B40965B5A0D89754E405D8940F50F804B4007EC6AF294734E405D8940F50F804B40
30261	Мельниково	6	58	812	60.436802	60.453268000000001	54.881504999999997	54.871715000000002	0103000020E61000000100000005000000E869C020E9374E4061376C5B946F4B40E869C020E9374E405721E527D5704B40632992AF043A4E405721E527D5704B40632992AF043A4E4061376C5B946F4B40E869C020E9374E4061376C5B946F4B40
55205	Меведево	6	58	812	60.758640999999997	60.782508999999997	54.972282	54.956243999999998	0103000020E61000000100000005000000CE33F6251B614E40847F1134667A4B40CE33F6251B614E40A73E90BC737C4B40AFE9414129644E40A73E90BC737C4B40AFE9414129644E40847F1134667A4B40CE33F6251B614E40847F1134667A4B40
30049	Маскайка	6	58	812	60.524909000000001	60.552962999999998	54.799334000000002	54.786451	0103000020E610000001000000050000002330D63730434E400874266DAA644B402330D63730434E405A4A969350664B40F372D87DC7464E405A4A969350664B40F372D87DC7464E400874266DAA644B402330D63730434E400874266DAA644B40
53060	Малково	6	58	812	60.347752	60.368735999999998	54.945872000000001	54.929177000000003	0103000020E610000001000000050000002E8F3523832C4E4003999D45EF764B402E8F3523832C4E40DF196D5512794B40CE6DC2BD322F4E40DF196D5512794B40CE6DC2BD322F4E4003999D45EF764B402E8F3523832C4E4003999D45EF764B40
29096	Кундравы	6	58	812	60.207839	60.235885000000003	54.845554999999997	54.808213000000002	0103000020E61000000100000005000000ABEAE5779A1A4E40DD99098673674B40ABEAE5779A1A4E4011FC6F253B6C4B40F94ECC7A311E4E4011FC6F253B6C4B40F94ECC7A311E4E40DD99098673674B40ABEAE5779A1A4E40DD99098673674B40
29317	Крыжановка	6	58	812	60.379866999999997	60.397607999999998	54.720382000000001	54.711779999999997	0103000020E6100000010000000500000031EA5A7B9F304E4033F9669B1B5B4B4031EA5A7B9F304E404450357A355C4B406150A6D1E4324E404450357A355C4B406150A6D1E4324E4033F9669B1B5B4B4031EA5A7B9F304E4033F9669B1B5B4B40
29879	Коротаново	6	58	812	60.780909999999999	60.791007999999998	54.849930000000001	54.842143999999998	0103000020E61000000100000005000000478FDFDBF4634E40E542E55FCB6B4B40478FDFDBF4634E40D4F19881CA6C4B40EB6F09C03F654E40D4F19881CA6C4B40EB6F09C03F654E40E542E55FCB6B4B40478FDFDBF4634E40E542E55FCB6B4B40
29072	Колотовка	6	58	812	60.695714000000002	60.713070000000002	54.711879000000003	54.700622000000003	0103000020E6100000010000000500000047AF06280D594E40D76D50FBAD594B4047AF06280D594E40C7DADFD91E5B4B401EE1B4E0455B4E40C7DADFD91E5B4B401EE1B4E0455B4E40D76D50FBAD594B4047AF06280D594E40D76D50FBAD594B40
28821	Ключи	6	58	812	60.758560000000003	60.772807999999998	55.016466000000001	55.009228	0103000020E61000000100000005000000E2067C7E18614E408F1A13622E814B40E2067C7E18614E407BBFD18E1B824B40280B5F5FEB624E407BBFD18E1B824B40280B5F5FEB624E408F1A13622E814B40E2067C7E18614E408F1A13622E814B40
29272	Ключевка 2-я	6	58	812	60.495066999999999	60.517749000000002	54.717157	54.707670999999998	0103000020E61000000100000005000000172AFF5A5E3F4E40EFA99CF6945A4B40172AFF5A5E3F4E407A8CF2CCCB5B4B40B344679945424E407A8CF2CCCB5B4B40B344679945424E40EFA99CF6945A4B40172AFF5A5E3F4E40EFA99CF6945A4B40
30257	Камбулат	6	58	812	60.558864999999997	60.578995999999997	54.852983000000002	54.847447000000003	0103000020E6100000010000000500000084F068E388474E40F20BAF24796C4B4084F068E388474E40A185048C2E6D4B40E5417A8A1C4A4E40A185048C2E6D4B40E5417A8A1C4A4E40F20BAF24796C4B4084F068E388474E40F20BAF24796C4B40
29053	Звягино	6	58	812	60.738554999999998	60.762144999999997	54.750337999999999	54.736243999999999	0103000020E610000001000000050000000DA661F8885E4E4028F04E3E3D5E4B400DA661F8885E4E40187959130B604B40ABE7A4F78D614E40187959130B604B40ABE7A4F78D614E4028F04E3E3D5E4B400DA661F8885E4E4028F04E3E3D5E4B40
30453	Зауралово	6	58	812	60.200814000000001	60.210183999999998	54.665010000000002	54.645587999999996	0103000020E610000001000000050000001B4AED45B4194E405358A9A0A2524B401B4AED45B4194E40A9C1340C1F554B403C122F4FE71A4E40A9C1340C1F554B403C122F4FE71A4E405358A9A0A2524B401B4AED45B4194E405358A9A0A2524B40
30661	Запивалово	6	58	812	60.607266000000003	60.624091999999997	54.971196999999997	54.958647999999997	0103000020E6100000010000000500000083FC6CE4BA4D4E401A3048FAB47A4B4083FC6CE4BA4D4E40957CEC2E507C4B40FDD8243FE24F4E40957CEC2E507C4B40FDD8243FE24F4E401A3048FAB47A4B4083FC6CE4BA4D4E401A3048FAB47A4B40
29626	Десятилетие	6	58	812	60.294804999999997	60.308154000000002	54.911445000000001	54.902346000000001	0103000020E6100000010000000500000040D9942BBC254E4095D6DF1280734B4040D9942BBC254E40268DD13AAA744B40D8101C9771274E40268DD13AAA744B40D8101C9771274E4095D6DF1280734B4040D9942BBC254E4095D6DF1280734B40
29496	Верхние Караси	6	58	812	60.409025999999997	60.432794999999999	55.149213000000003	55.141978999999999	0103000020E610000001000000050000005A9BC6F65A344E4001DC2C5E2C924B405A9BC6F65A344E40AC915D6919934B40A86F99D365374E40AC915D6919934B40A86F99D365374E4001DC2C5E2C924B405A9BC6F65A344E4001DC2C5E2C924B40
28890	Варламово	6	58	812	60.657015000000001	60.687108000000002	54.636043000000001	54.614902000000001	0103000020E61000000100000005000000A0FD481119544E405C1FD61BB54E4B40A0FD481119544E40C4EC65DB69514B40F568AA27F3574E40C4EC65DB69514B40F568AA27F3574E405C1FD61BB54E4B40A0FD481119544E405C1FD61BB54E4B40
29147	Бутырки	6	58	812	60.195649000000003	60.211413999999998	54.850344	54.844762000000003	0103000020E61000000100000005000000603FC4060B194E40A8734529216C4B40603FC4060B194E40C72C7B12D86C4B4051F52B9D0F1B4E40C72C7B12D86C4B4051F52B9D0F1B4E40A8734529216C4B40603FC4060B194E40A8734529216C4B40
29729	Боровое	6	58	812	60.317810999999999	60.336998999999999	54.932859999999998	54.923119	0103000020E610000001000000050000008FA7E507AE284E407AA86DC328764B408FA7E507AE284E408FDFDBF467774B4071E481C8222B4E408FDFDBF467774B4071E481C8222B4E407AA86DC328764B408FA7E507AE284E407AA86DC328764B40
53057	Большаково	6	58	812	60.416257000000002	60.434798999999998	54.651609999999998	54.643697000000003	0103000020E6100000010000000500000094DDCCE847354E4044C4CDA964524B4094DDCCE847354E408FDFDBF467534B40B0AA5E7EA7374E408FDFDBF467534B40B0AA5E7EA7374E4044C4CDA964524B4094DDCCE847354E4044C4CDA964524B40
29354	Болотово	6	58	812	60.237698999999999	60.259115000000001	54.738301999999997	54.726022999999998	0103000020E610000001000000050000005DA5BBEB6C1E4E4068925852EE5C4B405DA5BBEB6C1E4E40234910AE805E4B40977329AE2A214E40234910AE805E4B40977329AE2A214E4068925852EE5C4B405DA5BBEB6C1E4E4068925852EE5C4B40
53054	Бишкиль	6	58	812	60.727290000000004	60.772160999999997	55.016739000000001	54.974411000000003	0103000020E610000001000000050000009B5AB6D6175D4E406CEEE87FB97C4B409B5AB6D6175D4E40ACC8E88024824B40921FF12BD6624E40ACC8E88024824B40921FF12BD6624E406CEEE87FB97C4B409B5AB6D6175D4E406CEEE87FB97C4B40
30021	Барсуки	6	58	812	60.632949000000004	60.650924000000003	54.848757999999997	54.842464999999997	0103000020E6100000010000000500000099840B7904514E402783A3E4D56B4B4099840B7904514E40F31B261AA46C4B403C17467A51534E40F31B261AA46C4B403C17467A51534E402783A3E4D56B4B4099840B7904514E402783A3E4D56B4B40
30592	Барановка	6	58	812	60.503366999999997	60.520183000000003	55.017069999999997	55.003326999999999	0103000020E610000001000000050000005C7171546E404E40CE18E6046D804B405C7171546E404E4011DF89592F824B40B477465B95424E4011DF89592F824B40B477465B95424E40CE18E6046D804B405C7171546E404E40CE18E6046D804B40
30502	Алтынташ	6	58	812	59.915860000000002	59.939351000000002	54.714942000000001	54.706333999999998	0103000020E6100000010000000500000077DB85E63AF54D40C4060B27695A4B4077DB85E63AF54D40B7442E38835B4B40823B50A73CF84D40B7442E38835B4B40823B50A73CF84D40C4060B27695A4B4077DB85E63AF54D40C4060B27695A4B40
27336	Яринка	6	58	941	59.991660000000003	60.003832000000003	54.424796000000001	54.410221	0103000020E610000001000000050000002D6002B7EEFE4D40F390291F82344B402D6002B7EEFE4D405EBC1FB75F364B40D25625917D004E405EBC1FB75F364B40D25625917D004E40F390291F82344B402D6002B7EEFE4D40F390291F82344B40
7670	Фоминский	6	58	941	59.752994999999999	59.761600999999999	54.357647	54.350631	0103000020E610000001000000050000009886E12362E04D405DFB027AE12C4B409886E12362E04D409A417C60C72D4B40EACC3D247CE14D409A417C60C72D4B40EACC3D247CE14D405DFB027AE12C4B409886E12362E04D405DFB027AE12C4B40
26883	Уйское	6	58	941	59.979073999999997	60.018483000000003	54.394399	54.361015000000002	0103000020E61000000100000005000000942EFD4B52FD4D40C72E51BD352E4B40942EFD4B52FD4D409D499BAA7B324B401844A4A65D024E409D499BAA7B324B401844A4A65D024E40C72E51BD352E4B40942EFD4B52FD4D40C72E51BD352E4B40
25570	Токмасский	6	58	941	60.254570000000001	60.271988	54.422407999999997	54.418447	0103000020E610000001000000050000007845F0BF95204E40FE0DDAAB8F354B407845F0BF95204E40CDC8207711364B40C573B680D0224E40CDC8207711364B40C573B680D0224E40FE0DDAAB8F354B407845F0BF95204E40FE0DDAAB8F354B40
26812	Соколовское	6	58	941	60.277495000000002	60.304380999999999	54.559631000000003	54.550618999999998	0103000020E61000000100000005000000DAE6C6F484234E4032C7F2AE7A464B40DAE6C6F484234E40F56915FDA1474B400B43E4F4F5264E40F56915FDA1474B400B43E4F4F5264E4032C7F2AE7A464B40DAE6C6F484234E4032C7F2AE7A464B40
26051	Речной	6	58	941	59.860388999999998	59.878723000000001	54.531073999999997	54.524777999999998	0103000020E61000000100000005000000486B0C3A21EE4D4084D4EDEC2B434B40486B0C3A21EE4D40C1E09A3BFA434B401B9FC9FE79F04D40C1E09A3BFA434B401B9FC9FE79F04D4084D4EDEC2B434B40486B0C3A21EE4D4084D4EDEC2B434B40
26306	Петропавловка	6	58	941	59.800175000000003	59.820261000000002	54.177990000000001	54.164808999999998	0103000020E61000000100000005000000D50968226CE64D40118B187618154B40D50968226CE64D40ED815660C8164B409697FC4FFEE84D40ED815660C8164B409697FC4FFEE84D40118B187618154B40D50968226CE64D40118B187618154B40
27229	Октябрьский	6	58	941	59.867899000000001	59.885981999999998	54.452312999999997	54.444555000000001	0103000020E61000000100000005000000959D7E5017EF4D40FB22A12DE7384B40959D7E5017EF4D401F477364E5394B401E6CB1DB67F14D401F477364E5394B401E6CB1DB67F14D40FB22A12DE7384B40959D7E5017EF4D40FB22A12DE7384B40
26782	Никольское	6	58	941	60.158206999999997	60.180647	54.581876000000001	54.567649000000003	0103000020E61000000100000005000000C77F812040144E40B64DF1B8A8484B40C77F812040144E40E529ABE97A4A4B406D8FDE701F174E40E529ABE97A4A4B406D8FDE701F174E40B64DF1B8A8484B40C77F812040144E40B64DF1B8A8484B40
26138	Нижнеусцелемово	6	58	941	59.989790999999997	60.007587000000001	54.280380000000001	54.271825999999997	0103000020E610000001000000050000000470B378B1FE4D40EB19C231CB224B400470B378B1FE4D40EB39E97DE3234B40F86F5E9CF8004E40EB39E97DE3234B40F86F5E9CF8004E40EB19C231CB224B400470B378B1FE4D40EB19C231CB224B40
26330	Мирный	6	58	941	60.295972999999996	60.316634000000001	54.580179999999999	54.569809999999997	0103000020E61000000100000005000000DFBF7971E2254E408577B988EF484B40DFBF7971E2254E408AE59656434A4B409D66817687284E408AE59656434A4B409D66817687284E408577B988EF484B40DFBF7971E2254E408577B988EF484B40
26080	Маслово	6	58	941	60.014594000000002	60.034716000000003	54.472628	54.462069	0103000020E61000000100000005000000E25B5837DE014E406ABFB513253B4B40E25B5837DE014E40429605137F3C4B40F052EA9271044E40429605137F3C4B40F052EA9271044E406ABFB513253B4B40E25B5837DE014E406ABFB513253B4B40
7616	Магадеево	6	58	941	60.282310000000003	60.294581000000001	54.222099999999998	54.214118999999997	0103000020E61000000100000005000000B9AAECBB22244E40E2395B40681B4B40B9AAECBB22244E408638D6C56D1C4B40F18288D4B4254E408638D6C56D1C4B40F18288D4B4254E40E2395B40681B4B40B9AAECBB22244E40E2395B40681B4B40
26720	Лесной	6	58	941	60.372042	60.388832000000001	54.344140000000003	54.333824999999997	0103000020E61000000100000005000000855E7F129F2F4E4029CB10C7BA2A4B40855E7F129F2F4E406B9F8EC70C2C4B40B3D1393FC5314E406B9F8EC70C2C4B40B3D1393FC5314E4029CB10C7BA2A4B40855E7F129F2F4E4029CB10C7BA2A4B40
26689	Лебедевка	6	58	941	60.318061999999998	60.326228	54.602089999999997	54.591841000000002	0103000020E61000000100000005000000D80C7041B6284E404AB72572C14B4B40D80C7041B6284E40D39FFD48114D4B400E85CFD6C1294E40D39FFD48114D4B400E85CFD6C1294E404AB72572C14B4B40D80C7041B6284E404AB72572C14B4B40
25852	Ларино	6	58	941	59.940581000000002	59.966389999999997	54.590124000000003	54.561019999999999	0103000020E61000000100000005000000971E4DF564F84D407233DC80CF474B40971E4DF564F84D40D84AE82E894B4B403997E2AAB2FB4D40D84AE82E894B4B403997E2AAB2FB4D407233DC80CF474B40971E4DF564F84D407233DC80CF474B40
25812	Кумляк	6	58	941	60.293008	60.320838000000002	54.363343999999998	54.341258000000003	0103000020E61000000100000005000000B2BB404981254E40CBBF9657AE2B4B40B2BB404981254E405299620E822E4B4033A8363811294E405299620E822E4B4033A8363811294E40CBBF9657AE2B4B40B2BB404981254E40CBBF9657AE2B4B40
26634	Краснокаменка	6	58	941	60.220379999999999	60.23133	54.609113999999998	54.597672000000003	0103000020E61000000100000005000000A3586E69351C4E4012DE1E84804C4B40A3586E69351C4E4093C49272F74D4B40B64AB0389C1D4E4093C49272F74D4B40B64AB0389C1D4E4012DE1E84804C4B40A3586E69351C4E4012DE1E84804C4B40
25908	Кочнево	6	58	941	59.954540999999999	59.962769999999999	54.536344999999997	54.524898	0103000020E6100000010000000500000077D844662EFA4D402FDE8FDB2F434B4077D844662EFA4D40C22FF5F3A6444B40F3C81F0C3CFB4D40C22FF5F3A6444B40F3C81F0C3CFB4D402FDE8FDB2F434B4077D844662EFA4D402FDE8FDB2F434B40
25680	Кидыш	6	58	941	60.078400999999999	60.102888999999998	54.155439999999999	54.145257999999998	0103000020E61000000100000005000000A27C410B090A4E40BEBD6BD097124B40A27C410B090A4E40C03E3A75E5134B401F0F7D772B0D4E40C03E3A75E5134B401F0F7D772B0D4E40BEBD6BD097124B40A27C410B090A4E40BEBD6BD097124B40
26597	Зерновой	6	58	941	60.327449999999999	60.341805000000001	54.454825	54.445869000000002	0103000020E61000000100000005000000A089B0E1E9294E406EA6423C12394B40A089B0E1E9294E409C33A2B4373A4B40FD4D2844C02B4E409C33A2B4373A4B40FD4D2844C02B4E406EA6423C12394B40A089B0E1E9294E406EA6423C12394B40
26536	Заозерный	6	58	941	60.349539	60.363194	54.507641	54.500630000000001	0103000020E6100000010000000500000099D6A6B1BD2C4E40C0B2D2A414404B4099D6A6B1BD2C4E40EB8D5A61FA404B403D0D18247D2E4E40EB8D5A61FA404B403D0D18247D2E4E40C0B2D2A414404B4099D6A6B1BD2C4E40C0B2D2A414404B40
55206	Заматохина	6	58	941	59.951082999999997	59.959868	54.493361999999998	54.486668000000002	0103000020E610000001000000050000000A647616BDF94D403F0114234B3E4B400A647616BDF94D40698B6B7C263F4B400C3D62F4DCFA4D40698B6B7C263F4B400C3D62F4DCFA4D403F0114234B3E4B400A647616BDF94D403F0114234B3E4B40
25761	Гусары	6	58	941	60.272697999999998	60.284061000000001	54.185445999999999	54.173490000000001	0103000020E61000000100000005000000A1D79FC4E7224E406E179AEB34164B40A1D79FC4E7224E404696CCB1BC174B40D788601C5C244E404696CCB1BC174B40D788601C5C244E406E179AEB34164B40A1D79FC4E7224E406E179AEB34164B40
27188	Горки	6	58	941	60.009050999999999	60.019542999999999	54.349608000000003	54.341850999999998	0103000020E61000000100000005000000807F4A9528014E406D8D08C6C12B4B40807F4A9528014E40C23577F4BF2C4B40D0EE906280024E40C23577F4BF2C4B40D0EE906280024E406D8D08C6C12B4B40807F4A9528014E406D8D08C6C12B4B40
27141	Глазуновка	6	58	941	59.910711999999997	59.920530999999997	54.327303999999998	54.320887999999997	0103000020E610000001000000050000009109F83592F44D40E4D6A4DB12294B409109F83592F44D40CCECF318E5294B4022FAB5F5D3F54D40CCECF318E5294B4022FAB5F5D3F54D40E4D6A4DB12294B409109F83592F44D40E4D6A4DB12294B40
25988	Выдрино	6	58	941	59.826054999999997	59.841065999999998	54.490136	54.480899000000001	0103000020E6100000010000000500000040D9942BBCE94D40EDD632198E3D4B4040D9942BBCE94D40CF4BC5C6BC3E4B4086E3F90CA8EB4D40CF4BC5C6BC3E4B4086E3F90CA8EB4D40EDD632198E3D4B4040D9942BBCE94D40EDD632198E3D4B40
26513	Восточный	6	58	941	60.510913000000002	60.535527000000002	54.589815999999999	54.583316000000003	0103000020E61000000100000005000000F60CE19865414E40E59D4319AA4A4B40F60CE19865414E402A5437177F4B4B40009013268C444E402A5437177F4B4B40009013268C444E40E59D4319AA4A4B40F60CE19865414E40E59D4319AA4A4B40
21195	Воронино	6	58	941	59.817827000000001	59.837491	54.372906	54.365924999999997	0103000020E6100000010000000500000095641D8EAEE84D40F7E461A1D62E4B4095641D8EAEE84D40B83D4162BB2F4B40E0D8B3E732EB4D40B83D4162BB2F4B40E0D8B3E732EB4D40F7E461A1D62E4B4095641D8EAEE84D40F7E461A1D62E4B40
26219	Вишневка	6	58	941	60.035254999999999	60.058225	54.247928000000002	54.242429999999999	0103000020E610000001000000050000009F02603C83044E40DEC83CF2071F4B409F02603C83044E40A0E1CD1ABC1F4B40A167B3EA73074E40A0E1CD1ABC1F4B40A167B3EA73074E40DEC83CF2071F4B409F02603C83044E40DEC83CF2071F4B40
25634	Вандышевка	6	58	941	60.085560999999998	60.101298999999997	54.343325999999998	54.332276	0103000020E610000001000000050000001268B0A9F30A4E40739F1C05882A4B401268B0A9F30A4E40E9EE3A1BF22B4B400A0F9A5DF70C4E40E9EE3A1BF22B4B400A0F9A5DF70C4E40739F1C05882A4B401268B0A9F30A4E40739F1C05882A4B40
26424	Булатово	6	58	941	60.367083999999998	60.403922999999999	54.568823999999999	54.554295000000003	0103000020E610000001000000050000004371C79BFC2E4E400DAB7823F3464B404371C79BFC2E4E4007978E39CF484B40158DB5BFB3334E4007978E39CF484B40158DB5BFB3334E400DAB7823F3464B404371C79BFC2E4E400DAB7823F3464B40
27064	Брюхово	6	58	941	59.999673000000001	60.009186	54.306790999999997	54.300680999999997	0103000020E61000000100000005000000DCD8EC48F5FF4D40A8C30AB77C264B40DCD8EC48F5FF4D4083DA6FED44274B4060CAC0012D014E4083DA6FED44274B4060CAC0012D014E40A8C30AB77C264B40DCD8EC48F5FF4D40A8C30AB77C264B40
25737	Бирюковский	6	58	941	60.239891	60.251263999999999	54.142383000000002	54.137234999999997	0103000020E6100000010000000500000068CD8FBFB41E4E40EB6E9EEA90114B4068CD8FBFB41E4E40D1402C9B39124B40C154336B29204E40D1402C9B39124B40C154336B29204E40EB6E9EEA90114B4068CD8FBFB41E4E40EB6E9EEA90114B40
26146	Березовка	6	58	941	59.902222999999999	59.912069000000002	54.254246000000002	54.245660999999998	0103000020E610000001000000050000007959130B7CF34D408A73D4D1711F4B407959130B7CF34D40C59107228B204B4004594FADBEF44D40C59107228B204B4004594FADBEF44D408A73D4D1711F4B407959130B7CF34D408A73D4D1711F4B40
25544	Белово	6	58	941	60.125526999999998	60.144112999999997	54.4251	54.41534	0103000020E61000000100000005000000EBE1CB4411104E403E5C72DC29354B40EBE1CB4411104E40CAC342AD69364B40D7F6764B72124E40CAC342AD69364B40D7F6764B72124E403E5C72DC29354B40EBE1CB4411104E403E5C72DC29354B40
25414	Аминево	6	58	941	60.117010999999998	60.130881000000002	54.206147000000001	54.192515999999998	0103000020E61000000100000005000000D9226937FA0E4E4076FA415DA4184B40D9226937FA0E4E4092955F06631A4B407A5567B5C0104E4092955F06631A4B407A5567B5C0104E4076FA415DA4184B40D9226937FA0E4E4076FA415DA4184B40
55164	Хуторка	6	58	439	61.520367999999998	61.534587999999999	54.376939	54.366596999999999	0103000020E6100000010000000500000045F12A6B9BC24E40E6E786A6EC2E4B4045F12A6B9BC24E4021CB82893F304B40C26A2C616DC44E4021CB82893F304B40C26A2C616DC44E40E6E786A6EC2E4B4045F12A6B9BC24E40E6E786A6EC2E4B40
3476	Хомутинино	6	58	439	61.429547999999997	61.451242000000001	54.550409999999999	54.536386999999998	0103000020E61000000100000005000000F607CA6DFBB64E40F17F4754A8444B40F607CA6DFBB64E4018B2BAD573464B40734A404CC2B94E4018B2BAD573464B40734A404CC2B94E40F17F4754A8444B40F607CA6DFBB64E40F17F4754A8444B40
55237	Формачево	6	58	439	61.302984000000002	61.313215999999997	54.537249000000003	54.523634000000001	0103000020E610000001000000050000000B9B012EC8A64E406E895C7006434B400B9B012EC8A64E4084674293C4444B40BE4A3E7617A84E4084674293C4444B40BE4A3E7617A84E406E895C7006434B400B9B012EC8A64E406E895C7006434B40
2418	Увельский	6	58	439	61.331614000000002	61.39331	54.466406999999997	54.383887000000001	0103000020E61000000100000005000000A872DA5372AA4E40062E8F3523314B40A872DA5372AA4E400FD07D39B33B4B404A9869FB57B24E400FD07D39B33B4B404A9869FB57B24E40062E8F3523314B40A872DA5372AA4E40062E8F3523314B40
3370	Синий Бор	6	58	439	61.311715999999997	61.346615999999997	54.55077	54.540925999999999	0103000020E61000000100000005000000E9D1544FE6A74E402EC72B103D454B40E9D1544FE6A74E4018CFA0A17F464B409A22C0E95DAC4E4018CFA0A17F464B409A22C0E95DAC4E402EC72B103D454B40E9D1544FE6A74E402EC72B103D454B40
3675	Рождественка	6	58	439	61.666164000000002	61.700893000000001	54.449993999999997	54.430557999999998	0103000020E61000000100000005000000E3E2A8DC44D54E40FD8348861C374B40E3E2A8DC44D54E40B7B2446799394B40677FA0DCB6D94E40B7B2446799394B40677FA0DCB6D94E40FD8348861C374B40E3E2A8DC44D54E40FD8348861C374B40
3576	Половинка	6	58	439	61.326107	61.345061000000001	54.351438999999999	54.336849000000001	0103000020E6100000010000000500000093FFC9DFBDA94E405C5837DE1D2B4B4093FFC9DFBDA94E40FCC401F4FB2C4B40021077F52AAC4E40FCC401F4FB2C4B40021077F52AAC4E405C5837DE1D2B4B4093FFC9DFBDA94E405C5837DE1D2B4B40
3021	Подгорный	6	58	439	61.029834000000001	61.041106999999997	54.614834000000002	54.603279000000001	0103000020E610000001000000050000008927BB99D1834E408AAE0B3F384D4B408927BB99D1834E40043C69E1B24E4B407E5182FE42854E40043C69E1B24E4B407E5182FE42854E408AAE0B3F384D4B408927BB99D1834E408AAE0B3F384D4B40
3958	Петровское	6	58	439	61.849510000000002	61.875543999999998	54.512020999999997	54.494706000000001	0103000020E61000000100000005000000FFCF61BEBCEC4E404791B586523F4B40FFCF61BEBCEC4E40BFEE74E789414B40C11A67D311F04E40BFEE74E789414B40C11A67D311F04E404791B586523F4B40FFCF61BEBCEC4E404791B586523F4B40
6526	Песчаное	6	58	439	61.411096999999998	61.428677	54.386383000000002	54.371349000000002	0103000020E61000000100000005000000EA3D95D39EB44E407F33315D882F4B40EA3D95D39EB44E407D5D86FF74314B4011C64FE3DEB64E407D5D86FF74314B4011C64FE3DEB64E407F33315D882F4B40EA3D95D39EB44E407F33315D882F4B40
3261	Нагорный	6	58	439	61.260620000000003	61.299616	54.547392000000002	54.536245999999998	0103000020E610000001000000050000007E5704FF5BA14E402F4E7CB5A3444B407E5704FF5BA14E40C80BE9F010464B40DEAD2CD159A64E40C80BE9F010464B40DEAD2CD159A64E402F4E7CB5A3444B407E5704FF5BA14E402F4E7CB5A3444B40
3818	Мордвиновка	6	58	439	61.859445999999998	61.886512000000003	54.356361	54.342601999999999	0103000020E61000000100000005000000C956975302EE4E40A8C5E061DA2B4B40C956975302EE4E40F148BC3C9D2D4B407BC1A73979F14E40F148BC3C9D2D4B407BC1A73979F14E40A8C5E061DA2B4B40C956975302EE4E40A8C5E061DA2B4B40
3896	Михири	6	58	439	61.094009	61.104367000000003	54.643379000000003	54.634968999999998	0103000020E61000000100000005000000CC43A67C088C4E40A67C08AA46514B40CC43A67C088C4E4073F7393E5A524B400DE4D9E55B8D4E4073F7393E5A524B400DE4D9E55B8D4E40A67C08AA46514B40CC43A67C088C4E40A67C08AA46514B40
6590	Мирный	6	58	439	61.407378000000001	61.419316000000002	54.352552000000003	54.347866000000003	0103000020E61000000100000005000000118E59F624B44E40F7B182DF862C4B40118E59F624B44E40D811876C202D4B4043588D25ACB54E40D811876C202D4B4043588D25ACB54E40F7B182DF862C4B40118E59F624B44E40F7B182DF862C4B40
4082	Малое Шумаково	6	58	439	62.041848999999999	62.072130999999999	54.458494000000002	54.447145999999996	0103000020E61000000100000005000000662FDB4E5B054F40C34483143C394B40662FDB4E5B054F40C4B46FEEAF3A4B408E03AF963B094F40C4B46FEEAF3A4B408E03AF963B094F40C34483143C394B40662FDB4E5B054F40C34483143C394B40
3859	Красносельское	6	58	439	61.198878999999998	61.221291999999998	54.581954000000003	54.565963000000004	0103000020E610000001000000050000003B6EF8DD74994E407FDFBF7971484B403B6EF8DD74994E4061E3FA777D4A4B40E76ED74B539C4E4061E3FA777D4A4B40E76ED74B539C4E407FDFBF7971484B403B6EF8DD74994E407FDFBF7971484B40
2799	Копанцево	6	58	439	61.391621000000001	61.401862000000001	54.491286000000002	54.483750000000001	0103000020E61000000100000005000000A2B60DA320B24E4052B81E85EB3D4B40A2B60DA320B24E40C87DAB75E23E4B40A9C0C93670B34E40C87DAB75E23E4B40A9C0C93670B34E4052B81E85EB3D4B40A2B60DA320B24E4052B81E85EB3D4B40
3685	Ключи	6	58	439	61.687004999999999	61.694280999999997	54.490820999999997	54.475720000000003	0103000020E610000001000000050000002098A3C7EFD74E40CD069964E43C4B402098A3C7EFD74E405298F738D33E4B40F99D2633DED84E405298F738D33E4B40F99D2633DED84E40CD069964E43C4B402098A3C7EFD74E40CD069964E43C4B40
3148	Кичигино	6	58	439	61.250064999999999	61.277005000000003	54.520211000000003	54.498215000000002	0103000020E61000000100000005000000E76F422102A04E4036B05582C53F4B40E76F422102A04E407E02284696424B400CEA5BE674A34E407E02284696424B400CEA5BE674A34E4036B05582C53F4B40E76F422102A04E4036B05582C53F4B40
2908	Катаево	6	58	439	61.386536999999997	61.399571000000002	54.459766000000002	54.451569999999997	0103000020E61000000100000005000000D3D85E0B7AB14E4067EDB60BCD394B40D3D85E0B7AB14E4008E8BE9CD93A4B400BB77C2425B34E4008E8BE9CD93A4B400BB77C2425B34E4067EDB60BCD394B40D3D85E0B7AB14E4067EDB60BCD394B40
3007	Каменский	6	58	439	61.042644000000003	61.077255999999998	54.533064000000003	54.512554000000002	0103000020E6100000010000000500000071AFCC5B75854E408DB7955E9B414B4071AFCC5B75854E406556EF703B444B40BBB54C86E3894E406556EF703B444B40BBB54C86E3894E408DB7955E9B414B4071AFCC5B75854E408DB7955E9B414B40
3771	Дуванкуль	6	58	439	61.561663000000003	61.585324999999997	54.540267999999998	54.530921999999997	0103000020E61000000100000005000000C72FBC92E4C74E400B5D8940F5434B40C72FBC92E4C74E40A489778027454B40FE43FAEDEBCA4E40A489778027454B40FE43FAEDEBCA4E400B5D8940F5434B40C72FBC92E4C74E400B5D8940F5434B40
3588	Водопойка	6	58	439	61.230759999999997	61.245168999999997	54.397208999999997	54.384213000000003	0103000020E61000000100000005000000CB9C2E8B899D4E405AD93EE42D314B40CB9C2E8B899D4E40A35698BED7324B401B7FA2B2619F4E40A35698BED7324B401B7FA2B2619F4E405AD93EE42D314B40CB9C2E8B899D4E405AD93EE42D314B40
3987	Большое Шумаково	6	58	439	61.878507999999997	61.891336000000003	54.493378	54.478073999999999	0103000020E610000001000000050000001EA33CF372F04E40B1886187313D4B401EA33CF372F04E406F48A302273F4B40ADDF4C4C17F24E406F48A302273F4B40ADDF4C4C17F24E40B1886187313D4B401EA33CF372F04E40B1886187313D4B40
3124	Березовка	6	58	439	61.172055	61.186723999999998	54.534171999999998	54.523749000000002	0103000020E61000000100000005000000800EF3E505964E4007280D350A434B40800EF3E505964E402E3883BF5F444B406CB07092E6974E402E3883BF5F444B406CB07092E6974E4007280D350A434B40800EF3E505964E4007280D350A434B40
24191	Ясные Поляны	6	58	135	61.390327999999997	61.418517000000001	54.204161999999997	54.176209	0103000020E61000000100000005000000465B9544F6B14E4064213A048E164B40465B9544F6B14E40008BFCFA211A4B40F7E80DF791B54E40008BFCFA211A4B40F7E80DF791B54E4064213A048E164B40465B9544F6B14E4064213A048E164B40
18859	Шантарино	6	58	135	62.217685000000003	62.240654999999997	54.121223000000001	54.110582999999998	0103000020E6100000010000000500000036EA211ADD1B4F402D3F7095270E4B4036EA211ADD1B4F40F2423A3C840F4B40374F75C8CD1E4F40F2423A3C840F4B40374F75C8CD1E4F402D3F7095270E4B4036EA211ADD1B4F402D3F7095270E4B40
45701	Чкалова	6	58	135	61.273591000000003	61.298915000000001	54.097053000000002	54.093128999999998	0103000020E610000001000000050000006FBDA60705A34E4093A7ACA6EB0B4B406FBDA60705A34E40467D923B6C0C4B4055A4C2D842A64E40467D923B6C0C4B4055A4C2D842A64E4093A7ACA6EB0B4B406FBDA60705A34E4093A7ACA6EB0B4B40
46114	Черноречье	6	58	135	60.654338000000003	60.675519999999999	54.021087000000001	54.014775999999998	0103000020E61000000100000005000000D943FB58C1534E400262122EE4014B40D943FB58C1534E4075AF93FAB2024B409FE5797077564E4075AF93FAB2024B409FE5797077564E400262122EE4014B40D943FB58C1534E400262122EE4014B40
45885	Целинный	6	58	135	60.937171999999997	60.967751	54.13541	54.115406999999998	0103000020E610000001000000050000000B5D8940F5774E405F5D15A8C50E4B400B5D8940F5774E4093C6681D55114B40EDD5C743DF7B4E4093C6681D55114B40EDD5C743DF7B4E405F5D15A8C50E4B400B5D8940F5774E405F5D15A8C50E4B40
45732	Херсонский	6	58	135	61.214832999999999	61.231963999999998	54.052280000000003	54.038519000000001	0103000020E61000000100000005000000008DD2A57F9B4E4027A3CA30EE044B40008DD2A57F9B4E40111E6D1CB1064B40B7EC10FFB09D4E40111E6D1CB1064B40B7EC10FFB09D4E4027A3CA30EE044B40008DD2A57F9B4E4027A3CA30EE044B40
23528	Травянка	6	58	135	61.814484999999998	61.828130000000002	54.166553999999998	54.159289000000001	0103000020E61000000100000005000000910A630B41E84E4068CEFA9463144B40910A630B41E84E404D8237A451154B40126BF12900EA4E404D8237A451154B40126BF12900EA4E4068CEFA9463144B40910A630B41E84E4068CEFA9463144B40
24701	Тогузак	6	58	135	61.115560000000002	61.139850000000003	54.269559999999998	54.261992999999997	0103000020E61000000100000005000000E65C8AABCA8E4E40F56393FC88214B40E65C8AABCA8E4E40A6272CF180224B403D2CD49AE6914E40A6272CF180224B403D2CD49AE6914E40F56393FC88214B40E65C8AABCA8E4E40F56393FC88214B40
23474	Суналы	6	58	135	61.756948000000001	61.770378000000001	54.244492999999999	54.237704999999998	0103000020E61000000100000005000000E5620CACE3E04E403F8C101E6D1E4B40E5620CACE3E04E40EB8CEF8B4B1F4B4069C70DBF9BE24E40EB8CEF8B4B1F4B4069C70DBF9BE24E403F8C101E6D1E4B40E5620CACE3E04E403F8C101E6D1E4B40
25385	Стрелецк	6	58	135	60.565728	60.579427000000003	54.021594999999998	54.013665000000003	0103000020E610000001000000050000003B376DC669484E40C80C54C6BF014B403B376DC669484E40E960FD9FC3024B40AFB5F7A92A4A4E40E960FD9FC3024B40AFB5F7A92A4A4E40C80C54C6BF014B403B376DC669484E40C80C54C6BF014B40
21272	Степное	6	58	135	60.397706999999997	60.425797000000003	54.081716999999998	54.059863999999997	0103000020E61000000100000005000000F4311F10E8324E40971AA19FA9074B40F4311F10E8324E407C43E1B3750A4B4012DE1E8480364E407C43E1B3750A4B4012DE1E8480364E40971AA19FA9074B40F4311F10E8324E40971AA19FA9074B40
21237	Степнинское	6	58	135	60.414200000000001	60.428348999999997	53.984662	53.977381000000001	0103000020E6100000010000000500000069006F8104354E40AB5D13D21AFD4A4069006F8104354E4096CE876709FE4A401C23D923D4364E4096CE876709FE4A401C23D923D4364E40AB5D13D21AFD4A4069006F8104354E40AB5D13D21AFD4A40
23624	Сливной	6	58	135	61.686017	61.712392000000001	54.136960999999999	54.121228000000002	0103000020E6100000010000000500000001C0B167CFD74E4004AE2B66840F4B4001C0B167CFD74E40EAE923F087114B404DF73AA92FDB4E40EAE923F087114B404DF73AA92FDB4E4004AE2B66840F4B4001C0B167CFD74E4004AE2B66840F4B40
25153	Скалистый	6	58	135	61.146183000000001	61.160592000000001	54.093308999999998	54.087277999999998	0103000020E61000000100000005000000971DE21FB6924E4084D4EDEC2B0B4B40971DE21FB6924E4013B69F8CF10B4B40E7FF55478E944E4013B69F8CF10B4B40E7FF55478E944E4084D4EDEC2B0B4B40971DE21FB6924E4084D4EDEC2B0B4B40
23150	Сбитнево	6	58	135	62.064549	62.084384	54.291269999999997	54.282803000000001	0103000020E61000000100000005000000A8FE412443084F40F81A82E332244B40A8FE412443084F402827DA5548254B4020274C18CD0A4F402827DA5548254B4020274C18CD0A4F40F81A82E332244B40A8FE412443084F40F81A82E332244B40
45916	Репино	6	58	135	61.052283000000003	61.067912999999997	54.206389999999999	54.197899999999997	0103000020E6100000010000000500000082919735B1864E406FF085C954194B4082919735B1864E40581CCEFC6A1A4B4093FC885FB1884E40581CCEFC6A1A4B4093FC885FB1884E406FF085C954194B4082919735B1864E406FF085C954194B40
45858	Полесье	6	58	135	60.993515000000002	61.007959999999997	54.251989000000002	54.243108999999997	0103000020E61000000100000005000000F08AE07F2B7F4E407F2E1A321E1F4B40F08AE07F2B7F4E40D3F9F02C41204B408CD651D504814E40D3F9F02C41204B408CD651D504814E407F2E1A321E1F4B40F08AE07F2B7F4E407F2E1A321E1F4B40
46001	Подгорное	6	58	135	60.82694	60.842202	54.023018	54.015675999999999	0103000020E610000001000000050000008BE07F2BD9694E4082AAD1AB01024B408BE07F2BD9694E40139CFA40F2024B401A506F46CD6B4E40139CFA40F2024B401A506F46CD6B4E4082AAD1AB01024B408BE07F2BD9694E4082AAD1AB01024B40
45539	Плодовый	6	58	135	61.388908000000001	61.402248	54.095263000000003	54.087246	0103000020E610000001000000050000008E93C2BCC7B14E40795A7EE02A0B4B408E93C2BCC7B14E406AC2F693310C4B40D270CADC7CB34E406AC2F693310C4B40D270CADC7CB34E40795A7EE02A0B4B408E93C2BCC7B14E40795A7EE02A0B4B40
24525	Осиповка	6	58	135	61.058140000000002	61.076895999999998	54.128641999999999	54.117677	0103000020E61000000100000005000000734BAB2171874E40E63E390A100F4B40734BAB2171874E402E724F5777104B40BB9866BAD7894E402E724F5777104B40BB9866BAD7894E40E63E390A100F4B40734BAB2171874E40E63E390A100F4B40
23020	Новый Мир	6	58	135	61.363216000000001	61.390309999999999	54.144446000000002	54.135468000000003	0103000020E6100000010000000500000025B1A4DC7DAE4E40C8D3F20357114B4025B1A4DC7DAE4E40DE04DF347D124B40A0A696ADF5B14E40DE04DF347D124B40A0A696ADF5B14E40C8D3F20357114B4025B1A4DC7DAE4E40C8D3F20357114B40
24309	Нижняя Санарка	6	58	135	61.188277999999997	61.218820999999998	54.132002	54.120854000000001	0103000020E610000001000000050000003447567E19984E409FCBD424780F4B403447567E19984E40D8800871E5104B40C9569753029C4E40D8800871E5104B40C9569753029C4E409FCBD424780F4B403447567E19984E409FCBD424780F4B40
312	Морозкино	6	58	135	61.636960000000002	61.654755999999999	54.112240999999997	54.104258999999999	0103000020E610000001000000050000001A6EC0E787D14E4026A8E15B580D4B401A6EC0E787D14E409A22C0E95D0E4B400D6E6B0BCFD34E409A22C0E95D0E4B400D6E6B0BCFD34E4026A8E15B580D4B401A6EC0E787D14E4026A8E15B580D4B40
23425	Метличье	6	58	135	61.683529	61.691398	54.246617999999998	54.235515999999997	0103000020E610000001000000050000000D6FD6E07DD74E40A5D76663251E4B400D6FD6E07DD74E406E4DBA2D911F4B408942CBBA7FD84E406E4DBA2D911F4B408942CBBA7FD84E40A5D76663251E4B400D6FD6E07DD74E40A5D76663251E4B40
46059	Логовой	6	58	135	61.060887999999998	61.075729000000003	54.008066999999997	54.001061	0103000020E61000000100000005000000035C902DCB874E40892650C422004B40035C902DCB874E40A296E65608014B40ED2DE57CB1894E40A296E65608014B40ED2DE57CB1894E40892650C422004B40035C902DCB874E40892650C422004B40
48418	Лебедевка	6	58	135	61.553730999999999	61.562911999999997	54.159737	54.152397999999998	0103000020E6100000010000000500000004E44BA8E0C64E40E7FC14C781134B4004E44BA8E0C64E40077B134372144B4052431B800DC84E40077B134372144B4052431B800DC84E40E7FC14C781134B4004E44BA8E0C64E40E7FC14C781134B40
24656	Лагерный	6	58	135	61.251914999999997	61.266683	54.249727	54.241304	0103000020E61000000100000005000000982F2FC03EA04E406E32AA0CE31E4B40982F2FC03EA04E40CFF6E80DF71F4B4018B325AB22A24E40CFF6E80DF71F4B4018B325AB22A24E406E32AA0CE31E4B40982F2FC03EA04E406E32AA0CE31E4B40
23966	Кумысное	6	58	135	61.499876999999998	61.522433999999997	54.194217999999999	54.186653	0103000020E61000000100000005000000E48233F8FBBF4E40A359D93EE4174B40E48233F8FBBF4E40B325AB22DC184B40C328081EDFC24E40B325AB22DC184B40C328081EDFC24E40A359D93EE4174B40E48233F8FBBF4E40A359D93EE4174B40
45838	Краснооктябрьский	6	58	135	61.111570999999998	61.121237000000001	54.306806000000002	54.303465000000003	0103000020E610000001000000050000004C1762F5478E4E40863DEDF0D7264B404C1762F5478E4E40B91B446B45274B405708ABB1848F4E40B91B446B45274B405708ABB1848F4E40863DEDF0D7264B404C1762F5478E4E40863DEDF0D7264B40
24968	Кособродка	6	58	135	60.868944999999997	60.895311	54.215904000000002	54.205168	0103000020E61000000100000005000000E882FA96396F4E40C617EDF1421A4B40E882FA96396F4E40AD8905BEA21B4B40E15F048D99724E40AD8905BEA21B4B40E15F048D99724E40C617EDF1421A4B40E882FA96396F4E40C617EDF1421A4B40
23869	Клястицкое	6	58	135	61.488791999999997	61.515939000000003	54.123961999999999	54.109099999999998	0103000020E61000000100000005000000F1457BBC90BE4E402EFF21FDF60D4B40F1457BBC90BE4E402FF99FFCDD0F4B4090DD054A0AC24E402FF99FFCDD0F4B4090DD054A0AC24E402EFF21FDF60D4B40F1457BBC90BE4E402EFF21FDF60D4B40
40275	Ключевка	6	58	135	61.983809000000001	62.021619000000001	54.055790000000002	54.041294999999998	0103000020E6100000010000000500000057410C74EDFD4E40813E912749054B4057410C74EDFD4E40D0B8702024074B4072FC5069C4024F40D0B8702024074B4072FC5069C4024F40813E912749054B4057410C74EDFD4E40813E912749054B40
23760	Кварцитный	6	58	135	61.731507999999998	61.749293999999999	54.035209000000002	54.015776000000002	0103000020E610000001000000050000009561DC0DA2DD4E40E607AEF204024B409561DC0DA2DD4E402FC37FBA81044B40658BA4DDE8DF4E402FC37FBA81044B40658BA4DDE8DF4E40E607AEF204024B409561DC0DA2DD4E40E607AEF204024B40
24050	Карсы	6	58	135	61.411563999999998	61.424419	54.260016	54.241925000000002	0103000020E61000000100000005000000001B1021AEB44E40DB8AFD65F71E4B40001B1021AEB44E40E7374C3448214B4088669E5C53B64E40E7374C3448214B4088669E5C53B64E40DB8AFD65F71E4B40001B1021AEB44E40DB8AFD65F71E4B40
23333	Каракулька	6	58	135	61.939943999999997	61.958081	54.181621	54.171961000000003	0103000020E610000001000000050000002409C21550F84E40FF976BD102164B402409C21550F84E4027A25F5B3F174B40A1F5F065A2FA4E4027A25F5B3F174B40A1F5F065A2FA4E40FF976BD102164B402409C21550F84E40FF976BD102164B40
45584	Карабаново	6	58	135	61.379781000000001	61.394325000000002	54.344633000000002	54.326239000000001	0103000020E610000001000000050000003352EFA99CB04E4002D71533C2294B403352EFA99CB04E40AA0F24EF1C2C4B40637FD93D79B24E40AA0F24EF1C2C4B40637FD93D79B24E4002D71533C2294B403352EFA99CB04E4002D71533C2294B40
25025	Каменная Санарка	6	58	135	60.719915	60.754373999999999	54.137562000000003	54.124426	0103000020E610000001000000050000002E73BA2C265C4E40D462F030ED0F4B402E73BA2C265C4E401096B1A19B114B40F279C5538F604E401096B1A19B114B40F279C5538F604E40D462F030ED0F4B402E73BA2C265C4E40D462F030ED0F4B40
19611	Каменная Речка	6	58	135	61.908664000000002	61.931247999999997	54.009723000000001	54.002822999999999	0103000020E61000000100000005000000BA86191A4FF44E409B560A815C004B40BA86191A4FF44E406F826F9A3E014B40923B6C2233F74E406F826F9A3E014B40923B6C2233F74E409B560A815C004B40BA86191A4FF44E409B560A815C004B40
46013	Каменка	6	58	135	60.879069000000001	60.895077000000001	54.056365999999997	54.047279000000003	0103000020E61000000100000005000000B6F63E5585704E40D064FF3C0D064B40B6F63E5585704E409C4D470037074B406E3315E291724E409C4D470037074B406E3315E291724E40D064FF3C0D064B40B6F63E5585704E40D064FF3C0D064B40
24162	Кадымцево	6	58	135	61.491630999999998	61.510801000000001	54.298116999999998	54.278013999999999	0103000020E610000001000000050000009259BDC3EDBE4E4042EA76F695234B409259BDC3EDBE4E40D9B0A6B228264B40CEE15AED61C14E40D9B0A6B228264B40CEE15AED61C14E4042EA76F695234B409259BDC3EDBE4E4042EA76F695234B40
49134	Искра	6	58	135	60.813924	60.833146999999997	53.976449000000002	53.96546	0103000020E61000000100000005000000FAB660A92E684E404FCC7A3194FB4A40FAB660A92E684E40209BE447FCFC4A4058E1968FA46A4E40209BE447FCFC4A4058E1968FA46A4E404FCC7A3194FB4A40FAB660A92E684E404FCC7A3194FB4A40
23251	Епанишниково	6	58	135	62.216777999999998	62.228149999999999	54.242288000000002	54.233463999999998	0103000020E61000000100000005000000033FAA61BF1B4F408C65FA25E21D4B40033FAA61BF1B4F404C1B0E4B031F4B408C4AEA04341D4F404C1B0E4B031F4B408C4AEA04341D4F408C65FA25E21D4B40033FAA61BF1B4F408C65FA25E21D4B40
49585	Дробышево	6	58	135	61.640211999999998	61.672767	54.208596	54.196883	0103000020E61000000100000005000000DD408177F2D14E40B6114F7633194B40DD408177F2D14E40C8091346B31A4B40FD69A33A1DD64E40C8091346B31A4B40FD69A33A1DD64E40B6114F7633194B40DD408177F2D14E40B6114F7633194B40
45888	Дачный	6	58	135	60.957689999999999	60.973357	54.171629000000003	54.165647	0103000020E6100000010000000500000066DAFE95957A4E401BD7BFEB33154B4066DAFE95957A4E40C90567F0F7154B40952A51F6967C4E40C90567F0F7154B40952A51F6967C4E401BD7BFEB33154B4066DAFE95957A4E401BD7BFEB33154B40
23187	Бурханкуль	6	58	135	62.138570000000001	62.154496999999999	54.357678	54.348663000000002	0103000020E61000000100000005000000761A69A9BC114F40A2293BFDA02C4B40761A69A9BC114F40D53F8864C82D4B40412AC58EC6134F40D53F8864C82D4B40412AC58EC6134F40A2293BFDA02C4B40761A69A9BC114F40A2293BFDA02C4B40
45437	Бобровка	6	58	135	61.723387000000002	61.756822	54.053258	54.036869000000003	0103000020E6100000010000000500000000ADF9F197DC4E403D9E961FB8044B4000ADF9F197DC4E400C207C28D1064B405872158BDFE04E400C207C28D1064B405872158BDFE04E403D9E961FB8044B4000ADF9F197DC4E403D9E961FB8044B40
24420	Берлин	6	58	135	61.183391999999998	61.201286000000003	54.010596	54.002251999999999	0103000020E610000001000000050000008C2C996379974E40E02C25CB49004B408C2C996379974E40F5BBB0355B014B40439259BDC3994E40F5BBB0355B014B40439259BDC3994E40E02C25CB49004B408C2C996379974E40E02C25CB49004B40
23798	Березники	6	58	135	61.749636000000002	61.763424999999998	54.096429999999998	54.088276	0103000020E61000000100000005000000BFF38B12F4DF4E40C782C2A04C0B4B40BFF38B12F4DF4E40382D78D1570C4B4072F90FE9B7E14E40382D78D1570C4B4072F90FE9B7E14E40C782C2A04C0B4B40BFF38B12F4DF4E40C782C2A04C0B4B40
25225	Белоключевка	6	58	135	61.005363000000003	61.017885999999997	54.035404	54.030793000000003	0103000020E61000000100000005000000E2CD1ABCAF804E400EF96706F1034B40E2CD1ABCAF804E40E412471E88044B403387A4164A824E40E412471E88044B403387A4164A824E400EF96706F1034B40E2CD1ABCAF804E400EF96706F1034B40
24554	Белокаменка	6	58	135	61.074345000000001	61.082915	54.194307000000002	54.180757	0103000020E6100000010000000500000081CF0F2384894E40F4C29D0B23174B4081CF0F2384894E402331410DDF184B4086AC6EF59C8A4E402331410DDF184B4086AC6EF59C8A4E40F4C29D0B23174B4081CF0F2384894E40F4C29D0B23174B40
49492	Белозеры	6	58	135	62.166445000000003	62.185138999999999	54.249954000000002	54.242804	0103000020E6100000010000000500000097CADB114E154F4043AB9333141F4B4097CADB114E154F4090C01F7EFE1F4B40691B7FA2B2174F4090C01F7EFE1F4B40691B7FA2B2174F4043AB9333141F4B4097CADB114E154F4043AB9333141F4B40
45599	Безводный	6	58	135	60.692588000000001	60.704625999999998	53.931032000000002	53.926276000000001	0103000020E6100000010000000500000010CD3CB9A6584E40EC88433690F64A4010CD3CB9A6584E40C6C37B0E2CF74A40A5F44C2F315A4E40C6C37B0E2CF74A40A5F44C2F315A4E40EC88433690F64A4010CD3CB9A6584E40EC88433690F64A40
428	Южно-Челябинский Прииск	6	58	56	61.206910000000001	61.219172	55.024692999999999	55.012852000000002	0103000020E61000000100000005000000919BE1067C9A4E4017D86322A5814B40919BE1067C9A4E4056B8E52329834B407619FED30D9C4E4056B8E52329834B407619FED30D9C4E4017D86322A5814B40919BE1067C9A4E4017D86322A5814B40
1423	Чишма	6	58	56	61.353613000000003	61.371552999999999	55.556100000000001	55.545665999999997	0103000020E610000001000000050000006138D73043AD4E4002452C62D8C54B406138D73043AD4E401EA7E8482EC74B4087DD770C8FAF4E401EA7E8482EC74B4087DD770C8FAF4E4002452C62D8C54B406138D73043AD4E4002452C62D8C54B40
2213	Чипышево	6	58	56	61.104734999999998	61.121138000000002	55.020476000000002	55.013677999999999	0103000020E610000001000000050000008FDFDBF4678D4E405C566133C0814B408FDFDBF4678D4E402C2D23F59E824B40C4263273818F4E402C2D23F59E824B40C4263273818F4E405C566133C0814B408FDFDBF4678D4E405C566133C0814B40
1027	Ужевка	6	58	56	61.246336999999997	61.261499999999998	55.328887999999999	55.313884999999999	0103000020E61000000100000005000000BA6587F8879F4E403CDA38622DA84B40BA6587F8879F4E40FF05820019AA4B40B6F3FDD478A14E40FF05820019AA4B40B6F3FDD478A14E403CDA38622DA84B40BA6587F8879F4E403CDA38622DA84B40
32069	Туктубаево	6	58	56	60.885348999999998	60.898051000000002	55.114415000000001	55.092736000000002	0103000020E61000000100000005000000ED45B41D53714E40B894F3C5DE8B4B40ED45B41D53714E40FF959526A58E4B40EF91CD55F3724E40FF959526A58E4B40EF91CD55F3724E40B894F3C5DE8B4B40ED45B41D53714E40B894F3C5DE8B4B40
32232	Трубный	6	58	56	60.961875999999997	60.974767	55.118214999999999	55.107283000000002	0103000020E610000001000000050000005567B5C01E7B4E4059350873BB8D4B405567B5C01E7B4E40C5724BAB218F4B402A1C412AC57C4E40C5724BAB218F4B402A1C412AC57C4E4059350873BB8D4B405567B5C01E7B4E4059350873BB8D4B40
1852	Томинский	6	58	56	61.172530999999999	61.195501	54.966540999999999	54.949098999999997	0103000020E61000000100000005000000E945ED7E15964E4049D576137C794B40E945ED7E15964E401F9F909DB77B4B40EBAA402D06994E401F9F909DB77B4B40EBAA402D06994E4049D576137C794B40E945ED7E15964E4049D576137C794B40
1520	Теченский	6	58	56	61.543723999999997	61.564205000000001	55.520263	55.507468000000003	0103000020E6100000010000000500000070067FBF98C54E401EE21FB6F4C04B4070067FBF98C54E40D0285DFA97C24B40AE9E93DE37C84E40D0285DFA97C24B40AE9E93DE37C84E401EE21FB6F4C04B4070067FBF98C54E401EE21FB6F4C04B40
1320	Султаева	6	58	56	61.337955999999998	61.355356	55.484096999999998	55.466208000000002	0103000020E6100000010000000500000055BE672442AB4E40199128B4ACBB4B4055BE672442AB4E40BD8BF7E3F6BD4B40FC372F4E7CAD4E40BD8BF7E3F6BD4B40FC372F4E7CAD4E40199128B4ACBB4B4055BE672442AB4E40199128B4ACBB4B40
1759	Солнечный	6	58	56	61.522424999999998	61.546669999999999	55.331054000000002	55.317241000000003	0103000020E6100000010000000500000070CE88D2DEC24E40A5F9635A9BA84B4070CE88D2DEC24E40E19A3BFA5FAA4B4027DA5548F9C54E40E19A3BFA5FAA4B4027DA5548F9C54E40A5F9635A9BA84B4070CE88D2DEC24E40A5F9635A9BA84B40
1373	Смольное	6	58	56	61.281326	61.294459000000003	55.558570000000003	55.549968999999997	0103000020E61000000100000005000000DBC1887D02A44E402B685A6265C64B40DBC1887D02A44E406C43C5387FC74B40A6811FD5B0A54E406C43C5387FC74B40A6811FD5B0A54E402B685A6265C64B40DBC1887D02A44E402B685A6265C64B40
55165	Смолино	6	58	56	60.86157	61.566882	55.641756999999998	54.92568	0103000020E610000001000000050000007C9BFEEC476E4E40D847A7AE7C764B407C9BFEEC476E4E40527DE71725D24B407558E1968FC84E40527DE71725D24B407558E1968FC84E40D847A7AE7C764B407C9BFEEC476E4E40D847A7AE7C764B40
587	Северный	6	58	56	61.198241000000003	61.213673999999997	55.134228999999998	55.124496000000001	0103000020E61000000100000005000000F9DC09F65F994E40CD3D247CEF8F4B40F9DC09F65F994E405F96766A2E914B40B4006DAB599B4E405F96766A2E914B40B4006DAB599B4E40CD3D247CEF8F4B40F9DC09F65F994E40CD3D247CEF8F4B40
1626	Саргазы	6	58	56	61.235906999999997	61.267339	55.033723000000002	55.012180999999998	0103000020E61000000100000005000000E0F25833329E4E40F850A2258F814B40E0F25833329E4E40BF0F070951844B4001F9122A38A24E40BF0F070951844B4001F9122A38A24E40F850A2258F814B40E0F25833329E4E40F850A2258F814B40
1291	Саккулово	6	58	56	61.379250999999996	61.408357000000002	55.495364000000002	55.472796000000002	0103000020E61000000100000005000000D6FCF84B8BB04E40FED64E9484BC4B40D6FCF84B8BB04E40D1CE691668BF4B40DD0BCC0A45B44E40D1CE691668BF4B40DD0BCC0A45B44E40FED64E9484BC4B40D6FCF84B8BB04E40FED64E9484BC4B40
485	Садовый	6	58	56	61.174112000000001	61.199767999999999	55.184165999999998	55.172131	0103000020E61000000100000005000000ABEB504D49964E405BD07B6308964B40ABEB504D49964E407F8461C092974B40C76471FF91994E407F8461C092974B40C76471FF91994E405BD07B6308964B40ABEB504D49964E405BD07B6308964B40
1069	Рощино	6	58	56	61.259388999999999	61.275064999999998	55.315646999999998	55.308002999999999	0103000020E6100000010000000500000098F8A3A833A14E40F2086EA46CA74B4098F8A3A833A14E404E0AF31E67A84B401AA3755435A34E404E0AF31E67A84B401AA3755435A34E40F2086EA46CA74B4098F8A3A833A14E40F2086EA46CA74B40
55221	Полетаево-II	6	58	56	61.109802000000002	61.131478000000001	55.085991999999997	55.069040999999999	0103000020E610000001000000050000008884EFFD0D8E4E40A48AE255D6884B408884EFFD0D8E4E40DBDB2DC9018B4B405E126745D4904E40DBDB2DC9018B4B405E126745D4904E40A48AE255D6884B408884EFFD0D8E4E40A48AE255D6884B40
2018	Полетаево	6	58	56	61.082600999999997	61.133526000000003	55.047595000000001	55.022851000000003	0103000020E61000000100000005000000F6CE68AB928A4E4028D714C8EC824B40F6CE68AB928A4E40003ACC9717864B403695456117914E40003ACC9717864B403695456117914E4028D714C8EC824B40F6CE68AB928A4E4028D714C8EC824B40
55128	Полевой	6	58	56	60.86157	61.566882	55.641756999999998	54.92568	0103000020E610000001000000050000007C9BFEEC476E4E40D847A7AE7C764B407C9BFEEC476E4E40527DE71725D24B407558E1968FC84E40527DE71725D24B407558E1968FC84E40D847A7AE7C764B407C9BFEEC476E4E40D847A7AE7C764B40
55235	Новый Кременкуль	6	58	56	61.165075000000002	61.173447000000003	55.191535999999999	55.186205999999999	0103000020E610000001000000050000009031772D21954E40D4282499D5974B409031772D21954E40DA006C4084984B406F4BE48233964E40DA006C4084984B406F4BE48233964E40D4282499D5974B409031772D21954E40D4282499D5974B40
968	Мирный	6	58	56	61.061984000000002	61.092806000000003	55.324806000000002	55.312046000000002	0103000020E6100000010000000500000009707A17EF874E407F6C921FF1A74B4009707A17EF874E40B5C5353E93A94B40B16F2711E18B4E40B5C5353E93A94B40B16F2711E18B4E407F6C921FF1A74B4009707A17EF874E407F6C921FF1A74B40
55189	Медиак	6	58	56	61.032367000000001	61.042715000000001	55.304487999999999	55.292402000000003	0103000020E610000001000000050000001D3C139A24844E407BA4C16D6DA54B401D3C139A24844E4021037976F9A64B403A0664AF77854E4021037976F9A64B403A0664AF77854E407BA4C16D6DA54B401D3C139A24844E407BA4C16D6DA54B40
924	Медиак	6	58	56	61.032367000000001	61.042715000000001	55.304487999999999	55.292402000000003	0103000020E610000001000000050000001D3C139A24844E407BA4C16D6DA54B401D3C139A24844E4021037976F9A64B403A0664AF77854E4021037976F9A64B403A0664AF77854E407BA4C16D6DA54B401D3C139A24844E407BA4C16D6DA54B40
711	Мамаева	6	58	56	60.892490000000002	60.913716999999998	55.202959	55.194609	0103000020E61000000100000005000000E700C11C3D724E40EE409DF2E8984B40E700C11C3D724E40E5B67D8FFA994B404D66BCADF4744E40E5B67D8FFA994B404D66BCADF4744E40EE409DF2E8984B40E700C11C3D724E40EE409DF2E8984B40
657	Малиновка	6	58	56	61.182008000000003	61.197594000000002	55.102621999999997	55.093122999999999	0103000020E6100000010000000500000021CEC3094C974E40B1C05774EB8B4B4021CEC3094C974E40D0ECBAB7228D4B4063F19BC24A994E40D0ECBAB7228D4B4063F19BC24A994E40B1C05774EB8B4B4021CEC3094C974E40B1C05774EB8B4B40
427	Кременкуль	6	58	56	61.135331999999998	61.169908	55.191952000000001	55.173478000000003	0103000020E61000000100000005000000170D198F52914E40AA49F08634964B40170D198F52914E406E3315E291984B4015AA9B8BBF954E406E3315E291984B4015AA9B8BBF954E40AA49F08634964B40170D198F52914E40AA49F08634964B40
68	Ключёвка	6	58	56	61.269801000000001	61.302526	55.353110000000001	55.334817999999999	0103000020E61000000100000005000000CCB6D3D688A24E405A0EF450DBAA4B40CCB6D3D688A24E40FEF15EB532AD4B404818062CB9A64E40FEF15EB532AD4B404818062CB9A64E405A0EF450DBAA4B40CCB6D3D688A24E405A0EF450DBAA4B40
311	Ключи	6	58	56	61.071497000000001	61.083480999999999	55.252763000000002	55.248319000000002	0103000020E610000001000000050000008D614ED026894E40DBFCBFEAC89F4B408D614ED026894E40C651B9895AA04B402F6B6281AF8A4E40C651B9895AA04B402F6B6281AF8A4E40DBFCBFEAC89F4B408D614ED026894E40DBFCBFEAC89F4B40
816	Кисегачинский	6	58	56	61.098061000000001	61.112496999999998	55.366661000000001	55.357322000000003	0103000020E61000000100000005000000AC014A438D8C4E40171230BABCAD4B40AC014A438D8C4E40FDDB65BFEEAE4B40F5F23B4D668E4E40FDDB65BFEEAE4B40F5F23B4D668E4E40171230BABCAD4B40AC014A438D8C4E40171230BABCAD4B40
810	Касарги	6	58	56	61.168399000000001	61.192833	55.376185999999997	55.361083000000001	0103000020E61000000100000005000000EDD632198E954E401F12BEF737AE4B40EDD632198E954E40459BE3DC26B04B40774B72C0AE984E40459BE3DC26B04B40774B72C0AE984E401F12BEF737AE4B40EDD632198E954E401F12BEF737AE4B40
32143	Кайгородово	6	58	56	61.060628000000001	61.074722000000001	55.137743999999998	55.119909	0103000020E61000000100000005000000679C86A8C2874E407FBF982D598F4B40679C86A8C2874E40309C6B98A1914B405725917D90894E40309C6B98A1914B405725917D90894E407FBF982D598F4B40679C86A8C2874E407FBF982D598F4B40
55171	Казанцево	6	58	56	60.86157	61.566882	55.641756999999998	54.92568	0103000020E610000001000000050000007C9BFEEC476E4E40D847A7AE7C764B407C9BFEEC476E4E40527DE71725D24B407558E1968FC84E40527DE71725D24B407558E1968FC84E40D847A7AE7C764B407C9BFEEC476E4E40D847A7AE7C764B40
320	Заварухино	6	58	56	61.197907999999998	61.216602000000002	55.290157000000001	55.285578999999998	0103000020E61000000100000005000000F2CEA10C55994E4052B648DA8DA44B40F2CEA10C55994E404DDA54DD23A54B40C51F459DB99B4E404DDA54DD23A54B40C51F459DB99B4E4052B648DA8DA44B40F2CEA10C55994E4052B648DA8DA44B40
139	Есаульский	6	58	56	61.199506999999997	61.238529999999997	55.307147000000001	55.292453000000002	0103000020E610000001000000050000005A29047289994E40FD4E93196FA54B405A29047289994E404208C89750A74B40B48EAA26889E4E404208C89750A74B40B48EAA26889E4E40FD4E93196FA54B405A29047289994E40FD4E93196FA54B40
32340	Долгодеревенское	6	58	56	61.274625	61.369396999999999	55.367203000000003	55.320293999999997	0103000020E61000000100000005000000FED478E926A34E40718DCF64FFA84B40FED478E926A34E401EFF058200AF4B40C91EA16648AF4E401EFF058200AF4B40C91EA16648AF4E40718DCF64FFA84B40FED478E926A34E40718DCF64FFA84B40
31903	Высокий	6	58	56	60.880650000000003	60.896056000000002	55.059379	55.051282999999998	0103000020E61000000100000005000000789CA223B9704E409EEBFB7090864B40789CA223B9704E40DB8827BB99874B403AB187F6B1724E40DB8827BB99874B403AB187F6B1724E409EEBFB7090864B40789CA223B9704E409EEBFB7090864B40
32274	Вознесенка	6	58	56	61.351457000000003	61.383122999999998	54.996991000000001	54.983266999999998	0103000020E61000000100000005000000A379008BFCAC4E40361E6CB1DB7D4B40A379008BFCAC4E4003B4AD669D7F4B4036ACA92C0AB14E4003B4AD669D7F4B4036ACA92C0AB14E40361E6CB1DB7D4B40A379008BFCAC4E40361E6CB1DB7D4B40
2313	Витаминный	6	58	56	61.023366000000003	61.038277999999998	54.994197	54.987405000000003	0103000020E610000001000000050000004FEB36A8FD824E4015747B49637E4B404FEB36A8FD824E400264E8D8417F4B400114234BE6844E400264E8D8417F4B400114234BE6844E4015747B49637E4B404FEB36A8FD824E4015747B49637E4B40
2370	Верхние Малюки	6	58	56	60.982033999999999	60.997692000000001	55.013756000000001	55.008712000000003	0103000020E61000000100000005000000B0C7444AB37D4E40988A8D791D814B40B0C7444AB37D4E40D80FB1C1C2814B408CBD175FB47F4E40D80FB1C1C2814B408CBD175FB47F4E40988A8D791D814B40B0C7444AB37D4E40988A8D791D814B40
31955	Бутаки	6	58	56	61.172944000000001	61.190595999999999	55.047708	55.023660999999997	0103000020E610000001000000050000000C056C0723964E406798DA5207834B400C056C0723964E40F8E0B54B1B864B40CC5F217365984E40F8E0B54B1B864B40CC5F217365984E406798DA5207834B400C056C0723964E406798DA5207834B40
1513	Большое Таскино	6	58	56	61.281227000000001	61.321058000000001	55.641756999999998	55.632219999999997	0103000020E6100000010000000500000048E00F3FFFA34E4045F0BF95ECD04B4048E00F3FFFA34E40527DE71725D24B40410FB56D18A94E40527DE71725D24B40410FB56D18A94E4045F0BF95ECD04B4048E00F3FFFA34E4045F0BF95ECD04B40
32496	Большое Баландино	6	58	56	61.445887999999997	61.485019000000001	55.372456999999997	55.357106999999999	0103000020E61000000100000005000000E4D6A4DB12B94E401A16A3AEB5AD4B40E4D6A4DB12B94E404815C5ABACAF4B402578431A15BE4E404815C5ABACAF4B402578431A15BE4E401A16A3AEB5AD4B40E4D6A4DB12B94E401A16A3AEB5AD4B40
543	Большие Харлуши	6	58	56	60.964489999999998	60.994458000000002	55.223956000000001	55.206868	0103000020E61000000100000005000000D6A88768747B4E40624B8FA67A9A4B40D6A88768747B4E401ADF1797AA9C4B406F9F55664A7F4E401ADF1797AA9C4B406F9F55664A7F4E40624B8FA67A9A4B40D6A88768747B4E40624B8FA67A9A4B40
1854	Архангельское	6	58	56	60.965074000000001	61.001258	54.938761999999997	54.926296000000001	0103000020E61000000100000005000000261C7A8B877B4E40333509DE90764B40261C7A8B877B4E40205D6C5A29784B40DF6DDE3829804E40205D6C5A29784B40DF6DDE3829804E40333509DE90764B40261C7A8B877B4E40333509DE90764B40
6453	Альмеева	6	58	56	60.86157	60.868127999999999	55.219482999999997	55.211331999999999	0103000020E610000001000000050000007C9BFEEC476E4E40944C4EED0C9B4B407C9BFEEC476E4E409483D904189C4B40F65E7CD11E6F4E409483D904189C4B40F65E7CD11E6F4E40944C4EED0C9B4B407C9BFEEC476E4E40944C4EED0C9B4B40
32060	Алишева	6	58	56	60.867804	60.887872999999999	55.131990000000002	55.123471000000002	0103000020E6100000010000000500000043AB9333146F4E409180D1E5CD8F4B4043AB9333146F4E4014B35E0CE5904B402E008DD2A5714E4014B35E0CE5904B402E008DD2A5714E409180D1E5CD8F4B4043AB9333146F4E409180D1E5CD8F4B40
25755	Чёрная Речка	6	58	1756	59.146731000000003	59.167149999999999	55.036169000000001	55.028388	0103000020E610000001000000050000009A27D714C8924D40A7CCCD37A2834B409A27D714C8924D408410902FA1844B4061C3D32B65954D408410902FA1844B4061C3D32B65954D40A7CCCD37A2834B409A27D714C8924D40A7CCCD37A2834B40
26208	Чулковка	6	58	1756	58.998806000000002	59.012810000000002	55.206955999999998	55.198047000000003	0103000020E61000000100000005000000388600E0D87F4D401409A69A59994B40388600E0D87F4D4001DBC1887D9A4B40E88711C2A3814D4001DBC1887D9A4B40E88711C2A3814D401409A69A59994B40388600E0D87F4D401409A69A59994B40
55137	Сулея	6	58	1756	58.855038999999998	58.904069	55.141922000000001	55.123460999999999	0103000020E61000000100000005000000FBE6FEEA716D4D406DAAEE91CD8F4B40FBE6FEEA716D4D409D4A06802A924B40E9297288B8734D409D4A06802A924B40E9297288B8734D406DAAEE91CD8F4B40FBE6FEEA716D4D406DAAEE91CD8F4B40
55120	Рудничное	6	58	1756	58.907456000000003	58.912936000000002	54.975226999999997	54.969455000000004	0103000020E610000001000000050000008D47A98427744D40CBF8F719177C4B408D47A98427744D408D96033DD47C4B40A8AB3B16DB744D408D96033DD47C4B40A8AB3B16DB744D40CBF8F719177C4B408D47A98427744D40CBF8F719177C4B40
26242	Романовка	6	58	1756	59.061444999999999	59.085538	55.218460999999998	55.208579	0103000020E6100000010000000500000059C0046EDD874D40F2D077B7B29A4B4059C0046EDD874D40C939B187F69B4B405A48C0E8F28A4D40C939B187F69B4B405A48C0E8F28A4D40F2D077B7B29A4B4059C0046EDD874D40F2D077B7B29A4B40
55139	Межевой	6	58	1756	58.767992	58.840063999999998	55.184479000000003	55.140667000000001	0103000020E6100000010000000500000079CBD58F4D624D402F50526001924B4079CBD58F4D624D403FE603029D974B4002469737876B4D403FE603029D974B4002469737876B4D402F50526001924B4079CBD58F4D624D402F50526001924B40
25691	Малый Бердяуш	6	58	1756	59.171605999999997	59.192186	55.102626999999998	55.092917	0103000020E6100000010000000500000010E6762FF7954D40081F4AB4E48B4B4010E6762FF7954D40E257ACE1228D4B40E15F048D99984D40E257ACE1228D4B40E15F048D99984D40081F4AB4E48B4B4010E6762FF7954D40081F4AB4E48B4B40
55141	Магнитский	6	58	1756	59.251223000000003	59.263485000000003	55.014541000000001	55.008308999999997	0103000020E610000001000000050000006380441328A04D4098A1F14410814B406380441328A04D40BFB9BF7ADC814B4048FE60E0B9A14D40BFB9BF7ADC814B4048FE60E0B9A14D4098A1F14410814B406380441328A04D4098A1F14410814B40
25987	Жукатау	6	58	1756	59.185654999999997	59.211554	55.177874000000003	55.164068	0103000020E6100000010000000500000060AB048BC3974D40FA28232E00954B4060AB048BC3974D4084674293C4964B4043AB9333149B4D4084674293C4964B4043AB9333149B4D40FA28232E00954B4060AB048BC3974D40FA28232E00954B40
55178	Ельничный	6	58	1756	58.873607	58.886561	54.958219	54.947470000000003	0103000020E610000001000000050000004147AB5AD26F4D4077F86BB246794B404147AB5AD26F4D40F2B391EBA67A4B405C74B2D47A714D40F2B391EBA67A4B405C74B2D47A714D4077F86BB246794B404147AB5AD26F4D4077F86BB246794B40
26397	Верхний Айск	6	58	1756	58.894421000000001	58.925404	55.235990999999999	55.230122999999999	0103000020E6100000010000000500000085ED27637C724D405987A3AB749D4B4085ED27637C724D403E93FDF3349E4B4036CB65A373764D403E93FDF3349E4B4036CB65A373764D405987A3AB749D4B4085ED27637C724D405987A3AB749D4B40
25735	Большая Запань	6	58	1756	59.090209000000002	59.105111999999998	55.037582	55.028120000000001	0103000020E610000001000000050000000667F0F78B8B4D40882EA86F99834B400667F0F78B8B4D408A75AA7CCF844B4065355D4F748D4D408A75AA7CCF844B4065355D4F748D4D40882EA86F99834B400667F0F78B8B4D40882EA86F99834B40
55142	Бердяуш	6	58	1756	59.113143000000001	59.168658999999998	55.174197999999997	55.143821000000003	0103000020E61000000100000005000000BB6246787B8E4D4030BDFDB968924B40BB6246787B8E4D40A983BC1E4C964B4089963C9E96954D40A983BC1E4C964B4089963C9E96954D4030BDFDB968924B40BB6246787B8E4D4030BDFDB968924B40
24783	Бакал	6	58	1756	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
55232	Алексеевка	6	58	1756	58.666967999999997	58.708838	55.167122999999997	55.143785000000001	0103000020E6100000010000000500000040BD19355F554D40E353008C67924B4040BD19355F554D4067B4554964954B40BE141E34BB5A4D4067B4554964954B40BE141E34BB5A4D40E353008C67924B4040BD19355F554D40E353008C67924B40
26313	Айлино	6	58	1756	58.809989000000002	58.847377000000002	55.234368000000003	55.220860000000002	0103000020E61000000100000005000000548F34B8AD674D404E7FF623459C4B40548F34B8AD674D404E9D47C5FF9D4B40F9307BD9766C4D404E9D47C5FF9D4B40F9307BD9766C4D404E7FF623459C4B40548F34B8AD674D404E7FF623459C4B40
40358	Сатка	6	58	6905	59.040073999999997	59.062406000000003	55.157907000000002	55.140847000000001	0103000020E61000000100000005000000BFB5132521854D40AF5E454607924B40BFB5132521854D409D67EC4B36944B407F8978EBFC874D409D67EC4B36944B407F8978EBFC874D40AF5E454607924B40BFB5132521854D40AF5E454607924B40
55186	Старый Кумляк	6	58	6933	60.459484000000003	60.466752	54.506224000000003	54.498513000000003	0103000020E610000001000000050000008484285FD03A4E40C0D02346CF3F4B408484285FD03A4E40A439B2F2CB404B40DAAB8F87BE3B4E40A439B2F2CB404B40DAAB8F87BE3B4E40C0D02346CF3F4B408484285FD03A4E40C0D02346CF3F4B40
55213	Светлый	6	58	6933	60.407328	60.427208	54.290391999999997	54.279716999999998	0103000020E610000001000000050000005F5FEB5223344E404F9143C4CD234B405F5FEB5223344E409082A7902B254B40774B72C0AE364E409082A7902B254B40774B72C0AE364E404F9143C4CD234B405F5FEB5223344E404F9143C4CD234B40
55185	Радиомайка	6	58	6933	60.405755999999997	60.41977	54.245961000000001	54.232275000000001	0103000020E61000000100000005000000F01307D0EF334E40D656EC2FBB1D4B40F01307D0EF334E40B58B69A67B1F4B40C4EBFA05BB354E40B58B69A67B1F4B40C4EBFA05BB354E40D656EC2FBB1D4B40F01307D0EF334E40D656EC2FBB1D4B40
55210	Поляновка	6	58	6933	60.974282000000002	60.990703000000003	54.434306999999997	54.423979000000003	0103000020E610000001000000050000006E8AC745B57C4E406C98A1F144364B406E8AC745B57C4E4041B62C5F97374B4049861C5BCF7E4E4041B62C5F97374B4049861C5BCF7E4E406C98A1F144364B406E8AC745B57C4E406C98A1F144364B40
41023	Михайловка	6	58	6933	59.790374	59.808205999999998	53.18036	53.167000999999999	0103000020E61000000100000005000000EACDA8F92AE54D401CB3EC4960954A40EACDA8F92AE54D40D7C0560916974A402A37514B73E74D40D7C0560916974A402A37514B73E74D401CB3EC4960954A40EACDA8F92AE54D401CB3EC4960954A40
55211	Кукушка	6	58	6933	60.502181	60.513849999999998	54.557417000000001	54.550671000000001	0103000020E6100000010000000500000017D68D7747404E4085ED27637C464B4017D68D7747404E40029EB47059474B40598638D6C5414E40029EB47059474B40598638D6C5414E4085ED27637C464B4017D68D7747404E4085ED27637C464B40
55193	Воронино	6	58	6933	59.817827000000001	59.837491	54.372906	54.365924999999997	0103000020E6100000010000000500000095641D8EAEE84D40F7E461A1D62E4B4095641D8EAEE84D40B83D4162BB2F4B40E0D8B3E732EB4D40B83D4162BB2F4B40E0D8B3E732EB4D40F7E461A1D62E4B4095641D8EAEE84D40F7E461A1D62E4B40
55156	Верхняя Кабанка	6	58	6933	60.915244999999999	60.935834	54.448281999999999	54.435809999999996	0103000020E61000000100000005000000EC6987BF26754E4087A2409FC8374B40EC6987BF26754E4057B1F84D61394B40103E9468C9774E4057B1F84D61394B40103E9468C9774E4087A2409FC8374B40EC6987BF26754E4087A2409FC8374B40
55244	Шишминка	6	58	1494	62.800620000000002	62.829141	54.263534	54.255650000000003	0103000020E61000000100000005000000034356B77A664F40789CA223B9204B40034356B77A664F4029B16B7BBB214B40E962D34A216A4F4029B16B7BBB214B40E962D34A216A4F40789CA223B9204B40034356B77A664F40789CA223B9204B40
55223	Шипкино	6	58	1494	62.595480000000002	62.612450000000003	54.335830999999999	54.323523999999999	0103000020E6100000010000000500000007B64AB0384C4F404DBC033C69294B4007B64AB0384C4F40D2FD9C82FC2A4B40B537F8C2644E4F40D2FD9C82FC2A4B40B537F8C2644E4F404DBC033C69294B4007B64AB0384C4F404DBC033C69294B40
55234	Чудиново	6	58	1494	62.507840999999999	62.533622000000001	54.625973999999999	54.611564999999999	0103000020E61000000100000005000000B24813EF00414F406A300DC3474E4B40B24813EF00414F40BA1281EA1F504B408B36C7B94D444F40BA1281EA1F504B408B36C7B94D444F406A300DC3474E4B40B24813EF00414F406A300DC3474E4B40
55240	Чернякино	6	58	1494	63.050260999999999	63.063277999999997	54.414622999999999	54.410808000000003	0103000020E61000000100000005000000D3A1D3F36E864F40B477465B95344B40D3A1D3F36E864F40AF95D05D12354B403447567E19884F40AF95D05D12354B403447567E19884F40B477465B95344B40D3A1D3F36E864F40B477465B95344B40
55182	Харлуши	6	58	1494	62.362456999999999	62.375573000000003	54.190092999999997	54.186399999999999	0103000020E61000000100000005000000679AB0FD642E4F40B9FC87F4DB174B40679AB0FD642E4F406919A9F754184B405C21ACC612304F406919A9F754184B405C21ACC612304F40B9FC87F4DB174B40679AB0FD642E4F40B9FC87F4DB174B40
55167	Уйско-Чебаркульская	6	58	1494	62.624468999999998	62.658999999999999	54.100411000000001	54.089390999999999	0103000020E61000000100000005000000D32EA699EE4F4F4043C70E2A710B4B40D32EA699EE4F4F404F948444DA0C4B403108AC1C5A544F404F948444DA0C4B403108AC1C5A544F4043C70E2A710B4B40D32EA699EE4F4F4043C70E2A710B4B40
55183	Теренкуль	6	58	1494	62.349727999999999	62.373919999999998	54.292720000000003	54.287444000000001	0103000020E610000001000000050000006C3F19E3C32C4F4039B709F7CA244B406C3F19E3C32C4F404C7155D977254B4000A94D9CDC2F4F404C7155D977254B4000A94D9CDC2F4F4039B709F7CA244B406C3F19E3C32C4F4039B709F7CA244B40
55222	Сысоево	6	58	1494	62.719565000000003	62.741186999999996	54.284242999999996	54.271106000000003	0103000020E61000000100000005000000522CB7B41A5C4F40ECDFF599B3224B40522CB7B41A5C4F40F78E1A1362244B40349C3237DF5E4F40F78E1A1362244B40349C3237DF5E4F40ECDFF599B3224B40522CB7B41A5C4F40ECDFF599B3224B40
48175	Степановка	6	58	1494	62.754463999999999	62.763249999999999	54.491076999999997	54.485956999999999	0103000020E610000001000000050000003201BF4692604F409221C7D6333E4B403201BF4692604F40AD68739CDB3E4B4004560E2DB2614F40AD68739CDB3E4B4004560E2DB2614F409221C7D6333E4B403201BF4692604F409221C7D6333E4B40
55184	Спорное	6	58	1494	62.477378999999999	62.490988000000002	54.338838000000003	54.333084999999997	0103000020E610000001000000050000000A664CC11A3D4F40E2E47E87A22A4B400A664CC11A3D4F402F52280B5F2B4B403E5DDDB1D83E4F402F52280B5F2B4B403E5DDDB1D83E4F40E2E47E87A22A4B400A664CC11A3D4F40E2E47E87A22A4B40
55246	Сосновенькое	6	58	1494	62.528357999999997	62.550393999999997	54.220705000000002	54.215251000000002	0103000020E610000001000000050000003C4A253CA1434F4035B742588D1B4B403C4A253CA1434F402788BA0F401C4B4012F5824F73464F402788BA0F401C4B4012F5824F73464F4035B742588D1B4B403C4A253CA1434F4035B742588D1B4B40
48171	Семеновка	6	58	1494	62.615639000000002	62.626328999999998	54.375230000000002	54.371248999999999	0103000020E6100000010000000500000032923D42CD4E4F401BD65416852F4B4032923D42CD4E4F40323D618907304B40A8C4758C2B504F40323D618907304B40A8C4758C2B504F401BD65416852F4B4032923D42CD4E4F401BD65416852F4B40
55188	Свободный	6	58	1494	62.453150999999998	62.471494999999997	54.391311000000002	54.384180999999998	0103000020E6100000010000000500000029931ADA003A4F404E5FCFD72C314B4029931ADA003A4F4054C8957A16324B401F9DBAF2593C4F4054C8957A16324B401F9DBAF2593C4F404E5FCFD72C314B4029931ADA003A4F404E5FCFD72C314B40
55146	Подовинное	6	58	1494	62.494895999999997	62.529409000000001	54.242378000000002	54.225833000000002	0103000020E61000000100000005000000EA758BC0583F4F40C5AD8218E81C4B40EA758BC0583F4F408CA2073E061F4B40A29A92ACC3434F408CA2073E061F4B40A29A92ACC3434F40C5AD8218E81C4B40EA758BC0583F4F40C5AD8218E81C4B40
55191	Окунево	6	58	1494	63.149732	63.158786999999997	54.618670999999999	54.611862000000002	0103000020E6100000010000000500000014950D6B2A934F4024D5777E514E4B4014950D6B2A934F40E7FD7F9C304F4B40D503E62153944F40E7FD7F9C304F4B40D503E62153944F4024D5777E514E4B4014950D6B2A934F4024D5777E514E4B40
55125	Октябрьское	6	58	1494	62.696486999999998	62.759377999999998	54.429321999999999	54.395567999999997	0103000020E61000000100000005000000698B6B7C26594F400CACE3F8A1324B40698B6B7C26594F4006BAF605F4364B40A4A65D4C33614F4006BAF605F4364B40A4A65D4C33614F400CACE3F8A1324B40698B6B7C26594F400CACE3F8A1324B40
19219	Новомосковское	6	58	1494	63.042454999999997	63.067267000000001	54.358879999999999	54.342728000000001	0103000020E610000001000000050000009D465A2A6F854F4035B6D782DE2B4B409D465A2A6F854F402098A3C7EF2D4B40CE8C7E349C884F402098A3C7EF2D4B40CE8C7E349C884F4035B6D782DE2B4B409D465A2A6F854F4035B6D782DE2B4B40
55242	Нововарламово	6	58	1494	62.323146999999999	62.343629	54.394373000000002	54.380437000000001	0103000020E61000000100000005000000776682E15C294F401C98DC28B2304B40776682E15C294F4074B680D07A324B40857AFA08FC2B4F4074B680D07A324B40857AFA08FC2B4F401C98DC28B2304B40776682E15C294F401C98DC28B2304B40
55225	Мяконьки	6	58	1494	62.859316	62.872799000000001	54.664203000000001	54.651192999999999	0103000020E61000000100000005000000FB761211FE6D4F402B31CF4A5A534B40FB761211FE6D4F40DA73999A04554B40A27DACE0B76F4F40DA73999A04554B40A27DACE0B76F4F402B31CF4A5A534B40FB761211FE6D4F402B31CF4A5A534B40
55230	Могильное	6	58	1494	62.573813000000001	62.593423000000001	54.585340000000002	54.573787000000003	0103000020E61000000100000005000000848252B472494F405BEF37DA71494B40848252B472494F403485CE6BEC4A4B40DCD8EC48F54B4F403485CE6BEC4A4B40DCD8EC48F54B4F405BEF37DA71494B40848252B472494F405BEF37DA71494B40
55224	Маячное	6	58	1494	62.767876000000001	62.783965000000002	54.268760999999998	54.260446999999999	0103000020E6100000010000000500000010B1C1C249624F40B0ABC95356214B4010B1C1C249624F405AB8ACC266224B40B51A12F758644F405AB8ACC266224B40B51A12F758644F40B0ABC95356214B4010B1C1C249624F40B0ABC95356214B40
18107	Лысково	6	58	1494	62.675232999999999	62.691160000000004	54.560299000000001	54.549349999999997	0103000020E610000001000000050000000917F2086E564F405F07CE1951464B400917F2086E564F40A27DACE0B7474B40D5264EEE77584F40A27DACE0B7474B40D5264EEE77584F405F07CE1951464B400917F2086E564F405F07CE1951464B40
55199	Лебедки	6	58	1494	62.833973999999998	62.847709000000002	54.464523	54.452444	0103000020E610000001000000050000006EDBF7A8BF6A4F40BEA25BAFE9394B406EDBF7A8BF6A4F40B29E5A7D753B4B402FC37FBA816C4F40B29E5A7D753B4B402FC37FBA816C4F40BEA25BAFE9394B406EDBF7A8BF6A4F40BEA25BAFE9394B40
55198	Лафетное	6	58	1494	63.125540000000001	63.138728	54.521313999999997	54.513866	0103000020E61000000100000005000000802BD9B111904F405F43705CC6414B40802BD9B111904F403579CA6ABA424B400E85CFD6C1914F403579CA6ABA424B400E85CFD6C1914F405F43705CC6414B40802BD9B111904F405F43705CC6414B40
55179	Кузнецово	6	58	1494	62.662754999999997	62.683937	54.610590000000002	54.607081000000001	0103000020E610000001000000050000005721E527D5544F40F18288D4B44D4B405721E527D5544F40E0A128D0274E4B401EC3633F8B574F40E0A128D0274E4B401EC3633F8B574F40F18288D4B44D4B405721E527D5544F40F18288D4B44D4B40
55160	Крутоярский	6	58	1494	63.144773000000001	63.178809999999999	54.200591000000003	54.180529999999997	0103000020E61000000100000005000000022CF2EB87924F4033F9669B1B174B40022CF2EB87924F409C6F44F7AC194B405019FF3EE3964F409C6F44F7AC194B405019FF3EE3964F4033F9669B1B174B40022CF2EB87924F4033F9669B1B174B40
17530	Кочердык	6	58	1494	62.967509	63.003377999999998	54.581384999999997	54.563223000000001	0103000020E61000000100000005000000F7CABC55D77B4F4071ADF6B017484B40F7CABC55D77B4F4046B1DCD26A4A4B4050C3B7B06E804F4046B1DCD26A4A4B4050C3B7B06E804F4071ADF6B017484B40F7CABC55D77B4F4071ADF6B017484B40
55236	Киевка	6	58	1494	62.868918999999998	62.885734999999997	54.401181000000001	54.389183000000003	0103000020E61000000100000005000000BFEFDFBC386F4F406094A0BFD0314B40BFEFDFBC386F4F40676325E659334B4016F6B4C35F714F40676325E659334B4016F6B4C35F714F406094A0BFD0314B40BFEFDFBC386F4F406094A0BFD0314B40
55168	Каракульское	6	58	1494	62.398829999999997	62.447859999999999	54.068857999999999	54.053755000000002	0103000020E61000000100000005000000F35487DC0C334F408D7F9F71E1064B40F35487DC0C334F40B308C556D0084B40E197FA7953394F40B308C556D0084B40E197FA7953394F408D7F9F71E1064B40F35487DC0C334F408D7F9F71E1064B40
55209	Камышное	6	58	1494	62.507311000000001	62.520623999999998	54.121338999999999	54.113835000000002	0103000020E6100000010000000500000056F31C91EF404F40F1113125920E4B4056F31C91EF404F405B5D4E09880F4B40A0C1A6CEA3424F405B5D4E09880F4B40A0C1A6CEA3424F40F1113125920E4B4056F31C91EF404F40F1113125920E4B40
55217	Зуевка	6	58	1494	62.335363999999998	62.351875	54.641123	54.632984	0103000020E61000000100000005000000BC202235ED2A4F401572A59E05514B40BC202235ED2A4F4051DB865110524B40D7A3703D0A2D4F4051DB865110524B40D7A3703D0A2D4F401572A59E05514B40BC202235ED2A4F401572A59E05514B40
55233	Замериново	6	58	1494	62.419932000000003	62.426355000000001	54.679588000000003	54.671008	0103000020E610000001000000050000009E45EF54C0354F405CAD1397E3554B409E45EF54C0354F40856055BDFC564B4038BEF6CC92364F40856055BDFC564B4038BEF6CC92364F405CAD1397E3554B409E45EF54C0354F405CAD1397E3554B40
55192	Журавлиное	6	58	1494	62.828360000000004	62.848562999999999	54.548723000000003	54.540837000000003	0103000020E6100000010000000500000044A852B3076A4F40BFBB95253A454B4044A852B3076A4F4011C8258E3C464B403ECC5EB69D6C4F4011C8258E3C464B403ECC5EB69D6C4F40BFBB95253A454B4044A852B3076A4F40BFBB95253A454B40
55239	Деньгино	6	58	1494	62.695481000000001	62.720345999999999	54.266852	54.261750999999997	0103000020E61000000100000005000000A4FE7A8505594F40FF58880E81214B40A4FE7A8505594F40A46FD23428224B40F7E6374C345C4F40A46FD23428224B40F7E6374C345C4F40FF58880E81214B40A4FE7A8505594F40FF58880E81214B40
55174	Горелое	6	58	1494	62.995994000000003	63.010438999999998	54.505451000000001	54.495919000000001	0103000020E6100000010000000500000091813CBB7C7F4F40863B17467A3F4B4091813CBB7C7F4F40815D4D9EB2404B402DCDAD1056814F40815D4D9EB2404B402DCDAD1056814F40863B17467A3F4B4091813CBB7C7F4F40863B17467A3F4B40
55180	Ваганово	6	58	1494	62.305720000000001	62.326875000000001	54.505749000000002	54.489409000000002	0103000020E61000000100000005000000D7DD3CD521274F401DAF40F4A43E4B40D7DD3CD521274F400B7E1B62BC404B40A4703D0AD7294F400B7E1B62BC404B40A4703D0AD7294F401DAF40F4A43E4B40D7DD3CD521274F401DAF40F4A43E4B40
55228	Быково	6	58	1494	62.981945000000003	62.991512	54.292814999999997	54.281956000000001	0103000020E6100000010000000500000041BCAE5FB07D4F409B745B2217244B4041BCAE5FB07D4F409D6340F67A254B40B8CB7EDDE97E4F409D6340F67A254B40B8CB7EDDE97E4F409B745B2217244B4041BCAE5FB07D4F409B745B2217244B40
55227	Буланово	6	58	1494	62.634557000000001	62.648201999999998	54.494999	54.485863000000002	0103000020E610000001000000050000005439ED2939514F4011AB3FC2303E4B405439ED2939514F40BF4692205C3F4B40D4997B48F8524F40BF4692205C3F4B40D4997B48F8524F4011AB3FC2303E4B405439ED2939514F4011AB3FC2303E4B40
17329	Боровое	6	58	1494	62.290098	62.315519999999999	54.660823000000001	54.652537000000002	0103000020E61000000100000005000000485167EE21254F400937195586534B40485167EE21254F40E9B81AD995544B40F19D98F562284F40E9B81AD995544B40F19D98F562284F400937195586534B40485167EE21254F400937195586534B40
18616	Большеникольское	6	58	1494	62.163741000000002	62.190116000000003	54.556592000000002	54.535457000000001	0103000020E61000000100000005000000D6011077F5144F4007B5DFDA89444B40D6011077F5144F408D9B1A683E474B40223999B855184F408D9B1A683E474B40223999B855184F4007B5DFDA89444B40D6011077F5144F4007B5DFDA89444B40
55231	Березовский	6	58	1494	62.807572999999998	62.833157	54.122399999999999	54.112662999999998	0103000020E61000000100000005000000F910548D5E674F40103CBEBD6B0E4B40F910548D5E674F40E4839ECDAA0F4B407CB779E3A46A4F40E4839ECDAA0F4B407CB779E3A46A4F40103CBEBD6B0E4B40F910548D5E674F40103CBEBD6B0E4B40
55226	Барсучье	6	58	1494	62.630550999999997	62.652847000000001	54.451177000000001	54.443282000000004	0103000020E61000000100000005000000E4BA29E5B5504F40E773EE76BD384B40E4BA29E5B5504F408CDAFD2AC0394B405725917D90534F408CDAFD2AC0394B405725917D90534F40E773EE76BD384B40E4BA29E5B5504F40E773EE76BD384B40
55176	Банниково	6	58	1494	63.074883999999997	63.089616999999997	54.680774	54.673350999999997	0103000020E61000000100000005000000307F85CC95894F404CDD955D30564B40307F85CC95894F40CAFB389A23574B403315E291788B4F40CAFB389A23574B403315E291788B4F404CDD955D30564B40307F85CC95894F404CDD955D30564B40
55220	Бакшан	6	58	1494	62.287393999999999	62.307777000000002	54.633771000000003	54.619906	0103000020E6100000010000000500000087889B53C9244F400E4C6E14594F4B4087889B53C9244F409D137B681F514B4002BB9A3C65274F409D137B681F514B4002BB9A3C65274F400E4C6E14594F4B4087889B53C9244F400E4C6E14594F4B40
55247	Александровка	6	58	1494	62.217281	62.234968000000002	54.484383000000001	54.470148000000002	0103000020E61000000100000005000000668522DDCF1B4F40D12346CF2D3C4B40668522DDCF1B4F4083DE1B43003E4B40A3CD716E131E4F4083DE1B43003E4B40A3CD716E131E4F40D12346CF2D3C4B40668522DDCF1B4F40D12346CF2D3C4B40
51931	Медведевка	6	58	5668	21.710574000000001	21.720195	54.463712000000001	54.456349000000003	0103000020E610000001000000050000004E637B2DE8B53540FA47DFA4693A4B404E637B2DE8B53540A26131EA5A3B4B4023BE13B35EB83540A26131EA5A3B4B4023BE13B35EB83540FA47DFA4693A4B404E637B2DE8B53540FA47DFA4693A4B40
23965	Шемаха	6	58	921	59.252526000000003	59.276896999999998	56.254716999999999	56.229807000000001	0103000020E61000000100000005000000E2B19FC552A04D4029B2D6506A1D4C40E2B19FC552A04D401C5E10919A204C4025AE635C71A34D401C5E10919A204C4025AE635C71A34D4029B2D6506A1D4C40E2B19FC552A04D4029B2D6506A1D4C40
24313	Ункурда	6	58	921	59.389536999999997	59.425964	55.811174000000001	55.792558999999997	0103000020E610000001000000050000007DCA3159DCB14D404293C49272E54B407DCA3159DCB14D40C9AEB48CD4E74B40FDA204FD85B64D40C9AEB48CD4E74B40FDA204FD85B64D404293C49272E54B407DCA3159DCB14D404293C49272E54B40
24177	Ташкинова	6	58	921	59.185862	59.217185999999998	56.165669000000001	56.150108000000003	0103000020E61000000100000005000000DAC87553CA974D401A6F2BBD36134C40DAC87553CA974D40037B4CA434154C40149337C0CC9B4D40037B4CA434154C40149337C0CC9B4D401A6F2BBD36134C40DAC87553CA974D401A6F2BBD36134C40
24018	Сказ	6	58	921	59.310448999999998	59.329403999999997	56.292543000000002	56.282969999999999	0103000020E61000000100000005000000B709F7CABCA74D40E3DF675C38244C40B709F7CABCA74D403DD68C0C72254C40F69507E929AA4D403DD68C0C72254C40F69507E929AA4D40E3DF675C38244C40B709F7CABCA74D40E3DF675C38244C40
7338	Ситцева	6	58	921	59.718769000000002	59.745952000000003	55.795245999999999	55.779888999999997	0103000020E610000001000000050000007730629F00DC4D404CC11A67D3E34B407730629F00DC4D402D23F59ECAE54B406231EA5A7BDF4D402D23F59ECAE54B406231EA5A7BDF4D404CC11A67D3E34B407730629F00DC4D404CC11A67D3E34B40
24455	Нестерово	6	58	921	59.449311000000002	59.475560000000002	55.856735	55.848488000000003	0103000020E61000000100000005000000D55DD90583B94D40348639419BEC4B40D55DD90583B94D40562B137EA9ED4B4094A46B26DFBC4D40562B137EA9ED4B4094A46B26DFBC4D40348639419BEC4B40D55DD90583B94D40348639419BEC4B40
24163	Межевая	6	58	921	59.145679999999999	59.163431000000003	56.176915000000001	56.170811	0103000020E6100000010000000500000034D769A4A5924D4006668522DD154C4034D769A4A5924D40FF959526A5164C408813984EEB944D40FF959526A5164C408813984EEB944D4006668522DD154C4034D769A4A5924D4006668522DD154C40
24520	Котово	6	58	921	59.593535000000003	59.610360999999997	55.864913999999999	55.857017999999997	0103000020E61000000100000005000000040473F4F8CB4D40AA0A0DC4B2ED4B40040473F4F8CB4D4020ED7F80B5EE4B407EE02A4F20CE4D4020ED7F80B5EE4B407EE02A4F20CE4D40AA0A0DC4B2ED4B40040473F4F8CB4D40AA0A0DC4B2ED4B40
24261	Кедровый	6	58	921	59.374544	59.379224000000001	55.970135999999997	55.967542000000002	0103000020E61000000100000005000000DE74CB0EF1AF4D40D3C08F6AD8FB4B40DE74CB0EF1AF4D400C569C6A2DFC4B40DDED7A698AB04D400C569C6A2DFC4B40DDED7A698AB04D40D3C08F6AD8FB4B40DE74CB0EF1AF4D40D3C08F6AD8FB4B40
24356	Калиновка	6	58	921	59.274867	59.306891999999998	55.828125999999997	55.818012000000003	0103000020E61000000100000005000000F4DF83D72EA34D4027DE019EB4E84B40F4DF83D72EA34D40D07B630800EA4B40B7B3AF3C48A74D40D07B630800EA4B40B7B3AF3C48A74D4027DE019EB4E84B40F4DF83D72EA34D4027DE019EB4E84B40
24665	Гривенка	6	58	921	59.596715000000003	59.618760000000002	55.628698	55.621521000000001	0103000020E610000001000000050000002E04392861CC4D407C6308008ECF4B402E04392861CC4D40C287122D79D04B405709168733CF4D40C287122D79D04B405709168733CF4D407C6308008ECF4B402E04392861CC4D407C6308008ECF4B40
24406	Беляево	6	58	921	59.281433999999997	59.314940999999997	55.905557999999999	55.896948000000002	0103000020E61000000100000005000000C1FD800706A44D40371B2B31CFF24B40C1FD800706A44D40CA501553E9F34B40B39597FC4FA84D40CA501553E9F34B40B39597FC4FA84D40371B2B31CFF24B40C1FD800706A44D40371B2B31CFF24B40
24060	Арасланово	6	58	921	59.282367999999998	59.309559999999998	56.214922000000001	56.196567000000002	0103000020E61000000100000005000000EDB776A224A44D40863C821B29194C40EDB776A224A44D4070986890821B4C402B137EA99FA74D4070986890821B4C402B137EA99FA74D40863C821B29194C40EDB776A224A44D40863C821B29194C40
24617	Аптрякова	6	58	921	59.703192999999999	59.722354000000003	55.714210999999999	55.703307000000002	0103000020E6100000010000000500000058E36C3A02DA4D402106BAF605DA4B4058E36C3A02DA4D40C3B81B446BDB4B4041118B1876DC4D40C3B81B446BDB4B4041118B1876DC4D402106BAF605DA4B4058E36C3A02DA4D402106BAF605DA4B40
53078	Южный	6	58	1486	60.037761000000003	60.088749999999997	53.540120999999999	53.519058999999999	0103000020E610000001000000050000003A083A5AD5044E40E4D87A8670C24A403A083A5AD5044E40007157AF22C54A408FC2F5285C0B4E40007157AF22C54A408FC2F5285C0B4E40E4D87A8670C24A403A083A5AD5044E40E4D87A8670C24A40
17495	Чернореченский	6	58	1486	59.507601999999999	59.517178000000001	53.732498999999997	53.726393999999999	0103000020E610000001000000050000002DB1321AF9C04D405C01857AFADC4A402DB1321AF9C04D4025ADF886C2DD4A40F81A82E332C24D4025ADF886C2DD4A40F81A82E332C24D405C01857AFADC4A402DB1321AF9C04D405C01857AFADC4A40
53077	Фершампенуаз	6	58	1486	59.799734999999998	59.843662000000002	53.532018000000001	53.507016999999998	0103000020E61000000100000005000000B83B6BB75DE64D400DC2DCEEE5C04A40B83B6BB75DE64D401171732A19C44A406170CD1DFDEB4D401171732A19C44A406170CD1DFDEB4D400DC2DCEEE5C04A40B83B6BB75DE64D400DC2DCEEE5C04A40
17223	Требиятский	6	58	1486	59.590390999999997	59.599662000000002	53.415900999999998	53.406357999999997	0103000020E61000000100000005000000266DAAEE91CB4D40E63BF88903B44A40266DAAEE91CB4D40D5AF743E3CB54A40B55373B9C1CC4D40D5AF743E3CB54A40B55373B9C1CC4D40E63BF88903B44A40266DAAEE91CB4D40E63BF88903B44A40
17875	Совхозный	6	58	1486	59.393462	59.405355999999998	53.545417999999998	53.540244000000001	0103000020E61000000100000005000000001C7BF65CB24D401CEE23B726C54A40001C7BF65CB24D402A53CC41D0C54A40629E95B4E2B34D402A53CC41D0C54A40629E95B4E2B34D401CEE23B726C54A40001C7BF65CB24D401CEE23B726C54A40
18869	Слюда	6	58	1486	59.880223999999998	59.889800000000001	53.407963000000002	53.399647000000002	0103000020E61000000100000005000000C093162EABF04D40E67805A227B34A40C093162EABF04D40317DAF2138B44A408BFD65F7E4F14D40317DAF2138B44A408BFD65F7E4F14D40E67805A227B34A40C093162EABF04D40E67805A227B34A40
17586	Северный	6	58	1486	60.039019000000003	60.055394999999997	53.594766999999997	53.579363000000001	0103000020E6100000010000000500000019761893FE044E4098C1189128CA4A4019761893FE044E40B9DE365321CC4A4053AEF02E17074E40B9DE365321CC4A4053AEF02E17074E4098C1189128CA4A4019761893FE044E4098C1189128CA4A40
18698	Рассвет	6	58	1486	59.807226999999997	59.818240000000003	53.451622999999998	53.446550000000002	0103000020E610000001000000050000005EB9DE3653E74D40B003E78C28B94A405EB9DE3653E74D408A8F4FC8CEB94A40B8239C16BCE84D408A8F4FC8CEB94A40B8239C16BCE84D40B003E78C28B94A405EB9DE3653E74D40B003E78C28B94A40
18177	Придорожный	6	58	1486	59.660828000000002	59.675623000000002	53.638159999999999	53.627620999999998	0103000020E61000000100000005000000FB230C0396D44D4033A48AE255D04A40FB230C0396D44D40C4CE143AAFD14A4074B680D07AD64D40C4CE143AAFD14A4074B680D07AD64D4033A48AE255D04A40FB230C0396D44D4033A48AE255D04A40
53072	Подгорный	6	58	1486	59.424984000000002	59.440686999999997	53.721919	53.715801999999996	0103000020E6100000010000000500000061A92EE065B64D40A83462669FDB4A4061A92EE065B64D4036AE7FD767DC4A40DC627E6E68B84D4036AE7FD767DC4A40DC627E6E68B84D40A83462669FDB4A4061A92EE065B64D40A83462669FDB4A40
17948	Петровский	6	58	1486	59.558284999999998	59.571032000000002	53.597872000000002	53.587674999999997	0103000020E61000000100000005000000766C04E275C74D40A1D634EF38CB4A40766C04E275C74D40D998D71187CC4A40187C9A9317C94D40D998D71187CC4A40187C9A9317C94D40A1D634EF38CB4A40766C04E275C74D40A1D634EF38CB4A40
18551	Переселенческий	6	58	1486	59.710909000000001	59.722875000000002	53.573990000000002	53.563567999999997	0103000020E610000001000000050000004EB7EC10FFDA4D403B8908FF22C84A404EB7EC10FFDA4D40931D1B8178C94A404A0C022B87DC4D40931D1B8178C94A404A0C022B87DC4D403B8908FF22C84A404EB7EC10FFDA4D403B8908FF22C84A40
18234	Париж	6	58	1486	60.078696999999998	60.117719999999998	53.320635000000003	53.285975999999998	0103000020E610000001000000050000008BA548BE120A4E406FB88FDC9AA44A408BA548BE120A4E40FB7953910AA94A40E50AEF72110F4E40FB7953910AA94A40E50AEF72110F4E406FB88FDC9AA44A408BA548BE120A4E406FB88FDC9AA44A40
53075	Остроленский	6	58	1486	59.711942000000001	59.738137000000002	53.691879999999998	53.676543000000002	0103000020E610000001000000050000000D535BEA20DB4D403BAB05F698D64A400D535BEA20DB4D40D4601A868FD84A40D97BF1457BDE4D40D4601A868FD84A40D97BF1457BDE4D403BAB05F698D64A400D535BEA20DB4D403BAB05F698D64A40
18367	Новочерниговский	6	58	1486	59.842908000000001	59.856938999999997	53.254477999999999	53.246304000000002	0103000020E61000000100000005000000B5C4CA68E4EB4D40DF6FB4E3869F4A40B5C4CA68E4EB4D4097C62FBC92A04A405ED5592DB0ED4D4097C62FBC92A04A405ED5592DB0ED4D40DF6FB4E3869F4A40B5C4CA68E4EB4D40DF6FB4E3869F4A40
53073	Нагайбакский	6	58	1486	59.509236999999999	59.544972000000001	53.551340000000003	53.534063000000003	0103000020E61000000100000005000000E27492AD2EC14D407880272D5CC44A40E27492AD2EC14D40037D224F92C64A402C9E7AA4C1C54D40037D224F92C64A402C9E7AA4C1C54D407880272D5CC44A40E27492AD2EC14D407880272D5CC44A40
17747	Набережный	6	58	1486	59.968904999999999	59.978983999999997	53.544170999999999	53.537959000000001	0103000020E6100000010000000500000027F73B1405FC4D4060CB2BD7DBC44A4027F73B1405FC4D403F373465A7C54A4054A703594FFD4D403F373465A7C54A4054A703594FFD4D4060CB2BD7DBC44A4027F73B1405FC4D4060CB2BD7DBC44A40
17787	Лесные Поляны	6	58	1486	59.878463000000004	59.888102000000003	53.650506999999998	53.645356	0103000020E610000001000000050000007FDFBF7971F04D40812381069BD24A407FDFBF7971F04D40D76839D043D34A4090C18A53ADF14D40D76839D043D34A4090C18A53ADF14D40812381069BD24A407FDFBF7971F04D40812381069BD24A40
18274	Лебединое	6	58	1486	59.869928999999999	59.896859999999997	53.266365999999998	53.257612999999999	0103000020E61000000100000005000000C66B5ED559EF4D4021037976F9A04A40C66B5ED559EF4D401762F54718A24A40978BF84ECCF24D401762F54718A24A40978BF84ECCF24D4021037976F9A04A40C66B5ED559EF4D4021037976F9A04A40
55243	Куропатнинский	6	58	1486	59.660550000000001	59.674491000000003	53.761806	53.753241000000003	0103000020E61000000100000005000000B8AF03E78CD44D40D0807A336AE04A40B8AF03E78CD44D40C3F2E7DB82E14A40223999B855D64D40C3F2E7DB82E14A40223999B855D64D40D0807A336AE04A40B8AF03E78CD44D40D0807A336AE04A40
18799	Курганный	6	58	1486	59.662185000000001	59.674860000000002	53.464550000000003	53.454535	0103000020E610000001000000050000006D73637AC2D44D4095F1EF332EBA4A406D73637AC2D44D40ACADD85F76BB4A4075B0FECF61D64D40ACADD85F76BB4A4075B0FECF61D64D4095F1EF332EBA4A406D73637AC2D44D4095F1EF332EBA4A40
17661	Куликовский	6	58	1486	60.016264	60.032874	53.603734000000003	53.594676	0103000020E61000000100000005000000130D52F014024E40A9DBD9571ECC4A40130D52F014024E40DCBDDC2747CD4A40C171193735044E40DCBDDC2747CD4A40C171193735044E40A9DBD9571ECC4A40130D52F014024E40A9DBD9571ECC4A40
18325	Кужебаевский	6	58	1486	60.265484000000001	60.279381000000001	53.311774999999997	53.303888000000001	0103000020E610000001000000050000003ECE3461FB214E40CCD24ECDE5A64A403ECE3461FB214E40EE5A423EE8A74A40D80FB1C1C2234E40EE5A423EE8A74A40D80FB1C1C2234E40CCD24ECDE5A64A403ECE3461FB214E40CCD24ECDE5A64A40
18490	Крупское	6	58	1486	59.755358000000001	59.76567	53.616331000000002	53.601858	0103000020E61000000100000005000000D0622992AFE04D40016BD5AE09CD4A40D0622992AFE04D40684128EFE3CE4A40A0C37C7901E24D40684128EFE3CE4A40A0C37C7901E24D40016BD5AE09CD4A40D0622992AFE04D40016BD5AE09CD4A40
53071	Кассельский	6	58	1486	59.559462000000003	59.579206999999997	53.809285000000003	53.793103000000002	0103000020E6100000010000000500000069AD68739CC74D4004AE2B6684E54A4069AD68739CC74D405A12A0A696E74A40A04E797423CA4D405A12A0A696E74A40A04E797423CA4D4004AE2B6684E54A4069AD68739CC74D4004AE2B6684E54A40
17123	Калининский	6	58	1486	59.938209999999998	59.954414999999997	53.687508000000001	53.680010000000003	0103000020E61000000100000005000000DC63E94317F84D40FB7953910AD74A40DC63E94317F84D4083DE1B4300D84A40EAE74D452AFA4D4083DE1B4300D84A40EAE74D452AFA4D40FB7953910AD74A40DC63E94317F84D40FB7953910AD74A40
18758	Знаменка	6	58	1486	59.965591000000003	59.978149000000002	53.537391	53.529074999999999	0103000020E61000000100000005000000EE27637C98FB4D40CB10C7BAB8C34A40EE27637C98FB4D401615713AC9C44A40BCCE86FC33FD4D401615713AC9C44A40BCCE86FC33FD4D40CB10C7BAB8C34A40EE27637C98FB4D40CB10C7BAB8C34A40
17291	Заречный	6	58	1486	59.735926999999997	59.74474	53.406534999999998	53.400410000000001	0103000020E61000000100000005000000279F1EDB32DE4D40E57E87A240B34A40279F1EDB32DE4D40F5D6C05609B44A40F302ECA353DF4D40F5D6C05609B44A40F302ECA353DF4D40E57E87A240B34A40279F1EDB32DE4D40E57E87A240B34A40
18433	Гумбейский	6	58	1486	59.734310000000001	59.756346000000001	53.573647000000001	53.564354000000002	0103000020E610000001000000050000001990BDDEFDDD4D40F3AE7AC03CC84A401990BDDEFDDD4D406939D0436DC94A40EF3A1BF2CFE04D406939D0436DC94A40EF3A1BF2CFE04D40F3AE7AC03CC84A401990BDDEFDDD4D40F3AE7AC03CC84A40
17989	Березовая Роща	6	58	1486	59.487282999999998	59.498573999999998	53.561326999999999	53.55547	0103000020E61000000100000005000000C972124A5FBE4D405EF415A419C74A40C972124A5FBE4D404FAE2990D9C74A406551D845D1BF4D404FAE2990D9C74A406551D845D1BF4D405EF415A419C74A40C972124A5FBE4D405EF415A419C74A40
17192	Балканы	6	58	1486	59.595278	59.615417999999998	53.447366000000002	53.432727999999997	0103000020E610000001000000050000009F03CB1132CC4D40200890A163B74A409F03CB1132CC4D40D2AB014A43B94A4053AF5B04C6CE4D40D2AB014A43B94A4053AF5B04C6CE4D40200890A163B74A409F03CB1132CC4D40200890A163B74A40
17677	Астафьевский	6	58	1486	60.064287999999998	60.078364999999998	53.477916999999998	53.471801999999997	0103000020E610000001000000050000003BC3D4963A084E40FC17080264BC4A403BC3D4963A084E40E9995E622CBD4A40551344DD070A4E40E9995E622CBD4A40551344DD070A4E40FC17080264BC4A403BC3D4963A084E40FC17080264BC4A40
53070	Арсинский	6	58	1486	59.877124000000002	59.893940999999998	53.760869	53.740962000000003	0103000020E61000000100000005000000B344679945F04D4015CAC2D7D7DE4A40B344679945F04D4026C5C72764E14A40DAC69FA86CF24D4026C5C72764E14A40DAC69FA86CF24D4015CAC2D7D7DE4A40B344679945F04D4015CAC2D7D7DE4A40
18046	Арасламбаевский	6	58	1486	59.596544999999999	59.610711000000002	53.547750000000001	53.539349999999999	0103000020E61000000100000005000000D1CB28965BCC4D407E8CB96B09C54A40D1CB28965BCC4D40273108AC1CC64A405B272EC72BCE4D40273108AC1CC64A405B272EC72BCE4D407E8CB96B09C54A40D1CB28965BCC4D407E8CB96B09C54A40
17367	Александро-Невский	6	58	1486	59.729970999999999	59.742907000000002	53.385831000000003	53.376232999999999	0103000020E61000000100000005000000A30392B06FDD4D408656276728B04A40A30392B06FDD4D40396403E962B14A40187C9A9317DF4D40396403E962B14A40187C9A9317DF4D408656276728B04A40A30392B06FDD4D408656276728B04A40
55204	Октябрьский	6	58	1686	59.512363000000001	59.524310999999997	55.410806000000001	55.400742000000001	0103000020E6100000010000000500000019575C1C95C14D401B118C834BB34B4019575C1C95C14D4013807F4A95B44B406EF7729F1CC34D4013807F4A95B44B406EF7729F1CC34D401B118C834BB34B4019575C1C95C14D401B118C834BB34B40
55169	Магнитка	6	58	1686	59.664017000000001	59.722766999999997	55.365397000000002	55.322307000000002	0103000020E61000000100000005000000787E5182FED44D40CD22145B41A94B40787E5182FED44D403C873254C5AE4B4063D009A183DC4D403C873254C5AE4B4063D009A183DC4D40CD22145B41A94B40787E5182FED44D40CD22145B41A94B40
40400	Ковали	6	58	1686	59.646023999999997	59.666299000000002	55.343471000000001	55.327997000000003	0103000020E610000001000000050000002E3718EAB0D24D40D31742CEFBA94B402E3718EAB0D24D40ED0F94DBF6AB4B40C32D1F4949D54D40ED0F94DBF6AB4B40C32D1F4949D54D40D31742CEFBA94B402E3718EAB0D24D40D31742CEFBA94B40
22271	Каскиново	6	58	1686	59.401628000000002	59.418750000000003	55.465482999999999	55.457377999999999	0103000020E610000001000000050000003694DA8B68B34D4077F4BF5C8BBA4B403694DA8B68B34D4007EC6AF294BB4B409A99999999B54D4007EC6AF294BB4B409A99999999B54D4077F4BF5C8BBA4B403694DA8B68B34D4077F4BF5C8BBA4B40
40401	Злоказово	6	58	1686	59.434640999999999	59.478344	55.472898000000001	55.447324999999999	0103000020E610000001000000050000001840F850A2B74D4073D712F241B94B401840F850A2B74D40022CF2EB87BC4B40711E4E603ABD4D40022CF2EB87BC4B40711E4E603ABD4D4073D712F241B94B401840F850A2B74D4073D712F241B94B40
55216	Вознесенка	6	58	1686	59.614806999999999	59.630671999999997	55.542385000000003	55.531523999999997	0103000020E610000001000000050000000A2DEBFEB1CE4D4001857AFA08C44B400A2DEBFEB1CE4D40A56B26DF6CC54B405F402FDCB9D04D40A56B26DF6CC54B405F402FDCB9D04D4001857AFA08C44B400A2DEBFEB1CE4D4001857AFA08C44B40
55197	Александровка	6	58	1686	59.825301000000003	59.837130999999999	55.483075999999997	55.471831999999999	0103000020E61000000100000005000000952D9276A3E94D40679AB0FD64BC4B40952D9276A3E94D40C2BD326FD5BD4B40E0BBCD1B27EB4D40C2BD326FD5BD4B40E0BBCD1B27EB4D40679AB0FD64BC4B40952D9276A3E94D40679AB0FD64BC4B40
20493	Юлдашева	6	58	161	61.358086999999998	61.370071000000003	55.901097	55.893535999999997	0103000020E61000000100000005000000B60F79CBD5AD4E403AE63C635FF24B40B60F79CBD5AD4E4009C3802557F34B4059198D7C5EAF4E4009C3802557F34B4059198D7C5EAF4E403AE63C635FF24B40B60F79CBD5AD4E403AE63C635FF24B40
20693	Элеваторный	6	58	161	61.885244999999998	61.892423000000001	56.116222	56.108673000000003	0103000020E6100000010000000500000048F949B54FF14E40A77A32FFE80D4C4048F949B54FF14E40B189CC5CE00E4C405F99B7EA3AF24E40B189CC5CE00E4C405F99B7EA3AF24E40A77A32FFE80D4C4048F949B54FF14E40A77A32FFE80D4C40
20910	Чекурова	6	58	161	61.694892000000003	61.707135999999998	56.043236	56.034174	0103000020E6100000010000000500000043209738F2D84E40CF2F4AD05F044C4043209738F2D84E404301DBC188054C4081E9B46E83DA4E404301DBC188054C4081E9B46E83DA4E40CF2F4AD05F044C4043209738F2D84E40CF2F4AD05F044C40
48266	Халитово	6	58	161	61.730545999999997	61.762597999999997	55.876283999999998	55.855319999999999	0103000020E610000001000000050000009F1C058882DD4E40AFCE31207BED4B409F1C058882DD4E400801F9122AF04B405CFFAECF9CE14E400801F9122AF04B405CFFAECF9CE14E40AFCE31207BED4B409F1C058882DD4E40AFCE31207BED4B40
48112	Усть-Багаряк	6	58	161	61.826424000000003	61.902025999999999	56.146407000000004	56.114350000000002	0103000020E610000001000000050000009450FA42C8E94E4018265305A30E4C409450FA42C8E94E40E773EE76BD124C402312859675F34E40E773EE76BD124C402312859675F34E4018265305A30E4C409450FA42C8E94E4018265305A30E4C40
45933	Трудовой	6	58	161	61.725093999999999	61.753551999999999	55.995060000000002	55.986505999999999	0103000020E610000001000000050000004E4354E1CFDC4E4065A71FD445FE4B404E4354E1CFDC4E4065C746205EFF4B40EEEA556474E04E4065C746205EFF4B40EEEA556474E04E4065A71FD445FE4B404E4354E1CFDC4E4065A71FD445FE4B40
21051	Тахталым	6	58	161	61.730690000000003	61.741227000000002	55.894944000000002	55.881338	0103000020E61000000100000005000000D3C1FA3F87DD4E406C5CFFAECFF04B40D3C1FA3F87DD4E402FE065868DF24B40C3F4BD86E0DE4E402FE065868DF24B40C3F4BD86E0DE4E406C5CFFAECFF04B40D3C1FA3F87DD4E406C5CFFAECFF04B40
20350	Татарская Караболка	6	58	161	61.162855999999998	61.207709000000001	55.953099999999999	55.932015999999997	0103000020E610000001000000050000008BFA2477D8944E40A3ACDF4C4CF74B408BFA2477D8944E40A7E8482EFFF94B40DD0A6135969A4E40A7E8482EFFF94B40DD0A6135969A4E40A3ACDF4C4CF74B408BFA2477D8944E40A3ACDF4C4CF74B40
19817	Сураково	6	58	161	61.592413000000001	61.608097000000001	55.498367000000002	55.480714999999996	0103000020E61000000100000005000000D55C6E30D4CB4E402BD9B11188BD4B40D55C6E30D4CB4E40EC33677DCABF4B40DAE55B1FD6CD4E40EC33677DCABF4B40DAE55B1FD6CD4E402BD9B11188BD4B40D55C6E30D4CB4E402BD9B11188BD4B40
19636	Султаново	6	58	161	61.776873000000002	61.793419999999998	55.640481999999999	55.623502999999999	0103000020E610000001000000050000009D12109370E34E409CFA40F2CECF4B409D12109370E34E409DD66D50FBD14B4004FF5BC98EE54E409DD66D50FBD14B4004FF5BC98EE54E409CFA40F2CECF4B409D12109370E34E409CFA40F2CECF4B40
19506	Сосновка	6	58	161	61.787005999999998	61.799618000000002	55.892843999999997	55.883606	0103000020E61000000100000005000000BDE0D39CBCE44E4052465C001AF14B40BDE0D39CBCE44E40043752B648F24B407FA5F3E159E64E40043752B648F24B407FA5F3E159E64E4052465C001AF14B40BDE0D39CBCE44E4052465C001AF14B40
48167	Синарский	6	58	161	61.878427000000002	61.889916999999997	56.130958999999997	56.123638999999997	0103000020E610000001000000050000003276C24B70F04E404CC11A67D30F4C403276C24B70F04E40F50EB743C3104C40C493DDCCE8F14E40F50EB743C3104C40C493DDCCE8F14E404CC11A67D30F4C403276C24B70F04E404CC11A67D30F4C40
55195	Серкино	6	58	161	61.824052000000002	61.835577000000001	56.010930999999999	56.002113000000001	0103000020E61000000100000005000000091A33897AE94E40BFF2203D45004C40091A33897AE94E409CC1DF2F66014C401825E82FF4EA4E409CC1DF2F66014C401825E82FF4EA4E40BFF2203D45004C40091A33897AE94E40BFF2203D45004C40
55215	Сарыкульмяк	6	58	161	61.050189000000003	61.070248999999997	55.769823000000002	55.757576999999998	0103000020E610000001000000050000003ACFD8976C864E40D4997B48F8E04B403ACFD8976C864E40B45A608F89E24B40D1C952EBFD884E40B45A608F89E24B40D1C952EBFD884E40D4997B48F8E04B403ACFD8976C864E40D4997B48F8E04B40
61103	Разъезд N2	6	58	161	60.923679999999997	62.242739	56.239848000000002	55.439450999999998	0103000020E6100000010000000500000011FC6F253B764E40E5982CEE3FB84B4011FC6F253B764E406901DA56B31E4C405C3B5112121F4F406901DA56B31E4C405C3B5112121F4F40E5982CEE3FB84B4011FC6F253B764E40E5982CEE3FB84B40
19754	Нугуманово	6	58	161	61.780565000000003	61.809094999999999	55.499656999999999	55.486372000000003	0103000020E610000001000000050000007DB3CD8DE9E34E4056D80C7041BE4B407DB3CD8DE9E34E40D61BB5C2F4BF4B40B62DCA6C90E74E40D61BB5C2F4BF4B40B62DCA6C90E74E4056D80C7041BE4B407DB3CD8DE9E34E4056D80C7041BE4B40
19698	Новое Курманово	6	58	161	61.714241999999999	61.750399000000002	55.541091999999999	55.524859999999997	0103000020E61000000100000005000000FEB627486CDB4E40417DCB9C2EC34B40FEB627486CDB4E404910AE8042C54B40BEF90D130DE04E404910AE8042C54B40BEF90D130DE04E40417DCB9C2EC34B40FEB627486CDB4E40417DCB9C2EC34B40
478	Новобурино	6	58	161	61.631956000000002	61.667251	55.991515999999997	55.968891999999997	0103000020E61000000100000005000000684128EFE3D04E4092AD2EA704FC4B40684128EFE3D04E40F9BA0CFFE9FE4B40959C137B68D54E40F9BA0CFFE9FE4B40959C137B68D54E4092AD2EA704FC4B40684128EFE3D04E4092AD2EA704FC4B40
19595	Муслюмово	6	58	161	61.583914	61.625892999999998	55.599626000000001	55.573576000000003	0103000020E6100000010000000500000099D6A6B1BDCA4E40A0E238F06AC94B4099D6A6B1BDCA4E4068EA758BC0CC4B40CDE506431DD04E4068EA758BC0CC4B40CDE506431DD04E40A0E238F06AC94B4099D6A6B1BDCA4E40A0E238F06AC94B40
28035	Метлино	6	58	161	60.971901000000003	61.009189999999997	55.794097000000001	55.783867999999998	0103000020E6100000010000000500000090F98040677C4E40C23060C955E44B4090F98040677C4E40056D72F8A4E54B40A1B94E232D814E40056D72F8A4E54B40A1B94E232D814E40C23060C955E44B4090F98040677C4E40C23060C955E44B40
47716	Маяк	6	58	161	61.683062	61.697408000000003	55.854956000000001	55.845638000000001	0103000020E61000000100000005000000F7915B936ED74E409F20B1DD3DEC4B40F7915B936ED74E406EC2BD326FED4B4001FC53AA44D94E406EC2BD326FED4B4001FC53AA44D94E409F20B1DD3DEC4B40F7915B936ED74E409F20B1DD3DEC4B40
21101	Мансурова	6	58	161	61.643706000000002	61.662787000000002	55.912495999999997	55.901176999999997	0103000020E61000000100000005000000971E4DF564D24E40257497C459F34B40971E4DF564D24E408BDD3EABCCF44B40639B5434D6D44E408BDD3EABCCF44B40639B5434D6D44E40257497C459F34B40971E4DF564D24E40257497C459F34B40
47680	Лесной	6	58	161	61.624105	61.633851999999997	55.678164000000002	55.670594999999999	0103000020E61000000100000005000000922232ACE2CF4E4039EE940ED6D54B40922232ACE2CF4E408BA9F413CED64B408940F50F22D14E408BA9F413CED64B408940F50F22D14E4039EE940ED6D54B40922232ACE2CF4E4039EE940ED6D54B40
19221	Кунашак	6	58	161	61.511662999999999	61.580689999999997	55.715327000000002	55.681285000000003	0103000020E6100000010000000500000060C9552C7EC14E40B020CD5834D74B4060C9552C7EC14E401079CBD58FDB4B409F8EC70C54CA4E401079CBD58FDB4B409F8EC70C54CA4E40B020CD5834D74B4060C9552C7EC14E40B020CD5834D74B40
21181	Кунакбаева	6	58	161	61.530006999999998	61.545079999999999	55.961545999999998	55.955131000000002	0103000020E6100000010000000500000056D3F544D7C34E40A9328CBB41FA4B4056D3F544D7C34E40C0CC77F013FB4B4012DA722EC5C54E40C0CC77F013FB4B4012DA722EC5C54E40A9328CBB41FA4B4056D3F544D7C34E40A9328CBB41FA4B40
20799	Кумкуль	6	58	161	62.041677999999997	62.057676999999998	56.022277000000003	56.015192999999996	0103000020E61000000100000005000000397B67B455054F4066101FD8F1014C40397B67B455054F40FC3905F9D9024C409E5DBEF561074F40FC3905F9D9024C409E5DBEF561074F4066101FD8F1014C40397B67B455054F4066101FD8F1014C40
21336	Кубагушева	6	58	161	61.871600000000001	61.886718999999999	55.836114999999999	55.830047999999998	0103000020E61000000100000005000000C898BB9690EF4E401B0E4B033FEA4B40C898BB9690EF4E40F758FAD005EB4B40F4DE180280F14E40F758FAD005EB4B40F4DE180280F14E401B0E4B033FEA4B40C898BB9690EF4E401B0E4B033FEA4B40
48033	Карагайкуль	6	58	161	61.228288999999997	61.248735000000003	55.785674999999998	55.762144999999997	0103000020E61000000100000005000000AD84EE92389D4E40ABE7A4F78DE14B40AD84EE92389D4E40742497FF90E44B406F2F698CD69F4E40742497FF90E44B406F2F698CD69F4E40ABE7A4F78DE14B40AD84EE92389D4E40ABE7A4F78DE14B40
20032	Каинкуль	6	58	161	61.300936	61.322693000000001	55.734324000000001	55.723633	0103000020E610000001000000050000003318231285A64E4037A79201A0DC4B403318231285A64E407E552E54FEDD4B40F6D214014EA94E407E552E54FEDD4B40F6D214014EA94E4037A79201A0DC4B403318231285A64E4037A79201A0DC4B40
20924	Иксанова	6	58	161	62.023721000000002	62.041840000000001	56.074247999999997	56.064957	0103000020E610000001000000050000003D9D2B4A09034F40B952CF8250084C403D9D2B4A09034F408EE55DF580094C4013D55B035B054F408EE55DF580094C4013D55B035B054F40B952CF8250084C403D9D2B4A09034F40B952CF8250084C40
20246	Ибрагимова	6	58	161	61.172279000000003	61.191324000000002	55.748331	55.741455000000002	0103000020E61000000100000005000000D064FF3C0D964E40543A58FFE7DE4B40D064FF3C0D964E409FCA694FC9DF4B404F78094E7D984E409FCA694FC9DF4B404F78094E7D984E40543A58FFE7DE4B40D064FF3C0D964E40543A58FFE7DE4B40
20125	Голубинка	6	58	161	61.158607000000003	61.173617999999998	55.838009999999997	55.828116000000001	0103000020E6100000010000000500000056F5F23B4D944E40ADA580B4FFE94B4056F5F23B4D944E4048DC63E943EB4B409BFF571D39964E4048DC63E943EB4B409BFF571D39964E40ADA580B4FFE94B4056F5F23B4D944E40ADA580B4FFE94B40
48360	Бурино	6	58	161	61.826225999999998	61.845359999999999	55.937421999999998	55.927720000000001	0103000020E610000001000000050000006D8D08C6C1E94E402DEC6987BFF64B406D8D08C6C1E94E408446B071FDF74B405CACA8C134EC4E408446B071FDF74B405CACA8C134EC4E402DEC6987BFF64B406D8D08C6C1E94E402DEC6987BFF64B40
20080	Большой Куяш	6	58	161	61.087496000000002	61.120474000000002	55.851807999999998	55.818477999999999	0103000020E61000000100000005000000F243A511338B4E406C3F19E3C3E84B40F243A511338B4E404F3C670B08ED4B40580229B16B8F4E404F3C670B08ED4B40580229B16B8F4E406C3F19E3C3E84B40F243A511338B4E406C3F19E3C3E84B40
20465	Большая Тюлякова	6	58	161	61.519739000000001	61.5336	55.877651999999998	55.863337999999999	0103000020E6100000010000000500000056BABBCE86C24E4070B20DDC81EE4B4056BABBCE86C24E406EA296E656F04B40A3923A014DC44E406EA296E656F04B40A3923A014DC44E4070B20DDC81EE4B4056BABBCE86C24E4070B20DDC81EE4B40
21153	Большая Казакбаева	6	58	161	61.578884000000002	61.586635999999999	55.925203000000003	55.914988000000001	0103000020E61000000100000005000000BE16F4DE18CA4E40C11DA8531EF54B40BE16F4DE18CA4E409F94490D6DF64B40005471E316CB4E409F94490D6DF64B40005471E316CB4E40C11DA8531EF54B40BE16F4DE18CA4E40C11DA8531EF54B40
21271	Баязитова	6	58	161	61.921483000000002	61.938524000000001	55.910876000000002	55.894041000000001	0103000020E61000000100000005000000F568AA27F3F54E403E247CEF6FF24B40F568AA27F3F54E400C5BB39597F44B406C41EF8D21F84E400C5BB39597F44B406C41EF8D21F84E403E247CEF6FF24B40F568AA27F3F54E403E247CEF6FF24B40
21364	Баракова	6	58	161	61.807091999999997	61.820971	55.759673999999997	55.751061999999997	0103000020E610000001000000050000007E6E68CA4EE74E4059A2B3CC22E04B407E6E68CA4EE74E408DCF64FF3CE14B4072FBE59315E94E408DCF64FF3CE14B4072FBE59315E94E4059A2B3CC22E04B407E6E68CA4EE74E4059A2B3CC22E04B40
17283	Аширово	6	58	161	62.088866000000003	62.107362999999999	55.937981999999998	55.924643000000003	0103000020E61000000100000005000000F9DC09F65F0B4F40D8BCAAB35AF64B40F9DC09F65F0B4F404B1E4FCB0FF84B4075E61E12BE0D4F404B1E4FCB0FF84B4075E61E12BE0D4F40D8BCAAB35AF64B40F9DC09F65F0B4F40D8BCAAB35AF64B40
19951	Аминева	6	58	161	61.389024999999997	61.406343999999997	55.713354000000002	55.696494000000001	0103000020E61000000100000005000000C7293A92CBB14E401CEE23B726D94B40C7293A92CBB14E40433C122F4FDB4B408176871403B44E40433C122F4FDB4B408176871403B44E401CEE23B726D94B40C7293A92CBB14E401CEE23B726D94B40
19199	Якупово	6	58	1449	62.140762000000002	62.168089000000002	55.352182999999997	55.343916	0103000020E6100000010000000500000081423D7D04124F401B49827005AC4B4081423D7D04124F40849A215514AD4B409FE8BAF083154F40849A215514AD4B409FE8BAF083154F401B49827005AC4B4081423D7D04124F401B49827005AC4B40
18730	Шуранкуль	6	58	1449	62.355953999999997	62.397590000000001	55.766846000000001	55.752459999999999	0103000020E61000000100000005000000B07092E68F2D4F402AC6F99B50E04B40B07092E68F2D4F40C2887D0228E24B40BB9BA73AE4324F40C2887D0228E24B40BB9BA73AE4324F402AC6F99B50E04B40B07092E68F2D4F402AC6F99B50E04B40
18963	Шумово	6	58	1449	61.878687999999997	61.912948999999998	55.387197999999998	55.373623000000002	0103000020E610000001000000050000009EB12FD978F04E404704E3E0D2AF4B409EB12FD978F04E40CE893DB48FB14B403CF54883DBF44E40CE893DB48FB14B403CF54883DBF44E404704E3E0D2AF4B409EB12FD978F04E404704E3E0D2AF4B40
16733	Черкасово	6	58	1449	61.695197999999998	61.711852999999998	55.300069999999998	55.287747000000003	0103000020E610000001000000050000004F1F813FFCD84E40D542C9E4D4A44B404F1F813FFCD84E405F419AB168A64B409D47C5FF1DDB4E405F419AB168A64B409D47C5FF1DDB4E40D542C9E4D4A44B404F1F813FFCD84E40D542C9E4D4A44B40
17832	Худяково	6	58	1449	61.695773000000003	61.724842000000002	55.284097000000003	55.271245999999998	0103000020E610000001000000050000004C38F4160FD94E40DD955D30B8A24B404C38F4160FD94E4024F25D4A5DA44B403562669FC7DC4E4024F25D4A5DA44B403562669FC7DC4E40DD955D30B8A24B404C38F4160FD94E40DD955D30B8A24B40
18305	Харино	6	58	1449	61.741343999999998	61.757531999999998	55.354537999999998	55.345329	0103000020E61000000100000005000000FC8A355CE4DE4E4021AE9CBD33AC4B40FC8A355CE4DE4E4039984D8061AD4B4034D6FECEF6E04E4039984D8061AD4B4034D6FECEF6E04E4021AE9CBD33AC4B40FC8A355CE4DE4E4021AE9CBD33AC4B40
16624	Ханжино	6	58	1449	61.931669999999997	61.942881	55.081431000000002	55.067556000000003	0103000020E6100000010000000500000008556AF640F74E400553CDACA5884B4008556AF640F74E40B7F0BC546C8A4B4088821953B0F84E40B7F0BC546C8A4B4088821953B0F84E400553CDACA5884B4008556AF640F74E400553CDACA5884B40
16705	Фроловка	6	58	1449	61.864575000000002	61.879002	55.116562000000002	55.103161999999998	0103000020E6100000010000000500000038F8C264AAEE4E4050189469348D4B4038F8C264AAEE4E406AFAEC80EB8E4B402E8F352383F04E406AFAEC80EB8E4B402E8F352383F04E4050189469348D4B4038F8C264AAEE4E4050189469348D4B40
16466	Феклино	6	58	1449	62.5105	62.522033999999998	55.533999999999999	55.522621999999998	0103000020E61000000100000005000000D34D621058414F40C6151747E5C24B40D34D621058414F403108AC1C5AC44B4035B39602D2424F403108AC1C5AC44B4035B39602D2424F40C6151747E5C24B40D34D621058414F40C6151747E5C24B40
19062	Устьянцево	6	58	1449	62.023918000000002	62.038803000000001	55.350397000000001	55.344244000000003	0103000020E6100000010000000500000093E4B9BE0F034F4010ECF82F10AC4B4093E4B9BE0F034F40EACE13CFD9AC4B404CFE277FF7044F40EACE13CFD9AC4B404CFE277FF7044F4010ECF82F10AC4B4093E4B9BE0F034F4010ECF82F10AC4B40
18849	Усольцево	6	58	1449	62.027206	62.041606000000002	55.629958000000002	55.622582999999999	0103000020E61000000100000005000000A320787C7B034F40D505BCCCB0CF4B40A320787C7B034F4042EDB776A2D04B40A0A86C5853054F4042EDB776A2D04B40A0A86C5853054F40D505BCCCB0CF4B40A320787C7B034F40D505BCCCB0CF4B40
17126	Тирикуль	6	58	1449	62.200949000000001	62.222473000000001	55.606659999999998	55.595928000000001	0103000020E61000000100000005000000FB9463B2B8194F40A662635E47CC4B40FB9463B2B8194F404BE5ED08A7CD4B401B9FC9FE791C4F404BE5ED08A7CD4B401B9FC9FE791C4F40A662635E47CC4B40FB9463B2B8194F40A662635E47CC4B40
18938	Теренкуль	6	58	1449	62.294795999999998	62.323875000000001	55.640833000000001	55.620403000000003	0103000020E61000000100000005000000ED7E15E0BB254F408FAB915D69CF4B40ED7E15E0BB254F404A99D4D006D24B40FA7E6ABC74294F404A99D4D006D24B40FA7E6ABC74294F408FAB915D69CF4B40ED7E15E0BB254F408FAB915D69CF4B40
17638	Таукаево	6	58	1449	62.144875999999996	62.164045999999999	55.157854999999998	55.146903000000002	0103000020E61000000100000005000000D6FCF84B8B124F409757AEB7CD924B40D6FCF84B8B124F404A41B79734944B4012859675FF144F404A41B79734944B4012859675FF144F409757AEB7CD924B40D6FCF84B8B124F409757AEB7CD924B40
17086	Тавранкуль	6	58	1449	62.116436	62.138606000000003	55.468953999999997	55.456735000000002	0103000020E61000000100000005000000DD09F65FE70E4F4023F8DF4A76BA4B40DD09F65FE70E4F4008AA46AF06BC4B40C38366D7BD114F4008AA46AF06BC4B40C38366D7BD114F4023F8DF4A76BA4B40DD09F65FE70E4F4023F8DF4A76BA4B40
18509	Сычево	6	58	1449	61.623790999999997	61.641209000000003	55.309247999999997	55.298025000000003	0103000020E6100000010000000500000002452C62D8CF4E40F931E6AE25A64B4002452C62D8CF4E403C2D3F7095A74B405073F22213D24E403C2D3F7095A74B405073F22213D24E40F931E6AE25A64B4002452C62D8CF4E40F931E6AE25A64B40
18741	Сугояк	6	58	1449	62.044677999999998	62.073433000000001	55.752434999999998	55.727221999999998	0103000020E61000000100000005000000E36C3A02B8054F404277499C15DD4B40E36C3A02B8054F40D1AE42CA4FE04B403DB9A64066094F40D1AE42CA4FE04B403DB9A64066094F404277499C15DD4B40E36C3A02B8054F404277499C15DD4B40
17928	Слава	6	58	1449	61.684911999999997	61.706012999999999	55.386445999999999	55.375014999999998	0103000020E61000000100000005000000A8514832ABD74E403541D47D00B04B40A8514832ABD74E40C3D5011077B14B4082C64CA25EDA4E40C3D5011077B14B4082C64CA25EDA4E403541D47D00B04B40A8514832ABD74E403541D47D00B04B40
19051	Сафоново	6	58	1449	61.980988000000004	61.997399999999999	55.351308000000003	55.344050000000003	0103000020E610000001000000050000005DE2C80391FD4E402B1895D409AC4B405DE2C80391FD4E405E6919A9F7AC4B40E4839ECDAAFF4E405E6919A9F7AC4B40E4839ECDAAFF4E402B1895D409AC4B405DE2C80391FD4E402B1895D409AC4B40
18535	Русская Теча	6	58	1449	62.182623999999997	62.205261	55.771554999999999	55.753189999999996	0103000020E610000001000000050000007BBB253960174F404DD6A88768E04B407BBB253960174F405B087250C2E24B40771211FE451A4F405B087250C2E24B40771211FE451A4F404DD6A88768E04B407BBB253960174F404DD6A88768E04B40
16811	Родник	6	58	1449	61.939584000000004	61.957138	55.155802999999999	55.147540999999997	0103000020E6100000010000000500000025ECDB4944F84E40D9E89C9FE2924B4025ECDB4944F84E4031CF4A5AF1934B4022E17B7F83FA4E4031CF4A5AF1934B4022E17B7F83FA4E40D9E89C9FE2924B4025ECDB4944F84E40D9E89C9FE2924B40
19151	Пятково	6	58	1449	62.094031999999999	62.108989000000001	55.335473999999998	55.331612999999997	0103000020E610000001000000050000008463963D090C4F40D7F6764B72AA4B408463963D090C4F404354E1CFF0AA4B40D74FFF59F30D4F404354E1CFF0AA4B40D74FFF59F30D4F40D7F6764B72AA4B408463963D090C4F40D7F6764B72AA4B40
17186	Попово	6	58	1449	61.887903999999999	61.921177999999998	55.488458000000001	55.479244999999999	0103000020E6100000010000000500000069FE98D6A6F14E40C1E270E657BD4B4069FE98D6A6F14E401BBCAFCA85BE4B40B8E52329E9F54E401BBCAFCA85BE4B40B8E52329E9F54E40C1E270E657BD4B4069FE98D6A6F14E40C1E270E657BD4B40
18105	Печенкино	6	58	1449	61.890689000000002	61.914270000000002	55.022623000000003	55.011149000000003	0103000020E6100000010000000500000017F4DE1802F24E400A3197546D814B4017F4DE1802F24E4097917A4FE5824B4062DBA2CC06F54E4097917A4FE5824B4062DBA2CC06F54E400A3197546D814B4017F4DE1802F24E400A3197546D814B40
18397	Петровский	6	58	1449	61.590283999999997	61.642637000000001	55.233783000000003	55.217469999999999	0103000020E6100000010000000500000010AD156D8ECB4E4039EE940ED69B4B4010AD156D8ECB4E402EAEF199EC9D4B408B19E1ED41D24E402EAEF199EC9D4B408B19E1ED41D24E4039EE940ED69B4B4010AD156D8ECB4E4039EE940ED69B4B40
55219	Пашнино 1-е	6	58	1449	62.040877999999999	62.057794000000001	55.123682000000002	55.112586999999998	0103000020E610000001000000050000001D90847D3B054F40357A3540698E4B401D90847D3B054F404C8DD0CFD48F4B40D8F335CB65074F404C8DD0CFD48F4B40D8F335CB65074F40357A3540698E4B401D90847D3B054F40357A3540698E4B40
17509	Пашнино	6	58	1449	62.040877999999999	62.057794000000001	55.123682000000002	55.112586999999998	0103000020E610000001000000050000001D90847D3B054F40357A3540698E4B401D90847D3B054F404C8DD0CFD48F4B40D8F335CB65074F404C8DD0CFD48F4B40D8F335CB65074F40357A3540698E4B401D90847D3B054F40357A3540698E4B40
16533	Октябрьский	6	58	1449	61.802286000000002	61.830061999999998	55.084977000000002	55.075262000000002	0103000020E61000000100000005000000F304C24EB1E64E40D7506A2FA2894B40F304C24EB1E64E40C3F4BD86E08A4B4080D3BB783FEA4E40C3F4BD86E08A4B4080D3BB783FEA4E40D7506A2FA2894B40F304C24EB1E64E40D7506A2FA2894B40
18430	Озерный	6	58	1449	61.683214	61.700372000000002	55.218193999999997	55.204478999999999	0103000020E61000000100000005000000AD156D8E73D74E4001DC2C5E2C9A4B40AD156D8E73D74E407A17EFC7ED9B4B405E8429CAA5D94E407A17EFC7ED9B4B405E8429CAA5D94E4001DC2C5E2C9A4B40AD156D8E73D74E4001DC2C5E2C9A4B40
18619	Нижнепетропавловское	6	58	1449	62.227530000000002	62.264100999999997	55.832135999999998	55.816409	0103000020E61000000100000005000000F06DFAB31F1D4F407D94111780E84B40F06DFAB31F1D4F4081E9B46E83EA4B40A2EBC20FCE214F4081E9B46E83EA4B40A2EBC20FCE214F407D94111780E84B40F06DFAB31F1D4F407D94111780E84B40
37842	Мирный	6	58	1449	61.546024000000003	62.522033999999998	55.832135999999998	55.005181	0103000020E61000000100000005000000626A4B1DE4C54E40C1C760C5A9804B40626A4B1DE4C54E4081E9B46E83EA4B4035B39602D2424F4081E9B46E83EA4B4035B39602D2424F40C1C760C5A9804B40626A4B1DE4C54E40C1C760C5A9804B40
18134	Миасское	6	58	1449	61.869560999999997	61.914296999999998	55.300069999999998	55.267687000000002	0103000020E6100000010000000500000043705CC64DEF4E403D484F9143A24B4043705CC64DEF4E405F419AB168A64B405BEA20AF07F54E405F419AB168A64B405BEA20AF07F54E403D484F9143A24B4043705CC64DEF4E403D484F9143A24B40
18030	Луговой	6	58	1449	61.715850000000003	61.734796000000003	55.029415	55.019810999999997	0103000020E61000000100000005000000BA6B09F9A0DB4E40EF8CB62A89824B40BA6B09F9A0DB4E408481E7DEC3834B40A69D9ACB0DDE4E408481E7DEC3834B40A69D9ACB0DDE4E40EF8CB62A89824B40BA6B09F9A0DB4E40EF8CB62A89824B40
17727	Лесной	6	58	1449	61.918653999999997	61.939431999999996	55.249977000000001	55.238202999999999	0103000020E61000000100000005000000772B4B7496F54E409067976F7D9E4B40772B4B7496F54E4048E00F3FFF9F4B406E68CA4E3FF84E4048E00F3FFF9F4B406E68CA4E3FF84E409067976F7D9E4B40772B4B7496F54E409067976F7D9E4B40
17912	Лазурный	6	58	1449	61.669775000000001	61.700524999999999	55.365079999999999	55.347043999999997	0103000020E61000000100000005000000D656EC2FBBD54E40F22213F06BAC4B40D656EC2FBBD54E403B3602F1BAAE4B40E4839ECDAAD94E403B3602F1BAAE4B40E4839ECDAAD94E40F22213F06BAC4B40D656EC2FBBD54E40F22213F06BAC4B40
17811	Курейное	6	58	1449	62.014333000000001	62.027296	55.275112999999997	55.268163999999999	0103000020E610000001000000050000007520EBA9D5014F4076FBAC3253A24B407520EBA9D5014F402BDA1CE736A34B40E3A7716F7E034F402BDA1CE736A34B40E3A7716F7E034F4076FBAC3253A24B407520EBA9D5014F4076FBAC3253A24B40
18839	Кирды	6	58	1449	62.049501999999997	62.061926	55.830038000000002	55.813349000000002	0103000020E61000000100000005000000158BDF1456064F40FE9DEDD11BE84B40158BDF1456064F40F83768AF3EEA4B40D462F030ED074F40F83768AF3EEA4B40D462F030ED074F40FE9DEDD11BE84B40158BDF1456064F40FE9DEDD11BE84B40
17409	Канашево	6	58	1449	62.046188000000001	62.092379000000001	55.221322000000001	55.200024999999997	0103000020E61000000100000005000000DCBB067DE9054F40F2B0506B9A994B40DCBB067DE9054F4052F17F47549C4B4029EB3713D30B4F4052F17F47549C4B4029EB3713D30B4F40F2B0506B9A994B40DCBB067DE9054F40F2B0506B9A994B40
17540	Калуга-Соловьевка	6	58	1449	62.217793	62.236756	55.085379000000003	55.076127999999997	0103000020E610000001000000050000001C261AA4E01B4F40AA27F38FBE894B401C261AA4E01B4F40F261F6B2ED8A4B40DE9046054E1E4F40F261F6B2ED8A4B40DE9046054E1E4F40AA27F38FBE894B401C261AA4E01B4F40AA27F38FBE894B40
17335	Дубровка	6	58	1449	61.636690000000002	61.663145999999998	55.446427	55.425946000000003	0103000020E610000001000000050000005AD8D30E7FD14E4057EE056685B64B405AD8D30E7FD14E4094861A8524B94B40923CD7F7E1D44E4094861A8524B94B40923CD7F7E1D44E4057EE056685B64B405AD8D30E7FD14E4057EE056685B64B40
17010	Бродокалмак	6	58	1449	62.032344000000002	62.114818999999997	55.584828000000002	55.562139000000002	0103000020E61000000100000005000000651C23D923044F403067B62BF4C74B40651C23D923044F407EE4D6A4DBCA4B40CEFA9463B20E4F407EE4D6A4DBCA4B40CEFA9463B20E4F403067B62BF4C74B40651C23D923044F403067B62BF4C74B40
17227	Боровое	6	58	1449	61.982120000000002	62.000311000000004	55.445706999999999	55.436177999999998	0103000020E61000000100000005000000AF5FB01BB6FD4E400A9E42AED4B74B40AF5FB01BB6FD4E40944C4EED0CB94B401F6ADB300A004F40944C4EED0CB94B401F6ADB300A004F400A9E42AED4B74B40AF5FB01BB6FD4E400A9E42AED4B74B40
17623	Берсеневка	6	58	1449	62.153590000000001	62.170011000000002	55.091670000000001	55.087119999999999	0103000020E610000001000000050000000F7F4DD6A8134F40EC6987BF268B4B400F7F4DD6A8134F401D03B2D7BB8B4B40EA7AA2EBC2154F401D03B2D7BB8B4B40EA7AA2EBC2154F40EC6987BF268B4B400F7F4DD6A8134F40EC6987BF268B4B40
16601	Березово	6	58	1449	61.783583	61.801414999999999	55.135669999999998	55.124825000000001	0103000020E61000000100000005000000CD599F724CE44E40925CFE43FA8F4B40CD599F724CE44E402F8672A25D914B400DC347C494E64E402F8672A25D914B400DC347C494E64E40925CFE43FA8F4B40CD599F724CE44E40925CFE43FA8F4B40
16879	Береговой	6	58	1449	61.559398999999999	61.571769000000003	55.313675000000003	55.308331000000003	0103000020E610000001000000050000002235ED629AC74E40E7ABE46377A74B402235ED629AC74E4052499D8026A84B40EEEE01BA2FC94E4052499D8026A84B40EEEE01BA2FC94E40E7ABE46377A74B402235ED629AC74E40E7ABE46377A74B40
18652	Беликуль	6	58	1449	62.416418999999998	62.449306999999997	55.708373999999999	55.694159999999997	0103000020E610000001000000050000006D37C1374D354F407E18213CDAD84B406D37C1374D354F4019ABCDFFABDA4B40936E4BE482394F4019ABCDFFABDA4B40936E4BE482394F407E18213CDAD84B406D37C1374D354F407E18213CDAD84B40
16451	Ачликуль	6	58	1449	62.416024	62.439478999999999	55.538096000000003	55.519534	0103000020E61000000100000005000000F12C414640354F407D94111780C24B40F12C414640354F40E10D6954E0C44B40AF230ED940384F40E10D6954E0C44B40AF230ED940384F407D94111780C24B40F12C414640354F407D94111780C24B40
16387	Алабуга	6	58	1449	62.328536999999997	62.373192000000003	55.541086999999997	55.530408999999999	0103000020E6100000010000000500000052431B800D2A4F4085402E71E4C34B4052431B800D2A4F4037A5BC5642C54B407E9065C1C42F4F4037A5BC5642C54B407E9065C1C42F4F4085402E71E4C34B4052431B800D2A4F4085402E71E4C34B40
55096	Копейск	6	58	1732	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
25974	Калачево	6	58	1732	61.52017	61.558214	54.947929999999999	54.928251000000003	0103000020E610000001000000050000001F2E39EE94C24E405ABDC3EDD0764B401F2E39EE94C24E40DA722EC555794B40AD156D8E73C74E40DA722EC555794B40AD156D8E73C74E405ABDC3EDD0764B401F2E39EE94C24E405ABDC3EDD0764B40
25820	Заозерный	6	58	1732	61.539231999999998	61.562821999999997	55.013734999999997	55.007086000000001	0103000020E61000000100000005000000747ADE8D05C54E403621AD31E8804B40747ADE8D05C54E40C0E78711C2814B4012BC218D0AC84E40C0E78711C2814B4012BC218D0AC84E403621AD31E8804B40747ADE8D05C54E403621AD31E8804B40
6102	Чернышевский	6	58	835	58.820777999999997	58.832698000000001	52.644416999999997	52.634548000000002	0103000020E610000001000000050000005DA3E5400F694D4001DF6DDE38514A405DA3E5400F694D4043FE99417C524A40E9B81AD9956A4D4043FE99417C524A40E9B81AD9956A4D4001DF6DDE38514A405DA3E5400F694D4001DF6DDE38514A40
16377	Черкасы	6	58	835	59.649267000000002	59.673215999999996	52.693840000000002	52.683517999999999	0103000020E610000001000000050000009FAF592E1BD34D40191D90847D574A409FAF592E1BD34D400D54C6BFCF584A406C921FF12BD64D400D54C6BFCF584A406C921FF12BD64D40191D90847D574A409FAF592E1BD34D40191D90847D574A40
6249	Чапаевский	6	58	835	59.689915999999997	59.701467999999998	52.832321	52.825747999999997	0103000020E610000001000000050000005A7EE02A4FD84D40635E471CB2694A405A7EE02A4FD84D401363997E896A4A40639813B4C9D94D401363997E896A4A40639813B4C9D94D40635E471CB2694A405A7EE02A4FD84D40635E471CB2694A40
16600	Целинный	6	58	835	59.395716999999998	59.404763000000003	52.734188000000003	52.728538	0103000020E6100000010000000500000051BCCADAA6B24D4056F2B1BB405D4A4051BCCADAA6B24D40CE8E54DFF95D4A40C0D02346CFB34D40CE8E54DFF95D4A40C0D02346CFB34D4056F2B1BB405D4A4051BCCADAA6B24D4056F2B1BB405D4A40
16054	Урал	6	58	835	58.983696000000002	59.004635999999998	52.625633000000001	52.611789999999999	0103000020E610000001000000050000005F9A22C0E97D4D408A027D224F4E4A405F9A22C0E97D4D403126FDBD14504A402F3196E997804D403126FDBD14504A402F3196E997804D408A027D224F4E4A405F9A22C0E97D4D408A027D224F4E4A40
16744	Увальский	6	58	835	58.884341999999997	58.896675999999999	52.821781000000001	52.801124999999999	0103000020E61000000100000005000000573D601E32714D40068195438B664A40573D601E32714D40B2BCAB1E30694A40D68D7747C6724D40B2BCAB1E30694A40D68D7747C6724D40068195438B664A40573D601E32714D40068195438B664A40
16707	Сыртинский	6	58	835	58.879285000000003	58.897582999999997	52.918978000000003	52.898308	0103000020E61000000100000005000000836E2F698C704D401ADEACC1FB724A40836E2F698C704D402BDF3312A1754A400839EFFFE3724D402BDF3312A1754A400839EFFFE3724D401ADEACC1FB724A40836E2F698C704D401ADEACC1FB724A40
16129	Смородинка	6	58	835	59.032322000000001	59.040523	52.680002000000002	52.674149	0103000020E610000001000000050000007D78962023844D40C8D0B1834A564A407D78962023844D40789B374E0A574A402FDE8FDB2F854D40789B374E0A574A402FDE8FDB2F854D40C8D0B1834A564A407D78962023844D40C8D0B1834A564A40
15898	Симбирка	6	58	835	59.192608	59.199759	52.708666999999998	52.697147000000001	0103000020E6100000010000000500000057790261A7984D4094C0E61C3C594A4057790261A7984D409160AA99B55A4A40740AF2B391994D409160AA99B55A4A40740AF2B391994D4094C0E61C3C594A4057790261A7984D4094C0E61C3C594A40
16186	Путь Октября	6	58	835	59.460638000000003	59.486187000000001	52.892640999999998	52.879503	0103000020E61000000100000005000000BEA59C2FF6BA4D40F0DDE68D93704A40BEA59C2FF6BA4D40CC086F0F42724A40C45E28603BBE4D40CC086F0F42724A40C45E28603BBE4D40F0DDE68D93704A40BEA59C2FF6BA4D40F0DDE68D93704A40
16319	Полоцкое	6	58	835	59.695701	59.718518000000003	52.776226000000001	52.761088999999998	0103000020E61000000100000005000000B265F9BA0CD94D40342C465D6B614A40B265F9BA0CD94D400727A25F5B634A402ECBD765F8DB4D400727A25F5B634A402ECBD765F8DB4D40342C465D6B614A40B265F9BA0CD94D40342C465D6B614A40
16999	Первомайка	6	58	835	59.143183000000001	59.150756000000001	52.970343999999997	52.962420000000002	0103000020E61000000100000005000000ED2B0FD253924D4017821C94307B4A40ED2B0FD253924D4056EF703B347C4A4080D6FCF84B934D4056EF703B347C4A4080D6FCF84B934D4017821C94307B4A40ED2B0FD253924D4017821C94307B4A40
16947	Октябрьский	6	58	835	59.062019999999997	59.072971000000003	52.819958	52.815886999999996	0103000020E6100000010000000500000055D97745F0874D40A31D37FC6E684A4055D97745F0874D40FA0B3D62F4684A4039471D1D57894D40FA0B3D62F4684A4039471D1D57894D40A31D37FC6E684A4055D97745F0874D40A31D37FC6E684A40
15840	Обручевка	6	58	835	59.203091999999998	59.227957000000004	52.771399000000002	52.762517000000003	0103000020E61000000100000005000000240A2DEBFE994D4070D234289A614A40240A2DEBFE994D406495D233BD624A4078F2E9B12D9D4D406495D233BD624A4078F2E9B12D9D4D4070D234289A614A40240A2DEBFE994D4070D234289A614A40
16636	Новый Кондуровский	6	58	835	59.412497999999999	59.419271000000002	52.602471000000001	52.596640000000001	0103000020E610000001000000050000002CD505BCCCB44D4023BE13B35E4C4A402CD505BCCCB44D40EBE40CC51D4D4A40A39410ACAAB54D40EBE40CC51D4D4A40A39410ACAAB54D4023BE13B35E4C4A402CD505BCCCB44D4023BE13B35E4C4A40
55245	Новый	6	58	835	59.320554999999999	59.328766000000002	52.847166000000001	52.843304000000003	0103000020E61000000100000005000000DEC83CF207A94D40024BAE62F16B4A40DEC83CF207A94D403E247CEF6F6C4A40B404190115AA4D403E247CEF6F6C4A40B404190115AA4D40024BAE62F16B4A40DEC83CF207A94D40024BAE62F16B4A40
15639	Новопокровский	6	58	835	58.781331999999999	58.814560999999998	52.666770999999997	52.652847999999999	0103000020E61000000100000005000000BDA8DDAF02644D4027A1F48590534A40BDA8DDAF02644D40EA758BC058554A406CCCEB8843684D40EA758BC058554A406CCCEB8843684D4027A1F48590534A40BDA8DDAF02644D4027A1F48590534A40
15776	Новоершовский	6	58	835	59.11618	59.127479999999998	52.454633999999999	52.447493999999999	0103000020E6100000010000000500000082397AFCDE8E4D40FF93BF7B47394A4082397AFCDE8E4D4028D36872313A4A407172BF4351904D4028D36872313A4A407172BF4351904D40FF93BF7B47394A4082397AFCDE8E4D40FF93BF7B47394A40
16447	Новинка	6	58	835	59.883457999999997	59.896869000000002	52.708252000000002	52.698723999999999	0103000020E61000000100000005000000DDB1D82615F14D401477BCC96F594A40DDB1D82615F14D40CEA96400A85A4A40EBE5779ACCF24D40CEA96400A85A4A40EBE5779ACCF24D401477BCC96F594A40DDB1D82615F14D401477BCC96F594A40
6163	Мартыновка	6	58	835	59.071237000000004	59.080399999999997	52.890206999999997	52.884881999999998	0103000020E61000000100000005000000F1A1444B1E894D40D76839D043714A40F1A1444B1E894D40CBD58F4DF2714A40984C158C4A8A4D40CBD58F4DF2714A40984C158C4A8A4D40D76839D043714A40F1A1444B1E894D40D76839D043714A40
16212	Лесной	6	58	835	59.512479999999996	59.528111000000003	52.904310000000002	52.895330999999999	0103000020E6100000010000000500000052EDD3F198C14D40280CCA349A724A4052EDD3F198C14D400FB9196EC0734A4035D4282499C34D400FB9196EC0734A4035D4282499C34D40280CCA349A724A4052EDD3F198C14D40280CCA349A724A40
6214	Кизильское	6	58	835	58.876859000000003	58.926509000000003	52.742105000000002	52.704929	0103000020E61000000100000005000000051A6CEA3C704D4041800C1D3B5A4A40051A6CEA3C704D405B99F04BFD5E4A408F39CFD897764D405B99F04BFD5E4A408F39CFD897764D4041800C1D3B5A4A40051A6CEA3C704D4041800C1D3B5A4A40
16476	Кацбахский	6	58	835	59.632333000000003	59.658473999999998	52.966802000000001	52.952736999999999	0103000020E610000001000000050000003E97A949F0D04D4036583849F3794A403E97A949F0D04D408CDAFD2AC07B4A4016A243E048D44D408CDAFD2AC07B4A4016A243E048D44D4036583849F3794A403E97A949F0D04D4036583849F3794A40
15929	Карабулак	6	58	835	59.146003999999998	59.165954999999997	52.899590000000003	52.887203	0103000020E61000000100000005000000E78A5242B0924D40E0F42EDE8F714A40E78A5242B0924D4082E7DEC325734A40C8CD70033E954D4082E7DEC325734A40C8CD70033E954D40E0F42EDE8F714A40E78A5242B0924D40E0F42EDE8F714A40
17037	Ильинка	6	58	835	58.890630999999999	58.902918999999997	52.854267999999998	52.834035	0103000020E61000000100000005000000E2E6543200724D40145CACA8C16A4A40E2E6543200724D40790261A7586D4A40F0F78BD992734D40790261A7586D4A40F0F78BD992734D40145CACA8C16A4A40E2E6543200724D40145CACA8C16A4A40
16536	Измайловский	6	58	835	59.289059999999999	59.316073000000003	52.666831000000002	52.655721	0103000020E61000000100000005000000774A07EBFFA44D4074266DAAEE534A40774A07EBFFA44D40C07ADCB75A554A4006137F1475A84D40C07ADCB75A554A4006137F1475A84D4074266DAAEE534A40774A07EBFFA44D4074266DAAEE534A40
16810	Зингейский	6	58	835	59.528021000000003	59.566011000000003	53.005634000000001	52.984088999999997	0103000020E61000000100000005000000F54C2F3196C34D403AADDBA0F67D4A40F54C2F3196C34D4072DF6A9DB8804A409016670C73C84D4072DF6A9DB8804A409016670C73C84D403AADDBA0F67D4A40F54C2F3196C34D403AADDBA0F67D4A40
16073	Ждановский	6	58	835	59.186985	59.208598000000002	52.612445999999998	52.599632	0103000020E61000000100000005000000D9EBDD1FEF974D404AD1CABDC04C4A40D9EBDD1FEF974D4073486AA1644E4A406901DA56B39A4D4073486AA1644E4A406901DA56B39A4D404AD1CABDC04C4A40D9EBDD1FEF974D404AD1CABDC04C4A40
15760	Грязнушинский	6	58	835	58.960546000000001	58.974370999999998	52.552036000000001	52.543723	0103000020E61000000100000005000000DD26DC2BF37A4D40A08A1BB798454A40DD26DC2BF37A4D407A1B9B1DA9464A40DD955D30B87C4D407A1B9B1DA9464A40DD955D30B87C4D40A08A1BB798454A40DD26DC2BF37A4D40A08A1BB798454A40
16875	Гранитный	6	58	835	58.956693000000001	58.976222	52.980798	52.968390999999997	0103000020E61000000100000005000000F4A78DEA747A4D40D05E7D3CF47B4A40F4A78DEA747A4D40B9FDF2C98A7D4A405FD1ADD7F47C4D40B9FDF2C98A7D4A405FD1ADD7F47C4D40D05E7D3CF47B4A40F4A78DEA747A4D40D05E7D3CF47B4A40
16863	Браиловский	6	58	835	59.379125000000002	59.392043000000001	53.027639000000001	53.016047	0103000020E610000001000000050000004A0C022B87B04D407619FED30D824A404A0C022B87B04D400D8CBCAC89834A4018D00B772EB24D400D8CBCAC89834A4018D00B772EB24D407619FED30D824A404A0C022B87B04D407619FED30D824A40
15685	Богдановское	6	58	835	59.045904	59.078369000000002	52.427734999999998	52.408171000000003	0103000020E61000000100000005000000B760A92EE0854D407B1684F23E344A40B760A92EE0854D40622D3E05C0364A409702D2FE078A4D40622D3E05C0364A409702D2FE078A4D407B1684F23E344A40B760A92EE0854D407B1684F23E344A40
16276	Амамбайка	6	58	835	59.497326000000001	59.508276000000002	52.801015999999997	52.790289000000001	0103000020E61000000100000005000000AAB9DC60A8BF4D40BCB1A03028654A40AAB9DC60A8BF4D404FC939B187664A40BDAB1E300FC14D404FC939B187664A40BDAB1E300FC14D40BCB1A03028654A40AAB9DC60A8BF4D40BCB1A03028654A40
55107	Юрюзань	6	58	954	58.397984999999998	58.466211999999999	54.884369	54.833843000000002	0103000020E6100000010000000500000037A6272CF1324D40D07F0F5EBB6A4B4037A6272CF1324D40514CDE0033714B405A80B6D5AC3B4D40514CDE0033714B405A80B6D5AC3B4D40D07F0F5EBB6A4B4037A6272CF1324D40D07F0F5EBB6A4B40
16275	Шарлаш	6	58	954	57.931904000000003	57.940652999999998	54.969864000000001	54.960099999999997	0103000020E610000001000000050000007C8159A148F74C40DE718A8EE47A4B407C8159A148F74C40ACC8E880247C4B4030F1475167F84C40ACC8E880247C4B4030F1475167F84C40DE718A8EE47A4B407C8159A148F74C40DE718A8EE47A4B40
15977	Тюлюк	6	58	954	58.760050999999997	58.782167999999999	54.61768	54.604348000000002	0103000020E610000001000000050000006325E65949614D4096B377465B4D4B406325E65949614D4057B26323104F4B4026FDBD141E644D4057B26323104F4B4026FDBD141E644D4096B377465B4D4B406325E65949614D4096B377465B4D4B40
40213	Трехгорный городской округ	6	58	954	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
11614	Трехгорный	6	58	954	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
15927	Совхозный	6	58	954	58.364694	58.380873000000001	54.834308999999998	54.826431999999997	0103000020E610000001000000050000001286014BAE2E4D40162F1686C8694B401286014BAE2E4D4015E126A3CA6A4B40F7764B72C0304D4015E126A3CA6A4B40F7764B72C0304D40162F1686C8694B401286014BAE2E4D40162F1686C8694B40
16183	Серпиевка	6	58	954	57.852034000000003	57.870432000000001	54.864803000000002	54.852392000000002	0103000020E61000000100000005000000408A3A730FED4C409FAF592E1B6D4B40408A3A730FED4C40C93D5DDDB16E4B4029B2D6506AEF4C40C93D5DDDB16E4B4029B2D6506AEF4C409FAF592E1B6D4B40408A3A730FED4C409FAF592E1B6D4B40
15179	Половинка	6	58	954	58.275015000000003	58.290754	54.797035000000001	54.793002000000001	0103000020E61000000100000005000000697407B133234D40D0D4EB1681654B40697407B133234D4039622D3E05664B403197546D37254D4039622D3E05664B403197546D37254D40D0D4EB1681654B40697407B133234D40D0D4EB1681654B40
16137	Орловка	6	58	954	58.075302000000001	58.101874000000002	54.878765000000001	54.865757000000002	0103000020E6100000010000000500000065A9F57EA3094D403CA41820D16E4B4065A9F57EA3094D404AEF1B5F7B704B4007280D350A0D4D404AEF1B5F7B704B4007280D350A0D4D403CA41820D16E4B4065A9F57EA3094D403CA41820D16E4B40
7882	Меседа	6	58	954	58.68683	58.708694999999999	54.777666000000004	54.764037999999999	0103000020E61000000100000005000000B2F4A10BEA574D405C7347FFCB614B40B2F4A10BEA574D40079B3A8F8A634B405BEB8B84B65A4D40079B3A8F8A634B405BEB8B84B65A4D405C7347FFCB614B40B2F4A10BEA574D405C7347FFCB614B40
15781	Лемеза	6	58	954	57.847731000000003	57.867297000000001	54.628377	54.618848	0103000020E6100000010000000500000017670C7382EC4C40F6984869364F4B4017670C7382EC4C40804754A86E504B409F758D9603EF4C40804754A86E504B409F758D9603EF4C40F6984869364F4B4017670C7382EC4C40F6984869364F4B40
16325	Карауловка	6	58	954	57.981696999999997	58.000264999999999	54.781793999999998	54.774394999999998	0103000020E6100000010000000500000068CA4E3FA8FD4C40CC9717601F634B4068CA4E3FA8FD4C40C11A67D311644B40AE2AFBAE08004D40C11A67D311644B40AE2AFBAE08004D40CC9717601F634B4068CA4E3FA8FD4C40CC9717601F634B40
14446	Верх-Катав	6	58	954	58.270190999999997	58.296664	54.622157999999999	54.613666000000002	0103000020E610000001000000050000003656629E95224D406555849B8C4E4B403656629E95224D40EE7893DFA24F4B4045F30016F9254D40EE7893DFA24F4B4045F30016F9254D406555849B8C4E4B403656629E95224D406555849B8C4E4B40
15762	Бедярыш	6	58	954	57.687390999999998	57.71311	54.656875999999997	54.647458	0103000020E610000001000000050000004948A46DFCD74C404CC45BE7DF524B404948A46DFCD74C407EC3448314544B40AC39403047DB4C407EC3448314544B40AC39403047DB4C404CC45BE7DF524B404948A46DFCD74C404CC45BE7DF524B40
16215	Аратское	6	58	954	57.883862000000001	57.898513000000001	54.894150000000003	54.883710999999998	0103000020E61000000100000005000000AD16D86322F14C40C70E2A711D714B40AD16D86322F14C40F5DBD78173724B40F303577902F34C40F5DBD78173724B40F303577902F34C40C70E2A711D714B40AD16D86322F14C40C70E2A711D714B40
13877	Юшково	6	58	1255	61.346867000000003	61.379575000000003	56.072906000000003	56.05883	0103000020E61000000100000005000000E4874A2366AC4E400803CFBD87074C40E4874A2366AC4E4052D7DAFB54094C408AB0E1E995B04E4052D7DAFB54094C408AB0E1E995B04E400803CFBD87074C40E4874A2366AC4E400803CFBD87074C40
13722	Щербаковка	6	58	1255	60.902119999999996	60.922054000000003	56.195689999999999	56.180953000000002	0103000020E61000000100000005000000A4880CAB78734E407A8EC87729174C40A4880CAB78734E40BE13B35E0C194C40B0928FDD05764E40BE13B35E0C194C40B0928FDD05764E407A8EC87729174C40A4880CAB78734E407A8EC87729174C40
14316	Шабурово	6	58	1255	61.218533999999998	61.261617000000001	56.224801999999997	56.206792	0103000020E6100000010000000500000033880FECF89B4E4087890629781A4C4033880FECF89B4E40A609DB4FC61C4C40F08975AA7CA14E40A609DB4FC61C4C40F08975AA7CA14E4087890629781A4C4033880FECF89B4E4087890629781A4C40
13572	Черкаскуль	6	58	1255	60.852730999999999	60.860869000000001	56.186875000000001	56.182049999999997	0103000020E6100000010000000500000087A4164A266D4E404F1E166A4D174C4087A4164A266D4E4052B81E85EB174C40F39194F4306E4E4052B81E85EB174C40F39194F4306E4E404F1E166A4D174C4087A4164A266D4E404F1E166A4D174C40
55218	Усть-Караболка	6	58	1255	61.66921	61.681876000000003	56.056930000000001	56.049787000000002	0103000020E61000000100000005000000FD135CACA8D54E400B62A06B5F064C40FD135CACA8D54E40A514747B49074C40B2F677B647D74E40A514747B49074C40B2F677B647D74E400B62A06B5F064C40FD135CACA8D54E400B62A06B5F064C40
14018	Тюбук	6	58	1255	60.920554000000003	60.953360000000004	56.070765999999999	56.039062000000001	0103000020E61000000100000005000000DB19A6B6D4754E401842CEFBFF044C40DB19A6B6D4754E4099D53BDC0E094C4044A852B3077A4E4099D53BDC0E094C4044A852B3077A4E401842CEFBFF044C40DB19A6B6D4754E401842CEFBFF044C40
14424	Тимино	6	58	1255	61.196803000000003	61.242410999999997	56.313828000000001	56.301732999999999	0103000020E610000001000000050000009A6038D730994E40DE8FDB2F9F264C409A6038D730994E40D84812842B284C406798DA52079F4E40D84812842B284C406798DA52079F4E40DE8FDB2F9F264C409A6038D730994E40DE8FDB2F9F264C40
28226	Снежинск	6	58	1255	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
13315	Полднево	6	58	1255	61.630707999999998	61.648342	56.186750000000004	56.172499999999999	0103000020E61000000100000005000000ACA92C0ABBD04E40AE47E17A14164C40ACA92C0ABBD04E4096438B6CE7174C40C64FE3DEFCD24E4096438B6CE7174C40C64FE3DEFCD24E40AE47E17A14164C40ACA92C0ABBD04E40AE47E17A14164C40
13852	Огневское	6	58	1255	61.508814999999998	61.529845000000002	56.132308000000002	56.092345000000002	0103000020E610000001000000050000006C5B94D920C14E407D7901F6D10B4C406C5B94D920C14E40E57FF277EF104C407D7901F6D1C34E40E57FF277EF104C407D7901F6D1C34E407D7901F6D10B4C406C5B94D920C14E407D7901F6D10B4C40
13782	Маук	6	58	1255	60.451039999999999	60.476435000000002	55.914538999999998	55.899835000000003	0103000020E610000001000000050000000B98C0ADBB394E40E96514CB2DF34B400B98C0ADBB394E4051F52B9D0FF54B40BBD573D2FB3C4E4051F52B9D0FF54B40BBD573D2FB3C4E40E96514CB2DF34B400B98C0ADBB394E40E96514CB2DF34B40
14354	Ларино	6	58	1255	61.270913999999998	61.318750000000001	56.301108999999997	56.282026000000002	0103000020E61000000100000005000000A703594FADA24E40944F8F6D19244C40A703594FADA24E4000C45DBD8A264C40CDCCCCCCCCA84E4000C45DBD8A264C40CDCCCCCCCCA84E40944F8F6D19244C40A703594FADA24E40944F8F6D19244C40
13942	Кызылова	6	58	1255	61.648170999999998	61.655501000000001	56.011394000000003	56.001826000000001	0103000020E61000000100000005000000999B6F44F7D24E40292499D53B004C40999B6F44F7D24E4071AFCC5B75014C4066BFEE74E7D34E4071AFCC5B75014C4066BFEE74E7D34E40292499D53B004C40999B6F44F7D24E40292499D53B004C40
14233	Красный Партизан	6	58	1255	60.956217000000002	60.974964999999997	55.969627000000003	55.964075000000001	0103000020E610000001000000050000008B709351657A4E4013F241CF66FB4B408B709351657A4E40C828CFBC1CFC4B4050DF32A7CB7C4E40C828CFBC1CFC4B4050DF32A7CB7C4E4013F241CF66FB4B408B709351657A4E4013F241CF66FB4B40
13303	Клепалово	6	58	1255	61.580374999999997	61.608204999999998	56.165478999999998	56.139069999999997	0103000020E610000001000000050000003F355EBA49CA4E4067EDB60BCD114C403F355EBA49CA4E405F96766A2E154C40C02154A9D9CD4E405F96766A2E154C40C02154A9D9CD4E4067EDB60BCD114C403F355EBA49CA4E4067EDB60BCD114C40
13648	Клеопино	6	58	1255	60.915720999999998	60.934316000000003	56.142189999999999	56.135568999999997	0103000020E6100000010000000500000055A1815836754E40FBAC32535A114C4055A1815836754E40BCE82B4833124C409510ACAA97774E40BCE82B4833124C409510ACAA97774E40FBAC32535A114C4055A1815836754E40FBAC32535A114C40
13231	Зотино	6	58	1255	61.660110000000003	61.671922000000002	56.198900999999999	56.190787	0103000020E610000001000000050000009CE1067C7ED44E4040C05AB56B184C409CE1067C7ED44E402312859675194C4041BB438A01D64E402312859675194C4041BB438A01D64E4040C05AB56B184C409CE1067C7ED44E4040C05AB56B184C40
13709	Знаменка	6	58	1255	60.872205999999998	60.902209999999997	56.117406000000003	56.109451	0103000020E61000000100000005000000FFAF3A72A46F4E40DBC1887D020E4C40FFAF3A72A46F4E40562DE928070F4C40E40F069E7B734E40562DE928070F4C40E40F069E7B734E40DBC1887D020E4C40FFAF3A72A46F4E40DBC1887D020E4C40
13587	Григорьевка	6	58	1255	60.926015	60.955084999999997	56.163142999999998	56.154153999999998	0103000020E610000001000000050000007F4DD6A887764E4017467A51BB134C407F4DD6A887764E4021C9ACDEE1144C4038F3AB39407A4E4021C9ACDEE1144C4038F3AB39407A4E4017467A51BB134C407F4DD6A887764E4017467A51BB134C40
14158	Воскресенское	6	58	1255	60.816394000000003	60.843854999999998	56.076960999999997	56.060262999999999	0103000020E6100000010000000500000048533D997F684E405514AFB2B6074C4048533D997F684E40A208A9DBD9094C4075C8CD70036C4E40A208A9DBD9094C4075C8CD70036C4E405514AFB2B6074C4048533D997F684E405514AFB2B6074C40
13509	Воздвиженка	6	58	1255	60.761353999999997	60.803277999999999	56.130206000000001	56.114766000000003	0103000020E61000000100000005000000E256410C74614E40AC58FCA6B00E4C40E256410C74614E401ADF1797AA104C4053CC41D0D1664E401ADF1797AA104C4053CC41D0D1664E40AC58FCA6B00E4C40E256410C74614E40AC58FCA6B00E4C40
12947	Вишневогорск	6	58	1255	60.623632999999998	60.673616000000003	56.019435000000001	55.979868000000003	0103000020E610000001000000050000006ADAC534D34F4E40CF328B506CFD4B406ADAC534D34F4E40EAB298D87C024C40FB07910C39564E40EAB298D87C024C40FB07910C39564E40CF328B506CFD4B406ADAC534D34F4E40CF328B506CFD4B40
13463	Булзи	6	58	1255	61.056783000000003	61.118505999999996	56.101819999999996	56.071047	0103000020E6100000010000000500000001FC53AA44874E404DBD6E1118094C4001FC53AA44874E40130A1170080D4C409C3061342B8F4E40130A1170080D4C409C3061342B8F4E404DBD6E1118094C4001FC53AA44874E404DBD6E1118094C40
29049	Ближний Береговой	6	58	1255	60.779240000000001	60.786389999999997	56.016305000000003	56.007407999999998	0103000020E6100000010000000500000016DEE522BE634E4048DDCEBEF2004C4016DEE522BE634E4072E1404816024C4062F3716DA8644E4072E1404816024C4062F3716DA8644E4048DDCEBEF2004C4016DEE522BE634E4048DDCEBEF2004C40
13370	Береговой	6	58	1255	61.266728000000001	61.298520000000003	55.997598000000004	55.981943000000001	0103000020E61000000100000005000000B876A22424A24E40A0C4E74EB0FD4B40B876A22424A24E400B47904AB1FF4B40D99942E735A64E400B47904AB1FF4B40D99942E735A64E40A0C4E74EB0FD4B40B876A22424A24E40A0C4E74EB0FD4B40
13144	Багаряк	6	58	1255	61.476726999999997	61.529314999999997	56.215938999999999	56.190807	0103000020E61000000100000005000000620FED6305BD4E40876C205D6C184C40620FED6305BD4E4029779FE3A31B4C4020240B98C0C34E4029779FE3A31B4C4020240B98C0C34E40876C205D6C184C40620FED6305BD4E40876C205D6C184C40
13090	Аракуль	6	58	1255	60.522384000000002	60.539757999999999	56.011560000000003	56.003667999999998	0103000020E6100000010000000500000012FA997ADD424E4057056A3178004C4012FA997ADD424E408CF84ECC7A014C408FE046CA16454E408CF84ECC7A014C408FE046CA16454E4057056A3178004C4012FA997ADD424E4057056A3178004C40
14142	Аллаки	6	58	1255	60.958345999999999	60.993496999999998	56.004095999999997	55.994542000000003	0103000020E610000001000000050000004F20EC14AB7A4E40CD3FFA264DFF4B404F20EC14AB7A4E40AF05BD3786004C4049D6E1E82A7F4E40AF05BD3786004C4049D6E1E82A7F4E40CD3FFA264DFF4B404F20EC14AB7A4E40CD3FFA264DFF4B40
14312	Южно-Степной	6	58	1235	60.670138999999999	60.691276999999999	52.825732000000002	52.817275000000002	0103000020E610000001000000050000001763601DC7554E40516B9A779C684A401763601DC7554E405EA10F96B1694A400EBDC5C37B584E405EA10F96B1694A400EBDC5C37B584E40516B9A779C684A401763601DC7554E40516B9A779C684A40
13937	Центральный	6	58	1235	60.701121999999998	60.73612	53.067920000000001	53.048344	0103000020E61000000100000005000000C8409E5DBE594E409A7ADD2230864A40C8409E5DBE594E40465F419AB1884A403CF71E2E395E4E40465F419AB1884A403CF71E2E395E4E409A7ADD2230864A40C8409E5DBE594E409A7ADD2230864A40
15173	Татищево	6	58	1235	60.36985	60.384250000000002	53.362290000000002	53.355663999999997	0103000020E610000001000000050000007A36AB3E572F4E40A92EE06586AD4A407A36AB3E572F4E407CD5CA845FAE4A4077BE9F1A2F314E407CD5CA845FAE4A4077BE9F1A2F314E40A92EE06586AD4A407A36AB3E572F4E40A92EE06586AD4A40
14141	Сухореченский	6	58	1235	60.860798000000003	60.877884000000002	52.942312999999999	52.934351999999997	0103000020E610000001000000050000002A3BFDA02E6E4E40E179A9D898774A402A3BFDA02E6E4E403ECC5EB69D784A4041D7BE805E704E403ECC5EB69D784A4041D7BE805E704E40E179A9D898774A402A3BFDA02E6E4E40E179A9D898774A40
14440	Снежный	6	58	1235	60.007389000000003	60.030602000000002	52.874713999999997	52.847904999999997	0103000020E61000000100000005000000D2AC6C1FF2004E40B48EAA26886C4A40D2AC6C1FF2004E403AADDBA0F66F4A409A982EC4EA034E403AADDBA0F66F4A409A982EC4EA034E40B48EAA26886C4A40D2AC6C1FF2004E40B48EAA26886C4A40
14282	Сенной	6	58	1235	60.785429000000001	60.803807999999997	53.029663999999997	53.020977000000002	0103000020E610000001000000050000003D2AFEEF88644E40EE7BD45FAF824A403D2AFEEF88644E402CEFAA07CC834A40AF21382EE3664E402CEFAA07CC834A40AF21382EE3664E40EE7BD45FAF824A403D2AFEEF88644E40EE7BD45FAF824A40
15368	Родники	6	58	1235	60.537260000000003	60.556592000000002	53.104049000000003	53.093884000000003	0103000020E6100000010000000500000078B988EFC4444E4010CF1264048C4A4078B988EFC4444E403C17467A518D4A408D9B1A683E474E403C17467A518D4A408D9B1A683E474E4010CF1264048C4A4078B988EFC4444E4010CF1264048C4A40
14159	Рассветный	6	58	1235	60.887487	60.897736000000002	52.946399	52.942459999999997	0103000020E6100000010000000500000005508C2C99714E40E2E47E87A2784A4005508C2C99714E40CAFB389A23794A408F386403E9724E40CAFB389A23794A408F386403E9724E40E2E47E87A2784A4005508C2C99714E40E2E47E87A2784A40
14563	Песчанка	6	58	1235	59.917009999999998	59.934131999999998	52.971558000000002	52.964388999999997	0103000020E610000001000000050000006F0D6C9560F54D40A2CF4719717B4A406F0D6C9560F54D40661536035C7C4A40D3122BA391F74D40661536035C7C4A40D3122BA391F74D40A2CF4719717B4A406F0D6C9560F54D40A2CF4719717B4A40
14020	Первомайка	6	58	1235	60.934548999999997	60.947135000000003	53.054006000000001	53.045712999999999	0103000020E6100000010000000500000037C1374D9F774E40430070ECD9854A4037C1374D9F774E40D6E429ABE9864A40D0F23CB83B794E40D6E429ABE9864A40D0F23CB83B794E40430070ECD9854A4037C1374D9F774E40430070ECD9854A40
15107	Ольховка	6	58	1235	60.590637999999998	60.618943999999999	53.218809999999998	53.204788999999998	0103000020E610000001000000050000002EE3A6069A4B4E404FCAA486369A4A402EE3A6069A4B4E40D50451F7019C4A401807978E394F4E40D50451F7019C4A401807978E394F4E404FCAA486369A4A402EE3A6069A4B4E404FCAA486369A4A40
13997	Озерный	6	58	1235	60.867634000000002	60.878072000000003	53.095343999999997	53.086236999999997	0103000020E61000000100000005000000E77283A10E6F4E40425A63D0098B4A40E77283A10E6F4E4056EF703B348C4A4044C4CDA964704E4056EF703B348C4A4044C4CDA964704E40425A63D0098B4A40E77283A10E6F4E40425A63D0098B4A40
13866	Новониколаевка	6	58	1235	60.850780999999998	60.869627999999999	53.154049000000001	53.147692999999997	0103000020E6100000010000000500000072874D64E66C4E408F6CAE9AE7924A4072874D64E66C4E40A27DACE0B7934A40CBD765F84F6F4E40A27DACE0B7934A40CBD765F84F6F4E408F6CAE9AE7924A4072874D64E66C4E408F6CAE9AE7924A40
14230	Новокатенино	6	58	1235	60.761291	60.773741999999999	52.944375000000001	52.941243999999998	0103000020E610000001000000050000009CDEC5FB71614E4032C7F2AE7A784A409CDEC5FB71614E407B14AE47E1784A4054C554FA09634E407B14AE47E1784A4054C554FA09634E4032C7F2AE7A784A409CDEC5FB71614E4032C7F2AE7A784A40
55094	Новокаолиновый	6	58	1235	59.865212999999997	59.997014	53.127813000000003	53.048462999999998	0103000020E610000001000000050000007A89B14CBFEE4D4074081C0934864A407A89B14CBFEE4D407880272D5C904A40BBD39D279EFF4D407880272D5C904A40BBD39D279EFF4D4074081C0934864A407A89B14CBFEE4D4074081C0934864A40
14591	Неплюевка	6	58	1235	60.097014000000001	60.140726000000001	52.913944000000001	52.888930999999999	0103000020E6100000010000000500000088A06AF46A0C4E4046B3B27DC8714A4088A06AF46A0C4E400E30F31DFC744A4034D93F4F03124E400E30F31DFC744A4034D93F4F03124E4046B3B27DC8714A4088A06AF46A0C4E4046B3B27DC8714A40
15501	Некрасово	6	58	1235	60.347814999999997	60.365682	52.933011	52.916061999999997	0103000020E610000001000000050000007407B133852C4E40DE8D058541754A407407B133852C4E4075E789E76C774A40315EF3AACE2E4E4075E789E76C774A40315EF3AACE2E4E40DE8D058541754A407407B133852C4E40DE8D058541754A40
13851	Мичуринский	6	58	1235	60.750025999999998	60.769843000000002	53.115842999999998	53.101804999999999	0103000020E6100000010000000500000029931ADA00604E40DEC83CF2078D4A4029931ADA00604E403A3C84F1D38E4A40FB0626378A624E403A3C84F1D38E4A40FB0626378A624E40DEC83CF2078D4A4029931ADA00604E40DEC83CF2078D4A40
14836	Михайловка	6	58	1235	59.790374	59.808205999999998	53.18036	53.167000999999999	0103000020E61000000100000005000000EACDA8F92AE54D401CB3EC4960954A40EACDA8F92AE54D40D7C0560916974A402A37514B73E74D40D7C0560916974A402A37514B73E74D401CB3EC4960954A40EACDA8F92AE54D401CB3EC4960954A40
12653	Локомотивный	6	58	1235	60.580227000000001	60.628717999999999	53.053806000000002	53.027644000000002	0103000020E61000000100000005000000CBA0DAE0444A4E401FF7ADD689834A40CBA0DAE0444A4E400F2A711DE3864A400934D8D479504E400F2A711DE3864A400934D8D479504E401FF7ADD689834A40CBA0DAE0444A4E401FF7ADD689834A40
15570	Красный Яр	6	58	1235	60.459744999999998	60.483676000000003	52.979143999999998	52.970989000000003	0103000020E61000000100000005000000F0BF95ECD83A4E404CE3175E497C4A40F0BF95ECD83A4E408D093197547D4A4018EE5C18E93D4E408D093197547D4A4018EE5C18E93D4E404CE3175E497C4A40F0BF95ECD83A4E404CE3175E497C4A40
15402	Краснотал	6	58	1235	60.505854999999997	60.531582999999998	53.075856999999999	53.064722000000003	0103000020E6100000010000000500000050C24CDBBF404E4076AA7CCF48884A4050C24CDBBF404E401A16A3AEB5894A40060E68E90A444E401A16A3AEB5894A40060E68E90A444E4076AA7CCF48884A4050C24CDBBF404E4076AA7CCF48884A40
14645	Коноплянка	6	58	1235	60.233342	60.247931000000001	52.849189000000003	52.841307999999998	0103000020E6100000010000000500000041649126DE1D4E407CEE04FBAF6B4A4041649126DE1D4E40BD8FA339B26C4A401155F833BC1F4E40BD8FA339B26C4A401155F833BC1F4E407CEE04FBAF6B4A4041649126DE1D4E407CEE04FBAF6B4A40
14803	Кизилчилик	6	58	1235	59.965392999999999	59.974870000000003	53.044809000000001	53.031115999999997	0103000020E61000000100000005000000C76471FF91FB4D40F030ED9BFB834A40C76471FF91FB4D4082C8224DBC854A40FFEC478AC8FC4D4082C8224DBC854A40FFEC478AC8FC4D40F030ED9BFB834A40C76471FF91FB4D40F030ED9BFB834A40
14504	Каракуль	6	58	1235	60.068834000000003	60.086602999999997	52.788955000000001	52.779924000000001	0103000020E610000001000000050000002B6D718DCF084E40C9AEB48CD4634A402B6D718DCF084E400282397AFC644A40245E9ECE150B4E400282397AFC644A40245E9ECE150B4E40C9AEB48CD4634A402B6D718DCF084E40C9AEB48CD4634A40
14992	Запасное	6	58	1235	60.016938000000003	60.064576000000002	53.119221000000003	53.106805999999999	0103000020E61000000100000005000000A3073E062B024E401F82AAD1AB8D4A40A3073E062B024E408BFF3BA2428F4A40A20DC00644084E408BFF3BA2428F4A40A20DC00644084E401F82AAD1AB8D4A40A3073E062B024E401F82AAD1AB8D4A40
14358	Елизаветопольское	6	58	1235	60.597330999999997	60.621710999999998	52.838690999999997	52.830013999999998	0103000020E6100000010000000500000088F19A57754C4E406F9C14E63D6A4A4088F19A57754C4E408A39083A5A6B4A401F48DE39944F4E408A39083A5A6B4A401F48DE39944F4E406F9C14E63D6A4A4088F19A57754C4E406F9C14E63D6A4A40
14736	Еленинка	6	58	1235	59.861521000000003	59.886485	53.123085000000003	53.112228000000002	0103000020E610000001000000050000009BE8F35146EE4D4006D9B27C5D8E4A409BE8F35146EE4D4068D0D03FC18F4A4081B2295778F14D4068D0D03FC18F4A4081B2295778F14D4006D9B27C5D8E4A409BE8F35146EE4D4006D9B27C5D8E4A40
14916	Джабык	6	58	1235	59.953212000000001	59.982900999999998	53.171978000000003	53.154902	0103000020E61000000100000005000000CF13CFD902FA4D40E10A28D4D3934A40CF13CFD902FA4D40D5D0066003964A40541A31B3CFFD4D40D5D0066003964A40541A31B3CFFD4D40E10A28D4D3934A40CF13CFD902FA4D40E10A28D4D3934A40
15205	Горная	6	58	1235	60.464578000000003	60.475105999999997	53.342699000000003	53.337538000000002	0103000020E610000001000000050000007638BA4A773B4E402194F77134AB4A407638BA4A773B4E409BAF928FDDAB4A401211FE45D03C4E409BAF928FDDAB4A401211FE45D03C4E402194F77134AB4A407638BA4A773B4E402194F77134AB4A40
14427	Вишневый	6	58	1235	60.604050000000001	60.615772999999997	52.944685	52.936045	0103000020E610000001000000050000000C93A982514D4E40CB4A9352D0774A400C93A982514D4E40C9022670EB784A40416150A6D14E4E40C9022670EB784A40416150A6D14E4E40CB4A9352D0774A400C93A982514D4E40CB4A9352D0774A40
15077	Великопетровка	6	58	1235	60.472627000000003	60.498651000000002	53.257505000000002	53.241228	0103000020E61000000100000005000000721AA20A7F3C4E409370218FE09E4A40721AA20A7F3C4E403BC780ECF5A04A40118FC4CBD33F4E403BC780ECF5A04A40118FC4CBD33F4E409370218FE09E4A40721AA20A7F3C4E409370218FE09E4A40
15465	Варшавка	6	58	1235	60.325752000000001	60.353223	52.851261000000001	52.839001000000003	0103000020E61000000100000005000000A54DD53DB2294E40D9278062646B4A40A54DD53DB2294E401DAED51EF66C4A40F6984869362D4E401DAED51EF66C4A40F6984869362D4E40D9278062646B4A40A54DD53DB2294E40D9278062646B4A40
15270	Анненское	6	58	1235	60.357920999999997	60.399369	53.134929	53.109271	0103000020E610000001000000050000009BC6F65AD02D4E405BB39597FC8D4A409BC6F65AD02D4E4018247D5A45914A40A304FD851E334E4018247D5A45914A40A304FD851E334E405BB39597FC8D4A409BC6F65AD02D4E405BB39597FC8D4A40
14716	Акмулла	6	58	1235	60.139594000000002	60.159275999999998	53.041074000000002	53.028565	0103000020E61000000100000005000000E25B5837DE114E40B6679604A8834A40E25B5837DE114E40A35BAFE941854A40D384ED2763144E40A35BAFE941854A40D384ED2763144E40B6679604A8834A40E25B5837DE114E40B6679604A8834A40
23146	Шибаево	6	58	852	61.619236000000001	61.637309999999999	54.913732000000003	54.903308000000003	0103000020E61000000100000005000000C040102043CF4E408B1BB7989F734B40C040102043CF4E4083A7902BF5744B40F6B4C35F93D14E4083A7902BF5744B40F6B4C35F93D14E408B1BB7989F734B40C040102043CF4E408B1BB7989F734B40
23114	Шеломенцево	6	58	852	61.697128999999997	61.714573999999999	54.831079000000003	54.812654999999999	0103000020E61000000100000005000000ED0BE8853BD94E4027F73B1405684B40ED0BE8853BD94E403AB2F2CB606A4B4034492C2977DB4E403AB2F2CB606A4B4034492C2977DB4E4027F73B1405684B40ED0BE8853BD94E4027F73B1405684B40
48686	Шатрово	6	58	852	61.733933	61.755105999999998	54.959975999999997	54.950122999999998	0103000020E61000000100000005000000433A3C84F1DD4E40B51666A19D794B40433A3C84F1DD4E40F2785A7EE07A4B40B6813B50A7E04E40F2785A7EE07A4B40B6813B50A7E04E40B51666A19D794B40433A3C84F1DD4E40B51666A19D794B40
55208	Таянды	6	58	852	61.043182999999999	61.060996000000003	54.789732000000001	54.776918000000002	0103000020E61000000100000005000000205F420587854E403DD68C0C72634B40205F420587854E40664D2CF015654B40EA9788B7CE874E40664D2CF015654B40EA9788B7CE874E403DD68C0C72634B40205F420587854E403DD68C0C72634B40
48352	Сухоруково	6	58	852	61.672955000000002	61.703076000000003	54.735796999999998	54.724437000000002	0103000020E610000001000000050000000057B26323D64E409581035ABA5C4B400057B26323D64E4059BF99982E5E4B401F4DF564FED94E4059BF99982E5E4B401F4DF564FED94E409581035ABA5C4B400057B26323D64E409581035ABA5C4B40
48053	Соколово	6	58	852	61.529449999999997	61.547289999999997	54.717765999999997	54.705267999999997	0103000020E61000000100000005000000006F8104C5C34E402975C938465A4B40006F8104C5C34E4022179CC1DF5B4B40C3B645990DC64E4022179CC1DF5B4B40C3B645990DC64E402975C938465A4B40006F8104C5C34E402975C938465A4B40
23428	Селезян	6	58	852	61.814763999999997	61.83361	54.920222000000003	54.900689	0103000020E61000000100000005000000A4FACE2F4AE84E40F86EF3C649734B40A4FACE2F4AE84E40A587A1D5C9754B402DCF83BBB3EA4E40A587A1D5C9754B402DCF83BBB3EA4E40F86EF3C649734B40A4FACE2F4AE84E40F86EF3C649734B40
21932	Сарыкуль	6	58	852	61.592492999999997	61.606112000000003	54.721249999999998	54.707946	0103000020E61000000100000005000000F10D85CFD6CB4E40C1AA7AF99D5A4B40F10D85CFD6CB4E40B81E85EB515C4B4049DBF81395CD4E40B81E85EB515C4B4049DBF81395CD4E40C1AA7AF99D5A4B40F10D85CFD6CB4E40C1AA7AF99D5A4B40
19910	Сары	6	58	852	61.309784999999998	61.315722000000001	54.824311000000002	54.815550000000002	0103000020E610000001000000050000004BE5ED08A7A74E405C2041F163684B404BE5ED08A7A74E40D55DD90583694B405950189469A84E40D55DD90583694B405950189469A84E405C2041F163684B404BE5ED08A7A74E405C2041F163684B40
48016	Приозерный	6	58	852	61.430159000000003	61.440354999999997	54.769616999999997	54.762397	0103000020E61000000100000005000000408A3A730FB74E40C5C8923996614B40408A3A730FB74E400AB952CF82624B40A6D0798D5DB84E400AB952CF82624B40A6D0798D5DB84E40C5C8923996614B40408A3A730FB74E40C5C8923996614B40
48503	Потапово	6	58	852	61.715544999999999	61.741433999999998	54.778533000000003	54.768360000000001	0103000020E610000001000000050000007DE882FA96DB4E40FCC6D79E59624B407DE882FA96DB4E40ABED26F8A6634B403C122F4FE7DE4E40ABED26F8A6634B403C122F4FE7DE4E40FCC6D79E59624B407DE882FA96DB4E40FCC6D79E59624B40
48430	Погудино	6	58	852	62.004612999999999	62.017927	54.762417999999997	54.753819999999997	0103000020E610000001000000050000007711A62897004F400D897B2C7D604B407711A62897004F40DCF0BBE996614B40925B936E4B024F40DCF0BBE996614B40925B936E4B024F400D897B2C7D604B407711A62897004F400D897B2C7D604B40
48399	Погорелка	6	58	852	60.961112	60.974722	54.748196999999998	54.736691	0103000020E6100000010000000500000086E5CFB7057B4E40F72004E44B5E4B4086E5CFB7057B4E408FFB56EBC45F4B408A58C4B0C37C4E408FFB56EBC45F4B408A58C4B0C37C4E40F72004E44B5E4B4086E5CFB7057B4E40F72004E44B5E4B40
55214	Писклово	6	58	852	62.005727	62.023954000000003	54.585304000000001	54.567805999999997	0103000020E6100000010000000500000023DA8EA9BB004F407D3CF4DDAD484B4023DA8EA9BB004F40E71BD13DEB4A4B40E04DB7EC10034F40E71BD13DEB4A4B40E04DB7EC10034F407D3CF4DDAD484B4023DA8EA9BB004F407D3CF4DDAD484B40
55173	Печенкино	6	58	852	61.621212999999997	61.654440999999998	54.848582	54.839925000000001	0103000020E61000000100000005000000CE6C57E883CF4E40E10B93A9826B4B40CE6C57E883CF4E40B5FCC0559E6C4B40AD1402B9C4D34E40B5FCC0559E6C4B40AD1402B9C4D34E40E10B93A9826B4B40CE6C57E883CF4E40E10B93A9826B4B40
22923	Новобатурино	6	58	852	61.346975	61.362552000000001	54.856144	54.848292000000001	0103000020E61000000100000005000000CAC342AD69AC4E40AEBA0ED5946C4B40CAC342AD69AC4E4054556820966D4B40B98C9B1A68AE4E4054556820966D4B40B98C9B1A68AE4E40AEBA0ED5946C4B40CAC342AD69AC4E40AEBA0ED5946C4B40
22629	Новобаландино	6	58	852	61.738568000000001	61.750605999999998	54.596113000000003	54.586091000000003	0103000020E61000000100000005000000A2EF6E6589DE4E406FBDA607054B4B40A2EF6E6589DE4E4038DC476E4D4C4B4037177FDB13E04E4038DC476E4D4C4B4037177FDB13E04E406FBDA607054B4B40A2EF6E6589DE4E406FBDA607054B4B40
48312	Николаевка	6	58	852	61.843411000000003	61.853318999999999	54.659829000000002	54.649082999999997	0103000020E61000000100000005000000180B43E4F4EB4E40DDB1D82615534B40180B43E4F4EB4E40E8F9D34675544B401807978E39ED4E40E8F9D34675544B401807978E39ED4E40DDB1D82615534B40180B43E4F4EB4E40DDB1D82615534B40
48628	Назарово	6	58	852	61.764142999999997	61.791623000000001	54.834744999999998	54.824435000000001	0103000020E61000000100000005000000D13B1570CFE14E40C156091687694B40D13B1570CFE14E40F0BF95ECD86A4B4076E107E753E54E40F0BF95ECD86A4B4076E107E753E54E40C156091687694B40D13B1570CFE14E40C156091687694B40
45505	Лебедевка	6	58	852	61.958134999999999	61.973128000000003	54.722845999999997	54.706698000000003	0103000020E610000001000000050000009413ED2AA4FA4E4006137F14755A4B409413ED2AA4FA4E40AF05BD37865C4B40346953758FFC4E40AF05BD37865C4B40346953758FFC4E4006137F14755A4B409413ED2AA4FA4E4006137F14755A4B40
48562	Кораблево	6	58	852	61.696375000000003	61.708689999999997	54.933366999999997	54.922927999999999	0103000020E610000001000000050000004260E5D022D94E400648348122764B404260E5D022D94E403315E29178774B4049809A5AB6DA4E403315E29178774B4049809A5AB6DA4E400648348122764B404260E5D022D94E400648348122764B40
48084	Копытово	6	58	852	62.007469999999998	62.026918999999999	54.822800999999998	54.811067000000001	0103000020E61000000100000005000000BED9E6C6F4004F40B3EE1F0BD1674B40BED9E6C6F4004F40DC0E0D8B51694B400D52F01472034F40DC0E0D8B51694B400D52F01472034F40B3EE1F0BD1674B40BED9E6C6F4004F40B3EE1F0BD1674B40
6443	Коелга	6	58	852	60.890712000000001	60.915703000000001	54.661208999999999	54.642299999999999	0103000020E61000000100000005000000CF13CFD902724E40431CEBE236524B40CF13CFD902724E4012691B7FA2544B40AFEC82C135754E4012691B7FA2544B40AFEC82C135754E40431CEBE236524B40CF13CFD902724E40431CEBE236524B40
22540	Каратабан	6	58	852	61.671751999999998	61.703732000000002	54.69211	54.672825000000003	0103000020E61000000100000005000000E48233F8FBD54E4032772D211F564B40E48233F8FBD54E40069E7B0F97584B400893E2E313DA4E40069E7B0F97584B400893E2E313DA4E4032772D211F564B40E48233F8FBD54E4032772D211F564B40
22965	Журавлево	6	58	852	61.664169999999999	61.677653999999997	54.861004999999999	54.850816000000002	0103000020E61000000100000005000000FE7DC68503D54E40EF74E789E76C4B40FE7DC68503D54E40A3586E69356E4B407500C45DBDD64E40A3586E69356E4B407500C45DBDD64E40EF74E789E76C4B40FE7DC68503D54E40EF74E789E76C4B40
6348	Еткуль	6	58	852	61.571660999999999	61.618329000000003	54.845720999999998	54.807414000000001	0103000020E6100000010000000500000007B309302CC94E40912A8A5759674B4007B309302CC94E402C45F295406C4B408E95986725CF4E402C45F295406C4B408E95986725CF4E40912A8A5759674B4007B309302CC94E40912A8A5759674B40
22259	Еманжелинка	6	58	852	61.283751000000002	61.311078000000002	54.812840999999999	54.788891	0103000020E61000000100000005000000899AE8F351A44E40EB8D5A61FA644B40899AE8F351A44E4089EC832C0B684B40A7406667D1A74E4089EC832C0B684B40A7406667D1A74E40EB8D5A61FA644B40899AE8F351A44E40EB8D5A61FA644B40
48377	Долговка	6	58	852	60.932842999999998	60.950682999999998	54.795586999999998	54.78736	0103000020E61000000100000005000000B9A6406667774E40DB166536C8644B40B9A6406667774E40B60F79CBD5654B407CEE04FBAF794E40B60F79CBD5654B407CEE04FBAF794E40DB166536C8644B40B9A6406667774E40DB166536C8644B40
22239	Депутатский	6	58	852	61.122000999999997	61.133426999999998	54.843865000000001	54.834781	0103000020E61000000100000005000000268A90BA9D8F4E403D29931ADA6A4B40268A90BA9D8F4E40999EB0C4036C4B40A2B3CC2214914E40999EB0C4036C4B40A2B3CC2214914E403D29931ADA6A4B40268A90BA9D8F4E403D29931ADA6A4B40
22485	Грознецкий	6	58	852	61.553128999999998	61.558717000000001	54.648119999999999	54.639122	0103000020E610000001000000050000000EBC5AEECCC64E40BA13ECBFCE514B400EBC5AEECCC64E4017F19D98F5524B40105CE50984C74E4017F19D98F5524B40105CE50984C74E40BA13ECBFCE514B400EBC5AEECCC64E40BA13ECBFCE514B40
48149	Березняки	6	58	852	61.179394000000002	61.192329999999998	54.814822999999997	54.805728000000002	0103000020E61000000100000005000000A08CF161F6964E405ABC581822674B40A08CF161F6964E40A983BC1E4C684B401405FA449E984E40A983BC1E4C684B401405FA449E984E405ABC581822674B40A08CF161F6964E405ABC581822674B40
61087	Белоусово	6	58	852	61.939737000000001	61.957172999999997	54.801281000000003	54.787168000000001	0103000020E61000000100000005000000ABEB504D49F84E40973AC8EBC1644B40ABEB504D49F84E40FEF3346090664B409ECE15A584FA4E40FEF3346090664B409ECE15A584FA4E40973AC8EBC1644B40ABEB504D49F84E40973AC8EBC1644B40
21840	Белоносово	6	58	852	61.435395999999997	61.458140999999998	54.818631000000003	54.805967000000003	0103000020E6100000010000000500000094675E0EBBB74E40DF5339ED29674B4094675E0EBBB74E40F33E8EE6C8684B4076FA415DA4BA4E40F33E8EE6C8684B4076FA415DA4BA4E40DF5339ED29674B4094675E0EBBB74E40DF5339ED29674B40
21750	Бектыш	6	58	852	61.433464999999998	61.454870999999997	54.869973999999999	54.856335999999999	0103000020E61000000100000005000000F67AF7C77BB74E409831056B9C6D4B40F67AF7C77BB74E40662FDB4E5B6F4B400C73823639BA4E40662FDB4E5B6F4B400C73823639BA4E409831056B9C6D4B40F67AF7C77BB74E409831056B9C6D4B40
48594	Аткуль	6	58	852	61.880341000000001	61.897328000000002	54.892302000000001	54.879722999999998	0103000020E61000000100000005000000FA298E03AFF04E40FE4465C39A704B40FA298E03AFF04E40E413B2F336724B407EE4D6A4DBF24E40E413B2F336724B407EE4D6A4DBF24E40FE4465C39A704B40FA298E03AFF04E40FE4465C39A704B40
6583	Этовна	6	58	134	60.057406999999998	60.066983	54.032792000000001	54.025779	0103000020E61000000100000005000000DEC7D11C59074E4038F6ECB94C034B40DEC7D11C59074E4004C93B8732044B40A93121E692084E4004C93B8732044B40A93121E692084E4038F6ECB94C034B40DEC7D11C59074E4038F6ECB94C034B40
7467	Эстонский	6	58	134	59.427796000000001	59.459668000000001	53.906267999999997	53.900644999999997	0103000020E6100000010000000500000008AEF204C2B64D402827DA5548F34A4008AEF204C2B64D40A6B4FE9600F44A404582A966D6BA4D40A6B4FE9600F44A404582A966D6BA4D402827DA5548F34A4008AEF204C2B64D402827DA5548F34A40
7174	Шеметовский	6	58	134	59.573430999999999	59.586258999999998	54.056339000000001	54.050350999999999	0103000020E610000001000000050000009CC1DF2F66C94D401329CDE671064B409CC1DF2F66C94D40A33EC91D36074B402AFEEF880ACB4D40A33EC91D36074B402AFEEF880ACB4D401329CDE671064B409CC1DF2F66C94D401329CDE671064B40
7256	Форштадт	6	58	134	59.188512000000003	59.212891999999997	53.894803000000003	53.886085000000001	0103000020E61000000100000005000000A873452921984D40F33CB83B6BF14A40A873452921984D406DAE9AE788F24A403ECA880B409B4D406DAE9AE788F24A403ECA880B409B4D40F33CB83B6BF14A40A873452921984D40F33CB83B6BF14A40
5896	Уфимский	6	58	134	59.821078999999997	59.843276000000003	53.816817999999998	53.803590999999997	0103000020E610000001000000050000005837DE1D19E94D40122EE411DCE64A405837DE1D19E94D405E64027E8DE84A4038C0CC77F0EB4D405E64027E8DE84A4038C0CC77F0EB4D40122EE411DCE64A405837DE1D19E94D40122EE411DCE64A40
5443	Урлядинский	6	58	134	59.412201000000003	59.429009000000001	54.031078999999998	54.022061000000001	0103000020E6100000010000000500000073309B00C3B44D402FC214E5D2024B4073309B00C3B44D40D34B8C65FA034B40475854C4E9B64D40D34B8C65FA034B40475854C4E9B64D402FC214E5D2024B4073309B00C3B44D402FC214E5D2024B40
6295	Томинский	6	58	134	60.248747999999999	60.257049000000002	53.939593000000002	53.932749000000001	0103000020E61000000100000005000000037976F9D61F4E403830B95164F74A40037976F9D61F4E4078465B9544F84A40193C4CFBE6204E4078465B9544F84A40193C4CFBE6204E403830B95164F74A40037976F9D61F4E403830B95164F74A40
5786	Тайсара	6	58	134	58.901876999999999	58.916843	53.708384000000002	53.693154	0103000020E61000000100000005000000DE019EB470734D40B98B3045B9D84A40DE019EB470734D403D81B053ACDA4A408448861C5B754D403D81B053ACDA4A408448861C5B754D40B98B3045B9D84A40DE019EB470734D40B98B3045B9D84A40
6449	Сухтелинский	6	58	134	60.070433000000001	60.089216999999998	53.951410000000003	53.941468999999998	0103000020E6100000010000000500000093C7D3F203094E405299620E82F84A4093C7D3F203094E402F8B89CDC7F94A40A59F70766B0B4E402F8B89CDC7F94A40A59F70766B0B4E405299620E82F84A4093C7D3F203094E405299620E82F84A40
7094	Сурменевский	6	58	134	59.670934000000003	59.698844999999999	54.052190000000003	54.034103000000002	0103000020E6100000010000000500000022E3512AE1D54D4006D9B27C5D044B4022E3512AE1D54D40D1967329AE064B408FFCC1C073D94D40D1967329AE064B408FFCC1C073D94D4006D9B27C5D044B4022E3512AE1D54D4006D9B27C5D044B40
46396	Спасский	6	58	134	59.181783000000003	59.212488	53.724167000000001	53.693393999999998	0103000020E6100000010000000500000001FC53AA44974D400E9F7422C1D84A4001FC53AA44974D40D5EB1681B1DC4A406F6589CE329B4D40D5EB1681B1DC4A406F6589CE329B4D400E9F7422C1D84A4001FC53AA44974D400E9F7422C1D84A40
46085	Смирновский	6	58	134	59.784553000000002	59.790202999999998	53.821224999999998	53.809136000000002	0103000020E61000000100000005000000467D923B6CE44D401502B9C491E74A40467D923B6CE44D402CD49AE61DE94A40BD19355F25E54D402CD49AE61DE94A40BD19355F25E54D401502B9C491E74A40467D923B6CE44D401502B9C491E74A40
5753	Смеловский	6	58	134	58.844996000000002	58.885061	53.602206000000002	53.590122999999998	0103000020E610000001000000050000001BA034D4286C4D4007CF842689CB4A401BA034D4286C4D403DBA111615CD4A4087FBC8AD49714D403DBA111615CD4A4087FBC8AD49714D4007CF842689CB4A401BA034D4286C4D4007CF842689CB4A40
7317	Сафроновский	6	58	134	59.330167000000003	59.345545999999999	53.894266999999999	53.887087999999999	0103000020E61000000100000005000000F69B89E942AA4D4047567E198CF14A40F69B89E942AA4D402E724F5777F24A40BEA1F0D93AAC4D402E724F5777F24A40BEA1F0D93AAC4D4047567E198CF14A40F69B89E942AA4D4047567E198CF14A40
7388	Самарский	6	58	134	59.240479000000001	59.253155	54.009146999999999	53.996206999999998	0103000020E61000000100000005000000F92F1004C89E4D40EC8502B683FF4A40F92F1004C89E4D40A2ED98BA2B014B40D1E80E6267A04D40A2ED98BA2B014B40D1E80E6267A04D40EC8502B683FF4A40F92F1004C89E4D40EC8502B683FF4A40
2024	Сабановский	6	58	134	59.341386999999997	59.349345999999997	53.623899000000002	53.620266999999998	0103000020E61000000100000005000000C823B891B2AB4D40DEE4B7E864CF4A40C823B891B2AB4D40E98024ECDBCF4A40847EA65EB7AC4D40E98024ECDBCF4A40847EA65EB7AC4D40DEE4B7E864CF4A40C823B891B2AB4D40DEE4B7E864CF4A40
6627	Полосинский	6	58	134	59.414555	59.427867999999997	53.848759999999999	53.843299000000002	0103000020E6100000010000000500000057B2632310B54D40F0DFBC38F1EB4A4057B2632310B54D409413ED2AA4EC4A40A180ED60C4B64D409413ED2AA4EC4A40A180ED60C4B64D40F0DFBC38F1EB4A4057B2632310B54D40F0DFBC38F1EB4A40
46130	Подольский	6	58	134	59.643931000000002	59.658456999999999	53.858150000000002	53.850012999999997	0103000020E61000000100000005000000B7F0BC546CD24D406116DA39CDEC4A40B7F0BC546CD24D40FD87F4DBD7ED4A404069A85148D44D40FD87F4DBD7ED4A404069A85148D44D406116DA39CDEC4A40B7F0BC546CD24D406116DA39CDEC4A40
46155	Петропавловский	6	58	134	60.086297000000002	60.137546	54.028249000000002	54.007258	0103000020E61000000100000005000000185FB4C70B0B4E40335184D4ED004B40185FB4C70B0B4E408692C9A99D034B400AD9791B9B114E408692C9A99D034B400AD9791B9B114E40335184D4ED004B40185FB4C70B0B4E40335184D4ED004B40
7180	Новоурлядинский	6	58	134	59.482574999999997	59.48854	53.986742999999997	53.982846000000002	0103000020E61000000100000005000000006F8104C5BD4D409180D1E5CDFD4A40006F8104C5BD4D40494739984DFE4A40D8648D7A88BE4D40494739984DFE4A40D8648D7A88BE4D409180D1E5CDFD4A40006F8104C5BD4D409180D1E5CDFD4A40
6343	Новотоминский	6	58	134	60.262591999999998	60.270128	53.888229000000003	53.882703999999997	0103000020E610000001000000050000007A185A9D9C214E403106D671FCF04A407A185A9D9C214E40ED2DE57CB1F14A40F0DDE68D93224E40ED2DE57CB1F14A40F0DDE68D93224E403106D671FCF04A407A185A9D9C214E403106D671FCF04A40
47284	Новоозерный	6	58	134	59.405957999999998	59.412712999999997	53.637577999999998	53.630156999999997	0103000020E6100000010000000500000058C6866EF6B34D40382C0DFCA8D04A4058C6866EF6B34D401553E9279CD14A4028D192C7D3B44D401553E9279CD14A4028D192C7D3B44D40382C0DFCA8D04A4058C6866EF6B34D40382C0DFCA8D04A40
6270	Новокопаловский	6	58	134	59.913857	59.924042999999998	53.972875000000002	53.965978999999997	0103000020E610000001000000050000003F1C2444F9F44D40B7CF2A33A5FB4A403F1C2444F9F44D404A0C022B87FC4A40828C800A47F64D404A0C022B87FC4A40828C800A47F64D40B7CF2A33A5FB4A403F1C2444F9F44D40B7CF2A33A5FB4A40
6764	Нововоронинский	6	58	134	59.295707999999998	59.311554000000001	53.764712000000003	53.751175000000003	0103000020E6100000010000000500000031957EC2D9A54D4052499D8026E04A4031957EC2D9A54D40EC6D3315E2E14A4010786000E1A74D40EC6D3315E2E14A4010786000E1A74D4052499D8026E04A4031957EC2D9A54D4052499D8026E04A40
7450	Новоахуново	6	58	134	59.257035000000002	59.270868999999998	53.956777000000002	53.946058000000001	0103000020E61000000100000005000000B476DB85E6A04D40410FB56D18F94A40B476DB85E6A04D40524832AB77FA4A400740DCD5ABA24D40524832AB77FA4A400740DCD5ABA24D40410FB56D18F94A40B476DB85E6A04D40410FB56D18F94A40
55148	Межозерный	6	58	134	59.360394999999997	59.394361000000004	54.159241999999999	54.129717999999997	0103000020E610000001000000050000002A52616C21AE4D40ECD973999A104B402A52616C21AE4D402713B70A62144B40B0E8D66B7AB24D402713B70A62144B40B0E8D66B7AB24D40ECD973999A104B402A52616C21AE4D40ECD973999A104B40
6974	Малый Бугодак	6	58	134	58.959702	58.989570999999998	53.826673	53.811194	0103000020E61000000100000005000000F1F3DF83D77A4D40105B7A34D5E74A40F1F3DF83D77A4D403CBEBD6BD0E94A40F6083543AA7E4D403CBEBD6BD0E94A40F6083543AA7E4D40105B7A34D5E74A40F1F3DF83D77A4D40105B7A34D5E74A40
45908	Ложкина	6	58	134	59.303209000000003	59.316305999999997	54.072557000000003	54.064568000000001	0103000020E610000001000000050000002B6D718DCFA64D401F2FA4C343084B402B6D718DCFA64D40460C3B8C49094B40A8C30AB77CA84D40460C3B8C49094B40A8C30AB77CA84D401F2FA4C343084B402B6D718DCFA64D401F2FA4C343084B40
46334	Линевка	6	58	134	60.263193000000001	60.274538999999997	54.000070999999998	53.992497	0103000020E61000000100000005000000A0C4E74EB0214E40663046240AFF4A40A0C4E74EB0214E40C956975302004B40FF3C0D1824234E40C956975302004B40FF3C0D1824234E40663046240AFF4A40A0C4E74EB0214E40663046240AFF4A40
6208	Крутой Лог	6	58	134	59.911602000000002	59.918922999999999	54.034103000000002	54.026339999999998	0103000020E61000000100000005000000EE7BD45FAFF44D40CF49EF1B5F034B40EE7BD45FAFF44D4006D9B27C5D044B406745D4449FF54D4006D9B27C5D044B406745D4449FF54D40CF49EF1B5F034B40EE7BD45FAFF44D40CF49EF1B5F034B40
5824	Краснинский	6	58	134	59.656103000000002	59.677177	53.927129999999998	53.907217000000003	0103000020E610000001000000050000005CE7DF2EFBD34D4008B0C8AF1FF44A405CE7DF2EFBD34D40FB912232ACF64A403C4D66BCADD64D40FB912232ACF64A403C4D66BCADD64D4008B0C8AF1FF44A405CE7DF2EFBD34D4008B0C8AF1FF44A40
46174	Комсомольское	6	58	134	60.114485999999999	60.125230000000002	54.078600000000002	54.070664999999998	0103000020E61000000100000005000000C8EC2C7AA70E4E4065FCFB8C0B094B40C8EC2C7AA70E4E4099BB96900F0A4B40323D618907104E4099BB96900F0A4B40323D618907104E4065FCFB8C0B094B40C8EC2C7AA70E4E4065FCFB8C0B094B40
46569	Кожанов	6	58	134	59.105255999999997	59.115281000000003	53.801175999999998	53.788581999999998	0103000020E6100000010000000500000098DA5207798D4D406D1B4641F0E44A4098DA5207798D4D40882B67EF8CE64A40D36C1E87C18E4D40882B67EF8CE64A40D36C1E87C18E4D406D1B4641F0E44A4098DA5207798D4D406D1B4641F0E44A40
5622	Кирса	6	58	134	58.929527999999998	58.963420999999997	53.646102999999997	53.631507999999997	0103000020E61000000100000005000000AF5B04C6FA764D40C8940F41D5D04A40AF5B04C6FA764D407A6CCB80B3D24A40CAA31B61517B4D407A6CCB80B3D24A40CAA31B61517B4D40C8940F41D5D04A40AF5B04C6FA764D40C8940F41D5D04A40
6445	Кидышевский	6	58	134	59.906751	59.922885000000001	54.106085999999998	54.098621000000001	0103000020E61000000100000005000000C24EB16A10F44D4073D9E89C9F0C4B40C24EB16A10F44D401F48DE39940D4B40077C7E1821F64D401F48DE39940D4B40077C7E1821F64D4073D9E89C9F0C4B40C24EB16A10F44D4073D9E89C9F0C4B40
5347	Карагайский	6	58	134	59.500515	59.531362999999999	54.131031999999998	54.103304000000001	0103000020E61000000100000005000000271422E010C04D40E3C5C210390D4B40271422E010C04D405F5D15A8C5104B40F8A6E9B303C44D405F5D15A8C5104B40F8A6E9B303C44D40E3C5C210390D4B40271422E010C04D40E3C5C210390D4B40
5657	Казанцевский	6	58	134	58.982025	58.995373999999998	53.683919000000003	53.669347000000002	0103000020E610000001000000050000005D6DC5FEB27D4D407E569929ADD54A405D6DC5FEB27D4D40780E65A88AD74A40F4A44C6A687F4D40780E65A88AD74A40F4A44C6A687F4D407E569929ADD54A405D6DC5FEB27D4D407E569929ADD54A40
46414	Ивановский	6	58	134	59.216081000000003	59.225009999999997	53.619064999999999	53.612132000000003	0103000020E61000000100000005000000BC24CE8AA89B4D40E46A64575ACE4A40BC24CE8AA89B4D40938C9C853DCF4A40F0A2AF20CD9C4D40938C9C853DCF4A40F0A2AF20CD9C4D40E46A64575ACE4A40BC24CE8AA89B4D40E46A64575ACE4A40
46682	Дзержинка	6	58	134	59.163404	59.179366999999999	53.845488000000003	53.834394000000003	0103000020E610000001000000050000008E041A6CEA944D4044FD2E6CCDEA4A408E041A6CEA944D408A9466F338EC4A40A67D737FF5964D408A9466F338EC4A40A67D737FF5964D4044FD2E6CCDEA4A408E041A6CEA944D4044FD2E6CCDEA4A40
6010	Горбуновский	6	58	134	59.742942999999997	59.757199	54.001621999999998	53.989919	0103000020E6100000010000000500000064E597C118DF4D40325871AAB5FE4A4064E597C118DF4D40207A522635004B402EC896E5EBE04D40207A522635004B402EC896E5EBE04D40325871AAB5FE4A4064E597C118DF4D40325871AAB5FE4A40
6864	Вятский	6	58	134	58.969107000000001	58.993451999999998	53.907535000000003	53.898797999999999	0103000020E610000001000000050000008FA9BBB20B7C4D40E8DA17D00BF34A408FA9BBB20B7C4D40D97C5C1B2AF44A40A912656F297F4D40D97C5C1B2AF44A40A912656F297F4D40E8DA17D00BF34A408FA9BBB20B7C4D40E8DA17D00BF34A40
7007	Волковский	6	58	134	59.113799	59.140757000000001	53.936540000000001	53.901620999999999	0103000020E61000000100000005000000A4A833F7908E4D408331225168F34A40A4A833F7908E4D40ABB2EF8AE0F74A406FD74B5304924D40ABB2EF8AE0F74A406FD74B5304924D408331225168F34A40A4A833F7908E4D408331225168F34A40
55145	Верхнеуральск	6	58	134	59.186903999999998	59.246569999999998	53.898066	53.852186000000003	0103000020E61000000100000005000000ECBE6378EC974D40F60D4C6E14ED4A40ECBE6378EC974D4024D3A1D3F3F24A405D16139B8F9F4D4024D3A1D3F3F24A405D16139B8F9F4D40F60D4C6E14ED4A40ECBE6378EC974D40F60D4C6E14ED4A40
6890	Большой Бугодак	6	58	134	59.010466000000001	59.014850000000003	53.872236000000001	53.851416	0103000020E6100000010000000500000027DC2BF356814D4044A51133FBEC4A4027DC2BF356814D406A32E36DA5EF4A403D2CD49AE6814D406A32E36DA5EF4A403D2CD49AE6814D4044A51133FBEC4A4027DC2BF356814D4044A51133FBEC4A40
309	Бабарыкинский	6	58	134	59.298268	59.316296999999999	53.549500000000002	53.540419999999997	0103000020E61000000100000005000000BFB854A52DA64D405A0D897B2CC54A40BFB854A52DA64D407593180456C64A4055698B6B7CA84D407593180456C64A4055698B6B7CA84D405A0D897B2CC54A40BFB854A52DA64D405A0D897B2CC54A40
55181	Александровский	6	58	134	59.314824000000002	59.332934000000002	54.128630999999999	54.121597999999999	0103000020E610000001000000050000007AFF1F274CA84D4027A1F485900F4B407AFF1F274CA84D403A2009FB76104B40FDDCD0949DAA4D403A2009FB76104B40FDDCD0949DAA4D4027A1F485900F4B407AFF1F274CA84D4027A1F485900F4B40
13169	Толсты	6	58	834	60.724666999999997	60.745930000000001	53.349837999999998	53.341613000000002	0103000020E61000000100000005000000C6BE64E3C15C4E40B9718BF9B9AB4A40C6BE64E3C15C4E40F372D87DC7AC4A407A8D5DA27A5F4E40F372D87DC7AC4A407A8D5DA27A5F4E40B9718BF9B9AB4A40C6BE64E3C15C4E40B9718BF9B9AB4A40
13147	Солнце	6	58	834	60.660643999999998	60.674836999999997	53.336827999999997	53.329734999999999	0103000020E6100000010000000500000039268BFB8F544E405CACA8C134AA4A4039268BFB8F544E4044300E2E1DAB4A40BC900E0F61564E4044300E2E1DAB4A40BC900E0F61564E405CACA8C134AA4A4039268BFB8F544E405CACA8C134AA4A40
12625	Саламат	6	58	834	61.114652999999997	61.126753000000001	53.557828999999998	53.546038000000003	0103000020E61000000100000005000000B3B112F3AC8E4E40C72FBC92E4C54A40B3B112F3AC8E4E4054E1CFF066C74A40BFD53A7139904E4054E1CFF066C74A40BFD53A7139904E40C72FBC92E4C54A40B3B112F3AC8E4E40C72FBC92E4C54A40
12311	Ракитный	6	58	834	61.268624000000003	61.288170999999998	53.049523999999998	53.042377999999999	0103000020E61000000100000005000000DA756F4562A24E40F2086EA46C854A40DA756F4562A24E40FD2E6CCD56864A40EB538EC9E2A44E40FD2E6CCD56864A40EB538EC9E2A44E40F2086EA46C854A40DA756F4562A24E40F2086EA46C854A40
12904	Правда	6	58	834	60.831035999999997	60.847996999999999	53.419029999999999	53.414220999999998	0103000020E610000001000000050000003AE63C635F6A4E408028983105B54A403AE63C635F6A4E407D0569C6A2B54A40950D6B2A8B6C4E407D0569C6A2B54A40950D6B2A8B6C4E408028983105B54A403AE63C635F6A4E408028983105B54A40
12890	Новый Урал	6	58	834	60.754716000000002	60.776696999999999	53.419040000000003	53.403325000000002	0103000020E610000001000000050000004CE2AC889A604E4061545227A0B34A404CE2AC889A604E40A1DB4B1AA3B54A405EF3AACE6A634E40A1DB4B1AA3B54A405EF3AACE6A634E4061545227A0B34A404CE2AC889A604E4061545227A0B34A40
13094	Новопокровка	6	58	834	61.143416999999999	61.162523999999998	53.310603	53.291127000000003	0103000020E610000001000000050000006058FE7C5B924E40C6FD47A643A54A406058FE7C5B924E400E85CFD6C1A74A4055682096CD944E400E85CFD6C1A74A4055682096CD944E40C6FD47A643A54A406058FE7C5B924E40C6FD47A643A54A40
12522	Новокулевчи	6	58	834	61.253729999999997	61.267724999999999	53.246881000000002	53.236533999999999	0103000020E61000000100000005000000CD0182397AA04E402F3201BF469E4A40CD0182397AA04E407C80EECB999F4A402AA913D044A24E407C80EECB999F4A402AA913D044A24E402F3201BF469E4A40CD0182397AA04E402F3201BF469E4A40
55238	Нововладимировский	6	58	834	61.336616999999997	61.347002000000003	53.050812999999998	53.045822000000001	0103000020E6100000010000000500000089230F4416AB4E40FAB7CB7EDD854A4089230F4416AB4E40179B560A81864A40C4D2C08F6AAC4E40179B560A81864A40C4D2C08F6AAC4E40FAB7CB7EDD854A4089230F4416AB4E40FAB7CB7EDD854A40
12706	Николаевка	6	58	834	61.995081999999996	62.022875999999997	53.042350999999996	53.029013999999997	0103000020E610000001000000050000004C6BD3D85EFF4E40259012BBB6834A404C6BD3D85EFF4E40F8F9EFC16B854A4080EECB99ED024F40F8F9EFC16B854A4080EECB99ED024F40259012BBB6834A404C6BD3D85EFF4E40259012BBB6834A40
11462	Маслоковцы	6	58	834	61.611339999999998	61.632818999999998	53.014319	53.00526	0103000020E610000001000000050000004A5E9D6340CE4E400DFD135CAC804A404A5E9D6340CE4E40105B7A34D5814A40CAA4863600D14E40105B7A34D5814A40CAA4863600D14E400DFD135CAC804A404A5E9D6340CE4E400DFD135CAC804A40
12545	Лейпциг	6	58	834	61.030157000000003	61.064732999999997	53.573951999999998	53.564000999999998	0103000020E610000001000000050000006C5F402FDC834E40A5F44C2F31C84A406C5F402FDC834E40A5BC564277C94A4069FCC22B49884E40A5BC564277C94A4069FCC22B49884E40A5F44C2F31C84A406C5F402FDC834E40A5F44C2F31C84A40
11736	Кызыл-Маяк	6	58	834	60.891007999999999	60.904176999999997	53.323399999999999	53.315126999999997	0103000020E61000000100000005000000B83CD68C0C724E40158BDF1456A84A40B83CD68C0C724E4061C3D32B65A94A40CF656A12BC734E4061C3D32B65A94A40CF656A12BC734E40158BDF1456A84A40B83CD68C0C724E40158BDF1456A84A40
12461	Кулевчи	6	58	834	61.409480000000002	61.438288999999997	53.168863999999999	53.155982000000002	0103000020E61000000100000005000000DC2E34D769B44E40E161DA37F7934A40DC2E34D769B44E4062BCE6559D954A4028999CDA19B84E4062BCE6559D954A4028999CDA19B84E40E161DA37F7934A40DC2E34D769B44E40E161DA37F7934A40
12172	Красный Октябрь	6	58	834	61.148465000000002	61.175370000000001	53.012357999999999	53.001797000000003	0103000020E61000000100000005000000E2CCAFE600934E408F1D54E23A804A40E2CCAFE600934E4007EC6AF294814A408A592F8672964E4007EC6AF294814A408A592F8672964E408F1D54E23A804A40E2CCAFE600934E408F1D54E23A804A40
11951	Красноармейский	6	58	834	60.942131000000003	60.950944	53.301208000000003	53.292149999999999	0103000020E610000001000000050000001EC6A4BF97784E4061C3D32B65A54A401EC6A4BF97784E4094A5D6FB8DA64A40E9297288B8794E4094A5D6FB8DA64A40E9297288B8794E4061C3D32B65A54A401EC6A4BF97784E4061C3D32B65A54A40
12836	Красная Заря	6	58	834	60.689435000000003	60.699854999999999	53.423366000000001	53.418069000000003	0103000020E61000000100000005000000E0DBF4673F584E40583CF54883B54A40E0DBF4673F584E40821E6ADB30B64A40967840D994594E40821E6ADB30B64A40967840D994594E40583CF54883B54A40E0DBF4673F584E40583CF54883B54A40
11912	Комсомольский	6	58	834	61.007590999999998	61.038772000000002	53.286352999999998	53.274588999999999	0103000020E61000000100000005000000395FECBDF8804E40B16B7BBB25A34A40395FECBDF8804E40450E1137A7A44A4011001C7BF6844E40450E1137A7A44A4011001C7BF6844E40B16B7BBB25A34A40395FECBDF8804E40B16B7BBB25A34A40
12414	Кинжитай	6	58	834	61.516747000000002	61.522900999999997	53.19905	53.196492999999997	0103000020E610000001000000050000002FA704C424C24E404B72C0AE26994A402FA704C424C24E4068226C787A994A40D905836BEEC24E4068226C787A994A40D905836BEEC24E404B72C0AE26994A402FA704C424C24E404B72C0AE26994A40
11871	Катенино	6	58	834	61.045141000000001	61.069566000000002	53.183765000000001	53.172857999999998	0103000020E61000000100000005000000B85A272EC7854E400D6D003620964A40B85A272EC7854E4021938C9C85974A40EF74E789E7884E4021938C9C85974A40EF74E789E7884E400D6D003620964A40B85A272EC7854E400D6D003620964A40
11826	Караоба	6	58	834	61.197073000000003	61.207287000000001	53.174477000000003	53.169663	0103000020E610000001000000050000005AF624B039994E40AE2B6684B7954A405AF624B039994E40BD73284355964A4067F16261889A4E40BD73284355964A4067F16261889A4E40AE2B6684B7954A405AF624B039994E40AE2B6684B7954A40
12133	Камышинка	6	58	834	61.189760999999997	61.199382	53.118254	53.111708999999998	0103000020E610000001000000050000003387A4164A984E409DD5027B4C8E4A403387A4164A984E40834F73F2228F4A409EB4705985994E40834F73F2228F4A409EB4705985994E409DD5027B4C8E4A403387A4164A984E409DD5027B4C8E4A40
11806	Казановка	6	58	834	61.205857999999999	61.239446000000001	53.509543999999998	53.500199000000002	0103000020E610000001000000050000005BCF108E599A4E40F73E558506C04A405BCF108E599A4E40BFEFDFBC38C14A403A94A12AA69E4E40BFEFDFBC38C14A403A94A12AA69E4E40F73E558506C04A405BCF108E599A4E40F73E558506C04A40
13031	Заречье	6	58	834	61.076241000000003	61.093955000000001	53.464329999999997	53.453774000000003	0103000020E61000000100000005000000A3CEDC43C2894E4037E3344415BA4A40A3CEDC43C2894E409D465A2A6FBB4A40D925AAB7068C4E409D465A2A6FBB4A40D925AAB7068C4E4037E3344415BA4A40A3CEDC43C2894E4037E3344415BA4A40
12772	Дружный	6	58	834	60.912244000000001	60.928845000000003	53.557572	53.553319999999999	0103000020E6100000010000000500000072FC5069C4744E40821C9430D3C64A4072FC5069C4744E402995F0845EC74A40CD069964E4764E402995F0845EC74A40CD069964E4764E40821C9430D3C64A4072FC5069C4744E40821C9430D3C64A40
12080	Городище	6	58	834	61.123320999999997	61.144917	53.001716000000002	52.990729999999999	0103000020E610000001000000050000007BF486FBC88F4E4042959A3DD07E4A407BF486FBC88F4E40A2F0D93A38804A4035D1E7A38C924E40A2F0D93A38804A4035D1E7A38C924E4042959A3DD07E4A407BF486FBC88F4E4042959A3DD07E4A40
12364	Владимировка	6	58	834	61.395977999999999	61.412390000000002	53.050704000000003	53.044424999999997	0103000020E61000000100000005000000BEF73768AFB24E40F90FE9B7AF854A40BEF73768AFB24E4061E3FA777D864A4046990D32C9B44E4061E3FA777D864A4046990D32C9B44E40F90FE9B7AF854A40BEF73768AFB24E40F90FE9B7AF854A40
6015	Варна	6	58	834	60.948734000000002	61.004671999999999	53.402321000000001	53.361414000000003	0103000020E61000000100000005000000384D9F1D70794E4085285FD042AE4A40384D9F1D70794E403CBF28417FB34A407C9A931799804E403CBF28417FB34A407C9A931799804E4085285FD042AE4A40384D9F1D70794E4085285FD042AE4A40
11507	Бородиновка	6	58	834	60.745804	60.774864999999998	53.545209	53.536470999999999	0103000020E61000000100000005000000ED9C6681765F4E404F20EC14ABC44A40ED9C6681765F4E40103E9468C9C54A4053E8BCC62E634E40103E9468C9C54A4053E8BCC62E634E404F20EC14ABC44A40ED9C6681765F4E404F20EC14ABC44A40
12759	Большевик	6	58	834	60.907240999999999	60.929312000000003	53.447167	53.442812000000004	0103000020E61000000100000005000000904B1C7920744E4060234910AEB84A40904B1C7920744E40DB6CACC43CB94A40E3E313B2F3764E40DB6CACC43CB94A40E3E313B2F3764E4060234910AEB84A40904B1C7920744E4060234910AEB84A40
12032	Белоглинка	6	58	834	61.053783000000003	61.061354999999999	53.086593999999998	53.081260999999998	0103000020E61000000100000005000000570A815CE2864E405AB8ACC2668A4A40570A815CE2864E40D1031F83158B4A4019390B7BDA874E40D1031F83158B4A4019390B7BDA874E405AB8ACC2668A4A40570A815CE2864E405AB8ACC2668A4A40
11409	Арчаглы-Аят	6	58	834	61.776072999999997	61.807378999999997	53.081108999999998	53.068196	0103000020E6100000010000000500000080272D5C56E34E40E8DB82A5BA884A4080272D5C56E34E40A4349BC7618A4A40143DF03158E74E40A4349BC7618A4A40143DF03158E74E40E8DB82A5BA884A4080272D5C56E34E40E8DB82A5BA884A40
13013	Алтырка	6	58	834	61.135250999999997	61.156010999999999	53.390455000000003	53.379133000000003	0103000020E610000001000000050000002AE09EE74F914E40CDEA1D6E87B04A402AE09EE74F914E40A4C7EF6DFAB14A407B681F2BF8934E40A4C7EF6DFAB14A407B681F2BF8934E40CDEA1D6E87B04A402AE09EE74F914E40CDEA1D6E87B04A40
11251	Алексеевка	6	58	834	61.444721000000001	61.473942999999998	53.557566999999999	53.547387000000001	0103000020E61000000100000005000000166C239EECB84E40B6A0F7C610C64A40166C239EECB84E40172AFF5A5EC74A4085950A2AAABC4E40172AFF5A5EC74A4085950A2AAABC4E40B6A0F7C610C64A40166C239EECB84E40B6A0F7C610C64A40
11369	Александровка	6	58	834	61.684849	61.704971	53.140994999999997	53.132038999999999	0103000020E6100000010000000500000062D9CC21A9D74E40F56569A7E6904A4062D9CC21A9D74E4023F3C81F0C924A4070D05E7D3CDA4E4023F3C81F0C924A4070D05E7D3CDA4E40F56569A7E6904A4062D9CC21A9D74E40F56569A7E6904A40
11302	Алакамыс	6	58	834	61.657181000000001	61.671948999999998	53.218465000000002	53.210828999999997	0103000020E61000000100000005000000BB46CB811ED44E403106D671FC9A4A40BB46CB811ED44E400B293FA9F69B4A403ACAC16C02D64E400B293FA9F69B4A403ACAC16C02D64E403106D671FC9A4A40BB46CB811ED44E403106D671FC9A4A40
10899	Ясная Поляна	6	58	1076	60.641545999999998	60.664254999999997	52.470179000000002	52.450074000000001	0103000020E610000001000000050000009770E82D1E524E40D4635B069C394A409770E82D1E524E400C2252D32E3C4A402C9ACE4E06554E400C2252D32E3C4A402C9ACE4E06554E40D4635B069C394A409770E82D1E524E40D4635B069C394A40
11206	Сосновка	6	58	1076	60.104478999999998	60.116920999999998	52.571672999999997	52.563122999999997	0103000020E61000000100000005000000340F60915F0D4E400D501A6A14484A40340F60915F0D4E40CB80B3942C494A40999B6F44F70E4E40CB80B3942C494A40999B6F44F70E4E400D501A6A14484A40340F60915F0D4E400D501A6A14484A40
11113	Синий Шихан	6	58	1076	60.028058999999999	60.038623999999999	52.019699000000003	52.015276	0103000020E61000000100000005000000E2ADF36F97034E40F4346090F4014A40E2ADF36F97034E40C861307F85024A409C6B98A1F1044E40C861307F85024A409C6B98A1F1044E40F4346090F4014A40E2ADF36F97034E40F4346090F4014A40
10633	Светлые Озера	6	58	1076	60.329183999999998	60.335472000000003	52.611713000000002	52.606364999999997	0103000020E61000000100000005000000E82E89B3222A4E4032384A5E9D4D4A40E82E89B3222A4E40DFC4909C4C4E4A40A35C1ABFF02A4E40DFC4909C4C4E4A40A35C1ABFF02A4E4032384A5E9D4D4A40E82E89B3222A4E4032384A5E9D4D4A40
11178	Рымникский	6	58	1076	60.130386000000001	60.16384	52.509895999999998	52.495956	0103000020E610000001000000050000009AED0A7DB0104E40A320787C7B3F4A409AED0A7DB0104E403C2EAA4544414A4069E388B5F8144E403C2EAA4544414A4069E388B5F8144E40A320787C7B3F4A409AED0A7DB0104E40A320787C7B3F4A40
11020	Павловский	6	58	1076	60.015878000000001	60.038992	52.093311	52.081888999999997	0103000020E61000000100000005000000EA5C514A08024E407973B8567B0A4A40EA5C514A08024E40B4AD669DF10B4A401F679AB0FD044E40B4AD669DF10B4A401F679AB0FD044E407973B8567B0A4A40EA5C514A08024E407973B8567B0A4A40
10316	Октябрьский	6	58	1076	60.480972000000001	60.49062	52.387492999999999	52.383321000000002	0103000020E610000001000000050000005725917D903D4E405D6F9BA910314A405725917D903D4E40E736E15E99314A40BB61DBA2CC3E4E40E736E15E99314A40BB61DBA2CC3E4E405D6F9BA910314A405725917D903D4E405D6F9BA910314A40
10361	Новый	6	58	1076	60.397078	60.403061000000001	52.327393000000001	52.321064	0103000020E6100000010000000500000005FBAF73D3324E4023F609A018294A4005FBAF73D3324E403CF88903E8294A4083A5BA8097334E403CF88903E8294A4083A5BA8097334E4023F609A018294A4005FBAF73D3324E4023F609A018294A40
10559	Новогеоргиевский	6	58	1076	60.456960000000002	60.477370000000001	52.682704000000001	52.667715999999999	0103000020E6100000010000000500000043CA4FAA7D3A4E400A82C7B777554A4043CA4FAA7D3A4E40986C3CD862574A40B70BCD751A3D4E40986C3CD862574A40B70BCD751A3D4E400A82C7B777554A4043CA4FAA7D3A4E400A82C7B777554A40
10934	Наследницкий	6	58	1076	60.321466999999998	60.343367999999998	52.170186999999999	52.153078000000001	0103000020E6100000010000000500000022DFA5D425294E4059DE550F98134A4022DFA5D425294E40289A07B0C8154A40183F8D7BF32B4E40289A07B0C8154A40183F8D7BF32B4E4059DE550F98134A4022DFA5D425294E4059DE550F98134A40
10532	Могутовский	6	58	1076	60.202359000000001	60.228985999999999	52.714770999999999	52.701044000000003	0103000020E61000000100000005000000908653E6E6194E404D874ECFBB594A40908653E6E6194E408A90BA9D7D5B4A40F59ECA694F1D4E408A90BA9D7D5B4A40F59ECA694F1D4E404D874ECFBB594A40908653E6E6194E404D874ECFBB594A40
9912	Мирное	6	58	1076	60.245010999999998	60.262044000000003	52.446863	52.436866000000002	0103000020E6100000010000000500000083143C855C1F4E40FF5D9F39EB374A4083143C855C1F4E406F6589CE32394A40780E65A88A214E406F6589CE32394A40780E65A88A214E40FF5D9F39EB374A4083143C855C1F4E40FF5D9F39EB374A40
10220	Маяк	6	58	1076	60.402180999999999	60.430765000000001	52.395775	52.387811999999997	0103000020E610000001000000050000004A09C1AA7A334E40887FD8D2A3314A404A09C1AA7A334E4086C954C1A8324A4077A1B94E23374E4086C954C1A8324A4077A1B94E23374E40887FD8D2A3314A404A09C1AA7A334E40887FD8D2A3314A40
10049	Мариинский	6	58	1076	61.004286	61.020249	52.337755999999999	52.323374999999999	0103000020E6100000010000000500000053EA92718C804E4008AC1C5A64294A4053EA92718C804E408E03AF963B2B4A406B63EC8497824E408E03AF963B2B4A406B63EC8497824E4008AC1C5A64294A4053EA92718C804E4008AC1C5A64294A40
10816	Лебяжий	6	58	1076	60.706485000000001	60.714561000000003	52.530116	52.525447999999997	0103000020E61000000100000005000000AA0EB9196E5A4E40D2DF4BE141434A40AA0EB9196E5A4E400D8B51D7DA434A40A0FF1EBC765B4E400D8B51D7DA434A40A0FF1EBC765B4E40D2DF4BE141434A40AA0EB9196E5A4E40D2DF4BE141434A40
10990	Коряжный	6	58	1076	60.192082999999997	60.199691000000001	52.285235999999998	52.280123000000003	0103000020E610000001000000050000000C8FFD2C96184E40C0ED0912DB234A400C8FFD2C96184E4028D2FD9C82244A401C2785798F194E4028D2FD9C82244A401C2785798F194E40C0ED0912DB234A400C8FFD2C96184E40C0ED0912DB234A40
10833	Комсомольский	6	58	1076	60.621684000000002	60.651625000000003	52.388866999999998	52.377631999999998	0103000020E6100000010000000500000026396057934F4E4027F6D03E56304A4026396057934F4E402FBFD364C6314A40C520B07268534E402FBFD364C6314A40C520B07268534E4027F6D03E56304A4026396057934F4E4027F6D03E56304A40
10719	Княженский	6	58	1076	60.644474000000002	60.679068000000001	52.652613000000002	52.644412000000003	0103000020E61000000100000005000000A88FC01F7E524E403293A8177C524A40A88FC01F7E524E40E4F8A1D288534A404CE141B3EB564E40E4F8A1D288534A404CE141B3EB564E403293A8177C524A40A88FC01F7E524E403293A8177C524A40
10640	Калининский	6	58	1076	59.670853000000001	59.712426999999998	52.525973999999998	52.499195999999998	0103000020E6100000010000000500000035B6D782DED54D40A2258FA7E53F4A4035B6D782DED54D40ED45B41D53434A40C9E4D4CE30DB4D40ED45B41D53434A40C9E4D4CE30DB4D40A2258FA7E53F4A4035B6D782DED54D40A2258FA7E53F4A40
10742	Заозерный	6	58	1076	60.52516	60.541392999999999	52.561075000000002	52.554248000000001	0103000020E610000001000000050000006C95607138434E40CCEF3499F1464A406C95607138434E4036CD3B4ED1474A4044A4A65D4C454E4036CD3B4ED1474A4044A4A65D4C454E40CCEF3499F1464A406C95607138434E40CCEF3499F1464A40
10451	Гогино	6	58	1076	60.493493999999998	60.509960999999997	52.716118999999999	52.700678000000003	0103000020E61000000100000005000000D862B7CF2A3F4E406B8313D1AF594A40D862B7CF2A3F4E40A98592C9A95B4A40239EEC6646414E40A98592C9A95B4A40239EEC6646414E406B8313D1AF594A40D862B7CF2A3F4E406B8313D1AF594A40
10267	Восход	6	58	1076	60.531447999999997	60.542209999999997	52.382897999999997	52.378951000000001	0103000020E6100000010000000500000026C3F17C06444E40ACE4637781304A4026C3F17C06444E4016DA39CD02314A4036C8242367454E4016DA39CD02314A4036C8242367454E40ACE4637781304A4026C3F17C06444E40ACE4637781304A40
11082	Восточный	6	58	1076	60.157246000000001	60.167980999999997	52.099176	52.092382000000001	0103000020E61000000100000005000000A2B60DA320144E409A5E622CD30B4A40A2B60DA320144E40284696CCB10C4A40B8ACC26680154E40284696CCB10C4A40B8ACC26680154E409A5E622CD30B4A40A2B60DA320144E409A5E622CD30B4A40
9521	Бреды	6	58	1076	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
10427	Боровое	6	58	1076	60.416105000000002	60.444913999999997	52.666831000000002	52.658158	0103000020E61000000100000005000000DE59BBED42354E40E6CC76853E544A40DE59BBED42354E40C07ADCB75A554A402AC423F1F2384E40C07ADCB75A554A402AC423F1F2384E40E6CC76853E544A40DE59BBED42354E40E6CC76853E544A40
10123	Атамановский	6	58	1076	60.699730000000002	60.716977	52.235272999999999	52.224091999999999	0103000020E61000000100000005000000DA03ADC090594E40CAA5F10BAF1C4A40DA03ADC090594E40DF50F86C1D1E4A40FA7DFFE6C55B4E40DF50F86C1D1E4A40FA7DFFE6C55B4E40CAA5F10BAF1C4A40DA03ADC090594E40CAA5F10BAF1C4A40
10035	Андреевский	6	58	1076	60.778044999999999	60.803620000000002	52.377828999999998	52.365732999999999	0103000020E610000001000000050000007DE882FA96634E40B308C556D02E4A407DE882FA96634E407D3D5FB35C304A40AD342905DD664E407D3D5FB35C304A40AD342905DD664E40B308C556D02E4A407DE882FA96634E40B308C556D02E4A40
9948	Амурский	6	58	1076	59.605671999999998	59.629027999999998	52.589621000000001	52.566992999999997	0103000020E610000001000000050000002C0DFCA886CD4D40CC07043A93484A402C0DFCA886CD4D40750470B3784B4A40572250FD83D04D40750470B3784B4A40572250FD83D04D40CC07043A93484A402C0DFCA886CD4D40CC07043A93484A40
55172	Усть-Курышка	6	58	946	57.186777999999997	57.199812000000001	54.849080000000001	54.829662999999996	0103000020E610000001000000050000005FCE6C57E8974C40C2D9AD65326A4B405FCE6C57E8974C4006D847A7AE6C4B4097AC8A7093994C4006D847A7AE6C4B4097AC8A7093994C40C2D9AD65326A4B405FCE6C57E8974C40C2D9AD65326A4B40
55132	Ук	6	58	946	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
10058	Точильный	6	58	946	57.165658999999998	57.190604999999998	55.102735000000003	55.083060000000003	0103000020E61000000100000005000000DFA4695034954C408ACDC7B5A18A4B40DFA4695034954C40C993A46B268D4B401FBAA0BE65984C40C993A46B268D4B401FBAA0BE65984C408ACDC7B5A18A4B40DFA4695034954C408ACDC7B5A18A4B40
10149	Сухая Атя	6	58	946	57.392887000000002	57.411123000000003	54.860922000000002	54.851412000000003	0103000020E610000001000000050000000403081F4AB24C4003B68311FB6C4B400403081F4AB24C4016342DB1326E4B4014D1AFAD9FB44C4016342DB1326E4B4014D1AFAD9FB44C4003B68311FB6C4B400403081F4AB24C4003B68311FB6C4B40
55170	Сим	6	58	946	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
55149	Первомайский	6	58	946	57.151249999999997	57.164634	55.082616999999999	55.070143999999999	0103000020E610000001000000050000008FC2F5285C934C405C01857AFA884B408FC2F5285C934C40FC8BA031938A4B40A3E716BA12954C40FC8BA031938A4B40A3E716BA12954C405C01857AFA884B408FC2F5285C934C405C01857AFA884B40
9854	Муратовка	6	58	946	57.951514000000003	57.975292000000003	55.113993000000001	55.102792000000001	0103000020E61000000100000005000000D4D7F335CBF94C402D25CB49288D4B40D4D7F335CBF94C40897C9752978E4B407506465ED6FC4C40897C9752978E4B407506465ED6FC4C402D25CB49288D4B40D4D7F335CBF94C402D25CB49288D4B40
55155	Миньяр	6	58	946	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
9946	Малояз	6	58	946	58.107066000000003	58.134824000000002	55.208419999999997	55.200251000000002	0103000020E61000000100000005000000BC41B456B40D4D40E3FE23D3A1994B40BC41B456B40D4D4089EAAD81AD9A4B40A35BAFE941114D4089EAAD81AD9A4B40A35BAFE941114D40E3FE23D3A1994B40BC41B456B40D4D40E3FE23D3A1994B40
55133	Кропачево	6	58	946	57.968465000000002	58.008412999999997	55.026885999999998	54.997295000000001	0103000020E610000001000000050000000B293FA9F6FB4C406FBBD05CA77F4B400B293FA9F6FB4C40315C1D0071834B403DEE5BAD13014D40315C1D0071834B403DEE5BAD13014D406FBBD05CA77F4B400B293FA9F6FB4C406FBBD05CA77F4B40
9926	Илек	6	58	946	57.980924999999999	58.019103000000001	55.235621000000002	55.222313	0103000020E61000000100000005000000166A4DF38EFD4C40E23C9CC0749C4B40166A4DF38EFD4C401BA034D4289E4B40B42094F771024D401BA034D4289E4B40B42094F771024D40E23C9CC0749C4B40166A4DF38EFD4C40E23C9CC0749C4B40
9841	Ерал	6	58	946	57.907136999999999	57.939520999999999	55.033579000000003	55.015298999999999	0103000020E61000000100000005000000EBFEB1101DF44C40AC545051F5814B40EBFEB1101DF44C408C6A11514C844B40DE73603942F84C408C6A11514C844B40DE73603942F84C40AC545051F5814B40EBFEB1101DF44C40AC545051F5814B40
10033	Биянка	6	58	946	57.654558000000002	57.693508999999999	55.185358000000001	55.1721	0103000020E61000000100000005000000E7AA798EC8D34C4020D26F5F07964B40E7AA798EC8D34C40A7069ACFB9974B40A73D25E7C4D84C40A7069ACFB9974B40A73D25E7C4D84C4020D26F5F07964B40E7AA798EC8D34C4020D26F5F07964B40
22367	Яраткулова	6	58	339	60.429003999999999	60.460867999999998	55.240265999999998	55.226481999999997	0103000020E6100000010000000500000035ED629AE9364E40FB90B75CFD9C4B4035ED629AE9364E409D2B4A09C19E4B40EFE2FDB8FD3A4E409D2B4A09C19E4B40EFE2FDB8FD3A4E40FB90B75CFD9C4B4035ED629AE9364E40FB90B75CFD9C4B40
5250	Ялтырова	6	58	339	60.521602999999999	60.539147	55.249802000000003	55.244397999999997	0103000020E610000001000000050000006C3F19E3C3424E40999A046F489F4B406C3F19E3C3424E40DA3C0E83F99F4B40465ED6C402454E40DA3C0E83F99F4B40465ED6C402454E40999A046F489F4B406C3F19E3C3424E40999A046F489F4B40
12961	Чубары	6	58	339	60.811290999999997	60.824810999999997	55.249946000000001	55.239865999999999	0103000020E6100000010000000500000002452C62D8674E400FB6D8EDB39E4B4002452C62D8674E400DE2033BFE9F4B40C630276893694E400DE2033BFE9F4B40C630276893694E400FB6D8EDB39E4B4002452C62D8674E400FB6D8EDB39E4B40
47947	Чапаевка	6	58	339	60.804833000000002	60.828665000000001	55.365043999999997	55.358125000000001	0103000020E61000000100000005000000ECDE8AC404674E40A4703D0AD7AD4B40ECDE8AC404674E40EECC04C3B9AE4B40802BD9B1116A4E40EECC04C3B9AE4B40802BD9B1116A4E40A4703D0AD7AD4B40ECDE8AC404674E40A4703D0AD7AD4B40
2878	Худайбердинский	6	58	339	60.908704999999998	60.932537000000004	55.615161000000001	55.605097999999998	0103000020E61000000100000005000000185B087250744E400070ECD973CD4B40185B087250744E4028637C98BDCE4B40ADA7565F5D774E4028637C98BDCE4B40ADA7565F5D774E400070ECD973CD4B40185B087250744E400070ECD973CD4B40
5306	Халитова	6	58	339	60.393323000000002	60.412314000000002	55.316471999999997	55.309099000000003	0103000020E61000000100000005000000DFE1766858324E40F81C588E90A74B40DFE1766858324E40C30C8D2782A84B406BD784B4C6344E40C30C8D2782A84B406BD784B4C6344E40F81C588E90A74B40DFE1766858324E40F81C588E90A74B40
24265	Уразбаева	6	58	339	60.334214000000003	60.370595999999999	55.185749000000001	55.173744999999997	0103000020E61000000100000005000000C4EE3B86C72A4E40F86BB2463D964B40C4EE3B86C72A4E40E2218C9FC6974B40A30392B06F2F4E40E2218C9FC6974B40A30392B06F2F4E40F86BB2463D964B40C4EE3B86C72A4E40F86BB2463D964B40
13904	Старая Соболева	6	58	339	61.036301000000002	61.062469	55.549596999999999	55.543618000000002	0103000020E61000000100000005000000F3E7DB82A5844E402BC24D4695C54B40F3E7DB82A5844E40677DCA3159C64B40C501F4FBFE874E40677DCA3159C64B40C501F4FBFE874E402BC24D4695C54B40F3E7DB82A5844E402BC24D4695C54B40
27800	Селяева	6	58	339	60.852415999999998	60.864831000000002	55.390542000000003	55.373336999999999	0103000020E61000000100000005000000274BADF71B6D4E4081B1BE81C9AF4B40274BADF71B6D4E4073DBBE47FDB14B4093C83EC8B26E4E4073DBBE47FDB14B4093C83EC8B26E4E4081B1BE81C9AF4B40274BADF71B6D4E4081B1BE81C9AF4B40
47231	Норкино	6	58	339	60.909486000000001	60.928691999999998	55.508692000000003	55.502380000000002	0103000020E61000000100000005000000BE1589096A744E400E15E3FC4DC04B40BE1589096A744E4051DEC7D11CC14B4046072461DF764E4051DEC7D11CC14B4046072461DF764E400E15E3FC4DC04B40BE1589096A744E400E15E3FC4DC04B40
5150	Новый Миасс	6	58	339	60.511398	60.517919999999997	55.320509000000001	55.310606	0103000020E61000000100000005000000B29E5A7D75414E407FF8F9EFC1A74B40B29E5A7D75414E406E895C7006A94B40DFF8DA334B424E406E895C7006A94B40DFF8DA334B424E407FF8F9EFC1A74B40B29E5A7D75414E407FF8F9EFC1A74B40
23601	Новая Соболева	6	58	339	60.999290999999999	61.020840999999997	55.511750999999997	55.496955	0103000020E61000000100000005000000F4177AC4E87F4E40B64AB0389CBF4B40F4177AC4E87F4E40FF58880E81C14B403DB5FAEAAA824E40FF58880E81C14B403DB5FAEAAA824E40B64AB0389CBF4B40F4177AC4E87F4E40B64AB0389CBF4B40
25865	Метелёва	6	58	339	60.983822000000004	61.003458999999999	55.358938999999999	55.344878999999999	0103000020E61000000100000005000000EC8A19E1ED7D4E40E109BDFE24AC4B40EC8A19E1ED7D4E40252191B6F1AD4B403DF0315871804E40252191B6F1AD4B403DF0315871804E40E109BDFE24AC4B40EC8A19E1ED7D4E40E109BDFE24AC4B40
11778	Маякский	6	58	339	60.540179999999999	60.549055000000003	55.390045999999998	55.384681999999998	0103000020E6100000010000000500000005FA449E24454E4010AE80423DB14B4005FA449E24454E40C2F7FE06EDB14B40475A2A6F47464E40C2F7FE06EDB14B40475A2A6F47464E4010AE80423DB14B4005FA449E24454E4010AE80423DB14B40
55196	Малая Ультракова	6	58	339	60.759898999999997	60.775233	55.410539999999997	55.405029999999996	0103000020E61000000100000005000000ADA1D45E44614E400EF3E505D8B34B40ADA1D45E44614E4094D920938CB44B40D6E3BED53A634E4094D920938CB44B40D6E3BED53A634E400EF3E505D8B34B40ADA1D45E44614E400EF3E505D8B34B40
5617	Мавлютова	6	58	339	60.522554999999997	60.544079000000004	55.341577000000001	55.330413999999998	0103000020E610000001000000050000003EAE0D15E3424E40FD1186014BAA4B403EAE0D15E3424E406C088ECBB8AB4B405FB87361A4454E406C088ECBB8AB4B405FB87361A4454E40FD1186014BAA4B403EAE0D15E3424E40FD1186014BAA4B40
26875	Левашева	6	58	339	60.897817000000003	60.918801999999999	55.300618	55.297902000000001	0103000020E610000001000000050000007C65DEAAEB724E40DDB419A721A64B407C65DEAAEB724E40624B8FA67AA64B40ECBFCE4D9B754E40624B8FA67AA64B40ECBFCE4D9B754E40DDB419A721A64B407C65DEAAEB724E40DDB419A721A64B40
16217	Куянбаева	6	58	339	60.474153999999999	60.497708000000003	55.186200999999997	55.177838000000001	0103000020E6100000010000000500000040A20914B13C4E4037FE4465C3964B4040A20914B13C4E40C2BD326FD5974B40927A4FE5B43F4E40C2BD326FD5974B40927A4FE5B43F4E4037FE4465C3964B4040A20914B13C4E4037FE4465C3964B40
1622	Курманова	6	58	339	60.807087000000003	60.853529999999999	55.463737999999999	55.440987999999997	0103000020E610000001000000050000006D0377A04E674E40D7F6764B72B84B406D0377A04E674E40CBF44BC45BBB4B40D3139678406D4E40CBF44BC45BBB4B40D3139678406D4E40D7F6764B72B84B406D0377A04E674E40D7F6764B72B84B40
4107	Кулуево	6	58	339	60.588194999999999	60.616760999999997	55.234307000000001	55.210535999999998	0103000020E61000000100000005000000DA5548F9494B4E40B950F9D7F29A4B40DA5548F9494B4E40A81C93C5FD9D4B4060394206F24E4E40A81C93C5FD9D4B4060394206F24E4E40B950F9D7F29A4B40DA5548F9494B4E40B950F9D7F29A4B40
55163	Кузяшева	6	58	339	60.757905000000001	60.786552	55.355372000000003	55.342703	0103000020E61000000100000005000000C93CF20703614E40DC9E20B1DDAB4B40C93CF20703614E4002F566D47CAD4B403C4D66BCAD644E4002F566D47CAD4B403C4D66BCAD644E40DC9E20B1DDAB4B40C93CF20703614E40DC9E20B1DDAB4B40
48615	Кузнецкое	6	58	339	60.612791000000001	60.666761999999999	55.503227000000003	55.477460000000001	0103000020E610000001000000050000003E247CEF6F4E4E40F792C6681DBD4B403E247CEF6F4E4E406BBB09BE69C04B40971B0C7558554E406BBB09BE69C04B40971B0C7558554E40F792C6681DBD4B403E247CEF6F4E4E40F792C6681DBD4B40
48115	Кировский	6	58	339	60.925288000000002	60.935420999999998	55.235061000000002	55.225999999999999	0103000020E61000000100000005000000CDB051D66F764E40B0726891ED9C4B40CDB051D66F764E4054C8957A169E4B40ED7E15E0BB774E4054C8957A169E4B40ED7E15E0BB774E40B0726891ED9C4B40CDB051D66F764E40B0726891ED9C4B40
46115	Камышевка	6	58	339	60.923580999999999	60.939939000000003	55.385418000000001	55.369346999999998	0103000020E610000001000000050000007E1AF7E637764E4017F032C346AF4B407E1AF7E637764E4016A5846055B14B40139ED0EB4F784E4016A5846055B14B40139ED0EB4F784E4017F032C346AF4B407E1AF7E637764E4017F032C346AF4B40
23084	Ишалино	6	58	339	61.036777999999998	61.056693000000003	55.427770000000002	55.408225000000002	0103000020E610000001000000050000002C9B3924B5844E406E3480B740B44B402C9B3924B5844E40DF1AD82AC1B64B40C1745AB741874E40DF1AD82AC1B64B40C1745AB741874E406E3480B740B44B402C9B3924B5844E406E3480B740B44B40
16426	Илимбетова	6	58	339	61.221031000000004	61.246974000000002	55.469611999999998	55.457459999999998	0103000020E610000001000000050000007B336ABE4A9C4E40349D9D0C8EBA4B407B336ABE4A9C4E4092E7FA3E1CBC4B402D7B12D89C9F4E4092E7FA3E1CBC4B402D7B12D89C9F4E40349D9D0C8EBA4B407B336ABE4A9C4E40349D9D0C8EBA4B40
16112	Дербишева	6	58	339	61.105490000000003	61.140101999999999	55.473030999999999	55.452212000000003	0103000020E610000001000000050000000C0742B2808D4E40EC6D3315E2B94B400C0742B2808D4E40417FA1478CBC4B40560DC2DCEE914E40417FA1478CBC4B40560DC2DCEE914E40EC6D3315E2B94B400C0742B2808D4E40EC6D3315E2B94B40
1617	Губернское	6	58	339	60.568449999999999	60.634162000000003	55.497990000000001	55.459062000000003	0103000020E61000000100000005000000A2B437F8C2484E400E6B2A8BC2BA4B40A2B437F8C2484E4016DEE522BEBF4B40D82E6D382C514E4016DEE522BEBF4B40D82E6D382C514E400E6B2A8BC2BA4B40A2B437F8C2484E400E6B2A8BC2BA4B40
9245	Буланцы	6	58	339	60.820363999999998	60.836516000000003	55.333466000000001	55.324129999999997	0103000020E610000001000000050000006A6803B001694E4084D382177DA94B406A6803B001694E40FA298E03AFAA4B40564ACFF4126B4E40FA298E03AFAA4B40564ACFF4126B4E4084D382177DA94B406A6803B001694E4084D382177DA94B40
55190	Большая Усманова	6	58	339	60.790405999999997	60.810420000000001	55.298578999999997	55.293643000000003	0103000020E61000000100000005000000F54718062C654E4084D9041896A54B40F54718062C654E40DD2230D637A64B401D03B2D7BB674E40DD2230D637A64B401D03B2D7BB674E4084D9041896A54B40F54718062C654E4084D9041896A54B40
4742	Большая Куйсарина	6	58	339	60.589092999999998	60.612960999999999	55.154238999999997	55.147303999999998	0103000020E61000000100000005000000B9A64066674B4E40F54883DBDA924B40B9A64066674B4E404562821ABE934B409A5C8C81754E4E404562821ABE934B409A5C8C81754E4E40F54883DBDA924B40B9A64066674B4E40F54883DBDA924B40
5174	Большая Исянгильдина	6	58	339	60.663077999999999	60.679265999999998	55.149752999999997	55.144767999999999	0103000020E610000001000000050000003A596ABDDF544E40F0C000C287924B403A596ABDDF544E402BBD361B2B934B4072A43330F2564E402BBD361B2B934B4072A43330F2564E40F0C000C287924B403A596ABDDF544E40F0C000C287924B40
9601	Биккулова	6	58	339	60.467291000000003	60.486469999999997	55.284205	55.273420999999999	0103000020E610000001000000050000008A5B0531D03B4E4012859675FFA24B408A5B0531D03B4E400A2E56D460A44B40183E22A6443E4E400A2E56D460A44B40183E22A6443E4E4012859675FFA24B408A5B0531D03B4E4012859675FFA24B40
28153	Бижеляк	6	58	339	60.720660000000002	60.731879999999997	55.59751	55.590322	0103000020E6100000010000000500000087C43D963E5C4E40FE0DDAAB8FCB4B4087C43D963E5C4E4038842A357BCC4B40594C6C3EAE5D4E4038842A357BCC4B40594C6C3EAE5D4E40FE0DDAAB8FCB4B4087C43D963E5C4E40FE0DDAAB8FCB4B40
27488	Бигарды	6	58	339	60.919026000000002	60.929195	55.444318000000003	55.437638	0103000020E610000001000000050000003C16DBA4A2754E4051BEA08504B84B403C16DBA4A2754E4017838769DFB84B40A94D9CDCEF764E4017838769DFB84B40A94D9CDCEF764E4051BEA08504B84B403C16DBA4A2754E4051BEA08504B84B40
22442	Башакуль	6	58	339	61.183481	61.204304	55.692535999999997	55.679971000000002	0103000020E61000000100000005000000FC372F4E7C974E403D9D2B4A09D74B40FC372F4E7C974E40BDA60705A5D84B4093382BA2269A4E40BDA60705A5D84B4093382BA2269A4E403D9D2B4A09D74B40FC372F4E7C974E403D9D2B4A09D74B40
2553	Байрамгулово	6	58	339	60.491526999999998	60.523363000000003	55.383617999999998	55.369259999999997	0103000020E61000000100000005000000ED0C535BEA3E4E4048DC63E943AF4B40ED0C535BEA3E4E40161406651AB14B40DE770C8FFD424E40161406651AB14B40DE770C8FFD424E4048DC63E943AF4B40ED0C535BEA3E4E4048DC63E943AF4B40
8784	Байгазина	6	58	339	60.782384	60.799675999999998	55.160339	55.152346000000001	0103000020E61000000100000005000000F374AE2825644E4095D6DF1280934B40F374AE2825644E40FDA204FD85944B40B3B27DC85B664E40FDA204FD85944B40B3B27DC85B664E4095D6DF1280934B40F374AE2825644E4095D6DF1280934B40
14977	Бажикаева	6	58	339	60.901553999999997	60.940047	55.473745000000001	55.461987000000001	0103000020E61000000100000005000000FBC9181F66734E40AD16D86322BB4B40FBC9181F66734E405FD218ADA3BC4B40F9D9C87553784E405FD218ADA3BC4B40F9D9C87553784E40AD16D86322BB4B40FBC9181F66734E40AD16D86322BB4B40
27619	Аязгулова	6	58	339	60.815145000000001	60.828809	55.533617999999997	55.519294000000002	0103000020E61000000100000005000000BC3FDEAB56684E402881CD3978C24B40BC3FDEAB56684E40494739984DC44B40B3D0CE69166A4E40494739984DC44B40B3D0CE69166A4E402881CD3978C24B40BC3FDEAB56684E402881CD3978C24B40
7088	Аргаяш	6	58	339	60.850287000000002	60.902551000000003	55.507238999999998	55.475582000000003	0103000020E61000000100000005000000639B5434D66C4E407C48F8DEDFBC4B40639B5434D66C4E40BC202235EDC04B406EFC89CA86734E40BC202235EDC04B406EFC89CA86734E407C48F8DEDFBC4B40639B5434D66C4E407C48F8DEDFBC4B40
10624	Аргази	6	58	339	60.423552000000001	60.434834000000002	55.361967999999997	55.353611000000001	0103000020E61000000100000005000000E413B2F336364E40C040102043AD4B40E413B2F336364E406919A9F754AE4B402D98F8A3A8374E406919A9F754AE4B402D98F8A3A8374E40C040102043AD4B40E413B2F336364E40C040102043AD4B40
32510	Акбашева	6	58	339	60.826698	60.863681	55.300654000000002	55.286316999999997	0103000020E6100000010000000500000095D5743DD1694E40F8A41309A6A44B4095D5743DD1694E40AFB48CD47BA64B409A9658198D6E4E40AFB48CD47BA64B409A9658198D6E4E40F8A41309A6A44B4095D5743DD1694E40F8A41309A6A44B40
5514	Айбатова	6	58	339	60.653395000000003	60.665225	55.219411000000001	55.210997999999996	0103000020E610000001000000050000005A2F8672A2534E40BDC282FB019B4B405A2F8672A2534E40FBB0DEA8159C4B40A5BDC11726554E40FBB0DEA8159C4B40A5BDC11726554E40BDC282FB019B4B405A2F8672A2534E40BDC282FB019B4B40
19192	Абдырова	6	58	339	61.054653999999999	61.083570999999999	55.391129999999997	55.380999000000003	0103000020E610000001000000050000003C4CFBE6FE864E4084674293C4B04B403C4CFBE6FE864E40033E3F8C10B24B406FF25B74B28A4E40033E3F8C10B24B406FF25B74B28A4E4084674293C4B04B403C4CFBE6FE864E4084674293C4B04B40
9409	Янгельский	6	58	935	58.968451999999999	58.996147000000001	53.134059000000001	53.115302999999997	0103000020E6100000010000000500000076DF313CF67B4D40BA10AB3FC28E4A4076DF313CF67B4D40035E66D828914A401781B1BE817F4D40035E66D828914A401781B1BE817F4D40BA10AB3FC28E4A4076DF313CF67B4D40BA10AB3FC28E4A40
8539	Южный	6	58	935	59.450181999999998	59.461644999999997	53.123354999999997	53.117741000000002	0103000020E61000000100000005000000BA9F53909FB94D40FD321823128F4A40BA9F53909FB94D402766BD18CA8F4A4053AEF02E17BB4D402766BD18CA8F4A4053AEF02E17BB4D40FD321823128F4A40BA9F53909FB94D40FD321823128F4A40
9180	Черноотрог	6	58	935	59.134757	59.142131999999997	53.165182000000001	53.156008999999997	0103000020E610000001000000050000001BF4A5B73F914D40DA70581AF8934A401BF4A5B73F914D40A6F10BAF24954A4087DBA16131924D40A6F10BAF24954A4087DBA16131924D40DA70581AF8934A401BF4A5B73F914D40DA70581AF8934A40
9318	Черниговский	6	58	935	59.670135000000002	59.692627999999999	53.261971000000003	53.247866999999999	0103000020E61000000100000005000000D673D2FBC6D54D40FA60191BBA9F4A40D673D2FBC6D54D400EC0064488A14A409E25C808A8D84D400EC0064488A14A409E25C808A8D84D40FA60191BBA9F4A40D673D2FBC6D54D40FA60191BBA9F4A40
8617	Харьковский	6	58	935	59.095078000000001	59.116224000000003	53.224412000000001	53.217311000000002	0103000020E61000000100000005000000D84812842B8C4D40D107CBD8D09B4A40D84812842B8C4D403C6A4C88B99C4A405281936DE08E4D403C6A4C88B99C4A405281936DE08E4D40D107CBD8D09B4A40D84812842B8C4D40D107CBD8D09B4A40
9303	Утарка	6	58	935	59.355148999999997	59.363809000000003	53.144776	53.140687	0103000020E61000000100000005000000821ABE8575AD4D4076FC170802924A40821ABE8575AD4D40739F1C0588924A40C87E164B91AE4D40739F1C0588924A40C87E164B91AE4D4076FC170802924A40821ABE8575AD4D4076FC170802924A40
7880	Урожайный	6	58	935	59.276214000000003	59.291701000000003	53.462378999999999	53.453318000000003	0103000020E610000001000000050000004359F8FA5AA34D401558005306BA4A404359F8FA5AA34D40B8AD2D3C2FBB4A40F29A577556A54D40B8AD2D3C2FBB4A40F29A577556A54D401558005306BA4A404359F8FA5AA34D401558005306BA4A40
9359	Требиат	6	58	935	59.657172000000003	59.666226999999999	53.293453	53.282831999999999	0103000020E6100000010000000500000068EC4B361ED44D409221C7D633A44A4068EC4B361ED44D40E0F42EDE8FA54A40295B24ED46D54D40E0F42EDE8FA54A40295B24ED46D54D409221C7D633A44A4068EC4B361ED44D409221C7D633A44A40
9068	Ташказган	6	58	935	58.994512	59.005839000000002	53.041285000000002	53.031858	0103000020E6100000010000000500000062BD512B4C7F4D40D80E46EC13844A4062BD512B4C7F4D405E68AED348854A404B051555BF804D405E68AED348854A404B051555BF804D40D80E46EC13844A4062BD512B4C7F4D40D80E46EC13844A40
8287	Субутак	6	58	935	59.548889000000003	59.597371000000003	53.244067999999999	53.226745999999999	0103000020E610000001000000050000002C11A8FE41C64D40D93F4F03069D4A402C11A8FE41C64D400400C79E3D9F4A40174A26A776CC4D400400C79E3D9F4A40174A26A776CC4D40D93F4F03069D4A402C11A8FE41C64D40D93F4F03069D4A40
7972	Солодянка	6	58	935	59.436464999999998	59.449472	53.463386999999997	53.455275	0103000020E61000000100000005000000A06CCA15DEB74D40DCD7817346BA4A40A06CCA15DEB74D401E32E54350BB4A40DE3B6A4C88B94D401E32E54350BB4A40DE3B6A4C88B94D40DCD7817346BA4A40A06CCA15DEB74D40DCD7817346BA4A40
9048	Светлогорск	6	58	935	59.145788000000003	59.157780000000002	53.141255000000001	53.130217999999999	0103000020E610000001000000050000001B13622EA9924D40DEACC1FBAA904A401B13622EA9924D40C0B2D2A414924A4040FB912232944D40C0B2D2A414924A4040FB912232944D40DEACC1FBAA904A401B13622EA9924D40DEACC1FBAA904A40
8915	Ржавка	6	58	935	59.047072	59.062235999999999	53.606982000000002	53.597487000000001	0103000020E6100000010000000500000056478E7406864D4080643A747ACC4A4056478E7406864D405EA10F96B1CD4A4022516859F7874D405EA10F96B1CD4A4022516859F7874D4080643A747ACC4A4056478E7406864D4080643A747ACC4A40
8828	Приморский	6	58	935	59.104843000000002	59.129905999999998	53.562716999999999	53.525241999999999	0103000020E61000000100000005000000761BD47E6B8D4D40293E3E213BC34A40761BD47E6B8D4D409DF3531C07C84A40EFC682C2A0904D409DF3531C07C84A40EFC682C2A0904D40293E3E213BC34A40761BD47E6B8D4D40293E3E213BC34A40
8675	Первомайский	6	58	935	59.368659999999998	59.393597	53.323157999999999	53.311253999999998	0103000020E61000000100000005000000F3AB394030AF4D40E55FCB2BD7A74A40F3AB394030AF4D406BB8C83D5DA94A40E066F16261B24D406BB8C83D5DA94A40E066F16261B24D40E55FCB2BD7A74A40F3AB394030AF4D40E55FCB2BD7A74A40
7831	Озерный	6	58	935	59.226322000000003	59.235880000000002	53.379257000000003	53.371257999999997	0103000020E61000000100000005000000C32E8A1EF89C4D406E30D46185AF4A40C32E8A1EF89C4D40B9E34D7E8BB04A40E7E3DA50319E4D40B9E34D7E8BB04A40E7E3DA50319E4D406E30D46185AF4A40C32E8A1EF89C4D406E30D46185AF4A40
9458	Новоянгелька	6	58	935	58.913142000000001	58.936219999999999	53.203310999999999	53.194744999999998	0103000020E61000000100000005000000514D49D6E1744D409E077767ED984A40514D49D6E1744D4062F54718069A4A4039EE940ED6774D4062F54718069A4A4039EE940ED6774D409E077767ED984A40514D49D6E1744D409E077767ED984A40
8085	Новобурановка	6	58	935	59.494334000000002	59.510899000000002	53.352004000000001	53.335155999999998	0103000020E6100000010000000500000083A6255646BF4D4072874D64E6AA4A4083A6255646BF4D40D50792770EAD4A409147702365C14D40D50792770EAD4A409147702365C14D4072874D64E6AA4A4083A6255646BF4D4072874D64E6AA4A40
8029	Новобуранное	6	58	935	59.465390999999997	59.474373999999997	53.359898999999999	53.352665000000002	0103000020E61000000100000005000000266DAAEE91BB4D40D0B8702024AD4A40266DAAEE91BB4D407A6EA12B11AE4A404E098849B8BC4D407A6EA12B11AE4A404E098849B8BC4D40D0B8702024AD4A40266DAAEE91BB4D40D0B8702024AD4A40
8549	Наровчатка	6	58	935	59.082087999999999	59.101717000000001	53.295513999999997	53.281373000000002	0103000020E6100000010000000500000070B20DDC818A4D401C7DCC0704A44A4070B20DDC818A4D404CC11A67D3A54A403F390A10058D4D404CC11A67D3A54A403F390A10058D4D401C7DCC0704A44A4070B20DDC818A4D401C7DCC0704A44A40
8712	Наваринка	6	58	935	59.404933999999997	59.422963000000003	53.295023999999998	53.282153999999998	0103000020E61000000100000005000000EC8497E0D4B34D40C1374D9F1DA44A40EC8497E0D4B34D407EC4AF58C3A54A408335CEA623B64D407EC4AF58C3A54A408335CEA623B64D40C1374D9F1DA44A40EC8497E0D4B34D40C1374D9F1DA44A40
8213	Муравейник	6	58	935	59.284910000000004	59.298133	53.493524999999998	53.486077999999999	0103000020E61000000100000005000000D5264EEE77A44D400DA7CCCD37BE4A40D5264EEE77A44D401361C3D32BBF4A40DF6DDE3829A64D401361C3D32BBF4A40DF6DDE3829A64D400DA7CCCD37BE4A40D5264EEE77A44D400DA7CCCD37BE4A40
8754	Малиновка	6	58	935	59.264518000000002	59.275495999999997	53.313851999999997	53.305636	0103000020E61000000100000005000000079ACFB9DBA14D40793D98141FA74A40079ACFB9DBA14D4060E4654D2CA84A40E316F37343A34D4060E4654D2CA84A40E316F37343A34D40793D98141FA74A40079ACFB9DBA14D40793D98141FA74A40
8228	Магнитный	6	58	935	59.515408999999998	59.536842999999998	53.214092000000001	53.198628999999997	0103000020E6100000010000000500000033880FECF8C14D40C284D1AC6C994A4033880FECF8C14D40E92ADD5D679B4A40130B7C45B7C44D40E92ADD5D679B4A40130B7C45B7C44D40C284D1AC6C994A4033880FECF8C14D40C284D1AC6C994A40
7943	Красноярский	6	58	935	59.410854	59.419387999999998	53.484662999999998	53.478464000000002	0103000020E6100000010000000500000024B726DD96B44D401C28F04E3EBD4A4024B726DD96B44D40664AEB6F09BE4A40DC2A8881AEB54D40664AEB6F09BE4A40DC2A8881AEB54D401C28F04E3EBD4A4024B726DD96B44D401C28F04E3EBD4A40
8469	Кировский	6	58	935	59.581543000000003	59.593266	53.216545000000004	53.206741000000001	0103000020E61000000100000005000000DF1B430070CA4D4005DF347D769A4A40DF1B430070CA4D40618E1EBFB79B4A4014EAE923F0CB4D40618E1EBFB79B4A4014EAE923F0CB4D4005DF347D769A4A40DF1B430070CA4D4005DF347D769A4A40
9187	Зингейка	6	58	935	59.268695000000001	59.285179999999997	53.111887000000003	53.105752000000003	0103000020E61000000100000005000000A3CC069964A24D4049BE1248898D4A40A3CC069964A24D407DEC2E50528E4A4094BC3AC780A44D407DEC2E50528E4A4094BC3AC780A44D4049BE1248898D4A40A3CC069964A24D4049BE1248898D4A40
8134	Желтинский	6	58	935	59.211401000000002	59.234766	53.568112999999997	53.552325000000003	0103000020E61000000100000005000000BDAB1E300F9B4D40B1E1E995B2C64A40BDAB1E300F9B4D405AB741EDB7C84A403B1BF2CF0C9E4D405AB741EDB7C84A403B1BF2CF0C9E4D40B1E1E995B2C64A40BDAB1E300F9B4D40B1E1E995B2C64A40
7671	Гумбейский	6	58	935	59.238072000000003	59.248896999999999	53.281238000000002	53.271250000000002	0103000020E61000000100000005000000F20BAF24799E4D401F85EB51B8A24A40F20BAF24799E4D403C32569BFFA34A4048895DDBDB9F4D403C32569BFFA34A4048895DDBDB9F4D401F85EB51B8A24A40F20BAF24799E4D401F85EB51B8A24A40
8787	Гумбейка	6	58	935	59.431111000000001	59.449804999999998	53.333466999999999	53.322443	0103000020E6100000010000000500000012F92EA52EB74D407DE9EDCF45A94A4012F92EA52EB74D40CAA5F10BAFAA4A40E449D23593B94D40CAA5F10BAFAA4A40E449D23593B94D407DE9EDCF45A94A4012F92EA52EB74D407DE9EDCF45A94A40
8456	Вперед	6	58	935	59.516297999999999	59.527410000000003	53.221473000000003	53.209783000000002	0103000020E61000000100000005000000BF7E880D16C24D40DE205A2BDA9A4A40BF7E880D16C24D4038F92D3A599C4A40ACCABE2B82C34D4038F92D3A599C4A40ACCABE2B82C34D40DE205A2BDA9A4A40BF7E880D16C24D40DE205A2BDA9A4A40
9111	Воздвиженка	6	58	935	59.005543000000003	59.018667000000001	53.078783000000001	53.069862000000001	0103000020E6100000010000000500000062DC0DA2B5804D40D89DEE3CF1884A4062DC0DA2B5804D408A3DB48F158A4A40D94125AE63824D408A3DB48F158A4A40D94125AE63824D40D89DEE3CF1884A4062DC0DA2B5804D40D89DEE3CF1884A40
8909	Верхнекизильское	6	58	935	59.065955000000002	59.081522999999997	53.545524999999998	53.532617999999999	0103000020E61000000100000005000000FC00A43671884D4066A19DD32CC44A40FC00A43671884D40401361C3D3C54A40976F7D586F8A4D40401361C3D3C54A40976F7D586F8A4D4066A19DD32CC44A40FC00A43671884D4066A19DD32CC44A40
7745	Буранный	6	58	935	59.323546999999998	59.360135	53.406036	53.389800000000001	0103000020E6100000010000000500000005DCF3FC69A94D408BFD65F7E4B14A4005DCF3FC69A94D40D47FD6FCF8B34A408E9257E718AE4D40D47FD6FCF8B34A408E9257E718AE4D408BFD65F7E4B14A4005DCF3FC69A94D408BFD65F7E4B14A40
7802	Буранная	6	58	935	59.291594000000003	59.318353999999999	53.404828000000002	53.387104000000001	0103000020E61000000100000005000000DCDAC2F352A54D404D13B69F8CB14A40DCDAC2F352A54D40A7406667D1B34A408046E9D2BFA84D40A7406667D1B34A408046E9D2BFA84D404D13B69F8CB14A40DCDAC2F352A54D404D13B69F8CB14A40
9247	Базарский	6	58	935	59.336896000000003	59.348744000000003	53.095467999999997	53.07987	0103000020E610000001000000050000009D137B681FAB4D403CF71E2E398A4A409D137B681FAB4D4042E8A04B388C4A408F56B5A4A3AC4D4042E8A04B388C4A408F56B5A4A3AC4D403CF71E2E398A4A409D137B681FAB4D403CF71E2E398A4A40
8380	Алексеевский	6	58	935	59.718283999999997	59.728650999999999	53.137867999999997	53.130034000000002	0103000020E61000000100000005000000BA9EE8BAF0DB4D401DAF40F4A4904A40BA9EE8BAF0DB4D401C959BA8A5914A404E999B6F44DD4D401C959BA8A5914A404E999B6F44DD4D401DAF40F4A4904A40BA9EE8BAF0DB4D401DAF40F4A4904A40
7531	Агаповка	6	58	935	59.121721999999998	59.149408000000001	53.318564000000002	53.286341999999998	0103000020E61000000100000005000000139A2496948F4D4051BCCADAA6A44A40139A2496948F4D406BD784B4C6A84A4061E124CD1F934D406BD784B4C6A84A4061E124CD1F934D4051BCCADAA6A44A40139A2496948F4D4051BCCADAA6A44A40
7698	Аблязово	6	58	935	59.172710000000002	59.182287000000002	53.224881000000003	53.216819999999998	0103000020E6100000010000000500000099D87C5C1B964D40328FFCC1C09B4A4099D87C5C1B964D40F33E8EE6C89C4A4034BE2F2E55974D40F33E8EE6C89C4A4034BE2F2E55974D40328FFCC1C09B4A4099D87C5C1B964D40328FFCC1C09B4A40
55115	Аша	6	58	7349	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
61166	сельское поселение Унъюган	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61209	сельское поселение Сосновка	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61050	пгт.Березово	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61211	Ларьяк	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61090	городское поселение Октябрьское	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61053	городское поселение Белоярский	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61140	Ямки	6	59	\N	71.003532000000007	71.032655000000005	61.290883000000001	61.265014999999998	0103000020E61000000100000005000000541F48DE39C0514087F9F202ECA14E40541F48DE39C051402FFB75A73BA54E404243FF0417C251402FFB75A73BA54E404243FF0417C2514087F9F202ECA14E40541F48DE39C0514087F9F202ECA14E40
61190	Ягурьях	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61270	Ягодный	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61126	Юмас	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
60780	Югорск	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61262	Шугур	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61240	Чемаши	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61294	Чантырья	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55060	Ханты-Мансийск	6	59	\N	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
3251	Ханты-Мансийск	6	59	\N	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
61078	Урманный	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
40347	Урай	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55066	Талинка	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
7010	Сургут	6	59	\N	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
61172	Сорум	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55074	Советский	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61183	Сибирский	6	59	\N	69.775193000000002	69.796662999999995	60.581403000000002	60.563043	0103000020E61000000100000005000000A4C519C39C715140F19E03CB11484E40A4C519C39C715140ED65DB696B4A4E40BABBCE86FC725140ED65DB696B4A4E40BABBCE86FC725140F19E03CB11484E40A4C519C39C715140F19E03CB11484E40
61062	Сергино	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61223	Светлый	6	59	\N	68.381501999999998	68.460958000000005	60.653066000000003	60.624226999999998	0103000020E61000000100000005000000F3565D876A185140DD239BABE64F4E40F3565D876A1851409510ACAA97534E4018B5FB55801D51409510ACAA97534E4018B5FB55801D5140DD239BABE64F4E40F3565D876A185140DD239BABE64F4E40
61137	Саранпауль	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61154	Радужный	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55056	Пыть-Ях	6	59	\N	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
61059	Приобье	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61160	Покачи	6	59	\N	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
62113	Перегребное	6	59	\N	\N	\N	\N	\N	\N
61248	Пальяново	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61077	Октябрьское	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55069	Нягань	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55065	Нягань	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
1172	Нижневартовск	6	59	\N	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
8178	Нефтеюганск	6	59	\N	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
61128	Мулымья	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55058	Междуреченский	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
80	Мегион	6	59	\N	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
61089	Луговой	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61111	Леуши	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61123	Лангепас	6	59	\N	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
61099	Куминский	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61167	Красноленинский	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61162	Корлики	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55072	Кондинское	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61139	Когалым	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61115	Кедровый	6	59	\N	68.234547000000006	68.254822000000004	61.487358	61.470793999999998	0103000020E61000000100000005000000FF976BD1020F5140969350FA42BC4E40FF976BD1020F5140D4B837BF61BE4E404913EF004F105140D4B837BF61BE4E404913EF004F105140969350FA42BC4E40FF976BD1020F5140969350FA42BC4E40
61205	Заречный	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55068	Березово	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55064	Белоярский	6	59	\N	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55062	Сургут	6	59	7345	73.356525000000005	73.489627999999996	61.302334000000002	61.239614000000003	0103000020E6100000010000000500000036CD3B4ED1565240F6D4EAABAB9E4E4036CD3B4ED1565240043C69E1B2A64E402DCDAD10565F5240043C69E1B2A64E402DCDAD10565F5240F6D4EAABAB9E4E4036CD3B4ED1565240F6D4EAABAB9E4E40
55059	Нефтеюганск	6	59	7344	72.562072999999998	72.642418000000006	61.131489000000002	61.096054000000002	0103000020E61000000100000005000000BC3D0801F923524033535A7F4B8C4E40BC3D0801F92352405264ADA1D4904E40271763601D2952405264ADA1D4904E40271763601D29524033535A7F4B8C4E40BC3D0801F923524033535A7F4B8C4E40
10910	Ярки	6	59	1032	69.491065000000006	69.520349999999993	60.968603999999999	60.962884000000003	0103000020E6100000010000000500000075CDE49B6D5F5140BCEB6CC83F7B4E4075CDE49B6D5F51402C634337FB7B4E404F1E166A4D6151402C634337FB7B4E404F1E166A4D615140BCEB6CC83F7B4E4075CDE49B6D5F5140BCEB6CC83F7B4E40
61068	Шапша	6	59	1032	69.451468000000006	69.471832000000006	61.094465999999997	61.085814999999997	0103000020E6100000010000000500000032CC09DAE45C5140CC4065FCFB8A4E4032CC09DAE45C5140BE4A3E76178C4E40344DD87E325E5140BE4A3E76178C4E40344DD87E325E5140CC4065FCFB8A4E4032CC09DAE45C5140CC4065FCFB8A4E40
52116	Цингалы	6	59	1032	69.681974999999994	69.717314999999999	60.185749999999999	60.162962	0103000020E61000000100000005000000226C787AA56B5140D13E56F0DB144E40226C787AA56B5140B29DEFA7C6174E40897B2C7DE86D5140B29DEFA7C6174E40897B2C7DE86D5140D13E56F0DB144E40226C787AA56B5140D13E56F0DB144E40
10732	Тюли	6	59	1032	69.631472000000002	69.661232999999996	60.746240999999998	60.737296000000001	0103000020E61000000100000005000000BE1589096A6851405EBC1FB75F5E4E40BE1589096A68514098F738D3845F4E404D8237A4516A514098F738D3845F4E404D8237A4516A51405EBC1FB75F5E4E40BE1589096A6851405EBC1FB75F5E4E40
11957	Троица	6	59	1032	68.408576999999994	68.435526999999993	61.122948000000001	61.110840000000003	0103000020E6100000010000000500000075392520261A5140598B4F01308E4E4075392520261A5140E78D93C2BC8F4E409961A3ACDF1B5140E78D93C2BC8F4E409961A3ACDF1B5140598B4F01308E4E4075392520261A5140598B4F01308E4E40
52178	Согом	6	59	1032	68.066265000000001	68.076120000000003	60.510789000000003	60.507511000000001	0103000020E61000000100000005000000A5F78DAF3D0451401DAED51EF6404E40A5F78DAF3D0451400A14B18861414E4094A46B26DF0451400A14B18861414E4094A46B26DF0451401DAED51EF6404E40A5F78DAF3D0451401DAED51EF6404E40
61225	Селиярово	6	59	1032	70.336551	70.378888000000003	61.298561999999997	61.292788999999999	0103000020E61000000100000005000000E99B340D8A95514074D0251C7AA54E40E99B340D8A95514007EA944737A64E40333674B33F98514007EA944737A64E40333674B33F98514074D0251C7AA54E40E99B340D8A95514074D0251C7AA54E40
10543	Реполово	6	59	1032	69.817136000000005	69.844156999999996	60.658304000000001	60.650336000000003	0103000020E610000001000000050000009818CBF44B745140ABB4C5353E534E409818CBF44B745140BA69334E43544E4020EC14AB06765140BA69334E43544E4020EC14AB06765140ABB4C5353E534E409818CBF44B745140ABB4C5353E534E40
11095	Пырьях	6	59	1032	69.212434999999999	69.227913000000001	61.404837999999998	61.396968999999999	0103000020E61000000100000005000000A661F888984D51404E4354E1CFB24E40A661F888984D5140CA1649BBD1B34E4054556820964E5140CA1649BBD1B34E4054556820964E51404E4354E1CFB24E40A661F888984D51404E4354E1CFB24E40
52159	Нялинское	6	59	1032	69.541470000000004	69.568697999999998	61.297158000000003	61.281910000000003	0103000020E61000000100000005000000F870C971A76251402B357BA015A44E40F870C971A762514055DFF94509A64E403DD34B8C6564514055DFF94509A64E403DD34B8C656451402B357BA015A44E40F870C971A76251402B357BA015A44E40
52184	Луговской	6	59	1032	68.490126000000004	68.517326999999995	61.069763000000002	61.04974	0103000020E61000000100000005000000D63A71395E1F5140CAA65CE15D864E40D63A71395E1F514045BC75FEED884E409E95B4E21B21514045BC75FEED884E409E95B4E21B215140CAA65CE15D864E40D63A71395E1F5140CAA65CE15D864E40
52152	Кышик	6	59	1032	68.926599999999993	68.947413999999995	61.451785999999998	61.445121	0103000020E610000001000000050000004F1E166A4D3B5140A4E194B9F9B84E404F1E166A4D3B51403465A71FD4B94E407171546EA23C51403465A71FD4B94E407171546EA23C5140A4E194B9F9B84E404F1E166A4D3B5140A4E194B9F9B84E40
11367	Кирпичный	6	59	1032	68.642444999999995	68.690577000000005	61.084975	61.075907999999998	0103000020E61000000100000005000000A31EA2D11D2951409CC0745AB7894E40A31EA2D11D29514022FDF675E08A4E40AB97DF69322C514022FDF675E08A4E40AB97DF69322C51409CC0745AB7894E40A31EA2D11D2951409CC0745AB7894E40
52206	Кедровый	6	59	1032	68.234547000000006	68.254822000000004	61.487358	61.470793999999998	0103000020E61000000100000005000000FF976BD1020F5140969350FA42BC4E40FF976BD1020F5140D4B837BF61BE4E404913EF004F105140D4B837BF61BE4E404913EF004F105140969350FA42BC4E40FF976BD1020F5140969350FA42BC4E40
11273	Зенково	6	59	1032	69.874780999999999	69.894453999999996	61.207680000000003	61.198622	0103000020E61000000100000005000000618A7269FC775140102219726C994E40618A7269FC77514043041C42959A4E40B071FDBB3E79514043041C42959A4E40B071FDBB3E795140102219726C994E40618A7269FC775140102219726C994E40
12191	Елизарово	6	59	1032	68.288859000000002	68.303141999999994	61.400534999999998	61.387031	0103000020E61000000100000005000000F08975AA7C125140E3C4573B8AB14E40F08975AA7C125140A1F31ABB44B34E40D102B4AD66135140A1F31ABB44B34E40D102B4AD66135140E3C4573B8AB14E40F08975AA7C125140E3C4573B8AB14E40
52113	Горноправдинск	6	59	1032	69.905475999999993	69.947275000000005	60.066087000000003	60.051895000000002	0103000020E6100000010000000500000006D49B51F3795140B8E9CF7EA4064E4006D49B51F37951406BD8EF8975084E4061545227A07C51406BD8EF8975084E4061545227A07C5140B8E9CF7EA4064E4006D49B51F3795140B8E9CF7EA4064E40
52084	Выкатной	6	59	1032	69.540499999999994	69.562212000000002	60.652365000000003	60.635824	0103000020E610000001000000050000003BDF4F8D9762514086014BAE62514E403BDF4F8D976251400C0742B280534E40CD5A0A48FB6351400C0742B280534E40CD5A0A48FB63514086014BAE62514E403BDF4F8D9762514086014BAE62514E40
9980	Бобровский	6	59	1032	69.912654000000003	69.931599000000006	59.973981999999999	59.963876999999997	0103000020E6100000010000000500000012A452EC687A5140EC2E505260FB4D4012A452EC687A514043723271ABFC4D40207F69519F7B514043723271ABFC4D40207F69519F7B5140EC2E505260FB4D4012A452EC687A5140EC2E505260FB4D40
61206	Белый Яр	6	59	1032	70.869234000000006	70.876878000000005	61.067213000000002	61.064183	0103000020E6100000010000000500000090A4A487A1B75140C6FA062637884E4090A4A487A1B75140DB6E826F9A884E403E25E7C41EB85140DB6E826F9A884E403E25E7C41EB85140C6FA062637884E4090A4A487A1B75140C6FA062637884E40
61210	Белый Яр	6	59	1032	70.869234000000006	70.876878000000005	61.067213000000002	61.064183	0103000020E6100000010000000500000090A4A487A1B75140C6FA062637884E4090A4A487A1B75140DB6E826F9A884E403E25E7C41EB85140DB6E826F9A884E403E25E7C41EB85140C6FA062637884E4090A4A487A1B75140C6FA062637884E40
61161	Белый Яр	6	59	1032	70.869234000000006	70.876878000000005	61.067213000000002	61.064183	0103000020E6100000010000000500000090A4A487A1B75140C6FA062637884E4090A4A487A1B75140DB6E826F9A884E403E25E7C41EB85140DB6E826F9A884E403E25E7C41EB85140C6FA062637884E4090A4A487A1B75140C6FA062637884E40
11650	Белогорье	6	59	1032	68.617624000000006	68.630370999999997	61.059916000000001	61.049273999999997	0103000020E61000000100000005000000624ED026872751408445459C4E864E40624ED02687275140EA40D653AB874E4032569BFF57285140EA40D653AB874E4032569BFF572851408445459C4E864E40624ED026872751408445459C4E864E40
10305	Батово	6	59	1032	69.816444000000004	69.849906000000004	60.409830999999997	60.402324999999998	0103000020E61000000100000005000000FDC0559E407451407DAEB6627F334E40FDC0559E4074514088F19A5775344E4026AB22DC6476514088F19A5775344E4026AB22DC647651407DAEB6627F334E40FDC0559E407451407DAEB6627F334E40
10817	Базьяны	6	59	1032	69.581587999999996	69.596680000000006	60.840713999999998	60.825682	0103000020E61000000100000005000000BFEFDFBC38655140AC72A1F2AF694E40BFEFDFBC3865514009A52F849C6B4E40598B4F013066514009A52F849C6B4E40598B4F0130665140AC72A1F2AF694E40BFEFDFBC38655140AC72A1F2AF694E40
61169	сельское поселение Нижнесортымский	6	59	676	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
61134	Фёдоровский	6	59	676	73.677727000000004	73.750130999999996	61.622988999999997	61.597293000000001	0103000020E61000000100000005000000702711E15F6B52409B90D61874CC4E40702711E15F6B52404562821ABECF4E40CF2D7425027052404562821ABECF4E40CF2D7425027052409B90D61874CC4E40702711E15F6B52409B90D61874CC4E40
52646	Ульт-Ягун	6	59	676	74.196736999999999	74.230109999999996	61.512081999999999	61.496581999999997	0103000020E61000000100000005000000713AC956978C524021E4BCFF8FBF4E40713AC956978C5240656F29E78BC14E40E21E4B1FBA8E5240656F29E78BC14E40E21E4B1FBA8E524021E4BCFF8FBF4E40713AC956978C524021E4BCFF8FBF4E40
52634	Угут	6	59	676	74.035013000000006	74.070183	60.516117000000001	60.495350000000002	0103000020E61000000100000005000000D57B2AA73D8252406C09F9A0673F4E40D57B2AA73D8252406FF4311F10424E400D6FD6E07D8452406FF4311F10424E400D6FD6E07D8452406C09F9A0673F4E40D57B2AA73D8252406C09F9A0673F4E40
26648	Тром-Аган	6	59	676	74.306700000000006	74.314515	61.681837999999999	61.676665	0103000020E61000000100000005000000BA6B09F9A093524086AC6EF59CD64E40BA6B09F9A0935240C495B37746D74E407EC6850321945240C495B37746D74E407EC685032194524086AC6EF59CD64E40BA6B09F9A093524086AC6EF59CD64E40
52607	Сытомино	6	59	676	71.274832000000004	71.316288999999998	61.310428999999999	61.290886999999998	0103000020E610000001000000050000003CF9F4D896D1514070EA03C93BA54E403CF9F4D896D15140705D3123BCA74E4069C537143ED45140705D3123BCA74E4069C537143ED4514070EA03C93BA54E403CF9F4D896D1514070EA03C93BA54E40
52591	Солнечный	6	59	676	73.168795000000003	73.198870999999997	61.287179000000002	61.270493999999999	0103000020E610000001000000050000009D2E8B89CD4A5240D2E1218C9FA24E409D2E8B89CD4A52408B8C0E48C2A44E40DC476E4DBA4C52408B8C0E48C2A44E40DC476E4DBA4C5240D2E1218C9FA24E409D2E8B89CD4A5240D2E1218C9FA24E40
52601	Сайгатина	6	59	676	72.870878000000005	72.912982	61.276707999999999	61.257703999999997	0103000020E6100000010000000500000094331477BC3752403106D671FCA04E4094331477BC3752405245F12A6BA34E408CF50D4C6E3A52405245F12A6BA34E408CF50D4C6E3A52403106D671FCA04E4094331477BC3752403106D671FCA04E40
61149	Русскинская	6	59	676	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
61093	Нижнесортымский	6	59	676	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
61216	Нижнесортымский	6	59	676	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
56689	Лянтор	6	59	676	72.134304	72.186342999999994	61.632159000000001	61.607968	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
52625	Локосово	6	59	676	74.773312000000004	74.861525999999998	61.148791000000003	61.126010999999998	0103000020E61000000100000005000000AE669DF17DB15240D7F7E12021904E40AE669DF17DB1524036785F950B934E40D6A9F23D23B7524036785F950B934E40D6A9F23D23B75240D7F7E12021904E40AE669DF17DB15240D7F7E12021904E40
5258	Лемпино	6	59	676	71.235656000000006	71.761899	61.276972000000001	60.966490999999998	0103000020E61000000100000005000000CC46E7FC14CF51406D7022FAB57B4E40CC46E7FC14CF514030F488D173A34E40BAF605F4C2F0514030F488D173A34E40BAF605F4C2F051406D7022FAB57B4E40CC46E7FC14CF51406D7022FAB57B4E40
61131	Высокий Мыс	6	59	676	72.129085000000003	72.143934000000002	61.228577000000001	61.218130000000002	0103000020E61000000100000005000000DE59BBED42085240642310AFEB9B4E40DE59BBED4208524014CFD902429D4E4014B2F3363609524014CFD902429D4E4014B2F33636095240642310AFEB9B4E40DE59BBED42085240642310AFEB9B4E40
40335	Белый Яр	6	59	676	73.224095000000005	73.288477999999998	61.272821	61.255181	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
55063	Белый Яр	6	59	676	73.224095000000005	73.288477999999998	61.272821	61.255181	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
61194	Барсово	6	59	676	73.177598000000003	73.19896	61.25712	61.248842000000003	0103000020E61000000100000005000000717500C45D4B524085EFFD0DDA9F4E40717500C45D4B5240E292E34EE9A04E40944DB9C2BB4C5240E292E34EE9A04E40944DB9C2BB4C524085EFFD0DDA9F4E40717500C45D4B524085EFFD0DDA9F4E40
61076	сельское поселение Алябьевский	6	59	7342	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
62101	городское поселение Таежный	6	59	7342	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61070	городское поселение Советский	6	59	7342	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
62100	городское поселение Малиновский	6	59	7342	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
62117	городское поселение Коммунистический	6	59	7342	\N	\N	\N	\N	\N
61074	городское поселение Агириш	6	59	7342	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61088	Советский	6	59	7342	39.574120999999998	39.596829999999997	52.604905000000002	52.603712000000002	0103000020E61000000100000005000000317903CC7CC94340F419506F464D4A40317903CC7CC94340EC17EC866D4D4A40C6A2E9EC64CC4340EC17EC866D4D4A40C6A2E9EC64CC4340F419506F464D4A40317903CC7CC94340F419506F464D4A40
61100	Советский	6	59	7342	48.458396	48.494571000000001	56.772669999999998	56.743439000000002	0103000020E61000000100000005000000014F5AB8AC3A484015C95702295F4C40014F5AB8AC3A4840D74CBED9E6624C4067463F1A4E3F4840D74CBED9E6624C4067463F1A4E3F484015C95702295F4C40014F5AB8AC3A484015C95702295F4C40
61085	Пионерский	6	59	7342	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55025	Зеленоборск	6	59	7342	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61257	п. Кормужиханка	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61186	п. Комсомольский	6	59	5247	39.696624	39.701833999999998	47.240667000000002	47.237920000000003	0103000020E61000000100000005000000EACDA8F92AD943403C889D29749E4740EACDA8F92AD94340FC1C1F2DCE9E4740459C4EB2D5D94340FC1C1F2DCE9E4740459C4EB2D5D943403C889D29749E4740EACDA8F92AD943403C889D29749E4740
61249	п. Горнореченск	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61245	Шеркалы	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61267	Унъюган	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61065	Приобье	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61251	Перегребное	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61163	Нижние Нарыкары	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61237	Малый Алтым	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61230	Карымкары	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61252	Каменное	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61244	Большой Атлым	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61273	Большие Леуши	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61204	Андра	6	59	5247	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
52024	Покур	6	59	306	75.474007	75.497363000000007	61.010925	60.996012999999998	0103000020E61000000100000005000000CEC4742156DE524007B29E5A7D7F4E40CEC4742156DE5240BADA8AFD65814E4064CF9ECBD4DF5240BADA8AFD65814E4064CF9ECBD4DF524007B29E5A7D7F4E40CEC4742156DE524007B29E5A7D7F4E40
26519	Покачи	6	59	306	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
61117	Новоаганск	6	59	306	76.637370000000004	76.696847000000005	61.960787000000003	61.935482999999998	0103000020E61000000100000005000000E65C8AABCA285340637B2DE8BDF74E40E65C8AABCA28534003B68311FBFA4E4035D42824992C534003B68311FBFA4E4035D42824992C5340637B2DE8BDF74E40E65C8AABCA285340637B2DE8BDF74E40
61203	Мостоотряд № 95	6	59	306	76.853738000000007	76.865120000000005	60.922707000000003	60.917219000000003	0103000020E610000001000000050000008F56B5A4A33653408A22A46E67754E408F56B5A4A3365340286552431B764E4065C746205E375340286552431B764E4065C746205E3753408A22A46E67754E408F56B5A4A33653408A22A46E67754E40
29500	Лангепас	6	59	306	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
61108	Излучинск	6	59	306	76.868523999999994	76.902794999999998	60.959324000000002	60.939003999999997	0103000020E61000000100000005000000A1F2AFE5953753401668774831784E40A1F2AFE5953753404B22FB20CB7A4E4082FFAD64C73953404B22FB20CB7A4E4082FFAD64C73953401668774831784E40A1F2AFE5953753401668774831784E40
61113	Излучинск	6	59	306	76.868523999999994	76.902794999999998	60.959324000000002	60.939003999999997	0103000020E61000000100000005000000A1F2AFE5953753401668774831784E40A1F2AFE5953753404B22FB20CB7A4E4082FFAD64C73953404B22FB20CB7A4E4082FFAD64C73953401668774831784E40A1F2AFE5953753401668774831784E40
2120	Зайцева Речка	6	59	306	76.646551000000002	76.669636999999994	60.649979000000002	60.639971000000003	0103000020E610000001000000050000008D0C721761295340B8B1D991EA514E408D0C7217612953401C0B0A8332534E4042CC2555DB2A53401C0B0A8332534E4042CC2555DB2A5340B8B1D991EA514E408D0C721761295340B8B1D991EA514E40
61141	Ваховск	6	59	306	74.478898000000001	77.063674000000006	62.000548000000002	59.630099000000001	0103000020E61000000100000005000000AB07CC43A69E5240041F8315A7D04D40AB07CC43A69E5240030AF5F411004F40C1E61C3C13445340030AF5F411004F40C1E61C3C13445340041F8315A7D04D40AB07CC43A69E5240041F8315A7D04D40
52013	Вата	6	59	306	75.777951999999999	75.828940000000003	61.092244000000001	61.081516999999998	0103000020E61000000100000005000000E6762FF7C9F15240B58828266F8A4E40E6762FF7C9F1524049A0C1A6CE8B4E4029965B5A0DF5524049A0C1A6CE8B4E4029965B5A0DF55240B58828266F8A4E40E6762FF7C9F15240B58828266F8A4E40
3697	Варьёган	6	59	306	76.724649999999997	76.756530999999995	62.000776000000002	61.989353999999999	0103000020E61000000100000005000000F8C264AA602E53405915E126A3FE4E40F8C264AA602E5340944F8F6D19004F4040DAFF006B305340944F8F6D19004F4040DAFF006B3053405915E126A3FE4E40F8C264AA602E53405915E126A3FE4E40
2369	Вампугол	6	59	306	76.601427999999999	76.608750000000001	60.860886999999998	60.856031999999999	0103000020E6100000010000000500000084B9DDCB7D2653402C2AE274926D4E4084B9DDCB7D2653409946938B316E4E40295C8FC2F52653409946938B316E4E40295C8FC2F52653402C2AE274926D4E4084B9DDCB7D2653402C2AE274926D4E40
52010	Аган	6	59	306	75.069575999999998	75.089787999999999	61.643464000000002	61.634402999999999	0103000020E610000001000000050000008925E5EE73C45240FDBD141E34D14E408925E5EE73C45240A11342075DD24E40B0E42A16BFC55240A11342075DD24E40B0E42A16BFC55240FDBD141E34D14E408925E5EE73C45240FDBD141E34D14E40
61202	п. КС5	6	59	768	70.106195999999997	73.376692000000006	61.250798000000003	59.333699000000003	0103000020E61000000100000005000000D3BD4EEACB8651409DDA19A6B6AA4D40D3BD4EEACB8651407CF31B261AA04E408D2AC3B81B5852407CF31B261AA04E408D2AC3B81B5852409DDA19A6B6AA4D40D3BD4EEACB8651409DDA19A6B6AA4D40
6207	Юганская Обь	6	59	768	73.123357999999996	73.137893000000005	61.063578	61.059306999999997	0103000020E61000000100000005000000CCECF318E547524041B62C5F97874E40CCECF318E54752405F5FEB5223884E403B56293DD34852405F5FEB5223884E403B56293DD348524041B62C5F97874E40CCECF318E547524041B62C5F97874E40
6582	Чеускино	6	59	768	72.426462999999998	72.440342000000001	61.124712000000002	61.115391000000002	0103000020E610000001000000050000000F7D772B4B1B52405AA0DD21C58E4E400F7D772B4B1B52409AB51490F68F4E40894336902E1C52409AB51490F68F4E40894336902E1C52405AA0DD21C58E4E400F7D772B4B1B52405AA0DD21C58E4E40
6019	Усть-Юган	6	59	768	73.084289999999996	73.112857000000005	60.937041000000001	60.923966	0103000020E610000001000000050000004F58E20165455240D74E948444764E404F58E201654552406D01A1F5F0774E40FB07910C394752406D01A1F5F0774E40FB07910C39475240D74E948444764E404F58E20165455240D74E948444764E40
6680	Сингапай	6	59	768	72.645167000000001	72.679805999999999	61.160609999999998	61.146723999999999	0103000020E61000000100000005000000575D876A4A295240E7C41EDAC7924E40575D876A4A2952408DB454DE8E944E40F96706F1812B52408DB454DE8E944E40F96706F1812B5240E7C41EDAC7924E40575D876A4A295240E7C41EDAC7924E40
7184	Сивыс-Ях	6	59	768	71.694811999999999	71.710362000000003	60.166471000000001	60.159058000000002	0103000020E610000001000000050000009337C0CC77EC5140661536035C144E409337C0CC77EC5140C05DF6EB4E154E408E942D9276ED5140C05DF6EB4E154E408E942D9276ED5140661536035C144E409337C0CC77EC5140661536035C144E40
6353	Сентябрьский	6	59	768	72.199216000000007	72.217793999999998	60.498703999999996	60.487761999999996	0103000020E61000000100000005000000C23577F4BF0C5240A31D37FC6E3E4E40C23577F4BF0C524033315D88D53F4E40F6D03E56F00D524033315D88D53F4E40F6D03E56F00D5240A31D37FC6E3E4E40C23577F4BF0C5240A31D37FC6E3E4E40
6976	Салым	6	59	768	71.439727000000005	71.479512999999997	60.082875000000001	60.050691	0103000020E61000000100000005000000C40AB77C24DC5140CC99ED0A7D064E40C40AB77C24DC5140F853E3A59B0A4E4070404B57B0DE5140F853E3A59B0A4E4070404B57B0DE5140CC99ED0A7D064E40C40AB77C24DC5140CC99ED0A7D064E40
7528	Пыть-Ях	6	59	768	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
5402	Пойковский	6	59	768	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
55057	Пойковский	6	59	768	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
7386	Куть-Ях	6	59	768	72.026415999999998	72.045748000000003	60.336903999999997	60.314689000000001	0103000020E61000000100000005000000D505BCCCB00152409AB4A9BA47284E40D505BCCCB00152401FF296AB1F2B4E40E0F60489ED0252401FF296AB1F2B4E40E0F60489ED0252409AB4A9BA47284E40D505BCCCB00152409AB4A9BA47284E40
61224	Каркатеевский	6	59	768	72.421881999999997	72.468952999999999	60.977334999999997	60.960166999999998	0103000020E6100000010000000500000059315C1D001B524066D993C0E67A4E4059315C1D001B52403A1E3350197D4E401C977153031E52403A1E3350197D4E401C977153031E524066D993C0E67A4E4059315C1D001B524066D993C0E67A4E40
61208	КС-6	6	59	768	70.106195999999997	73.376692000000006	61.250798000000003	59.333699000000003	0103000020E61000000100000005000000D3BD4EEACB8651409DDA19A6B6AA4D40D3BD4EEACB8651407CF31B261AA04E408D2AC3B81B5852407CF31B261AA04E408D2AC3B81B5852409DDA19A6B6AA4D40D3BD4EEACB8651409DDA19A6B6AA4D40
61135	Ушья	6	59	138	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
62114	Поселок городского типа Мортка	6	59	138	\N	\N	\N	\N	\N
62112	Поселок городского типа Междуреченский	6	59	138	\N	\N	\N	\N	\N
60957	Половинка	6	59	138	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
61116	Лиственичный	6	59	138	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
322	Кама	6	59	138	69.041908000000006	69.050549000000004	60.417622999999999	60.410435	0103000020E61000000100000005000000365CE49EAE4251401F11532289344E40365CE49EAE4251405987A3AB74354E401D76DF313C4351405987A3AB74354E401D76DF313C4351401F11532289344E40365CE49EAE4251401F11532289344E40
61118	Дальний	6	59	138	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
590	Болчары	6	59	138	68.791304999999994	68.831818999999996	59.821738000000003	59.807237999999998	0103000020E61000000100000005000000520ABABDA4325140520B259353E74D40520ABABDA4325140B3F0F5B52EE94D40404CC2853C355140B3F0F5B52EE94D40404CC2853C355140520B259353E74D40520ABABDA4325140520B259353E74D40
45965	Алтай	6	59	138	68.956702000000007	68.966296	60.335363000000001	60.324727000000003	0103000020E610000001000000050000002481069B3A3D5140699082A790294E402481069B3A3D5140ECA4BE2CED2A4E405C902DCBD73D5140ECA4BE2CED2A4E405C902DCBD73D5140699082A790294E402481069B3A3D5140699082A790294E40
61119	Назарово	6	59	7529	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
61133	с.Теги	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61214	п.Хулимсунт	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61265	п.Приполярный	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61235	Сосьева	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
62116	Поселок городского типа Березово	6	59	7346	\N	\N	\N	\N	\N
61147	Няксимволь	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55071	Игрим	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61168	Ванзетур	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61220	Березово	6	59	7346	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61152	сельское поселение Казым	6	59	7524	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61241	Полноват	6	59	7524	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61236	Лыхма	6	59	7524	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
61222	Верхнеказымский	6	59	7524	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
55075	Ялуторовск	6	57	\N	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
922	Тюмень	6	57	\N	65.257116999999994	65.859707	57.310547999999997	57.054262999999999	0103000020E61000000100000005000000B88FDC9A7450504001310917F2864C40B88FDC9A745050404AEB6F09C0A74C401B498270057750404AEB6F09C0A74C401B4982700577504001310917F2864C40B88FDC9A7450504001310917F2864C40
55078	Тобольск	6	57	\N	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
9877	Патрушево	6	57	\N	65.512499000000005	65.574158999999995	57.105378000000002	57.074617000000003	0103000020E61000000100000005000000E50E9BC8CC605040E25CC30C8D894C40E50E9BC8CC605040E4DBBB067D8D4C400FED6305BF645040E4DBBB067D8D4C400FED6305BF645040E25CC30C8D894C40E50E9BC8CC605040E25CC30C8D894C40
7814	Московский	6	57	\N	65.397082999999995	65.443697	57.120949000000003	57.096553	0103000020E610000001000000050000000BB3D0CE6959504054AA44D95B8C4C400BB3D0CE69595040F1BDBF417B8F4C4055151A88655C5040F1BDBF417B8F4C4055151A88655C504054AA44D95B8C4C400BB3D0CE6959504054AA44D95B8C4C40
62094	Луговое	6	57	\N	65.321687999999995	65.381021000000004	57.229953000000002	57.203825999999999	0103000020E6100000010000000500000000E143899654504089096AF8169A4C4000E1438996545040FD4E93196F9D4C40B685E7A562585040FD4E93196F9D4C40B685E7A56258504089096AF8169A4C4000E143899654504089096AF8169A4C40
55088	Колесниково	6	57	\N	66.895419000000004	66.923688999999996	56.316353999999997	56.288266	0103000020E61000000100000005000000E44D7E8B4EB950403D4679E6E5244C40E44D7E8B4EB95040B9FAB1497E284C4032AB77B81DBB5040B9FAB1497E284C4032AB77B81DBB50403D4679E6E5244C40E44D7E8B4EB950403D4679E6E5244C40
55076	Ишим	6	57	\N	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
55086	Заводоуковск	6	57	\N	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
55083	Заводоуковск	6	57	\N	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
55081	Боровский	6	57	\N	65.679620999999997	65.758268999999999	57.070521999999997	57.026398999999998	0103000020E61000000100000005000000302B14E97E6B5040D4D2DC0A61834C40302B14E97E6B504002D369DD06894C408524B37A8770504002D369DD06894C408524B37A87705040D4D2DC0A61834C40302B14E97E6B5040D4D2DC0A61834C40
24526	Ярково	6	57	1718	67.047926000000004	67.092078000000001	57.41825	57.384315999999998	0103000020E6100000010000000500000033A8363811C350402EAA454431B14C4033A8363811C35040A8C64B3789B54C4097AB1F9BE4C55040A8C64B3789B54C4097AB1F9BE4C550402EAA454431B14C4033A8363811C350402EAA454431B14C40
24407	Щетково	6	57	1718	67.064419000000001	67.085286999999994	57.46584	57.449364000000003	0103000020E610000001000000050000006D8FDE701FC45040F8FF71C284B94C406D8FDE701FC45040969526A5A0BB4C4088F19A5775C55040969526A5A0BB4C4088F19A5775C55040F8FF71C284B94C406D8FDE701FC45040F8FF71C284B94C40
23283	Шатанова	6	57	1718	67.287470999999996	67.301242000000002	57.720790999999998	57.710681000000001	0103000020E6100000010000000500000019E3C3EC65D25040BD715298F7DA4C4019E3C3EC65D25040252026E142DC4C40A08B868C47D35040252026E142DC4C40A08B868C47D35040BD715298F7DA4C4019E3C3EC65D25040BD715298F7DA4C40
24169	Чечкино	6	57	1718	66.900566999999995	66.939741999999995	57.149600999999997	57.131926999999997	0103000020E61000000100000005000000D636C5E3A2B95040CD3AE3FBE2904C40D636C5E3A2B950407539252026934C405E2BA1BB24BC50407539252026934C405E2BA1BB24BC5040CD3AE3FBE2904C40D636C5E3A2B95040CD3AE3FBE2904C40
23445	Усть-Тавда	6	57	1718	67.148807000000005	67.165353999999994	57.780315000000002	57.771801000000004	0103000020E610000001000000050000009E9ACB0D86C9504093020B60CAE24C409E9ACB0D86C9504004CAA65CE1E34C40D190F12895CA504004CAA65CE1E34C40D190F12895CA504093020B60CAE24C409E9ACB0D86C9504093020B60CAE24C40
23614	Усалка	6	57	1718	66.953081999999995	66.975261000000003	57.325217000000002	57.311739000000003	0103000020E61000000100000005000000001AA54BFFBC5040A2F14410E7A74C40001AA54BFFBC5040378DEDB5A0A94C401D041DAD6ABE5040378DEDB5A0A94C401D041DAD6ABE5040A2F14410E7A74C40001AA54BFFBC5040A2F14410E7A74C40
24100	Староалександровка	6	57	1718	66.931297999999998	66.956451000000001	57.120244999999997	57.113545000000002	0103000020E610000001000000050000002235ED629ABB5040EACF7EA4888E4C402235ED629ABB5040F6402B30648F4C407F4E417E36BD5040F6402B30648F4C407F4E417E36BD5040EACF7EA4888E4C402235ED629ABB5040EACF7EA4888E4C40
24316	Сорокино	6	57	1718	67.465418	67.483249999999998	57.833838	57.823951999999998	0103000020E61000000100000005000000103E9468C9DD5040A5BC564277E94C40103E9468C9DD5040BE141E34BBEA4C40B0726891EDDE5040BE141E34BBEA4C40B0726891EDDE5040A5BC564277E94C40103E9468C9DD5040A5BC564277E94C40
23681	Покровское	6	57	1718	66.760392999999993	66.809414000000004	57.250565999999999	57.230426000000001	0103000020E61000000100000005000000DEC66647AAB05040F51263997E9D4C40DEC66647AAB05040A9BEF38B12A04C402CBB6070CDB35040A9BEF38B12A04C402CBB6070CDB35040F51263997E9D4C40DEC66647AAB05040F51263997E9D4C40
23344	Плеханово	6	57	1718	67.036732999999998	67.057357999999994	57.794454000000002	57.783347999999997	0103000020E61000000100000005000000C66B5ED559C2504089B14CBF44E44C40C66B5ED559C2504094162EABB0E54C407E8AE3C0ABC3504094162EABB0E54C407E8AE3C0ABC3504089B14CBF44E44C40C66B5ED559C2504089B14CBF44E44C40
24449	Петропавловка	6	57	1718	66.860007999999993	66.880920000000003	57.504176000000001	57.4998	0103000020E610000001000000050000001893FE5E0AB7504039454772F9BF4C401893FE5E0AB75040CCB6D3D688C04C401C9947FE60B85040CCB6D3D688C04C401C9947FE60B8504039454772F9BF4C401893FE5E0AB7504039454772F9BF4C40
23766	Новоселово	6	57	1718	67.191522000000006	67.203173000000007	57.538916999999998	57.534230999999998	0103000020E61000000100000005000000BB9D7DE541CC504033C170AE61C44C40BB9D7DE541CC50401421753BFBC44C40899B53C900CD50401421753BFBC44C40899B53C900CD504033C170AE61C44C40BB9D7DE541CC504033C170AE61C44C40
23870	Новоалександровка	6	57	1718	67.803247999999996	67.832649000000004	57.492066000000001	57.481738	0103000020E61000000100000005000000F4A44C6A68F35040C79E3D97A9BD4C40F4A44C6A68F350409DBCC804FCBE4C400403081F4AF550409DBCC804FCBE4C400403081F4AF55040C79E3D97A9BD4C40F4A44C6A68F35040C79E3D97A9BD4C40
24268	Мотуши	6	57	1718	66.472707999999997	66.498247000000006	57.135106999999998	57.128262999999997	0103000020E61000000100000005000000AF230ED9409E5040B72407EC6A904C40AF230ED9409E5040F73AA92F4B914C4021956247E39F5040F73AA92F4B914C4021956247E39F5040B72407EC6A904C40AF230ED9409E5040B72407EC6A904C40
24015	Маранка	6	57	1718	67.147926999999996	67.175360999999995	57.325819000000003	57.310082000000001	0103000020E6100000010000000500000081CCCEA277C95040058A58C4B0A74C4081CCCEA277C950402DB5DE6FB4A94C409BFF571D39CB50402DB5DE6FB4A94C409BFF571D39CB5040058A58C4B0A74C4081CCCEA277C95040058A58C4B0A74C40
24049	Карбаны	6	57	1718	66.987559000000005	67.002848999999998	57.239778999999999	57.225952999999997	0103000020E61000000100000005000000B6F7A92A34BF50406FB72407EC9C4C40B6F7A92A34BF504040A20914B19E4C40E27492AD2EC0504040A20914B19E4C40E27492AD2EC050406FB72407EC9C4C40B6F7A92A34BF50406FB72407EC9C4C40
23539	Караульнояр	6	57	1718	67.226483999999999	67.247352000000006	57.659820000000003	57.648378999999998	0103000020E610000001000000050000004E44BFB67ECE5040E3344415FED24C404E44BFB67ECE5040959F54FB74D44C406AA67B9DD4CF5040959F54FB74D44C406AA67B9DD4CF5040E3344415FED24C404E44BFB67ECE5040E3344415FED24C40
23727	Иевлево	6	57	1718	67.142887000000002	67.160764	57.582315999999999	57.567968	0103000020E610000001000000050000008201840F25C950405796E82CB3C84C408201840F25C9504001F8A75489CA4C40F29716F549CA504001F8A75489CA4C40F29716F549CA50405796E82CB3C84C408201840F25C950405796E82CB3C84C40
24190	Дубровное	6	57	1718	66.565154000000007	66.590783000000002	57.178651000000002	57.167324999999998	0103000020E6100000010000000500000008CDAE7B2BA45040CF66D5E76A954C4008CDAE7B2BA45040E8323509DE964C4019028063CFA55040E8323509DE964C4019028063CFA55040CF66D5E76A954C4008CDAE7B2BA45040CF66D5E76A954C40
23193	Гилево	6	57	1718	67.074813000000006	67.099687000000003	57.616225	57.607855999999998	0103000020E61000000100000005000000341477BCC9C45040B456B439CECD4C40341477BCC9C4504022FDF675E0CE4C408735954561C6504022FDF675E0CE4C408735954561C65040B456B439CECD4C40341477BCC9C45040B456B439CECD4C40
23810	Варвара	6	57	1718	67.227535000000003	67.246274	57.450032	57.439362000000003	0103000020E6100000010000000500000081ECF5EE8FCE5040768D96033DB84C4081ECF5EE8FCE5040A51309A69AB94C40BAF605F4C2CF5040A51309A69AB94C40BAF605F4C2CF5040768D96033DB84C4081ECF5EE8FCE5040768D96033DB84C40
23395	Большой Краснояр	6	57	1718	67.122900000000001	67.141378000000003	57.747179000000003	57.738239999999998	0103000020E610000001000000050000006B2BF697DDC75040AD4CF8A57EDE4C406B2BF697DDC7504006A1BC8FA3DF4C40EE974F560CC9504006A1BC8FA3DF4C40EE974F560CC95040AD4CF8A57EDE4C406B2BF697DDC75040AD4CF8A57EDE4C40
23249	Аксарина	6	57	1718	67.253990999999999	67.267330999999999	57.745103999999998	57.736379999999997	0103000020E610000001000000050000009D9E776341D05040D8B628B341DE4C409D9E776341D05040340F60915FDF4C403F8D7BF31BD15040340F60915FDF4C403F8D7BF31BD15040D8B628B341DE4C409D9E776341D05040D8B628B341DE4C40
20691	Ялуторовск	6	57	1641	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
21912	Южное	6	57	1641	65.978778000000005	65.994364000000004	56.643683000000003	56.638683999999998	0103000020E61000000100000005000000D6027B4CA47E50403E3DB665C0514C40D6027B4CA47E5040DFFE5C3464524C407714E7A8A37F5040DFFE5C3464524C407714E7A8A37F50403E3DB665C0514C40D6027B4CA47E50403E3DB665C0514C40
22090	Черемушки	6	57	1641	65.957667999999998	65.974340999999995	56.714190000000002	56.708415000000002	0103000020E610000001000000050000003F1BB96E4A7D5040787FBC57AD5A4C403F1BB96E4A7D5040AC90F2936A5B4C40B9895A9A5B7E5040AC90F2936A5B4C40B9895A9A5B7E5040787FBC57AD5A4C403F1BB96E4A7D5040787FBC57AD5A4C40
21615	Хохлово	6	57	1641	66.364057000000003	66.387699999999995	56.718561999999999	56.704827999999999	0103000020E610000001000000050000005038BBB54C9750400DA7CCCD375A4C405038BBB54C975040FD12F1D6F95B4C40302AA913D0985040FD12F1D6F95B4C40302AA913D09850400DA7CCCD375A4C405038BBB54C9750400DA7CCCD375A4C40
21506	Старый Кавдык	6	57	1641	66.220461	66.234915000000001	56.777951999999999	56.762448999999997	0103000020E61000000100000005000000C84274081C8E504017EFC7ED97614C40C84274081C8E5040CCED5EEE93634C40C095ECD8088F5040CCED5EEE93634C40C095ECD8088F504017EFC7ED97614C40C84274081C8E504017EFC7ED97614C40
21751	Прогресс	6	57	1641	66.189082999999997	66.196771999999996	56.679406	56.672443000000001	0103000020E61000000100000005000000B14E95EF198C50404AB6BA9C12564C40B14E95EF198C5040645A9BC6F6564C402F3196E9978C5040645A9BC6F6564C402F3196E9978C50404AB6BA9C12564C40B14E95EF198C50404AB6BA9C12564C40
21426	Петелино	6	57	1641	66.450644999999994	66.470012999999994	56.762064000000002	56.736370000000001	0103000020E61000000100000005000000C746205ED79C5040B5E0455F415E4C40C746205ED79C5040BFBA2A508B614C4078EC67B1149E5040BFBA2A508B614C4078EC67B1149E5040B5E0455F415E4C40C746205ED79C5040B5E0455F415E4C40
21693	Памятное	6	57	1641	66.270568999999995	66.288284000000004	56.614950999999998	56.600766999999998	0103000020E61000000100000005000000EE93A300519150400DC2DCEEE54C4C40EE93A300519150403DD2E0B6B64E4C4072FDBB3E739250403DD2E0B6B64E4C4072FDBB3E739250400DC2DCEEE54C4C40EE93A300519150400DC2DCEEE54C4C40
21564	Новый Кавдык	6	57	1641	66.317057000000005	66.330217000000005	56.805126000000001	56.798831999999997	0103000020E61000000100000005000000F27D71A94A945040C77F812040664C40F27D71A94A9450406494675E0E674C4054E57B46229550406494675E0E674C4054E57B4622955040C77F812040664C40F27D71A94A945040C77F812040664C40
21050	Новоатьялово	6	57	1641	66.652766	66.686300000000003	57.033301000000002	57.024729000000001	0103000020E61000000100000005000000357C0BEBC6A95040A321E3512A834C40357C0BEBC6A9504049F6083543844C40ABCFD556ECAB504049F6083543844C40ABCFD556ECAB5040A321E3512A834C40357C0BEBC6A95040A321E3512A834C40
21648	Криволукская	6	57	1641	66.413734000000005	66.432293000000001	56.690291999999999	56.678308000000001	0103000020E6100000010000000500000092CF2B9E7A9A5040BE4EEACBD2564C4092CF2B9E7A9A50406058FE7C5B584C408B5242B0AA9B50406058FE7C5B584C408B5242B0AA9B5040BE4EEACBD2564C4092CF2B9E7A9A5040BE4EEACBD2564C40
61256	Киева	6	57	1641	65.946815999999998	65.975059000000002	56.792237	56.779437000000001	0103000020E6100000010000000500000017D522A2987C50406C257497C4634C4017D522A2987C504030D7A20568654C40E92ADD5D677E504030D7A20568654C40E92ADD5D677E50406C257497C4634C4017D522A2987C50406C257497C4634C40
22193	Карабаш	6	57	1641	66.097337999999993	66.109672000000003	56.802731000000001	56.795495000000003	0103000020E610000001000000050000001DAA29C93A865040D690B8C7D2654C401DAA29C93A865040213EB0E3BF664C405D52B5DD04875040213EB0E3BF664C405D52B5DD04875040D690B8C7D2654C401DAA29C93A865040D690B8C7D2654C40
21852	Зиново	6	57	1641	66.118950999999996	66.143242000000001	56.645000000000003	56.635511000000001	0103000020E61000000100000005000000E5B4A7E49C875040C79FA86C58514C40E5B4A7E49C875040C3F5285C8F524C40795A7EE02A895040C3F5285C8F524C40795A7EE02A895040C79FA86C58514C40E5B4A7E49C875040C79FA86C58514C40
20931	Большое Тихвино	6	57	1641	66.722026	66.735905000000002	57.038702999999998	57.033287000000001	0103000020E6100000010000000500000026378AAC35AE5040E43098BF42844C4026378AAC35AE5040E8A04B38F4844C40A0FD481119AF5040E8A04B38F4844C40A0FD481119AF5040E43098BF42844C4026378AAC35AE5040E43098BF42844C40
22055	Беркут	6	57	1641	66.043420999999995	66.068870000000004	56.748182999999997	56.735585	0103000020E610000001000000050000006ABDDF68C7825040CE3637A6275E4C406ABDDF68C78250402A36E675C45F4C403C6BB75D688450402A36E675C45F4C403C6BB75D68845040CE3637A6275E4C406ABDDF68C7825040CE3637A6275E4C40
21462	Бердюгино	6	57	1641	66.397366000000005	66.416087000000005	56.818823999999999	56.80518	0103000020E61000000100000005000000B6A2CD716E99504057B2632310674C40B6A2CD716E99504007978E39CF684C409C525E2BA19A504007978E39CF684C409C525E2BA19A504057B2632310674C40B6A2CD716E99504057B2632310674C40
21098	Аслана	6	57	1641	66.504095000000007	66.533469999999994	56.875866000000002	56.861514999999997	0103000020E61000000100000005000000F0C4AC1743A05040B8019F1F466E4C40F0C4AC1743A05040D4D688601C704C406AD95A5F24A25040D4D688601C704C406AD95A5F24A25040B8019F1F466E4C40F0C4AC1743A05040B8019F1F466E4C40
21816	Анисимовка	6	57	1641	66.295955000000006	66.312296000000003	56.696762999999997	56.687815999999998	0103000020E610000001000000050000009D853DEDF092504030D5CC5A0A584C409D853DEDF09250400B08AD872F594C40FCAA5CA8FC9350400B08AD872F594C40FCAA5CA8FC93504030D5CC5A0A584C409D853DEDF092504030D5CC5A0A584C40
17510	Юргинское	6	57	1503	67.353658999999993	67.419972000000001	56.835352999999998	56.806077000000002	0103000020E61000000100000005000000E8BB5B59A2D650406687F8872D674C40E8BB5B59A2D65040C8CEDBD8EC6A4C40164F3DD2E0DA5040C8CEDBD8EC6A4C40164F3DD2E0DA50406687F8872D674C40E8BB5B59A2D650406687F8872D674C40
20485	Шипаково	6	57	1503	67.623225000000005	67.653722999999999	56.860166999999997	56.843383000000003	0103000020E610000001000000050000002D431CEBE2E750404E8061F9F36B4C402D431CEBE2E75040990CC7F3196E4C402769FE98D6E95040990CC7F3196E4C402769FE98D6E950404E8061F9F36B4C402D431CEBE2E750404E8061F9F36B4C40
20471	Соколова	6	57	1503	67.914648	67.927565000000001	56.844051999999998	56.834761999999998	0103000020E6100000010000000500000084D6C39789FA5040C6F8307BD96A4C4084D6C39789FA5040CB0F5CE5096C4C4083FA96395DFB5040CB0F5CE5096C4C4083FA96395DFB5040C6F8307BD96A4C4084D6C39789FA5040C6F8307BD96A4C40
19965	Синьга	6	57	1503	67.066278999999994	67.081460000000007	56.742215000000002	56.727970999999997	0103000020E61000000100000005000000575A46EA3DC45040DCB75A272E5D4C40575A46EA3DC45040E2CCAFE6005F4C40A9FB00A436C55040E2CCAFE6005F4C40A9FB00A436C55040DCB75A272E5D4C40575A46EA3DC45040DCB75A272E5D4C40
20362	Северо-Плетнево	6	57	1503	68.041471999999999	68.082920000000001	56.873981999999998	56.859265999999998	0103000020E61000000100000005000000C8EC2C7AA70251404948A46DFC6D4C40C8EC2C7AA702514076A565A4DE6F4C40CC0BB08F4E05514076A565A4DE6F4C40CC0BB08F4E0551404948A46DFC6D4C40C8EC2C7AA70251404948A46DFC6D4C40
20802	Палецкая	6	57	1503	67.418381999999994	67.439150999999995	56.811861999999998	56.802908000000002	0103000020E610000001000000050000000BCF4BC5C6DA504030D978B0C5664C400BCF4BC5C6DA5040BD6E1118EB674C405DC0CB0C1BDC5040BD6E1118EB674C405DC0CB0C1BDC504030D978B0C5664C400BCF4BC5C6DA504030D978B0C5664C40
20224	Новый Тап	6	57	1503	67.699268000000004	67.770467999999994	57.060890999999998	57.030715000000001	0103000020E61000000100000005000000EBC891CEC0EC5040923F1878EE834C40EBC891CEC0EC504074CFBA46CB874C4054A703594FF1504074CFBA46CB874C4054A703594FF15040923F1878EE834C40EBC891CEC0EC5040923F1878EE834C40
20137	Лесное	6	57	1503	67.226941999999994	67.263206999999994	56.939174999999999	56.924042999999998	0103000020E61000000100000005000000AF05BD3786CE5040828C800A47764C40AF05BD3786CE5040431CEBE236784C4002452C62D8D05040431CEBE236784C4002452C62D8D05040828C800A47764C40AF05BD3786CE5040828C800A47764C40
20043	Лабино	6	57	1503	67.776252999999997	67.800409000000002	56.883243	56.872943999999997	0103000020E61000000100000005000000001B1021AEF15040A59E05A1BC6F4C40001B1021AEF15040E1B54B1B0E714C40249BABE639F35040E1B54B1B0E714C40249BABE639F35040A59E05A1BC6F4C40001B1021AEF15040A59E05A1BC6F4C40
20823	Заозерная	6	57	1503	67.316683999999995	67.344271000000006	56.840971000000003	56.830970000000001	0103000020E61000000100000005000000A7CAF78C44D4504083FA96395D6A4C40A7CAF78C44D4504035F10EF0A46B4C40857D3B8908D6504035F10EF0A46B4C40857D3B8908D6504083FA96395D6A4C40A7CAF78C44D4504083FA96395D6A4C40
19922	Володино	6	57	1503	67.481148000000005	67.516011000000006	56.747970000000002	56.728631999999998	0103000020E610000001000000050000004B22FB20CBDE5040D76839D0435D4C404B22FB20CBDE5040CF31207BBD5F4C401558005306E15040CF31207BBD5F4C401558005306E15040D76839D0435D4C404B22FB20CBDE5040D76839D0435D4C40
19868	Бушуево	6	57	1503	67.328676999999999	67.376835	56.742013	56.721867000000003	0103000020E61000000100000005000000A27C410B09D55040E4874A23665C4C40A27C410B09D550407A1A3048FA5E4C403E3F8C101ED850407A1A3048FA5E4C403E3F8C101ED85040E4874A23665C4C40A27C410B09D55040E4874A23665C4C40
19757	Агарак	6	57	1503	67.935974000000002	67.953033000000005	56.977530000000002	56.962772000000001	0103000020E6100000010000000500000001FA7DFFE6FB504094C0E61C3C7B4C4001FA7DFFE6FB5040F06DFAB31F7D4C4090C01F7EFEFC5040F06DFAB31F7D4C4090C01F7EFEFC504094C0E61C3C7B4C4001FA7DFFE6FB504094C0E61C3C7B4C40
19597	Шашова	6	57	1508	66.293332000000007	66.304192999999998	56.375034999999997	56.366056	0103000020E61000000100000005000000B3B794F3C592504096404AECDA2E4C40B3B794F3C59250407CED992501304C4004ABEAE5779350407CED992501304C4004ABEAE57793504096404AECDA2E4C40B3B794F3C592504096404AECDA2E4C40
19546	Черная	6	57	1508	66.315753999999998	66.336783999999994	56.343977000000002	56.329042999999999	0103000020E6100000010000000500000032E543503594504026FDBD141E2A4C4032E5435035945040C1C93670072C4C403A747ADE8D955040C1C93670072C4C403A747ADE8D95504026FDBD141E2A4C4032E543503594504026FDBD141E2A4C40
19647	Чащина	6	57	1508	66.313787000000005	66.320605	56.418019000000001	56.411839000000001	0103000020E610000001000000050000003DBA111615945040D21BEE23B7344C403DBA111615945040A60D87A581354C40C87BD5CA84945040A60D87A581354C40C87BD5CA84945040D21BEE23B7344C403DBA111615945040D21BEE23B7344C40
19388	Упорово	6	57	1508	66.247975999999994	66.298956000000004	56.326771999999998	56.301479	0103000020E61000000100000005000000588CBAD6DE8F504024B726DD96264C40588CBAD6DE8F5040CF9F36AAD3294C405ABC581822935040CF9F36AAD3294C405ABC58182293504024B726DD96264C40588CBAD6DE8F504024B726DD96264C40
19332	Тютрина	6	57	1508	66.055916999999994	66.085552000000007	56.261943000000002	56.257078	0103000020E610000001000000050000009692E52494835040B34291EEE7204C409692E524948350404435255987214C40E08618AF798550404435255987214C40E08618AF79855040B34291EEE7204C409692E52494835040B34291EEE7204C40
19304	Суерка	6	57	1508	66.011189000000002	66.049592000000004	56.259408000000001	56.240433000000003	0103000020E61000000100000005000000CC441152B780504089F02F82C61E4C40CC441152B78050400F29064834214C402B89EC832C8350400F29064834214C402B89EC832C83504089F02F82C61E4C40CC441152B780504089F02F82C61E4C40
18760	Слободчики	6	57	1508	66.549252999999993	66.576975000000004	56.152343999999999	56.143929999999997	0103000020E61000000100000005000000B60E0EF626A35040E674594C6C124C40B60E0EF626A35040F4DE180280134C4004E78C28EDA45040F4DE180280134C4004E78C28EDA45040E674594C6C124C40B60E0EF626A35040E674594C6C124C40
19189	Скородум	6	57	1508	66.139010999999996	66.172274999999999	56.262922000000003	56.247340999999999	0103000020E6100000010000000500000031B2648EE5885040DFFAB0DEA81F4C4031B2648EE588504010B3976DA7214C40C7BAB88D068B504010B3976DA7214C40C7BAB88D068B5040DFFAB0DEA81F4C4031B2648EE5885040DFFAB0DEA81F4C40
19078	Пятково	6	57	1508	66.748103999999998	66.798490999999999	56.159478999999997	56.141227000000001	0103000020E610000001000000050000006F8099EFE0AF5040F627F1B913124C406F8099EFE0AF50400BB3D0CE69144C409FC9FE791AB350400BB3D0CE69144C409FC9FE791AB35040F627F1B913124C406F8099EFE0AF5040F627F1B913124C40
18309	Октябрьский	6	57	1508	66.460778000000005	66.472115000000002	56.114705999999998	56.108868999999999	0103000020E61000000100000005000000D82D02637D9D50402C465D6BEF0D4C40D82D02637D9D5040D653ABAFAE0E4C40DE3CD521379E5040D653ABAFAE0E4C40DE3CD521379E50402C465D6BEF0D4C40D82D02637D9D50402C465D6BEF0D4C40
18861	Одино	6	57	1508	66.011486000000005	66.016193000000001	56.130060999999998	56.116256999999997	0103000020E610000001000000050000002997C62FBC8050402D776682E10E4C402997C62FBC80504016BEBED6A5104C40255B5D4E0981504016BEBED6A5104C40255B5D4E098150402D776682E10E4C402997C62FBC8050402D776682E10E4C40
18726	Нифаки	6	57	1508	65.829414999999997	65.853526000000002	56.429125999999997	56.424123000000002	0103000020E61000000100000005000000F5F3A622157550409F3D97A949364C40F5F3A6221575504080EECB99ED364C404912842BA076504080EECB99ED364C404912842BA07650409F3D97A949364C40F5F3A622157550409F3D97A949364C40
19044	Нижнеманай	6	57	1508	66.764381999999998	66.779625999999993	56.051088999999997	56.046543999999997	0103000020E61000000100000005000000ABE97AA2EBB050409AE95E27F5054C40ABE97AA2EBB05040B91798158A064C401F477364E5B15040B91798158A064C401F477364E5B150409AE95E27F5054C40ABE97AA2EBB050409AE95E27F5054C40
17820	Морево	6	57	1508	66.260471999999993	66.281052000000003	56.164425999999999	56.153852999999998	0103000020E610000001000000050000008461C092AB9050401CB28174B1134C408461C092AB905040594E42E90B154C406D1E87C1FC915040594E42E90B154C406D1E87C1FC9150401CB28174B1134C408461C092AB9050401CB28174B1134C40
18016	Масали	6	57	1508	66.560563000000002	66.575466000000006	56.086368999999998	56.068483999999998	0103000020E610000001000000050000004016A243E0A350404E266E15C4084C404016A243E0A35040B131AF230E0B4C40707D586FD4A45040B131AF230E0B4C40707D586FD4A450404E266E15C4084C404016A243E0A350404E266E15C4084C40
18206	Маркова	6	57	1508	66.558120000000002	66.573606999999996	56.110630999999998	56.105761000000001	0103000020E6100000010000000500000096CFF23CB8A350409C189293890D4C4096CFF23CB8A350403E761728290E4C406D7022FAB5A450403E761728290E4C406D7022FAB5A450409C189293890D4C4096CFF23CB8A350409C189293890D4C40
61281	Лыково	6	57	1508	65.903229999999994	65.918949999999995	56.377836000000002	56.373165999999998	0103000020E6100000010000000500000007B13385CE79504054FD4AE7C32F4C4007B13385CE79504030A017EE5C304C40302AA913D07A504030A017EE5C304C40302AA913D07A504054FD4AE7C32F4C4007B13385CE79504054FD4AE7C32F4C40
18958	Липиха	6	57	1508	65.730439000000004	65.766147000000004	56.367682000000002	56.360790999999999	0103000020E61000000100000005000000452E3883BF6E504077D844662E2E4C40452E3883BF6E5040F8A92A34102F4C406D3B6D8D08715040F8A92A34102F4C406D3B6D8D0871504077D844662E2E4C40452E3883BF6E504077D844662E2E4C40
19152	Киселево	6	57	1508	66.878045999999998	66.911185000000003	56.166722	56.159519000000003	0103000020E610000001000000050000008D98D9E731B850409A0B5C1E6B144C408D98D9E731B8504009C3802557154C40C5E6E3DA50BA504009C3802557154C40C5E6E3DA50BA50409A0B5C1E6B144C408D98D9E731B850409A0B5C1E6B144C40
18139	Кизак	6	57	1508	66.583668000000003	66.592346000000006	56.056925	56.046509	0103000020E6100000010000000500000031EE06D15AA550401EFCC401F4054C4031EE06D15AA5504093A9825149074C40A77A32FFE8A5504093A9825149074C40A77A32FFE8A550401EFCC401F4054C4031EE06D15AA550401EFCC401F4054C40
18438	Кашаир	6	57	1508	66.463842	66.480433000000005	56.203707999999999	56.197217999999999	0103000020E61000000100000005000000B8205B96AF9D50405D177E703E194C40B8205B96AF9D50407FF78E1A131A4C40D4BA0D6ABF9E50407FF78E1A131A4C40D4BA0D6ABF9E50405D177E703E194C40B8205B96AF9D50405D177E703E194C40
18624	Ингалинское	6	57	1508	65.931725	65.962474	56.427498	56.420628000000001	0103000020E6100000010000000500000066F7E461A17B504015E46723D7354C4066F7E461A17B50407E8D2441B8364C4005508C2C997D50407E8D2441B8364C4005508C2C997D504015E46723D7354C4066F7E461A17B504015E46723D7354C40
18304	Емуртлинский	6	57	1508	66.488878	66.506097999999994	56.157589000000002	56.148502999999998	0103000020E61000000100000005000000F86EF3C6499F5040CF2D742502134C40F86EF3C6499F5040CC9A58E02B144C408BA4DDE863A05040CC9A58E02B144C408BA4DDE863A05040CF2D742502134C40F86EF3C6499F5040CF2D742502134C40
18229	Емуртла	6	57	1508	66.450654	66.490548000000004	56.163634000000002	56.151010999999997	0103000020E61000000100000005000000F1F3DF83D79C50400A2B155454134C40F1F3DF83D79C5040C0417BF5F1144C4091477023659F5040C0417BF5F1144C4091477023659F50400A2B155454134C40F1F3DF83D79C50400A2B155454134C40
18109	Дубровинский	6	57	1508	66.519132999999997	66.528880000000001	56.014423000000001	56.006098999999999	0103000020E610000001000000050000008F519E7939A15040E7C41EDAC7004C408F519E7939A15040B5A7E49CD8014C408BE07F2BD9A15040B5A7E49CD8014C408BE07F2BD9A15040E7C41EDAC7004C408F519E7939A15040E7C41EDAC7004C40
18033	Видонова	6	57	1508	66.600735999999998	66.609997000000007	56.042465999999997	56.025829000000002	0103000020E61000000100000005000000E961687572A65040EA245B5D4E034C40E961687572A650409198A0866F054C401F6ADB300AA750409198A0866F054C401F6ADB300AA75040EA245B5D4E034C40E961687572A65040EA245B5D4E034C40
17845	Бызово	6	57	1508	66.187213999999997	66.197716	56.315555000000003	56.293072000000002	0103000020E610000001000000050000009DD66D50FB8B5040C9AF1F6283254C409DD66D50FB8B50406E8B321B64284C4057790261A78C50406E8B321B64284C4057790261A78C5040C9AF1F6283254C409DD66D50FB8B5040C9AF1F6283254C40
17643	Буньково	6	57	1508	66.115887999999998	66.139854999999997	56.176473999999999	56.168446000000003	0103000020E61000000100000005000000ED7F80B56A8750402E9276A38F154C40ED7F80B56A875040124C35B396164C40A7CB6262F3885040124C35B396164C40A7CB6262F38850402E9276A38F154C40ED7F80B56A8750402E9276A38F154C40
16942	Уват	6	57	1464	68.860753000000003	68.925486000000006	59.156064999999998	59.131917000000001	0103000020E61000000100000005000000C53BC09316375140AA6400A8E2904D40C53BC093163751406E861BF0F9934D40FAB9A1293B3B51406E861BF0F9934D40FAB9A1293B3B5140AA6400A8E2904D40C53BC09316375140AA6400A8E2904D40
17114	Туртас	6	57	1464	69.100801000000004	69.159192000000004	58.959314999999997	58.921173000000003	0103000020E61000000100000005000000DD99098673465140A77A32FFE8754D40DD99098673465140F7C77BD5CA7A4D403B72A433304A5140F7C77BD5CA7A4D403B72A433304A5140A77A32FFE8754D40DD99098673465140A77A32FFE8754D40
17321	Солянка	6	57	1464	68.966583999999997	68.989185000000006	59.435951000000003	59.429101000000003	0103000020E610000001000000050000008F352383DC3D514028D714C8ECB64D408F352383DC3D51404AD40B3ECDB74D40672C9ACE4E3F51404AD40B3ECDB74D40672C9ACE4E3F514028D714C8ECB64D408F352383DC3D514028D714C8ECB64D40
17307	Першино	6	57	1464	68.905696000000006	68.930508000000003	59.354539000000003	59.345699000000003	0103000020E610000001000000050000008E075BECF639514045A165DD3FAC4D408E075BECF63951400A14B18861AD4D40A62A6D718D3B51400A14B18861AD4D40A62A6D718D3B514045A165DD3FAC4D408E075BECF639514045A165DD3FAC4D40
17224	Осинник	6	57	1464	68.826796999999999	68.848742999999999	59.276260000000001	59.264530000000001	0103000020E6100000010000000500000094DBF63DEA345140CB67791EDCA14D4094DBF63DEA345140B398D87C5CA34D405FED28CE51365140B398D87C5CA34D405FED28CE51365140CB67791EDCA14D4094DBF63DEA345140CB67791EDCA14D40
55090	Нагорный	6	57	1464	69.021497999999994	69.035341000000003	59.135176999999999	59.130448999999999	0103000020E610000001000000050000007BBB253960415140E065868DB2904D407BBB253960415140F015DD7A4D914D404FCDE50643425140F015DD7A4D914D404FCDE50643425140E065868DB2904D407BBB253960415140E065868DB2904D40
17610	Муген	6	57	1464	70.787459999999996	70.795598999999996	59.808169999999997	59.804060999999997	0103000020E610000001000000050000001FBAA0BE65B25140997E8978EBE64D401FBAA0BE65B25140DDCD531D72E74D40BD6E1118EBB25140DDCD531D72E74D40BD6E1118EBB25140997E8978EBE64D401FBAA0BE65B25140997E8978EBE64D40
16830	Красный Яр	6	57	1464	68.568657000000002	68.601202999999998	58.870783000000003	58.860228999999997	0103000020E610000001000000050000000E6954E0642451400F09DFFB1B6E4D400E6954E064245140D6743DD1756F4D4074D0251C7A265140D6743DD1756F4D4074D0251C7A2651400F09DFFB1B6E4D400E6954E0642451400F09DFFB1B6E4D40
17031	Ивановка	6	57	1464	68.881360999999998	68.904690000000002	59.090592000000001	59.077443000000002	0103000020E6100000010000000500000012BEF73768385140EE26F8A6E9894D4012BEF73768385140BEA3C684988B4D402BC1E270E6395140BEA3C684988B4D402BC1E270E6395140EE26F8A6E9894D4012BEF73768385140EE26F8A6E9894D40
17399	Демьянское	6	57	1464	69.279961	69.348871000000003	59.606192	59.585489000000003	0103000020E61000000100000005000000F3C98AE1EA5151407995B54DF1CA4D40F3C98AE1EA515140658C0FB397CD4D4076E107E753565140658C0FB397CD4D4076E107E7535651407995B54DF1CA4D40F3C98AE1EA5151407995B54DF1CA4D40
17521	Демьянка	6	57	1464	69.980215999999999	70.008161999999999	59.551628000000001	59.532711999999997	0103000020E6100000010000000500000005C1E3DBBB7E5140E71725E82FC44D4005C1E3DBBB7E514069C70DBF9BC64D407AC4E8B98580514069C70DBF9BC64D407AC4E8B985805140E71725E82FC44D4005C1E3DBBB7E5140E71725E82FC44D40
16729	Горнослинкино	6	57	1464	68.775315000000006	68.821388999999996	58.767204999999997	58.755971000000002	0103000020E610000001000000050000004A46CEC29E315140BADC60A8C3604D404A46CEC29E315140F12900C633624D40D3122BA391345140F12900C633624D40D3122BA391345140BADC60A8C3604D404A46CEC29E315140BADC60A8C3604D40
16910	Алымка	6	57	1464	68.788250000000005	68.818990999999997	59.029513000000001	59.020018999999998	0103000020E610000001000000050000009CC420B07232514039268BFB8F824D409CC420B07232514047E7FC14C7834D40F92D3A596A34514047E7FC14C7834D40F92D3A596A34514039268BFB8F824D409CC420B07232514039268BFB8F824D40
5639	Янтык	6	57	624	65.861430999999996	65.879748000000006	57.323670999999997	57.313406999999998	0103000020E61000000100000005000000AD307DAF2177504032AB77B81DA84C40AD307DAF21775040F1D4230D6EA94C402C2E8ECA4D785040F1D4230D6EA94C402C2E8ECA4D78504032AB77B81DA84C40AD307DAF2177504032AB77B81DA84C40
4147	Якуши	6	57	624	66.016048999999995	66.033880999999994	57.135511999999999	57.123587999999998	0103000020E610000001000000050000008B8862F206815040CA1649BBD18F4C408B8862F206815040971B0C7558914C402BBD361B2B825040971B0C7558914C402BBD361B2B825040CA1649BBD18F4C408B8862F206815040CA1649BBD18F4C40
4693	Щербак	6	57	624	66.242649	66.259007999999994	57.157983999999999	57.151408000000004	0103000020E610000001000000050000000EDAAB8F878F5040282D5C5661934C400EDAAB8F878F504048A5D8D138944C40C0594A969390504048A5D8D138944C40C0594A9693905040282D5C5661934C400EDAAB8F878F5040282D5C5661934C40
4035	Чикча	6	57	624	65.962007	65.990717000000004	57.154034000000003	57.140791999999998	0103000020E610000001000000050000007AE1CE85917D5040EBC4E57805924C407AE1CE85917D50406D3CD862B7934C40D7A546E8677F50406D3CD862B7934C40D7A546E8677F5040EBC4E57805924C407AE1CE85917D5040EBC4E57805924C40
4026	Червишево	6	57	624	65.417115999999993	65.437569999999994	56.956077999999998	56.928837999999999	0103000020E61000000100000005000000DAA84E07B25A50401AA4E029E4764C40DAA84E07B25A504069368FC3607A4C407CED9925015C504069368FC3607A4C407CED9925015C50401AA4E029E4764C40DAA84E07B25A50401AA4E029E4764C40
7197	Чаплык	6	57	624	65.072350999999998	65.082070999999999	56.976446000000003	56.968449999999997	0103000020E610000001000000050000004EB51666A1445040D5E76A2BF67B4C404EB51666A1445040AF27BA2EFC7C4C40CD3CB9A640455040AF27BA2EFC7C4C40CD3CB9A640455040D5E76A2BF67B4C404EB51666A1445040D5E76A2BF67B4C40
6900	Ушакова	6	57	624	65.148870000000002	65.175172000000003	57.086156000000003	57.078893000000001	0103000020E61000000100000005000000C1560916874950401171732A198A4C40C156091687495040562DE928078B4C4032CB9E04364B5040562DE928078B4C4032CB9E04364B50401171732A198A4C40C1560916874950401171732A198A4C40
7095	Успенка	6	57	624	65.034477999999993	65.097341999999998	57.087637999999998	57.067366	0103000020E610000001000000050000009D9B36E334425040616EF7729F884C409D9B36E33442504084F1D3B8378B4C40BEA1F0D93A46504084F1D3B8378B4C40BEA1F0D93A465040616EF7729F884C409D9B36E334425040616EF7729F884C40
5477	Тураева	6	57	624	65.797301000000004	65.826207999999994	57.153574999999996	57.148766000000002	0103000020E610000001000000050000005C04C6FA06735040DD60A8C30A934C405C04C6FA06735040D93D7958A8934C4063EC8497E0745040D93D7958A8934C4063EC8497E0745040DD60A8C30A934C405C04C6FA06735040DD60A8C30A934C40
55087	Тараскуль	6	57	624	65.399930999999995	65.464034999999996	57.014919999999996	57.003627000000002	0103000020E61000000100000005000000056A317898595040F9307BD976804C40056A317898595040350708E6E8814C40C24CDBBFB25D5040350708E6E8814C40C24CDBBFB25D5040F9307BD976804C40056A317898595040F9307BD976804C40
6060	Субботина	6	57	624	65.825327999999999	65.845495	57.119278000000001	57.112250000000003	0103000020E61000000100000005000000471E882CD2745040EE7C3F355E8E4C40471E882CD2745040EF906280448F4C409E7B0F971C765040EF906280448F4C409E7B0F971C765040EE7C3F355E8E4C40471E882CD2745040EE7C3F355E8E4C40
7061	Созоново	6	57	624	66.288086000000007	66.320785000000001	57.148674	57.136434999999999	0103000020E61000000100000005000000DF1B430070925040CF83BBB376914C40DF1B430070925040FCE1E7BF07934C400803CFBD87945040FCE1E7BF07934C400803CFBD87945040CF83BBB376914C40DF1B430070925040CF83BBB376914C40
7001	Салаирка	6	57	624	64.985448000000005	65.029430000000005	57.383510000000001	57.372762999999999	0103000020E6100000010000000500000027FA7C94113F50405514AFB2B6AF4C4027FA7C94113F504030D80DDB16B14C405DE15D2EE241504030D80DDB16B14C405DE15D2EE24150405514AFB2B6AF4C4027FA7C94113F50405514AFB2B6AF4C40
6505	Пышминка	6	57	624	65.873334	65.880241999999996	56.970607999999999	56.965290000000003	0103000020E61000000100000005000000081F4AB4E4775040F3936A9F8E7B4C40081F4AB4E4775040349E08E23C7C4C4033A48AE255785040349E08E23C7C4C4033A48AE255785040F3936A9F8E7B4C40081F4AB4E4775040F3936A9F8E7B4C40
61279	Подъем	6	57	624	65.181900999999996	65.191188999999994	57.129044999999998	57.125478000000001	0103000020E6100000010000000500000005871744A44B50400A2FC1A90F904C4005871744A44B50402D5BEB8B84904C40B796C9703C4C50402D5BEB8B84904C40B796C9703C4C50400A2FC1A90F904C4005871744A44B50400A2FC1A90F904C40
6863	Перевалово	6	57	624	65.215821000000005	65.247523000000001	57.091742000000004	57.074769000000003	0103000020E610000001000000050000009032E202D04D504098E0D40792894C409032E202D04D5040B7D5AC33BE8B4C408080B56AD74F5040B7D5AC33BE8B4C408080B56AD74F504098E0D40792894C409032E202D04D504098E0D40792894C40
6276	Падерина	6	57	624	65.433492000000001	65.458887000000004	57.090451000000002	57.076172999999997	0103000020E61000000100000005000000F8C43A55BE5B50404AEB6F09C0894C40F8C43A55BE5B5040FC71FBE5938B4C40D06394675E5D5040FC71FBE5938B4C40D06394675E5D50404AEB6F09C0894C40F8C43A55BE5B50404AEB6F09C0894C40
6813	Онохино	6	57	624	65.524150000000006	65.558097000000004	56.929628000000001	56.917662	0103000020E61000000100000005000000B30C71AC8B6150401764CBF275754C40B30C71AC8B61504013B9E00CFE764C40BABF7ADCB763504013B9E00CFE764C40BABF7ADCB76350401764CBF275754C40B30C71AC8B6150401764CBF275754C40
5790	Новотуринский	6	57	624	65.869471000000004	65.878058999999993	57.176797000000001	57.170209999999997	0103000020E610000001000000050000008274B169A5775040E0B9F770C9954C408274B169A5775040F583BA48A1964C40573D601E32785040F583BA48A1964C40573D601E32785040E0B9F770C9954C408274B169A5775040E0B9F770C9954C40
6691	Новотарманский	6	57	624	65.200855000000004	65.243678000000003	57.287125000000003	57.276383000000003	0103000020E610000001000000050000003D0FEECEDA4C5040CF15A58460A34C403D0FEECEDA4C5040986E1283C0A44C404D309C6B984F5040986E1283C0A44C404D309C6B984F5040CF15A58460A34C403D0FEECEDA4C5040CF15A58460A34C40
6386	Муллаши	6	57	624	66.070549999999997	66.089235000000002	57.005671	56.994709999999998	0103000020E61000000100000005000000E6AE25E483845040888043A8527F4C40E6AE25E4838450408FC4CBD3B9804C4026AAB706B68550408FC4CBD3B9804C4026AAB706B6855040888043A8527F4C40E6AE25E483845040888043A8527F4C40
6090	Московский	6	57	624	65.406955999999994	65.455078	57.118892000000002	57.100825999999998	0103000020E610000001000000050000004DBA2D910B5A5040124BCADDE78C4C404DBA2D910B5A5040C6E061DA378F4C4043C879FF1F5D5040C6E061DA378F4C4043C879FF1F5D5040124BCADDE78C4C404DBA2D910B5A5040124BCADDE78C4C40
6780	Молчанова	6	57	624	65.162802999999997	65.190453000000005	57.290455999999999	57.281170000000003	0103000020E61000000100000005000000342C465D6B4A5040E44EE960FDA34C40342C465D6B4A5040A77686A92DA54C40359BC761304C5040A77686A92DA54C40359BC761304C5040E44EE960FDA34C40342C465D6B4A5040E44EE960FDA34C40
7402	Мичурино	6	57	624	65.180364999999995	65.196444	56.961216999999998	56.949137	0103000020E61000000100000005000000F415A4198B4B504037363B527D794C40F415A4198B4B5040FBAD9D28097B4C40B5DFDA89924C5040FBAD9D28097B4C40B5DFDA89924C504037363B527D794C40F415A4198B4B504037363B527D794C40
6613	Марай	6	57	624	66.016920999999996	66.034653000000006	56.856411999999999	56.853656000000001	0103000020E610000001000000050000006667D13B1581504060048D99446D4C406667D13B1581504073F38DE89E6D4C40556D37C13782504073F38DE89E6D4C40556D37C13782504060048D99446D4C406667D13B1581504060048D99446D4C40
5972	Мальково	6	57	624	65.855440000000002	65.886583999999999	57.134096	57.116003999999997	0103000020E610000001000000050000002DEC6987BF765040431A1538D98E4C402DEC6987BF7650402043C70E2A914C400A4AD1CABD7850402043C70E2A914C400A4AD1CABD785040431A1538D98E4C402DEC6987BF765040431A1538D98E4C40
7272	Малиновка	6	57	624	65.063152000000002	65.073177999999999	57.109073000000002	57.102722999999997	0103000020E6100000010000000500000054ABAFAE0A44504004C6FA06268D4C4054ABAFAE0A44504035F0A31AF68D4C405932C7F2AE44504035F0A31AF68D4C405932C7F2AE44504004C6FA06268D4C4054ABAFAE0A44504004C6FA06268D4C40
5966	Луговое	6	57	624	65.331029999999998	65.373287000000005	57.225003000000001	57.207999000000001	0103000020E61000000100000005000000ACFF73982F555040E44C13B69F9A4C40ACFF73982F5550403E40F7E5CC9C4C40684128EFE35750403E40F7E5CC9C4C40684128EFE3575040E44C13B69F9A4C40ACFF73982F555040E44C13B69F9A4C40
7445	Леваши	6	57	624	65.375578000000004	65.3904	56.841816999999999	56.830112999999997	0103000020E6100000010000000500000037C64E7809585040027E8D24416A4C4037C64E7809585040C11BD2A8C06B4C40F0164850FC585040C11BD2A8C06B4C40F0164850FC585040027E8D24416A4C4037C64E7809585040027E8D24416A4C40
5565	Кулига	6	57	624	65.053827999999996	65.104788999999997	57.253833	57.238128000000003	0103000020E61000000100000005000000FBE6FEEA71435040862172FA7A9E4C40FBE6FEEA71435040A2D288997DA04C40C1FEEBDCB4465040A2D288997DA04C40C1FEEBDCB4465040862172FA7A9E4C40FBE6FEEA71435040862172FA7A9E4C40
5891	Кулаково	6	57	624	65.252302	65.287443999999994	57.237918000000001	57.216070999999999	0103000020E61000000100000005000000C9AD49B725505040984EEB36A89B4C40C9AD49B7255050409B90D618749E4C409CDB847B655250409B90D618749E4C409CDB847B65525040984EEB36A89B4C40C9AD49B725505040984EEB36A89B4C40
4195	Криводанова	6	57	624	66.193646000000001	66.209132999999994	57.131517000000002	57.116292000000001	0103000020E61000000100000005000000144031B2648C5040AA6400A8E28E4C40144031B2648C50401CEF8E8CD5904C40EBE0606F628D50401CEF8E8CD5904C40EBE0606F628D5040AA6400A8E28E4C40144031B2648C5040AA6400A8E28E4C40
5842	Княжево	6	57	624	65.738578000000004	65.754171999999997	56.885328000000001	56.872359000000003	0103000020E61000000100000005000000E3E2A8DC446F504086AFAF75A96F4C40E3E2A8DC446F5040D61D8B6D52714C40C5E3A25A44705040D61D8B6D52714C40C5E3A25A4470504086AFAF75A96F4C40E3E2A8DC446F504086AFAF75A96F4C40
5703	Каскара	6	57	624	65.883071999999999	65.971439000000004	57.187674999999999	57.168990000000001	0103000020E61000000100000005000000DA006C4084785040EFACDD76A1954C40DA006C40847850406EA301BC05984C40C6C37B0E2C7E50406EA301BC05984C40C6C37B0E2C7E5040EFACDD76A1954C40DA006C4084785040EFACDD76A1954C40
5526	Каменка	6	57	624	65.100854999999996	65.154798999999997	57.266469999999998	57.249918000000001	0103000020E61000000100000005000000D6A887687446504043572250FD9F4C40D6A8876874465040BCAE5FB01BA24C40069D103AE8495040BCAE5FB01BA24C40069D103AE849504043572250FD9F4C40D6A887687446504043572250FD9F4C40
7149	Зырянка	6	57	624	65.016171	65.039732999999998	57.143073000000001	57.127091	0103000020E61000000100000005000000310917F208415040D74E948444904C40310917F20841504066F84F3750924C409BE447FC8A42504066F84F3750924C409BE447FC8A425040D74E948444904C40310917F208415040D74E948444904C40
6599	Железный Перебор	6	57	624	66.011172000000002	66.030233999999993	56.981355999999998	56.972718	0103000020E6100000010000000500000061A8C30AB7805040821DFF05827C4C4061A8C30AB7805040DFDDCA129D7D4C408B4E965AEF815040DFDDCA129D7D4C408B4E965AEF815040821DFF05827C4C4061A8C30AB7805040821DFF05827C4C40
5359	Ембаево	6	57	624	65.741478999999998	65.797928999999996	57.156812000000002	57.144669	0103000020E61000000100000005000000EEEA5564746F50405DDF878384924C40EEEA5564746F504068CF656A12944C40EBE1CB441173504068CF656A12944C40EBE1CB44117350405DDF878384924C40EEEA5564746F50405DDF878384924C40
7346	Друганова	6	57	624	65.319486999999995	65.341954000000001	56.964961000000002	56.959159999999997	0103000020E61000000100000005000000D11F9A7972545040D0D03FC1C57A4C40D11F9A79725450402E7590D7837B4C4021AF0793E25550402E7590D7837B4C4021AF0793E2555040D0D03FC1C57A4C40D11F9A7972545040D0D03FC1C57A4C40
6194	Гусево	6	57	624	65.301332000000002	65.321149000000005	57.090338000000003	57.077587000000001	0103000020E61000000100000005000000404F03064953504021CCED5EEE894C40404F03064953504004CB1132908B4C40290989B48D54504004CB1132908B4C40290989B48D54504021CCED5EEE894C40404F03064953504021CCED5EEE894C40
5329	Горьковка	6	57	624	65.249758999999997	65.281452000000002	57.146070999999999	57.132694000000001	0103000020E610000001000000050000006D382C0DFC4F50400E30F31DFC904C406D382C0DFC4F50406FF25B74B2924C4034D93F4F035250406FF25B74B2924C4034D93F4F035250400E30F31DFC904C406D382C0DFC4F50400E30F31DFC904C40
55077	Винзили	6	57	624	65.734489999999994	65.809005999999997	56.974463999999998	56.936902000000003	0103000020E610000001000000050000004C4F58E2016F50404CC79C67EC774C404C4F58E2016F50408E90813CBB7C4C4023111AC1C67350408E90813CBB7C4C4023111AC1C67350404CC79C67EC774C404C4F58E2016F50404CC79C67EC774C40
55073	Боровский	6	57	624	65.695818000000003	65.750966000000005	57.061190000000003	57.028838999999998	0103000020E61000000100000005000000F67D3848886C5040B7EC10FFB0834C40F67D3848886C5040CF6BEC12D5874C401C9AB2D30F705040CF6BEC12D5874C401C9AB2D30F705040B7EC10FFB0834C40F67D3848886C5040B7EC10FFB0834C40
4633	Борки	6	57	624	66.047706000000005	66.084456000000003	57.181728999999997	57.168092000000001	0103000020E61000000100000005000000AC74779D0D835040105CE50984954C40AC74779D0D8350400DDE57E542974C40DD7C23BA678550400DDE57E542974C40DD7C23BA67855040105CE50984954C40AC74779D0D835040105CE50984954C40
7281	Большие Акияры	6	57	624	65.364401999999998	65.395296000000002	56.956432	56.946083999999999	0103000020E610000001000000050000003526C45C525750406AA2CF4719794C403526C45C52575040876C205D6C7A4C40560F98874C595040876C205D6C7A4C40560F98874C5950406AA2CF4719794C403526C45C525750406AA2CF4719794C40
6474	Богандинское	6	57	624	65.816209999999998	65.830233000000007	56.959622000000003	56.949407000000001	0103000020E61000000100000005000000C32ADEC83C745040F7CB272B86794C40C32ADEC83C745040D542C9E4D47A4C40D7C3978922755040D542C9E4D47A4C40D7C3978922755040F7CB272B86794C40C32ADEC83C745040F7CB272B86794C40
55080	Богандинский	6	57	624	65.830394999999996	65.916111999999998	56.904133000000002	56.859000999999999	0103000020E61000000100000005000000C3F01131257550409B1DA9BEF36D4C40C3F0113125755040001E51A1BA734C4048DE3994A17A5040001E51A1BA734C4048DE3994A17A50409B1DA9BEF36D4C40C3F01131257550409B1DA9BEF36D4C40
4239	Андреевский	6	57	624	65.761062999999993	65.811475999999999	57.087071000000002	57.053381999999999	0103000020E6100000010000000500000085CC9541B5705040F818AC38D5864C4085CC9541B57050400BB77C24258B4C404A5F0839EF7350400BB77C24258B4C404A5F0839EF735040F818AC38D5864C4085CC9541B5705040F818AC38D5864C40
1898	Тобольск	6	57	54	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
32427	Соколовка	6	57	54	68.34751	68.373030999999997	58.250084000000001	58.237412999999997	0103000020E610000001000000050000001C42959A3D1651409752978C631E4D401C42959A3D1651405EA0A4C002204D403A596ABDDF1751405EA0A4C002204D403A596ABDDF1751409752978C631E4D401C42959A3D1651409752978C631E4D40
1466	Сибиряк	6	57	54	68.45599	68.473094000000003	58.154274999999998	58.141902999999999	0103000020E610000001000000050000006553AEF02E1D5140261AA4E029124D406553AEF02E1D514092CB7F48BF134D40C47B0E2C471E514092CB7F48BF134D40C47B0E2C471E5140261AA4E029124D406553AEF02E1D5140261AA4E029124D40
1579	Санниково	6	57	54	68.584655999999995	68.620005000000006	58.055522000000003	58.037230999999998	0103000020E6100000010000000500000040DAFF006B255140DDB243FCC3044D4040DAFF006B255140B11A4B581B074D40D1967329AE275140B11A4B581B074D40D1967329AE275140DDB243FCC3044D4040DAFF006B255140DDB243FCC3044D40
1449	Прииртышский	6	57	54	68.326443999999995	68.368934999999993	58.186950000000003	58.151634999999999	0103000020E610000001000000050000006DFE5F75E4145140E8F692C668134D406DFE5F75E41451405DFE43FAED174D4062D68BA19C1751405DFE43FAED174D4062D68BA19C175140E8F692C668134D406DFE5F75E4145140E8F692C668134D40
32298	Преображенка	6	57	54	68.539929000000001	68.565441000000007	58.158923999999999	58.145502999999998	0103000020E610000001000000050000005E4A5D328E225140253CA1D79F124D405E4A5D328E2251405646239F57144D4053B4722F302451405646239F57144D4053B4722F30245140253CA1D79F124D405E4A5D328E225140253CA1D79F124D40
1566	Полуянова	6	57	54	68.794224	68.818047000000007	58.044144000000003	58.031846999999999	0103000020E61000000100000005000000B16CE690D4325140E4BCFF8F13044D40B16CE690D43251404628B682A6054D40D2E5CDE15A3451404628B682A6054D40D2E5CDE15A345140E4BCFF8F13044D40B16CE690D4325140E4BCFF8F13044D40
162	Октябрьский	6	57	54	68.742408999999995	68.754949999999994	58.273490000000002	58.264643999999997	0103000020E6100000010000000500000063D009A1832F5140938AC6DADF214D4063D009A1832F51403BE466B801234D405F07CE19513051403BE466B801234D405F07CE1951305140938AC6DADF214D4063D009A1832F5140938AC6DADF214D40
1123	Нижние Аремзяны	6	57	54	68.598939000000001	68.642489999999995	58.509241000000003	58.492297999999998	0103000020E6100000010000000500000022533E04552651406FF1F09E033F4D4022533E0455265140246420CF2E414D407380608E1E295140246420CF2E414D407380608E1E2951406FF1F09E033F4D4022533E04552651406FF1F09E033F4D40
1223	Надцы	6	57	54	68.563303000000005	68.581871000000007	58.634177999999999	58.617961999999999	0103000020E6100000010000000500000047AF06280D245140DB15FA60194F4D4047AF06280D245140DDEBA4BE2C514D406ADFDC5F3D255140DDEBA4BE2C514D406ADFDC5F3D255140DB15FA60194F4D4047AF06280D245140DB15FA60194F4D40
348	Медянки-Татарские	6	57	54	68.211640000000003	68.22878	58.146315999999999	58.132401000000002	0103000020E61000000100000005000000A1A17F828B0D5140967A1684F2104D40A1A17F828B0D5140D670917BBA124D40A67EDE54A40E5140D670917BBA124D40A67EDE54A40E5140967A1684F2104D40A1A17F828B0D5140967A1684F2104D40
1686	Маслова	6	57	54	68.412385999999998	68.430406000000005	58.077486	58.065286999999998	0103000020E6100000010000000500000002D53F88641A51404EED0C535B084D4002D53F88641A5140EDF2AD0FEB094D4024809BC58B1B5140EDF2AD0FEB094D4024809BC58B1B51404EED0C535B084D4002D53F88641A51404EED0C535B084D40
1101	Малая Зоркальцева	6	57	54	68.380432999999996	68.404176000000007	58.421041000000002	58.404994000000002	0103000020E610000001000000050000006D54A70359185140C289E8D7D6334D406D54A7035918514038A3E6ABE4354D4000750305DE19514038A3E6ABE4354D4000750305DE195140C289E8D7D6334D406D54A70359185140C289E8D7D6334D40
805	Кутарбитка	6	57	54	67.962474	67.986872000000005	57.842227000000001	57.825634000000001	0103000020E6100000010000000500000005508C2C99FD50409B3BFA5FAEE94C4005508C2C99FD504073672618CEEB4C40A4552DE928FF504073672618CEEB4C40A4552DE928FF50409B3BFA5FAEE94C4005508C2C99FD50409B3BFA5FAEE94C40
728	Карачино	6	57	54	68.128140999999999	68.169392000000002	58.023836000000003	58.011474999999997	0103000020E61000000100000005000000B6114F76330851405DDC460378014D40B6114F7633085140D63BDC0E0D034D400F0D8B51D70A5140D63BDC0E0D034D400F0D8B51D70A51405DDC460378014D40B6114F76330851405DDC460378014D40
1245	Ингаир	6	57	54	68.761813000000004	68.771074999999996	58.610004000000004	58.603636999999999	0103000020E61000000100000005000000BB2A508BC1305140E9D32AFA434D4D40BB2A508BC1305140F0366F9C144E4D40D8F0F44A59315140F0366F9C144E4D40D8F0F44A59315140E9D32AFA434D4D40BB2A508BC1305140E9D32AFA434D4D40
608	Загваздина	6	57	54	68.669788999999994	68.685446999999996	58.123871000000001	58.115794999999999	0103000020E610000001000000050000001D8EAED2DD2A51402905DD5ED20E4D401D8EAED2DD2A51401FF64201DB0F4D400B09185DDE2B51401FF64201DB0F4D400B09185DDE2B51402905DD5ED20E4D401D8EAED2DD2A51402905DD5ED20E4D40
665	Епанчина	6	57	54	68.71078	68.731234000000001	58.102851999999999	58.091732	0103000020E61000000100000005000000A8A9656B7D2D514093FFC9DFBD0B4D40A8A9656B7D2D5140022A1C412A0D4D404AEEB089CC2E5140022A1C412A0D4D404AEEB089CC2E514093FFC9DFBD0B4D40A8A9656B7D2D514093FFC9DFBD0B4D40
432	Дегтярево	6	57	54	68.066202000000004	68.102628999999993	57.898026000000002	57.889755000000001	0103000020E61000000100000005000000823B50A73C045140EB39E97DE3F14C40823B50A73C045140967A1684F2F24C40C1A7397991065140967A1684F2F24C40C1A7397991065140EB39E97DE3F14C40823B50A73C045140EB39E97DE3F14C40
292	Ворогушино	6	57	54	68.269833000000006	68.285956999999996	58.119712	58.103337000000003	0103000020E610000001000000050000006C98A1F144115140BFBB95253A0D4D406C98A1F14411514029780AB9520F4D40FCC3961E4D12514029780AB9520F4D40FCC3961E4D125140BFBB95253A0D4D406C98A1F144115140BFBB95253A0D4D40
64	Верхние Аремзяны	6	57	54	68.576139999999995	68.600663999999995	58.314244000000002	58.302452000000002	0103000020E61000000100000005000000B77A4E7ADF2451400E4E44BFB6264D40B77A4E7ADF2451406C7BBB2539284D409CF86A47712651406C7BBB2539284D409CF86A47712651400E4E44BFB6264D40B77A4E7ADF2451400E4E44BFB6264D40
32494	Булашово	6	57	54	67.836872	67.859814999999998	57.781202999999998	57.768878000000001	0103000020E610000001000000050000000ABC934F8FF55040944E24986AE24C400ABC934F8FF55040BF44BC75FEE34C400E677E3507F75040BF44BC75FEE34C400E677E3507F75040944E24986AE24C400ABC934F8FF55040944E24986AE24C40
217	Бизино	6	57	54	68.252054999999999	68.286163999999999	58.152414	58.131383999999997	0103000020E61000000100000005000000C5724BAB21105140DC9BDF30D1104D40C5724BAB21105140EDB94C4D82134D40B952CF8250125140EDB94C4D82134D40B952CF8250125140DC9BDF30D1104D40C5724BAB21105140DC9BDF30D1104D40
32406	Башкова	6	57	54	68.294652999999997	68.301964999999996	58.310046	58.295264000000003	0103000020E61000000100000005000000C5AA4198DB125140D4D7F335CB254D40C5AA4198DB125140B8205B96AF274D4058E2016553135140B8205B96AF274D4058E2016553135140D4D7F335CB254D40C5AA4198DB125140D4D7F335CB254D40
32356	Байкалово	6	57	54	67.628012999999996	67.676000999999999	57.785117999999997	57.767735999999999	0103000020E610000001000000050000009F1D705D31E850401EFB592C45E24C409F1D705D31E850401EC022BF7EE44C400DC4B29943EB50401EC022BF7EE44C400DC4B29943EB50401EFB592C45E24C409F1D705D31E850401EFB592C45E24C40
32269	Абалак	6	57	54	68.581745999999995	68.603286999999995	58.134538999999997	58.120919000000001	0103000020E610000001000000050000000B2593533B255140863B17467A0F4D400B2593533B255140AD84EE9238114D4086C613419C265140AD84EE9238114D4086C613419C265140863B17467A0F4D400B2593533B255140863B17467A0F4D40
32133	Рядовичи	6	57	1774	69.803956999999997	69.811233999999999	56.497427000000002	56.490141999999999	0103000020E61000000100000005000000FA980F0874735140B1321AF9BC3E4C40FA980F0874735140DE921CB0AB3F4C40CFD90242EB735140DE921CB0AB3F4C40CFD90242EB735140B1321AF9BC3E4C40FA980F0874735140B1321AF9BC3E4C40
32155	Покровка	6	57	1774	69.551297000000005	69.575272999999996	56.799048999999997	56.786631	0103000020E61000000100000005000000825836734863514088821953B0644C4082583673486351406473D53C47664C406551D845D16451406473D53C47664C406551D845D164514088821953B0644C40825836734863514088821953B0644C40
31644	Осиновка	6	57	1774	69.881373999999994	69.888425999999995	56.593131	56.580098999999997	0103000020E61000000100000005000000DC627E6E687851409DB81CAF404A4C40DC627E6E68785140349F73B7EB4B4C40A1BAB9F8DB785140349F73B7EB4B4C40A1BAB9F8DB7851409DB81CAF404A4C40DC627E6E687851409DB81CAF404A4C40
32503	Нижнепинигино	6	57	1774	69.974485000000001	69.998262999999994	56.510075000000001	56.504272999999998	0103000020E61000000100000005000000535C55F65D7E5140BEA085048C404C40535C55F65D7E5140ECC039234A414C40A3737E8AE37F5140ECC039234A414C40A3737E8AE37F5140BEA085048C404C40535C55F65D7E5140BEA085048C404C40
31828	Нефтяник	6	57	1774	69.675921000000002	69.684769000000003	56.722622000000001	56.715499000000001	0103000020E610000001000000050000007F6B274A426B51400DA9A278955B4C407F6B274A426B514060AFB0E07E5C4C4023145B41D36B514060AFB0E07E5C4C4023145B41D36B51400DA9A278955B4C407F6B274A426B51400DA9A278955B4C40
32063	Калиновка	6	57	1774	69.412175000000005	69.437427	56.850653999999999	56.839080000000003	0103000020E61000000100000005000000A54E4013615A5140255D33F9666B4C40A54E4013615A5140151BF33AE26C4C40CBD8D0CDFE5B5140151BF33AE26C4C40CBD8D0CDFE5B5140255D33F9666B4C40A54E4013615A5140255D33F9666B4C40
31951	Жидоусово	6	57	1774	69.976308000000003	70.00421	56.740259999999999	56.733876000000002	0103000020E61000000100000005000000AFB48CD47B7E5140DFA815A6EF5D4C40AFB48CD47B7E5140BB44F5D6C05E4C403C1405FA44805140BB44F5D6C05E4C403C1405FA44805140DFA815A6EF5D4C40AFB48CD47B7E5140DFA815A6EF5D4C40
31919	Желнина	6	57	1774	70.117209000000003	70.133109000000005	56.702060000000003	56.692897000000002	0103000020E6100000010000000500000000732D5A808751408E3F51D9B0584C4000732D5A8087514036EA211ADD594C4069739CDB8488514036EA211ADD594C4069739CDB848851408E3F51D9B0584C4000732D5A808751408E3F51D9B0584C40
31860	Готопутово	6	57	1774	70.147824	70.179310000000001	56.780935999999997	56.765912	0103000020E610000001000000050000001764CBF27589514096CE876709624C401764CBF2758951407022FAB5F5634C402176A6D0798B51407022FAB5F5634C402176A6D0798B514096CE876709624C401764CBF27589514096CE876709624C40
31732	Ворсиха	6	57	1774	69.738918999999996	69.772623999999993	56.762878000000001	56.753157000000002	0103000020E6100000010000000500000027D9EA724A6F514072E0D57267604C4027D9EA724A6F5140406B7EFCA5614C40B306EFAB72715140406B7EFCA5614C40B306EFAB7271514072E0D57267604C4027D9EA724A6F514072E0D57267604C40
25745	Большое Сорокино	6	57	1774	69.767422999999994	69.852287000000004	56.649766	56.618353999999997	0103000020E61000000100000005000000AFCC5B751D715140E6AC4F39264F4C40AFCC5B751D715140C00644882B534C4095F3C5DE8B765140C00644882B534C4095F3C5DE8B765140E6AC4F39264F4C40AFCC5B751D715140E6AC4F39264F4C40
31695	Александровка	6	57	1774	69.721923000000004	69.755753999999996	56.612073000000002	56.60425	0103000020E61000000100000005000000BCCE86FC336E5140D34D6210584D4C40BCCE86FC336E5140DFE17668584E4C408E7406465E705140DFE17668584E4C408E7406465E705140D34D6210584D4C40BCCE86FC336E5140D34D6210584D4C40
31024	Хантиновка	6	57	1780	70.107714000000001	70.121044999999995	55.886302000000001	55.881413999999999	0103000020E6100000010000000500000091D442C9E4865140471E882CD2F04B4091D442C9E486514090300C5872F14B4009168733BF87514090300C5872F14B4009168733BF875140471E882CD2F04B4091D442C9E4865140471E882CD2F04B40
31417	Усово	6	57	1780	69.897795000000002	69.915824999999998	55.456769999999999	55.440033999999997	0103000020E61000000100000005000000CAE02879757951406490BB0853B84B40CAE02879757951409FE5797077BA4B40FDF675E09C7A51409FE5797077BA4B40FDF675E09C7A51406490BB0853B84B40CAE02879757951406490BB0853B84B40
61264	Травное	6	57	1780	70.226094000000003	70.242344000000003	55.751016	55.739624999999997	0103000020E6100000010000000500000099F4F752788E5140E9263108ACDE4B4099F4F752788E5140E962D34A21E04B4070986890828F5140E962D34A21E04B4070986890828F5140E9263108ACDE4B4099F4F752788E5140E9263108ACDE4B40
31331	Степное	6	57	1780	70.187646000000001	70.202692999999996	55.610518999999996	55.598055000000002	0103000020E610000001000000050000006A4E5E64028C5140CA1AF5108DCC4B406A4E5E64028C5140164B917C25CE4B4033880FECF88C5140164B917C25CE4B4033880FECF88C5140CA1AF5108DCC4B406A4E5E64028C5140CA1AF5108DCC4B40
25685	Сладково	6	57	1780	70.306206000000003	70.359798999999995	55.539929999999998	55.520105000000001	0103000020E61000000100000005000000B2F50CE19893514038BEF6CC92C24B40B2F50CE1989351408C101E6D1CC54B408B8862F2069751408C101E6D1CC54B408B8862F20697514038BEF6CC92C24B40B2F50CE19893514038BEF6CC92C24B40
31205	Новоандреевка	6	57	1780	70.429373999999996	70.454688000000004	55.861772000000002	55.846957000000003	0103000020E610000001000000050000002CF015DD7A9B5140240F441669EC4B402CF015DD7A9B5140E44D7E8B4EEE4B408E78B29B199D5140E44D7E8B4EEE4B408E78B29B199D5140240F441669EC4B402CF015DD7A9B5140240F441669EC4B40
31152	Никулино	6	57	1780	70.618926999999999	70.634764000000004	55.561425999999997	55.542074999999997	0103000020E6100000010000000500000021E7FD7F9CA75140567DAEB662C54B4021E7FD7F9CA75140E28FA2CEDCC74B40672B2FF99FA85140E28FA2CEDCC74B40672B2FF99FA85140567DAEB662C54B4021E7FD7F9CA75140567DAEB662C54B40
31061	Менжинское	6	57	1780	69.864333000000002	69.881752000000006	55.778390999999999	55.767913999999998	0103000020E61000000100000005000000A1F65B3B51775140FD1186014BE24B40A1F65B3B517751401840F850A2E34B40B0CBF09F6E7851401840F850A2E34B40B0CBF09F6E785140FD1186014BE24B40A1F65B3B51775140FD1186014BE24B40
30942	Маслянский	6	57	1780	70.107946999999996	70.160059000000004	55.936771	55.917369000000001	0103000020E61000000100000005000000E2AC889AE88651409FAEEE586CF54B40E2AC889AE8865140AD6BB41CE8F74B408D9B1A683E8A5140AD6BB41CE8F74B408D9B1A683E8A51409FAEEE586CF54B40E2AC889AE88651409FAEEE586CF54B40
30827	Лопазное	6	57	1780	70.414192	70.435023999999999	55.488897000000001	55.471265000000002	0103000020E61000000100000005000000F390291F829A5140EE5F596952BC4B40F390291F829A5140670E492D94BE4B40683EE76ED79B5140670E492D94BE4B40683EE76ED79B5140EE5F596952BC4B40F390291F829A5140EE5F596952BC4B40
30250	Александровка	6	57	1780	69.929021000000006	69.963641999999993	55.274507999999997	55.257617000000003	0103000020E6100000010000000500000006137F14757B514063F20698F9A04B4006137F14757B5140C43E011423A34B4054C37E4FAC7D5140C43E011423A34B4054C37E4FAC7D514063F20698F9A04B4006137F14757B514063F20698F9A04B40
30692	Южно-Плетнево	6	57	1779	67.477149999999995	67.521904000000006	56.419483	56.404936999999997	0103000020E61000000100000005000000545227A089DE50405DF8C1F9D4334C40545227A089DE50402E1D739EB1354C40B4E908E066E150402E1D739EB1354C40B4E908E066E150405DF8C1F9D4334C40545227A089DE50405DF8C1F9D4334C40
30664	Шабаново	6	57	1779	67.864845000000003	67.902799000000002	56.494777999999997	56.475428999999998	0103000020E61000000100000005000000FCC6D79E59F75040F54883DBDA3C4C40FCC6D79E59F75040E063B0E2543F4C4023F77475C7F95040E063B0E2543F4C4023F77475C7F95040F54883DBDA3C4C40FCC6D79E59F75040F54883DBDA3C4C40
30391	Ситниково	6	57	1779	67.819524999999999	67.852187999999998	56.387504999999997	56.347020000000001	0103000020E610000001000000050000004850FC1873F450406A87BF266B2C4C404850FC1873F45040AB048BC399314C40CB82893F8AF65040AB048BC399314C40CB82893F8AF650406A87BF266B2C4C404850FC1873F450406A87BF266B2C4C40
29904	Омутинское	6	57	1779	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
25649	Окуневское	6	57	1779	67.444091999999998	67.462732000000003	56.572017000000002	56.546917000000001	0103000020E61000000100000005000000931ADA006CDC50402F50526001464C40931ADA006CDC5040C6E061DA37494C4003B4AD669DDD5040C6E061DA37494C4003B4AD669DDD50402F50526001464C40931ADA006CDC50402F50526001464C40
29769	Крутинская	6	57	1779	67.306021000000001	67.321652	56.452444	56.444288999999998	0103000020E61000000100000005000000E9B81AD995D350407C7C4276DE384C40E9B81AD995D35040BEA25BAFE9394C405A2C45F295D45040BEA25BAFE9394C405A2C45F295D450407C7C4276DE384C40E9B81AD995D350407C7C4276DE384C40
30348	Кашевская	6	57	1779	67.693203999999994	67.711241999999999	56.460585999999999	56.448115999999999	0103000020E61000000100000005000000355D4F745DEC50403C6876DD5B394C40355D4F745DEC50406B7F677BF43A4C40AA622AFD84ED50406B7F677BF43A4C40AA622AFD84ED50403C6876DD5B394C40355D4F745DEC50403C6876DD5B394C40
29809	Журавлевское	6	57	1779	67.669740000000004	67.691424999999995	56.274614	56.265177000000001	0103000020E61000000100000005000000AD342905DDEA50406153E751F1214C40AD342905DDEA50400A83328D26234C40C1A8A44E40EC50400A83328D26234C40C1A8A44E40EC50406153E751F1214C40AD342905DDEA50406153E751F1214C40
29594	Вагай	6	57	1779	67.278614000000005	67.335386999999997	56.482066000000003	56.461596	0103000020E610000001000000050000004C8DD0CFD4D1504072FBE593153B4C404C8DD0CFD4D15040BC41B456B43D4C403A2009FB76D55040BC41B456B43D4C403A2009FB76D5504072FBE593153B4C404C8DD0CFD4D1504072FBE593153B4C40
29530	Большой Краснояр	6	57	1779	67.707594999999998	67.731966	56.56982	56.555674000000003	0103000020E610000001000000050000000AF4893C49ED5040679E5C5320474C400AF4893C49ED5040A94D9CDCEF484C402CF2EB87D8EE5040A94D9CDCEF484C402CF2EB87D8EE5040679E5C5320474C400AF4893C49ED5040679E5C5320474C40
29714	Большекрутинская	6	57	1779	67.342833999999996	67.372001999999995	56.456035	56.444274999999998	0103000020E610000001000000050000003D7D04FEF0D5504017B7D100DE384C403D7D04FEF0D550406A6AD95A5F3A4C40FB027AE1CED750406A6AD95A5F3A4C40FB027AE1CED7504017B7D100DE384C403D7D04FEF0D5504017B7D100DE384C40
29460	Чугунаево	6	57	854	65.653542999999999	65.672766999999993	57.655394999999999	57.643456	0103000020E61000000100000005000000E7E104A6D36950401E3526C45CD24C40E7E104A6D3695040207BBDFBE3D34C40FEB4519D0E6B5040207BBDFBE3D34C40FEB4519D0E6B50401E3526C45CD24C40E7E104A6D36950401E3526C45CD24C40
29397	Черепаново	6	57	854	65.983035999999998	66.001047999999997	57.706349000000003	57.697346000000003	0103000020E610000001000000050000009AB2D30FEA7E50408BFF3BA242D94C409AB2D30FEA7E5040FA47DFA469DA4C407A6EA12B11805040FA47DFA469DA4C407A6EA12B118050408BFF3BA242D94C409AB2D30FEA7E50408BFF3BA242D94C40
29209	Тюнево	6	57	854	65.683860999999993	65.713048000000001	57.396892999999999	57.382854999999999	0103000020E61000000100000005000000A180ED60C46B5040170E846401B14C40A180ED60C46B50407381CB63CDB24C409B1E1494A26D50407381CB63CDB24C409B1E1494A26D5040170E846401B14C40A180ED60C46B5040170E846401B14C40
28979	Тукман	6	57	854	66.486057000000002	66.504238999999998	57.575353	57.567138	0103000020E610000001000000050000007BBFD18E1B9F5040D0285DFA97C84C407BBFD18E1B9F5040E753C72AA5C94C408997A77345A05040E753C72AA5C94C408997A77345A05040D0285DFA97C84C407BBFD18E1B9F5040D0285DFA97C84C40
28506	Торгили	6	57	854	66.037321000000006	66.049440000000004	57.284424999999999	57.279263	0103000020E610000001000000050000000F9D9E7763825040CEFDD5E3BEA34C400F9D9E77638250401895D40968A44C4050C763062A8350401895D40968A44C4050C763062A835040CEFDD5E3BEA34C400F9D9E7763825040CEFDD5E3BEA34C40
27058	Средние Тарманы	6	57	854	65.319441999999995	65.393237999999997	57.368530999999997	57.364030999999997	0103000020E6100000010000000500000001BEDBBC7154504076DD5B9198AE4C4001BEDBBC71545040F54718062CAF4C40D862B7CF2A595040F54718062CAF4C40D862B7CF2A59504076DD5B9198AE4C4001BEDBBC7154504076DD5B9198AE4C40
28740	Сартово	6	57	854	66.057516000000007	66.071986999999993	57.592880999999998	57.578184999999998	0103000020E61000000100000005000000CBBF9657AE835040D50451F701CA4C40CBBF9657AE835040BBB54C86E3CB4C402DAF5C6F9B845040BBB54C86E3CB4C402DAF5C6F9B845040D50451F701CA4C40CBBF9657AE835040D50451F701CA4C40
29056	Паченка	6	57	854	66.300977000000003	66.328681000000003	57.679892000000002	57.662318999999997	0103000020E6100000010000000500000049F60835439350407C4276DEC6D44C4049F6083543935040F16778B306D74C404374081C09955040F16778B306D74C404374081C099550407C4276DEC6D44C4049F60835439350407C4276DEC6D44C40
28233	Новопокровка	6	57	854	65.371399999999994	65.390255999999994	57.478467000000002	57.468603999999999	0103000020E61000000100000005000000006F8104C55750402C634337FBBB4C40006F8104C55750408D9B1A683EBD4C4056444DF4F95850408D9B1A683EBD4C4056444DF4F95850402C634337FBBB4C40006F8104C55750402C634337FBBB4C40
28816	Новоникольское	6	57	854	65.222154000000003	65.253487000000007	57.661732000000001	57.650790999999998	0103000020E610000001000000050000003D2B69C5374E5040FCC3961E4DD34C403D2B69C5374E5040BC5B59A2B3D44C4084BD892139505040BC5B59A2B3D44C4084BD892139505040FCC3961E4DD34C403D2B69C5374E5040FCC3961E4DD34C40
28683	Нижняя Тавда	6	57	854	66.134446999999994	66.214577000000006	57.696480000000001	57.659762000000001	0103000020E61000000100000005000000E60297C79A8850406092CA1473D44C40E60297C79A885040B728B34126D94C40535E2BA1BB8D5040B728B34126D94C40535E2BA1BB8D50406092CA1473D44C40E60297C79A8850406092CA1473D44C40
6395	Нариманова	6	57	854	65.083904000000004	65.107134000000002	57.378363	57.368355999999999	0103000020E610000001000000050000003B00E2AE5E45504087A4164A26AF4C403B00E2AE5E4550401B82E3326EB04C408A929048DB4650401B82E3326EB04C408A929048DB46504087A4164A26AF4C403B00E2AE5E45504087A4164A26AF4C40
28600	Мияссы	6	57	854	65.898450999999994	65.933413000000002	57.874969	57.859133999999997	0103000020E61000000100000005000000BE839F3880795040DA70581AF8ED4C40BE839F3880795040C501F4FBFEEF4C40522AE109BD7B5040C501F4FBFEEF4C40522AE109BD7B5040DA70581AF8ED4C40BE839F3880795040DA70581AF8ED4C40
29348	Лесозаводский	6	57	854	65.554817999999997	65.574438000000001	57.383695000000003	57.374504999999999	0103000020E61000000100000005000000DB4E5B23826350402098A3C7EFAF4C40DB4E5B2382635040C251F2EA1CB14C4019E59997C3645040C251F2EA1CB14C4019E59997C36450402098A3C7EFAF4C40DB4E5B23826350402098A3C7EFAF4C40
28536	Кунчур	6	57	854	66.180755000000005	66.198282000000006	57.278756999999999	57.268962000000002	0103000020E61000000100000005000000AA656B7D918B5040F2EEC8586DA24C40AA656B7D918B5040FA43334FAEA34C40AC58FCA6B08C5040FA43334FAEA34C40AC58FCA6B08C5040F2EEC8586DA24C40AA656B7D918B5040F2EEC8586DA24C40
28331	Красный Яр	6	57	854	65.952988000000005	65.983063000000001	57.474865999999999	57.458767000000002	0103000020E61000000100000005000000C05E61C1FD7C5040F5BD86E0B8BA4C40C05E61C1FD7C5040BDFDB968C8BC4C4017BA1281EA7E5040BDFDB968C8BC4C4017BA1281EA7E5040F5BD86E0B8BA4C40C05E61C1FD7C5040F5BD86E0B8BA4C40
29150	Конченбург	6	57	854	66.302701999999996	66.325644999999994	57.476739000000002	57.466692000000002	0103000020E61000000100000005000000C39B35785F93504005A73E90BCBB4C40C39B35785F93504027DD96C805BD4C40C746205ED794504027DD96C805BD4C40C746205ED794504005A73E90BCBB4C40C39B35785F93504005A73E90BCBB4C40
29000	Киндер	6	57	854	66.377180999999993	66.399306999999993	57.642045000000003	57.631908000000003	0103000020E610000001000000050000000BEBC6BB23985040570A815CE2D04C400BEBC6BB23985040B9C7D2872ED24C401684F23E8E995040B9C7D2872ED24C401684F23E8E995040570A815CE2D04C400BEBC6BB23985040570A815CE2D04C40
29092	Картымский	6	57	854	66.381843000000003	66.401328000000007	57.474479000000002	57.467984000000001	0103000020E61000000100000005000000384D9F1D70985040908653E6E6BB4C40384D9F1D70985040C4D155BABBBC4C4006BEA25BAF995040C4D155BABBBC4C4006BEA25BAF995040908653E6E6BB4C40384D9F1D70985040908653E6E6BB4C40
29321	Карагандинский	6	57	854	65.691416000000004	65.725416999999993	57.424191999999998	57.418066000000003	0103000020E6100000010000000500000098FBE428406C5040E7C8CA2F83B54C4098FBE428406C5040C79C67EC4BB64C4098BD6C3B6D6E5040C79C67EC4BB64C4098BD6C3B6D6E5040E7C8CA2F83B54C4098FBE428406C5040E7C8CA2F83B54C40
28416	Канаш	6	57	854	65.624634999999998	65.659418000000002	57.600921	57.591309000000003	0103000020E61000000100000005000000F73B1405FA6750404D6A6803B0CB4C40F73B1405FA675040643DB5FAEACC4C4033198EE7336A5040643DB5FAEACC4C4033198EE7336A50404D6A6803B0CB4C40F73B1405FA6750404D6A6803B0CB4C40
28311	Иска	6	57	854	65.764529999999993	65.799330999999995	57.587342999999997	57.558356000000003	0103000020E61000000100000005000000E5B33C0FEE70504040C39B3578C74C40E5B33C0FEE7050406B44300E2ECB4C4074EB353D287350406B44300E2ECB4C4074EB353D2873504040C39B3578C74C40E5B33C0FEE70504040C39B3578C74C40
28916	Веселая Грива	6	57	854	65.211860000000001	65.242734999999996	57.612310999999998	57.606051999999998	0103000020E6100000010000000500000028D53E1D8F4D504073D6A71C93CD4C4028D53E1D8F4D504093FDF33460CE4C400DA661F8884F504093FDF33460CE4C400DA661F8884F504073D6A71C93CD4C4028D53E1D8F4D504073D6A71C93CD4C40
28258	Велижаны	6	57	854	65.736862000000002	65.791740000000004	57.56832	57.544685000000001	0103000020E6100000010000000500000092EA3BBF286F504096CFF23CB8C54C4092EA3BBF286F5040D4D4B2B5BEC84C40D8BB3FDEAB725040D4D4B2B5BEC84C40D8BB3FDEAB72504096CFF23CB8C54C4092EA3BBF286F504096CFF23CB8C54C40
28162	Бухтал	6	57	854	65.142949999999999	65.191333	57.514436000000003	57.496626999999997	0103000020E61000000100000005000000A5BDC11726495040C1A7397991BF4C40A5BDC117264950404AF1F109D9C14C405169C4CC3E4C50404AF1F109D9C14C405169C4CC3E4C5040C1A7397991BF4C40A5BDC11726495040C1A7397991BF4C40
28149	Березовка	6	57	854	65.781938999999994	65.808925000000002	57.677241000000002	57.667209999999997	0103000020E61000000100000005000000E21DE0490B72504036C8242367D54C40E21DE0490B725040534145D5AFD64C40ADFA5C6DC5735040534145D5AFD64C40ADFA5C6DC573504036C8242367D54C40E21DE0490B72504036C8242367D54C40
28042	Антипино	6	57	854	66.538347999999999	66.581520999999995	57.825240999999998	57.809992000000001	0103000020E610000001000000050000007D772B4B74A25040C5025FD1ADE74C407D772B4B74A25040BF28417FA1E94C40FB3BDBA337A55040BF28417FA1E94C40FB3BDBA337A55040C5025FD1ADE74C407D772B4B74A25040C5025FD1ADE74C40
27977	Андрюшино	6	57	854	65.947255999999996	65.978311000000005	57.763520999999997	57.750382999999999	0103000020E61000000100000005000000253CA1D79F7C5040B83CD68C0CE04C40253CA1D79F7C504094675E0EBBE14C404B94BDA59C7E504094675E0EBBE14C404B94BDA59C7E5040B83CD68C0CE04C40253CA1D79F7C5040B83CD68C0CE04C40
27883	Яровское	6	57	1799	69.129484000000005	69.151870000000002	55.579642999999997	55.567839999999997	0103000020E61000000100000005000000BD5642774948514029AE2AFBAEC84B40BD564277494851407B2DE8BD31CA4B4096CFF23CB84951407B2DE8BD31CA4B4096CFF23CB849514029AE2AFBAEC84B40BD5642774948514029AE2AFBAEC84B40
27736	Чирки	6	57	1799	68.976473999999996	69.001474000000002	55.759582999999999	55.750281999999999	0103000020E610000001000000050000003CD9CD8C7E3E51408463963D09E04B403CD9CD8C7E3E51407DCC07043AE14B40D6726726184051407DCC07043AE14B40D6726726184051408463963D09E04B403CD9CD8C7E3E51408463963D09E04B40
27834	Челюскинцев	6	57	1799	69.611969999999999	69.635559000000001	55.766911	55.759202999999999	0103000020E61000000100000005000000850838842A67514036035C902DE14B40850838842A675140A9F8BF232AE24B406CEBA7FFAC685140A9F8BF232AE24B406CEBA7FFAC68514036035C902DE14B40850838842A67514036035C902DE14B40
27642	Смирное	6	57	1799	68.973375000000004	68.996848	55.818928	55.812018999999999	0103000020E610000001000000050000009EEFA7C64B3E5140855D143DF0E74B409EEFA7C64B3E5140ACE3F8A1D2E84B4050C58D5BCC3F5140ACE3F8A1D2E84B4050C58D5BCC3F5140855D143DF0E74B409EEFA7C64B3E5140855D143DF0E74B40
27937	Сладчанка	6	57	1799	69.218093999999994	69.226304999999996	55.535986999999999	55.522041000000002	0103000020E610000001000000050000000B5D8940F54D5140E8154F3DD2C24B400B5D8940F54D5140630AD6389BC44B40F67AF7C77B4E5140630AD6389BC44B40F67AF7C77B4E5140E8154F3DD2C24B400B5D8940F54D5140E8154F3DD2C24B40
27544	Пешнево	6	57	1799	69.394891999999999	69.427032999999994	55.563813000000003	55.548955999999997	0103000020E61000000100000005000000EE5C18E945595140B378B13044C64B40EE5C18E945595140A3073E062BC84B4004543882545B5140A3073E062BC84B4004543882545B5140B378B13044C64B40EE5C18E945595140B378B13044C64B40
27510	Песчаное	6	57	1799	69.308537000000001	69.325963999999999	55.831260999999998	55.819696999999998	0103000020E61000000100000005000000C826F911BF5351408DD0CFD4EBE84B40C826F911BF5351405AB8ACC266EA4B4018EB1B98DC5451405AB8ACC266EA4B4018EB1B98DC5451408DD0CFD4EBE84B40C826F911BF5351408DD0CFD4EBE84B40
27462	Огнево	6	57	1799	69.303353000000001	69.320330999999996	55.777424000000003	55.770836000000003	0103000020E610000001000000050000002F89B3226A5351402C4A09C1AAE24B402F89B3226A53514011902FA182E34B404739984D8054514011902FA182E34B404739984D805451402C4A09C1AAE24B402F89B3226A5351402C4A09C1AAE24B40
27344	Новоселезнево	6	57	1799	69.199282999999994	69.212254999999999	55.688679999999998	55.671244999999999	0103000020E6100000010000000500000085E97B0DC14C5140404D2D5BEBD54B4085E97B0DC14C514063B48EAA26D84B4066DAFE95954D514063B48EAA26D84B4066DAFE95954D5140404D2D5BEBD54B4085E97B0DC14C5140404D2D5BEBD54B40
26502	Новогеоргиевка	6	57	1799	69.433519000000004	69.452483000000001	55.385126999999997	55.380324000000002	0103000020E6100000010000000500000075CC79C6BE5B514024F1F274AEB04B4075CC79C6BE5B51403EE76ED74BB14B40BEBF417BF55C51403EE76ED74BB14B40BEBF417BF55C514024F1F274AEB04B4075CC79C6BE5B514024F1F274AEB04B40
26650	Малый Ченчерь	6	57	1799	69.363684000000006	69.375955000000005	55.796643000000003	55.789825999999998	0103000020E610000001000000050000000685419946575140E7C3B30419E54B4006854199465751402ECBD765F8E54B4022718FA50F5851402ECBD765F8E54B4022718FA50F585140E7C3B30419E54B400685419946575140E7C3B30419E54B40
61259	Малые Ярки	6	57	1799	69.308384000000004	69.324202999999997	55.613289999999999	55.607880000000002	0103000020E6100000010000000500000005A73E90BC5351403DF20703CFCD4B4005A73E90BC5351405F7B664980CE4B40F790F0BDBF5451405F7B664980CE4B40F790F0BDBF5451403DF20703CFCD4B4005A73E90BC5351403DF20703CFCD4B40
27711	Коротаевка	6	57	1799	69.051779999999994	69.061760000000007	55.832106000000003	55.823504999999997	0103000020E610000001000000050000008FA50F5D50435140D68BA19C68E94B408FA50F5D5043514017670C7382EA4B40DD0C37E0F343514017670C7382EA4B40DD0C37E0F3435140D68BA19C68E94B408FA50F5D50435140D68BA19C68E94B40
27620	Копотилово	6	57	1799	69.468446	69.493554000000003	55.539268	55.531351000000001	0103000020E610000001000000050000004A7CEE04FB5D514034D93F4F03C44B404A7CEE04FB5D5140C1E3DBBB06C54B40D7338463965F5140C1E3DBBB06C54B40D7338463965F514034D93F4F03C44B404A7CEE04FB5D514034D93F4F03C44B40
27139	Казанское	6	57	1799	69.190389999999994	69.253173000000004	55.673406999999997	55.620479000000003	0103000020E6100000010000000500000011DF89592F4C51406A6D1ADB6BCF4B4011DF89592F4C5140E0F2583332D64B40BCCE86FC33505140E0F2583332D64B40BCCE86FC335051406A6D1ADB6BCF4B4011DF89592F4C51406A6D1ADB6BCF4B40
26965	Ильинка	6	57	1799	69.313316	69.334192000000002	55.455295	55.441457999999997	0103000020E6100000010000000500000011548D5E0D5451405E471CB281B84B4011548D5E0D5451402384471B47BA4B406EA5D766635551402384471B47BA4B406EA5D766635551405E471CB281B84B4011548D5E0D5451405E471CB281B84B40
27078	Ельцово	6	57	1799	69.336582000000007	69.349913000000001	55.404125999999998	55.386496999999999	0103000020E61000000100000005000000079B3A8F8A5551404580D3BB78B14B40079B3A8F8A5551404DBB9866BAB34B407FDC7EF9645651404DBB9866BAB34B407FDC7EF9645651404580D3BB78B14B40079B3A8F8A5551404580D3BB78B14B40
26793	Дубынка	6	57	1799	68.880955999999998	68.916593000000006	55.490375999999998	55.480612000000001	0103000020E61000000100000005000000C24D4695613851405708ABB184BD4B40C24D469561385140245F09A4C4BE4B4086AFAF75A93A5140245F09A4C4BE4B4086AFAF75A93A51405708ABB184BD4B40C24D4695613851405708ABB184BD4B40
26867	Грачи	6	57	1799	68.836282999999995	68.867760000000004	55.570247999999999	55.558259	0103000020E61000000100000005000000D9CC21A9853551404DD9E90775C74B40D9CC21A985355140014EEFE2FDC84B40BA313D6189375140014EEFE2FDC84B40BA313D61893751404DD9E90775C74B40D9CC21A9853551404DD9E90775C74B40
26790	Гагарье	6	57	1799	69.218642000000003	69.237093999999999	55.747225999999998	55.734445000000001	0103000020E610000001000000050000000DE2033BFE4D5140F9DA334B02DE4B400DE2033BFE4D5140465C001AA5DF4B40FB04508C2C4F5140465C001AA5DF4B40FB04508C2C4F5140F9DA334B02DE4B400DE2033BFE4D5140F9DA334B02DE4B40
26599	Большой Ченчерь	6	57	1799	69.425927999999999	69.446329000000006	55.795034000000001	55.783838000000003	0103000020E61000000100000005000000D89C8367425B514058AEB7CD54E44B40D89C8367425B5140A29A92ACC3E54B40699082A7905C5140A29A92ACC3E54B40699082A7905C514058AEB7CD54E44B40D89C8367425B514058AEB7CD54E44B40
26677	Большие Ярки	6	57	1799	69.284767000000002	69.313046	55.599406999999999	55.584415999999997	0103000020E61000000100000005000000B9FE5D9F395251402BA1BB24CECA4B40B9FE5D9F395251402AFF5A5EB9CC4B40310917F2085451402AFF5A5EB9CC4B40310917F2085451402BA1BB24CECA4B40B9FE5D9F395251402BA1BB24CECA4B40
27061	Благодатное	6	57	1799	69.157404	69.181990999999996	55.394478999999997	55.386783000000001	0103000020E610000001000000050000009D103AE8124A51400BD3F71A82B14B409D103AE8124A5140B9FAB1497EB24B40A54A94BDA54B5140B9FAB1497EB24B40A54A94BDA54B51400BD3F71A82B14B409D103AE8124A51400BD3F71A82B14B40
26988	Баландина	6	57	1799	69.329881	69.356740000000002	55.489555000000003	55.476050999999998	0103000020E6100000010000000500000098A432C51C555140321D3A3DEFBC4B4098A432C51C555140F14BFDBCA9BE4B40344B02D4D4565140F14BFDBCA9BE4B40344B02D4D4565140321D3A3DEFBC4B4098A432C51C555140321D3A3DEFBC4B40
26429	Афонькино	6	57	1799	69.417781000000005	69.435001	55.460864000000001	55.444946000000002	0103000020E61000000100000005000000F9F884ECBC5A5140363E93FDF3B84B40F9F884ECBC5A5140AEF36F97FDBA4B408C2E6F0ED75B5140AEF36F97FDBA4B408C2E6F0ED75B5140363E93FDF3B84B40F9F884ECBC5A5140363E93FDF3B84B40
24963	Шаблыкино	6	57	657	69.754227	69.775606999999994	56.024275000000003	56.008324000000002	0103000020E61000000100000005000000A7B0524145705140CEE2C5C210014C40A7B0524145705140228E75711B034C401DE38A8BA3715140228E75711B034C401DE38A8BA3715140CEE2C5C210014C40A7B0524145705140CEE2C5C210014C40
24857	Черемшанка	6	57	657	69.388549999999995	69.416020000000003	56.224952999999999	56.214962	0103000020E6100000010000000500000017B7D100DE585140FEF0F3DF831B4C4017B7D100DE5851408C118942CB1C4C40D89E5912A05A51408C118942CB1C4C40D89E5912A05A5140FEF0F3DF831B4C4017B7D100DE585140FEF0F3DF831B4C40
24666	Тоболово	6	57	657	69.124983999999998	69.152939000000003	56.213155	56.197142999999997	0103000020E610000001000000050000007D21E4BCFF47514052D158FB3B194C407D21E4BCFF4751404CFDBCA9481B4C401CD2A8C0C94951404CFDBCA9481B4C401CD2A8C0C949514052D158FB3B194C407D21E4BCFF47514052D158FB3B194C40
23117	Таловка (Разъезд №38)	6	57	657	69.403955999999994	69.416882000000001	56.155338	56.145885999999997	0103000020E610000001000000050000007841446ADA595140DD787764AC124C407841446ADA595140BCE9961DE2134C40A112D731AE5A5140BCE9961DE2134C40A112D731AE5A5140DD787764AC124C407841446ADA595140DD787764AC124C40
24424	Стрехнино	6	57	657	69.520951999999994	69.554630000000003	56.144562000000001	56.132523999999997	0103000020E610000001000000050000004AB20E4757615140B1F7E28BF6104C404AB20E4757615140471FF30181124C405AD8D30E7F635140471FF30181124C405AD8D30E7F635140B1F7E28BF6104C404AB20E4757615140B1F7E28BF6104C40
23380	Синицына	6	57	657	69.467341000000005	69.490481000000003	56.017688999999997	56.010699000000002	0103000020E610000001000000050000001EC539EAE85D5140CA8CB7955E014C401EC539EAE85D5140DD3F16A243024C40CD936B0A645F5140DD3F16A243024C40CD936B0A645F5140CA8CB7955E014C401EC539EAE85D5140CA8CB7955E014C40
24949	Савина	6	57	657	69.496069000000006	69.520511999999997	56.242924000000002	56.235636	0103000020E61000000100000005000000CEE33098BF5F514050E10852291E4C40CEE33098BF5F5140EEB43522181F4C403C4B901150615140EEB43522181F4C403C4B90115061514050E10852291E4C40CEE33098BF5F514050E10852291E4C40
24256	Равнец	6	57	657	69.778580000000005	69.81268	56.197223000000001	56.187660999999999	0103000020E6100000010000000500000076543541D471514009DE904605184C4076543541D47151406F826F9A3E194C404087F9F2027451406F826F9A3E194C404087F9F20274514009DE904605184C4076543541D471514009DE904605184C40
24161	Прокуткино	6	57	657	69.756005000000002	69.773145	56.318919999999999	56.304324999999999	0103000020E6100000010000000500000033A7CB6262705140772D211FF4264C4033A7CB62627051402905DD5ED2284C4038842A357B7151402905DD5ED2284C4038842A357B715140772D211FF4264C4033A7CB6262705140772D211FF4264C40
24021	Плодопитомник	6	57	657	69.405680000000004	69.418823000000003	56.086063000000003	56.075519	0103000020E610000001000000050000000B293FA9F6595140029D499BAA094C400B293FA9F6595140A532C51C040B4C4002F4FBFECD5A5140A532C51C040B4C4002F4FBFECD5A5140029D499BAA094C400B293FA9F6595140029D499BAA094C40
24090	Плешково	6	57	657	69.669685999999999	69.702366999999995	56.082104999999999	56.070163000000001	0103000020E61000000100000005000000B325AB22DC6A5140D331E719FB084C40B325AB22DC6A514046EBA86A820A4C4089B2B794F36C514046EBA86A820A4C4089B2B794F36C5140D331E719FB084C40B325AB22DC6A5140D331E719FB084C40
23865	Пахомова	6	57	657	69.389672000000004	69.407747000000001	56.060865999999997	56.050742	0103000020E61000000100000005000000AF0AD462F05851404E44BFB67E064C40AF0AD462F05851401BB80375CA074C40B282DF86185A51401BB80375CA074C40B282DF86185A51404E44BFB67E064C40AF0AD462F05851404E44BFB67E064C40
61253	Патрушево	6	57	657	68.587898999999993	70.068196999999998	56.645198000000001	55.809398000000002	0103000020E6100000010000000500000078962023A025514052B9895A9AE74B4078962023A0255140E9B81AD995524C40DC2BF3565D845140E9B81AD995524C40DC2BF3565D84514052B9895A9AE74B4078962023A025514052B9895A9AE74B40
23433	Орловка	6	57	657	69.492332000000005	69.502689000000004	55.959978999999997	55.947485	0103000020E610000001000000050000008EB1135E825F5140AC39403047F94B408EB1135E825F514063EC8497E0FA4B40C6C37B0E2C60514063EC8497E0FA4B40C6C37B0E2C605140AC39403047F94B408EB1135E825F5140AC39403047F94B40
24802	Опеновка	6	57	657	69.156829000000002	69.174840000000003	56.237411999999999	56.232874000000002	0103000020E610000001000000050000001F84807C094A51405B0BB3D0CE1D4C401F84807C094A5140C7D63384631E4C4017821C94304B5140C7D63384631E4C4017821C94304B51405B0BB3D0CE1D4C401F84807C094A51405B0BB3D0CE1D4C40
23158	Октябрьский	6	57	657	68.914490999999998	68.945941000000005	56.296379000000002	56.280301999999999	0103000020E61000000100000005000000205F4205873A51406F8099EFE0234C40205F4205873A5140501C40BFEF254C4084BC1E4C8A3C5140501C40BFEF254C4084BC1E4C8A3C51406F8099EFE0234C40205F4205873A51406F8099EFE0234C40
23635	Ожогино	6	57	657	68.755767000000006	68.776499999999999	56.068776	56.063394000000002	0103000020E6100000010000000500000059198D7C5E3051409E616A4B1D084C4059198D7C5E305140F65FE7A6CD084C4004560E2DB2315140F65FE7A6CD084C4004560E2DB23151409E616A4B1D084C4059198D7C5E3051409E616A4B1D084C40
23797	Новотравное	6	57	657	69.23227	69.257035999999999	55.937446999999999	55.915210000000002	0103000020E61000000100000005000000E275FD82DD4E5140707CED9925F54B40E275FD82DD4E5140DD5D6743FEF74B4042791F4773505140DD5D6743FEF74B4042791F4773505140707CED9925F54B40E275FD82DD4E5140707CED9925F54B40
23717	Новолокти	6	57	657	69.040514999999999	69.068156000000002	56.028067999999998	56.007739999999998	0103000020E61000000100000005000000D6FF39CC974251407E6FD39FFD004C40D6FF39CC97425140350873BB97034C40ADC1FBAA5C445140350873BB97034C40ADC1FBAA5C4451407E6FD39FFD004C40D6FF39CC974251407E6FD39FFD004C40
23302	Новокировский	6	57	657	68.947395999999998	68.962981999999997	56.337017000000003	56.327030999999998	0103000020E610000001000000050000001E17D522A23C51409BE3DC26DC294C401E17D522A23C51401899805F232B4C40BF28417FA13D51401899805F232B4C40BF28417FA13D51409BE3DC26DC294C401E17D522A23C51409BE3DC26DC294C40
23075	Нерпино	6	57	657	69.216316000000006	69.238324000000006	56.108944000000001	56.102387999999998	0103000020E610000001000000050000008066101FD84D51405DC0CB0C1B0D4C408066101FD84D5140378C82E0F10D4C4086764EB3404F5140378C82E0F10D4C4086764EB3404F51405DC0CB0C1B0D4C408066101FD84D51405DC0CB0C1B0D4C40
22895	Мизоново	6	57	657	69.057332000000002	69.105383000000003	56.081391000000004	56.062710000000003	0103000020E61000000100000005000000EA40D653AB435140EB909BE106084C40EA40D653AB435140299831056B0A4C407BA35698BE465140299831056B0A4C407BA35698BE465140EB909BE106084C40EA40D653AB435140EB909BE106084C40
22833	Мезенка	6	57	657	69.410729000000003	69.424806000000004	56.140022999999999	56.127893	0103000020E6100000010000000500000034A14962495A514094313ECC5E104C4034A14962495A51400AD80E46EC114C4041498105305B51400AD80E46EC114C4041498105305B514094313ECC5E104C4034A14962495A514094313ECC5E104C40
23017	Малоудалово	6	57	657	69.355284999999995	69.375119999999995	56.160044999999997	56.153618000000002	0103000020E6100000010000000500000099F04BFDBC565140D9092FC1A9134C4099F04BFDBC565140B471C45A7C144C40D50451F701585140B471C45A7C144C40D50451F701585140D9092FC1A9134C4099F04BFDBC565140D9092FC1A9134C40
24315	Макарова	6	57	657	69.838417000000007	69.854118999999997	56.171191999999998	56.165328000000002	0103000020E6100000010000000500000045DAC69FA87551407A8EC87729154C4045DAC69FA87551401DAB949EE9154C401AF9BCE2A97651401DAB949EE9154C401AF9BCE2A97651407A8EC87729154C4045DAC69FA87551407A8EC87729154C40
23771	Локти	6	57	657	68.964302000000004	68.981809999999996	55.992085000000003	55.980074000000002	0103000020E61000000100000005000000EA5DBC1FB73D514078D4981073FD4B40EA5DBC1FB73D514014ED2AA4FCFE4B40B0389CF9D53E514014ED2AA4FCFE4B40B0389CF9D53E514078D4981073FD4B40EA5DBC1FB73D514078D4981073FD4B40
24616	Лозовое	6	57	657	69.474518000000003	69.482010000000002	56.163549000000003	56.159413000000001	0103000020E6100000010000000500000041D7BE805E5E514054C72AA567144C4041D7BE805E5E51409225732CEF144C4014967840D95E51409225732CEF144C4014967840D95E514054C72AA567144C4041D7BE805E5E514054C72AA567144C40
23472	Лариха	6	57	657	69.325496999999999	69.355069	55.874353999999997	55.864201999999999	0103000020E610000001000000050000008D7C5EF1D4545140A391CF2B9EEE4B408D7C5EF1D45451403A90F5D4EAEF4B40B3B45373B95651403A90F5D4EAEF4B40B3B45373B9565140A391CF2B9EEE4B408D7C5EF1D4545140A391CF2B9EEE4B40
24704	Кукарцева	6	57	657	68.984164000000007	69.005094999999997	56.237896999999997	56.229866999999999	0103000020E61000000100000005000000A379008BFC3E5140FEB627486C1D4C40A379008BFC3E51408368AD68731E4C40E197FA79534051408368AD68731E4C40E197FA7953405140FEB627486C1D4C40A379008BFC3E5140FEB627486C1D4C40
23252	Крутые Озерки	6	57	657	68.989563000000004	69.009326000000001	56.278162999999999	56.269886	0103000020E610000001000000050000003A950C00553F5140FAD2DB9F8B224C403A950C00553F514087FA5DD89A234C40294014CC9840514087FA5DD89A234C40294014CC98405140FAD2DB9F8B224C403A950C00553F5140FAD2DB9F8B224C40
24351	Кошкарагай	6	57	657	69.802852999999999	69.823549999999997	56.120638	56.115569000000001	0103000020E61000000100000005000000B69F8CF16173514039B709F7CA0E4C40B69F8CF161735140D253E410710F4C40BB270F0BB5745140D253E410710F4C40BB270F0BB574514039B709F7CA0E4C40B69F8CF16173514039B709F7CA0E4C40
23327	Клепиково	6	57	657	69.442753999999994	69.457262	55.971904000000002	55.955891999999999	0103000020E61000000100000005000000158BDF14565C5140074147AB5AFA4B40158BDF14565C5140016DAB5967FC4B4007EDD5C7435D5140016DAB5967FC4B4007EDD5C7435D5140074147AB5AFA4B40158BDF14565C5140074147AB5AFA4B40
23204	Карасуль	6	57	657	68.915325999999993	68.941744999999997	56.313738000000001	56.299025999999998	0103000020E610000001000000050000006CCB80B3943A5140AC53E57B46264C406CCB80B3943A514098C1189128284C40FA0AD28C453C514098C1189128284C40FA0AD28C453C5140AC53E57B46264C406CCB80B3943A5140AC53E57B46264C40
24194	Казанка	6	57	657	69.738344999999995	69.756715	56.378833	56.373185999999997	0103000020E61000000100000005000000910A630B416F51409BA9108FC42F4C40910A630B416F5140A2D288997D304C402159C0046E705140A2D288997D304C402159C0046E7051409BA9108FC42F4C40910A630B416F51409BA9108FC42F4C40
4461	Ишим	6	57	657	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
24552	Зырянка	6	57	657	69.483986999999999	69.512148999999994	56.138753999999999	56.131695999999998	0103000020E610000001000000050000001B2C9CA4F95E5140CB811E6ADB104C401B2C9CA4F95E51403718EAB0C2114C40766B990CC76051403718EAB0C2114C40766B990CC7605140CB811E6ADB104C401B2C9CA4F95E5140CB811E6ADB104C40
24061	Заозерный	6	57	657	69.495467000000005	69.531400000000005	56.330216	56.319704000000002	0103000020E61000000100000005000000D34F38BBB55F51404033880FEC284C40D34F38BBB55F5140D74E9484442A4C400B46257502625140D74E9484442A4C400B462575026251404033880FEC284C40D34F38BBB55F51404033880FEC284C40
24777	Завьялово	6	57	657	69.212335999999993	69.230104999999995	56.177306000000002	56.171317000000002	0103000020E61000000100000005000000DCF0BBE9964D5140DA1F28B7ED154C40DCF0BBE9964D51403AB187F6B1164C405969520ABA4E51403AB187F6B1164C405969520ABA4E5140DA1F28B7ED154C40DCF0BBE9964D5140DA1F28B7ED154C40
22932	Ершово (Безруково)	6	57	657	69.289761999999996	69.316953999999996	56.183228	56.174314000000003	0103000020E61000000100000005000000E867EA758B525140139ED0EB4F164C40E867EA758B52514012DBDD0374174C4087156EF94854514012DBDD0374174C4087156EF948545140139ED0EB4F164C40E867EA758B525140139ED0EB4F164C40
22790	Десятова	6	57	657	68.896182999999994	68.918263999999994	56.268366	56.249761999999997	0103000020E61000000100000005000000CB0EF10F5B3951404BE48233F81F4C40CB0EF10F5B395140DEAD2CD159224C4006465ED6C43A5140DEAD2CD159224C4006465ED6C43A51404BE48233F81F4C40CB0EF10F5B3951404BE48233F81F4C40
25058	Голдобино	6	57	657	69.996700000000004	70.014729000000003	56.074643999999999	56.063484000000003	0103000020E6100000010000000500000016FBCBEEC97F5140DEE8633E20084C4016FBCBEEC97F5140DB6B41EF8D094C406153E751F1805140DB6B41EF8D094C406153E751F1805140DEE8633E20084C4016FBCBEEC97F5140DEE8633E20084C40
22760	Гагарино	6	57	657	69.360063999999994	69.398736	56.012124	56.000593000000002	0103000020E61000000100000005000000E21DE0490B575140A3CD716E13004C40E21DE0490B57514094BF7B478D014C4039EFFFE38459514094BF7B478D014C4039EFFFE384595140A3CD716E13004C40E21DE0490B575140A3CD716E13004C40
22720	Второпесьяново	6	57	657	69.113197999999997	69.144244	55.879899000000002	55.863090999999997	0103000020E610000001000000050000003FFED2A23E475140683C11C479EE4B403FFED2A23E4751403D64CA87A0F04B403BA92F4B3B4951403D64CA87A0F04B403BA92F4B3B495140683C11C479EE4B403FFED2A23E475140683C11C479EE4B40
61274	Воронина	6	57	657	69.422775000000001	69.437884999999994	55.903221000000002	55.898274999999998	0103000020E6100000010000000500000040A4DFBE0E5B51403EE8D9ACFAF24B4040A4DFBE0E5B5140BC07E8BE9CF34B402C9ACE4E065C5140BC07E8BE9CF34B402C9ACE4E065C51403EE8D9ACFAF24B4040A4DFBE0E5B51403EE8D9ACFAF24B40
23970	Ваньковка	6	57	657	69.367637000000002	69.381991999999997	56.092706999999997	56.086153000000003	0103000020E610000001000000050000002CF3565D87575140E5B9BE0F070B4C402CF3565D875751401D8EAED2DD0B4C405AD5928E725851401D8EAED2DD0B4C405AD5928E72585140E5B9BE0F070B4C402CF3565D87575140E5B9BE0F070B4C40
23882	Быкова	6	57	657	69.269656999999995	69.288154000000006	56.065458999999997	56.059835999999997	0103000020E61000000100000005000000CC086F0F42515140CD8FBFB4A8074C40CC086F0F425151404B1DE4F560084C408B8D791D715251404B1DE4F560084C408B8D791D71525140CD8FBFB4A8074C40CC086F0F42515140CD8FBFB4A8074C40
22621	Бутусово	6	57	657	69.186347999999995	69.206801999999996	56.427208999999998	56.418287999999997	0103000020E61000000100000005000000336B2920ED4B5140952710768A354C40336B2920ED4B514047C7D5C8AE364C40D5AF743E3C4D514047C7D5C8AE364C40D5AF743E3C4D5140952710768A354C40336B2920ED4B5140952710768A354C40
22537	Боровое	6	57	657	69.674232000000003	69.693365999999997	56.171337000000001	56.161313	0103000020E61000000100000005000000AB7AF99D266B5140B7B585E7A5144C40AB7AF99D266B514021CCED5EEE154C40228AC91B606C514021CCED5EEE154C40228AC91B606C5140B7B585E7A5144C40AB7AF99D266B5140B7B585E7A5144C40
22676	Борисовка	6	57	657	69.047162999999998	69.063539000000006	56.350861000000002	56.346032999999998	0103000020E6100000010000000500000033A5F5B7044351401B2B31CF4A2C4C4033A5F5B7044351408F386403E92C4C4051C1E105114451408F386403E92C4C4051C1E105114451401B2B31CF4A2C4C4033A5F5B7044351401B2B31CF4A2C4C40
22593	Большой Остров	6	57	657	69.608851999999999	69.629181000000003	56.113506999999998	56.106073000000002	0103000020E61000000100000005000000AB06616EF76651408BFED0CC930D4C40AB06616EF7665140FC6EBA65870E4C40EF90628044685140FC6EBA65870E4C40EF906280446851408BFED0CC930D4C40AB06616EF76651408BFED0CC930D4C40
24880	Большеудалово	6	57	657	69.353442999999999	69.370555999999993	56.178358000000003	56.171973999999999	0103000020E61000000100000005000000028063CF9E56514093E1783E03164C40028063CF9E565140707D586FD4164C408A558330B7575140707D586FD4164C408A558330B757514093E1783E03164C40028063CF9E56514093E1783E03164C40
24515	Бокаревка	6	57	657	69.635694000000001	69.643401999999995	56.212173999999997	56.208373999999999	0103000020E61000000100000005000000DC10E335AF68514019ABCDFFAB1A4C40DC10E335AF685140DF878384281B4C40950B957F2D695140DF878384281B4C40950B957F2D69514019ABCDFFAB1A4C40DC10E335AF68514019ABCDFFAB1A4C40
22439	Шорохово	6	57	1650	65.364906000000005	65.394721000000004	56.674816999999997	56.646845999999996	0103000020E610000001000000050000004F07B29E5A57504032C687D9CB524C404F07B29E5A57504075E4486760564C40D882DE1B4359504075E4486760564C40D882DE1B4359504032C687D9CB524C404F07B29E5A57504032C687D9CB524C40
21059	Турушево	6	57	1650	65.111581000000001	65.138844000000006	56.448051	56.438164	0103000020E61000000100000005000000B876A224244750406C2409C215384C40B876A2242447504055F833BC59394C40BCCFF1D1E248504055F833BC59394C40BCCFF1D1E24850406C2409C215384C40B876A224244750406C2409C215384C40
22283	Станичное	6	57	1650	65.415013999999999	65.428407000000007	56.347977999999998	56.331412999999998	0103000020E610000001000000050000007558E1968F5A5040103CBEBD6B2A4C407558E1968F5A50401EDD088B8A2C4C40299831056B5B50401EDD088B8A2C4C40299831056B5B5040103CBEBD6B2A4C407558E1968F5A5040103CBEBD6B2A4C40
22243	Солобоево	6	57	1650	65.362875000000003	65.398961	56.447727	56.433067999999999	0103000020E610000001000000050000004E62105839575040D978B0C56E374C404E62105839575040A2444B1E4F394C4049D8B79388595040A2444B1E4F394C4049D8B79388595040D978B0C56E374C404E62105839575040D978B0C56E374C40
61032	Слобода-Бешкиль	6	57	1650	65.823469000000003	65.859536000000006	56.537795000000003	56.528283999999999	0103000020E61000000100000005000000451152B7B3745040028063CF9E434C40451152B7B3745040E6797077D6444C40056F48A302775040E6797077D6444C40056F48A302775040028063CF9E434C40451152B7B3745040028063CF9E434C40
21146	Сизикова	6	57	1650	65.152158	65.164473000000001	56.482174999999998	56.477269	0103000020E61000000100000005000000C974E8F4BC49504083328D26173D4C40C974E8F4BC49504072F90FE9B73D4C40CD04C3B9864A504072F90FE9B73D4C40CD04C3B9864A504083328D26173D4C40C974E8F4BC49504083328D26173D4C40
21644	Решетникова	6	57	1650	65.127813000000003	65.141161999999994	56.626842000000003	56.621324999999999	0103000020E610000001000000050000003CC093162E485040F697DD93874F4C403CC093162E4850402FE1D05B3C504C40075C57CC084950402FE1D05B3C504C40075C57CC08495040F697DD93874F4C403CC093162E485040F697DD93874F4C40
55089	Рафайлово	6	57	1650	65.235637999999994	65.271102999999997	56.438397999999999	56.427487999999997	0103000020E6100000010000000500000078EC67B1144F50405AB741EDB7364C4078EC67B1144F5040DF50F86C1D384C403DB665C059515040DF50F86C1D384C403DB665C0595150405AB741EDB7364C4078EC67B1144F50405AB741EDB7364C40
21942	Рассвет	6	57	1650	65.720979999999997	65.747579000000002	56.55048	56.532662999999999	0103000020E610000001000000050000007C444C89246E504006651A4D2E444C407C444C89246E5040118DEE2076464C404A0B9755D86F5040118DEE2076464C404A0B9755D86F504006651A4D2E444C407C444C89246E504006651A4D2E444C40
21915	Онуфриево	6	57	1650	65.732325000000003	65.745225000000005	56.447887000000001	56.437393	0103000020E61000000100000005000000C442AD69DE6E5040EA3F6B7EFC374C40C442AD69DE6E5040DBA6785C54394C4058CA32C4B16F5040DBA6785C54394C4058CA32C4B16F5040EA3F6B7EFC374C40C442AD69DE6E5040EA3F6B7EFC374C40
21763	Новикова	6	57	1650	65.239052000000001	65.248402999999996	56.542138000000001	56.530290000000001	0103000020E61000000100000005000000C782C2A04C4F5040ABB2EF8AE0434C40C782C2A04C4F50409DF529C764454C409C4EB2D5E54F50409DF529C764454C409C4EB2D5E54F5040ABB2EF8AE0434C40C782C2A04C4F5040ABB2EF8AE0434C40
21820	Минино	6	57	1650	65.629306999999997	65.663083	56.431176000000001	56.422325999999998	0103000020E610000001000000050000003509DE9046685040102043C70E364C403509DE9046685040F96871C630374C4026E2ADF36F6A5040F96871C630374C4026E2ADF36F6A5040102043C70E364C403509DE9046685040102043C70E364C40
22402	Малыши	6	57	1650	65.419595000000001	65.426242999999999	56.470388	56.463997999999997	0103000020E610000001000000050000002BA4FCA4DA5A504067B45549643B4C402BA4FCA4DA5A504026378AAC353C4C408849B890475B504026378AAC353C4C408849B890475B504067B45549643B4C402BA4FCA4DA5A504067B45549643B4C40
21860	Лога	6	57	1650	65.600757999999999	65.614537999999996	56.440936000000001	56.433644999999999	0103000020E61000000100000005000000DDB3AED1726650407689EAAD81374C40DDB3AED17266504085D0419770384C408D0931975467504085D0419770384C408D093197546750407689EAAD81374C40DDB3AED1726650407689EAAD81374C40
21561	Кукушки	6	57	1650	65.457009999999997	65.476943000000006	56.635649000000001	56.618844000000003	0103000020E610000001000000050000007AFCDEA63F5D5040B5A9BA47364F4C407AFCDEA63F5D5040185E49F25C514C4098C3EE3B865E5040185E49F25C514C4098C3EE3B865E5040B5A9BA47364F4C407AFCDEA63F5D5040B5A9BA47364F4C40
22320	Красногорское	6	57	1650	65.555564000000004	65.572424999999996	56.494272000000002	56.482627000000001	0103000020E6100000010000000500000070B54E5C8E6350405395B6B8C63D4C4070B54E5C8E6350400DAA0D4E443F4C406B9A779CA26450400DAA0D4E443F4C406B9A779CA26450405395B6B8C63D4C4070B54E5C8E6350405395B6B8C63D4C40
21601	Красново	6	57	1650	65.168272999999999	65.179411999999999	56.608213999999997	56.590057999999999	0103000020E6100000010000000500000030F31DFCC44A5040205F4205874B4C4030F31DFCC44A5040137CD3F4D94D4C40A320787C7B4B5040137CD3F4D94D4C40A320787C7B4B5040205F4205874B4C4030F31DFCC44A5040205F4205874B4C40
21523	Коммунар	6	57	1650	65.518032000000005	65.555025000000001	56.572657	56.558228999999997	0103000020E610000001000000050000000492B06F27615040E256410C74474C400492B06F27615040A96917D34C494C4098DD938785635040A96917D34C494C4098DD938785635040E256410C74474C400492B06F27615040E256410C74474C40
21469	Кировский	6	57	1650	65.729101	65.749078999999995	56.722948000000002	56.711938000000004	0103000020E61000000100000005000000C79E3D97A96E5040CC63CDC8205B4C40C79E3D97A96E5040B45A608F895C4C40B4C70BE9F06F5040B45A608F895C4C40B4C70BE9F06F5040CC63CDC8205B4C40C79E3D97A96E5040CC63CDC8205B4C40
21319	Исетское	6	57	1650	65.301169999999999	65.350649000000004	56.501018999999999	56.465350000000001	0103000020E610000001000000050000005322895E46535040C898BB96903B4C405322895E465350405AD6FD6321404C4002D88008715650405AD6FD6321404C4002D8800871565040C898BB96903B4C405322895E46535040C898BB96903B4C40
22492	Зерновой	6	57	1650	65.396732999999998	65.407054000000002	56.609065999999999	56.602590999999997	0103000020E610000001000000050000009D0FCF126459504095EEAEB3214D4C409D0FCF1264595040828DEBDFF54D4C402F6D382C0D5A5040828DEBDFF54D4C402F6D382C0D5A504095EEAEB3214D4C409D0FCF126459504095EEAEB3214D4C40
21270	Денисово	6	57	1650	65.640347000000006	65.664430999999993	56.663169000000003	56.650216	0103000020E61000000100000005000000DFC5FB71FB68504000AB23473A534C40DFC5FB71FB6850404B5CC7B8E2544C40B5DC9909866A50404B5CC7B8E2544C40B5DC9909866A504000AB23473A534C40DFC5FB71FB68504000AB23473A534C40
21009	Гаева	6	57	1650	65.198924000000005	65.229331999999999	56.460456999999998	56.450459000000002	0103000020E61000000100000005000000EE98BA2BBB4C50402D98F8A3A8394C40EE98BA2BBB4C50406D1B4641F03A4C4048FB1F60AD4E50406D1B4641F03A4C4048FB1F60AD4E50402D98F8A3A8394C40EE98BA2BBB4C50402D98F8A3A8394C40
21227	Верхний Ингал	6	57	1650	65.783467000000002	65.803327999999993	56.439995000000003	56.434536000000001	0103000020E61000000100000005000000B29FC55224725040A3772AE09E374C40B29FC55224725040A7B393C151384C4082FDD7B969735040A7B393C151384C4082FDD7B969735040A3772AE09E374C40B29FC55224725040A3772AE09E374C40
21200	Верхнебешкиль	6	57	1650	65.515013999999994	65.533331000000004	56.525796999999997	56.513953999999998	0103000020E61000000100000005000000DBBE47FDF5605040FED2A23EC9414C40DBBE47FDF5605040DEAAEB504D434C405ABC581822625040DEAAEB504D434C405ABC581822625040FED2A23EC9414C40DBBE47FDF5605040FED2A23EC9414C40
22364	Ботники	6	57	1650	65.460001000000005	65.472829000000004	56.480778000000001	56.474803000000001	0103000020E6100000010000000500000026C808A8705D504077853E58C63C4C4026C808A8705D504072512D228A3D4C406DE690D4425E504072512D228A3D4C406DE690D4425E504077853E58C63C4C4026C808A8705D504077853E58C63C4C40
22110	Битюки	6	57	1650	65.321839999999995	65.335566999999998	56.395879999999998	56.384624000000002	0103000020E61000000100000005000000DBA2CC0699545040DCA0F65B3B314C40DBA2CC0699545040FB912232AC324C407AA702EE79555040FB912232AC324C407AA702EE79555040DCA0F65B3B314C40DBA2CC0699545040DCA0F65B3B314C40
20919	Бархатово	6	57	1650	65.200595000000007	65.236975999999999	56.476199999999999	56.470272999999999	0103000020E610000001000000050000006F2F698CD64C50408D98D9E7313C4C406F2F698CD64C5040772D211FF43C4C40F67B629D2A4F5040772D211FF43C4C40F67B629D2A4F50408D98D9E7313C4C406F2F698CD64C50408D98D9E7313C4C40
20906	Архангельское	6	57	1650	65.656363999999996	65.676593999999994	56.534579000000001	56.520777000000002	0103000020E61000000100000005000000649126DE016A504027C11BD2A8424C40649126DE016A50406F10AD156D444C40DEAAEB504D6B50406F10AD156D444C40DEAAEB504D6B504027C11BD2A8424C40649126DE016A504027C11BD2A8424C40
18522	Яковлево	6	57	1485	66.652648999999997	66.665558000000004	56.447349000000003	56.438352999999999	0103000020E6100000010000000500000018B14F00C5A950403F8D7BF31B384C4018B14F00C5A95040FC7266BB42394C40D6E5948098AA5040FC7266BB42394C40D6E5948098AA50403F8D7BF31B384C4018B14F00C5A950403F8D7BF31B384C40
20133	Щучье	6	57	1485	66.653313999999995	66.667767999999995	56.640822	56.632268000000003	0103000020E61000000100000005000000360186E5CFA9504057276728EE504C40360186E5CFA9504056478E7406524C402E54FEB5BCAA504056478E7406524C402E54FEB5BCAA504057276728EE504C40360186E5CFA9504057276728EE504C40
20368	Шиликуль	6	57	1485	66.187483999999998	66.200491	56.454428	56.442945999999999	0103000020E610000001000000050000007D21E4BCFF8B50406FF25B74B2384C407D21E4BCFF8B50407F315BB22A3A4C401C0934D8D48C50407F315BB22A3A4C401C0934D8D48C50406FF25B74B2384C407D21E4BCFF8B50406FF25B74B2384C40
19652	Шестаково	6	57	1485	66.955211000000006	66.981055999999995	56.700316000000001	56.688319999999997	0103000020E61000000100000005000000E371512D22BD50406397A8DE1A584C40E371512D22BD5040CA6E66F4A3594C40DAE21A9FC9BE5040CA6E66F4A3594C40DAE21A9FC9BE50406397A8DE1A584C40E371512D22BD50406397A8DE1A584C40
18654	Центральный	6	57	1485	66.596675000000005	66.617165999999997	56.322769000000001	56.316713999999997	0103000020E61000000100000005000000D0D556EC2FA65040B91798158A284C40D0D556EC2FA65040D1949D7E50294C40008DD2A57FA75040D1949D7E50294C40008DD2A57FA75040B91798158A284C40D0D556EC2FA65040B91798158A284C40
19920	Урожайный	6	57	1485	66.667237999999998	66.682276000000002	56.482125000000003	56.475538999999998	0103000020E6100000010000000500000080290307B4AA50407C7C4276DE3C4C4080290307B4AA5040C1CAA145B63D4C4020B6F468AAAB5040C1CAA145B63D4C4020B6F468AAAB50407C7C4276DE3C4C4080290307B4AA50407C7C4276DE3C4C40
20073	Тумашово	6	57	1485	66.743981000000005	66.771263000000005	56.625484999999998	56.616911999999999	0103000020E610000001000000050000001BF67B629DAF50404641F0F8F64E4C401BF67B629DAF5040BC9179E40F504C405A677C5F5CB15040BC9179E40F504C405A677C5F5CB150404641F0F8F64E4C401BF67B629DAF50404641F0F8F64E4C40
20356	Сунгурово	6	57	1485	66.372159999999994	66.383702999999997	56.485754	56.475166000000002	0103000020E6100000010000000500000047382D78D1975040E8154F3DD23C4C4047382D78D19750405AF3E32F2D3E4C40221807978E9850405AF3E32F2D3E4C40221807978E985040E8154F3DD23C4C4047382D78D1975040E8154F3DD23C4C40
19968	Степной	6	57	1485	66.731296999999998	66.743110000000001	56.469417999999997	56.461834000000003	0103000020E610000001000000050000006DAAEE91CDAE5040271763601D3B4C406DAAEE91CDAE5040AD1397E3153C4C4028D53E1D8FAF5040AD1397E3153C4C4028D53E1D8FAF5040271763601D3B4C406DAAEE91CDAE5040271763601D3B4C40
19401	Старая Заимка	6	57	1485	66.830911	66.85248	56.526929000000003	56.514093000000003	0103000020E61000000100000005000000BFB854A52DB55040200DA7CCCD414C40BFB854A52DB550403128D36872434C409F1F46088FB650403128D36872434C409F1F46088FB65040200DA7CCCD414C40BFB854A52DB55040200DA7CCCD414C40
19503	Сосновка	6	57	1485	66.911238999999995	66.937226999999993	56.547834999999999	56.534505000000003	0103000020E61000000100000005000000BEF561BD51BA50403546EBA86A444C40BEF561BD51BA5040554D10751F464C40677BF486FBBB5040554D10751F464C40677BF486FBBB50403546EBA86A444C40BEF561BD51BA50403546EBA86A444C40
20038	Семеново	6	57	1485	66.682123000000004	66.719637000000006	56.519342000000002	56.510973999999997	0103000020E610000001000000050000005D363AE7A7AB50409B8D959867414C405D363AE7A7AB504039B874CC79424C4076FF58880EAE504039B874CC79424C4076FF58880EAE50409B8D959867414C405D363AE7A7AB50409B8D959867414C40
20727	Сединкино	6	57	1485	66.880398999999997	66.893128000000004	56.398665000000001	56.385133000000003	0103000020E61000000100000005000000971B0C7558B8504021CEC3094C314C40971B0C7558B85040A987687407334C4015C9570229B95040A987687407334C4015C9570229B9504021CEC3094C314C40971B0C7558B8504021CEC3094C314C40
19854	Речной	6	57	1485	66.650448999999995	66.667013999999995	56.512121	56.504626000000002	0103000020E61000000100000005000000D1ADD7F4A0A950400C5BB39597404C40D1ADD7F4A0A95040234C512E8D414C4058FE7C5BB0AA5040234C512E8D414C4058FE7C5BB0AA50400C5BB39597404C40D1ADD7F4A0A950400C5BB39597404C40
20612	Пономарева	6	57	1485	66.397841999999997	66.407769000000002	56.538961999999998	56.531813999999997	0103000020E610000001000000050000006ABE4A3E7699504008C72C7B12444C406ABE4A3E76995040B4E4F1B4FC444C40A6D425E3189A5040B4E4F1B4FC444C40A6D425E3189A504008C72C7B12444C406ABE4A3E7699504008C72C7B12444C40
20689	Першино	6	57	1485	66.768154999999993	66.780156000000005	56.413860999999997	56.405225000000002	0103000020E6100000010000000500000091D0967329B15040C442AD69DE334C4091D0967329B15040800BB265F9344C40CE716E13EEB15040800BB265F9344C40CE716E13EEB15040C442AD69DE334C4091D0967329B15040C442AD69DE334C40
19743	Падун	6	57	1485	66.592686999999998	66.632006000000004	56.519286999999998	56.503557999999998	0103000020E61000000100000005000000EB707495EEA55040D0D1AA9674404C40EB707495EEA55040751E15FF77424C400D384BC972A85040751E15FF77424C400D384BC972A85040D0D1AA9674404C40EB707495EEA55040D0D1AA9674404C40
18759	Озерки	6	57	1485	66.522150999999994	66.529984999999996	56.436481999999998	56.432091999999997	0103000020E61000000100000005000000B72407EC6AA150407E6E68CA4E374C40B72407EC6AA1504076A565A4DE374C40B7973446EBA1504076A565A4DE374C40B7973446EBA150407E6E68CA4E374C40B72407EC6AA150407E6E68CA4E374C40
20221	Новолыбаево	6	57	1485	66.340575000000001	66.360579999999999	56.494385999999999	56.482945000000001	0103000020E6100000010000000500000074B515FBCB95504024624A24D13D4C4074B515FBCB955040D5CC5A0A483F4C40DEE522BE13975040D5CC5A0A483F4C40DEE522BE1397504024624A24D13D4C4074B515FBCB95504024624A24D13D4C40
61286	Новозаимская	6	57	1485	66.09599	67.314797999999996	56.967198000000003	56.158596000000003	0103000020E610000001000000050000008EAF3DB32486504062A3ACDF4C144C408EAF3DB324865040D960E124CD7B4C4028B682A625D45040D960E124CD7B4C4028B682A625D4504062A3ACDF4C144C408EAF3DB32486504062A3ACDF4C144C40
19049	Новая Заимка	6	57	1485	66.875539000000003	66.958749999999995	56.492930000000001	56.475513999999997	0103000020E61000000100000005000000D8D7BAD408B8504023658BA4DD3C4C40D8D7BAD408B85040D09B8A54183F4C408FC2F5285CBD5040D09B8A54183F4C408FC2F5285CBD504023658BA4DD3C4C40D8D7BAD408B8504023658BA4DD3C4C40
20474	Нижнеингал	6	57	1485	66.129515999999995	66.140097999999995	56.472907999999997	56.465389999999999	0103000020E61000000100000005000000C2137AFD4988504056F146E6913B4C40C2137AFD498850402502D53F883C4C400A0F9A5DF78850402502D53F883C4C400A0F9A5DF788504056F146E6913B4C40C2137AFD4988504056F146E6913B4C40
18731	Мичуринский	6	57	1485	66.556196999999997	66.572789	56.411451	56.403919999999999	0103000020E6100000010000000500000088484DBB98A35040A4198BA6B3334C4088484DBB98A350400874266DAA344C408CA03193A8A450400874266DAA344C408CA03193A8A45040A4198BA6B3334C4088484DBB98A35040A4198BA6B3334C40
19436	Марково	6	57	1485	66.782330000000002	66.800036000000006	56.525241000000001	56.514977000000002	0103000020E61000000100000005000000802BD9B111B250409A982EC4EA414C40802BD9B111B2504059C2DA183B434C40DAE731CA33B3504059C2DA183B434C40DAE731CA33B350409A982EC4EA414C40802BD9B111B250409A982EC4EA414C40
18610	Лесной	6	57	1485	66.450914999999995	66.464336000000003	56.286282999999997	56.278942000000001	0103000020E61000000100000005000000A79196CADB9C50408CBD175FB4234C40A79196CADB9C50404C33DDEBA4244C40C09657AEB79D50404C33DDEBA4244C40C09657AEB79D50408CBD175FB4234C40A79196CADB9C50408CBD175FB4234C40
19693	Лебедевка	6	57	1485	66.933553000000003	66.979555000000005	56.798532000000002	56.770401	0103000020E610000001000000050000004B051555BFBB504021E7FD7F9C624C404B051555BFBB50409D67EC4B36664C4088687407B1BE50409D67EC4B36664C4088687407B1BE504021E7FD7F9C624C404B051555BFBB504021E7FD7F9C624C40
52043	Красная	6	57	1485	66.694699999999997	66.704006000000007	56.335484999999998	56.323177999999999	0103000020E61000000100000005000000FF21FDF675AC5040B2648EE55D294C40FF21FDF675AC504037A6272CF12A4C40058C2E6F0EAD504037A6272CF12A4C40058C2E6F0EAD5040B2648EE55D294C40FF21FDF675AC5040B2648EE55D294C40
19554	Кошелева	6	57	1485	66.993515000000002	67.008481000000003	56.555739000000003	56.546633999999997	0103000020E610000001000000050000007845F0BF95BF5040DA70581AF8454C407845F0BF95BF50404E0E9F7422474C40CB68E4F38AC050404E0E9F7422474C40CB68E4F38AC05040DA70581AF8454C407845F0BF95BF5040DA70581AF8454C40
20500	Комсомольский	6	57	1485	66.589821000000001	66.602461000000005	56.543329	56.538133000000002	0103000020E610000001000000050000009E5F94A0BFA55040FEF2C98AE1444C409E5F94A0BFA55040F4FBFECD8B454C40640795B88EA65040F4FBFECD8B454C40640795B88EA65040FEF2C98AE1444C409E5F94A0BFA55040FEF2C98AE1444C40
18866	Комиссарово	6	57	1485	66.838340000000002	66.865110000000001	56.248235999999999	56.242074000000002	0103000020E610000001000000050000006FBBD05CA7B55040209BE447FC1E4C406FBBD05CA7B550404DD87E32C61F4C40535C55F65DB750404DD87E32C61F4C40535C55F65DB75040209BE447FC1E4C406FBBD05CA7B55040209BE447FC1E4C40
20251	Комарова	6	57	1485	66.331654	66.336855999999997	56.459577000000003	56.450752000000001	0103000020E610000001000000050000009BE5B2D139955040A54DD53DB2394C409BE5B2D139955040357F4C6BD33A4C4087DD770C8F955040357F4C6BD33A4C4087DD770C8F955040A54DD53DB2394C409BE5B2D139955040A54DD53DB2394C40
19615	Каменка	6	57	1485	66.827326999999997	66.844044999999994	56.673937000000002	56.666359	0103000020E610000001000000050000004206F2ECF2B45040983270404B554C404206F2ECF2B450403D484F9143564C408CD651D504B650403D484F9143564C408CD651D504B65040983270404B554C404206F2ECF2B45040983270404B554C40
17108	Заводоуковск	6	57	1485	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
18942	Дронова	6	57	1485	66.738671999999994	66.758920000000003	56.359026	56.351858999999997	0103000020E61000000100000005000000239EEC6646AF5040D1E638B7092D4C40239EEC6646AF5040F4346090F42D4C40F111312592B05040F4346090F42D4C40F111312592B05040D1E638B7092D4C40239EEC6646AF5040D1E638B7092D4C40
61276	Горюново	6	57	1485	66.564121	66.583650000000006	56.279451999999999	56.265892000000001	0103000020E61000000100000005000000287FF78E1AA450404F22C2BF08224C40287FF78E1AA45040A1664815C5234C40DE9387855AA55040A1664815C5234C40DE9387855AA550404F22C2BF08224C40287FF78E1AA450404F22C2BF08224C40
20589	Гилево	6	57	1485	66.420354000000003	66.444788000000003	56.525151999999999	56.514946999999999	0103000020E610000001000000050000008AAF7614E79A50402F1686C8E9414C408AAF7614E79A5040E9B6442E38434C40CF691668779C5040E9B6442E38434C40CF691668779C50402F1686C8E9414C408AAF7614E79A50402F1686C8E9414C40
19339	Боровинка	6	57	1485	67.024722999999994	67.060034999999999	56.638233999999997	56.619280000000003	0103000020E61000000100000005000000601DC70F95C1504090882991444F4C40601DC70F95C15040FE98D6A6B1514C4062670A9DD7C35040FE98D6A6B1514C4062670A9DD7C3504090882991444F4C40601DC70F95C1504090882991444F4C40
18437	Бигила	6	57	1485	66.646900000000002	66.665818999999999	56.410445000000003	56.395122999999998	0103000020E6100000010000000500000013F241CF66A95040DE72F56393324C4013F241CF66A9504043E7357689344C408C834BC79CAA504043E7357689344C408C834BC79CAA5040DE72F56393324C4013F241CF66A95040DE72F56393324C40
16300	Шулындино	6	57	1435	68.596396999999996	68.616258999999999	56.540480000000002	56.518706000000002	0103000020E61000000100000005000000AE9B525E2B265140971E4DF564424C40AE9B525E2B2651403012DA722E454C4067B796C9702751403012DA722E454C4067B796C970275140971E4DF564424C40AE9B525E2B265140971E4DF564424C40
16322	Черемшанка	6	57	1435	68.712971999999993	68.731306000000004	56.427453	56.413293000000003	0103000020E61000000100000005000000ADBD4F55A12D51403755F7C8E6344C40ADBD4F55A12D5140DEC9A7C7B6364C409757AEB7CD2E5140DEC9A7C7B6364C409757AEB7CD2E51403755F7C8E6344C40ADBD4F55A12D51403755F7C8E6344C40
17516	Усть-Ламенка	6	57	1435	68.049063000000004	68.091866999999993	56.513407999999998	56.489108000000002	0103000020E61000000100000005000000651C23D923035140221B48179B3E4C40651C23D9230351409CC0745AB7414C4039252026E10551409CC0745AB7414C4039252026E1055140221B48179B3E4C40651C23D923035140221B48179B3E4C40
17396	Средние Чирки	6	57	1435	68.290799000000007	68.308819	56.105877	56.095779999999998	0103000020E6100000010000000500000069AD68739C12514031CEDF84420C4C4069AD68739C1251400533A6608D0D4C408A58C4B0C31351400533A6608D0D4C408A58C4B0C313514031CEDF84420C4C4069AD68739C12514031CEDF84420C4C40
17313	Ражево	6	57	1435	68.373947000000001	68.412780999999995	56.159654000000003	56.146678000000001	0103000020E61000000100000005000000FDDB65BFEE17514077853E58C6124C40FDDB65BFEE1751407A56D28A6F144C4040DAFF006B1A51407A56D28A6F144C4040DAFF006B1A514077853E58C6124C40FDDB65BFEE17514077853E58C6124C40
16922	Оськина	6	57	1435	68.134231999999997	68.158090999999999	56.677022000000001	56.667200000000001	0103000020E61000000100000005000000E884D0419708514013F241CF66554C40E884D0419708514015562AA8A8564C40AFB2B6291E0A514015562AA8A8564C40AFB2B6291E0A514013F241CF66554C40E884D0419708514013F241CF66554C40
17617	Новая Хмелевка	6	57	1435	68.806881000000004	68.833929999999995	56.615490999999999	56.607733000000003	0103000020E61000000100000005000000E2B034F0A333514099D9E731CA4D4C40E2B034F0A3335140BDFDB968C84E4C40CF49EF1B5F355140BDFDB968C84E4C40CF49EF1B5F35514099D9E731CA4D4C40E2B034F0A333514099D9E731CA4D4C40
17012	Никольск	6	57	1435	68.064099999999996	68.074099000000004	56.648933999999997	56.633763000000002	0103000020E610000001000000050000001CEBE2361A0451401A355F251F514C401CEBE2361A04514098A1F14410534C40A56ABB09BE04514098A1F14410534C40A56ABB09BE0451401A355F251F514C401CEBE2361A0451401A355F251F514C40
17298	Медведево	6	57	1435	68.473139000000003	68.504301999999996	56.374158000000001	56.347209999999997	0103000020E6100000010000000500000094DDCCE8471E51400D6C9560712C4C4094DDCCE8471E5140B5C4CA68E42F4C40AC53E57B46205140B5C4CA68E42F4C40AC53E57B462051400D6C9560712C4C4094DDCCE8471E51400D6C9560712C4C40
17215	Малышенка	6	57	1435	68.579886000000002	68.604329000000007	56.625737000000001	56.607926999999997	0103000020E61000000100000005000000215A2BDA1C2551407DAD4B8DD04D4C40215A2BDA1C255140D672672618504C4090C18A53AD265140D672672618504C4090C18A53AD2651407DAD4B8DD04D4C40215A2BDA1C2551407DAD4B8DD04D4C40
17424	Лапушина	6	57	1435	68.149754999999999	68.169724000000002	56.178994000000003	56.170079999999999	0103000020E6100000010000000500000066DAFE959509514012DA722EC5154C4066DAFE959509514012178046E9164C402A560DC2DC0A514012178046E9164C402A560DC2DC0A514012DA722EC5154C4066DAFE959509514012DA722EC5154C40
17208	Ламенский	6	57	1435	67.975329000000002	68.002593000000005	56.438307999999999	56.421947000000003	0103000020E61000000100000005000000C97553CA6BFE50409AD2FA5B02364C40C97553CA6BFE50409FC9FE791A384C40B58CD47B2A0051409FC9FE791A384C40B58CD47B2A0051409AD2FA5B02364C40C97553CA6BFE50409AD2FA5B02364C40
17132	Королево	6	57	1435	68.478061999999994	68.511210000000005	56.559831000000003	56.546320999999999	0103000020E6100000010000000500000076DD5B91981E51401B0FB6D8ED454C4076DD5B91981E5140BC24CE8AA8474C40D8D825AAB7205140BC24CE8AA8474C40D8D825AAB72051401B0FB6D8ED454C4076DD5B91981E51401B0FB6D8ED454C40
17027	Земляная	6	57	1435	68.450924000000001	68.483344000000002	56.215632999999997	56.210397	0103000020E61000000100000005000000D13E56F0DB1C51409816F549EE1A4C40D13E56F0DB1C51401C78B5DC991B4C40F12DAC1BEF1E51401C78B5DC991B4C40F12DAC1BEF1E51409816F549EE1A4C40D13E56F0DB1C51409816F549EE1A4C40
16914	Евсино	6	57	1435	68.279641999999996	68.300869000000006	56.710431	56.699787000000001	0103000020E61000000100000005000000A2258FA7E51151403E95D39E92594C40A2258FA7E511514044882B67EF5A4C4056D80C704113514044882B67EF5A4C4056D80C70411351403E95D39E92594C40A2258FA7E51151403E95D39E92594C40
55079	Голышманово	6	57	1435	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
16408	Голышманово	6	57	1435	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
16218	Голышманово	6	57	1435	68.589848000000003	68.614525	56.474260999999998	56.463476	0103000020E610000001000000050000001B67D311C02551408E3D7B2E533B4C401B67D311C025514056629E95B43C4C40C364AA605427514056629E95B43C4C40C364AA60542751408E3D7B2E533B4C401B67D311C02551408E3D7B2E533B4C40
16200	Гладилово	6	57	1435	68.534161999999995	68.563374999999994	56.385596	56.366923999999997	0103000020E610000001000000050000000531D0B52F2251400A0F9A5DF72E4C400531D0B52F225140F5BBB0355B314C40931804560E245140F5BBB0355B314C40931804560E2451400A0F9A5DF72E4C400531D0B52F2251400A0F9A5DF72E4C40
16113	Боровлянка	6	57	1435	68.265646000000004	68.298426000000006	56.551388000000003	56.521889000000002	0103000020E610000001000000050000000C9414580011514032923D42CD424C400C9414580011514014B4C9E193464C40AC915D691913514014B4C9E193464C40AC915D691913514032923D42CD424C400C9414580011514032923D42CD424C40
16108	Бескозобово	6	57	1435	68.502540999999994	68.529579999999996	56.697414999999999	56.686574999999998	0103000020E610000001000000050000008BF9B9A12920514027A089B0E1574C408BF9B9A129205140B35E0CE544594C40672783A3E4215140B35E0CE544594C40672783A3E421514027A089B0E1574C408BF9B9A12920514027A089B0E1574C40
15630	Шешуки	6	57	1342	70.392775999999998	70.411326000000003	57.046612000000003	57.039810000000003	0103000020E61000000100000005000000D6A9F23D23995140E2067C7E18854C40D6A9F23D23995140F3CCCB61F7854C40A67F492A539A5140F3CCCB61F7854C40A67F492A539A5140E2067C7E18854C40D6A9F23D23995140E2067C7E18854C40
15937	Чуртан	6	57	1342	70.567642000000006	70.585564000000005	56.705444999999997	56.692210000000003	0103000020E6100000010000000500000082751C3F54A451406AFB57569A584C4082751C3F54A45140381092054C5A4C40C26D6DE179A55140381092054C5A4C40C26D6DE179A551406AFB57569A584C4082751C3F54A451406AFB57569A584C40
14793	Чебаклей	6	57	1342	70.555173999999994	70.574720999999997	56.781094000000003	56.770198999999998	0103000020E61000000100000005000000BA6587F887A35140B9347EE195624C40BA6587F887A35140098D60E3FA634C40C3D4963AC8A45140098D60E3FA634C40C3D4963AC8A45140B9347EE195624C40BA6587F887A35140B9347EE195624C40
15042	Усть-Барсук	6	57	1342	70.719061999999994	70.732151000000002	56.803342000000001	56.798053000000003	0103000020E61000000100000005000000F7729F1C05AE5140C3BCC79926664C40F7729F1C05AE51406AC020E9D3664C40F52EDE8FDBAE51406AC020E9D3664C40F52EDE8FDBAE5140C3BCC79926664C40F7729F1C05AE5140C3BCC79926664C40
15833	Староборовая	6	57	1342	70.742688000000001	70.753315000000001	57.082267999999999	57.075723000000004	0103000020E610000001000000050000006DC83F3388AF51400B47904AB1894C406DC83F3388AF5140F0C000C2878A4C4085251E5036B05140F0C000C2878A4C4085251E5036B051400B47904AB1894C406DC83F3388AF51400B47904AB1894C40
15729	Сартам	6	57	1342	70.713177999999999	70.738016999999999	56.883001999999998	56.866799	0103000020E61000000100000005000000828E56B5A4AD51404E9A0645F36E4C40828E56B5A4AD5140BB26A43506714C4017B9A7AB3BAF5140BB26A43506714C4017B9A7AB3BAF51404E9A0645F36E4C40828E56B5A4AD51404E9A0645F36E4C40
15623	Рябово	6	57	1342	70.333847000000006	70.361721000000003	57.035128	57.025170000000003	0103000020E6100000010000000500000089B7CEBF5D955140906B43C538834C4089B7CEBF5D955140429605137F844C40B151D66F26975140429605137F844C40B151D66F26975140906B43C538834C4089B7CEBF5D955140906B43C538834C40
15463	Поддубровное	6	57	1342	70.583848000000003	70.597645999999997	56.924491000000003	56.913888	0103000020E61000000100000005000000717500C45DA551407A1A3048FA744C40717500C45DA55140223999B855764C40742502D53FA65140223999B855764C40742502D53FA651407A1A3048FA744C40717500C45DA551407A1A3048FA744C40
15344	Озёрное	6	57	1342	71.246086000000005	71.275389000000004	56.809147000000003	56.793292000000001	0103000020E6100000010000000500000039807EDFBFCF5140D7169E978A654C4039807EDFBFCF51400954FF2092674C40672B2FF99FD151400954FF2092674C40672B2FF99FD15140D7169E978A654C4039807EDFBFCF5140D7169E978A654C40
15542	Одино	6	57	1342	70.589965000000007	70.602397999999994	56.984082999999998	56.967624999999998	0103000020E6100000010000000500000038328FFCC1A5514060E5D022DB7B4C4038328FFCC1A5514058C6866EF67D4C40404B57B08DA6514058C6866EF67D4C40404B57B08DA6514060E5D022DB7B4C4038328FFCC1A5514060E5D022DB7B4C40
15252	Нововяткино	6	57	1342	70.428745000000006	70.449972000000002	56.596446	56.588178999999997	0103000020E61000000100000005000000B554DE8E709B5140D4981073494B4C40B554DE8E709B51403EEAAF57584C4C4068075C57CC9C51403EEAAF57584C4C4068075C57CC9C5140D4981073494B4C40B554DE8E709B5140D4981073494B4C40
15555	Малышево	6	57	1342	70.665773999999999	70.678134999999997	56.997774	56.991855999999999	0103000020E61000000100000005000000BC218D0A9CAA5140B22B2D23F57E4C40BC218D0A9CAA51404966F50EB77F4C4078D1579066AB51404966F50EB77F4C4078D1579066AB5140B22B2D23F57E4C40BC218D0A9CAA5140B22B2D23F57E4C40
16000	Малахово	6	57	1342	70.378079999999997	70.392920000000004	56.691547999999997	56.682175000000001	0103000020E6100000010000000500000063D17476329851400C93A98251574C4063D17476329851409ECE15A584584C40707CED99259951409ECE15A584584C40707CED99259951400C93A98251574C4063D17476329851400C93A98251574C40
15141	Коточиги	6	57	1342	70.934757000000005	70.954977999999997	56.819823999999997	56.804968000000002	0103000020E61000000100000005000000412D060FD3BB5140CC29013109674C40412D060FD3BB5140EA3C2AFEEF684C4091990B5C1EBD5140EA3C2AFEEF684C4091990B5C1EBD5140CC29013109674C40412D060FD3BB5140CC29013109674C40
15331	Комиссаровка	6	57	1342	70.380450999999994	70.396243999999996	56.588611	56.582608	0103000020E61000000100000005000000C0AE264F59985140A93121E6924A4C40C0AE264F599851406E88F19A574B4C401E4FCB0F5C9951406E88F19A574B4C401E4FCB0F5C995140A93121E6924A4C40C0AE264F59985140A93121E6924A4C40
15060	Каргалы	6	57	1342	70.673553999999996	70.704410999999993	57.081994000000002	57.064898999999997	0103000020E61000000100000005000000C2853C821BAB51408445459C4E884C40C2853C821BAB5140EF3B86C77E8A4C4054FCDF1115AD5140EF3B86C77E8A4C4054FCDF1115AD51408445459C4E884C40C2853C821BAB51408445459C4E884C40
14881	Калинино	6	57	1342	70.822333	70.848213000000001	56.831530999999998	56.817675999999999	0103000020E61000000100000005000000FB5A971AA1B45140AF5C6F9BA9684C40FB5A971AA1B451401A4E999B6F6A4C40B1C22D1F49B651401A4E999B6F6A4C40B1C22D1F49B65140AF5C6F9BA9684C40FB5A971AA1B45140AF5C6F9BA9684C40
14481	Заборка	6	57	1342	70.734144999999998	70.752398999999997	56.625484999999998	56.616411999999997	0103000020E6100000010000000500000067614F3BFCAE5140546EA296E64E4C4067614F3BFCAE5140BC9179E40F504C40C2A2224E27B05140BC9179E40F504C40C2A2224E27B05140546EA296E64E4C4067614F3BFCAE5140546EA296E64E4C40
14860	Ермаки	6	57	1342	70.926196000000004	70.950485999999998	57.262813999999999	57.243251000000001	0103000020E61000000100000005000000E86B96CB46BB514012DC48D9229F4C40E86B96CB46BB514029779FE3A3A14C4093533BC3D4BC514029779FE3A3A14C4093533BC3D4BC514012DC48D9229F4C40E86B96CB46BB514012DC48D9229F4C40
16022	Доставалово	6	57	1342	70.572754000000003	70.584540000000004	56.732562999999999	56.721012000000002	0103000020E61000000100000005000000CEA96400A8A451400403081F4A5C4C40CEA96400A8A451403CA1D79FC45D4C400CCD751A69A551403CA1D79FC45D4C400CCD751A69A551400403081F4A5C4C40CEA96400A8A451400403081F4A5C4C40
15808	Долгушино	6	57	1342	70.658389999999997	70.674020999999996	56.911824000000003	56.903052000000002	0103000020E61000000100000005000000DC80CF0F23AA5140304B3B3597734C40DC80CF0F23AA51409DDA19A6B6744C404DF4F92823AB51409DDA19A6B6744C404DF4F92823AB5140304B3B3597734C40DC80CF0F23AA5140304B3B3597734C40
14583	Викулово	6	57	1342	70.577093000000005	70.629212999999993	56.832476999999997	56.794963000000003	0103000020E6100000010000000500000009707A17EFA45140D943FB58C1654C4009707A17EFA451400AD6389B8E6A4C40F44D9A0645A851400AD6389B8E6A4C40F44D9A0645A85140D943FB58C1654C4009707A17EFA45140D943FB58C1654C40
15240	Бородино	6	57	1342	71.139617999999999	71.173187999999996	56.812665000000003	56.807679	0103000020E61000000100000005000000B5FB5580EFC851403F55850662674C40B5FB5580EFC851404BCD1E6805684C40D1031F8315CB51404BCD1E6805684C40D1031F8315CB51403F55850662674C40B5FB5580EFC851403F55850662674C40
14955	Борки	6	57	1342	70.713645	70.730722	56.848030000000001	56.841231000000001	0103000020E610000001000000050000000DFD135CACAD5140D1B01875AD6B4C400DFD135CACAD514071033E3F8C6C4C40EF1D3526C4AE514071033E3F8C6C4C40EF1D3526C4AE5140D1B01875AD6B4C400DFD135CACAD5140D1B01875AD6B4C40
14561	Боково	6	57	1342	70.24512	70.283028999999999	56.807850999999999	56.800896999999999	0103000020E610000001000000050000001DE6CB0BB08F5140753BFBCA83664C401DE6CB0BB08F51403C855CA967674C4074B4AA251D9251403C855CA967674C4074B4AA251D925140753BFBCA83664C401DE6CB0BB08F5140753BFBCA83664C40
14485	Березино	6	57	1342	70.441833000000003	70.459287000000003	56.820104000000001	56.812547000000002	0103000020E61000000100000005000000CA52EBFD469C514041BB438A01684C40CA52EBFD469C5140CEA8F92AF9684C40971E4DF5649D5140CEA8F92AF9684C40971E4DF5649D514041BB438A01684C40CA52EBFD469C514041BB438A01684C40
14386	Балаганы	6	57	1342	70.629698000000005	70.653655999999998	56.665202000000001	56.650556999999999	0103000020E61000000100000005000000D316D7F84CA851408997A77345534C40D316D7F84CA85140ED9DD15625554C4063B5F97FD5A95140ED9DD15625554C4063B5F97FD5A951408997A77345534C40D316D7F84CA851408997A77345534C40
15166	Базариха	6	57	1342	71.066835999999995	71.088063000000005	56.797038000000001	56.786833000000001	0103000020E61000000100000005000000828C800A47C45140F03499F1B6644C40828C800A47C45140AAD5575705664C40363FFED2A2C55140AAD5575705664C40363FFED2A2C55140F03499F1B6644C40828C800A47C45140F03499F1B6644C40
15442	Ачимово	6	57	1342	71.326403999999997	71.359928999999994	56.806125999999999	56.797960000000003	0103000020E6100000010000000500000026529ACDE3D4514012C2A38D23664C4026529ACDE3D45140473A03232F674C4072F8A41309D75140473A03232F674C4072F8A41309D7514012C2A38D23664C4026529ACDE3D4514012C2A38D23664C40
13082	Юрмы	6	57	1123	68.087554999999995	68.110894000000002	57.388216	57.378430999999999	0103000020E610000001000000050000007B6649809A0551407365506D70B04C407B6649809A05514058E4D70FB1B14C40A6D425E31807514058E4D70FB1B14C40A6D425E3180751407365506D70B04C407B6649809A0551407365506D70B04C40
12968	Шишкина	6	57	1123	68.69408	68.714472000000001	57.518892999999998	57.499127999999999	0103000020E61000000100000005000000B13385CE6B2C51404A42226DE3BF4C40B13385CE6B2C5140C98FF8156BC24C40187AC4E8B92D5140C98FF8156BC24C40187AC4E8B92D51404A42226DE3BF4C40B13385CE6B2C51404A42226DE3BF4C40
13063	Шестовое	6	57	1123	68.232984000000002	68.273938000000001	57.452264	57.442428	0103000020E61000000100000005000000711FB935E90E5140D76A0F7BA1B84C40711FB935E90E51403E9468C9E3B94C406DC83F33881151403E9468C9E3B94C406DC83F3388115140D76A0F7BA1B84C40711FB935E90E5140D76A0F7BA1B84C40
12636	Черное	6	57	1123	69.14958	69.185772999999998	57.664707	57.636494999999996	0103000020E61000000100000005000000AF08FEB792495140A4880CAB78D14C40AF08FEB7924951400D36751E15D54C40B5DE6FB4E34B51400D36751E15D54C40B5DE6FB4E34B5140A4880CAB78D14C40AF08FEB792495140A4880CAB78D14C40
14101	Фатеево	6	57	1123	69.304961000000006	69.323215000000005	58.049840000000003	58.043039	0103000020E610000001000000050000008D63247B84535140EDB94C4D82054D408D63247B845351402E04392861064D40E8A4F78DAF5451402E04392861064D40E8A4F78DAF545140EDB94C4D82054D408D63247B84535140EDB94C4D82054D40
12992	Ушаково	6	57	1123	68.387422000000001	68.434466999999998	57.487958999999996	57.475166999999999	0103000020E610000001000000050000000FF0A485CB185140B891B245D2BC4C400FF0A485CB185140F964C57075BE4C403D0CAD4ECE1B5140F964C57075BE4C403D0CAD4ECE1B5140B891B245D2BC4C400FF0A485CB185140B891B245D2BC4C40
13346	Тукуз	6	57	1123	69.750157000000002	69.782595999999998	57.658920000000002	57.641288000000003	0103000020E6100000010000000500000064778192027051409CA8A5B915D24C4064778192027051401557957D57D44C40BF7E880D167251401557957D57D44C40BF7E880D167251409CA8A5B915D24C4064778192027051409CA8A5B915D24C40
14003	Супра	6	57	1123	69.549464999999998	69.570988	58.007961000000002	57.987127000000001	0103000020E61000000100000005000000FC523F6F2A635140D2FF722D5AFE4C40FC523F6F2A6351405D52B5DD04014D40249A40118B6451405D52B5DD04014D40249A40118B645140D2FF722D5AFE4C40FC523F6F2A635140D2FF722D5AFE4C40
13254	Сулейменская	6	57	1123	69.578515999999993	69.595574999999997	57.811521999999997	57.803139999999999	0103000020E610000001000000050000009D0DF96706655140020EA14ACDE64C409D0DF9670665514004FEF0F3DFE74C402CD49AE61D66514004FEF0F3DFE74C402CD49AE61D665140020EA14ACDE64C409D0DF96706655140020EA14ACDE64C40
12434	Старый Погост	6	57	1123	68.923554999999993	68.939364999999995	57.950237000000001	57.946038999999999	0103000020E61000000100000005000000AA436E861B3B5140CADE52CE17F94C40AA436E861B3B51407E39B35DA1F94C407380608E1E3C51407E39B35DA1F94C407380608E1E3C5140CADE52CE17F94C40AA436E861B3B5140CADE52CE17F94C40
13713	Ренчики	6	57	1123	69.744399000000001	69.757649000000001	57.958747000000002	57.951946999999997	0103000020E61000000100000005000000350BB43BA46F51403D433866D9F94C40350BB43BA46F5140AE11C138B8FA4C4037363B527D705140AE11C138B8FA4C4037363B527D7051403D433866D9F94C40350BB43BA46F51403D433866D9F94C40
12839	Птицкое	6	57	1123	68.840864999999994	68.865702999999996	57.743417999999998	57.732508000000003	0103000020E6100000010000000500000077D66EBBD0355140790778D2C2DD4C4077D66EBBD0355140FDA02E5228DF4C4024438EAD67375140FDA02E5228DF4C4024438EAD67375140790778D2C2DD4C4077D66EBBD0355140790778D2C2DD4C40
12713	Первомайский	6	57	1123	69.043929000000006	69.072970999999995	57.410276000000003	57.399900000000002	0103000020E61000000100000005000000259694BBCF425140D0D556EC2FB34C40259694BBCF425140B72A89EC83B44C409CA38E8EAB445140B72A89EC83B44C409CA38E8EAB445140D0D556EC2FB34C40259694BBCF425140D0D556EC2FB34C40
10223	Новые Юрты	6	57	1123	69.130651999999998	69.141136000000003	57.225212999999997	57.214120999999999	0103000020E610000001000000050000000CCA349A5C48514083312251689B4C400CCA349A5C48514028D192C7D39C4C4073124A5F0849514028D192C7D39C4C4073124A5F0849514083312251689B4C400CCA349A5C48514083312251689B4C40
13365	Малый Уват	6	57	1123	69.961765	69.976271999999994	57.604171999999998	57.597130999999997	0103000020E61000000100000005000000FF5BC98E8D7D5140C136E2C96ECC4C40FF5BC98E8D7D51405794128255CD4C4008008E3D7B7E51405794128255CD4C4008008E3D7B7E5140C136E2C96ECC4C40FF5BC98E8D7D5140C136E2C96ECC4C40
12906	Малые Конданы	6	57	1123	68.691582999999994	68.700969999999998	57.695580999999997	57.687137999999997	0103000020E610000001000000050000000DDE57E5422C51405FEB5223F4D74C400DDE57E5422C5140075C57CC08D94C40895E46B1DC2C5140075C57CC08D94C40895E46B1DC2C51405FEB5223F4D74C400DDE57E5422C51405FEB5223F4D74C40
13914	Курья	6	57	1123	69.782955000000001	69.807406999999998	57.999000000000002	57.988939999999999	0103000020E6100000010000000500000057CF49EF1B72514066DAFE9595FE4C4057CF49EF1B7251401D5A643BDFFF4C40EFE3688EAC7351401D5A643BDFFF4C40EFE3688EAC73514066DAFE9595FE4C4057CF49EF1B72514066DAFE9595FE4C40
12282	Куларовское	6	57	1123	68.749919000000006	68.76634	57.984551000000003	57.976730000000003	0103000020E610000001000000050000008AE942ACFE2F5140D482177D05FD4C408AE942ACFE2F51403F1F65C405FE4C407767EDB60B3151403F1F65C405FE4C407767EDB60B315140D482177D05FD4C408AE942ACFE2F5140D482177D05FD4C40
12346	Куларово	6	57	1123	68.779824000000005	68.800970000000007	57.961741000000004	57.952114000000002	0103000020E61000000100000005000000B328ECA2E831514029081EDFDEF94C40B328ECA2E8315140761C3F541AFB4C40F0C4AC1743335140761C3F541AFB4C40F0C4AC174333514029081EDFDEF94C40B328ECA2E831514029081EDFDEF94C40
14297	Кобякская	6	57	1123	68.912837999999994	68.933740999999998	58.045153999999997	58.033285999999997	0103000020E61000000100000005000000F22213F06B3A514013B534B742044D40F22213F06B3A51404CA4349BC7054D40CC7B9C69C23B51404CA4349BC7054D40CC7B9C69C23B514013B534B742044D40F22213F06B3A514013B534B742044D40
13625	Касьяново	6	57	1123	69.136222000000004	69.161553999999995	58.022444	58.011313000000001	0103000020E61000000100000005000000BABF7ADCB7485140848252B472014D40BABF7ADCB7485140E7FEEA71DF024D406EA296E6564A5140E7FEEA71DF024D406EA296E6564A5140848252B472014D40BABF7ADCB7485140848252B472014D40
13275	Казанское	6	57	1123	69.635459999999995	69.662059999999997	57.797106999999997	57.785814000000002	0103000020E61000000100000005000000A27A6B60AB685140965E9B8D95E44C40A27A6B60AB685140D234289A07E64C4058FFE7305F6A5140D234289A07E64C4058FFE7305F6A5140965E9B8D95E44C40A27A6B60AB685140965E9B8D95E44C40
14024	Иртыш	6	57	1123	69.469874000000004	69.501540000000006	58.046883000000001	58.035707000000002	0103000020E6100000010000000500000068CF656A125E5140809E060C92044D4068CF656A125E514083DE1B4300064D40B2683A3B1960514083DE1B4300064D40B2683A3B19605140809E060C92044D4068CF656A125E5140809E060C92044D40
14109	Инжура	6	57	1123	69.185278999999994	69.206738999999999	58.065196999999998	58.058678999999998	0103000020E61000000100000005000000AD68739CDB4B514022FB20CB82074D40AD68739CDB4B51400E66136058084D40B2F336363B4D51400E66136058084D40B2F336363B4D514022FB20CB82074D40AD68739CDB4B514022FB20CB82074D40
13151	Заречный	6	57	1123	69.117554999999996	69.144675000000007	57.888277000000002	57.871772	0103000020E61000000100000005000000CD1E680586475140C5C8923996EF4C40CD1E680586475140FE648C0FB3F14C402063EE5A42495140FE648C0FB3F14C402063EE5A42495140C5C8923996EF4C40CD1E680586475140C5C8923996EF4C40
13639	Дубровное	6	57	1123	69.404764	69.438505000000006	57.963703000000002	57.942025999999998	0103000020E6100000010000000500000048A643A7E7595140A8FDD64E94F84C4048A643A7E75951404F07B29E5AFB4C407B884677105C51404F07B29E5AFB4C407B884677105C5140A8FDD64E94F84C4048A643A7E7595140A8FDD64E94F84C40
13732	Второсалинская	6	57	1123	69.926353000000006	69.940708000000001	57.996791999999999	57.985185000000001	0103000020E610000001000000050000004CE3175E497B514040C1C58A1AFE4C404CE3175E497B51400C7558E196FF4C407AC5538F347C51400C7558E196FF4C407AC5538F347C514040C1C58A1AFE4C404CE3175E497B514040C1C58A1AFE4C40
14204	Второвагайское	6	57	1123	68.954033999999993	68.975297999999995	58.015155999999998	58.006307	0103000020E6100000010000000500000069519FE40E3D5140315EF3AACE004D4069519FE40E3D5140492BBEA1F0014D40AB764D486B3E5140492BBEA1F0014D40AB764D486B3E5140315EF3AACE004D4069519FE40E3D5140315EF3AACE004D40
12347	Вагай	6	57	1123	68.982915000000006	69.034452000000002	57.955199	57.914830000000002	0103000020E61000000100000005000000DDEF5014E83E514029B3412619F54C40DDEF5014E83E51400116F9F543FA4C4009522976344251400116F9F543FA4C40095229763442514029B3412619F54C40DDEF5014E83E514029B3412619F54C40
12798	Бушмина	6	57	1123	68.972251999999997	68.986562000000006	57.756371000000001	57.747385999999999	0103000020E610000001000000050000001EDE7360393E51407FBE2D58AADF4C401EDE7360393E51404852D2C3D0E04C407D5EF1D4233F51404852D2C3D0E04C407D5EF1D4233F51407FBE2D58AADF4C401EDE7360393E51407FBE2D58AADF4C40
13826	Большой Карагай	6	57	1123	70.228914000000003	70.255756000000005	57.962777000000003	57.941009000000001	0103000020E610000001000000050000002EE6E786A68E5140EF1EA0FB72F84C402EE6E786A68E5140A62BD8463CFB4C405FF0694E5E905140A62BD8463CFB4C405FF0694E5E905140EF1EA0FB72F84C402EE6E786A68E5140EF1EA0FB72F84C40
14194	Бегишево	6	57	1123	69.082907000000006	69.109757000000002	58.048034999999999	58.039613000000003	0103000020E61000000100000005000000026729594E4551408CBFED0912054D40026729594E4551401C08C90226064D4074603942064751401C08C90226064D4074603942064751408CBFED0912054D40026729594E4551408CBFED0912054D40
11373	Шабурова	6	57	1146	68.247815000000003	68.262951000000001	55.950271999999998	55.939287	0103000020E61000000100000005000000541D7233DC0F51406B47718E3AF84B40541D7233DC0F5140FA264D83A2F94B40D55C6E30D4105140FA264D83A2F94B40D55C6E30D41051406B47718E3AF84B40541D7233DC0F51406B47718E3AF84B40
12238	Старорямова	6	57	1146	68.214146	68.237682000000007	55.694626999999997	55.683228999999997	0103000020E610000001000000050000006EA46C91B40D5140E256410C74D74B406EA46C91B40D514094F59B89E9D84B404436902E360F514094F59B89E9D84B404436902E360F5140E256410C74D74B406EA46C91B40D5140E256410C74D74B40
11280	Полозаозерье	6	57	1146	68.279129999999995	68.303518999999994	55.890300000000003	55.873869999999997	0103000020E6100000010000000500000047551344DD1151404E7ADFF8DAEF4B4047551344DD1151407DD0B359F5F14B40BCADF4DA6C1351407DD0B359F5F14B40BCADF4DA6C1351404E7ADFF8DAEF4B4047551344DD1151404E7ADFF8DAEF4B40
11579	Пеганово	6	57	1146	68.671774999999997	68.716528999999994	55.870601999999998	55.857335999999997	0103000020E610000001000000050000004ED1915CFE2A51407BD7A02FBDED4B404ED1915CFE2A514085EAE6E26FEF4B40AD68739CDB2D514085EAE6E26FEF4B40AD68739CDB2D51407BD7A02FBDED4B404ED1915CFE2A51407BD7A02FBDED4B40
11657	Останино	6	57	1146	68.808920999999998	68.821478999999997	55.880595999999997	55.876480999999998	0103000020E610000001000000050000000C03965CC53351405E48878730F04B400C03965CC5335140847EA65EB7F04B4073D6A71C93345140847EA65EB7F04B4073D6A71C933451405E48878730F04B400C03965CC53351405E48878730F04B40
11678	Окунево	6	57	1146	68.676320000000004	68.709925999999996	55.722259000000001	55.71266	0103000020E610000001000000050000005E68AED3482B51406C95607138DB4B405E68AED3482B5140EF1EA0FB72DC4B402025766D6F2D5140EF1EA0FB72DC4B402025766D6F2D51406C95607138DB4B405E68AED3482B51406C95607138DB4B40
11765	Одышка	6	57	1146	68.835475000000002	68.851168000000001	55.721508	55.712983999999999	0103000020E610000001000000050000000A68226C783551401F49490F43DB4B400A68226C78355140B4E6C75F5ADC4B40B6D9588979365140B4E6C75F5ADC4B40B6D95889793651401F49490F43DB4B400A68226C783551401F49490F43DB4B40
11489	Мелехино	6	57	1146	68.563860000000005	68.589408000000006	56.055086000000003	56.047665000000002	0103000020E6100000010000000500000072E1404816245140F91400E319064C4072E1404816245140D63BDC0E0D074C400D0055DCB8255140D63BDC0E0D074C400D0055DCB8255140F91400E319064C4072E1404816245140F91400E319064C40
11466	Луговая	6	57	1146	68.247366	68.253204999999994	56.026784999999997	56.014145999999997	0103000020E610000001000000050000001C0934D8D40F514042AF3F89CF014C401C0934D8D40F5140FD82DDB06D034C40C18BBE8234105140FD82DDB06D034C40C18BBE823410514042AF3F89CF014C401C0934D8D40F514042AF3F89CF014C40
11191	Кутырева	6	57	1146	68.167128000000005	68.179659999999998	55.895857999999997	55.883716999999997	0103000020E61000000100000005000000BD8FA339B20A5140A9F57EA31DF14B40BD8FA339B20A514013EE9579ABF24B408F19A88C7F0B514013EE9579ABF24B408F19A88C7F0B5140A9F57EA31DF14B40BD8FA339B20A5140A9F57EA31DF14B40
11843	Карькова	6	57	1146	68.672456999999994	68.687270999999996	55.785321000000003	55.780774999999998	0103000020E61000000100000005000000D7BD1589092B51406744696FF0E34B40D7BD1589092B514057EE056685E44B404F1F813FFC2B514057EE056685E44B404F1F813FFC2B51406744696FF0E34B40D7BD1589092B51406744696FF0E34B40
11287	Истошино	6	57	1146	68.220174	68.253141999999997	55.961319000000003	55.953301000000003	0103000020E610000001000000050000007D5BB054170E51403F1F65C405FA4B407D5BB054170E5140000341800CFB4B409ECF807A33105140000341800CFB4B409ECF807A331051403F1F65C405FA4B407D5BB054170E51403F1F65C405FA4B40
11942	Зарослое	6	57	1146	68.597807000000003	68.623283999999998	55.483204000000001	55.474618	0103000020E6100000010000000500000079944A7842265140E50B5A48C0BC4B4079944A7842265140F0A5F0A0D9BD4B40AF0793E2E3275140F0A5F0A0D9BD4B40AF0793E2E3275140E50B5A48C0BC4B4079944A7842265140E50B5A48C0BC4B40
10774	Гагарина	6	57	1146	68.233693000000002	68.259223000000006	55.795864000000002	55.791051000000003	0103000020E6100000010000000500000077137CD3F40E5140EB3BBF2841E54B4077137CD3F40E514029081EDFDEE54B40BFD7101C9710514029081EDFDEE54B40BFD7101C97105140EB3BBF2841E54B4077137CD3F40E5140EB3BBF2841E54B40
12142	Воробьево	6	57	1146	68.223291000000003	68.233873000000003	55.647385999999997	55.636473000000002	0103000020E610000001000000050000006F9F55664A0E5140BDE47FF277D14B406F9F55664A0E5140B2F1608BDDD24B40B79A75C6F70E5140B2F1608BDDD24B40B79A75C6F70E5140BDE47FF277D14B406F9F55664A0E5140BDE47FF277D14B40
11398	Босоногова	6	57	1146	68.244410000000002	68.270668000000001	55.978997	55.969925000000003	0103000020E610000001000000050000002F34D769A40F514052499D8026FC4B402F34D769A40F5140E9F010C64FFD4B40B804E09F52115140E9F010C64FFD4B40B804E09F5211514052499D8026FC4B402F34D769A40F514052499D8026FC4B40
10823	Бердюжье	6	57	1146	68.286980999999997	68.335311000000004	55.819960000000002	55.788555000000002	0103000020E61000000100000005000000B2648EE55D125140740CC85EEFE44B40B2648EE55D1251409B030473F4E84B404DBF44BC751551409B030473F4E84B404DBF44BC75155140740CC85EEFE44B40B2648EE55D125140740CC85EEFE44B40
10738	Юрминка	6	57	1065	68.609889999999993	68.630093000000002	56.776975999999998	56.754204000000001	0103000020E61000000100000005000000130A1170082751409641B5C189604C40130A11700827514071E316F373634C40111C97715328514071E316F373634C40111C9771532851409641B5C189604C40130A1170082751409641B5C189604C40
61283	Усть-Лотовка	6	57	1065	69.349660999999998	69.365589	56.968798	56.961649000000001	0103000020E61000000100000005000000F2EB87D860565140959D7E50177B4C40F2EB87D8605651401137A792017C4C40C0B167CF655751401137A792017C4C40C0B167CF65575140959D7E50177B4C40F2EB87D860565140959D7E50177B4C40
10628	Сорочкино	6	57	1065	68.835815999999994	68.861553000000001	56.986516000000002	56.972340000000003	0103000020E610000001000000050000004E5E64027E355140DC4B1AA3757C4C404E5E64027E355140897D0228467E4C4053B131AF23375140897D0228467E4C4053B131AF23375140DC4B1AA3757C4C404E5E64027E355140DC4B1AA3757C4C40
9702	Смородиновка	6	57	1065	68.652298999999999	68.685779999999994	56.792661000000003	56.783278000000003	0103000020E61000000100000005000000AA0D4E44BF29514091D6187442644C40AA0D4E44BF29514047E867EA75654C400E10CCD1E32B514047E867EA75654C400E10CCD1E32B514091D6187442644C40AA0D4E44BF29514091D6187442644C40
10472	Слободчики	6	57	1065	68.715298000000004	68.741331000000002	56.939013000000003	56.928145000000001	0103000020E610000001000000050000003B394371C72D514014799274CD764C403B394371C72D51406AC2F69331784C40B42094F7712F51406AC2F69331784C40B42094F7712F514014799274CD764C403B394371C72D514014799274CD764C40
10422	Русаково	6	57	1065	68.880435000000006	68.908670000000001	56.994160999999998	56.974812999999997	0103000020E610000001000000050000003ED00A0C593851409A5B21ACC67C4C403ED00A0C59385140B5FAEAAA407F4C40CE3637A6273A5140B5FAEAAA407F4C40CE3637A6273A51409A5B21ACC67C4C403ED00A0C593851409A5B21ACC67C4C40
10009	Овсово	6	57	1065	69.112937000000002	69.127840000000006	56.866715999999997	56.854531999999999	0103000020E6100000010000000500000089601C5C3A47514057B1F84D616D4C4089601C5C3A475140C075C58CF06E4C40B9C7D2872E485140C075C58CF06E4C40B9C7D2872E48514057B1F84D616D4C4089601C5C3A47514057B1F84D616D4C40
10312	Новоуфимская	6	57	1065	68.979294999999993	68.995806000000002	57.124603999999998	57.117137	0103000020E61000000100000005000000B988EFC4AC3E514066136058FE8E4C40B988EFC4AC3E5140B3791C06F38F4C4047CA1649BB3F5140B3791C06F38F4C4047CA1649BB3F514066136058FE8E4C40B988EFC4AC3E514066136058FE8E4C40
10172	Новопетрово	6	57	1065	69.124166000000002	69.148987000000005	57.192591	57.185070000000003	0103000020E610000001000000050000009C51F355F247514041BCAE5FB0974C409C51F355F2475140814067D2A6984C40DE21C50089495140814067D2A6984C40DE21C5008949514041BCAE5FB0974C409C51F355F247514041BCAE5FB0974C40
10090	Новоберезовка	6	57	1065	69.356613999999993	69.391926999999995	57.123632000000001	57.086910000000003	0103000020E61000000100000005000000EDD286C3D256514002D9EBDD1F8B4C40EDD286C3D25651409A5E622CD38F4C40D7DAFB54155951409A5E622CD38F4C40D7DAFB541559514002D9EBDD1F8B4C40EDD286C3D256514002D9EBDD1F8B4C40
10660	Новоаптула	6	57	1065	68.914508999999995	68.940235999999999	57.067022999999999	57.040990000000001	0103000020E6100000010000000500000073B9C150873A514045BB0A293F854C4073B9C150873A5140378AAC3594884C4066A19DD32C3C5140378AAC3594884C4066A19DD32C3C514045BB0A293F854C4073B9C150873A514045BB0A293F854C40
10549	Николаевка	6	57	1065	68.865460999999996	68.888305000000003	56.875089000000003	56.869760999999997	0103000020E61000000100000005000000A9BD88B6633751400A2B1554546F4C40A9BD88B663375140700B96EA02704C40E4F736FDD9385140700B96EA02704C40E4F736FDD93851400A2B1554546F4C40A9BD88B6633751400A2B1554546F4C40
9908	Малиновка	6	57	1065	68.870858999999996	68.898392999999999	57.157505	57.14087	0103000020E61000000100000005000000581B6327BC375140677E350708924C40581B6327BC3751406EFAB31F29944C40247D5A457F3951406EFAB31F29944C40247D5A457F395140677E350708924C40581B6327BC375140677E350708924C40
9779	Кротово	6	57	1065	69.258069000000006	69.294342999999998	56.924554000000001	56.904663999999997	0103000020E6100000010000000500000022C7D633845051402CEFAA07CC734C4022C7D6338450514068B114C957764C409EB30584D652514068B114C957764C409EB30584D65251402CEFAA07CC734C4022C7D633845051402CEFAA07CC734C40
9671	Кармацкая	6	57	1065	68.635671000000002	68.662701999999996	56.747176000000003	56.735491000000003	0103000020E6100000010000000500000000016BD5AE2851404DC0AF91245E4C4000016BD5AE285140952D9276A35F4C409A3FA6B5692A5140952D9276A35F4C409A3FA6B5692A51404DC0AF91245E4C4000016BD5AE2851404DC0AF91245E4C40
9808	Вилкова	6	57	1065	69.180921999999995	69.201933999999994	56.906463000000002	56.898524999999999	0103000020E610000001000000050000001F48DE39944B5140B7D100DE02734C401F48DE39944B51405C04C6FA06744C40D47C957CEC4C51405C04C6FA06744C40D47C957CEC4C5140B7D100DE02734C401F48DE39944B5140B7D100DE02734C40
10571	Валгина	6	57	1065	68.735536999999994	68.746765999999994	56.921661	56.907317999999997	0103000020E61000000100000005000000DEFFC709132F51403B8908FF22744C40DEFFC709132F5140D47FD6FCF8754C40F1F09E03CB2F5140D47FD6FCF8754C40F1F09E03CB2F51403B8908FF22744C40DEFFC709132F51403B8908FF22744C40
10107	Большой Кусеряк	6	57	1065	69.398062999999993	69.429333	57.062598999999999	57.055115000000001	0103000020E61000000100000005000000D9AF3BDD79595140704221020E874C40D9AF3BDD7959514093E1783E03884C40FD851E317A5B514093E1783E03884C40FD851E317A5B5140704221020E874C40D9AF3BDD79595140704221020E874C40
9574	Большескаредная	6	57	1065	68.645291999999998	68.662109000000001	56.828615999999997	56.812260999999999	0103000020E61000000100000005000000B517D1764C2951407B681F2BF8674C40B517D1764C2951409E78CE16106A4C40C9586DFE5F2A51409E78CE16106A4C40C9586DFE5F2A51407B681F2BF8674C40B517D1764C2951407B681F2BF8674C40
9388	Аромашево	6	57	1065	68.613033999999999	68.679608000000002	56.895836000000003	56.835470999999998	0103000020E610000001000000050000008255F5F23B275140D2E0B6B6F06A4C408255F5F23B2751402C4A09C1AA724C4066868DB27E2B51402C4A09C1AA724C4066868DB27E2B5140D2E0B6B6F06A4C408255F5F23B275140D2E0B6B6F06A4C40
8493	Яровое	6	57	979	67.567772000000005	67.591945999999993	55.993423999999997	55.989592000000002	0103000020E6100000010000000500000069E55E6056E450400E315EF3AAFE4B4069E55E6056E45040DF87838428FF4B40DFBF7971E2E55040DF87838428FF4B40DFBF7971E2E550400E315EF3AAFE4B4069E55E6056E450400E315EF3AAFE4B40
9292	Южно-Дубровное	6	57	979	67.673738	67.693132000000006	55.781585	55.767513999999998	0103000020E61000000100000005000000A304FD851EEB50406F9C14E63DE24B40A304FD851EEB5040A7052FFA0AE44B40E9F351465CEC5040A7052FFA0AE44B40E9F351465CEC50406F9C14E63DE24B40A304FD851EEB50406F9C14E63DE24B40
8421	Снегирева	6	57	979	67.745413999999997	67.758960999999999	55.958284999999997	55.950302000000001	0103000020E61000000100000005000000C1FEEBDCB4EF504065A9F57EA3F94B40C1FEEBDCB4EF5040A99F3715A9FA4B40207C28D192F05040A99F3715A9FA4B40207C28D192F0504065A9F57EA3F94B40C1FEEBDCB4EF504065A9F57EA3F94B40
8413	Семискуль	6	57	979	67.670880999999994	67.683133999999995	55.974257000000001	55.969878999999999	0103000020E610000001000000050000007FA0DCB6EFEA5040E109BDFE24FC4B407FA0DCB6EFEA504015731074B4FC4B404832AB77B8EB504015731074B4FC4B404832AB77B8EB5040E109BDFE24FC4B407FA0DCB6EFEA5040E109BDFE24FC4B40
9246	Раздолье	6	57	979	67.215380999999994	67.23818	56.123302000000002	56.114455	0103000020E6100000010000000500000081CB63CDC8CD50408DEE2076A60E4C4081CB63CDC8CD504005C4245CC80F4C40ECA353573ECF504005C4245CC80F4C40ECA353573ECF50408DEE2076A60E4C4081CB63CDC8CD50408DEE2076A60E4C40
9130	Прохорово	6	57	979	67.396283999999994	67.416397000000003	55.927331000000002	55.912565999999998	0103000020E6100000010000000500000065FB90B75CD9504084B872F6CEF44B4065FB90B75CD9504093C83EC8B2F64B40C3499A3FA6DA504093C83EC8B2F64B40C3499A3FA6DA504084B872F6CEF44B4065FB90B75CD9504084B872F6CEF44B40
9325	Полое	6	57	979	67.771106000000003	67.776747	55.748325999999999	55.740091	0103000020E61000000100000005000000F6EFFACC59F150402F88484DBBDE4B40F6EFFACC59F150408D5F7825C9DF4B4008910C39B6F150408D5F7825C9DF4B4008910C39B6F150402F88484DBBDE4B40F6EFFACC59F150402F88484DBBDE4B40
8605	Плоское	6	57	979	67.793537000000001	67.807191000000003	56.028872	56.017125	0103000020E610000001000000050000009FCA694FC9F25040D578E92631024C409FCA694FC9F2504093E2E313B2034C4009A87004A9F3504093E2E313B2034C4009A87004A9F35040D578E92631024C409FCA694FC9F25040D578E92631024C40
9053	Орлово	6	57	979	67.891560999999996	67.916659999999993	55.883277	55.867590999999997	0103000020E61000000100000005000000E658DE550FF95040E7A6CD380DEF4B40E658DE550FF950408D2782380FF14B404963B48EAAFA50408D2782380FF14B404963B48EAAFA5040E7A6CD380DEF4B40E658DE550FF95040E7A6CD380DEF4B40
8937	Няшино	6	57	979	68.072113000000002	68.088436000000002	55.876874000000001	55.868828999999998	0103000020E610000001000000050000007427D87F9D0451407F68E6C935EF4B407427D87F9D0451403A5B40683DF04B4080F277EFA80551403A5B40683DF04B4080F277EFA80551407F68E6C935EF4B407427D87F9D0451407F68E6C935EF4B40
8771	Новорямова	6	57	979	68.067801000000003	68.082058000000004	55.783372	55.778871000000002	0103000020E61000000100000005000000B66801DA56045140C366800BB2E34B40B66801DA56045140124DA08845E44B400398327040055140124DA08845E44B400398327040055140C366800BB2E34B40B66801DA56045140C366800BB2E34B40
61289	Менщиково	6	57	979	67.621707000000001	67.632029000000003	55.89873	55.892434999999999	0103000020E610000001000000050000006F2C280CCAE750402367614F3BF24B406F2C280CCAE7504090F7AA9509F34B40E947C32973E8504090F7AA9509F34B40E947C32973E850402367614F3BF24B406F2C280CCAE750402367614F3BF24B40
8693	Крашенева	6	57	979	67.869471000000004	67.885937999999996	56.111223000000003	56.104179999999999	0103000020E610000001000000050000008274B169A5F75040DA722EC5550D4C408274B169A5F7504011C8258E3C0E4C4027124C35B3F8504011C8258E3C0E4C4027124C35B3F85040DA722EC5550D4C408274B169A5F75040DA722EC5550D4C40
8861	Красноорловское	6	57	979	67.946556000000001	67.96472	55.967520999999998	55.958547000000003	0103000020E6100000010000000500000049F59D5F94FC5040E75608ABB1FA4B4049F59D5F94FC5040BB9866BAD7FB4B400473F4F8BDFD5040BB9866BAD7FB4B400473F4F8BDFD5040E75608ABB1FA4B4049F59D5F94FC5040E75608ABB1FA4B40
8852	Капралиха	6	57	979	67.247118999999998	67.270430000000005	56.177145000000003	56.162596000000001	0103000020E6100000010000000500000018CE35CCD0CF5040EF3A1BF2CF144C4018CE35CCD0CF504031D3F6AFAC164C40DE76A1B94ED1504031D3F6AFAC164C40DE76A1B94ED15040EF3A1BF2CF144C4018CE35CCD0CF5040EF3A1BF2CF144C40
8710	Калмакское	6	57	979	67.989163000000005	68.021214999999998	55.762737999999999	55.755712000000003	0103000020E6100000010000000500000073DA53724EFF5040EE98BA2BBBE04B4073DA53724EFF50404EB51666A1E14B40D1CB28965B0151404EB51666A1E14B40D1CB28965B015140EE98BA2BBBE04B4073DA53724EFF5040EE98BA2BBBE04B40
8592	Иваново	6	57	979	67.759400999999997	67.774421000000004	56.097898999999998	56.083033999999998	0103000020E610000001000000050000002EE3A6069AF05040603AADDBA00A4C402EE3A6069AF05040D2A755F4870C4C407B15191D90F15040D2A755F4870C4C407B15191D90F15040603AADDBA00A4C402EE3A6069AF05040603AADDBA00A4C40
8976	Забошное	6	57	979	67.997652000000002	68.014432999999997	55.904260999999998	55.900233999999998	0103000020E610000001000000050000007F32C687D9FF5040A65F22DE3AF34B407F32C687D9FF50402D060FD3BEF34B40ECBE6378EC0051402D060FD3BEF34B40ECBE6378EC005140A65F22DE3AF34B407F32C687D9FF5040A65F22DE3AF34B40
9140	Жиряково	6	57	979	67.483931999999996	67.507998000000001	55.823372999999997	55.818640000000002	0103000020E61000000100000005000000395FECBDF8DE504046990D32C9E84B40395FECBDF8DE504067B4554964E94B40BD1B0B0A83E0504067B4554964E94B40BD1B0B0A83E0504046990D32C9E84B40395FECBDF8DE504046990D32C9E84B40
9211	Вьялково	6	57	979	67.435989000000006	67.460971999999998	55.945850999999998	55.937542999999998	0103000020E610000001000000050000009C1A683EE7DB5040FFCBB56801F84B409C1A683EE7DB5040C7F143A511F94B40CA17B49080DD5040C7F143A511F94B40CA17B49080DD5040FFCBB56801F84B409C1A683EE7DB5040FFCBB56801F84B40
9080	Бурлаки	6	57	979	67.730519999999999	67.743537000000003	55.882393999999998	55.878898999999997	0103000020E61000000100000005000000BB44F5D6C0EE504059BE2EC37FF04B40BB44F5D6C0EE5040E3175E49F2F04B406C97361C96EF5040E3175E49F2F04B406C97361C96EF504059BE2EC37FF04B40BB44F5D6C0EE504059BE2EC37FF04B40
8204	Армизонское	6	57	979	67.657200000000003	67.713864999999998	55.957388000000002	55.929979000000003	0103000020E6100000010000000500000099BB96900FEA5040C07B478D09F74B4099BB96900FEA50409BCAA2B08BFA4B409430D3F6AFED50409BCAA2B08BFA4B409430D3F6AFED5040C07B478D09F74B4099BB96900FEA5040C07B478D09F74B40
61344	п. Нефтяников	6	57	784	69.870900000000006	71.261590999999996	56.645138000000003	55.874996000000003	0103000020E6100000010000000500000088855AD3BC775140BF1072DEFFEF4B4088855AD3BC77514014B4C9E193524C40637B2DE8BDD0514014B4C9E193524C40637B2DE8BDD05140BF1072DEFFEF4B4088855AD3BC775140BF1072DEFFEF4B40
7553	Яузяк	6	57	784	70.713807000000003	70.733362999999997	56.557941	56.549343	0103000020E61000000100000005000000FA298E03AFAD5140ADA415DF50464C40FA298E03AFAD51407C0C569C6A474C402C465D6BEFAE51407C0C569C6A474C402C465D6BEFAE5140ADA415DF50464C40FA298E03AFAD5140ADA415DF50464C40
6095	Шипунова	6	57	784	70.313930999999997	70.337772000000001	56.328553999999997	56.32226	0103000020E61000000100000005000000D68C0C72179451408C67D0D03F294C40D68C0C7217945140287CB60E0E2A4C404A60730E9E955140287CB60E0E2A4C404A60730E9E9551408C67D0D03F294C40D68C0C72179451408C67D0D03F294C40
7933	Шевырино	6	57	784	70.451768999999999	70.475285999999997	56.187370999999999	56.176313999999998	0103000020E610000001000000050000002F1686C8E99C5140D9E9077591164C402F1686C8E99C5140029CDEC5FB174C40C98FF8156B9E5140029CDEC5FB174C40C98FF8156B9E5140D9E9077591164C402F1686C8E99C5140D9E9077591164C40
7473	Челнокова	6	57	784	70.522447999999997	70.541985999999994	56.510720999999997	56.500914999999999	0103000020E610000001000000050000001477BCC96FA15140B58993FB1D404C401477BCC96FA15140B130444E5F414C40F3380CE6AFA25140B130444E5F414C40F3380CE6AFA25140B58993FB1D404C401477BCC96FA15140B58993FB1D404C40
7804	Фирсова	6	57	784	70.066175999999999	70.076183	56.172334999999997	56.168740999999997	0103000020E61000000100000005000000EDF1423A3C845140463F1A4E99154C40EDF1423A3C845140637AC2120F164C40B760A92EE0845140637AC2120F164C40B760A92EE0845140463F1A4E99154C40EDF1423A3C845140463F1A4E99154C40
7661	Тушнолобово	6	57	784	70.124054000000001	70.151785000000004	56.215868	56.206687000000002	0103000020E61000000100000005000000083C3080F087514012C138B8741A4C40083C3080F087514060200890A11B4C407FC16ED8B689514060200890A11B4C407FC16ED8B689514012C138B8741A4C40083C3080F087514012C138B8741A4C40
7435	Тельцова	6	57	784	70.674999999999997	70.687460000000002	56.369781000000003	56.358043000000002	0103000020E610000001000000050000003333333333AB5140E7C75F5AD42D4C403333333333AB514052D7DAFB542F4C40B9533A58FFAB514052D7DAFB542F4C40B9533A58FFAB5140E7C75F5AD42D4C403333333333AB5140E7C75F5AD42D4C40
61282	Татарская	6	57	784	70.473211000000006	70.485930999999994	56.221789999999999	56.210687	0103000020E61000000100000005000000E146CA16499E51409F58A7CAF71A4C40E146CA16499E5140384A5E9D631C4C403447567E199F5140384A5E9D631C4C403447567E199F51409F58A7CAF71A4C40E146CA16499E51409F58A7CAF71A4C40
6275	Сычево	6	57	784	70.199369000000004	70.221260999999998	56.125093999999997	56.11833	0103000020E6100000010000000500000085B53176C28C51405E11FC6F250F4C4085B53176C28C51408176871403104C4056B8E523298E51408176871403104C4056B8E523298E51405E11FC6F250F4C4085B53176C28C51405E11FC6F250F4C40
6408	Сысоева	6	57	784	70.208172000000005	70.222104999999999	56.325225000000003	56.319619000000003	0103000020E6100000010000000500000059FCA6B0528D514012178046E9284C4059FCA6B0528D5140BA6B09F9A0294C40CCD1E3F7368E5140BA6B09F9A0294C40CCD1E3F7368E514012178046E9284C4059FCA6B0528D514012178046E9284C40
7056	Старая Маслянка	6	57	784	70.105215999999999	70.122086999999993	56.089272000000001	56.078809	0103000020E6100000010000000500000005C1E3DBBB865140B3D0CE69160A4C4005C1E3DBBB8651406939D0436D0B4C401211FE45D08751406939D0436D0B4C401211FE45D0875140B3D0CE69160A4C4005C1E3DBBB865140B3D0CE69160A4C40
7398	Спирина	6	57	784	70.690550000000002	70.707545999999994	56.463783999999997	56.450901999999999	0103000020E610000001000000050000002E90A0F831AC5140BAD91F28B7394C402E90A0F831AC51403B342C465D3B4C40999A046F48AD51403B342C465D3B4C40999A046F48AD5140BAD91F28B7394C402E90A0F831AC5140BAD91F28B7394C40
8092	Смоленка	6	57	784	70.628135	70.640450999999999	56.208804999999998	56.200603000000001	0103000020E61000000100000005000000459E245D33A85140603DEE5BAD194C40459E245D33A85140E21E4B1FBA1A4C4031EC3026FDA85140E21E4B1FBA1A4C4031EC3026FDA85140603DEE5BAD194C40459E245D33A85140603DEE5BAD194C40
7725	Репьева	6	57	784	70.113552999999996	70.119642999999996	56.199686999999997	56.193382	0103000020E610000001000000050000003657CD73448751404AD1CABDC0184C403657CD7344875140DA37F7578F194C40800C1D3BA8875140DA37F7578F194C40800C1D3BA88751404AD1CABDC0184C403657CD73448751404AD1CABDC0184C40
7362	Погорелка	6	57	784	70.651679999999999	70.664022000000003	56.527290999999998	56.510109999999997	0103000020E6100000010000000500000044DD0720B5A9514068AED3484B414C4044DD0720B5A95140D13C80457E434C40C57421567FAA5140D13C80457E434C40C57421567FAA514068AED3484B414C4044DD0720B5A9514068AED3484B414C40
7566	Партизан	6	57	784	70.833112	70.863124999999997	56.052149999999997	56.034928000000001	0103000020E61000000100000005000000EE79FEB451B551407BDB4C8578044C40EE79FEB451B55140423EE8D9AC064C400AD7A3703DB75140423EE8D9AC064C400AD7A3703DB751407BDB4C8578044C40EE79FEB451B551407BDB4C8578044C40
6988	Пайкова	6	57	784	70.130971000000002	70.149952999999996	56.110134000000002	56.099752000000002	0103000020E610000001000000050000005D6E30D461885140F5DA6CACC40C4C405D6E30D461885140BE16F4DE180E4C40F9BB77D498895140BE16F4DE180E4C40F9BB77D498895140F5DA6CACC40C4C405D6E30D461885140F5DA6CACC40C4C40
7269	Ощепково	6	57	784	70.684459000000004	70.712828000000002	56.49127	56.473480000000002	0103000020E61000000100000005000000FC1C1F2DCEAB5140B1A71DFE9A3C4C40FC1C1F2DCEAB5140C2C073EFE13E4C4014EB54F99EAD5140C2C073EFE13E4C4014EB54F99EAD5140B1A71DFE9A3C4C40FC1C1F2DCEAB5140B1A71DFE9A3C4C40
7110	Назарово	6	57	784	70.772548	70.791888999999998	56.574665000000003	56.561973999999999	0103000020E61000000100000005000000C6A52A6D71B15140E59997C3EE474C40C6A52A6D71B15140F3936A9F8E494C40FA43334FAEB25140F3936A9F8E494C40FA43334FAEB25140E59997C3EE474C40C6A52A6D71B15140E59997C3EE474C40
6975	Мешалкина	6	57	784	70.058064000000002	70.076155999999997	56.085962000000002	56.082521999999997	0103000020E61000000100000005000000CC441152B7835140AA99B514900A4C40CC441152B7835140715985CD000B4C403A596ABDDF845140715985CD000B4C403A596ABDDF845140AA99B514900A4C40CC441152B7835140AA99B514900A4C40
6873	Марай	6	57	784	70.286955000000006	70.301786000000007	56.052829000000003	56.046900999999998	0103000020E610000001000000050000001E1B81785D92514029931ADA00064C401E1B81785D925140E4A3C519C3064C4001193A7650935140E4A3C519C3064C4001193A765093514029931ADA00064C401E1B81785D92514029931ADA00064C40
6901	Майский	6	57	784	70.125868999999994	70.167730000000006	55.940123999999997	55.925662000000003	0103000020E6100000010000000500000022A5D93C0E8851403293A8177CF64B4022A5D93C0E885140A417B5FB55F84B40B8239C16BC8A5140A417B5FB55F84B40B8239C16BC8A51403293A8177CF64B4022A5D93C0E8851403293A8177CF64B40
6713	Ленинка	6	57	784	70.402550000000005	70.426625000000001	56.061605	56.044758999999999	0103000020E610000001000000050000004F401361C3995140D099B4A9BA054C404F401361C3995140922232ACE2074C40FCA9F1D24D9B5140922232ACE2074C40FCA9F1D24D9B5140D099B4A9BA054C404F401361C3995140D099B4A9BA054C40
6601	Лапина	6	57	784	70.574558999999994	70.592813000000007	56.258668	56.252327000000001	0103000020E61000000100000005000000D6A71C93C5A45140EB724A404C204C40D6A71C93C5A45140C84274081C214C4032E9EFA5F0A55140C84274081C214C4032E9EFA5F0A55140EB724A404C204C40D6A71C93C5A45140EB724A404C204C40
6384	Костылева	6	57	784	70.029785000000004	70.052638000000002	56.273544999999999	56.264156999999997	0103000020E61000000100000005000000543A58FFE7815140360186E5CF214C40543A58FFE7815140FE7DC68503234C40B821C66B5E835140FE7DC68503234C40B821C66B5E835140360186E5CF214C40543A58FFE7815140360186E5CF214C40
6487	Конево	6	57	784	70.702236999999997	70.728153000000006	56.302897000000002	56.279896999999998	0103000020E61000000100000005000000A2427573F1AC5140CF9F36AAD3234C40A2427573F1AC51403C873254C5264C40FF5E0A0F9AAE51403C873254C5264C40FF5E0A0F9AAE5140CF9F36AAD3234C40A2427573F1AC5140CF9F36AAD3234C40
7624	Камышинская	6	57	784	70.702973	70.729401999999993	56.110902000000003	56.101548999999999	0103000020E61000000100000005000000253E7782FDAC514083F8C08EFF0C4C40253E7782FDAC5140CF876709320E4C40C4E8B985AEAE5140CF876709320E4C40C4E8B985AEAE514083F8C08EFF0C4C40253E7782FDAC514083F8C08EFF0C4C40
61284	Камышинка	6	57	784	70.650215000000003	70.671460999999994	56.137554999999999	56.129539000000001	0103000020E610000001000000050000009817601F9DA951403D47E4BB94104C409817601F9DA951405D33F9669B114C4086E28E37F9AA51405D33F9669B114C4086E28E37F9AA51403D47E4BB94104C409817601F9DA951403D47E4BB94104C40
5860	Еремина	6	57	784	70.467192999999995	70.476705999999993	56.346984999999997	56.339562000000001	0103000020E61000000100000005000000E3FA777DE69D5140707B82C4762B4C40E3FA777DE69D5140ED9925016A2C4C40A5F3E159829E5140ED9925016A2C4C40A5F3E159829E5140707B82C4762B4C40E3FA777DE69D5140707B82C4762B4C40
6825	Восток	6	57	784	70.542085	70.561597000000006	56.030236000000002	56.019883	0103000020E61000000100000005000000BDA94885B1A25140895FB1868B024C40BDA94885B1A25140B894F3C5DE034C4008228B34F1A35140B894F3C5DE034C4008228B34F1A35140895FB1868B024C40BDA94885B1A25140895FB1868B024C40
7294	Быструха	6	57	784	70.610518999999996	70.639436000000003	56.437486999999997	56.412756000000002	0103000020E610000001000000050000008BA548BE12A75140289D4830D5344C408BA548BE12A751406BB6F292FF374C40A5F8F884ECA851406BB6F292FF374C40A5F8F884ECA85140289D4830D5344C408BA548BE12A75140289D4830D5344C40
6307	Болдырево	6	57	784	70.111611999999994	70.149655999999993	56.326892000000001	56.316094999999997	0103000020E61000000100000005000000D575A8A624875140EDB60BCD75284C40D575A8A6248751407AA9D898D7294C409C69C2F6938951407AA9D898D7294C409C69C2F693895140EDB60BCD75284C40D575A8A624875140EDB60BCD75284C40
5802	Бобыльск	6	57	784	70.520588000000004	70.545857999999996	56.322493999999999	56.316654	0103000020E610000001000000050000002AAC545051A15140E412471E88284C402AAC545051A15140FF93BF7B47294C40A3906456EFA25140FF93BF7B47294C40A3906456EFA25140E412471E88284C402AAC545051A15140E412471E88284C40
6179	Банниково	6	57	784	70.260445000000004	70.293978999999993	56.124034999999999	56.112411999999999	0103000020E61000000100000005000000085A8121AB905140C7D63384630E4C40085A8121AB9051409947FE60E00F4C407DAD4B8DD09251409947FE60E00F4C407DAD4B8DD0925140C7D63384630E4C40085A8121AB905140C7D63384630E4C40
5555	Абатское	6	57	784	70.396458999999993	70.475583	56.306168	56.277453000000001	0103000020E610000001000000050000001CCD91955F995140AB96749483234C401CCD91955F995140768A558330274C4026E2ADF36F9E5140768A558330274C4026E2ADF36F9E5140AB96749483234C401CCD91955F995140AB96749483234C40
50142	станция Решёты	6	56	\N	60.158763999999998	60.290565000000001	56.872948999999998	56.800705000000001	0103000020E610000001000000050000001DE4F56052144E40315F5E807D664C401DE4F56052144E40B709F7CABC6F4C405E2EE23B31254E40B709F7CABC6F4C405E2EE23B31254E40315F5E807D664C401DE4F56052144E40315F5E807D664C40
49962	п. Восточный	6	56	\N	61.777034	61.839503000000001	58.808472999999999	58.783392999999997	0103000020E61000000100000005000000A6F0A0D975E34E402975C93846644D40A6F0A0D975E34E407959130B7C674D406BF294D574EB4E407959130B7C674D406BF294D574EB4E402975C93846644D40A6F0A0D975E34E402975C93846644D40
49906	Филькино	6	56	\N	60.690333000000003	60.734538999999998	59.619056	59.594963	0103000020E61000000100000005000000BF2CEDD45C584E403FAA61BF27CC4D40BF2CEDD45C584E4040321D3A3DCF4D407A51BB5F055E4E4040321D3A3DCF4D407A51BB5F055E4E403FAA61BF27CC4D40BF2CEDD45C584E403FAA61BF27CC4D40
50103	Туринск	6	56	\N	63.661197000000001	63.733224	58.068415000000002	58.014274	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
50169	Торфяник	6	56	\N	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
61096	Сысерть	6	56	\N	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
49883	Сухой Лог	6	56	\N	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
49868	Среднеуральск	6	56	\N	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
49854	Смолинское	6	56	\N	61.638793	61.652051999999998	56.433211999999997	56.424017999999997	0103000020E61000000100000005000000F5F411F8C3D14E402975C93846364C40F5F411F8C3D14E400C1EA67D73374C404CA59F7076D34E400C1EA67D73374C404CA59F7076D34E402975C93846364C40F5F411F8C3D14E402975C93846364C40
49984	Сигнальный	6	56	\N	59.774419999999999	59.789681999999999	58.798268999999998	58.789400000000001	0103000020E6100000010000000500000025AFCE3120E34D4030BB270F0B654D4025AFCE3120E34D408F34B8AD2D664D40B41EBE4C14E54D408F34B8AD2D664D40B41EBE4C14E54D4030BB270F0B654D4025AFCE3120E34D4030BB270F0B654D40
6144	Серов	6	56	\N	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
4770	Североуральск	6	56	\N	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
49895	Реж	6	56	\N	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
6072	Ревда	6	56	\N	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
1641	Полевской	6	56	\N	60.14705	60.277341999999997	56.514752999999999	56.416311	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
16	Первоуральск	6	56	\N	59.863757	60.054901000000001	56.933847	56.853822999999998	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
61334	Пелым	6	56	\N	61.975121999999999	62.005754000000003	61.023615999999997	61.011710000000001	0103000020E6100000010000000500000018CE35CCD0FC4E40A18499B67F814E4018CE35CCD0FC4E40C7D45DD905834E401DE90C8CBC004F40C7D45DD905834E401DE90C8CBC004F40A18499B67F814E4018CE35CCD0FC4E40A18499B67F814E40
49886	Новоуральск	6	56	\N	60.050859000000003	60.121772	57.263199	57.226635999999999	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
1810	Нижняя Тура	6	56	\N	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
12051	Нижняя Салда	6	56	\N	60.682966999999998	60.767364000000001	58.092008	58.050798	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
9945	Нижний Тагил	6	56	\N	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
50124	Нижние Серги	6	56	\N	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
20037	Невьянск	6	56	\N	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
50135	Михайловск	6	56	\N	59.068559999999998	59.154744000000001	56.469383000000001	56.405943000000001	0103000020E6100000010000000500000029E8F692C6884D402385B2F0F5334C4029E8F692C6884D403126FDBD143C4C4049A0C1A6CE934D403126FDBD143C4C4049A0C1A6CE934D402385B2F0F5334C4029E8F692C6884D402385B2F0F5334C40
49991	Лесной	6	56	\N	59.757837000000002	59.823917000000002	58.660030999999996	58.623361000000003	0103000020E61000000100000005000000715985CD00E14D400A4D124BCA4F4D40715985CD00E14D404FAC53E57B544D4029CFBC1C76E94D404FAC53E57B544D4029CFBC1C76E94D400A4D124BCA4F4D40715985CD00E14D400A4D124BCA4F4D40
8815	Кушва	6	56	\N	59.682324999999999	59.821123	58.314900999999999	58.256017	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
49894	Крылатовский	6	56	\N	60.190403000000003	60.205908000000001	56.625053999999999	56.615713999999997	0103000020E61000000100000005000000B80721205F184E403CD862B7CF4E4C40B80721205F184E40F31DFCC401504C400DFE7E315B1A4E40F31DFCC401504C400DFE7E315B1A4E403CD862B7CF4E4C40B80721205F184E403CD862B7CF4E4C40
7561	Красноуфимск	6	56	\N	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
6272	Красноуральск	6	56	\N	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
49845	Краснотурьинск	6	56	\N	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
450	Кировград	6	56	\N	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
49875	Качканар	6	56	\N	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
29288	Карпинск	6	56	\N	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
23556	Камышлов	6	56	\N	62.647987000000001	62.793137000000002	56.869515	56.826217	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
49945	КаменскУральский	6	56	\N	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
20970	Каменск-Уральский	6	56	\N	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
16563	Ирбит	6	56	\N	63.005606	63.103791999999999	57.695076	57.644934999999997	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
49923	Ивдель	6	56	\N	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
17774	Ивдель	6	56	\N	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
13	Екатеринбург	6	56	\N	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
49870	Дегтярск	6	56	\N	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
61129	Волчанск	6	56	\N	60.002439000000003	60.105044999999997	59.949162999999999	59.888649999999998	0103000020E61000000100000005000000139ED0EB4F004E4092CB7F48BFF14D40139ED0EB4F004E4060C9552C7EF94D40DDCD531D720D4E4060C9552C7EF94D40DDCD531D720D4E4092CB7F48BFF14D40139ED0EB4F004E4092CB7F48BFF14D40
50206	Верхотурье	6	56	\N	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
50137	Верхняя Тура	6	56	\N	59.789143000000003	59.877977999999999	58.377597999999999	58.343620999999999	0103000020E61000000100000005000000056F48A302E54D40029CDEC5FB2B4D40056F48A302E54D407B849A2155304D40C24D469561F04D407B849A2155304D40C24D469561F04D40029CDEC5FB2B4D40056F48A302E54D40029CDEC5FB2B4D40
49904	Верхняя Салда	6	56	\N	60.511738999999999	60.597915	58.074283999999999	58.018836	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
11998	Верхняя Пышма	6	56	\N	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
61314	Верхний Тагил	6	56	\N	59.911799000000002	59.980421999999997	57.391567999999999	57.343580000000003	0103000020E6100000010000000500000044C362D4B5F44D40A4C7EF6DFAAB4C4044C362D4B5F44D407F1475E61EB24C40B323D5777EFD4D407F1475E61EB24C40B323D5777EFD4D40A4C7EF6DFAAB4C4044C362D4B5F44D40A4C7EF6DFAAB4C40
10875	Богданович	6	56	\N	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
50100	Бобровский	6	56	\N	60.946874000000001	60.994467	56.694206999999999	56.649261000000003	0103000020E6100000010000000500000063B7CF2A33794E40BDC804FC1A534C4063B7CF2A33794E40BFD364C6DB584C40C2F9D4B14A7F4E40BFD364C6DB584C40C2F9D4B14A7F4E40BDC804FC1A534C4063B7CF2A33794E40BDC804FC1A534C40
888	Березовский	6	56	\N	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
9344	Белоярский	6	56	\N	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
49890	Байкалово	6	56	\N	63.735523000000001	63.786233000000003	57.409185000000001	57.388114000000002	0103000020E61000000100000005000000583A1F9E25DE4F40548F34B8ADB14C40583A1F9E25DE4F40C381902C60B44C409B046F48A3E44F40C381902C60B44C409B046F48A3E44F40548F34B8ADB14C40583A1F9E25DE4F40548F34B8ADB14C40
6503	Асбест	6	56	\N	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
49978	Артёмовский	6	56	\N	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
49843	Алапаевск	6	56	\N	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
49842	Черёмухово	6	56	6986	59.960262999999998	59.996195999999998	60.357675	60.334575000000001	0103000020E610000001000000050000008847E2E5E9FA4D409487855AD32A4E408847E2E5E9FA4D4064CC5D4BC82D4E40F833BC5983FF4D4064CC5D4BC82D4E40F833BC5983FF4D409487855AD32A4E408847E2E5E9FA4D409487855AD32A4E40
49912	Сосьва (Долгая Паберега)	6	56	6986	59.889727999999998	59.912491000000003	60.409688000000003	60.398187999999998	0103000020E61000000100000005000000F12A6B9BE2F14D406FD40AD3F7324E40F12A6B9BE2F14D4026C808A870344E407A724D81CCF44D4026C808A870344E407A724D81CCF44D406FD40AD3F7324E40F12A6B9BE2F14D406FD40AD3F7324E40
49967	Калья	6	56	6986	59.974150999999999	60.001621999999998	60.250002000000002	60.233449999999998	0103000020E61000000100000005000000CF2EDFFAB0FC4D4027A089B0E11D4E40CF2EDFFAB0FC4D40A1F7C61000204E40207A522635004E40A1F7C61000204E40207A522635004E4027A089B0E11D4E40CF2EDFFAB0FC4D4027A089B0E11D4E40
47936	Мариинск	6	56	1336	59.858161000000003	59.895881000000003	56.629426000000002	56.608575999999999	0103000020E61000000100000005000000F1D93A38D8ED4D40B49080D1E54D4C40F1D93A38D8ED4D4045A0FA0791504C40CC0D863AACF24D4045A0FA0791504C40CC0D863AACF24D40B49080D1E54D4C40F1D93A38D8ED4D40B49080D1E54D4C40
15768	Дегтярск	6	56	1336	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
49940	Полдневая	6	56	7000	60.266840999999999	60.306510000000003	56.307890999999998	56.288421	0103000020E61000000100000005000000B01D8CD827224E40643DB5FAEA244C40B01D8CD827224E40CADDE7F868274C40D0F23CB83B274E40CADDE7F868274C40D0F23CB83B274E40643DB5FAEA244C40B01D8CD827224E40643DB5FAEA244C40
49964	Косой Брод	6	56	7000	60.316571000000003	60.351776000000001	56.487081000000003	56.472445999999998	0103000020E6100000010000000500000057EE056685284E4021904B1C793C4C4057EE056685284E4062C092AB583E4C4044C2F7FE062D4E4062C092AB583E4C4044C2F7FE062D4E4021904B1C793C4C4057EE056685284E4021904B1C793C4C40
50129	Зюзельский	6	56	7000	60.117818999999997	60.145235999999997	56.493203000000001	56.481324999999998	0103000020E6100000010000000500000078EC67B1140F4E40A4DFBE0E9C3D4C4078EC67B1140F4E4001A5A146213F4C40D619DF1797124E4001A5A146213F4C40D619DF1797124E40A4DFBE0E9C3D4C4078EC67B1140F4E40A4DFBE0E9C3D4C40
49975	Старые Решёты	6	56	6987	60.226469999999999	60.265574000000001	56.852705999999998	56.843451999999999	0103000020E6100000010000000500000037C30DF8FC1C4E4076DF313CF66B4C4037C30DF8FC1C4E402E8D5F78256D4C407E552E54FE214E402E8D5F78256D4C407E552E54FE214E4076DF313CF66B4C4037C30DF8FC1C4E4076DF313CF66B4C40
49851	Новоуткинск	6	56	6987	59.534120999999999	59.579953000000003	57.002955999999998	56.976790000000001	0103000020E61000000100000005000000AC8DB1135EC44D40A9876874077D4C40AC8DB1135EC44D40DAA9B9DC60804C40CA1B60E63BCA4D40DAA9B9DC60804C40CA1B60E63BCA4D40A9876874077D4C40AC8DB1135EC44D40A9876874077D4C40
49915	Новоалексеевское	6	56	6987	60.112555	60.153689	56.855964	56.841507	0103000020E610000001000000050000002A00C633680E4E40732D5A80B66B4C402A00C633680E4E40D446753A906D4C40A260C614AC134E40D446753A906D4C40A260C614AC134E40732D5A80B66B4C402A00C633680E4E40732D5A80B66B4C40
49948	Крылосово	6	56	6987	59.672434000000003	59.706057999999999	56.953868999999997	56.933278000000001	0103000020E61000000100000005000000F75B3B5112D64D40C4094CA775774C40F75B3B5112D64D4088D51F61187A4C40228AC91B60DA4D4088D51F61187A4C40228AC91B60DA4D40C4094CA775774C40F75B3B5112D64D40C4094CA775774C40
49847	Битимка	6	56	6987	59.745530000000002	59.765410000000003	56.93947	56.922437000000002	0103000020E61000000100000005000000EC17EC866DDF4D4068CF656A12764C40EC17EC866DDF4D405CC98E8D40784C40040473F4F8E14D405CC98E8D40784C40040473F4F8E14D4068CF656A12764C40EC17EC866DDF4D4068CF656A12764C40
49957	Билимбай	6	56	6987	59.782451000000002	59.846733999999998	56.981920000000002	56.935732999999999	0103000020E610000001000000050000007BDCB75A27E44D40DC645419C6774C407BDCB75A27E44D40E8A4F78DAF7D4C40A4349BC761EC4D40E8A4F78DAF7D4C40A4349BC761EC4D40DC645419C6774C407BDCB75A27E44D40DC645419C6774C40
49914	Таёжный	6	56	728	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
5314	Новая Тура	6	56	728	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
11234	Лесной	6	56	728	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
61255	Ис	6	56	728	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
5221	Большая Именная	6	56	728	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
49989	Ёлкино	6	56	728	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
14675	Верхняя Тура	6	56	1359	59.789143000000003	59.877977999999999	58.377597999999999	58.343620999999999	0103000020E61000000100000005000000056F48A302E54D40029CDEC5FB2B4D40056F48A302E54D407B849A2155304D40C24D469561F04D407B849A2155304D40C24D469561F04D40029CDEC5FB2B4D40056F48A302E54D40029CDEC5FB2B4D40
49897	Баранчинский	6	56	1359	59.668346999999997	59.734202000000003	58.190522999999999	58.150157999999998	0103000020E610000001000000050000009AB0FD648CD54D40CB9D996038134D409AB0FD648CD54D406211C30E63184D403354C554FADD4D406211C30E63184D403354C554FADD4D40CB9D996038134D409AB0FD648CD54D40CB9D996038134D40
49267	Берёзовая Роща	6	56	6965	57.716316999999997	57.755285999999998	56.648924000000001	56.623399999999997	0103000020E61000000100000005000000CF488446B0DB4C40C7293A92CB4F4C40CF488446B0DB4C4075CB0EF10F534C4036902E36ADE04C4075CB0EF10F534C4036902E36ADE04C40C7293A92CB4F4C40CF488446B0DB4C40C7293A92CB4F4C40
49889	Краснодольский	6	56	6994	59.947021999999997	59.963389999999997	58.37632	58.367607	0103000020E61000000100000005000000D74B530438F94D40ED6305BF0D2F4D40D74B530438F94D40556AF6402B304D408FA50F5D50FB4D40556AF6402B304D408FA50F5D50FB4D40ED6305BF0D2F4D40D74B530438F94D40ED6305BF0D2F4D40
49981	Дачный	6	56	6994	59.920037000000001	59.938640999999997	58.414318999999999	58.400519000000003	0103000020E61000000100000005000000130EBDC5C3F54D409C36E33444334D40130EBDC5C3F54D40438EAD6708354D40A5D7666325F84D40438EAD6708354D40A5D7666325F84D409C36E33444334D40130EBDC5C3F54D409C36E33444334D40
2105	Рудничный	6	56	383	60.274017999999998	60.301488999999997	59.709780000000002	59.688637	0103000020E61000000100000005000000F641960513234E4064E8D84125D84D40F641960513234E406DAD2F12DADA4D40478D093197264E406DAD2F12DADA4D40478D093197264E4064E8D84125D84D40F641960513234E4064E8D84125D84D40
6077	Прибрежный	6	56	383	60.227629	60.241149	59.854038000000003	59.846811000000002	0103000020E61000000100000005000000834F73F2221D4E405072874D64EC4D40834F73F2221D4E4048C5FF1D51ED4D40473B6EF8DD1E4E4048C5FF1D51ED4D40473B6EF8DD1E4E405072874D64EC4D40834F73F2221D4E405072874D64EC4D40
49900	Краснотурьинск	6	56	383	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
49881	Нейво-Рудянка	6	56	1323	60.115304000000002	60.166902999999998	57.354312	57.324128000000002	0103000020E610000001000000050000008B8C0E48C20E4E40E4DBBB067DA94C408B8C0E48C20E4E40494A7A185AAD4C40594DD7135D154E40494A7A185AAD4C40594DD7135D154E40E4DBBB067DA94C408B8C0E48C20E4E40E4DBBB067DA94C40
49974	Лёвиха	6	56	1323	59.882631000000003	59.923990000000003	57.606231000000001	57.571984	0103000020E61000000100000005000000C8B7770DFAF04D40EAEA8EC536C94C40C8B7770DFAF04D40236937FA98CD4C4060EAE74D45F64D40236937FA98CD4C4060EAE74D45F64D40EAEA8EC536C94C40C8B7770DFAF04D40EAEA8EC536C94C40
49987	Карпушиха	6	56	1323	59.879297999999999	59.907226999999999	57.513455	57.489879999999999	0103000020E6100000010000000500000017B83CD68CF04D40747B4963B4BE4C4017B83CD68CF04D40DD7BB8E4B8C14C402B86AB0320F44D40DD7BB8E4B8C14C402B86AB0320F44D40747B4963B4BE4C4017B83CD68CF04D40747B4963B4BE4C40
14058	Верхний Тагил	6	56	1323	59.911799000000002	59.980421999999997	57.391567999999999	57.343580000000003	0103000020E6100000010000000500000044C362D4B5F44D40A4C7EF6DFAAB4C4044C362D4B5F44D407F1475E61EB24C40B323D5777EFD4D407F1475E61EB24C40B323D5777EFD4D40A4C7EF6DFAAB4C4044C362D4B5F44D40A4C7EF6DFAAB4C40
61159	Валерьяновск	6	56	7002	59.540776999999999	59.573385999999999	58.769015000000003	58.754015000000003	0103000020E61000000100000005000000E9B6442E38C54D40C3D8429083604D40E9B6442E38C54D40159161156F624D40FCFD62B664C94D40159161156F624D40FCFD62B664C94D40C3D8429083604D40E9B6442E38C54D40C3D8429083604D40
29638	Сосновка	6	56	1537	59.79712	59.827573000000001	59.940533000000002	59.927174999999998	0103000020E61000000100000005000000677E350708E64D409B559FABADF64D40677E350708E64D4086E7A56263F84D40BC067DE9EDE94D4086E7A56263F84D40BC067DE9EDE94D409B559FABADF64D40677E350708E64D409B559FABADF64D40
29690	Новая Княсьпа	6	56	1537	59.637014000000001	59.648493999999999	59.889479999999999	59.885503	0103000020E610000001000000050000000D8CBCAC89D14D4044C18C2958F14D400D8CBCAC89D14D4019390B7BDAF14D407CD3F4D901D34D4019390B7BDAF14D407CD3F4D901D34D4044C18C2958F14D400D8CBCAC89D14D4044C18C2958F14D40
18260	Кытлым	6	56	1537	59.189805	59.213054	59.507739000000001	59.494599999999998	0103000020E6100000010000000500000003CFBD874B984D40014D840D4FBF4D4003CFBD874B984D40AEF36F97FDC04D4018247D5A459B4D40AEF36F97FDC04D4018247D5A459B4D40014D840D4FBF4D4003CFBD874B984D40014D840D4FBF4D40
30825	Каквинские Печи	6	56	1537	59.591693999999997	59.615867000000001	59.718792999999998	59.712480999999997	0103000020E61000000100000005000000A59E05A1BCCB4D40BC02D19332DB4D40A59E05A1BCCB4D40FFCBB56801DC4D40C3D7D7BAD4CE4D40FFCBB56801DC4D40C3D7D7BAD4CE4D40BC02D19332DB4D40A59E05A1BCCB4D40BC02D19332DB4D40
61180	Волчанск	6	56	1537	60.002439000000003	60.105044999999997	59.949162999999999	59.888649999999998	0103000020E61000000100000005000000139ED0EB4F004E4092CB7F48BFF14D40139ED0EB4F004E4060C9552C7EF94D40DDCD531D720D4E4060C9552C7EF94D40DDCD531D720D4E4092CB7F48BFF14D40139ED0EB4F004E4092CB7F48BFF14D40
30718	Веселовка	6	56	1537	59.984589999999997	60.004317	59.693086999999998	59.685326000000003	0103000020E61000000100000005000000FCFB8C0B07FE4D409C8C2AC3B8D74D40FCFB8C0B07FE4D4031242713B7D84D408EE89E758D004E4031242713B7D84D408EE89E758D004E409C8C2AC3B8D74D40FCFB8C0B07FE4D409C8C2AC3B8D74D40
26186	Черноусова	6	56	1596	61.746662000000001	61.763891999999998	56.538727999999999	56.528612000000003	0103000020E610000001000000050000003E95D39E92DF4E40F722DA8EA9434C403E95D39E92DF4E4041B8020AF5444C4088D68A36C7E14E4041B8020AF5444C4088D68A36C7E14E40F722DA8EA9434C403E95D39E92DF4E40F722DA8EA9434C40
25763	Черемхово	6	56	1596	61.773594000000003	61.827635999999998	56.511197000000003	56.484679999999997	0103000020E61000000100000005000000E030D12005E34E403C8386FE093E4C40E030D12005E34E401B683EE76E414C40027FF8F9EFE94E401B683EE76E414C40027FF8F9EFE94E403C8386FE093E4C40E030D12005E34E403C8386FE093E4C40
24127	Троицкое	6	56	1596	61.399374000000002	61.426332000000002	56.395581	56.382052999999999	0103000020E61000000100000005000000B56FEEAF1EB34E405A2BDA1CE7304C40B56FEEAF1EB34E40A1F5F065A2324C40809E060C92B64E40A1F5F065A2324C40809E060C92B64E405A2BDA1CE7304C40B56FEEAF1EB34E405A2BDA1CE7304C40
22021	Травянское	6	56	1596	61.974421	62.057758	56.453732000000002	56.425044	0103000020E610000001000000050000008FC4CBD3B9FC4E4036AE7FD767364C408FC4CBD3B9FC4E400893E2E3133A4C408B8A389D64074F400893E2E3133A4C408B8A389D64074F4036AE7FD767364C408FC4CBD3B9FC4E4036AE7FD767364C40
24235	Сосновское	6	56	1596	61.235053999999998	61.269413999999998	56.452691999999999	56.424491000000003	0103000020E61000000100000005000000A165DD3F169E4E40223999B855364C40A165DD3F169E4E409694BBCFF1394C40D28A6F287CA24E409694BBCFF1394C40D28A6F287CA24E40223999B855364C40A165DD3F169E4E40223999B855364C40
24997	Соколова	6	56	1596	62.186531000000002	62.246934000000003	56.360008000000001	56.341453000000001	0103000020E610000001000000050000005858703FE0174F40800F5EBBB42B4C405858703FE0174F403126FDBD142E4C409F2287889B1F4F403126FDBD142E4C409F2287889B1F4F40800F5EBBB42B4C405858703FE0174F40800F5EBBB42B4C40
24820	Рыбниковское	6	56	1596	61.649715999999998	61.704891000000003	56.354821000000001	56.340245000000003	0103000020E610000001000000050000000ED8D5E429D34E4053D0ED258D2B4C400ED8D5E429D34E408E7747C66A2D4C40541F48DE39DA4E408E7747C66A2D4C40541F48DE39DA4E4053D0ED258D2B4C400ED8D5E429D34E4053D0ED258D2B4C40
25554	Позариха	6	56	1596	61.867790999999997	61.895747	56.467046000000003	56.451225000000001	0103000020E61000000100000005000000AE6186C613EF4E409D11A5BDC1394C40AE6186C613EF4E4023DDCF29C83B4C40BC3E73D6A7F24E4023DDCF29C83B4C40BC3E73D6A7F24E409D11A5BDC1394C40AE6186C613EF4E409D11A5BDC1394C40
26068	Пирогово	6	56	1596	61.946258999999998	61.975876	56.275208999999997	56.256028000000001	0103000020E61000000100000005000000D845D1031FF94E401E6E8786C5204C40D845D1031FF94E404D486B0C3A234C40C4793881E9FC4E404D486B0C3A234C40C4793881E9FC4E401E6E8786C5204C40D845D1031FF94E401E6E8786C5204C40
21344	Первомайский	6	56	1596	61.579656	61.60145	56.4985	56.487442999999999	0103000020E610000001000000050000001077F52A32CA4E4002D53F88643E4C401077F52A32CA4E402B8716D9CE3F4C40F0164850FCCC4E402B8716D9CE3F4C40F0164850FCCC4E4002D53F88643E4C401077F52A32CA4E4002D53F88643E4C40
49996	Новый Завод	6	56	1596	61.847265	61.875633000000001	56.459640999999998	56.445239999999998	0103000020E61000000100000005000000D105F52D73EC4E407E6FD39FFD384C40D105F52D73EC4E404B732B84D53A4C403126FDBD14F04E404B732B84D53A4C403126FDBD14F04E407E6FD39FFD384C40D105F52D73EC4E407E6FD39FFD384C40
25931	Новый Быт	6	56	1596	61.907299000000002	61.917549000000001	56.192805999999997	56.185682999999997	0103000020E61000000100000005000000C558A65F22F44E402A36E675C4174C40C558A65F22F44E407D3CF4DDAD184C401FBDE13E72F54E407D3CF4DDAD184C401FBDE13E72F54E402A36E675C4174C40C558A65F22F44E402A36E675C4174C40
23558	Новоисетское	6	56	1596	62.134312000000001	62.156177	56.3718	56.360930000000003	0103000020E61000000100000005000000EDBAB72231114F40991249F4322E4C40EDBAB72231114F408F537424972F4C4096B1A19BFD134F408F537424972F4C4096B1A19BFD134F40991249F4322E4C40EDBAB72231114F40991249F4322E4C40
27758	Монастырка	6	56	1596	61.989503999999997	62.02373	56.391471000000003	56.375518	0103000020E610000001000000050000006EA12B11A8FE4E4098874CF910304C406EA12B11A8FE4E408D2AC3B81B324C4090F7AA9509034F408D2AC3B81B324C4090F7AA9509034F4098874CF910304C406EA12B11A8FE4E4098874CF910304C40
49919	Мартюш	6	56	1596	61.873963000000003	61.898575999999998	56.404752000000002	56.390020999999997	0103000020E6100000010000000500000000750305DEEF4E4069E04735EC314C4000750305DEEF4E40CC7EDDE9CE334C40397CD28904F34E40CC7EDDE9CE334C40397CD28904F34E4069E04735EC314C4000750305DEEF4E4069E04735EC314C40
61234	Маминское	6	56	1596	61.379044999999998	61.421553000000003	56.456795999999997	56.430196000000002	0103000020E610000001000000050000002D5BEB8B84B04E405D6F9BA910374C402D5BEB8B84B04E40C878944A783A4C40EE43DE72F5B54E40C878944A783A4C40EE43DE72F5B54E405D6F9BA910374C402D5BEB8B84B04E405D6F9BA910374C40
24429	Ленинский	6	56	1596	61.274650999999999	61.285026999999999	56.415480000000002	56.409219999999998	0103000020E61000000100000005000000276893C327A34E403F6F2A5261344C40276893C327A34E403012DA722E354C400EBDC5C37BA44E403012DA722E354C400EBDC5C37BA44E403F6F2A5261344C40276893C327A34E403F6F2A5261344C40
49878	Лебяжье	6	56	1596	61.652752	61.664636999999999	56.550519000000001	56.541791000000003	0103000020E610000001000000050000000533A6608DD34E403222516859454C400533A6608DD34E40CF69166877464C40145B41D312D54E40CF69166877464C40145B41D312D54E403222516859454C400533A6608DD34E403222516859454C40
53061	Кремлёвка	6	56	1596	61.961440000000003	61.974960000000003	56.468756999999997	56.458556999999999	0103000020E610000001000000050000007B88467710FB4E400A2DEBFEB13A4C407B88467710FB4E40B262B83A003C4C403F74417DCBFC4E40B262B83A003C4C403F74417DCBFC4E400A2DEBFEB13A4C407B88467710FB4E400A2DEBFEB13A4C40
24888	Колчедан	6	56	1596	62.170065000000001	62.237411999999999	56.376021999999999	56.351061000000001	0103000020E61000000100000005000000DD989EB0C4154F4056F31C91EF2C4C40DD989EB0C4154F40CB49287D21304C40C7D63384631E4F40CB49287D21304C40C7D63384631E4F4056F31C91EF2C4C40DD989EB0C4154F4056F31C91EF2C4C40
25645	Клевакинское	6	56	1596	61.710236000000002	61.746698000000002	56.591831999999997	56.571649999999998	0103000020E610000001000000050000008F386403E9DA4E401361C3D32B494C408F386403E9DA4E40F65CA626C14B4C408BFED0CC93DF4E40F65CA626C14B4C408BFED0CC93DF4E401361C3D32B494C408F386403E9DA4E401361C3D32B494C40
23755	Горный	6	56	1596	61.58493	61.596634999999999	56.435929000000002	56.430947000000003	0103000020E6100000010000000500000082397AFCDECA4E4098A7734529374C4082397AFCDECA4E4062307F85CC374C40115322895ECC4E4062307F85CC374C40115322895ECC4E4098A7734529374C4082397AFCDECA4E4098A7734529374C40
23461	Брод	6	56	1596	61.835020999999998	61.858341000000003	56.416345999999997	56.405903000000002	0103000020E61000000100000005000000923CD7F7E1EA4E40952C27A1F4334C40923CD7F7E1EA4E4003E962D34A354C4071E82D1EDEED4E4003E962D34A354C4071E82D1EDEED4E40952C27A1F4334C40923CD7F7E1EA4E40952C27A1F4334C40
25075	Большая Грязнуха	6	56	1596	62.069794999999999	62.093662999999999	56.436148000000003	56.418371999999998	0103000020E610000001000000050000005036E50AEF084F40F3C7B4368D354C405036E50AEF084F40A01B9AB2D3374C4031EC3026FD0B4F40A01B9AB2D3374C4031EC3026FD0B4F40F3C7B4368D354C405036E50AEF084F40F3C7B4368D354C40
25662	Белоносова	6	56	1596	61.595629000000002	61.635154	56.615009999999998	56.605558000000002	0103000020E610000001000000050000004CC631923DCC4E4064EAAEEC824D4C404CC631923DCC4E40425BCEA5B84E4C4038F6ECB94CD14E40425BCEA5B84E4C4038F6ECB94CD14E4064EAAEEC824D4C404CC631923DCC4E4064EAAEEC824D4C40
26139	Барабановское	6	56	1596	61.851261999999998	61.891416999999997	56.305764000000003	56.296894000000002	0103000020E61000000100000005000000ED293927F6EC4E407730629F00264C40ED293927F6EC4E40A725564623274C40990CC7F319F24E40A725564623274C40990CC7F319F24E407730629F00264C40ED293927F6EC4E407730629F00264C40
49839	Ирбит	6	56	6985	63.005606	63.103791999999999	57.695076	57.644934999999997	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
19003	Хорпия	6	56	1444	60.524352	60.546989000000004	61.284728000000001	61.278196000000001	0103000020E61000000100000005000000CDCB61F71D434E4063F030ED9BA34E40CDCB61F71D434E40B42094F771A44E40C9224DBC03464E40B42094F771A44E40C9224DBC03464E4063F030ED9BA34E40CDCB61F71D434E4063F030ED9BA34E40
19316	Старая Сама	6	56	1444	60.344617	60.382040000000003	60.205942999999998	60.194960000000002	0103000020E61000000100000005000000A452EC681C2C4E409B030473F4184E40A452EC681C2C4E4089EB18575C1A4E40C6E1CCAFE6304E4089EB18575C1A4E40C6E1CCAFE6304E409B030473F4184E40A452EC681C2C4E409B030473F4184E40
18998	Северный	6	56	1444	60.388652	60.401587999999997	60.987290999999999	60.977815999999997	0103000020E6100000010000000500000033C34659BF314E40B5C01E13297D4E4033C34659BF314E404C512E8D5F7E4E40A73B4F3C67334E404C512E8D5F7E4E40A73B4F3C67334E40B5C01E13297D4E4033C34659BF314E40B5C01E13297D4E40
16308	Пелым	6	56	1444	61.975121999999999	62.005754000000003	61.023615999999997	61.011710000000001	0103000020E6100000010000000500000018CE35CCD0FC4E40A18499B67F814E4018CE35CCD0FC4E40C7D45DD905834E401DE90C8CBC004F40C7D45DD905834E401DE90C8CBC004F40A18499B67F814E4018CE35CCD0FC4E40A18499B67F814E40
19514	Оус	6	56	1444	61.499670000000002	61.527276000000001	60.914991999999998	60.892187999999997	0103000020E610000001000000050000006B65C22FF5BF4E401BF1643733724E406B65C22FF5BF4E40020D36751E754E409CFBABC77DC34E40020D36751E754E409CFBABC77DC34E401BF1643733724E406B65C22FF5BF4E401BF1643733724E40
19413	Маслово	6	56	1444	60.449576	60.487358999999998	60.124209	60.102082000000003	0103000020E610000001000000050000008388D4B48B394E4051C1E105110D4E408388D4B48B394E40376F9C14E60F4E40A4349BC7613E4E40376F9C14E60F4E40A4349BC7613E4E4051C1E105110D4E408388D4B48B394E4051C1E105110D4E40
19159	Екатерининка	6	56	1444	60.415871000000003	60.444419000000003	60.423907999999997	60.413348999999997	0103000020E610000001000000050000006B2DCC423B354E40CA6ABA9EE8344E406B2DCC423B354E40A2410A9E42364E404B5CC7B8E2384E40A2410A9E42364E404B5CC7B8E2384E40CA6ABA9EE8344E406B2DCC423B354E40CA6ABA9EE8344E40
19218	Денежкино	6	56	1444	60.398254999999999	60.419437000000002	60.223146999999997	60.206806	0103000020E61000000100000005000000F73B1405FA324E40EC4E779E781A4E40F73B1405FA324E40AA99B514901C4E40BEDD921CB0354E40AA99B514901C4E40BEDD921CB0354E40EC4E779E781A4E40F73B1405FA324E40EC4E779E781A4E40
16461	Атымья	6	56	1444	62.277943999999998	62.301290999999999	61.080438000000001	61.066555000000001	0103000020E61000000100000005000000490F43AB93234F405131CEDF84884E40490F43AB93234F4086ADD9CA4B8A4E4021CA17B490264F4086ADD9CA4B8A4E4021CA17B490264F405131CEDF84884E40490F43AB93234F405131CEDF84884E40
15815	Шабровский	6	56	964	60.560687999999999	60.641734	56.649627000000002	56.624716999999997	0103000020E610000001000000050000003CA1D79FC4474E40AB2006BAF64F4C403CA1D79FC4474E409FCC3FFA26534C409A5DF75624524E409FCC3FFA26534C409A5DF75624524E40AB2006BAF64F4C403CA1D79FC4474E40AB2006BAF64F4C40
8040	Северка	6	56	964	60.280943999999998	60.316419000000003	56.879043000000003	56.855206000000003	0103000020E61000000100000005000000F30016F9F5234E40E7ABE463776D4C40F30016F9F5234E408D63247B84704C40A16AF46A80284E408D63247B84704C40A16AF46A80284E40E7ABE463776D4C40F30016F9F5234E40E7ABE463776D4C40
50101	Рудный	6	56	964	60.012222000000001	60.943604000000001	56.962198000000001	56.604092000000001	0103000020E610000001000000050000005725917D90014E403BE3FBE2524D4C405725917D90014E406823D74D297B4C40F92F1004C8784E406823D74D297B4C40F92F1004C8784E403BE3FBE2524D4C405725917D90014E403BE3FBE2524D4C40
48180	Мостовка	6	56	964	60.849353000000001	60.853180000000002	56.812907000000003	56.810442999999999	0103000020E6100000010000000500000037E15E99B76C4E40D522A298BC674C4037E15E99B76C4E4041D829560D684C40F7CC9200356D4E4041D829560D684C40F7CC9200356D4E40D522A298BC674C4037E15E99B76C4E40D522A298BC674C40
49986	Медный	6	56	964	60.372959000000002	60.386963000000002	56.776176999999997	56.766835	0103000020E61000000100000005000000DBDFD91EBD2F4E40CE3637A627624C40DBDFD91EBD2F4E40257497C459634C408BE1EA0088314E40257497C459634C408BE1EA0088314E40CE3637A627624C40DBDFD91EBD2F4E40CE3637A627624C40
15884	Горный Щит	6	56	964	60.502198999999997	60.540404000000002	56.696776999999997	56.670188000000003	0103000020E61000000100000005000000BD8A8C0E48404E40F9156BB8C8554C40BD8A8C0E48404E4070CD1DFD2F594C40555051F52B454E4070CD1DFD2F594C40555051F52B454E40F9156BB8C8554C40BD8A8C0E48404E40F9156BB8C8554C40
10550	Среднеуральск	6	56	312	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
47122	Соколовка	6	56	312	60.625053000000001	60.633496999999998	57.083598000000002	57.078355000000002	0103000020E6100000010000000500000023A298BC01504E40323D6189078A4C4023A298BC01504E406901DA56B38A4C409B8E006E16514E406901DA56B38A4C409B8E006E16514E40323D6189078A4C4023A298BC01504E40323D6189078A4C40
47031	Санаторный	6	56	312	60.546495	60.563806	57.021304000000001	57.008651999999998	0103000020E61000000100000005000000B936548CF3454E40C2853C821B814C40B936548CF3454E4012A3E716BA824C40F0A485CB2A484E4012A3E716BA824C40F0A485CB2A484E40C2853C821B814C40B936548CF3454E40C2853C821B814C40
1406	Мостовское	6	56	312	60.641007000000002	60.655262999999998	57.168585	57.157510000000002	0103000020E61000000100000005000000E8C072840C524E408065A54929944C40E8C072840C524E404FCC7A3194954C40B1A371A8DF534E404FCC7A3194954C40B1A371A8DF534E408065A54929944C40E8C072840C524E408065A54929944C40
47129	Красный	6	56	312	60.666744000000001	60.703817000000001	57.062089999999998	57.046430000000001	0103000020E61000000100000005000000F1660DDE57554E40D2C6116BF1854C40F1660DDE57554E404EB4AB90F2874C4036AFEAAC165A4E404EB4AB90F2874C4036AFEAAC165A4E40D2C6116BF1854C40F1660DDE57554E40D2C6116BF1854C40
13208	Исеть	6	56	312	60.347805999999999	60.389847000000003	56.988531000000002	56.966898999999998	0103000020E6100000010000000500000021AD31E8842C4E407EC4AF58C37B4C4021AD31E8842C4E40850A0E2F887E4C40CCB8A981E6314E40850A0E2F887E4C40CCB8A981E6314E407EC4AF58C37B4C4021AD31E8842C4E407EC4AF58C37B4C40
13497	Балтым	6	56	312	60.593055	60.614640999999999	57.003348000000003	56.987163000000002	0103000020E6100000010000000500000059DDEA39E94B4E401F69705B5B7E4C4059DDEA39E94B4E40E6400FB56D804C40EFE3688EAC4E4E40E6400FB56D804C40EFE3688EAC4E4E401F69705B5B7E4C4059DDEA39E94B4E401F69705B5B7E4C40
49942	Солнечный	6	56	136	61.195284999999998	61.205077000000003	57.131276999999997	57.121344999999998	0103000020E610000001000000050000001E335019FF984E403D44A33B888F4C401E335019FF984E40C6DB4AAFCD904C40B61490F63F9A4E40C6DB4AAFCD904C40B61490F63F9A4E403D44A33B888F4C401E335019FF984E403D44A33B888F4C40
48966	Октябрьский	6	56	136	60.727173000000001	60.748328999999998	57.038679000000002	57.030273999999999	0103000020E6100000010000000500000061C43E01145D4E40A5F5B704E0834C4061C43E01145D4E406005F86EF3844C40FED2A23EC95F4E406005F86EF3844C40FED2A23EC95F4E40A5F5B704E0834C4061C43E01145D4E40A5F5B704E0834C40
50105	Монетный	6	56	136	60.832438000000003	60.927461999999998	57.078212999999998	57.037537999999998	0103000020E610000001000000050000004DF910548D6A4E40BA2D910BCE844C404DF910548D6A4E409F8F32E2028A4C4031242713B7764E409F8F32E2028A4C4031242713B7764E40BA2D910BCE844C404DF910548D6A4E40BA2D910BCE844C40
49941	Лубяной	6	56	136	61.119638000000002	61.150036999999998	57.116712	57.108618999999997	0103000020E61000000100000005000000EFAD484C508F4E40B35C363AE78D4C40EFAD484C508F4E407F86376BF08E4C405018946934934E407F86376BF08E4C405018946934934E40B35C363AE78D4C40EFAD484C508F4E40B35C363AE78D4C40
49938	Лосиный	6	56	136	61.047494	61.081189999999999	57.158496	57.129592000000002	0103000020E61000000100000005000000CC608C4814864E4060E97C7896904C40CC608C4814864E40FE45D09849944C409161156F648A4E40FE45D09849944C409161156F648A4E4060E97C7896904C40CC608C4814864E4060E97C7896904C40
49943	Безречный	6	56	136	61.062865000000002	61.079042999999999	57.085197999999998	57.069391000000003	0103000020E610000001000000050000001288D7F50B884E4081D1E5CDE1884C401288D7F50B884E40A1D79FC4E78A4C4026FDBD141E8A4E40A1D79FC4E78A4C4026FDBD141E8A4E4081D1E5CDE1884C401288D7F50B884E4081D1E5CDE1884C40
15724	Рефтинский	6	56	1393	61.659041000000002	61.689591999999998	57.098562999999999	57.080077000000003	0103000020E6100000010000000500000090DC9A745BD44E40B61490F63F8A4C4090DC9A745BD44E403ECC5EB69D8C4C40A7CAF78C44D84E403ECC5EB69D8C4C40A7CAF78C44D84E40B61490F63F8A4C4090DC9A745BD44E40B61490F63F8A4C40
61170	Малышева	6	56	1393	61.385593	61.405301999999999	57.127510999999998	57.101227000000002	0103000020E610000001000000050000008448861C5BB14E40713C9F01F58C4C408448861C5BB14E40AC70CB4752904C406F8099EFE0B34E40AC70CB4752904C406F8099EFE0B34E40713C9F01F58C4C408448861C5BB14E40713C9F01F58C4C40
50145	Красноармейский	6	56	1393	61.304071	61.313144000000001	56.999966000000001	56.997137000000002	0103000020E61000000100000005000000BD546CCCEBA64E40D7506A2FA27F4C40BD546CCCEBA64E40548EC9E2FE7F4C402578431A15A84E40548EC9E2FE7F4C402578431A15A84E40D7506A2FA27F4C40BD546CCCEBA64E40D7506A2FA27F4C40
6564	Нейво-Шайтанский	6	56	825	61.223672000000001	61.272126999999998	57.741318999999997	57.715792	0103000020E61000000100000005000000F583BA48A19C4E40855E7F129FDB4C40F583BA48A19C4E40A3737E8AE3DE4C40E6ADBA0ED5A24E40A3737E8AE3DE4C40E6ADBA0ED5A24E40855E7F129FDB4C40F583BA48A19C4E40855E7F129FDB4C40
6271	Мелкозёрово	6	56	825	61.495341000000003	61.526888999999997	57.755885999999997	57.740617999999998	0103000020E6100000010000000500000019AF795567BF4E401A6A1492CCDE4C4019AF795567BF4E408BC058DFC0E04C40A2CF471971C34E408BC058DFC0E04C40A2CF471971C34E401A6A1492CCDE4C4019AF795567BF4E401A6A1492CCDE4C40
6078	Западный	6	56	825	61.598773000000001	61.626620000000003	57.872748999999999	57.862011000000003	0103000020E61000000100000005000000295DFA97A4CC4E4069E55E6056EE4C40295DFA97A4CC4E40F04E3E3DB6EF4C4080828B1535D04E40F04E3E3DB6EF4C4080828B1535D04E4069E55E6056EE4C40295DFA97A4CC4E4069E55E6056EE4C40
6141	Асбестовский	6	56	825	61.380454999999998	61.410333000000001	57.762445	57.749158000000001	0103000020E61000000100000005000000C24CDBBFB2B04E40B5C4CA68E4DF4C40C24CDBBFB2B04E40D6FF39CC97E14C401BBCAFCA85B44E40D6FF39CC97E14C401BBCAFCA85B44E40B5C4CA68E4DF4C40C24CDBBFB2B04E40B5C4CA68E4DF4C40
2905	Шамары	6	56	457	58.191175000000001	58.240420999999998	57.362991999999998	57.319763999999999	0103000020E610000001000000050000000A68226C78184D401538D906EEA84C400A68226C78184D40D55A988576AE4C40C422861DC61E4D40D55A988576AE4C40C422861DC61E4D401538D906EEA84C400A68226C78184D401538D906EEA84C40
2670	Шаля	6	56	457	58.706018	58.765594	57.270187999999997	57.236539999999998	0103000020E6100000010000000500000094313ECC5E5A4D40111956F1469E4C4094313ECC5E5A4D40C5E2378595A24C40C501F4FBFE614D40C5E2378595A24C40C501F4FBFE614D40111956F1469E4C4094313ECC5E5A4D40111956F1469E4C40
3638	Чусовое (Шайтанка)	6	56	457	59.233984999999997	59.263314999999999	57.352156000000001	57.332213000000003	0103000020E6100000010000000500000095607138F39D4D402D27A1F485AA4C4095607138F39D4D408B8BA37213AD4C40EBC5504EB4A14D408B8BA37213AD4C40EBC5504EB4A14D402D27A1F485AA4C4095607138F39D4D402D27A1F485AA4C40
47506	Сылва	6	56	457	58.760393000000001	58.801606999999997	57.326393000000003	57.300037000000003	0103000020E61000000100000005000000BD8DCD8E54614D40844BC79C67A64C40BD8DCD8E54614D405952EE3EC7A94C40519FE40E9B664D405952EE3EC7A94C40519FE40E9B664D40844BC79C67A64C40BD8DCD8E54614D40844BC79C67A64C40
17069	Староуткинск	6	56	457	59.302840000000003	59.370384999999999	57.243743000000002	57.216163000000002	0103000020E61000000100000005000000D8F50B76C3A64D4079CDAB3AAB9B4C40D8F50B76C3A64D4081D07AF8329F4C40E8F692C668AF4D4081D07AF8329F4C40E8F692C668AF4D4079CDAB3AAB9B4C40D8F50B76C3A64D4079CDAB3AAB9B4C40
3365	Сарга	6	56	457	58.925457999999999	58.954985999999998	57.206161000000002	57.189459999999997	0103000020E6100000010000000500000029E9616875764D4038F3AB3940984C4029E9616875764D40F75AD07B639A4C40A51133FB3C7A4D40F75AD07B639A4C40A51133FB3C7A4D4038F3AB3940984C4029E9616875764D4038F3AB3940984C40
61299	Роща (Большие Урмы)	6	56	457	58.222814	58.255125999999997	57.585737000000002	57.566958999999997	0103000020E61000000100000005000000A48B4D2B851C4D402096CD1C92C84C40A48B4D2B851C4D405187156EF9CA4C40FD2D01F8A7204D405187156EF9CA4C40FD2D01F8A7204D402096CD1C92C84C40A48B4D2B851C4D402096CD1C92C84C40
47405	Платоново	6	56	457	58.152062999999998	58.182398999999997	57.480038999999998	57.467292	0103000020E6100000010000000500000040F7E5CC76134D405AD76839D0BB4C4040F7E5CC76134D40FBE6FEEA71BD4C405BE9B5D958174D40FBE6FEEA71BD4C405BE9B5D958174D405AD76839D0BB4C4040F7E5CC76134D405AD76839D0BB4C40
47595	Мартьяново	6	56	457	59.169925999999997	59.195770000000003	57.401428000000003	57.389127999999999	0103000020E61000000100000005000000BB5E9A22C0954D409CFA40F2CEB14C40BB5E9A22C0954D406FD921FE61B34C40DBC4C9FD0E994D406FD921FE61B34C40DBC4C9FD0E994D409CFA40F2CEB14C40BB5E9A22C0954D409CFA40F2CEB14C40
3215	Коптелы	6	56	457	58.302503000000002	58.316490000000002	57.454045999999998	57.446201000000002	0103000020E6100000010000000500000090F8156BB8264D40A438471D1DB94C4090F8156BB8264D409770E82D1EBA4C406AC18BBE82284D409770E82D1EBA4C406AC18BBE82284D40A438471D1DB94C4090F8156BB8264D40A438471D1DB94C40
50147	Коптело-Шамары	6	56	457	58.265267999999999	58.287942000000001	57.400782999999997	57.386659000000002	0103000020E610000001000000050000007156444DF4214D401FDAC70A7EB14C407156444DF4214D4079E57ADB4CB34C408A929048DB244D4079E57ADB4CB34C408A929048DB244D401FDAC70A7EB14C407156444DF4214D401FDAC70A7EB14C40
3542	Колпаковка	6	56	457	58.790379000000001	58.835419999999999	57.463594000000001	57.446390000000001	0103000020E61000000100000005000000FC389A232B654D4077A1B94E23B94C40FC389A232B654D40984F560C57BB4C405036E50AEF6A4D40984F560C57BB4C405036E50AEF6A4D4077A1B94E23B94C40FC389A232B654D4077A1B94E23B94C40
3480	Илим	6	56	457	58.951213000000003	58.980452999999997	57.374175000000001	57.358400000000003	0103000020E61000000100000005000000D943FB58C1794D4076711B0DE0AD4C40D943FB58C1794D408BFD65F7E4AF4C40EE21E17B7F7D4D408BFD65F7E4AF4C40EE21E17B7F7D4D4076711B0DE0AD4C40D943FB58C1794D4076711B0DE0AD4C40
47367	Гора	6	56	457	58.211567000000002	58.228976000000003	57.369428999999997	57.358094000000001	0103000020E61000000100000005000000D8F4A0A0141B4D4069723106D6AD4C40D8F4A0A0141B4D40D498107349AF4C40D2C8E7154F1D4D40D498107349AF4C40D2C8E7154F1D4D4069723106D6AD4C40D8F4A0A0141B4D4069723106D6AD4C40
29739	Вогулка	6	56	457	58.501407999999998	58.541032999999999	57.341132000000002	57.328505999999997	0103000020E61000000100000005000000F4F928232E404D4017450F7C0CAA4C40F4F928232E404D403ECF9F36AAAB4C404487C09140454D403ECF9F36AAAB4C404487C09140454D4017450F7C0CAA4C40F4F928232E404D4017450F7C0CAA4C40
50179	Сабик	6	56	7043	59.176608999999999	59.204259	57.119762000000001	57.102234000000003	0103000020E61000000100000005000000F296AB1F9B964D400745F300168D4C40F296AB1F9B964D40DBA6785C548F4C40F374AE28259A4D40DBA6785C548F4C40F374AE28259A4D400745F300168D4C40F296AB1F9B964D400745F300168D4C40
50203	Унь	6	56	7041	58.674360999999998	58.693181000000003	57.590397000000003	57.581322	0103000020E610000001000000050000005359147651564D40003961C268CA4C405359147651564D400954FF2092CB4C40B39AAE27BA584D400954FF2092CB4C40B39AAE27BA584D40003961C268CA4C405359147651564D40003961C268CA4C40
1743	Шухруповское	6	56	2	63.480752000000003	63.511240999999998	58.095452000000002	58.082126000000002	0103000020E6100000010000000500000049BE124889BD4F405E13D21A830A4D4049BE124889BD4F403D2B69C5370C4D40EAAF575870C14F403D2B69C5370C4D40EAAF575870C14F405E13D21A830A4D4049BE124889BD4F405E13D21A830A4D40
2212	Чукреевское	6	56	2	63.204107	63.228459999999998	58.069986	58.060859000000001	0103000020E610000001000000050000003DF19C2D209A4F4069554B3ACA074D403DF19C2D209A4F40C4961E4DF5084D40DA38622D3E9D4F40C4961E4DF5084D40DA38622D3E9D4F4069554B3ACA074D403DF19C2D209A4F4069554B3ACA074D40
1405	Чекуново	6	56	2	63.717198000000003	63.732244000000001	58.080379999999998	58.071232999999999	0103000020E61000000100000005000000D960E124CDDB4F40AFB2B6291E094D40D960E124CDDB4F4051A04FE4490A4D409B58E02BBADD4F4051A04FE4490A4D409B58E02BBADD4F40AFB2B6291E094D40D960E124CDDB4F40AFB2B6291E094D40
1516	Фабричное	6	56	2	63.744264000000001	63.783555999999997	58.104402999999998	58.087212999999998	0103000020E610000001000000050000008ACBF10A44DF4F409D64ABCB290B4D408ACBF10A44DF4F40594DD7135D0D4D40D34A21904BE44F40594DD7135D0D4D40D34A21904BE44F409D64ABCB290B4D408ACBF10A44DF4F409D64ABCB290B4D40
2104	Усениново	6	56	2	63.379286999999998	63.403568999999997	58.083416	58.076549	0103000020E610000001000000050000002366F6798CB04F4050C58D5BCC094D402366F6798CB04F4048FB1F60AD0A4D40F7562426A8B34F4048FB1F60AD0A4D40F7562426A8B34F4050C58D5BCC094D402366F6798CB04F4050C58D5BCC094D40
4	Туринск	6	56	2	63.661197000000001	63.733224	58.068415000000002	58.014274	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
1642	Смычка	6	56	2	63.767969999999998	63.803220000000003	58.061644999999999	58.045487000000001	0103000020E61000000100000005000000912749D74CE24F4053B29C84D2054D40912749D74CE24F40207BBDFBE3074D401FBFB7E9CFE64F40207BBDFBE3074D401FBFB7E9CFE64F4053B29C84D2054D40912749D74CE24F4053B29C84D2054D40
1980	Назарово	6	56	2	63.365533999999997	63.387245999999998	57.968089999999997	57.959220000000002	0103000020E61000000100000005000000BCC96FD1C9AE4F40A6D590B8C7FA4C40BCC96FD1C9AE4F40D5CA845FEAFB4C40DFC0E44691B14F40D5CA845FEAFB4C40DFC0E44691B14F40A6D590B8C7FA4C40BCC96FD1C9AE4F40A6D590B8C7FA4C40
1184	Липовское	6	56	2	63.850517000000004	63.886358999999999	57.862321999999999	57.848632000000002	0103000020E6100000010000000500000095D8B5BDDDEC4F40672B2FF99FEC4C4095D8B5BDDDEC4F40874F3A9160EE4C40F4C1323674F14F40874F3A9160EE4C40F4C1323674F14F40672B2FF99FEC4C4095D8B5BDDDEC4F40672B2FF99FEC4C40
1855	Леонтьевское	6	56	2	63.494199999999999	63.534534000000001	58.043343	58.036811999999998	0103000020E6100000010000000500000073D712F241BF4F40D80C7041B6044D4073D712F241BF4F4059C16F438C054D40CF4C309C6BC44F4059C16F438C054D40CF4C309C6BC44F40D80C7041B6044D4073D712F241BF4F40D80C7041B6044D40
2563	Ленское	6	56	2	63.180974999999997	63.219279	58.161222000000002	58.149731000000003	0103000020E61000000100000005000000613255302A974F404419AA622A134D40613255302A974F40A7B228ECA2144D408CD99255119C4F40A7B228ECA2144D408CD99255119C4F404419AA622A134D40613255302A974F404419AA622A134D40
1054	Коркинское	6	56	2	63.787823000000003	63.818787999999998	57.977077999999999	57.962428000000003	0103000020E61000000100000005000000B0045262D7E44F409A6038D730FB4C40B0045262D7E44F400FD253E410FD4C40BA2D910BCEE84F400FD253E410FD4C40BA2D910BCEE84F409A6038D730FB4C40B0045262D7E44F409A6038D730FB4C40
946	Ерзовское	6	56	2	63.708655	63.731634	58.008448000000001	58.000813000000001	0103000020E61000000100000005000000CD920035B5DA4F40B134F0A31A004D40CD920035B5DA4F40BADBF5D214014D402252D32EA6DD4F40BADBF5D214014D402252D32EA6DD4F40B134F0A31A004D40CD920035B5DA4F40B134F0A31A004D40
2334	Дымковское	6	56	2	63.058022999999999	63.082636999999998	58.073965000000001	58.062277999999999	0103000020E6100000010000000500000039B5334C6D874F4051A1BAB9F8074D4039B5334C6D874F403A0664AF77094D40433866D9938A4F403A0664AF77094D40433866D9938A4F4051A1BAB9F8074D4039B5334C6D874F4051A1BAB9F8074D40
1290	Городище	6	56	2	63.904065000000003	63.916884000000003	57.975603	57.960557000000001	0103000020E61000000100000005000000A83AE466B8F34F40D1782288F3FA4C40A83AE466B8F34F409370218FE0FC4C40E31C75745CF54F409370218FE0FC4C40E31C75745CF54F40D1782288F3FA4C40A83AE466B8F34F40D1782288F3FA4C40
2446	Благовещенское	6	56	2	62.946002999999997	62.970123000000001	58.143498999999998	58.130780999999999	0103000020E610000001000000050000007D7555A016794F4016F88A6EBD104D407D7555A016794F401D01DC2C5E124D40780C8FFD2C7C4F401D01DC2C5E124D40780C8FFD2C7C4F4016F88A6EBD104D407D7555A016794F4016F88A6EBD104D40
61340	п. ж/д станции Тугулым	6	56	1628	64.070989999999995	65.237290999999999	57.397596999999998	56.734499	0103000020E61000000100000005000000F415A4198B045040ECF82F10045E4C40F415A4198B0450406DFE5F75E4B24C40A62897C62F4F50406DFE5F75E4B24C40A62897C62F4F5040ECF82F10045E4C40F415A4198B045040ECF82F10045E4C40
61331	Яр	6	56	1628	64.070989999999995	65.237290999999999	57.397596999999998	56.734499	0103000020E61000000100000005000000F415A4198B045040ECF82F10045E4C40F415A4198B0450406DFE5F75E4B24C40A62897C62F4F50406DFE5F75E4B24C40A62897C62F4F5040ECF82F10045E4C40F415A4198B045040ECF82F10045E4C40
30264	Юшкова	6	56	1628	64.705515000000005	64.727182999999997	57.127637999999997	57.116985999999997	0103000020E6100000010000000500000099F56228272D5040800BB265F98E4C4099F56228272D504009DD257156904C4042CD902A8A2E504009DD257156904C4042CD902A8A2E5040800BB265F98E4C4099F56228272D5040800BB265F98E4C40
31428	Юшала	6	56	1628	64.242559	64.286064999999994	57.086924000000003	57.066426	0103000020E610000001000000050000006E162F16860F504053CDACA580884C406E162F16860F5040679E5C53208B4C40EFE192E34E125040679E5C53208B4C40EFE192E34E12504053CDACA580884C406E162F16860F504053CDACA580884C40
31802	Щелконогова	6	56	1628	64.431098000000006	64.445910999999995	57.202232000000002	57.192073999999998	0103000020E61000000100000005000000BFD7101C971B5040B9347EE195984C40BFD7101C971B5040331AF9BCE2994C404E7B4ACE891C5040331AF9BCE2994C404E7B4ACE891C5040B9347EE195984C40BFD7101C971B5040B9347EE195984C40
29557	Филина	6	56	1628	64.775665000000004	64.806019000000006	57.058262999999997	57.050597000000003	0103000020E61000000100000005000000B8E9CF7EA43150404B2366F679864C40B8E9CF7EA43150408EC8772975874C40193DB7D0953350408EC8772975874C40193DB7D0953350404B2366F679864C40B8E9CF7EA43150404B2366F679864C40
20423	Тямкина	6	56	1628	64.603862000000007	64.617497999999998	57.160024	57.154800999999999	0103000020E610000001000000050000000553CDACA5265040AD31E884D0934C400553CDACA52650409D499BAA7B944C401BD65416852750409D499BAA7B944C401BD6541685275040AD31E884D0934C400553CDACA5265040AD31E884D0934C40
20436	Тугулым	6	56	1628	64.616536999999994	64.663645000000002	57.068618000000001	57.047694	0103000020E6100000010000000500000088F19A5775275040931B45D61A864C4088F19A57752750405EF58079C8884C40DAC9E028792A50405EF58079C8884C40DAC9E028792A5040931B45D61A864C4088F19A5775275040931B45D61A864C40
32024	Трошково	6	56	1628	64.393655999999993	64.421486000000002	57.3371	57.317689000000001	0103000020E61000000100000005000000F277EFA83119504044A67C08AAA84C40F277EFA831195040A5BDC11726AB4C40336E6AA0F91A5040A5BDC11726AB4C40336E6AA0F91A504044A67C08AAA84C40F277EFA83119504044A67C08AAA84C40
31216	Потаскуева	6	56	1628	64.277252000000004	64.291355999999993	56.844445999999998	56.836272999999998	0103000020E610000001000000050000000A302C7FBE1150408FC360FE0A6B4C400A302C7FBE115040779E78CE166C4C4093DFA293A5125040779E78CE166C4C4093DFA293A51250408FC360FE0A6B4C400A302C7FBE1150408FC360FE0A6B4C40
29979	Полушина	6	56	1628	64.959029000000001	64.973652999999999	57.180543999999998	57.167681999999999	0103000020E6100000010000000500000099BA2BBB603D50405E10919A76954C4099BA2BBB603D504098BED7101C974C40BF29AC54503E504098BED7101C974C40BF29AC54503E50405E10919A76954C4099BA2BBB603D50405E10919A76954C40
31752	Ошкуково	6	56	1628	64.539354000000003	64.571297999999999	57.094611999999998	57.079289000000003	0103000020E61000000100000005000000E0BDA3C6842250405EF75624268A4C40E0BDA3C68422504092E7FA3E1C8C4C404B917C259024504092E7FA3E1C8C4C404B917C25902450405EF75624268A4C40E0BDA3C6842250405EF75624268A4C40
49960	Остров	6	56	1628	64.871982000000003	64.890775000000005	56.984755	56.978821000000003	0103000020E61000000100000005000000D82C978DCE375040ABD1AB014A7D4C40D82C978DCE37504047C9AB730C7E4C400B4625750239504047C9AB730C7E4C400B46257502395040ABD1AB014A7D4C40D82C978DCE375040ABD1AB014A7D4C40
30619	Нижняя Коркина	6	56	1628	64.425286	64.453142	56.959724999999999	56.954374999999999	0103000020E61000000100000005000000965CC5E2371B50405C8FC2F5287A4C40965CC5E2371B5040A913D044D87A4C406B9C4D47001D5040A913D044D87A4C406B9C4D47001D50405C8FC2F5287A4C40965CC5E2371B50405C8FC2F5287A4C40
28609	Мальцево	6	56	1628	64.947405000000003	64.962504999999993	57.070785999999998	57.062486	0103000020E6100000010000000500000048C49448A23C50409B3A8F8AFF874C4048C49448A23C5040E08101840F894C40224F92AE993D5040E08101840F894C40224F92AE993D50409B3A8F8AFF874C4048C49448A23C50409B3A8F8AFF874C40
30726	Луговая	6	56	1628	64.536379999999994	64.562862999999993	56.945799000000001	56.933822999999997	0103000020E610000001000000050000009F8EC70C5422504055A0168387774C409F8EC70C5422504075CB0EF10F794C40384888F20524504075CB0EF10F794C40384888F20524504055A0168387774C409F8EC70C5422504055A0168387774C40
32281	Колобова	6	56	1628	64.717606000000004	64.729463999999993	57.089267	57.078887999999999	0103000020E61000000100000005000000755AB741ED2D5040FF058200198A4C40755AB741ED2D504057CEDE196D8B4C40FFE6C589AF2E504057CEDE196D8B4C40FFE6C589AF2E5040FF058200198A4C40755AB741ED2D5040FF058200198A4C40
29835	Кармак	6	56	1628	64.846856000000002	64.879302999999993	57.099800000000002	57.090519	0103000020E61000000100000005000000F81A82E33236504054556820968B4C40F81A82E3323650400612143FC68C4C4094111780463850400612143FC68C4C40941117804638504054556820968B4C40F81A82E33236504054556820968B4C40
30516	Калачики	6	56	1628	64.749208999999993	64.766619000000006	56.860185999999999	56.853369999999998	0103000020E610000001000000050000009B374E0AF32F50409AB1683A3B6D4C409B374E0AF32F5040103D29931A6E4C40815F234910315040103D29931A6E4C40815F2349103150409AB1683A3B6D4C409B374E0AF32F50409AB1683A3B6D4C40
31894	Ивановка	6	56	1628	64.384754000000001	64.391176999999999	57.286672000000003	57.279837000000001	0103000020E6100000010000000500000055C03DCF9F185040FA9AE5B2D1A34C4055C03DCF9F185040E75608ABB1A44C40A27C410B09195040E75608ABB1A44C40A27C410B09195040FA9AE5B2D1A34C4055C03DCF9F185040FA9AE5B2D1A34C40
32107	Зубково	6	56	1628	64.217865000000003	64.244742000000002	57.374267000000003	57.351883999999998	0103000020E610000001000000050000005B7C0A80F10D50402AFEEF880AAD4C405B7C0A80F10D50406C7C26FBE7AF4C404A7D59DAA90F50406C7C26FBE7AF4C404A7D59DAA90F50402AFEEF880AAD4C405B7C0A80F10D50402AFEEF880AAD4C40
30410	Заводоуспенское	6	56	1628	65.001259000000005	65.047701000000004	56.873972000000002	56.851253999999997	0103000020E61000000100000005000000D8F4A0A0144050406A4B1DE4F56C4C40D8F4A0A01440504053CF8250DE6F4C4023BF7E880D43504053CF8250DE6F4C4023BF7E880D4350406A4B1DE4F56C4C40D8F4A0A0144050406A4B1DE4F56C4C40
48891	Журавлёва	6	56	1628	64.571639000000005	64.580568	57.082174999999999	57.073515999999998	0103000020E610000001000000050000009087BEBB95245040CADDE7F868894C409087BEBB952450403FC6DCB5848A4C40AA46AF06282550403FC6DCB5848A4C40AA46AF0628255040CADDE7F868894C409087BEBB95245040CADDE7F868894C40
31317	Ертарский	6	56	1628	64.273345000000006	64.311487	56.806545	56.780458000000003	0103000020E610000001000000050000009CE1067C7E11504067F3380CE6634C409CE1067C7E1150404CE0D6DD3C674C4044882B67EF1350404CE0D6DD3C674C4044882B67EF13504067F3380CE6634C409CE1067C7E11504067F3380CE6634C40
61323	Дёмино	6	56	1628	64.379812999999999	64.403420999999994	56.963621000000003	56.958041000000001	0103000020E610000001000000050000001F662FDB4E185040139D6516A17A4C401F662FDB4E185040925ED4EE577B4C40416150A6D1195040925ED4EE577B4C40416150A6D1195040139D6516A17A4C401F662FDB4E185040139D6516A17A4C40
30122	Дубровина	6	56	1628	64.888996000000006	64.906234999999995	57.262990000000002	57.247537000000001	0103000020E6100000010000000500000097917A4FE538504065C6DB4AAF9F4C4097917A4FE5385040689604A8A9A14C4065DF15C1FF395040689604A8A9A14C4065DF15C1FF39504065C6DB4AAF9F4C4097917A4FE538504065C6DB4AAF9F4C40
20487	Верховино	6	56	1628	64.890396999999993	64.919368000000006	57.127212999999998	57.107005999999998	0103000020E6100000010000000500000037DDB243FC385040E63C635FB28D4C4037DDB243FC3850402250FD8348904C404B3FE1ECD63A50402250FD8348904C404B3FE1ECD63A5040E63C635FB28D4C4037DDB243FC385040E63C635FB28D4C40
31130	Большой Рамыл	6	56	1628	64.269553999999999	64.291220999999993	56.920741999999997	56.907397000000003	0103000020E6100000010000000500000062A06B5F4011504088BEBB9525744C4062A06B5F40115040DD06B5DFDA754C4023BA675DA3125040DD06B5DFDA754C4023BA675DA312504088BEBB9525744C4062A06B5F4011504088BEBB9525744C40
50177	Луговской	6	56	7042	64.505936000000005	64.555452000000002	56.967953999999999	56.947904999999999	0103000020E610000001000000050000009F77634161205040815B77F354794C409F776341612050402504ABEAE57B4C40DC9F8B868C2350402504ABEAE57B4C40DC9F8B868C235040815B77F354794C409F77634161205040815B77F354794C40
50210	Ядрышникова	6	56	7061	64.746810999999994	64.762944000000005	57.165202999999998	57.154429999999998	0103000020E61000000100000005000000C1525DC0CB2F5040B9C2BB5CC4934C40C1525DC0CB2F5040BD19355F25954C407C2B1213D4305040BD19355F25954C407C2B1213D4305040B9C2BB5CC4934C40C1525DC0CB2F5040B9C2BB5CC4934C40
49141	Чупина	6	56	1634	63.873629999999999	63.890959000000002	57.099784999999997	57.089379000000001	0103000020E61000000100000005000000F9669B1BD3EF4F407FF964C5708B4C40F9669B1BD3EF4F40D0D03FC1C58C4C40D789CBF10AF24F40D0D03FC1C58C4C40D789CBF10AF24F407FF964C5708B4C40F9669B1BD3EF4F407FF964C5708B4C40
20551	Троицкий	6	56	1634	63.697083999999997	63.786645999999998	57.073681999999998	57.047320999999997	0103000020E610000001000000050000004D486B0C3AD94F40FEB4519D0E864C404D486B0C3AD94F40E5266A696E894C40BDC3EDD0B0E44F40E5266A696E894C40BDC3EDD0B0E44F40FEB4519D0E864C404D486B0C3AD94F40FEB4519D0E864C40
27765	Трехозёрная	6	56	1634	63.594892000000002	63.614080000000001	56.639352000000002	56.623756999999998	0103000020E610000001000000050000007653CA6B25CC4F4056D3F544D74F4C407653CA6B25CC4F40EC504D49D6514C405890662C9ACE4F40EC504D49D6514C405890662C9ACE4F4056D3F544D74F4C407653CA6B25CC4F4056D3F544D74F4C40
26266	Талица	6	56	1634	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
49835	Талица	6	56	1634	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
49076	Пионерский	6	56	1634	63.732531999999999	63.764843999999997	57.114015000000002	57.096221	0103000020E6100000010000000500000001A3CB9BC3DD4F401E1840F8508C4C4001A3CB9BC3DD4F407120240B988E4C405A457F68E6E14F407120240B988E4C405A457F68E6E14F401E1840F8508C4C4001A3CB9BC3DD4F401E1840F8508C4C40
28389	Первухина	6	56	1634	64.061898999999997	64.082847999999998	57.107832000000002	57.098421000000002	0103000020E61000000100000005000000ED293927F6035040AC1E300F998C4C40ED293927F60350402CBB6070CD8D4C407FA2B2614D0550402CBB6070CD8D4C407FA2B2614D055040AC1E300F998C4C40ED293927F6035040AC1E300F998C4C40
48616	Пеньки	6	56	1634	64.103005999999993	64.119103999999993	56.691108	56.684049000000002	0103000020E61000000100000005000000AC527AA69706504046EEE9EA8E574C40AC527AA6970650408200193A76584C40A83462669F0750408200193A76584C40A83462669F07504046EEE9EA8E574C40AC527AA69706504046EEE9EA8E574C40
49228	Панова	6	56	1634	63.462336999999998	63.481434999999998	57.189138	57.174826000000003	0103000020E61000000100000005000000895DDBDB2DBB4F40C93EC8B260964C40895DDBDB2DBB4F4026378AAC35984C402B137EA99FBD4F4026378AAC35984C402B137EA99FBD4F40C93EC8B260964C40895DDBDB2DBB4F40C93EC8B260964C40
27200	Нижний Катарач	6	56	1634	64.087779999999995	64.111962000000005	56.650750000000002	56.641134000000001	0103000020E610000001000000050000008B4F01309E055040452DCDAD10524C408B4F01309E0550409EEFA7C64B534C404419AA622A0750409EEFA7C64B534C404419AA622A075040452DCDAD10524C408B4F01309E055040452DCDAD10524C40
28192	Мохирёва	6	56	1634	64.017397000000003	64.03998	57.018653999999998	57.008209999999998	0103000020E610000001000000050000001B834E081D01504005C078060D814C401B834E081D01504044F8174163824C409F1F46088F02504044F8174163824C409F1F46088F02504005C078060D814C401B834E081D01504005C078060D814C40
28285	Мака	6	56	1634	63.707684999999998	63.722830000000002	56.953688	56.948622	0103000020E61000000100000005000000546F0D6C95DA4F40102219726C794C40546F0D6C95DA4F40384BC972127A4C40AA4885B185DC4F40384BC972127A4C40AA4885B185DC4F40102219726C794C40546F0D6C95DA4F40102219726C794C40
49175	Луговая (Большая Луговая)	6	56	1634	63.648135000000003	63.667521000000001	57.061292000000002	57.050635999999997	0103000020E610000001000000050000004D327216F6D24F4008008E3D7B864C404D327216F6D24F40D3C08F6AD8874C405532005471D54F40D3C08F6AD8874C405532005471D54F4008008E3D7B864C404D327216F6D24F4008008E3D7B864C40
48970	Кузнецовский	6	56	1634	64.064117999999993	64.082012000000006	57.188586999999998	57.180934000000001	0103000020E610000001000000050000006F4562821A045040035E66D828974C406F4562821A045040B2B96A9E23984C404B7842AF3F055040B2B96A9E23984C404B7842AF3F055040035E66D828974C406F4562821A045040035E66D828974C40
48736	Красногорка	6	56	1634	63.758673000000002	63.882883	56.694094	56.664762000000003	0103000020E61000000100000005000000DAAD65321CE14F40D1CFD4EB16554C40DAAD65321CE14F40C72C7B12D8584C40E198654F02F14F40C72C7B12D8584C40E198654F02F14F40D1CFD4EB16554C40DAAD65321CE14F40D1CFD4EB16554C40
49024	Комсомольский	6	56	1634	63.931688000000001	63.953113000000002	57.124594000000002	57.110436999999997	0103000020E61000000100000005000000AF09698D41F74F4059A2B3CC228E4C40AF09698D41F74F4090A339B2F28F4C403C32569BFFF94F4090A339B2F28F4C403C32569BFFF94F4059A2B3CC228E4C40AF09698D41F74F4059A2B3CC228E4C40
27666	Казаковское	6	56	1634	63.733808000000003	63.760182	56.671978000000003	56.650364000000003	0103000020E6100000010000000500000087C5A86BEDDD4F40753FA7203F534C4087C5A86BEDDD4F40D5D0066003564C400281CEA44DE14F40D5D0066003564C400281CEA44DE14F40753FA7203F534C4087C5A86BEDDD4F40753FA7203F534C40
48687	Зарубина	6	56	1634	63.887860000000003	63.912959000000001	56.609952999999997	56.596139000000001	0103000020E610000001000000050000009AB67F65A5F14F40616F62484E4C4C409AB67F65A5F14F406D8C9DF0124E4C4060CB2BD7DBF44F406D8C9DF0124E4C4060CB2BD7DBF44F40616F62484E4C4C409AB67F65A5F14F40616F62484E4C4C40
28894	Завьяловское	6	56	1634	63.533482999999997	63.584876000000001	57.143932	57.114381000000002	0103000020E6100000010000000500000069FCC22B49C44F4053245F09A48E4C4069FCC22B49C44F40876C205D6C924C408F1B7E37DDCA4F40876C205D6C924C408F1B7E37DDCA4F4053245F09A48E4C4069FCC22B49C44F4053245F09A48E4C40
27661	Горскино	6	56	1634	63.722785000000002	63.739457999999999	56.643619000000001	56.627059000000003	0103000020E610000001000000050000000A85083884DC4F40CCD4247843504C400A85083884DC4F40C80A7E1B62524C40FE614B8FA6DE4F40C80A7E1B62524C40FE614B8FA6DE4F40CCD4247843504C400A85083884DC4F40CCD4247843504C40
28744	Горбуновское	6	56	1634	63.619317000000002	63.650803000000003	57.092030000000001	57.079963999999997	0103000020E61000000100000005000000AD6D8AC745CF4F40BD6DA6423C8A4C40AD6D8AC745CF4F401D2098A3C78B4C40C19140834DD34F401D2098A3C78B4C40C19140834DD34F40BD6DA6423C8A4C40AD6D8AC745CF4F40BD6DA6423C8A4C40
61266	Вновь-Юрмытское	6	56	1634	63.324418000000001	63.359164999999997	57.216343999999999	57.197673000000002	0103000020E61000000100000005000000EB1D6E8786A94F40AF264F594D994C40EB1D6E8786A94F40C9570229B19B4C40156F641EF9AD4F40C9570229B19B4C40156F641EF9AD4F40AF264F594D994C40EB1D6E8786A94F40AF264F594D994C40
27527	Вихляева	6	56	1634	63.961872	63.991048999999997	56.702258	56.691983	0103000020E610000001000000050000001478279F1EFB4F40A93121E692584C401478279F1EFB4F405CAD1397E3594C40E3DD91B1DAFE4F405CAD1397E3594C40E3DD91B1DAFE4F40A93121E692584C401478279F1EFB4F40A93121E692584C40
27380	Буткинское Озеро	6	56	1634	64.010327000000004	64.039306999999994	56.548484999999999	56.538876999999999	0103000020E6100000010000000500000003D19332A900504086C8E9EBF9444C4003D19332A90050405CACA8C134464C403FE08101840250405CACA8C134464C403FE081018402504086C8E9EBF9444C4003D19332A900504086C8E9EBF9444C40
26977	Бутка	6	56	1634	63.758574000000003	63.810389000000001	56.729565999999998	56.71219	0103000020E6100000010000000500000047CCECF318E14F40E544BB0A295B4C4047CCECF318E14F4003232F6B625D4C40E204A6D3BAE74F4003232F6B625D4C40E204A6D3BAE74F40E544BB0A295B4C4047CCECF318E14F40E544BB0A295B4C40
48569	Боровской	6	56	1634	63.780565000000003	63.790770000000002	56.814793999999999	56.805486000000002	0103000020E610000001000000050000007DB3CD8DE9E34F4064B14D2A1A674C407DB3CD8DE9E34F400F7D772B4B684C4037548CF337E54F400F7D772B4B684C4037548CF337E54F4064B14D2A1A674C407DB3CD8DE9E34F4064B14D2A1A674C40
49097	Бор	6	56	1634	63.459147999999999	63.467879000000003	57.058684	57.048017000000002	0103000020E610000001000000050000000C03965CC5BA4F407653CA6B25864C400C03965CC5BA4F40346612F582874C401BBE8575E3BB4F40346612F582874C401BBE8575E3BB4F407653CA6B25864C400C03965CC5BA4F407653CA6B25864C40
48938	Беляковское	6	56	1634	64.184070000000006	64.217001999999994	56.992190000000001	56.984617999999998	0103000020E610000001000000050000002F8B89CDC70B5040C6866EF6077E4C402F8B89CDC70B504089B5F814007F4C40A94A5B5CE30D504089B5F814007F4C40A94A5B5CE30D5040C6866EF6077E4C402F8B89CDC70B5040C6866EF6077E4C40
28749	Белая Елань	6	56	1634	63.672353999999999	63.704711000000003	57.021025000000002	57.007049000000002	0103000020E61000000100000005000000DAAA24B20FD64F40193C4CFBE6804C40DAAA24B20FD64F40FFB27BF2B0824C40D41055F833DA4F40FFB27BF2B0824C40D41055F833DA4F40193C4CFBE6804C40DAAA24B20FD64F40193C4CFBE6804C40
27756	Басмановское	6	56	1634	63.677222999999998	63.701360000000001	56.618397999999999	56.598194999999997	0103000020E61000000100000005000000AC8C463EAFD64F40BBD05CA7914C4C40AC8C463EAFD64F40B6F468AA274F4C407D5C1B2AC6D94F40B6F468AA274F4C407D5C1B2AC6D94F40BBD05CA7914C4C40AC8C463EAFD64F40BBD05CA7914C4C40
40352	Балаир	6	56	1634	64.019938999999994	64.049008000000001	57.172015000000002	57.156748999999998	0103000020E610000001000000050000008E3A3AAE460150402157EA5910944C408E3A3AAE46015040F2B5679604964C40834F73F222035040F2B5679604964C40834F73F2220350402157EA5910944C408E3A3AAE460150402157EA5910944C40
50207	Талица	6	56	7060	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
19987	Увал	6	56	1573	65.564862000000005	65.582289000000003	57.811535999999997	57.801293999999999	0103000020E610000001000000050000003430F2B226645040923D42CD90E64C403430F2B22664504069C36169E0E74C4084F414394465504069C36169E0E74C4084F4143944655040923D42CD90E64C403430F2B226645040923D42CD90E64C40
24821	Тавда	6	56	1573	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
48154	Ленино	6	56	1573	65.325218000000007	65.344514000000004	58.131118000000001	58.121741	0103000020E610000001000000050000008484285FD05450408ACA8635950F4D408484285FD05450405EF58079C8104D40E8C072840C5650405EF58079C8104D40E8C072840C5650408ACA8635950F4D408484285FD05450408ACA8635950F4D40
48151	Крутое	6	56	1573	65.053090999999995	65.079815999999994	58.110218000000003	58.102415000000001	0103000020E61000000100000005000000902DCBD76543504057CF49EF1B0D4D40902DCBD7654350401CB7989F1B0E4D40A46C91B41B4550401CB7989F1B0E4D40A46C91B41B45504057CF49EF1B0D4D40902DCBD76543504057CF49EF1B0D4D40
18946	Кошуки	6	56	1573	65.519029000000003	65.53546	57.967827999999997	57.956435999999997	0103000020E610000001000000050000003D2B69C537615040C85BAE7E6CFA4C403D2B69C5376150409813B4C9E1FB4C403C1405FA446250409813B4C9E1FB4C403C1405FA44625040C85BAE7E6CFA4C403D2B69C537615040C85BAE7E6CFA4C40
26018	Карьер	6	56	1573	65.092410999999998	65.111140000000006	58.051268999999998	58.041533000000001	0103000020E610000001000000050000009AB2D30FEA455040365A0EF450054D409AB2D30FEA45504039268BFB8F064D40C251F2EA1C47504039268BFB8F064D40C251F2EA1C475040365A0EF450054D409AB2D30FEA455040365A0EF450054D40
26066	Карабашка	6	56	1573	65.686960999999997	65.714798999999999	58.451901999999997	58.438974000000002	0103000020E610000001000000050000002828452BF76B5040ACE5CE4C30384D402828452BF76B50409D7FBBECD7394D40AA0D4E44BF6D50409D7FBBECD7394D40AA0D4E44BF6D5040ACE5CE4C30384D402828452BF76B5040ACE5CE4C30384D40
48079	Земляное	6	56	1573	65.059612999999999	65.071686	58.006435000000003	57.995336999999999	0103000020E61000000100000005000000A75A0BB3D0435040D7BFEB3367FF4C40A75A0BB3D04350405F46B1DCD2004D403065E080964450405F46B1DCD2004D403065E08096445040D7BFEB3367FF4C40A75A0BB3D0435040D7BFEB3367FF4C40
47275	Герасимовка	6	56	1573	65.771178000000006	65.789664999999999	58.101534999999998	58.085794999999997	0103000020E610000001000000050000004359F8FA5A71504085949F54FB0A4D404359F8FA5A7150401E335019FF0C4D40EF7211DF897250401E335019FF0C4D40EF7211DF8972504085949F54FB0A4D404359F8FA5A71504085949F54FB0A4D40
25930	Большая Пустынь	6	56	1573	65.189429000000004	65.207575000000006	57.955868000000002	57.947581999999997	0103000020E610000001000000050000007FFACF9A1F4C50409E23F25D4AF94C407FFACF9A1F4C50407FA5F3E159FA4C40E71DA7E8484D50407FA5F3E159FA4C40E71DA7E8484D50409E23F25D4AF94C407FFACF9A1F4C50409E23F25D4AF94C40
25841	Азанка	6	56	1573	64.759907999999996	64.810689999999994	58.048088	58.028162999999999	0103000020E6100000010000000500000000FE2955A230504087FA5DD89A034D4000FE2955A23050403FAA61BF27064D406E4C4F58E23350403FAA61BF27064D406E4C4F58E233504087FA5DD89A034D4000FE2955A230504087FA5DD89A034D40
50186	Тавда	6	56	7049	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
61320	Унже-Павинская	6	56	897	64.052987999999999	64.067666000000003	58.895747999999998	58.882531999999998	0103000020E6100000010000000500000026C5C7276403504034D6FECEF6704D4026C5C727640350408CBAD6DEA7724D404643C6A3540450408CBAD6DEA7724D404643C6A35404504034D6FECEF6704D4026C5C7276403504034D6FECEF6704D40
24728	Торомка	6	56	897	64.342605000000006	64.360992999999993	58.349355000000003	58.343994000000002	0103000020E610000001000000050000008D9C853DED1550409702D2FE072C4D408D9C853DED155040D8D825AAB72C4D406F4562821A175040D8D825AAB72C4D406F4562821A1750409702D2FE072C4D408D9C853DED1550409702D2FE072C4D40
6924	Таборы	6	56	897	64.526993000000004	64.575959999999995	58.531281999999997	58.511538999999999	0103000020E61000000100000005000000240ED940BA21504074D0251C7A414D40240ED940BA2150400B7A6F0C01444D4077F35487DC2450400B7A6F0C01444D4077F35487DC24504074D0251C7A414D40240ED940BA21504074D0251C7A414D40
24428	Пальмино	6	56	897	64.950907999999998	64.966575000000006	58.622644000000001	58.607332	0103000020E610000001000000050000004E603AADDB3C50403AE8120EBD4D4D404E603AADDB3C50407B8670CCB24F4D406688635DDC3D50407B8670CCB24F4D406688635DDC3D50403AE8120EBD4D4D404E603AADDB3C50403AE8120EBD4D4D40
23978	Озерки	6	56	897	64.356295000000003	64.394661999999997	58.828736999999997	58.826188999999999	0103000020E610000001000000050000009D2E8B89CD16504050A8A78FC0694D409D2E8B89CD16504019FED30D146A4D4055BE67244219504019FED30D146A4D4055BE67244219504050A8A78FC0694D409D2E8B89CD16504050A8A78FC0694D40
24531	Оверино	6	56	897	64.759504000000007	64.779824000000005	58.275852	58.266263000000002	0103000020E61000000100000005000000994BAAB69B3050404391EEE714224D40994BAAB69B305040A2444B1E4F234D40B328ECA2E8315040A2444B1E4F234D40B328ECA2E83150404391EEE714224D40994BAAB69B3050404391EEE714224D40
24275	Кузнецово	6	56	897	64.763214000000005	64.796379999999999	58.467550000000003	58.456035999999997	0103000020E610000001000000050000005C76887FD83050403AE63C635F3A4D405C76887FD8305040569FABADD83B4D4010CCD1E3F7325040569FABADD83B4D4010CCD1E3F73250403AE63C635F3A4D405C76887FD83050403AE63C635F3A4D40
24572	Добрино	6	56	897	64.358011000000005	64.368970000000004	58.276868999999998	58.264814000000001	0103000020E61000000100000005000000EE26F8A6E9165040F0C2D66CE5214D40EE26F8A6E91650405B23827170234D4021CD58349D1750405B23827170234D4021CD58349D175040F0C2D66CE5214D40EE26F8A6E9165040F0C2D66CE5214D40
23524	Щелкун	6	56	611	60.916817000000002	60.958587999999999	56.315320999999997	56.284523999999998	0103000020E610000001000000050000005BB56B425A754E40AB764D486B244C405BB56B425A754E40FA5E43705C284C40452BF702B37A4E40FA5E43705C284C40452BF702B37A4E40AB764D486B244C405BB56B425A754E40AB764D486B244C40
23456	Черданцево	6	56	611	60.927992000000003	60.958202	56.607658999999998	56.592536000000003	0103000020E610000001000000050000008E791D71C8764E40F1D93A38D84B4C408E791D71C8764E405E0F26C5C74D4C401C7BF65CA67A4E405E0F26C5C74D4C401C7BF65CA67A4E40F1D93A38D84B4C408E791D71C8764E40F1D93A38D84B4C40
61109	Сысерть	6	56	611	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
46984	Патруши	6	56	611	60.788753	60.810941	56.700879	56.682001999999997	0103000020E610000001000000050000009ACFB9DBF5644E403EE76ED74B574C409ACFB9DBF5644E4002BA2F67B6594C4026FE28EACC674E4002BA2F67B6594C4026FE28EACC674E403EE76ED74B574C409ACFB9DBF5644E403EE76ED74B574C40
50152	Патруши	6	56	611	60.788753	60.810941	56.700879	56.682001999999997	0103000020E610000001000000050000009ACFB9DBF5644E403EE76ED74B574C409ACFB9DBF5644E4002BA2F67B6594C4026FE28EACC674E4002BA2F67B6594C4026FE28EACC674E403EE76ED74B574C409ACFB9DBF5644E403EE76ED74B574C40
46892	Новоипатово	6	56	611	61.058875999999998	61.093964	56.248876000000003	56.237161999999998	0103000020E610000001000000050000007842AF3F89874E404EED0C535B1E4C407842AF3F89874E403161342BDB1F4C402C802903078C4E403161342BDB1F4C402C802903078C4E404EED0C535B1E4C407842AF3F89874E404EED0C535B1E4C40
46842	Никольское	6	56	611	60.892229999999998	60.927632000000003	56.268216000000002	56.253712	0103000020E610000001000000050000004A41B79734724E40274D83A279204C404A41B79734724E40C921E2E654224C408E5C37A5BC764E40C921E2E654224C408E5C37A5BC764E40274D83A279204C404A41B79734724E40274D83A279204C40
46823	Колос	6	56	611	60.999381	61.006979999999999	56.636971000000003	56.633158999999999	0103000020E61000000100000005000000349F73B7EB7F4E408315A75A0B514C40349F73B7EB7F4E400EC0064488514C40F0DC7BB8E4804E400EC0064488514C40F0DC7BB8E4804E408315A75A0B514C40349F73B7EB7F4E408315A75A0B514C40
50123	Ключи	6	56	611	61.052570000000003	61.077300999999999	56.642674	56.617213999999997	0103000020E6100000010000000500000018601F9DBA864E4011514CDE004F4C4018601F9DBA864E40A8FE412443524C405B79C9FFE4894E40A8FE412443524C405B79C9FFE4894E4011514CDE004F4C4018601F9DBA864E4011514CDE004F4C40
46812	Кашино	6	56	611	60.852327000000002	60.883498000000003	56.553015000000002	56.517752999999999	0103000020E61000000100000005000000B83F170D196D4E40F433F5BA45424C40B83F170D196D4E4046990D32C9464C406C0A647616714E4046990D32C9464C406C0A647616714E40F433F5BA45424C40B83F170D196D4E40F433F5BA45424C40
22809	Двуреченск	6	56	611	61.080337	61.109217999999998	56.608218999999998	56.585982999999999	0103000020E6100000010000000500000052D4997B488A4E408881AE7D014B4C4052D4997B488A4E4025E7C41EDA4D4C403811FDDAFA8D4E4025E7C41EDA4D4C403811FDDAFA8D4E408881AE7D014B4C4052D4997B488A4E408881AE7D014B4C40
22738	Верхняя Сысерть	6	56	611	60.739668999999999	60.769834000000003	56.446846999999998	56.427791999999997	0103000020E61000000100000005000000B96E4A79AD5E4E40C6BE64E3C1364C40B96E4A79AD5E4E4069A8514832394C40A8ACA6EB89624E4069A8514832394C40A8ACA6EB89624E40C6BE64E3C1364C40B96E4A79AD5E4E40C6BE64E3C1364C40
46869	Верхняя Боёвка	6	56	611	60.956710999999999	60.982618000000002	56.258743000000003	56.249195999999998	0103000020E610000001000000050000009A5C8C81757A4E40A2258FA7E51F4C409A5C8C81757A4E40D388997D1E214C40003B376DC67D4E40D388997D1E214C40003B376DC67D4E40A2258FA7E51F4C409A5C8C81757A4E40A2258FA7E51F4C40
47021	Бородулино	6	56	611	60.796405999999998	60.826599000000002	56.690306999999997	56.656916000000002	0103000020E61000000100000005000000492BBEA1F0654E400D1CD0D215544C40492BBEA1F0654E409599D2FA5B584C4002F4FBFECD694E409599D2FA5B584C4002F4FBFECD694E400D1CD0D215544C40492BBEA1F0654E400D1CD0D215544C40
46689	Большой Исток	6	56	611	60.720948	60.812226000000003	56.732573000000002	56.708795000000002	0103000020E61000000100000005000000ED0E2906485C4E40BF4868CBB95A4C40ED0E2906485C4E406077BAF3C45D4C40FF7A8505F7674E406077BAF3C45D4C40FF7A8505F7674E40BF4868CBB95A4C40ED0E2906485C4E40BF4868CBB95A4C40
23366	Большое Седельниково	6	56	611	60.690711	60.731943000000001	56.660477999999998	56.646098000000002	0103000020E6100000010000000500000065FED13769584E406901DA56B3524C4065FED13769584E401EDD088B8A544C40A0C4E74EB05D4E401EDD088B8A544C40A0C4E74EB05D4E406901DA56B3524C4065FED13769584E406901DA56B3524C40
46623	Бобровский	6	56	611	60.946874000000001	60.994467	56.694206999999999	56.649261000000003	0103000020E6100000010000000500000063B7CF2A33794E40BDC804FC1A534C4063B7CF2A33794E40BFD364C6DB584C40C2F9D4B14A7F4E40BFD364C6DB584C40C2F9D4B14A7F4E40BDC804FC1A534C4063B7CF2A33794E40BDC804FC1A534C40
22456	Асбест	6	56	611	60.515332999999998	60.534134000000002	56.478437	56.470840000000003	0103000020E6100000010000000500000058C6866EF6414E4007D3307C443C4C4058C6866EF6414E402219726C3D3D4C4041D7BE805E444E402219726C3D3D4C4041D7BE805E444E4007D3307C443C4C4058C6866EF6414E4007D3307C443C4C40
3879	Арамиль	6	56	611	60.903719000000002	60.958939000000001	56.718325	56.709215	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
61293	Аверинское	6	56	611	61.013142999999999	61.043084	56.335191000000002	56.314875999999998	0103000020E61000000100000005000000EE9579ABAE814E40CC2555DB4D284C40EE9579ABAE814E40EF74E789E72A4C408D7DC9C683854E40EF74E789E72A4C408D7DC9C683854E40CC2555DB4D284C40EE9579ABAE814E40CC2555DB4D284C40
61337	Абрамовское	6	56	611	61.002695000000003	61.022665000000003	56.388551	56.369979999999998	0103000020E610000001000000050000006E6E4C4F58804E40481630815B2F4C406E6E4C4F58804E40FFE9060ABC314C40C6E1CCAFE6824E40FFE9060ABC314C40C6E1CCAFE6824E40481630815B2F4C406E6E4C4F58804E40481630815B2F4C40
49930	Шата	6	56	1189	61.945540000000001	61.973028999999997	56.925738000000003	56.915627999999998	0103000020E61000000100000005000000A987687407F94E40A4A65D4C33754C40A987687407F94E400D5531957E764C40A087DA368CFC4E400D5531957E764C40A087DA368CFC4E40A4A65D4C33754C40A987687407F94E40A4A65D4C33754C40
49853	Филатовское	6	56	1189	62.280180999999999	62.325006999999999	56.856032999999996	56.841009999999997	0103000020E61000000100000005000000F4FA93F8DC234F40F2CD3637A66B4C40F4FA93F8DC234F40FCA5457D926D4C404CFC51D499294F40FCA5457D926D4C404CFC51D499294F40F2CD3637A66B4C40F4FA93F8DC234F40F2CD3637A66B4C40
11383	Сухой Лог	6	56	1189	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
49931	Сухой Лог	6	56	1189	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
49959	Светлое	6	56	1189	61.784418000000002	61.805312999999998	56.933813000000001	56.922328999999998	0103000020E6100000010000000500000066321CCF67E44E4081936DE00E764C4066321CCF67E44E4032CA332F87774C409605137F14E74E4032CA332F87774C409605137F14E74E4081936DE00E764C4066321CCF67E44E4081936DE00E764C40
49985	Рудянское	6	56	1189	61.930107	61.959015000000001	56.991453999999997	56.974331999999997	0103000020E61000000100000005000000ED6305BF0DF74E401FB935E9B67C4C40ED6305BF0DF74E4083BEF4F6E77E4C40CDAFE600C1FA4E4083BEF4F6E77E4C40CDAFE600C1FA4E401FB935E9B67C4C40ED6305BF0DF74E401FB935E9B67C4C40
49935	Новопышминское	6	56	1189	62.205998000000001	62.257398999999999	56.898372000000002	56.886287000000003	0103000020E610000001000000050000004D8578245E1A4F405BEF37DA71714C404D8578245E1A4F4031D28BDAFD724C40F5824F73F2204F4031D28BDAFD724C40F5824F73F2204F405BEF37DA71714C404D8578245E1A4F405BEF37DA71714C40
49925	Курьи	6	56	1189	62.095550000000003	62.167541	56.925699000000002	56.900137000000001	0103000020E6100000010000000500000000917EFB3A0C4F40B47570B037734C4000917EFB3A0C4F404F78094E7D764C409CDEC5FB71154F404F78094E7D764C409CDEC5FB71154F40B47570B037734C4000917EFB3A0C4F40B47570B037734C40
4730	Ках	8	75	621	46.787233000000001	46.795264000000003	42.560778999999997	42.554124000000002	0103000020E610000001000000050000007EAA0A0DC4644740E0F60489ED4645407EAA0A0DC46447404CA4349BC7474540D4D7F335CB6547404CA4349BC7474540D4D7F335CB654740E0F60489ED4645407EAA0A0DC4644740E0F60489ED464540
49836	Знаменское	6	56	1189	61.931319999999999	61.957129000000002	56.947403999999999	56.932245999999999	0103000020E610000001000000050000002C0E677E35F74E40D5E940D653774C402C0E677E35F74E40BF0CC68844794C40CF86FC3383FA4E40BF0CC68844794C40CF86FC3383FA4E40D5E940D653774C402C0E677E35F74E40D5E940D653774C40
49949	Заимка	6	56	1189	62.171430999999998	62.197589999999998	56.855545999999997	56.844540000000002	0103000020E61000000100000005000000A2427573F1154F40F91400E3196C4C40A2427573F1154F409F1C0588826D4C4021020EA14A194F409F1C0588826D4C4021020EA14A194F40F91400E3196C4C40A2427573F1154F40F91400E3196C4C40
49885	ГляденыСанаторий	6	56	1189	61.621886000000003	62.469096	57.217396000000001	56.766105000000003	0103000020E610000001000000050000008EEBDFF599CF4E40AB2688BA0F624C408EEBDFF599CF4E40FF23D3A1D39B4C409B5775560B3C4F40FF23D3A1D39B4C409B5775560B3C4F40AB2688BA0F624C408EEBDFF599CF4E40AB2688BA0F624C40
49956	Алтынай	6	56	1189	61.951245	62.012168000000003	57.086689999999997	57.056603000000003	0103000020E61000000100000005000000E4BD6A65C2F94E4081ED60C43E874C40E4BD6A65C2F94E40F3716DA8188B4C40640795B88E014F40F3716DA8188B4C40640795B88E014F4081ED60C43E874C40E4BD6A65C2F94E4081ED60C43E874C40
50121	Восточный	6	56	7022	59.194682999999998	59.201169	60.182453000000002	60.168508000000003	0103000020E61000000100000005000000280B5F5FEB984D40A48E8EAB91154E40280B5F5FEB984D404F07B29E5A174E4009FCE1E7BF994D404F07B29E5A174E4009FCE1E7BF994D40A48E8EAB91154E40280B5F5FEB984D40A48E8EAB91154E40
49944	Поселок Сосьва	6	56	7001	59.194682999999998	59.201169	60.182453000000002	60.168508000000003	0103000020E61000000100000005000000280B5F5FEB984D40A48E8EAB91154E40280B5F5FEB984D404F07B29E5A174E4009FCE1E7BF994D404F07B29E5A174E4009FCE1E7BF994D40A48E8EAB91154E40280B5F5FEB984D40A48E8EAB91154E40
49993	Юрты	6	56	1580	64.093466000000006	64.107399000000001	57.563363000000003	57.556216999999997	0103000020E610000001000000050000006E52D158FB055040573D601E32C74C406E52D158FB05504063635E471CC84C40E1270EA0DF06504063635E471CC84C40E1270EA0DF065040573D601E32C74C406E52D158FB055040573D601E32C74C40
46447	Шадринка	6	56	1580	64.755758	64.765513999999996	57.425040000000003	57.420233000000003	0103000020E610000001000000050000002F6CCD565E30504099D9E731CAB54C402F6CCD565E305040F5BEF1B567B64C4054A86E2EFE305040F5BEF1B567B64C4054A86E2EFE30504099D9E731CAB54C402F6CCD565E30504099D9E731CAB54C40
20985	Храмцово	6	56	1580	64.296306000000001	64.329723000000001	57.682361	57.669612000000001	0103000020E61000000100000005000000F3E670ADF61250402C8194D8B5D54C40F3E670ADF61250406E88F19A57D74C404C6F7F2E1A1550406E88F19A57D74C404C6F7F2E1A1550402C8194D8B5D54C40F3E670ADF61250402C8194D8B5D54C40
61300	Усть-Ницинское	6	56	1580	64.516986000000003	64.533002999999994	57.483179999999997	57.468304000000003	0103000020E610000001000000050000005A9F724C16215040024BAE62F1BB4C405A9F724C16215040670A9DD7D8BD4C40DF6A9DB81C225040670A9DD7D8BD4C40DF6A9DB81C225040024BAE62F1BB4C405A9F724C16215040024BAE62F1BB4C40
49950	Туринская Слобода	6	56	1580	64.374199000000004	64.408154999999994	57.634269000000003	57.604225	0103000020E610000001000000050000008ACC5CE0F21750407A36AB3E57CD4C408ACC5CE0F2175040EEEE01BA2FD14C40BA2C26361F1A5040EEEE01BA2FD14C40BA2C26361F1A50407A36AB3E57CD4C408ACC5CE0F21750407A36AB3E57CD4C40
19414	Тимофеево	6	56	1580	64.494348000000002	64.514973999999995	57.558225999999998	57.549079999999996	0103000020E61000000100000005000000F435CB65A31F50409F71E14048C64C40F435CB65A31F504071E316F373C74C4094128255F520504071E316F373C74C4094128255F52050409F71E14048C64C40F435CB65A31F50409F71E14048C64C40
61302	Сладковское	6	56	1580	64.203348000000005	64.231932	57.759891000000003	57.750114000000004	0103000020E61000000100000005000000406D54A7030D5040C9224DBC03E04C40406D54A7030D50402BC3B81B44E14C4056B950F9D70E50402BC3B81B44E14C4056B950F9D70E5040C9224DBC03E04C40406D54A7030D5040C9224DBC03E04C40
18995	Решетникова (Симахина)	6	56	1580	64.778610999999998	64.796514999999999	57.487935	57.478059999999999	0103000020E6100000010000000500000093533BC3D43150404CC3F01131BD4C4093533BC3D431504071C971A774BE4C4080F10C1AFA32504071C971A774BE4C4080F10C1AFA3250404CC3F01131BD4C4093533BC3D43150404CC3F01131BD4C40
50141	Пушкарёво	6	56	1580	64.012671999999995	64.034239999999997	57.779960000000003	57.773116000000002	0103000020E61000000100000005000000CB64389ECF005040D6011077F5E24C40CB64389ECF0050401618B2BAD5E34C40C30DF8FC300250401618B2BAD5E34C40C30DF8FC30025040D6011077F5E24C40CB64389ECF005040D6011077F5E24C40
20164	Ницинское	6	56	1580	64.167001999999997	64.198999999999998	57.533906999999999	57.527534000000003	0103000020E6100000010000000500000076172829B00A504098C3EE3B86C34C4076172829B00A5040800D881057C44C40DBF97E6ABC0C5040800D881057C44C40DBF97E6ABC0C504098C3EE3B86C34C4076172829B00A504098C3EE3B86C34C40
20852	Макуй	6	56	1580	64.256573000000003	64.272276000000005	57.800843	57.792579000000003	0103000020E61000000100000005000000580229B16B1050408A3F8A3A73E54C40580229B16B105040821DFF0582E64C4016DF50F86C115040821DFF0582E64C4016DF50F86C1150408A3F8A3A73E54C40580229B16B1050408A3F8A3A73E54C40
19106	Липчинское	6	56	1580	64.735106000000002	64.752578	57.393537000000002	57.376640000000002	0103000020E61000000100000005000000FA4509FA0B2F5040C72E51BD35B04C40FA4509FA0B2F50400B62A06B5FB24C401A6CEA3C2A3050400B62A06B5FB24C401A6CEA3C2A305040C72E51BD35B04C40FA4509FA0B2F5040C72E51BD35B04C40
20548	Куминовское	6	56	1580	64.090753000000007	64.120971999999995	57.796224000000002	57.789451	0103000020E61000000100000005000000E4C0ABE5CE055040B265F9BA0CE54C40E4C0ABE5CE055040292504ABEAE54C40D4EE5701BE075040292504ABEAE54C40D4EE5701BE075040B265F9BA0CE54C40E4C0ABE5CE055040B265F9BA0CE54C40
19520	Красный Яр	6	56	1580	64.486641000000006	64.508919000000006	57.584926000000003	57.580559999999998	0103000020E6100000010000000500000023F94A20251F5040D1AE42CA4FCA4C4023F94A20251F5040414AECDADECA4C400954FF2092205040414AECDADECA4C400954FF2092205040D1AE42CA4FCA4C4023F94A20251F5040D1AE42CA4FCA4C40
19883	Краснослободское	6	56	1580	64.314694000000003	64.339838	57.518830000000001	57.507339000000002	0103000020E61000000100000005000000D68F4DF223145040207EFE7BF0C04C40D68F4DF22314504083177D0569C24C4009FCE1E7BF15504083177D0569C24C4009FCE1E7BF155040207EFE7BF0C04C40D68F4DF223145040207EFE7BF0C04C40
20232	Звезда	6	56	1580	64.153491000000002	64.167658000000003	57.627401999999996	57.619007000000003	0103000020E61000000100000005000000BE4EEACBD20950405F7F129F3BCF4C40BE4EEACBD2095040F5B86FB54ED04C406BBA9EE8BA0A5040F5B86FB54ED04C406BBA9EE8BA0A50405F7F129F3BCF4C40BE4EEACBD20950405F7F129F3BCF4C40
19412	Жирякова	6	56	1580	64.554544000000007	64.565494999999999	57.504272999999998	57.497337999999999	0103000020E610000001000000050000005B0C1EA67D2350406E8786C5A8BF4C405B0C1EA67D235040BEA085048CC04C404CC3F01131245040BEA085048CC04C404CC3F011312450406E8786C5A8BF4C405B0C1EA67D2350406E8786C5A8BF4C40
19627	Ермакова	6	56	1580	64.285679000000002	64.307030999999995	57.414594999999998	57.410232999999998	0103000020E61000000100000005000000DB89929048125040B75ED38382B44C40DB89929048125040E50AEF7211B54C40ECF65965A6135040E50AEF7211B54C40ECF65965A6135040B75ED38382B44C40DB89929048125040B75ED38382B44C40
19838	Голякова	6	56	1580	64.408873	64.421621000000002	57.448754000000001	57.441052999999997	0103000020E61000000100000005000000EACDA8F92A1A5040BE66B96C74B84C40EACDA8F92A1A50407FF964C570B94C40A393A5D6FB1A50407FF964C570B94C40A393A5D6FB1A5040BE66B96C74B84C40EACDA8F92A1A5040BE66B96C74B84C40
20052	Бобровское	6	56	1580	64.146897999999993	64.173641000000003	57.505423999999998	57.497092000000002	0103000020E610000001000000050000004276DEC666095040378DEDB5A0BF4C404276DEC666095040874ECFBBB1C04C40AA0F24EF1C0B5040874ECFBBB1C04C40AA0F24EF1C0B5040378DEDB5A0BF4C404276DEC666095040378DEDB5A0BF4C40
20918	Андронова	6	56	1580	64.271934000000002	64.287125000000003	57.737245000000001	57.725386	0103000020E61000000100000005000000E92ADD5D67115040F67CCD72D9DC4C40E92ADD5D67115040DC114E0B5EDE4C404C37894160125040DC114E0B5EDE4C404C37894160125040F67CCD72D9DC4C40E92ADD5D67115040F67CCD72D9DC4C40
50217	Туринская Слобода	6	56	7036	64.374199000000004	64.408154999999994	57.634269000000003	57.604225	0103000020E610000001000000050000008ACC5CE0F21750407A36AB3E57CD4C408ACC5CE0F2175040EEEE01BA2FD14C40BA2C26361F1A5040EEEE01BA2FD14C40BA2C26361F1A50407A36AB3E57CD4C408ACC5CE0F21750407A36AB3E57CD4C40
49916	Черноярский	6	56	1490	60.762611999999997	60.782231000000003	59.609552000000001	59.599977000000003	0103000020E61000000100000005000000C1C41F459D614E4015ADDC0BCCCC4D40C1C41F459D614E400F9BC8CC05CE4D406D75392520644E400F9BC8CC05CE4D406D75392520644E4015ADDC0BCCCC4D40C1C41F459D614E4015ADDC0BCCCC4D40
49873	Сосьва	6	56	1490	61.814970000000002	61.877870000000001	59.190094000000002	59.156882000000003	0103000020E610000001000000050000004E9CDCEF50E84E4061AA99B514944D404E9CDCEF50E84E403A950C0055984D40DC114E0B5EF04E403A950C0055984D40DC114E0B5EF04E4061AA99B514944D404E9CDCEF50E84E4061AA99B514944D40
18528	Семёнова	6	56	1490	61.053226000000002	61.072423000000001	59.374707000000001	59.368431000000001	0103000020E6100000010000000500000001A60C1CD0864E4092EA3BBF28AF4D4001A60C1CD0864E40884A2366F6AF4D40363D282845894E40884A2366F6AF4D40363D282845894E4092EA3BBF28AF4D4001A60C1CD0864E4092EA3BBF28AF4D40
49992	Романово	6	56	1490	61.495448000000003	61.527267000000002	59.155996000000002	59.13814	0103000020E610000001000000050000002F6F0ED76ABF4E407D224F92AE914D402F6F0ED76ABF4E4046274BADF7934D4049A12C7C7DC34E4046274BADF7934D4049A12C7C7DC34E407D224F92AE914D402F6F0ED76ABF4E407D224F92AE914D40
18462	Поспелкова	6	56	1490	60.860438000000002	60.877605000000003	59.430542000000003	59.418554	0103000020E610000001000000050000002A1E17D5226E4E4014CE6E2D93B54D402A1E17D5226E4E40F8C610001CB74D402EE7525C55704E40F8C610001CB74D402EE7525C55704E4014CE6E2D93B54D402A1E17D5226E4E4014CE6E2D93B54D40
17859	Первомайский	6	56	1490	61.388845000000003	61.410899000000001	59.497638000000002	59.481921999999997	0103000020E61000000100000005000000481B47ACC5B14E40889CBE9EAFBD4D40481B47ACC5B14E40999F1B9AB2BF4D40C47AA35698B44E40999F1B9AB2BF4D40C47AA35698B44E40889CBE9EAFBD4D40481B47ACC5B14E40889CBE9EAFBD4D40
49971	Пасынок	6	56	1490	61.448853	61.465381999999998	59.280898999999998	59.270130999999999	0103000020E6100000010000000500000012DBDD0374B94E40615111A793A24D4012DBDD0374B94E40533D997FF4A34D40D3122BA391BB4E40533D997FF4A34D40D3122BA391BB4E40615111A793A24D4012DBDD0374B94E40615111A793A24D40
18352	Морозково	6	56	1490	60.971335000000003	60.987721000000001	59.399974999999998	59.390945000000002	0103000020E61000000100000005000000E73A8DB4547C4E4072C45A7C0AB24D40E73A8DB4547C4E40DA1B7C6132B34D40454948A46D7E4E40DA1B7C6132B34D40454948A46D7E4E4072C45A7C0AB24D40E73A8DB4547C4E4072C45A7C0AB24D40
49864	Маслова	6	56	1490	61.275773999999998	61.288511999999997	59.293106000000002	59.282282000000002	0103000020E61000000100000005000000268BFB8F4CA34E40EF1F0BD121A44D40268BFB8F4CA34E407521567F84A54D40744012F6EDA44E407521567F84A54D40744012F6EDA44E40EF1F0BD121A44D40268BFB8F4CA34E40EF1F0BD121A44D40
17377	Ларьковка	6	56	1490	60.549737999999998	60.594392999999997	59.934807999999997	59.917212999999997	0103000020E6100000010000000500000029AF95D05D464E40A73B4F3C67F54D4029AF95D05D464E400305DEC9A7F74D4054FCDF11154C4E400305DEC9A7F74D4054FCDF11154C4E40A73B4F3C67F54D4029AF95D05D464E40A73B4F3C67F54D40
17460	Красный Яр	6	56	1490	60.718198999999998	60.733829999999998	59.847448999999997	59.839362000000001	0103000020E610000001000000050000008C82E0F1ED5B4E40A9C0C93670EB4D408C82E0F1ED5B4E409203763579EC4D406E693524EE5D4E409203763579EC4D406E693524EE5D4E40A9C0C93670EB4D408C82E0F1ED5B4E40A9C0C93670EB4D40
17622	Красноярка	6	56	1490	60.503177999999998	60.535572000000002	59.434120999999998	59.414053000000003	0103000020E610000001000000050000008908FF2268404E40C5E74EB0FFB44D408908FF2268404E40DFC0E44691B74D40A053909F8D444E40DFC0E44691B74D40A053909F8D444E40C5E74EB0FFB44D408908FF2268404E40C5E74EB0FFB44D40
17767	Красноглинный	6	56	1490	61.219099999999997	61.267904999999999	59.397239999999996	59.379624999999997	0103000020E61000000100000005000000DC4603780B9C4E403BDF4F8D97B04D40DC4603780B9C4E40DE54A4C2D8B24D40AAB706B64AA24E40DE54A4C2D8B24D40AAB706B64AA24E403BDF4F8D97B04D40DC4603780B9C4E403BDF4F8D97B04D40
50193	Кошай	6	56	1490	61.835783999999997	61.882657999999999	59.096943000000003	59.076943	0103000020E61000000100000005000000914259F8FAEA4E40FC53AA44D9894D40914259F8FAEA4E40BF49D3A0688C4D40C1C6F5EFFAF04E40BF49D3A0688C4D40C1C6F5EFFAF04E40FC53AA44D9894D40914259F8FAEA4E40FC53AA44D9894D40
18840	Ключевой (Замарайка)	6	56	1490	60.386999000000003	60.404021999999998	59.647587999999999	59.637504999999997	0103000020E61000000100000005000000D84AE82E89314E40AB048BC399D14D40D84AE82E89314E401AA4E029E4D24D40A86E2EFEB6334E401AA4E029E4D24D40A86E2EFEB6334E40AB048BC399D14D40D84AE82E89314E40AB048BC399D14D40
18783	Еловка Новая	6	56	1490	60.570084999999999	60.585059999999999	59.73657	59.732289000000002	0103000020E610000001000000050000005778978BF8484E403B1C5DA5BBDD4D405778978BF8484E407C9BFEEC47DE4D405019FF3EE34A4E407C9BFEEC47DE4D405019FF3EE34A4E403B1C5DA5BBDD4D405778978BF8484E403B1C5DA5BBDD4D40
40380	Восточный	6	56	1490	61.777034	61.839503000000001	58.808472999999999	58.783392999999997	0103000020E61000000100000005000000A6F0A0D975E34E402975C93846644D40A6F0A0D975E34E407959130B7C674D406BF294D574EB4E407959130B7C674D406BF294D574EB4E402975C93846644D40A6F0A0D975E34E402975C93846644D40
17918	Боровой	6	56	1490	61.389968000000003	61.41142	59.556539000000001	59.534660000000002	0103000020E61000000100000005000000473EAF78EAB14E405C3D27BD6FC44D40473EAF78EAB14E406AF981AB3CC74D40CD751A69A9B44E406AF981AB3CC74D40CD751A69A9B44E405C3D27BD6FC44D40473EAF78EAB14E405C3D27BD6FC44D40
50183	Марсяты	6	56	7046	60.446010000000001	60.487448999999998	60.051611999999999	60.026761	0103000020E6100000010000000500000030D80DDB16394E4075E789E76C034E4030D80DDB16394E40630AD6389B064E40E4BB94BA643E4E40630AD6389B064E40E4BB94BA643E4E4075E789E76C034E4030D80DDB16394E4075E789E76C034E40
48640	Черемисское	6	56	1347	60.873283999999998	60.908937999999999	57.460394000000001	57.433931000000001	0103000020E610000001000000050000005E0F26C5C76F4E403CDC0E0D8BB74C405E0F26C5C76F4E4027A3CA30EEBA4C40BB0B941458744E4027A3CA30EEBA4C40BB0B941458744E403CDC0E0D8BB74C405E0F26C5C76F4E403CDC0E0D8BB74C40
48603	Фирсово	6	56	1347	61.093910000000001	61.114913000000001	57.502146000000003	57.487969	0103000020E6100000010000000500000039622D3E058C4E401D3BA8C475BE4C4039622D3E058C4E409BE8F35146C04C4050711C78B58E4E409BE8F35146C04C4050711C78B58E4E401D3BA8C475BE4C4039622D3E058C4E401D3BA8C475BE4C40
48520	Сохарёво	6	56	1347	61.509138999999998	61.526629	57.491267999999998	57.482714999999999	0103000020E610000001000000050000001F0F7D772BC14E40F224E99AC9BD4C401F0F7D772BC14E4021C9ACDEE1BE4C4006103E9468C34E4021C9ACDEE1BE4C4006103E9468C34E40F224E99AC9BD4C401F0F7D772BC14E40F224E99AC9BD4C40
24729	Соколово	6	56	1347	61.217339000000003	61.243830000000003	57.477930000000001	57.470413999999998	0103000020E610000001000000050000009B92ACC3D19B4E404FCAA48636BC4C409B92ACC3D19B4E407EE36BCF2CBD4C4050E449D2359F4E407EE36BCF2CBD4C4050E449D2359F4E404FCAA48636BC4C409B92ACC3D19B4E404FCAA48636BC4C40
14450	Реж	6	56	1347	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
48720	Першино	6	56	1347	61.458043000000004	61.476027000000002	57.431708	57.423247000000003	0103000020E61000000100000005000000B4942C27A1BA4E40A8902BF52CB64C40B4942C27A1BA4E40F6B52E3542B74C40AA81E673EEBC4E40F6B52E3542B74C40AA81E673EEBC4E40A8902BF52CB64C40B4942C27A1BA4E40A8902BF52CB64C40
48480	Ощепково	6	56	1347	61.439959000000002	61.474958000000001	57.486648000000002	57.479739000000002	0103000020E610000001000000050000005A4A969350B84E40D1CE691668BD4C405A4A969350B84E40F8544E7B4ABE4C409E7C7A6CCBBC4E40F8544E7B4ABE4C409E7C7A6CCBBC4E40D1CE691668BD4C405A4A969350B84E40D1CE691668BD4C40
46721	Останино	6	56	1347	61.302041000000003	61.329169999999998	57.433611999999997	57.410818999999996	0103000020E610000001000000050000008C868C47A9A64E40A7C98CB795B44C408C868C47A9A64E409A93179980B74C408369183E22AA4E409A93179980B74C408369183E22AA4E40A7C98CB795B44C408C868C47A9A64E40A7C98CB795B44C40
48685	Октябрьское	6	56	1347	60.943910000000002	60.974182999999996	57.408036000000003	57.396462	0103000020E61000000100000005000000062FFA0AD2784E40AA0D4E44BFB24C40062FFA0AD2784E409BCB0D863AB44C40DAA84E07B27C4E409BCB0D863AB44C40DAA84E07B27C4E40AA0D4E44BFB24C40062FFA0AD2784E40AA0D4E44BFB24C40
50231	Липовское	6	56	1347	61.153180999999996	61.190443000000002	57.458272999999998	57.432758999999997	0103000020E610000001000000050000002DAF5C6F9B934E405B069CA564B74C402DAF5C6F9B934E40E5D18DB0A8BA4C404660AC6F60984E40E5D18DB0A8BA4C404660AC6F60984E405B069CA564B74C402DAF5C6F9B934E405B069CA564B74C40
15813	Ленёвское	6	56	1347	61.359730999999996	61.394100000000002	57.596952000000002	57.577663999999999	0103000020E61000000100000005000000BE2D58AA0BAE4E40CC09DAE4F0C94C40BE2D58AA0BAE4E4012A452EC68CC4C4043AD69DE71B24E4012A452EC68CC4C4043AD69DE71B24E40CC09DAE4F0C94C40BE2D58AA0BAE4E40CC09DAE4F0C94C40
15401	Костоусово	6	56	1347	61.211086999999999	61.233544999999999	57.270868999999998	57.261012999999998	0103000020E610000001000000050000002DCE18E6049B4E40596ABDDF68A14C402DCE18E6049B4E400740DCD5ABA24C40799274CDE49D4E400740DCD5ABA24C40799274CDE49D4E40596ABDDF68A14C402DCE18E6049B4E40596ABDDF68A14C40
16168	Колташи	6	56	1347	60.864435999999998	60.877946000000001	57.413214000000004	57.398488999999998	0103000020E6100000010000000500000016BEBED6A56E4E406A6803B001B34C4016BEBED6A56E4E40EB1F4432E4B44C40B7D3D68860704E40EB1F4432E4B44C40B7D3D68860704E406A6803B001B34C4016BEBED6A56E4E406A6803B001B34C40
15888	Клевакинское	6	56	1347	61.338619999999999	61.365659999999998	57.532640999999998	57.512158999999997	0103000020E61000000100000005000000C1E270E657AB4E4010AD156D8EC14C40C1E270E657AB4E401EC18D942DC44C4049BA66F2CDAE4E401EC18D942DC44C4049BA66F2CDAE4E4010AD156D8EC14C40C1E270E657AB4E4010AD156D8EC14C40
40394	Каменка	6	56	1347	61.229447999999998	61.249076000000002	57.527925000000003	57.510984000000001	0103000020E61000000100000005000000F910548D5E9D4E40BF6378EC67C14C40F910548D5E9D4E40D3DEE00B93C34C40F81BEDB8E19F4E40D3DEE00B93C34C40F81BEDB8E19F4E40BF6378EC67C14C40F910548D5E9D4E40BF6378EC67C14C40
49963	Голендухино	6	56	1347	61.39958	61.427787000000002	57.457740999999999	57.443998000000001	0103000020E610000001000000050000005E11FC6F25B34E40A5BE2CEDD4B84C405E11FC6F25B34E40E884D04197BA4C40B55373B9C1B64E40E884D04197BA4C40B55373B9C1B64E40A5BE2CEDD4B84C405E11FC6F25B34E40A5BE2CEDD4B84C40
48475	Глинское	6	56	1347	61.406866000000001	61.430455000000002	57.489942999999997	57.473086000000002	0103000020E610000001000000050000005BED612F14B44E40051901158EBC4C405BED612F14B44E40BAF3C473B6BE4C4029B3412619B74E40BAF3C473B6BE4C4029B3412619B74E40051901158EBC4C405BED612F14B44E40051901158EBC4C40
15770	Арамашка	6	56	1347	61.482576000000002	61.514671999999997	57.535626999999998	57.521019000000003	0103000020E61000000100000005000000D1EAE40CC5BD4E401DCC26C0B0C24C40D1EAE40CC5BD4E4063EDEF6C8FC44C405D15A8C5E0C14E4063EDEF6C8FC44C405D15A8C5E0C14E401DCC26C0B0C24C40D1EAE40CC5BD4E401DCC26C0B0C24C40
50204	Озерный	6	56	7058	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
11394	Юрмытское	6	56	1142	63.067391999999998	63.089015000000003	57.015537000000002	57.005386999999999	0103000020E610000001000000050000008A01124DA0884F406A696E85B0804C408A01124DA0884F406170CD1DFD814C403EEDF0D7648B4F406170CD1DFD814C403EEDF0D7648B4F406A696E85B0804C408A01124DA0884F406A696E85B0804C40
11773	Чупино	6	56	1142	63.363737999999998	63.402239000000002	57.019207000000002	56.999867000000002	0103000020E61000000100000005000000FE277FF78EAE4F40C1AC50A4FB7F4C40FE277FF78EAE4F40596DFE5F75824C407F164B917CB34F40596DFE5F75824C407F164B917CB34F40C1AC50A4FB7F4C40FE277FF78EAE4F40C1AC50A4FB7F4C40
12485	Четкарино	6	56	1142	63.112146000000003	63.135205999999997	56.739193999999998	56.728430000000003	0103000020E610000001000000050000004930D5CC5A8E4F4070B6B9313D5D4C404930D5CC5A8E4F4020B3B3E89D5E4C408A1C226E4E914F4020B3B3E89D5E4C408A1C226E4E914F4070B6B9313D5D4C404930D5CC5A8E4F4070B6B9313D5D4C40
11994	Чернышово	6	56	1142	63.227561999999999	63.245806999999999	56.925448000000003	56.914321000000001	0103000020E61000000100000005000000FBE769C0209D4F40E485747808754C40FBE769C0209D4F4006137F1475764C405E10919A769F4F4006137F1475764C405E10919A769F4F40E485747808754C40FBE769C0209D4F40E485747808754C40
12160	Черемыш	6	56	1142	63.035781	63.081999000000003	56.860934	56.852544000000002	0103000020E61000000100000005000000BA68C87894844F4055336B29206D4C40BA68C87894844F40DA01D715336E4C4001A777F17E8A4F40DA01D715336E4C4001A777F17E8A4F4055336B29206D4C40BA68C87894844F4055336B29206D4C40
11229	Холкина	6	56	1142	62.998860000000001	63.015918999999997	57.072488999999997	57.057214999999999	0103000020E610000001000000050000002BA4FCA4DA7F4F409AEB34D252874C402BA4FCA4DA7F4F40ED28CE5147894C40483140A209824F40ED28CE5147894C40483140A209824F409AEB34D252874C402BA4FCA4DA7F4F409AEB34D252874C40
12352	Тупицыно	6	56	1142	63.172252999999998	63.187542000000001	56.822749999999999	56.813127999999999	0103000020E61000000100000005000000A6D1E4620C964F401FBB0B9414684C40A6D1E4620C964F405A643BDF4F694C402F50526001984F405A643BDF4F694C402F50526001984F401FBB0B9414684C40A6D1E4620C964F401FBB0B9414684C40
11560	Трифоново	6	56	1142	63.142904999999999	63.166862999999999	56.995308000000001	56.977378000000002	0103000020E61000000100000005000000AAB706B64A924F403AEAE8B81A7D4C40AAB706B64A924F403DB9A640667F4C40CBF44BC45B954F403DB9A640667F4C40CBF44BC45B954F403AEAE8B81A7D4C40AAB706B64A924F403AEAE8B81A7D4C40
11479	Тимохинское	6	56	1142	63.153649000000001	63.178441999999997	56.910477999999998	56.888289	0103000020E6100000010000000500000014083BC5AA934F40C2323674B3714C4014083BC5AA934F401EDD088B8A744C40CD1DFD2FD7964F401EDD088B8A744C40CD1DFD2FD7964F40C2323674B3714C4014083BC5AA934F40C2323674B3714C40
11142	Талица	6	56	1142	63.023096000000002	63.047989000000001	57.120280000000001	57.099829	0103000020E610000001000000050000008F554ACFF4824F40A0185932C78C4C408F554ACFF4824F40732EC555658F4C40ACC8E88024864F40732EC555658F4C40ACC8E88024864F40A0185932C78C4C408F554ACFF4824F40A0185932C78C4C40
12974	Речелга	6	56	1142	63.370564999999999	63.388019	56.757914	56.747273999999997	0103000020E61000000100000005000000680586AC6EAF4F405793A7ACA65F4C40680586AC6EAF4F401C97715303614C40029D499BAAB14F401C97715303614C40029D499BAAB14F405793A7ACA65F4C40680586AC6EAF4F405793A7ACA65F4C40
10683	Пышма	6	56	1142	63.202821999999998	63.284793999999998	56.980139999999999	56.931789999999999	0103000020E6100000010000000500000064744012F6994F40B35E0CE544774C4064744012F6994F402FC03E3A757D4C406B0C3A2174A44F402FC03E3A757D4C406B0C3A2174A44F40B35E0CE544774C4064744012F6994F40B35E0CE544774C40
11853	Пылаева	6	56	1142	63.315103000000001	63.345044000000001	56.992013	56.976329	0103000020E610000001000000050000008DEF8B4B55A84F4075914259F87C4C408DEF8B4B55A84F407A1A3048FA7E4C402CD7DB662AAC4F407A1A3048FA7E4C402CD7DB662AAC4F4075914259F87C4C408DEF8B4B55A84F4075914259F87C4C40
11667	Пульниково	6	56	1142	63.257539000000001	63.291845000000002	57.111732000000003	57.091976000000003	0103000020E61000000100000005000000E738B709F7A04F402A029CDEC58B4C40E738B709F7A04F4056F5F23B4D8E4C4025404D2D5BA54F4056F5F23B4D8E4C4025404D2D5BA54F402A029CDEC58B4C40E738B709F7A04F402A029CDEC58B4C40
11329	Печёркино	6	56	1142	63.007168999999998	63.036248000000001	57.037264	57.024954000000001	0103000020E61000000100000005000000C345EEE9EA804F40C3F352B131834C40C345EEE9EA804F40B9A81611C5844C40D04543C6A3844F40B9A81611C5844C40D04543C6A3844F40C3F352B131834C40C345EEE9EA804F40C3F352B131834C40
12641	Первомайский	6	56	1142	63.009199000000002	63.026681000000004	56.735945000000001	56.724375999999999	0103000020E61000000100000005000000F513CE6E2D814F40EF004F5AB85C4C40F513CE6E2D814F40CE531D72335E4C40593673486A834F40CE531D72335E4C40593673486A834F40EF004F5AB85C4C40F513CE6E2D814F40EF004F5AB85C4C40
12925	Мартынова	6	56	1142	63.213341999999997	63.230606999999999	56.624262000000002	56.611651999999999	0103000020E610000001000000050000007E6E68CA4E9B4F403944DC9C4A4E4C407E6E68CA4E9B4F405A1135D1E74F4C40459DB987849D4F405A1135D1E74F4C40459DB987849D4F403944DC9C4A4E4C407E6E68CA4E9B4F403944DC9C4A4E4C40
12580	Комарова	6	56	1142	63.107897000000001	63.128622	56.760908999999998	56.748601999999998	0103000020E61000000100000005000000132BA391CF8D4F402FDCB930D25F4C40132BA391CF8D4F40B41D537765614C40E7C589AF76904F40B41D537765614C40E7C589AF76904F402FDCB930D25F4C40132BA391CF8D4F402FDCB930D25F4C40
11609	Катарач	6	56	1142	63.218919999999997	63.231757000000002	57.025944000000003	57.012037999999997	0103000020E610000001000000050000005C381092059C4F40952710768A814C405C381092059C4F4083C30B2252834C403ECF9F36AA9D4F4083C30B2252834C403ECF9F36AA9D4F40952710768A814C405C381092059C4F40952710768A814C40
12259	Духовая	6	56	1142	63.015272000000003	63.036085999999997	56.841177000000002	56.828473000000002	0103000020E61000000100000005000000B345D26EF4814F403C4F3C670B6A4C40B345D26EF4814F40DE921CB0AB6B4C40F6EB4E779E844F40DE921CB0AB6B4C40F6EB4E779E844F403C4F3C670B6A4C40B345D26EF4814F403C4F3C670B6A4C40
12851	Боровлянское	6	56	1142	63.155085999999997	63.182879999999997	56.650759999999998	56.631917000000001	0103000020E61000000100000005000000A208A9DBD9934F40AA6400A8E2504C40A208A9DBD9934F40C1C58A1A4C534C40D68BA19C68974F40C1C58A1A4C534C40D68BA19C68974F40AA6400A8E2504C40A208A9DBD9934F40AA6400A8E2504C40
10250	Южаково	6	56	340	60.971505999999998	61.026150999999999	57.637945000000002	57.604711999999999	0103000020E6100000010000000500000013EF004F5A7C4E40D7BFEB3367CD4C4013EF004F5A7C4E40C8D2872EA8D14C40FCE07CEA58834E40C8D2872EA8D14C40FCE07CEA58834E40D7BFEB3367CD4C4013EF004F5A7C4E40D7BFEB3367CD4C40
61341	Шумиха	6	56	340	60.531726999999997	60.584843999999997	57.664707	57.612054999999998	0103000020E6100000010000000500000039B35DA10F444E40382D78D157CE4C4039B35DA10F444E400D36751E15D54C4083A10E2BDC4A4E400D36751E15D54C4083A10E2BDC4A4E40382D78D157CE4C4039B35DA10F444E40382D78D157CE4C40
49338	Шиловка	6	56	340	60.16234	60.189909	57.779330999999999	57.764049	0103000020E61000000100000005000000946A9F8EC7144E4050C58D5BCCE14C40946A9F8EC7144E4026E1421EC1E34C40A81B28F04E184E4026E1421EC1E34C40A81B28F04E184E4050C58D5BCCE14C40946A9F8EC7144E4050C58D5BCCE14C40
8117	Черноисточинск	6	56	340	59.840032999999998	59.897354	57.750588999999998	57.708089999999999	0103000020E61000000100000005000000C7478B3386EB4D40F44F70B1A2DA4C40C7478B3386EB4D4061DEE34C13E04C40A777F17EDCF24D4061DEE34C13E04C40A777F17EDCF24D40F44F70B1A2DA4C40C7478B3386EB4D40F44F70B1A2DA4C40
10196	Усть-Утка	6	56	340	59.016933999999999	59.034837000000003	57.623576	57.615430000000003	0103000020E610000001000000050000006118B0E42A824D40187D0569C6CE4C406118B0E42A824D4006499F56D1CF4C406BD8EF8975844D4006499F56D1CF4C406BD8EF8975844D40187D0569C6CE4C406118B0E42A824D40187D0569C6CE4C40
8051	Уралец	6	56	340	59.625515	59.685144999999999	57.666145999999998	57.635319000000003	0103000020E61000000100000005000000271422E010D04D4083C30B2252D14C40271422E010D04D403C2EAA4544D54C404B02D4D4B2D74D403C2EAA4544D54C404B02D4D4B2D74D4083C30B2252D14C40271422E010D04D4083C30B2252D14C40
8707	Сулём	6	56	340	59.109181999999997	59.137065	57.540661	57.526780000000002	0103000020E61000000100000005000000EBA7FFACF98D4D40EC17EC866DC34C40EBA7FFACF98D4D40809C306134C54C408F368E588B914D40809C306134C54C408F368E588B914D40EC17EC866DC34C40EBA7FFACF98D4D40EC17EC866DC34C40
22811	Студёный	6	56	340	59.857703000000001	59.863909999999997	57.754714999999997	57.751382	0103000020E610000001000000050000002E573F36C9ED4D40CB660E492DE04C402E573F36C9ED4D407B6649809AE04C40FB57569A94EE4D407B6649809AE04C40FB57569A94EE4D40CB660E492DE04C402E573F36C9ED4D40CB660E492DE04C40
49538	Синегорский	6	56	340	59.488728999999999	59.531030000000001	57.901747	57.890478000000002	0103000020E61000000100000005000000ABCDFFAB8EBE4D405CE7DF2EFBF14C40ABCDFFAB8EBE4D40102219726CF34C40F29881CAF8C34D40102219726CF34C40F29881CAF8C34D405CE7DF2EFBF14C40ABCDFFAB8EBE4D405CE7DF2EFBF14C40
1643	Покровское	6	56	340	60.225445999999998	60.291347000000002	57.979889	57.955987	0103000020E61000000100000005000000CB811E6ADB1C4E40593332C85DFA4C40CB811E6ADB1C4E40E65AB4006DFD4C40D464C6DB4A254E40E65AB4006DFD4C40D464C6DB4A254E40593332C85DFA4C40CB811E6ADB1C4E40593332C85DFA4C40
9632	Петрокаменское	6	56	340	60.621343000000003	60.678341000000003	57.722492000000003	57.699221999999999	0103000020E610000001000000050000009D4CDC2A884F4E406552431B80D94C409D4CDC2A884F4E4092CF2B9E7ADC4C409A44BDE0D3564E4092CF2B9E7ADC4C409A44BDE0D3564E406552431B80D94C409D4CDC2A884F4E406552431B80D94C40
9533	Новопаньшино	6	56	340	60.868648999999998	60.896380000000001	57.574700999999997	57.558916000000004	0103000020E61000000100000005000000FF59F3E32F6F4E40079B3A8F8AC74C40FF59F3E32F6F4E403FFD67CD8FC94C40ED647094BC724E403FFD67CD8FC94C40ED647094BC724E40079B3A8F8AC74C40FF59F3E32F6F4E40079B3A8F8AC74C40
10396	Новоасбест	6	56	340	60.266697000000001	60.306142000000001	57.759757	57.735976999999998	0103000020E610000001000000050000007D78962023224E40D9CD8C7E34DE4C407D78962023224E401BF4A5B73FE14C404DF73AA92F274E401BF4A5B73FE14C404DF73AA92F274E40D9CD8C7E34DE4C407D78962023224E40D9CD8C7E34DE4C40
8501	Новая Башкарка	6	56	340	60.809612000000001	60.828898000000002	57.633656999999999	57.622781000000003	0103000020E610000001000000050000007E39B35DA1674E40FCC8AD49B7CF4C407E39B35DA1674E40D4F02DAC1BD14C4023DC6454196A4E40D4F02DAC1BD14C4023DC6454196A4E40FCC8AD49B7CF4C407E39B35DA1674E40FCC8AD49B7CF4C40
22910	Николо-Павловское	6	56	340	60.028894999999999	60.074637000000003	57.800972000000002	57.773159999999997	0103000020E610000001000000050000004B02D4D4B2034E40A54929E8F6E24C404B02D4D4B2034E408081204086E64C40290989B48D094E408081204086E64C40290989B48D094E40A54929E8F6E24C404B02D4D4B2034E40A54929E8F6E24C40
50114	Мурзинка	6	56	340	61.002803	61.035393999999997	57.696008999999997	57.684193999999998	0103000020E6100000010000000500000054AA44D95B804E40490F43AB93D74C4054AA44D95B804E405F5CAAD216D94C40C03C64CA87844E405F5CAAD216D94C40C03C64CA87844E40490F43AB93D74C4054AA44D95B804E40490F43AB93D74C40
8417	Мокроусское	6	56	340	60.803099000000003	60.823886000000002	57.693705000000001	57.684348	0103000020E61000000100000005000000A439B2F2CB664E40A08A1BB798D74C40A439B2F2CB664E402D095053CBD84C40EED0B01875694E402D095053CBD84C40EED0B01875694E40A08A1BB798D74C40A439B2F2CB664E40A08A1BB798D74C40
49069	Маркова	6	56	340	60.859135999999999	60.868074	57.520753999999997	57.514257000000001	0103000020E610000001000000050000007B681F2BF86D4E409A5E622CD3C14C407B681F2BF86D4E406EA12B11A8C24C400341800C1D6F4E406EA12B11A8C24C400341800C1D6F4E409A5E622CD3C14C407B681F2BF86D4E409A5E622CD3C14C40
9004	Малая Лая	6	56	340	59.876460000000002	59.889215999999998	58.131335999999997	58.109043999999997	0103000020E6100000010000000500000047205ED72FF04D409AE95E27F50D4D4047205ED72FF04D40CB64389ECF104D403B8A73D4D1F14D40CB64389ECF104D403B8A73D4D1F14D409AE95E27F50D4D4047205ED72FF04D409AE95E27F50D4D40
9399	Ленёвка	6	56	340	60.075850000000003	60.091166000000001	57.747884999999997	57.737994999999998	0103000020E6100000010000000500000068B3EA73B5094E4046CEC29E76DE4C4068B3EA73B5094E40A01518B2BADF4C40EA40D653AB0B4E40A01518B2BADF4C40EA40D653AB0B4E4046CEC29E76DE4C4068B3EA73B5094E4046CEC29E76DE4C40
7901	Лая	6	56	340	59.913533000000001	59.944273000000003	58.069105	58.047583000000003	0103000020E610000001000000050000008C683BA6EEF44D403C6C223317064D408C683BA6EEF44D40BB7EC16ED8084D4077BF0AF0DDF84D40BB7EC16ED8084D4077BF0AF0DDF84D403C6C223317064D408C683BA6EEF44D403C6C223317064D40
45566	Краснополье	6	56	340	60.451219999999999	60.483522999999998	57.729864999999997	57.703555000000001	0103000020E610000001000000050000008BA6B393C1394E40F9F719170EDA4C408BA6B393C1394E405DBF60376CDD4C4091EEE714E43D4E405DBF60376CDD4C4091EEE714E43D4E40F9F719170EDA4C408BA6B393C1394E40F9F719170EDA4C40
8773	Кайгородское	6	56	340	61.042077999999997	61.066099000000001	57.574444999999997	57.550117999999998	0103000020E61000000100000005000000C7F0D8CF62854E40707841446AC64C40C7F0D8CF62854E40E42CEC6987C94C402FA699EE75884E40E42CEC6987C94C402FA699EE75884E40707841446AC64C40C7F0D8CF62854E40707841446AC64C40
46109	Зональный	6	56	340	60.107345000000002	60.127960999999999	57.891252999999999	57.883066999999997	0103000020E61000000100000005000000CF31207BBD0D4E40A296E65608F14C40CF31207BBD0D4E401FBB0B9414F24C40EC14AB0661104E401FBB0B9414F24C40EC14AB0661104E40A296E65608F14C40CF31207BBD0D4E40A296E65608F14C40
7760	Горноуральский	6	56	340	59.896241000000003	59.915509	58.079613999999999	58.059235999999999	0103000020E61000000100000005000000CC2A6C06B8F24D40785F950B95074D40CC2A6C06B8F24D40E126A3CA300A4D40CA181F662FF54D40E126A3CA300A4D40CA181F662FF54D40785F950B95074D40CC2A6C06B8F24D40785F950B95074D40
6329	Висимо-Уткинск	6	56	340	59.185367999999997	59.397523	57.718603999999999	57.663271999999999	0103000020E61000000100000005000000CADC7C23BA974D401F2DCE18E6D44C40CADC7C23BA974D402C634337FBDB4C4033349E08E2B24D402C634337FBDB4C4033349E08E2B24D401F2DCE18E6D44C40CADC7C23BA974D401F2DCE18E6D44C40
6805	Висим	6	56	340	59.467528999999999	59.531784999999999	57.662058999999999	57.639029000000001	0103000020E610000001000000050000003E7782FDD7BB4D400919C8B3CBD14C403E7782FDD7BB4D40E0826C59BED44C406EC0E78711C44D40E0826C59BED44C406EC0E78711C44D400919C8B3CBD14C403E7782FDD7BB4D400919C8B3CBD14C40
45462	Бызово	6	56	340	60.865945000000004	60.898032999999998	57.542033000000004	57.526035999999998	0103000020E610000001000000050000003F912749D76E4E406342CC2555C34C403F912749D76E4E40282D5C5661C54C4048DDCEBEF2724E40282D5C5661C54C4048DDCEBEF2724E406342CC2555C34C403F912749D76E4E406342CC2555C34C40
45479	Бродово	6	56	340	60.582706000000002	60.604391	57.680773000000002	57.667257999999997	0103000020E610000001000000050000006C97361C964A4E4047FFCBB568D54C406C97361C964A4E40FA7FD59123D74C40957F2DAF5C4D4E40FA7FD59123D74C40957F2DAF5C4D4E4047FFCBB568D54C406C97361C964A4E4047FFCBB568D54C40
9735	Беляковка	6	56	340	60.691726000000003	60.707590000000003	57.701169999999998	57.682538999999998	0103000020E610000001000000050000007EE5417A8A584E404D9F1D705DD74C407EE5417A8A584E40D97745F0BFD94C40037D224F925A4E40D97745F0BFD94C40037D224F925A4E404D9F1D705DD74C407EE5417A8A584E404D9F1D705DD74C40
8315	Башкарка	6	56	340	60.869179000000003	60.888924000000003	57.635801000000001	57.620596999999997	0103000020E610000001000000050000005CAFE941416F4E40737FF5B86FCF4C405CAFE941416F4E40CEE15AED61D14C409450FA42C8714E40CEE15AED61D14C409450FA42C8714E40737FF5B86FCF4C405CAFE941416F4E40737FF5B86FCF4C40
45381	Балакино	6	56	340	60.042352000000001	60.068393999999998	58.062783000000003	58.041804999999997	0103000020E61000000100000005000000C97553CA6B054E4096E7C1DD59054D40C97553CA6B054E4055DFF94509084D400E9F7422C1084E4055DFF94509084D400E9F7422C1084E4096E7C1DD59054D40C97553CA6B054E4096E7C1DD59054D40
9226	Анатольская	6	56	340	60.103364999999997	60.113947000000003	57.697268999999999	57.686787000000002	0103000020E61000000100000005000000884677103B0D4E40B328ECA2E8D74C40884677103B0D4E40DFC14F1C40D94C40193DB7D0950E4E40DFC14F1C40D94C40193DB7D0950E4E40B328ECA2E8D74C40884677103B0D4E40B328ECA2E8D74C40
50192	Покровское	6	56	7053	60.225445999999998	60.291347000000002	57.979889	57.955987	0103000020E61000000100000005000000CB811E6ADB1C4E40593332C85DFA4C40CB811E6ADB1C4E40E65AB4006DFD4C40D464C6DB4A254E40E65AB4006DFD4C40D464C6DB4A254E40593332C85DFA4C40CB811E6ADB1C4E40593332C85DFA4C40
50156	Станционный-Полевской	6	56	7031	60.297635	60.337322	56.449095999999997	56.435755	0103000020E610000001000000050000008E9257E718264E40C408E1D1C6374C408E9257E718264E40D8614CFA7B394C40541C075E2D2B4E40D8614CFA7B394C40541C075E2D2B4E40C408E1D1C6374C408E9257E718264E40C408E1D1C6374C40
50095	Кузино	6	56	7016	59.406694999999999	59.464582	57.035662000000002	57.009906000000001	0103000020E610000001000000050000002E39EE940EB44D4060048D9944814C402E39EE940EB44D40E0DA899290844C40B727486C77BB4D40E0DA899290844C40B727486C77BB4D4060048D9944814C402E39EE940EB44D4060048D9944814C40
40181	Юрты	6	56	781	59.645223999999999	59.660217000000003	59.160245000000003	59.153554999999997	0103000020E61000000100000005000000124C35B396D24D409291B3B0A7934D40124C35B396D24D407C2C7DE882944D40B2A19BFD81D44D407C2C7DE882944D40B2A19BFD81D44D409291B3B0A7934D40124C35B396D24D409291B3B0A7934D40
7384	Шайтанка	6	56	781	60.004128000000001	60.022517000000001	59.451931000000002	59.442590000000003	0103000020E61000000100000005000000BB7F2C4487004E40B1C403CAA6B84D40BB7F2C4487004E40388600E0D8B94D40514D49D6E1024E40388600E0D8B94D40514D49D6E1024E40B1C403CAA6B84D40BB7F2C4487004E40B1C403CAA6B84D40
7322	Старая Ляля	6	56	781	59.854782999999998	59.883780999999999	59.080939000000001	59.067053999999999	0103000020E61000000100000005000000A016838769ED4D407288B83995884D40A016838769ED4D4048FC8A355C8A4D40C0E95DBC1FF14D4048FC8A355C8A4D40C0E95DBC1FF14D407288B83995884D40A016838769ED4D407288B83995884D40
7560	Салтаново	6	56	781	60.670471999999997	60.695714000000002	59.077691999999999	59.069969	0103000020E610000001000000050000001D71C806D2554E40EE5D83BEF4884D401D71C806D2554E409694BBCFF1894D4047AF06280D594E409694BBCFF1894D4047AF06280D594E40EE5D83BEF4884D401D71C806D2554E40EE5D83BEF4884D40
49908	Савинова	6	56	781	60.331681000000003	60.345559999999999	59.025520999999998	59.016905999999999	0103000020E6100000010000000500000030DAE385742A4E40978DCEF929824D4030DAE385742A4E403C2EAA4544834D402367614F3B2C4E403C2EAA4544834D402367614F3B2C4E40978DCEF929824D4030DAE385742A4E40978DCEF929824D40
7022	Павда	6	56	781	59.490533999999997	59.539439000000002	59.259005999999999	59.238244000000002	0103000020E61000000100000005000000BCC96FD1C9BE4D40EF3B86C77E9E4D40BCC96FD1C9BE4D40E0BBCD1B27A14D40EE974F560CC54D40E0BBCD1B27A14D40EE974F560CC54D40EF3B86C77E9E4D40BCC96FD1C9BE4D40EF3B86C77E9E4D40
5504	Новая Ляля	6	56	781	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
7631	Лопаево	6	56	781	60.392181999999998	60.399585000000002	59.238515999999997	59.226348999999999	0103000020E61000000100000005000000390A100533324E40BC3D0801F99C4D40390A100533324E404FC939B1879E4D40707CED9925334E404FC939B1879E4D40707CED9925334E40BC3D0801F99C4D40390A100533324E40BC3D0801F99C4D40
6410	Лобва	6	56	781	60.461739000000001	60.561388999999998	59.203057000000001	59.169355000000003	0103000020E61000000100000005000000D52478431A3B4E400135B56CAD954D40D52478431A3B4E40A81C93C5FD994D40C5AA4198DB474E40A81C93C5FD994D40C5AA4198DB474E400135B56CAD954D40D52478431A3B4E400135B56CAD954D40
50164	Лесной	6	56	7034	59.757837000000002	59.823917000000002	58.660030999999996	58.623361000000003	0103000020E61000000100000005000000715985CD00E14D400A4D124BCA4F4D40715985CD00E14D404FAC53E57B544D4029CFBC1C76E94D404FAC53E57B544D4029CFBC1C76E94D400A4D124BCA4F4D40715985CD00E14D400A4D124BCA4F4D40
61322	Ис	6	56	7531	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
49846	Нижняя Тура	6	56	6988	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
3689	Шарама	6	56	1	59.006180999999998	59.026617000000002	56.433340999999999	56.423431000000001	0103000020E61000000100000005000000A46DFC89CA804D40698EACFC32364C40A46DFC89CA804D400A82C7B777374C404242942F68834D400A82C7B777374C404242942F68834D40698EACFC32364C40A46DFC89CA804D40698EACFC32364C40
3546	Уфа-Шигири	6	56	1	58.912109000000001	58.941215	56.453623	56.442686999999999	0103000020E6100000010000000500000092B1DAFCBF744D40A3AEB5F7A9384C4092B1DAFCBF744D4051DB8651103A4C4098C0ADBB79784D4051DB8651103A4C4098C0ADBB79784D40A3AEB5F7A9384C4092B1DAFCBF744D40A3AEB5F7A9384C40
3369	Урмикеево	6	56	1	59.003953000000003	59.031180999999997	56.468134999999997	56.450394000000003	0103000020E610000001000000050000004DDC2A8881804D404628B682A6394C404DDC2A8881804D40758E01D9EB3B4C40D7A02FBDFD834D40758E01D9EB3B4C40D7A02FBDFD834D404628B682A6394C404DDC2A8881804D404628B682A6394C40
4098	Тюльгаш	6	56	1	59.047314999999998	59.107788999999997	56.266097000000002	56.255837999999997	0103000020E610000001000000050000001CCEFC6A0E864D407A89B14CBF204C401CCEFC6A0E864D4028486C770F224C402CEFAA07CC8D4D4028486C770F224C402CEFAA07CC8D4D407A89B14CBF204C401CCEFC6A0E864D407A89B14CBF204C40
2514	Талица	6	56	1	58.755775	58.774272000000003	56.843668000000001	56.834322999999998	0103000020E610000001000000050000003411363CBD604D407AA69718CB6A4C403411363CBD604D4043572250FD6B4C40B11A4B581B634D4043572250FD6B4C40B11A4B581B634D407AA69718CB6A4C403411363CBD604D407AA69718CB6A4C40
2735	Старобухарово	6	56	1	58.923175999999998	58.946389000000003	56.920079000000001	56.911588000000002	0103000020E61000000100000005000000DE3994A12A764D4089B663EAAE744C40DE3994A12A764D40425E0F26C5754C40A725564623794D40425E0F26C5754C40A725564623794D4089B663EAAE744C40DE3994A12A764D4089B663EAAE744C40
2977	Сосновый Бор (Новоселы)	6	56	1	58.812781999999999	58.831556999999997	56.709654999999998	56.695442999999997	0103000020E610000001000000050000008463963D09684D40B69DB64604594C408463963D09684D40B0389CF9D55A4C4043E1B375706A4D40B0389CF9D55A4C4043E1B375706A4D40B69DB64604594C408463963D09684D40B69DB64604594C40
50237	Село Шокурово	6	56	1	59.094099	59.132905999999998	56.331578	56.311421000000003	0103000020E610000001000000050000000CCB9F6F0B8C4D40D124B1A4DC274C400CCB9F6F0B8C4D405B09DD25712A4C4099B8551003914D405B09DD25712A4C4099B8551003914D40D124B1A4DC274C400CCB9F6F0B8C4D40D124B1A4DC274C40
4532	Рябиновка	6	56	1	59.078639000000003	59.095958000000003	56.215563000000003	56.208855	0103000020E610000001000000050000005798BED7108A4D40944DB9C2BB1A4C405798BED7108A4D40249D8191971B4C4011E50B5A488C4D40249D8191971B4C4011E50B5A488C4D40944DB9C2BB1A4C405798BED7108A4D40944DB9C2BB1A4C40
3968	Перепряжка	6	56	1	58.974550999999998	58.997152999999997	56.345224000000002	56.331763000000002	0103000020E610000001000000050000005DA45016BE7C4D40ED82C135772A4C405DA45016BE7C4D40ACE5CE4C302C4C40DC0DA2B5A27F4D40ACE5CE4C302C4C40DC0DA2B5A27F4D40ED82C135772A4C405DA45016BE7C4D40ED82C135772A4C40
1471	Первомайское	6	56	1	59.519002	59.548681999999999	56.828724000000001	56.81268	0103000020E61000000100000005000000804754A86EC24D40800EF3E505684C40804754A86EC24D4085B4C6A0136A4C40B2F336363BC64D4085B4C6A0136A4C40B2F336363BC64D40800EF3E505684C40804754A86EC24D40800EF3E505684C40
2405	Отевка	6	56	1	58.609439999999999	58.634053999999999	56.855890000000002	56.847512999999999	0103000020E61000000100000005000000E76F4221024E4D40A9F7544E7B6C4C40E76F4221024E4D409A7CB3CD8D6D4C40F1F274AE28514D409A7CB3CD8D6D4C40F1F274AE28514D40A9F7544E7B6C4C40E76F4221024E4D40A9F7544E7B6C4C40
4361	Нижние Серги	6	56	1	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
2865	Накоряково	6	56	1	58.887647999999999	58.905974000000001	56.768200999999998	56.758589999999998	0103000020E610000001000000050000000E2E1D739E714D404C89247A19614C400E2E1D739E714D4093E00D6954624C405E83BEF4F6734D4093E00D6954624C405E83BEF4F6734D404C89247A19614C400E2E1D739E714D404C89247A19614C40
387	Михайловский Завод	6	56	1	59.237012	59.259497000000003	56.413119000000002	56.398465999999999	0103000020E610000001000000050000003961C268569E4D40B24813EF00334C403961C268569E4D40992D5915E1344C407F349C3237A14D40992D5915E1344C407F349C3237A14D40B24813EF00334C403961C268569E4D40B24813EF00334C40
3	Михайловск	6	56	1	59.068559999999998	59.154744000000001	56.469383000000001	56.405943000000001	0103000020E6100000010000000500000029E8F692C6884D402385B2F0F5334C4029E8F692C6884D403126FDBD143C4C4049A0C1A6CE934D403126FDBD143C4C4049A0C1A6CE934D402385B2F0F5334C4029E8F692C6884D402385B2F0F5334C40
1937	Малиновый	6	56	1	58.474395999999999	58.496071999999998	56.940094000000002	56.929403000000001	0103000020E6100000010000000500000036AD1402B93C4D40F3E670ADF6764C4036AD1402B93C4D403A950C0055784C400C3B8C497F3F4D403A950C0055784C400C3B8C497F3F4D40F3E670ADF6764C4036AD1402B93C4D40F3E670ADF6764C40
1582	Лазоревый	6	56	1	59.518059000000001	59.530949999999997	56.771273999999998	56.765542000000003	0103000020E610000001000000050000000133DFC14FC24D4073DBBE47FD614C400133DFC14FC24D40A7203F1BB9624C40D5E76A2BF6C34D40A7203F1BB9624C40D5E76A2BF6C34D4073DBBE47FD614C400133DFC14FC24D4073DBBE47FD614C40
3880	Красноармеец	6	56	1	59.010249999999999	59.041052999999998	56.331034000000002	56.315575000000003	0103000020E610000001000000050000005A643BDF4F814D40B537F8C264284C405A643BDF4F814D409AEE75525F2A4C408B33863941854D409AEE75525F2A4C408B33863941854D40B537F8C264284C405A643BDF4F814D40B537F8C264284C40
2634	Контуганово	6	56	1	58.741286000000002	58.765729	56.875649000000003	56.861407	0103000020E61000000100000005000000C87DAB75E25E4D40D2C5A695426E4C40C87DAB75E25E4D4037E3344415704C40A54C6A6803624D4037E3344415704C40A54C6A6803624D40D2C5A695426E4C40C87DAB75E25E4D40D2C5A695426E4C40
1706	Ключевая	6	56	1	58.459529000000003	58.501156999999999	56.836623000000003	56.825187999999997	0103000020E610000001000000050000002448A5D8D13A4D409C86A8C29F694C402448A5D8D13A4D406C0A6476166B4C40AB949EE925404D406C0A6476166B4C40AB949EE925404D409C86A8C29F694C402448A5D8D13A4D409C86A8C29F694C40
2058	Кленовское	6	56	1	58.605387999999998	58.686542000000003	56.834766999999999	56.815981000000001	0103000020E6100000010000000500000007B29E5A7D4D4D402594BE1072684C4007B29E5A7D4D4D40D86322A5D96A4C404CAAB69BE0574D40D86322A5D96A4C404CAAB69BE0574D402594BE1072684C4007B29E5A7D4D4D402594BE1072684C40
2287	Киселёвка	6	56	1	58.610329	58.622231999999997	56.780576000000003	56.766159000000002	0103000020E610000001000000050000007366BB421F4E4D409E44847F11624C407366BB421F4E4D40710514EAE9634C402843554CA54F4D40710514EAE9634C402843554CA54F4D409E44847F11624C407366BB421F4E4D409E44847F11624C40
14817	Киргишаны	6	56	1	59.145195000000001	59.190415999999999	56.846843999999997	56.834018	0103000020E610000001000000050000007845F0BF95924D403E23111AC16A4C407845F0BF95924D402B685A62656C4C404C512E8D5F984D402B685A62656C4C404C512E8D5F984D403E23111AC16A4C407845F0BF95924D403E23111AC16A4C40
1251	Дружинино	6	56	1	59.49729	59.537866999999999	56.799354999999998	56.779733	0103000020E610000001000000050000005D50DF32A7BF4D40554E7B4ACE634C405D50DF32A7BF4D407172BF4351664C407F4C6BD3D8C44D407172BF4351664C407F4C6BD3D8C44D40554E7B4ACE634C405D50DF32A7BF4D40554E7B4ACE634C40
530	Верхние Серги	6	56	1	59.537723	59.581111999999997	56.666289999999996	56.627896	0103000020E610000001000000050000004CA7751BD4C44D4005A568E55E504C404CA7751BD4C44D406FD39FFD48554C4015A8C5E061CA4D406FD39FFD48554C4015A8C5E061CA4D4005A568E55E504C404CA7751BD4C44D4005A568E55E504C40
3094	Васькино	6	56	1	58.797232999999999	58.820507999999997	56.762222000000001	56.748246999999999	0103000020E610000001000000050000005F251FBB0B664D40412AC58EC65F4C405F251FBB0B664D405725917D90614C409D0DF96706694D405725917D90614C409D0DF96706694D40412AC58EC65F4C405F251FBB0B664D40412AC58EC65F4C40
13108	Бисерть	6	56	1	59.032187	59.088925000000003	56.879314000000001	56.832053000000002	0103000020E610000001000000050000009D2D20B41E844D40F4C473B6806A4C409D2D20B41E844D401D75745C8D704C40FE65F7E4618B4D401D75745C8D704C40FE65F7E4618B4D40F4C473B6806A4C409D2D20B41E844D40F4C473B6806A4C40
1009	Атиг	6	56	1	59.414088	59.456318000000003	56.704273999999998	56.675291999999999	0103000020E6100000010000000500000041D5E8D500B54D400EA0DFF76F564C4041D5E8D500B54D4028B682A6255A4C40BF49D3A068BA4D4028B682A6255A4C40BF49D3A068BA4D400EA0DFF76F564C4041D5E8D500B54D400EA0DFF76F564C40
3263	Аракаево	6	56	1	59.203234999999999	59.224642000000003	56.449817000000003	56.435262999999999	0103000020E610000001000000050000008733BF9A039A4D405514AFB2B6374C408733BF9A039A4D40A9177C9A93394C406EA7AD11C19C4D40A9177C9A93394C406EA7AD11C19C4D405514AFB2B6374C408733BF9A039A4D405514AFB2B6374C40
3586	Акбаш	6	56	1	59.010492999999997	59.044269	56.394924000000003	56.372174000000001	0103000020E6100000010000000500000020EBA9D557814D40F435CB65A32F4C4020EBA9D557814D40E833A0DE8C324C40029D499BAA854D40E833A0DE8C324C40029D499BAA854D40F435CB65A32F4C4020EBA9D557814D40F435CB65A32F4C40
50205	Верхние Серги	6	56	7059	59.537723	59.581111999999997	56.666289999999996	56.627896	0103000020E610000001000000050000004CA7751BD4C44D4005A568E55E504C404CA7751BD4C44D406FD39FFD48554C4015A8C5E061CA4D406FD39FFD48554C4015A8C5E061CA4D4005A568E55E504C404CA7751BD4C44D4005A568E55E504C40
49859	с. Шурала	6	56	1035	60.134312000000001	60.266112999999997	57.450477999999997	57.379356999999999	0103000020E61000000100000005000000EDBAB72231114E401C412AC58EB04C40EDBAB72231114E40A3C85A43A9B94C402D05A4FD0F224E40A3C85A43A9B94C402D05A4FD0F224E401C412AC58EB04C40EDBAB72231114E401C412AC58EB04C40
11231	Шайдуриха	6	56	1035	60.552962999999998	60.592407999999999	57.392014000000003	57.379536999999999	0103000020E61000000100000005000000F372D87DC7464E409C4F1DAB94B04C40F372D87DC7464E407EC9C6832DB24C40C3F17C06D44B4E407EC9C6832DB24C40C3F17C06D44B4E409C4F1DAB94B04C40F372D87DC7464E409C4F1DAB94B04C40
45901	Цементный	6	56	1035	60.137303000000003	60.169300999999997	57.486294999999998	57.458888000000002	0103000020E6100000010000000500000044520B2593114E4070438CD7BCBA4C4044520B2593114E40AA9A20EA3EBE4C400D17B9A7AB154E40AA9A20EA3EBE4C400D17B9A7AB154E4070438CD7BCBA4C4044520B2593114E4070438CD7BCBA4C40
30839	Федьковка	6	56	1035	60.254137999999998	60.270991000000002	57.429605000000002	57.422432999999998	0103000020E61000000100000005000000DE550F9887204E4026E0D74812B64C40DE550F9887204E405B99F04BFDB64C40534145D5AF224E405B99F04BFDB64C40534145D5AF224E4026E0D74812B64C40DE550F9887204E4026E0D74812B64C40
46920	Тарасково	6	56	1035	60.050795999999998	60.073945000000002	57.143653999999998	57.117142000000001	0103000020E610000001000000050000004162BB7B80064E40787E5182FE8E4C404162BB7B80064E4044F8174163924C40F3599E0777094E4044F8174163924C40F3599E0777094E40787E5182FE8E4C404162BB7B80064E40787E5182FE8E4C40
30262	Таватуй	6	56	1035	60.118330999999998	60.145415	57.081753999999997	57.062677000000001	0103000020E610000001000000050000002E8D5F78250F4E400F9BC8CC05884C402E8D5F78250F4E40992842EA768A4C4086AC6EF59C124E40992842EA768A4C4086AC6EF59C124E400F9BC8CC05884C402E8D5F78250F4E400F9BC8CC05884C40
30884	Середовина	6	56	1035	60.274566	60.290968999999997	57.491427999999999	57.482937999999997	0103000020E61000000100000005000000F94B8BFA24234E4071FF91E9D0BD4C40F94B8BFA24234E405A2BDA1CE7BE4C402D93E1783E254E405A2BDA1CE7BE4C402D93E1783E254E4071FF91E9D0BD4C40F94B8BFA24234E4071FF91E9D0BD4C40
30828	Ребристый	6	56	1035	60.26773	60.283000999999999	57.473089999999999	57.461933000000002	0103000020E610000001000000050000003C1405FA44224E40BAF8DB9E20BB4C403C1405FA44224E4046088F368EBC4C401EDE736039244E4046088F368EBC4C401EDE736039244E40BAF8DB9E20BB4C403C1405FA44224E40BAF8DB9E20BB4C40
46961	Починок	6	56	1035	59.927025999999998	59.945090999999998	57.074392000000003	57.061458999999999	0103000020E610000001000000050000005645B8C9A8F64D40BE8575E3DD874C405645B8C9A8F64D40C28A53AD85894C40395FECBDF8F84D40C28A53AD85894C40395FECBDF8F84D40BE8575E3DD874C405645B8C9A8F64D40BE8575E3DD874C40
46935	Пальники	6	56	1035	59.835838000000003	59.860576999999999	57.148614999999999	57.135790999999998	0103000020E61000000100000005000000856055BDFCEA4D40AA0B789961914C40856055BDFCEA4D40F758FAD005934C404B581B6327EE4D40F758FAD005934C404B581B6327EE4D40AA0B789961914C40856055BDFCEA4D40AA0B789961914C40
46094	Осиновка	6	56	1035	60.548983	60.569949999999999	57.509863000000003	57.500816	0103000020E61000000100000005000000AD872F1345464E4022A81ABD1AC04C40AD872F1345464E406138D73043C14C40772D211FF4484E406138D73043C14C40772D211FF4484E4022A81ABD1AC04C40AD872F1345464E4022A81ABD1AC04C40
17766	Новоуральск	6	56	1035	60.050859000000003	60.121772	57.263199	57.226635999999999	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
49928	Новоуральск	6	56	1035	60.050859000000003	60.121772	57.263199	57.226635999999999	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
30414	Нижние Таволги	6	56	1035	60.368637999999997	60.385894	57.592345999999999	57.578653000000003	0103000020E610000001000000050000000B08AD872F2F4E40BC5D2F4D11CA4C400B08AD872F2F4E404DF564FED1CB4C407FDC7EF964314E404DF564FED1CB4C407FDC7EF964314E40BC5D2F4D11CA4C400B08AD872F2F4E40BC5D2F4D11CA4C40
30720	Кунара	6	56	1035	60.457597999999997	60.477530999999999	57.403207000000002	57.394176999999999	0103000020E61000000100000005000000855B3E92923A4E40EEEA556474B24C40855B3E92923A4E40574277499CB34C40C0E95DBC1F3D4E40574277499CB34C40C0E95DBC1F3D4E40EEEA556474B24C40855B3E92923A4E40EEEA556474B24C40
46063	Конёво	6	56	1035	60.621226	60.650995999999999	57.481122999999997	57.466400999999998	0103000020E6100000010000000500000063B66455844F4E402DE92807B3BB4C4063B66455844F4E403C2D3F7095BD4C40D5E940D653534E403C2D3F7095BD4C40D5E940D653534E402DE92807B3BB4C4063B66455844F4E402DE92807B3BB4C40
46118	Киприно	6	56	1035	60.724576999999996	60.748381999999999	57.46096	57.452773000000001	0103000020E6100000010000000500000086376BF0BE5C4E4083C13577F4B94C4086376BF0BE5C4E40D061BEBC00BB4C4021753BFBCA5F4E40D061BEBC00BB4C4021753BFBCA5F4E4083C13577F4B94C4086376BF0BE5C4E4083C13577F4B94C40
45927	Калиново	6	56	1035	60.140644999999999	60.161585000000002	57.142305999999998	57.125024000000003	0103000020E6100000010000000500000047ACC5A700124E40899B53C900904C4047ACC5A700124E402503401537924C40184339D1AE144E402503401537924C40184339D1AE144E40899B53C900904C4047ACC5A700124E40899B53C900904C40
31028	Забельный	6	56	1035	60.161512999999999	60.171636999999997	57.506971	57.500100000000003	0103000020E610000001000000050000007E703E75AC144E40645DDC4603C04C407E703E75AC144E409D82FC6CE4C04C404BE48233F8154E409D82FC6CE4C04C404BE48233F8154E40645DDC4603C04C407E703E75AC144E40645DDC4603C04C40
30512	Верхние Таволги	6	56	1035	60.364486999999997	60.384115999999999	57.572330999999998	57.560364999999997	0103000020E6100000010000000500000098689082A72E4E405969520ABAC74C4098689082A72E4E4055BE672442C94C4067EF8CB62A314E4055BE672442C94C4067EF8CB62A314E405969520ABAC74C4098689082A72E4E405969520ABAC74C40
15145	Верх-Нейвинский	6	56	1035	60.114854999999999	60.163921000000002	57.281923999999997	57.253146000000001	0103000020E610000001000000050000001B649291B30E4E407E8E8F1667A04C401B649291B30E4E408FFAEB1516A44C405610035DFB144E408FFAEB1516A44C405610035DFB144E407E8E8F1667A04C401B649291B30E4E407E8E8F1667A04C40
30123	Вересковый	6	56	1035	60.174304999999997	60.177565999999999	57.472591999999999	57.471063000000001	0103000020E61000000100000005000000BF4351A04F164E4086ADD9CA4BBC4C40BF4351A04F164E40F52C08E57DBC4C40D670917BBA164E40F52C08E57DBC4C40D670917BBA164E4086ADD9CA4BBC4C40BF4351A04F164E4086ADD9CA4BBC4C40
30411	Быньги	6	56	1035	60.270460999999997	60.314028999999998	57.548819000000002	57.527698000000001	0103000020E61000000100000005000000F6EB4E779E224E401215AA9B8BC34C40F6EB4E779E224E40333674B33FC64C406F7F2E1A32284E40333674B33FC64C406F7F2E1A32284E401215AA9B8BC34C40F6EB4E779E224E401215AA9B8BC34C40
30218	Аять	6	56	1035	60.216031999999998	63.669227999999997	57.538646999999997	57.021956000000003	0103000020E61000000100000005000000DA71C3EFA61B4E40BAF94674CF824C40DA71C3EFA61B4E40548B8862F2C44C40A3C85A43A9D54F40548B8862F2C44C40A3C85A43A9D54F40BAF94674CF824C40DA71C3EFA61B4E40BAF94674CF824C40
30716	Аятское	6	56	1035	60.67897	60.710887	57.424754	57.399289000000003	0103000020E61000000100000005000000897B2C7DE8564E408753E6E61BB34C40897B2C7DE8564E402F6CCD565EB64C4066136058FE5A4E402F6CCD565EB64C4066136058FE5A4E408753E6E61BB34C40897B2C7DE8564E408753E6E61BB34C40
50190	Новоуральск	6	56	7048	60.050859000000003	60.121772	57.263199	57.226635999999999	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
50159	Юва	6	56	932	57.930278000000001	57.970064000000001	56.451408999999998	56.429872000000003	0103000020E610000001000000050000001A18795913F74C40AABBB20B06374C401A18795913F74C405E0F26C5C7394C407383A10E2BFC4C405E0F26C5C7394C407383A10E2BFC4C40AABBB20B06374C401A18795913F74C40AABBB20B06374C40
27942	Чувашково	6	56	932	57.872525000000003	57.894371999999997	56.691710999999998	56.679549000000002	0103000020E61000000100000005000000A1F831E6AEEF4C40C7832D76FB564C40A1F831E6AEEF4C4048A46DFC89584C40A33A1DC87AF24C4048A46DFC89584C40A33A1DC87AF24C40C7832D76FB564C40A1F831E6AEEF4C40C7832D76FB564C40
28326	Чигвинцево	6	56	932	57.734966	57.752231000000002	56.557138000000002	56.548434999999998	0103000020E6100000010000000500000002D6AA5D13DE4C40AA7D3A1E33464C4002D6AA5D13DE4C40EFAD484C50474C40C904FC1A49E04C40EFAD484C50474C40C904FC1A49E04C40AA7D3A1E33464C4002D6AA5D13DE4C40AA7D3A1E33464C40
27472	Чатлык	6	56	932	57.687652	57.704908000000003	56.793277000000003	56.777568000000002	0103000020E61000000100000005000000B68311FB04D84C404435255987634C40B68311FB04D84C40A2D5C9198A654C402A58E36C3ADA4C40A2D5C9198A654C402A58E36C3ADA4C404435255987634C40B68311FB04D84C404435255987634C40
61321	Усть-Бугалыш	6	56	932	57.843859999999999	57.86815	56.294300999999997	56.284539000000002	0103000020E610000001000000050000008733BF9A03EC4C40E1B721C66B244C408733BF9A03EC4C400D17B9A7AB254C40DE02098A1FEF4C400D17B9A7AB254C40DE02098A1FEF4C40E1B721C66B244C408733BF9A03EC4C40E1B721C66B244C40
61332	Усть-Баяк	6	56	932	57.984724	58.014360000000003	56.632922000000001	56.617570999999998	0103000020E610000001000000050000000CCB9F6F0BFE4C40A0FA07910C4F4C400CCB9F6F0BFE4C409F758D9603514C406F2F698CD6014D409F758D9603514C406F2F698CD6014D40A0FA07910C4F4C400CCB9F6F0BFE4C40A0FA07910C4F4C40
29295	Татарская Еманзельга	6	56	932	57.916614000000003	57.951092000000003	56.245635	56.228575999999997	0103000020E610000001000000050000002387889B53F54C40435376FA411D4C402387889B53F54C4061E0B9F7701F4C405EBEF561BDF94C4061E0B9F7701F4C405EBEF561BDF94C40435376FA411D4C402387889B53F54C40435376FA411D4C40
28841	Сызги	6	56	932	57.85463	57.873790999999997	56.457163999999999	56.442956000000002	0103000020E610000001000000050000001A170E8464ED4C4093C83EC8B2384C401A170E8464ED4C404B749659843A4C4002452C62D8EF4C404B749659843A4C4002452C62D8EF4C4093C83EC8B2384C401A170E8464ED4C4093C83EC8B2384C40
28891	Средний Бугалыш	6	56	932	57.966911000000003	58.022049000000003	56.309413999999997	56.287567000000003	0103000020E61000000100000005000000439259BDC3FB4C405534D6FECE244C40439259BDC3FB4C405776C1E09A274C406BF46A80D2024D405776C1E09A274C406BF46A80D2024D405534D6FECE244C40439259BDC3FB4C405534D6FECE244C40
28196	Средний Баяк	6	56	932	57.976486999999999	57.994579000000002	56.576574000000001	56.564796000000001	0103000020E610000001000000050000000DFCA886FDFC4C40B0743E3C4B484C400DFCA886FDFC4C40A9DC442DCD494C40EA245B5D4EFF4C40A9DC442DCD494C40EA245B5D4EFF4C40B0743E3C4B484C400DFCA886FDFC4C40B0743E3C4B484C40
29277	Сарсы-Вторые	6	56	932	57.976109999999998	57.995756	56.224601999999997	56.203082000000002	0103000020E6100000010000000500000037A6272CF1FC4C4001344A97FE194C4037A6272CF1FC4C40DF4E22C2BF1C4C40DC65BFEE74FF4C40DF4E22C2BF1C4C40DC65BFEE74FF4C4001344A97FE194C4037A6272CF1FC4C4001344A97FE194C40
29472	Саргая	6	56	932	57.704639	57.731479999999998	56.256528000000003	56.231133	0103000020E610000001000000050000003A3E5A9C31DA4C40600322C4951D4C403A3E5A9C31DA4C401041D5E8D5204C40CBD6FA22A1DD4C401041D5E8D5204C40CBD6FA22A1DD4C40600322C4951D4C403A3E5A9C31DA4C40600322C4951D4C40
28564	Сарана	6	56	932	57.689951000000001	57.744838000000001	56.489749000000003	56.468572999999999	0103000020E61000000100000005000000D76B7A5050D84C40F1643733FA3B4C40D76B7A5050D84C40D61F6118B03E4C40B66801DA56DF4C40D61F6118B03E4C40B66801DA56DF4C40F1643733FA3B4C40D76B7A5050D84C40F1643733FA3B4C40
61319	Русский Усть-Маш	6	56	932	57.860371000000001	57.885055999999999	56.326242999999998	56.314587000000003	0103000020E61000000100000005000000A2B60DA320EE4C40965F066344284C40A2B60DA320EE4C4043C6A354C2294C407590D78349F14C4043C6A354C2294C407590D78349F14C40965F066344284C40A2B60DA320EE4C40965F066344284C40
28063	Рахмангулово	6	56	932	58.024276999999998	58.067386999999997	56.594161999999997	56.585205000000002	0103000020E61000000100000005000000C2853C821B034D40543A58FFE74A4C40C2853C821B034D4052431B800D4C4C4078962023A0084D4052431B800D4C4C4078962023A0084D40543A58FFE74A4C40C2853C821B034D40543A58FFE74A4C40
27799	Приданниково	6	56	932	57.772309	57.801395999999997	56.666181000000002	56.646306000000003	0103000020E6100000010000000500000007B47405DBE24C40B39AAE27BA524C4007B47405DBE24C40B91B446B45554C409692E52494E64C40B91B446B45554C409692E52494E64C40B39AAE27BA524C4007B47405DBE24C40B39AAE27BA524C40
49296	Подгорная	6	56	932	57.785818999999996	57.829971999999998	56.744889999999998	56.725161	0103000020E61000000100000005000000A7C98CB795E44C40D6AA5D13D25C4C40A7C98CB795E44C40088F368E585F4C40404CC2853CEA4C40088F368E585F4C40404CC2853CEA4C40D6AA5D13D25C4C40A7C98CB795E44C40D6AA5D13D25C4C40
45371	Озерки	6	56	932	57.833402999999997	57.855699000000001	56.429718000000001	56.417028000000002	0103000020E61000000100000005000000B3B112F3ACEA4C4016C26A2C61354C40B3B112F3ACEA4C405340DAFF00374C40261C7A8B87ED4C405340DAFF00374C40261C7A8B87ED4C4016C26A2C61354C40B3B112F3ACEA4C4016C26A2C61354C40
29158	Новый Бугалыш	6	56	932	57.925677999999998	57.964745999999998	56.306941999999999	56.298012	0103000020E610000001000000050000003750E09D7CF64C4064E8D84125264C403750E09D7CF64C4069E21DE049274C40317903CC7CFB4C4069E21DE049274C40317903CC7CFB4C4064E8D84125264C403750E09D7CF64C4064E8D84125264C40
55028	Новое Село	6	56	932	57.510603000000003	57.543427000000001	56.876657999999999	56.860024000000003	0103000020E61000000100000005000000A81E69705BC14C4037E33444156E4C40A81E69705BC14C406DE34F5436704C40B76114048FC54C406DE34F5436704C40B76114048FC54C4037E33444156E4C40A81E69705BC14C4037E33444156E4C40
27242	Нижнеиргинское	6	56	932	57.410378000000001	57.453173	56.875717999999999	56.850476	0103000020E61000000100000005000000BB7F2C4487B44C403604C765DC6C4C40BB7F2C4487B44C405F42058717704C401137A79201BA4C405F42058717704C401137A79201BA4C403604C765DC6C4C40BB7F2C4487B44C403604C765DC6C4C40
28661	Натальинск	6	56	932	57.858314	57.883673000000002	56.481364999999997	56.465384999999998	0103000020E6100000010000000500000077D9AF3BDDED4C40448655BC913B4C4077D9AF3BDDED4C4032384A5E9D3D4C40DAAD65321CF14C4032384A5E9D3D4C40DAAD65321CF14C40448655BC913B4C4077D9AF3BDDED4C40448655BC913B4C40
61315	Марийский Усть-Маш	6	56	932	57.894426000000003	57.912132	56.337307000000003	56.328085000000002	0103000020E610000001000000050000009758198D7CF24C4072A774B0FE294C409758198D7CF24C401FDB32E02C2B4C404AD1CABDC0F44C401FDB32E02C2B4C404AD1CABDC0F44C4072A774B0FE294C409758198D7CF24C4072A774B0FE294C40
28555	Марийские Ключики	6	56	932	57.822659000000002	57.847633000000002	56.46734	56.458621999999998	0103000020E610000001000000050000004A61DEE34CE94C40F19C2D20B43A4C404A61DEE34CE94C406B0E10CCD13B4C405401F73C7FEC4C406B0E10CCD13B4C405401F73C7FEC4C40F19C2D20B43A4C404A61DEE34CE94C40F19C2D20B43A4C40
49345	Крылово	6	56	932	57.876334	57.914521000000001	56.644632999999999	56.630659000000001	0103000020E61000000100000005000000BA2F67B62BF04C40CBF6216FB9504C40BA2F67B62BF04C4010768A5583524C40AB402D060FF54C4010768A5583524C40AB402D060FF54C40CBF6216FB9504C40BA2F67B62BF04C40CBF6216FB9504C40
29558	Криулино	6	56	932	57.800452999999997	57.828012999999999	56.601322000000003	56.573391000000001	0103000020E61000000100000005000000177E703E75E64C400E6954E064494C40177E703E75E64C40C32E8A1EF84C4C40D8D47954FCE94C40C32E8A1EF84C4C40D8D47954FCE94C400E6954E064494C40177E703E75E64C400E6954E064494C40
27479	Красный Турыш	6	56	932	57.680205000000001	57.694569000000001	56.828142999999997	56.820118999999998	0103000020E61000000100000005000000B0C91AF510D74C4003EACDA8F9684C40B0C91AF510D74C40A6B4FE96006A4C4060E811A3E7D84C40A6B4FE96006A4C4060E811A3E7D84C4003EACDA8F9684C40B0C91AF510D74C4003EACDA8F9684C40
27205	Красносоколье	6	56	932	57.392007	57.433132000000001	56.925021000000001	56.907947	0103000020E61000000100000005000000CB660E492DB24C402BC0779B37744C40CB660E492DB24C407E8E8F1667764C40F06C8FDE70B74C407E8E8F1667764C40F06C8FDE70B74C402BC0779B37744C40CB660E492DB24C402BC0779B37744C40
49495	Красная Поляна	6	56	932	57.848019000000001	57.866290999999997	56.524113999999997	56.516838999999997	0103000020E610000001000000050000007DB1F7E28BEC4C400F26C5C727424C407DB1F7E28BEC4C4018B0E42A16434C40D9E89C9FE2EE4C4018B0E42A16434C40D9E89C9FE2EE4C400F26C5C727424C407DB1F7E28BEC4C400F26C5C727424C40
49891	Ключики	6	56	932	57.707199000000003	57.723377999999997	56.699807	56.686836999999997	0103000020E61000000100000005000000C861307F85DA4C4064575A46EA574C40C861307F85DA4C408541994693594C40AC527AA697DC4C408541994693594C40AC527AA697DC4C4064575A46EA574C40C861307F85DA4C4064575A46EA574C40
49510	Калиновка	6	56	932	57.873423000000003	57.893526999999999	56.592759000000001	56.583654000000003	0103000020E6100000010000000500000080492A53CCEF4C40FD169D2CB54A4C4080492A53CCEF4C4070B4E386DF4B4C40E78BBD175FF24C4070B4E386DF4B4C40E78BBD175FF24C40FD169D2CB54A4C4080492A53CCEF4C40FD169D2CB54A4C40
28384	Зауфа	6	56	932	57.724707000000002	57.772919999999999	56.495052000000001	56.468283999999997	0103000020E610000001000000050000005517F032C3DC4C40BA9EE8BAF03B4C405517F032C3DC4C40E2E82ADD5D3F4C405036E50AEFE24C40E2E82ADD5D3F4C405036E50AEFE24C40BA9EE8BAF03B4C405517F032C3DC4C40BA9EE8BAF03B4C40
45652	Дегтярка	6	56	932	57.630859999999998	57.643742000000003	56.258833000000003	56.249460999999997	0103000020E61000000100000005000000622D3E05C0D04C4050508A56EE1F4C40622D3E05C0D04C401310937021214C40E4874A2366D24C401310937021214C40E4874A2366D24C4050508A56EE1F4C40622D3E05C0D04C4050508A56EE1F4C40
45445	Голенищево	6	56	932	58.053679000000002	58.079738999999996	56.316878000000003	56.310388000000003	0103000020E61000000100000005000000B2BD16F4DE064D40128942CBBA274C40B2BD16F4DE064D40346953758F284C409D9B36E3340A4D40346953758F284C409D9B36E3340A4D40128942CBBA274C40B2BD16F4DE064D40128942CBBA274C40
27586	Верхняя Ирга	6	56	932	57.561599999999999	57.576844000000001	56.812339999999999	56.800379999999997	0103000020E6100000010000000500000080B74082E2C74C40AD2F12DA72664C4080B74082E2C74C40C79DD2C1FA674C4069723106D6C94C40C79DD2C1FA674C4069723106D6C94C40AD2F12DA72664C4080B74082E2C74C40AD2F12DA72664C40
29024	Верхний Бугалыш	6	56	932	58.001649	58.027242000000001	56.308680000000003	56.295499999999997	0103000020E610000001000000050000001A89D00836004D40E7FBA9F1D2254C401A89D00836004D40F37684D382274C40F08975AA7C034D40F37684D382274C40F08975AA7C034D40E7FBA9F1D2254C401A89D00836004D40E7FBA9F1D2254C40
28277	Верхний Баяк	6	56	932	58.010677000000001	58.020989	56.550975999999999	56.543278999999998	0103000020E61000000100000005000000E2E82ADD5D014D4042CD902A8A454C40E2E82ADD5D014D40C170AE6186464C40B2497EC4AF024D40C170AE6186464C40B2497EC4AF024D4042CD902A8A454C40E2E82ADD5D014D4042CD902A8A454C40
27858	Верх-Никитино	6	56	932	57.676521000000001	57.695934000000001	56.619611999999996	56.610214999999997	0103000020E610000001000000050000005307793D98D64C40AA436E861B4E4C405307793D98D64C40C51A2E724F4F4C405516855D14D94C40C51A2E724F4F4C405516855D14D94C40AA436E861B4E4C405307793D98D64C40AA436E861B4E4C40
27382	Верх-Бобровка	6	56	932	57.610343	57.621203000000001	56.856386999999998	56.852544000000002	0103000020E61000000100000005000000D82B2CB81FCE4C4055336B29206D4C40D82B2CB81FCE4C401ADCD6169E6D4C40AB96749483CF4C401ADCD6169E6D4C40AB96749483CF4C4055336B29206D4C40D82B2CB81FCE4C4055336B29206D4C40
27529	Большой Турыш	6	56	932	57.608097000000001	57.632711	56.761052999999997	56.743547999999997	0103000020E61000000100000005000000DAE55B1FD6CD4C40CB80B3942C5F4C40DAE55B1FD6CD4C40E7C2482F6A614C40E4688EACFCD04C40E7C2482F6A614C40E4688EACFCD04C40CB80B3942C5F4C40DAE55B1FD6CD4C40CB80B3942C5F4C40
27377	Большое Кошаево	6	56	932	57.53351	57.556516000000002	56.856299	56.842737999999997	0103000020E61000000100000005000000630B410E4AC44C40588CBAD6DE6B4C40630B410E4AC44C407B4CA4349B6D4C40B2D991EA3BC74C407B4CA4349B6D4C40B2D991EA3BC74C40588CBAD6DE6B4C40630B410E4AC44C40588CBAD6DE6B4C40
29366	Большая Тавра	6	56	932	58.003616000000001	58.028624999999998	56.149135000000001	56.123955000000002	0103000020E6100000010000000500000005DF347D76004D407D96E7C1DD0F4C4005DF347D76004D4030D80DDB16134C408B6CE7FBA9034D4030D80DDB16134C408B6CE7FBA9034D407D96E7C1DD0F4C4005DF347D76004D407D96E7C1DD0F4C40
28195	Бишково	6	56	932	58.109267000000003	58.120092	56.582403999999997	56.572870000000002	0103000020E610000001000000050000001AC40776FC0D4D40056EDDCD53494C401AC40776FC0D4D40A087DA368C4A4C407041B62C5F0F4D40A087DA368C4A4C407041B62C5F0F4D40056EDDCD53494C401AC40776FC0D4D40056EDDCD53494C40
49281	Александровское	6	56	932	57.817449000000003	57.833618999999999	56.719445999999998	56.708227000000001	0103000020E61000000100000005000000EF92382BA2E84C407592AD2EA75A4C40EF92382BA2E84C40779E78CE165C4C4080290307B4EA4C40779E78CE165C4C4080290307B4EA4C407592AD2EA75A4C40EF92382BA2E84C407592AD2EA75A4C40
50225	Русская Тавра	6	56	7066	57.950499000000001	58.006329000000001	56.135427999999997	56.112226999999997	0103000020E61000000100000005000000BBF083F3A9F94C40355D4F745D0E4C40BBF083F3A9F94C40397B67B455114C4019028063CF004D40397B67B455114C4019028063CF004D40355D4F745D0E4C40BBF083F3A9F94C40355D4F745D0E4C40
50227	Приданниково	6	56	7066	57.772309	57.801395999999997	56.666181000000002	56.646306000000003	0103000020E6100000010000000500000007B47405DBE24C40B39AAE27BA524C4007B47405DBE24C40B91B446B45554C409692E52494E64C40B91B446B45554C409692E52494E64C40B39AAE27BA524C4007B47405DBE24C40B39AAE27BA524C40
50162	Рудничный	6	56	7023	60.274017999999998	60.301488999999997	59.709780000000002	59.688637	0103000020E61000000100000005000000F641960513234E4064E8D84125D84D40F641960513234E406DAD2F12DADA4D40478D093197264E406DAD2F12DADA4D40478D093197264E4064E8D84125D84D40F641960513234E4064E8D84125D84D40
49849	Каменск-Уральский	6	56	3951	61.075018999999998	62.401910999999998	56.686262999999997	56.131089000000003	0103000020E6100000010000000500000010CAFB389A894E40C4EE3B86C7104C4010CAFB389A894E4038BA4A77D7574C408A73D4D171334F4038BA4A77D7574C408A73D4D171334F40C4EE3B86C7104C4010CAFB389A894E40C4EE3B86C7104C40
50093	Качканар	6	56	7015	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
61298	Шипицына	6	56	1800	62.574244	62.590243000000001	56.796156000000003	56.780763	0103000020E610000001000000050000004DF6CFD380494F40A376BF0AF0634C404DF6CFD380494F40D1419770E8654C40B2D826158D4B4F40D1419770E8654C40B2D826158D4B4F40A376BF0AF0634C404DF6CFD380494F40A376BF0AF0634C40
26646	Чикунова	6	56	1800	62.824137999999998	62.841231999999998	56.702069999999999	56.687099000000003	0103000020E6100000010000000500000007B29E5A7D694F40A20E2BDCF2574C4007B29E5A7D694F4059C0046EDD594C40A12C7C7DAD6B4F4059C0046EDD594C40A12C7C7DAD6B4F40A20E2BDCF2574C4007B29E5A7D694F40A20E2BDCF2574C40
26466	Фадюшина	6	56	1800	62.720830999999997	62.740954000000002	56.796235000000003	56.77449	0103000020E61000000100000005000000B378B130445C4F401E8A027D22634C40B378B130445C4F401D774A07EB654C4092EBA694D75E4F401D774A07EB654C4092EBA694D75E4F401E8A027D22634C40B378B130445C4F401E8A027D22634C40
48829	Раздольное	6	56	1800	62.827227999999998	62.848931	56.830250999999997	56.821804	0103000020E61000000100000005000000F12A6B9BE2694F406ADC9BDF30694C40F12A6B9BE2694F40533C2EAA456A4C40C1C760C5A96C4F40533C2EAA456A4C40C1C760C5A96C4F406ADC9BDF30694C40F12A6B9BE2694F406ADC9BDF30694C40
26562	Ожгиха	6	56	1800	62.891817000000003	62.922862000000002	56.759675999999999	56.748443999999999	0103000020E610000001000000050000002882380F27724F4097715303CD5F4C402882380F27724F402EC72B103D614C404F5C8E5720764F402EC72B103D614C404F5C8E5720764F4097715303CD5F4C402882380F27724F4097715303CD5F4C40
26931	Обуховское	6	56	1800	62.577612999999999	62.649748000000002	56.845666999999999	56.814216999999999	0103000020E610000001000000050000004A5F0839EF494F40726C3D4338684C404A5F0839EF494F403927F6D03E6C4C401A5245F12A534F403927F6D03E6C4C401A5245F12A534F40726C3D4338684C404A5F0839EF494F40726C3D4338684C40
48806	Никольское	6	56	1800	62.888044000000001	62.951976999999999	56.851520000000001	56.839336000000003	0103000020E610000001000000050000005BB4006DAB714F40802DAF5C6F6B4C405BB4006DAB714F40E9F17B9BFE6C4C40A8C5E061DA794F40E9F17B9BFE6C4C40A8C5E061DA794F40802DAF5C6F6B4C405BB4006DAB714F40802DAF5C6F6B4C40
49083	Куровское	6	56	1800	62.877228000000002	62.921362000000002	57.058506999999999	57.047831000000002	0103000020E610000001000000050000005891D10149704F40145E82531F864C405891D10149704F4025CB49287D874C407AE3A430EF754F4025CB49287D874C407AE3A430EF754F40145E82531F864C405891D10149704F40145E82531F864C40
26655	Куваева	6	56	1800	62.676409999999997	62.694043999999998	56.647019	56.638323	0103000020E61000000100000005000000FB57569A94564F406EA46C91B4514C40FB57569A94564F400072C284D1524C4015FE0C6FD6584F400072C284D1524C4015FE0C6FD6584F406EA46C91B4514C40FB57569A94564F406EA46C91B4514C40
26938	Кокшарова	6	56	1800	62.572358000000001	62.590522	56.857185000000001	56.843210999999997	0103000020E610000001000000050000004FCDE50643494F4050508A56EE6B4C404FCDE50643494F4096CFF23CB86D4C40C5C89239964B4F4096CFF23CB86D4C40C5C89239964B4F4050508A56EE6B4C404FCDE50643494F4050508A56EE6B4C40
27193	Квашнинское	6	56	1800	62.678386000000003	62.722439000000001	57.099412999999998	57.08081	0103000020E610000001000000050000003A083A5AD5564F404A9869FB578A4C403A083A5AD5564F400CE6AF90B98C4C406F2D93E1785C4F400CE6AF90B98C4C406F2D93E1785C4F404A9869FB578A4C403A083A5AD5564F404A9869FB578A4C40
48987	Калиновское	6	56	1800	62.455029000000003	62.496971000000002	56.832334000000003	56.811660000000003	0103000020E61000000100000005000000A5DDE8633E3A4F4056BC9179E4674C40A5DDE8633E3A4F40A8ACA6EB896A4C40BC07E8BE9C3F4F40A8ACA6EB896A4C40BC07E8BE9C3F4F4056BC9179E4674C40A5DDE8633E3A4F4056BC9179E4674C40
48950	Захаровское	6	56	1800	62.627747999999997	62.654876999999999	56.714739000000002	56.691177000000003	0103000020E610000001000000050000009010E50B5A504F40AB5FE97C78584C409010E50B5A504F407F164B917C5B4C4088F37002D3534F407F164B917C5B4C4088F37002D3534F40AB5FE97C78584C409010E50B5A504F40AB5FE97C78584C40
27029	Галкинское	6	56	1800	62.718063999999998	62.745454000000002	56.921764000000003	56.884673999999997	0103000020E61000000100000005000000AC376A85E95B4F408DCF64FF3C714C40AC376A85E95B4F40A950DD5CFC754C40115663096B5F4F40A950DD5CFC754C40115663096B5F4F408DCF64FF3C714C40AC376A85E95B4F408DCF64FF3C714C40
48890	Восход	6	56	1800	62.835016000000003	62.853917000000003	56.731447000000003	56.723773000000001	0103000020E6100000010000000500000081D1E5CDE16A4F40295DFA97A45C4C4081D1E5CDE16A4F40F0E0270EA05D4C40CD3FFA264D6D4F40F0E0270EA05D4C40CD3FFA264D6D4F40295DFA97A45C4C4081D1E5CDE16A4F40295DFA97A45C4C40
27107	Большое Пульниково	6	56	1800	62.691150999999998	62.714139000000003	57.016751999999997	57.003019999999999	0103000020E6100000010000000500000081CCCEA277584F40F19D98F562804C4081CCCEA277584F404012F6ED24824C402AE620E8685B4F404012F6ED24824C402AE620E8685B4F40F19D98F562804C4081CCCEA277584F40F19D98F562804C40
26462	Баранникова	6	56	1800	62.777569	62.799218000000003	56.808363999999997	56.802213000000002	0103000020E6100000010000000500000014B1886187634F4089B663EAAE664C4014B1886187634F40C2A1B77878674C40F12F82C64C664F40C2A1B77878674C40F12F82C64C664F4089B663EAAE664C4014B1886187634F4089B663EAAE664C40
49874	Шилова	6	56	5880	61.365138999999999	61.384399000000002	56.482557999999997	56.468026000000002	0103000020E6100000010000000500000040BFEFDFBCAE4E40BFD6A546E83B4C4040BFEFDFBCAE4E402A36E675C43D4C40BCCE86FC33B14E402A36E675C43D4C40BCCE86FC33B14E40BFD6A546E83B4C4040BFEFDFBCAE4E40BFD6A546E83B4C40
50090	Сипавское	6	56	5880	61.902206	61.940581999999999	56.259808	56.246335999999999	0103000020E61000000100000005000000A320787C7BF34E40EAE923F0871F4C40A320787C7BF34E409D9E776341214C40679AB0FD64F84E409D9E776341214C40679AB0FD64F84E40EAE923F0871F4C40A320787C7BF34E40EAE923F0871F4C40
22861	Якшина	6	56	1492	62.445515999999998	62.483927999999999	57.411172999999998	57.403595000000003	0103000020E6100000010000000500000020EC14AB06394F4021EA3E00A9B34C4020EC14AB06394F40C5FF1D51A1B44C4031CF4A5AF13D4F40C5FF1D51A1B44C4031CF4A5AF13D4F4021EA3E00A9B34C4020EC14AB06394F4021EA3E00A9B34C40
22996	Шмаковское	6	56	1492	62.403097000000002	62.432436000000003	57.402999000000001	57.391781000000002	0103000020E61000000100000005000000D00EB8AE98334F40DB183BE125B24C40D00EB8AE98334F400DA9A27895B34C4079CE16105A374F400DA9A27895B34C4079CE16105A374F40DB183BE125B24C40D00EB8AE98334F40DB183BE125B24C40
19213	Чёрновское	6	56	1492	63.360692	63.387551999999999	57.623904000000003	57.605117	0103000020E61000000100000005000000E4F6CB272BAE4F4077A04E7974CD4C40E4F6CB272BAE4F40FBEB1516DCCF4C40ECBFCE4D9BB14F40FBEB1516DCCF4C40ECBFCE4D9BB14F4077A04E7974CD4C40E4F6CB272BAE4F4077A04E7974CD4C40
19315	Чубаровское	6	56	1492	63.489789000000002	63.514043999999998	57.647396000000001	57.643022000000002	0103000020E610000001000000050000006478EC67B1BE4F40E44D7E8B4ED24C406478EC67B1BE4F40D6C743DFDDD24C403E5A9C31CCC14F40D6C743DFDDD24C403E5A9C31CCC14F40E44D7E8B4ED24C406478EC67B1BE4F40E44D7E8B4ED24C40
22297	Чернорицкое	6	56	1492	62.733893000000002	62.767301000000003	57.416791000000003	57.403483999999999	0103000020E61000000100000005000000B5E1B034F05D4F40C93A1C5DA5B34C40B5E1B034F05D4F403222516859B54C4014984EEB36624F403222516859B54C4014984EEB36624F40C93A1C5DA5B34C40B5E1B034F05D4F40C93A1C5DA5B34C40
20754	Чащина	6	56	1492	62.787467999999997	62.814534999999999	57.706738000000001	57.698852000000002	0103000020E61000000100000005000000C1525DC0CB644F40425F7AFB73D94C40C1525DC0CB644F40946B0A6476DA4C404339D1AE42684F40946B0A6476DA4C404339D1AE42684F40425F7AFB73D94C40C1525DC0CB644F40425F7AFB73D94C40
19887	Харловское (Харлово)	6	56	1492	63.083857999999999	63.117643999999999	57.43835	57.426993000000003	0103000020E6100000010000000500000005C1E3DBBB8A4F407B4FE5B4A7B64C4005C1E3DBBB8A4F40CE1951DA1BB84C400A4966F50E8F4F40CE1951DA1BB84C400A4966F50E8F4F407B4FE5B4A7B64C4005C1E3DBBB8A4F407B4FE5B4A7B64C40
20537	Фомина	6	56	1492	62.972000000000001	62.998365999999997	57.694802000000003	57.685724	0103000020E6100000010000000500000023DBF97E6A7C4F40890AD5CDC5D74C4023DBF97E6A7C4F4003999D45EFD84C401BB80375CA7F4F4003999D45EFD84C401BB80375CA7F4F40890AD5CDC5D74C4023DBF97E6A7C4F40890AD5CDC5D74C40
22810	Стриганское	6	56	1492	62.520462000000002	62.545408000000002	57.278066000000003	57.250560999999998	0103000020E61000000100000005000000C767B27F9E424F409753026212A04C40C767B27F9E424F409510ACAA97A34C40077DE9EDCF454F409510ACAA97A34C40077DE9EDCF454F409753026212A04C40C767B27F9E424F409753026212A04C40
17588	Спутник	6	56	1492	63.138565999999997	63.145887000000002	57.641361000000003	57.638109	0103000020E61000000100000005000000342BDB87BC914F404224438EADD14C40342BDB87BC914F4006F7031E18D24C40AEF4DA6CAC924F4006F7031E18D24C40AEF4DA6CAC924F404224438EADD14C40342BDB87BC914F404224438EADD14C40
20183	Симанова (Татарщина)	6	56	1492	62.765253000000001	62.785995	57.631146999999999	57.617932000000003	0103000020E610000001000000050000003C1570CFF3614F407193516518CF4C403C1570CFF3614F40F8FBC56CC9D04C40E6E8F17B9B644F40F8FBC56CC9D04C40E6E8F17B9B644F407193516518CF4C403C1570CFF3614F407193516518CF4C40
19001	Рябиновый	6	56	1492	63.072746000000002	63.086508000000002	57.646721999999997	57.641703	0103000020E610000001000000050000001975ADBD4F894F405F5FEB5223D24C401975ADBD4F894F4046CD57C9C7D24C40D36BB3B1128B4F4046CD57C9C7D24C40D36BB3B1128B4F405F5FEB5223D24C401975ADBD4F894F405F5FEB5223D24C40
18071	Рудное	6	56	1492	62.601821999999999	62.624423999999998	57.931323999999996	57.925499000000002	0103000020E61000000100000005000000B401D880084D4F4088BD50C076F64C40B401D880084D4F406DFDF49F35F74C40336B2920ED4F4F406DFDF49F35F74C40336B2920ED4F4F4088BD50C076F64C40B401D880084D4F4088BD50C076F64C40
20847	Речкалова	6	56	1492	62.813186999999999	62.845455000000001	57.594912000000001	57.579078000000003	0103000020E610000001000000050000002444F98216684F40A3EA573A1FCA4C402444F98216684F40BDFF8F1326CC4C40AE9E93DE376C4F40BDFF8F1326CC4C40AE9E93DE376C4F40A3EA573A1FCA4C402444F98216684F40A3EA573A1FCA4C40
21717	Ретнева	6	56	1492	62.638643999999999	62.681773	57.560127999999999	57.544922	0103000020E61000000100000005000000B0E42A16BF514F407A6F0C01C0C54C40B0E42A16BF514F4075C93846B2C74C40DD25715644574F4075C93846B2C74C40DD25715644574F407A6F0C01C0C54C40B0E42A16BF514F407A6F0C01C0C54C40
22011	Пьянково	6	56	1492	62.944772	62.972360000000002	57.426470000000002	57.404958000000001	0103000020E610000001000000050000009816F549EE784F407520EBA9D5B34C409816F549EE784F40D15CA79196B64C4023F8DF4A767C4F40D15CA79196B64C4023F8DF4A767C4F407520EBA9D5B34C409816F549EE784F407520EBA9D5B34C40
20047	Прядеина	6	56	1492	63.062254000000003	63.080570999999999	57.397475	57.384329999999999	0103000020E61000000100000005000000C90567F0F7874F40936FB6B931B14C40C90567F0F7874F4022FDF675E0B24C40C5008926508A4F4022FDF675E0B24C40C5008926508A4F40936FB6B931B14C40C90567F0F7874F40936FB6B931B14C40
20233	Пионерский	6	56	1492	63.003109000000002	63.025512999999997	57.685796000000003	57.67559	0103000020E6100000010000000500000061A92EE065804F4098C0ADBB79D64C4061A92EE065804F4023DDCF29C8D74C40B94F8E0244834F4023DDCF29C8D74C40B94F8E0244834F4098C0ADBB79D64C4061A92EE065804F4098C0ADBB79D64C40
22616	Першина	6	56	1492	62.634475999999999	62.645066999999997	57.268655000000003	57.255536999999997	0103000020E61000000100000005000000670C738236514F407FF5B86FB5A04C40670C738236514F4015747B4963A24C404A5D328E91524F4015747B4963A24C404A5D328E91524F407FF5B86FB5A04C40670C738236514F407FF5B86FB5A04C40
21776	Осинцевское	6	56	1492	62.476292000000001	62.511012000000001	57.558360999999998	57.544075999999997	0103000020E6100000010000000500000058ACE122F73C4F40ED444948A4C54C4058ACE122F73C4F40512E8D5F78C74C4089EE59D768414F40512E8D5F78C74C4089EE59D768414F40ED444948A4C54C4058ACE122F73C4F40ED444948A4C54C40
47006	Ольховка	6	56	1492	63.231793000000003	63.242761000000002	57.513565999999997	57.505443	0103000020E610000001000000050000008B389D64AB9D4F40FE7E315BB2C04C408B389D64AB9D4F40342BDB87BCC14C4044DFDDCA129F4F40342BDB87BCC14C4044DFDDCA129F4F40FE7E315BB2C04C408B389D64AB9D4F40FE7E315BB2C04C40
20161	Новгородова	6	56	1492	63.097441000000003	63.112003000000001	57.570632000000003	57.554431000000001	0103000020E6100000010000000500000010255AF2788C4F40BD715298F7C64C4010255AF2788C4F408A0629780AC94C40E606431D568E4F408A0629780AC94C40E606431D568E4F40BD715298F7C64C4010255AF2788C4F40BD715298F7C64C40
18168	Ницинское	6	56	1492	62.750970000000002	62.775089999999999	57.884607000000003	57.876792999999999	0103000020E610000001000000050000007923F3C81F604F404D2EC6C03AF04C407923F3C81F604F4006685BCD3AF14C4073BA2C2636634F4006685BCD3AF14C4073BA2C2636634F404D2EC6C03AF04C407923F3C81F604F404D2EC6C03AF04C40
19507	Никитина	6	56	1492	63.276223999999999	63.295223	57.569662000000001	57.561301	0103000020E61000000100000005000000662FDB4E5BA34F40261B0FB6D8C74C40662FDB4E5BA34F4011E335AFEAC84C40750305DEC9A54F4011E335AFEAC84C40750305DEC9A54F40261B0FB6D8C74C40662FDB4E5BA34F40261B0FB6D8C74C40
17273	Нижняя	6	56	1492	63.306713000000002	63.326951999999999	57.646172999999997	57.641812999999999	0103000020E610000001000000050000000821205F42A74F40E692AAED26D24C400821205F42A74F407347FFCBB5D24C404FAE2990D9A94F407347FFCBB5D24C404FAE2990D9A94F40E692AAED26D24C400821205F42A74F40E692AAED26D24C40
20421	Мельникова	6	56	1492	63.021075000000003	63.046156000000003	57.697716999999997	57.683996999999998	0103000020E61000000100000005000000B1E1E995B2824F40F3C7B4368DD74C40B1E1E995B2824F407E6E68CA4ED94C40D1419770E8854F407E6E68CA4ED94C40D1419770E8854F40F3C7B4368DD74C40B1E1E995B2824F40F3C7B4368DD74C40
23089	Лопатково	6	56	1492	63.356074999999997	63.381838999999999	57.856772999999997	57.837474999999998	0103000020E610000001000000050000002BF697DD93AD4F40DA1B7C6132EB4C402BF697DD93AD4F40438CD7BCAAED4C402EABB019E0B04F40438CD7BCAAED4C402EABB019E0B04F40DA1B7C6132EB4C402BF697DD93AD4F40DA1B7C6132EB4C40
22553	Лаптева	6	56	1492	62.791080000000001	62.804797000000001	57.301428000000001	57.287970999999999	0103000020E610000001000000050000008542041C42654F402499D53BDCA44C408542041C42654F40A20C553195A64C409F758D9603674F40A20C553195A64C409F758D9603674F402499D53BDCA44C408542041C42654F402499D53BDCA44C40
18359	Курьинский	6	56	1492	62.896039000000002	62.913727000000002	57.830671000000002	57.823990000000002	0103000020E610000001000000050000006478EC67B1724F40931D1B8178E94C406478EC67B1724F40295E656D53EA4C40713C9F01F5744F40295E656D53EA4C40713C9F01F5744F40931D1B8178E94C406478EC67B1724F40931D1B8178E94C40
22454	Крутихинское	6	56	1492	62.738295000000001	62.762729	57.358007000000001	57.344847999999999	0103000020E6100000010000000500000071E65773805E4F40A60BB1FA23AC4C4071E65773805E4F409A5E622CD3AD4C40FB5A971AA1614F409A5E622CD3AD4C40FB5A971AA1614F40A60BB1FA23AC4C4071E65773805E4F40A60BB1FA23AC4C40
18272	Ключи	6	56	1492	62.868136999999997	62.898249	57.832061000000003	57.816321000000002	0103000020E6100000010000000500000049B9FB1C1F6F4F40DE04DF347DE84C4049B9FB1C1F6F4F4077A38FF980EA4C401555BFD2F9724F4077A38FF980EA4C401555BFD2F9724F40DE04DF347DE84C4049B9FB1C1F6F4F40DE04DF347DE84C40
20593	Кириллова	6	56	1492	62.862253000000003	62.878540000000001	57.642690000000002	57.630130000000001	0103000020E610000001000000050000005FF0694E5E6E4F403F1D8F19A8D04C405FF0694E5E6E4F40AEBB79AA43D24C402A1DACFF73704F40AEBB79AA43D24C402A1DACFF73704F403F1D8F19A8D04C405FF0694E5E6E4F403F1D8F19A8D04C40
19112	Кирга	6	56	1492	63.237972999999997	63.253262999999997	57.649442999999998	57.638643999999999	0103000020E610000001000000050000005E2A36E6759E4F40B0E42A16BFD14C405E2A36E6759E4F40DDCEBEF220D34C40B72407EC6AA04F40DDCEBEF220D34C40B72407EC6AA04F40B0E42A16BFD14C405E2A36E6759E4F40B0E42A16BFD14C40
22070	Килачёвское	6	56	1492	62.628979000000001	62.673929999999999	57.414746000000001	57.388928999999997	0103000020E61000000100000005000000766F456282504F40A5BBEB6CC8B14C40766F456282504F40CB129D6516B54C408AE5965643564F40CB129D6516B54C408AE5965643564F40A5BBEB6CC8B14C40766F456282504F40A5BBEB6CC8B14C40
50139	Ирбит	6	56	1492	62.141894000000001	63.632496000000003	58.037197999999997	57.134838000000002	0103000020E61000000100000005000000D3BF249529124F400821205F42914C40D3BF249529124F4001BD70E7C2044D40E86C01A1F5D04F4001BD70E7C2044D40E86C01A1F5D04F400821205F42914C40D3BF249529124F400821205F42914C40
19570	Знаменское	6	56	1492	63.213934999999999	63.251071000000003	57.548403999999998	57.538231000000003	0103000020E61000000100000005000000213CDA38629B4F40C158DFC0E4C44C40213CDA38629B4F406F7F2E1A32C64C40ADFC321823A04F406F7F2E1A32C64C40ADFC321823A04F40C158DFC0E4C44C40213CDA38629B4F40C158DFC0E4C44C40
21064	Зайково	6	56	1492	62.701481999999999	62.772483999999999	57.572307000000002	57.502223000000001	0103000020E61000000100000005000000C85D8429CA594F404626E0D748C04C40C85D8429CA594F40CD22145B41C94C40755776C1E0624F40CD22145B41C94C40755776C1E0624F404626E0D748C04C40C85D8429CA594F404626E0D748C04C40
18690	Дубская	6	56	1492	63.177174999999998	63.200783000000001	57.685766999999998	57.668356000000003	0103000020E610000001000000050000009B559FABAD964F40EE0A7DB08CD54C409B559FABAD964F4088D68A36C7D74C40E04BE141B3994F4088D68A36C7D74C40E04BE141B3994F40EE0A7DB08CD54C409B559FABAD964F40EE0A7DB08CD54C40
18793	Гуни	6	56	1492	63.343310000000002	63.353631999999998	57.702424999999998	57.691862999999998	0103000020E61000000100000005000000E4310395F1AB4F40FE277FF78ED84C40E4310395F1AB4F404772F90FE9D94C40D76839D043AD4F404772F90FE9D94C40D76839D043AD4F40FE277FF78ED84C40E4310395F1AB4F40FE277FF78ED84C40
22344	Горки	6	56	1492	62.567461999999999	62.591734000000002	57.324541000000004	57.294137999999997	0103000020E6100000010000000500000083DC4598A2484F4063416150A6A54C4083DC4598A2484F40079B3A8F8AA94C4034F790F0BD4B4F40079B3A8F8AA94C4034F790F0BD4B4F4063416150A6A54C4083DC4598A2484F4063416150A6A54C40
18907	Гаёва	6	56	1492	63.133975	63.147747000000003	57.652991999999998	57.647255999999999	0103000020E61000000100000005000000A5BDC11726914F40E411DC48D9D24C40A5BDC11726914F405A46EA3D95D34C40838AAA5FE9924F405A46EA3D95D34C40838AAA5FE9924F40E411DC48D9D24C40A5BDC11726914F40E411DC48D9D24C40
18476	Волково	6	56	1492	63.064310999999996	63.087003000000003	57.787767000000002	57.780746999999998	0103000020E61000000100000005000000F3E2C4573B884F409DB98784EFE34C40F3E2C4573B884F401CEF8E8CD5E44C40B3D30FEA228B4F401CEF8E8CD5E44C40B3D30FEA228B4F409DB98784EFE34C40F3E2C4573B884F409DB98784EFE34C40
19722	Большой Камыш (Галищева)	6	56	1492	63.155462999999997	63.169459000000003	57.505806	57.488607999999999	0103000020E61000000100000005000000785E2A36E6934F403048FAB48ABE4C40785E2A36E6934F406F0F4240BEC04C40A6811FD5B0954F406F0F4240BEC04C40A6811FD5B0954F403048FAB48ABE4C40785E2A36E6934F403048FAB48ABE4C40
21920	Большая Кочёвка	6	56	1492	62.902417	62.921047999999999	57.491520000000001	57.477246999999998	0103000020E610000001000000050000005E2D776682734F409B8E006E16BD4C405E2D776682734F403BAA9A20EABE4C40EA059FE6E4754F403BAA9A20EABE4C40EA059FE6E4754F409B8E006E16BD4C405E2D776682734F409B8E006E16BD4C40
61336	Болшая Зверева	6	56	1492	63.181919000000001	63.195869000000002	57.525039999999997	57.514150999999998	0103000020E61000000100000005000000B1C22D1F49974F40541A31B3CFC14C40B1C22D1F49974F40C18BBE8234C34C406EA6423C12994F40C18BBE8234C34C406EA6423C12994F40541A31B3CFC14C40B1C22D1F49974F40541A31B3CFC14C40
18595	Бердюгина	6	56	1492	63.050350999999999	63.070303000000003	57.752505999999997	57.741872000000001	0103000020E610000001000000050000001329CDE671864F40B8E864A9F5DE4C401329CDE671864F409A05DA1D52E04C40C5E74EB0FF884F409A05DA1D52E04C40C5E74EB0FF884F40B8E864A9F5DE4C401329CDE671864F40B8E864A9F5DE4C40
22203	Белослудское	6	56	1492	62.673661000000003	62.693415000000002	57.455741000000003	57.451251999999997	0103000020E610000001000000050000009BCB0D863A564F40962023A0C2B94C409BCB0D863A564F40223999B855BA4C4026C79DD2C1584F40223999B855BA4C4026C79DD2C1584F40962023A0C2B94C409BCB0D863A564F40962023A0C2B94C40
22736	Анохинское	6	56	1492	62.684511999999998	62.704014999999998	57.206029999999998	57.196049000000002	0103000020E610000001000000050000001ADCD6169E574F40EEB4352218994C401ADCD6169E574F4058FFE7305F9A4C405C72DC291D5A4F4058FFE7305F9A4C405C72DC291D5A4F40EEB4352218994C401ADCD6169E574F40EEB4352218994C40
50180	Удинцева	6	56	7039	62.669843	62.689058000000003	57.925733000000001	57.920555999999998	0103000020E610000001000000050000002E3A596ABD554F407B116DC7D4F54C402E3A596ABD554F40FBE93F6B7EF64C400A86730D33584F40FBE93F6B7EF64C400A86730D33584F407B116DC7D4F54C402E3A596ABD554F407B116DC7D4F54C40
50234	Скородумское	6	56	7069	62.693522000000002	62.734513	57.577606000000003	57.557187999999996	0103000020E610000001000000050000003C873254C5584F40A0DCB6EF51C74C403C873254C5584F4098FC4FFEEEC94C4051BEA085045E4F4098FC4FFEEEC94C4051BEA085045E4F40A0DCB6EF51C74C403C873254C5584F40A0DCB6EF51C74C40
50086	Палкино	6	56	7014	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
17077	Нихвор	6	56	1483	62.686300000000003	62.704256999999998	59.244863000000002	59.233972999999999	0103000020E61000000100000005000000569FABADD8574F40D192C7D3F29D4D40569FABADD8574F400F80B8AB579F4D40527DE717255A4F400F80B8AB579F4D40527DE717255A4F40D192C7D3F29D4D40569FABADD8574F40D192C7D3F29D4D40
17576	Зыкова	6	56	1483	62.560895000000002	62.579517000000003	59.608787	59.602131	0103000020E61000000100000005000000B6BE4868CB474F403274ECA012CD4D40B6BE4868CB474F406F9D7FBBECCD4D40EF3CF19C2D4A4F406F9D7FBBECCD4D40EF3CF19C2D4A4F403274ECA012CD4D40B6BE4868CB474F403274ECA012CD4D40
61112	Гари	6	56	1483	62.324441	62.366849999999999	59.452590000000001	59.405338	0103000020E61000000100000005000000A33D5E4887294F40BCE9961DE2B34D40A33D5E4887294F40923F1878EEB94D40D044D8F0F42E4F40923F1878EEB94D40D044D8F0F42E4F40BCE9961DE2B34D40A33D5E4887294F40BCE9961DE2B34D40
17169	Андрюшино	6	56	1483	62.976483000000002	63.007744000000002	59.220509999999997	59.204498999999998	0103000020E61000000100000005000000CC0C1B65FD7C4F404888F2052D9A4D40CC0C1B65FD7C4F407138F3AB399C4D40C05E61C1FD804F407138F3AB399C4D40C05E61C1FD804F404888F2052D9A4D40CC0C1B65FD7C4F404888F2052D9A4D40
61326	Усть-Салда	6	56	1364	61.347693	61.361536999999998	58.796104999999997	58.785189000000003	0103000020E610000001000000050000002906483481AC4E40E816BA1281644D402906483481AC4E404E97C5C4E6654D40A0A52BD846AE4E404E97C5C4E6654D40A0A52BD846AE4E40E816BA1281644D402906483481AC4E40E816BA1281644D40
46967	Таёжный	6	56	1364	61.810532000000002	61.833888999999999	58.710307999999998	58.690756	0103000020E61000000100000005000000452E3883BFE74E4005C24EB16A584D40452E3883BFE74E40280B5F5FEB5A4D4040BFEFDFBCEA4E40280B5F5FEB5A4D4040BFEFDFBCEA4E4005C24EB16A584D40452E3883BFE74E4005C24EB16A584D40
50133	Прокопьевская Салда	6	56	1364	61.077390000000001	61.109504999999999	58.709485000000001	58.694842999999999	0103000020E61000000100000005000000CB845FEAE7894E40616D8C9DF0584D40CB845FEAE7894E4054008C67D05A4D40CEDF8442048E4E4054008C67D05A4D40CEDF8442048E4E40616D8C9DF0584D40CB845FEAE7894E40616D8C9DF0584D40
14737	Привокзальный	6	56	1364	60.671298	60.758695000000003	58.896239999999999	58.853965000000002	0103000020E6100000010000000500000063EFC517ED554E40DE76A1B94E6D4D4063EFC517ED554E40FBAE08FEB7724D40C251F2EA1C614E40FBAE08FEB7724D40C251F2EA1C614E40DE76A1B94E6D4D4063EFC517ED554E40DE76A1B94E6D4D40
15968	Меркушино	6	56	1364	61.589573999999999	61.604045999999997	58.762459	58.756489000000002	0103000020E6100000010000000500000034492C2977CB4E405264ADA1D4604D4034492C2977CB4E403BC5AA4198614D40CAA31B6151CD4E403BC5AA4198614D40CAA31B6151CD4E405264ADA1D4604D4034492C2977CB4E405264ADA1D4604D40
15818	Красногорское	6	56	1364	61.154240999999999	61.170456000000001	58.805546	58.795144999999998	0103000020E61000000100000005000000E659492BBE934E40F949B54FC7654D40E659492BBE934E4039B69E211C674D4018B49080D1954E4039B69E211C674D4018B49080D1954E40F949B54FC7654D40E659492BBE934E40F949B54FC7654D40
16484	Косолманка	6	56	1364	60.522303000000001	60.547690000000003	58.751924000000002	58.741912999999997	0103000020E6100000010000000500000025CD1FD3DA424E4016BD5301F75E4D4025CD1FD3DA424E40EC89AE0B3F604D40522CB7B41A464E40EC89AE0B3F604D40522CB7B41A464E4016BD5301F75E4D4025CD1FD3DA424E4016BD5301F75E4D40
16064	Кордюково	6	56	1364	61.753003999999997	61.778686999999998	58.752082999999999	58.739283999999998	0103000020E61000000100000005000000EBE0606F62E04E40603AADDBA05E4D40EBE0606F62E04E405470784144604D400169FF03ACE34E405470784144604D400169FF03ACE34E40603AADDBA05E4D40EBE0606F62E04E40603AADDBA05E4D40
16255	Карпунинский	6	56	1364	61.784733000000003	61.814746	58.73715	58.702955000000003	0103000020E61000000100000005000000C68B852172E44E40A4C7EF6DFA594D40C68B852172E44E408A1F63EE5A5E4D40FE45D09849E84E408A1F63EE5A5E4D40FE45D09849E84E40A4C7EF6DFA594D40C68B852172E44E40A4C7EF6DFA594D40
16564	Карелино	6	56	1364	60.384089000000003	60.408828	58.714728999999998	58.700276000000002	0103000020E610000001000000050000006EE00ED429314E403C16DBA4A2594D406EE00ED429314E405B40683D7C5B4D4034D8D47954344E405B40683D7C5B4D4034D8D47954344E403C16DBA4A2594D406EE00ED429314E403C16DBA4A2594D40
16166	Дерябино	6	56	1364	61.910559999999997	61.926191000000003	58.747866999999999	58.733792000000001	0103000020E61000000100000005000000DB85E63A8DF44E40810871E5EC5D4D40DB85E63A8DF44E40FA60191BBA5F4D40BE6C3B6D8DF64E40FA60191BBA5F4D40BE6C3B6D8DF64E40810871E5EC5D4D40DB85E63A8DF44E40810871E5EC5D4D40
14923	Верхотурье	6	56	1364	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
50200	Половинный	6	56	7024	60.585177000000002	60.591312000000002	57.065486	57.060152000000002	0103000020E610000001000000050000008AAF7614E74A4E40FE648C0FB3874C408AAF7614E74A4E40452C62D861884C40BEDD921CB04B4E40452C62D861884C40BEDD921CB04B4E40FE648C0FB3874C408AAF7614E74A4E40FE648C0FB3874C40
50125	Кедровое	6	56	7024	60.558073999999998	60.600340000000003	57.164495000000002	57.153097000000002	0103000020E61000000100000005000000BB5F05F86E474E40D00EB8AE98934C40BB5F05F86E474E4082AD122C0E954C40863DEDF0D74C4E4082AD122C0E954C40863DEDF0D74C4E40D00EB8AE98934C40BB5F05F86E474E40D00EB8AE98934C40
14633	Северная	6	56	743	60.429112000000003	60.459718000000002	58.013463000000002	58.004317999999998	0103000020E610000001000000050000001C295B24ED364E405E64027E8D004D401C295B24ED364E40605AD427B9014D40F7B0170AD83A4E40605AD427B9014D40F7B0170AD83A4E405E64027E8D004D401C295B24ED364E405E64027E8D004D40
16561	Свободный	6	56	743	60.378788999999998	60.399754999999999	58.043447999999998	58.030397999999998	0103000020E61000000100000005000000D28A6F287C304E4091EEE714E4034D40D28A6F287C304E40CE893DB48F054D40CCB4FD2B2B334E40CE893DB48F054D40CCB4FD2B2B334E4091EEE714E4034D40D28A6F287C304E4091EEE714E4034D40
14452	Песчаный Карьер	6	56	743	60.761533999999997	60.769779999999997	58.239525999999998	58.236541000000003	0103000020E61000000100000005000000626534F279614E40E294B9F9461E4D40626534F279614E405645B8C9A81E4D40B48EAA2688624E405645B8C9A81E4D40B48EAA2688624E40E294B9F9461E4D40626534F279614E40E294B9F9461E4D40
14529	Никитино	6	56	743	60.452638999999998	60.471961999999998	57.951393000000003	57.932433000000003	0103000020E6100000010000000500000073F22213F0394E40085BECF659F74C4073F22213F0394E405952EE3EC7F94C40357A3540693C4E405952EE3EC7F94C40357A3540693C4E40085BECF659F74C4073F22213F0394E40085BECF659F74C40
14818	Нелоба	6	56	743	60.717247	60.729759999999999	58.01426	57.999091	0103000020E61000000100000005000000BA13ECBFCE5B4E402D5DC136E2FF4C40BA13ECBFCE5B4E400BD28C45D3014D40E8F692C6685D4E400BD28C45D3014D40E8F692C6685D4E402D5DC136E2FF4C40BA13ECBFCE5B4E402D5DC136E2FF4C40
14913	Малыгино	6	56	743	60.956271000000001	60.965477999999997	58.239643999999998	58.235636	0103000020E610000001000000050000007E8E8F16677A4E4050E10852291E4D407E8E8F16677A4E40605793A7AC1E4D40F58079C8947B4E40605793A7AC1E4D40F58079C8947B4E4050E10852291E4D407E8E8F16677A4E4050E10852291E4D40
5217	Выя	6	56	743	60.566473999999999	60.568143999999997	58.327407000000001	58.325980000000001	0103000020E610000001000000050000006404543882484E4036936FB6B9294D406404543882484E40A1BDFA78E8294D4095B54DF1B8484E40A1BDFA78E8294D4095B54DF1B8484E4036936FB6B9294D406404543882484E4036936FB6B9294D40
12163	Верхняя Салда	6	56	743	60.511738999999999	60.597915	58.074283999999999	58.018836	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
14248	Басьяновский	6	56	743	60.726624999999999	60.754365	58.319764999999997	58.295070000000003	0103000020E610000001000000050000005EBA490C025D4E40EF0390DAC4254D405EBA490C025D4E40E5B33C0FEE284D409F1F46088F604E40E5B33C0FEE284D409F1F46088F604E40EF0390DAC4254D405EBA490C025D4E40EF0390DAC4254D40
50239	Ежевичный	6	56	7068	60.761076000000003	60.767256000000003	58.273083	58.26614	0103000020E61000000100000005000000A0E238F06A614E40271422E010224D40A0E238F06A614E40FA0B3D62F4224D4074D4D17135624E40FA0B3D62F4224D4074D4D17135624E40271422E010224D40A0E238F06A614E40271422E010224D40
12003	Чернокоровское	6	56	1197	62.220416	62.244121999999997	56.752516	56.744807000000002	0103000020E61000000100000005000000F0C16B97361C4F407B6AF5D5555F4C40F0C16B97361C4F40BEDBBC7152604C40F71DC3633F1F4F40BEDBBC7152604C40F71DC3633F1F4F407B6AF5D5555F4C40F0C16B97361C4F407B6AF5D5555F4C40
11608	Тыгиш	6	56	1197	61.901172000000003	61.93927	56.784565000000001	56.770490000000002	0103000020E610000001000000050000001409A69A59F34E4091F2936A9F624C401409A69A59F34E400A4B3CA06C644C40950ED6FF39F84E400A4B3CA06C644C40950ED6FF39F84E4091F2936A9F624C401409A69A59F34E4091F2936A9F624C40
11660	Кунарское	6	56	1197	61.862985000000002	61.902025999999999	56.793858999999998	56.780540999999999	0103000020E6100000010000000500000023F8DF4A76EE4E40F4177AC4E8634C4023F8DF4A76EE4E405051F52B9D654C402312859675F34E405051F52B9D654C402312859675F34E40F4177AC4E8634C4023F8DF4A76EE4E40F4177AC4E8634C40
11561	Коменки	6	56	1197	62.072642999999999	62.082264000000002	56.799438000000002	56.792724999999997	0103000020E6100000010000000500000044A4A65D4C094F405DDC460378654C4044A4A65D4C094F40FF9600FC53664C40AFD172A0870A4F40FF9600FC53664C40AFD172A0870A4F405DDC460378654C4044A4A65D4C094F405DDC460378654C40
22607	Каменноозёрское	6	56	1197	61.822372000000001	61.851135999999997	56.674115	56.655307999999998	0103000020E61000000100000005000000B492567C43E94E405167EE21E1534C40B492567C43E94E401C5F7B6649564C4060394206F2EC4E401C5F7B6649564C4060394206F2EC4E405167EE21E1534C40B492567C43E94E405167EE21E1534C40
47628	Ильинское	6	56	1197	62.43779	62.523220000000002	56.688453000000003	56.647627999999997	0103000020E610000001000000050000000742B28009384F40A8FC6B79E5524C400742B28009384F40A3EA573A1F584C407B4E7ADFF8424F40A3EA573A1F584C407B4E7ADFF8424F40A8FC6B79E5524C400742B28009384F40A8FC6B79E5524C40
11668	Грязновское	6	56	1197	61.694730999999997	61.732595000000003	56.789150999999997	56.773887999999999	0103000020E61000000100000005000000394206F2ECD84E40286211C30E634C40394206F2ECD84E40874D64E602654C40481B47ACC5DD4E40874D64E602654C40481B47ACC5DD4E40286211C30E634C40394206F2ECD84E40286211C30E634C40
11996	Гарашкинское	6	56	1197	62.380521999999999	62.417020999999998	56.605483999999997	56.576290999999998	0103000020E610000001000000050000004AB4E4F1B4304F4054FD4AE7C3494C404AB4E4F1B4304F402920ED7F804D4C40635FB2F160354F402920ED7F804D4C40635FB2F160354F4054FD4AE7C3494C404AB4E4F1B4304F4054FD4AE7C3494C40
47556	Волковское	6	56	1197	62.329058000000003	62.380540000000003	56.744973999999999	56.733516000000002	0103000020E610000001000000050000005C3E92921E2A4F40DF8B2FDAE35D4C405C3E92921E2A4F40662FDB4E5B5F4C40F168E388B5304F40662FDB4E5B5F4C40F168E388B5304F40DF8B2FDAE35D4C405C3E92921E2A4F40DF8B2FDAE35D4C40
46685	Байны	6	56	1197	62.107354000000001	62.152225000000001	56.710619000000001	56.686911000000002	0103000020E61000000100000005000000228C9FC6BD0D4F409F211CB3EC574C40228C9FC6BD0D4F4047753A90F55A4C401A51DA1B7C134F4047753A90F55A4C401A51DA1B7C134F409F211CB3EC574C40228C9FC6BD0D4F409F211CB3EC574C40
50173	Полдневой	6	56	7038	62.083691999999999	62.098227000000001	56.654693999999999	56.644573999999999	0103000020E61000000100000005000000EA77616BB60A4F400BED9C6681524C40EA77616BB60A4F4097715303CD534C40C74ACCB3920C4F4097715303CD534C40C74ACCB3920C4F400BED9C6681524C40EA77616BB60A4F400BED9C6681524C40
50118	пос.Кедровка	6	56	7021	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
61305	п.Прохладный	6	56	920	60.858471000000002	61.741982	56.946765999999997	56.455024999999999	0103000020E610000001000000050000003FC8B260E26D4E4063EE5A423E3A4C403FC8B260E26D4E407C7BD7A02F794C403F1C2444F9DE4E407C7BD7A02F794C403F1C2444F9DE4E4063EE5A423E3A4C403FC8B260E26D4E4063EE5A423E3A4C40
46982	Черноусово	6	56	920	61.233454999999999	61.274678000000002	56.584173999999997	56.559260999999999	0103000020E61000000100000005000000390B7BDAE19D4E40D1764CDD95474C40390B7BDAE19D4E403596B036C64A4C40217711A628A34E403596B036C64A4C40217711A628A34E40D1764CDD95474C40390B7BDAE19D4E40D1764CDD95474C40
8500	Чернобровкина	6	56	920	61.250118000000001	61.262650000000001	56.675103999999997	56.654842000000002	0103000020E610000001000000050000000A12DBDD03A04E400C06D7DCD1534C400A12DBDD03A04E400BB3D0CE69564C40AF25E4839EA14E400BB3D0CE69564C40AF25E4839EA14E400C06D7DCD1534C400A12DBDD03A04E400C06D7DCD1534C40
10603	Хромцово	6	56	920	61.452688999999999	61.475506000000003	56.599291000000001	56.584263	0103000020E61000000100000005000000252191B6F1B94E40A5A14621C94A4C40252191B6F1B94E40C1E44691B54C4C40A1866F61DDBC4E40C1E44691B54C4C40A1866F61DDBC4E40A5A14621C94A4C40252191B6F1B94E40A5A14621C94A4C40
47012	Студенческий	6	56	920	61.259425	61.280365000000003	56.701008000000002	56.689065999999997	0103000020E61000000100000005000000E561A1D634A14E408C648F5033584C40E561A1D634A14E40001E51A1BA594C40B6F81400E3A34E40001E51A1BA594C40B6F81400E3A34E408C648F5033584C40E561A1D634A14E408C648F5033584C40
46991	Совхозный	6	56	920	61.418354999999998	61.452311000000002	56.562930999999999	56.548867000000001	0103000020E610000001000000050000001D8F19A88CB54E40446D1B4641464C401D8F19A88CB54E40C9737D1F0E484C407F4FAC53E5B94E40C9737D1F0E484C407F4FAC53E5B94E40446D1B4641464C401D8F19A88CB54E40446D1B4641464C40
7323	Светлый	6	56	920	60.948535999999997	60.957087999999999	56.712589999999999	56.705233	0103000020E61000000100000005000000118AADA069794E40AD872F13455A4C40118AADA069794E4073BA2C26365B4C4070B20DDC817A4E4073BA2C26365B4C4070B20DDC817A4E40AD872F13455A4C40118AADA069794E40AD872F13455A4C40
9798	Режик	6	56	920	61.389609	61.414295000000003	56.860495999999998	56.851343	0103000020E61000000100000005000000179D2CB5DEB14E40DA56B3CEF86C4C40179D2CB5DEB14E405E2BA1BB246E4C40BBF2599E07B54E405E2BA1BB246E4C40BBF2599E07B54E40DA56B3CEF86C4C40179D2CB5DEB14E40DA56B3CEF86C4C40
46750	Рассоха	6	56	920	61.027228000000001	61.051338999999999	56.723135999999997	56.706028000000003	0103000020E610000001000000050000008BC404357C834E40B80721205F5A4C408BC404357C834E40B6476FB88F5C4C403201BF4692864E40B6476FB88F5C4C403201BF4692864E40B80721205F5A4C408BC404357C834E40B80721205F5A4C40
22066	Поварня	6	56	920	60.977085000000002	60.996865	56.711452999999999	56.675826000000001	0103000020E61000000100000005000000C2340C1F117D4E40ACE4637781564C40C2340C1F117D4E400FD253E4105B4C4076C3B645997F4E400FD253E4105B4C4076C3B645997F4E40ACE4637781564C40C2340C1F117D4E40ACE4637781564C40
46914	Октябрьский	6	56	920	61.450946000000002	61.459865999999998	56.658959000000003	56.651339	0103000020E610000001000000050000008A213999B8B94E40FFCD8B135F534C408A213999B8B94E40D333BDC458544C406B459BE3DCBA4E40D333BDC458544C406B459BE3DCBA4E40FFCD8B135F534C408A213999B8B94E40FFCD8B135F534C40
47322	Некрасово	6	56	920	61.631346000000001	61.668868000000003	56.682442000000002	56.667842999999998	0103000020E61000000100000005000000EF3A1BF2CFD04E4067EE21E17B554C40EF3A1BF2CFD04E405BB56B425A574C40A4AB74779DD54E405BB56B425A574C40A4AB74779DD54E4067EE21E17B554C40EF3A1BF2CFD04E4067EE21E17B554C40
9994	Малобрусянское	6	56	920	61.109847000000002	61.148249999999997	56.740541999999998	56.732236999999998	0103000020E6100000010000000500000028486C770F8E4E40E8F527F1B95D4C4028486C770F8E4E403FA88B14CA5E4C40E5D022DBF9924E403FA88B14CA5E4C40E5D022DBF9924E40E8F527F1B95D4C4028486C770F8E4E40E8F527F1B95D4C40
50221	Малиновка	6	56	920	61.505347999999998	61.512157000000002	56.869588999999998	56.865191000000003	0103000020E61000000100000005000000AC8C463EAFC04E4093E52494BE6E4C40AC8C463EAFC04E400DFB3DB14E6F4C4070B54E5C8EC14E400DFB3DB14E6F4C4070B54E5C8EC14E4093E52494BE6E4C40AC8C463EAFC04E4093E52494BE6E4C40
46867	Логиново	6	56	920	61.280464000000002	61.310566000000001	56.631669000000002	56.611161000000003	0103000020E6100000010000000500000049DA8D3EE6A34E409BCB0D863A4E4C4049DA8D3EE6A34E40D272A087DA504C40F19F6EA0C0A74E40D272A087DA504C40F19F6EA0C0A74E409BCB0D863A4E4C4049DA8D3EE6A34E409BCB0D863A4E4C40
49968	Курманка	6	56	920	61.278064999999998	61.296067000000001	56.772266000000002	56.753661000000001	0103000020E61000000100000005000000C49448A297A34E40A5A2B1F677604C40C49448A297A34E4008E8BE9CD9624C4061360186E5A54E4008E8BE9CD9624C4061360186E5A54E40A5A2B1F677604C40C49448A297A34E40A5A2B1F677604C40
10684	Кочневское	6	56	920	61.479880999999999	61.515014000000001	56.643965000000001	56.622557999999998	0103000020E61000000100000005000000637C98BD6CBD4E407CEE04FBAF4F4C40637C98BD6CBD4E406362F3716D524C40B77D8FFAEBC14E406362F3716D524C40B77D8FFAEBC14E407CEE04FBAF4F4C40637C98BD6CBD4E407CEE04FBAF4F4C40
47971	Косулино	6	56	920	60.943621999999998	60.981765000000003	56.747768000000001	56.730687000000003	0103000020E610000001000000050000009FE40E9BC8784E40624ED026875D4C409FE40E9BC8784E40677FA0DCB65F4C40C1ADBB79AA7D4E40677FA0DCB65F4C40C1ADBB79AA7D4E40624ED026875D4C409FE40E9BC8784E40624ED026875D4C40
10332	Колюткино	6	56	920	61.167887	61.204583	56.620809999999999	56.609859	0103000020E6100000010000000500000037363B527D954E40EC1516DC0F4E4C4037363B527D954E40CF83BBB3764F4C40A62897C62F9A4E40CF83BBB3764F4C40A62897C62F9A4E40EC1516DC0F4E4C4037363B527D954E40EC1516DC0F4E4C40
46937	Камышево	6	56	920	61.319406000000001	61.35877	56.550454999999999	56.520544000000001	0103000020E61000000100000005000000B612BA4BE2A84E408410902FA1424C40B612BA4BE2A84E40B875374F75464C409964E42CECAD4E40B875374F75464C409964E42CECAD4E408410902FA1424C40B612BA4BE2A84E408410902FA1424C40
18065	Измоденова	6	56	920	61.593032000000001	61.610073	56.714036999999998	56.700445000000002	0103000020E61000000100000005000000A1BDFA78E8CB4E40C8D2872EA8594C40A1BDFA78E8CB4E4025917D90655B4C4018963FDF16CE4E4025917D90655B4C4018963FDF16CE4E40C8D2872EA8594C40A1BDFA78E8CB4E40C8D2872EA8594C40
10494	Златогорова	6	56	920	61.342123999999998	61.365633000000003	56.577233	56.553600000000003	0103000020E610000001000000050000009E961FB8CAAB4E406688635DDC464C409E961FB8CAAB4E4003965CC5E2494C4050ABE80FCDAE4E4003965CC5E2494C4050ABE80FCDAE4E406688635DDC464C409E961FB8CAAB4E406688635DDC464C40
16360	Заречный	6	56	920	61.303199999999997	61.379942999999997	56.821123999999998	56.765526999999999	0103000020E61000000100000005000000D712F241CFA64E403D9AEAC9FC614C40D712F241CFA64E40F8FA5A971A694C400CACE3F8A1B04E40F8FA5A971A694C400CACE3F8A1B04E403D9AEAC9FC614C40D712F241CFA64E403D9AEAC9FC614C40
46780	Гусева	6	56	920	61.142122999999998	61.172091000000002	56.716664999999999	56.710520000000002	0103000020E610000001000000050000003481221631924E40B493C151F25A4C403481221631924E400B98C0ADBB5B4C40CD77F01307964E400B98C0ADBB5B4C40CD77F01307964E40B493C151F25A4C403481221631924E40B493C151F25A4C40
10185	Гагарский	6	56	920	61.186706000000001	61.205589000000003	56.754939	56.745389000000003	0103000020E61000000100000005000000C6FB71FBE5974E402AE620E8685F4C40C6FB71FBE5974E40CBBC55D7A1604C406CB587BD509A4E40CBBC55D7A1604C406CB587BD509A4E402AE620E8685F4C40C6FB71FBE5974E402AE620E8685F4C40
49911	Гагарка	6	56	920	61.249858000000003	61.290534000000001	56.778075999999999	56.754648000000003	0103000020E610000001000000050000006E52D158FB9F4E40F4FE3F4E98604C406E52D158FB9F4E40B8E68EFE97634C402330D63730A54E40B8E68EFE97634C402330D63730A54E40F4FE3F4E98604C406E52D158FB9F4E40F4FE3F4E98604C40
15011	Верхнее Дуброво	6	56	920	61.028306000000001	61.065756999999998	56.768058000000003	56.736612000000001	0103000020E61000000100000005000000EA23F0879F834E40ABEB504D495E4C40EA23F0879F834E4031B77BB94F624C40D53DB2B96A884E4031B77BB94F624C40D53DB2B96A884E40ABEB504D495E4C40EA23F0879F834E40ABEB504D495E4C40
17457	Бруснятское	6	56	920	61.495232999999999	61.565759999999997	56.726934	56.706457999999998	0103000020E61000000100000005000000327381CB63BF4E40B0FF3A376D5A4C40327381CB63BF4E40DC2C5E2C0C5D4C4046B1DCD26AC84E40DC2C5E2C0C5D4C4046B1DCD26AC84E40B0FF3A376D5A4C40327381CB63BF4E40B0FF3A376D5A4C40
49947	Боярка	6	56	920	61.289679999999997	61.312973999999997	56.786912000000001	56.774282999999997	0103000020E610000001000000050000001327F73B14A54E40A46C91B41B634C401327F73B14A54E403C6A4C88B9644C40C83F33880FA84E403C6A4C88B9644C40C83F33880FA84E40A46C91B41B634C401327F73B14A54E40A46C91B41B634C40
10193	Большебрусянское	6	56	920	61.229591999999997	61.271659999999997	56.646726999999998	56.625069000000003	0103000020E610000001000000050000002CB64945639D4E40295FD04202504C402CB64945639D4E40583849F3C7524C40D0D03FC1C5A24E40583849F3C7524C40D0D03FC1C5A24E40295FD04202504C402CB64945639D4E40295FD04202504C40
10393	Белореченский	6	56	920	61.354018000000003	61.367339999999999	56.689897000000002	56.683272000000002	0103000020E6100000010000000500000001193A7650AD4E40E222F77475574C4001193A7650AD4E40E44D7E8B4E584C409E4143FF04AF4E40E44D7E8B4E584C409E4143FF04AF4E40E222F77475574C4001193A7650AD4E40E222F77475574C40
9305	Шаламы	6	56	836	63.650579	63.67698	57.366253999999998	57.356195999999997	0103000020E61000000100000005000000713B342C46D34F40A67B9DD497AD4C40713B342C46D34F40BC033C69E1AE4C40E605D847A7D64F40BC033C69E1AE4C40E605D847A7D64F40A67B9DD497AD4C40713B342C46D34F40A67B9DD497AD4C40
50096	Шадринка	6	56	836	63.462983000000001	63.474850000000004	57.568103000000001	57.557428999999999	0103000020E610000001000000050000004FCDE50643BB4F40C66B5ED559C74C404FCDE50643BB4F4037E15E99B7C84C40B84082E2C7BC4F4037E15E99B7C84C40B84082E2C7BC4F40C66B5ED559C74C404FCDE50643BB4F40C66B5ED559C74C40
9219	Чурманское	6	56	836	63.588819000000001	63.610433	57.473244999999999	57.465293000000003	0103000020E61000000100000005000000B821C66B5ECB4F40640795B88EBB4C40B821C66B5ECB4F406DFFCA4A93BC4C4018B325AB22CE4F406DFFCA4A93BC4C4018B325AB22CE4F40640795B88EBB4C40B821C66B5ECB4F40640795B88EBB4C40
9101	Пелевина	6	56	836	63.980924999999999	63.996285999999998	57.427118999999998	57.417271	0103000020E61000000100000005000000166A4DF38EFD4F40DC48D92269B54C40166A4DF38EFD4F400740DCD5ABB64C4038BBB54C86FF4F400740DCD5ABB64C4038BBB54C86FF4F40DC48D92269B54C40166A4DF38EFD4F40DC48D92269B54C40
9066	Нижняя Иленка	6	56	836	64.020020000000002	64.042963	57.564058000000003	57.556584000000001	0103000020E610000001000000050000000551F701480150400ABDFE243EC74C400551F701480150400A86730D33C84C4009FCE1E7BF0250400A86730D33C84C4009FCE1E7BF0250400ABDFE243EC74C400551F701480150400ABDFE243EC74C40
6126	Менщикова	6	56	836	63.588092000000003	63.616073999999998	57.649746	57.644333000000003	0103000020E610000001000000050000000685419946CB4F40E65DF58079D24C400685419946CB4F40795A7EE02AD34C403CF54883DBCE4F40795A7EE02AD34C403CF54883DBCE4F40E65DF58079D24C400685419946CB4F40E65DF58079D24C40
9014	Малая Серкова	6	56	836	63.403030000000001	63.422747999999999	57.376994000000003	57.368423999999997	0103000020E6100000010000000500000048A7AE7C96B34F40DF87838428AF4C4048A7AE7C96B34F40E564E25641B04C408639419B1CB64F40E564E25641B04C408639419B1CB64F40DF87838428AF4C4048A7AE7C96B34F40DF87838428AF4C40
8774	Макушина	6	56	836	63.852511	63.867998	57.619802	57.612672000000003	0103000020E61000000100000005000000793D98141FED4F4064963D096CCE4C40793D98141FED4F4069FF03AC55CF4C40287FF78E1AEF4F4069FF03AC55CF4C40287FF78E1AEF4F4064963D096CCE4C40793D98141FED4F4064963D096CCE4C40
46314	Ляпуново	6	56	836	63.461052000000002	63.502257999999998	57.424593999999999	57.395530999999998	0103000020E61000000100000005000000B1E07EC003BB4F40EFC682C2A0B24C40B1E07EC003BB4F40F609A01859B64C40C2137AFD49C04F40F609A01859B64C40C2137AFD49C04F40EFC682C2A0B24C40B1E07EC003BB4F40EFC682C2A0B24C40
47289	Липовка	6	56	836	63.730412000000001	63.745054000000003	57.361516999999999	57.345809000000003	0103000020E61000000100000005000000904DF2237EDD4F40CCD4247843AC4C40904DF2237EDD4F4059F9653046AE4C4083E0F1ED5DDF4F4059F9653046AE4C4083E0F1ED5DDF4F40CCD4247843AC4C40904DF2237EDD4F40CCD4247843AC4C40
61324	Краснополянское	6	56	836	62.936193000000003	64.174897999999999	57.801999000000002	57.236296000000003	0103000020E6100000010000000500000040DF162CD5774F407B1684F23E9E4C4040DF162CD5774F405D363AE7A7E64C40B1886187310B50405D363AE7A7E64C40B1886187310B50407B1684F23E9E4C4040DF162CD5774F407B1684F23E9E4C40
48894	Игнатьева	6	56	836	63.783332000000001	63.797964999999998	57.622207000000003	57.613602999999998	0103000020E6100000010000000500000084F4143944E44F401EDD088B8ACE4C4084F4143944E44F40D02B9E7AA4CF4C40232D95B723E64F40D02B9E7AA4CF4C40232D95B723E64F401EDD088B8ACE4C4084F4143944E44F401EDD088B8ACE4C40
48516	Елань	6	56	836	63.682639000000002	63.716191999999999	57.639308	57.626781000000001	0103000020E61000000100000005000000B1FCF9B660D74F4089601C5C3AD04C40B1FCF9B660D74F401C0934D8D4D14C4013D4F02DACDB4F401C0934D8D4D14C4013D4F02DACDB4F4089601C5C3AD04C40B1FCF9B660D74F4089601C5C3AD04C40
46408	Гуляева	6	56	836	64.065051999999994	64.089252999999999	57.529978999999997	57.522382	0103000020E610000001000000050000008522DDCF290450407102D369DDC24C408522DDCF290450408C48145AD6C34C4079043752B60550408C48145AD6C34C4079043752B60550407102D369DDC24C408522DDCF290450407102D369DDC24C40
46586	Городище	6	56	836	63.914558	63.947274	57.598022999999998	57.580531000000001	0103000020E61000000100000005000000C8258E3C10F54F4037A8FDD64ECA4C40C8258E3C10F54F40BEA085048CCC4C40F12C414640F94F40BEA085048CCC4C40F12C414640F94F4037A8FDD64ECA4C40C8258E3C10F54F4037A8FDD64ECA4C40
47803	Вязовка	6	56	836	63.850166000000002	63.872273999999997	57.507764000000002	57.495683999999997	0103000020E61000000100000005000000E8154F3DD2EC4F404293C49272BF4C40E8154F3DD2EC4F40070B2769FEC04C405793A7ACA6EF4F40070B2769FEC04C405793A7ACA6EF4F404293C49272BF4C40E8154F3DD2EC4F404293C49272BF4C40
46131	Байкалово	6	56	836	63.735523000000001	63.786233000000003	57.409185000000001	57.388114000000002	0103000020E61000000100000005000000583A1F9E25DE4F40548F34B8ADB14C40583A1F9E25DE4F40C381902C60B44C409B046F48A3E44F40C381902C60B44C409B046F48A3E44F40548F34B8ADB14C40583A1F9E25DE4F40548F34B8ADB14C40
8775	Баженовское	6	56	836	63.886763999999999	63.899107000000001	57.542782000000003	57.537810999999998	0103000020E6100000010000000500000094A2957B81F14F40EB36A8FDD6C44C4094A2957B81F14F40C26D6DE179C54C40664D2CF015F34F40C26D6DE179C54C40664D2CF015F34F40EB36A8FDD6C44C4094A2957B81F14F40EB36A8FDD6C44C40
7279	Ялым	6	56	734	58.081446	58.107954999999997	56.789698000000001	56.777498999999999	0103000020E61000000100000005000000EC3191D26C0A4D401BD6541685634C40EC3191D26C0A4D40BADBF5D214654C4047382D78D10D4D40BADBF5D214654C4047382D78D10D4D401BD6541685634C40EC3191D26C0A4D401BD6541685634C40
8316	Уфимский	6	56	734	58.024124999999998	58.078463999999997	56.718449	56.693410999999998	0103000020E610000001000000050000000C022B8716034D40E4D70FB1C1584C400C022B8716034D40056C0723F65B4C40E8F4BC1B0B0A4D40056C0723F65B4C40E8F4BC1B0B0A4D40E4D70FB1C1584C400C022B8716034D40E4D70FB1C1584C40
7080	Тюш	6	56	734	58.341517000000003	58.362816000000002	56.805146000000001	56.790180999999997	0103000020E6100000010000000500000097033DD4B62B4D40D575A8A624654C4097033DD4B62B4D40AB402D060F674C40973B33C1702E4D40AB402D060F674C40973B33C1702E4D40D575A8A624654C4097033DD4B62B4D40D575A8A624654C40
7754	Судницына	6	56	734	58.161109000000003	58.168258999999999	56.745990999999997	56.738200999999997	0103000020E61000000100000005000000AF0B3F389F144D40EF6FD05E7D5E4C40AF0B3F389F144D401F0E12A27C5F4C40FB20CB8289154D401F0E12A27C5F4C40FB20CB8289154D40EF6FD05E7D5E4C40AF0B3F389F144D40EF6FD05E7D5E4C40
6926	Сарга (Грачи)	6	56	734	58.163462000000003	58.175679000000002	56.812275999999997	56.802833999999997	0103000020E61000000100000005000000C311A452EC144D40F50EB743C3664C40C311A452EC144D40B0A9F3A8F8674C4008CC43A67C164D40B0A9F3A8F8674C4008CC43A67C164D40F50EB743C3664C40C311A452EC144D40F50EB743C3664C40
5859	Русский Потам	6	56	734	58.055377	58.082614	56.895408000000003	56.873750999999999	0103000020E61000000100000005000000ADF9F19716074D4074ECA012D76F4C40ADF9F19716074D40D449B6BA9C724C408B187618930A4D40D449B6BA9C724C408B187618930A4D4074ECA012D76F4C40ADF9F19716074D4074ECA012D76F4C40
5715	Русские Карши (Одина)	6	56	734	57.915680000000002	57.936692000000001	56.900647999999997	56.887943999999997	0103000020E61000000100000005000000F7CC920035F54C40F7562426A8714C40F7CC920035F54C40999A046F48734C4061360186E5F74C40999A046F48734C4061360186E5F74C40F7562426A8714C40F7CC920035F54C40F7562426A8714C40
7019	Осыпь	6	56	734	58.188813000000003	58.195540999999999	56.787557999999997	56.778061000000001	0103000020E61000000100000005000000A3073E062B184D4083A5BA8097634C40A3073E062B184D4001DA56B3CE644C407903CC7C07194D4001DA56B3CE644C407903CC7C07194D4083A5BA8097634C40A3073E062B184D4083A5BA8097634C40
7639	Нижний Арий	6	56	734	58.187088000000003	58.212187	56.728834999999997	56.709812999999997	0103000020E61000000100000005000000AEBCE47FF2174D4048A30227DB5A4C40AEBCE47FF2174D400F971C774A5D4C4074D190F1281B4D400F971C774A5D4C4074D190F1281B4D4048A30227DB5A4C40AEBCE47FF2174D4048A30227DB5A4C40
6074	Марийские Карши	6	56	734	58.052134000000002	58.074421000000001	56.834786000000001	56.824764000000002	0103000020E610000001000000050000003D81B053AC064D408675E3DD91694C403D81B053AC064D404F948444DA6A4C405C9198A086094D404F948444DA6A4C405C9198A086094D408675E3DD91694C403D81B053AC064D408675E3DD91694C40
6340	Малый Ут	6	56	734	57.935012	57.949654000000002	57.014287000000003	57.007828000000003	0103000020E610000001000000050000000CAF2479AEF74C401EFF058200814C400CAF2479AEF74C4005E10A28D4814C40FF4124438EF94C4005E10A28D4814C40FF4124438EF94C401EFF058200814C400CAF2479AEF74C401EFF058200814C40
6495	Лямпа	6	56	734	57.942836	57.960811	56.983941000000002	56.975960999999998	0103000020E61000000100000005000000E8BE9CD9AEF84C40F295404AEC7C4C40E8BE9CD9AEF84C40C61858C7F17D4C408B51D7DAFBFA4C40C61858C7F17D4C408B51D7DAFBFA4C40F295404AEC7C4C40E8BE9CD9AEF84C40F295404AEC7C4C40
5322	Кочкильда	6	56	734	57.988182999999999	57.999384999999997	56.859448	56.853282	0103000020E6100000010000000500000049BBD1C77CFE4C40FB213658386D4C4049BBD1C77CFE4C406A4E5E64026E4C40758E01D9EBFF4C406A4E5E64026E4C40758E01D9EBFF4C40FB213658386D4C4049BBD1C77CFE4C40FB213658386D4C40
6618	Корзуновка	6	56	734	58.215986999999998	58.242469	56.944257	56.925246999999999	0103000020E610000001000000050000003AAE4676A51B4D406EDC627E6E764C403AAE4676A51B4D407102D369DD784C409CA56439091F4D407102D369DD784C409CA56439091F4D406EDC627E6E764C403AAE4676A51B4D406EDC627E6E764C40
8042	Конёвка	6	56	734	58.382632999999998	58.398263999999998	56.624777000000002	56.618293999999999	0103000020E6100000010000000500000068AF3E1EFA304D4011A8FE41244F4C4068AF3E1EFA304D40812557B1F84F4C404A969350FA324D40812557B1F84F4C404A969350FA324D4011A8FE41244F4C4068AF3E1EFA304D4011A8FE41244F4C40
7559	Кирчигаз	6	56	734	58.266300999999999	58.282471000000001	56.589759999999998	56.569060999999998	0103000020E6100000010000000500000030F2B22616224D40EB36A8FDD6484C4030F2B22616224D40963E74417D4B4C40C2887D0228244D40963E74417D4B4C40C2887D0228244D40EB36A8FDD6484C4030F2B22616224D40EB36A8FDD6484C40
8262	Катырева	6	56	734	58.473030999999999	58.507032000000002	56.635392000000003	56.620562	0103000020E61000000100000005000000417FA1478C3C4D40F7915B936E4F4C40417FA1478C3C4D40ED116A8654514C404303B16CE6404D40ED116A8654514C404303B16CE6404D40F7915B936E4F4C40417FA1478C3C4D40F7915B936E4F4C40
7504	Карги	6	56	734	58.246017000000002	58.274349999999998	56.629699000000002	56.608541000000002	0103000020E6100000010000000500000049A12C7C7D1F4D4038A3E6ABE44D4C4049A12C7C7D1F4D4076A911FA99504C402CD49AE61D234D4076A911FA99504C402CD49AE61D234D4038A3E6ABE44D4C4049A12C7C7D1F4D4038A3E6ABE44D4C40
7219	Заря	6	56	734	57.952204999999999	57.969776000000003	56.752985000000002	56.738843000000003	0103000020E61000000100000005000000390B7BDAE1F94C4074F04C68925E4C40390B7BDAE1F94C4075B0FECF61604C400D39B69E21FC4C4075B0FECF61604C400D39B69E21FC4C4074F04C68925E4C40390B7BDAE1F94C4074F04C68925E4C40
8111	Еманзельга	6	56	734	58.355387	58.364334999999997	56.597026	56.587103999999997	0103000020E6100000010000000500000037363B527D2D4D40E6AC4F39264B4C4037363B527D2D4D404C6E14596B4C4C40E2E47E87A22E4D404C6E14596B4C4C40E2E47E87A22E4D40E6AC4F39264B4C4037363B527D2D4D40E6AC4F39264B4C40
61330	Верхний Потам	6	56	734	57.995458999999997	58.017836000000003	56.923296999999998	56.913249	0103000020E6100000010000000500000022C154336BFF4C40670DDE57E5744C4022C154336BFF4C4059BF99982E764C408258367348024D4059BF99982E764C408258367348024D40670DDE57E5744C4022C154336BFF4C40670DDE57E5744C40
7816	Верхний Арий	6	56	734	58.274189	58.308253000000001	56.701872999999999	56.691014000000003	0103000020E6100000010000000500000023F609A018234D40018A912573584C4023F609A018234D40037976F9D6594C406BF294D574274D40037976F9D6594C406BF294D574274D40018A912573584C4023F609A018234D40018A912573584C40
61325	Верх-Тиса	6	56	734	57.817072000000003	57.851343	56.901518000000003	56.886808000000002	0103000020E61000000100000005000000193DB7D095E84C4064EAAEEC82714C40193DB7D095E84C40AF601BF164734C40DA56B3CEF8EC4C40AF601BF164734C40DA56B3CEF8EC4C4064EAAEEC82714C40193DB7D095E84C4064EAAEEC82714C40
5487	Быково	6	56	734	57.605195000000002	57.631425999999998	56.899856999999997	56.888976999999997	0103000020E61000000100000005000000F3599E0777CD4C40B6F292FFC9714C40F3599E0777CD4C40D009A1832E734C400BEC3191D2D04C40D009A1832E734C400BEC3191D2D04C40B6F292FFC9714C40F3599E0777CD4C40B6F292FFC9714C40
6277	Большой Ут	6	56	734	57.983179	58.004739000000001	57.018839999999997	57.005381999999997	0103000020E61000000100000005000000978E39CFD8FD4C4058FE7C5BB0804C40978E39CFD8FD4C40A6ED5F5969824C4004029D499B004D40A6ED5F5969824C4004029D499B004D4058FE7C5BB0804C40978E39CFD8FD4C4058FE7C5BB0804C40
5432	Бакряж	6	56	734	57.697766999999999	57.718598999999998	56.891165000000001	56.875014999999998	0103000020E61000000100000005000000309DD66D50D94C403541D47D00704C40309DD66D50D94C40802BD9B111724C401AF8510DFBDB4C40802BD9B111724C401AF8510DFBDB4C403541D47D00704C40309DD66D50D94C403541D47D00704C40
5111	Ачит	6	56	734	57.874904999999998	57.920639000000001	56.818804	56.761975	0103000020E61000000100000005000000AE0D15E3FCEF4C404FAF946588614C40AE0D15E3FCEF4C40C0EAC891CE684C400936AE7FD7F54C40C0EAC891CE684C400936AE7FD7F54C404FAF946588614C40AE0D15E3FCEF4C404FAF946588614C40
6701	Афанасьевское	6	56	734	58.256393000000003	58.307003999999999	56.826566999999997	56.813201999999997	0103000020E6100000010000000500000030F65E7CD1204D405985CD0017684C4030F65E7CD1204D40F6798CF2CC694C40DFDE35E84B274D40F6798CF2CC694C40DFDE35E84B274D405985CD0017684C4030F65E7CD1204D405985CD0017684C40
6798	Афанасьевский	6	56	734	58.317137000000002	58.353904999999997	56.861161000000003	56.844520000000003	0103000020E6100000010000000500000000ADF9F197284D40B2683A3B196C4C4000ADF9F197284D409BCB0D863A6E4C40087250C24C2D4D409BCB0D863A6E4C40087250C24C2D4D40B2683A3B196C4C4000ADF9F197284D40B2683A3B196C4C40
6130	Артемейкова	6	56	734	58.066282000000001	58.073155	56.854660000000003	56.845303000000001	0103000020E610000001000000050000002028B7ED7B084D40F81A82E3326C4C402028B7ED7B084D408599B67F656D4C40FA449E245D094D408599B67F656D4C40FA449E245D094D40F81A82E3326C4C402028B7ED7B084D40F81A82E3326C4C40
50172	Гайны	6	56	7037	58.014251999999999	58.043931999999998	56.730820000000001	56.715643	0103000020E6100000010000000500000088F37002D3014D40404E98309A5B4C4088F37002D3014D40A1A17F828B5D4C40BA9F53909F054D40A1A17F828B5D4C40BA9F53909F054D40404E98309A5B4C4088F37002D3014D40404E98309A5B4C40
50195	Ключ	6	56	7054	58.400689	58.427261999999999	56.627786999999998	56.618022000000003	0103000020E61000000100000005000000F86EF3C649334D40B11A4B581B4F4C40F86EF3C649334D404EED0C535B504C406A696E85B0364D404EED0C535B504C406A696E85B0364D40B11A4B581B4F4C40F86EF3C649334D40B11A4B581B4F4C40
50160	Рефтинский	6	56	7032	61.659041000000002	61.689591999999998	57.098562999999999	57.080077000000003	0103000020E6100000010000000500000090DC9A745BD44E40B61490F63F8A4C4090DC9A745BD44E403ECC5EB69D8C4C40A7CAF78C44D84E403ECC5EB69D8C4C40A7CAF78C44D84E40B61490F63F8A4C4090DC9A745BD44E40B61490F63F8A4C40
4704	Черкасовка	6	56	446	58.849829	58.893630999999999	56.168089999999999	56.146362000000003	0103000020E61000000100000005000000A0185932C76C4D4047B071FDBB124C40A0185932C76C4D406F641EF983154C408CD8278062724D406F641EF983154C408CD8278062724D4047B071FDBB124C40A0185932C76C4D4047B071FDBB124C40
3984	Чекмаш	6	56	446	58.447158999999999	58.456716999999998	56.398674999999997	56.394345999999999	0103000020E61000000100000005000000588E90813C394D407AA702EE79324C40588E90813C394D40CC5D4BC807334C407C43E1B3753A4D40CC5D4BC807334C407C43E1B3753A4D407AA702EE79324C40588E90813C394D407AA702EE79324C40
61329	Усть-Югуш	6	56	446	58.628646000000003	58.643692999999999	56.420881999999999	56.411844000000002	0103000020E610000001000000050000007061DD7877504D40E486DF4DB7344C407061DD7877504D40CFBC1C76DF354C4002D53F8864524D40CFBC1C76DF354C4002D53F8864524D40E486DF4DB7344C407061DD7877504D40E486DF4DB7344C40
4764	Усть-Манчаж	6	56	446	58.166265000000003	58.177925000000002	56.547507000000003	56.538246999999998	0103000020E6100000010000000500000017BCE82B48154D40C6151747E5444C4017BCE82B48154D4061AA99B514464C400612143FC6164D4061AA99B514464C400612143FC6164D40C6151747E5444C4017BCE82B48154D40C6151747E5444C40
3598	Токари	6	56	446	58.127242000000003	58.139226000000001	56.414209999999997	56.404055	0103000020E61000000100000005000000BD56427749104D4084640113B8334C40BD56427749104D408CD651D504354C405F605628D2114D408CD651D504354C405F605628D2114D4084640113B8334C40BD56427749104D4084640113B8334C40
4701	Сухановка	6	56	446	58.664138000000001	58.769035000000002	56.167268	56.137273999999998	0103000020E61000000100000005000000F303577902554D40A94BC63192114C40F303577902554D406BD5AE0969154C405C3D27BD6F624D406BD5AE0969154C405C3D27BD6F624D40A94BC63192114C40F303577902554D40A94BC63192114C40
4585	Старые Арти	6	56	446	58.570793999999999	58.604418000000003	56.340096000000003	56.294989999999999	0103000020E6100000010000000500000063601DC70F494D40D252793BC2254C4063601DC70F494D400EC00644882B4C408F8EAB915D4D4D400EC00644882B4C408F8EAB915D4D4D40D252793BC2254C4063601DC70F494D40D252793BC2254C40
4206	Соколята	6	56	446	58.075338000000002	58.107443000000004	56.262706999999999	56.252017000000002	0103000020E61000000100000005000000B212F3ACA4094D409D84D21742204C40B212F3ACA4094D4013B70A62A0214C40929735B1C00D4D4013B70A62A0214C40929735B1C00D4D409D84D21742204C40B212F3ACA4094D409D84D21742204C40
4363	Симинчи	6	56	446	58.314442	58.339182000000001	56.443398999999999	56.422266	0103000020E61000000100000005000000923EADA23F284D403B1BF2CF0C364C40923EADA23F284D40200A664CC1384C4029B2D6506A2B4D40200A664CC1384C4029B2D6506A2B4D403B1BF2CF0C364C40923EADA23F284D403B1BF2CF0C364C40
4590	Сенная	6	56	446	58.641240000000003	58.672178000000002	56.260182999999998	56.254192000000003	0103000020E610000001000000050000008B71FE2614524D40D2730B5D89204C408B71FE2614524D40D2FC31AD4D214C409C8BBFED09564D40D2FC31AD4D214C409C8BBFED09564D40D2730B5D89204C408B71FE2614524D40D2730B5D89204C40
49840	Село Манчаж	6	56	446	58.127152000000002	58.163319000000001	56.489342000000001	56.466290000000001	0103000020E610000001000000050000007DCF488446104D40D6390664AF3B4C407DCF488446104D40954737C2A23E4C4060E811A3E7144D40954737C2A23E4C4060E811A3E7144D40D6390664AF3B4C407DCF488446104D40D6390664AF3B4C40
4302	Свердловское	6	56	446	58.332031000000001	58.358485999999999	56.210832000000003	56.186154000000002	0103000020E610000001000000050000000C21E7FD7F2A4D408202EFE4D3174C400C21E7FD7F2A4D40A379008BFC1A4C40740987DEE22D4D40A379008BFC1A4C40740987DEE22D4D408202EFE4D3174C400C21E7FD7F2A4D408202EFE4D3174C40
4105	Сажино	6	56	446	58.173335000000002	58.225715000000001	56.332540999999999	56.313592999999997	0103000020E6100000010000000500000047205ED72F164D4094A0BFD023284C4047205ED72F164D4021CA17B4902A4C40BB9BA73AE41C4D4021CA17B4902A4C40BB9BA73AE41C4D4094A0BFD023284C4047205ED72F164D4094A0BFD023284C40
61309	Пристань	6	56	446	58.543017999999996	58.583227000000001	56.459845000000001	56.438786	0103000020E61000000100000005000000D591239D81454D40A9F8BF232A384C40D591239D81454D40541D7233DC3A4C407592AD2EA74A4D40541D7233DC3A4C407592AD2EA74A4D40A9F8BF232A384C40D591239D81454D40A9F8BF232A384C40
3792	Поташка	6	56	446	58.782913999999998	58.819574000000003	56.255482000000001	56.219427000000003	0103000020E610000001000000050000004FCAA48636644D40016E162F161C4C404FCAA48636644D40BC5B59A2B3204C40725303CDE7684D40BC5B59A2B3204C40725303CDE7684D40016E162F161C4C404FCAA48636644D40016E162F161C4C40
3736	Пантелейково	6	56	446	58.556106999999997	58.572214000000002	56.376351	56.357813999999998	0103000020E61000000100000005000000D009A1832E474D40850662D9CC2D4C40D009A1832E474D40906802452C304C401C28F04E3E494D40906802452C304C401C28F04E3E494D40850662D9CC2D4C40D009A1832E474D40850662D9CC2D4C40
3149	Омельково	6	56	446	58.331968000000003	58.349969999999999	56.266967000000001	56.253726999999998	0103000020E61000000100000005000000C6A86BED7D2A4D405C8E57207A204C40C6A86BED7D2A4D403D0E83F92B224C40624A24D1CB2C4D403D0E83F92B224C40624A24D1CB2C4D405C8E57207A204C40C6A86BED7D2A4D405C8E57207A204C40
3646	Новый Златоуст	6	56	446	58.443629000000001	58.462465999999999	56.227499999999999	56.214866999999998	0103000020E610000001000000050000005247C7D5C8384D40ACFE08C3801B4C405247C7D5C8384D4085EB51B81E1D4C4087C1FC15323B4D4085EB51B81E1D4C4087C1FC15323B4D40ACFE08C3801B4C405247C7D5C8384D40ACFE08C3801B4C40
4519	Нижний Бардым	6	56	446	58.249960999999999	58.264631000000001	56.477139000000001	56.462451000000001	0103000020E610000001000000050000004223D8B8FE1F4D4052802898313B4C404223D8B8FE1F4D40B55208E4123D4C40FF40B96DDF214D40B55208E4123D4C40FF40B96DDF214D4052802898313B4C404223D8B8FE1F4D4052802898313B4C40
3375	Малая Тавра	6	56	446	58.146745000000003	58.166696000000002	56.169773999999997	56.155864000000001	0103000020E61000000100000005000000FFEC478AC8124D40D74FFF59F3134C40FFEC478AC8124D4005DB8827BB154C40E02F664B56154D4005DB8827BB154C40E02F664B56154D40D74FFF59F3134C40FFEC478AC8124D40D74FFF59F3134C40
3073	Малая Дегтярка	6	56	446	58.252772999999998	58.261253000000004	56.336253999999997	56.330914	0103000020E61000000100000005000000E9279CDD5A204D40EFE4D3635B2A4C40E9279CDD5A204D401893FE5E0A2B4C40AF7D01BD70214D401893FE5E0A2B4C40AF7D01BD70214D40EFE4D3635B2A4C40E9279CDD5A204D40EFE4D3635B2A4C40
3220	Курки	6	56	446	58.470999999999997	58.490637999999997	56.502594000000002	56.491771999999997	0103000020E610000001000000050000003F355EBA493C4D40548B8862F23E4C403F355EBA493C4D403A950C0055404C406116DA39CD3E4D403A950C0055404C406116DA39CD3E4D40548B8862F23E4C403F355EBA493C4D40548B8862F23E4C40
4150	Конёво	6	56	446	58.144965999999997	58.168663000000002	56.360157999999998	56.351174999999998	0103000020E610000001000000050000001684F23E8E124D401E166A4DF32C4C401684F23E8E124D4046B247A8192E4C40CB85CABF96154D4046B247A8192E4C40CB85CABF96154D401E166A4DF32C4C401684F23E8E124D401E166A4DF32C4C40
3528	Кадочниково	6	56	446	58.041381000000001	58.062393	56.481955999999997	56.478104000000002	0103000020E6100000010000000500000080D6FCF84B054D401C0B0A83323D4C4080D6FCF84B054D40340EF5BBB03D4C40EA3F6B7EFC074D40340EF5BBB03D4C40EA3F6B7EFC074D401C0B0A83323D4C4080D6FCF84B054D401C0B0A83323D4C40
61312	Дружино-Бардым	6	56	446	58.226891999999999	58.250743	56.516944000000002	56.509365000000003	0103000020E61000000100000005000000ADDC0BCC0A1D4D40105D50DF32414C40ADDC0BCC0A1D4D4085EE92382B424C40B859BC5818204D4085EE92382B424C40B859BC5818204D40105D50DF32414C40ADDC0BCC0A1D4D40105D50DF32414C40
4431	Верхний Бардым	6	56	446	58.270136999999998	58.291463	56.428652999999997	56.414209999999997	0103000020E61000000100000005000000433866D993224D408CD651D504354C40433866D993224D40882AFC19DE364C403D7FDAA84E254D40882AFC19DE364C403D7FDAA84E254D408CD651D504354C40433866D993224D408CD651D504354C40
3035	Большие Карзи	6	56	446	58.337484000000003	58.351506999999998	56.315905000000001	56.294984999999997	0103000020E610000001000000050000002E76FBAC322B4D40C0E78711C2254C402E76FBAC322B4D404AD235936F284C4054A86E2EFE2C4D404AD235936F284C4054A86E2EFE2C4D40C0E78711C2254C402E76FBAC322B4D40C0E78711C2254C40
2907	Биткино	6	56	446	58.201506000000002	58.225132000000002	56.529108999999998	56.522545000000001	0103000020E6100000010000000500000051F9D7F2CA194D401BD82AC1E2424C4051F9D7F2CA194D407782FDD7B9434C403CA41820D11C4D407782FDD7B9434C403CA41820D11C4D401BD82AC1E2424C4051F9D7F2CA194D401BD82AC1E2424C40
3894	Берёзовка	6	56	446	58.872520000000002	58.962665999999999	56.222841000000003	56.197052999999997	0103000020E610000001000000050000008F8D40BCAE6F4D40124A5F0839194C408F8D40BCAE6F4D409E9ACB0D861C4C404E7CB5A3387B4D409E9ACB0D861C4C404E7CB5A3387B4D40124A5F0839194C408F8D40BCAE6F4D40124A5F0839194C40
2973	Бараба	6	56	446	58.338742000000003	58.355665999999999	56.288606000000001	56.277433000000002	0103000020E610000001000000050000000DE4D9E55B2B4D4064EAAEEC82234C400DE4D9E55B2B4D40F6B6990AF1244C404A26A776862D4D40F6B6990AF1244C404A26A776862D4D4064EAAEEC82234C400DE4D9E55B2B4D4064EAAEEC82234C40
4849	Бакийково	6	56	446	58.153185999999998	58.168008	56.559458999999997	56.548271999999997	0103000020E610000001000000050000003F1A4E999B134D4000A8E2C62D464C403F1A4E999B134D40F7393E5A9C474C40B2BB404981154D40F7393E5A9C474C40B2BB404981154D4000A8E2C62D464C403F1A4E999B134D4000A8E2C62D464C40
3435	Багышково	6	56	446	58.208854000000002	58.240574000000002	56.133792999999997	56.128104	0103000020E61000000100000005000000C4D155BABB1A4D404F3E3DB665104C40C4D155BABB1A4D4084B7072120114C404B22FB20CB1E4D4084B7072120114C404B22FB20CB1E4D404F3E3DB665104C40C4D155BABB1A4D404F3E3DB665104C40
4044	Афонасково	6	56	446	58.520829999999997	58.530800999999997	56.464092000000001	56.452240000000003	0103000020E610000001000000050000004963B48EAA424D40B6F81400E3394C404963B48EAA424D40E92ADD5D673B4C4090D78349F1434D40E92ADD5D673B4C4090D78349F1434D40B6F81400E3394C404963B48EAA424D40B6F81400E3394C40
3833	Артя-Шигири	6	56	446	58.712153000000001	58.730362	56.324306	56.314940999999997	0103000020E61000000100000005000000C85F5AD4275B4D40B39597FC4F284C40C85F5AD4275B4D40C3F2E7DB82294C40DE1E84807C5D4D40C3F2E7DB82294C40DE1E84807C5D4D40B39597FC4F284C40C85F5AD4275B4D40B39597FC4F284C40
2518	Арти	6	56	446	58.495677000000001	58.563679999999998	56.439473	56.393065	0103000020E6100000010000000500000090300C58723F4D40E31934F44F324C4090300C58723F4D40CD3CB9A640384C4063B48EAA26484D40CD3CB9A640384C4063B48EAA26484D40E31934F44F324C4090300C58723F4D40E31934F44F324C40
4358	Андрейково	6	56	446	58.330719999999999	58.341805000000001	56.231943000000001	56.217309999999998	0103000020E610000001000000050000000A117008552A4D40008C67D0D01B4C400A117008552A4D40A0C4E74EB01D4C40FD4D2844C02B4D40A0C4E74EB01D4C40FD4D2844C02B4D40008C67D0D01B4C400A117008552A4D40008C67D0D01B4C40
2786	Азигулово	6	56	446	58.277638000000003	58.327378000000003	56.546078000000001	56.529952000000002	0103000020E610000001000000050000003D1059A489234D4093399677D5434C403D1059A489234D40558847E2E5454C4007B7B585E7294D40558847E2E5454C4007B7B585E7294D4093399677D5434C403D1059A489234D4093399677D5434C40
50187	Манчаж	6	56	7050	58.127152000000002	58.163319000000001	56.489342000000001	56.466290000000001	0103000020E610000001000000050000007DCF488446104D40D6390664AF3B4C407DCF488446104D40954737C2A23E4C4060E811A3E7144D40954737C2A23E4C4060E811A3E7144D40D6390664AF3B4C407DCF488446104D40D6390664AF3B4C40
50235	Малые Карзи	6	56	7050	58.374583999999999	58.397249000000002	56.187345999999998	56.176439000000002	0103000020E610000001000000050000006CCD565EF22F4D40965E9B8D95164C406CCD565EF22F4D40A98427F4FA174C4032AF230ED9324D40A98427F4FA174C4032AF230ED9324D40965E9B8D95164C406CCD565EF22F4D40965E9B8D95164C40
1255	Шогринское	6	56	11	61.966892999999999	61.997318999999997	57.459207999999997	57.436078000000002	0103000020E610000001000000050000009CDD5A26C3FB4E40A7406667D1B74C409CDD5A26C3FB4E40E107E753C7BA4C40F7562426A8FF4E40E107E753C7BA4C40F7562426A8FF4E40A7406667D1B74C409CDD5A26C3FB4E40A7406667D1B74C40
61125	Сосновый Бор	6	56	11	62.241489999999999	62.275393000000001	57.375815000000003	57.366365999999999	0103000020E61000000100000005000000D027F224E91E4F40E42EC214E5AE4C40D027F224E91E4F40522CB7B41AB04C400F46EC1340234F40522CB7B41AB04C400F46EC1340234F40E42EC214E5AE4C40D027F224E91E4F40E42EC214E5AE4C40
49898	Покровское	6	56	11	61.635783000000004	61.738847	57.371034999999999	57.329089000000003	0103000020E61000000100000005000000282D5C5661D14E40973C9E961FAA4C40282D5C5661D14E40EF552B137EAF4C40B5DFDA8992DE4E40EF552B137EAF4C40B5DFDA8992DE4E40973C9E961FAA4C40282D5C5661D14E40973C9E961FAA4C40
892	Писанец	6	56	11	62.139539999999997	62.161450000000002	57.376086999999998	57.351224000000002	0103000020E61000000100000005000000EE3D5C72DC114F4000C974E8F4AC4C40EE3D5C72DC114F40B2B96A9E23B04C4038F8C264AA144F40B2B96A9E23B04C4038F8C264AA144F4000C974E8F4AC4C40EE3D5C72DC114F4000C974E8F4AC4C40
1935	Незевай	6	56	11	61.798395999999997	61.817315000000001	57.505468	57.490566999999999	0103000020E61000000100000005000000ECA012D731E64E4098BF42E6CABE4C40ECA012D731E64E405796E82CB3C04C40DFC325C79DE84E405796E82CB3C04C40DFC325C79DE84E4098BF42E6CABE4C40ECA012D731E64E4098BF42E6CABE4C40
50109	Мостовское	6	56	11	61.920135999999999	61.956940000000003	57.398057000000001	57.383443	0103000020E61000000100000005000000A6EF3504C7F54E40A87004A914B14C40A6EF3504C7F54E40D1782288F3B24C40FC1D8A027DFA4E40D1782288F3B24C40FC1D8A027DFA4E40A87004A914B14C40A6EF3504C7F54E40A87004A914B14C40
1812	Липино	6	56	11	61.677115000000001	61.696607999999998	57.477876000000002	57.465282999999999	0103000020E61000000100000005000000C6504EB4ABD64E404031B2648EBB4C40C6504EB4ABD64E408BC56F0A2BBD4C40E41071732AD94E408BC56F0A2BBD4C40E41071732AD94E404031B2648EBB4C40C6504EB4ABD64E404031B2648EBB4C40
1003	Лебёдкино	6	56	11	62.222608000000001	62.255935000000001	57.547882000000001	57.538009000000002	0103000020E61000000100000005000000FBE93F6B7E1C4F4012FA997ADDC44C40FBE93F6B7E1C4F40960854FF20C64C406D73637AC2204F40960854FF20C64C406D73637AC2204F4012FA997ADDC44C40FBE93F6B7E1C4F4012FA997ADDC44C40
449	Красногвардейский	6	56	11	62.279677999999997	62.353662999999997	57.393523000000002	57.360419999999998	0103000020E6100000010000000500000091B41B7DCC234F408369183E22AE4C4091B41B7DCC234F40A69C2FF65EB24C40126745D4442D4F40A69C2FF65EB24C40126745D4442D4F408369183E22AE4C4091B41B7DCC234F408369183E22AE4C40
14	Буланаш	6	56	11	61.974285999999999	62.008170999999997	57.295197999999999	57.257868999999999	0103000020E61000000100000005000000AF795567B5FC4E407CD3F4D901A14C40AF795567B5FC4E401CEC4D0CC9A54C4047E350BF0B014F401CEC4D0CC9A54C4047E350BF0B014F407CD3F4D901A14C40AF795567B5FC4E407CD3F4D901A14C40
1130	Бичур	6	56	11	62.143968999999998	62.157507000000003	57.596305999999998	57.580737999999997	0103000020E61000000100000005000000A45181936D124F40B0C56E9F55CA4C40A45181936D124F404C3448C153CC4C400FF27A3029144F404C3448C153CC4C400FF27A3029144F40B0C56E9F55CA4C40A45181936D124F40B0C56E9F55CA4C40
2059	Артёмовский	6	56	11	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
50112	Мироново	6	56	7020	61.853158000000001	61.946384999999999	57.385629999999999	57.291710999999999	0103000020E610000001000000050000000F29064834ED4E4015713AC956A54C400F29064834ED4E40A12DE7525CB14C406536C82423F94E40A12DE7525CB14C406536C82423F94E4015713AC956A54C400F29064834ED4E4015713AC956A54C40
50228	Большое Трифоново	6	56	7067	61.804307000000001	61.833646000000002	57.358894999999997	57.348649999999999	0103000020E61000000100000005000000D1782288F3E64E400DE02D90A0AC4C40D1782288F3E64E4055D97745F0AD4C407A3881E9B4EA4E4055D97745F0AD4C407A3881E9B4EA4E400DE02D90A0AC4C40D1782288F3E64E400DE02D90A0AC4C40
29732	Ячменёва	6	56	481	62.220865000000003	62.238607000000002	57.873959999999997	57.866731999999999	0103000020E6100000010000000500000060EAE74D451C4F40C632FD12F1EE4C4060EAE74D451C4F408E01D9EBDDEF4C4060CC96AC8A1E4F408E01D9EBDDEF4C4060CC96AC8A1E4F40C632FD12F1EE4C4060EAE74D451C4F40C632FD12F1EE4C40
20288	Ясашная	6	56	481	61.158921999999997	61.189230999999999	57.947265999999999	57.933489000000002	0103000020E61000000100000005000000B54E5C8E57944E407F164B917CF74C40B54E5C8E57944E406E4E250340F94C40D731AEB838984E406E4E250340F94C40D731AEB838984E407F164B917CF74C40B54E5C8E57944E407F164B917CF74C40
47956	Ярославское	6	56	481	62.068044	62.083736999999999	57.778775000000003	57.768307	0103000020E61000000100000005000000325871AAB5084F40D9243FE257E24C40325871AAB5084F40A1F831E6AEE34C408A3BDEE4B70A4F40A1F831E6AEE34C408A3BDEE4B70A4F40D9243FE257E24C40325871AAB5084F40D9243FE257E24C40
19522	Ялунинское	6	56	481	61.976694000000002	62.006858999999999	57.749619000000003	57.739364000000002	0103000020E6100000010000000500000087191A4F04FD4E407DEBC37AA3DE4C4087191A4F04FD4E40E9BAF083F3DF4C40755776C1E0004F40E9BAF083F3DF4C40755776C1E0004F407DEBC37AA3DE4C4087191A4F04FD4E407DEBC37AA3DE4C40
19210	Хабарчиха	6	56	481	61.740194000000002	61.754593999999997	58.524816000000001	58.515093	0103000020E6100000010000000500000004594FADBEDE4E4003B34291EE414D4004594FADBEDE4E407235B22B2D434D4000E1438996E04E407235B22B2D434D4000E1438996E04E4003B34291EE414D4004594FADBEDE4E4003B34291EE414D40
50226	Фоминское	6	56	481	62.183953000000002	62.202835999999998	58.501505999999999	58.495294000000001	0103000020E6100000010000000500000024809BC58B174F40D8F335CB653F4D4024809BC58B174F40B75F3E5931404D40C939B187F6194F40B75F3E5931404D40C939B187F6194F40D8F335CB653F4D4024809BC58B174F40D8F335CB653F4D40
30324	Толмачёво	6	56	481	61.785190999999998	61.804900000000004	57.881315000000001	57.865955999999997	0103000020E61000000100000005000000880E812381E44E4032E36DA5D7EE4C40880E812381E44E40B43C0FEECEF04C40744694F606E74E40B43C0FEECEF04C40744694F606E74E4032E36DA5D7EE4C40880E812381E44E4032E36DA5D7EE4C40
29977	Строкинка	6	56	481	61.928589000000002	61.946618000000001	58.164678000000002	58.155016000000003	0103000020E6100000010000000500000072361D01DCF64E40AA2D7590D7134D4072361D01DCF64E40732F302B14154D4008E753C72AF94E40732F302B14154D4008E753C72AF94E40AA2D7590D7134D4072361D01DCF64E40AA2D7590D7134D40
9008	Санкино	6	56	481	62.584476000000002	62.608263000000001	58.479677000000002	58.466199000000003	0103000020E6100000010000000500000001A60C1CD04A4F40C636A968AC3B4D4001A60C1CD04A4F405BD2510E663D4D40F52EDE8FDB4D4F405BD2510E663D4D40F52EDE8FDB4D4F40C636A968AC3B4D4001A60C1CD04A4F40C636A968AC3B4D40
29787	Самоцвет	6	56	481	61.771528000000004	61.788102000000002	57.610999	57.597332999999999	0103000020E6100000010000000500000062F9F36DC1E24E4029E9616875CC4C4062F9F36DC1E24E40C171193735CE4C40C3F4BD86E0E44E40C171193735CE4C40C3F4BD86E0E44E4029E9616875CC4C4062F9F36DC1E24E4029E9616875CC4C40
50157	Раскатиха	6	56	481	61.715203000000002	61.747613999999999	57.564979999999998	57.550320999999997	0103000020E6100000010000000500000024809BC58BDB4E40A8A624EB70C64C4024809BC58BDB4E407172BF4351C84C401004C8D0B1DF4E407172BF4351C84C401004C8D0B1DF4E40A8A624EB70C64C4024809BC58BDB4E40A8A624EB70C64C40
61327	Первунова	6	56	481	62.213669000000003	62.231527999999997	57.963779000000002	57.956063999999998	0103000020E61000000100000005000000A3957B81591B4F4004711E4E60FA4C40A3957B81591B4F402AC93A1C5DFB4C40DC0DA2B5A21D4F402AC93A1C5DFB4C40DC0DA2B5A21D4F4004711E4E60FA4C40A3957B81591B4F4004711E4E60FA4C40
30412	Нижняя Синячиха	6	56	481	61.752079000000002	61.791882999999999	57.956111	57.941868999999997	0103000020E610000001000000050000001381EA1F44E04E40E00ED4298FF84C401381EA1F44E04E40452C62D861FA4C4012A1116C5CE54E40452C62D861FA4C4012A1116C5CE54E40E00ED4298FF84C401381EA1F44E04E40E00ED4298FF84C40
19406	Невьянское	6	56	481	62.249324000000001	62.275312	57.926206000000001	57.913639000000003	0103000020E61000000100000005000000D00D4DD9E91F4F40D2AC6C1FF2F44C40D00D4DD9E91F4F40F3AD0FEB8DF64C402219726C3D234F40F3AD0FEB8DF64C402219726C3D234F40D2AC6C1FF2F44C40D00D4DD9E91F4F40D2AC6C1FF2F44C40
21925	Муратково	6	56	481	62.388086000000001	62.408667000000001	58.440773	58.429245000000002	0103000020E610000001000000050000008A0453CDAC314F405B7C0A80F1364D408A0453CDAC314F40DBFAE93F6B384D402BFA43334F344F40DBFAE93F6B384D402BFA43334F344F405B7C0A80F1364D408A0453CDAC314F405B7C0A80F1364D40
49980	Мугайское	6	56	481	61.555518999999997	61.596338000000003	58.397340999999997	58.371203999999999	0103000020E610000001000000050000003FA7203F1BC74E407B12D89C832F4D403FA7203F1BC74E40122EE411DC324D4058AEB7CD54CC4E40122EE411DC324D4058AEB7CD54CC4E407B12D89C832F4D403FA7203F1BC74E407B12D89C832F4D40
21345	Михалёва	6	56	481	62.35342	62.378096999999997	57.93627	57.928398999999999	0103000020E610000001000000050000004CE0D6DD3C2D4F40CE5147C7D5F64C404CE0D6DD3C2D4F40EB1C03B2D7F74C409CDB847B65304F40EB1C03B2D7F74C409CDB847B65304F40CE5147C7D5F64C404CE0D6DD3C2D4F40CE5147C7D5F64C40
30722	Махнёво	6	56	481	61.682899999999997	61.736196999999997	58.471400000000003	58.440114000000001	0103000020E610000001000000050000001D38674469D74E408141D2A755384D401D38674469D74E40CEAACFD5563C4D40E7340BB43BDE4E40CEAACFD5563C4D40E7340BB43BDE4E408141D2A755384D401D38674469D74E408141D2A755384D40
61304	Курорт Самоцвет	6	56	481	61.747767000000003	61.760621999999998	57.585881000000001	57.575797000000001	0103000020E6100000010000000500000097033DD4B6DF4E40451152B7B3C94C4097033DD4B6DF4E40842C0B26FECA4C401E4FCB0F5CE14E40842C0B26FECA4C401E4FCB0F5CE14E40451152B7B3C94C4097033DD4B6DF4E40451152B7B3C94C40
19729	Курорт ''Самоцвет''	6	56	481	61.747767000000003	61.760621999999998	57.585881000000001	57.575797000000001	0103000020E6100000010000000500000097033DD4B6DF4E40451152B7B3C94C4097033DD4B6DF4E40842C0B26FECA4C401E4FCB0F5CE14E40842C0B26FECA4C401E4FCB0F5CE14E40451152B7B3C94C4097033DD4B6DF4E40451152B7B3C94C40
46879	Костино	6	56	481	62.145406000000001	62.177475999999999	57.856394999999999	57.841897000000003	0103000020E610000001000000050000003352EFA99C124F40DECCE847C3EB4C403352EFA99C124F409DBAF2599EED4C4096E99788B7164F409DBAF2599EED4C4096E99788B7164F40DECCE847C3EB4C403352EFA99C124F40DECCE847C3EB4C40
47067	Коптелово	6	56	481	61.844057999999997	61.882675999999996	57.711906999999997	57.702824	0103000020E61000000100000005000000ADF6B0170AEC4E40056C0723F6D94C40ADF6B0170AEC4E409065C1C41FDB4C40677BF486FBF04E409065C1C41FDB4C40677BF486FBF04E40056C0723F6D94C40ADF6B0170AEC4E40056C0723F6D94C40
49027	Кокшарова	6	56	481	61.784778000000003	61.798440999999997	58.446891000000001	58.43985	0103000020E61000000100000005000000664F029B73E44E40A3923A014D384D40664F029B73E44E4039F06AB933394D408C648F5033E64E4039F06AB933394D408C648F5033E64E40A3923A014D384D40664F029B73E44E40A3923A014D384D40
14776	Клевакино	6	56	481	62.106186000000001	62.12276	57.819164000000001	57.806080000000001	0103000020E6100000010000000500000083A5BA80970D4F40D7FA22A12DE74C4083A5BA80970D4F40C007AF5DDAE84C40E4A08499B60F4F40C007AF5DDAE84C40E4A08499B60F4F40D7FA22A12DE74C4083A5BA80970D4F40D7FA22A12DE74C40
31165	Кишкинское	6	56	481	61.872785999999998	61.896985999999998	58.464593999999998	58.457712000000001	0103000020E610000001000000050000000D349F73B7EF4E404E7E8B4E963A4D400D349F73B7EF4E407BF5F1D0773B4D40247CEF6FD0F24E407BF5F1D0773B4D40247CEF6FD0F24E404E7E8B4E963A4D400D349F73B7EF4E404E7E8B4E963A4D40
45812	Кировское (Монастырское)	6	56	481	62.042585000000003	62.086378000000003	58.001871999999999	57.990814999999998	0103000020E610000001000000050000006C26DF6C73054F4070B1A206D3FE4C406C26DF6C73054F40996379573D004D40058C2E6F0E0B4F40996379573D004D40058C2E6F0E0B4F4070B1A206D3FE4C406C26DF6C73054F4070B1A206D3FE4C40
11671	Катышка	6	56	481	61.734203000000001	61.755043999999998	57.652389999999997	57.641539000000002	0103000020E6100000010000000500000003D0285DFADD4E40E50D30F31DD24C4003D0285DFADD4E40641EF98381D34C4040852348A5E04E40641EF98381D34C4040852348A5E04E40E50D30F31DD24C4003D0285DFADD4E40E50D30F31DD24C40
9796	Измоденово	6	56	481	61.694650000000003	61.717286999999999	58.236294999999998	58.221145	0103000020E610000001000000050000004D158C4AEAD84E404356B77A4E1C4D404D158C4AEAD84E40AA9A20EA3E1E4D40486C770FD0DB4E40AA9A20EA3E1E4D40486C770FD0DB4E404356B77A4E1C4D404D158C4AEAD84E404356B77A4E1C4D40
47443	Заря	6	56	481	61.722569	61.738720999999998	57.873108000000002	57.861781000000001	0103000020E610000001000000050000003D0D18247DDC4E4037A8FDD64EEE4C403D0D18247DDC4E4020F0C000C2EF4C4028EFE3688EDE4E4020F0C000C2EF4C4028EFE3688EDE4E4037A8FDD64EEE4C403D0D18247DDC4E4037A8FDD64EEE4C40
29934	Ельничная	6	56	481	61.874366999999999	61.893627000000002	58.119155999999997	58.105701000000003	0103000020E61000000100000005000000CFD90242EBEF4E40C713419C870D4D40CFD90242EBEF4E40A38FF980400F4D404BE9995E62F24E40A38FF980400F4D404BE9995E62F24E40C713419C870D4D40CFD90242EBEF4E40C713419C870D4D40
47649	Деево	6	56	481	61.645620000000001	61.687894	57.575184	57.561041000000003	0103000020E610000001000000050000005FD218ADA3D24E408A5B0531D0C74C405FD218ADA3D24E405B971AA19FC94C40AC8E1CE90CD84E405B971AA19FC94C40AC8E1CE90CD84E408A5B0531D0C74C405FD218ADA3D24E408A5B0531D0C74C40
16063	Голубковское	6	56	481	62.488014999999997	62.521054999999997	57.948493999999997	57.938552999999999	0103000020E610000001000000050000008D7A8846773E4F400648348122F84C408D7A8846773E4F40E2395B4068F94C40693524EEB1424F40E2395B4068F94C40693524EEB1424F400648348122F84C408D7A8846773E4F400648348122F84C40
19275	Гаранинка	6	56	481	62.416428000000003	62.440269000000001	58.030985000000001	58.020733	0103000020E61000000100000005000000C19140834D354F4057790261A7024D40C19140834D354F4052D50451F7034D40A8380EBC5A384F4052D50451F7034D40A8380EBC5A384F4057790261A7024D40C19140834D354F4057790261A7024D40
2870	Вогулка	6	56	481	62.054380000000002	62.072417999999999	57.751309999999997	57.741261000000002	0103000020E610000001000000050000003BC780ECF5064F406F66F4A3E1DE4C403BC780ECF5064F40319413ED2AE04C4024D236FE44094F40319413ED2AE04C4024D236FE44094F406F66F4A3E1DE4C403BC780ECF5064F406F66F4A3E1DE4C40
19942	Верхняя Синячиха	6	56	481	61.640732999999997	61.706606000000001	58.012332999999998	57.968066	0103000020E61000000100000005000000E63BF88903D24E404D2F3196E9FB4C40E63BF88903D24E40AED4B32094014D402594BE1072DA4E40AED4B32094014D402594BE1072DA4E404D2F3196E9FB4C40E63BF88903D24E404D2F3196E9FB4C40
10502	Бутакова	6	56	481	62.148145999999997	62.166885000000001	57.824128999999999	57.809483999999998	0103000020E610000001000000050000004084B872F6124F405051F52B9DE74C404084B872F6124F40B4571F0F7DE94C40B398D87C5C154F40B4571F0F7DE94C40B398D87C5C154F405051F52B9DE74C404084B872F6124F405051F52B9DE74C40
20293	Бубчиково	6	56	481	61.706364000000001	61.725884000000001	58.146230000000003	58.126114000000001	0103000020E610000001000000050000002F89B3226ADA4E40ACC8E88024104D402F89B3226ADA4E40D8D825AAB7124D40475854C4E9DC4E40D8D825AAB7124D40475854C4E9DC4E40ACC8E88024104D402F89B3226ADA4E40ACC8E88024104D40
31025	Большая Ерзовка	6	56	481	61.783555999999997	61.794218999999998	58.428730999999999	58.422260999999999	0103000020E61000000100000005000000D34A21904BE44E4029B000A60C364D40D34A21904BE44E4004E44BA8E0364D40506EDBF7A8E54E4004E44BA8E0364D40506EDBF7A8E54E4029B000A60C364D40D34A21904BE44E4029B000A60C364D40
19834	Болотовское	6	56	481	62.454228999999998	62.468459000000003	58.525004000000003	58.518773000000003	0103000020E6100000010000000500000088F2052D243A4F401F86562767424D4088F2052D243A4F407522C15433434D402942EA76F63B4F407522C15433434D402942EA76F63B4F401F86562767424D4088F2052D243A4F401F86562767424D40
50216	Бобровка	6	56	481	62.160265000000003	62.187905999999998	57.992789999999999	57.985895999999997	0103000020E61000000100000005000000C3D8429083144F40ECA012D731FE4C40C3D8429083144F40DEE522BE13FF4C40705CC64D0D184F40DEE522BE13FF4C40705CC64D0D184F40ECA012D731FE4C40C3D8429083144F40ECA012D731FE4C40
4039	Арамашево	6	56	481	61.716541999999997	61.743338000000001	57.614624999999997	57.597512000000002	0103000020E61000000100000005000000EF1AF4A5B7DB4E40D97BF1457BCC4C40EF1AF4A5B7DB4E40E9263108ACCE4C40E1EF17B325DF4E40E9263108ACCE4C40E1EF17B325DF4E40D97BF1457BCC4C40EF1AF4A5B7DB4E40D97BF1457BCC4C40
50201	Калач	6	56	7035	63.015757000000001	63.050935000000003	58.554271	58.547716999999999	0103000020E610000001000000050000006FD74B5304824F404B3B35971B464D406FD74B5304824F40840F255AF2464D40639CBF0985864F40840F255AF2464D40639CBF0985864F404B3B35971B464D406FD74B5304824F404B3B35971B464D40
61092	Покровское	6	56	7071	60.225445999999998	60.291347000000002	57.979889	57.955987	0103000020E61000000100000005000000CB811E6ADB1C4E40593332C85DFA4C40CB811E6ADB1C4E40E65AB4006DFD4C40D464C6DB4A254E40E65AB4006DFD4C40D464C6DB4A254E40593332C85DFA4C40CB811E6ADB1C4E40593332C85DFA4C40
60715	урган	6	55	\N	65.117329999999995	65.669937000000004	55.533313	55.290469999999999	0103000020E61000000100000005000000BD35B055824750400C3CF71E2EA54B40BD35B055824750400DC4B29943C44B405858703FE06A50400DC4B29943C44B405858703FE06A50400C3CF71E2EA54B40BD35B055824750400C3CF71E2EA54B40
54993	Юргамыш	6	55	\N	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
54952	Щучье	6	55	\N	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
54925	Шумиха	6	55	\N	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
54957	Шадринск	6	55	\N	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
1010	Шадринск	6	55	\N	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
54920	Целинное	6	55	\N	63.650317999999999	63.702168999999998	54.517440999999998	54.491579000000002	0103000020E610000001000000050000000400C79E3DD34F404033880FEC3E4B400400C79E3DD34F40054EB6813B424B40ECA17DACE0D94F40054EB6813B424B40ECA17DACE0D94F404033880FEC3E4B400400C79E3DD34F404033880FEC3E4B40
54919	Петухово	6	55	\N	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
54918	Макушино	6	55	\N	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
55032	Лесниково	6	55	\N	65.309685999999999	65.332601999999994	55.298302	55.279384999999998	0103000020E61000000100000005000000DC813AE5D153504019FF3EE3C2A34B40DC813AE5D15350406B2A8BC22EA64B406325E659495550406B2A8BC22EA64B406325E6594955504019FF3EE3C2A34B40DC813AE5D153504019FF3EE3C2A34B40
54979	Лебяжье	6	55	\N	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
54914	Куртамыш	6	55	\N	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
1331	Курган	6	55	\N	65.191198	65.585279999999997	55.509390000000003	55.318429000000002	0103000020E61000000100000005000000E14389963C4C50408B8C0E48C2A84B40E14389963C4C5040697407B133C14B402FC03E3A75655040697407B133C14B402FC03E3A756550408B8C0E48C2A84B40E14389963C4C50408B8C0E48C2A84B40
55024	Курган	6	55	\N	65.117329999999995	65.669937000000004	55.533313	55.290469999999999	0103000020E61000000100000005000000BD35B055824750400C3CF71E2EA54B40BD35B055824750400DC4B29943C44B405858703FE06A50400DC4B29943C44B405858703FE06A50400C3CF71E2EA54B40BD35B055824750400C3CF71E2EA54B40
54936	Катайск	6	55	\N	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
54987	Каргаполье	6	55	\N	64.198228	64.225896000000006	55.871232999999997	55.856022000000003	0103000020E61000000100000005000000B2497EC4AF0C50400954FF2092ED4B40B2497EC4AF0C504015191D9084EF4B4006137F14750E504015191D9084EF4B4006137F14750E50400954FF2092ED4B40B2497EC4AF0C50400954FF2092ED4B40
54933	Далматово	6	55	\N	62.890999000000001	62.975772999999997	56.278582999999998	56.248226000000003	0103000020E6100000010000000500000065E256410C724F402A029CDEC51F4C4065E256410C724F405C1C959BA8234C40EFA83121E67C4F405C1C959BA8234C40EFA83121E67C4F402A029CDEC51F4C4065E256410C724F402A029CDEC51F4C40
54961	Введенское	6	55	\N	65.092680000000001	65.151680999999996	55.437055999999998	55.424255000000002	0103000020E61000000100000005000000923F1878EE4550400E15E3FC4DB64B40923F1878EE455040A2427573F1B74B402C9B3924B5495040A2427573F1B74B402C9B3924B54950400E15E3FC4DB64B40923F1878EE4550400E15E3FC4DB64B40
52056	Большое Чаусово	6	55	\N	65.366343000000001	65.397379999999998	55.515287999999998	55.499132000000003	0103000020E610000001000000050000009607E929725750408C31B08EE3BF4B409607E92972575040B8020AF5F4C14B40680586AC6E595040B8020AF5F4C14B40680586AC6E5950408C31B08EE3BF4B409607E929725750408C31B08EE3BF4B40
12223	сельского типа Кипель	6	55	1124	64.507058999999998	64.541877999999997	55.285271000000002	55.271759000000003	0103000020E610000001000000050000001E8997A77320504064B2B8FFC8A24B401E8997A773205040A5BF97C283A44B40001B1021AE225040A5BF97C283A44B40001B1021AE22504064B2B8FFC8A24B401E8997A77320504064B2B8FFC8A24B40
54976	Юргамыш	6	55	1124	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
10234	Юргамыш	6	55	1124	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
12472	Шемелино	6	55	1124	64.283011000000002	64.302603000000005	55.575943000000002	55.564602000000001	0103000020E61000000100000005000000215A2BDA1C125040CBA0DAE044C84B40215A2BDA1C12504019AE0E80B8C94B40FA2AF9D85D13504019AE0E80B8C94B40FA2AF9D85D135040CBA0DAE044C84B40215A2BDA1C125040CBA0DAE044C84B40
13056	Чинеево	6	55	1124	64.634225000000001	64.656323	55.482484999999997	55.467509	0103000020E610000001000000050000008F53742497285040F7CABC55D7BB4B408F53742497285040C0E78711C2BD4B4035272F32012A5040C0E78711C2BD4B4035272F32012A5040F7CABC55D7BB4B408F53742497285040F7CABC55D7BB4B40
12959	Фадюшино	6	55	1124	64.182937999999993	64.222464000000002	55.610168000000002	55.604188000000001	0103000020E6100000010000000500000085CC9541B50B50405D514A0856CD4B4085CC9541B50B50406A882AFC19CE4B406422A5D93C0E50406A882AFC19CE4B406422A5D93C0E50405D514A0856CD4B4085CC9541B50B50405D514A0856CD4B40
11884	Туманова	6	55	1124	64.030861999999999	64.047561999999999	55.519626000000002	55.512892999999998	0103000020E610000001000000050000001B2C9CA4F901504075AC527AA6C14B401B2C9CA4F90150405E13D21A83C24B4012A27C410B0350405E13D21A83C24B4012A27C410B03504075AC527AA6C14B401B2C9CA4F901504075AC527AA6C14B40
12895	Таловка	6	55	1124	64.310122000000007	64.328699	55.207048	55.195127999999997	0103000020E610000001000000050000004AF1F109D913504056444DF4F9984B404AF1F109D9135040E259828C809A4B4096CE876709155040E259828C809A4B4096CE87670915504056444DF4F9984B404AF1F109D913504056444DF4F9984B40
12878	Скоблино	6	55	1124	64.307543999999993	64.335688000000005	55.161296	55.152439000000001	0103000020E610000001000000050000002F8507CDAE13504046D1031F83934B402F8507CDAE135040E17CEA58A5944B40386A85E97B155040E17CEA58A5944B40386A85E97B15504046D1031F83934B402F8507CDAE13504046D1031F83934B40
12173	Редуть	6	55	1124	64.219139999999996	64.233540000000005	55.493654999999997	55.486795000000001	0103000020E61000000100000005000000B54FC763060E50409C6D6E4C4FBE4B40B54FC763060E5040E140481630BF4B40B493C151F20E5040E140481630BF4B40B493C151F20E50409C6D6E4C4FBE4B40B54FC763060E50409C6D6E4C4FBE4B40
12599	Раздольная	6	55	1124	64.447536999999997	64.459089000000006	55.343890999999999	55.336087999999997	0103000020E61000000100000005000000FFAF3A72A41C5040FD497CEE04AB4B40FFAF3A72A41C5040C231CB9E04AC4B40043DD4B6611D5040C231CB9E04AC4B40043DD4B6611D5040FD497CEE04AB4B40FFAF3A72A41C5040FD497CEE04AB4B40
12977	Плотникова	6	55	1124	64.116812999999993	64.134626999999995	55.651201	55.641508000000002	0103000020E61000000100000005000000D9AF3BDD79075040AA0F24EF1CD24B40D9AF3BDD79075040AE0FEB8D5AD34B40268A90BA9D085040AE0FEB8D5AD34B40268A90BA9D085040AA0F24EF1CD24B40D9AF3BDD79075040AA0F24EF1CD24B40
12565	Петровское	6	55	1124	64.369617000000005	64.389757000000003	55.297918000000003	55.282173999999998	0103000020E61000000100000005000000ECC20FCEA717504008E412471EA44B40ECC20FCEA7175040E371512D22A64B40C61858C7F1185040E371512D22A64B40C61858C7F118504008E412471EA44B40ECC20FCEA717504008E412471EA44B40
12819	Пески	6	55	1124	64.229776000000001	64.250698	55.195663000000003	55.185794999999999	0103000020E61000000100000005000000F75965A6B40E504052616C21C8974B40F75965A6B40E5040C504357C0B994B400CCB9F6F0B105040C504357C0B994B400CCB9F6F0B10504052616C21C8974B40F75965A6B40E504052616C21C8974B40
12265	Падун	6	55	1124	64.612449999999995	64.636111	55.173338999999999	55.167616000000002	0103000020E61000000100000005000000DA1B7C6132275040A724EB7074954B40DA1B7C6132275040880FECF82F964B400E68E90AB6285040880FECF82F964B400E68E90AB6285040A724EB7074954B40DA1B7C6132275040A724EB7074954B40
11995	Норильное	6	55	1124	64.497636	64.506529	55.078854	55.068179999999998	0103000020E61000000100000005000000FC53AA44D91F5040E21E4B1FBA884B40FC53AA44D91F504053944BE3178A4B40705E9CF86A20504053944BE3178A4B40705E9CF86A205040E21E4B1FBA884B40FC53AA44D91F5040E21E4B1FBA884B40
54954	Новый Мир	6	55	1124	64.486102000000002	64.506619000000001	55.339094000000003	55.330762999999997	0103000020E610000001000000050000004B21904B1C1F504009DD257156AA4B404B21904B1C1F50408A22A46E67AB4B40102219726C2050408A22A46E67AB4B40102219726C20504009DD257156AA4B404B21904B1C1F504009DD257156AA4B40
13109	Новая Заворина	6	55	1124	64.760626999999999	64.785330000000002	55.432464000000003	55.428322000000001	0103000020E61000000100000005000000185DDE1CAE30504023145B41D3B64B40185DDE1CAE3050404359F8FA5AB74B4055A4C2D8423250404359F8FA5AB74B4055A4C2D84232504023145B41D3B64B40185DDE1CAE30504023145B41D3B64B40
13474	Нива	6	55	1124	64.414901	64.420201000000006	55.362428999999999	55.358733999999998	0103000020E61000000100000005000000F984ECBC8D1A50404CFBE6FEEAAD4B40F984ECBC8D1A50409D0FCF1264AE4B40C72FBC92E41A50409D0FCF1264AE4B40C72FBC92E41A50404CFBE6FEEAAD4B40F984ECBC8D1A50404CFBE6FEEAAD4B40
12683	Малое Белое	6	55	1124	64.407929999999993	64.424880999999999	55.429844000000003	55.420121999999999	0103000020E61000000100000005000000AA436E861B1A5040412AC58EC6B54B40AA436E861B1A5040E030D12005B74B4046EC1340311B5040E030D12005B74B4046EC1340311B5040412AC58EC6B54B40AA436E861B1A5040412AC58EC6B54B40
12422	Кулаш	6	55	1124	64.305316000000005	64.320640999999995	55.677442999999997	55.668666000000002	0103000020E6100000010000000500000084BC1E4C8A1350403CF9F4D896D54B4084BC1E4C8A135040BAF3C473B6D64B406E30D46185145040BAF3C473B6D64B406E30D461851450403CF9F4D896D54B4084BC1E4C8A1350403CF9F4D896D54B40
12490	Красный Уралец	6	55	1124	64.394994999999994	64.435463999999996	55.305050999999999	55.291003000000003	0103000020E6100000010000000500000058C51B9947195040DA0418963FA54B4058C51B9947195040594E42E90BA74B4076A565A4DE1B5040594E42E90BA74B4076A565A4DE1B5040DA0418963FA54B4058C51B9947195040DA0418963FA54B40
12321	Кислянское	6	55	1124	64.318439999999995	64.342963999999995	55.565263999999999	55.553279000000003	0103000020E610000001000000050000003F6F2A52611450402448A5D8D1C64B403F6F2A526114504096CD1C925AC84B4024ED461FF315504096CD1C925AC84B4024ED461FF31550402448A5D8D1C64B403F6F2A52611450402448A5D8D1C64B40
12132	Караси	6	55	1124	64.166589000000002	64.196961000000002	55.450277	55.421112999999998	0103000020E61000000100000005000000E5B7E864A90A5040D175E107E7B54B40E5B7E864A90A50400C923EADA2B94B4099654F029B0C50400C923EADA2B94B4099654F029B0C5040D175E107E7B54B40E5B7E864A90A5040D175E107E7B54B40
13137	Зырянка	6	55	1124	64.733614000000003	64.774066000000005	55.403446000000002	55.389581	0103000020E61000000100000005000000D1782288F32E50404D124BCADDB14B40D1782288F32E5040DCD9571EA4B34B4084BC1E4C8A315040DCD9571EA4B34B4084BC1E4C8A3150404D124BCADDB14B40D1782288F32E50404D124BCADDB14B40
12090	Ерохина	6	55	1124	64.657482000000002	64.664479999999998	55.246701999999999	55.239584000000001	0103000020E610000001000000050000005BED612F142A50408B5242B0AA9E4B405BED612F142A5040CCED5EEE939F4B4026361FD7862A5040CCED5EEE939F4B4026361FD7862A50408B5242B0AA9E4B405BED612F142A50408B5242B0AA9E4B40
12722	Губерля	6	55	1124	64.596288999999999	64.608542	55.564816	55.560606	0103000020E61000000100000005000000BB7D5699292650407FF8F9EFC1C74B40BB7D569929265040F72004E44BC84B40840F255AF2265040F72004E44BC84B40840F255AF22650407FF8F9EFC1C74B40BB7D5699292650407FF8F9EFC1C74B40
54926	Горохово	6	55	1124	64.613788	64.648122000000001	55.275888000000002	55.264296000000002	0103000020E6100000010000000500000058AB764D48275040583B8A73D4A14B4058AB764D48275040EFAD484C50A34B405C74B2D47A295040EFAD484C50A34B405C74B2D47A295040583B8A73D4A14B4058AB764D48275040583B8A73D4A14B40
11943	Гагарье	6	55	1124	64.484530000000007	64.527360999999999	55.130409999999998	55.117319000000002	0103000020E6100000010000000500000094FB1D8A021F504087191A4F048F4B4094FB1D8A021F504022895E46B1904B40E50B5A48C021504022895E46B1904B40E50B5A48C021504087191A4F048F4B4094FB1D8A021F504087191A4F048F4B40
12787	Вохменка	6	55	1124	64.584135000000003	64.597213999999994	55.587722999999997	55.579185000000003	0103000020E61000000100000005000000BC5CC47762255040B9AAECBB22CA4B40BC5CC47762255040B20DDC813ACB4B40A7AD11C138265040B20DDC813ACB4B40A7AD11C138265040B9AAECBB22CA4B40BC5CC47762255040B9AAECBB22CA4B40
11824	Вилкино	6	55	1124	64.118475000000004	64.136927	55.550203000000003	55.535595000000001	0103000020E6100000010000000500000031992A1895075040587380608EC44B4031992A18950750409F94490D6DC64B401FBC7669C30850409F94490D6DC64B401FBC7669C3085040587380608EC44B4031992A1895075040587380608EC44B40
10299	Яковлевка	6	55	1058	62.344410000000003	62.364362	55.157670000000003	55.146070000000002	0103000020E610000001000000050000002B357BA0152C4F409F76F86BB2924B402B357BA0152C4F40B9C7D2872E944B40DCF3FC69A32E4F40B9C7D2872E944B40DCF3FC69A32E4F409F76F86BB2924B402B357BA0152C4F409F76F86BB2924B40
54974	Чумляк	6	55	1058	62.668244000000001	62.688797000000001	55.311508000000003	55.299855000000001	0103000020E61000000100000005000000C6DFF60489554F4063450DA661A64B40C6DFF60489554F40A038807EDFA74B409D4A06802A584F40A038807EDFA74B409D4A06802A584F4063450DA661A64B40C6DFF60489554F4063450DA661A64B40
11637	Чудняково	6	55	1058	62.618693	62.637557000000001	55.578766999999999	55.568313000000003	0103000020E61000000100000005000000CFA10C55314F4F402272FA7ABEC84B40CFA10C55314F4F4084807C0915CA4B40FE2AC0779B514F4084807C0915CA4B40FE2AC0779B514F402272FA7ABEC84B40CFA10C55314F4F402272FA7ABEC84B40
10147	Чистое	6	55	1058	62.478510999999997	62.502369999999999	55.163877999999997	55.146887999999997	0103000020E610000001000000050000005CE333D93F3D4F406116DA39CD924B405CE333D93F3D4F4056444DF4F9944B40EA3E00A94D404F4056444DF4F9944B40EA3E00A94D404F406116DA39CD924B405CE333D93F3D4F406116DA39CD924B40
10855	Чесноковка 1-я	6	55	1058	62.262349	62.267209000000001	55.353898000000001	55.344208000000002	0103000020E61000000100000005000000B491EBA694214F40C382FB010FAC4B40B491EBA694214F40560F98874CAD4B4033198EE733224F40560F98874CAD4B4033198EE733224F40C382FB010FAC4B40B491EBA694214F40C382FB010FAC4B40
11706	Чердаки	6	55	1058	62.609278000000003	62.622312999999998	55.615943999999999	55.606440999999997	0103000020E610000001000000050000000E164ED2FC4D4F400DFAD2DB9FCD4B400E164ED2FC4D4F406E15C440D7CE4B401570CFF3A74F4F406E15C440D7CE4B401570CFF3A74F4F400DFAD2DB9FCD4B400E164ED2FC4D4F400DFAD2DB9FCD4B40
11798	Утичье	6	55	1058	62.816789	62.841375999999997	55.706435999999997	55.697944999999997	0103000020E61000000100000005000000C45DBD8A8C684F400FB4024356D94B40C45DBD8A8C684F40C85BAE7E6CDA4B40D4D17135B26B4F40C85BAE7E6CDA4B40D4D17135B26B4F400FB4024356D94B40C45DBD8A8C684F400FB4024356D94B40
9927	Тунгуй	6	55	1058	62.84037	62.855317999999997	55.065415999999999	55.055424000000002	0103000020E610000001000000050000000F45813E916B4F40EEB4352218874B400F45813E916B4F404C512E8D5F884B400ED76A0F7B6D4F404C512E8D5F884B400ED76A0F7B6D4F40EEB4352218874B400F45813E916B4F40EEB4352218874B40
9996	Сухоборское	6	55	1058	62.676777999999999	62.700313999999999	55.152377000000001	55.138669999999998	0103000020E610000001000000050000007E5358A9A0564F40D97745F0BF914B407E5358A9A0564F40D0D4EB1681934B4029779FE3A3594F40D0D4EB1681934B4029779FE3A3594F40D97745F0BF914B407E5358A9A0564F40D97745F0BF914B40
10679	Советская	6	55	1058	62.620776999999997	62.657231000000003	55.32414	55.319719999999997	0103000020E61000000100000005000000F38DE89E754F4F4045F0BF95ECA84B40F38DE89E754F4F40A8A9656B7DA94B406D75392520544F40A8A9656B7DA94B406D75392520544F4045F0BF95ECA84B40F38DE89E754F4F4045F0BF95ECA84B40
11393	Пуктыш	6	55	1058	62.689318	62.717570000000002	55.476388	55.469836000000001	0103000020E61000000100000005000000A6457D923B584F40E23D079623BC4B40A6457D923B584F407A1A3048FABC4B409D4B7155D95B4F407A1A3048FABC4B409D4B7155D95B4F40E23D079623BC4B40A6457D923B584F40E23D079623BC4B40
54962	Плановый	6	55	1058	62.711857000000002	62.745570999999998	55.270609999999998	55.259818000000003	0103000020E61000000100000005000000DF3653211E5B4F40C1745AB741A14B40DF3653211E5B4F403BFC3559A3A24B404AECDADE6E5F4F403BFC3559A3A24B404AECDADE6E5F4F40C1745AB741A14B40DF3653211E5B4F40C1745AB741A14B40
10999	Пивкино	6	55	1058	62.360264999999998	62.387987000000003	55.269559000000001	55.254451000000003	0103000020E610000001000000050000005C72DC291D2E4F409EB7B1D991A04B405C72DC291D2E4F40D6ABC8E880A24B40F722DA8EA9314F40D6ABC8E880A24B40F722DA8EA9314F409EB7B1D991A04B405C72DC291D2E4F409EB7B1D991A04B40
11220	Петрушино	6	55	1058	62.499262000000002	62.517183000000003	55.272257000000003	55.263865000000003	0103000020E610000001000000050000005A1135D1E73F4F408FC70C54C6A14B405A1135D1E73F4F40B58D3F51D9A24B400A86730D33424F40B58D3F51D9A24B400A86730D33424F408FC70C54C6A14B405A1135D1E73F4F408FC70C54C6A14B40
11306	Петровское	6	55	1058	62.792445000000001	62.812837000000002	55.37238	55.359538000000001	0103000020E610000001000000050000007A7077D66E654F40AAD5575705AE4B407A7077D66E654F409DD7D825AAAF4B4048FDF50A0B684F409DD7D825AAAF4B4048FDF50A0B684F40AAD5575705AE4B407A7077D66E654F40AAD5575705AE4B40
54994	Песчанское	6	55	1058	62.688088	62.733047999999997	55.707101000000002	55.668512999999997	0103000020E610000001000000050000009162804413584F40B5F97FD591D54B409162804413584F4005FC1A4982DA4B40F8325184D45D4F4005FC1A4982DA4B40F8325184D45D4F40B5F97FD591D54B409162804413584F40B5F97FD591D54B40
10367	Отрадное	6	55	1058	62.851913000000003	62.870229999999999	55.279862000000001	55.273457000000001	0103000020E61000000100000005000000C504357C0B6D4F405FEE93A300A34B40C504357C0B6D4F4053B29C84D2A34B40C1FF56B2636F4F4053B29C84D2A34B40C1FF56B2636F4F405FEE93A300A34B40C504357C0B6D4F405FEE93A300A34B40
9836	Нифанка	6	55	1058	62.773625000000003	62.789893999999997	55.198082999999997	55.178794000000003	0103000020E610000001000000050000001B2FDD2406634F404B5CC7B8E2964B401B2FDD2406634F406072A3C85A994B403FA7203F1B654F406072A3C85A994B403FA7203F1B654F404B5CC7B8E2964B401B2FDD2406634F404B5CC7B8E2964B40
11576	Николаевка	6	55	1058	62.741052000000003	62.776518000000003	55.574497999999998	55.562244999999997	0103000020E610000001000000050000005551BCCADA5E4F4075ABE7A4F7C74B405551BCCADA5E4F4007CF842689C94B40AF601BF164634F4007CF842689C94B40AF601BF164634F4075ABE7A4F7C74B405551BCCADA5E4F4075ABE7A4F7C74B40
11549	Никитино	6	55	1058	62.617713999999999	62.629814000000003	55.468071000000002	55.458516000000003	0103000020E6100000010000000500000003249A40114F4F40AC58FCA6B0BA4B4003249A40114F4F405F9A22C0E9BB4B400F48C2BE9D504F405F9A22C0E9BB4B400F48C2BE9D504F40AC58FCA6B0BA4B4003249A40114F4F40AC58FCA6B0BA4B40
11492	Михайловка	6	55	1058	62.485841000000001	62.507750999999999	55.445574000000001	55.431002999999997	0103000020E610000001000000050000002907B309303E4F402BBD361B2BB74B402907B309303E4F4055F99E9108B94B4072C119FCFD404F4055F99E9108B94B4072C119FCFD404F402BBD361B2BB74B402907B309303E4F402BBD361B2BB74B40
10462	Медведское	6	55	1058	62.972493999999998	62.992697	55.256242	55.234717000000003	0103000020E6100000010000000500000032C7F2AE7A7C4F405A68E7340B9E4B4032C7F2AE7A7C4F404AEEB089CCA04B402DEBFEB1107F4F404AEEB089CCA04B402DEBFEB1107F4F405A68E7340B9E4B4032C7F2AE7A7C4F405A68E7340B9E4B40
11064	Майка	6	55	1058	62.255414000000002	62.271825999999997	55.242508999999998	55.229537000000001	0103000020E610000001000000050000006478EC67B1204F40691CEA77619D4B406478EC67B1204F402AFEEF880A9F4B40EB19C231CB224F402AFEEF880A9F4B40EB19C231CB224F40691CEA77619D4B406478EC67B1204F40691CEA77619D4B40
10280	Курорт Озеро	6	55	1058	62.518737000000002	62.550358000000003	55.138413	55.131366999999997	0103000020E61000000100000005000000D21C59F965424F40066344A2D0904B40D21C59F965424F40AE2B6684B7914B40C68B852172464F40AE2B6684B7914B40C68B852172464F40066344A2D0904B40D21C59F965424F40066344A2D0904B40
11252	Куликово	6	55	1058	62.427360999999998	62.443530000000003	55.32497	55.321446000000002	0103000020E61000000100000005000000FD4AE7C3B3364F400BB77C2425A94B40FD4AE7C3B3364F402F17F19D98A94B40BF654E97C5384F402F17F19D98A94B40BF654E97C5384F400BB77C2425A94B40FD4AE7C3B3364F400BB77C2425A94B40
10790	Красноярское	6	55	1058	62.446773	62.475887999999998	55.337905999999997	55.330266000000002	0103000020E610000001000000050000002FDE8FDB2F394F40897D022846AA4B402FDE8FDB2F394F40A38FF98040AB4B408847E2E5E93C4F40A38FF98040AB4B408847E2E5E93C4F40897D022846AA4B402FDE8FDB2F394F40897D022846AA4B40
10783	Косулино	6	55	1058	62.322958	62.341876999999997	55.330522000000002	55.320171000000002	0103000020E61000000100000005000000A4FD0FB056294F405610035DFBA84B40A4FD0FB056294F40E44D7E8B4EAA4B40962023A0C22B4F40E44D7E8B4EAA4B40962023A0C22B4F405610035DFBA84B40A4FD0FB056294F405610035DFBA84B40
9855	Козино	6	55	1058	62.651670000000003	62.669933	55.235025	55.222405000000002	0103000020E6100000010000000500000065E42CEC69534F40C3BB5CC4779C4B4065E42CEC69534F40075F984C159E4B406EC1525DC0554F40075F984C159E4B406EC1525DC0554F40C3BB5CC4779C4B4065E42CEC69534F40C3BB5CC4779C4B40
10595	Клюквенная	6	55	1058	62.936571000000001	62.969368000000003	55.218758999999999	55.209791000000003	0103000020E61000000100000005000000E6B0FB8EE1774F4061FF756EDA9A4B40E6B0FB8EE1774F40535A7F4B009C4B40FCE42840147C4F40535A7F4B009C4B40FCE42840147C4F4061FF756EDA9A4B40E6B0FB8EE1774F4061FF756EDA9A4B40
54992	Каясан	6	55	1058	62.220218000000003	62.260966000000003	55.212051000000002	55.200353999999997	0103000020E61000000100000005000000CAFE791A301C4F40B7CF2A33A5994B40CAFE791A301C4F40C40AB77C249B4B4019AF795567214F40C40AB77C249B4B4019AF795567214F40B7CF2A33A5994B40CAFE791A301C4F40B7CF2A33A5994B40
55045	Калмаково-Миасское	6	55	1058	62.800530000000002	62.842427000000001	55.326844999999999	55.321829999999999	0103000020E61000000100000005000000C3BB5CC477664F40936FB6B931A94B40C3BB5CC477664F4039EE940ED6A94B403A22DFA5D46B4F4039EE940ED6A94B403A22DFA5D46B4F40936FB6B931A94B40C3BB5CC477664F40936FB6B931A94B40
10446	Зайково	6	55	1058	62.869754	62.892670000000003	55.273707999999999	55.262161999999996	0103000020E6100000010000000500000058C85C19546F4F40812040868EA14B4058C85C19546F4F40A8531EDD08A34B40670FB40243724F40A8531EDD08A34B40670FB40243724F40812040868EA14B4058C85C19546F4F40812040868EA14B40
10078	Даньково	6	55	1058	62.681286999999998	62.696119000000003	55.108255999999997	55.096657	0103000020E610000001000000050000005018946934574F40F9F6AE415F8C4B405018946934574F4042CC2555DB8D4B40E78F696D1A594F4042CC2555DB8D4B40E78F696D1A594F40F9F6AE415F8C4B405018946934574F40F9F6AE415F8C4B40
9989	Варгановское	6	55	1058	62.947071999999999	62.969116999999997	55.125380999999997	55.116418000000003	0103000020E61000000100000005000000897AC1A739794F403755F7C8E68E4B40897AC1A739794F4017450F7C0C904B40B27F9E060C7C4F4017450F7C0C904B40B27F9E060C7C4F403755F7C8E68E4B40897AC1A739794F403755F7C8E68E4B40
10700	Белоярское	6	55	1058	62.351739999999999	62.390647000000001	55.333368999999998	55.324376000000001	0103000020E61000000100000005000000F758FAD0052D4F40BCCD1B2785A94B40F758FAD0052D4F400740DCD5ABAA4B40E8A38CB800324F400740DCD5ABAA4B40E8A38CB800324F40BCCD1B2785A94B40F758FAD0052D4F40BCCD1B2785A94B40
10124	Арасланова	6	55	1058	62.704653	62.719591999999999	55.091318999999999	55.083827999999997	0103000020E610000001000000050000009F03CB11325A4F409A3E3BE0BA8A4B409F03CB11325A4F4070404B57B08B4B404B3B35971B5C4F4070404B57B08B4B404B3B35971B5C4F409A3E3BE0BA8A4B409F03CB11325A4F409A3E3BE0BA8A4B40
11048	Алакуль	6	55	1058	62.502854999999997	62.533496999999997	55.212082000000002	55.206384999999997	0103000020E61000000100000005000000A6D0798D5D404F4046B1DCD26A9A4B40A6D0798D5D404F40FF08C380259B4B40CEC133A149444F40FF08C380259B4B40CEC133A149444F4046B1DCD26A9A4B40A6D0798D5D404F4046B1DCD26A9A4B40
55049	Чесноково	6	55	910	63.480015000000002	63.491478000000001	55.319806999999997	55.313530999999998	0103000020E61000000100000005000000734BAB2171BD4F401EA4A7C821A84B40734BAB2171BD4F4014048F6FEFA84B400C5A48C0E8BE4F4014048F6FEFA84B400C5A48C0E8BE4F401EA4A7C821A84B40734BAB2171BD4F401EA4A7C821A84B40
9234	Хохлы	6	55	910	63.473539000000002	63.498485000000002	55.241878	55.234107000000002	0103000020E61000000100000005000000B6300BED9CBC4F40E161DA37F79D4B40B6300BED9CBC4F409ACFB9DBF59E4B40F645425BCEBF4F409ACFB9DBF59E4B40F645425BCEBF4F40E161DA37F79D4B40B6300BED9CBC4F40E161DA37F79D4B40
9125	Трусилово	6	55	910	63.338109000000003	63.356020999999998	55.188139	55.176445000000001	0103000020E61000000100000005000000DCBDDC2747AB4F407845F0BF95964B40DCBDDC2747AB4F40130D52F014984B4038D89B1892AD4F40130D52F014984B4038D89B1892AD4F407845F0BF95964B40DCBDDC2747AB4F407845F0BF95964B40
8260	Травяное	6	55	910	63.405391999999999	63.425991000000003	55.574381000000002	55.555045999999997	0103000020E61000000100000005000000AF0793E2E3B34F4047E350BF0BC74B40AF0793E2E3B34F40CE380D5185C94B40F7B182DF86B64F40CE380D5185C94B40F7B182DF86B64F4047E350BF0BC74B40AF0793E2E3B34F4047E350BF0BC74B40
9007	Столбово	6	55	910	63.122233999999999	63.167158999999998	55.077643000000002	55.063107000000002	0103000020E61000000100000005000000C93A1C5DA58F4F400893E2E313884B40C93A1C5DA58F4F40B5E1B034F0894B40B41D537765954F40B5E1B034F0894B40B41D537765954F400893E2E313884B40C93A1C5DA58F4F400893E2E313884B40
8342	Стариково	6	55	910	62.995204000000001	63.014139999999998	55.491722000000003	55.478831999999997	0103000020E61000000100000005000000986C3CD8627F4F409E23F25D4ABD4B40986C3CD8627F4F40A35C1ABFF0BE4B4060C8EA56CF814F40A35C1ABFF0BE4B4060C8EA56CF814F409E23F25D4ABD4B40986C3CD8627F4F409E23F25D4ABD4B40
9088	Сажино	6	55	910	63.334417000000002	63.357664999999997	55.108761000000001	55.094028999999999	0103000020E61000000100000005000000FC1C1F2DCEAA4F4013F06B24098C4B40FC1C1F2DCEAA4F40460A65E1EB8D4B4040F67AF7C7AD4F40460A65E1EB8D4B4040F67AF7C7AD4F4013F06B24098C4B40FC1C1F2DCEAA4F4013F06B24098C4B40
9028	Птичье	6	55	910	63.382880999999998	63.422621999999997	55.127218999999997	55.104337000000001	0103000020E6100000010000000500000040A19E3E02B14F40A26131EA5A8D4B4040A19E3E02B14F40043752B648904B40F9484A7A18B64F40043752B648904B40F9484A7A18B64F40A26131EA5A8D4B4040A19E3E02B14F40A26131EA5A8D4B40
8033	Прошкино	6	55	910	62.957473999999998	62.973779	55.717633999999997	55.700820999999998	0103000020E6100000010000000500000099620E828E7A4F40CDACA580B4D94B4099620E828E7A4F40B33F506EDBDB4B400B444FCAA47C4F40B33F506EDBDB4B400B444FCAA47C4F40CDACA580B4D94B4099620E828E7A4F40CDACA580B4D94B40
9163	Петухи	6	55	910	63.611933000000001	63.635846000000001	55.192681999999998	55.165343	0103000020E61000000100000005000000ED2B0FD253CE4F40AFCF9CF529954B40ED2B0FD253CE4F409143C4CDA9984B406EA5D76663D14F409143C4CDA9984B406EA5D76663D14F40AFCF9CF529954B40ED2B0FD253CE4F40AFCF9CF529954B40
8107	Михайловка	6	55	910	62.857663000000002	62.880372000000001	55.654649999999997	55.644821	0103000020E61000000100000005000000A0FEB3E6C76D4F401363997E89D24B40A0FEB3E6C76D4F40C7293A92CBD34B4035289A07B0704F40C7293A92CBD34B4035289A07B0704F401363997E89D24B40A0FEB3E6C76D4F401363997E89D24B40
8718	Межлесье	6	55	910	63.316360000000003	63.328290000000003	55.521352999999998	55.512183999999998	0103000020E610000001000000050000009CE1067C7EA84F4069C4CC3E8FC14B409CE1067C7EA84F40F355F2B1BBC24B404BCD1E6805AA4F40F355F2B1BBC24B404BCD1E6805AA4F4069C4CC3E8FC14B409CE1067C7EA84F4069C4CC3E8FC14B40
8938	Малое Дюрягино	6	55	910	63.214770000000001	63.237416000000003	55.207890999999996	55.193339999999999	0103000020E61000000100000005000000BA1457957D9B4F401B81785DBF984B40BA1457957D9B4F40FD101B2C9C9A4B4009C6C1A5639E4F40FD101B2C9C9A4B4009C6C1A5639E4F401B81785DBF984B40BA1457957D9B4F401B81785DBF984B40
9205	Кушма	6	55	910	63.397576999999998	63.416657000000001	55.312055999999998	55.297718000000003	0103000020E6100000010000000500000026529ACDE3B24F401CB7989F1BA64B4026529ACDE3B24F40A2427573F1A74B4022533E0455B54F40A2427573F1A74B4022533E0455B54F401CB7989F1BA64B4026529ACDE3B24F401CB7989F1BA64B40
8283	Куликово	6	55	910	63.414617999999997	63.434669	55.638947999999999	55.631407000000003	0103000020E610000001000000050000009D2ADF3312B54F4095BBCFF1D1D04B409D2ADF3312B54F401CEC4D0CC9D14B40E2CAD93BA3B74F401CEC4D0CC9D14B40E2CAD93BA3B74F4095BBCFF1D1D04B409D2ADF3312B54F4095BBCFF1D1D04B40
8568	Крутая Горка	6	55	910	63.247864	63.291108999999999	55.402613000000002	55.388081999999997	0103000020E6100000010000000500000089EDEE01BA9F4F404815C5ABACB14B4089EDEE01BA9F4F40E4F8A1D288B34B401F49490F43A54F40E4F8A1D288B34B401F49490F43A54F404815C5ABACB14B4089EDEE01BA9F4F404815C5ABACB14B40
8640	Красный Холм	6	55	910	63.223367000000003	63.239986000000002	55.438082999999999	55.428086999999998	0103000020E61000000100000005000000B900344A979C4F40DF6B088ECBB64B40B900344A979C4F407FF78E1A13B84B40BABF7ADCB79E4F407FF78E1A13B84B40BABF7ADCB79E4F40DF6B088ECBB64B40B900344A979C4F40DF6B088ECBB64B40
8676	Котлик	6	55	910	63.254601000000001	63.272460000000002	55.498601999999998	55.489254000000003	0103000020E61000000100000005000000B343FCC396A04F40F6B704E09FBE4B40B343FCC396A04F402FDCB930D2BF4B40EDBB22F8DFA24F402FDCB930D2BF4B40EDBB22F8DFA24F40F6B704E09FBE4B40B343FCC396A04F40F6B704E09FBE4B40
8472	Кипель	6	55	910	63.073573000000003	63.093677	55.311728000000002	55.300516000000002	0103000020E610000001000000050000002F6F0ED76A894F405EF6EB4E77A64B402F6F0ED76A894F40AE9FFEB3E6A74B4096B1A19BFD8B4F40AE9FFEB3E6A74B4096B1A19BFD8B4F405EF6EB4E77A64B402F6F0ED76A894F405EF6EB4E77A64B40
8411	Карачельское	6	55	910	63.198276999999997	63.227454000000002	55.402147999999997	55.393697000000003	0103000020E610000001000000050000004546072461994F4044C4CDA964B24B404546072461994F406E13EE9579B34B4015AC71361D9D4F406E13EE9579B34B4015AC71361D9D4F4044C4CDA964B24B404546072461994F4044C4CDA964B24B40
8786	Карандашово	6	55	910	63.185305	63.202966000000004	55.233603000000002	55.219509000000002	0103000020E6100000010000000500000084640113B8974F40BE16F4DE189C4B4084640113B8974F40AE9FFEB3E69D4B40981936CAFA994F40AE9FFEB3E69D4B40981936CAFA994F40BE16F4DE189C4B4084640113B8974F40BE16F4DE189C4B40
8767	Каменное	6	55	910	63.198797999999996	63.234496999999998	55.270457	55.251603000000003	0103000020E610000001000000050000004E417E3672994F40AA49F08634A04B404E417E3672994F40B5FCC0559EA24B404B0169FF039E4F40B5FCC0559EA24B404B0169FF039E4F40AA49F08634A04B404E417E3672994F40AA49F08634A04B40
8519	Горшково	6	55	910	63.000745999999999	63.025675	55.351241999999999	55.343885999999998	0103000020E6100000010000000500000029CDE67118804F40B0C6D97404AC4B4029CDE67118804F40A67D737FF5AC4B4093A9825149834F40A67D737FF5AC4B4093A9825149834F40B0C6D97404AC4B4029CDE67118804F40B0C6D97404AC4B40
8100	Галкино	6	55	910	62.919260000000001	62.951725000000003	55.602891	55.587086999999997	0103000020E61000000100000005000000AF42CA4FAA754F401074B4AA25CB4B40AF42CA4FAA754F40C00644882BCD4B408FE4F21FD2794F40C00644882BCD4B408FE4F21FD2794F401074B4AA25CB4B40AF42CA4FAA754F401074B4AA25CB4B40
8422	Большое Дюрягино	6	55	910	63.212713000000001	63.252184999999997	55.390931000000002	55.383837999999997	0103000020E610000001000000050000008F37F92D3A9B4F40247B849A21B14B408F37F92D3A9B4F400DFFE9060AB24B4058C51B9947A04F400DFFE9060AB24B4058C51B9947A04F40247B849A21B14B408F37F92D3A9B4F40247B849A21B14B40
8183	Большая Рига	6	55	910	63.199615000000001	63.260117000000001	55.598120999999999	55.576996000000001	0103000020E610000001000000050000004165FCFB8C994F401FF64201DBC94B404165FCFB8C994F4081069B3A8FCC4B401B118C834BA14F4081069B3A8FCC4B401B118C834BA14F401FF64201DBC94B404165FCFB8C994F401FF64201DBC94B40
8846	Благовещенское	6	55	910	63.300730000000001	63.351601000000002	55.414056000000002	55.406951999999997	0103000020E610000001000000050000008A7615527EA64F405985CD0017B44B408A7615527EA64F40365B79C9FFB44B40D61EF64201AD4F40365B79C9FFB44B40D61EF64201AD4F405985CD0017B44B408A7615527EA64F405985CD0017B44B40
8864	Березово	6	55	910	63.038663999999997	63.069153	55.186247000000002	55.172001999999999	0103000020E610000001000000050000002AC423F1F2844F405D6C5A2904964B402AC423F1F2844F4033FD12F1D6974B40CCB56801DA884F4033FD12F1D6974B40CCB56801DA884F405D6C5A2904964B402AC423F1F2844F405D6C5A2904964B40
7120	Яутла	6	55	228	64.455864000000005	64.487386000000001	56.650210999999999	56.636704000000002	0103000020E610000001000000050000001FDB32E02C1D5040BF9D44847F514C401FDB32E02C1D5040EE3F321D3A534C40CFA10C55311F5040EE3F321D3A534C40CFA10C55311F5040BF9D44847F514C401FDB32E02C1D5040BF9D44847F514C40
7039	Широково	6	55	228	64.755758	64.778098999999997	56.502062000000002	56.492502999999999	0103000020E610000001000000050000002F6CCD565E30504048179B560A3F4C402F6CCD565E3050403D484F9143404C403883BF5FCC3150403D484F9143404C403883BF5FCC31504048179B560A3F4C402F6CCD565E30504048179B560A3F4C40
54953	Шатрово	6	55	228	64.602594999999994	64.657185999999996	56.533620999999997	56.506413999999999	0103000020E61000000100000005000000EB6E9EEA90265040471E882CD2404C40EB6E9EEA90265040BABA63B14D444C40E658DE550F2A5040BABA63B14D444C40E658DE550F2A5040471E882CD2404C40EB6E9EEA90265040471E882CD2404C40
4576	Черное Макарово	6	55	228	64.814885000000004	64.831755000000001	56.382416999999997	56.373131000000001	0103000020E6100000010000000500000010406A1327345040D80FB1C1C22F4C4010406A13273450409B374E0AF3304C4035D252793B3550409B374E0AF3304C4035D252793B355040D80FB1C1C22F4C4010406A1327345040D80FB1C1C22F4C40
6906	Терсюкское	6	55	228	64.799972999999994	64.827146999999997	56.299655999999999	56.285069	0103000020E61000000100000005000000B62BF4C1323350403D0D18247D244C40B62BF4C1323350406C06B8205B264C40027FF8F9EF3450406C06B8205B264C40027FF8F9EF3450403D0D18247D244C40B62BF4C1323350403D0D18247D244C40
6833	Спицыно	6	55	228	64.634045	64.666141999999994	56.219512000000002	56.208874999999999	0103000020E610000001000000050000004FCC7A3194285040DBF97E6ABC1A4C404FCC7A31942850402F8A1EF8181C4C407D1F0E12A22A50402F8A1EF8181C4C407D1F0E12A22A5040DBF97E6ABC1A4C404FCC7A3194285040DBF97E6ABC1A4C40
6758	Сопинина	6	55	228	64.594662999999997	64.612243000000007	56.204514000000003	56.193382	0103000020E610000001000000050000000A4966F50E2650404AD1CABDC0184C400A4966F50E2650407EC9C6832D1A4C401E8D43FD2E2750407EC9C6832D1A4C401E8D43FD2E2750404AD1CABDC0184C400A4966F50E2650404AD1CABDC0184C40
16685	Смолина	6	55	228	64.454633999999999	64.475168999999994	56.104717000000001	56.098450999999997	0103000020E61000000100000005000000946934B9181D504016A1D80A9A0C4C40946934B9181D5040E92ADD5D670D4C40ACC43C2B691E5040E92ADD5D670D4C40ACC43C2B691E504016A1D80A9A0C4C40946934B9181D504016A1D80A9A0C4C40
6735	Сладчанка	6	55	228	64.682168000000004	64.704769999999996	56.225932999999998	56.220613999999998	0103000020E610000001000000050000002D98F8A3A82B504016855D143D1C4C402D98F8A3A82B5040280B5F5FEB1C4C40EC4CA1F31A2D5040280B5F5FEB1C4C40EC4CA1F31A2D504016855D143D1C4C402D98F8A3A82B504016855D143D1C4C40
6639	Самохвалово	6	55	228	64.703430999999995	64.729707000000005	56.654313000000002	56.639575000000001	0103000020E6100000010000000500000086FF7403052D50406B2BF697DD514C4086FF7403052D5040802C4487C0534C40632AFD84B32E5040802C4487C0534C40632AFD84B32E50406B2BF697DD514C4086FF7403052D50406B2BF697DD514C40
5902	Саломатова	6	55	228	64.945616999999999	64.972863000000004	56.572270000000003	56.562618999999998	0103000020E61000000100000005000000AA622AFD843C5040DA8D3EE603484C40AA622AFD843C5040B03DB32440494C40431F2C63433E5040B03DB32440494C40431F2C63433E5040DA8D3EE603484C40AA622AFD843C5040DA8D3EE603484C40
7005	Портнягино	6	55	228	64.742255999999998	64.759710999999996	56.246955999999997	56.238667	0103000020E61000000100000005000000A0504F1F812F504035D1E7A38C1E4C40A0504F1F812F504086C613419C1F4C4055DAE21A9F30504086C613419C1F4C4055DAE21A9F30504035D1E7A38C1E4C40A0504F1F812F504035D1E7A38C1E4C40
16755	Поротова	6	55	228	64.488562999999999	64.504823000000002	56.117109999999997	56.105159	0103000020E6100000010000000500000048C2BE9D441F5040A6F0A0D9750D4C4048C2BE9D441F50406C04E275FD0E4C4031D120054F2050406C04E275FD0E4C4031D120054F205040A6F0A0D9750D4C4048C2BE9D441F5040A6F0A0D9750D4C40
6578	Ожогино	6	55	228	64.505694000000005	64.534287000000006	56.405802999999999	56.389543000000003	0103000020E6100000010000000500000024F25D4A5D20504060B1868BDC314C4024F25D4A5D20504031CF4A5AF1334C4064EB19C23122504031CF4A5AF1334C4064EB19C23122504060B1868BDC314C4024F25D4A5D20504060B1868BDC314C40
6543	Мостовское	6	55	228	64.988529	65.026428999999993	56.416904000000002	56.405858000000002	0103000020E610000001000000050000007289230F443F5040F568AA27F3334C407289230F443F50402AC93A1C5D354C409FAA4203B14150402AC93A1C5D354C409FAA4203B1415040F568AA27F3334C407289230F443F5040F568AA27F3334C40
54938	Мехонское	6	55	228	64.559314000000001	64.580163999999996	56.179726000000002	56.157913999999998	0103000020E610000001000000050000007A8CF2CCCB2350404FCAA48636144C407A8CF2CCCB235040D61EF64201174C4042942F6821255040D61EF64201174C4042942F68212550404FCAA48636144C407A8CF2CCCB2350404FCAA48636144C40
6315	Ленская	6	55	228	64.508343999999994	64.533199999999994	56.192158999999997	56.184044	0103000020E610000001000000050000008AC745B5882050403483F8C08E174C408AC745B588205040E75086AA98184C408A8EE4F21F225040E75086AA98184C408A8EE4F21F2250403483F8C08E174C408AC745B5882050403483F8C08E174C40
55040	Кызылбай	6	55	228	64.251219000000006	64.279641999999996	56.352293000000003	56.346437000000002	0103000020E610000001000000050000009148DBF813105040EB8F300C582C4C409148DBF8131050400CCEE0EF172D4C40A2258FA7E51150400CCEE0EF172D4C40A2258FA7E5115040EB8F300C582C4C409148DBF813105040EB8F300C582C4C40
55010	Кызылбай	6	55	228	64.251219000000006	64.279641999999996	56.352293000000003	56.346437000000002	0103000020E610000001000000050000009148DBF813105040EB8F300C582C4C409148DBF8131050400CCEE0EF172D4C40A2258FA7E51150400CCEE0EF172D4C40A2258FA7E5115040EB8F300C582C4C409148DBF813105040EB8F300C582C4C40
6840	Коршунова	6	55	228	64.767354999999995	64.780631999999997	56.230677	56.222515000000001	0103000020E61000000100000005000000035B25581C3150404AEF1B5F7B1C4C40035B25581C3150403E78EDD2861D4C40828DEBDFF53150403E78EDD2861D4C40828DEBDFF53150404AEF1B5F7B1C4C40035B25581C3150404AEF1B5F7B1C4C40
6018	Кондинское	6	55	228	64.412807999999998	64.456394000000003	56.101880999999999	56.093032999999998	0103000020E61000000100000005000000BDE13E726B1A504071395E81E80B4C40BDE13E726B1A5040B98AC56F0A0D4C40CD052E8F351D5040B98AC56F0A0D4C40CD052E8F351D504071395E81E80B4C40BDE13E726B1A504071395E81E80B4C40
6003	Кодское	6	55	228	64.861238	64.923545000000004	56.39038	56.379525999999998	0103000020E61000000100000005000000A304FD851E375040A8FDD64E94304C40A304FD851E3750409981CAF8F7314C4099D87C5C1B3B50409981CAF8F7314C4099D87C5C1B3B5040A8FDD64E94304C40A304FD851E375040A8FDD64E94304C40
6412	Ключи	6	55	228	65.056999000000005	65.071416999999997	56.439492999999999	56.430678999999998	0103000020E61000000100000005000000E73922DFA543504078094E7D20374C40E73922DFA543504014E97E4E41384C4038D89B189244504014E97E4E41384C4038D89B189244504078094E7D20374C40E73922DFA543504078094E7D20374C40
5696	Каширцево	6	55	228	64.341607999999994	64.358343000000005	56.248866	56.239837999999999	0103000020E610000001000000050000005303CDE7DC155040452BF702B31E4C405303CDE7DC1550400D8B51D7DA1F4C4009707A17EF1650400D8B51D7DA1F4C4009707A17EF165040452BF702B31E4C405303CDE7DC155040452BF702B31E4C40
5934	Камышевка	6	55	228	64.779814999999999	64.805525000000003	56.364759999999997	56.345782999999997	0103000020E61000000100000005000000897B2C7DE8315040A2410A9E422C4C40897B2C7DE8315040C971A774B02E4C4011C7BAB88D335040C971A774B02E4C4011C7BAB88D335040A2410A9E422C4C40897B2C7DE8315040A2410A9E422C4C40
6672	Ирюм	6	55	228	64.644069999999999	64.665208000000007	56.690713000000002	56.675435	0103000020E610000001000000050000006C9560713829504071C971A774564C406C9560713829504006F6984869584C40684293C4922A504006F6984869584C40684293C4922A504071C971A774564C406C9560713829504071C971A774564C40
5784	Ильино	6	55	228	64.859801000000004	64.894313999999994	56.599865000000001	56.585110999999998	0103000020E610000001000000050000005C04C6FA06375040D2C3D0EAE44A4C405C04C6FA06375040ED815660C84C4C40B796C9703C395040ED815660C84C4C40B796C9703C395040D2C3D0EAE44A4C405C04C6FA06375040D2C3D0EAE44A4C40
5716	Изъедугино	6	55	228	64.524918	64.549683999999999	56.329087999999999	56.320283000000003	0103000020E610000001000000050000003BC5AA41982150407E3B8908FF284C403BC5AA4198215040C6C03A8E1F2A4C409BC8CC052E235040C6C03A8E1F2A4C409BC8CC052E2350407E3B8908FF284C403BC5AA41982150407E3B8908FF284C40
6461	Духовка	6	55	228	65.075765000000004	65.087110999999993	56.395775999999998	56.385182999999998	0103000020E610000001000000050000009D4B7155D9445040D2FC31AD4D314C409D4B7155D94450405645B8C9A8324C40CC07043A934550405645B8C9A8324C40CC07043A93455040D2FC31AD4D314C409D4B7155D9445040D2FC31AD4D314C40
5823	Дружинина	6	55	228	64.924550999999994	64.948447000000002	56.588293	56.578606999999998	0103000020E61000000100000005000000FB1EF5D72B3B50404B1E4FCB0F4A4C40FB1EF5D72B3B50409DBB5D2F4D4B4C4051BF0B5BB33C50409DBB5D2F4D4B4C4051BF0B5BB33C50404B1E4FCB0F4A4C40FB1EF5D72B3B50404B1E4FCB0F4A4C40
5486	Дворцы	6	55	228	64.548480999999995	64.567982999999998	56.527470000000001	56.512444000000002	0103000020E610000001000000050000008D5E0D501A2350400684D6C397414C408D5E0D501A23504081CF0F2384434C40C66B5ED55924504081CF0F2384434C40C66B5ED5592450400684D6C397414C408D5E0D501A2350400684D6C397414C40
5605	Дальняя Кубасова	6	55	228	64.459269000000006	64.486587	56.271256000000001	56.262697000000003	0103000020E6100000010000000500000044C4CDA9641D5040F0E0270EA0214C4044C4CDA9641D5040016C4084B8224C4029EACC3D241F5040016C4084B8224C4029EACC3D241F5040F0E0270EA0214C4044C4CDA9641D5040F0E0270EA0214C40
6943	Воротниково	6	55	228	64.754096000000004	64.766762	56.266846999999999	56.256037999999997	0103000020E61000000100000005000000D882DE1B4330504041446ADAC5204C40D882DE1B433050409204E10A28224C403274ECA0123150409204E10A28224C403274ECA01231504041446ADAC5204C40D882DE1B4330504041446ADAC5204C40
54928	Барино	6	55	228	64.835222999999999	64.867401000000001	56.284883999999998	56.264972	0103000020E610000001000000050000007D772B4B74355040882D3D9AEA214C407D772B4B74355040AB93331477244C4022E17B7F83375040AB93331477244C4022E17B7F83375040882D3D9AEA214C407D772B4B74355040882D3D9AEA214C40
4618	Юлдус	6	55	436	64.355018999999999	64.375626999999994	56.104336000000004	56.093871999999998	0103000020E610000001000000050000005A9D9CA1B81650404B0169FF030C4C405A9D9CA1B8165040D2E5CDE15A0D4C40A71FD4450A185040D2E5CDE15A0D4C40A71FD4450A1850404B0169FF030C4C405A9D9CA1B81650404B0169FF030C4C40
13687	Шахматово	6	55	436	63.855241999999997	63.870629999999998	56.028821999999998	56.021971000000001	0103000020E610000001000000050000003315E29178ED4F40EF3A1BF2CF024C403315E29178ED4F40E1B37570B0034C404F75C8CD70EF4F40E1B37570B0034C404F75C8CD70EF4F40EF3A1BF2CF024C403315E29178ED4F40EF3A1BF2CF024C40
3621	Чистопрудное	6	55	436	63.912005999999998	63.933053999999998	56.019978000000002	56.012551000000002	0103000020E61000000100000005000000BDE0D39CBCF44F401C446B459B014C40BDE0D39CBCF44F40DB519CA38E024C4074B33F506EF74F40DB519CA38E024C4074B33F506EF74F401C446B459B014C40BDE0D39CBCF44F401C446B459B014C40
3541	Черемисское	6	55	436	63.807433000000003	63.825767999999997	56.017316999999998	56.009819	0103000020E61000000100000005000000085BECF659E74F4091F0BDBF41014C40085BECF659E74F401955867137024C40AA0A0DC4B2E94F401955867137024C40AA0A0DC4B2E94F4091F0BDBF41014C40085BECF659E74F4091F0BDBF41014C40
2487	Фрунзе	6	55	436	63.283248999999998	63.297486999999997	55.786074999999997	55.780926999999998	0103000020E61000000100000005000000F6CFD38041A44F401DC87A6AF5E34B40F6CFD38041A44F40029A081B9EE44B4019FED30D14A64F40029A081B9EE44B4019FED30D14A64F401DC87A6AF5E34B40F6CFD38041A44F401DC87A6AF5E34B40
4894	Тюленёво	6	55	436	64.022733000000002	64.044723000000005	56.224342	56.217145000000002	0103000020E610000001000000050000008FE21C7574015040B6BE4868CB1B4C408FE21C7574015040438F183DB71C4C404298DBBDDC025040438F183DB71C4C404298DBBDDC025040B6BE4868CB1B4C408FE21C7574015040B6BE4868CB1B4C40
4719	Титова	6	55	436	64.252243000000007	64.266813999999997	56.162927000000003	56.150319000000003	0103000020E6100000010000000500000047E9D2BF24105040D57B2AA73D134C4047E9D2BF241050405551BCCADA144C405B07077B131150405551BCCADA144C405B07077B13115040D57B2AA73D134C4047E9D2BF24105040D57B2AA73D134C40
5041	Тарасова	6	55	436	63.708691000000002	63.725022000000003	56.401823	56.391306999999998	0103000020E610000001000000050000001AFCFD62B6DA4F4012D9075916324C401AFCFD62B6DA4F40EBE3A1EF6E334C40B5705985CDDC4F40EBE3A1EF6E334C40B5705985CDDC4F4012D9075916324C401AFCFD62B6DA4F4012D9075916324C40
3760	Сухринское	6	55	436	63.366045999999997	63.391469000000001	56.136817999999998	56.130974000000002	0103000020E61000000100000005000000726A6798DAAE4F402B508BC1C3104C40726A6798DAAE4F4087C0914083114C40EC32FCA71BB24F4087C0914083114C40EC32FCA71BB24F402B508BC1C3104C40726A6798DAAE4F402B508BC1C3104C40
5157	Сосновское	6	55	436	63.620117	63.632451000000003	56.312455	56.301797999999998	0103000020E61000000100000005000000C9586DFE5FCF4F40C5FF1D51A1264C40C9586DFE5FCF4F40603C8386FE274C4048A98427F4D04F40603C8386FE274C4048A98427F4D04F40C5FF1D51A1264C40C9586DFE5FCF4F40C5FF1D51A1264C40
3732	Соровское	6	55	436	64.014934999999994	64.053239000000005	56.045679	56.039475000000003	0103000020E610000001000000050000003524EEB1F40050403B014D840D054C403524EEB1F4005040978E39CFD8054C40CBF78C4468035040978E39CFD8054C40CBF78C44680350403B014D840D054C403524EEB1F40050403B014D840D054C40
4681	Сибирки	6	55	436	64.291427999999996	64.308252999999993	56.124647000000003	56.118043999999998	0103000020E61000000100000005000000E048A0C1A612504098BED7101C0F4C40E048A0C1A6125040B345D26EF40F4C403579CA6ABA135040B345D26EF40F4C403579CA6ABA13504098BED7101C0F4C40E048A0C1A612504098BED7101C0F4C40
2746	Просвет	6	55	436	63.278308000000003	63.288234000000003	55.860787000000002	55.854945999999998	0103000020E610000001000000050000008B1BB7989FA34F404AECDADE6EED4B408B1BB7989FA34F4036E9B6442EEE4B4032CC09DAE4A44F4036E9B6442EEE4B4032CC09DAE4A44F404AECDADE6EED4B408B1BB7989FA34F404AECDADE6EED4B40
13661	Прогресс	6	55	436	63.610298	63.620593	56.120215999999999	56.115769999999998	0103000020E610000001000000050000003868AF3E1ECE4F40D0ED258DD10E4C403868AF3E1ECE4F405C3AE63C630F4C40329067976FCF4F405C3AE63C630F4C40329067976FCF4F40D0ED258DD10E4C403868AF3E1ECE4F40D0ED258DD10E4C40
3304	Понькино	6	55	436	63.330536000000002	63.368445000000001	56.008253000000003	55.995291999999999	0103000020E610000001000000050000004913EF004FAA4F4037FC6EBA65FF4B404913EF004FAA4F40058C2E6F0E014C40F7AFAC3429AF4F40058C2E6F0E014C40F7AFAC3429AF4F4037FC6EBA65FF4B404913EF004FAA4F4037FC6EBA65FF4B40
54973	Погорелка	6	55	436	63.702007000000002	63.751953	56.081471999999998	56.069012000000001	0103000020E610000001000000050000001348895DDBD94F400A849D62D5084C401348895DDBD94F4015C5ABAC6D0A4C408690F3FE3FE04F4015C5ABAC6D0A4C408690F3FE3FE04F400A849D62D5084C401348895DDBD94F400A849D62D5084C40
2988	Погадайское	6	55	436	63.491182000000002	63.527554000000002	55.983434000000003	55.975440999999996	0103000020E610000001000000050000002331410DDFBE4F40B9162D40DBFC4B402331410DDFBE4F4022E3512AE1FD4B40DF6FB4E386C34F4022E3512AE1FD4B40DF6FB4E386C34F40B9162D40DBFC4B402331410DDFBE4F40B9162D40DBFC4B40
2409	Песчанотаволжанское	6	55	436	63.300747999999999	63.330733000000002	55.734541999999998	55.724514999999997	0103000020E61000000100000005000000302B14E97EA64F40103B53E8BCDC4B40302B14E97EA64F40EBC4E57805DE4B409F5A7D7555AA4F40EBC4E57805DE4B409F5A7D7555AA4F40103B53E8BCDC4B40302B14E97EA64F40103B53E8BCDC4B40
54924	Ольховка	6	55	436	63.754244	63.786718	56.363892	56.334651999999998	0103000020E61000000100000005000000249A40118BE04F403FC571E0D52A4C40249A40118BE04F4055A35703942E4C405796E82CB3E44F4055A35703942E4C405796E82CB3E44F403FC571E0D52A4C40249A40118BE04F403FC571E0D52A4C40
2831	Октябрь	6	55	436	63.330221000000002	63.344647999999999	55.955952000000003	55.945483000000003	0103000020E61000000100000005000000E9B985AE44AA4F4045F6419605F94B40E9B985AE44AA4F40DD4598A25CFA4B40DF50F86C1DAC4F40DD4598A25CFA4B40DF50F86C1DAC4F4045F6419605F94B40E9B985AE44AA4F4045F6419605F94B40
3659	Нижнеполевское	6	55	436	63.953670000000002	63.976407000000002	56.051837999999996	56.045312000000003	0103000020E610000001000000050000009296CADB11FA4F40E50E9BC8CC054C409296CADB11FA4F405358A9A0A2064C40F14A92E7FAFC4F405358A9A0A2064C40F14A92E7FAFC4F40E50E9BC8CC054C409296CADB11FA4F40E50E9BC8CC054C40
4807	Неонилинское	6	55	436	64.173506000000003	64.206446999999997	56.201594999999998	56.186559000000003	0103000020E610000001000000050000003AEAE8B81A0B504022E3512AE1174C403AEAE8B81A0B5040C0046EDDCD194C40DE567A6D360D5040C0046EDDCD194C40DE567A6D360D504022E3512AE1174C403AEAE8B81A0B504022E3512AE1174C40
3853	Мыльниково	6	55	436	63.500425	63.520448999999999	56.09693	56.092154999999998	0103000020E61000000100000005000000E78C28ED0DC04F40D9942BBCCB0B4C40E78C28ED0DC04F402A00C633680C4C40321EA5129EC24F402A00C633680C4C40321EA5129EC24F40D9942BBCCB0B4C40E78C28ED0DC04F40D9942BBCCB0B4C40
16643	Могилева	6	55	436	64.371539999999996	64.390834999999996	56.105198999999999	56.089351999999998	0103000020E61000000100000005000000F949B54FC717504085EAE6E26F0B4C40F949B54FC717504034492C29770D4C4075C8CD700319504034492C29770D4C4075C8CD700319504085EAE6E26F0B4C40F949B54FC717504085EAE6E26F0B4C40
2715	Мингали	6	55	436	63.833494000000002	63.844498000000002	55.881914000000002	55.855865999999999	0103000020E61000000100000005000000C4B46FEEAFEA4F4011E15F048DED4B40C4B46FEEAFEA4F4039F1D58EE2F04B40CAC4AD8218EC4F4039F1D58EE2F04B40CAC4AD8218EC4F4011E15F048DED4B40C4B46FEEAFEA4F4011E15F048DED4B40
4317	Маслянское	6	55	436	63.917530999999997	63.9542	56.088976000000002	56.078397000000002	0103000020E610000001000000050000007808E3A771F54F40618DB3E9080A4C407808E3A771F54F408010C990630B4C40EEEBC03923FA4F408010C990630B4C40EEEBC03923FA4F40618DB3E9080A4C407808E3A771F54F40618DB3E9080A4C40
3962	Мальцево	6	55	436	63.422136999999999	63.446131000000001	56.247371000000001	56.232804000000002	0103000020E610000001000000050000003DB7D09508B64F4062307F85CC1D4C403DB7D09508B64F404A7D59DAA91F4C40AB5D13D21AB94F404A7D59DAA91F4C40AB5D13D21AB94F4062307F85CC1D4C403DB7D09508B64F4062307F85CC1D4C40
3182	Макарово	6	55	436	63.671168000000002	63.692548000000002	55.988354000000001	55.980159999999998	0103000020E61000000100000005000000950F41D5E8D54F40766C04E275FD4B40950F41D5E8D54F40766F456282FE4B408274B169A5D84F40766F456282FE4B408274B169A5D84F40766C04E275FD4B40950F41D5E8D54F40766C04E275FD4B40
3411	Красномыльское	6	55	436	63.430706999999998	63.466414999999998	56.098385999999998	56.091743000000001	0103000020E6100000010000000500000042942F6821B74F408751103CBE0B4C4042942F6821B74F402F3196E9970C4C4092AE997CB3BB4F402F3196E9970C4C4092AE997CB3BB4F408751103CBE0B4C4042942F6821B74F408751103CBE0B4C40
54940	Красная Нива	6	55	436	63.639305	63.658141999999998	56.023555000000002	56.014780999999999	0103000020E61000000100000005000000AB9509BFD4D14F4014CD0358E4014C40AB9509BFD4D14F402254A9D903034C40E00F3FFF3DD44F402254A9D903034C40E00F3FFF3DD44F4014CD0358E4014C40AB9509BFD4D14F4014CD0358E4014C40
55001	Красная Звезда	6	55	436	63.445574000000001	63.473871000000003	55.986893000000002	55.974685000000001	0103000020E6100000010000000500000055F99E9108B94F406D73637AC2FC4B4055F99E9108B94F405FD3838252FE4B40ECC20FCEA7BC4F405FD3838252FE4B40ECC20FCEA7BC4F406D73637AC2FC4B4055F99E9108B94F406D73637AC2FC4B40
13547	Комсомольская	6	55	436	63.630842999999999	63.650336000000003	55.900717999999998	55.895100999999997	0103000020E610000001000000050000008CF4A276BFD04F40F6CE68AB92F24B408CF4A276BFD04F40927538BA4AF34B40ABB4C5353ED34F40927538BA4AF34B40ABB4C5353ED34F40F6CE68AB92F24B408CF4A276BFD04F40F6CE68AB92F24B40
2639	Колесниково	6	55	436	63.778849000000001	63.789557000000002	55.769195000000003	55.755752999999999	0103000020E61000000100000005000000DBC2F352B1E34F404C6DA983BCE04B40DBC2F352B1E34F40959F54FB74E24B40F8A92A3410E54F40959F54FB74E24B40F8A92A3410E54F404C6DA983BCE04B40DBC2F352B1E34F404C6DA983BCE04B40
4423	Кокорина	6	55	436	64.096377000000004	64.114009999999993	56.073960999999997	56.066730999999997	0103000020E610000001000000050000008BC56F0A2B0650408F5033A48A084C408BC56F0A2B065040F816D68D77094C40AF5A99F04B075040F816D68D77094C40AF5A99F04B0750408F5033A48A084C408BC56F0A2B0650408F5033A48A084C40
3332	Коврига	6	55	436	63.301322999999996	63.323718	56.130096000000002	56.121752000000001	0103000020E610000001000000050000002C4487C091A64F407E1CCD91950F4C402C4487C091A64F4093AB58FCA6104C40329067976FA94F4093AB58FCA6104C40329067976FA94F407E1CCD91950F4C402C4487C091A64F407E1CCD91950F4C40
4232	Ключи	6	55	436	63.605268000000002	63.616244999999999	56.136029999999998	56.131605999999998	0103000020E610000001000000050000005DA8FC6B79CD4F408BFA2477D8104C405DA8FC6B79CD4F402FA3586E69114C4069A9BC1DE1CE4F402FA3586E69114C4069A9BC1DE1CE4F408BFA2477D8104C405DA8FC6B79CD4F408BFA2477D8104C40
54951	Канаши	6	55	436	63.459498000000004	63.485657000000003	56.212238999999997	56.192729999999997	0103000020E61000000100000005000000E94999D4D0BA4F40A27A6B60AB184C40E94999D4D0BA4F40C6F7C5A52A1B4C40680932022ABE4F40C6F7C5A52A1B4C40680932022ABE4F40A27A6B60AB184C40E94999D4D0BA4F40A27A6B60AB184C40
4953	Ичкино	6	55	436	63.858978999999998	63.874034999999999	56.253937000000001	56.237206999999998	0103000020E61000000100000005000000B3791C06F3ED4F40EEB089CC5C1E4C40B3791C06F3ED4F40471FF30181204C409947FE60E0EF4F40471FF30181204C409947FE60E0EF4F40EEB089CC5C1E4C40B3791C06F3ED4F40EEB089CC5C1E4C40
4506	Ильтяково	6	55	436	64.165349000000006	64.188984000000005	56.063836000000002	56.057810000000003	0103000020E6100000010000000500000049DBF813950A5040DEB06D5166074C4049DBF813950A50405B272EC72B084C40E8DD5850180C50405B272EC72B084C40E8DD5850180C5040DEB06D5166074C4049DBF813950A5040DEB06D5166074C40
4129	Иванищевское	6	55	436	63.53678	63.55003	56.222430000000003	56.212719999999997	0103000020E61000000100000005000000CD920035B5C44F40419AB1683A1B4C40CD920035B5C44F401CD31396781C4C40D1E80E6267C64F401CD31396781C4C40D1E80E6267C64F40419AB1683A1B4C40CD920035B5C44F40419AB1683A1B4C40
5170	Зеленоборское	6	55	436	63.925786000000002	63.950481000000003	56.349139999999998	56.334192999999999	0103000020E610000001000000050000001E8CD82780F64F40ACC612D6C62A4C401E8CD82780F64F40DBDC989EB02C4C40153C855CA9F94F40DBDC989EB02C4C40153C855CA9F94F40ACC612D6C62A4C401E8CD82780F64F40ACC612D6C62A4C40
3828	Замараевское	6	55	436	63.253667	63.283436999999999	56.164530999999997	56.158209999999997	0103000020E610000001000000050000008789062978A04F4038F3AB3940144C408789062978A04F40CE16105A0F154C40F9BCE2A947A44F40CE16105A0F154C40F9BCE2A947A44F4038F3AB3940144C408789062978A04F4038F3AB3940144C40
13748	Завьялова	6	55	436	63.893968000000001	63.911081000000003	56.081586999999999	56.072910999999998	0103000020E61000000100000005000000D4D51D8B6DF24F406342CC2555094C40D4D51D8B6DF24F40AE635C71710A4C40E5805D4D9EF44F40AE635C71710A4C40E5805D4D9EF44F406342CC2555094C40D4D51D8B6DF24F406342CC2555094C40
3092	Жеребенкова	6	55	436	63.529899	63.542789999999997	55.926170999999997	55.917309000000003	0103000020E610000001000000050000007097FDBAD3C34F40CAA99D616AF54B407097FDBAD3C34F4076C075C58CF64B40444C89247AC54F4076C075C58CF64B40444C89247AC54F40CAA99D616AF54B407097FDBAD3C34F40CAA99D616AF54B40
2867	Демьяна Бедного	6	55	436	63.418005000000001	63.428165	55.938299000000001	55.931567999999999	0103000020E610000001000000050000004148163081B54F400400C79E3DF74B404148163081B54F404C6F7F2E1AF84B405B25581CCEB64F404C6F7F2E1AF84B405B25581CCEB64F400400C79E3DF74B404148163081B54F400400C79E3DF74B40
3057	Демино	6	55	436	63.554009999999998	63.581121000000003	55.977913999999998	55.969490999999998	0103000020E6100000010000000500000017D4B7CCE9C64F401762F54718FC4B4017D4B7CCE9C64F40782634492CFD4B406902452C62CA4F40782634492CFD4B406902452C62CA4F401762F54718FC4B4017D4B7CCE9C64F401762F54718FC4B40
55041	Глубокая	6	55	436	63.740177000000003	63.761386000000002	56.218190999999997	56.203257000000001	0103000020E610000001000000050000002E20B41EBEDE4F406FD74B53041A4C402E20B41EBEDE4F4009A4C4AEED1B4C40EED0B01875E14F4009A4C4AEED1B4C40EED0B01875E14F406FD74B53041A4C402E20B41EBEDE4F406FD74B53041A4C40
4191	Ганино	6	55	436	63.553353999999999	63.575766999999999	56.189363999999998	56.179340000000003	0103000020E610000001000000050000002E8ECA4DD4C64F40AD6EF59CF4164C402E8ECA4DD4C64F4016855D143D184C40DA8EA9BBB2C94F4016855D143D184C40DA8EA9BBB2C94F40AD6EF59CF4164C402E8ECA4DD4C64F40AD6EF59CF4164C40
4417	Верхозино	6	55	436	64.011314999999996	64.038938000000002	56.082647000000001	56.068795999999999	0103000020E6100000010000000500000012BD8C62B90050403D0CAD4ECE084C4012BD8C62B9005040670E492D940A4C409624CFF57D025040670E492D940A4C409624CFF57D0250403D0CAD4ECE084C4012BD8C62B90050403D0CAD4ECE084C40
3453	Верхняя Полевая	6	55	436	63.563504999999999	63.583897	56.075574000000003	56.068308999999999	0103000020E61000000100000005000000F5108DEE20C84F40E0826C59BE084C40F5108DEE20C84F40C636A968AC094C40C39D0B23BDCA4F40C636A968AC094C40C39D0B23BDCA4F40E0826C59BE084C40F5108DEE20C84F40E0826C59BE084C40
4827	Борчаниново	6	55	436	64.060794000000001	64.107623000000004	56.212825000000002	56.205015000000003	0103000020E61000000100000005000000C172840CE4035040401878EE3D1A4C40C172840CE4035040B7627FD93D1B4C400953944BE3065040B7627FD93D1B4C400953944BE3065040401878EE3D1A4C40C172840CE4035040401878EE3D1A4C40
2525	Большое Кабанье	6	55	436	63.516199999999998	63.536951000000002	55.806655999999997	55.788570999999997	0103000020E61000000100000005000000FC1873D712C24F4079C9FFE4EFE44B40FC1873D712C24F40A38FF98040E74B40FA4674CFBAC44F40A38FF98040E74B40FA4674CFBAC44F4079C9FFE4EFE44B40FC1873D712C24F4079C9FFE4EFE44B40
54930	Батурино	6	55	436	63.64076	63.678210999999997	55.870541000000003	55.850276999999998	0103000020E61000000100000005000000E04A766C04D24F403FC571E0D5EC4B40E04A766C04D24F40E06932E36DEF4B40CB64389ECFD64F40E06932E36DEF4B40CB64389ECFD64F403FC571E0D5EC4B40E04A766C04D24F403FC571E0D5EC4B40
3519	Барневское	6	55	436	63.810603999999998	63.832720999999999	56.050224	56.045966	0103000020E61000000100000005000000DE0033DFC1E74F402D5DC136E2054C40DE0033DFC1E74F40B6BC72BD6D064C40A1D80A9A96EA4F40B6BC72BD6D064C40A1D80A9A96EA4F402D5DC136E2054C40DE0033DFC1E74F402D5DC136E2054C40
5244	Байрак	6	55	436	64.241382999999999	64.255819000000002	56.483547000000002	56.468820999999998	0103000020E61000000100000005000000DDB3AED1720F5040C9569753023C4C40DDB3AED1720F50401A8A3BDEE43D4C4082ACA7565F1050401A8A3BDEE43D4C4082ACA7565F105040C9569753023C4C40DDB3AED1720F5040C9569753023C4C40
4080	Агапино	6	55	436	63.549760999999997	63.565489999999997	56.237727	56.229812000000003	0103000020E61000000100000005000000E1CE85915EC64F403B1DC87A6A1D4C40E1CE85915EC64F4027309DD66D1E4C40861BF0F961C84F4027309DD66D1E4C40861BF0F961C84F403B1DC87A6A1D4C40E1CE85915EC64F403B1DC87A6A1D4C40
14367	Шестаково	6	55	318	68.007489000000007	68.023712000000003	55.413423000000002	55.407009000000002	0103000020E610000001000000050000001B8524B37A005140BE16F4DE18B44B401B8524B37A00514005357C0BEBB44B407521567F8401514005357C0BEBB44B407521567F84015140BE16F4DE18B44B401B8524B37A005140BE16F4DE18B44B40
2372	Чердынцево	6	55	318	68.338454999999996	68.363068999999996	55.466825	55.460276999999998	0103000020E61000000100000005000000BB0A293FA9155140ED0C535BEABA4B40BB0A293FA915514044FAEDEBC0BB4B40404CC2853C17514044FAEDEBC0BB4B40404CC2853C175140ED0C535BEABA4B40BB0A293FA9155140ED0C535BEABA4B40
1822	Чебачье	6	55	318	68.169445999999994	68.176929000000001	55.426876	55.415956999999999	0103000020E61000000100000005000000081C0934D80A514069C537143EB54B40081C0934D80A514041B96DDFA3B64B40B22D03CE520B514041B96DDFA3B64B40B22D03CE520B514069C537143EB54B40081C0934D80A514069C537143EB54B40
54985	Частоозерье	6	55	318	67.889296999999999	67.934050999999997	55.584206999999999	55.551746000000001	0103000020E6100000010000000500000094DBF63DEAF8504073D9E89C9FC64B4094DBF63DEAF85040118C834BC7CA4B40F372D87DC7FB5040118C834BC7CA4B40F372D87DC7FB504073D9E89C9FC64B4094DBF63DEAF8504073D9E89C9FC64B40
2256	Сивково	6	55	318	67.693465000000003	67.715168000000006	55.559719999999999	55.548119999999997	0103000020E61000000100000005000000ECFA05BB61EC50404A24D1CB28C64B40ECFA05BB61EC50406475ABE7A4C74B4054C90050C5ED50406475ABE7A4C74B4054C90050C5ED50404A24D1CB28C64B40ECFA05BB61EC50404A24D1CB28C64B40
2144	Песьяное	6	55	318	67.756275000000002	67.765105000000005	55.396023	55.388133000000003	0103000020E6100000010000000500000013F241CF66F05040CBBF9657AEB14B4013F241CF66F050405EBBB4E1B0B24B406440F67AF7F050405EBBB4E1B0B24B406440F67AF7F05040CBBF9657AEB14B4013F241CF66F05040CBBF9657AEB14B40
1897	Окуневка	6	55	318	67.843536999999998	67.851864000000006	55.468698000000003	55.461976999999997	0103000020E61000000100000005000000D2FD9C82FCF550408940F50F22BB4B40D2FD9C82FCF55040AED9CA4BFEBB4B40F22895F084F65040AED9CA4BFEBB4B40F22895F084F650408940F50F22BB4B40D2FD9C82FCF550408940F50F22BB4B40
1934	Новотроицкое	6	55	318	68.026156	68.049852999999999	55.406118999999997	55.395456000000003	0103000020E610000001000000050000000726378AAC015140E5805D4D9EB24B400726378AAC01514061A417B5FBB34B40E126A3CA3003514061A417B5FBB34B40E126A3CA30035140E5805D4D9EB24B400726378AAC015140E5805D4D9EB24B40
14412	Малодолгие	6	55	318	67.751379	67.762643999999995	55.449255999999998	55.439630000000001	0103000020E61000000100000005000000ADF9F19716F05040952BBCCB45B84B40ADF9F19716F0504011C4793881B94B40669FC728CFF0504011C4793881B94B40669FC728CFF05040952BBCCB45B84B40ADF9F19716F05040952BBCCB45B84B40
2184	Лиханово	6	55	318	67.724888000000007	67.746347999999998	55.683798000000003	55.676844000000003	0103000020E61000000100000005000000D350A39064EE5040363FFED2A2D64B40D350A39064EE5040FD885FB186D74B40D7DB662AC4EF5040FD885FB186D74B40D7DB662AC4EF5040363FFED2A2D64B40D350A39064EE5040363FFED2A2D64B40
2296	Лебяжье	6	55	318	67.577168999999998	67.595692	55.678843999999998	55.673645999999998	0103000020E61000000100000005000000F6D03E56F0E45040658A39083AD64B40F6D03E56F0E45040FC8A355CE4D64B40499F56D11FE65040FC8A355CE4D64B40499F56D11FE65040658A39083AD64B40F6D03E56F0E45040658A39083AD64B40
1677	Казанцево	6	55	318	67.890600000000006	67.899062000000001	55.659312	55.651166000000003	0103000020E6100000010000000500000054742497FFF850403222516859D34B4054742497FFF8504020EEEA5564D44B40E3C4573B8AF9504020EEEA5564D44B40E3C4573B8AF950403222516859D34B4054742497FFF850403222516859D34B40
2057	Долгие	6	55	318	67.724169000000003	67.746258999999995	55.452793999999997	55.444021999999997	0103000020E61000000100000005000000BBF1EEC858EE50402D5A80B6D5B84B40BBF1EEC858EE50409AE95E27F5B94B401FD61BB5C2EF50409AE95E27F5B94B401FD61BB5C2EF50402D5A80B6D5B84B40BBF1EEC858EE50402D5A80B6D5B84B40
1584	Денисова	6	55	318	67.897210999999999	67.918025	55.597129000000002	55.588537000000002	0103000020E6100000010000000500000022A7AFE76BF9504034BE2F2E55CB4B4022A7AFE76BF95040213F1BB96ECC4B4044FAEDEBC0FA5040213F1BB96ECC4B4044FAEDEBC0FA504034BE2F2E55CB4B4022A7AFE76BF9504034BE2F2E55CB4B40
2028	Гомзино	6	55	318	68.034806000000003	68.049385999999998	55.365233000000003	55.359788999999999	0103000020E6100000010000000500000018EDF1423A025140F33AE2900DAE4B4018EDF1423A025140C23577F4BFAE4B4056B8E52329035140C23577F4BFAE4B4056B8E52329035140F33AE2900DAE4B4018EDF1423A025140F33AE2900DAE4B40
29606	Восточное	6	55	318	67.868510000000001	67.888847999999996	55.428806999999999	55.418134000000002	0103000020E61000000100000005000000EF8FF7AA95F750403FAC376A85B54B40EF8FF7AA95F75040DFA5D425E3B64B405CC7B8E2E2F85040DFA5D425E3B64B405CC7B8E2E2F850403FAC376A85B54B40EF8FF7AA95F750403FAC376A85B54B40
25500	Волчье	6	55	318	67.842063999999993	67.853958000000006	55.387371999999999	55.377941	0103000020E61000000100000005000000E4486760E4F55040A568E55E60B04B40E4486760E4F550406CB1DB6795B14B40168A743FA7F650406CB1DB6795B14B40168A743FA7F65040A568E55E60B04B40E4486760E4F55040A568E55E60B04B40
1788	Бутырино	6	55	318	68.161568000000003	68.171018000000004	55.519967000000001	55.504981000000001	0103000020E6100000010000000500000021054F21570A5140FA0CA837A3C04B4021054F21570A5140E7FF55478EC24B40C0417BF5F10A5140E7FF55478EC24B40C0417BF5F10A5140FA0CA837A3C04B4021054F21570A5140FA0CA837A3C04B40
1701	Беляковское	6	55	318	68.087124000000003	68.110282999999995	55.654761999999998	55.641199	0103000020E6100000010000000500000097AC8A70930551402C9D0FCF12D24B4097AC8A7093055140EF54C03DCFD34B4081936DE00E075140EF54C03DCFD34B4081936DE00E0751402C9D0FCF12D24B4097AC8A70930551402C9D0FCF12D24B40
975	Чалкино	6	55	80	63.485109000000001	63.503264000000001	54.323250999999999	54.311534000000002	0103000020E6100000010000000500000065FF3C0D18BE4F40C9CB9A58E0274B4065FF3C0D18BE4F401CB3EC4960294B4088A06AF46AC04F401CB3EC4960294B4088A06AF46AC04F40C9CB9A58E0274B4065FF3C0D18BE4F40C9CB9A58E0274B40
54923	Целинное	6	55	80	63.650317999999999	63.702168999999998	54.517440999999998	54.491579000000002	0103000020E610000001000000050000000400C79E3DD34F404033880FEC3E4B400400C79E3DD34F40054EB6813B424B40ECA17DACE0D94F40054EB6813B424B40ECA17DACE0D94F404033880FEC3E4B400400C79E3DD34F404033880FEC3E4B40
54991	Целинное	6	55	80	63.650317999999999	63.702168999999998	54.517440999999998	54.491579000000002	0103000020E610000001000000050000000400C79E3DD34F404033880FEC3E4B400400C79E3DD34F40054EB6813B424B40ECA17DACE0D94F40054EB6813B424B40ECA17DACE0D94F404033880FEC3E4B400400C79E3DD34F404033880FEC3E4B40
31930	Фроловка	6	55	80	63.518616000000002	63.536025000000002	54.455798999999999	54.450626999999997	0103000020E610000001000000050000005797530262C24F40E8D84125AE394B405797530262C24F405646239F573A4B40516B9A779CC44F405646239F573A4B40516B9A779CC44F40E8D84125AE394B405797530262C24F40E8D84125AE394B40
32001	Усть-Уйское	6	55	80	63.887869000000002	63.920729000000001	54.274391999999999	54.261972	0103000020E61000000100000005000000ED10FFB0A5F14F40DE3B6A4C88214B40ED10FFB0A5F14F405B24ED461F234B4049BDA772DAF54F405B24ED461F234B4049BDA772DAF54F40DE3B6A4C88214B40ED10FFB0A5F14F40DE3B6A4C88214B40
738	Трехозерки	6	55	80	63.599096000000003	63.617736000000001	54.405636000000001	54.394723999999997	0103000020E610000001000000050000000C957F2DAFCC4F402079E75086324B400C957F2DAFCC4F40460A65E1EB334B40EBC726F911CF4F40460A65E1EB334B40EBC726F911CF4F402079E75086324B400C957F2DAFCC4F402079E75086324B40
394	Становое	6	55	80	64.078967000000006	64.094373000000004	54.637042999999998	54.624327000000001	0103000020E61000000100000005000000A69D9ACB0D055040418177F2E94F4B40A69D9ACB0D055040A79201A08A514B4007280D350A065040A79201A08A514B4007280D350A065040418177F2E94F4B40A69D9ACB0D055040418177F2E94F4B40
354	Сетово	6	55	80	64.001801999999998	64.022400000000005	54.656204000000002	54.643763999999997	0103000020E6100000010000000500000050C422861D005040CB2BD7DB66524B4050C422861D00504090C01F7EFE534B408CDB68006F01504090C01F7EFE534B408CDB68006F015040CB2BD7DB66524B4050C422861D005040CB2BD7DB66524B40
31958	Рыбное	6	55	80	63.499957999999999	63.514752999999999	54.406061000000001	54.392999000000003	0103000020E61000000100000005000000D1AFAD9FFEBF4F402C2E8ECA4D324B40D1AFAD9FFEBF4F402D978DCEF9334B404A42226DE3C14F402D978DCEF9334B404A42226DE3C14F402C2E8ECA4D324B40D1AFAD9FFEBF4F402C2E8ECA4D324B40
31622	Рачеевка	6	55	80	63.341199000000003	63.352193999999997	54.311008999999999	54.300665000000002	0103000020E61000000100000005000000C636A968ACAB4F40A306D3307C264B40C636A968ACAB4F407EE19524CF274B4078EC67B114AD4F407EE19524CF274B4078EC67B114AD4F40A306D3307C264B40C636A968ACAB4F40A306D3307C264B40
1217	Пруды	6	55	80	63.910128999999998	63.920540000000003	54.434925	54.428499000000002	0103000020E610000001000000050000001212691B7FF44F4032AF230ED9364B401212691B7FF44F403D9B559FAB374B4076543541D4F54F403D9B559FAB374B4076543541D4F54F4032AF230ED9364B401212691B7FF44F4032AF230ED9364B40
31875	Приозерная	6	55	80	64.103554000000003	64.114108999999999	54.345351999999998	54.339505000000003	0103000020E61000000100000005000000AED7F4A0A00650400CEA5BE6742B4B40AED7F4A0A0065040D9CD8C7E342C4B4079CBD58F4D075040D9CD8C7E342C4B4079CBD58F4D0750400CEA5BE6742B4B40AED7F4A0A00650400CEA5BE6742B4B40
866	Полынный Лог	6	55	80	63.643616999999999	63.651980000000002	54.306381000000002	54.299928999999999	0103000020E610000001000000050000002713B70A62D24F409D0FCF1264264B402713B70A62D24F40D28E1B7E37274B40B3D2A41474D34F40D28E1B7E37274B40B3D2A41474D34F409D0FCF1264264B402713B70A62D24F409D0FCF1264264B40
54963	Половинное	6	55	80	63.826495999999999	63.858116000000003	54.704279	54.686349	0103000020E610000001000000050000002D23F59ECAE94F403752B648DA574B402D23F59ECAE94F403A2174D0255A4B405116BEBED6ED4F403A2174D0255A4B405116BEBED6ED4F403752B648DA574B402D23F59ECAE94F403752B648DA574B40
32147	Подуровка	6	55	80	64.000966000000005	64.008386999999999	54.339227000000001	54.333972000000003	0103000020E610000001000000050000001C9AB2D30F005040CEE33098BF2A4B401C9AB2D30F005040C97553CA6B2B4B408AADA06989005040C97553CA6B2B4B408AADA06989005040CEE33098BF2A4B401C9AB2D30F005040CEE33098BF2A4B40
32189	Пески	6	55	80	63.243048999999999	63.274535	54.623837000000002	54.610371000000001	0103000020E61000000100000005000000AA29C93A1C9F4F40A2B60DA3204E4B40AA29C93A1C9F4F4073840CE4D94F4B40BE4D7FF623A34F4073840CE4D94F4B40BE4D7FF623A34F40A2B60DA3204E4B40AA29C93A1C9F4F40A2B60DA3204E4B40
40294	Первомайка	6	55	80	63.249580000000002	63.264977000000002	54.345624999999998	54.339914	0103000020E610000001000000050000002BDEC83CF29F4F40EDB94C4D822B4B402BDEC83CF29F4F400AD7A3703D2C4B409A982EC4EAA14F400AD7A3703D2C4B409A982EC4EAA14F40EDB94C4D822B4B402BDEC83CF29F4F40EDB94C4D822B4B40
145	Патранино	6	55	80	63.211373999999999	63.231262999999998	54.363827000000001	54.359319999999997	0103000020E61000000100000005000000C39CA04D0E9B4F403C66A032FE2D4B40C39CA04D0E9B4F406E3315E2912E4B402EE3A6069A9D4F406E3315E2912E4B402EE3A6069A9D4F403C66A032FE2D4B40C39CA04D0E9B4F403C66A032FE2D4B40
32437	Николаевка	6	55	80	63.306227	63.322397000000002	54.435229	54.430447999999998	0103000020E610000001000000050000007B13437232A74F40765089EB18374B407B13437232A74F40A9A27895B5374B400DAA0D4E44A94F40A9A27895B5374B400DAA0D4E44A94F40765089EB18374B407B13437232A74F40765089EB18374B40
32216	Молоденки	6	55	80	63.335971000000001	63.34693	54.590260000000001	54.579464999999999	0103000020E61000000100000005000000C4B3041901AB4F409C16BCE82B4A4B40C4B3041901AB4F408811C2A38D4B4B402A00C63368AC4F408811C2A38D4B4B402A00C63368AC4F409C16BCE82B4A4B40C4B3041901AB4F409C16BCE82B4A4B40
772	Михалево	6	55	80	63.567304999999998	63.587893999999999	54.297870000000003	54.284343	0103000020E61000000100000005000000BBED42739DC84F405BECF65965244B40BBED42739DC84F40D23AAA9A20264B40DFC14F1C40CB4F40D23AAA9A20264B40DFC14F1C40CB4F405BECF65965244B40BBED42739DC84F405BECF65965244B40
31605	Матвеевка	6	55	80	63.657046000000001	63.680231999999997	54.575592999999998	54.563839000000002	0103000020E61000000100000005000000DBFB54151AD44F40CC9A58E02B484B40DBFB54151AD44F403C670B08AD494B40A9D898D711D74F403C670B08AD494B40A9D898D711D74F40CC9A58E02B484B40DBFB54151AD44F40CC9A58E02B484B40
1140	Марс	6	55	80	63.707872999999999	63.720503000000001	54.426195	54.421402	0103000020E61000000100000005000000575C1C959BDA4F40083C3080F0354B40575C1C959BDA4F40FF5BC98E8D364B40BFD53A7139DC4F40FF5BC98E8D364B40BFD53A7139DC4F40083C3080F0354B40575C1C959BDA4F40083C3080F0354B40
32471	Мануйлово	6	55	80	63.355761000000001	63.366315999999998	54.356057	54.351816999999997	0103000020E610000001000000050000009C18929389AD4F40A296E656082D4B409C18929389AD4F4085419946932D4B4032005471E3AE4F4085419946932D4B4032005471E3AE4F40A296E656082D4B409C18929389AD4F40A296E656082D4B40
55016	Луговое	6	55	80	63.554440999999997	63.570690999999997	54.227111999999998	54.222763999999998	0103000020E61000000100000005000000E04735ECF7C64F40F25CDF87831C4B40E04735ECF7C64F40BB438A01121D4B408E8F16670CC94F40BB438A01121D4B408E8F16670CC94F40F25CDF87831C4B40E04735ECF7C64F40F25CDF87831C4B40
272	Листвянка	6	55	80	64.050464000000005	64.059608999999995	54.417824000000003	54.405301000000001	0103000020E6100000010000000500000006685BCD3A0350409F0436E7E0334B4006685BCD3A035040F1BDBF417B354B40066344A2D0035040F1BDBF417B354B40066344A2D00350409F0436E7E0334B4006685BCD3A0350409F0436E7E0334B40
32377	Кременевка	6	55	80	63.209029999999998	63.220365999999999	54.424571	54.417493999999998	0103000020E6100000010000000500000002F1BA7EC19A4F405B23827170354B4002F1BA7EC19A4F403EEAAF5758364B403E93FDF3349C4F403EEAAF5758364B403E93FDF3349C4F405B23827170354B4002F1BA7EC19A4F405B23827170354B40
32056	Красный Октябрь	6	55	80	63.734544	63.747767000000003	54.274265999999997	54.270311999999997	0103000020E610000001000000050000008CBCAC8905DE4F40B1DB679599224B408CBCAC8905DE4F40CE33F6251B234B4097033DD4B6DF4F40CE33F6251B234B4097033DD4B6DF4F40B1DB679599224B408CBCAC8905DE4F40B1DB679599224B40
54982	Костыгин Лог	6	55	80	63.814655999999999	63.837240000000001	54.438265999999999	54.425235999999998	0103000020E61000000100000005000000BEBED6A546E84F407A8A1C226E364B40BEBED6A546E84F407079AC1919384B40977329AE2AEB4F407079AC1919384B40977329AE2AEB4F407A8A1C226E364B40BEBED6A546E84F407A8A1C226E364B40
237	Косолапово	6	55	80	63.984267000000003	64.004254000000003	54.511802000000003	54.495213	0103000020E610000001000000050000001AC40776FCFD4F40EBC6BB23633F4B401AC40776FCFD4F4082035ABA82414B4024B891B24500504082035ABA82414B4024B891B245005040EBC6BB23633F4B401AC40776FCFD4F40EBC6BB23633F4B40
55023	Кислянка	6	55	80	63.249507999999999	63.282916	54.366219000000001	54.352981999999997	0103000020E61000000100000005000000910BCEE0EF9F4F40D009A1832E2D4B40910BCEE0EF9F4F404016A243E02E4B40F0C16B9736A44F404016A243E02E4B40F0C16B9736A44F40D009A1832E2D4B40910BCEE0EF9F4F40D009A1832E2D4B40
31806	Казак-Кочердык	6	55	80	64.230693000000002	64.252934999999994	54.372366	54.357168999999999	0103000020E61000000100000005000000A29A92ACC30E50409012BBB6B72D4B40A29A92ACC30E5040381268B0A92F4B40E140481630105040381268B0A92F4B40E1404816301050409012BBB6B72D4B40A29A92ACC30E50409012BBB6B72D4B40
31772	Иванково	6	55	80	63.411932	63.428137999999997	54.674272999999999	54.669603000000002	0103000020E6100000010000000500000083161230BAB44F40D926158DB5554B4083161230BAB44F40B4C9E1934E564B406116DA39CDB64F40B4C9E1934E564B406116DA39CDB64F40D926158DB5554B4083161230BAB44F40D926158DB5554B40
60870	Зеленая Сопка	6	55	80	63.854469000000002	63.865222000000003	54.461131999999999	54.454867	0103000020E6100000010000000500000011397D3D5FED4F40CB83F414393A4B4011397D3D5FED4F40CD91955F063B4B40CEE33098BFEE4F40CD91955F063B4B40CEE33098BFEE4F40CB83F414393A4B4011397D3D5FED4F40CB83F414393A4B40
31724	Заманилки	6	55	80	63.583069999999999	63.602176999999998	54.684074000000003	54.673699999999997	0103000020E61000000100000005000000ADA3AA09A2CA4F4058A835CD3B564B40ADA3AA09A2CA4F409F05A1BC8F574B40A2B3CC2214CD4F409F05A1BC8F574B40A2B3CC2214CD4F4058A835CD3B564B40ADA3AA09A2CA4F4058A835CD3B564B40
31566	Дулино	6	55	80	63.728391000000002	63.748666	54.498339999999999	54.491562999999999	0103000020E61000000100000005000000B2D991EA3BDD4F403A765089EB3E4B40B2D991EA3BDD4F40F224E99AC93F4B4046D09849D4DF4F40F224E99AC93F4B4046D09849D4DF4F403A765089EB3E4B40B2D991EA3BDD4F403A765089EB3E4B40
615	Дудино	6	55	80	63.866219000000001	63.887194999999998	54.705621000000001	54.698988	0103000020E610000001000000050000004016A243E0EE4F40F225547078594B404016A243E0EE4F40772FF7C9515A4B405D16139B8FF14F40772FF7C9515A4B405D16139B8FF14F40F225547078594B404016A243E0EE4F40F225547078594B40
661	Воздвиженка	6	55	80	63.866380999999997	63.880763000000002	54.661791999999998	54.651176999999997	0103000020E6100000010000000500000019709692E5EE4F40257497C459534B4019709692E5EE4F409160AA99B5544B4070438CD7BCF04F409160AA99B5544B4070438CD7BCF04F40257497C459534B4019709692E5EE4F40257497C459534B40
31700	Большое Дубровное	6	55	80	63.468077000000001	63.495296000000003	54.589466999999999	54.580382999999998	0103000020E61000000100000005000000418177F2E9BB4F40C2137AFD494A4B40418177F2E9BB4F401E8997A7734B4B4079EBFCDB65BF4F401E8997A7734B4B4079EBFCDB65BF4F40C2137AFD494A4B40418177F2E9BB4F40C2137AFD494A4B40
55054	Белоозерки	6	55	80	63.395367	63.404421999999997	54.360878999999997	54.353712000000002	0103000020E610000001000000050000007575C7629BB24F40F419506F462D4B407575C7629BB24F4016687748312E4B4036E49F19C4B34F4016687748312E4B4036E49F19C4B34F40F419506F462D4B407575C7629BB24F40F419506F462D4B40
30699	Яланское	6	55	1874	62.685994999999998	62.722456999999999	54.982404000000002	54.972835000000003	0103000020E61000000100000005000000191C25AFCE574F40BCB376DB857C4B40191C25AFCE574F40D4BA0D6ABF7D4B4015E29178795C4F40D4BA0D6ABF7D4B4015E29178795C4F40BCB376DB857C4B40191C25AFCE574F40BCB376DB857C4B40
30969	Сулюклино	6	55	1874	62.597087999999999	62.614291000000001	54.929926999999999	54.918861	0103000020E61000000100000005000000C26A2C616D4C4F40F148BC3C9D754B40C26A2C616D4C4F406D5512D907774B40139D6516A14E4F406D5512D907774B40139D6516A14E4F40F148BC3C9D754B40C26A2C616D4C4F40F148BC3C9D754B40
30289	Сулейманово	6	55	1874	62.54363	62.566122999999997	54.767487000000003	54.753461000000001	0103000020E61000000100000005000000EF8FF7AA95454F40DEE7F86871604B40EF8FF7AA95454F40768D96033D624B40B741EDB776484F40768D96033D624B40B741EDB776484F40DEE7F86871604B40EF8FF7AA95454F40DEE7F86871604B40
30602	Субботино	6	55	1874	62.715693000000002	62.734602000000002	54.868341999999998	54.860776999999999	0103000020E61000000100000005000000F27C06D49B5B4F401213D4F02D6E4B40F27C06D49B5B4F4022DFA5D4256F4B40C1C93670075E4F4022DFA5D4256F4B40C1C93670075E4F401213D4F02D6E4B40F27C06D49B5B4F401213D4F02D6E4B40
30383	Сокольники	6	55	1874	62.597141999999998	62.604067999999998	54.816727	54.810237000000001	0103000020E61000000100000005000000B58828266F4C4F402C8194D8B5674B40B58828266F4C4F404E61A5828A684B40B247A819524D4F404E61A5828A684B40B247A819524D4F402C8194D8B5674B40B58828266F4C4F402C8194D8B5674B40
54921	Сафакулево	6	55	1874	62.506709000000001	62.563464000000003	55.002479999999998	54.976275999999999	0103000020E6100000010000000500000060CB2BD7DB404F4052EFA99CF67C4B4060CB2BD7DB404F407172BF4351804B40973C9E961F484F407172BF4351804B40973C9E961F484F4052EFA99CF67C4B4060CB2BD7DB404F4052EFA99CF67C4B40
55031	Сарт-Абдрашево	6	55	1874	62.230862999999999	62.260337	54.78519	54.769849999999998	0103000020E61000000100000005000000A06D35EB8C1D4F40AD69DE718A624B40A06D35EB8C1D4F40B8921D1B81644B4029780AB952214F40B8921D1B81644B4029780AB952214F40AD69DE718A624B40A06D35EB8C1D4F40AD69DE718A624B40
55047	Сарт-Абдрашево	6	55	1874	62.230862999999999	62.260337	54.78519	54.769849999999998	0103000020E61000000100000005000000A06D35EB8C1D4F40AD69DE718A624B40A06D35EB8C1D4F40B8921D1B81644B4029780AB952214F40B8921D1B81644B4029780AB952214F40AD69DE718A624B40A06D35EB8C1D4F40AD69DE718A624B40
30163	Преображенка	6	55	1874	62.153742999999999	62.174152999999997	54.750836999999997	54.741337999999999	0103000020E61000000100000005000000957EC2D9AD134F401AA4E029E45E4B40957EC2D9AD134F4039D0436D1B604B4009C03FA54A164F4039D0436D1B604B4009C03FA54A164F401AA4E029E45E4B40957EC2D9AD134F401AA4E029E45E4B40
29967	Озерная	6	55	1874	62.241382000000002	62.262107	54.853220999999998	54.849645000000002	0103000020E61000000100000005000000EAEBF99AE51E4F40DF1AD82AC16C4B40EAEBF99AE51E4F4055A18158366D4B40BE86E0B88C214F4055A18158366D4B40BE86E0B88C214F40DF1AD82AC16C4B40EAEBF99AE51E4F40DF1AD82AC16C4B40
30448	Надеждинка	6	55	1874	62.662683000000001	62.676364999999997	54.711269999999999	54.695528000000003	0103000020E61000000100000005000000BE4EEACBD2544F40E5B9BE0F07594B40BE4EEACBD2544F401E5036E50A5B4B405B94D92093564F401E5036E50A5B4B405B94D92093564F40E5B9BE0F07594B40BE4EEACBD2544F40E5B9BE0F07594B40
30630	Мурзабаева	6	55	1874	62.773167000000001	62.782491999999998	54.932053000000003	54.925007000000001	0103000020E6100000010000000500000058ACE122F7624F4019C91EA166764B4058ACE122F7624F40C19140834D774B40D9B0A6B228644F40C19140834D774B40D9B0A6B228644F4019C91EA166764B4058ACE122F7624F4019C91EA166764B40
31064	Мартыновка	6	55	1874	62.469213000000003	62.502612999999997	54.918317000000002	54.908852000000003	0103000020E61000000100000005000000D5EDEC2B0F3C4F40BD73284355744B40D5EDEC2B0F3C4F40302E55698B754B40B0C56E9F55404F40302E55698B754B40B0C56E9F55404F40BD73284355744B40D5EDEC2B0F3C4F40BD73284355744B40
29758	Мансурово	6	55	1874	62.268062	62.300491999999998	55.017380000000003	55.003687999999997	0103000020E6100000010000000500000072A609DB4F224F409EB12FD978804B4072A609DB4F224F4060CD018239824B40D55A988576264F4060CD018239824B40D55A988576264F409EB12FD978804B4072A609DB4F224F409EB12FD978804B40
30789	Максимовка	6	55	1874	62.700422000000003	62.705829000000001	54.935043	54.92792	0103000020E6100000010000000500000010B3976DA7594F40F4A62215C6764B4010B3976DA7594F4047AD307DAF774B40C1C8CB9A585A4F4047AD307DAF774B40C1C8CB9A585A4F40F4A62215C6764B4010B3976DA7594F40F4A62215C6764B40
29720	Карасево	6	55	1874	62.360885000000003	62.384754000000001	55.064915999999997	55.049514000000002	0103000020E61000000100000005000000F94ECC7A312E4F40DA58897956864B40F94ECC7A312E4F405A7EE02A4F884B40AA807B9E3F314F405A7EE02A4F884B40AA807B9E3F314F40DA58897956864B40F94ECC7A312E4F40DA58897956864B40
29866	Камышное	6	55	1874	62.279606000000001	62.303303	54.831214000000003	54.811166	0103000020E61000000100000005000000F8E12021CA234F4046D09849D4674B40F8E12021CA234F401AFD6838656A4B40ACE3F8A1D2264F401AFD6838656A4B40ACE3F8A1D2264F4046D09849D4674B40F8E12021CA234F4046D09849D4674B40
55050	Калмык-Абдрашево	6	55	1874	62.734763999999998	62.756512000000001	54.993240999999998	54.982084	0103000020E610000001000000050000009A232BBF0C5E4F4062F6B2EDB47D4B409A232BBF0C5E4F40EE056685227F4B400A849D62D5604F40EE056685227F4B400A849D62D5604F4062F6B2EDB47D4B409A232BBF0C5E4F4062F6B2EDB47D4B40
30338	Бурматово	6	55	1874	62.440494000000001	62.454562000000003	54.770287000000003	54.764251000000002	0103000020E61000000100000005000000C80A7E1B62384F40B8770DFAD2614B40C80A7E1B62384F4059C4B0C398624B408F006E162F3A4F4059C4B0C398624B408F006E162F3A4F40B8770DFAD2614B40C80A7E1B62384F40B8770DFAD2614B40
30557	Бугуй	6	55	1874	62.756872000000001	62.768369999999997	54.812202999999997	54.80442	0103000020E610000001000000050000000AA1832EE1604F40C91F0C3CF7664B400AA1832EE1604F40465B9544F6674B401F9DBAF259624F40465B9544F6674B401F9DBAF259624F40C91F0C3CF7664B400AA1832EE1604F40C91F0C3CF7664B40
29678	Боровичи (Боровое)	6	55	1874	62.568513000000003	62.584251000000002	55.066664000000003	55.052959000000001	0103000020E61000000100000005000000E92CB308C5484F40B2834A5CC7864B40E92CB308C5484F4008E9297288884B40E1D39CBCC84A4F4008E9297288884B40E1D39CBCC84A4F40B2834A5CC7864B40E92CB308C5484F40B2834A5CC7864B40
29893	Большое Султаново	6	55	1874	62.146960999999997	62.169221	54.819263999999997	54.809764999999999	0103000020E61000000100000005000000CB64389ECF124F4004392861A6674B40CB64389ECF124F4023658BA4DD684B40F165A208A9154F4023658BA4DD684B40F165A208A9154F4004392861A6674B40CB64389ECF124F4004392861A6674B40
31082	Бикбирды	6	55	1874	62.381357999999999	62.403016000000001	54.884120000000003	54.874698000000002	0103000020E61000000100000005000000B308C556D0304F4035F0A31AF66F4B40B308C556D0304F40A9DE1AD82A714B40E3E13D0796334F40A9DE1AD82A714B40E3E13D0796334F4035F0A31AF66F4B40B308C556D0304F4035F0A31AF66F4B40
30913	Белое Озеро (Белое)	6	55	1874	62.724136999999999	62.734647000000002	55.063906000000003	55.048988000000001	0103000020E610000001000000050000006A696E85B05C4F40BFF2203D45864B406A696E85B05C4F40540262122E884B40618DB3E9085E4F40540262122E884B40618DB3E9085E4F40BFF2203D45864B406A696E85B05C4F40BFF2203D45864B40
30212	Баязитово	6	55	1874	62.361756999999997	62.371071999999998	54.798499	54.790484999999997	0103000020E61000000100000005000000AE0CAA0D4E2E4F40417DCB9C2E654B40AE0CAA0D4E2E4F40C171193735664B400C3B8C497F2F4F40C171193735664B400C3B8C497F2F4F40417DCB9C2E654B40AE0CAA0D4E2E4F40417DCB9C2E654B40
29601	Бахарево	6	55	1874	62.502459999999999	62.530002000000003	55.106622999999999	55.092958000000003	0103000020E610000001000000050000002AC6F99B50404F4067F3380CE68B4B402AC6F99B50404F402E008DD2A58D4B404568041BD7434F402E008DD2A58D4B404568041BD7434F4067F3380CE68B4B402AC6F99B50404F4067F3380CE68B4B40
30476	Бакаево	6	55	1874	62.578645999999999	62.594437999999997	54.673403	54.662339000000003	0103000020E6100000010000000500000009FB7612114A4F40C4EE3B86C7544B4009FB7612114A4F409F03CB1132564B40F4BF5C8B164C4F409F03CB1132564B40F4BF5C8B164C4F40C4EE3B86C7544B4009FB7612114A4F40C4EE3B86C7544B40
30084	Азналино	6	55	1874	62.273955000000001	62.29768	54.713740999999999	54.702401000000002	0103000020E61000000100000005000000B0C91AF510234F40BFD6A546E8594B40B0C91AF510234F403C6876DD5B5B4B402E56D4601A264F403C6876DD5B5B4B402E56D4601A264F40BFD6A546E8594B40B0C91AF510234F40BFD6A546E8594B40
29812	Аджитарово	6	55	1874	62.128867999999997	62.150427999999998	54.970913000000003	54.958528999999999	0103000020E610000001000000050000001EC022BF7E104F4040A20914B17A4B401EC022BF7E104F4071218FE0467C4B408B33863941134F4071218FE0467C4B408B33863941134F4040A20914B17A4B401EC022BF7E104F4040A20914B17A4B40
30976	Абултаево	6	55	1874	62.569277	62.586111000000002	54.870953	54.858283999999998	0103000020E61000000100000005000000B8AE9811DE484F400C570740DC6D4B40B8AE9811DE484F4032AD4D637B6F4B40B6696CAF054B4F4032AD4D637B6F4B40B6696CAF054B4F400C570740DC6D4B40B8AE9811DE484F400C570740DC6D4B40
29403	сельского типа Боровлянка	6	55	1838	64.981082000000001	65.014931000000004	54.627996000000003	54.615955	0103000020E610000001000000050000006F2C280CCA3E504062670A9DD74E4B406F2C280CCA3E50406902452C62504B40952C27A1F44050406902452C62504B40952C27A1F440504062670A9DD74E4B406F2C280CCA3E504062670A9DD74E4B40
29544	Ясная	6	55	1838	65.355788000000004	65.365678000000003	54.610965	54.603712000000002	0103000020E61000000100000005000000CB13083BC5565040F419506F464D4B40CB13083BC55650401500E319344E4B4078B7B244675750401500E319344E4B4078B7B24467575040F419506F464D4B40CB13083BC5565040F419506F464D4B40
55042	Ярославское	6	55	1838	65.288881000000003	65.313522000000006	55.046723	55.035715000000003	0103000020E61000000100000005000000E4DBBB067D525040037D224F92844B40E4DBBB067D5250404A7CEE04FB854B40E62494BE105450404A7CEE04FB854B40E62494BE10545040037D224F92844B40E4DBBB067D525040037D224F92844B40
28990	Ялым	6	55	1838	65.064177000000001	65.095375000000004	54.777298000000002	54.758090000000003	0103000020E61000000100000005000000F209D9791B4450405BB6D61709614B40F209D9791B445040849F38807E634B40C976BE9F1A465040849F38807E634B40C976BE9F1A4650405BB6D61709614B40F209D9791B4450405BB6D61709614B40
28424	Чернавское	6	55	1838	65.105857999999998	65.125800999999996	55.005536999999997	54.987270000000002	0103000020E610000001000000050000004701A260C6465040352905DD5E7E4B404701A260C64650407FF5B86FB5804B407633A31F0D4850407FF5B86FB5804B407633A31F0D485040352905DD5E7E4B404701A260C6465040352905DD5E7E4B40
28587	Утятское	6	55	1838	65.173159999999996	65.189276000000007	55.168871000000003	55.152088999999997	0103000020E610000001000000050000006C3EAE0D154B5040698A00A777934B406C3EAE0D154B5040151F9F909D954B40BC7A15191D4C5040151F9F909D954B40BC7A15191D4C5040698A00A777934B406C3EAE0D154B5040698A00A777934B40
55037	Туманова	6	55	1838	65.446706000000006	65.465273999999994	54.839602999999997	54.829532999999998	0103000020E61000000100000005000000543BC3D4965C5040F4F928232E6A4B40543BC3D4965C5040CE4F711C786B4B40766B990CC75D5040CE4F711C786B4B40766B990CC75D5040F4F928232E6A4B40543BC3D4965C5040F4F928232E6A4B40
28431	Раскатиха	6	55	1838	65.154628000000002	65.189841999999999	55.047471000000002	55.036127999999998	0103000020E61000000100000005000000F0C2D66CE5495040253CA1D79F844B40F0C2D66CE549504014419C8713864B40105A0F5F264C504014419C8713864B40105A0F5F264C5040253CA1D79F844B40F0C2D66CE5495040253CA1D79F844B40
29498	Притобольное	6	55	1838	65.144288000000003	65.157341000000002	54.617142999999999	54.608472999999996	0103000020E61000000100000005000000234DBC033C495040DFBF7971E24D4B40234DBC033C49504048FAB48AFE4E4B407A54FCDF114A504048FAB48AFE4E4B407A54FCDF114A5040DFBF7971E24D4B40234DBC033C495040DFBF7971E24D4B40
29344	Плотниково	6	55	1838	65.057519999999997	65.071579	54.735734000000001	54.710121000000001	0103000020E610000001000000050000006BB75D68AE435040F699B33EE55A4B406BB75D68AE43504013471E882C5E4B40250516C09444504013471E882C5E4B40250516C094445040F699B33EE55A4B406BB75D68AE435040F699B33EE55A4B40
28844	Патраки	6	55	1838	65.455815000000001	65.478722000000005	54.951875000000001	54.944682999999998	0103000020E61000000100000005000000AE81AD122C5D5040280B5F5FEB784B40AE81AD122C5D5040A4703D0AD7794B400C789961A35E5040A4703D0AD7794B400C789961A35E5040280B5F5FEB784B40AE81AD122C5D5040280B5F5FEB784B40
28700	Осиновка	6	55	1838	65.327894999999998	65.366153999999995	54.989775999999999	54.976430999999998	0103000020E6100000010000000500000067614F3BFC54504079E6E5B0FB7C4B4067614F3BFC545040CF2EDFFAB07E4B402CD32F116F575040CF2EDFFAB07E4B402CD32F116F57504079E6E5B0FB7C4B4067614F3BFC54504079E6E5B0FB7C4B40
28622	Обухово	6	55	1838	65.376178999999993	65.409794000000005	55.085816999999999	55.075395999999998	0103000020E61000000100000005000000499C155113585040E61F7D93A6894B40499C1551135850406D382C0DFC8A4B4036069D103A5A50406D382C0DFC8A4B4036069D103A5A5040E61F7D93A6894B40499C155113585040E61F7D93A6894B40
29155	Обрядовка	6	55	1838	65.250423999999995	65.263872000000006	54.769497000000001	54.763269999999999	0103000020E610000001000000050000008B8862F2065050404B02D4D4B2614B408B8862F20650504060AFB0E07E624B4021956247E350504060AFB0E07E624B4021956247E35050404B02D4D4B2614B408B8862F2065050404B02D4D4B2614B40
29095	Новокаминка	6	55	1838	65.178173000000001	65.20205	54.781295999999998	54.771532999999998	0103000020E61000000100000005000000EF01BA2F674B50407364E597C1624B40EF01BA2F674B5040703FE08101644B40098A1F63EE4C5040703FE08101644B40098A1F63EE4C50407364E597C1624B40EF01BA2F674B50407364E597C1624B40
29302	Нижняя Алабуга	6	55	1838	65.310674000000006	65.335504	54.703572000000001	54.694398999999997	0103000020E61000000100000005000000EC6D3315E253504003B00111E2584B40EC6D3315E2535040CF30B5A50E5A4B4057EBC4E578555040CF30B5A50E5A4B4057EBC4E57855504003B00111E2584B40EC6D3315E253504003B00111E2584B40
28516	Нагорское	6	55	1838	65.187740000000005	65.203613000000004	55.160235999999998	55.141094000000002	0103000020E61000000100000005000000AB09A2EE034C5040B7D4415E0F924B40AB09A2EE034C504028D2FD9C82944B409702D2FE074D504028D2FD9C82944B409702D2FE074D5040B7D4415E0F924B40AB09A2EE034C5040B7D4415E0F924B40
29433	Мочалово	6	55	1838	65.015424999999993	65.035341000000003	54.654854999999998	54.642597000000002	0103000020E610000001000000050000009CA223B9FC405040FDC0559E40524B409CA223B9FC405040A04FE449D2534B404FCDE50643425040A04FE449D2534B404FCDE50643425040FDC0559E40524B409CA223B9FC405040FDC0559E40524B40
54972	Межборное	6	55	1838	65.086185	65.119682999999995	54.967723999999997	54.940886999999996	0103000020E61000000100000005000000F819170E84455040A31D37FC6E784B40F819170E84455040F3C64961DE7B4B40C7B8E2E2A8475040F3C64961DE7B4B40C7B8E2E2A8475040A31D37FC6E784B40F819170E84455040A31D37FC6E784B40
28489	Камышное	6	55	1838	65.1751	65.195079000000007	55.107056	55.096234000000003	0103000020E61000000100000005000000E561A1D6344B5040B3614D65518C4B40E561A1D6344B5040986BD102B48D4B40BB48A12C7C4C5040986BD102B48D4B40BB48A12C7C4C5040B3614D65518C4B40E561A1D6344B5040B3614D65518C4B40
29230	Ершовка	6	55	1838	65.477878000000004	65.502761000000007	54.723647	54.715904000000002	0103000020E61000000100000005000000965E9B8D955E5040AD8905BEA25B4B40965E9B8D955E50409C6C0377A05C4B40132D793C2D6050409C6C0377A05C4B40132D793C2D605040AD8905BEA25B4B40965E9B8D955E5040AD8905BEA25B4B40
28790	Давыдовка	6	55	1838	65.379458	65.419495999999995	54.942444000000002	54.924717999999999	0103000020E61000000100000005000000280D350A49585040E202D0285D764B40280D350A49585040DD274701A2784B406133C005D95A5040DD274701A2784B406133C005D95A5040E202D0285D764B40280D350A49585040E202D0285D764B40
54950	Глядянское	6	55	1838	65.076842999999997	65.111895000000004	54.920102999999997	54.895341000000002	0103000020E610000001000000050000004CFBE6FEEA4450404CE2AC889A724B404CFBE6FEEA445040CAF962EFC5754B408065A54929475040CAF962EFC5754B408065A549294750404CE2AC889A724B404CFBE6FEEA4450404CE2AC889A724B40
29159	Гладковское	6	55	1838	65.444083000000006	65.464348999999999	54.720699000000003	54.714022	0103000020E610000001000000050000006A6D1ADB6B5C5040F04FA912655B4B406A6D1ADB6B5C504045A165DD3F5C4B408A3BDEE4B75D504045A165DD3F5C4B408A3BDEE4B75D5040F04FA912655B4B406A6D1ADB6B5C5040F04FA912655B4B40
28980	Водный	6	55	1838	65.101861	65.107718000000006	54.822620000000001	54.815300999999998	0103000020E6100000010000000500000039EFFFE384465040B3B27DC85B684B4039EFFFE3844650408C84B69C4B694B4032CC09DAE44650408C84B69C4B694B4032CC09DAE4465040B3B27DC85B684B4039EFFFE384465040B3B27DC85B684B40
28919	Верхнеберезово	6	55	1838	65.097863000000004	65.112128999999996	54.841256999999999	54.828066	0103000020E61000000100000005000000431F2C6343465040FB761211FE694B40431F2C6343465040FA43334FAE6B4B40B9FB1C1F2D475040FA43334FAE6B4B40B9FB1C1F2D475040FB761211FE694B40431F2C6343465040FB761211FE694B40
29285	Банщиково	6	55	1838	65.382935000000003	65.395456999999993	54.713501000000001	54.708004000000003	0103000020E610000001000000050000009A5FCD0182585040F6B704E09F5A4B409A5FCD0182585040E7543200545B4B405A7EE02A4F595040E7543200545B4B405A7EE02A4F595040F6B704E09F5A4B409A5FCD0182585040F6B704E09F5A4B40
28302	Арсеновка	6	55	1838	65.104071000000005	65.114743000000004	54.923155000000001	54.914012	0103000020E61000000100000005000000925D6919A946504066136058FE744B40925D6919A9465040C7116BF129764B407A1C06F357475040C7116BF129764B407A1C06F35747504066136058FE744B40925D6919A946504066136058FE744B40
28057	Яровое	6	55	1806	66.184348999999997	66.233468999999999	54.886755999999998	54.876392000000003	0103000020E610000001000000050000003883BF5FCC8B5040EF3CF19C2D704B403883BF5FCC8B504011C4793881714B404FE8F527F18E504011C4793881714B404FE8F527F18E5040EF3CF19C2D704B403883BF5FCC8B5040EF3CF19C2D704B40
27894	Чулошное	6	55	1806	66.205539999999999	66.219796000000002	54.766219999999997	54.755507999999999	0103000020E6100000010000000500000045813E91278D5040E5EE737CB4604B4045813E91278D504043C5387F13624B40AAF23D23118E504043C5387F13624B40AAF23D23118E5040E5EE737CB4604B4045813E91278D5040E5EE737CB4604B40
27907	Чернавчик	6	55	1806	66.492407999999998	66.508415999999997	54.83614	54.831670000000003	0103000020E610000001000000050000007B12D89C839F50403C889D29746A4B407B12D89C839F50405070B1A2066B4B40D73043E389A050405070B1A2066B4B40D73043E389A050403C889D29746A4B407B12D89C839F50403C889D29746A4B40
27889	Хлупово	6	55	1806	65.889019000000005	65.909724999999995	54.782967999999997	54.766286999999998	0103000020E6100000010000000500000073A1F2AFE5785040CB2C42B115624B4073A1F2AFE578504042E8A04B38644B40A1D634EF387A504042E8A04B38644B40A1D634EF387A5040CB2C42B115624B4073A1F2AFE5785040CB2C42B115624B40
27520	Филиппово	6	55	1806	66.077494000000002	66.092028999999997	54.685296999999998	54.676521999999999	0103000020E61000000100000005000000B8E864A9F58450402383DC4598564B40B8E864A9F58450400186E5CFB7574B4026529ACDE38550400186E5CFB7574B4026529ACDE38550402383DC4598564B40B8E864A9F58450402383DC4598564B40
27990	Успенка	6	55	1806	66.359610000000004	66.376328000000001	54.797688999999998	54.784706999999997	0103000020E610000001000000050000002254A9D9039750409CF86A4771644B402254A9D90397504081B053AC1A664B406C2409C21598504081B053AC1A664B406C2409C2159850409CF86A4771644B402254A9D9039750409CF86A4771644B40
27798	Сухмень	6	55	1806	66.574352000000005	66.605497	54.883364	54.862720000000003	0103000020E610000001000000050000001A19E42EC2A4504075CDE49B6D6E4B401A19E42EC2A450405C3B511212714B40DF347D76C0A650405C3B511212714B40DF347D76C0A6504075CDE49B6D6E4B401A19E42EC2A4504075CDE49B6D6E4B40
27643	Сумки	6	55	1806	65.769722000000002	65.782298999999995	55.055903000000001	55.049647999999998	0103000020E61000000100000005000000C040102043715040E9279CDD5A864B40C040102043715040C85F5AD427874B40622CD32F11725040C85F5AD427874B40622CD32F11725040E9279CDD5A864B40C040102043715040E9279CDD5A864B40
27155	Романово	6	55	1806	65.575317999999996	65.595207000000002	54.641289999999998	54.637132000000001	0103000020E6100000010000000500000035B39602D2645040179E978A8D514B4035B39602D26450403CA06CCA15524B406BD619DF176650403CA06CCA15524B406BD619DF17665040179E978A8D514B4035B39602D2645040179E978A8D514B40
27567	Привольное	6	55	1806	66.706260999999998	66.728925000000004	54.790433	54.784846999999999	0103000020E610000001000000050000002D5C566133AD50408EAED2DD75644B402D5C566133AD5040EF5696E82C654B40280F0BB5A6AE5040EF5696E82C654B40280F0BB5A6AE50408EAED2DD75644B402D5C566133AD50408EAED2DD75644B40
54948	Половинное	6	55	1806	65.947570999999996	66.019041000000001	54.806339999999999	54.781623000000003	0103000020E61000000100000005000000D5E8D500A57C50409566F3380C644B40D5E8D500A57C504073BA2C2636674B401F12BEF73781504073BA2C2636674B401F12BEF7378150409566F3380C644B40D5E8D500A57C50409566F3380C644B40
27149	Пищальное	6	55	1806	65.677160000000001	65.695314999999994	54.698493999999997	54.685614999999999	0103000020E61000000100000005000000338AE596566B5040D252793BC2574B40338AE596566B5040E2395B4068594B40C45A7C0A806C5040E2395B4068594B40C45A7C0A806C5040D252793BC2574B40338AE596566B5040D252793BC2574B40
27438	Петровка	6	55	1806	65.990852000000004	65.998424	54.762880000000003	54.751305000000002	0103000020E6100000010000000500000047CB811E6A7F5040202922C32A604B4047CB811E6A7F5040E162450DA6614B40A8E2C62DE67F5040E162450DA6614B40A8E2C62DE67F5040202922C32A604B4047CB811E6A7F5040202922C32A604B40
27022	Новые Байдары	6	55	1806	65.840204	65.868223	54.953121000000003	54.935628000000001	0103000020E61000000100000005000000FA7DFFE6C5755040679C86A8C2774B40FA7DFFE6C5755040BF1072DEFF794B40A4A833F790775040BF1072DEFF794B40A4A833F790775040679C86A8C2774B40FA7DFFE6C5755040679C86A8C2774B40
27978	Новая Украинка	6	55	1806	66.067828000000006	66.078418999999997	54.764366000000003	54.756776000000002	0103000020E610000001000000050000003370404B57845040E8323509DE604B403370404B578450405116BEBED6614B40A41820D1048550405116BEBED6614B40A41820D104855040E8323509DE604B403370404B57845040E8323509DE604B40
26970	Менщиково	6	55	1806	65.649203999999997	65.670512000000002	54.824606000000003	54.813884000000002	0103000020E61000000100000005000000AC1BEF8E8C6950406C5ED5592D684B40AC1BEF8E8C695040EE0A7DB08C694B40D6E429ABE96A5040EE0A7DB08C694B40D6E429ABE96A50406C5ED5592D684B40AC1BEF8E8C6950406C5ED5592D684B40
27041	Марай	6	55	1806	65.871834000000007	65.889773000000005	54.946989000000002	54.930843000000003	0103000020E610000001000000050000009E62D520CC775040F35A09DD25774B409E62D520CC775040FC5580EF36794B4049F7730AF2785040FC5580EF36794B4049F7730AF2785040F35A09DD25774B409E62D520CC775040F35A09DD25774B40
55055	Малодубровное	6	55	1806	65.670755	65.694264000000004	55.082689000000002	55.069060999999998	0103000020E61000000100000005000000392861A6ED6A5040EB36A8FDD6884B40392861A6ED6A5040965E9B8D958A4B4092B245D26E6C5040965E9B8D958A4B4092B245D26E6C5040EB36A8FDD6884B40392861A6ED6A5040EB36A8FDD6884B40
28130	Казенное	6	55	1806	66.220963999999995	66.227225000000004	54.916139000000001	54.907438999999997	0103000020E61000000100000005000000F9653046248E5040B60E0EF626744B40F9653046248E50408ACBF10A44754B405AF5B9DA8A8E50408ACBF10A44754B405AF5B9DA8A8E5040B60E0EF626744B40F9653046248E5040B60E0EF626744B40
27091	Жилино	6	55	1806	65.910658999999995	65.924565000000001	54.887590000000003	54.877102000000001	0103000020E61000000100000005000000B7B3AF3C487A5040CBA0DAE044704B40B7B3AF3C487A5040DA20938C9C714B40AE81AD122C7B5040DA20938C9C714B40AE81AD122C7B5040CBA0DAE044704B40B7B3AF3C487A5040CBA0DAE044704B40
27417	Дубровка	6	55	1806	66.009338999999997	66.025895000000006	54.828932000000002	54.826825999999997	0103000020E61000000100000005000000F3E49A0299805040C2BD326FD5694B40F3E49A0299805040CF4D9B711A6A4B4051888043A8815040CF4D9B711A6A4B4051888043A8815040C2BD326FD5694B40F3E49A0299805040C2BD326FD5694B40
26892	Воскресенское	6	55	1806	65.77328	65.796456000000006	54.642488	54.631321	0103000020E61000000100000005000000A8A9656B7D71504096236420CF504B40A8A9656B7D7150404609FA0B3D524B40FE2C9622F97250404609FA0B3D524B40FE2C9622F972504096236420CF504B40A8A9656B7D71504096236420CF504B40
27594	Воздвиженка	6	55	1806	66.499262000000002	66.516167999999993	54.766790999999998	54.763742000000001	0103000020E61000000100000005000000AD889AE8F39F5040734A404CC2614B40AD889AE8F39F5040FEEE1D3526624B4078CF81E508A15040FEEE1D3526624B4078CF81E508A15040734A404CC2614B40AD889AE8F39F5040734A404CC2614B40
26885	Васильевка	6	55	1806	66.067119000000005	66.086072999999999	54.893492999999999	54.882886999999997	0103000020E610000001000000050000002D7C7DAD4B8450402288F37002714B402D7C7DAD4B8450403B1A87FA5D724B4064045438828550403B1A87FA5D724B4064045438828550402288F37002714B402D7C7DAD4B8450402288F37002714B40
26810	Булдак	6	55	1806	66.110004000000004	66.128752000000006	55.042447000000003	55.033703000000003	0103000020E61000000100000005000000789B374E0A8750407863416150844B40789B374E0A8750401B683EE76E854B40DB5207793D8850401B683EE76E854B40DB5207793D8850407863416150844B40789B374E0A8750407863416150844B40
26772	Башкирское	6	55	1806	65.835155999999998	65.858179000000007	54.737516999999997	54.722467000000002	0103000020E61000000100000005000000B9C326327375504039B874CC795C4B40B9C32632737550403C9F01F5665E4B404CC79C67EC7650403C9F01F5665E4B404CC79C67EC76504039B874CC795C4B40B9C326327375504039B874CC795C4B40
28099	Батырево	6	55	1806	66.353213999999994	66.370407999999998	54.892347999999998	54.887610000000002	0103000020E61000000100000005000000519FE40E9B96504021CD58349D714B40519FE40E9B9650405453927538724B40508BC1C3B49750405453927538724B40508BC1C3B497504021CD58349D714B40519FE40E9B96504021CD58349D714B40
26730	Байдары	6	55	1806	65.840860000000006	65.873638999999997	55.016506999999997	54.995151999999997	0103000020E61000000100000005000000EF2076A6D075504045460724617F4B40EF2076A6D0755040D993C0E61C824B40A6608DB3E9775040D993C0E61C824B40A6608DB3E977504045460724617F4B40EF2076A6D075504045460724617F4B40
26105	Утчанское	6	55	1293	67.901398	67.910703999999996	55.286178999999997	55.275185	0103000020E6100000010000000500000082AB3C81B0F95040C5AC174339A34B4082AB3C81B0F95040A7E67283A1A44B4087156EF948FA5040A7E67283A1A44B4087156EF948FA5040C5AC174339A34B4082AB3C81B0F95040C5AC174339A34B40
26344	Троицкое	6	55	1293	68.047175999999993	68.073272000000003	55.153015000000003	55.142930999999997	0103000020E61000000100000005000000FD497CEE04035140D34A21904B924B40FD497CEE040351401366DAFE95934B409AED0A7DB00451401366DAFE95934B409AED0A7DB0045140D34A21904B924B40FD497CEE04035140D34A21904B924B40
24746	Стрельцы	6	55	1293	67.716093000000001	67.739602000000005	54.970126999999998	54.964405999999997	0103000020E6100000010000000500000040F9BB77D4ED50407808E3A7717B4B4040F9BB77D4ED5040B9FB1C1F2D7C4B409983A0A355EF5040B9FB1C1F2D7C4B409983A0A355EF50407808E3A7717B4B4040F9BB77D4ED50407808E3A7717B4B40
26680	Староберезово	6	55	1293	67.782550000000001	67.796582000000001	55.155304000000001	55.147762	0103000020E61000000100000005000000075F984C15F25040B8CB7EDDE9924B40075F984C15F2504010786000E1934B4044A51133FBF2504010786000E1934B4044A51133FBF25040B8CB7EDDE9924B40075F984C15F25040B8CB7EDDE9924B40
26575	Рынки	6	55	1293	67.701566999999997	67.725758999999996	55.183621000000002	55.176116	0103000020E61000000100000005000000FB3C4679E6EC5040B32616F88A964B40FB3C4679E6EC5040EEED96E480974B40C571E0D572EE5040EEED96E480974B40C571E0D572EE5040B32616F88A964B40FB3C4679E6EC5040B32616F88A964B40
26012	Пьянково	6	55	1293	67.561860999999993	67.574105000000003	55.144129999999997	55.136029999999998	0103000020E6100000010000000500000076F9D687F5E350402FA3586E69914B4076F9D687F5E35040AD2F12DA72924B4016DEE522BEE45040AD2F12DA72924B4016DEE522BEE450402FA3586E69914B4076F9D687F5E350402FA3586E69914B40
26548	Подувальная	6	55	1293	67.522677000000002	67.538730000000001	54.867103999999998	54.863	0103000020E61000000100000005000000C5573B8A73E150405839B4C8766E4B40C5573B8A73E150408A1D8D43FD6E4B40F1D7648D7AE250408A1D8D43FD6E4B40F1D7648D7AE250405839B4C8766E4B40C5573B8A73E150405839B4C8766E4B40
13535	Петухово	6	55	1293	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
26451	Петухово	6	55	1293	67.944552999999999	67.971152000000004	55.107118	55.098072999999999	0103000020E61000000100000005000000AD156D8E73FC504070CFF3A78D8C4B40AD156D8E73FC50400E68E90AB68D4B407BDCB75A27FE50400E68E90AB68D4B407BDCB75A27FE504070CFF3A78D8C4B40AD156D8E73FC504070CFF3A78D8C4B40
25949	Песьяное	6	55	1293	68.458605000000006	68.473849000000001	55.253152999999998	55.247539000000003	0103000020E610000001000000050000000E32C9C8591D514006BEA25BAF9F4B400E32C9C8591D514030F1475167A04B40828FC18A531E514030F1475167A04B40828FC18A531E514006BEA25BAF9F4B400E32C9C8591D514006BEA25BAF9F4B40
26258	Пашково	6	55	1293	68.156214000000006	68.191410000000005	55.259315000000001	55.239922	0103000020E610000001000000050000005A4B0169FF095140A3CB9BC3B59E4B405A4B0169FF0951405E2EE23B31A14B402788BA0F400C51405E2EE23B31A14B402788BA0F400C5140A3CB9BC3B59E4B405A4B0169FF095140A3CB9BC3B59E4B40
54981	Октябрьское	6	55	1293	67.839387000000002	67.871150999999998	55.014453000000003	55.006186999999997	0103000020E61000000100000005000000016C4084B8F55040865451BCCA804B40016C4084B8F55040202A8D98D9814B402CB81FF0C0F75040202A8D98D9814B402CB81FF0C0F75040865451BCCA804B40016C4084B8F55040865451BCCA804B40
25608	Новое Ильинское	6	55	1293	68.043717999999998	68.067729999999997	55.250520000000002	55.239471000000002	0103000020E61000000100000005000000C70F9546CC02514093AB58FCA69E4B40C70F9546CC025140397F130A11A04B4051BD35B055045140397F130A11A04B4051BD35B05504514093AB58FCA69E4B40C70F9546CC02514093AB58FCA69E4B40
26065	Новогеоргиевка 2-я	6	55	1293	67.823909	67.849806999999998	55.280928000000003	55.272953999999999	0103000020E610000001000000050000005378D0ECBAF45040FCA71B28F0A24B405378D0ECBAF45040EE43DE72F5A34B405C3AE63C63F65040EE43DE72F5A34B405C3AE63C63F65040FCA71B28F0A24B405378D0ECBAF45040FCA71B28F0A24B40
26624	Новогеоргиевка 1-я	6	55	1293	67.655096999999998	67.669416999999996	55.231216000000003	55.228608000000001	0103000020E610000001000000050000004BADF71BEDE950404FCDE506439D4B404BADF71BEDE95040EE27637C989D4B40BB9866BAD7EA5040EE27637C989D4B40BB9866BAD7EA50404FCDE506439D4B404BADF71BEDE950404FCDE506439D4B40
25917	Новоберезово	6	55	1293	67.773872999999995	67.796052000000003	55.086311000000002	55.072761999999997	0103000020E6100000010000000500000079909E2287F150401E32E54350894B4079909E2287F150407D24253D0C8B4B40967A1684F2F250407D24253D0C8B4B40967A1684F2F250401E32E54350894B4079909E2287F150401E32E54350894B40
25432	Новая Лебяжка	6	55	1293	68.613393000000002	68.619664	55.260618000000001	55.248576	0103000020E610000001000000050000001AA6B6D44127514006499F56D19F4B401AA6B6D441275140DD5F3DEE5BA14B408CA03193A8275140DD5F3DEE5BA14B408CA03193A827514006499F56D19F4B401AA6B6D44127514006499F56D19F4B40
25762	Матасы	6	55	1293	68.025813999999997	68.049045000000007	55.011705999999997	55.001787999999998	0103000020E61000000100000005000000DA71C3EFA60151403BC3D4963A804B40DA71C3EFA60151405F950B957F814B4012C2A38D230351405F950B957F814B4012C2A38D230351403BC3D4963A804B40DA71C3EFA60151403BC3D4963A804B40
55013	Курорт Озеро Медвежье	6	55	1293	67.929191000000003	68.086997999999994	55.243166000000002	55.151451000000002	0103000020E61000000100000005000000342F87DD77FB504027F911BF62934B40342F87DD77FB5040E4BF4010209F4B4050340F6091055140E4BF4010209F4B4050340F609105514027F911BF62934B40342F87DD77FB504027F911BF62934B40
13828	Курорт ''Озеро Медвежье''	6	55	1293	67.929191000000003	68.086997999999994	55.243166000000002	55.151451000000002	0103000020E61000000100000005000000342F87DD77FB504027F911BF62934B40342F87DD77FB5040E4BF4010209F4B4050340F6091055140E4BF4010209F4B4050340F609105514027F911BF62934B40342F87DD77FB504027F911BF62934B40
26372	Казанцевское	6	55	1293	68.188597999999999	68.205063999999993	55.114868000000001	55.110202999999998	0103000020E61000000100000005000000D38558FD110C5140E675C4211B8E4B40D38558FD110C5140B0AD9FFEB38E4B409065C1C41F0D5140B0AD9FFEB38E4B409065C1C41F0D5140E675C4211B8E4B40D38558FD110C5140E675C4211B8E4B40
25702	Зотино	6	55	1293	68.045531999999994	68.059967999999998	55.086382999999998	55.079616999999999	0103000020E61000000100000005000000F9BA0CFFE9025140529ACDE3308A4B40F9BA0CFFE902514016F71F990E8B4B409EB30584D603514016F71F990E8B4B409EB30584D6035140529ACDE3308A4B40F9BA0CFFE9025140529ACDE3308A4B40
26114	Золотовка	6	55	1293	67.873514	67.885884000000004	55.285569000000002	55.277898	0103000020E6100000010000000500000048A643A7E7F75040D9CF622992A34B4048A643A7E7F750402FE065868DA44B402E03CE52B2F850402FE065868DA44B402E03CE52B2F85040D9CF622992A34B4048A643A7E7F75040D9CF622992A34B40
25603	Жидки	6	55	1293	68.113821999999999	68.144660999999999	55.312645000000003	55.302498999999997	0103000020E610000001000000050000002EE411DC480751404E098849B8A64B402EE411DC48075140042159C004A84B406D00362042095140042159C004A84B406D003620420951404E098849B8A64B402EE411DC480751404E098849B8A64B40
25818	Горбуново	6	55	1293	68.183801000000003	68.194481999999994	55.016480999999999	55.009967000000003	0103000020E6100000010000000500000037FE4465C30B51400685419946814B4037FE4465C30B5140B000A60C1C824B40486AA164720C5140B000A60C1C824B40486AA164720C51400685419946814B4037FE4465C30B51400685419946814B40
25746	Горбунешное	6	55	1293	68.209402999999995	68.225052000000005	55.076957999999998	55.072968000000003	0103000020E61000000100000005000000CB2BD7DB660D5140C8D3F20357894B40CB2BD7DB660D514031957EC2D9894B4090F98040670E514031957EC2D9894B4090F98040670E5140C8D3F20357894B40CB2BD7DB660D5140C8D3F20357894B40
26163	Воробьи	6	55	1293	67.721770000000006	67.737544999999997	55.326712000000001	55.320856999999997	0103000020E61000000100000005000000F94ECC7A31EE5040A9D898D711A94B40F94ECC7A31EE5040FA9AE5B2D1A94B400395F1EF33EF5040FA9AE5B2D1A94B400395F1EF33EF5040A9D898D711A94B40F94ECC7A31EE5040A9D898D711A94B40
26295	Буранное	6	55	1293	68.132767999999999	68.142757000000003	55.228973000000003	55.226118	0103000020E61000000100000005000000247D5A457F085140BA84436FF19C4B40247D5A457F0851406155BDFC4E9D4B409B9141EE220951406155BDFC4E9D4B409B9141EE22095140BA84436FF19C4B40247D5A457F085140BA84436FF19C4B40
26474	Большое Приютное	6	55	1293	67.581740999999994	67.609948000000003	54.914394999999999	54.907434000000002	0103000020E61000000100000005000000826F9A3E3BE55040A5A31CCC26744B40826F9A3E3BE550401E5036E50A754B40AE10566309E750401E5036E50A754B40AE10566309E75040A5A31CCC26744B40826F9A3E3BE55040A5A31CCC26744B40
25394	Большое Каменное	6	55	1293	68.554445999999999	68.577685000000002	55.296903	55.288542	0103000020E610000001000000050000007959130B7C235140DFC2BAF1EEA44B407959130B7C235140CA8AE1EA00A64B40F29881CAF8245140CA8AE1EA00A64B40F29881CAF8245140DFC2BAF1EEA44B407959130B7C235140DFC2BAF1EEA44B40
25514	Большое Гусиное	6	55	1293	67.403604999999999	67.441164000000001	54.989821999999997	54.980549000000003	0103000020E6100000010000000500000022E010AAD4D9504011902FA1827D4B4022E010AAD4D950403F6EBF7CB27E4B400B0BEE073CDC50403F6EBF7CB27E4B400B0BEE073CDC504011902FA1827D4B4022E010AAD4D9504011902FA1827D4B40
24815	Богданы	6	55	1293	67.589988000000005	67.611305000000002	54.955148000000001	54.945914000000002	0103000020E610000001000000050000001442075DC2E550400E6ABFB513794B401442075DC2E550407F6B274A427A4B4067B8019F1FE750407F6B274A427A4B4067B8019F1FE750400E6ABFB513794B401442075DC2E550400E6ABFB513794B40
25326	Актабан	6	55	1293	68.311982	68.338751000000002	55.316785000000003	55.301842999999998	0103000020E6100000010000000500000034BC5983F713514065C39ACAA2A64B4034BC5983F7135140836E2F698CA84B40309FAC18AE155140836E2F698CA84B40309FAC18AE15514065C39ACAA2A64B4034BC5983F713514065C39ACAA2A64B40
23586	Щигры	6	55	1680	66.613932000000005	66.626293000000004	55.993428999999999	55.985492999999998	0103000020E61000000100000005000000F27D71A94AA75040EDB776A224FE4B40F27D71A94AA75040F1F274AE28FF4B40AE2D3C2F15A85040F1F274AE28FF4B40AE2D3C2F15A85040EDB776A224FE4B40F27D71A94AA75040EDB776A224FE4B40
24668	Шелепово	6	55	1680	67.293328000000002	67.309004000000002	55.718471000000001	55.707745000000003	0103000020E6100000010000000500000012C0CDE2C5D250402A745E6397DA4B4012C0CDE2C5D25040ED0F94DBF6DB4B405395B6B8C6D35040ED0F94DBF6DB4B405395B6B8C6D350402A745E6397DA4B4012C0CDE2C5D250402A745E6397DA4B40
23323	Чесноково	6	55	1680	66.892464000000004	66.903693000000004	55.805188999999999	55.792878000000002	0103000020E61000000100000005000000DF3653211EB95040E4DBBB067DE54B40DF3653211EB95040AA0CE36E10E74B40F2272A1BD6B95040AA0CE36E10E74B40F2272A1BD6B95040E4DBBB067DE54B40DF3653211EB95040E4DBBB067DE54B40
24283	Утичье	6	55	1680	66.886921000000001	66.915254000000004	55.709353	55.697406999999998	0103000020E61000000100000005000000AE484C50C3B850403080F0A144D94B40AE484C50C3B85040E5284014CCDA4B402062838593BA5040E5284014CCDA4B402062838593BA50403080F0A144D94B40AE484C50C3B850403080F0A144D94B40
23506	Уварово	6	55	1680	66.647053	66.662208000000007	55.939740999999998	55.920093000000001	0103000020E61000000100000005000000D671FC5069A95040A723809BC5F54B40D671FC5069A95040ECDADE6E49F84B4093C9A99D61AA5040ECDADE6E49F84B4093C9A99D61AA5040A723809BC5F54B40D671FC5069A95040A723809BC5F54B40
23822	Травное	6	55	1680	66.838348999999994	66.854797000000005	55.584654999999998	55.562811000000004	0103000020E6100000010000000500000098689082A7B550401F6ADB300AC84B4098689082A7B55040B0389CF9D5CA4B4003EE79FEB4B65040B0389CF9D5CA4B4003EE79FEB4B650401F6ADB300AC84B4098689082A7B550401F6ADB300AC84B40
24355	Тетерье	6	55	1680	66.870365000000007	66.877103000000005	55.736975000000001	55.728140000000003	0103000020E6100000010000000500000051A5660FB4B75040697407B133DD4B4051A5660FB4B750401C7C613255DE4B404E0E9F7422B850401C7C613255DE4B404E0E9F7422B85040697407B133DD4B4051A5660FB4B75040697407B133DD4B40
55044	Сунгурова	6	55	1680	66.625736000000003	66.649910000000006	55.645547000000001	55.628855999999999	0103000020E6100000010000000500000083FB010F0CA850405AF2785A7ED04B4083FB010F0CA85040F583BA48A1D24B40FAD51C2098A95040F583BA48A1D24B40FAD51C2098A950405AF2785A7ED04B4083FB010F0CA850405AF2785A7ED04B40
23988	Старопершино	6	55	1680	66.402728999999994	66.424503999999999	55.700719999999997	55.690517	0103000020E61000000100000005000000A609DB4FC6995040802A6EDC62D84B40A609DB4FC699504099D36531B1D94B405B41D3122B9B504099D36531B1D94B405B41D3122B9B5040802A6EDC62D84B40A609DB4FC6995040802A6EDC62D84B40
24469	Рассвет	6	55	1680	67.113367999999994	67.134756999999993	55.662968999999997	55.651891999999997	0103000020E610000001000000050000006D1ADB6B41C750401343723271D34B406D1ADB6B41C7504083A10E2BDCD44B400DFAD2DB9FC8504083A10E2BDCD44B400DFAD2DB9FC850401343723271D34B406D1ADB6B41C750401343723271D34B40
23309	Пороги	6	55	1680	66.772952000000004	66.786472000000003	55.79016	55.781094000000003	0103000020E610000001000000050000002E58AA0B78B15040098D60E3FAE34B402E58AA0B78B15040BE4D7FF623E54B4010CEA78E55B25040BE4D7FF623E54B4010CEA78E55B25040098D60E3FAE34B402E58AA0B78B15040098D60E3FAE34B40
24262	Отставное	6	55	1680	66.331564999999998	66.350500999999994	55.767656000000002	55.759613000000002	0103000020E61000000100000005000000E3DF675C38955040E84EB0FF3AE14B40E3DF675C38955040024A438D42E24B40C70DBF9B6E965040024A438D42E24B40C70DBF9B6E965040E84EB0FF3AE14B40E3DF675C38955040E84EB0FF3AE14B40
24568	Одино	6	55	1680	67.048151000000004	67.064186000000007	55.843969999999999	55.830311000000002	0103000020E610000001000000050000004391EEE714C3504029417FA147EA4B404391EEE714C350400E677E3507EC4B401CB7989F1BC450400E677E3507EC4B401CB7989F1BC4504029417FA147EA4B404391EEE714C3504029417FA147EA4B40
23945	Новотроицкое	6	55	1680	66.442757999999998	66.460229999999996	55.674970999999999	55.668132	0103000020E61000000100000005000000B682A625569C50409EB4705985D54B40B682A625569C5040CC5F217365D64B40D6A88768749D5040CC5F217365D64B40D6A88768749D50409EB4705985D54B40B682A625569C50409EB4705985D54B40
54980	Мокроусово	6	55	1680	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
23906	Михайловка	6	55	1680	66.479759999999999	66.502657999999997	55.643926999999998	55.626472	0103000020E61000000100000005000000747B4963B49E50400BEE073C30D04B40747B4963B49E504075012F336CD24B40A8C4758C2BA0504075012F336CD24B40A8C4758C2BA050400BEE073C30D04B40747B4963B49E50400BEE073C30D04B40
24398	Межеумное	6	55	1680	66.937020000000004	66.947772999999998	55.697629999999997	55.689943	0103000020E61000000100000005000000ABECBB22F8BB5040548D5E0D50D84B40ABECBB22F8BB5040AF5A99F04BD94B4009C21550A8BC5040AF5A99F04BD94B4009C21550A8BC5040548D5E0D50D84B40ABECBB22F8BB5040548D5E0D50D84B40
24166	Малое Середкино	6	55	1680	66.374916999999996	66.385301999999996	55.820784000000003	55.808684999999997	0103000020E61000000100000005000000B96DDFA3FE97504004E275FD82E74B40B96DDFA3FE975040408A3A730FE94B405645B8C9A8985040408A3A730FE94B405645B8C9A898504004E275FD82E74B40B96DDFA3FE97504004E275FD82E74B40
23777	Малое Песьяново	6	55	1680	66.603161	66.618279999999999	55.587890999999999	55.576284000000001	0103000020E61000000100000005000000404E98309AA65040A29A92ACC3C94B40404E98309AA650406E4E250340CB4B4056F146E691A750406E4E250340CB4B4056F146E691A75040A29A92ACC3C94B40404E98309AA65040A29A92ACC3C94B40
24085	Малое Мостовское	6	55	1680	66.358900000000006	66.371027999999995	55.781447999999997	55.769778000000002	0103000020E6100000010000000500000034A2B437F89650401497E31588E24B4034A2B437F896504026C3F17C06E44B409E7939ECBE97504026C3F17C06E44B409E7939ECBE9750401497E31588E24B4034A2B437F89650401497E31588E24B40
24492	Лопарево	6	55	1680	67.309164999999993	67.321202999999997	55.556930000000001	55.547075999999997	0103000020E610000001000000050000005704FF5BC9D3504097361C9606C64B405704FF5BC9D35040A514747B49C74B40221807978ED45040A514747B49C74B40221807978ED4504097361C9606C64B405704FF5BC9D3504097361C9606C64B40
23631	Лапушки	6	55	1680	66.658991999999998	66.676373999999996	55.722577999999999	55.708109999999998	0103000020E61000000100000005000000D714C8EC2CAA50403BFC3559A3DA4B40D714C8EC2CAA50409067976F7DDC4B4057772CB649AB50409067976F7DDC4B4057772CB649AB50403BFC3559A3DA4B40D714C8EC2CAA50403BFC3559A3DA4B40
24597	Куртан	6	55	1680	67.182269000000005	67.206308000000007	55.790579999999999	55.769599999999997	0103000020E61000000100000005000000C784984BAACB50403480B74082E24B40C784984BAACB5040936FB6B931E54B40CE39782634CD5040936FB6B931E54B40CE39782634CD50403480B74082E24B40C784984BAACB50403480B74082E24B40
23846	Круглое	6	55	1680	66.481870999999998	66.498220000000003	55.796633	55.78772	0103000020E61000000100000005000000037976F9D69E5040DB334B02D4E44B40037976F9D69E50400AF5F411F8E54B40A48D23D6E29F50400AF5F411F8E54B40A48D23D6E29F5040DB334B02D4E44B40037976F9D69E5040DB334B02D4E44B40
23398	Крепость	6	55	1680	66.734808999999998	66.748059999999995	55.852004999999998	55.841856999999997	0103000020E610000001000000050000009DF3531C07AF50404F745DF8C1EB4B409DF3531C07AF5040A583F57F0EED4B4087DC0C37E0AF5040A583F57F0EED4B4087DC0C37E0AF50404F745DF8C1EB4B409DF3531C07AF50404F745DF8C1EB4B40
55039	Кокарево	6	55	1680	66.706225000000003	66.713924000000006	55.881368999999999	55.870789000000002	0103000020E6100000010000000500000087A757CA32AD5040B85B920376EF4B4087A757CA32AD5040A75A0BB3D0F04B4017F549EEB0AD5040A75A0BB3D0F04B4017F549EEB0AD5040B85B920376EF4B4087A757CA32AD5040B85B920376EF4B40
23498	Карпунино	6	55	1680	66.860114999999993	66.878692999999998	55.865025000000003	55.858508	0103000020E6100000010000000500000023F3C81F0CB750405CAD1397E3ED4B4023F3C81F0CB75040789CA223B9EE4B40588E90813CB85040789CA223B9EE4B40588E90813CB850405CAD1397E3ED4B4023F3C81F0CB750405CAD1397E3ED4B40
24074	Дмитриевка	6	55	1680	66.370084000000006	66.388966999999994	55.732311000000003	55.713664000000001	0103000020E610000001000000050000007731CD74AF975040912A8A5759DB4B407731CD74AF97504023C0E95DBCDD4B40490ED8D5E498504023C0E95DBCDD4B40490ED8D5E4985040912A8A5759DB4B407731CD74AF975040912A8A5759DB4B40
24713	Большое Щучье	6	55	1680	67.422595999999999	67.433456000000007	55.665680000000002	55.661999000000002	0103000020E61000000100000005000000E8DA17D00BDB50400B7E1B62BCD44B40E8DA17D00BDB5040F7CC920035D54B4052103CBEBDDB5040F7CC920035D54B4052103CBEBDDB50400B7E1B62BCD44B40E8DA17D00BDB50400B7E1B62BCD44B40
23694	Большое Песьяное	6	55	1680	66.692526000000001	66.706512000000004	55.680301	55.671137999999999	0103000020E610000001000000050000004D68925852AC50402A8D98D9E7D54B404D68925852AC5040D237691A14D74B40D28E1B7E37AD5040D237691A14D74B40D28E1B7E37AD50402A8D98D9E7D54B404D68925852AC50402A8D98D9E7D54B40
22781	Шаламово	6	55	1349	63.558070000000001	63.580976999999997	55.608445000000003	55.593690000000002	0103000020E610000001000000050000007A7077D66EC74F402BFBAE08FECB4B407A7077D66EC74F4016359886E1CD4B40355D4F745DCA4F4016359886E1CD4B40355D4F745DCA4F402BFBAE08FECB4B407A7077D66EC74F402BFBAE08FECB4B40
22348	Троицкое (Штанное)	6	55	1349	63.712940000000003	63.733986999999999	55.701591999999998	55.690216999999997	0103000020E610000001000000050000005001309E41DB4F405512D90759D84B405001309E41DB4F404F9143C4CDD94B4036583849F3DD4F404F9143C4CDD94B4036583849F3DD4F405512D90759D84B405001309E41DB4F405512D90759D84B40
22506	Сосново	6	55	1349	63.814135	63.831426999999998	55.006957	54.992342999999998	0103000020E61000000100000005000000B5C35F9335E84F400FB56D18057F4B40B5C35F9335E84F4038BD8BF7E3804B4075012F336CEA4F4038BD8BF7E3804B4075012F336CEA4F400FB56D18057F4B40B5C35F9335E84F400FB56D18057F4B40
21854	Сладкокарасинское	6	55	1349	64.089370000000002	64.102018000000001	55.401192000000002	55.389958999999998	0103000020E6100000010000000500000096CFF23CB8055040F3E32F2DEAB14B4096CFF23CB80550405BB56B425AB34B409D668176870650405BB56B425AB34B409D66817687065040F3E32F2DEAB14B4096CFF23CB8055040F3E32F2DEAB14B40
21759	Сладкое	6	55	1349	64.126075	64.142630999999994	55.350945000000003	55.347157000000003	0103000020E61000000100000005000000F775E09C11085040EBC9FCA36FAC4B40F775E09C11085040EDD808C4EBAC4B405419C6DD20095040EDD808C4EBAC4B405419C6DD20095040EBC9FCA36FAC4B40F775E09C11085040EBC9FCA36FAC4B40
22689	Первомайское	6	55	1349	63.786062999999999	63.803426999999999	55.550621	55.534097000000003	0103000020E610000001000000050000003ECC5EB69DE44F4024F25D4A5DC44B403ECC5EB69DE44F40D3BEB9BF7AC64B4098DC28B2D6E64F40D3BEB9BF7AC64B4098DC28B2D6E64F4024F25D4A5DC44B403ECC5EB69DE44F4024F25D4A5DC44B40
22599	Островное	6	55	1349	63.821365999999998	63.838811999999997	55.350551000000003	55.339810999999997	0103000020E61000000100000005000000EE05668522E94F4018E945ED7EAB4B40EE05668522E94F40414AECDADEAC4B4005BF0D315EEB4F40414AECDADEAC4B4005BF0D315EEB4F4018E945ED7EAB4B40EE05668522E94F4018E945ED7EAB4B40
22518	Новые Пески	6	55	1349	63.887374999999999	63.909680000000002	55.784835000000001	55.767944	0103000020E61000000100000005000000DD24068195F14F4068942EFD4BE24B40DD24068195F14F40CAE0287975E44B40A3E9EC6470F44F40CAE0287975E44B40A3E9EC6470F44F4068942EFD4BE24B40DD24068195F14F4068942EFD4BE24B40
22416	Мыркайское	6	55	1349	63.775615000000002	63.793258000000002	55.048023000000001	55.033672000000003	0103000020E61000000100000005000000BEA4315A47E34F403D65355D4F844B40BEA4315A47E34F40583A1F9E25864B402BA5677A89E54F40583A1F9E25864B402BA5677A89E54F403D65355D4F844B40BEA4315A47E34F403D65355D4F844B40
22849	Мокрушино	6	55	1349	63.400227000000001	63.429934000000003	55.664704999999998	55.660699000000001	0103000020E61000000100000005000000F4FC69A33AB34F40FDBFEAC891D44B40F4FC69A33AB34F406C3EAE0D15D54B4020B8CA1308B74F406C3EAE0D15D54B4020B8CA1308B74F40FDBFEAC891D44B40F4FC69A33AB34F40FDBFEAC891D44B40
21187	Мишкино	6	55	1349	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
54929	Мишкино	6	55	1349	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
22611	Маслово	6	55	1349	63.769668000000003	63.778939000000001	55.25206	55.244217999999996	0103000020E610000001000000050000008D63247B84E24F40198C1189429F4B408D63247B84E24F409C50888043A04B401B4AED45B4E34F409C50888043A04B401B4AED45B4E34F40198C1189429F4B408D63247B84E24F40198C1189429F4B40
22411	Масли	6	55	1349	63.788415999999998	63.816775999999997	55.212955000000001	55.197209000000001	0103000020E6100000010000000500000052D2C3D0EAE44F400ABDFE243E994B4052D2C3D0EAE44F408542041C429B4B402F14B01D8CE84F408542041C429B4B402F14B01D8CE84F400ABDFE243E994B4052D2C3D0EAE44F400ABDFE243E994B40
22085	Малое Окунево	6	55	1349	63.567233000000002	63.589305000000003	55.474271000000002	55.465671999999998	0103000020E61000000100000005000000221B48179BC84F40DA54DD239BBB4B40221B48179BC84F407A3881E9B4BC4B40452FA3586ECB4F407A3881E9B4BC4B40452FA3586ECB4F40DA54DD239BBB4B40221B48179BC84F40DA54DD239BBB4B40
22277	Лебяжье	6	55	1349	64.088211000000001	64.098326	55.161358	55.152813999999999	0103000020E610000001000000050000007009C03FA50550407B2FBE688F934B407009C03FA505504057790261A7944B402D9622F94A06504057790261A7944B402D9622F94A0650407B2FBE688F934B407009C03FA50550407B2FBE688F934B40
22343	Купай	6	55	1349	63.634408999999998	63.663603999999999	55.654527999999999	55.639871999999997	0103000020E61000000100000005000000DFA4695034D14F4024D06053E7D14B40DFA4695034D14F407C28D192C7D34B4055BFD2F9F0D44F407C28D192C7D34B4055BFD2F9F0D44F4024D06053E7D14B40DFA4695034D14F4024D06053E7D14B40
54998	Краснознаменское	6	55	1349	64.013282000000004	64.037824000000001	55.264434999999999	55.248047	0103000020E6100000010000000500000008E8BE9CD90050407A6F0C01C09F4B4008E8BE9CD900504079758E01D9A14B4040C05AB56B02504079758E01D9A14B4040C05AB56B0250407A6F0C01C09F4B4008E8BE9CD90050407A6F0C01C09F4B40
22171	Коровье	6	55	1349	63.940573000000001	63.965133000000002	55.111145	55.090314999999997	0103000020E61000000100000005000000144031B264F84F404BAB21718F8B4B40144031B264F84F40950ED6FF398E4B402BA5677A89FB4F40950ED6FF398E4B402BA5677A89FB4F404BAB21718F8B4B40144031B264F84F404BAB21718F8B4B40
54996	Кирово	6	55	1349	63.731400000000001	63.786045000000001	55.565722000000001	55.540837000000003	0103000020E61000000100000005000000AF25E4839EDD4F40BFBB95253AC54B40AF25E4839EDD4F405950189469C84B409817601F9DE44F405950189469C84B409817601F9DE44F40BFBB95253AC54B40AF25E4839EDD4F40BFBB95253AC54B40
21582	Иванковское	6	55	1349	63.855519999999999	63.866947000000003	55.392403000000002	55.386758	0103000020E610000001000000050000007689EAAD81ED4F40B2BB404981B14B407689EAAD81ED4F4018EDF1423AB24B40C32E8A1EF8EE4F4018EDF1423AB24B40C32E8A1EF8EE4F40B2BB404981B14B407689EAAD81ED4F40B2BB404981B14B40
21984	Дубровное	6	55	1349	63.850867000000001	63.877941999999997	55.712234000000002	55.688609	0103000020E61000000100000005000000711FB935E9EC4F409A5DF75624D84B40711FB935E9EC4F40B58CD47B2ADB4B4075E4486760F04F40B58CD47B2ADB4B4075E4486760F04F409A5DF75624D84B40711FB935E9EC4F409A5DF75624D84B40
21893	Гладышево	6	55	1349	63.709769000000001	63.726917	55.384507999999997	55.370804999999997	0103000020E61000000100000005000000795BE9B5D9DA4F40BD18CA8976AF4B40795BE9B5D9DA4F407286E28E37B14B4006F4C29D0BDD4F407286E28E37B14B4006F4C29D0BDD4F40BD18CA8976AF4B40795BE9B5D9DA4F40BD18CA8976AF4B40
55052	Гаганова	6	55	1349	63.813766999999999	63.839261	55.568517	55.561715999999997	0103000020E6100000010000000500000032C85D8429E84F40E9D1544FE6C74B4032C85D8429E84F402A1C412AC5C84B4075E789E76CEB4F402A1C412AC5C84B4075E789E76CEB4F40E9D1544FE6C74B4032C85D8429E84F40E9D1544FE6C74B40
21793	Восход	6	55	1349	64.060344999999998	64.082020999999997	55.370666	55.352808000000003	0103000020E61000000100000005000000895E46B1DC03504033E202D028AD4B40895E46B1DC0350409CDEC5FB71AF4B40742502D53F0550409CDEC5FB71AF4B40742502D53F05504033E202D028AD4B40895E46B1DC03504033E202D028AD4B40
21681	Введенское	6	55	1349	64.067387999999994	64.094616000000002	55.327463999999999	55.320883000000002	0103000020E610000001000000050000002409C21550045040D36BB3B112A94B402409C21550045040054F2157EAA94B406A6B44300E065040054F2157EAA94B406A6B44300E065040D36BB3B112A94B402409C21550045040D36BB3B112A94B40
21659	Варлаково	6	55	1349	63.936449000000003	63.969112000000003	55.589497999999999	55.581139	0103000020E610000001000000050000009BAF928FDDF74F400FB743C362CA4B409BAF928FDDF74F405987A3AB74CB4B40A114ADDC0BFC4F405987A3AB74CB4B40A114ADDC0BFC4F400FB743C362CA4B409BAF928FDDF74F400FB743C362CA4B40
21965	Бутырское	6	55	1349	63.544657999999998	63.579495000000001	55.380538999999999	55.369055000000003	0103000020E610000001000000050000009CC0745AB7C54F4070B6B9313DAF4B409CC0745AB7C54F4020ED7F80B5B04B40079964E42CCA4F4020ED7F80B5B04B40079964E42CCA4F4070B6B9313DAF4B409CC0745AB7C54F4070B6B9313DAF4B40
19404	Ясные Зори	6	55	1577	67.304232999999996	67.310143999999994	55.144053	55.137059999999998	0103000020E610000001000000050000004B57B08D78D350407DCB9C2E8B914B404B57B08D78D3504002F2255470924B403D433866D9D3504002F2255470924B403D433866D9D350407DCB9C2E8B914B404B57B08D78D350407DCB9C2E8B914B40
20098	Чебаки	6	55	1577	67.266801000000001	67.280885999999995	55.074561000000003	55.064627999999999	0103000020E610000001000000050000009162804413D15040F433F5BA45884B409162804413D150404E4700378B894B40DFF94509FAD150404E4700378B894B40DFF94509FAD15040F433F5BA45884B409162804413D15040F433F5BA45884B40
19562	Ударник	6	55	1577	67.222020000000001	67.233104999999995	55.343291999999998	55.334747	0103000020E61000000100000005000000B5C35F9335CE504091B75CFDD8AA4B40B5C35F9335CE50403D7D04FEF0AB4B402EE23B31EBCE50403D7D04FEF0AB4B402EE23B31EBCE504091B75CFDD8AA4B40B5C35F9335CE504091B75CFDD8AA4B40
19759	Трюхино	6	55	1577	67.297020000000003	67.325424999999996	55.514136000000001	55.502527999999998	0103000020E6100000010000000500000082902C6002D3504082A966D652C04B4082902C6002D350401FD95C35CFC14B40401361C3D3D450401FD95C35CFC14B40401361C3D3D4504082A966D652C04B4082902C6002D3504082A966D652C04B40
21021	Требушинное	6	55	1577	66.853468000000007	66.873626000000002	55.054743000000002	55.045938999999997	0103000020E61000000100000005000000AF0B3F389FB65040334E4354E1854B40AF0B3F389FB65040AC5791D101874B40DCBB067DE9B75040AC5791D101874B40DCBB067DE9B75040334E4354E1854B40AF0B3F389FB65040334E4354E1854B40
19966	Степное	6	55	1577	67.425280999999998	67.438261999999995	55.192470999999998	55.185847000000003	0103000020E610000001000000050000000DA7CCCD37DB5040A587A1D5C9974B400DA7CCCD37DB5040D636C5E3A2984B4017450F7C0CDC5040D636C5E3A2984B4017450F7C0CDC5040A587A1D5C9974B400DA7CCCD37DB5040A587A1D5C9974B40
20201	Слевное	6	55	1577	67.207691999999994	67.230320000000006	54.980963000000003	54.968623000000001	0103000020E6100000010000000500000003E962D34ACD5040A393A5D6FB7B4B4003E962D34ACD504004CB1132907D4B4058E71890BDCE504004CB1132907D4B4058E71890BDCE5040A393A5D6FB7B4B4003E962D34ACD5040A393A5D6FB7B4B40
20344	Сетовное	6	55	1577	67.057637	67.083212000000003	55.082394999999998	55.073293	0103000020E6100000010000000500000088821953B0C350404B033FAA61894B4088821953B0C350404D2D5BEB8B8A4B40A0A86C5853C550404D2D5BEB8B8A4B40A0A86C5853C550404B033FAA61894B4088821953B0C350404B033FAA61894B40
55046	Садовод	6	55	1577	67.249239000000003	67.258869000000004	55.181555000000003	55.176203000000001	0103000020E61000000100000005000000D1782288F3CF5040823AE5D18D964B40D1782288F3CF504070B6B9313D974B40B03C484F91D0504070B6B9313D974B40B03C484F91D05040823AE5D18D964B40D1782288F3CF5040823AE5D18D964B40
20621	Раздолье	6	55	1577	67.118722000000005	67.126429999999999	55.278123999999998	55.271790000000003	0103000020E6100000010000000500000035D4282499C750409FB0C403CAA24B4035D4282499C75040C91D369199A34B40EECEDA6D17C85040C91D369199A34B40EECEDA6D17C850409FB0C403CAA24B4035D4282499C750409FB0C403CAA24B40
20789	Профинтерн	6	55	1577	67.000217000000006	67.013727000000003	54.896101999999999	54.887765999999999	0103000020E61000000100000005000000CFF9298E03C050401840F850A2714B40CFF9298E03C05040AAF06778B3724B409F0436E7E0C05040AAF06778B3724B409F0436E7E0C050401840F850A2714B40CFF9298E03C050401840F850A2714B40
20685	Привольное	6	55	1577	67.014167	67.028379000000001	55.208677000000002	55.204695000000001	0103000020E61000000100000005000000AD6BB41CE8C05040CE531D72339A4B40AD6BB41CE8C05040B5368DEDB59A4B402A3927F6D0C15040B5368DEDB59A4B402A3927F6D0C15040CE531D72339A4B40AD6BB41CE8C05040CE531D72339A4B40
19799	Покровка	6	55	1577	67.208265999999995	67.222154000000003	55.474826999999998	55.468657999999998	0103000020E6100000010000000500000099B7EA3A54CD50401F813FFCFCBB4B4099B7EA3A54CD5040FF209221C7BC4B403D2B69C537CE5040FF209221C7BC4B403D2B69C537CE50401F813FFCFCBB4B4099B7EA3A54CD50401F813FFCFCBB4B40
54997	Пионерское	6	55	1577	67.505735000000001	67.522524000000004	55.270240999999999	55.257303999999998	0103000020E61000000100000005000000535C55F65DE05040A3906456EFA04B40535C55F65DE05040E884D04197A24B4002D8800871E15040E884D04197A24B4002D8800871E15040A3906456EFA04B40535C55F65DE05040A3906456EFA04B40
21114	Пеган	6	55	1577	66.962146000000004	66.967922000000002	54.982812000000003	54.974747000000001	0103000020E610000001000000050000008BFED0CC93BD5040E36F7B82C47C4B408BFED0CC93BD5040E50E9BC8CC7D4B400DC51D6FF2BD5040E50E9BC8CC7D4B400DC51D6FF2BD5040E36F7B82C47C4B408BFED0CC93BD5040E36F7B82C47C4B40
19461	Обутковское	6	55	1577	67.362398999999996	67.384884	55.304015999999997	55.293315	0103000020E610000001000000050000009946938B31D750408F368E588BA54B409946938B31D75040F9BA0CFFE9A64B403C3080F0A1D85040F9BA0CFFE9A64B403C3080F0A1D850408F368E588BA54B409946938B31D750408F368E588BA54B40
20937	Неверовское	6	55	1577	66.829087999999999	66.839724000000004	54.810822999999999	54.800823999999999	0103000020E6100000010000000500000063601DC70FB550400BED9C6681664B4063601DC70FB550401CEC4D0CC9674B40A56ABB09BEB550401CEC4D0CC9674B40A56ABB09BEB550400BED9C6681664B4063601DC70FB550400BED9C6681664B40
21014	Моховое	6	55	1577	66.818091999999993	66.836040999999994	54.989156000000001	54.977744000000001	0103000020E61000000100000005000000A1478C9E5BB450401CEE23B7267D4B40A1478C9E5BB450403352EFA99C7E4B405E471CB281B550403352EFA99C7E4B405E471CB281B550401CEE23B7267D4B40A1478C9E5BB450401CEE23B7267D4B40
19870	Моршиха	6	55	1577	67.041017999999994	67.081451000000001	55.383443999999997	55.372038000000003	0103000020E610000001000000050000000723F609A0C25040446FF1F09EAF4B400723F609A0C2504078EC67B114B14B407F4E417E36C5504078EC67B114B14B407F4E417E36C55040446FF1F09EAF4B400723F609A0C25040446FF1F09EAF4B40
20260	Мартино	6	55	1577	67.171713999999994	67.201393999999993	54.916837000000001	54.901558999999999	0103000020E61000000100000005000000FB90B75CFDCA50400D350A4966734B40FB90B75CFDCA5040A26131EA5A754B4014E7A8A3E3CC5040A26131EA5A754B4014E7A8A3E3CC50400D350A4966734B40FB90B75CFDCA50400D350A4966734B40
18962	Макушино	6	55	1577	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
55043	Копырено	6	55	1577	67.382368999999997	67.402041999999994	55.339590000000001	55.336457000000003	0103000020E610000001000000050000004580D3BB78D8504051C1E10511AB4B404580D3BB78D850403A0664AF77AB4B4094675E0EBBD950403A0664AF77AB4B4094675E0EBBD9504051C1E10511AB4B404580D3BB78D8504051C1E10511AB4B40
20576	Коновалово	6	55	1577	66.943253999999996	66.972081000000003	55.263582999999997	55.250238000000003	0103000020E610000001000000050000008E7406465EBC5040B51B7DCC07A04B408E7406465EBC50400A647616BDA14B4008043A9336BE50400A647616BDA14B4008043A9336BE5040B51B7DCC07A04B408E7406465EBC5040B51B7DCC07A04B40
20817	Клюквенное	6	55	1577	66.723392000000004	66.742785999999995	54.936621000000002	54.92895	0103000020E61000000100000005000000098CF50D4CAE504042CF66D5E7764B40098CF50D4CAE504098DF6932E3774B404E7B4ACE89AF504098DF6932E3774B404E7B4ACE89AF504042CF66D5E7764B40098CF50D4CAE504042CF66D5E7764B40
19629	Казаркино	6	55	1577	67.397864999999996	67.431031000000004	55.405337000000003	55.389611000000002	0103000020E6100000010000000500000046CEC29E76D95040B894F3C5DEB14B4046CEC29E76D95040EC6D3315E2B34B40FB230C0396DB5040EC6D3315E2B34B40FB230C0396DB5040B894F3C5DEB14B4046CEC29E76D95040B894F3C5DEB14B40
20466	Золотое	6	55	1577	66.982204999999993	67.007465999999994	55.129519999999999	55.119053999999998	0103000020E61000000100000005000000EE3D5C72DCBE50409F3A56293D8F4B40EE3D5C72DCBE5040C616821C94904B403E75AC527AC05040C616821C94904B403E75AC527AC050409F3A56293D8F4B40EE3D5C72DCBE50409F3A56293D8F4B40
40343	Журавлевка	6	55	1577	67.301179000000005	67.315534	55.198216000000002	55.192892999999998	0103000020E610000001000000050000007DCF488446D350404C50C3B7B0984B407DCF488446D35040A0C552245F994B40ABB184B531D45040A0C552245F994B40ABB184B531D450404C50C3B7B0984B407DCF488446D350404C50C3B7B0984B40
20371	Гренадеры	6	55	1577	67.115425999999999	67.127354999999994	55.096167000000001	55.085811	0103000020E61000000100000005000000EBC6BB2363C750408B51D7DAFB8A4B40EBC6BB2363C750402BFA43334F8C4B40DAFE959526C850402BFA43334F8C4B40DAFE959526C850408B51D7DAFB8A4B40EBC6BB2363C750408B51D7DAFB8A4B40
20153	Братанники	6	55	1577	67.323952000000006	67.340534000000005	55.057022000000003	55.04842	0103000020E61000000100000005000000535E2BA1BBD45040753C66A032864B40535E2BA1BBD450408693347F4C874B40454B1E4FCBD550408693347F4C874B40454B1E4FCBD55040753C66A032864B40535E2BA1BBD45040753C66A032864B40
20891	Бородинка	6	55	1577	66.726715999999996	66.734576000000004	54.863844999999998	54.854159000000003	0103000020E61000000100000005000000B75ED38382AE5040C34A0515556D4B40B75ED38382AE504014E81379926E4B404C1B0E4B03AF504014E81379926E4B404C1B0E4B03AF5040C34A0515556D4B40B75ED38382AE5040C34A0515556D4B40
20729	Большое Курейное	6	55	1577	66.928531000000007	66.967769000000004	54.926755999999997	54.913603000000002	0103000020E610000001000000050000009F94490D6DBB504085436FF1F0744B409F94490D6DBB504096AFCBF09F764B404A4563EDEFBD504096AFCBF09F764B404A4563EDEFBD504085436FF1F0744B409F94490D6DBB504085436FF1F0744B40
20513	Большое Кривинское	6	55	1577	66.900773000000001	66.919458000000006	55.183985999999997	55.179858000000003	0103000020E61000000100000005000000AB07CC43A6B9504045F6419605974B40AB07CC43A6B95040FF756EDA8C974B40EB025E66D8BA5040FF756EDA8C974B40EB025E66D8BA504045F6419605974B40AB07CC43A6B9504045F6419605974B40
20015	Басковское	6	55	1577	67.479522000000003	67.500309000000001	55.040956000000001	55.025292	0103000020E610000001000000050000009AED0A7DB0DE5040DB6CACC43C834B409AED0A7DB0DE50409949D40B3E854B403F390A1005E050409949D40B3E854B403F390A1005E05040DB6CACC43C834B409AED0A7DB0DE5040DB6CACC43C834B40
19697	Антипино	6	55	1577	67.431236999999996	67.439520000000002	55.445144999999997	55.439599000000001	0103000020E61000000100000005000000CFF4126399DB50405A2DB0C744B84B40CFF4126399DB50402C7DE882FAB84B40077C7E1821DC50402C7DE882FAB84B40077C7E1821DC50405A2DB0C744B84B40CFF4126399DB50405A2DB0C744B84B40
18622	Юдино	6	55	1472	66.455730000000003	66.467336000000003	55.454402000000002	55.445977999999997	0103000020E61000000100000005000000977329AE2A9D5040245E9ECE15B94B40977329AE2A9D5040569E40D829BA4B40950F41D5E89D5040569E40D829BA4B40950F41D5E89D5040245E9ECE15B94B40977329AE2A9D5040245E9ECE15B94B40
18862	Черемушки	6	55	1472	66.601732999999996	66.620822000000004	55.291649	55.282553999999998	0103000020E6100000010000000500000022FB20CB82A650404FADBEBA2AA44B4022FB20CB82A650409F7422C154A54B40CAA8328CBBA750409F7422C154A54B40CAA8328CBBA750404FADBEBA2AA44B4022FB20CB82A650404FADBEBA2AA44B40
18927	Чаешное	6	55	1472	66.590387000000007	66.598661000000007	55.368436000000003	55.361666999999997	0103000020E61000000100000005000000F33E8EE6C8A550406E85B01A4BAE4B40F33E8EE6C8A55040A4552DE928AF4B4001193A7650A65040A4552DE928AF4B4001193A7650A650406E85B01A4BAE4B40F33E8EE6C8A550406E85B01A4BAE4B40
17395	Центральное	6	55	1472	66.513249000000002	66.547608999999994	55.165774999999996	55.156585	0103000020E610000001000000050000001A6D5512D9A05040A7052FFA0A944B401A6D5512D9A0504048BF7D1D38954B40B27F9E060CA3504048BF7D1D38954B40B27F9E060CA35040A7052FFA0A944B401A6D5512D9A05040A7052FFA0A944B40
18814	Хутора	6	55	1472	66.252332999999993	66.271764000000005	55.086238999999999	55.074849999999998	0103000020E61000000100000005000000E6AC4F3926905040840D4FAF94894B40E6AC4F3926905040E3512AE1098B4B40BB0ED59464915040E3512AE1098B4B40BB0ED59464915040840D4FAF94894B40E6AC4F3926905040840D4FAF94894B40
18160	Суерская	6	55	1472	66.604302000000004	66.621360999999993	55.441212999999998	55.430835000000002	0103000020E6100000010000000500000013BA4BE2ACA65040707CED9925B74B4013BA4BE2ACA65040F7C8E6AA79B84B40A180ED60C4A75040F7C8E6AA79B84B40A180ED60C4A75040707CED9925B74B4013BA4BE2ACA65040707CED9925B74B40
18660	Речное	6	55	1472	66.358056000000005	66.380649000000005	55.189957999999997	55.182279000000001	0103000020E61000000100000005000000BE88B663EA965040B1DF13EB54974B40BE88B663EA96504089CE328B50984B4054909F8D5C98504089CE328B50984B4054909F8D5C985040B1DF13EB54974B40BE88B663EA965040B1DF13EB54974B40
18511	Прилогино	6	55	1472	66.372600000000006	66.402486999999994	55.479796	55.472060999999997	0103000020E61000000100000005000000569FABADD8975040C85BAE7E6CBC4B40569FABADD8975040356090F469BD4B402B84D558C2995040356090F469BD4B402B84D558C2995040C85BAE7E6CBC4B40569FABADD8975040C85BAE7E6CBC4B40
18413	Плоское	6	55	1472	66.247230999999999	66.267155000000002	55.244655000000002	55.234805000000001	0103000020E61000000100000005000000ACE3F8A1D28F5040F9F719170E9E4B40ACE3F8A1D28F5040C5E6E3DA509F4B40A0FD481119915040C5E6E3DA509F4B40A0FD481119915040F9F719170E9E4B40ACE3F8A1D28F5040F9F719170E9E4B40
18034	Песьяное	6	55	1472	66.635688999999999	66.656000000000006	55.051400999999998	55.045397999999999	0103000020E61000000100000005000000535BEA20AFA85040E3A6069ACF854B40535BEA20AFA85040A8FDD64E94864B40448B6CE7FBA95040A8FDD64E94864B40448B6CE7FBA95040E3A6069ACF854B40535BEA20AFA85040E3A6069ACF854B40
17837	Островное	6	55	1472	66.779652999999996	66.795607000000004	55.217136000000004	55.20861	0103000020E610000001000000050000009C4EB2D5E5B150402DCF83BBB39A4B409C4EB2D5E5B150406364C91CCB9B4B40FF5D9F39EBB250406364C91CCB9B4B40FF5D9F39EBB250402DCF83BBB39A4B409C4EB2D5E5B150402DCF83BBB39A4B40
18242	Налимово	6	55	1472	66.889022999999995	66.905157000000003	55.375107	55.360776000000001	0103000020E610000001000000050000001399B9C0E5B85040429770E82DAE4B401399B9C0E5B8504016C0948103B04B40B62FA017EEB9504016C0948103B04B40B62FA017EEB95040429770E82DAE4B401399B9C0E5B85040429770E82DAE4B40
18112	Менщиково	6	55	1472	66.598714999999999	66.610401999999993	55.487417000000001	55.471922999999997	0103000020E61000000100000005000000FA27B85851A65040779D0DF967BC4B40FA27B85851A65040D94125AE63BE4B406EDA8CD310A75040D94125AE63BE4B406EDA8CD310A75040779D0DF967BC4B40FA27B85851A65040779D0DF967BC4B40
54989	Лопатки	6	55	1472	66.598526000000007	66.642066999999997	54.999650000000003	54.973610000000001	0103000020E6100000010000000500000091F3FE3F4EA650407F87A2409F7C4B4091F3FE3F4EA6504024B9FC87F47F4B40D0B52FA017A9504024B9FC87F47F4B40D0B52FA017A950407F87A2409F7C4B4091F3FE3F4EA650407F87A2409F7C4B40
17802	Лисье	6	55	1472	66.753951999999998	66.787171999999998	55.143265	55.130589999999998	0103000020E610000001000000050000003EB0E3BF40B05040A297512CB7904B403EB0E3BF40B05040AAD4EC8156924B40EC14AB0661B25040AAD4EC8156924B40EC14AB0661B25040A297512CB7904B403EB0E3BF40B05040A297512CB7904B40
18335	Лебяжье 1-е	6	55	1472	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
54947	Лебяжье	6	55	1472	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
17751	Кукушкино	6	55	1472	66.222679999999997	66.242524000000003	55.321615000000001	55.313935999999998	0103000020E610000001000000050000004A5E9D63408E5040BE840A0E2FA84B404A5E9D63408E5040977329AE2AA94B40B01F6283858F5040977329AE2AA94B40B01F6283858F5040BE840A0E2FA84B404A5E9D63408E5040BE840A0E2FA84B40
18181	Кузнецово	6	55	1472	66.605174000000005	66.621324999999999	55.507778999999999	55.502146000000003	0103000020E61000000100000005000000EE98BA2BBBA650409BE8F35146C04B40EE98BA2BBBA650403C4CFBE6FEC04B40FBCBEEC9C3A750403C4CFBE6FEC04B40FBCBEEC9C3A750409BE8F35146C04B40EE98BA2BBBA650409BE8F35146C04B40
18766	Кузинка	6	55	1472	66.268099000000007	66.274458999999993	55.150010000000002	55.141300000000001	0103000020E61000000100000005000000C845B5882891504060764F1E16924B40C845B588289150405709168733934B40F1457BBC909150405709168733934B40F1457BBC9091504060764F1E16924B40C845B5882891504060764F1E16924B40
18530	Красная Горка	6	55	1472	66.445048999999997	66.452702000000002	55.515309000000002	55.504725999999998	0103000020E610000001000000050000008507CDAE7B9C50406FB88FDC9AC04B408507CDAE7B9C5040D02A33A5F5C14B405D35CF11F99C5040D02A33A5F5C14B405D35CF11F99C50406FB88FDC9AC04B408507CDAE7B9C50406FB88FDC9AC04B40
17705	Камышное	6	55	1472	66.246646999999996	66.262384999999995	55.425491000000001	55.408670000000001	0103000020E6100000010000000500000004AA7F10C98F50409C6D6E4C4FB44B4004AA7F10C98F504005DF347D76B64B40807D74EACA90504005DF347D76B64B40807D74EACA9050409C6D6E4C4FB44B4004AA7F10C98F50409C6D6E4C4FB44B40
17603	Калашное	6	55	1472	66.518854000000005	66.533226999999997	55.083373999999999	55.073092000000003	0103000020E61000000100000005000000865968E734A15040B4CC22145B894B40865968E734A1504019ABCDFFAB8A4B400796236420A2504019ABCDFFAB8A4B400796236420A25040B4CC22145B894B40865968E734A15040B4CC22145B894B40
18716	Желтики	6	55	1472	66.383487000000002	66.407112999999995	55.236919999999998	55.230446000000001	0103000020E610000001000000050000003CDC0E0D8B9850403CBF28417F9D4B403CDC0E0D8B98504058E20165539E4B40B131AF230E9A504058E20165539E4B40B131AF230E9A50403CBF28417F9D4B403CDC0E0D8B9850403CBF28417F9D4B40
17496	Дубровное	6	55	1472	66.889624999999995	66.901518999999993	55.529043000000001	55.516491000000002	0103000020E610000001000000050000000E2DB29DEFB85040D4D688601CC24B400E2DB29DEFB85040C09657AEB7C34B403F6EBF7CB2B95040C09657AEB7C34B403F6EBF7CB2B95040D4D688601CC24B400E2DB29DEFB85040D4D688601CC24B40
18284	Головное	6	55	1472	66.799667999999997	66.828980000000001	55.316108	55.285938000000002	0103000020E6100000010000000500000018EAB0C22DB350408257CB9D99A44B4018EAB0C22DB350408200193A76A84B40704221020EB550408200193A76A84B40704221020EB550408257CB9D99A44B4018EAB0C22DB350408257CB9D99A44B40
16892	Верхнеглубокое	6	55	1472	66.502809999999997	66.531987999999998	55.299444999999999	55.291372000000003	0103000020E610000001000000050000008386FE092EA050402D7C7DAD4BA54B408386FE092EA05040B1F9B83654A64B40537765170CA25040B1F9B83654A64B40537765170CA250402D7C7DAD4BA54B408386FE092EA050402D7C7DAD4BA54B40
54983	Василки	6	55	1472	66.070496000000006	67.052093999999997	55.614398999999999	54.900596	0103000020E61000000100000005000000ED9FA701838450404774CFBA46734B40ED9FA70183845040F9D85DA0A4CE4B405794128255C35040F9D85DA0A4CE4B405794128255C350404774CFBA46734B40ED9FA701838450404774CFBA46734B40
17319	Большое Моховое	6	55	1472	66.272321000000005	66.300760999999994	55.567321	55.547871000000001	0103000020E61000000100000005000000E6400FB56D915040A2B60DA320C64B40E6400FB56D915040C1AA7AF99DC84B4062BA10AB3F935040C1AA7AF99DC84B4062BA10AB3F935040A2B60DA320C64B40E6400FB56D915040A2B60DA320C64B40
18421	Белянино	6	55	1472	66.107121000000006	66.123506000000006	55.214655999999998	55.206128999999997	0103000020E61000000100000005000000C0ED0912DB865040EBE0606F629A4B40C0ED0912DB865040F1F109D9799B4B4007B7B585E7875040F1F109D9799B4B4007B7B585E7875040EBE0606F629A4B40C0ED0912DB865040EBE0606F629A4B40
17436	Балакуль	6	55	1472	66.838528999999994	66.856064000000003	55.452441	55.439559000000003	0103000020E61000000100000005000000D8EF8975AAB55040CCD4247843B84B40D8EF8975AAB550404D2F3196E9B94B401CD2A8C0C9B650404D2F3196E9B94B401CD2A8C0C9B65040CCD4247843B84B40D8EF8975AAB55040CCD4247843B84B40
17904	Баксары	6	55	1472	66.582401000000004	66.602119000000002	55.154223999999999	55.148451999999999	0103000020E61000000100000005000000180AD80E46A550404D83A27900934B40180AD80E46A550401021AE9CBD934B403753211E89A650401021AE9CBD934B403753211E89A650404D83A27900934B40180AD80E46A550404D83A27900934B40
17305	Арлагуль	6	55	1472	66.336335000000005	66.356008000000003	55.511909000000003	55.503037999999997	0103000020E6100000010000000500000003603C83869550409752978C63C04B4003603C838695504098C3EE3B86C14B405247C7D5C896504098C3EE3B86C14B405247C7D5C89650409752978C63C04B4003603C83869550409752978C63C04B40
17637	Александровка	6	55	1472	66.371216000000004	66.393107999999998	55.111947999999998	55.103296	0103000020E6100000010000000500000020F0C000C297504060E7A6CD388D4B4020F0C000C2975040226DE34F548E4B40F1F274AE28995040226DE34F548E4B40F1F274AE2899504060E7A6CD388D4B4020F0C000C297504060E7A6CD388D4B40
15864	Ярки	6	55	1305	64.789722999999995	64.817229999999995	54.807409	54.799905000000003	0103000020E61000000100000005000000897956D28A32504015747B4963664B40897956D28A3250407FBF982D59674B40D8D30E7F4D3450407FBF982D59674B40D8D30E7F4D34504015747B4963664B40897956D28A32504015747B4963664B40
14902	Язево	6	55	1305	64.910448000000002	64.925107999999994	54.882809999999999	54.873874999999998	0103000020E610000001000000050000005A2DB0C7443A504060E5D022DB6F4B405A2DB0C7443A5040774A07EBFF704B4026512FF8343B5040774A07EBFF704B4026512FF8343B504060E5D022DB6F4B405A2DB0C7443A504060E5D022DB6F4B40
15040	Чесноковка	6	55	1305	64.154263999999998	64.169130999999993	54.546492999999998	54.539887	0103000020E61000000100000005000000CFBC1C76DF0950408D4468041B454B40CFBC1C76DF095040183F8D7BF3454B40586FD40AD30A5040183F8D7BF3454B40586FD40AD30A50408D4468041B454B40CFBC1C76DF0950408D4468041B454B40
15384	Черноборье	6	55	1305	64.195325999999994	64.212761999999998	54.677708000000003	54.667197000000002	0103000020E61000000100000005000000BE839F38800C5040A27E17B666554B40BE839F38800C5040691EC022BF564B4038F581E49D0D5040691EC022BF564B4038F581E49D0D5040A27E17B666554B40BE839F38800C5040A27E17B666554B40
16445	Угловое	6	55	1305	64.319598999999997	64.334286000000006	54.445104000000001	54.441209000000001	0103000020E6100000010000000500000065355D4F74145040B6D9588979384B4065355D4F74145040CEA8F92AF9384B40AF601BF164155040CEA8F92AF9384B40AF601BF164155040B6D9588979384B4065355D4F74145040B6D9588979384B40
14509	Сычево	6	55	1305	64.317632000000003	64.337089000000006	54.912775000000003	54.906570000000002	0103000020E61000000100000005000000700A2B155414504072C45A7C0A744B40700A2B15541450409FCDAACFD5744B40D9B5BDDD921550409FCDAACFD5744B40D9B5BDDD9215504072C45A7C0A744B40700A2B155414504072C45A7C0A744B40
14681	Стрижово	6	55	1305	64.411865000000006	64.422500999999997	55.030137000000003	55.025312	0103000020E610000001000000050000007E5704FF5B1A50402219726C3D834B407E5704FF5B1A504025B37A87DB834B40BF61A2410A1B504025B37A87DB834B40BF61A2410A1B50402219726C3D834B407E5704FF5B1A50402219726C3D834B40
16086	Степное	6	55	1305	64.793235999999993	64.810151000000005	55.080519000000002	55.074891000000001	0103000020E61000000100000005000000A180ED60C4325040E3E13D0796894B40A180ED60C432504073DA53724E8A4B4097749483D933504073DA53724E8A4B4097749483D9335040E3E13D0796894B40A180ED60C4325040E3E13D0796894B40
15182	Сосновка	6	55	1305	65.000198999999995	65.009101000000001	55.069808999999999	55.062942	0103000020E610000001000000050000007B9FAA4203405040BDC5C37B0E884B407B9FAA4203405040B5FB5580EF884B4019575C1C95405040B5FB5580EF884B4019575C1C95405040BDC5C37B0E884B407B9FAA4203405040BDC5C37B0E884B40
14610	Сорокино	6	55	1305	64.195856000000006	64.213930000000005	54.960932999999997	54.952267999999997	0103000020E610000001000000050000006DAE9AE7880C50407F83F6EAE3794B406DAE9AE7880C5040D65240DAFF7A4B4088687407B10D5040D65240DAFF7A4B4088687407B10D50407F83F6EAE3794B406DAE9AE7880C50407F83F6EAE3794B40
54978	Советское	6	55	1305	64.515207000000004	64.546674999999993	54.630555000000001	54.617243000000002	0103000020E61000000100000005000000E6EAC726F9205040AC5791D1014F4B40E6EAC726F920504026AAB706B6504B409CA223B9FC22504026AAB706B6504B409CA223B9FC225040AC5791D1014F4B40E6EAC726F9205040AC5791D1014F4B40
16170	Пушкино	6	55	1305	64.627567999999997	64.650358999999995	54.981267000000003	54.969109000000003	0103000020E610000001000000050000000801F9122A28504030A182C30B7C4B400801F9122A28504070D234289A7D4B4031EA5A7B9F29504070D234289A7D4B4031EA5A7B9F29504030A182C30B7C4B400801F9122A28504030A182C30B7C4B40
14366	Птичье	6	55	1305	64.519806000000003	64.530334999999994	54.686739000000003	54.679057	0103000020E61000000100000005000000EF90628044215040588FFB56EB564B40EF90628044215040A2F14410E7574B40253B3602F1215040A2F14410E7574B40253B3602F1215040588FFB56EB564B40EF90628044215040588FFB56EB564B40
15952	Песьяное	6	55	1305	64.799640999999994	64.817848999999995	55.004064999999997	54.99194	0103000020E610000001000000050000009BE271512D33504010CCD1E3F77E4B409BE271512D3350407407B13385804B403E0455A3573450407407B13385804B403E0455A35734504010CCD1E3F77E4B409BE271512D33504010CCD1E3F77E4B40
15701	Перевалово	6	55	1305	64.525600999999995	64.543808999999996	54.760168	54.750427000000002	0103000020E61000000100000005000000AC6F6072A32150408884EFFD0D604B40AC6F6072A32150409DBB5D2F4D614B404F9143C4CD2250409DBB5D2F4D614B404F9143C4CD2250408884EFFD0D604B40AC6F6072A32150408884EFFD0D604B40
15903	Пепелино	6	55	1305	64.139747	64.153878000000006	55.067869999999999	55.043880999999999	0103000020E61000000100000005000000B4AD669DF108504038F581E49D854B40B4AD669DF10850409430D3F6AF884B40BB641C23D90950409430D3F6AF884B40BB641C23D909504038F581E49D854B40B4AD669DF108504038F581E49D854B40
14971	Острова	6	55	1305	64.345848000000004	64.359393999999995	54.560158000000001	54.555599999999998	0103000020E61000000100000005000000C558A65F221650402CD49AE61D474B40C558A65F22165040E04BE141B3474B403B18B14F00175040E04BE141B3474B403B18B14F001750402CD49AE61D474B40C558A65F221650402CD49AE61D474B40
15755	Обанино	6	55	1305	64.636210000000005	64.662845000000004	54.851246000000003	54.839779999999998	0103000020E61000000100000005000000D8D825AAB7285040DDEA39E97D6B4B40D8D825AAB7285040E86C01A1F56C4B404C546F0D6C2A5040E86C01A1F56C4B404C546F0D6C2A5040DDEA39E97D6B4B40D8D825AAB7285040DDEA39E97D6B4B40
55048	Новая Калиновка	6	55	1305	64.416984999999997	64.434835000000007	54.753737000000001	54.745255999999998	0103000020E610000001000000050000000B7BDAE1AF1A5040EA92718C645F4B400B7BDAE1AF1A504080643A747A604B40FF092E56D41B504080643A747A604B40FF092E56D41B5040EA92718C645F4B400B7BDAE1AF1A5040EA92718C645F4B40
55002	Нижнее	6	55	1305	64.464039	64.503923999999998	54.867896000000002	54.853127999999998	0103000020E610000001000000050000006344A2D0B21D5040A4A65D4C336D4B406344A2D0B21D5040242A5437176F4B40D9EA724A40205040242A5437176F4B40D9EA724A40205040A4A65D4C336D4B406344A2D0B21D5040A4A65D4C336D4B40
15536	Маслово	6	55	1305	64.245020999999994	64.265916000000004	55.081287000000003	55.070422000000001	0103000020E6100000010000000500000053758F6CAE0F50409F758D9603894B4053758F6CAE0F5040844BC79C678A4B40ECDE8AC404115040844BC79C678A4B40ECDE8AC4041150409F758D9603894B4053758F6CAE0F50409F758D9603894B40
15673	Малетино	6	55	1305	64.520525000000006	64.549963000000005	54.859689000000003	54.854159000000003	0103000020E6100000010000000500000007F0164850215040C34A0515556D4B4007F016485021504090DD054A0A6E4B40A5C002983223504090DD054A0A6E4B40A5C0029832235040C34A0515556D4B4007F0164850215040C34A0515556D4B40
16045	Лебяжье	6	55	1305	64.911597999999998	64.931647999999996	54.961041000000002	54.948551000000002	0103000020E610000001000000050000005646239F573A504047CB811E6A794B405646239F573A5040BD8E3864037B4B4090D8EE1EA03B5040BD8E3864037B4B4090D8EE1EA03B504047CB811E6A794B405646239F573A504047CB811E6A794B40
13752	Куртамыш	6	55	1305	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
14846	Курмыши	6	55	1305	64.849334999999996	64.866564999999994	54.818589000000003	54.812182999999997	0103000020E61000000100000005000000481630815B365040FFAECF9CF5674B40481630815B365040C4EE3B86C7684B40EDB60BCD75375040C4EE3B86C7684B40EDB60BCD75375040FFAECF9CF5674B40481630815B365040FFAECF9CF5674B40
16376	Красная Звезда	6	55	1305	64.591725999999994	64.611524000000003	54.622695	54.616852000000002	0103000020E61000000100000005000000588CBAD6DE255040713C9F01F54E4B40588CBAD6DE255040FD304278B44F4B40062E8F3523275040FD304278B44F4B40062E8F3523275040713C9F01F54E4B40588CBAD6DE255040713C9F01F54E4B40
15415	Косулино	6	55	1305	64.034589999999994	64.068493000000004	54.820078000000002	54.801732000000001	0103000020E6100000010000000500000031B1F9B8360250400E1478279F664B4031B1F9B836025040A515DF50F8684B4051C0763062045040A515DF50F8684B4051C07630620450400E1478279F664B4031B1F9B8360250400E1478279F664B40
15237	Костылево	6	55	1305	64.264847000000003	64.285616000000005	54.768878999999998	54.755623	0103000020E6100000010000000500000066DCD440F31050407E8D2441B8604B4066DCD440F310504064CA87A06A624B40B8CD54884712504064CA87A06A624B40B8CD5488471250407E8D2441B8604B4066DCD440F31050407E8D2441B8604B40
15622	Коновалова	6	55	1305	64.562287999999995	64.607310999999996	54.855657000000001	54.846285999999999	0103000020E61000000100000005000000BABBCE86FC23504005888219536C4B40BABBCE86FC235040F7CB272B866D4B4011E0F42EDE265040F7CB272B866D4B4011E0F42EDE26504005888219536C4B40BABBCE86FC23504005888219536C4B40
16336	Коминтерн	6	55	1305	64.542524999999998	64.555370999999994	54.558315	54.547668000000002	0103000020E61000000100000005000000CB10C7BAB82250406A882AFC19464B40CB10C7BAB8225040E1EEACDD76474B406589CE328B235040E1EEACDD76474B406589CE328B2350406A882AFC19464B40CB10C7BAB82250406A882AFC19464B40
15992	Ключики	6	55	1305	64.724991000000003	64.751401000000001	55.071998999999998	55.054237999999998	0103000020E610000001000000050000003DB9A640662E5040A8195245F1864B403DB9A640662E50401F2C634337894B40A14B38F4163050401F2C634337894B40A14B38F416305040A8195245F1864B403DB9A640662E5040A8195245F1864B40
15328	Клоктухино	6	55	1305	64.191158000000001	64.213355000000007	54.751071000000003	54.743546000000002	0103000020E610000001000000050000009A97C3EE3B0C50402B89EC832C5F4B409A97C3EE3B0C5040ADFC321823604B400ADCBA9BA70D5040ADFC321823604B400ADCBA9BA70D50402B89EC832C5F4B409A97C3EE3B0C50402B89EC832C5F4B40
15806	Кислое	6	55	1305	64.693737999999996	64.707222000000002	54.844346999999999	54.833443000000003	0103000020E61000000100000005000000847F1134662C5040420A9E42AE6A4B40847F1134662C5040E4BCFF8F136C4B40C0401020432D5040E4BCFF8F136C4B40C0401020432D5040420A9E42AE6A4B40847F1134662C5040420A9E42AE6A4B40
15115	Камыши	6	55	1305	64.905606000000006	64.921964000000003	55.029404	55.021323000000002	0103000020E61000000100000005000000EE43DE72F539504089D349B6BA824B40EE43DE72F5395040902FA182C3834B40B8054B75013B5040902FA182C3834B40B8054B75013B504089D349B6BA824B40EE43DE72F539504089D349B6BA824B40
15089	Каминское	6	55	1305	64.942383000000007	64.975818000000004	54.804389	54.775444	0103000020E610000001000000050000009C53C900503C504091F0BDBF41634B409C53C900503C50408E210038F6664B40483657CD733E50408E210038F6664B40483657CD733E504091F0BDBF41634B409C53C900503C504091F0BDBF41634B40
54988	Камаган	6	55	1305	64.256573000000003	64.298794000000001	54.599424999999997	54.589696000000004	0103000020E61000000100000005000000580229B16B105040804A95287B4B4B40580229B16B105040D0B359F5B94C4B406D8FDE701F135040D0B359F5B94C4B406D8FDE701F135040804A95287B4B4B40580229B16B105040804A95287B4B4B40
14762	Закоулово	6	55	1305	64.884557999999998	64.903710000000004	54.842314999999999	54.822972999999998	0103000020E61000000100000005000000925A28999C385040D93EE42D57694B40925A28999C38504012F758FAD06B4B405DC47762D639504012F758FAD06B4B405DC47762D6395040D93EE42D57694B40925A28999C385040D93EE42D57694B40
14664	Закомалдино	6	55	1305	64.529104000000004	64.553403000000003	55.017648000000001	55.007561000000003	0103000020E61000000100000005000000B30B06D7DC215040CFDC43C2F7804B40B30B06D7DC2150407F6B274A42824B4088A06AF46A2350407F6B274A42824B4088A06AF46A235040CFDC43C2F7804B40B30B06D7DC215040CFDC43C2F7804B40
14547	Жуково	6	55	1305	64.230585000000005	64.250815000000003	54.939340999999999	54.928825000000003	0103000020E61000000100000005000000AF7C96E7C10E5040865AD3BCE3764B40AF7C96E7C10E50405E656D533C784B4029965B5A0D1050405E656D533C784B4029965B5A0D105040865AD3BCE3764B40AF7C96E7C10E5040865AD3BCE3764B40
14418	Долговка	6	55	1305	64.132624000000007	64.168574000000007	54.994419000000001	54.966881999999998	0103000020E610000001000000050000008BAA5FE97C085040A88B14CAC27B4B408BAA5FE97C085040B1C22D1F497F4B402E3D9AEAC90A5040B1C22D1F497F4B402E3D9AEAC90A5040A88B14CAC27B4B408BAA5FE97C085040A88B14CAC27B4B40
16272	Добровольное	6	55	1305	64.415268999999995	64.425070000000005	54.557814	54.551554000000003	0103000020E61000000100000005000000BA826DC4931A50402FFD4B5299464B40BA826DC4931A50401FA0FB7266474B40B020CD58341B50401FA0FB7266474B40B020CD58341B50402FFD4B5299464B40BA826DC4931A50402FFD4B5299464B40
15254	Вехти	6	55	1305	64.343278999999995	64.366527000000005	54.776814999999999	54.765649000000003	0103000020E61000000100000005000000D4997B48F8155040899B53C900624B40D4997B48F8155040680586AC6E634B407786A92D75175040680586AC6E634B407786A92D75175040899B53C900624B40D4997B48F8155040899B53C900624B40
55003	Верхнее	6	55	1305	64.261854999999997	64.284062000000006	54.908816000000002	54.896149000000001	0103000020E61000000100000005000000D252793BC2105040EBABAB02B5724B40D252793BC2105040700A2B1554744B40540262122E125040700A2B1554744B40540262122E125040EBABAB02B5724B40D252793BC2105040EBABAB02B5724B40
14260	Березово	6	55	1305	64.460391999999999	64.469769999999997	54.673054	54.660598999999998	0103000020E61000000100000005000000C3D50110771D504099620E828E544B40C3D50110771D504093382BA226564B4015A930B6101E504093382BA226564B4015A930B6101E504099620E828E544B40C3D50110771D504099620E828E544B40
14229	Белоногово	6	55	1305	64.144651999999994	64.167586	54.783527999999997	54.764297999999997	0103000020E61000000100000005000000435376FA41095040F8325184D4614B40435376FA4109504009C03FA54A644B401E51A1BAB90A504009C03FA54A644B401E51A1BAB90A5040F8325184D4614B40435376FA41095040F8325184D4614B40
12869	сельского типа Новая Сидоровка	6	55	1181	65.110951999999997	65.132395000000002	55.405414	55.394652999999998	0103000020E6100000010000000500000040DB6AD619475040572250FD83B24B4040DB6AD61947504097AB1F9BE4B34B40DAC9E0287948504097AB1F9BE4B34B40DAC9E02879485040572250FD83B24B4040DB6AD619475040572250FD83B24B40
60764	микрорайон КГСХА	6	55	1181	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
54917	Шмаково	6	55	1181	64.847036000000003	64.873975999999999	55.197111999999997	55.183410000000002	0103000020E6100000010000000500000038A27BD63536504033E197FA79974B4038A27BD63536504017D34CF73A994B404A5F0839EF37504017D34CF73A994B404A5F0839EF37504033E197FA79974B4038A27BD63536504033E197FA79974B40
55021	Шкодинское	6	55	1181	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
13407	Чесноки	6	55	1181	64.865432999999996	64.894557000000006	55.305363999999997	55.290588	0103000020E6100000010000000500000044F8174163375040164ED2FC31A54B4044F817416337504018B0E42A16A74B401BDA006C4039504018B0E42A16A74B401BDA006C40395040164ED2FC31A54B4044F8174163375040164ED2FC31A54B40
13099	Чашинский	6	55	1181	64.951365999999993	64.973105000000004	55.668407000000002	55.649026999999997	0103000020E61000000100000005000000AF21382EE33C5040499C155113D34B40AF21382EE33C504070B54E5C8ED54B40BEA4315A473E504070B54E5C8ED54B40BEA4315A473E5040499C155113D34B40AF21382EE33C5040499C155113D34B40
11712	Усть-Утяк	6	55	1181	65.291325000000001	65.315057999999993	55.279006000000003	55.268994999999997	0103000020E6100000010000000500000076E09C11A5525040CDE49B6D6EA24B4076E09C11A5525040A3B1F677B6A34B40F69507E929545040A3B1F677B6A34B40F69507E929545040CDE49B6D6EA24B4076E09C11A5525040CDE49B6D6EA24B40
11819	Темляково	6	55	1181	65.204151999999993	65.221247000000005	55.211748	55.197496999999998	0103000020E610000001000000050000006EDA8CD3104D50407007EA9447994B406EDA8CD3104D5040287FF78E1A9B4B40A4552DE9284E5040287FF78E1A9B4B40A4552DE9284E50407007EA9447994B406EDA8CD3104D50407007EA9447994B40
12957	Сычево	6	55	1181	64.948869000000002	64.971929000000003	55.439481999999998	55.428924000000002	0103000020E610000001000000050000000CCC0A45BA3C5040193C4CFBE6B64B400CCC0A45BA3C5040209738F240B84B402D42B115343E5040209738F240B84B402D42B115343E5040193C4CFBE6B64B400CCC0A45BA3C5040193C4CFBE6B64B40
54970	Старый Просвет	6	55	1181	65.038566000000003	65.068838999999997	55.606619000000002	55.592540999999997	0103000020E61000000100000005000000342F87DD7742504002452C62D8CB4B40342F87DD77425040ED10FFB0A5CD4B401E6CB1DB67445040ED10FFB0A5CD4B401E6CB1DB6744504002452C62D8CB4B40342F87DD7742504002452C62D8CB4B40
11934	Становая	6	55	1181	65.478883999999994	65.496958000000006	55.262633999999998	55.252716999999997	0103000020E61000000100000005000000F8A41309A65E50405512D90759A04B40F8A41309A65E5040A968ACFD9DA14B40145FED28CE5F5040A968ACFD9DA14B40145FED28CE5F50405512D90759A04B40F8A41309A65E50405512D90759A04B40
12218	Светлые Поляны	6	55	1181	65.568922000000001	65.582189999999997	55.303052999999998	55.297691999999998	0103000020E6100000010000000500000065FED13769645040F2237EC51AA64B4065FED1376964504033FAD170CAA64B40BA83D8994265504033FAD170CAA64B40BA83D89942655040F2237EC51AA64B4065FED13769645040F2237EC51AA64B40
55029	Садовое	6	55	1181	65.114051000000003	65.140029999999996	55.259186999999997	55.243448999999998	0103000020E61000000100000005000000DFC4909C4C475040389F3A56299F4B40DFC4909C4C4750403046240A2DA14B405E9D6340F64850403046240A2DA14B405E9D6340F6485040389F3A56299F4B40DFC4909C4C475040389F3A56299F4B40
13669	Романовка	6	55	1181	65.042993999999993	65.050801000000007	55.343347999999999	55.340117999999997	0103000020E6100000010000000500000026FBE769C0425040F56393FC88AB4B4026FBE769C0425040D192C7D3F2AB4B40AA66D65240435040D192C7D3F2AB4B40AA66D65240435040F56393FC88AB4B4026FBE769C0425040F56393FC88AB4B40
12094	Ровная	6	55	1181	65.478353999999996	65.496661000000003	55.155138999999998	55.144427999999998	0103000020E610000001000000050000004A7A185A9D5E50403750E09D7C924B404A7A185A9D5E5040C5AA4198DB934B40B70C384BC95F5040C5AA4198DB934B40B70C384BC95F50403750E09D7C924B404A7A185A9D5E50403750E09D7C924B40
54946	Просвет	6	55	1181	65.054789	65.094144	55.575285999999998	55.560091999999997	0103000020E610000001000000050000008ECBB8A98143504028603B18B1C74B408ECBB8A9814350405FECBDF8A2C94B4056478E74064650405FECBDF8A2C94B4056478E740646504028603B18B1C74B408ECBB8A98143504028603B18B1C74B40
11480	Придорожный	6	55	1181	65.401646999999997	65.414456999999999	55.379117000000001	55.370835	0103000020E6100000010000000500000056629E95B4595040289B728577AF4B4056629E95B4595040C72DE6E786B04B404A26A776865A5040C72DE6E786B04B404A26A776865A5040289B728577AF4B4056629E95B4595040289B728577AF4B40
13392	Пименовка	6	55	1181	64.904060999999999	64.940200000000004	55.349229999999999	55.340434999999999	0103000020E61000000100000005000000B325AB22DC395040F6B4C35F93AB4B40B325AB22DC3950401B649291B3AC4B40C0EC9E3C2C3C50401B649291B3AC4B40C0EC9E3C2C3C5040F6B4C35F93AB4B40B325AB22DC395040F6B4C35F93AB4B40
54969	Падеринское	6	55	1181	65.587363999999994	65.608761999999999	55.600003000000001	55.583657000000002	0103000020E6100000010000000500000041B62C5F976550406E8AC745B5CA4B4041B62C5F976550403E40F7E5CCCC4B400B43E4F4F56650403E40F7E5CCCC4B400B43E4F4F56650406E8AC745B5CA4B4041B62C5F976550406E8AC745B5CA4B40
13259	Орловка	6	55	1181	64.792013999999995	64.822979000000004	55.202378000000003	55.196936999999998	0103000020E6100000010000000500000058FE7C5BB0325040A92F4B3B35994B4058FE7C5BB032504007B7B585E7994B40DE921CB0AB34504007B7B585E7994B40DE921CB0AB345040A92F4B3B35994B4058FE7C5BB0325040A92F4B3B35994B40
13686	Новокомогоровка	6	55	1181	64.966376999999994	64.981451000000007	55.278452000000001	55.271327999999997	0103000020E61000000100000005000000D2A6EA1ED93D50409A3E3BE0BAA24B40D2A6EA1ED93D5040BEC0AC50A4A34B4019E8DA17D03E5040BEC0AC50A4A34B4019E8DA17D03E50409A3E3BE0BAA24B40D2A6EA1ED93D50409A3E3BE0BAA24B40
12487	Новое Лушниково	6	55	1181	65.635334	65.650462000000005	55.582903999999999	55.576096	0103000020E610000001000000050000005C02F04FA96850409FAD8383BDC94B405C02F04FA9685040925A28999CCA4B409C525E2BA1695040925A28999CCA4B409C525E2BA16950409FAD8383BDC94B405C02F04FA96850409FAD8383BDC94B40
12004	Митино	6	55	1181	65.472532999999999	65.493876999999998	55.203040999999999	55.184869999999997	0103000020E61000000100000005000000F8510DFB3D5E50407901F6D1A9974B40F8510DFB3D5E5040A25F5B3FFD994B40C8CF46AE9B5F5040A25F5B3FFD994B40C8CF46AE9B5F50407901F6D1A9974B40F8510DFB3D5E50407901F6D1A9974B40
54960	Менщиково	6	55	1181	65.075837000000007	65.115748999999994	55.217207999999999	55.201129999999999	0103000020E61000000100000005000000EAB46E83DA4450404B1FBAA0BE994B40EAB46E83DA445040FC36C478CD9B4B40DC627E6E68475040FC36C478CD9B4B40DC627E6E684750404B1FBAA0BE994B40EAB46E83DA4450404B1FBAA0BE994B40
11989	Марково	6	55	1181	65.657244000000006	65.688963999999999	55.286025000000002	55.261577000000003	0103000020E61000000100000005000000815F2349106A50406231EA5A7BA14B40815F2349106A5040516B9A779CA44B40C40776FC176C5040516B9A779CA44B40C40776FC176C50406231EA5A7BA14B40815F2349106A50406231EA5A7BA14B40
12171	Лукино	6	55	1181	65.449759999999998	65.464438999999999	55.358724000000002	55.350662999999997	0103000020E6100000010000000500000022C32ADEC85C504068757286E2AC4B4022C32ADEC85C5040292504ABEAAD4B402AFF5A5EB95D5040292504ABEAAD4B402AFF5A5EB95D504068757286E2AC4B4022C32ADEC85C504068757286E2AC4B40
12789	Логоушка	6	55	1181	65.006863999999993	65.029915000000003	55.435702999999997	55.42989	0103000020E6100000010000000500000043E1B375704050405070B1A206B74B4043E1B3757040504071E2AB1DC5B74B403BAA9A20EA41504071E2AB1DC5B74B403BAA9A20EA4150405070B1A206B74B4043E1B375704050405070B1A206B74B40
12973	Логовушка	6	55	1181	64.901455999999996	64.919161000000003	55.414624000000003	55.408695000000002	0103000020E610000001000000050000001CB28174B1395040F584251E50B44B401CB28174B13950408011346612B54B408EB0A888D33A50408011346612B54B408EB0A888D33A5040F584251E50B44B401CB28174B1395040F584251E50B44B40
54942	Лесниково	6	55	1181	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
12902	Кропани	6	55	1181	65.112909999999999	65.131621999999993	55.368558999999998	55.365150999999997	0103000020E610000001000000050000000C59DDEA39475040048D9944BDAE4B400C59DDEA39475040BFD2F9F02CAF4B40C85BAE7E6C485040BFD2F9F02CAF4B40C85BAE7E6C485040048D9944BDAE4B400C59DDEA39475040048D9944BDAE4B40
54937	Колташево	6	55	1181	65.595844	65.616775000000004	55.485097000000003	55.477153000000001	0103000020E610000001000000050000002461DF4E226650401A18795913BD4B402461DF4E22665040A13193A817BE4B40637FD93D79675040A13193A817BE4B40637FD93D796750401A18795913BD4B402461DF4E226650401A18795913BD4B40
12130	Колесниково	6	55	1181	65.517573999999996	65.545143999999993	55.335816999999999	55.317352999999997	0103000020E61000000100000005000000A2D0B2EE1F615040CC24EA059FA84B40A2D0B2EE1F6150406D382C0DFCAA4B4014E7A8A3E36250406D382C0DFCAA4B4014E7A8A3E3625040CC24EA059FA84B40A2D0B2EE1F615040CC24EA059FA84B40
54915	Кетово	6	55	1181	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
54916	Каширино	6	55	1181	65.511510999999999	65.535405999999995	55.285573999999997	55.270308	0103000020E61000000100000005000000D522A298BC60504070ECD97399A24B40D522A298BC605040404B57B08DA44B404205871744625040404B57B08DA44B40420587174462504070ECD97399A24B40D522A298BC60504070ECD97399A24B40
54945	Иковка	6	55	1181	64.920813999999993	64.967113999999995	55.616117000000003	55.601909999999997	0103000020E61000000100000005000000BBECD79DEE3A504053910A630BCD4B40BBECD79DEE3A50403CC1FEEBDCCE4B403D601E32E53D50403CC1FEEBDCCE4B403D601E32E53D504053910A630BCD4B40BBECD79DEE3A504053910A630BCD4B40
12425	Залесовский	6	55	1181	65.594165000000004	65.601665999999994	55.458741000000003	55.454059999999998	0103000020E6100000010000000500000062DBA2CC06665040FC3559A31EBA4B4062DBA2CC06665040CC2A6C06B8BA4B405E471CB281665040CC2A6C06B8BA4B405E471CB281665040FC3559A31EBA4B4062DBA2CC06665040FC3559A31EBA4B40
12326	Грачево	6	55	1181	65.673225000000002	65.692628999999997	55.511017000000002	55.503354000000002	0103000020E6100000010000000500000060764F1E166B5040C82764E76DC04B4060764F1E166B50409B594B0169C14B40B7D09508546C50409B594B0169C14B40B7D09508546C5040C82764E76DC04B4060764F1E166B5040C82764E76DC04B40
13531	Галишово	6	55	1181	64.969386	64.998446999999999	55.198447999999999	55.188586000000001	0103000020E61000000100000005000000D1CC936B0A3E5040E23D079623984B40D1CC936B0A3E504072FA7ABE66994B4084F23E8EE63F504072FA7ABE66994B4084F23E8EE63F5040E23D079623984B40D1CC936B0A3E5040E23D079623984B40
54949	Введенское	6	55	1181	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
54943	Большое Чаусово	6	55	1181	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
13335	Большое Раково	6	55	1181	64.740324999999999	64.759000999999998	55.237135000000002	55.225147	0103000020E6100000010000000500000051DA1B7C612F504071E5EC9DD19C4B4051DA1B7C612F504055DE8E705A9E4B406728EE789330504055DE8E705A9E4B406728EE789330504071E5EC9DD19C4B4051DA1B7C612F504071E5EC9DD19C4B40
12597	Белый Яр	6	55	1181	65.472460999999996	65.480823999999998	55.54289	55.536394999999999	0103000020E61000000100000005000000ABE80FCD3C5E5040745E6397A8C44B40ABE80FCD3C5E5040A8A9656B7DC54B4071C806D2C55E5040A8A9656B7DC54B4071C806D2C55E5040745E6397A8C44B40ABE80FCD3C5E5040745E6397A8C44B40
11800	Бараба	6	55	1181	65.229511000000002	65.259990999999999	55.253270999999998	55.232767000000003	0103000020E61000000100000005000000A0C4E74EB04E5040454B1E4FCB9D4B40A0C4E74EB04E50403A03232F6BA04B4047904AB1A35050403A03232F6BA04B4047904AB1A3505040454B1E4FCB9D4B40A0C4E74EB04E5040454B1E4FCB9D4B40
16592	Балки	6	55	1181	65.323627999999999	65.331569000000002	55.281543999999997	55.277093000000001	0103000020E6100000010000000500000079043752B6545040AB798EC877A34B4079043752B6545040483140A209A44B4084D72E6D38555040483140A209A44B4084D72E6D38555040AB798EC877A34B4079043752B6545040AB798EC877A34B40
10239	Шутихинское	6	55	1038	62.622430000000001	62.654868	56.067419000000001	56.046830999999997	0103000020E610000001000000050000004F0647C9AB4F4F4030B8E68EFE054C404F0647C9AB4F4F408410902FA1084C403599F1B6D2534F408410902FA1084C403599F1B6D2534F4030B8E68EFE054C404F0647C9AB4F4F4030B8E68EFE054C40
9677	Шутино	6	55	1038	62.757185999999997	62.780946999999998	56.416530000000002	56.400444	0103000020E61000000100000005000000997E8978EB604F4091F0BDBF41334C40997E8978EB604F40C5E6E3DA50354C4064744012F6634F40C5E6E3DA50354C4064744012F6634F4091F0BDBF41334C40997E8978EB604F4091F0BDBF41334C40
11205	Чусовая	6	55	1038	62.528061999999998	62.557409999999997	56.186329000000001	56.181559999999998	0103000020E6100000010000000500000053211E8997434F408121AB5B3D174C4053211E8997434F40F0A5F0A0D9174C404F3BFC3559474F40F0A5F0A0D9174C404F3BFC3559474F408121AB5B3D174C4053211E8997434F408121AB5B3D174C40
9990	Черемисское	6	55	1038	62.648077000000001	62.683632000000003	56.250802	56.238022000000001	0103000020E610000001000000050000001825E82FF4524F4040DD4081771E4C401825E82FF4524F40BDE2A9471A204C40E23FDD4081574F40BDE2A9471A204C40E23FDD4081574F4040DD4081771E4C401825E82FF4524F4040DD4081771E4C40
10709	Ушаковское	6	55	1038	62.432417999999998	62.477091000000001	56.287461999999998	56.275238999999999	0103000020E61000000100000005000000D219187959374F40B8CA13083B234C40D219187959374F40DF6B088ECB244C40A41B6151113D4F40DF6B088ECB244C40A41B6151113D4F40B8CA13083B234C40D219187959374F40B8CA13083B234C40
10126	Улугушское	6	55	1038	62.325321000000002	62.348757999999997	56.072308	56.063132000000003	0103000020E61000000100000005000000DCD9571EA4294F4061AA99B514084C40DCD9571EA4294F409D9E776341094C40F31B261AA42C4F409D9E776341094C40F31B261AA42C4F4061AA99B514084C40DCD9571EA4294F4061AA99B514084C40
10150	Петропавловское	6	55	1038	62.545211000000002	62.573256000000001	56.087071999999999	56.070163000000001	0103000020E61000000100000005000000B1355B79C9454F40D331E719FB084C40B1355B79C9454F40DB32E02C250B4C402E1EDE7360494F40DB32E02C250B4C402E1EDE7360494F40D331E719FB084C40B1355B79C9454F40D331E719FB084C40
10782	Оконечникова	6	55	1038	62.402090999999999	62.434241999999998	56.289529999999999	56.285783000000002	0103000020E610000001000000050000000A82C7B777334F405B608F8994244C400A82C7B777334F40FE9AAC510F254C405A46EA3D95374F40FE9AAC510F254C405A46EA3D95374F405B608F8994244C400A82C7B777334F405B608F8994244C40
10609	Никитинское	6	55	1038	62.371971000000002	62.392083999999997	56.2836	56.274514000000003	0103000020E61000000100000005000000BC07E8BE9C2F4F40A725564623234C40BC07E8BE9C2F4F40A3923A014D244C4076A4FACE2F324F40A3923A014D244C4076A4FACE2F324F40A725564623234C40BC07E8BE9C2F4F40A725564623234C40
10928	Марай	6	55	1038	62.203023999999999	62.210112000000002	56.237521999999998	56.227615	0103000020E61000000100000005000000CC26C0B0FC194F401E8A027D221D4C40CC26C0B0FC194F404E0AF31E671E4C40A33F34F3E41A4F404E0AF31E671E4C40A33F34F3E41A4F401E8A027D221D4C40CC26C0B0FC194F401E8A027D221D4C40
9696	Лукина	6	55	1038	62.710006999999997	62.731512000000002	56.432923000000002	56.425372000000003	0103000020E610000001000000050000002D776682E15A4F402B51F69672364C402D776682E15A4F40D65757056A374C40D7506A2FA25D4F40D65757056A374C40D7506A2FA25D4F402B51F69672364C402D776682E15A4F402B51F69672364C40
10526	Лобаново	6	55	1038	62.413006000000003	62.447519	55.868071	55.857104	0103000020E61000000100000005000000A1866F61DD344F40A9A27895B5ED4B40A1866F61DD344F4092CD55F31CEF4B4058AB764D48394F4092CD55F31CEF4B4058AB764D48394F40A9A27895B5ED4B40A1866F61DD344F40A9A27895B5ED4B40
9768	Корюково	6	55	1038	62.464658999999997	62.507238999999998	56.402839999999998	56.380662000000001	0103000020E61000000100000005000000626534F2793B4F403C6A4C88B9304C40626534F2793B4F40A4C2D84290334C40BC202235ED404F40A4C2D84290334C40BC202235ED404F403C6A4C88B9304C40626534F2793B4F403C6A4C88B9304C40
10445	Камышино	6	55	1038	62.723588999999997	62.746236000000003	55.913626000000001	55.907691999999997	0103000020E61000000100000005000000675F79909E5C4F40A06B5F402FF44B40675F79909E5C4F403D635FB2F1F44B40878C47A9845F4F403D635FB2F1F44B40878C47A9845F4F40A06B5F402FF44B40675F79909E5C4F40A06B5F402FF44B40
10306	Казанцева	6	55	1038	62.560445999999999	62.583928	55.940694000000001	55.925854000000001	0103000020E610000001000000050000004696CCB1BC474F40766F456282F64B404696CCB1BC474F408FC536A968F84B40FE9B1727BE4A4F408FC536A968F84B40FE9B1727BE4A4F40766F456282F64B404696CCB1BC474F40766F456282F64B40
10674	Ипатова	6	55	1038	62.352181000000002	62.363957999999997	56.298627000000003	56.289520000000003	0103000020E61000000100000005000000E4A25A44142D4F40DBC4C9FD0E254C40E4A25A44142D4F40EF59D76839264C400C8FFD2C962E4F40EF59D76839264C400C8FFD2C962E4F40DBC4C9FD0E254C40E4A25A44142D4F40DBC4C9FD0E254C40
54955	Ильинское	6	55	1038	62.568486	62.602837999999998	56.277102999999997	56.257973	0103000020E61000000100000005000000EF1D3526C4484F4021205F4205214C40EF1D3526C4484F40CE4F711C78234C409D64ABCB294D4F40CE4F711C78234C409D64ABCB294D4F4021205F4205214C40EF1D3526C4484F4021205F4205214C40
10861	Зырянка	6	55	1038	62.122751000000001	62.143861000000001	56.222284999999999	56.211843999999999	0103000020E610000001000000050000009146054EB60F4F404AED45B41D1B4C409146054EB60F4F4018B2BAD5731C4C40BE1589096A124F4018B2BAD5731C4C40BE1589096A124F404AED45B41D1B4C409146054EB60F4F404AED45B41D1B4C40
11149	Заречье	6	55	1038	62.623364000000002	62.632697999999998	56.261913	56.258257999999998	0103000020E610000001000000050000007BC03C64CA4F4F4016F71F990E214C407BC03C64CA4F4F40D9B27C5D86214C404F1F813FFC504F40D9B27C5D86214C404F1F813FFC504F4016F71F990E214C407BC03C64CA4F4F4016F71F990E214C40
9919	Гусиное	6	55	1038	62.715764999999998	62.726886	56.277867999999998	56.271326000000002	0103000020E610000001000000050000008B4F01309E5B4F40FA4674CFBA224C408B4F01309E5B4F406E4DBA2D91234C40CBF5B6990A5D4F406E4DBA2D91234C40CBF5B6990A5D4F40FA4674CFBA224C408B4F01309E5B4F40FA4674CFBA224C40
10366	Верхняя Теча	6	55	1038	62.581969999999998	62.604894999999999	55.920037999999998	55.901035999999998	0103000020E6100000010000000500000066A032FE7D4A4F406342CC2555F34B4066A032FE7D4A4F40E38920CEC3F54B40C84109336D4D4F40E38920CEC3F54B40C84109336D4D4F406342CC2555F34B4066A032FE7D4A4F406342CC2555F34B40
10086	Верхние Пески	6	55	1038	62.586101999999997	62.612324000000001	56.188147000000001	56.178488000000002	0103000020E61000000100000005000000620FED63054B4F403E5DDDB1D8164C40620FED63054B4F4096EB6D3315184C40284701A2604E4F4096EB6D3315184C40284701A2604E4F403E5DDDB1D8164C40620FED63054B4F403E5DDDB1D8164C40
10992	Верхнеключевское	6	55	1038	62.227629	62.257049000000002	56.263196999999998	56.253042000000001	0103000020E61000000100000005000000834F73F2221D4F40D94125AE63204C40834F73F2221D4F40E1B37570B0214C40193C4CFBE6204F40E1B37570B0214C40193C4CFBE6204F40D94125AE63204C40834F73F2221D4F40D94125AE63204C40
10276	Бугаево	6	55	1038	62.687522000000001	62.716735	55.985765000000001	55.966881999999998	0103000020E61000000100000005000000E8A38CB800584F40A88B14CAC2FB4B40E8A38CB800584F404E452A8C2DFE4B400473F4F8BD5B4F404E452A8C2DFE4B400473F4F8BD5B4F40A88B14CAC2FB4B40E8A38CB800584F40A88B14CAC2FB4B40
9829	Боровское	6	55	1038	62.641474000000002	62.671180999999997	56.272835000000001	56.262481999999999	0103000020E61000000100000005000000FE9DEDD11B524F40F3E49A0299214C40FE9DEDD11B524F40221ADD41EC224C4029594E42E9554F40221ADD41EC224C4029594E42E9554F40F3E49A0299214C40FE9DEDD11B524F40F3E49A0299214C40
10916	Борисова	6	55	1038	62.143241000000003	62.166400000000003	56.241118999999998	56.224212000000001	0103000020E61000000100000005000000223999B855124F4075AF93FAB21C4C40223999B855124F40DCB8C5FCDC1E4C40F7065F984C154F40DCB8C5FCDC1E4C40F7065F984C154F4075AF93FAB21C4C40223999B855124F4075AF93FAB21C4C40
10792	Большое Касаргульское	6	55	1038	62.329211000000001	62.342514999999999	56.156210000000002	56.144877999999999	0103000020E61000000100000005000000E23D0796232A4F4077F4BF5C8B124C40E23D0796232A4F4072A774B0FE134C40D9B11188D72B4F4072A774B0FE134C40D9B11188D72B4F4077F4BF5C8B124C40E23D0796232A4F4077F4BF5C8B124C40
10596	Басказык	6	55	1038	62.544671999999998	62.555748000000001	55.813034999999999	55.802638999999999	0103000020E610000001000000050000000186E5CFB7454F4040BFEFDFBCE64B400186E5CFB7454F406EC0E78711E84B40A1681EC022474F406EC0E78711E84B40A1681EC022474F4040BFEFDFBCE64B400186E5CFB7454F4040BFEFDFBCE64B40
10458	Анчугово	6	55	1038	62.553367000000001	62.585231	55.899102999999997	55.886876999999998	0103000020E61000000100000005000000C3D7D7BAD4464F408C497F2F85F14B40C3D7D7BAD4464F40245E9ECE15F34B407DCD72D9E84A4F40245E9ECE15F34B407DCD72D9E84A4F408C497F2F85F14B40C3D7D7BAD4464F408C497F2F85F14B40
7440	Шахматова	6	55	909	64.519519000000003	64.531889000000007	56.003194999999998	55.988253	0103000020E61000000100000005000000A4A99ECC3F215040429605137FFE4B40A4A99ECC3F2150405F419AB168004C408A0629780A2250405F419AB168004C408A0629780A225040429605137FFE4B40A4A99ECC3F215040429605137FFE4B40
7679	Чемякина	6	55	909	64.755560000000003	64.771576999999994	56.042788000000002	56.030422000000002	0103000020E610000001000000050000009C8A54185B3050401A8A3BDEE4034C409C8A54185B305040A454C2137A054C4021567F8461315040A454C2137A054C4021567F84613150401A8A3BDEE4034C409C8A54185B3050401A8A3BDEE4034C40
55033	Чаши	6	55	909	64.857159999999993	64.892579999999995	55.905861000000002	55.890588000000001	0103000020E610000001000000050000001EDC9DB5DB365040E31A9FC9FEF14B401EDC9DB5DB36504066DCD440F3F34B401344DD072039504066DCD440F3F34B401344DD0720395040E31A9FC9FEF14B401EDC9DB5DB365040E31A9FC9FEF14B40
54913	Чаши	6	55	909	64.857159999999993	64.892579999999995	55.905861000000002	55.890588000000001	0103000020E610000001000000050000001EDC9DB5DB365040E31A9FC9FEF14B401EDC9DB5DB36504066DCD440F3F34B401344DD072039504066DCD440F3F34B401344DD0720395040E31A9FC9FEF14B401EDC9DB5DB365040E31A9FC9FEF14B40
8673	Усть-Миасское	6	55	909	64.467623000000003	64.480236000000005	56.054090000000002	56.033580000000001	0103000020E61000000100000005000000E0F60489ED1D50405CE674594C044C40E0F60489ED1D50403485CE6BEC064C402997C62FBC1E50403485CE6BEC064C402997C62FBC1E50405CE674594C044C40E0F60489ED1D50405CE674594C044C40
7672	Тукманное	6	55	909	64.711031000000006	64.721513999999999	55.970464	55.959071999999999	0103000020E610000001000000050000004DDC2A88812D504031410DDFC2FA4B404DDC2A88812D504001F9122A38FC4B40CB660E492D2E504001F9122A38FC4B40CB660E492D2E504031410DDFC2FA4B404DDC2A88812D504031410DDFC2FA4B40
8634	Твердыш	6	55	909	64.487710000000007	64.512054000000006	55.750042999999998	55.739311000000001	0103000020E61000000100000005000000A9FB00A4361F50405A492BBEA1DE4B40A9FB00A4361F5040FFCBB56801E04B404EF2237EC5205040FFCBB56801E04B404EF2237EC52050405A492BBEA1DE4B40A9FB00A4361F50405A492BBEA1DE4B40
55012	Тагильская	6	55	909	64.420291000000006	64.439874000000003	55.931663	55.913373999999997	0103000020E6100000010000000500000067F3380CE61A504023827170E9F44B4067F3380CE61A504056F2B1BB40F74B40161747E5261C504056F2B1BB40F74B40161747E5261C504023827170E9F44B4067F3380CE61A504023827170E9F44B40
8480	Сосновка	6	55	909	64.662871999999993	64.685096000000001	55.719658000000003	55.709175000000002	0103000020E61000000100000005000000C85BAE7E6C2A50400612143FC6DA4B40C85BAE7E6C2A50400327DBC01DDC4B40B5A7E49CD82B50400327DBC01DDC4B40B5A7E49CD82B50400612143FC6DA4B40C85BAE7E6C2A50400612143FC6DA4B40
8425	Соколово	6	55	909	64.063030999999995	64.077269000000001	55.644531000000001	55.637529999999998	0103000020E6100000010000000500000096E82CB308045040041C42959AD14B4096E82CB3080450400C21E7FD7FD24B40A8FFACF9F10450400C21E7FD7FD24B40A8FFACF9F1045040041C42959AD14B4096E82CB308045040041C42959AD14B40
8407	Северная	6	55	909	65.007339999999999	65.026653999999994	56.075111999999997	56.061669999999999	0103000020E61000000100000005000000F8FC304278405040799274CDE4074C40F8FC304278405040C1C41F459D094C40AF93FAB2B4415040C1C41F459D094C40AF93FAB2B4415040799274CDE4074C40F8FC304278405040799274CDE4074C40
7541	Салтосарайская	6	55	909	64.974272999999997	64.993038999999996	55.786287999999999	55.774720000000002	0103000020E610000001000000050000000D18247D5A3E504050C763062AE34B400D18247D5A3E50405E9ECE15A5E44B40C32973F38D3F50405E9ECE15A5E44B40C32973F38D3F504050C763062AE34B400D18247D5A3E504050C763062AE34B40
8333	Осиновское	6	55	909	64.085290999999998	64.110938000000004	56.039257999999997	56.026181000000001	0103000020E6100000010000000500000029E9616875055040676325E659034C4029E96168750550409D0DF96706054C408E78B29B190750409D0DF96706054C408E78B29B19075040676325E659034C4029E9616875055040676325E659034C40
8276	Окуневское	6	55	909	64.175095999999996	64.190736000000001	55.743932999999998	55.736828000000003	0103000020E61000000100000005000000446ADAC5340B50407863416150DE4B40446ADAC5340B504024B5503239DF4B40DF8AC404350C504024B5503239DF4B40DF8AC404350C50407863416150DE4B40446ADAC5340B50407863416150DE4B40
8261	Новоиковское	6	55	909	64.849667999999994	64.873231000000004	55.957126000000002	55.939540000000001	0103000020E610000001000000050000004B1DE4F56036504055A4C2D842F84B404B1DE4F5603650405E13D21A83FA4B409EB64604E33750405E13D21A83FA4B409EB64604E337504055A4C2D842F84B404B1DE4F56036504055A4C2D842F84B40
9023	Нечунаева	6	55	909	64.308909	64.331169000000003	56.055135999999997	56.048172999999998	0103000020E610000001000000050000002A1C412AC51350406DC669882A064C402A1C412AC5135040876A4AB20E074C40BD1C76DF31155040876A4AB20E074C40BD1C76DF311550406DC669882A064C402A1C412AC51350406DC669882A064C40
7255	Малышева	6	55	909	64.590073000000004	64.604095000000001	56.125700999999999	56.116627999999999	0103000020E610000001000000050000002B508BC1C325504021E692AAED0E4C402B508BC1C325504089096AF816104C40562B137EA926504089096AF816104C40562B137EA926504021E692AAED0E4C402B508BC1C325504021E692AAED0E4C40
8114	Майский	6	55	909	64.169939999999997	64.195982000000001	55.870863999999997	55.858635	0103000020E610000001000000050000001092054CE00A5040B9196EC0E7ED4B401092054CE00A5040C2A1B77878EF4B40B32616F88A0C5040C2A1B77878EF4B40B32616F88A0C5040B9196EC0E7ED4B401092054CE00A5040B9196EC0E7ED4B40
54967	Красный Октябрь	6	55	909	64.792697000000004	64.832205000000002	55.670976000000003	55.628946999999997	0103000020E61000000100000005000000CAA8328CBB3250406AF5D55581D04B40CAA8328CBB3250405133A48AE2D54B4055A4C2D8423550405133A48AE2D54B4055A4C2D8423550406AF5D55581D04B40CAA8328CBB3250406AF5D55581D04B40
14900	Ключи	6	55	909	64.439299000000005	64.457004999999995	55.928148	55.922550000000001	0103000020E61000000100000005000000988A8D791D1C504060764F1E16F64B40988A8D791D1C504085ECBC8DCDF64B40F146E6913F1D504085ECBC8DCDF64B40F146E6913F1D504060764F1E16F64B40988A8D791D1C504060764F1E16F64B40
54968	Каргаполье	6	55	909	64.401498000000004	64.463949	55.967838999999998	55.928471000000002	0103000020E6100000010000000500000034DAAA24B219504068244223D8F64B4034DAAA24B21950408C65FA25E2FB4B40C3802557B11D50408C65FA25E2FB4B40C3802557B11D504068244223D8F64B4034DAAA24B219504068244223D8F64B40
55053	Зауральская	6	55	909	64.091211000000001	64.107803000000004	55.780633000000002	55.773277	0103000020E610000001000000050000004582A966D6055040DFDFA0BDFAE24B404582A966D6055040D5963AC8EBE34B4049DA8D3EE6065040D5963AC8EBE34B4049DA8D3EE6065040DFDFA0BDFAE24B404582A966D6055040DFDFA0BDFAE24B40
7749	Журавлево	6	55	909	64.321197999999995	64.346027000000007	55.885452999999998	55.864120999999997	0103000020E6100000010000000500000099620E828E145040B66455849BEE4B4099620E828E14504092921E8656F14B401D226E4E2516504092921E8656F14B401D226E4E25165040B66455849BEE4B4099620E828E145040B66455849BEE4B40
7556	Житниковское	6	55	909	64.744870000000006	64.762792000000005	55.915557999999997	55.901223000000002	0103000020E61000000100000005000000617138F3AB2F504096B377465BF34B40617138F3AB2F5040ABCB290131F54B40A1698995D1305040ABCB290131F54B40A1698995D130504096B377465BF34B40617138F3AB2F504096B377465BF34B40
7615	Жикина	6	55	909	64.651292999999995	64.676490999999999	55.880031000000002	55.874738000000001	0103000020E6100000010000000500000047C7D5C8AE295040C3482F6AF7EF4B4047C7D5C8AE295040AC3B16DBA4F04B407442E8A04B2B5040AC3B16DBA4F04B407442E8A04B2B5040C3482F6AF7EF4B4047C7D5C8AE295040C3482F6AF7EF4B40
54966	Долговское	6	55	909	64.239333999999999	64.268224000000004	55.834997000000001	55.807501000000002	0103000020E6100000010000000500000089B48D3F510F5040603E59315CE74B4089B48D3F510F50400AA1832EE1EA4B402600FF942A1150400AA1832EE1EA4B402600FF942A115040603E59315CE74B4089B48D3F510F5040603E59315CE74B40
7175	Деулина	6	55	909	64.884388000000001	64.901222000000004	55.773969999999998	55.759323999999999	0103000020E61000000100000005000000643E20D099385040B188618731E14B40643E20D099385040E50AEF7211E34B40E31B0A9FAD395040E50AEF7211E34B40E31B0A9FAD395040B188618731E14B40643E20D099385040B188618731E14B40
55051	Дачный	6	55	909	64.375716999999995	64.383612999999997	55.902712000000001	55.897195000000004	0103000020E6100000010000000500000047E350BF0B1850403F912749D7F24B4047E350BF0B18504077DA1A118CF34B4082548A1D8D18504077DA1A118CF34B4082548A1D8D1850403F912749D7F24B4047E350BF0B1850403F912749D7F24B40
7331	Вяткино	6	55	909	64.499180999999993	64.513851000000003	55.985604000000002	55.974367999999998	0103000020E610000001000000050000003672DD94F21F50406C223317B8FC4B403672DD94F21F50404567994528FE4B4015014EEFE22050404567994528FE4B4015014EEFE22050406C223317B8FC4B403672DD94F21F50406C223317B8FC4B40
7409	Володина	6	55	909	64.49239	64.503214999999997	55.965727999999999	55.959907999999999	0103000020E6100000010000000500000028B85851831F50409A95ED43DEFA4B4028B85851831F50406E6AA0F99CFB4B40D3F6AFAC342050406E6AA0F99CFB4B40D3F6AFAC342050409A95ED43DEFA4B4028B85851831F50409A95ED43DEFA4B40
7318	Брылино	6	55	909	64.934782999999996	64.955983000000003	56.064942000000002	56.051557000000003	0103000020E61000000100000005000000D576137CD33B5040A070766B99064C40D576137CD33B50408411FB0450084C400C2252D32E3D50408411FB0450084C400C2252D32E3D5040A070766B99064C40D576137CD33B5040A070766B99064C40
7155	Большое Банниково	6	55	909	64.856881000000001	64.863646000000003	55.745528999999998	55.733736	0103000020E6100000010000000500000015E46723D7365040EDF2AD0FEBDD4B4015E46723D73650401B9C887E6DDF4B408F54DFF9453750401B9C887E6DDF4B408F54DFF945375040EDF2AD0FEBDD4B4015E46723D7365040EDF2AD0FEBDD4B40
7805	Бакланское	6	55	909	64.302790999999999	64.322851	55.845399999999998	55.834482000000001	0103000020E610000001000000050000007BA180ED60135040E38C614ED0EA4B407BA180ED60135040EA04341136EC4B40C79E3D97A9145040EA04341136EC4B40C79E3D97A9145040E38C614ED0EA4B407BA180ED60135040E38C614ED0EA4B40
7006	Украинец	6	55	839	64.800539000000001	64.816511000000006	54.401318000000003	54.389927	0103000020E610000001000000050000000B0BEE073C335040E869C020E9314B400B0BEE073C335040E8A562635E334B40C1745AB741345040E8A562635E334B40C1745AB741345040E869C020E9314B400B0BEE073C335040E869C020E9314B40
6947	Труд и Знание	6	55	839	64.732598999999993	64.746694000000005	54.47119	54.462429999999998	0103000020E610000001000000050000004485EAE6E22E50403A58FFE7303B4B404485EAE6E22E5040E31934F44F3C4B40A587A1D5C92F5040E31934F44F3C4B40A587A1D5C92F50403A58FFE7303B4B404485EAE6E22E50403A58FFE7303B4B40
6919	Северный	6	55	839	64.692633000000001	64.699918999999994	54.556471999999999	54.549089000000002	0103000020E6100000010000000500000058C85C19542C5040F3CB608C48464B4058C85C19542C5040E29178793A474B4056B60F79CB2C5040E29178793A474B4056B60F79CB2C5040F3CB608C48464B4058C85C19542C5040F3CB608C48464B40
6851	Редуть	6	55	839	64.922988000000004	64.940308000000002	54.660494999999997	54.654657	0103000020E610000001000000050000006EA6423C123B50407A8CF2CCCB534B406EA6423C123B5040F415A4198B544B40B30A9B012E3C5040F415A4198B544B40B30A9B012E3C50407A8CF2CCCB534B406EA6423C123B50407A8CF2CCCB534B40
54965	Прорывное	6	55	839	64.377809999999997	64.409934000000007	54.384517000000002	54.363737999999998	0103000020E610000001000000050000008386FE092E185040FE277FF78E2E4B408386FE092E185040C6E061DA37314B402FE1D05B3C1A5040C6E061DA37314B402FE1D05B3C1A5040FE277FF78E2E4B408386FE092E185040FE277FF78E2E4B40
6767	Отряд-Алабуга	6	55	839	65.079510999999997	65.088798999999995	54.449308000000002	54.442999999999998	0103000020E61000000100000005000000062B4EB51645504062105839B4384B40062B4EB51645504064EAAEEC82394B40B83A00E2AE45504064EAAEEC82394B40B83A00E2AE45504062105839B4384B40062B4EB51645504062105839B4384B40
6836	Озерное	6	55	839	64.632616999999996	64.649173000000005	54.409717999999998	54.400385	0103000020E61000000100000005000000317903CC7C2850408C67D0D03F334B40317903CC7C285040904AB1A371344B408F1CE90C8C295040904AB1A371344B408F1CE90C8C2950408C67D0D03F334B40317903CC7C2850408C67D0D03F334B40
6728	Лебедевка	6	55	839	64.821578000000002	64.833471000000003	54.562914999999997	54.558450999999998	0103000020E610000001000000050000003D47E4BB9434504091B586527B474B403D47E4BB94345040C3B645990D484B4086CABF9657355040C3B645990D484B4086CABF965735504091B586527B474B403D47E4BB9434504091B586527B474B40
6661	Круглое	6	55	839	64.887298000000001	64.905102999999997	54.505597000000002	54.495564000000002	0103000020E6100000010000000500000099F38C7DC9385040988922A46E3F4B4099F38C7DC938504055FA0967B7404B40BC202235ED39504055FA0967B7404B40BC202235ED395040988922A46E3F4B4099F38C7DC9385040988922A46E3F4B40
6569	Красногорка	6	55	839	65.130804999999995	65.145940999999993	54.532490000000003	54.526679999999999	0103000020E61000000100000005000000CF49EF1B5F48504088BA0F406A434B40CF49EF1B5F48504039B9DFA128444B405089EB185749504039B9DFA128444B405089EB185749504088BA0F406A434B40CF49EF1B5F48504088BA0F406A434B40
6634	Комсомольская	6	55	839	64.951186000000007	64.966196999999994	54.519359000000001	54.511352000000002	0103000020E61000000100000005000000709A3E3BE03C5040425F7AFB73414B40709A3E3BE03C50400FF10F5B7A424B40921FF12BD63D50400FF10F5B7A424B40921FF12BD63D5040425F7AFB73414B40709A3E3BE03C5040425F7AFB73414B40
7031	Искра	6	55	839	64.550079999999994	64.560410000000005	54.409261999999998	54.406227999999999	0103000020E61000000100000005000000C18BBE8234235040185C7347FF334B40C18BBE82342350406EBF7CB262344B407D96E7C1DD2350406EBF7CB262344B407D96E7C1DD235040185C7347FF334B40C18BBE8234235040185C7347FF334B40
6546	Зубаревка	6	55	839	65.178954000000004	65.196551999999997	54.360295999999998	54.354146999999998	0103000020E61000000100000005000000425F7AFB734B5040FE7C5BB0542D4B40425F7AFB734B50409770E82D1E2E4B40A8FDD64E944C50409770E82D1E2E4B40A8FDD64E944C5040FE7C5BB0542D4B40425F7AFB734B5040FE7C5BB0542D4B40
54911	Звериноголовское	6	55	839	64.837118000000004	64.872099000000006	54.482322000000003	54.447904999999999	0103000020E610000001000000050000002639605793355040815B77F354394B402639605793355040171230BABC3D4B40F5F75278D0375040171230BABC3D4B40F5F75278D0375040815B77F354394B402639605793355040815B77F354394B40
6320	Жаворонки	6	55	839	65.032618999999997	65.047387000000001	54.459184999999998	54.453009000000002	0103000020E610000001000000050000009B8E006E1642504097E5EB32FC394B409B8E006E1642504029E8F692C63A4B405BD07B630843504029E8F692C63A4B405BD07B630843504097E5EB32FC394B409B8E006E1642504097E5EB32FC394B40
6244	Верхняя Алабуга	6	55	839	64.926231000000001	64.946299999999994	54.571250999999997	54.559103999999998	0103000020E61000000100000005000000A662635E473B5040098849B890474B40A662635E473B50405567B5C01E494B401B0DE02D903C50405567B5C01E494B401B0DE02D903C5040098849B890474B40A662635E473B5040098849B890474B40
6200	Бугровое	6	55	839	64.839921000000004	64.856738000000007	54.626829000000001	54.615459999999999	0103000020E61000000100000005000000508E0244C135504082FFAD64C74E4B40508E0244C13550409A97C3EE3B504B4064CF9ECBD43650409A97C3EE3B504B4064CF9ECBD436504082FFAD64C74E4B40508E0244C135504082FFAD64C74E4B40
5892	Ясная Поляна	6	55	580	62.757140999999997	62.781908000000001	55.988041000000003	55.980432	0103000020E61000000100000005000000F9BA0CFFE9604F40D7F9B7CB7EFD4B40F9BA0CFFE9604F40B70DA32078FE4B408A3DB48F15644F40B70DA32078FE4B408A3DB48F15644F40D7F9B7CB7EFD4B40F9BA0CFFE9604F40D7F9B7CB7EFD4B40
4434	Язовка	6	55	580	63.62574	63.644263000000002	56.468035999999998	56.455920999999996	0103000020E6100000010000000500000047E6913F18D04F40A1478C9E5B3A4C4047E6913F18D04F40E2AC889AE83B4C40ED82C13577D24F40E2AC889AE83B4C40ED82C13577D24F40A1478C9E5B3A4C4047E6913F18D04F40A1478C9E5B3A4C40
5708	Юровка	6	55	580	62.956432	62.982232000000003	56.064394	56.050500999999997	0103000020E61000000100000005000000876C205D6C7A4F4028B517D176064C40876C205D6C7A4F40810706103E084C40D78A36C7B97D4F40810706103E084C40D78A36C7B97D4F4028B517D176064C40876C205D6C7A4F4028B517D176064C40
5161	Широковское	6	55	580	63.033974999999998	63.075485999999998	56.363843000000003	56.332490999999997	0103000020E61000000100000005000000D8F0F44A59844F406F9BA9108F2A4C40D8F0F44A59844F4074F04C68922E4C4026A77686A9894F4074F04C68922E4C4026A77686A9894F406F9BA9108F2A4C40D8F0F44A59844F406F9BA9108F2A4C40
4885	Уральцевское	6	55	580	63.104312999999998	63.126798000000001	56.432724	56.411580000000001	0103000020E6100000010000000500000019C6DD205A8D4F4006D847A7AE344C4019C6DD205A8D4F40DF18028063374C405F99B7EA3A904F40DF18028063374C405F99B7EA3A904F4006D847A7AE344C4019C6DD205A8D4F4006D847A7AE344C40
54935	Уксянское	6	55	580	62.977021999999998	63.047800000000002	55.958744000000003	55.935611999999999	0103000020E610000001000000050000007BBC900E0F7D4F4061DF4E22C2F74B407BBC900E0F7D4F403D9E961FB8FA4B40D95F764F1E864F403D9E961FB8FA4B40D95F764F1E864F4061DF4E22C2F74B407BBC900E0F7D4F4061DF4E22C2F74B40
4973	Тамакульское	6	55	580	63.038224	63.068632000000001	56.482573000000002	56.464728999999998	0103000020E610000001000000050000000EF62686E4844F405B40683D7C3B4C400EF62686E4844F406077BAF3C43D4C40C3BAF1EEC8884F406077BAF3C43D4C40C3BAF1EEC8884F405B40683D7C3B4C400EF62686E4844F405B40683D7C3B4C40
4802	Смирново	6	55	580	63.193739999999998	63.209181999999998	56.311461000000001	56.300620000000002	0103000020E61000000100000005000000A9F6E978CC984F40034356B77A264C40A9F6E978CC984F405F7D3CF4DD274C40B874CC79C69A4F405F7D3CF4DD274C40B874CC79C69A4F40034356B77A264C40A9F6E978CC984F40034356B77A264C40
52135	Сараткуль	6	55	580	63.462175000000002	63.470286999999999	56.547800000000002	56.535908999999997	0103000020E61000000100000005000000B003E78C28BB4F40E75086AA98444C40B003E78C28BB4F40D95F764F1E464C40F25D4A5D32BC4F40D95F764F1E464C40F25D4A5D32BC4F40E75086AA98444C40B003E78C28BB4F40E75086AA98444C40
54964	Песчано-Коледино	6	55	580	62.797583000000003	62.832248999999997	55.917501000000001	55.902186999999998	0103000020E610000001000000050000003C6C223317664F402CF015DD7AF34B403C6C223317664F400E863AAC70F54B4079909E22876A4F400E863AAC70F54B4079909E22876A4F402CF015DD7AF34B403C6C223317664F402CF015DD7AF34B40
5611	Пески	6	55	580	62.872664999999998	62.896991	56.119950000000003	56.104320999999999	0103000020E6100000010000000500000092AE997CB36F4F409CA4F9635A0D4C4092AE997CB36F4F40DE9387855A0F4C4036E7E099D0724F40DE9387855A0F4C4036E7E099D0724F409CA4F9635A0D4C4092AE997CB36F4F409CA4F9635A0D4C40
5585	Першинское	6	55	580	62.743316	62.76634	56.112302	56.098591999999996	0103000020E61000000100000005000000F94B8BFA245F4F40D8D2A3A99E0C4C40F94B8BFA245F4F4040A374E95F0E4C40EECEDA6D17624F4040A374E95F0E4C40EECEDA6D17624F40D8D2A3A99E0C4C40F94B8BFA245F4F40D8D2A3A99E0C4C40
4572	Параткуль	6	55	580	63.498745	63.515507999999997	56.512284999999999	56.497720000000001	0103000020E6100000010000000500000092054CE0D6BF4F405648F949B53F4C4092054CE0D6BF4F409D9D0C8E92414C40C669882AFCC14F409D9D0C8E92414C40C669882AFCC14F405648F949B53F4C4092054CE0D6BF4F405648F949B53F4C40
52153	Падерино	6	55	580	62.980651000000002	63.002040000000001	56.542470999999999	56.530408999999999	0103000020E6100000010000000500000015E5D2F8857D4F4085402E71E4434C4015E5D2F8857D4F40A30392B06F454C4055A4C2D842804F40A30392B06F454C4055A4C2D842804F4085402E71E4434C4015E5D2F8857D4F4085402E71E4434C40
5999	Павелево	6	55	580	63.192670999999997	63.217357	55.973778000000003	55.962663999999997	0103000020E610000001000000050000009DF17D71A9984F40AD84EE9238FB4B409DF17D71A9984F403BC8EBC1A4FC4B404147AB5AD29B4F403BC8EBC1A4FC4B404147AB5AD29B4F40AD84EE9238FB4B409DF17D71A9984F40AD84EE9238FB4B40
4954	Новосельское	6	55	580	63.22307	63.244540000000001	56.52825	56.517341000000002	0103000020E61000000100000005000000FF5BC98E8D9C4F40A2F0D93A38424C40FF5BC98E8D9C4F40560E2DB29D434C402C4833164D9F4F40560E2DB29D434C402C4833164D9F4F40A2F0D93A38424C40FF5BC98E8D9C4F40A2F0D93A38424C40
54959	Новопетропавловское	6	55	580	62.959487000000003	63.008848999999998	55.893065999999997	55.864874	0103000020E61000000100000005000000F5F75278D07A4F409294F430B4EE4B40F5F75278D07A4F40B39597FC4FF24B4018CDCAF621814F40B39597FC4FF24B4018CDCAF621814F409294F430B4EE4B40F5F75278D07A4F409294F430B4EE4B40
4813	Нижний Яр	6	55	580	63.078423999999998	63.109433000000003	56.205981000000001	56.193116000000003	0103000020E610000001000000050000005A9C31CC098A4F40CC2A6C06B8184C405A9C31CC098A4F40774CDD955D1A4C40350D8AE6018E4F40774CDD955D1A4C40350D8AE6018E4F40CC2A6C06B8184C405A9C31CC098A4F40CC2A6C06B8184C40
5074	Мясниково	6	55	580	62.997261000000002	63.027012999999997	56.411292000000003	56.379511000000001	0103000020E61000000100000005000000C3499A3FA67F4F4073BC02D193304C40C3499A3FA67F4F40A08D5C37A5344C408EC8772975834F40A08D5C37A5344C408EC8772975834F4073BC02D193304C40C3499A3FA67F4F4073BC02D193304C40
5701	Макарьевское	6	55	580	62.966925000000003	62.981639000000001	56.089156000000003	56.076644000000002	0103000020E61000000100000005000000A857CA32C47B4F40A2B77878CF094C40A857CA32C47B4F40001FBC76690B4C4034BDC458A67D4F40001FBC76690B4C4034BDC458A67D4F40A2B77878CF094C40A857CA32C47B4F40A2B77878CF094C40
54977	Любимово	6	55	580	63.047215999999999	63.075063999999998	55.953301000000003	55.933892	0103000020E6100000010000000500000089EC832C0B864F407EFFE6C589F74B4089EC832C0B864F403F1F65C405FA4B40B08D78B29B894F403F1F65C405FA4B40B08D78B29B894F407EFFE6C589F74B4089EC832C0B864F407EFFE6C589F74B40
6118	Лебяжье	6	55	580	63.070023999999997	63.094521	55.779260999999998	55.766824999999997	0103000020E61000000100000005000000B1F7E28BF6884F40AA60545227E24B40B1F7E28BF6884F402D060FD3BEE34B4082E49D43198C4F402D060FD3BEE34B4082E49D43198C4F40AA60545227E24B40B1F7E28BF6884F40AA60545227E24B40
5415	Крутиха	6	55	580	63.132358000000004	63.172414000000003	56.176673999999998	56.156390000000002	0103000020E6100000010000000500000097AE601BF1904F40F2B5679604144C4097AE601BF1904F40D906EE409D164C40B0AF75A911964F40D906EE409D164C40B0AF75A911964F40F2B5679604144C4097AE601BF1904F40F2B5679604144C40
4665	Кривское	6	55	580	63.348438999999999	63.382387000000001	56.359059999999999	56.341597999999998	0103000020E6100000010000000500000052D32EA699AC4F408330B77BB92B4C4052D32EA699AC4F40A0A696ADF52D4C4031B5A50EF2B04F40A0A696ADF52D4C4031B5A50EF2B04F408330B77BB92B4C4052D32EA699AC4F408330B77BB92B4C40
5172	Крестовка	6	55	580	62.828899	62.857509999999998	56.379984	56.365003999999999	0103000020E61000000100000005000000F357C85C196A4F4060747973B82E4C40F357C85C196A4F406B80D250A3304C4019FF3EE3C26D4F406B80D250A3304C4019FF3EE3C26D4F4060747973B82E4C40F357C85C196A4F4060747973B82E4C40
5331	Красноисетское	6	55	580	62.981172000000001	63.007644999999997	56.217005	56.203758000000001	0103000020E610000001000000050000001EE0490B977D4F403126FDBD141A4C401EE0490B977D4F40C408E1D1C61B4C402C7DE882FA804F40C408E1D1C61B4C402C7DE882FA804F403126FDBD141A4C401EE0490B977D4F403126FDBD141A4C40
5500	Ключевское	6	55	580	62.77129	62.797269	56.191664000000003	56.167338000000001	0103000020E61000000100000005000000ADDD76A1B9624F4064B0E2546B154C40ADDD76A1B9624F4008E9297288184C40AC8E1CE90C664F4008E9297288184C40AC8E1CE90C664F4064B0E2546B154C40ADDD76A1B9624F4064B0E2546B154C40
5317	Затеченское	6	55	580	62.905524999999997	62.946793999999997	56.234234999999998	56.220993999999997	0103000020E61000000100000005000000EE5A423EE8734F405D4E0988491C4C40EE5A423EE8734F400E4A9869FB1D4C404606B98B30794F400E4A9869FB1D4C404606B98B30794F405D4E0988491C4C40EE5A423EE8734F405D4E0988491C4C40
52170	Загайнова	6	55	580	63.224975000000001	63.240507000000001	56.145384	56.138176999999999	0103000020E6100000010000000500000074B515FBCB9C4F409A07B0C8AF114C4074B515FBCB9C4F404BAE62F19B124C40C3BAF1EEC89E4F404BAE62F19B124C40C3BAF1EEC89E4F409A07B0C8AF114C4074B515FBCB9C4F409A07B0C8AF114C40
4407	Вознесенское	6	55	580	63.558267999999998	63.584192999999999	56.498192000000003	56.492427999999997	0103000020E61000000100000005000000A033695375C74F403DD175E1073F4C40A033695375C74F407E9065C1C43F4C40ACC612D6C6CA4F407E9065C1C43F4C40ACC612D6C6CA4F403DD175E1073F4C40A033695375C74F403DD175E1073F4C40
5248	Верхний Яр	6	55	580	62.784269999999999	62.814813000000001	56.271076000000001	56.262076999999998	0103000020E61000000100000005000000F19D98F562644F40530438BD8B214C40F19D98F562644F40815D4D9EB2224C4086ADD9CA4B684F40815D4D9EB2224C4086ADD9CA4B684F40530438BD8B214C40F19D98F562644F40530438BD8B214C40
4227	Верхний Суварыш	6	55	580	63.042662	63.062100999999998	56.275089000000001	56.268366	0103000020E610000001000000050000001764CBF275854F40DEAD2CD159224C401764CBF275854F40A33EC91D36234C404206F2ECF2874F40A33EC91D36234C404206F2ECF2874F40DEAD2CD159224C401764CBF275854F40DEAD2CD159224C40
52128	Беляковка	6	55	580	63.530034000000001	63.549391999999997	56.566392999999998	56.557915999999999	0103000020E6100000010000000500000050E27327D8C34F4023F59ECA69474C4050E27327D8C34F4077D7D9907F484C408E57207A52C64F4077D7D9907F484C408E57207A52C64F4023F59ECA69474C4050E27327D8C34F4023F59ECA69474C40
5936	Белоярка 1-я	6	55	580	63.215389999999999	63.245223000000003	55.984918999999998	55.973379999999999	0103000020E6100000010000000500000056F146E6919B4F404D4A41B797FC4B4056F146E6919B4F40C11A67D311FE4B400F9D9E77639F4F40C11A67D311FE4B400F9D9E77639F4F404D4A41B797FC4B4056F146E6919B4F404D4A41B797FC4B40
52141	Белое	6	55	580	63.454709999999999	63.470053	56.434317	56.420006000000001	0103000020E610000001000000050000000395F1EF33BA4F40D80FB1C1C2354C400395F1EF33BA4F40658C0FB397374C407F315BB22ABC4F40658C0FB397374C407F315BB22ABC4F40D80FB1C1C2354C400395F1EF33BA4F40D80FB1C1C2354C40
3440	Яблочное	6	55	229	66.156177999999997	66.180413999999999	55.766658	55.755828999999999	0103000020E61000000100000005000000B39602D2FE895040272F3201BFE04B40B39602D2FE895040BF9B6ED921E24B40656F29E78B8B5040BF9B6ED921E24B40656F29E78B8B5040272F3201BFE04B40B39602D2FE895040272F3201BFE04B40
2277	Юрахлы	6	55	229	66.113057999999995	66.131088000000005	55.327941000000003	55.322757000000003	0103000020E6100000010000000500000046239F573C8750400DC7F31950A94B4046239F573C8750403F027FF8F9A94B407A39ECBE638850403F027FF8F9A94B407A39ECBE638850400DC7F31950A94B4046239F573C8750400DC7F31950A94B40
3623	Шмаково	6	55	229	65.923603999999997	65.939278999999999	55.931345999999998	55.920053000000003	0103000020E610000001000000050000001B9DF3531C7B504019CBF44BC4F54B401B9DF3531C7B504055A1815836F74B4074B4AA251D7C504055A1815836F74B4074B4AA251D7C504019CBF44BC4F54B401B9DF3531C7B504019CBF44BC4F54B40
3526	Шастово	6	55	229	66.013310000000004	66.036702000000005	55.946173999999999	55.932067000000004	0103000020E610000001000000050000006DAD2F12DA8050402657B1F84DF74B406DAD2F12DA805040AA29C93A1CF94B40A96C585359825040AA29C93A1CF94B40A96C5853598250402657B1F84DF74B406DAD2F12DA8050402657B1F84DF74B40
3518	Урал	6	55	229	66.168727000000004	66.187141999999994	55.830638999999998	55.823732	0103000020E61000000100000005000000F1BC546CCC8A50409755D80C70E94B40F1BC546CCC8A50401DE4F56052EA4B40506D7022FA8B50401DE4F56052EA4B40506D7022FA8B50409755D80C70E94B40F1BC546CCC8A50409755D80C70E94B40
3412	Терпугово	6	55	229	66.264657999999997	66.285004999999998	55.928561999999999	55.914534000000003	0103000020E61000000100000005000000FCA71B28F0905040408A3A730FF54B40FCA71B28F090504078279F1EDBF64B40938C9C853D92504078279F1EDBF64B40938C9C853D925040408A3A730FF54B40FCA71B28F0905040408A3A730FF54B40
3322	Сычево	6	55	229	65.645773000000005	65.657270999999994	55.409564000000003	55.401778999999998	0103000020E61000000100000005000000F3E84658546950401B9C887E6DB34B40F3E84658546950403ACFD8976CB44B40FD6662BA106A50403ACFD8976CB44B40FD6662BA106A50401B9C887E6DB34B40F3E84658546950401B9C887E6DB34B40
3208	Строево	6	55	229	65.880943000000002	65.892306000000005	55.173771000000002	55.159990000000001	0103000020E61000000100000005000000F8A8BF5E61785040F1D7648D7A944B40F8A8BF5E6178504022FFCC203E964B409301A08A1B79504022FFCC203E964B409301A08A1B795040F1D7648D7A944B40F8A8BF5E61785040F1D7648D7A944B40
3193	Спорное	6	55	229	65.803526000000005	65.818357000000006	55.148266	55.136122999999998	0103000020E6100000010000000500000016DF50F86C735040E09D7C7A6C914B4016DF50F86C735040EB8D5A61FA924B40F9DC09F65F745040EB8D5A61FA924B40F9DC09F65F745040E09D7C7A6C914B4016DF50F86C735040E09D7C7A6C914B40
3063	Попово	6	55	229	66.058216000000002	66.072310999999999	55.422497999999997	55.409953000000002	0103000020E61000000100000005000000A7069ACFB9835040D4F2035779B44B40A7069ACFB98350400D501A6A14B64B40070951BEA08450400D501A6A14B64B40070951BEA0845040D4F2035779B44B40A7069ACFB9835040D4F2035779B44B40
2946	Пичугино	6	55	229	65.798962000000003	65.819740999999993	55.446314999999998	55.435502999999997	0103000020E61000000100000005000000CB2F833122735040AA27F38FBEB74B40CB2F8331227350406C5B94D920B94B402E8CF4A2767450406C5B94D920B94B402E8CF4A276745040AA27F38FBEB74B40CB2F833122735040AA27F38FBEB74B40
2853	Ошурково	6	55	229	66.161396999999994	66.182310000000001	55.969003000000001	55.958889999999997	0103000020E610000001000000050000000A2B1554548A5040103B53E8BCFA4B400A2B1554548A5040EA5C514A08FC4B40F6EE8FF7AA8B5040EA5C514A08FC4B40F6EE8FF7AA8B5040103B53E8BCFA4B400A2B1554548A5040103B53E8BCFA4B40
54995	Мостовское	6	55	229	66.116866999999999	66.153249000000002	55.749319	55.720762999999998	0103000020E61000000100000005000000D3BEB9BF7A8750405B9544F641DC4B40D3BEB9BF7A875040BEA25BAFE9DF4B4043C9E4D4CE895040BEA25BAFE9DF4B4043C9E4D4CE8950405B9544F641DC4B40D3BEB9BF7A8750405B9544F641DC4B40
2620	Медвежье	6	55	229	65.957892000000001	65.972211999999999	55.294832	55.284855999999998	0103000020E6100000010000000500000067463F1A4E7D5040E108522976A44B4067463F1A4E7D50403AE8120EBDA54B40D731AEB8387E50403AE8120EBDA54B40D731AEB8387E5040E108522976A44B4067463F1A4E7D5040E108522976A44B40
2600	Лихачи	6	55	229	65.986513000000002	66.004739999999998	55.515782999999999	55.498485000000002	0103000020E610000001000000050000000C056C07237F5040F645425BCEBF4B400C056C07237F5040986A662D05C24B40EA3E00A94D805040986A662D05C24B40EA3E00A94D805040F645425BCEBF4B400C056C07237F5040F645425BCEBF4B40
2968	Кабанье	6	55	229	65.868590999999995	65.881302000000005	55.398420999999999	55.386952000000001	0103000020E6100000010000000500000065A6B4FE96775040978FA4A487B14B4065A6B4FE9677504012859675FFB24B4090F980406778504012859675FFB24B4090F9804067785040978FA4A487B14B4065A6B4FE96775040978FA4A487B14B40
2839	Заложное	6	55	229	66.074853000000004	66.097446000000005	55.696061999999998	55.683239	0103000020E610000001000000050000007BC03C64CA845040062D246074D74B407BC03C64CA84504082FE428F18D94B4011C8258E3C86504082FE428F18D94B4011C8258E3C865040062D246074D74B407BC03C64CA845040062D246074D74B40
2510	Дундино	6	55	229	65.966821999999993	65.998639999999995	55.082106000000003	55.071288000000003	0103000020E6100000010000000500000069C36169E07D5040734C16F71F894B4069C36169E07D504017670C73828A4B408E1EBFB7E97F504017670C73828A4B408E1EBFB7E97F5040734C16F71F894B4069C36169E07D5040734C16F71F894B40
2492	Дубровное	6	55	229	65.854595000000003	65.878877000000003	55.264265000000002	55.250644000000001	0103000020E61000000100000005000000CF143AAFB17650402578431A15A04B40CF143AAFB17650401D3D7E6FD3A14B40390D51853F7850401D3D7E6FD3A14B40390D51853F7850402578431A15A04B40CF143AAFB17650402578431A15A04B40
2403	Верхнесуерское	6	55	229	66.281312999999997	66.310633999999993	55.908323000000003	55.891506999999997	0103000020E6100000010000000500000023BC3D0801925040D993C0E61CF24B4023BC3D0801925040319A95ED43F44B40A4C16D6DE1935040319A95ED43F44B40A4C16D6DE1935040D993C0E61CF24B4023BC3D0801925040D993C0E61CF24B40
54958	Варгаши	6	55	229	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
32139	Варгаши	6	55	229	65.828615999999997	65.850022999999993	55.360765999999998	55.345728999999999	0103000020E610000001000000050000004F3C670B08755040AF230ED940AC4B404F3C670B087550401EC18D942DAE4B404276DEC6667650401EC18D942DAE4B404276DEC666765040AF230ED940AC4B404F3C670B08755040AF230ED940AC4B40
1797	Варгаши	6	55	229	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
3072	Большое Просеково	6	55	229	66.190134	66.217416	55.941122999999997	55.932738000000001	0103000020E61000000100000005000000E4F6CB272B8C504044DE72F563F74B40E4F6CB272B8C5040B741EDB776F84B402368CC24EA8D5040B741EDB776F84B402368CC24EA8D504044DE72F563F74B40E4F6CB272B8C504044DE72F563F74B40
890	Белово	6	55	229	66.321736999999999	66.331906000000004	55.887281000000002	55.881630999999999	0103000020E61000000100000005000000713AC95697945040E411DC48D9F04B40713AC956979450405CAE7E6C92F14B4028D6A9F23D9550405CAE7E6C92F14B4028D6A9F23D955040E411DC48D9F04B40713AC95697945040E411DC48D9F04B40
31606	Барашково	6	55	229	65.767054000000002	65.780296000000007	55.499611000000002	55.488227999999999	0103000020E610000001000000050000000611A96917715040E97E4E417EBE4B400611A9691771504066DCD440F3BF4B40C74CA25EF071504066DCD440F3BF4B40C74CA25EF0715040E97E4E417EBE4B400611A96917715040E97E4E417EBE4B40
1698	Ягодная	6	55	92	65.073672000000002	65.103622000000001	56.09928	56.084777000000003	0103000020E6100000010000000500000061A8C30AB7445040FC3905F9D90A4C4061A8C30AB7445040CD920035B50C4C405A492BBEA1465040CD920035B50C4C405A492BBEA1465040FC3905F9D90A4C4061A8C30AB7445040FC3905F9D90A4C40
1493	Юрково	6	55	92	65.315174999999996	65.323627999999999	55.857129	55.851475000000001	0103000020E610000001000000050000001361C3D32B545040492EFF21FDEC4B401361C3D32B54504002BA2F67B6ED4B4079043752B654504002BA2F67B6ED4B4079043752B6545040492EFF21FDEC4B401361C3D32B545040492EFF21FDEC4B40
1684	Чимеево	6	55	92	65.129249999999999	65.144351	56.100113	56.087282999999999	0103000020E6100000010000000500000083C0CAA145485040963FDF162C0B4C4083C0CAA145485040C573B680D00C4C404609FA0B3D495040C573B680D00C4C404609FA0B3D495040963FDF162C0B4C4083C0CAA145485040963FDF162C0B4C40
55015	Усть-Суерское	6	55	92	65.802520000000001	65.812517999999997	56.043647999999997	56.033484999999999	0103000020E61000000100000005000000B398D87C5C7350400AF4893C49044C40B398D87C5C7350409544F64196054C40535A7F4B007450409544F64196054C40535A7F4B007450400AF4893C49044C40B398D87C5C7350400AF4893C49044C40
769	Тюменцева	6	55	92	65.404511999999997	65.431066000000001	56.103442000000001	56.092767000000002	0103000020E61000000100000005000000BBB54C86E3595040F392FFC9DF0B4C40BBB54C86E3595040348463963D0D4C40B91AD995965B5040348463963D0D4C40B91AD995965B5040F392FFC9DF0B4C40BBB54C86E3595040F392FFC9DF0B4C40
616	Стенниково	6	55	92	65.562264999999996	65.572506000000004	56.041803000000002	56.033766	0103000020E61000000100000005000000DEAB5626FC635040BEDBBC7152044C40DEAB5626FC635040F6EFFACC59054C40E2B034F0A3645040F6EFFACC59054C40E2B034F0A3645040BEDBBC7152044C40DEAB5626FC635040BEDBBC7152044C40
31965	Стеклозавод	6	55	92	65.483654000000001	65.510351999999997	56.227519999999998	56.216684000000001	0103000020E610000001000000050000001825E82FF45E504082C8224DBC1B4C401825E82FF45E5040CC9717601F1D4C40AF5C6F9BA9605040CC9717601F1D4C40AF5C6F9BA960504082C8224DBC1B4C401825E82FF45E504082C8224DBC1B4C40
1612	Скопино	6	55	92	65.407252	65.42971	55.870778999999999	55.861170999999999	0103000020E61000000100000005000000C24EB16A105A5040BEA1F0D93AEE4B40C24EB16A105A50409485AFAF75EF4B40E8305F5E805B50409485AFAF75EF4B40E8305F5E805B5040BEA1F0D93AEE4B40C24EB16A105A5040BEA1F0D93AEE4B40
1552	Скаты	6	55	92	65.295743999999999	65.318184000000002	55.721812	55.710154000000003	0103000020E610000001000000050000003FFF3D78ED525040D28F8653E6DA4B403FFF3D78ED52504020EEEA5564DC4B4012876C205D54504020EEEA5564DC4B4012876C205D545040D28F8653E6DA4B403FFF3D78ED525040D28F8653E6DA4B40
1425	Светлый Дол	6	55	92	65.351736000000002	65.380482000000001	55.810172000000001	55.799441000000002	0103000020E61000000100000005000000DB34B6D782565040700A2B1554E64B40DB34B6D782565040451152B7B3E74B40DEAD2CD159585040451152B7B3E74B40DEAD2CD159585040700A2B1554E64B40DB34B6D782565040700A2B1554E64B40
1233	Рычково	6	55	92	65.492654999999999	65.508277000000007	55.649901	55.642083	0103000020E610000001000000050000007F4DD6A8875F5040A62897C62FD24B407F4DD6A8875F5040A051BAF42FD34B40C713419C87605040A051BAF42FD34B40C713419C87605040A62897C62FD24B407F4DD6A8875F5040A62897C62FD24B40
390	Романовское	6	55	92	65.845405	65.854918999999995	55.933881999999997	55.923917000000003	0103000020E61000000100000005000000FEB7921D1B765040F69B89E942F64B40FEB7921D1B7650405A29047289F74B40A86E2EFEB67650405A29047289F74B40A86E2EFEB6765040F69B89E942F64B40FEB7921D1B765040F69B89E942F64B40
1087	Речкино	6	55	92	65.650227999999998	65.657110000000003	55.965400000000002	55.956637999999998	0103000020E6100000010000000500000062BCE6559D695040300E2E1D73FA4B4062BCE6559D6950407AC7293A92FB4B40F9F719170E6A50407AC7293A92FB4B40F9F719170E6A5040300E2E1D73FA4B4062BCE6559D695040300E2E1D73FA4B40
1154	Редькино	6	55	92	65.471750999999998	65.485927000000004	55.623010000000001	55.611704000000003	0103000020E61000000100000005000000BD361B2B315E50408C6A11514CCE4B40BD361B2B315E50405D8AABCABECF4B40944F8F6D195F50405D8AABCABECF4B40944F8F6D195F50408C6A11514CCE4B40BD361B2B315E50408C6A11514CCE4B40
979	Пьянково	6	55	92	65.069243	65.093372000000002	55.857619	55.844253000000002	0103000020E61000000100000005000000861E317A6E4450406346787B10EC4B40861E317A6E445040D0B69A75C6ED4B402D978DCEF9455040D0B69A75C6ED4B402D978DCEF94550406346787B10EC4B40861E317A6E4450406346787B10EC4B40
123	Полевое	6	55	92	65.387292000000002	65.403981999999999	55.809089999999998	55.801682999999997	0103000020E6100000010000000500000028806264C95850402C616D8C9DE64B4028806264C9585040A4C2D84290E74B400D8B51D7DA595040A4C2D84290E74B400D8B51D7DA5950402C616D8C9DE64B4028806264C95850402C616D8C9DE64B40
32215	Подборная	6	55	92	65.591505999999995	65.609893999999997	56.122504999999997	56.116543	0103000020E61000000100000005000000D158FB3BDB655040F3C98AE1EA0E4C40D158FB3BDB655040594C6C3EAE0F4C40B401D88008675040594C6C3EAE0F4C40B401D88008675040F3C98AE1EA0E4C40D158FB3BDB655040F3C98AE1EA0E4C40
376	Петуховское	6	55	92	65.786826000000005	65.794848000000002	55.932682	55.927135	0103000020E610000001000000050000001F69705B5B7250400DFD135CACF64B401F69705B5B725040B0C8AF1F62F74B40A05225CADE725040B0C8AF1F62F74B40A05225CADE7250400DFD135CACF64B401F69705B5B7250400DFD135CACF64B40
752	Першино	6	55	92	65.378343999999998	65.406704000000005	56.092174999999997	56.080181000000003	0103000020E61000000100000005000000D2A8C0C9365850405B61FA5E430A4C40D2A8C0C9365850402041F163CC0B4C40C1C93670075A50402041F163CC0B4C40C1C93670075A50405B61FA5E430A4C40D2A8C0C9365850405B61FA5E430A4C40
560	Памятное	6	55	92	65.682658000000004	65.706390999999996	56.016354999999997	56.002304000000002	0103000020E6100000010000000500000094162EABB06B504033535A7F4B004C4094162EABB06B50402310AFEB17024C4014CC9882356D50402310AFEB17024C4014CC9882356D504033535A7F4B004C4094162EABB06B504033535A7F4B004C40
1387	Орловка	6	55	92	65.375416000000001	65.389492000000004	55.912849000000001	55.906401000000002	0103000020E610000001000000050000004A99D4D006585040E607AEF204F44B404A99D4D006585040D9976C3CD8F44B406F83DA6FED585040D9976C3CD8F44B406F83DA6FED585040E607AEF204F44B404A99D4D006585040E607AEF204F44B40
286	Новодостовалово	6	55	92	65.815158999999994	65.831410000000005	55.922671000000001	55.917526000000002	0103000020E610000001000000050000009082A7902B745040679DF17D71F54B409082A7902B745040DBFB54151AF64B4050E449D235755040DBFB54151AF64B4050E449D235755040679DF17D71F54B409082A7902B745040679DF17D71F54B40
109	Нижнетобольное	6	55	92	65.604675	65.618778000000006	55.778162999999999	55.766648000000004	0103000020E610000001000000050000005D6DC5FEB26650409CC58B8521E24B405D6DC5FEB266504087FA5DD89AE34B40FF5E0A0F9A67504087FA5DD89AE34B40FF5E0A0F9A6750409CC58B8521E24B405D6DC5FEB26650409CC58B8521E24B40
32163	Мясникова	6	55	92	65.743230999999994	65.753255999999993	56.117987999999997	56.109324999999998	0103000020E61000000100000005000000E597C118916F50404ED1915CFE0D4C40E597C118916F504004A9143B1A0F4C400261A7583570504004A9143B1A0F4C400261A758357050404ED1915CFE0D4C40E597C118916F50404ED1915CFE0D4C40
1340	Мендерское	6	55	92	65.280572000000006	65.303550999999999	55.814720000000001	55.808836999999997	0103000020E61000000100000005000000180B43E4F4515040BA6587F887E74B40180B43E4F4515040D5B2B5BE48E84B40C26A2C616D535040D5B2B5BE48E84B40C26A2C616D535040BA6587F887E74B40180B43E4F4515040BA6587F887E74B40
32082	Масляная	6	55	92	65.708259999999996	65.720772999999994	55.812666	55.809479000000003	0103000020E610000001000000050000002844C021546D50403FE603029DE74B402844C021546D50401B49827005E84B40BFB51325216E50401B49827005E84B40BFB51325216E50403FE603029DE74B402844C021546D50403FE603029DE74B40
879	Малый Камаган	6	55	92	65.120986000000002	65.136015	55.859417999999998	55.848866999999998	0103000020E610000001000000050000008751103CBE475040AAD381ACA7EC4B408751103CBE475040FFCBB56801EE4B40FD304278B4485040FFCBB56801EE4B40FD304278B4485040AAD381ACA7EC4B408751103CBE475040AAD381ACA7EC4B40
32474	Малый Заполой	6	55	92	65.541954000000004	65.550146999999996	55.717497000000002	55.710078000000003	0103000020E61000000100000005000000EE7BD45FAF625040F7CDFDD5E3DA4B40EE7BD45FAF62504033FD12F1D6DB4B40853FC39B3563504033FD12F1D6DB4B40853FC39B35635040F7CDFDD5E3DA4B40EE7BD45FAF625040F7CDFDD5E3DA4B40
61046	Лихачи	6	55	92	65.619343999999998	65.624429000000006	55.671675999999998	55.665025	0103000020E61000000100000005000000533E0455A3675040DE02098A1FD54B40533E0455A367504009C1AA7AF9D54B40236B0DA5F667504009C1AA7AF9D54B40236B0DA5F6675040DE02098A1FD54B40533E0455A3675040DE02098A1FD54B40
31882	Куликово	6	55	92	65.618195	65.634409000000005	55.901344000000002	55.888907000000003	0103000020E610000001000000050000003FE3C28190675040BE175FB4C7F14B403FE3C2819067504011397D3D5FF34B4070D234289A68504011397D3D5FF34B4070D234289A685040BE175FB4C7F14B403FE3C28190675040BE175FB4C7F14B40
31805	Корюкина	6	55	92	65.569614000000001	65.591497000000004	55.81259	55.802199000000002	0103000020E610000001000000050000000056478E7464504024F1F274AEE64B400056478E746450404087F9F202E84B40A8AB3B16DB6550404087F9F202E84B40A8AB3B16DB65504024F1F274AEE64B400056478E7464504024F1F274AEE64B40
1258	Кирово	6	55	92	65.329628999999997	65.338800000000006	55.763396999999998	55.754916999999999	0103000020E610000001000000050000000BB43BA418555040E318C91EA1E04B400BB43BA418555040A86E2EFEB6E14B40A1F831E6AE555040A86E2EFEB6E14B40A1F831E6AE555040E318C91EA1E04B400BB43BA418555040E318C91EA1E04B40
32307	Зюзино	6	55	92	65.699563999999995	65.717457999999993	55.713456000000001	55.707678999999999	0103000020E610000001000000050000005F5D15A8C56C50407288B83995DA4B405F5D15A8C56C50404791B58652DB4B403A90F5D4EA6D50404791B58652DB4B403A90F5D4EA6D50407288B83995DA4B405F5D15A8C56C50407288B83995DA4B40
1041	Екимово	6	55	92	65.678776999999997	65.688056000000003	55.996540000000003	55.989849	0103000020E61000000100000005000000BA111615716B5040397D3D5FB3FE4B40BA111615716B5040F3936A9F8EFF4B404374081C096C5040F3936A9F8EFF4B404374081C096C5040397D3D5FB3FE4B40BA111615716B5040397D3D5FB3FE4B40
55005	Доможирова	6	55	92	65.466881999999998	65.496094999999997	55.915416999999998	55.909469000000001	0103000020E61000000100000005000000D4450A65E15D5040E8DCED7A69F44B40D4450A65E15D5040E9995E622CF54B40622D3E05C05F5040E9995E622CF54B40622D3E05C05F5040E8DCED7A69F44B40D4450A65E15D5040E8DCED7A69F44B40
509	Волосникова	6	55	92	65.728148000000004	65.742979000000005	56.028700999999998	56.022348000000001	0103000020E6100000010000000500000076A911FA996E5040C5909C4CDC024C4076A911FA996E5040662E7079AC034C4059A7CAF78C6F5040662E7079AC034C4059A7CAF78C6F5040C5909C4CDC024C4076A911FA996E5040C5909C4CDC024C40
32054	Боровское	6	55	92	65.734229999999997	65.763749000000004	55.806246000000002	55.794350000000001	0103000020E610000001000000050000007E6FD39FFD6E5040EFC9C342ADE54B407E6FD39FFD6E5040F243A51133E74B4093567C43E1705040F243A51133E74B4093567C43E1705040EFC9C342ADE54B407E6FD39FFD6E5040EFC9C342ADE54B40
31904	Боровлянка	6	55	92	65.453092999999996	65.483528000000007	56.248815999999998	56.236581000000001	0103000020E61000000100000005000000FA42C879FF5C504070ED4449481E4C40FA42C879FF5C50405B5CE333D91F4C40D2AC6C1FF25E50405B5CE333D91F4C40D2AC6C1FF25E504070ED4449481E4C40FA42C879FF5C504070ED4449481E4C40
32393	Большой Камаган	6	55	92	65.070537000000002	65.105050000000006	55.925863999999997	55.905476999999998	0103000020E610000001000000050000001C0A9FAD83445040DD239BABE6F34B401C0A9FAD83445040994528B682F64B40789CA223B9465040994528B682F64B40789CA223B9465040DD239BABE6F34B401C0A9FAD83445040DD239BABE6F34B40
32253	Большое Зарослое	6	55	92	65.260405000000006	65.266818000000001	55.901082000000002	55.891173000000002	0103000020E61000000100000005000000C1ADBB79AA505040030AF5F411F24B40C1ADBB79AA505040D481ACA756F34B40FCFECD8B13515040D481ACA756F34B40FCFECD8B13515040030AF5F411F24B40C1ADBB79AA505040030AF5F411F24B40
31991	Березовский	6	55	92	65.926154999999994	65.942144999999996	55.794106999999997	55.78604	0103000020E61000000100000005000000B8019F1F467B504086AC6EF59CE44B40B8019F1F467B50402843554CA5E54B40C1C58A1A4C7C50402843554CA5E54B40C1C58A1A4C7C504086AC6EF59CE44B40B8019F1F467B504086AC6EF59CE44B40
31564	Березово	6	55	92	65.466639999999998	65.482567000000003	56.034922999999999	56.025658	0103000020E6100000010000000500000059C0046EDD5D5040BD70E7C248034C4059C0046EDD5D504069705B5B78044C403FC8B260E25E504069705B5B78044C403FC8B260E25E5040BD70E7C248034C4059C0046EDD5D5040BD70E7C248034C40
54912	Белозерское	6	55	92	65.536663000000004	65.612194000000002	55.840299999999999	55.815199999999997	0103000020E610000001000000050000004A7EC4AF586250407FD93D7958E84B404A7EC4AF58625040166A4DF38EEB4B40AD33BE2F2E675040166A4DF38EEB4B40AD33BE2F2E6750407FD93D7958E84B404A7EC4AF586250407FD93D7958E84B40
54934	Белозерское	6	55	92	65.536663000000004	65.612194000000002	55.840299999999999	55.815199999999997	0103000020E610000001000000050000004A7EC4AF586250407FD93D7958E84B404A7EC4AF58625040166A4DF38EEB4B40AD33BE2F2E675040166A4DF38EEB4B40AD33BE2F2E6750407FD93D7958E84B404A7EC4AF586250407FD93D7958E84B40
31477	Баярак	6	55	92	65.407197999999994	65.425802000000004	55.959293000000002	55.950791000000002	0103000020E61000000100000005000000C83F33880F5A5040632AFD84B3F94B40C83F33880F5A50401024EF1CCAFA4B4092240857405B50401024EF1CCAFA4B4092240857405B5040632AFD84B3F94B40C83F33880F5A5040632AFD84B3F94B40
32422	Ачикуль	6	55	92	65.479405	65.489062000000004	55.755571000000003	55.744683000000002	0103000020E610000001000000050000007D224F92AE5E50408F71C5C551DF4B407D224F92AE5E50402C67EF8CB6E04B40D9EDB3CA4C5F50402C67EF8CB6E04B40D9EDB3CA4C5F50408F71C5C551DF4B407D224F92AE5E50408F71C5C551DF4B40
31353	Ягодное	6	55	1880	63.666955000000002	63.687139999999999	54.862046999999997	54.849266	0103000020E61000000100000005000000AC730CC85ED54F4068CD8FBFB46C4B40AC730CC85ED54F40B54E5C8E576E4B4000E31934F4D74F40B54E5C8E576E4B4000E31934F4D74F4068CD8FBFB46C4B40AC730CC85ED54F4068CD8FBFB46C4B40
31175	Юламаново	6	55	1880	62.946263000000002	62.972512000000002	54.807693999999998	54.791409000000002	0103000020E610000001000000050000001A355F251F794F404A61DEE34C654B401A355F251F794F407496598462674B40D97BF1457B7C4F407496598462674B40D97BF1457B7C4F404A61DEE34C654B401A355F251F794F404A61DEE34C654B40
30211	Щучанка	6	55	1880	62.850304999999999	62.865459999999999	54.987059000000002	54.977392000000002	0103000020E61000000100000005000000095053CBD66C4F409FAF592E1B7D4B40095053CBD66C4F407A1C06F3577E4B4082FFAD64C76E4F407A1C06F3577E4B4082FFAD64C76E4F409FAF592E1B7D4B40095053CBD66C4F409FAF592E1B7D4B40
31167	Шарипово	6	55	1880	63.453972999999998	63.473241999999999	54.849908999999997	54.840443	0103000020E610000001000000050000002D228AC91BBA4F407993DFA2936B4B402D228AC91BBA4F40BCC96FD1C96C4B40FC8BA03193BC4F40BCC96FD1C96C4B40FC8BA03193BC4F407993DFA2936B4B402D228AC91BBA4F407993DFA2936B4B40
30917	Чистое	6	55	1880	63.847875999999999	63.871473999999999	54.886983999999998	54.875636	0103000020E610000001000000050000001A88653387EC4F40A29927D714704B401A88653387EC4F40A20914B188714B403BA8C4758CEF4F40A20914B188714B403BA8C4758CEF4F40A29927D714704B401A88653387EC4F40A29927D714704B40
30485	Учкулево	6	55	1880	63.320689999999999	63.344630000000002	55.040275000000001	55.029063999999998	0103000020E61000000100000005000000BE13B35E0CA94F40D7BE805EB8834B40BE13B35E0CA94F4057EC2FBB27854B40399CF9D51CAC4F4057EC2FBB27854B40399CF9D51CAC4F40D7BE805EB8834B40BE13B35E0CA94F40D7BE805EB8834B40
55014	Убалина	6	55	1880	63.512974999999997	63.524365000000003	54.738005999999999	54.731538999999998	0103000020E610000001000000050000003255302AA9C14F40D05FE811A35D4B403255302AA9C14F403A2009FB765E4B4062156F641EC34F403A2009FB765E4B4062156F641EC34F40D05FE811A35D4B403255302AA9C14F40D05FE811A35D4B40
30701	Танрыкулово	6	55	1880	63.145356999999997	63.168049000000003	54.915300999999999	54.896501000000001	0103000020E61000000100000005000000519FE40E9B924F4068EA758BC0724B40519FE40E9B924F40807F4A9528754B4011902FA182954F40807F4A9528754B4011902FA182954F4068EA758BC0724B40519FE40E9B924F4068EA758BC0724B40
31465	Солнечная	6	55	1880	63.680861	63.698953000000003	54.961238000000002	54.956150999999998	0103000020E61000000100000005000000990F087426D74F40D384ED27637A4B40990F087426D74F4013D6C6D8097B4B407638BA4A77D94F4013D6C6D8097B4B407638BA4A77D94F40D384ED27637A4B40990F087426D74F40D384ED27637A4B40
30627	Рыбное	6	55	1880	63.909401000000003	63.925435999999998	54.949539000000001	54.936692999999998	0103000020E6100000010000000500000090F9804067F44F4031B2648EE5774B4090F9804067F44F4066A3737E8A794B404145D5AF74F64F4066A3737E8A794B404145D5AF74F64F4031B2648EE5774B4090F9804067F44F4031B2648EE5774B40
31089	Поляна	6	55	1880	63.161976000000003	63.175854999999999	54.746170999999997	54.737662999999998	0103000020E61000000100000005000000535E2BA1BB944F40103CBEBD6B5E4B40535E2BA1BB944F409F1C0588825F4B4046EBA86A82964F409F1C0588825F4B4046EBA86A82964F40103CBEBD6B5E4B40535E2BA1BB944F40103CBEBD6B5E4B40
30770	Подъясово	6	55	1880	63.000818000000002	63.013537999999997	54.864409000000002	54.857010000000002	0103000020E61000000100000005000000C39FE1CD1A804F40282CF180B26D4B40C39FE1CD1A804F401DAF40F4A46E4B406AA0F99CBB814F401DAF40F4A46E4B406AA0F99CBB814F40282CF180B26D4B40C39FE1CD1A804F40282CF180B26D4B40
30554	Парамоново	6	55	1880	63.532926000000003	63.552644000000001	54.812364000000002	54.801177000000003	0103000020E6100000010000000500000014984EEB36C44F4059A7CAF78C664B4014984EEB36C44F405039268BFB674B40522AE109BDC64F405039268BFB674B40522AE109BDC64F4059A7CAF78C664B4014984EEB36C44F4059A7CAF78C664B40
54984	Мир	6	55	1880	63.447738999999999	63.475847000000002	54.823355999999997	54.804352999999999	0103000020E610000001000000050000006612F5824FB94F4041B8020AF5664B406612F5824FB94F40917BBABA63694B402A73F38DE8BC4F40917BBABA63694B402A73F38DE8BC4F4041B8020AF5664B406612F5824FB94F4041B8020AF5664B40
55008	Малышева	6	55	1880	63.410252	63.429845	54.933847999999998	54.926239000000002	0103000020E610000001000000050000002E8F352383B44F40CFA3E2FF8E764B402E8F352383B44F40AEB7CD5488774B40B0AC342905B74F40AEB7CD5488774B40B0AC342905B74F40CFA3E2FF8E764B402E8F352383B44F40CFA3E2FF8E764B40
30073	Майлык	6	55	1880	63.022709999999996	63.041494	55.000124999999997	54.988638999999999	0103000020E6100000010000000500000065A54929E8824F406B4606B98B7E4B4065A54929E8824F40BC74931804804B40787DE6AC4F854F40BC74931804804B40787DE6AC4F854F406B4606B98B7E4B4065A54929E8824F406B4606B98B7E4B40
30777	Крутой Лог	6	55	1880	63.188746000000002	63.197539999999996	54.837135000000004	54.831099000000002	0103000020E610000001000000050000001BA034D428984F40815EB873616A4B401BA034D428984F4022AB5B3D276B4B406FD39FFD48994F4022AB5B3D276B4B406FD39FFD48994F40815EB873616A4B401BA034D428984F40815EB873616A4B40
30342	Казенное	6	55	1880	63.233302000000002	63.250146000000001	54.805531000000002	54.795670000000001	0103000020E61000000100000005000000B30B06D7DC9D4F404434BA83D8654B40B30B06D7DC9D4F400475CAA31B674B40D49CBCC804A04F400475CAA31B674B40D49CBCC804A04F404434BA83D8654B40B30B06D7DC9D4F404434BA83D8654B40
30875	Казаккулово	6	55	1880	63.195456	63.216692000000002	54.915689	54.911366999999998	0103000020E610000001000000050000004BE7C3B304994F40AAD381ACA7744B404BE7C3B304994F404A27124C35754B4005A73E90BC9B4F404A27124C35754B4005A73E90BC9B4F40AAD381ACA7744B404BE7C3B304994F40AAD381ACA7744B40
30153	Искандарово	6	55	1880	63.000512999999998	63.010565	54.965915000000003	54.956564999999998	0103000020E61000000100000005000000861C5BCF10804F40C6BFCFB8707A4B40861C5BCF10804F40A1DB4B1AA37B4B40BABDA4315A814F40A1DB4B1AA37B4B40BABDA4315A814F40C6BFCFB8707A4B40861C5BCF10804F40C6BFCFB8707A4B40
30227	Иванково	6	55	1880	63.422038000000001	63.433850999999997	55.046208	55.034100000000002	0103000020E61000000100000005000000AAD5575705B64F40956588635D844B40AAD5575705B64F402368CC24EA854B401F2BF86D88B74F402368CC24EA854B401F2BF86D88B74F40956588635D844B40AAD5575705B64F40956588635D844B40
31373	Вишняково	6	55	1880	63.786458000000003	63.812635	54.769455999999998	54.758910999999998	0103000020E61000000100000005000000BBD6DEA7AAE44F408EC9E2FE23614B40BBD6DEA7AAE44F4001DBC1887D624B40E04A766C04E84F4001DBC1887D624B40E04A766C04E84F408EC9E2FE23614B40BBD6DEA7AAE44F408EC9E2FE23614B40
31263	Бухарово	6	55	1880	62.938313000000001	62.949291000000002	54.778849999999998	54.771850000000001	0103000020E61000000100000005000000B134F0A31A784F4074B515FBCB624B40B134F0A31A784F40AB3E575BB1634B408EB1135E82794F40AB3E575BB1634B408EB1135E82794F4074B515FBCB624B40B134F0A31A784F4074B515FBCB624B40
30066	Бороздинка	6	55	1880	62.901356999999997	62.935887999999998	54.907817000000001	54.897288000000003	0103000020E61000000100000005000000A5828AAA5F734F40F08B4B55DA724B40A5828AAA5F734F405DE0F25833744B40035C902DCB774F405DE0F25833744B40035C902DCB774F40F08B4B55DA724B40A5828AAA5F734F40F08B4B55DA724B40
31070	Байганино	6	55	1880	63.395206000000002	63.405599000000002	54.723511999999999	54.715192000000002	0103000020E610000001000000050000006C97361C96B24F40302E55698B5B4B406C97361C96B24F40BC218D0A9C5C4B40292504ABEAB34F40BC218D0A9C5C4B40292504ABEAB34F40302E55698B5B4B406C97361C96B24F40302E55698B5B4B40
31255	Аскарово	6	55	1880	62.825153	62.836525000000002	54.741109000000002	54.732486000000002	0103000020E6100000010000000500000020990E9D9E694F409163EB19C25D4B4020990E9D9E694F40B9E2E2A8DC5E4B40A9A44E40136B4F40B9E2E2A8DC5E4B40A9A44E40136B4F409163EB19C25D4B4020990E9D9E694F409163EB19C25D4B40
54927	Альменево	6	55	1880	63.555160000000001	63.601522000000003	54.962116000000002	54.928820000000002	0103000020E6100000010000000500000010069E7B0FC74F4074EFE192E3764B4010069E7B0FC74F40AB7AF99D267B4B408AE942ACFECC4F40AB7AF99D267B4B408AE942ACFECC4F4074EFE192E3764B4010069E7B0FC74F4074EFE192E3764B40
30452	Алакуль	6	55	1880	63.310611000000002	63.330958000000003	54.934716999999999	54.926611000000001	0103000020E610000001000000050000009163EB19C2A74F40938E72309B764B409163EB19C2A74F40F30181CEA4774B40BF2CEDD45CAA4F40F30181CEA4774B40BF2CEDD45CAA4F40938E72309B764B409163EB19C2A74F40938E72309B764B40
155	Томск	5	54	\N	84.896390999999994	85.141262999999995	56.631020999999997	56.399949999999997	0103000020E61000000100000005000000705B5B785E3955408104C58F31334C40705B5B785E3955406B0BCF4BC5504C40A148F7730A4955406B0BCF4BC5504C40A148F7730A4955408104C58F31334C40705B5B785E3955408104C58F31334C40
15359	Сугот	5	54	\N	82.962929000000003	82.979979	57.996600999999998	57.980499999999999	0103000020E61000000100000005000000AED7F4A0A0BD54402FDD240681FD4C40AED7F4A0A0BD544098141F9F90FF4C4013F1D6F9B7BE544098141F9F90FF4C4013F1D6F9B7BE54402FDD240681FD4C40AED7F4A0A0BD54402FDD240681FD4C40
56685	Стрежевой	5	54	\N	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
15337	Староабрамкино	5	54	\N	83.049229999999994	83.069998999999996	57.972754000000002	57.956603000000001	0103000020E61000000100000005000000DAFE959526C35440B42094F771FA4C40DAFE959526C35440CF86FC3383FC4C402CF015DD7AC45440CF86FC3383FC4C402CF015DD7AC45440B42094F771FA4C40DAFE959526C35440B42094F771FA4C40
60291	Северск	5	54	\N	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
13356	Пудино	5	54	\N	79.429990000000004	79.455044000000001	57.577697999999998	57.565859000000003	0103000020E61000000100000005000000DAE6C6F484DB5340DA9255116EC84C40DAE6C6F484DB5340787B1002F2C94C406D8FDE701FDD5340787B1002F2C94C406D8FDE701FDD5340DA9255116EC84C40DAE6C6F484DB5340DA9255116EC84C40
60301	Колпашево	5	54	\N	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
13243	Кедровый	5	54	\N	79.550974999999994	79.586134999999999	57.570348000000003	57.554550999999996	0103000020E61000000100000005000000787AA52C43E35340677BF486FBC64C40787AA52C43E3534065ABCB2901C94C409F02603C83E5534065ABCB2901C94C409F02603C83E55340677BF486FBC64C40787AA52C43E35340677BF486FBC64C40
52317	Зональная Станция	5	54	\N	85.003298999999998	85.049895000000006	56.442717000000002	56.418177999999997	0103000020E610000001000000050000000247020D364055400EF450DB86354C400247020D364055400E315EF3AA384C40F94ECC7A314355400E315EF3AA384C40F94ECC7A314355400EF450DB86354C400247020D364055400EF450DB86354C40
60302	ЗАТО Северск	5	54	\N	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
60370	Госсортучасток	5	54	\N	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
60304	Аэропорт	5	54	\N	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
60320	Аэропорт	5	54	\N	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
60289	Асино	5	54	\N	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
3346	Федораевка	5	54	448	83.697166999999993	83.710200999999998	56.874620999999998	56.860083000000003	0103000020E610000001000000050000006D3656629EEC54403C6C2233176E4C406D3656629EEC544089B2B794F36F4C408925E5EE73ED544089B2B794F36F4C408925E5EE73ED54403C6C2233176E4C406D3656629EEC54403C6C2233176E4C40
47717	Татьяновка	5	54	448	83.535210000000006	83.579137000000003	56.824966000000003	56.818626999999999	0103000020E61000000100000005000000809F71E140E25440B14F00C5C8684C40809F71E140E25440EE27637C98694C40D4B9A29410E55440EE27637C98694C40D4B9A29410E55440B14F00C5C8684C40809F71E140E25440B14F00C5C8684C40
49299	Половинка (Базанаково)	5	54	448	84.361048999999994	84.397448999999995	56.722735999999998	56.694588000000003	0103000020E6100000010000000500000039D0436D1B175540D7187442E8584C4039D0436D1B17554028D2FD9C825C4C40FC34EECD6F19554028D2FD9C825C4C40FC34EECD6F195540D7187442E8584C4039D0436D1B175540D7187442E8584C40
47910	Победа	5	54	448	84.156484000000006	84.181861999999995	56.547969000000002	56.520256000000003	0103000020E610000001000000050000003A9677D5030A55401EC6A4BF97424C403A9677D5030A5540651C23D923464C40A69883A0A30B5540651C23D923464C40A69883A0A30B55401EC6A4BF97424C403A9677D5030A55401EC6A4BF97424C40
3494	Новоильинка	5	54	448	84.052746999999997	84.106682000000006	56.990806999999997	56.973184000000003	0103000020E6100000010000000500000093FDF33460035540C87E164B917C4C4093FDF33460035540EDD286C3D27E4C409A44BDE0D3065540EDD286C3D27E4C409A44BDE0D3065540C87E164B917C4C4093FDF33460035540C87E164B917C4C40
4299	Нащёково	5	54	448	84.042227999999994	84.081627999999995	56.537571999999997	56.522430999999997	0103000020E610000001000000050000006EBE11DDB302554052B5DD04DF424C406EBE11DDB3025540669FC728CF444C40069CA56439055540669FC728CF444C40069CA5643905554052B5DD04DF424C406EBE11DDB302554052B5DD04DF424C40
47937	Монастырка	5	54	448	83.712196000000006	83.741264999999999	56.952559000000001	56.932127999999999	0103000020E61000000100000005000000E415889E94ED5440CBD765F84F774C40E415889E94ED544057410C74ED794C40D82AC1E270EF544057410C74ED794C40D82AC1E270EF5440CBD765F84F774C40E415889E94ED5440CBD765F84F774C40
46285	Михайловка (Кочубай)	5	54	448	83.670738	83.688417000000001	56.939691000000003	56.920161999999998	0103000020E61000000100000005000000CE8B135FEDEA5440CF8250DEC7754C40CE8B135FEDEA54403BAC70CB47784C40AB402D060FEC54403BAC70CB47784C40AB402D060FEC5440CF8250DEC7754C40CE8B135FEDEA5440CF8250DEC7754C40
48124	Мельниково	5	54	448	84.057805000000002	84.099450000000004	56.578085999999999	56.541949000000002	0103000020E61000000100000005000000E622BE13B3035540CA8CB7955E454C40E622BE13B30355404223D8B8FE494C40956588635D0655404223D8B8FE494C40956588635D065540CA8CB7955E454C40E622BE13B3035540CA8CB7955E454C40
2761	Маркелово	5	54	448	83.553661000000005	83.575363999999993	56.713755999999997	56.695562000000002	0103000020E6100000010000000500000086048C2E6FE35440912BF52C08594C4086048C2E6FE3544071A94A5B5C5B4C40EDD286C3D2E4544071A94A5B5C5B4C40EDD286C3D2E45440912BF52C08594C4086048C2E6FE35440912BF52C08594C40
3765	Малобрагино	5	54	448	84.371882999999997	84.391681000000005	56.867783000000003	56.842374	0103000020E610000001000000050000000EBC5AEECC175540178046E9D26B4C400EBC5AEECC1755402C836A83136F4C40BC5D2F4D111955402C836A83136F4C40BC5D2F4D11195540178046E9D26B4C400EBC5AEECC175540178046E9D26B4C40
47859	Каргала	5	54	448	83.947608000000002	83.968987999999996	56.624583999999999	56.613812000000003	0103000020E61000000100000005000000645B069CA5FC544039F24064914E4C40645B069CA5FC54406CCD565EF24F4C40DA8D3EE603FE54406CCD565EF24F4C40DA8D3EE603FE544039F24064914E4C40645B069CA5FC544039F24064914E4C40
2811	Гынгазово	5	54	448	83.575113000000002	83.594228999999999	56.646543999999999	56.636361999999998	0103000020E6100000010000000500000049A0C1A6CEE4544065355D4F74514C4049A0C1A6CEE4544067B62BF4C1524C406D5512D907E6544067B62BF4C1524C406D5512D907E6544065355D4F74514C4049A0C1A6CEE4544065355D4F74514C40
47969	Гусево	5	54	448	83.993279000000001	84.035597999999993	56.894945999999997	56.872855000000001	0103000020E610000001000000050000006E3315E291FF544036936FB6B96F4C406E3315E291FF5440CFD72C978D724C406473D53C47025540CFD72C978D724C406473D53C4702554036936FB6B96F4C406E3315E291FF544036936FB6B96F4C40
2698	Вороновка	5	54	448	83.438793000000004	83.478283000000005	56.835520000000002	56.821040000000004	0103000020E61000000100000005000000AE2D3C2F15DC54409B5AB6D617694C40AE2D3C2F15DC5440B493C151F26A4C40E6CE4C309CDE5440B493C151F26A4C40E6CE4C309CDE54409B5AB6D617694C40AE2D3C2F15DC54409B5AB6D617694C40
48093	Бушуево	5	54	448	84.278835000000001	84.298005000000003	56.904668999999998	56.891573000000001	0103000020E61000000100000005000000BB7EC16ED8115540917F66101F724C40BB7EC16ED81155403E5A9C31CC734C40D9429083121355403E5A9C31CC734C40D942908312135540917F66101F724C40BB7EC16ED8115540917F66101F724C40
60305	Батурино	5	54	448	83.555870999999996	83.569650999999993	56.502639000000002	56.490732999999999	0103000020E61000000100000005000000DE72F56393E35440B308C556D03E4C40DE72F56393E35440DA58897956404C408EC8772975E45440DA58897956404C408EC8772975E45440B308C556D03E4C40DE72F56393E35440B308C556D03E4C40
2888	Баткат	5	54	448	83.839890999999994	83.882812999999999	56.561219999999999	56.543030999999999	0103000020E610000001000000050000001A4D2EC6C0F554406ADB300A82454C401A4D2EC6C0F5544039EE940ED6474C40F4DE180280F8544039EE940ED6474C40F4DE180280F854406ADB300A82454C401A4D2EC6C0F554406ADB300A82454C40
47828	Бабарыкино	5	54	448	83.596779999999995	83.618950999999996	56.564895	56.547134999999997	0103000020E610000001000000050000000ABABDA431E654409CBF098508464C400ABABDA431E654404356B77A4E484C40E5B4A7E49CE754404356B77A4E484C40E5B4A7E49CE754409CBF098508464C400ABABDA431E654409CBF098508464C40
2540	Анастасьевка	5	54	448	83.562950000000001	83.581903999999994	56.78246	56.762044000000003	0103000020E6100000010000000500000020D26F5F07E45440780E65A88A614C4020D26F5F07E45440CE3637A627644C40575A46EA3DE55440CE3637A627644C40575A46EA3DE55440780E65A88A614C4020D26F5F07E45440780E65A88A614C40
349	Черёмушки	5	54	146	82.597296999999998	82.617787000000007	57.778170000000003	57.771417	0103000020E61000000100000005000000EE3F321D3AA654400A4AD1CABDE24C40EE3F321D3AA654403A5D16139BE34C4037397CD289A754403A5D16139BE34C4037397CD289A754400A4AD1CABDE24C40EE3F321D3AA654400A4AD1CABDE24C40
1774	Чемондаевка	5	54	146	82.999651999999998	83.012946999999997	57.747227000000002	57.734391000000002	0103000020E6100000010000000500000062D8614CFABF544006BD378600DE4C4062D8614CFABF544017D86322A5DF4C403465A71FD4C0544017D86322A5DF4C403465A71FD4C0544006BD378600DE4C4062D8614CFABF544006BD378600DE4C40
1726	Чаинск	5	54	146	82.581746999999993	82.604483000000002	57.936700000000002	57.923754000000002	0103000020E61000000100000005000000F3E2C4573BA554404CC631923DF64C40F3E2C4573BA55440E4141DC9E5F74C403BFF76D9AFA65440E4141DC9E5F74C403BFF76D9AFA654404CC631923DF64C40F3E2C4573BA554404CC631923DF64C40
1105	Усть-Бакчар	5	54	146	82.301940000000002	82.333973	57.622024000000003	57.601495	0103000020E61000000100000005000000AC5626FC5293544090DAC4C9FDCC4C40AC5626FC52935440DFA9807B9ECF4C40CF2F4AD05F955440DFA9807B9ECF4C40CF2F4AD05F95544090DAC4C9FDCC4C40AC5626FC5293544090DAC4C9FDCC4C40
2023	Трудовой	5	54	146	82.636257000000001	82.644970000000001	57.815727000000003	57.813042000000003	0103000020E6100000010000000500000078B6476FB8A854402123A0C211E84C4078B6476FB8A854406BBB09BE69E84C40AC39403047A954406BBB09BE69E84C40AC39403047A954402123A0C211E84C4078B6476FB8A854402123A0C211E84C40
984	Третья Тига	5	54	146	82.360518999999996	82.384324000000007	57.498837999999999	57.484045999999999	0103000020E610000001000000050000008BA548BE129754403BE12538F5BD4C408BA548BE12975440430070ECD9BF4C4059C4B0C398985440430070ECD9BF4C4059C4B0C3989854403BE12538F5BD4C408BA548BE129754403BE12538F5BD4C40
60342	Тоинка	5	54	146	82.613636999999997	82.745437999999993	58.064867999999997	57.994951	0103000020E6100000010000000500000065A71FD445A75440AE0FEB8D5AFF4C4065A71FD445A75440494739984D084D4085CC9541B5AF5440494739984D084D4085CC9541B5AF5440AE0FEB8D5AFF4C4065A71FD445A75440AE0FEB8D5AFF4C40
1885	Сухой Лог	5	54	146	82.821956	82.836392000000004	57.703795999999997	57.691583999999999	0103000020E6100000010000000500000010B056ED9AB45440EB3713D385D84C4010B056ED9AB454401E87C1FC15DA4C40B5A84F7287B554401E87C1FC15DA4C40B5A84F7287B55440EB3713D385D84C4010B056ED9AB45440EB3713D385D84C40
1249	Стрельниково	5	54	146	82.430372000000006	82.458076000000005	57.717517999999998	57.711176000000002	0103000020E610000001000000050000004E4700378B9B54409DD9AED007DB4C404E4700378B9B54404A253CA1D7DB4C4048C5FF1D519D54404A253CA1D7DB4C4048C5FF1D519D54409DD9AED007DB4C404E4700378B9B54409DD9AED007DB4C40
2135	Подгорное	5	54	146	82.605714000000006	82.673968000000002	57.805067999999999	57.766195000000003	0103000020E61000000100000005000000AE2EA704C4A65440EBAD81AD12E24C40AE2EA704C4A654402F87DD770CE74C403CA3AD4A22AB54402F87DD770CE74C403CA3AD4A22AB5440EBAD81AD12E24C40AE2EA704C4A65440EBAD81AD12E24C40
1353	Обское	5	54	146	83.370441	83.396932000000007	57.745483999999998	57.733435	0103000020E610000001000000050000003E062B4EB5D75440F25EB532E1DD4C403E062B4EB5D754407BD80B056CDF4C4019AF795567D954407BD80B056CDF4C4019AF795567D95440F25EB532E1DD4C403E062B4EB5D75440F25EB532E1DD4C40
1126	Новые Ключи	5	54	146	82.333246000000003	82.346343000000005	57.624876999999998	57.616042	0103000020E6100000010000000500000076E107E753955440317BD976DACE4C4076E107E753955440E48233F8FBCF4C40B58CD47B2A965440E48233F8FBCF4C40B58CD47B2A965440317BD976DACE4C4076E107E753955440317BD976DACE4C40
1452	Новоколомино	5	54	146	83.257476999999994	83.275075000000001	57.833857999999999	57.825643999999997	0103000020E61000000100000005000000389ECF807AD05440BE11DDB3AEE94C40389ECF807AD0544005C1E3DBBBEA4C409F3C2CD49AD1544005C1E3DBBBEA4C409F3C2CD49AD15440BE11DDB3AEE94C40389ECF807AD05440BE11DDB3AEE94C40
998	Нижняя Тига	5	54	146	82.302586000000005	82.332509000000002	57.570604000000003	57.554946999999999	0103000020E610000001000000050000008F8EAB915D935440B401D88008C74C408F8EAB915D935440C07B478D09C94C400B28D4D347955440C07B478D09C94C400B28D4D347955440B401D88008C74C408F8EAB915D935440B401D88008C74C40
1959	Мушкино	5	54	146	82.646101999999999	82.669844999999995	57.812663000000001	57.801091999999997	0103000020E6100000010000000500000055F833BC59A954402A8BC22E8AE64C4055F833BC59A95440AAD5575705E84C40E71890BDDEAA5440AAD5575705E84C40E71890BDDEAA54402A8BC22E8AE64C4055F833BC59A954402A8BC22E8AE64C40
907	Лось-Гора (Шоры-Еры)	5	54	146	82.266034000000005	82.282266000000007	57.527118000000002	57.515436999999999	0103000020E61000000100000005000000F16778B306915440FD12F1D6F9C14C40F16778B3069154400491459A78C34C4075B169A5109254400491459A78C34C4075B169A510925440FD12F1D6F9C14C40F16778B306915440FD12F1D6F9C14C40
1341	Лесоучасток-Чая	5	54	146	82.444017000000002	82.470877000000002	57.707709999999999	57.696769000000003	0103000020E610000001000000050000008E7747C66A9C5440EEEE01BA2FD94C408E7747C66A9C5440AD86C43D96DA4C4012DC48D9229E5440AD86C43D96DA4C4012DC48D9229E5440EEEE01BA2FD94C408E7747C66A9C5440EEEE01BA2FD94C40
1463	Леботер	5	54	146	83.162066999999993	83.187723000000005	57.883105	57.870614000000003	0103000020E61000000100000005000000B130444E5FCA54404AB8904770EF4C40B130444E5FCA544090F7AA9509F14C40406D54A703CC544090F7AA9509F14C40406D54A703CC54404AB8904770EF4C40B130444E5FCA54404AB8904770EF4C40
1572	Коломинские Гривы	5	54	146	83.135091000000003	83.159220000000005	57.804315000000003	57.781083000000002	0103000020E61000000100000005000000F9BEB854A5C85440153B1A87FAE34C40F9BEB854A5C8544054573ECBF3E64C40A03715A930CA544054573ECBF3E64C40A03715A930CA5440153B1A87FAE34C40F9BEB854A5C85440153B1A87FAE34C40
1835	Ермиловка	5	54	146	82.739455000000007	82.760278	57.727443000000001	57.708661999999997	0103000020E610000001000000050000004777103B53AF54407FF5B86FB5DA4C404777103B53AF5440215A2BDA1CDD4C4092770E65A8B05440215A2BDA1CDD4C4092770E65A8B054407FF5B86FB5DA4C404777103B53AF54407FF5B86FB5DA4C40
51982	Гришкино	5	54	146	82.589014000000006	82.720815000000002	58.077024999999999	58.007131000000001	0103000020E61000000100000005000000B7B8C667B2A55440D6E429ABE9004D40B7B8C667B2A55440B9FC87F4DB094D40D7DD3CD521AE5440B9FC87F4DB094D40D7DD3CD521AE5440D6E429ABE9004D40B7B8C667B2A55440D6E429ABE9004D40
2083	Григорьевка	5	54	146	82.616799	82.635232000000002	57.761178000000001	57.751286	0103000020E61000000100000005000000274D83A279A75440A9F8BF232AE04C40274D83A279A75440A437DC476EE14C40DA571EA4A7A85440A437DC476EE14C40DA571EA4A7A85440A9F8BF232AE04C40274D83A279A75440A9F8BF232AE04C40
856	Гореловка	5	54	146	82.198687000000007	82.230506000000005	57.485061999999999	57.466304999999998	0103000020E61000000100000005000000FCC8AD49B78C54400B7BDAE1AFBB4C40FCC8AD49B78C54402444F98216BE4C4009E23C9CC08E54402444F98216BE4C4009E23C9CC08E54400B7BDAE1AFBB4C40FCC8AD49B78C54400B7BDAE1AFBB4C40
1229	Варгатер	5	54	146	82.429051000000001	82.455453000000006	57.687157999999997	57.669544999999999	0103000020E610000001000000050000003B545392759B5440A4198BA6B3D54C403B545392759B5440A69718CBF4D74C405EF75624269D5440A69718CBF4D74C405EF75624269D5440A4198BA6B3D54C403B545392759B5440A4198BA6B3D54C40
799	Бундюр	5	54	146	81.981590999999995	82.011505	57.552601000000003	57.540125000000003	0103000020E6100000010000000500000011C30E63D27E54404260E5D022C54C4011C30E63D27E5440535E2BA1BBC64C4064AF777FBC805440535E2BA1BBC64C4064AF777FBC8054404260E5D022C54C4011C30E63D27E54404260E5D022C54C40
60353	Яр	5	54	52	84.323715000000007	86.176920999999993	57.102131999999997	56.147295	0103000020E61000000100000005000000618E1EBFB7145540A2EE0390DA124C40618E1EBFB714554002F04FA9128D4C40703E75AC528B554002F04FA9128D4C40703E75AC528B5540A2EE0390DA124C40618E1EBFB7145540A2EE0390DA124C40
46816	Чёрная Речка	5	54	52	84.897631000000004	84.922145999999998	56.411441000000003	56.392741999999998	0103000020E610000001000000050000000D384BC97239554000E2AE5E45324C400D384BC972395540E59D4319AA344C40C808A870043B5540E59D4319AA344C40C808A870043B554000E2AE5E45324C400D384BC97239554000E2AE5E45324C40
46643	Халдеево	5	54	52	85.581885999999997	85.607578000000004	56.638496000000004	56.630243	0103000020E610000001000000050000000400C79E3D65554037C478CDAB504C400400C79E3D6555403C50A73CBA514C4039F1D58EE26655403C50A73CBA514C4039F1D58EE266554037C478CDAB504C400400C79E3D65554037C478CDAB504C40
31900	Турунтаево	5	54	52	85.952063999999993	86.012322999999995	56.652031999999998	56.630960999999999	0103000020E61000000100000005000000BBECD79DEE7C554096067E54C3504C40BBECD79DEE7C554005F9D9C875534C40457F68E6C980554005F9D9C875534C40457F68E6C980554096067E54C3504C40BBECD79DEE7C554096067E54C3504C40
48060	Трубачево	5	54	52	85.097702999999996	85.107962000000001	56.429867000000002	56.424824999999998	0103000020E61000000100000005000000266E15C440465540F8C264AA60364C40266E15C4404655409850C1E105374C407DCD72D9E84655409850C1E105374C407DCD72D9E8465540F8C264AA60364C40266E15C440465540F8C264AA60364C40
46254	Томское	5	54	52	85.609689000000003	85.621735999999999	56.850206	56.839433999999997	0103000020E61000000100000005000000C8EE0225056755404293C492726B4C40C8EE022505675540766EDA8CD36C4C40BCAFCA85CA675540766EDA8CD36C4C40BCAFCA85CA6755404293C492726B4C40C8EE0225056755404293C492726B4C40
32419	Тахтамышево	5	54	52	84.870564000000002	84.892904999999999	56.389578	56.370947000000001	0103000020E61000000100000005000000CC441152B737554050C6F8307B2F4C40CC441152B7375540DC9E20B1DD314C40D55B035B25395540DC9E20B1DD314C40D55B035B2539554050C6F8307B2F4C40CC441152B737554050C6F8307B2F4C40
46591	Сухоречье	5	54	52	85.448072999999994	85.481292999999994	56.483894999999997	56.472555	0103000020E610000001000000050000001E4E603AAD5C5540D847A7AE7C3C4C401E4E603AAD5C554055D97745F03D4C40CCB22781CD5E554055D97745F03D4C40CCB22781CD5E5540D847A7AE7C3C4C401E4E603AAD5C5540D847A7AE7C3C4C40
32087	Спасо-Яйское	5	54	52	86.114372000000003	86.121557999999993	56.715311999999997	56.698497000000003	0103000020E6100000010000000500000000E5EFDE5187554054AD855968594C4000E5EFDE51875540DA37F7578F5B4C404CA4349BC7875540DA37F7578F5B4C404CA4349BC787554054AD855968594C4000E5EFDE5187554054AD855968594C40
31056	Синий Утёс	5	54	52	84.916262000000003	84.926511000000005	56.339821000000001	56.334158000000002	0103000020E6100000010000000500000053245F09A43A554030D978B0C52A4C4053245F09A43A55403CBF28417F2B4C409818CBF44B3B55403CBF28417F2B4C409818CBF44B3B554030D978B0C52A4C4053245F09A43A554030D978B0C52A4C40
31837	Семилужки	5	54	52	85.339179000000001	85.385326000000006	56.62182	56.609952999999997	0103000020E610000001000000050000005C1FD61BB55555406D8C9DF0124E4C405C1FD61BB5555540D6FF39CC974F4C401B13622EA9585540D6FF39CC974F4C401B13622EA95855406D8C9DF0124E4C405C1FD61BB55555406D8C9DF0124E4C40
60283	Самусь	5	54	52	84.690676999999994	84.718444000000005	56.762473	56.733643999999998	0103000020E610000001000000050000005CC64D0D342C55400C74ED0BE85D4C405CC64D0D342C5540A08A1BB798614C407A008BFCFA2D5540A08A1BB798614C407A008BFCFA2D55400C74ED0BE85D4C405CC64D0D342C55400C74ED0BE85D4C40
29586	Рыбалово	5	54	52	84.503360000000001	84.533767999999995	56.514153	56.492522000000001	0103000020E610000001000000050000005587DC0C37205540BF47FDF50A3F4C405587DC0C37205540F511F8C3CF414C40AFE9414129225540F511F8C3CF414C40AFE9414129225540BF47FDF50A3F4C405587DC0C37205540BF47FDF50A3F4C40
46795	Романовка	5	54	52	85.924611999999996	85.951238000000004	56.458646000000002	56.451363999999998	0103000020E610000001000000050000004E5FCFD72C7B5540BE4BA94BC6394C404E5FCFD72C7B55407A3881E9B43A4C40992D5915E17C55407A3881E9B43A4C40992D5915E17C5540BE4BA94BC6394C404E5FCFD72C7B5540BE4BA94BC6394C40
46440	Рассвет	5	54	52	85.189367000000004	85.216362000000004	56.631219000000002	56.617823999999999	0103000020E6100000010000000500000044FCC3961E4C55408A5759DB144F4C4044FCC3961E4C554092CEC0C8CB504C40388600E0D84D554092CEC0C8CB504C40388600E0D84D55408A5759DB144F4C4044FCC3961E4C55408A5759DB144F4C40
610	Поросино	5	54	52	84.749003999999999	84.770805999999993	56.556804999999997	56.542416000000003	0103000020E61000000100000005000000AF2479AEEF2F5540E06932E36D454C40AF2479AEEF2F5540E89FE06245474C40E063B0E254315540E89FE06245474C40E063B0E254315540E06932E36D454C40AF2479AEEF2F5540E06932E36D454C40
32012	Подломск	5	54	52	85.801282	85.831636000000003	56.652453000000001	56.643203	0103000020E61000000100000005000000E7374C344873554034D8D47954524C40E7374C3448735540AB96749483534C40488B338639755540AB96749483534C40488B33863975554034D8D47954524C40E7374C344873554034D8D47954524C40
45909	Плотниково	5	54	52	85.237076999999999	85.258205000000004	56.389009999999999	56.377611999999999	0103000020E61000000100000005000000906802452C4F5540E0490B9755304C40906802452C4F554092E86514CB314C407AAA436E8650554092E86514CB314C407AAA436E86505540E0490B9755304C40906802452C4F5540E0490B9755304C40
45923	Петухово	5	54	52	85.257836999999995	85.285155000000003	56.329048	56.310806999999997	0103000020E61000000100000005000000B8ACC26680505540162F1686C8274C40B8ACC266805055403868AF3E1E2A4C409ED2C1FA3F5255403868AF3E1E2A4C409ED2C1FA3F525540162F1686C8274C40B8ACC26680505540162F1686C8274C40
60332	Петрово	5	54	52	84.799858	84.826600999999997	56.539870000000001	56.532941000000001	0103000020E610000001000000050000006ADC9BDF3033554049D9226937444C406ADC9BDF30335540B70BCD751A454C40D175E107E7345540B70BCD751A454C40D175E107E734554049D9226937444C406ADC9BDF3033554049D9226937444C40
46696	Перовка	5	54	52	85.958819000000005	85.988822999999996	56.697972999999998	56.686377	0103000020E6100000010000000500000024F25D4A5D7D554001DD9733DB574C4024F25D4A5D7D5540D93EE42D57594C4016A243E0487F5540D93EE42D57594C4016A243E0487F554001DD9733DB574C4024F25D4A5D7D554001DD9733DB574C40
6058	Октябрьское	5	54	52	85.422596999999996	85.446807000000007	56.731951000000002	56.72081	0103000020E61000000100000005000000D09849D40B5B55409C508880435C4C40D09849D40B5B554023A30392B05D4C40EE27637C985C554023A30392B05D4C40EE27637C985C55409C508880435C4C40D09849D40B5B55409C508880435C4C40
32353	Новорождественское	5	54	52	85.984862000000007	86.029139000000001	56.500954	56.477820000000001	0103000020E61000000100000005000000AF44A0FA077F5540F7AFAC34293D4C40AF44A0FA077F55407366BB421F404C407102D369DD8155407366BB421F404C407102D369DD815540F7AFAC34293D4C40AF44A0FA077F5540F7AFAC34293D4C40
46543	Новомихайловка	5	54	52	85.134364000000005	85.159381999999994	56.5426	56.535646	0103000020E61000000100000005000000A070766B99485540DA1D520C90444C40A070766B99485540A167B3EA73454C408C648F50334A5540A167B3EA73454C408C648F50334A5540DA1D520C90444C40A070766B99485540DA1D520C90444C40
46730	Новоархангельское	5	54	52	85.879138999999995	85.906537	56.715331999999997	56.708252000000002	0103000020E61000000100000005000000D76839D043785540CEA96400A85A4C40D76839D04378554021E4BCFF8F5B4C404BE7C3B3047A554021E4BCFF8F5B4C404BE7C3B3047A5540CEA96400A85A4C40D76839D043785540CEA96400A85A4C40
46667	Нелюбино	5	54	52	84.529949999999999	84.572053999999994	56.572389000000001	56.554369000000001	0103000020E61000000100000005000000F9A067B3EA21554047753A90F5464C40F9A067B3EA2155408ACBF10A44494C40F16261889C2455408ACBF10A44494C40F16261889C24554047753A90F5464C40F9A067B3EA21554047753A90F5464C40
45795	Наумовка	5	54	52	85.093939000000006	85.153902000000002	56.767263999999997	56.753290999999997	0103000020E610000001000000050000006A34B9180346554081AFE8D66B604C406A34B91803465540F6B2EDB435624C407F32C687D9495540F6B2EDB435624C407F32C687D949554081AFE8D66B604C406A34B9180346554081AFE8D66B604C40
60296	Моряковский Затон	5	54	52	84.624506999999994	84.664212000000006	56.702204000000002	56.679510000000001	0103000020E61000000100000005000000E04735ECF727554009A7052FFA564C40E04735ECF7275540698F17D2E1594C4017670C73822A5540698F17D2E1594C4017670C73822A554009A7052FFA564C40E04735ECF727554009A7052FFA564C40
46410	Молодёжный	5	54	52	85.317466999999994	85.329334000000003	56.675539000000001	56.669939999999997	0103000020E61000000100000005000000CAA31B615154554020240B98C0554C40CAA31B61515455401616DC0F78564C407FDDE9CE135555401616DC0F78564C407FDDE9CE1355554020240B98C0554C40CAA31B615154554020240B98C0554C40
45862	Мирный	5	54	52	85.108177999999995	85.137067000000002	56.447135000000003	56.436442	0103000020E6100000010000000500000063096B63EC465540E84CDA54DD374C4063096B63EC465540D0F23CB83B394C401897AAB4C5485540D0F23CB83B394C401897AAB4C5485540E84CDA54DD374C4063096B63EC465540E84CDA54DD374C40
29900	Межениновка	5	54	52	85.351360999999997	85.392628999999999	56.371301000000003	56.350696999999997	0103000020E61000000100000005000000C005D9B27C56554014E7A8A3E32C4C40C005D9B27C5655406EFC89CA862F4C40849D62D5205955406EFC89CA862F4C40849D62D52059554014E7A8A3E32C4C40C005D9B27C56554014E7A8A3E32C4C40
32280	Мазалово	5	54	52	86.122735000000006	86.148974999999993	56.603973000000003	56.579934999999999	0103000020E61000000100000005000000C6C4E6E3DA8755402367614F3B4A4C40C6C4E6E3DA8755406155BDFC4E4D4C40FB3A70CE888955406155BDFC4E4D4C40FB3A70CE888955402367614F3B4A4C40C6C4E6E3DA8755402367614F3B4A4C40
31640	Лязгино	5	54	52	85.223934999999997	85.240374000000003	56.488377999999997	56.483060000000002	0103000020E61000000100000005000000815B77F3544E5540BD00FBE8D43D4C40815B77F3544E5540FE0A992B833E4C40C233A149624F5540FE0A992B833E4C40C233A149624F5540BD00FBE8D43D4C40815B77F3544E5540BD00FBE8D43D4C40
30656	Лучаново	5	54	52	85.047353000000001	85.080607999999998	56.367702000000001	56.345913000000003	0103000020E610000001000000050000008597E0D40743554071218FE0462C4C408597E0D4074355403F56F0DB102F4C40F1F274AE284555403F56F0DB102F4C40F1F274AE2845554071218FE0462C4C408597E0D40743554071218FE0462C4C40
60297	Лоскутово	5	54	52	85.046813999999998	85.120395000000002	56.393773000000003	56.364910000000002	0103000020E61000000100000005000000ADBF2500FF425540DFFDF15EB52E4C40ADBF2500FF4255401F86562767324C4086E63A8DB44755401F86562767324C4086E63A8DB4475540DFFDF15EB52E4C40ADBF2500FF425540DFFDF15EB52E4C40
45618	Лаврово	5	54	52	84.399154999999993	84.432042999999993	56.446314999999998	56.435147999999998	0103000020E610000001000000050000003BC269C18B195540BC75FEEDB2374C403BC269C18B1955406C5B94D920394C40CEDDAE97A61B55406C5B94D920394C40CEDDAE97A61B5540BC75FEEDB2374C403BC269C18B195540BC75FEEDB2374C40
222	Курлек	5	54	52	84.837524000000002	84.872415000000004	56.229787000000002	56.203037000000002	0103000020E610000001000000050000005E6743FE993555406170CD1DFD194C405E6743FE99355540E20511A9691D4C408D62B9A5D5375540E20511A9691D4C408D62B9A5D53755406170CD1DFD194C405E6743FE993555406170CD1DFD194C40
493	Кудринский Участок	5	54	52	84.659729999999996	84.677507000000006	56.540053999999998	56.533949	0103000020E610000001000000050000002A8C2D04392A5540AF5DDA7058444C402A8C2D04392A554078094E7D20454C40E9F351465C2B554078094E7D20454C40E9F351465C2B5540AF5DDA7058444C402A8C2D04392A5540AF5DDA7058444C40
60303	Корнилово	5	54	52	84.323715000000007	86.176920999999993	57.102131999999997	56.147295	0103000020E61000000100000005000000618E1EBFB7145540A2EE0390DA124C40618E1EBFB714554002F04FA9128D4C40703E75AC528B554002F04FA9128D4C40703E75AC528B5540A2EE0390DA124C40618E1EBFB7145540A2EE0390DA124C40
31521	Копылово	5	54	52	85.091469000000004	85.166936000000007	56.615352000000001	56.589478	0103000020E6100000010000000500000043E6CAA0DA45554012DBDD03744B4C4043E6CAA0DA4555409CC3B5DAC34E4C409B215514AF4A55409CC3B5DAC34E4C409B215514AF4A554012DBDD03744B4C4043E6CAA0DA45554012DBDD03744B4C40
31115	Коларово	5	54	52	84.928335000000004	84.959174000000004	56.341413000000003	56.33325	0103000020E61000000100000005000000DC2E34D7693B55402DB29DEFA72A4C40DC2E34D7693B5540F2B6D26BB32B4C401B4B581B633D5540F2B6D26BB32B4C401B4B581B633D55402DB29DEFA72A4C40DC2E34D7693B55402DB29DEFA72A4C40
29748	Козюлино	5	54	52	84.492041	84.508506999999994	56.809531	56.804372000000001	0103000020E61000000100000005000000A2D288997D1F5540B8E864A9F5664C40A2D288997D1F5540910C39B69E674C405FB2F1608B205540910C39B69E674C405FB2F1608B205540B8E864A9F5664C40A2D288997D1F5540B8E864A9F5664C40
6401	Кисловка	5	54	52	84.854422	84.886589999999998	56.423375999999998	56.408571999999999	0103000020E61000000100000005000000E8BE9CD9AE365540D90759164C344C40E8BE9CD9AE365540A5F44C2F31364C407BBDFBE3BD385540A5F44C2F31364C407BBDFBE3BD385540D90759164C344C40E8BE9CD9AE365540D90759164C344C40
62	Кафтанчиково	5	54	52	84.848493000000005	84.881271999999996	56.363996999999998	56.332870999999997	0103000020E61000000100000005000000A37895B54D365540B66455849B2A4C40A37895B54D365540CA6B2574972E4C405AB8ACC266385540CA6B2574972E4C405AB8ACC266385540B66455849B2A4C40A37895B54D365540B66455849B2A4C40
45562	Карбышево	5	54	52	84.441601000000006	84.462406000000001	56.492685999999999	56.485008000000001	0103000020E610000001000000050000006138D730431C55403126FDBD143E4C406138D730431C55403999B855103F4C4059DE550F981D55403999B855103F4C4059DE550F981D55403126FDBD143E4C406138D730431C55403126FDBD143E4C40
159	Кандинка	5	54	52	84.793507000000005	84.838144	56.303147000000003	56.291254000000002	0103000020E610000001000000050000006A8995D1C8325540236AA2CF47254C406A8995D1C8325540B5705985CD264C40AC55BB26A4355540B5705985CD264C40AC55BB26A4355540236AA2CF47254C406A8995D1C8325540236AA2CF47254C40
293	Калтай	5	54	52	84.866665999999995	84.894980000000004	56.289369999999998	56.271486000000003	0103000020E6100000010000000500000087A3AB747737554033A9A10DC0224C4087A3AB7477375540C5387F130A254C40BEA4315A47395540C5387F130A254C40BEA4315A4739554033A9A10DC0224C4087A3AB747737554033A9A10DC0224C40
31208	Итатка	5	54	52	85.581716	85.623784000000001	56.833022999999997	56.813502999999997	0103000020E61000000100000005000000D6E3BED53A6555405419C6DD20684C40D6E3BED53A6555406CE8667FA06A4C4028F1B913EC6755406CE8667FA06A4C4028F1B913EC6755405419C6DD20684C40D6E3BED53A6555405419C6DD20684C40
546	Зоркальцево	5	54	52	84.720618000000002	84.756028999999998	56.536822999999998	56.511625000000002	0103000020E610000001000000050000002CBAF59A1E2E5540736891ED7C414C402CBAF59A1E2E5540CC5EB69DB6444C40F77475C762305540CC5EB69DB6444C40F77475C762305540736891ED7C414C402CBAF59A1E2E5540736891ED7C414C40
49559	Губино	5	54	52	84.615020999999999	84.641997000000003	56.596648999999999	56.581636000000003	0103000020E610000001000000050000009B560A815C2755409016670C734A4C409B560A815C275540761893FE5E4C4C4054C8957A16295540761893FE5E4C4C4054C8957A162955409016670C734A4C409B560A815C2755409016670C734A4C40
52199	Гарь	5	54	52	85.256704999999997	85.280708000000004	57.102131999999997	57.092945	0103000020E610000001000000050000000FEECEDA6D505540D2A92B9FE58B4C400FEECEDA6D50554002F04FA9128D4C4070EEAF1EF751554002F04FA9128D4C4070EEAF1EF7515540D2A92B9FE58B4C400FEECEDA6D505540D2A92B9FE58B4C40
47537	Вороново	5	54	52	85.216892000000001	85.221877000000006	56.344076999999999	56.339416999999997	0103000020E61000000100000005000000E6B0FB8EE14D55406C5A2904722B4C40E6B0FB8EE14D5540242713B70A2C4C4004AF963B334E5540242713B70A2C4C4004AF963B334E55406C5A2904722B4C40E6B0FB8EE14D55406C5A2904722B4C40
46520	Воронино	5	54	52	85.239564999999999	85.278345999999999	56.561056000000001	56.54851	0103000020E610000001000000050000000A117008554F5540B5C35F9335464C400A117008554F5540BF9CD9AED0474C403CBEBD6BD0515540BF9CD9AED0474C403CBEBD6BD0515540B5C35F9335464C400A117008554F5540B5C35F9335464C40
46120	Вершинино	5	54	52	84.912622999999996	84.947945000000004	56.245869999999996	56.212665000000001	0103000020E61000000100000005000000F4A44C6A683A55407E00529B381B4C40F4A44C6A683A5540A4880CAB781F4C40085A8121AB3C5540A4880CAB781F4C40085A8121AB3C55407E00529B381B4C40F4A44C6A683A55407E00529B381B4C40
29676	Верхнее Сеченово	5	54	52	84.333138000000005	84.361327000000003	56.437173999999999	56.424232000000003	0103000020E6100000010000000500000083C30B225215554056F5F23B4D364C4083C30B2252155540AC545051F5374C405B0A48FB1F175540AC545051F5374C405B0A48FB1F17554056F5F23B4D364C4083C30B225215554056F5F23B4D364C40
726	Борики	5	54	52	84.778343000000007	84.788332999999994	56.561706000000001	56.555306999999999	0103000020E610000001000000050000008484285FD0315540B41EBE4C14474C408484285FD0315540C6FB71FBE5474C40E256410C74325540C6FB71FBE5474C40E256410C74325540B41EBE4C14474C408484285FD0315540B41EBE4C14474C40
30286	Бол. Протопопово	5	54	52	85.175083999999998	85.207603000000006	56.422987999999997	56.412063000000003	0103000020E6100000010000000500000062838593344B55402272FA7ABE344C4062838593344B5540DB4C857824364C404CE3175E494D5540DB4C857824364C404CE3175E494D55402272FA7ABE344C4062838593344B55402272FA7ABE344C40
5981	Богашево	5	54	52	85.110557999999997	85.192735999999996	56.377541999999998	56.350257999999997	0103000020E61000000100000005000000EA93DC6113475540C8940F41D52C4C40EA93DC6113475540E76ED74B53304C40C23060C9554C5540E76ED74B53304C40C23060C9554C5540C8940F41D52C4C40EA93DC6113475540C8940F41D52C4C40
45548	Берёзкино	5	54	52	84.617168000000007	84.638709000000006	56.489074000000002	56.480882999999999	0103000020E61000000100000005000000D10836AE7F275540E719FB928D3D4C40D10836AE7F27554076A911FA993E4C404CAAB69BE028554076A911FA993E4C404CAAB69BE0285540E719FB928D3D4C40D10836AE7F275540E719FB928D3D4C40
46002	Белоусово	5	54	52	85.177941000000004	85.190929999999994	56.315914999999997	56.299999999999997	0103000020E6100000010000000500000086E7A562634B55406666666666264C4086E7A562634B55406DA818E76F284C40D1747632384C55406DA818E76F284C40D1747632384C55406666666666264C4086E7A562634B55406666666666264C40
23476	Батурино	5	54	52	84.960513000000006	84.982764000000003	56.270681000000003	56.253252000000003	0103000020E610000001000000050000008198840B793D5540C4D2C08F6A204C408198840B793D55400553CDACA5224C40EAEBF99AE53E55400553CDACA5224C40EAEBF99AE53E5540C4D2C08F6A204C408198840B793D5540C4D2C08F6A204C40
31608	Аркашево	5	54	52	85.259435999999994	85.269936999999999	56.445672999999999	56.439014999999998	0103000020E61000000100000005000000ECD973999A5055400ABABDA431384C40ECD973999A505540E8DA17D00B394C40BEBED6A546515540E8DA17D00B394C40BEBED6A5465155400ABABDA431384C40ECD973999A5055400ABABDA431384C40
31232	Александровское	5	54	52	85.371474000000006	85.401072999999997	56.752791999999999	56.732379999999999	0103000020E610000001000000050000001E54E23AC65755404B1FBAA0BE5D4C401E54E23AC65755406058FE7C5B604C40C093162EAB5955406058FE7C5B604C40C093162EAB5955404B1FBAA0BE5D4C401E54E23AC65755404B1FBAA0BE5D4C40
60348	86-й Квартал	5	54	52	84.545383000000001	84.567581000000004	56.376685000000002	56.36842	0103000020E61000000100000005000000D732198EE72255409E98F562282F4C40D732198EE722554067F2CD3637304C402F35423F5324554067F2CD3637304C402F35423F532455409E98F562282F4C40D732198EE72255409E98F562282F4C40
28892	Четь-Конторка	5	54	1384	88.113213000000002	88.124891000000005	57.063827000000003	57.057181	0103000020E61000000100000005000000DA1EBDE13E075640EE79FEB451874C40DA1EBDE13E07564008CDAE7B2B884C402524D236FE07564008CDAE7B2B884C402524D236FE075640EE79FEB451874C40DA1EBDE13E075640EE79FEB451874C40
60326	Черный Яр	5	54	1384	87.304351999999994	87.327510000000004	57.051482999999998	57.039653000000001	0103000020E61000000100000005000000389ECF807AD355401A18795913854C40389ECF807AD3554065A6B4FE96864C403BC780ECF5D4554065A6B4FE96864C403BC780ECF5D455401A18795913854C40389ECF807AD355401A18795913854C40
28911	Центрополигон	5	54	1384	88.269924000000003	88.313869999999994	57.434522000000001	57.416010999999997	0103000020E61000000100000005000000F419506F461156405CE333D93FB54C40F419506F461156403EB2B96A9EB74C40834C3272161456403EB2B96A9EB74C40834C3272161456405CE333D93FB54C40F419506F461156405CE333D93FB54C40
28977	Тегульдет	5	54	1384	88.125196000000003	88.204427999999993	57.316741	57.294814000000002	0103000020E61000000100000005000000C36515360308564094331477BCA54C40C365153603085640B32616F88AA84C40BF982D59150D5640B32616F88AA84C40BF982D59150D564094331477BCA54C40C36515360308564094331477BCA54C40
28778	Покровский Яр	5	54	1384	88.274963999999997	88.284548999999998	57.081035	57.075071999999999	0103000020E61000000100000005000000F3E49A0299115640336C94F59B894C40F3E49A02991156406A6AD95A5F8A4C400247020D361256406A6AD95A5F8A4C400247020D36125640336C94F59B894C40F3E49A0299115640336C94F59B894C40
15157	Озерное	5	54	1384	88.634883000000002	88.640803000000005	57.477227999999997	57.474299999999999	0103000020E6100000010000000500000054724EECA1285640143FC6DCB5BC4C4054724EECA1285640245E9ECE15BD4C40700B96EA02295640245E9ECE15BD4C40700B96EA02295640143FC6DCB5BC4C4054724EECA1285640143FC6DCB5BC4C40
52803	Новошумилово	5	54	1384	88.499893	88.515891999999994	57.423766000000001	57.419049999999999	0103000020E61000000100000005000000F59F353FFE1F5640C4B12E6EA3B54C40F59F353FFE1F56401094DBF63DB64C402711E15F042156401094DBF63DB64C402711E15F04215640C4B12E6EA3B54C40F59F353FFE1F5640C4B12E6EA3B54C40
52781	Куяновская Гарь	5	54	1384	88.347843999999995	88.363878999999997	57.351457000000003	57.346513000000002	0103000020E6100000010000000500000007077B1343165640C651B9895AAC4C4007077B1343165640A379008BFCAC4C40E02C25CB49175640A379008BFCAC4C40E02C25CB49175640C651B9895AAC4C4007077B1343165640C651B9895AAC4C40
47501	Красный Яр	5	54	1384	87.610838999999999	87.623407	57.231907	57.226913000000003	0103000020E61000000100000005000000C40776FC17E75540C504357C0B9D4C40C40776FC17E75540535BEA20AF9D4C403D4679E6E5E75540535BEA20AF9D4C403D4679E6E5E75540C504357C0B9D4C40C40776FC17E75540C504357C0B9D4C40
52797	Красная Горка	5	54	1384	87.220457999999994	87.250174999999999	57.111477999999998	57.099369000000003	0103000020E610000001000000050000000F09DFFB1BCE55403D9E961FB88C4C400F09DFFB1BCE55409B1C3EE9448E4C40B7D100DE02D055409B1C3EE9448E4C40B7D100DE02D055403D9E961FB88C4C400F09DFFB1BCE55403D9E961FB88C4C40
18749	Белый Яр	5	54	1384	88.735539000000003	88.782341000000002	57.505332000000003	57.488211	0103000020E61000000100000005000000AF7B2B12132F56401346B3B27DBE4C40AF7B2B12132F5640A7CF0EB8AEC04C407A54FCDF11325640A7CF0EB8AEC04C407A54FCDF113256401346B3B27DBE4C40AF7B2B12132F56401346B3B27DBE4C40
52773	Байгалы	5	54	1384	87.875698	87.894276000000005	57.246529000000002	57.241498	0103000020E610000001000000050000000CCB9F6F0BF8554053060E68E99E4C400CCB9F6F0BF85540FF4124438E9F4C40416667D13BF95540FF4124438E9F4C40416667D13BF9554053060E68E99E4C400CCB9F6F0BF8554053060E68E99E4C40
52709	Францево	5	54	1813	86.401966999999999	86.414139000000006	57.565278999999997	57.557313000000001	0103000020E610000001000000050000008FC4CBD3B99955405D514A0856C74C408FC4CBD3B9995540CB0EF10F5BC84C40E23FDD40819A5540CB0EF10F5BC84C40E23FDD40819A55405D514A0856C74C408FC4CBD3B99955405D514A0856C74C40
52728	Успенка	5	54	1813	86.124872999999994	86.169483	57.145592000000001	57.129553000000001	0103000020E61000000100000005000000D1C952EBFD875540A20C553195904C40D1C952EBFD875540954737C2A2924C40978E39CFD88A5540954737C2A2924C40978E39CFD88A5540A20C553195904C40D1C952EBFD875540A20C553195904C40
52691	Улу-Юл	5	54	1813	85.777664999999999	85.802665000000005	57.718483999999997	57.701867	0103000020E610000001000000050000009B8F6B43C5715540219221C7D6D94C409B8F6B43C57155408159A148F7DB4C40352905DD5E7355408159A148F7DB4C40352905DD5E735540219221C7D6D94C409B8F6B43C5715540219221C7D6D94C40
60354	Уйданово	5	54	1813	86.540756999999999	86.557744	56.938173999999997	56.929383000000001	0103000020E6100000010000000500000051853FC39BA25540AC3AAB05F6764C4051853FC39BA255408FFAEB1516784C4093E2E313B2A355408FFAEB1516784C4093E2E313B2A35540AC3AAB05F6764C4051853FC39BA25540AC3AAB05F6764C40
52720	Узень	5	54	1813	86.178259999999995	86.233137999999997	57.304893999999997	57.295544	0103000020E61000000100000005000000D68BA19C688B5540B743C362D4A54C40D68BA19C688B5540915F3FC406A74C401C5DA5BBEB8E5540915F3FC406A74C401C5DA5BBEB8E5540B743C362D4A54C40D68BA19C688B5540B743C362D4A54C40
52757	Туендат	5	54	1813	86.380128999999997	86.414876000000007	57.138565	57.124192999999998	0103000020E61000000100000005000000B7D095085498554031B2648EE58F4C40B7D095085498554064AF777FBC914C404DF910548D9A554064AF777FBC914C404DF910548D9A554031B2648EE58F4C40B7D095085498554031B2648EE58F4C40
60356	Торбеево	5	54	1813	86.335635999999994	86.352677	57.034348999999999	57.017541000000001	0103000020E610000001000000050000000ED76A0F7B95554069AB92C83E824C400ED76A0F7B9555403DD34B8C65844C404A438D42929655403DD34B8C65844C404A438D429296554069AB92C83E824C400ED76A0F7B95554069AB92C83E824C40
60313	Сергеево	5	54	1813	86.056421	86.102406000000002	57.283617	57.264927	0103000020E61000000100000005000000B073D3669C835540E869C020E9A14C40B073D3669C83554079CBD58F4DA44C40823AE5D18D86554079CBD58F4DA44C40823AE5D18D865540E869C020E9A14C40B073D3669C835540E869C020E9A14C40
52717	Сахалинка	5	54	1813	86.036666999999994	86.067595999999995	57.317582000000002	57.304932999999998	0103000020E61000000100000005000000EA758BC0588255404F3C670B08A74C40EA758BC0588255402EE6E786A6A84C40C9552C7E538455402EE6E786A6A84C40C9552C7E538455404F3C670B08A74C40EA758BC0588255404F3C670B08A74C40
52732	Первомайское	5	54	1813	86.207274999999996	86.262387000000004	57.090738999999999	57.064689000000001	0103000020E61000000100000005000000D1915CFE438D55409AB4A9BA47884C40D1915CFE438D554062BCE6559D8B4C4051F9D7F2CA90554062BCE6559D8B4C4051F9D7F2CA9055409AB4A9BA47884C40D1915CFE438D55409AB4A9BA47884C40
60309	Орехово	5	54	1813	86.674470999999997	86.697226000000001	57.227950999999997	57.215071999999999	0103000020E610000001000000050000006DC669882AAB55408524B37A879B4C406DC669882AAB5540950B957F2D9D4C40F0FACC599FAC5540950B957F2D9D4C40F0FACC599FAC55408524B37A879B4C406DC669882AAB55408524B37A879B4C40
60321	Новый	5	54	1813	86.186075000000002	86.204561999999996	57.111409999999999	57.106003999999999	0103000020E610000001000000050000009BE61DA7E88B5540629F008A918D4C409BE61DA7E88B55404339D1AE428E4C404700378B178D55404339D1AE428E4C404700378B178D5540629F008A918D4C409BE61DA7E88B5540629F008A918D4C40
60362	Новомариинка	5	54	1813	86.485923999999997	86.527291000000005	57.139131999999996	57.134779999999999	0103000020E61000000100000005000000DB15FA60199F5540D313967840914C40DB15FA60199F5540DDE9CE13CF914C40691EC022BFA15540DDE9CE13CF914C40691EC022BFA15540D313967840914C40DB15FA60199F5540D313967840914C40
60350	Малиновка	5	54	1813	86.814841999999999	86.833545000000001	57.026178999999999	57.014949000000001	0103000020E61000000100000005000000105A0F5F26B45540D00D4DD9E9814C40105A0F5F26B45540C66B5ED559834C40A3AF20CD58B55540C66B5ED559834C40A3AF20CD58B55540D00D4DD9E9814C40105A0F5F26B45540D00D4DD9E9814C40
60347	Ломовицк 2	5	54	1813	86.295005000000003	86.318325000000002	57.136229999999998	57.122067999999999	0103000020E6100000010000000500000004CAA65CE1925540AEF199EC9F8F4C4004CAA65CE1925540F65D11FC6F914C40F31FD26F5F945540F65D11FC6F914C40F31FD26F5F945540AEF199EC9F8F4C4004CAA65CE1925540AEF199EC9F8F4C40
60345	Куяново	5	54	1813	86.458461999999997	86.472448999999997	56.955558000000003	56.941060999999998	0103000020E610000001000000050000005C1D0071579D55404145D5AF74784C405C1D0071579D554031B77BB94F7A4C40C901BB9A3C9E554031B77BB94F7A4C40C901BB9A3C9E55404145D5AF74784C405C1D0071579D55404145D5AF74784C40
52748	Крутоложное	5	54	1813	86.313734999999994	86.34178	57.047291999999999	57.037063000000003	0103000020E610000001000000050000001327F73B149455402272FA7ABE844C401327F73B1494554064AE0CAA0D864C40529B38B9DF95554064AE0CAA0D864C40529B38B9DF9555402272FA7ABE844C401327F73B149455402272FA7ABE844C40
27416	Комсомольск	5	54	1813	85.984358	86.038931000000005	57.418259999999997	57.398474	0103000020E610000001000000050000009563B2B8FF7E554035272F3201B34C409563B2B8FF7E5540CB9C2E8B89B54C403DF372D87D825540CB9C2E8B89B54C403DF372D87D82554035272F3201B34C409563B2B8FF7E554035272F3201B34C40
60351	Калмаки	5	54	1813	86.419943000000004	86.437513999999993	56.991905000000003	56.985481	0103000020E61000000100000005000000C9CB9A58E09A554029EACC3D247E4C40C9CB9A58E09A554094DE37BEF67E4C40B262B83A009C554094DE37BEF67E4C40B262B83A009C554029EACC3D247E4C40C9CB9A58E09A554029EACC3D247E4C40
46332	Заречный	5	54	1813	86.167462	86.183605	57.182983	57.177537999999998	0103000020E61000000100000005000000A85489B2B78A55400CE6AF90B9964C40A85489B2B78A5540AB5CA8FC6B974C4074982F2FC08B5540AB5CA8FC6B974C4074982F2FC08B55400CE6AF90B9964C40A85489B2B78A55400CE6AF90B9964C40
60357	Ежи	5	54	1813	86.105254000000002	86.125564999999995	57.166989000000001	57.150319000000003	0103000020E610000001000000050000007CF1457BBC865540D57B2AA73D934C407CF1457BBC86554058E542E55F954C406C21C8410988554058E542E55F954C406C21C84109885540D57B2AA73D934C407CF1457BBC865540D57B2AA73D934C40
60343	Вознесенка	5	54	1813	86.058190999999994	86.088140999999993	57.207380000000001	57.198169999999998	0103000020E61000000100000005000000FA7ABE66B98355402F8672A25D994C40FA7ABE66B983554018EC866D8B9A4C40F31B261AA485554018EC866D8B9A4C40F31B261AA48555402F8672A25D994C40FA7ABE66B98355402F8672A25D994C40
60368	Берёзовка	5	54	1813	86.740138000000002	86.768362999999994	57.013185	56.993851999999997	0103000020E61000000100000005000000B821C66B5EAF55403788D68A367F4C40B821C66B5EAF55401DE6CB0BB0814C40361D01DC2CB155401DE6CB0BB0814C40361D01DC2CB155403788D68A367F4C40B821C66B5EAF55403788D68A367F4C40
60312	Беляй	5	54	1813	86.243144999999998	86.277101000000002	57.057391000000003	57.045495000000003	0103000020E61000000100000005000000E6CB0BB08F8F5540D690B8C7D2854C40E6CB0BB08F8F5540D90A9A9658874C40172CD505BC915540D90A9A9658874C40172CD505BC915540D690B8C7D2854C40E6CB0BB08F8F5540D690B8C7D2854C40
52704	Балагачёво	5	54	1813	86.037979000000007	86.066194999999993	57.421013000000002	57.411566000000001	0103000020E61000000100000005000000D4BB783F6E825540A112D731AEB44C40D4BB783F6E8255406E1805C1E3B54C40280AF4893C8455406E1805C1E3B54C40280AF4893C845540A112D731AEB44C40D4BB783F6E825540A112D731AEB44C40
60355	Альмяково	5	54	1813	85.680421999999993	85.703526999999994	57.626278999999997	57.601196000000002	0103000020E61000000100000005000000A65EB7088C6B5540363E93FDF3CC4C40A65EB7088C6B5540F69507E929D04C4097361C96066D5540F69507E929D04C4097361C96066D5540363E93FDF3CC4C40A65EB7088C6B5540363E93FDF3CC4C40
60307	Шпалозавод	5	54	7205	81.037974000000006	82.092631999999995	59.204481000000001	58.659253999999997	0103000020E610000001000000050000004B06802A6E425440EBE0606F62544D404B06802A6E425440A2D3F36E2C9A4D4009A4C4AEED855440A2D3F36E2C9A4D4009A4C4AEED855440EBE0606F62544D404B06802A6E425440EBE0606F62544D40
52675	Усть-Чузик	5	54	7205	80.063912999999999	81.118571000000003	58.328153	57.768988999999998	0103000020E6100000010000000500000083328D2617045440EBFD463B6EE24C4083328D2617045440CA8AE1EA002A4D4042D0D1AA96475440CA8AE1EA002A4D4042D0D1AA96475440EBFD463B6EE24C4083328D2617045440EBFD463B6EE24C40
60323	Толмачево	5	54	7205	80.905383	81.960041000000004	58.981596000000003	58.432811999999998	0103000020E61000000100000005000000AED689CBF13954407EA8346266374D40AED689CBF139544035F10EF0A47D4D406D74CE4F717D544035F10EF0A47D4D406D74CE4F717D54407EA8346266374D40AED689CBF13954407EA8346266374D40
52671	Тарск	5	54	7205	80.064991000000006	81.119648999999995	58.565317	58.009911000000002	0103000020E6100000010000000500000033E202D028045440726F7EC344014D4033E202D028045440B96FB54E5C484D40F17F4754A8475440B96FB54E5C484D40F17F4754A8475440726F7EC344014D4033E202D028045440726F7EC344014D40
52667	Талиновка	5	54	7205	81.061851000000004	82.116508999999994	59.251018999999999	58.706536	0103000020E61000000100000005000000658EE55DF54354402CB98AC56F5A4D40658EE55DF54354405AD6FD6321A04D40232C2AE2748754405AD6FD6321A04D40232C2AE2748754402CB98AC56F5A4D40658EE55DF54354402CB98AC56F5A4D40
60358	Старица	5	54	7205	80.056196	81.110854000000003	58.411892000000002	57.854053	0103000020E61000000100000005000000A08A1BB7980354407D06D49B51ED4C40A08A1BB798035440F5BD86E0B8344D405F28603B18475440F5BD86E0B8344D405F28603B184754407D06D49B51ED4C40A08A1BB7980354407D06D49B51ED4C40
60334	Рогалёво	5	54	7205	79.600149000000002	79.615095999999994	57.498997000000003	57.489885000000001	0103000020E6100000010000000500000089EE59D768E6534086E63A8DB4BE4C4089EE59D768E65340ACE63922DFBF4C40A0F99CBB5DE75340ACE63922DFBF4C40A0F99CBB5DE7534086E63A8DB4BE4C4089EE59D768E6534086E63A8DB4BE4C40
52663	Прокоп	5	54	7205	80.831244999999996	81.885902999999999	58.977311	58.428457999999999	0103000020E61000000100000005000000AA7D3A1E33355440D3DA34B6D7364D40AA7D3A1E33355440B282DF86187D4D40691B7FA2B2785440B282DF86187D4D40691B7FA2B2785440D3DA34B6D7364D40AA7D3A1E33355440D3DA34B6D7364D40
52645	Парабель	5	54	7205	80.976941999999994	82.031600999999995	58.987822999999999	58.439138	0103000020E61000000100000005000000AF05BD37863E544026378AAC35384D40AF05BD37863E5440499EEBFB707E4D40566133C005825440499EEBFB707E4D40566133C00582544026378AAC35384D40AF05BD37863E544026378AAC35384D40
60322	Новосельцево	5	54	7205	81.164968999999999	82.219627000000003	58.906899000000003	58.356923999999999	0103000020E61000000100000005000000A5F622DA8E4A5440299485AFAF2D4D40A5F622DA8E4A544037E3344415744D406494675E0E8E544037E3344415744D406494675E0E8E5440299485AFAF2D4D40A5F622DA8E4A5440299485AFAF2D4D40
60338	Новиково	5	54	7205	80.098381000000003	81.153039000000007	58.482382000000001	57.925660999999998	0103000020E610000001000000050000000F63D2DF4B0654406117450F7CF64C400F63D2DF4B065440EC1681B1BE3D4D40CE001764CB495440EC1681B1BE3D4D40CE001764CB4954406117450F7CF64C400F63D2DF4B0654406117450F7CF64C40
52638	Нельмач	5	54	7205	80.577489	81.632147000000003	58.951922000000003	58.402664999999999	0103000020E610000001000000050000002F336C94F5245440361FD7868A334D402F336C94F5245440E52B8194D8794D40EED0B01875685440E52B8194D8794D40EED0B01875685440361FD7868A334D402F336C94F5245440361FD7868A334D40
52632	Нарым	5	54	7205	81.076081000000002	82.130739000000005	59.195362000000003	58.649988999999998	0103000020E6100000010000000500000035B6D782DE4454403FE1ECD632534D4035B6D782DE445440CA703C9F01994D40F4531C075E885440CA703C9F01994D40F4531C075E8854403FE1ECD632534D4035B6D782DE4454403FE1ECD632534D40
60366	Малое Нестерово	5	54	7205	81.050622000000004	82.105279999999993	58.932859000000001	58.383298000000003	0103000020E61000000100000005000000529D0E643D435440A54FABE80F314D40529D0E643D435440BF6378EC67774D40103B53E8BC865440BF6378EC67774D40103B53E8BC865440A54FABE80F314D40529D0E643D435440A54FABE80F314D40
60331	Лушниково	5	54	7205	79.421077999999994	79.440482000000003	57.565095999999997	57.552368999999999	0103000020E610000001000000050000002AC423F1F2DA534080290307B4C64C402AC423F1F2DA5340DA8CD31055C84C40821E6ADB30DC5340DA8CD31055C84C40821E6ADB30DC534080290307B4C64C402AC423F1F2DA534080290307B4C64C40
60327	Луговское	5	54	7205	81.111384000000001	82.166042000000004	59.170918	58.625154999999999	0103000020E610000001000000050000000D535BEA2047544027F73B1405504D400D535BEA204754401C261AA4E0954D40CCF09F6EA08A54401C261AA4E0954D40CCF09F6EA08A544027F73B1405504D400D535BEA2047544027F73B1405504D40
60300	Кирзавод	5	54	7205	80.970106000000001	82.024764000000005	58.947702999999997	58.398378000000001	0103000020E61000000100000005000000D1E97937163E544013B9E00CFE324D40D1E97937163E544019A9F7544E794D409087BEBB9581544019A9F7544E794D409087BEBB9581544013B9E00CFE324D40D1E97937163E544013B9E00CFE324D40
60340	Кедровый	5	54	7205	79.550974999999994	79.586134999999999	57.570343000000001	57.554550999999996	0103000020E61000000100000005000000787AA52C43E35340677BF486FBC64C40787AA52C43E353405340DAFF00C94C409F02603C83E553405340DAFF00C94C409F02603C83E55340677BF486FBC64C40787AA52C43E35340677BF486FBC64C40
60337	Заводской	5	54	7205	80.790290999999996	81.844949	58.946227	58.396878999999998	0103000020E61000000100000005000000AED4B320943254400EBC5AEECC324D40AED4B32094325440CDCB61F71D794D406D72F8A413765440CDCB61F71D794D406D72F8A4137654400EBC5AEECC324D40AED4B320943254400EBC5AEECC324D40
52684	Верхняя Чигара	5	54	7205	81.289026000000007	82.343683999999996	58.839615999999999	58.28857	0103000020E61000000100000005000000666CE8667F525440A94D9CDCEF244D40666CE8667F52544063997E89786B4D40240A2DEBFE95544063997E89786B4D40240A2DEBFE955440A94D9CDCEF244D40666CE8667F525440A94D9CDCEF244D40
60316	Алатаево	5	54	7205	81.229647999999997	82.284306000000001	59.102525999999997	58.555669999999999	0103000020E61000000100000005000000E065868DB24E544025AFCE3120474D40E065868DB24E5440AE7E6C921F8D4D409F03CB1132925440AE7E6C921F8D4D409F03CB113292544025AFCE3120474D40E065868DB24E544025AFCE3120474D40
25289	Фёдоровка (Нижняя Фёдоровка)	5	54	807	83.848892000000006	83.859572999999997	57.707670999999998	57.698092000000003	0103000020E6100000010000000500000082751C3F54F65440B4CC22145BD94C4082751C3F54F65440EFA99CF694DA4C4093E1783E03F75440EFA99CF694DA4C4093E1783E03F75440B4CC22145BD94C4082751C3F54F65440B4CC22145BD94C40
25534	Тунгусово	5	54	807	83.472318999999999	83.513012000000003	57.631107999999998	57.609138000000002	0103000020E61000000100000005000000E29178793ADE54401C60E63BF8CD4C40E29178793ADE54403A1F9E25C8D04C40289D4830D5E054403A1F9E25C8D04C40289D4830D5E054401C60E63BF8CD4C40E29178793ADE54401C60E63BF8CD4C40
5854	Сулзат	5	54	807	83.900069000000002	83.933611999999997	57.799748999999998	57.781635000000001	0103000020E610000001000000050000002EC901BB9AF9544059349D9D0CE44C402EC901BB9AF954401D01DC2C5EE64C40CDC98B4CC0FB54401D01DC2C5EE64C40CDC98B4CC0FB544059349D9D0CE44C402EC901BB9AF9544059349D9D0CE44C40
26064	Суйга	5	54	807	84.712254000000001	84.743803	57.875897999999999	57.861044	0103000020E610000001000000050000007E1CCD91952D5540613596B036EE4C407E1CCD91952D5540DF50F86C1DF04C40ABEAE5779A2F5540DF50F86C1DF04C40ABEAE5779A2F5540613596B036EE4C407E1CCD91952D5540613596B036EE4C40
48367	Соколовка	5	54	807	83.811746999999997	83.848676999999995	57.502107000000002	57.487369000000001	0103000020E610000001000000050000001268B0A9F3F35440C80A7E1B62BE4C401268B0A9F3F35440DD0BCC0A45C04C4083F755B950F65440DD0BCC0A45C04C4083F755B950F65440C80A7E1B62BE4C401268B0A9F3F35440C80A7E1B62BE4C40
5723	Сарафановка	5	54	807	83.438676999999998	83.464342000000002	57.718493000000002	57.706940000000003	0103000020E610000001000000050000007920B24813DC5440FC1D8A027DDA4C407920B24813DC5440D5B32094F7DB4C40310A82C7B7DD5440D5B32094F7DB4C40310A82C7B7DD5440FC1D8A027DDA4C407920B24813DC5440FC1D8A027DDA4C40
52394	Сайга	5	54	807	85.358502000000001	85.490302999999997	58.064487	57.994568999999998	0103000020E610000001000000050000003D635FB2F1565540C64E78094EFF4C403D635FB2F156554032022A1C41084D405D88D51F615F554032022A1C41084D405D88D51F615F5540C64E78094EFF4C403D635FB2F1565540C64E78094EFF4C40
25683	Нарга (Новостройка)	5	54	807	83.524114999999995	83.577968999999996	57.702319000000003	57.674916000000003	0103000020E61000000100000005000000F415A4198BE1544009C6C1A563D64C40F415A4198BE15440022EC896E5D94C408446B071FDE45440022EC896E5D94C408446B071FDE4544009C6C1A563D64C40F415A4198BE1544009C6C1A563D64C40
24957	Молчаново	5	54	807	83.734474000000006	83.80386	57.609278000000003	57.568266999999999	0103000020E61000000100000005000000CA703C9F01EF5440B1321AF9BCC84C40CA703C9F01EF54400E164ED2FCCD4C4001A4367172F354400E164ED2FCCD4C4001A4367172F35440B1321AF9BCC84C40CA703C9F01EF5440B1321AF9BCC84C40
60311	Могочин	5	54	807	83.541004000000001	83.608340999999996	57.723103000000002	57.704031000000001	0103000020E6100000010000000500000055C03DCF9FE25440622F14B01DDA4C4055C03DCF9FE25440DB519CA38EDC4C4038F4160FEFE65440DB519CA38EDC4C4038F4160FEFE65440622F14B01DDA4C4055C03DCF9FE25440622F14B01DDA4C40
48362	Майково	5	54	807	83.628373999999994	83.647463000000002	57.641750999999999	57.632928999999997	0103000020E6100000010000000500000007EA944737E8544051D845D103D14C4007EA944737E85440709692E524D24C40AF97A60870E95440709692E524D24C40AF97A60870E9544051D845D103D14C4007EA944737E8544051D845D103D14C40
48088	Колбинка	5	54	807	83.408582999999993	83.439493999999996	57.519627	57.506284999999998	0103000020E61000000100000005000000E6AC4F3926DA544049BA66F2CDC04C40E6AC4F3926DA54402E8F352383C24C40723271AB20DC54402E8F352383C24C40723271AB20DC544049BA66F2CDC04C40E6AC4F3926DA544049BA66F2CDC04C40
5797	Игреково	5	54	807	83.770370999999997	83.822687999999999	57.756804000000002	57.727020000000003	0103000020E610000001000000050000005BB22AC24DF15440DBC4C9FD0EDD4C405BB22AC24DF15440B2BD16F4DEE04C40F2B391EBA6F45440B2BD16F4DEE04C40F2B391EBA6F45440DBC4C9FD0EDD4C405BB22AC24DF15440DBC4C9FD0EDD4C40
48388	Гришино	5	54	807	83.595972000000003	83.613641999999999	57.542482	57.525016000000001	0103000020E610000001000000050000003B55BE6724E6544039F06AB933C34C403B55BE6724E654409755D80C70C54C40EE5C18E945E754409755D80C70C54C40EE5C18E945E7544039F06AB933C34C403B55BE6724E6544039F06AB933C34C40
25592	Верхняя Фёдоровка	5	54	807	83.546689999999998	83.571995999999999	57.630279000000002	57.620837999999999	0103000020E6100000010000000500000037C30DF8FCE25440990E9D9E77CF4C4037C30DF8FCE25440842D76FBACD04C40575C1C959BE45440842D76FBACD04C40575C1C959BE45440990E9D9E77CF4C4037C30DF8FCE25440990E9D9E77CF4C40
24463	Рыбалово	5	54	765	84.000878	84.021512999999999	57.142384	57.130803	0103000020E610000001000000050000004C5299620E005540FE9B1727BE904C404C5299620E005540A1BC8FA339924C4016DC0F7860015540A1BC8FA339924C4016DC0F7860015540FE9B1727BE904C404C5299620E005540FE9B1727BE904C40
24089	Пудовка	5	54	765	83.672471999999999	83.697148999999996	57.239136000000002	57.225223	0103000020E6100000010000000500000072DEFFC709EB54404CA7751BD49C4C4072DEFFC709EB5440ECA529029C9E4C401ADCD6169EEC5440ECA529029C9E4C401ADCD6169EEC54404CA7751BD49C4C4072DEFFC709EB54404CA7751BD49C4C40
24507	Петровка	5	54	765	83.908585000000002	83.949045999999996	57.195937000000001	57.186484999999998	0103000020E61000000100000005000000B728B34126FA5440E71890BDDE974C40B728B34126FA5440C689AF7614994C4093196F2BBDFC5440C689AF7614994C4093196F2BBDFC5440E71890BDDE974C40B728B34126FA5440E71890BDDE974C40
24319	Новониколаевка	5	54	765	83.886424000000005	83.913220999999993	57.124760000000002	57.116444000000001	0103000020E61000000100000005000000EE98BA2BBBF8544060E811A3E78E4C40EE98BA2BBBF85440ABECBB22F88F4C404E417E3672FA5440ABECBB22F88F4C404E417E3672FA544060E811A3E78E4C40EE98BA2BBBF8544060E811A3E78E4C40
24057	Новокривошеино	5	54	765	83.783899000000005	83.803509000000005	57.321401999999999	57.308588999999998	0103000020E610000001000000050000007F17B6662BF25440E27327D87FA74C407F17B6662BF254403B6F63B323A94C40AB4203B16CF354403B6F63B323A94C40AB4203B16CF35440E27327D87FA74C407F17B6662BF25440E27327D87FA74C40
5563	Новоисламбуль (Чёрная Речка)	5	54	765	83.778751999999997	83.804874999999996	57.414217000000001	57.403396000000001	0103000020E6100000010000000500000074ECA012D7F154402AABE97AA2B34C4074ECA012D7F154403F390A1005B54C408D976E1283F354403F390A1005B54C408D976E1283F354402AABE97AA2B34C4074ECA012D7F154402AABE97AA2B34C40
24663	Никольское	5	54	765	84.354392000000004	84.372826000000003	57.203470000000003	57.184817000000002	0103000020E61000000100000005000000B37DC85BAE165540575F5D15A8974C40B37DC85BAE165540CBDB114E0B9A4C404E469561DC175540CBDB114E0B9A4C404E469561DC175540575F5D15A8974C40B37DC85BAE165540575F5D15A8974C40
24171	Малиновка	5	54	765	83.472937999999999	83.499178000000001	57.373868999999999	57.356152000000002	0103000020E6100000010000000500000048C2BE9D44DE5440D733846396AD4C4048C2BE9D44DE54407EFE7BF0DAAF4C407E384888F2DF54407EFE7BF0DAAF4C407E384888F2DF5440D733846396AD4C4048C2BE9D44DE5440D733846396AD4C40
23689	Кривошеино	5	54	765	83.897706999999997	83.947778999999997	57.360492000000001	57.323064000000002	0103000020E61000000100000005000000FA980F0874F95440EA4141295AA94C40FA980F0874F954401D3C139A24AE4C407A354069A8FC54401D3C139A24AE4C407A354069A8FC5440EA4141295AA94C40FA980F0874F95440EA4141295AA94C40
24784	Красный Яр	5	54	765	84.482223000000005	84.550863000000007	57.167003000000001	57.112352999999999	0103000020E610000001000000050000004298DBBDDC1E5540C24D4695618E4C404298DBBDDC1E5540BDAAB35A60954C40E564E25641235540BDAAB35A60954C40E564E25641235540C24D4695618E4C404298DBBDDC1E5540C24D4695618E4C40
24698	Карнаухово	5	54	765	84.391565	84.401499999999999	57.074362999999998	57.058174999999999	0103000020E610000001000000050000008750A5660F195540EF38454772874C408750A5660F19554027840EBA84894C4004560E2DB219554027840EBA84894C4004560E2DB2195540EF38454772874C408750A5660F195540EF38454772874C40
24400	Иштан	5	54	765	84.116590000000002	84.134844000000001	57.169297	57.149298000000002	0103000020E610000001000000050000009A42E73576075540DAAD65321C934C409A42E73576075540CC272B86AB954C40F583BA48A1085540CC272B86AB954C40F583BA48A1085540DAAD65321C934C409A42E73576075540DAAD65321C934C40
5530	Жуково	5	54	765	83.931295000000006	83.948183	57.409951	57.392242000000003	0103000020E610000001000000050000006AFB57569AFB54400F0F61FC34B24C406AFB57569AFB544033FB3C4679B44C40E2E7BF07AFFC544033FB3C4679B44C40E2E7BF07AFFC54400F0F61FC34B24C406AFB57569AFB54400F0F61FC34B24C40
24558	Елизарьево	5	54	765	83.951525000000004	83.971962000000005	57.305720999999998	57.287699000000003	0103000020E61000000100000005000000E4141DC9E5FC5440C40B2252D3A44C40E4141DC9E5FC5440A759A0DD21A74C401BBD1AA034FE5440A759A0DD21A74C401BBD1AA034FE5440C40B2252D3A44C40E4141DC9E5FC5440C40B2252D3A44C40
24606	Егорово	5	54	765	84.043530000000004	84.060948999999994	57.187455999999997	57.180889999999998	0103000020E6100000010000000500000046990D32C902554033164D6727974C4046990D32C902554030B8E68EFE974C40546EA296E603554030B8E68EFE974C40546EA296E603554033164D6727974C4046990D32C902554033164D6727974C40
24180	Володино	5	54	765	83.883289000000005	83.913777999999994	57.107460000000003	57.085824000000002	0103000020E61000000100000005000000A9FA95CE87F85440209BE447FC8A4C40A9FA95CE87F8544068D0D03FC18D4C407973B8567BFA544068D0D03FC18D4C407973B8567BFA5440209BE447FC8A4C40A9FA95CE87F85440209BE447FC8A4C40
24947	Вознесенка	5	54	765	83.618465	83.645010999999997	57.085867999999998	57.079172	0103000020E610000001000000050000001F2E39EE94E754402461DF4E228A4C401F2E39EE94E75440EFE2FDB8FD8A4C40DBA337DC47E95440EFE2FDB8FD8A4C40DBA337DC47E954402461DF4E228A4C401F2E39EE94E754402461DF4E228A4C40
24348	Белосток	5	54	765	83.648495999999994	83.666704999999993	57.179845999999998	57.168975000000003	0103000020E610000001000000050000008EE55DF580E95440BA6B09F9A0954C408EE55DF580E954408028983105974C4019C5724BABEA54408028983105974C4019C5724BABEA5440BA6B09F9A0954C408EE55DF580E95440BA6B09F9A0954C40
52297	Юдино	5	54	7144	83.288073999999995	84.342731999999998	58.719158999999998	58.166196999999997	0103000020E61000000100000005000000FC34EECD6FD25440BED87BF145154D40FC34EECD6FD25440E1CFF0660D5C4D40BBD23252EF155540E1CFF0660D5C4D40BBD23252EF155540BED87BF145154D40FC34EECD6FD25440BED87BF145154D40
52289	Чугунка	5	54	7144	82.557114999999996	83.611772999999999	58.557797000000001	58.002271999999998	0103000020E610000001000000050000001B47ACC5A7A3544027D9EA724A004D401B47ACC5A7A35440496760E465474D40DAE4F04927E75440496760E465474D40DAE4F04927E7544027D9EA724A004D401B47ACC5A7A3544027D9EA724A004D40
52271	Чажемто	5	54	7144	82.299145999999993	83.353803999999997	58.336950999999999	57.777925000000003	0103000020E61000000100000005000000ABAE433525935440D3DEE00B93E34C40ABAE43352593544060ADDA35212B4D406A4C88B9A4D6544060ADDA35212B4D406A4C88B9A4D65440D3DEE00B93E34C40ABAE433525935440D3DEE00B93E34C40
52282	Усть-Чая	5	54	7144	82.110732999999996	83.165391	58.545738999999998	57.990023000000001	0103000020E61000000100000005000000A165DD3F16875440D7A4DB12B9FE4C40A165DD3F168754406C938AC6DA454D40600322C495CA54406C938AC6DA454D40600322C495CA5440D7A4DB12B9FE4C40A165DD3F16875440D7A4DB12B9FE4C40
52253	Тогур	5	54	7144	82.319564	83.374223000000001	58.635292999999997	58.080998000000001	0103000020E61000000100000005000000A73E90BC739454404D8578245E0A4D40A73E90BC739454405930F14751514D404E9A0645F3D754405930F14751514D404E9A0645F3D754404D8578245E0A4D40A73E90BC739454404D8578245E0A4D40
52286	Тискино	5	54	7144	82.666027	83.720685000000003	58.360069000000003	57.801409	0103000020E6100000010000000500000031D0B52FA0AA54402BDCF29194E64C4031D0B52FA0AA5440D7A6B1BD162E4D40F06DFAB31FEE5440D7A6B1BD162E4D40F06DFAB31FEE54402BDCF29194E64C4031D0B52FA0AA54402BDCF29194E64C40
52276	Старокороткино	5	54	7144	82.906621999999999	83.038422999999995	58.068072000000001	57.998161000000003	0103000020E6100000010000000500000062F5471806BA5440439259BDC3FF4C4062F5471806BA5440FCE25295B6084D40821ABE8575C25440FCE25295B6084D40821ABE8575C25440439259BDC3FF4C4062F5471806BA5440439259BDC3FF4C40
52267	Север	5	54	7144	82.287171000000001	83.341829000000004	58.718940000000003	58.165973999999999	0103000020E6100000010000000500000004577902619254403FFED2A23E154D400457790261925440A4E4D539065C4D40C3F4BD86E0D55440A4E4D539065C4D40C3F4BD86E0D554403FFED2A23E154D4004577902619254403FFED2A23E154D40
60306	Озерное	5	54	7144	82.384459000000007	83.439116999999996	58.505113000000001	57.948751999999999	0103000020E61000000100000005000000C9E9EBF99A985440DE019EB470F94C40C9E9EBF99A98544069E4F38AA7404D408787307E1ADC544069E4F38AA7404D408787307E1ADC5440DE019EB470F94C40C9E9EBF99A985440DE019EB470F94C40
52108	Новоселово	5	54	7144	82.467786000000004	83.522445000000005	58.673470999999999	58.119782999999998	0103000020E61000000100000005000000B5E1B034F09D5440F2CEA10C550F4D40B5E1B034F09D5440F7E6374C34564D405C3D27BD6FE15440F7E6374C34564D405C3D27BD6FE15440F2CEA10C550F4D40B5E1B034F09D5440F2CEA10C550F4D40
60336	Новоильинка	5	54	7144	82.500692000000001	83.555350000000004	58.504458999999997	57.948087999999998	0103000020E610000001000000050000009B5775560BA0544072DD94F25AF94C409B5775560BA054402096CD1C92404D405AF5B9DA8AE354402096CD1C92404D405AF5B9DA8AE3544072DD94F25AF94C409B5775560BA0544072DD94F25AF94C40
52281	Новогорное	5	54	7144	82.112063000000006	83.166720999999995	58.525503	57.969465	0103000020E61000000100000005000000DE054A0A2C875440EECEDA6D17FC4C40DE054A0A2C8754409679ABAE43434D409CA38E8EABCA54409679ABAE43434D409CA38E8EABCA5440EECEDA6D17FC4C40DE054A0A2C875440EECEDA6D17FC4C40
52272	Могильный-Мыс	5	54	7144	82.293431999999996	83.348090999999997	58.398817000000001	57.840770999999997	0103000020E6100000010000000500000064E60297C79254406D3656629EEB4C4064E60297C79254405F0B7A6F0C334D400B42791F47D654405F0B7A6F0C334D400B42791F47D654406D3656629EEB4C4064E60297C79254406D3656629EEB4C40
60349	Маракса 1-я	5	54	7144	82.560986999999997	83.615645000000001	58.666269	58.112467000000002	0103000020E61000000100000005000000CB9E0436E7A354408B709351650E4D40CB9E0436E7A3544058AB764D48554D408A3C49BA66E7544058AB764D48554D408A3C49BA66E754408B709351650E4D40CB9E0436E7A354408B709351650E4D40
52302	Куржино	5	54	7144	82.034610000000001	83.089268000000004	59.175848000000002	58.630164000000001	0103000020E610000001000000050000005587DC0C37825440EB8EC536A9504D405587DC0C378254409488F02F82964D4014252191B6C554409488F02F82964D4014252191B6C55440EB8EC536A9504D405587DC0C37825440EB8EC536A9504D40
60344	Копыловка	5	54	7144	81.739783000000003	82.794441000000006	58.945442	58.396082	0103000020E61000000100000005000000C1C8CB9A586F54406344A2D0B2324D40C1C8CB9A586F5440E621533E04794D408066101FD8B25440E621533E04794D408066101FD8B254406344A2D0B2324D40C1C8CB9A586F54406344A2D0B2324D40
52207	Колпашево	5	54	7144	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
52305	Инкино	5	54	7144	81.607290000000006	82.661947999999995	58.754458999999997	58.202058000000001	0103000020E61000000100000005000000064CE0D6DD66544095F25A09DD194D40064CE0D6DD6654402096CD1C92604D40C4E9245B5DAA54402096CD1C92604D40C4E9245B5DAA544095F25A09DD194D40064CE0D6DD66544095F25A09DD194D40
52306	Иванкино	5	54	7144	81.903149999999997	82.957808999999997	58.716738999999997	58.163738000000002	0103000020E610000001000000050000007958A835CD795440658EE55DF5144D407958A835CD7954404562821ABE5B4D4020B41EBE4CBD54404562821ABE5B4D4020B41EBE4CBD5440658EE55DF5144D407958A835CD795440658EE55DF5144D40
52300	Дальнее	5	54	7144	82.409296999999995	83.463954999999999	58.989224	58.440561000000002	0103000020E6100000010000000500000075560BEC319A54405072874D64384D4075560BEC319A54408B355CE49E7E4D4034F44F70B1DD54408B355CE49E7E4D4034F44F70B1DD54405072874D64384D4075560BEC319A54405072874D64384D40
52103	Волково	5	54	7144	82.367005000000006	83.421662999999995	58.668548999999999	58.114781999999998	0103000020E61000000100000005000000FC1D8A027D975440B115342DB10E4D40FC1D8A027D97544002637D0393554D40BABBCE86FCDA544002637D0393554D40BABBCE86FCDA5440B115342DB10E4D40FC1D8A027D975440B115342DB10E4D40
52284	Большая Саровка	5	54	7144	82.734029000000007	83.788686999999996	58.382237000000003	57.823928000000002	0103000020E610000001000000050000003354C554FAAE54401D21037976E94C403354C554FAAE54401C295B24ED304D40F1F109D979F254401C295B24ED304D40F1F109D979F254401D21037976E94C403354C554FAAE54401D21037976E94C40
52299	Белояровка	5	54	7144	82.823303999999993	83.877961999999997	58.696460999999999	58.143138	0103000020E610000001000000050000009FAA4203B1B454404D68925852124D409FAA4203B1B4544040F850A225594D405E48878730F8544040F850A225594D405E48878730F854404D68925852124D409FAA4203B1B454404D68925852124D40
23441	Чилино	5	54	746	83.507874000000001	83.541659999999993	55.845683000000001	55.825673999999999	0103000020E61000000100000005000000471FF30181E05440299485AFAFE94B40471FF30181E054403FE42D573FEC4B404963B48EAAE254403FE42D573FEC4B404963B48EAAE25440299485AFAFE94B40471FF30181E05440299485AFAFE94B40
47190	Хмелевка	5	54	746	83.311025999999998	83.346661999999995	56.291539	56.279857	0103000020E610000001000000050000002A8D98D9E7D354404147AB5AD2234C402A8D98D9E7D354401841632651254C400531D0B52FD654401841632651254C400531D0B52FD654404147AB5AD2234C402A8D98D9E7D354404147AB5AD2234C40
23153	Уртам	5	54	746	83.915440000000004	83.950419999999994	56.142620999999998	56.123061999999997	0103000020E61000000100000005000000D15CA79196FA5440AFB0E07EC00F4C40D15CA79196FA5440855CA96741124C40B75D68AED3FC5440855CA96741124C40B75D68AED3FC5440AFB0E07EC00F4C40D15CA79196FA5440AFB0E07EC00F4C40
22584	Терсалгай	5	54	746	83.428499000000002	83.446455999999998	56.390081000000002	56.374251999999998	0103000020E6100000010000000500000099D711876CDB5440363B527DE72F4C4099D711876CDB54403FE5982CEE314C4097C62FBC92DC54403FE5982CEE314C4097C62FBC92DC5440363B527DE72F4C4099D711876CDB5440363B527DE72F4C40
20607	Тека	5	54	746	83.752638000000005	83.771879999999996	56.190410999999997	56.177591	0103000020E6100000010000000500000085EE92382BF054402F88484DBB164C4085EE92382BF054403AE63C635F184C40EF1B5F7B66F154403AE63C635F184C40EF1B5F7B66F154402F88484DBB164C4085EE92382BF054402F88484DBB164C40
22400	Старая Ювала	5	54	746	83.430618999999993	83.456040999999999	56.328828000000001	56.295369999999998	0103000020E610000001000000050000005182FE428FDB5440191C25AFCE254C405182FE428FDB54402A013109172A4C40A62897C62FDD54402A013109172A4C40A62897C62FDD5440191C25AFCE254C405182FE428FDB5440191C25AFCE254C40
23082	Сафроновка	5	54	746	83.904148000000006	83.923911000000004	56.364944000000001	56.351719000000003	0103000020E610000001000000050000009BAF928FDDF95440E030D120052D4C409BAF928FDDF954408B6F287CB62E4C408A5A9A5B21FB54408B6F287CB62E4C408A5A9A5B21FB5440E030D120052D4C409BAF928FDDF95440E030D120052D4C40
22627	Песочнодубровка	5	54	746	83.445998000000003	83.473467999999997	56.417033000000004	56.398480999999997	0103000020E610000001000000050000003605323B8BDC5440E789E76C01334C403605323B8BDC5440282D5C5661354C40F6ECB94C4DDE5440282D5C5661354C40F6ECB94C4DDE5440E789E76C01334C403605323B8BDC5440E789E76C01334C40
47569	Осиновка	5	54	746	83.478256000000002	83.510811000000004	55.963903999999999	55.949646999999999	0103000020E6100000010000000500000069C70DBF9BDE54404CDF6B088EF94B4069C70DBF9BDE5440E63DCE3461FB4B40F9DB9E20B1E05440E63DCE3461FB4B40F9DB9E20B1E054404CDF6B088EF94B4069C70DBF9BDE54404CDF6B088EF94B40
47645	Новосергеевка	5	54	746	83.706841999999995	83.727700999999996	56.146577999999998	56.134444999999999	0103000020E610000001000000050000001C5C3AE63CED54402C0E677E35114C401C5C3AE63CED544013286211C3124C400E1137A792EE544013286211C3124C400E1137A792EE54402C0E677E35114C401C5C3AE63CED54402C0E677E35114C40
47426	Новопокровка	5	54	746	83.849053999999995	83.877359999999996	56.330379999999998	56.314467	0103000020E610000001000000050000006EA296E656F65440EB55647440284C406EA296E656F6544051A04FE4492A4C4063B48EAA26F8544051A04FE4492A4C4063B48EAA26F85440EB55647440284C406EA296E656F65440EB55647440284C40
22719	Муллова	5	54	746	83.466453000000001	83.492790999999997	56.453283999999996	56.443866999999997	0103000020E61000000100000005000000C007AF5DDADD5440066344A2D0384C40C007AF5DDADD544068E6C935053A4C40D73043E389DF544068E6C935053A4C40D73043E389DF5440066344A2D0384C40C007AF5DDADD5440066344A2D0384C40
22672	Кожевниково-на-Шегарке	5	54	746	83.416927999999999	83.441461000000004	56.444653000000002	56.431812999999998	0103000020E610000001000000050000005932C7F2AEDA54406B7EFCA545374C405932C7F2AEDA5440BE88B663EA384C40685DA3E540DC5440BE88B663EA384C40685DA3E540DC54406B7EFCA545374C405932C7F2AEDA54406B7EFCA545374C40
5233	Кожевниково	5	54	746	83.947086999999996	83.990036000000003	56.278243000000003	56.238106999999999	0103000020E61000000100000005000000DFDDCA129DFC54406EF9484A7A1E4C40DFDDCA129DFC5440A4AB74779D234C403677F4BF5CFF5440A4AB74779D234C403677F4BF5CFF54406EF9484A7A1E4C40DFDDCA129DFC54406EF9484A7A1E4C40
22919	Киреевск	5	54	746	84.080235000000002	84.106196999999995	56.381529999999998	56.350732000000001	0103000020E61000000100000005000000A73FFB912205554091D442C9E42C4C40A73FFB9122055540B0389CF9D5304C40BB7B80EECB065540B0389CF9D5304C40BB7B80EECB06554091D442C9E42C4C40A73FFB912205554091D442C9E42C4C40
52483	Зайцево	5	54	746	83.655520999999993	83.682784999999996	56.290998999999999	56.280307000000001	0103000020E61000000100000005000000D6355A0EF4E9544081EB8A19E1234C40D6355A0EF4E9544098158A743F254C40C24CDBBFB2EB544098158A743F254C40C24CDBBFB2EB544081EB8A19E1234C40D6355A0EF4E9544081EB8A19E1234C40
23390	Ерестная	5	54	746	83.591776999999993	83.608889000000005	55.878945000000002	55.868358999999998	0103000020E610000001000000050000009961A3ACDFE55440F817416326EF4B409961A3ACDFE55440CAFD0E4581F04B403A799109F8E65440CAFD0E4581F04B403A799109F8E65440F817416326EF4B409961A3ACDFE55440F817416326EF4B40
47541	Еловка	5	54	746	83.719239000000002	83.742369999999994	55.951154000000002	55.939740999999998	0103000020E610000001000000050000007FC0030308EE5440ECDADE6E49F84B407FC0030308EE5440D4BA0D6ABFF94B4004E275FD82EF5440D4BA0D6ABFF94B4004E275FD82EF5440ECDADE6E49F84B407FC0030308EE5440ECDADE6E49F84B40
22428	Елгай	5	54	746	83.325757999999993	83.349554999999995	56.257323	56.244160000000001	0103000020E61000000100000005000000431A1538D9D45440E57E87A2401F4C40431A1538D9D454401AC1C6F5EF204C40CF49EF1B5FD654401AC1C6F5EF204C40CF49EF1B5FD65440E57E87A2401F4C40431A1538D9D45440E57E87A2401F4C40
23115	Десятово	5	54	746	83.874656000000002	83.906259000000006	56.426687000000001	56.417217000000001	0103000020E6100000010000000500000003D0285DFAF75440E92ADD5D67354C4003D0285DFAF754406E50FBAD9D364C402AADBF2500FA54406E50FBAD9D364C402AADBF2500FA5440E92ADD5D67354C4003D0285DFAF75440E92ADD5D67354C40
52480	Борзуновка	5	54	746	83.533682999999996	83.574718000000004	56.145881000000003	56.128495999999998	0103000020E6100000010000000500000098DBBDDC27E254405AD5928E72104C4098DBBDDC27E25440CC0D863AAC124C400B9B012EC8E45440CC0D863AAC124C400B9B012EC8E454405AD5928E72104C4098DBBDDC27E254405AD5928E72104C40
23518	Базой	5	54	746	83.348414000000005	83.380053000000004	55.754410999999998	55.738444000000001	0103000020E61000000100000005000000FDDD3B6A4CD65440B6F63E5585DE4B40FDDD3B6A4CD654400F5F268A90E04B40CA6FD1C952D854400F5F268A90E04B40CA6FD1C952D85440B6F63E5585DE4B40FDDD3B6A4CD65440B6F63E5585DE4B40
47421	Аркадьево	5	54	746	83.860749999999996	83.877791000000002	56.294010999999998	56.280226999999996	0103000020E610000001000000050000000C022B8716F75440643A747ADE234C400C022B8716F7544006D50627A2254C40486E4DBA2DF8544006D50627A2254C40486E4DBA2DF85440643A747ADE234C400C022B8716F75440643A747ADE234C40
35509	Аптала	5	54	746	83.210873000000007	83.230816000000004	56.180342000000003	56.170551000000003	0103000020E6100000010000000500000001A777F17ECD54406AA67B9DD4154C4001A777F17ECD5440310C587215174C4030D978B0C5CE5440310C587215174C4030D978B0C5CE54406AA67B9DD4154C4001A777F17ECD54406AA67B9DD4154C40
60360	д. Лозунга	5	54	7151	80.151373000000007	81.206030999999996	59.252211000000003	58.707746999999998	0103000020E61000000100000005000000D61F6118B0095440CA6B2574975A4D40D61F6118B00954408258367348A04D4094BDA59C2F4D54408258367348A04D4094BDA59C2F4D5440CA6B2574975A4D40D61F6118B0095440CA6B2574975A4D40
52422	Усть-Тым	5	54	7151	79.491578000000004	80.546235999999993	59.698168000000003	59.160848999999999	0103000020E61000000100000005000000B85B920376DF5340124C35B396944D40B85B920376DF53408F8EAB915DD94D4076F9D687F52254408F8EAB915DD94D4076F9D687F5225440124C35B396944D40B85B920376DF5340124C35B396944D40
52126	Тымск	5	54	7151	79.775831999999994	80.830489999999998	59.643568000000002	59.105372000000003	0103000020E610000001000000050000002DCC423BA7F1534002F566D47C8D4D402DCC423BA7F153404660AC6F60D24D40EC6987BF263554404660AC6F60D24D40EC6987BF2635544002F566D47C8D4D402DCC423BA7F1534002F566D47C8D4D40
60329	Староюгино	5	54	7151	79.952369000000004	81.007026999999994	59.270963000000002	58.726799	0103000020E610000001000000050000005A2E1B9DF3FC5340FCE1E7BF075D4D405A2E1B9DF3FC534089B663EAAEA24D4018CC5F217340544089B663EAAEA24D4018CC5F2173405440FCE1E7BF075D4D405A2E1B9DF3FC5340FCE1E7BF075D4D40
52122	Старая Березовка	5	54	7151	79.021812999999995	80.076470999999998	59.252656999999999	58.708199999999998	0103000020E610000001000000050000002B685A6265C153407B832F4CA65A4D402B685A6265C15340800D881057A04D40EA059FE6E4045440800D881057A04D40EA059FE6E40454407B832F4CA65A4D402B685A6265C153407B832F4CA65A4D40
52419	Средний Васюган	5	54	7151	77.712896000000001	78.767554000000004	59.487222000000003	58.946519000000002	0103000020E61000000100000005000000C05C8B16A06D53407505DB8827794D40C05C8B16A06D534024F25D4A5DBE4D407FFACF9A1FB1534024F25D4A5DBE4D407FFACF9A1FB153407505DB8827794D40C05C8B16A06D53407505DB8827794D40
52460	Сосновка	5	54	7151	80.777075999999994	81.831733999999997	59.388947000000002	58.846670000000003	0103000020E610000001000000050000006AA0F99CBB3154408E40BCAE5F6C4D406AA0F99CBB3154404C70EA03C9B14D40293E3E213B7554404C70EA03C9B14D40293E3E213B7554408E40BCAE5F6C4D406AA0F99CBB3154408E40BCAE5F6C4D40
60365	Пятый километр	5	54	7151	80.281467000000006	81.336124999999996	59.328769000000001	58.785528999999997	0103000020E61000000100000005000000CFF9298E03125440A087DA368C644D40CFF9298E031254402578431A15AA4D408D976E12835554402578431A15AA4D408D976E1283555440A087DA368C644D40CFF9298E03125440A087DA368C644D40
60310	Павлово	5	54	7151	80.391304000000005	81.445961999999994	59.270314999999997	58.726140000000001	0103000020E61000000100000005000000D1B2EE1F0B195440A228D027F25C4D40D1B2EE1F0B195440224F92AE99A24D408F5033A48A5C5440224F92AE99A24D408F5033A48A5C5440A228D027F25C4D40D1B2EE1F0B195440A228D027F25C4D40
52417	Новый Тевриз	5	54	7151	77.006136999999995	78.060794999999999	59.412849000000001	58.870955000000002	0103000020E61000000100000005000000EA92718C64405340D3A414747B6F4D40EA92718C64405340D9976C3CD8B44D40A930B610E4835340D9976C3CD8B44D40A930B610E4835340D3A414747B6F4D40EA92718C64405340D3A414747B6F4D40
52421	Новый Васюган	5	54	7151	75.970515000000006	77.025172999999995	58.852117	58.301270000000002	0103000020E61000000100000005000000C251F2EA1CFE52400AA2EE0390264D40C251F2EA1CFE5240CDAE7B2B126D4D4080EF366F9C415340CDAE7B2B126D4D4080EF366F9C4153400AA2EE0390264D40C251F2EA1CFE52400AA2EE0390264D40
52474	Новоюгино	5	54	7151	80.054542999999995	81.109200999999999	59.264194000000003	58.719920999999999	0103000020E61000000100000005000000724EECA17D035440105A0F5F265C4D40724EECA17D03544054E6E61BD1A14D4031EC3026FD46544054E6E61BD1A14D4031EC3026FD465440105A0F5F265C4D40724EECA17D035440105A0F5F265C4D40
52429	Неготка	5	54	7151	80.121414000000001	81.176072000000005	59.991335999999997	59.458731999999998	0103000020E61000000100000005000000B3D1393FC507544078D0ECBAB7BA4D40B3D1393FC507544079AC1919E4FE4D40726F7EC3444B544079AC1919E4FE4D40726F7EC3444B544078D0ECBAB7BA4D40B3D1393FC507544078D0ECBAB7BA4D40
52433	Напас	5	54	7151	81.482361999999995	82.537019999999998	60.157243999999999	59.627315000000003	0103000020E6100000010000000500000052B5DD04DF5E544027A5A0DB4BD04D4052B5DD04DF5E544001BF469220144E40115322895EA2544001BF469220144E40115322895EA2544027A5A0DB4BD04D4052B5DD04DF5E544027A5A0DB4BD04D40
52438	Мыльджино	5	54	7151	77.954417000000007	79.009074999999996	59.263283000000001	58.718995999999997	0103000020E61000000100000005000000C66F0A2B157D534037FA980F085C4D40C66F0A2B157D5340E04BE141B3A14D40840D4FAF94C05340E04BE141B3A14D40840D4FAF94C0534037FA980F085C4D40C66F0A2B157D534037FA980F085C4D40
60317	Молодежный	5	54	7151	81.196077000000002	82.250736000000003	60.188935000000001	59.659517000000001	0103000020E61000000100000005000000DC9F8B868C4C5440F913950D6BD44D40DC9F8B868C4C5440EE08A7052F184E4083FB010F0C905440EE08A7052F184E4083FB010F0C905440F913950D6BD44D40DC9F8B868C4C5440F913950D6BD44D40
52466	Киндал	5	54	7151	80.066203000000002	81.120862000000002	59.422006000000003	58.880257999999998	0103000020E610000001000000050000006AF981AB3C0454406C054D4BAC704D406AF981AB3C0454409F5BE84A04B64D401155F833BC4754409F5BE84A04B64D401155F833BC4754406C054D4BAC704D406AF981AB3C0454406C054D4BAC704D40
60318	Киевский	5	54	7151	79.869642999999996	80.924301	60.035283	59.503388000000001	0103000020E61000000100000005000000800C1D3BA8F7534074999A046FC04D40800C1D3BA8F75340698D412784044E403FAA61BF273B5440698D412784044E403FAA61BF273B544074999A046FC04D40800C1D3BA8F7534074999A046FC04D40
60294	Каргасок	5	54	7151	80.335014999999999	81.389673000000002	59.321378000000003	58.778019999999998	0103000020E61000000100000005000000D82AC1E27015544024D1CB2896634D40D82AC1E270155440B3D30FEA22A94D4097C80567F0585440B3D30FEA22A94D4097C80567F058544024D1CB2896634D40D82AC1E27015544024D1CB2896634D40
52462	Восток	5	54	7151	80.750485999999995	81.805143999999999	59.438732999999999	58.897253999999997	0103000020E61000000100000005000000C6866EF607305440431A1538D9724D40C6866EF6073054408656276728B84D408524B37A877354408656276728B84D408524B37A87735440431A1538D9724D40C6866EF607305440431A1538D9724D40
52427	Вертикос	5	54	7151	79.139313000000001	80.193971000000005	59.653871000000002	59.115841000000003	0103000020E6100000010000000500000017BA1281EAC853409A44BDE0D38E4D4017BA1281EAC85340C366800BB2D34D40D65757056A0C5440C366800BB2D34D40D65757056A0C54409A44BDE0D38E4D4017BA1281EAC853409A44BDE0D38E4D40
52471	Бондарка	5	54	7151	80.216402000000002	81.271060000000006	59.299166	58.755453000000003	0103000020E610000001000000050000007F32C687D90D5440225514AFB2604D407F32C687D90D54409E094D124BA64D403ED00A0C595154409E094D124BA64D403ED00A0C59515440225514AFB2604D407F32C687D90D5440225514AFB2604D40
52477	Большая Грива	5	54	7151	79.722956999999994	80.777614999999997	59.196435000000001	58.65108	0103000020E6100000010000000500000083DA6FED44EE5340338AE59656534D4083DA6FED44EE5340176536C824994D404278B471C4315440176536C824994D404278B471C4315440338AE59656534D4083DA6FED44EE5340338AE59656534D40
9043	Шиняево	5	54	853	87.023816999999994	87.039806999999996	56.678767999999998	56.664192999999997	0103000020E61000000100000005000000AF05BD3786C15540B69DB64604554C40AF05BD3786C1554021C9ACDEE1564C40B8C9A8328CC2554021C9ACDEE1564C40B8C9A8328CC25540B69DB64604554C40AF05BD3786C15540B69DB64604554C40
20705	Чердаты	5	54	853	86.923134000000005	86.964276999999996	56.960323000000002	56.942990999999999	0103000020E61000000100000005000000D8F4A0A014BB55400FB6D8EDB3784C40D8F4A0A014BB55405E4C33DDEB7A4C403DD2E0B6B6BD55405E4C33DDEB7A4C403DD2E0B6B6BD55400FB6D8EDB3784C40D8F4A0A014BB55400FB6D8EDB3784C40
20081	Цыганово	5	54	853	86.440837000000002	86.48075	56.875560999999998	56.866332	0103000020E61000000100000005000000797764AC369C554038BD8BF7E36E4C40797764AC369C55409753026212704C4054E3A59BC49E55409753026212704C4054E3A59BC49E554038BD8BF7E36E4C40797764AC369C554038BD8BF7E36E4C40
46361	Тукай	5	54	853	87.097190999999995	87.122138000000007	56.745631000000003	56.735210000000002	0103000020E61000000100000005000000CB9D996038C6554099D87C5C1B5E4C40CB9D996038C6554020F12BD6705F4C4054E6E61BD1C7554020F12BD6705F4C4054E6E61BD1C7554099D87C5C1B5E4C40CB9D996038C6554099D87C5C1B5E4C40
20467	Туендат	5	54	853	86.925443000000001	86.941388000000003	56.739885000000001	56.725639999999999	0103000020E61000000100000005000000FAD346753ABB5540B05582C5E15C4C40FAD346753ABB554086E63A8DB45E4C40333674B33FBC554086E63A8DB45E4C40333674B33FBC5540B05582C5E15C4C40FAD346753ABB5540B05582C5E15C4C40
46188	Семёновка	5	54	853	86.272465999999994	86.302092999999999	56.883114999999997	56.864865999999999	0103000020E6100000010000000500000067D13B15709155400FB6D8EDB36E4C4067D13B1570915540B3CD8DE909714C406FD6E07D55935540B3CD8DE909714C406FD6E07D559355400FB6D8EDB36E4C4067D13B15709155400FB6D8EDB36E4C40
20695	Прушинский	5	54	853	86.902148999999994	86.914223000000007	56.888092	56.883823999999997	0103000020E610000001000000050000009FC728CFBCB95540BFB5132521714C409FC728CFBCB955406CEBA7FFAC714C4011902FA182BA55406CEBA7FFAC714C4011902FA182BA5540BFB5132521714C409FC728CFBCB95540BFB5132521714C40
60298	Причулымский	5	54	853	86.557644999999994	86.583866999999998	56.848832000000002	56.834775999999998	0103000020E61000000100000005000000C971A774B0A355402BBEA1F0D96A4C40C971A774B0A355402EE6E786A66C4C40AC8DB1135EA555402EE6E786A66C4C40AC8DB1135EA555402BBEA1F0D96A4C40C971A774B0A355402BBEA1F0D96A4C40
20490	Окунеево	5	54	853	86.975344000000007	87.009561000000005	56.781734999999998	56.762143000000002	0103000020E6100000010000000500000064963D096CBE55400BF0DDE68D614C4064963D096CBE5540BC9179E40F644C404B94BDA59CC05540BC9179E40F644C404B94BDA59CC055400BF0DDE68D614C4064963D096CBE55400BF0DDE68D614C40
20231	Мишутино	5	54	853	86.318002000000007	86.356071999999998	56.722315999999999	56.706913	0103000020E6100000010000000500000002840F255A945540020F0C207C5A4C4002840F255A94554053B0C6D9745C4C405DC136E2C996554053B0C6D9745C4C405DC136E2C9965540020F0C207C5A4C4002840F255A945540020F0C207C5A4C40
46441	Кучуково	5	54	853	87.019981000000001	87.037391	56.973444000000001	56.966011000000002	0103000020E61000000100000005000000A662635E47C15540C3499A3FA67B4C40A662635E47C15540643E20D0997C4C408B8A389D64C25540643E20D0997C4C408B8A389D64C25540C3499A3FA67B4C40A662635E47C15540C3499A3FA67B4C40
46087	Красноярка	5	54	853	86.819755999999998	86.847234999999998	56.826050000000002	56.812424	0103000020E61000000100000005000000C9ACDEE176B45540253E7782FD674C40C9ACDEE176B455402F6EA301BC694C40B341261939B655402F6EA301BC694C40B341261939B65540253E7782FD674C40C9ACDEE176B45540253E7782FD674C40
48566	Иловка	5	54	853	86.811212999999995	86.838206999999997	56.896262999999998	56.882683	0103000020E61000000100000005000000C345EEE9EAB355401ADEACC1FB704C40C345EEE9EAB35540B3CEF8BEB8724C40CF11F92EA5B55540B3CEF8BEB8724C40CF11F92EA5B555401ADEACC1FB704C40C345EEE9EAB355401ADEACC1FB704C40
6381	Зырянское	5	54	853	86.584325000000007	86.654008000000005	56.843122000000001	56.815725	0103000020E610000001000000050000000E4FAF9465A55540CAC342AD69684C400E4FAF9465A55540E144F46BEB6B4C40A2D45E44DBA95540E144F46BEB6B4C40A2D45E44DBA95540CAC342AD69684C400E4FAF9465A55540CAC342AD69684C40
46223	Дубровка	5	54	853	86.436633	86.458731999999998	56.734848999999997	56.719361999999997	0103000020E61000000100000005000000AED689CBF19B554019FED30D145C4C40AED689CBF19B5540C83F33880F5E4C403C6876DD5B9D5540C83F33880F5E4C403C6876DD5B9D554019FED30D145C4C40AED689CBF19B554019FED30D145C4C40
20348	Громышевка	5	54	853	86.399578000000005	86.430847999999997	56.601976000000001	56.590172000000003	0103000020E61000000100000005000000DF8C9AAF92995540E9818FC18A4B4C40DF8C9AAF929955400B7DB08C0D4D4C4002637D03939B55400B7DB08C0D4D4C4002637D03939B5540E9818FC18A4B4C40DF8C9AAF92995540E9818FC18A4B4C40
7647	Высокое	5	54	853	86.887597	86.926871000000006	56.609636000000002	56.601159000000003	0103000020E61000000100000005000000C6C1A563CEB85540195932C7F24C4C40C6C1A563CEB855406D3B6D8D084E4C401827BEDA51BB55406D3B6D8D084E4C401827BEDA51BB5540195932C7F24C4C40C6C1A563CEB85540195932C7F24C4C40
46081	Богословка	5	54	853	86.706091999999998	86.748420999999993	56.811033999999999	56.795855000000003	0103000020E61000000100000005000000E7FD7F9C30AD5540D6AD9E93DE654C40E7FD7F9C30AD5540D7F84CF6CF674C40EFA83121E6AF5540D7F84CF6CF674C40EFA83121E6AF5540D6AD9E93DE654C40E7FD7F9C30AD5540D6AD9E93DE654C40
20033	Берлинка	5	54	853	86.541106999999997	86.556872999999996	56.846651999999999	56.814655999999999	0103000020E61000000100000005000000BF28417FA1A25540BEBED6A546684C40BF28417FA1A25540E78BBD175F6C4C40A0C1A6CEA3A35540E78BBD175F6C4C40A0C1A6CEA3A35540BEBED6A546684C40BF28417FA1A25540BEBED6A546684C40
14094	Беловодовка	5	54	853	87.049356000000003	87.082378000000006	56.602877999999997	56.587598999999997	0103000020E61000000100000005000000217711A628C35540C614AC71364B4C40217711A628C355402BBD361B2B4D4C403CFA5FAE45C555402BBD361B2B4D4C403CFA5FAE45C55540C614AC71364B4C40217711A628C35540C614AC71364B4C40
55950	Самусь	5	54	7388	84.690676999999994	84.718444000000005	56.762473	56.733643999999998	0103000020E610000001000000050000005CC64D0D342C55400C74ED0BE85D4C405CC64D0D342C5540A08A1BB798614C407A008BFCFA2D5540A08A1BB798614C407A008BFCFA2D55400C74ED0BE85D4C405CC64D0D342C55400C74ED0BE85D4C40
60308	Ягодное	5	54	7179	84.715137999999996	85.769795999999999	58.531615000000002	57.975675000000003	0103000020E610000001000000050000001E882CD2C42D55402D431CEBE2FC4C401E882CD2C42D55401288D7F50B444D40DD257156447155401288D7F50B444D40DD257156447155402D431CEBE2FC4C401E882CD2C42D55402D431CEBE2FC4C40
60324	Центральный	5	54	7179	83.943259999999995	84.997917999999999	59.011147000000001	58.462834000000001	0103000020E61000000100000005000000FFE7305F5EFC54400ABDFE243E3B4D40FFE7305F5EFC54406939D0436D814D40BE8575E3DD3F55406939D0436D814D40BE8575E3DD3F55400ABDFE243E3B4D40FFE7305F5EFC54400ABDFE243E3B4D40
52384	Степановка	5	54	7179	86.244016000000002	87.298675000000003	58.912047999999999	58.362155000000001	0103000020E61000000100000005000000D9EC48F59D8F55409C8A54185B2E4D40D9EC48F59D8F5540EC3026FDBD744D408048BF7D1DD35540EC3026FDBD744D408048BF7D1DD355409C8A54185B2E4D40D9EC48F59D8F55409C8A54185B2E4D40
52401	Палочка	5	54	7179	84.077010999999999	85.131669000000002	58.653326999999997	58.099319000000001	0103000020E61000000100000005000000AA9B8BBFED0455408B6F287CB60C4D40AA9B8BBFED045540014C1938A0534D406939D0436D485540014C1938A0534D406939D0436D4855408B6F287CB60C4D40AA9B8BBFED0455408B6F287CB60C4D40
60339	Нибегинский	5	54	7179	84.363690000000005	85.418347999999995	58.560295000000004	58.004809000000002	0103000020E6100000010000000500000077F86BB246175540FDDCD0949D004D4077F86BB246175540618E1EBFB7474D403596B036C65A5540618E1EBFB7474D403596B036C65A5540FDDCD0949D004D4077F86BB246175540FDDCD0949D004D40
52398	Макзыр	5	54	7179	85.074625999999995	86.129283999999998	58.895319999999998	58.345160999999997	0103000020E610000001000000050000009A5B21ACC6445540656D533C2E2C4D409A5B21ACC644554034BA83D899724D4059F965304688554034BA83D899724D4059F9653046885540656D533C2E2C4D409A5B21ACC6445540656D533C2E2C4D40
52397	Лисица	5	54	7179	84.703593999999995	85.758252999999996	58.974429999999998	58.425531999999997	0103000020E610000001000000050000005BEA20AF072D554063B323D577364D405BEA20AF072D5540E21E4B1FBA7C4D400246973787705540E21E4B1FBA7C4D40024697378770554063B323D577364D405BEA20AF072D554063B323D577364D40
52387	Клюквинка	5	54	7179	85.329611999999997	86.384270000000001	58.815761000000002	58.264336	0103000020E61000000100000005000000A017EE5C18555540E69315C3D5214D40A017EE5C18555540172D40DB6A684D405FB532E197985540172D40DB6A684D405FB532E197985540E69315C3D5214D40A017EE5C18555540E69315C3D5214D40
52382	Катайга	5	54	7179	87.398927	88.453585000000004	59.020356999999997	58.472191000000002	0103000020E61000000100000005000000739F1C0588D95540973B33C1703C4D40739F1C0588D95540519FE40E9B824D40323D6189071D5640519FE40E9B824D40323D6189071D5640973B33C1703C4D40739F1C0588D95540973B33C1703C4D40
52388	Дружный	5	54	7179	85.542925999999994	86.597583999999998	59.032736	58.484768000000003	0103000020E610000001000000050000007A89B14CBF625540DC12B9E00C3E4D407A89B14CBF62554070B378B130844D403927F6D03EA6554070B378B130844D403927F6D03EA65540DC12B9E00C3E4D407A89B14CBF625540DC12B9E00C3E4D40
58563	Белый Яр	5	54	7179	84.523159000000007	85.577816999999996	58.719982000000002	58.167033000000004	0103000020E61000000100000005000000EBE6E26F7B215540282D5C5661154D40EBE6E26F7B215540B6DAC35E285C4D40A98427F4FA645540B6DAC35E285C4D40A98427F4FA645540282D5C5661154D40EBE6E26F7B215540282D5C5661154D40
17499	Чумакаевка	5	54	694	82.325852999999995	82.337943999999993	57.049396999999999	57.039892999999999	0103000020E610000001000000050000006C938AC6DA9454406F2BBD361B854C406C938AC6DA945440A0C211A452864C4048F8DEDFA0955440A0C211A452864C4048F8DEDFA09554406F2BBD361B854C406C938AC6DA9454406F2BBD361B854C40
45415	Чернышевка	5	54	694	81.980503999999996	82.002639000000002	57.005319	56.991836999999997	0103000020E610000001000000050000003866D993C07E54403BFBCA83F47E4C403866D993C07E54401286014BAE804C406DACC43C2B8054401286014BAE804C406DACC43C2B8054403BFBCA83F47E4C403866D993C07E54403BFBCA83F47E4C40
18300	Хуторское	5	54	694	81.914586	81.932337000000004	57.279496000000002	57.261446999999997	0103000020E6100000010000000500000049D8B793887A54409351651877A14C4049D8B793887A544071AE6186C6A34C4073F6CE68AB7B544071AE6186C6A34C4073F6CE68AB7B54409351651877A14C4049D8B793887A54409351651877A14C40
45366	Сухое	5	54	694	82.172420000000002	82.185078000000004	57.116008999999998	57.107201000000003	0103000020E61000000100000005000000494BE5ED088B54409C8C2AC3B88D4C40494BE5ED088B544055850662D98E4C40624D6551D88B544055850662D98E4C40624D6551D88B54409C8C2AC3B88D4C40494BE5ED088B54409C8C2AC3B88D4C40
45469	Пчелка	5	54	694	81.914766	81.923246000000006	57.225738999999997	57.216017000000001	0103000020E61000000100000005000000895FB1868B7A5440A530EF71A69B4C40895FB1868B7A54404337FB03E59C4C406C0A6476167B54404337FB03E59C4C406C0A6476167B5440A530EF71A69B4C40895FB1868B7A5440A530EF71A69B4C40
17411	Поротниково	5	54	694	82.328817000000001	82.362459000000001	57.009808	57.000613000000001	0103000020E610000001000000050000009B5775560B955440EA79371614804C409B5775560B9554409D9E776341814C4004C93B87329754409D9E776341814C4004C93B8732975440EA79371614804C409B5775560B955440EA79371614804C40
17401	Полынянка	5	54	694	82.500674000000004	82.515243999999996	56.959724999999999	56.944958999999997	0103000020E6100000010000000500000048FDF50A0BA05440CA87A06AF4784C4048FDF50A0BA05440A913D044D87A4C40745DF8C1F9A05440A913D044D87A4C40745DF8C1F9A05440CA87A06AF4784C4048FDF50A0BA05440CA87A06AF4784C40
49428	Плотниково	5	54	694	83.070547000000005	83.085019000000003	56.863734000000001	56.844776000000003	0103000020E610000001000000050000002E7590D783C454400D39B69E216C4C402E7590D783C45440BD38F1D58E6E4C40792288F370C55440BD38F1D58E6E4C40792288F370C554400D39B69E216C4C402E7590D783C454400D39B69E216C4C40
49489	Первомайск (Воробьёвка)	5	54	694	82.238393000000002	82.259521000000007	56.987079999999999	56.977755999999999	0103000020E610000001000000050000001AA6B6D4418F5440E0BBCD1B277D4C401AA6B6D4418F544091442FA3587E4C4004E8F7FD9B90544091442FA3587E4C4004E8F7FD9B905440E0BBCD1B277D4C401AA6B6D4418F5440E0BBCD1B277D4C40
18423	Парбиг	5	54	694	81.384058999999993	81.428651000000002	57.243544	57.215257000000001	0103000020E61000000100000005000000012F336C94585440179E978A8D9B4C40012F336C945854408A9125732C9F4C4074999A046F5B54408A9125732C9F4C4074999A046F5B5440179E978A8D9B4C40012F336C94585440179E978A8D9B4C40
18124	Панычево	5	54	694	81.785543000000004	81.804569000000001	57.062800000000003	57.049109000000001	0103000020E6100000010000000500000083A62556467254403A78263449864C4083A62556467254402B1895D409884C400798F90E7E7354402B1895D409884C400798F90E7E7354403A78263449864C4083A62556467254403A78263449864C40
18617	Новая Бурка	5	54	694	81.042169000000001	81.061160000000001	56.925851000000002	56.909509999999997	0103000020E61000000100000005000000ECF99AE5B242544046B1DCD26A744C40ECF99AE5B242544005FC1A4982764C40B2F4A10BEA43544005FC1A4982764C40B2F4A10BEA43544046B1DCD26A744C40ECF99AE5B242544046B1DCD26A744C40
18735	Кёнга	5	54	694	80.963998000000004	80.986266999999998	57.435442999999999	57.420164999999997	0103000020E6100000010000000500000034DAAA24B23D544040F67AF7C7B54C4034DAAA24B23D5440D522A298BCB74C40F0879FFF1E3F5440D522A298BCB74C40F0879FFF1E3F544040F67AF7C7B54C4034DAAA24B23D544040F67AF7C7B54C40
18403	Крыловка	5	54	694	81.875887000000006	81.910373000000007	57.460543999999999	57.446216	0103000020E6100000010000000500000076FF58880E785440D9791B9B1DB94C4076FF58880E7854403C2F151BF3BA4C40558A1D8D437A54403C2F151BF3BA4C40558A1D8D437A5440D9791B9B1DB94C4076FF58880E785440D9791B9B1DB94C40
45604	Кедровка	5	54	694	81.227796999999995	81.254206999999994	57.126337999999997	57.118505999999996	0103000020E610000001000000050000001F48DE39944E54409C3061342B8F4C401F48DE39944E5440FB1EF5D72B904C4083DA6FED44505440FB1EF5D72B904C4083DA6FED445054409C3061342B8F4C401F48DE39944E54409C3061342B8F4C40
18323	Высокий Яр	5	54	694	81.892630999999994	81.930503999999999	57.332607000000003	57.313974999999999	0103000020E610000001000000050000005419C6DD207954407C61325530A84C405419C6DD20795440D9B5BDDD92AA4C400533A6608D7B5440D9B5BDDD92AA4C400533A6608D7B54407C61325530A84C405419C6DD207954407C61325530A84C40
41054	Вавиловка	5	54	694	82.011208999999994	82.039721	57.061694000000003	57.048257	0103000020E61000000100000005000000EF1AF4A5B7805440CB660E492D864C40EF1AF4A5B7805440022EC896E5874C40B9FDF2C98A825440022EC896E5874C40B9FDF2C98A825440CB660E492D864C40EF1AF4A5B7805440CB660E492D864C40
49417	Бородинск	5	54	694	82.917779999999993	82.933159000000003	57.028030999999999	57.01491	0103000020E61000000100000005000000103B53E8BCBA544012312592E8814C40103B53E8BCBA54401823128596834C40F5BD86E0B8BB54401823128596834C40F5BD86E0B8BB544012312592E8814C40103B53E8BCBA544012312592E8814C40
4867	Большая Галка	5	54	694	81.951749000000007	81.977413999999996	56.934736000000001	56.915053	0103000020E610000001000000050000000C40A374E97C5440A88DEA7420754C400C40A374E97C54406A32E36DA5774C40C32973F38D7E54406A32E36DA5774C40C32973F38D7E5440A88DEA7420754C400C40A374E97C5440A88DEA7420754C40
45452	Богатырёвка	5	54	694	81.745541000000003	81.760542999999998	56.985166999999997	56.974150999999999	0103000020E61000000100000005000000F03499F1B66F5440CF2EDFFAB07C4C40F03499F1B66F5440990CC7F3197E4C40E90C8CBCAC705440990CC7F3197E4C40E90C8CBCAC705440CF2EDFFAB07C4C40F03499F1B66F5440CF2EDFFAB07C4C40
4850	Бакчар	5	54	694	82.008667000000003	82.101417999999995	57.036504000000001	57.006191000000001	0103000020E610000001000000050000007C6308008E805440C843DFDDCA804C407C6308008E8054402B16BF29AC844C40724EECA17D8654402B16BF29AC844C40724EECA17D865440C843DFDDCA804C407C6308008E805440C843DFDDCA804C40
40332	село Ново-Кусково	5	54	498	86.040233999999998	86.082696999999996	57.058781000000003	57.041410999999997	0103000020E61000000100000005000000FC8BA03193825540EA58A5F44C854C40FC8BA031938255402750C42286874C408C9E5BE84A8555402750C42286874C408C9E5BE84A855540EA58A5F44C854C40FC8BA03193825540EA58A5F44C854C40
13072	Ягодное	5	54	498	86.064605	86.101104000000007	56.808093	56.797274999999999	0103000020E610000001000000050000001E8A027D228455408E75711B0D664C401E8A027D22845540329067976F674C40AB5FE97C78865540329067976F674C40AB5FE97C788655408E75711B0D664C401E8A027D228455408E75711B0D664C40
13166	Цветковка	5	54	498	85.825968000000003	85.846745999999996	56.809975000000001	56.801642000000001	0103000020E61000000100000005000000B9E2E2A8DC745540CE8C7E349C664C40B9E2E2A8DC745540EFC9C342AD674C403481221631765540EFC9C342AD674C403481221631765540CE8C7E349C664C40B9E2E2A8DC745540CE8C7E349C664C40
12554	Филимоновка	5	54	498	85.803492000000006	85.837951000000004	57.192673999999997	57.169862999999999	0103000020E6100000010000000500000040A6B5696C73554075E61E12BE954C4040A6B5696C7355400E65A88AA9984C40A2293BFDA07555400E65A88AA9984C40A2293BFDA075554075E61E12BE954C4040A6B5696C73554075E61E12BE954C40
52217	Феоктистовка	5	54	498	86.191886999999994	86.214453000000006	56.970210999999999	56.959474	0103000020E61000000100000005000000C36169E0478C554060AE450BD07A4C40C36169E0478C5540179CC1DF2F7C4C40DD611399B98D5540179CC1DF2F7C4C40DD611399B98D554060AE450BD07A4C40C36169E0478C554060AE450BD07A4C40
52221	Тихомировка	5	54	498	86.048147999999998	86.106655000000003	56.937108000000002	56.927343999999998	0103000020E610000001000000050000008A5759DB1483554027124C35B3764C408A5759DB14835540F568AA27F3774C401D3D7E6FD3865540F568AA27F3774C401D3D7E6FD386554027124C35B3764C408A5759DB1483554027124C35B3764C40
7098	Светлый	5	54	498	85.95899	85.976371999999998	56.939774999999997	56.930315999999998	0103000020E610000001000000050000003ACC9717607D554007793D9814774C403ACC9717607D5540984C158C4A784C40BA2EFCE07C7E5540984C158C4A784C40BA2EFCE07C7E554007793D9814774C403ACC9717607D554007793D9814774C40
60333	Победа	5	54	498	86.246270999999993	86.264408000000003	56.950605000000003	56.942784000000003	0103000020E6100000010000000500000001BD70E7C28F554096986725AD784C4001BD70E7C28F55400135B56CAD794C404033880FEC9055400135B56CAD794C404033880FEC90554096986725AD784C4001BD70E7C28F554096986725AD784C40
60325	Первопашинск (Кайлушка)	5	54	498	85.470467999999997	85.492126999999996	57.580970000000001	57.566293000000002	0103000020E610000001000000050000002174D0251C5E5540147AFD497CC84C402174D0251C5E554083FA96395DCA4C40A19E3E027F5F554083FA96395DCA4C40A19E3E027F5F5540147AFD497CC84C402174D0251C5E5540147AFD497CC84C40
12351	Новониколаевка	5	54	498	85.831824999999995	85.894141000000005	57.312686999999997	57.289416000000003	0103000020E61000000100000005000000B1BFEC9E3C75554036785F950BA54C40B1BFEC9E3C7555403271AB2006A84C40D1402C9B397955403271AB2006A84C40D1402C9B3979554036785F950BA54C40B1BFEC9E3C75554036785F950BA54C40
12526	Ново-Кусково	5	54	498	86.040233999999998	86.082696999999996	57.058781000000003	57.041410999999997	0103000020E61000000100000005000000FC8BA03193825540EA58A5F44C854C40FC8BA031938255402750C42286874C408C9E5BE84A8555402750C42286874C408C9E5BE84A855540EA58A5F44C854C40FC8BA03193825540EA58A5F44C854C40
12670	Новиковка	5	54	498	85.924835999999999	85.983676000000003	56.931451000000003	56.916758000000002	0103000020E61000000100000005000000768A5583307B5540562C7E5358754C40768A5583307B5540CB694FC939774C400C772E8CF47E5540CB694FC939774C400C772E8CF47E5540562C7E5358754C40768A5583307B5540562C7E5358754C40
52214	Нижние Соколы	5	54	498	85.778482999999994	85.807704999999999	56.880465000000001	56.869107	0103000020E610000001000000050000007C5F5CAAD2715540C2DCEEE53E6F4C407C5F5CAAD2715540E622BE13B3704C4034F44F70B1735540E622BE13B3704C4034F44F70B1735540C2DCEEE53E6F4C407C5F5CAAD2715540C2DCEEE53E6F4C40
12746	Моисеевка	5	54	498	85.786208000000002	85.814649000000003	56.942686000000002	56.932054999999998	0103000020E61000000100000005000000A1F65B3B51725540618907944D774C40A1F65B3B51725540D33252EFA9784C40062E8F3523745540D33252EFA9784C40062E8F3523745540618907944D774C40A1F65B3B51725540618907944D774C40
60315	Михайловка	5	54	498	85.769615999999999	85.792191000000003	57.280625000000001	57.266767000000002	0103000020E610000001000000050000009D9E7763417155407653CA6B25A24C409D9E77634171554052B81E85EBA34C40E04BE141B372554052B81E85EBA34C40E04BE141B37255407653CA6B25A24C409D9E7763417155407653CA6B25A24C40
12239	Минаевка	5	54	498	85.827889999999996	85.863822999999996	57.447963999999999	57.421889999999998	0103000020E61000000100000005000000DEAB5626FC7455403541D47D00B64C40DEAB5626FC74554086E464E256B94C4016A243E04877554086E464E256B94C4016A243E0487755403541D47D00B64C40DEAB5626FC7455403541D47D00B64C40
52222	Мало-Жирово	5	54	498	85.970488000000003	86.004031999999995	56.801350999999997	56.793813999999998	0103000020E61000000100000005000000454AB3791C7E5540B08D78B29B654C40454AB3791C7E5540F6CE68AB92664C40CC086F0F42805540F6CE68AB92664C40CC086F0F42805540B08D78B29B654C40454AB3791C7E5540B08D78B29B654C40
12179	Копыловка	5	54	498	85.729613999999998	85.763508000000002	57.506467999999998	57.478026	0103000020E610000001000000050000000A2DEBFEB16E5540A051BAF42FBD4C400A2DEBFEB16E55403A3C84F1D3C04C40008FA850DD7055403A3C84F1D3C04C40008FA850DD705540A051BAF42FBD4C400A2DEBFEB16E5540A051BAF42FBD4C40
12630	Казанка	5	54	498	85.899342000000004	85.939639999999997	57.098768	57.079988	0103000020E61000000100000005000000D57ABFD18E7955404609FA0B3D8A4C40D57ABFD18E79554017F2086EA48C4C40DC80CF0F237C554017F2086EA48C4C40DC80CF0F237C55404609FA0B3D8A4C40D57ABFD18E7955404609FA0B3D8A4C40
60335	Воронино-Пашня	5	54	498	85.884071000000006	85.900419999999997	56.905509000000002	56.894030999999998	0103000020E61000000100000005000000E415889E947855401A4E999B6F724C40E415889E94785540E99D0AB8E7734C40842A357BA0795540E99D0AB8E7734C40842A357BA07955401A4E999B6F724C40E415889E947855401A4E999B6F724C40
47875	Вознесенка	5	54	498	86.246037999999999	86.258497000000006	56.985804999999999	56.979272000000002	0103000020E61000000100000005000000B0E42A16BF8F5540BBF1EEC8587D4C40B0E42A16BF8F5540DC9DB5DB2E7E4C404E4700378B905540DC9DB5DB2E7E4C404E4700378B905540BBF1EEC8587D4C40B0E42A16BF8F5540BBF1EEC8587D4C40
12329	Большой Кордон	5	54	498	85.857229000000004	85.869714999999999	57.378129999999999	57.367395000000002	0103000020E61000000100000005000000B30B06D7DC76554062DBA2CC06AF4C40B30B06D7DC76554078D1579066B04C40CD751A69A977554078D1579066B04C40CD751A69A977554062DBA2CC06AF4C40B30B06D7DC76554062DBA2CC06AF4C40
12975	Больше-Дорохово	5	54	498	86.187252000000001	86.210032999999996	56.900063000000003	56.881286000000003	0103000020E610000001000000050000001407D0EFFB8B55401A36CAFACD704C401407D0EFFB8B55407AABAE4335734C402B85402E718D55407AABAE4335734C402B85402E718D55401A36CAFACD704C401407D0EFFB8B55401A36CAFACD704C40
2998	Батурино	5	54	498	85.138334	85.209453999999994	57.766871999999999	57.741928999999999	0103000020E61000000100000005000000317BD976DA4855401C7A8B87F7DE4C40317BD976DA485540EB1B98DC28E24C400C01C0B1674D5540EB1B98DC28E24C400C01C0B1674D55401C7A8B87F7DE4C40317BD976DA4855401C7A8B87F7DE4C40
11644	Асино	5	54	498	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
60314	Северный	5	54	5666	76.647430999999997	77.702089000000001	60.935428999999999	60.418103000000002	0103000020E61000000100000005000000A9DA6E826F29534004AE2B6684354E40A9DA6E826F295340705D3123BC774E406878B306EF6C5340705D3123BC774E406878B306EF6C534004AE2B6684354E40A9DA6E826F29534004AE2B6684354E40
60330	Октябрьский	5	54	5666	78.878630999999999	79.933289000000002	59.750608	59.214131999999999	0103000020E610000001000000050000001D90847D3BB85340778368AD689B4D401D90847D3BB85340D80E46EC13E04D40DC2DC901BBFB5340D80E46EC13E04D40DC2DC901BBFB5340778368AD689B4D401D90847D3BB85340778368AD689B4D40
38396	Новоникольское	5	54	5666	54.491678999999998	54.524602999999999	52.433121999999997	52.417493	0103000020E61000000100000005000000A3906456EF3E4B408BA71E6970354A40A3906456EF3E4B40CC96AC8A70374A401631EC3026434B40CC96AC8A70374A401631EC3026434B408BA71E6970354A40A3906456EF3E4B408BA71E6970354A40
52338	Назино	5	54	5666	78.420552999999998	79.475211000000002	60.401085000000002	59.875095000000002	0103000020E61000000100000005000000054F2157EA9A534052F2EA1C03F04D40054F2157EA9A534045F5D6C056334E40C4EC65DB69DE534045F5D6C056334E40C4EC65DB69DE534052F2EA1C03F04D40054F2157EA9A534052F2EA1C03F04D40
52342	Лукашкин Яр	5	54	5666	77.880234000000002	78.934892000000005	60.587752999999999	60.064784000000003	0103000020E61000000100000005000000F2B4FCC055785340ECA694D74A084E40F2B4FCC0557853401D90847D3B4B4E40B1524145D5BB53401D90847D3B4B4E40B1524145D5BB5340ECA694D74A084E40F2B4FCC055785340ECA694D74A084E40
60328	Ларино	5	54	5666	77.153614000000005	78.208271999999994	60.793767000000003	60.274140000000003	0103000020E610000001000000050000004C8DD0CFD44953404243FF0417234E404C8DD0CFD449534070D234289A654E400A2B1554548D534070D234289A654E400A2B1554548D53404243FF0417234E404C8DD0CFD44953404243FF0417234E40
38490	Александровское	5	54	5666	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
59567	Черногорск	5	46	\N	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
12532	Черногорск	5	46	\N	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
12183	Сорск	5	46	\N	90.179635000000005	90.286022000000003	54.026451000000002	53.985773999999999	0103000020E61000000100000005000000E38DCC237F8B5640A19FA9D72DFE4A40E38DCC237F8B564027F911BF62034B40F0FB372F4E92564027F911BF62034B40F0FB372F4E925640A19FA9D72DFE4A40E38DCC237F8B5640A19FA9D72DFE4A40
11092	Саяногорск	5	46	\N	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
14315	Подсинее	5	46	\N	91.534769999999995	91.559760999999995	53.681395999999999	53.651488999999998	0103000020E610000001000000050000007138F3AB39E25640145AD6FD63D34A407138F3AB39E2564007D0EFFB37D74A40E124CD1FD3E3564007D0EFFB37D74A40E124CD1FD3E35640145AD6FD63D34A407138F3AB39E25640145AD6FD63D34A40
7985	Абакан	5	46	\N	91.321735000000004	91.534806000000003	53.758856999999999	53.660037000000003	0103000020E61000000100000005000000A1BE654E97D456403293A8177CD44A40A1BE654E97D456409BABE63922E14A4018EDF1423AE256409BABE63922E14A4018EDF1423AE256403293A8177CD44A40A1BE654E97D456403293A8177CD44A40
10580	Абаза	5	46	\N	90.054570999999996	90.153413	52.664084000000003	52.595984000000001	0103000020E61000000100000005000000D7135D177E8356403A782634494C4A40D7135D177E83564000E65AB400554A400072C284D189564000E65AB400554A400072C284D18956403A782634494C4A40D7135D177E8356403A782634494C4A40
22671	Шира	5	46	1651	89.940638000000007	89.999701999999999	54.509433999999999	54.467804000000001	0103000020E61000000100000005000000FED7B969337C564010786000E13B4B40FED7B969337C564038BC202235414B40BBEF181EFB7F564038BC202235414B40BBEF181EFB7F564010786000E13B4B40FED7B969337C564010786000E13B4B40
59591	Черное Озеро	5	46	1651	89.416775999999999	89.440383999999995	54.696995999999999	54.675345	0103000020E610000001000000050000007E703E75AC5A5640314278B471564B407E703E75AC5A5640AEB8382A37594B40A06B5F402F5C5640AEB8382A37594B40A06B5F402F5C5640314278B471564B407E703E75AC5A5640314278B471564B40
25545	Целинное	5	46	1651	89.900914	89.931833999999995	54.587615	54.568302000000003	0103000020E610000001000000050000008CA03193A87956402E20B41EBE484B408CA03193A8795640CCD1E3F7364B4B4041D3122BA37B5640CCD1E3F7364B4B4041D3122BA37B56402E20B41EBE484B408CA03193A87956402E20B41EBE484B40
25640	Фыркал	5	46	1651	89.794769000000002	89.823128999999994	54.635907000000003	54.621304000000002	0103000020E61000000100000005000000FAB7CB7EDD725640DF6FB4E3864F4B40FAB7CB7EDD72564014268C6665514B40E8D84125AE74564014268C6665514B40E8D84125AE745640DF6FB4E3864F4B40FAB7CB7EDD725640DF6FB4E3864F4B40
24709	Туим	5	46	1651	89.905153999999996	89.965952000000001	54.346390999999997	54.306086999999998	0103000020E61000000100000005000000FDF50A0BEE795640895DDBDB2D274B40FDF50A0BEE7956407A50508A562C4B405F605628D27D56407A50508A562C4B405F605628D27D5640895DDBDB2D274B40FDF50A0BEE795640895DDBDB2D274B40
60022	Топанов	5	46	1651	89.651892000000004	89.663938999999999	54.546796000000001	54.538069	0103000020E610000001000000050000008A213999B8695640E7FEEA71DF444B408A213999B8695640B4CA4C69FD454B407EE200FA7D6A5640B4CA4C69FD454B407EE200FA7D6A5640E7FEEA71DF444B408A213999B8695640E7FEEA71DF444B40
25274	Талкин Ключ	5	46	1651	89.419928999999996	89.432640000000006	54.733826999999998	54.726013000000002	0103000020E610000001000000050000001669E21DE05A564045BC75FEED5C4B401669E21DE05A5640FDF50A0BEE5D4B4041BCAE5FB05B5640FDF50A0BEE5D4B4041BCAE5FB05B564045BC75FEED5C4B401669E21DE05A564045BC75FEED5C4B40
25766	Сон	5	46	1651	90.375924999999995	90.403073000000006	54.391311000000002	54.377961999999997	0103000020E61000000100000005000000EC2FBB270F985640BC900E0F61304B40EC2FBB270F98564054C8957A16324B40A439B2F2CB99564054C8957A16324B40A439B2F2CB995640BC900E0F61304B40EC2FBB270F985640BC900E0F61304B40
25585	Соленоозерное	5	46	1651	89.864119000000002	89.894339000000002	54.736305999999999	54.722363000000001	0103000020E610000001000000050000008B36C7B94D775640946B0A64765C4B408B36C7B94D7756409EEC66463F5E4B406422A5D93C7956409EEC66463F5E4B406422A5D93C795640946B0A64765C4B408B36C7B94D775640946B0A64765C4B40
33142	Малый Спирин	5	46	1651	89.935633999999993	89.953591000000003	54.445596999999999	54.435192000000001	0103000020E61000000100000005000000A4C16D6DE17B56408CBD175FB4374B40A4C16D6DE17B56400D198F5209394B40A3B08BA2077D56400D198F5209394B40A3B08BA2077D56408CBD175FB4374B40A4C16D6DE17B56408CBD175FB4374B40
59595	Малый Кобежиков	5	46	1651	89.726965000000007	89.734385000000003	54.547580000000004	54.536313999999997	0103000020E610000001000000050000008C153598866E56408731E9EFA5444B408C153598866E5640CBF8F71917464B40126BF129006F5640CBF8F71917464B40126BF129006F56408731E9EFA5444B408C153598866E56408731E9EFA5444B40
24879	Коммунар	5	46	1651	89.266084000000006	89.319596000000004	54.353606999999997	54.334676000000002	0103000020E610000001000000050000004A7F2F8507515640C860C5A9D62A4B404A7F2F85075156407E5182FE422D4B40ADFBC742745456407E5182FE422D4B40ADFBC74274545640C860C5A9D62A4B404A7F2F8507515640C860C5A9D62A4B40
24670	Колодезный	5	46	1651	90.134439999999998	90.153655000000001	54.486553000000001	54.479157000000001	0103000020E610000001000000050000008DD13AAA9A88564022533E04553D4B408DD13AAA9A885640A662635E473E4B407BF7C77BD5895640A662635E473E4B407BF7C77BD589564022533E04553D4B408DD13AAA9A88564022533E04553D4B40
25037	Ефремкино	5	46	1651	89.439188999999999	89.451909000000001	54.475982000000002	54.460075000000003	0103000020E61000000100000005000000D4F02DAC1B5C5640865AD3BCE33A4B40D4F02DAC1B5C56400ABE69FAEC3C4B4028F1B913EC5C56400ABE69FAEC3C4B4028F1B913EC5C5640865AD3BCE33A4B40D4F02DAC1B5C5640865AD3BCE33A4B40
25340	Джирим	5	46	1651	90.382187000000002	90.416438999999997	54.818579	54.801670000000001	0103000020E61000000100000005000000357D76C0759856409817601F9D664B40357D76C075985640A0185932C7684B40DA71C3EFA69A5640A0185932C7684B40DA71C3EFA69A56409817601F9D664B40357D76C0759856409817601F9D664B40
60031	Гольджа	5	46	1651	90.500324000000006	90.515865000000005	54.390723999999999	54.384763	0103000020E61000000100000005000000DA59F44E05A05640FDDAFAE93F314B40DA59F44E05A0564093E1783E03324B40AB09A2EE03A1564093E1783E03324B40AB09A2EE03A15640FDDAFAE93F314B40DA59F44E05A05640FDDAFAE93F314B40
20932	Гайдаровск	5	46	1651	89.158268000000007	89.186098000000001	54.625791	54.613624000000002	0103000020E6100000010000000500000037001B10214A56403605323B8B4E4B4037001B10214A5640C99063EB19504B4077F69507E94B5640C99063EB19504B4077F69507E94B56403605323B8B4E4B4037001B10214A56403605323B8B4E4B40
25434	Ворота	5	46	1651	90.507007999999999	90.527417	54.708716000000003	54.700268000000001	0103000020E61000000100000005000000DDB3AED172A05640B937BF61A2594B40DDB3AED172A056407313B534B75A4B40AF963B33C1A156407313B534B75A4B40AF963B33C1A15640B937BF61A2594B40DDB3AED172A05640B937BF61A2594B40
25749	Власьево	5	46	1651	90.389221000000006	90.412477999999993	54.467903999999997	54.460959000000003	0103000020E61000000100000005000000A77A32FFE898564000E65AB4003B4B40A77A32FFE898564073D53C47E43B4B407214200A669A564073D53C47E43B4B407214200A669A564000E65AB4003B4B40A77A32FFE898564000E65AB4003B4B40
25672	Борец	5	46	1651	90.346434000000002	90.380615000000006	54.469760999999998	54.456353999999997	0103000020E610000001000000050000003D0E83F92B9656400BB3D0CE693A4B403D0E83F92B965640D7F7E120213C4B407E5704FF5B985640D7F7E120213C4B407E5704FF5B9856400BB3D0CE693A4B403D0E83F92B9656400BB3D0CE693A4B40
25869	Беренжак	5	46	1651	89.464197999999996	89.494731999999999	54.148600999999999	54.131152999999998	0103000020E610000001000000050000009737876BB55D5640DAE21A9FC9104B409737876BB55D56409293895B05134B40381268B0A95F56409293895B05134B40381268B0A95F5640DAE21A9FC9104B409737876BB55D5640DAE21A9FC9104B40
25237	Белый Балахчин	5	46	1651	89.473845999999995	89.487814999999998	54.560628000000001	54.551856999999998	0103000020E61000000100000005000000C9552C7E535E5640CA880B40A3464B40C9552C7E535E5640679C86A8C2474B40E3DF675C385F5640679C86A8C2474B40E3DF675C385F5640CA880B40A3464B40C9552C7E535E5640CA880B40A3464B40
59576	Черногорск	5	46	1625	89.165149	91.524699999999996	54.275495999999997	53.378999	0103000020E61000000100000005000000E57D1CCD914A5640BD1B0B0A83B04A40E57D1CCD914A5640E316F37343234B40840D4FAF94E15640E316F37343234B40840D4FAF94E15640BD1B0B0A83B04A40E57D1CCD914A5640BD1B0B0A83B04A40
59582	Чарков	5	46	1625	90.369152	90.400898999999995	53.710095000000003	53.696165999999998	0103000020E6100000010000000500000031D0B52FA0975640274BADF71BD94A4031D0B52FA0975640CD069964E4DA4A40F17F4754A8995640CD069964E4DA4A40F17F4754A8995640274BADF71BD94A4031D0B52FA0975640274BADF71BD94A40
23894	Усть-Бюр	5	46	1625	90.202892000000006	90.254086999999998	53.849769000000002	53.819104000000003	0103000020E61000000100000005000000AF27BA2EFC8C5640EB025E66D8E84A40AF27BA2EFC8C5640CB13083BC5EC4A40AED51EF642905640CB13083BC5EC4A40AED51EF642905640EB025E66D8E84A40AF27BA2EFC8C5640EB025E66D8E84A40
22714	Усть-Абакан	5	46	1625	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
60006	Усть-Абакан	5	46	1625	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
23244	Тепличный	5	46	1625	91.324555000000004	91.346393000000006	53.795873999999998	53.780963999999997	0103000020E6100000010000000500000036B05582C5D456403AADDBA0F6E34A4036B05582C5D456404CDE0033DFE54A400EA48B4D2BD656404CDE0033DFE54A400EA48B4D2BD656403AADDBA0F6E34A4036B05582C5D456403AADDBA0F6E34A40
23537	Ташеба	5	46	1625	91.288146999999995	91.329010999999994	53.684538000000003	53.672078999999997	0103000020E61000000100000005000000315C1D0071D2564008AA46AF06D64A40315C1D0071D25640446FF1F09ED74A408D4127840ED55640446FF1F09ED74A408D4127840ED5564008AA46AF06D64A40315C1D0071D2564008AA46AF06D64A40
20346	Сонское	5	46	1625	90.196702999999999	90.236829999999998	54.177678999999998	54.153758000000003	0103000020E610000001000000050000009B012EC8968C5640CBBF9657AE134B409B012EC8968C5640CE177B2FBE164B408C2D0439288F5640CE177B2FBE164B408C2D0439288F5640CBBF9657AE134B409B012EC8968C5640CBBF9657AE134B40
24167	Солнечное	5	46	1625	91.176558	91.196932000000004	53.696305000000002	53.684697	0103000020E6100000010000000500000038F6ECB94CCB5640AC55BB26A4D74A4038F6ECB94CCB56404985B18520D94A404CE2AC889ACC56404985B18520D94A404CE2AC889ACC5640AC55BB26A4D74A4038F6ECB94CCB5640AC55BB26A4D74A40
59590	Сапогов	5	46	1625	91.273944	91.29898	53.626210999999998	53.610925000000002	0103000020E61000000100000005000000DE3B6A4C88D1564087A757CA32CE4A40DE3B6A4C88D156409EB29AAE27D04A401E8A027D22D356409EB29AAE27D04A401E8A027D22D3564087A757CA32CE4A40DE3B6A4C88D1564087A757CA32CE4A40
23210	Расцвет	5	46	1625	91.346958999999998	91.357865000000004	53.794528999999997	53.780591000000001	0103000020E610000001000000050000006283859334D65640A646E867EAE34A406283859334D656409E5C5320B3E54A4084D89942E7D656409E5C5320B3E54A4084D89942E7D65640A646E867EAE34A406283859334D65640A646E867EAE34A40
59579	Райков	5	46	1625	91.152034	91.187184999999999	53.531509999999997	53.514550999999997	0103000020E610000001000000050000005378D0ECBAC95640E28FA2CEDCC14A405378D0ECBAC956409CBF098508C44A405053CBD6FACB56409CBF098508C44A405053CBD6FACB5640E28FA2CEDCC14A405378D0ECBAC95640E28FA2CEDCC14A40
60038	Мохов	5	46	1625	91.400220000000004	91.414682999999997	53.929212999999997	53.923450000000003	0103000020E6100000010000000500000021CD58349DD95640E0BE0E9C33F64A4021CD58349DD956404F029B73F0F64A4042CD902A8ADA56404F029B73F0F64A4042CD902A8ADA5640E0BE0E9C33F64A4021CD58349DD95640E0BE0E9C33F64A40
24020	Московское	5	46	1625	91.091900999999993	91.121409999999997	53.935065999999999	53.919457999999999	0103000020E610000001000000050000000F5EBBB4E1C55640D505BCCCB0F54A400F5EBBB4E1C55640FFCC203EB0F74A4012DA722EC5C75640FFCC203EB0F74A4012DA722EC5C75640D505BCCCB0F54A400F5EBBB4E1C55640D505BCCCB0F54A40
24266	Курганная	5	46	1625	91.115534999999994	91.124015	53.793534000000001	53.788756999999997	0103000020E61000000100000005000000C6A2E9EC64C75640DBBE47FDF5E44A40C6A2E9EC64C75640CD21A98592E54A40A94D9CDCEFC75640CD21A98592E54A40A94D9CDCEFC75640DBBE47FDF5E44A40C6A2E9EC64C75640DBBE47FDF5E44A40
23971	Ковыльная	5	46	1625	91.180484000000007	91.191281000000004	53.907307000000003	53.901736999999997	0103000020E61000000100000005000000E25CC30C8DCB5640EC4B361E6CF34A40E25CC30C8DCB56404837C2A222F44A4028D6A9F23DCC56404837C2A222F44A4028D6A9F23DCC5640EC4B361E6CF34A40E25CC30C8DCB5640EC4B361E6CF34A40
23757	Капчалы	5	46	1625	90.721722999999997	90.748106000000007	53.632393999999998	53.609113999999998	0103000020E610000001000000050000005871AAB530AE564093C49272F7CD4A405871AAB530AE5640E3175E49F2D04A4040FCFCF7E0AF5640E3175E49F2D04A4040FCFCF7E0AF564093C49272F7CD4A405871AAB530AE564093C49272F7CD4A40
23325	Калинино	5	46	1625	91.376846	91.406688000000003	53.772210999999999	53.730170999999999	0103000020E610000001000000050000003868AF3E1ED856406ABE4A3E76DD4A403868AF3E1ED85640444E5FCFD7E24A403EEB1A2D07DA5640444E5FCFD7E24A403EEB1A2D07DA56406ABE4A3E76DD4A403868AF3E1ED856406ABE4A3E76DD4A40
23692	Имени Ильича	5	46	1625	90.929952	90.942887999999996	53.519396	53.512397999999997	0103000020E6100000010000000500000063B6645584BB56409544F64196C14A4063B6645584BB56402CD670917BC24A409DF2E84658BC56402CD670917BC24A409DF2E84658BC56409544F64196C14A4063B6645584BB56409544F64196C14A40
23294	Зеленое	5	46	1625	91.289692000000002	91.321914000000007	53.779516999999998	53.768560000000001	0103000020E610000001000000050000006C7A50508AD25640C381902C60E24A406C7A50508AD2564088D68A36C7E34A40F9872D3D9AD4564088D68A36C7E34A40F9872D3D9AD45640C381902C60E24A406C7A50508AD25640C381902C60E24A40
59586	Доможаков	5	46	1625	91.016092	91.046554	53.450712000000003	53.436821000000002	0103000020E610000001000000050000008B6EBDA607C156405F9A22C0E9B74A408B6EBDA607C1564017F549EEB0B94A40DFDFA0BDFAC2564017F549EEB0B94A40DFDFA0BDFAC256405F9A22C0E9B74A408B6EBDA607C156405F9A22C0E9B74A40
23722	Весеннее	5	46	1625	90.682889000000003	90.724517000000006	53.632368	53.616335999999997	0103000020E6100000010000000500000015731074B4AB564079AC1919E4CE4A4015731074B4AB5640BA84436FF1D04A4059198D7C5EAE5640BA84436FF1D04A4059198D7C5EAE564079AC1919E4CE4A4015731074B4AB564079AC1919E4CE4A40
24086	Вершино-Биджа	5	46	1625	90.954970000000003	90.996077	53.992252999999998	53.962806	0103000020E6100000010000000500000050AA7D3A1EBD564040321D3A3DFB4A4050AA7D3A1EBD5640CF2D742502FF4A400FD3BEB9BFBF5640CF2D742502FF4A400FD3BEB9BFBF564040321D3A3DFB4A4050AA7D3A1EBD564040321D3A3DFB4A40
22376	Чиланы	5	46	1669	90.032894999999996	90.054912000000002	52.821084999999997	52.807384999999996	0103000020E61000000100000005000000EC4CA1F31A825640F623456458674A40EC4CA1F31A8256403A1E335019694A401C0A9FAD838356403A1E335019694A401C0A9FAD83835640F623456458674A40EC4CA1F31A825640F623456458674A40
22578	Харой	5	46	1669	89.869877000000002	89.879453999999996	52.902729000000001	52.898411000000003	0103000020E61000000100000005000000BAA29410AC775640EFAEB321FF724A40BAA29410AC7756404D13B69F8C734A4087156EF9487856404D13B69F8C734A4087156EF948785640EFAEB321FF724A40BAA29410AC775640EFAEB321FF724A40
22126	Харачул	5	46	1669	90.260052000000002	90.270724000000001	52.718933999999997	52.705660000000002	0103000020E610000001000000050000009AD024B1A4905640350C1F11535A4A409AD024B1A4905640C1FD8007065C4A40828FC18A53915640C1FD8007065C4A40828FC18A53915640350C1F11535A4A409AD024B1A4905640350C1F11535A4A40
21762	Таштып	5	46	1669	89.864164000000002	89.915205999999998	52.809883999999997	52.778078000000001	0103000020E610000001000000050000005B9885764E77564059DE550F98634A405B9885764E775640DEC66647AA674A4097C62FBC927A5640DEC66647AA674A4097C62FBC927A564059DE550F98634A405B9885764E77564059DE550F98634A40
22404	Печегол	5	46	1669	90.080540999999997	90.089856999999995	52.863771999999997	52.859374000000003	0103000020E610000001000000050000002D3F70952785564030849CF7FF6D4A402D3F709527855640AA99B514906E4A4044149337C0855640AA99B514906E4A4044149337C085564030849CF7FF6D4A402D3F70952785564030849CF7FF6D4A40
21552	Нижний Матур	5	46	1669	89.445432999999994	89.460802999999999	52.642766999999999	52.618991000000001	0103000020E61000000100000005000000C9E369F9815C564059C2DA183B4F4A40C9E369F9815C564059F9653046524A4084B9DDCB7D5D564059F9653046524A4084B9DDCB7D5D564059C2DA183B4F4A40C9E369F9815C564059C2DA183B4F4A40
60012	Нижний Курлугаш	5	46	1669	89.820307999999997	89.840440000000001	52.789766	52.775637000000003	0103000020E610000001000000050000006B2920ED7F745640A648BE1248634A406B2920ED7F74564012BF620D17654A400490DAC4C975564012BF620D17654A400490DAC4C9755640A648BE1248634A406B2920ED7F745640A648BE1248634A40
22427	Нижний Имек	5	46	1669	89.951920999999999	89.969149999999999	52.830264	52.823610000000002	0103000020E610000001000000050000000AD80E46EC7C56404C546F0D6C694A400AD80E46EC7C5640E8853B17466A4A40C7BAB88D067E5640E8853B17466A4A40C7BAB88D067E56404C546F0D6C694A400AD80E46EC7C56404C546F0D6C694A40
21650	Нижние Сиры	5	46	1669	89.754219000000006	89.771090000000001	52.759177000000001	52.751503	0103000020E6100000010000000500000066C1C41F4570564046EC134031604A4066C1C41F457056400D7041B62C614A407311DF89597156400D7041B62C614A407311DF895971564046EC134031604A4066C1C41F4570564046EC134031604A40
21509	Матур	5	46	1669	89.442458999999999	89.480080999999998	52.666049999999998	52.646608999999998	0103000020E6100000010000000500000089B48D3F515C56404E266E15C4524A4089B48D3F515C56401AC05B2041554A40959BA8A5B95E56401AC05B2041554A40959BA8A5B95E56404E266E15C4524A4089B48D3F515C56404E266E15C4524A40
22035	Малые Арбаты	5	46	1669	90.303646999999998	90.323311000000004	52.731471999999997	52.701681999999998	0103000020E61000000100000005000000D3A1D3F36E9356408F183DB7D0594A40D3A1D3F36E93564048F8DEDFA05D4A40F9DB9E20B194564048F8DEDFA05D4A40F9DB9E20B19456408F183DB7D0594A40D3A1D3F36E9356408F183DB7D0594A40
22192	Малая Сея	5	46	1669	89.826794000000007	89.83399	52.758527999999998	52.749361	0103000020E61000000100000005000000DCA16131EA745640EDF2AD0FEB5F4A40DCA16131EA745640D68C0C7217614A403ACC971760755640D68C0C7217614A403ACC971760755640EDF2AD0FEB5F4A40DCA16131EA745640EDF2AD0FEB5F4A40
21900	Кызылсуг	5	46	1669	89.547157999999996	89.562690000000003	52.788426000000001	52.781221000000002	0103000020E61000000100000005000000AAEFFCA20463564066F9BA0CFF634A40AAEFFCA20463564076A8A624EB644A4052F2EA1C0364564076A8A624EB644A4052F2EA1C0364564066F9BA0CFF634A40AAEFFCA20463564066F9BA0CFF634A40
22615	Кубайка	5	46	1669	89.817460999999994	89.830037000000004	52.335379000000003	52.326892999999998	0103000020E610000001000000050000005930F147517456404A253CA1D7294A405930F14751745640F261F6B2ED2A4A40145E82531F755640F261F6B2ED2A4A40145E82531F7556404A253CA1D7294A405930F147517456404A253CA1D7294A40
22477	Имек	5	46	1669	89.918593000000001	89.937988000000004	52.855105000000002	52.846159	0103000020E6100000010000000500000069554B3ACA7A5640A81B28F04E6C4A4069554B3ACA7A5640B3D2A414746D4A409702D2FE077C5640B3D2A414746D4A409702D2FE077C5640A81B28F04E6C4A4069554B3ACA7A5640A81B28F04E6C4A40
22266	Верхняя Сея	5	46	1669	89.688632999999996	89.708010000000002	52.684997000000003	52.676910999999997	0103000020E61000000100000005000000917C2590126C5640BDA60705A5564A40917C2590126C5640D76D50FBAD574A406CCF2C09506D5640D76D50FBAD574A406CCF2C09506D5640BDA60705A5564A40917C2590126C5640BDA60705A5564A40
22549	Верхний Имек	5	46	1669	89.834689999999995	89.850582000000003	52.877034999999999	52.870632000000001	0103000020E6100000010000000500000016139B8F6B755640F06C8FDE706F4A4016139B8F6B7556404339D1AE42704A403E247CEF6F7656404339D1AE42704A403E247CEF6F765640F06C8FDE706F4A4016139B8F6B755640F06C8FDE706F4A40
21710	Верхние Сиры	5	46	1669	89.705799999999996	89.724987999999996	52.778120999999999	52.769432000000002	0103000020E610000001000000050000001361C3D32B6D5640793F6EBF7C624A401361C3D32B6D564058AA0B7899634A40847F1134666E564058AA0B7899634A40847F1134666E5640793F6EBF7C624A401361C3D32B6D5640793F6EBF7C624A40
21951	Верх-Таштып	5	46	1669	89.432479000000001	89.455098000000007	52.816813000000003	52.806013	0103000020E610000001000000050000003C4D66BCAD5B56404F93196F2B674A403C4D66BCAD5B56404DF910548D684A40679E5C53205D56404DF910548D684A40679E5C53205D56404F93196F2B674A403C4D66BCAD5B56404F93196F2B674A40
22331	Бутрахты	5	46	1669	89.984673000000001	89.999315999999993	52.817743	52.808779000000001	0103000020E610000001000000050000004510E7E1047F56408658FD1186674A404510E7E1047F564037C478CDAB684A40A69718CBF47F564037C478CDAB684A40A69718CBF47F56408658FD1186674A404510E7E1047F56408658FD1186674A40
22106	Большие Арбаты	5	46	1669	90.363761999999994	90.384755999999996	52.716523000000002	52.712130999999999	0103000020E61000000100000005000000C36169E047975640E0BBCD1B275B4A40C36169E04797564079EA9106B75B4A40253CA1D79F98564079EA9106B75B4A40253CA1D79F985640E0BBCD1B275B4A40C36169E047975640E0BBCD1B275B4A40
22236	Большая Сея	5	46	1669	89.778366000000005	89.802908000000002	52.748542999999998	52.734209999999997	0103000020E610000001000000050000006094A0BFD0715640B532E197FA5D4A406094A0BFD07156402A53CC41D05F4A40986C3CD8627356402A53CC41D05F4A40986C3CD862735640B532E197FA5D4A406094A0BFD0715640B532E197FA5D4A40
22010	Арбаты	5	46	1669	90.267022999999995	90.300314	52.703733999999997	52.686788	0103000020E61000000100000005000000E811A3E71691564083A44FABE8574A40E811A3E716915640A88AA9F4135A4A40FB21365838935640A88AA9F4135A4A40FB2136583893564083A44FABE8574A40E811A3E71691564083A44FABE8574A40
21843	Анчул	5	46	1669	89.471879000000001	89.493078999999994	52.813046	52.801990000000004	0103000020E61000000100000005000000D42AFA43335E56400ADCBA9BA7664A40D42AFA43335E564062122EE411684A400AD6389B8E5F564062122EE411684A400AD6389B8E5F56400ADCBA9BA7664A40D42AFA43335E56400ADCBA9BA7664A40
20707	Устинкино	5	46	1627	89.544139000000001	89.573414999999997	54.913576999999997	54.898654999999998	0103000020E610000001000000050000009A5E622CD362564085B1852007734B409A5E622CD36256405BB05417F0744B404B02D4D4B26456405BB05417F0744B404B02D4D4B264564085B1852007734B409A5E622CD362564085B1852007734B40
21360	Сарала	5	46	1627	89.209975	89.267179999999996	54.871952999999998	54.858238	0103000020E61000000100000005000000917EFB3A704D56409C1727BEDA6D4B40917EFB3A704D56401553E9279C6F4B404C89247A195156401553E9279C6F4B404C89247A195156409C1727BEDA6D4B40917EFB3A704D56409C1727BEDA6D4B40
21464	Приисковое	5	46	1627	88.683149	88.708912999999995	54.665359000000002	54.650599	0103000020E61000000100000005000000E35295B6B82B5640B8E7F9D346534B40E35295B6B82B5640B58CD47B2A554B4064ADA1D45E2D5640B58CD47B2A554B4064ADA1D45E2D5640B8E7F9D346534B40E35295B6B82B5640B8E7F9D346534B40
33154	Подкамень	5	46	1627	89.444650999999993	89.450957000000002	54.823787000000003	54.817765000000001	0103000020E610000001000000050000008EC87729755C56401F680586AC684B408EC87729755C56405BEF37DA71694B40BFB9BF7ADC5C56405BEF37DA71694B40BFB9BF7ADC5C56401F680586AC684B408EC87729755C56401F680586AC684B40
21434	Орджоникидзевское	5	46	1627	88.937147999999993	89.002958000000007	54.787084999999998	54.761929000000002	0103000020E61000000100000005000000C1E09A3BFA3B5640DF6FB4E386614B40C1E09A3BFA3B564009168733BF644B40BE50C0763040564009168733BF644B40BE50C07630405640DF6FB4E386614B40C1E09A3BFA3B5640DF6FB4E386614B40
20998	Новомарьясово	5	46	1627	90.102541000000002	90.137835999999993	55.089939000000001	55.070056000000001	0103000020E61000000100000005000000F25F200890865640BD715298F7884B40F25F20089086564046D1031F838B4B40880D164ED288564046D1031F838B4B40880D164ED2885640BD715298F7884B40F25F200890865640BD715298F7884B40
21202	Монастырево	5	46	1627	90.396271999999996	90.417877000000004	55.043365000000001	55.034657000000003	0103000020E6100000010000000500000083143C855C995640EBC9FCA36F844B4083143C855C9956404165FCFB8C854B400A302C7FBE9A56404165FCFB8C854B400A302C7FBE9A5640EBC9FCA36F844B4083143C855C995640EBC9FCA36F844B40
20690	Малый Сютик	5	46	1627	89.830620999999994	89.844662	54.956017000000003	54.949420000000003	0103000020E61000000100000005000000BB97FBE4287556408C15359886794B40BB97FBE428755640C4B5DAC35E7A4B40228B34F10E765640C4B5DAC35E7A4B40228B34F10E7656408C15359886794B40BB97FBE4287556408C15359886794B40
20912	Костино	5	46	1627	89.497013999999993	89.505683000000005	55.036881000000001	55.023769000000001	0103000020E61000000100000005000000DDE9CE13CF5F56404ED4D2DC0A834B40DDE9CE13CF5F5640016C4084B8844B402AC93A1C5D605640016C4084B8844B402AC93A1C5D6056404ED4D2DC0A834B40DDE9CE13CF5F56404ED4D2DC0A834B40
20583	Копьево	5	46	1627	89.840197000000003	89.858604	55.048600999999998	55.030771999999999	0103000020E61000000100000005000000A14CA3C9C5755640F6D03E56F0834B40A14CA3C9C5755640C5C6BC8E38864B40BF0D315EF3765640C5C6BC8E38864B40BF0D315EF3765640F6D03E56F0834B40A14CA3C9C5755640F6D03E56F0834B40
20392	Копьево	5	46	1627	89.800977000000003	89.836253999999997	55.002474999999997	54.981566999999998	0103000020E6100000010000000500000049F60835437356409AEAC9FCA37D4B4049F60835437356405F07CE1951804B408C497F2F857556405F07CE1951804B408C497F2F857556409AEAC9FCA37D4B4049F60835437356409AEAC9FCA37D4B40
21105	Конгарово	5	46	1627	90.217956999999998	90.225313999999997	55.102431000000003	55.096209000000002	0103000020E61000000100000005000000CBBBEA01F38D56405A4A9693508C4B40CBBBEA01F38D56405D8C81751C8D4B402E55698B6B8E56405D8C81751C8D4B402E55698B6B8E56405A4A9693508C4B40CBBBEA01F38D56405A4A9693508C4B40
21267	Кожухово	5	46	1627	89.790125000000003	89.808801000000003	54.902434	54.884441000000002	0103000020E6100000010000000500000021B0726891725640EB1ED95C35714B4021B0726891725640346612F582734B4037FE4465C3735640346612F582734B4037FE4465C3735640EB1ED95C35714B4021B0726891725640EB1ED95C35714B40
21151	Когунек	5	46	1627	90.198049999999995	90.221226999999999	54.963878999999999	54.950319	0103000020E61000000100000005000000423EE8D9AC8C56403BE2900DA4794B40423EE8D9AC8C56408D261763607B4B40807F4A95288E56408D261763607B4B40807F4A95288E56403BE2900DA4794B40423EE8D9AC8C56403BE2900DA4794B40
21332	Кобяково	5	46	1627	89.770685999999998	89.778464999999997	54.803164000000002	54.790272000000002	0103000020E610000001000000050000000B5F5FEB52715640E67805A227654B400B5F5FEB527156408BA9F413CE664B402905DD5ED27156408BA9F413CE664B402905DD5ED2715640E67805A227654B400B5F5FEB52715640E67805A227654B40
21226	Июс	5	46	1627	89.747005999999999	89.779166000000004	54.708539000000002	54.692900000000002	0103000020E610000001000000050000009CFA40F2CE6F5640FFB27BF2B0584B409CFA40F2CE6F56406478EC67B15A4B40EE0912DBDD7156406478EC67B15A4B40EE0912DBDD715640FFB27BF2B0584B409CFA40F2CE6F5640FFB27BF2B0584B40
21058	Горюново	5	46	1627	90.172923999999995	90.186965000000001	55.054862	55.046222999999998	0103000020E61000000100000005000000622CD32F118B564058A9A0A2EA854B40622CD32F118B564086E5CFB705874B40C91F0C3CF78B564086E5CFB705874B40C91F0C3CF78B564058A9A0A2EA854B40622CD32F118B564058A9A0A2EA854B40
20595	Большой Сютик	5	46	1627	89.861001999999999	89.871898999999999	55.023181000000001	55.014355000000002	0103000020E6100000010000000500000099F221A81A7756405DC47762D6814B4099F221A81A775640BD715298F7824B40919A7631CD775640BD715298F7824B40919A7631CD7756405DC47762D6814B4099F221A81A7756405DC47762D6814B40
19391	Черемушка	5	46	1574	90.992574000000005	91.004035999999999	54.468646999999997	54.458824	0103000020E610000001000000050000000937195586BF5640594FADBEBA3A4B400937195586BF56402B2FF99FFC3B4B406D00362042C056402B2FF99FFC3B4B406D00362042C05640594FADBEBA3A4B400937195586BF5640594FADBEBA3A4B40
19336	Усть-Ерба	5	46	1574	91.153570000000002	91.174931999999998	54.45046	54.440738000000003	0103000020E6100000010000000500000064E94317D4C956405F0D501A6A384B4064E94317D4C95640FD135CACA8394B4087C1FC1532CB5640FD135CACA8394B4087C1FC1532CB56405F0D501A6A384B4064E94317D4C956405F0D501A6A384B40
19425	Троицкое	5	46	1574	91.063890999999998	91.112983999999997	54.288452999999997	54.277168000000003	0103000020E610000001000000050000008FE046CA16C45640B6BFB33D7A234B408FE046CA16C456406FB72407EC244B40293E3E213BC756406FB72407EC244B40293E3E213BC75640B6BFB33D7A234B408FE046CA16C45640B6BFB33D7A234B40
19641	Толчея	5	46	1574	91.067888999999994	91.082539999999995	54.062528	54.052745000000002	0103000020E6100000010000000500000085B01A4B58C4564086032159C0064B4085B01A4B58C45640CA8AE1EA00084B402827DA5548C55640CA8AE1EA00084B402827DA5548C5564086032159C0064B4085B01A4B58C4564086032159C0064B40
19711	Таежная	5	46	1574	90.952203999999995	90.964133000000004	54.148769999999999	54.143444000000002	0103000020E61000000100000005000000B4C70BE9F0BC56405A677C5F5C124B40B4C70BE9F0BC56401E5036E50A134B40A4FFE55AB4BD56401E5036E50A134B40A4FFE55AB4BD56405A677C5F5C124B40B4C70BE9F0BC56405A677C5F5C124B40
19740	Советская Хакасия	5	46	1574	91.424484000000007	91.447192999999999	54.119132999999998	54.106544999999997	0103000020E61000000100000005000000386BF0BE2ADB5640B2463D44A30D4B40386BF0BE2ADB5640EB6F09C03F0F4B40028063CF9EDC5640EB6F09C03F0F4B40028063CF9EDC5640B2463D44A30D4B40386BF0BE2ADB5640B2463D44A30D4B40
18949	Сарагаш	5	46	1574	90.72466	90.765057999999996	54.781888000000002	54.766812000000002	0103000020E610000001000000050000000A2E56D460AE5640161747E526624B400A2E56D460AE56404391EEE714644B40C362D4B5F6B056404391EEE714644B40C362D4B5F6B05640161747E526624B400A2E56D460AE5640161747E526624B40
20242	Пушное	5	46	1574	90.469817000000006	90.493550999999997	54.233868999999999	54.217094000000003	0103000020E61000000100000005000000B686527B119E5640341477BCC91B4B40B686527B119E56402C465D6BEF1D4B401EFAEE56969F56402C465D6BEF1D4B401EFAEE56969F5640341477BCC91B4B40B686527B119E5640341477BCC91B4B40
19607	Полиндейка	5	46	1574	91.121994000000001	91.132881999999995	54.221747999999998	54.214151000000001	0103000020E61000000100000005000000BA13ECBFCEC75640EEB3CA4C691B4B40BA13ECBFCEC7564009FA0B3D621C4B40880E812381C8564009FA0B3D621C4B40880E812381C85640EEB3CA4C691B4B40BA13ECBFCEC75640EEB3CA4C691B4B40
19067	Первомайское	5	46	1574	90.767762000000005	90.799830999999998	54.592086000000002	54.577832000000001	0103000020E6100000010000000500000024473A0323B15640884A2366F6494B4024473A0323B15640B1355B79C94B4B40EDD45C6E30B35640B1355B79C94B4B40EDD45C6E30B35640884A2366F6494B4024473A0323B15640884A2366F6494B40
19819	Красный Камень	5	46	1574	91.263002999999998	91.278381999999993	54.096836000000003	54.089142000000002	0103000020E61000000100000005000000FEEF880AD5D056409B594B01690B4B40FEEF880AD5D05640A9893E1F650C4B40E272BC02D1D15640A9893E1F650C4B40E272BC02D1D156409B594B01690B4B40FEEF880AD5D056409B594B01690B4B40
59597	Карасуг	5	46	1574	90.602112000000005	90.612900999999994	54.312337999999997	54.305382999999999	0103000020E61000000100000005000000DE21C50089A656408FE046CA16274B40DE21C50089A6564026A60BB1FA274B40E2AB1DC539A7564026A60BB1FA274B40E2AB1DC539A756408FE046CA16274B40DE21C50089A656408FE046CA16274B40
19311	Знаменка	5	46	1574	90.960127	91.016217999999995	54.374673999999999	54.345357	0103000020E610000001000000050000006C4084B872BD5640EB387EA8342C4B406C4084B872BD5640AC545051F52F4B40D1E638B709C15640AC545051F52F4B40D1E638B709C15640EB387EA8342C4B406C4084B872BD5640EB387EA8342C4B40
19138	Заречная	5	46	1574	90.701852000000002	90.716476999999998	54.586801000000001	54.582768000000002	0103000020E6100000010000000500000076A8A624EBAC5640E2934E24984A4B4076A8A624EBAC56404B21904B1C4B4B4084D558C2DAAD56404B21904B1C4B4B4084D558C2DAAD5640E2934E24984A4B4076A8A624EBAC5640E2934E24984A4B40
20135	Верх-Ерба	5	46	1574	90.745491999999999	90.767492000000004	54.326611	54.313713999999997	0103000020E610000001000000050000007FDB1324B6AF56400F26C5C727284B407FDB1324B6AF5640C6C1A563CE294B4044FCC3961EB15640C6C1A563CE294B4044FCC3961EB156400F26C5C727284B407FDB1324B6AF56400F26C5C727284B40
19231	Борозда	5	46	1574	90.793974000000006	90.800460000000001	54.542138000000001	54.535806999999998	0103000020E61000000100000005000000F5F75278D0B25640E3FBE25295444B40F5F75278D0B256409DF529C764454B40657094BC3AB356409DF529C764454B40657094BC3AB35640E3FBE25295444B40F5F75278D0B25640E3FBE25295444B40
19541	Бородино	5	46	1574	91.110028999999997	91.138451000000003	54.106081000000003	54.089607000000001	0103000020E61000000100000005000000242713B70AC75640103FFF3D780B4B40242713B70AC756400EDDEC0F940D4B404E469561DCC856400EDDEC0F940D4B404E469561DCC85640103FFF3D780B4B40242713B70AC75640103FFF3D780B4B40
20089	Большая Ерба	5	46	1574	90.605543999999995	90.632682000000003	54.263570999999999	54.236289999999997	0103000020E610000001000000050000007F129F3BC1A65640982F2FC03E1E4B407F129F3BC1A656404696CCB1BC214B4025B1A4DC7DA856404696CCB1BC214B4025B1A4DC7DA85640982F2FC03E1E4B407F129F3BC1A65640982F2FC03E1E4B40
19861	Боград	5	46	1574	90.819773999999995	90.870232000000001	54.244472000000002	54.209817999999999	0103000020E610000001000000050000001C075E2D77B456405A0EF450DB1A4B401C075E2D77B45640D464C6DB4A1F4B40B1FB8EE1B1B75640D464C6DB4A1F4B40B1FB8EE1B1B756405A0EF450DB1A4B401C075E2D77B456405A0EF450DB1A4B40
20041	Белелик	5	46	1574	90.727778000000001	90.746821999999995	54.150115	54.145311	0103000020E61000000100000005000000E42F2DEA93AE5640E15F048D99124B40E42F2DEA93AE5640CCD1E3F736134B40BB7B80EECBAF5640CCD1E3F736134B40BB7B80EECBAF5640E15F048D99124B40E42F2DEA93AE5640E15F048D99124B40
19043	Базандаиха	5	46	1574	90.676394000000002	90.694809000000006	54.838743000000001	54.832307999999998	0103000020E610000001000000050000007B4D0F0A4AAB56407E198C11896A4B407B4D0F0A4AAB5640DD5F3DEE5B6B4B40DBFD2AC077AC5640DD5F3DEE5B6B4B40DBFD2AC077AC56407E198C11896A4B407B4D0F0A4AAB56407E198C11896A4B40
19490	Абакано-Перевоз	5	46	1574	91.301063999999997	91.319192000000001	54.280147999999997	54.268782000000002	0103000020E610000001000000050000003080F0A144D3564072E0D57267224B403080F0A144D356401805C1E3DB234B40454948A46DD456401805C1E3DB234B40454948A46DD4564072E0D57267224B403080F0A144D3564072E0D57267224B40
59583	д. Новокурск	5	46	1506	91.244856999999996	91.274690000000007	53.117713000000002	53.095236	0103000020E6100000010000000500000096CCB1BCABCF564070B378B1308C4A4096CCB1BCABCF564033A83638118F4A4073A25D8594D1564033A83638118F4A4073A25D8594D1564070B378B1308C4A4096CCB1BCABCF564070B378B1308C4A40
60018	Шалгинов	5	46	1506	90.933411000000007	90.952078	53.354111000000003	53.337656000000003	0103000020E6100000010000000500000082AE7D01BDBB56402BA6D24F38AB4A4082AE7D01BDBB5640B2135E8253AD4A406E4F90D8EEBC5640B2135E8253AD4A406E4F90D8EEBC56402BA6D24F38AB4A4082AE7D01BDBB56402BA6D24F38AB4A40
60005	Черемушки	5	46	1506	91.403076999999996	91.425327999999993	52.868915000000001	52.840148999999997	0103000020E6100000010000000500000044317903CCD9564030629F008A6B4A4044317903CCD956407E00529B386F4A40AD84EE9238DB56407E00529B386F4A40AD84EE9238DB564030629F008A6B4A4044317903CCD9564030629F008A6B4A40
59571	Черемушки	5	46	1506	91.403076999999996	91.425327999999993	52.868915000000001	52.840148999999997	0103000020E6100000010000000500000044317903CCD9564030629F008A6B4A4044317903CCD956407E00529B386F4A40AD84EE9238DB56407E00529B386F4A40AD84EE9238DB564030629F008A6B4A4044317903CCD9564030629F008A6B4A40
60021	Чаптыков	5	46	1506	90.796623999999994	90.815723000000006	53.246395999999997	53.233468000000002	0103000020E610000001000000050000005BCD3AE3FBB25640CE548847E29D4A405BCD3AE3FBB25640BFEE74E7899F4A4015E63DCE34B45640BFEE74E7899F4A4015E63DCE34B45640CE548847E29D4A405BCD3AE3FBB25640CE548847E29D4A40
18404	Уты	5	46	1506	90.767762000000005	90.800775000000002	53.087670000000003	53.065646999999998	0103000020E6100000010000000500000024473A0323B156404E0AF31E67884A4024473A0323B15640906B43C5388B4A40151DC9E53FB35640906B43C5388B4A40151DC9E53FB356404E0AF31E67884A4024473A0323B156404E0AF31E67884A40
17939	Усть-Киндирла	5	46	1506	90.618380999999999	90.658867999999998	53.041285000000002	53.025716000000003	0103000020E61000000100000005000000F0DDE68D93A75640F27D71A94A834A40F0DDE68D93A756405E68AED348854A406118B0E42AAA56405E68AED348854A406118B0E42AAA5640F27D71A94A834A40F0DDE68D93A75640F27D71A94A834A40
17826	Табат	5	46	1506	90.697495000000004	90.728702999999996	52.965429999999998	52.918641000000001	0103000020E61000000100000005000000E88711C2A3AC5640E3E13D0796754A40E88711C2A3AC5640E449D235937B4A40D05FE811A3AE5640E449D235937B4A40D05FE811A3AE5640E3E13D0796754A40E88711C2A3AC5640E3E13D0796754A40
18524	Сабинка	5	46	1506	91.154909000000004	91.193023999999994	53.100605000000002	53.076889999999999	0103000020E61000000100000005000000CA367007EAC95640D9B11188D7894A40CA367007EAC956403468E89FE08C4A40F5D555815ACC56403468E89FE08C4A40F5D555815ACC5640D9B11188D7894A40CA367007EAC95640D9B11188D7894A40
18415	Новотроицкое	5	46	1506	91.032674999999998	91.070340999999999	53.159114000000002	53.144700999999998	0103000020E610000001000000050000006519E25817C256406859F78F85924A406519E25817C25640FA2AF9D85D944A4059A4897780C45640FA2AF9D85D944A4059A4897780C456406859F78F85924A406519E25817C256406859F78F85924A40
18823	Новониколаевка	5	46	1506	91.282415	91.304990000000004	53.202815000000001	53.184455999999997	0103000020E6100000010000000500000097395D1613D2564086C613419C974A4097395D1613D25640B21188D7F5994A40DAE6C6F484D35640B21188D7F5994A40DAE6C6F484D3564086C613419C974A4097395D1613D2564086C613419C974A40
18738	Новоенисейка	5	46	1506	91.492243999999999	91.524044000000004	53.170693999999997	53.158444000000003	0103000020E61000000100000005000000BE69FAEC80DF5640AC1F9BE447944A40BE69FAEC80DF5640CCCF0D4DD9954A40906AD8EF89E15640CCCF0D4DD9954A40906AD8EF89E15640AC1F9BE447944A40BE69FAEC80DF5640AC1F9BE447944A40
60037	Маткичек	5	46	1506	90.419871000000001	90.435806999999997	53.013869	53.004939999999998	0103000020E610000001000000050000007C629D2ADF9A56409B38B9DFA1804A407C629D2ADF9A5640D0B69A75C6814A408B170B43E49B5640D0B69A75C6814A408B170B43E49B56409B38B9DFA1804A407C629D2ADF9A56409B38B9DFA1804A40
17633	Малый Монок	5	46	1506	90.426231000000001	90.471514999999997	52.844805000000001	52.837961999999997	0103000020E61000000100000005000000A662635E479B564037A5BC56426B4A40A662635E479B5640A73FFB91226C4A40B324404D2D9E5640A73FFB91226C4A40B324404D2D9E564037A5BC56426B4A40A662635E479B564037A5BC56426B4A40
59569	Майна	5	46	1506	91.452520000000007	91.497911999999999	53.015163999999999	52.985655999999999	0103000020E610000001000000050000004D327216F6DC5640978DCEF9297E4A404D327216F6DC5640CC09DAE4F0814A404D124BCADDDF5640CC09DAE4F0814A404D124BCADDDF5640978DCEF9297E4A404D327216F6DC5640978DCEF9297E4A40
18198	Куйбышево	5	46	1506	90.766486	90.793687000000006	53.205258000000001	53.187899000000002	0103000020E61000000100000005000000E1B54B1B0EB15640BEF90D130D984A40E1B54B1B0EB15640069FE6E4459A4A40AA108FC4CBB25640069FE6E4459A4A40AA108FC4CBB25640BEF90D130D984A40E1B54B1B0EB15640BEF90D130D984A40
17621	Красный Катамор	5	46	1506	91.05153	91.087363999999994	53.027070000000002	53.018241000000003	0103000020E61000000100000005000000D3307C444CC35640223999B855824A40D3307C444CC35640F3599E0777834A4041B62C5F97C55640F3599E0777834A4041B62C5F97C55640223999B855824A40D3307C444CC35640223999B855824A40
60015	Койбалы	5	46	1506	90.640776000000002	90.662954999999997	53.168501999999997	53.157255999999997	0103000020E61000000100000005000000F303577902A95640C58CF0F620944A40F303577902A95640C1A7397991954A400FEECEDA6DAA5640C1A7397991954A400FEECEDA6DAA5640C58CF0F620944A40F303577902A95640C58CF0F620944A40
18521	Кирба	5	46	1506	91.206202000000005	91.238533000000004	53.289098000000003	53.272326999999997	0103000020E61000000100000005000000AB97DF6932CD5640AD68739CDBA24A40AB97DF6932CD564065ABCB2901A54A401381EA1F44CF564065ABCB2901A54A401381EA1F44CF5640AD68739CDBA24A40AB97DF6932CD5640AD68739CDBA24A40
18640	Калы	5	46	1506	91.255905999999996	91.298575999999997	53.082191000000002	53.058059999999998	0103000020E6100000010000000500000069368FC360D05640569A94826E874A4069368FC360D056404583143C858A4A40B6D782DE1BD356404583143C858A4A40B6D782DE1BD35640569A94826E874A4069368FC360D05640569A94826E874A40
18940	Дмитриевка	5	46	1506	91.375722999999994	91.408340999999993	53.274034	53.266285000000003	0103000020E61000000100000005000000B8567BD80BD856402B357BA015A24A40B8567BD80BD85640FCFECD8B13A34A406B274A4222DA5640FCFECD8B13A34A406B274A4222DA56402B357BA015A24A40B8567BD80BD856402B357BA015A24A40
18128	Дехановка	5	46	1506	90.982657000000003	90.994038000000003	53.003694000000003	52.989201000000001	0103000020E61000000100000005000000DF8B2FDAE3BE5640D3156C239E7E4A40DF8B2FDAE3BE56408198840B79804A40CD3E8F519EBF56408198840B79804A40CD3E8F519EBF5640D3156C239E7E4A40DF8B2FDAE3BE5640D3156C239E7E4A40
60019	Буденновка	5	46	1506	90.819018999999997	90.839887000000004	53.000230999999999	52.982261999999999	0103000020E610000001000000050000005EF3AACE6AB45640410DDFC2BA7D4A405EF3AACE6AB4564002B9C49107804A407A5567B5C0B5564002B9C49107804A407A5567B5C0B55640410DDFC2BA7D4A405EF3AACE6AB45640410DDFC2BA7D4A40
17719	Бондарево	5	46	1506	90.459325000000007	90.520779000000005	52.942058000000003	52.913634999999999	0103000020E610000001000000050000000E4FAF94659D564090BDDEFDF1744A400E4FAF94659D5640B477465B95784A40645C717154A15640B477465B95784A40645C717154A1564090BDDEFDF1744A400E4FAF94659D564090BDDEFDF1744A40
17537	Большой Монок	5	46	1506	90.277981999999994	90.291725999999997	52.879905000000001	52.860874000000003	0103000020E610000001000000050000001BB80375CA91564005FD851E316E4A401BB80375CA9156401F4B1FBAA0704A40255987A3AB9256401F4B1FBAA0704A40255987A3AB92564005FD851E316E4A401BB80375CA91564005FD851E316E4A40
60013	Богословка	5	46	1506	91.267628999999999	91.281965999999997	52.981285999999997	52.970804999999999	0103000020E61000000100000005000000849D62D520D156408AE59656437C4A40849D62D520D15640E60297C79A7D4A405F251FBB0BD25640E60297C79A7D4A405F251FBB0BD256408AE59656437C4A40849D62D520D156408AE59656437C4A40
18008	Бея	5	46	1506	90.880787999999995	90.960386999999997	53.064570000000003	53.033265999999998	0103000020E6100000010000000500000064ADA1D45EB85640CC086F0F42844A4064ADA1D45EB85640C0266BD443884A403A2009FB76BD5640C0266BD443884A403A2009FB76BD5640CC086F0F42844A4064ADA1D45EB85640CC086F0F42844A40
17102	Шора	5	46	1402	89.341165000000004	89.354685000000003	53.328251000000002	53.316267000000003	0103000020E610000001000000050000008D62B9A5D5555640EBE6E26F7BA84A408D62B9A5D55556408DF0F62004AA4A406FD8B628B35656408DF0F62004AA4A406FD8B628B3565640EBE6E26F7BA84A408D62B9A5D5555640EBE6E26F7BA84A40
16131	Усть-Чуль	5	46	1402	89.851696000000004	89.884161000000006	52.969628	52.95552	0103000020E610000001000000050000009488F02F827656404356B77A4E7A4A409488F02F8276564098A432C51C7C4A4084D904189678564098A432C51C7C4A4084D90418967856404356B77A4E7A4A409488F02F827656404356B77A4E7A4A40
60016	Усть-Хоиза	5	46	1402	89.906510999999995	89.921961999999994	53.140146999999999	53.130536999999997	0103000020E61000000100000005000000B69DB646047A56407FF5B86FB5904A40B69DB646047A5640F6D03E56F0914A40E789E76C017B5640F6D03E56F0914A40E789E76C017B56407FF5B86FB5904A40B69DB646047A56407FF5B86FB5904A40
16404	Усть-Камышта	5	46	1402	90.685602000000003	90.724902999999998	53.357056	53.344973000000003	0103000020E610000001000000050000009F0436E7E0AB56406380441328AC4A409F0436E7E0AB5640986BD102B4AD4A406D718DCF64AE5640986BD102B4AD4A406D718DCF64AE56406380441328AC4A409F0436E7E0AB56406380441328AC4A40
59585	Усть-Есь	5	46	1402	90.237199000000004	90.258785000000003	52.965499999999999	52.943849	0103000020E6100000010000000500000036E9B6442E8F564060AE450BD0784A4036E9B6442E8F5640DD240681957B4A4081ECF5EE8F905640DD240681957B4A4081ECF5EE8F90564060AE450BD0784A4036E9B6442E8F564060AE450BD0784A40
60011	Усть-База	5	46	1402	90.374658999999994	90.397161999999994	53.167180000000002	53.155544999999996	0103000020E61000000100000005000000BB09BE69FA975640350708E6E8934A40BB09BE69FA975640CC457C2766954A40B14D2A1A6B995640CC457C2766954A40B14D2A1A6B995640350708E6E8934A40BB09BE69FA975640350708E6E8934A40
16432	Пуланколь	5	46	1402	90.595707000000004	90.617149999999995	53.393236000000002	53.382323999999997	0103000020E61000000100000005000000E4BF401020A65640EA3C2AFEEFB04A40E4BF401020A6564010CEA78E55B24A407DAEB6627FA7564010CEA78E55B24A407DAEB6627FA75640EA3C2AFEEFB04A40E4BF401020A65640EA3C2AFEEFB04A40
15934	Полтаков	5	46	1402	90.175968999999995	90.198858999999999	52.963183999999998	52.949747000000002	0103000020E6100000010000000500000007077B13438B5640B03C484F91794A4007077B13438B5640E603029D497B4A40FA60191BBA8C5640E603029D497B4A40FA60191BBA8C5640B03C484F91794A4007077B13438B5640B03C484F91794A40
16102	Нижняя Тея	5	46	1402	90.029634000000001	90.049261999999999	52.941971000000002	52.926470000000002	0103000020E6100000010000000500000061360186E5815640D15CA79196764A4061360186E5815640E563778192784A40E0BBCD1B27835640E563778192784A40E0BBCD1B27835640D15CA79196764A4061360186E5815640D15CA79196764A40
17391	Нижняя База	5	46	1402	90.336346000000006	90.353808999999998	53.226832000000002	53.205711000000001	0103000020E61000000100000005000000FD885FB186955640B7B6F0BC549A4A40FD885FB186955640D8D7BAD4089D4A40F30181CEA4965640D8D7BAD4089D4A40F30181CEA4965640B7B6F0BC549A4A40FD885FB186955640B7B6F0BC549A4A40
17202	Неожиданный	5	46	1402	89.063873000000001	89.080160000000006	53.353642999999998	53.343651000000001	0103000020E610000001000000050000003C86C77E164456406D1E87C1FCAB4A403C86C77E16445640CBBA7F2C44AD4A40A29C685721455640CBBA7F2C44AD4A40A29C6857214556406D1E87C1FCAB4A403C86C77E164456406D1E87C1FCAB4A40
15549	Луговая	5	46	1402	90.561508000000003	90.579734999999999	53.161980999999997	53.152008000000002	0103000020E61000000100000005000000501C40BFEFA356407D5D86FF74934A40501C40BFEFA3564064C91CCBBB944A402E56D4601AA5564064C91CCBBB944A402E56D4601AA556407D5D86FF74934A40501C40BFEFA356407D5D86FF74934A40
16623	Кызлас	5	46	1402	89.945040000000006	89.967381000000003	53.122149999999998	53.103119	0103000020E610000001000000050000005C5A0D897B7C5640514CDE00338D4A405C5A0D897B7C56406B9A779CA28F4A406571FF91E97D56406B9A779CA28F4A406571FF91E97D5640514CDE00338D4A405C5A0D897B7C5640514CDE00338D4A40
59589	Катанов	5	46	1402	90.704600999999997	90.723680999999999	53.248524000000003	53.232669999999999	0103000020E61000000100000005000000A6EECA2E18AD564052616C21C89D4A40A6EECA2E18AD5640B4226AA2CF9F4A4024EF1CCA50AE5640B4226AA2CF9F4A4024EF1CCA50AE564052616C21C89D4A40A6EECA2E18AD564052616C21C89D4A40
16510	Камышта	5	46	1402	90.383776999999995	90.396856	53.569716999999997	53.559866999999997	0103000020E610000001000000050000003FFD67CD8F985640088ECBB8A9C74A403FFD67CD8F985640D47C957CECC84A402B4EB51666995640D47C957CECC84A402B4EB51666995640088ECBB8A9C74A403FFD67CD8F985640088ECBB8A9C74A40
16609	Казановка	5	46	1402	90.024045999999998	90.066266999999996	53.233198000000002	53.212263999999998	0103000020E6100000010000000500000060E63BF8898156401F0F7D772B9B4A4060E63BF8898156400EBF9B6ED99D4A407573F1B73D8456400EBF9B6ED99D4A407573F1B73D8456401F0F7D772B9B4A4060E63BF8898156401F0F7D772B9B4A40
59596	Илиморов	5	46	1402	89.897212999999994	89.926516000000007	52.988636999999997	52.985405999999998	0103000020E61000000100000005000000F22213F06B7956401EA4A7C8217E4A40F22213F06B795640CA4E3FA88B7E4A4021CEC3094C7B5640CA4E3FA88B7E4A4021CEC3094C7B56401EA4A7C8217E4A40F22213F06B7956401EA4A7C8217E4A40
17000	Вершина Теи	5	46	1402	89.550759999999997	89.570414999999997	53.279482999999999	53.256535999999997	0103000020E610000001000000050000007AFCDEA63F635640921FF12BD6A04A407AFCDEA63F635640DC645419C6A34A407689EAAD81645640DC645419C6A34A407689EAAD81645640921FF12BD6A04A407AFCDEA63F635640921FF12BD6A04A40
16207	Верхняя Тея	5	46	1402	89.721602000000004	89.737654000000006	52.996887000000001	52.987250000000003	0103000020E610000001000000050000009BAE27BA2E6E5640EE7C3F355E7E4A409BAE27BA2E6E56405E6743FE997F4A40DF701FB9356F56405E6743FE997F4A40DF701FB9356F5640EE7C3F355E7E4A409BAE27BA2E6E5640EE7C3F355E7E4A40
17425	Верхняя База	5	46	1402	90.290387999999993	90.303826999999998	53.253852999999999	53.235951999999997	0103000020E61000000100000005000000A7C98CB79592564080B6D5AC339E4A40A7C98CB795925640E97E4E417EA04A401329CDE671935640E97E4E417EA04A401329CDE67193564080B6D5AC339E4A40A7C98CB79592564080B6D5AC339E4A40
16529	Верхний Аскиз	5	46	1402	90.147187000000002	90.219672000000003	53.175286999999997	53.153908999999999	0103000020E610000001000000050000005ED905836B895640B0C7444AB3934A405ED905836B895640FC34EECD6F964A4034F6251B0F8E5640FC34EECD6F964A4034F6251B0F8E5640B0C7444AB3934A405ED905836B895640B0C7444AB3934A40
16935	Бискамжа	5	46	1402	89.509311999999994	89.537923000000006	53.467267999999997	53.437061999999997	0103000020E6100000010000000500000076DD5B91986056408429CAA5F1B74A4076DD5B9198605640D13B1570CFBB4A400A3197546D625640D13B1570CFBB4A400A3197546D6256408429CAA5F1B74A4076DD5B91986056408429CAA5F1B74A40
16840	Бирикчуль	5	46	1402	89.861639999999994	89.914416000000003	53.377161999999998	53.311114000000003	0103000020E610000001000000050000003A3B191C25775640F4A96395D2A74A403A3B191C25775640A0A52BD846B04A401BBCAFCA857A5640A0A52BD846B04A401BBCAFCA857A5640F4A96395D2A74A403A3B191C25775640F4A96395D2A74A40
15716	Бельтирское	5	46	1402	90.374767000000006	90.425332999999995	53.050629000000001	53.012466000000003	0103000020E61000000100000005000000AF27BA2EFC975640EE27637C98814A40AF27BA2EFC975640569DD5027B864A40363AE7A7389B5640569DD5027B864A40363AE7A7389B5640EE27637C98814A40AF27BA2EFC975640EE27637C98814A40
17124	Балыкса	5	46	1402	89.114017000000004	89.163882999999998	53.429186999999999	53.407646	0103000020E61000000100000005000000098CF50D4C475640302C7FBE2DB44A40098CF50D4C475640266F8099EFB64A40B4571F0F7D4A5640266F8099EFB64A40B4571F0F7D4A5640302C7FBE2DB44A40098CF50D4C475640302C7FBE2DB44A40
60008	Аскиз	5	46	1402	90.397153000000003	90.465199999999996	53.146363999999998	53.122717999999999	0103000020E6100000010000000500000088A06AF46A995640B5503239B58F4A4088A06AF46A995640E7A7380EBC924A40598638D6C59D5640E7A7380EBC924A40598638D6C59D5640B5503239B58F4A4088A06AF46A995640B5503239B58F4A40
17236	Аскиз	5	46	1402	90.397153000000003	90.465199999999996	53.146363999999998	53.122717999999999	0103000020E6100000010000000500000088A06AF46A995640B5503239B58F4A4088A06AF46A995640E7A7380EBC924A40598638D6C59D5640E7A7380EBC924A40598638D6C59D5640B5503239B58F4A4088A06AF46A995640B5503239B58F4A40
15443	Аскиз	5	46	1402	90.503118000000001	90.560564999999997	53.155448	53.105649	0103000020E61000000100000005000000DA01D71533A0564074ED0BE8858D4A40DA01D71533A05640431D56B8E5934A401092054CE0A35640431D56B8E5934A401092054CE0A3564074ED0BE8858D4A40DA01D71533A0564074ED0BE8858D4A40
60014	Анхаков (Ворошилово)	5	46	1402	90.323149000000001	90.340791999999993	53.019340999999997	53.011122	0103000020E610000001000000050000000CAF2479AE945640102219726C814A400CAF2479AE945640683C11C479824A4042AF3F89CF955640683C11C479824A4042AF3F89CF955640102219726C814A400CAF2479AE945640102219726C814A40
59592	д. Кайбалы	5	46	1343	90.999392	91.936092000000002	53.735050000000001	53.139223999999999	0103000020E6100000010000000500000094F8DC09F6BF5640BE688F17D2914A4094F8DC09F6BF564060764F1E16DE4A4006836BEEE8FB564060764F1E16DE4A4006836BEEE8FB5640BE688F17D2914A4094F8DC09F6BF5640BE688F17D2914A40
14960	Смирновка	5	46	1343	91.357298999999998	91.387778999999995	53.38908	53.376038999999999	0103000020E610000001000000050000002FF99FFCDDD65640A182C30B22B04A402FF99FFCDDD656408BC3995FCDB14A40D6C4025FD1D856408BC3995FCDB14A40D6C4025FD1D85640A182C30B22B04A402FF99FFCDDD65640A182C30B22B04A40
60024	Сартыков	5	46	1343	91.173602000000002	91.188353000000006	53.477241999999997	53.464947000000002	0103000020E610000001000000050000004B21904B1CCB5640C9AF1F6283BB4A404B21904B1CCB564089230F4416BD4A40A0C6BDF90DCC564089230F4416BD4A40A0C6BDF90DCC5640C9AF1F6283BB4A404B21904B1CCB5640C9AF1F6283BB4A40
15367	Очуры	5	46	1343	91.625265999999996	91.685597000000001	53.180236000000001	53.159503000000001	0103000020E610000001000000050000003F53AF5B04E85640944E24986A944A403F53AF5B04E85640EBC726F911974A40164F3DD2E0EB5640EBC726F911974A40164F3DD2E0EB5640944E24986A944A403F53AF5B04E85640944E24986A944A40
15130	Новороссийское	5	46	1343	91.588040000000007	91.610938000000004	53.384929	53.372494000000003	0103000020E610000001000000050000005A2F8672A2E5564066FA25E2ADAF4A405A2F8672A2E5564018247D5A45B14A408E78B29B19E7564018247D5A45B14A408E78B29B19E7564066FA25E2ADAF4A405A2F8672A2E5564066FA25E2ADAF4A40
15342	Новомихайловка	5	46	1343	91.549475999999999	91.585713999999996	53.258479999999999	53.246761999999997	0103000020E61000000100000005000000F67B629D2AE35640A1F2AFE5959F4A40F67B629D2AE35640C55565DF15A14A40CCB392567CE55640C55565DF15A14A40CCB392567CE55640A1F2AFE5959F4A40F67B629D2AE35640A1F2AFE5959F4A40
15045	Лукьяновка	5	46	1343	91.547724000000002	91.572400999999999	53.420205000000003	53.409176000000002	0103000020E61000000100000005000000FFCEF6E80DE35640702711E15FB44A40FFCEF6E80DE35640CF4E0647C9B54A40A7CCCD37A2E45640CF4E0647C9B54A40A7CCCD37A2E45640702711E15FB44A40FFCEF6E80DE35640702711E15FB44A40
14979	Летник	5	46	1343	91.635247000000007	91.662942000000001	53.511809	53.503808999999997	0103000020E61000000100000005000000757808E3A7E85640193735D07CC04A40757808E3A7E85640346612F582C14A40454948A46DEA5640346612F582C14A40454948A46DEA5640193735D07CC04A40757808E3A7E85640193735D07CC04A40
14873	Краснополье	5	46	1343	91.354442000000006	91.38494	53.437233999999997	53.423827000000003	0103000020E610000001000000050000000C957F2DAFD65640B61490F63FB64A400C957F2DAFD656408159A148F7B74A4006BB61DBA2D856408159A148F7B74A4006BB61DBA2D85640B61490F63FB64A400C957F2DAFD65640B61490F63FB64A40
15264	Кирово	5	46	1343	91.852791999999994	91.910696999999999	53.359931000000003	53.328181000000001	0103000020E610000001000000050000009692E52494F656409415C3D501AA4A409692E52494F6564086E8103812AE4A402EE411DC48FA564086E8103812AE4A402EE411DC48FA56409415C3D501AA4A409692E52494F656409415C3D501AA4A40
14771	Изыхские Копи	5	46	1343	91.268662000000006	91.304631000000001	53.558523999999998	53.546247000000001	0103000020E6100000010000000500000064EB19C231D15640E144F46BEBC54A4064EB19C231D15640FB03E5B67DC74A40429605137FD35640FB03E5B67DC74A40429605137FD35640E144F46BEBC54A4064EB19C231D15640E144F46BEBC54A40
15068	Герасимово	5	46	1343	91.553535999999994	91.571089000000001	53.330466999999999	53.322808000000002	0103000020E61000000100000005000000274A42226DE356408F71C5C551A94A40274A42226DE3564020B41EBE4CAA4A40BE86E0B88CE4564020B41EBE4CAA4A40BE86E0B88CE456408F71C5C551A94A40274A42226DE356408F71C5C551A94A40
15147	Берёзовка	5	46	1343	91.647536000000002	91.662510999999995	53.413201000000001	53.405664999999999	0103000020E61000000100000005000000E4BED53A71E95640E010AAD4ECB34A40E4BED53A71E9564056D636C5E3B44A40608F899466EA564056D636C5E3B44A40608F899466EA5640E010AAD4ECB34A40E4BED53A71E95640E010AAD4ECB34A40
14482	Белый Яр	5	46	1343	91.345989000000003	91.411979000000002	53.620581999999999	53.579597999999997	0103000020E61000000100000005000000A6F10BAF24D65640DB696B4430CA4A40A6F10BAF24D656403E3E213B6FCF4A40E2E82ADD5DDA56403E3E213B6FCF4A40E2E82ADD5DDA5640DB696B4430CA4A40A6F10BAF24D65640DB696B4430CA4A40
59584	Аршанов	5	46	1343	91.046688000000003	91.081282999999999	53.42615	53.399850999999998	0103000020E610000001000000050000006747AAEFFCC25640EE224C512EB34A406747AAEFFCC256405F984C158CB64A4021AE9CBD33C556405F984C158CB64A4021AE9CBD33C55640EE224C512EB34A406747AAEFFCC25640EE224C512EB34A40
60017	Алтай	5	46	1343	91.793844000000007	91.819806	53.452143999999997	53.434863	0103000020E610000001000000050000000E881057CEF25640C79E3D97A9B74A400E881057CEF25640938AC6DADFB94A4022C495B377F45640938AC6DADFB94A4022C495B377F45640C79E3D97A9B74A400E881057CEF25640C79E3D97A9B74A40
28323	Кызыл	5	45	\N	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
29675	Ак-Довурак	5	45	\N	90.486517000000006	90.622477000000003	51.202716000000002	51.161861000000002	0103000020E61000000100000005000000ADFC3218239F5640BABF7ADCB7944940ADFC3218239F56401F300F99F2994940C860C5A9D6A756401F300F99F2994940C860C5A9D6A75640BABF7ADCB7944940ADFC3218239F5640BABF7ADCB7944940
5045	Эрзин	5	45	724	95.147282000000004	95.177367000000004	50.265552999999997	50.252578	0103000020E6100000010000000500000087527B116DC9574034D8D4795420494087527B116DC95740662D05A4FD214940F0181EFB59CB5740662D05A4FD214940F0181EFB59CB574034D8D4795420494087527B116DC9574034D8D47954204940
59933	Нарын	5	45	724	95.556985999999995	95.580324000000005	50.203854999999997	50.193482000000003	0103000020E610000001000000050000001C959BA8A5E35740AE2EA704C41849401C959BA8A5E357402310AFEB171A49405F45460724E557402310AFEB171A49405F45460724E55740AE2EA704C41849401C959BA8A5E35740AE2EA704C4184940
59953	Морен	5	45	724	95.362689000000003	95.381545000000003	50.318537999999997	50.308793999999999	0103000020E610000001000000050000009D67EC4B36D75740BB99D18F862749409D67EC4B36D7574041446ADAC5284940F33CB83B6BD8574041446ADAC5284940F33CB83B6BD85740BB99D18F862749409D67EC4B36D75740BB99D18F86274940
5130	Булун-Бажы	5	45	724	95.206337000000005	95.222847999999999	50.271465999999997	50.265161999999997	0103000020E610000001000000050000001BBD1AA034CD57402B1213D4F02149401BBD1AA034CD5740EBFCDB65BF224940A8FE412443CE5740EBFCDB65BF224940A8FE412443CE57402B1213D4F02149401BBD1AA034CD57402B1213D4F0214940
59995	Бай-Даг	5	45	724	95.095035999999993	95.117116999999993	50.303046999999999	50.294817999999999	0103000020E6100000010000000500000054FCDF1115C65740D522A298BC25494054FCDF1115C6574051137D3ECA2649408F334DD87EC7574051137D3ECA2649408F334DD87EC75740D522A298BC25494054FCDF1115C65740D522A298BC254940
60036	Элегест	5	45	7500	93.948193000000003	93.97287	51.371813000000003	51.354559999999999	0103000020E61000000100000005000000F452B131AF7C5740213CDA3862AD4940F452B131AF7C5740249D819197AF49409C508880437E5740249D819197AF49409C508880437E5740213CDA3862AD4940F452B131AF7C5740213CDA3862AD4940
59963	Эйлиг-Хем	5	45	593	92.668902000000003	92.679232999999996	51.616410000000002	51.609513999999997	0103000020E61000000100000005000000A88E554ACF2A5740213A048E04CE4940A88E554ACF2A5740B476DB85E6CE49404B57B08D782B5740B476DB85E6CE49404B57B08D782B5740213A048E04CE4940A88E554ACF2A5740213A048E04CE4940
59981	Шанчы	5	45	593	91.960706000000002	91.968521999999993	51.609631999999998	51.601520999999998	0103000020E610000001000000050000008BC404357CFD5640B96DDFA3FECC49408BC404357CFD56402B4CDF6B08CE494037DDB243FCFD56402B4CDF6B08CE494037DDB243FCFD5640B96DDFA3FECC49408BC404357CFD5640B96DDFA3FECC4940
3725	Шагонар	5	45	593	92.901638000000005	92.941658000000004	51.544283999999998	51.512861000000001	0103000020E610000001000000050000002DB5DE6FB43957406A32E36DA5C149402DB5DE6FB439574037DE1D19ABC549401381EA1F443C574037DE1D19ABC549401381EA1F443C57406A32E36DA5C149402DB5DE6FB43957406A32E36DA5C14940
4045	Чодураа	5	45	593	92.875191000000001	92.893013999999994	51.387036000000002	51.366442999999997	0103000020E610000001000000050000003AB01C21033857408F6CAE9AE7AE49403AB01C2103385740F52F49658AB14940B037312427395740F52F49658AB14940B0373124273957408F6CAE9AE7AE49403AB01C21033857408F6CAE9AE7AE4940
4397	Чаа-Холь	5	45	593	92.325449000000006	92.347907000000006	51.521889999999999	51.507727000000003	0103000020E6100000010000000500000005E10A28D4145740EA25C632FDC0494005E10A28D4145740020EA14ACDC249402BC3B81B44165740020EA14ACDC249402BC3B81B44165740EA25C632FDC0494005E10A28D4145740EA25C632FDC04940
60026	Хайыракан	5	45	593	93.115994000000001	93.151764999999997	51.568089000000001	51.559640000000002	0103000020E61000000100000005000000102219726C47574048C49448A2C74940102219726C475740D21BEE23B7C849405BEB8B84B6495740D21BEE23B7C849405BEB8B84B649574048C49448A2C74940102219726C47574048C49448A2C74940
59932	Торгалыг	5	45	593	92.814195999999995	92.832718999999997	51.342678999999997	51.316132000000003	0103000020E610000001000000050000002D228AC91B3457400B9C6C0377A849402D228AC91B3457405303CDE7DCAB494080F0A1444B3557405303CDE7DCAB494080F0A1444B3557400B9C6C0377A849402D228AC91B3457400B9C6C0377A84940
59991	Ишти-Хем	5	45	593	92.461787000000001	92.477892999999995	51.321930000000002	51.316515000000003	0103000020E61000000100000005000000F3AD0FEB8D1D5740C3D8429083A84940F3AD0FEB8D1D5740F7CC920035A94940307F85CC951E5740F7CC920035A94940307F85CC951E5740C3D8429083A84940F3AD0FEB8D1D5740C3D8429083A84940
59993	Ийи-Тал	5	45	593	93.329155	93.347768000000002	51.569280999999997	51.560357000000003	0103000020E61000000100000005000000271422E010555740D78A36C7B9C74940271422E010555740F99D2633DEC849401AA6B6D441565740F99D2633DEC849401AA6B6D441565740D78A36C7B9C74940271422E010555740D78A36C7B9C74940
59988	Арыскан	5	45	593	92.700280000000006	92.712399000000005	51.412356000000003	51.398164000000001	0103000020E61000000100000005000000BF823463D12C5740E738B709F7B24940BF823463D12C57409A27D714C8B4494000ADF9F1972D57409A27D714C8B4494000ADF9F1972D5740E738B709F7B24940BF823463D12C5740E738B709F7B24940
59997	Арыг-Узю	5	45	593	92.584361999999999	92.604097999999993	51.432321999999999	51.414777000000001	0103000020E610000001000000050000009CC1DF2F662557400611A96917B549409CC1DF2F66255740B0ABC95356B749400E65A88AA9265740B0ABC95356B749400E65A88AA92657400611A96917B549409CC1DF2F662557400611A96917B54940
59980	Арыг-Бажы	5	45	593	93.046768999999998	93.066775000000007	51.452353000000002	51.423887999999998	0103000020E61000000100000005000000DD5D6743FE4257405B9544F641B64940DD5D6743FE425740AE9FFEB3E6B94940304CA60A46445740AE9FFEB3E6B94940304CA60A464457405B9544F641B64940DD5D6743FE4257405B9544F641B64940
59951	Ак-Дуруг	5	45	593	92.190370000000001	92.234269999999995	51.411059000000002	51.375776999999999	0103000020E61000000100000005000000EE08A7052F0C574064CBF27519B04940EE08A7052F0C5740FDDCD0949DB44940C51B9947FE0E5740FDDCD0949DB44940C51B9947FE0E574064CBF27519B04940EE08A7052F0C574064CBF27519B04940
59975	Ырбан	5	45	551	95.710543999999999	95.743331999999995	52.716712999999999	52.707051	0103000020E610000001000000050000009E978A8D79ED574053CDACA5805A4A409E978A8D79ED57401CCF6740BD5B4A407F8461C092EF57401CCF6740BD5B4A407F8461C092EF574053CDACA5805A4A409E978A8D79ED574053CDACA5805A4A40
3402	Тоора-Хем	5	45	551	96.111058	96.129123000000007	52.473410000000001	52.458092000000001	0103000020E61000000100000005000000637D03931B075840954737C2A23A4A40637D03931B075840B8CCE9B2983C4A40558A1D8D43085840B8CCE9B2983C4A40558A1D8D43085840954737C2A23A4A40637D03931B075840954737C2A23A4A40
59960	Сыстыг-Хем	5	45	551	95.492181000000002	95.516830999999996	52.669364999999999	52.663362999999997	0103000020E610000001000000050000009BADBCE47FDF57402F302B14E9544A409BADBCE47FDF5740240B98C0AD554A40C6A354C213E15740240B98C0AD554A40C6A354C213E157402F302B14E9544A409BADBCE47FDF57402F302B14E9544A40
59944	Ий	5	45	551	94.475998000000004	99.269695999999996	53.726095999999998	51.593497999999997	0103000020E6100000010000000500000088BD50C0769E5740E61E12BEF7CB494088BD50C0769E5740D2E0B6B6F0DC4A402BF702B342D15840D2E0B6B6F0DC4A402BF702B342D15840E61E12BEF7CB494088BD50C0769E5740E61E12BEF7CB4940
59968	Адыр-Кежиг	5	45	551	96.233847999999995	96.252011999999993	52.453119999999998	52.444788000000003	0103000020E610000001000000050000000A0F9A5DF70E58409ED32CD0EE384A400A0F9A5DF70E5840EE940ED6FF394A40C58CF0F620105840EE940ED6FF394A40C58CF0F6201058409ED32CD0EE384A400A0F9A5DF70E58409ED32CD0EE384A40
60061	сумон Чыргаланды	5	45	500	93.115094999999997	95.612493000000001	50.995496000000003	50.143520000000002	0103000020E61000000100000005000000B83B6BB75D475740352905DD5E124940B83B6BB75D47574040A6B5696C7F4940DA01D71533E7574040A6B5696C7F4940DA01D71533E75740352905DD5E124940B83B6BB75D475740352905DD5E124940
59956	Шуурмак	5	45	500	95.322183999999993	95.338345000000004	50.657606999999999	50.643649000000003	0103000020E61000000100000005000000D8D2A3A99ED45740338D261763524940D8D2A3A99ED45740724F57772C544940F870C971A7D55740724F57772C544940F870C971A7D55740338D261763524940D8D2A3A99ED45740338D261763524940
3012	Самагалтай	5	45	500	94.990104000000002	95.020331999999996	50.609586999999998	50.589821999999998	0103000020E61000000100000005000000E2E82ADD5DBF57400C3B8C497F4B4940E2E82ADD5DBF57408B8862F2064E4940FCC3961E4DC157408B8862F2064E4940FCC3961E4DC157400C3B8C497F4B4940E2E82ADD5DBF57400C3B8C497F4B4940
60066	Оо-Шынаа	5	45	500	93.732444999999998	93.754328000000001	50.660181999999999	50.65249	0103000020E610000001000000050000009947FE60E06E5740C87BD5CA845349409947FE60E06E574035B401D880544940419DF2E84670574035B401D880544940419DF2E846705740C87BD5CA845349409947FE60E06E5740C87BD5CA84534940
59950	О-Шынаа	5	45	500	93.115094999999997	95.612493000000001	50.995496000000003	50.143520000000002	0103000020E61000000100000005000000B83B6BB75D475740352905DD5E124940B83B6BB75D47574040A6B5696C7F4940DA01D71533E7574040A6B5696C7F4940DA01D71533E75740352905DD5E124940B83B6BB75D475740352905DD5E124940
59940	Берт-Даг	5	45	500	94.783535999999998	94.799741999999995	50.634062999999998	50.619	0103000020E6100000010000000500000046CF2D7425B25740AC1C5A643B4F494046CF2D7425B25740444DF4F92851494035CF11F92EB35740444DF4F92851494035CF11F92EB35740AC1C5A643B4F494046CF2D7425B25740AC1C5A643B4F4940
3355	Ак-Эрик	5	45	500	94.607116000000005	94.626861000000005	50.520530000000001	50.512213000000003	0103000020E61000000100000005000000373811FDDAA6574004CB113290414940373811FDDAA657401F4B1FBAA0424940D388997D1EA857401F4B1FBAA0424940D388997D1EA8574004CB113290414940373811FDDAA6574004CB113290414940
59999	Кунгуртуг	5	45	7499	97.514584999999997	97.533171999999993	50.603949999999998	50.592697999999999	0103000020E61000000100000005000000C780ECF5EE605840CA332F87DD4B4940C780ECF5EE605840A835CD3B4E4D494025C9737D1F625840A835CD3B4E4D494025C9737D1F625840CA332F87DD4B4940C780ECF5EE605840CA332F87DD4B4940
59992	Чал-Кежиг (Элегест)	5	45	424	93.926409000000007	93.93665	51.303424999999997	51.293152999999997	0103000020E61000000100000005000000166EF9484A7B5740B5DC990986A54940166EF9484A7B5740F7E461A1D6A649401973D712F27B5740F7E461A1D6A649401973D712F27B5740B5DC990986A54940166EF9484A7B5740B5DC990986A54940
4687	Хову-Аксы	5	45	424	93.699969999999993	93.728375	51.139651999999998	51.124889000000003	0103000020E61000000100000005000000978BF84ECC6C5740A950DD5CFC8F4940978BF84ECC6C57401669E21DE0914940560E2DB29D6E57401669E21DE0914940560E2DB29D6E5740A950DD5CFC8F4940978BF84ECC6C5740A950DD5CFC8F4940
59973	Усть-Хадын (Хадын-Аксы)	5	45	424	94.560097999999996	94.572765000000004	51.291373	51.286776000000003	0103000020E61000000100000005000000852348A5D8A357408CA37213B5A44940852348A5D8A35740FDF7E0B54BA54940C8D2872EA8A45740FDF7E0B54BA54940C8D2872EA8A457408CA37213B5A44940852348A5D8A357408CA37213B5A44940
59987	Успенка	5	45	424	94.240226000000007	94.254321000000004	51.24174	51.230806000000001	0103000020E610000001000000050000008869DFDC5F8F57403CDC0E0D8B9D49408869DFDC5F8F574049111956F19E4940E86B96CB4690574049111956F19E4940E86B96CB469057403CDC0E0D8B9D49408869DFDC5F8F57403CDC0E0D8B9D4940
59972	Сосновка	5	45	424	94.511921999999998	94.532673000000003	51.154111	51.121254	0103000020E6100000010000000500000096067E54C3A057402D414640858F494096067E54C3A05740187AC4E8B9934940959D7E5017A25740187AC4E8B9934940959D7E5017A257402D414640858F494096067E54C3A057402D414640858F4940
59971	Сой	5	45	424	95.218276000000003	95.236997000000002	51.008482000000001	50.999861000000003	0103000020E610000001000000050000001C60E63BF8CD5740DFC5FB71FB7F49401C60E63BF8CD5740664D2CF015814940021077F52ACF5740664D2CF015814940021077F52ACF5740DFC5FB71FB7F49401C60E63BF8CD5740DFC5FB71FB7F4940
59996	Сайлыг	5	45	424	93.666714999999996	93.701345000000003	51.132677999999999	51.113326999999998	0103000020E610000001000000050000002B306475AB6A57407C60C77F818E49402B306475AB6A57400873BB97FB904940A48D23D6E26C57400873BB97FB904940A48D23D6E26C57407C60C77F818E49402B306475AB6A57407C60C77F818E4940
32656	Межегей (Алаак)	5	45	424	94.312755999999993	94.332617999999997	51.269264999999997	51.251190000000001	0103000020E610000001000000050000002DE8BD3104945740878A71FE26A049402DE8BD31049457408D7A884677A24940E603029D499557408D7A884677A24940E603029D49955740878A71FE26A049402DE8BD3104945740878A71FE26A04940
59961	Кызыл-Арыг (Кызларик)	5	45	424	95.194667999999993	95.203507999999999	50.931296000000003	50.915227999999999	0103000020E61000000100000005000000F964C57075CC57401631EC3026754940F964C57075CC5740A47213B5347749405C1E6B4606CD5740A47213B5347749405C1E6B4606CD57401631EC3026754940F964C57075CC57401631EC3026754940
32675	Кочетово	5	45	424	94.050196999999997	94.073723999999999	51.351802999999997	51.336371	0103000020E61000000100000005000000DE567A6D36835740522976340EAB4940DE567A6D368357403DD175E107AD49408A3BDEE4B78457403DD175E107AD49408A3BDEE4B7845740522976340EAB4940DE567A6D36835740522976340EAB4940
59937	Дурген	5	45	424	94.489553999999998	94.514159000000006	51.154370999999998	51.137397	0103000020E6100000010000000500000010E84CDA549F5740C5C892399691494010E84CDA549F5740B439CE6DC29349406C7C26FBE7A05740B439CE6DC29349406C7C26FBE7A05740C5C892399691494010E84CDA549F5740C5C8923996914940
2691	Владимировка	5	45	424	95.285343999999995	95.326010999999994	51.016261999999998	50.994782000000001	0103000020E6100000010000000500000007077B1343D2574022533E04557F494007077B1343D2574072158BDF14824940B8C83D5DDDD4574072158BDF14824940B8C83D5DDDD4574022533E04557F494007077B1343D2574022533E04557F4940
59910	Балгазын	5	45	424	95.154109000000005	95.198549	51.011032	50.984684000000001	0103000020E610000001000000050000003CC1FEEBDCC957407E7214200A7E49403CC1FEEBDCC95740D09A1F7F69814940D369DD06B5CC5740D09A1F7F69814940D369DD06B5CC57407E7214200A7E49403CC1FEEBDCC957407E7214200A7E4940
2302	Бай-Хаак	5	45	424	94.447252000000006	94.480642000000003	51.168255000000002	51.150664999999996	0103000020E610000001000000050000008544DAC69F9C57406FD39FFD489349408544DAC69F9C5740BA313D618995494061C5A9D6C29E5740BA313D618995494061C5A9D6C29E57406FD39FFD489349408544DAC69F9C57406FD39FFD48934940
2095	Суг-Аксы	5	45	360	91.252915000000002	91.296537000000001	51.409923999999997	51.392268999999999	0103000020E61000000100000005000000BE6A65C22FD05640081EDFDE35B24940BE6A65C22FD0564039ECBE6378B4494074435376FAD2564039ECBE6378B4494074435376FAD25640081EDFDE35B24940BE6A65C22FD05640081EDFDE35B24940
59982	Кызыл-Тайга	5	45	360	91.376514	91.403760000000005	51.485185999999999	51.473894000000001	0103000020E610000001000000050000001D1F2DCE18D85640A4E2FF8EA8BC49401D1F2DCE18D85640103D29931ABE4940B6DB2E34D7D95640103D29931ABE4940B6DB2E34D7D95640A4E2FF8EA8BC49401D1F2DCE18D85640A4E2FF8EA8BC4940
59947	Кара-Чыраа	5	45	360	91.295700999999994	91.333206000000004	51.426948000000003	51.408271999999997	0103000020E610000001000000050000003F19E3C3ECD25640AEEFC34142B449403F19E3C3ECD25640DB8B683BA6B649402F35423F53D55640DB8B683BA6B649402F35423F53D55640AEEFC34142B449403F19E3C3ECD25640AEEFC34142B44940
59957	Ишкин	5	45	360	91.458072000000001	91.492988999999994	51.573065999999997	51.560872000000003	0103000020E61000000100000005000000A7CD380D51DD5640FE9E58A7CAC74940A7CD380D51DD56408A39083A5AC949406A12BC218DDF56408A39083A5AC949406A12BC218DDF5640FE9E58A7CAC74940A7CD380D51DD5640FE9E58A7CAC74940
59954	Бора-Тайга	5	45	360	91.129136000000003	91.163910000000001	51.407429	51.400928999999998	0103000020E610000001000000050000001F2FA4C343C856404D8237A451B349401F2FA4C343C8564093382BA226B44940315F5E807DCA564093382BA226B44940315F5E807DCA56404D8237A451B349401F2FA4C343C856404D8237A451B34940
60001	Баян-Тала	5	45	360	91.425139999999999	91.437895999999995	51.469805000000001	51.435746999999999	0103000020E610000001000000050000002C0E677E35DB5640412AC58EC6B749402C0E677E35DB5640A73FFB9122BC494026C3F17C06DC5640A73FFB9122BC494026C3F17C06DC5640412AC58EC6B749402C0E677E35DB5640412AC58EC6B74940
32570	Алдан-Маадыр	5	45	360	90.957279	90.983923000000004	51.302061999999999	51.291091000000002	0103000020E610000001000000050000007289230F44BD564079944A7842A549407289230F44BD5640A3AEB5F7A9A6494010B22C98F8BE5640A3AEB5F7A9A6494010B22C98F8BE564079944A7842A549407289230F44BD564079944A7842A54940
59985	Ак-Даш	5	45	360	91.115921999999998	91.135594999999995	51.344068	51.332016000000003	0103000020E61000000100000005000000C3B81B446BC75640D7DF12807FAA4940C3B81B446BC75640D1CC936B0AAC494012A0A696ADC85640D1CC936B0AAC494012A0A696ADC85640D7DF12807FAA4940C3B81B446BC75640D7DF12807FAA4940
59949	Ээрбек	5	45	263	94.204239999999999	94.217884999999995	51.658529000000001	51.647018000000003	0103000020E610000001000000050000003E22A644128D574030F65E7CD1D249403E22A644128D5740DA3BA3AD4AD449407E52EDD3F18D5740DA3BA3AD4AD449407E52EDD3F18D574030F65E7CD1D249403E22A644128D574030F65E7CD1D24940
1790	Шивилиг	5	45	263	93.705934999999997	93.728672000000003	52.243848	52.229337999999998	0103000020E610000001000000050000008386FE092E6D574072DD94F25A1D4A408386FE092E6D5740F6984869361F4A40B360E28FA26E5740F6984869361F4A40B360E28FA26E574072DD94F25A1D4A408386FE092E6D574072DD94F25A1D4A40
60002	Холчук	5	45	263	92.886707999999999	95.072794000000002	52.914459999999998	51.552097000000003	0103000020E610000001000000050000008046E9D2BF385740209C4F1DABC649408046E9D2BF38574005C078060D754A4015562AA8A8C4574005C078060D754A4015562AA8A8C45740209C4F1DABC649408046E9D2BF385740209C4F1DABC64940
59934	Уюк	5	45	263	94.013437999999994	94.046126999999998	52.081142	52.073686000000002	0103000020E6100000010000000500000083A10E2BDC8057402716F88A6E094A4083A10E2BDC805740802A6EDC620A4A409B1DA9BEF3825740802A6EDC620A4A409B1DA9BEF38257402716F88A6E094A4083A10E2BDC8057402716F88A6E094A40
1113	Туран	5	45	263	93.901696000000001	93.932023000000001	52.162205	52.128028999999998	0103000020E61000000100000005000000C7BB2363B579574044F8174163104A40C7BB2363B5795740B41F2922C3144A40AB07CC43A67B5740B41F2922C3144A40AB07CC43A67B574044F8174163104A40C7BB2363B579574044F8174163104A40
59979	Тарлаг	5	45	263	93.403176000000002	93.416066999999998	52.071255999999998	52.063217000000002	0103000020E610000001000000050000000EA2B5A2CD5957408FC6A17E17084A400EA2B5A2CD59574067D2A6EA1E094A40787C7BD7A05A574067D2A6EA1E094A40787C7BD7A05A57408FC6A17E17084A400EA2B5A2CD5957408FC6A17E17084A40
59976	Суш	5	45	263	94.158479999999997	94.180335999999997	52.064861999999998	52.060155999999999	0103000020E610000001000000050000007C444C89248A57403F541A31B3074A407C444C89248A57406760E4654D084A40A79201A08A8B57406760E4654D084A40A79201A08A8B57403F541A31B3074A407C444C89248A57403F541A31B3074A40
59952	Сесерлиг (Германовка)	5	45	263	94.247943000000006	94.267266000000006	51.882126999999997	51.872726	0103000020E610000001000000050000006B11514CDE8F5740382F4E7CB5EF49406B11514CDE8F574094F59B89E9F049404C55DAE21A91574094F59B89E9F049404C55DAE21A915740382F4E7CB5EF49406B11514CDE8F5740382F4E7CB5EF4940
1886	Найырал	5	45	263	93.936819999999997	93.948705000000004	52.156658	52.141472999999998	0103000020E61000000100000005000000478FDFDBF47B57402D228AC91B124A40478FDFDBF47B574011548D5E0D144A404F232D95B77C574011548D5E0D144A404F232D95B77C57402D228AC91B124A40478FDFDBF47B57402D228AC91B124A40
59922	Аржаан	5	45	263	93.593762999999996	93.616759999999999	52.065316000000003	52.054268999999998	0103000020E61000000100000005000000CAA4863600665740E3175E49F2064A40CAA4863600665740E9F351465C084A40C85EEFFE78675740E9F351465C084A40C85EEFFE78675740E3175E49F2064A40CAA4863600665740E3175E49F2064A40
789	Чаа-Суур (Арыг-Бажы)	5	45	196	92.755069000000006	92.765534000000002	50.833779999999997	50.820368999999999	0103000020E610000001000000050000004D4EED0C533057407CD3F4D9016949404D4EED0C533057408907944DB96A4940787E5182FE3057408907944DB96A4940787E5182FE3057407CD3F4D9016949404D4EED0C533057407CD3F4D901694940
914	Хандагайты	5	45	196	92.069654	92.089183000000006	50.738480000000003	50.727699999999999	0103000020E6100000010000000500000047020D36750457404CA60A46255D494047020D367504574003603C83865E4940FD169D2CB505574003603C83865E4940FD169D2CB50557404CA60A46255D494047020D36750457404CA60A46255D4940
988	Солчур (Арыг-Бажы)	5	45	196	92.028205999999997	92.043494999999993	50.756787000000003	50.747360999999998	0103000020E6100000010000000500000043E38920CE01574026A77686A95F494043E38920CE015740DC847B65DE60494087A2409FC8025740DC847B65DE60494087A2409FC802574026A77686A95F494043E38920CE01574026A77686A95F4940
1015	Саглы	5	45	196	91.310873999999998	91.339431000000005	50.497100000000003	50.491106000000002	0103000020E610000001000000050000004FCB0F5CE5D35640486FB88FDC3E49404FCB0F5CE5D35640BA6B09F9A03F4940E90FCD3CB9D55640BA6B09F9A03F4940E90FCD3CB9D55640486FB88FDC3E49404FCB0F5CE5D35640486FB88FDC3E4940
849	Дус-Даг	5	45	196	92.675010999999998	92.685045000000002	50.819856999999999	50.807524000000001	0103000020E610000001000000050000002D5C5661332B5740185E49F25C6749402D5C5661332B5740C632FD12F168494074D2FBC6D72B5740C632FD12F168494074D2FBC6D72B5740185E49F25C6749402D5C5661332B5740185E49F25C674940
730	Ак-Чыраа	5	45	196	93.230941999999999	93.243779000000004	50.700808000000002	50.694892000000003	0103000020E610000001000000050000007651F4C0C74E574043209738F25849407651F4C0C74E574039639813B4594940E71C3C139A4F574039639813B4594940E71C3C139A4F574043209738F25849407651F4C0C74E574043209738F2584940
542	Мугур-Аксы	5	45	171	90.430713999999995	90.457042999999999	50.384590000000003	50.376531	0103000020E610000001000000050000007AFB73D1909B56401077F52A323049407AFB73D1909B5640302FC03E3A31494068774831409D5640302FC03E3A31494068774831409D56401077F52A323049407AFB73D1909B56401077F52A32304940
59959	Кызыл-Хая	5	45	171	89.866607999999999	89.870622999999995	50.048026	50.044504000000003	0103000020E61000000100000005000000ED9C66817677564046459C4EB2054940ED9C668176775640C9AD49B7250649404E098849B8775640C9AD49B7250649404E098849B877564046459C4EB2054940ED9C66817677564046459C4EB2054940
59967	Шамбалыг	5	45	1924	95.077743999999996	95.097577999999999	51.248128000000001	51.235464	0103000020E61000000100000005000000745DF8C1F9C4574053B131AF239E4940745DF8C1F9C45740679C86A8C29F4940C8B3CBB73EC65740679C86A8C29F4940C8B3CBB73EC6574053B131AF239E4940745DF8C1F9C4574053B131AF239E4940
59948	Черби	5	45	1924	94.574264999999997	94.607988000000006	51.893028000000001	51.880015	0103000020E61000000100000005000000328FFCC1C0A45740A67EDE54A4F04940328FFCC1C0A45740C634D3BD4EF2494012178046E9A65740C634D3BD4EF2494012178046E9A65740A67EDE54A4F04940328FFCC1C0A45740A67EDE54A4F04940
59921	Целинное	5	45	1924	94.795249999999996	94.815174999999996	51.337918999999999	51.322172000000002	0103000020E6100000010000000500000037894160E5B25740EDD79DEE3CA9494037894160E5B2574038D906EE40AB49401361C3D32BB4574038D906EE40AB49401361C3D32BB45740EDD79DEE3CA9494037894160E5B25740EDD79DEE3CA94940
59936	Усть-Элегест	5	45	1924	94.068612000000002	94.109836000000001	51.568821999999997	51.559936999999998	0103000020E610000001000000050000003E079623648457400169FF03ACC749403E07962364845740669FC728CFC849401AFB928D07875740669FC728CFC849401AFB928D078757400169FF03ACC749403E079623648457400169FF03ACC74940
59998	Терлиг-Хая	5	45	1924	93.518806999999995	93.527557000000002	51.715381000000001	51.698152	0103000020E61000000100000005000000E57B46223461574089D1730B5DD94940E57B4622346157400397C79A91DB4940A8716F7EC36157400397C79A91DB4940A8716F7EC361574089D1730B5DD94940E57B46223461574089D1730B5DD94940
33070	Сукпак	5	45	1924	94.247152	94.281576000000001	51.652774000000001	51.633519999999997	0103000020E6100000010000000500000006499F56D18F574053AEF02E17D1494006499F56D18F5740EDD632198ED34940AAD5575705925740EDD632198ED34940AAD557570592574053AEF02E17D1494006499F56D18F574053AEF02E17D14940
59925	Кунгуртуг	5	45	1924	97.514584999999997	97.533171999999993	50.603949999999998	50.592697999999999	0103000020E61000000100000005000000C780ECF5EE605840CA332F87DD4B4940C780ECF5EE605840A835CD3B4E4D494025C9737D1F625840A835CD3B4E4D494025C9737D1F625840CA332F87DD4B4940C780ECF5EE605840CA332F87DD4B4940
59919	Кара-Хаак	5	45	1924	94.448437999999996	94.469044999999994	51.897824	51.883740000000003	0103000020E6100000010000000500000027124C35B39C574062156F641EF1494027124C35B39C57402EC896E5EBF249408CD651D5049E57402EC896E5EBF249408CD651D5049E574062156F641EF1494027124C35B39C574062156F641EF14940
32233	Каа-Хем	5	45	1924	94.544881000000004	94.618471	51.704923000000001	51.673488999999996	0103000020E610000001000000050000008ECD8E54DFA257409D9B36E334D649408ECD8E54DFA257405F99B7EA3ADA494090A1630795A757405F99B7EA3ADA494090A1630795A757409D9B36E334D649408ECD8E54DFA257409D9B36E334D64940
59939	Баян-Кол	5	45	1924	93.527422000000001	93.573362000000003	51.590141000000003	51.574185	0103000020E61000000100000005000000384C3448C1615740486DE2E47EC94940384C3448C1615740AE8383BD89CB49403AB187F6B1645740AE8383BD89CB49403AB187F6B1645740486DE2E47EC94940384C3448C1615740486DE2E47EC94940
59984	Эржей	5	45	1929	95.923022000000003	95.938823999999997	51.340141000000003	51.334226999999998	0103000020E6100000010000000500000044DFDDCA12FB5740583849F3C7AA494044DFDDCA12FB5740AE8383BD89AB4940CB2C42B115FC5740AE8383BD89AB4940CB2C42B115FC5740583849F3C7AA494044DFDDCA12FB5740583849F3C7AA4940
59983	Усть-Ужеп	5	45	1929	96.243002000000004	96.253647000000001	51.340113000000002	51.329887999999997	0103000020E6100000010000000500000035B742588D0F5840E2AB1DC539AA494035B742588D0F5840E4F8A1D288AB4940A06EA0C03B105840E4F8A1D288AB4940A06EA0C03B105840E2AB1DC539AA494035B742588D0F5840E2AB1DC539AA4940
59966	Усть-Бурен (Грязнуха)	5	45	1929	95.644508999999999	95.667046999999997	51.421753000000002	51.382168999999998	0103000020E61000000100000005000000923EADA23FE95740C345EEE9EAB04940923EADA23FE95740B5FE9600FCB549404679E6E5B0EA5740B5FE9600FCB549404679E6E5B0EA5740C345EEE9EAB04940923EADA23FE95740C345EEE9EAB04940
59941	Суг-Бажы	5	45	1929	94.843005000000005	94.868714999999995	51.660853000000003	51.646034	0103000020E6100000010000000500000054573ECBF3B55740520DFB3DB1D2494054573ECBF3B55740543BC3D496D44940DBA2CC0699B75740543BC3D496D44940DBA2CC0699B75740520DFB3DB1D2494054573ECBF3B55740520DFB3DB1D24940
59978	Сизим	5	45	1929	95.937349999999995	95.947888000000006	51.322279000000002	51.312421999999998	0103000020E61000000100000005000000F5B9DA8AFDFB57408446B071FDA74940F5B9DA8AFDFB57400398327040A9494056116E32AAFC57400398327040A9494056116E32AAFC57408446B071FDA74940F5B9DA8AFDFB57408446B071FDA74940
59916	Сарыг-Сеп (Знаменка)	5	45	1929	95.530574999999999	95.585130000000007	51.505524000000001	51.476115999999998	0103000020E61000000100000005000000D044D8F0F4E15740198D7C5EF1BC4940D044D8F0F4E15740EBABAB02B5C04940257A19C572E55740EBABAB02B5C04940257A19C572E55740198D7C5EF1BC4940D044D8F0F4E15740198D7C5EF1BC4940
59924	Кундустуг (Федоровка)	5	45	1929	95.168769999999995	95.191057000000001	51.580756000000001	51.568334999999998	0103000020E61000000100000005000000F0A2AF20CDCA574009168733BFC84940F0A2AF20CDCA5740577A6D3656CA494000AB23473ACC5740577A6D3656CA494000AB23473ACC574009168733BFC84940F0A2AF20CDCA574009168733BFC84940
60003	Кок-Хаак	5	45	1929	95.469014000000001	95.505018000000007	51.517710000000001	51.505456000000002	0103000020E610000001000000050000006FD74B5304DE574093C83EC8B2C049406FD74B5304DE5740F5673F5244C249400C79043752E05740F5673F5244C249400C79043752E0574093C83EC8B2C049406FD74B5304DE574093C83EC8B2C04940
33020	Ильинка	5	45	1929	95.462644999999995	95.499403999999998	51.127664000000003	51.106828999999998	0103000020E610000001000000050000001B2AC6F99BDD5740D7A19A92AC8D49401B2AC6F99BDD57403370404B5790494076DF313CF6DF57403370404B5790494076DF313CF6DF5740D7A19A92AC8D49401B2AC6F99BDD5740D7A19A92AC8D4940
59935	Дерзиг-Аксы (Даниловка)	5	45	1929	95.590779999999995	95.622050999999999	51.460642	51.451605999999998	0103000020E6100000010000000500000060C8EA56CFE55740B456B439CEB9494060C8EA56CFE55740FF942A51F6BA49406C5CFFAECFE75740FF942A51F6BA49406C5CFFAECFE75740B456B439CEB9494060C8EA56CFE55740B456B439CEB94940
59930	Бурен-Хем (Зубовка)	5	45	1929	94.986339999999998	95.026557999999994	51.657209999999999	51.622863000000002	0103000020E6100000010000000500000025AFCE3120BF5740B9718BF9B9CF494025AFCE3120BF5740554D10751FD449409E5C5320B3C15740554D10751FD449409E5C5320B3C15740B9718BF9B9CF494025AFCE3120BF5740B9718BF9B9CF4940
59969	Бурен-Бай-Хаак	5	45	1929	95.545613000000003	95.564406000000005	51.251167000000002	51.237623999999997	0103000020E6100000010000000500000070D1C952EBE25740525F96766A9E494070D1C952EBE25740CF6A813D26A04940A3EA573A1FE45740CF6A813D26A04940A3EA573A1FE45740525F96766A9E494070D1C952EBE25740525F96766A9E4940
59986	Бояровка	5	45	1929	95.340106000000006	95.363561000000004	51.545673000000001	51.531320999999998	0103000020E6100000010000000500000019CBF44BC4D55740C956975302C4494019CBF44BC4D55740B5A7E49CD8C5494078465B9544D75740B5A7E49CD8C5494078465B9544D75740C956975302C4494019CBF44BC4D55740C956975302C44940
59994	Авыйган	5	45	1929	95.588059000000001	95.598713000000004	51.324412000000002	51.317219000000001	0103000020E61000000100000005000000954737C2A2E55740BD55D7A19AA84940954737C2A2E557400937195586A949402AAC545051E657400937195586A949402AAC545051E65740BD55D7A19AA84940954737C2A2E55740BD55D7A19AA84940
59912	Сарыг-Сеп (Знаменка)	5	45	7496	95.530574999999999	95.585130000000007	51.505524000000001	51.476115999999998	0103000020E61000000100000005000000D044D8F0F4E15740198D7C5EF1BC4940D044D8F0F4E15740EBABAB02B5C04940257A19C572E55740EBABAB02B5C04940257A19C572E55740198D7C5EF1BC4940D044D8F0F4E15740198D7C5EF1BC4940
60027	Ийме	5	45	7502	91.580584000000002	91.604281999999998	51.588344999999997	51.573838000000002	0103000020E610000001000000050000002D25CB4928E55640DD99098673C949402D25CB4928E55640EFE192E34ECB4940EFE3688EACE65640EFE192E34ECB4940EFE3688EACE65640DD99098673C949402D25CB4928E55640DD99098673C94940
59990	Элдиг-Хем	5	45	1904	91.099356999999998	91.113083000000003	50.871043	50.867421999999998	0103000020E610000001000000050000003C6876DD5BC656405BEA20AF076F49403C6876DD5BC65640723447567E6F4940F3AE7AC03CC75640723447567E6F4940F3AE7AC03CC756405BEA20AF076F49403C6876DD5BC656405BEA20AF076F4940
59918	Шеми	5	45	1904	91.283654999999996	91.299861000000007	51.166328999999998	51.148116999999999	0103000020E6100000010000000500000033164D6727D25640A67D737FF592494033164D6727D256402DB0C7444A954940231631EC30D356402DB0C7444A954940231631EC30D35640A67D737FF592494033164D6727D25640A67D737FF5924940
59970	Чыргакы	5	45	1904	91.000955000000005	91.010324999999995	51.073858999999999	51.057789	0103000020E6100000010000000500000022718FA50FC05640C68844A16587494022718FA50FC05640F4C13236748949403255302AA9C05640F4C13236748949403255302AA9C05640C68844A16587494022718FA50FC05640C68844A165874940
59938	Чыраа-Бажы	5	45	1904	91.047460999999998	91.059364000000002	51.179549000000002	51.162647	0103000020E6100000010000000500000078B5DC9909C3564071E5EC9DD194494078B5DC9909C35640C7832D76FB964940D3A3A99ECCC35640C7832D76FB964940D3A3A99ECCC3564071E5EC9DD194494078B5DC9909C3564071E5EC9DD1944940
30824	Чадан	5	45	1904	91.526478999999995	91.608575999999999	51.308228	51.274309000000002	0103000020E61000000100000005000000F8C1F9D4B1E15640CEFFAB8E1CA34940F8C1F9D4B1E1564012DBDD0374A749405A48C0E8F2E6564012DBDD0374A749405A48C0E8F2E65640CEFFAB8E1CA34940F8C1F9D4B1E15640CEFFAB8E1CA34940
59958	Хорум-Даг	5	45	1904	91.039439000000002	91.057540000000003	51.286022000000003	51.277098000000002	0103000020E61000000100000005000000F7CB272B86C25640BDE47FF277A34940F7CB272B86C25640E0F76F5E9CA449408F8D40BCAEC35640E0F76F5E9CA449408F8D40BCAEC35640BDE47FF277A34940F7CB272B86C25640BDE47FF277A34940
59965	Хондергей	5	45	1904	91.609806000000006	91.629165	51.132559000000001	51.120337999999997	0103000020E61000000100000005000000E5B9BE0F07E75640A73B4F3C678F4940E5B9BE0F07E756402EE57CB1F79049406CB2463D44E856402EE57CB1F79049406CB2463D44E85640A73B4F3C678F4940E5B9BE0F07E75640A73B4F3C678F4940
59977	Хайыракан	5	45	1904	91.547597999999994	91.569875999999994	51.301527	51.290629000000003	0103000020E61000000100000005000000B8567BD80BE356407522C15433A54940B8567BD80BE3564035EECD6F98A649409EB12FD978E4564035EECD6F98A649409EB12FD978E456407522C15433A54940B8567BD80BE356407522C15433A54940
59917	Теве-Хая	5	45	1904	91.441264000000004	91.461664999999996	51.371498000000003	51.360942999999999	0103000020E61000000100000005000000BD395CAB3DDC56402D5C566133AE4940BD395CAB3DDC5640C443183F8DAF49404D2D5BEB8BDD5640C443183F8DAF49404D2D5BEB8BDD56402D5C566133AE4940BD395CAB3DDC56402D5C566133AE4940
59926	Бажын-Алаак	5	45	1904	91.719149000000002	91.746431000000001	51.236485000000002	51.224623999999999	0103000020E61000000100000005000000DFFC868906EE5640C7F2AE7AC09C4940DFFC868906EE56404E7FF623459E49401E6E8786C5EF56404E7FF623459E49401E6E8786C5EF5640C7F2AE7AC09C4940DFFC868906EE5640C7F2AE7AC09C4940
30767	Эрги-Барлык	5	45	1890	90.392571000000004	90.417652000000004	50.941234999999999	50.927242999999997	0103000020E61000000100000005000000EA961DE21F995640F3380CE6AF764940EA961DE21F995640DF6C73637A784940FA4674CFBA9A5640DF6C73637A784940FA4674CFBA9A5640F3380CE6AF764940EA961DE21F995640F3380CE6AF764940
30668	Шекпээр (Биче-Тей)	5	45	1890	90.670760999999999	90.691387000000006	51.175533999999999	51.162291000000003	0103000020E61000000100000005000000AA9B8BBFEDAA5640B3B794F3C5944940AA9B8BBFEDAA564004ABEAE5779649404B7842AF3FAC564004ABEAE5779649404B7842AF3FAC5640B3B794F3C5944940AA9B8BBFEDAA5640B3B794F3C5944940
30671	Хонделен	5	45	1890	90.291475000000005	90.318378999999993	51.258986	51.249831	0103000020E610000001000000050000008126C286A792564074435376FA9F49408126C286A7925640990F087426A14940EC2E505260945640990F087426A14940EC2E50526094564074435376FA9F49408126C286A792564074435376FA9F4940
30265	Кызыл-Мажалык (Барун)	5	45	1890	90.549992000000003	90.598887000000005	51.155138999999998	51.133451999999998	0103000020E61000000100000005000000F243A51133A35640FBCA83F414914940F243A51133A35640C5AA4198DB934940F9BF232A54A65640C5AA4198DB934940F9BF232A54A65640FBCA83F414914940F243A51133A35640FBCA83F414914940
30589	Дон-Терезин	5	45	1890	90.695762000000002	90.719082	51.222610000000003	51.209493000000002	0103000020E610000001000000050000002CF3565D87AC5640D7DEA7AAD09A49402CF3565D87AC56409CE1067C7E9C49401B49827005AE56409CE1067C7E9C49401B49827005AE5640D7DEA7AAD09A49402CF3565D87AC5640D7DEA7AAD09A4940
59974	Бижиктик-Хая	5	45	1890	90.629277000000002	90.643561000000005	51.108752000000003	51.096761999999998	0103000020E6100000010000000500000000C8091346A856406EBF7CB2628C494000C8091346A85640F3AFE595EB8D4940CAFE791A30A95640F3AFE595EB8D4940CAFE791A30A956406EBF7CB2628C494000C8091346A856406EBF7CB2628C4940
30513	Барлык	5	45	1890	90.523240000000001	90.548356999999996	51.143149999999999	51.129551999999997	0103000020E6100000010000000500000061FD9FC37CA15640D190F1289590494061FD9FC37CA1564011363CBD529249401762F54718A3564011363CBD529249401762F54718A35640D190F1289590494061FD9FC37CA15640D190F12895904940
30450	Аянгаты (Сарыг-Бель)	5	45	1890	90.837003999999993	90.851044000000002	51.000258000000002	50.986781999999998	0103000020E61000000100000005000000C1A7397991B55640072461DF4E7E4940C1A7397991B55640FCC742740880494040DD408177B65640FCC742740880494040DD408177B65640072461DF4E7E4940C1A7397991B55640072461DF4E7E4940
30407	Аксы-Барлык (Алдын-Булак)	5	45	1890	90.394035000000002	90.409298000000007	51.125256	51.114638999999997	0103000020E61000000100000005000000AE9E93DE379956404EECA17DAC8E4940AE9E93DE379956405BD07B63089049405E143DF0319A56405BD07B63089049405E143DF0319A56404EECA17DAC8E4940AE9E93DE379956404EECA17DAC8E4940
59928	Шуй	5	45	389	90.333408000000006	90.347196999999994	50.897620000000003	50.878028	0103000020E61000000100000005000000630E828E56955640747CB43863704940630E828E56955640261E5036E57249403C11C47938965640261E5036E57249403C11C47938965640747CB43863704940630E828E56955640747CB43863704940
59964	Хемчик	5	45	389	90.182661999999993	90.196999000000005	51.023090000000003	51.014170999999997	0103000020E61000000100000005000000340EF5BBB08B56409BC6F65AD0814940340EF5BBB08B5640AD6EF59CF48249401096B1A19B8C5640AD6EF59CF48249401096B1A19B8C56409BC6F65AD0814940340EF5BBB08B56409BC6F65AD0814940
29972	Тээли (Бай-Тайга)	5	45	389	90.190270999999996	90.220040999999995	51.020947999999997	51.004162999999998	0103000020E6100000010000000500000024986A662D8C5640376DC6698880494024986A662D8C564053758F6CAE824940DDB1D826158E564053758F6CAE824940DDB1D826158E5640376DC6698880494024986A662D8C5640376DC66988804940
59943	Кызыл-Даг	5	45	389	90.101301000000007	90.113752000000005	51.046154000000001	51.034905999999999	0103000020E61000000100000005000000568330B77B8656409337C0CC77844940568330B77B865640304AD05FE8854940B2F677B647875640304AD05FE8854940B2F677B6478756409337C0CC77844940568330B77B8656409337C0CC77844940
59927	Кара-Холь (Тапсы-Аксы)	5	45	389	89.759376000000003	89.768699999999995	51.288150999999999	51.277419000000002	0103000020E610000001000000050000008257CB9D99705640FF243E7782A349408257CB9D99705640A4A7C821E2A44940DA1B7C6132715640A4A7C821E2A44940DA1B7C6132715640FF243E7782A349408257CB9D99705640FF243E7782A34940
2020	Дружба	5	45	389	90.218378999999999	90.232293999999996	51.010832999999998	51.002706000000003	0103000020E6100000010000000500000086C8E9EBF98D564062C092AB5880494086C8E9EBF98D5640D95BCAF962814940A643A7E7DD8E5640D95BCAF962814940A643A7E7DD8E564062C092AB5880494086C8E9EBF98D564062C092AB58804940
59920	Бай-Тал (Чон-Терек)	5	45	389	90.043674999999993	90.069151000000005	50.915841	50.904663999999997	0103000020E61000000100000005000000C7293A92CB8256402CEFAA07CC734940C7293A92CB82564000AB23473A75494016DF50F86C84564000AB23473A75494016DF50F86C8456402CEFAA07CC734940C7293A92CB8256402CEFAA07CC734940
59923	сумон Кызыл-Даг	5	45	7497	88.791809000000001	99.273622000000003	53.729601000000002	49.743535000000001	0103000020E610000001000000050000006CEBA7FFAC3256403737A6272CDF48406CEBA7FFAC3256408010C99063DD4A40D55DD90583D158408010C99063DD4A40D55DD90583D158403737A6272CDF48406CEBA7FFAC3256403737A6272CDF4840
24699	Улан-Удэ	5	44	\N	107.425985	107.803062	51.912405	51.737639999999999	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
59464	Улан-Удэ	5	44	\N	107.425985	107.803062	51.912405	51.737639999999999	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
60864	Северобайкальск	5	44	\N	109.254003	109.366185	55.650652999999998	55.602891	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
60876	Кяхта	5	44	\N	106.416549	106.486851	50.379559	50.321345000000001	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
60947	Каменск	5	44	\N	106.558384	106.62384400000001	52.009162000000003	51.972670000000001	0103000020E6100000010000000500000005A73E90BCA35A4071E6577380FC494005A73E90BCA35A40D82E6D382C014A409373620FEDA75A40D82E6D382C014A409373620FEDA75A4071E6577380FC494005A73E90BCA35A4071E6577380FC4940
60868	Закаменск	5	44	\N	103.269229	103.308378	50.402168000000003	50.335732999999998	0103000020E61000000100000005000000A088450C3BD159400F98874CF92A4940A088450C3BD15940B6BFB33D7A33494094331477BCD35940B6BFB33D7A33494094331477BCD359400F98874CF92A4940A088450C3BD159400F98874CF92A4940
60878	Гусиноозерск	5	44	\N	106.43933	106.559569	51.333309999999997	51.260812000000001	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
60867	Бабушкин	5	44	\N	105.841402	105.89354899999999	51.721324000000003	51.703332000000003	0103000020E610000001000000050000007F32C687D9755A407A1D71C806DA49407F32C687D9755A40F3E8465854DC4940E71725E82F795A40F3E8465854DC4940E71725E82F795A407A1D71C806DA49407F32C687D9755A407A1D71C806DA4940
60713	Улан-Удэ	5	44	7505	107.51133400000001	107.74473500000001	51.895918000000002	51.778264	0103000020E610000001000000050000004ED53DB2B9E05A40BBD39D279EE349404ED53DB2B9E05A40E9F2E670ADF24940F14BFDBCA9EF5A40E9F2E670ADF24940F14BFDBCA9EF5A40BBD39D279EE349404ED53DB2B9E05A40BBD39D279EE34940
60394	Улан-Удэ	5	44	7505	107.51133400000001	107.74473500000001	51.895918000000002	51.778264	0103000020E610000001000000050000004ED53DB2B9E05A40BBD39D279EE349404ED53DB2B9E05A40E9F2E670ADF24940F14BFDBCA9EF5A40E9F2E670ADF24940F14BFDBCA9EF5A40BBD39D279EE349404ED53DB2B9E05A40BBD39D279EE34940
52913	Хоринск	5	44	1744	109.73294	109.798553	52.177185000000001	52.137073000000001	0103000020E61000000100000005000000897B2C7DE86E5B401215AA9B8B114A40897B2C7DE86E5B40BF2B82FFAD164A40DAC70A7E1B735B40BF2B82FFAD164A40DAC70A7E1B735B401215AA9B8B114A40897B2C7DE86E5B401215AA9B8B114A40
52856	Хасурта	5	44	1744	108.856472	108.88232499999999	52.299650999999997	52.265988	0103000020E61000000100000005000000247CEF6FD0365B40719010E50B224A40247CEF6FD0365B405A9BC6F65A264A405DDC460378385B405A9BC6F65A264A405DDC460378385B40719010E50B224A40247CEF6FD0365B40719010E50B224A40
52878	Хандагай	5	44	1744	109.117001	109.134051	52.015309000000002	52.004721000000004	0103000020E610000001000000050000005B26C3F17C475B405E4D9EB29A004A405B26C3F17C475B40D02A33A5F5014A40C03FA54A94485B40D02A33A5F5014A40C03FA54A94485B405E4D9EB29A004A405B26C3F17C475B405E4D9EB29A004A40
32815	Удинск	5	44	1744	109.19329500000001	109.233881	52.145097999999997	52.135531	0103000020E61000000100000005000000BEDEFDF15E4C5B400E4C6E1459114A40BEDEFDF15E4C5B40855B3E9292124A40F88903E8F74E5B40855B3E9292124A40F88903E8F74E5B400E4C6E1459114A40BEDEFDF15E4C5B400E4C6E1459114A40
60801	Тэгда	5	44	1744	108.90746	108.93633199999999	52.405765000000002	52.381656	0103000020E61000000100000005000000679B1BD3133A5B403D29931ADA304A40679B1BD3133A5B40446E861BF0334A40B08C0DDDEC3B5B40446E861BF0334A40B08C0DDDEC3B5B403D29931ADA304A40679B1BD3133A5B403D29931ADA304A40
52847	Тохорюкта	5	44	1744	109.28098900000001	109.307794	52.565137	52.552664999999998	0103000020E610000001000000050000004A6249B9FB515B4069520ABABD464A404A6249B9FB515B403961C26856484A40ECF99AE5B2535B403961C26856484A40ECF99AE5B2535B4069520ABABD464A404A6249B9FB515B4069520ABABD464A40
60918	Тарбагатай	5	44	1744	109.182515	109.212339	52.114697	52.109437	0103000020E61000000100000005000000E2016553AE4B5B4076FC1708020E4A40E2016553AE4B5B4083F92B64AE0E4A40952A51F6964D5B4083F92B64AE0E4A40952A51F6964D5B4076FC1708020E4A40E2016553AE4B5B4076FC1708020E4A40
60985	Санномыск	5	44	1744	109.39035800000001	109.428124	52.127961999999997	52.118141999999999	0103000020E61000000100000005000000D9EE1EA0FB585B405B24ED461F0F4A40D9EE1EA0FB585B40BC900E0F61104A407EA83462665B5B40BC900E0F61104A407EA83462665B5B405B24ED461F0F4A40D9EE1EA0FB585B405B24ED461F0F4A40
52905	Ониноборск	5	44	1744	110.009334	110.034882	52.262768999999999	52.247751999999998	0103000020E610000001000000050000006A2FA2ED98805B4061C26856B61F4A406A2FA2ED98805B4089B3226AA2214A40054EB6813B825B4089B3226AA2214A40054EB6813B825B4061C26856B61F4A406A2FA2ED98805B4061C26856B61F4A40
52851	Ойбонт	5	44	1744	109.19840600000001	109.217478	52.502473999999999	52.493439000000002	0103000020E61000000100000005000000225514AFB24C5B4015C95702293F4A40225514AFB24C5B408F8B6A1151404A405E66D828EB4D5B408F8B6A1151404A405E66D828EB4D5B4015C95702293F4A40225514AFB24C5B4015C95702293F4A40
60917	Нарын	5	44	1744	109.305063	109.314909	52.081767999999997	52.071013000000001	0103000020E610000001000000050000000F0EF62686535B40A14B38F416094A400F0EF62686535B40FEEDB25F770A4A40D40D147827545B40FEEDB25F770A4A40D40D147827545B40A14B38F416094A400F0EF62686535B40A14B38F416094A40
52842	Малая Курба	5	44	1744	109.512017	109.52161099999999	52.656098	52.646379000000003	0103000020E61000000100000005000000BF7FF3E2C4605B401DE90C8CBC524A40BF7FF3E2C4605B404A7CEE04FB534A40F78E1A1362615B404A7CEE04FB534A40F78E1A1362615B401DE90C8CBC524A40BF7FF3E2C4605B401DE90C8CBC524A40
52893	Майла	5	44	1744	109.99456499999999	110.010465	52.514319	52.500435000000003	0103000020E61000000100000005000000C22FF5F3A67F5B400B630B410E404A40C22FF5F3A67F5B40105B7A34D5414A402B306475AB805B40105B7A34D5414A402B306475AB805B400B630B410E404A40C22FF5F3A67F5B400B630B410E404A40
60958	Кульский Станок	5	44	1744	109.606763	109.62320200000001	52.172860999999997	52.160592000000001	0103000020E61000000100000005000000105B7A34D5665B40E7FF55478E144A40105B7A34D5665B407EE02A4F20164A405133A48AE2675B407EE02A4F20164A405133A48AE2675B40E7FF55478E144A40105B7A34D5665B40E7FF55478E144A40
52887	Кульск	5	44	1744	109.60484	109.631924	52.135851000000002	52.127791000000002	0103000020E6100000010000000500000002D4D4B2B5665B4090DC9A745B104A4002D4D4B2B5665B408010C99063114A40AE635C7171685B408010C99063114A40AE635C7171685B4090DC9A745B104A4002D4D4B2B5665B4090DC9A745B104A40
52901	Зун-Хурай	5	44	1744	110.039903	110.065775	52.172401999999998	52.162824000000001	0103000020E61000000100000005000000C90050C58D825B408080B56AD7144A40C90050C58D825B40EBE1CB4411164A403E7958A835845B40EBE1CB4411164A403E7958A835845B408080B56AD7144A40C90050C58D825B408080B56AD7144A40
60988	Додо-Гол	5	44	1744	108.723027	108.733636	52.005636000000003	51.995938000000002	0103000020E6100000010000000500000000C80913462E5B40FD6B79E57AFF494000C80913462E5B4013D731AEB8004A40C5CA68E4F32E5B4013D731AEB8004A40C5CA68E4F32E5B40FD6B79E57AFF494000C80913462E5B40FD6B79E57AFF4940
32838	Верхние Тальцы	5	44	1744	108.90415400000001	108.964871	52.050409000000002	52.033296999999997	0103000020E610000001000000050000000C23BDA8DD395B4007077B1343044A400C23BDA8DD395B40483657CD73064A40F7764B72C03D5B40483657CD73064A40F7764B72C03D5B4007077B1343044A400C23BDA8DD395B4007077B1343044A40
52896	Булум	5	44	1744	110.10488700000001	110.121309	52.287168999999999	52.277940999999998	0103000020E61000000100000005000000A3B1F677B6865B40D89B189293234A40A3B1F677B6865B4067B62BF4C1244A4078EDD286C3875B4067B62BF4C1244A4078EDD286C3875B40D89B189293234A40A3B1F677B6865B40D89B189293234A40
52871	Баян-Гол	5	44	1744	109.324359	109.344014	52.178074000000002	52.168525000000002	0103000020E61000000100000005000000734A404CC2545B407AC7293A92154A40734A404CC2545B404B22FB20CB164A406FD74B5304565B404B22FB20CB164A406FD74B5304565B407AC7293A92154A40734A404CC2545B407AC7293A92154A40
52861	Барун-Хасурта	5	44	1744	109.007434	109.026792	52.154260000000001	52.142632999999996	0103000020E6100000010000000500000039B874CC79405B40492A53CC41124A4039B874CC79405B405D8AABCABE134A40D8F2CAF5B6415B405D8AABCABE134A40D8F2CAF5B6415B40492A53CC41124A4039B874CC79405B40492A53CC41124A40
52907	Ашанга	5	44	1744	110.252517	110.27323199999999	52.371628000000001	52.361823000000001	0103000020E61000000100000005000000C72B103D29905B4066F84F37502E4A40C72B103D29905B4092239D81912F4A401F0E12A27C915B4092239D81912F4A401F0E12A27C915B4066F84F37502E4A40C72B103D29905B4066F84F37502E4A40
52892	Анинск	5	44	1744	109.82511599999999	109.85351199999999	52.202117999999999	52.189515999999998	0103000020E6100000010000000500000001DA56B3CE745B40CC086F0F42184A4001DA56B3CE745B406AF7AB00DF194A4096AFCBF09F765B406AF7AB00DF194A4096AFCBF09F765B40CC086F0F42184A4001DA56B3CE745B40CC086F0F42184A40
52909	Амгаланта	5	44	1744	110.38029299999999	110.390165	52.403495999999997	52.393577000000001	0103000020E61000000100000005000000747973B856985B4099BA2BBB60324A40747973B856985B408D08C6C1A5334A40CEC29E76F8985B408D08C6C1A5334A40CEC29E76F8985B4099BA2BBB60324A40747973B856985B4099BA2BBB60324A40
52891	Алан	5	44	1744	109.863169	109.872817	52.319020999999999	52.309106	0103000020E61000000100000005000000F27A30293E775B40AA7F10C990274A40F27A30293E775B405DDE1CAED5284A402499D53BDC775B405DDE1CAED5284A402499D53BDC775B40AA7F10C990274A40F27A30293E775B40AA7F10C990274A40
61057	Шулута	5	44	1671	103.12988199999999	103.140519	51.803555000000003	51.793790999999999	0103000020E61000000100000005000000B39597FC4FC85940F86D88F19AE54940B39597FC4FC85940C6C4E6E3DAE64940DD5D6743FEC85940C6C4E6E3DAE64940DD5D6743FEC85940F86D88F19AE54940B39597FC4FC85940F86D88F19AE54940
22977	Шимки	5	44	1671	102.00273	102.02544	51.685411999999999	51.667299999999997	0103000020E61000000100000005000000F52D73BA2C805940764F1E166AD54940F52D73BA2C8059409A249694BBD74940A80018CFA08159409A249694BBD74940A80018CFA0815940764F1E166AD54940F52D73BA2C805940764F1E166AD54940
21711	Шанай	5	44	1671	102.854118	102.86291199999999	51.756036000000002	51.745514999999997	0103000020E61000000100000005000000323B8BDEA9B65940B6D617096DDF4940323B8BDEA9B65940A14CA3C9C5E04940DCD440F339B75940A14CA3C9C5E04940DCD440F339B75940B6D617096DDF4940323B8BDEA9B65940B6D617096DDF4940
22913	Хужиры	5	44	1671	102.07927599999999	102.101338	51.682150999999998	51.674187000000003	0103000020E61000000100000005000000E4D6A4DB12855940B63176C24BD64940E4D6A4DB1285594083F755B950D74940E4F560527C86594083F755B950D74940E4F560527C865940B63176C24BD64940E4D6A4DB12855940B63176C24BD64940
60977	Хойтогол	5	44	1671	100.667627	103.809889	51.975898999999998	51.043095999999998	0103000020E610000001000000050000004DBB9866BA2A5940514B732B848549404DBB9866BA2A59407C992842EAFC4940F818AC38D5F359407C992842EAFC4940F818AC38D5F35940514B732B848549404DBB9866BA2A5940514B732B84854940
22646	Харбяты	5	44	1671	102.27035600000001	102.29285900000001	51.678319999999999	51.658982000000002	0103000020E61000000100000005000000C19140834D9159408B53AD8559D44940C19140834D915940821C9430D3D64940B7D5AC33BE925940821C9430D3D64940B7D5AC33BE9259408B53AD8559D44940C19140834D9159408B53AD8559D44940
22205	Улбугай	5	44	1671	102.306675	102.318371	51.809981000000001	51.804568000000003	0103000020E610000001000000050000000DE02D90A09359403EB48F15FCE649400DE02D90A0935940D1B01875ADE74940AB3FC23060945940D1B01875ADE74940AB3FC230609459403EB48F15FCE649400DE02D90A09359403EB48F15FCE64940
23021	Туран	5	44	1671	101.605918	101.695893	51.643939000000003	51.628494000000003	0103000020E61000000100000005000000B2834A5CC7665940BADDCB7D72D04940B2834A5CC76659403ACFD8976CD24940FB20CB82896C59403ACFD8976CD24940FB20CB82896C5940BADDCB7D72D04940B2834A5CC7665940BADDCB7D72D04940
21977	Тунка	5	44	1671	102.516198	102.56118600000001	51.775689	51.731856000000001	0103000020E61000000100000005000000AE10566309A15940D1B01875ADDD4940AE10566309A15940F86EF3C649E34940473EAF78EAA35940F86EF3C649E34940473EAF78EAA35940D1B01875ADDD4940AE10566309A15940D1B01875ADDD4940
21576	Торы	5	44	1671	102.98753499999999	103.030924	51.797389000000003	51.780777	0103000020E61000000100000005000000F12900C633BF5940083C3080F0E34940F12900C633BF59405798BED710E64940562AA8A8FAC159405798BED710E64940562AA8A8FAC15940083C3080F0E34940F12900C633BF5940083C3080F0E34940
60961	Толтой	5	44	1671	100.667627	103.809889	51.975898999999998	51.043095999999998	0103000020E610000001000000050000004DBB9866BA2A5940514B732B848549404DBB9866BA2A59407C992842EAFC4940F818AC38D5F359407C992842EAFC4940F818AC38D5F35940514B732B848549404DBB9866BA2A5940514B732B84854940
61006	Токурен	5	44	1671	100.667627	103.809889	51.975898999999998	51.043095999999998	0103000020E610000001000000050000004DBB9866BA2A5940514B732B848549404DBB9866BA2A59407C992842EAFC4940F818AC38D5F359407C992842EAFC4940F818AC38D5F35940514B732B848549404DBB9866BA2A5940514B732B84854940
22194	Талое	5	44	1671	102.46865099999999	102.493498	51.825453000000003	51.810783000000001	0103000020E61000000100000005000000368FC360FE9D59408E93C2BCC7E74940368FC360FE9D59404BB1A371A8E949400DA9A278959F59404BB1A371A8E949400DA9A278959F59408E93C2BCC7E74940368FC360FE9D59408E93C2BCC7E74940
22299	Тагархай	5	44	1671	102.37298	102.40858900000001	51.883256000000003	51.874594000000002	0103000020E61000000100000005000000F98381E7DE97594090A339B2F2EF4940F98381E7DE97594076FF58880EF1494058207A52269A594076FF58880EF1494058207A52269A594090A339B2F2EF4940F98381E7DE97594090A339B2F2EF4940
61014	Табалангут	5	44	1671	102.49248299999999	102.50264300000001	51.789619000000002	51.777549999999998	0103000020E6100000010000000500000080B56AD7849F59409D8026C286E3494080B56AD7849F59406EA6423C12E549400EA48B4D2BA059406EA6423C12E549400EA48B4D2BA059409D8026C286E3494080B56AD7849F59409D8026C286E34940
22529	Охор-Шибирь	5	44	1671	102.403559	102.439536	51.686138	51.668495	0103000020E610000001000000050000006AC020E9D39959400F45813E91D549406AC020E9D39959407C45B75ED3D749408A5A9A5B219C59407C45B75ED3D749408A5A9A5B219C59400F45813E91D549406AC020E9D39959400F45813E91D54940
22660	Нуган	5	44	1671	102.189724	102.207178	51.696610999999997	51.679895000000002	0103000020E610000001000000050000000BD12170248C594062DBA2CC06D749400BD12170248C594055849B8C2AD94940D89C8367428D594055849B8C2AD94940D89C8367428D594062DBA2CC06D749400BD12170248C594062DBA2CC06D74940
60944	Ниловка	5	44	1671	101.665323	101.68456500000001	51.696644999999997	51.670841000000003	0103000020E61000000100000005000000B491EBA6946A594071E82D1EDED54940B491EBA6946A594001F6D1A92BD949401FBFB7E9CF6B594001F6D1A92BD949401FBFB7E9CF6B594071E82D1EDED54940B491EBA6946A594071E82D1EDED54940
49341	Никольск	5	44	1671	102.562866	102.584093	51.736251000000003	51.723833999999997	0103000020E61000000100000005000000F1811DFF05A45940CEDDAE97A6DC4940F1811DFF05A45940DB5207793DDE4940A4349BC761A55940DB5207793DDE4940A4349BC761A55940CEDDAE97A6DC4940F1811DFF05A45940CEDDAE97A6DC4940
23169	Монды	5	44	1671	100.976091	101.01008299999999	51.680028999999998	51.669578999999999	0103000020E61000000100000005000000E0BA6246783E5940508BC1C3B4D54940E0BA6246783E594071AAB5300BD74940B7CF2A33A540594071AAB5300BD74940B7CF2A33A5405940508BC1C3B4D54940E0BA6246783E5940508BC1C3B4D54940
22568	Малый Жемчуг	5	44	1671	102.35529200000001	102.365982	51.690297000000001	51.684277999999999	0103000020E61000000100000005000000F321A81ABD965940A7AFE76B96D74940F321A81ABD96594072C3EFA65BD849402E3BC43F6C97594072C3EFA65BD849402E3BC43F6C975940A7AFE76B96D74940F321A81ABD965940A7AFE76B96D74940
22716	Кырен	5	44	1671	102.10024199999999	102.164885	51.694741	51.671249000000003	0103000020E61000000100000005000000E1EB6B5D6A865940823CBB7CEBD54940E1EB6B5D6A8659405D18E945EDD8494076A6D0798D8A59405D18E945EDD8494076A6D0798D8A5940823CBB7CEBD54940E1EB6B5D6A865940823CBB7CEBD54940
21646	Зун-Мурино	5	44	1671	102.85539300000001	102.899051	51.757904000000003	51.726328000000002	0103000020E610000001000000050000008D0E48C2BEB65940A515DF50F8DC49408D0E48C2BEB65940F9C08EFF02E14940E99B340D8AB95940F9C08EFF02E14940E99B340D8AB95940A515DF50F8DC49408D0E48C2BEB65940A515DF50F8DC4940
22436	Зактуй	5	44	1671	102.620969	102.65341600000001	51.705911	51.684227999999997	0103000020E610000001000000050000001CB5C2F4BDA75940F58079C894D749401CB5C2F4BDA759407E71A94A5BDA4940B9AB5791D1A959407E71A94A5BDA4940B9AB5791D1A95940F58079C894D749401CB5C2F4BDA75940F58079C894D74940
22489	Жемчуг	5	44	1671	102.444378	102.47040200000001	51.693981999999998	51.673422000000002	0103000020E61000000100000005000000F6436CB0709C594016342DB132D64940F6436CB0709C59409F01F566D4D84940467EFD101B9E59409F01F566D4D84940467EFD101B9E594016342DB132D64940F6436CB0709C594016342DB132D64940
21827	Еловка	5	44	1671	102.748655	102.780141	51.770228000000003	51.742095999999997	0103000020E61000000100000005000000293FA9F6E9AF5940073F7100FDDE4940293FA9F6E9AF5940543BC3D496E24940335184D4EDB15940543BC3D496E24940335184D4EDB15940073F7100FDDE4940293FA9F6E9AF5940073F7100FDDE4940
21733	Далахай	5	44	1671	102.975363	103.021384	51.822808999999999	51.800046000000002	0103000020E610000001000000050000009FAEEE586CBE5940D7A546E867E649409FAEEE586CBE59405FED28CE51E94940172AFF5A5EC159405FED28CE51E94940172AFF5A5EC15940D7A546E867E649409FAEEE586CBE5940D7A546E867E64940
21810	Гужиры	5	44	1671	102.88220800000001	102.9079	51.794286999999997	51.78866	0103000020E6100000010000000500000041118B1876B85940E9D495CFF2E4494041118B1876B85940A8514832ABE5494075029A081BBA5940A8514832ABE5494075029A081BBA5940E9D495CFF2E4494041118B1876B85940E9D495CFF2E44940
22083	Галбай	5	44	1671	102.532	102.54622000000001	51.799003999999996	51.782749000000003	0103000020E61000000100000005000000355EBA490CA2594005FD851E31E44940355EBA490CA25940C4AF58C345E64940F41ABB44F5A25940C4AF58C345E64940F41ABB44F5A2594005FD851E31E44940355EBA490CA2594005FD851E31E44940
21892	Ахалик	5	44	1671	102.668481	102.697209	51.796543	51.779395000000001	0103000020E61000000100000005000000D53F8864C8AA59403DD52137C3E34940D53F8864C8AA5940CA6DFB1EF5E54940855E7F129FAC5940CA6DFB1EF5E54940855E7F129FAC59403DD52137C3E34940D53F8864C8AA59403DD52137C3E34940
22355	Аршан	5	44	1671	102.422836	102.45187900000001	51.919265000000003	51.899247000000003	0103000020E6100000010000000500000093E4B9BE0F9B5940580394861AF3494093E4B9BE0F9B5940C1ADBB79AAF54940F3AFE595EB9C5940C1ADBB79AAF54940F3AFE595EB9C5940580394861AF3494093E4B9BE0F9B5940580394861AF34940
21252	Харитоново	5	44	1632	106.98518199999999	107.007209	51.239145999999998	51.215676999999999	0103000020E61000000100000005000000E7A6CD380DBF5A40ECBFCE4D9B9B4940E7A6CD380DBF5A400F7C0C569C9E494029CFBC1C76C05A400F7C0C569C9E494029CFBC1C76C05A40ECBFCE4D9B9B4940E7A6CD380DBF5A40ECBFCE4D9B9B4940
60907	Хандагатай	5	44	1632	107.305306	107.329363	51.281739999999999	51.266972000000003	0103000020E6100000010000000500000072512D228AD35A404F7974232CA2494072512D228AD35A40CEFC6A0E10A44940CC608C4814D55A40CEFC6A0E10A44940CC608C4814D55A404F7974232CA2494072512D228AD35A404F7974232CA24940
20832	Тарбагатай	5	44	1632	107.327449	107.397203	51.494478000000001	51.466740999999999	0103000020E61000000100000005000000E886A6ECF4D45A40E659492BBEBB4940E886A6ECF4D45A40B64B1B0E4BBF4940E1B721C66BD95A40B64B1B0E4BBF4940E1B721C66BD95A40E659492BBEBB4940E886A6ECF4D45A40E659492BBEBB4940
20758	Пестерево	5	44	1632	107.441868	107.49017000000001	51.506129000000001	51.489381000000002	0103000020E610000001000000050000008849B89047DC5A4053245F09A4BE49408849B89047DC5A405247C7D5C8C04940BEDEFDF15EDF5A405247C7D5C8C04940BEDEFDF15EDF5A4053245F09A4BE49408849B89047DC5A4053245F09A4BE4940
21491	Николаевский	5	44	1632	107.77579799999999	107.809162	51.666964999999998	51.640785999999999	0103000020E610000001000000050000005793A7ACA6F15A4009DE904605D249405793A7ACA6F15A40CF49EF1B5FD549409FCA694FC9F35A40CF49EF1B5FD549409FCA694FC9F35A4009DE904605D249405793A7ACA6F15A4009DE904605D24940
21008	Нижний Жирим	5	44	1632	107.17900299999999	107.21781	51.436095999999999	51.416063999999999	0103000020E61000000100000005000000B2B8FFC874CB5A407F85CC9541B54940B2B8FFC874CB5A404DF564FED1B7494079AF5A99F0CD5A404DF564FED1B7494079AF5A99F0CD5A407F85CC9541B54940B2B8FFC874CB5A407F85CC9541B54940
20545	Надеино	5	44	1632	107.64799499999999	107.684673	51.550899000000001	51.541842000000003	0103000020E610000001000000050000002D3E05C078E95A40B4CC22145BC549402D3E05C078E95A401633C2DB83C6494012DDB3AED1EB5A401633C2DB83C6494012DDB3AED1EB5A40B4CC22145BC549402D3E05C078E95A40B4CC22145BC54940
20526	Куйтун	5	44	1632	107.717237	107.788348	51.535629	51.519851000000003	0103000020E61000000100000005000000CB9E0436E7ED5A407EE5417A8AC24940CB9E0436E7ED5A4004E5B67D8FC449407D772B4B74F25A4004E5B67D8FC449407D772B4B74F25A407EE5417A8AC24940CB9E0436E7ED5A407EE5417A8AC24940
20646	Десятниково	5	44	1632	107.424063	107.47383000000001	51.423696999999997	51.411126000000003	0103000020E61000000100000005000000651C23D923DB5A408544DAC69FB44940651C23D923DB5A40E7340BB43BB649404777103B53DE5A40E7340BB43BB649404777103B53DE5A408544DAC69FB44940651C23D923DB5A408544DAC69FB44940
21028	Верхний Жирим	5	44	1632	107.207713	107.226955	51.330007000000002	51.298305999999997	0103000020E610000001000000050000000F7D772B4BCD5A40AC1919E42EA649400F7D772B4BCD5A40BD395CAB3DAA49407AAA436E86CE5A40BD395CAB3DAA49407AAA436E86CE5A40AC1919E42EA649400F7D772B4BCD5A40AC1919E42EA64940
20746	Бурнашево	5	44	1632	107.37383800000001	107.393619	51.432147999999998	51.419910999999999	0103000020E61000000100000005000000220038F6ECD75A40861DC6A4BFB54940220038F6ECD75A4012842BA050B749406405BF0D31D95A4012842BA050B749406405BF0D31D95A40861DC6A4BFB54940220038F6ECD75A40861DC6A4BFB54940
20633	Большой Куналей	5	44	1632	107.57806100000001	107.636595	51.446424999999998	51.419125000000001	0103000020E61000000100000005000000F58590F3FEE45A40CFF753E3A5B54940F58590F3FEE45A40F38E537424B949400473F4F8BDE85A40F38E537424B949400473F4F8BDE85A40CFF753E3A5B54940F58590F3FEE45A40CFF753E3A5B54940
21093	Барыкино-Ключи	5	44	1632	107.25586300000001	107.27363099999999	51.265439000000001	51.251133000000003	0103000020E610000001000000050000006A50340F60D05A4023F94A2025A049406A50340F60D05A409E0AB8E7F9A14940FE0A992B83D15A409E0AB8E7F9A14940FE0A992B83D15A4023F94A2025A049406A50340F60D05A4023F94A2025A04940
21188	Барыкино	5	44	1632	107.183252	107.20265499999999	51.248291999999999	51.224359	0103000020E610000001000000050000004DBB9866BACB5A4019C8B3CBB79C49404DBB9866BACB5A40E1ED4108C89F4940BC57AD4CF8CC5A40E1ED4108C89F4940BC57AD4CF8CC5A4019C8B3CBB79C49404DBB9866BACB5A4019C8B3CBB79C4940
60873	улус Зурган-Дэбэ	5	44	1551	105.2717	107.09119200000001	51.5961	50.600594000000001	0103000020E61000000100000005000000AF94658863515A404016A243E04C4940AF94658863515A40A3923A014DCC49400A6AF816D6C55A40A3923A014DCC49400A6AF816D6C55A404016A243E04C4940AF94658863515A404016A243E04C4940
19085	Ягодное	5	44	1551	106.48850400000001	106.515462	51.406137000000001	51.396023	0103000020E61000000100000005000000C6FD47A6439F5A405EBBB4E1B0B24940C6FD47A6439F5A400859164CFCB349402B155454FDA05A400859164CFCB349402B155454FDA05A405EBBB4E1B0B24940C6FD47A6439F5A405EBBB4E1B0B24940
19368	Шана	5	44	1551	106.199399	106.22064399999999	50.933566999999996	50.924404000000003	0103000020E61000000100000005000000BAF605F4C28C5A405325CADE52764940BAF605F4C28C5A40FACF9A1F7F774940C00303081F8E5A40FACF9A1F7F774940C00303081F8E5A405325CADE52764940BAF605F4C28C5A405325CADE52764940
60959	Усть-Урма	5	44	1551	105.970715	105.985923	51.054743000000002	51.040049000000003	0103000020E6100000010000000500000025AFCE31207E5A40679E5C532085494025AFCE31207E5A40AC5791D101874940F357C85C197F5A40AC5791D101874940F357C85C197F5A40679E5C532085494025AFCE31207E5A40679E5C5320854940
61011	Усть-Алташа (Алташа)	5	44	1551	107.06259	107.076065	51.041198999999999	51.028244999999998	0103000020E61000000100000005000000A0C37C7901C45A4044A33B889D834940A0C37C7901C45A405FD0420246854940B2D7BB3FDEC45A405FD0420246854940B2D7BB3FDEC45A4044A33B889D834940A0C37C7901C45A4044A33B889D834940
60955	Удунга	5	44	1551	105.979051	105.98945399999999	51.132863999999998	51.118935999999998	0103000020E610000001000000050000006E8786C5A87E5A4095287B4B398F49406E8786C5A87E5A406A6803B0019149405EB9DE36537F5A406A6803B0019149405EB9DE36537F5A4095287B4B398F49406E8786C5A87E5A4095287B4B398F4940
60874	Тохой	5	44	1551	106.57137299999999	106.630195	51.374983999999998	51.354126000000001	0103000020E6100000010000000500000050340F6091A45A40E754320054AD494050340F6091A45A40FA42C879FFAF494093C6681D55A85A40FA42C879FFAF494093C6681D55A85A40E754320054AD494050340F6091A45A40E754320054AD4940
20127	Темник (Ацула)	5	44	1551	106.16885600000001	106.193838	51.009728000000003	50.999327999999998	0103000020E61000000100000005000000F06E6589CE8A5A4011FDDAFAE97F4940F06E6589CE8A5A4081ED60C43E81494036AE7FD7678C5A4081ED60C43E81494036AE7FD7678C5A4011FDDAFAE97F4940F06E6589CE8A5A4011FDDAFAE97F4940
60893	Ташир	5	44	1551	105.798705	105.833102	50.992519999999999	50.977215999999999	0103000020E61000000100000005000000B58993FB1D735A406090F469157D4940B58993FB1D735A401E5036E50A7F4940DC0E0D8B51755A401E5036E50A7F4940DC0E0D8B51755A406090F469157D4940B58993FB1D735A406090F469157D4940
19255	Таежный	5	44	1551	105.712943	105.72685799999999	51.203974000000002	51.198968000000001	0103000020E61000000100000005000000603AADDBA06D5A40AB798EC877994940603AADDBA06D5A40FE9DEDD11B9A494080B56AD7846E5A40FE9DEDD11B9A494080B56AD7846E5A40AB798EC877994940603AADDBA06D5A40AB798EC877994940
20250	Средний Убукун	5	44	1551	106.714403	106.738649	51.472408000000001	51.450325999999997	0103000020E61000000100000005000000844A5CC7B8AD5A40ED444948A4B94940844A5CC7B8AD5A40342F87DD77BC4940478E740646AF5A40342F87DD77BC4940478E740646AF5A40ED444948A4B94940844A5CC7B8AD5A40ED444948A4B94940
19280	Селендума	5	44	1551	106.221542	106.244997	50.932681000000002	50.904732000000003	0103000020E61000000100000005000000302C7FBE2D8E5A4085D21742CE734940302C7FBE2D8E5A40E04C4C17627749408FA7E507AE8F5A40E04C4C17627749408FA7E507AE8F5A4085D21742CE734940302C7FBE2D8E5A4085D21742CE734940
60932	Селендума	5	44	1551	106.221542	106.244997	50.932681000000002	50.904732000000003	0103000020E61000000100000005000000302C7FBE2D8E5A4085D21742CE734940302C7FBE2D8E5A40E04C4C17627749408FA7E507AE8F5A40E04C4C17627749408FA7E507AE8F5A4085D21742CE734940302C7FBE2D8E5A4085D21742CE734940
19489	Поворот	5	44	1551	106.61668400000001	106.63018599999999	50.926918999999998	50.913308000000001	0103000020E61000000100000005000000DBFD2AC077A75A406C96CB46E7744940DBFD2AC077A75A4040852348A57649406919A9F754A85A4040852348A57649406919A9F754A85A406C96CB46E7744940DBFD2AC077A75A406C96CB46E7744940
60966	Нур-Тухум	5	44	1551	106.433958	106.454035	50.814075000000003	50.797989000000001	0103000020E610000001000000050000009B75C6F7C59B5A40ACC8E880246649409B75C6F7C59B5A40E0BE0E9C33684940520FD1E80E9D5A40E0BE0E9C33684940520FD1E80E9D5A40ACC8E880246649409B75C6F7C59B5A40ACC8E88024664940
19449	Новоселенгинск	5	44	1551	106.611896	106.65347	51.101264	51.082510999999997	0103000020E610000001000000050000006823D74D29A75A40B6476FB88F8A49406823D74D29A75A408E210038F68C4940B2BAD573D2A95A408E210038F68C4940B2BAD573D2A95A40B6476FB88F8A49406823D74D29A75A40B6476FB88F8A4940
60983	Зурган-Дэбэ (Ноёхон)	5	44	1551	107.009068	107.029056	51.078397000000002	51.065328999999998	0103000020E610000001000000050000002BDCF29194C05A407D3D5FB35C8849402BDCF29194C05A40618DB3E9088A49402A70B20DDCC15A40618DB3E9088A49402A70B20DDCC15A407D3D5FB35C8849402BDCF29194C05A407D3D5FB35C884940
60987	Жаргаланта	5	44	1551	106.653839	106.677509	51.416933999999998	51.400360999999997	0103000020E610000001000000050000005C76887FD8A95A4003CC7C073FB349405C76887FD8A95A40944BE3175EB54940B96FB54E5CAB5A40944BE3175EB54940B96FB54E5CAB5A4003CC7C073FB349405C76887FD8A95A4003CC7C073FB34940
60956	Ехэ-Цаган	5	44	1551	106.32943	106.34674099999999	51.007885999999999	50.992865000000002	0103000020E610000001000000050000009014916115955A40E92B4833167F49409014916115955A40520C906802814940ABCB290131965A40520C906802814940ABCB290131965A40E92B4833167F49409014916115955A40E92B4833167F4940
60954	Енхор	5	44	1551	106.490821	106.50466400000001	50.996318000000002	50.981355000000001	0103000020E6100000010000000500000029CC7B9C699F5A400F62670A9D7D494029CC7B9C699F5A4044352559877F4940FDDD3B6A4CA05A4044352559877F4940FDDD3B6A4CA05A400F62670A9D7D494029CC7B9C699F5A400F62670A9D7D4940
60962	Дэдэ-Сутой	5	44	1551	106.846949	106.85977699999999	51.271638000000003	51.259352	0103000020E610000001000000050000005018946934B65A407B13437232A149405018946934B65A40E92CB308C5A2494097361C9606B75A40E92CB308C5A2494097361C9606B75A407B13437232A149405018946934B65A407B13437232A14940
46986	Дэбэн (Обон-Гызык)	5	44	1551	106.305903	106.312658	50.751721000000003	50.743501999999999	0103000020E61000000100000005000000E42F2DEA93935A405B41D3122B5F4940E42F2DEA93935A40B45BCB64386049404C35B39602945A40B45BCB64386049404C35B39602945A405B41D3122B5F4940E42F2DEA93935A405B41D3122B5F4940
18497	Гусиноозерск	5	44	1551	106.43933	106.559569	51.333309999999997	51.260812000000001	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
60528	Гусиноозерск	5	44	1551	106.43933	106.559569	51.333309999999997	51.260812000000001	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
19181	Бараты	5	44	1551	106.364518	106.383455	51.252367999999997	51.234634999999997	0103000020E610000001000000050000006A334E4354975A409CBF0985089E49406A334E4354975A40494739984DA04940361FD7868A985A40494739984DA04940361FD7868A985A409CBF0985089E49406A334E4354975A409CBF0985089E4940
19110	Ардасан	5	44	1551	106.56894800000001	106.579081	51.440928999999997	51.435124000000002	0103000020E61000000100000005000000FA47DFA469A45A4034DAAA24B2B74940FA47DFA469A45A40D26D895C70B849400A2FC1A90FA55A40D26D895C70B849400A2FC1A90FA55A4034DAAA24B2B74940FA47DFA469A45A4034DAAA24B2B74940
17877	Янчукан	5	44	1479	112.790769	112.818563	56.259622999999998	56.24588	0103000020E61000000100000005000000336C94F59B325C40C85EEFFE781F4C40336C94F59B325C400B2593533B214C40CDAD105663345C400B2593533B214C40CDAD105663345C40C85EEFFE781F4C40336C94F59B325C40C85EEFFE781F4C40
61052	Холодная	5	44	1479	109.749568	109.76734500000001	55.884292000000002	55.874747999999997	0103000020E6100000010000000500000033880FECF86F5B40E61E12BEF7EF4B4033880FECF86F5B40A60EF27A30F14B40F2EF332E1C715B40A60EF27A30F14B40F2EF332E1C715B40E61E12BEF7EF4B4033880FECF86F5B40E61E12BEF7EF4B40
17532	Уоян	5	44	1479	111.612341	111.624343	56.136301000000003	56.123427999999997	0103000020E61000000100000005000000FF3F4E9830E75B4091B41B7DCC0F4C40FF3F4E9830E75B40C0B4A84F72114C40239F573CF5E75B40C0B4A84F72114C40239F573CF5E75B4091B41B7DCC0F4C40FF3F4E9830E75B4091B41B7DCC0F4C40
17925	Северобайкальск	5	44	1479	109.254003	109.366185	55.650652999999998	55.602891	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
17605	Новый Уоян	5	44	1479	111.706368	111.75652100000001	56.149811999999997	56.128731000000002	0103000020E6100000010000000500000038BC202235ED5B409E7DE5417A104C4038BC202235ED5B403046240A2D134C402F6F0ED76AF05B403046240A2D134C402F6F0ED76AF05B409E7DE5417A104C4038BC202235ED5B409E7DE5417A104C40
60933	Новый Уоян	5	44	1479	111.706368	111.75652100000001	56.149811999999997	56.128731000000002	0103000020E6100000010000000500000038BC202235ED5B409E7DE5417A104C4038BC202235ED5B403046240A2D134C402F6F0ED76AF05B403046240A2D134C402F6F0ED76AF05B409E7DE5417A104C4038BC202235ED5B409E7DE5417A104C40
16975	Нижнеангарск	5	44	1479	109.538589	109.61376	55.818483000000001	55.761583000000002	0103000020E61000000100000005000000103FFF3D78625B4044183F8D7BE14B40103FFF3D78625B407EAA0A0DC4E84B40F3E505D847675B407EAA0A0DC4E84B40F3E505D847675B4044183F8D7BE14B40103FFF3D78625B4044183F8D7BE14B40
17829	Кумора	5	44	1479	111.191427	111.225437	55.891753999999999	55.879662000000003	0103000020E610000001000000050000009224085740CC5B4059C4B0C398F04B409224085740CC5B40E109BDFE24F24B40BC934F8F6DCE5B40E109BDFE24F24B40BC934F8F6DCE5B4059C4B0C398F04B409224085740CC5B4059C4B0C398F04B40
17318	Кичера	5	44	1479	110.08641799999999	110.114329	55.946455999999998	55.924526999999998	0103000020E6100000010000000500000049F25CDF87855B406EA296E656F64B4049F25CDF87855B402E8D5F7825F94B4000FF942A51875B402E8D5F7825F94B4000FF942A51875B406EA296E656F64B4049F25CDF87855B406EA296E656F64B40
17423	Верхняя Заимка	5	44	1479	110.120985	110.156307	55.852890000000002	55.843530000000001	0103000020E610000001000000050000009F93DE37BE875B40F29881CAF8EB4B409F93DE37BE875B40F08AE07F2BED4B40B24813EF008A5B40F08AE07F2BED4B40B24813EF008A5B40F29881CAF8EB4B409F93DE37BE875B40F29881CAF8EB4B40
17238	Байкальское	5	44	1479	109.168852	109.20226	55.359732000000001	55.353417	0103000020E610000001000000050000004F779E78CE4A5B40DB6CACC43CAD4B404F779E78CE4A5B408FA9BBB20BAE4B407E52EDD3F14C5B408FA9BBB20BAE4B407E52EDD3F14C5B40DB6CACC43CAD4B404F779E78CE4A5B40DB6CACC43CAD4B40
17484	Ангоя	5	44	1479	110.89988700000001	110.916641	56.012410000000003	56.005490000000002	0103000020E610000001000000050000001EC6A4BF97B95B403F3A75E5B3004C401EC6A4BF97B95B405A12A0A696014C400E4B033FAABA5B405A12A0A696014C400E4B033FAABA5B403F3A75E5B3004C401EC6A4BF97B95B403F3A75E5B3004C40
60261	Нижнеангарск	5	44	7504	109.538589	109.61376	55.818483000000001	55.761583000000002	0103000020E61000000100000005000000103FFF3D78625B4044183F8D7BE14B40103FFF3D78625B407EAA0A0DC4E84B40F3E505D847675B407EAA0A0DC4E84B40F3E505D847675B4044183F8D7BE14B40103FFF3D78625B4044183F8D7BE14B40
15474	Ярцы	5	44	1140	108.130893	108.155103	52.880057000000001	52.872258000000002	0103000020E610000001000000050000009F91088D60085B4052D66F26A66F4A409F91088D60085B40D5CE30B5A5704A40BC202235ED095B40D5CE30B5A5704A40BC202235ED095B4052D66F26A66F4A409F91088D60085B4052D66F26A66F4A40
16796	Югово	5	44	1140	107.099322	107.13097	52.127172000000002	52.117826999999998	0103000020E610000001000000050000007E71A94A5BC65A40FBCA83F4140F4A407E71A94A5BC65A40C47B0E2C47104A4075B0FECF61C85A40C47B0E2C47104A4075B0FECF61C85A40FBCA83F4140F4A407E71A94A5BC65A40FBCA83F4140F4A40
15847	Халзаново	5	44	1140	107.67198	107.683532	52.228223	52.222585000000002	0103000020E610000001000000050000003BE466B801EB5A4043CA4FAA7D1C4A403BE466B801EB5A40F6984869361D4A403F7100FDBEEB5A40F6984869361D4A403F7100FDBEEB5A4043CA4FAA7D1C4A403BE466B801EB5A4043CA4FAA7D1C4A40
16041	Турунтаево	5	44	1140	107.60908000000001	107.666213	52.214078000000001	52.178874999999998	0103000020E610000001000000050000007429AE2AFBE65A4037894160E5164A407429AE2AFBE65A4084656CE8661B4A40E2CAD93BA3EA5A4084656CE8661B4A40E2CAD93BA3EA5A4037894160E5164A407429AE2AFBE65A4037894160E5164A40
15360	Турка	5	44	1140	108.21208300000001	108.247648	52.958796	52.931057000000003	0103000020E61000000100000005000000684293C4920D5B401FDB32E02C774A40684293C4920D5B408FC4CBD3B97A4A40DE3AFF76D90F5B408FC4CBD3B97A4A40DE3AFF76D90F5B401FDB32E02C774A40684293C4920D5B401FDB32E02C774A40
46156	Троицкое	5	44	1140	107.159285	107.202009	52.122345000000003	52.116301	0103000020E61000000100000005000000936FB6B931CA5A40FDBE7FF3E20E4A40936FB6B931CA5A4021EA3E00A90F4A40DA1F28B7EDCC5A4021EA3E00A90F4A40DA1F28B7EDCC5A40FDBE7FF3E20E4A40936FB6B931CA5A40FDBE7FF3E20E4A40
16467	Татаурово	5	44	1140	107.42086500000001	107.452629	52.147562999999998	52.133419000000004	0103000020E61000000100000005000000FDC1C073EFDA5A4020D5B0DF13114A40FDC1C073EFDA5A40C18C2958E3124A40280EA0DFF7DC5A40C18C2958E3124A40280EA0DFF7DC5A4020D5B0DF13114A40FDC1C073EFDA5A4020D5B0DF13114A40
46239	Таловка	5	44	1140	107.123559	107.153994	52.120747000000001	52.111572000000002	0103000020E6100000010000000500000018080264E8C75A401D93C5FD470E4A4018080264E8C75A40890B40A3740F4A40EF71A609DBC95A40890B40A3740F4A40EF71A609DBC95A401D93C5FD470E4A4018080264E8C75A401D93C5FD470E4A40
16450	Старое Татаурово	5	44	1140	107.458882	107.48612799999999	52.106633000000002	52.084158000000002	0103000020E6100000010000000500000047AE9B525EDD5A4030D978B0C50A4A4047AE9B525EDD5A4052D66F26A60D4A40DF6A9DB81CDF5A4052D66F26A60D4A40DF6A9DB81CDF5A4030D978B0C50A4A4047AE9B525EDD5A4030D978B0C50A4A40
45553	Соболиха	5	44	1140	108.390066	108.405293	52.926144000000001	52.916539999999998	0103000020E61000000100000005000000055262D7F6185B40E8BCC62E51754A40055262D7F6185B407DB1F7E28B764A400E130D52F0195B407DB1F7E28B764A400E130D52F0195B40E8BCC62E51754A40055262D7F6185B40E8BCC62E51754A40
47088	Покровка	5	44	1140	107.27965	107.30465	52.157310000000003	52.146734000000002	0103000020E61000000100000005000000E4141DC9E5D15A400B9B012EC8124A40E4141DC9E5D15A40B9AAECBB22144A407DAEB6627FD35A40B9AAECBB22144A407DAEB6627FD35A400B9B012EC8124A40E4141DC9E5D15A400B9B012EC8124A40
15579	Нестерово	5	44	1140	107.873104	107.88979500000001	52.377313000000001	52.358457000000001	0103000020E610000001000000050000006F8099EFE0F75A40DA0242EBE12D4A406F8099EFE0F75A4086ADD9CA4B304A403D49BA66F2F85A4086ADD9CA4B304A403D49BA66F2F85A40DA0242EBE12D4A406F8099EFE0F75A40DA0242EBE12D4A40
16960	Мостовка	5	44	1140	107.019327	107.048334	52.096786000000002	52.083129	0103000020E61000000100000005000000823B50A73CC15A40B22C98F8A30A4A40823B50A73CC15A40F75AD07B630C4A403B527DE717C35A40F75AD07B630C4A403B527DE717C35A40B22C98F8A30A4A40823B50A73CC15A40B22C98F8A30A4A40
45959	Лиственничное	5	44	1140	107.527118	107.538814	52.171154000000001	52.164509000000002	0103000020E6100000010000000500000082C8224DBCE15A40E77283A10E154A4082C8224DBCE15A40304AD05FE8154A402028B7ED7BE25A40304AD05FE8154A402028B7ED7BE25A40E77283A10E154A4082C8224DBCE15A40E77283A10E154A40
10649	Котокель	5	44	1140	108.06800200000001	108.082735	52.764245000000003	52.756953000000003	0103000020E6100000010000000500000002840F255A045B40F7CDFDD5E3604A4002840F255A045B40D690B8C7D2614A4003CFBD874B055B40D690B8C7D2614A4003CFBD874B055B40F7CDFDD5E3604A4002840F255A045B40F7CDFDD5E3604A40
16145	Кома	5	44	1140	107.475375	107.515449	52.171855999999998	52.159222	0103000020E610000001000000050000008195438B6CDE5A40E066F16261144A408195438B6CDE5A4089CF9D60FF154A406170CD1DFDE05A4089CF9D60FF154A406170CD1DFDE05A40E066F16261144A408195438B6CDE5A40E066F16261144A40
10714	Кика	5	44	1140	108.01221700000001	108.034567	52.503264000000001	52.488833	0103000020E6100000010000000500000023DDCF29C8005B40501A6A14923E4A4023DDCF29C8005B4088A06AF46A404A4055A1815836025B4088A06AF46A404A4055A1815836025B40501A6A14923E4A4023DDCF29C8005B40501A6A14923E4A40
15775	Карымск	5	44	1140	107.69666599999999	107.718693	52.262703000000002	52.243505999999996	0103000020E610000001000000050000000C8FFD2C96EC5A409C3061342B1F4A400C8FFD2C96EC5A40D2C77C40A0214A404EB7EC10FFED5A40D2C77C40A0214A404EB7EC10FFED5A409C3061342B1F4A400C8FFD2C96EC5A409C3061342B1F4A40
16223	Итанца	5	44	1140	107.484053	107.504408	52.161791000000001	52.145927	0103000020E61000000100000005000000F7216FB9FADE5A403C4D66BCAD124A40F7216FB9FADE5A40C1E44691B5144A40CFF57D3848E05A40C1E44691B5144A40CFF57D3848E05A403C4D66BCAD124A40F7216FB9FADE5A403C4D66BCAD124A40
45613	Исток	5	44	1140	108.19643499999999	108.23066900000001	52.873361000000003	52.859541999999998	0103000020E610000001000000050000008B321B64920C5B40EBC4E578056E4A408B321B64920C5B400A4D124BCA6F4A40DECCE847C30E5B400A4D124BCA6F4A40DECCE847C30E5B40EBC4E578056E4A408B321B64920C5B40EBC4E578056E4A40
15868	Иркилик	5	44	1140	107.65316900000001	107.688446	52.202074000000003	52.178891999999998	0103000020E61000000100000005000000B5705985CDE95A400DC2DCEEE5164A40B5705985CDE95A409BAF928FDD194A40F8C3CF7F0FEC5A409BAF928FDD194A40F8C3CF7F0FEC5A400DC2DCEEE5164A40B5705985CDE95A400DC2DCEEE5164A40
33021	Ильинка	5	44	1140	107.220146	107.305836	52.128813999999998	52.116067999999999	0103000020E6100000010000000500000018963FDF16CE5A405A0EF450DB0E4A4018963FDF16CE5A402BA226FA7C104A40207C28D192D35A402BA226FA7C104A40207C28D192D35A405A0EF450DB0E4A4018963FDF16CE5A405A0EF450DB0E4A40
15763	Зырянск	5	44	1140	107.75626	107.793944	52.270358999999999	52.259743	0103000020E6100000010000000500000078D1579066F05A40B62E35423F214A4078D1579066F05A40F296AB1F9B224A40BFB67EFACFF25A40F296AB1F9B224A40BFB67EFACFF25A40B62E35423F214A4078D1579066F05A40B62E35423F214A40
15202	Золотой Ключ	5	44	1140	108.649733	108.661959	52.989547999999999	52.984234999999998	0103000020E610000001000000050000007288B83995295B400E4A9869FB7D4A407288B83995295B403EE94482A97E4A40BE1248895D2A5B403EE94482A97E4A40BE1248895D2A5B400E4A9869FB7D4A407288B83995295B400E4A9869FB7D4A40
10737	Гурулево	5	44	1140	107.915019	107.932599	52.405182000000003	52.397666000000001	0103000020E61000000100000005000000FE0DDAAB8FFA5A40965D30B8E6324A40FE0DDAAB8FFA5A40C576F700DD334A401152B7B3AFFB5A40C576F700DD334A401152B7B3AFFB5A40965D30B8E6324A40FE0DDAAB8FFA5A40965D30B8E6324A40
15497	Гремячинск	5	44	1140	107.95943200000001	107.98369599999999	52.806710000000002	52.790964000000002	0103000020E6100000010000000500000019AF795567FD5A401C28F04E3E654A4019AF795567FD5A4097ADF54542674A402F4D11E0F4FE5A4097ADF54542674A402F4D11E0F4FE5A401C28F04E3E654A4019AF795567FD5A401C28F04E3E654A40
15323	Горячинск	5	44	1140	108.283131	108.31676400000001	52.991120000000002	52.976851000000003	0103000020E61000000100000005000000F65E7CD11E125B404F081D74097D4A40F65E7CD11E125B40AD342905DD7E4A40362383DC45145B40AD342905DD7E4A40362383DC45145B404F081D74097D4A40F65E7CD11E125B404F081D74097D4A40
15663	Бурля	5	44	1140	107.74337800000001	107.754886	52.356796000000003	52.352148	0103000020E6100000010000000500000038A4518193EF5A4008AD872F132D4A4038A4518193EF5A40FCABC77DAB2D4A40548D5E0D50F05A40FCABC77DAB2D4A40548D5E0D50F05A4008AD872F132D4A4038A4518193EF5A4008AD872F132D4A40
45925	Бурдуково	5	44	1140	107.50233299999999	107.521809	52.092835000000001	52.088962000000002	0103000020E61000000100000005000000E6AC4F3926E05A401B4B581B630B4A40E6AC4F3926E05A404B766C04E20B4A408B70935165E15A404B766C04E20B4A408B70935165E15A401B4B581B630B4A40E6AC4F3926E05A401B4B581B630B4A40
45693	Батурино	5	44	1140	107.85330500000001	107.86219800000001	52.337938000000001	52.332048999999998	0103000020E61000000100000005000000DA20938C9CF65A40B2D5E594802A4A40DA20938C9CF65A40AF09698D412B4A404E2B85402EF75A40AF09698D412B4A404E2B85402EF75A40B2D5E594802A4A40DA20938C9CF65A40B2D5E594802A4A40
61054	Ангыр	5	44	1140	106.95649899999999	110.718994	53.385196999999998	51.905399000000003	0103000020E6100000010000000500000007EA944737BD5A40626A4B1DE4F3494007EA944737BD5A4037C2A2224EB14A404B0169FF03AE5B4037C2A2224EB14A404B0169FF03AE5B40626A4B1DE4F3494007EA944737BD5A40626A4B1DE4F34940
15063	Хара-Хужир	5	44	1362	99.711468999999994	99.720586999999995	52.608252	52.600332000000002	0103000020E610000001000000050000008AC745B588ED5840035FD1ADD74C4A408AC745B588ED584001DD9733DB4D4A400EBBEF181EEE584001DD9733DB4D4A400EBBEF181EEE5840035FD1ADD74C4A408AC745B588ED5840035FD1ADD74C4A40
14759	Сорок	5	44	1362	100.16369899999999	100.184585	52.329529000000001	52.319957000000002	0103000020E61000000100000005000000D3D85E0B7A0A59402A90D959F4284A40D3D85E0B7A0A5940B30A9B012E2A4A4042959A3DD00B5940B30A9B012E2A4A4042959A3DD00B59402A90D959F4284A40D3D85E0B7A0A59402A90D959F4284A40
15118	Саяны	5	44	1362	99.669472999999996	99.682562000000004	52.694412999999997	52.678691000000001	0103000020E61000000100000005000000852348A5D8EA5840768BC058DF564A40852348A5D8EA584068757286E2584A4083DF8618AFEB584068757286E2584A4083DF8618AFEB5840768BC058DF564A40852348A5D8EA5840768BC058DF564A40
14689	Самарта	5	44	1362	101.13312500000001	101.14139900000001	52.104712999999997	52.100515000000001	0103000020E61000000100000005000000EC51B81E85485940F4E0EEACDD0C4A40EC51B81E85485940A73B4F3C670D4A40FA2B64AE0C495940A73B4F3C670D4A40FA2B64AE0C495940F4E0EEACDD0C4A40EC51B81E85485940F4E0EEACDD0C4A40
14976	Орлик	5	44	1362	99.814927999999995	99.837655999999996	52.527925000000003	52.502946000000001	0103000020E610000001000000050000000F26C5C727F45840B7D3D68860404A400F26C5C727F45840D3DEE00B93434A401553E9279CF55840D3DEE00B93434A401553E9279CF55840B7D3D68860404A400F26C5C727F45840B7D3D68860404A40
61031	Шинестуй	5	44	1278	108.229771	108.24750400000001	51.344783	51.338318000000001	0103000020E610000001000000050000006EA46C91B40E5B40F6D214014EAB49406EA46C91B40E5B40BF9B6ED921AC49404568041BD70F5B40BF9B6ED921AC49404568041BD70F5B40F6D214014EAB49406EA46C91B40E5B40F6D214014EAB4940
14648	Шаралдай	5	44	1278	107.62338099999999	107.658694	51.044941999999999	51.008668999999998	0103000020E61000000100000005000000A8FC6B79E5E75A4098BED7101C814940A8FC6B79E5E75A40C11BD2A8C08549409204E10A28EA5A40C11BD2A8C08549409204E10A28EA5A4098BED7101C814940A8FC6B79E5E75A4098BED7101C814940
60886	Цолга	5	44	1278	107.230665	107.259114	51.083976999999997	51.071012000000003	0103000020E610000001000000050000003DD52137C3CE5A40D1CFD4EB168949403DD52137C3CE5A40DF4E22C2BF8A4940E3FBE25295D05A40DF4E22C2BF8A4940E3FBE25295D05A40D1CFD4EB168949403DD52137C3CE5A40D1CFD4EB16894940
14323	Хонхолой	5	44	1278	108.184226	108.269513	51.142263	51.122627000000001	0103000020E61000000100000005000000AA44D95BCA0B5B40A54DD53DB28F4940AA44D95BCA0B5B4026378AAC35924940333674B33F115B4026378AAC35924940333674B33F115B40A54DD53DB28F4940AA44D95BCA0B5B40A54DD53DB28F4940
14348	Харьястка	5	44	1278	107.652828	107.662476	51.258304000000003	51.242224999999998	0103000020E61000000100000005000000707A17EFC7E95A4005A3923A019F4940707A17EFC7E95A408736001B10A14940A298BC0166EA5A408736001B10A14940A298BC0166EA5A4005A3923A019F4940707A17EFC7E95A4005A3923A019F4940
14280	Харашибирь	5	44	1278	107.966538	108.01179500000001	51.105635999999997	51.086103999999999	0103000020E61000000100000005000000D71533C2DBFD5A400307B474058B4940D71533C2DBFD5A40DFA3FE7A858D494068D0D03FC1005B40DFA3FE7A858D494068D0D03FC1005B400307B474058B4940D71533C2DBFD5A400307B474058B4940
14213	Тугнуй	5	44	1278	108.09653299999999	108.12835099999999	51.222541999999997	51.207219000000002	0103000020E61000000100000005000000067FBF982D065B400F0EF626869A4940067FBF982D065B4043FE99417C9C49402BDA1CE736085B4043FE99417C9C49402BDA1CE736085B400F0EF626869A4940067FBF982D065B400F0EF626869A4940
61038	Тахай	5	44	1278	107.496961	107.532957	51.045712000000002	51.031920999999997	0103000020E61000000100000005000000CC988235CEDF5A401E87C1FC15844940CC988235CEDF5A4073840CE4D9854940274BADF71BE25A4073840CE4D9854940274BADF71BE25A401E87C1FC15844940CC988235CEDF5A401E87C1FC15844940
49423	Степной	5	44	1278	108.208265	108.221084	51.222565000000003	51.215581	0103000020E61000000100000005000000B1F9B836540D5B40CA518028989B4940B1F9B836540D5B40FC1D8A027D9C4940CF6A813D260E5B40FC1D8A027D9C4940CF6A813D260E5B40CA518028989B4940B1F9B836540D5B40CA518028989B4940
14070	Саган-Нур	5	44	1278	108.42111199999999	108.471615	51.350391000000002	51.334361999999999	0103000020E6100000010000000500000000FDBE7FF31A5B403883BF5FCCAA494000FDBE7FF31A5B4008E8BE9CD9AC49406553AEF02E1E5B4008E8BE9CD9AC49406553AEF02E1E5B403883BF5FCCAA494000FDBE7FF31A5B403883BF5FCCAA4940
13995	Подлопатки	5	44	1278	107.08326	107.106464	50.933992000000003	50.903187000000003	0103000020E610000001000000050000002844C02154C55A401096B1A19B7349402844C02154C55A40E25CC30C8D774940E38C614ED0C65A40E25CC30C8D774940E38C614ED0C65A401096B1A19B7349402844C02154C55A401096B1A19B734940
13895	Новый Заган	5	44	1278	107.732383	107.772367	51.041685999999999	51.017434999999999	0103000020E610000001000000050000005E49F25CDFEE5A402367614F3B8249405E49F25CDFEE5A40BC5983F7558549409E60FF756EF15A40BC5983F7558549409E60FF756EF15A402367614F3B8249405E49F25CDFEE5A402367614F3B824940
49427	Новоспасск	5	44	1278	108.119674	108.12449700000001	51.282325999999998	51.269795000000002	0103000020E610000001000000050000009E0B23BDA8075B40EACF7EA488A249409E0B23BDA8075B40BE67244223A44940CFDC43C2F7075B40BE67244223A44940CFDC43C2F7075B40EACF7EA488A249409E0B23BDA8075B40EACF7EA488A24940
60757	Никольск	5	44	1278	108.30006400000001	108.34253699999999	51.199486999999998	51.176861000000002	0103000020E610000001000000050000003FADA23F34135B400C789961A39649403FADA23F34135B40137D3ECA88994940E02A4F20EC155B40137D3ECA88994940E02A4F20EC155B400C789961A39649403FADA23F34135B400C789961A3964940
61039	Нарсата	5	44	1278	107.90019700000001	107.90733	51.267355000000002	51.256025999999999	0103000020E6100000010000000500000045BDE0D39CF95A407D76C075C5A0494045BDE0D39CF95A4007B64AB038A24940802BD9B111FA5A4007B64AB038A24940802BD9B111FA5A407D76C075C5A0494045BDE0D39CF95A407D76C075C5A04940
13613	Мухоршибирь	5	44	1278	107.79405199999999	107.857671	51.059584000000001	51.033445	0103000020E61000000100000005000000B2D47ABFD1F25A407C9BFEEC47844940B2D47ABFD1F25A40B4AED172A087494091EEE714E4F65A40B4AED172A087494091EEE714E4F65A407C9BFEEC47844940B2D47ABFD1F25A407C9BFEEC47844940
60883	Кусоты	5	44	1278	108.339707	108.364509	51.358322000000001	51.334395999999998	0103000020E610000001000000050000003ACE6DC2BD155B40E4F4F57CCDAA49403ACE6DC2BD155B40FAB7CB7EDDAD494040868E1D54175B40FAB7CB7EDDAD494040868E1D54175B40E4F4F57CCDAA49403ACE6DC2BD155B40E4F4F57CCDAA4940
49230	Калиновка	5	44	1278	107.76485700000001	107.788599	51.303615999999998	51.272184000000003	0103000020E610000001000000050000007847C66AF3F05A404B3FE1ECD6A249407847C66AF3F05A406B459BE3DCA6494022AAF06778F25A406B459BE3DCA6494022AAF06778F25A404B3FE1ECD6A249407847C66AF3F05A404B3FE1ECD6A24940
61020	Зандин	5	44	1278	107.426785	107.43858899999999	51.074176000000001	51.067124	0103000020E61000000100000005000000185B087250DB5A406B63EC8497884940185B087250DB5A40F51263997E894940A9D898D711DC5A40F51263997E894940A9D898D711DC5A406B63EC8497884940185B087250DB5A406B63EC8497884940
14439	Гашей	5	44	1278	107.3596	107.391023	51.047263999999998	51.030504999999998	0103000020E6100000010000000500000010E9B7AF03D75A40A7AE7C96E783494010E9B7AF03D75A409A232BBF0C864940F73E558506D95A409A232BBF0C864940F73E558506D95A40A7AE7C96E783494010E9B7AF03D75A40A7AE7C96E7834940
13495	Галтай	5	44	1278	107.785653	107.796972	51.241954999999997	51.227849999999997	0103000020E610000001000000050000004640852348F25A40613255302A9D49404640852348F25A40450DA661F89E4940F9F4D89601F35A40450DA661F89E4940F9F4D89601F35A40613255302A9D49404640852348F25A40613255302A9D4940
13764	Верхний Сутай	5	44	1278	107.897673	107.908039	51.318260000000002	51.306184000000002	0103000020E610000001000000050000002460747973F95A407C478D0931A749402460747973F95A40FFCF61BEBCA84940861F9C4F1DFA5A40FFCF61BEBCA84940861F9C4F1DFA5A407C478D0931A749402460747973F95A407C478D0931A74940
61022	Бом	5	44	1278	108.015927	108.03752299999999	51.228825999999998	51.219152000000001	0103000020E61000000100000005000000E607AEF204015B402F6D382C0D9C4940E607AEF204015B40BC3C9D2B4A9D49404276DEC666025B40BC3C9D2B4A9D49404276DEC666025B402F6D382C0D9C4940E607AEF204015B402F6D382C0D9C4940
13363	Бар	5	44	1278	107.55493	107.56447	51.308335	51.287255000000002	0103000020E610000001000000050000006F641EF983E35A40664E97C5C4A449406F641EF983E35A40289B728577A74940AE64C74620E45A40289B728577A74940AE64C74620E45A40664E97C5C4A449406F641EF983E35A40664E97C5C4A44940
61029	Балта	5	44	1278	107.14278299999999	107.162474	51.078488	51.071120000000001	0103000020E610000001000000050000002FDB4E5B23C95A40B70BCD751A8949402FDB4E5B23C95A40719010E50B8A4940D21C59F965CA5A40719010E50B8A4940D21C59F965CA5A40B70BCD751A8949402FDB4E5B23C95A40B70BCD751A894940
60900	Усть-Муя	5	44	1267	115.607967	115.645732	56.420378999999997	56.409075000000001	0103000020E6100000010000000500000006836BEEE8E65C403C4ED1915C344C4006836BEEE8E65C406C76A4FACE354C40C37E4FAC53E95C406C76A4FACE354C40C37E4FAC53E95C403C4ED1915C344C4006836BEEE8E65C403C4ED1915C344C40
32530	Таксимо	5	44	1267	114.800166	114.94120100000001	56.371172000000001	56.322699	0103000020E61000000100000005000000C15774EB35B35C40D8B969334E294C40C15774EB35B35C4070986890822F4C409A7D1EA33CBC5C4070986890822F4C409A7D1EA33CBC5C40D8B969334E294C40C15774EB35B35C40D8B969334E294C40
60717	Северомуйск	5	44	1267	114.337992	116.252876	57.249299999999998	55.197994999999999	0103000020E61000000100000005000000D19332A9A1955C40C1E270E657994B40D19332A9A1955C404772F90FE99F4C405F7CD11E2F105D404772F90FE99F4C405F7CD11E2F105D40C1E270E657994B40D19332A9A1955C40C1E270E657994B40
61058	Витим	5	44	1267	115.724245	115.728413	56.226123999999999	56.222985999999999	0103000020E61000000100000005000000A852B3075AEE5C40A1BB24CE8A1C4C40A852B3075AEE5C409C6B98A1F11C4C40CD3E8F519EEE5C409C6B98A1F11C4C40CD3E8F519EEE5C40A1BB24CE8A1C4C40A852B3075AEE5C40A1BB24CE8A1C4C40
61003	Энхэ-Тала	5	44	1152	107.15155900000001	107.17728700000001	50.223689999999998	50.214019	0103000020E61000000100000005000000871A8524B3C95A407FDC7EF9641B4940871A8524B3C95A409B38B9DFA11C494062C092AB58CB5A409B38B9DFA11C494062C092AB58CB5A407FDC7EF9641B4940871A8524B3C95A407FDC7EF9641B4940
11502	Шарагол	5	44	1152	107.33784300000001	107.354542	50.020541999999999	50.014870000000002	0103000020E61000000100000005000000AF0B3F389FD55A4084D89942E7014940AF0B3F389FD55A40E318C91EA1024940BDC3EDD0B0D65A40E318C91EA1024940BDC3EDD0B0D65A4084D89942E7014940AF0B3F389FD55A4084D89942E7014940
11242	Шазагай	5	44	1152	107.305099	107.354381	50.271828999999997	50.265903999999999	0103000020E61000000100000005000000B5C2F4BD86D35A4013F06B2409224940B5C2F4BD86D35A405C8DEC4ACB224940B954A52DAED65A405C8DEC4ACB224940B954A52DAED65A4013F06B2409224940B5C2F4BD86D35A4013F06B2409224940
12217	Чикой	5	44	1152	106.906193	106.92023399999999	50.277442000000001	50.266070999999997	0103000020E610000001000000050000004EB7EC10FFB95A40FEB4519D0E2249404EB7EC10FFB95A40B7442E3883234940B4AA251DE5BA5A40B7442E3883234940B4AA251DE5BA5A40FEB4519D0E2249404EB7EC10FFB95A40FEB4519D0E224940
61021	Хутор	5	44	1152	107.31416299999999	107.330054	50.028407000000001	50.020316000000001	0103000020E610000001000000050000003FA7203F1BD45A40F3CAF5B6990249403FA7203F1BD45A401EFD2FD7A20349407FFACF9A1FD55A401EFD2FD7A20349407FFACF9A1FD55A40F3CAF5B6990249403FA7203F1BD45A40F3CAF5B699024940
12561	Хоронхой	5	44	1152	106.13010300000001	106.163915	50.488377999999997	50.467398000000003	0103000020E610000001000000050000002387889B53885A40A01B9AB2D33B49402387889B53885A40FE0A992B833E4940BA1457957D8A5A40FE0A992B833E4940BA1457957D8A5A40A01B9AB2D33B49402387889B53885A40A01B9AB2D33B4940
61008	Холой	5	44	1152	107.10993999999999	107.134141	50.224071000000002	50.220336000000003	0103000020E610000001000000050000006C21C84109C75A40D41055F8331C49406C21C84109C75A40B37DC85BAE1C4940600322C495C85A40B37DC85BAE1C4940600322C495C85A40D41055F8331C49406C21C84109C75A40D41055F8331C4940
60960	Хилгантуй	5	44	1152	106.869237	106.884867	50.438612999999997	50.430207000000003	0103000020E6100000010000000500000048DE3994A1B75A4051C1E1051137494048DE3994A1B75A40DB4C857824384940D19332A9A1B85A40DB4C857824384940D19332A9A1B85A4051C1E1051137494048DE3994A1B75A4051C1E10511374940
61061	Харьяста	5	44	1152	106.63520800000001	106.639852	50.724494999999997	50.717104999999997	0103000020E61000000100000005000000168A743FA7A85A402766BD18CA5B4940168A743FA7A85A40C98E8D40BC5C4940EF91CD55F3A85A40C98E8D40BC5C4940EF91CD55F3A85A402766BD18CA5B4940168A743FA7A85A402766BD18CA5B4940
11136	Хамнигадай	5	44	1152	107.424818	107.43509400000001	50.182597999999999	50.173507000000001	0103000020E610000001000000050000002330D63730DB5A404450357A351649402330D63730DB5A4052280B5F5F174940E52B8194D8DB5A4052280B5F5F174940E52B8194D8DB5A404450357A351649402330D63730DB5A404450357A35164940
12515	Усть-Кяхта	5	44	1152	106.269153	106.290308	50.533351000000003	50.511251000000001	0103000020E61000000100000005000000B32781CD39915A400E863AAC70414940B32781CD39915A40FB2477D8444449401971016894925A40FB2477D8444449401971016894925A400E863AAC70414940B32781CD39915A400E863AAC70414940
11886	Усть-Киран	5	44	1152	106.80521400000001	106.82702500000001	50.428147000000003	50.410044999999997	0103000020E6100000010000000500000002124DA088B35A40B471C45A7C34494002124DA088B35A40B5705985CD3649405DFE43FAEDB45A40B5705985CD3649405DFE43FAEDB45A40B471C45A7C34494002124DA088B35A40B471C45A7C344940
60881	Усть-Дунгуй	5	44	1152	107.66738100000001	107.68225700000001	49.997709	49.986075	0103000020E61000000100000005000000323ECC5EB6EA5A409C33A2B437FE4840323ECC5EB6EA5A4062F6B2EDB4FF4840E59D4319AAEB5A4062F6B2EDB4FF4840E59D4319AAEB5A409C33A2B437FE4840323ECC5EB6EA5A409C33A2B437FE4840
11808	Унгуркуй	5	44	1152	107.146708	107.165357	50.312187999999999	50.297142999999998	0103000020E61000000100000005000000F183F3A963C95A401F9E25C808264940F183F3A963C95A40111AC1C6F52749408ACA863595CA5A40111AC1C6F52749408ACA863595CA5A401F9E25C808264940F183F3A963C95A401F9E25C808264940
10896	Уладый	5	44	1152	107.637359	107.646827	50.179997	50.168509999999998	0103000020E61000000100000005000000EC33677DCAE85A40448655BC91154940EC33677DCAE85A40663046240A174940DECA129D65E95A40663046240A174940DECA129D65E95A40448655BC91154940EC33677DCAE85A40448655BC91154940
11343	Убур-Киреть	5	44	1152	107.218861	107.26704700000001	50.295917000000003	50.261372000000001	0103000020E61000000100000005000000AC5791D101CE5A40890B40A374214940AC5791D101CE5A404CAAB69BE0254940ADDF4C4C17D15A404CAAB69BE0254940ADDF4C4C17D15A40890B40A374214940AC5791D101CE5A40890B40A374214940
11213	Тамир	5	44	1152	107.370955	107.418386	50.269157999999997	50.246288	0103000020E6100000010000000500000069520ABABDD75A40D9B27C5D861F494069520ABABDD75A4077BAF3C473224940ACC612D6C6DA5A4077BAF3C473224940ACC612D6C6DA5A40D9B27C5D861F494069520ABABDD75A40D9B27C5D861F4940
61012	Субуктуй	5	44	1152	106.41962100000001	106.428496	50.564681999999998	50.558329999999998	0103000020E61000000100000005000000C0ED0912DB9A5A401630815B77474940C0ED0912DB9A5A40E751F17F47484940E09D7C7A6C9B5A40E751F17F47484940E09D7C7A6C9B5A401630815B77474940C0ED0912DB9A5A401630815B77474940
48420	Семеновка	5	44	1152	107.32983900000001	107.354632	50.158163999999999	50.155642	0103000020E61000000100000005000000817C09151CD55A4028F1B913EC134940817C09151CD55A40C8B3CBB73E1449405D876A4AB2D65A40C8B3CBB73E1449405D876A4AB2D65A4028F1B913EC134940817C09151CD55A4028F1B913EC134940
11821	Полканово	5	44	1152	107.032505	107.042647	50.313786999999998	50.304307000000001	0103000020E6100000010000000500000037FDD98F14C25A40D1782288F326494037FDD98F14C25A407974232C2A28494071917BBABAC25A407974232C2A28494071917BBABAC25A40D1782288F326494037FDD98F14C25A40D1782288F3264940
48354	Первомайское	5	44	1152	107.445425	107.45390500000001	50.118817	50.113652999999999	0103000020E6100000010000000500000088F4DBD781DC5A40D00B772E8C0E494088F4DBD781DC5A40BB9A3C65350F49406B9F8EC70CDD5A40BB9A3C65350F49406B9F8EC70CDD5A40D00B772E8C0E494088F4DBD781DC5A40D00B772E8C0E4940
48588	Октябрьский	5	44	1152	107.068375	107.084778	50.223131000000002	50.217143	0103000020E610000001000000050000004C37894160C45A4015C78157CB1B49404C37894160C45A40A5DC7D8E8F1C4940E65AB4006DC55A40A5DC7D8E8F1C4940E65AB4006DC55A4015C78157CB1B49404C37894160C45A4015C78157CB1B4940
12393	Новодесятниково	5	44	1152	106.700785	106.714574	50.796463000000003	50.777881999999998	0103000020E61000000100000005000000C02154A9D9AC5A40D3122BA391634940C02154A9D9AC5A40AEBCE47FF26549409A249694BBAD5A40AEBCE47FF26549409A249694BBAD5A40D3122BA391634940C02154A9D9AC5A40D3122BA391634940
12616	Наушки	5	44	1152	106.090433	106.131468	50.416685999999999	50.371389999999998	0103000020E61000000100000005000000AB5E7EA7C9855A40DD0720B5892F4940AB5E7EA7C9855A40BC5983F7553549401D1EC2F869885A40BC5983F7553549401D1EC2F869885A40DD0720B5892F4940AB5E7EA7C9855A40DD0720B5892F4940
61041	Мурочи	5	44	1152	106.971025	106.978391	50.27834	50.272514000000001	0103000020E610000001000000050000004CA60A4625BE5A40E0D91EBDE12249404CA60A4625BE5A40969526A5A0234940D9EC48F59DBE5A40969526A5A0234940D9EC48F59DBE5A40E0D91EBDE12249404CA60A4625BE5A40E0D91EBDE1224940
10854	Малая Кудара	5	44	1152	107.671621	107.70275599999999	50.202280999999999	50.180503999999999	0103000020E61000000100000005000000A393A5D6FBEA5A400A664CC11A174940A393A5D6FBEA5A4014CD0358E419494056444DF4F9EC5A4014CD0358E419494056444DF4F9EC5A400A664CC11A174940A393A5D6FBEA5A400A664CC11A174940
60812	Майский	5	44	1152	106.05857899999999	107.9318	50.836095	49.960825999999997	0103000020E61000000100000005000000DF4E22C2BF835A40C092AB58FCFA4840DF4E22C2BF835A40B0AC3429056B49406B9A779CA2FB5A40B0AC3429056B49406B9A779CA2FB5A40C092AB58FCFA4840DF4E22C2BF835A40C092AB58FCFA4840
60525	Кяхта	5	44	1152	106.416549	106.486851	50.379559	50.321345000000001	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
12692	Кяхта	5	44	1152	106.416549	106.486851	50.379559	50.321345000000001	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
60950	Курорт Киран	5	44	1152	106.84999500000001	106.85815100000001	50.332000999999998	50.323335	0103000020E61000000100000005000000DEB06D5166B65A407A53910A63294940DEB06D5166B65A40A19E3E027F2A4940E7012CF2EBB65A40A19E3E027F2A4940E7012CF2EBB65A407A53910A63294940DEB06D5166B65A407A53910A63294940
11057	Кудара-Сомон	5	44	1152	107.37517699999999	107.40734500000001	50.16581	50.152951999999999	0103000020E61000000100000005000000874D64E602D85A40CCED5EEE93134940874D64E602D85A40C5AC1743391549401B4CC3F011DA5A40C5AC1743391549401B4CC3F011DA5A40CCED5EEE93134940874D64E602D85A40CCED5EEE93134940
12061	Киран	5	44	1152	106.696518	106.717251	50.346080999999998	50.331127000000002	0103000020E61000000100000005000000D2C43BC093AC5A404BE9995E622A4940D2C43BC093AC5A402C62D8614C2C49407E01BD70E7AD5A402C62D8614C2C49407E01BD70E7AD5A404BE9995E622A4940D2C43BC093AC5A404BE9995E622A4940
12403	Калинишна	5	44	1152	106.484596	106.492268	50.655842	50.650039999999997	0103000020E610000001000000050000006FF1F09E039F5A40C18BBE82345349406FF1F09E039F5A40EFAB72A1F25349408237A451819F5A40EFAB72A1F25349408237A451819F5A40C18BBE82345349406FF1F09E039F5A40C18BBE8234534940
60925	Ивановка	5	44	1152	107.22833799999999	107.24421100000001	50.187553000000001	50.181438999999997	0103000020E61000000100000005000000C79BFC169DCE5A40069CA56439174940C79BFC169DCE5A4023A298BC01184940B4942C27A1CF5A4023A298BC01184940B4942C27A1CF5A40069CA56439174940C79BFC169DCE5A40069CA56439174940
12050	Дурены	5	44	1152	106.878112	106.89626699999999	50.322944	50.314708000000003	0103000020E61000000100000005000000698EACFC32B85A4011E50B5A48284940698EACFC32B85A403F389F3A56294940FA5E43705CB95A403F389F3A56294940FA5E43705CB95A4011E50B5A48284940698EACFC32B85A4011E50B5A48284940
10952	Дунгуй	5	44	1152	107.53733200000001	107.571018	50.154083	50.143282999999997	0103000020E6100000010000000500000009C6C1A563E25A405089EB185712494009C6C1A563E25A404EEFE2FDB813494059DB148F8BE45A404EEFE2FDB813494059DB148F8BE45A405089EB185712494009C6C1A563E25A405089EB1857124940
60991	Бурдуны	5	44	1152	106.626296	106.64022900000001	50.405785000000002	50.400848000000003	0103000020E610000001000000050000006667D13B15A85A406155BDFC4E3349406667D13B15A85A408B1A4CC3F0334940DA3C0E83F9A85A408B1A4CC3F0334940DA3C0E83F9A85A406155BDFC4E3349406667D13B15A85A406155BDFC4E334940
33064	Большой Луг	5	44	1152	106.76691	106.786017	50.617463000000001	50.603624000000003	0103000020E610000001000000050000006C3EAE0D15B15A40558A1D8D434D49406C3EAE0D15B15A40BABE0F07094F494067463F1A4EB25A40BABE0F07094F494067463F1A4EB25A40558A1D8D434D49406C3EAE0D15B15A40558A1D8D434D4940
11591	Большая Кудара	5	44	1152	107.032155	107.06737800000001	50.20702	50.197299000000001	0103000020E61000000100000005000000C959D8D30EC25A404A44F81741194940C959D8D30EC25A4018CFA0A17F1A4940139ED0EB4FC45A4018CFA0A17F1A4940139ED0EB4FC45A404A44F81741194940C959D8D30EC25A404A44F81741194940
11038	Ара-Алцагат	5	44	1152	107.429237	107.451498	50.144623000000003	50.122830999999998	0103000020E61000000100000005000000EC4E779E78DB5A40ADF71BEDB80F4940EC4E779E78DB5A40ED9FA70183124940670DDE57E5DC5A40ED9FA70183124940670DDE57E5DC5A40ADF71BEDB80F4940EC4E779E78DB5A40ADF71BEDB80F4940
11425	Анагустай	5	44	1152	107.56737099999999	107.586631	49.994739000000003	49.979118	0103000020E61000000100000005000000B96C74CE4FE45A40647616BD53FD4840B96C74CE4FE45A402387889B53FF484077F4BF5C8BE55A402387889B53FF484077F4BF5C8BE55A40647616BD53FD4840B96C74CE4FE45A40647616BD53FD4840
60857	улус Харгана	5	44	1111	109.942993	112.01459800000001	55.543399000000001	53.922097999999998	0103000020E61000000100000005000000D8D64FFF597C5B407FDAA84E07F64A40D8D64FFF597C5B40EDD632198EC54B409225732CEF005C40EDD632198EC54B409225732CEF005C407FDAA84E07F64A40D8D64FFF597C5B407FDAA84E07F64A40
60951	Элэсун	5	44	1111	110.089814	110.103477	54.045588000000002	54.024673999999997	0103000020E61000000100000005000000452E3883BF855B40DF87838428034B40452E3883BF855B40878BDCD3D5054B40D8B8FE5D9F865B40878BDCD3D5054B40D8B8FE5D9F865B40DF87838428034B40452E3883BF855B40DF87838428034B40
10514	Шаманка	5	44	1111	110.463396	110.490346	54.471043000000002	54.463759000000003	0103000020E610000001000000050000003946B247A89D5B40E31C75745C3B4B403946B247A89D5B403F0114234B3C4B405D6E30D4619F5B403F0114234B3C4B405D6E30D4619F5B40E31C75745C3B4B403946B247A89D5B40E31C75745C3B4B40
10394	Хонхино	5	44	1111	110.216593	110.226968	54.237937000000002	54.228006000000001	0103000020E61000000100000005000000B9E2E2A8DC8D5B4059A5F44C2F1D4B40B9E2E2A8DC8D5B4012C138B8741E4B40444FCAA4868E5B4012C138B8741E4B40444FCAA4868E5B4059A5F44C2F1D4B40B9E2E2A8DC8D5B4059A5F44C2F1D4B40
60890	Улюнхан	5	44	1111	111.057919	111.07736800000001	54.869627000000001	54.854004000000003	0103000020E610000001000000050000004AB4E4F1B4C35B409C53C900506D4B404AB4E4F1B4C35B40FB5B02F04F6F4B407270E998F3C45B40FB5B02F04F6F4B407270E998F3C45B409C53C900506D4B404AB4E4F1B4C35B409C53C900506D4B40
60992	Сахули	5	44	1111	110.378388	110.420322	54.426094999999997	54.403199000000001	0103000020E61000000100000005000000BA4C4D8237985B40D4635B069C334B40BA4C4D8237985B409BFEEC478A364B4084F23E8EE69A5B409BFEEC478A364B4084F23E8EE69A5B40D4635B069C334B40BA4C4D8237985B40D4635B069C334B40
32779	Могойто	5	44	1111	110.45184399999999	110.467474	54.393943	54.371122999999997	0103000020E6100000010000000500000034B91803EB9C5B408EE55DF5802F4B4034B91803EB9C5B407BBE66B96C324B40BD6E1118EB9D5B407BBE66B96C324B40BD6E1118EB9D5B408EE55DF5802F4B4034B91803EB9C5B408EE55DF5802F4B40
32846	Майский	5	44	1111	110.78767000000001	110.808628	54.602663	54.585355999999997	0103000020E6100000010000000500000095826E2F69B25B40394206F2EC4A4B4095826E2F69B25B402FC1A90F244D4B4050A8A78FC0B35B402FC1A90F244D4B4050A8A78FC0B35B40394206F2EC4A4B4095826E2F69B25B40394206F2EC4A4B40
60287	Курумкан	5	44	1111	110.283913	110.33712	54.343057999999999	54.312967999999998	0103000020E61000000100000005000000317A6EA12B925B40E658DE550F284B40317A6EA12B925B40CA501553E92B4B40F6B4C35F93955B40CA501553E92B4B40F6B4C35F93955B40E658DE550F284B40317A6EA12B925B40E658DE550F284B40
60875	Курумкан	5	44	1111	110.283913	110.33712	54.343057999999999	54.312967999999998	0103000020E61000000100000005000000317A6EA12B925B40E658DE550F284B40317A6EA12B925B40CA501553E92B4B40F6B4C35F93955B40CA501553E92B4B40F6B4C35F93955B40E658DE550F284B40317A6EA12B925B40E658DE550F284B40
60885	Барагхан (Саранхур)	5	44	1111	110.150657	110.174076	54.160981999999997	54.142868999999997	0103000020E6100000010000000500000076FA415DA4895B405D4E098849124B4076FA415DA4895B40519FE40E9B144B402FC1A90F248B5B40519FE40E9B144B402FC1A90F248B5B405D4E098849124B4076FA415DA4895B405D4E098849124B40
60889	Арзгун (Разгон)	5	44	1111	110.723719	110.747039	54.387515999999998	54.370226000000002	0103000020E610000001000000050000009B1F7F6951AE5B408010C990632F4B409B1F7F6951AE5B409F56D11F9A314B408A75AA7CCFAF5B409F56D11F9A314B408A75AA7CCFAF5B408010C990632F4B409B1F7F6951AE5B408010C990632F4B40
60288	Аргада	5	44	1111	110.667089	110.695853	54.251058	54.228554000000003	0103000020E610000001000000050000005EA10F96B1AA5B405CAFE941411D4B405EA10F96B1AA5B4018B325AB22204B40B47405DB88AC5B4018B325AB22204B40B47405DB88AC5B405CAFE941411D4B405EA10F96B1AA5B405CAFE941411D4B40
10418	Алла	5	44	1111	110.80254600000001	110.83894600000001	54.697432999999997	54.680664999999998	0103000020E6100000010000000500000048E2E5E95CB35B401344DD0720574B4048E2E5E95CB35B4059130B7C45594B400B47904AB1B55B4059130B7C45594B400B47904AB1B55B401344DD0720574B4048E2E5E95CB35B401344DD0720574B40
60896	улус Могсохон	5	44	1022	109.06849200000001	111.804383	52.185198	51.359200000000001	0103000020E610000001000000050000006902452C62445B40925CFE43FAAD49406902452C62445B406EA46C91B4174A40569DD5027BF35B406EA46C91B4174A40569DD5027BF35B40925CFE43FAAD49406902452C62445B40925CFE43FAAD4940
61024	Эдэрмэг	5	44	1022	109.648067	109.673723	51.699340999999997	51.681418999999998	0103000020E610000001000000050000007AA702EE79695B40BFEFDFBC38D749407AA702EE79695B403FE0810184D9494008E412471E6B5B403FE0810184D9494008E412471E6B5B40BFEFDFBC38D749407AA702EE79695B40BFEFDFBC38D74940
61007	Чесан	5	44	1022	110.49472900000001	110.524473	51.975461000000003	51.954901999999997	0103000020E6100000010000000500000080D8D2A3A99F5B4047718E3A3AFA494080D8D2A3A99F5B4001C3F2E7DBFC4940A4A833F790A15B4001C3F2E7DBFC4940A4A833F790A15B4047718E3A3AFA494080D8D2A3A99F5B4047718E3A3AFA4940
9715	Хуртэй	5	44	1022	110.812472	110.840024	51.952648000000003	51.937869999999997	0103000020E610000001000000050000009B3A8F8AFFB35B4023F3C81F0CF849409B3A8F8AFFB35B40C74CA25EF0F94940BAF605F4C2B55B40C74CA25EF0F94940BAF605F4C2B55B4023F3C81F0CF849409B3A8F8AFFB35B4023F3C81F0CF84940
61026	Ушхайта	5	44	1022	109.83663199999999	109.863079	51.824078	51.809573999999998	0103000020E610000001000000050000005FB2F1608B755B4090D8EE1EA0E749405FB2F1608B755B4032AD4D637BE9494052B7B3AF3C775B4032AD4D637BE9494052B7B3AF3C775B4090D8EE1EA0E749405FB2F1608B755B4090D8EE1EA0E74940
61042	Усть-Орот	5	44	1022	109.766007	109.786767	51.990892000000002	51.974828000000002	0103000020E610000001000000050000007460394206715B40D09CF529C7FC49407460394206715B401CEF8E8CD5FE49409CA4F9635A725B401CEF8E8CD5FE49409CA4F9635A725B40D09CF529C7FC49407460394206715B40D09CF529C7FC4940
61044	Улзытэ	5	44	1022	110.118398	110.137793	51.918843000000003	51.911448999999998	0103000020E610000001000000050000005B7A34D593875B40677C5F5CAAF449405B7A34D593875B404B94BDA59CF549408927BB99D1885B404B94BDA59CF549408927BB99D1885B40677C5F5CAAF449405B7A34D593875B40677C5F5CAAF44940
9339	Сулхара	5	44	1022	110.15031500000001	110.188979	51.755974999999999	51.744214999999997	0103000020E610000001000000050000004A46CEC29E895B40A818E76F42DF49404A46CEC29E895B40FBCBEEC9C3E049405F28603B188C5B40FBCBEEC9C3E049405F28603B188C5B40A818E76F42DF49404A46CEC29E895B40A818E76F42DF4940
8908	Новокижингинск	5	44	1022	109.582553	109.617848	51.631647000000001	51.604995000000002	0103000020E61000000100000005000000F3CB608C48655B402C9FE57970CD4940F3CB608C48655B40EACE13CFD9D04940897956D28A675B40EACE13CFD9D04940897956D28A675B402C9FE57970CD4940F3CB608C48655B402C9FE57970CD4940
47765	Михайловка	5	44	1022	110.445798	110.48565600000001	51.901676000000002	51.886074000000001	0103000020E61000000100000005000000D2A755F4879C5B40FFEA71DF6AF14940D2A755F4879C5B4047CB811E6AF34940CC46E7FC149F5B4047CB811E6AF34940CC46E7FC149F5B40FFEA71DF6AF14940D2A755F4879C5B40FFEA71DF6AF14940
9026	Леоновка	5	44	1022	109.723777	109.744331	51.757575000000003	51.739525	0103000020E610000001000000050000003526C45C526E5B4086C954C1A8DE49403526C45C526E5B4034A2B437F8E0494089997D1EA36F5B4034A2B437F8E0494089997D1EA36F5B4086C954C1A8DE49403526C45C526E5B4086C954C1A8DE4940
61017	Куорка	5	44	1022	109.443916	109.460804	51.569392999999998	51.559103	0103000020E61000000100000005000000F48AA71E695C5B40390CE6AF90C74940F48AA71E695C5B4021C9ACDEE1C849406C770FD07D5D5B4021C9ACDEE1C849406C770FD07D5D5B40390CE6AF90C74940F48AA71E695C5B40390CE6AF90C74940
60911	Кулькисон	5	44	1022	111.01012900000001	111.02117800000001	52.051926000000002	52.045164	0103000020E6100000010000000500000070EF1AF4A5C05B40707A17EFC7054A4070EF1AF4A5C05B40F3E7DB82A5064A404359F8FA5AC15B40F3E7DB82A5064A404359F8FA5AC15B40707A17EFC7054A4070EF1AF4A5C05B40707A17EFC7054A40
60906	Красный Яр	5	44	1022	109.894762	109.908686	51.921881999999997	51.919803999999999	0103000020E6100000010000000500000007EDD5C743795B40705D3123BCF5494007EDD5C743795B40B262B83A00F64940511553E9277A5B40B262B83A00F64940511553E9277A5B40705D3123BCF5494007EDD5C743795B40705D3123BCF54940
61023	Кодунский Станок (Худанский Станок)	5	44	1022	109.74631599999999	109.759818	52.053339000000001	52.038201000000001	0103000020E61000000100000005000000D11E2FA4C36F5B4056D636C5E3044A40D11E2FA4C36F5B40F94CF6CFD3064A40603AADDBA0705B40F94CF6CFD3064A40603AADDBA0705B4056D636C5E3044A40D11E2FA4C36F5B4056D636C5E3044A40
9123	Кижинга	5	44	1022	109.87654499999999	109.94776299999999	51.860902000000003	51.818010000000001	0103000020E610000001000000050000003A1E335019785B4086E63A8DB4E849403A1E335019785B40CF87670932EE4940F7562426A87C5B40CF87670932EE4940F7562426A87C5B4086E63A8DB4E849403A1E335019785B4086E63A8DB4E84940
9366	Иннокентьевка	5	44	1022	110.02403	110.03636400000001	51.923253000000003	51.915304999999996	0103000020E61000000100000005000000DD0720B589815B40C16ED8B628F54940DD0720B589815B408A7780272DF649401DB0ABC953825B408A7780272DF649401DB0ABC953825B40C16ED8B628F54940DD0720B589815B40C16ED8B628F54940
60884	Загустай	5	44	1022	110.70913899999999	110.74967100000001	51.986266000000001	51.969752	0103000020E610000001000000050000005C548B8862AD5B40849D62D520FC49405C548B8862AD5B401094DBF63DFE49409EF0129CFAAF5B401094DBF63DFE49409EF0129CFAAF5B40849D62D520FC49405C548B8862AD5B40849D62D520FC4940
61025	Булак	5	44	1022	110.547523	110.571302	51.973719000000003	51.960385000000002	0103000020E61000000100000005000000B3B3E89D0AA35B40D4484BE5EDFA4940B3B3E89D0AA35B40363FFED2A2FC4940EC88433690A45B40363FFED2A2FC4940EC88433690A45B40D4484BE5EDFA4940B3B3E89D0AA35B40D4484BE5EDFA4940
61036	Бахлайта	5	44	1022	110.027731	110.071883	51.794469999999997	51.785808000000003	0103000020E6100000010000000500000077853E58C6815B40B477465B95E4494077853E58C6815B4099D36531B1E54940DB8827BB99845B4099D36531B1E54940DB8827BB99845B40B477465B95E4494077853E58C6815B40B477465B95E44940
7376	Шигаево	5	44	718	106.45832900000001	106.480886	52.190497999999998	52.175820999999999	0103000020E61000000100000005000000BD732843559D5A409A79724D81164A40BD732843559D5A4009FA0B3D62184A40ACC612D6C69E5A4009FA0B3D62184A40ACC612D6C69E5A409A79724D81164A40BD732843559D5A409A79724D81164A40
5888	Шергино	5	44	718	106.714313	106.75214099999999	52.123190999999998	52.100586	0103000020E61000000100000005000000E486DF4DB7AD5A40BD378600E00C4A40E486DF4DB7AD5A40AD1402B9C40F4A40C43E011423B05A40AD1402B9C40F4A40C43E011423B05A40BD378600E00C4A40E486DF4DB7AD5A40BD378600E00C4A40
5355	Шерашово	5	44	718	106.69234899999999	106.708259	52.266919999999999	52.254362999999998	0103000020E61000000100000005000000C51A2E724FAC5A40FE277FF78E204A40C51A2E724FAC5A40FC523F6F2A224A4040868E1D54AD5A40FC523F6F2A224A4040868E1D54AD5A40FE277FF78E204A40C51A2E724FAC5A40FE277FF78E204A40
5952	Хандала	5	44	718	106.70197899999999	106.722892	52.120646999999998	52.107711000000002	0103000020E61000000100000005000000A4DE5339EDAC5A40B1355B79C90D4A40A4DE5339EDAC5A4025AE635C710F4A4090A2CEDC43AE5A4025AE635C710F4A4090A2CEDC43AE5A40B1355B79C90D4A40A4DE5339EDAC5A40B1355B79C90D4A40
6006	Фофоново	5	44	718	106.74317600000001	106.764745	52.064534999999999	52.046875	0103000020E6100000010000000500000004CB113290AF5A400000000000064A4004CB113290AF5A404339D1AE42084A40E4310395F1B05A404339D1AE42084A40E4310395F1B05A400000000000064A4004CB113290AF5A400000000000064A40
6154	Тресково	5	44	718	106.889709	106.913946	52.062437000000003	52.045274999999997	0103000020E610000001000000050000003D7D04FEF0B85A40C7293A92CB054A403D7D04FEF0B85A40BA8784EFFD074A40D7135D177EBA5A40BA8784EFFD074A40D7135D177EBA5A40C7293A92CB054A403D7D04FEF0B85A40C7293A92CB054A40
7801	Тимлюй	5	44	718	106.550766	106.57719400000001	51.989117	51.971387999999997	0103000020E61000000100000005000000EB6F09C03FA35A4009DD257156FC4940EB6F09C03FA35A407575C7629BFE4940A35C1ABFF0A45A407575C7629BFE4940A35C1ABFF0A45A4009DD257156FC4940EB6F09C03FA35A4009DD257156FC4940
7359	Творогово	5	44	718	106.476089	106.507925	52.175291000000001	52.160161000000002	0103000020E61000000100000005000000103FFF3D789E5A401E8CD82780144A40103FFF3D789E5A403E247CEF6F164A4088F4DBD781A05A403E247CEF6F164A4088F4DBD781A05A401E8CD82780144A40103FFF3D789E5A401E8CD82780144A40
6082	Таракановка	5	44	718	106.949618	106.970782	52.078628999999999	52.069667000000003	0103000020E61000000100000005000000596C938AC6BC5A40234E27D9EA084A40596C938AC6BC5A4033C2DB83100A4A40E962D34A21BE5A4033C2DB83100A4A40E962D34A21BE5A40234E27D9EA084A40596C938AC6BC5A40234E27D9EA084A40
8657	Танхой	5	44	718	105.09348300000001	105.13986300000001	51.564382999999999	51.544772000000002	0103000020E61000000100000005000000D9EE1EA0FB455A4065E3C116BBC54940D9EE1EA0FB455A408DB5BFB33DC84940E9BAF083F3485A408DB5BFB33DC84940E9BAF083F3485A4065E3C116BBC54940D9EE1EA0FB455A4065E3C116BBC54940
5026	Сухая	5	44	718	107.092207	107.137474	52.554834	52.535210999999997	0103000020E61000000100000005000000965D30B8E6C55A40CFBA46CB81444A40965D30B8E6C55A40BC5AEECC04474A403883BF5FCCC85A40BC5AEECC04474A403883BF5FCCC85A40CFBA46CB81444A40965D30B8E6C55A40CFBA46CB81444A40
7549	Степной Дворец	5	44	718	106.386707	106.403254	52.178207	52.166347999999999	0103000020E610000001000000050000009888B7CEBF985A40A4E029E44A154A409888B7CEBF985A408A75AA7CCF164A40CC7EDDE9CE995A408A75AA7CCF164A40CC7EDDE9CE995A40A4E029E44A154A409888B7CEBF985A40A4E029E44A154A40
6266	Селенгинск	5	44	718	106.835649	106.890131	52.029519000000001	51.987675000000003	0103000020E61000000100000005000000D97BF1457BB55A40D50968226CFE4940D97BF1457BB55A4029CE5147C7034A40F88903E8F7B85A4029CE5147C7034A40F88903E8F7B85A40D50968226CFE4940D97BF1457BB55A40D50968226CFE4940
5756	Романово	5	44	718	106.656758	106.674464	52.118363000000002	52.10275	0103000020E61000000100000005000000BAD8B45208AA5A40FED478E9260D4A40BAD8B45208AA5A403A07CF84260F4A4014950D6B2AAB5A403A07CF84260F4A4014950D6B2AAB5A40FED478E9260D4A40BAD8B45208AA5A40FED478E9260D4A40
7475	Ранжурово	5	44	718	106.405418	106.43351800000001	52.181171999999997	52.168033000000001	0103000020E610000001000000050000006CCD565EF2995A400BD3F71A82154A406CCD565EF2995A40B779E3A430174A408D0E48C2BE9B5A40B779E3A430174A408D0E48C2BE9B5A400BD3F71A82154A406CCD565EF2995A400BD3F71A82154A40
8152	Посольское	5	44	718	106.175405	106.195581	52.029601999999997	52.006528000000003	0103000020E6100000010000000500000083A3E4D5398B5A401041D5E8D5004A4083A3E4D5398B5A40B6F292FFC9034A4004AE2B66848C5A40B6F292FFC9034A4004AE2B66848C5A401041D5E8D5004A4083A3E4D5398B5A401041D5E8D5004A40
7997	Посольская	5	44	718	106.33150500000001	106.361931	51.977308000000001	51.963171000000003	0103000020E61000000100000005000000795DBF6037955A4052BAF42F49FB4940795DBF6037955A40410FB56D18FD4940261AA4E029975A40410FB56D18FD4940261AA4E029975A4052BAF42F49FB4940795DBF6037955A4052BAF42F49FB4940
8639	Переемная	5	44	718	105.243852	105.26463	51.581439000000003	51.576580999999997	0103000020E610000001000000050000001C446B459B4F5A405B3FFD67CDC949401C446B459B4F5A403ACFD8976CCA494097E2AAB2EF505A403ACFD8976CCA494097E2AAB2EF505A405B3FFD67CDC949401C446B459B4F5A405B3FFD67CDC94940
5201	Оймур	5	44	718	106.803183	106.869713	52.347340000000003	52.316147999999998	0103000020E61000000100000005000000016DAB5967B35A401059A48977284A40016DAB5967B35A40DC4B1AA3752C4A40FDF9B660A9B75A40DC4B1AA3752C4A40FDF9B660A9B75A401059A48977284A40016DAB5967B35A401059A48977284A40
6779	Нюки	5	44	718	106.697712	106.71256099999999	52.032577000000003	52.021510999999997	0103000020E61000000100000005000000B6813B50A7AC5A408BC058DFC0024A40B6813B50A7AC5A4008CDAE7B2B044A40ECD973999AAD5A4008CDAE7B2B044A40ECD973999AAD5A408BC058DFC0024A40B6813B50A7AC5A408BC058DFC0024A40
60945	Новый Энхэлук	5	44	718	106.95918500000001	106.99974400000001	52.499217999999999	52.479691000000003	0103000020E6100000010000000500000015747B4963BD5A40C097C283663D4A4015747B4963BD5A408AC91B60E63F4A40D31742CEFBBF5A408AC91B60E63F4A40D31742CEFBBF5A40C097C283663D4A4015747B4963BD5A40C097C283663D4A40
6062	Никольск	5	44	718	106.863829	106.887445	52.073436999999998	52.067053999999999	0103000020E6100000010000000500000087156EF948B75A407288B83995084A4087156EF948B75A407EA8346266094A40EBFF1CE6CBB85A407EA8346266094A40EBFF1CE6CBB85A407288B83995084A4087156EF948B75A407288B83995084A40
8566	Мишиха	5	44	718	105.580478	105.596638	51.656025999999997	51.648963000000002	0103000020E610000001000000050000000A83328D26655A4033A8363811D349400A83328D26655A40B0A9F3A8F8D34940416326512F665A40B0A9F3A8F8D34940416326512F665A4033A8363811D349400A83328D26655A4033A8363811D34940
8299	Мантуриха	5	44	718	105.976877	105.98393799999999	51.779696000000001	51.774797999999997	0103000020E61000000100000005000000BCCD1B27857E5A40CB80B3942CE34940BCCD1B27857E5A4038691A14CDE34940AAD216D7F87E5A4038691A14CDE34940AAD216D7F87E5A40CB80B3942CE34940BCCD1B27857E5A40CB80B3942CE34940
7301	Малое Колесово	5	44	718	106.53533299999999	106.551574	52.132424	52.121858000000003	0103000020E610000001000000050000000DDE57E542A25A40C460FE0A990F4A400DDE57E542A25A404E9A0645F3104A40BBD408FD4CA35A404E9A0645F3104A40BBD408FD4CA35A40C460FE0A990F4A400DDE57E542A25A40C460FE0A990F4A40
60894	Кудара	5	44	718	106.63422799999999	106.67329599999999	52.252830000000003	52.207146000000002	0103000020E61000000100000005000000478D093197A85A40A5BF97C2831A4A40478D093197A85A404EB9C2BB5C204A40C4211B4817AB5A404EB9C2BB5C204A40C4211B4817AB5A40A5BF97C2831A4A40478D093197A85A40A5BF97C2831A4A40
5642	Красный Яр	5	44	718	106.571715	106.59823299999999	52.192065999999997	52.169359	0103000020E610000001000000050000007DE882FA96A45A404224438EAD154A407DE882FA96A45A403656629E95184A40D498107349A65A403656629E95184A40D498107349A65A404224438EAD154A407DE882FA96A45A404224438EAD154A40
5569	Корсаково	5	44	718	106.60797100000001	106.630042	52.260492999999997	52.245739999999998	0103000020E61000000100000005000000A77A32FFE8A65A40D6A88768741F4A40A77A32FFE8A65A4020EBA9D557214A40D046AE9B52A85A4020EBA9D557214A40D046AE9B52A85A40D6A88768741F4A40A77A32FFE8A65A40D6A88768741F4A40
8488	Клюевка	5	44	718	105.75015999999999	105.778143	51.694690999999999	51.681145999999998	0103000020E610000001000000050000001CB1169F02705A408EE6C8CA2FD749401CB1169F02705A40ABE97AA2EBD8494020274C18CD715A40ABE97AA2EBD8494020274C18CD715A408EE6C8CA2FD749401CB1169F02705A408EE6C8CA2FD74940
7189	Каргино	5	44	718	106.592151	106.60443100000001	52.087612	52.081873000000002	0103000020E61000000100000005000000CCD24ECDE5A55A4074B680D07A0A4A40CCD24ECDE5A55A405B5EB9DE360B4A40126C5CFFAEA65A405B5EB9DE360B4A40126C5CFFAEA65A4074B680D07A0A4A40CCD24ECDE5A55A4074B680D07A0A4A40
7618	Каменск	5	44	718	106.558384	106.62384400000001	52.009162000000003	51.972670000000001	0103000020E6100000010000000500000005A73E90BCA35A4071E6577380FC494005A73E90BCA35A40D82E6D382C014A409373620FEDA75A40D82E6D382C014A409373620FEDA75A4071E6577380FC494005A73E90BCA35A4071E6577380FC4940
60736	Каменск	5	44	718	106.558384	106.62384400000001	52.009162000000003	51.972670000000001	0103000020E6100000010000000500000005A73E90BCA35A4071E6577380FC494005A73E90BCA35A40D82E6D382C014A409373620FEDA75A40D82E6D382C014A409373620FEDA75A4071E6577380FC494005A73E90BCA35A4071E6577380FC4940
6895	Кабанск	5	44	718	106.630779	106.676575	52.068223000000003	52.042377000000002	0103000020E610000001000000050000003B00E2AE5EA85A40228D0A9C6C054A403B00E2AE5EA85A40E2EA0088BB084A40A3923A014DAB5A40E2EA0088BB084A40A3923A014DAB5A40228D0A9C6C054A403B00E2AE5EA85A40228D0A9C6C054A40
7576	Истомино	5	44	718	106.28285200000001	106.309748	52.142031000000003	52.123904000000003	0103000020E61000000100000005000000ED66463F1A925A40FBEB1516DC0F4A40ED66463F1A925A40540262122E124A40178046E9D2935A40540262122E124A40178046E9D2935A40FBEB1516DC0F4A40ED66463F1A925A40FBEB1516DC0F4A40
8174	Исток	5	44	718	106.248582	106.266817	52.109226999999997	52.088729000000001	0103000020E61000000100000005000000F4177AC4E88F5A40789ACC785B0B4A40F4177AC4E88F5A408B6B7C26FB0D4A4014419C8713915A408B6B7C26FB0D4A4014419C8713915A40789ACC785B0B4A40F4177AC4E88F5A40789ACC785B0B4A40
5002	Заречье	5	44	718	107.14204599999999	107.160354	52.557588000000003	52.542014000000002	0103000020E61000000100000005000000C4211B4817C95A40B1FCF9B660454A40C4211B4817C95A402F52280B5F474A4019726C3D43CA5A402F52280B5F474A4019726C3D43CA5A40B1FCF9B660454A40C4211B4817C95A40B1FCF9B660454A40
6867	Закалтус	5	44	718	106.57467	106.59826	52.025134999999999	52.011960999999999	0103000020E6100000010000000500000082FFAD64C7A45A40EAE923F087014A4082FFAD64C7A45A40137EA99F37034A4051A04FE449A65A40137EA99F37034A4051A04FE449A65A40EAE923F087014A4082FFAD64C7A45A40EAE923F087014A40
5669	Жилино	5	44	718	106.598341	106.615076	52.152481000000002	52.138261	0103000020E61000000100000005000000C8B60C384BA65A40F8A75489B2114A40C8B60C384BA65A407521567F84134A407D23BA675DA75A407521567F84134A407D23BA675DA75A40F8A75489B2114A40C8B60C384BA65A40F8A75489B2114A40
6811	Елань	5	44	718	106.669532	106.698108	52.009405999999998	51.996581999999997	0103000020E6100000010000000500000008E8BE9CD9AA5A4021E4BCFF8FFF494008E8BE9CD9AA5A406E313F3734014A40DD442DCDADAC5A406E313F3734014A40DD442DCDADAC5A4021E4BCFF8FFF494008E8BE9CD9AA5A4021E4BCFF8FFF4940
60948	Дулан	5	44	718	106.874977	106.882846	52.379336000000002	52.370753999999998	0103000020E6100000010000000500000024F0879FFFB75A403B6EF8DD742F4A4024F0879FFFB75A40051901158E304A40E259828C80B85A40051901158E304A40E259828C80B85A403B6EF8DD742F4A4024F0879FFFB75A403B6EF8DD742F4A40
5312	Дубинино	5	44	718	106.750991	106.77936	52.308653999999997	52.298318000000002	0103000020E61000000100000005000000C8258E3C10B05A4071E7C2482F264A40C8258E3C10B05A40C9E369F981274A40E0F3C308E1B15A40C9E369F981274A40E0F3C308E1B15A4071E7C2482F264A40C8258E3C10B05A4071E7C2482F264A40
7893	Горный	5	44	718	106.402822	106.410566	51.974434000000002	51.972270999999999	0103000020E61000000100000005000000FF06EDD5C7995A40B3EC496073FC4940FF06EDD5C7995A40240ED940BAFC49405FB69DB6469A5A40240ED940BAFC49405FB69DB6469A5A40B3EC496073FC4940FF06EDD5C7995A40B3EC496073FC4940
8812	Выдрино	5	44	718	104.631282	104.656614	51.475140000000003	51.446066000000002	0103000020E610000001000000050000006C239EEC66285A40C4EDD0B018B949406C239EEC66285A40BF823463D1BC49402106BAF6052A5A40BF823463D1BC49402106BAF6052A5A40C4EDD0B018B949406C239EEC66285A40C4EDD0B018B94940
5769	Быково	5	44	718	106.69661600000001	106.72945	52.171005000000001	52.147148999999999	0103000020E61000000100000005000000B477465B95AC5A40CE5147C7D5124A40B477465B95AC5A40EB39E97DE3154A404D840D4FAFAE5A40EB39E97DE3154A404D840D4FAFAE5A40CE5147C7D5124A40B477465B95AC5A40CE5147C7D5124A40
6215	Брянск	5	44	718	106.835307	106.89088599999999	52.047727999999999	52.018452000000003	0103000020E61000000100000005000000ACC77DAB75B55A40DD4598A25C024A40ACC77DAB75B55A403F8D7BF31B064A40B69DB64604B95A403F8D7BF31B064A40B69DB64604B95A40DD4598A25C024A40ACC77DAB75B55A40DD4598A25C024A40
8256	Боярский	5	44	718	106.05059300000001	106.076213	51.855457000000001	51.831786999999998	0103000020E61000000100000005000000051A6CEA3C835A40751E15FF77EA4940051A6CEA3C835A4030116F9D7FED4940ECA17DACE0845A4030116F9D7FED4940ECA17DACE0845A40751E15FF77EA4940051A6CEA3C835A40751E15FF77EA4940
7452	Борки	5	44	718	106.459281	106.47938600000001	52.158548000000003	52.149436000000001	0103000020E6100000010000000500000026AB22DC649D5A402B6C06B820134A4026AB22DC649D5A40516C054D4B144A40420A9E42AE9E5A40516C054D4B144A40420A9E42AE9E5A402B6C06B820134A4026AB22DC649D5A402B6C06B820134A40
7274	Большое Колесово	5	44	718	106.53854	106.563782	52.116045999999997	52.099524000000002	0103000020E610000001000000050000009FE5797077A25A406495D233BD0C4A409FE5797077A25A40726A6798DA0E4A40B404190115A45A40726A6798DA0E4A40B404190115A45A406495D233BD0C4A409FE5797077A25A406495D233BD0C4A40
7909	Большая Речка	5	44	718	106.295168	106.332628	51.977713000000001	51.967005	0103000020E61000000100000005000000D9B45208E4925A40C408E1D1C6FB4940D9B45208E4925A40E1EF17B325FD4940F86EF3C649955A40E1EF17B325FD4940F86EF3C649955A40C408E1D1C6FB4940D9B45208E4925A40C408E1D1C6FB4940
6721	Береговая	5	44	718	106.728273	106.74668800000001	52.030338999999998	52.020246999999998	0103000020E61000000100000005000000D4635B069CAE5A40CA6B257497024A40D4635B069CAE5A408C65FA25E2034A40341477BCC9AF5A408C65FA25E2034A40341477BCC9AF5A40CA6B257497024A40D4635B069CAE5A40CA6B257497024A40
60982	Байкальский Прибой	5	44	718	106.192437	106.200863	51.939413000000002	51.933788999999997	0103000020E61000000100000005000000956247E3508C5A40A92EE06586F74940956247E3508C5A40F83768AF3EF849407EFE7BF0DA8C5A40F83768AF3EF849407EFE7BF0DA8C5A40A92EE06586F74940956247E3508C5A40A92EE06586F74940
8338	Бабушкин	5	44	718	105.841402	105.89354899999999	51.721324000000003	51.703332000000003	0103000020E610000001000000050000007F32C687D9755A407A1D71C806DA49407F32C687D9755A40F3E8465854DC4940E71725E82F795A40F3E8465854DC4940E71725E82F795A407A1D71C806DA49407F32C687D9755A407A1D71C806DA4940
60880	Хурамша	5	44	577	106.977942	107.004244	51.642938000000001	51.618831999999998	0103000020E61000000100000005000000A1D80A9A96BE5A40F0DB10E335CF4940A1D80A9A96BE5A4086ADD9CA4BD24940124DA08845C05A4086ADD9CA4BD24940124DA08845C05A40F0DB10E335CF4940A1D80A9A96BE5A40F0DB10E335CF4940
60899	Хойтобэе	5	44	577	107.421925	107.44225400000001	51.795088999999997	51.787151000000001	0103000020E610000001000000050000005917B7D100DB5A40C1012D5DC1E449405917B7D100DB5A406534F279C5E549409DA1B8E34DDC5A406534F279C5E549409DA1B8E34DDC5A40C1012D5DC1E449405917B7D100DB5A40C1012D5DC1E44940
4821	Улус Оронгой	5	44	577	107.042153	107.093025	51.526620000000001	51.508932000000001	0103000020E61000000100000005000000691B7FA2B2C25A40A6F10BAF24C14940691B7FA2B2C25A40B3B5BE4868C34940772D211FF4C55A40B3B5BE4868C34940772D211FF4C55A40A6F10BAF24C14940691B7FA2B2C25A40A6F10BAF24C14940
4238	Тапхар	5	44	577	107.371844	107.378833	51.737211000000002	51.726579000000001	0103000020E61000000100000005000000AFCDC64ACCD75A40EE7A698A00DD4940AFCDC64ACCD75A4030A017EE5CDE49405169C4CC3ED85A4030A017EE5CDE49405169C4CC3ED85A40EE7A698A00DD4940AFCDC64ACCD75A40EE7A698A00DD4940
4063	Сужа	5	44	577	107.463059	107.472922	51.781132999999997	51.771047000000003	0103000020E61000000100000005000000954737C2A2DD5A40E75608ABB1E24940954737C2A2DD5A40C669882AFCE34940C5E3A25A44DE5A40C669882AFCE34940C5E3A25A44DE5A40E75608ABB1E24940954737C2A2DD5A40E75608ABB1E24940
45473	Сотниково	5	44	577	107.454848	107.48947800000001	51.914344	51.866847999999997	0103000020E61000000100000005000000AA29C93A1CDD5A402F4D11E0F4EE4940AA29C93A1CDD5A409CA5643909F549402387889B53DF5A409CA5643909F549402387889B53DF5A402F4D11E0F4EE4940AA29C93A1CDD5A402F4D11E0F4EE4940
21262	Солонцы	5	44	577	107.382561	107.405809	51.621901999999999	51.609403	0103000020E6100000010000000500000067EE21E17BD85A40CA8AE1EA00CE494067EE21E17BD85A4093A8177C9ACF49400ADB4FC6F8D95A4093A8177C9ACF49400ADB4FC6F8D95A40CA8AE1EA00CE494067EE21E17BD85A40CA8AE1EA00CE4940
52463	Саратовка	5	44	577	107.421395	107.42921	51.656382999999998	51.647162999999999	0103000020E61000000100000005000000ABECBB22F8DA5A403317B83CD6D24940ABECBB22F8DA5A403F53AF5B04D449406F47382D78DB5A403F53AF5B04D449406F47382D78DB5A403317B83CD6D24940ABECBB22F8DA5A403317B83CD6D24940
26360	Поселье	5	44	577	107.529426	107.54277500000001	51.812615000000001	51.802568999999998	0103000020E61000000100000005000000BCE9961DE2E15A4047E4BB94BAE64940BCE9961DE2E15A40999EB0C403E8494088855AD3BCE25A40999EB0C403E8494088855AD3BCE25A4047E4BB94BAE64940BCE9961DE2E15A4047E4BB94BAE64940
3808	Ошурково	5	44	577	107.46375999999999	107.480091	51.964002999999998	51.955984000000001	0103000020E61000000100000005000000594C6C3EAEDD5A40E8BF07AF5DFA4940594C6C3EAEDD5A40791F477364FB4940A7069ACFB9DE5A40791F477364FB4940A7069ACFB9DE5A40E8BF07AF5DFA4940594C6C3EAEDD5A40E8BF07AF5DFA4940
4780	Оронгой	5	44	577	107.04321299999999	107.060928	51.536777999999998	51.526373	0103000020E61000000100000005000000C5707500C4C25A40AB3FC23060C34940C5707500C4C25A402C9B3924B5C4494049DA8D3EE6C35A402C9B3924B5C4494049DA8D3EE6C35A40AB3FC23060C34940C5707500C4C25A40AB3FC23060C34940
4141	Нижняя Иволга	5	44	577	107.40452500000001	107.43376499999999	51.775103999999999	51.768532999999998	0103000020E61000000100000005000000865AD3BCE3D95A40C972124A5FE24940865AD3BCE3D95A40D87F9D9B36E34940904946CEC2DB5A40D87F9D9B36E34940904946CEC2DB5A40C972124A5FE24940865AD3BCE3D95A40C972124A5FE24940
21329	Нижний Саянтуй	5	44	577	107.49782399999999	107.52772899999999	51.743870000000001	51.727366000000004	0103000020E610000001000000050000007DCA3159DCDF5A40761C3F541ADD49407DCA3159DCDF5A40DE3CD52137DF4940A609DB4FC6E15A40DE3CD52137DF4940A609DB4FC6E15A40761C3F541ADD49407DCA3159DCDF5A40761C3F541ADD4940
4260	Красноярово	5	44	577	107.27031599999999	107.297068	51.795439999999999	51.785992	0103000020E6100000010000000500000079E57ADB4CD15A407575C7629BE4494079E57ADB4CD15A4012F758FAD0E549400A2C802903D35A4012F758FAD0E549400A2C802903D35A407575C7629BE4494079E57ADB4CD15A407575C7629BE44940
45685	Колобки	5	44	577	107.363867	107.379794	51.658349999999999	51.644710000000003	0103000020E61000000100000005000000FE45D09849D75A40BCB376DB85D24940FE45D09849D75A402AA913D044D44940E44D7E8B4ED85A402AA913D044D44940E44D7E8B4ED85A40BCB376DB85D24940FE45D09849D75A40BCB376DB85D24940
47758	Кокорино	5	44	577	106.982829	107.012733	51.634189999999997	51.600794	0103000020E61000000100000005000000DD239BABE6BE5A4007D15AD1E6CC4940DD239BABE6BE5A40A1B94E232DD149401EA5129ED0C05A40A1B94E232DD149401EA5129ED0C05A4007D15AD1E6CC4940DD239BABE6BE5A4007D15AD1E6CC4940
45702	Ключи	5	44	577	107.168313	107.185821	51.691749000000002	51.682440999999997	0103000020E61000000100000005000000779FE3A3C5CA5A408A39083A5AD74940779FE3A3C5CA5A403605323B8BD849403E7AC37DE4CB5A403605323B8BD849403E7AC37DE4CB5A408A39083A5AD74940779FE3A3C5CA5A408A39083A5AD74940
4928	Кибалино	5	44	577	107.006912	107.032191	51.427796000000001	51.412934999999997	0103000020E61000000100000005000000CC7C073F71C05A40D72FD80DDBB44940CC7C073F71C05A4008AEF204C2B649406F0ED76A0FC25A4008AEF204C2B649406F0ED76A0FC25A40D72FD80DDBB44940CC7C073F71C05A40D72FD80DDBB44940
4688	Каленово	5	44	577	107.08225400000001	107.14420200000001	51.763066000000002	51.751342000000001	0103000020E61000000100000005000000C6FD47A643C55A403D0E83F92BE04940C6FD47A643C55A4043588D25ACE149402481069B3AC95A4043588D25ACE149402481069B3AC95A403D0E83F92BE04940C6FD47A643C55A403D0E83F92BE04940
3615	Иволгинск	5	44	577	107.257075	107.303096	51.761611000000002	51.734768000000003	0103000020E61000000100000005000000A167B3EA73D05A40DC12B9E00CDE4940A167B3EA73D05A400EA320787CE1494019E3C3EC65D35A400EA320787CE1494019E3C3EC65D35A40DC12B9E00CDE4940A167B3EA73D05A40DC12B9E00CDE4940
4010	Гурульба	5	44	577	107.39609900000001	107.422186	51.834097	51.811624000000002	0103000020E610000001000000050000009DBE9EAF59D95A400953944BE3E749409DBE9EAF59D95A408A58C4B0C3EA49400FB56D1805DB5A408A58C4B0C3EA49400FB56D1805DB5A400953944BE3E749409DBE9EAF59D95A400953944BE3E74940
4900	Ганзурино	5	44	577	107.21462099999999	107.266858	51.522686	51.515070000000001	0103000020E610000001000000050000003A02B859BCCD5A404B9352D0EDC149403A02B859BCCD5A40DD09F65FE7C2494043AB933314D15A40DD09F65FE7C2494043AB933314D15A404B9352D0EDC149403A02B859BCCD5A404B9352D0EDC14940
21352	Вознесеновка	5	44	577	107.46504400000001	107.48697199999999	51.717312	51.707680000000003	0103000020E61000000100000005000000DECCE847C3DD5A4043041C4295DA4940DECCE847C3DD5A40A1832EE1D0DB494055849B8C2ADF5A40A1832EE1D0DB494055849B8C2ADF5A4043041C4295DA4940DECCE847C3DD5A4043041C4295DA4940
4592	Верхняя Иволга	5	44	577	107.18705199999999	107.204362	51.758583999999999	51.744259999999997	0103000020E61000000100000005000000B0A9F3A8F8CB5A4048DC63E943DF4940B0A9F3A8F8CB5A406AA2CF4719E14940E4A25A4414CD5A406AA2CF4719E14940E4A25A4414CD5A4048DC63E943DF4940B0A9F3A8F8CB5A4048DC63E943DF4940
21468	Верхний Саянтуй	5	44	577	107.538949	107.568315	51.648426000000001	51.631636	0103000020E61000000100000005000000904DF2237EE25A40F67CCD72D9D04940904DF2237EE25A4024F0879FFFD24940E1B4E0455FE45A4024F0879FFFD24940E1B4E0455FE45A40F67CCD72D9D04940904DF2237EE25A40F67CCD72D9D04940
61000	сельское поселение Усть-Бургалтайское	5	44	379	102.148392	104.657099	51.319695000000003	50.131498999999998	0103000020E610000001000000050000003CBF28417F895940753A90F5D41049403CBF28417F895940EDD808C4EBA84940FFCEF6E80D2A5A40EDD808C4EBA84940FFCEF6E80D2A5A40753A90F5D41049403CBF28417F895940753A90F5D4104940
61001	сельское поселение Мылинское	5	44	379	102.148392	104.657099	51.319695000000003	50.131498999999998	0103000020E610000001000000050000003CBF28417F895940753A90F5D41049403CBF28417F895940EDD808C4EBA84940FFCEF6E80D2A5A40EDD808C4EBA84940FFCEF6E80D2A5A40753A90F5D41049403CBF28417F895940753A90F5D4104940
60978	Шара-Азарга	5	44	379	103.03780500000001	103.063183	50.488888000000003	50.473211999999997	0103000020E6100000010000000500000005A8A9656BC259409109F835923C494005A8A9656BC2594014B4C9E1933E494071AAB5300BC4594014B4C9E1933E494071AAB5300BC459409109F835923C494005A8A9656BC259409109F835923C4940
60912	Цакир	5	44	379	103.568826	103.60087799999999	50.448169999999998	50.434820000000002	0103000020E6100000010000000500000054C72AA567E45940C8D2872EA837494054C72AA567E459402F8672A25D394940B2B8FFC874E659402F8672A25D394940B2B8FFC874E65940C8D2872EA837494054C72AA567E45940C8D2872EA8374940
60946	Цаган-Морин	5	44	379	103.190618	103.21237499999999	50.750267000000001	50.731816000000002	0103000020E61000000100000005000000DA01D71533CC594043588D25AC5D4940DA01D71533CC59404F22C2BF086049403BDF4F8D97CD59404F22C2BF086049403BDF4F8D97CD594043588D25AC5D4940DA01D71533CC594043588D25AC5D4940
60941	Хуртага	5	44	379	103.931054	103.95091600000001	50.457008000000002	50.431004999999999	0103000020E61000000100000005000000D733846396FB5940CCB4FD2B2B374940D733846396FB59405401F73C7F3A4940904FC8CEDBFC59405401F73C7F3A4940904FC8CEDBFC5940CCB4FD2B2B374940D733846396FB5940CCB4FD2B2B374940
45517	Хужир	5	44	379	103.25506300000001	103.27858999999999	50.429850999999999	50.420388000000003	0103000020E61000000100000005000000DCDAC2F352D05940C0D02346CF354940DCDAC2F352D059409293895B0537494087BF266BD4D159409293895B0537494087BF266BD4D15940C0D02346CF354940DCDAC2F352D05940C0D02346CF354940
60901	Холтосон	5	44	379	103.301694	103.33848	50.305157999999999	50.286658000000003	0103000020E6100000010000000500000090D959F44ED3594082919735B124494090D959F44ED359406F0ED76A0F274940689604A8A9D559406F0ED76A0F274940689604A8A9D5594082919735B124494090D959F44ED3594082919735B1244940
60910	Харацай	5	44	379	104.468408	104.490336	50.489851000000002	50.477322000000001	0103000020E61000000100000005000000D34B8C65FA1D5A40A6D425E3183D4940D34B8C65FA1D5A40DA740470B33E49404B033FAA611F5A40DA740470B33E49404B033FAA611F5A40A6D425E3183D4940D34B8C65FA1D5A40A6D425E3183D4940
60940	Хамней	5	44	379	103.854275	103.882814	50.410595999999998	50.392446999999997	0103000020E6100000010000000500000096B20C71ACF65940E7340BB43B32494096B20C71ACF6594028EFE3688E344940DC9C4A0680F8594028EFE3688E344940DC9C4A0680F85940E7340BB43B32494096B20C71ACF65940E7340BB43B324940
60942	Утата	5	44	379	102.772856	102.79393899999999	50.838461000000002	50.815458	0103000020E610000001000000050000001D21037976B159407BA180ED606849401D21037976B1594059FCA6B0526B4940360186E5CFB2594059FCA6B0526B4940360186E5CFB259407BA180ED606849401D21037976B159407BA180ED60684940
60949	Улентуй	5	44	379	103.417784	103.427611	50.502811999999999	50.494016999999999	0103000020E61000000100000005000000B1321AF9BCDA59408255F5F23B3F4940B1321AF9BCDA5940A704C4245C4049403B1A87FA5DDB5940A704C4245C4049403B1A87FA5DDB59408255F5F23B3F4940B1321AF9BCDA59408255F5F23B3F4940
60892	Улекчин	5	44	379	104.27623199999999	104.305795	50.499614999999999	50.463838000000003	0103000020E61000000100000005000000F486FBC8AD115A402F52280B5F3B4940F486FBC8AD115A40A7CB6262F33F4940F111312592135A40A7CB6262F33F4940F111312592135A402F52280B5F3B4940F486FBC8AD115A402F52280B5F3B4940
60909	Санага	5	44	379	102.78544100000001	102.817727	50.751936999999998	50.708331999999999	0103000020E6100000010000000500000001FC53AA44B25940EA5A7B9FAA5A494001FC53AA44B2594080D3BB783F6049409983A0A355B4594080D3BB783F6049409983A0A355B45940EA5A7B9FAA5A494001FC53AA44B25940EA5A7B9FAA5A4940
60963	Нурта	5	44	379	103.125957	103.13901799999999	50.392740000000003	50.384596000000002	0103000020E61000000100000005000000F2ECF2AD0FC85940121615713A314940F2ECF2AD0FC8594060EAE74D453249408AE3C0ABE5C8594060EAE74D453249408AE3C0ABE5C85940121615713A314940F2ECF2AD0FC85940121615713A314940
60908	Михайловка	5	44	379	104.138897	104.174533	50.418689999999998	50.401989999999998	0103000020E61000000100000005000000CD203EB0E3085A40D6A8876874334940CD203EB0E3085A40C49448A297354940A8C4758C2B0B5A40C49448A297354940A8C4758C2B0B5A40D6A8876874334940CD203EB0E3085A40D6A8876874334940
32545	Закаменск	5	44	379	103.269229	103.308378	50.402168000000003	50.335732999999998	0103000020E61000000100000005000000A088450C3BD159400F98874CF92A4940A088450C3BD15940B6BFB33D7A33494094331477BCD35940B6BFB33D7A33494094331477BCD359400F98874CF92A4940A088450C3BD159400F98874CF92A4940
60935	Ехэ-Цакир	5	44	379	103.50766900000001	103.521072	50.484153999999997	50.459606000000001	0103000020E610000001000000050000005B0C1EA67DE05940CF85915ED43A49405B0C1EA67DE05940211D1EC2F83D494020B75F3E59E15940211D1EC2F83D494020B75F3E59E15940CF85915ED43A49405B0C1EA67DE05940CF85915ED43A4940
60986	Енгорбой	5	44	379	102.909086	102.927797	50.523049	50.502056000000003	0103000020E6100000010000000500000018D00B772EBA59405B61FA5E4340494018D00B772EBA59404E9A0645F3424940EC14AB0661BB59404E9A0645F3424940EC14AB0661BB59405B61FA5E4340494018D00B772EBA59405B61FA5E43404940
60895	Дутулур	5	44	379	103.357596	103.39184	50.444028000000003	50.431021999999999	0103000020E610000001000000050000008C4B55DAE2D65940A2ED98BA2B3749408C4B55DAE2D659401041D5E8D5384940F05014E813D959401041D5E8D5384940F05014E813D95940A2ED98BA2B3749408C4B55DAE2D65940A2ED98BA2B374940
60979	Далахай	5	44	379	102.889323	102.89922199999999	50.912139000000003	50.887717000000002	0103000020E61000000100000005000000292504ABEAB85940378DEDB5A0714940292504ABEAB85940FD3383F8C0744940FF756EDA8CB95940FD3383F8C0744940FF756EDA8CB95940378DEDB5A0714940292504ABEAB85940378DEDB5A0714940
60999	Бургуй	5	44	379	103.77528599999999	103.792552	50.474702000000001	50.442892000000001	0103000020E61000000100000005000000FCC22B499EF159407CD45FAFB0384940FCC22B499EF1594043ACFE08C33C49404818062CB9F2594043ACFE08C33C49404818062CB9F259407CD45FAFB0384940FCC22B499EF159407CD45FAFB0384940
60975	Бортой	5	44	379	103.373299	103.397329	50.685836000000002	50.675744999999999	0103000020E610000001000000050000004A287D21E4D75940BFB7E9CF7E5649404A287D21E4D75940B1355B79C957494027309DD66DD95940B1355B79C957494027309DD66DD95940BFB7E9CF7E5649404A287D21E4D75940BFB7E9CF7E564940
33128	Баянгол	5	44	379	103.459771	103.48213	50.709878000000003	50.692615000000004	0103000020E610000001000000050000008D2958E36CDD59400ADCBA9BA75849408D2958E36CDD594030134548DD5A4940E99AC937DBDE594030134548DD5A4940E99AC937DBDE59400ADCBA9BA75849408D2958E36CDD59400ADCBA9BA7584940
60937	улус Хонхолой	5	44	24	107.644294	109.384996	52.358798	51.399799000000002	0103000020E6100000010000000500000094C0E61C3CE95A409CFC169D2CB3494094C0E61C3CE95A4063EFC517ED2D4A40D04543C6A3585B4063EFC517ED2D4A40D04543C6A3585B409CFC169D2CB3494094C0E61C3CE95A409CFC169D2CB34940
1286	Эрхирик	5	44	24	107.807626	107.83489899999999	51.897035000000002	51.880220999999999	0103000020E610000001000000050000008E59F624B0F35A404F20EC14ABF049408E59F624B0F35A40062FFA0AD2F24940A31D37FC6EF55A40062FFA0AD2F24940A31D37FC6EF55A404F20EC14ABF049408E59F624B0F35A404F20EC14ABF04940
61035	Шэнэ-Буса	5	44	24	108.491962	108.509857	51.741459999999996	51.732464	0103000020E61000000100000005000000FC372F4E7C1F5B40A9BF5E61C1DD4940FC372F4E7C1F5B4065A54929E8DE4940BF28417FA1205B4065A54929E8DE4940BF28417FA1205B40A9BF5E61C1DD4940FC372F4E7C1F5B40A9BF5E61C1DD4940
1025	Шабур	5	44	24	108.308077	108.329134	51.483116000000003	51.467111000000003	0103000020E6100000010000000500000096E99788B7135B400A4D124BCABB494096E99788B7135B405116BEBED6BD49401B800D8810155B405116BEBED6BD49401B800D8810155B400A4D124BCABB494096E99788B7135B400A4D124BCABB4940
60882	Челутай, 3-й км	5	44	24	108.354799	108.37201899999999	51.761175999999999	51.753711000000003	0103000020E61000000100000005000000D369DD06B5165B4057D11F9A79E04940D369DD06B5165B40034015376EE14940669FC728CF175B40034015376EE14940669FC728CF175B4057D11F9A79E04940D369DD06B5165B4057D11F9A79E04940
475	Челутай	5	44	24	108.355158	108.40198700000001	51.762931999999999	51.750410000000002	0103000020E610000001000000050000006BBA9EE8BA165B40B24B546F0DE049406BBA9EE8BA165B4033897AC1A7E14940B39AAE27BA195B4033897AC1A7E14940B39AAE27BA195B40B24B546F0DE049406BBA9EE8BA165B40B24B546F0DE04940
60968	Хара-Шибирь	5	44	24	108.448852	108.459892	52.075707000000001	52.067165000000003	0103000020E61000000100000005000000A12FBDFDB91C5B40CA37DBDC98084A40A12FBDFDB91C5B40058A58C4B0094A404AECDADE6E1D5B40058A58C4B0094A404AECDADE6E1D5B40CA37DBDC98084A40A12FBDFDB91C5B40CA37DBDC98084A40
862	Хара-Кутул	5	44	24	109.30466800000001	109.322796	51.765495999999999	51.758454999999998	0103000020E61000000100000005000000D10836AE7F535B406C3EAE0D15E14940D10836AE7F535B40029CDEC5FBE14940E5D18DB0A8545B40029CDEC5FBE14940E5D18DB0A8545B406C3EAE0D15E14940D10836AE7F535B406C3EAE0D15E14940
32483	Усть-Брянь	5	44	24	108.12642	108.14824	51.947330000000001	51.925196999999997	0103000020E61000000100000005000000DC63E94317085B40BCADF4DA6CF64940DC63E94317085B408542041C42F9494061FD9FC37C095B408542041C42F9494061FD9FC37C095B40BCADF4DA6CF64940DC63E94317085B40BCADF4DA6CF64940
1594	Унэгэтэй	5	44	24	108.546688	108.58573699999999	52.120448000000003	52.079735999999997	0103000020E610000001000000050000006747AAEFFC225B402C280CCA340A4A406747AAEFFC225B402F6F0ED76A0F4A40A8C30AB77C255B402F6F0ED76A0F4A40A8C30AB77C255B402C280CCA340A4A406747AAEFFC225B402C280CCA340A4A40
32432	Тодогто	5	44	24	108.040882	108.058543	51.851173000000003	51.843473000000003	0103000020E61000000100000005000000AF3F89CF9D025B408E075BECF6EB4940AF3F89CF9D025B407E1EA33CF3EC4940399A232BBF035B407E1EA33CF3EC4940399A232BBF035B408E075BECF6EB4940AF3F89CF9D025B408E075BECF6EB4940
688	Ташелан	5	44	24	108.881238	108.910928	51.688561	51.679358999999998	0103000020E61000000100000005000000847F113466385B40239F573CF5D64940847F113466385B40892650C422D84940AF40F4A44C3A5B40892650C422D84940AF40F4A44C3A5B40239F573CF5D64940847F113466385B40239F573CF5D64940
531	Татарский Ключ	5	44	24	108.387156	108.406452	51.691799000000003	51.680413999999999	0103000020E61000000100000005000000D09CF529C7185B40CADE52CE17D74940D09CF529C7185B40E833A0DE8CD8494034D93F4F031A5B40E833A0DE8CD8494034D93F4F031A5B40CADE52CE17D74940D09CF529C7185B40CADE52CE17D74940
1292	Старый Онохой	5	44	24	108.03871700000001	108.06215400000001	51.949506	51.932045000000002	0103000020E610000001000000050000002733DE567A025B403EB324404DF749402733DE567A025B408AADA06989F949403354C554FA035B408AADA06989F949403354C554FA035B403EB324404DF749402733DE567A025B403EB324404DF74940
1511	Старая Курба	5	44	24	108.501305	108.528676	52.009971	52.003069000000004	0103000020E610000001000000050000009014916115205B40D350A39064004A409014916115205B404774CFBA46014A40878BDCD3D5215B404774CFBA46014A40878BDCD3D5215B40D350A39064004A409014916115205B40D350A39064004A40
898	Старая Брянь	5	44	24	108.111768	108.141161	51.594712000000001	51.567025000000001	0103000020E61000000100000005000000512FF83427075B40D881734694C84940512FF83427075B40F644D7851FCC49401F9E25C808095B40F644D7851FCC49401F9E25C808095B40D881734694C84940512FF83427075B40D881734694C84940
1411	Первомаевка	5	44	24	108.385368	108.409677	52.044859000000002	52.017726000000003	0103000020E61000000100000005000000323B8BDEA9185B40FB2477D844024A40323B8BDEA9185B4034F790F0BD054A40193BE125381A5B4034F790F0BD054A40193BE125381A5B40FB2477D844024A40323B8BDEA9185B40FB2477D844024A40
60934	Онохой-Шибирь	5	44	24	108.011741	108.022368	51.982627999999998	51.973757999999997	0103000020E610000001000000050000006EC1525DC0005B40F31B261AA4FC49406EC1525DC0005B4023111AC1C6FD4940861E317A6E015B4023111AC1C6FD4940861E317A6E015B40F31B261AA4FC49406EC1525DC0005B40F31B261AA4FC4940
60877	Онохой	5	44	24	108.001015	108.098123	51.941662000000001	51.902431	0103000020E610000001000000050000008CF337A110005B40C3F2E7DB82F349408CF337A110005B4067F1626188F8494011FFB0A547065B4067F1626188F8494011FFB0A547065B40C3F2E7DB82F349408CF337A110005B40C3F2E7DB82F34940
32193	Онохой	5	44	24	108.001015	108.098123	51.941662000000001	51.902431	0103000020E610000001000000050000008CF337A110005B40C3F2E7DB82F349408CF337A110005B4067F1626188F8494011FFB0A547065B4067F1626188F8494011FFB0A547065B40C3F2E7DB82F349408CF337A110005B40C3F2E7DB82F34940
169	Новоильинск	5	44	24	108.68383300000001	108.762688	51.690838999999997	51.670544999999997	0103000020E610000001000000050000003DBB7CEBC32B5B4087BF266BD4D549403DBB7CEBC32B5B4092E68F696DD849404E4354E1CF305B4092E68F696DD849404E4354E1CF305B4087BF266BD4D549403DBB7CEBC32B5B4087BF266BD4D54940
1560	Новая Курба	5	44	24	108.503497	108.520448	52.050553000000001	52.032910000000001	0103000020E6100000010000000500000095287B4B39205B400EDB166536044A4095287B4B39205B407BDB4C8578064A4031D120054F215B407BDB4C8578064A4031D120054F215B400EDB166536044A4095287B4B39205B400EDB166536044A40
29982	Новая Брянь	5	44	24	108.237398	108.29409	51.732965999999998	51.696745	0103000020E61000000100000005000000B1886187310F5B406553AEF02ED94940B1886187310F5B403B8A73D4D1DD49402905DD5ED2125B403B8A73D4D1DD49402905DD5ED2125B406553AEF02ED94940B1886187310F5B406553AEF02ED94940
30	Нижние Тальцы	5	44	24	107.889363	107.978386	51.896079	51.877262999999999	0103000020E6100000010000000500000070D1C952EBF85A40D47E6B274AF0494070D1C952EBF85A40F2D077B7B2F24940503750E09DFE5A40F2D077B7B2F24940503750E09DFE5A40D47E6B274AF0494070D1C952EBF85A40D47E6B274AF04940
1393	Нарын-Ацагат	5	44	24	108.278577	108.296767	52.011339999999997	52.000652000000002	0103000020E61000000100000005000000BD1AA034D4115B40A8565F5D15004A40BD1AA034D4115B407D91D09673014A400DE2033BFE125B407D91D09673014A400DE2033BFE125B40A8565F5D15004A40BD1AA034D4115B40A8565F5D15004A40
52879	Нарын	5	44	24	109.070459	109.086378	51.717641	51.70984	0103000020E610000001000000050000005E2D776682445B4042B28009DCDA49405E2D776682445B4066A208A9DBDB49400246973787455B4066A208A9DBDB49400246973787455B4042B28009DCDA49405E2D776682445B4042B28009DCDA4940
699	Мухор-Тала	5	44	24	108.80401000000001	108.816847	51.761521000000002	51.747070000000001	0103000020E610000001000000050000000CEA5BE674335B404FE960FD9FDF49400CEA5BE674335B40CE1B278579E149407CB5A33847345B40CE1B278579E149407CB5A33847345B404FE960FD9FDF49400CEA5BE674335B404FE960FD9FDF4940
1191	Кижа	5	44	24	108.877106	108.88850600000001	51.460911000000003	51.452330000000003	0103000020E610000001000000050000000648348122385B40F67F0EF3E5B949400648348122385B40EFAEB321FFBA494030134548DD385B40EFAEB321FFBA494030134548DD385B40F67F0EF3E5B949400648348122385B40F67F0EF3E5B94940
417	Илька	5	44	24	108.492519	108.557216	51.732591999999997	51.712217000000003	0103000020E61000000100000005000000276A696E851F5B40DF5339ED29DB4940276A696E851F5B40D6A71C93C5DD4940B5334C6DA9235B40D6A71C93C5DD4940B5334C6DA9235B40DF5339ED29DB4940276A696E851F5B40DF5339ED29DB4940
32098	Заиграево	5	44	24	108.250738	108.301142	51.849499000000002	51.817864999999998	0103000020E61000000100000005000000537765170C105B4082C5E1CCAFE84940537765170C105B400B7E1B62BCEC4940EE5C18E945135B400B7E1B62BCEC4940EE5C18E945135B4082C5E1CCAFE84940537765170C105B4082C5E1CCAFE84940
60929	Добо-Ёнхор	5	44	24	108.153818	108.165003	52.007331999999998	52.000563	0103000020E6100000010000000500000050E27327D8095B40384BC97212004A4050E27327D8095B406D1B4641F0004A407B2FBE688F0A5B406D1B4641F0004A407B2FBE688F0A5B40384BC97212004A4050E27327D8095B40384BC97212004A40
48986	Горхон	5	44	24	108.77083500000001	108.79654499999999	51.569679000000001	51.549404000000003	0103000020E610000001000000050000002EE7525C55315B405325CADE52C649402EE7525C55315B40E71BD13DEBC84940B532E197FA325B40E71BD13DEBC84940B532E197FA325B405325CADE52C649402EE7525C55315B405325CADE52C64940
967	Атхатай	5	44	24	108.034226	108.05566899999999	51.540733000000003	51.535232000000001	0103000020E6100000010000000500000011AB3FC230025B40E7E26F7B82C4494011AB3FC230025B401A6F2BBD36C54940AA99B51490035B401A6F2BBD36C54940AA99B51490035B40E7E26F7B82C4494011AB3FC230025B40E7E26F7B82C44940
1661	Ангир	5	44	24	108.592726	108.60409900000001	52.223678	52.215463	0103000020E610000001000000050000004A5F0839EF255B40C03FA54A941B4A404A5F0839EF255B40D76A0F7BA11C4A40F722DA8EA9265B40D76A0F7BA11C4A40F722DA8EA9265B40C03FA54A941B4A404A5F0839EF255B40C03FA54A941B4A40
31035	Эгита	5	44	1903	110.726558	110.744919	52.431891999999998	52.417465	0103000020E610000001000000050000006B2920ED7FAE5B40C11C3D7E6F354A406B2920ED7FAE5B40B7B3AF3C48374A40D1CABDC0ACAF5B40B7B3AF3C48374A40D1CABDC0ACAF5B40C11C3D7E6F354A406B2920ED7FAE5B40C11C3D7E6F354A40
31716	Ширинга	5	44	1903	111.698508	111.71160500000001	52.685723000000003	52.669420000000002	0103000020E61000000100000005000000A4FFE55AB4EC5B40E8A4F78DAF554A40A4FFE55AB4EC5B40B98E71C5C5574A40E3AAB2EF8AED5B40B98E71C5C5574A40E3AAB2EF8AED5B40E8A4F78DAF554A40A4FFE55AB4EC5B40E8A4F78DAF554A40
60930	Целинный	5	44	1903	112.852349	112.87848099999999	52.611691	52.600217000000001	0103000020E61000000100000005000000D0F1D1E28C365C406AC020E9D34C4A40D0F1D1E28C365C40F72004E44B4E4A40124A5F0839385C40F72004E44B4E4A40124A5F0839385C406AC020E9D34C4A40D0F1D1E28C365C406AC020E9D34C4A40
31825	Хорга	5	44	1903	111.81643	111.82711999999999	52.822929999999999	52.815320999999997	0103000020E610000001000000050000004A5E9D6340F45B40FA5E43705C684A404A5E9D6340F45B40DA722EC555694A408577B988EFF45B40DA722EC555694A408577B988EFF45B40FA5E43705C684A404A5E9D6340F45B40FA5E43705C684A40
60984	Хангир	5	44	1903	110.892216	110.899573	52.363472999999999	52.360300000000002	0103000020E61000000100000005000000F33D23111AB95B40D95F764F1E2E4A40F33D23111AB95B4050FD8348862E4A4056D7A19A92B95B4050FD8348862E4A4056D7A19A92B95B40D95F764F1E2E4A40F33D23111AB95B40D95F764F1E2E4A40
30893	Усть-Эгита	5	44	1903	110.600605	110.618903	52.339517000000001	52.326715999999998	0103000020E610000001000000050000001A34F44F70A65B403B8A73D4D1294A401A34F44F70A65B40D0B7054B752B4A405D19541B9CA75B40D0B7054B752B4A405D19541B9CA75B403B8A73D4D1294A401A34F44F70A65B403B8A73D4D1294A40
30822	Ульдурга	5	44	1903	110.52502	110.55592300000001	52.234279999999998	52.212251000000002	0103000020E61000000100000005000000BD6F7CED99A15B408BC56F0A2B1B4A40BD6F7CED99A15B40AE0D15E3FC1D4A400806103E94A35B40AE0D15E3FC1D4A400806103E94A35B408BC56F0A2B1B4A40BD6F7CED99A15B408BC56F0A2B1B4A40
60976	Улзытэ (Занультуй)	5	44	1903	110.859185	110.869327	52.46855	52.456687000000002	0103000020E61000000100000005000000AE0D15E3FCB65B4012C138B8743A4A40AE0D15E3FCB65B4039454772F93B4A40E8A1B60DA3B75B4039454772F93B4A40E8A1B60DA3B75B4012C138B8743A4A40AE0D15E3FCB65B4012C138B8743A4A40
31298	Укыр	5	44	1903	111.397428	111.41762199999999	52.531874999999999	52.519157999999997	0103000020E61000000100000005000000F1A0D9756FD95B4077BAF3C473424A40F1A0D9756FD95B40AE47E17A14444A40C405A051BADA5B40AE47E17A14444A40C405A051BADA5B4077BAF3C473424A40F1A0D9756FD95B4077BAF3C473424A40
31696	Тулдун	5	44	1903	111.57631000000001	111.59011700000001	52.692627999999999	52.681213999999997	0103000020E61000000100000005000000E6965643E2E45B40E6C9350532574A40E6965643E2E45B409E25C808A8584A4013F4177AC4E55B409E25C808A8584A4013F4177AC4E55B40E6C9350532574A40E6965643E2E45B40E6C9350532574A40
30859	Тужинка	5	44	1903	110.537148	110.561061	52.312811000000004	52.300927999999999	0103000020E61000000100000005000000284701A260A25B40B03907CF84264A40284701A260A25B401F6ADB300A284A40E883656CE8A35B401F6ADB300A284A40E883656CE8A35B40B03907CF84264A40284701A260A25B40B03907CF84264A40
31944	Телемба	5	44	1903	113.278465	113.29771599999999	52.745834000000002	52.729635000000002	0103000020E610000001000000050000002905DD5ED2515C402C82FFAD645D4A402905DD5ED2515C40581F0F7D775F4A40BDDF68C70D535C40581F0F7D775F4A40BDDF68C70D535C402C82FFAD645D4A402905DD5ED2515C402C82FFAD645D4A40
31453	Сосново-Озерское	5	44	1903	111.502073	111.576454	52.547671000000001	52.50658	0103000020E6100000010000000500000018CDCAF621E05B4062670A9DD7404A4018CDCAF621E05B40DBFB54151A464A407F69519FE4E45B40DBFB54151A464A407F69519FE4E45B4062670A9DD7404A4018CDCAF621E05B4062670A9DD7404A40
60898	Романовка	5	44	1903	112.75182700000001	112.793042	53.223618999999999	53.203159999999997	0103000020E61000000100000005000000FD4FFEEE1D305C407CED9925019A4A40FD4FFEEE1D305C40D2E1218C9F9C4A40AF963B33C1325C40D2E1218C9F9C4A40AF963B33C1325C407CED9925019A4A40FD4FFEEE1D305C407CED9925019A4A40
31017	Поперечное	5	44	1903	110.69619400000001	110.72603599999999	52.387889000000001	52.379413	0103000020E61000000100000005000000F96A47718EAC5B40B056ED9A90304A40F96A47718EAC5B4034BDC458A6314A40FEEDB25F77AE5B4034BDC458A6314A40FEEDB25F77AE5B40B056ED9A90304A40F96A47718EAC5B40B056ED9A90304A40
31852	Озерный	5	44	1903	111.690117	111.70284700000001	52.935133	52.924982	0103000020E61000000100000005000000795A7EE02AEC5B40C0B167CF65764A40795A7EE02AEC5B4087342A70B2774A40DFC5FB71FBEC5B4087342A70B2774A40DFC5FB71FBEC5B40C0B167CF65764A40795A7EE02AEC5B40C0B167CF65764A40
31117	Можайка	5	44	1903	110.77868700000001	110.80127	52.418349999999997	52.406281	0103000020E6100000010000000500000081B4FF01D6B15B403BFE0B0401344A4081B4FF01D6B15B400B24287E8C354A400551F70148B35B400B24287E8C354A400551F70148B35B403BFE0B0401344A4081B4FF01D6B15B403BFE0B0401344A40
60936	Комсомольское	5	44	1903	111.076505	111.117361	52.487527999999998	52.474632999999997	0103000020E61000000100000005000000C03E3A75E5C45B401A4D2EC6C03C4A40C03E3A75E5C45B4030F14751673E4A40DB34B6D782C75B4030F14751673E4A40DB34B6D782C75B401A4D2EC6C03C4A40C03E3A75E5C45B401A4D2EC6C03C4A40
31928	Исинга	5	44	1903	111.982429	112.01806500000001	52.920155999999999	52.902799999999999	0103000020E610000001000000050000001669E21DE0FE5B40166A4DF38E734A401669E21DE0FE5B40ED9BFBABC7754A40F20C1AFA27015C40ED9BFBABC7754A40F20C1AFA27015C40166A4DF38E734A401669E21DE0FE5B40166A4DF38E734A40
31652	Домна	5	44	1903	111.70540699999999	111.72132499999999	52.567267000000001	52.556767000000001	0103000020E61000000100000005000000A5D7666325ED5B40FB3E1C2444474A40A5D7666325ED5B40CE8C7E349C484A40613255302AEE5B40CE8C7E349C484A40613255302AEE5B40FB3E1C2444474A40A5D7666325ED5B40FB3E1C2444474A40
31779	Гунда	5	44	1903	111.711246	111.73933599999999	52.790692	52.769623000000003	0103000020E610000001000000050000004B5AF10D85ED5B40ED9FA70183624A404B5AF10D85ED5B40BB9A3C6535654A405930F14751EF5B40BB9A3C6535654A405930F14751EF5B40ED9FA70183624A404B5AF10D85ED5B40ED9FA70183624A40
31242	Гонда	5	44	1903	111.22371200000001	111.250105	52.537019000000001	52.526583000000002	0103000020E6100000010000000500000042EE224C51CE5B4096D05D1267434A4042EE224C51CE5B40522AE109BD444A403BE466B801D05B40522AE109BD444A403BE466B801D05B4096D05D1267434A4042EE224C51CE5B4096D05D1267434A40
31391	Гарам	5	44	1903	111.43961299999999	111.449001	52.576549	52.571781999999999	0103000020E610000001000000050000005F79909E22DC5B4082380F2730494A405F79909E22DC5B4050C58D5BCC494A40C3B7B06EBCDC5B4050C58D5BCC494A40C3B7B06EBCDC5B4082380F2730494A405F79909E22DC5B4082380F2730494A40
29207	Шартыкей	5	44	1860	104.796662	104.808663	50.520833000000003	50.505540000000003	0103000020E61000000100000005000000D2FD9C82FC325A40F168E388B5404940D2FD9C82FC325A40BBD6DEA7AA4249400E9F7422C1335A40BBD6DEA7AA4249400E9F7422C1335A40F168E388B5404940D2FD9C82FC325A40F168E388B5404940
60904	Цагатуй	5	44	1860	105.29101300000001	105.311971	50.737077999999997	50.721826	0103000020E610000001000000050000007F6DFDF49F525A4085B35BCB645C49407F6DFDF49F525A40F04C6892585E49403A933655F7535A40F04C6892585E49403A933655F7535A4085B35BCB645C49407F6DFDF49F525A4085B35BCB645C4940
30655	Цаган-Усун	5	44	1860	106.024012	106.03871700000001	50.440126999999997	50.430483000000002	0103000020E610000001000000050000008AADA06989815A40F33D23111A3749408AADA06989815A40158BDF14563849402733DE567A825A40158BDF14563849402733DE567A825A40F33D23111A3749408AADA06989815A40F33D23111A374940
29311	Хулдат	5	44	1860	104.685064	104.693786	50.497391999999998	50.482686999999999	0103000020E61000000100000005000000AFEAAC16D82B5A40289A07B0C83D4940AFEAAC16D82B5A4061A5828AAA3F49400D1B65FD662C5A4061A5828AAA3F49400D1B65FD662C5A40289A07B0C83D4940AFEAAC16D82B5A40289A07B0C83D4940
60914	Хужир	5	44	1860	106.192994	106.199803	50.578010999999996	50.571032000000002	0103000020E61000000100000005000000C09481035A8C5A40187C9A9317494940C09481035A8C5A4037DDB243FC49494022A98592C98C5A4037DDB243FC49494022A98592C98C5A40187C9A9317494940C09481035A8C5A40187C9A9317494940
60995	Улзар	5	44	1860	104.812175	104.824788	50.764204999999997	50.749566000000002	0103000020E610000001000000050000003EE8D9ACFA335A40C61858C7F15F49403EE8D9ACFA335A4047382D78D161494087889B53C9345A4047382D78D161494087889B53C9345A40C61858C7F15F49403EE8D9ACFA335A40C61858C7F15F4940
60902	Тэнгэрэк	5	44	1860	105.10914099999999	105.13008000000001	50.486963000000003	50.481012999999997	0103000020E61000000100000005000000C669882AFC465A40B5F97FD5913D4940C669882AFC465A4058AEB7CD543E49404777103B53485A4058AEB7CD543E49404777103B53485A40B5F97FD5913D4940C669882AFC465A40B5F97FD5913D4940
60970	Тасархай	5	44	1860	105.558891	105.56472100000001	50.529027999999997	50.522545999999998	0103000020E61000000100000005000000D7C1C1DEC4635A40EB538EC9E2424940D7C1C1DEC4635A408A558330B743494053978C6324645A408A558330B743494053978C6324645A40EB538EC9E2424940D7C1C1DEC4635A40EB538EC9E2424940
60905	Старый Укырчелон	5	44	1860	104.969506	104.982775	50.517201999999997	50.504795000000001	0103000020E61000000100000005000000A6D1E4620C3E5A409817601F9D404940A6D1E4620C3E5A4080B6D5AC33424940E4141DC9E53E5A4080B6D5AC33424940E4141DC9E53E5A409817601F9D404940A6D1E4620C3E5A409817601F9D404940
29818	Петропавловка	5	44	1860	105.280719	105.351856	50.616576999999999	50.601709	0103000020E610000001000000050000006A17D34CF7515A40BC5AEECC044D49406A17D34CF7515A409F3BC1FEEB4E4940B03907CF84565A409F3BC1FEEB4E4940B03907CF84565A40BC5AEECC044D49406A17D34CF7515A40BC5AEECC044D4940
29338	Оёр	5	44	1860	104.974833	105.00459499999999	50.544142000000001	50.527819999999998	0103000020E61000000100000005000000F183F3A9633E5A405D16139B8F434940F183F3A9633E5A40A530EF71A645494068AED3484B405A40A530EF71A645494068AED3484B405A405D16139B8F434940F183F3A9633E5A405D16139B8F434940
60973	Нюгуй	5	44	1860	105.747663	105.764974	50.526662999999999	50.519458999999998	0103000020E61000000100000005000000795BE9B5D96F5A40724EECA17D424940795BE9B5D96F5A40B28174B16943494094128255F5705A40B28174B16943494094128255F5705A40724EECA17D424940795BE9B5D96F5A40724EECA17D424940
29274	Нижний Торей	5	44	1860	104.80506099999999	104.84367	50.540146	50.520415	0103000020E610000001000000050000003E92921E86335A4086AC6EF59C4249403E92921E86335A4059880E812345494072A774B0FE355A4059880E812345494072A774B0FE355A4086AC6EF59C4249403E92921E86335A4086AC6EF59C424940
60928	Нижний Бургалтай	5	44	1860	105.11542	105.136889	50.569665000000001	50.552864999999997	0103000020E610000001000000050000007A53910A63475A40300DC347C44649407A53910A63475A40825660C8EA484940A88B14CAC2485A40825660C8EA484940A88B14CAC2485A40300DC347C44649407A53910A63475A40300DC347C4464940
60980	Нарын	5	44	1860	104.545097	104.57856	50.545332999999999	50.522722999999999	0103000020E61000000100000005000000740987DEE2225A40FAEE5696E8424940740987DEE2225A40FC36C478CD45494085B1852007255A40FC36C478CD45494085B1852007255A40FAEE5696E8424940740987DEE2225A40FAEE5696E8424940
60972	Инзагатуй	5	44	1860	105.73570599999999	105.758578	50.837891999999997	50.820909999999998	0103000020E61000000100000005000000245E9ECE156F5A40CC7A319413694940245E9ECE156F5A403ECA880B406B4940C45DBD8A8C705A403ECA880B406B4940C45DBD8A8C705A40CC7A319413694940245E9ECE156F5A40CC7A319413694940
30549	Енхор	5	44	1860	105.814049	105.847475	50.525047999999998	50.509830000000001	0103000020E61000000100000005000000DB15FA6019745A408542041C42414940DB15FA6019745A40446ADAC5344349405E4BC8073D765A40446ADAC5344349405E4BC8073D765A408542041C42414940DB15FA6019745A408542041C42414940
30076	Дэдэ-Ичетуй	5	44	1860	105.404956	105.44294499999999	50.744875999999998	50.727117999999997	0103000020E610000001000000050000006A1492CCEA595A409D2ADF33125D49406A1492CCEA595A40A3C9C518585F49404F3BFC35595C5A40A3C9C518585F49404F3BFC35595C5A409D2ADF33125D49406A1492CCEA595A409D2ADF33125D4940
60887	Дырестуй	5	44	1860	106.047332	106.08886099999999	50.658200999999998	50.646743999999998	0103000020E610000001000000050000007903CC7C07835A402E71E481C85249407903CC7C07835A40E5982CEE3F544940F3380CE6AF855A40E5982CEE3F544940F3380CE6AF855A402E71E481C85249407903CC7C07835A402E71E481C8524940
60989	Додо-Ичетуй	5	44	1860	105.452432	105.460876	50.639690000000002	50.629955000000002	0103000020E610000001000000050000007DEA58A5F45C5A40D1798D5DA25049407DEA58A5F45C5A4004CAA65CE1514940B9E00CFE7E5D5A4004CAA65CE1514940B9E00CFE7E5D5A40D1798D5DA25049407DEA58A5F45C5A40D1798D5DA2504940
30413	Джида	5	44	1860	106.165514	106.198914	50.693899000000002	50.668557999999997	0103000020E61000000100000005000000EE4108C8978A5A4055BDFC4E93554940EE4108C8978A5A4012DDB3AED1584940DC2DC901BB8C5A4012DDB3AED1584940DC2DC901BB8C5A4055BDFC4E93554940EE4108C8978A5A4055BDFC4E93554940
60897	Гэгэтуй	5	44	1860	105.21426099999999	105.232928	50.654597000000003	50.631239999999998	0103000020E61000000100000005000000BAF3C473B64D5A40A9F6E978CC504940BAF3C473B64D5A40A587A1D5C9534940A794D74AE84E5A40A587A1D5C9534940A794D74AE84E5A40A9F6E978CC504940BAF3C473B64D5A40A9F6E978CC504940
60926	Верхний Торей	5	44	1860	104.810918	104.819317	50.666713999999999	50.646253000000002	0103000020E61000000100000005000000376F9C14E6335A4090F8156BB8524940376F9C14E6335A4086E464E256554940A30392B06F345A4086E464E256554940A30392B06F345A4090F8156BB8524940376F9C14E6335A4090F8156BB8524940
29607	Верхний Бургалтай	5	44	1860	105.044094	105.07344999999999	50.619577999999997	50.606310999999998	0103000020E61000000100000005000000CAFCA36FD2425A403F1A4E999B4D4940CAFCA36FD2425A4019A9F7544E4F494009F9A067B3445A4019A9F7544E4F494009F9A067B3445A403F1A4E999B4D4940CAFCA36FD2425A403F1A4E999B4D4940
29746	Булык	5	44	1860	105.258162	105.27342400000001	50.602052	50.589638999999998	0103000020E610000001000000050000007AC4E8B985505A401BB96E4A794B49407AC4E8B985505A40E63E390A104D4940427C60C77F515A40E63E390A104D4940427C60C77F515A401BB96E4A794B49407AC4E8B985505A401BB96E4A794B4940
30570	Боций	5	44	1860	105.641204	105.66279900000001	50.482061999999999	50.463448	0103000020E610000001000000050000001F84807C09695A40C4B29943523B49401F84807C09695A407A522635B43D494094347F4C6B6A5A407A522635B43D494094347F4C6B6A5A40C4B29943523B49401F84807C09695A40C4B29943523B4940
60993	Боргой	5	44	1860	105.82270800000001	105.844088	50.754717999999997	50.738480000000003	0103000020E61000000100000005000000168A743FA7745A4003603C83865E4940168A743FA7745A40ECD973999A6049408CBCAC8905765A40ECD973999A6049408CBCAC8905765A4003603C83865E4940168A743FA7745A4003603C83865E4940
30176	Белоозерск	5	44	1860	105.68628099999999	105.722313	50.654733999999998	50.642665999999998	0103000020E610000001000000050000006FB72407EC6B5A40252026E1425249406FB72407EC6B5A4025CADE52CE534940711E4E603A6E5A4025CADE52CE534940711E4E603A6E5A40252026E1425249406FB72407EC6B5A40252026E142524940
29134	Армак	5	44	1860	104.58951	104.598547	50.612490000000001	50.598399000000001	0103000020E610000001000000050000008FAA2688BA255A40C47AA356984C49408FAA2688BA255A4043908312664E49409C8713984E265A4043908312664E49409C8713984E265A40C47AA356984C49408FAA2688BA255A40C47AA356984C4940
60994	Алцак	5	44	1860	104.600146	104.628012	50.683135999999998	50.658537000000003	0103000020E61000000100000005000000D0B4C4CA68265A405D1ABFF04A544940D0B4C4CA68265A40315C1D0071574940B75F3E5931285A40315C1D0071574940B75F3E5931285A405D1ABFF04A544940D0B4C4CA68265A405D1ABFF04A544940
60888	Шибертуй	5	44	1820	107.856611	107.88708200000001	50.807422000000003	50.785485000000001	0103000020E610000001000000050000003599F1B6D2F65A40D13FC1C58A6449403599F1B6D2F65A401409A69A59674940B3B794F3C5F85A401409A69A59674940B3B794F3C5F85A40D13FC1C58A6449403599F1B6D2F65A40D13FC1C58A644940
60903	Шанага	5	44	1820	108.14222100000001	108.15578600000001	50.839326	50.822071000000001	0103000020E610000001000000050000007CF31B261A095B40B9FE5D9F396949407CF31B261A095B405C57CC086F6B49402ECBD765F8095B405C57CC086F6B49402ECBD765F8095B40B9FE5D9F396949407CF31B261A095B40B9FE5D9F39694940
61019	Хаян	5	44	1820	107.29526300000001	107.304497	50.622292000000002	50.610770000000002	0103000020E61000000100000005000000022EC896E5D25A4060B01BB62D4E4940022EC896E5D25A40FE47A643A74F4940BA2EFCE07CD35A40FE47A643A74F4940BA2EFCE07CD35A4060B01BB62D4E4940022EC896E5D25A4060B01BB62D4E4940
28819	Узкий Луг	5	44	1820	108.007411	108.028881	50.714281999999997	50.695667999999998	0103000020E610000001000000050000005DA8FC6B79005B40D66F26A60B5949405DA8FC6B79005B408C0FB3976D5B4940739EB12FD9015B408C0FB3976D5B4940739EB12FD9015B40D66F26A60B5949405DA8FC6B79005B40D66F26A60B594940
28174	Топка	5	44	1820	107.061817	107.10849399999999	50.482664	50.454099999999997	0103000020E610000001000000050000008F554ACFF4C35A408A8EE4F21F3A49408F554ACFF4C35A40707A17EFC73D4940FB73D190F1C65A40707A17EFC73D4940FB73D190F1C65A408A8EE4F21F3A49408F554ACFF4C35A408A8EE4F21F3A4940
27842	Сухой Ручей	5	44	1820	107.49802099999999	107.50595300000001	50.558129999999998	50.538881000000003	0103000020E6100000010000000500000028EE7893DFDF5A40C8B7770DFA44494028EE7893DFDF5A404F75C8CD704749400A14B18861E05A404F75C8CD704749400A14B18861E05A40C8B7770DFA44494028EE7893DFDF5A40C8B7770DFA444940
28073	Старые Ключи	5	44	1820	107.070154	107.091767	50.567599999999999	50.554473000000002	0103000020E61000000100000005000000C0EB33677DC45A40ECC1A4F8F8464940C0EB33677DC45A40D49AE61DA748494088F6B182DFC55A40D49AE61DA748494088F6B182DFC55A40ECC1A4F8F8464940C0EB33677DC45A40ECC1A4F8F8464940
61030	Средний Харлун	5	44	1820	106.91479	106.922839	50.644688000000002	50.630240999999998	0103000020E610000001000000050000004D2D5BEB8BBA5A4096CCB1BCAB5049404D2D5BEB8BBA5A40D40FEA22855249404B1E4FCB0FBB5A40D40FEA22855249404B1E4FCB0FBB5A4096CCB1BCAB5049404D2D5BEB8BBA5A4096CCB1BCAB504940
47204	Слобода	5	44	1820	107.90291000000001	107.91202800000001	50.634611	50.600434	0103000020E61000000100000005000000CF4E0647C9F95A4007B47405DB4C4940CF4E0647C9F95A404757E9EE3A5149405342B0AA5EFA5A404757E9EE3A5149405342B0AA5EFA5A4007B47405DB4C4940CF4E0647C9F95A4007B47405DB4C4940
27584	Сахарный Завод	5	44	1820	107.509394	107.530495	50.639564	50.620891999999998	0103000020E61000000100000005000000D5B14AE999E05A408C2C9963794F4940D5B14AE999E05A4077D9AF3BDD51494042EC4CA1F3E15A4077D9AF3BDD51494042EC4CA1F3E15A408C2C9963794F4940D5B14AE999E05A408C2C9963794F4940
33056	Потанино	5	44	1820	108.136292	108.160736	50.820261000000002	50.799765000000001	0103000020E6100000010000000500000036AD1402B9085B4023BE13B35E66494036AD1402B9085B409697FC4FFE6849408DD2A57F490A5B409697FC4FFE6849408DD2A57F490A5B4023BE13B35E66494036AD1402B9085B4023BE13B35E664940
61004	Поселье	5	44	1820	107.888321	107.903206	50.620418000000001	50.607031999999997	0103000020E6100000010000000500000067D65240DAF85A400FD07D39B34D494067D65240DAF85A40C4EC65DB694F494043E38920CEF95A40C4EC65DB694F494043E38920CEF95A400FD07D39B34D494067D65240DAF85A400FD07D39B34D4940
45991	Покровка	5	44	1820	107.433549	107.471386	50.722076999999999	50.701115999999999	0103000020E61000000100000005000000AA0D4E44BFDB5A40E659492BBE594940AA0D4E44BFDB5A40CE18E6046D5C4940B4722F302BDE5A40CE18E6046D5C4940B4722F302BDE5A40E659492BBE594940AA0D4E44BFDB5A40E659492BBE594940
28374	Петропавловка	5	44	1820	107.512134	107.533406	50.725988999999998	50.684409000000002	0103000020E61000000100000005000000DC4AAFCDC6E05A40460BD0B69A574940DC4AAFCDC6E05A40BC202235ED5C49405F5FEB5223E25A40BC202235ED5C49405F5FEB5223E25A40460BD0B69A574940DC4AAFCDC6E05A40460BD0B69A574940
28051	Окино-Ключи	5	44	1820	107.09059000000001	107.11536599999999	50.615177000000003	50.583295999999997	0103000020E610000001000000050000000FD6FF39CCC55A409DF17D71A94A49400FD6FF39CCC55A402E20B41EBE4E49408044132862C75A402E20B41EBE4E49408044132862C75A409DF17D71A94A49400FD6FF39CCC55A409DF17D71A94A4940
28483	Новосретенка	5	44	1820	107.667345	107.69848	50.738669000000002	50.712702	0103000020E610000001000000050000008B89CDC7B5EA5A409BE5B2D1395B49408B89CDC7B5EA5A40D6C8AEB48C5E49403F3A75E5B3EC5A40D6C8AEB48C5E49403F3A75E5B3EC5A409BE5B2D1395B49408B89CDC7B5EA5A409BE5B2D1395B4940
28363	Нижний Мангиртуй	5	44	1820	107.153248	107.17434900000001	50.687998999999998	50.664532999999999	0103000020E610000001000000050000005B0BB3D0CEC95A406F0ED76A0F5549405B0BB3D0CEC95A402157EA5910584940C845B58828CB5A402157EA5910584940C845B58828CB5A406F0ED76A0F5549405B0BB3D0CEC95A406F0ED76A0F554940
28539	Мотня	5	44	1820	107.702568	107.728053	50.690612000000002	50.667935999999997	0103000020E61000000100000005000000D5CDC5DFF6EC5A4018E945ED7E554940D5CDC5DFF6EC5A40D21C59F9655849404D309C6B98EE5A40D21C59F9655849404D309C6B98EE5A4018E945ED7E554940D5CDC5DFF6EC5A4018E945ED7E554940
28625	Малый Куналей	5	44	1820	107.78992	107.861282	50.622703999999999	50.587871999999997	0103000020E61000000100000005000000349D9D0C8EF25A40F71DC3633F4B4940349D9D0C8EF25A40508BC1C3B44F49408BA8893E1FF75A40508BC1C3B44F49408BA8893E1FF75A40F71DC3633F4B4940349D9D0C8EF25A40F71DC3633F4B4940
32946	Елань	5	44	1820	107.339011	107.36127999999999	50.556282000000003	50.519350000000003	0103000020E61000000100000005000000FE7E315BB2D55A40BC96900F7A424940FE7E315BB2D55A403FADA23F34474940BA2C26361FD75A403FADA23F34474940BA2C26361FD75A40BC96900F7A424940FE7E315BB2D55A40BC96900F7A424940
61028	Дунда-Киреть	5	44	1820	107.448362	107.46489200000001	50.594625000000001	50.577891000000001	0103000020E610000001000000050000003AB187F6B1DC5A408DD31055F84949403AB187F6B1DC5A40273108AC1C4C4940030B60CAC0DD5A40273108AC1C4C4940030B60CAC0DD5A408DD31055F84949403AB187F6B1DC5A408DD31055F8494940
61016	Дабатуй	5	44	1820	107.941654	107.952838	50.807609999999997	50.797128999999998	0103000020E610000001000000050000007289230F44FC5A40BAD8B452086649407289230F44FC5A4016F6B4C35F674940B5183C4CFBFC5A4016F6B4C35F674940B5183C4CFBFC5A40BAD8B452086649407289230F44FC5A40BAD8B45208664940
61033	Гутай	5	44	1820	107.74126699999999	107.758129	50.741774999999997	50.735408	0103000020E61000000100000005000000A8A624EB70EF5A40BF9B6ED9215E4940A8A624EB70EF5A40C5FEB27BF25E49408C497F2F85F05A40C5FEB27BF25E49408C497F2F85F05A40BF9B6ED9215E4940A8A624EB70EF5A40BF9B6ED9215E4940
28296	Верхний Мангиртуй	5	44	1820	107.23698	107.262744	50.678027999999998	50.667130999999998	0103000020E61000000100000005000000977329AE2ACF5A40EA92718C64554940977329AE2ACF5A40DAE21A9FC956494018CE35CCD0D05A40DAE21A9FC956494018CE35CCD0D05A40EA92718C64554940977329AE2ACF5A40EA92718C64554940
28759	Буй	5	44	1820	107.944529	107.985196	50.650050999999998	50.631863000000003	0103000020E61000000100000005000000E947C32973FC5A40B74604E3E0504940E947C32973FC5A40B5DD04DF345349409A0986730DFF5A40B5DD04DF345349409A0986730DFF5A40B74604E3E0504940E947C32973FC5A40B74604E3E0504940
27404	Бичура	5	44	1820	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
60971	Билютай	5	44	1820	107.08617099999999	107.10965299999999	50.786059999999999	50.765664000000001	0103000020E6100000010000000500000045B75ED383C55A40BEDC27470162494045B75ED383C55A40CD58349D9D644940213A048E04C75A40CD58349D9D644940213A048E04C75A40BEDC27470162494045B75ED383C55A40BEDC274701624940
27927	Ара-Киреть	5	44	1820	107.427324	107.43663100000001	50.598547000000003	50.584291	0103000020E61000000100000005000000F032C34659DB5A406F2C280CCA4A4940F032C34659DB5A40390F27309D4C4940DE5A26C3F1DB5A40390F27309D4C4940DE5A26C3F1DB5A406F2C280CCA4A4940F032C34659DB5A406F2C280CCA4A4940
60967	Ципикан	5	44	1750	113.34584700000001	113.359331	54.926425000000002	54.914985000000001	0103000020E61000000100000005000000DD9A745B22565C4050AA7D3A1E754B40DD9A745B22565C4031992A1895764B40185C7347FF565C4031992A1895764B40185C7347FF565C4050AA7D3A1E754B40DD9A745B22565C4050AA7D3A1E754B40
60996	Усть-Джилинда	5	44	1750	111.92886300000001	111.958669	53.669161000000003	53.656019000000001	0103000020E61000000100000005000000BADDCB7D72FB5B40FE463B6EF8D34A40BADDCB7D72FB5B401C615111A7D54A4019AC38D55AFD5B401C615111A7D54A4019AC38D55AFD5B40FE463B6EF8D34A40BADDCB7D72FB5B40FE463B6EF8D34A40
60981	Уакит	5	44	1750	113.626167	113.64354	55.491976999999999	55.469382000000003	0103000020E6100000010000000500000067B5C01E13685C4061AA99B514BC4B4067B5C01E13685C402DB1321AF9BE4B40BE6A65C22F695C402DB1321AF9BE4B40BE6A65C22F695C4061AA99B514BC4B4067B5C01E13685C4061AA99B514BC4B40
46427	Северный	5	44	1750	113.260426	113.286666	54.357883000000001	54.345393999999999	0103000020E61000000100000005000000CC41D0D1AA505C40081EDFDE352C4B40CC41D0D1AA505C40AE65321CCF2D4B4002B859BC58525C40AE65321CCF2D4B4002B859BC58525C40081EDFDE352C4B40CC41D0D1AA505C40081EDFDE352C4B40
61051	Россошино	5	44	1750	114.287623	114.304035	54.296903	54.283602000000002	0103000020E61000000100000005000000F4A44C6A68925C40448A01124D244B40F4A44C6A68925C40CA8AE1EA00264B40B875374F75935C40CA8AE1EA00264B40B875374F75935C40448A01124D244B40F4A44C6A68925C40448A01124D244B40
61013	Монгой	5	44	1750	113.813366	113.829464	53.973219	53.95825	0103000020E610000001000000050000006A6B44300E745C402DB29DEFA7FA4A406A6B44300E745C40446CB07092FC4A40664D2CF015755C40446CB07092FC4A40664D2CF015755C402DB29DEFA7FA4A406A6B44300E745C402DB29DEFA7FA4A40
26962	Маловский	5	44	1750	113.53301999999999	113.56172100000001	54.403136000000003	54.389225000000003	0103000020E610000001000000050000004A07EBFF1C625C408FE4F21FD2314B404A07EBFF1C625C408EEBDFF599334B407E1EA33CF3635C408EEBDFF599334B407E1EA33CF3635C408FE4F21FD2314B404A07EBFF1C625C408FE4F21FD2314B40
60916	Варваринский	5	44	1750	112.349678	112.374526	54.323293	54.312984	0103000020E610000001000000050000005D88D51F61165C40EC1516DC0F284B405D88D51F61165C404B033FAA61294B401C60E63BF8175C404B033FAA61294B401C60E63BF8175C40EC1516DC0F284B405D88D51F61165C40EC1516DC0F284B40
24438	Багдарин	5	44	1750	113.56739899999999	113.60009700000001	54.460341999999997	54.424733000000003	0103000020E610000001000000050000001E32E54350645C401844A4A65D364B401E32E54350645C40D47C957CEC3A4B40605B3FFD67665C40D47C957CEC3A4B40605B3FFD67665C401844A4A65D364B401E32E54350645C401844A4A65D364B40
61034	у.Хошун-Узур	5	44	1768	108.420699	111.218897	54.154797000000002	53.030394999999999	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
60924	Ярикто	5	44	1768	108.420699	111.218897	54.154797000000002	53.030394999999999	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
26386	Юбилейный	5	44	1768	110.22362699999999	110.245402	53.730933	53.722718	0103000020E610000001000000050000002AE09EE74F8E5B40821DFF0582DC4A402AE09EE74F8E5B40994869368FDD4A40DF1797AAB48F5B40994869368FDD4A40DF1797AAB48F5B40821DFF0582DC4A402AE09EE74F8E5B40821DFF0582DC4A40
60919	Шапеньково	5	44	1768	109.64221000000001	109.65337599999999	53.570813999999999	53.561492999999999	0103000020E6100000010000000500000082CAF8F719695B406AF7AB00DFC74A4082CAF8F719695B40AA0CE36E10C94A4071FF91E9D0695B40AA0CE36E10C94A4071FF91E9D0695B406AF7AB00DFC74A4082CAF8F719695B406AF7AB00DFC74A40
26041	Читкан	5	44	1768	109.76301599999999	109.788932	53.511381	53.489946000000003	0103000020E61000000100000005000000C8940F41D5705B402C67EF8CB6BE4A40C8940F41D5705B40DC65BFEE74C14A4025B1A4DC7D725B40DC65BFEE74C14A4025B1A4DC7D725B402C67EF8CB6BE4A40C8940F41D5705B402C67EF8CB6BE4A40
26832	Хилгана	5	44	1768	110.081127	110.12492	53.926228999999999	53.907429	0103000020E61000000100000005000000A5F44C2F31855B4093382BA226F44A40A5F44C2F31855B40ABCDFFAB8EF64A4072A774B0FE875B40ABCDFFAB8EF64A4072A774B0FE875B4093382BA226F44A40A5F44C2F31855B4093382BA226F44A40
26642	Хара-Усун	5	44	1768	110.11629600000001	110.12761500000001	53.805754999999998	53.801650000000002	0103000020E61000000100000005000000F629C76471875B40516B9A779CE64A40F629C76471875B4053CBD6FA22E74A40A9DE1AD82A885B4053CBD6FA22E74A40A9DE1AD82A885B40516B9A779CE64A40F629C76471875B40516B9A779CE64A40
25547	Усть-Баргузин	5	44	1768	109.00227700000001	109.054362	53.423070000000003	53.394181000000003	0103000020E610000001000000050000001D226E4E25405B4030DAE38574B24A401D226E4E25405B4099F5622827B64A404A09C1AA7A435B4099F5622827B64A404A09C1AA7A435B4030DAE38574B24A401D226E4E25405B4030DAE38574B24A40
26106	Уро	5	44	1768	109.81679800000001	109.865055	53.560347999999998	53.527811	0103000020E610000001000000050000000C5C1E6B46745B400ABC934F8FC34A400C5C1E6B46745B408330B77BB9C74A40718FA50F5D775B408330B77BB9C74A40718FA50F5D775B400ABC934F8FC34A400C5C1E6B46745B400ABC934F8FC34A40
26520	Уржил	5	44	1768	110.333904	110.354511	53.836998000000001	53.818418999999999	0103000020E610000001000000050000003B00E2AE5E955B4067B62BF4C1E84A403B00E2AE5E955B40A1681EC022EB4A40A0C4E74EB0965B40A1681EC022EB4A40A0C4E74EB0965B4067B62BF4C1E84A403B00E2AE5E955B4067B62BF4C1E84A40
26675	Улюн	5	44	1768	109.890918	109.928386	53.836376000000001	53.818418999999999	0103000020E61000000100000005000000BC5AEECC04795B4067B62BF4C1E84A40BC5AEECC04795B406494675E0EEB4A401D041DAD6A7B5B406494675E0EEB4A401D041DAD6A7B5B4067B62BF4C1E84A40BC5AEECC04795B4067B62BF4C1E84A40
26746	Улюкчикан	5	44	1768	109.937468	109.963466	53.874583000000001	53.867485000000002	0103000020E61000000100000005000000FA42C879FF7B5B40A2629CBF09EF4A40FA42C879FF7B5B409C51F355F2EF4A40B5334C6DA97D5B409C51F355F2EF4A40B5334C6DA97D5B40A2629CBF09EF4A40FA42C879FF7B5B40A2629CBF09EF4A40
26235	Суво	5	44	1768	110.000979	110.019431	53.663975000000001	53.650554999999997	0103000020E61000000100000005000000E63E390A10805B40E89FE06245D34A40E63E390A10805B40492EFF21FDD44A40D461855B3E815B40492EFF21FDD44A40D461855B3E815B40E89FE06245D34A40E63E390A10805B40E89FE06245D34A40
26588	Соёл	5	44	1768	110.19102700000001	110.20172599999999	53.859175	53.850852000000003	0103000020E61000000100000005000000CB694FC9398C5B403CDEE4B7E8EC4A40CB694FC9398C5B4039454772F9ED4A402F302B14E98C5B4039454772F9ED4A402F302B14E98C5B403CDEE4B7E8EC4A40CB694FC9398C5B403CDEE4B7E8EC4A40
52412	Нестериха	5	44	1768	109.697879	109.72221399999999	53.651077999999998	53.640808	0103000020E610000001000000050000002C64AE0CAA6C5B40F1811DFF05D24A402C64AE0CAA6C5B4092921E8656D34A40A7AD11C1386E5B4092921E8656D34A40A7AD11C1386E5B40F1811DFF05D24A402C64AE0CAA6C5B40F1811DFF05D24A40
26111	Малое Уро	5	44	1768	109.832159	109.854859	53.532912000000003	53.523085000000002	0103000020E610000001000000050000009D84D21742755B409B030473F4C24A409D84D21742755B40AFD2DD7536C44A403EEC8502B6765B40AFD2DD7536C44A403EEC8502B6765B409B030473F4C24A409D84D21742755B409B030473F4C24A40
25723	Максимиха	5	44	1768	108.710235	108.753309	53.272074000000003	53.261701000000002	0103000020E610000001000000050000005F5E807D742D5B404E2A1A6B7FA14A405F5E807D742D5B40C40B2252D3A24A4014B2F33636305B40C40B2252D3A24A4014B2F33636305B404E2A1A6B7FA14A405F5E807D742D5B404E2A1A6B7FA14A40
25923	Макаринино (Башарово)	5	44	1768	109.066839	109.126721	53.445718999999997	53.438366000000002	0103000020E610000001000000050000003BC6151747445B40D4D688601CB84A403BC6151747445B40581AF8510DB94A40DAAD65321C485B40581AF8510DB94A40DAAD65321C485B40D4D688601CB84A403BC6151747445B40D4D688601CB84A40
25854	Курбулик (Покойники)	5	44	1768	109.033395	109.04705800000001	53.708826000000002	53.702606000000003	0103000020E610000001000000050000006536C82423425B4098FC4FFEEED94A406536C82423425B40FA4674CFBADA4A40F9C08EFF02435B40FA4674CFBADA4A40F9C08EFF02435B4098FC4FFEEED94A406536C82423425B4098FC4FFEEED94A40
26448	Ина	5	44	1768	110.21096	110.242761	53.748843000000001	53.733420000000002	0103000020E61000000100000005000000E8305F5E808D5B40BD1DE1B4E0DD4A40E8305F5E808D5B40556B6116DADF4A40A2EF6E65898F5B40556B6116DADF4A40A2EF6E65898F5B40BD1DE1B4E0DD4A40E8305F5E808D5B40BD1DE1B4E0DD4A40
25989	Зорино	5	44	1768	109.35554	109.374925	53.511617000000001	53.50338	0103000020E61000000100000005000000DF1AD82AC1565B40F1BA7EC16EC04A40DF1AD82AC1565B40F08975AA7CC14A40FB5C6DC5FE575B40F08975AA7CC14A40FB5C6DC5FE575B40F1BA7EC16EC04A40DF1AD82AC1565B40F1BA7EC16EC04A40
26211	Душелан	5	44	1768	109.878674	109.895212	53.604129	53.592699000000003	0103000020E610000001000000050000001D76DF313C785B409BAF928FDDCB4A401D76DF313C785B4058C85C1954CD4A4027BF45274B795B4058C85C1954CD4A4027BF45274B795B409BAF928FDDCB4A401D76DF313C785B409BAF928FDDCB4A40
25556	Гусиха	5	44	1768	109.25403	109.27096299999999	53.439321	53.424926999999997	0103000020E61000000100000005000000FC8C0B0742505B40FC17080264B64A40FC8C0B0742505B4017B9A7AB3BB84A4044DB317557515B4017B9A7AB3BB84A4044DB317557515B40FC17080264B64A40FC8C0B0742505B40FC17080264B64A40
26849	Борогол	5	44	1768	110.160664	110.186904	53.905619999999999	53.897207000000002	0103000020E610000001000000050000004069A851488A5B40035FD1ADD7F24A404069A851488A5B40404D2D5BEBF34A4076DF313CF68B5B40404D2D5BEBF34A4076DF313CF68B5B40035FD1ADD7F24A404069A851488A5B40035FD1ADD7F24A40
26294	Бодон	5	44	1768	110.083732	110.10202200000001	53.710504999999998	53.702019999999997	0103000020E610000001000000050000003C6876DD5B855B40A79196CADBD94A403C6876DD5B855B407E52EDD3F1DA4A403E5E488787865B407E52EDD3F1DA4A403E5E488787865B40A79196CADBD94A403C6876DD5B855B40A79196CADBD94A40
26489	Баянгол (Чебукчен)	5	44	1768	110.25357700000001	110.30500499999999	53.797224999999997	53.763004000000002	0103000020E610000001000000050000002481069B3A905B40CD5B751DAAE14A402481069B3A905B40DC4603780BE64A407407B13385935B40DC4603780BE64A407407B13385935B40CD5B751DAAE14A402481069B3A905B40CD5B751DAAE14A40
25173	Баргузин	5	44	1768	109.58647000000001	109.66059	53.630231999999999	53.600351000000003	0103000020E61000000100000005000000738577B988655B407A8F334DD8CC4A40738577B988655B4043723271ABD04A402384471B476A5B4043723271ABD04A402384471B476A5B407A8F334DD8CC4A40738577B988655B407A8F334DD8CC4A40
25975	Адамово	5	44	1768	109.291741	109.31349899999999	53.485895999999997	53.476390000000002	0103000020E61000000100000005000000C07971E2AB525B401B12F758FABC4A40C07971E2AB525B40ECA012D731BE4A4009151C5E10545B40ECA012D731BE4A4009151C5E10545B401B12F758FABC4A40C07971E2AB525B401B12F758FABC4A40
12949	Горно-Алтайск	5	43	\N	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
32526	Шыргайту	5	43	687	85.286879999999996	85.303076000000004	51.208658	51.201542000000003	0103000020E610000001000000050000001878EE3D5C5255409E62D520CC9949401878EE3D5C5255403E062B4EB59A4940F60CE198655355403E062B4EB59A4940F60CE198655355409E62D520CC9949401878EE3D5C5255409E62D520CC994940
5733	Шебалино	5	43	687	85.654443000000001	85.695639999999997	51.320101000000001	51.270493999999999	0103000020E610000001000000050000002786E464E2695540D2E1218C9FA249402786E464E26955405D35CF11F9A849408672A25D856C55405D35CF11F9A849408672A25D856C5540D2E1218C9FA249402786E464E2695540D2E1218C9FA24940
5381	Черга	5	43	687	85.548091999999997	85.586189000000005	51.582597999999997	51.55077	0103000020E61000000100000005000000C0CC77F01363554018CFA0A17FC64940C0CC77F013635540855B3E9292CA49409911DE1E84655540855B3E9292CA49409911DE1E8465554018CFA0A17FC64940C0CC77F01363554018CFA0A17FC64940
60267	Улусчерга	5	43	687	85.436260000000004	85.467000999999996	51.526815999999997	51.507334	0103000020E61000000100000005000000642310AFEB5B55400E130D52F0C04940642310AFEB5B55403881E9B46EC34940C18C2958E35D55403881E9B46EC34940C18C2958E35D55400E130D52F0C04940642310AFEB5B55400E130D52F0C04940
5941	Топучая	5	43	687	85.581051000000002	85.588892999999999	51.130864000000003	51.120440000000002	0103000020E61000000100000005000000B89388F02F655540AC90F2936A8F4940B89388F02F655540A41CCC26C0904940F9F5436CB0655540A41CCC26C0904940F9F5436CB0655540AC90F2936A8F4940B89388F02F655540AC90F2936A8F4940
5785	Мыюта	5	43	687	85.612842000000001	85.640536999999995	51.423152000000002	51.411143000000003	0103000020E6100000010000000500000060E7A6CD386755405B7D7555A0B4494060E7A6CD38675540569E40D829B6494030B8E68EFE685540569E40D829B6494030B8E68EFE6855405B7D7555A0B4494060E7A6CD386755405B7D7555A0B44940
5242	Мухор-Черга	5	43	687	85.341847000000001	85.35472	51.415754999999997	51.400888999999999	0103000020E61000000100000005000000164F3DD2E0555540BF29AC5450B34940164F3DD2E05555400113B87537B549402DCF83BBB35655400113B87537B549402DCF83BBB3565540BF29AC5450B34940164F3DD2E0555540BF29AC5450B34940
5195	Мариинск	5	43	687	84.954960999999997	84.982926000000006	51.424421000000002	51.397320999999998	0103000020E6100000010000000500000026FDBD141E3D5540CB811E6ADBB2494026FDBD141E3D5540295E656D53B64940D7187442E83E5540295E656D53B64940D7187442E83E5540CB811E6ADBB2494026FDBD141E3D5540CB811E6ADBB24940
6119	Малая Черга	5	43	687	85.542962000000003	85.563309000000004	51.352393999999997	51.338391000000001	0103000020E61000000100000005000000213EB0E3BF6255406021736550AB4940213EB0E3BF6255403FA7203F1BAD4940B82231410D6455403FA7203F1BAD4940B82231410D6455406021736550AB4940213EB0E3BF6255406021736550AB4940
5988	Кумалыр	5	43	687	85.614791999999994	85.625193999999993	51.208393000000001	51.200718000000002	0103000020E61000000100000005000000EA758BC058675540F9DB9E20B1994940EA758BC05867554090DB2F9FAC9A4940F2E9B12D0368554090DB2F9FAC9A4940F2E9B12D03685540F9DB9E20B1994940EA758BC058675540F9DB9E20B1994940
4787	Каспа	5	43	687	85.986379999999997	86.021287999999998	51.119314000000003	51.111297	0103000020E610000001000000050000006C5B94D9207F55404B92E7FA3E8E49406C5B94D9207F55403CFA5FAE458F494006F357C85C8155403CFA5FAE458F494006F357C85C8155404B92E7FA3E8E49406C5B94D9207F55404B92E7FA3E8E4940
5388	Камлак	5	43	687	85.651595999999998	85.696259999999995	51.633150999999998	51.618614000000001	0103000020E61000000100000005000000158DB5BFB3695540836C59BE2ECF4940158DB5BFB369554000378B170BD14940D4601A868F6C554000378B170BD14940D4601A868F6C5540836C59BE2ECF4940158DB5BFB3695540836C59BE2ECF4940
5624	Камай	5	43	687	85.749063000000007	85.755709999999993	51.511505	51.503847	0103000020E6100000010000000500000032E9EFA5F06F55400798F90E7EC0494032E9EFA5F06F5540C85EEFFE78C14940A6D0798D5D705540C85EEFFE78C14940A6D0798D5D7055400798F90E7EC0494032E9EFA5F06F55400798F90E7EC04940
5139	Ильинка	5	43	687	85.083779000000007	85.121894999999995	51.456735999999999	51.429986	0103000020E61000000100000005000000DD4598A25C45554072DEFFC709B74940DD4598A25C455540F373435376BA4940F0A2AF20CD475540F373435376BA4940F0A2AF20CD47554072DEFFC709B74940DD4598A25C45554072DEFFC709B74940
5844	Дьектиек	5	43	687	85.597444999999993	85.618268	51.277340000000002	51.264722999999996	0103000020E61000000100000005000000280AF4893C665540DFBF7971E2A14940280AF4893C665540B3EF8AE07FA34940740AF2B391675540B3EF8AE07FA34940740AF2B391675540DFBF7971E2A14940280AF4893C665540DFBF7971E2A14940
6133	Верх-Черга	5	43	687	85.448783000000006	85.464817999999994	51.376294000000001	51.367820999999999	0103000020E610000001000000050000000D0055DCB85C554019E42EC214AF49400D0055DCB85C55402CD7DB662AB04940E525FF93BF5D55402CD7DB662AB04940E525FF93BF5D554019E42EC214AF49400D0055DCB85C554019E42EC214AF4940
60265	Верх-Апшуяхта	5	43	687	85.887681999999998	85.908630000000002	51.235886999999998	51.230455999999997	0103000020E61000000100000005000000DDCF29C8CF7855405F950B957F9D4940DDCF29C8CF7855409946938B319E4940878A71FE267A55409946938B319E4940878A71FE267A55405F950B957F9D4940DDCF29C8CF7855405F950B957F9D4940
4893	Беш-Озек	5	43	687	85.240966999999998	85.253722999999994	51.125323999999999	51.115361999999998	0103000020E61000000100000005000000931ADA006C4F5540BF99982EC48E4940931ADA006C4F5540B3B3E89D0A9049408DCF64FF3C505540B3B3E89D0A9049408DCF64FF3C505540BF99982EC48E4940931ADA006C4F5540BF99982EC48E4940
5076	Барагаш	5	43	687	85.185873000000001	85.221365000000006	51.281908999999999	51.270820999999998	0103000020E61000000100000005000000670DDE57E54B5540F6083543AAA24940670DDE57E54B55405AB9179815A44940A9DE1AD82A4E55405AB9179815A44940A9DE1AD82A4E5540F6083543AAA24940670DDE57E54B5540F6083543AAA24940
5542	Актел	5	43	687	85.653634999999994	85.677242000000007	51.525320000000001	51.513461	0103000020E610000001000000050000005721E527D5695540BF620D17B9C149405721E527D5695540A5F78DAF3DC34940925ED4EE576B5540A5F78DAF3DC34940925ED4EE576B5540BF620D17B9C149405721E527D5695540BF620D17B9C14940
4125	Ынырга	5	43	280	86.771534000000003	86.802014	51.831530999999998	51.816267000000003	0103000020E61000000100000005000000227024D060B15540EBE6E26F7BE84940227024D060B155401A4E999B6FEA4940C93B873254B355401A4E999B6FEA4940C93B873254B35540EBE6E26F7BE84940227024D060B15540EBE6E26F7BE84940
3898	Чоя	5	43	280	86.531468000000004	86.562765999999996	52.029390999999997	51.993170999999997	0103000020E61000000100000005000000B7B75B9203A25540F52A323A20FF4940B7B75B9203A25540FBE59315C3034A403F53AF5B04A45540FBE59315C3034A403F53AF5B04A45540F52A323A20FF4940B7B75B9203A25540F52A323A20FF4940
4286	Ускуч (Верх-Пьянково)	5	43	280	86.897011000000006	86.918650999999997	52.041463	52.030726999999999	0103000020E61000000100000005000000BF49D3A068B95540560DC2DCEE034A40BF49D3A068B955403D7FDAA84E054A40035C902DCBBA55403D7FDAA84E054A40035C902DCBBA5540560DC2DCEE034A40BF49D3A068B95540560DC2DCEE034A40
60274	Уймень	5	43	280	86.912694999999999	86.926691000000005	51.666634999999999	51.647056999999997	0103000020E61000000100000005000000410E4A9869BA5540EDD286C3D2D24940410E4A9869BA55403AAFB14B54D54940D89FC4E74EBB55403AAFB14B54D54940D89FC4E74EBB5540EDD286C3D2D24940410E4A9869BA5540EDD286C3D2D24940
4509	Туньжа	5	43	280	86.451824000000002	86.475036000000003	52.011806	51.999110000000002	0103000020E6100000010000000500000011E335AFEA9C5540A48D23D6E2FF494011E335AFEA9C5540C3F2E7DB82014A400D1B65FD669E5540C3F2E7DB82014A400D1B65FD669E5540A48D23D6E2FF494011E335AFEA9C5540A48D23D6E2FF4940
1181	Советское	5	43	280	86.603872999999993	86.624245999999999	52.040300000000002	52.029778999999998	0103000020E61000000100000005000000FE7BF0DAA5A65540C58D5BCCCF034A40FE7BF0DAA5A65540B003E78C28054A402AAA7EA5F3A75540B003E78C28054A402AAA7EA5F3A75540C58D5BCCCF034A40FE7BF0DAA5A65540C58D5BCCCF034A40
4543	Сейка	5	43	280	86.713530000000006	86.751105999999993	51.902065	51.862803999999997	0103000020E61000000100000005000000C1ADBB79AAAD5540D26D895C70EE4940C1ADBB79AAAD5540E1EEACDD76F349401475E61E12B05540E1EEACDD76F349401475E61E12B05540D26D895C70EE4940C1ADBB79AAAD5540D26D895C70EE4940
4364	Паспаул	5	43	280	86.315665999999993	86.363528000000002	51.950127999999999	51.914420999999997	0103000020E61000000100000005000000629D2ADF3394554047E350BF0BF54940629D2ADF33945540C78157CB9DF949408ACBF10A44975540C78157CB9DF949408ACBF10A4497554047E350BF0BF54940629D2ADF3394554047E350BF0BF54940
3985	Киска	5	43	280	86.482618000000002	86.498661999999996	52.062840999999999	52.057237000000001	0103000020E61000000100000005000000809D9B36E39E5540828FC18A53074A40809D9B36E39E554089EC832C0B084A4082700514EA9F554089EC832C0B084A4082700514EA9F5540828FC18A53074A40809D9B36E39E5540828FC18A53074A40
4644	Каракокша	5	43	280	86.676626999999996	86.711149000000006	51.776586000000002	51.754435999999998	0103000020E61000000100000005000000CC2555DB4DAB55406876DD5B91E04940CC2555DB4DAB55400744882B67E349405265187783AD55400744882B67E349405265187783AD55406876DD5B91E04940CC2555DB4DAB55406876DD5B91E04940
3868	Гусевка	5	43	280	86.528593999999998	86.537981000000002	52.032544000000001	52.024177000000002	0103000020E6100000010000000500000028B7ED7BD4A155405F28603B18034A4028B7ED7BD4A155402CD7DB662A044A40A437DC476EA255402CD7DB662A044A40A437DC476EA255405F28603B18034A4028B7ED7BD4A155405F28603B18034A40
3478	Элекмонар	5	43	323	85.982714999999999	86.046404999999993	51.482196000000002	51.442743	0103000020E61000000100000005000000799274CDE47E554037C478CDABB84940799274CDE47E55408A213999B8BD4940BC57AD4CF88255408A213999B8BD4940BC57AD4CF882554037C478CDABB84940799274CDE47E554037C478CDABB84940
3036	Эдиган	5	43	323	86.244078999999999	86.274298999999999	51.113016000000002	51.101818999999999	0103000020E61000000100000005000000FCA886FD9E8F5540438EAD67088D4940FCA886FD9E8F55405EF6EB4E778E4940D594641D8E9155405EF6EB4E778E4940D594641D8E915540438EAD67088D4940FCA886FD9E8F5540438EAD67088D4940
1529	Чепош	5	43	323	85.819490999999999	85.843044000000006	51.598002000000001	51.579911000000003	0103000020E610000001000000050000007217618A727455409BCB0D863ACA49407217618A72745540A7785C548BCC4940B345D26EF4755540A7785C548BCC4940B345D26EF47555409BCB0D863ACA49407217618A727455409BCB0D863ACA4940
3254	Чемал	5	43	323	85.983639999999994	86.041132000000005	51.423881999999999	51.387940999999998	0103000020E6100000010000000500000065C22FF5F37E554086E3F90CA8B1494065C22FF5F37E554079AEEFC341B649406CB41CE8A182554079AEEFC341B649406CB41CE8A182554086E3F90CA8B1494065C22FF5F37E554086E3F90CA8B14940
2183	Усть-Сема	5	43	323	85.755844999999994	85.773343999999994	51.658434	51.635576999999998	0103000020E6100000010000000500000016F6B4C35F7055407E8B4E965AD1494016F6B4C35F7055408849B89047D44940B323D5777E7155408849B89047D44940B323D5777E7155407E8B4E965AD1494016F6B4C35F7055407E8B4E965AD14940
3703	Узнезя	5	43	323	85.926192999999998	85.956070999999994	51.532302000000001	51.517648000000001	0103000020E610000001000000050000002F3201BF467B55407F6B274A42C249402F3201BF467B554036CCD07822C44940DB696B44307D554036CCD07822C44940DB696B44307D55407F6B274A42C249402F3201BF467B55407F6B274A42C24940
46162	Турбаза Катунь	5	43	323	85.903142000000003	85.911254	51.549174000000001	51.542878000000002	0103000020E6100000010000000500000038691A14CD795540E4DBBB067DC5494038691A14CD79554021E868554BC6494059164CFC517A554021E868554BC6494059164CFC517A5540E4DBBB067DC5494038691A14CD795540E4DBBB067DC54940
3137	Толгоек	5	43	323	86.056438999999997	86.061452000000003	51.341227000000003	51.338290000000001	0103000020E6100000010000000500000003CE52B29C8355402C4833164DAB494003CE52B29C83554090C18A53ADAB494086915ED4EE83554090C18A53ADAB494086915ED4EE8355402C4833164DAB494003CE52B29C8355402C4833164DAB4940
10025	Ороктой	5	43	323	86.102037999999993	86.120911000000007	51.059556000000001	51.047438999999997	0103000020E61000000100000005000000C03C64CA8786554008C72C7B12864940C03C64CA87865540EA23F0879F87494082AE7D01BD875540EA23F0879F87494082AE7D01BD87554008C72C7B12864940C03C64CA8786554008C72C7B12864940
2812	Куюс	5	43	323	86.227307999999994	86.238230999999999	51.034537999999998	51.019168999999998	0103000020E61000000100000005000000A087DA368C8E55406B0C3A2174824940A087DA368C8E5540103CBEBD6B8449402D793C2D3F8F5540103CBEBD6B8449402D793C2D3F8F55406B0C3A2174824940A087DA368C8E55406B0C3A2174824940
45884	Еланда	5	43	323	86.084637000000001	86.095534000000001	51.223112	51.211502000000003	0103000020E6100000010000000500000005C24EB16A855540F1845E7F129B494005C24EB16A8555402EAC1BEF8E9C4940FD69A33A1D8655402EAC1BEF8E9C4940FD69A33A1D865540F1845E7F129B494005C24EB16A855540F1845E7F129B4940
1482	Бешпельтир	5	43	323	85.982759000000001	86.003645000000006	51.638376999999998	51.623086999999998	0103000020E6100000010000000500000061360186E57E554008C89750C1CF494061360186E57E554061C26856B6D14940D0F23CB83B80554061C26856B6D14940D0F23CB83B80554008C89750C1CF494061360186E57E554008C89750C1CF4940
3613	Аюла	5	43	323	85.971583999999993	85.978789000000006	51.442310999999997	51.427841000000001	0103000020E610000001000000050000004754A86E2E7E5540A8716F7EC3B649404754A86E2E7E55409DD497A59DB84940D02B9E7AA47E55409DD497A59DB84940D02B9E7AA47E5540A8716F7EC3B649404754A86E2E7E5540A8716F7EC3B64940
3783	Аскат	5	43	323	85.894553999999999	85.903232000000003	51.540447	51.530279	0103000020E6100000010000000500000062A06B5F40795540B760A92EE0C3494062A06B5F40795540541C075E2DC54940D82C978DCE795540541C075E2DC54940D82C978DCE795540B760A92EE0C3494062A06B5F40795540B760A92EE0C34940
3662	Анос	5	43	323	85.936639999999997	85.954705000000004	51.506925000000003	51.496110000000002	0103000020E610000001000000050000000708E6E8F17B5540FA9B508880BF49400708E6E8F17B55402D431CEBE2C04940F91400E3197D55402D431CEBE2C04940F91400E3197D5540FA9B508880BF49400708E6E8F17B5540FA9B508880BF4940
32949	Чендек	5	43	253	85.943988000000004	85.970748999999998	50.274948999999999	50.258153	0103000020E6100000010000000500000041F4A44C6A7C5540A12E52280B21494041F4A44C6A7C5540B188618731234940FBE769C0207E5540B188618731234940FBE769C0207E5540A12E52280B21494041F4A44C6A7C5540A12E52280B214940
32782	Усть-Кокса	5	43	253	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
59425	Тихонькая	5	43	253	85.792236000000003	85.806178000000003	50.206252999999997	50.198689000000002	0103000020E61000000100000005000000B0AD9FFEB3725540988922A46E194940B0AD9FFEB3725540D7D9907F661A49404D309C6B98735540D7D9907F661A49404D309C6B98735540988922A46E194940B0AD9FFEB3725540988922A46E194940
60270	Талда	5	43	253	85.014160000000004	85.027257000000006	50.510551999999997	50.497982	0103000020E61000000100000005000000543A58FFE740554093FFC9DFBD3F4940543A58FFE7405540257497C45941494093E52494BE415540257497C45941494093E52494BE41554093FFC9DFBD3F4940543A58FFE740554093FFC9DFBD3F4940
60250	Огневка	5	43	253	85.506930999999994	85.536323999999993	50.239485000000002	50.226168000000001	0103000020E610000001000000050000000795B88E716055406CB3B112F31C49400795B88E71605540F870C971A71E4940D503E62153625540F870C971A71E4940D503E621536255406CB3B112F31C49400795B88E716055406CB3B112F31C4940
60255	Катанда	5	43	253	86.168693000000005	86.189353999999994	50.179217999999999	50.147815000000001	0103000020E610000001000000050000001B84B9DDCB8A5540DB6D179AEB1249401B84B9DDCB8A5540616D8C9DF016494079573D601E8C5540616D8C9DF016494079573D601E8C5540DB6D179AEB1249401B84B9DDCB8A5540DB6D179AEB124940
59494	Кастахта	5	43	253	85.733118000000005	85.742836999999994	50.331961	50.313482	0103000020E61000000100000005000000F986C267EB6E55403DF19C2D20284940F986C267EB6E55401346B3B27D2A49408F5033A48A6F55401346B3B27D2A49408F5033A48A6F55403DF19C2D20284940F986C267EB6E55403DF19C2D20284940
60252	Карагай	5	43	253	84.610736000000003	84.630219999999994	50.400612000000002	50.391539999999999	0103000020E610000001000000050000005A9F724C16275540B58993FB1D3249405A9F724C162755404D310741473349403F524486552855404D310741473349403F52448655285540B58993FB1D3249405A9F724C16275540B58993FB1D324940
60259	Горбуново	5	43	253	85.824197999999996	85.850967999999995	50.227032999999999	50.215643999999998	0103000020E610000001000000050000006EDBF7A8BF74554010CAFB389A1B49406EDBF7A8BF7455406F0ED76A0F1D4940527C7C42767655406F0ED76A0F1D4940527C7C427676554010CAFB389A1B49406EDBF7A8BF74554010CAFB389A1B4940
32898	Верх-Уймон	5	43	253	85.729650000000007	85.750608	50.219580999999998	50.207568000000002	0103000020E61000000100000005000000B1E1E995B26E55401BD99596911A4940B1E1E995B26E554057E9EE3A1B1C49406C0723F60970554057E9EE3A1B1C49406C0723F6097055401BD99596911A4940B1E1E995B26E55401BD99596911A4940
60257	Амур	5	43	253	85.101062999999996	85.149033000000003	50.408047000000003	50.393836999999998	0103000020E610000001000000050000007BF5F1D077465540357A3540693249407BF5F1D0774655408F1D54E23A3449409641B5C1894955408F1D54E23A3449409641B5C189495540357A3540693249407BF5F1D077465540357A354069324940
406	Яконур	5	43	29	84.861194999999995	84.883249000000006	51.044896999999999	51.024023999999997	0103000020E61000000100000005000000A31EA2D11D375540D828EB3713834940A31EA2D11D3755402158552FBF854940624ED026873855402158552FBF854940624ED02687385540D828EB3713834940A31EA2D11D375540D828EB3713834940
228	Ябоган	5	43	29	85.058959000000002	85.090992999999997	50.916437000000002	50.901823999999998	0103000020E610000001000000050000008333F8FBC5435540BB5F05F86E7349408333F8FBC543554014ECBFCE4D7549408ECA4DD4D245554014ECBFCE4D7549408ECA4DD4D2455540BB5F05F86E7349408333F8FBC5435540BB5F05F86E734940
680	Черный Ануй	5	43	29	84.718299999999999	84.749588000000003	51.363771999999997	51.342981999999999	0103000020E61000000100000005000000E02D90A0F82D5540EF8E8CD5E6AB4940E02D90A0F82D5540AA99B51490AE4940575EF23FF92F5540AA99B51490AE4940575EF23FF92F5540EF8E8CD5E6AB4940E02D90A0F82D5540EF8E8CD5E6AB4940
566	Усть-Мута	5	43	29	84.744549000000006	84.764446000000007	51.244086000000003	51.224325	0103000020E610000001000000050000004051D9B0A62F55406D567DAEB69C49404051D9B0A62F5540ABB4C5353E9F4940B763EAAEEC305540ABB4C5353E9F4940B763EAAEEC3055406D567DAEB69C49404051D9B0A62F55406D567DAEB69C4940
32186	Усть-Кумир	5	43	29	84.274218000000005	84.300843999999998	51.035778999999998	51.027973000000003	0103000020E610000001000000050000005F7EA7C98C115540E415889E948349405F7EA7C98C1155401971016894844940A94C3107411355401971016894844940A94C310741135540E415889E948349405F7EA7C98C115540E415889E94834940
49276	Усть-Кан	5	43	29	84.733750999999998	84.786994000000007	50.942982999999998	50.917681000000002	0103000020E61000000100000005000000111AC1C6F52E55408E942D9276754940111AC1C6F52E55408CD7BCAAB37849407D09151C5E3255408CD7BCAAB37849407D09151C5E3255408E942D9276754940111AC1C6F52E55408E942D9276754940
32300	Тюдрала	5	43	29	84.475997000000007	84.493073999999993	50.998669999999997	50.987138999999999	0103000020E61000000100000005000000A0FF1EBC761E554096CD1C925A7E4940A0FF1EBC761E554087BF266BD47F4940812040868E1F554087BF266BD47F4940812040868E1F554096CD1C925A7E4940A0FF1EBC761E554096CD1C925A7E4940
785	Турата	5	43	29	84.759101000000001	84.778199999999998	51.320647000000001	51.312736999999998	0103000020E6100000010000000500000019575C1C95305540E49F19C407A8494019575C1C95305540BF47FDF50AA94940D26F5F07CE315540BF47FDF50AA94940D26F5F07CE315540E49F19C407A8494019575C1C95305540E49F19C407A84940
49209	Талица	5	43	29	84.300341000000003	84.319044000000005	51.039980999999997	51.033999999999999	0103000020E61000000100000005000000782975C9381355403108AC1C5A844940782975C9381355400EBBEF181E8549400B7F86376B1455400EBBEF181E8549400B7F86376B1455403108AC1C5A844940782975C9381355403108AC1C5A844940
32201	Санаровка	5	43	29	84.384665999999996	84.397250999999997	51.068035000000002	51.06156	0103000020E610000001000000050000008578245E9E185540F25EB532E18749408578245E9E185540DFFDF15EB58849406953758F6C195540DFFDF15EB58849406953758F6C195540F25EB532E18749408578245E9E185540F25EB532E1874940
325	Оро	5	43	29	84.995484000000005	85.006201000000004	50.915336000000003	50.909021000000003	0103000020E610000001000000050000003EEC8502B63F55404930D5CC5A7449403EEC8502B63F5540FD6CE4BA29754940F60CE19865405540FD6CE4BA29754940F60CE198654055404930D5CC5A7449403EEC8502B63F55404930D5CC5A744940
35	Мендур-Соккон	5	43	29	84.793802999999997	84.826852000000002	50.804563999999999	50.790382000000001	0103000020E61000000100000005000000DE1D19ABCD3255406DACC43C2B654940DE1D19ABCD325540FCC401F4FB66494076A8A624EB345540FCC401F4FB66494076A8A624EB3455406DACC43C2B654940DE1D19ABCD3255406DACC43C2B654940
167	Кырлык	5	43	29	84.932475999999994	84.956821000000005	50.811469000000002	50.794482000000002	0103000020E610000001000000050000008313D1AFAD3B55405EA10F96B16549408313D1AFAD3B5540E25B5837DE67494011C8258E3C3D5540E25B5837DE67494011C8258E3C3D55405EA10F96B16549408313D1AFAD3B55405EA10F96B1654940
59447	Коргон	5	43	29	84.026551999999995	84.049783000000005	51.103198999999996	51.087569000000002	0103000020E610000001000000050000002DE92807B30155405C920376358B49402DE92807B30155406DFDF49F358D4940653909A52F0355406DFDF49F358D4940653909A52F0355405C920376358B49402DE92807B30155405C920376358B4940
32380	Козуль	5	43	29	84.679331000000005	84.692222000000001	50.983232000000001	50.962491	0103000020E610000001000000050000002D0ABB287A2B5540E0D8B3E7327B49402D0ABB287A2B5540BA30D28BDA7D494097E4805D4D2C5540BA30D28BDA7D494097E4805D4D2C5540E0D8B3E7327B49402D0ABB287A2B5540E0D8B3E7327B4940
469	Келей	5	43	29	84.749021999999997	84.762765999999999	51.186149	51.174748999999998	0103000020E61000000100000005000000027FF8F9EF2F55401D01DC2C5E964940027FF8F9EF2F55407097FDBAD39749400C207C28D13055407097FDBAD39749400C207C28D13055401D01DC2C5E964940027FF8F9EF2F55401D01DC2C5E964940
32333	Кайсын	5	43	29	84.587361000000001	84.596999999999994	50.956279000000002	50.946075999999998	0103000020E61000000100000005000000897C975297255540E7C3B30419794940897C975297255540016DAB59677A494091ED7C3F35265540016DAB59677A494091ED7C3F35265540E7C3B30419794940897C975297255540E7C3B30419794940
49172	Владимировка	5	43	29	84.196262000000004	84.219744000000006	51.049624999999999	51.045169000000001	0103000020E61000000100000005000000A5DC7D8E8F0C554082E50819C8854940A5DC7D8E8F0C55403108AC1C5A864940815F2349100E55403108AC1C5A864940815F2349100E554082E50819C8854940A5DC7D8E8F0C554082E50819C8854940
279	Верх-Ябоган	5	43	29	85.228318000000002	85.238540999999998	50.930717000000001	50.923206	0103000020E61000000100000005000000A4C519C39C4E554049BC3C9D2B764940A4C519C39C4E5540666A12BC2177494054707841444F5540666A12BC2177494054707841444F554049BC3C9D2B764940A4C519C39C4E554049BC3C9D2B764940
572	Верх-Мута	5	43	29	84.664113	84.679888000000005	51.196942	51.187865000000002	0103000020E610000001000000050000004DF6CFD3802A55401288D7F50B9849404DF6CFD3802A5540BB9A3C6535994940583CF548832B5540BB9A3C6535994940583CF548832B55401288D7F50B9849404DF6CFD3802A55401288D7F50B984940
897	Верх-Ануй	5	43	29	84.973179000000002	84.996319	51.151184999999998	51.136408000000003	0103000020E61000000100000005000000DB899290483E5540D6743DD175914940DB899290483E5540A852B3075A9349408A58C4B0C33F5540A852B3075A9349408A58C4B0C33F5540D6743DD175914940DB899290483E5540D6743DD175914940
32702	Белый Ануй	5	43	29	84.875558999999996	84.924301999999997	51.243606999999997	51.223896000000003	0103000020E61000000100000005000000FBAD9D280938554045DAC69FA89C4940FBAD9D2809385540D009A1832E9F4940276893C3273B5540D009A1832E9F4940276893C3273B554045DAC69FA89C4940FBAD9D280938554045DAC69FA89C4940
31274	Язула	5	43	1911	88.770465000000002	88.781217999999996	50.618509000000003	50.613765000000001	0103000020E610000001000000050000009C6D6E4C4F315640F836FDD98F4E49409C6D6E4C4F3156400EA48B4D2B4F4940FA42C879FF3156400EA48B4D2B4F4940FA42C879FF315640F836FDD98F4E49409C6D6E4C4F315640F836FDD98F4E4940
31867	Чибит	5	43	1911	87.495863999999997	87.537194999999997	50.322754000000003	50.314570000000003	0103000020E61000000100000005000000E1D05B3CBCDF5540C0266BD443284940E1D05B3CBCDF55409C53C90050294940C824236761E255409C53C90050294940C824236761E25540C0266BD443284940E1D05B3CBCDF5540C0266BD443284940
32053	Чибиля	5	43	1911	87.909824999999998	87.928905999999998	50.626618000000001	50.620131999999998	0103000020E610000001000000050000005305A3923AFA5540FE99417C604F49405305A3923AFA5540DF8AC40435504940B9C3263273FB5540DF8AC40435504940B9C3263273FB5540FE99417C604F49405305A3923AFA5540FE99417C604F4940
31936	Улаган	5	43	1911	87.941563000000002	87.970183000000006	50.640033000000003	50.622560999999997	0103000020E61000000100000005000000EA07759142FC5540ED612F14B04F4940EA07759142FC55402EAEF199EC514940A708707A17FE55402EAEF199EC514940A708707A17FE5540ED612F14B04F4940EA07759142FC5540ED612F14B04F4940
31194	Саратан	5	43	1911	88.258992000000006	88.271101000000002	50.523083999999997	50.516222999999997	0103000020E610000001000000050000003E7B2E5393105640B4386398134249403E7B2E5393105640CA87A06AF44249406D3A02B859115640CA87A06AF44249406D3A02B859115640B4386398134249403E7B2E5393105640B438639813424940
31515	Паспарта	5	43	1911	87.876327000000003	87.888229999999993	50.837688	50.832517000000003	0103000020E610000001000000050000008466D7BD15F85540992EC4EA8F6A49408466D7BD15F855403620425C396B4940DE54A4C2D8F855403620425C396B4940DE54A4C2D8F85540992EC4EA8F6A49408466D7BD15F85540992EC4EA8F6A4940
31678	Коо	5	43	1911	87.890942999999993	87.905118000000002	51.100546000000001	51.092418000000002	0103000020E6100000010000000500000068E6C93505F95540E7C75F5AD48B494068E6C93505F955402FDFFAB0DE8C494057410C74EDF955402FDFFAB0DE8C494057410C74EDF95540E7C75F5AD48B494068E6C93505F95540E7C75F5AD48B4940
31112	Кара-Кудюр	5	43	1911	87.821529999999996	87.829533999999995	50.681229999999999	50.668351999999999	0103000020E61000000100000005000000B4AB90F293F45540AC1BEF8E8C554940B4AB90F293F45540EC866D8B32574940E23AC61517F55540EC866D8B32574940E23AC61517F55540AC1BEF8E8C554940B4AB90F293F45540AC1BEF8E8C554940
31592	Балыкча	5	43	1911	87.709259000000003	87.723855999999998	51.294673000000003	51.278129	0103000020E610000001000000050000003259DC7F64ED5540DB8827BB99A349403259DC7F64ED5540D20149D8B7A54940DBC01DA853EE5540D20149D8B7A54940DBC01DA853EE5540DB8827BB99A349403259DC7F64ED5540DB8827BB99A34940
31370	Балыктуюль	5	43	1911	88.032122000000001	88.046719999999993	50.765732	50.744967000000003	0103000020E61000000100000005000000DBDE6E490E025640B4CC22145B5F4940DBDE6E490E02564016C09481036249406C04E275FD02564016C09481036249406C04E275FD025640B4CC22145B5F4940DBDE6E490E025640B4CC22145B5F4940
31793	Акташ	5	43	1911	87.581141000000002	87.650148999999999	50.335290000000001	50.307499999999997	0103000020E610000001000000050000005857056A31E555408FC2F5285C2749405857056A31E55540825660C8EA2A4940BC218D0A9CE95540825660C8EA2A4940BC218D0A9CE955408FC2F5285C2749405857056A31E555408FC2F5285C274940
12409	Яйлю	5	43	851	87.599969999999999	87.616372999999996	51.772646000000002	51.767831000000001	0103000020E61000000100000005000000312592E865E6554070ED444948E24940312592E865E655404FB16A10E6E24940CB48BDA772E755404FB16A10E6E24940CB48BDA772E7554070ED444948E24940312592E865E6554070ED444948E24940
30676	Чуйка	5	43	851	87.496393999999995	87.511934999999994	51.970756000000002	51.961610999999998	0103000020E610000001000000050000008FFB56EBC4DF5540A73CBA1116FB49408FFB56EBC4DF5540A9328CBB41FC494060AB048BC3E05540A9328CBB41FC494060AB048BC3E05540A73CBA1116FB49408FFB56EBC4DF5540A73CBA1116FB4940
11801	Усть-Пыжа	5	43	851	87.084722999999997	87.104162000000002	51.865456999999999	51.852826	0103000020E61000000100000005000000048E041A6CC55540D996016729ED4940048E041A6CC55540118C834BC7EE49401ADF1797AAC65540118C834BC7EE49401ADF1797AAC65540D996016729ED4940048E041A6CC55540D996016729ED4940
31050	Удаловка	5	43	851	86.934416999999996	86.949867999999995	52.359507999999998	52.349491	0103000020E61000000100000005000000E4F4F57CCDBB5540889FFF1EBC2C4A40E4F4F57CCDBB55403F53AF5B042E4A4015E126A3CABC55403F53AF5B042E4A4015E126A3CABC5540889FFF1EBC2C4A40E4F4F57CCDBB5540889FFF1EBC2C4A40
13312	Турочак	5	43	851	87.090804000000006	87.149356999999995	52.276795	52.243147999999998	0103000020E61000000100000005000000259694BBCFC555403D0B42791F1F4A40259694BBCFC555402159C0046E234A406F9BA9108FC955402159C0046E234A406F9BA9108FC955403D0B42791F1F4A40259694BBCFC555403D0B42791F1F4A40
11733	Тулой	5	43	851	87.119846999999993	87.128012999999996	52.011856000000002	51.998632999999998	0103000020E610000001000000050000008461C092ABC755406ADAC534D3FF49408461C092ABC755407521567F84014A409F1D705D31C855407521567F84014A409F1D705D31C855406ADAC534D3FF49408461C092ABC755406ADAC534D3FF4940
18964	Тондошка	5	43	851	87.105284999999995	87.117232999999999	52.125906000000001	52.117136000000002	0103000020E6100000010000000500000099F04BFDBCC655409697FC4FFE0E4A4099F04BFDBCC65540622F14B01D104A40C440D7BE80C75540622F14B01D104A40C440D7BE80C755409697FC4FFE0E4A4099F04BFDBCC655409697FC4FFE0E4A40
6335	Суранаш	5	43	851	87.754534000000007	87.764405999999994	52.296174999999998	52.288744999999999	0103000020E61000000100000005000000166EF9484AF0554017F19D98F5244A40166EF9484AF055404772F90FE9254A406FB72407ECF055404772F90FE9254A406FB72407ECF0554017F19D98F5244A40166EF9484AF0554017F19D98F5244A40
60281	Санькин-Аил	5	43	851	87.097172999999998	87.110837000000004	52.19041	52.183540999999998	0103000020E6100000010000000500000078431A1538C65540D13C80457E174A4078431A1538C655406A6AD95A5F184A40F48B12F417C755406A6AD95A5F184A40F48B12F417C75540D13C80457E174A4078431A1538C65540D13C80457E174A40
30965	Озеро-Куреево	5	43	851	86.740947000000006	86.760422000000005	52.472768000000002	52.458333000000003	0103000020E610000001000000050000007044F7AC6BAF5540BBD6DEA7AA3A4A407044F7AC6BAF5540344C6DA9833C4A402C4A09C1AAB05540344C6DA9833C4A402C4A09C1AAB05540BBD6DEA7AA3A4A407044F7AC6BAF5540BBD6DEA7AA3A4A40
48728	Майск	5	43	851	88.117335999999995	88.163589999999999	52.336506999999997	52.328324000000002	0103000020E610000001000000050000002EA9DA6E82075640F73E5585062A4A402EA9DA6E8207564002F04FA9122B4A40F8FC3042780A564002F04FA9122B4A40F8FC3042780A5640F73E5585062A4A402EA9DA6E82075640F73E5585062A4A40
30744	Курмач-Байгол	5	43	851	87.653734	87.663021999999998	52.134425	52.119016000000002	0103000020E61000000100000005000000219221C7D6E95540B2D991EA3B0F4A40219221C7D6E95540E561A1D634114A40D3A1D3F36EEA5540E561A1D634114A40D3A1D3F36EEA5540B2D991EA3B0F4A40219221C7D6E95540B2D991EA3B0F4A40
11703	Кебезень	5	43	851	87.079728000000003	87.107045999999997	51.931690000000003	51.90072	0103000020E61000000100000005000000D52478431AC55540336DFFCA4AF34940D52478431AC555405001309E41F74940BA4A77D7D9C655405001309E41F74940BA4A77D7D9C65540336DFFCA4AF34940D52478431AC55540336DFFCA4AF34940
13444	Каяшкан	5	43	851	87.351737999999997	87.375390999999993	52.380775999999997	52.372127999999996	0103000020E61000000100000005000000ABB019E082D6554083F6EAE3A12F4A40ABB019E082D65540048D9944BD304A409D0DF96706D85540048D9944BD304A409D0DF96706D8554083F6EAE3A12F4A40ABB019E082D6554083F6EAE3A12F4A40
30918	Каначак	5	43	851	86.720895999999996	86.731002000000004	52.463403	52.452840000000002	0103000020E610000001000000050000004DF4F92823AE55400B293FA9F6394A404DF4F92823AE554024EF1CCA503B4A40E1D39CBCC8AE554024EF1CCA503B4A40E1D39CBCC8AE55400B293FA9F6394A404DF4F92823AE55400B293FA9F6394A40
12455	Иогач	5	43	851	87.239332000000005	87.279342999999997	51.788170000000001	51.776586000000002	0103000020E61000000100000005000000B9382A3751CF55400744882B67E34940B9382A3751CF55401BD82AC1E2E44940755776C1E0D155401BD82AC1E2E44940755776C1E0D155400744882B67E34940B9382A3751CF55400744882B67E34940
48766	Дмитриевка	5	43	851	86.896472000000003	86.930993999999998	52.45234	52.426934000000003	0103000020E61000000100000005000000E77118CC5FB9554076C6F7C5A5364A40E77118CC5FB955401956F146E6394A406CB1DB6795BB55401956F146E6394A406CB1DB6795BB554076C6F7C5A5364A40E77118CC5FB9554076C6F7C5A5364A40
10991	Верх-Бийск	5	43	851	87.081299999999999	87.099428000000003	52.04251	52.027219000000002	0103000020E610000001000000050000008C4AEA0434C55540386A85E97B034A408C4AEA0434C5554061E0B9F770054A40A11342075DC6554061E0B9F770054A40A11342075DC65540386A85E97B034A408C4AEA0434C55540386A85E97B034A40
30653	Бийка	5	43	851	87.648173	87.666067999999996	51.939574	51.921731999999999	0103000020E610000001000000050000009D499BAA7BE955409DD66D50FBF549409D499BAA7BE955400116F9F543F84940603AADDBA0EA55400116F9F543F84940603AADDBA0EA55409DD66D50FBF549409D499BAA7BE955409DD66D50FBF54940
12838	Артыбаш	5	43	851	87.241335000000007	87.289295999999993	51.797395000000002	51.786465	0103000020E6100000010000000500000055185B0872CF55406D3997E2AAE4494055185B0872CF5540397F130A11E6494045B75ED383D25540397F130A11E6494045B75ED383D255406D3997E2AAE4494055185B0872CF55406D3997E2AAE44940
60279	с.Малый Яломан	5	43	195	85.239097999999998	87.500597999999997	51.296498	50.192697000000003	0103000020E610000001000000050000007FA2B2614D4F5540C784984BAA1849407FA2B2614D4F55402AAA7EA5F3A549405A9C31CC09E055402AAA7EA5F3A549405A9C31CC09E05540C784984BAA1849407FA2B2614D4F5540C784984BAA184940
13010	Шиба	5	43	195	85.728257999999997	85.748254000000003	50.852024999999998	50.846026000000002	0103000020E61000000100000005000000394371C79B6E554069C878944A6C4940394371C79B6E5540EC2FBB270F6D49407AC6BE64E36F5540EC2FBB270F6D49407AC6BE64E36F554069C878944A6C4940394371C79B6E554069C878944A6C4940
12281	Шашикман	5	43	195	86.041212999999999	86.073390000000003	50.795296	50.776685999999998	0103000020E61000000100000005000000E2CAD93BA38255406AA164726A634940E2CAD93BA3825540DF516342CC6549409F76F86BB2845540DF516342CC6549409F76F86BB28455406AA164726A634940E2CAD93BA38255406AA164726A634940
45507	Хабаровка	5	43	195	86.281915999999995	86.293414999999996	50.698846000000003	50.669643000000001	0103000020E61000000100000005000000060E68E90A925540677FA0DCB6554940060E68E90A925540607825C973594940F949B54FC7925540607825C973594940F949B54FC7925540677FA0DCB6554940060E68E90A925540677FA0DCB6554940
12086	Улита	5	43	195	86.200502	86.217256000000006	50.717697999999999	50.699838	0103000020E6100000010000000500000016325706D58C5540C03FA54A9459494016325706D58C5540CA332F87DD5B494007B7B585E78D5540CA332F87DD5B494007B7B585E78D5540C03FA54A9459494016325706D58C5540C03FA54A94594940
60275	Туекта	5	43	195	85.866562000000002	85.894069000000002	50.841993000000002	50.835628	0103000020E61000000100000005000000357D76C0757755409ACFB9DBF56A4940357D76C075775540003B376DC66B494084D72E6D38795540003B376DC66B494084D72E6D387955409ACFB9DBF56A4940357D76C0757755409ACFB9DBF56A4940
13020	Теньга	5	43	195	85.638193000000001	85.665726000000006	50.842413999999998	50.835748000000002	0103000020E6100000010000000500000050E27327D868554045D95BCAF96A494050E27327D8685540A5D8D138D46B4940348639419B6A5540A5D8D138D46B4940348639419B6A554045D95BCAF96A494050E27327D868554045D95BCAF96A4940
12892	Талда	5	43	195	85.762439000000001	85.775769999999994	50.843302000000001	50.839092999999998	0103000020E610000001000000050000007A8CF2CCCB705540B9A64066676B49407A8CF2CCCB7055406153E751F16B4940F2CD3637A67155406153E751F16B4940F2CD3637A6715540B9A64066676B49407A8CF2CCCB705540B9A64066676B4940
12168	Онгудай	5	43	195	86.105423999999999	86.164803000000006	50.763339000000002	50.732129999999998	0103000020E61000000100000005000000AA0D4E44BF865540D235936FB65D4940AA0D4E44BF8655407461A417B561494018D2E1218C8A55407461A417B561494018D2E1218C8A5540D235936FB65D4940AA0D4E44BF865540D235936FB65D4940
45966	Озерное	5	43	195	85.574224000000001	85.583727999999994	50.913184000000001	50.906191999999997	0103000020E6100000010000000500000003250516C0645540CBF27519FE73494003250516C0645540809D9B36E37449409B70AFCC5B655540809D9B36E37449409B70AFCC5B655540CBF27519FE73494003250516C0645540CBF27519FE734940
12369	Нижняя Талда	5	43	195	85.970983000000004	85.985472000000001	50.861753999999998	50.84722	0103000020E61000000100000005000000357EE195247E5540314278B4716C4940357EE195247E55403D997FF44D6E4940EBC726F9117F55403D997FF44D6E4940EBC726F9117F5540314278B4716C4940357EE195247E5540314278B4716C4940
45805	Нефтебаза	5	43	195	85.829453000000001	85.835553000000004	50.855642000000003	50.851484999999997	0103000020E610000001000000050000006C2409C2157555406C04E275FD6C49406C2409C215755540C28A53AD856D4940C8444AB379755540C28A53AD856D4940C8444AB3797555406C04E275FD6C49406C2409C2157555406C04E275FD6C4940
49547	Малая Иня	5	43	195	86.659514000000001	86.690128999999999	50.453229	50.445754999999998	0103000020E610000001000000050000004450357A35AA5540A583F57F0E3949404450357A35AA5540A54C6A68033A49405B41D3122BAC5540A54C6A68033A49405B41D3122BAC5540A583F57F0E3949404450357A35AA5540A583F57F0E394940
11960	Купчегень	5	43	195	86.416385000000005	86.426276000000001	50.631669000000002	50.617257000000002	0103000020E61000000100000005000000E162450DA69A5540111D0247024F4940E162450DA69A5540D272A087DA50494076C4211B489B5540D272A087DA50494076C4211B489B5540111D0247024F4940E162450DA69A5540111D0247024F4940
12655	Кулада	5	43	195	85.780485999999996	85.791534999999996	50.692414999999997	50.682257	0103000020E61000000100000005000000183F8D7BF3715540C93B873254574940183F8D7BF37155404221020EA1584940EBA86A82A87255404221020EA1584940EBA86A82A8725540C93B873254574940183F8D7BF3715540C93B873254574940
13229	Каярлык	5	43	195	85.574591999999996	85.582605000000001	50.688015999999998	50.676470000000002	0103000020E61000000100000005000000C422861DC6645540D15CA79196564940C422861DC6645540F78F85E8105849401C5F7B6649655540F78F85E8105849401C5F7B6649655540D15CA79196564940C422861DC6645540D15CA79196564940
724	Каракол	5	43	195	85.937089	85.957948000000002	50.816397000000002	50.812401999999999	0103000020E610000001000000050000003F1C2444F97B55403D9AEAC9FC6749403F1C2444F97B5540B9C667B27F68494031D120054F7D5540B9C667B27F68494031D120054F7D55403D9AEAC9FC6749403F1C2444F97B55403D9AEAC9FC674940
60285	Кара Кобы	5	43	195	85.576442	85.584581	50.818917999999996	50.811525000000003	0103000020E610000001000000050000009D82FC6CE464554076711B0DE06749409D82FC6CE4645540880D164ED26849403B376DC669655540880D164ED26849403B376DC66965554076711B0DE06749409D82FC6CE464554076711B0DE0674940
11300	Иодро	5	43	195	86.973359000000002	86.979836000000006	50.403568999999997	50.395341000000002	0103000020E610000001000000050000001B118C834BBE55404CE2AC889A3249401B118C834BBE5540F7562426A833494062DC0DA2B5BE5540F7562426A833494062DC0DA2B5BE55404CE2AC889A3249401B118C834BBE55404CE2AC889A324940
49562	Иня	5	43	195	86.619827000000001	86.641710000000003	50.458803000000003	50.443420000000003	0103000020E61000000100000005000000618BDD3EABA7554038328FFCC1384940618BDD3EABA755404227840EBA3A494009E1D1C611A955404227840EBA3A494009E1D1C611A9554038328FFCC1384940618BDD3EABA7554038328FFCC1384940
11368	Инегень	5	43	195	86.690066000000002	86.697935000000001	50.325814000000001	50.319820999999997	0103000020E610000001000000050000003885950A2AAC554079C9FFE4EF2849403885950A2AAC55401B4AED45B4294940F6EE8FF7AAAC55401B4AED45B4294940F6EE8FF7AAAC554079C9FFE4EF2849403885950A2AAC554079C9FFE4EF284940
13167	Ело	5	43	195	85.552870999999996	85.567072999999993	50.777962000000002	50.763213999999998	0103000020E6100000010000000500000009FA0B3D62635540B7EC10FFB061494009FA0B3D62635540F0C3414294634940745C8DEC4A645540F0C3414294634940745C8DEC4A645540B7EC10FFB061494009FA0B3D62635540B7EC10FFB0614940
12618	Боочи	5	43	195	85.814971999999997	85.828474	50.745628000000004	50.738343999999998	0103000020E61000000100000005000000F7C95180287455405299620E825E4940F7C9518028745540AF7D01BD705F494086E5CFB705755540AF7D01BD705F494086E5CFB7057555405299620E825E4940F7C95180287455405299620E825E4940
11918	Большой Яломан	5	43	195	86.411120999999994	86.423680000000004	50.490338000000001	50.486946000000003	0103000020E61000000100000005000000B96C74CE4F9A554082751C3F543E4940B96C74CE4F9A554037FE4465C33E494009FEB7921D9B554037FE4465C33E494009FEB7921D9B554082751C3F543E4940B96C74CE4F9A554082751C3F543E4940
12559	Бичикту-Боом	5	43	195	85.902917000000002	85.916967	50.794817999999999	50.783543000000002	0103000020E6100000010000000500000028806264C97955403F0114234B64494028806264C9795540D522A298BC654940B8205B96AF7A5540D522A298BC654940B8205B96AF7A55403F0114234B64494028806264C97955403F0114234B644940
30185	Усть-Муны	5	43	863	85.732471000000004	85.766733000000002	51.729073	51.719360000000002	0103000020E610000001000000050000002E910BCEE06E554079060DFD13DC49402E910BCEE06E5540C4B2994352DD4940E5F0492712715540C4B2994352DD4940E5F049271271554079060DFD13DC49402E910BCEE06E554079060DFD13DC4940
30601	Урлу-Аспак	5	43	863	86.205003000000005	86.227568000000005	51.689024000000003	51.67794	0103000020E610000001000000050000003E25E7C41E8D55403B53E8BCC6D649403E25E7C41E8D55405E143DF031D849406F675F79908E55405E143DF031D849406F675F79908E55403B53E8BCC6D649403E25E7C41E8D55403B53E8BCC6D64940
11011	Средний Сайдыс	5	43	863	86.147519000000003	86.159422000000006	51.766772000000003	51.75976	0103000020E61000000100000005000000792288F3708955408C67D0D03FE14940792288F37089554088BEBB9525E24940D41055F8338A554088BEBB9525E24940D41055F8338A55408C67D0D03FE14940792288F3708955408C67D0D03FE14940
30034	Соузга	5	43	863	85.829335999999998	85.872698	51.895539999999997	51.878391000000001	0103000020E610000001000000050000004F594DD713755540E50CC51D6FF049404F594DD7137555404221020EA1F249403752B648DA7755404221020EA1F249403752B648DA775540E50CC51D6FF049404F594DD713755540E50CC51D6FF04940
48533	Подгорное	5	43	863	85.881528000000003	85.898587000000006	52.037818000000001	52.027118999999999	0103000020E6100000010000000500000088A06AF46A785540D40CA9A278034A4088A06AF46A7855409E996038D7044A4017670C73827955409E996038D7044A4017670C7382795540D40CA9A278034A4088A06AF46A785540D40CA9A278034A40
30101	Манжерок	5	43	863	85.761827999999994	85.792676	51.839289000000001	51.813389000000001	0103000020E61000000100000005000000554B3ACAC17055408CF678211DE84940554B3ACAC17055403F726BD26DEB4940BE141E34BB7255403F726BD26DEB4940BE141E34BB7255408CF678211DE84940554B3ACAC17055408CF678211DE84940
6509	Майма	5	43	863	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
30379	Кызыл-Озек	5	43	863	85.981592000000006	86.014757000000003	51.909709999999997	51.870468000000002	0103000020E61000000100000005000000FA804067D27E5540761BD47E6BEF4940FA804067D27E55400D6C956071F44940C61858C7F18055400D6C956071F44940C61858C7F1805540761BD47E6BEF4940FA804067D27E5540761BD47E6BEF4940
29956	Карлушка	5	43	863	85.847337999999993	85.860659999999996	51.984707999999998	51.977147000000002	0103000020E610000001000000050000001DAA29C93A7655403831242713FD49401DAA29C93A765540060E68E90AFE49406C3EAE0D15775540060E68E90AFE49406C3EAE0D157755403831242713FD49401DAA29C93A7655403831242713FD4940
11107	Карасук	5	43	863	86.129373000000001	86.15061	51.855535000000003	51.844825	0103000020E6100000010000000500000011FFB0A547885540EEEBC03923EC494011FFB0A547885540ACCABE2B82ED4940D61C2098A3895540ACCABE2B82ED4940D61C2098A3895540EEEBC03923EC494011FFB0A547885540EEEBC03923EC4940
48410	Дубровка	5	43	863	85.832363999999998	85.849620000000002	51.935381999999997	51.922364999999999	0103000020E610000001000000050000008997A77345755540CEFC6A0E10F649408997A773457555402FA2ED98BAF74940C381902C607655402FA2ED98BAF74940C381902C60765540CEFC6A0E10F649408997A77345755540CEFC6A0E10F64940
30215	Верх-Карагуж	5	43	863	86.029903000000004	86.073750000000004	52.058677000000003	52.038738000000002	0103000020E6100000010000000500000059C345EEE9815540658EE55DF5044A4059C345EEE981554082035ABA82074A401F85EB51B884554082035ABA82074A401F85EB51B8845540658EE55DF5044A4059C345EEE9815540658EE55DF5044A40
30503	Бирюля	5	43	863	86.045147	86.061964000000003	51.794398000000001	51.768048999999998	0103000020E61000000100000005000000CD203EB0E3825540DD5CFC6D4FE24940CD203EB0E382554000016BD5AEE54940E161DA37F783554000016BD5AEE54940E161DA37F7835540DD5CFC6D4FE24940CD203EB0E3825540DD5CFC6D4FE24940
59414	Алферово	5	43	863	85.992649999999998	86.009179000000003	51.979681999999997	51.968237000000002	0103000020E61000000100000005000000F697DD93877F55407AE3A430EFFB4940F697DD93877F55406C3D433866FD4940D7338463968055406C3D433866FD4940D7338463968055407AE3A430EFFB4940F697DD93877F55407AE3A430EFFB4940
48613	Александровка	5	43	863	86.104059000000007	86.120570000000001	51.745865999999999	51.729089000000002	0103000020E61000000100000005000000B07614E7A8865540CA6FD1C952DD4940B07614E7A886554063997E8978DF49403DB83B6BB787554063997E8978DF49403DB83B6BB7875540CA6FD1C952DD4940B07614E7A8865540CA6FD1C952DD4940
28909	Чаган-Узун	5	43	841	88.355147000000002	88.369754	50.104576999999999	50.099648000000002	0103000020E6100000010000000500000071917BBABA165640508E0244C10C494071917BBABA165640F77475C7620D49402C64AE0CAA175640F77475C7620D49402C64AE0CAA175640508E0244C10C494071917BBABA165640508E0244C10C4940
29312	Теленгит-Сортогой	5	43	841	88.739086999999998	88.755059000000003	50.013567000000002	50.007865000000002	0103000020E6100000010000000500000085798F334D2F56403BE466B80101494085798F334D2F564005A73E90BC0149403BE3FBE25230564005A73E90BC0149403BE3FBE2523056403BE466B80101494085798F334D2F56403BE466B801014940
32886	Тебелер	5	43	841	88.782241999999997	88.802293000000006	49.921391999999997	49.907772000000001	0103000020E61000000100000005000000B0E3BF4010325640BD1C76DF31F44840B0E3BF4010325640E4654D2CF0F54840D333BDC458335640E4654D2CF0F54840D333BDC458335640BD1C76DF31F44840B0E3BF4010325640BD1C76DF31F44840
29486	Ташанта	5	43	841	89.188254000000001	89.199959000000007	49.719714000000003	49.711292	0103000020E61000000100000005000000D655815A0C4C564006F4C29D0BDB4840D655815A0C4C5640973C9E961FDC48409E62D520CC4C5640973C9E961FDC48409E62D520CC4C564006F4C29D0BDB4840D655815A0C4C564006F4C29D0BDB4840
28949	Ортолык	5	43	841	88.494979000000001	88.509378999999996	50.038902999999998	50.030797	0103000020E610000001000000050000003C4D66BCAD1F56404FE8F527F10349403C4D66BCAD1F5640AF5B04C6FA0449403A9160AA99205640AF5B04C6FA0449403A9160AA992056404FE8F527F10349403C4D66BCAD1F56404FE8F527F1034940
29004	Мухор-Тархата	5	43	841	88.526375000000002	88.539822999999998	49.996046999999997	49.982841999999998	0103000020E61000000100000005000000A69BC420B02156404F9143C4CDFD4840A69BC420B0215640B323D5777EFF48403BA8C4758C225640B323D5777EFF48403BA8C4758C2256404F9143C4CDFD4840A69BC420B02156404F9143C4CDFD4840
28856	Кызыл-Таш	5	43	841	87.932210999999995	87.947024999999996	50.221044999999997	50.209021	0103000020E610000001000000050000002C7E5358A9FB5540AF963B33C11A49402C7E5358A9FB5540DFF8DA334B1C4940A4DFBE0E9CFC5540DFF8DA334B1C4940A4DFBE0E9CFC5540AF963B33C11A49402C7E5358A9FB5540AF963B33C11A4940
32738	Курай	5	43	841	87.923407999999995	87.936721000000006	50.235652999999999	50.229736000000003	0103000020E610000001000000050000005837DE1D19FB5540605B3FFD671D49405837DE1D19FB5540261AA4E0291E49407E1EA33CF3FB5540261AA4E0291E49407E1EA33CF3FB5540605B3FFD671D49405837DE1D19FB5540605B3FFD671D4940
29091	Кош-Агач	5	43	841	88.642042000000004	88.680840000000003	50.009613000000002	49.983080000000001	0103000020E61000000100000005000000242A54371729564004ADC090D5FD4840242A543717295640E84EB0FF3A014940C173EFE1922B5640E84EB0FF3A014940C173EFE1922B564004ADC090D5FD4840242A54371729564004ADC090D5FD4840
29429	Кокоря	5	43	841	88.991135999999997	89.004935000000003	49.920904999999998	49.906432000000002	0103000020E61000000100000005000000D978B0C56E3F56402106BAF605F44840D978B0C56E3F564087DC0C37E0F54840C5E6E3DA5040564087DC0C37E0F54840C5E6E3DA504056402106BAF605F44840D978B0C56E3F56402106BAF605F44840
29384	Жана-Аул	5	43	841	88.911618000000004	88.926332000000002	49.849663999999997	49.840561000000001	0103000020E610000001000000050000007A1C06F3573A564083A5BA8097EB48407A1C06F3573A5640554B3ACAC1EC4840404F0306493B5640554B3ACAC1EC4840404F0306493B564083A5BA8097EB48407A1C06F3573A564083A5BA8097EB4840
32924	Беляши (Джазатор)	5	43	841	87.418599999999998	87.431302000000002	49.712515000000003	49.701253999999999	0103000020E61000000100000005000000C286A757CADA55403718EAB0C2D94840C286A757CADA5540697407B133DB4840C32CB4739ADB5540697407B133DB4840C32CB4739ADB55403718EAB0C2D94840C286A757CADA55403718EAB0C2D94840
29041	Бельтир	5	43	841	88.162108000000003	88.190342000000001	49.979025	49.972861000000002	0103000020E61000000100000005000000E19A3BFA5F0A5640E54691B586FC4840E19A3BFA5F0A5640B37BF2B050FD4840894336902E0C5640B37BF2B050FD4840894336902E0C5640E54691B586FC4840E19A3BFA5F0A5640E54691B586FC4840
60029	Приветная	5	53	\N	73.172432999999998	73.197226999999998	54.968246000000001	54.951762000000002	0103000020E6100000010000000500000013F06B24094B5240ACC95356D3794B4013F06B24094B5240CD3D247CEF7B4B40D8B8FE5D9F4C5240CD3D247CEF7B4B40D8B8FE5D9F4C5240ACC95356D3794B4013F06B24094B5240ACC95356D3794B40
41	Омск	5	53	\N	73.096777000000003	73.660775000000001	55.14132	54.824285000000003	0103000020E610000001000000050000005280289831465240ACCABE2B82694B405280289831465240A72215C616924B40ECC039234A6A5240A72215C616924B40ECC039234A6A5240ACCABE2B82694B405280289831465240ACCABE2B82694B40
13096	Новомосковка	5	53	\N	73.524338999999998	73.553084999999996	55.026018999999998	55.011319	0103000020E610000001000000050000001C412AC58E6152406669A7E672814B401C412AC58E6152408D09319754834B401FBAA0BE656352408D09319754834B401FBAA0BE656352406669A7E672814B401C412AC58E6152406669A7E672814B40
48683	Муромцево	5	53	\N	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
7329	Магистральный	5	53	\N	73.227275000000006	73.250200000000007	54.936103000000003	54.916795999999998	0103000020E61000000100000005000000B30C71AC8B4E5240438D429259754B40B30C71AC8B4E524000581D39D2774B40645DDC460350524000581D39D2774B40645DDC4603505240438D429259754B40B30C71AC8B4E5240438D429259754B40
46330	Яблоновка	5	53	245	72.568890999999994	72.578287000000003	54.401437999999999	54.387751999999999	0103000020E6100000010000000500000047FFCBB568245240B37A87DBA1314B4047FFCBB56824524092AF045262334B40ED2C7AA70225524092AF045262334B40ED2C7AA702255240B37A87DBA1314B4047FFCBB568245240B37A87DBA1314B40
32275	Шербакуль	5	53	245	72.360590000000002	72.425421	54.641596999999997	54.616706000000001	0103000020E61000000100000005000000F05014E8131752409D9FE238F04E4B40F05014E813175240191BBAD91F524B40068200193A1B5240191BBAD91F524B40068200193A1B52409D9FE238F04E4B40F05014E8131752409D9FE238F04E4B40
60850	Шахат	5	53	245	72.378941999999995	72.388347999999993	54.380583999999999	54.374468999999998	0103000020E610000001000000050000002C45F29540185240D32EA699EE2F4B402C45F29540185240C0B0FCF9B6304B40E3DD91B1DA185240C0B0FCF9B6304B40E3DD91B1DA185240D32EA699EE2F4B402C45F29540185240D32EA699EE2F4B40
60851	Чадское	5	53	245	72.568540999999996	72.580281999999997	54.332329000000001	54.323965000000001	0103000020E61000000100000005000000D95BCAF9622452403A0664AF77294B40D95BCAF9622452409641B5C1892A4B40471D1D57232552409641B5C1892A4B40471D1D57232552403A0664AF77294B40D95BCAF9622452403A0664AF77294B40
46150	Центральное	5	53	245	72.545812999999995	72.558622999999997	54.647264999999997	54.637022000000002	0103000020E61000000100000005000000D32EA699EE225240906AD8EF89514B40D32EA699EE225240376C5B94D9524B40C7F2AE7AC0235240376C5B94D9524B40C7F2AE7AC0235240906AD8EF89514B40D32EA699EE225240906AD8EF89514B40
973	Тарналы	5	53	245	72.665899999999993	72.678377999999995	54.596525	54.588616999999999	0103000020E61000000100000005000000029A081B9E2A5240506F46CD574B4B40029A081B9E2A52408A1F63EE5A4C4B40DB148F8B6A2B52408A1F63EE5A4C4B40DB148F8B6A2B5240506F46CD574B4B40029A081B9E2A5240506F46CD574B4B40
1018	Таловское	5	53	245	72.272869	72.299961999999994	54.451439000000001	54.440292999999997	0103000020E61000000100000005000000E7C589AF7611524030D461855B384B40E7C589AF76115240C991CEC0C8394B40BC02D19332135240C991CEC0C8394B40BC02D1933213524030D461855B384B40E7C589AF7611524030D461855B384B40
46402	Солнцево	5	53	245	72.563159999999996	72.576634999999996	54.301143000000003	54.289861000000002	0103000020E61000000100000005000000959A3DD00A24524064B14D2A1A254B40959A3DD00A245240AD3594DA8B264B40A7AE7C96E7245240AD3594DA8B264B40A7AE7C96E724524064B14D2A1A254B40959A3DD00A24524064B14D2A1A254B40
46261	Славянское	5	53	245	72.115853000000001	72.138795999999999	54.479827	54.469138000000001	0103000020E610000001000000050000002F89B3226A075240CAA7C7B60C3C4B402F89B3226A075240705E9CF86A3D4B4033349E08E2085240705E9CF86A3D4B4033349E08E2085240CAA7C7B60C3C4B402F89B3226A075240CAA7C7B60C3C4B40
45866	Путиловка	5	53	245	72.081474	72.114459999999994	54.561359000000003	54.550144000000003	0103000020E610000001000000050000005B5EB9DE360552409A0B5C1E6B464B405B5EB9DE360552405B28999CDA474B40CF2C0950530752405B28999CDA474B40CF2C0950530752409A0B5C1E6B464B405B5EB9DE360552409A0B5C1E6B464B40
46039	Новоскатовка	5	53	245	72.272105999999994	72.298292000000004	54.342114000000002	54.330790999999998	0103000020E61000000100000005000000E7C2482F6A115240D367075C572A4B40E7C2482F6A1152407BC03C64CA2B4B40242A5437171352407BC03C64CA2B4B40242A543717135240D367075C572A4B40E7C2482F6A115240D367075C572A4B40
52999	Максимовка	5	53	245	72.160004999999998	72.193879999999993	54.532969999999999	54.514149000000003	0103000020E61000000100000005000000938C9C853D0A5240B4226AA2CF414B40938C9C853D0A5240E3DF675C38444B404DD6A887680C5240E3DF675C38444B404DD6A887680C5240B4226AA2CF414B40938C9C853D0A5240B4226AA2CF414B40
45928	Кутузовка	5	53	245	72.508695000000003	72.534530000000004	54.475914000000003	54.458955000000003	0103000020E61000000100000005000000E12879758E205240F8AA9509BF3A4B40E12879758E205240B2DAFCBFEA3C4B40C72E51BD35225240B2DAFCBFEA3C4B40C72E51BD35225240F8AA9509BF3A4B40E12879758E205240F8AA9509BF3A4B40
30437	Кудук-Чилик	5	53	245	72.490046000000007	72.506457999999995	54.378607000000002	54.371983	0103000020E6100000010000000500000048E2E5E95C1F524080D591239D2F4B4048E2E5E95C1F5240B284B53176304B400BB3D0CE69205240B284B53176304B400BB3D0CE6920524080D591239D2F4B4048E2E5E95C1F524080D591239D2F4B40
28239	Крушановка	5	53	245	72.416410999999997	72.431134	54.310924999999997	54.305135999999997	0103000020E6100000010000000500000075AC527AA61A5240876A4AB20E274B4075AC527AA61A52402041F163CC274B40658C0FB3971B52402041F163CC274B40658C0FB3971B5240876A4AB20E274B4075AC527AA61A5240876A4AB20E274B40
46234	Красный Восток	5	53	245	72.171601999999993	72.179210999999995	54.444904999999999	54.427604000000002	0103000020E61000000100000005000000677BF486FB0A5240C4D155BABB364B40677BF486FB0A5240D769A4A5F2384B4057056A31780B5240D769A4A5F2384B4057056A31780B5240C4D155BABB364B40677BF486FB0A5240C4D155BABB364B40
53094	Красноярка	5	53	245	72.655938000000006	72.686822000000006	54.393906000000001	54.376393999999998	0103000020E61000000100000005000000098D60E3FA2952408F34B8AD2D304B40098D60E3FA2952405ED905836B324B40180B43E4F42B52405ED905836B324B40180B43E4F42B52408F34B8AD2D304B40098D60E3FA2952408F34B8AD2D304B40
60823	Комиссаровское-1	5	53	245	72.708884999999995	72.736112000000006	54.510035000000002	54.499982000000003	0103000020E61000000100000005000000FFE7305F5E2D52405A4B0169FF3F4B40FFE7305F5E2D52405E68AED348414B405D8C81751C2F52405E68AED348414B405D8C81751C2F52405A4B0169FF3F4B40FFE7305F5E2D52405A4B0169FF3F4B40
1451	Кокчинск	5	53	245	72.573274999999995	72.592005	54.367147000000003	54.361088000000002	0103000020E610000001000000050000005227A089B0245240317DAF21382E4B405227A089B02452408AE942ACFE2E4B406284F068E32552408AE942ACFE2E4B406284F068E3255240317DAF21382E4B405227A089B0245240317DAF21382E4B40
60189	Карагаш	5	53	245	72.682699	72.694277999999997	54.412542999999999	54.405678000000002	0103000020E61000000100000005000000C3802557B12B5240755AB741ED334B40C3802557B12B5240CC988235CE344B404415FE0C6F2C5240CC988235CE344B404415FE0C6F2C5240755AB741ED334B40C3802557B12B5240755AB741ED334B40
53109	Кайчубай	5	53	245	72.710942000000003	72.719188000000003	54.725513999999997	54.714458	0103000020E6100000010000000500000095D6DF12802D5240CB2E185C735B4B4095D6DF12802D524023658BA4DD5C4B403EEB1A2D072E524023658BA4DD5C4B403EEB1A2D072E5240CB2E185C735B4B4095D6DF12802D5240CB2E185C735B4B40
28789	Изюмовка	5	53	245	72.619016999999999	72.672978999999998	54.681247999999997	54.668467999999997	0103000020E61000000100000005000000C1AA7AF99D2752401536035C90554B40C1AA7AF99D275240923B6C2233574B4044F98216122B5240923B6C2233574B4044F98216122B52401536035C90554B40C1AA7AF99D2752401536035C90554B40
45912	Елизаветино	5	53	245	72.068808000000004	72.084241000000006	54.504353000000002	54.494109999999999	0103000020E61000000100000005000000016DAB5967045240335019FF3E3F4B40016DAB5967045240DB519CA38E404B40DFFE5C3464055240DB519CA38E404B40DFFE5C3464055240335019FF3E3F4B40016DAB5967045240335019FF3E3F4B40
45974	Екатеринославка	5	53	245	72.434656000000004	72.473876000000004	54.354913000000003	54.337184999999998	0103000020E61000000100000005000000A7406667D11B5240D3D9C9E0282B4B40A7406667D11B52406FF607CA6D2D4B40FF9600FC531E52406FF607CA6D2D4B40FF9600FC531E5240D3D9C9E0282B4B40A7406667D11B5240D3D9C9E0282B4B40
45947	Дубровка	5	53	245	72.434242999999995	72.457571999999999	54.500782000000001	54.493352000000002	0103000020E6100000010000000500000015E126A3CA1B524046B58828263F4B4015E126A3CA1B52407636E49F19404B402EE411DC481D52407636E49F19404B402EE411DC481D524046B58828263F4B4015E126A3CA1B524046B58828263F4B40
47257	Вишневка	5	53	245	72.511640999999997	72.521585999999999	54.775084999999997	54.766012000000003	0103000020E61000000100000005000000BC92E4B9BE205240FA2B64AE0C624B40BC92E4B9BE205240614F3BFC35634B404B033FAA61215240614F3BFC35634B404B033FAA61215240FA2B64AE0C624B40BC92E4B9BE205240FA2B64AE0C624B40
45821	Вербовка	5	53	245	72.230451000000002	72.245604999999998	54.595283000000002	54.582298000000002	0103000020E6100000010000000500000027158DB5BF0E52405B43A9BD884A4B4027158DB5BF0E5240B16EBC3B324C4B40FBAE08FEB70F5240B16EBC3B324C4B40FBAE08FEB70F52405B43A9BD884A4B4027158DB5BF0E52405B43A9BD884A4B40
46108	Борисовское	5	53	245	72.57199	72.602919	54.633020000000002	54.615746000000001	0103000020E61000000100000005000000E6E8F17B9B2452404852D2C3D04E4B40E6E8F17B9B24524062DBA2CC06514B40C5C892399626524062DBA2CC06514B40C5C89239962652404852D2C3D04E4B40E6E8F17B9B2452404852D2C3D04E4B40
53114	Большой Искак	5	53	245	72.813547	72.827157	54.729813	54.721708	0103000020E6100000010000000500000092B06F27113452407BA180ED605C4B4092B06F27113452400B992B836A5D4B4014EAE923F03452400B992B836A5D4B4014EAE923F03452407BA180ED605C4B4092B06F27113452407BA180ED605C4B40
60846	Большевасильевка	5	53	245	72.242739999999998	72.260383000000004	54.657010999999997	54.645550999999998	0103000020E61000000100000005000000965B5A0D890F52403673486AA1524B40965B5A0D890F52405E0EBBEF18544B40CD5B751DAA1052405E0EBBEF18544B40CD5B751DAA1052403673486AA1524B40965B5A0D890F52403673486AA1524B40
32397	Бабеж	5	53	245	72.192083999999994	72.222159000000005	54.641404000000001	54.628788	0103000020E610000001000000050000006E85B01A4B0C5240020F0C207C504B406E85B01A4B0C524005C3B98619524B40C6E061DA370E524005C3B98619524B40C6E061DA370E5240020F0C207C504B406E85B01A4B0C5240020F0C207C504B40
46053	Александровское	5	53	245	72.694646000000006	72.727884000000003	54.670794999999998	54.654609999999998	0103000020E6100000010000000500000006137F14752C524039D1AE42CA534B4006137F14752C524000A94D9CDC554B4007D2C5A6952E524000A94D9CDC554B4007D2C5A6952E524039D1AE42CA534B4006137F14752C524039D1AE42CA534B40
60807	д. Большое Озеро	5	53	1788	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
52986	Черлак	5	53	1788	74.772610999999998	74.826959000000002	54.167523000000003	54.138078999999998	0103000020E61000000100000005000000E961687572B15240D7A19A92AC114B40E961687572B15240F629C76471154B40810871E5ECB45240F629C76471154B40810871E5ECB45240D7A19A92AC114B40E961687572B15240D7A19A92AC114B40
30998	Целинное (отд. N3 свх. Красный Октябрь)	5	53	1788	74.913656000000003	74.926618000000005	54.141159999999999	54.135098999999997	0103000020E61000000100000005000000D4F2035779BA5240745C8DEC4A114B40D4F2035779BA52406EC0E78711124B40A37895B54DBB52406EC0E78711124B40A37895B54DBB5240745C8DEC4A114B40D4F2035779BA5240745C8DEC4A114B40
53126	Татарское	5	53	1788	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
31881	Татарка	5	53	1788	75.047801000000007	75.073860999999994	53.970661	53.951298999999999	0103000020E61000000100000005000000D5EDEC2B0FC35240D7DB662AC4F94A40D5EDEC2B0FC352405740A19E3EFC4A40CADC7C23BAC452405740A19E3EFC4A40CADC7C23BAC45240D7DB662AC4F94A40D5EDEC2B0FC35240D7DB662AC4F94A40
31762	Суворовка (отд. №4 свх. Коммунист)	5	53	1788	74.675674000000001	74.693783999999994	54.480950999999997	54.470514999999999	0103000020E610000001000000050000007B30293E3EAB524083A3E4D5393C4B407B30293E3EAB52403FFD67CD8F3D4B403C9F01F566AC52403FFD67CD8F3D4B403C9F01F566AC524083A3E4D5393C4B407B30293E3EAB524083A3E4D5393C4B40
31197	Стретенка	5	53	1788	75.332054999999997	75.341721000000007	54.407862999999999	54.397036	0103000020E610000001000000050000004A5E9D6340D55240D6AA5D13D2324B404A5E9D6340D55240CD1FD3DA34344B40D0D6C1C1DED55240CD1FD3DA34344B40D0D6C1C1DED55240D6AA5D13D2324B404A5E9D6340D55240D6AA5D13D2324B40
31584	Соляное	5	53	1788	74.583703999999997	74.623895000000005	54.386539999999997	54.361603000000002	0103000020E61000000100000005000000D7A205685BA552405891D101492E4B40D7A205685BA55240444C89247A314B40D4484BE5EDA75240444C89247A314B40D4484BE5EDA752405891D101492E4B40D7A205685BA552405891D101492E4B40
31747	Северное	5	53	1788	74.754681000000005	74.772979000000007	54.510829999999999	54.499761999999997	0103000020E61000000100000005000000687A89B14CB052404BE48233F83F4B40687A89B14CB0524068E89FE062414B40AB5FE97C78B1524068E89FE062414B40AB5FE97C78B152404BE48233F83F4B40687A89B14CB052404BE48233F83F4B40
30565	Путь Ленина	5	53	1788	74.795706999999993	74.812415999999999	54.253757	54.244204000000003	0103000020E61000000100000005000000B08C0DDDECB25240B5C6A013421F4B40B08C0DDDECB25240C710001C7B204B40D1AFAD9FFEB35240C710001C7B204B40D1AFAD9FFEB35240B5C6A013421F4B40B08C0DDDECB25240B5C6A013421F4B40
52437	Пробуждение (отд. №3 свх. Елизаветинский)	5	53	1788	74.880399999999995	74.892042000000004	54.339593999999998	54.329194999999999	0103000020E610000001000000050000007FD93D7958B85240DC80CF0F232A4B407FD93D7958B852407BF5F1D0772B4B40242A543717B952407BF5F1D0772B4B40242A543717B95240DC80CF0F232A4B407FD93D7958B85240DC80CF0F232A4B40
31684	Привольное (отд. №2 свх. Коммунист)	5	53	1788	74.752838999999994	74.770132000000004	54.418923999999997	54.412447999999998	0103000020E61000000100000005000000D009A1832EB052407AA69718CB344B40D009A1832EB0524037C1374D9F354B409966BAD749B1524037C1374D9F354B409966BAD749B152407AA69718CB344B40D009A1832EB052407AA69718CB344B40
31437	Преображенка	5	53	1788	75.095843000000002	75.108321000000004	54.320405000000001	54.307367999999997	0103000020E610000001000000050000003CA3AD4A22C6524020EBA9D557274B403CA3AD4A22C65240C93CF20703294B40151E34BBEEC65240C93CF20703294B40151E34BBEEC6524020EBA9D557274B403CA3AD4A22C6524020EBA9D557274B40
31833	Подлесное (отд. №5 свх. Коммунист)	5	53	1788	74.667552999999998	74.680597000000006	54.356817999999997	54.352232000000001	0103000020E6100000010000000500000030D63730B9AA5240664D2CF0152D4B4030D63730B9AA5240E34F5436AC2D4B405E30B8E68EAB5240E34F5436AC2D4B405E30B8E68EAB5240664D2CF0152D4B4030D63730B9AA5240664D2CF0152D4B40
31364	Погранично-Григорьевка	5	53	1788	75.284632999999999	75.298584000000005	54.106872000000003	54.100653999999999	0103000020E610000001000000050000003197546D37D25240151BF33AE20C4B403197546D37D25240D76D50FBAD0D4B40F8C610001CD35240D76D50FBAD0D4B40F8C610001CD35240151BF33AE20C4B403197546D37D25240151BF33AE20C4B40
30446	Первый Шаг	5	53	1788	75.251897999999997	75.258869000000004	54.071109	54.062950999999998	0103000020E6100000010000000500000061FBC9181FD05240102043C70E084B4061FBC9181FD05240C3B986191A094B40B03C484F91D05240C3B986191A094B40B03C484F91D05240102043C70E084B4061FBC9181FD05240102043C70E084B40
31985	Ольховка	5	53	1788	75.048951000000002	75.061059999999998	53.888499000000003	53.879593999999997	0103000020E61000000100000005000000D106600322C3524000E1438996F04A40D106600322C35240ADC3D155BAF14A4000C63368E8C35240ADC3D155BAF14A4000C63368E8C3524000E1438996F04A40D106600322C3524000E1438996F04A40
31536	Ольговка	5	53	1788	74.983481999999995	75.010135000000005	54.362557000000002	54.354205	0103000020E61000000100000005000000198D7C5EF1BE5240338AE596562D4B40198D7C5EF1BE5240CBF78C44682E4B40E162450DA6C05240CBF78C44682E4B40E162450DA6C05240338AE596562D4B40198D7C5EF1BE5240338AE596562D4B40
31413	Николаевка	5	53	1788	75.005257	75.030103999999994	54.267240999999999	54.253630999999999	0103000020E61000000100000005000000CEC4742156C052403A2009FB76204B40CEC4742156C052403E93FDF334224B40A4DE5339EDC152403E93FDF334224B40A4DE5339EDC152403A2009FB76204B40CEC4742156C052403A2009FB76204B40
60230	Народно-Степное	5	53	1788	75.115264999999994	75.132493999999994	53.911338000000001	53.897832999999999	0103000020E61000000100000005000000E657738060C7524081221631ECF24A40E657738060C7524010CD3CB9A6F44A40A33A1DC87AC8524010CD3CB9A6F44A40A33A1DC87AC8524081221631ECF24A40E657738060C7524081221631ECF24A40
60181	Народно-Береговое	5	53	1788	75.066890000000001	75.083445999999995	53.926774999999999	53.911518999999998	0103000020E610000001000000050000007C9BFEEC47C45240605793A7ACF44A407C9BFEEC47C452400DE02D90A0F64A40D93EE42D57C552400DE02D90A0F64A40D93EE42D57C55240605793A7ACF44A407C9BFEEC47C45240605793A7ACF44A40
31074	Михайловка	5	53	1788	75.242457000000002	75.255257999999998	54.154559999999996	54.142547	0103000020E61000000100000005000000EC6B5D6A84CF52404B92E7FA3E124B40EC6B5D6A84CF524087A2409FC8134B40B682A62556D0524087A2409FC8134B40B682A62556D052404B92E7FA3E124B40EC6B5D6A84CF52404B92E7FA3E124B40
31257	Медет	5	53	1788	75.531418000000002	75.551845999999998	54.190688000000002	54.178353999999999	0103000020E610000001000000050000005EA0A4C002E252402E8ECA4DD4164B405EA0A4C002E25240ADDEE17668184B406B9BE27151E35240ADDEE17668184B406B9BE27151E352402E8ECA4DD4164B405EA0A4C002E252402E8ECA4DD4164B40
26047	Малый Атмас	5	53	1788	74.929312999999993	74.945922999999993	53.998150000000003	53.988621999999999	0103000020E61000000100000005000000D9AF3BDD79BB5240950D6B2A8BFE4A40D9AF3BDD79BB52404F401361C3FF4A4030629F008ABC52404F401361C3FF4A4030629F008ABC5240950D6B2A8BFE4A40D9AF3BDD79BB5240950D6B2A8BFE4A40
32183	Макаркино	5	53	1788	74.926186999999999	74.943201000000002	54.446544000000003	54.440890000000003	0103000020E61000000100000005000000BEBED6A546BB5240159161156F384B40BEBED6A546BB5240CE1C925A28394B407D23BA675DBC5240CE1C925A28394B407D23BA675DBC5240159161156F384B40BEBED6A546BB5240159161156F384B40
31080	Лесная База	5	53	1788	74.956721000000002	74.973204999999993	54.147689	54.140796000000002	0103000020E610000001000000050000005F99B7EA3ABD52402DB4739A05124B405F99B7EA3ABD52404E7D2079E7124B406FD39FFD48BE52404E7D2079E7124B406FD39FFD48BE52402DB4739A05124B405F99B7EA3ABD52402DB4739A05124B40
32055	Кузнецовка	5	53	1788	75.308672000000001	75.335361000000006	53.980172000000003	53.96895	0103000020E61000000100000005000000384C3448C1D35240C7BAB88D06FC4A40384C3448C1D352403B3AAE4676FD4A40A6D6FB8D76D552403B3AAE4676FD4A40A6D6FB8D76D55240C7BAB88D06FC4A40384C3448C1D35240C7BAB88D06FC4A40
30853	Крупское	5	53	1788	74.480542	74.497179000000003	54.467930000000003	54.464021000000002	0103000020E61000000100000005000000AF963B33C19E524020D4450A653B4B40AF963B33C19E52409D685721E53B4B408350DEC7D19F52409D685721E53B4B408350DEC7D19F524020D4450A653B4B40AF963B33C19E524020D4450A653B4B40
30946	Красный Октябрь	5	53	1788	74.997639000000007	75.030455000000003	54.139519	54.128388000000001	0103000020E61000000100000005000000B58D3F51D9BF524074999A046F104B40B58D3F51D9BF5240D71533C2DB114B40FB3F87F9F2C15240D71533C2DB114B40FB3F87F9F2C1524074999A046F104B40B58D3F51D9BF524074999A046F104B40
30902	Красный Овцевод	5	53	1788	74.446882000000002	74.463115000000002	54.584958999999998	54.572921000000001	0103000020E61000000100000005000000F3CAF5B6999C52408718AF7955494B40F3CAF5B6999C52401C40BFEFDF4A4B405FD218ADA39D52401C40BFEFDF4A4B405FD218ADA39D52408718AF7955494B40F3CAF5B6999C52408718AF7955494B40
31277	Козинка	5	53	1788	75.408088000000006	75.414664000000002	54.143338	54.134329000000001	0103000020E61000000100000005000000F778211D1EDA5240C3F352B131114B40F778211D1EDA524014234BE658124B4007B5DFDA89DA524014234BE658124B4007B5DFDA89DA5240C3F352B131114B40F778211D1EDA5240C3F352B131114B40
30714	Иртыш	5	53	1788	74.349818999999997	74.394994999999994	54.504452000000001	54.478330999999997	0103000020E610000001000000050000003E213B6F63965240DCD440F3393D4B403E213B6F639652406E3315E291404B4058C51B99479952406E3315E291404B4058C51B9947995240DCD440F3393D4B403E213B6F63965240DCD440F3393D4B40
32219	Золотухино	5	53	1788	74.788763000000003	74.799066999999994	54.438454999999998	54.424964000000003	0103000020E61000000100000005000000DF52CE177BB252401AFD683865364B40DF52CE177BB2524043E21E4B1F384B400514EAE923B3524043E21E4B1F384B400514EAE923B352401AFD683865364B40DF52CE177BB252401AFD683865364B40
60069	Елизаветинка	5	53	1788	74.667167000000006	74.692409999999995	54.266137000000001	54.24897	0103000020E610000001000000050000001C7E37DDB2AA5240B2D7BB3FDE1F4B401C7E37DDB2AA5240B6A0F7C610224B40185B087250AC5240B6A0F7C610224B40185B087250AC5240B2D7BB3FDE1F4B401C7E37DDB2AA5240B2D7BB3FDE1F4B40
31159	Джартаргуль	5	53	1788	75.565464000000006	75.580071000000004	54.383819000000003	54.374364999999997	0103000020E610000001000000050000002FC4EA8F30E452402EE23B31EB2F4B402FC4EA8F30E45240AE4A22FB20314B40EA961DE21FE55240AE4A22FB20314B40EA961DE21FE552402EE23B31EB2F4B402FC4EA8F30E452402EE23B31EB2F4B40
30654	Гринск	5	53	1788	74.645949000000002	74.655182999999994	54.322195000000001	54.303933000000001	0103000020E610000001000000050000009278793A57A952406C96CB46E7264B409278793A57A95240A5F78DAF3D294B404A79AD84EEA95240A5F78DAF3D294B404A79AD84EEA952406C96CB46E7264B409278793A57A952406C96CB46E7264B40
30804	Верхнеильинка	5	53	1788	74.272321000000005	74.294248999999994	54.547418	54.536110000000001	0103000020E61000000100000005000000E6400FB56D9152407F87A2409F444B40E6400FB56D915240F19E03CB11464B405DF8C1F9D4925240F19E03CB11464B405DF8C1F9D49252407F87A2409F444B40E6400FB56D9152407F87A2409F444B40
50013	Васьковка	5	53	1788	74.997782999999998	75.008804999999995	54.447485999999998	54.438077999999997	0103000020E610000001000000050000004E603AADDBBF52406D8C9DF012384B404E603AADDBBF52407CB5A33847394B40A4C2D84290C052407CB5A33847394B40A4C2D84290C052406D8C9DF012384B404E603AADDBBF52406D8C9DF012384B40
30739	Бердниково	5	53	1788	74.417642000000001	74.440190000000001	54.423910999999997	54.410462000000003	0103000020E61000000100000005000000E8DB82A5BA9A52401920D1048A344B40E8DB82A5BA9A524013B534B742364B40AE81AD122C9C524013B534B742364B40AE81AD122C9C52401920D1048A344B40E8DB82A5BA9A52401920D1048A344B40
36928	Чапаево	5	53	4673	129.37662499999999	129.42210700000001	61.666846	61.650632999999999	0103000020E61000000100000005000000643BDF4F0D2C6040645930F147D34E40643BDF4F0D2C6040F5BBB0355BD54E40350D8AE6812D6040F5BBB0355BD54E40350D8AE6812D6040645930F147D34E40643BDF4F0D2C6040645930F147D34E40
53101	Ярково	5	53	1443	71.450425999999993	71.468103999999997	57.656844999999997	57.647010999999999	0103000020E6100000010000000500000028D192C7D3DC51407D93A641D1D24C4028D192C7D3DC514043C5387F13D44C401DC87A6AF5DD514043C5387F13D44C401DC87A6AF5DD51407D93A641D1D24C4028D192C7D3DC51407D93A641D1D24C40
60825	Южный	5	53	1443	71.179269000000005	71.194773999999995	57.661934000000002	57.659039999999997	0103000020E61000000100000005000000F20BAF2479CB5140BF60376C5BD44C40F20BAF2479CB5140240ED940BAD44C401C075E2D77CC5140240ED940BAD44C401C075E2D77CC5140BF60376C5BD44C40F20BAF2479CB5140BF60376C5BD44C40
60845	Эбаргуль	5	53	1443	71.375829999999993	71.393967000000004	57.697971000000003	57.686045999999997	0103000020E61000000100000005000000C3B645990DD851409BC6F65AD0D74C40C3B645990DD8514039471D1D57D94C40022D5DC136D9514039471D1D57D94C40022D5DC136D951409BC6F65AD0D74C40C3B645990DD851409BC6F65AD0D74C40
60131	Утускун	5	53	1443	71.314770999999993	71.338522999999995	57.741449000000003	57.732315	0103000020E61000000100000005000000ABAE433525D4514064AF777FBCDD4C40ABAE433525D45140725303CDE7DE4C40677C5F5CAAD55140725303CDE7DE4C40677C5F5CAAD5514064AF777FBCDD4C40ABAE433525D4514064AF777FBCDD4C40
52408	Усть-Ишим	5	53	1443	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
60228	Слободчики	5	53	1443	70.909873000000005	70.942096000000006	57.505350999999997	57.497231999999997	0103000020E61000000100000005000000DCA0F65B3BBA51402843554CA5BF4C40DCA0F65B3BBA51401D007157AFC04C40516C054D4BBC51401D007157AFC04C40516C054D4BBC51402843554CA5BF4C40DCA0F65B3BBA51402843554CA5BF4C40
53103	Скородум	5	53	1443	70.881243999999995	70.944305999999997	57.805748999999999	57.792650999999999	0103000020E61000000100000005000000F5F23B4D66B851402312859675E54C40F5F23B4D66B8514071E481C822E74C40A9DA6E826FBC514071E481C822E74C40A9DA6E826FBC51402312859675E54C40F5F23B4D66B851402312859675E54C40
52391	Саургачи	5	53	1443	70.687055000000001	70.705748999999997	57.770668999999998	57.762109000000002	0103000020E6100000010000000500000069E388B5F8AB51405F7EA7C98CE14C4069E388B5F8AB514040852348A5E24C40D28BDAFD2AAD514040852348A5E24C40D28BDAFD2AAD51405F7EA7C98CE14C4069E388B5F8AB51405F7EA7C98CE14C40
60835	Паново	5	53	1443	70.814948000000001	70.842509000000007	57.799264999999998	57.791547000000001	0103000020E6100000010000000500000033FCA71B28B451409B1F7F6951E54C4033FCA71B28B4514031EBC5504EE64C407C65DEAAEBB5514031EBC5504EE64C407C65DEAAEBB551409B1F7F6951E54C4033FCA71B28B451409B1F7F6951E54C40
52403	Орехово	5	53	1443	70.822035999999997	70.870266999999998	57.458849000000001	57.451484999999998	0103000020E610000001000000050000009E08E23C9CB4514039D1AE42CAB94C409E08E23C9CB45140B2666490BBBA4C406FF25B74B2B75140B2666490BBBA4C406FF25B74B2B7514039D1AE42CAB94C409E08E23C9CB4514039D1AE42CAB94C40
52993	Никольск	5	53	1443	71.163664999999995	71.179412999999997	57.747543999999998	57.733910999999999	0103000020E61000000100000005000000FD9FC37C79CA51405B96AFCBF0DD4C40FD9FC37C79CA514017299485AFDF4C408BDEA9807BCB514017299485AFDF4C408BDEA9807BCB51405B96AFCBF0DD4C40FD9FC37C79CA51405B96AFCBF0DD4C40
53125	Малая Бича	5	53	1443	70.441248999999999	70.470849000000001	57.953428000000002	57.93065	0103000020E610000001000000050000002219726C3D9C5140DE02098A1FF74C402219726C3D9C51409C8BBFED09FA4C40AD16D863229E51409C8BBFED09FA4C40AD16D863229E5140DE02098A1FF74C402219726C3D9C5140DE02098A1FF74C40
30014	Летние	5	53	1443	71.229197999999997	71.249561999999997	57.683996999999998	57.677424000000002	0103000020E61000000100000005000000C093162EABCE514044C362D4B5D64C40C093162EABCE5140F3C7B4368DD74C40C214E5D2F8CF5140F3C7B4368DD74C40C214E5D2F8CF514044C362D4B5D64C40C093162EABCE514044C362D4B5D64C40
47930	Красноярка	5	53	1443	71.253111000000004	71.269621999999998	57.736533999999999	57.729120000000002	0103000020E6100000010000000500000081D07AF832D05140056EDDCD53DD4C4081D07AF832D051402F3201BF46DE4C400E12A27C41D151402F3201BF46DE4C400E12A27C41D15140056EDDCD53DD4C4081D07AF832D05140056EDDCD53DD4C40
28578	Кайнаул	5	53	1443	70.420102999999997	70.439507000000006	57.922778999999998	57.91601	0103000020E61000000100000005000000E57CB1F7E29A51408C67D0D03FF54C40E57CB1F7E29A5140C1374D9F1DF64C403DD7F7E1209C5140C1374D9F1DF64C403DD7F7E1209C51408C67D0D03FF54C40E57CB1F7E29A51408C67D0D03FF54C40
51912	Кайлы	5	53	1443	70.682671999999997	70.697961000000006	57.297187000000001	57.286760000000001	0103000020E610000001000000050000004679E6E5B0AB514086E63A8DB4A44C404679E6E5B0AB5140EFE53E390AA64C408B389D64ABAC5140EFE53E390AA64C408B389D64ABAC514086E63A8DB4A44C404679E6E5B0AB514086E63A8DB4A44C40
52413	Ильчебага	5	53	1443	71.534571	71.560271999999998	57.621608999999999	57.613405	0103000020E61000000100000005000000F698486936E25140F819170E84CE4C40F698486936E251401BF33AE290CF4C405437177FDBE351401BF33AE290CF4C405437177FDBE35140F819170E84CE4C40F698486936E25140F819170E84CE4C40
30336	Затон	5	53	1443	70.908382000000003	70.917778999999996	57.754057000000003	57.748672999999997	0103000020E610000001000000050000009B9141EE22BA5140F8325184D4DF4C409B9141EE22BA5140F22895F084E04C40287D21E4BCBA5140F22895F084E04C40287D21E4BCBA5140F8325184D4DF4C409B9141EE22BA5140F8325184D4DF4C40
53122	Загваздино	5	53	1443	70.545435999999995	70.583408000000006	57.823717000000002	57.808947000000003	0103000020E61000000100000005000000E883656CE8A25140429946938BE74C40E883656CE8A251406214048F6FE94C40630E828E56A551406214048F6FE94C40630E828E56A55140429946938BE74C40E883656CE8A25140429946938BE74C40
60226	Борки	5	53	1443	70.849982999999995	70.863151999999999	57.795692000000003	57.787109999999998	0103000020E61000000100000005000000FBC9181F66B65140622D3E05C0E44C40FBC9181F66B651402CD8463CD9E54C4087DEE2E13DB751402CD8463CD9E54C4087DEE2E13DB75140622D3E05C0E44C40FBC9181F66B65140622D3E05C0E44C40
52389	Большая Тебендя	5	53	1443	70.831388000000004	70.845158999999995	57.734400999999998	57.726312999999998	0103000020E610000001000000050000005C92037635B551406FD40AD3F7DC4C405C92037635B5514029931ADA00DE4C40E23AC61517B6514029931ADA00DE4C40E23AC61517B651406FD40AD3F7DC4C405C92037635B551406FD40AD3F7DC4C40
60840	Большая Тава	5	53	1443	71.188170999999997	71.208850999999996	57.504897	57.491219999999998	0103000020E610000001000000050000008FC360FE0ACC51401092054CE0BE4C408FC360FE0ACC51409C6C0377A0C04C4029AF95D05DCD51409C6C0377A0C04C4029AF95D05DCD51401092054CE0BE4C408FC360FE0ACC51401092054CE0BE4C40
52381	Большая Бича	5	53	1443	70.602928000000006	70.635347999999993	57.881210000000003	57.864615999999998	0103000020E61000000100000005000000EF75525F96A6514096CCB1BCABEE4C40EF75525F96A651403F74417DCBF04C400E65A88AA9A851403F74417DCBF04C400E65A88AA9A8514096CCB1BCABEE4C40EF75525F96A6514096CCB1BCABEE4C40
53043	Бакшеева	5	53	1443	70.487628999999998	70.502073999999993	57.917214999999999	57.910927999999998	0103000020E6100000010000000500000032E54350359F51405E81E84999F44C4032E54350359F51404833164D67F54C40008BFCFA21A051404833164D67F54C40008BFCFA21A051405E81E84999F44C4032E54350359F51405E81E84999F44C40
60843	Ашеваны	5	53	1443	71.184875000000005	71.196607	57.642178999999999	57.628332	0103000020E6100000010000000500000046B6F3FDD4CB5140E083D72E6DD04C4046B6F3FDD4CB5140C896E5EB32D24C408ACA863595CC5140C896E5EB32D24C408ACA863595CC5140E083D72E6DD04C4046B6F3FDD4CB5140E083D72E6DD04C40
16296	Аксёново	5	53	1443	71.478533999999996	71.526045999999994	57.700279999999999	57.677703000000001	0103000020E610000001000000050000008A01124DA0DE514057B3CEF8BED64C408A01124DA0DE51407D0569C6A2D94C40438CD7BCAAE151407D0569C6A2D94C40438CD7BCAAE1514057B3CEF8BED64C408A01124DA0DE514057B3CEF8BED64C40
26358	Ярославка	5	53	447	71.841031000000001	71.868313000000001	55.998745	55.983006000000003	0103000020E6100000010000000500000005FBAF73D3F55140CAE2FE23D3FD4B4005FBAF73D3F5514092054CE0D6FF4B40446CB07092F7514092054CE0D6FF4B40446CB07092F75140CAE2FE23D3FD4B4005FBAF73D3F55140CAE2FE23D3FD4B40
60824	Чистое	5	53	447	72.647422000000006	72.651904000000002	55.925758000000002	55.923406999999997	0103000020E61000000100000005000000802DAF5C6F295240E0F2583332F64B40802DAF5C6F2952405401F73C7FF64B406C088ECBB82952405401F73C7FF64B406C088ECBB8295240E0F2583332F64B40802DAF5C6F295240E0F2583332F64B40
26858	Черноусово	5	53	447	72.058423000000005	72.067504999999997	55.727283	55.719692999999999	0103000020E610000001000000050000006495D233BD0352407F1475E61EDC4B406495D233BD035240E8F7FD9B17DD4B4041D47D0052045240E8F7FD9B17DD4B4041D47D00520452407F1475E61EDC4B406495D233BD0352407F1475E61EDC4B40
26318	Чащино	5	53	447	72.160813000000005	72.174251999999996	55.940714	55.931713999999999	0103000020E6100000010000000500000063F19BC24A0A5240D89C836742F74B4063F19BC24A0A5240D671FC5069F84B40CE50DCF1260B5240D671FC5069F84B40CE50DCF1260B5240D89C836742F74B4063F19BC24A0A5240D89C836742F74B40
28309	Хутора	5	53	447	72.180289000000002	72.206402999999995	56.232999	56.218525999999997	0103000020E6100000010000000500000007B5DFDA890B5240B0A9F3A8F81B4C4007B5DFDA890B5240178046E9D21D4C40F6B2EDB4350D5240178046E9D21D4C40F6B2EDB4350D5240B0A9F3A8F81B4C4007B5DFDA890B5240B0A9F3A8F81B4C40
59474	Тюкалинское городское поселение	5	53	447	71.730197000000004	73.276996999999994	56.489198000000002	55.457199000000003	0103000020E61000000100000005000000CAA8328CBBEE5140C861307F85BA4B40CAA8328CBBEE514062A2410A9E3E4C40C405A051BA51524062A2410A9E3E4C40C405A051BA515240C861307F85BA4B40CAA8328CBBEE5140C861307F85BA4B40
25792	Тюкалинск	5	53	447	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
28178	Троицк	5	53	447	72.216707	72.247510000000005	55.706116999999999	55.697392000000001	0103000020E610000001000000050000001D740987DE0D5240FB3E1C2444D94B401D740987DE0D52402713B70A62DA4B40B6DB2E34D70F52402713B70A62DA4B40B6DB2E34D70F5240FB3E1C2444D94B401D740987DE0D5240FB3E1C2444D94B40
27909	Старый Конкуль	5	53	447	72.059518999999995	72.079884000000007	56.101408999999997	56.094289000000003	0103000020E61000000100000005000000669FC728CF035240B0AF75A9110C4C40669FC728CF035240914259F8FA0C4C4051DEC7D11C055240914259F8FA0C4C4051DEC7D11C055240B0AF75A9110C4C40669FC728CF035240B0AF75A9110C4C40
28096	Старосолдатское	5	53	447	72.587593999999996	72.645149000000004	56.209640999999998	56.187210999999998	0103000020E61000000100000005000000DA54DD239B255240C939B187F6174C40DA54DD239B2552404B732B84D51A4C400403081F4A2952404B732B84D51A4C400403081F4A295240C939B187F6174C40DA54DD239B255240C939B187F6174C40
28451	Соколовка	5	53	447	72.216247999999993	72.232741000000004	56.130702999999997	56.119624000000002	0103000020E61000000100000005000000D3F4D901D70D52408AE8D7D64F0F4C40D3F4D901D70D52409A3E3BE0BA104C400EDC813AE50E52409A3E3BE0BA104C400EDC813AE50E52408AE8D7D64F0F4C40D3F4D901D70D52408AE8D7D64F0F4C40
46772	Сергеевка	5	53	447	72.377414999999999	72.393000999999998	55.752136	55.742584999999998	0103000020E6100000010000000500000045813E912718524005C078060DDF4B4045813E9127185240771211FE45E04B40E692AAED26195240771211FE45E04B40E692AAED2619524005C078060DDF4B4045813E912718524005C078060DDF4B40
27062	Сарыбалы	5	53	447	72.405910000000006	72.431880000000007	56.270811000000002	56.263776999999997	0103000020E61000000100000005000000A4C7EF6DFA195240EF37DA71C3214C40A4C7EF6DFA195240D33252EFA9224C40FAF202ECA31B5240D33252EFA9224C40FAF202ECA31B5240EF37DA71C3214C40A4C7EF6DFA195240EF37DA71C3214C40
28006	Сажино	5	53	447	72.369708000000003	72.401866999999996	55.897689999999997	55.883701000000002	0103000020E610000001000000050000007444BE4BA9175240A438471D1DF14B407444BE4BA91752401EF98381E7F24B40DD955D30B81952401EF98381E7F24B40DD955D30B8195240A438471D1DF14B407444BE4BA9175240A438471D1DF14B40
26710	Приозёрка	5	53	447	72.576984999999993	72.594745000000003	56.109647000000002	56.105400000000003	0103000020E6100000010000000500000015527E52ED245240CC7F48BF7D0D4C4015527E52ED245240618DB3E9080E4C40691D554D10265240618DB3E9080E4C40691D554D10265240CC7F48BF7D0D4C4015527E52ED245240CC7F48BF7D0D4C40
27240	Охотниково	5	53	447	72.789769000000007	72.814184999999995	55.946430999999997	55.935864000000002	0103000020E61000000100000005000000429946938B3252407BC03C64CAF74B40429946938B325240D575A8A624F94B4033F9669B1B345240D575A8A624F94B4033F9669B1B3452407BC03C64CAF74B40429946938B3252407BC03C64CAF74B40
28394	Островная	5	53	447	72.131366999999997	72.155828	56.353006000000001	56.343373999999997	0103000020E610000001000000050000008331225168085240FA25E2ADF32B4C40833122516808524059A5F44C2F2D4C4045F30016F909524059A5F44C2F2D4C4045F30016F9095240FA25E2ADF32B4C408331225168085240FA25E2ADF32B4C40
52378	Орлово-Кукушкино	5	53	447	72.182804000000004	72.207068000000007	55.765149000000001	55.757241999999998	0103000020E61000000100000005000000FE648C0FB30B52402D944C4EEDE04B40FE648C0FB30B524097C80567F0E14B401503249A400D524097C80567F0E14B401503249A400D52402D944C4EEDE04B40FE648C0FB30B52402D944C4EEDE04B40
27628	Орловка	5	53	447	72.728306000000003	72.738628000000006	55.904280999999997	55.893596000000002	0103000020E61000000100000005000000C2DEC4909C2E524010EB8D5A61F24B40C2DEC4909C2E524074B2D47ABFF34B403CFA5FAE452F524074B2D47ABFF34B403CFA5FAE452F524010EB8D5A61F24B40C2DEC4909C2E524010EB8D5A61F24B40
27968	Октябрьский	5	53	447	72.206906000000004	72.229382000000001	55.826492999999999	55.810299000000001	0103000020E6100000010000000500000028D6A9F23D0D5240A27DACE0B7E74B4028D6A9F23D0D5240BCAFCA85CAE94B40A112D731AE0E5240BCAFCA85CAE94B40A112D731AE0E5240A27DACE0B7E74B4028D6A9F23D0D5240A27DACE0B7E74B40
26565	Оброскино	5	53	447	72.659189999999995	72.665649000000002	55.551226999999997	55.547671999999999	0103000020E610000001000000050000006AF6402B302A5240AB77B81D1AC64B406AF6402B302A52400AD6389B8EC64B405E6743FE992A52400AD6389B8EC64B405E6743FE992A5240AB77B81D1AC64B406AF6402B302A5240AB77B81D1AC64B40
27786	Новый Кошкуль	5	53	447	72.326436000000001	72.352478000000005	55.999822999999999	55.984485999999997	0103000020E610000001000000050000002C0FD253E414524057AF22A303FE4B402C0FD253E4145240F1643733FAFF4B40CFA3E2FF8E165240F1643733FAFF4B40CFA3E2FF8E16524057AF22A303FE4B402C0FD253E414524057AF22A303FE4B40
27870	Новый Конкуль	5	53	447	72.078034000000002	72.099305999999999	56.087484000000003	56.083320000000001	0103000020E61000000100000005000000787E5182FE045240268DD13AAA0A4C40787E5182FE0452402E76FBAC320B4C40FB928D075B0652402E76FBAC320B4C40FB928D075B065240268DD13AAA0A4C40787E5182FE045240268DD13AAA0A4C40
27532	Нагибино	5	53	447	72.691287000000003	72.725269999999995	55.774720000000002	55.753270999999998	0103000020E610000001000000050000009949D40B3E2C52403A03232F6BE04B409949D40B3E2C524050C763062AE34B4046B1DCD26A2E524050C763062AE34B4046B1DCD26A2E52403A03232F6BE04B409949D40B3E2C52403A03232F6BE04B40
27405	Малиновка	5	53	447	72.513814999999994	72.546989999999994	55.648747999999998	55.637163999999999	0103000020E610000001000000050000006E4C4F58E2205240221807978ED14B406E4C4F58E220524036ACA92C0AD34B404C4F58E20123524036ACA92C0AD34B404C4F58E201235240221807978ED14B406E4C4F58E2205240221807978ED14B40
26510	Максимовка	5	53	447	72.686705000000003	72.717687999999995	55.647416999999997	55.637824999999999	0103000020E61000000100000005000000FB3F87F9F22B52401DC9E53FA4D14B40FB3F87F9F22B5240EDEF6C8FDED24B40D32EA699EE2D5240EDEF6C8FDED24B40D32EA699EE2D52401DC9E53FA4D14B40FB3F87F9F22B52401DC9E53FA4D14B40
32502	Луговая (Николаевка)	5	53	447	72.135947999999999	72.157148000000007	56.194268000000001	56.184970999999997	0103000020E61000000100000005000000397D3D5FB3085240ADDA3521AD174C40397D3D5FB3085240655419C6DD184C4070287CB60E0A5240655419C6DD184C4070287CB60E0A5240ADDA3521AD174C40397D3D5FB3085240ADDA3521AD174C40
26828	Лидинка	5	53	447	71.915447999999998	71.930960999999996	55.663263000000001	55.657224999999997	0103000020E61000000100000005000000124C35B396FA51408A8EE4F21FD44B40124C35B396FA5140CCD24ECDE5D44B407E3672DD94FB5140CCD24ECDE5D44B407E3672DD94FB51408A8EE4F21FD44B40124C35B396FA51408A8EE4F21FD44B40
26256	Лаптево (Первомайский)	5	53	447	72.092173000000003	72.105423000000002	56.011589999999998	56.002234000000001	0103000020E61000000100000005000000C0249529E60552403A78263449004C40C0249529E6055240F67AF7C77B014C40C24F1C40BF065240F67AF7C77B014C40C24F1C40BF0652403A78263449004C40C0249529E60552403A78263449004C40
26980	Кумыра	5	53	447	72.314820999999995	72.324198999999993	56.206231000000002	56.194057999999998	0103000020E6100000010000000500000004C6FA06261452407AC37DE4D6184C4004C6FA0626145240F03504C7651A4C40569929ADBF145240F03504C7651A4C40569929ADBF1452407AC37DE4D6184C4004C6FA06261452407AC37DE4D6184C40
28053	Красный Шар	5	53	447	72.313885999999997	72.329920999999999	55.861868000000001	55.856229999999996	0103000020E61000000100000005000000062B4EB51614524052EDD3F198ED4B40062B4EB51614524006BCCCB051EE4B40DF50F86C1D15524006BCCCB051EE4B40DF50F86C1D15524052EDD3F198ED4B40062B4EB51614524052EDD3F198ED4B40
27257	Красноусово	5	53	447	72.005566999999999	72.036738	55.869996	55.853960999999998	0103000020E61000000100000005000000F5BBB0355B0052409C8713984EED4B40F5BBB0355B0052404ED367075CEF4B404F2157EA590252404ED367075CEF4B404F2157EA590252409C8713984EED4B40F5BBB0355B0052409C8713984EED4B40
27825	Кошкуль	5	53	447	72.371827999999994	72.386937000000003	56.019278999999997	56.014881000000003	0103000020E610000001000000050000002CEFAA07CC175240782AE09EE7014C402CEFAA07CC175240F23FF9BB77024C4031276893C3185240F23FF9BB77024C4031276893C3185240782AE09EE7014C402CEFAA07CC175240782AE09EE7014C40
27102	Коршуновка	5	53	447	72.860826000000003	72.891116999999994	56.011746000000002	55.998759999999997	0103000020E61000000100000005000000FA62EFC517375240C746205ED7FF4B40FA62EFC517375240EEED96E480014C4037FA980F08395240EEED96E480014C4037FA980F08395240C746205ED7FF4B40FA62EFC517375240C746205ED7FF4B40
3060	Короли	5	53	447	72.051362999999995	72.076075000000003	55.583199999999998	55.578783000000001	0103000020E610000001000000050000005D4E0988490352408A3DB48F15CA4B405D4E0988490352407B832F4CA6CA4B40C442AD69DE0452407B832F4CA6CA4B40C442AD69DE0452408A3DB48F15CA4B405D4E0988490352408A3DB48F15CA4B40
3176	Климино	5	53	447	71.931122999999999	71.945757	55.847543000000002	55.842534000000001	0103000020E610000001000000050000006B63EC8497FB514050E27327D8EB4B406B63EC8497FB5140147AFD497CEC4B40A33D5E4887FC5140147AFD497CEC4B40A33D5E4887FC514050E27327D8EB4B406B63EC8497FB514050E27327D8EB4B40
27525	Каспиль	5	53	447	72.478538999999998	72.498148999999998	55.765918999999997	55.754015000000003	0103000020E6100000010000000500000013B70A62A01E5240C3D8429083E04B4013B70A62A01E5240483140A209E24B403FE257ACE11F5240483140A209E24B403FE257ACE11F5240C3D8429083E04B4013B70A62A01E5240C3D8429083E04B40
28122	Карбаиново	5	53	447	72.733048999999994	72.745993999999996	56.194679000000001	56.183458000000002	0103000020E6100000010000000500000064575A46EA2E524044183F8D7B174C4064575A46EA2E5240E71BD13DEB184C40C8409E5DBE2F5240E71BD13DEB184C40C8409E5DBE2F524044183F8D7B174C4064575A46EA2E524044183F8D7B174C40
3119	Кабырдак	5	53	447	72.422780000000003	72.451813999999999	56.124115000000003	56.109560999999999	0103000020E61000000100000005000000C959D8D30E1B524062F54718060E4C40C959D8D30E1B5240B6F81400E30F4C40FF774485EA1C5240B6F81400E30F4C40FF774485EA1C524062F54718060E4C40C959D8D30E1B524062F54718060E4C40
27751	Ильинка	5	53	447	72.389955999999998	72.408721	55.643571000000001	55.636254999999998	0103000020E6100000010000000500000041B8020AF51852404F75C8CD70D14B4041B8020AF5185240B7D3D68860D24B400F0C207C281A5240B7D3D68860D24B400F0C207C281A52404F75C8CD70D14B4041B8020AF51852404F75C8CD70D14B40
26213	Зотино	5	53	447	72.172302999999999	72.191787000000005	55.990957000000002	55.985790000000001	0103000020E610000001000000050000002C802903070B5240A75CE15D2EFE4B402C802903070B5240035FD1ADD7FE4B401233FB3C460C5240035FD1ADD7FE4B401233FB3C460C5240A75CE15D2EFE4B402C802903070B5240A75CE15D2EFE4B40
27461	Залесная	5	53	447	72.566824999999994	72.583156000000002	55.670980999999998	55.665731000000001	0103000020E6100000010000000500000088635DDC46245240797764AC36D54B4088635DDC46245240629E95B4E2D54B40D61D8B6D52255240629E95B4E2D54B40D61D8B6D52255240797764AC36D54B4088635DDC46245240797764AC36D54B40
27178	Журавлёвка (Казанка)	5	53	447	72.932501999999999	72.944162000000006	56.048867000000001	56.041570999999998	0103000020E61000000100000005000000185DDE1CAE3B524023BBD23252054C40185DDE1CAE3B5240446D1B4641064C40100874266D3C5240446D1B4641064C40100874266D3C524023BBD23252054C40185DDE1CAE3B524023BBD23252054C40
2529	Гуровка	5	53	447	72.621837999999997	72.639660000000006	55.592953000000001	55.588293	0103000020E610000001000000050000003E5A9C31CC2752409DBB5D2F4DCB4B403E5A9C31CC275240558847E2E5CB4B40CD237F30F0285240558847E2E5CB4B40CD237F30F02852409DBB5D2F4DCB4B403E5A9C31CC2752409DBB5D2F4DCB4B40
27325	Вторая Пятилетка	5	53	447	72.147589999999994	72.163831999999999	55.862777000000001	55.851252000000002	0103000020E61000000100000005000000DDCD531D72095240CA5356D3F5EC4B40DDCD531D72095240D95E0B7A6FEE4B40738236397C0A5240D95E0B7A6FEE4B40738236397C0A5240CA5356D3F5EC4B40DDCD531D72095240CA5356D3F5EC4B40
26625	Восточный	5	53	447	72.606961999999996	72.619844000000001	55.997990000000001	55.989260000000002	0103000020E610000001000000050000008BFA2477D8265240D89E5912A0FE4B408BFA2477D826524016DEE522BEFF4B40CC272B86AB27524016DEE522BEFF4B40CC272B86AB275240D89E5912A0FE4B408BFA2477D8265240D89E5912A0FE4B40
2618	Валуевка	5	53	447	72.005296999999999	72.029740000000004	55.702692999999996	55.682270000000003	0103000020E6100000010000000500000015713AC9560052405E85949F54D74B4015713AC95600524066101FD8F1D94B4084D89942E701524066101FD8F1D94B4084D89942E70152405E85949F54D74B4015713AC9560052405E85949F54D74B40
2613	Белоглазово	5	53	447	72.649694999999994	72.685888000000006	56.057850000000002	56.047680999999997	0103000020E61000000100000005000000FB57569A94295240FED137691A064C40FB57569A942952406C09F9A067074C40022EC896E52B52406C09F9A067074C40022EC896E52B5240FED137691A064C40FB57569A94295240FED137691A064C40
26370	Бекишево	5	53	447	72.687647999999996	72.721829	55.588903000000002	55.573062	0103000020E610000001000000050000003ACAC16C022C5240494A7A185AC94B403ACAC16C022C524016C26A2C61CB4B407B134372322E524016C26A2C61CB4B407B134372322E5240494A7A185AC94B403ACAC16C022C5240494A7A185AC94B40
26182	Атрачи	5	53	447	72.002493999999999	72.044284000000005	55.961264	55.945982000000001	0103000020E61000000100000005000000EB1B98DC28005240664D2CF015F94B40EB1B98DC280052403C69E1B20AFB4B401CEF8E8CD50252403C69E1B20AFB4B401CEF8E8CD5025240664D2CF015F94B40EB1B98DC28005240664D2CF015F94B40
24600	Фёдоровка	5	53	1155	73.251780999999994	73.270636999999994	57.594347999999997	57.586219	0103000020E6100000010000000500000044300E2E1D5052409CA5643909CB4C4044300E2E1D505240B438639813CC4C409A05DA1D52515240B438639813CC4C409A05DA1D525152409CA5643909CB4C4044300E2E1D5052409CA5643909CB4C40
25581	Утьма	5	53	1155	71.743735000000001	71.771024999999995	57.585158	57.568171	0103000020E61000000100000005000000FF78AF5A99EF51408FC4CBD3B9C84C40FF78AF5A99EF5140137F1475E6CA4C407FD93D7958F15140137F1475E6CA4C407FD93D7958F151408FC4CBD3B9C84C40FF78AF5A99EF51408FC4CBD3B9C84C40
25468	Утузы	5	53	1155	72.244383999999997	72.275205	57.517417999999999	57.510665000000003	0103000020E610000001000000050000009AEAC9FCA30F52401E1B81785DC14C409AEAC9FCA30F52404D2EC6C03AC24C4086AC6EF59C1152404D2EC6C03AC24C4086AC6EF59C1152401E1B81785DC14C409AEAC9FCA30F52401E1B81785DC14C40
25681	Ураш	5	53	1155	71.619784999999993	71.635703000000007	57.615174000000003	57.602637999999999	0103000020E610000001000000050000004963B48EAAE75140D6A9F23D23CD4C404963B48EAAE75140BDAC8905BECE4C4006BEA25BAFE85140BDAC8905BECE4C4006BEA25BAFE85140D6A9F23D23CD4C404963B48EAAE75140D6A9F23D23CD4C40
24013	Тевриз	5	53	1155	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
24769	Ташетканы	5	53	1155	72.794548000000006	72.806557999999995	57.413480999999997	57.401622000000003	0103000020E610000001000000050000008BC6DADFD932524054AD855968B34C408BC6DADFD9325240394206F2ECB44C40F01472A59E335240394206F2ECB44C40F01472A59E33524054AD855968B34C408BC6DADFD932524054AD855968B34C40
25125	Тайчи	5	53	1155	73.194190000000006	73.214851999999993	57.333359999999999	57.323273	0103000020E6100000010000000500000075CDE49B6D4C52400457790261A94C4075CDE49B6D4C5240B4E55C8AABAA4C40BB5E9A22C04D5240B4E55C8AABAA4C40BB5E9A22C04D52400457790261A94C4075CDE49B6D4C52400457790261A94C40
25632	Тавинск	5	53	1155	71.695719999999994	71.714988000000005	57.595413999999998	57.586421999999999	0103000020E6100000010000000500000014CB2DAD86EC5140D4D347E00FCB4C4014CB2DAD86EC51404FCAA48636CC4C401442075DC2ED51404FCAA48636CC4C401442075DC2ED5140D4D347E00FCB4C4014CB2DAD86EC5140D4D347E00FCB4C40
25218	Поддол	5	53	1155	71.865232000000006	71.872480999999993	57.496985000000002	57.488129000000001	0103000020E61000000100000005000000F9DC09F65FF75140569DD5027BBE4C40F9DC09F65FF7514021CD58349DBF4C4068588CBAD6F7514021CD58349DBF4C4068588CBAD6F75140569DD5027BBE4C40F9DC09F65FF75140569DD5027BBE4C40
25445	Петрово	5	53	1155	72.049907000000005	72.094939999999994	57.531041999999999	57.521943	0103000020E61000000100000005000000DB3521AD3103524025B03907CFC24C40DB3521AD31035240B6662B2FF9C34C4043C5387F13065240B6662B2FF9C34C4043C5387F1306524025B03907CFC24C40DB3521AD3103524025B03907CFC24C40
25322	Петелино	5	53	1155	72.681773000000007	72.696533000000002	57.432952999999998	57.423372999999998	0103000020E61000000100000005000000EF92382BA22B52403481221631B64C40EF92382BA22B524040DAFF006BB74C406DE525FF932C524040DAFF006BB74C406DE525FF932C52403481221631B64C40EF92382BA22B52403481221631B64C40
24690	Нагорно-Аевск	5	53	1155	72.935781000000006	72.948365999999993	57.400807	57.391733000000002	0103000020E61000000100000005000000F7CDFDD5E33B5240CAE1934E24B24C40F7CDFDD5E33B52400281CEA44DB34C40DAA84E07B23C52400281CEA44DB34C40DAA84E07B23C5240CAE1934E24B24C40F7CDFDD5E33B5240CAE1934E24B24C40
53093	Малая Кулары	5	53	1155	71.965384999999998	71.981052000000005	57.540565000000001	57.536380999999999	0103000020E6100000010000000500000022C32ADEC8FD51400F99F221A8C44C4022C32ADEC8FD51405E2EE23B31C54C403AEB538EC9FE51405E2EE23B31C54C403AEB538EC9FE51400F99F221A8C44C4022C32ADEC8FD51400F99F221A8C44C40
24501	Кускуны	5	53	1155	72.448291999999995	72.460599000000002	57.528118999999997	57.511834999999998	0103000020E61000000100000005000000BDC3EDD0B01C52405DF92CCF83C14C40BDC3EDD0B01C5240B7B2446799C34C4080643A747A1D5240B7B2446799C34C4080643A747A1D52405DF92CCF83C14C40BDC3EDD0B01C52405DF92CCF83C14C40
25301	Кузнецово	5	53	1155	72.195363	72.235552999999996	57.586281999999997	57.579194000000001	0103000020E610000001000000050000004DF6CFD3800C52400C056C0723CA4C404DF6CFD3800C5240E21DE0490BCB4C4061DEE34C130F5240E21DE0490BCB4C4061DEE34C130F52400C056C0723CA4C404DF6CFD3800C52400C056C0723CA4C40
25202	Кипо-Кулары	5	53	1155	71.853319999999997	71.879334999999998	57.538265000000003	57.530506000000003	0103000020E6100000010000000500000074417DCB9CF65140782AE09EE7C34C4074417DCB9CF651406DCA15DEE5C44C409ACE4E0647F851406DCA15DEE5C44C409ACE4E0647F85140782AE09EE7C34C4074417DCB9CF65140782AE09EE7C34C40
25135	Кип	5	53	1155	71.82938	71.854021000000003	57.555947000000003	57.543956000000001	0103000020E6100000010000000500000037FDD98F14F55140433BA759A0C54C4037FDD98F14F5514098A7734529C74C403946B247A8F6514098A7734529C74C403946B247A8F65140433BA759A0C54C4037FDD98F14F55140433BA759A0C54C40
53037	Кайсы	5	53	1155	71.680062000000007	71.706562000000005	57.663300999999997	57.651124000000003	0103000020E610000001000000050000002750C42286EB514003D2FE0758D34C402750C42286EB5140B933130CE7D44C402BA6D24F38ED5140B933130CE7D44C402BA6D24F38ED514003D2FE0758D34C402750C42286EB514003D2FE0758D34C40
53102	Иванов-Мыс	5	53	1155	73.099947999999998	73.116747000000004	57.391863999999998	57.379778999999999	0103000020E610000001000000050000003DD34B8C65465240925A28999CB04C403DD34B8C65465240683D7C9928B24C40FEB968C878475240683D7C9928B24C40FEB968C878475240925A28999CB04C403DD34B8C65465240925A28999CB04C40
25016	Журавлёвка	5	53	1155	72.655264000000003	72.679571999999993	57.510182	57.493009999999998	0103000020E61000000100000005000000C18F6AD8EF295240EC4CA1F31ABF4C40C18F6AD8EF2952400281CEA44DC14C40BFD18E1B7E2B52400281CEA44DC14C40BFD18E1B7E2B5240EC4CA1F31ABF4C40C18F6AD8EF295240EC4CA1F31ABF4C40
24990	Ермиловка	5	53	1155	72.903081999999998	72.923573000000005	57.639437999999998	57.629604999999998	0103000020E61000000100000005000000CDE67118CC395240F4328AE596D04C40CDE67118CC395240EAE8B81AD9D14C40FE9DEDD11B3B5240EAE8B81AD9D14C40FE9DEDD11B3B5240F4328AE596D04C40CDE67118CC395240F4328AE596D04C40
24908	Екатериновка	5	53	1155	72.644133999999994	72.686758999999995	57.611992000000001	57.595534000000001	0103000020E61000000100000005000000770FD07D39295240FAD346753ACC4C40770FD07D39295240F2B4FCC055CE4C40F44E05DCF32B5240F2B4FCC055CE4C40F44E05DCF32B5240FAD346753ACC4C40770FD07D39295240FAD346753ACC4C40
10889	Бородинка	5	53	1155	72.944395999999998	72.976538000000005	57.471701000000003	57.457265999999997	0103000020E61000000100000005000000499EEBFB703C52404FC939B187BA4C40499EEBFB703C5240C93EC8B260BC4C4048533D997F3E5240C93EC8B260BC4C4048533D997F3E52404FC939B187BA4C40499EEBFB703C52404FC939B187BA4C40
24789	Белый Яр	5	53	1155	72.358658000000005	72.405523000000002	57.597000000000001	57.575304000000003	0103000020E61000000100000005000000B91CAF40F416524006A1BC8FA3C94C40B91CAF40F416524023DBF97E6ACC4C40A7B1BD16F419524023DBF97E6ACC4C40A7B1BD16F419524006A1BC8FA3C94C40B91CAF40F416524006A1BC8FA3C94C40
24675	Бакшеево	5	53	1155	72.982422	73.006316999999996	57.405554000000002	57.395327000000002	0103000020E61000000100000005000000BD378600E03E5240E71C3C139AB24C40BD378600E03E524089618731E9B34C402A1A6B7F6740524089618731E9B34C402A1A6B7F67405240E71C3C139AB24C40BD378600E03E5240E71C3C139AB24C40
25400	Байбы	5	53	1155	72.531377000000006	72.549002000000002	57.469262000000001	57.452047	0103000020E610000001000000050000002F36AD1402225240A1A014ADDCB94C402F36AD1402225240B6A0F7C610BC4C4012DC48D922235240B6A0F7C610BC4C4012DC48D922235240A1A014ADDCB94C402F36AD1402225240A1A014ADDCB94C40
24548	Александровка	5	53	1155	73.040812000000003	73.058014999999997	57.583233	57.577683999999998	0103000020E610000001000000050000003352EFA99C42524013B69F8CF1C94C403352EFA99C42524057790261A7CA4C405BEB8B84B643524057790261A7CA4C405BEB8B84B643524013B69F8CF1C94C403352EFA99C42524013B69F8CF1C94C40
60834	с.Екатерининское	5	53	873	73.533097999999995	75.847696999999997	58.574581000000002	56.506697000000003	0103000020E6100000010000000500000008E412471E6252409CFD8172DB404C4008E412471E62524095F3C5DE8B494D40B5FAEAAA40F6524095F3C5DE8B494D40B5FAEAAA40F652409CFD8172DB404C4008E412471E6252409CFD8172DB404C40
23494	Черняево	5	53	873	74.506727999999995	74.530246000000005	56.705810999999997	56.687618000000001	0103000020E61000000100000005000000EBFD463B6EA052400A12DBDD03584C40EBFD463B6EA052401A14CD03585A4C406E35EB8CEFA152401A14CD03585A4C406E35EB8CEFA152400A12DBDD03584C40EBFD463B6EA052400A12DBDD03584C40
22356	Чекрушево	5	53	873	74.261003000000002	74.280450999999999	56.923546999999999	56.909210000000002	0103000020E610000001000000050000001B4AED45B49052401C9947FE60744C401B4AED45B4905240D2A8C0C936764C405A48C0E8F2915240D2A8C0C936764C405A48C0E8F29152401C9947FE60744C401B4AED45B49052401C9947FE60744C40
60826	Фрунзе	5	53	873	74.501455000000007	74.517058000000006	56.830325000000002	56.820990999999999	0103000020E610000001000000050000009B5AB6D617A05240B9A7AB3B16694C409B5AB6D617A052408E06F016486A4C40A708707A17A152408E06F016486A4C40A708707A17A15240B9A7AB3B16694C409B5AB6D617A05240B9A7AB3B16694C40
23218	Усть-Тара	5	53	873	74.634585000000001	74.665011000000007	56.679920000000003	56.671478999999998	0103000020E610000001000000050000000F62670A9DA85240B3791C06F3554C400F62670A9DA85240BBF2599E07574C40BD1E4C8A8FAA5240BBF2599E07574C40BD1E4C8A8FAA5240B3791C06F3554C400F62670A9DA85240B3791C06F3554C40
22159	Тимирка	5	53	873	74.184583000000003	74.207076999999998	57.210641000000003	57.201749	0103000020E6100000010000000500000072193735D08B5240178046E9D2994C4072193735D08B52402F19C748F69A4C403EB0E3BF408D52402F19C748F69A4C403EB0E3BF408D5240178046E9D2994C4072193735D08B5240178046E9D2994C40
60829	Тимино	5	53	873	73.818897000000007	73.836404999999999	56.947173999999997	56.938488	0103000020E61000000100000005000000B972F6CE687452401FD8F15F20784C40B972F6CE687452408DCF64FF3C794C407F4DD6A8877552408DCF64FF3C794C407F4DD6A8877552401FD8F15F20784C40B972F6CE687452401FD8F15F20784C40
6562	Тара	5	53	873	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
22853	Соусканово	5	53	873	73.815914000000006	73.839702000000003	56.983832999999997	56.974905999999997	0103000020E610000001000000050000004F965AEF377452404B5645B8C97C4C404F965AEF37745240DFDC5F3DEE7D4C40B11875ADBD755240DFDC5F3DEE7D4C40B11875ADBD7552404B5645B8C97C4C404F965AEF377452404B5645B8C97C4C40
53008	Сидоровка	5	53	873	74.595742000000001	74.605462000000003	57.013331999999998	57.006573000000003	0103000020E61000000100000005000000A2B60DA320A65240B0045262D7804C40A2B60DA320A65240C1FEEBDCB4814C40213EB0E3BFA65240C1FEEBDCB4814C40213EB0E3BFA65240B0045262D7804C40A2B60DA320A65240B0045262D7804C40
46381	Сеитово	5	53	873	74.207426999999996	74.220965000000007	57.002156999999997	56.995660999999998	0103000020E61000000100000005000000AC53E57B468D52408A73D4D1717F4C40AC53E57B468D52408E3A3AAE46804C40E223624A248E52408E3A3AAE46804C40E223624A248E52408A73D4D1717F4C40AC53E57B468D52408A73D4D1717F4C40
60856	Себеляково	5	53	873	74.100447000000003	74.111119000000002	57.037685000000003	57.028300000000002	0103000020E61000000100000005000000CEFE40B96D865240083D9B559F834C40CEFE40B96D8652405F46B1DCD2844C40B6BDDD921C8752405F46B1DCD2844C40B6BDDD921C875240083D9B559F834C40CEFE40B96D865240083D9B559F834C40
40295	Самсоново	5	53	873	74.345416999999998	74.364884000000004	56.977148	56.968592000000001	0103000020E61000000100000005000000E09EE74F1B965240689599D2FA7B4C40E09EE74F1B96524008AD872F137D4C405BB56B425A97524008AD872F137D4C405BB56B425A975240689599D2FA7B4C40E09EE74F1B965240689599D2FA7B4C40
7130	Пятилетка	5	53	873	74.099772999999999	74.133225999999993	57.138764999999999	57.129392000000003	0103000020E6100000010000000500000086014BAE62865240992EC4EA8F904C4086014BAE628652402B6A300DC3914C40853E58C6868852402B6A300DC3914C40853E58C686885240992EC4EA8F904C4086014BAE62865240992EC4EA8F904C40
22056	Пологрудово	5	53	873	74.126784999999998	74.180693000000005	57.12838	57.108021999999998	0103000020E61000000100000005000000E527D53E1D885240CF9F36AAD38D4C40E527D53E1D885240F1BA7EC16E904C406F675F79908B5240F1BA7EC16E904C406F675F79908B5240CF9F36AAD38D4C40E527D53E1D885240CF9F36AAD38D4C40
21662	Пихтовое	5	53	873	74.474891999999997	74.491923999999997	57.470821000000001	57.462291999999998	0103000020E6100000010000000500000073486AA1649E5240E9995E622CBB4C4073486AA1649E524090A2CEDC43BC4C408507CDAE7B9F524090A2CEDC43BC4C408507CDAE7B9F5240E9995E622CBB4C4073486AA1649E5240E9995E622CBB4C40
53034	Петрово	5	53	873	74.163696999999999	74.187610000000006	56.960146999999999	56.952750000000002	0103000020E61000000100000005000000035DFB027A8A5240CBA145B6F3794C40035DFB027A8A52401F2DCE18E67A4C40C4995FCD018C52401F2DCE18E67A4C40C4995FCD018C5240CBA145B6F3794C40035DFB027A8A5240CBA145B6F3794C40
40456	Петровка	5	53	873	75.097369999999998	75.111474000000001	57.413214000000004	57.406906999999997	0103000020E610000001000000050000002367614F3BC65240B9C1508715B44C402367614F3BC65240EB1F4432E4B44C40AD16D86322C75240EB1F4432E4B44C40AD16D86322C75240B9C1508715B44C402367614F3BC65240B9C1508715B44C40
53018	Орлово	5	53	873	74.061181000000005	74.085076999999998	56.668981000000002	56.657722	0103000020E61000000100000005000000BE88B663EA8352400BEE073C30544C40BE88B663EA8352409C525E2BA1554C401329CDE6718552409C525E2BA1554C401329CDE6718552400BEE073C30544C40BE88B663EA8352400BEE073C30544C40
23866	Новоермаковка	5	53	873	74.760062000000005	74.767005999999995	57.054479000000001	57.041460000000001	0103000020E61000000100000005000000AC3B16DBA4B05240CC0BB08F4E854C40AC3B16DBA4B05240CEA8F92AF9864C407D7555A016B15240CEA8F92AF9864C407D7555A016B15240CC0BB08F4E854C40AC3B16DBA4B05240CC0BB08F4E854C40
46166	Нерпинский Кордон	5	53	873	74.454886000000002	74.464596999999998	56.952367000000002	56.948421000000003	0103000020E61000000100000005000000215A2BDA1C9D524079EBFCDB65794C40215A2BDA1C9D524013656F29E7794C4076340EF5BB9D524013656F29E7794C4076340EF5BB9D524079EBFCDB65794C40215A2BDA1C9D524079EBFCDB65794C40
46825	Нагорное	5	53	873	74.871013000000005	74.911347000000006	56.735506000000001	56.718691	0103000020E6100000010000000500000004594FADBEB75240FB761211FE5B4C4004594FADBEB752408201840F255E4C40B2135E8253BA52408201840F255E4C40B2135E8253BA5240FB761211FE5B4C4004594FADBEB75240FB761211FE5B4C40
21784	Межевная	5	53	873	74.838053000000002	74.867294000000001	57.094211000000001	57.088997999999997	0103000020E6100000010000000500000024D40CA9A2B5524067B45549648B4C4024D40CA9A2B5524034F6251B0F8C4C401781B1BE81B7524034F6251B0F8C4C401781B1BE81B7524067B45549648B4C4024D40CA9A2B5524067B45549648B4C40
46453	Междуречье	5	53	873	74.569429999999997	74.611840000000001	56.828118000000003	56.795366999999999	0103000020E610000001000000050000001FD7868A71A45240A8A8FA95CE654C401FD7868A71A452404E9D47C5FF694C409E98F56228A752404E9D47C5FF694C409E98F56228A75240A8A8FA95CE654C401FD7868A71A45240A8A8FA95CE654C40
23317	Машканка	5	53	873	74.795356999999996	74.813799000000003	56.724004999999998	56.716275000000003	0103000020E6100000010000000500000042E90B21E7B25240A1F831E6AE5B4C4042E90B21E7B25240FB912232AC5C4C401FA1664815B45240FB912232AC5C4C401FA1664815B45240A1F831E6AE5B4C4042E90B21E7B25240A1F831E6AE5B4C40
21871	Мартюшево	5	53	873	74.505065999999999	74.526786999999999	57.126382	57.110602999999998	0103000020E610000001000000050000009414580053A0524074EB353D288E4C409414580053A05240CB660E492D904C404F3DD2E0B6A15240CB660E492D904C404F3DD2E0B6A1524074EB353D288E4C409414580053A0524074EB353D288E4C40
46260	Лоскутово	5	53	873	74.221727999999999	74.237503000000004	56.875771999999998	56.868521000000001	0103000020E61000000100000005000000E126A3CA308E5240D27135B22B6F4C40E126A3CA308E52405260014C19704C40EC6CC83F338F52405260014C19704C40EC6CC83F338F5240D27135B22B6F4C40E126A3CA308E5240D27135B22B6F4C40
46282	Ложниково	5	53	873	73.867611999999994	73.896332000000001	56.903537999999998	56.886533	0103000020E610000001000000050000007F677BF48677524092E9D0E979714C407F677BF486775240BC581822A7734C40EE96E4805D795240BC581822A7734C40EE96E4805D79524092E9D0E979714C407F677BF48677524092E9D0E979714C40
15387	Литковка	5	53	873	75.090183999999994	75.120914999999997	57.345931	57.337401999999997	0103000020E61000000100000005000000D6A71C93C5C5524070CD1DFD2FAB4C40D6A71C93C5C5524017D68D7747AC4C4022A64412BDC7524017D68D7747AC4C4022A64412BDC7524070CD1DFD2FAB4C40D6A71C93C5C5524070CD1DFD2FAB4C40
21769	Курляно-Дубовка	5	53	873	74.825603000000001	74.841710000000006	57.181158000000003	57.168506000000001	0103000020E61000000100000005000000B01EF7ADD6B452400397C79A91954C40B01EF7ADD6B4524053B4722F30974C40D6AD9E93DEB5524053B4722F30974C40D6AD9E93DEB552400397C79A91954C40B01EF7ADD6B452400397C79A91954C40
47022	Крапивка	5	53	873	74.322483000000005	74.337737000000004	57.088709000000001	57.074299000000003	0103000020E6100000010000000500000006A1BC8FA394524011902FA182894C4006A1BC8FA394524031EE06D15A8B4C408C69A67B9D95524031EE06D15A8B4C408C69A67B9D95524011902FA182894C4006A1BC8FA394524011902FA182894C40
46630	Коренево	5	53	873	74.512055000000004	74.519682000000003	56.756878	56.743547999999997	0103000020E6100000010000000500000036B05582C5A05240CB80B3942C5F4C4036B05582C5A05240EC87D860E1604C4079944A7842A15240EC87D860E1604C4079944A7842A15240CB80B3942C5F4C4036B05582C5A05240CB80B3942C5F4C40
46442	Коновалово	5	53	873	73.991866999999999	74.002566000000002	56.811793000000002	56.798310000000001	0103000020E61000000100000005000000D3BEB9BF7A7F5240EE08A7052F664C40D3BEB9BF7A7F5240950F41D5E8674C403885950A2A805240950F41D5E8674C403885950A2A805240EE08A7052F664C40D3BEB9BF7A7F5240EE08A7052F664C40
23509	Кольтюгино	5	53	873	74.300223000000003	74.320021999999994	56.695051999999997	56.682040999999998	0103000020E6100000010000000500000073A087DA36935240FCC3961E4D574C4073A087DA369352407B82C476F7584C4008008E3D7B9452407B82C476F7584C4008008E3D7B945240FCC3961E4D574C4073A087DA36935240FCC3961E4D574C40
22771	Кириллино	5	53	873	73.767217000000002	73.789790999999994	56.891607	56.878473	0103000020E61000000100000005000000DBFB54151A715240A2B5A2CD71704C40DBFB54151A7152403DF19C2D20724C4035EB8CEF8B7252403DF19C2D20724C4035EB8CEF8B725240A2B5A2CD71704C40DBFB54151A715240A2B5A2CD71704C40
23243	Киргап	5	53	873	74.610905000000002	74.621442999999999	56.722611999999998	56.715938999999999	0103000020E61000000100000005000000A0FD481119A7524029779FE3A35B4C40A0FD481119A752403CD9CD8C7E5C4C400055DCB8C5A752403CD9CD8C7E5C4C400055DCB8C5A7524029779FE3A35B4C40A0FD481119A7524029779FE3A35B4C40
13234	Киксы	5	53	873	74.657330000000002	74.667929999999998	57.333427999999998	57.329143000000002	0103000020E61000000100000005000000802BD9B111AA52408A5A9A5B21AA4C40802BD9B111AA52400CC9C9C4ADAA4C401B81785DBFAA52400CC9C9C4ADAA4C401B81785DBFAA52408A5A9A5B21AA4C40802BD9B111AA52408A5A9A5B21AA4C40
10900	Ишеево	5	53	873	74.358999999999995	74.371576000000005	57.082966999999996	57.073721999999997	0103000020E61000000100000005000000E5D022DBF9965240737FF5B86F894C40E5D022DBF9965240D8D2A3A99E8A4C40A0FEB3E6C7975240D8D2A3A99E8A4C40A0FEB3E6C7975240737FF5B86F894C40E5D022DBF9965240737FF5B86F894C40
20492	Имшегал	5	53	873	74.548858999999993	74.575422000000003	57.360841999999998	57.351039	0103000020E6100000010000000500000060C77F8120A352406E4F90D8EEAC4C4060C77F8120A35240F982161230AE4C4088D9CBB6D3A45240F982161230AE4C4088D9CBB6D3A452406E4F90D8EEAC4C4060C77F8120A352406E4F90D8EEAC4C40
53010	Ивановка	5	53	873	74.921200999999996	74.938719000000006	56.731709000000002	56.721722999999997	0103000020E61000000100000005000000B8020AF5F4BA5240B0E2546B615C4C40B8020AF5F4BA52402D98F8A3A85D4C409148DBF813BC52402D98F8A3A85D4C409148DBF813BC5240B0E2546B615C4C40B8020AF5F4BA5240B0E2546B615C4C40
46583	Заливино	5	53	873	74.507302999999993	74.519834000000003	56.805259	56.782322000000001	0103000020E61000000100000005000000698A00A777A052407D78962023644C40698A00A777A05240A3E716BA12674C405456D3F544A15240A3E716BA12674C405456D3F544A152407D78962023644C40698A00A777A052407D78962023644C40
46769	Ермаковка	5	53	873	74.711821999999998	74.735878999999997	57.049450999999998	57.035646999999997	0103000020E61000000100000005000000B1A4DC7D8EAD5240AA99B51490844C40B1A4DC7D8EAD524093E00D6954864C400BB43BA418AF524093E00D6954864C400BB43BA418AF5240AA99B51490844C40B1A4DC7D8EAD5240AA99B51490844C40
53121	Екатерининскоое	5	53	873	74.541618	74.605425999999994	56.897255999999999	56.871994999999998	0103000020E61000000100000005000000323B8BDEA9A2524044A33B889D6F4C40323B8BDEA9A25240E411DC48D9724C407A89B14CBFA65240E411DC48D9724C407A89B14CBFA6524044A33B889D6F4C40323B8BDEA9A2524044A33B889D6F4C40
45802	Егоровка	5	53	873	74.878460000000004	74.906324999999995	57.171219999999998	57.161785999999999	0103000020E6100000010000000500000007B64AB038B85240AF795567B5944C4007B64AB038B85240E7357689EA954C4005A3923A01BA5240E7357689EA954C4005A3923A01BA5240AF795567B5944C4007B64AB038B85240AF795567B5944C40
46079	Гриневичи	5	53	873	74.294447000000005	74.307122000000007	57.306139000000002	57.294921000000002	0103000020E61000000100000005000000F1D93A38D8925240AAF3A8F8BFA54C40F1D93A38D8925240DC8310902FA74C40757808E3A7935240DC8310902FA74C40757808E3A7935240AAF3A8F8BFA54C40F1D93A38D8925240AAF3A8F8BFA54C40
22952	Вставское	5	53	873	73.951837999999995	73.979471000000004	56.863286000000002	56.852238	0103000020E61000000100000005000000C345EEE9EA7C524048348122166D4C40C345EEE9EA7C52401E8CD827806E4C40591822A7AF7E52401E8CD827806E4C40591822A7AF7E524048348122166D4C40C345EEE9EA7C524048348122166D4C40
22948	Большие Туралы	5	53	873	73.973685000000003	74.017398	56.764234999999999	56.747841999999999	0103000020E61000000100000005000000C5E6E3DA507E5240A1496249B95F4C40C5E6E3DA507E5240B2BAD573D2614C400341800C1D815240B2BAD573D2614C400341800C1D815240A1496249B95F4C40C5E6E3DA507E5240A1496249B95F4C40
22606	Большие Кучки	5	53	873	74.096969999999999	74.116750999999994	56.715539	56.708705999999999	0103000020E610000001000000050000005CACA8C1348652404F3DD2E0B65A4C405CACA8C1348652409B012EC8965B4C409EB12FD9788752409B012EC8965B4C409EB12FD9788752404F3DD2E0B65A4C405CACA8C1348652404F3DD2E0B65A4C40
45890	Бобровка	5	53	873	74.675638000000006	74.704222000000001	57.153776000000001	57.144767000000002	0103000020E61000000100000005000000D57B2AA73DAB524020459DB987924C40D57B2AA73DAB5240717495EEAE934C40EBC726F911AD5240717495EEAE934C40EBC726F911AD524020459DB987924C40D57B2AA73DAB524020459DB987924C40
45937	Баженово	5	53	873	74.501283999999998	74.524271999999996	57.065266000000001	57.053182	0103000020E6100000010000000500000084807C0915A05240315EF3AACE864C4084807C0915A0524037C5E3A25A884C40588D25AC8DA1524037C5E3A25A884C40588D25AC8DA15240315EF3AACE864C4084807C0915A05240315EF3AACE864C40
22290	Атирка	5	53	873	74.258954000000003	74.293468000000004	57.265428	57.244961000000004	0103000020E61000000100000005000000C74ACCB392905240D2E5CDE15A9F4C40C74ACCB392905240AAB8718BF9A14C400B9B012EC8925240AAB8718BF9A14C400B9B012EC8925240D2E5CDE15A9F4C40C74ACCB392905240D2E5CDE15A9F4C40
23138	Атак	5	53	873	74.628764000000004	74.647825999999995	56.808447000000001	56.800305999999999	0103000020E61000000100000005000000BD395CAB3DA852407365506D70664C40BD395CAB3DA8524050C6F8307B674C40E7DF2EFB75A9524050C6F8307B674C40E7DF2EFB75A952407365506D70664C40BD395CAB3DA852407365506D70664C40
53085	ст. Стрела	5	53	1527	73.632424	73.764224999999996	54.608170000000001	54.531590999999999	0103000020E61000000100000005000000274D83A27968524089EC832C0B444B40274D83A2796852404434BA83D84D4B404772F90FE97052404434BA83D84D4B404772F90FE970524089EC832C0B444B40274D83A27968524089EC832C0B444B40
19366	Черноглазовка	5	53	1527	74.034132999999997	74.043870999999996	54.347639999999998	54.342506999999998	0103000020E61000000100000005000000B8AD2D3C2F82524056D3F544D72B4B40B8AD2D3C2F8252400664AF777F2C4B408A8F4FC8CE8252400664AF777F2C4B408A8F4FC8CE82524056D3F544D72B4B40B8AD2D3C2F82524056D3F544D72B4B40
18604	Черниговка	5	53	1527	73.477626999999998	73.486682000000002	54.594442999999998	54.578656000000002	0103000020E61000000100000005000000F12BD670915E52402DD15966114A4B40F12BD670915E5240062B4EB5164C4B40526342CC255F5240062B4EB5164C4B40526342CC255F52402DD15966114A4B40F12BD670915E52402DD15966114A4B40
20159	Харламово	5	53	1527	73.607335000000006	73.637203999999997	54.700367	54.681252999999998	0103000020E61000000100000005000000D6AD9E93DE665240A4A65D4C33574B40D6AD9E93DE6652404C1938A0A5594B40583849F3C76852404C1938A0A5594B40583849F3C7685240A4A65D4C33574B40D6AD9E93DE665240A4A65D4C33574B40
19345	Тихорецкое	5	53	1527	74.062016999999997	74.079839000000007	54.415204000000003	54.404409999999999	0103000020E61000000100000005000000F2B22616F88352407216F6B4C3334B40F2B22616F88352408E95986725354B40817C09151C8552408E95986725354B40817C09151C8552407216F6B4C3334B40F2B22616F88352407216F6B4C3334B40
18055	Таврическое	5	53	1527	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
19876	Сосновское	5	53	1527	73.140497999999994	73.180940000000007	54.613211999999997	54.588856999999997	0103000020E61000000100000005000000D1C952EBFD485240A5828AAA5F4B4B40D1C952EBFD485240E3C116BB7D4E4B4073A25D85944B5240E3C116BB7D4E4B4073A25D85944B5240A5828AAA5F4B4B40D1C952EBFD485240A5828AAA5F4B4B40
19576	Сосновка	5	53	1527	74.097104999999999	74.109115000000003	54.499307999999999	54.493608000000002	0103000020E61000000100000005000000CCD1E3F736865240A185048C2E3F4B40CCD1E3F736865240CA501553E93F4B4032207BBDFB865240CA501553E93F4B4032207BBDFB865240A185048C2E3F4B40CCD1E3F736865240A185048C2E3F4B40
18925	Солоновка	5	53	1527	73.956913999999998	73.974153000000001	54.587338000000003	54.577857999999999	0103000020E6100000010000000500000069C537143E7D5240B1DD3D40F7494B4069C537143E7D52405AD93EE42D4B4B403813D385587E52405AD93EE42D4B4B403813D385587E5240B1DD3D40F7494B4069C537143E7D5240B1DD3D40F7494B40
52980	Садовое	5	53	1527	73.234965000000003	73.255339000000006	54.646984000000003	54.63832	0103000020E6100000010000000500000019ADA3AA094F5240FD304278B4514B4019ADA3AA094F52408484285FD0524B402D996379575052408484285FD0524B402D99637957505240FD304278B4514B4019ADA3AA094F5240FD304278B4514B40
19662	Пристанское	5	53	1527	74.326822000000007	74.367022000000006	54.483195000000002	54.447904999999999	0103000020E610000001000000050000004167D2A6EA945240815B77F354394B404167D2A6EA9452409D4B7155D93D4B4067BAD7497D9752409D4B7155D93D4B4067BAD7497D975240815B77F354394B404167D2A6EA945240815B77F354394B40
19567	Прииртышье	5	53	1527	74.062026000000003	74.109699000000006	54.543301999999997	54.524552999999997	0103000020E610000001000000050000001C60E63BF883524064027E8D24434B401C60E63BF8835240FAEC80EB8A454B40DA59F44E05875240FAEC80EB8A454B40DA59F44E0587524064027E8D24434B401C60E63BF883524064027E8D24434B40
19779	Победа	5	53	1527	74.299531000000002	74.315961999999999	54.509152	54.498967999999998	0103000020E61000000100000005000000D84812842B93524011E0F42EDE3F4B40D84812842B935240B4588AE42B414B40D731AEB838945240B4588AE42B414B40D731AEB83894524011E0F42EDE3F4B40D84812842B93524011E0F42EDE3F4B40
18818	Пальцевка	5	53	1527	73.639709999999994	73.652959999999993	54.483891	54.476233000000001	0103000020E61000000100000005000000253B3602F16852405323F433F53C4B40253B3602F168524014EAE923F03D4B402766BD18CA69524014EAE923F03D4B402766BD18CA6952405323F433F53C4B40253B3602F16852405323F433F53C4B40
19135	Новоуральский	5	53	1527	74.112718000000001	74.140502999999995	54.372155999999997	54.337054000000002	0103000020E61000000100000005000000EAEA8EC536875240357EE195242B4B40EAEA8EC5368752404D81CCCEA22F4B405A7F4B00FE8852404D81CCCEA22F4B405A7F4B00FE885240357EE195242B4B40EAEA8EC536875240357EE195242B4B40
18662	Новоселецк	5	53	1527	73.505358000000001	73.527294999999995	54.669550000000001	54.643149999999999	0103000020E6100000010000000500000068B114C95760524011363CBD52524B4068B114C957605240B6847CD0B3554B4009168733BF615240B6847CD0B3554B4009168733BF61524011363CBD52524B4068B114C95760524011363CBD52524B40
18734	Новобелозеровка	5	53	1527	73.414664000000002	73.433654000000004	54.599966999999999	54.579726000000001	0103000020E6100000010000000500000007B5DFDA895A524009522976344A4B4007B5DFDA895A5240F1D6F9B7CB4C4B40E5F1B4FCC05B5240F1D6F9B7CB4C4B40E5F1B4FCC05B524009522976344A4B4007B5DFDA895A524009522976344A4B40
20310	Неверовка	5	53	1527	73.285019000000005	73.311501000000007	54.468426999999998	54.446717	0103000020E6100000010000000500000046EF54C03D5252409BC8CC052E394B4046EF54C03D5252401DC87A6AF53B4B40F7EAE3A1EF5352401DC87A6AF53B4B40F7EAE3A1EF5352409BC8CC052E394B4046EF54C03D5252409BC8CC052E394B40
20636	Муртук	5	53	1527	73.301494000000005	73.314942000000002	54.531303999999999	54.524887999999997	0103000020E610000001000000050000002D7C7DAD4B5352400B08AD872F434B402D7C7DAD4B535240F31DFCC401444B40C2887D0228545240F31DFCC401444B40C2887D02285452400B08AD872F434B402D7C7DAD4B5352400B08AD872F434B40
18991	Любомировка	5	53	1527	73.567341999999996	73.596438000000006	54.443931999999997	54.421045999999997	0103000020E610000001000000050000006CE9D1544F645240490ED8D5E4354B406CE9D1544F645240EDD286C3D2384B40DE054A0A2C665240EDD286C3D2384B40DE054A0A2C665240490ED8D5E4354B406CE9D1544F645240490ED8D5E4354B40
18836	Луговое	5	53	1527	73.890249999999995	73.912896000000003	54.629106	54.613608999999997	0103000020E61000000100000005000000E5D022DBF978524000C45DBD8A4E4B40E5D022DBF9785240D3DB9F8B86504B408D2958E36C7A5240D3DB9F8B86504B408D2958E36C7A524000C45DBD8A4E4B40E5D022DBF978524000C45DBD8A4E4B40
20195	Лобково	5	53	1527	73.553381999999999	73.576693000000006	54.706994999999999	54.698728000000003	0103000020E610000001000000050000007C0C569C6A63524056664AEB6F594B407C0C569C6A635240BFB7E9CF7E5A4B4042B5C189E8645240BFB7E9CF7E5A4B4042B5C189E864524056664AEB6F594B407C0C569C6A63524056664AEB6F594B40
19986	Лесное	5	53	1527	72.947010000000006	72.956064999999995	54.558216000000002	54.551819999999999	0103000020E610000001000000050000000ABFD4CF9B3C5240ADA3AA09A2464B400ABFD4CF9B3C52404E0D349F73474B406AF6402B303D52404E0D349F73474B406AF6402B303D5240ADA3AA09A2464B400ABFD4CF9B3C5240ADA3AA09A2464B40
20483	Коянбай (Куямбай)	5	53	1527	73.165507000000005	73.181550999999999	54.455370000000002	54.444602000000003	0103000020E610000001000000050000009510ACAA974A52403CDEE4B7E8384B409510ACAA974A52402ECA6C90493A4B4097E315889E4B52402ECA6C90493A4B4097E315889E4B52403CDEE4B7E8384B409510ACAA974A52403CDEE4B7E8384B40
18566	Копейкино	5	53	1527	73.748234999999994	73.782550999999998	54.654449	54.644108000000003	0103000020E610000001000000050000003EAE0D15E36F5240C68B852172524B403EAE0D15E36F524030F31DFCC4534B40EF1CCA501572524030F31DFCC4534B40EF1CCA5015725240C68B852172524B403EAE0D15E36F5240C68B852172524B40
18747	Карповка	5	53	1527	73.725795000000005	73.747032000000004	54.51811	54.505299000000001	0103000020E610000001000000050000006C26DF6C736E5240CBD93BA3AD404B406C26DF6C736E524083DDB06D51424B4031444E5FCF6F524083DDB06D51424B4031444E5FCF6F5240CBD93BA3AD404B406C26DF6C736E5240CBD93BA3AD404B40
20273	Камышино	5	53	1527	73.517628999999999	73.533501999999999	54.764406999999999	54.758496000000001	0103000020E61000000100000005000000849D62D520615240CB129D6516614B40849D62D520615240AFEAAC16D8614B40709692E524625240AFEAAC16D8614B40709692E524625240CB129D6516614B40849D62D520615240CB129D6516614B40
53044	Зеленополье	5	53	1527	73.243795000000006	73.258257999999998	54.528733000000003	54.515351000000003	0103000020E610000001000000050000006AFB57569A4F5240FF7A8505F7414B406AFB57569A4F524072A8DF85AD434B408BFB8F4C8750524072A8DF85AD434B408BFB8F4C87505240FF7A8505F7414B406AFB57569A4F5240FF7A8505F7414B40
19455	Жатва	5	53	1527	74.075896	74.102890000000002	54.362589	54.344679999999997	0103000020E610000001000000050000006C79E57ADB845240EACA67791E2C4B406C79E57ADB845240D671FC50692E4B407845F0BF95865240D671FC50692E4B407845F0BF95865240EACA67791E2C4B406C79E57ADB845240EACA67791E2C4B40
19974	Воронково	5	53	1527	73.120797999999994	73.141036999999997	54.561354000000001	54.548884999999999	0103000020E6100000010000000500000005DB8827BB475240EA211ADD41464B4005DB8827BB47524049BDA772DA474B40A9A10DC00649524049BDA772DA474B40A9A10DC006495240EA211ADD41464B4005DB8827BB475240EA211ADD41464B40
19019	Веселые Рощи	5	53	1527	73.542745999999994	73.561215000000004	54.527923000000001	54.513019999999997	0103000020E610000001000000050000003A02B859BC625240D218ADA3AA414B403A02B859BC62524032E719FB92434B4094C151F2EA63524032E719FB92434B4094C151F2EA635240D218ADA3AA414B403A02B859BC625240D218ADA3AA414B40
19096	Березовка	5	53	1527	73.399940000000001	73.414116000000007	54.485858	54.475678000000002	0103000020E610000001000000050000002F17F19D985952409EB64604E33C4B402F17F19D98595240FF3F4E98303E4B40063065E0805A5240FF3F4E98303E4B40063065E0805A52409EB64604E33C4B402F17F19D985952409EB64604E33C4B40
19676	Баландино	5	53	1527	74.350905999999995	74.370964999999998	54.434941000000002	54.415109999999999	0103000020E61000000100000005000000177E703E759652400C1F115322354B40177E703E7596524043588D25AC374B407BBDFBE3BD97524043588D25AC374B407BBDFBE3BD9752400C1F115322354B40177E703E759652400C1F115322354B40
19775	Байдалин	5	53	1527	74.253519999999995	74.269546000000005	54.397213999999998	54.387757000000001	0103000020E610000001000000050000007138F3AB39905240C5E57805A2314B407138F3AB39905240B5C189E8D7324B4021B1DD3D40915240B5C189E8D7324B4021B1DD3D40915240C5E57805A2314B407138F3AB39905240C5E57805A2314B40
20405	Андреевка	5	53	1527	73.263486	73.280662000000007	54.396563999999998	54.384894000000003	0103000020E610000001000000050000000C3D62F4DC5052409C36E33444314B400C3D62F4DC505240AE62F19BC2324B40B8CEBF5DF6515240AE62F19BC2324B40B8CEBF5DF65152409C36E33444314B400C3D62F4DC5052409C36E33444314B40
34423	Екатерининское	5	53	2846	54.052745000000002	54.094813000000002	58.479249000000003	58.469192999999997	0103000020E6100000010000000500000086032159C0064B408D4127840E3C4D4086032159C0064B4003D2FE07583D4D402A1E17D5220C4B4003D2FE07583D4D402A1E17D5220C4B408D4127840E3C4D4086032159C0064B408D4127840E3C4D40
17213	Хмелёвка	5	53	1448	75.250641000000002	75.28819	56.827384000000002	56.813448999999999	0103000020E610000001000000050000005A828C800AD0524061FBC9181F684C405A828C800AD05240E99D0AB8E7694C40314278B471D25240E99D0AB8E7694C40314278B471D2524061FBC9181F684C405A828C800AD0524061FBC9181F684C40
17450	Усть-Инцы	5	53	1448	74.963620000000006	74.986069000000001	57.008660999999996	56.996676000000001	0103000020E61000000100000005000000617138F3ABBD5240A35A4414937F4C40617138F3ABBD524015E0BBCD1B814C405DA626C11BBF524015E0BBCD1B814C405DA626C11BBF5240A35A4414937F4C40617138F3ABBD5240A35A4414937F4C40
17522	Унара	5	53	1448	74.891493999999994	74.914195000000007	57.058408999999997	57.044908	0103000020E6100000010000000500000022A5D93C0EB9524015AA9B8BBF854C4022A5D93C0EB95240626534F279874C40ACCABE2B82BA5240626534F279874C40ACCABE2B82BA524015AA9B8BBF854C4022A5D93C0EB9524015AA9B8BBF854C40
16984	Тамбовка	5	53	1448	75.379953	75.394514999999998	56.888632999999999	56.875830999999998	0103000020E610000001000000050000001841632651D8524057E9EE3A1B704C401841632651D85240BC92E4B9BE714C4003B2D7BB3FD95240BC92E4B9BE714C4003B2D7BB3FD9524057E9EE3A1B704C401841632651D8524057E9EE3A1B704C40
17511	Сыщиково	5	53	1448	75.113709999999998	75.129268999999994	56.980263000000001	56.971212000000001	0103000020E610000001000000050000009ACE4E0647C75240CBBDC0AC507C4C409ACE4E0647C752404B3D0B42797D4C40BED87BF145C852404B3D0B42797D4C40BED87BF145C85240CBBDC0AC507C4C409ACE4E0647C75240CBBDC0AC507C4C40
17627	Седельниково	5	53	1448	75.276773000000006	75.344127999999998	56.960883000000003	56.937314000000001	0103000020E610000001000000050000009DDA19A6B6D152409E0AB8E7F9774C409DDA19A6B6D152402524D236FE7A4C40D368723106D652402524D236FE7A4C40D368723106D652409E0AB8E7F9774C409DDA19A6B6D152409E0AB8E7F9774C40
16509	Саратовка	5	53	1448	75.938857999999996	75.952414000000005	57.087187999999998	57.072825999999999	0103000020E61000000100000005000000A165DD3F16FC52403526C45C52894C40A165DD3F16FC5240444DF4F9288B4C402A90D959F4FC5240444DF4F9288B4C402A90D959F4FC52403526C45C52894C40A165DD3F16FC52403526C45C52894C40
16606	Рагозино	5	53	1448	75.923047999999994	75.945541000000006	56.949210999999998	56.931322999999999	0103000020E61000000100000005000000D828EB3713FB52409D81919735774C40D828EB3713FB52407100FDBE7F794C40BD0166BE83FC52407100FDBE7F794C40BD0166BE83FC52409D81919735774C40D828EB3713FB52409D81919735774C40
16667	Петропавловка	5	53	1448	75.959519	75.986963000000003	56.955689999999997	56.949863999999998	0103000020E61000000100000005000000003961C268FD5240E9D2BF2495794C40003961C268FD52409F8EC70C547A4C402CD7DB662AFF52409F8EC70C547A4C402CD7DB662AFF5240E9D2BF2495794C40003961C268FD5240E9D2BF2495794C40
17352	Павловка	5	53	1448	75.137497999999994	75.149032000000005	56.799033999999999	56.792645999999998	0103000020E61000000100000005000000FC5069C4CCC8524011A7936C75654C40FC5069C4CCC852402F3201BF46664C40AE8383BD89C952402F3201BF46664C40AE8383BD89C9524011A7936C75654C40FC5069C4CCC8524011A7936C75654C40
17052	Новоуйка	5	53	1448	75.191720000000004	75.206541999999999	57.038601	57.026321000000003	0103000020E610000001000000050000004E7FF62345CC524059198D7C5E834C404E7FF62345CC5240E44BA8E0F0844C4007D0EFFB37CD5240E44BA8E0F0844C4007D0EFFB37CD524059198D7C5E834C404E7FF62345CC524059198D7C5E834C40
16839	Новоалександровка	5	53	1448	75.674465999999995	75.686466999999993	56.867483	56.854182999999999	0103000020E61000000100000005000000E41071732AEB52404BE658DE556D4C40E41071732AEB5240016BD5AE096F4C4020B24813EFEB5240016BD5AE096F4C4020B24813EFEB52404BE658DE556D4C40E41071732AEB52404BE658DE556D4C40
17295	Михайловка	5	53	1448	75.141585000000006	75.158968000000002	56.845061999999999	56.836992000000002	0103000020E61000000100000005000000AB2688BA0FC95240BF81C98D226B4C40AB2688BA0FC95240D28BDAFD2A6C4C4013471E882CCA5240D28BDAFD2A6C4C4013471E882CCA5240BF81C98D226B4C40AB2688BA0FC95240BF81C98D226B4C40
17111	Лилейка	5	53	1448	75.139807000000005	75.163889999999995	57.059266000000001	57.050024000000001	0103000020E610000001000000050000001F300F99F2C85240EF01BA2F67864C401F300F99F2C85240E3E13D0796874C400D897B2C7DCA5240E3E13D0796874C400D897B2C7DCA5240EF01BA2F67864C401F300F99F2C85240EF01BA2F67864C40
16759	Лебединка	5	53	1448	75.831778999999997	75.854821000000001	56.929088	56.912080000000003	0103000020E61000000100000005000000F99FFCDD3BF55240F8AA9509BF744C40F99FFCDD3BF55240938D075BEC764C40C7BB2363B5F65240938D075BEC764C40C7BB2363B5F65240F8AA9509BF744C40F99FFCDD3BF55240F8AA9509BF744C40
17388	Кукарка	5	53	1448	75.054485	75.081002999999995	56.947752999999999	56.933306999999999	0103000020E61000000100000005000000D847A7AE7CC352405E10919A76774C40D847A7AE7CC35240CBD765F84F794C402FF834272FC55240CBD765F84F794C402FF834272FC552405E10919A76774C40D847A7AE7CC352405E10919A76774C40
17134	Короленка	5	53	1448	75.120654000000002	75.138521999999995	57.014958999999998	57.003377	0103000020E610000001000000050000006C088ECBB8C75240804754A86E804C406C088ECBB8C75240F3E32F2DEA814C40B2F1608BDDC85240F3E32F2DEA814C40B2F1608BDDC85240804754A86E804C406C088ECBB8C75240804754A86E804C40
16700	Кейзес	5	53	1448	75.711466999999999	75.752161000000001	56.945597999999997	56.922128000000001	0103000020E61000000100000005000000BA4BE2AC88ED5240EA5C514A08764C40BA4BE2AC88ED5240DD94F25A09794C40E814E46723F05240DD94F25A09794C40E814E46723F05240EA5C514A08764C40BA4BE2AC88ED5240EA5C514A08764C40
16438	Ельничное	5	53	1448	76.142353	76.165889000000007	56.926107000000002	56.917243999999997	0103000020E6100000010000000500000033DFC14F1C095340E2395B4068754C4033DFC14F1C09534060CC96AC8A764C400971E5EC9D0A534060CC96AC8A764C400971E5EC9D0A5340E2395B4068754C4033DFC14F1C095340E2395B4068754C40
16371	Елизарово	5	53	1448	76.035678000000004	76.059780000000003	56.943482000000003	56.936185000000002	0103000020E61000000100000005000000F3CB608C48025340BD00FBE8D4774C40F3CB608C48025340AE2EA704C4784C401D3D7E6FD3035340AE2EA704C4784C401D3D7E6FD3035340BD00FBE8D4774C40F3CB608C48025340BD00FBE8D4774C40
16911	Евлантьевка	5	53	1448	75.447586999999999	75.473899000000003	56.932585000000003	56.921376000000002	0103000020E6100000010000000500000058C7F143A5DC5240DFA815A6EF754C4058C7F143A5DC5240BEDEFDF15E774C40DBA6785C54DE5240BEDEFDF15E774C40DBA6785C54DE5240DFA815A6EF754C4058C7F143A5DC5240DFA815A6EF754C40
17997	Денисовка	5	53	1448	75.323063000000005	75.343203000000003	56.975264000000003	56.965079000000003	0103000020E610000001000000050000000DE36E10ADD4524038876BB5877B4C400DE36E10ADD45240AB7B6473D57C4C40E738B709F7D55240AB7B6473D57C4C40E738B709F7D5524038876BB5877B4C400DE36E10ADD4524038876BB5877B4C40
17200	Голубовка	5	53	1448	75.258627000000004	75.290571	56.889906000000003	56.874625999999999	0103000020E6100000010000000500000035B742588DD052409B1DA9BEF36F4C4035B742588DD05240D1419770E8714C40A08A1BB798D25240D1419770E8714C40A08A1BB798D252409B1DA9BEF36F4C4035B742588DD052409B1DA9BEF36F4C40
17609	Богомель	5	53	1448	74.881352000000007	74.899786000000006	57.029798999999997	57.023606999999998	0103000020E61000000100000005000000E910381268B85240747ADE8D05834C40E910381268B852400C3A2174D0834C4084D9041896B952400C3A2174D0834C4084D9041896B95240747ADE8D05834C40E910381268B85240747ADE8D05834C40
16964	Богдановка	5	53	1448	75.376548999999997	75.409632999999999	56.946883999999997	56.938763000000002	0103000020E61000000100000005000000DB15FA6019D85240F1D8CF6229784C40DB15FA6019D85240868DB27E33794C403197546D37DA5240868DB27E33794C403197546D37DA5240F1D8CF6229784C40DB15FA6019D85240F1D8CF6229784C40
16819	Бакино	5	53	1448	75.654387999999997	75.684203999999994	56.833728000000001	56.821911999999998	0103000020E6100000010000000500000045B9347EE1E952405018946934694C4045B9347EE1E9524037E15E99B76A4C40B6F292FFC9EB524037E15E99B76A4C40B6F292FFC9EB52405018946934694C4045B9347EE1E952405018946934694C40
60853	с.Васисс	5	53	375	72.765199999999993	74.078194999999994	56.131596000000002	55.349198999999999	0103000020E610000001000000050000008CB96B09F9305240E065868DB2AC4B408CB96B09F930524068244223D8104C407CED99250185524068244223D8104C407CED992501855240E065868DB2AC4B408CB96B09F9305240E065868DB2AC4B40
52968	Щербаки	5	53	375	73.452760999999995	73.485128000000003	56.020229999999998	56.008319	0103000020E61000000100000005000000DFF94509FA5C5240BC77D49810014C40DFF94509FA5C5240F4328AE596024C40EE974F560C5F5240F4328AE596024C40EE974F560C5F5240BC77D49810014C40DFF94509FA5C5240BC77D49810014C40
14581	Черноозерье	5	53	375	73.980513000000002	74.002216000000004	55.745220000000003	55.738014	0103000020E61000000100000005000000621399B9C07E5240BDFE243E77DE4B40621399B9C07E52409E29745E63DF4B40CAE1934E248052409E29745E63DF4B40CAE1934E24805240BDFE243E77DE4B40621399B9C07E5240BDFE243E77DE4B40
53079	Хохлово	5	53	375	73.594920000000002	73.646096999999997	55.884141	55.869076	0103000020E6100000010000000500000020EF552B1366524087DEE2E13DEF4B4020EF552B13665240C00644882BF14B40CC423BA759695240C00644882BF14B40CC423BA75969524087DEE2E13DEF4B4020EF552B1366524087DEE2E13DEF4B40
14423	Урусово	5	53	375	73.278353999999993	73.305851000000004	55.660988000000003	55.654192999999999	0103000020E610000001000000050000007DAD4B8DD0515240D522A298BCD34B407DAD4B8DD0515240348639419BD44B40BB9C121093535240348639419BD44B40BB9C121093535240D522A298BCD34B407DAD4B8DD0515240D522A298BCD34B40
2425	Увальная Бития	5	53	375	73.325469999999996	73.359741	55.498815999999998	55.485663000000002	0103000020E6100000010000000500000010751F80D45452404AF086342ABE4B4010751F80D45452405B5CE333D9BF4B40F1811DFF055752405B5CE333D9BF4B40F1811DFF055752404AF086342ABE4B4010751F80D45452404AF086342ABE4B40
15321	Тамбовка	5	53	375	73.019001000000003	73.041179999999997	55.476934	55.470382000000001	0103000020E61000000100000005000000D865F84F374152404450357A35BC4B40D865F84F37415240DC2C5E2C0CBD4B40F44F70B1A2425240DC2C5E2C0CBD4B40F44F70B1A24252404450357A35BC4B40D865F84F374152404450357A35BC4B40
1926	Саргатское	5	53	375	73.472497000000004	73.520944	55.628256	55.593853000000003	0103000020E61000000100000005000000529D0E643D5E5240D5D0066003CC4B40529D0E643D5E524005C24EB16AD04B4009C380255761524005C24EB16AD04B4009C3802557615240D5D0066003CC4B40529D0E643D5E5240D5D0066003CC4B40
60198	Преображенка	5	53	375	73.028908999999999	73.064581000000004	55.545126000000003	55.534184000000003	0103000020E61000000100000005000000D86322A5D9415240F3052D2460C44B40D86322A5D9415240831953B0C6C54B405ABC581822445240831953B0C6C54B405ABC581822445240F3052D2460C44B40D86322A5D9415240F3052D2460C44B40
15705	Плоское	5	53	375	72.952184000000003	72.973780000000005	55.849316999999999	55.842095	0103000020E6100000010000000500000091F12895F03C52400490DAC4C9EB4B4091F12895F03C5240EA77616BB6EC4B40EE5F5969523E5240EA77616BB6EC4B40EE5F5969523E52400490DAC4C9EB4B4091F12895F03C52400490DAC4C9EB4B40
15032	Павловка	5	53	375	72.805597000000006	72.812820000000002	55.580064999999998	55.568868000000002	0103000020E610000001000000050000005E30B8E68E335240D7DEA7AAD0C84B405E30B8E68E335240F146E6913FCA4B4039622D3E05345240F146E6913FCA4B4039622D3E05345240D7DEA7AAD0C84B405E30B8E68E335240D7DEA7AAD0C84B40
15932	Орловка	5	53	375	73.571267000000006	73.590276000000003	55.916198999999999	55.903201000000003	0103000020E610000001000000050000002E9276A38F645240755B22179CF34B402E9276A38F6452405FD0420246F54B4047E7FC14C76552405FD0420246F54B4047E7FC14C7655240755B22179CF34B402E9276A38F645240755B22179CF34B40
52966	Новотроицкое	5	53	375	72.765199999999993	74.078194999999994	56.131596000000002	55.349198999999999	0103000020E610000001000000050000008CB96B09F9305240E065868DB2AC4B408CB96B09F930524068244223D8104C407CED99250185524068244223D8104C407CED992501855240E065868DB2AC4B408CB96B09F9305240E065868DB2AC4B40
15159	Новопокровка	5	53	375	73.181900999999996	73.197154999999995	55.581775	55.575280999999997	0103000020E6100000010000000500000005871744A44B52404D81CCCEA2C94B4005871744A44B5240B1506B9A77CA4B408B4F01309E4C5240B1506B9A77CA4B408B4F01309E4C52404D81CCCEA2C94B4005871744A44B52404D81CCCEA2C94B40
14875	Николаевка	5	53	375	72.829277000000005	72.850333000000006	55.624535000000002	55.616563999999997	0103000020E61000000100000005000000CD94D6DF123552400AF2B391EBCE4B40CD94D6DF123552408B1A4CC3F0CF4B406A6D1ADB6B3652408B1A4CC3F0CF4B406A6D1ADB6B3652400AF2B391EBCE4B40CD94D6DF123552400AF2B391EBCE4B40
15233	Нижнеиртышское	5	53	375	73.235234000000005	73.284435000000002	55.457684	55.430922000000002	0103000020E61000000100000005000000113AE8120E4F52403F90BC7328B74B40113AE8120E4F524084F3A96395BA4B409EB5DB2E3452524084F3A96395BA4B409EB5DB2E345252403F90BC7328B74B40113AE8120E4F52403F90BC7328B74B40
14865	Михайловка	5	53	375	72.952768000000006	72.985394999999997	55.674031999999997	55.661490999999998	0103000020E61000000100000005000000392BA226FA3C524096CCB1BCABD44B40392BA226FA3C52408E3A3AAE46D64B4015A930B6103F52408E3A3AAE46D64B4015A930B6103F524096CCB1BCABD44B40392BA226FA3C524096CCB1BCABD44B40
15683	Куртайлы	5	53	375	73.081218000000007	73.095348999999999	55.915759999999999	55.907908999999997	0103000020E610000001000000050000002E76FBAC324552403D5FB35C36F44B402E76FBAC32455240137EA99F37F54B40342DB1321A465240137EA99F37F54B40342DB1321A4652403D5FB35C36F44B402E76FBAC324552403D5FB35C36F44B40
2032	Красный Путь	5	53	375	73.605421000000007	73.623495000000005	55.648859999999999	55.638469999999998	0103000020E61000000100000005000000F2D3B837BF66524012BD8C62B9D14B40F2D3B837BF6652405ED72FD80DD34B400D8E9257E76752405ED72FD80DD34B400D8E9257E767524012BD8C62B9D14B40F2D3B837BF66524012BD8C62B9D14B40
15926	Карманово	5	53	375	73.441064999999995	73.466594999999998	55.815038000000001	55.806241	0103000020E61000000100000005000000419AB1683A5C5240E0D8B3E732E74B40419AB1683A5C5240A67F492A53E84B40895E46B1DC5D5240A67F492A53E84B40895E46B1DC5D5240E0D8B3E732E74B40419AB1683A5C5240E0D8B3E732E74B40
16148	Калмакуль (Чугуново)	5	53	375	73.319568000000004	73.335513000000006	56.037131000000002	56.028585999999997	0103000020E61000000100000005000000483657CD73545240CD8FBFB4A8034C40483657CD735452407A5567B5C0044C408198840B795552407A5567B5C0044C408198840B79555240CD8FBFB4A8034C40483657CD73545240CD8FBFB4A8034C40
16352	Калачевка	5	53	375	73.399580999999998	73.422955000000002	55.535885	55.520986000000001	0103000020E6100000010000000500000097C62FBC9259524041D653ABAFC24B4097C62FBC925952405FB532E197C44B40802BD9B1115B52405FB532E197C44B40802BD9B1115B524041D653ABAFC24B4097C62FBC9259524041D653ABAFC24B40
15841	Казырлы	5	53	375	73.716255000000004	73.741461999999999	55.836216	55.826984000000003	0103000020E610000001000000050000002D26361FD76D52405B28999CDAE94B402D26361FD76D52402B323A2009EB4B40834E081D746F52402B323A2009EB4B40834E081D746F52405B28999CDAE94B402D26361FD76D52405B28999CDAE94B40
15798	Интенис	5	53	375	73.479512999999997	73.502232000000006	55.780137000000003	55.770563000000003	0103000020E6100000010000000500000070404B57B05E5240FB40F2CEA1E24B4070404B57B05E524025B37A87DBE34B404DC0AF912460524025B37A87DBE34B404DC0AF9124605240FB40F2CEA1E24B4070404B57B05E5240FB40F2CEA1E24B40
14659	Ивановка	5	53	375	73.682011000000003	73.696133000000003	55.683559000000002	55.670752	0103000020E61000000100000005000000C9207711A66B524001DD9733DBD54B40C9207711A66B524078F17EDC7ED74B40A62A6D718D6C524078F17EDC7ED74B40A62A6D718D6C524001DD9733DBD54B40C9207711A66B524001DD9733DBD54B40
14365	Заготзерно	5	53	375	73.584615999999997	73.612347	55.607742999999999	55.599387	0103000020E61000000100000005000000F92D3A596A655240E35295B6B8CC4B40F92D3A596A655240BCAFCA85CACD4B4070B378B130675240BCAFCA85CACD4B4070B378B130675240E35295B6B8CC4B40F92D3A596A655240E35295B6B8CC4B40
2267	Десподзиновка	5	53	375	73.163109000000006	73.181164999999993	55.712513000000001	55.704636000000001	0103000020E61000000100000005000000BB2BBB60704A5240C9CA2F8331DA4B40BB2BBB60704A5240C87C40A033DB4B40828B1535984B5240C87C40A033DB4B40828B1535984B5240C9CA2F8331DA4B40BB2BBB60704A5240C9CA2F8331DA4B40
16046	Горькое	5	53	375	73.760110999999995	73.775193999999999	56.013658	56.005006999999999	0103000020E610000001000000050000001C959BA8A570524023A0C211A4004C401C959BA8A570524015AA9B8BBF014C408C834BC79C71524015AA9B8BBF014C408C834BC79C71524023A0C211A4004C401C959BA8A570524023A0C211A4004C40
53026	Галицыно	5	53	375	73.080220999999995	73.091791000000001	55.863232000000004	55.853208000000002	0103000020E61000000100000005000000F4DC425722455240C15774EB35ED4B40F4DC4257224552402B6EDC627EEE4B404CC45BE7DF4552402B6EDC627EEE4B404CC45BE7DF455240C15774EB35ED4B40F4DC425722455240C15774EB35ED4B40
15279	Верблюжье	5	53	375	73.134739999999994	73.174256999999997	55.402239999999999	55.384774	0103000020E61000000100000005000000A25D85949F485240F12C414640B14B40A25D85949F4852404F92AE997CB34B405706D506274B52404F92AE997CB34B405706D506274B5240F12C414640B14B40A25D85949F485240F12C414640B14B40
53048	Большешипицыно	5	53	375	73.158580999999998	73.170062000000001	55.737527	55.728164999999997	0103000020E610000001000000050000001631EC30264A5240C18BBE8234DD4B401631EC30264A52406075E44867DE4B40B612BA4BE24A52406075E44867DE4B40B612BA4BE24A5240C18BBE8234DD4B401631EC30264A5240C18BBE8234DD4B40
16098	Беспалово	5	53	375	73.297182000000006	73.322146000000004	55.949661999999996	55.940854999999999	0103000020E610000001000000050000006FBDA6070553524098A3C7EF6DF84B406FBDA60705535240812040868EF94B4062A2410A9E545240812040868EF94B4062A2410A9E54524098A3C7EF6DF84B406FBDA6070553524098A3C7EF6DF84B40
52984	Баженово	5	53	375	73.059470000000005	73.112640999999996	55.646242999999998	55.626995000000001	0103000020E61000000100000005000000F645425BCE435240B5E0455F41D04B40F645425BCE4352406C223317B8D24B4014CC9882354752406C223317B8D24B4014CC988235475240B5E0455F41D04B40F645425BCE435240B5E0455F41D04B40
49168	Андреевка	5	53	375	73.799547000000004	73.856869000000003	55.723424999999999	55.703591000000003	0103000020E610000001000000050000005B272EC72B735240466117450FDA4B405B272EC72B735240ED0DBE3099DC4B4033FD12F1D6765240ED0DBE3099DC4B4033FD12F1D6765240466117450FDA4B405B272EC72B735240466117450FDA4B40
16219	Аксеново	5	53	375	73.276268999999999	73.290120999999999	55.575149000000003	55.562967999999998	0103000020E6100000010000000500000083F92B64AE515240E658DE550FC84B4083F92B64AE515240DFA9807B9EC94B4080B8AB5791525240DFA9807B9EC94B4080B8AB5791525240E658DE550FC84B4083F92B64AE515240E658DE550FC84B40
40328	Индеры	5	53	6900	73.257853999999995	73.282377999999994	55.862484000000002	55.854810000000001	0103000020E61000000100000005000000234910AE805052409A25016A6AED4B40234910AE8050524061A92EE065EE4B4008C72C7B1252524061A92EE065EE4B4008C72C7B125252409A25016A6AED4B40234910AE805052409A25016A6AED4B40
52855	Черноусовка	5	53	1257	73.446805999999995	73.459417999999999	53.577454000000003	53.566766000000001	0103000020E61000000100000005000000056A3178985C52400C3ECDC98BC84A40056A3178985C5240E2783E03EAC94A40664CC11A675D5240E2783E03EAC94A40664CC11A675D52400C3ECDC98BC84A40056A3178985C52400C3ECDC98BC84A40
52844	Цветочное	5	53	1257	74.038821999999996	74.077152999999996	53.673806999999996	53.657172000000003	0103000020E610000001000000050000006117450F7C82524068EC4B361ED44A406117450F7C8252406E68CA4E3FD64A4073F22213F08452406E68CA4E3FD64A4073F22213F084524068EC4B361ED44A406117450F7C82524068EC4B361ED44A40
52866	Хлебодаровка	5	53	1257	73.461806999999993	73.489879999999999	53.780543000000002	53.769432999999999	0103000020E610000001000000050000001684F23E8E5D524049BBD1C77CE24A401684F23E8E5D5240950F41D5E8E34A40BABDA4315A5F5240950F41D5E8E34A40BABDA4315A5F524049BBD1C77CE24A401684F23E8E5D524049BBD1C77CE24A40
52868	Тогунас	5	53	1257	73.547281999999996	73.556821999999997	53.779240000000001	53.771498000000001	0103000020E6100000010000000500000020EC14AB06635240F7764B72C0E24A4020EC14AB0663524016DEE522BEE34A405FECBDF8A263524016DEE522BEE34A405FECBDF8A2635240F7764B72C0E24A4020EC14AB06635240F7764B72C0E24A40
60147	Тамчилик	5	53	1257	73.708179000000001	73.719506999999993	53.741058000000002	53.730288000000002	0103000020E61000000100000005000000B22D03CE526D5240A454C2137ADD4A40B22D03CE526D5240373811FDDADE4A408E8F16670C6E5240373811FDDADE4A408E8F16670C6E5240A454C2137ADD4A40B22D03CE526D5240A454C2137ADD4A40
12969	Степное	5	53	1257	74.396620999999996	74.409216000000001	53.791092999999996	53.785406000000002	0103000020E6100000010000000500000009FA0B3D62995240850A0E2F88E44A4009FA0B3D62995240198C118942E54A40FF3F4E98309A5240198C118942E54A40FF3F4E98309A5240850A0E2F88E44A4009FA0B3D62995240850A0E2F88E44A40
53116	Степановка	5	53	1257	73.450821000000005	73.472928999999993	53.844478000000002	53.829155	0103000020E6100000010000000500000067D65240DA5C52404E2844C021EA4A4067D65240DA5C52408318E8DA17EC4A401E15FF77445E52408318E8DA17EC4A401E15FF77445E52404E2844C021EA4A4067D65240DA5C52404E2844C021EA4A40
53110	Солнечное	5	53	1257	73.874816999999993	73.903831999999994	53.777206999999997	53.766649000000001	0103000020E61000000100000005000000073F7100FD7752406C41EF8D21E24A40073F7100FD775240739CDB847BE34A4002452C62D8795240739CDB847BE34A4002452C62D87952406C41EF8D21E24A40073F7100FD7752406C41EF8D21E24A40
53099	Русская Поляна	5	53	1257	73.855430999999996	73.915520000000001	53.791912000000004	53.765894000000003	0103000020E61000000100000005000000033FAA61BF765240F01989D008E24A40033FAA61BF765240ADA7565F5DE54A405FB532E1977A5240ADA7565F5DE54A405FB532E1977A5240F01989D008E24A40033FAA61BF765240F01989D008E24A40
53119	Ротовка	5	53	1257	74.037752999999995	74.049216000000001	53.781346999999997	53.771172999999997	0103000020E61000000100000005000000DB148F8B6A8252407347FFCBB5E24A40DB148F8B6A825240F2E9B12D03E44A40289CDD5A26835240F2E9B12D03E44A40289CDD5A268352407347FFCBB5E24A40DB148F8B6A8252407347FFCBB5E24A40
49460	Розовка	5	53	1257	74.033432000000005	74.054974000000001	53.856296	53.84442	0103000020E61000000100000005000000F4A8F8BF238252404E0B5EF415EC4A40F4A8F8BF238252400AD9791B9BED4A405708ABB1848352400AD9791B9BED4A405708ABB1848352404E0B5EF415EC4A40F4A8F8BF238252404E0B5EF415EC4A40
60863	Пограничное	5	53	1257	73.726065000000006	73.732416000000001	53.838729999999998	53.834207999999997	0103000020E610000001000000050000004C7155D9776E5240E107E753C7EA4A404C7155D9776E5240481630815BEB4A404CC45BE7DF6E5240481630815BEB4A404CC45BE7DF6E5240E107E753C7EA4A404C7155D9776E5240E107E753C7EA4A40
46104	Озерное	5	53	1257	73.782308	73.795773999999994	53.928370999999999	53.923318000000002	0103000020E610000001000000050000008CD992551172524071E7C2482FF64A408CD992551172524004C765DCD4F64A40744012F6ED72524004C765DCD4F64A40744012F6ED72524071E7C2482FF64A408CD992551172524071E7C2482FF64A40
51913	Невольное	5	53	1257	73.798648999999997	73.814621000000002	53.733777000000003	53.720565999999998	0103000020E61000000100000005000000EBFEB1101D735240054EB6813BDC4A40EBFEB1101D7352404CC79C67ECDD4A40A1681EC0227452404CC79C67ECDD4A40A1681EC022745240054EB6813BDC4A40EBFEB1101D735240054EB6813BDC4A40
60140	Логуновка	5	53	1257	74.444528000000005	74.466527999999997	53.867023000000003	53.861776999999996	0103000020E61000000100000005000000018A9125739C5240F5B86FB54EEE4A40018A9125739C52409EF0129CFAEE4A40C5AA4198DB9D52409EF0129CFAEE4A40C5AA4198DB9D5240F5B86FB54EEE4A40018A9125739C5240F5B86FB54EEE4A40
52850	Жуковка	5	53	1257	73.566838000000004	73.583646000000002	53.591721	53.583478999999997	0103000020E610000001000000050000005308E412476452408E739B70AFCA4A405308E412476452409FAD8383BDCB4A403D9CC0745A6552409FAD8383BDCB4A403D9CC0745A6552408E739B70AFCA4A405308E412476452408E739B70AFCA4A40
60813	Добровольск	5	53	1257	74.238472999999999	74.279624999999996	53.655026999999997	53.635672	0103000020E61000000100000005000000A8FE4124438F5240D07D39B35DD14A40A8FE4124438F52409D7FBBECD7D34A4037894160E59152409D7FBBECD7D34A4037894160E5915240D07D39B35DD14A40A8FE4124438F5240D07D39B35DD14A40
53112	Волотовка	5	53	1257	74.038634000000002	74.058001000000004	53.815181000000003	53.808391999999998	0103000020E61000000100000005000000E0A0BDFA788252408C2C996379E74A40E0A0BDFA7882524009A9DBD957E84A40A988D349B683524009A9DBD957E84A40A988D349B68352408C2C996379E74A40E0A0BDFA788252408C2C996379E74A40
53086	Бузан	5	53	1257	73.932497999999995	73.946924999999993	53.934091000000002	53.928572000000003	0103000020E610000001000000050000007765170CAE7B52409CFD8172DBF64A407765170CAE7B5240753E3C4B90F74A40F2B0506B9A7C5240753E3C4B90F74A40F2B0506B9A7C52409CFD8172DBF64A407765170CAE7B52409CFD8172DBF64A40
60839	Бас-Агаш	5	53	1257	74.231071	74.243485000000007	53.913454000000002	53.906171999999998	0103000020E61000000100000005000000750305DEC98E52408446B071FDF34A40750305DEC98E52404033880FECF44A4043041C42958F52404033880FECF44A4043041C42958F52408446B071FDF34A40750305DEC98E52408446B071FDF34A40
53111	Алабота	5	53	1257	73.747857999999994	73.781481999999997	53.964860999999999	53.943435000000001	0103000020E610000001000000050000005303CDE7DC6F52406D73637AC2F84A405303CDE7DC6F5240CA17B49080FB4A40691A14CD03725240CA17B49080FB4A40691A14CD037252406D73637AC2F84A405303CDE7DC6F52406D73637AC2F84A40
53082	Андриановка	5	53	7253	73.744964999999993	73.756140000000002	53.809493000000003	53.800925999999997	0103000020E6100000010000000500000089EAAD81AD6F52400F4240BE84E64A4089EAAD81AD6F5240A4AB74779DE74A40A3CC069964705240A4AB74779DE74A40A3CC0699647052400F4240BE84E64A4089EAAD81AD6F52400F4240BE84E64A40
46185	Щегловка	5	53	373	71.542952	71.557792000000006	54.292656999999998	54.277330999999997	0103000020E610000001000000050000000FD3BEB9BFE251405F950B957F234B400FD3BEB9BFE2514005F9D9C875254B401C7E37DDB2E3514005F9D9C875254B401C7E37DDB2E351405F950B957F234B400FD3BEB9BFE251405F950B957F234B40
45543	Шахово	5	53	373	71.841425999999998	71.863524999999996	54.465648000000002	54.451821000000002	0103000020E61000000100000005000000430070ECD9F55140B1524145D5394B40430070ECD9F5514052B9895A9A3B4B40D1915CFE43F7514052B9895A9A3B4B40D1915CFE43F75140B1524145D5394B40430070ECD9F55140B1524145D5394B40
46509	Шаровка	5	53	373	71.528156999999993	71.549456000000006	54.582439000000001	54.569110999999999	0103000020E61000000100000005000000D2890453CDE151409D6516A1D8484B40D2890453CDE151401D75745C8D4A4B40D3A57F492AE351401D75745C8D4A4B40D3A57F492AE351409D6516A1D8484B40D2890453CDE151409D6516A1D8484B40
11812	Хмаровка	5	53	373	71.563558999999998	71.577798000000001	54.545940000000002	54.532349000000004	0103000020E610000001000000050000007497C45911E451407787140324444B407497C45911E4514004CAA65CE1454B406E6C76A4FAE4514004CAA65CE1454B406E6C76A4FAE451407787140324444B407497C45911E451407787140324444B40
45678	Увальное	5	53	373	71.571060000000003	71.591722000000004	54.443705999999999	54.440182999999998	0103000020E6100000010000000500000071033E3F8CE45140A9A0A2EA57384B4071033E3F8CE45140FD84B35BCB384B40B894F3C5DEE55140FD84B35BCB384B40B894F3C5DEE55140A9A0A2EA57384B4071033E3F8CE45140A9A0A2EA57384B40
11983	Терпенье	5	53	373	71.233796999999996	71.256164999999996	54.254035999999999	54.245902999999998	0103000020E61000000100000005000000C939B187F6CE5140807EDFBF791F4B40C939B187F6CE5140DA006C4084204B404F58E20165D05140DA006C4084204B404F58E20165D05140807EDFBF791F4B40C939B187F6CE5140807EDFBF791F4B40
52990	Соловьевка	5	53	373	71.265382000000002	71.305859999999996	54.484833000000002	54.476101999999997	0103000020E610000001000000050000009DBCC804FCD05140B4C70BE9F03C4B409DBCC804FCD05140C382FB010F3E4B40E449D23593D35140C382FB010F3E4B40E449D23593D35140B4C70BE9F03C4B409DBCC804FCD05140B4C70BE9F03C4B40
12610	Смелое	5	53	373	71.405356999999995	71.418688000000003	54.501832999999998	54.491501	0103000020E61000000100000005000000198D7C5EF1D95140C4793881E93E4B40198D7C5EF1D95140DB8651103C404B4092CEC0C8CBDA5140DB8651103C404B4092CEC0C8CBDA5140C4793881E93E4B40198D7C5EF1D95140C4793881E93E4B40
11170	Святогорск	5	53	373	71.367582999999996	71.390382000000002	54.390445999999997	54.381968000000001	0103000020E6100000010000000500000032E4D87A86D751402C0FD253E4304B4032E4D87A86D75140506D7022FA314B409DBCC804FCD85140506D7022FA314B409DBCC804FCD851402C0FD253E4304B4032E4D87A86D751402C0FD253E4304B40
46708	Полтавка	5	53	373	71.734077999999997	71.787796999999998	54.385586000000004	54.346155000000003	0103000020E61000000100000005000000A3AD4A22FBEE5140672C9ACE4E2C4B40A3AD4A22FBEE5140D2E5CDE15A314B40C3B81B446BF25140D2E5CDE15A314B40C3B81B446BF25140672C9ACE4E2C4B40A3AD4A22FBEE5140672C9ACE4E2C4B40
46452	Платово	5	53	373	71.708044999999998	71.738919999999993	54.494272000000002	54.482844999999998	0103000020E610000001000000050000002AC6F99B50ED5140C0046EDDCD3D4B402AC6F99B50ED51400DAA0D4E443F4B400F971C774AEF51400DAA0D4E443F4B400F971C774AEF5140C0046EDDCD3D4B402AC6F99B50ED5140C0046EDDCD3D4B40
46561	Ольгино	5	53	373	71.661934000000002	71.692691999999994	54.277414999999998	54.256785999999998	0103000020E6100000010000000500000012876C205DEA51400B09185DDE204B4012876C205DEA5140BD35B05582234B40DA8CD31055EC5140BD35B05582234B40DA8CD31055EC51400B09185DDE204B4012876C205DEA51400B09185DDE204B40
12547	Ольвиополь	5	53	373	71.246741999999998	71.267968999999994	54.520555999999999	54.512633000000001	0103000020E610000001000000050000002D23F59ECACF5140D9EC48F59D414B402D23F59ECACF514048DE3994A1424B40E0D5726726D1514048DE3994A1424B40E0D5726726D15140D9EC48F59D414B402D23F59ECACF5140D9EC48F59D414B40
11124	Новотимофеевка	5	53	373	71.557658000000004	71.579954000000001	54.354199999999999	54.340921999999999	0103000020E6100000010000000500000094162EABB0E35140533E0455A32B4B4094162EABB0E35140211FF46C562D4B40CDCB61F71DE55140211FF46C562D4B40CDCB61F71DE55140533E0455A32B4B4094162EABB0E35140533E0455A32B4B40
46310	Новосергеевка	5	53	373	71.975446000000005	72.006733999999994	54.464508000000002	54.454479999999997	0103000020E61000000100000005000000E6400FB56DFE5140D15790662C3A4B40E6400FB56DFE51407D5D86FF743B4B405C7171546E0052407D5D86FF743B4B405C7171546E005240D15790662C3A4B40E6400FB56DFE5140D15790662C3A4B40
46525	Новоильиновка	5	53	373	71.104519999999994	71.124041000000005	54.240488999999997	54.229948	0103000020E61000000100000005000000C971A774B0C65140EBE3A1EF6E1D4B40C971A774B0C651401C06F357C81E4B403E97A949F0C751401C06F357C81E4B403E97A949F0C75140EBE3A1EF6E1D4B40C971A774B0C65140EBE3A1EF6E1D4B40
12237	Никополь	5	53	373	71.736180000000004	71.757209000000003	54.155762000000003	54.146670999999998	0103000020E6100000010000000500000009FEB7921DEF5140C422861DC6124B4009FEB7921DEF5140D3FA5B02F0134B4029CFBC1C76F05140D3FA5B02F0134B4029CFBC1C76F05140C422861DC6124B4009FEB7921DEF5140C422861DC6124B40
12516	Мечебилово	5	53	373	71.228048000000001	71.252274999999997	54.443680000000001	54.436228999999997	0103000020E61000000100000005000000C47AA35698CE51408C48145AD6374B40C47AA35698CE5140D4F19881CA384B404CA60A4625D05140D4F19881CA384B404CA60A4625D051408C48145AD6374B40C47AA35698CE51408C48145AD6374B40
12464	Лубянск	5	53	373	71.440867999999995	71.458905999999999	54.476531000000001	54.468682999999999	0103000020E6100000010000000500000096766A2E37DC51407898F6CDFD3B4B4096766A2E37DC5140DD43C2F7FE3C4B400B7C45B75EDD5140DD43C2F7FE3C4B400B7C45B75EDD51407898F6CDFD3B4B4096766A2E37DC51407898F6CDFD3B4B40
46633	Крым	5	53	373	71.486592000000002	71.503461999999999	54.235900000000001	54.225442999999999	0103000020E61000000100000005000000B29FC55224DF51405A0EF450DB1C4B40B29FC55224DF51402E90A0F8311E4B40D731AEB838E051402E90A0F8311E4B40D731AEB838E051405A0EF450DB1C4B40B29FC55224DF51405A0EF450DB1C4B40
1916	Краснопутиловка	5	53	373	71.944794999999999	71.968349000000003	54.422434000000003	54.408203999999998	0103000020E61000000100000005000000289B728577FC5140560C570740344B40289B728577FC5140F75B3B5112364B405187156EF9FD5140F75B3B5112364B405187156EF9FD5140560C570740344B40289B728577FC5140560C570740344B40
46416	Красногорка	5	53	373	71.667233999999993	71.695863000000003	54.577455999999998	54.560132000000003	0103000020E61000000100000005000000DF313CF6B3EA5140B7B8C667B2474B40DF313CF6B3EA514082700514EA494B40C6DFF60489EC514082700514EA494B40C6DFF60489EC5140B7B8C667B2474B40DF313CF6B3EA5140B7B8C667B2474B40
11624	Коконовка	5	53	373	71.936531000000002	71.961440999999994	54.315463000000001	54.303674999999998	0103000020E610000001000000050000002C2CB81FF0FB514070CE88D2DE264B402C2CB81FF0FB51408D0C721761284B402502D53F88FD51408D0C721761284B402502D53F88FD514070CE88D2DE264B402C2CB81FF0FB514070CE88D2DE264B40
46372	Каменка	5	53	373	72.014622000000003	72.037394000000006	54.383017000000002	54.377737000000003	0103000020E6100000010000000500000056F31C91EF0052409DBE9EAF59304B4056F31C91EF005240F16778B306314B4044C4CDA964025240F16778B306314B4044C4CDA9640252409DBE9EAF59304B4056F31C91EF0052409DBE9EAF59304B40
46325	Еремеевка	5	53	373	72.027117000000004	72.066130999999999	54.293917999999998	54.266705000000002	0103000020E610000001000000050000009A0AF148BC0152400057B26323224B409A0AF148BC01524055DAE21A9F254B401D90847D3B04524055DAE21A9F254B401D90847D3B0452400057B26323224B409A0AF148BC0152400057B26323224B40
46071	Добрянка	5	53	373	71.419308000000001	71.432855000000004	54.223269000000002	54.214945999999998	0103000020E61000000100000005000000E0BC38F1D5DA5140F833BC59831B4B40E0BC38F1D5DA5140F69A1E14941C4B403F3A75E5B3DB5140F69A1E14941C4B403F3A75E5B3DB5140F833BC59831B4B40E0BC38F1D5DA5140F833BC59831B4B40
10955	Длинное	5	53	373	71.365409	71.390112999999999	54.219473999999998	54.212819000000003	0103000020E61000000100000005000000802A6EDC62D75140D57B2AA73D1B4B40802A6EDC62D7514041295AB9171C4B40A52F849CF7D8514041295AB9171C4B40A52F849CF7D85140D57B2AA73D1B4B40802A6EDC62D75140D57B2AA73D1B4B40
11557	Гостиловка	5	53	373	71.945639999999997	71.970910000000003	54.357663000000002	54.351334999999999	0103000020E610000001000000050000008672A25D85FC51405778978BF82C4B408672A25D85FC5140A0FEB3E6C72D4B400057B26323FE5140A0FEB3E6C72D4B400057B26323FE51405778978BF82C4B408672A25D85FC51405778978BF82C4B40
46616	Георгиевка	5	53	373	71.760039000000006	71.786557000000002	54.307206000000001	54.288426999999999	0103000020E61000000100000005000000D02B9E7AA4F0514046240A2DEB244B40D02B9E7AA4F051404791B58652274B4027DC2BF356F251404791B58652274B4027DC2BF356F2514046240A2DEB244B40D02B9E7AA4F0514046240A2DEB244B40
46111	Воронцовка	5	53	373	71.480976999999996	71.520970000000005	54.339269000000002	54.317746999999997	0103000020E610000001000000050000003448C153C8DE514078B306EFAB284B403448C153C8DE5140F8C5A52A6D2B4B409E0C8E9257E15140F8C5A52A6D2B4B409E0C8E9257E1514078B306EFAB284B403448C153C8DE514078B306EFAB284B40
45987	Вольное	5	53	373	71.341137000000003	71.373583999999994	54.295358	54.274943999999998	0103000020E61000000100000005000000289D4830D5D551409F1D705D31234B40289D4830D5D55140554E7B4ACE254B40C493DDCCE8D75140554E7B4ACE254B40C493DDCCE8D751409F1D705D31234B40289D4830D5D551409F1D705D31234B40
53021	Бородинка	5	53	373	71.231281999999993	71.25197	54.314248999999997	54.308571000000001	0103000020E61000000100000005000000D2890453CDCE51403CBF28417F274B40D2890453CDCE51407DE6AC4F39284B40AE64C74620D051407DE6AC4F39284B40AE64C74620D051403CBF28417F274B40D2890453CDCE51403CBF28417F274B40
52963	Бельдеж №7	5	53	373	71.825805000000003	71.842217000000005	54.424210000000002	54.411867000000001	0103000020E61000000100000005000000E4F736FDD9F451409CA6CF0EB8344B40E4F736FDD9F451406E5166834C364B40A8C821E2E6F551406E5166834C364B40A8C821E2E6F551409CA6CF0EB8344B40E4F736FDD9F451409CA6CF0EB8344B40
11261	Бельдеж №3	5	53	373	71.756247999999999	71.779190999999997	54.399054	54.384343999999999	0103000020E6100000010000000500000096EA025E66F05140F834272F32314B4096EA025E66F0514043AB933314334B409A95ED43DEF1514043AB933314334B409A95ED43DEF15140F834272F32314B4096EA025E66F05140F834272F32314B40
53019	Бельдеж №12	5	53	373	71.875705999999994	71.891695999999996	54.395966000000001	54.387918999999997	0103000020E610000001000000050000004DBA2D910BF851409E3F6D54A7314B404DBA2D910BF85140FA298E03AF324B40567E198C11F95140FA298E03AF324B40567E198C11F951409E3F6D54A7314B404DBA2D910BF851409E3F6D54A7314B40
11757	Белотурковка	5	53	373	71.579451000000006	71.595099000000005	54.521647999999999	54.512931000000002	0103000020E610000001000000050000009CA8A5B915E55140630D17B9A7414B409CA8A5B915E551400C03965CC5424B4078B81D1A16E651400C03965CC5424B4078B81D1A16E65140630D17B9A7414B409CA8A5B915E55140630D17B9A7414B40
10851	Бежевка	5	53	373	71.335378000000006	71.352635000000006	54.240841000000003	54.227705999999998	0103000020E61000000100000005000000117349D576D551402E8D5F78251D4B40117349D576D551409A44BDE0D31E4B40331B649291D651409A44BDE0D31E4B40331B649291D651402E8D5F78251D4B40117349D576D551402E8D5F78251D4B40
46588	Андрюшевка	5	53	373	71.615662	71.628499000000005	54.224716999999998	54.220489999999998	0103000020E61000000100000005000000F5D8960167E751402A8C2D04391C4B40F5D8960167E7514078EDD286C31C4B4066A4DE5339E8514078EDD286C31C4B4066A4DE5339E851402A8C2D04391C4B40F5D8960167E751402A8C2D04391C4B40
9818	Ясная Поляна	5	53	1043	73.554343000000003	73.572991999999999	54.316482000000001	54.306117999999998	0103000020E610000001000000050000000FF10F5B7A635240C45BE7DF2E274B400FF10F5B7A635240E7E26F7B82284B40A837A3E6AB645240E7E26F7B82284B40A837A3E6AB645240C45BE7DF2E274B400FF10F5B7A635240C45BE7DF2E274B40
10135	Ярмоклеевка	5	53	1043	73.676586	73.700920999999994	54.339500000000001	54.329251999999997	0103000020E610000001000000050000009DBB5D2F4D6B52404012F6ED242A4B409DBB5D2F4D6B5240FA7E6ABC742B4B401805C1E3DB6C5240FA7E6ABC742B4B401805C1E3DB6C52404012F6ED242A4B409DBB5D2F4D6B52404012F6ED242A4B40
9340	Явлено-Покровка	5	53	1043	73.501898999999995	73.522552000000005	54.116889999999998	54.103794999999998	0103000020E6100000010000000500000049B9FB1C1F605240813E9127490D4B4049B9FB1C1F6052405E9D6340F60E4B40679DF17D716152405E9D6340F60E4B40679DF17D71615240813E9127490D4B4049B9FB1C1F605240813E9127490D4B40
9554	Юрьевка	5	53	1043	73.376827000000006	73.410217000000003	54.033262999999998	54.015405999999999	0103000020E61000000100000005000000FD4FFEEE1D585240C214E5D2F8014B40FD4FFEEE1D5852405B9544F641044B40D9D0CDFE405A52405B9544F641044B40D9D0CDFE405A5240C214E5D2F8014B40FD4FFEEE1D585240C214E5D2F8014B40
10325	Южное	5	53	1043	74.010363999999996	74.032480000000007	54.015787000000003	53.998874999999998	0103000020E610000001000000050000009143C4CDA980524060E5D022DBFF4A409143C4CDA9805240DA59F44E05024B408B71FE2614825240DA59F44E05024B408B71FE261482524060E5D022DBFF4A409143C4CDA980524060E5D022DBFF4A40
9719	Хорошки	5	53	1043	73.513101000000006	73.540141000000006	54.276389999999999	54.263033999999998	0103000020E61000000100000005000000E0A293A5D660524037DE1D19AB214B40E0A293A5D660524081785DBF60234B40A48E8EAB9162524081785DBF60234B40A48E8EAB9162524037DE1D19AB214B40E0A293A5D660524037DE1D19AB214B40
10613	Топольки	5	53	1043	73.912654000000003	73.924942999999999	54.400221999999999	54.391331999999998	0103000020E6100000010000000500000012A452EC687A52406BF0BE2A17324B4012A452EC687A5240E29178793A334B4081EA1F44327B5240E29178793A334B4081EA1F44327B52406BF0BE2A17324B4012A452EC687A52406BF0BE2A17324B40
10464	Тихвинка	5	53	1043	73.811081000000001	73.849511000000007	54.366695999999997	54.353516999999997	0103000020E610000001000000050000000C5A48C0E87352403ECA880B402D4B400C5A48C0E873524079C9FFE4EF2E4B40E8A562635E76524079C9FFE4EF2E4B40E8A562635E7652403ECA880B402D4B400C5A48C0E87352403ECA880B402D4B40
10426	Степное	5	53	1043	73.873613000000006	73.881445999999997	54.049156000000004	54.043711000000002	0103000020E6100000010000000500000012178046E9775240DCBC715298054B4012178046E97752407B336ABE4A064B4029CC7B9C697852407B336ABE4A064B4029CC7B9C69785240DCBC715298054B4012178046E9775240DCBC715298054B40
9952	Семяновка	5	53	1043	73.747776999999999	73.756185000000002	54.268802999999998	54.258270000000003	0103000020E61000000100000005000000DDEC0F94DB6F5240DBC4C9FD0E214B40DDEC0F94DB6F52408908FF2268224B40732EC555657052408908FF2268224B40732EC55565705240DBC4C9FD0E214B40DDEC0F94DB6F5240DBC4C9FD0E214B40
10351	Раздольное	5	53	1043	73.959995000000006	73.975742999999994	54.087885	54.079799000000001	0103000020E61000000100000005000000B554DE8E707D524073A087DA360A4B40B554DE8E707D52408C67D0D03F0B4B404293C492727E52408C67D0D03F0B4B404293C492727E524073A087DA360A4B40B554DE8E707D524073A087DA360A4B40
10717	Пашенная Роща	5	53	1043	74.041624999999996	74.074836000000005	54.221232000000001	54.202466000000001	0103000020E610000001000000050000008B6CE7FBA9825240A646E867EA194B408B6CE7FBA9825240126A8654511C4B401024EF1CCA845240126A8654511C4B401024EF1CCA845240A646E867EA194B408B6CE7FBA9825240A646E867EA194B40
9131	Павлоградка	5	53	1043	73.543347999999995	73.583853000000005	54.218631000000002	54.187801	0103000020E610000001000000050000003596B036C6625240FB93F8DC09184B403596B036C66252402672C119FC1B4B40FA2AF9D85D6552402672C119FC1B4B40FA2AF9D85D655240FB93F8DC09184B403596B036C6625240FB93F8DC09184B40
10644	Новоуральское	5	53	1043	74.189721000000006	74.232417999999996	54.252442000000002	54.239910000000002	0103000020E6100000010000000500000053978C63248C5240DFFDF15EB51E4B4053978C63248C52408411FB0450204B401C40BFEFDF8E52408411FB0450204B401C40BFEFDF8E5240DFFDF15EB51E4B4053978C63248C5240DFFDF15EB51E4B40
9389	Назаровка	5	53	1043	73.432882000000006	73.440329000000006	54.176825999999998	54.160480999999997	0103000020E61000000100000005000000BC41B456B45B52408F5033A48A144B40BC41B456B45B52408F8AFF3BA2164B40BF9EAF592E5C52408F8AFF3BA2164B40BF9EAF592E5C52408F5033A48A144B40BC41B456B45B52408F5033A48A144B40
10230	Милоградовка	5	53	1043	73.653184999999993	73.677214000000006	54.098979999999997	54.080871000000002	0103000020E61000000100000005000000374F75C8CD695240F0181EFB590A4B40374F75C8CD695240A27A6B60AB0C4B402D996379576B5240A27A6B60AB0C4B402D996379576B5240F0181EFB590A4B40374F75C8CD695240F0181EFB590A4B40
9923	Логиновка	5	53	1043	73.719641999999993	73.740167999999997	54.282797000000002	54.272036	0103000020E61000000100000005000000FEB4519D0E6E5240D6AA5D13D2224B40FEB4519D0E6E524016342DB132244B40ED629AE95E6F524016342DB132244B40ED629AE95E6F5240D6AA5D13D2224B40FEB4519D0E6E5240D6AA5D13D2224B40
9457	Липов Кут	5	53	1043	73.359570000000005	73.369065000000006	54.227490000000003	54.221226999999999	0103000020E61000000100000005000000DBA7E3310357524000FF942A511C4B40DBA7E3310357524062156F641E1D4B404A46CEC29E57524062156F641E1D4B404A46CEC29E57524000FF942A511C4B40DBA7E3310357524000FF942A511C4B40
10542	Краснодарка	5	53	1043	74.011307000000002	74.035291999999998	54.255088000000001	54.245623999999999	0103000020E61000000100000005000000D1CDFE40B98052406D8E739B701F4B40D1CDFE40B980524010CD3CB9A6204B40DE7360394282524010CD3CB9A6204B40DE736039428252406D8E739B701F4B40D1CDFE40B98052406D8E739B701F4B40
9852	Кохановка	5	53	1043	73.319056000000003	73.327635000000001	54.278319000000003	54.268923999999998	0103000020E61000000100000005000000ED65DB696B545240048E041A6C224B40ED65DB696B5452407F6DFDF49F234B409981CAF8F75452407F6DFDF49F234B409981CAF8F7545240048E041A6C224B40ED65DB696B545240048E041A6C224B40
10072	Константиноградка	5	53	1043	73.834401999999997	73.856949	54.204625	54.194513000000001	0103000020E61000000100000005000000E36DA5D766755240CCD24ECDE5184B40E36DA5D766755240D578E926311A4B40C1559E40D8765240D578E926311A4B40C1559E40D8765240CCD24ECDE5184B40E36DA5D766755240CCD24ECDE5184B40
10784	Золотухино	5	53	1043	74.206267999999994	74.220246000000003	54.212376999999996	54.201143999999999	0103000020E61000000100000005000000868DB27E338D5240B0E42A16BF194B40868DB27E338D524017B6662B2F1B4B40CAC4AD82188E524017B6662B2F1B4B40CAC4AD82188E5240B0E42A16BF194B40868DB27E338D5240B0E42A16BF194B40
9623	Дувановка	5	53	1043	73.244613000000001	73.264250000000004	53.975988999999998	53.962372000000002	0103000020E610000001000000050000004BCB48BDA74F5240064B75012FFB4A404BCB48BDA74F5240BC202235EDFC4A40F4FDD478E9505240BC202235EDFC4A40F4FDD478E9505240064B75012FFB4A404BCB48BDA74F5240064B75012FFB4A40
9762	Глинкино	5	53	1043	73.572866000000005	73.591470000000001	54.271951999999999	54.263713000000003	0103000020E6100000010000000500000062BF27D6A9645240D943FB58C1214B4062BF27D6A9645240780AB952CF224B402BA4FCA4DA655240780AB952CF224B402BA4FCA4DA655240D943FB58C1214B4062BF27D6A9645240D943FB58C1214B40
10119	Божедаровка	5	53	1043	73.733457999999999	73.754191000000006	54.192284999999998	54.179966	0103000020E6100000010000000500000055BFD2F9F06E52402B323A2009174B4055BFD2F9F06E524074417DCB9C184B4001FC53AA4470524074417DCB9C184B4001FC53AA447052402B323A2009174B4055BFD2F9F06E52402B323A2009174B40
9493	Богодуховка	5	53	1043	73.384255999999993	73.406777000000005	54.088751999999999	54.070543999999998	0103000020E61000000100000005000000AC527AA697585240EA76F69507094B40AC527AA69758524030BABC395C0B4B40F6F065A2085A524030BABC395C0B4B40F6F065A2085A5240EA76F69507094B40AC527AA697585240EA76F69507094B40
9394	Бердовка	5	53	1043	73.431506999999996	73.441316999999998	54.202998000000001	54.196277000000002	0103000020E61000000100000005000000AF3F89CF9D5B52407FFACF9A1F194B40AF3F89CF9D5B5240A393A5D6FB194B40CE8AA8893E5C5240A393A5D6FB194B40CE8AA8893E5C52407FFACF9A1F194B40AF3F89CF9D5B52407FFACF9A1F194B40
9643	Белоусовка	5	53	1043	73.522057000000004	73.538820000000001	54.052686999999999	54.035336000000001	0103000020E610000001000000050000007769C361696152408C2FDAE385044B407769C3616961524051F69672BE064B40919BE1067C62524051F69672BE064B40919BE1067C6252408C2FDAE385044B407769C361696152408C2FDAE385044B40
8923	имени Комиссарова	5	53	422	73.626478000000006	73.643895999999998	54.738821999999999	54.727994000000002	0103000020E61000000100000005000000776A2E371868524095D74AE82E5D4B40776A2E37186852405CC823B8915E4B409D819197356952405CC823B8915E4B409D8191973569524095D74AE82E5D4B40776A2E371868524095D74AE82E5D4B40
7922	Чернолучье	5	53	422	73.009693999999996	73.033705999999995	55.250633000000001	55.234343000000003	0103000020E61000000100000005000000EA3D95D39E405240F58590F3FE9D4B40EA3D95D39E4052403126FDBD14A04B4074EB353D284252403126FDBD14A04B4074EB353D28425240F58590F3FE9D4B40EA3D95D39E405240F58590F3FE9D4B40
53098	Чернолучинский	5	53	422	73.024102999999997	73.031576999999999	55.288480999999997	55.280605000000001	0103000020E61000000100000005000000122F4FE78A4152400B0C59DDEAA34B40122F4FE78A415240394206F2ECA44B409293895B05425240394206F2ECA44B409293895B054252400B0C59DDEAA34B40122F4FE78A4152400B0C59DDEAA34B40
49445	Хвойный	5	53	422	73.578579000000005	73.585667000000001	55.114502000000002	55.107695	0103000020E61000000100000005000000C1C9367007655240AB7823F3C88D4B40C1C9367007655240CEA96400A88E4B402CD670917B655240CEA96400A88E4B402CD670917B655240AB7823F3C88D4B40C1C9367007655240AB7823F3C88D4B40
45468	Харино	5	53	422	73.189734999999999	73.209676999999999	55.169431000000003	55.147782999999997	0103000020E6100000010000000500000005FA449E244C5240CFF3A78DEA924B4005FA449E244C5240DCF63DEAAF954B404C6E14596B4D5240DCF63DEAAF954B404C6E14596B4D5240CFF3A78DEA924B4005FA449E244C5240CFF3A78DEA924B40
8444	Халдеевка	5	53	422	73.650328000000002	73.667692000000002	55.332360000000001	55.325242000000003	0103000020E6100000010000000500000014EB54F99E69524090A4A487A1A94B4014EB54F99E695240D13FC1C58AAA4B4041F33977BB6A5240D13FC1C58AAA4B4041F33977BB6A524090A4A487A1A94B4014EB54F99E69524090A4A487A1A94B40
8899	Усть-Заостровка	5	53	422	73.589431000000005	73.618384000000006	54.782749000000003	54.746524000000001	0103000020E61000000100000005000000E90FCD3CB9655240EDD632198E5F4B40E90FCD3CB965524005FD851E31644B40A9177C9A9367524005FD851E31644B40A9177C9A93675240EDD632198E5F4B40E90FCD3CB9655240EDD632198E5F4B40
40308	Ульяновка	5	53	422	73.659868000000003	73.682775000000007	54.974725999999997	54.961930000000002	0103000020E6100000010000000500000053EBFD463B6A52404985B185207B4B4053EBFD463B6A5240CB4752D2C37C4B40B1E1E995B26B5240CB4752D2C37C4B40B1E1E995B26B52404985B185207B4B4053EBFD463B6A52404985B185207B4B40
49308	Трусовка	5	53	422	73.705449000000002	73.713587000000004	55.246661000000003	55.237371000000003	0103000020E61000000100000005000000BDFF8F13266D52406902452C629E4B40BDFF8F13266D52406E197096929F4B4073F6CE68AB6D52406E197096929F4B4073F6CE68AB6D52406902452C629E4B40BDFF8F13266D52406902452C629E4B40
46928	Троицкое	5	53	422	73.290633	73.318669999999997	54.892648999999999	54.847814999999997	0103000020E61000000100000005000000DB8827BB995252407407B133856C4B40DB8827BB995252404FE78A5242724B40D80DDB16655452404FE78A5242724B40D80DDB16655452407407B133856C4B40DB8827BB995252407407B133856C4B40
52994	Розовка	5	53	422	73.659131000000002	73.695289000000002	54.722878000000001	54.700454999999998	0103000020E61000000100000005000000E831CA332F6A5240EBA86A82A8594B40E831CA332F6A5240BB7F2C44875C4B4030116F9D7F6C5240BB7F2C44875C4B4030116F9D7F6C5240EBA86A82A8594B40E831CA332F6A5240EBA86A82A8594B40
48717	Речной	5	53	422	73.789935	73.812016	54.681846999999998	54.670414999999998	0103000020E61000000100000005000000CFBD874B8E725240B9DFA128D0554B40CFBD874B8E72524017F032C346574B400AF5F411F873524017F032C346574B400AF5F411F8735240B9DFA128D0554B40CFBD874B8E725240B9DFA128D0554B40
49060	Ребровка	5	53	422	73.170107000000002	73.184676999999994	54.931308000000001	54.906756000000001	0103000020E6100000010000000500000086747808E34A5240D4B9A29410744B4086747808E34A52406840BD1935774B40B2D47ABFD14B52406840BD1935774B40B2D47ABFD14B5240D4B9A29410744B4086747808E34A5240D4B9A29410744B40
49090	Ракитинка	5	53	422	73.505205000000004	73.538343999999995	54.904255999999997	54.893731000000002	0103000020E61000000100000005000000A5315A4755605240F03504C765724B40A5315A47556052401B9B1DA9BE734B40DC7F643A746252401B9B1DA9BE734B40DC7F643A74625240F03504C765724B40A5315A4755605240F03504C765724B40
45977	Пятилетка	5	53	422	72.926196000000004	72.946066999999999	54.944352000000002	54.929198	0103000020E61000000100000005000000E86B96CB463B52401AC1C6F5EF764B40E86B96CB463B5240C3F4BD86E0784B40CA349A5C8C3C5240C3F4BD86E0784B40CA349A5C8C3C52401AC1C6F5EF764B40E86B96CB463B52401AC1C6F5EF764B40
48834	Пушкино	5	53	422	73.457432999999995	73.485872999999998	55.101745999999999	55.082318000000001	0103000020E610000001000000050000001DC70F95465D5240A2EF6E65898A4B401DC70F95465D5240D93F4F03068D4B409A40118B185F5240D93F4F03068D4B409A40118B185F5240A2EF6E65898A4B401DC70F95465D5240A2EF6E65898A4B40
7768	Путинцево	5	53	422	73.244450999999998	73.262184000000005	54.799101	54.793531999999999	0103000020E610000001000000050000005E9ECE15A54F52402C2AE27492654B405E9ECE15A54F5240B7990AF148664B403562669FC7505240B7990AF148664B403562669FC75052402C2AE27492654B405E9ECE15A54F52402C2AE27492654B40
2265	Покрово-Иртышское	5	53	422	74.128069999999994	74.161693999999997	54.560068999999999	54.554268999999998	0103000020E610000001000000050000005166834C32885240E3175E49F2464B405166834C3288524070404B57B0474B40677DCA31598A524070404B57B0474B40677DCA31598A5240E3175E49F2464B405166834C32885240E3175E49F2464B40
52995	Покровка	5	53	422	73.432388000000003	73.453847999999994	55.386594000000002	55.368630000000003	0103000020E61000000100000005000000B4CBB73EAC5B5240892991442FAF4B40B4CBB73EAC5B5240386A85E97BB14B40B8567BD80B5D5240386A85E97BB14B40B8567BD80B5D5240892991442FAF4B40B4CBB73EAC5B5240892991442FAF4B40
8684	Подгородка	5	53	422	73.539449000000005	73.558879000000005	55.148091999999998	55.139071999999999	0103000020E61000000100000005000000093719558662524008E57D1CCD914B4009371955866252404D66BCADF4924B40F5DA6CACC46352404D66BCADF4924B40F5DA6CACC463524008E57D1CCD914B40093719558662524008E57D1CCD914B40
40405	Петровка	5	53	422	73.025863999999999	73.063980000000001	54.964716000000003	54.954335999999998	0103000020E6100000010000000500000033897AC1A74152409EB29AAE277A4B4033897AC1A7415240C7F65AD07B7B4B4047E6913F18445240C7F65AD07B7B4B4047E6913F184452409EB29AAE277A4B4033897AC1A74152409EB29AAE277A4B40
49247	Омский	5	53	422	73.337418	73.363253	55.110366999999997	55.095481999999997	0103000020E610000001000000050000003BC5AA4198555240A7AD11C1388C4B403BC5AA419855524060C77F81208E4B4021CB82893F57524060C77F81208E4B4021CB82893F575240A7AD11C1388C4B403BC5AA4198555240A7AD11C1388C4B40
46636	Новотроицкое	5	53	422	73.140129999999999	73.177229999999994	55.275734	55.263249999999999	0103000020E6100000010000000500000010CCD1E3F748524004560E2DB2A14B4010CCD1E3F7485240983270404BA34B40AF777FBC574B5240983270404BA34B40AF777FBC574B524004560E2DB2A14B4010CCD1E3F748524004560E2DB2A14B40
7642	Новоомский	5	53	422	73.289996000000002	73.478425999999999	54.853397000000001	54.833053999999997	0103000020E6100000010000000500000022FE614B8F525240A7E67283A16A4B4022FE614B8F52524094C0E61C3C6D4B4097E315889E5E524094C0E61C3C6D4B4097E315889E5E5240A7E67283A16A4B4022FE614B8F525240A7E67283A16A4B40
46133	Никоновка	5	53	422	73.542377000000002	73.573531000000003	55.373854000000001	55.359347999999997	0103000020E610000001000000050000009146054EB662524006F1811DFFAD4B409146054EB662524049BDA772DAAF4B40800F5EBBB464524049BDA772DAAF4B40800F5EBBB464524006F1811DFFAD4B409146054EB662524006F1811DFFAD4B40
48732	Николенко	5	53	422	73.868825000000001	73.877753999999996	54.796205	54.787244999999999	0103000020E610000001000000050000009F3C2CD49A7752404278B471C4644B409F3C2CD49A775240B2F4A10BEA654B40B9FB1C1F2D785240B2F4A10BEA654B40B9FB1C1F2D7852404278B471C4644B409F3C2CD49A7752404278B471C4644B40
6855	Нижняя Ильинка	5	53	422	73.223916000000003	73.247550000000004	55.390787000000003	55.372472000000002	0103000020E610000001000000050000004643C6A3544E52407E569929ADAF4B404643C6A3544E5240DA59F44E05B24B40FD87F4DBD74F5240DA59F44E05B24B40FD87F4DBD74F52407E569929ADAF4B404643C6A3544E52407E569929ADAF4B40
49475	Нива	5	53	422	73.778211999999996	73.788398999999998	54.757024999999999	54.745162999999998	0103000020E61000000100000005000000B456B439CE71524039984D80615F4B40B456B439CE71524090A0F831E6604B40BE4C14217572524090A0F831E6604B40BE4C14217572524039984D80615F4B40B456B439CE71524039984D80615F4B40
49119	Надеждино	5	53	422	73.231703999999993	73.269891000000001	55.202146999999997	55.189582999999999	0103000020E610000001000000050000008D96033DD44E52405470784144984B408D96033DD44E524004FEF0F3DF994B40069FE6E44551524004FEF0F3DF994B40069FE6E4455152405470784144984B408D96033DD44E52405470784144984B40
41365	Морозовка	5	53	422	73.536781000000005	73.570036000000002	54.930050999999999	54.917395999999997	0103000020E610000001000000050000004F07B29E5A62524098BD6C3B6D754B404F07B29E5A625240594E42E90B774B40BB6246787B645240594E42E90B774B40BB6246787B64524098BD6C3B6D754B404F07B29E5A62524098BD6C3B6D754B40
48546	Мельничное	5	53	422	73.030544000000006	73.048554999999993	55.027371000000002	55.020161999999999	0103000020E61000000100000005000000B345D26EF44152409C4F1DAB94824B40B345D26EF4415240EEED96E480834B40AA436E861B435240EEED96E480834B40AA436E861B4352409C4F1DAB94824B40B345D26EF44152409C4F1DAB94824B40
24765	Лузино	5	53	422	73.007547000000002	73.047764999999998	54.953648999999999	54.934407	0103000020E61000000100000005000000B58B69A67B405240A51309A69A774B40B58B69A67B4052407A6EA12B117A4B402E39EE940E4352407A6EA12B117A4B402E39EE940E435240A51309A69A774B40B58B69A67B405240A51309A69A774B40
46284	Красноярка	5	53	422	73.072558000000001	73.117617999999993	55.336661999999997	55.309590999999998	0103000020E610000001000000050000000B444FCAA444524066118AADA0A74B400B444FCAA444524029E78BBD17AB4B40F0DAA50D8747524029E78BBD17AB4B40F0DAA50D8747524066118AADA0A74B400B444FCAA444524066118AADA0A74B40
2956	Красная Тула	5	53	422	74.287440000000004	74.302189999999996	54.650506	54.639862000000001	0103000020E61000000100000005000000FCE3BD6A6592524001FA7DFFE6514B40FCE3BD6A6592524007EDD5C743534B4068CBB9145793524007EDD5C743534B4068CBB9145793524001FA7DFFE6514B40FCE3BD6A6592524001FA7DFFE6514B40
48835	Красная Горка	5	53	422	73.098519999999994	73.136949999999999	55.126776	55.110944000000003	0103000020E610000001000000050000001F80D4264E465240FED7B969338E4B401F80D4264E46524077F52A323A904B40FBCBEEC9C348524077F52A323A904B40FBCBEEC9C3485240FED7B969338E4B401F80D4264E465240FED7B969338E4B40
53105	Комсомол	5	53	422	74.037142000000003	74.054516000000007	54.649369999999998	54.640174999999999	0103000020E61000000100000005000000B7D3D68860825240C05B2041F1514B40B7D3D688608252407380608E1E534B40F646AD307D8352407380608E1E534B40F646AD307D835240C05B2041F1514B40B7D3D68860825240C05B2041F1514B40
49226	Ключи	5	53	422	73.206631999999999	73.228703999999993	55.163986000000001	55.146126000000002	0103000020E61000000100000005000000A7936C75394D5240338CBB41B4924B40A7936C75394D52403D80457EFD944B40B81D1A16A34E52403D80457EFD944B40B81D1A16A34E5240338CBB41B4924B40A7936C75394D5240338CBB41B4924B40
8555	Классино	5	53	422	73.490536000000006	73.514708999999996	55.315980000000003	55.310738999999998	0103000020E61000000100000005000000AF601BF1645F5240BE4BA94BC6A74B40AF601BF1645F524055185B0872A84B403D7D04FEF060524055185B0872A84B403D7D04FEF0605240BE4BA94BC6A74B40AF601BF1645F5240BE4BA94BC6A74B40
49340	Калиновка	5	53	422	73.600858000000002	73.619983000000005	55.204484999999998	55.196947000000002	0103000020E610000001000000050000008FE21C7574665240CD052E8F35994B408FE21C7574665240E3C281902C9A4B40DD442DCDAD675240E3C281902C9A4B40DD442DCDAD675240CD052E8F35994B408FE21C7574665240CD052E8F35994B40
46364	Калинино	5	53	422	73.742943999999994	73.764944	54.863351999999999	54.846690000000002	0103000020E610000001000000050000009AB0FD648C6F5240D5EC8156606C4B409AB0FD648C6F5240D5777E51826E4B405FD1ADD7F4705240D5777E51826E4B405FD1ADD7F4705240D5EC8156606C4B409AB0FD648C6F5240D5EC8156606C4B40
49173	Калачево	5	53	422	73.316325000000006	73.334650999999994	54.768442999999998	54.764375999999999	0103000020E61000000100000005000000107A36AB3E54524074ECA012D7614B40107A36AB3E54524089EB18575C624B40B72407EC6A55524089EB18575C624B40B72407EC6A55524074ECA012D7614B40107A36AB3E54524074ECA012D7614B40
14811	Иртышский	5	53	422	73.574078999999998	73.606346000000002	54.826686000000002	54.801223999999998	0103000020E610000001000000050000008194D8B5BD64524099620E828E664B408194D8B5BD645240D107CBD8D0694B40DE03745FCE665240D107CBD8D0694B40DE03745FCE66524099620E828E664B408194D8B5BD64524099620E828E664B40
48830	Дружино	5	53	422	73.117169000000004	73.141925999999998	55.031571999999997	55.015289000000003	0103000020E61000000100000005000000B9C667B27F475240897E6DFDF4814B40B9C667B27F47524012BC218D0A844B40EF1CCA501549524012BC218D0A844B40EF1CCA5015495240897E6DFDF4814B40B9C667B27F475240897E6DFDF4814B40
60838	Девятириковка	5	53	422	73.814396000000002	73.833305999999993	55.255585000000004	55.243377000000002	0103000020E61000000100000005000000917F66101F7452409FCC3FFA269F4B40917F66101F745240912C6002B7A04B40E063B0E254755240912C6002B7A04B40E063B0E2547552409FCC3FFA269F4B40917F66101F7452409FCC3FFA269F4B40
49135	Дачный	5	53	422	73.337498999999994	73.352104999999995	55.255144000000001	55.250320000000002	0103000020E61000000100000005000000B1DB67959955524072C45A7C0AA04B40B1DB679599555240A4E2FF8EA8A04B4084F068E388565240A4E2FF8EA8A04B4084F068E38856524072C45A7C0AA04B40B1DB67959955524072C45A7C0AA04B40
48860	Горячий Ключ	5	53	422	73.142285999999999	73.161465000000007	55.042937000000002	55.024909999999998	0103000020E610000001000000050000006F2BBD361B495240F3AB394030834B406F2BBD361B495240E964A9F57E854B40B79C4B71554A5240E964A9F57E854B40B79C4B71554A5240F3AB394030834B406F2BBD361B495240F3AB394030834B40
48662	Вперед	5	53	422	73.759625999999997	73.774986999999996	55.092112999999998	55.087578999999998	0103000020E610000001000000050000003ECC5EB69D7052407F68E6C9358B4B403ECC5EB69D705240AA44D95BCA8B4B40CFF4126399715240AA44D95BCA8B4B40CFF41263997152407F68E6C9358B4B403ECC5EB69D7052407F68E6C9358B4B40
8854	Верхний Карбуш	5	53	422	73.217843000000002	73.232566000000006	54.896034999999998	54.887222000000001	0103000020E61000000100000005000000672AC423F14D52405725917D90714B40672AC423F14D524022895E46B1724B40570A815CE24E524022895E46B1724B40570A815CE24E52405725917D90714B40672AC423F14D52405725917D90714B40
49291	Бородинка	5	53	422	73.667737000000002	73.687869000000006	55.308280000000003	55.290429000000003	0103000020E610000001000000050000001155F833BC6A5240AE6708C72CA54B401155F833BC6A5240650113B875A74B40AABBB20B066C5240650113B875A74B40AABBB20B066C5240AE6708C72CA54B401155F833BC6A5240AE6708C72CA54B40
53092	Богословка	5	53	422	73.704639999999998	73.739637999999999	55.040477000000003	55.029657	0103000020E6100000010000000500000005DD5ED2186D52407A8CF2CCCB834B4005DD5ED2186D5240BF9EAF592E854B403F389F3A566F5240BF9EAF592E854B403F389F3A566F52407A8CF2CCCB834B4005DD5ED2186D52407A8CF2CCCB834B40
8038	Березянка	5	53	422	73.392600999999999	73.400632000000002	55.188684000000002	55.182603	0103000020E610000001000000050000001FD8F15F205952406493FC885F974B401FD8F15F20595240A5A31CCC26984B40CA6E66F4A3595240A5A31CCC26984B40CA6E66F4A35952406493FC885F974B401FD8F15F205952406493FC885F974B40
30711	Ачаирский	5	53	422	73.966139999999996	74.019131000000002	54.616304	54.589905000000002	0103000020E61000000100000005000000E0D6DD3CD57D52409A5FCD01824B4B40E0D6DD3CD57D52406E32AA0CE34E4B40BFD53A71398152406E32AA0CE34E4B40BFD53A71398152409A5FCD01824B4B40E0D6DD3CD57D52409A5FCD01824B4B40
6358	Ачаир	5	53	422	73.835435000000004	73.902341000000007	54.664672000000003	54.648401	0103000020E61000000100000005000000C3BB5CC477755240CBD8D0CDFE524B40C3BB5CC4777552409148DBF813554B40C23577F4BF7952409148DBF813554B40C23577F4BF795240CBD8D0CDFE524B40C3BB5CC477755240CBD8D0CDFE524B40
48678	Андреевский	5	53	422	73.705961000000002	73.715329999999994	55.096089999999997	55.089181000000004	0103000020E6100000010000000500000018D00B772E6D5240593673486A8B4B4018D00B772E6D52407FBC57AD4C8C4B4040F67AF7C76D52407FBC57AD4C8C4B4040F67AF7C76D5240593673486A8B4B4018D00B772E6D5240593673486A8B4B40
53087	Андреевка	5	53	422	73.601037000000005	73.635954999999996	55.047497	55.036917000000003	0103000020E61000000100000005000000E7ABE463776652404ED53DB2B9844B40E7ABE463776652403DD4B66114864B4092AE997CB36852403DD4B66114864B4092AE997CB36852404ED53DB2B9844B40E7ABE463776652404ED53DB2B9844B40
4932	Язово	5	53	636	75.535855999999995	75.550928999999996	54.768639999999998	54.756849000000003	0103000020E6100000010000000500000062D7F6764BE252405281936DE0604B4062D7F6764BE25240DF32A7CB62624B40C05AB56B42E35240DF32A7CB62624B40C05AB56B42E352405281936DE0604B4062D7F6764BE252405281936DE0604B40
4848	Чистово	5	53	636	75.536816999999999	75.577635999999998	54.692146000000001	54.6708	0103000020E61000000100000005000000F5BBB0355BE2524012143FC6DC554B40F5BBB0355BE252405307793D98584B40813FFCFCF7E452405307793D98584B40813FFCFCF7E4524012143FC6DC554B40F5BBB0355BE2524012143FC6DC554B40
4536	Стрельниково	5	53	636	74.979304999999997	74.996947000000006	54.753481999999998	54.743192999999998	0103000020E61000000100000005000000CBF3E0EEACBE5240DDCEBEF2205F4B40CBF3E0EEACBE5240F50F221972604B401A36CAFACDBF5240F50F221972604B401A36CAFACDBF5240DDCEBEF2205F4B40CBF3E0EEACBE5240DDCEBEF2205F4B40
6160	Соловьевка	5	53	636	75.021030999999994	75.027283999999995	54.996308999999997	54.985674000000003	0103000020E61000000100000005000000F04C689258C152403E42CD902A7E4B40F04C689258C15240F0DAA50D877F4B400FED6305BFC15240F0DAA50D877F4B400FED6305BFC152403E42CD902A7E4B40F04C689258C152403E42CD902A7E4B40
5628	Сергеевка	5	53	636	74.853954000000002	74.889105000000001	54.822136999999998	54.808000999999997	0103000020E610000001000000050000007592AD2EA7B652405111A7936C674B407592AD2EA7B6524070EA03C93B694B40726DA818E7B8524070EA03C93B694B40726DA818E7B852405111A7936C674B407592AD2EA7B652405111A7936C674B40
5410	Рождественка	5	53	636	74.991405	75.014249000000007	54.619509999999998	54.610323999999999	0103000020E61000000100000005000000D105F52D73BF524061FBC9181F4E4B40D105F52D73BF5240C1C58A1A4C4F4B400C40A374E9C05240C1C58A1A4C4F4B400C40A374E9C0524061FBC9181F4E4B40D105F52D73BF524061FBC9181F4E4B40
4725	Пресновка	5	53	636	75.286914999999993	75.304225000000002	54.812291000000002	54.801575999999997	0103000020E61000000100000005000000D66EBBD05CD2524016A1D80A9A664B40D66EBBD05CD25240E6EAC726F9674B400A68226C78D35240E6EAC726F9674B400A68226C78D3524016A1D80A9A664B40D66EBBD05CD2524016A1D80A9A664B40
5742	Павловка	5	53	636	74.648679999999999	74.65822	54.847188000000003	54.834361000000001	0103000020E610000001000000050000006F641EF983A9524068075C57CC6A4B406F641EF983A9524026C808A8706C4B40AE64C74620AA524026C808A8706C4B40AE64C74620AA524068075C57CC6A4B406F641EF983A9524068075C57CC6A4B40
5166	Орловка	5	53	636	75.282647999999995	75.297720999999996	54.735895999999997	54.724739	0103000020E61000000100000005000000E811A3E716D2524060915F3FC45C4B40E811A3E716D25240ECA012D7315E4B40469561DC0DD35240ECA012D7315E4B40469561DC0DD3524060915F3FC45C4B40E811A3E716D2524060915F3FC45C4B40
5828	Ольховка	5	53	636	74.886823000000007	74.903486999999998	54.787239999999997	54.780495999999999	0103000020E61000000100000005000000CD9541B5C1B852405454FD4AE7634B40CD9541B5C1B85240300DC347C4644B401D5723BBD2B95240300DC347C4644B401D5723BBD2B952405454FD4AE7634B40CD9541B5C1B852405454FD4AE7634B40
4321	Оконешниково	5	53	636	75.052121999999997	75.110809000000003	54.859808000000001	54.824472	0103000020E61000000100000005000000BC5983F755C35240DE3B6A4C88694B40BC5983F755C352406A6B44300E6E4B408FC6A17E17C752406A6B44300E6E4B408FC6A17E17C75240DE3B6A4C88694B40BC5983F755C35240DE3B6A4C88694B40
6125	Николаевка	5	53	636	74.975127000000001	75.003110000000007	54.958953000000001	54.943539999999999	0103000020E61000000100000005000000959C137B68BE5240E23B31EBC5784B40959C137B68BE524057B3CEF8BE7A4B40991249F432C0524057B3CEF8BE7A4B40991249F432C05240E23B31EBC5784B40959C137B68BE5240E23B31EBC5784B40
4524	Михайловка	5	53	636	75.186456000000007	75.199112999999997	54.733291000000001	54.724795999999998	0103000020E61000000100000005000000278925E5EECB5240C422861DC65C4B40278925E5EECB5240BFB9BF7ADC5D4B4057CD7344BECC5240BFB9BF7ADC5D4B4057CD7344BECC5240C422861DC65C4B40278925E5EECB5240C422861DC65C4B40
5445	Маяк	5	53	636	75.042141999999998	75.070564000000005	54.568192000000003	54.551777999999999	0103000020E610000001000000050000006FF25B74B2C252407E5358A9A0464B406FF25B74B2C25240A7ECF483BA484B409911DE1E84C45240A7ECF483BA484B409911DE1E84C452407E5358A9A0464B406FF25B74B2C252407E5358A9A0464B40
5559	Мариновка	5	53	636	75.299301999999997	75.316703000000004	54.575029000000001	54.564047000000002	0103000020E61000000100000005000000276893C327D3524016342DB132484B40276893C327D3524034A0DE8C9A494B40E3E2A8DC44D4524034A0DE8C9A494B40E3E2A8DC44D4524016342DB132484B40276893C327D3524016342DB132484B40
5209	Любимовка	5	53	636	75.100864999999999	75.123205999999996	54.674908000000002	54.656869999999998	0103000020E61000000100000005000000E813799274C652409CDCEF5014544B40E813799274C6524086E7A56263564B40F12A6B9BE2C7524086E7A56263564B40F12A6B9BE2C752409CDCEF5014544B40E813799274C652409CDCEF5014544B40
5062	Ленинск	5	53	636	75.478785999999999	75.494838999999999	54.543464	54.535676000000002	0103000020E6100000010000000500000017F2086EA4DE524045A0FA0791444B4017F2086EA4DE5240D446753A90454B4043723271ABDF5240D446753A90454B4043723271ABDF524045A0FA0791444B4017F2086EA4DE524045A0FA0791444B40
4700	Куломзино	5	53	636	75.455160000000006	75.479433	54.838259999999998	54.827567999999999	0103000020E61000000100000005000000A29C685721DD5240AA9B8BBFED694B40A29C685721DD5240C1C58A1A4C6B4B40E2E7BF07AFDE5240C1C58A1A4C6B4B40E2E7BF07AFDE5240AA9B8BBFED694B40A29C685721DD5240AA9B8BBFED694B40
4998	Крестики	5	53	636	75.419425000000004	75.449977000000004	54.633578	54.618873999999998	0103000020E61000000100000005000000FD87F4DBD7DA52401F2C6343374F4B40FD87F4DBD7DA524088BB7A1519514B40F1BC546CCCDC524088BB7A1519514B40F1BC546CCCDC52401F2C6343374F4B40FD87F4DBD7DA52401F2C6343374F4B40
4643	Красовка	5	53	636	75.161698000000001	75.183554000000001	54.935167	54.916465000000002	0103000020E610000001000000050000000875914259CA5240DE76A1B94E754B400875914259CA524033A6608DB3774B4033C34659BFCB524033A6608DB3774B4033C34659BFCB5240DE76A1B94E754B400875914259CA5240DE76A1B94E754B40
5680	Кочковатое	5	53	636	74.657250000000005	74.671254000000005	54.757275	54.749600000000001	0103000020E61000000100000005000000F2D24D6210AA5240728A8EE4F25F4B40F2D24D6210AA5240098A1F63EE604B40CA5356D3F5AA5240098A1F63EE604B40CA5356D3F5AA5240728A8EE4F25F4B40F2D24D6210AA5240728A8EE4F25F4B40
5339	Костяковка	5	53	636	75.066305999999997	75.090264000000005	54.707295999999999	54.702145999999999	0103000020E61000000100000005000000D461855B3EC4524034828DEBDF594B40D461855B3EC45240BA4BE2AC885A4B406500A8E2C6C55240BA4BE2AC885A4B406500A8E2C6C5524034828DEBDF594B40D461855B3EC4524034828DEBDF594B40
5310	Кирилловка	5	53	636	75.170636999999999	75.186222000000001	54.651594000000003	54.646458000000003	0103000020E61000000100000005000000349F73B7EBCA5240691EC022BF524B40349F73B7EBCA52408A22A46E67534B40EDF2AD0FEBCB52408A22A46E67534B40EDF2AD0FEBCB5240691EC022BF524B40349F73B7EBCA5240691EC022BF524B40
5228	Камышино	5	53	636	74.866099000000006	74.887621999999993	54.695481000000001	54.689163999999998	0103000020E610000001000000050000004B06802A6EB752404FCAA48636584B404B06802A6EB75240A4FE7A8505594B40724D81CCCEB85240A4FE7A8505594B40724D81CCCEB852404FCAA48636584B404B06802A6EB752404FCAA48636584B40
5915	Золотая Нива	5	53	636	74.886131000000006	74.921705000000003	54.906506999999998	54.887616000000001	0103000020E61000000100000005000000323ECC5EB6B8524003B4AD669D714B40323ECC5EB6B852402B4CDF6B08744B40D2E3F736FDBA52402B4CDF6B08744B40D2E3F736FDBA524003B4AD669D714B40323ECC5EB6B8524003B4AD669D714B40
6057	Елизаветино	5	53	636	74.756018999999995	74.780382000000003	54.882297000000001	54.867880999999997	0103000020E61000000100000005000000E509849D62B05240EEE87FB9166F4B40E509849D62B05240F12DAC1BEF704B40C61858C7F1B15240F12DAC1BEF704B40C61858C7F1B15240EEE87FB9166F4B40E509849D62B05240EEE87FB9166F4B40
5803	Волчино	5	53	636	74.952552999999995	74.962316999999999	54.801462000000001	54.794756999999997	0103000020E610000001000000050000003AADDBA0F6BC52402FA2ED98BA654B403AADDBA0F6BC52404E7E8B4E96664B40A1D80A9A96BD52404E7E8B4E96664B40A1D80A9A96BD52402FA2ED98BA654B403AADDBA0F6BC52402FA2ED98BA654B40
5974	Березовка	5	53	636	74.921443999999994	74.931540999999996	54.864601	54.855009000000003	0103000020E610000001000000050000001B4641F0F8BA5240916456EF706D4B401B4641F0F8BA5240618BDD3EAB6E4B408578245E9EBB5240618BDD3EAB6E4B408578245E9EBB5240916456EF706D4B401B4641F0F8BA5240916456EF706D4B40
5529	Андреевка	5	53	636	75.075038000000006	75.085314999999994	54.538125999999998	54.531689999999998	0103000020E6100000010000000500000044FD2E6CCDC452401CCEFC6A0E444B4044FD2E6CCDC452404B901150E1444B40EDB60BCD75C552404B901150E1444B40EDB60BCD75C552401CCEFC6A0E444B4044FD2E6CCDC452401CCEFC6A0E444B40
4910	Алексеевка	5	53	636	75.439413000000002	75.452717000000007	54.776040999999999	54.763263999999999	0103000020E61000000100000005000000FC1BB4571FDC5240691B7FA2B2614B40FC1BB4571FDC524075ADBD4F55634B40F855B950F9DC524075ADBD4F55634B40F855B950F9DC5240691B7FA2B2614B40FC1BB4571FDC5240691B7FA2B2614B40
47874	Цветково	5	53	527	72.490971000000002	72.509062999999998	54.083491000000002	54.069111999999997	0103000020E610000001000000050000003412A1116C1F52406DE179A9D8084B403412A1116C1F5240534145D5AF0A4B40A226FA7C94205240534145D5AF0A4B40A226FA7C942052406DE179A9D8084B403412A1116C1F52406DE179A9D8084B40
47794	Тишанка	5	53	527	72.899507	72.911615999999995	54.316077	54.309984	0103000020E610000001000000050000007AE1CE85913952404224438EAD274B407AE1CE859139524047020D3675284B40A9A0A2EA573A524047020D3675284B40A9A0A2EA573A52404224438EAD274B407AE1CE85913952404224438EAD274B40
3194	Славгородка	5	53	527	72.921947000000003	72.942751999999999	54.119635000000002	54.110362000000002	0103000020E610000001000000050000004D69FD2D013B52404F5C8E57200E4B404D69FD2D013B52407E3A1E33500F4B40450F7C0C563C52407E3A1E33500F4B40450F7C0C563C52404F5C8E57200E4B404D69FD2D013B52404F5C8E57200E4B40
3715	Сарат	5	53	527	73.077894000000001	73.101583000000005	54.368395999999997	54.364109999999997	0103000020E610000001000000050000007FA31D37FC445240C2120F289B2E4B407FA31D37FC44524015FDA199272F4B4018B5FB558046524015FDA199272F4B4018B5FB5580465240C2120F289B2E4B407FA31D37FC445240C2120F289B2E4B40
47899	Побочино	5	53	527	72.658004000000005	72.692751000000001	54.203555999999999	54.189628999999996	0103000020E61000000100000005000000C828CFBC1C2A5240C4AF58C345184B40C828CFBC1C2A5240C9737D1F0E1A4B405D514A08562C5240C9737D1F0E1A4B405D514A08562C5240C4AF58C345184B40C828CFBC1C2A5240C4AF58C345184B40
47753	Песчанка	5	53	527	73.159425999999996	73.180293000000006	54.343935000000002	54.336433999999997	0103000020E6100000010000000500000074081C09344A524098A1F144102B4B4074081C09344A52409279E40F062C4B40A8ACA6EB894B52409279E40F062C4B40A8ACA6EB894B524098A1F144102B4B4074081C09344A524098A1F144102B4B40
47811	Орехово	5	53	527	72.477793000000005	72.499010999999996	53.989410999999997	53.976523999999998	0103000020E610000001000000050000007F501729941E52402AE109BDFEFC4A407F501729941E5240BDA60705A5FE4A400856D5CBEF1F5240BDA60705A5FE4A400856D5CBEF1F52402AE109BDFEFC4A407F501729941E52402AE109BDFEFC4A40
47570	Одесское	5	53	527	72.941404000000006	72.991557	54.220232000000003	54.200491	0103000020E61000000100000005000000B61490F63F3C5240381268B0A9194B40B61490F63F3C52402FC4EA8F301C4B40ACC77DAB753F52402FC4EA8F301C4B40ACC77DAB753F5240381268B0A9194B40B61490F63F3C5240381268B0A9194B40
47722	Лукьяновка	5	53	527	73.038934999999995	73.068219999999997	54.324221999999999	54.306711999999997	0103000020E61000000100000005000000DDEA39E97D42524037A5BC5642274B40DDEA39E97D4252406552431B80294B40B83B6BB75D4452406552431B80294B40B83B6BB75D44524037A5BC5642274B40DDEA39E97D42524037A5BC5642274B40
47684	Желанное	5	53	527	72.559809000000001	72.594375999999997	54.176240999999997	54.147419999999997	0103000020E610000001000000050000006AC020E9D32352405E6397A8DE124B406AC020E9D32352406F9BA9108F164B40BF61A2410A2652406F9BA9108F164B40BF61A2410A2652405E6397A8DE124B406AC020E9D32352405E6397A8DE124B40
3935	Громогласово	5	53	527	72.670302000000007	72.700530000000001	53.975459000000001	53.963866000000003	0103000020E61000000100000005000000611C5C3AE62A5240F9DC09F65FFB4A40611C5C3AE62A524060CB2BD7DBFC4A407BF7C77BD52C524060CB2BD7DBFC4A407BF7C77BD52C5240F9DC09F65FFB4A40611C5C3AE62A5240F9DC09F65FFB4A40
47740	Генераловка	5	53	527	73.188827000000003	73.212399000000005	54.256107999999998	54.240898999999999	0103000020E610000001000000050000008466D7BD154C5240CE5147C7D51E4B408466D7BD154C52403A1F9E25C8204B4000ADF9F1974D52403A1F9E25C8204B4000ADF9F1974D5240CE5147C7D51E4B408466D7BD154C5240CE5147C7D51E4B40
47660	Ганновка	5	53	527	73.248088999999993	73.279332999999994	54.117339000000001	54.098790000000001	0103000020E61000000100000005000000D45FAFB0E04F5240FF959526A50C4B40D45FAFB0E04F5240CEC5DFF6040F4B4063EC8497E0515240CEC5DFF6040F4B4063EC8497E0515240FF959526A50C4B40D45FAFB0E04F5240FF959526A50C4B40
3343	Буняковка	5	53	527	73.148528999999996	73.175757000000004	54.135705999999999	54.117977000000003	0103000020E610000001000000050000007C60C77F814952401157CEDE190F4B407C60C77F814952407CEF6FD05E114B40C2C2499A3F4B52407CEF6FD05E114B40C2C2499A3F4B52401157CEDE190F4B407C60C77F814952401157CEDE190F4B40
3524	Брезицк	5	53	527	72.488069999999993	72.510643999999999	54.193885999999999	54.184925	0103000020E61000000100000005000000280AF4893C1F52403D9B559FAB174B40280AF4893C1F52407D93A641D1184B4083F92B64AE2052407D93A641D1184B4083F92B64AE2052403D9B559FAB174B40280AF4893C1F52403D9B559FAB174B40
47826	Бобровица	5	53	527	72.409143999999998	72.420382000000004	54.090916999999997	54.082968000000001	0103000020E61000000100000005000000B2D6506A2F1A5240A94E07B29E0A4B40B2D6506A2F1A524041D3122BA30B4B40EF74E789E71A524041D3122BA30B4B40EF74E789E71A5240A94E07B29E0A4B40B2D6506A2F1A5240A94E07B29E0A4B40
47624	Благодаровка	5	53	527	73.165103000000002	73.195080000000004	54.080105000000003	54.063837999999997	0103000020E610000001000000050000002D5E2C0C914A5240FB1EF5D72B084B402D5E2C0C914A5240809F71E1400A4B40A306D3307C4C5240809F71E1400A4B40A306D3307C4C5240FB1EF5D72B084B402D5E2C0C914A5240FB1EF5D72B084B40
47612	Белосток	5	53	527	72.767527000000001	72.796982	54.175255	54.161915	0103000020E6100000010000000500000002F390291F315240ADDD76A1B9144B4002F390291F315240F1BA7EC16E164B400B60CAC001335240F1BA7EC16E164B400B60CAC001335240ADDD76A1B9144B4002F390291F315240ADDD76A1B9144B40
53091	Черлакское	5	53	266	74.494645000000006	74.531135000000006	53.785699000000001	53.769545000000001	0103000020E6100000010000000500000051888043A89F524071E6577380E24A4051888043A89F5240FDBFEAC891E44A40B4B0A71DFEA15240FDBFEAC891E44A40B4B0A71DFEA1524071E6577380E24A4051888043A89F524071E6577380E24A40
40474	Славянка	5	53	266	74.513259000000005	74.546119000000004	54.186331000000003	54.169989999999999	0103000020E610000001000000050000002CD8463CD9A05240D252793BC2154B402CD8463CD9A05240919DB7B1D9174B405A2E1B9DF3A25240919DB7B1D9174B405A2E1B9DF3A25240D252793BC2154B402CD8463CD9A05240D252793BC2154B40
2155	Сибирское	5	53	266	74.844476	74.856559000000004	54.014341999999999	54.005288999999998	0103000020E61000000100000005000000719010E50BB65240A703594FAD004B40719010E50BB65240C87A6AF5D5014B400C06D7DCD1B65240C87A6AF5D5014B400C06D7DCD1B65240A703594FAD004B40719010E50BB65240A703594FAD004B40
61442	Русановка	5	53	266	74.544538000000003	74.565864000000005	54.130003000000002	54.116278000000001	0103000020E61000000100000005000000795BE9B5D9A25240459F8F32E20E4B40795BE9B5D9A25240E2B034F0A3104B40F67EA31D37A45240E2B034F0A3104B40F67EA31D37A45240459F8F32E20E4B40795BE9B5D9A25240459F8F32E20E4B40
1963	Рассохино	5	53	266	74.613653999999997	74.623410000000007	54.244840000000003	54.236932000000003	0103000020E61000000100000005000000D0436D1B46A752401DB0ABC9531E4B40D0436D1B46A752405760C8EA561F4B40F67F0EF3E5A752405760C8EA561F4B40F67F0EF3E5A752401DB0ABC9531E4B40D0436D1B46A752401DB0ABC9531E4B40
46354	Победа	5	53	266	74.477586000000002	74.497574	54.055605	54.045408000000002	0103000020E61000000100000005000000C2C1DEC4909E5240077DE9EDCF054B40C2C1DEC4909E52403E3F8C101E074B40C1559E40D89F52403E3F8C101E074B40C1559E40D89F5240077DE9EDCF054B40C2C1DEC4909E5240077DE9EDCF054B40
2997	Платоновка	5	53	266	74.667320000000004	74.683588	53.888727000000003	53.87764	0103000020E61000000100000005000000DFFDF15EB5AA5240AAD4EC8156F04A40DFFDF15EB5AA52403E096CCEC1F14A4009FCE1E7BFAB52403E096CCEC1F14A4009FCE1E7BFAB5240AAD4EC8156F04A40DFFDF15EB5AA5240AAD4EC8156F04A40
2859	Пичугино	5	53	266	74.591420999999997	74.599973000000006	53.766697000000001	53.761209999999998	0103000020E61000000100000005000000BA4A77D7D9A55240AFB14B546FE14A40BA4A77D7D9A552407D78962023E24A40EA5E27F565A652407D78962023E24A40EA5E27F565A65240AFB14B546FE14A40BA4A77D7D9A55240AFB14B546FE14A40
53042	Новороссийка	5	53	266	74.660653999999994	74.679599999999994	54.119508000000003	54.105331	0103000020E610000001000000050000002EFEB62748AA5240A320787C7B0D4B402EFEB62748AA524021CEC3094C0F4B402497FF907EAB524021CEC3094C0F4B402497FF907EAB5240A320787C7B0D4B402EFEB62748AA5240A320787C7B0D4B40
1765	Новоивановка	5	53	266	74.402640000000005	74.417911000000004	54.392538000000002	54.386451000000001	0103000020E61000000100000005000000EF0390DAC4995240D540F33977314B40EF0390DAC4995240F83768AF3E324B40E068C70DBF9A5240F83768AF3E324B40E068C70DBF9A5240D540F33977314B40EF0390DAC4995240D540F33977314B40
52967	Нововаршавка	5	53	266	74.672072	74.719888999999995	54.183692000000001	54.151364999999998	0103000020E61000000100000005000000AB23473A03AB52402861A6ED5F134B40AB23473A03AB5240B7442E3883174B4002F04FA912AE5240B7442E3883174B4002F04FA912AE52402861A6ED5F134B40AB23473A03AB52402861A6ED5F134B40
1909	Нетесово	5	53	266	74.405541999999997	74.413932000000003	54.236373999999998	54.227696000000002	0103000020E61000000100000005000000E2C96E66F49952400BB77C24251D4B40E2C96E66F4995240F6CFD380411E4B4025B1A4DC7D9A5240F6CFD380411E4B4025B1A4DC7D9A52400BB77C24251D4B40E2C96E66F49952400BB77C24251D4B40
2417	Моисеевка	5	53	266	74.566249999999997	74.575772000000001	53.934493000000003	53.930576000000002	0103000020E610000001000000050000000AD7A3703DA45240A438471D1DF74A400AD7A3703DA45240A4AB74779DF74A40F67CCD72D9A45240A4AB74779DF74A40F67CCD72D9A45240A438471D1DF74A400AD7A3703DA45240A438471D1DF74A40
2612	Любовский	5	53	266	74.445481000000001	74.465432000000007	54.152588000000002	54.142161999999999	0103000020E61000000100000005000000527FBDC2829C5240F25D4A5D32124B40527FBDC2829C52408BE1EA0088134B40C3A04CA3C99D52408BE1EA0088134B40C3A04CA3C99D5240F25D4A5D32124B40527FBDC2829C5240F25D4A5D32124B40
2645	Любовка	5	53	266	74.439013000000003	74.448741999999996	54.161808999999998	54.157186000000003	0103000020E610000001000000050000003561FBC9189C5240CDB1BCAB1E144B403561FBC9189C524067994528B6144B40DD955D30B89C524067994528B6144B40DD955D30B89C5240CDB1BCAB1E144B403561FBC9189C5240CDB1BCAB1E144B40
1118	Красный Яр	5	53	266	74.717310999999995	74.728369000000001	54.146951000000001	54.127254000000001	0103000020E61000000100000005000000E883656CE8AD52408124ECDB49104B40E883656CE8AD5240A88E554ACF124B40E59A02999DAE5240A88E554ACF124B40E59A02999DAE52408124ECDB49104B40E883656CE8AD52408124ECDB49104B40
53113	Караман	5	53	266	74.987415999999996	75.000720000000001	53.859684999999999	53.848737999999997	0103000020E6100000010000000500000004E3E0D231BF5240AC6F6072A3EC4A4004E3E0D231BF52404EEE77280AEE4A40001DE6CB0BC052404EEE77280AEE4A40001DE6CB0BC05240AC6F6072A3EC4A4004E3E0D231BF5240AC6F6072A3EC4A40
2361	Каразюк	5	53	266	74.547341000000003	74.560563999999999	54.073618000000003	54.062232000000002	0103000020E61000000100000005000000A3B08BA207A35240E161DA37F7074B40A3B08BA207A35240CF328B506C094B4028D4D347E0A35240CF328B506C094B4028D4D347E0A35240E161DA37F7074B40A3B08BA207A35240E161DA37F7074B40
60837	Изумрудное	5	53	266	74.630273000000003	74.640998999999994	54.221663999999997	54.213793000000003	0103000020E6100000010000000500000051A3906456A852408F8EAB915D1B4B4051A3906456A85240AB59677C5F1C4B403271AB2006A95240AB59677C5F1C4B403271AB2006A952408F8EAB915D1B4B4051A3906456A852408F8EAB915D1B4B40
60858	Жар-Агач	5	53	266	74.507966999999994	74.520436000000004	54.368391000000003	54.362867000000001	0103000020E610000001000000050000009F1C058882A0524019E6046D722E4B409F1C058882A052400492B06F272F4B404FEACBD24EA152400492B06F272F4B404FEACBD24EA1524019E6046D722E4B409F1C058882A0524019E6046D722E4B40
53120	Ермаковка	5	53	266	74.082795000000004	75.026797999999999	54.402496999999997	53.668995000000002	0103000020E610000001000000050000006E5166834C8552400118CFA0A1D54A406E5166834C8552407ADE8D0585334B404966F50EB7C152407ADE8D0585334B404966F50EB7C152400118CFA0A1D54A406E5166834C8552400118CFA0A1D54A40
2310	Дробышево	5	53	266	74.661265	74.688761999999997	53.993645999999998	53.979329999999997	0103000020E61000000100000005000000533F6F2A52AA5240EFFE78AF5AFD4A40533F6F2A52AA52408EE6C8CA2FFF4A40902E36AD14AC52408EE6C8CA2FFF4A40902E36AD14AC5240EFFE78AF5AFD4A40533F6F2A52AA5240EFFE78AF5AFD4A40
61475	Большегривское	5	53	266	74.889562999999995	74.926384999999996	53.921408999999997	53.909492999999998	0103000020E61000000100000005000000D32EA699EEB85240707841446AF44A40D32EA699EEB85240BA9EE8BAF0F54A4051A04FE449BB5240BA9EE8BAF0F54A4051A04FE449BB5240707841446AF44A40D32EA699EEB85240707841446AF44A40
2075	Богдановка	5	53	266	74.777884	74.797207	54.095585	54.083115999999997	0103000020E610000001000000050000003A05F9D9C8B152401DE38A8BA30A4B403A05F9D9C8B152407C7E18213C0C4B401B49827005B352407C7E18213C0C4B401B49827005B352401DE38A8BA30A4B403A05F9D9C8B152401DE38A8BA30A4B40
61485	Бобринка	5	53	266	74.227503999999996	74.253026000000006	54.129416999999997	54.108429999999998	0103000020E6100000010000000500000063EDEF6C8F8E5240E0F3C308E10D4B4063EDEF6C8F8E5240F1457BBC90104B406AC2F69331905240F1457BBC90104B406AC2F69331905240E0F3C308E10D4B4063EDEF6C8F8E5240E0F3C308E10D4B40
1573	Береговое	5	53	266	74.903683999999998	74.921130000000005	53.950149000000003	53.943593999999997	0103000020E61000000100000005000000C87A6AF5D5B95240D5592DB0C7F84A40C87A6AF5D5B95240DFA9807B9EF94A4054573ECBF3BA5240DFA9807B9EF94A4054573ECBF3BA5240D5592DB0C7F84A40C87A6AF5D5B95240D5592DB0C7F84A40
53039	Алкул	5	53	266	74.940443000000002	74.954897000000003	53.94556	53.936264000000001	0103000020E610000001000000050000002330D63730BC52400936AE7FD7F74A402330D63730BC5240F0332E1C08F94A401B834E081DBD5240F0332E1C08F94A401B834E081DBD52400936AE7FD7F74A402330D63730BC52400936AE7FD7F74A40
1453	Александровка	5	53	266	74.843209999999999	74.869512	53.978107000000001	53.964146	0103000020E61000000100000005000000406A1327F7B55240DC48D92269FB4A40406A1327F7B552408D7E349C32FD4A40B1DEA815A6B752408D7E349C32FD4A40B1DEA815A6B75240DC48D92269FB4A40406A1327F7B55240DC48D92269FB4A40
528	Хутора	5	53	95	74.598994000000005	74.615405999999993	55.881166999999998	55.874299000000001	0103000020E610000001000000050000000420EEEA55A6524077F69507E9EF4B400420EEEA55A652403FA88B14CAF04B40C7F0D8CF62A752403FA88B14CAF04B40C7F0D8CF62A7524077F69507E9EF4B400420EEEA55A6524077F69507E9EF4B40
31446	Хортицы	5	53	95	74.897880999999998	74.930535000000006	55.599356999999998	55.579205000000002	0103000020E61000000100000005000000C9ACDEE176B952400057B26323CA4B40C9ACDEE176B9524078D0ECBAB7CC4B402332ACE28DBB524078D0ECBAB7CC4B402332ACE28DBB52400057B26323CA4B40C9ACDEE176B952400057B26323CA4B40
32171	Хомутинка	5	53	95	75.118983999999998	75.144863999999998	55.504063000000002	55.489116000000003	0103000020E61000000100000005000000D32F116F9DC75240A5F9635A9BBE4B40D32F116F9DC75240D40FEA2285C04B408997A77345C95240D40FEA2285C04B408997A77345C95240A5F9635A9BBE4B40D32F116F9DC75240A5F9635A9BBE4B40
31498	Удачная	5	53	95	74.974318999999994	74.989868999999999	55.648564999999998	55.645522	0103000020E61000000100000005000000C537143E5BBE52409C6C0377A0D24B40C537143E5BBE5240452A8C2D04D34B40C09481035ABF5240452A8C2D04D34B40C09481035ABF52409C6C0377A0D24B40C537143E5BBE52409C6C0377A0D24B40
53104	Старомалиновка	5	53	95	74.554553999999996	74.58569	55.864040000000003	55.852637000000001	0103000020E610000001000000050000006C770FD07DA35240062E8F3523ED4B406C770FD07DA35240CA37DBDC98EE4B4008E6E8F17BA55240CA37DBDC98EE4B4008E6E8F17BA55240062E8F3523ED4B406C770FD07DA35240062E8F3523ED4B40
53016	Соловецкое	5	53	95	74.978190999999995	75.012703999999999	55.317348000000003	55.308002999999999	0103000020E61000000100000005000000758F6CAE9ABE5240F2086EA46CA74B40758F6CAE9ABE5240BBB9F8DB9EA84B40D1217024D0C05240BBB9F8DB9EA84B40D1217024D0C05240F2086EA46CA74B40758F6CAE9ABE5240F2086EA46CA74B40
30742	Смирновка	5	53	95	74.826078999999993	74.842060000000004	55.488166999999997	55.471984999999997	0103000020E61000000100000005000000643A747ADEB45240ED9925016ABC4B40643A747ADEB4524043FE99417CBE4B404451A04FE4B5524043FE99417CBE4B404451A04FE4B55240ED9925016ABC4B40643A747ADEB45240ED9925016ABC4B40
60836	Слободка (Малая Омка)	5	53	95	74.971318999999994	74.979348999999999	55.390107	55.379612999999999	0103000020E61000000100000005000000F0BE2A172ABE52407711A62897B04B40F0BE2A172ABE52406878B306EFB14B40B3976DA7ADBE52406878B306EFB14B40B3976DA7ADBE52407711A62897B04B40F0BE2A172ABE52407711A62897B04B40
32396	Сидоровка	5	53	95	74.544376	74.571316999999993	55.726725000000002	55.714596999999998	0103000020E610000001000000050000008C2E6F0ED7A25240EC681CEA77DB4B408C2E6F0ED7A25240C217265305DD4B4086A92D7590A45240C217265305DD4B4086A92D7590A45240EC681CEA77DB4B408C2E6F0ED7A25240EC681CEA77DB4B40
32268	Рязанка	5	53	95	75.17971	75.207628999999997	55.531193000000002	55.524926000000001	0103000020E61000000100000005000000E8305F5E80CB5240F96871C630C34B40E8305F5E80CB52409C6ED921FEC34B40E02C25CB49CD52409C6ED921FEC34B40E02C25CB49CD5240F96871C630C34B40E8305F5E80CB5240F96871C630C34B40
31087	Рождественка	5	53	95	74.538510000000002	74.550484999999995	55.556457000000002	55.550198000000002	0103000020E610000001000000050000006AA4A5F276A252408D2958E36CC64B406AA4A5F276A25240AD50A4FB39C74B4011FC6F253BA35240AD50A4FB39C74B4011FC6F253BA352408D2958E36CC64B406AA4A5F276A252408D2958E36CC64B40
52983	Радищево	5	53	95	75.066468	75.081883000000005	55.882631000000003	55.870894999999997	0103000020E61000000100000005000000C18EFF0241C45240FD9FC37C79EF4B40C18EFF0241C45240C8B7770DFAF04B404CC631923DC55240C8B7770DFAF04B404CC631923DC55240FD9FC37C79EF4B40C18EFF0241C45240FD9FC37C79EF4B40
425	Пустынное	5	53	95	74.670041999999995	74.692580000000007	55.944716999999997	55.934128999999999	0103000020E61000000100000005000000923CD7F7E1AA5240629F008A91F74B40923CD7F7E1AA5240D47C957CECF84B404777103B53AC5240D47C957CECF84B404777103B53AC5240629F008A91F74B40923CD7F7E1AA5240629F008A91F74B40
30651	Пугачевка	5	53	95	74.817473000000007	74.820141000000007	55.371837999999997	55.360126000000001	0103000020E610000001000000050000003C17467A51B452403B38D89B18AE4B403C17467A51B452407CB4386398AF4B40F646AD307DB452407CB4386398AF4B40F646AD307DB452403B38D89B18AE4B403C17467A51B452403B38D89B18AE4B40
30432	Придорожное	5	53	95	74.805355000000006	74.822350999999998	55.410780000000003	55.402715000000001	0103000020E61000000100000005000000E3AAB2EF8AB35240E84D452A8CB34B40E3AAB2EF8AB35240EAEC647094B44B404EB51666A1B45240EAEC647094B44B404EB51666A1B45240E84D452A8CB34B40E3AAB2EF8AB35240E84D452A8CB34B40
31978	Полтавка	5	53	95	75.061544999999995	75.079898	55.303820999999999	55.292940000000002	0103000020E61000000100000005000000DE8E705AF0C352405AD8D30E7FA54B40DE8E705AF0C35240446B459BE3A64B400341800C1DC55240446B459BE3A64B400341800C1DC552405AD8D30E7FA54B40DE8E705AF0C352405AD8D30E7FA54B40
32408	Покровка	5	53	95	74.624380000000002	74.638951000000006	55.793489999999998	55.779513999999999	0103000020E61000000100000005000000B21188D7F5A752401763601DC7E34B40B21188D7F5A75240FDD98F1491E54B40C72FBC92E4A85240FDD98F1491E54B40C72FBC92E4A852401763601DC7E34B40B21188D7F5A752401763601DC7E34B40
800	Петропавловка	5	53	95	75.015749	75.026510999999999	55.819014000000003	55.815579999999997	0103000020E6100000010000000500000076FC170802C15240C6A2E9EC64E84B4076FC170802C15240AB7B6473D5E84B40FE7E315BB2C15240AB7B6473D5E84B40FE7E315BB2C15240C6A2E9EC64E84B4076FC170802C15240C6A2E9EC64E84B40
30945	Паутовка	5	53	95	74.483973000000006	74.503799000000001	55.496673999999999	55.481907999999997	0103000020E6100000010000000500000069C9E369F99E524023D74D29AFBD4B4069C9E369F99E524002637D0393BF4B407B30293E3EA0524002637D0393BF4B407B30293E3EA0524023D74D29AFBD4B4069C9E369F99E524023D74D29AFBD4B40
118	Отрадновка	5	53	95	74.684055000000001	74.698562999999993	55.806306999999997	55.795611000000001	0103000020E61000000100000005000000946A9F8EC7AB52403FABCC94D6E54B40946A9F8EC7AB524097C4591135E74B4085CC9541B5AC524097C4591135E74B4085CC9541B5AC52403FABCC94D6E54B40946A9F8EC7AB52403FABCC94D6E54B40
31582	Озерное	5	53	95	74.854366999999996	74.871191999999994	55.686660000000003	55.682107999999999	0103000020E6100000010000000500000006F2ECF2ADB65240842BA0504FD74B4006F2ECF2ADB6524056BC9179E4D74B405B22179CC1B7524056BC9179E4D74B405B22179CC1B75240842BA0504FD74B4006F2ECF2ADB65240842BA0504FD74B40
740	Новотроицк	5	53	95	75.066423	75.086248999999995	55.798636999999999	55.782789999999999	0103000020E61000000100000005000000F12C414640C4524063D1747632E44B40F12C414640C452401230BABC39E64B400394861A85C552401230BABC39E64B400394861A85C5524063D1747632E44B40F12C414640C4524063D1747632E44B40
31267	Новоивановка	5	53	95	74.492597000000004	74.505623	55.569209000000001	55.560693000000001	0103000020E61000000100000005000000E54691B5869F52404E0CC9C9C4C74B40E54691B5869F524060CB2BD7DBC84B40BF4692205CA0524060CB2BD7DBC84B40BF4692205CA052404E0CC9C9C4C74B40E54691B5869F52404E0CC9C9C4C74B40
258	Николаевка	5	53	95	74.831773999999996	74.856719999999996	55.809403000000003	55.806322000000002	0103000020E6100000010000000500000070EA03C93BB55240CD052E8F35E74B4070EA03C93BB5524064247B849AE74B4010751F80D4B6524064247B849AE74B4010751F80D4B65240CD052E8F35E74B4070EA03C93BB55240CD052E8F35E74B40
30099	Нижняя Омка (Красный Восток)	5	53	95	74.940766999999994	74.950226000000001	55.417194000000002	55.413096000000003	0103000020E61000000100000005000000FC89CA8635BC5240E10D6954E0B44B40FC89CA8635BC5240310BED9C66B54B40C573B680D0BC5240310BED9C66B54B40C573B680D0BC5240E10D6954E0B44B40FC89CA8635BC5240E10D6954E0B44B40
31972	Медвежья Грива	5	53	95	75.208877999999999	75.219289000000003	55.260371999999997	55.254537999999997	0103000020E61000000100000005000000A6B6D4415ECD52406CCB80B394A04B40A6B6D4415ECD5240A565A4DE53A14B40D8D7BAD408CE5240A565A4DE53A14B40D8D7BAD408CE52406CCB80B394A04B40A6B6D4415ECD52406CCB80B394A04B40
31162	Любимовка	5	53	95	74.666071000000002	74.679860000000005	55.509146000000001	55.502344999999998	0103000020E61000000100000005000000197442E8A0AA5240912749D74CC04B40197442E8A0AA5240D27135B22BC14B40F37684D382AB5240D27135B22BC14B40F37684D382AB5240912749D74CC04B40197442E8A0AA5240912749D74CC04B40
31835	Локти	5	53	95	75.025899999999993	75.042823999999996	55.232356000000003	55.221065000000003	0103000020E61000000100000005000000D93D7958A8C1524027A5A0DB4B9C4B40D93D7958A8C15240C38366D7BD9D4B40F8DEDFA0BDC25240C38366D7BD9D4B40F8DEDFA0BDC2524027A5A0DB4B9C4B40D93D7958A8C1524027A5A0DB4B9C4B40
31362	Лесной	5	53	95	74.544053000000005	74.558066999999994	55.593837999999998	55.584415999999997	0103000020E610000001000000050000009B92ACC3D1A252402BA1BB24CECA4B409B92ACC3D1A252409F8F32E202CC4B40847EA65EB7A352409F8F32E202CC4B40847EA65EB7A352402BA1BB24CECA4B409B92ACC3D1A252402BA1BB24CECA4B40
30481	Лаврино	5	53	95	74.723545000000001	74.752443999999997	55.389862000000001	55.382277999999999	0103000020E61000000100000005000000CC0BB08F4EAE52407AFD497CEEB04B40CC0BB08F4EAE524001FA7DFFE6B14B409204E10A28B0524001FA7DFFE6B14B409204E10A28B052407AFD497CEEB04B40CC0BB08F4EAE52407AFD497CEEB04B40
32123	Киршовка	5	53	95	75.066063999999997	75.084918999999999	55.467657000000003	55.456878000000003	0103000020E6100000010000000500000059DC7F643AC45240862172FA7ABA4B4059DC7F643AC452406C5F402FDCBB4B40C7F319506FC552406C5F402FDCBB4B40C7F319506FC55240862172FA7ABA4B4059DC7F643AC45240862172FA7ABA4B40
60848	Камышинка	5	53	95	74.806872999999996	74.828108999999998	55.444184999999997	55.438051999999999	0103000020E61000000100000005000000A0C1A6CEA3B3524044F9821612B84B40A0C1A6CEA3B35240D72FD80DDBB84B407D21E4BCFFB45240D72FD80DDBB84B407D21E4BCFFB4524044F9821612B84B40A0C1A6CEA3B3524044F9821612B84B40
31680	Измайловка	5	53	95	74.880067999999994	74.897468000000003	55.260396999999998	55.257314000000001	0103000020E610000001000000050000006490BB0853B85240C76647AAEFA04B406490BB0853B85240FE7C5BB054A14B40384D9F1D70B95240FE7C5BB054A14B40384D9F1D70B95240C76647AAEFA04B406490BB0853B85240C76647AAEFA04B40
30898	Зенкуль	5	53	95	74.742940000000004	74.764661000000004	55.496006000000001	55.489983000000002	0103000020E61000000100000005000000FAB836548CAF5240494C50C3B7BE4B40FAB836548CAF5240554FE61F7DBF4B40B5E1B034F0B05240554FE61F7DBF4B40B5E1B034F0B05240494C50C3B7BE4B40FAB836548CAF5240494C50C3B7BE4B40
53031	Еланчино	5	53	95	75.077589000000003	75.092958999999993	55.608246000000001	55.598089999999999	0103000020E61000000100000005000000E161DA37F7C4524046088F368ECC4B40E161DA37F7C452401FF64201DBCD4B409B374E0AF3C552401FF64201DBCD4B409B374E0AF3C5524046088F368ECC4B40E161DA37F7C4524046088F368ECC4B40
53028	Глухониколаевка	5	53	95	75.019917000000007	75.039841999999993	55.293781000000003	55.274830999999999	0103000020E610000001000000050000009BE8F35146C15240A77686A92DA34B409BE8F35146C15240D597A59D9AA54B4076C075C58CC25240D597A59D9AA54B4076C075C58CC25240A77686A92DA34B409BE8F35146C15240A77686A92DA34B40
843	Воскресенка	5	53	95	74.903873000000004	74.914213000000004	55.780335000000001	55.774020999999998	0103000020E6100000010000000500000032AF230ED9B9524067B5C01E13E34B4032AF230ED9B952404B766C04E2E34B40FF243E7782BA52404B766C04E2E34B40FF243E7782BA524067B5C01E13E34B4032AF230ED9B9524067B5C01E13E34B40
30334	Вишневка	5	53	95	74.974247000000005	74.984640999999996	55.448841999999999	55.441136999999998	0103000020E6100000010000000500000079CE16105ABE52401C075E2D77B84B4079CE16105ABE52401E8997A773B94B403F53AF5B04BF52401E8997A773B94B403F53AF5B04BF52401C075E2D77B84B4079CE16105ABE52401C075E2D77B84B40
31410	Виноградовка	5	53	95	74.976258999999999	74.981425000000002	55.529986000000001	55.521287000000001	0103000020E610000001000000050000003E5B07077BBE52403C6A4C88B9C24B403E5B07077BBE52403FABCC94D6C34B40849ECDAACFBE52403FABCC94D6C34B40849ECDAACFBE52403C6A4C88B9C24B403E5B07077BBE52403C6A4C88B9C24B40
370	Борисовка	5	53	95	74.705237999999994	74.717885999999993	55.883797000000001	55.875359000000003	0103000020E610000001000000050000005F79909E22AD524030A182C30BF04B405F79909E22AD5240C6A6954220F14B4066101FD8F1AD5240C6A6954220F14B4066101FD8F1AD524030A182C30BF04B405F79909E22AD524030A182C30BF04B40
631	Бещаул	5	53	95	74.504446000000002	74.522025999999997	55.837308	55.825355000000002	0103000020E610000001000000050000004626E0D748A05240884B8E3BA5E94B404626E0D748A05240EF5696E82CEB4B40596ABDDF68A15240EF5696E82CEB4B40596ABDDF68A15240884B8E3BA5E94B404626E0D748A05240884B8E3BA5E94B40
30811	Ачаирка	5	53	95	74.849705	74.863566000000006	55.538677	55.529868	0103000020E61000000100000005000000DA8F149161B652403599F1B6D2C34B40DA8F149161B65240BF0D315EF3C44B4001FC53AA44B75240BF0D315EF3C44B4001FC53AA44B752403599F1B6D2C34B40DA8F149161B652403599F1B6D2C34B40
30572	Антоновка	5	53	95	74.943353999999999	74.967465000000004	55.352930999999998	55.338633000000002	0103000020E6100000010000000500000040A374E95FBC5240562C7E5358AB4B4040A374E95FBC52404E5FCFD72CAD4B4094C151F2EABD52404E5FCFD72CAD4B4094C151F2EABD5240562C7E5358AB4B4040A374E95FBC5240562C7E5358AB4B40
28307	Ястреб	5	53	625	71.139070000000004	71.155590000000004	55.891719000000002	55.881379000000003	0103000020E61000000100000005000000B476DB85E6C85140CB30EE06D1F04B40B476DB85E6C85140651C23D923F24B406B65C22FF5C95140651C23D923F24B406B65C22FF5C95140CB30EE06D1F04B40B476DB85E6C85140CB30EE06D1F04B40
29164	Черняевка	5	53	625	71.704909000000001	71.723575999999994	55.681832999999997	55.669457999999999	0103000020E61000000100000005000000FD69A33A1DED5140D505BCCCB0D54B40FD69A33A1DED5140B22AC24D46D74B40E90AB6114FEE5140B22AC24D46D74B40E90AB6114FEE5140D505BCCCB0D54B40FD69A33A1DED5140D505BCCCB0D54B40
29877	Черемновка	5	53	625	71.759050999999999	71.795090999999999	55.422201000000001	55.413176999999997	0103000020E61000000100000005000000C03FA54A94F05140CD3AE3FBE2B44B40C03FA54A94F0514054ABAFAE0AB64B4003965CC5E2F2514054ABAFAE0AB64B4003965CC5E2F25140CD3AE3FBE2B44B40C03FA54A94F05140CD3AE3FBE2B44B40
29921	Фомиха	5	53	625	71.502302999999998	71.5261	55.475470000000001	55.469056000000002	0103000020E61000000100000005000000B16B7BBB25E051400DFFE9060ABC4B40B16B7BBB25E05140541D7233DCBC4B403D9B559FABE15140541D7233DCBC4B403D9B559FABE151400DFFE9060ABC4B40B16B7BBB25E051400DFFE9060ABC4B40
29661	Утичье	5	53	625	71.627762000000004	71.646663000000004	55.325794999999999	55.312685999999999	0103000020E61000000100000005000000FBEAAA402DE8514062F5471806A84B40FBEAAA402DE85140A4198BA6B3A94B40212235ED62E95140A4198BA6B3A94B40212235ED62E9514062F5471806A84B40FBEAAA402DE8514062F5471806A84B40
28458	Тупицыно	5	53	625	70.575916000000007	70.592256000000006	55.455663000000001	55.443868999999999	0103000020E61000000100000005000000904FC8CEDBA45140A75A0BB3D0B84B40904FC8CEDBA45140A67F492A53BA4B4007B7B585E7A55140A67F492A53BA4B4007B7B585E7A55140A75A0BB3D0B84B40904FC8CEDBA45140A75A0BB3D0B84B40
29341	Сырьевка	5	53	625	71.096265000000002	71.101788999999997	55.543807000000001	55.538314999999997	0103000020E61000000100000005000000F7AFAC3429C651401EF98381E7C44B40F7AFAC3429C65140FE2AC0779BC54B40EC8502B683C65140FE2AC0779BC54B40EC8502B683C651401EF98381E7C44B40F7AFAC3429C651401EF98381E7C44B40
28818	Сулу Терек (аул №2)	5	53	625	71.549132999999998	71.564160999999999	55.658236000000002	55.652669000000003	0103000020E61000000100000005000000E109BDFE24E35140780E65A88AD34B40E109BDFE24E351406286C61341D44B406F2BBD361BE451406286C61341D44B406F2BBD361BE45140780E65A88AD34B40E109BDFE24E35140780E65A88AD34B40
28238	Староназываевка	5	53	625	71.277904000000007	71.289959999999994	55.476255000000002	55.469177999999999	0103000020E610000001000000050000005EDBDB2DC9D15140580053060EBC4B405EDBDB2DC9D151403BC780ECF5BC4B407B4963B48ED251403BC780ECF5BC4B407B4963B48ED25140580053060EBC4B405EDBDB2DC9D15140580053060EBC4B40
29516	Старинка	5	53	625	71.404674	71.426692000000003	55.746988000000002	55.735717999999999	0103000020E61000000100000005000000A8E2C62DE6D951400D8AE6012CDE4B40A8E2C62DE6D951409240834D9DDF4B40C05DF6EB4EDB51409240834D9DDF4B40C05DF6EB4EDB51400D8AE6012CDE4B40A8E2C62DE6D951400D8AE6012CDE4B40
29710	Спасск	5	53	625	71.625849000000002	71.644425999999996	55.405183999999998	55.393160000000002	0103000020E61000000100000005000000FFCEF6E80DE85140350C1F1153B24B40FFCEF6E80DE85140656EBE11DDB34B404BAC8C463EE95140656EBE11DDB34B404BAC8C463EE95140350C1F1153B24B40FFCEF6E80DE85140350C1F1153B24B40
29256	Рыбье	5	53	625	70.976690000000005	70.985476000000006	55.453110000000002	55.446523999999997	0103000020E610000001000000050000002315C61682BE51408670CCB227B94B402315C61682BE5140CBBE2B82FFB94B408CBFED0912BF5140CBBE2B82FFB94B408CBFED0912BF51408670CCB227B94B402315C61682BE51408670CCB227B94B40
30001	Ростовка	5	53	625	71.882390000000001	71.896384999999995	55.389049	55.375393000000003	0103000020E610000001000000050000005114E81379F85140DC12B9E00CB04B405114E81379F8514050C58D5BCCB14B40FFE7305F5EF9514050C58D5BCCB14B40FFE7305F5EF95140DC12B9E00CB04B405114E81379F85140DC12B9E00CB04B40
28046	Редкое	5	53	625	71.042733999999996	71.059533000000002	55.769150000000003	55.760539999999999	0103000020E61000000100000005000000581B6327BCC2514061A6ED5F59E14B40581B6327BCC25140F5DBD78173E24B4019028063CFC35140F5DBD78173E24B4019028063CFC3514061A6ED5F59E14B40581B6327BCC2514061A6ED5F59E14B40
28003	Путь Социализма (Путиловка)	5	53	625	71.252679999999998	71.274122000000006	55.760230999999997	55.752693000000001	0103000020E610000001000000050000009C16BCE82BD05140CD76853E58E04B409C16BCE82BD05140E333D93F4FE14B404E4700378BD15140E333D93F4FE14B404E4700378BD15140CD76853E58E04B409C16BCE82BD05140CD76853E58E04B40
29237	Покровка	5	53	625	70.989428000000004	71.010717999999997	55.529527000000002	55.516393999999998	0103000020E61000000100000005000000CA6FD1C952BF5140E1ECD63219C24B40CA6FD1C952BF5140ACAC6D8AC7C34B40A0DE8C9AAFC05140ACAC6D8AC7C34B40A0DE8C9AAFC05140E1ECD63219C24B40CA6FD1C952BF5140E1ECD63219C24B40
28554	Носовка	5	53	625	70.542165999999995	70.555982	55.325333999999998	55.308244000000002	0103000020E6100000010000000500000033C005D9B2A251401898158A74A74B4033C005D9B2A251407023658BA4A94B408ACA863595A351407023658BA4A94B408ACA863595A351401898158A74A74B4033C005D9B2A251401898158A74A74B40
29596	Новоосиново	5	53	625	71.334130000000002	71.341764999999995	55.849226000000002	55.844399000000003	0103000020E6100000010000000500000033A7CB6262D5514037E3344415EC4B4033A7CB6262D55140DA740470B3EC4B40B77A4E7ADFD55140DA740470B3EC4B40B77A4E7ADFD5514037E3344415EC4B4033A7CB6262D5514037E3344415EC4B40
28172	Нововоскресенка (Ерасовка)	5	53	625	71.316908999999995	71.337642000000002	55.487703000000003	55.482734999999998	0103000020E61000000100000005000000B7B3AF3C48D4514039D1AE42CABD4B40B7B3AF3C48D451409F94490D6DBE4B4063F030ED9BD551409F94490D6DBE4B4063F030ED9BD5514039D1AE42CABD4B40B7B3AF3C48D4514039D1AE42CABD4B40
28127	Нахимовка	5	53	625	71.292986999999997	71.306506999999996	55.327858999999997	55.31785	0103000020E61000000100000005000000CDC98B4CC0D251404D840D4FAFA84B40CDC98B4CC0D251408159A148F7A94B40AF3F89CF9DD351408159A148F7A94B40AF3F89CF9DD351404D840D4FAFA84B40CDC98B4CC0D251404D840D4FAFA84B40
29157	Налимово	5	53	625	71.814826999999994	71.832587000000004	55.643754000000001	55.632413	0103000020E610000001000000050000007539252026F451405A48C0E8F2D04B407539252026F45140A855F48766D24B40C904FC1A49F55140A855F48766D24B40C904FC1A49F551405A48C0E8F2D04B407539252026F451405A48C0E8F2D04B40
27322	Называевск	5	53	625	71.308769999999996	71.386465999999999	55.601671000000003	55.552587000000003	0103000020E6100000010000000500000019FF3EE3C2D35140EE98BA2BBBC64B4019FF3EE3C2D35140CFF9298E03CD4B4005C1E3DBBBD85140CFF9298E03CD4B4005C1E3DBBBD85140EE98BA2BBBC64B4019FF3EE3C2D35140EE98BA2BBBC64B40
29011	Муравьевка	5	53	625	71.398394999999994	71.420439999999999	55.677442999999997	55.668416999999998	0103000020E61000000100000005000000F4F8BD4D7FD95140938B31B08ED54B40F4F8BD4D7FD95140BAF3C473B6D64B40897B2C7DE8DA5140BAF3C473B6D64B40897B2C7DE8DA5140938B31B08ED54B40F4F8BD4D7FD95140938B31B08ED54B40
29419	Михайловка	5	53	625	71.220978000000002	71.229709999999997	55.588766	55.581459000000002	0103000020E61000000100000005000000ACC8E88024CE5140817B9E3F6DCA4B40ACC8E88024CE5140957F2DAF5CCB4B401B649291B3CE5140957F2DAF5CCB4B401B649291B3CE5140817B9E3F6DCA4B40ACC8E88024CE5140817B9E3F6DCA4B40
27781	Милютино	5	53	625	71.829847000000001	71.847031999999999	55.513590999999998	55.501151	0103000020E61000000100000005000000C26B97361CF55140C9AD49B725C04B40C26B97361CF551408D429259BDC14B4097AAB4C535F651408D429259BDC14B4097AAB4C535F65140C9AD49B725C04B40C26B97361CF55140C9AD49B725C04B40
28885	Мангут	5	53	625	70.751886999999996	70.788303999999997	55.789192999999997	55.768541999999997	0103000020E6100000010000000500000067D2A6EA1EB051401CCD91955FE24B4067D2A6EA1EB05140B69DB64604E54B4095D39E9273B25140B69DB64604E54B4095D39E9273B251401CCD91955FE24B4067D2A6EA1EB051401CCD91955FE24B40
28787	Лорис-Меликово (Дунаевка)	5	53	625	71.582532	71.611799000000005	55.591909999999999	55.5749	0103000020E61000000100000005000000E7374C3448E55140363CBD5296C94B40E7374C3448E551407216F6B4C3CB4B406F2EFEB627E751407216F6B4C3CB4B406F2EFEB627E75140363CBD5296C94B40E7374C3448E55140363CBD5296C94B40
29948	Лески	5	53	625	71.930673999999996	71.950355999999999	55.446514000000001	55.439089000000003	0103000020E61000000100000005000000334FAE2990FB514045847F1134B84B40334FAE2990FB5140639AE95E27B94B40ACE3F8A1D2FC5140639AE95E27B94B40ACE3F8A1D2FC514045847F1134B84B40334FAE2990FB514045847F1134B84B40
28708	Лебяжье	5	53	625	70.993533999999997	71.020384000000007	55.240251000000001	55.224967999999997	0103000020E61000000100000005000000B35DA10F96BF5140C1525DC0CB9C4B40B35DA10F96BF514068EA758BC09E4B402657B1F84DC1514068EA758BC09E4B402657B1F84DC15140C1525DC0CB9C4B40B35DA10F96BF5140C1525DC0CB9C4B40
53036	Кочковатский	5	53	625	71.689233999999999	71.704918000000006	55.455632000000001	55.446809999999999	0103000020E61000000100000005000000A452EC681CEC51404CC3F01131B94B40A452EC681CEC51406B813D2652BA4B40271763601DED51406B813D2652BA4B40271763601DED51404CC3F01131B94B40A452EC681CEC51404CC3F01131B94B40
27828	Кочковатка	5	53	625	71.645117999999997	71.653677999999999	55.516063000000003	55.503104	0103000020E61000000100000005000000E603029D49E951404F3E3DB665C04B40E603029D49E951407CD6355A0EC24B40570740DCD5E951407CD6355A0EC24B40570740DCD5E951404F3E3DB665C04B40E603029D49E951404F3E3DB665C04B40
28962	Котино	5	53	625	70.803711000000007	70.813556000000005	55.770076000000003	55.760596	0103000020E61000000100000005000000DF1B430070B35140F5BBB0355BE14B40DF1B430070B351409EB7B1D991E24B40BC5D2F4D11B451409EB7B1D991E24B40BC5D2F4D11B45140F5BBB0355BE14B40DF1B430070B35140F5BBB0355BE14B40
29795	Константиновка	5	53	625	71.700210999999996	71.728086000000005	55.234492000000003	55.224254000000002	0103000020E610000001000000050000002A53CC41D0EC5140A4FFE55AB49C4B402A53CC41D0EC51403A9677D5039E4B403BAB05F698EE51403A9677D5039E4B403BAB05F698EE5140A4FFE55AB49C4B402A53CC41D0EC5140A4FFE55AB49C4B40
28576	Князево	5	53	625	70.970877999999999	71.001959999999997	55.355234000000003	55.334183000000003	0103000020E61000000100000005000000FA997ADD22BE514089F02F82C6AA4B40FA997ADD22BE5140B136C64E78AD4B409CF9D51C20C05140B136C64E78AD4B409CF9D51C20C0514089F02F82C6AA4B40FA997ADD22BE514089F02F82C6AA4B40
28403	Кисляки	5	53	625	70.623436999999996	70.638771000000006	55.350273999999999	55.339390999999999	0103000020E6100000010000000500000072874D64E6A7514043C70E2A71AB4B4072874D64E6A75140CE5147C7D5AC4B4087A8C29FE1A85140CE5147C7D5AC4B4087A8C29FE1A8514043C70E2A71AB4B4072874D64E6A7514043C70E2A71AB4B40
29107	Кирей (аул №1)	5	53	625	71.556821999999997	71.565517999999997	55.669635	55.664648999999997	0103000020E610000001000000050000005FECBDF8A2E35140D828EB3713D54B405FECBDF8A2E35140E4A08499B6D54B4028D3687231E45140E4A08499B6D54B4028D3687231E45140D828EB3713D54B405FECBDF8A2E35140D828EB3713D54B40
28372	Караульное	5	53	625	70.932691000000005	70.959191000000004	55.837888999999997	55.825415999999997	0103000020E6100000010000000500000082919735B1BB51402DCC423BA7E94B4082919735B1BB5140CD565EF23FEB4B4086E7A56263BD5140CD565EF23FEB4B4086E7A56263BD51402DCC423BA7E94B4082919735B1BB51402DCC423BA7E94B40
52985	Каран-Гарал	5	53	625	71.551368999999994	71.562571000000005	55.770856000000002	55.759117000000003	0103000020E61000000100000005000000CEC133A149E35140386BF0BE2AE14B40CEC133A149E3514073F6CE68ABE24B4065ABCB2901E4514073F6CE68ABE24B4065ABCB2901E45140386BF0BE2AE14B40CEC133A149E35140386BF0BE2AE14B40
27912	Калмацкое	5	53	625	70.825395999999998	70.837693999999999	55.467059999999996	55.458306999999998	0103000020E61000000100000005000000F38FBE49D3B451409143C4CDA9BA4B40F38FBE49D3B4514087A2409FC8BB4B408C834BC79CB5514087A2409FC8BB4B408C834BC79CB551409143C4CDA9BA4B40F38FBE49D3B451409143C4CDA9BA4B40
28636	Кабаново	5	53	625	70.860861	70.879707999999994	55.349511999999997	55.329610000000002	0103000020E61000000100000005000000B859BC5818B75140A03715A930AA4B40B859BC5818B751409FC728CFBCAC4B40E481C8224DB851409FC728CFBCAC4B40E481C8224DB85140A03715A930AA4B40B859BC5818B75140A03715A930AA4B40
28249	Искра	5	53	625	70.966333000000006	70.989391999999995	55.929620999999997	55.915830999999997	0103000020E61000000100000005000000EB025E66D8BD5140DCD440F339F54B40EB025E66D8BD5140605628D2FDF64B4023BBD23252BF5140605628D2FDF64B4023BBD23252BF5140DCD440F339F54B40EB025E66D8BD5140DCD440F339F54B40
28092	Жирновка	5	53	625	71.317160999999999	71.349491	55.393819000000001	55.383279999999999	0103000020E6100000010000000500000044A4A65D4CD45140FE9AAC510FB14B4044A4A65D4CD451408FC536A968B24B40C4CF7F0F5ED651408FC536A968B24B40C4CF7F0F5ED65140FE9AAC510FB14B4044A4A65D4CD45140FE9AAC510FB14B40
28691	Дурбет	5	53	625	71.178515000000004	71.209309000000005	55.333419999999997	55.323228999999998	0103000020E610000001000000050000001CB62DCA6CCB5140340F60915FA94B401CB62DCA6CCB514089EAAD81ADAA4B408B70935165CD514089EAAD81ADAA4B408B70935165CD5140340F60915FA94B401CB62DCA6CCB5140340F60915FA94B40
17761	Драгунский	5	53	625	71.948442999999997	71.962204999999997	55.331417999999999	55.325220999999999	0103000020E61000000100000005000000B0C7444AB3FC5140787C7BD7A0A94B40B0C7444AB3FC514022A7AFE76BAA4B400DC347C494FD514022A7AFE76BAA4B400DC347C494FD5140787C7BD7A0A94B40B0C7444AB3FC5140787C7BD7A0A94B40
29788	Драгунка	5	53	625	71.825507999999999	71.855934000000005	55.321430999999997	55.314003	0103000020E6100000010000000500000087A5811FD5F4514046EC134031A84B4087A5811FD5F45140D575A8A624A94B403562669FC7F65140D575A8A624A94B403562669FC7F6514046EC134031A84B4087A5811FD5F4514046EC134031A84B40
29411	Гагаринка	5	53	625	71.255886000000004	71.268867	55.527509000000002	55.523207999999997	0103000020E610000001000000050000004660AC6F60D05140B680D07AF8C24B404660AC6F60D051403FAC376A85C34B4050FEEE1D35D151403FAC376A85C34B4050FEEE1D35D15140B680D07AF8C24B404660AC6F60D05140B680D07AF8C24B40
28937	Бузан	5	53	625	70.570041000000003	70.581952000000001	55.695290999999997	55.688308999999997	0103000020E6100000010000000500000044183F8D7BA451406F4562821AD84B4044183F8D7BA45140001AA54BFFD84B40E0F599B33EA55140001AA54BFFD84B40E0F599B33EA551406F4562821AD84B4044183F8D7BA451406F4562821AD84B40
27861	Большепесчанка	5	53	625	70.794099000000003	70.819117000000006	55.535482999999999	55.518172999999997	0103000020E6100000010000000500000053B29C84D2B25140C9552C7E53C24B4053B29C84D2B251403048FAB48AC44B4040A6B5696CB451403048FAB48AC44B4040A6B5696CB45140C9552C7E53C24B4053B29C84D2B25140C9552C7E53C24B40
29036	Богословка (Моховое)	5	53	625	71.316074	71.322819999999993	55.655152999999999	55.646706000000002	0103000020E610000001000000050000006B47718E3AD4514041102043C7D24B406B47718E3AD451402A70B20DDCD34B40A99F3715A9D451402A70B20DDCD34B40A99F3715A9D4514041102043C7D24B406B47718E3AD4514041102043C7D24B40
27702	Богодуховка	5	53	625	71.752125000000007	71.766587999999999	55.485177999999998	55.477061999999997	0103000020E610000001000000050000004260E5D022F0514009151C5E10BD4B404260E5D022F051408D5E0D501ABE4B4063601DC70FF151408D5E0D501ABE4B4063601DC70FF1514009151C5E10BD4B404260E5D022F0514009151C5E10BD4B40
29327	Батареевка	5	53	625	71.052408999999997	71.071057999999994	55.528956000000001	55.522163999999997	0103000020E61000000100000005000000074147AB5AC3514003931B45D6C24B40074147AB5AC35140F18288D4B4C34B40A087DA368CC45140F18288D4B4C34B40A087DA368CC4514003931B45D6C24B40074147AB5AC3514003931B45D6C24B40
29503	Байымбет (аул №6)	5	53	625	71.135422000000005	71.145142000000007	55.625318	55.619293999999996	0103000020E610000001000000050000002C4A09C1AAC85140F44D9A0645CF4B402C4A09C1AAC85140D1CC936B0AD04B40ABD1AB014AC95140D1CC936B0AD04B40ABD1AB014AC95140F44D9A0645CF4B402C4A09C1AAC85140F44D9A0645CF4B40
26255	Юдинка	5	53	353	76.026578000000001	76.045668000000006	56.451593000000003	56.437556999999998	0103000020E61000000100000005000000C2323674B3015340649126DE01384C40C2323674B3015340200DA7CCCD394C40529E7939EC025340200DA7CCCD394C40529E7939EC025340649126DE01384C40C2323674B3015340649126DE01384C40
26118	Черталы	5	53	353	75.384075999999993	75.392645999999999	56.35924	56.350611999999998	0103000020E610000001000000050000006CCB80B394D85240E6CAA0DAE02C4C406CCB80B394D8524020B58993FB2D4C40EF39B01C21D9524020B58993FB2D4C40EF39B01C21D95240E6CAA0DAE02C4C406CCB80B394D85240E6CAA0DAE02C4C40
48587	Ушаково	5	53	353	75.681257000000002	75.695873000000006	56.372053999999999	56.359808000000001	0103000020E61000000100000005000000F3CAF5B699EB52406A6B44300E2E4C40F3CAF5B699EB5240492C29779F2F4C40D84AE82E89EC5240492C29779F2F4C40D84AE82E89EC52406A6B44300E2E4C40F3CAF5B699EB52406A6B44300E2E4C40
25294	Тармакла	5	53	353	75.513819999999996	75.542997	56.508102999999998	56.494132	0103000020E61000000100000005000000F701486DE2E052401BF4A5B73F3F4C40F701486DE2E05240EFFFE38409414C40DF347D76C0E25240EFFFE38409414C40DF347D76C0E252401BF4A5B73F3F4C40F701486DE2E052401BF4A5B73F3F4C40
14212	Танатово	5	53	353	74.797297	74.812802000000005	56.377217999999999	56.369610999999999	0103000020E61000000100000005000000BB0CFFE906B35240F59ECA694F2F4C40BB0CFFE906B3524034BBEEAD48304C40E607AEF204B4524034BBEEAD48304C40E607AEF204B45240F59ECA694F2F4C40BB0CFFE906B35240F59ECA694F2F4C40
25724	Сперановка	5	53	353	74.947018999999997	74.959801999999996	56.126975000000002	56.116045999999997	0103000020E61000000100000005000000336C94F59BBC5240726A6798DA0E4C40336C94F59BBC52406E3480B740104C40AA285E656DBD52406E3480B740104C40AA285E656DBD5240726A6798DA0E4C40336C94F59BBC5240726A6798DA0E4C40
48627	Самохвалово	5	53	353	75.557703000000004	75.580034999999995	56.350456999999999	56.339956000000001	0103000020E610000001000000050000006478EC67B1E352401C0A9FAD832B4C406478EC67B1E35240BFD364C6DB2C4C4043E21E4B1FE55240BFD364C6DB2C4C4043E21E4B1FE552401C0A9FAD832B4C406478EC67B1E352401C0A9FAD832B4C40
48530	Рязаны	5	53	353	75.193652	75.223016999999999	56.575890000000001	56.568123999999997	0103000020E6100000010000000500000085B35BCB64CC52404E098849B8484C4085B35BCB64CC5240F60B76C3B6494C40EE5C18E945CE5240F60B76C3B6494C40EE5C18E945CE52404E098849B8484C4085B35BCB64CC52404E098849B8484C40
48437	Поречье	5	53	353	74.933651999999995	74.951879000000005	56.584308	56.572111	0103000020E61000000100000005000000147651F4C0BB52404757E9EE3A494C40147651F4C0BB52404565C39ACA4A4C40F3AFE595EBBC52404565C39ACA4A4C40F3AFE595EBBC52404757E9EE3A494C40147651F4C0BB52404757E9EE3A494C40
48793	Плотбище	5	53	353	75.470405	75.485128000000003	56.380656999999999	56.372931000000001	0103000020E61000000100000005000000FEB7921D1BDE52401155F833BC2F4C40FEB7921D1BDE52402AFF5A5EB9304C40EE974F560CDF52402AFF5A5EB9304C40EE974F560CDF52401155F833BC2F4C40FEB7921D1BDE52401155F833BC2F4C40
47925	Окунёво	5	53	353	74.893236999999999	74.917841999999993	56.446275	56.438338000000002	0103000020E61000000100000005000000F0A485CB2AB952400A4CA7751B384C40F0A485CB2AB95240DE02098A1F394C404B395FECBDBA5240DE02098A1F394C404B395FECBDBA52400A4CA7751B384C40F0A485CB2AB952400A4CA7751B384C40
48140	Новорождественка	5	53	353	74.898302999999999	74.933338000000006	56.212629999999997	56.193100999999999	0103000020E6100000010000000500000084B9DDCB7DB9524096E99788B7184C4084B9DDCB7DB952400113B875371B4C404D874ECFBBBB52400113B875371B4C404D874ECFBBBB524096E99788B7184C4084B9DDCB7DB9524096E99788B7184C40
26174	Низовое	5	53	353	75.839262000000005	75.873497	56.401121000000003	56.385741000000003	0103000020E61000000100000005000000A3B1F677B6F55240F9DC09F65F314C40A3B1F677B6F55240925ED4EE57334C40DD09F65FE7F75240925ED4EE57334C40DD09F65FE7F75240F9DC09F65F314C40A3B1F677B6F55240F9DC09F65F314C40
60136	Мыс	5	53	353	75.421599000000001	75.453579000000005	56.356053000000003	56.340998999999996	0103000020E61000000100000005000000AF415F7AFBDA5240FE7BF0DAA52B4C40AF415F7AFBDA524044520B25932D4C40C1C9367007DD524044520B25932D4C40C1C9367007DD5240FE7BF0DAA52B4C40AF415F7AFBDA5240FE7BF0DAA52B4C40
48657	Муромцево	5	53	353	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
25791	Моховой Привал	5	53	353	74.908302000000006	74.933329000000001	56.046759999999999	56.03105	0103000020E610000001000000050000000D39B69E21BA524039454772F9034C400D39B69E21BA524067614F3BFC054C4023DA8EA9BBBB524067614F3BFC054C4023DA8EA9BBBB524039454772F9034C400D39B69E21BA524039454772F9034C40
52962	Михайловка	5	53	353	75.91525	75.947563000000002	56.552954999999997	56.542054	0103000020E610000001000000050000007F6ABC7493FA52403F55850662454C407F6ABC7493FA52407094BC3AC7464C4094F947DFA4FC52407094BC3AC7464C4094F947DFA4FC52403F55850662454C407F6ABC7493FA52403F55850662454C40
25010	Лисино	5	53	353	75.074993000000006	75.108194999999995	56.412362000000002	56.389547999999998	0103000020E61000000100000005000000749B70AFCCC45240711C78B5DC314C40749B70AFCCC452407C0E2C47C8344C40CEA5B8AAECC652407C0E2C47C8344C40CEA5B8AAECC65240711C78B5DC314C40749B70AFCCC45240711C78B5DC314C40
26053	Курнево	5	53	353	75.553166000000004	75.573297999999994	56.308805	56.294320999999997	0103000020E6100000010000000500000096D05D1267E3524054C37E4FAC254C4096D05D1267E35240AFEB17EC86274C402E3718EAB0E45240AFEB17EC86274C402E3718EAB0E4524054C37E4FAC254C4096D05D1267E3524054C37E4FAC254C40
48054	Курганка	5	53	353	75.806867999999994	75.830539000000002	56.449767000000001	56.433878999999997	0103000020E61000000100000005000000170CAEB9A3F35240E9B5D95889374C40170CAEB9A3F35240F7E80DF791394C405DC30C8D27F55240F7E80DF791394C405DC30C8D27F55240E9B5D95889374C40170CAEB9A3F35240E9B5D95889374C40
48119	Костино	5	53	353	74.936104999999998	74.958410000000001	56.179831	56.166916999999998	0103000020E61000000100000005000000D027F224E9BB5240BE1248895D154C40D027F224E9BB52404BE7C3B304174C40338AE59656BD52404BE7C3B304174C40338AE59656BD5240BE1248895D154C40D027F224E9BB5240BE1248895D154C40
48232	Копьево	5	53	353	75.022746999999995	75.033975999999996	55.930070000000001	55.921042	0103000020E610000001000000050000004145D5AF74C15240081F4AB4E4F54B404145D5AF74C15240D07EA4880CF74B405436ACA92CC25240D07EA4880CF74B405436ACA92CC25240081F4AB4E4F54B404145D5AF74C15240081F4AB4E4F54B40
47988	Кондратьево	5	53	353	75.557056000000003	75.594605999999999	56.464122000000003	56.454631999999997	0103000020E61000000100000005000000998235CEA6E3524087DBA161313A4C40998235CEA6E3524054AD8559683B4C40580053060EE6524054AD8559683B4C40580053060EE6524087DBA161313A4C40998235CEA6E3524087DBA161313A4C40
53106	Кокшенёво	5	53	353	75.135818	75.167951000000002	56.391511000000001	56.382890000000003	0103000020E61000000100000005000000520DFB3DB1C8524094FB1D8A02314C40520DFB3DB1C852401B834E081D324C4027158DB5BFCA52401B834E081D324C4027158DB5BFCA524094FB1D8A02314C40520DFB3DB1C8524094FB1D8A02314C40
48094	Качесово	5	53	353	74.748204000000001	74.768946	56.048293999999999	56.032111999999998	0103000020E6100000010000000500000021AF0793E2AF524092E7FA3E1C044C4021AF0793E2AF5240E84B6F7F2E064C40F698486936B15240E84B6F7F2E064C40F698486936B1524092E7FA3E1C044C4021AF0793E2AF524092E7FA3E1C044C40
25313	Карбыза	5	53	353	75.899844000000002	75.927781999999993	56.599707000000002	56.580227999999998	0103000020E610000001000000050000001EE0490B97F952409B1C3EE9444A4C401EE0490B97F952405517F032C34C4C4051F4C0C760FB52405517F032C34C4C4051F4C0C760FB52409B1C3EE9444A4C401EE0490B97F952409B1C3EE9444A4C40
26640	Караклинка	5	53	353	75.174086000000003	75.191468999999998	56.654259000000003	56.649082999999997	0103000020E61000000100000005000000412C9B3924CB5240DDB1D82615534C40412C9B3924CB52408D0E48C2BE534C40A94C310741CC52408D0E48C2BE534C40A94C310741CC5240DDB1D82615534C40412C9B3924CB5240DDB1D82615534C40
25464	Камышино-Курское	5	53	353	74.838313999999997	74.861418999999998	55.976725000000002	55.953567999999997	0103000020E61000000100000005000000DA71C3EFA6B552408D4127840EFA4B40DA71C3EFA6B55240C217265305FD4B40CB49287D21B75240C217265305FD4B40CB49287D21B752408D4127840EFA4B40DA71C3EFA6B552408D4127840EFA4B40
26512	Инцисс	5	53	353	74.85284	74.866144000000006	56.496324000000001	56.487220000000001	0103000020E610000001000000050000001F2E39EE94B6524083FA96395D3E4C401F2E39EE94B65240261C7A8B873F4C401B683EE76EB75240261C7A8B873F4C401B683EE76EB7524083FA96395D3E4C401F2E39EE94B6524083FA96395D3E4C40
26716	Игоревка	5	53	353	75.087462000000002	75.099023000000003	56.575482999999998	56.557107999999999	0103000020E61000000100000005000000236937FA98C55240842BA0504F474C40236937FA98C55240B5334C6DA9494C4051A3906456C65240B5334C6DA9494C4051A3906456C65240842BA0504F474C40236937FA98C55240842BA0504F474C40
48205	Захаровка	5	53	353	74.967536999999993	74.977697000000006	56.020149000000004	56.009445999999997	0103000020E61000000100000005000000E02A4F20ECBD5240FC89CA8635014C40E02A4F20ECBD52400806103E94024C406E19709692BE52400806103E94024C406E19709692BE5240FC89CA8635014C40E02A4F20ECBD5240FC89CA8635014C40
26000	Дурново	5	53	353	75.398656000000003	75.425498000000005	56.301833000000002	56.282429999999998	0103000020E61000000100000005000000AB96749483D9524063B48EAA26244C40AB96749483D9524042EDB776A2264C40DCA0F65B3BDB524042EDB776A2264C40DCA0F65B3BDB524063B48EAA26244C40AB96749483D9524063B48EAA26244C40
47954	Гурово	5	53	353	75.125361999999996	75.163459000000003	56.310732000000002	56.297203000000003	0103000020E61000000100000005000000508A56EE05C85240F5A276BF0A264C40508A56EE05C852400CE9F010C6274C4029CFBC1C76CA52400CE9F010C6274C4029CFBC1C76CA5240F5A276BF0A264C40508A56EE05C85240F5A276BF0A264C40
26315	Гузенево	5	53	353	76.077127000000004	76.091984999999994	56.444906000000003	56.436521999999997	0103000020E61000000100000005000000DFA815A6EF04534004FEF0F3DF374C40DFA815A6EF045340A8E507AEF2384C403EAE0D15E3055340A8E507AEF2384C403EAE0D15E305534004FEF0F3DF374C40DFA815A6EF04534004FEF0F3DF374C40
25678	Большеникольск	5	53	353	74.988996999999998	75.021732	56.144185999999998	56.137269000000003	0103000020E61000000100000005000000E5B512BA4BBF524098E0D40792114C40E5B512BA4BBF52404145D5AF74124C40B5519D0E64C152404145D5AF74124C40B5519D0E64C1524098E0D40792114C40E5B512BA4BBF524098E0D40792114C40
1780	Большекрасноярка	5	53	353	75.917433000000003	75.943933000000001	56.415588999999997	56.403995000000002	0103000020E610000001000000050000005BD1E638B7FA5240AF5FB01BB6334C405BD1E638B7FA5240E6C9350532354C405F27F56569FC5240E6C9350532354C405F27F56569FC5240AF5FB01BB6334C405BD1E638B7FA5240AF5FB01BB6334C40
24985	Бергамак	5	53	353	75.038989000000001	75.069837000000007	56.421081000000001	56.406998999999999	0103000020E61000000100000005000000D7F9B7CB7EC252409A40118B18344C40D7F9B7CB7EC25240C6FB71FBE5354C4040C39B3578C45240C6FB71FBE5354C4040C39B3578C452409A40118B18344C40D7F9B7CB7EC252409A40118B18344C40
24902	Артын	5	53	353	74.737630999999993	74.772872000000007	56.171483000000002	56.135728999999998	0103000020E610000001000000050000000261A75835AF5240340F60915F114C400261A75835AF5240F568AA27F3154C40A0FF1EBC76B15240F568AA27F3154C40A0FF1EBC76B15240340F60915F114C400261A75835AF5240340F60915F114C40
53023	Муромцево	5	53	7252	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
61540	Ясная Поляна	5	53	1708	71.685191000000003	71.694929000000002	54.797818999999997	54.789710999999997	0103000020E61000000100000005000000DE205A2BDAEB51404E25034015654B40DE205A2BDAEB51404F90D8EE1E664B40B0027CB779EC51404F90D8EE1E664B40B0027CB779EC51404E25034015654B40DE205A2BDAEB51404E25034015654B40
49335	Элита	5	53	1708	72.102108000000001	72.134106000000003	54.919839000000003	54.905783	0103000020E610000001000000050000003D2AFEEF88065240EA2285B2F0734B403D2AFEEF88065240ED4ACB48BD754B40A20C553195085240ED4ACB48BD754B40A20C553195085240EA2285B2F0734B403D2AFEEF88065240EA2285B2F0734B40
24073	Шефер	5	53	1708	72.012493000000006	72.027772999999996	55.008814999999998	55.002305	0103000020E61000000100000005000000749B70AFCC00524003CFBD874B804B40749B70AFCC0052406C5B94D920814B408EAD6708C70152406C5B94D920814B408EAD6708C701524003CFBD874B804B40749B70AFCC00524003CFBD874B804B40
47223	Шевченко	5	53	1708	71.775310000000005	71.805880000000002	54.824928	54.808208	0103000020E61000000100000005000000C190D5AD9EF15140CB2E185C73674B40C190D5AD9EF1514000C79E3D97694B400820B58993F3514000C79E3D97694B400820B58993F35140CB2E185C73674B40C190D5AD9EF15140CB2E185C73674B40
53014	Тумба	5	53	1708	71.727798000000007	71.738650000000007	54.737819000000002	54.727494999999998	0103000020E610000001000000050000000806103E94EE51407380608E1E5D4B400806103E94EE514008AF5DDA705E4B40304CA60A46EF514008AF5DDA705E4B40304CA60A46EF51407380608E1E5D4B400806103E94EE51407380608E1E5D4B40
24677	Тумановка	5	53	1708	71.934627000000006	71.959509999999995	55.105356999999998	55.089247999999998	0103000020E610000001000000050000005ABDC3EDD0FB5140E09D7C7A6C8B4B405ABDC3EDD0FB5140CCB392567C8D4B40D68BA19C68FD5140CCB392567C8D4B40D68BA19C68FD5140E09D7C7A6C8B4B405ABDC3EDD0FB5140E09D7C7A6C8B4B40
47575	Татьяновка	5	53	1708	72.102405000000005	72.132210999999998	54.721245000000003	54.710375999999997	0103000020E610000001000000050000009A7CB3CD8D06524080EECB99ED5A4B409A7CB3CD8D065240A7B393C1515C4B40F94A202576085240A7B393C1515C4B40F94A20257608524080EECB99ED5A4B409A7CB3CD8D06524080EECB99ED5A4B40
46229	Степок	5	53	1708	72.013093999999995	72.028616999999997	54.845979999999997	54.833562999999998	0103000020E6100000010000000500000086713788D6005240EC134031B26A4B4086713788D6005240F8889812496C4B4004C765DCD4015240F8889812496C4B4004C765DCD4015240EC134031B26A4B4086713788D6005240EC134031B26A4B40
47464	Спартак	5	53	1708	72.213534999999993	72.227001000000001	55.035874999999997	55.022044999999999	0103000020E610000001000000050000004963B48EAA0D52402905DD5ED2824B404963B48EAA0D52403BDF4F8D97844B4032CA332F870E52403BDF4F8D97844B4032CA332F870E52402905DD5ED2824B404963B48EAA0D52402905DD5ED2824B40
47560	Селивановка	5	53	1708	72.000698	72.021547999999996	54.620584000000001	54.610647	0103000020E610000001000000050000000CCB9F6F0B00524044334FAE294E4B400CCB9F6F0B005240DF35E84B6F4F4B40D4D2DC0A61015240DF35E84B6F4F4B40D4D2DC0A6101524044334FAE294E4B400CCB9F6F0B00524044334FAE294E4B40
24782	Северное	5	53	1708	72.109097000000006	72.131941999999995	54.996521000000001	54.982408999999997	0103000020E61000000100000005000000DFC5FB71FB065240E525FF93BF7D4B40DFC5FB71FB0652407C6308008E7F4B4001BEDBBC710852407C6308008E7F4B4001BEDBBC71085240E525FF93BF7D4B40DFC5FB71FB065240E525FF93BF7D4B40
23683	Розенталь	5	53	1708	71.943897000000007	71.960345000000004	54.912909999999997	54.903717	0103000020E61000000100000005000000B972F6CE68FC51406CEBA7FFAC734B40B972F6CE68FC51407E18213CDA744B4023F8DF4A76FD51407E18213CDA744B4023F8DF4A76FD51406CEBA7FFAC734B40B972F6CE68FC51406CEBA7FFAC734B40
24496	Родная Долина	5	53	1708	71.737159000000005	71.750507999999996	54.870905999999998	54.858383000000003	0103000020E61000000100000005000000EF3CF19C2DEF5140A038807EDF6D4B40EF3CF19C2DEF5140F1F109D9796F4B40BAD8B45208F05140F1F109D9796F4B40BAD8B45208F05140A038807EDF6D4B40EF3CF19C2DEF5140A038807EDF6D4B40
47809	Помурино	5	53	1708	72.111549999999994	72.133737999999994	54.948509999999999	54.943441999999997	0103000020E610000001000000050000009A779CA2230752401FD61BB5C2784B409A779CA223075240E8F692C668794B40E00ED4298F085240E8F692C668794B40E00ED4298F0852401FD61BB5C2784B409A779CA2230752401FD61BB5C2784B40
24088	Новоцарицыно	5	53	1708	71.925804999999997	71.960543000000001	54.674683999999999	54.655875999999999	0103000020E610000001000000050000004A5E9D6340FB51409B1DA9BEF3534B404A5E9D6340FB51403691990B5C564B40B6D9588979FD51403691990B5C564B40B6D9588979FD51409B1DA9BEF3534B404A5E9D6340FB51409B1DA9BEF3534B40
53030	Новоалександровка	5	53	1708	71.668941000000004	71.690482000000003	54.863782	54.852634999999999	0103000020E61000000100000005000000077DE9EDCFEA51406536C824236D4B40077DE9EDCFEA5140CE6F9868906E4B40821E6ADB30EC5140CE6F9868906E4B40821E6ADB30EC51406536C824236D4B40077DE9EDCFEA51406536C824236D4B40
22852	Москаленки	5	53	1708	71.892621000000005	71.954093	54.959330000000001	54.922094999999999	0103000020E6100000010000000500000043AED4B320F951400E677E3507764B4043AED4B320F951402D095053CB7A4B40EC1516DC0FFD51402D095053CB7A4B40EC1516DC0FFD51400E677E3507764B4043AED4B320F951400E677E3507764B40
47504	Мироновка	5	53	1708	72.043852999999999	72.067019999999999	55.065179000000001	55.054006000000001	0103000020E610000001000000050000003735D07CCE025240D6E429ABE9864B403735D07CCE02524068B114C957884B40630B410E4A04524068B114C957884B40630B410E4A045240D6E429ABE9864B403735D07CCE025240D6E429ABE9864B40
24605	Миролюбовка	5	53	1708	71.629181000000003	71.661987999999994	54.870247999999997	54.861539	0103000020E61000000100000005000000EF90628044E85140419DF2E8466E4B40EF90628044E8514067B45549646F4B400B96EA025EEA514067B45549646F4B400B96EA025EEA5140419DF2E8466E4B40EF90628044E85140419DF2E8466E4B40
47404	Майский	5	53	1708	71.758304999999993	71.774052999999995	55.121155000000002	55.111361000000002	0103000020E610000001000000050000002BD9B11188F051406286C613418E4B402BD9B11188F051409A5FCD01828F4B40B91798158AF151409A5FCD01828F4B40B91798158AF151406286C613418E4B402BD9B11188F051406286C613418E4B40
47170	Красный Флаг	5	53	1708	71.926154999999994	71.936943999999997	54.876137999999997	54.866554000000001	0103000020E61000000100000005000000B8019F1F46FB5140E71BD13DEB6E4B40B8019F1F46FB514034643C4A25704B40BD8BF7E3F6FB514034643C4A25704B40BD8BF7E3F6FB5140E71BD13DEB6E4B40B8019F1F46FB5140E71BD13DEB6E4B40
47749	Красное Знамя	5	53	1708	72.041724000000002	72.068601000000001	55.099376999999997	55.083244999999998	0103000020E6100000010000000500000055DD239BAB0252401B47ACC5A78A4B4055DD239BAB025240BF7CB262B88C4B4044DE72F563045240BF7CB262B88C4B4044DE72F5630452401B47ACC5A78A4B4055DD239BAB0252401B47ACC5A78A4B40
47310	Корнеевка	5	53	1708	71.763982999999996	71.784841	54.923113999999998	54.916237000000002	0103000020E61000000100000005000000CCECF318E5F051404D31074147754B40CCECF318E5F05140683D7C9928764B40D6E3BED53AF25140683D7C9928764B40D6E3BED53AF251404D31074147754B40CCECF318E5F051404D31074147754B40
26062	Клаус	5	53	1708	71.943348999999998	71.959069999999997	54.936393000000002	54.920909999999999	0103000020E61000000100000005000000B7ED7BD45FFC51409947FE60E0754B40B7ED7BD45FFC5140079ACFB9DB774B40C824236761FD5140079ACFB9DB774B40C824236761FD51409947FE60E0754B40B7ED7BD45FFC51409947FE60E0754B40
60854	Кзыл-Агаш	5	53	1708	71.837374999999994	71.851128000000003	54.715274999999998	54.709330000000001	0103000020E610000001000000050000003BDF4F8D97F551402D095053CB5A4B403BDF4F8D97F55140BD5296218E5B4B406F2D93E178F65140BD5296218E5B4B406F2D93E178F651402D095053CB5A4B403BDF4F8D97F551402D095053CB5A4B40
33161	Инсарка	5	53	1708	71.845378999999994	71.862896000000006	54.814087000000001	54.802852999999999	0103000020E61000000100000005000000696E85B01AF651406C3F19E3C3664B40696E85B01AF65140A48CB80034684B405AF624B039F75140A48CB80034684B405AF624B039F751406C3F19E3C3664B40696E85B01AF651406C3F19E3C3664B40
47488	Ильичевка	5	53	1708	72.017775	72.038129999999995	55.058812000000003	55.040647	0103000020E61000000100000005000000EEEBC039230152401BD7BFEB33854B40EEEBC03923015240624ED02687874B40C6BFCFB870025240624ED02687874B40C6BFCFB8700252401BD7BFEB33854B40EEEBC039230152401BD7BFEB33854B40
23315	Илеуш	5	53	1708	71.975751000000002	71.984160000000003	54.803418999999998	54.795613000000003	0103000020E61000000100000005000000848252B472FE5140E0A293A5D6654B40848252B472FE514015FE0C6FD6664B400282397AFCFE514015FE0C6FD6664B400282397AFCFE5140E0A293A5D6654B40848252B472FE5140E0A293A5D6654B40
53088	Ивановка	5	53	1708	72.149117000000004	72.185760000000002	55.085121000000001	55.069602000000003	0103000020E61000000100000005000000C59107228B0952403CDEE4B7E8884B40C59107228B095240F699B33EE58A4B40EB39E97DE30B5240F699B33EE58A4B40EB39E97DE30B52403CDEE4B7E8884B40C59107228B0952403CDEE4B7E8884B40
48826	Звездино	5	53	1708	71.654882000000001	71.678481000000005	54.974457999999998	54.960075000000003	0103000020E610000001000000050000004D2F3196E9E95140865AD3BCE37A4B404D2F3196E9E95140ACA92C0ABB7C4B40467D923B6CEB5140ACA92C0ABB7C4B40467D923B6CEB5140865AD3BCE37A4B404D2F3196E9E95140865AD3BCE37A4B40
60167	Жанааул	5	53	1708	71.951946000000007	71.969669999999994	54.739097000000001	54.732926999999997	0103000020E61000000100000005000000B763EAAEECFC51407DAD4B8DD05D4B40B763EAAEECFC51402EC901BB9A5E4B40637AC2120FFE51402EC901BB9A5E4B40637AC2120FFE51407DAD4B8DD05D4B40B763EAAEECFC51407DAD4B8DD05D4B40
61518	Екатериновка	5	53	1708	71.805987999999999	71.840087999999994	54.922203000000003	54.905379000000003	0103000020E61000000100000005000000FB3DB14E95F351401BBE8575E3734B40FB3DB14E95F35140F5A276BF0A764B40C5707500C4F55140F5A276BF0A764B40C5707500C4F551401BBE8575E3734B40FB3DB14E95F351401BBE8575E3734B40
47661	Доброе Поле	5	53	1708	71.808161999999996	71.825445000000002	54.880862	54.867632	0103000020E61000000100000005000000ADF71BEDB8F35140467BBC900E6F4B40ADF71BEDB8F3514003250516C0704B4064E94317D4F4514003250516C0704B4064E94317D4F45140467BBC900E6F4B40ADF71BEDB8F35140467BBC900E6F4B40
23500	Гольбштадт	5	53	1708	71.900446000000002	71.925724000000002	54.925348999999997	54.918591999999997	0103000020E61000000100000005000000197442E8A0F95140012F336C94754B40197442E8A0F95140723106D671764B40D447E00F3FFB5140723106D671764B40D447E00F3FFB5140012F336C94754B40197442E8A0F95140012F336C94754B40
47642	Гвоздевка	5	53	1708	71.872013999999993	71.891560999999996	54.590389999999999	54.576151000000003	0103000020E61000000100000005000000DDE9CE13CFF751406347E350BF494B40DDE9CE13CFF7514056F146E6914B4B40E658DE550FF9514056F146E6914B4B40E658DE550FF951406347E350BF494B40DDE9CE13CFF751406347E350BF494B40
47137	Волчанка	5	53	1708	71.910865999999999	71.923199999999994	54.969517000000003	54.961744000000003	0103000020E610000001000000050000007442E8A04BFA5140E78F696D1A7B4B407442E8A04BFA514041F50F22197C4B40B3EA73B515FB514041F50F22197C4B40B3EA73B515FB5140E78F696D1A7B4B407442E8A04BFA5140E78F696D1A7B4B40
47390	Веселый	5	53	1708	71.788965000000005	71.805107000000007	54.972152999999999	54.962767999999997	0103000020E61000000100000005000000132C0E677EF2514052D158FB3B7B4B40132C0E677EF25140A9DA6E826F7C4B40F7B182DF86F35140A9DA6E826F7C4B40F7B182DF86F3514052D158FB3B7B4B40132C0E677EF2514052D158FB3B7B4B40
52996	Алексеевка	5	53	1708	71.901892000000004	71.936593999999999	54.851889	54.833967000000001	0103000020E610000001000000050000008A213999B8F95140BC783F6EBF6A4B408A213999B8F951403C69E1B20A6D4B404FE8F527F1FB51403C69E1B20A6D4B404FE8F527F1FB5140BC783F6EBF6A4B408A213999B8F95140BC783F6EBF6A4B40
46734	Шереметьевка	5	53	1656	72.553503000000006	72.562881000000004	54.851717999999998	54.846165999999997	0103000020E610000001000000050000003ACFD8976C2352405A7EE02A4F6C4B403ACFD8976C2352400FB56D18056D4B408CA2073E062452400FB56D18056D4B408CA2073E062452405A7EE02A4F6C4B403ACFD8976C2352405A7EE02A4F6C4B40
21770	Чебуренки	5	53	1656	72.509791000000007	72.529311000000007	54.888517	54.882156999999999	0103000020E61000000100000005000000E4326E6AA0205240FF774485EA704B40E4326E6AA02052405378D0ECBA714B40709A3E3BE02152405378D0ECBA714B40709A3E3BE0215240FF774485EA704B40E4326E6AA0205240FF774485EA704B40
49350	Уютное	5	53	1656	72.415476999999996	72.434117000000001	54.879738000000003	54.870947999999999	0103000020E610000001000000050000005FCFD72C971A524020425C397B6F4B405FCFD72C971A5240348639419B704B40CF68AB92C81B5240348639419B704B40CF68AB92C81B524020425C397B6F4B405FCFD72C971A524020425C397B6F4B40
21863	Усовка	5	53	1656	72.640810000000002	72.662091000000004	54.924075999999999	54.905259999999998	0103000020E61000000100000005000000C93CF207032952404030478FDF734B40C93CF207032952405E82531F48764B4076FEEDB25F2A52405E82531F48764B4076FEEDB25F2A52404030478FDF734B40C93CF207032952404030478FDF734B40
53013	Степное	5	53	1656	72.813359000000005	72.841690999999997	55.038711999999997	55.028067999999998	0103000020E61000000100000005000000113AE8120E345240350873BB97834B40113AE8120E3452403BFBCA83F4844B409A95ED43DE3552403BFBCA83F4844B409A95ED43DE355240350873BB97834B40113AE8120E345240350873BB97834B40
22508	Райнфельд	5	53	1656	72.340962000000005	72.363742999999999	54.942289000000002	54.934525999999998	0103000020E6100000010000000500000071CB4752D21552407FA1478C9E774B4071CB4752D2155240B6300BED9C784B408849B89047175240B6300BED9C784B408849B890471752407FA1478C9E774B4071CB4752D21552407FA1478C9E774B40
22350	Пикетное	5	53	1656	72.290377000000007	72.330245000000005	54.957861999999999	54.943317999999998	0103000020E61000000100000005000000AEA069899512524033DDEBA4BE784B40AEA0698995125240630AD6389B7A4B40B9AAECBB22155240630AD6389B7A4B40B9AAECBB2215524033DDEBA4BE784B40AEA069899512524033DDEBA4BE784B40
61531	Петровка	5	53	1656	72.708866999999998	72.715128000000007	54.970427000000001	54.960819000000001	0103000020E61000000100000005000000AC8DB1135E2D52400E30F31DFC7A4B40AC8DB1135E2D5240E413B2F3367C4B400D1D3BA8C42D5240E413B2F3367C4B400D1D3BA8C42D52400E30F31DFC7A4B40AC8DB1135E2D52400E30F31DFC7A4B40
21780	Охровка	5	53	1656	72.455515000000005	72.469519000000005	54.952567999999999	54.948168000000003	0103000020E6100000010000000500000099F56228271D52408F8EAB915D794B4099F56228271D5240AA9B8BBFED794B4071766B990C1E5240AA9B8BBFED794B4071766B990C1E52408F8EAB915D794B4099F56228271D52408F8EAB915D794B40
53022	Орловка	5	53	1656	72.443684000000005	72.479994000000005	55.033181999999996	55.022660000000002	0103000020E610000001000000050000008B709351651C5240B476DB85E6824B408B709351651C52406E68CA4E3F844B40AE11C138B81E52406E68CA4E3F844B40AE11C138B81E5240B476DB85E6824B408B709351651C5240B476DB85E6824B40
22613	Новая Шараповка	5	53	1656	72.770751000000004	72.789544000000006	54.986423000000002	54.975195999999997	0103000020E61000000100000005000000FF9600FC533152405298F738D37C4B40FF9600FC53315240D882DE1B437E4B4032B08EE387325240D882DE1B437E4B4032B08EE3873252405298F738D37C4B40FF9600FC533152405298F738D37C4B40
21476	Нейдорф	5	53	1656	72.281879000000004	72.296863000000002	54.852822000000003	54.845191999999997	0103000020E61000000100000005000000789B374E0A125240A06B5F402F6C4B40789B374E0A12524098A77345296D4B401E19ABCDFF12524098A77345296D4B401E19ABCDFF125240A06B5F402F6C4B40789B374E0A125240A06B5F402F6C4B40
21383	Москаленский	5	53	1656	72.307705999999996	72.343243000000001	54.897060000000003	54.878216000000002	0103000020E610000001000000050000001CB28174B11352407769C36169704B401CB28174B11352405F46B1DCD2724B402EE57CB1F71552405F46B1DCD2724B402EE57CB1F71552407769C36169704B401CB28174B11352407769C36169704B40
53003	Михайловка	5	53	1656	72.703053999999995	72.719835000000003	54.808332999999998	54.803122999999999	0103000020E610000001000000050000009B5434D6FE2C52402CD505BCCC664B409B5434D6FE2C524087A3AB7477674B4009E1D1C6112E524087A3AB7477674B4009E1D1C6112E52402CD505BCCC664B409B5434D6FE2C52402CD505BCCC664B40
21671	Марьяновский	5	53	1656	72.519025999999997	72.538663	54.926456000000002	54.917628999999998	0103000020E6100000010000000500000084F1D3B8372152403B6EF8DD74754B4084F1D3B8372152406C97361C96764B402D246074792252406C97361C96764B402D246074792252403B6EF8DD74754B4084F1D3B8372152403B6EF8DD74754B40
21121	Марьяновка	5	53	1656	72.618694000000005	72.666942000000006	54.971243000000001	54.951436000000001	0103000020E61000000100000005000000D00EB8AE98275240581EA4A7C8794B40D00EB8AE9827524006BCCCB0517C4B400C957F2DAF2A524006BCCCB0517C4B400C957F2DAF2A5240581EA4A7C8794B40D00EB8AE98275240581EA4A7C8794B40
22774	Малая Степнинка	5	53	1656	72.690315999999996	72.706935000000001	55.056609999999999	55.050049999999999	0103000020E61000000100000005000000F4F928232E2C52401895D40968864B40F4F928232E2C5240335019FF3E874B4075594C6C3E2D5240335019FF3E874B4075594C6C3E2D52401895D40968864B40F4F928232E2C52401895D40968864B40
21567	Лесногорский	5	53	1656	72.176434999999998	72.190323000000006	54.847560999999999	54.841838000000003	0103000020E61000000100000005000000AAB706B64A0B5240D943FB58C16B4B40AAB706B64A0B5240BA2EFCE07C6C4B404E2B85402E0C5240BA2EFCE07C6C4B404E2B85402E0C5240D943FB58C16B4B40AAB706B64A0B5240D943FB58C16B4B40
21875	Конезаводский	5	53	1656	72.840496999999999	72.865127999999999	54.952190999999999	54.938333	0103000020E61000000100000005000000B6D8EDB3CA355240F8E0B54B1B784B40B6D8EDB3CA355240D4450A65E1794B40A6B6D4415E375240D4450A65E1794B40A6B6D4415E375240F8E0B54B1B784B40B6D8EDB3CA355240F8E0B54B1B784B40
46607	Кара-Терек	5	53	1656	72.835573999999994	72.843532999999994	54.858797000000003	54.851112000000001	0103000020E61000000100000005000000D3D85E0B7A355240D89DEE3CF16C4B40D3D85E0B7A3552409373620FED6D4B403106D671FC3552409373620FED6D4B403106D671FC355240D89DEE3CF16C4B40D3D85E0B7A355240D89DEE3CF16C4B40
61528	Имени Чапаева	5	53	1656	72.302047000000002	72.319087999999994	54.996721999999998	54.989232999999999	0103000020E61000000100000005000000B7B6F0BC54135240DE8FDB2F9F7E4B40B7B6F0BC54135240139A2496947F4B40F22213F06B145240139A2496947F4B40F22213F06B145240DE8FDB2F9F7E4B40B7B6F0BC54135240DE8FDB2F9F7E4B40
46702	Зеленая Долина	5	53	1656	72.707994999999997	72.716718	54.775371	54.771912	0103000020E61000000100000005000000D1AE42CA4F2D5240EAB12D03CE624B40D1AE42CA4F2D524027A25F5B3F634B40179D2CB5DE2D524027A25F5B3F634B40179D2CB5DE2D5240EAB12D03CE624B40D1AE42CA4F2D5240EAB12D03CE624B40
46785	Заря Свободы	5	53	1656	72.365979999999993	72.391294000000002	54.990431999999998	54.977708	0103000020E610000001000000050000005DBF60376C175240CF842689257D4B405DBF60376C175240B874CC79C67E4B40BF47FDF50A195240B874CC79C67E4B40BF47FDF50A195240CF842689257D4B405DBF60376C175240CF842689257D4B40
60819	Домбай	5	53	1656	72.150007000000002	72.166499999999999	54.767055999999997	54.760396999999998	0103000020E61000000100000005000000F3CAF5B699095240FE7C5BB054614B40F3CAF5B699095240AC1919E42E624B402DB29DEFA70A5240AC1919E42E624B402DB29DEFA70A5240FE7C5BB054614B40F3CAF5B699095240FE7C5BB054614B40
46587	Голенки	5	53	1656	72.849694999999997	72.858777000000003	54.923662	54.914923000000002	0103000020E61000000100000005000000C824236761365240DAAD65321C754B40C8242367613652406B47718E3A764B40A663CE33F63652406B47718E3A764B40A663CE33F6365240DAAD65321C754B40C824236761365240DAAD65321C754B40
46641	Васильевка	5	53	1656	72.739992999999998	72.757581999999999	54.913618999999997	54.907210999999997	0103000020E610000001000000050000003691990B5C2F524025C9737D1F744B403691990B5C2F52408A00A777F1744B40738236397C3052408A00A777F1744B40738236397C30524025C9737D1F744B403691990B5C2F524025C9737D1F744B40
22291	Большая Роща	5	53	1656	72.542445000000001	72.552065999999996	54.798717000000003	54.792332999999999	0103000020E610000001000000050000003DB83B6BB72252405245F12A6B654B403DB83B6BB72252402FE1D05B3C664B40F2CEA10C552352402FE1D05B3C664B40F2CEA10C552352405245F12A6B654B403DB83B6BB72252405245F12A6B654B40
53081	Боголюбовка	5	53	1656	72.638484000000005	72.665746999999996	54.809593999999997	54.796194999999997	0103000020E610000001000000050000003CC1FEEBDC2852408E1EBFB7E9654B403CC1FEEBDC285240D784B4C6A0674B403F1A4E999B2A5240D784B4C6A0674B403F1A4E999B2A52408E1EBFB7E9654B403CC1FEEBDC2852408E1EBFB7E9654B40
61530	Березовка	5	53	1656	72.624613999999994	72.633218999999997	55.052571999999998	55.040466000000002	0103000020E61000000100000005000000EBA7FFACF9275240CB4C69FD2D854B40EBA7FFACF9275240B857E6ADBA864B402C0DFCA886285240B857E6ADBA864B402C0DFCA886285240CB4C69FD2D854B40EBA7FFACF9275240CB4C69FD2D854B40
52973	Алексеевка	5	53	1656	72.701167999999996	72.712414999999993	54.952863000000001	54.941155999999999	0103000020E610000001000000050000001C40BFEFDF2C52409337C0CC77784B401C40BFEFDF2C5240C3482F6AF7794B40828B1535982D5240C3482F6AF7794B40828B1535982D52409337C0CC77784B401C40BFEFDF2C52409337C0CC77784B40
21116	Южный	5	53	1507	72.311154999999999	72.325222999999994	55.058414999999997	55.050818999999997	0103000020E61000000100000005000000293FA9F6E9135240F981AB3C81864B40293FA9F6E9135240444C89247A874B400C3A2174D0145240444C89247A874B400C3A2174D0145240F981AB3C81864B40293FA9F6E9135240F981AB3C81864B40
17709	Щучье	5	53	1507	72.122185999999999	72.139037999999999	55.438803	55.425665000000002	0103000020E61000000100000005000000DC813AE5D1075240A306D3307CB64B40DC813AE5D10752407F315BB22AB84B40AEB9A3FFE50852407F315BB22AB84B40AEB9A3FFE5085240A306D3307CB64B40DC813AE5D1075240A306D3307CB64B40
20166	Шулаевка	5	53	1507	72.209484000000003	72.222752	55.193170000000002	55.189197999999998	0103000020E610000001000000050000004242942F680D5240FB3BDBA337984B404242942F680D5240BF4868CBB9984B4097C79A91410E5240BF4868CBB9984B4097C79A91410E5240FB3BDBA337984B404242942F680D5240FB3BDBA337984B40
20957	Шандровка	5	53	1507	72.440404999999998	72.458003000000005	55.212744999999998	55.199469999999998	0103000020E61000000100000005000000ACFF73982F1C52403D44A33B88994B40ACFF73982F1C52409AB1683A3B9B4B40139ED0EB4F1D52409AB1683A3B9B4B40139ED0EB4F1D52403D44A33B88994B40ACFF73982F1C52403D44A33B88994B40
21016	Чулково	5	53	1507	72.575942999999995	72.600825999999998	55.156568999999998	55.150432000000002	0103000020E610000001000000050000000C570740DC245240CD22145B41934B400C570740DC245240A148F7730A944B408925E5EE73265240A148F7730A944B408925E5EE73265240CD22145B41934B400C570740DC245240CD22145B41934B40
20843	Центрально-Любинский	5	53	1507	72.488618000000002	72.512709999999998	55.133951000000003	55.118673000000001	0103000020E610000001000000050000002A8F6E84451F524088F546AD308F4B402A8F6E84451F52401D226E4E25914B4042959A3DD02052401D226E4E25914B4042959A3DD020524088F546AD308F4B402A8F6E84451F524088F546AD308F4B40
18821	ХVI Партсъезд	5	53	1507	72.862837999999996	72.883938999999998	55.101215000000003	55.097619999999999	0103000020E61000000100000005000000BFEFDFBC38375240BFB7E9CF7E8C4B40BFEFDFBC38375240AD6EF59CF48C4B402C2AE27492385240AD6EF59CF48C4B402C2AE27492385240BFB7E9CF7E8C4B40BFEFDFBC38375240BFB7E9CF7E8C4B40
18525	Филатовка	5	53	1507	72.640127000000007	72.668926999999996	55.219309000000003	55.214275000000001	0103000020E6100000010000000500000058923CD7F7285240DAACFA5C6D9B4B4058923CD7F7285240F75B3B51129C4B40541A31B3CF2A5240F75B3B51129C4B40541A31B3CF2A5240DAACFA5C6D9B4B4058923CD7F7285240DAACFA5C6D9B4B40
18740	Федоровка	5	53	1507	72.928315999999995	72.941800000000001	55.083950999999999	55.077081999999997	0103000020E61000000100000005000000A0168387693B52401D8EAED2DD894B40A0168387693B5240B6BB07E8BE8A4B40DCD78173463C5240B6BB07E8BE8A4B40DCD78173463C52401D8EAED2DD894B40A0168387693B52401D8EAED2DD894B40
21026	Урожайный	5	53	1507	72.281869999999998	72.307822999999999	55.078859999999999	55.064157999999999	0103000020E610000001000000050000004EEE77280A1252406DE34F5436884B404EEE77280A125240357BA015188A4B40397D3D5FB3135240357BA015188A4B40397D3D5FB31352406DE34F5436884B404EEE77280A1252406DE34F5436884B40
20637	Увало-Ядрино	5	53	1507	72.893884	72.928315999999995	55.380293000000002	55.367981	0103000020E61000000100000005000000BB9A3C653539524052465C001AAF4B40BB9A3C6535395240E9F2E670ADB04B40A0168387693B5240E9F2E670ADB04B40A0168387693B524052465C001AAF4B40BB9A3C653539524052465C001AAF4B40
18053	Тарлык	5	53	1507	72.617300999999998	72.640882000000005	55.531900999999998	55.518836	0103000020E6100000010000000500000070B20DDC8127524065FED13769C24B4070B20DDC81275240D7DAFB5415C44B4016A6EF3504295240D7DAFB5415C44B4016A6EF350429524065FED13769C24B4070B20DDC8127524065FED13769C24B40
20491	Тавричанка	5	53	1507	72.755606	72.778360000000006	55.462992999999997	55.450491	0103000020E6100000010000000500000054AA44D95B305240381268B0A9B94B4054AA44D95B30524072A3C85A43BB4B40EF2076A6D031524072A3C85A43BB4B40EF2076A6D0315240381268B0A9B94B4054AA44D95B305240381268B0A9B94B40
18208	Субботинка	5	53	1507	72.405416000000002	72.416060999999999	55.378993999999999	55.368779000000004	0103000020E610000001000000050000009C51F355F2195240CE39782634AF4B409C51F355F2195240ABB019E082B04B40070951BEA01A5240ABB019E082B04B40070951BEA01A5240CE39782634AF4B409C51F355F2195240CE39782634AF4B40
20736	Степановка	5	53	1507	72.827498000000006	72.839607000000001	55.429430000000004	55.418399999999998	0103000020E6100000010000000500000059E02BBAF5345240BD5296218EB54B4059E02BBAF5345240EDF5EE8FF7B64B40889FFF1EBC355240EDF5EE8FF7B64B40889FFF1EBC355240BD5296218EB54B4059E02BBAF5345240BD5296218EB54B40
19880	Смоляновка	5	53	1507	72.528422000000006	72.542247000000003	55.270364000000001	55.256411	0103000020E610000001000000050000002A1F82AAD1215240D6AA5D13D2A04B402A1F82AAD121524004029D499BA24B40AAD6C22CB422524004029D499BA24B40AAD6C22CB4225240D6AA5D13D2A04B402A1F82AAD1215240D6AA5D13D2A04B40
20408	Северо-Любинский	5	53	1507	72.772270000000006	72.812962999999996	55.200169000000002	55.186740999999998	0103000020E61000000100000005000000A56B26DF6C31524042E90B21E7974B40A56B26DF6C315240265646239F994B40EA76F69507345240265646239F994B40EA76F6950734524042E90B21E7974B40A56B26DF6C31524042E90B21E7974B40
20330	Ровная Поляна	5	53	1507	72.515440999999996	72.521001999999996	55.111618999999997	55.098047999999999	0103000020E610000001000000050000001F813FFCFC20524017B83CD68C8C4B401F813FFCFC2052405D4E0988498E4B40A3C9C518582152405D4E0988498E4B40A3C9C5185821524017B83CD68C8C4B401F813FFCFC20524017B83CD68C8C4B40
20198	Протопоповка	5	53	1507	72.595616000000007	72.614687000000004	55.103800999999997	55.093715000000003	0103000020E610000001000000050000005C3E92921E265240841266DAFE8B4B405C3E92921E2652406325E659498D4B40B0912408572752406325E659498D4B40B091240857275240841266DAFE8B4B405C3E92921E265240841266DAFE8B4B40
19973	Пролетарский	5	53	1507	72.343962000000005	72.361236000000005	55.219000000000001	55.205697000000001	0103000020E61000000100000005000000464431790316524052F17F47549A4B40464431790316524079E92631089C4B40D388997D1E17524079E92631089C4B40D388997D1E17524052F17F47549A4B40464431790316524052F17F47549A4B40
18388	Помогаевка	5	53	1507	72.529087000000004	72.552819999999997	55.220382000000001	55.213926000000001	0103000020E61000000100000005000000486FB88FDC215240CEE15AED619B4B40486FB88FDC2152404450357A359C4B40C8242367612352404450357A359C4B40C824236761235240CEE15AED619B4B40486FB88FDC215240CEE15AED619B4B40
19665	Политотдел (Маяк)	5	53	1507	73.148143000000005	73.170627999999994	55.215051000000003	55.199824999999997	0103000020E610000001000000050000006808C72C7B4952402BF697DD93994B406808C72C7B4952406EFC89CA869B4B400AF2B391EB4A52406EFC89CA869B4B400AF2B391EB4A52402BF697DD93994B406808C72C7B4952402BF697DD93994B40
19781	Новокиевка	5	53	1507	72.441699	72.459377000000003	55.271272000000003	55.251638999999997	0103000020E6100000010000000500000042EBE1CB441C5240F6B2EDB435A04B4042EBE1CB441C52400729780AB9A24B4037E2C96E661D52400729780AB9A24B4037E2C96E661D5240F6B2EDB435A04B4042EBE1CB441C5240F6B2EDB435A04B40
19684	Новоархангелка	5	53	1507	73.010620000000003	73.048169000000001	55.357551999999998	55.342666999999999	0103000020E61000000100000005000000BF2B82FFAD4052408F352383DCAB4B40BF2B82FFAD405240484F9143C4AD4B4096EB6D3315435240484F9143C4AD4B4096EB6D33154352408F352383DCAB4B40BF2B82FFAD4052408F352383DCAB4B40
18199	Мокшино	5	53	1507	72.304642999999999	72.322141999999999	55.354522000000003	55.339083000000002	0103000020E61000000100000005000000247D5A457F13524096D05D1267AB4B40247D5A457F13524034DB15FA60AD4B40C1AA7AF99D14524034DB15FA60AD4B40C1AA7AF99D14524096D05D1267AB4B40247D5A457F13524096D05D1267AB4B40
18663	Матюшино	5	53	1507	72.774731000000003	72.781343000000007	55.272554	55.259084000000001	0103000020E61000000100000005000000A20C5531953152405C751DAA29A14B40A20C5531953152406E32AA0CE3A24B4059FD1186013252406E32AA0CE3A24B4059FD1186013252405C751DAA29A14B40A20C5531953152405C751DAA29A14B40
53009	Любинский	5	53	1507	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
19500	Любино-Малороссы	5	53	1507	72.982763000000006	73.033212000000006	55.210622999999998	55.194105999999998	0103000020E61000000100000005000000022EC896E53E52408BFA2477D8984B40022EC896E53E52408864C8B1F59A4B406D753925204252408864C8B1F59A4B406D753925204252408BFA2477D8984B40022EC896E53E52408BFA2477D8984B40
20875	Луговой	5	53	1507	72.386982000000003	72.400744000000003	55.122492999999999	55.111449	0103000020E6100000010000000500000001892650C41852400116F9F5438E4B4001892650C4185240957EC2D9AD8F4B405E8429CAA5195240957EC2D9AD8F4B405E8429CAA51952400116F9F5438E4B4001892650C41852400116F9F5438E4B40
53123	Красный Яр	5	53	1507	72.909486999999999	72.985476000000006	55.249084000000003	55.199933000000001	0103000020E61000000100000005000000C748F608353A52401232906797994B40C748F608353A52407BFA08FCE19F4B408CBFED09123F52407BFA08FCE19F4B408CBFED09123F52401232906797994B40C748F608353A52401232906797994B40
20275	Кочки	5	53	1507	72.669134	72.687540999999996	55.090381999999998	55.087114999999997	0103000020E6100000010000000500000011A96917D32A5240DAFE9595268B4B4011A96917D32A5240D3122BA3918B4B402F6AF7AB002C5240D3122BA3918B4B402F6AF7AB002C5240DAFE9595268B4B4011A96917D32A5240DAFE9595268B4B40
19581	Китайлы	5	53	1507	73.064877999999993	73.092528000000001	55.226954999999997	55.21407	0103000020E61000000100000005000000B60E0EF626445240018750A5669B4B40B60E0EF626445240F35487DC0C9D4B40B77D8FFAEB455240F35487DC0C9D4B40B77D8FFAEB455240018750A5669B4B40B60E0EF626445240018750A5669B4B40
18599	Квасовка	5	53	1507	72.681944000000001	72.714472000000001	55.279871999999997	55.269046000000003	0103000020E61000000100000005000000056D72F8A42B5240508F6D1970A24B40056D72F8A42B524076887FD8D2A34B40187AC4E8B92D524076887FD8D2A34B40187AC4E8B92D5240508F6D1970A24B40056D72F8A42B5240508F6D1970A24B40
18132	Капустино	5	53	1507	72.369850999999997	72.389605000000003	55.427979000000001	55.420386999999998	0103000020E61000000100000005000000255987A3AB175240EF54C03DCFB54B40255987A3AB175240F92F1004C8B64B40EB56CF49EF185240F92F1004C8B64B40EB56CF49EF185240EF54C03DCFB54B40255987A3AB175240EF54C03DCFB54B40
19890	Канаковка	5	53	1507	72.509727999999996	72.531692000000007	55.313316	55.309766000000003	0103000020E61000000100000005000000C07630629F205240D5B48B69A6A74B40C07630629F20524022A81ABD1AA84B40DFE2E13D0722524022A81ABD1AA84B40DFE2E13D07225240D5B48B69A6A74B40C07630629F205240D5B48B69A6A74B40
18727	Камышловский	5	53	1507	72.931352000000004	72.956793000000005	55.122425999999997	55.109569	0103000020E610000001000000050000001C446B459B3B5240E5D3635B068E4B401C446B459B3B52400D17B9A7AB8F4B40AC02B5183C3D52400D17B9A7AB8F4B40AC02B5183C3D5240E5D3635B068E4B401C446B459B3B5240E5D3635B068E4B40
20667	Калиновка	5	53	1507	72.771973000000003	72.781324999999995	55.384231999999997	55.370789000000002	0103000020E610000001000000050000004819710168315240B85B920376AF4B404819710168315240D009A1832EB14B4005A3923A01325240D009A1832EB14B4005A3923A01325240B85B920376AF4B404819710168315240B85B920376AF4B40
18571	Казанка	5	53	1507	72.738007999999994	72.765236000000002	55.278334000000001	55.259228	0103000020E61000000100000005000000ED0BE8853B2F52408F1A13622EA14B40ED0BE8853B2F5240B4AED172A0A34B40336E6AA0F9305240B4AED172A0A34B40336E6AA0F93052408F1A13622EA14B40ED0BE8853B2F52408F1A13622EA14B40
18294	Замелетеновка	5	53	1507	72.637917999999999	72.666573999999997	55.238249000000003	55.230353999999998	0103000020E61000000100000005000000E7E104A6D32852405B40683D7C9D4B40E7E104A6D328524001A777F17E9E4B404A97FE25A92A524001A777F17E9E4B404A97FE25A92A52405B40683D7C9D4B40E7E104A6D32852405B40683D7C9D4B40
18113	Веселая Поляна	5	53	1507	72.295991999999998	72.324288999999993	55.381480000000003	55.372401000000004	0103000020E610000001000000050000002BF86D88F1125240B5FF01D6AAAF4B402BF86D88F1125240FF092E56D4B04B40F65CA626C1145240FF092E56D4B04B40F65CA626C1145240B5FF01D6AAAF4B402BF86D88F1125240B5FF01D6AAAF4B40
20577	Быструха	5	53	1507	72.788411999999994	72.802237000000005	55.426467000000002	55.415436	0103000020E6100000010000000500000088F19A577532524060CAC0012DB54B4088F19A577532524060E97C7896B64B4009A9DBD95733524060E97C7896B64B4009A9DBD95733524060CAC0012DB54B4088F19A577532524060CAC0012DB54B40
20111	Борятино	5	53	1507	72.185795999999996	72.206798000000006	55.280523000000002	55.277056999999999	0103000020E6100000010000000500000091EEE714E40B52405E10919A76A34B4091EEE714E40B52404E637B2DE8A34B4035B8AD2D3C0D52404E637B2DE8A34B4035B8AD2D3C0D52405E10919A76A34B4091EEE714E40B52405E10919A76A34B40
17849	Большемогильное	5	53	1507	72.600151999999994	72.635859999999994	55.401048000000003	55.393380000000001	0103000020E610000001000000050000004128EFE36826524043739D465AB24B404128EFE3682652402810768A55B34B40693524EEB12852402810768A55B34B40693524EEB128524043739D465AB24B404128EFE36826524043739D465AB24B40
17992	Большаковка	5	53	1507	72.522754000000006	72.552819999999997	55.436300000000003	55.424101999999998	0103000020E610000001000000050000009B7631CD7421524087156EF948B64B409B7631CD74215240569FABADD8B74B40C824236761235240569FABADD8B74B40C82423676123524087156EF948B64B409B7631CD7421524087156EF948B64B40
17786	Боголюбовка	5	53	1507	72.642354999999995	72.672853000000003	55.319653000000002	55.301760999999999	0103000020E61000000100000005000000035B25581C295240A81ABD1AA0A64B40035B25581C295240BE88B663EAA84B40FE800706102B5240BE88B663EAA84B40FE800706102B5240A81ABD1AA0A64B40035B25581C295240A81ABD1AA0A64B40
18347	Беляевка	5	53	1507	72.710717000000002	72.713592000000006	55.243803	55.229219000000001	0103000020E6100000010000000500000085ED27637C2D5240984F560C579D4B4085ED27637C2D524056D5CBEF349F4B40FCABC77DAB2D524056D5CBEF349F4B40FCABC77DAB2D5240984F560C579D4B4085ED27637C2D5240984F560C579D4B40
20480	Барсуковка	5	53	1507	72.735268000000005	72.749210000000005	55.233674999999998	55.222000000000001	0103000020E61000000100000005000000E77283A10E2F524023DBF97E6A9C4B40E77283A10E2F52404772F90FE99D4B4084F57F0EF32F52404772F90FE99D4B4084F57F0EF32F524023DBF97E6A9C4B40E77283A10E2F524023DBF97E6A9C4B40
18456	Бабайловка	5	53	1507	72.609234000000001	72.621757000000002	55.233443999999999	55.218009000000002	0103000020E610000001000000050000001F679AB0FD265240E99D0AB8E79B4B401F679AB0FD26524045B9347EE19D4B40C843DFDDCA27524045B9347EE19D4B40C843DFDDCA275240E99D0AB8E79B4B401F679AB0FD265240E99D0AB8E79B4B40
17955	Астрахановка	5	53	1507	72.587468000000001	72.609594000000001	55.267487000000003	55.262141999999997	0103000020E6100000010000000500000094DC6113992552403A747ADE8DA14B4094DC611399255240768D96033DA24B409F758D9603275240768D96033DA24B409F758D96032752403A747ADE8DA14B4094DC6113992552403A747ADE8DA14B40
17630	Алексеевка	5	53	1507	72.046862000000004	72.093052999999998	55.356594999999999	55.343204999999998	0103000020E61000000100000005000000365B79C9FF0252406E693524EEAB4B40365B79C9FF0252406475ABE7A4AD4B40DCF29194F40552406475ABE7A4AD4B40DCF29194F40552406E693524EEAB4B40365B79C9FF0252406E693524EEAB4B40
19777	Авлы	5	53	1507	72.982853000000006	73.004510999999994	55.328851999999998	55.311988999999997	0103000020E61000000100000005000000A2F14410E73E52401ADB6B41EFA74B40A2F14410E73E5240B29C84D217AA4B40395E81E849405240B29C84D217AA4B40395E81E8494052401ADB6B41EFA74B40A2F14410E73E52401ADB6B41EFA74B40
53004	им. Максима Горького	5	53	1089	71.716570000000004	71.735641000000001	56.200327999999999	56.193452000000001	0103000020E61000000100000005000000DDD26A48DCED514043ACFE08C3184C40DDD26A48DCED51408E3C1059A4194C403126FDBD14EF51408E3C1059A4194C403126FDBD14EF514043ACFE08C3184C40DDD26A48DCED514043ACFE08C3184C40
16440	Яман	5	53	1089	71.377015	71.415248000000005	56.050375000000003	56.036256000000002	0103000020E610000001000000050000007EC6850321D8514053245F09A4044C407EC6850321D851409CC420B072064C40AFEE586C93DA51409CC420B072064C40AFEE586C93DA514053245F09A4044C407EC6850321D8514053245F09A4044C40
49070	Ширяево	5	53	1089	71.210386999999997	71.229367999999994	56.188046999999997	56.179786	0103000020E610000001000000050000003A2009FB76CD5140AB23473A03174C403A2009FB76CD5140328E91EC11184C40EEAF1EF7ADCE5140328E91EC11184C40EEAF1EF7ADCE5140AB23473A03174C403A2009FB76CD5140AB23473A03174C40
49144	Шипуново	5	53	1089	71.519972999999993	71.559364000000002	56.264266999999997	56.249316	0103000020E610000001000000050000006473D53C47E151404D2F3196E91F4C406473D53C47E15140BD344580D3214C40D3A3A99ECCE35140BD344580D3214C40D3A3A99ECCE351404D2F3196E91F4C406473D53C47E151404D2F3196E91F4C40
48862	Чумановка	5	53	1089	71.627240999999998	71.651692999999995	55.961455000000001	55.954168000000003	0103000020E61000000100000005000000766D6FB724E85140E371512D22FA4B40766D6FB724E85140B0C91AF510FB4B400E828E56B5E95140B0C91AF510FB4B400E828E56B5E95140E371512D22FA4B40766D6FB724E85140E371512D22FA4B40
16202	Чикишево	5	53	1089	71.580888000000002	71.600066999999996	55.909030000000001	55.898648999999999	0103000020E61000000100000005000000E3A8DC442DE55140A3CA30EE06F34B40E3A8DC442DE551409C8A54185BF44B402A1A6B7F67E651409C8A54185BF44B402A1A6B7F67E65140A3CA30EE06F34B40E3A8DC442DE55140A3CA30EE06F34B40
17351	Усть-Логатка	5	53	1089	71.977620000000002	72.001165	56.227634999999999	56.217941000000003	0103000020E6100000010000000500000098FA795391FE514091BA9D7DE51B4C4098FA795391FE51406536C824231D4C4097395D16130052406536C824231D4C4097395D161300524091BA9D7DE51B4C4098FA795391FE514091BA9D7DE51B4C40
17528	Усть-Китерма	5	53	1089	71.663820000000001	71.680313999999996	56.084626	56.075011000000003	0103000020E61000000100000005000000919BE1067CEA51408EEBDFF599094C40919BE1067CEA514016325706D50A4C40B340BB438AEB514016325706D50A4C40B340BB438AEB51408EEBDFF599094C40919BE1067CEA51408EEBDFF599094C40
17049	Толоконцево	5	53	1089	71.180256999999997	71.213162999999994	56.458844999999997	56.432371000000003	0103000020E6100000010000000500000001F8A75489CB5140925ED4EE57374C4001F8A75489CB51407077D66EBB3A4C40E76D6C76A4CD51407077D66EBB3A4C40E76D6C76A4CD5140925ED4EE57374C4001F8A75489CB5140925ED4EE57374C40
16766	Стахановка	5	53	1089	71.022711000000001	71.033625000000001	56.291468999999999	56.285522999999998	0103000020E610000001000000050000009B90D61874C15140BEA085048C244C409B90D61874C151401F662FDB4E254C40FED478E926C251401F662FDB4E254C40FED478E926C25140BEA085048C244C409B90D61874C15140BEA085048C244C40
17216	Сингуль	5	53	1089	71.652124000000001	71.661484999999999	56.248680999999998	56.241883999999999	0103000020E61000000100000005000000F33B4D66BCE951407CB60E0EF61E4C40F33B4D66BCE951407B116DC7D41F4C40DA722EC555EA51407B116DC7D41F4C40DA722EC555EA51407CB60E0EF61E4C40F33B4D66BCE951407CB60E0EF61E4C40
48781	Самаровка	5	53	1089	71.441173000000006	71.459310000000002	55.832399000000002	55.822083999999997	0103000020E6100000010000000500000035B8AD2D3CDC51404D486B0C3AE94B4035B8AD2D3CDC51408F1CE90C8CEA4B40732EC55565DD51408F1CE90C8CEA4B40732EC55565DD51404D486B0C3AE94B4035B8AD2D3CDC51404D486B0C3AE94B40
17618	Салтаим	5	53	1089	71.769157000000007	71.796789000000004	56.054552999999999	56.039665999999997	0103000020E61000000100000005000000541F48DE39F15140AE6186C613054C40541F48DE39F151400873BB97FB064C4001344A97FEF251400873BB97FB064C4001344A97FEF25140AE6186C613054C40541F48DE39F15140AE6186C613054C40
48883	Рыжково	5	53	1089	70.984622000000002	71.013180000000006	56.005223999999998	55.988827000000001	0103000020E61000000100000005000000043BFE0B04BF51406E3315E291FE4B40043BFE0B04BF5140C093162EAB004C40863DEDF0D7C05140C093162EAB004C40863DEDF0D7C051406E3315E291FE4B40043BFE0B04BF51406E3315E291FE4B40
52981	Паново	5	53	1089	70.949506999999997	70.988341000000005	56.360118	56.345194999999997	0103000020E61000000100000005000000AD1402B9C4BC514011DF89592F2C4C40AD1402B9C4BC5140B859BC58182E4C40F1129CFA40BF5140B859BC58182E4C40F1129CFA40BF514011DF89592F2C4C40AD1402B9C4BC514011DF89592F2C4C40
49047	Ольгино	5	53	1089	71.032296000000002	71.056855999999996	56.243690000000001	56.236700999999996	0103000020E61000000100000005000000AAF23D2311C251401AF7E6374C1E4C40AAF23D2311C251405E2EE23B311F4C4035255987A3C351405E2EE23B311F4C4035255987A3C351401AF7E6374C1E4C40AAF23D2311C251401AF7E6374C1E4C40
16085	Оглухино	5	53	1089	71.774833999999998	71.794786000000002	55.869737999999998	55.851571	0103000020E610000001000000050000000C7558E196F151406B9C4D4700ED4B400C7558E196F15140520B259353EF4B40655419C6DDF25140520B259353EF4B40655419C6DDF251406B9C4D4700ED4B400C7558E196F151406B9C4D4700ED4B40
48669	Новопокровка	5	53	1089	71.223781000000002	71.256381000000005	56.021286000000003	56.008665999999998	0103000020E61000000100000005000000D61D8B6D52CE5140274BADF71B014C40D61D8B6D52CE51406CEEE87FB9024C403694DA8B68D051406CEEE87FB9024C403694DA8B68D05140274BADF71B014C40D61D8B6D52CE5140274BADF71B014C40
53033	Новокарасук	5	53	1089	71.784761000000003	71.831500000000005	56.270930999999997	56.257708000000001	0103000020E61000000100000005000000488B338639F2514073F56393FC204C40488B338639F251407D3CF4DDAD224C40F0A7C64B37F551407D3CF4DDAD224C40F0A7C64B37F5514073F56393FC204C40488B338639F2514073F56393FC204C40
15999	Новгородцево	5	53	1089	71.613380000000006	71.630645999999999	55.943058999999998	55.934108999999999	0103000020E610000001000000050000005001309E41E751401BF33AE290F74B405001309E41E7514067994528B6F84B409B560A815CE8514067994528B6F84B409B560A815CE851401BF33AE290F74B405001309E41E751401BF33AE290F74B40
27705	Никольск	5	53	1089	71.225964000000005	71.24879	56.497725000000003	56.490281000000003	0103000020E61000000100000005000000B284B53176CE5140D36C1E87C13E4C40B284B53176CE514068B3EA73B53F4C409964E42CECCF514068B3EA73B53F4C409964E42CECCF5140D36C1E87C13E4C40B284B53176CE5140D36C1E87C13E4C40
9605	Крутинка	5	53	1089	71.466452000000004	71.545387000000005	56.019244	55.989426000000002	0103000020E61000000100000005000000D8497D59DADD5140F3E7DB82A5FE4B40D8497D59DADD514076525F9676024C40782AE09EE7E2514076525F9676024C40782AE09EE7E25140F3E7DB82A5FE4B40D8497D59DADD5140F3E7DB82A5FE4B40
49102	Красный Яр	5	53	1089	71.080759999999998	71.104106999999999	56.391531000000001	56.382192000000003	0103000020E61000000100000005000000CCB4FD2B2BC551407C65DEAAEB304C40CCB4FD2B2BC55140622F14B01D324C40381268B0A9C65140622F14B01D324C40381268B0A9C651407C65DEAAEB304C40CCB4FD2B2BC551407C65DEAAEB304C40
60830	Красный Пахарь	5	53	1089	71.488990000000001	71.520099000000002	56.094102999999997	56.088121999999998	0103000020E610000001000000050000008C84B69C4BDF51407007EA94470B4C408C84B69C4BDF51404DBA2D910B0C4C40ABEB504D49E151404DBA2D910B0C4C40ABEB504D49E151407007EA94470B4C408C84B69C4BDF51407007EA94470B4C40
17381	Коломенка	5	53	1089	71.821635999999998	71.838785000000001	56.306657999999999	56.299565999999999	0103000020E61000000100000005000000D74D29AF95F451402C7FBE2D58264C40D74D29AF95F451404487C09140274C4006D847A7AEF551404487C09140274C4006D847A7AEF551402C7FBE2D58264C40D74D29AF95F451402C7FBE2D58264C40
16347	Колодцы	5	53	1089	70.926196000000004	70.950055000000006	56.011293000000002	55.998952000000003	0103000020E61000000100000005000000E86B96CB46BB51400C23BDA8DDFF4B40E86B96CB46BB51403DD68C0C72014C40AF997CB3CDBC51403DD68C0C72014C40AF997CB3CDBC51400C23BDA8DDFF4B40E86B96CB46BB51400C23BDA8DDFF4B40
17505	Китерма	5	53	1089	71.611052999999998	71.639017999999993	56.103541999999997	56.090527999999999	0103000020E61000000100000005000000DAC70A7E1BE75140A7AFE76B960B4C40DAC70A7E1BE7514097E13FDD400D4C408AE3C0ABE5E8514097E13FDD400D4C408AE3C0ABE5E85140A7AFE76B960B4C40DAC70A7E1BE75140A7AFE76B960B4C40
40470	Камчатка	5	53	1089	71.274895000000001	71.295411999999999	56.371724999999998	56.364739999999998	0103000020E610000001000000050000005FB532E197D1514082C5E1CCAF2E4C405FB532E197D15140840D4FAF942F4C4024B6BB07E8D25140840D4FAF942F4C4024B6BB07E8D2514082C5E1CCAF2E4C405FB532E197D1514082C5E1CCAF2E4C40
15921	Калачики	5	53	1089	71.629092	71.642691999999997	56.056176000000001	56.045735000000001	0103000020E61000000100000005000000378B170B43E851402BA4FCA4DA054C40378B170B43E85140F96871C630074C40A759A0DD21E95140F96871C630074C40A759A0DD21E951402BA4FCA4DA054C40378B170B43E851402BA4FCA4DA054C40
48980	Зимино	5	53	1089	70.852272999999997	70.882744000000002	56.285612999999998	56.276114	0103000020E61000000100000005000000E2900DA48BB65140DFFB1BB457234C40E2900DA48BB65140FE277FF78E244C4060AFB0E07EB85140FE277FF78E244C4060AFB0E07EB85140DFFB1BB457234C40E2900DA48BB65140DFFB1BB457234C40
17440	Заозёрная	5	53	1089	71.861260999999999	71.889396000000005	56.396379000000003	56.387141	0103000020E610000001000000050000007F1475E61EF751406AF816D68D314C407F1475E61EF751401DE90C8CBC324C405E4C33DDEBF851401DE90C8CBC324C405E4C33DDEBF851406AF816D68D314C407F1475E61EF751406AF816D68D314C40
16684	Гуляй-Поле	5	53	1089	70.930490000000006	70.948087999999998	56.270561000000001	56.263857000000002	0103000020E6100000010000000500000053D0ED258DBB51400CE9F010C6214C4053D0ED258DBB51405A492BBEA1224C40B96E4A79ADBC51405A492BBEA1224C40B96E4A79ADBC51400CE9F010C6214C4053D0ED258DBB51400CE9F010C6214C40
52775	Горькое	5	53	1089	71.577878999999996	71.593508999999997	56.277797999999997	56.269635999999998	0103000020E61000000100000005000000E48233F8FBE4514081E9B46E83224C40E48233F8FBE45140757286E28E234C406D382C0DFCE55140757286E28E234C406D382C0DFCE5514081E9B46E83224C40E48233F8FBE4514081E9B46E83224C40
52745	Верхний Яман	5	53	1089	71.167446999999996	71.190641999999997	56.008977999999999	56.003366	0103000020E610000001000000050000000D349F73B7CA51408CF50D4C6E004C400D349F73B7CA51401631EC3026014C409ECF807A33CC51401631EC3026014C409ECF807A33CC51408CF50D4C6E004C400D349F73B7CA51408CF50D4C6E004C40
49006	Юрьево	5	53	1075	74.192569000000006	74.214406999999994	55.159073999999997	55.136262000000002	0103000020E610000001000000050000004D4EED0C538C524002D8800871914B404D4EED0C538C52406BD26D895C944B40244223D8B88D52406BD26D895C944B40244223D8B88D524002D8800871914B404D4EED0C538C524002D8800871914B40
48346	Фоминовка 2-я	5	53	1075	74.258028999999993	74.272599999999997	54.808653999999997	54.795451999999997	0103000020E61000000100000005000000DA1A118C83905240D6C4025FD1654B40DA1A118C83905240C9E369F981674B40EF38454772915240C9E369F981674B40EF38454772915240D6C4025FD1654B40DA1A118C83905240D6C4025FD1654B40
48417	Фоминовка 1-я	5	53	1075	74.255369999999999	74.266186000000005	54.836378000000003	54.827629999999999	0103000020E610000001000000050000004A9869FB579052402098A3C7EF694B404A9869FB57905240058C2E6F0E6B4B40CC29013109915240058C2E6F0E6B4B40CC290131099152402098A3C7EF694B404A9869FB579052402098A3C7EF694B40
53096	Сыропятское ж/д ст	5	53	1075	73.853562999999994	73.870361000000003	54.976581000000003	54.972158	0103000020E61000000100000005000000D784B4C6A0765240BB4560AC6F7C4B40D784B4C6A07652408F72309B007D4B40B0AD9FFEB37752408F72309B007D4B40B0AD9FFEB3775240BB4560AC6F7C4B40D784B4C6A0765240BB4560AC6F7C4B40
15162	Сыропятское	5	53	1075	73.857318000000006	73.889801000000006	55.058719000000004	55.036085999999997	0103000020E610000001000000050000006B11514CDE765240F6EB4E779E844B406B11514CDE765240B153AC1A84874B40AEBCE47FF2785240B153AC1A84874B40AEBCE47FF2785240F6EB4E779E844B406B11514CDE765240F6EB4E779E844B40
15518	Станкеевка	5	53	1075	73.943161000000003	73.960623999999996	54.931386000000003	54.926684000000002	0103000020E610000001000000050000003677F4BF5C7C5240FDDCD0949D764B403677F4BF5C7C5240E4F90CA837774B402CF015DD7A7D5240E4F90CA837774B402CF015DD7A7D5240FDDCD0949D764B403677F4BF5C7C5240FDDCD0949D764B40
15136	Спайка	5	53	1075	74.083980999999994	74.098946999999995	54.723793000000001	54.709788000000003	0103000020E61000000100000005000000101FD8F15F855240F08B4B55DA5A4B40101FD8F15F8552407009C03FA55C4B406342CC25558652407009C03FA55C4B406342CC2555865240F08B4B55DA5A4B40101FD8F15F855240F08B4B55DA5A4B40
48397	Салтыковка	5	53	1075	74.051039000000003	74.073363000000001	54.913271999999999	54.908127	0103000020E6100000010000000500000084F4143944835240ABCE6A813D744B4084F41439448352401F2DCE18E6744B40226FB9FAB18452401F2DCE18E6744B40226FB9FAB1845240ABCE6A813D744B4084F4143944835240ABCE6A813D744B40
48658	Рощинский	5	53	1075	74.115862000000007	74.137411999999998	55.115105	55.100541	0103000020E61000000100000005000000593673486A8752401D740987DE8C4B40593673486A875240944DB9C2BB8E4B40FD84B35BCB885240944DB9C2BB8E4B40FD84B35BCB8852401D740987DE8C4B40593673486A8752401D740987DE8C4B40
15078	Победитель	5	53	1075	74.054094000000006	74.083872999999997	54.787489000000001	54.770556999999997	0103000020E610000001000000050000003B3AAE4676835240185A9D9CA1624B403B3AAE4676835240D97A8670CC644B401D01DC2C5E855240D97A8670CC644B401D01DC2C5E855240185A9D9CA1624B403B3AAE4676835240185A9D9CA1624B40
48404	Новоселье	5	53	1075	74.233289999999997	74.254265000000004	54.878759000000002	54.857630999999998	0103000020E61000000100000005000000F71E2E39EE8E5240948444DAC66D4B40F71E2E39EE8E52406808C72C7B704B401EE1B4E0459052406808C72C7B704B401EE1B4E045905240948444DAC66D4B40F71E2E39EE8E5240948444DAC66D4B40
48206	Новая Деревня	5	53	1075	74.039288999999997	74.049610999999999	54.983395999999999	54.973160999999998	0103000020E61000000100000005000000EC8502B6838252400F5F268A907C4B40EC8502B68382524034828DEBDF7D4B4066A19DD32C83524034828DEBDF7D4B4066A19DD32C8352400F5F268A907C4B40EC8502B6838252400F5F268A907C4B40
48651	Никитино	5	53	1075	74.086478	74.096647000000004	55.040889	55.029017000000003	0103000020E61000000100000005000000B47405DB8885524097033DD4B6834B40B47405DB8885524011E2CAD93B854B406B10E6762F86524011E2CAD93B854B406B10E6762F86524097033DD4B6834B40B47405DB8885524097033DD4B6834B40
15470	Немировка	5	53	1075	73.871196999999995	73.891238000000001	54.928809999999999	54.920532000000001	0103000020E61000000100000005000000E4D70FB1C1775240F37519FED3754B40E4D70FB1C17752405019FF3EE3764B40F5BC1B0B0A7952405019FF3EE3764B40F5BC1B0B0A795240F37519FED3754B40E4D70FB1C1775240F37519FED3754B40
40466	Некрасовка	5	53	1075	74.110462999999996	74.139065000000002	54.894734999999997	54.883923000000003	0103000020E61000000100000005000000C11A67D31187524053978C6324714B40C11A67D31187524014CB2DAD86724B402BC1E270E688524014CB2DAD86724B402BC1E270E688524053978C6324714B40C11A67D31187524053978C6324714B40
53007	Михайловка	5	53	1075	74.264945999999995	74.286406999999997	54.773237000000002	54.758853999999999	0103000020E610000001000000050000002F4D11E0F49052402A38BC2022614B402F4D11E0F49052405187156EF9624B401C96067E549252405187156EF9624B401C96067E549252402A38BC2022614B402F4D11E0F49052402A38BC2022614B40
48239	Корниловка	5	53	1075	73.949099000000004	73.967343	55.026555999999999	55.022680000000001	0103000020E61000000100000005000000A56ABB09BE7C5240FB22A12DE7824B40A56ABB09BE7C52409CC1DF2F66834B40EE409DF2E87D52409CC1DF2F66834B40EE409DF2E87D5240FB22A12DE7824B40A56ABB09BE7C5240FB22A12DE7824B40
13946	Кормиловка	5	53	1075	74.066490000000002	74.127818000000005	55.014767999999997	54.991222	0103000020E61000000100000005000000B5E0455F41845240B189CC5CE07E4B40B5E0455F418452407F83F6EAE3814B40C5758C2B2E8852407F83F6EAE3814B40C5758C2B2E885240B189CC5CE07E4B40B5E0455F41845240B189CC5CE07E4B40
48638	Кольцово	5	53	1075	74.263283999999999	74.292479999999998	55.159604000000002	55.149901999999997	0103000020E61000000100000005000000D86322A5D990524070CD1DFD2F934B40D86322A5D9905240C82764E76D944B40FBAE08FEB7925240C82764E76D944B40FBAE08FEB792524070CD1DFD2F934B40D86322A5D990524070CD1DFD2F934B40
48602	Игнатьево	5	53	1075	74.198443999999995	74.210346999999999	55.059848000000002	55.053170000000001	0103000020E610000001000000050000009885764EB38C52406D904946CE864B409885764EB38C5240925D6919A9874B40F3734353768D5240925D6919A9874B40F3734353768D52406D904946CE864B409885764EB38C52406D904946CE864B40
48271	Зотино	5	53	1075	74.225680999999994	74.249262000000002	55.075901000000002	55.066240999999998	0103000020E610000001000000050000000795B88E718E5240C153C8957A884B400795B88E718E5240EA5DBC1FB7894B40AD889AE8F38F5240EA5DBC1FB7894B40AD889AE8F38F5240C153C8957A884B400795B88E718E5240C153C8957A884B40
47787	Ефимовка	5	53	1075	74.349576999999996	74.367829999999998	54.767783000000001	54.757055999999999	0103000020E61000000100000005000000C39B35785F965240CB9E0436E7604B40C39B35785F9652405FB69DB646624B40361FD7868A9752405FB69DB646624B40361FD7868A975240CB9E0436E7604B40C39B35785F965240CB9E0436E7604B40
48268	Георгиевка	5	53	1075	74.289839000000001	74.311407000000003	55.084584999999997	55.068472999999997	0103000020E61000000100000005000000BE86E0B88C9252405AD427B9C3884B40BE86E0B88C925240B75D68AED38A4B40B62FA017EE935240B75D68AED38A4B40B62FA017EE9352405AD427B9C3884B40BE86E0B88C9252405AD427B9C3884B40
48971	Веселый Привал (Варлаковка)	5	53	1075	74.371342999999996	74.394177999999997	54.888852999999997	54.873491000000001	0103000020E610000001000000050000004E266E15C4975240D82C978DCE6F4B404E266E15C4975240CAF962EFC5714B405FB35C363A995240CAF962EFC5714B405FB35C363A995240D82C978DCE6F4B404E266E15C4975240D82C978DCE6F4B40
48193	Борки	5	53	1075	74.024162000000004	74.039613000000003	55.035111000000001	55.018999999999998	0103000020E6100000010000000500000095F3C5DE8B815240DF4F8D976E824B4095F3C5DE8B8152406C5D6A847E844B40C6DFF604898252406C5D6A847E844B40C6DFF60489825240DF4F8D976E824B4095F3C5DE8B815240DF4F8D976E824B40
15317	Байкал	5	53	1075	73.965601000000007	73.970847000000006	55.098547000000003	55.089644999999997	0103000020E6100000010000000500000009FF2268CC7D5240FD9FC37C798B4B4009FF2268CC7D5240390F27309D8C4B40DD9A745B227E5240390F27309D8C4B40DD9A745B227E5240FD9FC37C798B4B4009FF2268CC7D5240FD9FC37C798B4B40
61158	а. Артакшил	5	53	1250	72.748194999999996	74.187494000000001	56.797896000000001	56.046695	0103000020E61000000100000005000000F701486DE22F524080F10C1AFA054C40F701486DE22F5240FBCDC47421664C408F8CD5E6FF8B5240FBCDC47421664C408F8CD5E6FF8B524080F10C1AFA054C40F701486DE22F524080F10C1AFA054C40
13849	Тоскино	5	53	1250	73.724466000000007	73.740347999999997	56.625658000000001	56.616287999999997	0103000020E610000001000000050000001844A4A65D6E524068757286E24E4C401844A4A65D6E52408A3DB48F15504C402DEA93DC616F52408A3DB48F15504C402DEA93DC616F524068757286E24E4C401844A4A65D6E524068757286E24E4C40
13801	Таскатлы	5	53	1250	73.139949999999999	73.167304000000001	56.244425	56.232033000000001	0103000020E61000000100000005000000D044D8F0F4485240E04BE141B31D4C40D044D8F0F448524093A98251491F4C405C1FD61BB54A524093A98251491F4C405C1FD61BB54A5240E04BE141B31D4C40D044D8F0F4485240E04BE141B31D4C40
13720	Талбакуль	5	53	1250	73.247910000000005	73.277400999999998	56.354900999999998	56.346836000000003	0103000020E610000001000000050000007D96E7C1DD4F5240A9893E1F652C4C407D96E7C1DD4F5240AA285E656D2D4C402CB81FF0C0515240AA285E656D2D4C402CB81FF0C0515240A9893E1F652C4C407D96E7C1DD4F5240A9893E1F652C4C40
53080	Строкино	5	53	1250	73.394154999999998	73.441928000000004	56.378374999999998	56.357779000000001	0103000020E6100000010000000500000083A3E4D5395952400919C8B3CB2D4C4083A3E4D539595240DF4F8D976E304C40F3CB608C485C5240DF4F8D976E304C40F3CB608C485C52400919C8B3CB2D4C4083A3E4D5395952400919C8B3CB2D4C40
53011	Сафоново	5	53	1250	73.721177999999995	73.737914000000004	56.198554999999999	56.187891999999998	0103000020E610000001000000050000000F26C5C7276E52400B9755D80C184C400F26C5C7276E524088BA0F406A194C40AD50A4FB396F524088BA0F406A194C40AD50A4FB396F52400B9755D80C184C400F26C5C7276E52400B9755D80C184C40
52982	Плотниково	5	53	1250	74.028114000000002	74.046081000000001	56.360182999999999	56.351894000000001	0103000020E61000000100000005000000D3A3A99ECC8152404ED4D2DC0A2D4C40D3A3A99ECC8152409FC9FE791A2E4C40E3FDB8FDF28252409FC9FE791A2E4C40E3FDB8FDF28252404ED4D2DC0A2D4C40D3A3A99ECC8152404ED4D2DC0A2D4C40
52589	Плахино	5	53	1250	73.346670000000003	73.374527	56.33032	56.317967000000003	0103000020E6100000010000000500000047205ED72F565240871A8524B3284C4047205ED72F5652407C9BFEEC472A4C40041E1840F85752407C9BFEEC472A4C40041E1840F8575240871A8524B3284C4047205ED72F565240871A8524B3284C40
53107	Новотроицк	5	53	1250	73.314969000000005	73.335936000000004	56.41666	56.408766999999997	0103000020E610000001000000050000003F90BC73285452408E57207A52344C403F90BC732854524093C6681D55354C402463B5F97F55524093C6681D55354C402463B5F97F5552408E57207A52344C403F90BC73285452408E57207A52344C40
13441	Новологиново	5	53	1250	73.759508999999994	73.800507999999994	56.5	56.488079999999997	0103000020E610000001000000050000002101A3CB9B70524074EACA67793E4C402101A3CB9B7052400000000000404C40ED0BE8853B7352400000000000404C40ED0BE8853B73524074EACA67793E4C402101A3CB9B70524074EACA67793E4C40
52998	Николаевка	5	53	1250	73.062640999999999	73.095141999999996	56.223255999999999	56.215367999999998	0103000020E61000000100000005000000E198654F024452406E4DBA2D911B4C40E198654F02445240615111A7931C4C40779E78CE16465240615111A7931C4C40779E78CE164652406E4DBA2D911B4C40E198654F024452406E4DBA2D911B4C40
45841	Мясники	5	53	1250	74.070317000000003	74.089208999999997	56.264597000000002	56.253807000000002	0103000020E6100000010000000500000095D6DF1280845240793F6EBF7C204C4095D6DF128084524053CF8250DE214C409160AA99B585524053CF8250DE214C409160AA99B5855240793F6EBF7C204C4095D6DF1280845240793F6EBF7C204C40
13241	Меркутлы	5	53	1250	72.961706000000007	72.981065000000001	56.095920999999997	56.082315999999999	0103000020E610000001000000050000007D9752978C3D524001F8A754890A4C407D9752978C3D5240F3FFAA23470C4C400490DAC4C93E5240F3FFAA23470C4C400490DAC4C93E524001F8A754890A4C407D9752978C3D524001F8A754890A4C40
13153	Ламаново	5	53	1250	73.813057999999998	73.836844999999997	56.298096999999999	56.285124000000003	0103000020E6100000010000000500000013F06B240974524001A777F17E244C4013F06B24097452409204E10A28264C408DB454DE8E7552409204E10A28264C408DB454DE8E75524001A777F17E244C4013F06B240974524001A777F17E244C40
13097	Кутырлы	5	53	1250	72.936940000000007	72.986311000000001	56.216174000000002	56.188623	0103000020E610000001000000050000001D9430D3F63B5240FF2268CC24184C401D9430D3F63B52406D1FF296AB1B4C40D82B2CB81F3F52406D1FF296AB1B4C40D82B2CB81F3F5240FF2268CC24184C401D9430D3F63B5240FF2268CC24184C40
13038	Крайчиково	5	53	1250	73.310989000000006	73.340220000000002	56.277132999999999	56.257252999999999	0103000020E610000001000000050000009C1A683EE753524021E692AAED204C409C1A683EE753524039D2191879234C407D5C1B2AC655524039D2191879234C407D5C1B2AC655524021E692AAED204C409C1A683EE753524021E692AAED204C40
13012	Корсино	5	53	1250	73.951794000000007	73.971717999999996	56.579127	56.563502	0103000020E61000000100000005000000DCA16131EA7C5240849D62D520484C40DCA16131EA7C5240849D62D5204A4C40CFBBB1A0307E5240849D62D5204A4C40CFBBB1A0307E5240849D62D520484C40DCA16131EA7C5240849D62D520484C40
52987	Колосовка	5	53	1250	73.576406000000006	73.649304000000001	56.477159	56.447538000000002	0103000020E61000000100000005000000F7CDFDD5E3645240CFDBD8EC48394C40F7CDFDD5E3645240FCFECD8B133D4C405E4A5D328E695240FCFECD8B133D4C405E4A5D328E695240CFDBD8EC48394C40F7CDFDD5E3645240CFDBD8EC48394C40
12858	Коготово	5	53	1250	73.560918999999998	73.574518999999995	56.532991000000003	56.526969000000001	0103000020E610000001000000050000001F2DCE18E6635240BF805EB873434C401F2DCE18E6635240FB07910C39444C408FFB56EBC4645240FB07910C39444C408FFB56EBC4645240BF805EB873434C401F2DCE18E6635240BF805EB873434C40
52561	Кабурлы	5	53	1250	73.936521999999997	73.952754999999996	56.216023999999997	56.201053999999999	0103000020E61000000100000005000000027FF8F9EF7B5240705D3123BC194C40027FF8F9EF7B52405793A7ACA61B4C406E861BF0F97C52405793A7ACA61B4C406E861BF0F97C5240705D3123BC194C40027FF8F9EF7B5240705D3123BC194C40
60844	Зелёная (Ильинка)	5	53	1250	73.133140999999995	73.146794999999997	56.359538999999998	56.350298000000002	0103000020E610000001000000050000006E30D4618548524057ED9A90D62C4C406E30D461854852407A51BB5F052E4C40D80DDB16654952407A51BB5F052E4C40D80DDB166549524057ED9A90D62C4C406E30D4618548524057ED9A90D62C4C40
53108	Дубрава (Николаевка)	5	53	1250	73.441416000000004	73.45984	56.465639000000003	56.459378000000001	0103000020E6100000010000000500000098FBE428405C52403E40F7E5CC3A4C4098FBE428405C5240FF5E0A0F9A3B4C402159C0046E5D5240FF5E0A0F9A3B4C402159C0046E5D52403E40F7E5CC3A4C4098FBE428405C52403E40F7E5CC3A4C40
53097	Владимировка	5	53	1250	73.629496000000003	73.658449000000005	56.147444999999998	56.136045000000003	0103000020E610000001000000050000009F3D97A94968524065E42CEC69114C409F3D97A949685240B77A4E7ADF124C405F454607246A5240B77A4E7ADF124C405F454607246A524065E42CEC69114C409F3D97A94968524065E42CEC69114C40
52548	Бражниково	5	53	1250	73.831303000000005	73.853167999999997	56.521835000000003	56.506379000000003	0103000020E6100000010000000500000045847F1134755240CB30EE06D1404C4045847F11347552403F74417DCB424C40997FF44D9A7652403F74417DCB424C40997FF44D9A765240CB30EE06D1404C4045847F1134755240CB30EE06D1404C40
52976	Аникино	5	53	1250	73.889189999999999	73.912169000000006	56.538009000000002	56.523904999999999	0103000020E61000000100000005000000897B2C7DE8785240FE9AAC510F434C40897B2C7DE878524012FA997ADD444C4034DB15FA607A524012FA997ADD444C4034DB15FA607A5240FE9AAC510F434C40897B2C7DE8785240FE9AAC510F434C40
60833	Александровка	5	53	1250	73.272461000000007	73.286313000000007	56.224322000000001	56.207667999999998	0103000020E61000000100000005000000DF1B4300705152407E3672DD941A4C40DF1B430070515240FCE25295B61C4C40DCDAC2F352525240FCE25295B61C4C40DCDAC2F3525252407E3672DD941A4C40DF1B4300705152407E3672DD941A4C40
46912	Царицыно	5	53	495	74.476149000000007	74.498930000000001	54.836258999999998	54.818688000000002	0103000020E610000001000000050000007BC1A739799E524057D0B4C4CA684B407BC1A739799E52402AFEEF880A6B4B40923F1878EE9F52402AFEEF880A6B4B40923F1878EE9F524057D0B4C4CA684B407BC1A739799E524057D0B4C4CA684B40
46831	Тургеневка	5	53	495	74.616313000000005	74.649559999999994	55.080030000000001	55.066885999999997	0103000020E6100000010000000500000061C614AC71A75240B6476FB88F884B4061C614AC71A7524075594C6C3E8A4B408B321B6492A9524075594C6C3E8A4B408B321B6492A95240B6476FB88F884B4061C614AC71A75240B6476FB88F884B40
46484	Таволжанка	5	53	495	74.771424999999994	74.785511	55.098455000000001	55.091906999999999	0103000020E610000001000000050000004694F6065FB1524001A3CB9BC38B4B404694F6065FB152405890662C9A8C4B407DE9EDCF45B252405890662C9A8C4B407DE9EDCF45B2524001A3CB9BC38B4B404694F6065FB1524001A3CB9BC38B4B40
47052	Стеклянка	5	53	495	74.869719000000003	74.881953999999993	54.576813999999999	54.570034999999997	0103000020E610000001000000050000006E6DE179A9B75240A54929E8F6484B406E6DE179A9B75240FEEF880AD5494B40E3A430EF71B85240FEEF880AD5494B40E3A430EF71B85240A54929E8F6484B406E6DE179A9B75240A54929E8F6484B40
10544	Старый Ревель	5	53	495	74.992976999999996	75.017805999999993	55.197944	55.189973999999999	0103000020E61000000100000005000000882B67EF8CBF52408F8B6A1151984B40882B67EF8CBF52403F389F3A56994B400BEBC6BB23C152403F389F3A56994B400BEBC6BB23C152408F8B6A1151984B40882B67EF8CBF52408F8B6A1151984B40
9955	Стародубка	5	53	495	74.508273000000003	74.550888999999998	55.081256000000003	55.075850000000003	0103000020E61000000100000005000000261C7A8B87A0524068B3EA73B5894B40261C7A8B87A05240494DBB98668A4B4079AEEFC341A35240494DBB98668A4B4079AEEFC341A3524068B3EA73B5894B40261C7A8B87A0524068B3EA73B5894B40
46405	Сорочино	5	53	495	74.787254000000004	74.832528999999994	55.120640000000002	55.101869999999998	0103000020E610000001000000050000004BE9995E62B25240C5387F130A8D4B404BE9995E62B25240734BAB21718F4B402EFEB62748B55240734BAB21718F4B402EFEB62748B55240C5387F130A8D4B404BE9995E62B25240C5387F130A8D4B40
46993	Семеновка	5	53	495	74.513321000000005	74.536776000000003	54.628804000000002	54.619661000000001	0103000020E6100000010000000500000067D65240DAA05240A7CD380D514F4B4067D65240DAA0524008CC43A67C504B40C651B9895AA2524008CC43A67C504B40C651B9895AA25240A7CD380D514F4B4067D65240DAA05240A7CD380D514F4B40
11505	Розенталь	5	53	495	74.585545999999994	74.602686000000006	54.616016999999999	54.606282999999998	0103000020E610000001000000050000006E13EE9579A55240758F6CAE9A4D4B406E13EE9579A55240D86322A5D94E4B4074F04C6892A65240D86322A5D94E4B4074F04C6892A65240758F6CAE9A4D4B406E13EE9579A55240758F6CAE9A4D4B40
47046	Репинка	5	53	495	74.737487000000002	74.765991	54.608139000000001	54.598987000000001	0103000020E61000000100000005000000698EACFC32AF524055DD239BAB4C4B40698EACFC32AF52400936AE7FD74D4B40F1811DFF05B152400936AE7FD74D4B40F1811DFF05B1524055DD239BAB4C4B40698EACFC32AF524055DD239BAB4C4B40
46864	Осокино	5	53	495	74.596316999999999	74.632437999999993	54.902681999999999	54.881608	0103000020E610000001000000050000002043C70E2AA652402CF2EB87D8704B402043C70E2AA652400C5872158B734B40D9AF3BDD79A852400C5872158B734B40D9AF3BDD79A852402CF2EB87D8704B402043C70E2AA652402CF2EB87D8704B40
53025	Орловка	5	53	495	75.127706000000003	75.145061999999996	55.203760000000003	55.185903000000003	0103000020E610000001000000050000003160C9552CC85240399D64ABCB974B403160C9552CC85240D21DC4CE149A4B401C7920B248C95240D21DC4CE149A4B401C7920B248C95240399D64ABCB974B403160C9552CC85240399D64ABCB974B40
46496	Новый Свет	5	53	495	74.844198000000006	74.869432000000003	55.129190000000001	55.111243000000002	0103000020E6100000010000000500000050560C5707B652405874EB353D8E4B4050560C5707B65240317C444C89904B4023861DC6A4B75240317C444C89904B4023861DC6A4B752405874EB353D8E4B4050560C5707B652405874EB353D8E4B40
10618	Новый Ревель	5	53	495	75.163235	75.187866	55.148122000000001	55.136957000000002	0103000020E6100000010000000500000001A4367172CA5240A9FA95CE87914B4001A4367172CA5240B8E864A9F5924B40F1811DFF05CC5240B8E864A9F5924B40F1811DFF05CC5240A9FA95CE87914B4001A4367172CA5240A9FA95CE87914B40
60855	Новое Село	5	53	495	74.584513000000001	74.605874999999997	54.975392999999997	54.963464999999999	0103000020E610000001000000050000008FC536A968A552409AEB34D2527B4B408FC536A968A55240A8DF85ADD97C4B40B29DEFA7C6A65240A8DF85ADD97C4B40B29DEFA7C6A652409AEB34D2527B4B408FC536A968A552409AEB34D2527B4B40
46723	Львовка	5	53	495	75.050747999999999	75.099553	55.047868000000001	55.033310999999998	0103000020E6100000010000000500000098158A743FC352406CCCEB8843844B4098158A743FC352403143E38920864B40FFCD8B135FC652403143E38920864B40FFCD8B135FC652406CCCEB8843844B4098158A743FC352406CCCEB8843844B40
10981	Лагушино	5	53	495	74.808606999999995	74.840649999999997	54.950087000000003	54.931102000000003	0103000020E6100000010000000500000044149337C0B35240BF9EAF592E774B4044149337C0B3524069AD68739C794B407958A835CDB5524069AD68739C794B407958A835CDB55240BF9EAF592E774B4044149337C0B35240BF9EAF592E774B40
46333	Куликово (Восресенского)	5	53	495	74.447941999999998	74.471496000000002	55.066870000000002	55.057378	0103000020E610000001000000050000004F20EC14AB9C524044C18C2958874B404F20EC14AB9C5240B18A37328F884B40780C8FFD2C9E5240B18A37328F884B40780C8FFD2C9E524044C18C2958874B404F20EC14AB9C524044C18C2958874B40
10450	Крутые Луки	5	53	495	74.887181999999996	74.899651000000006	55.152679999999997	55.142328999999997	0103000020E6100000010000000500000064E60297C7B85240DD2230D637924B4064E60297C7B852406B60AB048B934B4014B4C9E193B952406B60AB048B934B4014B4C9E193B95240DD2230D637924B4064E60297C7B85240DD2230D637924B40
46661	Ковалево	5	53	495	75.267258999999996	75.291352000000003	55.100175	55.088470000000001	0103000020E61000000100000005000000F2237EC51AD15240AC5626FC528B4B40F2237EC51AD152403B70CE88D28C4B40F3E7DB82A5D252403B70CE88D28C4B40F3E7DB82A5D25240AC5626FC528B4B40F2237EC51AD15240AC5626FC528B4B40
53051	Кибер-Спасское	5	53	495	74.503035999999994	74.529095999999996	55.207962999999999	55.195323000000002	0103000020E610000001000000050000007B2DE8BD31A052400C94145800994B407B2DE8BD31A0524097E315889E9A4B40711C78B5DCA1524097E315889E9A4B40711C78B5DCA152400C94145800994B407B2DE8BD31A052400C94145800994B40
6671	Калачинск	5	53	495	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
52970	Кабанье	5	53	495	75.194208000000003	75.217761999999993	55.007762	54.99165	0103000020E61000000100000005000000C82764E76DCC5240098A1F63EE7E4B40C82764E76DCC524066136058FE804B40F01307D0EFCD524066136058FE804B40F01307D0EFCD5240098A1F63EE7E4B40C82764E76DCC5240098A1F63EE7E4B40
46895	Индейка (Березовский)	5	53	495	74.407069000000007	74.424649000000002	54.963734000000002	54.949285000000003	0103000020E61000000100000005000000CA8D226B0D9A5240ACCABE2B82794B40CA8D226B0D9A52408A05BEA25B7B4B40DDD1FF722D9B52408A05BEA25B7B4B40DDD1FF722D9B5240ACCABE2B82794B40CA8D226B0D9A5240ACCABE2B82794B40
60816	Илюшкино	5	53	495	75.041359999999997	75.048582999999994	55.110058000000002	55.106824000000003	0103000020E6100000010000000500000034D769A4A5C25240C636A968AC8D4B4034D769A4A5C25240E3546B61168E4B400F09DFFB1BC35240E3546B61168E4B400F09DFFB1BC35240C636A968AC8D4B4034D769A4A5C25240C636A968AC8D4B40
46448	Измайловка	5	53	495	74.849534000000006	74.861697000000007	55.254748999999997	55.249699	0103000020E61000000100000005000000C4B5DAC35EB65240056C0723F69F4B40C4B5DAC35EB6524027D87F9D9BA04B40ED832C0B26B7524027D87F9D9BA04B40ED832C0B26B75240056C0723F69F4B40C4B5DAC35EB65240056C0723F69F4B40
46610	Ивановка	5	53	495	75.198043999999996	75.235037000000005	55.140954999999998	55.121071999999998	0103000020E61000000100000005000000D1CABDC0ACCC52400C3B8C497F8F4B40D1CABDC0ACCC5240959A3DD00A924B406616A1D80ACF5240959A3DD00A924B406616A1D80ACF52400C3B8C497F8F4B40D1CABDC0ACCC52400C3B8C497F8F4B40
10236	Докучаевка	5	53	495	74.886894999999996	74.900154000000001	55.183461999999999	55.170408000000002	0103000020E6100000010000000500000019FF3EE3C2B85240077DE9EDCF954B4019FF3EE3C2B852408507CDAE7B974B4045D7851F9CB952408507CDAE7B974B4045D7851F9CB95240077DE9EDCF954B4019FF3EE3C2B85240077DE9EDCF954B40
46466	Глуховка	5	53	495	74.699982000000006	74.729096999999996	55.092700000000001	55.079973000000003	0103000020E610000001000000050000007A724D81CCAC524011C8258E3C8A4B407A724D81CCAC52406B2BF697DD8B4B4026A77686A9AE52406B2BF697DD8B4B4026A77686A9AE524011C8258E3C8A4B407A724D81CCAC524011C8258E3C8A4B40
47014	Воскресенка	5	53	495	74.603448999999998	74.645094999999998	55.090856000000002	55.067525000000003	0103000020E6100000010000000500000073F38DE89EA65240CA54C1A8A4884B4073F38DE89EA652409C525E2BA18B4B400AF4893C49A952409C525E2BA18B4B400AF4893C49A95240CA54C1A8A4884B4073F38DE89EA65240CA54C1A8A4884B40
11438	Великорусское	5	53	495	74.614588999999995	74.642544000000001	54.661630000000002	54.64179	0103000020E61000000100000005000000CEDE196D55A752402E73BA2C26524B40CEDE196D55A75240B806B64AB0544B406D8FDE701FA95240B806B64AB0544B406D8FDE701FA952402E73BA2C26524B40CEDE196D55A752402E73BA2C26524B40
11126	Архангелка	5	53	495	74.495598000000001	74.518163000000001	55.071005	55.064405999999998	0103000020E61000000100000005000000A27DACE0B79F524045D5AF743E884B40A27DACE0B79F52401E6D1CB116894B40D3BF249529A152401E6D1CB116894B40D3BF249529A1524045D5AF743E884B40A27DACE0B79F524045D5AF743E884B40
53029	Южный	5	53	335	71.382548999999997	71.397577999999996	54.883623	54.878692000000001	0103000020E610000001000000050000008507CDAE7BD85140E0A0BDFA78704B408507CDAE7BD85140287FF78E1A714B40FBE6FEEA71D95140287FF78E1A714B40FBE6FEEA71D95140E0A0BDFA78704B408507CDAE7BD85140E0A0BDFA78704B40
53047	Хутор №12	5	53	335	71.290156999999994	71.303111000000001	55.062947000000001	55.051499	0103000020E61000000100000005000000266DAAEE91D251406B63EC8497864B40266DAAEE91D25140CF30B5A50E884B40B403AE2B66D35140CF30B5A50E884B40B403AE2B66D351406B63EC8497864B40266DAAEE91D251406B63EC8497864B40
53017	Улендыкуль	5	53	335	71.442188000000002	71.474545000000006	54.801358	54.789819999999999	0103000020E61000000100000005000000C1ABE5CE4CDC514005DD5ED218654B40C1ABE5CE4CDC5140A93121E692664B40BEDEFDF15EDE5140A93121E692664B40BEDEFDF15EDE514005DD5ED218654B40C1ABE5CE4CDC514005DD5ED218654B40
52988	Украинка	5	53	335	71.314142000000004	71.347829000000004	54.666545999999997	54.644984000000001	0103000020E6100000010000000500000034130CE71AD45140BD38F1D58E524B4034130CE71AD45140CAA31B6151554B406DE690D442D65140CAA31B6151554B406DE690D442D65140BD38F1D58E524B4034130CE71AD45140BD38F1D58E524B40
46316	Сосновка	5	53	335	71.167438000000004	71.174059	55.122852999999999	55.116269000000003	0103000020E61000000100000005000000E486DF4DB7CA5140F24410E7E18E4B40E486DF4DB7CA5140959BA8A5B98F4B40C4245CC823CB5140959BA8A5B98F4B40C4245CC823CB5140F24410E7E18E4B40E486DF4DB7CA5140F24410E7E18E4B40
52991	Солнцевка	5	53	335	71.268570999999994	71.312686999999997	54.994171000000001	54.976002999999999	0103000020E61000000100000005000000DB696B4430D1514021E692AAED7C4B40DB696B4430D15140D9D0CDFE407F4B4099B8551003D45140D9D0CDFE407F4B4099B8551003D4514021E692AAED7C4B40DB696B4430D1514021E692AAED7C4B40
52972	Северный	5	53	335	71.445430999999999	71.458905999999999	55.103378999999997	55.091237	0103000020E61000000100000005000000F96706F181DC5140B3976DA7AD8B4B40F96706F181DC5140ED0BE8853B8D4B400B7C45B75EDD5140ED0BE8853B8D4B400B7C45B75EDD5140B3976DA7AD8B4B40F96706F181DC5140B3976DA7AD8B4B40
53001	Рославка	5	53	335	71.020257999999998	71.039276000000001	54.949311000000002	54.941125	0103000020E61000000100000005000000DFDE35E84BC151405839B4C876784B40DFDE35E84BC15140D55DD90583794B4022E17B7F83C25140D55DD90583794B4022E17B7F83C251405839B4C876784B40DFDE35E84BC151405839B4C876784B40
52977	Пучково	5	53	335	71.502922999999996	71.520287999999994	54.939320000000002	54.928229999999999	0103000020E61000000100000005000000FF59F3E32FE0514042959A3DD0764B40FF59F3E32FE05140473D44A33B784B4014200A664CE15140473D44A33B784B4014200A664CE1514042959A3DD0764B40FF59F3E32FE0514042959A3DD0764B40
53024	Первотаровка	5	53	335	71.042483000000004	71.067976999999999	55.078451999999999	55.066220999999999	0103000020E61000000100000005000000B4E89D0AB8C251407AA702EE79884B40B4E89D0AB8C25140242713B70A8A4B4055F833BC59C45140242713B70A8A4B4055F833BC59C451407AA702EE79884B40B4E89D0AB8C251407AA702EE79884B40
53084	Ночка	5	53	335	71.308878000000007	71.336331000000001	54.717683000000001	54.703291	0103000020E610000001000000050000000D1D3BA8C4D351401B498270055A4B400D1D3BA8C4D3514095F25A09DD5B4B406268757286D5514095F25A09DD5B4B406268757286D551401B498270055A4B400D1D3BA8C4D351401B498270055A4B40
9260	Новорождественка	5	53	335	71.451224999999994	71.479387000000003	55.100731000000003	55.089773999999998	0103000020E61000000100000005000000CE88D2DEE0DC5140FB03E5B67D8B4B40CE88D2DEE0DC5140C158DFC0E48C4B402AC8CF46AEDE5140C158DFC0E48C4B402AC8CF46AEDE5140FB03E5B67D8B4B40CE88D2DEE0DC5140FB03E5B67D8B4B40
53090	Новопетроград	5	53	335	71.460424000000003	71.479881000000006	54.759732	54.753315999999998	0103000020E61000000100000005000000C992399677DD5140DAC69FA86C604B40C992399677DD5140C2DCEEE53E614B40323ECC5EB6DE5140C2DCEEE53E614B40323ECC5EB6DE5140DAC69FA86C604B40C992399677DD5140DAC69FA86C604B40
52969	Новолосево	5	53	335	71.192572999999996	71.218220000000002	55.148147999999999	55.132587000000001	0103000020E61000000100000005000000ED45B41D53CC5140F86F5E9CF8904B40ED45B41D53CC5140E17B7F83F6924B4052D50451F7CD5140E17B7F83F6924B4052D50451F7CD5140F86F5E9CF8904B40ED45B41D53CC5140F86F5E9CF8904B40
51914	Новодонка	5	53	335	71.391604000000001	71.412336999999994	54.659968999999997	54.644786000000003	0103000020E61000000100000005000000E63E390A10D951409775FF5888524B40E63E390A10D95140D9AF3BDD79544B40917BBABA63DA5140D9AF3BDD79544B40917BBABA63DA51409775FF5888524B40E63E390A10D951409775FF5888524B40
53006	Николайполь	5	53	335	71.509292000000002	71.529557999999994	54.871538000000001	54.863829000000003	0103000020E610000001000000050000005307793D98E051400F2BDCF2916E4B405307793D98E05140529CA38E8E6F4B4073D53C47E4E15140529CA38E8E6F4B4073D53C47E4E151400F2BDCF2916E4B405307793D98E051400F2BDCF2916E4B40
8999	Мясники	5	53	335	71.409336999999994	71.424509	54.591448999999997	54.578119000000001	0103000020E61000000100000005000000BC02D19332DA51401E19ABCDFF494B40BC02D19332DA51403E20D099B44B4B40E4F6CB272BDB51403E20D099B44B4B40E4F6CB272BDB51401E19ABCDFF494B40BC02D19332DA51401E19ABCDFF494B40
9044	Медвежье	5	53	335	71.273143000000005	71.307513	55.196494999999999	55.179879	0103000020E610000001000000050000006808C72C7BD151405C1E6B4606974B406808C72C7BD15140EC6987BF26994B401286014BAED35140EC6987BF26994B401286014BAED351405C1E6B4606974B406808C72C7BD151405C1E6B4606974B40
53020	Маргенау	5	53	335	71.554063999999997	71.579926999999998	54.923594999999999	54.913029000000002	0103000020E6100000010000000500000005F9D9C875E3514059A65F22DE744B4005F9D9C875E35140E3DF675C38764B4050C422861DE55140E3DF675C38764B4050C422861DE5514059A65F22DE744B4005F9D9C875E3514059A65F22DE744B40
51910	Лукерьино	5	53	335	71.363577000000006	71.384641999999999	55.225281000000003	55.210839	0103000020E61000000100000005000000FB2477D844D7514055DCB8C5FC9A4B40FB2477D844D7514081B4FF01D69C4B40C1AA7AF99DD8514081B4FF01D69C4B40C1AA7AF99DD8514055DCB8C5FC9A4B40FB2477D844D7514055DCB8C5FC9A4B40
8749	Лесной	5	53	335	71.135503	71.159954999999997	54.974353999999998	54.961641	0103000020E61000000100000005000000A260C614ACC8514012BF620D177B4B40A260C614ACC85140075DC2A1B77C4B403A75E5B33CCA5140075DC2A1B77C4B403A75E5B33CCA514012BF620D177B4B40A260C614ACC8514012BF620D177B4B40
8357	Ленинский	5	53	335	71.340113000000002	71.354089999999999	54.845218000000003	54.837032000000001	0103000020E6100000010000000500000072FC5069C4D551404DDA54DD236B4B4072FC5069C4D55140CAFE791A306C4B40CD751A69A9D65140CAFE791A306C4B40CD751A69A9D651404DDA54DD236B4B4072FC5069C4D551404DDA54DD236B4B40
53049	Культжугут	5	53	335	71.215489000000005	71.225280999999995	55.239711999999997	55.226923999999997	0103000020E6100000010000000500000075E95F92CACD5140B8567BD80B9D4B4075E95F92CACD5140B83A00E2AE9E4B4040DAFF006BCE5140B83A00E2AE9E4B4040DAFF006BCE5140B8567BD80B9D4B4075E95F92CACD5140B8567BD80B9D4B40
52997	Кудряевка	5	53	335	71.219656999999998	71.236519000000001	54.751632000000001	54.743577999999999	0103000020E6100000010000000500000099D53BDC0ECE514036035C902D5F4B4099D53BDC0ECE51404450357A35604B407D78962023CF51404450357A35604B407D78962023CF514036035C902D5F4B4099D53BDC0ECE514036035C902D5F4B40
52396	Ксеньевка	5	53	335	71.633358999999999	71.65446	54.723917999999998	54.710636000000001	0103000020E6100000010000000500000025E82FF488E851401DAED51EF65A4B4025E82FF488E851402C7E5358A95C4B40922232ACE2E951402C7E5358A95C4B40922232ACE2E951401DAED51EF65A4B4025E82FF488E851401DAED51EF65A4B40
8544	Кромы	5	53	335	71.063315000000003	71.096183999999994	54.772027000000001	54.765399000000002	0103000020E6100000010000000500000029965B5A0DC4514010B22C98F8614B4029965B5A0DC451408350DEC7D1624B408099EFE027C651408350DEC7D1624B408099EFE027C6514010B22C98F8614B4029965B5A0DC4514010B22C98F8614B40
53012	Красновознесенка	5	53	335	71.585612999999995	71.606848999999997	54.788102000000002	54.779919999999997	0103000020E6100000010000000500000032C7F2AE7AE5514087BF266BD4634B4032C7F2AE7AE55140C3F4BD86E0644B400F27309DD6E65140C3F4BD86E0644B400F27309DD6E6514087BF266BD4634B4032C7F2AE7AE5514087BF266BD4634B40
8917	Комсомольский	5	53	335	71.127975000000006	71.151923999999994	54.879095999999997	54.872419000000001	0103000020E6100000010000000500000029ED0DBE30C851405BB4006DAB6F4B4029ED0DBE30C85140AF05BD3786704B408FDE701FB9C95140AF05BD3786704B408FDE701FB9C951405BB4006DAB6F4B4029ED0DBE30C851405BB4006DAB6F4B40
53038	Каскат	5	53	335	71.122665999999995	71.139671000000007	54.801909000000002	54.795203000000001	0103000020E6100000010000000500000031957EC2D9C751402E573F36C9654B4031957EC2D9C751401DAF40F4A4664B40C74CA25EF0C851401DAF40F4A4664B40C74CA25EF0C851402E573F36C9654B4031957EC2D9C751402E573F36C9654B40
52974	Исилькуль	5	53	335	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
9463	Емонтаево	5	53	335	70.940937000000005	70.959109999999995	55.150947000000002	55.143059999999998	0103000020E610000001000000050000002BA6D24F38BC5140D1AE42CA4F924B402BA6D24F38BC5140F436363B52934B400FD1E80E62BD5140F436363B52934B400FD1E80E62BD5140D1AE42CA4F924B402BA6D24F38BC5140D1AE42CA4F924B40
52978	Евсюки	5	53	335	71.461601000000002	71.472397999999998	55.175015000000002	55.164011000000002	0103000020E6100000010000000500000042B3EBDE8ADD51409697FC4FFE944B4042B3EBDE8ADD51409CA73AE466964B40882CD2C43BDE51409CA73AE466964B40882CD2C43BDE51409697FC4FFE944B4042B3EBDE8ADD51409697FC4FFE944B40
53046	Гофнунгсталь	5	53	335	71.487471999999997	71.506704999999997	54.965879000000001	54.958224000000001	0103000020E61000000100000005000000CE6DC2BD32DF5140041F8315A77A4B40CE6DC2BD32DF514054724EECA17B4B400FEECEDA6DE0514054724EECA17B4B400FEECEDA6DE05140041F8315A77A4B40CE6DC2BD32DF5140041F8315A77A4B40
53040	Водяное	5	53	335	71.328327000000002	71.346670000000003	55.010978999999999	55.000745000000002	0103000020E6100000010000000500000034D93F4F03D551405951836918804B4034D93F4F03D55140ADF886C267814B4047205ED72FD65140ADF886C267814B4047205ED72FD651405951836918804B4034D93F4F03D551405951836918804B40
52975	Васютино	5	53	335	71.612517999999994	71.631795999999994	54.824751999999997	54.815922999999998	0103000020E61000000100000005000000868DB27E33E75140F086342A70684B40868DB27E33E75140C1A7397991694B40976F7D586FE85140C1A7397991694B40976F7D586FE85140F086342A70684B40868DB27E33E75140F086342A70684B40
8297	Боровое	5	53	335	71.357504000000006	71.367627999999996	54.773890999999999	54.766215000000003	0103000020E610000001000000050000001C0C7558E1D65140325A475513624B401C0C7558E1D6514099D53BDC0E634B400246973787D7514099D53BDC0E634B400246973787D75140325A475513624B401C0C7558E1D65140325A475513624B40
53083	Боевой	5	53	335	71.437714	71.460065	54.941208000000003	54.926310999999998	0103000020E6100000010000000500000016C0948103DC51406876DD5B91764B4016C0948103DC5140E65DF58079784B40314278B471DD5140E65DF58079784B40314278B471DD51406876DD5B91764B4016C0948103DC51406876DD5B91764B40
46934	Благовещенка	5	53	335	71.029375999999999	71.054781000000006	54.890960999999997	54.880592999999998	0103000020E6100000010000000500000063D2DF4BE1C15140130B7C45B7704B4063D2DF4BE1C15140778192020B724B404DDC2A8881C35140778192020B724B404DDC2A8881C35140130B7C45B7704B4063D2DF4BE1C15140130B7C45B7704B40
7779	Баррикада	5	53	335	71.530331000000004	71.554765000000003	54.790686999999998	54.776519	0103000020E6100000010000000500000085436FF1F0E151407FDC7EF964634B4085436FF1F0E15140A92F4B3B35654B40CAFD0E4581E35140A92F4B3B35654B40CAFD0E4581E351407FDC7EF964634B4085436FF1F0E151407FDC7EF964634B40
53089	Аполлоновка	5	53	335	71.535450999999995	71.559077000000002	55.174737999999998	55.160097999999998	0103000020E61000000100000005000000126745D444E25140D7135D177E944B40126745D444E2514029AF95D05D964B4088BCE5EAC7E3514029AF95D05D964B4088BCE5EAC7E35140D7135D177E944B40126745D444E25140D7135D177E944B40
6814	Шухово	5	53	469	73.464609999999993	73.500793999999999	57.241512999999998	57.231006000000001	0103000020E6100000010000000500000040D9942BBC5D52400397C79A919D4C4040D9942BBC5D52408847E2E5E99E4C401D0247020D6052408847E2E5E99E4C401D0247020D6052400397C79A919D4C4040D9942BBC5D52400397C79A919D4C40
6648	Чередово	5	53	469	73.646133000000006	73.667468	57.024915	57.013396	0103000020E6100000010000000500000073F7393E5A695240D8F2CAF5B6814C4073F7393E5A69524005172B6A30834C4019C8B3CBB76A524005172B6A30834C4019C8B3CBB76A5240D8F2CAF5B6814C4073F7393E5A695240D8F2CAF5B6814C40
6418	Усть-Шиш	5	53	469	73.359533999999996	73.407549000000003	57.333038999999999	57.316532000000002	0103000020E6100000010000000500000034F3E49A025752409911DE1E84A84C4034F3E49A0257524072A59E05A1AA4C401FA16648155A524072A59E05A1AA4C401FA16648155A52409911DE1E84A84C4034F3E49A025752409911DE1E84A84C40
6328	Усть-Тамак	5	53	469	73.717675	73.726864000000006	57.25226	57.242443000000002	0103000020E61000000100000005000000098A1F63EE6D524073124A5F089F4C40098A1F63EE6D5240630B410E4AA04C40F22895F0846E5240630B410E4AA04C40F22895F0846E524073124A5F089F4C40098A1F63EE6D524073124A5F089F4C40
2760	Тузаклы	5	53	469	73.363217000000006	73.380257999999998	57.255498000000003	57.248150000000003	0103000020E610000001000000050000007B1684F23E5752404F401361C39F4C407B1684F23E575240C2189128B4A04C40B682A62556585240C2189128B4A04C40B682A625565852404F401361C39F4C407B1684F23E5752404F401361C39F4C40
6591	Солдатка	5	53	469	73.788983000000002	73.802835000000002	57.158417999999998	57.132249000000002	0103000020E6100000010000000500000066868DB27E725240E0F60489ED904C4066868DB27E725240828C800A47944C4063450DA661735240828C800A47944C4063450DA661735240E0F60489ED904C4066868DB27E725240E0F60489ED904C40
6480	Семёновка	5	53	469	73.738281999999998	73.754954999999995	57.143717000000002	57.135019	0103000020E610000001000000050000006E4E2503406F524058AB764D48914C406E4E2503406F52408B70935165924C40E8BCC62E517052408B70935165924C40E8BCC62E5170524058AB764D48914C406E4E2503406F524058AB764D48914C40
6504	Пушкарёво	5	53	469	73.670271	73.688092999999995	57.142207999999997	57.133924999999998	0103000020E61000000100000005000000431D56B8E56A5240F38E537424914C40431D56B8E56A5240629D2ADF33924C40D1E638B7096C5240629D2ADF33924C40D1E638B7096C5240F38E537424914C40431D56B8E56A5240F38E537424914C40
6365	Новоягодное	5	53	469	73.499824000000004	73.523261000000005	57.361215999999999	57.350864999999999	0103000020E610000001000000050000006170CD1DFD5F5240D027F224E9AC4C406170CD1DFD5F52405E656D533CAE4C406D91B41B7D6152405E656D533CAE4C406D91B41B7D615240D027F224E9AC4C406170CD1DFD5F5240D027F224E9AC4C40
6793	Никольск	5	53	469	73.659608000000006	73.672903000000005	57.067106000000003	57.054763000000001	0103000020E61000000100000005000000850B7904376A5240F303577902874C40850B7904376A5240C5AEEDED96884C405798BED7106B5240C5AEEDED96884C405798BED7106B5240F303577902874C40850B7904376A5240F303577902874C40
6046	Мамешево	5	53	469	74.037734999999998	74.063175999999999	57.106116	57.091746000000001	0103000020E6100000010000000500000088BA0F406A825240F8C43A55BE8B4C4088BA0F406A8252408ACA8635958D4C40187959130B8452408ACA8635958D4C40187959130B845240F8C43A55BE8B4C4088BA0F406A825240F8C43A55BE8B4C40
6929	Малобутаково	5	53	469	73.553004000000001	73.568213	57.219351000000003	57.210465999999997	0103000020E61000000100000005000000A9A3E36A64635240C075C58CF09A4C40A9A3E36A6463524026AC8DB1139C4C405F0A0F9A5D64524026AC8DB1139C4C405F0A0F9A5D645240C075C58CF09A4C40A9A3E36A64635240C075C58CF09A4C40
6749	Котовщиково	5	53	469	73.548970999999995	73.571195000000003	56.937840000000001	56.927914000000001	0103000020E61000000100000005000000F4DC42572263524012C0CDE2C5764C40F4DC425722635240B97020240B784C40E12879758E645240B97020240B784C40E12879758E64524012C0CDE2C5764C40F4DC42572263524012C0CDE2C5764C40
5979	Копейкино	5	53	469	74.108504999999994	74.127287999999993	56.985408	56.974935000000002	0103000020E61000000100000005000000F59CF4BEF1865240E65C8AABCA7C4C40F59CF4BEF1865240BF9B6ED9217E4C40164B917C25885240BF9B6ED9217E4C40164B917C25885240E65C8AABCA7C4C40F59CF4BEF1865240E65C8AABCA7C4C40
6858	Кондрашино	5	53	469	73.655071000000007	73.676747000000006	57.160449	57.147961000000002	0103000020E61000000100000005000000B763EAAEEC695240AF0AD462F0924C40B763EAAEEC69524084D6C39789944C40A22AA6D24F6B524084D6C39789944C40A22AA6D24F6B5240AF0AD462F0924C40B763EAAEEC695240AF0AD462F0924C40
5800	Киселёво	5	53	469	73.889531000000005	73.916921000000002	57.122624999999999	57.115901000000001	0103000020E61000000100000005000000CE716E13EE7852406F490ED8D58E4C40CE716E13EE78524004560E2DB28F4C4000016BD5AE7A524004560E2DB28F4C4000016BD5AE7A52406F490ED8D58E4C40CE716E13EE7852406F490ED8D58E4C40
6274	Качуково	5	53	469	73.832397999999998	73.858880999999997	57.202981999999999	57.191358000000001	0103000020E610000001000000050000005FD0420246755240FBE93F6B7E984C405FD04202467552409DD66D50FB994C40F88903E8F77652409DD66D50FB994C40F88903E8F7765240FBE93F6B7E984C405FD0420246755240FBE93F6B7E984C40
5821	Знаменское	5	53	469	73.796969000000004	73.847328000000005	57.135326999999997	57.114322999999999	0103000020E6100000010000000500000041BB438A017352401E17D522A28E4C4041BB438A0173524005A2276552914C400C3F389F3A76524005A2276552914C400C3F389F3A7652401E17D522A28E4C4041BB438A017352401E17D522A28E4C40
6120	Завьялово	5	53	469	73.419775000000001	73.454262	57.156582999999998	57.141143999999997	0103000020E610000001000000050000006B2BF697DD5A52406803B00111924C406B2BF697DD5A5240060E68E90A944C403274ECA0125D5240060E68E90A944C403274ECA0125D52406803B00111924C406B2BF697DD5A52406803B00111924C40
5901	Бутаково	5	53	469	74.082166000000001	74.092181999999994	57.056083999999998	57.045651999999997	0103000020E61000000100000005000000F6B52E35428552409D7FBBECD7854C40F6B52E354285524018EAB0C22D874C40E9D1544FE685524018EAB0C22D874C40E9D1544FE68552409D7FBBECD7854C40F6B52E35428552409D7FBBECD7854C40
6211	Авяк	5	53	469	73.277608000000001	73.296651999999995	57.140855999999999	57.128194999999998	0103000020E61000000100000005000000E9465854C45152405F419AB168904C40E9465854C451524002B9C49107924C40C092AB58FC52524002B9C49107924C40C092AB58FC5252405F419AB168904C40E9465854C45152405F419AB168904C40
37138	Мясники	5	53	4828	33.366286000000002	33.379365999999997	54.813101000000003	54.803579999999997	0103000020E61000000100000005000000C87DAB75E2AE40401EDC9DB5DB664B40C87DAB75E2AE404026AC8DB113684B406F9BA9108FB0404026AC8DB113684B406F9BA9108FB040401EDC9DB5DB664B40C87DAB75E2AE40401EDC9DB5DB664B40
60842	д. карташово	5	53	345	73.386393999999996	74.631997999999996	55.759495999999999	55.163795	0103000020E61000000100000005000000B857E6ADBA585240C91F0C3CF7944B40B857E6ADBA585240AEB8382A37E14B40CB48BDA772A85240AEB8382A37E14B40CB48BDA772A85240C91F0C3CF7944B40B857E6ADBA585240C91F0C3CF7944B40
5524	Яковлевка	5	53	345	74.433415999999994	74.467444	55.404375999999999	55.395803000000001	0103000020E610000001000000050000000A647616BD9B5240505436ACA9B24B400A647616BD9B5240C6A4BF97C2B34B40882D3D9AEA9D5240C6A4BF97C2B34B40882D3D9AEA9D5240505436ACA9B24B400A647616BD9B5240505436ACA9B24B40
5447	Чучкино	5	53	345	73.627358000000001	73.647964999999999	55.420653000000001	55.416094999999999	0103000020E6100000010000000500000093382BA226685240BA83D89942B54B4093382BA2266852406EFB1EF5D7B54B40F8FC3042786952406EFB1EF5D7B54B40F8FC304278695240BA83D89942B54B4093382BA226685240BA83D89942B54B40
5405	Чулино	5	53	345	74.530219000000002	74.550521000000003	55.302104999999997	55.292771000000002	0103000020E61000000100000005000000F12DAC1BEFA15240CE1B278579A54B40F12DAC1BEFA15240A27A6B60ABA64B40B8B06EBC3BA35240A27A6B60ABA64B40B8B06EBC3BA35240CE1B278579A54B40F12DAC1BEFA15240CE1B278579A54B40
48916	Ударный	5	53	345	74.228590999999994	74.247401999999994	55.191586999999998	55.180675999999998	0103000020E610000001000000050000003C4A253CA18E52400796236420974B403C4A253CA18E52405CAB3DEC85984B40C2BD326FD58F52405CAB3DEC85984B40C2BD326FD58F52400796236420974B403C4A253CA18E52400796236420974B40
1703	Сягаевка	5	53	345	74.165880000000001	74.181186999999994	55.615608999999999	55.606710999999997	0103000020E61000000100000005000000DFC325C79D8A5240CD8FBFB4A8CD4B40DFC325C79D8A5240C70F9546CCCE4B4076DD5B91988B5240C70F9546CCCE4B4076DD5B91988B5240CD8FBFB4A8CD4B40DFC325C79D8A5240CD8FBFB4A8CD4B40
5297	Сухое	5	53	345	73.910156999999998	73.942809999999994	55.432423	55.411532000000001	0103000020E610000001000000050000006E4E2503407A5240F5A0A014ADB44B406E4E2503407A5240E48409A359B74B40DF15C1FF567C5240E48409A359B74B40DF15C1FF567C5240F5A0A014ADB44B406E4E2503407A5240F5A0A014ADB44B40
48879	Спасское	5	53	345	74.137214999999998	74.172545999999997	55.217717	55.207833999999998	0103000020E6100000010000000500000052616C21C8885240997FF44D9A9A4B4052616C21C888524041649126DE9B4B408FC360FE0A8B524041649126DE9B4B408FC360FE0A8B5240997FF44D9A9A4B4052616C21C8885240997FF44D9A9A4B40
48848	Соснино	5	53	345	74.399935999999997	74.420704999999998	55.443322000000002	55.431994000000003	0103000020E610000001000000050000008E1F2A8D98995240BC0853944BB74B408E1F2A8D9899524075CC79C6BEB84B40E010AAD4EC9A524075CC79C6BEB84B40E010AAD4EC9A5240BC0853944BB74B408E1F2A8D98995240BC0853944BB74B40
48843	Согра	5	53	345	74.233388000000005	74.254857999999999	55.717320000000001	55.705879000000003	0103000020E61000000100000005000000D9D138D4EF8E524073F7393E5ADA4B40D9D138D4EF8E524024624A24D1DB4B40EFC7ED974F90524024624A24D1DB4B40EFC7ED974F90524073F7393E5ADA4B40D9D138D4EF8E524073F7393E5ADA4B40
48822	Серебряное	5	53	345	74.317165000000003	74.345614999999995	55.713988000000001	55.701571999999999	0103000020E61000000100000005000000E59B6D6E4C94524008E57D1CCDD94B40E59B6D6E4C94524044DE72F563DB4B407380608E1E96524044DE72F563DB4B407380608E1E96524008E57D1CCDD94B40E59B6D6E4C94524008E57D1CCDD94B40
60144	Саратово	5	53	345	74.137771999999998	74.153177999999997	55.709510000000002	55.694159999999997	0103000020E610000001000000050000007D93A641D18852407E18213CDAD84B407D93A641D1885240AD174339D1DA4B40DE1D19ABCD895240AD174339D1DA4B40DE1D19ABCD8952407E18213CDAD84B407D93A641D18852407E18213CDAD84B40
48774	Рощино	5	53	345	74.223022	74.250483000000003	55.461787999999999	55.451889999999999	0103000020E61000000100000005000000771211FE458E5240D9B11188D7B94B40771211FE458E5240B6D782DE1BBB4B400E4DD9E907905240B6D782DE1BBB4B400E4DD9E907905240D9B11188D7B94B40771211FE458E5240D9B11188D7B94B40
48752	Подольск	5	53	345	74.339066000000003	74.351697000000001	55.520491999999997	55.512051	0103000020E61000000100000005000000E04BE141B39552402A711DE38AC14B40E04BE141B395524031EA5A7B9FC24B407C4622348296524031EA5A7B9FC24B407C462234829652402A711DE38AC14B40E04BE141B39552402A711DE38AC14B40
4847	Павлодаровка (Канавка)	5	53	345	73.918754000000007	73.959681000000003	55.275821000000001	55.260925999999998	0103000020E610000001000000050000006EC493DDCC7A52408A56EE0566A14B406EC493DDCC7A524067463F1A4EA34B40ED65DB696B7D524067463F1A4EA34B40ED65DB696B7D52408A56EE0566A14B406EC493DDCC7A52408A56EE0566A14B40
48713	Осиповка	5	53	345	73.547120000000007	73.570531000000003	55.407376999999997	55.402608000000001	0103000020E6100000010000000500000034BF9A0304635240D28DB0A888B34B4034BF9A03046352404012F6ED24B44B40AB967494836452404012F6ED24B44B40AB96749483645240D28DB0A888B34B4034BF9A0304635240D28DB0A888B34B40
48711	Октябрьское	5	53	345	73.585415999999995	73.620835999999997	55.565758000000002	55.547927000000001	0103000020E6100000010000000500000087A3AB747765524036CCD07822C64B4087A3AB7477655240A6B915C26AC84B407C0BEBC6BB675240A6B915C26AC84B407C0BEBC6BB67524036CCD07822C64B4087A3AB747765524036CCD07822C64B40
53131	Новоюрьево	5	53	345	74.256339999999994	74.266814999999994	55.247334000000002	55.237319999999997	0103000020E61000000100000005000000062AE3DF67905240E6577380609E4B40062AE3DF679052402D98F8A3A89F4B4043C5387F139152402D98F8A3A89F4B4043C5387F13915240E6577380609E4B40062AE3DF67905240E6577380609E4B40
47864	Новопокровка	5	53	345	74.023173999999997	74.060642000000001	55.718288000000001	55.698847999999998	0103000020E610000001000000050000008507CDAE7B8152400070ECD973D94B408507CDAE7B815240FC8D76DCF0DB4B40E6B0FB8EE1835240FC8D76DCF0DB4B40E6B0FB8EE18352400070ECD973D94B408507CDAE7B8152400070ECD973D94B40
4549	Новооболонь	5	53	345	73.738946999999996	73.762580999999997	55.592056999999997	55.581719	0103000020E610000001000000050000008C9E5BE84A6F52401D3BA8C475CA4B408C9E5BE84A6F5240162F1686C8CB4B4043E38920CE705240162F1686C8CB4B4043E38920CE7052401D3BA8C475CA4B408C9E5BE84A6F52401D3BA8C475CA4B40
53041	Максимовка	5	53	345	73.629514	73.634202999999999	55.463946999999997	55.452227000000001	0103000020E61000000100000005000000F29716F54968524021AF0793E2B94B40F29716F549685240E509849D62BB4B409B012EC896685240E509849D62BB4B409B012EC89668524021AF0793E2B94B40F29716F54968524021AF0793E2B94B40
4456	Лежанка	5	53	345	73.427366000000006	73.461763000000005	55.472009999999997	55.46116	0103000020E61000000100000005000000085BECF6595B5240971C774A07BB4B40085BECF6595B524046B1DCD26ABC4B402FE065868D5D524046B1DCD26ABC4B402FE065868D5D5240971C774A07BB4B40085BECF6595B5240971C774A07BB4B40
48600	Крутиха	5	53	345	73.796214000000006	73.808691999999994	55.604427000000001	55.592804999999998	0103000020E6100000010000000500000083A7902BF5725240E0F3C308E1CB4B4083A7902BF5725240E2E82ADD5DCD4B405B22179CC1735240E2E82ADD5DCD4B405B22179CC1735240E0F3C308E1CB4B4083A7902BF5725240E0F3C308E1CB4B40
48580	Красная Поляна	5	53	345	74.226147999999995	74.259654999999995	55.278148999999999	55.262906000000001	0103000020E6100000010000000500000092037635798E52400AF65FE7A6A14B4092037635798E52402235ED629AA34B408B4F01309E9052402235ED629AA34B408B4F01309E9052400AF65FE7A6A14B4092037635798E52400AF65FE7A6A14B40
60831	Кирсаново	5	53	345	74.377917999999994	74.396163000000001	55.271451999999996	55.259709999999998	0103000020E6100000010000000500000076A4FACE2F985240DA38622D3EA14B4076A4FACE2F98524086376BF0BEA24B40A8380EBC5A99524086376BF0BEA24B40A8380EBC5A995240DA38622D3EA14B4076A4FACE2F985240DA38622D3EA14B40
4249	Карасево	5	53	345	74.328457	74.343036999999995	55.312373999999998	55.307777000000002	0103000020E610000001000000050000001B4982700595524002BB9A3C65A74B401B49827005955240730F09DFFBA74B4059147651F4955240730F09DFFBA74B4059147651F495524002BB9A3C65A74B401B4982700595524002BB9A3C65A74B40
4163	Калачинская	5	53	345	74.563294999999997	74.575789999999998	55.258802000000003	55.250540999999998	0103000020E6100000010000000500000005C078060DA4524050A73CBA11A04B4005C078060DA45240D811876C20A14B4049D74CBED9A45240D811876C20A14B4049D74CBED9A4524050A73CBA11A04B4005C078060DA4524050A73CBA11A04B40
46191	Исаковка	5	53	345	74.406852999999998	74.432858999999993	55.749688999999996	55.741996999999998	0103000020E61000000100000005000000E3512AE1099A5240745DF8C1F9DE4B40E3512AE1099A5240E19524CFF5DF4B40DF313CF6B39B5240E19524CFF5DF4B40DF313CF6B39B5240745DF8C1F9DE4B40E3512AE1099A5240745DF8C1F9DE4B40
48136	Исаевка	5	53	345	74.147294000000002	74.175060999999999	55.309156000000002	55.300716000000001	0103000020E610000001000000050000006939D0436D89524025B1A4DC7DA64B406939D0436D8952405CAE7E6C92A74B4086730D33348B52405CAE7E6C92A74B4086730D33348B524025B1A4DC7DA64B406939D0436D89524025B1A4DC7DA64B40
48142	Дубровка	5	53	345	73.660362000000006	73.684832	55.514901000000002	55.507423000000003	0103000020E610000001000000050000005B61FA5E436A52407E1EA33CF3C04B405B61FA5E436A5240BFD6A546E8C14B4046D09849D46B5240BFD6A546E8C14B4046D09849D46B52407E1EA33CF3C04B405B61FA5E436A52407E1EA33CF3C04B40
48494	Демьяновка	5	53	345	73.776757000000003	73.803364999999999	55.426808999999999	55.413089999999997	0103000020E610000001000000050000001AFCFD62B6715240FE261422E0B44B401AFCFD62B6715240B95164ADA1B64B40117008556A735240B95164ADA1B64B40117008556A735240FE261422E0B44B401AFCFD62B6715240FE261422E0B44B40
3924	Горьковское	5	53	345	74.341697999999994	74.396800999999996	55.382488000000002	55.354497000000002	0103000020E61000000100000005000000F3C64961DE955240DBC35E2860AD4B40F3C64961DE955240658EE55DF5B04B404981053065995240658EE55DF5B04B404981053065995240DBC35E2860AD4B40F3C64961DE955240DBC35E2860AD4B40
53032	Георгиевка	5	53	345	73.864611999999994	73.898200000000003	55.588709999999999	55.576456999999998	0103000020E61000000100000005000000AAEE91CD557752406F46CD57C9C94B40AAEE91CD55775240016A6AD95ACB4B401A51DA1B7C795240016A6AD95ACB4B401A51DA1B7C7952406F46CD57C9C94B40AAEE91CD557752406F46CD57C9C94B40
48386	Веселый	5	53	345	74.447627999999995	74.460661999999999	55.311031	55.301397000000001	0103000020E610000001000000050000008731E9EFA59C5240670E492D94A64B408731E9EFA59C5240668522DDCFA74B40A320787C7B9D5240668522DDCFA74B40A320787C7B9D5240670E492D94A64B408731E9EFA59C5240670E492D94A64B40
48335	Богданово	5	53	345	73.948190999999994	73.975536000000005	55.711132999999997	55.697823	0103000020E6100000010000000500000023D74D29AF7C5240C4B2994352D94B4023D74D29AF7C52409D0DF96706DB4B4086048C2E6F7E52409D0DF96706DB4B4086048C2E6F7E5240C4B2994352D94B4023D74D29AF7C5240C4B2994352D94B40
60818	Бельсенды-Казах	5	53	345	74.026838999999995	74.045586999999998	55.360326000000001	55.350161999999997	0103000020E6100000010000000500000078D0ECBAB7815240A626C11BD2AC4B4078D0ECBAB781524002F390291FAE4B40DB87BCE5EA82524002F390291FAE4B40DB87BCE5EA825240A626C11BD2AC4B4078D0ECBAB7815240A626C11BD2AC4B40
3442	Астыровка	5	53	345	74.419960000000003	74.459835999999996	55.369959999999999	55.353437	0103000020E610000001000000050000003468E89FE09A52402219726C3DAD4B403468E89FE09A5240016A6AD95AAF4B408061F9F36D9D5240016A6AD95AAF4B408061F9F36D9D52402219726C3DAD4B403468E89FE09A52402219726C3DAD4B40
48250	Алексеевский	5	53	345	74.059590999999998	74.080926000000005	55.545676	55.528477000000002	0103000020E61000000100000005000000B308C556D083524017D86322A5C34B40B308C556D0835240261B0FB6D8C54B405AD93EE42D855240261B0FB6D8C54B405AD93EE42D85524017D86322A5C34B40B308C556D083524017D86322A5C34B40
53035	Алексеевка	5	53	345	74.021619999999999	74.051569000000001	55.525359000000002	55.514901000000002	0103000020E61000000100000005000000213CDA3862815240BFD6A546E8C14B40213CDA386281524063D4B5F63EC34B40321F10E84C83524063D4B5F63EC34B40321F10E84C835240BFD6A546E8C14B40213CDA3862815240BFD6A546E8C14B40
3307	Аксеновка	5	53	345	73.989486999999997	74.008846000000005	55.453283999999996	55.448163000000001	0103000020E610000001000000050000004C3448C1537F52407D23BA675DB94B404C3448C1537F524068E6C93505BA4B40D42CD0EE9080524068E6C93505BA4B40D42CD0EE908052407D23BA675DB94B404C3448C1537F52407D23BA675DB94B40
3191	Агафоновка	5	53	345	73.853759999999994	73.867585000000005	55.531824999999998	55.516119000000003	0103000020E6100000010000000500000082A8FB00A476524010ECF82F10C24B4082A8FB00A4765240FC1873D712C44B4003603C8386775240FC1873D712C44B4003603C838677524010ECF82F10C24B4082A8FB00A476524010ECF82F10C24B40
3108	Чернецовка	5	53	397	72.509719000000004	72.528467000000006	56.554096000000001	56.545642000000001	0103000020E6100000010000000500000097C9703C9F2052407AA9D898D7454C4097C9703C9F205240166C239EEC464C40FA804067D2215240166C239EEC464C40FA804067D22152407AA9D898D7454C4097C9703C9F2052407AA9D898D7454C40
2961	Чебаклы	5	53	397	73.061716000000004	73.080130999999994	57.099032000000001	57.087085999999999	0103000020E61000000100000005000000F568AA27F343524040F850A2258B4C40F568AA27F3435240F5A0A014AD8C4C405419C6DD20455240F5A0A014AD8C4C405419C6DD2045524040F850A2258B4C40F568AA27F343524040F850A2258B4C40
3011	Чаунино	5	53	397	73.075441999999995	73.091172	57.148493000000002	57.139234000000002	0103000020E61000000100000005000000ABAFAE0AD4445240E23E726BD2914C40ABAFAE0AD4445240AC5791D101934C40E69315C3D5455240AC5791D101934C40E69315C3D5455240E23E726BD2914C40ABAFAE0AD4445240E23E726BD2914C40
2693	Форпост	5	53	397	72.152917000000002	72.171916999999993	56.788908999999997	56.774608000000001	0103000020E6100000010000000500000028806264C9095240289CDD5A26634C4028806264C9095240914259F8FA644C40172829B0000B5240914259F8FA644C40172829B0000B5240289CDD5A26634C4028806264C9095240289CDD5A26634C40
2842	Фирстово	5	53	397	72.866629000000003	72.898500999999996	57.043258000000002	57.031097000000003	0103000020E61000000100000005000000F9307BD9763752407A008BFCFA834C40F9307BD9763752402BA5677A89854C40179B560A813952402BA5677A89854C40179B560A813952407A008BFCFA834C40F9307BD9763752407A008BFCFA834C40
2722	Уралы	5	53	397	72.944188999999994	72.978037999999998	57.074655999999997	57.064224000000003	0103000020E610000001000000050000008C0FB3976D3C524025CFF57D38884C408C0FB3976D3C52409F39EB538E894C40B20FB22C983E52409F39EB538E894C40B20FB22C983E524025CFF57D38884C408C0FB3976D3C524025CFF57D38884C40
2260	Уки	5	53	397	72.609871999999996	72.630640999999997	56.996617000000001	56.981620999999997	0103000020E61000000100000005000000C0AF9124082752408D08C6C1A57D4C40C0AF9124082752409ED15625917F4C4012A1116C5C2852409ED15625917F4C4012A1116C5C2852408D08C6C1A57D4C40C0AF9124082752408D08C6C1A57D4C40
2607	Становка	5	53	397	72.361307999999994	72.395705000000007	56.867108999999999	56.849251000000002	0103000020E610000001000000050000001FF296AB1F175240338CBB41B46C4C401FF296AB1F1752409C887E6DFD6E4C404777103B531952409C887E6DFD6E4C404777103B53195240338CBB41B46C4C401FF296AB1F175240338CBB41B46C4C40
2163	Решетино	5	53	397	72.431466999999998	72.450402999999994	56.930796999999998	56.919533999999999	0103000020E610000001000000050000006893C3279D1B5240B0C7444AB3754C406893C3279D1B5240821B295B24774C404CC11A67D31C5240821B295B24774C404CC11A67D31C5240B0C7444AB3754C406893C3279D1B5240B0C7444AB3754C40
2516	Листвяги	5	53	397	71.891597000000004	71.925687999999994	57.238712	57.230201999999998	0103000020E610000001000000050000008D0DDDEC0FF95140A5BC5642779D4C408D0DDDEC0FF95140D594641D8E9E4C402D93E1783EFB5140D594641D8E9E4C402D93E1783EFB5140A5BC5642779D4C408D0DDDEC0FF95140A5BC5642779D4C40
2652	Коновалиха	5	53	397	72.432608000000002	72.445310000000006	56.848281	56.840409000000001	0103000020E610000001000000050000003BFF76D9AF1B5240CD21A985926B4C403BFF76D9AF1B5240BA68C878946C4C403CA583F57F1C5240BA68C878946C4C403CA583F57F1C5240CD21A985926B4C403BFF76D9AF1B5240CD21A985926B4C40
2152	Верхние Уки	5	53	397	72.761426999999998	72.778296999999995	56.780619999999999	56.768956000000003	0103000020E61000000100000005000000A6D24F38BB305240100874266D624C40A6D24F38BB305240404D2D5BEB634C40CB64389ECF315240404D2D5BEB634C40CB64389ECF315240100874266D624C40A6D24F38BB305240100874266D624C40
2366	Большие Уки	5	53	397	72.597618999999995	72.654032999999998	56.968223999999999	56.935462999999999	0103000020E61000000100000005000000F71DC3633F2652401CCF6740BD774C40F71DC3633F265240E59997C3EE7B4C404E603AADDB295240E59997C3EE7B4C404E603AADDB2952401CCF6740BD774C40F71DC3633F2652401CCF6740BD774C40
2309	Белогривка	5	53	397	72.810134000000005	72.855093999999994	56.633203999999999	56.616377	0103000020E610000001000000050000002CD8463CD9335240D8800871E54E4C402CD8463CD933524023D923D40C514C405F402FDCB936524023D923D40C514C405F402FDCB9365240D8800871E54E4C402CD8463CD9335240D8800871E54E4C40
2862	Баслы	5	53	397	72.768388999999999	72.799272999999999	57.013061999999998	57.003352999999997	0103000020E61000000100000005000000CB660E492D315240F7AB00DF6D804C40CB660E492D3152400169FF03AC814C40DAE4F049273352400169FF03AC814C40DAE4F04927335240F7AB00DF6D804C40CB660E492D315240F7AB00DF6D804C40
2074	Аёв	5	53	397	72.614984000000007	72.640728999999993	56.935437999999998	56.922480999999998	0103000020E610000001000000050000000DE4D9E55B27524037177FDB13764C400DE4D9E55B275240C3B7B06EBC774C40522635B401295240C3B7B06EBC774C40522635B40129524037177FDB13764C400DE4D9E55B27524037177FDB13764C40
972	Яланкуль	5	53	103	73.765887000000006	73.787698000000006	56.119222999999998	56.109721999999998	0103000020E610000001000000050000009F5BE84A047152406BD3D85E0B0E4C409F5BE84A047152402BF702B3420F4C40FA47DFA4697252402BF702B3420F4C40FA47DFA4697252406BD3D85E0B0E4C409F5BE84A047152406BD3D85E0B0E4C40
32392	Яготово	5	53	103	74.384027000000003	74.403233	56.409255000000002	56.399776000000003	0103000020E61000000100000005000000FC71FBE593985240E4DC26DC2B334C40FC71FBE593985240BC5CC47762344C40C0EAC891CE995240BC5CC47762344C40C0EAC891CE995240E4DC26DC2B334C40FC71FBE593985240E4DC26DC2B334C40
32101	Шуево	5	53	103	74.647520999999998	74.661282999999997	56.531700000000001	56.525329999999997	0103000020E61000000100000005000000499EEBFB70A95240C8CD70033E434C40499EEBFB70A9524040A4DFBE0E444C40A699EE7552AA524040A4DFBE0E444C40A699EE7552AA5240C8CD70033E434C40499EEBFB70A95240C8CD70033E434C40
53052	Шипицино	5	53	103	74.550421999999998	74.581413999999995	56.023499999999999	56.005218999999997	0103000020E61000000100000005000000EE3F321D3AA35240AE282504AB004C40EE3F321D3AA352405EBA490C02034C40F0DB10E335A552405EBA490C02034C40F0DB10E335A55240AE282504AB004C40EE3F321D3AA35240AE282504AB004C40
1135	Черново	5	53	103	73.933306000000002	73.958459000000005	55.843631000000002	55.834921999999999	0103000020E6100000010000000500000047CA1649BB7B5240FF5A5EB9DEEA4B4047CA1649BB7B52402672C119FCEB4B40A4E36A64577D52402672C119FCEB4B40A4E36A64577D5240FF5A5EB9DEEA4B4047CA1649BB7B5240FF5A5EB9DEEA4B40
249	Черналы	5	53	103	74.165772000000004	74.181601000000001	56.326222999999999	56.318995000000001	0103000020E61000000100000005000000ECA529029C8A5240344B02D4D4284C40ECA529029C8A5240FC19DEACC1294C40F0FACC599F8B5240FC19DEACC1294C40F0FACC599F8B5240344B02D4D4284C40ECA529029C8A5240344B02D4D4284C40
32225	Чеплярово	5	53	103	74.748859999999993	74.760402999999997	56.586359999999999	56.580053999999997	0103000020E6100000010000000500000015527E52EDAF5240FDF49F353F4A4C4015527E52EDAF52405ED72FD80D4B4C40F0315871AAB052405ED72FD80D4B4C40F0315871AAB05240FDF49F353F4A4C4015527E52EDAF5240FDF49F353F4A4C40
60852	Чебаклы	5	53	103	73.865313	73.889989	55.976180999999997	55.960614	0103000020E610000001000000050000006FF3C64961775240350A4966F5FA4B406FF3C6496177524000FDBE7FF3FC4B402F336C94F578524000FDBE7FF3FC4B402F336C94F5785240350A4966F5FA4B406FF3C64961775240350A4966F5FA4B40
871	Уваровка	5	53	103	73.999791000000002	74.012259	56.013190000000002	56.003346000000001	0103000020E6100000010000000500000073F56393FC7F5240454948A46D004C4073F56393FC7F52402F51BD35B0014C403A05F9D9C88052402F51BD35B0014C403A05F9D9C8805240454948A46D004C4073F56393FC7F5240454948A46D004C40
143	Тусказань	5	53	103	74.313041999999996	74.336713000000003	56.372472999999999	56.366948999999998	0103000020E61000000100000005000000901150E1089452406326512FF82E4C40901150E1089452404ED2FC31AD2F4C40D6C8AEB48C9552404ED2FC31AD2F4C40D6C8AEB48C9552406326512FF82E4C40901150E1089452406326512FF82E4C40
1075	Трубчевка	5	53	103	74.017083	74.041859000000002	55.853648	55.844884999999998	0103000020E6100000010000000500000053944BE317815240C3F0113125EC4B4053944BE317815240DD25715644ED4B40C5025FD1AD825240DD25715644ED4B40C5025FD1AD825240C3F0113125EC4B4053944BE317815240C3F0113125EC4B40
32044	Терехово	5	53	103	74.626249000000001	74.637683999999993	56.555996999999998	56.547601999999998	0103000020E61000000100000005000000C689AF7614A85240B29C84D217464C40C689AF7614A8524049D6E1E82A474C40AD4B8DD0CFA8524049D6E1E82A474C40AD4B8DD0CFA85240B29C84D217464C40C689AF7614A85240B29C84D217464C40
52979	Такмык	5	53	103	74.664974999999998	74.693380000000005	56.257142999999999	56.230891999999997	0103000020E61000000100000005000000166A4DF38EAA52403A747ADE8D1D4C40166A4DF38EAA52409AB2D30FEA204C40D5EC815660AC52409AB2D30FEA204C40D5EC815660AC52403A747ADE8D1D4C40166A4DF38EAA52403A747ADE8D1D4C40
517	Сухокарасук	5	53	103	74.108981	74.126219000000006	56.087795	56.07799	0103000020E61000000100000005000000AAB8718BF986524020B58993FB094C40AAB8718BF98652404CE0D6DD3C0B4C409148DBF8138852404CE0D6DD3C0B4C409148DBF81388524020B58993FB094C40AAB8718BF986524020B58993FB094C40
32011	Секменево	5	53	103	74.563843000000006	74.577308000000002	56.616931999999998	56.606330999999997	0103000020E610000001000000050000000745F30016A4524086C613419C4D4C400745F30016A452408DEDB5A0F74E4C4007EE409DF2A452408DEDB5A0F74E4C4007EE409DF2A4524086C613419C4D4C400745F30016A4524086C613419C4D4C40
1621	Рямовка	5	53	103	74.368961999999996	74.391923000000006	55.991284	55.979726999999997	0103000020E61000000100000005000000DFDDCA129D9752400C01C0B167FD4B40DFDDCA129D9752402786E464E2FE4B4037E33444159952402786E464E2FE4B4037E33444159952400C01C0B167FD4B40DFDDCA129D9752400C01C0B167FD4B40
1277	Русиново	5	53	103	73.900148999999999	73.916049999999998	55.889386000000002	55.885266999999999	0103000020E61000000100000005000000BC218D0A9C795240309DD66D50F14B40BC218D0A9C79524098C28366D7F14B400DE02D90A07A524098C28366D7F14B400DE02D90A07A5240309DD66D50F14B40BC218D0A9C795240309DD66D50F14B40
1490	Ростовка	5	53	103	74.371756000000005	74.388706999999997	55.807429999999997	55.798222000000003	0103000020E61000000100000005000000E085ADD9CA9752404F7974232CE64B40E085ADD9CA97524096E7C1DD59E74B407B2E5393E098524096E7C1DD59E74B407B2E5393E09852404F7974232CE64B40E085ADD9CA9752404F7974232CE64B40
31753	Решетниково	5	53	103	74.694062000000002	74.711462999999995	56.303811000000003	56.292552999999998	0103000020E610000001000000050000005ED905836BAC524060AC6F6072254C405ED905836BAC524021956247E3264C4019541B9C88AD524021956247E3264C4019541B9C88AD524060AC6F6072254C405ED905836BAC524060AC6F6072254C40
53100	Почекуево	5	53	103	74.442803999999995	74.477172999999993	56.523563000000003	56.509448999999996	0103000020E610000001000000050000006EA296E6569C52406DFDF49F35414C406EA296E6569C5240A532C51C04434C4030629F008A9E5240A532C51C04434C4030629F008A9E52406DFDF49F35414C406EA296E6569C52406DFDF49F35414C40
31633	Осихино	5	53	103	74.463339000000005	74.480551000000006	56.119965999999998	56.110370000000003	0103000020E6100000010000000500000087FD9E58A79D5240D23AAA9A200E4C4087FD9E58A79D5240E350BF0B5B0F4C40D943FB58C19E5240E350BF0B5B0F4C40D943FB58C19E5240D23AAA9A200E4C4087FD9E58A79D5240D23AAA9A200E4C40
53128	Новологиново	5	53	103	74.600898000000001	74.629571999999996	56.590339999999998	56.572423999999998	0103000020E61000000100000005000000D68EE21C75A6524006B98B3045494C40D68EE21C75A65240A4C2D842904B4C408C9E5BE84AA85240A4C2D842904B4C408C9E5BE84AA8524006B98B3045494C40D68EE21C75A6524006B98B3045494C40
1711	Моховое Озеро	5	53	103	74.217578000000003	74.235904000000005	55.935586999999998	55.929364	0103000020E61000000100000005000000109546CCEC8D5240350A4966F5F64B40109546CCEC8D524008C89750C1F74B40B83F170D198F524008C89750C1F74B40B83F170D198F5240350A4966F5F64B40109546CCEC8D5240350A4966F5F64B40
53130	Могильно-Посельское	5	53	103	74.444761999999997	74.469303999999994	55.925884000000003	55.913913999999998	0103000020E610000001000000050000003A2009FB769C5240A3AD4A22FBF44B403A2009FB769C5240E1F1ED5D83F64B4072F8A413099E5240E1F1ED5D83F64B4072F8A413099E5240A3AD4A22FBF44B403A2009FB769C5240A3AD4A22FBF44B40
1367	Милино	5	53	103	74.311595999999994	74.335122999999996	55.84496	55.839678999999997	0103000020E610000001000000050000001F645930F1935240A911FA997AEB4B401F645930F1935240CE3637A627EC4B40CB48BDA772955240CE3637A627EC4B40CB48BDA772955240A911FA997AEB4B401F645930F1935240A911FA997AEB4B40
53050	Курносово	5	53	103	74.302306999999999	74.333892000000006	56.127150999999998	56.114615999999998	0103000020E61000000100000005000000859675FF5893524096CCB1BCAB0E4C40859675FF58935240AC53E57B46104C4059198D7C5E955240AC53E57B46104C4059198D7C5E95524096CCB1BCAB0E4C40859675FF5893524096CCB1BCAB0E4C40
742	Куйгалы	5	53	103	74.152970999999994	74.171413999999999	56.223095999999998	56.217309999999998	0103000020E61000000100000005000000218FE046CA895240008C67D0D01B4C40218FE046CA89524028EFE3688E1C4C40E6046D72F88A524028EFE3688E1C4C40E6046D72F88A5240008C67D0D01B4C40218FE046CA895240008C67D0D01B4C40
31588	Криводаново	5	53	103	74.476607000000001	74.497224000000003	56.180638000000002	56.167569	0103000020E61000000100000005000000DC82A5BA809E52406669A7E672154C40DC82A5BA809E52401A355F251F174C4053B29C84D29F52401A355F251F174C4053B29C84D29F52406669A7E672154C40DC82A5BA809E52406669A7E672154C40
52964	Красный Яр	5	53	103	74.604240000000004	74.627155999999999	56.160164999999999	56.137951999999999	0103000020E61000000100000005000000D8BB3FDEABA652407A354069A8114C40D8BB3FDEABA652405F7B664980144C405F5FEB5223A852405F7B664980144C405F5FEB5223A852407A354069A8114C40D8BB3FDEABA652407A354069A8114C40
32295	Кошкуль	5	53	103	74.298579000000004	74.315629000000001	56.503866000000002	56.493616000000003	0103000020E610000001000000050000006F1118EB1B935240246420CF2E3F4C406F1118EB1B9352407EC85BAE7E404C40D42AFA43339452407EC85BAE7E404C40D42AFA4333945240246420CF2E3F4C406F1118EB1B935240246420CF2E3F4C40
32449	Коршуново	5	53	103	74.407535999999993	74.424396999999999	56.455666999999998	56.445981000000003	0103000020E6100000010000000500000054FCDF11159A524096D1C8E715394C4054FCDF11159A5240E76ED74B533A4C4050E10852299B5240E76ED74B533A4C4050E10852299B524096D1C8E715394C4054FCDF11159A524096D1C8E715394C40
31908	Колбышево	5	53	103	74.658901999999998	74.672521000000003	56.460492000000002	56.444001	0103000020E6100000010000000500000037514B732BAA524016325706D5384C4037514B732BAA5240EA08E066F13A4C40E33785950AAB5240EA08E066F13A4C40E33785950AAB524016325706D5384C4037514B732BAA524016325706D5384C40
1966	Кирсановка	5	53	103	74.560196000000005	74.584925999999996	56.048515000000002	56.034444999999998	0103000020E6100000010000000500000067D65240DAA352405F419AB168044C4067D65240DAA35240C72E51BD35064C402025766D6FA55240C72E51BD35064C402025766D6FA552405F419AB168044C4067D65240DAA352405F419AB168044C40
362	Каракуль	5	53	103	74.087969000000001	74.103339000000005	56.318835	56.313268999999998	0103000020E61000000100000005000000F583BA48A1855240E1ECD63219284C40F583BA48A1855240FBE8D495CF284C40B0592E1B9D865240FBE8D495CF284C40B0592E1B9D865240E1ECD63219284C40F583BA48A1855240E1ECD63219284C40
52989	Ингалы	5	53	103	74.183064999999999	74.232525999999993	55.860028999999997	55.839421000000002	0103000020E61000000100000005000000B4024356B78B5240AE49B72572EB4B40B4024356B78B5240484E266E15EE4B400F5EBBB4E18E5240484E266E15EE4B400F5EBBB4E18E5240AE49B72572EB4B40B4024356B78B5240AE49B72572EB4B40
496	Добролюбовка	5	53	103	74.215781000000007	74.227513000000002	56.124395999999997	56.116709	0103000020E6100000010000000500000049861C5BCF8D52400E130D52F00E4C4049861C5BCF8D524069E04735EC0F4C408D9AAF928F8E524069E04735EC0F4C408D9AAF928F8E52400E130D52F00E4C4049861C5BCF8D52400E130D52F00E4C40
2025	Гущино	5	53	103	74.636444999999995	74.652623000000006	56.018327999999997	56.008856999999999	0103000020E61000000100000005000000F92CCF83BBA852409BABE63922014C40F92CCF83BBA85240F04C689258024C4084674293C4A95240F04C689258024C4084674293C4A952409BABE63922014C40F92CCF83BBA852409BABE63922014C40
31820	Ботвино	5	53	103	74.545769000000007	74.566196000000005	56.283695000000002	56.274723999999999	0103000020E61000000100000005000000EC8A19E1EDA2524091B6F1272A234C40EC8A19E1EDA25240F584251E50244C4011C8258E3CA45240F584251E50244C4011C8258E3CA4524091B6F1272A234C40EC8A19E1EDA2524091B6F1272A234C40
52965	Большеречье	5	53	103	74.598590000000002	74.649721999999997	56.128354999999999	56.075167	0103000020E610000001000000050000009C6D6E4C4FA65240855E7F129F094C409C6D6E4C4FA6524098A3C7EF6D104C40785F950B95A9524098A3C7EF6D104C40785F950B95A95240855E7F129F094C409C6D6E4C4FA65240855E7F129F094C40
60811	Большемурлы	5	53	103	74.535473999999994	74.550458000000006	55.933019999999999	55.925269	0103000020E61000000100000005000000EE76BD3445A252405680EF366FF64B40EE76BD3445A25240C84109336DF74B4095F430B43AA35240C84109336DF74B4095F430B43AA352405680EF366FF64B40EE76BD3445A252405680EF366FF64B40
32156	Берняжка	5	53	103	74.567265000000006	74.578647000000004	56.625534000000002	56.620953999999998	0103000020E6100000010000000500000097CADB114EA452400229B16B7B4F4C4097CADB114EA452409E44847F11504C406D3B6D8D08A552409E44847F11504C406D3B6D8D08A552400229B16B7B4F4C4097CADB114EA452400229B16B7B4F4C40
918	Березовка	5	53	103	73.861144999999993	73.868672000000004	55.922322999999999	55.914977999999998	0103000020E610000001000000050000004A07EBFF1C7752409D47C5FF1DF54B404A07EBFF1C7752409FAC18AE0EF64B40DCBC7152987752409FAC18AE0EF64B40DCBC7152987752409D47C5FF1DF54B404A07EBFF1C7752409D47C5FF1DF54B40
31494	Безымянная	5	53	103	74.552389000000005	74.560563999999999	56.136346000000003	56.129322999999999	0103000020E61000000100000005000000E46A64575AA3524070CFF3A78D104C40E46A64575AA35240607825C973114C4028D4D347E0A35240607825C973114C4028D4D347E0A3524070CFF3A78D104C40E46A64575AA3524070CFF3A78D104C40
25582	Ягодное	5	53	929	72.907493000000002	72.920195000000007	54.679015	54.668905000000002	0103000020E610000001000000050000005516855D143A5240C190D5AD9E554B405516855D143A5240293FA9F6E9564B4056BC9179E43A5240293FA9F6E9564B4056BC9179E43A5240C190D5AD9E554B405516855D143A5240C190D5AD9E554B40
61522	Южное	5	53	929	73.019486000000001	73.036580999999998	54.637835000000003	54.627543000000003	0103000020E61000000100000005000000B62E35423F415240B8EA3A5453504B40B62E35423F415240419FC893A4514B40EBA9D55757425240419FC893A4514B40EBA9D55757425240B8EA3A5453504B40B62E35423F415240B8EA3A5453504B40
30801	Цветнополье	5	53	929	72.853872999999993	72.904456999999994	54.498058	54.479162000000002	0103000020E61000000100000005000000FE7BF0DAA536524034BE2F2E553D4B40FE7BF0DAA53652406EC1525DC03F4B40D9E89C9FE23952406EC1525DC03F4B40D9E89C9FE239524034BE2F2E553D4B40FE7BF0DAA536524034BE2F2E553D4B40
60201	Тулумбай	5	53	929	73.019898999999995	73.034946000000005	54.838617999999997	54.835507	0103000020E61000000100000005000000478E7406464152401F4AB4E4F16A4B40478E74064641524020EBA9D5576B4B4011C8258E3C42524020EBA9D5576B4B4011C8258E3C4252401F4AB4E4F16A4B40478E7406464152401F4AB4E4F16A4B40
46235	Трубецкое	5	53	929	72.889347000000001	72.913241999999997	54.616470999999997	54.603560000000002	0103000020E61000000100000005000000EDF2AD0FEB3852403E963E74414D4B40EDF2AD0FEB38524059F78F85E84E4B405AD5928E723A524059F78F85E84E4B405AD5928E723A52403E963E74414D4B40EDF2AD0FEB3852403E963E74414D4B40
61502	Сосновка	5	53	929	73.131694999999993	73.164356999999995	54.824969000000003	54.806365999999997	0103000020E61000000100000005000000FD82DDB06D4852409C4D470037674B40FD82DDB06D4852405F9B8D9598694B4098F738D3844A52405F9B8D9598694B4098F738D3844A52409C4D470037674B40FD82DDB06D4852409C4D470037674B40
30488	Сереброполье	5	53	929	73.002606999999998	73.023258999999996	54.436591	54.430872000000001	0103000020E6100000010000000500000067EF8CB62A4052408D614ED026374B4067EF8CB62A4052402D5DC136E2374B409C1551137D4152402D5DC136E2374B409C1551137D4152408D614ED026374B4067EF8CB62A4052408D614ED026374B40
60827	Сегизбай	5	53	929	72.906801000000002	72.921165000000002	54.772671000000003	54.764901000000002	0103000020E61000000100000005000000BABE0F07093A5240BFD6A546E8614B40BABE0F07093A5240A8C821E2E6624B40124E0B5EF43A5240A8C821E2E6624B40124E0B5EF43A5240BFD6A546E8614B40BABE0F07093A5240BFD6A546E8614B40
7481	Руслановка	5	53	929	72.849012999999999	72.866431000000006	54.684443999999999	54.670160000000003	0103000020E610000001000000050000003F389F3A563652402F8B89CDC7554B403F389F3A56365240C2F869DC9B574B40664F029B73375240C2F869DC9B574B40664F029B733752402F8B89CDC7554B403F389F3A563652402F8B89CDC7554B40
53134	Розо-Долина	5	53	929	72.936139999999995	72.954322000000005	54.477347000000002	54.469729999999998	0103000020E610000001000000050000008E1EBFB7E93B52409CF9D51C203C4B408E1EBFB7E93B5240FFEBDCB4193D4B409DF6949C133D5240FFEBDCB4193D4B409DF6949C133D52409CF9D51C203C4B408E1EBFB7E93B52409CF9D51C203C4B40
46237	Пришиб	5	53	929	73.049228999999997	73.076745000000003	54.437277000000002	54.426326000000003	0103000020E61000000100000005000000F2406491264352409EB7B1D991364B40F240649126435240812557B1F8374B406B48DC63E9445240812557B1F8374B406B48DC63E94452409EB7B1D991364B40F2406491264352409EB7B1D991364B40
30168	Привальное	5	53	929	72.980013999999997	73.009271999999996	54.694716999999997	54.682580000000002	0103000020E61000000100000005000000D1E7A38CB83E5240AC730CC85E574B40D1E7A38CB83E5240D47C957CEC584B402F3196E997405240D47C957CEC584B402F3196E997405240AC730CC85E574B40D1E7A38CB83E5240AC730CC85E574B40
46380	Поповка	5	53	929	73.089222000000007	73.119082000000006	54.869875	54.858812999999998	0103000020E610000001000000050000005C0531D0B545524098309A95ED6D4B405C0531D0B5455240D34D6210586F4B40B5E21B0A9F475240D34D6210586F4B40B5E21B0A9F47524098309A95ED6D4B405C0531D0B545524098309A95ED6D4B40
45992	Пахомовка	5	53	929	73.133337999999995	73.157906999999994	54.686359000000003	54.670273999999999	0103000020E6100000010000000500000019541B9C88485240F7ADD689CB554B4019541B9C884852405B28999CDA574B40CE33F6251B4A52405B28999CDA574B40CE33F6251B4A5240F7ADD689CB554B4019541B9C88485240F7ADD689CB554B40
46363	Новинка	5	53	929	73.136724999999998	73.148493000000002	54.763658999999997	54.758302999999998	0103000020E61000000100000005000000EBE2361AC0485240B6BA9C1210614B40EBE2361AC0485240E525FF93BF614B40D6ABC8E880495240E525FF93BF614B40D6ABC8E880495240B6BA9C1210614B40EBE2361AC0485240B6BA9C1210614B40
46341	Мирная Долина	5	53	929	73.056558999999993	73.094289000000003	54.907640999999998	54.894694000000001	0103000020E61000000100000005000000D8D2A3A99E435240B6F63E5585724B40D8D2A3A99E4352401EC18D942D744B40D8D7BAD4084652401EC18D942D744B40D8D7BAD408465240B6F63E5585724B40D8D2A3A99E435240B6F63E5585724B40
46266	Кудук-Чилик	5	53	929	73.103829000000005	73.122172000000006	54.51164	54.503213000000002	0103000020E6100000010000000500000017D86322A546524006F6984869404B4017D86322A5465240A8A9656B7D414B402A1F82AAD1475240A8A9656B7D414B402A1F82AAD147524006F6984869404B4017D86322A546524006F6984869404B40
30341	Круч	5	53	929	73.362795000000006	73.376423000000003	54.753684999999997	54.744866000000002	0103000020E61000000100000005000000C00985083857524080F3E2C4575F4B40C0098508385752402D3E05C078604B40959D7E50175852402D3E05C078604B40959D7E501758524080F3E2C4575F4B40C00985083857524080F3E2C4575F4B40
30300	Кошкарево	5	53	929	73.317717999999999	73.335801000000004	54.743358999999998	54.740101000000003	0103000020E610000001000000050000006FD6E07D55545240535E2BA1BB5E4B406FD6E07D55545240F8174163265F4B40B43D7AC37D555240F8174163265F4B40B43D7AC37D555240535E2BA1BB5E4B406FD6E07D55545240535E2BA1BB5E4B40
30244	Звонарев Кут	5	53	929	73.353443999999996	73.387867	54.696111000000002	54.685589	0103000020E61000000100000005000000EA3D95D39E565240A9BF5E61C1574B40EA3D95D39E56524064B14D2A1A594B40A60C1CD0D258524064B14D2A1A594B40A60C1CD0D2585240A9BF5E61C1574B40EA3D95D39E565240A9BF5E61C1574B40
51911	Гуф	5	53	929	72.703692000000004	73.500094000000004	54.916195999999999	54.321696000000003	0103000020E610000001000000050000003D9D2B4A092D524084A0A3552D294B403D9D2B4A092D5240EE5C18E945754B4041BB438A01605240EE5C18E945754B4041BB438A0160524084A0A3552D294B403D9D2B4A092D524084A0A3552D294B40
53005	Березовка	5	53	929	73.049732000000006	73.092006999999995	54.802743999999997	54.787199000000001	0103000020E61000000100000005000000246420CF2E435240D238D4EFC2644B40246420CF2E435240B587BD50C0664B4032005471E3455240B587BD50C0664B4032005471E3455240D238D4EFC2644B40246420CF2E435240D238D4EFC2644B40
53117	Бердянка	5	53	929	73.089420000000004	73.112803	54.643155	54.631940999999998	0103000020E61000000100000005000000EFE6A90EB945524032005471E3504B40EFE6A90EB945524023A12DE752524B4001F9122A3847524023A12DE752524B4001F9122A3847524032005471E3504B40EFE6A90EB945524032005471E3504B40
46941	Александровка	5	53	929	72.739113000000003	72.770247999999995	54.567425	54.550071000000003	0103000020E610000001000000050000001AC39CA04D2F524030BDFDB968464B401AC39CA04D2F524066F7E461A1484B40CD7344BE4B31524066F7E461A1484B40CD7344BE4B31524030BDFDB968464B401AC39CA04D2F524030BDFDB968464B40
46051	Азово	5	53	929	72.999525000000006	73.048007999999996	54.72437	54.690424	0103000020E6100000010000000500000034A2B437F83F5240CF2F4AD05F584B4034A2B437F83F52400D1AFA27B85C4B40917C2590124352400D1AFA27B85C4B40917C259012435240CF2F4AD05F584B4034A2B437F83F5240CF2F4AD05F584B40
59179	п.Каревски	5	52	\N	78.896732	78.917338999999998	54.805692000000001	54.798110000000001	0103000020E61000000100000005000000B5519D0E64B95340274EEE7728664B40B5519D0E64B953400D535BEA20674B401A16A3AEB5BA53400D535BEA20674B401A16A3AEB5BA5340274EEE7728664B40B5519D0E64B95340274EEE7728664B40
59197	п. Сибиряк	5	52	\N	83.027096	83.041514000000006	55.033264000000003	55.028382999999998	0103000020E610000001000000050000008E76DCF0BBC154409561DC0DA2834B408E76DCF0BBC154402C11A8FE41844B40E014562AA8C254402C11A8FE41844B40E014562AA8C254409561DC0DA2834B408E76DCF0BBC154409561DC0DA2834B40
5332	Татарск	5	52	\N	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
15154	Обь	5	52	\N	82.673168000000004	82.726528000000002	55.006341999999997	54.992595999999999	0103000020E61000000100000005000000AE2D3C2F15AB5440F911BF620D7F4B40AE2D3C2F15AB5440AD4B8DD0CF804B4036E84B6F7FAE5440AD4B8DD0CF804B4036E84B6F7FAE5440F911BF620D7F4B40AE2D3C2F15AB5440F911BF620D7F4B40
65	Новосибирск	5	52	\N	82.751105999999993	83.160629999999998	55.199686	54.803927000000002	0103000020E610000001000000050000001475E61E12B054408AAF7614E7664B401475E61E12B054400ABC934F8F994B406A300DC347CA54400ABC934F8F994B406A300DC347CA54408AAF7614E7664B401475E61E12B054408AAF7614E7664B40
13294	Новолуговое	5	52	\N	83.096975999999998	83.141253000000006	54.992120999999997	54.967409000000004	0103000020E61000000100000005000000CD1FD3DA34C65440946DE00ED47B4B40CD1FD3DA34C65440605628D2FD7E4B4090DD054A0AC95440605628D2FD7E4B4090DD054A0AC95440946DE00ED47B4B40CD1FD3DA34C65440946DE00ED47B4B40
59203	Николо-Гавриловка	5	52	\N	75.264662999999999	75.276898000000003	55.704169	55.697980000000001	0103000020E61000000100000005000000855D143DF0D052408CA19C6857D94B40855D143DF0D05240B3EDB43522DA4B40FB9463B2B8D15240B3EDB43522DA4B40FB9463B2B8D152408CA19C6857D94B40855D143DF0D052408CA19C6857D94B40
59110	Купино	5	52	\N	77.252302999999998	77.344882999999996	54.387348000000003	54.326721999999997	0103000020E61000000100000005000000B16B7BBB255053401D71C806D2294B40B16B7BBB25505340E415889E94314B40917C259012565340E415889E94314B40917C2590125653401D71C806D2294B40B16B7BBB255053401D71C806D2294B40
14082	Куйбышев	5	52	\N	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
41205	Краснообск	5	52	\N	82.975774999999999	82.995654999999999	54.926859999999998	54.915782	0103000020E610000001000000050000004850FC1873BE5440FB21365838754B404850FC1873BE54403BFC3559A3764B4054C6BFCFB8BF54403BFC3559A3764B4054C6BFCFB8BF5440FB21365838754B404850FC1873BE5440FB21365838754B40
26706	Искитим	5	52	\N	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
25298	Бердск	5	52	\N	83.038747000000001	83.130599000000004	54.821728	54.730812	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
16965	Барабинск	5	52	\N	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
41268	Озерный	5	52	6941	82.937740000000005	82.945635999999993	55.136648000000001	55.129086999999998	0103000020E61000000100000005000000AB09A2EE03BC54405CAB3DEC85904B40AB09A2EE03BC54402B8881AE7D914B40E57ADB4C85BC54402B8881AE7D914B40E57ADB4C85BC54405CAB3DEC85904B40AB09A2EE03BC54405CAB3DEC85904B40
40313	Куйбышев	5	52	6896	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
25214	Мичуринский	5	52	1771	83.116658000000001	83.124697999999995	54.742745999999997	54.736503999999996	0103000020E6100000010000000500000046B41D5377C75440C4AF58C3455E4B4046B41D5377C754400E9E094D125F4B401AF8510DFBC754400E9E094D125F4B401AF8510DFBC75440C4AF58C3455E4B4046B41D5377C75440C4AF58C3455E4B40
41374	Бердск	5	52	1771	83.038747000000001	83.130599000000004	54.821728	54.730812	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
28664	Агролес	5	52	1771	83.124499999999998	83.152321000000001	54.762127	54.733193	0103000020E610000001000000050000008716D9CEF7C75440FC53AA44D95D4B408716D9CEF7C754400533A6608D614B409E5F94A0BFC954400533A6608D614B409E5F94A0BFC95440FC53AA44D95D4B408716D9CEF7C75440FC53AA44D95D4B40
41301	Барабинск	5	52	6939	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
34154	Мокрушино	5	52	2649	84.852652000000006	84.875208999999998	54.761805000000003	54.743031999999999	0103000020E610000001000000050000009EB7B1D991365540D4F02DAC1B5F4B409EB7B1D991365540F37684D382614B408D0A9C6C03385540F37684D382614B408D0A9C6C03385540D4F02DAC1B5F4B409EB7B1D991365540D4F02DAC1B5F4B40
38649	Залесный	5	52	5877	81.079826999999995	81.099913000000001	55.017349000000003	55.006661999999999	0103000020E610000001000000050000009E95B4E21B4554401F10E84CDA804B409E95B4E21B45544025CFF57D38824B407FDC7EF96446544025CFF57D38824B407FDC7EF9644654401F10E84CDA804B409E95B4E21B4554401F10E84CDA804B40
35929	Малинино	5	52	3985	76.272374999999997	76.296091000000004	55.561838000000002	55.554023000000001	0103000020E61000000100000005000000DF4F8D976E115340AC1DC539EAC64B40DF4F8D976E11534035D3BD4EEAC74B40F568AA27F312534035D3BD4EEAC74B40F568AA27F3125340AC1DC539EAC64B40DF4F8D976E115340AC1DC539EAC64B40
15860	Чулым	5	52	1423	80.926851999999997	80.990480000000005	55.111638999999997	55.058425	0103000020E61000000100000005000000DC0E0D8B513B544068226C787A874B40DC0E0D8B513B5440A4FACE2F4A8E4B40E5D53906643F5440A4FACE2F4A8E4B40E5D53906643F544068226C787A874B40DC0E0D8B513B544068226C787A874B40
42883	Чикман	5	52	1423	81.319766999999999	81.351260999999994	54.782302999999999	54.761592	0103000020E61000000100000005000000C3D50110775454409772BED87B614B40C3D50110775454400648348122644B400ED76A0F7B5654400648348122644B400ED76A0F7B5654409772BED87B614B40C3D50110775454409772BED87B614B40
24502	Филимоновский	5	52	1423	81.061419999999998	81.077814000000004	54.936450000000001	54.926797000000001	0103000020E6100000010000000500000080D4264EEE435440F583BA48A1764B4080D4264EEE4354406B2BF697DD774B40F14A92E7FA4454406B2BF697DD774B40F14A92E7FA445440F583BA48A1764B4080D4264EEE435440F583BA48A1764B40
24689	Ужаниха	5	52	1423	81.016693000000004	81.055491000000004	54.687539999999998	54.662188	0103000020E610000001000000050000009E44847F11415440DEE68D93C2544B409E44847F114154408E588B4F01584B403B8E1F2A8D4354408E588B4F01584B403B8E1F2A8D435440DEE68D93C2544B409E44847F11415440DEE68D93C2544B40
24853	Серебрянское	5	52	1423	80.685025999999993	80.717247999999998	54.880457999999997	54.86815	0103000020E6100000010000000500000038BA4A77D72B5440DE02098A1F6F4B4038BA4A77D72B544033C005D9B2704B40C5C72764E72D544033C005D9B2704B40C5C72764E72D5440DE02098A1F6F4B4038BA4A77D72B5440DE02098A1F6F4B40
25124	Секты	5	52	1423	81.420197999999999	81.440068999999994	55.147005999999998	55.140796000000002	0103000020E610000001000000050000000EF62686E45A54402DB4739A05924B400EF62686E45A54406B28B517D1924B40F0BE2A172A5C54406B28B517D1924B40F0BE2A172A5C54402DB4739A05924B400EF62686E45A54402DB4739A05924B40
24046	Пенек	5	52	1423	81.541775999999999	81.575220000000002	55.506729	55.482281	0103000020E610000001000000050000007E703E75AC625440B83D4162BBBD4B407E703E75AC625440A777F17EDCC04B4054008C67D0645440A777F17EDCC04B4054008C67D0645440B83D4162BBBD4B407E703E75AC625440B83D4162BBBD4B40
41370	Осиновский	5	52	1423	81.464260999999993	81.487050999999994	54.828066	54.814875000000001	0103000020E61000000100000005000000BAF3C473B65D5440FCA9F1D24D684B40BAF3C473B65D5440FB761211FE694B40FB1EF5D72B5F5440FB761211FE694B40FB1EF5D72B5F5440FCA9F1D24D684B40BAF3C473B65D5440FCA9F1D24D684B40
24349	Новоиткульское	5	52	1423	81.050765999999996	81.073682000000005	55.055675999999998	55.043995000000002	0103000020E61000000100000005000000EB6F09C03F4354400118CFA0A1854B40EB6F09C03F4354400796236420874B407313B534B74454400796236420874B407313B534B74454400118CFA0A1854B40EB6F09C03F4354400118CFA0A1854B40
25062	Кузнецкий	5	52	1423	81.295259999999999	81.312275	55.181590999999997	55.175134	0103000020E6100000010000000500000049F4328AE5525440763579CA6A964B4049F4328AE5525440BC1FB75F3E974B40F0164850FC535440BC1FB75F3E974B40F0164850FC535440763579CA6A964B4049F4328AE5525440763579CA6A964B40
24904	Кокошишо	5	52	1423	80.605911000000006	80.644350000000003	55.160710000000002	55.130873000000001	0103000020E610000001000000050000005952EE3EC7265440F7764B72C0904B405952EE3EC7265440F111312592944B405E4BC8073D295440F111312592944B405E4BC8073D295440F7764B72C0904B405952EE3EC7265440F7764B72C0904B40
25013	Кабинетное	5	52	1423	81.270223999999999	81.319739999999996	55.105671000000001	55.083162999999999	0103000020E6100000010000000500000009A69A594B5154405E9ECE15A58A4B4009A69A594B5154405C9198A0868D4B4046CEC29E765454405C9198A0868D4B4046CEC29E765454405E9ECE15A58A4B4009A69A594B5154405E9ECE15A58A4B40
41279	Иткуль	5	52	1423	81.011185999999995	81.047999000000004	55.086399	55.071581999999999	0103000020E61000000100000005000000130B7C45B7405440BB7D569929894B40130B7C45B74054401CB4571F0F8B4B4068CF656A124354401CB4571F0F8B4B4068CF656A12435440BB7D569929894B40130B7C45B7405440BB7D569929894B40
25199	Илюшино	5	52	1423	81.370547999999999	81.390383	55.026251999999999	55.019883	0103000020E610000001000000050000004966F50EB7575440895FB1868B824B404966F50EB757544030BABC395C834B40857AFA08FC58544030BABC395C834B40857AFA08FC585440895FB1868B824B404966F50EB7575440895FB1868B824B40
41280	Золотая Грива	5	52	1423	80.672754999999995	80.702202	55.001916999999999	54.985374	0103000020E610000001000000050000001CCEFC6A0E2B5440132A38BC207E4B401CCEFC6A0E2B54403927F6D03E804B40E44BA8E0F02C54403927F6D03E804B40E44BA8E0F02C5440132A38BC207E4B401CCEFC6A0E2B5440132A38BC207E4B40
48934	Воздвиженский	5	52	1423	80.724857	80.748564000000002	54.656902000000002	54.637517000000003	0103000020E61000000100000005000000B5519D0E642E544070D234289A514B40B5519D0E642E5440A8565F5D15544B40A1BDFA78E82F5440A8565F5D15544B40A1BDFA78E82F544070D234289A514B40B5519D0E642E544070D234289A514B40
24220	Большеникольское	5	52	1423	81.455950999999999	81.486575000000002	54.611694999999997	54.598287999999997	0103000020E6100000010000000500000006651A4D2E5D54406CCB80B3944C4B4006651A4D2E5D5440381092054C4E4B404703780B245F5440381092054C4E4B404703780B245F54406CCB80B3944C4B4006651A4D2E5D54406CCB80B3944C4B40
24152	Базово	5	52	1423	81.209885	81.259794999999997	54.544581999999998	54.525891000000001	0103000020E61000000100000005000000F1BA7EC16E4D54406021736550434B40F1BA7EC16E4D5440C1FEEBDCB4454B40842A357BA0505440C1FEEBDCB4454B40842A357BA05054406021736550434B40F1BA7EC16E4D54406021736550434B40
41378	Алексеевка	5	52	1423	81.126008999999996	81.154629	54.520885	54.502293000000002	0103000020E610000001000000050000001B800D88104854403F0114234B404B401B800D88104854400DFD135CAC424B40D8800871E54954400DFD135CAC424B40D8800871E54954403F0114234B404B401B800D88104854403F0114234B404B40
23246	Яминка	5	52	1609	75.948729999999998	75.958702000000002	54.714599	54.707920000000001	0103000020E61000000100000005000000FBAE08FEB7FC52409817601F9D5A4B40FBAE08FEB7FC52408D60E3FA775B4B400727A25F5BFD52408D60E3FA775B4B400727A25F5BFD52409817601F9D5A4B40FBAE08FEB7FC52409817601F9D5A4B40
23399	Яблоневка	5	52	1609	76.504078000000007	76.534188999999998	54.713828999999997	54.704321	0103000020E6100000010000000500000085285FD0422053406971C630275A4B4085285FD042205340DBF7A8BF5E5B4B4082380F2730225340DBF7A8BF5E5B4B4082380F27302253406971C630275A4B4085285FD0422053406971C630275A4B40
41299	Юдино	5	52	1609	76.733785999999995	76.753997999999996	54.761181000000001	54.753704999999997	0103000020E61000000100000005000000CF108E59F62E534074EACA6779604B40CF108E59F62E534015AB06616E614B40F6CFD3804130534015AB06616E614B40F6CFD3804130534074EACA6779604B40CF108E59F62E534074EACA6779604B40
41306	Шипицыно	5	52	1609	76.830157	76.865191999999993	54.528722999999999	54.514290000000003	0103000020E61000000100000005000000E962D34A2135534076543541D4414B40E962D34A213553404ED2FC31AD434B40B130444E5F3753404ED2FC31AD434B40B130444E5F37534076543541D4414B40E962D34A2135534076543541D4414B40
20954	Чистоозерное	5	52	1609	76.544321999999994	76.607043000000004	54.719940000000001	54.695768000000001	0103000020E61000000100000005000000921FF12BD62253403ACD02ED0E594B40921FF12BD6225340878A71FE265C4B400211E2CAD9265340878A71FE265C4B400211E2CAD92653403ACD02ED0E594B40921FF12BD62253403ACD02ED0E594B40
22685	Чебаклы	5	52	1609	76.901608999999993	76.915210000000002	54.650343999999997	54.643728000000003	0103000020E61000000100000005000000DF313CF6B33953407FC2D9AD65524B40DF313CF6B33953402D93E1783E534B4038BEF6CC923A53402D93E1783E534B4038BEF6CC923A53407FC2D9AD65524B40DF313CF6B33953407FC2D9AD65524B40
21392	Чаячье	5	52	1609	76.325851999999998	76.342211000000006	54.705356000000002	54.69699	0103000020E6100000010000000500000084D558C2DA145340CCD1E3F736594B4084D558C2DA145340C904FC1A495A4B403755F7C8E6155340C904FC1A495A4B403755F7C8E6155340CCD1E3F736594B4084D558C2DA145340CCD1E3F736594B40
22419	Цветнополье	5	52	1609	76.094204000000005	76.116400999999996	54.430207000000003	54.421883999999999	0103000020E61000000100000005000000C1C9367007065340535A7F4B00364B40C1C936700706534051C1E10511374B40300E2E1D7307534051C1E10511374B40300E2E1D73075340535A7F4B00364B40C1C9367007065340535A7F4B00364B40
41237	Троицкое	5	52	1609	76.704699000000005	76.736652000000007	54.954366999999998	54.944325999999997	0103000020E6100000010000000500000088A1D5C9192D53409961A3ACDF784B4088A1D5C9192D5340D9B0A6B2287A4B401D226E4E252F5340D9B0A6B2287A4B401D226E4E252F53409961A3ACDF784B4088A1D5C9192D53409961A3ACDF784B40
19888	Табулгинский	5	52	1609	76.301822000000001	76.316311999999996	54.905783	54.898969999999998	0103000020E61000000100000005000000A7CD380D51135340E50AEF7211734B40A7CD380D51135340EA2285B2F0734B4045D5AF743E145340EA2285B2F0734B4045D5AF743E145340E50AEF7211734B40A7CD380D51135340E50AEF7211734B40
21570	Табулга	5	52	1609	76.316609	76.355326000000005	54.912692	54.896853	0103000020E61000000100000005000000A227655243145340E5284014CC724B40A22765524314534011A96917D3744B40C95A43A9BD16534011A96917D3744B40C95A43A9BD165340E5284014CC724B40A227655243145340E5284014CC724B40
22077	Старый Кошкуль	5	52	1609	76.649883000000003	76.665926999999996	54.973573999999999	54.963067000000002	0103000020E610000001000000050000007DCEDDAE97295340AD6D8AC7457B4B407DCEDDAE97295340321EA5129E7C4B407FA1478C9E2A5340321EA5129E7C4B407FA1478C9E2A5340AD6D8AC7457B4B407DCEDDAE97295340AD6D8AC7457B4B40
49311	Романовка	5	52	1609	76.027907999999996	76.065089	54.656516000000003	54.642467000000003	0103000020E61000000100000005000000FED2A23EC90153402FE1D05B3C524B40FED2A23EC90153407FA65EB708544B4014950D6B2A0453407FA65EB708544B4014950D6B2A0453402FE1D05B3C524B40FED2A23EC90153402FE1D05B3C524B40
22943	Польяново	5	52	1609	75.888982999999996	75.918268999999995	54.566443	54.555689000000001	0103000020E61000000100000005000000CCECF318E5F852409CDF30D120474B40CCECF318E5F852402906483481484B408FFB56EBC4FA52402906483481484B408FFB56EBC4FA52409CDF30D120474B40CCECF318E5F852409CDF30D120474B40
59167	Покровка	5	52	1609	76.458641	76.487296999999998	54.832872999999999	54.823605000000001	0103000020E61000000100000005000000B4E6C75F5A1D53403AE97DE36B694B40B4E6C75F5A1D5340575C1C959B6A4B40179CC1DF2F1F5340575C1C959B6A4B40179CC1DF2F1F53403AE97DE36B694B40B4E6C75F5A1D53403AE97DE36B694B40
41218	Павловка	5	52	1609	76.204076999999998	76.240960999999999	54.496814000000001	54.486606000000002	0103000020E610000001000000050000006937FA980F0D5340C904FC1A493E4B406937FA980F0D5340F418E599973F4B4022A7AFE76B0F5340F418E599973F4B4022A7AFE76B0F5340C904FC1A493E4B406937FA980F0D5340C904FC1A493E4B40
47305	Ольховка	5	52	1609	76.617076999999995	76.626751999999996	54.750275999999999	54.744231999999997	0103000020E61000000100000005000000488787307E2753407E5182FE425F4B40488787307E275340A27C410B09604B40F7AC6BB41C285340A27C410B09604B40F7AC6BB41C2853407E5182FE425F4B40488787307E2753407E5182FE425F4B40
49677	Ольгино	5	52	1609	76.158460000000005	76.188590000000005	54.786622999999999	54.774244000000003	0103000020E61000000100000005000000596E6935240A5340E78F696D1A634B40596E6935240A534005A4FD0FB0644B409296CADB110C534005A4FD0FB0644B409296CADB110C5340E78F696D1A634B40596E6935240A5340E78F696D1A634B40
22772	Олтарь	5	52	1609	76.640478000000002	76.660186999999993	54.543484999999997	54.533549999999998	0103000020E61000000100000005000000AEF36F97FD285340F163CC5D4B444B40AEF36F97FD285340EB6E9EEA90454B40A38FF980402A5340EB6E9EEA90454B40A38FF980402A5340F163CC5D4B444B40AEF36F97FD285340F163CC5D4B444B40
49678	Новопокровка	5	52	1609	77.049086000000003	77.066126999999994	54.654812999999997	54.637413000000002	0103000020E61000000100000005000000412C9B3924435340CB85CABF96514B40412C9B392443534071FF91E9D0534B407C98BD6C3B44534071FF91E9D0534B407C98BD6C3B445340CB85CABF96514B40412C9B3924435340CB85CABF96514B40
47827	Новопесчаное	5	52	1609	76.688996000000003	76.711849000000001	54.848669999999998	54.832017	0103000020E61000000100000005000000CAC4AD82182C5340A75B76887F6A4B40CAC4AD82182C5340548CF337A16C4B402EAC1BEF8E2D5340548CF337A16C4B402EAC1BEF8E2D5340A75B76887F6A4B40CAC4AD82182C5340A75B76887F6A4B40
41346	Новокрасное	5	52	1609	76.164254	76.213921999999997	54.343792999999998	54.326590000000003	0103000020E610000001000000050000002E8F3523830A5340AF997CB3CD294B402E8F3523830A5340FFCBB568012C4B404679E6E5B00D5340FFCBB568012C4B404679E6E5B00D5340AF997CB3CD294B402E8F3523830A5340AF997CB3CD294B40
45822	Новоалексеевка	5	52	1609	76.596442999999994	76.612199000000004	54.791849999999997	54.783419000000002	0103000020E6100000010000000500000066BB421F2C2653405308E41247644B4066BB421F2C26534036AB3E575B654B4036E9B6442E27534036AB3E575B654B4036E9B6442E2753405308E41247644B4066BB421F2C2653405308E41247644B40
21783	Новая Кулында	5	52	1609	76.359251999999998	76.394969000000003	54.927774999999997	54.913266999999998	0103000020E6100000010000000500000072C119FCFD1653400DC2DCEEE5744B4072C119FCFD165340F085C954C1764B40C47B0E2C47195340F085C954C1764B40C47B0E2C471953400DC2DCEEE5744B4072C119FCFD1653400DC2DCEEE5744B40
41224	Мухино	5	52	1609	76.072635000000005	76.097212999999996	54.525823000000003	54.521334000000003	0103000020E61000000100000005000000E162450DA60453407D259012BB424B40E162450DA6045340083E062B4E434B40BFEFDFBC38065340083E062B4E434B40BFEFDFBC380653407D259012BB424B40E162450DA60453407D259012BB424B40
41272	Мироновка	5	52	1609	76.134664000000001	76.154776999999996	54.520477	54.506585000000001	0103000020E61000000100000005000000B5FCC0559E08534074D2FBC6D7404B40B5FCC0559E085340FCA886FD9E424B40124BCADDE7095340FCA886FD9E424B40124BCADDE709534074D2FBC6D7404B40B5FCC0559E08534074D2FBC6D7404B40
60698	Малая Тахта	5	52	1609	76.238770000000002	76.258837999999997	54.603143000000003	54.595815000000002	0103000020E610000001000000050000000551F701480F5340AEBB79AA434C4B400551F701480F5340DAE731CA334D4B40923D42CD90105340DAE731CA334D4B40923D42CD90105340AEBB79AA434C4B400551F701480F5340AEBB79AA434C4B40
21865	Канавы	5	52	1609	77.014465000000001	77.032556999999997	54.693660000000001	54.687446999999999	0103000020E61000000100000005000000F27B9BFEEC405340DD5D6743FE574B40F27B9BFEEC4053408D45D3D9C9584B406090F469154253408D45D3D9C9584B406090F46915425340DD5D6743FE574B40F27B9BFEEC405340DD5D6743FE574B40
23224	Ишимская	5	52	1609	75.892342999999997	75.908036999999993	54.734777999999999	54.719945000000003	0103000020E610000001000000050000002174D0251CF9524099F56228275C4B402174D0251CF95240FFE89B340D5E4B40B5A338471DFA5240FFE89B340D5E4B40B5A338471DFA524099F56228275C4B402174D0251CF9524099F56228275C4B40
41208	Журавка	5	52	1609	76.556736999999998	76.583453000000006	54.631816000000001	54.612248000000001	0103000020E6100000010000000500000048DE3994A12353404D8578245E4E4B4048DE3994A1235340768BC058DF504B403370404B57255340768BC058DF504B403370404B572553404D8578245E4E4B4048DE3994A12353404D8578245E4E4B40
49676	Елизаветинка	5	52	1609	76.457824000000002	76.498570999999998	54.754235000000001	54.742299000000003	0103000020E61000000100000005000000BBD408FD4C1D5340406D54A7035F4B40BBD408FD4C1D5340D13FC1C58A604B40FAEE5696E81F5340D13FC1C58A604B40FAEE5696E81F5340406D54A7035F4B40BBD408FD4C1D5340406D54A7035F4B40
41342	Георгиевка (Юхлино)	5	52	1609	75.931203999999994	75.944436999999994	54.766126	54.753839999999997	0103000020E61000000100000005000000E179A9D898FB5240543541D47D604B40E179A9D898FB5240C24EB16A10624B407808E3A771FC5240C24EB16A10624B407808E3A771FC5240543541D47D604B40E179A9D898FB5240543541D47D604B40
41277	Варваровка	5	52	1609	76.246781999999996	76.272897	54.405275000000003	54.386251999999999	0103000020E6100000010000000500000074CFBA46CB0F5340DE019EB470314B4074CFBA46CB0F534076711B0DE0334B404C8BFA247711534076711B0DE0334B404C8BFA2477115340DE019EB470314B4074CFBA46CB0F5340DE019EB470314B40
22889	Бугриновка	5	52	1609	76.658372999999997	76.671766000000005	54.397570000000002	54.393062	0103000020E6100000010000000500000071E481C8222A534072A609DB4F324B4071E481C8222A534074EFE192E3324B402524D236FE2A534074EFE192E3324B402524D236FE2A534072A609DB4F324B4071E481C8222A534072A609DB4F324B40
23313	Большая Тахта	5	52	1609	76.064729999999997	76.083755999999994	54.706729000000003	54.698359000000004	0103000020E610000001000000050000007C444C892404534003EFE4D363594B407C444C892404534041118B18765A4B40003620425C05534041118B18765A4B40003620425C05534003EFE4D363594B407C444C892404534003EFE4D363594B40
22724	Барабо-Юдино	5	52	1609	76.719691999999995	76.740505999999996	54.547240000000002	54.537787000000002	0103000020E6100000010000000500000057CC086F0F2E5340639B5434D6444B4057CC086F0F2E53401288D7F50B464B40791F4773642F53401288D7F50B464B40791F4773642F5340639B5434D6444B4057CC086F0F2E5340639B5434D6444B40
37177	Тимофеевка	5	52	4853	21.883068000000002	21.896992000000001	54.650651000000003	54.641373000000002	0103000020E61000000100000005000000E62494BE10E23540CAC4AD8218524B40E62494BE10E235400B0E2F8848534B400DC68844A1E535400B0E2F8848534B400DC68844A1E53540CAC4AD8218524B40E62494BE10E23540CAC4AD8218524B40
39729	Доронино	5	52	2685	38.101548999999999	38.113352999999996	59.061933000000003	59.052619	0103000020E6100000010000000500000083F8C08EFF0C4340F9122A38BC864D4083F8C08EFF0C434087C5A86BED874D40A5F3E159820E434087C5A86BED874D40A5F3E159820E4340F9122A38BC864D4083F8C08EFF0C4340F9122A38BC864D40
18675	Ясная Поляна	5	52	1505	83.823307999999997	83.853365999999994	54.269097000000002	54.256901999999997	0103000020E6100000010000000500000040A20914B1F4544074232C2AE2204B4040A20914B1F45440D2393FC571224B402C616D8C9DF65440D2393FC571224B402C616D8C9DF6544074232C2AE2204B4040A20914B1F4544074232C2AE2204B40
19875	Ярки	5	52	1505	83.268994000000006	83.296661999999998	54.157649999999997	54.134054999999996	0103000020E610000001000000050000007F349C3237D15440C16ED8B628114B407F349C3237D15440711B0DE02D144B40D2FD9C82FCD25440711B0DE02D144B40D2FD9C82FCD25440C16ED8B628114B407F349C3237D15440C16ED8B628114B40
19566	Южный	5	52	1505	83.414529999999999	83.433368000000002	54.016755000000003	54.007088000000003	0103000020E610000001000000050000007F4DD6A887DA5440D7187442E8004B407F4DD6A887DA5440B285200725024B4082C8224DBCDB5440B285200725024B4082C8224DBCDB5440D7187442E8004B407F4DD6A887DA5440D7187442E8004B40
19985	Шурыгино	5	52	1505	82.845096999999996	82.885997000000003	54.084215	54.066332000000003	0103000020E61000000100000005000000A73CBA1116B65440D25625917D084B40A73CBA1116B65440946A9F8EC70A4B40AAD6C22CB4B85440946A9F8EC70A4B40AAD6C22CB4B85440D25625917D084B40A73CBA1116B65440D25625917D084B40
17523	Черепаново	5	52	1505	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
20638	Чащино	5	52	1505	82.947927000000007	82.968975	54.065963000000004	54.052143000000001	0103000020E61000000100000005000000B5FF01D6AABC544090DB2F9FAC064B40B5FF01D6AABC54407FDFBF7971084B4010E9B7AF03BE54407FDFBF7971084B4010E9B7AF03BE544090DB2F9FAC064B40B5FF01D6AABC544090DB2F9FAC064B40
18988	Татарка	5	52	1505	83.71163	83.741876000000005	54.193469999999998	54.184314000000001	0103000020E610000001000000050000008F368E588BED5440F418E59997174B408F368E588BED5440E960FD9FC3184B40FD6B79E57AEF5440E960FD9FC3184B40FD6B79E57AEF5440F418E59997174B408F368E588BED5440F418E59997174B40
20197	Семеновский	5	52	1505	83.026610000000005	83.045681999999999	54.261941	54.254866999999997	0103000020E61000000100000005000000C8EF6DFAB3C1544031EA5A7B9F204B40C8EF6DFAB3C15440A33D5E4887214B4004013274ECC25440A33D5E4887214B4004013274ECC2544031EA5A7B9F204B40C8EF6DFAB3C1544031EA5A7B9F204B40
19185	Романово	5	52	1505	83.454252999999994	83.473262000000005	54.210039000000002	54.179239000000003	0103000020E6100000010000000500000008C72C7B12DD54407995B54DF1164B4008C72C7B12DD544039F1D58EE21A4B40221CB3EC49DE544039F1D58EE21A4B40221CB3EC49DE54407995B54DF1164B4008C72C7B12DD54407995B54DF1164B40
20781	Пятилетка	5	52	1505	83.321697999999998	83.338425000000001	54.249164999999998	54.237053000000003	0103000020E61000000100000005000000124C35B396D454409835B1C0571E4B40124C35B396D45440672783A3E41F4B4086C954C1A8D55440672783A3E41F4B4086C954C1A8D554409835B1C0571E4B40124C35B396D454409835B1C0571E4B40
19671	Пушной	5	52	1505	83.394614000000004	83.417665	54.242041	54.231012	0103000020E61000000100000005000000CD22145B41D95440E57D1CCD911D4B40CD22145B41D9544044A51133FB1E4B40C4EBFA05BBDA544044A51133FB1E4B40C4EBFA05BBDA5440E57D1CCD911D4B40CD22145B41D95440E57D1CCD911D4B40
19355	Привольный	5	52	1505	83.360001999999994	83.375274000000005	54.125075000000002	54.116647999999998	0103000020E61000000100000005000000A71FD4450AD7544068925852EE0E4B40A71FD4450AD754400B46257502104B4081423D7D04D854400B46257502104B4081423D7D04D8544068925852EE0E4B40A71FD4450AD7544068925852EE0E4B40
18125	Посевная	5	52	1505	83.309122000000002	83.360568000000001	54.31259	54.288017000000004	0103000020E61000000100000005000000581EA4A7C8D3544095D8B5BDDD244B40581EA4A7C8D354404087F9F202284B40FCFECD8B13D754404087F9F202284B40FCFECD8B13D7544095D8B5BDDD244B40581EA4A7C8D3544095D8B5BDDD244B40
18516	Падун	5	52	1505	83.611243000000002	83.619264999999999	54.345719000000003	54.342292	0103000020E610000001000000050000002CBAF59A1EE754405AD76839D02B4B402CBAF59A1EE754408C4D2B85402C4B40ADA3AA09A2E754408C4D2B85402C4B40ADA3AA09A2E754405AD76839D02B4B402CBAF59A1EE754405AD76839D02B4B40
19782	Отважный	5	52	1505	83.317565999999999	83.332657999999995	54.198794999999997	54.187032000000002	0103000020E610000001000000050000009414580053D454401AA721AAF0174B409414580053D45440DDCD531D72194B402DB0C7444AD55440DDCD531D72194B402DB0C7444AD554401AA721AAF0174B409414580053D454401AA721AAF0174B40
49607	Огнева Заимка	5	52	1505	83.722463000000005	83.754757999999995	54.302329999999998	54.279159999999997	0103000020E610000001000000050000007C6473D53CEE5440F92CCF83BB234B407C6473D53CEE5440C24CDBBFB2264B403D997FF44DF05440C24CDBBFB2264B403D997FF44DF05440F92CCF83BB234B407C6473D53CEE5440F92CCF83BB234B40
60692	Новошмаково	5	52	1505	83.678967	83.696745000000007	54.240499	54.231490000000001	0103000020E610000001000000050000000C04013274EB5440EFACDD76A11D4B400C04013274EB544040DCD5ABC81E4B40B329577897EC544040DCD5ABC81E4B40B329577897EC5440EFACDD76A11D4B400C04013274EB5440EFACDD76A11D4B40
60617	Нововоскресенка	5	52	1505	83.049274999999994	83.073260000000005	54.100749	54.087516000000001	0103000020E61000000100000005000000AA60545227C3544039F06AB9330B4B40AA60545227C35440670DDE57E50C4B40B806B64AB0C45440670DDE57E50C4B40B806B64AB0C4544039F06AB9330B4B40AA60545227C3544039F06AB9330B4B40
59165	Медведск	5	52	1505	82.637793000000002	84.011495999999994	54.481395999999997	53.934466999999998	0103000020E610000001000000050000008927BB99D1A854407A185A9D9CF74A408927BB99D1A854406D3656629E3D4B403A02B859BC0055406D3656629E3D4B403A02B859BC0055407A185A9D9CF74A408927BB99D1A854407A185A9D9CF74A40
19686	Майский	5	52	1505	83.345332999999997	83.371177000000003	54.194555000000001	54.183090999999997	0103000020E61000000100000005000000B14E95EF19D654409198A0866F174B40B14E95EF19D65440FB22A12DE7184B40C1012D5DC1D75440FB22A12DE7184B40C1012D5DC1D754409198A0866F174B40B14E95EF19D654409198A0866F174B40
18754	Лихановский	5	52	1505	83.618860999999995	83.634553999999994	54.306150000000002	54.297097000000001	0103000020E6100000010000000500000045F12A6B9BE75440AF5E454607264B4045F12A6B9BE75440D0D556EC2F274B40F16261889CE85440D0D556EC2F274B40F16261889CE85440AF5E454607264B4045F12A6B9BE75440AF5E454607264B40
18842	Листвянка	5	52	1505	83.708736999999999	83.724538999999993	54.158208000000002	54.142299000000001	0103000020E61000000100000005000000C51D6FF25BED544073A087DA36124B40C51D6FF25BED544098FBE42840144B404C6BD3D85EEE544098FBE42840144B404C6BD3D85EEE544073A087DA36124B40C51D6FF25BED544073A087DA36124B40
20409	Куриловка	5	52	1505	82.745078000000007	82.768066000000005	54.221327000000002	54.212266	0103000020E6100000010000000500000006BEA25BAFAF5440C00644882B1B4B4006BEA25BAFAF5440645C7171541C4B40DACA4BFE27B15440645C7171541C4B40DACA4BFE27B15440C00644882B1B4B4006BEA25BAFAF5440C00644882B1B4B40
19117	Крутишка	5	52	1505	83.132988999999995	83.156317999999999	54.186584000000003	54.175271000000002	0103000020E61000000100000005000000936E4BE482C85440F777B6476F164B40936E4BE482C854407BFA08FCE1174B40AC71361D01CA54407BFA08FCE1174B40AC71361D01CA5440F777B6476F164B40936E4BE482C85440F777B6476F164B40
20573	Карасево	5	52	1505	82.977678999999995	83.014887000000002	54.179735000000001	54.166195000000002	0103000020E610000001000000050000001ABFF04A92BE54401EE1B4E045154B401ABFF04A92BE54402979758E01174B40AD889AE8F3C054402979758E01174B40AD889AE8F3C054401EE1B4E045154B401ABFF04A92BE54401EE1B4E045154B40
19976	Карагужево	5	52	1505	83.114644999999996	83.134929	54.165056999999997	54.145088999999999	0103000020E610000001000000050000009869FB5756C754403201BF4692124B409869FB5756C75440E97C789620154B400C923EADA2C85440E97C789620154B400C923EADA2C854403201BF4692124B409869FB5756C754403201BF4692124B40
19029	Искра	5	52	1505	83.399743999999998	83.421527999999995	54.191257	54.180408999999997	0103000020E610000001000000050000006CB1DB6795D95440B87361A417174B406CB1DB6795D95440C710001C7B184B404A969350FADA5440C710001C7B184B404A969350FADA5440B87361A417174B406CB1DB6795D95440B87361A417174B40
20888	Инской	5	52	1505	83.215832000000006	83.233132999999995	54.225864000000001	54.218004999999998	0103000020E610000001000000050000008A5B0531D0CD5440A7AE7C96E71B4B408A5B0531D0CD544000AC8E1CE91C4B4093A7ACA6EBCE544000AC8E1CE91C4B4093A7ACA6EBCE5440A7AE7C96E71B4B408A5B0531D0CD5440A7AE7C96E71B4B40
19258	Зимовье	5	52	1505	83.532370999999998	83.551811000000001	54.238405	54.222831999999997	0103000020E61000000100000005000000AF95D05D12E254404A404CC2851C4B40AF95D05D12E25440F819170E841E4B40ADA415DF50E35440F819170E841E4B40ADA415DF50E354404A404CC2851C4B40AF95D05D12E254404A404CC2851C4B40
19459	Еловкино	5	52	1505	83.290796	83.301782000000003	54.103715999999999	54.095399999999998	0103000020E61000000100000005000000B073D3669CD25440EA043411360C4B40B073D3669CD254403509DE90460D4B406021736550D354403509DE90460D4B406021736550D35440EA043411360C4B40B073D3669CD25440EA043411360C4B40
18296	Дорогино	5	52	1505	83.306436000000005	83.335047000000003	54.372031	54.353853000000001	0103000020E610000001000000050000004B94BDA59CD35440B64B1B0E4B2D4B404B94BDA59CD35440910C39B69E2F4B40DEE7F86871D55440910C39B69E2F4B40DEE7F86871D55440B64B1B0E4B2D4B404B94BDA59CD35440B64B1B0E4B2D4B40
18207	Дорогина Заимка	5	52	1505	83.177456000000006	83.191046999999998	54.351906	54.337494999999997	0103000020E61000000100000005000000A81E69705BCB544021C84109332B4B40A81E69705BCB544012A27C410B2D4B40EE3F321D3ACC544012A27C410B2D4B40EE3F321D3ACC544021C84109332B4B40A81E69705BCB544021C84109332B4B40
20841	Грибной	5	52	1505	83.237561999999997	83.255788999999993	54.290622999999997	54.283622999999999	0103000020E610000001000000050000006E313F3734CF54405BB22AC24D244B406E313F3734CF5440923B6C2233254B404C6BD3D85ED05440923B6C2233254B404C6BD3D85ED054405BB22AC24D244B406E313F3734CF54405BB22AC24D244B40
18564	Высокая Поляна	5	52	1505	83.521618000000004	83.539010000000005	54.33287	54.328712000000003	0103000020E6100000010000000500000051C0763062E15440C1E61C3C132A4B4051C0763062E15440E6E8F17B9B2A4B40E38DCC237FE25440E6E8F17B9B2A4B40E38DCC237FE25440C1E61C3C132A4B4051C0763062E15440C1E61C3C132A4B40
20104	Виноград	5	52	1505	82.872217000000006	82.882690999999994	54.026947999999997	54.010221000000001	0103000020E61000000100000005000000FA804067D2B75440C05DF6EB4E014B40FA804067D2B75440A758350873034B404E5E64027EB85440A758350873034B404E5E64027EB85440C05DF6EB4E014B40FA804067D2B75440C05DF6EB4E014B40
20316	Верх-Мильтюши	5	52	1505	82.891880999999998	82.920366999999999	54.311844000000001	54.281179000000002	0103000020E610000001000000050000001FBB0B9414B9544037A968ACFD234B401FBB0B9414B9544017BA1281EA274B405454FD4AE7BA544017BA1281EA274B405454FD4AE7BA544037A968ACFD234B401FBB0B9414B9544037A968ACFD234B40
18832	Бураново	5	52	1505	83.883872999999994	83.910704999999993	54.214514000000001	54.193111999999999	0103000020E6100000010000000500000050340F6091F854408A3BDEE4B7184B4050340F6091F854405F44DB31751B4B406FD39FFD48FA54405F44DB31751B4B406FD39FFD48FA54408A3BDEE4B7184B4050340F6091F854408A3BDEE4B7184B40
19571	Бочкарево	5	52	1505	83.452923999999996	83.483960999999994	54.255870999999999	54.245891999999998	0103000020E61000000100000005000000B4E4F1B4FCDC54408C2C9963791F4B40B4E4F1B4FCDC5440567F8461C0204B4086E28E37F9DE5440567F8461C0204B4086E28E37F9DE54408C2C9963791F4B40B4E4F1B4FCDC54408C2C9963791F4B40
59122	Безменово	5	52	1505	83.471958999999998	83.488425000000007	54.128067000000001	54.119233000000001	0103000020E610000001000000050000006283859334DE54404FCDE506430F4B406283859334DE54403259DC7F64104B402063EE5A42DF54403259DC7F64104B402063EE5A42DF54404FCDE506430F4B406283859334DE54404FCDE506430F4B40
19088	Безменово	5	52	1505	83.471958999999998	83.488425000000007	54.128067000000001	54.119233000000001	0103000020E610000001000000050000006283859334DE54404FCDE506430F4B406283859334DE54403259DC7F64104B402063EE5A42DF54403259DC7F64104B402063EE5A42DF54404FCDE506430F4B406283859334DE54404FCDE506430F4B40
19765	Бариново	5	52	1505	83.295845	83.304728999999995	54.176456999999999	54.171787000000002	0103000020E61000000100000005000000D9EBDD1FEFD254406170CD1DFD154B40D9EBDD1FEFD254403C139A2496164B40234910AE80D354403C139A2496164B40234910AE80D354406170CD1DFD154B40D9EBDD1FEFD254406170CD1DFD154B40
60677	курортный поселок Озеро-Карачи	5	52	467	76.202692999999996	77.848091999999994	55.608795000000001	54.722195999999997	0103000020E6100000010000000500000033880FECF80C5340A8A624EB705C4B4033880FECF80C5340F27B9BFEECCD4B40F3FFAA2347765340F27B9BFEECCD4B40F3FFAA2347765340A8A624EB705C4B4033880FECF80C5340A8A624EB705C4B40
15138	Юрки	5	52	467	76.857951	76.877301000000003	55.061163000000001	55.052995000000003	0103000020E6100000010000000500000083A44FABE8365340FFEC478AC8864B4083A44FABE8365340D55C6E30D4874B40E1EF17B325385340D55C6E30D4874B40E1EF17B325385340FFEC478AC8864B4083A44FABE8365340FFEC478AC8864B40
41324	Щеглово	5	52	467	76.552991000000006	76.575655999999995	55.355316000000002	55.346255999999997	0103000020E61000000100000005000000DFFE5C34642353409A05DA1D52AC4B40DFFE5C34642353406EDFA3FE7AAD4B40C16F438CD72453406EDFA3FE7AAD4B40C16F438CD72453409A05DA1D52AC4B40DFFE5C34642353409A05DA1D52AC4B40
47886	Черниговка	5	52	467	76.946561000000003	76.965892999999994	55.039605000000002	55.027861999999999	0103000020E61000000100000005000000D2AA9674943C53408C6665FB90834B40D2AA9674943C534009E1D1C611854B40DC9BDF30D13D534009E1D1C611854B40DC9BDF30D13D53408C6665FB90834B40D2AA9674943C53408C6665FB90834B40
14422	Чаны	5	52	467	76.728729000000001	76.800486000000006	55.322029999999998	55.295406	0103000020E6100000010000000500000065A9F57EA32E5340668522DDCFA54B4065A9F57EA32E53405A2A6F4738A94B40FAB9A1293B3353405A2A6F4738A94B40FAB9A1293B335340668522DDCFA54B4065A9F57EA32E5340668522DDCFA54B40
17107	Тебисское	5	52	467	77.445836	77.474546000000004	55.348094000000003	55.333804000000001	0103000020E6100000010000000500000049D8B793885C534012A3E716BAAA4B4049D8B793885C534088F71C588EAC4B40A69C2FF65E5E534088F71C588EAC4B40A69C2FF65E5E534012A3E716BAAA4B4049D8B793885C534012A3E716BAAA4B40
49617	Тебис	5	52	467	77.499680999999995	77.518383999999998	55.311236000000001	55.298352999999999	0103000020E61000000100000005000000AF5B04C6FA5F5340EDD45C6E30A64B40AF5B04C6FA5F53403FABCC94D6A74B4042B115342D6153403FABCC94D6A74B4042B115342D615340EDD45C6E30A64B40AF5B04C6FA5F5340EDD45C6E30A64B40
16353	Тармакуль	5	52	467	76.964527000000004	76.985234000000005	55.317337999999999	55.303437000000002	0103000020E61000000100000005000000FA4674CFBA3D5340BCB20B06D7A64B40FA4674CFBA3D534097E315889EA84B40113AE8120E3F534097E315889EA84B40113AE8120E3F5340BCB20B06D7A64B40FA4674CFBA3D5340BCB20B06D7A64B40
17357	Танчик	5	52	467	77.385379	77.395224999999996	55.335498999999999	55.324975000000002	0103000020E610000001000000050000002C64AE0CAA5853404182E2C798A94B402C64AE0CAA5853409C6B98A1F1AA4B40F163CC5D4B5953409C6B98A1F1AA4B40F163CC5D4B5953404182E2C798A94B402C64AE0CAA5853404182E2C798A94B40
15662	Тайский	5	52	467	76.880139999999997	76.891512000000006	55.466085	55.462665999999999	0103000020E61000000100000005000000B1F9B836543853404E7CB5A338BB4B40B1F9B83654385340FD135CACA8BB4B4076FF58880E395340FD135CACA8BB4B4076FF58880E3953404E7CB5A338BB4B40B1F9B836543853404E7CB5A338BB4B40
41251	Таган	5	52	467	77.270251000000002	77.310863999999995	54.960912	54.950847000000003	0103000020E6100000010000000500000086ADD9CA4B515340F73FC05AB5794B4086ADD9CA4B515340BF2A172AFF7A4B403D601E32E5535340BF2A172AFF7A4B403D601E32E5535340F73FC05AB5794B4086ADD9CA4B515340F73FC05AB5794B40
16824	Старые Карачи	5	52	467	77.020195999999999	77.063215999999997	55.500886000000001	55.488850999999997	0103000020E61000000100000005000000A4E029E44A415340F6CE68AB92BE4B40A4E029E44A4153401B834E081DC04B405F251FBB0B4453401B834E081DC04B405F251FBB0B445340F6CE68AB92BE4B40A4E029E44A415340F6CE68AB92BE4B40
29991	Старая Преображенка	5	52	467	77.032843999999997	77.058698000000007	55.504939999999998	55.495460999999999	0103000020E61000000100000005000000AB77B81D1A425340C3B81B446BBF4B40AB77B81D1A4253409B38B9DFA1C04B40CD9541B5C14353409B38B9DFA1C04B40CD9541B5C1435340C3B81B446BBF4B40AB77B81D1A425340C3B81B446BBF4B40
49593	Север	5	52	467	76.832061999999993	76.847279	55.381960999999997	55.372768999999998	0103000020E61000000100000005000000A38FF9804035534037FB03E5B6AF4B40A38FF9804035534079AC1919E4B04B409BE5B2D13936534079AC1919E4B04B409BE5B2D13936534037FB03E5B6AF4B40A38FF9804035534037FB03E5B6AF4B40
17196	Приомский	5	52	467	77.643735000000007	77.656283999999999	55.413004000000001	55.403905999999999	0103000020E61000000100000005000000991249F4326953403F541A31B3B34B40991249F432695340008FA850DDB44B40D6389B8E006A5340008FA850DDB44B40D6389B8E006A53403F541A31B3B34B40991249F4326953403F541A31B3B34B40
41285	Полтавка	5	52	467	76.463707999999997	76.480739999999997	55.128959000000002	55.122297000000003	0103000020E6100000010000000500000030B95164AD1D534010B3976DA78F4B4030B95164AD1D53402FC37FBA81904B404278B471C41E53402FC37FBA81904B404278B471C41E534010B3976DA78F4B4030B95164AD1D534010B3976DA78F4B40
49675	Покровка	5	52	467	77.212795	77.245295999999996	55.566588000000003	55.553452	0103000020E610000001000000050000002670EB6E9E4D5340F1F3DF83D7C64B402670EB6E9E4D53402D27A1F485C84B40BC75FEEDB24F53402D27A1F485C84B40BC75FEEDB24F5340F1F3DF83D7C64B402670EB6E9E4D5340F1F3DF83D7C64B40
41252	Погорелка	5	52	467	77.425748999999996	77.455133000000004	55.450510999999999	55.442484999999998	0103000020E6100000010000000500000080D3BB783F5B53403BFC3559A3B84B4080D3BB783F5B53407FBE2D58AAB94B40259529E6205D53407FBE2D58AAB94B40259529E6205D53403BFC3559A3B84B4080D3BB783F5B53403BFC3559A3B84B40
15690	Песчаное Озеро	5	52	467	76.632789000000002	76.653755000000004	55.032041	55.019613999999997	0103000020E6100000010000000500000030116F9D7F285340994528B682824B4030116F9D7F285340C99063EB19844B402D26361FD7295340C99063EB19844B402D26361FD7295340994528B682824B4030116F9D7F285340994528B682824B40
14867	Песцы	5	52	467	76.665747999999994	76.680066999999994	55.303130000000003	55.296908000000002	0103000020E6100000010000000500000027D87F9D9B2A5340DCF5D21401A64B4027D87F9D9B2A5340DF37BEF6CCA64B40AF05BD37862B5340DF37BEF6CCA64B40AF05BD37862B5340DCF5D21401A64B4027D87F9D9B2A5340DCF5D21401A64B40
16373	Отреченское	5	52	467	77.219918000000007	77.237418000000005	55.124778999999997	55.113909999999997	0103000020E610000001000000050000005073F222134E5340FB57569A948E4B405073F222134E5340211D1EC2F88F4B40D55E44DB314F5340211D1EC2F88F4B40D55E44DB314F5340FB57569A948E4B405073F222134E5340FB57569A948E4B40
16906	Осинцево	5	52	467	77.216899999999995	77.250883000000002	55.504058000000001	55.490395999999997	0103000020E6100000010000000500000027A089B0E14D53406B0BCF4BC5BE4B4027A089B0E14D5340C2A4F8F884C04B40D50792770E505340C2A4F8F884C04B40D50792770E5053406B0BCF4BC5BE4B4027A089B0E14D53406B0BCF4BC5BE4B40
17500	Оравка	5	52	467	76.535043000000002	76.568091999999993	55.447263999999997	55.441831000000001	0103000020E610000001000000050000000ABDFE243E225340F3AD0FEB8DB84B400ABDFE243E225340CD565EF23FB94B40A1478C9E5B245340CD565EF23FB94B40A1478C9E5B245340F3AD0FEB8DB84B400ABDFE243E225340F3AD0FEB8DB84B40
60681	Озеро-Карачинский сельсовет	5	52	467	76.202692999999996	77.848091999999994	55.608795000000001	54.722195999999997	0103000020E6100000010000000500000033880FECF80C5340A8A624EB705C4B4033880FECF80C5340F27B9BFEECCD4B40F3FFAA2347765340F27B9BFEECCD4B40F3FFAA2347765340A8A624EB705C4B4033880FECF80C5340A8A624EB705C4B40
16079	Озеро-Карачи	5	52	467	76.940956	76.991530999999995	55.357101999999998	55.344531000000003	0103000020E6100000010000000500000066BE839F383C5340A6BA809719AC4B4066BE839F383C534008ABB184B5AD4B40177E703E753F534008ABB184B5AD4B40177E703E753F5340A6BA809719AC4B4066BE839F383C5340A6BA809719AC4B40
16293	Новояркуль	5	52	467	76.954223999999996	76.972054999999997	55.371603	55.361953	0103000020E61000000100000005000000BB438A01123D534034D8D47954AE4B40BB438A01123D5340390CE6AF90AF4B4073BA2C26363E5340390CE6AF90AF4B4073BA2C26363E534034D8D47954AE4B40BB438A01123D534034D8D47954AE4B40
17056	Новояблоновка	5	52	467	77.295646000000005	77.321617000000003	54.885156000000002	54.875656999999997	0103000020E610000001000000050000005E4C33DDEB525340B9C1508715704B405E4C33DDEB525340D9EDB3CA4C714B409C35785F95545340D9EDB3CA4C714B409C35785F95545340B9C1508715704B405E4C33DDEB525340B9C1508715704B40
15031	Новофеклино	5	52	467	77.023098000000005	77.044045999999994	55.132392000000003	55.123944999999999	0103000020E6100000010000000500000098A608707A41534059C0046EDD8F4B4098A608707A41534043209738F2904B40416150A6D142534043209738F2904B40416150A6D142534059C0046EDD8F4B4098A608707A41534059C0046EDD8F4B40
41245	Новопреображенка	5	52	467	77.081344000000001	77.107701000000006	55.349102000000002	55.336886999999997	0103000020E6100000010000000500000074EE76BD3445534049B9FB1C1FAB4B4074EE76BD34455340EE7BD45FAFAC4B40C72FBC92E4465340EE7BD45FAFAC4B40C72FBC92E446534049B9FB1C1FAB4B4074EE76BD3445534049B9FB1C1FAB4B40
16525	Нововасильевский	5	52	467	77.365886000000003	77.378344999999996	55.045180999999999	55.040967000000002	0103000020E610000001000000050000001D041DAD6A5753408D9B1A683E854B401D041DAD6A57534046B3B27DC8854B40BA66F2CD3658534046B3B27DC8854B40BA66F2CD365853408D9B1A683E854B401D041DAD6A5753408D9B1A683E854B40
41325	Николаевка	5	52	467	76.674353999999994	76.687207999999998	55.337240000000001	55.332186	0103000020E6100000010000000500000050FBAD9D282B53403318231285AA4B4050FBAD9D282B5340977329AE2AAB4B402C634337FB2B5340977329AE2AAB4B402C634337FB2B53403318231285AA4B4050FBAD9D282B53403318231285AA4B40
2743	Моховое	5	52	467	76.808741999999995	76.831684999999993	55.299290999999997	55.292161	0103000020E61000000100000005000000B439CE6DC233534055151A8865A54B40B439CE6DC23353405A7EE02A4FA64B40B8E4B8533A3553405A7EE02A4FA64B40B8E4B8533A35534055151A8865A54B40B439CE6DC233534055151A8865A54B40
16688	Межгривный	5	52	467	77.207718999999997	77.225317000000004	55.40457	55.398584	0103000020E6100000010000000500000080F0A1444B4D5340BC5AEECC04B34B4080F0A1444B4D5340AB7823F3C8B34B40E78EFE976B4E5340AB7823F3C8B34B40E78EFE976B4E5340BC5AEECC04B34B4080F0A1444B4D5340BC5AEECC04B34B40
49618	Малый Тебис	5	52	467	76.711264999999997	76.728064000000003	55.489896000000002	55.481862	0103000020E610000001000000050000008672A25D852D5340B3976DA7ADBD4B408672A25D852D53407A3881E9B4BE4B404759BF99982E53407A3881E9B4BE4B404759BF99982E5340B3976DA7ADBD4B408672A25D852D5340B3976DA7ADBD4B40
40418	Красное	5	52	467	76.798760999999999	76.826367000000005	55.540576999999999	55.531768999999997	0103000020E610000001000000050000007F1475E61E3353406803B00111C44B407F1475E61E33534022FC8BA031C54B4098DF6932E334534022FC8BA031C54B4098DF6932E33453406803B00111C44B407F1475E61E3353406803B00111C44B40
48553	Кошкуль	5	52	467	77.177976000000001	77.191702000000006	55.295273000000002	55.284359000000002	0103000020E6100000010000000500000044DE72F5634B534061A92EE065A44B4044DE72F5634B534027327381CBA54B40FB2477D8444C534027327381CBA54B40FB2477D8444C534061A92EE065A44B4044DE72F5634B534061A92EE065A44B40
15749	Ковыльный	5	52	467	76.680318	76.694817	55.137518	55.130693000000001	0103000020E61000000100000005000000543882548A2B53407768588CBA904B40543882548A2B5340404E98309A914B401CEDB8E1772C5340404E98309A914B401CEDB8E1772C53407768588CBA904B40543882548A2B53407768588CBA904B40
15230	Кабаклы	5	52	467	76.514283000000006	76.529966999999999	55.192435000000003	55.18506	0103000020E61000000100000005000000E2783E03EA2053401DE6CB0BB0974B40E2783E03EA2053408ACDC7B5A1984B40643DB5FAEA2153408ACDC7B5A1984B40643DB5FAEA2153401DE6CB0BB0974B40E2783E03EA2053401DE6CB0BB0974B40
45826	Зенкино	5	52	467	77.111509999999996	77.134434999999996	55.027655000000003	55.020626	0103000020E6100000010000000500000053CBD6FA2247534041B96DDFA3824B4053CBD6FA224753401349F4328A834B40041C42959A4853401349F4328A834B40041C42959A48534041B96DDFA3824B4053CBD6FA2247534041B96DDFA3824B40
15149	Земляная Заимка	5	52	467	76.609926000000002	76.629284999999996	55.178593999999997	55.164526000000002	0103000020E61000000100000005000000BABE0F0709275340BDAB1E300F954B40BABE0F070927534083A10E2BDC964B4041B797344628534083A10E2BDC964B4041B7973446285340BDAB1E300F954B40BABE0F0709275340BDAB1E300F954B40
16444	Двуозерный	5	52	467	77.207898999999998	77.215632999999997	55.093133000000002	55.087330999999999	0103000020E61000000100000005000000C0779B374E4D5340A77686A92D8B4B40C0779B374E4D5340D5963AC8EB8B4B400EBC5AEECC4D5340D5963AC8EB8B4B400EBC5AEECC4D5340A77686A92D8B4B40C0779B374E4D5340A77686A92D8B4B40
14956	Блюдчанское	5	52	467	76.878073999999998	76.912147000000004	55.119110999999997	55.106921999999997	0103000020E61000000100000005000000F25D4A5D32385340889CBE9EAF8D4B40F25D4A5D3238534003CC7C073F8F4B404089CF9D603A534003CC7C073F8F4B404089CF9D603A5340889CBE9EAF8D4B40F25D4A5D32385340889CBE9EAF8D4B40
15004	Блюдцы	5	52	467	76.986491000000001	77.011427999999995	54.952185999999998	54.94444	0103000020E6100000010000000500000018B325AB223F53406284F068E3784B4018B325AB223F5340C2DA183BE1794B408E90813CBB405340C2DA183BE1794B408E90813CBB4053406284F068E3784B4018B325AB223F53406284F068E3784B40
16213	Белехта	5	52	467	76.810367999999997	76.819745999999995	55.265968000000001	55.257950000000001	0103000020E61000000100000005000000656EBE11DD33534069006F8104A14B40656EBE11DD3353402AE44A3D0BA24B40B741EDB7763453402AE44A3D0BA24B40B741EDB77634534069006F8104A14B40656EBE11DD33534069006F8104A14B40
60697	Аялу	5	52	467	77.297263000000001	77.305654000000004	55.173673000000001	55.168726999999997	0103000020E61000000100000005000000E5D3635B06535340E179A9D898954B40E5D3635B065353405F99B7EA3A964B401079CBD58F5353405F99B7EA3A964B401079CBD58F535340E179A9D898954B40E5D3635B06535340E179A9D898954B40
14197	Яркуль-Матюшкино	5	52	1204	76.078214000000003	76.113320000000002	55.851762999999998	55.839441000000001	0103000020E61000000100000005000000B8054B7501055340F5F57CCD72EB4B40B8054B7501055340AF78EA9106ED4B40E57E87A240075340AF78EA9106ED4B40E57E87A240075340F5F57CCD72EB4B40B8054B7501055340F5F57CCD72EB4B40
49674	Яркуль	5	52	1204	75.664143999999993	75.692207999999994	55.998719999999999	55.985272000000002	0103000020E610000001000000050000006AF5D55581EA52400FD594641DFE4B406AF5D55581EA524039EE940ED6FF4B40E481C8224DEC524039EE940ED6FF4B40E481C8224DEC52400FD594641DFE4B406AF5D55581EA52400FD594641DFE4B40
11887	Янабино	5	52	1204	76.231233000000003	76.251677999999998	55.996066999999996	55.987592999999997	0103000020E6100000010000000500000062307F85CC0E534017618A7269FE4B4062307F85CC0E5340FACF9A1F7FFF4B40DAC70A7E1B105340FACF9A1F7FFF4B40DAC70A7E1B10534017618A7269FE4B4062307F85CC0E534017618A7269FE4B40
41233	Щербаки	5	52	1204	75.655771999999999	75.688272999999995	55.553468000000002	55.544856000000003	0103000020E610000001000000050000007B681F2BF8E95240C38366D7BDC54B407B681F2BF8E95240F7B0170AD8C64B40116E32AA0CEC5240F7B0170AD8C64B40116E32AA0CEC5240C38366D7BDC54B407B681F2BF8E95240C38366D7BDC54B40
13573	Чичканка	5	52	1204	76.207408999999998	76.228475000000003	56.103402000000003	56.097518000000001	0103000020E6100000010000000500000059F96530460D5340BB6246787B0C4C4059F96530460D5340A62BD8463C0D4C40083D9B559F0E5340A62BD8463C0D4C40083D9B559F0E5340BB6246787B0C4C4059F96530460D5340BB6246787B0C4C40
41282	Черниговка	5	52	1204	76.00421	76.025661999999997	56.020505999999997	56.013672999999997	0103000020E610000001000000050000003C1405FA440053404AEB6F09C0014C403C1405FA4400534096AFCBF09F024C40FFAF3A72A401534096AFCBF09F024C40FFAF3A72A40153404AEB6F09C0014C403C1405FA440053404AEB6F09C0014C40
13667	Усть-Тарка	5	52	1204	75.671132999999998	75.720512999999997	55.581316999999999	55.551088999999997	0103000020E610000001000000050000000C91D3D7F3EA5240B91798158AC64B400C91D3D7F3EA5240EECD6F9868CA4B40F1D58EE21CEE5240EECD6F9868CA4B40F1D58EE21CEE5240B91798158AC64B400C91D3D7F3EA5240B91798158AC64B40
13438	Угуй	5	52	1204	76.036621999999994	76.070218999999994	56.034560999999997	56.026533000000001	0103000020E610000001000000050000001A14CD0358025340E4A1EF6E65034C401A14CD0358025340C85BAE7E6C044C40B323D5777E045340C85BAE7E6C044C40B323D5777E045340E4A1EF6E65034C401A14CD0358025340E4A1EF6E65034C40
48745	Тихоновка	5	52	1204	75.878975999999994	75.895137000000005	55.770816000000003	55.765371999999999	0103000020E61000000100000005000000027E8D2441F8524016A3AEB5F7E14B40027E8D2441F85240E59D4319AAE24B40221CB3EC49F95240E59D4319AAE24B40221CB3EC49F9524016A3AEB5F7E14B40027E8D2441F8524016A3AEB5F7E14B40
12555	Тарка	5	52	1204	75.625147999999996	75.639314999999996	55.612532999999999	55.605733999999998	0103000020E610000001000000050000003ACAC16C02E85240A20914B188CD4B403ACAC16C02E85240425C397B67CE4B40E7357689EAE85240425C397B67CE4B40E7357689EAE85240A20914B188CD4B403ACAC16C02E85240A20914B188CD4B40
13049	Силиш	5	52	1204	75.849512000000004	75.866749999999996	55.911709000000002	55.903695999999997	0103000020E61000000100000005000000D06394675EF6524054C37E4FACF34B40D06394675EF65240043C69E1B2F44B40B6F3FDD478F75240043C69E1B2F44B40B6F3FDD478F7524054C37E4FACF34B40D06394675EF6524054C37E4FACF34B40
13325	Резино	5	52	1204	75.289159999999995	75.307917000000003	55.849336999999998	55.842191	0103000020E61000000100000005000000EDD3F19881D2524026FE28EACCEB4B40EDD3F19881D2524031242713B7EC4B407A3881E9B4D3524031242713B7EC4B407A3881E9B4D3524026FE28EACCEB4B40EDD3F19881D2524026FE28EACCEB4B40
41226	Победа	5	52	1204	75.540544999999995	75.559742	55.652495999999999	55.641396999999998	0103000020E610000001000000050000000B410E4A98E252405260014C19D24B400B410E4A98E25240AA622AFD84D34B40A60C1CD0D2E35240AA622AFD84D34B40A60C1CD0D2E352405260014C19D24B400B410E4A98E252405260014C19D24B40
49672	Октябрьский	5	52	1204	76.123227999999997	76.149970999999994	55.946033	55.931244999999997	0103000020E61000000100000005000000E57CB1F7E207534021C8410933F74B40E57CB1F7E2075340E8F7FD9B17F94B404C16F71F99095340E8F7FD9B17F94B404C16F71F9909534021C8410933F74B40E57CB1F7E207534021C8410933F74B40
41345	Новоникольск	5	52	1204	75.969606999999996	76.000778999999994	55.721218999999998	55.711959999999998	0103000020E6100000010000000500000040BE840A0EFE5240B3075A8121DB4B4040BE840A0EFE52407D2079E750DC4B4082E15CC30C0053407D2079E750DC4B4082E15CC30C005340B3075A8121DB4B4040BE840A0EFE5240B3075A8121DB4B40
44419	Мураши	5	52	1204	75.567638000000002	75.586978999999999	55.727373999999998	55.717055999999999	0103000020E61000000100000005000000E17D552E54E4524046B3B27DC8DB4B40E17D552E54E45240F8FA5A971ADD4B40151C5E1091E55240F8FA5A971ADD4B40151C5E1091E5524046B3B27DC8DB4B40E17D552E54E4524046B3B27DC8DB4B40
46038	Михайловка	5	52	1204	75.559094999999999	75.580806999999993	55.498663000000001	55.495435000000001	0103000020E61000000100000005000000DB166536C8E352409A25016A6ABF4B40DB166536C8E35240D55C6E30D4BF4B406C921FF12BE55240D55C6E30D4BF4B406C921FF12BE552409A25016A6ABF4B40DB166536C8E352409A25016A6ABF4B40
41203	Мирный	5	52	1204	76.131529	76.142937000000003	56.000104	55.992583000000003	0103000020E61000000100000005000000705E9CF86A08534065C8B1F50CFF4B40705E9CF86A085340A54C6A6803004C40DB183BE125095340A54C6A6803004C40DB183BE12509534065C8B1F50CFF4B40705E9CF86A08534065C8B1F50CFF4B40
40417	Мартыново	5	52	1204	75.738146999999998	75.752690999999999	56.066780999999999	56.056381999999999	0103000020E61000000100000005000000FE28EACC3DEF5240A20A7F8637074C40FE28EACC3DEF5240417FA1478C084C40963FDF162CF05240417FA1478C084C40963FDF162CF05240A20A7F8637074C40FE28EACC3DEF5240A20A7F8637074C40
12657	Кушаги	5	52	1204	75.73751	75.762698	55.677616	55.668025999999998	0103000020E61000000100000005000000459E245D33EF524058703FE081D54B40459E245D33EF5240889FFF1EBCD64B4060AE450BD0F05240889FFF1EBCD64B4060AE450BD0F0524058703FE081D54B40459E245D33EF524058703FE081D54B40
41302	Козино	5	52	1204	75.477771000000004	75.507549999999995	55.525170000000003	55.504429999999999	0103000020E610000001000000050000008BFED0CC93DE5240868F882991C04B408BFED0CC93DE5240906B43C538C34B406DC5FEB27BE05240906B43C538C34B406DC5FEB27BE05240868F882991C04B408BFED0CC93DE5240868F882991C04B40
48479	Камышево	5	52	1204	76.010445000000004	76.048399000000003	55.629679000000003	55.617663	0103000020E61000000100000005000000085A8121AB0053408179C8940FCF4B40085A8121AB0053402FFD4B5299D04B402F8A1EF8180353402FFD4B5299D04B402F8A1EF8180353408179C8940FCF4B40085A8121AB0053408179C8940FCF4B40
41384	Зеленая Роща	5	52	1204	75.465670000000003	75.480349000000004	55.585306000000003	55.576161999999997	0103000020E610000001000000050000009D2E8B89CDDD5240569929ADBFC94B409D2E8B89CDDD52408813984EEBCA4B40A56ABB09BEDE52408813984EEBCA4B40A56ABB09BEDE5240569929ADBFC94B409D2E8B89CDDD5240569929ADBFC94B40
49673	Еланка	5	52	1204	75.277878000000001	75.308949999999996	55.633983000000001	55.617199999999997	0103000020E61000000100000005000000C991CEC0C8D15240AC8BDB6800CF4B40C991CEC0C8D15240289CDD5A26D14B40598638D6C5D35240289CDD5A26D14B40598638D6C5D35240AC8BDB6800CF4B40C991CEC0C8D15240AC8BDB6800CF4B40
11705	Дубровино	5	52	1204	76.252414999999999	76.267525000000006	55.950589999999998	55.945709999999998	0103000020E6100000010000000500000045813E912710534005C078060DF94B4045813E9127105340CBF3E0EEACF94B4032772D211F115340CBF3E0EEACF94B4032772D211F11534005C078060DF94B4045813E912710534005C078060DF94B40
41230	Дмитриевка	5	52	1204	75.400425999999996	75.410180999999994	55.713380000000001	55.705975000000002	0103000020E61000000100000005000000F59D5F94A0D95240956588635DDA4B40F59D5F94A0D952406CCF2C0950DB4B40321CCF6740DA52406CCF2C0950DB4B40321CCF6740DA5240956588635DDA4B40F59D5F94A0D95240956588635DDA4B40
40414	Верхнеомка	5	52	1204	75.995739	76.021045000000001	55.509013000000003	55.500835000000002	0103000020E6100000010000000500000083161230BAFF524099D87C5C1BC04B4083161230BAFF5240931E865627C14B40A3AF20CD58015340931E865627C14B40A3AF20CD5801534099D87C5C1BC04B4083161230BAFF524099D87C5C1BC04B40
40415	Богословка	5	52	1204	75.834176999999997	75.849960999999993	55.521639	55.513233999999997	0103000020E61000000100000005000000D384ED2763F55240FE98D6A6B1C14B40D384ED2763F55240B9A81611C5C24B400778D2C265F65240B9A81611C5C24B400778D2C265F65240FE98D6A6B1C14B40D384ED2763F55240FE98D6A6B1C14B40
38000	Кабанка	5	52	5442	75.978275999999994	75.987205000000003	55.438803	55.430590000000002	0103000020E610000001000000050000008C9DF0129CFE524009FEB7921DB74B408C9DF0129CFE52407F315BB22AB84B40A75CE15D2EFF52407F315BB22AB84B40A75CE15D2EFF524009FEB7921DB74B408C9DF0129CFE524009FEB7921DB74B40
41293	Черный Мыс	5	52	1091	80.052404999999993	80.096880999999996	55.545726999999999	55.537658	0103000020E610000001000000050000006649809A5A035440653733FAD1C44B406649809A5A035440A8C5E061DAC54B40A4A65D4C33065440A8C5E061DAC54B40A4A65D4C33065440653733FAD1C44B406649809A5A035440653733FAD1C44B40
10249	Херсонка	5	52	1091	79.790025	79.809708000000001	55.057372999999998	55.050984	0103000020E610000001000000050000006F8104C58FF25340444FCAA486864B406F8104C58FF2534032569BFF57874B40D0D38041D2F3534032569BFF57874B40D0D38041D2F35340444FCAA486864B406F8104C58FF25340444FCAA486864B40
9646	Убинское	5	52	1091	79.620054999999994	79.723783999999995	55.318187999999999	55.280098000000002	0103000020E6100000010000000500000029AE2AFBAEE7534067D65240DAA34B4029AE2AFBAEE7534065FD6662BAA84B408E57207A52EE534065FD6662BAA84B408E57207A52EE534067D65240DAA34B4029AE2AFBAEE7534067D65240DAA34B40
10145	Раисино	5	52	1091	79.571223000000003	79.608565999999996	55.196254000000003	55.181015000000002	0103000020E6100000010000000500000046EEE9EA8EE45340F08AE07F2B974B4046EEE9EA8EE45340C7DADFD91E994B4048DDCEBEF2E65340C7DADFD91E994B4048DDCEBEF2E65340F08AE07F2B974B4046EEE9EA8EE45340F08AE07F2B974B40
47581	Пешково	5	52	1091	79.670261999999994	79.700383000000002	55.644247	55.637529999999998	0103000020E6100000010000000500000019709692E5EA5340041C42959AD14B4019709692E5EA5340E7C589AF76D24B4029EB3713D3EC5340E7C589AF76D24B4029EB3713D3EC5340041C42959AD14B4019709692E5EA5340041C42959AD14B40
41258	Орловское	5	52	1091	79.716283000000004	79.741409000000004	55.514727999999998	55.505893	0103000020E6100000010000000500000092EBA694D7ED53403E23111AC1C04B4092EBA694D7ED5340F12A6B9BE2C14B4072FDBB3E73EF5340F12A6B9BE2C14B4072FDBB3E73EF53403E23111AC1C04B4092EBA694D7ED53403E23111AC1C04B40
9925	Новодубровское	5	52	1091	79.966876999999997	79.994814000000005	55.709277	55.697752000000001	0103000020E610000001000000050000004B901150E1FD5340FB5B02F04FD94B404B901150E1FD53400A67B796C9DA4B4097E65608ABFF53400A67B796C9DA4B4097E65608ABFF5340FB5B02F04FD94B404B901150E1FD5340FB5B02F04FD94B40
10651	Новогандичево	5	52	1091	79.282747000000001	79.30171	55.012889000000001	55.000630999999998	0103000020E61000000100000005000000B282DF8618D25340902E36AD14804B40B282DF8618D2534034BDC458A6814B4013B875374FD3534034BDC458A6814B4013B875374FD35340902E36AD14804B40B282DF8618D25340902E36AD14804B40
41336	Николаевский 2-й	5	52	1091	78.999903000000003	79.024876000000006	55.189917000000001	55.180691000000003	0103000020E61000000100000005000000070B2769FEBF53403DD7F7E120974B40070B2769FEBF53402BFA43334F984B40249D819197C153402BFA43334F984B40249D819197C153403DD7F7E120974B40070B2769FEBF53403DD7F7E120974B40
41332	Московка	5	52	1091	79.792378999999997	79.799897999999999	55.254359000000001	55.243032999999997	0103000020E6100000010000000500000061C26856B6F25340A46C91B41B9F4B4061C26856B6F25340BD38F1D58EA04B40B188618731F35340BD38F1D58EA04B40B188618731F35340A46C91B41B9F4B4061C26856B6F25340A46C91B41B9F4B40
10718	Кундран	5	52	1091	79.298952	79.343069	54.912703	54.894196999999998	0103000020E61000000100000005000000B9C4910722D3534035971B0C75724B40B9C4910722D3534005FBAF73D3744B405FD1ADD7F4D5534005FBAF73D3744B405FD1ADD7F4D5534035971B0C75724B40B9C4910722D3534035971B0C75724B40
10948	Ксеньевка	5	52	1091	79.427087999999998	79.449330000000003	55.443674999999999	55.438358000000001	0103000020E61000000100000005000000E620E86855DB534051F86C1D1CB84B40E620E86855DB5340C286A757CAB84B4026C79DD2C1DC5340C286A757CAB84B4026C79DD2C1DC534051F86C1D1CB84B40E620E86855DB534051F86C1D1CB84B40
10459	Круглоозерное	5	52	1091	79.280061000000003	79.316218000000006	55.087594000000003	55.071854999999999	0103000020E61000000100000005000000A5F8F884ECD15340EC866D8B32894B40A5F8F884ECD15340B5A9BA47368B4B40051A6CEA3CD45340B5A9BA47368B4B40051A6CEA3CD45340EC866D8B32894B40A5F8F884ECD15340EC866D8B32894B40
41327	Крещенский	5	52	1091	79.758359999999996	79.786278999999993	55.406446000000003	55.397990999999998	0103000020E610000001000000050000000DA661F888F05340198D7C5EF1B24B400DA661F888F0534086CB2A6C06B44B4005A2276552F2534086CB2A6C06B44B4005A2276552F25340198D7C5EF1B24B400DA661F888F05340198D7C5EF1B24B40
41260	Колмаково	5	52	1091	79.267600999999999	79.288244000000006	55.436489000000002	55.429153999999997	0103000020E610000001000000050000001FD8F15F20D153404A79AD84EEB64B401FD8F15F20D1534029081EDFDEB74B402B51F69672D2534029081EDFDEB74B402B51F69672D253404A79AD84EEB64B401FD8F15F20D153404A79AD84EEB64B40
11290	Кожурла	5	52	1091	79.019073000000006	79.057879999999997	55.348826000000003	55.332289000000003	0103000020E6100000010000000500000025CFF57D38C1534008E9297288AA4B4025CFF57D38C153404CFF9254A6AC4B40EBC5504EB4C353404CFF9254A6AC4B40EBC5504EB4C3534008E9297288AA4B4025CFF57D38C1534008E9297288AA4B40
11177	Клубничная	5	52	1091	79.322999999999993	79.348477000000003	55.326588999999998	55.320504	0103000020E61000000100000005000000E9263108ACD453405C1E6B4606A94B40E9263108ACD45340DE1D19ABCDA94B40209A79724DD65340DE1D19ABCDA94B40209A79724DD653405C1E6B4606A94B40E9263108ACD453405C1E6B4606A94B40
41330	Кирилловка	5	52	1091	79.448009999999996	79.468006000000003	55.132268000000003	55.117206000000003	0103000020E61000000100000005000000FB912232ACDC53408F72309B008F4B40FB912232ACDC534057276728EE904B403C1570CFF3DD534057276728EE904B403C1570CFF3DD53408F72309B008F4B40FB912232ACDC53408F72309B008F4B40
41215	Каменка	5	52	1091	79.668060999999994	79.683601999999993	55.151702999999998	55.139828000000001	0103000020E61000000100000005000000EAAEEC82C1EA5340558847E2E5914B40EAAEEC82C1EA534040DAFF006B934B40BB5E9A22C0EB534040DAFF006B934B40BB5E9A22C0EB5340558847E2E5914B40EAAEEC82C1EA5340558847E2E5914B40
41297	Ермолаевка	5	52	1091	79.893322999999995	79.919409999999999	55.321548999999997	55.313982000000003	0103000020E61000000100000005000000EF703B342CF953402FC4EA8F30A84B40EF703B342CF95340DF87838428A94B4062670A9DD7FA5340DF87838428A94B4062670A9DD7FA53402FC4EA8F30A84B40EF703B342CF953402FC4EA8F30A84B40
41295	Владимировское	5	52	1091	79.586646999999999	79.611333000000002	55.378456999999997	55.369694000000003	0103000020E61000000100000005000000FAD2DB9F8BE5534083C30B2252AF4B40FAD2DB9F8BE553409CF86A4771B04B40CC7D721420E753409CF86A4771B04B40CC7D721420E7534083C30B2252AF4B40FAD2DB9F8BE5534083C30B2252AF4B40
41335	Борисоглебский	5	52	1091	79.302698000000007	79.321292999999997	55.278072000000002	55.264223999999999	0103000020E6100000010000000500000023A46E675FD35340BE688F17D2A14B4023A46E675FD3534077F700DD97A34B40C2DB831090D4534077F700DD97A34B40C2DB831090D45340BE688F17D2A14B4023A46E675FD35340BE688F17D2A14B40
11442	Белоозерный	5	52	1091	79.173035999999996	79.195368000000002	55.160457999999998	55.151409999999998	0103000020E61000000100000005000000F641960513CB5340C824236761934B40F641960513CB5340D73043E389944B40D6ABC8E880CC5340D73043E389944B40D6ABC8E880CC5340C824236761934B40F641960513CB5340C824236761934B40
10113	Асенкритово	5	52	1091	79.566407999999996	79.591857000000005	55.243397000000002	55.235830999999997	0103000020E61000000100000005000000560C570740E453400531D0B52F9E4B40560C570740E45340E67805A2279F4B4028BA2EFCE0E55340E67805A2279F4B4028BA2EFCE0E553400531D0B52F9E4B40560C570740E453400531D0B52F9E4B40
48132	Александро-Невское	5	52	1091	79.151843999999997	79.185316	55.268194999999999	55.247594999999997	0103000020E610000001000000050000000186E5CFB7C9534099D36531B19F4B400186E5CFB7C95340B1F9B83654A24B403CDBA337DCCB5340B1F9B83654A24B403CDBA337DCCB534099D36531B19F4B400186E5CFB7C9534099D36531B19F4B40
37903	Воробьи	5	52	5368	83.230905000000007	83.243176000000005	55.910715000000003	55.902616000000002	0103000020E61000000100000005000000E8DEC325C7CE5440556CCCEB88F34B40E8DEC325C7CE5440037D224F92F44B4004CB113290CF5440037D224F92F44B4004CB113290CF5440556CCCEB88F34B40E8DEC325C7CE5440556CCCEB88F34B40
35629	Новоселово	5	52	3763	141.99002200000001	142.000865	47.663555000000002	47.640464999999999	0103000020E61000000100000005000000420A9E42AEBF6140C79DD2C1FAD14740420A9E42AEBF6140740CC85EEFD44740C156091607C06140740CC85EEFD44740C156091607C06140C79DD2C1FAD14740420A9E42AEBF6140C79DD2C1FAD14740
41296	станция Изынский	5	52	843	83.798856000000001	83.930656999999997	55.218460999999998	55.143039000000002	0103000020E61000000100000005000000A88DEA7420F35440BA86191A4F924B40A88DEA7420F35440C939B187F69B4B40C8B260E28FFB5440C939B187F69B4B40C8B260E28FFB5440BA86191A4F924B40A88DEA7420F35440BA86191A4F924B40
41255	станция Буготак	5	52	843	83.696995999999999	83.828796999999994	55.185363000000002	55.109878000000002	0103000020E61000000100000005000000575C1C959BEC54406346787B108E4B40575C1C959BEC5440B9718BF9B9974B40778192020BF55440B9718BF9B9974B40778192020BF554406346787B108E4B40575C1C959BEC54406346787B108E4B40
7421	Янченково	5	52	843	84.242677999999998	84.274056000000002	55.292422999999999	55.278697999999999	0103000020E610000001000000050000005B5D4E09880F5540F5BA4560ACA34B405B5D4E09880F554092CCEA1D6EA54B4072512D228A11554092CCEA1D6EA54B4072512D228A115540F5BA4560ACA34B405B5D4E09880F5540F5BA4560ACA34B40
41294	Юрты	5	52	843	84.780212000000006	84.827687999999995	54.855910999999999	54.846606999999999	0103000020E6100000010000000500000098FC4FFEEE31554047C8409E5D6C4B4098FC4FFEEE315540B1A4DC7D8E6D4B40AAD216D7F8345540B1A4DC7D8E6D4B40AAD216D7F834554047C8409E5D6C4B4098FC4FFEEE31554047C8409E5D6C4B40
8690	Шубкино	5	52	843	84.232257000000004	84.253359000000003	55.082889999999999	55.072484000000003	0103000020E6100000010000000500000018D1764CDD0E5540DCBDDC2747894B4018D1764CDD0E55402D95B7239C8A4B406DC9AA08371055402D95B7239C8A4B406DC9AA0837105540DCBDDC2747894B4018D1764CDD0E5540DCBDDC2747894B40
9629	Шахта	5	52	843	84.740191999999993	84.772738000000004	55.103532999999999	55.088006	0103000020E61000000100000005000000B130444E5F2F554007EDD5C7438B4B40B130444E5F2F55404487C091408D4B401898158A743155404487C091408D4B401898158A7431554007EDD5C7438B4B40B130444E5F2F554007EDD5C7438B4B40
9496	Чемское	5	52	843	83.939010999999994	83.964335000000005	54.857123999999999	54.845196999999999	0103000020E6100000010000000500000064E597C118FC5440B2D6506A2F6C4B4064E597C118FC5440F04E3E3DB66D4B40D8D825AAB7FD5440F04E3E3DB66D4B40D8D825AAB7FD5440B2D6506A2F6C4B4064E597C118FC5440B2D6506A2F6C4B40
40240	Усть-Каменка	5	52	843	83.830907999999994	83.869490999999996	55.016486999999998	54.989010999999998	0103000020E61000000100000005000000067FBF982DF554402F3196E9977E4B40067FBF982DF5544092E7FA3E1C824B40A54A94BDA5F7544092E7FA3E1C824B40A54A94BDA5F754402F3196E9977E4B40067FBF982DF554402F3196E9977E4B40
6267	Тогучин	5	52	843	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
46241	Сурково	5	52	843	84.504159000000001	84.530587999999995	55.311677000000003	55.299464999999998	0103000020E61000000100000005000000FB3E1C2444205540F8A57EDE54A64B40FB3E1C24442055402CF52C08E5A74B409AE95E27F52155402CF52C08E5A74B409AE95E27F5215540F8A57EDE54A64B40FB3E1C2444205540F8A57EDE54A64B40
9062	Степногутово	5	52	843	84.946669999999997	84.976367999999994	54.855863999999997	54.841541999999997	0103000020E61000000100000005000000AD86C43D963C5540EF1AF4A5B76B4B40AD86C43D963C554070E998F38C6D4B40193735D07C3E554070E998F38C6D4B40193735D07C3E5540EF1AF4A5B76B4B40AD86C43D963C5540EF1AF4A5B76B4B40
8546	Старогутово	5	52	843	84.593442999999994	84.624363000000002	54.751980000000003	54.737237	0103000020E61000000100000005000000914259F8FA255540593332C85D5E4B40914259F8FA255540809F71E140604B4047753A90F5275540809F71E140604B4047753A90F5275540593332C85D5E4B40914259F8FA255540593332C85D5E4B40
41288	Смирновка	5	52	843	84.754582999999997	84.769091000000003	54.980274999999999	54.970224999999999	0103000020E6100000010000000500000086C77E164B3055407C613255307C4B4086C77E164B3055400F0BB5A6797D4B40782975C9383155400F0BB5A6797D4B40782975C9383155407C613255307C4B4086C77E164B3055407C613255307C4B40
7913	Саламатово	5	52	843	84.761401000000006	84.777929999999998	55.159058999999999	55.151209000000001	0103000020E61000000100000005000000128942CBBA30554031EE06D15A934B40128942CBBA3055403691990B5C944B40F224E99AC93155403691990B5C944B40F224E99AC931554031EE06D15A934B40128942CBBA30554031EE06D15A934B40
9333	Русско-Семеновский	5	52	843	84.465828000000002	84.495275000000007	55.287270999999997	55.273093000000003	0103000020E61000000100000005000000E9633E20D01D55401EE21FB6F4A24B40E9633E20D01D55406B0BCF4BC5A44B40B1E1E995B21F55406B0BCF4BC5A44B40B1E1E995B21F55401EE21FB6F4A24B40E9633E20D01D55401EE21FB6F4A24B40
9003	Репьево	5	52	843	83.443922999999998	83.473620999999994	55.071561000000003	55.050514	0103000020E610000001000000050000004DBC033C69DC5440BDFE243E77864B404DBC033C69DC5440A4552DE928894B40B96C74CE4FDE5440A4552DE928894B40B96C74CE4FDE5440BDFE243E77864B404DBC033C69DC5440BDFE243E77864B40
7211	Пойменное	5	52	843	84.407545999999996	84.433732000000006	55.064267000000001	55.050772000000002	0103000020E610000001000000050000006667D13B151A5540B9C667B27F864B406667D13B151A5540249BABE639884B40A3CEDC43C21B5540249BABE639884B40A3CEDC43C21B5540B9C667B27F864B406667D13B151A5540B9C667B27F864B40
7694	Новоабышево	5	52	843	84.515962999999999	84.547216000000006	54.900751	54.882649000000001	0103000020E610000001000000050000008CBCAC89052155406E6C76A4FA704B408CBCAC89052155406E6B0BCF4B734B4045F64196052355406E6B0BCF4B734B4045F64196052355406E6C76A4FA704B408CBCAC89052155406E6C76A4FA704B40
41371	Нечаевский	5	52	843	84.371055999999996	84.387872999999999	55.214548000000001	55.202209000000003	0103000020E61000000100000005000000033FAA61BF1755407BFA08FCE1994B40033FAA61BF1755400BB6114F769B4B40178046E9D21855400BB6114F769B4B40178046E9D21855407BFA08FCE1994B40033FAA61BF1755407BFA08FCE1994B40
9397	Налетиха	5	52	843	83.884663000000003	83.901910999999998	54.951591000000001	54.945407000000003	0103000020E61000000100000005000000CD3E8F519EF854406A34B91803794B40CD3E8F519EF854407F15E0BBCD794B40C539EAE8B8F954407F15E0BBCD794B40C539EAE8B8F954406A34B91803794B40CD3E8F519EF854406A34B91803794B40
41355	Мирный	5	52	843	84.738009000000005	84.754592000000002	54.729039	54.715300999999997	0103000020E61000000100000005000000D6C9198A3B2F5540E6E5B0FB8E5B4B40D6C9198A3B2F554018416326515D4B40B0743E3C4B30554018416326515D4B40B0743E3C4B305540E6E5B0FB8E5B4B40D6C9198A3B2F5540E6E5B0FB8E5B4B40
9049	Льниха	5	52	843	83.619184000000004	83.642819000000003	55.123475999999997	55.114657000000001	0103000020E61000000100000005000000378DEDB5A0E75440F5A0A014AD8E4B40378DEDB5A0E75440A2EBC20FCE8F4B40D68F4DF223E95440A2EBC20FCE8F4B40D68F4DF223E95440F5A0A014AD8E4B40378DEDB5A0E75440F5A0A014AD8E4B40
8855	Лекарственное	5	52	843	83.634221999999994	83.662357	55.006141	54.995545	0103000020E61000000100000005000000D619DF1797E854402159C0046E7F4B40D619DF1797E854401615713AC9804B40B5519D0E64EA54401615713AC9804B40B5519D0E64EA54402159C0046E7F4B40D619DF1797E854402159C0046E7F4B40
41185	Лебедево	5	52	843	84.320858000000001	84.355901000000003	54.926124999999999	54.907888999999997	0103000020E610000001000000050000003D2AFEEF88145540F6B2EDB435744B403D2AFEEF88145540068195438B764B4047E7FC14C7165540068195438B764B4047E7FC14C7165540F6B2EDB435744B403D2AFEEF88145540F6B2EDB435744B40
49610	Кусмень	5	52	843	84.782961	84.804592	55.265183999999998	55.253655999999999	0103000020E61000000100000005000000C84274081C3255409337C0CC77A04B40C84274081C32554013B69F8CF1A14B40E3A7716F7E33554013B69F8CF1A14B40E3A7716F7E3355409337C0CC77A04B40C84274081C3255409337C0CC77A04B40
8356	Курундус	5	52	843	84.768641000000002	84.802166999999997	55.064241000000003	55.044685999999999	0103000020E610000001000000050000005857056A31315540664B5645B8854B405857056A31315540FB07910C39884B408CBB41B456335540FB07910C39884B408CBB41B456335540664B5645B8854B405857056A31315540664B5645B8854B40
46713	Кудрино	5	52	843	84.271927000000005	84.303700000000006	55.257323999999997	55.242612000000001	0103000020E6100000010000000500000090F9804067115540FFCEF6E80D9F4B4090F9804067115540EA3C2AFEEFA04B40E5F21FD26F135540EA3C2AFEEFA04B40E5F21FD26F135540FFCEF6E80D9F4B4090F9804067115540FFCEF6E80D9F4B40
8550	Кудельный Ключ	5	52	843	84.244394	84.271837000000005	55.169874	55.151049999999998	0103000020E61000000100000005000000AC55BB26A40F5540C8073D9B55934B40AC55BB26A40F55406938656EBE954B40F03504C7651155406938656EBE954B40F03504C765115540C8073D9B55934B40AC55BB26A40F5540C8073D9B55934B40
8392	Коурак	5	52	843	84.654330999999999	84.703306999999995	54.838861999999999	54.813738999999998	0103000020E610000001000000050000009370218FE0295540683D7C9928684B409370218FE0295540B7ED7BD45F6B4B4010035DFB022D5540B7ED7BD45F6B4B4010035DFB022D5540683D7C9928684B409370218FE0295540683D7C9928684B40
9129	Колтырак	5	52	843	84.906137999999999	84.926546999999999	54.796365999999999	54.783954000000001	0103000020E610000001000000050000006CEA3C2AFE395540C1C8CB9A58644B406CEA3C2AFE395540BBD23252EF654B403ECDC98B4C3B5540BBD23252EF654B403ECDC98B4C3B5540C1C8CB9A58644B406CEA3C2AFE395540C1C8CB9A58644B40
46542	Ковалевка	5	52	843	84.217569999999995	84.239784999999998	55.297758999999999	55.290449000000002	0103000020E61000000100000005000000CEA5B8AAEC0D5540F513CE6E2DA54B40CEA5B8AAEC0D55407A8B87F71CA64B4091442FA3580F55407A8B87F71CA64B4091442FA3580F5540F513CE6E2DA54B40CEA5B8AAEC0D5540F513CE6E2DA54B40
8068	Киик	5	52	843	84.673985999999999	84.712838000000005	55.258001999999998	55.233649999999997	0103000020E610000001000000050000008FFD2C96222B5540EE5A423EE89D4B408FFD2C96222B5540BB26A43506A14B40265646239F2D5540BB26A43506A14B40265646239F2D5540EE5A423EE89D4B408FFD2C96222B5540EE5A423EE89D4B40
8897	Карпысак	5	52	843	83.693106999999998	83.729246000000003	55.053525999999998	55.030141999999998	0103000020E610000001000000050000003C6876DD5BEC5440361E6CB1DB834B403C6876DD5BEC54402BBEA1F0D9864B40492F6AF7ABEE54402BBEA1F0D9864B40492F6AF7ABEE5440361E6CB1DB834B403C6876DD5BEC5440361E6CB1DB834B40
7314	Кадниха	5	52	843	84.234018000000006	84.243576000000004	55.034275000000001	55.017194000000003	0103000020E61000000100000005000000392BA226FA0E5540FED7B96933824B40392BA226FA0E554003098A1F63844B40CB85CABF960F554003098A1F63844B40CB85CABF960F5540FED7B96933824B40392BA226FA0E5540FED7B96933824B40
6930	Изынский	5	52	843	83.985399999999998	84.005450999999994	55.187358000000003	55.177354999999999	0103000020E610000001000000050000009E5E29CB10FF54401B649291B3964B409E5E29CB10FF54406E52D158FB974B40C0AE264F590055406E52D158FB974B40C0AE264F590055401B649291B3964B409E5E29CB10FF54401B649291B3964B40
7777	Изылы	5	52	843	84.564041000000003	84.582527999999996	55.177370000000003	55.165503000000001	0103000020E610000001000000050000009A266C3F19245540E831CA332F954B409A266C3F1924554051A5660FB4964B40464085234825554051A5660FB4964B404640852348255540E831CA332F954B409A266C3F19245540E831CA332F954B40
46745	Златоуст	5	52	843	84.126318999999995	84.154329000000004	55.263855	55.250849000000002	0103000020E610000001000000050000004277499C15085540FE9DEDD11BA04B404277499C150855406BF12900C6A14B40C3F4BD86E00955406BF12900C6A14B40C3F4BD86E0095540FE9DEDD11BA04B404277499C15085540FE9DEDD11BA04B40
46631	Заречное	5	52	843	84.597044999999994	84.636454000000001	55.162931	55.145761	0103000020E61000000100000005000000614F3BFC352655402104E44BA8924B40614F3BFC3526554096404AECDA944B4023DA8EA9BB28554096404AECDA944B4023DA8EA9BB2855402104E44BA8924B40614F3BFC352655402104E44BA8924B40
41326	Долгово	5	52	843	84.446982000000006	84.465271000000001	55.443505999999999	55.433501	0103000020E61000000100000005000000A5F9635A9B1C554043E4F4F57CB74B40A5F9635A9B1C554036CAFACDC4B84B40BE310400C71D554036CAFACDC4B84B40BE310400C71D554043E4F4F57CB74B40A5F9635A9B1C554043E4F4F57CB74B40
59170	Дергоусово	5	52	843	83.394300000000001	85.087048999999993	55.499499	54.537394999999997	0103000020E61000000100000005000000053411363CD954405704FF5BC9444B40053411363CD954403EB14E95EFBF4B409109F835924555403EB14E95EFBF4B409109F835924555405704FF5BC9444B40053411363CD954405704FF5BC9444B40
7493	Гутово	5	52	843	84.28877	84.308093	55.281174999999998	55.270133000000001	0103000020E6100000010000000500000038842A357B1255400249D8B793A24B4038842A357B125540F5B9DA8AFDA34B4019C8B3CBB7135540F5B9DA8AFDA34B4019C8B3CBB71355400249D8B793A24B4038842A357B1255400249D8B793A24B40
44098	Горный	5	52	843	83.849108000000001	83.940259999999995	55.142215999999998	55.111851000000001	0103000020E6100000010000000500000068B114C957F6544030833122518E4B4068B114C957F65440E57B462234924B402A6F47382DFC5440E57B462234924B402A6F47382DFC544030833122518E4B4068B114C957F6544030833122518E4B40
46663	Гаревка	5	52	843	84.510779999999997	84.552704000000006	55.122394999999997	55.111196999999997	0103000020E61000000100000005000000DBDC989EB0205540E7340BB43B8E4B40DBDC989EB0205540D218ADA3AA8F4B40941799805F235540D218ADA3AA8F4B40941799805F235540E7340BB43B8E4B40DBDC989EB0205540E7340BB43B8E4B40
41331	Владимировка	5	52	843	83.983109999999996	84.010158000000004	54.966768000000002	54.953059000000003	0103000020E61000000100000005000000B7973446EBFE544049145AD6FD794B40B7973446EBFE5440E068C70DBF7B4B40BD72BD6DA6005540E068C70DBF7B4B40BD72BD6DA600554049145AD6FD794B40B7973446EBFE544049145AD6FD794B40
9279	Верх-Ачино	5	52	843	84.613898000000006	84.631135999999998	55.451900000000002	55.441468999999998	0103000020E610000001000000050000001C45D61A4A2755405299620E82B84B401C45D61A4A275540FD87F4DBD7B94B4002D53F8864285540FD87F4DBD7B94B4002D53F88642855405299620E82B84B401C45D61A4A2755405299620E82B84B40
7249	Вассино	5	52	843	84.359549000000001	84.397268999999994	55.068406000000003	55.049348999999999	0103000020E61000000100000005000000CF13CFD9021755408F8B6A1151864B40CF13CFD902175540D36C1E87C1884B40BCADF4DA6C195540D36C1E87C1884B40BCADF4DA6C1955408F8B6A1151864B40CF13CFD9021755408F8B6A1151864B40
6941	Буготак	5	52	843	83.789019999999994	83.818673000000004	55.160766000000002	55.134219000000002	0103000020E61000000100000005000000F4F8BD4D7FF254403CC093162E914B40F4F8BD4D7FF254408527F4FA93944B409147702365F454408527F4FA93944B409147702365F454403CC093162E914B40F4F8BD4D7FF254403CC093162E914B40
46216	Борцово	5	52	843	84.078169000000003	84.102513999999999	55.159187000000003	55.139282999999999	0103000020E61000000100000005000000E8A38CB800055540C3F17C06D4914B40E8A38CB8000555406479573D60944B407558E1968F0655406479573D60944B407558E1968F065540C3F17C06D4914B40E8A38CB800055540C3F17C06D4914B40
47027	Боровлянка	5	52	843	84.103960000000001	84.123615000000001	55.024346999999999	55.010798000000001	0103000020E61000000100000005000000E605D847A70655405D6E30D461814B40E605D847A7065540BB6070CD1D834B40E292E34EE9075540BB6070CD1D834B40E292E34EE90755405D6E30D461814B40E605D847A70655405D6E30D461814B40
8202	Березиково	5	52	843	84.789168000000004	84.823510999999996	55.052376000000002	55.036653999999999	0103000020E610000001000000050000002FC37FBA8132554040A20914B1844B402FC37FBA81325540338CBB41B4864B405C397B67B4345540338CBB41B4864B405C397B67B434554040A20914B1844B402FC37FBA8132554040A20914B1844B40
9461	Аплаксино	5	52	843	83.732146999999998	83.751928000000007	54.946756999999998	54.934598000000001	0103000020E610000001000000050000005437177FDBEE5440197442E8A0774B405437177FDBEE5440292158552F794B40973C9E961FF05440292158552F794B40973C9E961FF05440197442E8A0774B405437177FDBEE5440197442E8A0774B40
3388	Чернышевский	5	52	315	75.892010999999997	75.899744999999996	55.037598000000003	55.03248	0103000020E61000000100000005000000062B4EB516F9524015E3FC4D28844B40062B4EB516F952409032E202D0844B40546F0D6C95F952409032E202D0844B40546F0D6C95F9524015E3FC4D28844B40062B4EB516F9524015E3FC4D28844B40
1485	Чаны-Сакан	5	52	315	76.148058000000006	76.162215000000003	55.355069999999998	55.347991	0103000020E6100000010000000500000051FA42C879095340B32616F88AAC4B4051FA42C87909534036E50AEF72AD4B40ECFA05BB610A534036E50AEF72AD4B40ECFA05BB610A5340B32616F88AAC4B4051FA42C879095340B32616F88AAC4B40
4309	Ускюль	5	52	315	75.345304999999996	75.371347	55.341188000000002	55.32244	0103000020E610000001000000050000004C89247A19D652400C76C3B645A94B404C89247A19D65240D2E4620CACAB4B40EF1D3526C4D75240D2E4620CACAB4B40EF1D3526C4D752400C76C3B645A94B404C89247A19D652400C76C3B645A94B40
4518	Увальское	5	52	315	75.358654000000001	75.391307999999995	55.479903	55.469197999999999	0103000020E610000001000000050000001825E82FF4D652409FAC18AE0EBC4B401825E82FF4D652404B2025766DBD4B4071AAB5300BD952404B2025766DBD4B4071AAB5300BD952409FAC18AE0EBC4B401825E82FF4D652409FAC18AE0EBC4B40
4926	Тайлаково	5	52	315	75.635596000000007	75.656031999999996	55.398088999999999	55.390689999999999	0103000020E61000000100000005000000FB5DD89AADE85240E76F422102B24B40FB5DD89AADE85240DCF29194F4B24B404948A46DFCE95240DCF29194F4B24B404948A46DFCE95240E76F422102B24B40FB5DD89AADE85240E76F422102B24B40
3670	Степановка 2-я	5	52	315	75.505348999999995	75.521598999999995	55.233002999999997	55.222431	0103000020E610000001000000050000003E0455A357E05240EC4E779E789C4B403E0455A357E05240586FD40AD39D4B4015A8C5E061E15240586FD40AD39D4B4015A8C5E061E15240EC4E779E789C4B403E0455A357E05240EC4E779E789C4B40
43382	Сибиряк	5	52	315	75.401342	75.412867000000006	55.149923000000001	55.148189000000002	0103000020E61000000100000005000000B8205B96AFD9524040506EDBF7924B40B8205B96AFD9524088F546AD30934B4040A6B5696CDA524088F546AD30934B4040A6B5696CDA524040506EDBF7924B40B8205B96AFD9524040506EDBF7924B40
3101	Северотатарское	5	52	315	75.879416000000006	75.905745999999994	55.192739000000003	55.177267000000001	0103000020E6100000010000000500000011E50B5A48F852407CD45FAFB0964B4011E50B5A48F85240F6D4EAABAB984B40E61E12BEF7F95240F6D4EAABAB984B40E61E12BEF7F952407CD45FAFB0964B4011E50B5A48F852407CD45FAFB0964B40
41354	Розенталь	5	52	315	75.469505999999996	75.494533000000004	55.319893999999998	55.310718999999999	0103000020E61000000100000005000000A6D1E4620CDE5240779FE3A3C5A74B40A6D1E4620CDE5240E3175E49F2A84B40BD72BD6DA6DF5240E3175E49F2A84B40BD72BD6DA6DF5240779FE3A3C5A74B40A6D1E4620CDE5240779FE3A3C5A74B40
3197	Первомихайловка	5	52	315	75.794686999999996	75.821233000000007	55.118220000000001	55.105500999999997	0103000020E610000001000000050000009BE3DC26DCF25240FF58880E818D4B409BE3DC26DCF25240D7DD3CD5218F4B405859DB148FF45240D7DD3CD5218F4B405859DB148FF45240FF58880E818D4B409BE3DC26DCF25240FF58880E818D4B40
49669	Орловка	5	52	315	75.933629999999994	75.954640999999995	54.881152	54.867263999999999	0103000020E6100000010000000500000020240B98C0FB5240C37FBA81026F4B4020240B98C0FB52400A67B796C9704B40ED9A90D618FD52400A67B796C9704B40ED9A90D618FD5240C37FBA81026F4B4020240B98C0FB5240C37FBA81026F4B40
43635	Новотроицк	5	52	315	75.673675000000003	75.705601000000001	55.007618000000001	54.99823	0103000020E610000001000000050000008048BF7D1DEB52406BF12900C67F4B408048BF7D1DEB5240336E6AA0F9804B4098C1189128ED5240336E6AA0F9804B4098C1189128ED52406BF12900C67F4B408048BF7D1DEB52406BF12900C67F4B40
49668	Новопокровка	5	52	315	75.989873000000003	76.024637999999996	55.198211000000001	55.183081000000001	0103000020E61000000100000005000000618C48145AFF52406EC2BD326F974B40618C48145AFF52408E5A61FA5E994B40490F43AB930153408E5A61FA5E994B40490F43AB930153406EC2BD326F974B40618C48145AFF52406EC2BD326F974B40
3836	Новопервомайское	5	52	315	75.389053000000004	75.415516999999994	55.147983000000004	55.136380000000003	0103000020E6100000010000000500000049DA8D3EE6D852400CEA5BE674914B4049DA8D3EE6D8524097AE601BF1924B40A67B9DD497DA524097AE601BF1924B40A67B9DD497DA52400CEA5BE674914B4049DA8D3EE6D852400CEA5BE674914B40
41263	Новомихайловка	5	52	315	76.168898999999996	76.196799999999996	55.086666999999998	55.068596999999997	0103000020E61000000100000005000000EF54C03DCF0A534046CD57C9C7884B40EF54C03DCF0A53403B527DE7178B4B4094F6065F980C53403B527DE7178B4B4094F6065F980C534046CD57C9C7884B40EF54C03DCF0A534046CD57C9C7884B40
1429	Нововознесенка	5	52	315	75.903509	75.922329000000005	55.362920000000003	55.359169000000001	0103000020E6100000010000000500000011A96917D3F95240575EF23FF9AD4B4011A96917D3F952403C889D2974AE4B40C1C9367007FB52403C889D2974AE4B40C1C9367007FB5240575EF23FF9AD4B4011A96917D3F95240575EF23FF9AD4B40
41380	Никулино	5	52	315	75.502500999999995	75.529927000000001	55.054630000000003	55.04448	0103000020E61000000100000005000000444DF4F928E05240BDA94885B1854B40444DF4F928E05240B4B0A71DFE864B401D91EF52EAE15240B4B0A71DFE864B401D91EF52EAE15240BDA94885B1854B40444DF4F928E05240BDA94885B1854B40
41308	Николаевка	5	52	315	75.72372	75.754344000000003	54.824548999999998	54.806792000000002	0103000020E6100000010000000500000083DDB06D51EE52405456D3F544674B4083DDB06D51EE5240897956D28A694B40C47B0E2C47F05240897956D28A694B40C47B0E2C47F052405456D3F544674B4083DDB06D51EE52405456D3F544674B40
4176	Неудачино	5	52	315	75.492800000000003	75.515212000000005	55.140549	55.130420000000001	0103000020E6100000010000000500000001DE02098ADF5240465F419AB1904B4001DE02098ADF5240253E7782FD914B406FA0C03BF9E05240253E7782FD914B406FA0C03BF9E05240465F419AB1904B4001DE02098ADF5240465F419AB1904B40
41266	Минино	5	52	315	76.211892000000006	76.224630000000005	55.227874	55.221542999999997	0103000020E610000001000000050000002E9276A38F0D534030D461855B9C4B402E9276A38F0D5340EACDA8F92A9D4B40D5EC8156600E5340EACDA8F92A9D4B40D5EC8156600E534030D461855B9C4B402E9276A38F0D534030D461855B9C4B40
4133	Малый Ермак	5	52	315	75.637563	75.648145	55.235748999999998	55.229255000000002	0103000020E61000000100000005000000F0880AD5CDE85240E5B8533A589D4B40F0880AD5CDE852404888F2052D9E4B4038842A357BE952404888F2052D9E4B4038842A357BE95240E5B8533A589D4B40F0880AD5CDE85240E5B8533A589D4B40
2515	Малая Старинка	5	52	315	75.786585000000002	75.806330000000003	54.828122999999998	54.819051000000002	0103000020E610000001000000050000008CA19C6857F25240C860C5A9D6684B408CA19C6857F252405F0839EFFF694B4028F224E99AF352405F0839EFFF694B4028F224E99AF35240C860C5A9D6684B408CA19C6857F25240C860C5A9D6684B40
45429	Лопатино	5	52	315	75.716021999999995	75.736243000000002	55.396427000000003	55.385581999999999	0103000020E61000000100000005000000DB4DF04DD3ED524090F63FC05AB14B40DB4DF04DD3ED52402E20B41EBEB24B402CBAF59A1EEF52402E20B41EBEB24B402CBAF59A1EEF524090F63FC05AB14B40DB4DF04DD3ED524090F63FC05AB14B40
41348	Кузнецово	5	52	315	75.339071000000004	75.364215000000002	55.196012000000003	55.185456000000002	0103000020E610000001000000050000006901DA56B3D552406A6CAF05BD974B406901DA56B3D55240D1CFD4EB16994B409C6D6E4C4FD75240D1CFD4EB16994B409C6D6E4C4FD752406A6CAF05BD974B406901DA56B3D552406A6CAF05BD974B40
45547	Красноярка	5	52	315	76.296009999999995	76.312736999999998	55.542946000000001	55.528931	0103000020E610000001000000050000007E52EDD3F1125340986BD102B4C34B407E52EDD3F11253403CBF28417FC54B40F2CF0CE2031453403CBF28417FC54B40F2CF0CE203145340986BD102B4C34B407E52EDD3F1125340986BD102B4C34B40
5057	Кочневка	5	52	315	76.115421999999995	76.131708000000003	55.486682999999999	55.473551	0103000020E610000001000000050000004ACFF412630753407AFEB4519DBC4B404ACFF412630753407442E8A04BBE4B40C82764E76D0853407442E8A04BBE4B40C82764E76D0853407AFEB4519DBC4B404ACFF412630753407AFEB4519DBC4B40
60695	Комбар	5	52	315	76.310355999999999	76.331070999999994	55.468100999999997	55.460614	0103000020E61000000100000005000000838769DFDC135340350A4966F5BA4B40838769DFDC135340C91CCBBBEABB4B40DB696B4430155340C91CCBBBEABB4B40DB696B4430155340350A4966F5BA4B40838769DFDC135340350A4966F5BA4B40
49671	Козловка	5	52	315	75.684725	75.707927999999995	55.241149	55.231380000000001	0103000020E610000001000000050000003B70CE88D2EB524068791EDC9D9D4B403B70CE88D2EB5240473B6EF8DD9E4B400DFB3DB14EED5240473B6EF8DD9E4B400DFB3DB14EED524068791EDC9D9D4B403B70CE88D2EB524068791EDC9D9D4B40
45924	Киевка	5	52	315	76.056358000000003	76.079040000000006	55.261988000000002	55.251080000000002	0103000020E610000001000000050000008DB7955E9B0353400057B26323A04B408DB7955E9B035340E4F8A1D288A14B40DBC4C9FD0E055340E4F8A1D288A14B40DBC4C9FD0E0553400057B26323A04B408DB7955E9B0353400057B26323A04B40
41386	Камышино	5	52	315	75.872967000000003	75.886827999999994	54.879494999999999	54.874212	0103000020E610000001000000050000002FDFFAB0DEF75240A8E2C62DE66F4B402FDFFAB0DEF752406DFFCA4A93704B40554B3ACAC1F852406DFFCA4A93704B40554B3ACAC1F85240A8E2C62DE66F4B402FDFFAB0DEF75240A8E2C62DE66F4B40
4800	Казачий Мыс	5	52	315	75.858054999999993	75.890466000000004	55.515858999999999	55.502222000000003	0103000020E61000000100000005000000D5CA845FEAF6524076AA7CCF48C04B40D5CA845FEAF65240732CEFAA07C24B40CC0C1B65FDF85240732CEFAA07C24B40CC0C1B65FDF8524076AA7CCF48C04B40D5CA845FEAF6524076AA7CCF48C04B40
1952	Казаткуль	5	52	315	76.039703000000003	76.066410000000005	55.036169000000001	55.026515000000003	0103000020E6100000010000000500000066A3737E8A0253403EEDF0D764834B4066A3737E8A0253408410902FA1844B402788BA0F400453408410902FA1844B402788BA0F400453403EEDF0D764834B4066A3737E8A0253403EEDF0D764834B40
41298	Ивановка	5	52	315	76.315791000000004	76.340853999999993	55.256636999999998	55.245604	0103000020E61000000100000005000000C15774EB3514534026E2ADF36F9F4B40C15774EB35145340C6F8307BD9A04B407DAD4B8DD0155340C6F8307BD9A04B407DAD4B8DD015534026E2ADF36F9F4B40C15774EB3514534026E2ADF36F9F4B40
49670	Зубовка	5	52	315	75.513092	75.536771999999999	54.857019999999999	54.842595000000003	0103000020E61000000100000005000000B6F5D37FD6E05240F6622827DA6B4B40B6F5D37FD6E052404B02D4D4B26D4B40255AF2785AE252404B02D4D4B26D4B40255AF2785AE25240F6622827DA6B4B40B6F5D37FD6E05240F6622827DA6B4B40
41344	Евгеньевка	5	52	315	75.684265999999994	75.696905999999998	55.087784999999997	55.078958	0103000020E61000000100000005000000F1F09E03CBEB5240F8E0B54B1B8A4B40F1F09E03CBEB5240280AF4893C8B4B40B7989F1B9AEC5240280AF4893C8B4B40B7989F1B9AEC5240F8E0B54B1B8A4B40F1F09E03CBEB5240F8E0B54B1B8A4B40
41353	Дмитриевка	5	52	315	75.591155999999998	75.616453000000007	55.172300999999997	55.156357999999997	0103000020E6100000010000000500000063B5F97FD5E55240E63BF88903944B4063B5F97FD5E55240B7088CF50D964B405AA148F773E75240B7088CF50D964B405AA148F773E75240E63BF88903944B4063B5F97FD5E55240E63BF88903944B40
41183	Городенка	5	52	315	75.796735999999996	75.824349999999995	54.958689	54.948711000000003	0103000020E61000000100000005000000EFE2FDB8FDF25240802DAF5C6F794B40EFE2FDB8FDF2524079043752B67A4B40499D8026C2F4524079043752B67A4B40499D8026C2F45240802DAF5C6F794B40EFE2FDB8FDF25240802DAF5C6F794B40
41206	Волово	5	52	315	75.901111	75.914845999999997	54.838825999999997	54.828693000000001	0103000020E6100000010000000500000037C478CDABF952404AB6BA9C126A4B4037C478CDABF952406A847EA65E6B4B4017B83CD68CFA52406A847EA65E6B4B4017B83CD68CFA52404AB6BA9C126A4B4037C478CDABF952404AB6BA9C126A4B40
40397	Воздвиженка	5	52	315	75.277392000000006	75.294182000000006	55.288961999999998	55.281267	0103000020E61000000100000005000000030B60CAC0D15240D6389B8E00A44B40030B60CAC0D15240B4E4F1B4FCA44B409A44BDE0D3D25240B4E4F1B4FCA44B409A44BDE0D3D25240D6389B8E00A44B40030B60CAC0D15240D6389B8E00A44B40
3301	Ваховский	5	52	315	75.906519000000003	75.91516	55.088352	55.082256000000001	0103000020E61000000100000005000000F88C446804FA52402CF3565D878A4B40F88C446804FA5240A2444B1E4F8B4B40DFA63FFB91FA5240A2444B1E4F8B4B40DFA63FFB91FA52402CF3565D878A4B40F88C446804FA52402CF3565D878A4B40
2854	Варваровка	5	52	315	75.508860999999996	75.531058999999999	54.961941000000003	54.956839000000002	0103000020E610000001000000050000006E4DBA2D91E05240C8444AB3797A4B406E4DBA2D91E052403DD7F7E1207B4B40C64FE3DEFCE152403DD7F7E1207B4B40C64FE3DEFCE15240C8444AB3797A4B406E4DBA2D91E05240C8444AB3797A4B40
41334	Богдановка	5	52	315	76.204373000000004	76.224423000000002	55.319023000000001	55.316062000000002	0103000020E61000000100000005000000DECB7D72140D534012C138B874A84B40DECB7D72140D5340FED5E3BED5A84B40185E49F25C0E5340FED5E3BED5A84B40185E49F25C0E534012C138B874A84B40DECB7D72140D534012C138B874A84B40
41223	Безбожник	5	52	315	75.520701000000003	75.531166999999996	55.183683000000002	55.173518999999999	0103000020E61000000100000005000000A67F492A53E15240081EDFDE35964B40A67F492A53E1524064EAAEEC82974B40B96DDFA3FEE1524064EAAEEC82974B40B96DDFA3FEE15240081EDFDE35964B40A67F492A53E15240081EDFDE35964B40
62069	с.Харьковка	5	52	33	81.714889999999997	83.047469000000007	54.409399000000001	53.494301999999998	0103000020E61000000100000005000000328FFCC1C06D5440772CB64945BF4A40328FFCC1C06D5440EF01BA2F67344B40BAA46ABB09C35440EF01BA2F67344B40BAA46ABB09C35440772CB64945BF4A40328FFCC1C06D5440772CB64945BF4A40
46433	Шипуновский	5	52	33	82.593658000000005	82.601680000000002	53.971826	53.963923999999999	0103000020E6100000010000000500000090C01F7EFEA554402DEA93DC61FB4A4090C01F7EFEA5544085B35BCB64FC4A4011AAD4EC81A6544085B35BCB64FC4A4011AAD4EC81A654402DEA93DC61FB4A4090C01F7EFEA554402DEA93DC61FB4A40
1083	Шипуново	5	52	33	82.573554000000001	82.623429000000002	54.014907999999998	53.989002999999997	0103000020E610000001000000050000005C1FD61BB5A45440AC527AA697FE4A405C1FD61BB5A4544071395E81E8014B403198BF42E6A7544071395E81E8014B403198BF42E6A75440AC527AA697FE4A405C1FD61BB5A45440AC527AA697FE4A40
513	Шигаево	5	52	33	82.308093	82.333785000000006	54.259273999999998	54.242871999999998	0103000020E6100000010000000500000019C8B3CBB79354409B8E006E161F4B4019C8B3CBB7935440FF59F3E32F214B404EB9C2BB5C955440FF59F3E32F214B404EB9C2BB5C9554409B8E006E161F4B4019C8B3CBB79354409B8E006E161F4B40
869	Шарчино	5	52	33	82.510609000000002	82.550279000000003	54.274597	54.25949	0103000020E61000000100000005000000C5025FD1ADA05440CCD1E3F736214B40C5025FD1ADA05440344A97FE25234B403D2B69C537A35440344A97FE25234B403D2B69C537A35440CCD1E3F736214B40C5025FD1ADA05440CCD1E3F736214B40
260	Шайдурово	5	52	33	81.774124999999998	81.808961999999994	54.018098999999999	54.005321000000002	0103000020E61000000100000005000000068195438B715440B37DC85BAE004B40068195438B7154408F8B6A1151024B403B6D8D08C67354408F8B6A1151024B403B6D8D08C6735440B37DC85BAE004B40068195438B715440B37DC85BAE004B40
1145	Холодное	5	52	33	82.575072000000006	82.595742999999999	54.121197000000002	54.109411000000001	0103000020E610000001000000050000001A36CAFACDA454404D69FD2D010E4B401A36CAFACDA45440C9AF1F62830F4B408A743FA720A65440C9AF1F62830F4B408A743FA720A654404D69FD2D010E4B401A36CAFACDA454404D69FD2D010E4B40
32261	Тараданово	5	52	33	81.839083000000002	81.853589999999997	53.775606000000003	53.765360999999999	0103000020E610000001000000050000004BE82E89B375544022516859F7E14A404BE82E89B37554406B4AB20E47E34A40548CF337A17654406B4AB20E47E34A40548CF337A176544022516859F7E14A404BE82E89B375544022516859F7E14A40
31459	Сузун	5	52	33	82.276157999999995	82.348130999999995	53.822735000000002	53.762695000000001	0103000020E61000000100000005000000D7A19A92AC9154404FE960FD9FE14A40D7A19A92AC915440252367614FE94A4052EE3EC747965440252367614FE94A4052EE3EC7479654404FE960FD9FE14A40D7A19A92AC9154404FE960FD9FE14A40
915	Плоское	5	52	33	82.442930000000004	82.466807000000003	54.217357	54.204566999999997	0103000020E61000000100000005000000B51A12F7589C5440A06B5F402F1A4B40B51A12F7589C54404147AB5AD21B4B40CFA2772AE09D54404147AB5AD21B4B40CFA2772AE09D5440A06B5F402F1A4B40B51A12F7589C5440A06B5F402F1A4B40
41333	Нечунаевский	5	52	33	82.440450999999996	82.456001000000001	53.807042000000003	53.800739999999998	0103000020E61000000100000005000000641F6459309C5440AD4CF8A57EE64A40641F6459309C5440CD3FFA264DE74A405F7CD11E2F9D5440CD3FFA264DE74A405F7CD11E2F9D5440AD4CF8A57EE64A40641F6459309C5440AD4CF8A57EE64A40
243	Мышланка	5	52	33	82.068674000000001	82.108414999999994	54.022933000000002	54.010643999999999	0103000020E610000001000000050000007905A2276584544006F357C85C014B407905A22765845440E57FF277EF024B4055D97745F0865440E57FF277EF024B4055D97745F086544006F357C85C014B407905A2276584544006F357C85C014B40
31842	Мереть	5	52	33	82.386938000000001	82.409737000000007	53.585445999999997	53.566054000000001	0103000020E6100000010000000500000019E59997C39854408FE21C7574C84A4019E59997C398544079C9FFE4EFCA4A4084BD8921399A544079C9FFE4EFCA4A4084BD8921399A54408FE21C7574C84A4019E59997C39854408FE21C7574C84A40
1016	Маюрово	5	52	33	82.421396999999999	82.450018	54.327620000000003	54.307972999999997	0103000020E610000001000000050000007B681F2BF89A54408786C5A86B274B407B681F2BF89A5440FDC1C073EF294B4020274C18CD9C5440FDC1C073EF294B4020274C18CD9C54408786C5A86B274B407B681F2BF89A54408786C5A86B274B40
32153	Малышево	5	52	33	82.040754000000007	82.080262000000005	53.747532999999997	53.736663999999998	0103000020E61000000100000005000000994BAAB69B825440FD1186014BDE4A40994BAAB69B82544023D74D29AFDF4A4024473A032385544023D74D29AFDF4A4024473A0323855440FD1186014BDE4A40994BAAB69B825440FD1186014BDE4A40
361	Малая Крутишка	5	52	33	81.859348999999995	81.887816000000001	54.065603000000003	54.056334	0103000020E610000001000000050000006BB6F292FF76544091D3D7F335074B406BB6F292FF7654407FC2D9AD65084B40653733FAD17854407FC2D9AD65084B40653733FAD178544091D3D7F335074B406BB6F292FF76544091D3D7F335074B40
31901	Лесниковский	5	52	33	82.351185000000001	82.372439	53.597664000000002	53.589792000000003	0103000020E610000001000000050000002176A6D079965440A2B8E34D7ECB4A402176A6D0799654408FFF024180CC4A405130630AD69754408FFF024180CC4A405130630AD6975440A2B8E34D7ECB4A402176A6D079965440A2B8E34D7ECB4A40
39	Красный Камешок	5	52	33	82.156672999999998	82.173561000000007	53.914855000000003	53.903317999999999	0103000020E61000000100000005000000A3CA30EE068A5440AEF199EC9FF34A40A3CA30EE068A544082CAF8F719F54A401CB7989F1B8B544082CAF8F719F54A401CB7989F1B8B5440AEF199EC9FF34A40A3CA30EE068A5440AEF199EC9FF34A40
32346	Ключики	5	52	33	81.886936000000006	81.914648999999997	53.906108000000003	53.894055000000002	0103000020E610000001000000050000004969368FC3785440A3E9EC6470F24A404969368FC37854406E52D158FBF34A406C94F59B897A54406E52D158FBF34A406C94F59B897A5440A3E9EC6470F24A404969368FC3785440A3E9EC6470F24A40
32228	Каргаполово	5	52	33	81.923362999999995	81.945228	53.756509000000001	53.745615999999998	0103000020E6100000010000000500000088D51F61187B5440EAAF575870DF4A4088D51F61187B544099107349D5E04A40DDD0949D7E7C544099107349D5E04A40DDD0949D7E7C5440EAAF575870DF4A4088D51F61187B5440EAAF575870DF4A40
32447	Земледелец	5	52	33	82.032139999999998	82.054175000000001	53.869199999999999	53.860624000000001	0103000020E610000001000000050000002E39EE940E8254408C135FED28EE4A402E39EE940E82544073D712F241EF4A40B1506B9A7783544073D712F241EF4A40B1506B9A778354408C135FED28EE4A402E39EE940E8254408C135FED28EE4A40
753	Заковряжино	5	52	33	82.387782999999999	82.452380000000005	54.043737	54.02187	0103000020E6100000010000000500000077BCC96FD1985440BB61DBA2CC024B4077BCC96FD198544005508C2C99054B4054573ECBF39C544005508C2C99054B4054573ECBF39C5440BB61DBA2CC024B4077BCC96FD1985440BB61DBA2CC024B40
32016	Верх-Сузун	5	52	33	82.269591000000005	82.316663000000005	53.690835	53.672435999999998	0103000020E61000000100000005000000F1129CFA409154409753026212D64A40F1129CFA4091544051F701486DD84A409C36E3344494544051F701486DD84A409C36E334449454409753026212D64A40F1129CFA409154409753026212D64A40
625	Болтово	5	52	33	82.247581999999994	82.276436000000004	54.038350000000001	54.017764999999997	0103000020E6100000010000000500000002452C62D88F5440B8019F1F46024B4002452C62D88F54409BE61DA7E8044B40F9DB9E20B19154409BE61DA7E8044B40F9DB9E20B1915440B8019F1F46024B4002452C62D88F5440B8019F1F46024B40
32476	Бобровка	5	52	33	82.107167000000004	82.156358999999995	53.941330999999998	53.914535999999998	0103000020E61000000100000005000000780DFAD2DB865440E08101840FF54A40780DFAD2DB86544001DBC1887DF84A40DBDB2DC9018A544001DBC1887DF84A40DBDB2DC9018A5440E08101840FF54A40780DFAD2DB865440E08101840FF54A40
503	Битки	5	52	33	82.249450999999993	82.296091000000004	54.213124000000001	54.189835000000002	0103000020E6100000010000000500000016BD5301F78F54406E5166834C184B4016BD5301F78F544011FFB0A5471B4B40F568AA27F392544011FFB0A5471B4B40F568AA27F39254406E5166834C184B4016BD5301F78F54406E5166834C184B40
35203	Суходолье	5	52	3428	79.313998999999995	79.325739999999996	55.051302999999997	55.043298	0103000020E6100000010000000500000082FE428F18D45340B9FDF2C98A854B4082FE428F18D45340E597C11891864B40F0BF95ECD8D45340E597C11891864B40F0BF95ECD8D45340B9FDF2C98A854B4082FE428F18D45340B9FDF2C98A854B40
49608	деревня  Большие Кулики,	5	52	1376	77.709418999999997	77.724709000000004	56.284323999999998	56.273584999999997	0103000020E610000001000000050000004E0AF31E676D53408CD651D504234C404E0AF31E676D5340E4BB94BA64244C407B87DBA1616E5340E4BB94BA64244C407B87DBA1616E53408CD651D504234C404E0AF31E676D53408CD651D504234C40
31182	Чуваши	5	52	1376	78.797279000000003	78.831756999999996	56.403830999999997	56.393279999999997	0103000020E6100000010000000500000068B27F9E06B35340DF15C1FF56324C4068B27F9E06B35340340EF5BBB0334C40054EB6813BB55340340EF5BBB0334C40054EB6813BB55340DF15C1FF56324C4068B27F9E06B35340DF15C1FF56324C40
31123	Чебаки	5	52	1376	78.535932000000003	78.564687000000006	56.328349000000003	56.317816999999998	0103000020E610000001000000050000005038BBB54CA25340718E3A3AAE284C405038BBB54CA2534050560C57072A4C407D5EF1D423A4534050560C57072A4C407D5EF1D423A45340718E3A3AAE284C405038BBB54CA25340718E3A3AAE284C40
31075	Федоровка	5	52	1376	78.821363000000005	78.853622000000001	56.082416000000002	56.067498999999998	0103000020E610000001000000050000003FC91D3691B45340A0C1A6CEA3084C403FC91D3691B453406555849B8C0A4C405A492BBEA1B653406555849B8C0A4C405A492BBEA1B65340A0C1A6CEA3084C403FC91D3691B45340A0C1A6CEA3084C40
30796	Среднеичинский	5	52	1376	78.437297000000001	78.455038999999999	55.898856000000002	55.887977999999997	0103000020E61000000100000005000000E4688EACFC9B5340A3C85A43A9F14B40E4688EACFC9B53401DE8A1B60DF34B40E4D9E55B1F9D53401DE8A1B60DF34B40E4D9E55B1F9D5340A3C85A43A9F14B40E4688EACFC9B5340A3C85A43A9F14B40
30881	Северное	5	52	1376	78.320238000000003	78.387682999999996	56.361274999999999	56.332656	0103000020E61000000100000005000000EF3B86C77E945340BA68C878942A4C40EF3B86C77E94534063EE5A423E2E4C40C58D5BCCCF98534063EE5A423E2E4C40C58D5BCCCF985340BA68C878942A4C40EF3B86C77E945340BA68C878942A4C40
30967	Остяцк	5	52	1376	78.071197999999995	78.088751000000002	56.715311999999997	56.703043999999998	0103000020E6100000010000000500000099620E828E84534013D38558FD594C4099620E828E845340DA37F7578F5B4C40309FAC18AE855340DA37F7578F5B4C40309FAC18AE85534013D38558FD594C4099620E828E84534013D38558FD594C40
30977	Останинка	5	52	1376	78.248894000000007	78.278223999999994	56.729925999999999	56.716403	0103000020E61000000100000005000000EC8A19E1ED8F5340CEE0EF17B35B4C40EC8A19E1ED8F5340034015376E5D4C40963D096CCE915340034015376E5D4C40963D096CCE915340CEE0EF17B35B4C40EC8A19E1ED8F5340CEE0EF17B35B4C40
30751	Новотроицк	5	52	1376	78.669027	78.692239000000001	56.195680000000003	56.179845999999998	0103000020E6100000010000000500000006499F56D1AA53408028983105174C4006499F56D1AA53409B3DD00A0C194C400281CEA44DAC53409B3DD00A0C194C400281CEA44DAC53408028983105174C4006499F56D1AA53408028983105174C40
45957	Коб-Кордон	5	52	1376	77.286996000000002	80.555749000000006	57.112099000000001	55.727297999999998	0103000020E610000001000000050000004D8578245E5253401D39D21918DD4B404D8578245E52534008759142598E4C4039F240649123544008759142598E4C4039F24064912354401D39D21918DD4B404D8578245E5253401D39D21918DD4B40
41383	Ивановка	5	52	1376	78.840057000000002	78.850549000000001	56.349330000000002	56.344441000000003	0103000020E61000000100000005000000A8716F7EC3B55340663387A4162C4C40A8716F7EC3B553407FC16ED8B62C4C4050A912656FB653407FC16ED8B62C4C4050A912656FB65340663387A4162C4C40A8716F7EC3B55340663387A4162C4C40
30573	Гражданцево	5	52	1376	78.154705000000007	78.174674999999993	56.365667000000002	56.352876000000002	0103000020E61000000100000005000000C6E1CCAFE68953408BC56F0A2B2D4C40C6E1CCAFE6895340FC1C1F2DCE2E4C40711B0DE02D8B5340FC1C1F2DCE2E4C40711B0DE02D8B53408BC56F0A2B2D4C40C6E1CCAFE68953408BC56F0A2B2D4C40
31143	Витинск	5	52	1376	78.403709000000006	78.426410000000004	56.306562999999997	56.293326999999998	0103000020E610000001000000050000007506465ED6995340530438BD8B254C407506465ED6995340F294D5743D274C40FE2B2B4D4A9B5340F294D5743D274C40FE2B2B4D4A9B5340530438BD8B254C407506465ED6995340530438BD8B254C40
31344	Весёлая	5	52	1376	78.213419000000002	78.230829	56.612454	56.599423999999999	0103000020E6100000010000000500000015562AA8A88D53400038F6ECB94C4C4015562AA8A88D5340F62686E4644E4C40FA7DFFE6C58E5340F62686E4644E4C40FA7DFFE6C58E53400038F6ECB94C4C4015562AA8A88D53400038F6ECB94C4C40
30357	Верх-Красноярка	5	52	1376	77.904983000000001	77.941480999999996	56.377059000000003	56.363228999999997	0103000020E61000000100000005000000E71BD13DEB795340B9FAB1497E2E4C40E71BD13DEB795340CCD4247843304C408B338639417C5340CCD4247843304C408B338639417C5340B9FAB1497E2E4C40E71BD13DEB795340B9FAB1497E2E4C40
31282	Биаза	5	52	1376	78.288375000000002	78.310123000000004	56.605964999999998	56.583485000000003	0103000020E61000000100000005000000FA7E6ABC74925340715AF0A2AF4A4C40FA7E6ABC74925340A4C2D842904D4C4032AF230ED9935340A4C2D842904D4C4032AF230ED9935340715AF0A2AF4A4C40FA7E6ABC74925340715AF0A2AF4A4C40
30568	Бергуль	5	52	1376	78.463277000000005	78.498553000000001	56.612473999999999	56.601757999999997	0103000020E610000001000000050000004CFF9254A69D53409D0DF967064D4C404CFF9254A69D53403DD34B8C654E4C40A794D74AE89F53403DD34B8C654E4C40A794D74AE89F53409D0DF967064D4C404CFF9254A69D53409D0DF967064D4C40
14944	Алексеевка	5	52	1376	77.723073999999997	77.736917000000005	56.316578999999997	56.312004999999999	0103000020E61000000100000005000000A0A52BD8466E53402098A3C7EF274C40A0A52BD8466E5340D9CC21A985284C4074B7EBA5296F5340D9CC21A985284C4074B7EBA5296F53402098A3C7EF274C40A0A52BD8466E53402098A3C7EF274C40
36329	Красноникольск	5	52	3594	75.403093999999996	75.421788000000006	55.617032000000002	55.608521000000003	0103000020E61000000100000005000000AFCDC64ACCD95240F1F62004E4CD4B40AFCDC64ACCD95240F14A92E7FACE4B4019761893FEDA5240F14A92E7FACE4B4019761893FEDA5240F1F62004E4CD4B40AFCDC64ACCD95240F1F62004E4CD4B40
37198	Платоновка	5	52	4868	75.418454999999994	75.441936999999996	55.165385000000001	55.156281	0103000020E6100000010000000500000040F67AF7C7DA52403BFE0B0401944B4040F67AF7C7DA5240DE1FEF552B954B401C7920B248DC5240DE1FEF552B954B401C7920B248DC52403BFE0B0401944B4040F67AF7C7DA52403BFE0B0401944B40
29779	Шайдуровский	5	52	1819	81.308573999999993	81.331202000000005	54.417969999999997	54.401589999999999	0103000020E61000000100000005000000569929ADBF5354404833164D67334B40569929ADBF535440C45A7C0A80354B40AB97DF6932555440C45A7C0A80354B40AB97DF69325554404833164D67334B40569929ADBF5354404833164D67334B40
49614	Чингисы	5	52	1819	81.580431000000004	81.657910000000001	54.132503999999997	54.118516	0103000020E610000001000000050000006AA510C825655440C00644882B0F4B406AA510C8256554406A4B1DE4F5104B40876D8B321B6A54406A4B1DE4F5104B40876D8B321B6A5440C00644882B0F4B406AA510C825655440C00644882B0F4B40
28810	Чернаково	5	52	1819	81.923398000000006	82.454787999999994	54.383468000000001	54.362904	0103000020E6100000010000000500000047CCECF3187B544036CB65A3732E4B4047CCECF3187B54400188BB7A15314B403FA7203F1B9D54400188BB7A15314B403FA7203F1B9D544036CB65A3732E4B4047CCECF3187B544036CB65A3732E4B40
29593	Черемшанка	5	52	1819	81.489243000000002	81.504469	54.219788999999999	54.211754999999997	0103000020E610000001000000050000000133DFC14F5F5440DAE1AFC91A1B4B400133DFC14F5F5440A182C30B221C4B402236583849605440A182C30B221C4B402236583849605440DAE1AFC91A1B4B400133DFC14F5F5440DAE1AFC91A1B4B40
29699	Филиппово	5	52	1819	81.510191000000006	81.540177	54.326490999999997	54.309396	0103000020E61000000100000005000000ABED26F8A6605440B1C1C2499A274B40ABED26F8A66054401BB80375CA294B404A438D42926254401BB80375CA294B404A438D4292625440B1C1C2499A274B40ABED26F8A6605440B1C1C2499A274B40
29965	Устюжанино	5	52	1819	81.285801000000006	81.344515000000001	54.189734999999999	54.175218000000001	0103000020E61000000100000005000000810A47904A525440D4D51D8B6D164B40810A47904A5254400AF4893C49184B40D07EA4880C5654400AF4893C49184B40D07EA4880C565440D4D51D8B6D164B40810A47904A525440D4D51D8B6D164B40
30154	Усть-Хмелевка	5	52	1819	81.758971000000003	81.782658999999995	54.275500999999998	54.264738000000001	0103000020E6100000010000000500000032E719FB9270544015014EEFE2214B4032E719FB92705440F581E49D43234B40E23AC61517725440F581E49D43234B40E23AC6151772544015014EEFE2214B4032E719FB9270544015014EEFE2214B40
29636	Усть-Луковка	5	52	1819	81.692432999999994	81.757622999999995	54.397041000000002	54.375697000000002	0103000020E61000000100000005000000F46A80D2506C5440481ADCD616304B40F46A80D2506C5440E8154F3DD2324B40A2EC2DE57C705440E8154F3DD2324B40A2EC2DE57C705440481ADCD616304B40F46A80D2506C5440481ADCD616304B40
29889	Усть-Алеус	5	52	1819	81.437023999999994	81.458331999999999	54.102353000000001	54.097000000000001	0103000020E610000001000000050000004BE48233F85B544023DBF97E6A0C4B404BE48233F85B5440E1D231E7190D4B4075ADBD4F555D5440E1D231E7190D4B4075ADBD4F555D544023DBF97E6A0C4B404BE48233F85B544023DBF97E6A0C4B40
29184	Степной	5	52	1819	82.100160000000002	82.116060000000004	54.69699	54.688462000000001	0103000020E6100000010000000500000083177D0569865440F644D7851F584B4083177D0569865440CCD1E3F736594B40EC17EC866D875440CCD1E3F736594B40EC17EC866D875440F644D7851F584B4083177D0569865440F644D7851F584B40
29873	Спирино	5	52	1819	81.529747999999998	81.585038999999995	54.146023	54.122183	0103000020E61000000100000005000000C5C72764E761544047904AB1A30F4B40C5C72764E76154405EBBB4E1B0124B409CF86A47716554405EBBB4E1B0124B409CF86A477165544047904AB1A30F4B40C5C72764E761544047904AB1A30F4B40
29686	Рогалево	5	52	1819	81.575875999999994	81.611997000000002	54.354734999999998	54.336933000000002	0103000020E6100000010000000500000048A30227DB645440BAF8DB9E202B4B4048A30227DB6454408FDFDBF4672D4B40021077F52A6754408FDFDBF4672D4B40021077F52A675440BAF8DB9E202B4B4048A30227DB645440BAF8DB9E202B4B40
27401	Пушкарево	5	52	1819	81.374654000000007	81.396141	54.182969999999997	54.161766999999998	0103000020E610000001000000050000003354C554FA5754403849F3C7B4144B403354C554FA57544016139B8F6B174B40B4E6C75F5A59544016139B8F6B174B40B4E6C75F5A5954403849F3C7B4144B403354C554FA5754403849F3C7B4144B40
29793	Пролетарский	5	52	1819	81.150739999999999	81.173717999999994	54.392082000000002	54.375681	0103000020E61000000100000005000000BD8C62B9A5495440425DA45016304B40BD8C62B9A5495440D6AC33BE2F324B407F2E1A321E4B5440D6AC33BE2F324B407F2E1A321E4B5440425DA45016304B40BD8C62B9A5495440425DA45016304B40
28965	Плотниково	5	52	1819	82.200204999999997	82.232517999999999	54.600707999999997	54.590285999999999	0103000020E61000000100000005000000B9DFA128D08C5440B1A4DC7D8E4B4B40B9DFA128D08C54400839EFFFE34C4B40CE6E2D93E18E54400839EFFFE34C4B40CE6E2D93E18E5440B1A4DC7D8E4B4B40B9DFA128D08C5440B1A4DC7D8E4B4B40
29386	Петровский	5	52	1819	81.727422000000004	81.761127000000002	54.536852000000003	54.510410999999998	0103000020E61000000100000005000000051901158E6E54406342CC2555414B40051901158E6E54406765FB90B7444B409146054EB67054406765FB90B7444B409146054EB67054406342CC2555414B40051901158E6E54406342CC2555414B40
28601	Ордынское	5	52	1819	81.846197000000004	81.944643999999997	54.374741999999998	54.342759000000001	0103000020E610000001000000050000004B3E76172876544070B4E386DF2B4B404B3E7617287654400438BD8BF72F4B4035971B0C757C54400438BD8BF72F4B4035971B0C757C544070B4E386DF2B4B404B3E76172876544070B4E386DF2B4B40
29368	Новый Шарап	5	52	1819	82.021790999999993	82.062771999999995	54.423276999999999	54.405526000000002	0103000020E610000001000000050000003716140665815440BFD6A546E8334B4037161406658154401213D4F02D364B40B0C6D974048454401213D4F02D364B40B0C6D97404845440BFD6A546E8334B403716140665815440BFD6A546E8334B40
28996	Новопичугово	5	52	1819	82.335832999999994	82.357715999999996	54.615298000000003	54.601970000000001	0103000020E61000000100000005000000B9FAB1497E95544029965B5A0D4D4B40B9FAB1497E955440A9A5B915C24E4B406150A6D1E4965440A9A5B915C24E4B406150A6D1E496544029965B5A0D4D4B40B9FAB1497E95544029965B5A0D4D4B40
30072	Новокузьминка	5	52	1819	81.151386000000002	81.185261999999994	54.134624000000002	54.125929999999997	0103000020E61000000100000005000000A0C4E74EB0495440EACA67791E104B40A0C4E74EB0495440DCA0F65B3B114B4042CC2555DB4B5440DCA0F65B3B114B4042CC2555DB4B5440EACA67791E104B40A0C4E74EB0495440EACA67791E104B40
30082	Нижнекаменка	5	52	1819	81.892290000000003	81.929489000000004	54.323833999999998	54.304257999999997	0103000020E61000000100000005000000102384471B795440EFC517EDF1264B40102384471B7954409BAA7B6473294B40793F6EBF7C7B54409BAA7B6473294B40793F6EBF7C7B5440EFC517EDF1264B40102384471B795440EFC517EDF1264B40
30263	Милованово	5	52	1819	81.542612000000005	81.561818000000002	54.097507	54.089036999999998	0103000020E61000000100000005000000B39AAE27BA62544025917D90650B4B40B39AAE27BA625440C710001C7B0C4B4077137CD3F4635440C710001C7B0C4B4077137CD3F463544025917D90650B4B40B39AAE27BA62544025917D90650B4B40
29248	Малый Чик	5	52	1819	81.957381999999996	81.976731000000001	54.697640999999997	54.684272	0103000020E61000000100000005000000DCF126BF457D5440C5C8923996574B40DCF126BF457D5440A3ACDF4C4C594B40527FBDC2827E5440A3ACDF4C4C594B40527FBDC2827E5440C5C8923996574B40DCF126BF457D5440C5C8923996574B40
29113	Малоирменка	5	52	1819	81.878905000000003	81.905485999999996	54.543709999999997	54.531022	0103000020E610000001000000050000009ED2C1FA3F7854406FBA6587F8434B409ED2C1FA3F7854400B410E4A98454B40183F8D7BF37954400B410E4A98454B40183F8D7BF37954406FBA6587F8434B409ED2C1FA3F7854406FBA6587F8434B40
29324	Красный Яр	5	52	1819	82.138976	82.168431999999996	54.463403	54.443083000000001	0103000020E6100000010000000500000073BB97FBE4885440F03499F1B6384B4073BB97FBE488544024EF1CCA503B4B4064E60297C78A544024EF1CCA503B4B4064E60297C78A5440F03499F1B6384B4073BB97FBE4885440F03499F1B6384B40
29066	Козиха	5	52	1819	82.096073000000004	82.141536000000002	54.567858000000001	54.557631000000001	0103000020E61000000100000005000000D5415E0F268654402E1EDE7360474B40D5415E0F26865440D0622992AF484B403ACD02ED0E895440D0622992AF484B403ACD02ED0E8954402E1EDE7360474B40D5415E0F268654402E1EDE7360474B40
29541	Кирза	5	52	1819	81.635604999999998	81.679271999999997	54.263713000000003	54.223458999999998	0103000020E61000000100000005000000240B98C0AD685440997FF44D9A1C4B40240B98C0AD685440D943FB58C1214B40AA454431796B5440D943FB58C1214B40AA454431796B5440997FF44D9A1C4B40240B98C0AD685440997FF44D9A1C4B40
29239	Верх-Чик	5	52	1819	81.925535999999994	81.953554999999994	54.662166999999997	54.638361000000003	0103000020E6100000010000000500000052D158FB3B7B54405C0531D0B5514B4052D158FB3B7B5440C6BE64E3C1544B40FCFB8C0B077D5440C6BE64E3C1544B40FCFB8C0B077D54405C0531D0B5514B4052D158FB3B7B54405C0531D0B5514B40
28875	Верх-Ирмень	5	52	1819	82.206789999999998	82.260985000000005	54.589717	54.557527	0103000020E61000000100000005000000F3C81F0C3C8D544089D1730B5D474B40F3C81F0C3C8D54409772BED87B4B4B40C8EF6DFAB39054409772BED87B4B4B40C8EF6DFAB390544089D1730B5D474B40F3C81F0C3C8D544089D1730B5D474B40
29998	Верх-Алеус	5	52	1819	81.254118000000005	81.283186999999998	54.190530000000003	54.162711000000002	0103000020E61000000100000005000000CCD424784350544088D9CBB6D3144B40CCD424784350544015747B4963184B40C0E95DBC1F52544015747B4963184B40C0E95DBC1F52544088D9CBB6D3144B40CCD424784350544088D9CBB6D3144B40
28791	Вагайцево	5	52	1819	81.839217000000005	81.881051999999997	54.374710999999998	54.358669999999996	0103000020E61000000100000005000000D34F38BBB5755440350708E6E82D4B40D34F38BBB5755440C939B187F62F4B40D384ED2763785440C939B187F62F4B40D384ED2763785440350708E6E82D4B40D34F38BBB5755440350708E6E82D4B40
29482	Бугринская Роща	5	52	1819	81.697185000000005	81.708359999999999	54.476191	54.469451999999997	0103000020E61000000100000005000000C190D5AD9E6C54405985CD00173C4B40C190D5AD9E6C544024D3A1D3F33C4B40DA722EC5556D544024D3A1D3F33C4B40DA722EC5556D54405985CD00173C4B40C190D5AD9E6C54405985CD00173C4B40
29431	Борисовский	5	52	1819	81.602457000000001	81.626056000000005	54.538795	54.525604000000001	0103000020E61000000100000005000000C30FCEA78E665440CA52EBFD46434B40C30FCEA78E665440C91F0C3CF7444B40BC5D2F4D11685440C91F0C3CF7444B40BC5D2F4D11685440CA52EBFD46434B40C30FCEA78E665440CA52EBFD46434B40
60678	Березовка	5	52	1819	82.043897999999999	82.068144000000004	54.615870999999999	54.603180000000002	0103000020E6100000010000000500000007978E39CF825440F7CC9200354D4B4007978E39CF82544004C765DCD44E4B40CBDAA6785C84544004C765DCD44E4B40CBDAA6785C845440F7CC9200354D4B4007978E39CF825440F7CC9200354D4B40
39482	Пятилетка	5	52	6418	84.513367000000002	84.530049000000005	54.977061999999997	54.964689999999997	0103000020E610000001000000050000001FF64201DB2055409D6340F67A7B4B401FF64201DB20554009151C5E107D4B40C311A452EC21554009151C5E107D4B40C311A452EC2155409D6340F67A7B4B401FF64201DB2055409D6340F67A7B4B40
41190	рабочий поселок Кольцово	5	52	1354	83.167896999999996	83.192250999999999	54.945650000000001	54.930765000000001	0103000020E610000001000000050000002D060FD3BECA544077A1B94E23774B402D060FD3BECA544030BB270F0B794B40E46723D74DCC544030BB270F0B794B40E46723D74DCC544077A1B94E23774B402D060FD3BECA544077A1B94E23774B40
27929	Ярково	5	52	1354	82.579527999999996	82.622844999999998	54.817338999999997	54.795223999999997	0103000020E6100000010000000500000071C79BFC16A55440457F68E6C9654B4071C79BFC16A55440675F79909E684B40895E46B1DCA75440675F79909E684B40895E46B1DCA75440457F68E6C9654B4071C79BFC16A55440457F68E6C9654B40
25300	Элитный	5	52	1354	82.936877999999993	82.958509000000006	54.917841000000003	54.908811	0103000020E61000000100000005000000E19524CFF5BB54405E9F39EB53744B40E19524CFF5BB5440C7F65AD07B754B40FDFA213658BD5440C7F65AD07B754B40FDFA213658BD54405E9F39EB53744B40E19524CFF5BB54405E9F39EB53744B40
27451	Тулинский	5	52	1354	82.825298000000004	82.848635999999999	54.923279000000001	54.901972999999998	0103000020E6100000010000000500000012DDB3AED1B454400070ECD973734B4012DDB3AED1B45440B30A9B012E764B40548D5E0D50B65440B30A9B012E764B40548D5E0D50B654400070ECD973734B4012DDB3AED1B454400070ECD973734B40
28070	Толмачево	5	52	1354	82.664023	82.755688000000006	54.994486000000002	54.972659	0103000020E61000000100000005000000AD32535A7FAA54407D941117807C4B40AD32535A7FAA5440392A37514B7F4B40B37E33315DB05440392A37514B7F4B40B37E33315DB054407D941117807C4B40AD32535A7FAA54407D941117807C4B40
26742	Степной	5	52	1354	83.057674000000006	83.074445999999995	55.237772	55.229840000000003	0103000020E6100000010000000500000017F549EEB0C3544005A8A9656B9D4B4017F549EEB0C35440C7F319506F9E4B405AD427B9C3C45440C7F319506F9E4B405AD427B9C3C4544005A8A9656B9D4B4017F549EEB0C3544005A8A9656B9D4B40
26704	Сосновка	5	52	1354	82.936186000000006	82.957153000000005	55.242046999999999	55.228875000000002	0103000020E61000000100000005000000473EAF78EABB54409EEFA7C64B9D4B40473EAF78EABB5440268C6665FB9E4B402C11A8FE41BD5440268C6665FB9E4B402C11A8FE41BD54409EEFA7C64B9D4B40473EAF78EABB54409EEFA7C64B9D4B40
49619	Советский	5	52	1354	83.109031000000002	83.120772000000002	55.131171999999999	55.127116000000001	0103000020E6100000010000000500000003D0285DFAC6544030664B5645904B4003D0285DFAC6544051137D3ECA904B4071917BBABAC7544051137D3ECA904B4071917BBABAC7544030664B5645904B4003D0285DFAC6544030664B5645904B40
28321	Сенчанка	5	52	1354	82.439048999999997	82.477712999999994	54.847482999999997	54.837845999999999	0103000020E61000000100000005000000DB15FA60199C5440CE8AA8893E6B4B40DB15FA60199C54403E75AC527A6C4B40F0F78BD9929E54403E75AC527A6C4B40F0F78BD9929E5440CE8AA8893E6B4B40DB15FA60199C5440CE8AA8893E6B4B40
59137	Садовый	5	52	1354	82.190197999999995	83.505196999999995	55.432597000000001	54.569299000000001	0103000020E61000000100000005000000EF703B342C8C5440A05225CADE484B40EF703B342C8C544082ACA7565FB74B406342CC2555E0544082ACA7565FB74B406342CC2555E05440A05225CADE484B40EF703B342C8C5440A05225CADE484B40
26535	Раздольное	5	52	1354	83.110369000000006	83.146006	55.063395	55.051690000000001	0103000020E61000000100000005000000815F234910C75440DFC325C79D864B40815F234910C754406EDDCD531D884B4044C18C2958C954406EDDCD531D884B4044C18C2958C95440DFC325C79D864B40815F234910C75440DFC325C79D864B40
14556	Прогресс	5	52	1354	82.539480999999995	82.559522000000001	54.706187999999997	54.697048000000002	0103000020E610000001000000050000000EF450DB86A2544001DF6DDE38594B400EF450DB86A25440F0694E5E645A4B401FD95C35CFA35440F0694E5E645A4B401FD95C35CFA3544001DF6DDE38594B400EF450DB86A2544001DF6DDE38594B40
27797	Приобский	5	52	1354	82.763430999999997	82.779646	55.084363000000003	55.065370000000001	0103000020E610000001000000050000002A70B20DDCB05440DC114E0B5E884B402A70B20DDCB0544009FF2268CC8A4B40431D56B8E5B1544009FF2268CC8A4B40431D56B8E5B15440DC114E0B5E884B402A70B20DDCB05440DC114E0B5E884B40
26436	Плотниково	5	52	1354	83.386233000000004	83.410038	55.045417999999998	55.027515999999999	0103000020E61000000100000005000000B4E89D0AB8D85440F10EF0A485834B40B4E89D0AB8D854402A53CC41D0854B40810706103EDA54402A53CC41D0854B40810706103EDA5440F10EF0A485834B40B4E89D0AB8D85440F10EF0A485834B40
27984	Пайвино	5	52	1354	82.537181000000004	82.567419000000001	54.843777000000003	54.835849000000003	0103000020E6100000010000000500000016C26A2C61A2544079B29B19FD6A4B4016C26A2C61A25440FA0E7EE2006C4B404208C89750A45440FA0E7EE2006C4B404208C89750A4544079B29B19FD6A4B4016C26A2C61A2544079B29B19FD6A4B40
26308	Новолуговое	5	52	1354	83.083248999999995	83.148476000000002	54.997962000000001	54.969056999999999	0103000020E610000001000000050000002E1B9DF353C55440DD7A4D0F0A7C4B402E1B9DF353C554404C530438BD7F4B406B0F7BA180C954404C530438BD7F4B406B0F7BA180C95440DD7A4D0F0A7C4B402E1B9DF353C55440DD7A4D0F0A7C4B40
27050	Мочище	5	52	1354	83.098341000000005	83.133105999999998	55.167966	55.149954000000001	0103000020E61000000100000005000000C8B60C384BC65440C3F352B131934B40C8B60C384BC65440836BEEE87F954B40B03907CF84C85440836BEEE87F954B40B03907CF84C85440C3F352B131934B40C8B60C384BC65440C3F352B131934B40
41316	Михайловский	5	52	1354	83.440374000000006	83.467549000000005	55.078988000000003	55.068747000000002	0103000020E610000001000000050000008F006E162FDC54405C59A2B3CC884B408F006E162FDC544063635E471C8A4B40C311A452ECDD544063635E471C8A4B40C311A452ECDD54405C59A2B3CC884B408F006E162FDC54405C59A2B3CC884B40
27697	Марусино	5	52	1354	82.746596999999994	82.767105000000001	55.042813000000002	55.029713999999998	0103000020E61000000100000005000000AB92C83EC8AF5440DE1D19ABCD834B40AB92C83EC8AF5440FD6B79E57A854B4047E6913F18B15440FD6B79E57A854B4047E6913F18B15440DE1D19ABCD834B40AB92C83EC8AF5440DE1D19ABCD834B40
25341	Ленинское	5	52	1354	82.830948000000006	82.876816000000005	54.828195000000001	54.809691999999998	0103000020E610000001000000050000004E2B85402EB554409AEAC9FCA3674B404E2B85402EB55440F9DA334B026A4B400327DBC01DB85440F9DA334B026A4B400327DBC01DB854409AEAC9FCA3674B404E2B85402EB554409AEAC9FCA3674B40
27143	Ленинский	5	52	1354	83.132458999999997	83.163450999999995	55.144644	55.135300000000001	0103000020E61000000100000005000000E54350357AC854400C93A98251914B40E54350357AC8544004C8D0B183924B40E7DF2EFB75CA544004C8D0B183924B40E7DF2EFB75CA54400C93A98251914B40E54350357AC854400C93A98251914B40
59141	Кудряшовский	5	52	1354	82.761921999999998	82.781164000000004	55.118385000000004	55.089691000000002	0103000020E6100000010000000500000096067E54C3B054406EDFA3FE7A8B4B4096067E54C3B0544022AB5B3D278F4B4001344A97FEB1544022AB5B3D278F4B4001344A97FEB154406EDFA3FE7A8B4B4096067E54C3B054406EDFA3FE7A8B4B40
26818	Кубовая	5	52	1354	82.904601	82.925640000000001	55.267342999999997	55.251674999999999	0103000020E6100000010000000500000073BB97FBE4B95440431CEBE236A04B4073BB97FBE4B9544042E8A04B38A24B40A5F78DAF3DBB544042E8A04B38A24B40A5F78DAF3DBB5440431CEBE236A04B4073BB97FBE4B95440431CEBE236A04B40
27351	Крупской	5	52	1354	82.729708000000002	82.747549000000006	54.835284000000001	54.825473000000002	0103000020E610000001000000050000004BE82E89B3AE5440925D6919A9694B404BE82E89B3AE5440A06F0B96EA6A4B4015CAC2D7D7AF5440A06F0B96EA6A4B4015CAC2D7D7AF5440925D6919A9694B404BE82E89B3AE5440925D6919A9694B40
27599	Криводановка	5	52	1354	82.620778999999999	82.682204999999996	55.099072999999997	55.081369000000002	0103000020E61000000100000005000000CAC2D7D7BAA7544041F4A44C6A8A4B40CAC2D7D7BAA7544053758F6CAE8C4B40BB0A293FA9AB544053758F6CAE8C4B40BB0A293FA9AB544041F4A44C6A8A4B40CAC2D7D7BAA7544041F4A44C6A8A4B40
26609	Красный Яр	5	52	1354	82.903146000000007	82.913674	55.222558999999997	55.216653000000001	0103000020E61000000100000005000000D960E124CDB9544047CA1649BB9B4B40D960E124CDB95440193735D07C9C4B40274D83A279BA5440193735D07C9C4B40274D83A279BA544047CA1649BB9B4B40D960E124CDB9544047CA1649BB9B4B40
27503	Красный Восток	5	52	1354	82.808913000000004	82.818938000000003	54.934851999999999	54.922322000000001	0103000020E61000000100000005000000CB13083BC5B35440CF30B5A50E764B40CB13083BC5B35440D34CF73AA9774B40E8DCED7A69B45440D34CF73AA9774B40E8DCED7A69B45440CF30B5A50E764B40CB13083BC5B35440CF30B5A50E764B40
41273	Краснообск	5	52	1354	82.190197999999995	83.505196999999995	55.432597000000001	54.569299000000001	0103000020E61000000100000005000000EF703B342C8C5440A05225CADE484B40EF703B342C8C544082ACA7565FB74B406342CC2555E0544082ACA7565FB74B406342CC2555E05440A05225CADE484B40EF703B342C8C5440A05225CADE484B40
41209	Краснообск	5	52	1354	82.190197999999995	83.505196999999995	55.432597000000001	54.569299000000001	0103000020E61000000100000005000000EF703B342C8C5440A05225CADE484B40EF703B342C8C544082ACA7565FB74B406342CC2555E0544082ACA7565FB74B406342CC2555E05440A05225CADE484B40EF703B342C8C5440A05225CADE484B40
28210	Красномайский	5	52	1354	82.509747000000004	82.529330000000002	54.998730999999999	54.990602000000003	0103000020E61000000100000005000000FC8EE1B19FA0544015ADDC0BCC7E4B40FC8EE1B19FA054402D40DB6AD67F4B40ABB2EF8AE0A154402D40DB6AD67F4B40ABB2EF8AE0A1544015ADDC0BCC7E4B40FC8EE1B19FA0544015ADDC0BCC7E4B40
28145	Красноглинное	5	52	1354	82.693425000000005	82.710628	54.976756999999999	54.965702999999998	0103000020E61000000100000005000000A54E401361AC54401553E9279C7B4B40A54E401361AC5440CD91955F067D4B40CDE7DCED7AAD5440CD91955F067D4B40CDE7DCED7AAD54401553E9279C7B4B40A54E401361AC54401553E9279C7B4B40
28414	Кольцово	5	52	1354	83.167896999999996	83.192250999999999	54.945650000000001	54.930765000000001	0103000020E610000001000000050000002D060FD3BECA544077A1B94E23774B402D060FD3BECA544030BB270F0B794B40E46723D74DCC544030BB270F0B794B40E46723D74DCC544077A1B94E23774B402D060FD3BECA544077A1B94E23774B40
25725	Каинская Заимка	5	52	1354	83.137480999999994	83.154332999999994	54.875816999999998	54.866995000000003	0103000020E6100000010000000500000091B41B7DCCC85440D46531B1F96E4B4091B41B7DCCC85440F2237EC51A704B4063EC8497E0C95440F2237EC51A704B4063EC8497E0C95440D46531B1F96E4B4091B41B7DCCC85440D46531B1F96E4B40
26378	Издревая	5	52	1354	83.225120000000004	83.252330000000001	54.995054000000003	54.980963000000003	0103000020E610000001000000050000003C6BB75D68CE544004CB1132907D4B403C6BB75D68CE544083E0F1ED5D7F4B402E73BA2C26D0544083E0F1ED5D7F4B402E73BA2C26D0544004CB1132907D4B403C6BB75D68CE544004CB1132907D4B40
60680	Зеленый Мыс	5	52	1354	82.885153000000003	82.894216999999998	55.299973000000001	55.293908999999999	0103000020E6100000010000000500000034BDC458A6B85440028063CF9EA54B4034BDC458A6B854406D57E88365A64B40BEA1F0D93AB954406D57E88365A64B40BEA1F0D93AB95440028063CF9EA54B4034BDC458A6B85440028063CF9EA54B40
26479	Жеребцово	5	52	1354	83.267458000000005	83.299626000000004	55.126528999999998	55.106768000000002	0103000020E610000001000000050000006EC328081ED154403221E692AA8D4B406EC328081ED154406F7F2E1A32904B4001C287122DD354406F7F2E1A32904B4001C287122DD354403221E692AA8D4B406EC328081ED154403221E692AA8D4B40
25960	Железнодорожный	5	52	1354	83.268383	83.294505999999998	54.991909	54.977454000000002	0103000020E610000001000000050000005AF3E32F2DD1544015AC71361D7D4B405AF3E32F2DD15440D5CDC5DFF67E4B40739EB12FD9D25440D5CDC5DFF67E4B40739EB12FD9D2544015AC71361D7D4B405AF3E32F2DD1544015AC71361D7D4B40
25687	Двуречье	5	52	1354	83.195853	83.228515999999999	54.968158000000003	54.948903000000001	0103000020E61000000100000005000000B47405DB88CC5440C4094CA775794B40B47405DB88CC54402EAEF199EC7B4B4037A79201A0CE54402EAEF199EC7B4B4037A79201A0CE5440C4094CA775794B40B47405DB88CC5440C4094CA775794B40
26596	Гусиный Брод	5	52	1354	83.222057000000007	83.254064	55.074922000000001	55.062421000000001	0103000020E610000001000000050000004436902E36CE5440B4CA4C69FD874B404436902E36CE54401EE0490B97894B40D2C5A69542D054401EE0490B97894B40D2C5A69542D05440B4CA4C69FD874B404436902E36CE5440B4CA4C69FD874B40
60689	Голубой Залив	5	52	1354	82.904591999999994	82.928200000000004	54.837369000000002	54.830782999999997	0103000020E61000000100000005000000490ED8D5E4B954405089EB18576A4B40490ED8D5E4B9544095D74AE82E6B4B406C09F9A067BB544095D74AE82E6B4B406C09F9A067BB54405089EB18576A4B40490ED8D5E4B954405089EB18576A4B40
26032	Восход	5	52	1354	83.039806999999996	83.061744000000004	55.089922999999999	55.077075999999998	0103000020E61000000100000005000000B8C9A8328CC254403BA759A0DD894B40B8C9A8328CC254404014CC98828B4B405A2E1B9DF3C354404014CC98828B4B405A2E1B9DF3C354403BA759A0DD894B40B8C9A8328CC254403BA759A0DD894B40
27228	Витаминка	5	52	1354	83.097352999999998	83.113180999999997	55.138629000000002	55.131393000000003	0103000020E61000000100000005000000B8CA13083BC6544030F65E7CD1904B40B8CA13083BC654407BA35698BE914B40D461855B3EC754407BA35698BE914B40D461855B3EC7544030F65E7CD1904B40B8CA13083BC6544030F65E7CD1904B40
27299	Верх-Тула	5	52	1354	82.756378999999995	82.794594000000004	54.899358999999997	54.867741000000002	0103000020E610000001000000050000006518778368B05440FD321823126F4B406518778368B054407F2E1A321E734B4043E6CAA0DAB254407F2E1A321E734B4043E6CAA0DAB25440FD321823126F4B406518778368B05440FD321823126F4B40
26019	Быково	5	52	1354	83.278839000000005	83.301755	54.939340999999999	54.927810999999998	0103000020E610000001000000050000005C76887FD8D154403DEFC682C2764B405C76887FD8D154405E656D533C784B40E31934F44FD354405E656D533C784B40E31934F44FD354403DEFC682C2764B405C76887FD8D154403DEFC682C2764B40
14744	Боровое	5	52	1354	82.619457999999995	82.648518999999993	54.702474000000002	54.685223999999998	0103000020E61000000100000005000000B7CF2A33A5A754409737876BB5574B40B7CF2A33A5A75440292504ABEA594B406AF5D55581A95440292504ABEA594B406AF5D55581A954409737876BB5574B40B7CF2A33A5A754409737876BB5574B40
26952	Бибиха	5	52	1354	82.858823000000001	82.873232000000002	55.330348000000001	55.320391000000001	0103000020E610000001000000050000005E83BEF4F6B654406477819202A94B405E83BEF4F6B654404626E0D748AA4B4086747808E3B754404626E0D748AA4B4086747808E3B754406477819202A94B405E83BEF4F6B654406477819202A94B40
25895	Березовка	5	52	1354	83.318841000000006	83.350525000000005	54.999650000000003	54.984408000000002	0103000020E61000000100000005000000EFE714E467D45440DCF5D214017E4B40EFE714E467D4544024B9FC87F47F4B408CDB68006FD6544024B9FC87F47F4B408CDB68006FD65440DCF5D214017E4B40EFE714E467D45440DCF5D214017E4B40
14815	Береговое	5	52	1354	82.495013999999998	82.521738999999997	54.660141000000003	54.65137	0103000020E61000000100000005000000FA43334FAE9F54403ACC971760534B40FA43334FAE9F5440D7DF12807F544B400E83F92B64A15440D7DF12807F544B400E83F92B64A154403ACC971760534B40FA43334FAE9F54403ACC971760534B40
25776	Барышево	5	52	1354	83.148798999999997	83.203489000000005	54.976880999999999	54.945681	0103000020E610000001000000050000005CAB3DEC85C954406BB933130C794B405CAB3DEC85C95440B98AC56F0A7D4B402106BAF605CD5440B98AC56F0A7D4B402106BAF605CD54406BB933130C794B405CAB3DEC85C954406BB933130C794B40
28186	Алексеевка	5	52	1354	82.572053999999994	82.595580999999996	54.939852999999999	54.927413000000001	0103000020E61000000100000005000000F16261889CA4544050711C78B5764B40F16261889CA454401406651A4D784B409D47C5FF1DA654401406651A4D784B409D47C5FF1DA6544050711C78B5764B40F16261889CA4544050711C78B5764B40
36217	Дружинино	5	52	4196	59.49729	59.537866999999999	56.799354999999998	56.779733	0103000020E610000001000000050000005D50DF32A7BF4D40554E7B4ACE634C405D50DF32A7BF4D407172BF4351664C407F4C6BD3D8C44D407172BF4351664C407F4C6BD3D8C44D40554E7B4ACE634C405D50DF32A7BF4D40554E7B4ACE634C40
24462	Широкий Яр	5	52	1564	83.865170000000006	83.892290000000003	55.477102000000002	55.460746999999998	0103000020E61000000100000005000000BEDEFDF15EF75440745DF8C1F9BA4B40BEDEFDF15EF75440986DA7AD11BD4B40102384471BF95440986DA7AD11BD4B40102384471BF95440745DF8C1F9BA4B40BEDEFDF15EF75440745DF8C1F9BA4B40
24396	Участок-Балта	5	52	1564	83.926129000000003	83.954992000000004	55.431488999999999	55.416254000000002	0103000020E6100000010000000500000024B891B245FB5440236AA2CF47B54B4024B891B245FB5440B8CA13083BB74B4044FCC3961EFD5440B8CA13083BB74B4044FCC3961EFD5440236AA2CF47B54B4024B891B245FB5440236AA2CF47B54B40
23611	Успенка	5	52	1564	83.227913999999998	83.253291000000004	55.440105000000003	55.432550999999997	0103000020E610000001000000050000003C139A2496CE5440116DC7D45DB74B403C139A2496CE54402EE7525C55B84B40C15774EB35D054402EE7525C55B84B40C15774EB35D05440116DC7D45DB74B403C139A2496CE5440116DC7D45DB74B40
18819	Умрева	5	52	1564	83.612122999999997	83.637438000000003	55.550702000000001	55.542186999999998	0103000020E610000001000000050000004888F2052DE754407EA8346266C54B404888F2052DE75440C0EB33677DC64B4092CEC0C8CBE85440C0EB33677DC64B4092CEC0C8CBE854407EA8346266C54B404888F2052DE754407EA8346266C54B40
24154	Томилово	5	52	1564	83.826138	83.849000000000004	55.221496000000002	55.207571999999999	0103000020E61000000100000005000000E7FEEA71DFF454405CC823B8919A4B40E7FEEA71DFF45440F0181EFB599C4B407593180456F65440F0181EFB599C4B407593180456F654405CC823B8919A4B40E7FEEA71DFF454405CC823B8919A4B40
23501	Ташара	5	52	1564	83.456320000000005	83.533565999999993	55.532547999999998	55.506459	0103000020E61000000100000005000000B020CD5834DD5440E7E104A6D3C04B40B020CD5834DD54406DC669882AC44B407B1002F225E254406DC669882AC44B407B1002F225E25440E7E104A6D3C04B40B020CD5834DD5440E7E104A6D3C04B40
23864	Станционно-Ояшинский	5	52	1564	83.804884000000001	83.841274999999996	55.480657999999998	55.447595999999997	0103000020E61000000100000005000000B7442E3883F3544003E962D34AB94B40B7442E3883F35440C7478B3386BD4B4050FC1873D7F55440C7478B3386BD4B4050FC1873D7F5544003E962D34AB94B40B7442E3883F3544003E962D34AB94B40
24890	Сокур	5	52	1564	83.281983999999994	83.344434000000007	55.221665999999999	55.197491999999997	0103000020E61000000100000005000000B27F9E060CD254405E9CF86A47994B40B27F9E060CD254404C512E8D5F9C4B405A68E7340BD654404C512E8D5F9C4B405A68E7340BD654405E9CF86A47994B40B27F9E060CD254405E9CF86A47994B40
25031	Смоленский	5	52	1564	83.351307000000006	83.378210999999993	55.205409000000003	55.193314000000001	0103000020E61000000100000005000000C7F65AD07BD65440F2ED5D83BE984B40C7F65AD07BD65440ECA694D74A9A4B4032FFE89B34D85440ECA694D74A9A4B4032FFE89B34D85440F2ED5D83BE984B40C7F65AD07BD65440F2ED5D83BE984B40
23404	Сарачевка	5	52	1564	83.581787000000006	83.606949	55.509528000000003	55.493155000000002	0103000020E610000001000000050000003B8F8AFF3BE55440F06DFAB31FBF4B403B8F8AFF3BE55440BA32A83638C14B40C1559E40D8E65440BA32A83638C14B40C1559E40D8E65440F06DFAB31FBF4B403B8F8AFF3BE55440F06DFAB31FBF4B40
24093	Сарапулка	5	52	1564	83.731087000000002	83.764702	55.164175999999998	55.151307000000003	0103000020E61000000100000005000000F8E12021CAEE5440F4531C075E934B40F8E12021CAEE5440E0641BB803954B40E44BA8E0F0F05440E0641BB803954B40E44BA8E0F0F05440F4531C075E934B40F8E12021CAEE5440F4531C075E934B40
23938	Радуга	5	52	1564	83.732793999999998	83.738794999999996	55.498958999999999	55.494374000000001	0103000020E610000001000000050000001F2DCE18E6EE544011FFB0A547BF4B401F2DCE18E6EE5440BE8575E3DDBF4B40B1DCD26A48EF5440BE8575E3DDBF4B40B1DCD26A48EF544011FFB0A547BF4B401F2DCE18E6EE544011FFB0A547BF4B40
25076	Орск	5	52	1564	83.414719000000005	83.440715999999995	55.215671999999998	55.201411999999998	0103000020E61000000100000005000000E9818FC18ADA5440CF8250DEC7994B40E9818FC18ADA5440DA54DD239B9B4B40BBB4E1B034DC5440DA54DD239B9B4B40BBB4E1B034DC5440CF8250DEC7994B40E9818FC18ADA5440CF8250DEC7994B40
24607	Октябрьский	5	52	1564	83.155356999999995	83.184498000000005	55.179893999999997	55.166407999999997	0103000020E61000000100000005000000198D7C5EF1C9544079E57ADB4C954B40198D7C5EF1C95440915F3FC406974B405B0BB3D0CECB5440915F3FC406974B405B0BB3D0CECB544079E57ADB4C954B40198D7C5EF1C9544079E57ADB4C954B40
23707	Обской	5	52	1564	83.429818999999995	83.462301999999994	55.479754999999997	55.46902	0103000020E61000000100000005000000C30C8D2782DB5440C095ECD808BC4B40C30C8D2782DB5440D68BA19C68BD4B4006B8205B96DD5440D68BA19C68BD4B4006B8205B96DD5440C095ECD808BC4B40C30C8D2782DB5440C095ECD808BC4B40
23226	Новомошковское	5	52	1564	83.577233000000007	83.601648999999995	55.337916	55.326030000000003	0103000020E61000000100000005000000024BAE62F1E45440E8C1DD59BBA94B40024BAE62F1E45440C765DCD440AB4B40F3AACE6A81E65440C765DCD440AB4B40F3AACE6A81E65440E8C1DD59BBA94B40024BAE62F1E45440E8C1DD59BBA94B40
24007	Мошнино	5	52	1564	83.618187000000006	83.648855999999995	55.236061999999997	55.221707000000002	0103000020E61000000100000005000000FEF3346090E75440AB251DE5609C4B40FEF3346090E7544007EA9447379E4B400EF450DB86E9544007EA9447379E4B400EF450DB86E95440AB251DE5609C4B40FEF3346090E75440AB251DE5609C4B40
22950	Мошково	5	52	1564	83.552323000000001	83.634303000000003	55.318899999999999	55.288352000000003	0103000020E610000001000000050000000875914259E354403CDEE4B7E8A44B400875914259E35440E25817B7D1A84B404D309C6B98E85440E25817B7D1A84B404D309C6B98E854403CDEE4B7E8A44B400875914259E354403CDEE4B7E8A44B40
23142	Красногорский	5	52	1564	83.601450999999997	83.623037999999994	55.3977	55.387146999999999	0103000020E6100000010000000500000060C9552C7EE654404CDF6B088EB14B4060C9552C7EE6544042CF66D5E7B24B40938AC6DADFE7544042CF66D5E7B24B40938AC6DADFE754404CDF6B088EB14B4060C9552C7EE654404CDF6B088EB14B40
25150	Кошево	5	52	1564	83.481274999999997	83.507442999999995	55.261125999999997	55.251742	0103000020E610000001000000050000007958A835CDDE5440CB83F41439A04B407958A835CDDE54405111A7936CA14B40626534F279E054405111A7936CA14B40626534F279E05440CB83F41439A04B407958A835CDDE5440CB83F41439A04B40
24216	Кайлы	5	52	1564	84.076391000000001	84.105711999999997	55.304907999999998	55.285111999999998	0103000020E610000001000000050000005CAD1397E30455403CD9CD8C7EA44B405CAD1397E3045540F624B03907A74B40DDB243FCC3065540F624B03907A74B40DDB243FCC30655403CD9CD8C7EA44B405CAD1397E30455403CD9CD8C7EA44B40
24967	Емельяновский	5	52	1564	83.336134000000001	83.355421000000007	55.259571000000001	55.244926999999997	0103000020E61000000100000005000000B7442E3883D55440257497C4599F4B40B7442E3883D55440B9FE5D9F39A14B40F2D3B837BFD65440B9FE5D9F39A14B40F2D3B837BFD65440257497C4599F4B40B7442E3883D55440257497C4599F4B40
24247	Елтышево	5	52	1564	84.076228999999998	84.104256000000007	55.369464000000001	55.352618	0103000020E610000001000000050000006F8099EFE00455408FFD2C9622AD4B406F8099EFE00455405186AA984AAF4B405B9A5B21AC0655405186AA984AAF4B405B9A5B21AC0655408FFD2C9622AD4B406F8099EFE00455408FFD2C9622AD4B40
23603	Дубровино	5	52	1564	83.273171000000005	83.303713999999999	55.481045999999999	55.465024	0103000020E61000000100000005000000CDCD37A27BD1544074ED0BE885BB4B40CDCD37A27BD1544091EF52EA92BD4B409755D80C70D3544091EF52EA92BD4B409755D80C70D3544074ED0BE885BB4B40CDCD37A27BD1544074ED0BE885BB4B40
23312	Горный	5	52	1564	83.534499999999994	83.550642999999994	55.333542999999999	55.324607	0103000020E6100000010000000500000091ED7C3F35E25440BE86E0B88CA94B4091ED7C3F35E25440A5677A89B1AA4B405D3123BC3DE35440A5677A89B1AA4B405D3123BC3DE35440BE86E0B88CA94B4091ED7C3F35E25440BE86E0B88CA94B40
24493	Вороново	5	52	1564	83.767962999999995	83.808801000000003	55.489156999999999	55.474597000000003	0103000020E610000001000000050000006F62484E26F15440CEE33098BFBC4B406F62484E26F1544003CE52B29CBE4B4037FE4465C3F3544003CE52B29CBE4B4037FE4465C3F35440CEE33098BFBC4B406F62484E26F15440CEE33098BFBC4B40
24299	Верх-Балта	5	52	1564	83.750769000000005	83.770362000000006	55.340547999999998	55.330587999999999	0103000020E6100000010000000500000071766B990CF054409B3924B550AA4B4071766B990CF05440EE5BAD1397AB4B4032056B9C4DF15440EE5BAD1397AB4B4032056B9C4DF154409B3924B550AA4B4071766B990CF054409B3924B550AA4B40
23690	Белоярка	5	52	1564	83.181121000000005	83.212740999999994	55.422426000000002	55.405056000000002	0103000020E610000001000000050000009BE7887C97CB5440388600E0D8B34B409BE7887C97CB5440747D1F0E12B64B402C616D8C9DCD5440747D1F0E12B64B402C616D8C9DCD5440388600E0D8B34B409BE7887C97CB5440388600E0D8B34B40
24856	Барлакский	5	52	1564	83.207054999999997	83.263172999999995	55.174531999999999	55.165503000000001	0103000020E610000001000000050000004A5E9D6340CD5440E831CA332F954B404A5E9D6340CD5440800D881057964B402C0C91D3D7D05440800D881057964B402C0C91D3D7D05440E831CA332F954B404A5E9D6340CD5440E831CA332F954B40
24768	Барлак	5	52	1564	83.214915000000005	83.235298	55.217829999999999	55.202060000000003	0103000020E61000000100000005000000DF1AD82AC1CD544036EA211ADD994B40DF1AD82AC1CD5440390B7BDAE19B4B401CB4571F0FCF5440390B7BDAE19B4B401CB4571F0FCF544036EA211ADD994B40DF1AD82AC1CD544036EA211ADD994B40
24553	Балта	5	52	1564	83.856725999999995	83.879372000000004	55.525852999999998	55.507666999999998	0103000020E6100000010000000500000081E84999D4F654401421753BFBC04B4081E84999D4F6544072C0AE264FC34B4029417FA147F8544072C0AE264FC34B4029417FA147F854401421753BFBC04B4081E84999D4F654401421753BFBC04B40
34738	Крещенское	5	52	3083	80.030180999999999	80.066328999999996	55.864398999999999	55.855415999999998	0103000020E610000001000000050000007AFD497CEE015440D13C80457EED4B407AFD497CEE015440F9D85DA0A4EE4B40B071FDBB3E045440F9D85DA0A4EE4B40B071FDBB3E045440D13C80457EED4B407AFD497CEE015440D13C80457EED4B40
21022	Чупино	5	52	1647	84.144231000000005	84.172743999999994	54.404017000000003	54.386797000000001	0103000020E610000001000000050000007104A9143B0955407098689082314B407104A9143B09554097033DD4B6334B4022A5D93C0E0B554097033DD4B6334B4022A5D93C0E0B55407098689082314B407104A9143B0955407098689082314B40
21966	Чудиново	5	52	1647	84.812623000000002	84.842690000000005	54.343646	54.328538000000002	0103000020E610000001000000050000008E3EE6030234554023BF7E880D2A4B408E3EE603023455405BB39597FC2B4B40A4AA09A2EE3555405BB39597FC2B4B40A4AA09A2EE35554023BF7E880D2A4B408E3EE6030234554023BF7E880D2A4B40
21663	Суенга	5	52	1647	84.526824000000005	84.570868000000004	54.413811000000003	54.392952000000001	0103000020E61000000100000005000000DEAF027CB7215540EB724A404C324B40DEAF027CB7215540CFDC43C2F7344B404F95EF1989245540CFDC43C2F7344B404F95EF1989245540EB724A404C324B40DEAF027CB7215540EB724A404C324B40
20948	Серебренниково	5	52	1647	84.428252000000001	84.457482999999996	54.374333	54.361471000000002	0103000020E61000000100000005000000959C137B681B5540E9B985AE442E4B40959C137B681B55402368CC24EA2F4B4076DEC666471D55402368CC24EA2F4B4076DEC666471D5540E9B985AE442E4B40959C137B681B5540E9B985AE442E4B40
22421	Прямское	5	52	1647	83.844678999999999	83.871628999999999	54.325771000000003	54.312894	0103000020E610000001000000050000008D2782380FF65440AC8E1CE90C284B408D2782380FF654401C7E37DDB2294B40B14F00C5C8F754401C7E37DDB2294B40B14F00C5C8F75440AC8E1CE90C284B408D2782380FF65440AC8E1CE90C284B40
21489	Петени	5	52	1647	84.743363000000002	84.765119999999996	54.432543000000003	54.414873999999998	0103000020E610000001000000050000009D836742932F5540F8FA5A971A354B409D836742932F55408F8EAB915D374B40FE60E0B9F73055408F8EAB915D374B40FE60E0B9F7305540F8FA5A971A354B409D836742932F5540F8FA5A971A354B40
22321	Пеньково	5	52	1647	83.976408000000006	83.998327000000003	54.346449	54.332087000000001	0103000020E6100000010000000500000061E3FA777DFE5440A036AAD3812A4B4061E3FA777DFE5440AF5DDA70582C4B40AFEDED96E4FF5440AF5DDA70582C4B40AFEDED96E4FF5440A036AAD3812A4B4061E3FA777DFE5440A036AAD3812A4B40
22507	Пайвино	5	52	1647	84.111199999999997	84.133118999999994	54.417304999999999	54.393628	0103000020E610000001000000050000002CD49AE61D0755401B65FD6662324B402CD49AE61D07554088BA0F406A354B407ADE8D058508554088BA0F406A354B407ADE8D05850855401B65FD6662324B402CD49AE61D0755401B65FD6662324B40
22167	Никоново	5	52	1647	83.958225999999996	83.986901000000003	54.445664999999998	54.424843000000003	0103000020E61000000100000005000000520B259353FD54409F77634161364B40520B259353FD544065FCFB8C0B394B40F1D8CF6229FF544065FCFB8C0B394B40F1D8CF6229FF54409F77634161364B40520B259353FD54409F77634161364B40
21478	Нижняя Матренка	5	52	1647	84.755112999999994	84.769513000000003	54.467709999999997	54.459812999999997	0103000020E6100000010000000500000034F279C55330554048A30227DB3A4B4034F279C5533055408E01D9EBDD3B4B40333674B33F3155408E01D9EBDD3B4B40333674B33F31554048A30227DB3A4B4034F279C55330554048A30227DB3A4B40
22538	Маслянино	5	52	1647	84.143018999999995	84.248373000000001	54.363810999999998	54.315945999999997	0103000020E6100000010000000500000039ED293927095540A8A624EB70284B4039ED2939270955406876DD5B912E4B40670DDE57E50F55406876DD5B912E4B40670DDE57E50F5540A8A624EB70284B4039ED293927095540A8A624EB70284B40
22151	Мамоново	5	52	1647	84.240531000000004	84.301697000000004	54.319381	54.299404000000003	0103000020E6100000010000000500000026AB22DC640F55405325CADE52264B4026AB22DC640F55405DFB027AE1284B404913EF004F1355405DFB027AE1284B404913EF004F1355405325CADE52264B4026AB22DC640F55405325CADE52264B40
21969	Малая Томка	5	52	1647	84.405614	84.426400999999998	54.296835000000002	54.284942000000001	0103000020E610000001000000050000002F336C94F5195540E0A0BDFA78244B402F336C94F519554072A774B0FE254B40D47E6B274A1B554072A774B0FE254B40D47E6B274A1B5540E0A0BDFA78244B402F336C94F5195540E0A0BDFA78244B40
21203	Кинтереп	5	52	1647	83.978160000000003	83.990458000000004	54.484315000000002	54.473323999999998	0103000020E610000001000000050000005890662C9AFE5440B9347EE1953C4B405890662C9AFE54402BFBAE08FE3D4B40F183F3A963FF54402BFBAE08FE3D4B40F183F3A963FF5440B9347EE1953C4B405890662C9AFE5440B9347EE1953C4B40
21862	Загора	5	52	1647	84.597476	84.617283999999998	54.306832999999997	54.298689000000003	0103000020E610000001000000050000004609FA0B3D2655406556EF703B264B404609FA0B3D265540B22AC24D46274B400516C09481275540B22AC24D46274B400516C094812755406556EF703B264B404609FA0B3D2655406556EF703B264B40
21777	Жерновка	5	52	1647	84.682582999999994	84.696093000000005	54.341830000000002	54.328670000000002	0103000020E610000001000000050000008E739B70AF2B55409296CADB112A4B408E739B70AF2B55405665DF15C12B4B405F7EA7C98C2C55405665DF15C12B4B405F7EA7C98C2C55409296CADB112A4B408E739B70AF2B55409296CADB112A4B40
21679	Елбань	5	52	1647	84.574399	84.613007999999994	54.332355	54.311790999999999	0103000020E61000000100000005000000BAF605F4C2245540F4177AC4E8274B40BAF605F4C2245540BFD4CF9B8A2A4B40ED0BE8853B275540BFD4CF9B8A2A4B40ED0BE8853B275540F4177AC4E8274B40BAF605F4C2245540F4177AC4E8274B40
21585	Егорьевское	5	52	1647	84.578693000000001	84.609989999999996	54.508978999999997	54.491087999999998	0103000020E61000000100000005000000255B5D4E09255540A1BAB9F8DB3E4B40255B5D4E09255540E6AC4F3926414B40C5387F130A275540E6AC4F3926414B40C5387F130A275540A1BAB9F8DB3E4B40255B5D4E09255540A1BAB9F8DB3E4B40
21398	Дубровка	5	52	1647	84.704035000000005	84.735789999999994	54.468882000000001	54.460504	0103000020E61000000100000005000000520FD1E80E2D5540AED689CBF13A4B40520FD1E80E2D55406FD74B53043C4B4053AEF02E172F55406FD74B53043C4B4053AEF02E172F5540AED689CBF13A4B40520FD1E80E2D5540AED689CBF13A4B40
22067	Дресвянка	5	52	1647	84.535511	84.547961000000001	54.206778999999997	54.186931999999999	0103000020E610000001000000050000007DE9EDCF45225540B6494563ED174B407DE9EDCF45225540F23FF9BB771A4B40F19E03CB11235540F23FF9BB771A4B40F19E03CB11235540B6494563ED174B407DE9EDCF45225540B6494563ED174B40
21273	Верх-Ики	5	52	1647	84.124854999999997	84.601106000000001	54.616680000000002	54.512466000000003	0103000020E610000001000000050000007E6FD39FFD075540EE27637C98414B407E6FD39FFD075540740CC85EEF4E4B407BDB4C8578265540740CC85EEF4E4B407BDB4C8578265540EE27637C98414B407E6FD39FFD075540EE27637C98414B40
21388	Борково	5	52	1647	84.033226999999997	84.066131999999996	54.236089999999997	54.210527999999996	0103000020E6100000010000000500000007962364200255403672DD94F21A4B400796236420025540D1747632381E4B40054EB6813B045540D1747632381E4B40054EB6813B0455403672DD94F21A4B4007962364200255403672DD94F21A4B40
21251	Большой Изырак	5	52	1647	84.252380000000002	84.287171000000001	54.520451000000001	54.503788	0103000020E61000000100000005000000878A71FE26105540020F0C207C404B40878A71FE26105540D3156C239E424B400457790261125540D3156C239E424B400457790261125540020F0C207C404B40878A71FE26105540020F0C207C404B40
21120	Березово	5	52	1647	83.972941000000006	83.987143000000003	54.525159000000002	54.507399999999997	0103000020E6100000010000000500000001FC53AA44FE5440C5FEB27BF2404B4001FC53AA44FE54409C19FD6838434B406C5ED5592DFF54409C19FD6838434B406C5ED5592DFF5440C5FEB27BF2404B4001FC53AA44FE5440C5FEB27BF2404B40
22288	Барсуково	5	52	1647	83.923938000000007	83.941607000000005	54.397790000000001	54.387500000000003	0103000020E610000001000000050000000762D9CC21FB54409A99999999314B400762D9CC21FB5440825660C8EA324B40D2AB014A43FC5440825660C8EA324B40D2AB014A43FC54409A99999999314B400762D9CC21FB54409A99999999314B40
20874	Бажинск	5	52	1647	84.261830000000003	84.292489000000003	54.381601000000003	54.365862	0103000020E6100000010000000500000026C79DD2C1105540B16CE690D42E4B4026C79DD2C11055407A8F334DD8304B40255CC823B81255407A8F334DD8304B40255CC823B8125540B16CE690D42E4B4026C79DD2C1105540B16CE690D42E4B40
21115	Александровка	5	52	1647	84.357842000000005	84.373993999999996	54.443848000000003	54.426006000000001	0103000020E61000000100000005000000A8C821E2E61655402CF3565D87364B40A8C821E2E61655409032E202D0384B409DB98784EF1755409032E202D0384B409DB98784EF1755402CF3565D87364B40A8C821E2E61655402CF3565D87364B40
34439	Камышенка	5	52	2859	37.375216000000002	37.389507999999999	51.399675999999999	51.394803000000003	0103000020E61000000100000005000000CD77F01307B042406DAE9AE788B24940CD77F01307B04240807F4A9528B34940E3C3EC65DBB14240807F4A9528B34940E3C3EC65DBB142406DAE9AE788B24940CD77F01307B042406DAE9AE788B24940
59101	Новосибирск	5	52	3585	82.751105999999993	82.930419000000001	55.045237999999998	54.942019999999999	0103000020E610000001000000050000001475E61E12B05440C616821C94784B401475E61E12B05440AA44D95BCA854B40EE2422FC8BBB5440AA44D95BCA854B40EE2422FC8BBB5440C616821C94784B401475E61E12B05440C616821C94784B40
20315	Черновка	5	52	1555	76.443262000000004	76.479050999999998	56.784826000000002	56.771194999999999	0103000020E61000000100000005000000D06394675E1C53405BEB8B84B6624C40D06394675E1C53407786A92D75644C406E8786C5A81E53407786A92D75644C406E8786C5A81E53405BEB8B84B6624C40D06394675E1C53405BEB8B84B6624C40
19186	Чернаковка	5	52	1555	77.249617000000001	77.281642000000005	56.581884000000002	56.568491000000002	0103000020E61000000100000005000000A4E194B9F94F534001892650C4484C40A4E194B9F94F53406808C72C7B4A4C4086CB2A6C065253406808C72C7B4A4C4086CB2A6C0652534001892650C4484C40A4E194B9F94F534001892650C4484C40
19491	Усманка	5	52	1555	76.474091999999999	76.489534000000006	56.297223000000002	56.290728999999999	0103000020E61000000100000005000000E5D2F885571E5340D87F9D9B36254C40E5D2F885571E53403C4F3C670B264C40ED116A86541F53403C4F3C670B264C40ED116A86541F5340D87F9D9B36254C40E5D2F885571E5340D87F9D9B36254C40
19579	Сергеевка	5	52	1555	76.187916000000001	76.222060999999997	56.457974999999998	56.447463999999997	0103000020E610000001000000050000004A99D4D0060C53409411178046394C404A99D4D0060C53405BB1BFEC9E3A4C40E42D573F360E53405BB1BFEC9E3A4C40E42D573F360E53409411178046394C404A99D4D0060C53409411178046394C40
19372	Пахомово	5	52	1555	76.614588999999995	76.636606	56.433675000000001	56.422514999999997	0103000020E61000000100000005000000CEDE196D55275340E388B5F814364C40CEDE196D55275340E10B93A982374C40FE9B1727BE285340E10B93A982374C40FE9B1727BE285340E388B5F814364C40CEDE196D55275340E388B5F814364C40
20482	Орловка	5	52	1555	76.314263999999994	76.345426000000003	56.946480999999999	56.931852999999997	0103000020E61000000100000005000000D993C0E61C145340F9D687F546774C40D993C0E61C14534087A4164A26794C400A4CA7751B16534087A4164A26794C400A4CA7751B165340F9D687F546774C40D993C0E61C145340F9D687F546774C40
18985	Новый Майзас	5	52	1555	76.945240999999996	76.975711000000004	56.579053000000002	56.565837999999999	0103000020E61000000100000005000000A7751BD47E3C5340C26A2C616D484C40A7751BD47E3C53404AD3A0681E4A4C403DD68C0C723E53404AD3A0681E4A4C403DD68C0C723E5340C26A2C616D484C40A7751BD47E3C5340C26A2C616D484C40
20267	Новоложниково	5	52	1555	76.409198000000004	76.428906999999995	56.511812999999997	56.502609	0103000020E61000000100000005000000ACE5CE4C301A53406FD6E07D55404C40ACE5CE4C301A53407555A01683414C40A1815836731B53407555A01683414C40A1815836731B53406FD6E07D55404C40ACE5CE4C301A53406FD6E07D55404C40
19276	Межовка	5	52	1555	77.720315999999997	77.746744000000007	56.655594999999998	56.638204000000002	0103000020E6100000010000000500000046B247A8196E534094162EABB0514C4046B247A8196E5340E7357689EA534C40FE9E58A7CA6F5340E7357689EA534C40FE9E58A7CA6F534094162EABB0514C4046B247A8196E534094162EABB0514C40
19874	Малокрасноярка	5	52	1555	75.999126000000004	76.018924999999996	56.469228999999999	56.459701000000003	0103000020E6100000010000000500000055A52DAEF1FF524021787C7BD73A4C4055A52DAEF1FF5240DAAA24B20F3C4C40EA04341136015340DAAA24B20F3C4C40EA0434113601534021787C7BD73A4C4055A52DAEF1FF524021787C7BD73A4C40
19897	Малая Скирла	5	52	1555	76.070847000000001	76.102431999999993	56.486072	56.475194999999999	0103000020E610000001000000050000004301DBC188045340821C9430D33C4C404301DBC1880453402BC0779B373E4C401684F23E8E0653402BC0779B373E4C401684F23E8E065340821C9430D33C4C404301DBC188045340821C9430D33C4C40
18572	Кыштовка	5	52	1555	76.586057999999994	76.657582000000005	56.575785000000003	56.534792000000003	0103000020E61000000100000005000000C9E369F981255340CB14731074444C40C9E369F9812553408143A852B3494C400D1CD0D2152A53408143A852B3494C400D1CD0D2152A5340CB14731074444C40C9E369F981255340CB14731074444C40
19133	Куляба	5	52	1555	77.180069000000003	77.199239000000006	56.526263999999998	56.514699	0103000020E6100000010000000500000080812040864B5340572426A8E1414C4080812040864B5340F487669E5C434C409E45EF54C04C5340F487669E5C434C409E45EF54C04C5340572426A8E1414C4080812040864B5340572426A8E1414C40
20829	Крутиха	5	52	1555	77.152373999999995	77.181515000000005	56.824666000000001	56.811832000000003	0103000020E61000000100000005000000AFB0E07EC049534053EC681CEA674C40AFB0E07EC0495340C30FCEA78E694C40F12E17F19D4B5340C30FCEA78E694C40F12E17F19D4B534053EC681CEA674C40AFB0E07EC049534053EC681CEA674C40
19031	Коровинка	5	52	1555	76.758866999999995	76.774776000000003	56.548391000000002	56.536251999999998	0103000020E61000000100000005000000DFC0E446913053401135D1E7A3444C40DFC0E44691305340DB3521AD31464C40726E13EE95315340DB3521AD31464C40726E13EE953153401135D1E7A3444C40DFC0E446913053401135D1E7A3444C40
20402	Колбаса	5	52	1555	76.681127000000004	76.714877000000001	56.894424999999998	56.881424000000003	0103000020E610000001000000050000000C5BB395972B53406BF46A80D2704C400C5BB395972B5340C6DCB5847C724C4068EA758BC02D5340C6DCB5847C724C4068EA758BC02D53406BF46A80D2704C400C5BB395972B53406BF46A80D2704C40
41269	Козловка	5	52	1555	77.019163000000006	77.040327000000005	56.791570999999998	56.783208999999999	0103000020E61000000100000005000000C59272F7394153406877483140644C40C59272F73941534023BBD23252654C405589B2B79442534023BBD23252654C405589B2B7944253406877483140644C40C59272F7394153406877483140644C40
60693	Камышинка	5	52	1555	76.855013999999997	76.866431000000006	56.734864000000002	56.716580999999998	0103000020E61000000100000005000000D1E7A38CB8365340ADF71BEDB85B4C40D1E7A38CB8365340FE800706105E4C40664F029B73375340FE800706105E4C40664F029B73375340ADF71BEDB85B4C40D1E7A38CB8365340ADF71BEDB85B4C40
19565	Заливино	5	52	1555	76.323408999999998	76.340513000000001	56.456746000000003	56.446289999999998	0103000020E61000000100000005000000DA8EA9BBB21453401344DD0720394C40DA8EA9BBB2145340174A26A7763A4C4039B709F7CA155340174A26A7763A4C4039B709F7CA1553401344DD0720394C40DA8EA9BBB21453401344DD0720394C40
20100	Ерёмино	5	52	1555	76.382131999999999	76.410042000000004	56.615029999999997	56.604438999999999	0103000020E6100000010000000500000053B0C6D974185340A6B6D4415E4D4C4053B0C6D9741853408907944DB94E4C4022FFCC203E1A53408907944DB94E4C4022FFCC203E1A5340A6B6D4415E4D4C4053B0C6D974185340A6B6D4415E4D4C40
18848	Вятка	5	52	1555	76.701716000000005	76.719413000000003	56.547407999999997	56.539760999999999	0103000020E610000001000000050000001EC539EAE82C5340005471E316454C401EC539EAE82C5340CDC8207711464C404ED4D2DC0A2E5340CDC8207711464C404ED4D2DC0A2E5340005471E316454C401EC539EAE82C5340005471E316454C40
19680	Воскресенка	5	52	1555	76.145740000000004	76.166841000000005	56.443060000000003	56.430110999999997	0103000020E61000000100000005000000056EDDCD530953402E5393E00D374C40056EDDCD530953403815A930B6384C4072A8DF85AD0A53403815A930B6384C4072A8DF85AD0A53402E5393E00D374C40056EDDCD530953402E5393E00D374C40
19257	Верх-Тарка	5	52	1555	77.474132999999995	77.520126000000005	56.625297000000003	56.612400000000001	0103000020E61000000100000005000000143DF031585E534003098A1F634E4C40143DF031585E5340BAA46ABB09504C4028F38FBE49615340BAA46ABB09504C4028F38FBE4961534003098A1F634E4C40143DF031585E534003098A1F634E4C40
20578	Верх-Майзас	5	52	1555	76.874121000000002	76.910106999999996	56.690396	56.678649	0103000020E61000000100000005000000CCEF3499F1375340473B6EF8DD564C40CCEF3499F137534005A568E55E584C4015376E313F3A534005A568E55E584C4015376E313F3A5340473B6EF8DD564C40CCEF3499F1375340473B6EF8DD564C40
19348	Вараксино	5	52	1555	76.511111999999997	76.531161999999995	56.513770000000001	56.504674999999999	0103000020E61000000100000005000000F6251B0FB6205340ED0DBE3099404C40F6251B0FB62053403DD52137C3414C4030B8E68EFE2153403DD52137C3414C4030B8E68EFE215340ED0DBE3099404C40F6251B0FB6205340ED0DBE3099404C40
20479	Бочкарёвка	5	52	1555	76.849795	76.876132999999996	56.939788999999998	56.927708000000003	0103000020E610000001000000050000007A53910A63365340691EC022BF764C407A53910A63365340FD1186014B784C40917C259012385340FD1186014B784C40917C259012385340691EC022BF764C407A53910A63365340691EC022BF764C40
19997	Большеречье	5	52	1555	76.209492999999995	76.244105000000005	56.573335999999998	56.557578999999997	0103000020E610000001000000050000006BEF5355680D5340DBF7A8BF5E474C406BEF5355680D53404ACFF41263494C4091F2936A9F0F53404ACFF41263494C4091F2936A9F0F5340DBF7A8BF5E474C406BEF5355680D5340DBF7A8BF5E474C40
20676	Берёзовка	5	52	1555	76.913171000000006	76.939984999999993	56.802632000000003	56.791314999999997	0103000020E61000000100000005000000F629C764713A5340C8EA56CF49654C40F629C764713A53408E5C37A5BC664C40C16ED8B6283C53408E5C37A5BC664C40C16ED8B6283C5340C8EA56CF49654C40F629C764713A5340C8EA56CF49654C40
19767	Бакейка	5	52	1555	76.193691999999999	76.207373000000004	56.475085999999997	56.466518999999998	0103000020E61000000100000005000000CC5F2173650C534037FB03E5B63B4C40CC5F2173650C5340CB64389ECF3C4C40B3446799450D5340CB64389ECF3C4C40B3446799450D534037FB03E5B63B4C40CC5F2173650C534037FB03E5B63B4C40
14008	Яркуль	5	52	354	77.362131000000005	77.404217000000003	54.646619000000001	54.629747000000002	0103000020E610000001000000050000008A7780272D57534087E0B88C9B504B408A7780272D57534072FC5069C4524B402FDFFAB0DE59534072FC5069C4524B402FDFFAB0DE59534087E0B88C9B504B408A7780272D57534087E0B88C9B504B40
16603	Шаитик	5	52	354	77.576819	77.594021999999995	54.650219	54.645150000000001	0103000020E61000000100000005000000882D3D9AEA645340D881734694524B40882D3D9AEA645340711E4E603A534B40B0C6D97404665340711E4E603A534B40B0C6D97404665340D881734694524B40882D3D9AEA645340D881734694524B40
16833	Чумашки	5	52	354	77.776792999999998	77.806905	54.474615999999997	54.463901	0103000020E61000000100000005000000C0B0FCF9B671534075CAA31B613B4B40C0B0FCF9B671534044149337C03C4B40A67EDE54A473534044149337C03C4B40A67EDE54A473534075CAA31B613B4B40C0B0FCF9B671534075CAA31B613B4B40
16507	Чаинка	5	52	354	77.326269999999994	77.356973999999994	54.522207000000002	54.511749000000002	0103000020E610000001000000050000009EEA909BE15453405F61C1FD80414B409EEA909BE1545340035FD1ADD7424B406DE179A9D8565340035FD1ADD7424B406DE179A9D85653405F61C1FD80414B409EEA909BE15453405F61C1FD80414B40
16351	Тюменка	5	52	354	77.292107000000001	77.313333999999998	54.726132	54.718311999999997	0103000020E61000000100000005000000B1FB8EE1B15253408429CAA5F15B4B40B1FB8EE1B15253401F4AB4E4F15C4B4064AE0CAA0D5453401F4AB4E4F15C4B4064AE0CAA0D5453408429CAA5F15B4B40B1FB8EE1B15253408429CAA5F15B4B40
45997	Стеклянное	5	52	354	77.128245000000007	77.160539999999997	54.361696999999999	54.349456000000004	0103000020E610000001000000050000000938842A354853400CB265F9BA2C4B400938842A35485340D90759164C2E4B40CA6C9049464A5340D90759164C2E4B40CA6C9049464A53400CB265F9BA2C4B400938842A354853400CB265F9BA2C4B40
46754	Спасск	5	52	354	77.021319000000005	77.037820999999994	54.086269000000001	54.074511000000001	0103000020E6100000010000000500000024F25D4A5D4153409C18929389094B4024F25D4A5D4153404ED4D2DC0A0B4B408786C5A86B4253404ED4D2DC0A0B4B408786C5A86B4253409C18929389094B4024F25D4A5D4153409C18929389094B40
41358	Советский	5	52	354	77.023636999999994	77.042214000000001	54.035975000000001	54.022018000000003	0103000020E610000001000000050000006F7EC3448341534030F65E7CD1024B406F7EC344834153409F3C2CD49A044B40BC5B59A2B34253409F3C2CD49A044B40BC5B59A2B342534030F65E7CD1024B406F7EC3448341534030F65E7CD1024B40
41363	Сибирский	5	52	354	77.217106999999999	77.241208999999998	54.526262000000003	54.511733999999997	0103000020E61000000100000005000000E42EC214E54D53402920ED7F80414B40E42EC214E54D534054909F8D5C434B400EA0DFF76F4F534054909F8D5C434B400EA0DFF76F4F53402920ED7F80414B40E42EC214E54D53402920ED7F80414B40
40396	Рождественка	5	52	354	77.541928999999996	77.588352999999998	54.294701000000003	54.278466000000002	0103000020E6100000010000000500000041F0F8F6AE62534023861DC6A4234B4041F0F8F6AE6253409C8C2AC3B8254B4039605793A76553409C8C2AC3B8254B4039605793A765534023861DC6A4234B4041F0F8F6AE62534023861DC6A4234B40
41292	Петропавловка	5	52	354	77.059101999999996	77.066513	53.917506000000003	53.905504000000001	0103000020E610000001000000050000003448C153C8435340D732198EE7F34A403448C153C843534020F12BD670F54A4091F0BDBF4144534020F12BD670F54A4091F0BDBF41445340D732198EE7F34A403448C153C8435340D732198EE7F34A40
40467	Петровка	5	52	354	77.846385999999995	77.869364000000004	54.276395000000001	54.253131000000003	0103000020E61000000100000005000000B4722F302B765340494DBB9866204B40B4722F302B76534093E34EE960234B407714E7A8A377534093E34EE960234B407714E7A8A3775340494DBB9866204B40B4722F302B765340494DBB9866204B40
49667	Орловка	5	52	354	76.921372000000005	76.944163000000003	54.320709000000001	54.309302000000002	0103000020E61000000100000005000000CFDC43C2F73A5340304B3B3597274B40CFDC43C2F73A5340354415FE0C294B40F8C5A52A6D3C5340354415FE0C294B40F8C5A52A6D3C5340304B3B3597274B40CFDC43C2F73A5340304B3B3597274B40
41600	Новоселье	5	52	354	76.859630999999993	76.902651000000006	54.182712000000002	54.165577999999996	0103000020E610000001000000050000002DE8BD3104375340F277EFA831154B402DE8BD31043753401B4B581B63174B40E92CB308C53953401B4B581B63174B40E92CB308C5395340F277EFA831154B402DE8BD3104375340F277EFA831154B40
16822	Новорозино	5	52	354	77.774179000000004	77.805018000000004	54.656146999999997	54.644989000000002	0103000020E61000000100000005000000009013268C715340CFA3E2FF8E524B40009013268C7153402B2FF99FFC534B403FAC376A857353402B2FF99FFC534B403FAC376A85735340CFA3E2FF8E524B40009013268C715340CFA3E2FF8E524B40
17121	Новоключи	5	52	354	77.993898000000002	78.019131999999999	54.250259	54.237484000000002	0103000020E61000000100000005000000D4635B069C7F534061A92EE0651E4B40D4635B069C7F5340CC43A67C08204B40A7936C7539815340CC43A67C08204B40A7936C753981534061A92EE0651E4B40D4635B069C7F534061A92EE0651E4B40
16987	Новоказарино	5	52	354	77.804623000000007	77.828626	54.379530000000003	54.367536000000001	0103000020E6100000010000000500000001A777F17E735340240D6E6B0B2F4B4001A777F17E735340EAEC647094304B4061A7583508755340EAEC647094304B4061A7583508755340240D6E6B0B2F4B4001A777F17E735340240D6E6B0B2F4B40
43197	Моревка	5	52	354	77.273691999999997	77.297452000000007	54.242562	54.235695	0103000020E61000000100000005000000514B732B84515340556AF6402B1E4B40514B732B845153404DA088450C1F4B404F081D74095353404DA088450C1F4B404F081D7409535340556AF6402B1E4B40514B732B84515340556AF6402B1E4B40
18376	Метелево	5	52	354	76.722153000000006	76.751187000000002	54.096376999999997	54.088371000000002	0103000020E61000000100000005000000556D37C1372E53401975ADBD4F0B4B40556D37C1372E5340158BDF14560C4B408B8BA37213305340158BDF14560C4B408B8BA372133053401975ADBD4F0B4B40556D37C1372E53401975ADBD4F0B4B40
41347	Медяково	5	52	354	77.07432	77.101314000000002	54.138238000000001	54.117032999999999	0103000020E61000000100000005000000145CACA8C1445340C1C6F5EFFA0E4B40145CACA8C1445340408864C8B1114B402028B7ED7B465340408864C8B1114B402028B7ED7B465340C1C6F5EFFA0E4B40145CACA8C1445340C1C6F5EFFA0E4B40
41373	Мальково	5	52	354	77.429873000000001	77.458053000000007	54.585971000000001	54.57779	0103000020E61000000100000005000000BD1B0B0A835B534059FAD005F5494B40BD1B0B0A835B5340C4B30419014B4B406CB587BD505D5340C4B30419014B4B406CB587BD505D534059FAD005F5494B40BD1B0B0A835B534059FAD005F5494B40
17050	Лягушье	5	52	354	77.957021999999995	78.001084000000006	54.406542999999999	54.392465000000001	0103000020E610000001000000050000005CE333D93F7D53408EE9094B3C324B405CE333D93F7D534078B5DC9909344B402123A0C21180534078B5DC9909344B402123A0C2118053408EE9094B3C324B405CE333D93F7D53408EE9094B3C324B40
17104	Лукошино	5	52	354	78.063787000000005	78.085938999999996	54.324254000000003	54.314033999999999	0103000020E610000001000000050000003DBA11161584534081EA1F4432284B403DBA11161584534071CCB22781294B40DC9C4A068085534071CCB22781294B40DC9C4A068085534081EA1F4432284B403DBA11161584534081EA1F4432284B40
1791	Купино	5	52	354	77.252302999999998	77.344882999999996	54.387348000000003	54.326721999999997	0103000020E61000000100000005000000B16B7BBB255053401D71C806D2294B40B16B7BBB25505340E415889E94314B40917C259012565340E415889E94314B40917C2590125653401D71C806D2294B40B16B7BBB255053401D71C806D2294B40
41243	Куликовка	5	52	354	77.142582000000004	77.15992	54.509444000000002	54.503233999999999	0103000020E61000000100000005000000E4BF4010204953401D1EC2F869404B40E4BF4010204953405C92037635414B407C7E18213C4A53405C92037635414B407C7E18213C4A53401D1EC2F869404B40E4BF4010204953401D1EC2F869404B40
16898	Копкуль	5	52	354	77.616946999999996	77.648505	54.401774000000003	54.381323000000002	0103000020E610000001000000050000006117450F7C675340371B2B31CF304B406117450F7C6753400A3197546D334B40B8921D1B816953400A3197546D334B40B8921D1B81695340371B2B31CF304B406117450F7C675340371B2B31CF304B40
18341	Киргинцево	5	52	354	77.021902999999995	77.045599999999993	54.243346000000003	54.232458999999999	0103000020E61000000100000005000000CB2BD7DB6641534097546D37C11D4B40CB2BD7DB6641534064CE33F6251F4B40A52C431CEB42534064CE33F6251F4B40A52C431CEB42534097546D37C11D4B40CB2BD7DB6641534097546D37C11D4B40
17297	Зятьковка	5	52	354	77.310018999999997	77.349473000000003	54.285761999999998	54.273497999999996	0103000020E61000000100000005000000DF88EE59D7535340BDC282FB01234B40DF88EE59D7535340433866D993244B40717500C45D565340433866D993244B40717500C45D565340BDC282FB01234B40DF88EE59D7535340BDC282FB01234B40
46506	Вороновка	5	52	354	77.737887000000001	77.763865999999993	54.348385	54.34151	0103000020E610000001000000050000003049658A396F5340E4A08499B62B4B403049658A396F53405FB532E1972C4B40AF21382EE37053405FB532E1972C4B40AF21382EE3705340E4A08499B62B4B403049658A396F5340E4A08499B62B4B40
41307	Вишневка	5	52	354	76.831908999999996	76.854268000000005	53.987129000000003	53.980103	0103000020E61000000100000005000000E00F3FFF3D35534012DBDD0374FD4A40E00F3FFF3D35534073F7393E5AFE4A403D81B053AC36534073F7393E5AFE4A403D81B053AC36534012DBDD0374FD4A40E00F3FFF3D35534012DBDD0374FD4A40
17763	Веселый Кут	5	52	354	77.195070999999999	77.226782	54.186590000000002	54.168793999999998	0103000020E610000001000000050000007959130B7C4C534069E1B20A9B154B407959130B7C4C53405DE15D2EE2174B409354A698834E53405DE15D2EE2174B409354A698834E534069E1B20A9B154B407959130B7C4C534069E1B20A9B154B40
41256	Васильевка	5	52	354	76.917258000000004	76.945474000000004	54.048929000000001	54.033949999999997	0103000020E61000000100000005000000A4FFE55AB43A53407FD93D7958044B40A4FFE55AB43A5340BA69334E43064B40F94D61A5823C5340BA69334E43064B40F94D61A5823C53407FD93D7958044B40A4FFE55AB43A53407FD93D7958044B40
46997	Благовещенка	5	52	354	76.923671999999996	76.957133999999996	53.930273999999997	53.923009999999998	0103000020E61000000100000005000000C70E2A711D3B5340C3F0113125F64A40C70E2A711D3B5340D828EB3713F74A40F0F8F6AE413D5340D828EB3713F74A40F0F8F6AE413D5340C3F0113125F64A40C70E2A711D3B5340C3F0113125F64A40
41328	Басково	5	52	354	77.649313000000006	77.664125999999996	54.468082000000003	54.460959000000003	0103000020E6100000010000000500000088F71C588E69534000E65AB4003B4B4088F71C588E69534053EC681CEA3B4B40179B560A816A534053EC681CEA3B4B40179B560A816A534000E65AB4003B4B4088F71C588E69534000E65AB4003B4B40
17789	Аполиха	5	52	354	77.166711000000006	77.189672000000002	54.073892999999998	54.066375000000001	0103000020E610000001000000050000008B389D64AB4A5340D122DBF97E084B408B389D64AB4A5340A033695375094B40E23D0796234C5340A033695375094B40E23D0796234C5340D122DBF97E084B408B389D64AB4A5340D122DBF97E084B40
41447	Алферовка	5	52	354	76.498005000000006	76.524524	54.117306999999997	54.109290000000001	0103000020E61000000100000005000000A60F5D50DF1F5340D2E3F736FD0D4B40A60F5D50DF1F5340C24B70EA030F4B40E57D1CCD91215340C24B70EA030F4B40E57D1CCD91215340D2E3F736FD0D4B40A60F5D50DF1F5340D2E3F736FD0D4B40
13528	Ярково	5	52	1260	77.809438	77.832048	55.652014000000001	55.647112	0103000020E61000000100000005000000F0880AD5CD735340B16CE690D4D24B40F0880AD5CD7353405F44DB3175D34B40F12C4146407553405F44DB3175D34B40F12C414640755340B16CE690D4D24B40F0880AD5CD735340B16CE690D4D24B40
49616	Шагир (Татары)	5	52	1260	77.658385999999993	77.667925999999994	55.803398000000001	55.793627000000001	0103000020E610000001000000050000003B8908FF226A53407E1CCD9195E54B403B8908FF226A5340FED5E3BED5E64B407A89B14CBF6A5340FED5E3BED5E64B407A89B14CBF6A53407E1CCD9195E54B403B8908FF226A53407E1CCD9195E54B40
14558	Чумаково	5	52	1260	79.034649999999999	79.069792000000007	55.693896000000002	55.678966000000003	0103000020E610000001000000050000009C33A2B437C25340488C9E5BE8D64B409C33A2B437C25340A1698995D1D84B407061DD7877C45340A1698995D1D84B407061DD7877C45340488C9E5BE8D64B409C33A2B437C25340488C9E5BE8D64B40
14588	Ушково	5	52	1260	79.040777000000006	79.080590000000001	55.688395	55.674717000000001	0103000020E61000000100000005000000755B22179CC2534012876C205DD64B40755B22179CC253406EDDCD531DD84B409E98F56228C553406EDDCD531DD84B409E98F56228C5534012876C205DD64B40755B22179CC2534012876C205DD64B40
14494	Сергино	5	52	1260	78.417696000000007	78.442983999999996	55.789845999999997	55.781295999999998	0103000020E61000000100000005000000E2EA0088BB9A5340703FE08101E44B40E2EA0088BB9A53402E7079AC19E54B40AE2990D9599C53402E7079AC19E54B40AE2990D9599C5340703FE08101E44B40E2EA0088BB9A5340703FE08101E44B40
41262	Сартаково	5	52	1260	78.470903000000007	78.479912999999996	55.459587999999997	55.454810000000002	0103000020E61000000100000005000000A7255646239E534067F2CD3637BA4B40A7255646239E534028D192C7D3BA4B4037FB03E5B69E534028D192C7D3BA4B4037FB03E5B69E534067F2CD3637BA4B40A7255646239E534067F2CD3637BA4B40
14202	Помельцево	5	52	1260	78.501581000000002	78.526364999999998	55.470173000000003	55.45919	0103000020E61000000100000005000000E1D231E719A053403B53E8BCC6BA4B40E1D231E719A053402A3BFDA02EBC4B409430D3F6AFA153402A3BFDA02EBC4B409430D3F6AFA153403B53E8BCC6BA4B40E1D231E719A053403B53E8BCC6BA4B40
14478	Отрадненское	5	52	1260	78.538987000000006	78.559324000000004	55.535885	55.522215000000003	0103000020E61000000100000005000000077E54C37EA25340863DEDF0D7C24B40077E54C37EA253405FB532E197C44B408CF7E3F6CBA353405FB532E197C44B408CF7E3F6CBA35340863DEDF0D7C24B40077E54C37EA25340863DEDF0D7C24B40
14331	Осиново	5	52	1260	78.822800000000001	78.855778000000001	55.466768999999999	55.456575999999998	0103000020E6100000010000000500000086C954C1A8B45340BA11161571BA4B4086C954C1A8B45340B0E42A16BFBB4B40B9A81611C5B65340B0E42A16BFBB4B40B9A81611C5B65340BA11161571BA4B4086C954C1A8B45340BA11161571BA4B40
49613	Омь	5	52	1260	77.782173999999998	77.796735999999996	55.428592000000002	55.422007000000001	0103000020E61000000100000005000000047289230F7253406FD74B5304B64B40047289230F725340E3A9471ADCB64B40EFE2FDB8FD725340E3A9471ADCB64B40EFE2FDB8FD7253406FD74B5304B64B40047289230F7253406FD74B5304B64B40
14138	Новоичинское	5	52	1260	77.614008999999996	77.632109999999997	55.666310000000003	55.658372999999997	0103000020E61000000100000005000000C79C67EC4B675340E2C8039145D44B40C79C67EC4B675340B77F65A549D54B405F5E807D74685340B77F65A549D54B405F5E807D74685340E2C8039145D44B40C79C67EC4B675340E2C8039145D44B40
14195	Нагорное	5	52	1260	78.251337000000007	78.296953999999999	55.434829000000001	55.416938000000002	0103000020E6100000010000000500000096D1C8E715905340D63A71395EB54B4096D1C8E7159053401B2D077AA8B74B40A69A594B019353401B2D077AA8B74B40A69A594B01935340D63A71395EB54B4096D1C8E715905340D63A71395EB54B40
14050	Михайловка	5	52	1260	79.347587000000004	79.370827000000006	55.592393000000001	55.577429000000002	0103000020E61000000100000005000000F2608BDD3ED6534089618731E9C94B40F2608BDD3ED653408EB0A888D3CB4B40535E2BA1BBD753408EB0A888D3CB4B40535E2BA1BBD7534089618731E9C94B40F2608BDD3ED6534089618731E9C94B40
14413	Кульча	5	52	1260	79.092923999999996	79.117609000000002	55.538528999999997	55.532212000000001	0103000020E61000000100000005000000DD408177F2C55340F644D7851FC44B40DD408177F2C553404A79AD84EEC44B40C72DE6E786C753404A79AD84EEC44B40C72DE6E786C75340F644D7851FC44B40DD408177F2C55340F644D7851FC44B40
40315	Куйбышев	5	52	1260	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
41320	Красный Яр	5	52	1260	78.947845999999998	78.964213000000001	55.633876999999998	55.627844000000003	0103000020E610000001000000050000003EE94482A9BC5340B37E33315DD04B403EE94482A9BC5340E257ACE122D14B40325871AAB5BD5340E257ACE122D14B40325871AAB5BD5340B37E33315DD04B403EE94482A9BC5340B37E33315DD04B40
48994	Красновка	5	52	1260	78.986985000000004	79.009011999999998	55.488055000000003	55.480572000000002	0103000020E61000000100000005000000202922C32ABF5340C9AF1F6283BD4B40202922C32ABF53401CD3139678BE4B40615111A793C053401CD3139678BE4B40615111A793C05340C9AF1F6283BD4B40202922C32ABF5340C9AF1F6283BD4B40
13716	Константиновка (Опаринское)	5	52	1260	78.792508999999995	78.813916000000006	55.642767999999997	55.632188999999997	0103000020E610000001000000050000004832AB77B8B253400AF2B391EBD04B404832AB77B8B253402975C93846D24B403C6C223317B453402975C93846D24B403C6C223317B453400AF2B391EBD04B404832AB77B8B253400AF2B391EBD04B40
14361	Кондусла	5	52	1260	78.928442000000004	78.948312999999999	55.450563000000002	55.440227999999998	0103000020E61000000100000005000000E78EFE976BBB534049641F6459B84B40E78EFE976BBB5340D2E4620CACB94B40C9570229B1BC5340D2E4620CACB94B40C9570229B1BC534049641F6459B84B40E78EFE976BBB534049641F6459B84B40
14007	Комсомольский	5	52	1260	78.329786999999996	78.346773999999996	55.547651999999999	55.540903	0103000020E6100000010000000500000057E9EE3A1B95534076A73B4F3CC54B4057E9EE3A1B95534064CBF27519C64B409946938B3196534064CBF27519C64B409946938B3196534076A73B4F3CC54B4057E9EE3A1B95534076A73B4F3CC54B40
13850	Кама	5	52	1260	77.692081999999999	77.738659999999996	55.886746000000002	55.870742999999997	0103000020E610000001000000050000009E094D124B6C5340471CB28174EF4B409E094D124B6C5340EEED96E480F14B4041B79734466F5340EEED96E480F14B4041B79734466F5340471CB28174EF4B409E094D124B6C5340471CB28174EF4B40
13940	Ивушка	5	52	1260	78.215008999999995	78.229526000000007	55.545141000000001	55.536985999999999	0103000020E610000001000000050000001FD61BB5C28D534076340EF5BBC44B401FD61BB5C28D5340B85A272EC7C54B403BE5D18DB08E5340B85A272EC7C54B403BE5D18DB08E534076340EF5BBC44B401FD61BB5C28D534076340EF5BBC44B40
13802	Зоново	5	52	1260	79.315202999999997	79.338837999999996	55.736285000000002	55.72636	0103000020E61000000100000005000000782634492CD45340B08F4E5DF9DC4B40782634492CD4534087C43D963EDE4B4017299485AFD5534087C43D963EDE4B4017299485AFD55340B08F4E5DF9DC4B40782634492CD45340B08F4E5DF9DC4B40
14279	Заречный	5	52	1260	78.282454999999999	78.301400000000001	55.474806000000001	55.467571	0103000020E61000000100000005000000DEE522BE139253406DC7D45DD9BB4B40DEE522BE13925340E8F86871C6BC4B40ECC039234A935340E8F86871C6BC4B40ECC039234A9353406DC7D45DD9BB4B40DEE522BE139253406DC7D45DD9BB4B40
13708	Горбуново	5	52	1260	78.698994999999996	78.738007999999994	55.515523000000002	55.506877000000003	0103000020E6100000010000000500000052448655BCAC53401C0C7558E1C04B4052448655BCAC5340FCAA5CA8FCC14B40ED0BE8853BAF5340FCAA5CA8FCC14B40ED0BE8853BAF53401C0C7558E1C04B4052448655BCAC53401C0C7558E1C04B40
13607	Гжатск	5	52	1260	78.164361999999997	78.200681000000003	55.712822000000003	55.691941999999997	0103000020E6100000010000000500000021AD31E8848A53404A5D328E91D84B4021AD31E8848A534046EF54C03DDB4B406EFB1EF5D78C534046EF54C03DDB4B406EFB1EF5D78C53404A5D328E91D84B4021AD31E8848A53404A5D328E91D84B40
13382	Веснянка	5	52	1260	78.111389000000003	78.135113000000004	55.549571999999998	55.541708	0103000020E61000000100000005000000960854FF20875340A4FD0FB056C54B40960854FF208753400E66136058C64B40ED10FFB0A58853400E66136058C64B40ED10FFB0A5885340A4FD0FB056C54B40960854FF20875340A4FD0FB056C54B40
13437	Верх-Ича	5	52	1260	77.993835000000004	78.032373000000007	55.735641999999999	55.721772000000001	0103000020E61000000100000005000000B1A71DFE9A7F534092955F0663DC4B40B1A71DFE9A7F534032C85D8429DE4B40801134661282534032C85D8429DE4B40801134661282534092955F0663DC4B40B1A71DFE9A7F534092955F0663DC4B40
13246	Булатово	5	52	1260	77.788049000000001	77.822346999999993	55.525852999999998	55.509211999999998	0103000020E6100000010000000500000050A912656F725340895DDBDB2DC14B4050A912656F72534072C0AE264FC34B40ADBD4F55A174534072C0AE264FC34B40ADBD4F55A1745340895DDBDB2DC14B4050A912656F725340895DDBDB2DC14B40
13160	Балман	5	52	1260	79.417602000000002	79.448639	55.809206000000003	55.797620000000002	0103000020E61000000100000005000000A12FBDFDB9DA53405951836918E64B40A12FBDFDB9DA53400EDDEC0F94E74B40732D5A80B6DC53400EDDEC0F94E74B40732D5A80B6DC53405951836918E64B40A12FBDFDB9DA53405951836918E64B40
13665	Аул-Бергуль	5	52	1260	78.347842999999997	78.374962999999994	55.611581999999999	55.601640000000003	0103000020E610000001000000050000001F49490F4396534094FB1D8A02CD4B401F49490F439653404069A85148CE4B40718DCF64FF9753404069A85148CE4B40718DCF64FF97534094FB1D8A02CD4B401F49490F4396534094FB1D8A02CD4B40
14663	Андреевка	5	52	1260	79.138036999999997	79.159058000000002	55.713841000000002	55.702688000000002	0103000020E61000000100000005000000D4282499D5C8534055A52DAEF1D94B40D4282499D5C85340A0C552245FDB4B40B30A9B012ECA5340A0C552245FDB4B40B30A9B012ECA534055A52DAEF1D94B40D4282499D5C8534055A52DAEF1D94B40
13052	Абрамово	5	52	1260	78.204059000000001	78.234888999999995	55.444558000000001	55.431396999999997	0103000020E6100000010000000500000016DD7A4D0F8D5340D74B530438B74B4016DD7A4D0F8D53406C96CB46E7B84B402B4CDF6B088F53406C96CB46E7B84B402B4CDF6B088F5340D74B530438B74B4016DD7A4D0F8D5340D74B530438B74B40
37222	Украинка	5	52	4882	50.238273	50.256284999999998	53.697178999999998	53.682899999999997	0103000020E610000001000000050000008942CBBA7F1E49401D38674469D74A408942CBBA7F1E49409F3A56293DD94A4049BA66F2CD2049409F3A56293DD94A4049BA66F2CD2049401D38674469D74A408942CBBA7F1E49401D38674469D74A40
11265	Чернаки	5	52	1105	79.797571000000005	79.829380999999998	54.082118000000001	54.068551999999997	0103000020E610000001000000050000003C4F3C670BF35340A609DB4FC6084B403C4F3C670BF35340DB34B6D7820A4B401FBB0B9414F55340DB34B6D7820A4B401FBB0B9414F55340A609DB4FC6084B403C4F3C670BF35340A609DB4FC6084B40
11380	Целинный	5	52	1105	79.527384999999995	79.547910999999999	53.752026999999998	53.746724	0103000020E61000000100000005000000A9D903ADC0E15340B491EBA694DF4A40A9D903ADC0E15340C05AB56B42E04A4098874CF910E35340C05AB56B42E04A4098874CF910E35340B491EBA694DF4A40A9D903ADC0E15340B491EBA694DF4A40
11982	Хабаровский	5	52	1105	79.757694999999998	79.772796	53.848711999999999	53.842714000000001	0103000020E61000000100000005000000EF552B137EF05340D0F0660DDEEB4A40EF552B137EF0534083DC4598A2EC4A40B29E5A7D75F1534083DC4598A2EC4A40B29E5A7D75F15340D0F0660DDEEB4A40EF552B137EF05340D0F0660DDEEB4A40
10245	Успенский	5	52	1105	78.724380999999994	78.749435000000005	53.664914000000003	53.654760000000003	0103000020E61000000100000005000000003620425CAE53404F5DF92CCFD34A40003620425CAE53408753E6E61BD54A4094DE37BEF6AF53408753E6E61BD54A4094DE37BEF6AF53404F5DF92CCFD34A40003620425CAE53404F5DF92CCFD34A40
12702	Урожайный	5	52	1105	79.526127000000002	79.538291000000001	53.798900000000003	53.789459999999998	0103000020E61000000100000005000000BAA29410ACE1534005C078060DE54A40BAA29410ACE153402063EE5A42E64A40CB2E185C73E253402063EE5A42E64A40CB2E185C73E2534005C078060DE54A40BAA29410ACE1534005C078060DE54A40
10148	Ульяновка	5	52	1105	78.804196000000005	78.826322000000005	53.744391	53.732115	0103000020E61000000100000005000000BDE47FF277B353409DF4BEF1B5DD4A40BDE47FF277B35340E7374C3448DF4A40C87DAB75E2B45340E7374C3448DF4A40C87DAB75E2B453409DF4BEF1B5DD4A40BDE47FF277B353409DF4BEF1B5DD4A40
12861	Светлое	5	52	1105	78.700682999999998	78.725486000000004	54.205800000000004	54.183312000000001	0103000020E610000001000000050000003E7782FDD7AC5340707B82C476174B403E7782FDD7AC534027C286A7571A4B402DEDD45C6EAE534027C286A7571A4B402DEDD45C6EAE5340707B82C476174B403E7782FDD7AC5340707B82C476174B40
60586	Садовый	5	52	1105	79.482872999999998	79.505700000000004	53.752437	53.737617	0103000020E61000000100000005000000C5C72764E7DE5340A0FCDD3B6ADE4A40C5C72764E7DE534072A609DB4FE04A40956588635DE0534072A609DB4FE04A40956588635DE05340A0FCDD3B6ADE4A40C5C72764E7DE5340A0FCDD3B6ADE4A40
60654	Рямское	5	52	1105	78.778773999999999	78.791709999999995	54.293351000000001	54.282308999999998	0103000020E61000000100000005000000683EE76ED7B15340E82E89B322244B40683EE76ED7B15340DC9F8B868C254B40A27A6B60ABB25340DC9F8B868C254B40A27A6B60ABB25340E82E89B322244B40683EE76ED7B15340E82E89B322244B40
12552	Полойка	5	52	1105	78.203097999999997	79.360270999999997	54.244776999999999	54.186036000000001	0103000020E6100000010000000500000083F8C08EFF8C534078F01307D0174B4083F8C08EFF8C534010E84CDA541F4B409FAC18AE0ED7534010E84CDA541F4B409FAC18AE0ED7534078F01307D0174B4083F8C08EFF8C534078F01307D0174B40
12379	Половинное	5	52	1105	79.210217	79.273296999999999	53.776696999999999	53.723464	0103000020E610000001000000050000000C04013274CD5340ABEAE5779ADC4A400C04013274CD53405EF3AACE6AE34A401346B3B27DD153405EF3AACE6AE34A401346B3B27DD15340ABEAE5779ADC4A400C04013274CD5340ABEAE5779ADC4A40
11512	Петропавловка	5	52	1105	79.611440000000002	79.675122000000002	54.027599000000002	54.002299000000001	0103000020E61000000100000005000000D7DD3CD521E7534021E868554B004B40D7DD3CD521E753407F33315D88034B40D9B3E73235EB53407F33315D88034B40D9B3E73235EB534021E868554B004B40D7DD3CD521E7534021E868554B004B40
11610	Осинниковский	5	52	1105	78.782718000000003	78.801861000000002	53.894388999999997	53.886865	0103000020E6100000010000000500000065FF3C0D18B25340C87BD5CA84F14A4065FF3C0D18B253407973B8567BF24A4006BCCCB051B353407973B8567BF24A4006BCCCB051B35340C87BD5CA84F14A4065FF3C0D18B25340C87BD5CA84F14A40
12241	Орехов Лог	5	52	1105	79.370305999999999	79.409076999999996	53.84995	53.826039999999999	0103000020E61000000100000005000000CEE0EF17B3D753400B98C0ADBBE94A40CEE0EF17B3D753401B9E5E29CBEC4A40EE224C512EDA53401B9E5E29CBEC4A40EE224C512EDA53400B98C0ADBBE94A40CEE0EF17B3D753400B98C0ADBBE94A40
11818	Октябрьский	5	52	1105	79.627905999999996	79.657011999999995	53.966858000000002	53.949460000000002	0103000020E6100000010000000500000094BDA59C2FE853401A6EC0E787F94A4094BDA59C2FE8534020F0C000C2FB4A4017450F7C0CEA534020F0C000C2FB4A4017450F7C0CEA53401A6EC0E787F94A4094BDA59C2FE853401A6EC0E787F94A40
13009	Новый Баганенок	5	52	1105	78.712378999999999	78.745006000000004	53.877062000000002	53.853349000000001	0103000020E61000000100000005000000DCD6169E97AD534083893F8A3AED4A40DCD6169E97AD53403D484F9143F04A40B954A52DAEAF53403D484F9143F04A40B954A52DAEAF534083893F8A3AED4A40DCD6169E97AD534083893F8A3AED4A40
11556	Нижнечеремошное	5	52	1105	78.853999000000002	78.913044999999997	53.963850000000001	53.934837999999999	0103000020E6100000010000000500000045F46BEBA7B653406E8786C5A8F74A4045F46BEBA7B65340F31FD26F5FFB4A40AFB14B546FBA5340F31FD26F5FFB4A40AFB14B546FBA53406E8786C5A8F74A4045F46BEBA7B653406E8786C5A8F74A40
11440	Мохнатый Лог	5	52	1105	79.561126000000002	79.627403000000001	54.028683000000001	54.006982000000001	0103000020E61000000100000005000000DCBB067DE9E3534091D442C9E4004B40DCBB067DE9E35340C07971E2AB034B40639AE95E27E85340C07971E2AB034B40639AE95E27E8534091D442C9E4004B40DCBB067DE9E3534091D442C9E4004B40
11189	Майское	5	52	1105	79.745791999999994	79.774467000000001	54.080074000000003	54.063955	0103000020E6100000010000000500000094675E0EBBEF534035B56CAD2F084B4094675E0EBBEF534045A165DD3F0A4B40333509DE90F1534045A165DD3F0A4B40333509DE90F1534035B56CAD2F084B4094675E0EBBEF534035B56CAD2F084B40
12611	Луговой	5	52	1105	79.422865999999999	79.443707000000003	54.104951	54.091380999999998	0103000020E61000000100000005000000C8258E3C10DB5340E63C635FB20B4B40C8258E3C10DB53405C57CC086F0D4B4067800BB265DC53405C57CC086F0D4B4067800BB265DC5340E63C635FB20B4B40C8258E3C10DB5340E63C635FB20B4B40
11176	Лотошное	5	52	1105	78.775925999999998	78.819468000000001	54.148294999999997	54.126826999999999	0103000020E610000001000000050000006E8786C5A8B15340F99FFCDD3B104B406E8786C5A8B1534085949F54FB124B409607E92972B4534085949F54FB124B409607E92972B45340F99FFCDD3B104B406E8786C5A8B15340F99FFCDD3B104B40
10946	Локтенок	5	52	1105	79.00479	79.058518000000007	53.963484000000001	53.941701999999999	0103000020E610000001000000050000004356B77A4EC05340F549EEB089F84A404356B77A4EC05340111C977153FB4A408D0E48C2BEC35340111C977153FB4A408D0E48C2BEC35340F549EEB089F84A404356B77A4EC05340F549EEB089F84A40
11130	Лобино	5	52	1105	79.003163999999998	79.042761999999996	53.875309999999999	53.847431999999998	0103000020E610000001000000050000009221C7D633C05340BCCADAA678EC4A409221C7D633C053404EEE77280AF04A40BDE0D39CBCC253404EEE77280AF04A40BDE0D39CBCC25340BCCADAA678EC4A409221C7D633C05340BCCADAA678EC4A40
60655	Ленинградский	5	52	1105	79.232782	79.243786999999998	54.136054000000001	54.122252000000003	0103000020E610000001000000050000003D4679E6E5CE534070EF1AF4A50F4B403D4679E6E5CE5340B83EAC376A114B40280CCA349ACF5340B83EAC376A114B40280CCA349ACF534070EF1AF4A50F4B403D4679E6E5CE534070EF1AF4A50F4B40
11804	Курьинский	5	52	1105	79.837644999999995	79.859268	53.961593000000001	53.948936000000003	0103000020E610000001000000050000001B2AC6F99BF55340A0FF1EBC76F94A401B2AC6F99BF553400188BB7A15FB4A40F59F353FFEF653400188BB7A15FB4A40F59F353FFEF65340A0FF1EBC76F94A401B2AC6F99BF55340A0FF1EBC76F94A40
10716	Красный Хутор	5	52	1105	79.252167999999998	79.269469999999998	53.966186	53.956195000000001	0103000020E610000001000000050000004146408523D05340A3CC069964FA4A404146408523D0534031ED9BFBABFB4A40335019FF3ED1534031ED9BFBABFB4A40335019FF3ED15340A3CC069964FA4A404146408523D05340A3CC069964FA4A40
10429	Краснозерское	5	52	1105	79.208248999999995	79.283151000000004	53.995328999999998	53.966878999999999	0103000020E610000001000000050000002E1B9DF353CD53403718EAB0C2FB4A402E1B9DF353CD534054E1CFF066FF4A401A355F251FD2534054E1CFF066FF4A401A355F251FD253403718EAB0C2FB4A402E1B9DF353CD53403718EAB0C2FB4A40
10983	Конево	5	52	1105	78.993955999999997	79.012974	54.245482000000003	54.224727000000001	0103000020E610000001000000050000006E6AA0F99CBF53409CC3B5DAC31C4B406E6AA0F99CBF5340DBE044F46B1F4B40B16CE690D4C05340DBE044F46B1F4B40B16CE690D4C053409CC3B5DAC31C4B406E6AA0F99CBF53409CC3B5DAC31C4B40
10886	Колыбелька	5	52	1105	79.123762999999997	79.158321000000001	54.073354000000002	54.058728000000002	0103000020E610000001000000050000001C5DA5BBEBC7534004AE2B6684074B401C5DA5BBEBC75340F183F3A963094B40485167EE21CA5340F183F3A963094B40485167EE21CA534004AE2B6684074B401C5DA5BBEBC7534004AE2B6684074B40
10647	Кайгородский	5	52	1105	79.185118000000003	79.209057999999999	53.991571	53.976402	0103000020E61000000100000005000000A9F92AF9D8CB5340DFDFA0BDFAFC4A40A9F92AF9D8CB5340BD546CCCEBFE4A40E63DCE3461CD5340BD546CCCEBFE4A40E63DCE3461CD5340DFDFA0BDFAFC4A40A9F92AF9D8CB5340DFDFA0BDFAFC4A40
10326	Казанак	5	52	1105	79.146687999999997	79.175685999999999	54.194234000000002	54.176183000000002	0103000020E61000000100000005000000CDAD105663C953403B8E1F2A8D164B40CDAD105663C95340B9E2E2A8DC184B405D177E703ECB5340B9E2E2A8DC184B405D177E703ECB53403B8E1F2A8D164B40CDAD105663C953403B8E1F2A8D164B40
12103	Зуевский	5	52	1105	79.381480999999994	79.398144000000002	53.767181999999998	53.753751999999999	0103000020E61000000100000005000000E7C2482F6AD85340B5A50EF27AE04A40E7C2482F6AD85340390A100533E24A4050C6F8307BD95340390A100533E24A4050C6F8307BD95340B5A50EF27AE04A40E7C2482F6AD85340B5A50EF27AE04A40
10064	Зубково	5	52	1105	78.634190000000004	78.674102000000005	53.785299999999999	53.762551000000002	0103000020E61000000100000005000000D15CA79196A853401C446B459BE14A40D15CA79196A853403FC6DCB584E44A40C40AB77C24AB53403FC6DCB584E44A40C40AB77C24AB53401C446B459BE14A40D15CA79196A853401C446B459BE14A40
11692	Зеленая Роща	5	52	1105	79.641542999999999	79.654757000000004	53.907778999999998	53.898777000000003	0103000020E6100000010000000500000093FE5E0A0FE95340D1B2EE1F0BF34A4093FE5E0A0FE953406F7F2E1A32F44A40EF74E789E7E953406F7F2E1A32F44A40EF74E789E7E95340D1B2EE1F0BF34A4093FE5E0A0FE95340D1B2EE1F0BF34A40
12296	Голубинский	5	52	1105	79.259399999999999	79.278443999999993	53.708075000000001	53.696241000000001	0103000020E61000000100000005000000462575029AD053403291D26C1ED94A40462575029AD05340BF0E9C33A2DA4A401D71C806D2D15340BF0E9C33A2DA4A401D71C806D2D153403291D26C1ED94A40462575029AD053403291D26C1ED94A40
10863	Гербаево	5	52	1105	79.405816000000002	79.443860000000001	53.993375999999998	53.974178000000002	0103000020E61000000100000005000000630CACE3F8D95340C93D5DDDB1FC4A40630CACE3F8D95340CE50DCF126FF4A402A00C63368DC5340CE50DCF126FF4A402A00C63368DC5340C93D5DDDB1FC4A40630CACE3F8D95340C93D5DDDB1FC4A40
10028	Ганино	5	52	1105	79.017860999999996	79.027814000000006	53.766596	53.755093000000002	0103000020E61000000100000005000000EDB776A224C1534022382EE3A6E04A40EDB776A224C15340499F56D11FE24A40BE175FB4C7C15340499F56D11FE24A40BE175FB4C7C1534022382EE3A6E04A40EDB776A224C1534022382EE3A6E04A40
12915	Веселовское	5	52	1105	78.689311000000004	78.734801000000004	54.009655000000002	53.975703000000003	0103000020E610000001000000050000007A71E2AB1DAC5340F7CDFDD5E3FC4A407A71E2AB1DAC5340179F02603C014B405C04C6FA06AF5340179F02603C014B405C04C6FA06AF5340F7CDFDD5E3FC4A407A71E2AB1DAC5340F7CDFDD5E3FC4A40
11420	Беспятый	5	52	1105	79.692413999999999	79.702466999999999	54.187579999999997	54.180272000000002	0103000020E61000000100000005000000B952CF8250EC53403831242713174B40B952CF8250EC53401CB1169F02184B403BE12538F5EC53401CB1169F02184B403BE12538F5EC53403831242713174B40B952CF8250EC53403831242713174B40
9914	Аксениха	5	52	1105	78.930543999999998	78.958220999999995	53.726367000000003	53.709242000000003	0103000020E610000001000000050000004CDF6B088EBB53408E791D71C8DA4A404CDF6B088EBB534063F20698F9DC4A40C9552C7E53BD534063F20698F9DC4A40C9552C7E53BD53408E791D71C8DA4A404CDF6B088EBB53408E791D71C8DA4A40
34708	Александровка	5	52	3058	37.196235999999999	37.217920999999997	55.755884999999999	55.744687999999996	0103000020E610000001000000050000002026E1421E994240A0DCB6EF51DF4B402026E1421E994240BB44F5D6C0E04B40490ED8D5E49B4240BB44F5D6C0E04B40490ED8D5E49B4240A0DCB6EF51DF4B402026E1421E994240A0DCB6EF51DF4B40
48031	Троицкий	5	52	1054	79.916777999999994	79.939712	54.014073000000003	53.997171000000002	0103000020E610000001000000050000004EECA17DACFA534083C2A04CA3FF4A404EECA17DACFA5340D960E124CD014B4029EACC3D24FC5340D960E124CD014B4029EACC3D24FC534083C2A04CA3FF4A404EECA17DACFA534083C2A04CA3FF4A40
41350	Советский	5	52	1054	80.392346000000003	80.405129000000002	54.205441999999998	54.196292999999997	0103000020E61000000100000005000000DAAD65321C19544084B7072120194B40DAAD65321C195440C79C67EC4B1A4B40516A2FA2ED195440C79C67EC4B1A4B40516A2FA2ED19544084B7072120194B40DAAD65321C19544084B7072120194B40
47984	Решеты	5	52	1054	80.173030999999995	80.257014999999996	54.236353000000001	54.196714999999998	0103000020E610000001000000050000006D8C9DF0120B5440FAD005F52D194B406D8C9DF0120B5440DFA7AAD0401E4B4036E50AEF72105440DFA7AAD0401E4B4036E50AEF72105440FAD005F52D194B406D8C9DF0120B5440FAD005F52D194B40
9814	Республиканский	5	52	1054	80.772693000000004	80.788916	54.270054000000002	54.260868000000002	0103000020E61000000100000005000000483657CD733154405649641F64214B40483657CD73315440B613252191224B40A2D288997D325440B613252191224B40A2D288997D3254405649641F64214B40483657CD733154405649641F64214B40
41341	Покровка	5	52	1054	80.507994999999994	80.525852999999998	54.123159999999999	54.111955999999999	0103000020E6100000010000000500000004E275FD82205440A54BFF92540E4B4004E275FD822054407216F6B4C30F4B4039605793A72154407216F6B4C30F4B4039605793A7215440A54BFF92540E4B4004E275FD82205440A54BFF92540E4B40
9455	Новые Решеты	5	52	1054	80.379671000000002	80.401589000000001	54.134677000000003	54.122900999999999	0103000020E61000000100000005000000560F98874C185440A6D24F38BB0F4B40560F98874C185440FF428F183D114B40BC5B59A2B3195440FF428F183D114B40BC5B59A2B3195440A6D24F38BB0F4B40560F98874C185440A6D24F38BB0F4B40
9269	Новоцелинное	5	52	1054	80.506197999999998	80.531513000000004	54.362363000000002	54.350133	0103000020E610000001000000050000003DD34B8C652054400C207C28D12C4B403DD34B8C65205440E62329E9612E4B4087191A4F04225440E62329E9612E4B4087191A4F042254400C207C28D12C4B403DD34B8C652054400C207C28D12C4B40
9274	Красная Сибирь	5	52	1054	80.470993000000007	80.532627000000005	54.342114000000002	54.307882999999997	0103000020E6100000010000000500000047E9D2BF241E544047FFCBB568274B4047E9D2BF241E54407BC03C64CA2B4B40DD7D8E8F162254407BC03C64CA2B4B40DD7D8E8F1622544047FFCBB568274B4047E9D2BF241E544047FFCBB568274B40
9713	Кочки	5	52	1054	80.456072000000006	80.518083000000004	54.345976	54.318776999999997	0103000020E61000000100000005000000C4279D48301D5440C6DB4AAFCD284B40C4279D48301D5440B7990AF1482C4B404567994528215440B7990AF1482C4B404567994528215440C6DB4AAFCD284B40C4279D48301D5440C6DB4AAFCD284B40
9845	Жуланка	5	52	1054	80.580129999999997	80.636471999999998	54.373683	54.347262000000001	0103000020E610000001000000050000006C5B94D9202554406092CA14732C4B406C5B94D9202554401C0934D8D42F4B4076340EF5BB2854401C0934D8D42F4B4076340EF5BB2854406092CA14732C4B406C5B94D9202554406092CA14732C4B40
47950	Ермаковский	5	52	1054	80.301238999999995	80.319051999999999	54.132688000000002	54.115544999999997	0103000020E61000000100000005000000E751F17F47135440B01BB62DCA0E4B40E751F17F471354402C499EEBFB104B404C6E14596B1454402C499EEBFB104B404C6E14596B145440B01BB62DCA0E4B40E751F17F47135440B01BB62DCA0E4B40
41311	Быструха	5	52	1054	80.848716999999994	80.906856000000005	54.446261	54.422381000000001	0103000020E61000000100000005000000CAA31B6151365440D4B9A29410364B40CAA31B6151365440793D98141F394B409C8BBFED093A5440793D98141F394B409C8BBFED093A5440D4B9A29410364B40CAA31B6151365440D4B9A29410364B40
9625	Букреево Плесо	5	52	1054	79.925185999999997	79.965269000000006	54.146254999999996	54.119714000000002	0103000020E61000000100000005000000E42D573F36FB5340CA6FD1C9520F4B40E42D573F36FB534030F0DC7BB8124B40EEB5A0F7C6FD534030F0DC7BB8124B40EEB5A0F7C6FD5340CA6FD1C9520F4B40E42D573F36FB5340CA6FD1C9520F4B40
41385	Шагалово	5	52	829	82.20608	82.230101000000005	54.918095000000001	54.907325	0103000020E6100000010000000500000005172B6A308D5440EEEBC03923744B4005172B6A308D544081CF0F2384754B40B9718BF9B98E544081CF0F2384754B40B9718BF9B98E5440EEEBC03923744B4005172B6A308D5440EEEBC03923744B40
41225	Чистополье	5	52	829	82.489138999999994	82.506028000000001	54.972209999999997	54.955933999999999	0103000020E61000000100000005000000AE0CAA0D4E9F54403691990B5C7A4B40AE0CAA0D4E9F54400D6C9560717C4B400FB743C362A054400D6C9560717C4B400FB743C362A054403691990B5C7A4B40AE0CAA0D4E9F54403691990B5C7A4B40
7488	Чик	5	52	829	82.419475000000006	82.462630000000004	55.000186999999997	54.985647999999998	0103000020E61000000100000005000000569FABADD89A544014AFB2B6297E4B40569FABADD89A54403271AB2006804B408109DCBA9B9D54403271AB2006804B408109DCBA9B9D544014AFB2B6297E4B40569FABADD89A544014AFB2B6297E4B40
41216	Целинное	5	52	829	81.987206	82.003913999999995	54.816322999999997	54.804850999999999	0103000020E610000001000000050000008F1A13622E7F54409293895B05674B408F1A13622E7F54407EFCA5457D684B40C77F8120408054407EFCA5457D684B40C77F8120408054409293895B05674B408F1A13622E7F54409293895B05674B40
47590	Федосово	5	52	829	82.145453000000003	82.167254999999997	54.878045	54.869289999999999	0103000020E61000000100000005000000BA86191A4F895440B35E0CE5446F4B40BA86191A4F8954404AB54FC763704B40EBC5504EB48A54404AB54FC763704B40EBC5504EB48A5440B35E0CE5446F4B40BA86191A4F895440B35E0CE5446F4B40
41369	Федлсиха	5	52	829	81.325291000000007	82.821893000000003	55.513697999999998	54.649197999999998	0103000020E61000000100000005000000B9AB5791D1545440765089EB18534B40B9AB5791D1545440A30227DBC0C14B40EDF318E599B45440A30227DBC0C14B40EDF318E599B45440765089EB18534B40B9AB5791D1545440765089EB18534B40
47200	Троицк	5	52	829	82.232679000000005	82.259297000000004	55.137991	55.125771999999998	0103000020E61000000100000005000000D3DD7536E48E54405260014C19904B40D3DD7536E48E5440381268B0A9914B40DCBC715298905440381268B0A9914B40DCBC7152989054405260014C19904B40D3DD7536E48E54405260014C19904B40
41248	Студенкино	5	52	829	81.832255000000004	81.849027000000007	55.176197999999999	55.160750999999998	0103000020E61000000100000005000000AEBB79AA437554404FE61F7D93944B40AEBB79AA4375544070CFF3A78D964B40F29A57755676544070CFF3A78D964B40F29A5775567654404FE61F7D93944B40AEBB79AA437554404FE61F7D93944B40
41211	Семеновский	5	52	829	82.052756000000002	82.060301999999993	55.166840000000001	55.150854000000002	0103000020E61000000100000005000000BDAAB35A60835440433C122F4F934B40BDAAB35A6083544013D55B035B954B408978EBFCDB83544013D55B035B954B408978EBFCDB835440433C122F4F934B40BDAAB35A60835440433C122F4F934B40
47113	Светлый	5	52	829	82.257993999999997	82.306421999999998	55.019083000000002	55.007612000000002	0103000020E610000001000000050000001C2444F9829054405187156EF9804B401C2444F9829054406D74CE4F71824B409831056B9C9354406D74CE4F71824B409831056B9C9354405187156EF9804B401C2444F9829054405187156EF9804B40
40453	Речник	5	52	829	82.496900999999994	82.514508000000006	54.901367	54.888879000000003	0103000020E610000001000000050000006116DA39CD9F5440F48C7DC9C6714B406116DA39CD9F5440C9586DFE5F734B40F261F6B2EDA05440C9586DFE5F734B40F261F6B2EDA05440F48C7DC9C6714B406116DA39CD9F5440F48C7DC9C6714B40
7207	Прокудское	5	52	829	82.431728000000007	82.478089999999995	55.025776999999998	55.000559000000003	0103000020E610000001000000050000001F317A6EA19B5440F75B3B5112804B401F317A6EA19B544097FE25A94C834B40DBA2CC06999E544097FE25A94C834B40DBA2CC06999E5440F75B3B5112804B401F317A6EA19B5440F75B3B5112804B40
6934	Поваренка	5	52	829	82.103322000000006	82.437944000000002	54.835242999999998	54.722540000000002	0103000020E6100000010000000500000045BDE0D39C865440A306D3307C5C4B4045BDE0D39C865440419B1C3EE96A4B40AF5E4546079C5440419B1C3EE96A4B40AF5E4546079C5440A306D3307C5C4B4045BDE0D39C865440A306D3307C5C4B40
6516	Ольшанский	5	52	829	81.784546000000006	81.799880000000002	55.018416999999999	55.007627999999997	0103000020E610000001000000050000004A0D6D003672544056444DF4F9804B404A0D6D00367254406058FE7C5B824B405E2EE23B317354406058FE7C5B824B405E2EE23B3173544056444DF4F9804B404A0D6D003672544056444DF4F9804B40
41197	Овчинниково	5	52	829	81.672481000000005	81.698235999999994	55.203642000000002	55.193216999999997	0103000020E610000001000000050000009C8BBFED096B5440FF03AC55BB984B409C8BBFED096B5440C80BE9F0109A4B40F3380CE6AF6C5440C80BE9F0109A4B40F3380CE6AF6C5440FF03AC55BB984B409C8BBFED096B5440FF03AC55BB984B40
49611	Новорощинский	5	52	829	81.603876999999997	81.618654000000006	55.213915999999998	55.203786000000001	0103000020E610000001000000050000009F73B7EBA5665440FBB0DEA8159A4B409F73B7EBA5665440AA0B7899619B4B408962F20698675440AA0B7899619B4B408962F20698675440FBB0DEA8159A4B409F73B7EBA5665440FBB0DEA8159A4B40
7651	Новоотрубное (Улькино)	5	52	829	82.134628000000006	82.152540999999999	55.136313000000001	55.124527	0103000020E610000001000000050000000F48C2BE9D885440083C3080F08F4B400F48C2BE9D885440848252B472914B402593533BC3895440848252B472914B402593533BC3895440083C3080F08F4B400F48C2BE9D885440083C3080F08F4B40
6048	Новокремлевское	5	52	829	82.303888999999998	82.329804999999993	55.205424999999998	55.190641999999997	0103000020E610000001000000050000004E27D9EA729354403C9F01F566984B404E27D9EA72935440F163CC5D4B9A4B40AA436E861B955440F163CC5D4B9A4B40AA436E861B9554403C9F01F566984B404E27D9EA729354403C9F01F566984B40
6117	Молот	5	52	829	82.282599000000005	82.301580000000001	55.303939	55.294324000000003	0103000020E6100000010000000500000078B81D1A16925440C636A968ACA54B4078B81D1A169254404E7D2079E7A64B402C4833164D9354404E7D2079E7A64B402C4833164D935440C636A968ACA54B4078B81D1A16925440C636A968ACA54B40
41221	Маслово	5	52	829	81.833108999999993	81.847634999999997	54.869197	54.861792999999999	0103000020E61000000100000005000000354069A851755440FB75A73B4F6E4B40354069A8517554400264E8D8416F4B407AFCDEA63F7654400264E8D8416F4B407AFCDEA63F765440FB75A73B4F6E4B40354069A851755440FB75A73B4F6E4B40
8352	Малореченка	5	52	829	81.999504000000002	82.011190999999997	54.850132000000002	54.838493999999997	0103000020E61000000100000005000000280EA0DFF77F544034F279C5536B4B40280EA0DFF77F54403CA41820D16C4B409CC0745AB78054403CA41820D16C4B409CC0745AB780544034F279C5536B4B40280EA0DFF77F544034F279C5536B4B40
47402	Лесной	5	52	829	81.682488000000006	81.699528999999998	54.746051000000001	54.737465	0103000020E6100000010000000500000066FA25E2AD6B5440EA78CC40655E4B4066FA25E2AD6B5440F51263997E5F4B40A1664815C56C5440F51263997E5F4B40A1664815C56C5440EA78CC40655E4B4066FA25E2AD6B5440EA78CC40655E4B40
6361	Лесная Поляна	5	52	829	81.919347000000002	81.954425999999998	55.051921999999998	55.033723000000002	0103000020E610000001000000050000003FABCC94D67A5440BF0F070951844B403FABCC94D67A5440B1F84D61A5864B40EF1CCA50157D5440B1F84D61A5864B40EF1CCA50157D5440BF0F070951844B403FABCC94D67A5440BF0F070951844B40
6264	Крутологово	5	52	829	82.071242999999996	82.105703000000005	55.312429999999999	55.300325999999998	0103000020E6100000010000000500000069C4CC3E8F845440BA11161571A64B4069C4CC3E8F8454400725CCB4FDA74B40B40584D6C38654400725CCB4FDA74B40B40584D6C3865440BA11161571A64B4069C4CC3E8F845440BA11161571A64B40
7515	Крохалевка	5	52	829	82.536544000000006	82.553279000000003	55.156137000000001	55.136462999999999	0103000020E610000001000000050000005D37A5BC56A25440990E9D9E77914B405D37A5BC56A254400859164CFC934B4012A452EC68A354400859164CFC934B4012A452EC68A35440990E9D9E77914B405D37A5BC56A25440990E9D9E77914B40
8716	Коченево	5	52	829	82.166689000000005	82.245939000000007	55.043194999999997	54.995187999999999	0103000020E6100000010000000500000097E65608AB8A544092AF0452627F4B4097E65608AB8A5440E42CEC6987854B40E773EE76BD8F5440E42CEC6987854B40E773EE76BD8F544092AF0452627F4B4097E65608AB8A544092AF0452627F4B40
7014	Комихинский	5	52	829	82.112054000000001	82.123849000000007	54.780776000000003	54.771315000000001	0103000020E61000000100000005000000B4588AE42B87544006F52D73BA624B40B4588AE42B87544038C0CC77F0634B401C295B24ED87544038C0CC77F0634B401C295B24ED87544006F52D73BA624B40B4588AE42B87544006F52D73BA624B40
41271	Козлово	5	52	829	81.934672000000006	81.957076000000001	54.914504000000001	54.903547000000003	0103000020E610000001000000050000002A1F82AAD17B544010B3976DA7734B402A1F82AAD17B5440D50792770E754B4056F2B1BB407D5440D50792770E754B4056F2B1BB407D544010B3976DA7734B402A1F82AAD17B544010B3976DA7734B40
41382	Катково	5	52	829	81.898847000000004	82.549695	55.214553000000002	55.105671000000001	0103000020E61000000100000005000000E54691B5867954405C9198A0868D4B40E54691B5867954401D210379769B4B4095F1EF332EA354401D210379769B4B4095F1EF332EA354405C9198A0868D4B40E54691B5867954405C9198A0868D4B40
41278	Казаково	5	52	829	82.285068999999993	82.308901000000006	54.951813000000001	54.942661000000001	0103000020E610000001000000050000009E060C923E9254407A1B9B1DA9784B409E060C923E9254402E742502D5794B40E92CB308C59354402E742502D5794B40E92CB308C59354407A1B9B1DA9784B409E060C923E9254407A1B9B1DA9784B40
41198	Ермиловка	5	52	829	81.927638999999999	81.953214000000003	55.31765	55.301248999999999	0103000020E61000000100000005000000A0DFF76F5E7B5440F279C5538FA64B40A0DFF76F5E7B544086C954C1A8A84B40B8054B75017D544086C954C1A8A84B40B8054B75017D5440F279C5538FA64B40A0DFF76F5E7B5440F279C5538FA64B40
5978	Дупленская	5	52	829	81.605654999999999	81.635686000000007	55.099521000000003	55.078128	0103000020E610000001000000050000002B6A300DC366544071732A19008A4B402B6A300DC3665440F321A81ABD8C4B409B215514AF685440F321A81ABD8C4B409B215514AF68544071732A19008A4B402B6A300DC366544071732A19008A4B40
41367	Дружный	5	52	829	82.152675000000002	82.164237	54.976385000000001	54.971491	0103000020E61000000100000005000000ADFA5C6DC5895440DEAD2CD1597C4B40ADFA5C6DC589544009A7052FFA7C4B40C3F2E7DB828A544009A7052FFA7C4B40C3F2E7DB828A5440DEAD2CD1597C4B40ADFA5C6DC5895440DEAD2CD1597C4B40
46655	Вахрушево	5	52	829	82.140162000000004	82.171828000000005	55.253208999999998	55.240394999999999	0103000020E610000001000000050000001689096AF88854409B8F6B43C59E4B401689096AF8885440C4060B2769A04B406022DE3AFF8A5440C4060B2769A04B406022DE3AFF8A54409B8F6B43C59E4B401689096AF88854409B8F6B43C59E4B40
41300	Буньково	5	52	829	82.473742000000001	82.496792999999997	55.068123	55.058481999999998	0103000020E61000000100000005000000772FF7C9519E5440CCB392567C874B40772FF7C9519E54407E8D2441B8884B406EF8DD74CB9F54407E8D2441B8884B406EF8DD74CB9F5440CCB392567C874B40772FF7C9519E5440CCB392567C874B40
41381	Белобородово	5	52	829	82.033216999999993	82.056753	55.074814000000003	55.058193000000003	0103000020E61000000100000005000000F52A323A2082544096ED43DE72874B40F52A323A2082544038A4518193894B40CBBC55D7A183544038A4518193894B40CBBC55D7A183544096ED43DE72874B40F52A323A2082544096ED43DE72874B40
9147	Бармашево	5	52	829	82.062996999999996	82.078502	55.012352	55.003126000000002	0103000020E61000000100000005000000C0AF91240884544037E2C96E66804B40C0AF912408845440250516C094814B40EBAA402D06855440250516C094814B40EBAA402D0685544037E2C96E66804B40C0AF91240884544037E2C96E66804B40
41200	Антоновка	5	52	829	82.287333000000004	82.315899000000002	54.836517999999998	54.824570000000001	0103000020E61000000100000005000000F183F3A963925440A1A17F828B694B40F183F3A963925440F6419605136B4B40B47570B037945440F6419605136B4B40B47570B037945440A1A17F828B694B40F183F3A963925440A1A17F828B694B40
4459	Юрт-Ора	5	52	597	82.907376999999997	82.919854999999998	55.448999999999998	55.444333	0103000020E610000001000000050000002009FB7612BA54404CC45BE7DFB84B402009FB7612BA5440B6F3FDD478B94B40F98381E7DEBA5440B6F3FDD478B94B40F98381E7DEBA54404CC45BE7DFB84B402009FB7612BA54404CC45BE7DFB84B40
5211	Юрт-Акбалык	5	52	597	83.555762999999999	83.571663000000001	55.664735999999998	55.650779999999997	0103000020E61000000100000005000000EB54F99E91E35440087250C24CD34B40EB54F99E91E35440A73CBA1116D54B405455682096E45440A73CBA1116D54B405455682096E45440087250C24CD34B40EB54F99E91E35440087250C24CD34B40
4292	Южино	5	52	597	82.508004	82.531171999999998	55.495925	55.482667999999997	0103000020E610000001000000050000002E8F352383A05440B169A510C8BD4B402E8F352383A0544068226C787ABF4B404223D8B8FEA1544068226C787ABF4B404223D8B8FEA15440B169A510C8BD4B402E8F352383A05440B169A510C8BD4B40
5058	Черный Мыс	5	52	597	83.256714000000002	83.274473999999998	55.521006999999997	55.511037000000002	0103000020E61000000100000005000000399B8E006ED05440E20511A969C14B40399B8E006ED0544058FE7C5BB0C24B408C6665FB90D1544058FE7C5BB0C24B408C6665FB90D15440E20511A969C14B40399B8E006ED05440E20511A969C14B40
3930	Чаус	5	52	597	82.776240999999999	82.783193999999995	55.350473999999998	55.337091999999998	0103000020E610000001000000050000001E34BBEEADB1544022DFA5D425AB4B401E34BBEEADB15440950C0055DCAC4B40191BBAD91FB25440950C0055DCAC4B40191BBAD91FB2544022DFA5D425AB4B401E34BBEEADB1544022DFA5D425AB4B40
4634	Тропино	5	52	597	82.686031999999997	82.703288999999998	55.540343	55.525022999999997	0103000020E610000001000000050000009B00C3F2E7AB5440EB5223F433C34B409B00C3F2E7AB5440AFCF9CF529C54B40BDA8DDAF02AD5440AFCF9CF529C54B40BDA8DDAF02AD5440EB5223F433C34B409B00C3F2E7AB5440EB5223F433C34B40
4846	Таловка	5	52	597	82.932304999999999	82.954286999999994	55.586776	55.579393000000003	0103000020E610000001000000050000006D3997E2AABB54400344C18C29CA4B406D3997E2AABB5440F209D9791BCB4B40DEFFC70913BD5440F209D9791BCB4B40DEFFC70913BD54400344C18C29CA4B406D3997E2AABB54400344C18C29CA4B40
4027	Соколово	5	52	597	82.550342000000001	82.575458999999995	55.215133000000002	55.186587000000003	0103000020E6100000010000000500000060E7A6CD38A35440EC6D3315E2974B4060E7A6CD38A354402BA5677A899B4B40164CFC51D4A454402BA5677A899B4B40164CFC51D4A45440EC6D3315E2974B4060E7A6CD38A35440EC6D3315E2974B40
4315	Скала	5	52	597	82.749166000000002	82.782286999999997	55.386415	55.369484999999997	0103000020E610000001000000050000009C51F355F2AF544068AED3484BAF4B409C51F355F2AF544088D7F50B76B14B4080457EFD10B2544088D7F50B76B14B4080457EFD10B2544068AED3484BAF4B409C51F355F2AF544068AED3484BAF4B40
4248	Сидоровка	5	52	597	82.394285999999994	82.422359	55.450563000000002	55.432693999999998	0103000020E6100000010000000500000052D158FB3B9954407496598462B74B4052D158FB3B995440D2E4620CACB94B40F60A0BEE079B5440D2E4620CACB94B40F60A0BEE079B54407496598462B74B4052D158FB3B9954407496598462B74B40
5442	Северный	5	52	597	82.679951000000003	82.701519000000005	56.023117999999997	56.013038999999999	0103000020E610000001000000050000007BF8325184AB544049490F43AB014C407BF8325184AB544076F9D687F5024C4073A1F2AFE5AC544076F9D687F5024C4073A1F2AFE5AC544049490F43AB014C407BF8325184AB544049490F43AB014C40
5798	Пономаревка	5	52	597	82.353440000000006	82.383883999999995	56.140900999999999	56.130146000000003	0103000020E610000001000000050000004A46CEC29E96544045DAC69FA8104C404A46CEC29E965440A27C410B09124C404A5D328E91985440A27C410B09124C404A5D328E9198544045DAC69FA8104C404A46CEC29E96544045DAC69FA8104C40
5420	Пихтовка	5	52	597	82.677875	82.739248000000003	56.011172000000002	55.979933000000003	0103000020E61000000100000005000000AAF1D24D62AB5440B6A2CD716EFD4B40AAF1D24D62AB5440C25087156E014C408AE8D7D64FAF5440C25087156E014C408AE8D7D64FAF5440B6A2CD716EFD4B40AAF1D24D62AB5440B6A2CD716EFD4B40
4685	Паутовский	5	52	597	82.743722000000005	82.763557000000006	55.570701	55.559893000000002	0103000020E6100000010000000500000035D4282499AF54403221E692AAC74B4035D4282499AF5440B265F9BA0CC94B4071E82D1EDEB05440B265F9BA0CC94B4071E82D1EDEB054403221E692AAC74B4035D4282499AF54403221E692AAC74B40
4151	Новотырышкино	5	52	597	82.387540000000001	82.432213000000004	55.296712999999997	55.278492999999997	0103000020E6100000010000000500000014799274CD9854401C959BA8A5A34B4014799274CD98544026A60BB1FAA54B40FDF9B660A99B544026A60BB1FAA54B40FDF9B660A99B54401C959BA8A5A34B4014799274CD9854401C959BA8A5A34B40
4986	Новотроицк	5	52	597	83.263469000000001	83.284705000000002	55.607940999999997	55.595272000000001	0103000020E61000000100000005000000A1A014ADDCD05440BD1C76DF31CC4B40A1A014ADDCD05440E272BC02D1CD4B407E00529B38D25440E272BC02D1CD4B407E00529B38D25440BD1C76DF31CC4B40A1A014ADDCD05440BD1C76DF31CC4B40
41339	Новоалександровка	5	52	597	82.520733000000007	82.538798	56.171757999999997	56.164175	0103000020E61000000100000005000000AC3C81B053A1544010E9B7AF03154C40AC3C81B053A15440C669882AFC154C409D499BAA7BA25440C669882AFC154C409D499BAA7BA2544010E9B7AF03154C40AC3C81B053A1544010E9B7AF03154C40
5676	Мальчиха	5	52	597	82.540199999999999	82.562360999999996	55.854052000000003	55.843040000000002	0103000020E61000000100000005000000265305A392A25440249C16BCE8EB4B40265305A392A25440AD8A709351ED4B40EFE2FDB8FDA35440AD8A709351ED4B40EFE2FDB8FDA35440249C16BCE8EB4B40265305A392A25440249C16BCE8EB4B40
4033	Малый Оёш	5	52	597	82.648842000000002	82.676446999999996	55.282231000000003	55.272190000000002	0103000020E610000001000000050000005C9198A086A954402D26361FD7A24B405C9198A086A954406D75392520A44B408C9E5BE84AAB54406D75392520A44B408C9E5BE84AAB54402D26361FD7A24B405C9198A086A954402D26361FD7A24B40
41312	Малиновка	5	52	597	82.732268000000005	82.739643999999998	56.033686000000003	56.025185	0103000020E6100000010000000500000012FA997ADDAE5440C5AC174339034C4012FA997ADDAE5440A22AA6D24F044C40B0ABC95356AF5440A22AA6D24F044C40B0ABC95356AF5440C5AC174339034C4012FA997ADDAE5440C5AC174339034C40
4904	Малая Черемшанка	5	52	597	83.010853999999995	83.030778999999995	55.599972000000001	55.589680999999999	0103000020E61000000100000005000000F8C1F9D4B1C054404A09C1AA7ACB4B40F8C1F9D4B1C054400342EBE1CBCC4B40D4997B48F8C154400342EBE1CBCC4B40D4997B48F8C154404A09C1AA7ACB4B40F8C1F9D4B1C054404A09C1AA7ACB4B40
5545	Лаптевка	5	52	597	82.298130999999998	82.317480000000003	55.796866000000001	55.784354	0103000020E610000001000000050000001FBB0B94149354404F3E3DB665E44B401FBB0B9414935440ADA580B4FFE54B409548A29751945440ADA580B4FFE54B409548A297519454404F3E3DB665E44B401FBB0B94149354404F3E3DB665E44B40
5740	Королевка	5	52	597	83.008607999999995	83.043535000000006	56.039876999999997	56.023183000000003	0103000020E61000000100000005000000F99E91088DC054405E6919A9F7024C40F99E91088DC05440696E85B01A054C40CF4E0647C9C25440696E85B01A054C40CF4E0647C9C254405E6919A9F7024C40F99E91088DC054405E6919A9F7024C40
3752	Колывань	5	52	597	82.709729999999993	82.768281999999999	55.325001	55.294446999999998	0103000020E610000001000000050000005DBF60376CAD5440E1B37570B0A54B405DBF60376CAD54406A15FDA199A94B40C00644882BB154406A15FDA199A94B40C00644882BB15440E1B37570B0A54B405DBF60376CAD5440E1B37570B0A54B40
5340	Кандаурово	5	52	597	83.185333999999997	83.203192000000001	55.685523000000003	55.662953000000002	0103000020E610000001000000050000008F352383DCCB54407EE4D6A4DBD44B408F352383DCCB5440F2D3B837BFD74B40C4B3041901CD5440F2D3B837BFD74B40C4B3041901CD54407EE4D6A4DBD44B408F352383DCCB54407EE4D6A4DBD44B40
5156	Казанка	5	52	597	83.467827	83.486198000000002	55.671548999999999	55.663353999999998	0103000020E61000000100000005000000E44BA8E0F0DD5440DCD5ABC8E8D44B40E44BA8E0F0DD5440AC545051F5D54B405C5837DE1DDF5440AC545051F5D54B405C5837DE1DDF5440DCD5ABC8E8D44B40E44BA8E0F0DD5440DCD5ABC8E8D44B40
4805	Вьюны	5	52	597	82.913809000000001	82.942725999999993	55.540999999999997	55.504067999999997	0103000020E610000001000000050000009772BED87BBA5440E57ADB4C85C04B409772BED87BBA54406891ED7C3FC54B40B0C56E9F55BC54406891ED7C3FC54B40B0C56E9F55BC5440E57ADB4C85C04B409772BED87BBA5440E57ADB4C85C04B40
4138	Воробьево	5	52	597	82.555255000000002	82.585222999999999	55.312711999999998	55.306716999999999	0103000020E61000000100000005000000317C444C89A354404910AE8042A74B40317C444C89A354408B8862F206A84B407D772B4B74A554408B8862F206A84B407D772B4B74A554404910AE8042A74B40317C444C89A354404910AE8042A74B40
4550	Боярка	5	52	597	82.736526999999995	82.765713000000005	55.632164000000003	55.610545000000002	0103000020E61000000100000005000000BE67244223AF544040DEAB5626CE4B40BE67244223AF5440B2DAFCBFEAD04B40D047197101B15440B2DAFCBFEAD04B40D047197101B1544040DEAB5626CE4B40BE67244223AF544040DEAB5626CE4B40
3925	Большой Оёш	5	52	597	82.699408000000005	82.733345999999997	55.294089	55.284301999999997	0103000020E61000000100000005000000E4A3C519C3AC5440FC17080264A44B40E4A3C519C3AC5440828E56B5A4A54B40C1A90F24EFAE5440828E56B5A4A54B40C1A90F24EFAE5440FC17080264A44B40E4A3C519C3AC5440FC17080264A44B40
4408	Амба	5	52	597	82.758077	82.778639999999996	55.447274	55.430599999999998	0103000020E6100000010000000500000063B6645584B054402CD49AE61DB74B4063B6645584B05440F12C414640B94B40E0D6DD3CD5B15440F12C414640B94B40E0D6DD3CD5B154402CD49AE61DB74B4063B6645584B054402CD49AE61DB74B40
2695	Чернявский	5	52	250	80.254957000000005	80.261291	55.044088000000002	55.027329999999999	0103000020E61000000100000005000000B9382A37511054408F19A88C7F834B40B9382A3751105440B212F3ACA4854B404EEFE2FDB8105440B212F3ACA4854B404EEFE2FDB81054408F19A88C7F834B40B9382A37511054408F19A88C7F834B40
2493	Форпост-Каргат	5	52	250	80.433730999999995	80.453449000000006	55.281564000000003	55.269308000000002	0103000020E61000000100000005000000BA10AB3FC21B54408D463EAF78A24B40BA10AB3FC21B544090DD054A0AA44B40DA59F44E051D544090DD054A0AA44B40DA59F44E051D54408D463EAF78A24B40BA10AB3FC21B54408D463EAF78A24B40
1961	Филино	5	52	250	79.941077000000007	79.962222999999994	55.290633999999997	55.282867000000003	0103000020E610000001000000050000002481069B3AFC53400F0F61FC34A44B402481069B3AFC5340868DB27E33A54B40601DC70F95FD5340868DB27E33A54B40601DC70F95FD53400F0F61FC34A44B402481069B3AFC53400F0F61FC34A44B40
3213	Усть-Сумы	5	52	250	80.241483000000002	80.254076999999995	54.853386999999998	54.839219999999997	0103000020E610000001000000050000008FE21C75740F544016139B8F6B6B4B408FE21C75740F544070EA03C93B6D4B409C6A2DCC4210544070EA03C93B6D4B409C6A2DCC4210544016139B8F6B6B4B408FE21C75740F544016139B8F6B6B4B40
2157	Третьяковский	5	52	250	80.303663999999998	80.317103000000003	55.433562999999999	55.423462999999998	0103000020E610000001000000050000003E3E213B6F13544074081C0934B64B403E3E213B6F135440B9E00CFE7EB74B40AA9D616A4B145440B9E00CFE7EB74B40AA9D616A4B14544074081C0934B64B403E3E213B6F13544074081C0934B64B40
2505	Теренино	5	52	250	80.408489000000003	80.426922000000005	55.343701000000003	55.338954999999999	0103000020E61000000100000005000000A6F10BAF241A544068E89FE062AB4B40A6F10BAF241A54401F4DF564FEAB4B4059FCA6B0521B54401F4DF564FEAB4B4059FCA6B0521B544068E89FE062AB4B40A6F10BAF241A544068E89FE062AB4B40
3202	Сумы	5	52	250	80.427901000000006	80.470085999999995	54.824548999999998	54.800611000000004	0103000020E610000001000000050000003F3BE0BA621B5440B0E8D66B7A664B403F3BE0BA621B5440897956D28A694B40AD1397E3151E5440897956D28A694B40AD1397E3151E5440B0E8D66B7A664B403F3BE0BA621B5440B0E8D66B7A664B40
41289	Старомихайловский	5	52	250	79.980665999999999	80.009996000000001	55.098990000000001	55.087026999999999	0103000020E610000001000000050000002593533BC3FE53403B6F63B3238B4B402593533BC3FE5340C6504EB4AB8C4B40D04543C6A3005440C6504EB4AB8C4B40D04543C6A30054403B6F63B3238B4B402593533BC3FE53403B6F63B3238B4B40
3537	Сапожковский	5	52	250	80.419186999999994	80.438958999999997	54.533878999999999	54.520352000000003	0103000020E6100000010000000500000022FAB5F5D31A54404034F3E49A424B4022FAB5F5D31A5440B682A62556444B403B527DE7171C5440B682A62556444B403B527DE7171C54404034F3E49A424B4022FAB5F5D31A54404034F3E49A424B40
3399	Петровский	5	52	250	80.569367999999997	80.592687999999995	54.582313999999997	54.570284999999998	0103000020E61000000100000005000000E4D87A86702454401E335019FF484B40E4D87A86702454406000E143894A4B40D32EA699EE2554406000E143894A4B40D32EA699EE2554401E335019FF484B40E4D87A86702454401E335019FF484B40
3002	Первотроицк	5	52	250	80.359378000000007	80.390620999999996	55.098258999999999	55.086677000000002	0103000020E61000000100000005000000B939950C001754405F28603B188B4B40B939950C00175440D2C43BC0938C4B405F0839EFFF185440D2C43BC0938C4B405F0839EFFF1854405F28603B188B4B40B939950C001754405F28603B188B4B40
2841	Первомайский	5	52	250	80.174289000000002	80.190099000000004	55.046093999999997	55.042395999999997	0103000020E610000001000000050000005DC30C8D270B544098BD6C3B6D854B405DC30C8D270B54405A457F68E6854B402600FF942A0C54405A457F68E6854B402600FF942A0C544098BD6C3B6D854B405DC30C8D270B544098BD6C3B6D854B40
41267	Озерки 6-е	5	52	250	80.230191000000005	80.272465999999994	54.644786000000003	54.624232999999997	0103000020E6100000010000000500000059350873BB0E5440BF0AF0DDE64F4B4059350873BB0E54409775FF5888524B4067D13B15701154409775FF5888524B4067D13B1570115440BF0AF0DDE64F4B4059350873BB0E5440BF0AF0DDE64F4B40
2365	Натальинский	5	52	250	80.839860000000002	80.864500000000007	55.317132999999998	55.306444999999997	0103000020E61000000100000005000000FD4D2844C0355440E882FA9639A74B40FD4D2844C0355440BEBD6BD097A84B4017D9CEF753375440BEBD6BD097A84B4017D9CEF753375440E882FA9639A74B40FD4D2844C0355440E882FA9639A74B40
1364	Набережное	5	52	250	80.15316	80.192685999999995	55.179976000000003	55.167493	0103000020E610000001000000050000008BC3995FCD0954408BA71E6970954B408BC3995FCD0954404F081D7409974B406919A9F7540C54404F081D7409974B406919A9F7540C54408BA71E6970954B408BC3995FCD0954408BA71E6970954B40
2259	Мусы	5	52	250	80.421037999999996	80.438106000000005	55.461880000000001	55.447161999999999	0103000020E61000000100000005000000E3175E49F21A5440C901BB9A3CB94B40E3175E49F21A5440975643E21EBB4B409C8BBFED091C5440975643E21EBB4B409C8BBFED091C5440C901BB9A3CB94B40E3175E49F21A5440C901BB9A3CB94B40
3305	Москвинка	5	52	250	80.245202000000006	80.263077999999993	54.738686999999999	54.732460000000003	0103000020E610000001000000050000007CBABA63B10F544068D0D03FC15D4B407CBABA63B10F54407C7DAD4B8D5E4B4003931B45D61054407C7DAD4B8D5E4B4003931B45D610544068D0D03FC15D4B407CBABA63B10F544068D0D03FC15D4B40
3633	Маршанское	5	52	250	79.808871999999994	79.879047999999997	55.046470999999997	55.018438000000003	0103000020E610000001000000050000009BA9108FC4F353407880272D5C824B409BA9108FC4F35340309B00C3F2854B404FE78A5242F85340309B00C3F2854B404FE78A5242F853407880272D5C824B409BA9108FC4F353407880272D5C824B40
3445	Мамонтовое	5	52	250	80.321172000000004	80.347205000000002	54.670889000000003	54.660187999999998	0103000020E61000000100000005000000051901158E145440179B560A81544B40051901158E145440821FD5B0DF554B407E00529B38165440821FD5B0DF554B407E00529B38165440179B560A81544B40051901158E145440179B560A81544B40
1805	Лебедевский	5	52	250	80.146305999999996	80.162565999999998	55.234394000000002	55.224274000000001	0103000020E61000000100000005000000594DD7135D095440EBABAB02B59C4B40594DD7135D0954407730629F009E4B40425C397B670A54407730629F009E4B40425C397B670A5440EBABAB02B59C4B40594DD7135D095440EBABAB02B59C4B40
3049	Кубанский	5	52	250	80.425951999999995	80.456413999999995	55.109822000000001	55.104089999999999	0103000020E610000001000000050000009C6A2DCC421B54409AEB34D2528D4B409C6A2DCC421B5440CF30B5A50E8E4B40F0DB10E3351D5440CF30B5A50E8E4B40F0DB10E3351D54409AEB34D2528D4B409C6A2DCC421B54409AEB34D2528D4B40
2651	Кольцовка	5	52	250	80.208398000000003	80.236514999999997	54.993772999999997	54.978906000000002	0103000020E6100000010000000500000051A39064560D5440D9EDB3CA4C7D4B4051A39064560D5440EB5223F4337F4B40DC80CF0F230F5440EB5223F4337F4B40DC80CF0F230F5440D9EDB3CA4C7D4B4051A39064560D5440D9EDB3CA4C7D4B40
1029	Каргат	5	52	250	80.220965000000007	80.331180000000003	55.213962000000002	55.174373000000003	0103000020E61000000100000005000000E223624A240E54401827BEDA51964B40E223624A240E54401B4B581B639B4B40B745990D321554401B4B581B639B4B40B745990D321554401827BEDA51964B40E223624A240E54401827BEDA51964B40
2076	Карган	5	52	250	80.033845999999997	80.063283999999996	55.355234000000003	55.341372	0103000020E610000001000000050000006DC669882A02544093E2E313B2AB4B406DC669882A025440B136C64E78AD4B400B9755D80C045440B136C64E78AD4B400B9755D80C04544093E2E313B2AB4B406DC669882A02544093E2E313B2AB4B40
3668	Иванкино	5	52	250	79.900391999999997	79.930971	54.894741000000003	54.884979999999999	0103000020E610000001000000050000001F65C405A0F953409ACE4E0647714B401F65C405A0F95340F7B182DF86724B4090A1630795FB5340F7B182DF86724B4090A1630795FB53409ACE4E0647714B401F65C405A0F953409ACE4E0647714B40
2168	Груздевка	5	52	250	79.993458000000004	80.017542000000006	55.255487000000002	55.247878	0103000020E61000000100000005000000C6FCDCD094FF5340EEB25F77BA9F4B40C6FCDCD094FF5340CEC64ACCB3A04B409D137B681F015440CEC64ACCB3A04B409D137B681F015440EEB25F77BA9F4B40C6FCDCD094FF5340EEB25F77BA9F4B40
2949	Голубовский	5	52	250	80.397152000000006	80.411651000000006	54.996268000000001	54.985425999999997	0103000020E61000000100000005000000A0E238F06A19544065506D70227E4B40A0E238F06A1954409206B7B5857F4B4068976F7D581A54409206B7B5857F4B4068976F7D581A544065506D70227E4B40A0E238F06A19544065506D70227E4B40
41318	Гавриловка	5	52	250	80.134089000000003	80.158371000000002	55.166361999999999	55.156759999999998	0103000020E61000000100000005000000377007EA9408544015A930B610944B40377007EA9408544009A69A594B954B40A1681EC0220A544009A69A594B954B40A1681EC0220A544015A930B610944B40377007EA9408544015A930B610944B40
2307	Верхний Каргат	5	52	250	80.639831999999998	80.663483999999997	55.375878999999998	55.360084999999998	0103000020E61000000100000005000000CBBBEA01F3285440DC63E94317AE4B40CBBBEA01F3285440682096CD1CB04B40D55A9885762A5440682096CD1CB04B40D55A9885762A5440DC63E94317AE4B40CBBBEA01F3285440DC63E94317AE4B40
1477	Беркуты	5	52	250	79.980746999999994	80.006069999999994	55.185656000000002	55.180593000000002	0103000020E610000001000000050000009BA9108FC4FE53407A71E2AB1D974B409BA9108FC4FE534031276893C3974B4026DF6C736300544031276893C3974B4026DF6C73630054407A71E2AB1D974B409BA9108FC4FE53407A71E2AB1D974B40
1615	Безлюдный	5	52	250	80.053043000000002	80.076435000000004	55.231954999999999	55.225039000000002	0103000020E610000001000000050000000892770E650354408BA9F413CE9C4B400892770E65035440649291B3B09D4B404451A04FE4045440649291B3B09D4B404451A04FE40454408BA9F413CE9C4B400892770E650354408BA9F413CE9C4B40
3713	Аткуль	5	52	250	79.646870000000007	79.666139000000001	54.976157999999998	54.967599999999997	0103000020E61000000100000005000000DEB06D5166E9534007CE1951DA7B4B40DEB06D5166E9534048DDCEBEF27C4B40C5E57805A2EA534048DDCEBEF27C4B40C5E57805A2EA534007CE1951DA7B4B40DEB06D5166E9534007CE1951DA7B4B40
3349	Алабуга	5	52	250	80.457087000000001	80.476140999999998	54.676214000000002	54.662078000000001	0103000020E61000000100000005000000501BD5E9401D544057B3CEF8BE544B40501BD5E9401D5440768C2B2E8E564B4039D21918791E5440768C2B2E8E564B4039D21918791E544057B3CEF8BE544B40501BD5E9401D544057B3CEF8BE544B40
35542	Локти	5	52	3692	64.913421	64.926985999999999	55.998342999999998	55.986234000000003	0103000020E61000000100000005000000B29E5A7D753A5040051A6CEA3CFE4B40B29E5A7D753A5040639813B4C9FF4B40647616BD533B5040639813B4C9FF4B40647616BD533B5040051A6CEA3CFE4B40B29E5A7D753A5040051A6CEA3CFE4B40
41387	Ягодный	5	52	99	78.009196000000003	78.021979000000002	53.765504999999997	53.760209000000003	0103000020E6100000010000000500000042D0D1AA96805340FC8F4C874EE14A4042D0D1AA9680534055F65D11FCE14A40B98C9B1A6881534055F65D11FCE14A40B98C9B1A68815340FC8F4C874EE14A4042D0D1AA96805340FC8F4C874EE14A40
31339	Шилово-Курья	5	52	99	78.162700000000001	78.197348000000005	53.811278999999999	53.800857000000001	0103000020E61000000100000005000000CAC342AD698A5340E7E26F7B82E64A40CAC342AD698A53403E7782FDD7E74A40967B8159A18C53403E7782FDD7E74A40967B8159A18C5340E7E26F7B82E64A40CAC342AD698A5340E7E26F7B82E64A40
764	Чернокурья	5	52	99	78.359403999999998	78.386902000000006	53.855483999999997	53.841833000000001	0103000020E610000001000000050000004D83A27900975340C7D8092FC1EB4A404D83A279009753402920ED7F80ED4A4073309B00C39853402920ED7F80ED4A4073309B00C3985340C7D8092FC1EB4A404D83A27900975340C7D8092FC1EB4A40
31386	Чернозерка	5	52	99	77.930091000000004	77.941813999999994	53.833697999999998	53.825992999999997	0103000020E6100000010000000500000074D3669C867B5340CADC7C23BAE94A4074D3669C867B5340CC5EB69DB6EA4A408E3A3AAE467C5340CC5EB69DB6EA4A408E3A3AAE467C5340CADC7C23BAE94A4074D3669C867B5340CADC7C23BAE94A40
642	Хорошее	5	52	99	78.482815000000002	78.523606999999998	53.602173999999998	53.567284000000001	0103000020E610000001000000050000002BC1E270E69E5340A4C519C39CC84A402BC1E270E69E53403140A20914CD4A403A3DEFC682A153403140A20914CD4A403A3DEFC682A15340A4C519C39CC84A402BC1E270E69E5340A4C519C39CC84A40
41235	Троицкое	5	52	99	77.793492999999998	77.841678000000002	53.730395000000001	53.719681000000001	0103000020E61000000100000005000000B726DD96C8725340BB46CB811EDC4A40B726DD96C8725340BA1457957DDD4A40D0F0660DDE755340BA1457957DDD4A40D0F0660DDE755340BB46CB811EDC4A40B726DD96C8725340BB46CB811EDC4A40
735	Токаревка	5	52	99	78.340772999999999	78.350905999999995	53.599924000000001	53.588102999999997	0103000020E6100000010000000500000007978E39CF955340F9D687F546CB4A4007978E39CF955340F20A444FCACC4A40177E703E75965340F20A444FCACC4A40177E703E75965340F9D687F546CB4A4007978E39CF955340F9D687F546CB4A40
48892	Студеное	5	52	99	77.512957999999998	77.547363000000004	53.618045000000002	53.609946999999998	0103000020E610000001000000050000002E8ECA4DD46053408BA548BE12CE4A402E8ECA4DD4605340693A3B191CCF4A409702D2FE07635340693A3B191CCF4A409702D2FE076353408BA548BE12CE4A402E8ECA4DD46053408BA548BE12CE4A40
386	Сорочиха	5	52	99	77.941670000000002	77.954300000000003	53.735396000000001	53.726148999999999	0103000020E61000000100000005000000F5673F52447C5340F5824F73F2DC4A40F5673F52447C5340FBCDC47421DE4A40A9A44E40137D5340FBCDC47421DE4A40A9A44E40137D5340F5824F73F2DC4A40F5673F52447C5340F5824F73F2DC4A40
48718	Свободный Труд	5	52	99	78.562135999999995	78.574164999999994	53.664028000000002	53.65643	0103000020E61000000100000005000000DFF94509FAA35340800EF3E505D44A40DFF94509FAA353406CD097DEFED44A4080608E1EBFA453406CD097DEFED44A4080608E1EBFA45340800EF3E505D44A40DFF94509FAA35340800EF3E505D44A40
41356	Рождественский	5	52	99	78.565047000000007	78.585752999999997	54.114806000000002	54.093736999999997	0103000020E61000000100000005000000FD6CE4BA29A453406BB6F292FF0B4B40FD6CE4BA29A453403AB187F6B10E4B402BA226FA7CA553403AB187F6B10E4B402BA226FA7CA553406BB6F292FF0B4B40FD6CE4BA29A453406BB6F292FF0B4B40
41766	Рассказово	5	52	99	77.911963	77.928967999999998	53.672212000000002	53.656334000000001	0103000020E610000001000000050000005F0A0F9A5D7A53405EA0A4C002D44A405F0A0F9A5D7A534048FDF50A0BD64A40F4C13236747B534048FDF50A0BD64A40F4C13236747B53405EA0A4C002D44A405F0A0F9A5D7A53405EA0A4C002D44A40
49662	Поповка	5	52	99	77.636906999999994	77.657702999999998	53.744385999999999	53.725371000000003	0103000020E61000000100000005000000FBE59315C3685340C13BF9F4D8DC4A40FBE59315C3685340D5CC5A0A48DF4A40CADE52CE176A5340D5CC5A0A48DF4A40CADE52CE176A5340C13BF9F4D8DC4A40FBE59315C3685340C13BF9F4D8DC4A40
49666	Павловка	5	52	99	77.752583000000001	77.761638000000005	53.438253000000003	53.428269999999998	0103000020E61000000100000005000000A321E3512A705340D0ED258DD1B64A40A321E3512A705340DC2F9FAC18B84A4004594FADBE705340DC2F9FAC18B84A4004594FADBE705340D0ED258DD1B64A40A321E3512A705340D0ED258DD1B64A40
31484	Осолодино	5	52	99	77.952369000000004	77.959851999999998	53.780037999999998	53.777329999999999	0103000020E610000001000000050000005A2E1B9DF37C53408F19A88C7FE34A405A2E1B9DF37C534091D10149D8E34A40034015376E7D534091D10149D8E34A40034015376E7D53408F19A88C7FE34A405A2E1B9DF37C53408F19A88C7FE34A40
48804	Октябрьское	5	52	99	77.799520000000001	77.811539999999994	53.522768999999997	53.501778999999999	0103000020E61000000100000005000000DE1FEF552B735340E868554B3AC04A40DE1FEF552B7353406A2E3718EAC24A4055D97745F07353406A2E3718EAC24A4055D97745F0735340E868554B3AC04A40DE1FEF552B735340E868554B3AC04A40
505	Озерное-Титово	5	52	99	77.980198999999999	78.001084000000006	53.757398000000002	53.749124999999999	0103000020E610000001000000050000009A249694BB7E5340D9CEF753E3DF4A409A249694BB7E53402507EC6AF2E04A402123A0C2118053402507EC6AF2E04A402123A0C211805340D9CEF753E3DF4A409A249694BB7E5340D9CEF753E3DF4A40
41239	Новоивановка	5	52	99	77.894238999999999	77.900041999999999	53.465676000000002	53.453933999999997	0103000020E61000000100000005000000B2F336363B7953406F4562821ABA4A40B2F336363B7953401C446B459BBB4A40B1C1C2499A7953401C446B459BBB4A40B1C1C2499A7953406F4562821ABA4A40B2F336363B7953406F4562821ABA4A40
48688	Нестеровка	5	52	99	78.519375999999994	78.542068	53.784979999999997	53.773978	0103000020E61000000100000005000000F294D5743DA1534068E90AB611E34A40F294D5743DA15340CD0182397AE44A40520DFB3DB1A25340CD0182397AE44A40520DFB3DB1A2534068E90AB611E34A40F294D5743DA1534068E90AB611E34A40
49110	Морозовка	5	52	99	78.318055000000001	78.343873000000002	53.926971000000002	53.912913000000003	0103000020E6100000010000000500000013D55B035B945340F08B4B55DAF44A4013D55B035B94534093AB58FCA6F64A408E3EE6030296534093AB58FCA6F64A408E3EE60302965340F08B4B55DAF44A4013D55B035B945340F08B4B55DAF44A40
41275	Михайловка	5	52	99	78.038597999999993	78.063732999999999	53.649566999999998	53.637931000000002	0103000020E6100000010000000500000039ECBE6378825340630D17B9A7D14A4039ECBE6378825340C9C7EE0225D34A4043AB933314845340C9C7EE0225D34A4043AB933314845340630D17B9A7D14A4039ECBE6378825340630D17B9A7D14A40
131	Луганск	5	52	99	77.594838999999993	77.601702000000003	53.627246999999997	53.618231999999999	0103000020E61000000100000005000000A9D898D7116653409BABE63922CF4A40A9D898D711665340CEC133A149D04A4005FC1A4982665340CEC133A149D04A4005FC1A49826653409BABE63922CF4A40A9D898D7116653409BABE63922CF4A40
917	Кучугур	5	52	99	78.201498999999998	78.223849000000001	54.00403	53.992300999999998	0103000020E610000001000000050000004FCB0F5CE58C5340E0641BB803FF4A404FCB0F5CE58C5340F819170E84004B40828FC18A538E5340F819170E84004B40828FC18A538E5340E0641BB803FF4A404FCB0F5CE58C5340E0641BB803FF4A40
41310	Кукарка	5	52	99	78.385886999999997	78.410068999999993	54.220047000000001	54.196077000000002	0103000020E61000000100000005000000E63C635FB2985340B83F170D19194B40E63C635FB29853409D4A06802A1C4B409E060C923E9A53409D4A06802A1C4B409E060C923E9A5340B83F170D19194B40E63C635FB2985340B83F170D19194B40
29532	Карасук	5	52	99	77.996673999999999	78.087089000000006	53.754268000000003	53.715733	0103000020E6100000010000000500000081B1BE81C97F534080D591239DDB4A4081B1BE81C97F5340AD3594DA8BE04A40D9B5BDDD92855340AD3594DA8BE04A40D9B5BDDD9285534080D591239DDB4A4081B1BE81C97F534080D591239DDB4A40
49665	Карасарт	5	52	99	78.258227000000005	78.267398999999997	53.628084999999999	53.620410999999997	0103000020E610000001000000050000006EFC89CA86905340118AADA069CF4A406EFC89CA86905340D80DDB1665D04A40EBFEB1101D915340D80DDB1665D04A40EBFEB1101D915340118AADA069CF4A406EFC89CA86905340118AADA069CF4A40
49663	Калиновка	5	52	99	78.487611999999999	78.507591000000005	53.726084999999998	53.708016000000001	0103000020E61000000100000005000000C748F608359F5340BA85AE44A0DA4A40C748F608359F5340DE8E705AF0DC4A409D2FF65E7CA05340DE8E705AF0DC4A409D2FF65E7CA05340BA85AE44A0DA4A40C748F608359F5340BA85AE44A0DA4A40
32347	Калачи	5	52	99	77.866202000000001	77.888750000000002	53.595301999999997	53.585301999999999	0103000020E61000000100000005000000B56E83DA6F77534046240A2DEBCA4A40B56E83DA6F775340279F1EDB32CC4A407B14AE47E1785340279F1EDB32CC4A407B14AE47E178534046240A2DEBCA4A40B56E83DA6F77534046240A2DEBCA4A40
49347	Кавкуй	5	52	99	78.152351999999993	78.164201000000006	53.651792999999998	53.644513000000003	0103000020E61000000100000005000000BB5E9A22C0895340666CE8667FD24A40BB5E9A22C08953408061F9F36DD34A401D3EE944828A53408061F9F36DD34A401D3EE944828A5340666CE8667FD24A40BB5E9A22C0895340666CE8667FD24A40
31754	Ирбизино	5	52	99	78.463527999999997	78.486759000000006	54.048278000000003	54.024678999999999	0103000020E61000000100000005000000F0315871AA9D5340F1F274AE28034B40F0315871AA9D5340E38E37F92D064B402882380F279F5340E38E37F92D064B402882380F279F5340F1F274AE28034B40F0315871AA9D5340F1F274AE28034B40
32014	Грамотино	5	52	99	78.34469	78.356386000000001	53.750802	53.739789999999999	0103000020E610000001000000050000008750A5660F96534034F44F70B1DE4A408750A5660F965340BDE2A9471AE04A4025B03907CF965340BDE2A9471AE04A4025B03907CF96534034F44F70B1DE4A408750A5660F96534034F44F70B1DE4A40
41352	Благодатное	5	52	99	78.034420999999995	78.073667999999998	53.851649000000002	53.833018000000003	0103000020E61000000100000005000000EB5223F4338253405B7D7555A0EA4A40EB5223F433825340E7559DD502ED4A40C0B0FCF9B6845340E7559DD502ED4A40C0B0FCF9B68453405B7D7555A0EA4A40EB5223F4338253405B7D7555A0EA4A40
48543	Белое	5	52	99	78.443010999999998	78.481566000000001	53.955066000000002	53.927585999999998	0103000020E610000001000000050000002B31CF4A5A9C53401D1D5723BBF64A402B31CF4A5A9C5340C2C2499A3FFA4A40653733FAD19E5340C2C2499A3FFA4A40653733FAD19E53401D1D5723BBF64A402B31CF4A5A9C53401D1D5723BBF64A40
627	Астродым	5	52	99	77.757272999999998	77.776523999999995	53.647347000000003	53.630209999999998	0103000020E6100000010000000500000034492C29777053405BCEA5B8AAD04A4034492C2977705340F5143944DCD24A40C823B891B2715340F5143944DCD24A40C823B891B27153405BCEA5B8AAD04A4034492C29777053405BCEA5B8AAD04A40
48874	Анисимовка	5	52	99	77.848046999999994	77.872185000000002	53.415418000000003	53.413243999999999	0103000020E61000000100000005000000239EEC664676534055A2EC2DE5B44A40239EEC6646765340BA15C26A2CB54A40F4C308E1D1775340BA15C26A2CB54A40F4C308E1D177534055A2EC2DE5B44A40239EEC664676534055A2EC2DE5B44A40
49664	Александровский	5	52	99	78.207293000000007	78.228475000000003	53.708384000000002	53.693708999999998	0103000020E6100000010000000500000025ECDB49448D53406EF8DD74CBD84A4025ECDB49448D53403D81B053ACDA4A40083D9B559F8E53403D81B053ACDA4A40083D9B559F8E53406EF8DD74CBD84A4025ECDB49448D53406EF8DD74CBD84A40
59108	Новосибирск	5	52	7467	82.918238000000002	83.005742999999995	55.133915000000002	55.053283999999998	0103000020E6100000010000000500000072FC5069C4BA544035B39602D2864B4072FC5069C4BA5440D0B8702024914B40944BE3175EC05440D0B8702024914B40944BE3175EC0544035B39602D2864B4072FC5069C4BA544035B39602D2864B40
26865	Шибково	5	52	1791	83.272129000000007	83.308645999999996	54.499611000000002	54.485173000000003	0103000020E61000000100000005000000C4D2C08F6AD154407CF31B261A3E4B40C4D2C08F6AD1544066DCD440F33F4B40A30227DBC0D3544066DCD440F33F4B40A30227DBC0D354407CF31B261A3E4B40C4D2C08F6AD154407CF31B261A3E4B40
27300	Шадрино	5	52	1791	83.402159999999995	83.421986000000004	54.465361000000001	54.452883999999997	0103000020E6100000010000000500000099F04BFDBCD95440DA70581AF8394B4099F04BFDBCD95440BCEA01F3903B4B40AC5791D101DB5440BCEA01F3903B4B40AC5791D101DB5440DA70581AF8394B4099F04BFDBCD95440DA70581AF8394B40
29589	Чупино	5	52	1791	82.941350999999997	82.965417000000002	54.532772000000001	54.515768999999999	0103000020E61000000100000005000000A4C343183FBC544033A5F5B704424B40A4C343183FBC5440BD1C76DF31444B4028806264C9BD5440BD1C76DF31444B4028806264C9BD544033A5F5B704424B40A4C343183FBC544033A5F5B704424B40
26482	Чернореченский	5	52	1791	83.267368000000005	83.288829000000007	54.656480000000002	54.647587999999999	0103000020E61000000100000005000000CEFFAB8E1CD154401AA4E029E4524B40CEFFAB8E1CD15440323D618907544B40BB48A12C7CD25440323D618907544B40BB48A12C7CD254401AA4E029E4524B40CEFFAB8E1CD154401AA4E029E4524B40
30464	Целинный	5	52	1791	82.849210999999997	82.863072000000003	54.373274000000002	54.365609999999997	0103000020E61000000100000005000000D219187959B65440978BF84ECC2E4B40D219187959B654403B394371C72F4B40F98557923CB754403B394371C72F4B40F98557923CB75440978BF84ECC2E4B40D219187959B65440978BF84ECC2E4B40
28071	Харино	5	52	1791	83.587194999999994	83.617181000000002	54.622439999999997	54.611798999999998	0103000020E61000000100000005000000FB57569A94E55440DD5CFC6D4F4E4B40FB57569A94E5544072DC291DAC4F4B409BADBCE47FE7544072DC291DAC4F4B409BADBCE47FE75440DD5CFC6D4F4E4B40FB57569A94E55440DD5CFC6D4F4E4B40
30755	Факел Революции	5	52	1791	82.432419999999993	82.449253999999996	54.483080000000001	54.471131999999997	0103000020E61000000100000005000000B988EFC4AC9B5440AE0CAA0D4E3C4B40B988EFC4AC9B544004ADC090D53D4B403866D993C09C544004ADC090D53D4B403866D993C09C5440AE0CAA0D4E3C4B40B988EFC4AC9B5440AE0CAA0D4E3C4B40
27994	Усть-Чем	5	52	1791	83.711305999999993	83.747040999999996	54.672763000000003	54.654995	0103000020E61000000100000005000000B5DC990986ED544092054CE0D6534B40B5DC990986ED5440BC7A15191D564B405AF10D85CFEF5440BC7A15191D564B405AF10D85CFEF544092054CE0D6534B40B5DC990986ED544092054CE0D6534B40
27502	Ургун	5	52	1791	83.415563000000006	83.446680999999998	54.514080999999997	54.487572999999998	0103000020E610000001000000050000005F9B8D9598DA5440D0B4C4CA683E4B405F9B8D9598DA54405B3FFD67CD414B40A7AFE76B96DC54405B3FFD67CD414B40A7AFE76B96DC5440D0B4C4CA683E4B405F9B8D9598DA5440D0B4C4CA683E4B40
29428	Улыбино	5	52	1791	82.912165000000002	82.940084999999996	54.594698999999999	54.568724000000003	0103000020E6100000010000000500000093E34EE960BA5440A439B2F2CB484B4093E34EE960BA544061FBC9181F4C4B40739D465A2ABC544061FBC9181F4C4B40739D465A2ABC5440A439B2F2CB484B4093E34EE960BA5440A439B2F2CB484B40
29367	Тула	5	52	1791	82.695599000000001	82.705436000000006	54.597087999999999	54.586717	0103000020E610000001000000050000005708ABB184AC5440ED80EB8A194B4B405708ABB184AC5440C26A2C616D4C4B40F35A09DD25AD5440C26A2C616D4C4B40F35A09DD25AD5440ED80EB8A194B4B405708ABB184AC5440ED80EB8A194B4B40
26915	Таскаево	5	52	1791	83.225812000000005	83.241540999999998	54.513913000000002	54.497959000000002	0103000020E61000000100000005000000D7C22CB473CE5440DBDFD91EBD3F4B40D7C22CB473CE5440A0FEB3E6C7414B4029E9616875CF5440A0FEB3E6C7414B4029E9616875CF5440DBDFD91EBD3F4B40D7C22CB473CE5440DBDFD91EBD3F4B40
28187	Тальменка	5	52	1791	83.259499000000005	83.295062999999999	54.716574999999999	54.700257999999998	0103000020E610000001000000050000001096B1A19BD054409561DC0DA2594B401096B1A19BD05440CB10C7BAB85B4B409ED0EB4FE2D25440CB10C7BAB85B4B409ED0EB4FE2D254409561DC0DA2594B401096B1A19BD054409561DC0DA2594B40
29685	Степной	5	52	1791	82.927975000000004	82.955572000000004	54.510196999999998	54.498319000000002	0103000020E610000001000000050000005C2041F163BB5440DBFCBFEAC83F4B405C2041F163BB544037C2A2224E414B404B3E761728BD544037C2A2224E414B404B3E761728BD5440DBFCBFEAC83F4B405C2041F163BB5440DBFCBFEAC83F4B40
26825	Старый Искитим	5	52	1791	83.382289	83.418096000000006	54.618186000000001	54.607008	0103000020E61000000100000005000000B727486C77D8544087342A70B24D4B40B727486C77D854402B6C06B8204F4B40A9A5B915C2DA54402B6C06B8204F4B40A9A5B915C2DA544087342A70B24D4B40B727486C77D8544087342A70B24D4B40
27887	Старососедово	5	52	1791	83.914433000000002	83.939245	54.603154000000004	54.591261000000003	0103000020E610000001000000050000008658FD1186FA54403C33C170AE4B4B408658FD1186FA5440CE397826344D4B409E7B0F971CFC5440CE397826344D4B409E7B0F971CFC54403C33C170AE4B4B408658FD1186FA54403C33C170AE4B4B40
59133	Станция Евсино	5	52	1791	82.374792999999997	84.084395000000001	54.989099000000003	54.252999000000003	0103000020E610000001000000050000004371C79BFC975440DA756F4562204B404371C79BFC975440CFC0C8CB9A7E4B408A3C49BA66055540CFC0C8CB9A7E4B408A3C49BA66055540DA756F4562204B404371C79BFC975440DA756F4562204B40
29393	Советский	5	52	1791	82.669162	82.686131000000003	54.457427000000003	54.446114999999999	0103000020E61000000100000005000000766EDA8CD3AA5440A5A0DB4B1A394B40766EDA8CD3AA544059A7CAF78C3A4B406571FF91E9AB544059A7CAF78C3A4B406571FF91E9AB5440A5A0DB4B1A394B40766EDA8CD3AA5440A5A0DB4B1A394B40
41314	Село Новошилово	5	52	1791	82.374792999999997	84.084395000000001	54.989099000000003	54.252999000000003	0103000020E610000001000000050000004371C79BFC975440DA756F4562204B404371C79BFC975440CFC0C8CB9A7E4B408A3C49BA66055540CFC0C8CB9A7E4B408A3C49BA66055540DA756F4562204B404371C79BFC975440DA756F4562204B40
26594	Рябчинка	5	52	1791	83.100442999999999	83.118463000000006	54.617879000000002	54.611935000000003	0103000020E610000001000000050000002D077AA86DC654408E23D6E2534E4B402D077AA86DC654404EF1B8A8164F4B404FB2D5E594C754404EF1B8A8164F4B404FB2D5E594C754408E23D6E2534E4B402D077AA86DC654408E23D6E2534E4B40
26530	Рощинский	5	52	1791	83.210496000000006	83.226207000000002	54.63758	54.632331999999998	0103000020E6100000010000000500000016FC36C478CD54406D1B4641F0504B4016FC36C478CD5440B64AB0389C514B4015C8EC2C7ACE5440B64AB0389C514B4015C8EC2C7ACE54406D1B4641F0504B4016FC36C478CD54406D1B4641F0504B40
29797	Раздольный	5	52	1791	83.079026999999996	83.092348999999999	54.489116000000003	54.480443999999999	0103000020E61000000100000005000000102043C70EC554409BC761307F3D4B40102043C70EC55440A5F9635A9B3E4B405FB4C70BE9C55440A5F9635A9B3E4B405FB4C70BE9C554409BC761307F3D4B40102043C70EC554409BC761307F3D4B40
29489	Первомайский	5	52	1791	83.002868000000007	83.016216999999997	54.583252999999999	54.571423000000003	0103000020E610000001000000050000001E8D43FD2EC0544053978C6324494B401E8D43FD2EC054409E25C808A84A4B40E92807B309C154409E25C808A84A4B40E92807B309C1544053978C6324494B401E8D43FD2EC0544053978C6324494B40
29892	Октябрьский	5	52	1791	82.905490999999998	82.916531000000006	54.447591000000003	54.440350000000002	0103000020E61000000100000005000000A1F48590F3B95440956588635D384B40A1F48590F3B95440F27D71A94A394B404BB1A371A8BA5440F27D71A94A394B404BB1A371A8BA5440956588635D384B40A1F48590F3B95440956588635D384B40
29242	Озерки	5	52	1791	82.629069999999999	82.638510999999994	54.511581999999997	54.502088999999998	0103000020E610000001000000050000004339D1AE42A854403657CD7344404B404339D1AE42A85440739CDB847B414B40B8C83D5DDDA85440739CDB847B414B40B8C83D5DDDA854403657CD7344404B404339D1AE42A854403657CD7344404B40
27985	Новососедово	5	52	1791	83.972185999999994	83.991490999999996	54.65287	54.636099999999999	0103000020E6100000010000000500000042E8A04B38FE5440287E8CB96B514B4042E8A04B38FE54400F45813E91534B40D0D1AA9674FF54400F45813E91534B40D0D1AA9674FF5440287E8CB96B514B4042E8A04B38FE5440287E8CB96B514B40
30271	Новолокти	5	52	1791	82.898016999999996	82.919549000000004	54.399498999999999	54.386436000000003	0103000020E6100000010000000500000021904B1C79B95440A0FF1EBC76314B4021904B1C79B9544071E481C822334B4073840CE4D9BA544071E481C822334B4073840CE4D9BA5440A0FF1EBC76314B4021904B1C79B95440A0FF1EBC76314B40
27008	Новолебедевка	5	52	1791	83.133275999999995	83.169110000000003	54.465685000000001	54.458106999999998	0103000020E61000000100000005000000DE550F9887C85440CA880B40A33A4B40DE550F9887C854406F9EEA909B3B4B404DDBBFB2D2CA54406F9EEA909B3B4B404DDBBFB2D2CA5440CA880B40A33A4B40DE550F9887C85440CA880B40A33A4B40
28604	Нижний Коен	5	52	1791	83.385451000000003	83.402959999999993	54.825960000000002	54.808878	0103000020E6100000010000000500000079CDAB3AABD85440193A765089674B4079CDAB3AABD85440EFE6A90EB9694B402766BD18CAD95440EFE6A90EB9694B402766BD18CAD95440193A765089674B4079CDAB3AABD85440193A765089674B40
28059	Мосты	5	52	1791	83.841363999999999	83.875733999999994	54.781410000000001	54.762709000000001	0103000020E61000000100000005000000080264E8D8F55440B4AED172A0614B40080264E8D8F5544039622D3E05644B40B27F9E060CF8544039622D3E05644B40B27F9E060CF85440B4AED172A0614B40080264E8D8F55440B4AED172A0614B40
27272	Морозово	5	52	1791	83.205528000000001	83.230609000000001	54.777033000000003	54.762740000000001	0103000020E61000000100000005000000639AE95E27CD5440EFACDD76A1614B40639AE95E27CD5440D6743DD175634B40734A404CC2CE5440D6743DD175634B40734A404CC2CE5440EFACDD76A1614B40639AE95E27CD5440EFACDD76A1614B40
28413	Михайловка	5	52	1791	83.079755000000006	83.100667999999999	54.435020000000002	54.423805999999999	0103000020E61000000100000005000000522CB7B41AC554409EEC66463F364B40522CB7B41AC554408F8D40BCAE374B403DF0315871C654408F8D40BCAE374B403DF0315871C654409EEC66463F364B40522CB7B41AC554409EEC66463F364B40
28973	Маяк	5	52	1791	83.128668000000005	83.142546999999993	54.701912	54.688966000000001	0103000020E61000000100000005000000AC02B5183CC854402907B30930584B40AC02B5183CC85440C1559E40D8594B4025C9737D1FC95440C1559E40D8594B4025C9737D1FC954402907B30930584B40AC02B5183CC854402907B30930584B40
27803	Малиновка	5	52	1791	83.849907000000002	83.864926999999994	54.669195999999999	54.654417000000002	0103000020E610000001000000050000000E6954E064F654402579AEEFC3534B400E6954E064F65440984EEB36A8554B405A9BC6F65AF75440984EEB36A8554B405A9BC6F65AF754402579AEEFC3534B400E6954E064F654402579AEEFC3534B40
27224	Листвянский	5	52	1791	83.461054000000004	83.514467999999994	54.449685000000002	54.431637000000002	0103000020E6100000010000000500000029ECA2E881DD54402D5F97E13F374B4029ECA2E881DD54403A4030478F394B40AAB5300BEDE054403A4030478F394B40AAB5300BEDE054402D5F97E13F374B4029ECA2E881DD54402D5F97E13F374B40
26100	Линево	5	52	1791	83.353821999999994	83.398396000000005	54.465831000000001	54.437716000000002	0103000020E61000000100000005000000BDA60705A5D65440CD77F01307384B40BDA60705A5D65440433BA759A03B4B40DDB6EF517FD95440433BA759A03B4B40DDB6EF517FD95440CD77F01307384B40BDA60705A5D65440CD77F01307384B40
27793	Легостаево	5	52	1791	83.775689	83.842155000000005	54.662562999999999	54.631180999999998	0103000020E610000001000000050000007CB779E3A4F15440A46DFC89CA504B407CB779E3A4F15440134548DDCE544B406DCA15DEE5F55440134548DDCE544B406DCA15DEE5F55440A46DFC89CA504B407CB779E3A4F15440A46DFC89CA504B40
28893	Лебедевка	5	52	1791	83.218705999999997	83.247443000000004	54.679057	54.665661	0103000020E61000000100000005000000185C7347FFCD5440809C306134554B40185C7347FFCD5440588FFB56EB564B40F2272A1BD6CF5440588FFB56EB564B40F2272A1BD6CF5440809C306134554B40185C7347FFCD5440809C306134554B40
26745	Койниха	5	52	1791	83.248090000000005	83.260828000000004	54.571244999999998	54.564684	0103000020E61000000100000005000000BD1DE1B4E0CF54408849B89047484B40BD1DE1B4E0CF54407380608E1E494B406478EC67B1D054407380608E1E494B406478EC67B1D054408849B89047484B40BD1DE1B4E0CF54408849B89047484B40
28492	Китерня	5	52	1791	83.683755000000005	83.702539000000002	54.850422000000002	54.839795000000002	0103000020E610000001000000050000007FDE54A4C2EB5440132C0E677E6B4B407FDE54A4C2EB544043E6CAA0DA6C4B40884A2366F6EC544043E6CAA0DA6C4B40884A2366F6EC5440132C0E677E6B4B407FDE54A4C2EB5440132C0E677E6B4B40
27170	Керамкомбинат	5	52	1791	83.337967000000006	83.352626999999998	54.443282000000004	54.427802999999997	0103000020E6100000010000000500000025085740A1D55440BA10AB3FC2364B4025085740A1D55440E773EE76BD384B40F12BD67091D65440E773EE76BD384B40F12BD67091D65440BA10AB3FC2364B4025085740A1D55440BA10AB3FC2364B40
30071	Каменка	5	52	1791	82.607996	82.618235999999996	54.393129999999999	54.381658999999999	0103000020E6100000010000000500000053060E68E9A65440AE9CBD33DA304B4053060E68E9A65440CA89761552324B406E4DBA2D91A75440CA89761552324B406E4DBA2D91A75440AE9CBD33DA304B4053060E68E9A65440AE9CBD33DA304B40
28318	Калиновка	5	52	1791	83.452690000000004	83.474079000000003	54.718198000000001	54.700232	0103000020E610000001000000050000007B4E7ADFF8DC54406CCEC133A1594B407B4E7ADFF8DC5440BC067DE9ED5B4B401B2E724F57DE5440BC067DE9ED5B4B401B2E724F57DE54406CCEC133A1594B407B4E7ADFF8DC54406CCEC133A1594B40
29330	Завьялово	5	52	1791	82.428466999999998	82.462522000000007	54.511420000000001	54.484063999999996	0103000020E61000000100000005000000931ADA006C9B5440E19524CFF53D4B40931ADA006C9B54409A42E73576414B408EEBDFF5999D54409A42E73576414B408EEBDFF5999D5440E19524CFF53D4B40931ADA006C9B5440E19524CFF53D4B40
28214	Елбаши	5	52	1791	83.576317000000003	83.608143999999996	54.744045	54.725904	0103000020E610000001000000050000003FC8B260E2E454408E041A6CEA5C4B403FC8B260E2E454404CE0D6DD3C5F4B408DD0CFD4EBE654404CE0D6DD3C5F4B408DD0CFD4EBE654408E041A6CEA5C4B403FC8B260E2E454408E041A6CEA5C4B40
27142	Евсино	5	52	1791	83.312597999999994	83.328767999999997	54.424435000000003	54.409754999999997	0103000020E61000000100000005000000E1B20A9B01D45440AD2F12DA72344B40E1B20A9B01D454408E23D6E253364B402AFEEF880AD554408E23D6E253364B402AFEEF880AD55440AD2F12DA72344B40E1B20A9B01D45440AD2F12DA72344B40
28447	Дзержинский	5	52	1791	83.474439000000004	83.485308000000003	54.915647	54.911315999999999	0103000020E610000001000000050000009B3C65355DDE54402829B000A6744B409B3C65355DDE54401BD7BFEB33754B402E1F49490FDF54401BD7BFEB33754B402E1F49490FDF54402829B000A6744B409B3C65355DDE54402829B000A6744B40
27704	Девкино	5	52	1791	83.687465000000003	83.704308999999995	54.624243	54.610491000000003	0103000020E610000001000000050000004209336DFFEB54404DC0AF91244E4B404209336DFFEB5440E3E0D231E74F4B40D2510E6613ED5440E3E0D231E74F4B40D2510E6613ED54404DC0AF91244E4B404209336DFFEB54404DC0AF91244E4B40
27610	Гусельниково	5	52	1791	83.679353000000006	83.703823	54.525719000000002	54.505853000000002	0103000020E61000000100000005000000215C01857AEB5440B0CA85CABF404B40215C01857AEB544063F19BC24A434B400CCB9F6F0BED544063F19BC24A434B400CCB9F6F0BED5440B0CA85CABF404B40215C01857AEB5440B0CA85CABF404B40
30169	Горевка	5	52	1791	82.699139000000002	82.822800999999998	54.431925	54.357222	0103000020E61000000100000005000000EC1681B1BEAC5440B3B45373B92D4B40EC1681B1BEAC544093A9825149374B406E8786C5A8B4544093A9825149374B406E8786C5A8B45440B3B45373B92D4B40EC1681B1BEAC5440B3B45373B92D4B40
30389	Гилево	5	52	1791	82.928433999999996	82.945312999999999	54.351711999999999	54.346122999999999	0103000020E61000000100000005000000A59F70766BBB54405BB22AC24D2C4B40A59F70766BBB54402DCE18E6042D4B40F4DE180280BC54402DCE18E6042D4B40F4DE180280BC54405BB22AC24D2C4B40A59F70766BBB54405BB22AC24D2C4B40
28332	Верх-Коен	5	52	1791	83.483979000000005	83.514619999999994	54.880464000000003	54.860860000000002	0103000020E61000000100000005000000DA3C0E83F9DE5440A03715A9306E4B40DA3C0E83F9DE544016A75A0BB3704B408577B988EFE0544016A75A0BB3704B408577B988EFE05440A03715A9306E4B40DA3C0E83F9DE5440A03715A9306E4B40
29181	Быстровка	5	52	1791	82.562999000000005	82.601132000000007	54.543756999999999	54.526083999999997	0103000020E61000000100000005000000912BF52C08A45440747973B856434B40912BF52C08A454404CFC51D499454B4010255AF278A654404CFC51D499454B4010255AF278A65440747973B856434B40912BF52C08A45440747973B856434B40
28804	Бурмистрово	5	52	1791	82.820150999999996	82.850406000000007	54.645316999999999	54.626584000000001	0103000020E6100000010000000500000007B29E5A7DB4544033198EE733504B4007B29E5A7DB45440C34659BF99524B409F94490D6DB65440C34659BF99524B409F94490D6DB6544033198EE733504B4007B29E5A7DB4544033198EE733504B40
29691	Бородавкино	5	52	1791	82.897514000000001	82.915525000000002	54.492885999999999	54.481735999999998	0103000020E61000000100000005000000F06C8FDE70B9544026A77686A93D4B40F06C8FDE70B95440005471E3163F4B40E86A2BF697BA5440005471E3163F4B40E86A2BF697BA544026A77686A93D4B40F06C8FDE70B9544026A77686A93D4B40
29874	Березовка	5	52	1791	82.986931999999996	82.999059000000003	54.486172000000003	54.477953999999997	0103000020E610000001000000050000000ED8D5E429BF5440067FBF982D3D4B400ED8D5E429BF54408F1D54E23A3E4B4091F12895F0BF54408F1D54E23A3E4B4091F12895F0BF5440067FBF982D3D4B400ED8D5E429BF5440067FBF982D3D4B40
28726	Бердь	5	52	1791	83.161069999999995	83.195286999999993	54.745345	54.732345000000002	0103000020E6100000010000000500000078978BF84ECA5440CF31207BBD5D4B4078978BF84ECA54405A9E0777675F4B405F950B957FCC54405A9E0777675F4B405F950B957FCC5440CF31207BBD5D4B4078978BF84ECA5440CF31207BBD5D4B40
27634	Белово	5	52	1791	83.620549999999994	83.646448000000007	54.546567000000003	54.52854	0103000020E6100000010000000500000019E25817B7E754405D50DF32A7434B4019E25817B7E7544053094FE8F5454B4023A46E675FE9544053094FE8F5454B4023A46E675FE954405D50DF32A7434B4019E25817B7E754405D50DF32A7434B40
28271	Барабка	5	52	1791	83.423378	83.441479000000001	54.665286000000002	54.654245000000003	0103000020E6100000010000000500000023F609A018DB54402849D74CBE534B4023F609A018DB54404B3E761728554B40BBB7223141DC54404B3E761728554B40BBB7223141DC54402849D74CBE534B4023F609A018DB54402849D74CBE534B40
30242	Алексеевский	5	52	1791	82.726465000000005	82.748195999999993	54.310478000000003	54.300386000000003	0103000020E61000000100000005000000132C0E677EAE54409016670C73264B40132C0E677EAE544052103CBEBD274B40DFBF7971E2AF544052103CBEBD274B40DFBF7971E2AF54409016670C73264B40132C0E677EAE54409016670C73264B40
26700	Александровский	5	52	1791	83.154171000000005	83.172128999999998	54.588726000000001	54.578645999999999	0103000020E6100000010000000500000077BF0AF0DDC9544009FB7612114A4B4077BF0AF0DDC954400727A25F5B4B4B405D6C5A2904CB54400727A25F5B4B4B405D6C5A2904CB544009FB7612114A4B4077BF0AF0DDC9544009FB7612114A4B40
23208	Щелчиха	5	52	1399	78.379823000000002	78.399685000000005	54.668545999999999	54.661948000000002	0103000020E6100000010000000500000031D120054F98534089D349B6BA544B4031D120054F98534091EF52EA92554B40EAEC64709499534091EF52EA92554B40EAEC64709499534089D349B6BA544B4031D120054F98534089D349B6BA544B40
25892	Широкая Курья	5	52	1399	78.137134000000003	78.152540000000002	54.574131999999999	54.565921000000003	0103000020E61000000100000005000000DC4AAFCDC6885340508F6D1970484B40DC4AAFCDC688534025CB49287D494B403DD52137C389534025CB49287D494B403DD52137C3895340508F6D1970484B40DC4AAFCDC6885340508F6D1970484B40
25767	Чича	5	52	1399	78.572018	78.590576999999996	54.748747999999999	54.741622999999997	0103000020E610000001000000050000004BAE62F19BA453400F7BA180ED5E4B404BAE62F19BA45340037976F9D65F4B4044317903CCA55340037976F9D65F4B4044317903CCA553400F7BA180ED5E4B404BAE62F19BA453400F7BA180ED5E4B40
44373	Цветники	5	52	1399	78.744754999999998	78.760475	54.709226000000001	54.697412	0103000020E610000001000000050000001422E010AAAF534042EBE1CB44594B401422E010AAAF534088BCE5EAC75A4B403D9B559FABB0534088BCE5EAC75A4B403D9B559FABB0534042EBE1CB44594B401422E010AAAF534042EBE1CB44594B40
24965	Хапово	5	52	1399	78.838853	78.865128999999996	54.716850999999998	54.707259999999998	0103000020E61000000100000005000000B2497EC4AFB553406DE2E47E875A4B40B2497EC4AFB553406D8D08C6C15B4B408E7406465EB753406D8D08C6C15B4B408E7406465EB753406DE2E47E875A4B40B2497EC4AFB553406DE2E47E875A4B40
24707	Старогорносталево	5	52	1399	79.218733	79.249644000000004	54.683365999999999	54.655261000000003	0103000020E610000001000000050000009563B2B8FFCD534011ACAA97DF534B409563B2B8FFCD534063997E8978574B4021E9D32AFACF534063997E8978574B4021E9D32AFACF534011ACAA97DF534B409563B2B8FFCD534011ACAA97DF534B40
15374	Сарыбалык	5	52	1399	78.734164000000007	78.776815999999997	54.834505999999998	54.820295999999999	0103000020E61000000100000005000000A379008BFCAE534012859675FF684B40A379008BFCAE53406B28B517D16A4B409CC0745AB7B153406B28B517D16A4B409CC0745AB7B1534012859675FF684B40A379008BFCAE534012859675FF684B40
41242	Петропавловский	5	52	1399	78.637693999999996	78.648374000000004	54.921008	54.916372000000003	0103000020E61000000100000005000000BFB67EFACFA853402D7C7DAD4B754B40BFB67EFACFA853405CAD1397E3754B40E964A9F57EA953405CAD1397E3754B40E964A9F57EA953402D7C7DAD4B754B40BFB67EFACFA853402D7C7DAD4B754B40
45793	Петраки	5	52	1399	78.360078000000001	78.395156999999998	54.765093	54.754277000000002	0103000020E61000000100000005000000958098840B975340009013268C604B40958098840B97534003B34291EE614B4045F295404A99534003B34291EE614B4045F295404A995340009013268C604B40958098840B975340009013268C604B40
25418	Новощербаки	5	52	1399	78.885727000000003	78.898852000000005	54.945422999999998	54.936677000000003	0103000020E61000000100000005000000CA8B4CC0AFB853402CF52C08E5774B40CA8B4CC0AFB853406FF1F09E03794B406EFC89CA86B953406FF1F09E03794B406EFC89CA86B953402CF52C08E5774B40CA8B4CC0AFB853402CF52C08E5774B40
41286	Новороссийское	5	52	1399	78.264300000000006	78.299711000000002	54.350138000000001	54.339084999999997	0103000020E610000001000000050000004D158C4AEA90534036C82423672B4B404D158C4AEA9053401E8B6D52D12C4B4018D00B772E9353401E8B6D52D12C4B4018D00B772E93534036C82423672B4B404D158C4AEA90534036C82423672B4B40
49661	Новогребенщиково	5	52	1399	78.507904999999994	78.532158999999993	54.906025999999997	54.896360999999999	0103000020E61000000100000005000000641EF98381A0534076340EF5BB724B40641EF98381A05340B0A9F3A8F8734B4069519FE40EA25340B0A9F3A8F8734B4069519FE40EA2534076340EF5BB724B40641EF98381A0534076340EF5BB724B40
24937	Нижний Чулым (Сарапулово)	5	52	1399	78.912749000000005	78.958455000000001	54.625343000000001	54.605386000000003	0103000020E610000001000000050000003B1DC87A6ABA534067BAD7497D4D4B403B1DC87A6ABA53402AE44A3D0B504B4003ECA35357BD53402AE44A3D0B504B4003ECA35357BD534067BAD7497D4D4B403B1DC87A6ABA534067BAD7497D4D4B40
24854	Нижний Урюм (Лохмоткино)	5	52	1399	78.446073999999996	78.486947000000001	54.5304	54.521532999999998	0103000020E610000001000000050000002366F6798C9C53407364E597C1424B402366F6798C9C534032E6AE25E4434B40A9F8BF232A9F534032E6AE25E4434B40A9F8BF232A9F53407364E597C1424B402366F6798C9C53407364E597C1424B40
46272	Михайловка (Кокуй)	5	52	1399	78.543721000000005	78.581288000000001	54.570807000000002	54.561542000000003	0103000020E6100000010000000500000080492A53CCA253404CAAB69BE0474B4080492A53CCA25340F8A92A3410494B40AA6395D233A55340F8A92A3410494B40AA6395D233A553404CAAB69BE0474B4080492A53CCA253404CAAB69BE0474B40
25081	Мамон	5	52	1399	78.259169999999997	78.274540999999999	54.449387000000002	54.440072999999998	0103000020E61000000100000005000000AD86C43D96905340226DE34F54384B40AD86C43D96905340B01F628385394B40501A6A1492915340B01F628385394B40501A6A1492915340226DE34F54384B40AD86C43D96905340226DE34F54384B40
25204	Маландино	5	52	1399	78.534064000000001	78.560061000000005	54.81335	54.804009999999998	0103000020E61000000100000005000000247EC51A2EA2534017D4B7CCE9664B40247EC51A2EA25340CE1951DA1B684B40F7B0170AD8A35340CE1951DA1B684B40F7B0170AD8A3534017D4B7CCE9664B40247EC51A2EA2534017D4B7CCE9664B40
41319	Лянино	5	52	1399	78.479095999999998	78.535428999999993	54.376268000000003	54.359845	0103000020E610000001000000050000003EE94482A99E53408750A5660F2E4B403EE94482A99E53400344C18C29304B401E15FF7744A253400344C18C29304B401E15FF7744A253408750A5660F2E4B403EE94482A99E53408750A5660F2E4B40
26020	Здвинск	5	52	1399	78.64161	78.685492999999994	54.713793000000003	54.690741000000003	0103000020E6100000010000000500000057B2632310A95340D0807A336A584B4057B2632310A953408F8EAB915D5B4B40C328081EDFAB53408F8EAB915D5B4B40C328081EDFAB5340D0807A336A584B4057B2632310A95340D0807A336A584B40
25594	Горькое Озеро	5	52	1399	78.808293000000006	78.828208000000004	54.884773000000003	54.875754999999998	0103000020E610000001000000050000007D259012BBB353407C2766BD18704B407D259012BBB3534021B1DD3D40714B404792205C01B5534021B1DD3D40714B404792205C01B553407C2766BD18704B407D259012BBB353407C2766BD18704B40
45848	Городище (Заворино)	5	52	1399	78.040645999999995	78.064344000000006	54.643633999999999	54.634849000000003	0103000020E61000000100000005000000A52DAEF199825340FC7266BB42514B40A52DAEF199825340FD4B529962524B4068EC4B361E845340FD4B529962524B4068EC4B361E845340FC7266BB42514B40A52DAEF199825340FC7266BB42514B40
24570	Верх-Урюм	5	52	1399	78.560222999999993	78.612244000000004	54.500765999999999	54.481923999999999	0103000020E61000000100000005000000E3DD91B1DAA35340299485AFAF3D4B40E3DD91B1DAA353407079AC1919404B40064B75012FA753407079AC1919404B40064B75012FA75340299485AFAF3D4B40E3DD91B1DAA35340299485AFAF3D4B40
24384	Верх-Каргат	5	52	1399	79.068984	79.115516	54.806527000000003	54.785387	0103000020E61000000100000005000000A0FCDD3B6AC453400EDAAB8F87644B40A0FCDD3B6AC45340A62BD8463C674B408B8A389D64C75340A62BD8463C674B408B8A389D64C753400EDAAB8F87644B40A0FCDD3B6AC453400EDAAB8F87644B40
42961	Бережки	5	52	1399	78.972054999999997	78.984829000000005	54.760724000000003	54.753943999999997	0103000020E6100000010000000500000073BA2C2636BE5340F981AB3C81604B4073BA2C2636BE534023A46E675F614B40C1C9367007BF534023A46E675F614B40C1C9367007BF5340F981AB3C81604B4073BA2C2636BE5340F981AB3C81604B40
24798	Барлакуль	5	52	1399	78.651959000000005	78.683957000000007	54.311644000000001	54.300238999999998	0103000020E610000001000000050000004ED53DB2B9A95340EBFD463B6E264B404ED53DB2B9A9534050FF59F3E3274B40B3B794F3C5AB534050FF59F3E3274B40B3B794F3C5AB5340EBFD463B6E264B404ED53DB2B9A95340EBFD463B6E264B40
24619	Алексотово	5	52	1399	78.801995000000005	78.815029999999993	54.555945000000001	54.546242999999997	0103000020E610000001000000050000008E23D6E253B353409F55664AEB454B408E23D6E253B35340F7AFAC3429474B4091D0967329B45340F7AFAC3429474B4091D0967329B453409F55664AEB454B408E23D6E253B353409F55664AEB454B40
45362	Алексеевка	5	52	1399	78.498230000000007	78.538672000000005	54.893279999999997	54.881985999999998	0103000020E61000000100000005000000B6F81400E39F5340D2C3D0EAE4704B40B6F81400E39F5340DF15C1FF56724B4057D11F9A79A25340DF15C1FF56724B4057D11F9A79A25340D2C3D0EAE4704B40B6F81400E39F5340D2C3D0EAE4704B40
23778	Шагалка	5	52	1400	79.476512999999997	79.498746999999995	54.302928999999999	54.288989000000001	0103000020E610000001000000050000009BC761307FDE5340AEF36F97FD244B409BC761307FDE53404701A260C6264B40997E8978EBDF53404701A260C6264B40997E8978EBDF5340AEF36F97FD244B409BC761307FDE5340AEF36F97FD244B40
23789	Утянка	5	52	1400	79.698721000000006	79.823721000000006	54.801679999999998	54.697032	0103000020E61000000100000005000000D20149D8B7EC5340FB21365838594B40D20149D8B7EC5340BBED42739D664B40D20149D8B7F45340BBED42739D664B40D20149D8B7F45340FB21365838594B40D20149D8B7EC5340FB21365838594B40
41313	Травное	5	52	1400	79.598532000000006	79.632964000000001	54.263807	54.227105999999999	0103000020E61000000100000005000000026729594EE65340D95C35CF111D4B40026729594EE653405ABA826DC4214B40E7E26F7B82E853405ABA826DC4214B40E7E26F7B82E85340D95C35CF111D4B40026729594EE65340D95C35CF111D4B40
23642	Суздалка	5	52	1400	79.428578999999999	79.488488000000004	54.599936	54.571475	0103000020E6100000010000000500000027309DD66DDB5340A5BDC11726494B4027309DD66DDB5340B6D8EDB3CA4C4B40431F2C6343DF5340B6D8EDB3CA4C4B40431F2C6343DF5340A5BDC11726494B4027309DD66DDB5340A5BDC11726494B40
23300	Солонцовый	5	52	1400	79.895612999999997	79.908907999999997	54.811622	54.805821000000002	0103000020E61000000100000005000000D63730B951F953400BB77C2425674B40D63730B951F95340685BCD3AE3674B40A8C4758C2BFA5340685BCD3AE3674B40A8C4758C2BFA53400BB77C2425674B40D63730B951F953400BB77C2425674B40
23553	Согорное	5	52	1400	79.915375999999995	79.974475999999996	54.303238999999998	54.273850000000003	0103000020E61000000100000005000000C5E2378595FA53403B014D840D234B40C5E2378595FA534095EF1989D0264B4029AF95D05DFE534095EF1989D0264B4029AF95D05DFE53403B014D840D234B40C5E2378595FA53403B014D840D234B40
15426	Сарыбалык	5	52	1400	79.940538000000004	79.962933000000007	54.755737000000003	54.745058999999998	0103000020E610000001000000050000004CA94BC631FC5340944BE3175E5F4B404CA94BC631FC534047B071FDBB604B404FCFBBB1A0FD534047B071FDBB604B404FCFBBB1A0FD5340944BE3175E5F4B404CA94BC631FC5340944BE3175E5F4B40
22941	Покровка	5	52	1400	79.751801999999998	79.782363000000004	54.372844000000001	54.361308999999999	0103000020E6100000010000000500000050C422861DF053400F60915F3F2E4B4050C422861DF053404241295AB92F4B406EA6423C12F253404241295AB92F4B406EA6423C12F253400F60915F3F2E4B4050C422861DF053400F60915F3F2E4B40
22623	Плеханово	5	52	1400	79.418149999999997	79.444102000000001	54.363233999999999	54.354199999999999	0103000020E61000000100000005000000A2B437F8C2DA5340211FF46C562D4B40A2B437F8C2DA5340CB65A3737E2E4B40A585CB2A6CDC5340CB65A3737E2E4B40A585CB2A6CDC5340211FF46C562D4B40A2B437F8C2DA5340211FF46C562D4B40
60762	Кротово	5	52	1400	78.877499	80.396396999999993	54.887300000000003	54.140394999999998	0103000020E6100000010000000500000074D190F128B85340CEC29E76F8114B4074D190F128B85340D3DEE00B93714B40E1CE85915E195440D3DEE00B93714B40E1CE85915E195440CEC29E76F8114B4074D190F128B85340CEC29E76F8114B40
23241	Красная Грива	5	52	1400	79.941175999999999	79.957111999999995	54.774383999999998	54.767128999999997	0103000020E61000000100000005000000EDF1423A3CFC53401668774831624B40EDF1423A3CFC5340D845D1031F634B40FCA6B05241FD5340D845D1031F634B40FCA6B05241FD53401668774831624B40EDF1423A3CFC53401668774831624B40
23698	Комендантка	5	52	1400	79.616479999999996	79.629461000000006	54.605922999999997	54.598360999999997	0103000020E61000000100000005000000D6A8876874E75340D619DF17974C4B40D6A8876874E75340757286E28E4D4B40E146CA1649E85340757286E28E4D4B40E146CA1649E85340D619DF17974C4B40D6A8876874E75340D619DF17974C4B40
23113	Комарье	5	52	1400	80.199405999999996	80.240144000000001	54.431223000000003	54.410321000000003	0103000020E6100000010000000500000013286211C30C544057EE056685344B4013286211C30C54403A24B55032374B402995F0845E0F54403A24B55032374B402995F0845E0F544057EE056685344B4013286211C30C544057EE056685344B40
23059	Индерь	5	52	1400	79.969005999999993	80.001911000000007	54.560273000000002	54.524411999999998	0103000020E610000001000000050000002DE8BD3104FE5340A2D0B2EE1F434B402DE8BD3104FE534079EA9106B7474B402CA0504F1F00544079EA9106B7474B402CA0504F1F005440A2D0B2EE1F434B402DE8BD3104FE5340A2D0B2EE1F434B40
22989	Ильинка	5	52	1400	79.211798000000002	79.268320000000003	54.535640000000001	54.511733999999997	0103000020E61000000100000005000000EDD632198ECD53402920ED7F80414B40EDD632198ECD5340F836FDD98F444B403737A6272CD15340F836FDD98F444B403737A6272CD153402920ED7F80414B40EDD632198ECD53402920ED7F80414B40
23016	Дружный	5	52	1400	79.085134999999994	79.103757000000002	54.438183000000002	54.428918000000003	0103000020E61000000100000005000000AD2F12DA72C553403755F7C8E6364B40AD2F12DA72C55340E3546B6116384B40CA6E66F4A3C65340E3546B6116384B40CA6E66F4A3C653403755F7C8E6364B40AD2F12DA72C553403755F7C8E6364B40
22674	Довольное	5	52	1400	79.631750999999994	79.693960000000004	54.510630999999997	54.460425999999998	0103000020E61000000100000005000000C70DBF9B6EE85340321D3A3DEF3A4B40C70DBF9B6EE8534071A94A5B5C414B40DC2E34D769EC534071A94A5B5C414B40DC2E34D769EC5340321D3A3DEF3A4B40C70DBF9B6EE85340321D3A3DEF3A4B40
23499	Даниловская Ферма	5	52	1400	80.106834000000006	80.130936000000005	54.722175999999997	54.714458	0103000020E610000001000000050000007506465ED6065440CB2E185C735B4B407506465ED606544061FA5E43705C4B409F7763416108544061FA5E43705C4B409F77634161085440CB2E185C735B4B407506465ED6065440CB2E185C735B4B40
22582	Волчанка	5	52	1400	79.386501999999993	79.418177	54.445518	54.418982	0103000020E61000000100000005000000AB75E272BCD853406CCEC133A1354B40AB75E272BCD85340C1E3DBBB06394B401FBC7669C3DA5340C1E3DBBB06394B401FBC7669C3DA53406CCEC133A1354B40AB75E272BCD853406CCEC133A1354B40
23579	Брянский	5	52	1400	79.739153999999999	79.757999999999996	54.214872	54.203308999999997	0103000020E61000000100000005000000492D944C4EEF5340C1FD8007061A4B40492D944C4EEF5340BE69FAEC801B4B408D976E1283F05340BE69FAEC801B4B408D976E1283F05340C1FD8007061A4B40492D944C4EEF5340C1FD8007061A4B40
23157	Безногое	5	52	1400	80.035221000000007	80.049468000000005	54.408648999999997	54.398634000000001	0103000020E610000001000000050000007AC8940F410254406E895C7006334B407AC8940F410254408445459C4E344B40B58CD47B2A0354408445459C4E344B40B58CD47B2A0354406E895C7006334B407AC8940F410254406E895C7006334B40
22495	Баклуши	5	52	1400	79.106038999999996	79.139142000000007	54.396852000000003	54.362468	0103000020E610000001000000050000006F46CD57C9C653405BECF659652E4B406F46CD57C9C6534015ADDC0BCC324B4001E0D8B3E7C8534015ADDC0BCC324B4001E0D8B3E7C853405BECF659652E4B406F46CD57C9C653405BECF659652E4B40
22863	Баган	5	52	1400	79.765096999999997	79.787482999999995	54.518250999999999	54.500829000000003	0103000020E6100000010000000500000022516859F7F05340B7F1272A1B404B4022516859F7F05340450F7C0C56424B40FBC9181F66F25340450F7C0C56424B40FBC9181F66F25340B7F1272A1B404B4022516859F7F05340B7F1272A1B404B40
38927	Красноселье	5	52	6065	76.809387999999998	76.832745000000003	55.467666999999999	55.454565000000002	0103000020E6100000010000000500000097715303CD3353400074982F2FBA4B4097715303CD3353408F352383DCBB4B40153AAFB14B3553408F352383DCBB4B40153AAFB14B3553400074982F2FBA4B4097715303CD3353400074982F2FBA4B40
35187	Бедрино	5	52	3417	82.247716999999994	82.276956999999996	53.992502000000002	53.978192	0103000020E61000000100000005000000726A6798DA8F5440BB9A3C6535FD4A40726A6798DA8F5440789B374E0AFF4A407D59DAA9B9915440789B374E0AFF4A407D59DAA9B9915440BB9A3C6535FD4A40726A6798DA8F5440BB9A3C6535FD4A40
41228	Шипицыно	5	52	1623	77.270745000000005	77.306875000000005	56.079307	56.069555000000001	0103000020E610000001000000050000008E23D6E253515340FB22A12DE7084C408E23D6E25351534004AC55BB260A4C40713D0AD7A353534004AC55BB260A4C40713D0AD7A3535340FB22A12DE7084C408E23D6E253515340FB22A12DE7084C40
21963	Чистое Озеро	5	52	1623	77.158995000000004	77.176709000000002	55.665821999999999	55.655295000000002	0103000020E61000000100000005000000904E5DF92C4A5340BD1DE1B4E0D34B40904E5DF92C4A5340897AC1A739D54B402BFA43334F4B5340897AC1A739D54B402BFA43334F4B5340BD1DE1B4E0D34B40904E5DF92C4A5340BD1DE1B4E0D34B40
21771	Чаргары	5	52	1623	76.690325999999999	76.711417999999995	55.799182999999999	55.789724999999997	0103000020E6100000010000000500000006651A4D2E2C5340B3EA73B515E54B4006651A4D2E2C53407442E8A04BE64B4049F25CDF872D53407442E8A04BE64B4049F25CDF872D5340B3EA73B515E54B4006651A4D2E2C5340B3EA73B515E54B40
22255	Филошенка	5	52	1623	77.347282000000007	77.368122	56.252442000000002	56.240457999999997	0103000020E61000000100000005000000541F48DE39565340E107E753C71E4C40541F48DE395653408411FB0450204C400ABC934F8F5753408411FB0450204C400ABC934F8F575340E107E753C71E4C40541F48DE39565340E107E753C71E4C40
49029	Усть-Ламенка	5	52	1623	77.265058999999994	77.293248000000006	55.682558999999998	55.669752000000003	0103000020E61000000100000005000000AB2006BAF65053401E37FC6EBAD54B40AB2006BAF6505340944BE3175ED74B4084674293C4525340944BE3175ED74B4084674293C45253401E37FC6EBAD54B40AB2006BAF65053401E37FC6EBAD54B40
22156	Усть-Изес	5	52	1623	76.934163999999996	76.955832000000001	55.935546000000002	55.924351000000001	0103000020E610000001000000050000006F46CD57C93B53403083312251F64B406F46CD57C93B5340AAF3A8F8BFF74B40191EFB592C3D5340AAF3A8F8BFF74B40191EFB592C3D53403083312251F64B406F46CD57C93B53403083312251F64B40
21979	Урез	5	52	1623	77.113225999999997	77.129952000000003	55.924087999999998	55.911774000000001	0103000020E61000000100000005000000A4C343183F475340EBABAB02B5F44B40A4C343183F4753402250FD8348F64B4030833122514853402250FD8348F64B403083312251485340EBABAB02B5F44B40A4C343183F475340EBABAB02B5F44B40
21789	Туруновка	5	52	1623	77.019171999999998	77.048978000000005	55.646943999999998	55.635691000000001	0103000020E61000000100000005000000EE3F321D3A41534047AE9B525ED14B40EE3F321D3A415340F52B9D0FCFD24B404E0E9F7422435340F52B9D0FCFD24B404E0E9F742243534047AE9B525ED14B40EE3F321D3A41534047AE9B525ED14B40
21128	Старый Тартас	5	52	1623	76.728296999999998	76.755156999999997	55.616503000000002	55.607894999999999	0103000020E610000001000000050000009831056B9C2E53407233DC80CFCD4B409831056B9C2E53406571FF91E9CE4B401C96067E543053406571FF91E9CE4B401C96067E543053407233DC80CFCD4B409831056B9C2E53407233DC80CFCD4B40
49605	Сибирцево 2-е	5	52	1623	76.526060000000001	76.554356999999996	55.598711000000002	55.591665999999996	0103000020E61000000100000005000000F6EE8FF7AA215340DB1324B6BBCB4B40F6EE8FF7AA215340B360E28FA2CC4B40C153C8957A235340B360E28FA2CC4B40C153C8957A235340DB1324B6BBCB4B40F6EE8FF7AA215340DB1324B6BBCB4B40
47485	Сибирцево 1-е	5	52	1623	76.526060000000001	76.554356999999996	55.598711000000002	55.591665999999996	0103000020E61000000100000005000000F6EE8FF7AA215340DB1324B6BBCB4B40F6EE8FF7AA215340B360E28FA2CC4B40C153C8957A235340B360E28FA2CC4B40C153C8957A235340DB1324B6BBCB4B40F6EE8FF7AA215340DB1324B6BBCB4B40
20665	Селикла	5	52	1623	76.337647000000004	76.358236000000005	55.777388000000002	55.766146999999997	0103000020E61000000100000005000000ECA529029C155340D976DA1A11E24B40ECA529029C155340C426327381E34B40FE0FB056ED165340C426327381E34B40FE0FB056ED165340D976DA1A11E24B40ECA529029C155340D976DA1A11E24B40
21474	Петропавловка 2-я	5	52	1623	76.546954999999997	76.564848999999995	55.983811000000003	55.970857000000002	0103000020E610000001000000050000008E588B4F01235340DD0BCC0A45FC4B408E588B4F01235340F838D384EDFD4B40698B6B7C26245340F838D384EDFD4B40698B6B7C26245340DD0BCC0A45FC4B408E588B4F01235340DD0BCC0A45FC4B40
21303	Петропавловка 1-я	5	52	1623	76.983006000000003	76.998007999999999	55.812206000000003	55.797609000000001	0103000020E610000001000000050000006571FF91E93E534065FF3C0D18E64B406571FF91E93E5340B8CEBF5DF6E74B405E49F25CDF3F5340B8CEBF5DF6E74B405E49F25CDF3F534065FF3C0D18E64B406571FF91E93E534065FF3C0D18E64B40
41340	Павлово	5	52	1623	76.775028000000006	76.795680000000004	56.153131000000002	56.142611000000002	0103000020E61000000100000005000000FF5E0A0F9A3153406286C61341124C40FF5E0A0F9A3153407C80EECB99134C403485CE6BEC3253407C80EECB99134C403485CE6BEC3253406286C61341124C40FF5E0A0F9A3153406286C61341124C40
41199	Орлово	5	52	1623	76.913144000000003	76.921048999999996	55.785108000000001	55.773029000000001	0103000020E61000000100000005000000792288F3703A534007EE409DF2E24B40792288F3703A5340FBE93F6B7EE44B40DD408177F23A5340FBE93F6B7EE44B40DD408177F23A534007EE409DF2E24B40792288F3703A534007EE409DF2E24B40
41204	Ночка	5	52	1623	76.964572000000004	76.987838999999994	55.817694000000003	55.809403000000003	0103000020E61000000100000005000000CAA8328CBB3D534064247B849AE74B40CAA8328CBB3D534056116E32AAE84B40A7AD11C1383F534056116E32AAE84B40A7AD11C1383F534064247B849AE74B40CAA8328CBB3D534064247B849AE74B40
21117	Новый Тартас	5	52	1623	76.685025999999993	76.739266000000001	55.679088	55.667178	0103000020E6100000010000000500000038BA4A77D72B53402B4EB51666D54B4038BA4A77D72B5340938D075BECD64B40DD425722502F5340938D075BECD64B40DD425722502F53402B4EB51666D54B4038BA4A77D72B53402B4EB51666D54B40
21024	Новые Кулики	5	52	1623	77.176008999999993	77.191630000000004	56.148868999999998	56.139811999999999	0103000020E610000001000000050000004EB340BB434B53404FCB0F5CE5114C404EB340BB434B5340B131AF230E134C40AEBB79AA434C5340B131AF230E134C40AEBB79AA434C53404FCB0F5CE5114C404EB340BB434B53404FCB0F5CE5114C40
41265	Минино	5	52	1623	77.522515999999996	77.546034000000006	56.176563999999999	56.168686000000001	0103000020E61000000100000005000000C0E8F2E67061534083A5BA8097154C40C0E8F2E67061534052D32EA699164C4043209738F262534052D32EA699164C4043209738F262534083A5BA8097154C40C0E8F2E67061534083A5BA8097154C40
41368	Меньшиково	5	52	1623	76.680220000000006	76.714751000000007	55.939917999999999	55.925057000000002	0103000020E61000000100000005000000738577B9882B5340CBF78C4468F64B40738577B9882B5340FB75A73B4FF84B402272FA7ABE2D5340FB75A73B4FF84B402272FA7ABE2D5340CBF78C4468F64B40738577B9882B5340CBF78C4468F64B40
22072	Мариинка	5	52	1623	77.217843000000002	77.238180999999997	55.972987000000003	55.966926999999998	0103000020E61000000100000005000000672AC423F14D5340484F9143C4FB4B40672AC423F14D5340723788D68AFC4B40D461855B3E4F5340723788D68AFC4B40D461855B3E4F5340484F9143C4FB4B40672AC423F14D5340484F9143C4FB4B40
41304	Красноярка	5	52	1623	76.952256000000006	76.964222000000007	55.757004000000002	55.747008000000001	0103000020E61000000100000005000000DE5A26C3F13C5340D9EC48F59DDF4B40DE5A26C3F13C53407978CF81E5E04B405C0531D0B53D53407978CF81E5E04B405C0531D0B53D5340D9EC48F59DDF4B40DE5A26C3F13C5340D9EC48F59DDF4B40
41377	Ключевая	5	52	1623	76.827524999999994	76.846686000000005	55.723672999999998	55.712634000000001	0103000020E61000000100000005000000D5E76A2BF63453404302469737DB4B40D5E76A2BF6345340C5FF1D51A1DC4B40CAFE791A30365340C5FF1D51A1DC4B40CAFE791A303653404302469737DB4B40D5E76A2BF63453404302469737DB4B40
48684	Игнатьевка	5	52	1623	76.527856	76.544376	55.615547999999997	55.606695000000002	0103000020E61000000100000005000000D53F8864C8215340C8D2872EA8CD4B40D53F8864C8215340218FE046CACE4B408C2E6F0ED7225340218FE046CACE4B408C2E6F0ED7225340C8D2872EA8CD4B40D53F8864C8215340C8D2872EA8CD4B40
48675	Зыково	5	52	1623	76.931603999999993	76.945519000000004	55.672553999999998	55.666283999999997	0103000020E61000000100000005000000A83462669F3B53408DEC4ACB48D54B40A83462669F3B5340A165DD3F16D64B40C9AF1F62833C5340A165DD3F16D64B40C9AF1F62833C53408DEC4ACB48D54B40A83462669F3B53408DEC4ACB48D54B40
41214	Заречье	5	52	1623	76.722881000000001	76.750630000000001	55.710442999999998	55.700999000000003	0103000020E610000001000000050000009679ABAE432E5340ADC3D155BAD94B409679ABAE432E53400856D5CBEFDA4B40605969520A3053400856D5CBEFDA4B40605969520A305340ADC3D155BAD94B409679ABAE432E5340ADC3D155BAD94B40
47438	Григорьевка	5	52	1623	76.991342000000003	77.009649999999993	55.854734000000001	55.842801999999999	0103000020E61000000100000005000000AE49B725723F53406F8099EFE0EB4B40AE49B725723F5340BF6378EC67ED4B40029A081B9E405340BF6378EC67ED4B40029A081B9E4053406F8099EFE0EB4B40AE49B725723F53406F8099EFE0EB4B40
49660	Воробьёво	5	52	1623	76.514336999999998	76.539884999999998	56.133572000000001	56.119357999999998	0103000020E61000000100000005000000DB87BCE5EA2053400B42791F470F4C40DB87BCE5EA205340A6D425E318114C4076A6D0798D225340A6D425E318114C4076A6D0798D2253400B42791F470F4C40DB87BCE5EA2053400B42791F470F4C40
41357	Вознесенка	5	52	1623	76.366483000000002	76.403197000000006	55.620814000000003	55.607849999999999	0103000020E610000001000000050000008FE21C7574175340D26F5F07CECD4B408FE21C7574175340117349D576CF4B401A36CAFACD195340117349D576CF4B401A36CAFACD195340D26F5F07CECD4B408FE21C7574175340D26F5F07CECD4B40
20327	Венгерово	5	52	1623	76.708831000000004	76.800269999999998	55.697589000000001	55.668483000000002	0103000020E6100000010000000500000006D9B27C5D2D53404B77D7D990D54B4006D9B27C5D2D53405186AA984AD94B40137EA99F373353405186AA984AD94B40137EA99F373353404B77D7D990D54B4006D9B27C5D2D53404B77D7D990D54B40
41222	Бровничи	5	52	1623	76.996731999999994	77.012514999999993	55.928345	55.916981	0103000020E610000001000000050000001BB80375CA3F5340D50627A25FF54B401BB80375CA3F5340DB334B02D4F64B4067EDB60BCD405340DB334B02D4F64B4067EDB60BCD405340D50627A25FF54B401BB80375CA3F5340D50627A25FF54B40
49609	Светлая Поляна	5	52	1554	84.021584000000004	84.046386999999996	55.496873000000001	55.481873	0103000020E610000001000000050000007B87DBA161015540A7E9B303AEBD4B407B87DBA161015540F9A1D28899BF4B4069FD2D01F8025540F9A1D28899BF4B4069FD2D01F8025540A7E9B303AEBD4B407B87DBA161015540A7E9B303AEBD4B40
19127	Правососновка	5	52	1554	84.713331999999994	84.736059999999995	55.555743999999997	55.543236	0103000020E610000001000000050000002DCC423BA72D55404301DBC188C54B402DCC423BA72D55405F79909E22C74B4033F9669B1B2F55405F79909E22C74B4033F9669B1B2F55404301DBC188C54B402DCC423BA72D55404301DBC188C54B40
60573	Ояш	5	52	1554	83.826857000000004	83.853070000000002	55.562128000000001	55.537353000000003	0103000020E61000000100000005000000FF5D9F39EBF4544029B4ACFBC7C44B40FF5D9F39EBF454403C1570CFF3C74B40B8CCE9B298F654403C1570CFF3C74B40B8CCE9B298F6544029B4ACFBC7C44B40FF5D9F39EBF4544029B4ACFBC7C44B40
60623	Кунчурук	5	52	1554	84.285248999999993	84.310293999999999	55.927129999999998	55.909685000000003	0103000020E61000000100000005000000DE8D058541125540B554DE8E70F44B40DE8D058541125540FB912232ACF64B4048895DDBDB135540FB912232ACF64B4048895DDBDB135540B554DE8E70F44B40DE8D058541125540B554DE8E70F44B40
49659	Кривояш	5	52	1554	84.168091000000004	84.186173999999994	55.511073000000003	55.495787	0103000020E6100000010000000500000020F0C000C20A55401764CBF275BF4B4020F0C000C20A55402F6F0ED76AC14B4064575A46EA0B55402F6F0ED76AC14B4064575A46EA0B55401764CBF275BF4B4020F0C000C20A55401764CBF275BF4B40
41338	Корнилово	5	52	1554	84.586130999999995	84.608607000000006	55.523820000000001	55.508992999999997	0103000020E61000000100000005000000FE0A992B832555404B72C0AE26C14B40FE0A992B83255540D07EA4880CC34B407847C66AF3265540D07EA4880CC34B407847C66AF32655404B72C0AE26C14B40FE0A992B832555404B72C0AE26C14B40
46957	Киевка	5	52	1554	84.219015999999996	84.237646999999996	55.607655999999999	55.604101999999997	0103000020E610000001000000050000003F53AF5B040E55405EB9DE3653CD4B403F53AF5B040E5540ED9BFBABC7CD4B40853FC39B350F5540ED9BFBABC7CD4B40853FC39B350F55405EB9DE3653CD4B403F53AF5B040E55405EB9DE3653CD4B40
60576	Карасево	5	52	1554	84.151840000000007	84.176652000000004	55.727567000000001	55.715904999999999	0103000020E61000000100000005000000618E1EBFB70955407D0569C6A2DB4B40618E1EBFB70955400D535BEA20DD4B4079B130444E0B55400D535BEA20DD4B4079B130444E0B55407D0569C6A2DB4B40618E1EBFB70955407D0569C6A2DB4B40
41360	Зудово	5	52	1554	84.251166999999995	84.264371999999995	55.832293	55.817157999999999	0103000020E6100000010000000500000067B5C01E1310554017D522A298E84B4067B5C01E1310554049D8B79388EA4B40997E8978EB10554049D8B79388EA4B40997E8978EB10554017D522A298E84B4067B5C01E1310554017D522A298E84B40
47908	Елфимово	5	52	1554	84.680014	84.694655999999995	55.638784999999999	55.626319000000002	0103000020E610000001000000050000009EB47059852B554085EE92382BD04B409EB47059852B55407216F6B4C3D14B40177E703E752C55407216F6B4C3D14B40177E703E752C554085EE92382BD04B409EB47059852B554085EE92382BD04B40
60684	Егоровка	5	52	1554	84.200609999999998	84.233389000000003	55.627046	55.612614000000001	0103000020E61000000100000005000000095053CBD60C55402F89B3226ACE4B40095053CBD60C5540378B170B43D04B40C18F6AD8EF0E5540378B170B43D04B40C18F6AD8EF0E55402F89B3226ACE4B40095053CBD60C55402F89B3226ACE4B40
60579	Дивинка	5	52	1554	84.463950999999994	84.486480999999998	55.702266999999999	55.690140999999997	0103000020E6100000010000000500000093FC885FB11D55407A50508A56D84B4093FC885FB11D5540AF0793E2E3D94B4006483481221F5540AF0793E2E3D94B4006483481221F55407A50508A56D84B4093FC885FB11D55407A50508A56D84B40
60682	Варламово	5	52	1554	84.352344000000002	84.369763000000006	55.815255999999998	55.800432999999998	0103000020E61000000100000005000000473CD9CD8C165540D0D1AA9674E64B40473CD9CD8C16554013EF004F5AE84B4056116E32AA17554013EF004F5AE84B4056116E32AA175540D0D1AA9674E64B40473CD9CD8C165540D0D1AA9674E64B40
19692	Болотное	5	52	1554	84.348212000000004	84.431638000000007	55.687274000000002	55.650002000000001	0103000020E61000000100000005000000C904FC1A49165540D42AFA4333D34B40C904FC1A4916554010B22C98F8D74B407F6DFDF49F1B554010B22C98F8D74B407F6DFDF49F1B5540D42AFA4333D34B40C904FC1A49165540D42AFA4333D34B40
49200	Баратаевка	5	52	1554	84.441142999999997	84.467642999999995	55.620657000000001	55.614963000000003	0103000020E61000000100000005000000FF76D9AF3B1C554002A08A1BB7CE4B40FF76D9AF3B1C5540498446B071CF4B4003CDE7DCED1D5540498446B071CF4B4003CDE7DCED1D554002A08A1BB7CE4B40FF76D9AF3B1C554002A08A1BB7CE4B40
60683	Байкал	5	52	1554	83.876039000000006	83.899674000000005	55.646340000000002	55.631284999999998	0103000020E6100000010000000500000051C1E10511F8544049BA66F2CDD04B4051C1E10511F854405F0CE544BBD24B40F0C3414294F954405F0CE544BBD24B40F0C3414294F9544049BA66F2CDD04B4051C1E10511F8544049BA66F2CDD04B40
60627	Ача	5	52	1554	84.601043000000004	84.625189000000006	55.648377000000004	55.632362000000001	0103000020E61000000100000005000000581F0F7D77265540D89DEE3CF1D04B40581F0F7D77265540433D7D04FED24B406A34B91803285540433D7D04FED24B406A34B91803285540D89DEE3CF1D04B40581F0F7D77265540D89DEE3CF1D04B40
37628	Осиновка	5	52	5168	77.649249999999995	77.657470000000004	53.692529999999998	53.686447000000001	0103000020E61000000100000005000000643BDF4F8D695340FAB7CB7EDDD74A40643BDF4F8D695340DBBFB2D2A4D84A4079060DFD136A5340DBBFB2D2A4D84A4079060DFD136A5340FAB7CB7EDDD74A40643BDF4F8D695340FAB7CB7EDDD74A40
41236	станция Кирзинское	5	52	1326	77.889522999999997	78.021322999999995	55.378872000000001	55.303755000000002	0103000020E610000001000000050000008C82E0F1ED7853408D7F9F71E1A64B408C82E0F1ED78534060AFB0E07EB04B40C4E9245B5D81534060AFB0E07EB04B40C4E9245B5D8153408D7F9F71E1A64B408C82E0F1ED7853408D7F9F71E1A64B40
15608	Юный Пионер	5	52	1326	78.186954999999998	78.205882000000003	55.158045000000001	55.148651999999998	0103000020E61000000100000005000000B7B41A12F78B5340143E5B0707934B40B7B41A12F78B5340EE258DD13A944B407235B22B2D8D5340EE258DD13A944B407235B22B2D8D5340143E5B0707934B40B7B41A12F78B5340143E5B0707934B40
14360	Шубинское	5	52	1326	78.206357999999994	78.221440999999999	55.328724000000001	55.318874999999998	0103000020E6100000010000000500000026512FF8348D5340894160E5D0A84B4026512FF8348D534085B4C6A013AA4B40963FDF162C8E534085B4C6A013AA4B40963FDF162C8E5340894160E5D0A84B4026512FF8348D5340894160E5D0A84B40
14112	Устьянцево	5	52	1326	77.922535999999994	77.952772999999993	55.297369000000003	55.282943000000003	0103000020E610000001000000050000007D586FD40A7B5340EAD0E97937A44B407D586FD40A7B534010ECF82F10A64B40C1E09A3BFA7C534010ECF82F10A64B40C1E09A3BFA7C5340EAD0E97937A44B407D586FD40A7B5340EAD0E97937A44B40
16089	Усть-Тандовка	5	52	1326	78.067892000000001	78.092308000000003	55.011597999999999	55.002687000000002	0103000020E610000001000000050000003EEAAF5758845340EB8F300C58804B403EEAAF57588453407959130B7C814B40304AD05FE88553407959130B7C814B40304AD05FE8855340EB8F300C58804B403EEAAF5758845340EB8F300C58804B40
14882	Труновское	5	52	1326	78.746273000000002	78.764976000000004	55.345038000000002	55.340649999999997	0103000020E61000000100000005000000D238D4EFC2AF5340F2B0506B9AAB4B40D238D4EFC2AF53404AF086342AAC4B40658EE55DF5B053404AF086342AAC4B40658EE55DF5B05340F2B0506B9AAB4B40D238D4EFC2AF5340F2B0506B9AAB4B40
16372	Тополевка	5	52	1326	78.036631	78.052880999999999	54.818480999999998	54.811923	0103000020E6100000010000000500000044C18C295882534063EFC517ED674B4044C18C2958825340DDB243FCC3684B401B65FD6662835340DDB243FCC3684B401B65FD666283534063EFC517ED674B4044C18C295882534063EFC517ED674B40
46628	Таскаево	5	52	1326	78.575862000000001	78.620096000000004	55.101066000000003	55.087274999999998	0103000020E6100000010000000500000096404AECDAA453401361C3D32B8B4B4096404AECDAA45340685E0EBBEF8C4B40591822A7AFA75340685E0EBBEF8C4B40591822A7AFA753401361C3D32B8B4B4096404AECDAA453401361C3D32B8B4B40
15925	Тандов (Аул-Тандов)	5	52	1326	78.129337000000007	78.146944000000005	55.162844	55.158862999999997	0103000020E610000001000000050000006B4AB20E47885340B0C56E9F55944B406B4AB20E47885340C72C7B12D8944B40FB95CE8767895340C72C7B12D8944B40FB95CE8767895340B0C56E9F55944B406B4AB20E47885340B0C56E9F55944B40
15388	Старый Карапуз	5	52	1326	78.901223000000002	78.914698000000001	55.073618000000003	55.064642999999997	0103000020E61000000100000005000000CBD93BA3ADB953402975C93846884B40CBD93BA3ADB95340CF328B506C894B40DDED7A698ABA5340CF328B506C894B40DDED7A698ABA53402975C93846884B40CBD93BA3ADB953402975C93846884B40
16439	Староярково	5	52	1326	77.981195999999997	78.007363999999995	54.884788	54.877433000000003	0103000020E61000000100000005000000D3BD4EEACB7E534031B77BB94F704B40D3BD4EEACB7E534056F2B1BB40714B40BCCADAA67880534056F2B1BB40714B40BCCADAA67880534031B77BB94F704B40D3BD4EEACB7E534031B77BB94F704B40
14590	Старощербаково (Марандино)	5	52	1326	78.448131000000004	78.465046000000001	55.373874000000001	55.364812999999998	0103000020E61000000100000005000000B954A52DAE9C5340EC134031B2AE4B40B954A52DAE9C534090696D1ADBAF4B40AE484C50C39D534090696D1ADBAF4B40AE484C50C39D5340EC134031B2AE4B40B954A52DAE9C5340EC134031B2AE4B40
41321	Сизево	5	52	1326	78.261246	78.284090000000006	54.900052000000002	54.892214000000003	0103000020E610000001000000050000007E8D2441B890534045847F1134724B407E8D2441B8905340865968E734734B40B9C7D2872E925340865968E734734B40B9C7D2872E92534045847F1134724B407E8D2441B890534045847F1134724B40
15133	Пензино (Моховое)	5	52	1326	78.804879	78.823384000000004	55.290311000000003	55.278652000000001	0103000020E610000001000000050000002E8F352383B35340857B65DEAAA34B402E8F352383B35340A4552DE928A54B402E03CE52B2B45340A4552DE928A54B402E03CE52B2B45340857B65DEAAA34B402E8F352383B35340857B65DEAAA34B40
16346	Новоярково	5	52	1326	78.078573000000006	78.104839999999996	54.931288000000002	54.920211000000002	0103000020E6100000010000000500000050560C5707855340B1355B79C9754B4050560C57078553402194F77134774B4002D4D4B2B58653402194F77134774B4002D4D4B2B5865340B1355B79C9754B4050560C5707855340B1355B79C9754B40
16048	Новочановское	5	52	1326	78.160706000000005	78.187529999999995	54.959159999999997	54.945205000000001	0103000020E610000001000000050000005891D101498A53400282397AFC784B405891D101498A5340D0D03FC1C57A4B403541D47D008C5340D0D03FC1C57A4B403541D47D008C53400282397AFC784B405891D101498A53400282397AFC784B40
14741	Новоульяновское	5	52	1326	78.509198999999995	78.540693000000005	55.401983999999999	55.392183000000003	0103000020E61000000100000005000000FA0967B796A053400A86730D33B24B40FA0967B796A05340F4C1323674B34B40460BD0B69AA25340F4C1323674B34B40460BD0B69AA253400A86730D33B24B40FA0967B796A053400A86730D33B24B40
16834	Новотандово	5	52	1326	77.945937000000001	77.956232	55.096415	55.089964000000002	0103000020E61000000100000005000000E3C4573B8A7C53409FE8BAF0838B4B40E3C4573B8A7C534003ECA353578C4B40E0D8B3E7327D534003ECA353578C4B40E0D8B3E7327D53409FE8BAF0838B4B40E3C4573B8A7C53409FE8BAF0838B4B40
41372	Новоспасск	5	52	1326	78.167327	78.194168000000005	55.118538999999998	55.106948000000003	0103000020E61000000100000005000000382F4E7CB58A5340B22FD978B08D4B40382F4E7CB58A5340782634492C8F4B40817B9E3F6D8C5340782634492C8F4B40817B9E3F6D8C5340B22FD978B08D4B40382F4E7CB58A5340B22FD978B08D4B40
46385	Новониколаевка	5	52	1326	77.814019000000002	77.847427999999994	54.801493000000001	54.791097000000001	0103000020E61000000100000005000000A6D425E3187453405B7B9FAA42654B40A6D425E318745340897C975297664B40BD6DA6423C765340897C975297664B40BD6DA6423C7653405B7B9FAA42654B40A6D425E3187453405B7B9FAA42654B40
15657	Новокурупкаевка	5	52	1326	78.314839000000006	78.336021000000002	55.105227999999997	55.097177000000002	0103000020E6100000010000000500000058207A52269453403276C24B708C4B4058207A5226945340CE4F711C788D4B403B71395E81955340CE4F711C788D4B403B71395E819553403276C24B708C4B4058207A52269453403276C24B708C4B40
14999	Новокозловское	5	52	1326	78.533489000000003	78.555685999999994	55.275492999999997	55.265779000000002	0103000020E61000000100000005000000A6F10BAF24A25340577BD80B05A24B40A6F10BAF24A2534072A3C85A43A34B401536035C90A3534072A3C85A43A34B401536035C90A35340577BD80B05A24B40A6F10BAF24A25340577BD80B05A24B40
14805	Новогутово	5	52	1326	78.454051000000007	78.469285999999997	55.312280999999999	55.304575	0103000020E61000000100000005000000D5EDEC2B0F9D5340F0164850FCA64B40D5EDEC2B0F9D5340C214E5D2F8A74B401F9E25C8089E5340C214E5D2F8A74B401F9E25C8089E5340F0164850FCA64B40D5EDEC2B0F9D5340F0164850FCA64B40
14419	Круглоозерка	5	52	1326	78.004759000000007	78.019463999999999	55.230995	55.222363999999999	0103000020E610000001000000050000002657B1F84D80534064E76D6C769C4B402657B1F84D8053400F45813E919D4B40C2DCEEE53E8153400F45813E919D4B40C2DCEEE53E81534064E76D6C769C4B402657B1F84D80534064E76D6C769C4B40
41241	Красный Пахарь	5	52	1326	78.077072999999999	78.086433	55.268661000000002	55.264403999999999	0103000020E61000000100000005000000E59997C3EE8453403E7782FDD7A14B40E59997C3EE845340F75AD07B63A24B40E412471E88855340F75AD07B63A24B40E412471E888553403E7782FDD7A14B40E59997C3EE8453403E7782FDD7A14B40
41375	Кожевниково (Голованово)	5	52	1326	78.240144000000001	78.261325999999997	55.018742000000003	55.005831000000001	0103000020E610000001000000050000002995F0845E8F5340C826F911BF804B402995F0845E8F5340E4874A2366824B400CE6AF90B9905340E4874A2366824B400CE6AF90B9905340C826F911BF804B402995F0845E8F5340C826F911BF804B40
41323	Квашнино	5	52	1326	77.824079999999995	77.846574000000004	55.014178999999999	55.005412999999997	0103000020E6100000010000000500000069520ABABD74534093FC885FB1804B4069520ABABD7453401EA5129ED0814B4036E9B6442E7653401EA5129ED0814B4036E9B6442E76534093FC885FB1804B4069520ABABD74534093FC885FB1804B40
15236	Кармышак	5	52	1326	78.497511000000003	78.518244999999993	55.183976000000001	55.178193	0103000020E610000001000000050000009E996038D79F534025B03907CF964B409E996038D79F5340DC9F8B868C974B40319413ED2AA15340DC9F8B868C974B40319413ED2AA1534025B03907CF964B409E996038D79F534025B03907CF964B40
16201	Кармакла	5	52	1326	78.390889999999999	78.420670000000001	54.968380000000003	54.959108000000001	0103000020E6100000010000000500000057957D57049953407EAA0A0DC47A4B4057957D5704995340DD0C37E0F37B4B40221ADD41EC9A5340DD0C37E0F37B4B40221ADD41EC9A53407EAA0A0DC47A4B4057957D57049953407EAA0A0DC47A4B40
41287	Казанцево	5	52	1326	77.665366000000006	77.704235999999995	55.084435999999997	55.069819000000003	0103000020E61000000100000005000000B477465B956A5340D9D138D4EF884B40B477465B956A5340724D81CCCE8A4B409D2ADF33126D5340724D81CCCE8A4B409D2ADF33126D5340D9D138D4EF884B40B477465B956A5340D9D138D4EF884B40
16659	Зюзя	5	52	1326	77.832093	77.873631000000003	55.097496	55.085461000000002	0103000020E61000000100000005000000C18EFF0241755340AF0AD462F08A4B40C18EFF0241755340D3BEB9BF7A8C4B406571FF91E9775340D3BEB9BF7A8C4B406571FF91E9775340AF0AD462F08A4B40C18EFF0241755340AF0AD462F08A4B40
41246	Дунаевка	5	52	1326	78.216824000000003	78.228367000000006	55.222523000000002	55.213175999999997	0103000020E610000001000000050000003A3FC571E08D53406325E659499B4B403A3FC571E08D5340CDCD37A27B9C4B40151F9F909D8E5340CDCD37A27B9C4B40151F9F909D8E53406325E659499B4B403A3FC571E08D53406325E659499B4B40
46152	Горка	5	52	1326	78.347950999999995	78.363788	55.411015999999996	55.403809000000003	0103000020E61000000100000005000000126745D4449653404D6A6803B0B34B40126745D444965340FD101B2C9CB44B4058AB764D48975340FD101B2C9CB44B4058AB764D489753404D6A6803B0B34B40126745D4449653404D6A6803B0B34B40
41322	Голованово	5	52	1326	78.265287999999998	78.281485000000004	54.989289999999997	54.982745000000001	0103000020E610000001000000050000005C01857AFA9053405DA79196CA7D4B405C01857AFA9053404221020EA17E4B402254A9D9039253404221020EA17E4B402254A9D9039253405DA79196CA7D4B405C01857AFA9053405DA79196CA7D4B40
16605	Богатиха	5	52	1326	77.814423000000005	77.833504000000005	54.715004	54.707155999999998	0103000020E610000001000000050000000E87A5811F745340C8957A16845A4B400E87A5811F7453402D414640855B4B4074452921587553402D414640855B4B407445292158755340C8957A16845A4B400E87A5811F745340C8957A16845A4B40
41366	Белово	5	52	1326	77.495431999999994	77.531965999999997	55.050457000000002	55.038026000000002	0103000020E6100000010000000500000014596B28B55F5340E8323509DE844B4014596B28B55F5340596DFE5F75864B405F251FBB0B625340596DFE5F75864B405F251FBB0B625340E8323509DE844B4014596B28B55F5340E8323509DE844B40
15308	Бакмасиха	5	52	1326	78.823941000000005	78.849534000000006	55.158723999999999	55.146548000000003	0103000020E6100000010000000500000059350873BBB45340A9A5B915C2924B4059350873BBB453408F8B6A1151944B40C4B5DAC35EB653408F8B6A1151944B40C4B5DAC35EB65340A9A5B915C2924B4059350873BBB45340A9A5B915C2924B40
15689	Бадажки	5	52	1326	78.112952000000007	78.137386000000006	55.192677000000003	55.183328000000003	0103000020E610000001000000050000002481069B3A8753407638BA4A77974B402481069B3A87534080D8D2A3A9984B40693BA6EECA88534080D8D2A3A9984B40693BA6EECA8853407638BA4A77974B402481069B3A8753407638BA4A77974B40
15036	Арисово	5	52	1326	78.623688999999999	78.633309999999994	55.276308	55.270035999999998	0103000020E61000000100000005000000FF774485EAA753400F5F268A90A24B40FF774485EAA75340C4CF7F0F5EA34B40B48EAA2688A85340C4CF7F0F5EA34B40B48EAA2688A853400F5F268A90A24B40FF774485EAA753400F5F268A90A24B40
41244	Абакумово	5	52	1326	78.642374000000004	78.650423000000004	55.194814999999998	55.188904999999998	0103000020E610000001000000050000003F73D6A71CA953408386FE092E984B403F73D6A71CA9534097E2AAB2EF984B403D64CA87A0A9534097E2AAB2EF984B403D64CA87A0A953408386FE092E984B403F73D6A71CA953408386FE092E984B40
46710	Тычкино	5	52	232	77.780215999999996	77.794130999999993	54.112372999999998	54.100025000000002	0103000020E6100000010000000500000038F4160FEF71534026E4839ECD0C4B4038F4160FEF71534009FA0B3D620E4B40586FD40AD372534009FA0B3D620E4B40586FD40AD372534026E4839ECD0C4B4038F4160FEF71534026E4839ECD0C4B40
11971	Теренгуль	5	52	232	77.153092999999998	77.171895000000006	53.832496999999996	53.819853999999999	0103000020E61000000100000005000000C70F9546CC49534055BFD2F9F0E84A40C70F9546CC4953405182FE428FEA4A4024D6E253004B53405182FE428FEA4A4024D6E253004B534055BFD2F9F0E84A40C70F9546CC49534055BFD2F9F0E84A40
41274	Стретинка	5	52	232	77.744300999999993	77.752133999999998	54.059420000000003	54.043283000000002	0103000020E610000001000000050000005358A9A0A26F534084BC1E4C8A054B405358A9A0A26F53403A5D16139B074B406B0DA5F6227053403A5D16139B074B406B0DA5F62270534084BC1E4C8A054B405358A9A0A26F534084BC1E4C8A054B40
41270	Соловьевка	5	52	232	77.358861000000005	77.377699000000007	53.943466999999998	53.931891	0103000020E61000000100000005000000D5B32094F7565340E7374C3448F74A40D5B32094F756534078EDD286C3F84A40D82E6D382C58534078EDD286C3F84A40D82E6D382C585340E7374C3448F74A40D5B32094F7565340E7374C3448F74A40
41351	Славянка	5	52	232	77.337517000000005	77.356813000000002	54.140779999999999	54.132736000000001	0103000020E610000001000000050000000536E7E0995553403D80457EFD104B400536E7E09955534027F73B1405124B4069723106D656534027F73B1405124B4069723106D65653403D80457EFD104B400536E7E0995553403D80457EFD104B40
45750	Савкино	5	52	232	77.893538000000007	77.918260000000004	53.909937999999997	53.895763000000002	0103000020E61000000100000005000000EEEE01BA2F795340C2FBAA5CA8F24A40EEEE01BA2F7953409EB12FD978F44A40664E97C5C47A53409EB12FD978F44A40664E97C5C47A5340C2FBAA5CA8F24A40EEEE01BA2F795340C2FBAA5CA8F24A40
41303	Романовка	5	52	232	77.273871	77.284920999999997	53.866900999999999	53.851309000000001	0103000020E61000000100000005000000A9143B1A875153402EE57CB1F7EC4A40A9143B1A8751534052EFA99CF6EE4A40643C4A253C52534052EFA99CF6EE4A40643C4A253C5253402EE57CB1F7EC4A40A9143B1A875153402EE57CB1F7EC4A40
41213	Районная	5	52	232	77.423899000000006	77.435388000000003	53.784156000000003	53.781379000000001	0103000020E61000000100000005000000A8734529215B5340FE63213A04E44A40A8734529215B5340297B4B395FE44A408944A165DD5B5340297B4B395FE44A408944A165DD5B5340FE63213A04E44A40A8734529215B5340FE63213A04E44A40
41343	Подольск	5	52	232	77.212974000000003	77.235594000000006	53.960951999999999	53.955866	0103000020E610000001000000050000007E39B35DA14D5340DEAD2CD159FA4A407E39B35DA14D53404D83A27900FB4A409148DBF8134F53404D83A27900FB4A409148DBF8134F5340DEAD2CD159FA4A407E39B35DA14D5340DEAD2CD159FA4A40
45571	Петрушино	5	52	232	77.556436000000005	77.582964000000004	53.849513999999999	53.829473999999998	0103000020E610000001000000050000004B94BDA59C635340EF703B342CEA4A404B94BDA59C63534040BFEFDFBCEC4A40B4AF3C484F65534040BFEFDFBCEC4A40B4AF3C484F655340EF703B342CEA4A404B94BDA59C635340EF703B342CEA4A40
45499	Первомайский	5	52	232	77.417412999999996	77.433977999999996	54.153905999999999	54.146613000000002	0103000020E6100000010000000500000037FB03E5B65A53409015FC36C4124B4037FB03E5B65A53403F541A31B3134B40BE4BA94BC65B53403F541A31B3134B40BE4BA94BC65B53409015FC36C4124B4037FB03E5B65A53409015FC36C4124B40
13381	Палецкое	5	52	232	78.130334000000005	78.172653999999994	54.125892999999998	54.111469999999997	0103000020E61000000100000005000000A4E36A6457885340183E22A6440E4B40A4E36A6457885340CDE506431D104B4082E15CC30C8B5340CDE506431D104B4082E15CC30C8B5340183E22A6440E4B40A4E36A6457885340183E22A6440E4B40
45612	Осинники	5	52	232	78.019006000000005	78.030081999999993	54.207790000000003	54.200591000000003	0103000020E61000000100000005000000611BF164378153409C6F44F7AC194B40611BF16437815340CA37DBDC981A4B40B08C0DDDEC815340CA37DBDC981A4B40B08C0DDDEC8153409C6F44F7AC194B40611BF164378153409C6F44F7AC194B40
12916	Нижний Баган	5	52	232	77.390347000000006	77.404692999999995	54.088382000000003	54.084083	0103000020E61000000100000005000000DFC5FB71FB5853402593533BC30A4B40DFC5FB71FB5853400DC7F319500B4B40E3FA777DE65953400DC7F319500B4B40E3FA777DE65953402593533BC30A4B40DFC5FB71FB5853402593533BC30A4B40
41227	Мироновка	5	52	232	77.730377000000004	77.763130000000004	53.848329	53.837434000000002	0103000020E610000001000000050000000A302C7FBE6E53407C478D0931EB4A400A302C7FBE6E5340CB9F6F0B96EC4A402D26361FD7705340CB9F6F0B96EC4A402D26361FD77053407C478D0931EB4A400A302C7FBE6E53407C478D0931EB4A40
12765	Лозовское	5	52	232	77.621150999999998	77.632936999999998	54.106544999999997	54.095632000000002	0103000020E610000001000000050000002CB81FF0C0675340BD395CAB3D0C4B402CB81FF0C0675340B2463D44A30D4B406ADB300A82685340B2463D44A30D4B406ADB300A82685340BD395CAB3D0C4B402CB81FF0C0675340BD395CAB3D0C4B40
41349	Кузнецовка	5	52	232	77.541390000000007	77.567916999999994	53.916716000000001	53.904947	0103000020E610000001000000050000006A183E22A662534081CEA44DD5F34A406A183E22A662534027DC2BF356F54A40EA758BC05864534027DC2BF356F54A40EA758BC05864534081CEA44DD5F34A406A183E22A662534081CEA44DD5F34A40
41391	Красный Остров	5	52	232	78.305567999999994	78.314577999999997	54.115918999999998	54.105452	0103000020E6100000010000000500000010AD156D8E9353401EA67D737F0D4B4010AD156D8E93534015FE0C6FD60E4B40A182C30B2294534015FE0C6FD60E4B40A182C30B229453401EA67D737F0D4B4010AD156D8E9353401EA67D737F0D4B40
12775	Караси	5	52	232	77.652968999999999	77.663767000000007	54.078690000000002	54.06814	0103000020E6100000010000000500000051137D3ECA69534054C6BFCFB8084B4051137D3ECA695340D9429083120A4B40804A95287B6A5340D9429083120A4B40804A95287B6A534054C6BFCFB8084B4051137D3ECA69534054C6BFCFB8084B40
41231	Казанка	5	52	232	77.418132	77.438353000000006	53.991014999999997	53.974384000000001	0103000020E610000001000000050000004F5AB8ACC25A534072DF6A9DB8FC4A404F5AB8ACC25A5340376C5B94D9FE4A40A0C6BDF90D5C5340376C5B94D9FE4A40A0C6BDF90D5C534072DF6A9DB8FC4A404F5AB8ACC25A534072DF6A9DB8FC4A40
41232	Кавказское	5	52	232	77.979201000000003	77.994095999999999	53.963324999999998	53.955956	0103000020E6100000010000000500000079CDAB3AAB7E53401E3526C45CFA4A4079CDAB3AAB7E5340A835CD3B4EFB4A406745D4449F7F5340A835CD3B4EFB4A406745D4449F7F53401E3526C45CFA4A4079CDAB3AAB7E53401E3526C45CFA4A40
12413	Грушевка	5	52	232	77.168273999999997	77.182610999999994	53.921340000000001	53.914292000000003	0103000020E6100000010000000500000018B14F00C54A53404A7F2F8507F54A4018B14F00C54A5340923F1878EEF54A40F3380CE6AF4B5340923F1878EEF54A40F3380CE6AF4B53404A7F2F8507F54A4018B14F00C54A53404A7F2F8507F54A40
906	Гнедухино	5	52	232	77.692656999999997	77.712059999999994	54.165399000000001	54.160707000000002	0103000020E610000001000000050000001C96067E546C5340809E060C92144B401C96067E546C534043E55FCB2B154B408B321B64926D534043E55FCB2B154B408B321B64926D5340809E060C92144B401C96067E546C5340809E060C92144B40
12864	Водино	5	52	232	77.509517000000002	77.521932000000007	54.026276000000003	54.016818000000001	0103000020E6100000010000000500000063F030ED9B605340F8FD9B1727024B4063F030ED9B605340B95510035D034B4019AF795567615340B95510035D034B4019AF795567615340F8FD9B1727024B4063F030ED9B605340F8FD9B1727024B40
13979	Бронзовка	5	52	232	78.105791999999994	78.117317	53.953042000000003	53.945338	0103000020E610000001000000050000006B0BCF4BC586534041D5E8D500F94A406B0BCF4BC586534073DBBE47FDF94A40F390291F8287534073DBBE47FDF94A40F390291F8287534041D5E8D500F94A406B0BCF4BC586534041D5E8D500F94A40
31382	Бочаниха	5	52	232	77.660865000000001	77.685057	54.186252000000003	54.181573999999998	0103000020E610000001000000050000008C84B69C4B6A5340E6E61BD13D174B408C84B69C4B6A53404568041BD7174B4056B950F9D76B53404568041BD7174B4056B950F9D76B5340E6E61BD13D174B408C84B69C4B6A5340E6E61BD13D174B40
41309	Большие Луки	5	52	232	78.194733999999997	78.204696999999996	54.042589999999997	54.027428999999998	0103000020E61000000100000005000000D55A9885768C534022FB20CB82034B40D55A9885768C53407D91D09673054B40B72572C1198D53407D91D09673054B40B72572C1198D534022FB20CB82034B40D55A9885768C534022FB20CB82034B40
12043	Баган	5	52	232	77.633718000000002	77.697453999999993	54.108873000000003	54.084622000000003	0103000020E61000000100000005000000BD38F1D58E685340D542C9E4D40A4B40BD38F1D58E6853406E35EB8CEF0D4B40B81D1A16A36C53406E35EB8CEF0D4B40B81D1A16A36C5340D542C9E4D40A4B40BD38F1D58E685340D542C9E4D40A4B40
41219	Александро-Невский	5	52	232	77.379405000000006	77.406695999999997	54.024191999999999	54.015607000000003	0103000020E6100000010000000500000017BCE82B485853405A4B0169FF014B4017BCE82B48585340946934B918034B407FDAA84E075A5340946934B918034B407FDAA84E075A53405A4B0169FF014B4017BCE82B485853405A4B0169FF014B40
11875	III Интернационал	5	52	232	77.298817	77.312246999999999	53.756137000000003	53.751339999999999	0103000020E61000000100000005000000499F56D11F5353409C16BCE82BE04A40499F56D11F535340D525E318C9E04A408B51D7DAFB535340D525E318C9E04A408B51D7DAFB5353409C16BCE82BE04A40499F56D11F5353409C16BCE82BE04A40
59636	с.Туруханск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59833	с.Зотино	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51807	с. Вознесенка	5	49	\N	93.242512000000005	93.298370000000006	56.031387000000002	55.990352999999999	0103000020E61000000100000005000000CE380D51854F57406C3F19E3C3FE4B40CE380D51854F574081423D7D04044C40E2067C7E1853574081423D7D04044C40E2067C7E185357406C3F19E3C3FE4B40CE380D51854F57406C3F19E3C3FE4B40
59701	с. Ванавара	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59593	с. Богучаны	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59905	п.Суломай	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
60815	п. Хета	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59631	п. Невонка	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59498	п. Гремучий	5	49	\N	94.078601000000006	94.107922000000002	55.067149000000001	55.06521	0103000020E61000000100000005000000B51B7DCC07855740A3AF20CD58884B40B51B7DCC07855740C47AA35698884B403621AD31E8865740C47AA35698884B403621AD31E8865740A3AF20CD58884B40B51B7DCC07855740A3AF20CD58884B40
59893	Юкта	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
15627	Шивера	5	49	\N	93.468429999999998	93.510058000000001	56.336848000000003	56.312969000000002	0103000020E61000000100000005000000C79DD2C1FA5D5740B7D4415E0F284C40C79DD2C1FA5D57408CDCD3D51D2B4C400B444FCAA46057408CDCD3D51D2B4C400B444FCAA4605740B7D4415E0F284C40C79DD2C1FA5D5740B7D4415E0F284C40
48592	Шахтинский	5	49	\N	95.674045000000007	95.695165000000003	56.302028	56.287677000000002	0103000020E6100000010000000500000012C2A38D23EB5740DC679599D2244C4012C2A38D23EB5740F73C7FDAA8264C40BA1457957DEC5740F73C7FDAA8264C40BA1457957DEC5740DC679599D2244C4012C2A38D23EB5740DC679599D2244C40
51737	Шарыпово	5	49	\N	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
59633	Чистое Поле	5	49	\N	91.166640999999998	91.199725000000001	55.253675999999999	55.241339000000004	0103000020E610000001000000050000000E4B033FAACA5640EB1F4432E49E4B400E4B033FAACA5640DAE3857478A04B4064CC5D4BC8CC5640DAE3857478A04B4064CC5D4BC8CC5640EB1F4432E49E4B400E4B033FAACA5640EB1F4432E49E4B40
6946	Чечеул	5	49	\N	95.687691000000001	95.739127999999994	56.142240000000001	56.118540000000003	0103000020E610000001000000050000003AB01C2103EC574049A297512C0F4C403AB01C2103EC57406E179AEB34124C40B4E386DF4DEF57406E179AEB34124C40B4E386DF4DEF574049A297512C0F4C403AB01C2103EC574049A297512C0F4C40
59871	Чемдальск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59495	Хатанга	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59781	Фарково	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59668	Уяр	5	49	\N	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
59662	Усть-Мана	5	49	\N	92.458499000000003	92.499713	55.951794	55.930902000000003	0103000020E61000000100000005000000EB8F300C581D5740F8E3F6CB27F74B40EB8F300C581D5740B743C362D4F94B40B5183C4CFB1F5740B743C362D4F94B40B5183C4CFB1F5740F8E3F6CB27F74B40EB8F300C581D5740F8E3F6CB27F74B40
51753	Ужур	5	49	\N	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
59465	Тура	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51876	Тура	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
17183	Топольки	5	49	\N	91.632902000000001	91.650948999999997	53.667907	53.654957000000003	0103000020E61000000100000005000000ACE4637781E85640A5A487A1D5D34A40ACE4637781E856407EE200FA7DD54A404A97FE25A9E956407EE200FA7DD54A404A97FE25A9E95640A5A487A1D5D34A40ACE4637781E85640A5A487A1D5D34A40
13809	Терентьево	5	49	\N	93.279190999999997	93.316757999999993	56.128489999999999	56.104697000000002	0103000020E610000001000000050000009A95ED43DE515740A27E17B6660D4C409A95ED43DE51574078EE3D5C72104C40C4AF58C34554574078EE3D5C72104C40C4AF58C345545740A27E17B6660D4C409A95ED43DE515740A27E17B6660D4C40
59645	Тасеево	5	49	\N	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
59607	Талнах	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
25896	Сухая Балка	5	49	\N	92.886347999999998	92.927851000000004	56.151381999999998	56.132710000000003	0103000020E610000001000000050000000038F6ECB938574014ED2AA4FC104C400038F6ECB9385740FE99417C60134C40E62329E9613B5740FE99417C60134C40E62329E9613B574014ED2AA4FC104C400038F6ECB938574014ED2AA4FC104C40
59895	Суринда	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51907	Стрелка	5	49	\N	95.804013999999995	95.822311999999997	55.552799999999998	55.541749000000003	0103000020E61000000100000005000000ACE122F774F3574003D2FE0758C54B40ACE122F774F35740499D8026C2C64B40EFC682C2A0F45740499D8026C2C64B40EFC682C2A0F4574003D2FE0758C54B40ACE122F774F3574003D2FE0758C54B40
9531	Старцево	5	49	\N	92.964393999999999	92.995565999999997	56.177145000000003	56.151682000000001	0103000020E610000001000000050000005A9D9CA1B83D574029B2D6506A134C405A9D9CA1B83D574031D3F6AFAC164C409CC0745AB73F574031D3F6AFAC164C409CC0745AB73F574029B2D6506A134C405A9D9CA1B83D574029B2D6506A134C40
3083	Сосновоборск	5	49	\N	93.305969000000005	93.410838999999996	56.155718999999998	56.099521000000003	0103000020E61000000100000005000000C02500FF94535740F321A81ABD0C4C40C02500FF94535740D32EA699EE134C40F73AA92F4B5A5740D32EA699EE134C40F73AA92F4B5A5740F321A81ABD0C4C40C02500FF94535740F321A81ABD0C4C40
51796	Сорокино	5	49	\N	93.382199999999997	93.398522999999997	55.887498000000001	55.874192999999998	0103000020E61000000100000005000000FF21FDF67558574031B2648EE5EF4B40FF21FDF675585740F9A1D28899F14B400BED9C6681595740F9A1D28899F14B400BED9C668159574031B2648EE5EF4B40FF21FDF67558574031B2648EE5EF4B40
51908	Снежногорск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
24874	Снежница	5	49	\N	92.389741999999998	92.426770000000005	56.097045999999999	56.082912999999998	0103000020E610000001000000050000002BF86D88F1185740E5B4A7E49C0A4C402BF86D88F1185740931ADA006C0C4C407E3A1E33501B5740931ADA006C0C4C407E3A1E33501B5740E5B4A7E49C0A4C402BF86D88F1185740E5B4A7E49C0A4C40
60820	Село Туруханск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51798	Село Богучаны	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
17053	Селиваниха	5	49	\N	91.594076999999999	91.628878	53.705275999999998	53.680159000000003	0103000020E610000001000000050000009293895B05E65640408A3A730FD74A409293895B05E65640AC53E57B46DA4A4021CB82893FE85640AC53E57B46DA4A4021CB82893FE85640408A3A730FD74A409293895B05E65640408A3A730FD74A40
59605	Северо-Енисейский	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
47800	Свищево	5	49	\N	93.200247000000005	93.227663000000007	55.890476999999997	55.875298999999998	0103000020E61000000100000005000000D107CBD8D04C57405A9C31CC09F04B40D107CBD8D04C57408B6B7C26FBF14B4098E0D407924E57408B6B7C26FBF14B4098E0D407924E57405A9C31CC09F04B40D107CBD8D04C57405A9C31CC09F04B40
59688	Светлогорск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
10388	Причулымский	5	49	\N	90.420553999999996	90.445804999999993	56.400512999999997	56.378514000000003	0103000020E61000000100000005000000ED0C535BEA9A5640018A912573304C40ED0C535BEA9A5640B94F8E0244334C402BD9B111889C5640B94F8E0244334C402BD9B111889C5640018A912573304C40ED0C535BEA9A5640018A912573304C40
25797	Придорожный	5	49	\N	92.967501999999996	93.006516000000005	56.235045	56.219673	0103000020E610000001000000050000002234828DEB3D57403868AF3E1E1C4C402234828DEB3D57404E0B5EF4151E4C40A6B915C26A4057404E0B5EF4151E4C40A6B915C26A4057403868AF3E1E1C4C402234828DEB3D57403868AF3E1E1C4C40
16851	Преображенка	5	49	\N	90.560484000000002	90.589751000000007	56.36307	56.345868000000003	0103000020E610000001000000050000009A7B48F8DEA35640D15D1267452C4C409A7B48F8DEA356405114E813792E4C402272FA7ABEA556405114E813792E4C402272FA7ABEA55640D15D1267452C4C409A7B48F8DEA35640D15D1267452C4C40
59915	Поселок Сыромолотово	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51884	Попигай	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59620	Подтесово	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
6241	Подгорный	5	49	\N	93.422354999999996	93.451514000000003	56.130552000000002	56.114514999999997	0103000020E61000000100000005000000551344DD075B574062F3716DA80E4C40551344DD075B5740B5368DEDB5104C40EAEBF99AE55C5740B5368DEDB5104C40EAEBF99AE55C574062F3716DA80E4C40551344DD075B574062F3716DA80E4C40
26231	Погорелка	5	49	\N	92.956354000000005	93.004341999999994	56.349573999999997	56.325952999999998	0103000020E61000000100000005000000865968E7343D57403C84F1D3B8294C40865968E7343D574015C440D7BE2C4C40F3FFAA234740574015C440D7BE2C4C40F3FFAA23474057403C84F1D3B8294C40865968E7343D57403C84F1D3B8294C40
59784	Погодаево	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59602	Пинчуга	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
24564	Памяти 13 Борцов	5	49	\N	92.282859999999999	92.350960999999998	56.231938	56.200158000000002	0103000020E610000001000000050000002E56D4601A125740320400C79E194C402E56D4601A1257408E59F624B01D4C40F94A2025761657408E59F624B01D4C40F94A202576165740320400C79E194C402E56D4601A125740320400C79E194C40
45449	Орловка	5	49	\N	90.620168000000007	90.640047999999993	56.246440999999997	56.231383000000001	0103000020E61000000100000005000000A6811FD5B0A75640D9EC48F59D1D4C40A6811FD5B0A756405FB2F1608B1F4C40B1F7E28BF6A856405FB2F1608B1F4C40B1F7E28BF6A85640D9EC48F59D1D4C40A6811FD5B0A75640D9EC48F59D1D4C40
18240	Овсянка	5	49	\N	92.518623000000005	92.599425999999994	55.965550999999998	55.955030000000001	0103000020E6100000010000000500000005FD851E3121574075594C6C3EFA4B4005FD851E312157405FCFD72C97FB4B40D097DEFE5C2657405FCFD72C97FB4B40D097DEFE5C26574075594C6C3EFA4B4005FD851E3121574075594C6C3EFA4B40
51757	Норильск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59609	Норильск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
6422	Новый Путь	5	49	\N	93.434599000000006	93.485336000000004	56.175967999999997	56.157738999999999	0103000020E61000000100000005000000F5F75278D05B5740E126A3CA30144C40F5F75278D05B57403E92921E86164C4093E4B9BE0F5F57403E92921E86164C4093E4B9BE0F5F5740E126A3CA30144C40F5F75278D05B5740E126A3CA30144C40
51860	Новорыбная	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
7257	Новокурск	5	49	\N	89.307811000000001	89.342746000000005	55.762535	55.754578000000002	0103000020E610000001000000050000005796E82CB3535640FB230C0396E04B405796E82CB3535640168733BF9AE14B406E35EB8CEF555640168733BF9AE14B406E35EB8CEF555640FB230C0396E04B405796E82CB3535640FB230C0396E04B40
51788	Назарово	5	49	\N	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
745	Минусинск	5	49	\N	91.619247999999999	91.777989000000005	53.767735000000002	53.665063000000004	0103000020E6100000010000000500000042075DC2A1E75640CC63CDC820D54A4042075DC2A1E756404E7FF62345E24A4075E95F92CAF156404E7FF62345E24A4075E95F92CAF15640CC63CDC820D54A4042075DC2A1E75640CC63CDC820D54A40
24861	Минино	5	49	\N	92.499390000000005	92.567132000000001	56.067314000000003	56.037775000000003	0103000020E61000000100000005000000C47C7901F61F57409FCDAACFD5044C40C47C7901F61F57400F48C2BE9D084C40F72004E44B2457400F48C2BE9D084C40F72004E44B2457409FCDAACFD5044C40C47C7901F61F57409FCDAACFD5044C40
51791	Минжуль	5	49	\N	93.126423000000003	93.148512999999994	56.284658999999998	56.263531999999998	0103000020E61000000100000005000000959D7E501748574088B9A46ABB214C40959D7E50174857408BC1C3B46F244C40F981AB3C814957408BC1C3B46F244C40F981AB3C8149574088B9A46ABB214C40959D7E501748574088B9A46ABB214C40
59614	Манзя	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59756	Малое Озеро	5	49	\N	89.326361000000006	89.346896000000001	55.135154999999997	55.121659000000001	0103000020E61000000100000005000000276C3F19E3545640CD21A985928F4B40276C3F19E3545640087250C24C914B403FC7478B33565640087250C24C914B403FC7478B33565640CD21A985928F4B40276C3F19E3545640CD21A985928F4B40
49346	Лопатино	5	49	\N	93.240472999999994	93.267071999999999	55.968620000000001	55.948346999999998	0103000020E610000001000000050000008BA4DDE8634F57403E213B6F63F94B408BA4DDE8634F574032207BBDFBFB4B40596B28B51751574032207BBDFBFB4B40596B28B5175157403E213B6F63F94B408BA4DDE8634F57403E213B6F63F94B40
3405	Лесосибирск	5	49	\N	92.276337999999996	92.632277999999999	58.335619000000001	58.087421999999997	0103000020E6100000010000000500000017299485AF115740B779E3A4300B4D4017299485AF11574047753A90F52A4D40BDFE243E7728574047753A90F52A4D40BDFE243E77285740B779E3A4300B4D4017299485AF115740B779E3A4300B4D40
59743	Левоборежное	5	49	\N	95.569525999999996	95.611091000000002	56.240367999999997	56.230072	0103000020E61000000100000005000000300E2E1D73E45740D7DCD1FF721D4C40300E2E1D73E45740A180ED60C41E4C4051F86C1D1CE75740A180ED60C41E4C4051F86C1D1CE75740D7DCD1FF721D4C40300E2E1D73E45740D7DCD1FF721D4C40
59647	Лакино	5	49	\N	92.998512000000005	93.019569000000004	56.803238	56.792597000000001	0103000020E61000000100000005000000782AE09EE73F574030F488D173654C40782AE09EE73F5740C573B680D0664C40FDC0559E40415740C573B680D0664C40FDC0559E4041574030F488D173654C40782AE09EE73F574030F488D173654C40
46862	Курбатово	5	49	\N	90.424964000000003	90.455911	56.361693000000002	56.347873	0103000020E610000001000000050000008D7E349C329B5640A9143B1A872C4C408D7E349C329B56409818CBF44B2E4C40BFB854A52D9D56409818CBF44B2E4C40BFB854A52D9D5640A9143B1A872C4C408D7E349C329B5640A9143B1A872C4C40
59669	Кулаково	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
13985	Кузнецово	5	49	\N	93.029567	93.081030999999996	55.960115000000002	55.928542	0103000020E610000001000000050000009D82FC6CE4415740317BD976DAF64B409D82FC6CE441574014B35E0CE5FA4B4094BDA59C2F45574014B35E0CE5FA4B4094BDA59C2F455740317BD976DAF64B409D82FC6CE4415740317BD976DAF64B40
26135	Куваршино	5	49	\N	93.363901999999996	93.394175000000004	56.255491999999997	56.228164999999997	0103000020E61000000100000005000000BC3C9D2B4A575740C18BBE82341D4C40BC3C9D2B4A575740DF313CF6B3204C40A779C7293A595740DF313CF6B3204C40A779C7293A595740C18BBE82341D4C40BC3C9D2B4A575740C18BBE82341D4C40
51742	Кресты	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
25689	Красный Пахарь	5	49	\N	93.053416999999996	93.078202000000005	56.291314	56.276922999999996	0103000020E610000001000000050000003A03232F6B4357404E417E3672234C403A03232F6B435740F86EF3C649254C40D61EF64201455740F86EF3C649254C40D61EF642014557404E417E3672234C403A03232F6B4357404E417E3672234C40
1225	Красноярск	5	49	\N	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
6912	Краснополянск	5	49	\N	95.555773000000002	95.571916000000002	56.183588999999998	56.175953	0103000020E61000000100000005000000FDBFEAC891E357400951BEA085164C40FDBFEAC891E35740E27327D87F174C40C90391459AE45740E27327D87F174C40C90391459AE457400951BEA085164C40FDBFEAC891E357400951BEA085164C40
59612	Красногорьевский	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51789	Кодинск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51854	Кислокан	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
13664	Киндяково	5	49	\N	93.294721999999993	93.343931999999995	56.077497999999999	56.050541000000003	0103000020E6100000010000000500000059DAA9B9DC525740B70DA32078064C4059DAA9B9DC525740B1C05774EB094C4010035DFB02565740B1C05774EB094C4010035DFB02565740B70DA32078064C4059DAA9B9DC525740B70DA32078064C40
7605	Кедровый	5	49	\N	92.292544000000007	92.350583999999998	56.251922	56.222594999999998	0103000020E610000001000000050000000729780AB912574066A032FE7D1C4C400729780AB91257404B92E7FA3E204C400EA0DFF76F1657404B92E7FA3E204C400EA0DFF76F16574066A032FE7D1C4C400729780AB912574066A032FE7D1C4C40
1037	Канск	5	49	\N	95.604381000000004	95.801192999999998	56.276743000000003	56.155267000000002	0103000020E61000000100000005000000B954A52DAEE65740F392FFC9DF134C40B954A52DAEE65740CF328B506C234C402F3201BF46F35740CF328B506C234C402F3201BF46F35740F392FFC9DF134C40B954A52DAEE65740F392FFC9DF134C40
24992	Каменный Яр	5	49	\N	92.280381000000006	92.313851999999997	56.121155000000002	56.107624000000001	0103000020E61000000100000005000000DE5A26C3F1115740E2218C9FC60D4C40DE5A26C3F11157409A5FCD01820F4C4030F2B226161457409A5FCD01820F4C4030F2B22616145740E2218C9FC60D4C40DE5A26C3F1115740E2218C9FC60D4C40
49394	Каменка	5	49	\N	90.416349999999994	90.443648999999994	56.170982000000002	56.161223	0103000020E61000000100000005000000226C787AA59A5640772E8CF4A2144C40226C787AA59A5640331AF9BCE2154C40CC79C6BE649C5640331AF9BCE2154C40CC79C6BE649C5640772E8CF4A2144C40226C787AA59A5640772E8CF4A2144C40
30713	Иркутское	5	49	\N	93.107360999999997	93.139951999999994	56.386453000000003	56.367133000000003	0103000020E610000001000000050000006AF7AB00DF4657402524D236FE2E4C406AF7AB00DF4657407638BA4A77314C40A0C03BF9F44857407638BA4A77314C40A0C03BF9F44857402524D236FE2E4C406AF7AB00DF4657402524D236FE2E4C40
59468	Игарка	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
1592	Зыково	5	49	\N	93.119803000000005	93.199528000000001	55.981701000000001	55.931103999999998	0103000020E610000001000000050000009DBD33DAAA4757405F96766A2EF74B409DBD33DAAA475740AAB9DC60A8FD4B40B9A81611C54C5740AAB9DC60A8FD4B40B9A81611C54C57405F96766A2EF74B409DBD33DAAA4757405F96766A2EF74B40
48555	Зеленый Луг	5	49	\N	95.761208999999994	95.780845999999997	56.167799000000002	56.156058999999999	0103000020E61000000100000005000000EF1AF4A5B7F057408C9FC6BDF9134C40EF1AF4A5B7F0574098A608707A154C40984D8061F9F1574098A608707A154C40984D8061F9F157408C9FC6BDF9134C40EF1AF4A5B7F057408C9FC6BDF9134C40
59489	Зеленогорск	5	49	\N	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
59598	Заозерный	5	49	\N	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
51733	Железногорск	5	49	\N	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
51877	Жданиха	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
11422	Есаулово	5	49	\N	93.254324999999994	93.301720000000003	56.150202999999998	56.122148000000003	0103000020E6100000010000000500000088635DDC46505740CBA2B08BA20F4C4088635DDC465057406B6116DA39134C40252367614F5357406B6116DA39134C40252367614F535740CBA2B08BA20F4C4088635DDC46505740CBA2B08BA20F4C40
47515	Ермолаево	5	49	\N	93.132891000000001	93.175848000000002	56.153793	56.120793999999997	0103000020E61000000100000005000000B2BB404981485740C9C6832D760F4C40B2BB40498148574047AD307DAF134C404A44F817414B574047AD307DAF134C404A44F817414B5740C9C6832D760F4C40B2BB404981485740C9C6832D760F4C40
59478	Енисейск	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
1330	Емельяново	5	49	\N	92.597423000000006	92.741377999999997	56.200183000000003	56.153908999999999	0103000020E6100000010000000500000035B8AD2D3C265740B0C7444AB3134C4035B8AD2D3C2657408B1BB7989F194C4054FEB5BC722F57408B1BB7989F194C4054FEB5BC722F5740B0C7444AB3134C4035B8AD2D3C265740B0C7444AB3134C40
51811	Дудинка	5	49	\N	96.314993000000001	96.372502999999995	55.814619	55.801955999999997	0103000020E61000000100000005000000035E66D8281458405D6A847EA6E64B40035E66D828145840A1D9756F45E84B405CAAD216D7175840A1D9756F45E84B405CAAD216D71758405D6A847EA6E64B40035E66D8281458405D6A847EA6E64B40
25495	Дрокино	5	49	\N	92.727121999999994	92.781739999999999	56.122534999999999	56.078181000000001	0103000020E61000000100000005000000EF8CB62A892E57409415C3D5010A4C40EF8CB62A892E5740C4CE143AAF0F4C40677E350708325740C4CE143AAF0F4C40677E3507083257409415C3D5010A4C40EF8CB62A892E57409415C3D5010A4C40
51734	Додоново	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
17601	Дивногорск	5	49	\N	92.292867000000001	92.481891000000005	55.971505999999998	55.929107000000002	0103000020E61000000100000005000000F8C43A55BE1257400ABE69FAECF64B40F8C43A55BE12574013EF004F5AFC4B40274F594DD71E574013EF004F5AFC4B40274F594DD71E57400ABE69FAECF64B40F8C43A55BE1257400ABE69FAECF64B40
59752	Горошиха	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
10919	Горный	5	49	\N	90.535978	90.571183000000005	56.253222000000001	56.233404	0103000020E610000001000000050000000858AB764DA25640B760A92EE01D4C400858AB764DA256405950189469204C40FF4124438EA456405950189469204C40FF4124438EA45640B760A92EE01D4C400858AB764DA25640B760A92EE01D4C40
51889	Говорково	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
8248	Вознесенка	5	49	\N	93.242512000000005	93.298370000000006	56.031387000000002	55.990352999999999	0103000020E61000000100000005000000CE380D51854F57406C3F19E3C3FE4B40CE380D51854F574081423D7D04044C40E2067C7E1853574081423D7D04044C40E2067C7E185357406C3F19E3C3FE4B40CE380D51854F57406C3F19E3C3FE4B40
59617	Верхнепашино	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59496	Вернепашино	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59625	Ванавара	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
25325	Бугачево	5	49	\N	92.625495999999998	92.702552999999995	56.057574000000002	56.033304000000001	0103000020E61000000100000005000000D8F15F2008285740BA69334E43044C40D8F15F2008285740CA8CB7955E074C403AADDBA0F62C5740CA8CB7955E074C403AADDBA0F62C5740BA69334E43044C40D8F15F2008285740BA69334E43044C40
17249	Бородино	5	49	\N	94.868858000000003	94.935081999999994	55.920805000000001	55.893667000000001	0103000020E610000001000000050000008DB7955E9BB75740D94125AE63F24B408DB7955E9BB75740247F30F0DCF54B4002452C62D8BB5740247F30F0DCF54B4002452C62D8BB5740D94125AE63F24B408DB7955E9BB75740D94125AE63F24B40
29937	Большие Пруды	5	49	\N	93.430530000000005	93.466301000000001	56.403094000000003	56.387644000000002	0103000020E610000001000000050000009A7CB3CD8D5B5740CD3E8F519E314C409A7CB3CD8D5B57405F9B8D9598334C40E54526E0D75D57405F9B8D9598334C40E54526E0D75D5740CD3E8F519E314C409A7CB3CD8D5B5740CD3E8F519E314C40
59867	Боготол	5	49	\N	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
59886	Боготол	5	49	\N	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
1148	Березовка	5	49	\N	93.078138999999993	93.184391000000005	56.059780000000003	56.001714999999997	0103000020E61000000100000005000000B262B83A00455740D174763238004C40B262B83A004557403A7AFCDEA6074C4050ABE80FCD4B57403A7AFCDEA6074C4050ABE80FCD4B5740D174763238004C40B262B83A00455740D174763238004C40
48664	Бережки	5	49	\N	95.626129000000006	95.644248000000005	56.237957000000002	56.227445000000003	0103000020E61000000100000005000000F1845E7F12E85740C251F2EA1C1D4C40F1845E7F12E85740596DFE5F751E4C40DCA0F65B3BE95740596DFE5F751E4C40DCA0F65B3BE95740C251F2EA1C1D4C40F1845E7F12E85740C251F2EA1C1D4C40
13618	Бархатово	5	49	\N	93.340339	93.374205000000003	56.051772999999997	56.030844000000002	0103000020E610000001000000050000006AA33A1DC855574090A339B2F2034C406AA33A1DC85557406CE8667FA0064C40FB3F87F9F25757406CE8667FA0064C40FB3F87F9F257574090A339B2F2034C406AA33A1DC855574090A339B2F2034C40
59628	Балахта	5	49	\N	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
51896	Байкит	5	49	\N	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
3300	Ачинск	5	49	\N	90.303836000000004	90.601096999999996	56.336078999999998	56.189749999999997	0103000020E610000001000000050000003DD68C0C729356403F355EBA49184C403DD68C0C72935640AAEFFCA2042B4C40512E8D5F78A65640AAEFFCA2042B4C40512E8D5F78A656403F355EBA49184C403DD68C0C729356403F355EBA49184C40
59643	Артёмовск	5	49	\N	93.413811999999993	93.457165000000003	54.364609000000002	54.329546000000001	0103000020E610000001000000050000004FAC53E57B5A5740894336902E2A4B404FAC53E57B5A5740E469F981AB2E4B400EF8FC30425D5740E469F981AB2E4B400EF8FC30425D5740894336902E2A4B404FAC53E57B5A5740894336902E2A4B40
4815	Анцирь	5	49	\N	95.502843999999996	95.558441000000002	56.265296999999997	56.249080999999997	0103000020E6100000010000000500000059BF99982EE057400987DEE2E11F4C4059BF99982EE057400B5D8940F5214C40B7EF517FBDE357400B5D8940F5214C40B7EF517FBDE357400987DEE2E11F4C4059BF99982EE057400987DEE2E11F4C40
59857	п.Оскоба	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51883	Эконда	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59817	Учами	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59911	Тутончаны	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59820	Тура	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51754	Полигус	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51831	Нидым	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59854	Мирюга	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59797	Куюмба	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59717	Ванавара	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59872	Бурный	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59640	Байкит	5	49	7119	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
8427	Шушенское	5	49	994	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
59878	Шушенское	5	49	994	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
32605	Шунеры	5	49	994	91.579228000000001	91.601433999999998	53.131276999999997	53.122976999999999	0103000020E610000001000000050000005C3B511212E556408194D8B5BD8F4A405C3B511212E55640C6DB4AAFCD904A40F52C08E57DE65640C6DB4AAFCD904A40F52C08E57DE656408194D8B5BD8F4A405C3B511212E556408194D8B5BD8F4A40
32612	Шарып	5	49	994	91.621988000000002	91.636827999999994	53.106437999999997	53.089297999999999	0103000020E6100000010000000500000049A0C1A6CEE7564092CCEA1D6E8B4A4049A0C1A6CEE756409C86A8C29F8D4A40554B3ACAC1E856409C86A8C29F8D4A40554B3ACAC1E8564092CCEA1D6E8B4A4049A0C1A6CEE7564092CCEA1D6E8B4A40
32640	Субботино	5	49	994	91.905478000000002	91.936892	53.090201	53.056361000000003	0103000020E61000000100000005000000D74FFF59F3F956408BE255D636874A40D74FFF59F3F956408388D4B48B8B4A4094F8DC09F6FB56408388D4B48B8B4A4094F8DC09F6FB56408BE255D636874A40D74FFF59F3F956408BE255D636874A40
32652	Средняя Шушь	5	49	994	91.953654999999998	91.985042000000007	53.044992999999998	53.032296000000002	0103000020E61000000100000005000000AE2AFBAE08FD564054E57B4622844A40AE2AFBAE08FD564043C6A354C2854A40EFCB99ED0AFF564043C6A354C2854A40EFCB99ED0AFF564054E57B4622844A40AE2AFBAE08FD564054E57B4622844A40
32717	Синеборск	5	49	994	92.083783999999994	92.112449999999995	53.490031999999999	53.479064000000001	0103000020E6100000010000000500000065FB90B75C05574071581AF851BD4A4065FB90B75C0557402AFF5A5EB9BE4A40DA1B7C61320757402AFF5A5EB9BE4A40DA1B7C613207574071581AF851BD4A4065FB90B75C05574071581AF851BD4A40
32634	Сизая	5	49	994	91.497372999999996	91.540546000000006	53.011333999999998	52.987563999999999	0103000020E61000000100000005000000753A90F5D4DF56407D5A457F687E4A40753A90F5D4DF56409BAA7B6473814A40F4FE3F4E98E256409BAA7B6473814A40F4FE3F4E98E256407D5A457F687E4A40753A90F5D4DF56407D5A457F687E4A40
32617	Саянск	5	49	994	91.473622000000006	91.486206999999993	53.143009999999997	53.135058999999998	0103000020E61000000100000005000000A22AA6D24FDE5640E603029D49914A40A22AA6D24FDE56401F80D4264E924A408505F7031EDF56401F80D4264E924A408505F7031EDF5640E603029D49914A40A22AA6D24FDE5640E603029D49914A40
32619	Новопокровка	5	49	994	91.681025000000005	91.707111999999995	53.150382	53.139206999999999	0103000020E610000001000000050000008AB0E1E995EB5640E82FF488D1914A408AB0E1E995EB56401BF4A5B73F934A40FCA6B05241ED56401BF4A5B73F934A40FCA6B05241ED5640E82FF488D1914A408AB0E1E995EB5640E82FF488D1914A40
32684	Нижняя Коя	5	49	994	91.909188	91.935445999999999	53.459687000000002	53.451515999999998	0103000020E610000001000000050000009A7ADD2230FA564074CFBA46CBB94A409A7ADD2230FA5640BCB20B06D7BA4A40234BE658DEFB5640BCB20B06D7BA4A40234BE658DEFB564074CFBA46CBB94A409A7ADD2230FA564074CFBA46CBB94A40
32645	Майский	5	49	994	91.852935000000002	91.887512000000001	53.036400999999998	53.029744999999998	0103000020E6100000010000000500000048A7AE7C96F65640191C25AFCE834A4048A7AE7C96F656405645B8C9A8844A40AFB321FFCCF856405645B8C9A8844A40AFB321FFCCF85640191C25AFCE834A4048A7AE7C96F65640191C25AFCE834A40
32690	Лыткино	5	49	994	92.027783999999997	92.043009999999995	53.505614000000001	53.497686999999999	0103000020E6100000010000000500000088D68A36C70157407A522635B4BF4A4088D68A36C70157402B33A5F5B7C04A40A9D903ADC00257402B33A5F5B7C04A40A9D903ADC00257407A522635B4BF4A4088D68A36C70157407A522635B4BF4A40
32659	Ленск	5	49	994	91.805899999999994	91.829238000000004	53.059229000000002	53.04148	0103000020E610000001000000050000002BF697DD93F3564013B875374F854A402BF697DD93F35640C6FCDCD094874A406EA6423C12F55640C6FCDCD094874A406EA6423C12F5564013B875374F854A402BF697DD93F3564013B875374F854A40
32693	Козлово	5	49	994	92.047385000000006	92.058972999999995	53.397897	53.393188000000002	0103000020E610000001000000050000008B54185B08035740FF9600FC53B24A408B54185B080357409816F549EEB24A403596B036C60357409816F549EEB24A403596B036C6035740FF9600FC53B24A408B54185B08035740FF9600FC53B24A40
32599	Каптырево	5	49	994	91.777540000000002	91.819948999999994	53.211083000000002	53.184460999999999	0103000020E610000001000000050000003DD52137C3F156409831056B9C974A403DD52137C3F15640ECDE8AC4049B4A40D3D85E0B7AF45640ECDE8AC4049B4A40D3D85E0B7AF456409831056B9C974A403DD52137C3F156409831056B9C974A40
59906	Казанцево	5	49	994	91.990224999999995	92.022994999999995	53.417473000000001	53.398305000000001	0103000020E610000001000000050000009FABADD85FFF5640A96A82A8FBB24A409FABADD85FFF564044FB58C16FB54A402D3E05C07801574044FB58C16FB54A402D3E05C078015740A96A82A8FBB24A409FABADD85FFF5640A96A82A8FBB24A40
32559	Ильичево	5	49	994	91.827225999999996	91.868898000000002	53.281556000000002	53.265110999999997	0103000020E61000000100000005000000A8195245F1F45640A9674128EFA14A40A8195245F1F456400DFFE9060AA44A40D4635B069CF756400DFFE9060AA44A40D4635B069CF75640A9674128EFA14A40A8195245F1F45640A9674128EFA14A40
32630	Иджа	5	49	994	91.954445000000007	91.987179999999995	53.190795999999999	53.173586999999998	0103000020E610000001000000050000002B357BA015FD564060014C1938964A402B357BA015FD5640931ADA006C984A40FAD005F52DFF5640931ADA006C984A40FAD005F52DFF564060014C1938964A402B357BA015FD564060014C1938964A40
9006	Зарничный	5	49	994	91.965917000000005	91.986155999999994	53.248600000000003	53.240636000000002	0103000020E61000000100000005000000A1698995D1FD5640C11E1329CD9E4A40A1698995D1FD56408FE4F21FD29F4A4044300E2E1DFF56408FE4F21FD29F4A4044300E2E1DFF5640C11E1329CD9E4A40A1698995D1FD5640C11E1329CD9E4A40
32582	Ермолаево	5	49	994	91.998157000000006	92.016419999999997	53.237779000000003	53.231419000000002	0103000020E6100000010000000500000081D1E5CDE1FF5640265646239F9D4A4081D1E5CDE1FF56407A56D28A6F9E4A4005C078060D0157407A56D28A6F9E4A4005C078060D015740265646239F9D4A4081D1E5CDE1FF5640265646239F9D4A40
32721	Дубенское	5	49	994	92.295795999999996	92.316349000000002	53.475645	53.458067999999997	0103000020E6100000010000000500000068925852EE1257400CACE3F8A1BA4A4068925852EE125740C2C073EFE1BC4A40D447E00F3F145740C2C073EFE1BC4A40D447E00F3F1457400CACE3F8A1BA4A4068925852EE1257400CACE3F8A1BA4A40
32733	Весёлые Ключи	5	49	994	92.359666000000004	92.371245000000002	53.450133000000001	53.447445999999999	0103000020E61000000100000005000000ECDE8AC404175740EE5C18E945B94A40ECDE8AC404175740D9EC48F59DB94A406D73637AC2175740D9EC48F59DB94A406D73637AC2175740EE5C18E945B94A40ECDE8AC404175740EE5C18E945B94A40
32670	Белозеровка	5	49	994	91.732641999999998	91.747949000000006	53.103324000000001	53.078816000000003	0103000020E61000000100000005000000446B459BE3EE5640663387A4168A4A40446B459BE3EE56402A7288B8398D4A40DC847B65DEEF56402A7288B8398D4A40DC847B65DEEF5640663387A4168A4A40446B459BE3EE5640663387A4168A4A40
9090	Алтан	5	49	994	91.881403000000006	91.892273000000003	53.244774	53.236545	0103000020E610000001000000050000002AE620E868F856402384471B479E4A402AE620E868F856409F7422C1549F4A40A58636001BF956409F7422C1549F4A40A58636001BF956402384471B479E4A402AE620E868F856402384471B479E4A40
7740	Шушь	5	49	566	89.441399000000004	89.463255000000004	55.606878000000002	55.590674	0103000020E610000001000000050000002D5F97E13F5C56407B4CA4349BCB4B402D5F97E13F5C5640B954A52DAECD4B4058AD4CF8A55D5640B954A52DAECD4B4058AD4CF8A55D56407B4CA4349BCB4B402D5F97E13F5C56407B4CA4349BCB4B40
4113	Шарыпово	5	49	566	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
7815	Холмогорское	5	49	566	89.103480000000005	89.142368000000005	55.480587	55.441346000000003	0103000020E6100000010000000500000091F2936A9F465640371C96067EB84B4091F2936A9F465640FEF0F3DF83BD4B40CEFFAB8E1C495640FEF0F3DF83BD4B40CEFFAB8E1C495640371C96067EB84B4091F2936A9F465640371C96067EB84B40
8031	Темра	5	49	566	89.259589000000005	89.275362999999999	55.443480999999998	55.425123999999997	0103000020E61000000100000005000000B0592E1B9D505640525F96766AB64B40B0592E1B9D505640DDB243FCC3B84B40D2E1218C9F515640DDB243FCC3B84B40D2E1218C9F515640525F96766AB64B40B0592E1B9D505640525F96766AB64B40
20505	Сютик	5	49	566	89.752601999999996	89.770847000000003	55.899467000000001	55.891430999999997	0103000020E61000000100000005000000DE3994A12A705640FED137691AF24B40DE3994A12A705640666A12BC21F34B4010CEA78E55715640666A12BC21F34B4010CEA78E55715640FED137691AF24B40DE3994A12A705640FED137691AF24B40
7319	Скрипачи	5	49	566	89.374250000000004	89.388155999999995	55.797038000000001	55.788707000000002	0103000020E61000000100000005000000CBA145B6F35756402A90D959F4E44B40CBA145B6F3575640AAD5575705E64B40C16F438CD7585640AAD5575705E64B40C16F438CD75856402A90D959F4E44B40CBA145B6F35756402A90D959F4E44B40
5698	Сартачуль	5	49	566	89.213092000000003	89.230277000000001	55.252167999999998	55.244798000000003	0103000020E6100000010000000500000083C2A04CA34D56402810768A559F4B4083C2A04CA34D5640828C800A47A04B405801BEDBBC4E5640828C800A47A04B405801BEDBBC4E56402810768A559F4B4083C2A04CA34D56402810768A559F4B40
48226	Росинка	5	49	566	89.331166999999994	89.349124000000003	55.692048999999997	55.689999	0103000020E61000000100000005000000ECA012D731555640E8A221E351D84B40ECA012D731555640601DC70F95D84B40EB8F300C58565640601DC70F95D84B40EB8F300C58565640E8A221E351D84B40ECA012D731555640E8A221E351D84B40
33057	Родники	5	49	566	89.190202999999997	89.208546999999996	55.650947000000002	55.629623000000002	0103000020E61000000100000005000000782634492C4C56409BE7887C97D04B40782634492C4C5640F436363B52D34B40732B84D5584D5640F436363B52D34B40732B84D5584D56409BE7887C97D04B40782634492C4C56409BE7887C97D04B40
8176	Парная	5	49	566	89.207207999999994	89.259777999999997	55.299219000000001	55.276589999999999	0103000020E610000001000000050000000DDE57E5424D56404833164D67A34B400DDE57E5424D5640C1ABE5CE4CA64B40198EE733A0505640C1ABE5CE4CA64B40198EE733A05056404833164D67A34B400DDE57E5424D56404833164D67A34B40
8280	Ораки	5	49	566	89.502843999999996	89.530125999999996	55.335991	55.313741	0103000020E6100000010000000500000059BF99982E605640093543AA28A84B4059BF99982E6056400B60CAC001AB4B4098309A95ED6156400B60CAC001AB4B4098309A95ED615640093543AA28A84B4059BF99982E605640093543AA28A84B40
7176	Новоалтатка	5	49	566	89.473827999999997	89.486512000000005	55.728985999999999	55.719920999999999	0103000020E6100000010000000500000076FBAC32535E5640105A0F5F26DC4B4076FBAC32535E5640F59ECA694FDD4B4024473A03235F5640F59ECA694FDD4B4024473A03235F5640105A0F5F26DC4B4076FBAC32535E5640105A0F5F26DC4B40
51880	Никольск	5	49	566	89.150560999999996	89.172191999999995	55.702094000000002	55.688445999999999	0103000020E6100000010000000500000065C39ACAA2495640F0879FFF1ED84B4065C39ACAA2495640E25B5837DED94B4080289831054B5640E25B5837DED94B4080289831054B5640F0879FFF1ED84B4065C39ACAA2495640F0879FFF1ED84B40
7803	Можары	5	49	566	89.566714000000005	89.608135000000004	55.511409	55.498111999999999	0103000020E61000000100000005000000DD0BCC0A4564564061DF4E22C2BF4B40DD0BCC0A45645640A6F0A0D975C14B40642310AFEB665640A6F0A0D975C14B40642310AFEB66564061DF4E22C2BF4B40DD0BCC0A4564564061DF4E22C2BF4B40
48427	Линево	5	49	566	89.073773000000003	89.089806999999993	55.392986000000001	55.372871000000004	0103000020E61000000100000005000000FB9463B2B84456403C50A73CBAAF4B40FB9463B2B844564097E4805D4DB24B40EBFCDB65BF45564097E4805D4DB24B40EBFCDB65BF4556403C50A73CBAAF4B40FB9463B2B84456403C50A73CBAAF4B40
48138	Крутоярский	5	49	566	89.617568000000006	89.635587999999998	55.725442999999999	55.720529999999997	0103000020E6100000010000000500000098C3EE3B86675640B8E4B8533ADC4B4098C3EE3B866756405A0EF450DBDC4B40B96E4A79AD6856405A0EF450DBDC4B40B96E4A79AD685640B8E4B8533ADC4B4098C3EE3B86675640B8E4B8533ADC4B40
8258	Косые Ложки	5	49	566	89.208411999999996	89.221266999999997	55.381695000000001	55.369473999999997	0103000020E610000001000000050000000306499F564D5640745C8DEC4AAF4B400306499F564D5640FB05BB61DBB04B40C72B103D294E5640FB05BB61DBB04B40C72B103D294E5640745C8DEC4AAF4B400306499F564D5640745C8DEC4AAF4B40
7673	Инголь	5	49	566	88.702219999999997	88.718200999999993	55.520252999999997	55.513209000000003	0103000020E6100000010000000500000037A6272CF12C5640A6811FD5B0C14B4037A6272CF12C5640AC527AA697C24B4016BD5301F72D5640AC527AA697C24B4016BD5301F72D5640A6811FD5B0C14B4037A6272CF12C5640A6811FD5B0C14B40
7610	Ивановка	5	49	566	88.765569999999997	88.807080999999997	55.579531000000003	55.558090999999997	0103000020E610000001000000050000001E335019FF3056409198A0866FC74B401E335019FF305640540262122ECA4B40450E1137A7335640540262122ECA4B40450E1137A73356409198A0866FC74B401E335019FF3056409198A0866FC74B40
47983	Ершово	5	49	566	89.38485	89.398747	55.952050999999997	55.943244999999997	0103000020E6100000010000000500000066F7E461A1585640C98E8D40BCF84B4066F7E461A1585640E28FA2CEDCF94B403318231285595640E28FA2CEDCF94B403318231285595640C98E8D40BCF84B4066F7E461A1585640C98E8D40BCF84B40
7462	Дубинино	5	49	566	89.074662000000004	89.123412999999999	55.638587000000001	55.611739	0103000020E6100000010000000500000041102043C74456400858AB764DCE4B4041102043C74456404C530438BDD14B40AEB9A3FFE54756404C530438BDD14B40AEB9A3FFE54756400858AB764DCE4B4041102043C74456400858AB764DCE4B40
7029	Гудково	5	49	566	89.606222000000002	89.617216999999997	55.901622000000003	55.888967000000001	0103000020E6100000010000000500000068075C57CC665640931CB0ABC9F14B4068075C57CC66564054AD855968F34B404162BB7B8067564054AD855968F34B404162BB7B80675640931CB0ABC9F14B4068075C57CC665640931CB0ABC9F14B40
59650	Горячегорск	5	49	566	88.879852999999997	88.933851000000004	55.416054000000003	55.379694999999998	0103000020E610000001000000050000006612F5824F38564034BA83D899B04B406612F5824F3856405CAFE94141B54B409015FC36C43B56405CAFE94141B54B409015FC36C43B564034BA83D899B04B406612F5824F38564034BA83D899B04B40
7152	Горбы	5	49	566	89.720963999999995	89.740035000000006	55.773468999999999	55.756780999999997	0103000020E61000000100000005000000F9653046246E5640F99D2633DEE04B40F9653046246E564023BC3D0801E34B404EB9C2BB5C6F564023BC3D0801E34B404EB9C2BB5C6F5640F99D2633DEE04B40F9653046246E5640F99D2633DEE04B40
59875	Гляден	5	49	566	89.287599	89.313713000000007	55.503261999999999	55.489911999999997	0103000020E6100000010000000500000030D7A205685256407FF5B86FB5BE4B4030D7A20568525640E7A8A3E36AC04B4020D5B0DF13545640E7A8A3E36AC04B4020D5B0DF135456407FF5B86FB5BE4B4030D7A205685256407FF5B86FB5BE4B40
7327	Глинка	5	49	566	89.515231999999997	89.533647000000002	55.777844000000002	55.760590999999998	0103000020E610000001000000050000009276A38FF9605640E350BF0B5BE14B409276A38FF9605640E6B1666490E34B40F226BF4527625640E6B1666490E34B40F226BF4527625640E350BF0B5BE14B409276A38FF9605640E350BF0B5BE14B40
59753	Большое Озеро	5	49	566	89.307828999999998	89.325587999999996	55.195241000000003	55.182448999999998	0103000020E61000000100000005000000AAF06778B35356400D18247D5A974B40AAF06778B35356404FEB36A8FD984B4015FE0C6FD65456404FEB36A8FD984B4015FE0C6FD65456400D18247D5A974B40AAF06778B35356400D18247D5A974B40
8105	Береш	5	49	566	89.140642999999997	89.162598000000003	55.493986999999997	55.476587000000002	0103000020E61000000100000005000000535A7F4B00495640715985CD00BD4B40535A7F4B0049564017D34CF73ABF4B4048197101684A564017D34CF73ABF4B4048197101684A5640715985CD00BD4B40535A7F4B00495640715985CD00BD4B40
6932	Березовское	5	49	566	89.562500999999997	89.609527999999997	55.858761000000001	55.835493	0103000020E61000000100000005000000E8BD310400645640BA84436FF1EA4B40E8BD310400645640460A65E1EBED4B40C37FBA8102675640460A65E1EBED4B40C37FBA8102675640BA84436FF1EA4B40E8BD310400645640BA84436FF1EA4B40
48159	Белоозерка	5	49	566	89.532964000000007	89.560426000000007	55.657778999999998	55.644044000000001	0103000020E61000000100000005000000817C09151C625640AF97A60870D24B40817C09151C6256406F7F2E1A32D44B4000750305DE6356406F7F2E1A32D44B4000750305DE635640AF97A60870D24B40817C09151C625640AF97A60870D24B40
45910	Александровка	5	49	566	89.739791999999994	89.760830999999996	55.806159999999998	55.799021000000003	0103000020E61000000100000005000000EA758BC0586F56409BE8F35146E64B40EA758BC0586F5640F3AB394030E74B401CB28174B1705640F3AB394030E74B401CB28174B17056409BE8F35146E64B40EA758BC0586F56409BE8F35146E64B40
7953	Ажинское	5	49	566	89.199203999999995	89.219300000000004	55.552667999999997	55.539425999999999	0103000020E61000000100000005000000DF4E22C2BF4C5640594E42E90BC54B40DF4E22C2BF4C5640DAC534D3BDC64B40D200DE02094E5640DAC534D3BDC64B40D200DE02094E5640594E42E90BC54B40DF4E22C2BF4C5640594E42E90BC54B40
5070	Уяр	5	49	729	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
28218	Татьяновка	5	49	729	94.592123000000001	94.616934999999998	55.815367000000002	55.802076999999997	0103000020E61000000100000005000000670DDE57E5A55740D8EF8975AAE64B40670DDE57E5A557406B9E23F25DE84B407F30F0DC7BA757406B9E23F25DE84B407F30F0DC7BA75740D8EF8975AAE64B40670DDE57E5A55740D8EF8975AAE64B40
51741	Сушиновка	5	49	729	94.192283000000003	94.224604999999997	55.787255000000002	55.769286000000001	0103000020E61000000100000005000000EA245B5D4E8C5740A5A2B1F677E24B40EA245B5D4E8C5740664E97C5C4E44B402861A6ED5F8E5740664E97C5C4E44B402861A6ED5F8E5740A5A2B1F677E24B40EA245B5D4E8C5740A5A2B1F677E24B40
59834	Сухоной	5	49	729	94.154779000000005	94.181369000000004	55.618878000000002	55.601441999999999	0103000020E61000000100000005000000E3C62DE6E78957406D382C0DFCCC4B40E3C62DE6E7895740611BF16437CF4B4087E0B88C9B8B5740611BF16437CF4B4087E0B88C9B8B57406D382C0DFCCC4B40E3C62DE6E78957406D382C0DFCCC4B40
6213	Семеновка	5	49	729	94.140837000000005	94.178278000000006	55.707765000000002	55.694220999999999	0103000020E6100000010000000500000046443179038957402499D53BDCD84B4046443179038957407120240B98DA4B402AE620E8688B57407120240B98DA4B402AE620E8688B57402499D53BDCD84B4046443179038957402499D53BDCD84B40
6834	Покровка	5	49	729	94.536373999999995	94.561733000000004	55.725002000000003	55.717883	0103000020E610000001000000050000002E1B9DF353A257405CAD1397E3DB4B402E1B9DF353A257406EC493DDCCDC4B406005F86EF3A357406EC493DDCCDC4B406005F86EF3A357405CAD1397E3DB4B402E1B9DF353A257405CAD1397E3DB4B40
6664	Ольгино	5	49	729	94.284163000000007	94.317346999999998	55.874875000000003	55.863712	0103000020E61000000100000005000000EEEE01BA2F925740D594641D8EEE4B40EEEE01BA2F925740448B6CE7FBEF4B40F59ECA694F945740448B6CE7FBEF4B40F59ECA694F945740D594641D8EEE4B40EEEE01BA2F925740D594641D8EEE4B40
32942	Новопятницкое	5	49	729	94.460475000000002	94.499353999999997	55.860700999999999	55.846451000000002	0103000020E610000001000000050000000A68226C789D57405055A18158EC4B400A68226C789D574037514B732BEE4B401DC87A6AF59F574037514B732BEE4B401DC87A6AF59F57405055A18158EC4B400A68226C789D57405055A18158EC4B40
6310	Новониколаевка	5	49	729	94.362739000000005	94.383066999999997	55.633485	55.622532999999997	0103000020E61000000100000005000000F67EA31D3797574023D74D29AFCF4B40F67EA31D37975740D7C0560916D14B40514B732B84985740D7C0560916D14B40514B732B8498574023D74D29AFCF4B40F67EA31D3797574023D74D29AFCF4B40
6161	Новомихайловка	5	49	729	94.100977999999998	94.110895999999997	55.788640999999998	55.770921999999999	0103000020E6100000010000000500000064E76D6C768657402AE27492ADE24B4064E76D6C7686574072A43330F2E44B40765089EB1887574072A43330F2E44B40765089EB188757402AE27492ADE24B4064E76D6C768657402AE27492ADE24B40
6638	Новоалександровка	5	49	729	94.505526000000003	94.520869000000005	55.872329000000001	55.858184999999999	0103000020E61000000100000005000000C651B9895AA0574079758E01D9ED4B40C651B9895AA057401B2D077AA8EF4B400420EEEA55A157401B2D077AA8EF4B400420EEEA55A1574079758E01D9ED4B40C651B9895AA0574079758E01D9ED4B40
5940	Никольское	5	49	729	94.018477000000004	94.048300999999995	55.904795999999997	55.893101999999999	0103000020E610000001000000050000009BAE27BA2E81574000FF942A51F24B409BAE27BA2E8157409BC6F65AD0F34B404DD7135D178357409BC6F65AD0F34B404DD7135D1783574000FF942A51F24B409BAE27BA2E81574000FF942A51F24B40
6347	Николаевка	5	49	729	94.376024999999998	94.396631999999997	55.716225000000001	55.709859999999999	0103000020E610000001000000050000009E5E29CB10985740895E46B1DCDA4B409E5E29CB10985740EFC9C342ADDB4B4003232F6B62995740EFC9C342ADDB4B4003232F6B62995740895E46B1DCDA4B409E5E29CB10985740895E46B1DCDA4B40
5992	Марьевка	5	49	729	94.131682999999995	94.152991	55.856684000000001	55.845227999999999	0103000020E610000001000000050000001B9C887E6D885740EDD45C6E30EC4B401B9C887E6D885740D48041D2A7ED4B404565C39ACA895740D48041D2A7ED4B404565C39ACA895740EDD45C6E30EC4B401B9C887E6D885740EDD45C6E30EC4B40
6021	Каменно-Горновка	5	49	729	94.174541000000005	94.210627000000002	55.89987	55.880141999999999	0103000020E61000000100000005000000EAB303AE2B8B574003EB387EA8F04B40EAB303AE2B8B57406553AEF02EF34B40E529ABE97A8D57406553AEF02EF34B40E529ABE97A8D574003EB387EA8F04B40EAB303AE2B8B574003EB387EA8F04B40
5895	Жандат	5	49	729	93.922537000000005	93.932302000000007	55.894460000000002	55.886367	0103000020E610000001000000050000006616A1D80A7B574077A04E7974F14B406616A1D80A7B574043CA4FAA7DF24B40B5FF01D6AA7B574043CA4FAA7DF24B40B5FF01D6AA7B574077A04E7974F14B406616A1D80A7B574077A04E7974F14B40
59642	Громадск	5	49	729	94.373923000000005	94.421192000000005	55.908586	55.887836	0103000020E61000000100000005000000390EBC5AEE975740111B2C9CA4F14B40390EBC5AEE9757403ECDC98B4CF44B408F554ACFF49A57403ECDC98B4CF44B408F554ACFF49A5740111B2C9CA4F14B40390EBC5AEE975740111B2C9CA4F14B40
59777	Восточное	5	49	729	94.470490999999996	94.502786	55.632784000000001	55.619365999999999	0103000020E61000000100000005000000FD8348861C9E57408E20956247CF4B40FD8348861C9E57404EB7EC10FFD04B40BFB854A52DA057404EB7EC10FFD04B40BFB854A52DA057408E20956247CF4B40FD8348861C9E57408E20956247CF4B40
6448	Воронино	5	49	729	94.538179	94.571254999999994	55.675336000000001	55.664212999999997	0103000020E610000001000000050000003719558671A25740FD497CEE04D54B403719558671A25740DEE7F86871D64B404BAB21718FA45740DEE7F86871D64B404BAB21718FA45740FD497CEE04D54B403719558671A25740FD497CEE04D54B40
40267	Балай	5	49	729	93.973813000000007	94.013257999999993	55.875703000000001	55.857931999999998	0103000020E61000000100000005000000DCDAC2F3527E57408F183DB7D0ED4B40DCDAC2F3527E57402A01310917F04B40431A1538D98057402A01310917F04B40431A1538D98057408F183DB7D0ED4B40DCDAC2F3527E57408F183DB7D0ED4B40
59811	Авда	5	49	729	94.612909999999999	94.628972000000005	55.742575000000002	55.733274999999999	0103000020E610000001000000050000000C59DDEA39A75740B9FC87F4DBDD4B400C59DDEA39A75740E2E995B20CDF4B406286C61341A85740E2E995B20CDF4B406286C61341A85740B9FC87F4DBDD4B400C59DDEA39A75740B9FC87F4DBDD4B40
4004	Яга	5	49	476	90.252919000000006	90.266249999999999	55.507249000000002	55.495756	0103000020E610000001000000050000005F622CD32F905640DC65BFEE74BF4B405F622CD32F905640E0F60489EDC04B40D7A3703D0A915640E0F60489EDC04B40D7A3703D0A915640DC65BFEE74BF4B405F622CD32F905640DC65BFEE74BF4B40
4187	Черноозерск	5	49	476	90.206942999999995	90.218073000000004	55.187137	55.180880999999999	0103000020E61000000100000005000000B648DA8D3E8D5640E0BBCD1B27974B40B648DA8D3E8D56408F6FEF1AF4974B4000C974E8F48D56408F6FEF1AF4974B4000C974E8F48D5640E0BBCD1B27974B40B648DA8D3E8D5640E0BBCD1B27974B40
10272	Ушканка	5	49	476	90.215881999999993	90.225700000000003	55.573073000000001	55.568237000000003	0103000020E61000000100000005000000E272BC02D18D564047B071FDBBC84B40E272BC02D18D56403D9CC0745AC94B4043AD69DE718E56403D9CC0745AC94B4043AD69DE718E564047B071FDBBC84B40E272BC02D18D564047B071FDBBC84B40
3737	Усть-Изыкчуль (Марьясово)	5	49	476	90.008470000000003	90.027980999999997	55.502206999999999	55.495282000000003	0103000020E61000000100000005000000D13FC1C58A80564014268C6665BF4B40D13FC1C58A8056404069A85148C04B4033FAD170CA8156404069A85148C04B4033FAD170CA81564014268C6665BF4B40D13FC1C58A80564014268C6665BF4B40
2845	Ужур	5	49	476	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
4829	Тургужан	5	49	476	89.994401999999994	90.013114000000002	55.138041999999999	55.125314000000003	0103000020E61000000100000005000000ED444948A47F564090DD054A0A904B40ED444948A47F5640BABC395CAB914B40AA471ADCD6805640BABC395CAB914B40AA471ADCD680564090DD054A0A904B40ED444948A47F564090DD054A0A904B40
3961	Терехта	5	49	476	90.189723000000001	90.199675999999997	55.435288999999997	55.429726000000002	0103000020E610000001000000050000002313F06B248C5640D61EF64201B74B402313F06B248C56407EA7C98CB7B74B40F372D87DC78C56407EA7C98CB7B74B40F372D87DC78C5640D61EF64201B74B402313F06B248C5640D61EF64201B74B40
4112	Тарханка	5	49	476	90.443918999999994	90.471829999999997	55.604264000000001	55.586709999999997	0103000020E61000000100000005000000ACC43C2B699C56403A1E335019CB4B40ACC43C2B699C56403813D38558CD4B4063D17476329E56403813D38558CD4B4063D17476329E56403A1E335019CB4B40ACC43C2B699C56403A1E335019CB4B40
10294	Тальники	5	49	476	90.631972000000005	90.649939000000003	55.282533000000001	55.273062000000003	0103000020E6100000010000000500000037FFAF3A72A85640E3E313B2F3A24B4037FFAF3A72A856403885950A2AA44B404759BF9998A956403885950A2AA44B404759BF9998A95640E3E313B2F3A24B4037FFAF3A72A85640E3E313B2F3A24B40
10136	Сухореченский	5	49	476	90.081044000000006	90.087143999999995	55.596493000000002	55.590938000000001	0103000020E610000001000000050000005F622CD32F85564059FB3BDBA3CB4B405F622CD32F8556407FA5F3E159CC4B40BA826DC4938556407FA5F3E159CC4B40BA826DC49385564059FB3BDBA3CB4B405F622CD32F85564059FB3BDBA3CB4B40
4948	Сухая Долина	5	49	476	89.773165000000006	89.786837000000006	55.236935000000003	55.229799	0103000020E610000001000000050000005C5A0D897B715640A6D3BA0D6A9D4B405C5A0D897B7156408E23D6E2539E4B40199293895B7256408E23D6E2539E4B40199293895B725640A6D3BA0D6A9D4B405C5A0D897B715640A6D3BA0D6A9D4B40
4236	Старая Кузурба	5	49	476	90.344376999999994	90.369726999999997	55.223323999999998	55.213793000000003	0103000020E61000000100000005000000A71FD4450A9656408F8EAB915D9B4B40A71FD4450A965640B9347EE1959C4B40AF5C6F9BA9975640B9347EE1959C4B40AF5C6F9BA99756408F8EAB915D9B4B40A71FD4450A9656408F8EAB915D9B4B40
51778	Солнечный	5	49	476	89.738966000000005	89.844626000000005	55.294801	55.26267	0103000020E61000000100000005000000C8B60C384B6F5640F6D1A92B9FA14B40C8B60C384B6F5640FFE9060ABCA54B407CD6355A0E765640FFE9060ABCA54B407CD6355A0E765640F6D1A92B9FA14B40C8B60C384B6F5640F6D1A92B9FA14B40
59573	Солнечный	5	49	476	89.738966000000005	89.844626000000005	55.294801	55.26267	0103000020E61000000100000005000000C8B60C384B6F5640F6D1A92B9FA14B40C8B60C384B6F5640FFE9060ABCA54B407CD6355A0E765640FFE9060ABCA54B407CD6355A0E765640F6D1A92B9FA14B40C8B60C384B6F5640F6D1A92B9FA14B40
4065	Солгон	5	49	476	90.373589999999993	90.399839	55.536409999999997	55.517898000000002	0103000020E61000000100000005000000350708E6E8975640F8544E7B4AC24B40350708E6E8975640A99F3715A9C44B40952A51F696995640A99F3715A9C44B40952A51F696995640F8544E7B4AC24B40350708E6E8975640F8544E7B4AC24B40
4968	Солбатский	5	49	476	89.706976999999995	89.722751000000002	55.178182	55.171041000000002	0103000020E610000001000000050000008C81751C3F6D564038A3E6ABE4954B408C81751C3F6D5640315EF3AACE964B40AF09698D416E5640315EF3AACE964B40AF09698D416E564038A3E6ABE4954B408C81751C3F6D564038A3E6ABE4954B40
4421	Приреченск	5	49	476	90.262090999999998	90.286741000000006	55.216977	55.203235999999997	0103000020E61000000100000005000000DC645419C690564057AF22A3039A4B40DC645419C6905640FA7DFFE6C59B4B40085BECF659925640FA7DFFE6C59B4B40085BECF65992564057AF22A3039A4B40DC645419C690564057AF22A3039A4B40
59803	Прилужье	5	49	476	89.839900999999998	89.856995999999995	55.176577999999999	55.164382000000003	0103000020E610000001000000050000002CB81FF0C07556408A0629780A954B402CB81FF0C0755640B7989F1B9A964B406133C005D9765640B7989F1B9A964B406133C005D97656408A0629780A954B402CB81FF0C07556408A0629780A954B40
5029	Озеро Учум	5	49	476	89.687753000000001	89.712322	55.085945000000002	55.071390999999998	0103000020E6100000010000000500000075AE2825046C5640471D1D5723894B4075AE2825046C56409B20EA3E008B4B402A8E03AF966D56409B20EA3E008B4B402A8E03AF966D5640471D1D5723894B4075AE2825046C5640471D1D5723894B40
3731	Новоракитка	5	49	476	90.140090999999998	90.148211000000003	55.586654000000003	55.582054999999997	0103000020E61000000100000005000000B1DD3D40F788564094BC3AC780CA4B40B1DD3D40F7885640A708707A17CB4B40147AFD497C895640A708707A17CB4B40147AFD497C89564094BC3AC780CA4B40B1DD3D40F788564094BC3AC780CA4B40
4679	Новая Кузурба	5	49	476	90.175493000000003	90.196173000000002	55.262829000000004	55.252799000000003	0103000020E6100000010000000500000053EBFD463B8B564013BBB6B75BA04B4053EBFD463B8B56405FB87361A4A14B40EDD632198E8C56405FB87361A4A14B40EDD632198E8C564013BBB6B75BA04B4053EBFD463B8B564013BBB6B75BA04B40
3527	Михайловка	5	49	476	89.879605999999995	89.920649999999995	55.594518999999998	55.582538	0103000020E6100000010000000500000062D7F6764B785640B056ED9A90CA4B4062D7F6764B785640E1ECD63219CC4B40FE43FAEDEB7A5640E1ECD63219CC4B40FE43FAEDEB7A5640B056ED9A90CA4B4062D7F6764B785640B056ED9A90CA4B40
11633	Марьясово	5	49	476	89.876892999999995	89.884574000000001	55.453288999999998	55.449235000000002	0103000020E61000000100000005000000D845D1031F785640FA9B508880B94B40D845D1031F7856407A51BB5F05BA4B40153944DC9C7856407A51BB5F05BA4B40153944DC9C785640FA9B508880B94B40D845D1031F785640FA9B508880B94B40
4285	Малый Имыш	5	49	476	90.502606	90.547387000000001	55.228242999999999	55.211846000000001	0103000020E610000001000000050000007F315BB22AA05640EBE40CC51D9B4B407F315BB22AA056403D450E11379D4B405BD07B6308A356403D450E11379D4B405BD07B6308A35640EBE40CC51D9B4B407F315BB22AA05640EBE40CC51D9B4B40
4720	Лопатка	5	49	476	90.155163999999999	90.179948999999993	55.327936000000001	55.315252999999998	0103000020E610000001000000050000000F61FC34EE895640A27BD6355AA84B400F61FC34EE8956402D978DCEF9A94B40AA7CCF48848B56402D978DCEF9A94B40AA7CCF48848B5640A27BD6355AA84B400F61FC34EE895640A27BD6355AA84B40
3429	Локшино	5	49	476	89.675841000000005	89.717658	55.479500000000002	55.464171999999998	0103000020E61000000100000005000000F1129CFA406B564005DCF3FC69BB4B40F1129CFA406B56404C37894160BD4B409EEDD11BEE6D56404C37894160BD4B409EEDD11BEE6D564005DCF3FC69BB4B40F1129CFA406B564005DCF3FC69BB4B40
3327	Кулун	5	49	476	89.762951000000001	89.790439000000006	55.347101000000002	55.323853999999997	0103000020E61000000100000005000000D55C6E30D4705640E256410C74A94B40D55C6E30D470564057B439CE6DAC4B40E99E758D9672564057B439CE6DAC4B40E99E758D96725640E256410C74A94B40D55C6E30D4705640E256410C74A94B40
3624	Крутояр	5	49	476	89.986524000000003	90.021765000000002	55.581485000000001	55.558804000000002	0103000020E61000000100000005000000062E8F35237F5640DF6FB4E386C74B40062E8F35237F5640AA0EB9196ECA4B40A3CC069964815640AA0EB9196ECA4B40A3CC069964815640DF6FB4E386C74B40062E8F35237F5640DF6FB4E386C74B40
51904	Корнилово	5	49	476	89.315697999999998	90.779996999999995	55.684797000000003	55.055697000000002	0103000020E61000000100000005000000685A6265345456401FBE4C1421874B40685A62653454564010B3976DA7D74B40997E8978EBB1564010B3976DA7D74B40997E8978EBB156401FBE4C1421874B40685A6265345456401FBE4C1421874B40
4620	Ильинка	5	49	476	90.014083999999997	90.053816999999995	55.295867000000001	55.280810000000002	0103000020E6100000010000000500000066D993C0E6805640E4310395F1A34B4066D993C0E68056409A7B48F8DEA54B4001BEDBBC718356409A7B48F8DEA54B4001BEDBBC71835640E4310395F1A34B4066D993C0E6805640E4310395F1A34B40
3921	Изыкчуль	5	49	476	90.049306999999999	90.070687000000007	55.452058000000001	55.444674999999997	0103000020E61000000100000005000000B01D8CD827835640A52C431CEBB84B40B01D8CD82783564095F25A09DDB94B402750C4228684564095F25A09DDB94B402750C42286845640A52C431CEBB84B40B01D8CD827835640A52C431CEBB84B40
4891	Златоруновск	5	49	476	89.794392000000002	89.816373999999996	55.138047999999998	55.125951999999998	0103000020E610000001000000050000000F0D8B51D7725640D26EF4311F904B400F0D8B51D77256409CA38E8EAB914B4080D3BB783F7456409CA38E8EAB914B4080D3BB783F745640D26EF4311F904B400F0D8B51D7725640D26EF4311F904B40
3832	Васильевка	5	49	476	89.899934999999999	89.914039000000002	55.434068000000003	55.418802999999997	0103000020E61000000100000005000000A661F88898795640BC3B32569BB54B40A661F88898795640BD1E4C8A8FB74B4030116F9D7F7A5640BD1E4C8A8FB74B4030116F9D7F7A5640BC3B32569BB54B40A661F88898795640BC3B32569BB54B40
4314	Большой Имыш	5	49	476	90.615667999999999	90.631056000000001	55.144314999999999	55.132370999999999	0103000020E61000000100000005000000664CC11A67A756402BF86D88F1904B40664CC11A67A756403FA9F6E978924B40747CB43863A856403FA9F6E978924B40747CB43863A856402BF86D88F1904B40664CC11A67A756402BF86D88F1904B40
4401	Березовый Лог	5	49	476	90.653684999999996	90.668425999999997	55.163307000000003	55.153430999999998	0103000020E61000000100000005000000B0389CF9D5A95640A69883A0A3934B40B0389CF9D5A956409C1A683EE7944B40F372D87DC7AA56409C1A683EE7944B40F372D87DC7AA5640A69883A0A3934B40B0389CF9D5A95640A69883A0A3934B40
4502	Белопольск	5	49	476	90.345284000000007	90.355615	55.146763999999997	55.141542000000001	0103000020E6100000010000000500000041F50F221996564056815A0C1E924B4041F50F2219965640751DAA29C9924B40E4BD6A65C2965640751DAA29C9924B40E4BD6A65C296564056815A0C1E924B4041F50F221996564056815A0C1E924B40
59858	Белая Роща	5	49	476	89.833082000000005	89.846270000000004	55.502170999999997	55.493966	0103000020E61000000100000005000000B9382A375175564000AB23473ABF4B40B9382A3751755640F3FFAA2347C04B408065A54929765640F3FFAA2347C04B408065A5492976564000AB23473ABF4B40B9382A375175564000AB23473ABF4B40
3413	Ашпан	5	49	476	89.547489999999996	89.574286999999998	55.379137999999998	55.366681	0103000020E61000000100000005000000C5387F130A63564044882B67EFAE4B40C5387F130A635640DE550F9887B04B4026E1421EC1645640DE550F9887B04B4026E1421EC164564044882B67EFAE4B40C5387F130A63564044882B67EFAE4B40
4573	Арабкаево	5	49	476	90.314138999999997	90.333651000000003	55.088521999999998	55.077942	0103000020E610000001000000050000007BD976DA1A9456400F7EE200FA894B407BD976DA1A945640FE7C5BB0548B4B40C651B9895A955640FE7C5BB0548B4B40C651B9895A9556400F7EE200FA894B407BD976DA1A9456400F7EE200FA894B40
3636	Андроново	5	49	476	90.028017000000006	90.047762000000006	55.557872000000003	55.550829999999998	0103000020E61000000100000005000000DAAED007CB815640EDD3F19881C64B40DAAED007CB81564054AD855968C74B4076FF58880E83564054AD855968C74B4076FF58880E835640EDD3F19881C64B40DAAED007CB815640EDD3F19881C64B40
10227	Алексеевка	5	49	476	89.948040000000006	89.960741999999996	55.624281000000003	55.618383999999999	0103000020E6100000010000000500000031D3F6AFAC7C5640512FF83427CF4B4031D3F6AFAC7C5640D1419770E8CF4B40317903CC7C7D5640D1419770E8CF4B40317903CC7C7D5640512FF83427CF4B4031D3F6AFAC7C5640512FF83427CF4B40
51825	Чиринда	5	49	336	89.396985999999998	89.409059999999997	57.505443	57.498693000000003	0103000020E6100000010000000500000012BEF7376859564040DF162CD5BF4C4012BEF73768595640FE7E315BB2C04C408386FE092E5A5640FE7E315BB2C04C408386FE092E5A564040DF162CD5BF4C4012BEF7376859564040DF162CD5BF4C40
2728	Чиндат	5	49	336	89.294758000000002	89.304935999999998	57.3962	57.371335999999999	0103000020E61000000100000005000000008FA850DD525640EAE923F087AF4C40008FA850DD5256406D567DAEB6B24C40E0D74812845356406D567DAEB6B24C40E0D7481284535640EAE923F087AF4C40008FA850DD525640EAE923F087AF4C40
1606	Тюхтет	5	49	336	89.288101999999995	89.352619000000004	56.549576999999999	56.514966999999999	0103000020E6100000010000000500000061FA5E437052564076C24B70EA414C4061FA5E437052564020D1048A58464C40B03C484F9156564020D1048A58464C40B03C484F9156564076C24B70EA414C4061FA5E437052564076C24B70EA414C40
2619	Сплавной	5	49	336	89.069756999999996	89.094631000000007	57.016325999999999	57.001745	0103000020E61000000100000005000000B16A10E6764456403CF71E2E39804C40B16A10E67644564089096AF816824C40058C2E6F0E46564089096AF816824C40058C2E6F0E4656403CF71E2E39804C40B16A10E6764456403CF71E2E39804C40
2274	Соловьёвка	5	49	336	89.205770999999999	89.233941999999999	56.578978999999997	56.570037999999997	0103000020E61000000100000005000000C6DD205A2B4D564016BD5301F7484C40C6DD205A2B4D56400F09DFFB1B4A4C404BCADDE7F84E56400F09DFFB1B4A4C404BCADDE7F84E564016BD5301F7484C40C6DD205A2B4D564016BD5301F7484C40
1799	Пузаново	5	49	336	89.303903000000005	89.320728000000003	56.434730000000002	56.422987999999997	0103000020E61000000100000005000000018A912573535640DB4C857824364C40018A912573535640884B8E3BA5374C4056BABBCE86545640884B8E3BA5374C4056BABBCE86545640DB4C857824364C40018A912573535640DB4C857824364C40
15664	Проточный	5	49	336	89.899000999999998	89.929067000000003	57.510384999999999	57.496133999999998	0103000020E6100000010000000500000090847D3B897956408237A45181BF4C4090847D3B897956403AAFB14B54C14C40BE326FD5757B56403AAFB14B54C14C40BE326FD5757B56408237A45181BF4C4090847D3B897956408237A45181BF4C40
1695	Покровка	5	49	336	89.228615000000005	89.248863	56.543021000000003	56.530383999999998	0103000020E610000001000000050000000118CFA0A14E56402C29779FE3434C400118CFA0A14E564047054EB681454C40CE8B135FED4F564047054EB681454C40CE8B135FED4F56402C29779FE3434C400118CFA0A14E56402C29779FE3434C40
2707	Поваренкино	5	49	336	88.941181	88.969757000000001	57.076877000000003	57.058537000000001	0103000020E6100000010000000500000076A73B4F3C3C5640904DF2237E874C4076A73B4F3C3C56404568041BD7894C404B04AA7F103E56404568041BD7894C404B04AA7F103E5640904DF2237E874C4076A73B4F3C3C5640904DF2237E874C40
2840	Пасечное	5	49	336	89.306426999999999	89.324510000000004	57.440854000000002	57.433141999999997	0103000020E6100000010000000500000021E7FD7F9C5356401343723271B74C4021E7FD7F9C535640C82764E76DB84C40664E97C5C4545640C82764E76DB84C40664E97C5C45456401343723271B74C4021E7FD7F9C5356401343723271B74C40
1809	Оскаровка	5	49	336	89.168876999999995	89.195978999999994	56.439055000000003	56.426597000000001	0103000020E61000000100000005000000FB027AE1CE4A56402EC901BB9A364C40FB027AE1CE4A5640991249F432384C40FAEC80EB8A4C5640991249F432384C40FAEC80EB8A4C56402EC901BB9A364C40FB027AE1CE4A56402EC901BB9A364C40
2151	Новомитрополька	5	49	336	89.626569000000003	89.658503999999994	56.539566999999998	56.531596	0103000020E61000000100000005000000FFEBDCB4196856409B5775560B444C40FFEBDCB4196856401B800D8810454C404012F6ED246A56401B800D8810454C404012F6ED246A56409B5775560B444C40FFEBDCB4196856409B5775560B444C40
2169	Никольск	5	49	336	89.780557999999999	89.796718999999996	56.552534000000001	56.547238999999998	0103000020E6100000010000000500000065A88AA9F4715640410C74ED0B464C4065A88AA9F4715640CBF6216FB9464C408446B071FD725640CBF6216FB9464C408446B071FD725640410C74ED0B464C4065A88AA9F4715640410C74ED0B464C40
2384	Леонтьевка	5	49	336	89.124140999999995	89.180456000000007	56.616262999999996	56.592109999999998	0103000020E61000000100000005000000EFC517EDF147564039D1AE42CA4B4C40EFC517EDF14756400F5EBBB4E14E4C407D9752978C4B56400F5EBBB4E14E4C407D9752978C4B564039D1AE42CA4B4C40EFC517EDF147564039D1AE42CA4B4C40
2030	Ларнёвка	5	49	336	89.469965000000002	89.498783000000003	56.524237999999997	56.517366000000003	0103000020E61000000100000005000000F05014E8135E5640FB07910C39424C40F05014E8135E564004A9143B1A434C404033880FEC5F564004A9143B1A434C404033880FEC5F5640FB07910C39424C40F05014E8135E5640FB07910C39424C40
1929	Лазарево	5	49	336	89.433520999999999	89.465878000000004	56.451712000000001	56.438487000000002	0103000020E610000001000000050000004548DDCEBE5B56404F5C8E5720384C404548DDCEBE5B5640FA9AE5B2D1394C40427BF5F1D05D5640FA9AE5B2D1394C40427BF5F1D05D56404F5C8E5720384C404548DDCEBE5B56404F5C8E5720384C40
2503	Красинка	5	49	336	89.364098999999996	89.399331000000004	56.861485999999999	56.843176	0103000020E610000001000000050000006760E4654D575640D462F030ED6B4C406760E4654D5756401EFB592C456E4C40DB519CA38E5956401EFB592C456E4C40DB519CA38E595640D462F030ED6B4C406760E4654D575640D462F030ED6B4C40
51885	Ивановка	5	49	336	89.094227000000004	89.105905000000007	56.570861999999998	56.565832999999998	0103000020E610000001000000050000009DD9AED007465640B0FF3A376D484C409DD9AED007465640BB438A0112494C40E8DEC325C7465640BB438A0112494C40E8DEC325C7465640B0FF3A376D484C409DD9AED007465640B0FF3A376D484C40
59759	Зареченка	5	49	336	89.263101000000006	89.305088999999995	56.592565999999998	56.579762000000002	0103000020E61000000100000005000000E0A293A5D650564056BB26A4354A4C40E0A293A5D65056405B5CE333D94B4C40A3570394865356405B5CE333D94B4C40A35703948653564056BB26A4354A4C40E0A293A5D650564056BB26A4354A4C40
1906	Двинка	5	49	336	88.957890000000006	88.984802999999999	56.490459999999999	56.478735	0103000020E6100000010000000500000097CADB114E3D5640AC394030473D4C4097CADB114E3D564082FFAD64C73E4C402C802903073F564082FFAD64C73E4C402C802903073F5640AC394030473D4C4097CADB114E3D5640AC394030473D4C40
2602	Верх-Четск	5	49	336	89.058079000000006	89.069783999999999	56.928066999999999	56.918928999999999	0103000020E610000001000000050000006765FB90B7435640492C29779F754C406765FB90B743564098BF42E6CA764C402E724F577744564098BF42E6CA764C402E724F5777445640492C29779F754C406765FB90B7435640492C29779F754C40
2048	Васильевка	5	49	336	89.530214999999998	89.571286000000001	56.529600000000002	56.520305	0103000020E610000001000000050000005036E50AEF615640FF78AF5A99424C405036E50AEF61564016FBCBEEC9434C4069AA27F38F64564016FBCBEEC9434C4069AA27F38F645640FF78AF5A99424C405036E50AEF615640FF78AF5A99424C40
2496	Безручейка	5	49	336	89.397542999999999	89.428175999999993	56.611266000000001	56.603686000000003	0103000020E610000001000000050000003DF0315871595640CB863595454D4C403DF03158715956401094DBF63D4E4C40A73B4F3C675B56401094DBF63D4E4C40A73B4F3C675B5640CB863595454D4C403DF0315871595640CB863595454D4C40
59823	д.Сургутиха	5	49	7483	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
59889	д.Старо-Туруханск	5	49	7483	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
60007	Советская Речка	5	49	7483	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
59869	Келлог	5	49	7483	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
59810	Верхнеимбатск	5	49	7483	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
59899	Верещагино	5	49	7483	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
59942	п.Муторай	5	49	7492	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
32141	Ялай	5	49	93	94.231459000000001	94.246380000000002	57.149230000000003	57.138536000000002	0103000020E610000001000000050000005AD76839D08E5740CAA8328CBB914C405AD76839D08E574082CAF8F719934C40DD989EB0C48F574082CAF8F719934C40DD989EB0C48F5740CAA8328CBB914C405AD76839D08E5740CAA8328CBB914C40
6460	Шивера	5	49	93	95.949082000000004	95.956799000000004	57.379351999999997	57.376271000000003	0103000020E610000001000000050000003ACE6DC2BDFC574074B7EBA529B04C403ACE6DC2BDFC57400AD6389B8EB04C401D76DF313CFD57400AD6389B8EB04C401D76DF313CFD574074B7EBA529B04C403ACE6DC2BDFC574074B7EBA529B04C40
9236	Чигашет	5	49	93	95.987314999999995	95.998660000000001	57.391364000000003	57.386105999999998	0103000020E610000001000000050000006AF6402B30FF57400A65E1EB6BB14C406AF6402B30FF5740776A2E3718B24C40B2F4A10BEAFF5740776A2E3718B24C40B2F4A10BEAFF57400A65E1EB6BB14C406AF6402B30FF57400A65E1EB6BB14C40
32162	Хандала	5	49	93	94.906704000000005	94.925685999999999	57.134394	57.124989999999997	0103000020E61000000100000005000000C1C9367007BA5740DC291DACFF8F4C40C1C9367007BA5740AA6395D233914C405D177E703EBB5740AA6395D233914C405D177E703EBB5740DC291DACFF8F4C40C1C9367007BA5740DC291DACFF8F4C40
32338	Фаначет	5	49	93	95.474107000000004	95.499251000000001	57.150464999999997	57.143116999999997	0103000020E6100000010000000500000080F3E2C457DE5740354069A851924C4080F3E2C457DE5740A818E76F42934C40B35F77BAF3DF5740A818E76F42934C40B35F77BAF3DF5740354069A851924C4080F3E2C457DE5740354069A851924C40
45422	Унжа	5	49	93	94.474812	94.512083000000004	57.219208999999999	57.210397	0103000020E61000000100000005000000E5EFDE51639E57409816F549EE9A4C40E5EFDE51639E574093FE5E0A0F9C4C409B75C6F7C5A0574093FE5E0A0F9C4C409B75C6F7C5A057409816F549EE9A4C40E5EFDE51639E57409816F549EE9A4C40
113	Троицк	5	49	93	94.816980999999998	94.863962000000001	57.421793000000001	57.40936	0103000020E61000000100000005000000041DAD6A49B45740312592E865B44C40041DAD6A49B4574043572250FDB54C4027BF45274BB7574043572250FDB54C4027BF45274BB75740312592E865B44C40041DAD6A49B45740312592E865B44C40
1549	Тасеево	5	49	93	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
32943	Сухово	5	49	93	94.628801999999993	94.656586000000004	57.081955000000001	57.058135	0103000020E61000000100000005000000336ABE4A3EA8574061E0B9F770874C40336ABE4A3EA85740315F5E807D8A4C40BC40498105AA5740315F5E807D8A4C40BC40498105AA574061E0B9F770874C40336ABE4A3EA8574061E0B9F770874C40
49476	Струково	5	49	93	94.514202999999995	94.536795999999995	56.992483999999997	56.986579999999996	0103000020E610000001000000050000005320B3B3E8A057409F71E140487E4C405320B3B3E8A05740D1E638B7097F4C40E9279CDD5AA25740D1E638B7097F4C40E9279CDD5AA257409F71E140487E4C405320B3B3E8A057409F71E140487E4C40
32305	Скакальная	5	49	93	95.045512000000002	95.072227999999996	57.144362000000001	57.132263999999999	0103000020E61000000100000005000000D6E429ABE9C257401538D906EE904C40D6E429ABE9C2574080643A747A924C40C07630629FC4574080643A747A924C40C07630629FC457401538D906EE904C40D6E429ABE9C257401538D906EE904C40
31984	Сивохино	5	49	93	94.512685000000005	94.534352999999996	57.099673000000003	57.084282999999999	0103000020E610000001000000050000009609BFD4CFA05740EC4D0CC9C98A4C409609BFD4CFA05740A9A5B915C28C4C403FE1ECD632A25740A9A5B915C28C4C403FE1ECD632A25740EC4D0CC9C98A4C409609BFD4CFA05740EC4D0CC9C98A4C40
32411	Мурма	5	49	93	94.790265000000005	94.805868000000004	57.287669000000001	57.280397000000001	0103000020E610000001000000050000001A8BA6B393B25740C172840CE4A34C401A8BA6B393B2574059897956D2A44C402639605793B3574059897956D2A44C402639605793B35740C172840CE4A34C401A8BA6B393B25740C172840CE4A34C40
32077	Лукашино	5	49	93	94.366116000000005	94.378153999999995	57.130662000000001	57.123337999999997	0103000020E61000000100000005000000B6A2CD716E975740512D228AC98F4C40B6A2CD716E9757403C6A4C88B9904C4080B6D5AC339857403C6A4C88B9904C4080B6D5AC33985740512D228AC98F4C40B6A2CD716E975740512D228AC98F4C40
45516	Лужки	5	49	93	94.765614999999997	94.779656000000003	57.319369999999999	57.305050000000001	0103000020E61000000100000005000000EE940ED6FFB0574089D2DEE00BA74C40EE940ED6FFB0574069A9BC1DE1A84C40558847E2E5B1574069A9BC1DE1A84C40558847E2E5B1574089D2DEE00BA74C40EE940ED6FFB0574089D2DEE00BA74C40
49544	Корсаково	5	49	93	94.378342000000004	94.407168999999996	57.084890000000001	57.080036999999997	0103000020E61000000100000005000000022D5DC13698574027BC04A73E8A4C40022D5DC136985740F4E0EEACDD8A4C407BBC900E0F9A5740F4E0EEACDD8A4C407BBC900E0F9A574027BC04A73E8A4C40022D5DC13698574027BC04A73E8A4C40
49486	Караульное	5	49	93	94.730014999999995	94.757755000000003	57.085095000000003	57.079284000000001	0103000020E61000000100000005000000B9A5D590B8AE57404C8C65FA258A4C40B9A5D590B8AE5740CD069964E48A4C405AD8D30E7FB05740CD069964E48A4C405AD8D30E7FB057404C8C65FA258A4C40B9A5D590B8AE57404C8C65FA258A4C40
45363	Веселое	5	49	93	95.180232000000004	95.204719999999995	57.089086000000002	57.078066	0103000020E61000000100000005000000556CCCEB88CB5740FB761211FE894C40556CCCEB88CB57400744882B678B4C409335EA211ACD57400744882B678B4C409335EA211ACD5740FB761211FE894C40556CCCEB88CB5740FB761211FE894C40
45458	Вахрушево	5	49	93	94.495868999999999	94.514581000000007	57.232813	57.218463999999997	0103000020E610000001000000050000006A865451BC9F57403AADDBA0F69B4C406A865451BC9F5740B58AFED0CC9D4C40278925E5EEA05740B58AFED0CC9D4C40278925E5EEA057403AADDBA0F69B4C406A865451BC9F57403AADDBA0F69B4C40
49515	Бурмакино	5	49	93	94.778954999999996	94.784739999999999	57.017114999999997	57.007621999999998	0103000020E6100000010000000500000090831266DAB15740745DF8C1F9804C4090831266DAB15740B1A206D330824C403CF71E2E39B25740B1A206D330824C403CF71E2E39B25740745DF8C1F9804C4090831266DAB15740745DF8C1F9804C40
32472	Бартанас	5	49	93	94.654718000000003	94.667689999999993	57.260069000000001	57.256213000000002	0103000020E61000000100000005000000908653E6E6A95740B0E76B96CBA04C40908653E6E6A957400ADAE4F049A14C407077D66EBBAA57400ADAE4F049A14C407077D66EBBAA5740B0E76B96CBA04C40908653E6E6A95740B0E76B96CBA04C40
32218	Бакчет	5	49	93	94.977815000000007	94.997119999999995	57.065309999999997	57.049799	0103000020E6100000010000000500000073A25D8594BE5740CF2F4AD05F864C4073A25D8594BE5740060DFD135C884C40008C67D0D0BF5740060DFD135C884C40008C67D0D0BF5740CF2F4AD05F864C4073A25D8594BE5740CF2F4AD05F864C40
51861	Сындасско	5	49	7120	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51761	Поселок Дудинка	5	49	7120	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51760	Поселок Байкаловск	5	49	7120	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59850	п. Воронцово	5	49	7490	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59744	Тухард	5	49	7490	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59675	Караул	5	49	7490	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59637	Дудунка	5	49	7490	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59737	п. Усть-Порт	5	49	7121	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59689	п. Носок	5	49	7121	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51775	городское поселение Дудинка	5	49	7121	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
51898	городское поселение Диксон	5	49	7121	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59466	Миндерла	5	49	7122	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
51810	Мингуль	5	49	7122	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
51786	Воробино	5	49	7122	93.187167000000002	93.202851999999993	56.504863999999998	56.494729	0103000020E61000000100000005000000FDF84B8BFA4B5740FFB0A547533F4C40FDF84B8BFA4B5740C07630629F404C40677BF486FB4C5740C07630629F404C40677BF486FB4C5740FFB0A547533F4C40FDF84B8BFA4B5740FFB0A547533F4C40
51782	Борск	5	49	7122	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
31604	Шошкино	5	49	1147	92.803685000000002	92.824185	56.588675000000002	56.581972999999998	0103000020E610000001000000050000004AD235936F335740D7135D177E4A4C404AD235936F335740857CD0B3594B4C40A4367172BF345740857CD0B3594B4C40A4367172BF345740D7135D177E4A4C404AD235936F335740D7135D177E4A4C40
30237	Шилинка	5	49	1147	92.903371000000007	92.924850000000006	56.544742999999997	56.531933000000002	0103000020E61000000100000005000000E94999D4D0395740E3546B6116444C40E94999D4D0395740CADC7C23BA454C4029ED0DBE303B5740CADC7C23BA454C4029ED0DBE303B5740E3546B6116444C40E94999D4D0395740E3546B6116444C40
31454	Шила	5	49	1147	93.032055	93.070888999999994	56.559161000000003	56.540734	0103000020E61000000100000005000000172B6A300D425740EAEA8EC536454C40172B6A300D4257406E19709692474C405A290472894457406E19709692474C405A29047289445740EAEA8EC536454C40172B6A300D425740EAEA8EC536454C40
30594	Хлоптуново	5	49	1147	93.640691000000004	93.658747000000005	56.475394000000001	56.459541999999999	0103000020E61000000100000005000000DCF5D21401695740B891B245D23A4C40DCF5D21401695740795BE9B5D93C4C40A4552DE9286A5740795BE9B5D93C4C40A4552DE9286A5740B891B245D23A4C40DCF5D21401695740B891B245D23A4C40
59742	Толстомысово	5	49	1147	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
14809	Сухобузимское	5	49	1147	93.248450000000005	93.304226999999997	56.510860000000001	56.485410999999999	0103000020E610000001000000050000003D2CD49AE64F5740300F99F2213E4C403D2CD49AE64F5740D36A48DC63414C40DAE3857478535740D36A48DC63414C40DAE3857478535740300F99F2213E4C403D2CD49AE64F5740300F99F2213E4C40
30440	Седельниково	5	49	1147	93.390258000000003	93.412571999999997	56.530816000000002	56.519233	0103000020E6100000010000000500000027C0B0FCF95857408200193A76424C4027C0B0FCF9585740C61858C7F1434C40B3CF6394675A5740C61858C7F1434C40B3CF6394675A57408200193A76424C4027C0B0FCF95857408200193A76424C40
26527	Первомайский	5	49	1147	92.571703999999997	92.590164999999999	56.571848000000003	56.563997999999998	0103000020E6100000010000000500000083BF5FCC962457403481221631484C4083BF5FCC962457403A24B55032494C409B8F6B43C52557403A24B55032494C409B8F6B43C52557403481221631484C4083BF5FCC962457403481221631484C40
30935	Павловщина	5	49	1147	93.563695999999993	93.595675999999997	56.766134000000001	56.736922999999997	0103000020E61000000100000005000000B438639813645740C9552C7E535E4C40B438639813645740452DCDAD10624C40C6C03A8E1F665740452DCDAD10624C40C6C03A8E1F665740C9552C7E535E4C40B438639813645740C9552C7E535E4C40
31551	Новотроицкое	5	49	1147	93.018697000000003	93.032846000000006	56.663905999999997	56.655268	0103000020E6100000010000000500000022E2E65432415740C30E63D2DF534C4022E2E6543241574020CF2EDFFA544C407CF31B261A42574020CF2EDFFA544C407CF31B261A425740C30E63D2DF534C4022E2E65432415740C30E63D2DF534C40
30753	Нахвальское	5	49	1147	93.564701999999997	93.587509999999995	56.677822999999997	56.669826999999998	0103000020E61000000100000005000000177FDB1324645740287D21E4BC554C40177FDB132464574001BD70E7C2564C40AB048BC39965574001BD70E7C2564C40AB048BC399655740287D21E4BC554C40177FDB1324645740287D21E4BC554C40
30866	Малое Нахвальское	5	49	1147	93.557137999999995	93.568655000000007	56.713301000000001	56.696728	0103000020E61000000100000005000000F7562426A86357408F1A13622E594C40F7562426A8635740209A79724D5B4C403EEDF0D764645740209A79724D5B4C403EEDF0D7646457408F1A13622E594C40F7562426A86357408F1A13622E594C40
10781	Малиновка	5	49	1147	93.472104000000002	93.486630000000005	56.597745000000003	56.583703	0103000020E61000000100000005000000E413B2F3365E5740DEC9A7C7B64A4C40E413B2F3365E57407C2C7DE8824C4C4029D027F2245F57407C2C7DE8824C4C4029D027F2245F5740DEC9A7C7B64A4C40E413B2F3365E5740DEC9A7C7B64A4C40
30474	Кононово	5	49	1147	93.694985000000003	93.738022999999998	56.512638000000003	56.494112999999999	0103000020E610000001000000050000007A8D5DA27A6C5740A4C343183F3F4C407A8D5DA27A6C5740EB573A1F9E414C40882CD2C43B6F5740EB573A1F9E414C40882CD2C43B6F5740A4C343183F3F4C407A8D5DA27A6C5740A4C343183F3F4C40
31489	Ковригино	5	49	1147	93.198916999999994	93.224708000000007	56.628025000000001	56.615951000000003	0103000020E6100000010000000500000094675E0EBB4C574021787C7BD74E4C4094675E0EBB4C574003098A1F63504C4093C9A99D614E574003098A1F63504C4093C9A99D614E574021787C7BD74E4C4094675E0EBB4C574021787C7BD74E4C40
30399	Кекур	5	49	1147	93.559663	93.583432000000002	56.622419999999998	56.608898000000003	0103000020E610000001000000050000000072C284D1635740C74CA25EF04D4C400072C284D16357402B306475AB4F4C4027DC2BF3566557402B306475AB4F4C4027DC2BF356655740C74CA25EF04D4C400072C284D1635740C74CA25EF04D4C40
51815	Карымская	5	49	1147	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
30033	Исток	5	49	1147	93.688265000000001	93.710993000000002	56.610230000000001	56.597729999999999	0103000020E61000000100000005000000D07EA4880C6C574046EBA86A824C4C40D07EA4880C6C5740E08442041C4E4C40D6ABC8E8806D5740E08442041C4E4C40D6ABC8E8806D574046EBA86A824C4C40D07EA4880C6C574046EBA86A824C4C40
30307	Высотино	5	49	1147	93.393510000000006	93.426254	56.557032999999997	56.543135999999997	0103000020E61000000100000005000000892991442F595740DFA3FE7A85454C40892991442F59574079E57ADB4C474C408272DBBE475B574079E57ADB4C474C408272DBBE475B5740DFA3FE7A85454C40892991442F595740DFA3FE7A85454C40
19871	Бузуново	5	49	1147	93.317594	93.327815999999999	56.703325999999997	56.694800000000001	0103000020E61000000100000005000000F9D9C8755354574062A1D634EF584C40F9D9C8755354574097361C96065A4C40C1C6F5EFFA54574097361C96065A4C40C1C6F5EFFA54574062A1D634EF584C40F9D9C8755354574062A1D634EF584C40
30016	Бузим	5	49	1147	93.347283000000004	93.364153000000002	56.510586000000004	56.501133000000003	0103000020E610000001000000050000003CDD79E23956574023F94A2025404C403CDD79E239565740D2E5CDE15A414C40616F62484E575740D2E5CDE15A414C40616F62484E57574023F94A2025404C403CDD79E23956574023F94A2025404C40
30547	Большой Балчуг	5	49	1147	93.705819000000005	93.717918999999995	56.458348000000001	56.448369	0103000020E610000001000000050000004F7974232C6D574026C5C72764394C404F7974232C6D5740F017B325AB3A4C40548B8862F26D5740F017B325AB3A4C40548B8862F26D574026C5C72764394C404F7974232C6D574026C5C72764394C40
30787	Берег Таскино	5	49	1147	93.511090999999993	93.546070999999998	56.797837000000001	56.793311000000003	0103000020E61000000100000005000000EA9106B7B56057404E4700378B654C40EA9106B7B5605740F644D7851F664C40D192C7D3F2625740F644D7851F664C40D192C7D3F26257404E4700378B654C40EA9106B7B56057404E4700378B654C40
21467	Атаманово	5	49	1147	93.597849999999994	93.657453000000004	56.416924000000002	56.385800000000003	0103000020E61000000100000005000000787AA52C43665740FE65F7E461314C40787AA52C43665740717500C45D354C400E6ABFB5136A5740717500C45D354C400E6ABFB5136A5740FE65F7E461314C40787AA52C43665740FE65F7E461314C40
30323	Абакшино	5	49	1147	93.681438	93.707066999999995	56.579990000000002	56.563640999999997	0103000020E610000001000000050000001B1021AE9C6B5740A5D7666325484C401B1021AE9C6B5740E700C11C3D4A4C402C45F295406D5740E700C11C3D4A4C402C45F295406D5740A5D7666325484C401B1021AE9C6B5740A5D7666325484C40
51783	Татарская	5	49	7118	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
51744	Подсопки	5	49	7118	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
59639	рабочий поселок Северо-Енисейский	5	49	7126	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59627	Северо-Енисейский	5	49	7126	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59838	Вельмо	5	49	7126	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59914	Брянка	5	49	7126	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
25330	Чарга	5	49	252	95.155448000000007	95.182128000000006	55.386062000000003	55.371332000000002	0103000020E61000000100000005000000A20E2BDCF2C95740A9FA95CE87AF4B40A20E2BDCF2C957403B1DC87A6AB14B40E6EB32FCA7CB57403B1DC87A6AB14B40E6EB32FCA7CB5740A9FA95CE87AF4B40A20E2BDCF2C95740A9FA95CE87AF4B40
21413	Усть-Анжа	5	49	252	95.124275999999995	95.145287999999994	55.353217000000001	55.339094000000003	0103000020E610000001000000050000005FEB5223F4C757408A22A46E67AB4B405FEB5223F4C7574014B2F33636AD4B4014200A664CC9574014B2F33636AD4B4014200A664CC957408A22A46E67AB4B405FEB5223F4C757408A22A46E67AB4B40
29363	Унер	5	49	252	94.762703999999999	94.808231000000006	55.449899000000002	55.433450000000001	0103000020E61000000100000005000000D1217024D0B05740C139234A7BB74B40D1217024D0B0574066C0594A96B94B404227840EBAB3574066C0594A96B94B404227840EBAB35740C139234A7BB74B40D1217024D0B05740C139234A7BB74B40
29033	Тугач	5	49	252	95.260909999999996	95.304029	55.141593	55.129865000000002	0103000020E61000000100000005000000C24CDBBFB2D0574091F2936A9F904B40C24CDBBFB2D05740D82B2CB81F924B4047020D3675D35740D82B2CB81F924B4047020D3675D3574091F2936A9F904B40C24CDBBFB2D0574091F2936A9F904B40
1042	Тинская	5	49	252	95.016946000000004	95.062911999999997	55.422789000000002	55.415895999999996	0103000020E6100000010000000500000013F3ACA415C15740C34483143CB54B4013F3ACA415C15740E50D30F31DB64B40A9A10DC006C45740E50D30F31DB64B40A9A10DC006C45740C34483143CB54B4013F3ACA415C15740C34483143CB54B40
29298	Средняя Агинка	5	49	252	94.73536	94.757045000000005	55.325482000000001	55.316876999999998	0103000020E6100000010000000500000057B2632310AF574063EDEF6C8FA84B4057B2632310AF5740E5B7E864A9A94B406C26DF6C73B05740E5B7E864A9A94B406C26DF6C73B0574063EDEF6C8FA84B4057B2632310AF574063EDEF6C8FA84B40
47044	Петропавловка	5	49	252	94.844477999999995	94.874454999999998	55.183559000000002	55.177441999999999	0103000020E61000000100000005000000410C74ED0BB65740EA77616BB6964B40410C74ED0BB6574078F17EDC7E974B40B7B41A12F7B7574078F17EDC7E974B40B7B41A12F7B75740EA77616BB6964B40410C74ED0BB65740EA77616BB6964B40
59660	Павловка	5	49	252	94.871131000000005	94.881929	55.245942999999997	55.241283000000003	0103000020E6100000010000000500000009E23C9CC0B75740570A815CE29E4B4009E23C9CC0B757400ED76A0F7B9F4B403719558671B857400ED76A0F7B9F4B403719558671B85740570A815CE29E4B4009E23C9CC0B75740570A815CE29E4B40
29018	Орье	5	49	252	95.102483000000007	95.123513000000003	55.013353000000002	55.000982999999998	0103000020E610000001000000050000005859DB148FC657400D6D003620804B405859DB148FC65740D926158DB5814B4060E811A3E7C75740D926158DB5814B4060E811A3E7C757400D6D003620804B405859DB148FC657400D6D003620804B40
59726	Орловка	5	49	252	94.625864000000007	94.650324999999995	55.238131000000003	55.219324	0103000020E610000001000000050000009AEFE0270EA857402C9D0FCF129C4B409AEFE0270EA85740F7949C137B9E4B405BB1BFEC9EA95740F7949C137B9E4B405BB1BFEC9EA957402C9D0FCF129C4B409AEFE0270EA857402C9D0FCF129C4B40
46790	Нагорное	5	49	252	95.044613999999996	95.074742999999998	55.325636000000003	55.311681999999998	0103000020E6100000010000000500000066BCADF4DAC257403D601E32E5A74B4066BCADF4DAC257403C33C170AEA94B40B726DD96C8C457403C33C170AEA94B40B726DD96C8C457403D601E32E5A74B4066BCADF4DAC257403D601E32E5A74B40
19970	Межово	5	49	252	94.971778	95.005482999999998	55.551451	55.535711999999997	0103000020E610000001000000050000003A3E5A9C31BE57409109F83592C44B403A3E5A9C31BE57405A2C45F295C64B40C66B5ED559C057405A2C45F295C64B40C66B5ED559C057409109F83592C44B403A3E5A9C31BE57409109F83592C44B40
48514	Малиновка	5	49	252	94.753380000000007	94.779286999999997	55.133411000000002	55.121932000000001	0103000020E61000000100000005000000795DBF6037B05740FE2AC0779B8F4B40795DBF6037B057409DF6949C13914B40ABCC94D6DFB157409DF6949C13914B40ABCC94D6DFB15740FE2AC0779B8F4B40795DBF6037B05740FE2AC0779B8F4B40
29265	Кулижниково	5	49	252	94.670357999999993	94.708445999999995	55.279451999999999	55.273297999999997	0103000020E610000001000000050000002AA73D25E7AA5740F607CA6DFBA24B402AA73D25E7AA5740A1664815C5A34B40D93EE42D57AD5740A1664815C5A34B40D93EE42D57AD5740F607CA6DFBA24B402AA73D25E7AA5740F607CA6DFBA24B40
29123	Карлык	5	49	252	94.654116000000002	94.687550999999999	55.132736999999999	55.125227000000002	0103000020E6100000010000000500000095F25A09DDA95740C1C9367007904B4095F25A09DDA957400DFCA886FD904B4041D5E8D500AC57400DFCA886FD904B4041D5E8D500AC5740C1C9367007904B4095F25A09DDA95740C1C9367007904B40
48572	Гладково	5	49	252	95.073296999999997	95.091012000000006	55.225670999999998	55.205029000000003	0103000020E610000001000000050000004679E6E5B0C45740A5DDE8633E9A4B404679E6E5B0C45740EB538EC9E29C4B40CAE2FE23D3C55740EB538EC9E29C4B40CAE2FE23D3C55740A5DDE8633E9A4B404679E6E5B0C45740A5DDE8633E9A4B40
59840	Большой Ильбин	5	49	252	94.931443999999999	94.952123	55.182917000000003	55.170212999999997	0103000020E610000001000000050000008C834BC79CBB5740512D228AC9954B408C834BC79CBB5740F47002D369974B403EB14E95EFBC5740F47002D369974B403EB14E95EFBC5740512D228AC9954B408C834BC79CBB5740512D228AC9954B40
21370	Большой Арбай	5	49	252	94.687848000000002	94.705922000000001	55.187553000000001	55.173662999999998	0103000020E610000001000000050000009E279EB305AC57403BC3D4963A964B409E279EB305AC574023A298BC01984B40B9E177D32DAD574023A298BC01984B40B9E177D32DAD57403BC3D4963A964B409E279EB305AC57403BC3D4963A964B40
48705	Благодатка	5	49	252	94.816163000000003	94.837919999999997	55.499566000000002	55.483708999999998	0103000020E61000000100000005000000234DBC033CB45740F3E32F2DEABD4B40234DBC033CB45740C61858C7F1BF4B40842A357BA0B55740C61858C7F1BF4B40842A357BA0B55740F3E32F2DEABD4B40234DBC033CB45740F3E32F2DEABD4B40
28710	Агинское	5	49	252	94.880420000000001	94.931139000000002	55.274585000000002	55.244942000000002	0103000020E61000000100000005000000A3AF20CD58B857405BB56B425A9F4B40A3AF20CD58B85740707CED9925A34B40EE4108C897BB5740707CED9925A34B40EE4108C897BB57405BB56B425A9F4B40A3AF20CD58B857405BB56B425A9F4B40
27226	Абалаково	5	49	252	94.825883000000005	94.837282999999999	55.073489000000002	55.062735000000004	0103000020E61000000100000005000000A2D45E44DBB4574044A852B307884B40A2D45E44DBB45740D1CE691668894B40CB9F6F0B96B55740D1CE691668894B40CB9F6F0B96B5574044A852B307884B40A2D45E44DBB4574044A852B307884B40
28500	Чуриново	5	49	1113	94.857701000000006	94.883078999999995	55.659362999999999	55.653756000000001	0103000020E61000000100000005000000C72FBC92E4B657402AC8CF46AED34B40C72FBC92E4B65740A298BC0166D44B403332C85D84B85740A298BC0166D44B403332C85D84B857402AC8CF46AED34B40C72FBC92E4B657402AC8CF46AED34B40
28619	Усть-Кандыга	5	49	1113	94.717708000000002	94.752741999999998	55.546016999999999	55.532895000000003	0103000020E61000000100000005000000F70489EDEEAD5740D99942E735C44B40F70489EDEEAD5740AF0793E2E3C54B40D714C8EC2CB05740AF0793E2E3C54B40D714C8EC2CB05740D99942E735C44B40F70489EDEEAD5740D99942E735C44B40
9979	Успенка	5	49	1113	94.488906999999998	94.530625000000001	55.932091999999997	55.919502999999999	0103000020E6100000010000000500000045F295404A9F574075C93846B2F54B4045F295404A9F57407E6E68CA4EF74B40295C8FC2F5A157407E6E68CA4EF74B40295C8FC2F5A1574075C93846B2F54B4045F295404A9F574075C93846B2F54B40
19395	Урал	5	49	1113	94.736968000000005	94.768714000000003	55.920783999999998	55.895020000000002	0103000020E61000000100000005000000B58CD47B2AAF57400AA2EE0390F24B40B58CD47B2AAF57400C570740DCF54B408D7E349C32B157400C570740DCF54B408D7E349C32B157400AA2EE0390F24B40B58CD47B2AAF57400AA2EE0390F24B40
28098	Тульское	5	49	1113	95.020880000000005	95.039034999999998	55.834359999999997	55.830392000000003	0103000020E61000000100000005000000FE48111956C15740166EF9484AEA4B40FE48111956C15740978BF84ECCEA4B408F19A88C7FC25740978BF84ECCEA4B408F19A88C7FC25740166EF9484AEA4B40FE48111956C15740166EF9484AEA4B40
27683	Старая Солянка	5	49	1113	95.268411	95.283412999999996	56.045623999999997	56.034022999999998	0103000020E61000000100000005000000BFB854A52DD15740E9279CDD5A044C40BFB854A52DD15740D3F4D901D7054C40B890477023D25740D3F4D901D7054C40B890477023D25740E9279CDD5A044C40BFB854A52DD15740E9279CDD5A044C40
28434	Соловьевка	5	49	1113	94.940634000000003	94.950802999999993	55.710393000000003	55.705244	0103000020E610000001000000050000005DE0F25833BC5740A1D9756F45DA4B405DE0F25833BC574057276728EEDA4B40137CD3F4D9BC574057276728EEDA4B40137CD3F4D9BC5740A1D9756F45DA4B405DE0F25833BC5740A1D9756F45DA4B40
28514	Снегирёвка	5	49	1113	94.727023000000003	94.741585000000001	55.601294000000003	55.593161000000002	0103000020E61000000100000005000000261C7A8B87AE57409F211CB3ECCB4B40261C7A8B87AE5740F9A3A833F7CC4B40118DEE2076AF5740F9A3A833F7CC4B40118DEE2076AF57409F211CB3ECCB4B40261C7A8B87AE57409F211CB3ECCB4B40
25870	Сибиряк	5	49	1113	94.524444000000003	94.529430000000005	55.912143	55.910896000000001	0103000020E610000001000000050000005725917D90A157405307793D98F44B405725917D90A157403E23111AC1F44B405DE15D2EE2A157403E23111AC1F44B405DE15D2EE2A157405307793D98F44B405725917D90A157405307793D98F44B40
15423	Саянский	5	49	1113	94.690363000000005	94.725074000000006	55.557245999999999	55.540984999999999	0103000020E6100000010000000500000095D74AE82EAC5740335019FF3EC54B4095D74AE82EAC5740D5E940D653C74B40844BC79C67AE5740D5E940D653C74B40844BC79C67AE5740335019FF3EC54B4095D74AE82EAC5740335019FF3EC54B40
27647	Рябинки	5	49	1113	95.148557999999994	95.158242000000001	56.012461000000002	56.006089000000003	0103000020E61000000100000005000000C9E369F981C95740C4EE3B86C7004C40C9E369F981C95740DCBC715298014C40A2B60DA320CA5740DCBC715298014C40A2B60DA320CA5740C4EE3B86C7004C40C9E369F981C95740C4EE3B86C7004C40
18757	Рыбное	5	49	1113	94.75797	94.812633000000005	55.786879999999996	55.769478999999997	0103000020E6100000010000000500000058569A9482B05740B9FAB1497EE24B4058569A9482B0574030F0DC7BB8E44B40A0A9D72D02B4574030F0DC7BB8E44B40A0A9D72D02B45740B9FAB1497EE24B4058569A9482B05740B9FAB1497EE24B40
32861	Переясловка	5	49	1113	94.727975999999998	94.765292000000002	55.679777999999999	55.664116	0103000020E610000001000000050000007711A62897AE57400B60CAC001D54B407711A62897AE574028452BF702D74B40FDF84B8BFAB0574028452BF702D74B40FDF84B8BFAB057400B60CAC001D54B407711A62897AE57400B60CAC001D54B40
27308	Новокамала	5	49	1113	94.961590999999999	95.037893999999994	55.979081999999998	55.959705999999997	0103000020E610000001000000050000003048FAB48ABD574032E36DA5D7FA4B403048FAB48ABD5740170D198F52FD4B40BCADF4DA6CC25740170D198F52FD4B40BCADF4DA6CC2574032E36DA5D7FA4B403048FAB48ABD574032E36DA5D7FA4B40
27562	Новая Солянка	5	49	1113	95.180340000000001	95.230754000000005	56.013382	55.993594999999999	0103000020E61000000100000005000000488AC8B08ACB57400C3CF71E2EFF4B40488AC8B08ACB5740732D5A80B6014C40F5DA6CACC4CE5740732D5A80B6014C40F5DA6CACC4CE57400C3CF71E2EFF4B40488AC8B08ACB57400C3CF71E2EFF4B40
27148	Новая Прилука	5	49	1113	94.495204000000001	94.513907000000003	56.014080999999997	56.006934999999999	0103000020E610000001000000050000004C361E6CB19F57405019FF3EE3004C404C361E6CB19F57405B3FFD67CD014C40DF8B2FDAE3A057405B3FFD67CD014C40DF8B2FDAE3A057405019FF3EE3004C404C361E6CB19F57405019FF3EE3004C40
27160	Новая Печера	5	49	1113	94.511094999999997	94.532968999999994	56.056086000000001	56.041953999999997	0103000020E610000001000000050000008B89CDC7B5A05740DBF7A8BF5E054C408B89CDC7B5A05740B9E177D32D074C400932022A1CA25740B9E177D32D074C400932022A1CA25740DBF7A8BF5E054C408B89CDC7B5A05740DBF7A8BF5E054C40
59749	Новая	5	49	1113	94.793678	94.804674000000006	55.875853999999997	55.868112000000004	0103000020E610000001000000050000008063CF9ECBB25740F1A1444B1EEF4B408063CF9ECBB257400F09DFFB1BF04B40427C60C77FB357400F09DFFB1BF04B40427C60C77FB35740F1A1444B1EEF4B408063CF9ECBB25740F1A1444B1EEF4B40
27979	Низинка	5	49	1113	95.018805	95.031336999999994	55.809894	55.805785999999998	0103000020E610000001000000050000001500E31934C157408EC9E2FE23E74B401500E31934C15740029D499BAAE74B40E789E76C01C25740029D499BAAE74B40E789E76C01C257408EC9E2FE23E74B401500E31934C157408EC9E2FE23E74B40
28295	Налобино	5	49	1113	94.682269000000005	94.698385000000002	55.911371000000003	55.897492999999997	0103000020E61000000100000005000000C784984BAAAB5740C8B1F50CE1F24B40C784984BAAAB5740ECC20FCEA7F44B4016C1FF56B2AC5740ECC20FCEA7F44B4016C1FF56B2AC5740C8B1F50CE1F24B40C784984BAAAB5740C8B1F50CE1F24B40
27234	Малая Камала	5	49	1113	94.925955000000002	94.956227999999996	56.096639000000003	56.083185	0103000020E6100000010000000500000055A4C2D842BB574046425BCEA50A4C4055A4C2D842BB57405342B0AA5E0C4C403FE1ECD632BD57405342B0AA5E0C4C403FE1ECD632BD574046425BCEA50A4C4055A4C2D842BB574046425BCEA50A4C40
28125	Лощинка	5	49	1113	95.158089000000004	95.167502999999996	55.764465000000001	55.756498000000001	0103000020E61000000100000005000000DF3653211ECA5740A5BE2CEDD4E04B40DF3653211ECA5740E4F736FDD9E14B40D7BE805EB8CA5740E4F736FDD9E14B40D7BE805EB8CA5740A5BE2CEDD4E04B40DF3653211ECA5740A5BE2CEDD4E04B40
27986	Лозовая	5	49	1113	94.906353999999993	94.916630999999995	55.781317000000001	55.770679000000001	0103000020E61000000100000005000000522635B401BA5740645B069CA5E24B40522635B401BA57408867093202E44B40FCDF1115AABA57408867093202E44B40FCDF1115AABA5740645B069CA5E24B40522635B401BA5740645B069CA5E24B40
28595	Красногорьевка	5	49	1113	94.806183000000004	94.837183999999993	55.579566	55.570996000000001	0103000020E61000000100000005000000D6E5948098B35740CB129D6516C94B40D6E5948098B35740D0EFFB372FCA4B40012F336C94B55740D0EFFB372FCA4B40012F336C94B55740CB129D6516C94B40D6E5948098B35740CB129D6516C94B40
19343	Ирша	5	49	1113	94.758257999999998	94.823268999999996	55.938819000000002	55.916395999999999	0103000020E610000001000000050000008BFB8F4C87B05740B517D1764CF54B408BFB8F4C87B0574085EE92382BF84B40E1B37570B0B4574085EE92382BF84B40E1B37570B0B45740B517D1764CF54B408BFB8F4C87B05740B517D1764CF54B40
27440	Ивановка	5	49	1113	95.042744999999996	95.069443000000007	56.052169999999997	56.041415999999998	0103000020E6100000010000000500000052448655BCC25740FCC3961E4D054C4052448655BCC2574089EAAD81AD064C40EA7B0DC171C4574089EAAD81AD064C40EA7B0DC171C45740FCC3961E4D054C4052448655BCC25740FCC3961E4D054C40
40374	Зеленогорск	5	49	1113	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
33106	Заозерный	5	49	1113	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
27744	Завировка	5	49	1113	95.353733000000005	95.362500999999995	55.972630000000002	55.967188999999998	0103000020E6100000010000000500000006A1BC8FA3D65740850662D9CCFB4B4006A1BC8FA3D65740E38DCC237FFC4B401BF1643733D75740E38DCC237FFC4B401BF1643733D75740850662D9CCFB4B4006A1BC8FA3D65740850662D9CCFB4B40
28425	Двуречное	5	49	1113	94.758527000000001	94.780158999999998	55.714095	55.703012999999999	0103000020E610000001000000050000008388D4B48BB05740D8D47954FCD94B408388D4B48BB057405A9E077767DB4B4086AB0320EEB157405A9E077767DB4B4086AB0320EEB15740D8D47954FCD94B408388D4B48BB05740D8D47954FCD94B40
27419	Гмирянка	5	49	1113	94.865956999999995	94.883510000000001	56.009013000000003	56.002842999999999	0103000020E6100000010000000500000081AFE8D66BB75740E202D0285D004C4081AFE8D66BB75740931E865627014C4018EC866D8BB85740931E865627014C4018EC866D8BB85740E202D0285D004C4081AFE8D66BB75740E202D0285D004C40
28355	Глубоково	5	49	1113	94.754422000000005	94.767635999999996	55.864353000000001	55.854719000000003	0103000020E610000001000000050000008258367348B057408A22A46E67ED4B408258367348B0574089997D1EA3EE4B40DDCEBEF220B1574089997D1EA3EE4B40DDCEBEF220B157408A22A46E67ED4B408258367348B057408A22A46E67ED4B40
27519	Воскресенка	5	49	1113	94.962165999999996	94.983384999999998	55.949229000000003	55.941037000000001	0103000020E61000000100000005000000AED4B32094BD5740B9A981E673F84B40AED4B32094BD574018B5FB5580F94B402098A3C7EFBE574018B5FB5580F94B402098A3C7EFBE5740B9A981E673F84B40AED4B32094BD5740B9A981E673F84B40
28055	Верховая	5	49	1113	95.096114	95.119703999999999	55.897629000000002	55.890118000000001	0103000020E6100000010000000500000004AC55BB26C657405CCAF962EFF14B4004AC55BB26C657407978CF81E5F24B40D34CF73AA9C757407978CF81E5F24B40D34CF73AA9C757405CCAF962EFF14B4004AC55BB26C657405CCAF962EFF14B40
27895	Бородино	5	49	1113	94.954116999999997	94.985575999999995	55.876666999999998	55.864803000000002	0103000020E61000000100000005000000B0E3BF4010BD5740C93D5DDDB1EE4B40B0E3BF4010BD5740C03DCF9F36F04B403DEE5BAD13BF5740C03DCF9F36F04B403DEE5BAD13BF5740C93D5DDDB1EE4B40B0E3BF4010BD5740C93D5DDDB1EE4B40
27891	Большие Ключи	5	49	1113	95.166793999999996	95.198953000000003	55.956733	55.942287	0103000020E61000000100000005000000D1CABDC0ACCA5740153944DC9CF84B40D1CABDC0ACCA57408200193A76FA4B403B1C5DA5BBCC57408200193A76FA4B403B1C5DA5BBCC5740153944DC9CF84B40D1CABDC0ACCA5740153944DC9CF84B40
27088	Александровка	5	49	1113	94.535528999999997	94.578146000000004	55.997002999999999	55.988067000000001	0103000020E61000000100000005000000D0436D1B46A25740E0A0BDFA78FE4B40D0436D1B46A25740C78157CB9DFF4B400C94145800A55740C78157CB9DFF4B400C94145800A55740E0A0BDFA78FE4B40D0436D1B46A25740E0A0BDFA78FE4B40
27014	Чайда	5	49	1795	91.697481999999994	91.714595000000003	57.436131000000003	57.424714999999999	0103000020E610000001000000050000001DE38A8BA3EC5640718FA50F5DB64C401DE38A8BA3EC5640CAE2FE23D3B74C40A6B8AAECBBED5640CAE2FE23D3B74C40A6B8AAECBBED5640718FA50F5DB64C401DE38A8BA3EC5640718FA50F5DB64C40
51906	Туруханка	5	49	1795	91.831241000000006	91.841697999999994	57.593975999999998	57.588712999999998	0103000020E610000001000000050000000A86730D33F5564072DD94F25ACB4C400A86730D33F55640F04DD36707CC4C40F3C64961DEF55640F04DD36707CC4C40F3C64961DEF5564072DD94F25ACB4C400A86730D33F5564072DD94F25ACB4C40
51812	Троица	5	49	1795	92.150107000000006	92.186200999999997	57.776854999999998	57.766568999999997	0103000020E61000000100000005000000A5F9635A9B0957404F90D8EE1EE24C40A5F9635A9B095740F65D11FC6FE34C40E15E99B7EA0B5740F65D11FC6FE34C40E15E99B7EA0B57404F90D8EE1EE24C40A5F9635A9B0957404F90D8EE1EE24C40
26731	Солоуха	5	49	1795	92.295113000000001	92.313321999999999	57.759300000000003	57.750247999999999	0103000020E61000000100000005000000F7E7A221E3125740D8F15F2008E04C40F7E7A221E312574029ED0DBE30E14C4082C7B7770D14574029ED0DBE30E14C4082C7B7770D145740D8F15F2008E04C40F7E7A221E3125740D8F15F2008E04C40
26679	Пировское	5	49	1795	92.250322999999995	92.299792999999994	57.634601000000004	57.608559999999997	0103000020E61000000100000005000000F19BC24A05105740AED3484BE5CD4C40F19BC24A051057402481069B3AD14C4076A4FACE2F1357402481069B3AD14C4076A4FACE2F135740AED3484BE5CD4C40F19BC24A05105740AED3484BE5CD4C40
45395	Петропавловка	5	49	1795	92.163959000000006	92.173193999999995	57.569923000000003	57.560291999999997	0103000020E61000000100000005000000A2B8E34D7E0A5740EF1AF4A5B7C74C40A2B8E34D7E0A57407E1EA33CF3C84C404277499C150B57407E1EA33CF3C84C404277499C150B5740EF1AF4A5B7C74C40A2B8E34D7E0A5740EF1AF4A5B7C74C40
26453	Омский	5	49	1795	91.888715000000005	91.902028000000001	57.598683999999999	57.588824000000002	0103000020E61000000100000005000000BD1DE1B4E0F85640CA8CB7955ECB4C40BD1DE1B4E0F85640B95164ADA1CC4C40E204A6D3BAF95640B95164ADA1CC4C40E204A6D3BAF95640CA8CB7955ECB4C40BD1DE1B4E0F85640CA8CB7955ECB4C40
59787	Новый Тимерщик	5	49	1795	92.071172000000004	92.084018	57.598157999999998	57.593349000000003	0103000020E61000000100000005000000051901158E045740A20E2BDCF2CB4C40051901158E0457409EEBFB7090CC4C409F91088D600557409EEBFB7090CC4C409F91088D60055740A20E2BDCF2CB4C40051901158E045740A20E2BDCF2CB4C40
47650	Новотроицкое	5	49	1795	92.048786000000007	92.056214999999995	57.631262	57.626100999999998	0103000020E610000001000000050000002CA0504F1F035740177FDB1324D04C402CA0504F1F035740919A7631CDD04C40DBA2CC0699035740919A7631CDD04C40DBA2CC0699035740177FDB1324D04C402CA0504F1F035740177FDB1324D04C40
47646	Новониколаевское	5	49	1795	92.433183999999997	92.443235999999999	57.875768999999998	57.867612999999999	0103000020E61000000100000005000000A1496249B91B5740CF4A5AF10DEF4C40A1496249B91B5740E1ECD63219F04C403B1A87FA5D1C5740E1ECD63219F04C403B1A87FA5D1C5740CF4A5AF10DEF4C40A1496249B91B5740CF4A5AF10DEF4C40
26969	Куренная Ошма	5	49	1795	92.226957999999996	92.252443	57.824944000000002	57.822125999999997	0103000020E6100000010000000500000032E4D87A860E57407C98BD6C3BE94C4032E4D87A860E57400684D6C397E94C40AA46AF06281057400684D6C397E94C40AA46AF06281057407C98BD6C3BE94C4032E4D87A860E57407C98BD6C3BE94C40
47574	Комаровка	5	49	1795	91.874144999999999	91.888184999999993	57.567717000000002	57.557240999999998	0103000020E6100000010000000500000090BDDEFDF1F75640C37E4FAC53C74C4090BDDEFDF1F756400E315EF3AAC84C400EF3E505D8F856400E315EF3AAC84C400EF3E505D8F85640C37E4FAC53C74C4090BDDEFDF1F75640C37E4FAC53C74C40
26578	Коврига	5	49	1795	91.965008999999995	91.979579999999999	57.617010999999998	57.613328000000003	0103000020E610000001000000050000001FD61BB5C2FD56404DDC2A8881CE4C401FD61BB5C2FD5640D9226937FACE4C4034F44F70B1FE5640D9226937FACE4C4034F44F70B1FE56404DDC2A8881CE4C401FD61BB5C2FD56404DDC2A8881CE4C40
47532	Кириково	5	49	1795	92.475046000000006	92.490882999999997	57.584159	57.576993000000002	0103000020E610000001000000050000001F865627671E5740AE8218E8DAC94C401F865627671E57400055DCB8C5CA4C4064CA87A06A1F57400055DCB8C5CA4C4064CA87A06A1F5740AE8218E8DAC94C401F865627671E5740AE8218E8DAC94C40
26364	Кетский	5	49	1795	91.863392000000005	91.892038999999997	57.586938000000004	57.577359999999999	0103000020E6100000010000000500000032E884D041F756406002B7EEE6C94C4032E884D041F75640CC63CDC820CB4C406BF0BE2A17F95640CC63CDC820CB4C406BF0BE2A17F956406002B7EEE6C94C4032E884D041F756406002B7EEE6C94C40
26285	Икшурма	5	49	1795	91.992425999999995	92.010122999999993	57.642868	57.634587000000003	0103000020E61000000100000005000000CE6C57E883FF5640BFBB95253AD14C40CE6C57E883FF56408DD2A57F49D24C40FE7BF0DAA50057408DD2A57F49D24C40FE7BF0DAA5005740BFBB95253AD14C40CE6C57E883FF5640BFBB95253AD14C40
47619	Долгово	5	49	1795	92.303162	92.325674000000006	57.736203000000003	57.726073	0103000020E61000000100000005000000F5D89601671357401AC1C6F5EFDC4C40F5D8960167135740CA1B60E63BDE4C4015CAC2D7D7145740CA1B60E63BDE4C4015CAC2D7D71457401AC1C6F5EFDC4C40F5D89601671357401AC1C6F5EFDC4C40
26551	Волоковое	5	49	1795	92.439958000000004	92.451851000000005	57.661231000000001	57.655535	0103000020E6100000010000000500000045679945281C574012312592E8D34C4045679945281C5740FA0CA837A3D44C408EEA7420EB1C5740FA0CA837A3D44C408EEA7420EB1C574012312592E8D34C4045679945281C574012312592E8D34C40
26259	Бушуй	5	49	1795	92.204006000000007	92.219842999999997	57.469929999999998	57.463124000000001	0103000020E61000000100000005000000058C2E6F0E0D574011FFB0A547BB4C40058C2E6F0E0D574063B48EAA26BC4C404AD05FE8110E574063B48EAA26BC4C404AD05FE8110E574011FFB0A547BB4C40058C2E6F0E0D574011FFB0A547BB4C40
47674	Бельское	5	49	1795	92.155253999999999	92.172905999999998	57.826113999999997	57.815933000000001	0103000020E61000000100000005000000AF2479AEEF095740145D177E70E84C40AF2479AEEF0957404562821ABEE94C400FD253E4100B57404562821ABEE94C400FD253E4100B5740145D177E70E84C40AF2479AEEF095740145D177E70E84C40
26169	Алтат	5	49	1795	91.387240000000006	91.404388999999995	57.494518999999997	57.488351000000002	0103000020E61000000100000005000000FFEC478AC8D8564005FC1A4982BE4C40FFEC478AC8D8564014200A664CBF4C402D776682E1D9564014200A664CBF4C402D776682E1D9564005FC1A4982BE4C40FFEC478AC8D8564005FC1A4982BE4C40
59746	п. Катырык	5	49	1513	93.565897000000007	94.957898999999998	55.619798000000003	54.414496999999997	0103000020E61000000100000005000000E4F90CA83764574022A5D93C0E354B40E4F90CA8376457402810768A55CF4B40C0779B374EBD57402810768A55CF4B40C0779B374EBD574022A5D93C0E354B40E4F90CA83764574022A5D93C0E354B40
59765	Чистые Пруды	5	49	1513	93.565897000000007	94.957898999999998	55.619798000000003	54.414496999999997	0103000020E61000000100000005000000E4F90CA83764574022A5D93C0E354B40E4F90CA8376457402810768A55CF4B40C0779B374EBD57402810768A55CF4B40C0779B374EBD574022A5D93C0E354B40E4F90CA83764574022A5D93C0E354B40
25617	Хайдак	5	49	1513	94.060878000000002	94.105092999999997	55.472040999999997	55.463757999999999	0103000020E61000000100000005000000F0C2D66CE583574012A1116C5CBB4B40F0C2D66CE583574081AFE8D66BBC4B407782FDD7B986574081AFE8D66BBC4B407782FDD7B986574012A1116C5CBB4B40F0C2D66CE583574012A1116C5CBB4B40
19039	Хабайдак	5	49	1513	93.981780999999998	94.010985000000005	54.952615000000002	54.935136	0103000020E6100000010000000500000063B5F97FD57E5740F8A75489B2774B4063B5F97FD57E5740EB56CF49EF794B40C8EF6DFAB3805740EB56CF49EF794B40C8EF6DFAB3805740F8A75489B2774B4063B5F97FD57E5740F8A75489B2774B40
24599	Стойба	5	49	1513	94.484622000000002	94.500377999999998	55.505046999999998	55.491177	0103000020E61000000100000005000000043BFE0B049F574011C64FE3DEBE4B40043BFE0B049F5740B1F84D61A5C04B40D368723106A05740B1F84D61A5C04B40D368723106A0574011C64FE3DEBE4B40043BFE0B049F574011C64FE3DEBE4B40
25384	Солонечно-Талое	5	49	1513	94.224344000000002	94.251608000000004	55.300936	55.290197999999997	0103000020E6100000010000000500000072C3EFA65B8E5740ABAE433525A54B4072C3EFA65B8E57403318231285A64B405EDA70581A9057403318231285A64B405EDA70581A905740ABAE433525A54B4072C3EFA65B8E5740ABAE433525A54B40
26107	Партизанское	5	49	1513	94.360690000000005	94.429016000000004	55.514682000000001	55.487774999999999	0103000020E61000000100000005000000A27F828B15975740386744696FBE4B40A27F828B1597574081EB8A19E1C14B407D5D86FF749B574081EB8A19E1C14B407D5D86FF749B5740386744696FBE4B40A27F828B15975740386744696FBE4B40
17737	Ной	5	49	1513	94.276589999999999	94.300466999999998	55.551833000000002	55.538677	0103000020E61000000100000005000000A4198BA6B3915740BF0D315EF3C44B40A4198BA6B391574042EDB776A2C64B40BEA1F0D93A93574042EDB776A2C64B40BEA1F0D93A935740BF0D315EF3C44B40A4198BA6B3915740BF0D315EF3C44B40
47195	Новомихайловка	5	49	1513	94.540946000000005	94.573105999999996	55.293678999999997	55.277036000000003	0103000020E61000000100000005000000BBB9F8DB9EA2574047E867EA75A34B40BBB9F8DB9EA25740D042024697A54B400CC9C9C4ADA45740D042024697A54B400CC9C9C4ADA4574047E867EA75A34B40BBB9F8DB9EA2574047E867EA75A34B40
25948	Мина	5	49	1513	94.122007999999994	94.149199999999993	54.983989999999999	54.971826999999998	0103000020E610000001000000050000006C76A4FACE875740552FBFD3647C4B406C76A4FACE875740A7CB6262F37D4B400B24287E8C895740A7CB6262F37D4B400B24287E8C895740552FBFD3647C4B406C76A4FACE875740552FBFD3647C4B40
26017	Мана	5	49	1513	93.941833000000003	93.964893000000004	54.967852999999998	54.951099999999997	0103000020E61000000100000005000000CA52EBFD467C5740E09C11A5BD794B40CA52EBFD467C5740F12A6B9BE27B4B40EBC891CEC07D5740F12A6B9BE27B4B40EBC891CEC07D5740E09C11A5BD794B40CA52EBFD467C5740E09C11A5BD794B40
25506	Малый Имбеж	5	49	1513	94.050044	94.083029999999994	55.546812000000003	55.523800000000001	0103000020E610000001000000050000001BD7BFEB3383574089D2DEE00BC34B401BD7BFEB33835740BA8784EFFDC54B408FA50F5D50855740BA8784EFFDC54B408FA50F5D5085574089D2DEE00BC34B401BD7BFEB3383574089D2DEE00BC34B40
25926	Кой	5	49	1513	94.054885999999996	94.096029000000001	55.113529	55.088728000000003	0103000020E6100000010000000500000087C0914083835740A81E69705B8B4B4087C0914083835740E412471E888E4B40ED9DD15625865740E412471E888E4B40ED9DD15625865740A81E69705B8B4B4087C0914083835740A81E69705B8B4B40
25863	Кожелак	5	49	1513	93.985247999999999	94.026077000000001	55.347802000000001	55.332053000000002	0103000020E61000000100000005000000C39CA04D0E7F5740F4C473B680AA4B40C39CA04D0E7F5740E0BDA3C684AC4B40618BDD3EAB815740E0BDA3C684AC4B40618BDD3EAB815740F4C473B680AA4B40C39CA04D0E7F5740F4C473B680AA4B40
47174	Ивашиха	5	49	1513	94.475261000000003	94.516915999999995	55.187697	55.184438	0103000020E610000001000000050000001D041DAD6A9E5740E01115AA9B974B401D041DAD6A9E574056478E7406984B40DDB1D82615A1574056478E7406984B40DDB1D82615A15740E01115AA9B974B401D041DAD6A9E5740E01115AA9B974B40
25499	Запасной Имбеж	5	49	1513	94.103808000000001	94.134009000000006	55.570197	55.546633	0103000020E610000001000000050000000B444FCAA48657400AF5F411F8C54B400B444FCAA48657407FA31D37FCC84B40A9177C9A938857407FA31D37FCC84B40A9177C9A938857400AF5F411F8C54B400B444FCAA48657400AF5F411F8C54B40
59755	Дудинка	5	49	1513	93.565897000000007	94.957898999999998	55.619798000000003	54.414496999999997	0103000020E61000000100000005000000E4F90CA83764574022A5D93C0E354B40E4F90CA8376457402810768A55CF4B40C0779B374EBD57402810768A55CF4B40C0779B374EBD574022A5D93C0E354B40E4F90CA83764574022A5D93C0E354B40
59632	Ворогово	5	49	1513	93.565897000000007	94.957898999999998	55.619798000000003	54.414496999999997	0103000020E61000000100000005000000E4F90CA83764574022A5D93C0E354B40E4F90CA8376457402810768A55CF4B40C0779B374EBD57402810768A55CF4B40C0779B374EBD574022A5D93C0E354B40E4F90CA83764574022A5D93C0E354B40
23136	Вершино-Рыбное	5	49	1513	94.305173999999994	94.348365000000001	55.292802000000002	55.267978999999997	0103000020E61000000100000005000000BA6587F887935740E481C8224DA24B40BA6587F887935740091A33897AA54B408C84B69C4B965740091A33897AA54B408C84B69C4B965740E481C8224DA24B40BA6587F887935740E481C8224DA24B40
59775	Богуславка	5	49	1513	94.628693999999996	94.643542999999994	55.488570000000003	55.473081999999998	0103000020E61000000100000005000000404CC2853CA85740C32973F38DBC4B40404CC2853CA8574043E7357689BE4B4076A4FACE2FA9574043E7357689BE4B4076A4FACE2FA95740C32973F38DBC4B40404CC2853CA85740C32973F38DBC4B40
51794	Чулым	5	49	1737	90.498149999999995	91.788094999999998	55.249099000000001	54.627198999999997	0103000020E6100000010000000500000027A089B0E19F5640BD8A8C0E48504B4027A089B0E19F5640B03BDD79E29F4B4008C9022670F25640B03BDD79E29F4B4008C9022670F25640BD8A8C0E48504B4027A089B0E19F5640BD8A8C0E48504B40
24862	Чесноки	5	49	1737	91.532838999999996	91.545730000000006	55.207701	55.202084999999997	0103000020E6100000010000000500000022C2BF081AE256408E01D9EBDD994B4022C2BF081AE256405A2C45F2959A4B408D9C853DEDE256405A2C45F2959A4B408D9C853DEDE256408E01D9EBDD994B4022C2BF081AE256408E01D9EBDD994B40
24393	Черная Кома	5	49	1737	91.267799999999994	91.282685000000001	54.937060000000002	54.920738999999998	0103000020E610000001000000050000009A779CA223D156406C938AC6DA754B409A779CA223D15640E4310395F1774B407784D38217D25640E4310395F1774B407784D38217D256406C938AC6DA754B409A779CA223D156406C938AC6DA754B40
24994	Увалы	5	49	1737	90.976144000000005	91.000478999999999	55.114610999999996	55.108040000000003	0103000020E61000000100000005000000F20BAF2479BE564076543541D48D4B40F20BAF2479BE56408461C092AB8E4B406D5512D907C056408461C092AB8E4B406D5512D907C0564076543541D48D4B40F20BAF2479BE564076543541D48D4B40
25183	Толстый Мыс	5	49	1737	90.743129999999994	90.783355999999998	54.976142000000003	54.962690000000002	0103000020E610000001000000050000004BAB21718FAF5640D717096D397B4B404BAB21718FAF564043209738F27C4B400648348122B2564043209738F27C4B400648348122B25640D717096D397B4B404BAB21718FAF5640D717096D397B4B40
24175	Тесь	5	49	1737	91.086448000000004	91.096940000000004	54.746882999999997	54.740749999999998	0103000020E610000001000000050000007F33315D88C55640894160E5D05E4B407F33315D88C556401C78B5DC995F4B40276BD44334C656401C78B5DC995F4B40276BD44334C65640894160E5D05E4B407F33315D88C55640894160E5D05E4B40
24160	Тальцы	5	49	1737	91.154809999999998	91.167952	54.897163999999997	54.891871999999999	0103000020E6100000010000000500000000C63368E8C95640EB1B98DC28724B4000C63368E8C9564003931B45D6724B400FD3BEB9BFCA564003931B45D6724B400FD3BEB9BFCA5640EB1B98DC28724B4000C63368E8C95640EB1B98DC28724B40
24260	Табажак	5	49	1737	91.075839000000002	91.084183999999993	54.814014	54.808753000000003	0103000020E61000000100000005000000BA30D28BDAC456405DC5E23785674B40BA30D28BDAC456403A3E5A9C31684B402CB6494563C556403A3E5A9C31684B402CB6494563C556405DC5E23785674B40BA30D28BDAC456405DC5E23785674B40
33088	Светлолобово	5	49	1737	90.820547000000005	90.863414000000006	55.100278000000003	55.086315999999997	0103000020E610000001000000050000002E7590D783B456408E8F16670C8B4B402E7590D783B456401041D5E8D58C4B40263ACB2C42B756401041D5E8D58C4B40263ACB2C42B756408E8F16670C8B4B402E7590D783B456408E8F16670C8B4B40
24290	Приморский	5	49	1737	90.978712999999999	90.990803999999997	54.755580999999999	54.747537999999999	0103000020E61000000100000005000000E2CAD93BA3BE564035423F53AF5F4B40E2CAD93BA3BE56404F3DD2E0B6604B40BE2F2E5569BF56404F3DD2E0B6604B40BE2F2E5569BF564035423F53AF5F4B40E2CAD93BA3BE564035423F53AF5F4B40
23911	Новоселово	5	49	1737	90.957800000000006	90.998690999999994	55.021411000000001	54.983922999999997	0103000020E61000000100000005000000F7065F984CBD56401F645930F17D4B40F7065F984CBD564028637C98BD824B40CFF3A78DEABF564028637C98BD824B40CFF3A78DEABF56401F645930F17D4B40F7065F984CBD56401F645930F17D4B40
25060	Николаевка	5	49	1737	90.762317999999993	90.777805000000001	55.110650999999997	55.098289999999999	0103000020E61000000100000005000000BCC96FD1C9B056400DC347C4948C4B40BCC96FD1C9B056408522DDCF298E4B40946A9F8EC7B156408522DDCF298E4B40946A9F8EC7B156400DC347C4948C4B40BCC96FD1C9B056400DC347C4948C4B40
24940	Легостаево	5	49	1737	91.019523000000007	91.054315000000003	55.137234999999997	55.128844999999998	0103000020E6100000010000000500000045A165DD3FC1564066A032FE7D904B4045A165DD3FC15640EB6E9EEA90914B40AA2B9FE579C35640EB6E9EEA90914B40AA2B9FE579C3564066A032FE7D904B4045A165DD3FC1564066A032FE7D904B40
24817	Куртак	5	49	1737	91.533602000000002	91.545271	55.150647999999997	55.145708999999997	0103000020E6100000010000000500000022C5008926E25640CEDDAE97A6924B4022C5008926E25640999A046F48934B40431D56B8E5E25640999A046F48934B40431D56B8E5E25640CEDDAE97A6924B4022C5008926E25640CEDDAE97A6924B40
24718	Курганы	5	49	1737	91.307980999999998	91.324006999999995	55.184741000000002	55.179456999999999	0103000020E6100000010000000500000085B2F0F5B5D35640E6046D72F8964B4085B2F0F5B5D356407C9DD497A5974B40342BDB87BCD456407C9DD497A5974B40342BDB87BCD45640E6046D72F8964B4085B2F0F5B5D35640E6046D72F8964B40
24563	Кульчек	5	49	1737	91.400660999999999	91.429613000000003	54.918928000000001	54.902703000000002	0103000020E6100000010000000500000017F2086EA4D9564024809BC58B734B4017F2086EA4D9564079B0C56E9F754B40EF3B86C77EDB564079B0C56E9F754B40EF3B86C77EDB564024809BC58B734B4017F2086EA4D9564024809BC58B734B40
24081	Куллог	5	49	1737	91.177392999999995	91.191361999999998	54.820430999999999	54.811093	0103000020E6100000010000000500000084622B685ACB5640DC813AE5D1674B4084622B685ACB5640F2CF0CE203694B409EEC66463FCC5640F2CF0CE203694B409EEC66463FCC5640DC813AE5D1674B4084622B685ACB5640DC813AE5D1674B40
24359	Кома	5	49	1737	91.199177000000006	91.221131999999997	55.016553999999999	55.005253000000003	0103000020E610000001000000050000006347E350BFCC56405B9A5B21AC804B406347E350BFCC56401A4F04711E824B405706D50627CE56401A4F04711E824B405706D50627CE56405B9A5B21AC804B406347E350BFCC56405B9A5B21AC804B40
25143	Камчатка	5	49	1737	90.854611000000006	90.873250999999996	55.123564000000002	55.119332	0103000020E6100000010000000500000052F355F2B1B65640E2AE5E45468F4B4052F355F2B1B65640427BF5F1D08F4B40C18C2958E3B75640427BF5F1D08F4B40C18C2958E3B75640E2AE5E45468F4B4052F355F2B1B65640E2AE5E45468F4B40
25293	Интикуль	5	49	1737	90.569817999999998	90.595158999999995	54.957774000000001	54.948343999999999	0103000020E6100000010000000500000004ABEAE577A45640CDAD105663794B4004ABEAE577A45640C47AA356987A4B40E23AC61517A65640C47AA356987A4B40E23AC61517A65640CDAD105663794B4004ABEAE577A45640CDAD105663794B40
24464	Енисей	5	49	1737	91.351046999999994	91.369596999999999	55.040641999999998	55.033605000000001	0103000020E61000000100000005000000F816D68D77D65640B5FD2B2B4D844B40F816D68D77D65640096CCEC133854B40C8EC2C7AA7D75640096CCEC133854B40C8EC2C7AA7D75640B5FD2B2B4D844B40F816D68D77D65640B5FD2B2B4D844B40
24753	Дивный	5	49	1737	91.259769000000006	91.275408999999996	55.097656000000001	55.091262999999998	0103000020E61000000100000005000000F0E0270EA0D05640DC2A8881AE8B4B40F0E0270EA0D056400C21E7FD7F8C4B408A01124DA0D156400C21E7FD7F8C4B408A01124DA0D15640DC2A8881AE8B4B40F0E0270EA0D05640DC2A8881AE8B4B40
24506	Бескиш	5	49	1737	91.297633000000005	91.318510000000003	54.905513999999997	54.897126999999998	0103000020E61000000100000005000000774D486B0CD35640E6ADBA0ED5724B40774D486B0CD35640FA08FCE1E7734B40BC5CC47762D45640FA08FCE1E7734B40BC5CC47762D45640E6ADBA0ED5724B40774D486B0CD35640E6ADBA0ED5724B40
24664	Березовый	5	49	1737	91.196447000000006	91.215346999999994	55.192923999999998	55.186283000000003	0103000020E610000001000000050000006E19709692CC56408066101FD8974B406E19709692CC5640874ECFBBB1984B40AB92C83EC8CD5640874ECFBBB1984B40AB92C83EC8CD56408066101FD8974B406E19709692CC56408066101FD8974B40
25096	Бараит	5	49	1737	90.739769999999993	90.767653999999993	55.171225999999997	55.154327000000002	0103000020E61000000100000005000000F623456458AF5640E5F1B4FCC0934B40F623456458AF5640C91CCBBBEA954B4030293E3E21B15640C91CCBBBEA954B4030293E3E21B15640E5F1B4FCC0934B40F623456458AF5640E5F1B4FCC0934B40
25223	Аёшка	5	49	1737	90.837784999999997	90.861079000000004	54.924396999999999	54.920366000000001	0103000020E610000001000000050000001405FA449EB55640D82C978DCE754B401405FA449EB55640A0C211A452764B406F1118EB1BB75640A0C211A452764B406F1118EB1BB75640D82C978DCE754B401405FA449EB55640D82C978DCE754B40
24075	Анаш	5	49	1737	91.043086000000002	91.071087000000006	54.877034999999999	54.865009999999998	0103000020E61000000100000005000000973AC8EBC1C25640425BCEA5B86E4B40973AC8EBC1C256404339D1AE42704B40EE0A7DB08CC456404339D1AE42704B40EE0A7DB08CC45640425BCEA5B86E4B40973AC8EBC1C25640425BCEA5B86E4B40
22605	Южная Тунгуска	5	49	1163	97.418977999999996	97.446124999999995	56.498629000000001	56.482970000000002	0103000020E6100000010000000500000095EF1989D05A58407D7901F6D13D4C4095EF1989D05A584029EB3713D33F4C40643BDF4F8D5C584029EB3713D33F4C40643BDF4F8D5C58407D7901F6D13D4C4095EF1989D05A58407D7901F6D13D4C40
23032	Эстония	5	49	1163	96.487452000000005	96.507887999999994	56.402774999999998	56.395361999999999	0103000020E61000000100000005000000AB97DF69321F5840630AD6389B324C40AB97DF69321F5840BD5296218E334C40F981AB3C81205840BD5296218E334C40F981AB3C81205840630AD6389B324C40AB97DF69321F5840630AD6389B324C40
23625	Тины	5	49	1163	96.834245999999993	96.914017000000001	56.135413	56.115931000000003	0103000020E6100000010000000500000067B4554964355840DACBB6D3D60E4C4067B4554964355840043A933655114C403CBF28417F3A5840043A933655114C403CBF28417F3A5840DACBB6D3D60E4C4067B4554964355840DACBB6D3D60E4C40
21152	Тинской	5	49	1163	96.893320000000003	96.974788000000004	56.180177	56.130240999999998	0103000020E610000001000000050000003737A6272C39584096CCB1BCAB104C403737A6272C395840E63E390A10174C40212235ED623E5840E63E390A10174C40212235ED623E584096CCB1BCAB104C403737A6272C39584096CCB1BCAB104C40
51776	Тинской	5	49	1163	96.893320000000003	96.974788000000004	56.180177	56.130240999999998	0103000020E610000001000000050000003737A6272C39584096CCB1BCAB104C403737A6272C395840E63E390A10174C40212235ED623E5840E63E390A10174C40212235ED623E584096CCB1BCAB104C403737A6272C39584096CCB1BCAB104C40
23134	Стретенка	5	49	1163	96.392652999999996	96.416304999999994	56.471805000000003	56.459547000000001	0103000020E61000000100000005000000486B0C3A21195840CAFCA36FD23A4C40486B0C3A211958406E8B321B643C4C40520ABABDA41A58406E8B321B643C4C40520ABABDA41A5840CAFCA36FD23A4C40486B0C3A21195840CAFCA36FD23A4C40
59681	Старцево	5	49	1163	96.206098999999995	97.879992999999999	56.826611	55.815398000000002	0103000020E61000000100000005000000402FDCB9300D5840A69C2FF65EE84B40402FDCB9300D5840C6C1A563CE694C405FED28CE51785840C6C1A563CE694C405FED28CE51785840A69C2FF65EE84B40402FDCB9300D5840A69C2FF65EE84B40
20905	Соколовка	5	49	1163	96.715929000000003	96.762254999999996	56.381898	56.366675000000001	0103000020E610000001000000050000008350DEC7D12D584062A1D634EF2E4C408350DEC7D12D584033349E08E2304C40990D32C9C830584033349E08E2304C40990D32C9C830584062A1D634EF2E4C408350DEC7D12D584062A1D634EF2E4C40
23510	Поскотино	5	49	1163	96.287074000000004	96.313806999999997	56.475752	56.47175	0103000020E610000001000000050000000B62A06B5F125840AAF1D24D623C4C400B62A06B5F125840D8800871E53C4C406090F46915145840D8800871E53C4C406090F46915145840AAF1D24D623C4C400B62A06B5F125840AAF1D24D623C4C40
23127	Покровка	5	49	1163	96.761519000000007	96.772227000000001	56.428109999999997	56.416535000000003	0103000020E61000000100000005000000171230BABC305840D751D50451354C40171230BABC305840978BF84ECC364C40A585CB2A6C315840978BF84ECC364C40A585CB2A6C315840D751D50451354C40171230BABC305840D751D50451354C40
22600	Поканаевка	5	49	1163	97.634186999999997	97.681331	56.524635000000004	56.502136999999998	0103000020E610000001000000050000001823128596685840478E740646404C40182312859668584022AB5B3D27434C4010B056ED9A6B584022AB5B3D27434C4010B056ED9A6B5840478E740646404C401823128596685840478E740646404C40
18235	Поймо-Тины	5	49	1163	96.725612999999996	96.747415000000004	56.079518	56.064987000000002	0103000020E610000001000000050000005B238271702E584024D5777E51084C405B238271702E5840BFB854A52D0A4C408D62B9A5D52F5840BFB854A52D0A4C408D62B9A5D52F584024D5777E51084C405B238271702E584024D5777E51084C40
23043	Павловка	5	49	1163	96.614033000000006	96.632170000000002	56.090356999999997	56.081823	0103000020E610000001000000050000008C6A11514C275840C287122D790A4C408C6A11514C2758407AFB73D1900B4C40CAE02879752858407AFB73D1900B4C40CAE0287975285840C287122D790A4C408C6A11514C275840C287122D790A4C40
59727	Ошарово	5	49	1163	96.740686999999994	96.774085999999997	56.277858000000002	56.275838999999998	0103000020E61000000100000005000000A164726A672F58400DFB3DB14E234C40A164726A672F58404B77D7D990234C40A79201A08A3158404B77D7D990234C40A79201A08A3158400DFB3DB14E234C40A164726A672F58400DFB3DB14E234C40
14269	Ошарово	5	49	1163	96.740686999999994	96.774085999999997	56.277858000000002	56.275838999999998	0103000020E61000000100000005000000A164726A672F58400DFB3DB14E234C40A164726A672F58404B77D7D990234C40A79201A08A3158404B77D7D990234C40A79201A08A3158400DFB3DB14E234C40A164726A672F58400DFB3DB14E234C40
23588	Новорождественка	5	49	1163	96.411580000000001	96.432115999999994	56.439239000000001	56.431251000000003	0103000020E6100000010000000500000003ECA353571A584004AF963B33374C4003ECA353571A58405A10CAFB38384C400305DEC9A71B58405A10CAFB38384C400305DEC9A71B584004AF963B33374C4003ECA353571A584004AF963B33374C40
21588	Новоалександровка	5	49	1163	96.564616999999998	96.594594000000001	56.426622000000002	56.418447	0103000020E61000000100000005000000007157AF22245840FE0DDAAB8F354C40007157AF2224584087E0B88C9B364C407619FED30D26584087E0B88C9B364C407619FED30D265840FE0DDAAB8F354C40007157AF22245840FE0DDAAB8F354C40
22509	Новая Пойма	5	49	1163	96.581909999999993	96.603145999999995	56.180708000000003	56.176900000000003	0103000020E61000000100000005000000C8CD70033E255840CA54C1A8A4164C40C8CD70033E2558401310937021174C40A52DAEF1992658401310937021174C40A52DAEF199265840CA54C1A8A4164C40C8CD70033E255840CA54C1A8A4164C40
59487	Нижняя Пойма	5	49	1163	97.157550000000001	97.236789999999999	56.181705000000001	56.146653000000001	0103000020E61000000100000005000000075F984C154A58401E6E8786C5124C40075F984C154A58408542041C42174C4045813E91274F58408542041C42174C4045813E91274F58401E6E8786C5124C40075F984C154A58401E6E8786C5124C40
22054	Нижняя Пойма	5	49	1163	97.157550000000001	97.236789999999999	56.181705000000001	56.146653000000001	0103000020E61000000100000005000000075F984C154A58401E6E8786C5124C40075F984C154A58408542041C42174C4045813E91274F58408542041C42174C4045813E91274F58401E6E8786C5124C40075F984C154A58401E6E8786C5124C40
51848	Нижний Ингаш	5	49	1163	96.493928999999994	96.572765000000004	56.217615000000002	56.174228999999997	0103000020E61000000100000005000000F16261889C1F5840E481C8224D164C40F16261889C1F58403D0FEECEDA1B4C40C8D2872EA82458403D0FEECEDA1B4C40C8D2872EA8245840E481C8224D164C40F16261889C1F5840E481C8224D164C40
21653	Нижний Ингаш	5	49	1163	96.493928999999994	96.572765000000004	56.217615000000002	56.174228999999997	0103000020E61000000100000005000000F16261889C1F5840E481C8224D164C40F16261889C1F58403D0FEECEDA1B4C40C8D2872EA82458403D0FEECEDA1B4C40C8D2872EA8245840E481C8224D164C40F16261889C1F5840E481C8224D164C40
17906	Михайловка	5	49	1163	96.622882000000004	96.652040999999997	56.348337000000001	56.339860999999999	0103000020E6100000010000000500000018D1764CDD275840CA17B490802B4C4018D1764CDD2758404E7E8B4E962C4C40ACA92C0ABB2958404E7E8B4E962C4C40ACA92C0ABB295840CA17B490802B4C4018D1764CDD275840CA17B490802B4C40
22777	Максаковка	5	49	1163	96.506236000000001	96.529393999999996	56.264487000000003	56.258963000000001	0103000020E61000000100000005000000B403AE2B66205840E1EF17B325214C40B403AE2B66205840CC9BC3B5DA214C40B62C5F97E1215840CC9BC3B5DA214C40B62C5F97E1215840E1EF17B325214C40B403AE2B66205840E1EF17B325214C40
22865	Кучерово	5	49	1163	96.948008999999999	96.980474000000001	56.317697000000003	56.301558999999997	0103000020E6100000010000000500000013D4F02DAC3C584040683D7C99264C4013D4F02DAC3C5840C784984BAA284C4003250516C03E5840C784984BAA284C4003250516C03E584040683D7C99264C4013D4F02DAC3C584040683D7C99264C40
22232	Курдояки	5	49	1163	97.241111000000004	97.256885999999994	56.092069000000002	56.086992000000002	0103000020E610000001000000050000002DEDD45C6E4F5840BF81C98D220B4C402DEDD45C6E4F5840DBFCBFEAC80B4C403733FAD170505840DBFCBFEAC80B4C403733FAD170505840BF81C98D220B4C402DEDD45C6E4F5840BF81C98D220B4C40
21190	Кедровый	5	49	1163	97.690521000000004	97.711460000000002	56.553699999999999	56.540967000000002	0103000020E61000000100000005000000E10CFE7E316C58408D9B1A683E454C40E10CFE7E316C5840C9E53FA4DF464C40611A868F886D5840C9E53FA4DF464C40611A868F886D58408D9B1A683E454C40E10CFE7E316C58408D9B1A683E454C40
18111	Касьяново	5	49	1163	96.345760999999996	96.363071000000005	56.064464000000001	56.051048999999999	0103000020E61000000100000005000000DDCEBEF2201658402BBF0CC688064C40DDCEBEF2201658407AE2395B40084C4011C8258E3C1758407AE2395B40084C4011C8258E3C1758402BBF0CC688064C40DDCEBEF2201658402BBF0CC688064C40
21288	Канифольный	5	49	1163	97.311224999999993	97.369749999999996	56.277628	56.254322000000002	0103000020E61000000100000005000000A52C431CEB535840A053909F8D204C40A52C431CEB535840193A765089234C408B6CE7FBA9575840193A765089234C408B6CE7FBA9575840A053909F8D204C40A52C431CEB535840A053909F8D204C40
22767	Ивановка	5	49	1163	96.500557999999998	96.527445	56.318336000000002	56.304609999999997	0103000020E6100000010000000500000013F06B24092058406C04E275FD264C4013F06B2409205840DA91EA3BBF284C40145CACA8C1215840DA91EA3BBF284C40145CACA8C12158406C04E275FD264C4013F06B24092058406C04E275FD264C40
18157	Елизаветка	5	49	1163	97.038137000000006	97.065085999999994	56.139676999999999	56.129669	0103000020E6100000010000000500000020F12BD6704258400B2769FE98104C4020F12BD6704258406F8099EFE0114C405B5B785E2A4458406F8099EFE0114C405B5B785E2A4458400B2769FE98104C4020F12BD6704258400B2769FE98104C40
21230	Верхний Ингаш	5	49	1163	96.404006999999993	96.457240999999996	56.211243000000003	56.205765999999997	0103000020E61000000100000005000000B9162D40DB1958407A50508A561A4C40B9162D40DB1958402541B8020A1B4C40FB58C16F431D58402541B8020A1B4C40FB58C16F431D58407A50508A561A4C40B9162D40DB1958407A50508A561A4C40
22847	Бельняки	5	49	1163	97.230717999999996	97.248154	56.245944999999999	56.232298	0103000020E610000001000000050000004E266E15C44E58408E76DCF0BB1D4C404E266E15C44E5840AFCE31207B1F4C40C89750C1E14F5840AFCE31207B1F4C40C89750C1E14F58408E76DCF0BB1D4C404E266E15C44E58408E76DCF0BB1D4C40
22683	Александровка	5	49	1163	97.002437999999998	97.025345000000002	56.348497000000002	56.331149000000003	0103000020E610000001000000050000002191B6F127405840338D2617632A4C402191B6F12740584087E0B88C9B2C4C407F87A2409F41584087E0B88C9B2C4C407F87A2409F415840338D2617632A4C402191B6F127405840338D2617632A4C40
2904	Ярлыково	5	49	79	90.746813000000003	90.77149	56.012887999999997	56.003234999999997	0103000020E6100000010000000500000092CEC0C8CBAF5640ED9925016A004C4092CEC0C8CBAF564063416150A6014C403ACC971760B1564063416150A6014C403ACC971760B15640ED9925016A004C4092CEC0C8CBAF5640ED9925016A004C40
59864	Шипиловка	5	49	79	89.959762999999995	89.986002999999997	55.780552	55.773296999999999	0103000020E610000001000000050000004B3ACAC16C7D5640268C6665FBE24B404B3ACAC16C7D5640E869C020E9E34B4081B053AC1A7F5640E869C020E9E34B4081B053AC1A7F5640268C6665FBE24B404B3ACAC16C7D5640268C6665FBE24B40
49407	Чердынь	5	49	79	90.318720999999996	90.328845000000001	55.874237999999998	55.867243000000002	0103000020E6100000010000000500000019E3C3EC65945640AC5791D101EF4B4019E3C3EC65945640D175E107E7EF4B40001DE6CB0B955640D175E107E7EF4B40001DE6CB0B955640AC5791D101EF4B4019E3C3EC65945640AC5791D101EF4B40
21018	Холма	5	49	79	90.647773999999998	90.667554999999993	55.807870000000001	55.799112000000001	0103000020E61000000100000005000000BE4C142175A95640ABEB504D49E64B40BE4C142175A95640B3B5BE4868E74B4000529B38B9AA5640B3B5BE4868E74B4000529B38B9AA5640ABEB504D49E64B40BE4C142175A95640ABEB504D49E64B40
49599	Усть-Березовка	5	49	79	90.392814000000001	90.415899999999993	55.796309000000001	55.792017000000001	0103000020E610000001000000050000004DDA54DD23995640227024D060E54B404DDA54DD2399564057410C74EDE54B40029A081B9E9A564057410C74EDE54B40029A081B9E9A5640227024D060E54B404DDA54DD23995640227024D060E54B40
19270	Степноозерка	5	49	79	90.121557999999993	90.152208999999999	55.739848000000002	55.733964	0103000020E610000001000000050000004CA4349BC78756407E384888F2DD4B404CA4349BC78756406901DA56B3DE4B400A4AD1CABD8956406901DA56B3DE4B400A4AD1CABD8956407E384888F2DD4B404CA4349BC78756407E384888F2DD4B40
49478	Степной	5	49	79	90.412406000000004	90.443990999999997	55.706665000000001	55.692424000000003	0103000020E6100000010000000500000026AB22DC649A5640967B8159A1D84B4026AB22DC649A56402A1DACFF73DA4B40F92D3A596A9C56402A1DACFF73DA4B40F92D3A596A9C5640967B8159A1D84B4026AB22DC649A5640967B8159A1D84B40
20677	Старожилово	5	49	79	90.876575000000003	90.884919999999994	55.833466000000001	55.826695000000001	0103000020E61000000100000005000000705F07CE19B8564024624A24D1E94B40705F07CE19B85640FA298E03AFEA4B40E2E47E87A2B85640FA298E03AFEA4B40E2E47E87A2B8564024624A24D1E94B40705F07CE19B8564024624A24D1E94B40
21282	Средняя Березовка	5	49	79	90.349659000000003	90.375225	55.751649	55.742068000000003	0103000020E61000000100000005000000227024D0609656403EB48F15FCDE4B40227024D0609656401A89D00836E04B4010E9B7AF039856401A89D00836E04B4010E9B7AF039856403EB48F15FCDE4B40227024D0609656403EB48F15FCDE4B40
18967	Сохновка	5	49	79	90.171424000000002	90.187746000000004	55.963793000000003	55.957166999999998	0103000020E61000000100000005000000F86F5E9CF88A5640BCE7C07284FA4B40F86F5E9CF88A56408F8EAB915DFB4B401C7DCC07048C56408F8EAB915DFB4B401C7DCC07048C5640BCE7C07284FA4B40F86F5E9CF88A5640BCE7C07284FA4B40
20610	Скоробогатово	5	49	79	90.865201999999996	90.886869000000004	55.759217999999997	55.756118000000001	0103000020E61000000100000005000000C39B35785FB756405EF58079C8E04B40C39B35785FB756406B44300E2EE14B4085B53176C2B856406B44300E2EE14B4085B53176C2B856405EF58079C8E04B40C39B35785FB756405EF58079C8E04B40
49435	Сереуль	5	49	79	90.529123999999996	90.551940999999999	55.796415000000003	55.787239	0103000020E61000000100000005000000D6E1E82ADDA1564060915F3FC4E44B40D6E1E82ADDA156409D853DEDF0E54B409414580053A356409D853DEDF0E54B409414580053A3564060915F3FC4E44B40D6E1E82ADDA1564060915F3FC4E44B40
18651	Сереж	5	49	79	90.196100999999999	90.202603999999994	55.860585	55.857537999999998	0103000020E61000000100000005000000A06D35EB8C8C5640E38920CEC3ED4B40A06D35EB8C8C5640CE3637A627EE4B407B82C476F78C5640CE3637A627EE4B407B82C476F78C5640E38920CEC3ED4B40A06D35EB8C8C5640E38920CEC3ED4B40
20717	Селедково	5	49	79	91.035045999999994	91.049096000000006	55.896807000000003	55.889986999999998	0103000020E61000000100000005000000C2F693313EC25640BD6E1118EBF14B40C2F693313EC2564075E95F92CAF24B4053978C6324C3564075E95F92CAF24B4053978C6324C35640BD6E1118EBF14B40C2F693313EC25640BD6E1118EBF14B40
20930	Сахапта	5	49	79	90.676276999999999	90.704555999999997	55.768061000000003	55.749814999999998	0103000020E610000001000000050000005E82531F48AB56406E861BF0F9DF4B405E82531F48AB5640A22AA6D24FE24B40D68C0C7217AD5640A22AA6D24FE24B40D68C0C7217AD56406E861BF0F9DF4B405E82531F48AB56406E861BF0F9DF4B40
49058	Прогресс	5	49	79	90.046756000000002	90.053061999999997	55.844430000000003	55.832433999999999	0103000020E6100000010000000500000013B9E00CFE8256400B0A83328DEA4B4013B9E00CFE82564072E1404816EC4B4043AA285E6583564072E1404816EC4B4043AA285E658356400B0A83328DEA4B4013B9E00CFE8256400B0A83328DEA4B40
20790	Преображенский	5	49	79	90.428261000000006	90.447198	55.946330000000003	55.927992000000003	0103000020E61000000100000005000000BF49D3A0689B56408E791D71C8F64B40BF49D3A0689B5640A29C685721F94B408B355CE49E9C5640A29C685721F94B408B355CE49E9C56408E791D71C8F64B40BF49D3A0689B56408E791D71C8F64B40
49487	Предгорный	5	49	79	90.249964000000006	90.263150999999993	55.642696999999998	55.635894	0103000020E610000001000000050000005A4B0169FF8F56407FDC7EF964D14B405A4B0169FF8F5640601E32E543D24B4038BA4A77D7905640601E32E543D24B4038BA4A77D79056407FDC7EF964D14B405A4B0169FF8F56407FDC7EF964D14B40
20566	Подсосное	5	49	79	90.992887999999994	91.017853000000002	55.856451999999997	55.830446999999999	0103000020E61000000100000005000000D0251C7A8BBF5640D90759164CEA4B40D0251C7A8BBF5640014C1938A0ED4B40ACC8E88024C15640014C1938A0ED4B40ACC8E88024C15640D90759164CEA4B40D0251C7A8BBF5640D90759164CEA4B40
40386	Петровка	5	49	79	90.055766000000006	90.064892999999998	55.851838999999998	55.846274999999999	0103000020E61000000100000005000000A48E8EAB9183564011363CBD52EC4B40A48E8EAB918356408A3A730F09ED4B40512FF834278456408A3A730F09ED4B40512FF8342784564011363CBD52EC4B40A48E8EAB9183564011363CBD52EC4B40
51909	Новоалександровка	5	49	79	90.626789000000002	90.638979000000006	55.592424000000001	55.583891999999999	0103000020E61000000100000005000000861F9C4F1DA85640B1321AF9BCCA4B40861F9C4F1DA85640C9AEB48CD4CB4B402CF52C08E5A85640C9AEB48CD4CB4B402CF52C08E5A85640B1321AF9BCCA4B40861F9C4F1DA85640B1321AF9BCCA4B40
20189	Новая Сокса	5	49	79	89.836962999999997	89.857059000000007	55.687339999999999	55.672508999999998	0103000020E61000000100000005000000923D42CD9075564001A260C614D64B40923D42CD90755640C79DD2C1FAD74B4085EFFD0DDA765640C79DD2C1FAD74B4085EFFD0DDA76564001A260C614D64B40923D42CD9075564001A260C614D64B40
19072	Нижний Ададым	5	49	79	90.274218000000005	90.293612999999993	55.919497999999997	55.910088999999999	0103000020E610000001000000050000005F7EA7C98C91564084B9DDCB7DF44B405F7EA7C98C915640635E471CB2F54B408C2B2E8ECA925640635E471CB2F54B408C2B2E8ECA92564084B9DDCB7DF44B405F7EA7C98C91564084B9DDCB7DF44B40
95	Назарово	5	49	79	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
49575	Московка	5	49	79	90.569647000000003	90.595518999999996	55.636671	55.628301999999998	0103000020E61000000100000005000000EED0B01875A4564075012F336CD04B40EED0B01875A45640E3A7716F7ED14B406249B9FB1CA65640E3A7716F7ED14B406249B9FB1CA6564075012F336CD04B40EED0B01875A4564075012F336CD04B40
59801	Медведовск	5	49	79	90.476600000000005	90.496928999999994	55.693997000000003	55.681812999999998	0103000020E610000001000000050000008351499D809E56406B7EFCA545D74B408351499D809E5640D542C9E4D4D84B40C6DB4AAFCD9F5640D542C9E4D4D84B40C6DB4AAFCD9F56406B7EFCA545D74B408351499D809E56406B7EFCA545D74B40
48519	Лесные Поляны	5	49	79	90.708292999999998	90.720428999999996	55.928289999999997	55.920133999999997	0103000020E6100000010000000500000016BF29AC54AD564005F86EF3C6F54B4016BF29AC54AD5640179AEB34D2F64B40C2853C821BAE5640179AEB34D2F64B40C2853C821BAE564005F86EF3C6F54B4016BF29AC54AD564005F86EF3C6F54B40
20361	Куличка	5	49	79	89.668869999999998	89.685794999999999	55.994632000000003	55.988056999999998	0103000020E61000000100000005000000A2D11DC4CE6A5640BCCADAA678FE4B40A2D11DC4CE6A56400DC7F31950FF4B40A930B610E46B56400DC7F31950FF4B40A930B610E46B5640BCCADAA678FE4B40A2D11DC4CE6A5640BCCADAA678FE4B40
49504	Красногорский	5	49	79	90.379626000000002	90.386876000000001	55.625857000000003	55.617947000000001	0103000020E6100000010000000500000086ADD9CA4B985640A6D425E318CF4B4086ADD9CA4B985640817C09151CD04B40DEE68D93C2985640817C09151CD04B40DEE68D93C2985640A6D425E318CF4B4086ADD9CA4B985640A6D425E318CF4B40
19764	Красная Сопка	5	49	79	90.015880999999993	90.060653000000002	55.709972	55.691657999999997	0103000020E610000001000000050000002DE8BD31048156402502D53F88D84B402DE8BD3104815640B189CC5CE0DA4B40E0D91EBDE1835640B189CC5CE0DA4B40E0D91EBDE18356402502D53F88D84B402DE8BD31048156402502D53F88D84B40
48237	Красная Поляна	5	49	79	90.650801000000001	90.679564999999997	55.962679000000001	55.934269999999998	0103000020E6100000010000000500000010CD3CB9A6A9564024D1CB2896F74B4010CD3CB9A6A95640E3C5C21039FB4B4066A032FE7DAB5640E3C5C21039FB4B4066A032FE7DAB564024D1CB2896F74B4010CD3CB9A6A9564024D1CB2896F74B40
45351	Кольцово	5	49	79	90.266105999999994	90.291942000000006	55.788767999999997	55.785367000000001	0103000020E610000001000000050000003DD175E107915640C72DE6E786E44B403DD175E107915640CF108E59F6E44B400C957F2DAF925640CF108E59F6E44B400C957F2DAF925640C72DE6E786E44B403DD175E107915640C72DE6E786E44B40
19457	Кибитень	5	49	79	90.036524	90.066743000000002	55.803731999999997	55.794659000000003	0103000020E610000001000000050000003961C268568256406D3CD862B7E54B403961C26856825640D45FAFB0E0E64B402A8F6E8445845640D45FAFB0E0E64B402A8F6E84458456406D3CD862B7E54B403961C268568256406D3CD862B7E54B40
20016	Каргала	5	49	79	89.880459999999999	89.907391000000004	55.779727000000001	55.772162999999999	0103000020E61000000100000005000000EA5BE674597856403317B83CD6E24B40EA5BE6745978564073672618CEE34B40D36BB3B1127A564073672618CEE34B40D36BB3B1127A56403317B83CD6E24B40EA5BE674597856403317B83CD6E24B40
49458	Канаш	5	49	79	90.760358999999994	90.771327999999997	55.705036999999997	55.698968999999998	0103000020E61000000100000005000000088ECBB8A9B056407BF5F1D077D94B40088ECBB8A9B0564027BC04A73EDA4B404D9F1D705DB1564027BC04A73EDA4B404D9F1D705DB156407BF5F1D077D94B40088ECBB8A9B056407BF5F1D077D94B40
49038	Зеленая Горка	5	49	79	89.936182000000002	89.953304000000003	55.896352	55.891365	0103000020E61000000100000005000000A646E867EA7B564047E6913F18F24B40A646E867EA7B564023DA8EA9BBF24B4058C9C7EE027D564023DA8EA9BBF24B4058C9C7EE027D564047E6913F18F24B40A646E867EA7B564047E6913F18F24B40
20347	Захаринка	5	49	79	89.850482999999997	89.874459000000002	56.02937	56.016939000000001	0103000020E6100000010000000500000074B33F506E7656407383A10E2B024C4074B33F506E765640E4BD6A65C2034C4058ACE122F7775640E4BD6A65C2034C4058ACE122F77756407383A10E2B024C4074B33F506E7656407383A10E2B024C40
19344	Зарянка	5	49	79	90.051032000000006	90.060410000000005	55.899033000000003	55.892446	0103000020E610000001000000050000002BC3B81B4483564017B9A7AB3BF24B402BC3B81B448356402C836A8313F34B407D96E7C1DD8356402C836A8313F34B407D96E7C1DD83564017B9A7AB3BF24B402BC3B81B4483564017B9A7AB3BF24B40
49587	Жгутово	5	49	79	90.436687000000006	90.443038999999999	55.676046999999997	55.668762000000001	0103000020E61000000100000005000000A8E507AEF29B56405E6743FE99D54B40A8E507AEF29B56408AC745B588D64B4090F63FC05A9C56408AC745B588D64B4090F63FC05A9C56405E6743FE99D54B40A8E507AEF29B56405E6743FE99D54B40
48918	Ельник	5	49	79	90.029391000000004	90.044088000000002	55.942630000000001	55.929882999999997	0103000020E61000000100000005000000FEF2C98AE18156409D0DF96706F74B40FEF2C98AE18156403F1D8F19A8F84B4059897956D28256403F1D8F19A8F84B4059897956D28256409D0DF96706F74B40FEF2C98AE18156409D0DF96706F74B40
33058	Дорохово	5	49	79	90.220768000000007	90.331827000000004	56.054597999999999	56.014885999999997	0103000020E6100000010000000500000037001B10218E56408995D1C8E7014C4037001B10218E5640A8363811FD064C40823B50A73C955640A8363811FD064C40823B50A73C9556408995D1C8E7014C4037001B10218E56408995D1C8E7014C40
19557	Голубки	5	49	79	90.190602999999996	90.200646000000006	55.789644000000003	55.785549000000003	0103000020E610000001000000050000003FE1ECD6328C5640E833A0DE8CE44B403FE1ECD6328C5640C7BDF90D13E54B40B0045262D78C5640C7BDF90D13E54B40B0045262D78C5640E833A0DE8CE44B403FE1ECD6328C5640E833A0DE8CE44B40
19153	Глядень	5	49	79	90.123930000000001	90.153925000000001	55.794477000000001	55.767246	0103000020E61000000100000005000000923F1878EE87564050FEEE1D35E24B40923F1878EE8756404C361E6CB1E54B405B423EE8D98956404C361E6CB1E54B405B423EE8D989564050FEEE1D35E24B40923F1878EE87564050FEEE1D35E24B40
49121	Владимировка	5	49	79	90.507744000000002	90.538304999999994	56.022649999999999	56.010804999999998	0103000020E6100000010000000500000060AFB0E07EA056400FD1E80E62014C4060AFB0E07EA0564090A0F831E6024C407D91D09673A2564090A0F831E6024C407D91D09673A256400FD1E80E62014C4060AFB0E07EA056400FD1E80E62014C40
21376	Верхняя Березовка	5	49	79	90.270669999999996	90.298930999999996	55.692115000000001	55.680239999999998	0103000020E61000000100000005000000888043A8529156402CB7B41A12D74B40888043A85291564018096D3997D84B40AD307DAF2193564018096D3997D84B40AD307DAF219356402CB7B41A12D74B40888043A8529156402CB7B41A12D74B40
18923	Верхний Ададым	5	49	79	90.184736999999998	90.232266999999993	55.913120999999997	55.902746999999998	0103000020E610000001000000050000001D5723BBD28B5640F3C7B4368DF34B401D5723BBD28B564039252026E1F44B40293C6876DD8E564039252026E1F44B40293C6876DD8E5640F3C7B4368DF34B401D5723BBD28B5640F3C7B4368DF34B40
20151	Большая Сосновка	5	49	79	90.026067999999995	90.046746999999996	55.686371000000001	55.674742000000002	0103000020E6100000010000000500000037DE1D19AB8156406B9E23F25DD64B4037DE1D19AB8156401FF64201DBD74B40E90B21E7FD8256401FF64201DBD74B40E90B21E7FD8256406B9E23F25DD64B4037DE1D19AB8156406B9E23F25DD64B40
59764	Березовая Роща	5	49	79	90.012467000000001	90.024045999999998	55.724814000000002	55.720498999999997	0103000020E61000000100000005000000DF516342CC8056407DE6AC4F39DC4B40DF516342CC8056406BD784B4C6DC4B4060E63BF8898156406BD784B4C6DC4B4060E63BF8898156407DE6AC4F39DC4B40DF516342CC8056407DE6AC4F39DC4B40
49196	Березняки	5	49	79	89.841274999999996	89.851748999999998	55.726030999999999	55.719850000000001	0103000020E6100000010000000500000050FC1873D77556404703780B24DC4B4050FC1873D7755640EB707495EEDC4B40A5D93C0E83765640EB707495EEDC4B40A5D93C0E837656404703780B24DC4B4050FC1873D77556404703780B24DC4B40
48976	Антропово	5	49	79	90.138706999999997	90.155496999999997	55.825617999999999	55.806170999999999	0103000020E610000001000000050000007B2E5393E0885640E7FD7F9C30E74B407B2E5393E0885640957EC2D9ADE94B401268B0A9F3895640957EC2D9ADE94B401268B0A9F3895640E7FD7F9C30E74B407B2E5393E0885640E7FD7F9C30E74B40
59568	п. Мотыгино	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
51853	Южно-Енисейск	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
18820	Слюдрудник	5	49	1541	94.180820999999995	94.204042000000001	57.991326000000001	57.977817999999999	0103000020E61000000100000005000000855B3E92928B574056B8E52329FD4C40855B3E92928B574056D636C5E3FE4C40AB402D060F8D574056D636C5E3FE4C40AB402D060F8D574056B8E52329FD4C40855B3E92928B574056B8E52329FD4C40
59587	Поселок Раздолинск	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
59677	Первомайск	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
59710	Партизанск	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
59714	Орджоникидзе	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
51771	Новоангарск	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
48195	Никольск	5	49	1541	94.247601000000003	94.256045999999998	57.883735999999999	57.880065999999999	0103000020E610000001000000050000003E5DDDB1D88F57402829B000A6F04C403E5DDDB1D88F57402026E1421EF14C406211C30E639057402026E1421EF14C406211C30E639057402829B000A6F04C403E5DDDB1D88F57402829B000A6F04C40
59678	Мотыгино	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
18329	Машуковка	5	49	1541	94.361373	94.419107999999994	57.805633999999998	57.783098000000003	0103000020E61000000100000005000000132A38BC2097574011C8258E3CE44C40132A38BC20975740D845D1031FE74C407C5F5CAAD29A5740D845D1031FE74C407C5F5CAAD29A574011C8258E3CE44C40132A38BC2097574011C8258E3CE44C40
59730	Кирсантьево	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
59809	Бельск	5	49	1541	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
17736	имени Крупской	5	49	1439	91.952028999999996	91.968603000000002	53.694603999999998	53.690973999999997	0103000020E61000000100000005000000FDF50A0BEEFC5640723106D671D84A40FDF50A0BEEFC5640DCD5ABC8E8D84A40AEF36F97FDFD5640DCD5ABC8E8D84A40AEF36F97FDFD5640723106D671D84A40FDF50A0BEEFC5640723106D671D84A40
17308	Шошино	5	49	1439	92.426483000000005	92.453792000000007	53.823867	53.813155999999999	0103000020E6100000010000000500000033535A7F4B1B5740E945ED7E15E84A4033535A7F4B1B574077A04E7974E94A40EFCB99ED0A1D574077A04E7974E94A40EFCB99ED0A1D5740E945ED7E15E84A4033535A7F4B1B5740E945ED7E15E84A40
17934	Тигрицкое	5	49	1439	92.406369999999995	92.431927000000002	53.601661	53.586323	0103000020E61000000100000005000000D50451F7011A574041F2CEA10CCB4A40D50451F7011A5740AB23473A03CD4A409AD024B1A41B5740AB23473A03CD4A409AD024B1A41B574041F2CEA10CCB4A40D50451F7011A574041F2CEA10CCB4A40
16648	Тесь	5	49	1439	92.166798	92.199640000000002	53.879541000000003	53.857072000000002	0103000020E6100000010000000500000072C284D1AC0A57409E280989B4ED4A4072C284D1AC0A5740DE3EABCC94F04A404DBED9E6C60C5740DE3EABCC94F04A404DBED9E6C60C57409E280989B4ED4A4072C284D1AC0A57409E280989B4ED4A40
17492	Сухое Озеро	5	49	1439	91.891743000000005	91.905261999999993	53.611742	53.603360000000002	0103000020E61000000100000005000000F75B3B5112F9564077DB85E63ACD4A40F75B3B5112F9564079CBD58F4DCE4A40F01307D0EFF9564079CBD58F4DCE4A40F01307D0EFF9564077DB85E63ACD4A40F75B3B5112F9564077DB85E63ACD4A40
16583	Суходол	5	49	1439	91.767694000000006	91.787394000000006	53.788938000000002	53.780549000000001	0103000020E6100000010000000500000078D503E621F1564077F69507E9E34A4078D503E621F156402C499EEBFBE44A4044C4CDA964F256402C499EEBFBE44A4044C4CDA964F2564077F69507E9E34A4078D503E621F1564077F69507E9E34A40
17248	Солдатово	5	49	1439	91.833415000000002	91.853123999999994	53.662252000000002	53.654274000000001	0103000020E61000000100000005000000BC3FDEAB56F55640C24F1C40BFD34A40BC3FDEAB56F55640F5DA6CACC4D44A40B1DB679599F65640F5DA6CACC4D44A40B1DB679599F65640C24F1C40BFD34A40BC3FDEAB56F55640C24F1C40BFD34A40
16803	Прихолмье	5	49	1439	92.052514000000002	92.090648000000002	53.800884000000003	53.790326999999998	0103000020E610000001000000050000004225AE635C035740A912656F29E54A404225AE635C035740E1F1ED5D83E64A40A9DC442DCD055740E1F1ED5D83E64A40A9DC442DCD055740A912656F29E54A404225AE635C035740A912656F29E54A40
16858	Притубинский	5	49	1439	92.000313000000006	92.018979999999999	53.904952000000002	53.897212000000003	0103000020E61000000100000005000000E030D1200500574015CAC2D7D7F24A40E030D1200500574093399677D5F34A40CCD1E3F73601574093399677D5F34A40CCD1E3F73601574015CAC2D7D7F24A40E030D1200500574015CAC2D7D7F24A40
17397	Пригородный	5	49	1439	92.027244999999994	92.033973000000003	53.553539000000001	53.545996000000002	0103000020E61000000100000005000000B0FECF61BE01574098DF6932E3C54A40B0FECF61BE015740C007AF5DDAC64A409CFC169D2C025740C007AF5DDAC64A409CFC169D2C02574098DF6932E3C54A40B0FECF61BE01574098DF6932E3C54A40
59751	Опытное Поле	5	49	1439	91.424627999999998	92.644693000000004	54.032997999999999	53.463943999999998	0103000020E61000000100000005000000D13DEB1A2DDB56407496598462BB4A40D13DEB1A2DDB5640AD6A494739044B4073BD6DA642295740AD6A494739044B4073BD6DA6422957407496598462BB4A40D13DEB1A2DDB56407496598462BB4A40
16982	Озеро Тагарское	5	49	1439	91.791157999999996	91.802611999999996	53.601692999999997	53.595568999999998	0103000020E6100000010000000500000000FE2955A2F2564076C1E09A3BCC4A4000FE2955A2F25640B69DB64604CD4A4023D8B8FE5DF35640B69DB64604CD4A4023D8B8FE5DF3564076C1E09A3BCC4A4000FE2955A2F2564076C1E09A3BCC4A40
16343	Новотроицкое	5	49	1439	91.776156	91.808963000000006	53.881632000000003	53.861989000000001	0103000020E610000001000000050000000726378AACF156408141D2A755EE4A400726378AACF15640B58D3F51D9F04A40242BBF0CC6F35640B58D3F51D9F04A40242BBF0CC6F356408141D2A755EE4A400726378AACF156408141D2A755EE4A40
16277	Николо-Петровка	5	49	1439	91.668323000000001	91.700770000000006	53.940759	53.926054000000001	0103000020E61000000100000005000000890AD5CDC5EA56403D2AFEEF88F64A40890AD5CDC5EA5640763579CA6AF84A4026016A6AD9EC5640763579CA6AF84A4026016A6AD9EC56403D2AFEEF88F64A40890AD5CDC5EA56403D2AFEEF88F64A40
17642	Малая Ничка	5	49	1439	92.019968000000006	92.050753	53.633915999999999	53.625382999999999	0103000020E61000000100000005000000DCBDDC2747015740B83CD68C0CD04A40DCBDDC2747015740A034D42824D14A4021CB82893F035740A034D42824D14A4021CB82893F035740B83CD68C0CD04A40DCBDDC2747015740B83CD68C0CD04A40
16538	Малая Минуса	5	49	1439	91.765501999999998	91.813885999999997	53.738245999999997	53.721939999999996	0103000020E6100000010000000500000072C119FCFDF056404DD6A88768DC4A4072C119FCFDF056408F334DD87EDE4A40062B4EB516F456408F334DD87EDE4A40062B4EB516F456404DD6A88768DC4A4072C119FCFDF056404DD6A88768DC4A40
16760	Малая Иня	5	49	1439	92.202290000000005	92.227909999999994	53.811459999999997	53.798411000000002	0103000020E61000000100000005000000B493C151F20C574022E2E65432E64A40B493C151F20C57408E01D9EBDDE74A409B1BD313960E57408E01D9EBDDE74A409B1BD313960E574022E2E65432E64A40B493C151F20C574022E2E65432E64A40
16891	Лугавское	5	49	1439	91.782201999999998	91.805099999999996	53.527602999999999	53.511868	0103000020E610000001000000050000006937FA980FF2564039EFFFE384C14A406937FA980FF25640C022BF7E88C34A409D8026C286F35640C022BF7E88C34A409D8026C286F3564039EFFFE384C14A406937FA980FF2564039EFFFE384C14A40
16959	Кутужеково	5	49	1439	91.917541999999997	91.931942000000006	53.600966	53.583933000000002	0103000020E6100000010000000500000036AD1402B9FA564010070951BECA4A4036AD1402B9FA564004013274ECCC4A4035F10EF0A4FB564004013274ECCC4A4035F10EF0A4FB564010070951BECA4A4036AD1402B9FA564010070951BECA4A40
59828	Курейка	5	49	1439	91.955980999999994	91.990656000000001	53.931573	53.924717999999999	0103000020E610000001000000050000003BA6EECA2EFD5640E202D0285DF64A403BA6EECA2EFD5640166BB8C83DF74A4084656CE866FF5640166BB8C83DF74A4084656CE866FF5640E202D0285DF64A403BA6EECA2EFD5640E202D0285DF64A40
32811	Кочергино	5	49	1439	92.475871999999995	92.511769000000001	53.820076999999998	53.810662000000001	0103000020E610000001000000050000004145D5AF741E5740130EBDC5C3E74A404145D5AF741E5740D4997B48F8E84A40D386C3D2C0205740D4997B48F8E84A40D386C3D2C0205740130EBDC5C3E74A404145D5AF741E5740130EBDC5C3E74A40
17710	Коныгино	5	49	1439	92.043863000000002	92.063059999999993	53.694322	53.687449000000001	0103000020E6100000010000000500000049A0C1A6CE0257407E552E54FED74A4049A0C1A6CE0257405872158BDFD84A40E36BCF2C090457405872158BDFD84A40E36BCF2C090457407E552E54FED74A4049A0C1A6CE0257407E552E54FED74A40
17846	Колмаково	5	49	1439	92.294331999999997	92.310339999999997	53.716419999999999	53.706826999999997	0103000020E61000000100000005000000A48AE255D61257400377A04E79DA4A40A48AE255D6125740A4198BA6B3DB4A4000A94D9CDC135740A4198BA6B3DB4A4000A94D9CDC1357400377A04E79DA4A40A48AE255D61257400377A04E79DA4A40
16448	Кавказское	5	49	1439	91.905586	91.950861000000003	53.972132999999999	53.959040000000002	0103000020E61000000100000005000000CA6DFB1EF5F9564026C79DD2C1FA4A40CA6DFB1EF5F95640622EA9DA6EFC4A40AE8218E8DAFC5640622EA9DA6EFC4A40AE8218E8DAFC564026C79DD2C1FA4A40CA6DFB1EF5F9564026C79DD2C1FA4A40
17315	Знаменка	5	49	1439	91.888553999999999	91.932822999999999	53.542822999999999	53.524963999999997	0103000020E61000000100000005000000B8AE9811DEF85640E6C9350532C34A40B8AE9811DEF8564020425C397BC54A40397D3D5FB3FB564020425C397BC54A40397D3D5FB3FB5640E6C9350532C34A40B8AE9811DEF85640E6C9350532C34A40
17799	Жерлык	5	49	1439	92.431594000000004	92.450558000000001	53.762582999999999	53.749583000000001	0103000020E6100000010000000500000097C9703C9F1B57409C51F355F2DF4A4097C9703C9F1B574027BEDA519CE14A40E0BC38F1D51C574027BEDA519CE14A40E0BC38F1D51C57409C51F355F2DF4A4097C9703C9F1B57409C51F355F2DF4A40
16234	Городок	5	49	1439	91.786261999999994	91.823210000000003	53.933003999999997	53.910755000000002	0103000020E610000001000000050000009A05DA1D52F2564091D5AD9E93F44A409A05DA1D52F25640C284D1AC6CF74A405FEFFE78AFF45640C284D1AC6CF74A405FEFFE78AFF4564091D5AD9E93F44A409A05DA1D52F2564091D5AD9E93F44A40
17429	Восточное	5	49	1439	92.112513000000007	92.144887999999995	53.580801000000001	53.568818999999998	0103000020E61000000100000005000000FED7B96933075740F52B9D0FCFC84A40FED7B96933075740F73DEAAF57CA4A404D6551D845095740F73DEAAF57CA4A404D6551D845095740F52B9D0FCFC84A40FED7B96933075740F52B9D0FCFC84A40
17548	Верхняя Коя	5	49	1439	92.149783999999997	92.170580000000001	53.498555000000003	53.490841000000003	0103000020E61000000100000005000000B35DA10F960957409A44BDE0D3BE4A40B35DA10F96095740EF2076A6D0BF4A40825660C8EA0A5740EF2076A6D0BF4A40825660C8EA0A57409A44BDE0D3BE4A40B35DA10F960957409A44BDE0D3BE4A40
59655	Быстрая	5	49	1439	91.424627999999998	92.644693000000004	54.032997999999999	53.463943999999998	0103000020E61000000100000005000000D13DEB1A2DDB56407496598462BB4A40D13DEB1A2DDB5640AD6A494739044B4073BD6DA642295740AD6A494739044B4073BD6DA6422957407496598462BB4A40D13DEB1A2DDB56407496598462BB4A40
17607	Большая Ничка	5	49	1439	92.121307000000002	92.144852	53.677204000000003	53.657231000000003	0103000020E61000000100000005000000A8716F7EC30757406D75392520D44A40A8716F7EC3075740365CE49EAED64A40A7B0524145095740365CE49EAED64A40A7B05241450957406D75392520D44A40A8716F7EC30757406D75392520D44A40
16690	Большая Иня	5	49	1439	92.097789000000006	92.132266999999999	53.777164999999997	53.757275999999997	0103000020E61000000100000005000000263ACB2C42065740D905836BEEE04A40263ACB2C42065740444C89247AE34A40C3D5011077085740444C89247AE34A40C3D5011077085740D905836BEEE04A40263ACB2C42065740D905836BEEE04A40
15241	Шалинское	5	49	1366	93.726326999999998	93.773983000000001	55.732033000000001	55.698811999999997	0103000020E61000000100000005000000EACC3D247C6E5740B306EFAB72D94B40EACC3D247C6E5740E04BE141B3DD4B403D2AFEEF88715740E04BE141B3DD4B403D2AFEEF88715740B306EFAB72D94B40EACC3D247C6E5740B306EFAB72D94B40
15116	Тертеж	5	49	1366	93.735741000000004	93.775437999999994	55.884645999999996	55.871324000000001	0103000020E61000000100000005000000E3546B61166F5740261C7A8B87EF4B40E3546B61166F5740C34483143CF14B40D784B4C6A0715740C34483143CF14B40D784B4C6A0715740261C7A8B87EF4B40E3546B61166F5740261C7A8B87EF4B40
41028	Таежный	5	49	1366	93.169990999999996	94.165693000000005	56.085298999999999	54.703097999999997	0103000020E610000001000000050000005167EE21E14A574006F1811DFF594B405167EE21E14A5740D5B0DF13EB0A4C40460BD0B69A8A5740D5B0DF13EB0A4C40460BD0B69A8A574006F1811DFF594B405167EE21E14A574006F1811DFF594B40
15478	Сугристое	5	49	1366	93.841796000000002	93.868224999999995	55.58296	55.572065000000002	0103000020E61000000100000005000000D57954FCDF755740D717096D39C94B40D57954FCDF7557402670EB6E9ECA4B40742497FF907757402670EB6E9ECA4B40742497FF90775740D717096D39C94B40D57954FCDF755740D717096D39C94B40
16031	Степной Баджей	5	49	1366	93.748712999999995	93.765044000000003	55.212179999999996	55.196254000000003	0103000020E61000000100000005000000C345EEE9EA6F5740C7DADFD91E994B40C345EEE9EA6F5740C16ED8B6289B4B4011001C7BF6705740C16ED8B6289B4B4011001C7BF6705740C7DADFD91E994B40C345EEE9EA6F5740C7DADFD91E994B40
59766	Сосновка	5	49	1366	93.769383000000005	93.779839999999993	55.643895999999998	55.626787	0103000020E610000001000000050000004CC631923D7157406B47718E3AD04B404CC631923D7157403A03232F6BD24B40350708E6E87157403A03232F6BD24B40350708E6E87157406B47718E3AD04B404CC631923D7157406B47718E3AD04B40
15184	Сергеевка	5	49	1366	93.788329000000004	93.809089	55.931990999999996	55.924143999999998	0103000020E61000000100000005000000425F7AFB73725740B665C0594AF64B40425F7AFB737257404A95287B4BF74B406AA33A1DC87357404A95287B4BF74B406AA33A1DC8735740B665C0594AF64B40425F7AFB73725740B665C0594AF64B40
15538	Покосное	5	49	1366	93.935436999999993	93.953097999999997	55.593618999999997	55.579943	0103000020E61000000100000005000000F99D2633DE7B5740A6457D923BCA4B40F99D2633DE7B574061A417B5FBCB4B4083F8C08EFF7C574061A417B5FBCB4B4083F8C08EFF7C5740A6457D923BCA4B40F99D2633DE7B5740A6457D923BCA4B40
15857	Пимия	5	49	1366	93.631285000000005	93.649772999999996	55.370851000000002	55.353555	0103000020E61000000100000005000000255D33F9666857402C2B4D4A41AD4B40255D33F9666857402E58AA0B78AF4B40B9347EE1956957402E58AA0B78AF4B40B9347EE1956957402C2B4D4A41AD4B40255D33F9666857402C2B4D4A41AD4B40
14834	Первоманск	5	49	1366	93.609654000000006	93.651236999999995	55.863833	55.846113000000003	0103000020E610000001000000050000000AF835920467574038DC476E4DEC4B400AF8359204675740501A6A1492EE4B407D3CF4DDAD695740501A6A1492EE4B407D3CF4DDAD69574038DC476E4DEC4B400AF835920467574038DC476E4DEC4B40
15892	Орешное	5	49	1366	93.656689999999998	93.699242999999996	55.306753	55.275492999999997	0103000020E610000001000000050000000E677E35076A574072A3C85A43A34B400E677E35076A57409679ABAE43A74B403E3DB665C06C57409679ABAE43A74B403E3DB665C06C574072A3C85A43A34B400E677E35076A574072A3C85A43A34B40
14962	Новосельск	5	49	1366	93.473990000000001	93.498172999999994	55.833167000000003	55.812503999999997	0103000020E61000000100000005000000632827DA555E574041EF8D2100E84B40632827DA555E5740A08D5C37A5EA4B4003B00111E25F5740A08D5C37A5EA4B4003B00111E25F574041EF8D2100E84B40632827DA555E574041EF8D2100E84B40
14972	Новоникольск	5	49	1366	93.594938999999997	93.625328999999994	55.789588000000002	55.777656	0103000020E610000001000000050000005B07077B13665740E3C4573B8AE34B405B07077B1366574033A8363811E54B40620FED630568574033A8363811E54B40620FED6305685740E3C4573B8AE34B405B07077B13665740E3C4573B8AE34B40
15413	Новомихайловка	5	49	1366	93.763356000000002	93.784385	55.567998000000003	55.560896	0103000020E6100000010000000500000025CD1FD3DA705740863AAC70CBC74B4025CD1FD3DA705740C2189128B4C84B40459E245D33725740C2189128B4C84B40459E245D33725740863AAC70CBC74B4025CD1FD3DA705740863AAC70CBC74B40
15088	Нижняя Есауловка	5	49	1366	93.707955999999996	93.739254000000003	55.789127000000001	55.782612999999998	0103000020E6100000010000000500000072C0AE264F6D57405436ACA92CE44B4072C0AE264F6D5740FFB1101D02E54B40FB5B02F04F6F5740FFB1101D02E54B40FB5B02F04F6F57405436ACA92CE44B4072C0AE264F6D57405436ACA92CE44B40
15753	Нарва	5	49	1366	93.629956000000007	93.662439000000006	55.420943999999999	55.385872999999997	0103000020E61000000100000005000000D17AF8325168574067B4554964B14B40D17AF8325168574045B9347EE1B54B4014268C66656A574045B9347EE1B54B4014268C66656A574067B4554964B14B40D17AF8325168574067B4554964B14B40
15670	Малый Унгут	5	49	1366	93.346402999999995	93.360883000000001	55.445258000000003	55.439982000000001	0103000020E610000001000000050000001F0F7D772B565740126A865451B84B401F0F7D772B5657402524D236FEB84B40ACAB02B5185757402524D236FEB84B40ACAB02B518575740126A865451B84B401F0F7D772B565740126A865451B84B40
14757	Кускун	5	49	1366	93.564199000000002	93.602440000000001	55.957101000000002	55.943376000000001	0103000020E61000000100000005000000E65B1FD61B64574068EA758BC0F84B40E65B1FD61B64574005FC1A4982FA4B40587380608E66574005FC1A4982FA4B40587380608E66574068EA758BC0F84B40E65B1FD61B64574068EA758BC0F84B40
15946	Колбинский	5	49	1366	93.486980000000003	93.525958000000003	55.174280000000003	55.153832999999999	0103000020E61000000100000005000000977329AE2A5F5740D505BCCCB0934B40977329AE2A5F5740672C9ACE4E964B407444BE4BA9615740672C9ACE4E964B407444BE4BA9615740D505BCCCB0934B40977329AE2A5F5740D505BCCCB0934B40
15559	Кияй	5	49	1366	93.762232999999995	93.784547000000003	55.526015999999998	55.505057000000001	0103000020E61000000100000005000000A5BBEB6CC8705740D5CE30B5A5C04B40A5BBEB6CC87057401C96067E54C34B4032CB9E04367257401C96067E54C34B4032CB9E0436725740D5CE30B5A5C04B40A5BBEB6CC8705740D5CE30B5A5C04B40
16072	Кирза	5	49	1366	93.785139999999998	93.804147999999998	55.114106	55.106428000000001	0103000020E6100000010000000500000003B2D7BB3F72574079B0C56E9F8D4B4003B2D7BB3F725740812381069B8E4B4034492C2977735740812381069B8E4B4034492C297773574079B0C56E9F8D4B4003B2D7BB3F72574079B0C56E9F8D4B40
59694	Каяк	5	49	1366	93.169990999999996	94.165693000000005	56.085298999999999	54.703097999999997	0103000020E610000001000000050000005167EE21E14A574006F1811DFF594B405167EE21E14A5740D5B0DF13EB0A4C40460BD0B69A8A5740D5B0DF13EB0A4C40460BD0B69A8A574006F1811DFF594B405167EE21E14A574006F1811DFF594B40
15037	Камарчага	5	49	1366	93.664128000000005	93.718045000000004	55.826261000000002	55.799441000000002	0103000020E61000000100000005000000E816BA12816A5740700A2B1554E64B40E816BA12816A5740EA7AA2EBC2E94B409B030473F46D5740EA7AA2EBC2E94B409B030473F46D5740700A2B1554E64B40E816BA12816A5740700A2B1554E64B40
16176	Жайма	5	49	1366	93.668547000000004	93.687565000000006	54.859129000000003	54.842283999999999	0103000020E61000000100000005000000B1355B79C96A5740D7F84CF6CF6B4B40B1355B79C96A5740C90567F0F76D4B40F437A110016C5740C90567F0F76D4B40F437A110016C5740D7F84CF6CF6B4B40B1355B79C96A5740D7F84CF6CF6B4B40
16134	Выезжий Лог	5	49	1366	93.909107000000006	93.946997999999994	54.979360999999997	54.965930999999998	0103000020E61000000100000005000000246420CF2E7A5740A69883A0A37B4B40246420CF2E7A57402AFD84B35B7D4B4027D87F9D9B7C57402AFD84B35B7D4B4027D87F9D9B7C5740A69883A0A37B4B40246420CF2E7A5740A69883A0A37B4B40
14816	Ветвистый	5	49	1366	93.590933000000007	93.600087000000002	55.895434000000002	55.888255000000001	0103000020E610000001000000050000002448A5D8D165574016C1FF56B2F14B402448A5D8D1655740FDDCD0949DF24B404EF04DD367665740FDDCD0949DF24B404EF04DD36766574016C1FF56B2F14B402448A5D8D165574016C1FF56B2F14B40
15329	Верхняя Есауловка	5	49	1366	93.773758000000001	93.801094000000006	55.679164	55.668280000000003	0103000020E610000001000000050000002D414640857157401349F4328AD54B402D414640857157406E4F90D8EED64B4066C1C41F457357406E4F90D8EED64B4066C1C41F457357401349F4328AD54B402D414640857157401349F4328AD54B40
15621	Большой Унгут	5	49	1366	93.391380999999996	93.437348	55.444941	55.417000000000002	0103000020E61000000100000005000000A6D1E4620C5957404C37894160B54B40A6D1E4620C59574024D3A1D3F3B84B40253E7782FD5B574024D3A1D3F3B84B40253E7782FD5B57404C37894160B54B40A6D1E4620C5957404C37894160B54B40
15988	Анастасино	5	49	1366	93.380996999999994	93.403868000000003	55.131753000000003	55.115012	0103000020E61000000100000005000000F1B73D4162585740E35295B6B88E4B40F1B73D416258574030134548DD904B40A9F92AF9D859574030134548DD904B40A9F92AF9D8595740E35295B6B88E4B40F1B73D4162585740E35295B6B88E4B40
51865	Красноярск	5	49	7127	92.938513999999998	93.113523000000001	56.076402999999999	55.973022999999998	0103000020E61000000100000005000000A435069D103C5740BEA085048CFC4B40A435069D103C57407C28D192C7094C400116F9F5434757407C28D192C7094C400116F9F543475740BEA085048CFC4B40A435069D103C5740BEA085048CFC4B40
12893	Щетинкино	5	49	1068	93.440357000000006	93.454982000000001	54.541849999999997	54.532338000000003	0103000020E61000000100000005000000246420CF2E5C57408335CEA623444B40246420CF2E5C574036AB3E575B454B403291D26C1E5D574036AB3E575B454B403291D26C1E5D57408335CEA623444B40246420CF2E5C57408335CEA623444B40
12219	Шалоболино	5	49	1068	92.273554000000004	92.296766000000005	53.948315999999998	53.931731999999997	0103000020E6100000010000000500000029ECA2E8811157407E5182FE42F74A4029ECA2E88111574003232F6B62F94A402524D236FE12574003232F6B62F94A402524D236FE1257407E5182FE42F74A4029ECA2E8811157407E5182FE42F74A40
14671	Чибижек	5	49	1068	93.579875000000001	93.672752000000003	54.408056999999999	54.392695000000003	0103000020E61000000100000005000000273108AC1C655740C0266BD443324B40273108AC1C655740B2F336363B344B406494675E0E6B5740B2F336363B344B406494675E0E6B5740C0266BD443324B40273108AC1C655740C0266BD443324B40
14322	Черемшанка	5	49	1068	93.719517999999994	93.751300000000001	53.883532000000002	53.870080999999999	0103000020E6100000010000000500000088B839950C6E57407CEF6FD05EEF4A4088B839950C6E5740187C9A9317F14A40075F984C15705740187C9A9317F14A40075F984C157057407CEF6FD05EEF4A4088B839950C6E57407CEF6FD05EEF4A40
13057	Уральская (Грязнуха)	5	49	1068	92.811788000000007	92.822558999999998	54.044947999999998	54.034987000000001	0103000020E6100000010000000500000042D2A755F433574080643A747A044B4042D2A755F4335740A30227DBC0054B40F30181CEA4345740A30227DBC0054B40F30181CEA434574080643A747A044B4042D2A755F433574080643A747A044B40
14231	Тюхтят	5	49	1068	93.506527000000006	93.530987999999994	53.929080999999996	53.920135999999999	0103000020E61000000100000005000000A0E238F06A605740A6EF3504C7F54A40A0E238F06A605740E02A4F20ECF64A4061A417B5FB615740E02A4F20ECF64A4061A417B5FB615740A6EF3504C7F54A40A0E238F06A605740A6EF3504C7F54A40
13534	Тагашет	5	49	1068	92.595510000000004	92.605562000000006	54.192357999999999	54.182954000000002	0103000020E61000000100000005000000399CF9D51C265740115663096B174B40399CF9D51C265740DE8FDB2F9F184B40D36C1E87C1265740DE8FDB2F9F184B40D36C1E87C1265740115663096B174B40399CF9D51C265740115663096B174B40
13807	Рощинский	5	49	1068	92.772720000000007	92.807565999999994	53.881881	53.873334999999997	0103000020E61000000100000005000000C53D963E74315740E0B9F770C9EF4A40C53D963E743157405DFB027AE1F04A4023D74D29AF3357405DFB027AE1F04A4023D74D29AF335740E0B9F770C9EF4A40C53D963E74315740E0B9F770C9EF4A40
13267	Прудный	5	49	1068	92.468147000000002	92.484675999999993	54.002569000000001	53.995185999999997	0103000020E610000001000000050000001DAED51EF61D5740F1B73D4162FF4A401DAED51EF61D5740E17D552E54004B40FD497CEE041F5740E17D552E54004B40FD497CEE041F5740F1B73D4162FF4A401DAED51EF61D5740F1B73D4162FF4A40
13126	Поначево	5	49	1068	92.768822	92.786276000000001	54.127549999999999	54.116900999999999	0103000020E61000000100000005000000809C30613431574052EFA99CF60E4B40809C3061343157406A4DF38E53104B404D689258523257406A4DF38E53104B404D6892585232574052EFA99CF60E4B40809C30613431574052EFA99CF60E4B40
12387	Пойлово	5	49	1068	92.436751000000001	92.460565000000003	53.865471999999997	53.840929000000003	0103000020E61000000100000005000000B35F77BAF31B574006A1BC8FA3EB4A40B35F77BAF31B574046CD57C9C7EE4A40AA2B9FE5791D574046CD57C9C7EE4A40AA2B9FE5791D574006A1BC8FA3EB4A40B35F77BAF31B574006A1BC8FA3EB4A40
13815	Подгорный	5	49	1068	92.844110000000001	92.852661999999995	53.862149000000002	53.843192999999999	0103000020E61000000100000005000000800EF3E505365740AA9B8BBFEDEB4A40800EF3E505365740BAA3FFE55AEE4A40AF22A30392365740BAA3FFE55AEE4A40AF22A30392365740AA9B8BBFEDEB4A40800EF3E505365740AA9B8BBFEDEB4A40
14271	Петропавловка	5	49	1068	93.646161000000006	93.681383999999994	53.904485000000001	53.895423999999998	0103000020E61000000100000005000000D8BCAAB35A695740D906EE409DF24A40D8BCAAB35A6957407D5C1B2AC6F34A402101A3CB9B6B57407D5C1B2AC6F34A402101A3CB9B6B5740D906EE409DF24A40D8BCAAB35A695740D906EE409DF24A40
12576	Ойха	5	49	1068	92.565515000000005	92.582932999999997	53.874737000000003	53.861756	0103000020E610000001000000050000007099D36531245740DE9046054EEE4A407099D36531245740F3CCCB61F7EF4A4096B036C64E255740F3CCCB61F7EF4A4096B036C64E255740DE9046054EEE4A407099D36531245740DE9046054EEE4A40
12176	Новопокровка	5	49	1068	92.265478000000002	92.285096999999993	54.132820000000002	54.114932000000003	0103000020E61000000100000005000000AEF36F97FD105740C7A17E17B60E4B40AEF36F97FD1057409B20EA3E00114B4003CC7C073F1257409B20EA3E00114B4003CC7C073F125740C7A17E17B60E4B40AEF36F97FD105740C7A17E17B60E4B40
14604	Нижняя Быстрая	5	49	1068	92.807647000000003	92.825236000000004	54.220942000000001	54.214677000000002	0103000020E610000001000000050000009AED0A7DB0335740091A33897A1B4B409AED0A7DB03357400B28D4D3471C4B40D7DEA7AAD03457400B28D4D3471C4B40D7DEA7AAD0345740091A33897A1B4B409AED0A7DB0335740091A33897A1B4B40
12418	Мурино	5	49	1068	92.586490999999995	92.607196999999999	53.844946	53.832231999999998	0103000020E610000001000000050000007E198C1189255740A357039486EA4A407E198C11892557406971C63027EC4A40AD4ECE50DC2657406971C63027EC4A40AD4ECE50DC265740A357039486EA4A407E198C1189255740A357039486EA4A40
14173	Можарка	5	49	1068	93.318985999999995	93.346097	53.970618999999999	53.959823999999998	0103000020E61000000100000005000000707841446A5457403CF54883DBFA4A40707841446A54574028F04E3E3DFC4A40990F08742656574028F04E3E3DFC4A40990F0874265657403CF54883DBFA4A40707841446A5457403CF54883DBFA4A40
13186	Маринино	5	49	1068	92.581119000000001	92.597629999999995	54.023435999999997	54.014156999999997	0103000020E610000001000000050000006405BF0D31255740360186E5CF014B406405BF0D3125574047C66AF3FF024B40F146E6913F26574047C66AF3FF024B40F146E6913F265740360186E5CF014B406405BF0D31255740360186E5CF014B40
13542	Курское	5	49	1068	92.900012000000004	92.922298999999995	53.998112999999996	53.972710999999997	0103000020E610000001000000050000007C80EECB99395740CFBA46CB81FC4A407C80EECB99395740315BB22AC2FF4A408B8862F2063B5740315BB22AC2FF4A408B8862F2063B5740CFBA46CB81FC4A407C80EECB99395740CFBA46CB81FC4A40
12267	Курганчики	5	49	1068	92.319627999999994	92.333094000000003	53.987870000000001	53.970194999999997	0103000020E61000000100000005000000B2B8FFC87414574011DF89592FFC4A40B2B8FFC8741457408A592F8672FE4A409B1F7F69511557408A592F8672FE4A409B1F7F695115574011DF89592FFC4A40B2B8FFC87414574011DF89592FFC4A40
59475	Курагино	5	49	1068	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
12592	Курагино	5	49	1068	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
13616	Красный Кордон	5	49	1068	93.073026999999996	93.078794000000002	54.069994000000001	54.067515999999998	0103000020E61000000100000005000000662E7079AC44574076FA415DA4084B40662E7079AC44574047753A90F5084B40BF47FDF50A45574047753A90F5084B40BF47FDF50A45574076FA415DA4084B40662E7079AC44574076FA415DA4084B40
14546	Краснокаменск	5	49	1068	93.246519000000006	93.266937999999996	54.345756000000002	54.333122000000003	0103000020E61000000100000005000000EEB5A0F7C64F574000CADFBDA32A4B40EEB5A0F7C64F5740A9328CBB412C4B40D1031F8315515740A9328CBB412C4B40D1031F831551574000CADFBDA32A4B40EEB5A0F7C64F574000CADFBDA32A4B40
14457	Кошурниково	5	49	1068	93.359644000000003	93.402314000000004	54.327272999999998	54.290360999999997	0103000020E61000000100000005000000F88C44680457574055849B8C2A254B40F88C44680457574091EEE714E4294B40452E3883BF59574091EEE714E4294B40452E3883BF59574055849B8C2A254B40F88C44680457574055849B8C2A254B40
13662	Кордово	5	49	1068	93.250102999999996	93.292080999999996	54.104930000000003	54.085946999999997	0103000020E610000001000000050000006A6803B0015057403B18B14F000B4B406A6803B001505740452FA3586E0D4B401CB28174B1525740452FA3586E0D4B401CB28174B15257403B18B14F000B4B406A6803B0015057403B18B14F000B4B40
14135	Имисское	5	49	1068	93.152608999999998	93.174132999999998	53.911047000000003	53.895907000000001	0103000020E61000000100000005000000D1048A58C4495740F5A0A014ADF24A40D1048A58C4495740390F27309DF44A40E109BDFE244B5740390F27309DF44A40E109BDFE244B5740F5A0A014ADF24A40D1048A58C4495740F5A0A014ADF24A40
51890	Ильинка	5	49	1068	92.152199999999993	96.685323999999994	54.913696000000002	53.363897000000001	0103000020E61000000100000005000000E09C11A5BD095740670E492D94AE4A40E09C11A5BD095740363E93FDF3744B407DCA3159DC2B5840363E93FDF3744B407DCA3159DC2B5840670E492D94AE4A40E09C11A5BD095740670E492D94AE4A40
13388	Заречный	5	49	1068	92.379724999999993	92.389571000000004	54.057760999999999	54.050398000000001	0103000020E610000001000000050000004F1E166A4D18574054E4107173064B404F1E166A4D185740FCFD62B664074B40151E34BBEE185740FCFD62B664074B40151E34BBEE18574054E4107173064B404F1E166A4D18574054E4107173064B40
13415	Загорье	5	49	1068	92.532430000000005	92.539086999999995	54.111797000000003	54.106592999999997	0103000020E61000000100000005000000325A475513225740C37DE4D6A40D4B40325A4755132257403D65355D4F0E4B40B8ACC266802257403D65355D4F0E4B40B8ACC26680225740C37DE4D6A40D4B40325A475513225740C37DE4D6A40D4B40
13745	Журавлёво	5	49	1068	93.244281999999998	93.258080000000007	54.169404999999998	54.152540000000002	0103000020E610000001000000050000001840F850A24F57407AAA436E86134B401840F850A24F5740B2632310AF154B401CF0F96184505740B2632310AF154B401CF0F961845057407AAA436E86134B401840F850A24F57407AAA436E86134B40
14043	Жербатиха	5	49	1068	93.097497000000004	93.123700999999997	53.870303999999997	53.859710999999997	0103000020E61000000100000005000000529D0E643D465740778192020BEE4A40529D0E643D465740FBC9181F66EF4A40E15E99B7EA475740FBC9181F66EF4A40E15E99B7EA475740778192020BEE4A40529D0E643D465740778192020BEE4A40
13341	Детлово	5	49	1068	92.439284000000001	92.458481000000006	54.097396000000003	54.084409999999998	0103000020E61000000100000005000000FD69A33A1D1C574049BA66F2CD0A4B40FD69A33A1D1C57407061DD78770C4B409835B1C0571D57407061DD78770C4B409835B1C0571D574049BA66F2CD0A4B40FD69A33A1D1C574049BA66F2CD0A4B40
13957	Бугуртак	5	49	1068	92.856613999999993	92.882116999999994	53.820252000000004	53.805925000000002	0103000020E61000000100000005000000EDD286C3D2365740B003E78C28E74A40EDD286C3D2365740433D7D04FEE84A40B88FDC9A74385740433D7D04FEE84A40B88FDC9A74385740B003E78C28E74A40EDD286C3D2365740B003E78C28E74A40
13472	Брагино	5	49	1068	92.591853999999998	92.620994999999994	54.129227	54.096043999999999	0103000020E610000001000000050000006F8099EFE02557400F7D772B4B0C4B406F8099EFE02557404E61A5828A104B40B0FECF61BE2757404E61A5828A104B40B0FECF61BE2757400F7D772B4B0C4B406F8099EFE02557400F7D772B4B0C4B40
9425	Большая Ирба	5	49	1068	92.913379000000006	92.944396999999995	54.101635000000002	54.068282000000004	0103000020E610000001000000050000009B7631CD743A5740E773EE76BD084B409B7631CD743A574082902C60020D4B40315C1D00713C574082902C60020D4B40315C1D00713C5740E773EE76BD084B409B7631CD743A5740E773EE76BD084B40
12979	Березовское	5	49	1068	92.793040000000005	92.817779999999999	53.944308999999997	53.923493000000001	0103000020E61000000100000005000000DF1AD82AC1325740DF8AC40435F64A40DF1AD82AC1325740C328081EDFF84A40AAD4EC8156345740C328081EDFF84A40AAD4EC8156345740DF8AC40435F64A40DF1AD82AC1325740DF8AC40435F64A40
10144	Белый Яр	5	49	1068	92.658500000000004	92.678775000000002	53.842019000000001	53.835016000000003	0103000020E61000000100000005000000A01A2FDD242A574081D1E5CDE1EA4A40A01A2FDD242A574029CE5147C7EB4A40EA95B20C712B574029CE5147C7EB4A40EA95B20C712B574081D1E5CDE1EA4A40A01A2FDD242A574081D1E5CDE1EA4A40
13256	Байдово	5	49	1068	92.557366999999999	92.571695000000005	54.012315999999998	54.005406000000001	0103000020E61000000100000005000000A837A3E6AB235740E199D024B1004B40A837A3E6AB235740D89B189293014B405A12A0A696245740D89B189293014B405A12A0A696245740E199D024B1004B40A837A3E6AB235740E199D024B1004B40
14368	Артёмовск	5	49	1068	93.413811999999993	93.457165000000003	54.364609000000002	54.329546000000001	0103000020E610000001000000050000004FAC53E57B5A5740894336902E2A4B404FAC53E57B5A5740E469F981AB2E4B400EF8FC30425D5740E469F981AB2E4B400EF8FC30425D5740894336902E2A4B404FAC53E57B5A5740894336902E2A4B40
12141	Алексеевка	5	49	1068	92.221486999999996	92.239363999999995	54.064487999999997	54.038370999999998	0103000020E610000001000000050000004E5FCFD72C0E5740B20E4757E9044B404E5FCFD72C0E5740027E8D2441084B40BEF561BD510F5740027E8D2441084B40BEF561BD510F5740B20E4757E9044B404E5FCFD72C0E5740B20E4757E9044B40
12100	Уяр	5	49	1149	91.342404999999999	91.374672000000004	54.629362	54.607559999999999	0103000020E61000000100000005000000293FA9F6E9D55640CB2DAD86C44D4B40293FA9F6E9D556402EAC1BEF8E504B4086AE44A0FAD756402EAC1BEF8E504B4086AE44A0FAD75640CB2DAD86C44D4B40293FA9F6E9D55640CB2DAD86C44D4B40
12020	Уза	5	49	1149	91.605333000000002	91.639442000000003	54.441560000000003	54.431410999999997	0103000020E61000000100000005000000228C9FC6BDE656403C11C47938374B40228C9FC6BDE65640639CBF0985384B40166C239EECE85640639CBF0985384B40166C239EECE856403C11C47938374B40228C9FC6BDE656403C11C47938374B40
11992	Тубинск	5	49	1149	92.028592000000003	92.047196	54.083416999999997	54.072107000000003	0103000020E61000000100000005000000583B8A73D401574006685BCD3A094B40583B8A73D401574018778368AD0A4B4021205F420503574018778368AD0A4B4021205F420503574006685BCD3A094B40583B8A73D401574006685BCD3A094B40
11936	Теплый Ключ	5	49	1149	91.933729999999997	91.943207000000001	54.250532	54.242382999999997	0103000020E61000000100000005000000D252793BC2FB56409D0DF967061F4B40D252793BC2FB5640FD4CBD6E11204B40EE96E4805DFC5640FD4CBD6E11204B40EE96E4805DFC56409D0DF967061F4B40D252793BC2FB56409D0DF967061F4B40
11877	Саянск	5	49	1149	91.874826999999996	91.893952999999996	54.157676000000002	54.145437000000001	0103000020E6100000010000000500000019AA622AFDF756406E50FBAD9D124B4019AA622AFDF756409BAE27BA2E144B404FCAA48636F956409BAE27BA2E144B404FCAA48636F956406E50FBAD9D124B4019AA622AFDF756406E50FBAD9D124B40
11815	Сарушка	5	49	1149	91.541686999999996	91.549403999999996	54.508305	54.496755999999998	0103000020E61000000100000005000000C66AF3FFAAE25640BF0B5BB3953F4B40C66AF3FFAAE2564057B2632310414B40A912656F29E3564057B2632310414B40A912656F29E35640BF0B5BB3953F4B40C66AF3FFAAE25640BF0B5BB3953F4B40
11793	Салба	5	49	1149	91.694436999999994	91.726201000000003	54.686686999999999	54.669280000000001	0103000020E610000001000000050000007808E3A771EC5640F6EE8FF7AA554B407808E3A771EC56404FCB0F5CE5574B40A454C2137AEE56404FCB0F5CE5574B40A454C2137AEE5640F6EE8FF7AA554B407808E3A771EC5640F6EE8FF7AA554B40
11748	Новоивановка	5	49	1149	92.032176000000007	92.048902999999996	54.062643999999999	54.052025999999998	0103000020E61000000100000005000000D5EDEC2B0F0257405645B8C9A8064B40D5EDEC2B0F02574033A5F5B704084B40486B0C3A2103574033A5F5B704084B40486B0C3A210357405645B8C9A8064B40D5EDEC2B0F0257405645B8C9A8064B40
11713	Новая Сыда	5	49	1149	91.409831999999994	91.458449000000002	54.403236	54.385931999999997	0103000020E61000000100000005000000AC36FFAF3ADA56406C3D433866314B40AC36FFAF3ADA5640F148BC3C9D334B409278793A57DD5640F148BC3C9D334B409278793A57DD56406C3D433866314B40AC36FFAF3ADA56406C3D433866314B40
11635	Николаевка	5	49	1149	91.882830999999996	91.907094999999998	54.305304	54.286813000000002	0103000020E610000001000000050000004739984D80F85640A988D349B6244B404739984D80F8564043AB933314274B405ED72FD80DFA564043AB933314274B405ED72FD80DFA5640A988D349B6244B404739984D80F85640A988D349B6244B40
11574	Моисеевка	5	49	1149	91.757840000000002	91.789846999999995	54.174079999999996	54.164929999999998	0103000020E6100000010000000500000071E6577380F056408C101E6D1C154B4071E6577380F056409F71E14048164B40FF756EDA8CF256409F71E14048164B40FF756EDA8CF256408C101E6D1C154B4071E6577380F056408C101E6D1C154B40
11542	Лебяжье	5	49	1149	91.566984000000005	91.586917	54.201092000000003	54.184935000000003	0103000020E61000000100000005000000BD56427749E45640617138F3AB174B40BD56427749E456405EBEF561BD194B40DA1D520C90E556405EBEF561BD194B40DA1D520C90E55640617138F3AB174B40BD56427749E45640617138F3AB174B40
11386	Краснотуранск	5	49	1149	91.540087999999997	91.590663000000006	54.325693000000001	54.304704999999998	0103000020E61000000100000005000000923D42CD90E25640BEF6CC9200274B40923D42CD90E25640A0C4E74EB0294B4044FD2E6CCDE55640A0C4E74EB0294B4044FD2E6CCDE55640BEF6CC9200274B40923D42CD90E25640BEF6CC9200274B40
11381	Кортуз	5	49	1149	91.685524999999998	91.712249999999997	54.505623	54.482280000000003	0103000020E61000000100000005000000C9E53FA4DFEB5640E8C1DD59BB3D4B40C9E53FA4DFEB56407E8D2441B8404B40DD24068195ED56407E8D2441B8404B40DD24068195ED5640E8C1DD59BB3D4B40C9E53FA4DFEB5640E8C1DD59BB3D4B40
11246	Кара-Беллык	5	49	1149	91.597976000000003	91.623217999999994	54.591344999999997	54.577461	0103000020E61000000100000005000000BFF2203D45E6564094DBF63DEA494B40BFF2203D45E6564099D36531B14B4B40D311C0CDE2E7564099D36531B14B4B40D311C0CDE2E7564094DBF63DEA494B40BFF2203D45E6564094DBF63DEA494B40
11159	Диссос	5	49	1149	91.846970999999996	91.856303999999994	54.076830000000001	54.069893999999998	0103000020E61000000100000005000000446ADAC534F65640E3175E49F2084B40446ADAC534F6564004ADC090D5094B40C6DB4AAFCDF6564004ADC090D5094B40C6DB4AAFCDF65640E3175E49F2084B40446ADAC534F65640E3175E49F2084B40
11211	Джирим	5	49	1149	92.124360999999993	92.133758	54.022891000000001	54.017231000000002	0103000020E6100000010000000500000076F9D687F50757401BBD1AA034024B4076F9D687F5075740B62FA017EE024B4004E5B67D8F085740B62FA017EE024B4004E5B67D8F0857401BBD1AA034024B4076F9D687F50757401BBD1AA034024B40
11127	Галактионово	5	49	1149	92.099748000000005	92.121315999999993	54.142906000000004	54.130515000000003	0103000020E61000000100000005000000DA756F456206574098512CB7B4104B40DA756F45620657407B336ABE4A124B40D11E2FA4C30757407B336ABE4A124B40D11E2FA4C307574098512CB7B4104B40DA756F456206574098512CB7B4104B40
11059	Восточное	5	49	1149	91.646664000000001	91.668807999999999	54.096677999999997	54.086559999999999	0103000020E6100000010000000500000009E066F162E956402592E865140B4B4009E066F162E95640101FD8F15F0C4B4067D311C0CDEA5640101FD8F15F0C4B4067D311C0CDEA56402592E865140B4B4009E066F162E956402592E865140B4B40
11001	Белоярск	5	49	1149	91.665447999999998	91.685929999999999	54.392527999999999	54.384213000000003	0103000020E61000000100000005000000124C35B396EA56405AD93EE42D314B40124C35B396EA5640D461855B3E324B401956F146E6EB5640D461855B3E324B401956F146E6EB56405AD93EE42D314B40124C35B396EA56405AD93EE42D314B40
11047	Беллык	5	49	1149	91.312247999999997	91.349924000000001	54.553601	54.541348999999997	0103000020E61000000100000005000000730F09DFFBD35640745C8DEC4A454B40730F09DFFBD356403604C765DC464B407905A22765D656403604C765DC464B407905A22765D65640745C8DEC4A454B40730F09DFFBD35640745C8DEC4A454B40
10923	Александровка	5	49	1149	91.770542000000006	91.794195000000002	54.631664999999998	54.626640999999999	0103000020E61000000100000005000000728C648F50F1564097AAB4C535504B40728C648F50F1564090831266DA504B4064E94317D4F2564090831266DA504B4064E94317D4F2564097AAB4C535504B40728C648F50F1564097AAB4C535504B40
10794	Алгаштык	5	49	1149	91.602502999999999	91.614451000000003	54.656813	54.651823	0103000020E610000001000000050000007B2FBE688FE65640EBE3A1EF6E534B407B2FBE688FE65640384BC97212544B40A67F492A53E75640384BC97212544B40A67F492A53E75640EBE3A1EF6E534B407B2FBE688FE65640EBE3A1EF6E534B40
51868	Шадрино	5	49	1080	91.095789999999994	91.123863	55.882404000000001	55.865383999999999	0103000020E610000001000000050000002A52616C21C65640A73D25E7C4EE4B402A52616C21C6564007EE409DF2F04B40CE8B135FEDC7564007EE409DF2F04B40CE8B135FEDC75640A73D25E7C4EE4B402A52616C21C65640A73D25E7C4EE4B40
9981	Старая Козулька	5	49	1080	91.320791	91.340778999999998	56.210751999999999	56.202205999999997	0103000020E610000001000000050000007976F9D687D456400987DEE2E1194C407976F9D687D4564086C8E9EBF91A4C40780AB952CFD5564086C8E9EBF91A4C40780AB952CFD556400987DEE2E1194C407976F9D687D456400987DEE2E1194C40
10598	Новочернореченский	5	49	1080	91.064547000000005	91.119101999999998	56.278568	56.257753000000001	0103000020E610000001000000050000008483BD8921C4564013B9E00CFE204C408483BD8921C4564027DBC01DA8234C40D8B8FE5D9FC7564027DBC01DA8234C40D8B8FE5D9FC7564013B9E00CFE204C408483BD8921C4564013B9E00CFE204C40
51768	Новочернореченский	5	49	1080	91.064547000000005	91.119101999999998	56.278568	56.257753000000001	0103000020E610000001000000050000008483BD8921C4564013B9E00CFE204C408483BD8921C4564027DBC01DA8234C40D8B8FE5D9FC7564027DBC01DA8234C40D8B8FE5D9FC7564013B9E00CFE204C408483BD8921C4564013B9E00CFE204C40
10452	Ничково	5	49	1080	91.203632999999996	91.219875000000002	56.075719999999997	56.065750999999999	0103000020E61000000100000005000000BAD8B45208CD5640F3565D876A084C40BAD8B45208CD564099D36531B1094C40508D976E12CE564099D36531B1094C40508D976E12CE5640F3565D876A084C40BAD8B45208CD5640F3565D876A084C40
33086	Лазурный	5	49	1080	91.409014999999997	91.424062000000006	56.163207999999997	56.154611000000003	0103000020E61000000100000005000000B324404D2DDA56400A4D124BCA134C40B324404D2DDA56400839EFFFE3144C407D5EF1D423DB56400839EFFFE3144C407D5EF1D423DB56400A4D124BCA134C40B324404D2DDA56400A4D124BCA134C40
59908	Красный Яр	5	49	1080	91.042492999999993	91.061770999999993	55.996051999999999	55.980623000000001	0103000020E61000000100000005000000C5538F34B8C256404B5AF10D85FD4B40C5538F34B8C25640C58EC6A17EFF4B40D6355A0EF4C35640C58EC6A17EFF4B40D6355A0EF4C356404B5AF10D85FD4B40C5538F34B8C256404B5AF10D85FD4B40
10237	Косачи	5	49	1080	91.611001000000002	91.642972	56.140965999999999	56.128531000000002	0103000020E61000000100000005000000B134F0A31AE75640D7C22CB473104C40B134F0A31AE7564089EC832C0B124C40990F087426E9564089EC832C0B124C40990F087426E95640D7C22CB473104C40B134F0A31AE75640D7C22CB473104C40
9530	Козулька	5	49	1080	91.354245000000006	91.440985999999995	56.178378000000002	56.152234	0103000020E61000000100000005000000617138F3ABD656406DAB59677C134C40617138F3ABD65640B7291E17D5164C409BFF571D39DC5640B7291E17D5164C409BFF571D39DC56406DAB59677C134C40617138F3ABD656406DAB59677C134C40
40457	Заречный	5	49	1080	91.716948000000002	91.730226000000002	56.04766	56.038167000000001	0103000020E61000000100000005000000B03BDD79E2ED5640AA6400A8E2044C40B03BDD79E2ED5640E7A90EB919064C40172CD505BCEE5640E7A90EB919064C40172CD505BCEE5640AA6400A8E2044C40B03BDD79E2ED5640AA6400A8E2044C40
33112	Жуковка	5	49	1080	91.687151	91.728105999999997	56.106113000000001	56.076985999999998	0103000020E610000001000000050000007A1A3048FAEB5640FB1F60ADDA094C407A1A3048FAEB564019575C1C950D4C405E81E84999EE564019575C1C950D4C405E81E84999EE5640FB1F60ADDA094C407A1A3048FAEB5640FB1F60ADDA094C40
10356	Балахтон	5	49	1080	91.225605999999999	91.253444999999999	55.992654000000002	55.976478	0103000020E6100000010000000500000002F2255470CE5640BAA1293BFDFC4B4002F2255470CE56402E1F49490FFF4B406C95607138D056402E1F49490FFF4B406C95607138D05640BAA1293BFDFC4B4002F2255470CE5640BAA1293BFDFC4B40
10593	Аммала	5	49	1080	91.090023000000002	91.108816000000004	55.800553999999998	55.791111000000001	0103000020E61000000100000005000000D238D4EFC2C55640C040102043E54B40D238D4EFC2C556404B57B08D78E64B40055262D7F6C656404B57B08D78E64B40055262D7F6C65640C040102043E54B40D238D4EFC2C55640C040102043E54B40
59719	п.Таежный	5	49	1013	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
59782	Яркино	5	49	1013	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
51799	Тагара	5	49	1013	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
51862	Недокура	5	49	1013	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
51817	Кодинск	5	49	1013	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
59846	Климино	5	49	1013	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
59686	Имба (нежил.)	5	49	1013	99.324923999999996	99.330368000000007	57.933078000000002	57.930281999999998	0103000020E61000000100000005000000DF6B088ECBD458405B07077B13F74C40DF6B088ECBD45840FD4E93196FF74C4047E9D2BF24D55840FD4E93196FF74C4047E9D2BF24D558405B07077B13F74C40DF6B088ECBD458405B07077B13F74C40
32824	Ширыштык	5	49	936	93.107108999999994	93.128849000000002	53.362924	53.344074999999997	0103000020E61000000100000005000000DD06B5DFDA465740832F4CA60AAC4A40DD06B5DFDA4657407D772B4B74AE4A40D447E00F3F4857407D772B4B74AE4A40D447E00F3F485740832F4CA60AAC4A40DD06B5DFDA465740832F4CA60AAC4A40
32938	Шалагино	5	49	936	92.760206999999994	92.777193999999994	53.527228000000001	53.523797000000002	0103000020E610000001000000050000002DCC423BA7305740185FB4C70BC34A402DCC423BA73057408BC404357CC34A406F29E78BBD3157408BC404357CC34A406F29E78BBD315740185FB4C70BC34A402DCC423BA7305740185FB4C70BC34A40
32967	Чубчиково	5	49	936	92.640974	92.650576999999998	53.543667999999997	53.538018000000001	0103000020E6100000010000000500000086E5CFB705295740655419C6DDC44A4086E5CFB705295740DCF0BBE996C54A40E8A1B60DA3295740DCF0BBE996C54A40E8A1B60DA3295740655419C6DDC44A4086E5CFB705295740655419C6DDC44A40
32929	Черёмушка	5	49	936	92.711312000000007	92.739572999999993	53.538958999999998	53.52346	0103000020E610000001000000050000002750C422862D5740D061BEBC00C34A402750C422862D57404371C79BFCC44A404B00FE29552F57404371C79BFCC44A404B00FE29552F5740D061BEBC00C34A402750C422862D5740D061BEBC00C34A40
32973	Уджей	5	49	936	92.803380000000004	92.828828999999999	53.743667000000002	53.732908999999999	0103000020E61000000100000005000000AC90F2936A335740D7F84CF6CFDD4A40AC90F2936A335740A60EF27A30DF4A407D3ECA880B355740A60EF27A30DF4A407D3ECA880B355740D7F84CF6CFDD4A40AC90F2936A335740D7F84CF6CFDD4A40
32920	Таяты	5	49	936	93.481886000000003	93.501092	53.778132999999997	53.764434999999999	0103000020E610000001000000050000009E996038D75E574079758E01D9E14A409E996038D75E57401C78B5DC99E34A4062122EE4116057401C78B5DC99E34A4062122EE41160574079758E01D9E14A409E996038D75E574079758E01D9E14A40
24715	Таскино	5	49	936	92.571883999999997	92.609937000000002	53.715758999999998	53.706283999999997	0103000020E61000000100000005000000C34659BF9924574012D89C8367DA4A40C34659BF99245740A968ACFD9DDB4A40B4E7323509275740A968ACFD9DDB4A40B4E732350927574012D89C8367DA4A40C34659BF9924574012D89C8367DA4A40
59644	Таловка	5	49	936	92.992313999999993	93.007315000000006	53.363036999999998	53.357002000000001	0103000020E610000001000000050000003A579412823F5740A54DD53DB2AD4A403A579412823F5740751E15FF77AE4A404C7155D977405740751E15FF77AE4A404C7155D977405740A54DD53DB2AD4A403A579412823F5740A54DD53DB2AD4A40
32957	Старомолино	5	49	936	92.562253999999996	92.574021999999999	53.565204000000001	53.559973999999997	0103000020E61000000100000005000000E48233F8FB2357401E4E603AADC74A40E48233F8FB235740C1C8CB9A58C84A40CF4BC5C6BC245740C1C8CB9A58C84A40CF4BC5C6BC2457401E4E603AADC74A40E48233F8FB2357401E4E603AADC74A40
32910	Старая Копь	5	49	936	92.877831999999998	92.901674	53.658810000000003	53.649225999999999	0103000020E6100000010000000500000077D844662E38574040DB6AD619D34A4077D844662E3857408E23D6E253D44A40D369DD06B53957408E23D6E253D44A40D369DD06B539574040DB6AD619D34A4077D844662E38574040DB6AD619D34A40
32871	Средний Кужебар (Арсапка)	5	49	936	92.964061999999998	92.974114	53.495404999999998	53.481909000000002	0103000020E610000001000000050000003F541A31B33D5740F452B131AFBD4A403F541A31B33D57402FA3586E69BF4A40D9243FE2573E57402FA3586E69BF4A40D9243FE2573E5740F452B131AFBD4A403F541A31B33D5740F452B131AFBD4A40
32894	Сагайское	5	49	936	92.777697000000003	92.813683999999995	53.654572999999999	53.638272000000001	0103000020E61000000100000005000000A14CA3C9C5315740ECF99AE5B2D14A40A14CA3C9C53157401CEC4D0CC9D34A40D2510E66133457401CEC4D0CC9D34A40D2510E6613345740ECF99AE5B2D14A40A14CA3C9C5315740ECF99AE5B2D14A40
32862	Нижняя Буланка	5	49	936	92.697261999999995	92.716881000000001	53.353411999999999	53.346665999999999	0103000020E6100000010000000500000096AFCBF09F2C57404C512E8D5FAC4A4096AFCBF09F2C5740C901BB9A3CAD4A40EC87D860E12D5740C901BB9A3CAD4A40EC87D860E12D57404C512E8D5FAC4A4096AFCBF09F2C57404C512E8D5FAC4A40
32875	Нижний Кужебар	5	49	936	93.066416000000004	93.092681999999996	53.540500999999999	53.529443999999998	0103000020E6100000010000000500000098FBE428404457401E882CD2C4C34A4098FBE42840445740473A03232FC54A4062BB7B80EE455740473A03232FC54A4062BB7B80EE4557401E882CD2C4C34A4098FBE428404457401E882CD2C4C34A40
32889	Нижние Куряты	5	49	936	93.187292999999997	93.205403000000004	53.791912000000004	53.775835000000001	0103000020E610000001000000050000004371C79BFC4B5740CC0BB08F4EE34A404371C79BFC4B5740ADA7565F5DE54A4005E09F52254D5740ADA7565F5DE54A4005E09F52254D5740CC0BB08F4EE34A404371C79BFC4B5740CC0BB08F4EE34A40
32860	Моторское	5	49	936	92.920287000000002	92.955140999999998	53.412444999999998	53.393607000000003	0103000020E61000000100000005000000C6FB71FBE53A5740043DD4B661B24A40C6FB71FBE53A574009336DFFCAB44A406684B707213D574009336DFFCAB44A406684B707213D5740043DD4B661B24A40C6FB71FBE53A5740043DD4B661B24A40
32970	Лебедёвка	5	49	936	92.749661000000003	92.773610000000005	53.592137999999998	53.587611000000003	0103000020E610000001000000050000008C852172FA2F57408BE255D636CB4A408C852172FA2F5740035C902DCBCB4A40F37684D382315740035C902DCBCB4A40F37684D3823157408BE255D636CB4A408C852172FA2F57408BE255D636CB4A40
32850	Качулька	5	49	936	92.899535999999998	92.924032999999994	53.769848000000003	53.746451999999998	0103000020E61000000100000005000000C76471FF91395740530438BD8BDF4A40C76471FF913957400D7217618AE24A402FDB4E5B233B57400D7217618AE24A402FDB4E5B233B5740530438BD8BDF4A40C76471FF91395740530438BD8BDF4A40
32793	Каратузское	5	49	936	92.848871000000003	92.903587000000002	53.619540999999998	53.578785000000003	0103000020E6100000010000000500000076E107E7533657402B357BA015CA4A4076E107E753365740FCC3961E4DCF4A40CF85915ED4395740FCC3961E4DCF4A40CF85915ED43957402B357BA015CA4A4076E107E7533657402B357BA015CA4A40
32959	Верхний Суэтук	5	49	936	92.516799000000006	92.540756999999999	53.466211999999999	53.456319999999998	0103000020E61000000100000005000000C1E61C3C132157405F419AB168BA4A40C1E61C3C132157405A80B6D5ACBB4A4051853FC39B2257405A80B6D5ACBB4A4051853FC39B2257405F419AB168BA4A40C1E61C3C132157405F419AB168BA4A40
32847	Верхний Кужебар	5	49	936	93.227214000000004	93.257146000000006	53.376963000000003	53.359813000000003	0103000020E6100000010000000500000060CC96AC8A4E57407CD6355A0EAE4A4060CC96AC8A4E5740AA66D65240B04A4006137F1475505740AA66D65240B04A4006137F14755057407CD6355A0EAE4A4060CC96AC8A4E57407CD6355A0EAE4A40
7266	Хаерино	5	49	723	95.185613000000004	95.215383000000003	56.341836999999998	56.334268000000002	0103000020E61000000100000005000000992D5915E1CB5740B70C384BC92A4C40992D5915E1CB574008C89750C12B4C405247C7D5C8CD574008C89750C12B4C405247C7D5C8CD5740B70C384BC92A4C40992D5915E1CB5740B70C384BC92A4C40
7469	Филимоново	5	49	723	95.438534000000004	95.474179000000007	56.214511999999999	56.195295000000002	0103000020E61000000100000005000000C80BE9F010DC57404209336DFF184C40C80BE9F010DC5740BE4C1421751B4C40CD5CE0F258DE5740BE4C1421751B4C40CD5CE0F258DE57404209336DFF184C40C80BE9F010DC57404209336DFF184C40
6835	Терское	5	49	723	95.193752000000003	95.219551999999993	56.216284000000002	56.209865999999998	0103000020E6100000010000000500000037E2C96E66CC57406B459BE3DC1A4C4037E2C96E66CC5740F452B131AF1B4C405EF1D4230DCE5740F452B131AF1B4C405EF1D4230DCE57406B459BE3DC1A4C4037E2C96E66CC57406B459BE3DC1A4C40
5043	Тарай	5	49	723	95.823363000000001	95.842011999999997	55.867883999999997	55.856431999999998	0103000020E61000000100000005000000226FB9FAB1F45740BA9F53909FED4B40226FB9FAB1F457405F5CAAD216EF4B40BBB54C86E3F557405F5CAAD216EF4B40BBB54C86E3F55740BA9F53909FED4B40226FB9FAB1F45740BA9F53909FED4B40
47897	Тайна	5	49	723	95.497769000000005	95.516822000000005	56.445523000000001	56.433481	0103000020E610000001000000050000009CFD8172DBDF5740FC372F4E7C374C409CFD8172DBDF5740D34ECDE506394C409DF6949C13E15740D34ECDE506394C409DF6949C13E15740FC372F4E7C374C409CFD8172DBDF5740FC372F4E7C374C40
7164	Таежное	5	49	723	94.969380000000001	95.016811000000004	56.265182000000003	56.244990000000001	0103000020E61000000100000005000000605969520ABE57406CEC12D55B1F4C40605969520ABE574073BED87BF1214C40A3CD716E13C1574073BED87BF1214C40A3CD716E13C157406CEC12D55B1F4C40605969520ABE57406CEC12D55B1F4C40
6421	Тагаши	5	49	723	95.674987999999999	95.686891000000003	56.520504000000003	56.510860000000001	0103000020E61000000100000005000000514CDE0033EB5740D36A48DC63414C40514CDE0033EB5740F6B704E09F424C40AC3AAB05F6EB5740F6B704E09F424C40AC3AAB05F6EB5740D36A48DC63414C40514CDE0033EB5740D36A48DC63414C40
48450	Сухая Речка	5	49	723	95.362842000000001	95.374825000000001	56.202947000000002	56.198774999999998	0103000020E6100000010000000500000060E7A6CD38D7574096218E7571194C4060E7A6CD38D7574021E9D32AFA194C40492EFF21FDD7574021E9D32AFA194C40492EFF21FDD7574096218E7571194C4060E7A6CD38D7574096218E7571194C40
47975	Степняки	5	49	723	95.722769999999997	95.735562000000002	55.958320999999998	55.951546999999998	0103000020E61000000100000005000000EA211ADD41EE5740AFCDC64ACCF94B40EA211ADD41EE5740F6083543AAFA4B408B8BA37213EF5740F6083543AAFA4B408B8BA37213EF5740AFCDC64ACCF94B40EA211ADD41EE5740AFCDC64ACCF94B40
6572	Сотниково	5	49	723	95.518628000000007	95.559375000000003	56.351146	56.340690000000002	0103000020E610000001000000050000008EB27E3331E157408109DCBA9B2B4C408EB27E3331E15740840F255AF22C4C40CDCCCCCCCCE35740840F255AF22C4C40CDCCCCCCCCE357408109DCBA9B2B4C408EB27E3331E157408109DCBA9B2B4C40
59855	Северо-Александровка	5	49	723	95.235937000000007	95.261619999999994	56.534500000000001	56.523423999999999	0103000020E61000000100000005000000A6BA809719CF574083F8C08EFF424C40A6BA809719CF574023DBF97E6A444C40B0FECF61BED0574023DBF97E6A444C40B0FECF61BED0574083F8C08EFF424C40A6BA809719CF574083F8C08EFF424C40
6354	Рудяное	5	49	723	95.603014999999999	95.630027999999996	56.510125000000002	56.495832	0103000020E61000000100000005000000D6FF39CC97E65740B727486C773F4C40D6FF39CC97E657409EEFA7C64B414C401DE4F56052E857409EEFA7C64B414C401DE4F56052E85740B727486C773F4C40D6FF39CC97E65740B727486C773F4C40
7449	Польное	5	49	723	95.493465999999998	95.507596000000007	56.213836000000001	56.207458000000003	0103000020E6100000010000000500000007EC6AF294DF574094A5D6FB8D1A4C4007EC6AF294DF57408E5A61FA5E1B4C4026E5EE737CE057408E5A61FA5E1B4C4026E5EE737CE0574094A5D6FB8D1A4C4007EC6AF294DF574094A5D6FB8D1A4C40
6760	Петрушки	5	49	723	95.224771000000004	95.244739999999993	56.132328000000001	56.125529999999998	0103000020E61000000100000005000000B685E7A562CE57405C55F65D11104C40B685E7A562CE57402C2CB81FF0104C407901F6D1A9CF57402C2CB81FF0104C407901F6D1A9CF57405C55F65D11104C40B685E7A562CE57405C55F65D11104C40
51895	Пермяково	5	49	723	95.182226999999997	95.200355000000002	56.237917000000003	56.226734	0103000020E61000000100000005000000AF5C6F9BA9CB57401572A59E051D4C40AF5C6F9BA9CB5740CB147310741E4C40C425C79DD2CC5740CB147310741E4C40C425C79DD2CC57401572A59E051D4C40AF5C6F9BA9CB57401572A59E051D4C40
51804	Орловка	5	49	723	95.616148999999993	95.625725000000003	55.866636999999997	55.861004000000001	0103000020E61000000100000005000000A31D37FC6EE75740D3DC0A6135EE4B40A31D37FC6EE75740744012F6EDEE4B4089D2DEE00BE85740744012F6EDEE4B4089D2DEE00BE85740D3DC0A6135EE4B40A31D37FC6EE75740D3DC0A6135EE4B40
51870	Орешники	5	49	723	95.157227000000006	95.168571999999998	56.062835999999997	56.057201999999997	0103000020E6100000010000000500000016C3D50110CA574005A2276552074C4016C3D50110CA5740778192020B084C405DC136E2C9CA5740778192020B084C405DC136E2C9CA574005A2276552074C4016C3D50110CA574005A2276552074C40
32583	Мокруша	5	49	723	95.179945000000004	95.237966999999998	56.432226999999997	56.417850000000001	0103000020E610000001000000050000000A85083884CB57401A51DA1B7C354C400A85083884CB57405EB9DE3653374C40BEA1F0D93ACF57405EB9DE3653374C40BEA1F0D93ACF57401A51DA1B7C354C400A85083884CB57401A51DA1B7C354C40
59861	Малые Пруды	5	49	723	95.586280000000002	95.599243000000001	56.107016000000002	56.101619999999997	0103000020E6100000010000000500000021938C9C85E557404C4F58E2010D4C4021938C9C85E557400A1346B3B20D4C40D8D64FFF59E657400A1346B3B20D4C40D8D64FFF59E657404C4F58E2010D4C4021938C9C85E557404C4F58E2010D4C40
5494	Малая Уря	5	49	723	95.425481000000005	95.437663000000001	56.123328000000001	56.110424999999999	0103000020E610000001000000050000007104A9143BDB574095D40968220E4C407104A9143BDB57402E573F36C90F4C40D5EAABAB02DC57402E573F36C90F4C40D5EAABAB02DC574095D40968220E4C407104A9143BDB574095D40968220E4C40
6157	Любава	5	49	723	95.089232999999993	95.105618000000007	56.384928000000002	56.380692000000003	0103000020E61000000100000005000000552E54FEB5C55740A7ECF483BA304C40552E54FEB5C5574048A8195245314C409DF7FF71C2C6574048A8195245314C409DF7FF71C2C65740A7ECF483BA304C40552E54FEB5C55740A7ECF483BA304C40
51751	Леонтьевка	5	49	723	95.416319000000001	95.429047999999995	56.459577000000003	56.451816999999998	0103000020E61000000100000005000000056D72F8A4DA57406F63B323D5394C40056D72F8A4DA5740357F4C6BD33A4C40821ABE8575DB5740357F4C6BD33A4C40821ABE8575DB57406F63B323D5394C40056D72F8A4DA57406F63B323D5394C40
48709	Крутая Горка	5	49	723	95.469453999999999	95.481887	56.168792000000003	56.159824	0103000020E610000001000000050000007D3ECA880BDE5740D68EE21C75144C407D3ECA880BDE5740C9E9EBF99A154C408657923CD7DE5740C9E9EBF99A154C408657923CD7DE5740D68EE21C75144C407D3ECA880BDE5740D68EE21C75144C40
59795	Круглово	5	49	723	95.410568999999995	95.422282999999993	56.342615000000002	56.335855000000002	0103000020E6100000010000000500000017F032C346DA57405B99F04BFD2A4C4017F032C346DA57403D0FEECEDA2B4C4008AA46AF06DB57403D0FEECEDA2B4C4008AA46AF06DB57405B99F04BFD2A4C4017F032C346DA57405B99F04BFD2A4C40
32678	Красный Маяк	5	49	723	95.424655000000001	95.446933000000001	56.209411000000003	56.192704999999997	0103000020E610000001000000050000004E452A8C2DDB57404963B48EAA184C404E452A8C2DDB57401A36CAFACD1A4C4034A0DE8C9ADC57401A36CAFACD1A4C4034A0DE8C9ADC57404963B48EAA184C404E452A8C2DDB57404963B48EAA184C40
7185	Красный Курыш	5	49	723	95.031193000000002	95.062004999999999	56.218586000000002	56.211568	0103000020E610000001000000050000004EB7EC10FFC15740A87004A9141B4C404EB7EC10FFC1574086AE44A0FA1B4C4010CCD1E3F7C3574086AE44A0FA1B4C4010CCD1E3F7C35740A87004A9141B4C404EB7EC10FFC15740A87004A9141B4C40
48130	Зеленая Дубрава	5	49	723	95.523020000000002	95.534564000000003	55.917324000000001	55.908656000000001	0103000020E61000000100000005000000DAC9E02879E1574037A8FDD64EF44B40DAC9E02879E15740FFEA71DF6AF54B409D67EC4B36E25740FFEA71DF6AF54B409D67EC4B36E2574037A8FDD64EF44B40DAC9E02879E1574037A8FDD64EF44B40
48295	Залесный	5	49	723	94.958303999999998	94.978488999999996	56.502653000000002	56.495891	0103000020E6100000010000000500000010E84CDA54BD5740BCB0355B793F4C4010E84CDA54BD57403F1EFAEE56404C40BA9F53909FBE57403F1EFAEE56404C40BA9F53909FBE5740BCB0355B793F4C4010E84CDA54BD5740BCB0355B793F4C40
59866	Загорский	5	49	723	95.038047000000006	95.050336000000001	56.111750000000001	56.106127999999998	0103000020E61000000100000005000000802DAF5C6FC257404E98309A950D4C40802DAF5C6FC25740FCA9F1D24D0E4C40EF737CB438C35740FCA9F1D24D0E4C40EF737CB438C357404E98309A950D4C40802DAF5C6FC257404E98309A950D4C40
48030	Дорожный	5	49	723	95.567217999999997	95.582597000000007	56.052844	56.047584999999998	0103000020E61000000100000005000000F6ECB94C4DE45740DC63E94317064C40F6ECB94C4DE4574019E59997C3064C40DB6FED4449E5574019E59997C3064C40DB6FED4449E55740DC63E94317064C40F6ECB94C4DE45740DC63E94317064C40
59721	Гремучая Падь	5	49	723	95.777585000000002	95.784465999999995	56.446071000000003	56.435625999999999	0103000020E610000001000000050000000D37E0F3C3F15740C6A4BF97C2374C400D37E0F3C3F15740D658C2DA18394C40BBB4E1B034F25740D658C2DA18394C40BBB4E1B034F25740C6A4BF97C2374C400D37E0F3C3F15740C6A4BF97C2374C40
59648	Георгиевка	5	49	723	95.375185000000002	95.429856000000001	56.520950999999997	56.509155999999997	0103000020E61000000100000005000000C93CF20703D85740F54718062C414C40C93CF20703D85740C4E8B985AE424C40527FBDC282DB5740C4E8B985AE424C40527FBDC282DB5740F54718062C414C40C93CF20703D85740F54718062C414C40
5705	Верх-Амонаш	5	49	723	95.613984000000002	95.650509	55.910311	55.895918000000002	0103000020E610000001000000050000001B118C834BE75740E9F2E670ADF24B401B118C834BE757403318231285F44B403C3080F0A1E957403318231285F44B403C3080F0A1E95740E9F2E670ADF24B401B118C834BE75740E9F2E670ADF24B40
6629	Бошняково	5	49	723	95.319040000000001	95.353508000000005	56.118600999999998	56.110385000000001	0103000020E610000001000000050000006A87BF266BD45740077C7E18210E4C406A87BF266BD45740EE224C512E0F4C40F6B704E09FD65740EE224C512E0F4C40F6B704E09FD65740077C7E18210E4C406A87BF266BD45740077C7E18210E4C40
5469	Большая Уря	5	49	723	95.468779999999995	95.495388000000005	56.036357000000002	56.017372000000002	0103000020E610000001000000050000003541D47D00DE5740DDEEE53E39024C403541D47D00DE574087FD9E58A7044C402DB5DE6FB4DF574087FD9E58A7044C402DB5DE6FB4DF5740DDEEE53E39024C403541D47D00DE5740DDEEE53E39024C40
5324	Ашкаул	5	49	723	95.812341000000004	95.829650999999998	56.117953	56.101218000000003	0103000020E61000000100000005000000CC0C1B65FDF357401EE21FB6F40C4C40CC0C1B65FDF3574088BB7A15190F4C40FF05820019F5574088BB7A15190F4C40FF05820019F557401EE21FB6F40C4C40CC0C1B65FDF357401EE21FB6F40C4C40
5164	Астафьевка (Баженово)	5	49	723	95.460110999999998	95.480530000000002	56.40278	56.391610999999997	0103000020E61000000100000005000000E961687572DD57407EE02A4F20324C40E961687572DD5740CFBD874B8E334C40CDAFE600C1DE5740CFBD874B8E334C40CDAFE600C1DE57407EE02A4F20324C40E961687572DD57407EE02A4F20324C40
48314	Архангельское (Облава)	5	49	723	95.538039999999995	95.561998000000003	56.547477999999998	56.537075999999999	0103000020E6100000010000000500000026FC523F6FE25740B6BB07E8BE444C4026FC523F6FE25740C6A354C213464C40B79A75C6F7E35740C6A354C213464C40B79A75C6F7E35740B6BB07E8BE444C4026FC523F6FE25740B6BB07E8BE444C40
6459	Арефьевка	5	49	723	95.710893999999996	95.739056000000005	56.360771	56.352457000000001	0103000020E610000001000000050000000C3B8C497FED5740861F9C4F1D2D4C400C3B8C497FED5740302C7FBE2D2E4C40687A89B14CEF5740302C7FBE2D2E4C40687A89B14CEF5740861F9C4F1D2D4C400C3B8C497FED5740861F9C4F1D2D4C40
6111	Алега	5	49	723	95.077860000000001	95.108806999999999	56.423520000000003	56.42022	0103000020E61000000100000005000000A96A82A8FBC457400490DAC4C9354C40A96A82A8FBC45740D99942E735364C40DBA4A2B1F6C65740D99942E735364C40DBA4A2B1F6C657400490DAC4C9354C40A96A82A8FBC457400490DAC4C9354C40
4801	Челноки	5	49	581	93.197156000000007	93.222525000000005	57.585152999999998	57.570956000000002	0103000020E61000000100000005000000740D33349E4C57403DBA111615C94C40740D33349E4C57400114234BE6CA4C40B7627FD93D4E57400114234BE6CA4C40B7627FD93D4E57403DBA111615C94C40740D33349E4C57403DBA111615C94C40
4724	Талажанка	5	49	581	92.765524999999997	92.783743000000001	57.521793000000002	57.512608999999998	0103000020E610000001000000050000004ED1915CFE3057405051F52B9DC14C404ED1915CFE3057401024EF1CCAC24C40035E66D8283257401024EF1CCAC24C40035E66D8283257405051F52B9DC14C404ED1915CFE3057405051F52B9DC14C40
47724	Рождественское	5	49	581	93.127277000000007	93.165876999999995	57.625084000000001	57.612070000000003	0103000020E610000001000000050000001D226E4E254857406E6E4C4F58CE4C401D226E4E254857405EA0A4C002D04C40268A90BA9D4A57405EA0A4C002D04C40268A90BA9D4A57406E6E4C4F58CE4C401D226E4E254857406E6E4C4F58CE4C40
47704	Пятково	5	49	581	93.187939999999998	93.199645000000004	57.417639000000001	57.402543000000001	0103000020E610000001000000050000000E677E35074C5740EB1D6E8786B34C400E677E35074C57405F44DB3175B54C40D673D2FBC64C57405F44DB3175B54C40D673D2FBC64C5740EB1D6E8786B34C400E677E35074C5740EB1D6E8786B34C40
4580	Пискуновка	5	49	581	93.331140000000005	93.349861000000004	57.560668999999997	57.539738999999997	0103000020E610000001000000050000007099D3653155574018B0E42A16C54C407099D36531555740C5707500C4C74C405649641F64565740C5707500C4C74C405649641F6456574018B0E42A16C54C407099D3653155574018B0E42A16C54C40
4515	Отношка	5	49	581	92.696524999999994	92.722037999999998	57.386999000000003	57.373747999999999	0103000020E610000001000000050000002BF697DD932C5740037976F9D6AF4C402BF697DD932C5740D84AE82E89B14C40081EDFDE352E5740D84AE82E89B14C40081EDFDE352E5740037976F9D6AF4C402BF697DD932C5740037976F9D6AF4C40
4318	Момотово	5	49	581	93.303229999999999	93.336584000000002	57.638658	57.619228	0103000020E61000000100000005000000A14ACD1E685357403D62F4DC42CF4C40A14ACD1E6853574015AA9B8BBFD14C40D7169E978A55574015AA9B8BBFD14C40D7169E978A5557403D62F4DC42CF4C40A14ACD1E685357403D62F4DC42CF4C40
4283	Мокрушинское	5	49	581	93.181876000000003	93.210262999999998	57.529949999999999	57.511336999999997	0103000020E6100000010000000500000059FB3BDBA34B57400C1EA67D73C14C4059FB3BDBA34B5740F241CF66D5C34C40C423F1F2744D5740F241CF66D5C34C40C423F1F2744D57400C1EA67D73C14C4059FB3BDBA34B57400C1EA67D73C14C40
49600	Матвеевка	5	49	581	92.837309000000005	92.855940000000004	57.532690000000002	57.526238999999997	0103000020E6100000010000000500000060E97C78963557409B70AFCC5BC34C4060E97C78963557400074982F2FC44C40A6D590B8C73657400074982F2FC44C40A6D590B8C73657409B70AFCC5BC34C4060E97C78963557409B70AFCC5BC34C40
4131	Кемское	5	49	581	92.886914000000004	92.901745000000005	57.402456000000001	57.385485000000003	0103000020E610000001000000050000005517F032C33857409E0C8E9257B14C405517F032C33857401C0A9FAD83B34C403815A930B63957401C0A9FAD83B34C403815A930B63957409E0C8E9257B14C405517F032C33857409E0C8E9257B14C40
4076	Казачинское	5	49	581	93.259410000000003	93.287786999999994	57.717354	57.677039000000001	0103000020E610000001000000050000005890662C9A505740EB8EC536A9D64C405890662C9A505740D0D38041D2DB4C40B14D2A1A6B525740D0D38041D2DB4C40B14D2A1A6B525740EB8EC536A9D64C405890662C9A505740EB8EC536A9D64C40
4016	Казанка	5	49	581	93.769526999999997	93.789181999999997	57.348737999999997	57.339505000000003	0103000020E61000000100000005000000E5982CEE3F7157400CEA5BE674AB4C40E5982CEE3F715740AC6F6072A3AC4C40E12538F581725740AC6F6072A3AC4C40E12538F5817257400CEA5BE674AB4C40E5982CEE3F7157400CEA5BE674AB4C40
47470	Захаровка	5	49	581	93.297749999999994	93.304173000000006	57.807298000000003	57.794905	0103000020E61000000100000005000000931804560E535740A4367172BFE54C40931804560E5357402810768A55E74C40E1D40792775357402810768A55E74C40E1D4079277535740A4367172BFE54C40931804560E535740A4367172BFE54C40
3834	Дудовка	5	49	581	93.069012000000001	93.103093999999999	57.462828999999999	57.451886999999999	0103000020E6100000010000000500000005C24EB16A445740683EE76ED7B94C4005C24EB16A445740F8510DFB3DBB4C407C9A931799465740F8510DFB3DBB4C407C9A931799465740683EE76ED7B94C4005C24EB16A445740683EE76ED7B94C40
40436	Гамурино	5	49	581	92.647970999999998	92.66601	57.399797999999997	57.394075999999998	0103000020E6100000010000000500000069705B5B78295740BA11161571B24C4069705B5B78295740CB80B3942CB34C40C63368E89F2A5740CB80B3942CB34C40C63368E89F2A5740BA11161571B24C4069705B5B78295740BA11161571B24C40
47417	Галанино	5	49	581	93.259238999999994	93.287679999999995	57.636378999999998	57.607956999999999	0103000020E6100000010000000500000041B62C5F97505740E82FF488D1CD4C4041B62C5F975057403B6EF8DD74D14C40A6ED5F59695257403B6EF8DD74D14C40A6ED5F5969525740E82FF488D1CD4C4041B62C5F97505740E82FF488D1CD4C40
3729	Вороковка	5	49	581	92.845646000000002	92.860881000000006	57.600999000000002	57.589272999999999	0103000020E61000000100000005000000917F66101F36574039B5334C6DCB4C40917F66101F365740E0F60489EDCC4C40DC2F9FAC18375740E0F60489EDCC4C40DC2F9FAC1837574039B5334C6DCB4C40917F66101F36574039B5334C6DCB4C40
3645	Бобровка	5	49	581	93.126199	93.145521000000002	57.331479999999999	57.315185999999997	0103000020E610000001000000050000006D72F8A4134857401A14CD0358A84C406D72F8A41348574098A3C7EF6DAA4C4066F84F375049574098A3C7EF6DAA4C4066F84F37504957401A14CD0358A84C406D72F8A4134857401A14CD0358A84C40
33044	Юдино	5	49	272	95.491696000000005	95.529353999999998	55.680289999999999	55.661186000000001	0103000020E61000000100000005000000BDE47FF277DF57405A492BBEA1D44B40BDE47FF277DF5740DEE522BE13D74B406F8099EFE0E15740DEE522BE13D74B406F8099EFE0E157405A492BBEA1D44B40BDE47FF277DF57405A492BBEA1D44B40
32944	Чухломино	5	49	272	95.459680000000006	95.476478999999998	55.800398000000001	55.792427000000004	0103000020E6100000010000000500000005A8A9656BDD5740D4BB783F6EE54B4005A8A9656BDD574054E4107173E64B40C58EC6A17EDE574054E4107173E64B40C58EC6A17EDE5740D4BB783F6EE54B4005A8A9656BDD5740D4BB783F6EE54B40
32897	Хомутово	5	49	272	95.666067999999996	95.679120999999995	55.728489000000003	55.716929999999998	0103000020E61000000100000005000000603AADDBA0EA5740B9C2BB5CC4DB4B40603AADDBA0EA5740753FA7203FDD4B40B741EDB776EB5740753FA7203FDD4B40B741EDB776EB5740B9C2BB5CC4DB4B40603AADDBA0EA5740B9C2BB5CC4DB4B40
32906	Усть-Яруль	5	49	272	95.268061000000003	95.293833000000006	55.808588999999998	55.794274999999999	0103000020E61000000100000005000000511553E927D15740E4839ECDAAE54B40511553E927D15740E27327D87FE74B40145FED28CED25740E27327D87FE74B40145FED28CED25740E4839ECDAAE54B40511553E927D15740E4839ECDAAE54B40
32891	Усть-Каначуль	5	49	272	95.412167999999994	95.426513999999997	55.868732999999999	55.861801999999997	0103000020E610000001000000050000004B1DE4F560DA57404ED026874FEE4B404B1DE4F560DA57405DFA97A432EF4B40505260014CDB57405DFA97A432EF4B40505260014CDB57404ED026874FEE4B404B1DE4F560DA57404ED026874FEE4B40
32879	Тумаково	5	49	272	95.549295999999998	95.581483000000006	55.800843	55.787461999999998	0103000020E61000000100000005000000B6F468AA27E35740DF6B088ECBE44B40B6F468AA27E35740821DFF0582E64B40850B790437E55740821DFF0582E64B40850B790437E55740DF6B088ECBE44B40B6F468AA27E35740DF6B088ECBE44B40
26425	Талое	5	49	272	95.646054000000007	95.682714000000004	55.414853000000001	55.401722999999997	0103000020E61000000100000005000000CD5CE0F258E957408786C5A86BB34B40CD5CE0F258E95740E1D231E719B54B405EA10F96B1EB5740E1D231E719B54B405EA10F96B1EB57408786C5A86BB34B40CD5CE0F258E957408786C5A86BB34B40
2165	Стрелка	5	49	272	95.804013999999995	95.822311999999997	55.552799999999998	55.541749000000003	0103000020E61000000100000005000000ACE122F774F3574003D2FE0758C54B40ACE122F774F35740499D8026C2C64B40EFC682C2A0F45740499D8026C2C64B40EFC682C2A0F4574003D2FE0758C54B40ACE122F774F3574003D2FE0758C54B40
2494	Степановка	5	49	272	95.754669000000007	95.777090999999999	55.206000000000003	55.166110000000003	0103000020E610000001000000050000008693347F4CF05740F0C4AC1743954B408693347F4CF05740EE7C3F355E9A4B4005C1E3DBBBF15740EE7C3F355E9A4B4005C1E3DBBBF15740F0C4AC1743954B408693347F4CF05740F0C4AC1743954B40
32816	Сергеевка	5	49	272	95.377215000000007	95.389090999999993	55.486519999999999	55.476300999999999	0103000020E61000000100000005000000E223624A24D85740AB06616EF7BC4B40E223624A24D85740CA6C904946BE4B40BF0AF0DDE6D85740CA6C904946BE4B40BF0AF0DDE6D85740AB06616EF7BC4B40E223624A24D85740AB06616EF7BC4B40
32863	Рождественка	5	49	272	95.664820000000006	95.683019000000002	55.366956999999999	55.353974999999998	0103000020E61000000100000005000000836E2F698CEA5740014D840D4FAD4B40836E2F698CEA5740E6046D72F8AE4B40FCE25295B6EB5740E6046D72F8AE4B40FCE25295B6EB5740014D840D4FAD4B40836E2F698CEA5740014D840D4FAD4B40
32923	Преображенка	5	49	272	95.329901000000007	95.354011	55.803499000000002	55.797441999999997	0103000020E61000000100000005000000BC7A15191DD55740793A579412E64B40BC7A15191DD5574032AF230ED9E64B4027DBC01DA8D6574032AF230ED9E64B4027DBC01DA8D65740793A579412E64B40BC7A15191DD55740793A579412E64B40
33149	Подьянда	5	49	272	95.784465999999995	95.799486000000002	55.799137999999999	55.787421999999999	0103000020E61000000100000005000000BBB4E1B034F2574051137D3ECAE44B40BBB4E1B034F25740D47E6B274AE64B4008E753C72AF35740D47E6B274AE64B4008E753C72AF3574051137D3ECAE44B40BBB4E1B034F2574051137D3ECAE44B40
32972	Петропавловка-1	5	49	272	95.726228000000006	95.750850999999997	55.683858000000001	55.676670999999999	0103000020E61000000100000005000000215C01857AEE57406893C3279DD64B40215C01857AEE5740D28DB0A888D74B40CF4A5AF10DF05740D28DB0A888D74B40CF4A5AF10DF057406893C3279DD64B40215C01857AEE57406893C3279DD64B40
32776	Первое Мая	5	49	272	95.339754999999997	95.356229999999996	55.617317	55.603195999999997	0103000020E61000000100000005000000C269C18BBED55740FC89CA8635CD4B40C269C18BBED55740E621533E04CF4B40A9F6E978CCD65740E621533E04CF4B40A9F6E978CCD65740FC89CA8635CD4B40C269C18BBED55740FC89CA8635CD4B40
2397	Новотроицк	5	49	272	95.312707000000003	95.342432000000002	55.462527999999999	55.453912000000003	0103000020E61000000100000005000000BD8E386403D4574088A1D5C919BA4B40BD8E386403D45740FDBD141E34BB4B40A646E867EAD55740FDBD141E34BB4B40A646E867EAD5574088A1D5C919BA4B40BD8E386403D4574088A1D5C919BA4B40
2376	Новоалександровка	5	49	272	95.440815999999998	95.455511999999999	55.482505000000003	55.473174	0103000020E610000001000000050000006DE34F5436DC5740A4A833F790BC4B406DE34F5436DC574008944DB9C2BD4B40E0BBCD1B27DD574008944DB9C2BD4B40E0BBCD1B27DD5740A4A833F790BC4B406DE34F5436DC5740A4A833F790BC4B40
1687	Николаевка	5	49	272	95.187527000000003	95.217027000000002	55.436641999999999	55.430539000000003	0103000020E610000001000000050000007D073F7100CC57408753E6E61BB74B407D073F7100CC5740AF0793E2E3B74B4056D636C5E3CD5740AF0793E2E3B74B4056D636C5E3CD57408753E6E61BB74B407D073F7100CC57408753E6E61BB74B40
59903	Нагорная	5	49	272	95.423811000000001	95.438794000000001	55.682783000000001	55.668996	0103000020E61000000100000005000000D82B2CB81FDB5740D19332A9A1D54B40D82B2CB81FDB5740E4A1EF6E65D74B4096EB6D3315DC5740E4A1EF6E65D74B4096EB6D3315DC5740D19332A9A1D54B40D82B2CB81FDB5740D19332A9A1D54B40
32715	Михайловка	5	49	272	95.142439999999993	95.163910000000001	55.706268999999999	55.694616000000003	0103000020E610000001000000050000001A69A9BC1DC95740A1A3552DE9D84B401A69A9BC1DC95740DD96C80567DA4B40315F5E807DCA5740DD96C80567DA4B40315F5E807DCA5740A1A3552DE9D84B401A69A9BC1DC95740A1A3552DE9D84B40
32688	Минушка	5	49	272	95.882013999999998	95.899540000000002	55.404283999999997	55.395031000000003	0103000020E610000001000000050000004E27D9EA72F85740FEF3346090B24B404E27D9EA72F85740E525FF93BFB34B40685C381092F95740E525FF93BFB34B40685C381092F95740FEF3346090B24B404E27D9EA72F85740FEF3346090B24B40
32807	Мельничное	5	49	272	95.575948999999994	95.600204000000005	55.612945000000003	55.595627999999998	0103000020E610000001000000050000007DCA3159DCE457407B4ACE893DCC4B407DCA3159DCE45740959F54FB74CE4B406BBB09BE69E65740959F54FB74CE4B406BBB09BE69E657407B4ACE893DCC4B407DCA3159DCE457407B4ACE893DCC4B40
32753	Малый Ирбей	5	49	272	95.373182	95.381176999999994	55.640030000000003	55.634776000000002	0103000020E610000001000000050000002D5DC136E2D757409224085740D14B402D5DC136E2D75740BD3AC780ECD14B40313F373465D85740BD3AC780ECD14B40313F373465D857409224085740D14B402D5DC136E2D757409224085740D14B40
32785	Маловка	5	49	272	95.644041999999999	95.662367000000003	55.685229	55.676149000000002	0103000020E6100000010000000500000007D0EFFB37E957408F1CE90C8CD64B4007D0EFFB37E95740A9A27895B5D74B40C7BC8E3864EA5740A9A27895B5D74B40C7BC8E3864EA57408F1CE90C8CD64B4007D0EFFB37E957408F1CE90C8CD64B40
32956	Латынцево	5	49	272	95.351433	95.365832999999995	55.728282	55.717537999999998	0103000020E610000001000000050000000D6FD6E07DD6574091D10149D8DB4B400D6FD6E07DD65740FB21365838DD4B400BB3D0CE69D75740FB21365838DD4B400BB3D0CE69D7574091D10149D8DB4B400D6FD6E07DD6574091D10149D8DB4B40
32792	Коростелево	5	49	272	95.593242000000004	95.628510000000006	55.674889999999998	55.670071999999998	0103000020E6100000010000000500000046274BADF7E557408FFB56EBC4D54B4046274BADF7E55740DF32A7CB62D64B4060CD018239E85740DF32A7CB62D64B4060CD018239E857408FFB56EBC4D54B4046274BADF7E557408FFB56EBC4D54B40
32916	Каменка	5	49	272	95.226495999999997	95.258771999999993	55.845779	55.834274999999998	0103000020E61000000100000005000000302B14E97ECE5740696FF085C9EA4B40302B14E97ECE574061527C7C42EC4B40B6476FB88FD0574061527C7C42EC4B40B6476FB88FD05740696FF085C9EA4B40302B14E97ECE5740696FF085C9EA4B40
32760	Ирбейское	5	49	272	95.398577000000003	95.501424999999998	55.660362999999997	55.620128000000001	0103000020E6100000010000000500000005FC1A4982D95740BDAAB35A60CF4B4005FC1A4982D95740853E58C686D44B406519E25817E05740853E58C686D44B406519E25817E05740BDAAB35A60CF4B4005FC1A4982D95740BDAAB35A60CF4B40
1704	Изумрудный	5	49	272	95.416543000000004	95.431293999999994	55.657845000000002	55.651058999999997	0103000020E610000001000000050000002D98F8A3A8DA57401B62BCE655D34B402D98F8A3A8DA5740276BD44334D44B40813D26529ADB5740276BD44334D44B40813D26529ADB57401B62BCE655D34B402D98F8A3A8DA57401B62BCE655D34B40
33036	Ивановка	5	49	272	95.219228000000001	95.234859	55.456341999999999	55.440671999999999	0103000020E610000001000000050000008597E0D407CE5740A721AAF067B84B408597E0D407CE574047E5266A69BA4B40F60A0BEE07CF574047E5266A69BA4B40F60A0BEE07CF5740A721AAF067B84B408597E0D407CE5740A721AAF067B84B40
32719	Елисеевка	5	49	272	95.082693000000006	95.113443000000004	55.595948999999997	55.586547000000003	0103000020E61000000100000005000000ECA694D74AC557409148DBF813CB4B40ECA694D74AC55740BD8A8C0E48CC4B4073BD6DA642C75740BD8A8C0E48CC4B4073BD6DA642C757409148DBF813CB4B40ECA694D74AC557409148DBF813CB4B40
32703	Верхняя Уря	5	49	272	95.055941000000004	95.098197999999996	55.680250000000001	55.667355999999998	0103000020E610000001000000050000005B608F8994C357400A65E1EB6BD54B405B608F8994C35740508D976E12D74B4016A243E048C65740508D976E12D74B4016A243E048C657400A65E1EB6BD54B405B608F8994C357400A65E1EB6BD54B40
31376	Васильевка	5	49	272	95.722122999999996	95.736863999999997	55.489840000000001	55.485070999999998	0103000020E610000001000000050000001F2C634337EE5740779E78CE16BE4B401F2C634337EE5740E622BE13B3BE4B4062669FC728EF5740E622BE13B3BE4B4062669FC728EF5740779E78CE16BE4B401F2C634337EE5740779E78CE16BE4B40
32971	Бычковка	5	49	272	95.763651999999993	95.778277000000003	55.636609999999997	55.631701999999997	0103000020E610000001000000050000009961A3ACDFF05740AD68739CDBD04B409961A3ACDFF057403D27BD6F7CD14B40A88E554ACFF157403D27BD6F7CD14B40A88E554ACFF15740AD68739CDBD04B409961A3ACDFF05740AD68739CDBD04B40
32936	Буинка	5	49	272	95.489001000000002	95.504065999999995	55.311574	55.296042	0103000020E6100000010000000500000086ADD9CA4BDF5740081F4AB4E4A54B4086ADD9CA4BDF5740572426A8E1A74B40A2410A9E42E05740572426A8E1A74B40A2410A9E42E05740081F4AB4E4A54B4086ADD9CA4BDF5740081F4AB4E4A54B40
32858	Богачёво	5	49	272	95.763921999999994	95.790602000000007	55.387832000000003	55.37679	0103000020E6100000010000000500000079AC1919E4F05740DCBA9BA73AB04B4079AC1919E4F05740D02B9E7AA4B14B40BE89213999F25740D02B9E7AA4B14B40BE89213999F25740DCBA9BA73AB04B4079AC1919E4F05740DCBA9BA73AB04B40
32673	Благовещенка	5	49	272	95.795686000000003	95.823130000000006	55.446599999999997	55.437035999999999	0103000020E61000000100000005000000A5F8F884ECF257405B96AFCBF0B74B40A5F8F884ECF25740613255302AB94B40D1967329AEF45740613255302AB94B40D1967329AEF457405B96AFCBF0B74B40A5F8F884ECF257405B96AFCBF0B74B40
32870	Берёзовка	5	49	272	95.532938000000001	95.555135000000007	55.447493999999999	55.443812000000001	0103000020E61000000100000005000000EC32FCA71BE2574043C9E4D4CEB84B40EC32FCA71BE25740FF93BF7B47B94B405C77F35487E35740FF93BF7B47B94B405C77F35487E3574043C9E4D4CEB84B40EC32FCA71BE2574043C9E4D4CEB84B40
2282	Альгинка	5	49	272	95.425104000000005	95.441777000000002	55.503701	55.495634000000003	0103000020E61000000100000005000000865968E734DB5740916456EF70BF4B40865968E734DB574033FB3C4679C04B4000C8091346DC574033FB3C4679C04B4000C8091346DC5740916456EF70BF4B40865968E734DB5740916456EF70BF4B40
1146	Александровка	5	49	272	95.361782000000005	95.389953000000006	55.571744000000002	55.559165	0103000020E610000001000000050000000492B06F27D75740AF08FEB792C74B400492B06F27D7574095D74AE82EC94B40897E6DFDF4D8574095D74AE82EC94B40897E6DFDF4D85740AF08FEB792C74B400492B06F27D75740AF08FEB792C74B40
32686	Агул	5	49	272	95.876345999999998	95.896962000000002	55.505862999999998	55.496668999999997	0103000020E61000000100000005000000BF7E880D16F85740F0F78BD992BF4B40BF7E880D16F85740D3A0681EC0C04B404EF04DD367F95740D3A0681EC0C04B404EF04DD367F95740F0F78BD992BF4B40BF7E880D16F85740F0F78BD992BF4B40
59853	Ессей	5	49	7493	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
32049	Черниговка	5	49	83	96.015395999999996	96.044860999999997	56.312465000000003	56.307077	0103000020E610000001000000050000004F1F813FFC005840492D944C4E274C404F1F813FFC005840841266DAFE274C406AF7AB00DF025840841266DAFE274C406AF7AB00DF025840492D944C4E274C404F1F813FFC005840492D944C4E274C40
1093	Хайрюзовка	5	49	83	96.607619	96.637893000000005	55.794234000000003	55.785133999999999	0103000020E61000000100000005000000685BCD3AE3265840247D5A457FE44B40685BCD3AE326584086AFAF75A9E54B403B56293DD328584086AFAF75A9E54B403B56293DD3285840247D5A457FE44B40685BCD3AE3265840247D5A457FE44B40
746	Троицк	5	49	83	96.168145999999993	96.188843000000006	55.959111999999998	55.953083999999997	0103000020E6100000010000000500000001BD70E7C20A5840A12B11A8FEF94B4001BD70E7C20A5840BF99982EC4FA4B400745F300160C5840BF99982EC4FA4B400745F300160C5840A12B11A8FEF94B4001BD70E7C20A5840A12B11A8FEF94B40
299	Тарака	5	49	83	96.152551000000003	96.167912000000001	56.434013	56.427557999999998	0103000020E6100000010000000500000037FE4465C309584053927538BA364C4037FE4465C3095840F984ECBC8D374C40C826F911BF0A5840F984ECBC8D374C40C826F911BF0A584053927538BA364C4037FE4465C309584053927538BA364C40
32159	Степаново	5	49	83	96.272350000000003	96.325090000000003	56.227874999999997	56.219316999999997	0103000020E6100000010000000500000033C4B12E6E115840793A5794121C4C4033C4B12E6E115840BA490C022B1D4C406D904946CE145840BA490C022B1D4C406D904946CE145840793A5794121C4C4033C4B12E6E115840793A5794121C4C40
59741	Соколовка	5	49	83	95.891581000000002	95.907732999999993	56.431251000000003	56.42022	0103000020E610000001000000050000000A2FC1A90FF957400490DAC4C9354C400A2FC1A90FF9574004AF963B33374C40FF1F274C18FA574004AF963B33374C40FF1F274C18FA57400490DAC4C9354C400A2FC1A90FF957400490DAC4C9354C40
1040	Росляки	5	49	83	96.286202000000003	96.304708000000005	55.716818000000004	55.709783999999999	0103000020E610000001000000050000003083312251125840AE9CBD33DADA4B403083312251125840929735B1C0DB4B4018B5FB5580135840929735B1C0DB4B4018B5FB5580135840AE9CBD33DADA4B403083312251125840AE9CBD33DADA4B40
884	Прокопьевка	5	49	83	95.878313000000006	95.895533999999998	55.758747	55.748848000000002	0103000020E61000000100000005000000B5A9BA4736F8574067D65240DADF4B40B5A9BA4736F857401478279F1EE14B40309DD66D50F957401478279F1EE14B40309DD66D50F9574067D65240DADF4B40B5A9BA4736F8574067D65240DADF4B40
32337	Новосеменовка Баев	5	49	83	95.936210000000003	95.959584000000007	56.410170999999998	56.402810000000002	0103000020E610000001000000050000000B0C59DDEAFB57403A4030478F334C400B0C59DDEAFB57404162BB7B80344C40F47002D369FD57404162BB7B80344C40F47002D369FD57403A4030478F334C400B0C59DDEAFB57403A4030478F334C40
59725	Новопокровка	5	49	83	96.091150999999996	96.127155000000002	56.360202000000001	56.352880999999996	0103000020E61000000100000005000000DAFF006BD50558409C3061342B2D4C40DAFF006BD505584016FA60191B2E4C4077A1B94E2308584016FA60191B2E4C4077A1B94E230858409C3061342B2D4C40DAFF006BD50558409C3061342B2D4C40
111	Новоникольск	5	49	83	96.227209999999999	96.253342000000004	56.390126000000002	56.373947999999999	0103000020E61000000100000005000000BFD4CF9B8A0E5840CA332F87DD2F4C40BFD4CF9B8A0E5840DFA815A6EF314C40022D5DC136105840DFA815A6EF314C40022D5DC136105840CA332F87DD2F4C40BFD4CF9B8A0E5840CA332F87DD2F4C40
20457	Новониколаевка	5	49	83	96.170499000000007	96.201958000000005	55.795757000000002	55.777464000000002	0103000020E610000001000000050000000C40A374E90A58409FE8BAF083E34B400C40A374E90A58401348895DDBE54B40994A3FE1EC0C58401348895DDBE54B40994A3FE1EC0C58409FE8BAF083E34B400C40A374E90A58409FE8BAF083E34B40
381	Новогеоргиевка (Печкина)	5	49	83	95.986389000000003	95.996611999999999	56.377617000000001	56.361998	0103000020E61000000100000005000000960854FF20FF5740D49B51F3552E4C40960854FF20FF5740F2B4FCC055304C4046B3B27DC8FF5740F2B4FCC055304C4046B3B27DC8FF5740D49B51F3552E4C40960854FF20FF5740D49B51F3552E4C40
655	Лобачевка	5	49	83	96.346541999999999	96.360511000000002	55.840462000000002	55.830685000000003	0103000020E61000000100000005000000302C7FBE2D1658408E23D6E253EA4B40302C7FBE2D165840F0C3414294EB4B404AB6BA9C12175840F0C3414294EB4B404AB6BA9C121758408E23D6E253EA4B40302C7FBE2D1658408E23D6E253EA4B40
51814	Кучердаевка	5	49	83	95.914803000000006	95.942183	55.950432999999997	55.937800000000003	0103000020E6100000010000000500000018D2E1218CFA57402B1895D409F84B4018D2E1218CFA57400305DEC9A7F94B4038F6ECB94CFC57400305DEC9A7F94B4038F6ECB94CFC57402B1895D409F84B4018D2E1218CFA57402B1895D409F84B40
32083	Курыш-Поповичи	5	49	83	95.752729000000002	95.770938000000001	56.346491999999998	56.340445000000003	0103000020E610000001000000050000000D7041B62CF057401A8BA6B3932B4C400D7041B62CF05740AE2990D9592C4C40984F560C57F15740AE2990D9592C4C40984F560C57F157401A8BA6B3932B4C400D7041B62CF057401A8BA6B3932B4C40
32249	Красный Хлебороб	5	49	83	96.005092000000005	96.029642999999993	56.294376	56.287990999999998	0103000020E61000000100000005000000295E656D530058406B459BE3DC244C40295E656D53005840185DDE1CAE254C408AE3C0ABE5015840185DDE1CAE254C408AE3C0ABE50158406B459BE3DC244C40295E656D530058406B459BE3DC244C40
373	Краснинка	5	49	83	96.050341000000003	96.067507000000006	56.413297999999998	56.403860999999999	0103000020E61000000100000005000000782975C9380358409F909DB7B1334C40782975C93803584048C0E8F2E6344C401250E1085204584048C0E8F2E6344C401250E108520458409F909DB7B1334C40782975C9380358409F909DB7B1334C40
101	Коха	5	49	83	96.330883999999998	96.349992	56.354961000000003	56.344735999999997	0103000020E6100000010000000500000042B115342D1558407EE02A4F202C4C4042B115342D155840802DAF5C6F2D4C402577D84466165840802DAF5C6F2D4C402577D844661658407EE02A4F202C4C4042B115342D1558407EE02A4F202C4C40
59641	Карапсель	5	49	83	95.876840000000001	95.900187000000003	56.223086000000002	56.212124000000003	0103000020E61000000100000005000000C7F484251EF857402E5915E1261B4C40C7F484251EF85740051901158E1C4C403352EFA99CF95740051901158E1C4C403352EFA99CF957402E5915E1261B4C40C7F484251EF857402E5915E1261B4C40
11004	Иланский	5	49	83	96.019627	96.129634999999993	56.254632000000001	56.219873	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
985	Ельники	5	49	83	96.401338999999993	96.431307000000004	55.748204000000001	55.734890999999998	0103000020E61000000100000005000000FFE6C589AF195840F78F85E810DE4B40FFE6C589AF195840425E0F26C5DF4B404CE2AC889A1B5840425E0F26C5DF4B404CE2AC889A1B5840F78F85E810DE4B40FFE6C589AF195840F78F85E810DE4B40
51881	Далай	5	49	83	95.891464999999997	95.917766999999998	56.298512000000002	56.289655000000003	0103000020E61000000100000005000000D52137C30DF95740BB0F406A13254C40D52137C30DF9574056BB26A435264C404696CCB1BCFA574056BB26A435264C404696CCB1BCFA5740BB0F406A13254C40D52137C30DF95740BB0F406A13254C40
754	Гавриловка	5	49	83	96.176068999999998	96.189391000000001	56.001826000000001	55.989265000000003	0103000020E61000000100000005000000B935E9B6440B5840EA094B3CA0FE4B40B935E9B6440B5840292499D53B004C4008CA6DFB1E0C5840292499D53B004C4008CA6DFB1E0C5840EA094B3CA0FE4B40B935E9B6440B5840EA094B3CA0FE4B40
613	Верх-Атины	5	49	83	96.290936000000002	96.304239999999993	55.915013000000002	55.908954000000001	0103000020E61000000100000005000000A94E07B29E125840C1C8CB9A58F44B40A94E07B29E1258401A355F251FF54B40A4880CAB781358401A355F251FF54B40A4880CAB78135840C1C8CB9A58F44B40A94E07B29E125840C1C8CB9A58F44B40
47963	Бражное	5	49	83	95.845471000000003	95.874864000000002	56.073343000000001	56.057011000000003	0103000020E61000000100000005000000DAAD65321CF657409241EE224C074C40DAAD65321CF65740FD31AD4D63094C40A81C93C5FDF75740FD31AD4D63094C40A81C93C5FDF757409241EE224C074C40DAAD65321CF657409241EE224C074C40
32389	Богдановка	5	49	83	95.884484999999998	95.904759999999996	56.461888999999999	56.457607000000003	0103000020E610000001000000050000005D33F9669BF85740D9B5BDDD923A4C405D33F9669BF85740EAB0C22D1F3B4C40A7AE7C96E7F95740EAB0C22D1F3B4C40A7AE7C96E7F95740D9B5BDDD923A4C405D33F9669BF85740D9B5BDDD923A4C40
4969	Амонаш	5	49	83	95.832256999999998	95.846611999999993	55.909624999999998	55.899763999999998	0103000020E610000001000000050000007E37DDB243F557401F0F7D772BF34B407E37DDB243F55740DF4F8D976EF44B40AC1919E42EF65740DF4F8D976EF44B40AC1919E42EF657401F0F7D772BF34B407E37DDB243F557401F0F7D772BF34B40
30107	Центральный	5	49	1187	92.24691	92.272717999999998	54.369114000000003	54.356214000000001	0103000020E610000001000000050000008BC3995FCD0F57404D309C6B982D4B408BC3995FCD0F5740753FA7203F2F4B40F4C1323674115740753FA7203F2F4B40F4C13236741157404D309C6B982D4B408BC3995FCD0F57404D309C6B982D4B40
30468	Средняя Салба	5	49	1187	92.302102000000005	92.317696999999995	54.195028999999998	54.184730000000002	0103000020E610000001000000050000009983A0A355135740884B8E3BA5174B409983A0A355135740C362D4B5F6184B406342CC2555145740C362D4B5F6184B406342CC2555145740884B8E3BA5174B409983A0A355135740884B8E3BA5174B40
30934	Романовка	5	49	1187	92.011748999999995	92.026724000000002	54.736919999999998	54.716289000000003	0103000020E61000000100000005000000AFB0E07EC000574006BEA25BAF5B4B40AFB0E07EC000574058E20165535E4B402C8194D8B501574058E20165535E4B402C8194D8B501574006BEA25BAF5B4B40AFB0E07EC000574006BEA25BAF5B4B40
51857	Поселок Сибирь	5	49	1187	91.765996000000001	93.304793000000004	54.945898	54.123196	0103000020E610000001000000050000007A37161406F15640BF7FF3E2C40F4B407A37161406F1564008AD872F13794B402FC37FBA8153574008AD872F13794B402FC37FBA81535740BF7FF3E2C40F4B407A37161406F15640BF7FF3E2C40F4B40
30233	Отрок	5	49	1187	92.538304999999994	92.559308000000001	54.451261000000002	54.441366000000002	0103000020E610000001000000050000007D91D096732257407EC85BAE7E384B407D91D09673225740EA7AA2EBC2394B400919C8B3CB235740EA7AA2EBC2394B400919C8B3CB2357407EC85BAE7E384B407D91D096732257407EC85BAE7E384B40
30912	Октябрьский	5	49	1187	91.860077000000004	91.875878	54.393759000000003	54.387379000000003	0103000020E61000000100000005000000ADC266800BF756401F1494A295314B40ADC266800BF75640BAC0E5B166324B404C5299620EF85640BAC0E5B166324B404C5299620EF856401F1494A295314B40ADC266800BF756401F1494A295314B40
31481	Новотроицкое	5	49	1187	92.521281999999999	92.546515999999997	54.550749000000003	54.537211999999997	0103000020E61000000100000005000000957F2DAF5C2157406682E15CC3444B40957F2DAF5C21574001A777F17E464B4068AF3E1EFA22574001A777F17E464B4068AF3E1EFA2257406682E15CC3444B40957F2DAF5C2157406682E15CC3444B40
31204	Новоберёзовка	5	49	1187	92.050258999999997	92.078619000000003	54.551088999999997	54.520744000000001	0103000020E6100000010000000500000019558671370357404BCB48BDA7424B401955867137035740B91798158A464B400876FC1708055740B91798158A464B400876FC17080557404BCB48BDA7424B4019558671370357404BCB48BDA7424B40
31338	Никольское	5	49	1187	92.218908999999996	92.259970999999993	54.490251000000001	54.481647000000002	0103000020E6100000010000000500000034F3E49A020E5740B79BE09BA63D4B4034F3E49A020E574068EA758BC03E4B4023BA675DA310574068EA758BC03E4B4023BA675DA3105740B79BE09BA63D4B4034F3E49A020E5740B79BE09BA63D4B40
31308	Мензот	5	49	1187	92.236552000000003	92.246200000000002	54.566750999999996	54.555188000000001	0103000020E610000001000000050000006BF3FFAA230F5740DA907F6610474B406BF3FFAA230F5740D6FCF84B8B484B409D11A5BDC10F5740D6FCF84B8B484B409D11A5BDC10F5740DA907F6610474B406BF3FFAA230F5740DA907F6610474B40
30747	Малый Хабык	5	49	1187	92.059736999999998	92.093845999999999	54.446691000000001	54.432893	0103000020E610000001000000050000001D5723BBD20357406BD5AE0969374B401D5723BBD20357407235B22B2D394B401137A792010657407235B22B2D394B401137A792010657406BD5AE0969374B401D5723BBD20357406BD5AE0969374B40
28390	Майское Утро	5	49	1187	91.983819999999994	92.003851999999995	54.393045999999998	54.384601000000004	0103000020E61000000100000005000000A54929E8F6FE56402481069B3A314B40A54929E8F6FE56406CE9D1544F324B408C81751C3F0057406CE9D1544F324B408C81751C3F0057402481069B3A314B40A54929E8F6FE56402481069B3A314B40
30862	Майский	5	49	1187	91.978367000000006	91.998112000000006	54.493184999999997	54.481453999999999	0103000020E61000000100000005000000151F9F909DFE5640A243E048A03D4B40151F9F909DFE56405AF0A2AF203F4B40B16F2711E1FF56405AF0A2AF203F4B40B16F2711E1FF5640A243E048A03D4B40151F9F909DFE5640A243E048A03D4B40
30606	Куреж	5	49	1187	92.091205000000002	92.117489000000006	54.219952999999997	54.203225000000003	0103000020E61000000100000005000000D40E7F4DD6055740645DDC46031A4B40D40E7F4DD60557401BD47E6B271C4B40F22895F0840757401BD47E6B271C4B40F22895F084075740645DDC46031A4B40D40E7F4DD6055740645DDC46031A4B40
31094	Королевка	5	49	1187	92.132966999999994	92.153332000000006	54.746997	54.738197999999997	0103000020E610000001000000050000009F1C0588820857407EFCA5457D5E4B409F1C058882085740E59A02999D5F4B408A5B0531D0095740E59A02999D5F4B408A5B0531D00957407EFCA5457D5E4B409F1C0588820857407EFCA5457D5E4B40
30308	Козино	5	49	1187	92.668335999999996	92.688063	54.444533999999997	54.436329000000001	0103000020E6100000010000000500000053AF5B04C62A5740F0A5F0A0D9374B4053AF5B04C62A5740E3FA777DE6384B409CA56439092C5740E3FA777DE6384B409CA56439092C5740F0A5F0A0D9374B4053AF5B04C62A5740F0A5F0A0D9374B40
11311	Кедровая	5	49	1187	92.030218000000005	92.038392999999999	54.177953000000002	54.171818999999999	0103000020E6100000010000000500000009707A17EF0157406CEA3C2AFE154B4009707A17EF015740D09CF529C7164B404DD9E90775025740D09CF529C7164B404DD9E907750257406CEA3C2AFE154B4009707A17EF0157406CEA3C2AFE154B40
31012	Иннокентьевка	5	49	1187	91.868709999999993	91.896010000000004	54.786850999999999	54.774653999999998	0103000020E6100000010000000500000052EDD3F198F7564098DBBDDC27634B4052EDD3F198F7564096E99788B7644B40E5B8533A58F9564096E99788B7644B40E5B8533A58F9564098DBBDDC27634B4052EDD3F198F7564098DBBDDC27634B40
29919	Идринское	5	49	1187	92.078691000000006	92.189443999999995	54.400069999999999	54.361372000000003	0103000020E6100000010000000500000055DFF9450905574056D80C70412E4B4055DFF945090557402C0E677E35334B40191BBAD91F0C57402C0E677E35334B40191BBAD91F0C574056D80C70412E4B4055DFF9450905574056D80C70412E4B40
31547	Зезезино	5	49	1187	92.430695999999998	92.450700999999995	54.566146000000003	54.555950000000003	0103000020E6100000010000000500000027A1F485901B5740091B9E5E29474B4027A1F485901B57407061DD7877484B4091D10149D81C57407061DD7877484B4091D10149D81C5740091B9E5E29474B4027A1F485901B5740091B9E5E29474B40
31445	Еленинск	5	49	1187	92.364885000000001	92.392464000000004	54.509518	54.501775000000002	0103000020E6100000010000000500000043739D465A175740A779C7293A404B4043739D465A175740965CC5E237414B40DF3653211E195740965CC5E237414B40DF3653211E195740A779C7293A404B4043739D465A175740A779C7293A404B40
31213	Екатериновка	5	49	1187	92.146630999999999	92.168046000000004	54.566082999999999	54.546351999999999	0103000020E610000001000000050000001B65FD6662095740560DC2DCEE454B401B65FD666209574029E9616875484B40508E0244C10A574029E9616875484B40508E0244C10A5740560DC2DCEE454B401B65FD6662095740560DC2DCEE454B40
30794	Добромысловский	5	49	1187	91.873227999999997	91.889452000000006	54.504776	54.488624000000002	0103000020E61000000100000005000000E57CB1F7E2F756403605323B8B3E4B40E57CB1F7E2F7564021E7FD7F9C404B4028D714C8ECF8564021E7FD7F9C404B4028D714C8ECF856403605323B8B3E4B40E57CB1F7E2F756403605323B8B3E4B40
30707	Большой Хабык	5	49	1187	91.929902999999996	91.957104000000001	54.431741000000002	54.417462	0103000020E61000000100000005000000F25CDF8783FB564050A912656F354B40F25CDF8783FB5640D2AB014A43374B40BBB7223141FD5640D2AB014A43374B40BBB7223141FD564050A912656F354B40F25CDF8783FB564050A912656F354B40
30546	Большой Телек	5	49	1187	92.044088000000002	92.083056999999997	54.298468999999997	54.288947	0103000020E6100000010000000500000059897956D20257407FA31D37FC244B4059897956D202574056EF703B34264B400CAD4ECE5005574056EF703B34264B400CAD4ECE500557407FA31D37FC244B4059897956D20257407FA31D37FC244B40
30333	Большие Кныши	5	49	1187	92.551061000000004	92.584136999999998	54.267415	54.243640999999997	0103000020E6100000010000000500000078465B95442357407C7BD7A02F1F4B4078465B9544235740DCBA9BA73A224B408CD8278062255740DCBA9BA73A224B408CD82780622557407C7BD7A02F1F4B4078465B95442357407C7BD7A02F1F4B40
30443	Большая Салба	5	49	1187	92.317229999999995	92.339427000000001	54.245339999999999	54.225332000000002	0103000020E61000000100000005000000D8D30E7F4D145740035FD1ADD71C4B40D8D30E7F4D1457404833164D671F4B404818062CB91557404833164D671F4B404818062CB9155740035FD1ADD71C4B40D8D30E7F4D145740035FD1ADD71C4B40
30145	Большая Идра	5	49	1187	92.351330000000004	92.370903999999996	54.359971000000002	54.350510999999997	0103000020E61000000100000005000000A306D3307C165740B2F1608BDD2C4B40A306D3307C16574014419C87132E4B40287D21E4BC17574014419C87132E4B40287D21E4BC175740B2F1608BDD2C4B40A306D3307C165740B2F1608BDD2C4B40
18277	Адриха	5	49	1187	92.413034999999994	92.424605	54.432192000000001	54.418232000000003	0103000020E610000001000000050000009D465A2A6F1A574002124DA088354B409D465A2A6F1A5740E2CB441152374B40F52D73BA2C1B5740E2CB441152374B40F52D73BA2C1B574002124DA088354B409D465A2A6F1A574002124DA088354B40
29359	Танзыбей	5	49	1722	92.928011999999995	92.964941999999994	53.141221999999999	53.093223999999999	0103000020E61000000100000005000000EA92718C643B5740E59997C3EE8B4A40EA92718C643B5740E4BCFF8F13924A405B22179CC13D5740E4BCFF8F13924A405B22179CC13D5740E59997C3EE8B4A40EA92718C643B5740E59997C3EE8B4A40
32892	Семенниково	5	49	1722	92.219143000000003	92.258210000000005	53.204605999999998	53.195948000000001	0103000020E610000001000000050000006E895C70060E5740BADBF5D214994A406E895C70060E57405E488787309A4A4003603C83861057405E488787309A4A4003603C8386105740BADBF5D214994A406E895C70060E5740BADBF5D214994A40
49136	Салба	5	49	1722	92.584154999999996	92.611096000000003	53.247210000000003	53.227041999999997	0103000020E61000000100000005000000DF32A7CB62255740C26856B60F9D4A40DF32A7CB62255740419FC893A49F4A40DAAD65321C275740419FC893A49F4A40DAAD65321C275740C26856B60F9D4A40DF32A7CB62255740C26856B60F9D4A40
29772	Разъезжее	5	49	1722	92.418469999999999	92.451859999999996	53.131740999999998	53.114621999999997	0103000020E61000000100000005000000DB166536C81A574078B306EFAB8E4A40DB166536C81A57406B459BE3DC904A40B7973446EB1C57406B459BE3DC904A40B7973446EB1C574078B306EFAB8E4A40DB166536C81A574078B306EFAB8E4A40
40416	Песочный	5	49	1722	92.442481999999998	92.454060999999996	53.271599999999999	53.263235999999999	0103000020E6100000010000000500000065C405A0511C57409F909DB7B1A14A4065C405A0511C5740FBCBEEC9C3A24A40E658DE550F1D5740FBCBEEC9C3A24A40E658DE550F1D57409F909DB7B1A14A4065C405A0511C57409F909DB7B1A14A40
29125	Ойский	5	49	1722	92.481881999999999	92.511508000000006	53.251837999999999	53.234098000000003	0103000020E61000000100000005000000FDA19927D71E57408E075BECF69D4A40FDA19927D71E5740EDF1423A3CA04A401DE90C8CBC205740EDF1423A3CA04A401DE90C8CBC2057408E075BECF69D4A40FDA19927D71E57408E075BECF69D4A40
32805	Новополтавка	5	49	1722	92.607906999999997	92.627571000000003	53.329977	53.318882000000002	0103000020E610000001000000050000009B00C3F2E72657403CA41820D1A84A409B00C3F2E726574052B7B3AF3CAA4A40C13A8E1F2A28574052B7B3AF3CAA4A40C13A8E1F2A2857403CA41820D1A84A409B00C3F2E72657403CA41820D1A84A40
29109	Новоозерный	5	49	1722	92.401492000000005	92.426599999999993	53.250312999999998	53.237343000000003	0103000020E61000000100000005000000C366800BB21957409F776341619E4A40C366800BB2195740BF61A2410AA04A404F1E166A4D1B5740BF61A2410AA04A404F1E166A4D1B57409F776341619E4A40C366800BB21957409F776341619E4A40
29628	Нижнеусинское	5	49	1722	92.995385999999996	93.025929000000005	52.263342000000002	52.255118000000003	0103000020E610000001000000050000005C397B67B43F57407B4FE5B4A7204A405C397B67B43F5740E5D4CE30B5214A4027C11BD2A8415740E5D4CE30B5214A4027C11BD2A84157407B4FE5B4A7204A405C397B67B43F57407B4FE5B4A7204A40
59692	Нижнесуэтук	5	49	1722	92.453620999999998	92.475666000000004	53.352251000000003	53.336773999999998	0103000020E61000000100000005000000D8F15F20081D5740511212691BAB4A40D8F15F20081D5740DD7D8E8F16AD4A406D74CE4F711E5740DD7D8E8F16AD4A406D74CE4F711E5740511212691BAB4A40D8F15F20081D5740511212691BAB4A40
29703	Мигна	5	49	1722	92.209682999999998	92.238159999999993	53.143096	53.121529000000002	0103000020E61000000100000005000000BDE13E726B0D5740FF4124438E8F4A40BDE13E726B0D57401E1840F850924A40C8CD70033E0F57401E1840F850924A40C8CD70033E0F5740FF4124438E8F4A40BDE13E726B0D5740FF4124438E8F4A40
59757	Ивановка	5	49	1722	92.184944000000002	92.203807999999995	53.388247999999997	53.381200999999997	0103000020E61000000100000005000000DAE55B1FD60B5740EB19C231CBB04A40DAE55B1FD60B5740635E471CB2B14A4071AAB5300B0D5740635E471CB2B14A4071AAB5300B0D5740EB19C231CBB04A40DAE55B1FD60B5740EB19C231CBB04A40
23304	Ермаковское	5	49	1722	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
32810	Григорьевка	5	49	1722	92.834227999999996	92.856128999999996	53.231689000000003	53.208590999999998	0103000020E61000000100000005000000145AD6FD63355740B69E211CB39A4A40145AD6FD63355740E6EB32FCA79D4A400F0A4AD1CA365740E6EB32FCA79D4A400F0A4AD1CA365740B69E211CB39A4A40145AD6FD63355740B69E211CB39A4A40
29562	Верхнеусинское	5	49	1722	92.996527	93.049599000000001	52.248375000000003	52.230535000000003	0103000020E610000001000000050000002FA52E19C73F5740ACCABE2B821D4A402FA52E19C73F57406F1283C0CA1F4A4084BA48A12C4357406F1283C0CA1F4A4084BA48A12C435740ACCABE2B821D4A402FA52E19C73F5740ACCABE2B821D4A40
49325	Большая Речка	5	49	1722	92.405139000000005	92.433633	53.038713000000001	53.033768999999999	0103000020E6100000010000000500000063D520CCED1957402F4FE78A52844A4063D520CCED1957400C772E8CF4844A40D95DA0A4C01B57400C772E8CF4844A40D95DA0A4C01B57402F4FE78A52844A4063D520CCED1957402F4FE78A52844A40
29425	Арадан	5	49	1722	93.440070000000006	93.446788999999995	52.581347999999998	52.569817	0103000020E61000000100000005000000D97C5C1B2A5C574038DA71C3EF484A40D97C5C1B2A5C574029CC7B9C694A4A409ACDE330985C574029CC7B9C694A4A409ACDE330985C574038DA71C3EF484A40D97C5C1B2A5C574038DA71C3EF484A40
59578	с.Ярцево	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59594	п.Новокаргино	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59799	п. Александровский Шлюз	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59738	д.Назимово	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
51888	д.Малобелая	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59863	д.Колмогорово	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59816	Шишмарево	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
27047	Шапкино	5	49	1509	93.031398999999993	93.074177000000006	57.898586000000002	57.869154000000002	0103000020E610000001000000050000002288F370024257400398327040EF4C402288F370024257405D52B5DD04F34C406347E350BF4457405D52B5DD04F34C406347E350BF4457400398327040EF4C402288F370024257400398327040EF4C40
59709	Чалбышево	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59851	Усть-Тунгуска	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59860	Усть-Пит	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59603	Усть-Кемь	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
51823	Село Сым	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59663	Потапово	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
51849	Подтесово	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59492	Озерное	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59865	Новый Городок	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59667	Новоназимово	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59750	Маковское	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
51893	Майское	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59674	Кривляк	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
51800	Деревня Безымянка	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59762	Городище	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59691	Высокогорский	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59839	Байкал	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59891	Анциферово	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59798	Айдара	5	49	1509	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
59575	Элита	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59659	Шуваево	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59491	Частоостровское	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59654	Устюг	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59634	Талое	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59599	Солонцы	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59843	Серебряково	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59733	Раскаты	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59720	Плоское	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
51871	Памяти 13 Борцов	5	49	202	92.282859999999999	92.350960999999998	56.231938	56.200158000000002	0103000020E610000001000000050000002E56D4601A125740320400C79E194C402E56D4601A1257408E59F624B01D4C40F94A2025761657408E59F624B01D4C40F94A202576165740320400C79E194C402E56D4601A125740320400C79E194C40
59480	Никольское	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
9997	Можарский	5	49	202	91.651945999999995	91.664927000000006	56.193637000000003	56.189278999999999	0103000020E610000001000000050000008330B77BB9E95640E868554B3A184C408330B77BB9E95640D525E318C9184C408ECEF9298EEA5640D525E318C9184C408ECEF9298EEA5640E868554B3A184C408330B77BB9E95640E868554B3A184C40
59652	Минино	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
26411	Медведа	5	49	202	92.401887000000002	92.412164000000004	56.510651000000003	56.502200999999999	0103000020E61000000100000005000000016C4084B81957405E82531F48404C40016C4084B8195740B95510035D414C40AB251DE5601A5740B95510035D414C40AB251DE5601A57405E82531F48404C40016C4084B81957405E82531F48404C40
18712	Малый Кемчуг	5	49	202	92.140512999999999	92.161049000000006	56.233524000000003	56.227334999999997	0103000020E610000001000000050000006CEA3C2AFE0857403A1E3350191D4C406CEA3C2AFE085740626A4B1DE41D4C406D0377A04E0A5740626A4B1DE41D4C406D0377A04E0A57403A1E3350191D4C406CEA3C2AFE0857403A1E3350191D4C40
59729	Кубеково	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
25138	Кача	5	49	202	92.212701999999993	92.230649999999997	56.103828999999998	56.093651000000001	0103000020E61000000100000005000000CD72D9E89C0D57406D1E87C1FC0B4C40CD72D9E89C0D57402DB0C7444A0D4C40A2B437F8C20E57402DB0C7444A0D4C40A2B437F8C20E57406D1E87C1FC0B4C40CD72D9E89C0D57406D1E87C1FC0B4C40
25064	Зеледеево	5	49	202	91.959224000000006	91.994726	56.079362000000003	56.068620000000003	0103000020E6100000010000000500000074620FED63FD5640FFEC478AC8084C4074620FED63FD5640C845B588280A4C40C79E3D97A9FF5640C845B588280A4C40C79E3D97A9FF5640FFEC478AC8084C4074620FED63FD5640FFEC478AC8084C40
59862	Замятино	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59649	Емельяново	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
51749	Еловая	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59791	Гляден	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
26494	Гаревое	5	49	202	92.637658999999999	92.658338000000001	56.652042000000002	56.640199000000003	0103000020E6100000010000000500000001C0B167CF28574049F7730AF2514C4001C0B167CF28574029CFBC1C76534C40B3EDB435222A574029CFBC1C76534C40B3EDB435222A574049F7730AF2514C4001C0B167CF28574049F7730AF2514C40
765	Бахта	5	49	202	92.417445999999998	92.424992000000003	55.74109	55.736806999999999	0103000020E6100000010000000500000025766D6FB71A5740603B18B14FDE4B4025766D6FB71A574042B28009DCDE4B40F243A511331B574042B28009DCDE4B40F243A511331B5740603B18B14FDE4B4025766D6FB71A5740603B18B14FDE4B40
59769	Барабаново	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
51838	Арейское	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
59783	Арей	5	49	202	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
51777	Алексеевка	5	49	202	91.979292000000001	91.985123000000002	56.628673999999997	56.623806000000002	0103000020E61000000100000005000000014F5AB8ACFE5640388600E0D84F4C40014F5AB8ACFE564039ECBE6378504C4065E256410CFF564039ECBE6378504C4065E256410CFF5640388600E0D84F4C40014F5AB8ACFE5640388600E0D84F4C40
51837	Таскино	5	49	7125	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
60915	п. Хант. Оз.	5	49	7495	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
59913	п. Потапово	5	49	7495	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
23775	Шеломки	5	49	822	94.840093999999993	94.874257	56.808950000000003	56.793385000000001	0103000020E6100000010000000500000036E49F19C4B557408811C2A38D654C4036E49F19C4B55740B30C71AC8B674C4024D3A1D3F3B75740B30C71AC8B674C4024D3A1D3F3B757408811C2A38D654C4036E49F19C4B557408811C2A38D654C40
22858	Чурюково	5	49	822	95.049634999999995	95.066559999999996	56.638714	56.627253000000003	0103000020E610000001000000050000002A6F47382DC35740B1A888D349504C402A6F47382DC35740A9BF5E61C1514C4031CEDF8442C45740A9BF5E61C1514C4031CEDF8442C45740B1A888D349504C402A6F47382DC35740B1A888D349504C40
23488	Чемурай	5	49	822	95.337733999999998	95.347885000000005	56.910547000000001	56.905062000000001	0103000020E61000000100000005000000D32F116F9DD557401A6D5512D9734C40D32F116F9DD55740473CD9CD8C744C40377172BF43D65740473CD9CD8C744C40377172BF43D657401A6D5512D9734C40D32F116F9DD557401A6D5512D9734C40
22686	Усолка	5	49	822	95.310461000000004	95.331256999999994	56.786127999999998	56.771703000000002	0103000020E61000000100000005000000BE6BD097DED35740D09CF529C7624C40BE6BD097DED35740253CA1D79F644C408C648F5033D55740253CA1D79F644C408C648F5033D55740D09CF529C7624C40BE6BD097DED35740D09CF529C7624C40
22956	Улюколь	5	49	822	94.909417000000005	94.937192999999994	56.711951999999997	56.702109999999998	0103000020E610000001000000050000004B5B5CE333BA5740E71890BDDE594C404B5B5CE333BA574030293E3E215B4C40914259F8FABB574030293E3E215B4C40914259F8FABB5740E71890BDDE594C404B5B5CE333BA5740E71890BDDE594C40
23626	Топол	5	49	822	95.102329999999995	95.134238999999994	56.948509000000001	56.938797000000001	0103000020E6100000010000000500000094D920938CC657409D4A06802A784C4094D920938CC65740187B2FBE68794C4041B62C5F97C85740187B2FBE68794C4041B62C5F97C857409D4A06802A784C4094D920938CC657409D4A06802A784C40
23306	Таловая	5	49	822	95.481966999999997	95.502808000000002	56.808447000000001	56.803322000000001	0103000020E6100000010000000500000014B01D8CD8DE574023145B41D3664C4014B01D8CD8DE574050C6F8307B674C40B30A9B012EE0574050C6F8307B674C40B30A9B012EE0574023145B41D3664C4014B01D8CD8DE574023145B41D3664C40
5904	Сухо-Ерша	5	49	822	95.289278999999993	95.316937999999993	56.587950999999997	56.578893999999998	0103000020E61000000100000005000000DA1A118C83D25740E1ECD632194A4C40DA1A118C83D25740435376FA414B4C40043752B648D45740435376FA414B4C40043752B648D45740E1ECD632194A4C40DA1A118C83D25740E1ECD632194A4C40
23319	Семеновка	5	49	822	95.405404000000004	95.427825999999996	56.844033000000003	56.837913	0103000020E61000000100000005000000BA6A9E23F2D9574056F2B1BB406B4C40BA6A9E23F2D9574055DFF945096C4C4039984D8061DB574055DFF945096C4C4039984D8061DB574056F2B1BB406B4C40BA6A9E23F2D9574056F2B1BB406B4C40
23223	Плитная	5	49	822	95.547527000000002	95.563849000000005	56.744624000000002	56.743281000000003	0103000020E6100000010000000500000054ABAFAE0AE357407D5EF1D4235F4C4054ABAFAE0AE357408AE8D7D64F5F4C4078B81D1A16E457408AE8D7D64F5F4C4078B81D1A16E457407D5EF1D4235F4C4054ABAFAE0AE357407D5EF1D4235F4C40
23133	Петровка (Алатка)	5	49	822	95.477565999999996	95.503437000000005	56.598725999999999	56.591123000000003	0103000020E610000001000000050000009EEBFB7090DE5740EB7420EBA94B4C409EEBFB7090DE5740E8A1B60DA34C4C402BA6D24F38E05740E8A1B60DA34C4C402BA6D24F38E05740EB7420EBA94B4C409EEBFB7090DE5740EB7420EBA94B4C40
17538	Орловка	5	49	822	95.483485999999999	95.520532000000003	56.944409999999998	56.929447000000003	0103000020E61000000100000005000000BA84436FF1DE5740C32E8A1EF8764C40BA84436FF1DE5740F701486DE2784C406021736550E15740F701486DE2784C406021736550E15740C32E8A1EF8764C40BA84436FF1DE5740C32E8A1EF8764C40
59815	Новый	5	49	822	94.777697000000003	94.793453999999997	56.734690999999998	56.725076999999999	0103000020E61000000100000005000000A14CA3C9C5B15740780AB952CF5C4C40A14CA3C9C5B1574030D5CC5A0A5E4C40583849F3C7B2574030D5CC5A0A5E4C40583849F3C7B25740780AB952CF5C4C40A14CA3C9C5B15740780AB952CF5C4C40
22783	Николаевка	5	49	822	95.355852999999996	95.381930999999994	56.623603000000003	56.613830999999998	0103000020E61000000100000005000000BE4BA94BC6D65740AF22A303924E4C40BE4BA94BC6D6574000581D39D24F4C400795B88E71D8574000581D39D24F4C400795B88E71D85740AF22A303924E4C40BE4BA94BC6D65740AF22A303924E4C40
23231	Нижний Танай	5	49	822	95.348505000000003	95.375679000000005	56.758941	56.747402999999998	0103000020E61000000100000005000000855FEAE74DD6574055F7C8E6AA5F4C40855FEAE74DD65740F94B8BFA24614C40D1B2EE1F0BD85740F94B8BFA24614C40D1B2EE1F0BD8574055F7C8E6AA5F4C40855FEAE74DD6574055F7C8E6AA5F4C40
22933	Михайловка	5	49	822	95.117035999999999	95.150830999999997	56.695442999999997	56.688240999999998	0103000020E61000000100000005000000191D90847DC757401762F54718584C40191D90847DC75740B69DB64604594C40450E1137A7C95740B69DB64604594C40450E1137A7C957401762F54718584C40191D90847DC757401762F54718584C40
23952	Макарово	5	49	822	94.891271000000003	94.910764999999998	56.820335999999998	56.813403999999998	0103000020E61000000100000005000000E33785950AB95740C1374D9F1D684C40E33785950AB95740A0DD21C500694C40DA5548F949BA5740A0DD21C500694C40DA5548F949BA5740C1374D9F1D684C40E33785950AB95740C1374D9F1D684C40
23040	Курай	5	49	822	95.471896999999998	95.517450999999994	56.701951999999999	56.680306000000002	0103000020E610000001000000050000002785798F33DE5740E4A25A4414574C402785798F33DE57404FAE2990D9594C401492CCEA1DE157404FAE2990D9594C401492CCEA1DE15740E4A25A4414574C402785798F33DE5740E4A25A4414574C40
23700	Кондратьево	5	49	822	94.996105	95.018590000000003	56.851804999999999	56.843181000000001	0103000020E6100000010000000500000074982F2FC0BF5740E6CDE15AED6B4C4074982F2FC0BF5740DEC83CF2076D4C4017821C9430C15740DEC83CF2076D4C4017821C9430C15740E6CDE15AED6B4C4074982F2FC0BF5740E6CDE15AED6B4C40
23593	Колон	5	49	822	95.098224999999999	95.116461000000001	57.022072999999999	57.013694999999998	0103000020E6100000010000000500000093A9825149C65740328FFCC1C0814C4093A9825149C65740F38FBE49D3824C409B90D61874C75740F38FBE49D3824C409B90D61874C75740328FFCC1C0814C4093A9825149C65740328FFCC1C0814C40
22598	Кедровка	5	49	822	95.301091999999997	95.319139000000007	56.864767000000001	56.854467999999997	0103000020E610000001000000050000009545611745D3574040BD19355F6D4C409545611745D357407CD45FAFB06E4C4034F8FBC56CD457407CD45FAFB06E4C4034F8FBC56CD4574040BD19355F6D4C409545611745D3574040BD19355F6D4C40
8926	Канарай	5	49	822	94.720231999999996	94.751268999999994	56.958449000000002	56.944409999999998	0103000020E610000001000000050000001762F54718AE5740F701486DE2784C401762F54718AE574024F1F274AE7A4C40E95F92CA14B0574024F1F274AE7A4C40E95F92CA14B05740F701486DE2784C401762F54718AE5740F701486DE2784C40
22235	Дзержинское	5	49	822	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
23502	Денисово	5	49	822	95.077922999999998	95.109471999999997	56.863444000000001	56.845692	0103000020E61000000100000005000000CC26C0B0FCC45740923EADA23F6C4C40CC26C0B0FCC45740B6F63E55856E4C40F9F4D89601C75740B6F63E55856E4C40F9F4D89601C75740923EADA23F6C4C40CC26C0B0FCC45740923EADA23F6C4C40
22846	Вознесенка	5	49	822	95.044730000000001	95.071330000000003	56.660590999999997	56.654465999999999	0103000020E610000001000000050000009BC937DBDCC25740062CB98AC5534C409BC937DBDCC257401684F23E8E544C40514EB4AB90C457401684F23E8E544C40514EB4AB90C45740062CB98AC5534C409BC937DBDCC25740062CB98AC5534C40
45472	Борки	5	49	822	94.945988	94.968176	56.974454999999999	56.968062000000003	0103000020E61000000100000005000000249A40118BBC57400C40A374E97B4C40249A40118BBC57403B3602F1BA7C4C406A317898F6BD57403B3602F1BA7C4C406A317898F6BD57400C40A374E97B4C40249A40118BBC57400C40A374E97B4C40
23908	Большая Степь	5	49	822	94.781524000000005	94.799131000000003	56.887934999999999	56.880253000000003	0103000020E6100000010000000500000081423D7D04B257405B9A5B21AC704C4081423D7D04B25740A4FCA4DAA7714C40118E59F624B35740A4FCA4DAA7714C40118E59F624B357405B9A5B21AC704C4081423D7D04B257405B9A5B21AC704C40
23851	Батов	5	49	822	94.577759	94.602633999999995	56.838690999999997	56.830506999999997	0103000020E610000001000000050000000F7EE200FAA45740AE0CAA0D4E6A4C400F7EE200FAA457408A39083A5A6B4C404A5D328E91A657408A39083A5A6B4C404A5D328E91A65740AE0CAA0D4E6A4C400F7EE200FAA45740AE0CAA0D4E6A4C40
23126	Ашпатск	5	49	822	95.522516999999993	95.557489000000004	56.690579	56.681041999999998	0103000020E61000000100000005000000A8A624EB70E15740E9995E622C574C40A8A624EB70E15740F62686E464584C404EB857E6ADE35740F62686E464584C404EB857E6ADE35740E9995E622C574C40A8A624EB70E15740E9995E622C574C40
22698	Александро-Ерша	5	49	822	95.239673999999994	95.290492	56.635010999999999	56.624097999999996	0103000020E61000000100000005000000E5EC9DD156CF5740DFBF7971E24F4C40E5EC9DD156CF5740D5CC5A0A48514C40FAEFC16B97D25740D5CC5A0A48514C40FAEFC16B97D25740DFBF7971E24F4C40E5EC9DD156CF5740DFBF7971E24F4C40
21790	Удачное	5	49	875	90.363493000000005	90.385546000000005	56.684685999999999	56.674708000000003	0103000020E61000000100000005000000CCD4247843975640BF2CEDD45C564C40CCD4247843975640B80375CAA3574C40A24621C9AC985640B80375CAA3574C40A24621C9AC985640BF2CEDD45C564C40CCD4247843975640BF2CEDD45C564C40
14837	Турецк	5	49	875	90.678712000000004	90.701663999999994	56.580247999999997	56.570827000000001	0103000020E61000000100000005000000C7D9740470AB56403F56F0DB10494C40C7D9740470AB5640E2C80391454A4C40F4311F10E8AC5640E2C80391454A4C40F4311F10E8AC56403F56F0DB10494C40C7D9740470AB56403F56F0DB10494C40
21178	Таежка	5	49	875	90.999904000000001	91.018904000000006	56.62697	56.618952999999998	0103000020E61000000100000005000000EFC8586DFEBF56406B6116DA394F4C40EFC8586DFEBF56405CC98E8D40504C40DF701FB935C156405CC98E8D40504C40DF701FB935C156406B6116DA394F4C40EFC8586DFEBF56406B6116DA394F4C40
46009	Сучково	5	49	875	90.440910000000002	90.510664000000006	56.579489000000002	56.569080999999997	0103000020E61000000100000005000000AE9E93DE379C564032E36DA5D7484C40AE9E93DE379C564025B20FB22C4A4C40A7CF0EB8AEA0564025B20FB22C4A4C40A7CF0EB8AEA0564032E36DA5D7484C40AE9E93DE379C564032E36DA5D7484C40
59780	Сосновый Бор	5	49	875	90.550702000000001	90.565451999999993	56.624623	56.616630000000001	0103000020E61000000100000005000000E0F599B33EA35640C2DD59BBED4E4C40E0F599B33EA356402AAA7EA5F34F4C404CDD955D30A456402AAA7EA5F34F4C404CDD955D30A45640C2DD59BBED4E4C40E0F599B33EA35640C2DD59BBED4E4C40
21657	Симоново	5	49	875	90.455579	90.471299999999999	56.512493999999997	56.504308000000002	0103000020E61000000100000005000000A46FD234289D56403B8E1F2A8D404C40A46FD234289D5640B7B2446799414C40B5A679C7299E5640B7B2446799414C40B5A679C7299E56403B8E1F2A8D404C40A46FD234289D56403B8E1F2A8D404C40
21559	Новая-Еловка	5	49	875	90.633463000000006	90.653226000000004	56.504243000000002	56.482258999999999	0103000020E61000000100000005000000780E65A88AA85640D099B4A9BA3D4C40780E65A88AA85640541EDD088B404C4067B96C74CEA95640541EDD088B404C4067B96C74CEA95640D099B4A9BA3D4C40780E65A88AA85640D099B4A9BA3D4C40
21107	Кытат	5	49	875	91.192430999999999	91.209327999999999	56.810639999999999	56.797817000000002	0103000020E6100000010000000500000024EF1CCA50CC5640AF9811DE1E664C4024EF1CCA50CC56402B6A300DC3674C40C68844A165CD56402B6A300DC3674C40C68844A165CD5640AF9811DE1E664C4024EF1CCA50CC5640AF9811DE1E664C40
59754	Карабановка	5	49	875	90.419196999999997	90.443990999999997	56.752195	56.743246999999997	0103000020E610000001000000050000003465A71FD49A5640D0ECBAB7225F4C403465A71FD49A56407C9BFEEC47604C40F92D3A596A9C56407C9BFEEC47604C40F92D3A596A9C5640D0ECBAB7225F4C403465A71FD49A5640D0ECBAB7225F4C40
21011	Елга	5	49	875	90.826753999999994	90.852985000000004	56.799033999999999	56.792054	0103000020E6100000010000000500000094F59B89E9B456403F55850662654C4094F59B89E9B456402F3201BF46664C40A1BE654E97B656402F3201BF46664C40A1BE654E97B656403F55850662654C4094F59B89E9B456403F55850662654C40
21985	Бычки	5	49	875	90.235905000000002	90.267579999999995	56.566636000000003	56.550564000000001	0103000020E61000000100000005000000A0FD4811198F56406F2D93E178464C40A0FD4811198F56403E5E488787484C401344DD07209156403E5E488787484C401344DD07209156406F2D93E178464C40A0FD4811198F56406F2D93E178464C40
20827	Большой Улуй	5	49	875	90.561158000000006	90.600621000000004	56.668030999999999	56.636257999999998	0103000020E61000000100000005000000E2783E03EAA35640C0E8F2E670514C40E2783E03EAA356406ADB300A82554C409D12109370A656406ADB300A82554C409D12109370A65640C0E8F2E670514C40E2783E03EAA35640C0E8F2E670514C40
21310	Бобровка	5	49	875	90.804494000000005	90.823708999999994	56.632674000000002	56.613112999999998	0103000020E6100000010000000500000002F566D47CB3564050E09D7C7A4E4C4002F566D47CB35640C7832D76FB504C40EF1AF4A5B7B45640C7832D76FB504C40EF1AF4A5B7B4564050E09D7C7A4E4C4002F566D47CB3564050E09D7C7A4E4C40
20352	Язаевка	5	49	1460	93.290024000000003	93.306329000000005	57.330877000000001	57.315764000000001	0103000020E6100000010000000500000087C3D2C08F52574088A06AF46AA84C4087C3D2C08F525740D2FF722D5AAA4C404034F3E49A535740D2FF722D5AAA4C404034F3E49A53574088A06AF46AA84C4087C3D2C08F52574088A06AF46AA84C40
51790	Юксеево	5	49	1460	93.432918999999998	93.446788999999995	56.857401000000003	56.836883999999998	0103000020E610000001000000050000004AB4E4F1B45B5740D845D1031F6B4C404AB4E4F1B45B57406347E350BF6D4C409ACDE330985C57406347E350BF6D4C409ACDE330985C5740D845D1031F6B4C404AB4E4F1B45B5740D845D1031F6B4C40
19638	Тигино	5	49	1460	93.141659000000004	93.166775000000001	56.814546999999997	56.803947999999998	0103000020E61000000100000005000000C80BE9F010495740A1D79FC4E7664C40C80BE9F01049574007077B1343684C4096B20C71AC4A574007077B1343684C4096B20C71AC4A5740A1D79FC4E7664C40C80BE9F010495740A1D79FC4E7664C40
16762	Российка	5	49	1460	93.299150999999995	93.326864	57.078133999999999	57.047145	0103000020E6100000010000000500000034643C4A25535740C095ECD808864C4034643C4A25535740535A7F4B008A4C40588FFB56EB545740535A7F4B008A4C40588FFB56EB545740C095ECD808864C4034643C4A25535740C095ECD808864C40
45432	Раздольное	5	49	1460	93.131984000000003	93.152753000000004	57.242151	57.233587999999997	0103000020E6100000010000000500000019E6046D72485740785E2A36E69D4C4019E6046D72485740CBD8D0CDFE9E4C406BD784B4C6495740CBD8D0CDFE9E4C406BD784B4C6495740785E2A36E69D4C4019E6046D72485740785E2A36E69D4C40
19063	Предивинск	5	49	1460	93.414413999999994	93.453121999999993	57.077244	57.046968999999997	0103000020E610000001000000050000004A404CC2855A57408176871403864C404A404CC2855A5740F7E7A221E3894C4047C66AF3FF5C5740F7E7A221E3894C4047C66AF3FF5C57408176871403864C404A404CC2855A57408176871403864C40
20726	Пакуль	5	49	1460	93.317836	93.336924999999994	56.850540000000002	56.842841	0103000020E61000000100000005000000745FCE6C575457402D5DC136E26B4C40745FCE6C575457404DF8A57EDE6C4C401B0DE02D905557404DF8A57EDE6C4C401B0DE02D905557402D5DC136E26B4C40745FCE6C575457402D5DC136E26B4C40
45583	Муратово	5	49	1460	93.294633000000005	93.316156000000007	57.192694000000003	57.181626999999999	0103000020E61000000100000005000000A2D45E44DB5257400989B48D3F974C40A2D45E44DB52574056116E32AA984C40CA1B60E63B54574056116E32AA984C40CA1B60E63B5457400989B48D3F974C40A2D45E44DB5257400989B48D3F974C40
19157	Мостовское	5	49	1460	92.738619999999997	92.761634999999998	56.764184999999998	56.755768000000003	0103000020E61000000100000005000000FA0AD28C452F574082AE7D01BD604C40FA0AD28C452F5740008C67D0D0614C404B1FBAA0BE305740008C67D0D0614C404B1FBAA0BE30574082AE7D01BD604C40FA0AD28C452F574082AE7D01BD604C40
20508	Минск	5	49	1460	93.325947999999997	93.347893999999997	57.101115	57.095320999999998	0103000020E61000000100000005000000950C0055DC5457409ECF807A338C4C40950C0055DC54574049111956F18C4C40601E32E54356574049111956F18C4C40601E32E5435657409ECF807A338C4C40950C0055DC5457409ECF807A338C4C40
19564	Малый Кантат	5	49	1460	93.112031999999999	93.126171999999997	56.961044999999999	56.944498000000003	0103000020E61000000100000005000000C00644882B47574097917A4FE5784C40C00644882B475740FE7DC685037B4C40F06AB93313485740FE7DC685037B4C40F06AB9331348574097917A4FE5784C40C00644882B47574097917A4FE5784C40
51827	Луговское	5	49	1460	93.297148000000007	93.318106	57.309547000000002	57.297843999999998	0103000020E6100000010000000500000099840B7904535740A8A78FC01FA64C4099840B790453574097C9703C9FA74C4054AA44D95B54574097C9703C9FA74C4054AA44D95B545740A8A78FC01FA64C4099840B7904535740A8A78FC01FA64C40
45353	Красные Ключи	5	49	1460	92.774805000000001	92.796633999999997	56.930914999999999	56.922682999999999	0103000020E61000000100000005000000BFF1B567963157409FC9FE791A764C40BFF1B567963157408C2D043928774C406D382C0DFC3257408C2D043928774C406D382C0DFC3257409FC9FE791A764C40BFF1B567963157409FC9FE791A764C40
45644	Комарово	5	49	1460	93.288767000000007	93.309912999999995	56.903843000000002	56.89676	0103000020E61000000100000005000000804A95287B525740342E1C08C9724C40804A95287B525740F9DB9E20B1734C40BCE6559DD5535740F9DB9E20B1734C40BCE6559DD5535740342E1C08C9724C40804A95287B525740342E1C08C9724C40
49567	Казанка	5	49	1460	92.821894	92.838774000000001	57.033683000000003	57.024101999999999	0103000020E61000000100000005000000D5B14AE99934574054E23AC615834C40D5B14AE99934574031B77BB94F844C400CAF2479AE35574031B77BB94F844C400CAF2479AE35574054E23AC615834C40D5B14AE99934574054E23AC615834C40
46751	Еловка	5	49	1460	93.259615999999994	93.285075000000006	56.758028000000003	56.749402000000003	0103000020E610000001000000050000002C616D8C9D5057404CC79C67EC5F4C402C616D8C9D505740E5B9BE0F07614C40107A36AB3E525740E5B9BE0F07614C40107A36AB3E5257404CC79C67EC5F4C402C616D8C9D5057404CC79C67EC5F4C40
19701	Верх-Казанка	5	49	1460	92.776386000000002	92.797145999999998	57.053001000000002	57.044217000000003	0103000020E61000000100000005000000A0C4E74EB0315740B07614E7A8854C40A0C4E74EB0315740E1D39CBCC8864C40C808A87004335740E1D39CBCC8864C40C808A87004335740B07614E7A8854C40A0C4E74EB0315740B07614E7A8854C40
20463	Большой Кантат	5	49	1460	93.121167999999997	93.148261000000005	57.055472999999999	57.041401999999998	0103000020E6100000010000000500000097546D37C147574097FE25A94C854C4097546D37C1475740CF6740BD19874C406D91B41B7D495740CF6740BD19874C406D91B41B7D49574097FE25A94C854C4097546D37C147574097FE25A94C854C40
19273	Большая Мурта	5	49	1460	93.104737999999998	93.192413000000002	56.918536000000003	56.886243	0103000020E6100000010000000500000080290307B44657408BA71E6970714C4080290307B44657406E19709692754C40D1949D7E504C57406E19709692754C40D1949D7E504C57408BA71E6970714C4080290307B44657408BA71E6970714C40
59486	Большая Мурта	5	49	1460	93.104737999999998	93.192413000000002	56.918536000000003	56.886243	0103000020E6100000010000000500000080290307B44657408BA71E6970714C4080290307B44657406E19709692754C40D1949D7E504C57406E19709692754C40D1949D7E504C57408BA71E6970714C4080290307B44657408BA71E6970714C40
19149	Бартат	5	49	1460	93.126576	93.147219000000007	56.735470999999997	56.715103999999997	0103000020E61000000100000005000000581D39D219485740909E2287885B4C40581D39D2194857400514EAE9235E4C4064963D096C4957400514EAE9235E4C4064963D096C495740909E2287885B4C40581D39D219485740909E2287885B4C40
19468	Айтат	5	49	1460	92.974993999999995	92.993894999999995	57.015521999999997	57.004367999999999	0103000020E61000000100000005000000F5F23B4D663E5740109370218F804C40F5F23B4D663E57402B2FF99FFC814C401B2AC6F99B3F57402B2FF99FFC814C401B2AC6F99B3F5740109370218F804C40F5F23B4D663E5740109370218F804C40
59712	п. Хребтовый	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
59856	п. Беляки	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
59656	п. Ангарский	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
59845	Ярки	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
59672	Шиверский	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
18867	Чунояр	5	49	1558	97.298810000000003	97.348325000000003	57.45346	57.439672000000002	0103000020E61000000100000005000000F06DFAB31F535840C47B0E2C47B84C40F06DFAB31F535840A7052FFA0ABA4C4045D8F0F44A565840A7052FFA0ABA4C4045D8F0F44A565840C47B0E2C47B84C40F06DFAB31F535840C47B0E2C47B84C40
51758	Токучет	5	49	1558	96.691638999999995	96.712542999999997	57.621555999999998	57.613767000000003	0103000020E61000000100000005000000D76839D0432C5840992EC4EA8FCE4C40D76839D0432C5840F850A2258FCF4C40997FF44D9A2D5840F850A2258FCF4C40997FF44D9A2D5840992EC4EA8FCE4C40D76839D0432C5840992EC4EA8FCE4C40
59621	Село Богучаны	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
49421	Прилуки	5	49	1558	95.717883	95.739326000000005	57.752093000000002	57.747020999999997	0103000020E61000000100000005000000AED689CBF1ED57406D3656629EDF4C40AED689CBF1ED574078465B9544E04C4048C5FF1D51EF574078465B9544E04C4048C5FF1D51EF57406D3656629EDF4C40AED689CBF1ED57406D3656629EDF4C40
59826	Пинчуга	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
32714	Осиновый Мыс	5	49	1558	96.894191000000006	96.929522000000006	57.574711000000001	57.560316999999998	0103000020E610000001000000050000002A58E36C3A3958404832AB77B8C74C402A58E36C3A39584063D34A2190C94C4067BAD7497D3B584063D34A2190C94C4067BAD7497D3B58404832AB77B8C74C402A58E36C3A3958404832AB77B8C74C40
49301	Октябрьский	5	49	1558	97.500168000000002	97.570874000000003	57.453606000000001	57.433897000000002	0103000020E610000001000000050000005EA0A4C002605840906AD8EF89B74C405EA0A4C0026058407BA2EBC20FBA4C40C0081A33896458407BA2EBC20FBA4C40C0081A3389645840906AD8EF89B74C405EA0A4C002605840906AD8EF89B74C40
18719	Новохайский	5	49	1558	97.412042999999997	97.443788999999995	57.762574999999998	57.74765	0103000020E61000000100000005000000ED629AE95E5A58405D6DC5FEB2DF4C40ED629AE95E5A5840A4DFBE0E9CE14C40C554FA09675C5840A4DFBE0E9CE14C40C554FA09675C58405D6DC5FEB2DF4C40ED629AE95E5A58405D6DC5FEB2DF4C40
60034	Нижнетерянск	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
49315	Малеево	5	49	1558	97.522256999999996	97.548289999999994	57.432735000000001	57.428455999999997	0103000020E61000000100000005000000DAC69FA86C61584032E36DA5D7B64C40DAC69FA86C615840D36A48DC63B74C4053AEF02E17635840D36A48DC63B74C4053AEF02E1763584032E36DA5D7B64C40DAC69FA86C61584032E36DA5D7B64C40
18647	Кежек	5	49	1558	97.775662999999994	97.789434	57.822701000000002	57.816018999999997	0103000020E61000000100000005000000E76D6C76A471584012F5824F73E84C40E76D6C76A471584079B130444EE94C406E162F168672584079B130444EE94C406E162F168672584012F5824F73E84C40E76D6C76A471584012F5824F73E84C40
59870	Карабула	5	49	1558	97.458305999999993	97.688588999999993	58.000593000000002	57.856495000000002	0103000020E61000000100000005000000E063B0E2545D58400118CFA0A1ED4C40E063B0E2545D5840A3CD716E13004D40A9D898D7116C5840A3CD716E13004D40A9D898D7116C58400118CFA0A1ED4C40E063B0E2545D58400118CFA0A1ED4C40
59841	Иркинеево	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
59822	Бедоба	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
59676	Артюгино	5	49	1558	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
51752	д.Коробейниково	5	49	1396	89.995058	90.019591000000005	56.381937999999998	56.371724999999998	0103000020E61000000100000005000000E2E7BF07AF7F5640840D4FAF942F4C40E2E7BF07AF7F5640C18C2958E3304C40F1129CFA40815640C18C2958E3304C40F1129CFA40815640840D4FAF942F4C40E2E7BF07AF7F5640840D4FAF942F4C40
20374	Юрьевка	5	49	1396	89.288497000000007	89.352062000000004	56.321460999999999	56.307087000000003	0103000020E61000000100000005000000A0FF1EBC765256406D0377A04E274C40A0FF1EBC7652564040F850A225294C40850A0E2F8856564040F850A225294C40850A0E2F885656406D0377A04E274C40A0FF1EBC765256406D0377A04E274C40
32756	Шулдат	5	49	1396	89.586010000000002	89.604146999999998	56.387639	56.379022999999997	0103000020E61000000100000005000000414816308165564045B75ED383304C404148163081655640BBD39D279E314C407FBE2D58AA665640BBD39D279E314C407FBE2D58AA66564045B75ED383304C40414816308165564045B75ED383304C40
16990	Чайковский	5	49	1396	89.607489000000001	89.634016000000003	56.357574	56.346367000000001	0103000020E6100000010000000500000081EB8A19E1665640F2B4FCC0552C4C4081EB8A19E166564030F31DFCC42D4C400249D8B79368564030F31DFCC42D4C400249D8B793685640F2B4FCC0552C4C4081EB8A19E1665640F2B4FCC0552C4C40
40279	Село Медяково	5	49	1396	89.639612	89.664351999999994	56.287742000000001	56.280177000000002	0103000020E6100000010000000500000044882B67EF685640B30B06D7DC234C4044882B67EF685640C3D7D7BAD4244C400F4240BE846A5640C3D7D7BAD4244C400F4240BE846A5640B30B06D7DC234C4044882B67EF685640B30B06D7DC234C40
32735	Разгуляевка	5	49	1396	89.829660000000004	89.859071	56.275064	56.266362000000001	0103000020E6100000010000000500000029B3412619755640D672672618224C4029B34126197556404A27124C35234C404A7CEE04FB7656404A27124C35234C404A7CEE04FB765640D672672618224C4029B3412619755640D672672618224C40
19558	Орга	5	49	1396	89.768609999999995	89.788176000000007	56.155999000000001	56.147148999999999	0103000020E610000001000000050000003A58FFE730715640CE5147C7D5124C403A58FFE730715640B79A75C6F7134C407FDFBF7971725640B79A75C6F7134C407FDFBF7971725640CE5147C7D5124C403A58FFE730715640CE5147C7D5124C40
19635	Малая Косуль	5	49	1396	89.334076999999994	89.351665999999994	56.088543999999999	56.079864000000001	0103000020E6100000010000000500000021567F84615556405A10CAFB380A4C4021567F8461555640E620E868550B4C405E471CB281565640E620E868550B4C405E471CB2815656405A10CAFB380A4C4021567F84615556405A10CAFB380A4C40
32773	Лебедевка	5	49	1396	89.242180000000005	89.261358999999999	56.282001000000001	56.266621999999998	0103000020E61000000100000005000000B3EF8AE07F4F5640723271AB20224C40B3EF8AE07F4F56403B38D89B18244C40FA60191BBA5056403B38D89B18244C40FA60191BBA505640723271AB20224C40B3EF8AE07F4F5640723271AB20224C40
20149	Критово	5	49	1396	89.986569000000003	90.026579999999996	56.248345999999998	56.233843999999998	0103000020E61000000100000005000000D68F4DF2237F5640D32EA699EE1D4C40D68F4DF2237F5640D40B3ECDC91F4C4092AE997CB3815640D40B3ECDC91F4C4092AE997CB3815640D32EA699EE1D4C40D68F4DF2237F5640D32EA699EE1D4C40
20002	Красный Завод	5	49	1396	90.010696999999993	90.045471000000006	56.196572000000003	56.171166999999997	0103000020E61000000100000005000000944A7842AF805640C493DDCCE8154C40944A7842AF80564098A7734529194C40A77A32FFE882564098A7734529194C40A77A32FFE8825640C493DDCCE8154C40944A7842AF805640C493DDCCE8154C40
20097	Красная Речка	5	49	1396	90.040296999999995	90.074854999999999	56.234340000000003	56.223650999999997	0103000020E610000001000000050000001F48DE3994825640DD5B9198A01C4C401F48DE3994825640841266DAFE1D4C404B3CA06CCA845640841266DAFE1D4C404B3CA06CCA845640DD5B9198A01C4C401F48DE3994825640DD5B9198A01C4C40
16594	Каштан	5	49	1396	89.239780999999994	89.260262999999995	56.124029999999998	56.110785999999997	0103000020E61000000100000005000000F04C6892584F5640656D533C2E0E4C40F04C6892584F564087DC0C37E00F4C40F7562426A850564087DC0C37E00F4C40F7562426A8505640656D533C2E0E4C40F04C6892584F5640656D533C2E0E4C40
51735	Ильинка	5	49	1396	89.786370000000005	89.816850000000002	56.372976000000001	56.358905999999998	0103000020E610000001000000050000008E23D6E253725640492BBEA1F02D4C408E23D6E253725640B11875ADBD2F4C4035EF384547745640B11875ADBD2F4C4035EF384547745640492BBEA1F02D4C408E23D6E253725640492BBEA1F02D4C40
51780	Дмитриевка	5	49	1396	89.895228000000003	89.927809999999994	56.393403999999997	56.385651000000003	0103000020E61000000100000005000000AA9D616A4B795640B95510035D314C40AA9D616A4B795640CB0EF10F5B324C40B6B9313D617B5640CB0EF10F5B324C40B6B9313D617B5640B95510035D314C40AA9D616A4B795640B95510035D314C40
33054	Гнетово	5	49	1396	89.875698999999997	89.897689	56.288685999999998	56.278002999999998	0103000020E61000000100000005000000F488D1730B7856404E98309A95234C40F488D1730B7856401268B0A9F3244C40A73E90BC737956401268B0A9F3244C40A73E90BC737956404E98309A95234C40F488D1730B7856404E98309A95234C40
32762	Георгиевка	5	49	1396	89.330089000000001	89.356399999999994	56.399537000000002	56.387565000000002	0103000020E610000001000000050000003DF19C2D205556408109DCBA9B314C403DF19C2D205556405F45460724334C40D712F241CF5656405F45460724334C40D712F241CF5656408109DCBA9B314C403DF19C2D205556408109DCBA9B314C40
32635	Владимировка	5	49	1396	89.830629999999999	89.857939000000002	56.176409	56.160155000000003	0103000020E61000000100000005000000E544BB0A297556403CA583F57F144C40E544BB0A297556402BDCF29194164C40A1BDFA78E87656402BDCF29194164C40A1BDFA78E87656403CA583F57F144C40E544BB0A297556403CA583F57F144C40
33002	Вишняково-Катеюл	5	49	1396	89.453795999999997	89.464899000000003	56.311756000000003	56.302757	0103000020E610000001000000050000008FC360FE0A5D56404AD1CABDC0264C408FC360FE0A5D5640782AE09EE7274C405C3CBCE7C05D5640782AE09EE7274C405C3CBCE7C05D56404AD1CABDC0264C408FC360FE0A5D56404AD1CABDC0264C40
19709	Вагино	5	49	1396	89.792936999999995	89.834564999999998	56.363712999999997	56.337859999999999	0103000020E6100000010000000500000074B2D47ABF725640335019FF3E2B4C4074B2D47ABF725640A510C8258E2E4C40B858518369755640A510C8258E2E4C40B858518369755640335019FF3E2B4C4074B2D47ABF725640335019FF3E2B4C40
33125	Булатово	5	49	1396	89.634079	89.667181999999997	56.426079000000001	56.413896000000001	0103000020E61000000100000005000000250516C094685640FDF84B8BFA344C40250516C0946856409641B5C189364C40B69E211CB36A56409641B5C189364C40B69E211CB36A5640FDF84B8BFA344C40250516C094685640FDF84B8BFA344C40
19600	Большая Косуль	5	49	1396	89.326226000000005	89.373001000000002	56.141257000000003	56.124682	0103000020E61000000100000005000000B74604E3E05456402F336C94F50F4C40B74604E3E054564061AA99B514124C400518963FDF57564061AA99B514124C400518963FDF5756402F336C94F50F4C40B74604E3E05456402F336C94F50F4C40
16488	Боготол	5	49	1396	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
51747	Берёзовка	5	49	1396	89.193769000000003	89.223332999999997	56.396622999999998	56.382890000000003	0103000020E61000000100000005000000A27E17B6664C564094FB1D8A02314C40A27E17B6664C5640B3EBDE8AC4324C4086C77E164B4E5640B3EBDE8AC4324C4086C77E164B4E564094FB1D8A02314C40A27E17B6664C564094FB1D8A02314C40
51801	Александровка	5	49	1396	89.327672000000007	89.350911999999994	56.018417999999997	56.002918000000001	0103000020E6100000010000000500000028F4FA93F8545640ED48F59D5F004C4028F4FA93F854564030D461855B024C4088F19A577556564030D461855B024C4088F19A5775565640ED48F59D5F004C4028F4FA93F8545640ED48F59D5F004C40
59892	Боготол	5	49	7494	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
59882	Боготол	5	49	7494	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
15533	Шпагино-1	5	49	1352	90.618938	90.626277000000002	57.214252999999999	57.209764	0103000020E610000001000000050000001B1021AE9CA7564067F0F78BD99A4C401B1021AE9CA75640F2086EA46C9B4C402B4F20EC14A85640F2086EA46C9B4C402B4F20EC14A8564067F0F78BD99A4C401B1021AE9CA7564067F0F78BD99A4C40
32917	Сурикова	5	49	1352	91.389126000000005	91.407415999999998	56.990341000000001	56.976112999999998	0103000020E610000001000000050000007E01BD70E7D85640A8195245F17C4C407E01BD70E7D85640A8716F7EC37E4C407FF78E1A13DA5640A8716F7EC37E4C407FF78E1A13DA5640A8195245F17C4C407E01BD70E7D85640A8195245F17C4C40
14607	Старая Еловка	5	49	1352	90.658535000000001	90.671750000000003	56.902515999999999	56.884320000000002	0103000020E610000001000000050000005E11FC6F25AA56407099D36531714C405E11FC6F25AA5640F10EF0A485734C40A245B6F3FDAA5640F10EF0A485734C40A245B6F3FDAA56407099D36531714C405E11FC6F25AA56407099D36531714C40
17552	Сопка	5	49	1352	90.060006000000001	90.074972000000002	57.472147	57.466299999999997	0103000020E6100000010000000500000015E46723D7835640F90FE9B7AFBB4C4015E46723D7835640C7F319506FBC4C4068075C57CC845640C7F319506FBC4C4068075C57CC845640F90FE9B7AFBB4C4015E46723D7835640F90FE9B7AFBB4C40
14806	Сахарное	5	49	1352	90.288870000000003	90.299684999999997	56.810192000000001	56.799641000000001	0103000020E61000000100000005000000EAB298D87C92564037C5E3A25A664C40EAB298D87C9256408CBD175FB4674C408386FE092E9356408CBD175FB4674C408386FE092E93564037C5E3A25A664C40EAB298D87C92564037C5E3A25A664C40
48055	Рассвет	5	49	1352	91.455466999999999	91.488569999999996	57.009210000000003	56.993043	0103000020E61000000100000005000000105A0F5F26DD5640C84274081C7F4C40105A0F5F26DD5640E96514CB2D814C40A1F31ABB44DF5640E96514CB2D814C40A1F31ABB44DF5640C84274081C7F4C40105A0F5F26DD5640C84274081C7F4C40
15624	Промбор	5	49	1352	90.398491000000007	90.411974999999998	57.333243000000003	57.325304000000003	0103000020E61000000100000005000000063065E08099564006A1BC8FA3A94C40063065E0809956407B4FE5B4A7AA4C4041F163CC5D9A56407B4FE5B4A7AA4C4041F163CC5D9A564006A1BC8FA3A94C40063065E08099564006A1BC8FA3A94C40
48238	Полевое	5	49	1352	90.521739999999994	90.545815000000005	57.354816999999997	57.341084000000002	0103000020E61000000100000005000000F6402B3064A156402D98F8A3A8AB4C40F6402B3064A156404C88B9A46AAD4C40A4AA09A2EEA256404C88B9A46AAD4C40A4AA09A2EEA256402D98F8A3A8AB4C40F6402B3064A156402D98F8A3A8AB4C40
14505	Новобирилюссы	5	49	1352	90.662137999999999	90.702085999999994	56.970244999999998	56.930197999999997	0103000020E6100000010000000500000016DC0F7860AA5640FD6662BA10774C4016DC0F7860AA5640C30DF8FC307C4C40AF3E1EFAEEAC5640C30DF8FC307C4C40AF3E1EFAEEAC5640FD6662BA10774C4016DC0F7860AA5640FD6662BA10774C40
15699	Нижний Тунуй	5	49	1352	90.341025999999999	90.357006999999996	57.104356000000003	57.096822000000003	0103000020E610000001000000050000007C45B75ED395564044C4CDA9648C4C407C45B75ED3955640199293895B8D4C405B5CE333D9965640199293895B8D4C405B5CE333D996564044C4CDA9648C4C407C45B75ED395564044C4CDA9648C4C40
15795	Муслинка	5	49	1352	90.228134999999995	90.242695999999995	57.170219000000003	57.160823999999998	0103000020E61000000100000005000000AB048BC3998E5640B9347EE195944C40AB048BC3998E5640341477BCC9954C40AEB7CD54888F5640341477BCC9954C40AEB7CD54888F5640B9347EE195944C40AB048BC3998E5640B9347EE195944C40
15245	Мендельский	5	49	1352	91.472463000000005	91.484977000000001	57.102454000000002	57.092298999999997	0103000020E610000001000000050000007C6473D53CDE56400C3A2174D08B4C407C6473D53CDE564015AC71361D8D4C40FB93F8DC09DF564015AC71361D8D4C40FB93F8DC09DF56400C3A2174D08B4C407C6473D53CDE56400C3A2174D08B4C40
15389	Маталассы	5	49	1352	90.862435000000005	90.891154	57.158510999999997	57.145988000000003	0103000020E6100000010000000500000040FB912232B75640E2CD1ABCAF924C4040FB912232B756403387A4164A944C40C66CC9AA08B956403387A4164A944C40C66CC9AA08B95640E2CD1ABCAF924C4040FB912232B75640E2CD1ABCAF924C40
15326	Малая Кеть	5	49	1352	91.649322999999995	91.669534999999996	57.333666000000001	57.321610999999997	0103000020E6100000010000000500000099620E828EE9564055849B8C2AA94C4099620E828EE95640C1E44691B5AA4C40C02154A9D9EA5640C1E44691B5AA4C40C02154A9D9EA564055849B8C2AA94C4099620E828EE9564055849B8C2AA94C40
15747	Кирчиж	5	49	1352	90.194906000000003	90.208191999999997	57.143487999999998	57.129762999999997	0103000020E61000000100000005000000D4F20357798C56408C9DF0129C904C40D4F20357798C564029AF95D05D924C407CD28904538D564029AF95D05D924C407CD28904538D56408C9DF0129C904C40D4F20357798C56408C9DF0129C904C40
15235	Кемчуг	5	49	1352	91.461125999999993	91.482613999999998	57.026345999999997	57.019119000000003	0103000020E610000001000000050000007555A01683DD5640BADDCB7D72824C407555A01683DD5640B130444E5F834C40DFA5D425E3DE5640B130444E5F834C40DFA5D425E3DE5640BADDCB7D72824C407555A01683DD5640BADDCB7D72824C40
14760	Зачулымка	5	49	1352	90.446325999999999	90.466151999999994	56.895167000000001	56.884354999999999	0103000020E61000000100000005000000B056ED9A909C5640EC866D8B32714C40B056ED9A909C5640AEBA0ED594724C40C2BD326FD59D5640AEBA0ED594724C40C2BD326FD59D5640EC866D8B32714C40B056ED9A909C5640EC866D8B32714C40
14673	Дорохта	5	49	1352	90.561688000000004	90.572907999999998	57.148463999999997	57.141314999999999	0103000020E6100000010000000500000090A339B2F2A3564095B7239C16924C4090A339B2F2A3564011514CDE00934C4079E75086AAA4564011514CDE00934C4079E75086AAA4564095B7239C16924C4090A339B2F2A3564095B7239C16924C40
51875	Бор	5	49	1352	89.939344000000006	89.945659000000006	57.493924	57.485478000000001	0103000020E6100000010000000500000068EC4B361E7C5640B876A22424BE4C4068EC4B361E7C5640D15AD1E638BF4C40C28A53AD857C5640D15AD1E638BF4C40C28A53AD857C5640B876A22424BE4C4068EC4B361E7C5640B876A22424BE4C40
15829	Биктимировка	5	49	1352	90.227442999999994	90.242075999999997	57.204957	57.194834999999998	0103000020E6100000010000000500000010AD156D8E8E5640DE8E705AF0984C4010AD156D8E8E56400B0BEE073C9A4C4060C9552C7E8F56400B0BEE073C9A4C4060C9552C7E8F5640DE8E705AF0984C4010AD156D8E8E5640DE8E705AF0984C40
47863	Арефьево	5	49	1352	90.666889999999995	90.685205999999994	57.040643000000003	57.010342000000001	0103000020E61000000100000005000000E2016553AEAA56403BE3FBE252814C40E2016553AEAA5640DAE731CA33854C407841446ADAAB5640DAE731CA33854C407841446ADAAB56403BE3FBE252814C40E2016553AEAA56403BE3FBE252814C40
51773	Александровка	5	49	1352	90.225395000000006	90.232815000000002	57.112045000000002	57.102879999999999	0103000020E61000000100000005000000A56B26DF6C8E5640CCB4FD2B2B8D4C40A56B26DF6C8E56401557957D578E4C402BC1E270E68E56401557957D578E4C402BC1E270E68E5640CCB4FD2B2B8D4C40A56B26DF6C8E5640CCB4FD2B2B8D4C40
14355	Урман	5	49	493	92.973521000000005	92.991136999999995	55.557628000000001	55.546143999999998	0103000020E61000000100000005000000083E062B4E3E57400C74ED0BE8C54B40083E062B4E3E5740BDAAB35A60C74B40C136E2C96E3F5740BDAAB35A60C74B40C136E2C96E3F57400C74ED0BE8C54B40083E062B4E3E57400C74ED0BE8C54B40
6148	Тартат	5	49	493	93.351730000000003	93.383970000000005	56.175462000000003	56.157724000000002	0103000020E610000001000000050000006AC18BBE82565740ACE5CE4C30144C406AC18BBE825657406BD8EF8975164C404A29E8F6925857406BD8EF8975164C404A29E8F692585740ACE5CE4C30144C406AC18BBE82565740ACE5CE4C30144C40
14037	Маганск	5	49	493	93.243267000000003	93.272120999999999	55.875577	55.854522000000003	0103000020E610000001000000050000008C4CC0AF914F574034DB15FA60ED4B408C4CC0AF914F57409D103AE812F04B4082E3326E6A5157409D103AE812F04B4082E3326E6A51574034DB15FA60ED4B408C4CC0AF914F574034DB15FA60ED4B40
59703	Лукино	5	49	493	92.230892999999995	94.071692999999996	56.374696	55.229897000000001	0103000020E6100000010000000500000005F86EF3C60E57406939D0436D9D4B4005F86EF3C60E574094F8DC09F62F4C4089963C9E9684574094F8DC09F62F4C4089963C9E968457406939D0436D9D4B4005F86EF3C60E57406939D0436D9D4B40
59735	Калиновка	5	49	493	93.396069999999995	93.443987000000007	56.200293000000002	56.170555999999998	0103000020E610000001000000050000004F3BFC35595957407B116DC7D4154C404F3BFC3559595740124F7633A3194C40593673486A5C5740124F7633A3194C40593673486A5C57407B116DC7D4154C404F3BFC35595957407B116DC7D4154C40
51809	Жержул	5	49	493	93.290626000000003	93.300319000000002	55.405802000000001	55.394351	0103000020E610000001000000050000008257CB9D995257408C12F4177AB24B408257CB9D995257406153E751F1B34B4084D72E6D385357406153E751F1B34B4084D72E6D385357408C12F4177AB24B408257CB9D995257408C12F4177AB24B40
2945	Железногорск	5	49	493	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
14174	Верхняя Базаиха	5	49	493	93.369202000000001	93.397328000000002	55.697721000000001	55.683670999999997	0103000020E610000001000000050000008AE76C01A15757409F1C058882D74B408AE76C01A1575740C05DF6EB4ED94B403F726BD26D595740C05DF6EB4ED94B403F726BD26D5957409F1C058882D74B408AE76C01A15757409F1C058882D74B40
14267	Береть	5	49	493	92.991505000000004	93.012589000000006	55.693916000000002	55.686025999999998	0103000020E61000000100000005000000833463D1743F5740541A31B3CFD74B40833463D1743F5740E8154F3DD2D84B4085D21742CE405740E8154F3DD2D84B4085D21742CE405740541A31B3CFD74B40833463D1743F5740541A31B3CFD74B40
14130	Березовский	5	49	493	93.270109000000005	93.298522000000006	55.816465000000001	55.796542000000002	0103000020E61000000100000005000000BD56427749515740FAF19716F5E54B40BD5642774951574011AAD4EC81E84B40BDC804FC1A53574011AAD4EC81E84B40BDC804FC1A535740FAF19716F5E54B40BD56427749515740FAF19716F5E54B40
59481	Березовка	5	49	493	92.230892999999995	94.071692999999996	56.374696	55.229897000000001	0103000020E6100000010000000500000005F86EF3C60E57406939D0436D9D4B4005F86EF3C60E574094F8DC09F62F4C4089963C9E9684574094F8DC09F62F4C4089963C9E968457406939D0436D9D4B4005F86EF3C60E57406939D0436D9D4B40
59785	д.Малая Тумна	5	49	465	91.728384000000005	91.741230000000002	55.329692000000001	55.318885000000002	0103000020E6100000010000000500000080BBECD79DEE5640AD174339D1A84B4080BBECD79DEE56405DE0F25833AA4B401A34F44F70EF56405DE0F25833AA4B401A34F44F70EF5640AD174339D1A84B4080BBECD79DEE5640AD174339D1A84B40
59773	Ямская	5	49	465	91.620469	91.635220000000004	55.236077999999999	55.230528	0103000020E61000000100000005000000A3CB9BC3B5E75640F96706F1819D4B40A3CB9BC3B5E756400DA7CCCD379E4B40F870C971A7E856400DA7CCCD379E4B40F870C971A7E85640F96706F1819D4B40A3CB9BC3B5E75640F96706F1819D4B40
59713	Якушево	5	49	465	91.048817	91.066595000000007	55.195385000000002	55.187676000000003	0103000020E61000000100000005000000499F56D11FC356403F1F65C405984B40499F56D11FC3564082902C6002994B40F0C4AC1743C4564082902C6002994B40F0C4AC1743C456403F1F65C405984B40499F56D11FC356403F1F65C405984B40
47249	Черемушки	5	49	465	92.162808999999996	92.199325999999999	55.187260000000002	55.167713999999997	0103000020E61000000100000005000000A59F70766B0A5740698A00A777954B40A59F70766B0A5740ABECBB22F8974B4085CFD6C1C10C5740ABECBB22F8974B4085CFD6C1C10C5740698A00A777954B40A59F70766B0A5740698A00A777954B40
46821	Холодный Ключ	5	49	465	91.031201999999993	91.041020000000003	55.504894	55.497622999999997	0103000020E610000001000000050000007764AC36FFC15640635E471CB2BF4B407764AC36FFC156402BF9D85DA0C04B40D89E5912A0C256402BF9D85DA0C04B40D89E5912A0C25640635E471CB2BF4B407764AC36FFC15640635E471CB2BF4B40
12152	Угольный	5	49	465	91.329702999999995	91.353426999999996	55.380916999999997	55.369382000000002	0103000020E6100000010000000500000028999CDA19D5564094DDCCE847AF4B4028999CDA19D55640C6BE64E3C1B04B407FA1478C9ED65640C6BE64E3C1B04B407FA1478C9ED6564094DDCCE847AF4B4028999CDA19D5564094DDCCE847AF4B40
11794	Тюльково	5	49	465	91.217484999999996	91.281741999999994	55.362608000000002	55.352552000000003	0103000020E61000000100000005000000B7973446EBCD5640D811876C20AD4B40B7973446EBCD56404DA25EF069AE4B4037FA980F08D256404DA25EF069AE4B4037FA980F08D25640D811876C20AD4B40B7973446EBCD5640D811876C20AD4B40
12012	Трясучая	5	49	465	91.373154	91.388102000000003	55.563533	55.554858000000003	0103000020E61000000100000005000000C89750C1E1D7564045F6419605C74B40C89750C1E1D75640BF9B6ED921C84B40C860C5A9D6D85640BF9B6ED921C84B40C860C5A9D6D8564045F6419605C74B40C89750C1E1D7564045F6419605C74B40
12301	Тойлук	5	49	465	91.145296999999999	91.155196000000004	55.475285999999997	55.468009000000002	0103000020E610000001000000050000003ECDC98B4CC95640E99D0AB8E7BB4B403ECDC98B4CC95640921FF12BD6BC4B40151E34BBEEC95640921FF12BD6BC4B40151E34BBEEC95640E99D0AB8E7BB4B403ECDC98B4CC95640E99D0AB8E7BB4B40
33118	Ровное	5	49	465	91.112561999999997	91.128776999999999	55.517581999999997	55.502865	0103000020E610000001000000050000006E313F3734C75640CAA65CE15DC04B406E313F3734C75640C77F812040C24B4087DEE2E13DC85640C77F812040C24B4087DEE2E13DC85640CAA65CE15DC04B406E313F3734C75640CAA65CE15DC04B40
47093	Приморск	5	49	465	91.878788999999998	91.909610000000001	55.209935000000002	55.197518000000002	0103000020E6100000010000000500000069C537143EF85640882F134548994B4069C537143EF8564094A46B26DF9A4B405587DC0C37FA564094A46B26DF9A4B405587DC0C37FA5640882F134548994B4069C537143EF85640882F134548994B40
23471	Огур	5	49	465	91.849170999999998	91.887906999999998	55.362188000000003	55.349798	0103000020E610000001000000050000008B6D52D158F65640651A4D2EC6AC4B408B6D52D158F656407880272D5CAE4B40EDB8E177D3F856407880272D5CAE4B40EDB8E177D3F85640651A4D2EC6AC4B408B6D52D158F65640651A4D2EC6AC4B40
12717	Могучий	5	49	465	90.828064999999995	90.853720999999993	55.267907000000001	55.255015	0103000020E61000000100000005000000957D5704FFB45640A67EDE54A4A04B40957D5704FFB456404BAFCDC64AA24B4023BA675DA3B656404BAFCDC64AA24B4023BA675DA3B65640A67EDE54A4A04B40957D5704FFB45640A67EDE54A4A04B40
26797	Малая Тумна (Епишино)	5	49	465	91.728384000000005	91.741230000000002	55.329692000000001	55.318885000000002	0103000020E6100000010000000500000080BBECD79DEE5640AD174339D1A84B4080BBECD79DEE56405DE0F25833AA4B401A34F44F70EF56405DE0F25833AA4B401A34F44F70EF5640AD174339D1A84B4080BBECD79DEE5640AD174339D1A84B40
51787	Курбатово	5	49	465	91.146778999999995	91.176809000000006	55.581698000000003	55.576177000000001	0103000020E61000000100000005000000552FBFD364C956408CDAFD2AC0C94B40552FBFD364C9564006137F1475CA4B40DD28B2D650CB564006137F1475CA4B40DD28B2D650CB56408CDAFD2AC0C94B40552FBFD364C956408CDAFD2AC0C94B40
46691	Крюково	5	49	465	91.030006999999998	91.047201000000001	55.360791999999996	55.357275999999999	0103000020E61000000100000005000000ABE97AA2EBC15640A6D24F38BBAD4B40ABE97AA2EBC156404754A86E2EAE4B40AAD5575705C356404754A86E2EAE4B40AAD5575705C35640A6D24F38BBAD4B40ABE97AA2EBC15640A6D24F38BBAD4B40
59793	Красный Ключ	5	49	465	91.952038000000002	91.976382000000001	55.452921000000003	55.440345000000001	0103000020E6100000010000000500000027A3CA30EEFC564083FA96395DB84B4027A3CA30EEFC5640F855B950F9B94B40CC99ED0A7DFE5640F855B950F9B94B40CC99ED0A7DFE564083FA96395DB84B4027A3CA30EEFC564083FA96395DB84B40
59794	Красная	5	49	465	91.670361999999997	91.702332999999996	55.314602000000001	55.300721000000003	0103000020E61000000100000005000000CB9E0436E7EA5640371C96067EA64B40CB9E0436E7EA5640CBA0DAE044A84B40B3791C06F3EC5640CBA0DAE044A84B40B3791C06F3EC5640371C96067EA64B40CB9E0436E7EA5640371C96067EA64B40
46724	Кожаны	5	49	465	91.079639	91.096301999999994	55.365682999999997	55.351579000000001	0103000020E610000001000000050000001D1F2DCE18C55640EE7A698A00AD4B401D1F2DCE18C5564001DA56B3CEAE4B408522DDCF29C6564001DA56B3CEAE4B408522DDCF29C65640EE7A698A00AD4B401D1F2DCE18C55640EE7A698A00AD4B40
46690	Ключи	5	49	465	91.140022999999999	91.157621000000006	55.358786000000002	55.347607000000004	0103000020E61000000100000005000000056C0723F6C856402B6EDC627EAC4B40056C0723F6C856409F211CB3ECAD4B406C0A647616CA56409F211CB3ECAD4B406C0A647616CA56402B6EDC627EAC4B40056C0723F6C856402B6EDC627EAC4B40
12491	Ильтюково	5	49	465	91.094048000000001	91.104135999999997	55.21651	55.209128999999997	0103000020E610000001000000050000004510E7E104C6564095D233BDC49A4B404510E7E104C65640E4A08499B69B4B4085950A2AAAC65640E4A08499B69B4B4085950A2AAAC6564095D233BDC49A4B404510E7E104C6564095D233BDC49A4B40
59830	Ижульское	5	49	465	91.677018000000004	91.689010999999994	55.196731	55.189573000000003	0103000020E610000001000000050000006A334E4354EB5640319A95ED43984B406A334E4354EB5640008E3D7B2E994B4064E597C118EC5640008E3D7B2E994B4064E597C118EC5640319A95ED43984B406A334E4354EB5640319A95ED43984B40
51826	Жеблахты	5	49	465	90.607896999999994	93.288595999999998	55.771296999999997	54.763399	0103000020E610000001000000050000008995D1C8E7A656404966F50EB7614B408995D1C8E7A656405F402FDCB9E24B4069705B5B785257405F402FDCB9E24B4069705B5B785257404966F50EB7614B408995D1C8E7A656404966F50EB7614B40
12816	Даурское	5	49	465	91.960221000000004	91.978887999999998	55.228408000000002	55.220258999999999	0103000020E61000000100000005000000ADFBC74274FD564028D36872319C4B40ADFBC74274FD564088122D793C9D4B40999CDA19A6FE564088122D793C9D4B40999CDA19A6FE564028D36872319C4B40ADFBC74274FD564028D36872319C4B40
12386	Грузенка	5	49	465	90.951340999999999	90.969451000000007	55.486345999999998	55.472555999999997	0103000020E6100000010000000500000003965CC5E2BC5640A8C30AB77CBC4B4003965CC5E2BC56402C45F29540BE4B40C504357C0BBE56402C45F29540BE4B40C504357C0BBE5640A8C30AB77CBC4B4003965CC5E2BC5640A8C30AB77CBC4B40
46792	Гладкий Мыс	5	49	465	91.255026000000001	91.2761	55.490253000000003	55.482194	0103000020E610000001000000050000004D68925852D05640E9297288B8BD4B404D68925852D0564009E23C9CC0BE4B403D9B559FABD1564009E23C9CC0BE4B403D9B559FABD15640E9297288B8BD4B404D68925852D05640E9297288B8BD4B40
46992	Вольный	5	49	465	91.036276999999998	91.044353000000001	55.271734000000002	55.267333000000001	0103000020E610000001000000050000003526C45C52C256401F12BEF737A24B403526C45C52C256400B9B012EC8A24B40B01EF7ADD6C256400B9B012EC8A24B40B01EF7ADD6C256401F12BEF737A24B403526C45C52C256401F12BEF737A24B40
13101	Виленка	5	49	465	91.559734000000006	91.578770000000006	55.605311999999998	55.594915999999998	0103000020E61000000100000005000000651D8EAED2E35640FEEE1D3526CC4B40651D8EAED2E356402CF015DD7ACD4B40FB7953910AE556402CF015DD7ACD4B40FB7953910AE55640FEEE1D3526CC4B40651D8EAED2E35640FEEE1D3526CC4B40
13059	Большие Сыры	5	49	465	91.539000999999999	91.560784999999996	55.521566999999997	55.510843000000001	0103000020E61000000100000005000000B9E00CFE7EE25640FD31AD4D63C14B40B9E00CFE7EE256401FD61BB5C2C24B4097C5C4E6E3E356401FD61BB5C2C24B4097C5C4E6E3E35640FD31AD4D63C14B40B9E00CFE7EE25640FD31AD4D63C14B40
11743	Безъязыково	5	49	465	91.492054999999993	91.512618000000003	55.291131	55.284030000000001	0103000020E61000000100000005000000543541D47DDF56409C8A54185BA44B40543541D47DDF564007EDD5C743A54B40D255BABBCEE0564007EDD5C743A54B40D255BABBCEE056409C8A54185BA44B40543541D47DDF56409C8A54185BA44B40
12429	Балдаштык	5	49	465	90.989106000000007	90.996554000000003	55.409078999999998	55.401814999999999	0103000020E61000000100000005000000C19140834DBF5640680586AC6EB34B40C19140834DBF56407D3D5FB35CB44B40ACAC6D8AC7BF56407D3D5FB35CB44B40ACAC6D8AC7BF5640680586AC6EB34B40C19140834DBF5640680586AC6EB34B40
59477	Балахта	5	49	465	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
11245	Балахта	5	49	465	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
10996	Ястребово	5	49	1133	90.660673000000003	90.683886000000001	56.143453999999998	56.131189999999997	0103000020E610000001000000050000006A16687748AA5640F7C77BD5CA104C406A16687748AA56407D3D5FB35C124C404E0CC9C9C4AB56407D3D5FB35C124C404E0CC9C9C4AB5640F7C77BD5CA104C406A16687748AA5640F7C77BD5CA104C40
10673	Тимонино	5	49	1133	90.723833999999997	90.769638999999998	56.403945	56.395561999999998	0103000020E61000000100000005000000E76ED74B53AE56402AC58EC6A1324C40E76ED74B53AE5640FD304278B4334C4079AEEFC341B15640FD304278B4334C4079AEEFC341B156402AC58EC6A1324C40E76ED74B53AE56402AC58EC6A1324C40
10852	Тарутино	5	49	1133	90.812965000000005	90.859380999999999	56.309812999999998	56.288955999999999	0103000020E61000000100000005000000BBF2599E07B45640D2FD9C82FC244C40BBF2599E07B456401570CFF3A7274C4071732A1900B756401570CFF3A7274C4071732A1900B75640D2FD9C82FC244C40BBF2599E07B45640D2FD9C82FC244C40
10786	Покровка	5	49	1133	90.748771000000005	90.788486000000006	56.295439999999999	56.289161	0103000020E610000001000000050000005E4C33DDEBAF5640AB23473A03254C405E4C33DDEBAF564012F758FAD0254C40A6D6FB8D76B2564012F758FAD0254C40A6D6FB8D76B25640AB23473A03254C405E4C33DDEBAF5640AB23473A03254C40
27626	Плотбище	5	49	1133	90.832673999999997	90.858671000000001	56.046689999999998	56.040455000000001	0103000020E61000000100000005000000B08EE3874AB55640D7FA22A12D054C40B08EE3874AB556406E861BF0F9054C4083C13577F4B656406E861BF0F9054C4083C13577F4B65640D7FA22A12D054C40B08EE3874AB55640D7FA22A12D054C40
11212	Ольховка	5	49	1133	90.948260000000005	90.983258000000006	56.409424000000001	56.401305000000001	0103000020E61000000100000005000000B806B64AB0BC5640535C55F65D334C40B806B64AB0BC56404819710168344C40F261F6B2EDBE56404819710168344C40F261F6B2EDBE5640535C55F65D334C40B806B64AB0BC5640535C55F65D334C40
59768	Нагорново	5	49	1133	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
11062	Малый Улуй	5	49	1133	90.420957999999999	90.440190999999999	56.128962000000001	56.110062999999997	0103000020E6100000010000000500000055BFD2F9F09A5640F4BF5C8B160E4C4055BFD2F9F09A5640A036AAD381104C40963FDF162C9C5640A036AAD381104C40963FDF162C9C5640F4BF5C8B160E4C4055BFD2F9F09A5640F4BF5C8B160E4C40
10601	Лапшиха	5	49	1133	90.730877000000007	90.775855000000007	56.460267999999999	56.446444	0103000020E61000000100000005000000831953B0C6AE56406ABFB51325394C40831953B0C6AE56409AB2D30FEA3A4C400ADCBA9BA7B156409AB2D30FEA3A4C400ADCBA9BA7B156406ABFB51325394C40831953B0C6AE56406ABFB51325394C40
46199	Красная Заря	5	49	1133	90.286067000000003	90.297034999999994	56.488422999999997	56.478670000000001	0103000020E61000000100000005000000C05DF6EB4E925640C5C9FD0E453D4C40C05DF6EB4E9256409ECE15A5843E4C401CB1169F029356409ECE15A5843E4C401CB1169F02935640C5C9FD0E453D4C40C05DF6EB4E925640C5C9FD0E453D4C40
59776	Костеньки	5	49	1133	90.465128000000007	90.477705	56.080531999999998	56.069167999999998	0103000020E610000001000000050000000D1D3BA8C49D564001F73C7FDA084C400D1D3BA8C49D5640072461DF4E0A4C40AF08FEB7929E5640072461DF4E0A4C40AF08FEB7929E564001F73C7FDA084C400D1D3BA8C49D564001F73C7FDA084C40
51859	Ключи	5	49	1133	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
59747	Карловка	5	49	1133	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
10465	Борцы	5	49	1133	90.232195000000004	90.251283999999998	56.393728000000003	56.387056000000001	0103000020E61000000100000005000000DDD26A48DC8E56403CDC0E0D8B314C40DDD26A48DC8E56407FC2D9AD65324C4084807C09159056407FC2D9AD65324C4084807C09159056403CDC0E0D8B314C40DDD26A48DC8E56403CDC0E0D8B314C40
59497	Большая Салырь	5	49	1133	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
51832	Белый Яр	5	49	1133	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
51792	Малиновка	5	49	7123	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
51820	Берёзовый	5	49	7123	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
59859	Хиндичет	5	49	955	95.537492	97.672797000000003	57.578499000000001	56.424695	0103000020E610000001000000050000002577D84466E257402AE3DF675C364C402577D84466E2574065E256410CCA4C4034F6251B0F6B584065E256410CCA4C4034F6251B0F6B58402AE3DF675C364C402577D84466E257402AE3DF675C364C40
9995	Хандальск	5	49	955	97.111547000000002	97.132936000000001	57.099223000000002	57.086874999999999	0103000020E61000000100000005000000E23D07962347584085EB51B81E8B4C40E23D0796234758406901DA56B38C4C40821DFF05824858406901DA56B38C4C40821DFF058248584085EB51B81E8B4C40E23D07962347584085EB51B81E8B4C40
9682	Устьянск	5	49	955	95.980469999999997	96.036021000000005	56.530245000000001	56.513863999999998	0103000020E61000000100000005000000622D3E05C0FE5740BE4BA94BC6414C40622D3E05C0FE57400BEF7211DF434C40083E062B4E0258400BEF7211DF434C40083E062B4E025840BE4BA94BC6414C40622D3E05C0FE5740BE4BA94BC6414C40
45667	Турово	5	49	955	96.394620000000003	96.434137000000007	56.657508999999997	56.64931	0103000020E610000001000000050000003E963E74411958409E7B0F971C534C403E963E7441195840AFE9414129544C40F33E8EE6C81B5840AFE9414129544C40F33E8EE6C81B58409E7B0F971C534C403E963E74411958409E7B0F971C534C40
49522	Стерлитамак	5	49	955	95.872833	95.892650000000003	56.670642999999998	56.664470000000001	0103000020E61000000100000005000000A777F17EDCF7574029965B5A0D554C40A777F17EDCF757404A253CA1D7554C409031772D21F957404A253CA1D7554C409031772D21F9574029965B5A0D554C40A777F17EDCF7574029965B5A0D554C40
8677	Средние Мангареки	5	49	955	95.854759000000001	95.874602999999993	56.739761999999999	56.723565999999998	0103000020E610000001000000050000008CBD175FB4F65740AF3F89CF9D5C4C408CBD175FB4F657406A696E85B05E4C40F17EDC7EF9F757406A696E85B05E4C40F17EDC7EF9F75740AF3F89CF9D5C4C408CBD175FB4F65740AF3F89CF9D5C4C40
15540	Сенное	5	49	955	96.317966999999996	96.346846999999997	56.616298	56.611047999999997	0103000020E61000000100000005000000438D429259145840A22424D2364E4C40438D4292591458408C4B55DAE24E4C40CE6DC2BD321658408C4B55DAE24E4C40CE6DC2BD32165840A22424D2364E4C40438D429259145840A22424D2364E4C40
32806	Самойловка	5	49	955	95.882805000000005	95.915045000000006	56.842689	56.828831999999998	0103000020E61000000100000005000000B3EF8AE07FF857406BF0BE2A176A4C40B3EF8AE07FF8574077D9AF3BDD6B4C409357E71890FA574077D9AF3BDD6B4C409357E71890FA57406BF0BE2A176A4C40B3EF8AE07FF857406BF0BE2A176A4C40
45708	Пушкино	5	49	955	96.503647999999998	96.528818999999999	56.709868	56.706378999999998	0103000020E61000000100000005000000882CD2C43B20584064CA87A06A5A4C40882CD2C43B2058400C3D62F4DC5A4C4038A0A52BD82158400C3D62F4DC5A4C4038A0A52BD821584064CA87A06A5A4C40882CD2C43B20584064CA87A06A5A4C40
9074	Почет	5	49	955	96.410385000000005	96.444737000000003	57.204031000000001	57.176313999999998	0103000020E61000000100000005000000377172BF431A5840D9E9077591964C40377172BF431A5840622F14B01D9A4C408E942D92761C5840622F14B01D9A4C408E942D92761C5840D9E9077591964C40377172BF431A5840D9E9077591964C40
59748	Покатеево	5	49	955	97.401675999999995	97.418744000000004	57.002647000000003	56.982199999999999	0103000020E61000000100000005000000A3E5400FB5595840CB10C7BAB87D4C40A3E5400FB55958405D37A5BC56804C405C59A2B3CC5A58405D37A5BC56804C405C59A2B3CC5A5840CB10C7BAB87D4C40A3E5400FB5595840CB10C7BAB87D4C40
45535	Плахино	5	49	955	96.584110999999993	96.595753000000002	57.298257	57.282595999999998	0103000020E61000000100000005000000F78E1A13622558407EFD101B2CA44C40F78E1A1362255840CB660E492DA64C409CDF30D120265840CB660E492DA64C409CDF30D1202658407EFD101B2CA44C40F78E1A13622558407EFD101B2CA44C40
45903	Пея	5	49	955	96.862615000000005	96.893347000000006	57.179529000000002	57.172536999999998	0103000020E6100000010000000500000080828B1535375840CB2C42B115964C4080828B153537584080D767CEFA964C40B43EE5982C39584080D767CEFA964C40B43EE5982C395840CB2C42B115964C4080828B1535375840CB2C42B115964C40
9921	Огурцы	5	49	955	95.884152	95.921181000000004	56.536603999999997	56.530315000000002	0103000020E610000001000000050000005A2C45F295F8574004CAA65CE1434C405A2C45F295F857408E739B70AF444C40952C27A1F4FA57408E739B70AF444C40952C27A1F4FA574004CAA65CE1434C405A2C45F295F8574004CAA65CE1434C40
8109	Ношино	5	49	955	95.705467999999996	95.736119000000002	56.611013	56.602525999999997	0103000020E61000000100000005000000F817416326ED5740AE7E6C921F4D4C40F817416326ED574026378AAC354E4C40B6BDDD921CEF574026378AAC354E4C40B6BDDD921CEF5740AE7E6C921F4D4C40F817416326ED5740AE7E6C921F4D4C40
45342	Новоуспенка	5	49	955	96.311875999999998	96.338125000000005	56.777523000000002	56.761353	0103000020E61000000100000005000000111AC1C6F513584012DBDD0374614C40111AC1C6F5135840A471A8DF85634C40713D0AD7A3155840A471A8DF85634C40713D0AD7A315584012DBDD0374614C40111AC1C6F513584012DBDD0374614C40
9858	Новокиевлянка	5	49	955	96.196865000000003	96.217544000000004	56.567053000000001	56.558636	0103000020E61000000100000005000000882EA86F990C5840232F6B6281474C40882EA86F990C5840A20C553195484C403A5CAB3DEC0D5840A20C553195484C403A5CAB3DEC0D5840232F6B6281474C40882EA86F990C5840232F6B6281474C40
59763	Новгородка	5	49	955	96.153305000000003	96.173840999999996	56.468373999999997	56.457895000000001	0103000020E610000001000000050000000D54C6BFCF0958403F00A94D9C3A4C400D54C6BFCF095840FA25E2ADF33B4C400D6D0036200B5840FA25E2ADF33B4C400D6D0036200B58403F00A94D9C3A4C400D54C6BFCF0958403F00A94D9C3A4C40
49439	Мачино	5	49	955	95.768189000000007	95.782705000000007	56.564692000000001	56.557594000000002	0103000020E61000000100000005000000680932022AF1574011397D3D5F474C40680932022AF157400B28D4D347484C409B5AB6D617F257400B28D4D347484C409B5AB6D617F2574011397D3D5F474C40680932022AF1574011397D3D5F474C40
15546	Малкас	5	49	955	95.805926999999997	95.820507000000006	56.925665000000002	56.918477000000003	0103000020E61000000100000005000000A8FDD64E94F35740699082A790754C40A8FDD64E94F35740A306D3307C764C40E7C8CA2F83F45740A306D3307C764C40E7C8CA2F83F45740699082A790754C40A8FDD64E94F35740699082A790754C40
49488	Лазарево	5	49	955	96.786159999999995	96.812416999999996	56.829388999999999	56.817867999999997	0103000020E61000000100000005000000185B087250325840F3380CE6AF684C40185B087250325840C154336B296A4C40B96DDFA3FE335840C154336B296A4C40B96DDFA3FE335840F3380CE6AF684C40185B087250325840F3380CE6AF684C40
9675	Кунгул	5	49	955	95.864137999999997	95.879803999999993	56.820937000000001	56.816581999999997	0103000020E61000000100000005000000C64E78094EF757404A404CC285684C40C64E78094EF75740C689AF7614694C40F5B86FB54EF85740C689AF7614694C40F5B86FB54EF857404A404CC285684C40C64E78094EF757404A404CC285684C40
45794	Красный Яр	5	49	955	96.098499000000004	96.110303000000002	56.544525	56.538654000000001	0103000020E6100000010000000500000014ECBFCE4D06584007EE409DF2444C4014ECBFCE4D0658405D6DC5FEB2454C40A56950340F0758405D6DC5FEB2454C40A56950340F07584007EE409DF2444C4014ECBFCE4D06584007EE409DF2444C40
45439	Канарай	5	49	955	96.196693999999994	96.225628999999998	56.719585000000002	56.715153999999998	0103000020E6100000010000000500000071546EA2960C584042CD902A8A5B4C4071546EA2960C584099D87C5C1B5C4C40DE019EB4700E584099D87C5C1B5C4C40DE019EB4700E584042CD902A8A5B4C4071546EA2960C584042CD902A8A5B4C40
8418	Заозерка	5	49	955	95.806448000000003	95.827082000000004	56.716033000000003	56.708474000000002	0103000020E610000001000000050000002D7B12D89CF357407D08AA46AF5A4C402D7B12D89CF35740ABED26F8A65B4C400F4757E9EEF45740ABED26F8A65B4C400F4757E9EEF457407D08AA46AF5A4C402D7B12D89CF357407D08AA46AF5A4C40
9545	Залипье	5	49	955	96.351140999999998	96.383571000000003	56.679974000000001	56.663742999999997	0103000020E6100000010000000500000039D219187916584076F9D687F5544C4039D2191879165840AE10566309574C406B2C616D8C185840AE10566309574C406B2C616D8C18584076F9D687F5544C4039D219187916584076F9D687F5544C40
8506	Долженовка	5	49	955	95.893997999999996	95.903510999999995	56.691983	56.681477999999998	0103000020E610000001000000050000001F2C634337F95740C478CDAB3A574C401F2C634337F95740A93121E692584C40E124CD1FD3F95740A93121E692584C40E124CD1FD3F95740C478CDAB3A574C401F2C634337F95740C478CDAB3A574C40
49473	Долгий Мост	5	49	955	96.774437000000006	96.825443000000007	56.761175999999999	56.738413999999999	0103000020E61000000100000005000000FEF33460903158404B749659845E4C40FEF3346090315840034015376E614C40946DE00ED4345840034015376E614C40946DE00ED43458404B749659845E4C40FEF33460903158404B749659845E4C40
45765	Денисовка	5	49	955	96.049531999999999	96.102631000000002	56.583548999999998	56.561298999999998	0103000020E61000000100000005000000C00644882B035840852348A5D8474C40C00644882B035840874ECFBBB14A4C4092239D8191065840874ECFBBB14A4C4092239D8191065840852348A5D8474C40C00644882B035840852348A5D8474C40
8868	Гагарина	5	49	955	96.098140000000001	96.116671999999994	56.730687000000003	56.725352999999998	0103000020E610000001000000050000007C9BFEEC470658401A87FA5DD85C4C407C9BFEEC47065840624ED026875D4C40F816D68D77075840624ED026875D4C40F816D68D770758401A87FA5DD85C4C407C9BFEEC470658401A87FA5DD85C4C40
9010	Высокогородецк	5	49	955	96.275225000000006	96.306190000000001	56.715964	56.707026999999997	0103000020E61000000100000005000000AA8251499D115840CA3159DC7F5A4C40AA8251499D115840828E56B5A45B4C402F17F19D98135840828E56B5A45B4C402F17F19D98135840CA3159DC7F5A4C40AA8251499D115840CA3159DC7F5A4C40
45590	Восток	5	49	955	95.808963000000006	95.830972000000003	56.955725000000001	56.945611999999997	0103000020E61000000100000005000000242BBF0CC6F35740425A63D009794C40242BBF0CC6F357401C7C6132557A4C4012F92EA52EF557401C7C6132557A4C4012F92EA52EF55740425A63D009794C40242BBF0CC6F35740425A63D009794C40
9367	Быстровка	5	49	955	95.692047000000002	95.702639000000005	56.981082000000001	56.972507	0103000020E61000000100000005000000E012807F4AEC5740C710001C7B7C4C40E012807F4AEC5740DE585018947D4C403A799109F8EC5740DE585018947D4C403A799109F8EC5740C710001C7B7C4C40E012807F4AEC5740C710001C7B7C4C40
45870	Борзово	5	49	955	97.126324999999994	97.148396000000005	57.124271999999998	57.107568000000001	0103000020E61000000100000005000000B3EA73B5154858404E0CC9C9C48D4C40B3EA73B5154858407DE71725E88F4C40DDB6EF517F4958407DE71725E88F4C40DDB6EF517F4958404E0CC9C9C48D4C40B3EA73B5154858404E0CC9C9C48D4C40
9118	Бирюса	5	49	955	96.490083999999996	96.501322000000002	57.166603000000002	57.158861999999999	0103000020E61000000100000005000000BE1248895D1F5840E0490B9755944C40BE1248895D1F58402F35423F53954C40FBB0DEA8152058402F35423F53954C40FBB0DEA815205840E0490B9755944C40BE1248895D1F5840E0490B9755944C40
7959	Апано-Ключи	5	49	955	96.202146999999997	96.224389000000002	56.865594000000002	56.851210000000002	0103000020E61000000100000005000000027FF8F9EF0C58409B030473F46C4C40027FF8F9EF0C584092CEC0C8CB6E4C404225AE635C0E584092CEC0C8CB6E4C404225AE635C0E58409B030473F46C4C40027FF8F9EF0C58409B030473F46C4C40
49574	Алексеевка	5	49	955	96.008658999999994	96.029149000000004	56.738809000000003	56.731625000000001	0103000020E610000001000000050000003A747ADE8D005840CFF753E3A55D4C403A747ADE8D005840C87E164B915E4C40836DC493DD015840C87E164B915E4C40836DC493DD015840CFF753E3A55D4C403A747ADE8D005840CFF753E3A55D4C40
7810	Абан	5	49	955	96.034008999999998	96.107617000000005	56.690123999999997	56.659112	0103000020E6100000010000000500000042B115342D025840593332C85D544C4042B115342D025840A417B5FB55584C4098DF6932E3065840A417B5FB55584C4098DF6932E3065840593332C85D544C4042B115342D025840593332C85D544C40
51793	Кодинск	5	49	7124	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
59716	Заледеево	5	49	7124	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
56070	станции Тальжино	5	51	\N	87.384742000000003	87.420036999999994	53.765548000000003	53.754145999999999	0103000020E6100000010000000500000073D9E89C9FD8554061342BDB87E04A4073D9E89C9FD8554055C2137AFDE14A400987DEE2E1DA554055C2137AFDE14A400987DEE2E1DA554061342BDB87E04A4073D9E89C9FD8554061342BDB87E04A40
60737	Яя	5	51	\N	84.452399	89.402564999999996	56.832393000000003	52.162630999999998	0103000020E610000001000000050000008F6FEF1AF41C55406B28B517D1144A408F6FEF1AF41C5540AD3594DA8B6A4C40E960FD9FC3595640AD3594DA8B6A4C40E960FD9FC35956406B28B517D1144A408F6FEF1AF41C55406B28B517D1144A40
3682	Ясногорский	5	51	\N	85.877269999999996	85.903779999999998	55.351595000000003	55.341689000000002	0103000020E61000000100000005000000C3F011312578554094331477BCAB4B40C3F0113125785540F437A11001AD4B40D9B11188D7795540F437A11001AD4B40D9B11188D779554094331477BCAB4B40C3F011312578554094331477BCAB4B40
60794	Таштагол	5	51	\N	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
7244	Тайга	5	51	\N	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
3096	Сухово	5	51	\N	86.197806999999997	86.216168999999994	55.370972999999999	55.34319	0103000020E61000000100000005000000DFFAB0DEA88C5540392861A6EDAB4B40DFFAB0DEA88C55407959130B7CAF4B402D5A80B6D58D55407959130B7CAF4B402D5A80B6D58D5540392861A6EDAB4B40DFFAB0DEA88C5540392861A6EDAB4B40
60781	Староабашево	5	51	\N	87.464332999999996	87.495253000000005	53.826939000000003	53.815272	0103000020E61000000100000005000000075DC2A1B7DD554019AC38D55AE84A40075DC2A1B7DD5540BB641C23D9E94A40BD8FA339B2DF5540BB641C23D9E94A40BD8FA339B2DF554019AC38D55AE84A40075DC2A1B7DD554019AC38D55AE84A40
60720	Салаир	5	51	\N	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
60798	Рудничный	5	51	\N	86.223813000000007	86.281647000000007	56.102378000000002	56.064585000000001	0103000020E61000000100000005000000DCDAC2F3528E5540F5673F5244084C40DCDAC2F3528E55403AEAE8B81A0D4C400F812381069255403AEAE8B81A0D4C400F81238106925540F5673F5244084C40DCDAC2F3528E5540F5673F5244084C40
60705	Прокопьевск	5	51	\N	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
3800	Пригородный	5	51	\N	85.923713000000006	85.965512000000004	55.372401000000004	55.337491	0103000020E61000000100000005000000F778211D1E7B5540E0D8B3E732AB4B40F778211D1E7B5540B5FF01D6AAAF4B4051F9D7F2CA7D5540B5FF01D6AAAF4B4051F9D7F2CA7D5540E0D8B3E732AB4B40F778211D1E7B5540E0D8B3E732AB4B40
59364	Осинниковский городской округ	5	51	\N	84.452399	89.402564999999996	56.832393000000003	52.162630999999998	0103000020E610000001000000050000008F6FEF1AF41C55406B28B517D1144A408F6FEF1AF41C5540AD3594DA8B6A4C40E960FD9FC3595640AD3594DA8B6A4C40E960FD9FC35956406B28B517D1144A408F6FEF1AF41C55406B28B517D1144A40
16765	Осинники	5	51	\N	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
51916	Новокузнецк	5	51	\N	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
4775	Новоискитимск	5	51	\N	86.045749000000001	86.072491999999997	55.309314999999998	55.295200999999999	0103000020E61000000100000005000000C8B4368DED8255408D5F7825C9A54B40C8B4368DED825540C49448A297A74B402F4E7CB5A3845540C49448A297A74B402F4E7CB5A38455408D5F7825C9A54B40C8B4368DED8255408D5F7825C9A54B40
41081	Мыски	5	51	\N	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
2899	Мозжуха	5	51	\N	85.906187000000003	85.939442999999997	55.434998	55.409753000000002	0103000020E61000000100000005000000DD43C2F7FE7955400D384BC972B44B40DD43C2F7FE795540A7E9B303AEB74B40315D88D51F7C5540A7E9B303AEB74B40315D88D51F7C55400D384BC972B44B40DD43C2F7FE7955400D384BC972B44B40
59411	Металлургов	5	51	\N	87.012399000000002	87.046473000000006	53.907732000000003	53.891666999999998	0103000020E6100000010000000500000033E02C25CBC0554012F6ED2422F24A4033E02C25CBC055402FC4EA8F30F44A4069C9E369F9C255402FC4EA8F30F44A4069C9E369F9C2554012F6ED2422F24A4033E02C25CBC0554012F6ED2422F24A40
2673	Металлплощадка	5	51	\N	86.171306999999999	86.218171999999996	55.336092999999998	55.298451	0103000020E61000000100000005000000DBA4A2B1F68A5540B03A72A433A64B40DBA4A2B1F68A55400FB56D1805AB4B40C939B187F68D55400FB56D1805AB4B40C939B187F68D5540B03A72A433A64B40DBA4A2B1F68A5540B03A72A433A64B40
60703	Междуреченск	5	51	\N	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
26262	Киселевск	5	51	\N	86.499875000000003	86.799049999999994	54.075457	53.936985	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
2895	Кемерово	5	51	\N	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
41201	Калтан	5	51	\N	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
60760	Ивановка	5	51	\N	86.231126000000003	86.261947000000006	54.474412000000001	54.465277	0103000020E6100000010000000500000057D0B4C4CA8E55405E4A5D328E3B4B4057D0B4C4CA8E55403C6A4C88B93C4B40439259BDC39055403C6A4C88B93C4B40439259BDC39055405E4A5D328E3B4B4057D0B4C4CA8E55405E4A5D328E3B4B40
37297	Загорский	5	51	\N	86.999094999999997	87.016163000000006	53.763556999999999	53.752201999999997	0103000020E6100000010000000500000037A6272CF1BF55402EFEB62748E04A4037A6272CF1BF5540E1D05B3CBCE14A40F01989D008C15540E1D05B3CBCE14A40F01989D008C155402EFEB62748E04A4037A6272CF1BF55402EFEB62748E04A40
2542	Елыкаево	5	51	\N	86.235365999999999	86.265190000000004	55.314413000000002	55.287050000000001	0103000020E61000000100000005000000C8258E3C108F55408D28ED0DBEA44B40C8258E3C108F5540F83768AF3EA84B407B4E7ADFF8905540F83768AF3EA84B407B4E7ADFF89055408D28ED0DBEA44B40C8258E3C108F55408D28ED0DBEA44B40
59402	Елань	5	51	\N	87.249320999999995	87.278193000000002	53.716740000000001	53.699125000000002	0103000020E610000001000000050000002F4D11E0F4CF5540736891ED7CD94A402F4D11E0F4CF554016DEE522BEDB4A40793E03EACDD1554016DEE522BEDB4A40793E03EACDD15540736891ED7CD94A402F4D11E0F4CF5540736891ED7CD94A40
60719	Гурьевск	5	51	\N	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
9765	Березовский	5	51	\N	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
60701	Белово	5	51	\N	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
52146	Атаманово	5	51	\N	87.369049000000004	87.433610999999999	53.792352999999999	53.767384	0103000020E61000000100000005000000C767B27F9ED75540A1BC8FA339E24A40C767B27F9ED7554099F1B6D26BE54A40E50B5A48C0DB554099F1B6D26BE54A40E50B5A48C0DB5540A1BC8FA339E24A40C767B27F9ED75540A1BC8FA339E24A40
41109	Анжеро-Судженск	5	51	\N	85.940036000000006	86.137431000000007	56.14396	56.029843	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
41089	Тайжина	5	51	1434	87.413713000000001	87.474654999999998	53.709342999999997	53.655512000000002	0103000020E61000000100000005000000863B17467ADA55405A1135D1E7D34A40863B17467ADA5540C1525DC0CBDA4A4081785DBF60DE5540C1525DC0CBDA4A4081785DBF60DE55405A1135D1E7D34A40863B17467ADA55405A1135D1E7D34A40
16092	Тайжина	5	51	1434	87.413713000000001	87.474654999999998	53.709342999999997	53.655512000000002	0103000020E61000000100000005000000863B17467ADA55405A1135D1E7D34A40863B17467ADA5540C1525DC0CBDA4A4081785DBF60DE5540C1525DC0CBDA4A4081785DBF60DE55405A1135D1E7D34A40863B17467ADA55405A1135D1E7D34A40
41161	Чувашка	5	51	640	87.801784999999995	87.824332999999996	53.601911999999999	53.584221999999997	0103000020E61000000100000005000000185B087250F3554046CD57C9C7CA4A40185B087250F35540F488D1730BCD4A40DE0033DFC1F45540F488D1730BCD4A40DE0033DFC1F4554046CD57C9C7CA4A40185B087250F3554046CD57C9C7CA4A40
4783	Бородино	5	51	640	87.743528999999995	87.800940999999995	53.754038999999999	53.736407999999997	0103000020E610000001000000050000002AA8A8FA95EF5540A2410A9E42DE4A402AA8A8FA95EF55404B74965984E04A40A2410A9E42F355404B74965984E04A40A2410A9E42F35540A2410A9E42DE4A402AA8A8FA95EF5540A2410A9E42DE4A40
4229	Яшкинский	5	51	574	85.386215000000007	85.414942999999994	55.880035999999997	55.866667	0103000020E61000000100000005000000618E1EBFB7585540DFC2BAF1EEEE4B40618E1EBFB7585540BDA60705A5F04B4010AD156D8E5A5540BDA60705A5F04B4010AD156D8E5A5540DFC2BAF1EEEE4B40618E1EBFB7585540DFC2BAF1EEEE4B40
3580	Яшкино	5	51	574	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
41157	Яшкино	5	51	574	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
4714	Юрты-Константиновы	5	51	574	84.949005	84.965237999999999	56.074021000000002	56.061956000000002	0103000020E6100000010000000500000064AF777FBC3C55403FE5982CEE074C4064AF777FBC3C5540CE1B278579094C40D0B69A75C63D5540CE1B278579094C40D0B69A75C63D55403FE5982CEE074C4064AF777FBC3C55403FE5982CEE074C40
41094	Шахтер	5	51	574	85.116864000000007	85.140274000000005	55.821117999999998	55.806105000000002	0103000020E610000001000000050000001B8524B37A4755403012DA722EE74B401B8524B37A475540161406651AE94B40AA9ECC3FFA485540161406651AE94B40AA9ECC3FFA4855403012DA722EE74B401B8524B37A4755403012DA722EE74B40
60778	Хопкино	5	51	574	85.436628999999996	85.457325999999995	55.946612999999999	55.935153	0103000020E610000001000000050000000DDFC2BAF15B5540CEE0EF17B3F74B400DDFC2BAF15B5540F67B629D2AF94B40126745D4445D5540F67B629D2AF94B40126745D4445D5540CEE0EF17B3F74B400DDFC2BAF15B5540CEE0EF17B3F74B40
5537	Тутальская	5	51	574	84.977913000000001	85.010513000000003	55.763973999999997	55.747889999999998	0103000020E6100000010000000500000054556820963E5540B28009DCBADF4B4054556820963E5540457F68E6C9E14B40B4CBB73EAC405540457F68E6C9E14B40B4CBB73EAC405540B28009DCBADF4B4054556820963E5540B28009DCBADF4B40
41092	Таловка	5	51	574	85.828411000000003	85.843260000000001	55.966796000000002	55.958477000000002	0103000020E61000000100000005000000632992AF04755540EE7BD45FAFFA4B40632992AF04755540AAF3A8F8BFFB4B409981CAF8F7755540AAF3A8F8BFFB4B409981CAF8F7755540EE7BD45FAFFA4B40632992AF04755540EE7BD45FAFFA4B40
4680	Соломатово	5	51	574	85.006146999999999	85.031155999999996	55.934679000000003	55.924002999999999	0103000020E61000000100000005000000FCFD62B664405540F433F5BA45F64B40FCFD62B66440554006A1BC8FA3F74B40BF44BC75FE41554006A1BC8FA3F74B40BF44BC75FE415540F433F5BA45F64B40FCFD62B664405540F433F5BA45F64B40
5278	Северная	5	51	574	85.312004999999999	85.329936000000004	56.049787000000002	56.037402999999998	0103000020E6100000010000000500000010CCD1E3F7535540DAE21A9FC9044C4010CCD1E3F75355400B62A06B5F064C407A71E2AB1D5555400B62A06B5F064C407A71E2AB1D555540DAE21A9FC9044C4010CCD1E3F7535540DAE21A9FC9044C40
5368	Поломошное	5	51	574	84.945322000000004	84.980410000000006	55.754734999999997	55.734096000000001	0103000020E610000001000000050000001E8CD827803C5540ED0F94DBF6DD4B401E8CD827803C5540C2120F289BE04B40F8AA9509BF3E5540C2120F289BE04B40F8AA9509BF3E5540ED0F94DBF6DD4B401E8CD827803C5540ED0F94DBF6DD4B40
5265	Пашково	5	51	574	85.104844999999997	85.151754999999994	56.061193000000003	56.038172000000003	0103000020E610000001000000050000008B89CDC7B5465540BCCFF1D1E2044C408B89CDC7B546554040DF162CD5074C4049809A5AB649554040DF162CD5074C4049809A5AB6495540BCCFF1D1E2044C408B89CDC7B5465540BCCFF1D1E2044C40
5105	Пача	5	51	574	85.478688000000005	85.508413000000004	55.713211999999999	55.696286000000001	0103000020E61000000100000005000000363FFED2A25E5540D2544FE61FD94B40363FFED2A25E5540B08EE3874ADB4B401FF7ADD689605540B08EE3874ADB4B401FF7ADD689605540D2544FE61FD94B40363FFED2A25E5540D2544FE61FD94B40
46461	Октябрьский	5	51	574	85.104080999999994	85.117502000000002	55.780496999999997	55.775666999999999	0103000020E61000000100000005000000A3C85A43A946554010CB660E49E34B40A3C85A43A946554024D06053E7E34B40BCCD1B278547554024D06053E7E34B40BCCD1B278547554010CB660E49E34B40A3C85A43A946554010CB660E49E34B40
4096	Нижняя Тайменка	5	51	574	85.209965999999994	85.225695000000002	55.674985999999997	55.665537999999998	0103000020E6100000010000000500000067D13B15704D5540641F645930D54B4067D13B15704D554001A1F5F065D64B40BAF770C9714E554001A1F5F065D64B40BAF770C9714E5540641F645930D54B4067D13B15704D5540641F645930D54B40
5188	Нижнеяшкино	5	51	574	85.463749000000007	85.502573999999996	55.835973000000003	55.823383	0103000020E6100000010000000500000060234910AE5D55408B8A389D64E94B4060234910AE5D554065ABCB2901EB4B407974232C2A60554065ABCB2901EB4B407974232C2A6055408B8A389D64E94B4060234910AE5D55408B8A389D64E94B40
5674	Мохово	5	51	574	84.942897000000002	84.957098999999999	55.843409000000001	55.830573999999999	0103000020E61000000100000005000000C79FA86C583C55403674B33F50EA4B40C79FA86C583C554077137CD3F4EB4B4032022A1C413D554077137CD3F4EB4B4032022A1C413D55403674B33F50EA4B40C79FA86C583C55403674B33F50EA4B40
5118	Морковкино	5	51	574	85.614108999999999	85.625230000000002	55.714013999999999	55.697265000000002	0103000020E6100000010000000500000079CBD58F4D6755409ED2C1FA3FD94B4079CBD58F4D6755406D718DCF64DB4B40999EB0C4036855406D718DCF64DB4B40999EB0C4036855409ED2C1FA3FD94B4079CBD58F4D6755409ED2C1FA3FD94B40
4982	Литвиново	5	51	574	85.287068000000005	85.304316	55.837530000000001	55.826726000000001	0103000020E610000001000000050000009AEE75525F5255405F605628D2E94B409AEE75525F5255409EB5DB2E34EB4B4092E9D0E9795355409EB5DB2E34EB4B4092E9D0E9795355405F605628D2E94B409AEE75525F5255405F605628D2E94B40
4547	Ленинский	5	51	574	85.057440999999997	85.074625999999995	56.032910999999999	56.017617999999999	0103000020E61000000100000005000000C51C041DAD43554014E97E4E41024C40C51C041DAD435540DE567A6D36044C409A5B21ACC6445540DE567A6D36044C409A5B21ACC644554014E97E4E41024C40C51C041DAD43554014E97E4E41024C40
4614	Кулаково	5	51	574	85.019298000000006	85.029629	55.896816999999999	55.883707000000001	0103000020E6100000010000000500000035B8AD2D3C415540861F9C4F1DF14B4035B8AD2D3C41554098BF42E6CAF24B40D8800871E541554098BF42E6CAF24B40D8800871E5415540861F9C4F1DF14B4035B8AD2D3C415540861F9C4F1DF14B40
4936	Красноселка	5	51	574	85.196382999999997	85.226854000000003	55.875546	55.857436999999997	0103000020E61000000100000005000000629F008A914C5540AFB0E07EC0ED4B40629F008A914C554062122EE411F04B40E0BDA3C6844E554062122EE411F04B40E0BDA3C6844E5540AFB0E07EC0ED4B40629F008A914C5540AFB0E07EC0ED4B40
41083	Корчуганово	5	51	574	85.259210999999993	85.269596000000007	55.805123000000002	55.796542000000002	0103000020E61000000100000005000000DCF0BBE996505540FAF19716F5E54B40DCF0BBE996505540F3203D450EE74B407AC8940F41515540F3203D450EE74B407AC8940F41515540FAF19716F5E54B40DCF0BBE996505540FAF19716F5E54B40
4508	Колмогорово	5	51	574	85.638964999999999	85.683503999999999	55.649804000000003	55.626477000000001	0103000020E61000000100000005000000799274CDE46855401D59F96530D04B40799274CDE4685540AE6708C72CD34B40DAAB8F87BE6B5540AE6708C72CD34B40DAAB8F87BE6B55401D59F96530D04B40799274CDE46855401D59F96530D04B40
4083	Зырянка	5	51	574	85.216352999999998	85.238532000000006	55.724347000000002	55.711644999999997	0103000020E610000001000000050000000ED940BAD84D554053AEF02E17DB4B400ED940BAD84D554055FA0967B7DC4B402BC3B81B444F554055FA0967B7DC4B402BC3B81B444F554053AEF02E17DB4B400ED940BAD84D554053AEF02E17DB4B40
4395	Дубровка	5	51	574	85.334248000000002	85.367620000000002	55.925203000000003	55.919835999999997	0103000020E610000001000000050000003830B951645555407BD7A02FBDF54B403830B951645555409F94490D6DF64B40C1560916875755409F94490D6DF64B40C1560916875755407BD7A02FBDF54B403830B951645555407BD7A02FBDF54B40
3973	Власково	5	51	574	85.403355000000005	85.424762000000001	55.759267999999999	55.750064000000002	0103000020E61000000100000005000000666B7D91D059554017F4DE1802E04B40666B7D91D05955401D739EB12FE14B4059A5F44C2F5B55401D739EB12FE14B4059A5F44C2F5B554017F4DE1802E04B40666B7D91D059554017F4DE1802E04B40
41164	Ботьево	5	51	574	85.224770000000007	85.239582999999996	55.939765999999999	55.929682	0103000020E61000000100000005000000CEC7B5A1624E554006D7DCD1FFF64B40CEC7B5A1624E554045F295404AF84B405D6BEF53554F554045F295404AF84B405D6BEF53554F554006D7DCD1FFF64B40CEC7B5A1624E554006D7DCD1FFF64B40
4841	Балахнино	5	51	574	85.222210000000004	85.237579999999994	55.907525999999997	55.892279000000002	0103000020E6100000010000000500000007B64AB0384E55402CF4C13236F24B4007B64AB0384E55408522DDCF29F44B40C18BBE82344F55408522DDCF29F44B40C18BBE82344F55402CF4C13236F24B4007B64AB0384E55402CF4C13236F24B40
3965	Акация	5	51	574	85.356202999999994	85.384103999999994	55.739823000000001	55.728727999999997	0103000020E610000001000000050000002CEFAA07CC565540F9D687F546DD4B402CEFAA07CC56554010EA2285B2DE4B40D190F1289558554010EA2285B2DE4B40D190F12895585540F9D687F546DD4B402CEFAA07CC565540F9D687F546DD4B40
1276	Яя-Борик	5	51	236	86.440927000000002	86.470840999999993	56.283749	56.263952000000003	0103000020E61000000100000005000000193BE125389C55405EDBDB2DC9214C40193BE125389C5540E8A221E351244C406B274A42229E5540E8A221E351244C406B274A42229E55405EDBDB2DC9214C40193BE125389C55405EDBDB2DC9214C40
41150	Яя	5	51	236	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
41250	Яя	5	51	236	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
1163	Щербиновка	5	51	236	85.966716000000005	85.987008000000003	56.188378	56.171914000000001	0103000020E610000001000000050000004721C9ACDE7D5540BEDC274701164C404721C9ACDE7D554098A432C51C184C40FC389A232B7F554098A432C51C184C40FC389A232B7F5540BEDC274701164C404721C9ACDE7D5540BEDC274701164C40
2454	Улановка	5	51	236	86.089164999999994	86.116348000000002	56.416670000000003	56.396239000000001	0103000020E61000000100000005000000A9BC1DE1B48555402B33A5F5B7324C40A9BC1DE1B4855540B79C4B7155354C401FBDE13E72875540B79C4B7155354C401FBDE13E728755402B33A5F5B7324C40A9BC1DE1B48555402B33A5F5B7324C40
1738	Турат	5	51	236	86.167202000000003	86.193027999999998	56.090240999999999	56.077463000000002	0103000020E61000000100000005000000DA740470B38A554035D3BD4EEA094C40DA740470B38A554011E15F048D0B4C4096CD1C925A8C554011E15F048D0B4C4096CD1C925A8C554035D3BD4EEA094C40DA740470B38A554035D3BD4EEA094C40
2343	Судженка	5	51	236	86.236020999999994	86.271908999999994	56.192143999999999	56.173090999999999	0103000020E61000000100000005000000D40AD3F71A8F5540B01D8CD827164C40D40AD3F71A8F5540B20FB22C98184C403C9F01F566915540B20FB22C98184C403C9F01F566915540B01D8CD827164C40D40AD3F71A8F5540B01D8CD827164C40
1526	Соболинка	5	51	236	85.874736999999996	85.902010000000004	56.273004999999998	56.262461999999999	0103000020E6100000010000000500000079E6E5B0FB775540AC38D55A98214C4079E6E5B0FB7755407E52EDD3F1224C408FAA2688BA7955407E52EDD3F1224C408FAA2688BA795540AC38D55A98214C4079E6E5B0FB775540AC38D55A98214C40
2108	Сергеевка	5	51	236	86.343773999999996	86.362324999999998	56.393059999999998	56.376933999999999	0103000020E61000000100000005000000C4CDA964009655400F60915F3F304C40C4CDA96400965540D1AE42CA4F324C407C61325530975540D1AE42CA4F324C407C613255309755400F60915F3F304C40C4CDA964009655400F60915F3F304C40
6230	Рудничный	5	51	236	86.223813000000007	86.281647000000007	56.102378000000002	56.064585000000001	0103000020E61000000100000005000000DCDAC2F3528E5540F5673F5244084C40DCDAC2F3528E55403AEAE8B81A0D4C400F812381069255403AEAE8B81A0D4C400F81238106925540F5673F5244084C40DCDAC2F3528E5540F5673F5244084C40
2444	Ольговка	5	51	236	86.347188000000003	86.379176999999999	56.232373000000003	56.223691000000002	0103000020E6100000010000000500000013640454389655406CB41CE8A11C4C40136404543896554099BC0166BE1D4C404E999B6F4498554099BC0166BE1D4C404E999B6F449855406CB41CE8A11C4C4013640454389655406CB41CE8A11C4C40
1060	Новостройка	5	51	236	86.101821999999999	86.117272999999997	56.181604999999998	56.174675000000001	0103000020E61000000100000005000000DA006C4084865540E3361AC05B164C40DA006C408486554021E527D53E174C400BED9C668187554021E527D53E174C400BED9C6681875540E3361AC05B164C40DA006C4084865540E3361AC05B164C40
1862	Новониколаевка	5	51	236	86.450952000000001	86.483840000000001	56.178147000000003	56.159072000000002	0103000020E610000001000000050000003604C765DC9C5540CBDAA6785C144C403604C765DC9C5540B5705985CD164C40C91F0C3CF79E5540B5705985CD164C40C91F0C3CF79E5540CBDAA6785C144C403604C765DC9C5540CBDAA6785C144C40
1631	Назаровка	5	51	236	85.893906999999999	85.917271999999997	56.242939	56.232999	0103000020E6100000010000000500000097AAB4C535795540178046E9D21D4C4097AAB4C53579554023F609A0181F4C4056629E95B47A554023F609A0181F4C4056629E95B47A5540178046E9D21D4C4097AAB4C535795540178046E9D21D4C40
48283	Михайловка	5	51	236	85.804282000000001	85.809582000000006	56.275489	56.271531000000003	0103000020E61000000100000005000000BCB0355B79735540D36C1E87C1224C40BCB0355B7973554031B43A3943234C408A5B0531D073554031B43A3943234C408A5B0531D0735540D36C1E87C1224C40BCB0355B79735540D36C1E87C1224C40
2569	Медведчиково	5	51	236	86.182768999999993	86.194933000000006	56.533169000000001	56.520440000000001	0103000020E610000001000000050000003F6EBF7CB28B5540DFC325C79D424C403F6EBF7CB28B5540DA1EBDE13E444C4051FA42C8798C5540DA1EBDE13E444C4051FA42C8798C5540DFC325C79D424C403F6EBF7CB28B5540DFC325C79D424C40
2094	Марьевка	5	51	236	86.378629000000004	86.398274999999998	56.304650000000002	56.285153999999999	0103000020E610000001000000050000004D1421753B9855406B2920ED7F244C404D1421753B985540FB5C6DC5FE264C401FF46C567D995540FB5C6DC5FE264C401FF46C567D9955406B2920ED7F244C404D1421753B9855406B2920ED7F244C40
1989	Мальцево	5	51	236	86.440550000000002	86.456835999999996	56.12697	56.113306000000001	0103000020E610000001000000050000002E90A0F8319C554065389ECF800E4C402E90A0F8319C55405CC98E8D40104C40ABE80FCD3C9D55405CC98E8D40104C40ABE80FCD3C9D554065389ECF800E4C402E90A0F8319C554065389ECF800E4C40
937	Майский	5	51	236	86.157069000000007	86.167362999999995	56.184826000000001	56.169854000000001	0103000020E61000000100000005000000CA8D226B0D8A5540228C9FC6BD154C40CA8D226B0D8A5540AAB9DC60A8174C40DEE34C13B68A5540AAB9DC60A8174C40DEE34C13B68A5540228C9FC6BD154C40CA8D226B0D8A5540228C9FC6BD154C40
60802	Красная Горка	5	51	236	86.036398000000005	86.051947999999996	56.117395999999999	56.106138000000001	0103000020E61000000100000005000000F3E8465854825540726E13EE950D4C40F3E8465854825540325706D5060F4C40ED45B41D53835540325706D5060F4C40ED45B41D53835540726E13EE950D4C40F3E8465854825540726E13EE950D4C40
1757	Кайла	5	51	236	86.066823999999997	86.096773999999996	56.240037999999998	56.215702999999998	0103000020E61000000100000005000000A0A52BD8468455401553E9279C1B4C40A0A52BD8468455400CE6AF90B91E4C409946938B318655400CE6AF90B91E4C409946938B318655401553E9279C1B4C40A0A52BD8468455401553E9279C1B4C40
2550	Ишим	5	51	236	86.203817000000001	86.228368000000003	56.518379000000003	56.506131000000003	0103000020E610000001000000050000009B5775560B8D5540F33E8EE6C8404C409B5775560B8D554073F7393E5A424C40FDDCD0949D8E554073F7393E5A424C40FDDCD0949D8E5540F33E8EE6C8404C409B5775560B8D5540F33E8EE6C8404C40
1503	Емельяновка	5	51	236	85.895298999999994	85.921763999999996	56.387385000000002	56.370623000000002	0103000020E610000001000000050000000E492D944C7955409D121093702F4C400E492D944C79554001FBE8D495314C4054A86E2EFE7A554001FBE8D495314C4054A86E2EFE7A55409D121093702F4C400E492D944C7955409D121093702F4C40
1845	Данковка	5	51	236	86.1006	86.118172000000001	56.307352000000002	56.286912000000001	0103000020E61000000100000005000000917EFB3A708655403C6A4C88B9244C40917EFB3A708655401B2E724F57274C4063D34A21908755401B2E724F57274C4063D34A21908755403C6A4C88B9244C40917EFB3A708655403C6A4C88B9244C40
1402	Вознесенка	5	51	236	85.942677000000003	85.976569999999995	56.328403999999999	56.310721999999998	0103000020E61000000100000005000000406CE9D1547C5540E8120EBDC5274C40406CE9D1547C554013F06B24092A4C404D10751F807E554013F06B24092A4C404D10751F807E5540E8120EBDC5274C40406CE9D1547C5540E8120EBDC5274C40
1398	Верх-Великосельское	5	51	236	86.353755000000007	86.375916000000004	56.430956999999999	56.419811000000003	0103000020E61000000100000005000000FAF202ECA396554023C0E95DBC354C40FAF202ECA3965540BB7D569929374C40C382FB010F985540BB7D569929374C40C382FB010F98554023C0E95DBC354C40FAF202ECA396554023C0E95DBC354C40
1310	Бекет	5	51	236	86.456450000000004	86.481549000000001	56.365153999999997	56.355598999999998	0103000020E6100000010000000500000097900F7A369D5540C2BE9D44842D4C4097900F7A369D55407500C45DBD2E4C40FA9AE5B2D19E55407500C45DBD2E4C40FA9AE5B2D19E5540C2BE9D44842D4C4097900F7A369D5540C2BE9D44842D4C40
928	Безлесный	5	51	236	86.100223	86.123427000000007	56.149321	56.138618999999998	0103000020E61000000100000005000000A6D3BA0D6A86554057CD7344BE114C40A6D3BA0D6A86554092CD55F31C134C40611C5C3AE687554092CD55F31C134C40611C5C3AE687554057CD7344BE114C40A6D3BA0D6A86554057CD7344BE114C40
41131	Арышево	5	51	236	86.376653000000005	86.401634999999999	56.319803999999998	56.310343000000003	0103000020E610000001000000050000002E3C2F151B98554072C5C551B9274C402E3C2F151B985540A3906456EF284C40747B4963B4995540A3906456EF284C40747B4963B499554072C5C551B9274C402E3C2F151B98554072C5C551B9274C40
41105	Юргинский	5	51	38	84.631262000000007	84.650278999999998	55.698197999999998	55.685471999999997	0103000020E61000000100000005000000494DBB98662855406F29E78BBDD74B40494DBB9866285540F910548D5ED94B40A391CF2B9E295540F910548D5ED94B40A391CF2B9E2955406F29E78BBDD74B40494DBB98662855406F29E78BBDD74B40
41148	Юрга II	5	51	38	84.761671000000007	84.796211	55.688025000000003	55.661023999999998	0103000020E61000000100000005000000F2D3B837BF30554080EF366F9CD44B40F2D3B837BF3055404BEA043411D84B40CA6DFB1EF53255404BEA043411D84B40CA6DFB1EF532554080EF366F9CD44B40F2D3B837BF30554080EF366F9CD44B40
6960	Юрга	5	51	38	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
31765	Юльяновка	5	51	38	84.758347000000001	84.773959000000005	55.439124	55.43083	0103000020E610000001000000050000004301DBC1883055405E11FC6F25B74B404301DBC188305540C171193735B84B40795C548B88315540C171193735B84B40795C548B883155405E11FC6F25B74B404301DBC1883055405E11FC6F25B74B40
31671	Черный Падун	5	51	38	84.906379999999999	84.920914999999994	55.394162000000001	55.382421000000001	0103000020E61000000100000005000000E76F4221023A5540DD26DC2BF3B04B40E76F4221023A5540B9A981E673B24B4055D97745F03A5540B9A981E673B24B4055D97745F03A5540DD26DC2BF3B04B40E76F4221023A5540DD26DC2BF3B04B40
32348	Филоново	5	51	38	84.774355	84.791152999999994	55.871465999999998	55.860903	0103000020E610000001000000050000009F1F46088F3155409F03CB1132EE4B409F1F46088F315540B8C9A8328CEF4B4077483140A2325540B8C9A8328CEF4B4077483140A23255409F03CB1132EE4B409F1F46088F3155409F03CB1132EE4B40
682	Томилово	5	51	38	84.874696999999998	84.892949999999999	55.998095999999997	55.983550000000001	0103000020E61000000100000005000000323A2009FB3755408BFD65F7E4FD4B40323A2009FB3755405B22179CC1FF4B40A5BDC117263955405B22179CC1FF4B40A5BDC117263955408BFD65F7E4FD4B40323A2009FB3755408BFD65F7E4FD4B40
60730	Талая	5	51	38	84.885647000000006	84.898016999999996	55.796849999999999	55.780557000000002	0103000020E610000001000000050000003C33C170AE385540FAD4B14AE9E34B403C33C170AE385540A7E8482EFFE54B4021904B1C79395540A7E8482EFFE54B4021904B1C79395540FAD4B14AE9E34B403C33C170AE385540FAD4B14AE9E34B40
31948	Старый Шалай	5	51	38	84.850702999999996	84.860836000000006	55.614413999999996	55.608811000000003	0103000020E61000000100000005000000FBE6FEEA71365540F838D384EDCD4B40FBE6FEEA713655402E1A321EA5CE4B400CCEE0EF173755402E1A321EA5CE4B400CCEE0EF17375540F838D384EDCD4B40FBE6FEEA71365540F838D384EDCD4B40
32414	Сокольники	5	51	38	84.637478000000002	84.653648000000004	55.867702999999999	55.859093999999999	0103000020E61000000100000005000000D97A8670CC2855404C18CDCAF6ED4B40D97A8670CC2855400FD253E410EF4B4022C66B5ED52955400FD253E410EF4B4022C66B5ED52955404C18CDCAF6ED4B40D97A8670CC2855404C18CDCAF6ED4B40
32028	Сарсаз	5	51	38	84.814832999999993	84.831928000000005	55.696854000000002	55.684676000000003	0103000020E61000000100000005000000E6AC4F3926345540952D9276A3D74B40E6AC4F39263455401C0B0A8332D94B401C28F04E3E3555401C0B0A8332D94B401C28F04E3E355540952D9276A3D74B40E6AC4F3926345540952D9276A3D74B40
31411	Речной	5	51	38	85.094487000000001	85.114070999999996	55.695149000000001	55.688634	0103000020E610000001000000050000006BB933130C465540F374AE2825D84B406BB933130C4655406E6C76A4FAD84B40029B73F04C4755406E6C76A4FAD84B40029B73F04C475540F374AE2825D84B406BB933130C465540F374AE2825D84B40
824	Пятково	5	51	38	84.934650000000005	84.958869000000007	55.860377999999997	55.851146	0103000020E6100000010000000500000036CD3B4ED13B5540840F255AF2EC4B4036CD3B4ED13B55405419C6DD20EE4B407D09151C5E3D55405419C6DD20EE4B407D09151C5E3D5540840F255AF2EC4B4036CD3B4ED13B5540840F255AF2EC4B40
32213	Проскоково	5	51	38	84.705831000000003	84.740820999999997	55.849528999999997	55.825285000000001	0103000020E610000001000000050000003160C9552C2D55408F705AF0A2E94B403160C9552C2D55407500C45DBDEC4B4029CC7B9C692F55407500C45DBDEC4B4029CC7B9C692F55408F705AF0A2E94B403160C9552C2D55408F705AF0A2E94B40
32470	Приречье	5	51	38	84.795546000000002	84.807377000000002	55.895257000000001	55.885953000000001	0103000020E61000000100000005000000AC1DC539EA32554084656CE866F14B40AC1DC539EA325540EE4108C897F24B40BAA29410AC335540EE4108C897F24B40BAA29410AC33554084656CE866F14B40AC1DC539EA32554084656CE866F14B40
41188	Поперечное	5	51	38	84.973583000000005	84.996049999999997	55.512526000000001	55.494577999999997	0103000020E61000000100000005000000433C122F4F3E554019A9F7544EBF4B40433C122F4F3E5540C32CB4739AC14B4092CB7F48BF3F5540C32CB4739AC14B4092CB7F48BF3F554019A9F7544EBF4B40433C122F4F3E554019A9F7544EBF4B40
184	Новороманово	5	51	38	85.327860999999999	85.352267999999995	55.674391999999997	55.653714999999998	0103000020E610000001000000050000009128B4ACFB545540CBF3E0EEACD34B409128B4ACFB5455408E57207A52D64B4059DB148F8B5655408E57207A52D64B4059DB148F8B565540CBF3E0EEACD34B409128B4ACFB545540CBF3E0EEACD34B40
41116	Мальцево	5	51	38	84.820437999999996	84.835008999999999	55.967612000000003	55.950629999999997	0103000020E610000001000000050000005299620E82345540594C6C3EAEF94B405299620E82345540CC9BC3B5DAFB4B4067B796C970355540CC9BC3B5DAFB4B4067B796C970355540594C6C3EAEF94B405299620E82345540594C6C3EAEF94B40
41115	Макурино	5	51	38	84.650531000000001	84.682321999999999	56.04222	56.029687000000003	0103000020E610000001000000050000003082C64CA2295540E50E9BC8CC034C403082C64CA22955405A9E077767054C40D8D5E429AB2B55405A9E077767054C40D8D5E429AB2B5540E50E9BC8CC034C403082C64CA2295540E50E9BC8CC034C40
31491	Любаровка	5	51	38	84.869837000000004	84.889078999999995	55.520181000000001	55.504562	0103000020E6100000010000000500000073F6CE68AB375540F566D47C95C04B4073F6CE68AB37554013807F4A95C24B40DD239BABE638554013807F4A95C24B40DD239BABE6385540F566D47C95C04B4073F6CE68AB375540F566D47C95C04B40
31658	Линейный	5	51	38	84.761337999999995	84.789285000000007	55.478005000000003	55.464635999999999	0103000020E61000000100000005000000EECC04C3B9305540AA45443179BB4B40EECC04C3B9305540892991442FBD4B404C8E3BA583325540892991442FBD4B404C8E3BA583325540AA45443179BB4B40EECC04C3B9305540AA45443179BB4B40
41210	Лебяжье-Асаново	5	51	38	84.630238000000006	84.655057999999997	55.748370999999999	55.738551000000001	0103000020E6100000010000000500000093ACC3D155285540CCB6D3D688DE4B4093ACC3D1552855402D23F59ECADF4B40ECBE6378EC2955402D23F59ECADF4B40ECBE6378EC295540CCB6D3D688DE4B4093ACC3D155285540CCB6D3D688DE4B40
60773	Копылово	5	51	38	85.460542000000004	85.482892000000007	55.661146000000002	55.653455999999998	0103000020E61000000100000005000000CE1B2785795D5540FFAF3A72A4D34B40CE1B2785795D5540CCF09F6EA0D44B4001E0D8B3E75E5540CCF09F6EA0D44B4001E0D8B3E75E5540FFAF3A72A4D34B40CE1B2785795D5540FFAF3A72A4D34B40
302	Кожевниково	5	51	38	84.600082	84.633309999999994	56.014001	56.006230000000002	0103000020E61000000100000005000000C53A55BE6726554086200725CC004C40C53A55BE672655403F8EE6C8CA014C40B48EAA26882855403F8EE6C8CA014C40B48EAA268828554086200725CC004C40C53A55BE6726554086200725CC004C40
60729	Зимник	5	51	38	84.911680000000004	84.934336000000002	55.672488000000001	55.654198000000001	0103000020E61000000100000005000000B51A12F7583A5540E78D93C2BCD34B40B51A12F7583A5540EA79371614D64B406EDE3829CC3B5540EA79371614D64B406EDE3829CC3B5540E78D93C2BCD34B40B51A12F7583A5540E78D93C2BCD34B40
437	Зеледеево	5	51	38	84.857664	84.883437000000001	56.052264999999998	56.026398	0103000020E6100000010000000500000038BD8BF7E33655400457790261034C4038BD8BF7E3365540DBDC989EB0064C40E3C4573B8A385540DBDC989EB0064C40E3C4573B8A3855400457790261034C4038BD8BF7E33655400457790261034C40
46	Заозерный	5	51	38	84.709648999999999	84.735026000000005	55.894368999999998	55.886670000000002	0103000020E61000000100000005000000E7A8A3E36A2D5540132C0E677EF14B40E7A8A3E36A2D554032C7F2AE7AF24B406CED7DAA0A2F554032C7F2AE7AF24B406CED7DAA0A2F5540132C0E677EF14B40E7A8A3E36A2D5540132C0E677EF14B40
60772	Елгино	5	51	38	84.840174000000005	84.866684000000006	55.928597000000003	55.913120999999997	0103000020E61000000100000005000000C53C2B69C535554039252026E1F44B40C53C2B69C5355540F5143944DCF64B40DBFD2AC077375540F5143944DCF64B40DBFD2AC07737554039252026E1F44B40C53C2B69C535554039252026E1F44B40
31333	Верх-Тайменка	5	51	38	85.191730000000007	85.234318999999999	55.663623999999999	55.64414	0103000020E6100000010000000500000060EAE74D454C5540D105F52D73D24B4060EAE74D454C55409C6B98A1F1D44B4036751E15FF4E55409C6B98A1F1D44B4036751E15FF4E5540D105F52D73D24B4060EAE74D454C5540D105F52D73D24B40
41101	Васильевка	5	51	38	84.704457000000005	84.726331000000002	55.403047000000001	55.394627	0103000020E610000001000000050000000D1CD0D2152D55402E8F352383B24B400D1CD0D2152D55401EE0490B97B34B408BC404357C2E55401EE0490B97B34B408BC404357C2E55402E8F352383B24B400D1CD0D2152D55402E8F352383B24B40
41151	Варюхино	5	51	38	84.886347999999998	84.913504000000003	56.118544999999997	56.095640000000003	0103000020E610000001000000050000000038F6ECB9385540401878EE3D0C4C400038F6ECB93855405A0D897B2C0F4C40F9307BD9763A55405A0D897B2C0F4C40F9307BD9763A5540401878EE3D0C4C400038F6ECB9385540401878EE3D0C4C40
41097	Большеямное	5	51	38	85.483142999999998	85.497112000000001	55.590389000000002	55.570247999999999	0103000020E61000000100000005000000A5129ED0EB5E5540014EEFE2FDC84B40A5129ED0EB5E55408675E3DD91CB4B40BF9CD9AED05F55408675E3DD91CB4B40BF9CD9AED05F5540014EEFE2FDC84B40A5129ED0EB5E5540014EEFE2FDC84B40
41186	Белянино	5	51	38	85.243167999999997	85.260019999999997	55.542192	55.534077000000003	0103000020E61000000100000005000000C2DB8310904F5540DD4598A25CC44B40C2DB8310904F55409013268C66C54B409413ED2AA45055409013268C66C54B409413ED2AA4505540DD4598A25CC44B40C2DB8310904F5540DD4598A25CC44B40
32160	Безменово	5	51	38	84.734802000000002	84.762084000000002	55.841093999999998	55.830938000000003	0103000020E6100000010000000500000044C2F7FE062F55407880272D5CEA4B4044C2F7FE062F5540506EDBF7A8EB4B408333F8FBC5305540506EDBF7A8EB4B408333F8FBC53055407880272D5CEA4B4044C2F7FE062F55407880272D5CEA4B40
156	Алабучинка	5	51	38	84.651105999999999	84.665317000000002	55.960875999999999	55.946955000000003	0103000020E61000000100000005000000AE0E80B8AB29554050E449D235F94B40AE0E80B8AB29554072C119FCFDFA4B40431EC18D942A554072C119FCFDFA4B40431EC18D942A554050E449D235F94B40AE0E80B8AB29554050E449D235F94B40
30793	Шестаково	5	51	823	87.952360999999996	87.975617999999997	55.903433	55.885866999999998	0103000020E61000000100000005000000183F8D7BF3FC554085CD001764F14B40183F8D7BF3FC554047904AB1A3F34B40E4D87A8670FE554047904AB1A3F34B40E4D87A8670FE554085CD001764F14B40183F8D7BF3FC554085CD001764F14B40
6033	Чумай	5	51	823	87.748999999999995	87.79759	55.752941	55.728676999999998	0103000020E610000001000000050000000E2DB29DEFEF5540772CB64945DD4B400E2DB29DEFEF5540A568E55E60E04B407767EDB60BF35540A568E55E60E04B407767EDB60BF35540772CB64945DD4B400E2DB29DEFEF5540772CB64945DD4B40
30847	Усть-Чебула	5	51	823	87.756501	87.774341000000007	56.139606999999998	56.116934000000001	0103000020E610000001000000050000000B992B836AF055402EE57CB1F70E4C400B992B836AF0554076A565A4DE114C40EDBC8DCD8EF1554076A565A4DE114C40EDBC8DCD8EF155402EE57CB1F70E4C400B992B836AF055402EE57CB1F70E4C40
6016	Усть-Серта	5	51	823	87.973633000000007	88.009754000000001	56.013506999999997	55.996319	0103000020E610000001000000050000009C53C90050FE554014B1886187FF4B409C53C90050FE55402FA2ED98BA014C4055C03DCF9F0056402FA2ED98BA014C4055C03DCF9F00564014B1886187FF4B409C53C90050FE554014B1886187FF4B40
30538	Усманка	5	51	823	87.399986999999996	87.435901000000001	55.964185999999998	55.946919999999999	0103000020E61000000100000005000000CFF4126399D95540D3F6AFAC34F94B40CFF4126399D955406AA164726AFB4B40CCD24ECDE5DB55406AA164726AFB4B40CCD24ECDE5DB5540D3F6AFAC34F94B40CFF4126399D95540D3F6AFAC34F94B40
41091	Покровка	5	51	823	87.680261000000002	87.688552000000001	55.970951999999997	55.954697000000003	0103000020E61000000100000005000000A2EF6E6589EB55406F4BE48233FA4B40A2EF6E6589EB55402EFEB62748FC4B401B66683C11EC55402EFEB62748FC4B401B66683C11EC55406F4BE48233FA4B40A2EF6E6589EB55406F4BE48233FA4B40
30132	Покровка	5	51	823	87.680261000000002	87.688552000000001	55.970951999999997	55.954697000000003	0103000020E61000000100000005000000A2EF6E6589EB55406F4BE48233FA4B40A2EF6E6589EB55402EFEB62748FC4B401B66683C11EC55402EFEB62748FC4B401B66683C11EC55406F4BE48233FA4B40A2EF6E6589EB55406F4BE48233FA4B40
30115	Петропавловка	5	51	823	87.509985	87.519875999999996	55.974820999999999	55.963340000000002	0103000020E61000000100000005000000D61C2098A3E05540DE76A1B94EFB4B40D61C2098A3E055401D3A3DEFC6FC4B406B7EFCA545E155401D3A3DEFC6FC4B406B7EFCA545E15540DE76A1B94EFB4B40D61C2098A3E05540DE76A1B94EFB4B40
30202	Орлово-Розово	5	51	823	87.702637999999993	87.729641000000001	56.063006999999999	56.047339000000001	0103000020E6100000010000000500000051BB5F05F8EC5540A56950340F064C4051BB5F05F8EC5540A435069D10084C4087342A70B2EE5540A435069D10084C4087342A70B2EE5540A56950340F064C4051BB5F05F8EC5540A56950340F064C40
30046	Новоказанка	5	51	823	87.578410000000005	87.606042000000002	56.112704000000001	56.098320999999999	0103000020E610000001000000050000007B6B60AB04E5554048C153C8950C4C407B6B60AB04E555406F10AD156D0E4C4028806264C9E655406F10AD156D0E4C4028806264C9E6554048C153C8950C4C407B6B60AB04E5554048C153C8950C4C40
30370	Новоивановский	5	51	823	87.786081999999993	87.802871999999994	55.865243	55.852536000000001	0103000020E610000001000000050000005A7EE02A4FF25540D2544FE61FED4B405A7EE02A4FF25540E50B5A48C0EE4B40F1B73D4162F35540E50B5A48C0EE4B40F1B73D4162F35540D2544FE61FED4B405A7EE02A4FF25540D2544FE61FED4B40
30640	Николаевка	5	51	823	87.249787999999995	87.289008999999993	55.889543000000003	55.873092	0103000020E61000000100000005000000BABBCE86FCCF55401A33897AC1EF4B40BABBCE86FCCF554060B1868BDCF14B40FACF9A1F7FD2554060B1868BDCF14B40FACF9A1F7FD255401A33897AC1EF4B40BABBCE86FCCF55401A33897AC1EF4B40
30469	Михайловка	5	51	823	87.889362000000006	87.913822999999994	55.915073999999997	55.904231000000003	0103000020E610000001000000050000008813984EEBF85540C38366D7BDF34B408813984EEBF85540BFB5132521F54B4049D576137CFA5540BFB5132521F54B4049D576137CFA5540C38366D7BDF34B408813984EEBF85540C38366D7BDF34B40
30745	Курск-Смоленка	5	51	823	88.079239000000001	88.126992999999999	55.964458	55.948149999999998	0103000020E610000001000000050000005664744012055640E8D9ACFA5CF94B405664744012055640CB2E185C73FB4B408A743FA720085640CB2E185C73FB4B408A743FA720085640E8D9ACFA5CF94B405664744012055640E8D9ACFA5CF94B40
30956	Кураково	5	51	823	87.838571000000002	87.857776999999999	55.759830999999998	55.744374000000001	0103000020E61000000100000005000000F017B325ABF5554011FFB0A547DF4B40F017B325ABF5554055BE672442E14B40B49080D1E5F6554055BE672442E14B40B49080D1E5F6554011FFB0A547DF4B40F017B325ABF5554011FFB0A547DF4B40
31052	Карачарово	5	51	823	87.675759999999997	87.705791000000005	55.750950000000003	55.739477999999998	0103000020E610000001000000050000007AFCDEA63FEB5540450E1137A7DE4B407AFCDEA63FEB554032772D211FE04B40EAB303AE2BED554032772D211FE04B40EAB303AE2BED5540450E1137A7DE4B407AFCDEA63FEB5540450E1137A7DE4B40
30991	Казанка-20	5	51	823	87.498683999999997	87.520576000000005	55.654462000000002	55.644759999999998	0103000020E6100000010000000500000076C24B70EADF55406DE2E47E87D24B4076C24B70EADF5540C53C2B69C5D34B4048C5FF1D51E15540C53C2B69C5D34B4048C5FF1D51E155406DE2E47E87D24B4076C24B70EADF55406DE2E47E87D24B40
30433	Ивановка	5	51	823	87.753356999999994	87.773478999999995	55.891914999999997	55.880550999999997	0103000020E610000001000000050000009C4D470037F05540E4BA29E5B5F04B409C4D470037F05540EAE74D452AF24B40234910AE80F15540EAE74D452AF24B40234910AE80F15540E4BA29E5B5F04B409C4D470037F05540E4BA29E5B5F04B40
41178	Дмитриевка	5	51	823	87.899790999999993	87.917057	56.039887	56.021557999999999	0103000020E610000001000000050000000C8FFD2C96F95540CC7B9C69C2024C400C8FFD2C96F955408D4468041B054C4058E4D70FB1FA55408D4468041B054C4058E4D70FB1FA5540CC7B9C69C2024C400C8FFD2C96F95540CC7B9C69C2024C40
5905	Верх-Чебула	5	51	823	87.587159999999997	87.642199000000005	56.053753	56.016812999999999	0103000020E610000001000000050000003D61890794E55540E692AAED26024C403D61890794E55540EC87D860E1064C4088A1D5C919E95540EC87D860E1064C4088A1D5C919E95540E692AAED26024C403D61890794E55540E692AAED26024C40
41175	Верх-Чебула	5	51	823	87.587159999999997	87.642199000000005	56.053753	56.016812999999999	0103000020E610000001000000050000003D61890794E55540E692AAED26024C403D61890794E55540EC87D860E1064C4088A1D5C919E95540EC87D860E1064C4088A1D5C919E95540E692AAED26024C403D61890794E55540E692AAED26024C40
30574	Боровой	5	51	823	87.384428	87.403273999999996	55.916092999999996	55.906396000000001	0103000020E61000000100000005000000ABEAE5779AD85540D49CBCC804F44B40ABEAE5779AD85540198C118942F54B40EF54C03DCFD95540198C118942F54B40EF54C03DCFD95540D49CBCC804F44B40ABEAE5779AD85540D49CBCC804F44B40
30241	Алчедат	5	51	823	87.901263999999998	87.925600000000003	55.992331	55.977308999999998	0103000020E61000000100000005000000FA43334FAEF95540118B187618FD4B40FA43334FAEF955404BE7C3B304FF4B405E4BC8073DFB55404BE7C3B304FF4B405E4BC8073DFB5540118B187618FD4B40FA43334FAEF95540118B187618FD4B40
46367	Чулым	5	51	1825	89.195701	89.214988000000005	56.056528	56.031497999999999	0103000020E61000000100000005000000D9B27C5D864C5640D8F15F2008044C40D9B27C5D864C564076A73B4F3C074C401442075DC24D564076A73B4F3C074C401442075DC24D5640D8F15F2008044C40D9B27C5D864C5640D8F15F2008044C40
60793	Чернышево	5	51	1825	89.251018999999999	89.267943000000002	55.956083	55.94811	0103000020E610000001000000050000002DEBFEB1105056405A8121AB5BF94B402DEBFEB1105056407BA180ED60FA4B404C8C65FA255156407BA180ED60FA4B404C8C65FA255156405A8121AB5BF94B402DEBFEB1105056405A8121AB5BF94B40
60765	Тёплая Речка	5	51	1825	88.415604000000002	88.434809999999999	56.304659999999998	56.294331	0103000020E610000001000000050000008E058541991A5640789961A3AC254C408E058541991A56401E335019FF264C40527E52EDD31B56401E335019FF264C40527E52EDD31B5640789961A3AC254C408E058541991A5640789961A3AC254C40
41259	Тяжинский	5	51	1825	88.471147000000002	88.547889999999995	56.130372000000001	56.094017999999998	0103000020E61000000100000005000000F226BF45271E56401F9E25C8080C4C40F226BF45271E564035289A07B0104C408CF337A11023564035289A07B0104C408CF337A1102356401F9E25C8080C4C40F226BF45271E56401F9E25C8080C4C40
28921	Тяжино-Вершинка	5	51	1825	88.578657000000007	88.605328	55.925193	55.910220000000002	0103000020E610000001000000050000007FA65EB7082556402315C61682F44B407FA65EB7082556407BBE66B96CF64B4099D6A6B1BD2656407BBE66B96CF64B4099D6A6B1BD2656402315C61682F44B407FA65EB7082556402315C61682F44B40
29257	Тисуль	5	51	1825	88.670760999999999	88.698393999999993	56.081797999999999	56.059192000000003	0103000020E61000000100000005000000AA9B8BBFED2A5640A9177C9A93074C40AA9B8BBFED2A564069705B5B780A4C403F6EBF7CB22C564069705B5B780A4C403F6EBF7CB22C5640A9177C9A93074C40AA9B8BBFED2A5640A9177C9A93074C40
41166	Ступишино	5	51	1825	88.532393999999996	88.583813000000006	56.216558999999997	56.199812000000001	0103000020E610000001000000050000008BA548BE1222564097AC8A7093194C408BA548BE12225640C5538F34B81B4C40B37E33315D255640C5538F34B81B4C40B37E33315D25564097AC8A7093194C408BA548BE1222564097AC8A7093194C40
27949	Старый Урюп	5	51	1825	89.313614000000001	89.343491999999998	55.848488000000003	55.830765999999997	0103000020E6100000010000000500000056647440125456407A50508A56EA4B405664744012545640348639419BEC4B40029CDEC5FB555640348639419BEC4B40029CDEC5FB5556407A50508A56EA4B4056647440125456407A50508A56EA4B40
41154	Старый Тяжин	5	51	1825	88.569385999999994	88.583364000000003	56.140433999999999	56.133170999999997	0103000020E610000001000000050000003733FAD17024564047E350BF0B114C403733FAD1702456408C9FC6BDF9114C407B6AF5D5552556408C9FC6BDF9114C407B6AF5D55525564047E350BF0B114C403733FAD17024564047E350BF0B114C40
29132	Сандайка	5	51	1825	88.452164999999994	88.467769000000004	56.345109999999998	56.327689999999997	0103000020E6100000010000000500000055D97745F01C5640F59CF4BEF1294C4055D97745F01C5640E3C281902C2C4C404A4563EDEF1D5640E3C281902C2C4C404A4563EDEF1D5640F59CF4BEF1294C4055D97745F01C5640F59CF4BEF1294C40
28136	Путятинский	5	51	1825	88.259772999999996	88.271972000000005	56.000225	55.994154000000002	0103000020E6100000010000000500000090D8EE1EA01056400398327040FF4B4090D8EE1EA010564020D26F5F07004C40605B3FFD6711564020D26F5F07004C40605B3FFD671156400398327040FF4B4090D8EE1EA01056400398327040FF4B40
46244	Прокопьево	5	51	1825	88.332851000000005	88.357500999999999	56.369351999999999	56.361882999999999	0103000020E6100000010000000500000038DC476E4D1556403BFDA02E522E4C4038DC476E4D155640295B24ED462F4C4063D2DF4BE1165640295B24ED462F4C4063D2DF4BE11656403BFDA02E522E4C4038DC476E4D1556403BFDA02E522E4C40
46122	Преображенка	5	51	1825	88.553027999999998	88.590191000000004	56.046920999999998	56.026432999999997	0103000020E610000001000000050000006D718DCF642356408044132862034C406D718DCF64235640703FE08101064C4030D978B0C5255640703FE08101064C4030D978B0C52556408044132862034C406D718DCF642356408044132862034C40
45899	Почаевка	5	51	1825	88.403495000000007	88.436291999999995	56.141683	56.130747999999997	0103000020E610000001000000050000005F46B1DCD21956403A02B859BC104C405F46B1DCD219564018B325AB22124C4069E04735EC1B564018B325AB22124C4069E04735EC1B56403A02B859BC104C405F46B1DCD21956403A02B859BC104C40
27930	Новопреображенка	5	51	1825	89.213407000000004	89.236699999999999	55.886139999999997	55.875808999999997	0103000020E61000000100000005000000336FD575A84D56406F4562821AF04B40336FD575A84D5640B6D617096DF14B40A5BDC117264F5640B6D617096DF14B40A5BDC117264F56406F4562821AF04B40336FD575A84D56406F4562821AF04B40
60756	Новопокровка (Маковка)	5	51	1825	88.935890000000001	88.960576000000003	55.961832999999999	55.947580000000002	0103000020E61000000100000005000000D2A92B9FE53B5640FE2B2B4D4AF94B40D2A92B9FE53B5640569BFF571DFB4B40A454C2137A3D5640569BFF571DFB4B40A454C2137A3D5640FE2B2B4D4AF94B40D2A92B9FE53B5640FE2B2B4D4AF94B40
41156	Новоподзорново	5	51	1825	89.071130999999994	89.107612000000003	55.869971	55.848948	0103000020E61000000100000005000000D5AE09698D4456409700FC53AAEC4B40D5AE09698D445640F5BBB0355BEF4B400F2A711DE3465640F5BBB0355BEF4B400F2A711DE34656409700FC53AAEC4B40D5AE09698D4456409700FC53AAEC4B40
60751	Новомарьинка	5	51	1825	88.999904000000001	89.021850000000001	56.092731999999998	56.082506000000002	0103000020E61000000100000005000000EFC8586DFE3F5640A5DC7D8E8F0A4C40EFC8586DFE3F564076A565A4DE0B4C40BADA8AFD6541564076A565A4DE0B4C40BADA8AFD65415640A5DC7D8E8F0A4C40EFC8586DFE3F5640A5DC7D8E8F0A4C40
28281	Нововосточный	5	51	1825	88.533597999999998	88.567266000000004	56.164110000000001	56.133091	0103000020E6100000010000000500000081CD3978262256402B323A2009114C4081CD3978262256402979758E01154C407F880D164E2456402979758E01154C407F880D164E2456402B323A2009114C4081CD3978262256402B323A2009114C40
41158	Малопичугино	5	51	1825	88.869999000000007	88.906487999999996	55.856487000000001	55.841478000000002	0103000020E6100000010000000500000060234910AE375640D926158DB5EB4B4060234910AE3756407E39B35DA1ED4B40DA8D3EE6033A56407E39B35DA1ED4B40DA8D3EE6033A5640D926158DB5EB4B4060234910AE375640D926158DB5EB4B40
45774	Листвянка	5	51	1825	88.383633000000003	88.407735000000002	56.075152000000003	56.064449000000003	0103000020E61000000100000005000000A62A6D718D18564045A165DD3F084C40A62A6D718D185640501DAB949E094C40D09B8A54181A5640501DAB949E094C40D09B8A54181A564045A165DD3F084C40A62A6D718D18564045A165DD3F084C40
27876	Кубитет	5	51	1825	89.115031999999999	89.147892999999996	55.954506000000002	55.936937999999998	0103000020E61000000100000005000000957F2DAF5C47564098309A95EDF74B40957F2DAF5C475640FBEAAA402DFA4B40AB93331477495640FBEAAA402DFA4B40AB9333147749564098309A95EDF74B40957F2DAF5C47564098309A95EDF74B40
41152	Ключевая	5	51	1825	88.308263999999994	88.340145000000007	56.173893	56.166646	0103000020E610000001000000050000002FA2ED98BA1356402E01F8A754154C402FA2ED98BA1356406D00362042164C4078B988EFC41556406D00362042164C4078B988EFC41556402E01F8A754154C402FA2ED98BA1356402E01F8A754154C40
60706	Итатский	5	51	1825	88.991378999999995	89.102384000000001	56.079583	56.057569000000001	0103000020E610000001000000050000003CBCE7C0723F5640B821C66B5E074C403CBCE7C0723F5640A62897C62F0A4C408EE89E758D465640A62897C62F0A4C408EE89E758D465640B821C66B5E074C403CBCE7C0723F5640B821C66B5E074C40
41074	Изындаево	5	51	1825	89.173835999999994	89.200075999999996	55.756639	55.744323000000001	0103000020E6100000010000000500000084B70721204B56408F54DFF945DF4B4084B70721204B564067F0F78BD9E04B40BA2D910BCE4C564067F0F78BD9E04B40BA2D910BCE4C56408F54DFF945DF4B4084B70721204B56408F54DFF945DF4B40
45755	Заря	5	51	1825	88.312755999999993	88.327433999999997	56.044417000000003	56.037512999999997	0103000020E610000001000000050000002DE8BD31041456406116DA39CD044C402DE8BD31041456407731CD74AF054C404D66BCADF41456407731CD74AF054C404D66BCADF41456406116DA39CD044C402DE8BD31041456406116DA39CD044C40
46189	Даниловка	5	51	1825	88.631352000000007	88.662991000000005	56.317082999999997	56.299930000000003	0103000020E61000000100000005000000E9103812682856406E8B321B64264C40E9103812682856400C8FFD2C96284C40B6A2CD716E2A56400C8FFD2C96284C40B6A2CD716E2A56406E8B321B64264C40E9103812682856406E8B321B64264C40
46181	Георгиевка	5	51	1825	88.607483999999999	88.633688000000006	56.284134000000002	56.264667000000003	0103000020E61000000100000005000000F8359204E12656404CAAB69BE0214C40F8359204E126564041D7BE805E244C4088F71C588E28564041D7BE805E244C4088F71C588E2856404CAAB69BE0214C40F8359204E12656404CAAB69BE0214C40
28011	Валерьяновка	5	51	1825	88.377075000000005	88.408732000000001	56.020420999999999	56.004756	0103000020E61000000100000005000000E9482EFF21185640DA3A38D89B004C40E9482EFF211856406893C3279D024C40093543AA281A56406893C3279D024C40093543AA281A5640DA3A38D89B004C40E9482EFF21185640DA3A38D89B004C40
41068	Бороковка	5	51	1825	88.753263000000004	88.785162	56.136220999999999	56.123227	0103000020E610000001000000050000005C92037635305640FA7DFFE6C50F4C405C92037635305640A30392B06F114C40F7031E1840325640A30392B06F114C40F7031E1840325640FA7DFFE6C50F4C405C92037635305640FA7DFFE6C50F4C40
41072	Борисоглебское	5	51	1825	88.621326999999994	88.646739999999994	56.202705999999999	56.191498000000003	0103000020E61000000100000005000000CB4752D2C3275640ED9FA70183184C40CB4752D2C3275640FB592C45F2194C40F6402B3064295640FB592C45F2194C40F6402B3064295640ED9FA70183184C40CB4752D2C3275640ED9FA70183184C40
60786	Большая Покровка	5	51	1825	88.778784000000002	88.801447999999993	55.910341000000003	55.898003000000003	0103000020E610000001000000050000007AA9D898D7315640DE5A26C3F1F24B407AA9D898D73156409E9ACB0D86F44B40745C8DEC4A3356409E9ACB0D86F44B40745C8DEC4A335640DE5A26C3F1F24B407AA9D898D7315640DE5A26C3F1F24B40
27788	Акимо-Анненка	5	51	1825	88.782861999999994	88.814249000000004	56.085636000000001	56.073433999999999	0103000020E61000000100000005000000FED137691A3256400D350A4966094C40FED137691A3256401DAED51EF60A4C403F73D6A71C3456401DAED51EF60A4C403F73D6A71C3456400D350A4966094C40FED137691A3256400D350A4966094C40
41084	Тарасово	5	51	3787	85.128281999999999	85.175766999999993	54.893886000000002	54.875355999999996	0103000020E6100000010000000500000097AAB4C535485540BE2D58AA0B704B4097AAB4C535485540172D40DB6A724B40D32D3BC43F4B5540172D40DB6A724B40D32D3BC43F4B5540BE2D58AA0B704B4097AAB4C535485540BE2D58AA0B704B40
26579	Шишино	5	51	1748	85.212875999999994	85.241640000000004	55.375030000000002	55.355637999999999	0103000020E610000001000000050000009C86A8C29F4D5540809BC58B85AD4B409C86A8C29F4D55406B82A8FB00B04B40F3599E07774F55406B82A8FB00B04B40F3599E07774F5540809BC58B85AD4B409C86A8C29F4D5540809BC58B85AD4B40
27341	Черемичкино	5	51	1748	85.846862000000002	85.869292999999999	55.162875	55.148848000000001	0103000020E61000000100000005000000698EACFC327655409A0986730D934B40698EACFC32765540022B8716D9944B4012691B7FA2775540022B8716D9944B4012691B7FA27755409A0986730D934B40698EACFC327655409A0986730D934B40
27588	Цыпино	5	51	1748	85.486395000000002	85.512842000000006	55.150534999999998	55.136746000000002	0103000020E61000000100000005000000077C7E18215F5540EEED96E480914B40077C7E18215F5540A1F31ABB44934B40FA804067D2605540A1F31ABB44934B40FA804067D2605540EEED96E480914B40077C7E18215F5540EEED96E480914B40
26409	Центральный	5	51	1748	85.331695999999994	85.357909000000006	55.251849999999997	55.239060000000002	0103000020E61000000100000005000000B20DDC813A55554011E4A084999E4B40B20DDC813A555540B1BFEC9E3CA04B406C7C26FBE7565540B1BFEC9E3CA04B406C7C26FBE756554011E4A084999E4B40B20DDC813A55554011E4A084999E4B40
27003	Хорошеборка	5	51	1748	85.414385999999993	85.447579000000005	55.523417000000002	55.513182999999998	0103000020E61000000100000005000000E57ADB4C855A55407CEE04FBAFC14B40E57ADB4C855A5540D1950854FFC24B4017D86322A55C5540D1950854FFC24B4017D86322A55C55407CEE04FBAFC14B40E57ADB4C855A55407CEE04FBAFC14B40
26156	Усть-Сосново	5	51	1748	84.980868000000001	85.004782000000006	55.231858000000003	55.21275	0103000020E61000000100000005000000596C938AC63E5540AC1C5A643B9B4B40596C938AC63E554072A8DF85AD9D4B40026729594E40554072A8DF85AD9D4B40026729594E405540AC1C5A643B9B4B40596C938AC63E5540AC1C5A643B9B4B40
26035	Тыхта	5	51	1748	85.245188999999996	85.270691999999997	55.141413	55.122148000000003	0103000020E61000000100000005000000B115342DB14F5540CBA2B08BA28F4B40B115342DB14F5540581D39D219924B407CD2890453515540581D39D219924B407CD2890453515540CBA2B08BA28F4B40B115342DB14F5540CBA2B08BA28F4B40
27442	Трещевский	5	51	1748	85.755449999999996	85.785893999999999	55.131079	55.117401000000001	0103000020E61000000100000005000000D8F0F44A5970554044C2F7FE068F4B40D8F0F44A59705540A0185932C7904B40D90759164C725540A0185932C7904B40D90759164C72554044C2F7FE068F4B40D8F0F44A5970554044C2F7FE068F4B40
24390	Топки	5	51	1748	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
26834	Терехино	5	51	1748	85.484122999999997	85.511018000000007	55.350264000000003	55.342467999999997	0103000020E61000000100000005000000730F09DFFB5E554098F6CDFDD5AB4B40730F09DFFB5E5540AB7B6473D5AC4B40B66AD784B4605540AB7B6473D5AC4B40B66AD784B460554098F6CDFDD5AB4B40730F09DFFB5E554098F6CDFDD5AB4B40
25880	Среднеберезовский	5	51	1748	85.193310999999994	85.208186999999995	55.208004000000003	55.199793999999997	0103000020E6100000010000000500000040BD19355F4C5540F0F78BD992994B4040BD19355F4C5540F6B704E09F9A4B40F31C91EF524D5540F6B704E09F9A4B40F31C91EF524D5540F0F78BD992994B4040BD19355F4C5540F0F78BD992994B40
26722	Симаново	5	51	1748	85.324698999999995	85.350156999999996	55.395333000000001	55.376514	0103000020E61000000100000005000000CF8250DEC75455403A3E5A9C31B04B40CF8250DEC7545540C90391459AB24B40CADDE7F868565540C90391459AB24B40CADDE7F8685655403A3E5A9C31B04B40CF8250DEC75455403A3E5A9C31B04B40
26353	Романовский	5	51	1748	84.995304000000004	85.008285000000001	55.277467000000001	55.266916999999999	0103000020E61000000100000005000000FE648C0FB33F55408BDF14562AA24B40FE648C0FB33F5540105CE50984A34B400803CFBD87405540105CE50984A34B400803CFBD874055408BDF14562AA24B40FE648C0FB33F55408BDF14562AA24B40
41138	Рассвет	5	51	1748	85.416848000000002	85.446680999999998	55.358063999999999	55.347422999999999	0103000020E61000000100000005000000CBD93BA3AD5A554069705B5B78AC4B40CBD93BA3AD5A5540FEEF880AD5AD4B40A7AFE76B965C5540FEEF880AD5AD4B40A7AFE76B965C554069705B5B78AC4B40CBD93BA3AD5A554069705B5B78AC4B40
41140	Раздолье	5	51	1748	85.300883999999996	85.326476999999997	55.491956999999999	55.477137999999997	0103000020E61000000100000005000000F0F8F6AE41535540E4D6A4DB12BD4B40F0F8F6AE41535540E6046D72F8BE4B405B79C9FFE4545540E6046D72F8BE4B405B79C9FFE4545540E4D6A4DB12BD4B40F0F8F6AE41535540E4D6A4DB12BD4B40
27411	Пинигино	5	51	1748	85.980504999999994	86.002217000000002	55.091071999999997	55.077246000000002	0103000020E6100000010000000500000020240B98C07E554098DF6932E3894B4020240B98C07E554068CA4E3FA88B4B40B29FC5522480554068CA4E3FA88B4B40B29FC5522480554098DF6932E3894B4020240B98C07E554098DF6932E3894B40
27077	Опарино	5	51	1748	85.206247000000005	85.240696999999997	55.436872000000001	55.426166000000002	0103000020E610000001000000050000007BF99D26334D55406555849B8CB64B407BF99D26334D5540E144F46BEBB74B40B3CF6394674F5540E144F46BEBB74B40B3CF6394674F55406555849B8CB64B407BF99D26334D55406555849B8CB64B40
41142	Октябрьский	5	51	1748	85.589907999999994	85.603446000000005	55.327238999999999	55.315950000000001	0103000020E6100000010000000500000085E97B0DC1655540EA95B20C71A84B4085E97B0DC1655540E57CB1F7E2A94B40BBB9F8DB9E665540E57CB1F7E2A94B40BBB9F8DB9E665540EA95B20C71A84B4085E97B0DC1655540EA95B20C71A84B40
27635	Мокроусовский	5	51	1748	85.555628999999996	85.578536	55.182341000000001	55.172716999999999	0103000020E6100000010000000500000063EDEF6C8F6355404B3B35971B964B4063EDEF6C8F63554027DC2BF356974B40C1E3DBBB0665554027DC2BF356974B40C1E3DBBB066555404B3B35971B964B4063EDEF6C8F6355404B3B35971B964B40
27287	Медынино	5	51	1748	85.602942999999996	85.637698999999998	55.565361000000003	55.542487000000001	0103000020E6100000010000000500000089963C9E96665540A9C0C93670C54B4089963C9E9666554089B7CEBF5DC84B40486C770FD068554089B7CEBF5DC84B40486C770FD0685540A9C0C93670C54B4089963C9E96665540A9C0C93670C54B40
27568	Малый Корчуган	5	51	1748	85.568258999999998	85.590329999999994	55.241827000000001	55.232858999999998	0103000020E61000000100000005000000172AFF5A5E64554025CADE52CE9D4B40172AFF5A5E6455401825E82FF49E4B4040F67AF7C76555401825E82FF49E4B4040F67AF7C765554025CADE52CE9D4B40172AFF5A5E64554025CADE52CE9D4B40
25954	Магистральный	5	51	1748	85.280671999999996	85.300246000000001	55.188102999999998	55.175848000000002	0103000020E61000000100000005000000C939B187F65155409488F02F82964B40C939B187F6515540C6A354C213984B404FB0FF3A37535540C6A354C213984B404FB0FF3A375355409488F02F82964B40C939B187F65155409488F02F82964B40
41137	Лукошкино	5	51	1748	85.175983000000002	85.218491	55.275230999999998	55.264245000000003	0103000020E61000000100000005000000BA69334E434B5540D690B8C7D2A14B40BA69334E434B554035ECF7C43AA34B401ADEACC1FB4D554035ECF7C43AA34B401ADEACC1FB4D5540D690B8C7D2A14B40BA69334E434B5540D690B8C7D2A14B40
26636	Комсомольский	5	51	1748	85.171069000000003	85.183464999999998	55.379716000000002	55.373894	0103000020E61000000100000005000000011764CBF24A5540D71533C2DBAF4B40011764CBF24A55404CE2AC889AB04B407BBDFBE3BD4B55404CE2AC889AB04B407BBDFBE3BD4B5540D71533C2DBAF4B40011764CBF24A5540D71533C2DBAF4B40
60767	Кокуй	5	51	1748	85.013261999999997	85.021507999999997	55.336559000000001	55.326379000000003	0103000020E61000000100000005000000E411DC48D9405540F48C7DC9C6A94B40E411DC48D94055405516855D14AB4B408D261763604155405516855D14AB4B408D26176360415540F48C7DC9C6A94B40E411DC48D9405540F48C7DC9C6A94B40
26552	Козлово	5	51	1748	85.249033999999995	85.263666999999998	55.239527000000002	55.227950999999997	0103000020E61000000100000005000000E4654D2CF04F5540950B957F2D9D4B40E4654D2CF04F554027C11BD2A89E4B4034828DEBDF50554027C11BD2A89E4B4034828DEBDF505540950B957F2D9D4B40E4654D2CF04F5540950B957F2D9D4B40
26837	Ключевой	5	51	1748	85.362257	85.375929999999997	55.330275999999998	55.320785000000001	0103000020E61000000100000005000000D0EFFB372F57554010069E7B0FA94B40D0EFFB372F575540AC53E57B46AA4B4075E5B33C0F585540AC53E57B46AA4B4075E5B33C0F58554010069E7B0FA94B40D0EFFB372F57554010069E7B0FA94B40
26136	Катково	5	51	1748	85.047982000000005	85.070098000000002	55.151909000000003	55.139406000000001	0103000020E61000000100000005000000FD32182312435540DF6E490ED8914B40FD32182312435540EA7B0DC171934B40F660527C7C445540EA7B0DC171934B40F660527C7C445540DF6E490ED8914B40FD32182312435540DF6E490ED8914B40
27485	Знаменский	5	51	1748	85.689756000000003	85.706393000000006	55.198405999999999	55.190677999999998	0103000020E61000000100000005000000118E59F6246C55408908FF2268984B40118E59F6246C554043AA285E65994B40E547FC8A356D554043AA285E65994B40E547FC8A356D55408908FF2268984B40118E59F6246C55408908FF2268984B40
27125	Зарубино	5	51	1748	85.511889999999994	85.556482000000003	55.469662999999997	55.444496999999998	0103000020E61000000100000005000000904946CEC2605540C6151747E5B84B40904946CEC26055401492CCEA1DBC4B4003B4AD669D6355401492CCEA1DBC4B4003B4AD669D635540C6151747E5B84B40904946CEC2605540C6151747E5B84B40
27187	Глубокое	5	51	1748	85.690870000000004	85.7346	55.535227999999996	55.512740000000001	0103000020E6100000010000000500000067F2CD36376C5540EFACDD76A1C14B4067F2CD36376C5540A5F3E15982C44B4010E9B7AF036F5540A5F3E15982C44B4010E9B7AF036F5540EFACDD76A1C14B4067F2CD36376C5540EFACDD76A1C14B40
25833	Верх-Падунский	5	51	1748	85.194901000000002	85.216037999999998	55.162633	55.150416999999997	0103000020E610000001000000050000004B3D0B42794C554097E13FDD40934B404B3D0B42794C55400C207C28D1944B405E2C0C91D34D55400C207C28D1944B405E2C0C91D34D554097E13FDD40934B404B3D0B42794C554097E13FDD40934B40
41065	Большой Корчуган	5	51	1748	85.383987000000005	85.400453999999996	55.213766999999997	55.204191999999999	0103000020E61000000100000005000000B5C5353E935855406B0DA5F6229A4B40B5C5353E9358554065FB90B75C9B4B405A63D009A159554065FB90B75C9B4B405A63D009A15955406B0DA5F6229A4B40B5C5353E935855406B0DA5F6229A4B40
26204	Бархатово	5	51	1748	85.035000999999994	85.067717999999999	55.364972000000002	55.356344	0103000020E61000000100000005000000F294D5743D4255401B1021AE9CAD4B40F294D5743D42554055FA0967B7AE4B406FD6E07D5544554055FA0967B7AE4B406FD6E07D554455401B1021AE9CAD4B40F294D5743D4255401B1021AE9CAD4B40
41120	Центральный	5	51	860	87.630691999999996	87.661810000000003	55.223751	55.197245000000002	0103000020E610000001000000050000005376FA415DE855405726FC523F994B405376FA415DE8554041B96DDFA39C4B409C8A54185BEA554041B96DDFA39C4B409C8A54185BEA55405726FC523F994B405376FA415DE855405726FC523F994B40
24542	Утинка	5	51	860	88.330326999999997	88.345230000000001	55.745443000000002	55.735205999999998	0103000020E61000000100000005000000177FDB132415564057E9EE3A1BDE4B40177FDB13241556401D041DAD6ADF4B4047E6913F181656401D041DAD6ADF4B4047E6913F1816564057E9EE3A1BDE4B40177FDB132415564057E9EE3A1BDE4B40
24004	Усть-Колба	5	51	860	88.285347999999999	88.309549000000004	55.892496000000001	55.872238000000003	0103000020E61000000100000005000000A8FE4124431256400B2AAA7EA5EF4B40A8FE412443125640C9E7154F3DF24B409CE09BA6CF135640C9E7154F3DF24B409CE09BA6CF1356400B2AAA7EA5EF4B40A8FE4124431256400B2AAA7EA5EF4B40
23762	Усть-Барандат	5	51	860	88.672844999999995	88.699274000000003	55.826037999999997	55.807046	0103000020E61000000100000005000000BC9179E40F2B56400E2F88484DE74B40BC9179E40F2B56406AA0F99CBBE94B405C3CBCE7C02C56406AA0F99CBBE94B405C3CBCE7C02C56400E2F88484DE74B40BC9179E40F2B56400E2F88484DE74B40
24285	Третьяково	5	51	860	88.435492999999994	88.463223999999997	55.798423999999997	55.788814000000002	0103000020E61000000100000005000000C328081EDF1B564040506EDBF7E44B40C328081EDF1B5640B62BF4C132E64B403AAE4676A51D5640B62BF4C132E64B403AAE4676A51D564040506EDBF7E44B40C328081EDF1B564040506EDBF7E44B40
22614	Тисуль	5	51	860	88.285230999999996	88.336543000000006	55.782228000000003	55.739548999999997	0103000020E610000001000000050000008B338639411256400E65A88AA9DE4B408B33863941125640FC010F0C20E44B40A8ACA6EB89155640FC010F0C20E44B40A8ACA6EB891556400E65A88AA9DE4B408B338639411256400E65A88AA9DE4B40
41103	Тисуль	5	51	860	88.285230999999996	88.336543000000006	55.782228000000003	55.739548999999997	0103000020E610000001000000050000008B338639411256400E65A88AA9DE4B408B33863941125640FC010F0C20E44B40A8ACA6EB89155640FC010F0C20E44B40A8ACA6EB891556400E65A88AA9DE4B408B338639411256400E65A88AA9DE4B40
24186	Тамбар	5	51	860	88.599290999999994	88.637703000000002	55.604793000000001	55.585234999999997	0103000020E610000001000000050000006072A3C85A265640BEBC00FBE8CA4B406072A3C85A265640C4EC65DB69CD4B40E9633E20D0285640C4EC65DB69CD4B40E9633E20D0285640BEBC00FBE8CA4B406072A3C85A265640BEBC00FBE8CA4B40
60792	Серебряково	5	51	860	89.005212999999998	89.041872999999995	55.699486999999998	55.685411000000002	0103000020E61000000100000005000000E620E86855405640CAA8328CBBD74B40E620E86855405640137D3ECA88D94B407765170CAE425640137D3ECA88D94B407765170CAE425640CAA8328CBBD74B40E620E86855405640CAA8328CBBD74B40
23116	Ржавчик	5	51	860	88.268945000000002	88.281890000000004	55.697477999999997	55.688999000000003	0103000020E610000001000000050000000EDB16653611564005FD851E31D84B400EDB166536115640F9D687F546D94B4072C45A7C0A125640F9D687F546D94B4072C45A7C0A12564005FD851E31D84B400EDB16653611564005FD851E31D84B40
6457	Полуторник	5	51	860	88.463897000000003	88.486570999999998	55.332253000000001	55.316522999999997	0103000020E610000001000000050000009AED0A7DB01D564045B75ED383A84B409AED0A7DB01D5640BB7F2C4487AA4B40A60BB1FA231F5640BB7F2C4487AA4B40A60BB1FA231F564045B75ED383A84B409AED0A7DB01D564045B75ED383A84B40
23521	Новый Берикуль	5	51	860	88.106223999999997	88.137674000000004	55.497622999999997	55.481265	0103000020E610000001000000050000003883BF5FCC065640CFDA6D179ABD4B403883BF5FCC065640635E471CB2BF4B409CE09BA6CF085640635E471CB2BF4B409CE09BA6CF085640CFDA6D179ABD4B403883BF5FCC065640CFDA6D179ABD4B40
23565	Московка	5	51	860	88.082616000000002	88.095031000000006	55.370620000000002	55.358303999999997	0103000020E6100000010000000500000016889E94490556405303CDE7DCAD4B4016889E94490556402C9FE57970AF4B40CC46E7FC140656402C9FE57970AF4B40CC46E7FC140656405303CDE7DCAD4B4016889E94490556405303CDE7DCAD4B40
23330	Макаракский	5	51	860	88.030325000000005	88.056124999999994	55.606755999999997	55.590577000000003	0103000020E6100000010000000500000014D044D8F00156408962F20698CB4B4014D044D8F00156406D533C2EAACD4B403BDF4F8D970356406D533C2EAACD4B403BDF4F8D970356408962F20698CB4B4014D044D8F00156408962F20698CB4B40
23923	Листвянка	5	51	860	88.196909000000005	88.214883999999998	55.932082000000001	55.919367000000001	0103000020E6100000010000000500000070D234289A0C5640C5025FD1ADF54B4070D234289A0C56405B9885764EF74B40C11BD2A8C00D56405B9885764EF74B40C11BD2A8C00D5640C5025FD1ADF54B4070D234289A0C5640C5025FD1ADF54B40
23857	Куликовка	5	51	860	88.117947000000001	88.145129999999995	55.801141000000001	55.789825999999998	0103000020E6100000010000000500000053EA92718C075640E7C3B30419E54B4053EA92718C0756400C3ECDC98BE64B40C8EA56CF490956400C3ECDC98BE64B40C8EA56CF49095640E7C3B30419E54B4053EA92718C075640E7C3B30419E54B40
24615	Кондрашка	5	51	860	88.400422000000006	88.416556	55.728434	55.717548000000001	0103000020E6100000010000000500000055A69883A0195640B5A7E49CD8DB4B4055A69883A0195640B1A547533DDD4B40F73C7FDAA81A5640B1A547533DDD4B40F73C7FDAA81A5640B5A7E49CD8DB4B4055A69883A0195640B5A7E49CD8DB4B40
23209	Комсомольск	5	51	860	88.142660000000006	88.226795999999993	55.651840999999997	55.603603	0103000020E61000000100000005000000A29C6857210956403D62F4DC42CD4B40A29C6857210956409198A0866FD34B4045B75ED3830E56409198A0866FD34B4045B75ED3830E56403D62F4DC42CD4B40A29C6857210956403D62F4DC42CD4B40
41106	Комсомольск	5	51	860	88.142660000000006	88.226795999999993	55.651840999999997	55.603603	0103000020E61000000100000005000000A29C6857210956403D62F4DC42CD4B40A29C6857210956409198A0866FD34B4045B75ED3830E56409198A0866FD34B4045B75ED3830E56403D62F4DC42CD4B40A29C6857210956403D62F4DC42CD4B40
23914	Колба	5	51	860	88.194879	88.223220999999995	55.831848000000001	55.820981000000003	0103000020E6100000010000000500000057EBC4E5780C564096D1C8E715E94B4057EBC4E5780C56401B9FC9FE79EA4B40F2B1BB40490E56401B9FC9FE79EA4B40F2B1BB40490E564096D1C8E715E94B4057EBC4E5780C564096D1C8E715E94B40
24445	Кайчак	5	51	860	88.547881000000004	88.568353000000002	55.743436000000003	55.728189999999998	0103000020E610000001000000050000006346787B102356401AA3755435DD4B406346787B10235640A4552DE928DF4B4058E542E55F245640A4552DE928DF4B4058E542E55F2456401AA3755435DD4B406346787B102356401AA3755435DD4B40
24340	Дворниково	5	51	860	88.399596000000003	88.414013999999995	55.804212999999997	55.792225000000002	0103000020E6100000010000000500000032E719FB921956406C09F9A067E54B4032E719FB921956404F029B73F0E64B40838593347F1A56404F029B73F0E64B40838593347F1A56406C09F9A067E54B4032E719FB921956406C09F9A067E54B40
41220	Вознесенка	5	51	860	88.701915	88.730266	55.776603000000001	55.76014	0103000020E610000001000000050000009964E42CEC2C5640D3307C444CE14B409964E42CEC2C5640DD7C23BA67E34B405ED89AADBC2E5640DD7C23BA67E34B405ED89AADBC2E5640D3307C444CE14B409964E42CEC2C5640D3307C444CE14B40
24639	Большой Берчикуль	5	51	860	88.293064999999999	88.312109000000007	55.645150999999998	55.627122	0103000020E610000001000000050000008BA6B393C1125640124DA08845D04B408BA6B393C1125640A8FDD64E94D24B4063F20698F9135640A8FDD64E94D24B4063F20698F9135640124DA08845D04B408BA6B393C1125640124DA08845D04B40
23616	Большой Барандат	5	51	860	88.743191999999993	88.770680999999996	55.767712000000003	55.747540000000001	0103000020E6100000010000000500000086A92D75902F5640D6390664AFDF4B4086A92D75902F5640965F066344E24B4082A966D652315640965F066344E24B4082A966D652315640D6390664AFDF4B4086A92D75902F5640D6390664AFDF4B40
24252	Большепичугино	5	51	860	88.876582999999997	88.895583000000002	55.662882000000003	55.652867000000001	0103000020E61000000100000005000000B14E95EF193856409ED1562591D34B40B14E95EF19385640B58D3F51D9D44B40A1F65B3B51395640B58D3F51D9D44B40A1F65B3B513956409ED1562591D34B40B14E95EF193856409ED1562591D34B40
23387	Большая Натальевка	5	51	860	87.923085	87.942012000000005	55.523932000000002	55.511617999999999	0103000020E61000000100000005000000679B1BD313FB5540C005D9B27CC14B40679B1BD313FB5540F8A92A3410C34B40221CB3EC49FC5540F8A92A3410C34B40221CB3EC49FC5540C005D9B27CC14B40679B1BD313FB5540C005D9B27CC14B40
23486	Берикульский	5	51	860	88.105919	88.152244999999994	55.538671999999998	55.513294999999999	0103000020E610000001000000050000009A417C60C7065640A4198BA6B3C14B409A417C60C7065640ADA23F34F3C44B40B0FECF61BE095640ADA23F34F3C44B40B0FECF61BE095640A4198BA6B3C14B409A417C60C7065640A4198BA6B3C14B40
23148	Белогорск	5	51	860	88.470500000000001	88.494996999999998	55.033507	55.009512000000001	0103000020E61000000100000005000000273108AC1C1E5640B47570B037814B40273108AC1C1E5640F29716F549844B408FA7E507AE1F5640F29716F549844B408FA7E507AE1F5640B47570B037814B40273108AC1C1E5640B47570B037814B40
24522	Байла	5	51	860	88.495679999999993	88.507447999999997	55.748609999999999	55.740740000000002	0103000020E6100000010000000500000000529B38B91F5640666B7D91D0DE4B4000529B38B91F5640B2BAD573D2DF4B40EB1A2D077A205640B2BAD573D2DF4B40EB1A2D077A205640666B7D91D0DE4B4000529B38B91F5640666B7D91D0DE4B40
21993	Шерегеш	5	51	1653	87.966571999999999	88.018369000000007	52.934134	52.905808999999998	0103000020E61000000100000005000000AD4ECE50DCFD554013B69F8CF1734A40AD4ECE50DCFD5540740AF2B391774A40A8902BF52C015640740AF2B391774A40A8902BF52C01564013B69F8CF1734A40AD4ECE50DCFD554013B69F8CF1734A40
22225	Чугунаш	5	51	1653	87.741417999999996	87.789648999999997	52.935529000000002	52.860314000000002	0103000020E610000001000000050000009BAA7B6473EF55403E25E7C41E6E4A409BAA7B6473EF5540D4BA0D6ABF774A406C94F59B89F25540D4BA0D6ABF774A406C94F59B89F255403E25E7C41E6E4A409BAA7B6473EF55403E25E7C41E6E4A40
22366	Центральный	5	51	1653	87.659627	87.675527000000002	53.044176	53.030628	0103000020E61000000100000005000000C0232A5437EA5540C32B499EEB834A40C0232A5437EA554051A2258FA7854A40292499D53BEB554051A2258FA7854A40292499D53BEB5540C32B499EEB834A40C0232A5437EA5540C32B499EEB834A40
21910	Темиртау	5	51	1653	87.411009000000007	87.478804999999994	53.156457000000003	53.125166	0103000020E610000001000000050000002657B1F84DDA55401B49827005904A402657B1F84DDA55407A1D71C806944A40520ABABDA4DE55407A1D71C806944A40520ABABDA4DE55401B49827005904A402657B1F84DDA55401B49827005904A40
20973	Таштагол	5	51	1653	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
22585	Спасск	5	51	1653	87.731275999999994	87.775499999999994	52.755122	52.739499000000002	0103000020E610000001000000050000006116DA39CDEE55405D363AE7A75E4A406116DA39CDEE5540BC3E73D6A7604A401283C0CAA1F15540BC3E73D6A7604A401283C0CAA1F155405D363AE7A75E4A406116DA39CDEE55405D363AE7A75E4A40
21748	Мундыбаш	5	51	1653	87.249716000000006	87.319964999999996	53.230103999999997	53.185524000000001	0103000020E610000001000000050000006E52D158FBCF5540C24F1C40BF974A406E52D158FBCF5540E256410C749D4A4056B77A4E7AD45540E256410C749D4A4056B77A4E7AD45540C24F1C40BF974A406E52D158FBCF5540C24F1C40BF974A40
22307	Калары	5	51	1653	87.555448999999996	87.586647999999997	52.923386000000001	52.911755999999997	0103000020E610000001000000050000002366F6798CE3554044F7AC6BB4744A402366F6798CE35540C9CA2F8331764A40E2900DA48BE55540C9CA2F8331764A40E2900DA48BE5554044F7AC6BB4744A402366F6798CE3554044F7AC6BB4744A40
21581	Каз	5	51	1653	87.52664	87.631797000000006	53.124673999999999	53.099269	0103000020E61000000100000005000000FD304278B4E15540D940BAD8B48C4A40FD304278B4E15540AC545051F58F4A40802DAF5C6FE85540AC545051F58F4A40802DAF5C6FE85540D940BAD8B48C4A40FD304278B4E15540D940BAD8B48C4A40
28829	Веселая Грива	5	51	1653	87.389511999999996	87.392871999999997	52.978749000000001	52.976368000000001	0103000020E610000001000000050000009259BDC3EDD85540336E6AA0F97C4A409259BDC3EDD8554011FFB0A5477D4A40E7E099D024D9554011FFB0A5477D4A40E7E099D024D95540336E6AA0F97C4A409259BDC3EDD85540336E6AA0F97C4A40
22396	Базанча	5	51	1653	87.599242000000004	87.623676000000003	52.895265000000002	52.872388000000001	0103000020E61000000100000005000000F0181EFB59E6554020B6F468AA6F4A40F0181EFB59E655407120240B98724A4035D3BD4EEAE755407120240B98724A4035D3BD4EEAE7554020B6F468AA6F4A40F0181EFB59E6554020B6F468AA6F4A40
22426	Амзас	5	51	1653	87.528229999999994	87.553724000000003	53.019660000000002	53.009399999999999	0103000020E6100000010000000500000007B13385CEE155408C4AEA0434814A4007B13385CEE155400A85083884824A40A9C0C93670E355400A85083884824A40A9C0C93670E355408C4AEA0434814A4007B13385CEE155408C4AEA0434814A40
22494	Алтамаш	5	51	1653	87.667091999999997	87.697383000000002	52.564267000000001	52.538781999999998	0103000020E6100000010000000500000016DBA4A2B1EA554034D6FECEF6444A4016DBA4A2B1EA5540249BABE639484A4054724EECA1EC5540249BABE639484A4054724EECA1EC554034D6FECEF6444A4016DBA4A2B1EA554034D6FECEF6444A40
20674	Шуринка	5	51	868	85.280034000000001	85.300713999999999	54.841185000000003	54.823703999999999	0103000020E6100000010000000500000028F1B913EC515540CDCAF6216F694B4028F1B913EC515540617138F3AB6B4B40C2DCEEE53E535540617138F3AB6B4B40C2DCEEE53E535540CDCAF6216F694B4028F1B913EC515540CDCAF6216F694B40
20177	Цветущий	5	51	868	85.985149000000007	85.996054999999998	54.899504	54.891598000000002	0103000020E61000000100000005000000FA2B64AE0C7F5540EA961DE21F724B40FA2B64AE0C7F5540834F73F222734B401B81785DBF7F5540834F73F222734B401B81785DBF7F5540EA961DE21F724B40FA2B64AE0C7F5540EA961DE21F724B40
46423	Ушаково	5	51	868	85.843134000000006	85.863814000000005	54.938265000000001	54.919843999999998	0103000020E6100000010000000500000053094FE8F5755540FEB5BC72BD754B4053094FE8F5755540A0FD481119784B40EDF483BA48775540A0FD481119784B40EDF483BA48775540FEB5BC72BD754B4053094FE8F5755540FEB5BC72BD754B40
41147	Уфимцево	5	51	868	85.620478000000006	85.640933000000004	54.994686999999999	54.979804999999999	0103000020E61000000100000005000000CD785BE9B567554088BA0F406A7D4B40CD785BE9B5675540D06053E7517F4B40577BD80B05695540D06053E7517F4B40577BD80B0569554088BA0F406A7D4B40CD785BE9B567554088BA0F406A7D4B40
20971	Усть-Тарсьма	5	51	868	85.421726000000007	85.448468000000005	55.010905999999999	54.995533999999999	0103000020E61000000100000005000000DE770C8FFD5A55402D077AA86D7F4B40DE770C8FFD5A554043AA285E65814B405D5320B3B35C554043AA285E65814B405D5320B3B35C55402D077AA86D7F4B40DE770C8FFD5A55402D077AA86D7F4B40
41172	Усть-Каменка	5	51	868	85.174634999999995	85.199742999999998	55.013120999999998	54.998317999999998	0103000020E610000001000000050000002A6F47382D4B55400A815CE2C87F4B402A6F47382D4B554006F2ECF2AD814B40B726DD96C84C554006F2ECF2AD814B40B726DD96C84C55400A815CE2C87F4B402A6F47382D4B55400A815CE2C87F4B40
47139	Труд	5	51	868	85.913499000000002	85.931331	54.868772	54.855558000000002	0103000020E61000000100000005000000707B82C4767A554064EAAEEC826D4B40707B82C4767A55401BD7BFEB336F4B4010B056ED9A7B55401BD7BFEB336F4B4010B056ED9A7B554064EAAEEC826D4B40707B82C4767A554064EAAEEC826D4B40
47318	Титово	5	51	868	85.234481000000002	85.293796999999998	55.034714000000001	55.010998999999998	0103000020E6100000010000000500000023A298BC014F5540F4A44C6A68814B4023A298BC014F55404F5B238271844B406DAAEE91CD5255404F5B238271844B406DAAEE91CD525540F4A44C6A68814B4023A298BC014F5540F4A44C6A68814B40
47211	Тарасово	5	51	868	85.128281999999999	85.175766999999993	54.893886000000002	54.875355999999996	0103000020E6100000010000000500000097AAB4C535485540BE2D58AA0B704B4097AAB4C535485540172D40DB6A724B40D32D3BC43F4B5540172D40DB6A724B40D32D3BC43F4B5540BE2D58AA0B704B4097AAB4C535485540BE2D58AA0B704B40
19535	Соревнование	5	51	868	85.890511000000004	85.906932999999995	55.059224	55.048786	0103000020E610000001000000050000009C6ED921FE7855405740A19E3E864B409C6ED921FE785540B491EBA694874B4071AAB5300B7A5540B491EBA694874B4071AAB5300B7A55405740A19E3E864B409C6ED921FE7855405740A19E3E864B40
18845	Ранний	5	51	868	85.438246000000007	85.447515999999993	54.891871999999999	54.884943	0103000020E610000001000000050000009566F3380C5C55407DE9EDCF45714B409566F3380C5C5540EB1B98DC28724B40F31B261AA45C5540EB1B98DC28724B40F31B261AA45C55407DE9EDCF45714B409566F3380C5C55407DE9EDCF45714B40
18954	Пьяново	5	51	868	85.266109999999998	85.307845999999998	54.929777000000001	54.912278000000001	0103000020E61000000100000005000000DEC83CF2075155401E6E8786C5744B40DEC83CF20751554058C9C7EE02774B40158DB5BFB353554058C9C7EE02774B40158DB5BFB35355401E6E8786C5744B40DEC83CF2075155401E6E8786C5744B40
41162	Пушкино	5	51	868	85.489935000000003	85.506967000000003	54.780422999999999	54.772271000000003	0103000020E610000001000000050000009C8A54185B5F55401A53B0C6D9624B409C8A54185B5F5540EA059FE6E4634B40AE49B72572605540EA059FE6E4634B40AE49B725726055401A53B0C6D9624B409C8A54185B5F55401A53B0C6D9624B40
41079	Протопопово	5	51	868	85.999844999999993	86.027683999999994	54.880054000000001	54.866574999999997	0103000020E610000001000000050000006C04E275FD7F5540FE43FAEDEB6E4B406C04E275FD7F5540645B069CA5704B40D6A71C93C5815540645B069CA5704B40D6A71C93C5815540FE43FAEDEB6E4B406C04E275FD7F5540FE43FAEDEB6E4B40
17693	Промышленная	5	51	868	85.609607999999994	85.670351999999994	54.943824999999997	54.891379999999998	0103000020E6100000010000000500000051D845D1036755407C2766BD18724B4051D845D103675540D712F241CF784B40B933130CE76A5540D712F241CF784B40B933130CE76A55407C2766BD18724B4051D845D1036755407C2766BD18724B40
41062	Промышленная	5	51	868	85.609607999999994	85.670351999999994	54.943824999999997	54.891379999999998	0103000020E6100000010000000500000051D845D1036755407C2766BD18724B4051D845D103675540D712F241CF784B40B933130CE76A5540D712F241CF784B40B933130CE76A55407C2766BD18724B4051D845D1036755407C2766BD18724B40
46348	Прогресс	5	51	868	85.336826000000002	85.359534999999994	54.764074999999998	54.751002999999997	0103000020E61000000100000005000000529CA38E8E5555405419C6DD20604B40529CA38E8E5555407958A835CD614B401CB1169F025755407958A835CD614B401CB1169F025755405419C6DD20604B40529CA38E8E5555405419C6DD20604B40
46444	Портнягино	5	51	868	85.698182000000003	85.710768000000002	54.971181000000001	54.957138	0103000020E61000000100000005000000FA298E03AF6C554022E17B7F837A4B40FA298E03AF6C554090BFB4A84F7C4B40C6C210397D6D554090BFB4A84F7C4B40C6C210397D6D554022E17B7F837A4B40FA298E03AF6C554022E17B7F837A4B40
41146	Пор-Искитим	5	51	868	85.798686000000004	85.829470999999998	55.064689000000001	55.046455000000002	0103000020E610000001000000050000007A71E2AB1D7355402BDEC83CF2854B407A71E2AB1D7355409AB4A9BA47884B40BF7E880D167555409AB4A9BA47884B40BF7E880D167555402BDEC83CF2854B407A71E2AB1D7355402BDEC83CF2854B40
46803	Плотниково	5	51	868	85.916068999999993	85.964685000000003	55.035409999999999	55.006326999999999	0103000020E6100000010000000500000048F8DEDFA07A5540780AB952CF804B4048F8DEDFA07A5540C6F99B5088844B40467C2766BD7D5540C6F99B5088844B40467C2766BD7D5540780AB952CF804B4048F8DEDFA07A5540780AB952CF804B40
46747	Первомайский	5	51	868	85.905343000000002	85.921278999999998	54.984780000000001	54.978338000000001	0103000020E61000000100000005000000672AC423F17955408F37F92D3A7D4B40672AC423F1795540A0E062450D7E4B4076DF313CF67A5540A0E062450D7E4B4076DF313CF67A55408F37F92D3A7D4B40672AC423F17955408F37F92D3A7D4B40
19930	Пархаевка	5	51	868	85.454909000000001	85.472436000000002	54.705038999999999	54.692765000000001	0103000020E61000000100000005000000FD69A33A1D5D55401F680586AC584B40FD69A33A1D5D5540C8B3CBB73E5A4B40FF5C34643C5E5540C8B3CBB73E5A4B40FF5C34643C5E55401F680586AC584B40FD69A33A1D5D55401F680586AC584B40
19025	Падунская	5	51	868	85.017313000000001	85.064340000000001	55.04448	55.023831000000001	0103000020E61000000100000005000000EC32FCA71B415540C4D0EAE40C834B40EC32FCA71B415540BDA94885B1854B40C7F484251E445540BDA94885B1854B40C7F484251E445540C4D0EAE40C834B40EC32FCA71B415540C4D0EAE40C834B40
46544	Окунево	5	51	868	85.407083	85.454766000000006	54.962333000000001	54.943570999999999	0103000020E610000001000000050000007CF0DAA50D5A55401D3A3DEFC6784B407CF0DAA50D5A5540486E4DBA2D7B4B404C55DAE21A5D5540486E4DBA2D7B4B404C55DAE21A5D55401D3A3DEFC6784B407CF0DAA50D5A55401D3A3DEFC6784B40
45867	Октябрьский	5	51	868	85.812366999999995	85.824107999999995	54.983882000000001	54.975459999999998	0103000020E61000000100000005000000605628D2FD73554030478FDFDB7C4B40605628D2FD735540C18F6AD8EF7D4B40CE177B2FBE745540C18F6AD8EF7D4B40CE177B2FBE74554030478FDFDB7C4B40605628D2FD73554030478FDFDB7C4B40
41073	Озерки	5	51	868	84.889635999999996	84.918660000000003	54.997956000000002	54.980229000000001	0103000020E610000001000000050000000856D5CBEF3855409FCBD424787D4B400856D5CBEF3855406A6CAF05BD7F4B402D095053CB3A55406A6CAF05BD7F4B402D095053CB3A55409FCBD424787D4B400856D5CBEF3855409FCBD424787D4B40
41168	Морозово	5	51	868	85.771591999999998	85.798316999999997	54.908397000000001	54.898809999999997	0103000020E61000000100000005000000BC7669C361715540ACA8C1340C734B40BC7669C3617155406B64575A46744B40D0B52FA0177355406B64575A46744B40D0B52FA017735540ACA8C1340C734B40BC7669C361715540ACA8C1340C734B40
41066	Лебеди	5	51	868	85.575040999999999	85.599205999999995	55.048713999999997	55.036318000000001	0103000020E61000000100000005000000FC36C478CD645540C9207711A6844B40FC36C478CD645540BD6DA6423C864B4049641F6459665540BD6DA6423C864B4049641F6459665540C9207711A6844B40FC36C478CD645540C9207711A6844B40
19839	Краснинское	5	51	868	85.439673999999997	85.468689999999995	54.805982	54.788527999999999	0103000020E61000000100000005000000B2B96A9E235C55407AFD497CEE644B40B2B96A9E235C554014950D6B2A674B40957D5704FF5D554014950D6B2A674B40957D5704FF5D55407AFD497CEE644B40B2B96A9E235C55407AFD497CEE644B40
46855	Колычево	5	51	868	86.084340999999995	86.112466999999995	55.022019999999998	55.005583000000001	0103000020E61000000100000005000000902DCBD765855540F03499F1B6804B40902DCBD765855540D0ED258DD1824B4045B8C9A832875540D0ED258DD1824B4045B8C9A832875540F03499F1B6804B40902DCBD765855540F03499F1B6804B40
47032	Каменка	5	51	868	85.531958000000003	85.565690000000004	54.852381000000001	54.829895999999998	0103000020E610000001000000050000001E3691990B625540658A39083A6A4B401E3691990B625540AB5D13D21A6D4B40276BD44334645540AB5D13D21A6D4B40276BD44334645540658A39083A6A4B401E3691990B625540658A39083A6A4B40
20710	Калтышино	5	51	868	85.113153999999994	85.122515000000007	54.834989	54.827060000000003	0103000020E61000000100000005000000575A46EA3D47554036EA211ADD694B40575A46EA3D47554087C267EBE06A4B403F912749D747554087C267EBE06A4B403F912749D747554036EA211ADD694B40575A46EA3D47554036EA211ADD694B40
46404	Калинкино	5	51	868	85.765448000000006	85.789101000000002	54.929824000000004	54.918038000000003	0103000020E6100000010000000500000079B29B19FD7055401D3EE94482754B4079B29B19FD70554099840B7904774B406B0F7BA18072554099840B7904774B406B0F7BA1807255401D3EE94482754B4079B29B19FD7055401D3EE94482754B40
20154	Иваново-Родионовский	5	51	868	85.526891000000006	85.543464999999998	54.901305000000001	54.887362000000003	0103000020E61000000100000005000000A2630795B861554049DBF81395714B40A2630795B8615540535C55F65D734B4052616C21C8625540535C55F65D734B4052616C21C862554049DBF81395714B40A2630795B861554049DBF81395714B40
18312	Журавлево	5	51	868	85.045242000000002	85.076458000000002	54.790511000000002	54.773636000000003	0103000020E61000000100000005000000F699B33EE54255400F81238106634B40F699B33EE54255406B10E6762F654B40206118B0E44455406B10E6762F654B40206118B0E44455400F81238106634B40F699B33EE54255400F81238106634B40
41169	Еремино	5	51	868	85.698532999999998	85.727440000000001	54.904483999999997	54.896510999999997	0103000020E61000000100000005000000508BC1C3B46C55408BC058DFC0724B40508BC1C3B46C5540ACE0B721C6734B40587380608E6E5540ACE0B721C6734B40587380608E6E55408BC058DFC0724B40508BC1C3B46C55408BC058DFC0724B40
46746	Денисовка	5	51	868	84.994710999999995	85.012794999999997	54.959448999999999	54.950986	0103000020E610000001000000050000002C7E5358A93F5540187AC4E8B9794B402C7E5358A93F554007978E39CF7A4B4059A31EA2D140554007978E39CF7A4B4059A31EA2D1405540187AC4E8B9794B402C7E5358A93F5540187AC4E8B9794B40
47244	Голубево	5	51	868	85.063630000000003	85.090382000000005	54.856242999999999	54.846327000000002	0103000020E61000000100000005000000D942908312445540645C7171546C4B40D942908312445540E736E15E996D4B406A8995D1C8455540E736E15E996D4B406A8995D1C8455540645C7171546C4B40D942908312445540645C7171546C4B40
20048	Васьково	5	51	868	85.057610999999994	85.108734999999996	55.062792000000002	55.03557	0103000020E61000000100000005000000F3380CE6AF435540FF5BC98E8D844B40F3380CE6AF435540A839799109884B408E3BA583F5465540A839799109884B408E3BA583F5465540FF5BC98E8D844B40F3380CE6AF435540FF5BC98E8D844B40
46292	Ваганово	5	51	868	85.146832000000003	85.194361999999998	54.709178999999999	54.674241000000002	0103000020E6100000010000000500000067800BB265495540A94F72874D564B4067800BB2654955404701A260C65A4B407365506D704C55404701A260C65A4B407365506D704C5540A94F72874D564B4067800BB265495540A94F72874D564B40
46796	Березово	5	51	868	85.029036000000005	85.055222000000001	55.183698	55.164731000000003	0103000020E61000000100000005000000079ACFB9DB41554096D1C8E715954B40079ACFB9DB415540992B836A83974B404301DBC188435540992B836A83974B404301DBC18843554096D1C8E715954B40079ACFB9DB41554096D1C8E715954B40
20411	Байрак	5	51	868	85.858451000000002	85.876399000000006	54.871974000000002	54.861497	0103000020E61000000100000005000000FC8D76DCF0765540124DA088456E4B40FC8D76DCF07655402D7B12D89C6F4B40D1CFD4EB167855402D7B12D89C6F4B40D1CFD4EB16785540124DA088456E4B40FC8D76DCF0765540124DA088456E4B40
46771	Абышево	5	51	868	84.977967000000007	85.012129999999999	55.073535	55.051453000000002	0103000020E610000001000000050000004E64E602973E5540FB230C0396864B404E64E602973E5540410E4A9869894B403B53E8BCC6405540410E4A9869894B403B53E8BCC6405540FB230C0396864B404E64E602973E5540FB230C0396864B40
17055	Ясная Поляна	5	51	771	86.922640000000001	86.946067999999997	54.002315000000003	53.987717000000004	0103000020E61000000100000005000000D07EA4880CBB5540045ABA826DFE4A40D07EA4880CBB554027A5A0DB4B004B40B2F2CB608CBC554027A5A0DB4B004B40B2F2CB608CBC5540045ABA826DFE4A40D07EA4880CBB5540045ABA826DFE4A40
60768	Школьный	5	51	771	86.811159000000004	86.841953000000004	54.009056999999999	53.992697999999997	0103000020E61000000100000005000000CA367007EAB35540FD6662BA10FF4A40CA367007EAB3554062669FC728014B4039F1D58EE2B5554062669FC728014B4039F1D58EE2B55540FD6662BA10FF4A40CA367007EAB35540FD6662BA10FF4A40
16157	Шарап	5	51	771	86.891413999999997	86.916504000000003	53.920751000000003	53.904485000000001	0103000020E61000000100000005000000944C4EED0CB955407D5C1B2AC6F34A40944C4EED0CB955403161342BDBF54A40CEA96400A8BA55403161342BDBF54A40CEA96400A8BA55407D5C1B2AC6F34A40944C4EED0CB955407D5C1B2AC6F34A40
49560	Чапаевский	5	51	771	86.799490000000006	86.810629000000006	54.145679999999999	54.132604000000001	0103000020E61000000100000005000000A9DE1AD82AB35540CEA8F92AF9104B40A9DE1AD82AB3554034D769A4A5124B401C0C7558E1B3554034D769A4A5124B401C0C7558E1B35540CEA8F92AF9104B40A9DE1AD82AB35540CEA8F92AF9104B40
41070	Углерод	5	51	771	86.496290000000002	86.505004	54.095722000000002	54.090789999999998	0103000020E610000001000000050000003DD52137C39F5540E466B8019F0B4B403DD52137C39F5540FDC0559E400C4B4059164CFC51A05540FDC0559E400C4B4059164CFC51A05540E466B8019F0B4B403DD52137C39F5540E466B8019F0B4B40
41057	Тыхта	5	51	771	86.944728999999995	86.957530000000006	54.321807	54.315074000000003	0103000020E610000001000000050000004CA59F7076BC5540F3E8465854284B404CA59F7076BC5540DB4FC6F830294B4017BCE82B48BD5540DB4FC6F830294B4017BCE82B48BD5540F3E8465854284B404CA59F7076BC5540F3E8465854284B40
60769	Тырган	5	51	771	86.344071	86.353116999999997	54.135511000000001	54.131442999999997	0103000020E6100000010000000500000021205F4205965540E124CD1FD3104B4021205F4205965540C79FA86C58114B4058AA0B7899965540C79FA86C58114B4058AA0B7899965540E124CD1FD3104B4021205F4205965540E124CD1FD3104B40
17241	Трудармейский	5	51	771	86.380453000000003	86.441537999999994	54.140500000000003	54.109600999999998	0103000020E61000000100000005000000912A8A5759985540F04DD367070E4B40912A8A5759985540448B6CE7FB114B403D7C9928429C5540448B6CE7FB114B403D7C9928429C5540F04DD367070E4B40912A8A5759985540F04DD367070E4B40
41139	Трудармейский	5	51	771	86.380453000000003	86.441537999999994	54.140500000000003	54.109600999999998	0103000020E61000000100000005000000912A8A5759985540F04DD367070E4B40912A8A5759985540448B6CE7FB114B403D7C9928429C5540448B6CE7FB114B403D7C9928429C5540F04DD367070E4B40912A8A5759985540F04DD367070E4B40
16812	Тихоновка	5	51	771	86.570948999999999	86.588970000000003	54.241346999999998	54.23028	0103000020E61000000100000005000000C5ABAC6D8AA455402176A6D0791D4B40C5ABAC6D8AA455406DFE5F75E41E4B40CF143AAFB1A555406DFE5F75E41E4B40CF143AAFB1A555402176A6D0791D4B40C5ABAC6D8AA455402176A6D0791D4B40
41126	Терентьевское	5	51	771	86.911617000000007	86.958248999999995	54.110751999999998	54.080655	0103000020E61000000100000005000000925ED4EE57BA554023A12DE7520A4B40925ED4EE57BA5540B9FB1C1F2D0E4B402E1B9DF353BD5540B9FB1C1F2D0E4B402E1B9DF353BD554023A12DE7520A4B40925ED4EE57BA554023A12DE7520A4B40
15737	Терентьевское	5	51	771	86.911617000000007	86.958248999999995	54.110751999999998	54.080655	0103000020E61000000100000005000000925ED4EE57BA554023A12DE7520A4B40925ED4EE57BA5540B9FB1C1F2D0E4B402E1B9DF353BD5540B9FB1C1F2D0E4B402E1B9DF353BD554023A12DE7520A4B40925ED4EE57BA554023A12DE7520A4B40
60727	Терентьевская	5	51	771	86.863585	86.876484000000005	54.069977999999999	54.063262000000002	0103000020E610000001000000050000003C1405FA44B755402F8A1EF818084B403C1405FA44B7554041B8020AF5084B40E8DD585018B8554041B8020AF5084B40E8DD585018B855402F8A1EF818084B403C1405FA44B755402F8A1EF818084B40
49441	Соколово	5	51	771	86.888863000000001	86.912892999999997	54.207616999999999	54.189782000000001	0103000020E61000000100000005000000F7E7A221E3B855404BAFCDC64A184B40F7E7A221E3B85540FC8BA031931A4B40D4EFC2D66CBA5540FC8BA031931A4B40D4EFC2D66CBA55404BAFCDC64A184B40F7E7A221E3B855404BAFCDC64A184B40
45680	Смышляево	5	51	771	86.571848000000003	86.601600000000005	53.829559000000003	53.817005000000002	0103000020E610000001000000050000001D925A2899A4554091D5AD9E93E84A401D925A2899A455401E8D43FD2EEA4A408351499D80A655401E8D43FD2EEA4A408351499D80A6554091D5AD9E93E84A401D925A2899A4554091D5AD9E93E84A40
40407	Севск	5	51	771	86.712569000000002	86.731029000000007	54.059975000000001	54.048701000000001	0103000020E610000001000000050000002EC901BB9AAD5540292499D53B064B402EC901BB9AAD5540EFC9C342AD074B405EDBDB2DC9AE5540EFC9C342AD074B405EDBDB2DC9AE5540292499D53B064B402EC901BB9AAD5540292499D53B064B40
45699	Свободный	5	51	771	86.552201999999994	86.566817	53.884753000000003	53.874859000000001	0103000020E610000001000000050000004AB20E4757A355403ECE3461FBEF4A404AB20E4757A35540DA0418963FF14A404774CFBA46A45540DA0418963FF14A404774CFBA46A455403ECE3461FBEF4A404AB20E4757A355403ECE3461FBEF4A40
49465	Пушкино	5	51	771	86.784677000000002	86.804142999999996	54.194803	54.187786000000003	0103000020E61000000100000005000000193BE12538B25540C652245F09184B40193BE12538B25540D314014EEF184B40AB93331477B35540D314014EEF184B40AB93331477B35540C652245F09184B40193BE12538B25540C652245F09184B40
59367	Прокопьевский городской округ	5	51	771	86.089119999999994	87.096193999999997	54.321807	53.608040000000003	0103000020E61000000100000005000000D95A5F24B485554076543541D4CD4A40D95A5F24B4855540DB4FC6F830294B409204E10A28C65540DB4FC6F830294B409204E10A28C6554076543541D4CD4A40D95A5F24B485554076543541D4CD4A40
41060	Прокопьевск	5	51	771	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
17141	Плодопитомник	5	51	771	86.874948000000003	86.896050000000002	53.993487000000002	53.983851999999999	0103000020E61000000100000005000000D76CE525FFB75540560DC2DCEEFD4A40D76CE525FFB755402600FF942AFF4A402C6519E258B955402600FF942AFF4A402C6519E258B95540560DC2DCEEFD4A40D76CE525FFB75540560DC2DCEEFD4A40
16657	Новосафоновский	5	51	771	86.574218999999999	86.613089000000002	53.858001000000002	53.831732000000002	0103000020E610000001000000050000007A6F0C01C0A45540B284B53176EA4A407A6F0C01C0A45540B8770DFAD2ED4A406422A5D93CA75540B8770DFAD2ED4A406422A5D93CA75540B284B53176EA4A407A6F0C01C0A45540B284B53176EA4A40
45630	Новорождественское	5	51	771	86.738404000000003	86.762478999999999	53.774290999999998	53.759368000000002	0103000020E6100000010000000500000014CFD90242AF554081D07AF832E14A4014CFD90242AF5540274BADF71BE34A40C138B874CCB05540274BADF71BE34A40C138B874CCB0554081D07AF832E14A4014CFD90242AF554081D07AF832E14A40
41253	Михайловка	5	51	771	86.342372999999995	86.369789999999995	54.055101999999998	54.041691	0103000020E6100000010000000500000023827170E9955540CEC4742156054B4023827170E9955540DBF813950D074B40D218ADA3AA975540DBF813950D074B40D218ADA3AA975540CEC4742156054B4023827170E9955540CEC4742156054B40
16284	Маяковка	5	51	771	86.760799000000006	86.772208000000006	54.009135999999998	54.002611000000002	0103000020E6100000010000000500000017F549EEB0B0554010CEA78E55004B4017F549EEB0B05540AE9B525E2B014B406A6D1ADB6BB15540AE9B525E2B014B406A6D1ADB6BB1554010CEA78E55004B4017F549EEB0B0554010CEA78E55004B40
49399	Майский	5	51	771	86.837102000000002	86.856677000000005	54.305723999999998	54.297764999999998	0103000020E61000000100000005000000A35A441493B555405C72DC291D264B40A35A441493B5554018CDCAF621274B40118FC4CBD3B6554018CDCAF621274B40118FC4CBD3B655405C72DC291D264B40A35A441493B555405C72DC291D264B40
16239	Лучшево	5	51	771	86.898645999999999	86.916809999999998	53.845148000000002	53.825429	0103000020E61000000100000005000000992B836A83B95540C21550A8A7E94A40992B836A83B95540D12346CF2DEC4A4054A9D903ADBA5540D12346CF2DEC4A4054A9D903ADBA5540C21550A8A7E94A40992B836A83B95540C21550A8A7E94A40
49422	Лукьяновка	5	51	771	86.703074000000001	86.722333000000006	54.226827	54.212170999999998	0103000020E61000000100000005000000BF2A172AFFAC55406E14596B281B4B40BF2A172AFFAC5540C66CC9AA081D4B4095F430B43AAE5540C66CC9AA081D4B4095F430B43AAE55406E14596B281B4B40BF2A172AFFAC55406E14596B281B4B40
15576	Кутоново	5	51	771	86.676043000000007	86.699920000000006	54.096798999999997	54.088366000000001	0103000020E6100000010000000500000025ECDB4944AB5540070ABC934F0B4B4025ECDB4944AB55408BA4DDE8630C4B403F74417DCBAC55408BA4DDE8630C4B403F74417DCBAC5540070ABC934F0B4B4025ECDB4944AB5540070ABC934F0B4B40
29819	Краснобродский	5	51	771	86.410060999999999	86.470464000000007	54.17145	54.146112000000002	0103000020E610000001000000050000005D177E703E9A5540CEC64ACCB3124B405D177E703E9A55401973D712F2154B40817C09151C9E55401973D712F2154B40817C09151C9E5540CEC64ACCB3124B405D177E703E9A5540CEC64ACCB3124B40
15997	Котино	5	51	771	86.911446999999995	86.940461999999997	54.256186999999997	54.235911000000002	0103000020E610000001000000050000006342CC2555BA554022E2E654321E4B406342CC2555BA5540865451BCCA204B405E48878730BC5540865451BCCA204B405E48878730BC554022E2E654321E4B406342CC2555BA554022E2E654321E4B40
15595	Кольчегиз	5	51	771	86.856632000000005	86.872755999999995	54.127617999999998	54.117497	0103000020E61000000100000005000000412D060FD3B65540663046240A0F4B40412D060FD3B65540C23060C955104B40D158FB3BDBB75540C23060C955104B40D158FB3BDBB75540663046240A0F4B40412D060FD3B65540663046240A0F4B40
15287	Карагайла	5	51	771	86.538987000000006	86.571920000000006	54.178443999999999	54.159221000000002	0103000020E61000000100000005000000077E54C37EA2554010EB8D5A61144B40077E54C37EA255406E15C440D7164B406AFB57569AA455406E15C440D7164B406AFB57569AA4554010EB8D5A61144B40077E54C37EA2554010EB8D5A61144B40
60724	Каменный Ключ	5	51	771	86.089119999999994	86.103815999999995	54.095219999999998	54.087986000000001	0103000020E61000000100000005000000D95A5F24B4855540C0401020430B4B40D95A5F24B48555406AF6402B300C4B404C33DDEBA48655406AF6402B300C4B404C33DDEBA4865540C0401020430B4B40D95A5F24B4855540C0401020430B4B40
16388	Калачево	5	51	771	86.820994999999996	86.965759000000006	53.800894999999997	53.775115999999997	0103000020E610000001000000050000007DCB9C2E8BB455409C4D470037E34A407DCB9C2E8BB45540D44334BA83E64A405534D6FECEBD5540D44334BA83E64A405534D6FECEBD55409C4D470037E34A407DCB9C2E8BB455409C4D470037E34A40
41135	Калачево	5	51	771	86.820994999999996	86.965759000000006	53.800894999999997	53.775115999999997	0103000020E610000001000000050000007DCB9C2E8BB455409C4D470037E34A407DCB9C2E8BB45540D44334BA83E64A405534D6FECEBD5540D44334BA83E64A405534D6FECEBD55409C4D470037E34A407DCB9C2E8BB455409C4D470037E34A40
16526	Индустрия	5	51	771	86.714562999999998	86.734990999999994	53.834935999999999	53.802596000000001	0103000020E61000000100000005000000A0FB7266BBAD554041F33977BBE64A40A0FB7266BBAD55406420CF2EDFEA4A40ADF6B0170AAF55406420CF2EDFEA4A40ADF6B0170AAF554041F33977BBE64A40A0FB7266BBAD554041F33977BBE64A40
41159	Верх-Чумыш	5	51	771	86.459620999999999	86.476393000000002	53.971313000000002	53.953386999999999	0103000020E6100000010000000500000082E3326E6A9D55403DB7D09508FA4A4082E3326E6A9D5540FF9600FC53FC4A40C6C210397D9E5540FF9600FC53FC4A40C6C210397D9E55403DB7D09508FA4A4082E3326E6A9D55403DB7D09508FA4A40
16835	Верх-Егос	5	51	771	86.590119000000001	86.616674000000003	53.938029	53.920777999999999	0103000020E61000000100000005000000E36F7B82C4A555402A70B20DDCF54A40E36F7B82C4A555408CD9925511F84A40C992399677A755408CD9925511F84A40C992399677A755402A70B20DDCF54A40E36F7B82C4A555402A70B20DDCF54A40
16428	Бурлаки	5	51	771	86.669701000000003	86.700800999999998	54.162157000000001	54.138359000000001	0103000020E610000001000000050000004E469561DCAA5540BB0D6ABFB5114B404E469561DCAA5540A3E8818FC1144B40430070ECD9AC5540A3E8818FC1144B40430070ECD9AC5540BB0D6ABFB5114B404E469561DCAA5540BB0D6ABFB5114B40
16934	Большой Керлегеш	5	51	771	86.479590999999999	86.514759999999995	53.900272999999999	53.886747999999997	0103000020E610000001000000050000002E1D739EB19E55408EE55DF580F14A402E1D739EB19E5540643C4A253CF34A407E52EDD3F1A05540643C4A253CF34A407E52EDD3F1A055408EE55DF580F14A402E1D739EB19E55408EE55DF580F14A40
15019	Большая Талда	5	51	771	87.042484000000002	87.071669999999997	54.172877999999997	54.157133000000002	0103000020E610000001000000050000009CA6CF0EB8C25540AA0F24EF1C144B409CA6CF0EB8C255405419C6DD20164B40AD86C43D96C455405419C6DD20164B40AD86C43D96C45540AA0F24EF1C144B409CA6CF0EB8C25540AA0F24EF1C144B40
4097	Чуазас	5	51	632	87.724449000000007	87.736728999999997	53.494050000000001	53.488762000000001	0103000020E61000000100000005000000ADA7565F5DEE554087C3D2C08FBE4A40ADA7565F5DEE55405E4BC8073DBF4A40F240649126EF55405E4BC8073DBF4A40F240649126EF554087C3D2C08FBE4A40ADA7565F5DEE554087C3D2C08FBE4A40
13123	Чичербаево	5	51	632	87.160737999999995	87.177115000000001	53.995095999999997	53.990299999999998	0103000020E610000001000000050000005D4E098849CA5540499D8026C2FE4A405D4E098849CA5540B130444E5FFF4A40632827DA55CB5540B130444E5FFF4A40632827DA55CB5540499D8026C2FE4A405D4E098849CA5540499D8026C2FE4A40
12025	Чистогорский	5	51	632	87.365257999999997	87.378122000000005	53.967298	53.956972999999998	0103000020E610000001000000050000008D26176360D75540D7135D177EFA4A408D26176360D755403CBEBD6BD0FB4A407BF99D2633D855403CBEBD6BD0FB4A407BF99D2633D85540D7135D177EFA4A408D26176360D75540D7135D177EFA4A40
41107	Чистая Грива	5	51	632	87.492648000000003	87.512285000000006	54.039116	54.028835999999998	0103000020E61000000100000005000000261C7A8B87DF55404679E6E5B0034B40261C7A8B87DF55400B60CAC001054B40CF4E0647C9E055400B60CAC001054B40CF4E0647C9E055404679E6E5B0034B40261C7A8B87DF55404679E6E5B0034B40
14207	Усть-Аскарлы	5	51	632	87.550436000000005	87.561494999999994	54.198532	54.189145000000003	0103000020E61000000100000005000000A1A2EA573AE35540D99942E735184B40A1A2EA573AE35540D09A1F7F69194B408577B988EFE35540D09A1F7F69194B408577B988EFE35540D99942E735184B40A1A2EA573AE35540D99942E735184B40
48742	Успенка	5	51	632	87.196023999999994	87.232737999999998	54.085588000000001	54.077627999999997	0103000020E61000000100000005000000CA4E3FA88BCC55407FA0DCB6EF094B40CA4E3FA88BCC55400C772E8CF40A4B4055A2EC2DE5CE55400C772E8CF40A4B4055A2EC2DE5CE55407FA0DCB6EF094B40CA4E3FA88BCC55407FA0DCB6EF094B40
49021	Терехино	5	51	632	87.326316000000006	87.346733999999998	53.998483	53.983217000000003	0103000020E61000000100000005000000570A815CE2D4554085EFFD0DDAFD4A40570A815CE2D45540554E7B4ACEFF4A40529ACDE330D65540554E7B4ACEFF4A40529ACDE330D6554085EFFD0DDAFD4A40570A815CE2D4554085EFFD0DDAFD4A40
60749	Таргайский Дом Отдыха	5	51	632	87.094829000000004	87.109992000000005	53.562744000000002	53.546230999999999	0103000020E61000000100000005000000986DA7AD11C65540DB87BCE5EAC54A40986DA7AD11C655409702D2FE07C84A4096B4E21B0AC755409702D2FE07C84A4096B4E21B0AC75540DB87BCE5EAC54A40986DA7AD11C65540DB87BCE5EAC54A40
11550	Тальжино	5	51	632	87.432496999999998	87.451387999999994	53.753490999999997	53.743028000000002	0103000020E610000001000000050000008FA7E507AEDB55409301A08A1BDF4A408FA7E507AEDB5540486AA16472E04A40A3737E8AE3DC5540486AA16472E04A40A3737E8AE3DC55409301A08A1BDF4A408FA7E507AEDB55409301A08A1BDF4A40
12149	Тайлеп	5	51	632	87.192053999999999	87.216747999999995	53.449810999999997	53.439867999999997	0103000020E610000001000000050000003944DC9C4ACC5540494739984DB84A403944DC9C4ACC5540C630276893B94A404CDE0033DFCD5540C630276893B94A404CDE0033DFCD5540494739984DB84A403944DC9C4ACC5540494739984DB84A40
12897	Тагарыш	5	51	632	87.129423000000003	87.141613000000007	54.017189000000002	54.010353000000002	0103000020E610000001000000050000006A16687748C855402F35423F53014B406A16687748C85540EC6CC83F33024B4010ECF82F10C95540EC6CC83F33024B4010ECF82F10C955402F35423F53014B406A16687748C855402F35423F53014B40
13445	Степной	5	51	632	87.108834000000002	87.127662000000001	53.957673	53.950265999999999	0103000020E6100000010000000500000058ACE122F7C655401840F850A2F94A4058ACE122F7C6554090A1630795FA4A4049BC3C9D2BC8554090A1630795FA4A4049BC3C9D2BC855401840F850A2F94A4058ACE122F7C655401840F850A2F94A40
60787	Старое Ерунаково	5	51	632	87.176585000000003	87.192385999999999	53.995370999999999	53.991253	0103000020E61000000100000005000000B5FD2B2B4DCB5540EC87D860E1FE4A40B5FD2B2B4DCB55408331225168FF4A40548D5E0D50CC55408331225168FF4A40548D5E0D50CC5540EC87D860E1FE4A40B5FD2B2B4DCB5540EC87D860E1FE4A40
41090	Сосновка	5	51	632	87.115679	87.169605000000004	53.681033999999997	53.648094	0103000020E610000001000000050000006075E44867C75540EE5D83BEF4D24A406075E44867C7554066BB421F2CD74A403D0FEECEDACA554066BB421F2CD74A403D0FEECEDACA5540EE5D83BEF4D24A406075E44867C75540EE5D83BEF4D24A40
49015	Сидорово	5	51	632	87.331031999999993	87.348324000000005	53.967689999999997	53.955972000000003	0103000020E610000001000000050000007C7BD7A02FD5554024F25D4A5DFA4A407C7BD7A02FD5554047551344DDFB4A405D1ABFF04AD6554047551344DDFB4A405D1ABFF04AD6554024F25D4A5DFA4A407C7BD7A02FD5554024F25D4A5DFA4A40
48548	Северный	5	51	632	87.002401000000006	87.018390999999994	53.946010999999999	53.932828999999998	0103000020E61000000100000005000000931E865627C0554054E1CFF066F74A40931E865627C05540005471E316F94A409BE271512DC15540005471E316F94A409BE271512DC1554054E1CFF066F74A40931E865627C0554054E1CFF066F74A40
14542	Сары-Чумыш	5	51	632	86.707393999999994	86.737253999999993	53.246175000000001	53.233694	0103000020E61000000100000005000000BED87BF145AD5540BEA25BAFE99D4A40BED87BF145AD5540E10B93A9829F4A4017B6662B2FAF5540E10B93A9829F4A4017B6662B2FAF5540BEA25BAFE99D4A40BED87BF145AD5540BEA25BAFE99D4A40
41207	Сарбала	5	51	632	87.291927999999999	87.351450999999997	53.470692999999997	53.452589000000003	0103000020E610000001000000050000005932C7F2AED25540C2C3B46FEEB94A405932C7F2AED2554062BA10AB3FBC4A4060C9552C7ED6554062BA10AB3FBC4A4060C9552C7ED65540C2C3B46FEEB94A405932C7F2AED25540C2C3B46FEEB94A40
41191	Рассвет	5	51	632	86.922783999999993	86.942977999999997	53.731039000000003	53.716419999999999	0103000020E6100000010000000500000069519FE40EBB5540A4198BA6B3DB4A4069519FE40EBB5540DF8C9AAF92DD4A403DB665C059BC5540DF8C9AAF92DD4A403DB665C059BC5540A4198BA6B3DB4A4069519FE40EBB5540A4198BA6B3DB4A40
5122	Подобас	5	51	632	87.619831000000005	87.672696999999999	53.774659	53.749119999999998	0103000020E610000001000000050000000283A44FABE75540C763062AE3DF4A400283A44FABE75540AA46AF0628E34A4082C7B7770DEB5540AA46AF0628E34A4082C7B7770DEB5540C763062AE3DF4A400283A44FABE75540C763062AE3DF4A40
48866	Подгорный	5	51	632	87.008447000000004	87.017340000000004	53.815755000000003	53.809567000000001	0103000020E61000000100000005000000F52F49658AC05540DE7536E49FE74A40F52F49658AC055403546EBA86AE84A40693A3B191CC155403546EBA86AE84A40693A3B191CC15540DE7536E49FE74A40F52F49658AC05540DE7536E49FE74A40
14089	Осиновое Плесо	5	51	632	87.537267	87.583062999999996	54.216135999999999	54.203867000000002	0103000020E61000000100000005000000158E209562E25540E8DD5850181A4B40158E209562E255407FBE2D58AA1B4B407D2079E750E555407FBE2D58AA1B4B407D2079E750E55540E8DD5850181A4B40158E209562E25540E8DD5850181A4B40
46629	Новый	5	51	632	87.122748999999999	87.128919999999994	53.591870999999998	53.586739999999999	0103000020E6100000010000000500000078279F1EDBC75540A5A0DB4B1ACB4A4078279F1EDBC75540B439CE6DC2CB4A4038F3AB3940C85540B439CE6DC2CB4A4038F3AB3940C85540A5A0DB4B1ACB4A4078279F1EDBC75540A5A0DB4B1ACB4A40
6235	Новокузнецк	5	51	632	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
13168	Николаевка	5	51	632	87.140238999999994	87.189098000000001	53.488264000000001	53.469673999999998	0103000020E61000000100000005000000EBA7FFACF9C8554008E412471EBC4A40EBA7FFACF9C8554036E84B6F7FBE4A404C6F7F2E1ACC554036E84B6F7FBE4A404C6F7F2E1ACC554008E412471EBC4A40EBA7FFACF9C8554008E412471EBC4A40
12879	Недорезово (Пашкино)	5	51	632	87.107557999999997	87.135523000000006	54.010094000000002	53.995911	0103000020E61000000100000005000000151BF33AE2C65540035DFB027AFF4A40151BF33AE2C6554063F19BC24A014B40C636A968ACC8554063F19BC24A014B40C636A968ACC85540035DFB027AFF4A40151BF33AE2C65540035DFB027AFF4A40
41194	Мир	5	51	632	87.003488000000004	87.019766000000004	53.741159000000003	53.734422000000002	0103000020E610000001000000050000006C7BBB2539C0554041BB438A01DE4A406C7BBB2539C055406B11514CDEDE4A40A8E49CD843C155406B11514CDEDE4A40A8E49CD843C1554041BB438A01DE4A406C7BBB2539C0554041BB438A01DE4A40
41212	Малиновка	5	51	632	87.261745000000005	87.335982000000001	53.430888000000003	53.390470999999998	0103000020E610000001000000050000000FB9196EC0D05540A98427F4FAB14A400FB9196EC0D05540931E865627B74A40DC82A5BA80D55540931E865627B74A40DC82A5BA80D55540A98427F4FAB14A400FB9196EC0D05540A98427F4FAB14A40
13646	Малиновка	5	51	632	87.261745000000005	87.335982000000001	53.430888000000003	53.390470999999998	0103000020E610000001000000050000000FB9196EC0D05540A98427F4FAB14A400FB9196EC0D05540931E865627B74A40DC82A5BA80D55540931E865627B74A40DC82A5BA80D55540A98427F4FAB14A400FB9196EC0D05540A98427F4FAB14A40
9411	Лыс	5	51	632	87.026161999999999	87.054809000000006	53.159044000000002	53.146850000000001	0103000020E61000000100000005000000789961A3ACC1554074B515FBCB924A40789961A3ACC155400150C58D5B944A40B2A19BFD81C355400150C58D5B944A40B2A19BFD81C3554074B515FBCB924A40789961A3ACC1554074B515FBCB924A40
11966	Куртуково	5	51	632	87.183924000000005	87.234803999999997	53.644480999999999	53.634267999999999	0103000020E61000000100000005000000C53C2B69C5CB55401D739EB12FD14A40C53C2B69C5CB55405AF2785A7ED24A40143E5B0707CF55405AF2785A7ED24A40143E5B0707CF55401D739EB12FD14A40C53C2B69C5CB55401D739EB12FD14A40
14726	Кузедеево	5	51	632	87.141568000000007	87.255878999999993	53.344790000000003	53.315556999999998	0103000020E61000000100000005000000408A3A730FC955400E83F92B64A84A40408A3A730FC9554072FE261422AC4A40EC2E505260D0554072FE261422AC4A40EC2E505260D055400E83F92B64A84A40408A3A730FC955400E83F92B64A84A40
13980	Кругленькое	5	51	632	87.201001000000005	87.217331999999999	53.813516999999997	53.807462000000001	0103000020E61000000100000005000000A75D4C33DDCC5540A26131EA5AE74A40A75D4C33DDCC5540B9DE365321E84A40F4177AC4E8CD5540B9DE365321E84A40F4177AC4E8CD5540A26131EA5AE74A40A75D4C33DDCC5540A26131EA5AE74A40
41096	Красулино	5	51	632	87.065786000000003	87.093930999999998	54.032617000000002	54.018436999999999	0103000020E6100000010000000500000038A27BD635C45540A704C4245C024B4038A27BD635C4554096253ACB2C044B4028452BF702C6554096253ACB2C044B4028452BF702C65540A704C4245C024B4038A27BD635C45540A704C4245C024B40
41112	Красная Орловка	5	51	632	87.326764999999995	87.338964000000004	53.588470999999998	53.580190999999999	0103000020E610000001000000050000008E1EBFB7E9D455407E37DDB243CA4A408E1EBFB7E9D455407CD2890453CB4A405EA10F96B1D555407CD2890453CB4A405EA10F96B1D555407E37DDB243CA4A408E1EBFB7E9D455407E37DDB243CA4A40
13541	Костенково	5	51	632	86.800128000000001	86.844387999999995	53.644523	53.613916000000003	0103000020E610000001000000050000004A27124C35B35540DE3EABCC94CE4A404A27124C35B355408942CBBA7FD24A40A148F7730AB655408942CBBA7FD24A40A148F7730AB65540DE3EABCC94CE4A404A27124C35B35540DE3EABCC94CE4A40
14625	Кандалеп	5	51	632	86.908203999999998	86.937139000000002	53.276183000000003	53.269306	0103000020E610000001000000050000002B86AB0320BA5540EC4E779E78A24A402B86AB0320BA5540085BECF659A34A409833DB15FABB5540085BECF659A34A409833DB15FABB5540EC4E779E78A24A402B86AB0320BA5540EC4E779E78A24A40
12988	Казанково	5	51	632	87.255330999999998	87.285810999999995	54.006321	53.990839999999999	0103000020E61000000100000005000000EBA9D55757D05540C9C859D8D3FE4A40EBA9D55757D0554096236420CF004B40927538BA4AD2554096236420CF004B40927538BA4AD25540C9C859D8D3FE4A40EBA9D55757D05540C9C859D8D3FE4A40
60718	Ильинка	5	51	632	86.688000000000002	87.909484000000006	54.499693999999998	53.085965999999999	0103000020E6100000010000000500000079E9263108AC5540B24813EF008B4A4079E9263108AC5540F30016F9F53F4B400F0F61FC34FA5540F30016F9F53F4B400F0F61FC34FA5540B24813EF008B4A4079E9263108AC5540B24813EF008B4A40
14455	Зеленый Луг	5	51	632	87.298468	87.304845999999998	53.483088000000002	53.472445	0103000020E61000000100000005000000C3B986191AD355405114E81379BC4A40C3B986191AD35540878BDCD3D5BD4A404014CC9882D35540878BDCD3D5BD4A404014CC9882D355405114E81379BC4A40C3B986191AD355405114E81379BC4A40
60770	Заречный	5	51	632	87.299609000000004	87.306911999999997	53.600731000000003	53.596018000000001	0103000020E6100000010000000500000096253ACB2CD35540E6E95C514ACC4A4096253ACB2CD35540C158DFC0E4CC4A40FFAF3A72A4D35540C158DFC0E4CC4A40FFAF3A72A4D35540E6E95C514ACC4A4096253ACB2CD35540E6E95C514ACC4A40
14373	Загадное	5	51	632	87.811963000000006	87.821637999999993	54.153737	54.137203999999997	0103000020E61000000100000005000000F9A3A833F7F35540B07092E68F114B40F9A3A833F7F35540B3976DA7AD134B40A7C98CB795F45540B3976DA7AD134B40A7C98CB795F45540B07092E68F114B40F9A3A833F7F35540B07092E68F114B40
41108	Есаулка	5	51	632	87.430492999999998	87.444614999999999	53.898899	53.893031000000001	0103000020E610000001000000050000000B0A83328DDB554037A8FDD64EF24A400B0A83328DDB55401CB4571F0FF34A40E813799274DC55401CB4571F0FF34A40E813799274DC554037A8FDD64EF24A400B0A83328DDB554037A8FDD64EF24A40
41187	Бунгур	5	51	632	86.982737	87.023241999999996	53.754534	53.738714000000002	0103000020E610000001000000050000006DE4BA29E5BE5540768C2B2E8EDE4A406DE4BA29E5BE55402BDCF29194E04A40317903CC7CC155402BDCF29194E04A40317903CC7CC15540768C2B2E8EDE4A406DE4BA29E5BE5540768C2B2E8EDE4A40
41173	Боровково	5	51	632	87.485668000000004	87.508701000000002	53.794635	53.787444000000001	0103000020E61000000100000005000000AE2D3C2F15DF554039B709F7CAE44A40AE2D3C2F15DF5540E4A08499B6E54A40529CA38E8EE05540E4A08499B6E54A40529CA38E8EE0554039B709F7CAE44A40AE2D3C2F15DF554039B709F7CAE44A40
41174	Берензас	5	51	632	87.571718000000004	87.589342000000002	53.684531999999997	53.667864000000002	0103000020E610000001000000050000003622180797E455407F164B917CD54A403622180797E4554061889CBE9ED74A40310A82C7B7E5554061889CBE9ED74A40310A82C7B7E555407F164B917CD54A403622180797E455407F164B917CD54A40
41114	Бенжереп 2-й	5	51	632	86.779510999999999	86.806765999999996	53.269382	53.25667	0103000020E61000000100000005000000D3F71A82E3B15540A2EE0390DAA04A40D3F71A82E3B15540C710001C7BA24A409561DC0DA2B35540C710001C7BA24A409561DC0DA2B35540A2EE0390DAA04A40D3F71A82E3B15540A2EE0390DAA04A40
14698	Бенжереп 1-й	5	51	632	86.975110000000001	87.026071999999999	53.332467000000001	53.311909999999997	0103000020E610000001000000050000002A00C63368BE5540CEA5B8AAECA74A402A00C63368BE5540E7FF55478EAA4A40D8D5E429ABC15540E7FF55478EAA4A40D8D5E429ABC15540CEA5B8AAECA74A402A00C63368BE5540CEA5B8AAECA74A40
12443	Безруково	5	51	632	87.541291999999999	87.625005999999999	53.786752	53.757744000000002	0103000020E6100000010000000500000088653387A4E25540C05E61C1FDE04A4088653387A4E2554003081F4AB4E44A4071732A1900E8554003081F4AB4E44A4071732A1900E85540C05E61C1FDE04A4088653387A4E25540C05E61C1FDE04A40
12391	Бедарево	5	51	632	87.112093999999999	87.136591999999993	53.860295000000001	53.85201	0103000020E61000000100000005000000FB04508C2CC75540B7EEE6A90EED4A40FB04508C2CC75540C7F484251EEE4A404B395FECBDC85540C7F484251EEE4A404B395FECBDC85540B7EEE6A90EED4A40FB04508C2CC75540B7EEE6A90EED4A40
11423	Баевка	5	51	632	87.411197999999999	87.421896000000004	53.729111000000003	53.722143000000003	0103000020E610000001000000050000008F8B6A1151DA554086048C2E6FDC4A408F8B6A1151DA5540B2135E8253DD4A400C94145800DB5540B2135E8253DD4A400C94145800DB554086048C2E6FDC4A408F8B6A1151DA554086048C2E6FDC4A40
11805	Ашмарино	5	51	632	87.252752999999998	87.278830999999997	53.640273999999998	53.624780000000001	0103000020E61000000100000005000000D13DEB1A2DD05540F29881CAF8CF4A40D13DEB1A2DD05540533D997FF4D14A401A87FA5DD8D15540533D997FF4D14A401A87FA5DD8D15540F29881CAF8CF4A40D13DEB1A2DD05540F29881CAF8CF4A40
41202	Апанас	5	51	632	86.832170000000005	86.851286999999999	53.535159999999998	53.51923	0103000020E6100000010000000500000097ADF54542B55540118DEE2076C24A4097ADF54542B555404D10751F80C44A40A320787C7BB655404D10751F80C44A40A320787C7BB65540118DEE2076C24A4097ADF54542B55540118DEE2076C24A40
41182	Анисимово (Васьково)	5	51	632	87.059102999999993	87.070825999999997	54.052253999999998	54.045625000000001	0103000020E610000001000000050000001C06F357C8C35540A4703D0AD7054B401C06F357C8C35540E78A5242B0064B40376DC66988C45540E78A5242B0064B40376DC66988C45540A4703D0AD7054B401C06F357C8C35540A4703D0AD7054B40
41134	Абагур-Лесной	5	51	632	87.186942000000002	87.318742999999998	53.764819000000003	53.686655000000002	0103000020E61000000100000005000000ED0F94DBF6CB55404451A04FE4D74A40ED0F94DBF6CB5540022EC896E5E14A400D350A4966D45540022EC896E5E14A400D350A4966D455404451A04FE4D74A40ED0F94DBF6CB55404451A04FE4D74A40
1208	Междуреченск	5	51	285	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
47728	Тюменево	5	51	815	87.237993000000003	87.274995000000004	56.246105999999997	56.233739	0103000020E6100000010000000500000053EBFD463BCF55405E66D828EB1D4C4053EBFD463BCF5540B8ACC266801F4C4011E4A08499D15540B8ACC266801F4C4011E4A08499D155405E66D828EB1D4C4053EBFD463BCF55405E66D828EB1D4C40
10753	Тундинка	5	51	815	88.298445999999998	88.322134000000005	56.542619000000002	56.535626000000001	0103000020E61000000100000005000000CF6740BD1913564093718C648F444C40CF6740BD191356401898158A74454C4080BBECD79D1456401898158A74454C4080BBECD79D14564093718C648F444C40CF6740BD1913564093718C648F444C40
48032	Туйла	5	51	815	87.196824000000007	87.221114	56.609927999999996	56.594195999999997	0103000020E6100000010000000500000059C4B0C398CC5540FEB4519D0E4C4C4059C4B0C398CC55401475E61E124E4C4004AC55BB26CE55401475E61E124E4C4004AC55BB26CE5540FEB4519D0E4C4C4059C4B0C398CC5540FEB4519D0E4C4C40
14164	Тенгулы	5	51	815	87.542000999999999	87.575967000000006	56.385446999999999	56.375478999999999	0103000020E610000001000000050000008E59F624B0E25540DAAA24B20F304C408E59F624B0E25540B0ABC95356314C40D124B1A4DCE45540B0ABC95356314C40D124B1A4DCE45540DAAA24B20F304C408E59F624B0E25540DAAA24B20F304C40
60785	Таёжно-Михайловка	5	51	815	87.454254000000006	87.492018999999999	56.540520000000001	56.522658999999997	0103000020E61000000100000005000000F1845E7F12DD5540E3FA777DE6424C40F1845E7F12DD5540BE6A65C22F454C40AE80423D7DDF5540BE6A65C22F454C40AE80423D7DDF5540E3FA777DE6424C40F1845E7F12DD5540E3FA777DE6424C40
60795	Таежно-Александровка	5	51	815	87.328102999999999	87.369246000000004	56.577060000000003	56.565961999999999	0103000020E610000001000000050000000CAEB9A3FFD45540AE635C7171484C400CAEB9A3FFD4554036EA211ADD494C40728BF9B9A1D7554036EA211ADD494C40728BF9B9A1D75540AE635C7171484C400CAEB9A3FFD45540AE635C7171484C40
11069	Суслово	5	51	815	88.096603000000002	88.158174000000002	56.226948999999998	56.205651000000003	0103000020E61000000100000005000000836C59BE2E065640E2B19FC5521A4C40836C59BE2E065640116E32AA0C1D4C40F644D7851F0A5640116E32AA0C1D4C40F644D7851F0A5640E2B19FC5521A4C40836C59BE2E065640E2B19FC5521A4C40
47903	Рубино	5	51	815	88.158253999999999	88.183614000000006	56.362625999999999	56.352606999999999	0103000020E61000000100000005000000849D62D5200A56409BABE639222D4C40849D62D5200A5640F3565D876A2E4C409E45EF54C00B5640F3565D876A2E4C409E45EF54C00B56409BABE639222D4C40849D62D5200A56409BABE639222D4C40
47648	Раевка	5	51	815	87.870694999999998	87.885633999999996	56.181939999999997	56.160981999999997	0103000020E610000001000000050000009B728577B9F75540519FE40E9B144C409B728577B9F75540C8EA56CF49174C40718E3A3AAEF85540C8EA56CF49174C40718E3A3AAEF85540519FE40E9B144C409B728577B9F75540519FE40E9B144C40
60740	Пристань 2-я	5	51	815	87.794292999999996	87.838399999999993	56.210462	56.190361000000003	0103000020E61000000100000005000000459C4EB2D5F2554089B7CEBF5D184C40459C4EB2D5F255407F86376BF01A4C40D93D7958A8F555407F86376BF01A4C40D93D7958A8F5554089B7CEBF5D184C40459C4EB2D5F2554089B7CEBF5D184C40
41075	Приметкино	5	51	815	87.902557999999999	87.927961999999994	56.235435000000003	56.226838999999998	0103000020E61000000100000005000000902FA182C3F955408A3A730F091D4C40902FA182C3F95540B9AAECBB221E4C40917BBABA63FB5540B9AAECBB221E4C40917BBABA63FB55408A3A730F091D4C40902FA182C3F955408A3A730F091D4C40
9937	Правдинка	5	51	815	87.158069999999995	87.194864999999993	56.339481999999997	56.321829999999999	0103000020E61000000100000005000000A31EA2D11DCA5540936FB6B931294C40A31EA2D11DCA554053CA6B25742B4C40A4880CAB78CC554053CA6B25742B4C40A4880CAB78CC5540936FB6B931294C40A31EA2D11DCA5540936FB6B931294C40
60745	Пихтовка	5	51	815	88.068971000000005	88.085984999999994	56.654783000000002	56.648978999999997	0103000020E61000000100000005000000D65757056A04564038656EBE11534C40D65757056A045640077DE9EDCF534C4094BC3AC780055640077DE9EDCF534C4094BC3AC78005564038656EBE11534C40D65757056A04564038656EBE11534C40
47746	Петровка	5	51	815	87.384904000000006	87.399079	56.217896000000003	56.211548000000001	0103000020E6100000010000000500000060066344A2D8554061C43E01141B4C4060066344A2D85540F1F62004E41B4C404E61A5828AD95540F1F62004E41B4C404E61A5828AD9554061C43E01141B4C4060066344A2D8554061C43E01141B4C40
45470	Первомайский	5	51	815	88.010328999999999	88.032247999999996	56.179786	56.169638999999997	0103000020E61000000100000005000000D34CF73AA9005640259012BBB6154C40D34CF73AA9005640AB23473A03174C402157EA5910025640AB23473A03174C402157EA5910025640259012BBB6154C40D34CF73AA9005640259012BBB6154C40
23191	Обояновка	5	51	815	87.607228000000006	87.637016000000003	56.364395999999999	56.349310000000003	0103000020E61000000100000005000000CB4DD4D2DCE655403815A930B62C4C40CB4DD4D2DCE6554088653387A42E4C40D7C1C1DEC4E8554088653387A42E4C40D7C1C1DEC4E855403815A930B62C4C40CB4DD4D2DCE655403815A930B62C4C40
60776	Николаевка 2-я	5	51	815	88.070417000000006	88.110258000000002	56.296273999999997	56.279932000000002	0103000020E6100000010000000500000047054EB6810456404C8DD0CFD4234C4047054EB681045640DA53724EEC254C40D50792770E075640DA53724EEC254C40D50792770E0756404C8DD0CFD4234C4047054EB6810456404C8DD0CFD4234C40
60782	Николаевка 1-я	5	51	815	87.301989000000006	87.319704000000002	56.287207000000002	56.277093000000001	0103000020E610000001000000050000001DB0ABC953D35540AB798EC877234C401DB0ABC953D355405517F032C3244C40A019C40776D455405517F032C3244C40A019C40776D45540AB798EC877234C401DB0ABC953D35540AB798EC877234C40
47892	Мелехино	5	51	815	87.913751000000005	87.941643999999997	56.324660999999999	56.321725999999998	0103000020E61000000100000005000000FD6B79E57AFA5540EE224C512E294C40FD6B79E57AFA5540B1A4DC7D8E294C40601E32E543FC5540B1A4DC7D8E294C40601E32E543FC5540EE224C512E294C40FD6B79E57AFA5540EE224C512E294C40
6824	Мариинск	5	51	815	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
41153	Мальковка	5	51	815	87.544569999999993	87.582550999999995	56.143698999999998	56.128901999999997	0103000020E610000001000000050000007E18213CDAE25540CA3159DC7F104C407E18213CDAE25540E4BB94BA64124C402250FD8348E55540E4BB94BA64124C402250FD8348E55540CA3159DC7F104C407E18213CDAE25540CA3159DC7F104C40
10043	Малый Антибес	5	51	815	87.691615999999996	87.713840000000005	56.286392999999997	56.275109	0103000020E61000000100000005000000FB58C16F43EC5540EAEA8EC536234C40FB58C16F43EC5540D3669C86A8244C40E8A4F78DAFED5540D3669C86A8244C40E8A4F78DAFED5540EAEA8EC536234C40FB58C16F43EC5540EAEA8EC536234C40
10806	Малопесчанка	5	51	815	87.096985000000004	87.141613000000007	56.445996000000001	56.415464999999998	0103000020E61000000100000005000000F7CC920035C65540FAD005F52D354C40F7CC920035C65540CB129D6516394C4010ECF82F10C95540CB129D6516394C4010ECF82F10C95540FAD005F52D354C40F7CC920035C65540FAD005F52D354C40
47759	Лебяжий	5	51	815	88.152083000000005	88.174721000000005	56.387265999999997	56.378279999999997	0103000020E61000000100000005000000C4D155BABB0956408D5DA27A6B304C40C4D155BABB095640266DAAEE91314C402A3BFDA02E0B5640266DAAEE91314C402A3BFDA02E0B56408D5DA27A6B304C40C4D155BABB0956408D5DA27A6B304C40
10665	Куркули	5	51	815	88.045516000000006	88.062843999999998	56.413338000000003	56.406491000000003	0103000020E6100000010000000500000077DCF0BBE9025640268FA7E507344C4077DCF0BBE9025640D7187442E8344C40FD2FD7A205045640D7187442E8344C40FD2FD7A205045640268FA7E507344C4077DCF0BBE9025640268FA7E507344C40
10413	Красные Орлы	5	51	815	87.209103999999996	87.254298000000006	56.179369999999999	56.159498999999997	0103000020E610000001000000050000009E5DBEF561CD5540525F96766A144C409E5DBEF561CD554017F19D98F5164C400C5C1E6B46D0554017F19D98F5164C400C5C1E6B46D05540525F96766A144C409E5DBEF561CD5540525F96766A144C40
41167	Константиновка	5	51	815	88.069976999999994	88.075574000000003	56.139226000000001	56.123041999999998	0103000020E61000000100000005000000389ECF807A04564068041BD7BF0F4C40389ECF807A0456405F605628D2114C40639B5434D60456405F605628D2114C40639B5434D604564068041BD7BF0F4C40389ECF807A04564068041BD7BF0F4C40
12958	Колеул	5	51	815	87.329963000000006	87.352241000000006	56.524337000000003	56.509737000000001	0103000020E61000000100000005000000F778211D1ED55540D447E00F3F414C40F778211D1ED55540988A8D791D434C40DDD3D51D8BD65540988A8D791D434C40DDD3D51D8BD65540D447E00F3F414C40F778211D1ED55540D447E00F3F414C40
47850	Кирсановка	5	51	815	87.049921999999995	87.087075999999996	56.509920999999999	56.496478000000003	0103000020E6100000010000000500000075560BEC31C355407D9752978C3F4C4075560BEC31C355409545611745414C400E1137A792C555409545611745414C400E1137A792C555407D9752978C3F4C4075560BEC31C355407D9752978C3F4C40
41076	Камышенка	5	51	815	87.240939999999995	87.264808000000002	56.108255999999997	56.098326	0103000020E6100000010000000500000016139B8F6BCF55405A2C45F2950C4C4016139B8F6BCF554042CC2555DB0D4C4007EE409DF2D0554042CC2555DB0D4C4007EE409DF2D055405A2C45F2950C4C4016139B8F6BCF55405A2C45F2950C4C40
47580	Калининский	5	51	815	87.628707000000006	87.649242000000001	56.198715	56.191113000000001	0103000020E610000001000000050000000BF148BC3CE85540946B0A6476184C400BF148BC3CE85540C11C3D7E6F194C40234C512E8DE95540C11C3D7E6F194C40234C512E8DE95540946B0A6476184C400BF148BC3CE85540946B0A6476184C40
10066	Кайдулы	5	51	815	87.486673999999994	87.516732000000005	56.285663	56.275494000000002	0103000020E610000001000000050000001074B4AA25DF5540431F2C6343234C401074B4AA25DF5540B056ED9A90244C40FD32182312E15540B056ED9A90244C40FD32182312E15540431F2C6343234C401074B4AA25DF5540431F2C6343234C40
47980	Знаменка	5	51	815	88.221990000000005	88.246577000000002	56.066232999999997	56.044252	0103000020E6100000010000000500000080828B15350E56402C64AE0CAA054C4080828B15350E56403E75AC527A084C4088BCE5EAC70F56403E75AC527A084C4088BCE5EAC70F56402C64AE0CAA054C4080828B15350E56402C64AE0CAA054C40
60789	Болшой Антибес	5	51	815	87.739531999999997	87.764585999999994	56.313344000000001	56.297338000000003	0103000020E610000001000000050000001C96067E54EF5540D5EDEC2B0F264C401C96067E54EF5540EC32FCA71B284C40AF3E1EFAEEF05540EC32FCA71B284C40AF3E1EFAEEF05540D5EDEC2B0F264C401C96067E54EF5540D5EDEC2B0F264C40
48673	Благовещенка	5	51	815	87.367583999999994	87.405314000000004	56.391167000000003	56.368459999999999	0103000020E610000001000000050000001AA20A7F86D755402CF180B2292F4C401AA20A7F86D755402123A0C211324C401AA721AAF0D955402123A0C211324C401AA721AAF0D955402CF180B2292F4C401AA20A7F86D755402CF180B2292F4C40
5826	Белогородка	5	51	815	87.148071999999999	87.186160999999998	56.296314000000002	56.278503000000001	0103000020E61000000100000005000000035DFB027AC95540406B7EFCA5234C40035DFB027AC9554069ACFD9DED254C409AB2D30FEACB554069ACFD9DED254C409AB2D30FEACB5540406B7EFCA5234C40035DFB027AC95540406B7EFCA5234C40
60790	Антибесский	5	51	815	87.514701000000002	87.534509	56.172469999999997	56.166476000000003	0103000020E61000000100000005000000FC8D76DCF0E05540D2C8E7154F154C40FC8D76DCF0E0554043C5387F13164C40BB9A3C6535E2554043C5387F13164C40BB9A3C6535E25540D2C8E7154F154C40FC8D76DCF0E05540D2C8E7154F154C40
8378	Шабаново	5	51	35	85.577538000000004	85.632497000000001	54.682174000000003	54.658948000000002	0103000020E61000000100000005000000A08CF161F6645540DFE1766858544B40A08CF161F66455403C17467A51574B405C74B2D47A6855403C17467A51574B405C74B2D47A685540DFE1766858544B40A08CF161F6645540DFE1766858544B40
7748	Чусовитино	5	51	35	86.307348000000005	86.344600999999997	54.848109999999998	54.827500000000001	0103000020E610000001000000050000006D1FF296AB93554052B81E85EB694B406D1FF296AB9355408DB454DE8E6C4B40CF4A5AF10D9655408DB454DE8E6C4B40CF4A5AF10D96554052B81E85EB694B406D1FF296AB93554052B81E85EB694B40
59500	Чкаловский	5	51	35	85.942982000000001	85.969059999999999	54.694944999999997	54.682206000000001	0103000020E61000000100000005000000DEAD2CD1597C55404791B58652574B40DEAD2CD1597C554065C22FF5F3584B4027F73B14057E554065C22FF5F3584B4027F73B14057E55404791B58652574B40DEAD2CD1597C55404791B58652574B40
45907	Чесноково	5	51	35	86.389813000000004	86.431863000000007	54.822454	54.814014	0103000020E6100000010000000500000090A339B2F29855403A3E5A9C31684B4090A339B2F2985540713B342C46694B408F56B5A4A39B5540713B342C46694B408F56B5A4A39B55403A3E5A9C31684B4090A339B2F29855403A3E5A9C31684B40
6768	Худяшово	5	51	35	86.033693999999997	86.048839999999998	54.824388999999996	54.809018000000002	0103000020E610000001000000050000009204E10A288255400BF0DDE68D674B409204E10A288255405017299485694B4025AFCE31208355405017299485694B4025AFCE31208355400BF0DDE68D674B409204E10A288255400BF0DDE68D674B40
7040	Хрестиновский	5	51	35	85.309866999999997	85.338721000000007	54.577122000000003	54.565854000000002	0103000020E6100000010000000500000004C765DCD4535540C82764E76D484B4004C765DCD4535540ACE63922DF494B40FB5DD89AAD555540ACE63922DF494B40FB5DD89AAD555540C82764E76D484B4004C765DCD4535540C82764E76D484B40
46042	Хмелево	5	51	35	86.061856000000006	86.086298999999997	54.729630999999998	54.711883999999998	0103000020E61000000100000005000000EE43DE72F5835540D845D1031F5B4B40EE43DE72F5835540EA92718C645D4B405CAB3DEC85855540EA92718C645D4B405CAB3DEC85855540D845D1031F5B4B40EE43DE72F5835540D845D1031F5B4B40
6739	Трекино	5	51	35	86.057670000000002	86.076481000000001	54.836289999999998	54.827235999999999	0103000020E6100000010000000500000076FD82DDB0835540740987DEE2694B4076FD82DDB083554065FCFB8C0B6B4B40FC709010E584554065FCFB8C0B6B4B40FC709010E5845540740987DEE2694B4076FD82DDB0835540740987DEE2694B40
8514	Торопово	5	51	35	85.680493999999996	85.718294999999998	54.688878000000003	54.675334999999997	0103000020E61000000100000005000000F3C7B4368D6B55400D6C956071564B40F3C7B4368D6B55408A7780272D584B405778978BF86D55408A7780272D584B405778978BF86D55400D6C956071564B40F3C7B4368D6B55400D6C956071564B40
45834	Солнечный	5	51	35	86.085139999999996	86.096288999999999	54.644790999999998	54.633161000000001	0103000020E6100000010000000500000036E50AEF72855540240D6E6B0B514B4036E50AEF72855540A8E0F08288524B40BB7D569929865540A8E0F08288524B40BB7D569929865540240D6E6B0B514B4036E50AEF72855540240D6E6B0B514B40
46778	Соколовка	5	51	35	85.806231999999994	85.827611000000005	54.704706000000002	54.697609	0103000020E61000000100000005000000463F1A4E99735540983270404B594B40463F1A4E99735540C2A563CE335A4B40D5B32094F7745540C2A563CE335A4B40D5B32094F7745540983270404B594B40463F1A4E99735540983270404B594B40
46581	Семеново	5	51	35	86.414831000000007	86.424210000000002	54.909199000000001	54.890241000000003	0103000020E610000001000000050000007D9752978C9A55407847C66AF3714B407D9752978C9A5540284701A260744B40B728B341269B5540284701A260744B40B728B341269B55407847C66AF3714B407D9752978C9A55407847C66AF3714B40
41247	Свердловский	5	51	35	86.126408999999995	86.156422000000006	54.590285999999999	54.575786000000001	0103000020E61000000100000005000000E23AC6151788554051BF0B5BB3494B40E23AC61517885540B1A4DC7D8E4B4B40FF976BD1028A5540B1A4DC7D8E4B4B40FF976BD1028A554051BF0B5BB3494B40E23AC6151788554051BF0B5BB3494B40
60743	Родниковый	5	51	35	86.027000999999998	86.039308000000005	54.406821000000001	54.396973000000003	0103000020E6100000010000000500000065FD6662BA8155409032E202D0324B4065FD6662BA815540BB29E5B512344B40289EB30584825540BB29E5B512344B40289EB305848255409032E202D0324B4065FD6662BA8155409032E202D0324B40
7510	Ракитный	5	51	35	85.866607000000002	85.884241000000003	54.699773999999998	54.695362000000003	0103000020E6100000010000000500000005DF347D76775540CA703C9F01594B4005DF347D76775540A94BC63192594B401232906797785540A94BC63192594B401232906797785540CA703C9F01594B4005DF347D76775540CA703C9F01594B40
6030	Поселок Клейзавода	5	51	35	86.065969999999993	86.088734000000002	54.716455000000003	54.686604000000003	0103000020E6100000010000000500000018213CDA38845540C2A6CEA3E2574B4018213CDA38845540210725CCB45B4B40C5025FD1AD855540210725CCB45B4B40C5025FD1AD855540C2A6CEA3E2574B4018213CDA38845540C2A6CEA3E2574B40
41071	Полысаево	5	51	35	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
46276	Подгорное	5	51	35	85.990054000000001	86.019456000000005	54.495977000000003	54.48115	0103000020E6100000010000000500000089D1730B5D7F5540363CBD52963D4B4089D1730B5D7F5540BB48A12C7C3F4B4081ED60C43E815540BB48A12C7C3F4B4081ED60C43E815540363CBD52963D4B4089D1730B5D7F5540363CBD52963D4B40
46618	Панфилово	5	51	35	86.366529	86.394043999999994	54.960110999999998	54.934055000000001	0103000020E6100000010000000500000047020D367597554028D53E1D8F774B4047020D3675975540D2C3D0EAE47A4B40D74B530438995540D2C3D0EAE47A4B40D74B53043899554028D53E1D8F774B4047020D367597554028D53E1D8F774B40
46398	Павловка	5	51	35	86.072609	86.104292999999998	54.502370999999997	54.498142000000001	0103000020E610000001000000050000004C1938A0A5845540CC61F71DC33F4B404C1938A0A5845540BABA63B14D404B40E90C8CBCAC865540BABA63B14D404B40E90C8CBCAC865540CC61F71DC33F4B404C1938A0A5845540CC61F71DC33F4B40
46748	Орловский	5	51	35	85.732991999999996	85.740680999999995	54.801903000000003	54.785164000000002	0103000020E61000000100000005000000B20E4757E96E55408FFF024180644B40B20E4757E96E55403BC8EBC1A4664B4030F14751676F55403BC8EBC1A4664B4030F14751676F55408FFF024180644B40B20E4757E96E55408FFF024180644B40
7013	Новопокровка	5	51	35	86.452695000000006	86.466448	54.664468999999997	54.653053	0103000020E61000000100000005000000040473F4F89C554000C79E3D97534B40040473F4F89C5540581AF8510D554B403752B648DA9D5540581AF8510D554B403752B648DA9D554000C79E3D97534B40040473F4F89C554000C79E3D97534B40
7590	Новопокасьма	5	51	35	85.876749000000004	85.915852999999998	54.710324	54.701928000000002	0103000020E610000001000000050000003F73D6A71C785540C712D6C6D8594B403F73D6A71C7855402EC896E5EB5A4B4062BCE6559D7A55402EC896E5EB5A4B4062BCE6559D7A5540C712D6C6D8594B403F73D6A71C785540C712D6C6D8594B40
7645	Новогородец	5	51	35	86.030288999999996	86.051614999999998	54.617759	54.606662999999998	0103000020E610000001000000050000006D1B4641F0815540BC581822A74D4B406D1B4641F0815540A3E716BA124F4B40EA3E00A94D835540A3E716BA124F4B40EA3E00A94D835540BC581822A74D4B406D1B4641F0815540BC581822A74D4B40
41240	Новогеоргиевка	5	51	35	86.310329999999993	86.333434999999994	54.708368	54.685656000000002	0103000020E61000000100000005000000EE3D5C72DC93554031276893C3574B40EE3D5C72DC93554037C478CDAB5A4B40DF15C1FF5695554037C478CDAB5A4B40DF15C1FF5695554031276893C3574B40EE3D5C72DC93554031276893C3574B40
8151	Мусохраново	5	51	35	85.757902000000001	85.791471999999999	54.716465999999997	54.703831999999998	0103000020E61000000100000005000000ACE46377817055406BF0BE2A175A4B40ACE463778170554014596B28B55B4B40C8EC2C7AA772554014596B28B55B4B40C8EC2C7AA77255406BF0BE2A175A4B40ACE46377817055406BF0BE2A175A4B40
46512	Мирный	5	51	35	85.916904000000002	85.940196999999998	54.617393999999997	54.606439000000002	0103000020E6100000010000000500000095641D8EAE7A55406D020CCB9F4D4B4095641D8EAE7A5540915F3FC4064F4B4007B309302C7C5540915F3FC4064F4B4007B309302C7C55406D020CCB9F4D4B4095641D8EAE7A55406D020CCB9F4D4B40
43	Ленинск-Кузнецкий	5	51	35	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
6842	Красноярка	5	51	35	86.298544000000007	86.339391000000006	54.663775999999999	54.639034000000002	0103000020E61000000100000005000000B11A4B581B9355401B84B9DDCB514B40B11A4B581B93554052EFA99CF6544B40A2630795B895554052EFA99CF6544B40A2630795B89555401B84B9DDCB514B40B11A4B581B9355401B84B9DDCB514B40
41110	Красное	5	51	35	85.335172999999998	85.412751	54.618608000000002	54.594673	0103000020E6100000010000000500000024607479735555403868AF3E1E4C4B402460747973555540A185048C2E4F4B400B992B836A5A5540A185048C2E4F4B400B992B836A5A55403868AF3E1E4C4B4024607479735555403868AF3E1E4C4B40
7337	Красное	5	51	35	85.335172999999998	85.412751	54.618608000000002	54.594673	0103000020E6100000010000000500000024607479735555403868AF3E1E4C4B402460747973555540A185048C2E4F4B400B992B836A5A5540A185048C2E4F4B400B992B836A5A55403868AF3E1E4C4B4024607479735555403868AF3E1E4C4B40
60753	Красная Поляна	5	51	35	86.192982999999998	86.201938999999996	54.739789000000002	54.727209000000002	0103000020E61000000100000005000000C66B5ED5598C5540AE2D3C2F155D4B40C66B5ED5598C55406478EC67B15E4B405D328E91EC8C55406478EC67B15E4B405D328E91EC8C5540AE2D3C2F155D4B40C66B5ED5598C5540AE2D3C2F155D4B40
8574	Камышино	5	51	35	85.779650000000004	85.809510000000003	54.628329999999998	54.609912000000001	0103000020E61000000100000005000000E4141DC9E57155400FB8AE98114E4B40E4141DC9E57155403F8C101E6D504B403DF20703CF7355403F8C101E6D504B403DF20703CF7355400FB8AE98114E4B40E4141DC9E57155400FB8AE98114E4B40
60734	Егозово	5	51	35	86.106305000000006	86.119887000000006	54.717958000000003	54.709668000000001	0103000020E61000000100000005000000AF997CB3CD8655404582A966D65A4B40AF997CB3CD86554067F3380CE65B4B40CC0D863AAC87554067F3380CE65B4B40CC0D863AAC8755404582A966D65A4B40AF997CB3CD8655404582A966D65A4B40
6657	Драченино	5	51	35	86.022941000000003	86.055244999999999	54.775345000000002	54.748728	0103000020E61000000100000005000000342F87DD77815540BCCCB051D65F4B40342F87DD77815540FE0E45813E634B401F11532289835540FE0E45813E634B401F11532289835540BCCCB051D65F4B40342F87DD77815540BCCCB051D65F4B40
41234	Демьяновка	5	51	35	86.230147000000002	86.261551999999995	54.762298000000001	54.738920999999998	0103000020E6100000010000000500000071917BBABA8E5540EFA99CF6945E4B4071917BBABA8E554032E719FB92614B40048D9944BD90554032E719FB92614B40048D9944BD905540EFA99CF6945E4B4071917BBABA8E5540EFA99CF6945E4B40
6005	Восходящий	5	51	35	86.060715000000002	86.088194999999999	54.689622	54.678426999999999	0103000020E610000001000000050000001BD82AC1E283554098DC28B2D6564B401BD82AC1E2835540124DA08845584B40ED2AA4FCA4855540124DA08845584B40ED2AA4FCA485554098DC28B2D6564B401BD82AC1E283554098DC28B2D6564B40
7701	Возвышенка	5	51	35	85.854004000000003	85.872680000000003	54.573923000000001	54.566046999999998	0103000020E61000000100000005000000CEA96400A8765540DC7F643A74484B40CEA96400A87655400BB6114F76494B40E4F736FDD97755400BB6114F76494B40E4F736FDD9775540DC7F643A74484B40CEA96400A8765540DC7F643A74484B40
41125	Ариничево	5	51	35	85.396618000000004	85.423908999999995	54.569043000000001	54.545000000000002	0103000020E6100000010000000500000051C0763062595540F6285C8FC2454B4051C07630625955404582A966D6484B40B9DE3653215B55404582A966D6484B40B9DE3653215B5540F6285C8FC2454B4051C0763062595540F6285C8FC2454B40
5759	Шевели	5	51	613	86.333613999999997	86.363735000000005	55.078288000000001	55.064596999999999	0103000020E6100000010000000500000037DF88EE59955540B935E9B644884B4037DF88EE59955540AAD55757058A4B40475A2A6F47975540AAD55757058A4B40475A2A6F47975540B935E9B644884B4037DF88EE59955540B935E9B644884B40
5283	Тараданово	5	51	613	86.669863000000007	86.704393999999994	54.760058999999998	54.738847999999997	0103000020E610000001000000050000003B730F09DFAA5540855B3E92925E4B403B730F09DFAA5540E603029D49614B40E95F92CA14AD5540E603029D49614B40E95F92CA14AD5540855B3E92925E4B403B730F09DFAA5540855B3E92925E4B40
4517	Скарюпино	5	51	613	86.223122000000004	86.257033000000007	54.965480999999997	54.954884	0103000020E6100000010000000500000029417FA1478E5540A1BC8FA3397A4B4029417FA1478E554066F4A3E1947B4B408A3F8A3A7390554066F4A3E1947B4B408A3F8A3A73905540A1BC8FA3397A4B4029417FA1478E5540A1BC8FA3397A4B40
5922	Сарапки	5	51	613	86.396703000000002	86.432042999999993	55.074896000000003	55.063622000000002	0103000020E6100000010000000500000068CEFA94639955402FA704C424884B4068CEFA9463995540F54C2F3196894B40CEDDAE97A69B5540F54C2F3196894B40CEDDAE97A69B55402FA704C424884B4068CEFA94639955402FA704C424884B40
5185	Поперечное	5	51	613	86.780248	86.800882000000001	54.874656999999999	54.859434999999998	0103000020E610000001000000050000003EB14E95EFB15540D50451F7016E4B403EB14E95EFB15540D61BB5C2F46F4B40207D93A641B35540D61BB5C2F46F4B40207D93A641B35540D50451F7016E4B403EB14E95EFB15540D50451F7016E4B40
60774	Плотниковский	5	51	613	86.475530000000006	86.490747999999996	55.018045000000001	55.009419000000001	0103000020E61000000100000005000000159161156F9E5540037B4CA434814B40159161156F9E55409C6D6E4C4F824B40F4A44C6A689F55409C6D6E4C4F824B40F4A44C6A689F5540037B4CA434814B40159161156F9E5540037B4CA434814B40
5439	Перехляй	5	51	613	86.54974	86.589697000000001	54.892411000000003	54.872264000000001	0103000020E610000001000000050000006553AEF02EA3554034BDC458A66F4B406553AEF02EA355409BCB0D863A724B4028637C98BDA555409BCB0D863A724B4028637C98BDA5554034BDC458A66F4B406553AEF02EA3554034BDC458A66F4B40
60777	Новобарачаты	5	51	613	86.161955000000006	86.182175999999998	55.052221000000003	55.039729000000001	0103000020E610000001000000050000001E1B81785D8A5540F5D901D715854B401E1B81785D8A55400C957F2DAF864B406E8786C5A88B55400C957F2DAF864B406E8786C5A88B5540F5D901D715854B401E1B81785D8A5540F5D901D715854B40
4339	Михайловский	5	51	613	86.638637000000003	86.647630000000007	55.004928	54.997729	0103000020E61000000100000005000000FF40B96DDFA85540A9A27895B57F4B40FF40B96DDFA85540D76A0F7BA1804B40257A19C572A95540D76A0F7BA1804B40257A19C572A95540A9A27895B57F4B40FF40B96DDFA85540A9A27895B57F4B40
5093	Междугорное	5	51	613	86.818696000000003	86.840686000000005	54.943080000000002	54.921354999999998	0103000020E610000001000000050000006D57E88365B45540C780ECF5EE754B406D57E88365B455407FC16ED8B6784B40200DA7CCCDB555407FC16ED8B6784B40200DA7CCCDB55540C780ECF5EE754B406D57E88365B45540C780ECF5EE754B40
4682	Максимово	5	51	613	86.521794	86.538915000000003	54.831254999999999	54.825420999999999	0103000020E61000000100000005000000F04FA91265A155403F373465A7694B40F04FA91265A1554078D15790666A4B40BA1457957DA2554078D15790666A4B40BA1457957DA255403F373465A7694B40F04FA91265A155403F373465A7694B40
60754	Красные Ключи	5	51	613	86.256719000000004	86.276229999999998	55.003394	54.992193	0103000020E61000000100000005000000C25087156E905540FA28232E007F4B40C25087156E9055405680EF366F804B40240B98C0AD9155405680EF366F804B40240B98C0AD915540FA28232E007F4B40C25087156E905540FA28232E007F4B40
3886	Крапивинский	5	51	613	86.763997000000003	86.835403999999997	55.031298	54.981954999999999	0103000020E610000001000000050000007F4FAC53E5B05540649291B3B07D4B407F4FAC53E5B055401137A79201844B40A5BC564277B555401137A79201844B40A5BC564277B55540649291B3B07D4B407F4FAC53E5B05540649291B3B07D4B40
5125	Ключи	5	51	613	86.82696	86.858743000000004	54.778818999999999	54.771227000000003	0103000020E6100000010000000500000069C6A2E9ECB455406765FB90B7624B4069C6A2E9ECB4554070404B57B0634B40D02A33A5F5B6554070404B57B0634B40D02A33A5F5B655406765FB90B7624B4069C6A2E9ECB455406765FB90B7624B40
5262	Каменный	5	51	613	86.707915	86.733410000000006	54.961221999999999	54.944895000000002	0103000020E610000001000000050000004356B77A4EAD5540B493C151F2784B404356B77A4EAD55400D198F52097B4B40CD237F30F0AE55400D198F52097B4B40CD237F30F0AE5540B493C151F2784B404356B77A4EAD5540B493C151F2784B40
4842	Каменка	5	51	613	86.691854000000006	86.717491999999993	54.805515	54.793053999999998	0103000020E61000000100000005000000D6E6FF5547AC554022FB20CB82654B40D6E6FF5547AC5540FEB7921D1B674B4010C99063EBAD5540FEB7921D1B674B4010C99063EBAD554022FB20CB82654B40D6E6FF5547AC554022FB20CB82654B40
4234	Зеленогорский	5	51	613	86.938638999999995	86.976637999999994	55.009172	54.996727	0103000020E6100000010000000500000002F04FA912BC5540250516C0947F4B4002F04FA912BC5540FB04508C2C814B40F981AB3C81BE5540FB04508C2C814B40F981AB3C81BE5540250516C0947F4B4002F04FA912BC5540250516C0947F4B40
60731	Зеленовский	5	51	613	86.382194999999996	86.397008999999997	55.011597999999999	54.989130000000003	0103000020E61000000100000005000000766C04E2759855400ABFD4CF9B7E4B40766C04E2759855407959130B7C814B40EECD6F98689955407959130B7C814B40EECD6F98689955400ABFD4CF9B7E4B40766C04E2759855400ABFD4CF9B7E4B40
5608	Долгополово	5	51	613	86.595517999999998	86.614221000000001	54.779654999999998	54.769413999999998	0103000020E610000001000000050000007A8B87F71CA65540D28A6F287C624B407A8B87F71CA65540D9942BBCCB634B400DE198654FA75540D9942BBCCB634B400DE198654FA75540D28A6F287C624B407A8B87F71CA65540D28A6F287C624B40
4621	Борисово	5	51	613	86.543711999999999	86.585170000000005	54.819662999999998	54.796531999999999	0103000020E61000000100000005000000569C6A2DCCA25540D61BB5C2F4654B40569C6A2DCCA25540E15E99B7EA684B406C26DF6C73A55540E15E99B7EA684B406C26DF6C73A55540D61BB5C2F4654B40569C6A2DCCA25540D61BB5C2F4654B40
5768	Березовка	5	51	613	86.497664999999998	86.518613999999999	55.129565999999997	55.110284999999998	0103000020E6100000010000000500000049D74CBED99F5540A31EA2D11D8E4B4049D74CBED99F55403656629E95904B40DB4FC6F830A155403656629E95904B40DB4FC6F830A15540A31EA2D11D8E4B4049D74CBED99F5540A31EA2D11D8E4B40
5534	Бердюгино	5	51	613	86.471604999999997	86.494197	54.87144	54.859952999999997	0103000020E6100000010000000500000053E8BCC62E9E55406D8C9DF0126E4B4053E8BCC62E9E55408F368E588B6F4B40013274ECA09F55408F368E588B6F4B40013274ECA09F55406D8C9DF0126E4B4053E8BCC62E9E55406D8C9DF0126E4B40
4404	Барачаты	5	51	613	86.183102000000005	86.221845999999999	54.982771	54.966648999999997	0103000020E61000000100000005000000437573F1B78B554005DB8827BB7B4B40437573F1B78B5540863AAC70CB7D4B40E6AF90B9328E5540863AAC70CB7D4B40E6AF90B9328E554005DB8827BB7B4B40437573F1B78B554005DB8827BB7B4B40
4254	Банново	5	51	613	86.690398000000002	86.726933000000002	55.092041000000002	55.076602000000001	0103000020E6100000010000000500000053CE177B2FAC554073672618CE894B4053CE177B2FAC55401172DEFFC78B4B408658FD1186AE55401172DEFFC78B4B408658FD1186AE554073672618CE894B4053CE177B2FAC554073672618CE894B40
4991	Арсеново	5	51	613	86.866809000000003	86.886977000000002	54.807259000000002	54.799542000000002	0103000020E6100000010000000500000039B874CC79B75540A4E36A6457664B4039B874CC79B755406A334E4354674B4078D32D3BC4B855406A334E4354674B4078D32D3BC4B85540A4E36A6457664B4039B874CC79B75540A4E36A6457664B40
60710	Киселевск	5	51	7515	87.123844000000005	87.125703999999999	53.740093999999999	53.737985000000002	0103000020E610000001000000050000009373620FEDC7554023F8DF4A76DE4A409373620FEDC75540A0FB7266BBDE4A407D3ECA880BC85540A0FB7266BBDE4A407D3ECA880BC8554023F8DF4A76DE4A409373620FEDC7554023F8DF4A76DE4A40
41184	Ягуново	5	51	384	85.977406000000002	86.025419999999997	55.258592	55.234614999999998	0103000020E61000000100000005000000823AE5D18D7E5540551344DD079E4B40823AE5D18D7E5540ED80EB8A19A14B40842A357BA0815540ED80EB8A19A14B40842A357BA0815540551344DD079E4B40823AE5D18D7E5540551344DD079E4B40
3495	Щегловский	5	51	384	85.909312999999997	85.937466000000001	55.568618999999998	55.557169000000002	0103000020E61000000100000005000000F834272F327A55402AAC545051C74B40F834272F327A55402E71E481C8C84B402AC76471FF7B55402E71E481C8C84B402AC76471FF7B55402AAC545051C74B40F834272F327A55402AAC545051C74B40
3269	Черемушки	5	51	384	85.911738999999997	85.924315000000007	55.613686999999999	55.607559999999999	0103000020E6100000010000000500000037DF88EE597A5540CB2DAD86C4CD4B4037DF88EE597A55407C7DAD4B8DCE4B40F20C1AFA277B55407C7DAD4B8DCE4B40F20C1AFA277B5540CB2DAD86C4CD4B4037DF88EE597A5540CB2DAD86C4CD4B40
3401	Усть-Хмелевка	5	51	384	85.798084000000003	85.810147999999998	55.628551000000002	55.615304000000002	0103000020E610000001000000050000007FDDE9CE137355408B8C0E48C2CE4B407FDDE9CE137355401E6FF25B74D04B40DE3AFF76D97355401E6FF25B74D04B40DE3AFF76D97355408B8C0E48C2CE4B407FDDE9CE137355408B8C0E48C2CE4B40
2099	Успенка	5	51	384	86.579240999999996	86.611965999999995	55.721828000000002	55.700557000000003	0103000020E6100000010000000500000026E0D74812A55540F0FD0DDAABD94B4026E0D74812A5554026AB22DC64DC4B40E41071732AA7554026AB22DC64DC4B40E41071732AA75540F0FD0DDAABD94B4026E0D74812A55540F0FD0DDAABD94B40
2565	Тебеньковка	5	51	384	86.348804999999999	86.367058999999998	55.365678000000003	55.354773000000002	0103000020E610000001000000050000009AEB34D2529655407D40A03369AD4B409AEB34D252965540F06E6589CEAE4B40F52C08E57D975540F06E6589CEAE4B40F52C08E57D9755407D40A03369AD4B409AEB34D2529655407D40A03369AD4B40
41176	Сухая Речка	5	51	384	86.105639999999994	86.132238999999998	55.241703999999999	55.235030999999999	0103000020E61000000100000005000000904946CEC2865540E945ED7E159E4B40904946CEC2865540FCA71B28F09E4B405E10919A76885540FCA71B28F09E4B405E10919A76885540E945ED7E159E4B40904946CEC2865540E945ED7E159E4B40
2778	Старочервово	5	51	384	86.354303000000002	86.378889999999998	55.170614	55.150849000000001	0103000020E61000000100000005000000FB777DE6AC96554031D120054F934B40FB777DE6AC965540B01EF7ADD6954B4003B2D7BB3F985540B01EF7ADD6954B4003B2D7BB3F98554031D120054F934B40FB777DE6AC96554031D120054F934B40
48904	Сосновка 2-я	5	51	384	86.004138999999995	86.016886	55.846659000000002	55.835599000000002	0103000020E61000000100000005000000D76839D04380554000C974E8F4EA4B40D76839D0438055409AEE75525FEC4B40A87004A9148155409AEE75525FEC4B40A87004A91481554000C974E8F4EA4B40D76839D04380554000C974E8F4EA4B40
2675	Силино	5	51	384	86.285914000000005	86.309396000000007	55.275047000000001	55.261054000000001	0103000020E61000000100000005000000FDDD3B6A4C925540B83EAC376AA14B40FDDD3B6A4C92554074EE76BD34A34B40D960E124CD93554074EE76BD34A34B40D960E124CD935540B83EAC376AA14B40FDDD3B6A4C925540B83EAC376AA14B40
1979	Разведчик	5	51	384	86.149523000000002	86.169070000000005	55.744627000000001	55.723775000000003	0103000020E61000000100000005000000FDBFEAC891895540CA54C1A8A4DC4B40FDBFEAC891895540FB5B02F04FDF4B40062FFA0AD28A5540FB5B02F04FDF4B40062FFA0AD28A5540CA54C1A8A4DC4B40FDBFEAC891895540CA54C1A8A4DC4B40
60866	Промышленновский	5	51	384	86.139623	86.213806000000005	55.512469000000003	55.455039999999997	0103000020E610000001000000050000003EB14E95EF885540982F2FC03EBA4B403EB14E95EF8855405F9B8D9598C14B40126C5CFFAE8D55405F9B8D9598C14B40126C5CFFAE8D5540982F2FC03EBA4B403EB14E95EF885540982F2FC03EBA4B40
3361	Подъяково	5	51	384	85.819428000000002	85.841292999999993	55.572018999999997	55.555509000000001	0103000020E610000001000000050000004F5B2382717455401CD13DEB1AC74B404F5B23827174554066D828EB37C94B40A35698BED775554066D828EB37C94B40A35698BED77555401CD13DEB1AC74B404F5B2382717455401CD13DEB1AC74B40
2667	Осиновка	5	51	384	86.287863000000002	86.320651999999995	55.393773000000003	55.385249000000002	0103000020E610000001000000050000009FAEEE586C9255408AE8D7D64FB14B409FAEEE586C9255401F86562767B24B406859F78F859455401F86562767B24B406859F78F859455408AE8D7D64FB14B409FAEEE586C9255408AE8D7D64FB14B40
2330	Новостройка	5	51	384	86.195418000000004	86.239444000000006	55.261526000000003	55.241160000000001	0103000020E610000001000000050000002FC37FBA818C55403B8DB454DE9E4B402FC37FBA818C5540E08618AF79A14B404D4EED0C538F5540E08618AF79A14B404D4EED0C538F55403B8DB454DE9E4B402FC37FBA818C55403B8DB454DE9E4B40
60726	Мазурово	5	51	384	85.729478999999998	86.659101000000007	55.866556000000003	55.104754	0103000020E610000001000000050000009A07B0C8AF6E554006103E94688D4B409A07B0C8AF6E55408813984EEBEE4B40B3F0F5B52EAA55408813984EEBEE4B40B3F0F5B52EAA554006103E94688D4B409A07B0C8AF6E554006103E94688D4B40
2220	Кузбасский	5	51	384	86.138366000000005	86.172141999999994	55.150272999999999	55.133600999999999	0103000020E61000000100000005000000373811FDDA88554040DB6AD619914B40373811FDDA885540643C4A253C934B402711E15F048B5540643C4A253C934B402711E15F048B554040DB6AD619914B40373811FDDA88554040DB6AD619914B40
45980	Кедровка	5	51	384	86.075869999999995	86.128888000000003	55.530372999999997	55.499299999999998	0103000020E61000000100000005000000D72FD80DDB8455404772F90FE9BF4B40D72FD80DDB84554038D73043E3C34B40333674B33F88554038D73043E3C34B40333674B33F8855404772F90FE9BF4B40D72FD80DDB8455404772F90FE9BF4B40
2790	Звездный	5	51	384	85.837682000000001	85.860211000000007	55.460594	55.449734999999997	0103000020E61000000100000005000000AA9CF6949C755540EB6E9EEA90B94B40AA9CF6949C755540EE5D83BEF4BA4B40352A70B20D775540EE5D83BEF4BA4B40352A70B20D775540EB6E9EEA90B94B40AA9CF6949C755540EB6E9EEA90B94B40
3456	Верхотомское	5	51	384	85.932525999999996	85.975258999999994	55.491762999999999	55.459260999999998	0103000020E61000000100000005000000DC2A8881AE7B554004AA7F10C9BA4B40DC2A8881AE7B554001310917F2BE4B404C88B9A46A7E554001310917F2BE4B404C88B9A46A7E554004AA7F10C9BA4B40DC2A8881AE7B554004AA7F10C9BA4B40
41093	Благодатный	5	51	384	85.803670999999994	85.823452000000003	55.406002000000001	55.395935999999999	0103000020E61000000100000005000000976F7D586F7355408FA7E507AEB24B40976F7D586F735540280EA0DFF7B34B40DA740470B3745540280EA0DFF7B34B40DA740470B37455408FA7E507AEB24B40976F7D586F7355408FA7E507AEB24B40
2325	Березово	5	51	384	86.221971999999994	86.259432000000004	55.244829000000003	55.220993	0103000020E610000001000000050000002C280CCA348E55408DD2A57F499C4B402C280CCA348E5540630E828E569F4B404CE2AC889A905540630E828E569F4B404CE2AC889A9055408DD2A57F499C4B402C280CCA348E55408DD2A57F499C4B40
2209	Береговая	5	51	384	86.294655000000006	86.324145999999999	55.154944	55.120793999999997	0103000020E610000001000000050000009626A5A0DB925540C9C6832D768F4B409626A5A0DB925540105B7A34D5934B404548DDCEBE945540105B7A34D5934B404548DDCEBE945540C9C6832D768F4B409626A5A0DB925540C9C6832D768F4B40
3256	Барановка	5	51	384	85.932830999999993	85.973516000000004	55.650658	55.626278999999997	0103000020E610000001000000050000007A6CCB80B37B5540F69507E929D04B407A6CCB80B37B5540BD70E7C248D34B407F880D164E7E5540BD70E7C248D34B407F880D164E7E5540F69507E929D04B407A6CCB80B37B5540F69507E929D04B40
2449	Андреевка	5	51	384	86.198561999999995	86.236937999999995	55.453524000000002	55.435059000000003	0103000020E610000001000000050000009D0E643DB58C55404D6A6803B0B74B409D0E643DB58C5540BEF90D130DBA4B407F4B00FE298F5540BEF90D130DBA4B407F4B00FE298F55404D6A6803B0B74B409D0E643DB58C55404D6A6803B0B74B40
60804	Малиновка	5	51	7521	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
29220	Тёплая Речка	5	51	26	86.649632999999994	86.668317999999999	56.353085999999998	56.335101000000002	0103000020E61000000100000005000000C0594A9693A95540AFEDED96E42A4C40C0594A9693A9554075560BEC312D4C400055DCB8C5AA554075560BEC312D4C400055DCB8C5AA5540AFEDED96E42A4C40C0594A9693A95540AFEDED96E42A4C40
1396	Тунда	5	51	26	87.054180000000002	87.083573000000001	56.022398000000003	56.015742000000003	0103000020E610000001000000050000003A0664AF77C355403A9677D503024C403A0664AF77C3554077BF0AF0DD024C400875914259C5554077BF0AF0DD024C400875914259C555403A9677D503024C403A0664AF77C355403A9677D503024C40
48851	Троицкое	5	51	26	86.868938999999997	86.897729999999996	56.070735999999997	56.043667999999997	0103000020E6100000010000000500000003CE52B29CB75540DCF0BBE996054C4003CE52B29CB755402E5393E00D094C40D6A8876874B955402E5393E00D094C40D6A8876874B95540DCF0BBE996054C4003CE52B29CB75540DCF0BBE996054C40
1313	Симбирка	5	51	26	87.140480999999994	87.179989000000006	56.049520999999999	56.032429	0103000020E61000000100000005000000662D05A4FDC8554093382BA226044C40662D05A4FDC855408CBB41B456064C40F22895F084CB55408CBB41B456064C40F22895F084CB554093382BA226044C40662D05A4FDC8554093382BA226044C40
48559	Святославка	5	51	26	86.789446999999996	86.827032000000003	56.444403999999999	56.428981	0103000020E6100000010000000500000038BBB54C86B255407DCD72D9E8364C4038BBB54C86B25540151BF33AE2384C40B62FA017EEB45540151BF33AE2384C40B62FA017EEB455407DCD72D9E8364C4038BBB54C86B255407DCD72D9E8364C40
1522	Почитанка	5	51	26	86.678450999999995	86.707035000000005	56.295070000000003	56.276803000000001	0103000020E61000000100000005000000103CBEBD6BAB5540A437DC476E234C40103CBEBD6BAB5540EF0390DAC4254C402788BA0F40AD5540EF0390DAC4254C402788BA0F40AD5540A437DC476E234C40103CBEBD6BAB5540A437DC476E234C40
41170	Постниково	5	51	26	86.756308000000004	86.792689999999993	56.248210999999998	56.236725999999997	0103000020E61000000100000005000000016DAB5967B05540730E9E094D1E4C40016DAB5967B05540F4C0C760C51F4C407077D66EBBB25540F4C0C760C51F4C407077D66EBBB25540730E9E094D1E4C40016DAB5967B05540730E9E094D1E4C40
48577	Островка	5	51	26	86.928702999999999	86.971840999999998	56.382311999999999	56.371865	0103000020E610000001000000050000009D2CB5DE6FBB554076C3B645992F4C409D2CB5DE6FBB5540266F8099EF304C405DFA97A432BE5540266F8099EF304C405DFA97A432BE554076C3B645992F4C409D2CB5DE6FBB554076C3B645992F4C40
48428	Ольговка	5	51	26	86.363465000000005	86.377470000000002	56.561045999999997	56.54589	0103000020E61000000100000005000000670FB40243975540529B38B9DF454C40670FB402439755409BC6F65AD0474C40274EEE77289855409BC6F65AD0474C40274EEE7728985540529B38B9DF454C40670FB40243975540529B38B9DF454C40
48498	Новый Свет	5	51	26	86.820887999999997	86.846587999999997	55.832828999999997	55.819403000000001	0103000020E61000000100000005000000726BD26D89B45540459F8F32E2E84B40726BD26D89B45540871403249AEA4B40E84B6F7F2EB65540871403249AEA4B40E84B6F7F2EB65540459F8F32E2E84B40726BD26D89B45540459F8F32E2E84B40
1161	Новославянка	5	51	26	86.764212999999998	86.805059	56.546292000000001	56.523915000000002	0103000020E61000000100000005000000658BA4DDE8B0554022718FA50F434C40658BA4DDE8B05540810871E5EC454C406E162F1686B35540810871E5EC454C406E162F1686B3554022718FA50F434C40658BA4DDE8B0554022718FA50F434C40
48639	Новоорловка	5	51	26	86.662739000000002	86.691979000000003	56.569374000000003	56.561528000000003	0103000020E6100000010000000500000029B2D6506AAA5540E7E44526E0474C4029B2D6506AAA5540AB984A3FE1484C4034A1496249AC5540AB984A3FE1484C4034A1496249AC5540E7E44526E0474C4029B2D6506AAA5540E7E44526E0474C40
48466	Нижегородка	5	51	26	86.600468000000006	86.614203000000003	56.418357999999998	56.398456000000003	0103000020E61000000100000005000000DA9255116EA655408F72309B00334C40DA9255116EA655408E0244C18C354C40BA86191A4FA755408E0244C18C354C40BA86191A4FA755408F72309B00334C40DA9255116EA655408F72309B00334C40
41086	Ломачевка	5	51	26	86.816091	86.845448000000005	56.140464000000001	56.132303	0103000020E61000000100000005000000D6E3BED53AB45540D314014EEF104C40D6E3BED53AB45540F7216FB9FA114C40FE9DEDD11BB65540F7216FB9FA114C40FE9DEDD11BB65540D314014EEF104C40D6E3BED53AB45540D314014EEF104C40
1390	Летяжка	5	51	26	87.181884999999994	87.194226999999998	56.000120000000003	55.979585999999998	0103000020E6100000010000000500000082A8FB00A4CB55404ACFF41263FD4B4082A8FB00A4CB5540AB09A2EE03004C40034015376ECC5540AB09A2EE03004C40034015376ECC55404ACFF41263FD4B4082A8FB00A4CB55404ACFF41263FD4B40
41165	Левашовка	5	51	26	86.898295000000005	86.928398000000001	56.541632	56.52966	0103000020E6100000010000000500000043CA4FAA7DB95540EBFF1CE6CB434C4043CA4FAA7DB95540C93B873254454C40FFEA71DF6ABB5540C93B873254454C40FFEA71DF6ABB5540EBFF1CE6CB434C4043CA4FAA7DB95540EBFF1CE6CB434C40
48501	Красный Яр	5	51	26	86.922792999999999	86.963639000000001	55.912072000000002	55.890492000000002	0103000020E6100000010000000500000093FE5E0A0FBB5540C1AC50A4FBF14B4093FE5E0A0FBB554075CC79C6BEF44B409C89E942ACBD554075CC79C6BEF44B409C89E942ACBD5540C1AC50A4FBF14B4093FE5E0A0FBB5540C1AC50A4FBF14B40
923	Красная Тайга	5	51	26	86.875370000000004	86.893219999999999	55.905093999999998	55.897402	0103000020E610000001000000050000009279E40F06B85540B8AE9811DEF24B409279E40F06B8554025E7C41EDAF34B40850838842AB9554025E7C41EDAF34B40850838842AB95540B8AE9811DEF24B409279E40F06B85540B8AE9811DEF24B40
1057	Котовский	5	51	26	86.765649999999994	86.778172999999995	56.377347999999998	56.367122999999999	0103000020E61000000100000005000000AC8BDB6800B15540014EEFE2FD2E4C40AC8BDB6800B15540029B73F04C304C4055682096CDB15540029B73F04C304C4055682096CDB15540014EEFE2FD2E4C40AC8BDB6800B15540014EEFE2FD2E4C40
452	Колыон	5	51	26	86.535833999999994	86.571982000000006	56.482826000000003	56.464868000000003	0103000020E610000001000000050000006E85B01A4BA255407D7A6CCB803B4C406E85B01A4BA255404AD40B3ECD3D4C40A5F9635A9BA455404AD40B3ECD3D4C40A5F9635A9BA455407D7A6CCB803B4C406E85B01A4BA255407D7A6CCB803B4C40
183	Ижморский	5	51	26	86.608508	86.672602999999995	56.206916999999997	56.182191000000003	0103000020E61000000100000005000000AED689CBF1A655401250E10852174C40AED689CBF1A6554043FE99417C1A4C40410C74ED0BAB554043FE99417C1A4C40410C74ED0BAB55401250E10852174C40AED689CBF1A655401250E10852174C40
31	Ижморка 2-я	5	51	26	86.623491999999999	86.641295999999997	56.167754000000002	56.151201	0103000020E610000001000000050000005454FD4AE7A75540AE0FEB8D5A134C405454FD4AE7A75540F8E28BF678154C408FC360FE0AA95540F8E28BF678154C408FC360FE0AA95540AE0FEB8D5A134C405454FD4AE7A75540AE0FEB8D5A134C40
41077	Иверка	5	51	26	86.812911	86.842096999999995	55.948644000000002	55.938017000000002	0103000020E61000000100000005000000C1E3DBBB06B45540C80BE9F010F84B40C1E3DBBB06B45540F8C5A52A6DF94B40D2C3D0EAE4B55540F8C5A52A6DF94B40D2C3D0EAE4B55540C80BE9F010F84B40C1E3DBBB06B45540C80BE9F010F84B40
1756	Воскресенка	5	51	26	86.933464000000001	86.964618000000002	56.143613999999999	56.131439999999998	0103000020E6100000010000000500000093FFC9DFBDBB554070B1A206D3104C4093FFC9DFBDBB5540B69F8CF161124C4082C8224DBCBD5540B69F8CF161124C4082C8224DBCBD554070B1A206D3104C4093FFC9DFBDBB554070B1A206D3104C40
1500	Большая Песчанка	5	51	26	86.865758	86.889078999999995	56.239277999999999	56.231797999999998	0103000020E6100000010000000500000006103E9468B755409CA38E8EAB1D4C4006103E9468B755407E5358A9A01E4C40DD239BABE6B855407E5358A9A01E4C40DD239BABE6B855409CA38E8EAB1D4C4006103E9468B755409CA38E8EAB1D4C40
17165	Берикуль	5	51	26	87.051602000000003	87.079359999999994	56.213661000000002	56.205696000000003	0103000020E61000000100000005000000209A79724DC3554082751C3F541A4C40209A79724DC3554020B75F3E591B4C401327F73B14C5554020B75F3E591B4C401327F73B14C5554082751C3F541A4C40209A79724DC3554082751C3F541A4C40
48327	Азаново	5	51	26	86.553944000000001	86.589751000000007	56.120538000000003	56.106699999999996	0103000020E6100000010000000500000030F488D173A35540D93D7958A80D4C4030F488D173A355406FF607CA6D0F4C402272FA7ABEA555406FF607CA6D0F4C402272FA7ABEA55540D93D7958A80D4C4030F488D173A35540D93D7958A80D4C40
41059	Урск	5	51	1192	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
60742	Урск	5	51	1192	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
60779	Ур-Бедари	5	51	1192	85.921386999999996	85.954885000000004	54.450167	54.436453999999998	0103000020E6100000010000000500000069FD2D01F87A5540AC1A84B9DD374B4069FD2D01F87A5540855E7F129F394B40399CF9D51C7D5540855E7F129F394B40399CF9D51C7D5540AC1A84B9DD374B4069FD2D01F87A5540AC1A84B9DD374B40
41067	Сосновка	5	51	1192	85.704775999999995	85.746816999999993	54.302881999999997	54.284962999999998	0103000020E610000001000000050000005DC0CB0C1B6D5540F7C8E6AA79244B405DC0CB0C1B6D554006465ED6C4264B4032C687D9CB6F554006465ED6C4264B4032C687D9CB6F5540F7C8E6AA79244B405DC0CB0C1B6D5540F7C8E6AA79244B40
60783	Сосновка	5	51	1192	85.704775999999995	85.746816999999993	54.302881999999997	54.284962999999998	0103000020E610000001000000050000005DC0CB0C1B6D5540F7C8E6AA79244B405DC0CB0C1B6D554006465ED6C4264B4032C687D9CB6F554006465ED6C4264B4032C687D9CB6F5540F7C8E6AA79244B405DC0CB0C1B6D5540F7C8E6AA79244B40
41144	Салаир	5	51	1192	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
60741	Раздольный	5	51	1192	85.988669999999999	86.019509999999997	54.298189999999998	54.287537999999998	0103000020E610000001000000050000005322895E467F5540BA2D910BCE244B405322895E467F554043FF04172B264B407AFCDEA63F81554043FF04172B264B407AFCDEA63F815540BA2D910BCE244B405322895E467F5540BA2D910BCE244B40
60733	Новопестерево	5	51	1192	85.710398999999995	85.787330999999995	54.457019000000003	54.428049000000001	0103000020E610000001000000050000001C075E2D776D5540F20A444FCA364B401C075E2D776D554048533D997F3A4B40200890A16372554048533D997F3A4B40200890A163725540F20A444FCA364B401C075E2D776D5540F20A444FCA364B40
60700	Малая Салаирка	5	51	1192	85.928600000000003	85.964675999999997	54.335914000000002	54.321086999999999	0103000020E6100000010000000500000033C4B12E6E7B5540DB15FA6019294B4033C4B12E6E7B55406022DE3AFF2A4B401CCF6740BD7D55406022DE3AFF2A4B401CCF6740BD7D5540DB15FA6019294B4033C4B12E6E7B5540DB15FA6019294B40
41063	Гурьевск	5	51	1192	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
60748	Горскино	5	51	1192	85.610695000000007	85.645854999999997	54.477733999999998	54.454720999999999	0103000020E610000001000000050000002B357BA015675540F7E6374C343A4B402B357BA015675540F8174163263D4B4051BD35B055695540F8174163263D4B4051BD35B055695540F7E6374C343A4B402B357BA015675540F7E6374C343A4B40
60791	Гавриловка	5	51	1192	85.825473000000002	85.845343999999997	54.266658	54.254992999999999	0103000020E61000000100000005000000C9AEB48CD4745540BEDA519CA3204B40C9AEB48CD4745540BF9B6ED921224B40AB77B81D1A765540BF9B6ED921224B40AB77B81D1A765540BEDA519CA3204B40C9AEB48CD4745540BEDA519CA3204B40
60759	пос.ст.Разрез	5	51	890	85.866193999999993	87.515995000000004	54.669795000000001	54.107199999999999	0103000020E61000000100000005000000737FF5B86F775540CB10C7BAB80D4B40737FF5B86F7755401D03B2D7BB554B409279E40F06E155401D03B2D7BB554B409279E40F06E15540CB10C7BAB80D4B40737FF5B86F775540CB10C7BAB80D4B40
59361	микрорайон Старобелово	5	51	890	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
29862	имени Ильича	5	51	890	86.366421000000003	86.399756999999994	54.317332	54.305525000000003	0103000020E6100000010000000500000054E4107173975540228E75711B274B4054E4107173975540B5FCC0559E284B403656629E95995540B5FCC0559E284B403656629E95995540228E75711B274B4054E4107173975540228E75711B274B40
30736	Щебзавод	5	51	890	86.163257999999999	86.188851	54.210206999999997	54.186337000000002	0103000020E61000000100000005000000DDB3AED1728A554073840CE4D9174B40DDB3AED1728A5540F4311F10E81A4B4048348122168C5540F4311F10E81A4B4048348122168C554073840CE4D9174B40DDB3AED1728A554073840CE4D9174B40
30577	Шестаки	5	51	890	86.246334000000004	86.269169000000005	54.219574000000001	54.205641999999997	0103000020E610000001000000050000002579AEEFC38F55408E57207A521A4B402579AEEFC38F5540A58636001B1C4B4036069D103A915540A58636001B1C4B4036069D103A9155408E57207A521A4B402579AEEFC38F55408E57207A521A4B40
28713	Хахалино	5	51	890	86.519018000000003	86.534854999999993	54.478256999999999	54.473570000000002	0103000020E610000001000000050000004302469737A15540F12E17F19D3C4B404302469737A15540A20A7F86373D4B40884677103BA25540A20A7F86373D4B40884677103BA25540F12E17F19D3C4B404302469737A15540F12E17F19D3C4B40
28948	Уроп	5	51	890	86.666709999999995	86.685519999999997	54.53378	54.513756999999998	0103000020E61000000100000005000000A27A6B60ABAA5540A88B14CAC2414B40A27A6B60ABAA554023A12DE752444B404030478FDFAB554023A12DE752444B404030478FDFAB5540A88B14CAC2414B40A27A6B60ABAA5540A88B14CAC2414B40
30270	Убинский	5	51	890	86.302640999999994	86.333856999999995	54.482059999999997	54.474496000000002	0103000020E61000000100000005000000705B5B785E9355409A0AF148BC3C4B40705B5B785E935540D95A5F24B43D4B409A22C0E95D955540D95A5F24B43D4B409A22C0E95D9555409A0AF148BC3C4B40705B5B785E9355409A0AF148BC3C4B40
41123	Степной	5	51	890	86.469628	86.484936000000005	54.309685000000002	54.302672000000001	0103000020E610000001000000050000004C5299620E9E55401CB5C2F4BD264B404C5299620E9E5540E88711C2A3274B40CC290131099F5540E88711C2A3274B40CC290131099F55401CB5C2F4BD264B404C5299620E9E55401CB5C2F4BD264B40
28464	Старопестерево	5	51	890	86.358642000000003	86.427012000000005	54.507150000000003	54.488242999999997	0103000020E61000000100000005000000363E93FDF39655401EC022BF7E3E4B40363E93FDF39655404D158C4AEA404B40F9BF232A549B55404D158C4AEA404B40F9BF232A549B55401EC022BF7E3E4B40363E93FDF39655401EC022BF7E3E4B40
30340	Старобачаты	5	51	890	86.149998999999994	86.234485000000006	54.261051999999999	54.220199999999998	0103000020E61000000100000005000000B1DB679599895540234A7B832F1C4B40B1DB6795998955401747E5266A214B40C4995FCD018F55401747E5266A214B40C4995FCD018F5540234A7B832F1C4B40B1DB679599895540234A7B832F1C4B40
28579	Снежинский	5	51	890	86.365289000000004	86.379086999999998	54.444026000000001	54.435769000000001	0103000020E61000000100000005000000AB251DE56097554029CE5147C7374B40AB251DE5609755406F490ED8D5384B40AED51EF6429855406F490ED8D5384B40AED51EF64298554029CE5147C7374B40AB251DE56097554029CE5147C7374B40
41124	Сидоренково	5	51	890	86.577121000000005	86.607483999999999	54.383211000000003	54.368889000000003	0103000020E610000001000000050000006E35EB8CEFA45540556D37C1372F4B406E35EB8CEFA45540D63BDC0E0D314B40F8359204E1A65540D63BDC0E0D314B40F8359204E1A65540556D37C1372F4B406E35EB8CEFA45540556D37C1372F4B40
41122	Рямовая	5	51	890	86.917716999999996	86.940876000000003	54.564	54.554983999999997	0103000020E61000000100000005000000ED7E15E0BBBA5540D1E638B709474B40ED7E15E0BBBA5540D578E92631484B40D865F84F37BC5540D578E92631484B40D865F84F37BC5540D1E638B709474B40ED7E15E0BBBA5540D1E638B709474B40
23478	Проектная	5	51	890	86.232957999999996	86.246244000000004	54.550091999999999	54.540309999999998	0103000020E61000000100000005000000DCD5ABC8E88E5540D3D9C9E028454B40DCD5ABC8E88E554047E5266A69464B4085B53176C28F554047E5266A69464B4085B53176C28F5540D3D9C9E028454B40DCD5ABC8E88E5540D3D9C9E028454B40
29218	Поморцево	5	51	890	86.511373000000006	86.532662999999999	54.403294000000002	54.386913	0103000020E61000000100000005000000ADC3D155BAA05540D9B27C5D86314B40ADC3D155BAA05540265646239F334B4083328D2617A25540265646239F334B4083328D2617A25540D9B27C5D86314B40ADC3D155BAA05540D9B27C5D86314B40
41130	Пермяки	5	51	890	86.884649999999993	86.950479000000001	54.478033000000003	54.453313000000001	0103000020E61000000100000005000000029A081B9EB8554003ED0E29063A4B40029A081B9EB8554053B4722F303D4B403A22DFA5D4BC554053B4722F303D4B403A22DFA5D4BC554003ED0E29063A4B40029A081B9EB8554003ED0E29063A4B40
29453	Новый Каракан	5	51	890	86.700343000000004	86.715110999999993	54.395657	54.388722000000001	0103000020E61000000100000005000000E23E726BD2AC55402C9E7AA4C1314B40E23E726BD2AC55407CB779E3A4324B40A180ED60C4AD55407CB779E3A4324B40A180ED60C4AD55402C9E7AA4C1314B40E23E726BD2AC55402C9E7AA4C1314B40
41069	Новый Городок	5	51	890	86.274343999999999	86.318415000000002	54.317830999999998	54.291863999999997	0103000020E61000000100000005000000A5F622DA8E9155409B70AFCC5B254B40A5F622DA8E915540D653ABAFAE284B4093E34EE960945540D653ABAFAE284B4093E34EE9609455409B70AFCC5B254B40A5F622DA8E9155409B70AFCC5B254B40
60702	Новый Городок	5	51	890	86.274343999999999	86.318415000000002	54.317830999999998	54.291863999999997	0103000020E61000000100000005000000A5F622DA8E9155409B70AFCC5B254B40A5F622DA8E915540D653ABAFAE284B4093E34EE960945540D653ABAFAE284B4093E34EE9609455409B70AFCC5B254B40A5F622DA8E9155409B70AFCC5B254B40
29644	Новохудяково	5	51	890	86.820455999999993	86.847477999999995	54.513469000000001	54.503526999999998	0103000020E61000000100000005000000A5F3E15982B4554095D39E9273404B40A5F3E15982B455404241295AB9414B4016855D143DB655404241295AB9414B4016855D143DB6554095D39E9273404B40A5F3E15982B4554095D39E9273404B40
30047	Новороссийка	5	51	890	86.166528	86.189965000000001	54.450705999999997	54.441313999999998	0103000020E6100000010000000500000092770E65A88A55402BA226FA7C384B4092770E65A88A5540340EF5BBB0394B409E98F562288C5540340EF5BBB0394B409E98F562288C55402BA226FA7C384B4092770E65A88A55402BA226FA7C384B40
29741	Новобачаты	5	51	890	86.333686	86.356808999999998	54.264085999999999	54.243425000000002	0103000020E610000001000000050000008448861C5B955540B003E78C281F4B408448861C5B9555406DAAEE91CD214B40C87A6AF5D59655406DAAEE91CD214B40C87A6AF5D5965540B003E78C281F4B408448861C5B955540B003E78C281F4B40
28288	Мохово	5	51	890	86.324838	86.370760000000004	54.595241999999999	54.564121	0103000020E61000000100000005000000E09F5225CA94554050FEEE1D35484B40E09F5225CA945540529ACDE3304C4B408FAA2688BA975540529ACDE3304C4B408FAA2688BA97554050FEEE1D35484B40E09F5225CA94554050FEEE1D35484B40
30245	Мереть	5	51	890	86.309019000000006	86.331458999999995	54.502377000000003	54.498109999999997	0103000020E61000000100000005000000EEB5A0F7C6935540C0E78711C23F4B40EEB5A0F7C69355409DA1B8E34D404B40C03DCF9F369555409DA1B8E34D404B40C03DCF9F36955540C0E78711C23F4B40EEB5A0F7C6935540C0E78711C23F4B40
28839	Менчереп	5	51	890	86.470554000000007	86.488718000000006	54.439726999999998	54.415021000000003	0103000020E610000001000000050000002140868E1D9E55409D137B681F354B402140868E1D9E554087156EF948384B40DCBDDC27479F554087156EF948384B40DCBDDC27479F55409D137B681F354B402140868E1D9E55409D137B681F354B40
28670	Коротково	5	51	890	86.428889999999996	86.448599000000002	54.464768999999997	54.456223000000001	0103000020E6100000010000000500000036E50AEF729B55406D57E883653A4B4036E50AEF729B5540E998F38C7D3B4B402C8194D8B59C5540E998F38C7D3B4B402C8194D8B59C55406D57E883653A4B4036E50AEF729B55406D57E883653A4B40
29306	Коновалово	5	51	890	86.647278999999997	86.672369000000003	54.358749000000003	54.34731	0103000020E61000000100000005000000CE18E6046DA9554071C971A7742C4B40CE18E6046DA95540823CBB7CEB2D4B400876FC1708AB5540823CBB7CEB2D4B400876FC1708AB554071C971A7742C4B40CE18E6046DA9554071C971A7742C4B40
30130	Конево	5	51	890	86.231798999999995	86.255191999999994	54.533973000000003	54.522333000000003	0103000020E61000000100000005000000B60F79CBD58E5540904FC8CEDB424B40B60F79CBD58E554038F92D3A59444B40DA8CD3105590554038F92D3A59444B40DA8CD31055905540904FC8CEDB424B40B60F79CBD58E5540904FC8CEDB424B40
29717	Каралда	5	51	890	86.970815999999999	87.008869000000004	54.396286000000003	54.381297000000004	0103000020E61000000100000005000000BF9B6ED921BE55400E881057CE304B40BF9B6ED921BE55406CEEE87FB9324B40B03C484F91C055406CEEE87FB9324B40B03C484F91C055400E881057CE304B40BF9B6ED921BE55400E881057CE304B40
41127	Каракан	5	51	890	86.755104000000003	86.782736	54.404578000000001	54.383127000000002	0103000020E610000001000000050000000B45BA9F53B05540789B374E0A314B400B45BA9F53B055402E573F36C9334B40B859BC5818B255402E573F36C9334B40B859BC5818B25540789B374E0A314B400B45BA9F53B05540789B374E0A314B40
41136	Калиновка	5	51	890	86.199073999999996	86.216195999999997	54.499177000000003	54.490518000000002	0103000020E61000000100000005000000F8DEDFA0BD8C5540B70C384BC93E4B40F8DEDFA0BD8C55402CF52C08E53F4B40AA61BF27D68D55402CF52C08E53F4B40AA61BF27D68D5540B70C384BC93E4B40F8DEDFA0BD8C5540B70C384BC93E4B40
60761	Инюшка	5	51	890	86.785701000000003	86.815731	54.613785999999998	54.598919000000002	0103000020E61000000100000005000000CFDBD8EC48B25540FDF9B660A94C4B40CFDBD8EC48B255400F5F268A904E4B4056D5CBEF34B455400F5F268A904E4B4056D5CBEF34B45540FDF9B660A94C4B40CFDBD8EC48B25540FDF9B660A94C4B40
9204	Инской	5	51	890	86.389426999999998	86.454986000000005	54.452207999999999	54.414957999999999	0103000020E610000001000000050000007B4B395FEC985540569BFF571D354B407B4B395FEC985540AA7EA5F3E1394B40D388997D1E9D5540AA7EA5F3E1394B40D388997D1E9D5540569BFF571D354B407B4B395FEC985540569BFF571D354B40
29986	Ивановка	5	51	890	86.231126000000003	86.261947000000006	54.474412000000001	54.465277	0103000020E6100000010000000500000057D0B4C4CA8E55405E4A5D328E3B4B4057D0B4C4CA8E55403C6A4C88B93C4B40439259BDC39055403C6A4C88B93C4B40439259BDC39055405E4A5D328E3B4B4057D0B4C4CA8E55405E4A5D328E3B4B40
28383	Заря	5	51	890	86.504716999999999	86.521398000000005	54.535488000000001	54.524876999999996	0103000020E610000001000000050000000E2F88484DA0554017B6662B2F434B400E2F88484DA0554042B3EBDE8A444B40CA8CB7955EA1554042B3EBDE8A444B40CA8CB7955EA1554017B6662B2F434B400E2F88484DA0554017B6662B2F434B40
28361	Заринское	5	51	890	86.495930999999999	86.513492999999997	54.599753	54.590201999999998	0103000020E61000000100000005000000A5846055BD9F5540530438BD8B4B4B40A5846055BD9F5540C556D0B4C44C4B40656EBE11DDA05540C556D0B4C44C4B40656EBE11DDA05540530438BD8B4B4B40A5846055BD9F5540530438BD8B4B4B40
8604	Заречное	5	51	890	86.226355999999996	86.260923000000005	54.322032999999998	54.304695000000002	0103000020E610000001000000050000003750E09D7C8E55409B20EA3E00274B403750E09D7C8E5540CB9D996038294B408DF161F6B2905540CB9D996038294B408DF161F6B29055409B20EA3E00274B403750E09D7C8E55409B20EA3E00274B40
28846	Задубровский	5	51	890	86.600881000000001	86.622045999999997	54.438434000000001	54.422469999999997	0103000020E610000001000000050000006BF294D574A6554043C5387F13364B406BF294D574A655402CBAF59A1E384B40E3A6069ACFA755402CBAF59A1E384B40E3A6069ACFA7554043C5387F13364B406BF294D574A6554043C5387F13364B40
29364	Евтино	5	51	890	86.687945999999997	86.710988	54.363916000000003	54.345730000000003	0103000020E610000001000000050000007FDAA84E07AC5540809F71E1402C4B407FDAA84E07AC5540DE3EABCC942E4B404DF6CFD380AD5540DE3EABCC942E4B404DF6CFD380AD5540809F71E1402C4B407FDAA84E07AC5540809F71E1402C4B40
28931	Дунай-Ключ	5	51	890	86.697747000000007	86.712631999999999	54.472988999999998	54.463518999999998	0103000020E61000000100000005000000757808E3A7AC55408D093197543B4B40757808E3A7AC5540122F4FE78A3C4B4051853FC39BAD5540122F4FE78A3C4B4051853FC39BAD55408D093197543B4B40757808E3A7AC55408D093197543B4B40
9363	Грамотеино	5	51	890	86.361785999999995	86.407582000000005	54.541902999999998	54.500798000000003	0103000020E61000000100000005000000A4897780279755407CF31B261A404B40A489778027975540594DD7135D454B400D1CD0D2159A5540594DD7135D454B400D1CD0D2159A55407CF31B261A404B40A4897780279755407CF31B261A404B40
29050	Вишневка	5	51	890	86.383525000000006	86.412728999999999	54.415995000000002	54.398446	0103000020E61000000100000005000000B30C71AC8B9855406B9C4D4700334B40B30C71AC8B9855405726FC523F354B401747E5266A9A55405726FC523F354B401747E5266A9A55406B9C4D4700334B40B30C71AC8B9855406B9C4D4700334B40
60766	Бускускан	5	51	890	86.241141999999996	86.259799999999998	54.197161999999999	54.187058999999998	0103000020E610000001000000050000004AECDADE6E8F554013B69F8CF1174B404AECDADE6E8F5540C901BB9A3C194B400DE02D90A0905540C901BB9A3C194B400DE02D90A090554013B69F8CF1174B404AECDADE6E8F554013B69F8CF1174B40
41141	Белово	5	51	890	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
29810	Беково	5	51	890	86.139838999999995	86.203682000000001	54.371065999999999	54.355884000000003	0103000020E6100000010000000500000024ED461FF3885540B8955E9B8D2D4B4024ED461FF38855402A5437177F2F4B402B323A20098D55402A5437177F2F4B402B323A20098D5540B8955E9B8D2D4B4024ED461FF3885540B8955E9B8D2D4B40
41064	Бачатский	5	51	890	86.049126999999999	86.127899999999997	54.297033999999996	54.269502000000003	0103000020E61000000100000005000000709692E524835540721AA20A7F224B40709692E52483554068E6C93505264B40234A7B832F88554068E6C93505264B40234A7B832F885540721AA20A7F224B40709692E524835540721AA20A7F224B40
8672	Бачатский	5	51	890	86.049126999999999	86.127899999999997	54.297033999999996	54.269502000000003	0103000020E61000000100000005000000709692E524835540721AA20A7F224B40709692E52483554068E6C93505264B40234A7B832F88554068E6C93505264B40234A7B832F885540721AA20A7F224B40709692E524835540721AA20A7F224B40
30679	Артышта	5	51	890	86.235977000000005	86.302972999999994	54.131633000000001	54.108117999999997	0103000020E61000000100000005000000ED66463F1A8F5540F10D85CFD60D4B40ED66463F1A8F55408509A359D9104B408BA4DDE8639355408509A359D9104B408BA4DDE863935540F10D85CFD60D4B40ED66463F1A8F5540F10D85CFD60D4B40
59262	с. Преображенка	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59156	п.Алексеевск	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59254	п. Витимский	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59232	д.Салтыково	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59098	Шелехов	5	50	\N	103.938366	104.123159	52.23171	52.169508	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
59327	Чечуйск	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59090	Черемхово	5	50	\N	103.008978	103.233692	53.189619999999998	53.035524000000002	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
29581	Усть-Кут	5	50	\N	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
59092	Усть-Илимск	5	50	\N	102.560647	102.771293	58.135641	57.926875000000003	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
1308	Усолье-Сибирское	5	50	\N	103.556169	103.68287599999999	52.8185	52.717531999999999	0103000020E610000001000000050000002383DC4598E35940AFEAAC16D85B4A402383DC4598E3594054E3A59BC4684A404ACE893DB4EB594054E3A59BC4684A404ACE893DB4EB5940AFEAAC16D85B4A402383DC4598E35940AFEAAC16D85B4A40
59117	Усолье	5	50	\N	103.733541	103.75180400000001	52.738190000000003	52.724355000000003	0103000020E610000001000000050000009C51F355F2EE5940D8D825AAB75C4A409C51F355F2EE5940FC1D8A027D5E4A402140868E1DF05940FC1D8A027D5E4A402140868E1DF05940D8D825AAB75C4A409C51F355F2EE5940D8D825AAB75C4A40
59188	Ук	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59087	Тулун	5	50	\N	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
52142	Тайшет	5	50	\N	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
59286	Сухой Ручей	5	50	\N	103.752954	103.764758	51.646805999999998	51.640680000000003	0103000020E610000001000000050000001D59F96530F05940C4995FCD01D249401D59F96530F05940A46DFC89CAD24940AED689CBF1F05940A46DFC89CAD24940AED689CBF1F05940C4995FCD01D249401D59F96530F05940C4995FCD01D24940
59085	Слюдянка	5	50	\N	103.652343	103.738527	51.690190999999999	51.633105999999998	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
59160	Свирск	5	50	\N	103.287474	103.406025	53.122621000000002	52.979940999999997	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
59083	Саянск	5	50	\N	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
59293	Сахарово	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59284	Преображенка	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59332	Петропавловское	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
5456	Новолисиха	5	50	\N	104.43507200000001	104.475523	52.248551999999997	52.221747000000001	0103000020E61000000100000005000000F1D93A38D81B5A40397EA834621C4A40F1D93A38D81B5A407DAD4B8DD01F4A40BB5F05F86E1E5A407DAD4B8DD01F4A40BB5F05F86E1E5A40397EA834621C4A40F1D93A38D81B5A40397EA834621C4A40
59186	Новая Разводная	5	50	\N	104.37351	104.40427699999999	52.253646000000003	52.229557999999997	0103000020E61000000100000005000000A7AE7C96E7175A4080441328621D4A40A7AE7C96E7175A407061DD7877204A409961A3ACDF195A407061DD7877204A409961A3ACDF195A4080441328621D4A40A7AE7C96E7175A4080441328621D4A40
25086	Нижнеудинск	5	50	\N	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
3568	Молодежный	5	50	\N	104.38329299999999	104.45232799999999	52.260956	52.209629999999997	0103000020E6100000010000000500000049F25CDF87185A405721E527D51A4A4049F25CDF87185A40F5D8960167214A402AC423F1F21C5A40F5D8960167214A402AC423F1F21C5A405721E527D51A4A4049F25CDF87185A405721E527D51A4A40
59223	Маракан	5	50	\N	104.673934	104.770754	58.184278999999997	57.935127999999999	0103000020E61000000100000005000000666A12BC212B5A4075C93846B2F74C40666A12BC212B5A40772B4B7496174D40B7D0950854315A40772B4B7496174D40B7D0950854315A4075C93846B2F74C40666A12BC212B5A4075C93846B2F74C40
59321	Мамаканское муниципальное образование	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59142	Мама	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
2001	Малая Топка	5	50	\N	104.290766	104.336697	52.363912999999997	52.328296000000002	0103000020E610000001000000050000007B32FFE89B125A402DB4739A052A4A407B32FFE89B125A406CCB80B3942E4A4053EA92718C155A406CCB80B3942E4A4053EA92718C155A402DB4739A052A4A407B32FFE89B125A402DB4739A052A4A40
59159	Куйтун	5	50	\N	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
59218	Кривошапкино	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
17848	Красноярово	5	50	\N	107.450968	107.466194	57.339272000000001	57.335016000000003	0103000020E61000000100000005000000B9E2E2A8DCDC5A4081D1E5CDE1AA4C40B9E2E2A8DCDC5A406939D0436DAB4C40DAE55B1FD6DD5A406939D0436DAB4C40DAE55B1FD6DD5A4081D1E5CDE1AA4C40B9E2E2A8DCDC5A4081D1E5CDE1AA4C40
59309	Колотовка	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59112	Киренск	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
27	Иркутск	5	50	\N	104.06257600000001	104.48868299999999	52.427269000000003	52.19847	0103000020E61000000100000005000000EE60C43E01045A405A9E077767194A40EE60C43E01045A401DCC26C0B0364A401DC70F95461F5A401DCC26C0B0364A401DC70F95461F5A405A9E077767194A40EE60C43E01045A405A9E077767194A40
59134	Зима	5	50	\N	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
59118	Залари	5	50	\N	102.467016	102.53517100000001	53.577737999999997	53.534320000000001	0103000020E610000001000000050000005CAD1397E39D5940A3CC069964C44A405CAD1397E39D594006D49B51F3C94A4021B1DD3D40A2594006D49B51F3C94A4021B1DD3D40A25940A3CC069964C44A405CAD1397E39D5940A3CC069964C44A40
59169	Жигалово	5	50	\N	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
59124	Железногорск-Илимский	5	50	\N	104.068873	104.15471599999999	56.597963	56.482253999999998	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
59206	Ербогачен	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
2764	Дзержинск	5	50	\N	104.35729600000001	104.42498399999999	52.293086000000002	52.263804999999998	0103000020E6100000010000000500000077BF0AF0DD165A40B9C2BB5CC4214A4077BF0AF0DD165A402E7590D783254A40B05417F0321B5A402E7590D783254A40B05417F0321B5A40B9C2BB5CC4214A4077BF0AF0DD165A40B9C2BB5CC4214A40
59081	Братск	5	50	\N	101.36801699999999	101.978359	56.379621	56.081105000000001	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
59113	Бохан	5	50	\N	103.76191	103.803799	53.171671000000003	53.117330000000003	0103000020E61000000100000005000000B41F2922C3F059407B6B60AB048F4A40B41F2922C3F05940F855B950F9954A40AE635C7171F35940F855B950F9954A40AE635C7171F359407B6B60AB048F4A40B41F2922C3F059407B6B60AB048F4A40
59158	Бодайбо	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59080	Бодайбо	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59135	Бирюсинск	5	50	\N	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
59180	Балахнинское муниципальное образование	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
304	Ангарск	5	50	\N	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
59163	Алексеевск	5	50	\N	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59099	Шелехов	5	50	7465	104.07950099999999	104.131935	52.229993999999998	52.199066000000002	0103000020E61000000100000005000000F4BF5C8B16055A406EDFA3FE7A194A40F4BF5C8B16055A405B238271701D4A40A88C7F9F71085A405B238271701D4A40A88C7F9F71085A406EDFA3FE7A194A40F4BF5C8B16055A406EDFA3FE7A194A40
59088	Нижнеудинск	5	50	7464	99.000434999999996	99.077088000000003	54.933630999999998	54.877935999999998	0103000020E6100000010000000500000085B1852007C0584093FDF33460704B4085B1852007C0584011C4793881774B4080BA8102EFC4584011C4793881774B4080BA8102EFC4584093FDF33460704B4085B1852007C0584093FDF33460704B40
59145	Зима	5	50	7469	102.02002299999999	102.083049	53.943271000000003	53.890818000000003	0103000020E61000000100000005000000BD8A8C0E488159401558005306F24A40BD8A8C0E48815940F321A81ABDF84A40CBBDC0AC50855940F321A81ABDF84A40CBBDC0AC508559401558005306F24A40BD8A8C0E488159401558005306F24A40
28534	Шохтой	5	50	275	105.09833399999999	105.12374699999999	52.816600000000001	52.801684999999999	0103000020E610000001000000050000006E85B01A4B465A40CD58349D9D664A406E85B01A4B465A40F1F44A5986684A40997E8978EB475A40F1F44A5986684A40997E8978EB475A40CD58349D9D664A406E85B01A4B465A40CD58349D9D664A40
28280	Харат	5	50	275	105.037374	105.089557	52.762861000000001	52.743870999999999	0103000020E6100000010000000500000020EEEA5564425A40AEB8382A375F4A4020EEEA5564425A406A32E36DA5614A402F88484DBB455A406A32E36DA5614A402F88484DBB455A40AEB8382A375F4A4020EEEA5564425A40AEB8382A375F4A40
28763	Харанут	5	50	275	104.916398	104.977097	52.778399	52.741450999999998	0103000020E61000000100000005000000AB07CC43A63A5A40124BCADDE75E4A40AB07CC43A63A5A409B1E1494A2634A404301DBC1883E5A409B1E1494A2634A404301DBC1883E5A40124BCADDE75E4A40AB07CC43A63A5A40124BCADDE75E4A40
1160	Харазаргай	5	50	275	104.65570700000001	104.68298	52.973976999999998	52.955883	0103000020E6100000010000000500000088307E1AF7295A40B4E6C75F5A7A4A4088307E1AF7295A4031074147AB7C4A409DF4BEF1B52B5A4031074147AB7C4A409DF4BEF1B52B5A40B4E6C75F5A7A4A4088307E1AF7295A40B4E6C75F5A7A4A40
28139	Хабаровск	5	50	275	104.994551	105.010227	53.104680999999999	53.095137999999999	0103000020E6100000010000000500000010CD3CB9A63F5A40AD4D637B2D8C4A4010CD3CB9A63F5A409CC1DF2F668D4A4051A2258FA7405A409CC1DF2F668D4A4051A2258FA7405A40AD4D637B2D8C4A4010CD3CB9A63F5A40AD4D637B2D8C4A40
27070	Усть-Ордынский	5	50	275	104.701835	104.779144	52.833148000000001	52.784101999999997	0103000020E610000001000000050000000B0C59DDEA2C5A40355D4F745D644A400B0C59DDEA2C5A40295DFA97A46A4A40FAB7CB7EDD315A40295DFA97A46A4A40FAB7CB7EDD315A40355D4F745D644A400B0C59DDEA2C5A40355D4F745D644A40
28584	Тугутуй	5	50	275	104.77081699999999	104.826477	52.693944000000002	52.667769999999997	0103000020E61000000100000005000000DA8CD31055315A40FD9FC37C79554A40DA8CD31055315A40B2A03028D3584A405B79C9FFE4345A40B2A03028D3584A405B79C9FFE4345A40FD9FC37C79554A40DA8CD31055315A40FD9FC37C79554A40
27945	Серафимовск	5	50	275	104.884139	104.89786599999999	53.152472000000003	53.133924	0103000020E610000001000000050000009087BEBB95385A402313F06B24914A409087BEBB95385A4022C7D63384934A402E8CF4A276395A4022C7D63384934A402E8CF4A276395A402313F06B24914A409087BEBB95385A402313F06B24914A40
28855	Свердлово	5	50	275	104.776881	104.80614799999999	52.592395000000003	52.583109999999998	0103000020E6100000010000000500000090F8156BB8315A403BFC3559A34A4A4090F8156BB8315A402FA86F99D34B4A4017EFC7ED97335A402FA86F99D34B4A4017EFC7ED97335A403BFC3559A34A4A4090F8156BB8315A403BFC3559A34A4A40
28208	Отонхой	5	50	275	105.07694499999999	105.13282	52.959012999999999	52.939860000000003	0103000020E61000000100000005000000CEA5B8AAEC445A40C7681D554D784A40CEA5B8AAEC445A402CB81FF0C07A4A404D10751F80485A402CB81FF0C07A4A404D10751F80485A40C7681D554D784A40CEA5B8AAEC445A40C7681D554D784A40
28161	Олой	5	50	275	105.02206700000001	105.079289	52.914172000000001	52.899872000000002	0103000020E6100000010000000500000089D4B48B69415A40064B75012F734A4089D4B48B69415A409F758D9603754A40AF7B2B1213455A409F758D9603754A40AF7B2B1213455A40064B75012F734A4089D4B48B69415A40064B75012F734A40
59299	Новониколаевск	5	50	275	105.07509400000001	105.10727199999999	53.159756000000002	53.145014000000003	0103000020E610000001000000050000000E881057CE445A4028BB99D18F924A400E881057CE445A407EAB75E272944A40B2F1608BDD465A407EAB75E272944A40B2F1608BDD465A4028BB99D18F924A400E881057CE445A4028BB99D18F924A40
27668	Нижняя Идыга	5	50	275	104.600218	104.64472000000001	52.910375999999999	52.897883999999998	0103000020E610000001000000050000001D1EC2F869265A4003CDE7DCED724A401D1EC2F869265A401A88653387744A40F0C4AC1743295A401A88653387744A40F0C4AC1743295A4003CDE7DCED724A401D1EC2F869265A4003CDE7DCED724A40
59245	Муромцовка	5	50	275	105.197113	105.217603	53.211153000000003	53.196536000000002	0103000020E610000001000000050000007427D87F9D4C5A404B3E761728994A407427D87F9D4C5A40E5B9BE0F079B4A40BC202235ED4D5A40E5B9BE0F079B4A40BC202235ED4D5A404B3E761728994A407427D87F9D4C5A404B3E761728994A40
29003	Куяда	5	50	275	104.65497000000001	104.689519	52.620429000000001	52.607999999999997	0103000020E610000001000000050000001D774A07EB295A40E7FBA9F1D24D4A401D774A07EB295A40B83EAC376A4F4A401FBE4C14212C5A40B83EAC376A4F4A401FBE4C14212C5A40E7FBA9F1D24D4A401D774A07EB295A40E7FBA9F1D24D4A40
27406	Кулункун (Ата)	5	50	275	104.64868199999999	104.687489	52.845925999999999	52.835448999999997	0103000020E610000001000000050000003FE0810184295A40EA3C2AFEEF6A4A403FE0810184295A40056B9C4D476C4A4006D7DCD1FF2B5A40056B9C4D476C4A4006D7DCD1FF2B5A40EA3C2AFEEF6A4A403FE0810184295A40EA3C2AFEEF6A4A40
59247	Кукунут	5	50	275	104.69355299999999	104.731426	52.999684000000002	52.979649000000002	0103000020E61000000100000005000000BB421F2C632C5A4091477023657D4A40BB421F2C632C5A40D02A33A5F57F4A406C5CFFAECF2E5A40D02A33A5F57F4A406C5CFFAECF2E5A4091477023657D4A40BB421F2C632C5A4091477023657D4A40
27490	Кударейка	5	50	275	104.417806	104.45186099999999	52.889653000000003	52.854028999999997	0103000020E61000000100000005000000A5846055BD1A5A40F46A80D2506D4A40A5846055BD1A5A40E7E44526E0714A409F55664AEB1C5A40E7E44526E0714A409F55664AEB1C5A40F46A80D2506D4A40A5846055BD1A5A40F46A80D2506D4A40
28380	Корсук	5	50	275	104.98889200000001	105.02037799999999	52.800896000000002	52.783988000000001	0103000020E61000000100000005000000ABD1AB014A3F5A406D3A02B859644A40ABD1AB014A3F5A40A5BF97C283664A40B4E386DF4D415A40A5BF97C283664A40B4E386DF4D415A406D3A02B859644A40ABD1AB014A3F5A406D3A02B859644A40
59258	Комой	5	50	275	104.880295	104.898045	52.717728000000001	52.704149000000001	0103000020E6100000010000000500000045F5D6C056385A406C41EF8D215A4A4045F5D6C056385A4035B6D782DE5B4A408655BC9179395A4035B6D782DE5B4A408655BC9179395A406C41EF8D215A4A4045F5D6C056385A406C41EF8D215A4A40
29059	Капсал	5	50	275	104.63271	104.64907700000001	52.691279999999999	52.682797000000001	0103000020E610000001000000050000008A7615527E285A40496760E465574A408A7615527E285A407F30F0DC7B584A407EE5417A8A295A407F30F0DC7B584A407EE5417A8A295A40496760E465574A408A7615527E285A40496760E465574A40
28461	Ишины	5	50	275	105.001513	105.016327	52.821263999999999	52.808844000000001	0103000020E610000001000000050000003561FBC918405A406DC83F3388674A403561FBC918405A40EAB0C22D1F694A40ADC266800B415A40EAB0C22D1F694A40ADC266800B415A406DC83F3388674A403561FBC918405A406DC83F3388674A40
28939	Захал	5	50	275	104.711178	104.765463	52.608099000000003	52.595699000000003	0103000020E610000001000000050000009FE8BAF0832D5A4045A165DD3F4C4A409FE8BAF0832D5A407BDD2230D64D4A4013D38558FD305A407BDD2230D64D4A4013D38558FD305A4045A165DD3F4C4A409FE8BAF0832D5A4045A165DD3F4C4A40
29090	Зады	5	50	275	104.55636199999999	104.579323	52.770772000000001	52.762784000000003	0103000020E610000001000000050000002DAF5C6F9B235A40BFF4F6E7A2614A402DAF5C6F9B235A4015562AA8A8624A4085B4C6A013255A4015562AA8A8624A4085B4C6A013255A40BFF4F6E7A2614A402DAF5C6F9B235A40BFF4F6E7A2614A40
28928	Еловка	5	50	275	104.761573	104.802716	52.619312999999998	52.607436999999997	0103000020E610000001000000050000001021AE9CBD305A40AFB0E07EC04D4A401021AE9CBD305A406B7EFCA5454F4A4076FEEDB25F335A406B7EFCA5454F4A4076FEEDB25F335A40AFB0E07EC04D4A401021AE9CBD305A40AFB0E07EC04D4A40
59200	Гушит	5	50	275	104.977636	105.00234	52.891077000000003	52.879322999999999	0103000020E610000001000000050000001BD99596913E5A4070CFF3A78D704A401BD99596913E5A40E19BA6CF0E724A4040DEAB5626405A40E19BA6CF0E724A4040DEAB5626405A4070CFF3A78D704A401BD99596913E5A4070CFF3A78D704A40
27558	Гаханы	5	50	275	104.85646199999999	104.883672	53.055646000000003	53.039011000000002	0103000020E610000001000000050000001211FE45D0365A409697FC4FFE844A401211FE45D0365A409D137B681F874A40051901158E385A409D137B681F874A40051901158E385A409697FC4FFE844A401211FE45D0365A409697FC4FFE844A40
27731	Верхняя Идыга	5	50	275	104.55355	104.571364	52.929178999999998	52.916674999999998	0103000020E61000000100000005000000DAACFA5C6D235A40C8073D9B55754A40DAACFA5C6D235A40A3906456EF764A4027874F3A91245A40A3906456EF764A4027874F3A91245A40C8073D9B55754A40DAACFA5C6D235A40C8073D9B55754A40
28364	Верхний Кукут	5	50	275	105.05381300000001	105.09165900000001	52.748095999999997	52.724803000000001	0103000020E6100000010000000500000061C614AC71435A4077853E58C65C4A4061C614AC71435A405B22179CC15F4A4095D8B5BDDD455A405B22179CC15F4A4095D8B5BDDD455A4077853E58C65C4A4061C614AC71435A4077853E58C65C4A40
27434	Булуса	5	50	275	104.592412	104.609938	52.805365999999999	52.791133000000002	0103000020E6100000010000000500000082700514EA255A40A8E49CD843654A4082700514EA255A40B9A7AB3B16674A409CA5643909275A40B9A7AB3B16674A409CA5643909275A40A8E49CD843654A4082700514EA255A40A8E49CD843654A40
28703	Большая Кура	5	50	275	104.83849600000001	104.858924	52.741619999999998	52.727283999999997	0103000020E61000000100000005000000EB7420EBA9355A40B87361A4175D4A40EB7420EBA9355A409E077767ED5E4A40F86F5E9CF8365A409E077767ED5E4A40F86F5E9CF8365A40B87361A4175D4A40EB7420EBA9355A40B87361A4175D4A40
27639	Бозой	5	50	275	104.84025699999999	104.86344200000001	52.938623	52.918830999999997	0103000020E610000001000000050000000BCF4BC5C6355A4086C613419C754A400BCF4BC5C6355A40FF2268CC24784A408BFF3BA242375A40FF2268CC24784A408BFF3BA242375A4086C613419C754A400BCF4BC5C6355A4086C613419C754A40
28269	Баянгазуй	5	50	275	104.964386	104.986413	52.994501999999997	52.980786999999999	0103000020E6100000010000000500000019AE0E80B83D5A40C5ABAC6D8A7D4A4019AE0E80B83D5A403EE76ED74B7F4A405AD6FD63213F5A403EE76ED74B7F4A405AD6FD63213F5A40C5ABAC6D8A7D4A4019AE0E80B83D5A40C5ABAC6D8A7D4A40
27932	Байтог	5	50	275	104.859894	104.88369899999999	53.154449	53.130454999999998	0103000020E61000000100000005000000B401D88008375A40C24CDBBFB2904A40B401D88008375A4030F31DFCC4934A40812040868E385A4030F31DFCC4934A40812040868E385A40C24CDBBFB2904A40B401D88008375A40C24CDBBFB2904A40
27880	Ахины	5	50	275	104.968132	104.993078	53.267555999999999	53.255625000000002	0103000020E61000000100000005000000828DEBDFF53D5A401F85EB51B8A04A40828DEBDFF53D5A409EEC66463FA24A40221807978E3F5A409EEC66463FA24A40221807978E3F5A401F85EB51B8A04A40828DEBDFF53D5A401F85EB51B8A04A40
59269	Алужина	5	50	275	104.754593	104.80510599999999	52.716124000000001	52.698096999999997	0103000020E61000000100000005000000983270404B305A40C537143E5B594A40983270404B305A40BBF083F3A95B4A400EF450DB86335A40BBF083F3A95B4A400EF450DB86335A40C537143E5B594A40983270404B305A40C537143E5B594A40
25959	Шелехов	5	50	1786	103.938366	104.123159	52.23171	52.169508	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
26994	Шаманка	5	50	1786	103.70893599999999	103.84198600000001	52.116765000000001	52.060747999999997	0103000020E6100000010000000500000040BD19355FED594011A62897C6074A4040BD19355FED5940A228D027F20E4A40276C3F19E3F55940A228D027F20E4A40276C3F19E3F5594011A62897C6074A4040BD19355FED594011A62897C6074A40
59140	Чистые Ключи	5	50	1786	103.470793	104.223294	52.286496999999997	51.801794999999998	0103000020E61000000100000005000000E38BF67821DE5940548CF337A1E64940E38BF67821DE594078B306EFAB244A4027D9EA724A0E5A4078B306EFAB244A4027D9EA724A0E5A40548CF337A1E64940E38BF67821DE5940548CF337A1E64940
26934	Подкаменная	5	50	1786	103.888321	103.917337	51.975583	51.961466999999999	0103000020E6100000010000000500000067D65240DAF859407497C45911FB494067D65240DAF859404CC45BE7DFFC49404A9A3FA6B5FA59404CC45BE7DFFC49404A9A3FA6B5FA59407497C45911FB494067D65240DAF859407497C45911FB4940
26911	Олха	5	50	1786	104.074721	104.127021	52.173071	52.152039000000002	0103000020E61000000100000005000000C3D4963AC8045A40B85B920376134A40C3D4963AC8045A406971C63027164A40EF39B01C21085A406971C63027164A40EF39B01C21085A40B85B920376134A40C3D4963AC8045A40B85B920376134A40
27057	Моты	5	50	1786	103.87800799999999	103.925179	52.086671000000003	52.037131000000002	0103000020E610000001000000050000001668774831F859407A5567B5C0044A401668774831F859407D410B09180B4A408BFCFA2136FB59407D410B09180B4A408BFCFA2136FB59407A5567B5C0044A401668774831F859407A5567B5C0044A40
26819	Введенщина	5	50	1786	103.909009	103.96294399999999	52.219419000000002	52.194009000000001	0103000020E6100000010000000500000042B115342DFA594099107349D5184A4042B115342DFA59407E8FFAEB151C4A4048F8DEDFA0FD59407E8FFAEB151C4A4048F8DEDFA0FD594099107349D5184A4042B115342DFA594099107349D5184A40
26623	Большой Луг (Ханчин)	5	50	1786	104.07171200000001	104.11120200000001	52.096476000000003	52.039048000000001	0103000020E61000000100000005000000C5AEEDED96045A40B37C5D86FF044A40C5AEEDED96045A40A96C5853590C4A40FD4FFEEE1D075A40A96C5853590C4A40FD4FFEEE1D075A40B37C5D86FF044A40C5AEEDED96045A40B37C5D86FF044A40
26723	Баклаши	5	50	1786	104.001886	104.079932	52.237628000000001	52.211511999999999	0103000020E610000001000000050000007F1475E61E005A40145B41D3121B4A407F1475E61E005A40944E24986A1E4A40D9791B9B1D055A40944E24986A1E4A40D9791B9B1D055A40145B41D3121B4A407F1475E61E005A40145B41D3121B4A40
24042	Чунский	5	50	294	99.606482999999997	99.692048	56.106805999999999	56.066198	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
25089	Хоняки	5	50	294	99.352224000000007	99.39237	56.084876999999999	56.058638999999999	0103000020E61000000100000005000000723788D68AD6584094A2957B81074C40723788D68AD658405F97E13FDD0A4C409E7B0F971CD958405F97E13FDD0A4C409E7B0F971CD9584094A2957B81074C40723788D68AD6584094A2957B81074C40
25364	Таргиз	5	50	294	99.947062000000003	99.966762000000003	56.175325999999998	56.155794	0103000020E610000001000000050000003352EFA99CFC5840DE74CB0EF1134C403352EFA99CFC5840BA11161571164C40FF40B96DDFFD5840BA11161571164C40FF40B96DDFFD5840DE74CB0EF1134C403352EFA99CFC5840DE74CB0EF1134C40
12507	Сосновка	5	50	294	100.21966399999999	100.259585	56.139757000000003	56.115493999999998	0103000020E61000000100000005000000F20698F90E0E59402E71E481C80E4C40F20698F90E0E59408C31B08EE3114C400F62670A9D1059408C31B08EE3114C400F62670A9D1059402E71E481C80E4C40F20698F90E0E59402E71E481C80E4C40
25883	Приудинск	5	50	294	99.444552999999999	99.459734999999995	55.732326999999998	55.72307	0103000020E61000000100000005000000AD156D8E73DC5840FF5BC98E8DDC4B40AD156D8E73DC5840287D21E4BCDD4B40E674594C6CDD5840287D21E4BCDD4B40E674594C6CDD5840FF5BC98E8DDC4B40AD156D8E73DC5840FF5BC98E8DDC4B40
25588	Пионерский	5	50	294	99.349447999999995	99.366506999999999	56.098641999999998	56.084449999999997	0103000020E61000000100000005000000C4E9245B5DD65840D712F241CF0A4C40C4E9245B5DD658408A01124DA00C4C4053B0C6D974D758408A01124DA00C4C4053B0C6D974D75840D712F241CF0A4C40C4E9245B5DD65840D712F241CF0A4C40
25550	Парчум	5	50	294	99.015248	99.046339000000003	56.175913000000001	56.159773999999999	0103000020E610000001000000050000001555BFD2F9C058402460747973144C401555BFD2F9C058407BF8325184164C40E161DA37F7C258407BF8325184164C40E161DA37F7C258402460747973144C401555BFD2F9C058402460747973144C40
25220	Паренда	5	50	294	99.568098000000006	99.581626999999997	55.932803	55.924784000000002	0103000020E6100000010000000500000013BBB6B75BE458409AEE75525FF64B4013BBB6B75BE458402B4EB51666F74B401EDE736039E558402B4EB51666F74B401EDE736039E558409AEE75525FF64B4013BBB6B75BE458409AEE75525FF64B40
1278	Октябрьский	5	50	294	99.368105999999997	99.479613999999998	56.087755000000001	56.054864000000002	0103000020E6100000010000000500000087DD770C8FD7584027DD96C805074C4087DD770C8FD75840BE874B8E3B0B4C400A2DEBFEB1DE5840BE874B8E3B0B4C400A2DEBFEB1DE584027DD96C805074C4087DD770C8FD7584027DD96C805074C40
25619	Новочунка	5	50	294	99.241228000000007	99.306787	56.124682	56.095483999999999	0103000020E610000001000000050000004AB8904770CF584048A5D8D1380C4C404AB8904770CF58402F336C94F50F4C40A1F5F065A2D358402F336C94F50F4C40A1F5F065A2D3584048A5D8D1380C4C404AB8904770CF584048A5D8D1380C4C40
59278	Новобалтурина	5	50	294	99.186952000000005	99.212239999999994	56.187992000000001	56.174289000000002	0103000020E61000000100000005000000FF7A8505F7CB5840BA86191A4F164C40FF7A8505F7CB58406FF4311F10184C40CBB9145795CD58406FF4311F10184C40CBB9145795CD5840BA86191A4F164C40FF7A8505F7CB5840BA86191A4F164C40
25828	Мухино	5	50	294	99.494399999999999	99.511262000000002	55.824299000000003	55.814866000000002	0103000020E610000001000000050000001DC9E53FA4DF5840A94F72874DE84B401DC9E53FA4DF584011902FA182E94B40016C4084B8E0584011902FA182E94B40016C4084B8E05840A94F72874DE84B401DC9E53FA4DF5840A94F72874DE84B40
24620	Лесогорск	5	50	294	99.507857000000001	99.561279999999996	56.071478999999997	56.037156000000003	0103000020E61000000100000005000000DC82A5BA80E05840D36C1E87C1044C40DC82A5BA80E05840E6AC4F3926094C4087F9F202ECE35840E6AC4F3926094C4087F9F202ECE35840D36C1E87C1044C40DC82A5BA80E05840D36C1E87C1044C40
25277	Кулиш	5	50	294	99.725527999999997	99.747760999999997	55.845506	55.836781999999999	0103000020E610000001000000050000004415FE0C6FEE5840D4F02DAC1BEB4B404415FE0C6FEE58403049658A39EC4B405A0EF450DBEF58403049658A39EC4B405A0EF450DBEF5840D4F02DAC1BEB4B404415FE0C6FEE5840D4F02DAC1BEB4B40
25469	Каменск	5	50	294	99.108457000000001	99.136556999999996	56.179364999999997	56.167898999999998	0103000020E610000001000000050000006D01A1F5F0C65840FB03E5B67D154C406D01A1F5F0C658400586AC6EF5164C408D429259BDC858400586AC6EF5164C408D429259BDC85840FB03E5B67D154C406D01A1F5F0C65840FB03E5B67D154C40
25317	Изыкан	5	50	294	99.755864000000003	99.787682000000004	56.133532000000002	56.120457000000002	0103000020E61000000100000005000000520E661360F0584082C98D226B0F4C40520E661360F05840187C9A9317114C407769C36169F25840187C9A9317114C407769C36169F2584082C98D226B0F4C40520E661360F0584082C98D226B0F4C40
25667	Заводской	5	50	294	99.169748999999996	99.188524000000001	56.159137999999999	56.150243000000003	0103000020E61000000100000005000000D6E1E82ADDCA5840FAB9A1293B134C40D6E1E82ADDCA584082C64CA25E144C40B6A0F7C610CC584082C64CA25E144C40B6A0F7C610CC5840FAB9A1293B134C40D6E1E82ADDCA5840FAB9A1293B134C40
25198	Веселый	5	50	294	99.565089	99.604202000000001	55.948684	55.922535000000003	0103000020E6100000010000000500000014950D6B2AE458402B357BA015F64B4014950D6B2AE45840861E317A6EF94B40618BDD3EABE65840861E317A6EF94B40618BDD3EABE658402B357BA015F64B4014950D6B2AE458402B357BA015F64B40
25773	Бунбуй	5	50	294	99.014753999999996	99.035307000000003	56.392338000000002	56.374442000000002	0103000020E610000001000000050000000DDFC2BAF1C05840DA1F28B7ED2F4C400DDFC2BAF1C05840317DAF2138324C4079944A7842C25840317DAF2138324C4079944A7842C25840DA1F28B7ED2F4C400DDFC2BAF1C05840DA1F28B7ED2F4C40
59307	Бидога	5	50	294	99.440250000000006	99.498532999999995	56.059438	56.039026999999997	0103000020E610000001000000050000001904560E2DDC58409B5434D6FE044C401904560E2DDC5840E01115AA9B074C4083BEF4F6E7DF5840E01115AA9B074C4083BEF4F6E7DF58409B5434D6FE044C401904560E2DDC58409B5434D6FE044C40
24792	Баянда	5	50	294	99.556375000000003	99.570065999999997	55.999927999999997	55.989727999999999	0103000020E61000000100000005000000F853E3A59BE35840BEF73768AFFE4B40F853E3A59BE35840662D05A4FDFF4B40F0A31AF67BE45840662D05A4FDFF4B40F0A31AF67BE45840BEF73768AFFE4B40F853E3A59BE35840BEF73768AFFE4B40
21886	Юлинск	5	50	174	102.379071	102.394549	52.747742000000002	52.732987999999999	0103000020E610000001000000050000002BF702B342985940232E008DD25D4A402BF702B3429859403EEC8502B65F4A40D9EA724A409959403EEC8502B65F4A40D9EA724A40995940232E008DD25D4A402BF702B342985940232E008DD25D4A40
3270	Черемхово	5	50	174	103.008978	103.233692	53.189619999999998	53.035524000000002	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
22274	Чемодариха	5	50	174	103.280135	103.308773	53.152461000000002	53.139926000000003	0103000020E61000000100000005000000C2DD59BBEDD1594018EE5C18E9914A40C2DD59BBEDD159402E7590D783934A40D238D4EFC2D359402E7590D783934A40D238D4EFC2D3594018EE5C18E9914A40C2DD59BBEDD1594018EE5C18E9914A40
59276	Худорожкина	5	50	174	103.225697	103.241085	52.969828	52.962131999999997	0103000020E610000001000000050000008A73D4D171CE5940B0373124277B4A408A73D4D171CE59405F5FEB52237C4A4098A3C7EF6DCF59405F5FEB52237C4A4098A3C7EF6DCF5940B0373124277B4A408A73D4D171CE5940B0373124277B4A40
21794	Хандагай	5	50	174	102.139436	102.16157	53.139251000000002	53.119053999999998	0103000020E61000000100000005000000A5F8F884EC8859409F3A56293D8F4A40A5F8F884EC885940B8770DFAD2914A40F180B229578A5940B8770DFAD2914A40F180B229578A59409F3A56293D8F4A40A5F8F884EC8859409F3A56293D8F4A40
21971	Узкий Луг	5	50	174	103.23311699999999	103.260848	52.909942000000001	52.896526000000001	0103000020E6100000010000000500000010C99063EBCE5940C1012D5DC1724A4010C99063EBCE5940E0A0BDFA78744A40874ECFBBB1D05940E0A0BDFA78744A40874ECFBBB1D05940C1012D5DC1724A4010C99063EBCE5940C1012D5DC1724A40
21952	Тунгуска	5	50	174	102.78037500000001	102.799886	52.654733	52.636969000000001	0103000020E610000001000000050000006DE7FBA9F1B159406DC83F3388514A406DE7FBA9F1B15940554E7B4ACE534A40CFA10C5531B35940554E7B4ACE534A40CFA10C5531B359406DC83F3388514A406DE7FBA9F1B159406DC83F3388514A40
2925	Тальники	5	50	174	102.403379	102.436149	52.790371	52.775168999999998	0103000020E610000001000000050000002A3927F6D0995940BFEFDFBC38634A402A3927F6D0995940795A7EE02A654A40B8CB7EDDE99B5940795A7EE02A654A40B8CB7EDDE99B5940BFEFDFBC38634A402A3927F6D0995940BFEFDFBC38634A40
30236	Табук	5	50	174	102.869057	102.88954699999999	53.043239	53.028033999999998	0103000020E61000000100000005000000085740A19EB7594089963C9E96834A40085740A19EB75940B47405DB88854A4050508A56EEB85940B47405DB88854A4050508A56EEB8594089963C9E96834A40085740A19EB7594089963C9E96834A40
22190	Старый Кутугун	5	50	174	103.178517	103.196457	53.260742999999998	53.247521999999996	0103000020E61000000100000005000000EC3191D26CCB59402F8507CDAE9F4A40EC3191D26CCB594099D4D00660A14A407F8461C092CC594099D4D00660A14A407F8461C092CC59402F8507CDAE9F4A40EC3191D26CCB59402F8507CDAE9F4A40
20076	Средний Булай	5	50	174	103.11756699999999	103.12968499999999	52.978445000000001	52.961779999999997	0103000020E61000000100000005000000AF05BD3786C7594033F9669B1B7B4A40AF05BD3786C75940A5F78DAF3D7D4A40087250C24CC85940A5F78DAF3D7D4A40087250C24CC8594033F9669B1B7B4A40AF05BD3786C7594033F9669B1B7B4A40
1874	Свирск	5	50	174	103.287474	103.406025	53.122621000000002	52.979940999999997	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
21700	Саянское	5	50	174	102.23880800000001	102.263008	53.089410999999998	53.062784000000001	0103000020E610000001000000050000007C8159A1488F5940255B5D4E09884A407C8159A1488F59408A73D4D1718B4A4087A5811FD59059408A73D4D1718B4A4087A5811FD5905940255B5D4E09884A407C8159A1488F5940255B5D4E09884A40
21607	Савинская	5	50	174	102.895287	102.91016399999999	52.962854	52.95335	0103000020E610000001000000050000002C62D8614CB9594020D26F5F077A4A402C62D8614CB959405169C4CC3E7B4A40C77F812040BA59405169C4CC3E7B4A40C77F812040BA594020D26F5F077A4A402C62D8614CB9594020D26F5F077A4A40
22114	Рысево	5	50	174	103.00972400000001	103.02940599999999	53.205415000000002	53.196249999999999	0103000020E61000000100000005000000207F69519FC0594085EB51B81E994A40207F69519FC05940CE8DE9094B9A4A409813B4C9E1C15940CE8DE9094B9A4A409813B4C9E1C1594085EB51B81E994A40207F69519FC0594085EB51B81E994A40
21620	Русская Аларь	5	50	174	102.755465	102.778192	52.950268000000001	52.943663999999998	0103000020E610000001000000050000007311DF8959B05940CE3461FBC9784A407311DF8959B05940B937BF61A2794A409180D1E5CDB15940B937BF61A2794A409180D1E5CDB15940CE3461FBC9784A407311DF8959B05940CE3461FBC9784A40
22215	Поздеева	5	50	174	103.27738600000001	103.29599	53.200701000000002	53.189959999999999	0103000020E61000000100000005000000929735B1C0D159402AC6F99B50984A40929735B1C0D1594023A30392B0994A405B7C0A80F1D2594023A30392B0994A405B7C0A80F1D259402AC6F99B50984A40929735B1C0D159402AC6F99B50984A40
20560	Петровка	5	50	174	103.194885	103.222229	53.061399000000002	53.052717999999999	0103000020E61000000100000005000000C85EEFFE78CC59408CF4A276BF864A40C85EEFFE78CC5940E98024ECDB874A4042CEFBFF38CE5940E98024ECDB874A4042CEFBFF38CE59408CF4A276BF864A40C85EEFFE78CC59408CF4A276BF864A40
20000	Паршевникова	5	50	174	103.150454	103.167621	53.041187000000001	53.032696999999999	0103000020E610000001000000050000005A63D009A1C95940B2D6506A2F844A405A63D009A1C959409B02999D45854A40DC476E4DBACA59409B02999D45854A40DC476E4DBACA5940B2D6506A2F844A405A63D009A1C95940B2D6506A2F844A40
2883	Парфеново	5	50	174	102.828875	102.86514	52.996302	52.979621999999999	0103000020E61000000100000005000000355EBA490CB559409738F240647D4A40355EBA490CB559403E78EDD2867F4A40889D29745EB759403E78EDD2867F4A40889D29745EB759409738F240647D4A40355EBA490CB559409738F240647D4A40
21465	Онот	5	50	174	102.036489	102.070886	52.742066999999999	52.733310000000003	0103000020E610000001000000050000007B6AF5D55582594036EA211ADD5D4A407B6AF5D5558259406D382C0DFC5E4A40A2EF6E65898459406D382C0DFC5E4A40A2EF6E658984594036EA211ADD5D4A407B6AF5D55582594036EA211ADD5D4A40
21365	Новостройка	5	50	174	101.810886	101.84893	52.985959000000001	52.972642999999998	0103000020E6100000010000000500000031B2648EE573594077D7D9907F7C4A4031B2648EE573594033198EE7337E4A40F8A57EDE5476594033198EE7337E4A40F8A57EDE5476594077D7D9907F7C4A4031B2648EE573594077D7D9907F7C4A40
2766	Новогромово	5	50	174	102.950264	102.967826	53.184683	53.175611000000004	0103000020E610000001000000050000003CA41820D1BC5940B0E8D66B7A964A403CA41820D1BC594047904AB1A3974A40FC8D76DCF0BD594047904AB1A3974A40FC8D76DCF0BD5940B0E8D66B7A964A403CA41820D1BC5940B0E8D66B7A964A40
814	Нижняя Иреть	5	50	174	102.466989	102.51209299999999	52.991565000000001	52.967176000000002	0103000020E61000000100000005000000DFA5D425E39D5940F1BC546CCC7B4A40DFA5D425E39D5940DB6D179AEB7E4A40ACE0B721C6A05940DB6D179AEB7E4A40ACE0B721C6A05940F1BC546CCC7B4A40DFA5D425E39D5940F1BC546CCC7B4A40
20885	Нены	5	50	174	102.800273	102.815203	53.102145999999998	53.084273000000003	0103000020E61000000100000005000000CCB73EAC37B35940C9772975C98A4A40CCB73EAC37B3594067B5C01E138D4A40782634492CB4594067B5C01E138D4A40782634492CB45940C9772975C98A4A40CCB73EAC37B35940C9772975C98A4A40
59190	Мышелевка	5	50	174	103.136961	103.297912	52.903391999999997	52.842553000000002	0103000020E61000000100000005000000F5F411F8C3C85940C712D6C6D86B4A40F5F411F8C3C85940E8BB5B59A2734A4080457EFD10D35940E8BB5B59A2734A4080457EFD10D35940C712D6C6D86B4A40F5F411F8C3C85940C712D6C6D86B4A40
59193	Мишелевка	5	50	174	101.072318	103.493898	53.314895999999997	52.214100000000002	0103000020E61000000100000005000000603AADDBA04459406C09F9A0671B4A40603AADDBA044594013D21A834EA84A40D4635B069CDF594013D21A834EA84A40D4635B069CDF59406C09F9A0671B4A40603AADDBA04459406C09F9A0671B4A40
20926	Михайловка	5	50	174	103.269463	103.31927399999999	52.984766999999998	52.945867	0103000020E61000000100000005000000DA1EBDE13ED15940CDAE7B2B12794A40DA1EBDE13ED159400B9755D80C7E4A40A31D37FC6ED459400B9755D80C7E4A40A31D37FC6ED45940CDAE7B2B12794A40DA1EBDE13ED15940CDAE7B2B12794A40
20763	Лохово	5	50	174	102.87486	102.910631	53.073222000000001	53.046385000000001	0103000020E610000001000000050000000725CCB4FDB75940320395F1EF854A400725CCB4FDB7594082ACA7565F894A4052EE3EC747BA594082ACA7565F894A4052EE3EC747BA5940320395F1EF854A400725CCB4FDB75940320395F1EF854A40
20292	Козлова	5	50	174	102.924581	102.94379600000001	53.038750999999998	53.028748999999998	0103000020E610000001000000050000003160C9552CBB59407765170CAE834A403160C9552CBB5940F9D7F2CAF5844A401F86562767BC5940F9D7F2CAF5844A401F86562767BC59407765170CAE834A403160C9552CBB59407765170CAE834A40
20185	Ключи	5	50	174	103.032819	103.060559	52.952095999999997	52.941780999999999	0103000020E61000000100000005000000FFEBDCB419C25940417FA1478C784A40FFEBDCB419C2594082531F48DE794A409F1EDB32E0C3594082531F48DE794A409F1EDB32E0C35940417FA1478C784A40FFEBDCB419C25940417FA1478C784A40
22322	Кирзавод	5	50	174	102.92608199999999	102.93526199999999	53.227722	53.218491999999998	0103000020E6100000010000000500000083DA6FED44BB59400438BD8BF79B4A4083DA6FED44BB5940344A97FE259D4A4042CC2555DBBB5940344A97FE259D4A4042CC2555DBBB59400438BD8BF79B4A4083DA6FED44BB59400438BD8BF79B4A40
30277	Катом	5	50	174	102.85243800000001	102.866658	53.161569999999998	53.150803000000003	0103000020E6100000010000000500000088F71C588EB65940C19140834D934A4088F71C588EB65940E2016553AE944A4046B41D5377B75940E2016553AE944A4046B41D5377B75940C19140834D934A4088F71C588EB65940C19140834D934A40
20661	Каменно-Ангарск	5	50	174	103.362375	103.37868	53.289549999999998	53.272768999999997	0103000020E61000000100000005000000D578E92631D759406A2E3718EAA24A40D578E92631D75940454772F90FA54A408EE9094B3CD85940454772F90FA54A408EE9094B3CD859406A2E3718EAA24A40D578E92631D759406A2E3718EAA24A40
2803	Инга	5	50	174	101.95007099999999	101.98653400000001	52.979069000000003	52.968077000000001	0103000020E61000000100000005000000317898F6CD7C5940418177F2E97B4A40317898F6CD7C594083C30B22527D4A401899805F237F594083C30B22527D4A401899805F237F5940418177F2E97B4A40317898F6CD7C5940418177F2E97B4A40
2658	Зерновое	5	50	174	103.252529	103.272158	53.059407999999998	53.047336999999999	0103000020E61000000100000005000000A912656F29D05940047289230F864A40A912656F29D05940758F6CAE9A874A40115663096BD15940758F6CAE9A874A40115663096BD15940047289230F864A40A912656F29D05940047289230F864A40
20824	Жмурова	5	50	174	102.920207	102.93755299999999	53.140276999999998	53.11974	0103000020E6100000010000000500000038A3E6ABE4BA5940F302ECA3538F4A4038A3E6ABE4BA5940C4B0C398F4914A4011514CDE00BC5940C4B0C398F4914A4011514CDE00BC5940F302ECA3538F4A4038A3E6ABE4BA5940F302ECA3538F4A40
21723	Жалгай	5	50	174	102.311787	102.336814	53.144694999999999	53.133465000000001	0103000020E6100000010000000500000059147651F49359409014916115914A4059147651F49359408672A25D85924A4070B54E5C8E9559408672A25D85924A4070B54E5C8E9559409014916115914A4059147651F49359409014916115914A40
20397	Голуметь	5	50	174	102.33857399999999	102.41036800000001	53.060586999999998	53.021566999999997	0103000020E61000000100000005000000A8514832AB9559401FD61BB5C2824A40A8514832AB95594008C89750C1874A40CCD42478439A594008C89750C1874A40CCD42478439A59401FD61BB5C2824A40A8514832AB9559401FD61BB5C2824A40
59350	Герасимова	5	50	174	102.77588299999999	102.789331	53.014389000000001	52.995255999999998	0103000020E610000001000000050000006EA12B11A8B15940EA92718C647F4A406EA12B11A8B159400936AE7FD7814A4004AE2B6684B259400936AE7FD7814A4004AE2B6684B25940EA92718C647F4A406EA12B11A8B15940EA92718C647F4A40
59233	Верхняя Иреть	5	50	174	102.296345	102.32169500000001	52.972214999999998	52.960000000000001	0103000020E6100000010000000500000052D50451F79259407B14AE47E17A4A4052D50451F79259401FD7868A717C4A405A12A0A6969459401FD7868A717C4A405A12A0A6969459407B14AE47E17A4A4052D50451F79259407B14AE47E17A4A40
20278	Верхний Булай	5	50	174	103.011062	103.066686	53.037770999999999	53.024481000000002	0103000020E610000001000000050000009D0E643DB5C05940CB2F833122834A409D0E643DB5C059405DDE1CAED5844A4078465B9544C459405DDE1CAED5844A4078465B9544C45940CB2F833122834A409D0E643DB5C05940CB2F833122834A40
20122	Бельск	5	50	174	103.066228	103.090671	52.882866	52.859139999999996	0103000020E6100000010000000500000016855D143DC45940BC57AD4CF86D4A4016855D143DC459400B60CAC001714A4085ECBC8DCDC559400B60CAC001714A4085ECBC8DCDC55940BC57AD4CF86D4A4016855D143DC45940BC57AD4CF86D4A40
549	Белобородова	5	50	174	103.064719	103.080376	53.223635000000002	53.212215	0103000020E61000000100000005000000821B295B24C459403E5C72DC299B4A40821B295B24C45940D89E5912A09C4A4088D860E124C55940D89E5912A09C4A4088D860E124C559403E5C72DC299B4A40821B295B24C459403E5C72DC299B4A40
20613	Бархатова	5	50	174	103.347751	103.357722	53.011468999999998	53.004294999999999	0103000020E61000000100000005000000AF09698D41D65940A64412BD8C804A40AF09698D41D659407BF5F1D077814A40D2C3D0EAE4D659407BF5F1D077814A40D2C3D0EAE4D65940A64412BD8C804A40AF09698D41D65940A64412BD8C804A40
20749	Балухарь	5	50	174	103.23671	103.26110799999999	53.245193999999998	53.236576999999997	0103000020E61000000100000005000000B728B34126CF59402EFEB627489E4A40B728B34126CF594074965984629F4A40552E54FEB5D0594074965984629F4A40552E54FEB5D059402EFEB627489E4A40B728B34126CF59402EFEB627489E4A40
21246	Бажей	5	50	174	102.622981	102.671122	52.977679999999999	52.967739999999999	0103000020E61000000100000005000000E141B3EBDEA75940F98381E7DE7B4A40E141B3EBDEA7594005FA449E247D4A401268B0A9F3AA594005FA449E247D4A401268B0A9F3AA5940F98381E7DE7B4A40E141B3EBDEA75940F98381E7DE7B4A40
19967	Алехино	5	50	174	103.100948	103.14420200000001	53.078046999999998	53.060473999999999	0103000020E610000001000000050000002FA699EE75C659401021AE9CBD874A402FA699EE75C659408446B071FD894A402481069B3AC959408446B071FD894A402481069B3AC959401021AE9CBD874A402FA699EE75C659401021AE9CBD874A40
29745	Юголок	5	50	212	103.279515	103.31229399999999	54.193454000000003	54.177748000000001	0103000020E6100000010000000500000074EFE192E3D15940F7764B72C0164B4074EFE192E3D15940E4A3C519C3184B402B2FF99FFCD35940E4A3C519C3184B402B2FF99FFCD35940F7764B72C0164B4074EFE192E3D15940F7764B72C0164B40
29950	Чичкова	5	50	212	103.702082	103.718548	54.199485000000003	54.179144000000001	0103000020E610000001000000050000000F4757E9EEEC594027A3CA30EE164B400F4757E9EEEC5940738577B988194B40CC26C0B0FCED5940738577B988194B40CC26C0B0FCED594027A3CA30EE164B400F4757E9EEEC594027A3CA30EE164B40
3126	Халюты	5	50	212	103.386109	103.399638	53.840882000000001	53.831440000000001	0103000020E610000001000000050000003EEC8502B6D859400A4B3CA06CEA4A403EEC8502B6D85940C5E57805A2EB4A40490F43AB93D95940C5E57805A2EB4A40490F43AB93D959400A4B3CA06CEA4A403EEC8502B6D859400A4B3CA06CEA4A40
19271	Усть-Уда	5	50	212	103.01026299999999	103.058898	54.186473999999997	54.157017000000003	0103000020E61000000100000005000000F7562426A8C0594041F50F2219144B40F7562426A8C05940F3C64961DE174B4030F31DFCC4C35940F3C64961DE174B4030F31DFCC4C3594041F50F2219144B40F7562426A8C0594041F50F2219144B40
27583	Усть-Малой	5	50	212	103.654768	103.67304	53.953772999999998	53.945760999999997	0103000020E61000000100000005000000E99D0AB8E7E95940876A4AB20EF94A40E99D0AB8E7E959406667D13B15FA4A4097395D1613EB59406667D13B15FA4A4097395D1613EB5940876A4AB20EF94A40E99D0AB8E7E95940876A4AB20EF94A40
803	Тагай	5	50	212	103.533478	103.541994	53.726894999999999	53.707765999999999	0103000020E61000000100000005000000ACC8E88024E25940419C871398DA4A40ACC8E88024E259401E5036E50ADD4A4035289A07B0E259401E5036E50ADD4A4035289A07B0E25940419C871398DA4A40ACC8E88024E25940419C871398DA4A40
29648	Средняя Муя	5	50	212	103.51160400000001	103.531205	54.342156000000003	54.328223000000001	0103000020E610000001000000050000002E20B41EBEE05940C3651536032A4B402E20B41EBEE05940AA108FC4CB2B4B40309E4143FFE15940AA108FC4CB2B4B40309E4143FFE15940C3651536032A4B402E20B41EBEE05940C3651536032A4B40
19909	Светлолобово	5	50	212	103.116587	103.139162	54.289546000000001	54.274301999999999	0103000020E61000000100000005000000E108522976C759401B9DF3531C234B40E108522976C759400458E4D70F254B4024B6BB07E8C859400458E4D70F254B4024B6BB07E8C859401B9DF3531C234B40E108522976C759401B9DF3531C234B40
30126	Подволочное	5	50	212	103.36179199999999	103.373164	55.209504000000003	55.204093999999998	0103000020E6100000010000000500000015FDA19927D75940A8A78FC01F9A4B4015FDA19927D75940CB30EE06D19A4B40DA0242EBE1D75940CB30EE06D19A4B40DA0242EBE1D75940A8A78FC01F9A4B4015FDA19927D75940A8A78FC01F9A4B40
29884	Новая Уда	5	50	212	103.595479	103.62311099999999	54.040109999999999	54.016702000000002	0103000020E610000001000000050000001B9DF3531CE659408FE3874A23024B401B9DF3531CE659400C1F115322054B40C8B1F50CE1E759400C1F115322054B40C8B1F50CE1E759408FE3874A23024B401B9DF3531CE659408FE3874A23024B40
2577	Молька	5	50	212	103.321673	103.345766	53.889242000000003	53.874301000000003	0103000020E6100000010000000500000066C0594A96D4594018EE5C18E9EF4A4066C0594A96D45940651D8EAED2F14A406684B70721D65940651D8EAED2F14A406684B70721D6594018EE5C18E9EF4A4066C0594A96D4594018EE5C18E9EF4A40
19832	Михайловщина	5	50	212	103.03169699999999	103.044875	54.204557000000001	54.196530000000003	0103000020E610000001000000050000006798DA5207C25940695721E527194B406798DA5207C259407D957CEC2E1A4B401D5A643BDFC259407D957CEC2E1A4B401D5A643BDFC25940695721E527194B406798DA5207C25940695721E527194B40
19559	Малышевка	5	50	212	103.37857200000001	103.399027	53.743332000000002	53.726165000000002	0103000020E610000001000000050000009BCB0D863AD85940FB3F87F9F2DC4A409BCB0D863AD85940FF08C38025DF4A4025CE8AA889D95940FF08C38025DF4A4025CE8AA889D95940FB3F87F9F2DC4A409BCB0D863AD85940FB3F87F9F2DC4A40
19681	Лобагай	5	50	212	103.324799	103.334519	53.959319999999998	53.942317000000003	0103000020E6100000010000000500000081B1BE81C9D4594080BBECD79DF84A4081B1BE81C9D4594009336DFFCAFA4A40003961C268D5594009336DFFCAFA4A40003961C268D5594080BBECD79DF84A4081B1BE81C9D4594080BBECD79DF84A40
29983	Ключи	5	50	212	103.25791	103.266705	54.541704000000003	54.533648999999997	0103000020E61000000100000005000000EDD3F19881D059408445459C4E444B40EDD3F19881D05940630E828E56454B40802BD9B111D15940630E828E56454B40802BD9B111D159408445459C4E444B40EDD3F19881D059408445459C4E444B40
29807	Кижа	5	50	212	103.35404800000001	103.375608	54.129174999999996	54.119239	0103000020E61000000100000005000000B64DF1B8A8D6594031B43A39430F4B40B64DF1B8A8D65940FB3A70CE88104B406C0723F609D85940FB3A70CE88104B406C0723F609D8594031B43A39430F4B40B64DF1B8A8D6594031B43A39430F4B40
19745	Игжей	5	50	212	103.127861	103.15338199999999	54.028914999999998	54.015945000000002	0103000020E61000000100000005000000C45BE7DF2EC8594072C45A7C0A024B40C45BE7DF2EC8594092AE997CB3034B40E272BC02D1C9594092AE997CB3034B40E272BC02D1C9594072C45A7C0A024B40C45BE7DF2EC8594072C45A7C0A024B40
29863	Балаганка	5	50	212	103.312214	103.34964600000001	54.074294999999999	54.060054999999998	0103000020E610000001000000050000009DD66D50FBD359400B7BDAE1AF074B409DD66D50FBD35940CFA0A17F82094B4058CB9D9960D65940CFA0A17F82094B4058CB9D9960D659400B7BDAE1AF074B409DD66D50FBD359400B7BDAE1AF074B40
30118	Аталанка	5	50	212	103.078436	103.091156	54.836181000000003	54.824134000000001	0103000020E610000001000000050000000FB56D1805C55940C6C210397D694B400FB56D1805C55940AF44A0FA076B4B4063B5F97FD5C55940AF44A0FA076B4B4063B5F97FD5C55940C6C210397D694B400FB56D1805C55940C6C210397D694B40
30042	Аносово	5	50	212	103.23353	103.258072	54.667003999999999	54.639533999999998	0103000020E61000000100000005000000A228D027F2CE59400C570740DC514B40A228D027F2CE59408D26176360554B40DA006C4084D059408D26176360554B40DA006C4084D059400C570740DC514B40A228D027F2CE59400C570740DC514B40
59144	Янталь	5	50	7466	105.21430599999999	105.254829	56.859025000000003	56.842457000000003	0103000020E610000001000000050000008A558330B74D5A40A5A487A1D56B4C408A558330B74D5A4024B9FC87F46D4C40A2444B1E4F505A4024B9FC87F46D4C40A2444B1E4F505A40A5A487A1D56B4C408A558330B74D5A40A5A487A1D56B4C40
59187	Подымахино	5	50	7466	106.174201	106.184657	56.981620999999997	56.970908000000001	0103000020E610000001000000050000008D7BF31B268B5A405FB69DB6467C4C408D7BF31B268B5A408D08C6C1A57D4C408FFE976BD18B5A408D08C6C1A57D4C408FFE976BD18B5A405FB69DB6467C4C408D7BF31B268B5A405FB69DB6467C4C40
59177	Ния	5	50	7466	106.800704	106.808322	56.563496999999998	56.542262000000001	0103000020E61000000100000005000000B071FDBB3EB35A4089EE59D768454C40B071FDBB3EB35A40723271AB20484C40CAA8328CBBB35A40723271AB20484C40CAA8328CBBB35A4089EE59D768454C40B071FDBB3EB35A4089EE59D768454C40
59335	Небель	5	50	7466	107.061305	107.07293	56.374442000000002	56.367946000000003	0103000020E610000001000000050000003485CE6BECC35A40D658C2DA182F4C403485CE6BECC35A40DA1F28B7ED2F4C406D3997E2AAC45A40DA1F28B7ED2F4C406D3997E2AAC45A40D658C2DA182F4C403485CE6BECC35A40D658C2DA182F4C40
59176	Верхнемарково	5	50	7466	106.997435	107.06992	57.339796	57.315322000000002	0103000020E61000000100000005000000B0389CF9D5BF5A40CBDAA6785CA84C40B0389CF9D5BF5A40E3A7716F7EAB4C408655BC9179C45A40E3A7716F7EAB4C408655BC9179C45A40CBDAA6785CA84C40B0389CF9D5BF5A40CBDAA6785CA84C40
59126	р.п. Железнодорожный	5	50	331	102.72754500000001	102.806381	57.918353000000003	57.897266000000002	0103000020E610000001000000050000009357E71890AE594008E8BE9CD9F24C409357E71890AE59407D9752978CF54C4069C70DBF9BB359407D9752978CF54C4069C70DBF9BB3594008E8BE9CD9F24C409357E71890AE594008E8BE9CD9F24C40
15780	Эдучанка	5	50	331	102.11676199999999	102.166763	57.37003	57.357235000000003	0103000020E6100000010000000500000098DA52077987594048FE60E0B9AD4C4098DA520779875940FA449E245DAF4C40B4CBB73EAC8A5940FA449E245DAF4C40B4CBB73EAC8A594048FE60E0B9AD4C4098DA52077987594048FE60E0B9AD4C40
14351	Усть-Илимск	5	50	331	102.560647	102.771293	58.135641	57.926875000000003	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
59103	Усть- Илимск	5	50	331	102.560647	102.771293	58.135641	57.926875000000003	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
15515	Тубинский	5	50	331	103.268699	103.289935	57.676909000000002	57.637776000000002	0103000020E61000000100000005000000F25D4A5D32D159403C16DBA4A2D14C40F25D4A5D32D159401DAF40F4A4D64C40CFBD874B8ED259401DAF40F4A4D64C40CFBD874B8ED259403C16DBA4A2D14C40F25D4A5D32D159403C16DBA4A2D14C40
1654	Седаново	5	50	331	101.298289	101.319705	56.988501999999997	56.971128	0103000020E610000001000000050000006BF0BE2A175359406D1D1CEC4D7C4C406BF0BE2A17535940EA03C93B877E4C4088D7F50B76545940EA03C93B877E4C4088D7F50B765459406D1D1CEC4D7C4C406BF0BE2A175359406D1D1CEC4D7C4C40
15942	Подъеланка	5	50	331	101.64160800000001	101.657984	57.088543000000001	57.076411999999998	0103000020E610000001000000050000008736001B10695940CF8250DEC7894C408736001B1069594016A58460558B4C40A452EC681C6A594016A58460558B4C40A452EC681C6A5940CF8250DEC7894C408736001B10695940CF8250DEC7894C40
15409	Невон	5	50	331	102.700101	102.738765	58.063378	58.030613000000002	0103000020E6100000010000000500000067B96C74CEAC59408EEA7420EB034D4067B96C74CEAC594098A432C51C084D407C9BFEEC47AF594098A432C51C084D407C9BFEEC47AF59408EEA7420EB034D4067B96C74CEAC59408EEA7420EB034D40
1536	Кеуль	5	50	331	102.80234799999999	102.833915	58.437927999999999	58.409534999999998	0103000020E61000000100000005000000B4006DAB59B359409FC893A46B344D40B4006DAB59B35940580053060E384D40352905DD5EB55940580053060E384D40352905DD5EB559409FC893A46B344D40B4006DAB59B359409FC893A46B344D40
13411	Железнодорожный	5	50	331	102.72754500000001	102.806381	57.918353000000003	57.897266000000002	0103000020E610000001000000050000009357E71890AE594008E8BE9CD9F24C409357E71890AE59407D9752978CF54C4069C70DBF9BB359407D9752978CF54C4069C70DBF9BB3594008E8BE9CD9F24C409357E71890AE594008E8BE9CD9F24C40
15881	Ершово	5	50	331	102.226635	102.24212199999999	57.152476999999998	57.146192999999997	0103000020E6100000010000000500000041481630818E5940BAF3C473B6924C4041481630818E59403332C85D84934C4018E945ED7E8F59403332C85D84934C4018E945ED7E8F5940BAF3C473B6924C4041481630818E5940BAF3C473B6924C40
1618	Бадарминск	5	50	331	102.376259	102.39304799999999	57.772435000000002	57.761705999999997	0103000020E61000000100000005000000D8F4A0A0149859405F950B957FE14C40D8F4A0A01498594094A46B26DFE24C408670CCB22799594094A46B26DFE24C408670CCB2279959405F950B957FE14C40D8F4A0A0149859405F950B957FE14C40
15748	Бадарма	5	50	331	102.42135399999999	102.43229599999999	57.757586000000003	57.750532	0103000020E610000001000000050000007B82C476F79A5940FD4CBD6E11E04C407B82C476F79A594028F4FA93F8E04C40438CD7BCAA9B594028F4FA93F8E04C40438CD7BCAA9B5940FD4CBD6E11E04C407B82C476F79A5940FD4CBD6E11E04C40
13594	Целоты	5	50	1227	103.528941	103.553708	52.482269000000002	52.473354999999998	0103000020E61000000100000005000000DE205A2BDAE15940F4328AE5963C4A40DE205A2BDAE15940F46F97FDBA3D4A4026E2ADF36FE35940F46F97FDBA3D4A4026E2ADF36FE35940F4328AE5963C4A40DE205A2BDAE15940F4328AE5963C4A40
12880	Холмушино	5	50	1227	103.303078	103.317954	52.886550999999997	52.863511000000003	0103000020E61000000100000005000000C68844A165D359403E5E4887876E4A40C68844A165D35940389ECF807A714A4079E8BB5B59D45940389ECF807A714A4079E8BB5B59D459403E5E4887876E4A40C68844A165D359403E5E4887876E4A40
13988	Ходарей	5	50	1227	103.209779	103.226218	52.264588000000003	52.257852	0103000020E61000000100000005000000CE18E6046DCD5940A69A594B01214A40CE18E6046DCD594000750305DE214A400FF10F5B7ACE594000750305DE214A400FF10F5B7ACE5940A69A594B01214A40CE18E6046DCD5940A69A594B01214A40
12471	Хайта	5	50	1227	103.185452	103.208997	52.819462999999999	52.801293000000001	0103000020E6100000010000000500000094BE1072DECB5940C2C1DEC490664A4094BE1072DECB59401AA4E029E4684A4093FDF33460CD59401AA4E029E4684A4093FDF33460CD5940C2C1DEC490664A4094BE1072DECB5940C2C1DEC490664A40
13318	Тельма	5	50	1227	103.695695	103.738653	52.708486000000001	52.662216000000001	0103000020E61000000100000005000000683F524486EC5940A8716F7EC3544A40683F524486EC594041D653ABAF5A4A40E8853B1746EF594041D653ABAF5A4A40E8853B1746EF5940A8716F7EC3544A40683F524486EC5940A8716F7EC3544A40
59191	Тальяны	5	50	1227	103.250895	103.272948	52.207189999999997	52.184457999999999	0103000020E61000000100000005000000B7EEE6A90ED0594027BEDA519C174A40B7EEE6A90ED059407407B133851A4A408D60E3FA77D159407407B133851A4A408D60E3FA77D1594027BEDA519C174A40B7EEE6A90ED0594027BEDA519C174A40
12911	Тайтурка	5	50	1227	103.42021800000001	103.492407	52.876818	52.853523000000003	0103000020E6100000010000000500000032CC09DAE4DA594021B1DD3D406D4A4032CC09DAE4DA5940A6457D923B704A409354A69883DF5940A6457D923B704A409354A69883DF594021B1DD3D406D4A4032CC09DAE4DA594021B1DD3D406D4A40
59100	Средний	5	50	1227	103.48020699999999	103.548929	52.912824999999998	52.87341	0103000020E61000000100000005000000DB1324B6BBDE5940EBFF1CE6CB6F4A40DB1324B6BBDE594050FC1873D7744A40DDB419A721E3594050FC1873D7744A40DDB419A721E35940EBFF1CE6CB6F4A40DB1324B6BBDE5940EBFF1CE6CB6F4A40
58906	Сосновка	5	50	1227	103.380827	103.425428	52.829421000000004	52.812430999999997	0103000020E61000000100000005000000C39B35785FD85940D7A02FBDFD674A40C39B35785FD85940CDCEA2772A6A4A405FB35C363ADB5940CDCEA2772A6A4A405FB35C363ADB5940D7A02FBDFD674A40C39B35785FD85940D7A02FBDFD674A40
13831	Раздолье	5	50	1227	103.17390899999999	103.219579	52.454459	52.437387999999999	0103000020E61000000100000005000000B9DE365321CB5940D8D47954FC374A40B9DE365321CB5940BA2F67B62B3A4A40DBF813950DCE5940BA2F67B62B3A4A40DBF813950DCE5940D8D47954FC374A40B9DE365321CB5940D8D47954FC374A40
59242	Октябрьский	5	50	1227	102.97490500000001	102.988497	52.420721999999998	52.405648999999997	0103000020E610000001000000050000003EEDF0D764BE5940DA53724EEC334A403EEDF0D764BE5940965AEF37DA354A406CCCEB8843BF5940965AEF37DA354A406CCCEB8843BF5940DA53724EEC334A403EEDF0D764BE5940DA53724EEC334A40
13223	Новомальтинск	5	50	1227	103.534627	103.571225	52.878926999999997	52.859107000000002	0103000020E61000000100000005000000C0232A5437E25940E161DA37F76D4A40C0232A5437E25940234910AE80704A40166A4DF38EE45940234910AE80704A40166A4DF38EE45940E161DA37F76D4A40C0232A5437E25940E161DA37F76D4A40
13695	Новожилкино	5	50	1227	103.534223	103.568009	52.566899999999997	52.549917000000001	0103000020E610000001000000050000005871AAB530E25940D94125AE63464A405871AAB530E259401B0DE02D90484A405BB56B425AE459401B0DE02D90484A405BB56B425AE45940D94125AE63464A405871AAB530E25940D94125AE63464A40
12701	Мальта	5	50	1227	103.50655500000001	103.54235300000001	52.853740000000002	52.815463000000001	0103000020E6100000010000000500000005A8A9656BE059408D0C721761684A4005A8A9656BE05940BEA4315A476D4A40CD785BE9B5E25940BEA4315A476D4A40CD785BE9B5E259408D0C721761684A4005A8A9656BE059408D0C721761684A40
13035	Кочерикова	5	50	1227	103.40532399999999	103.41746000000001	52.950187	52.936560999999998	0103000020E610000001000000050000002B1213D4F0D95940C2DA183BE1774A402B1213D4F0D95940CC0A45BA9F794A40D8D825AAB7DA5940CC0A45BA9F794A40D8D825AAB7DA5940C2DA183BE1774A402B1213D4F0D95940C2DA183BE1774A40
59280	Ключевая	5	50	1227	103.56836800000001	103.58375599999999	52.591208000000002	52.581814000000001	0103000020E61000000100000005000000F3052D2460E459406F2D93E1784A4A40F3052D2460E45940199128B4AC4B4A40003620425CE55940199128B4AC4B4A40003620425CE559406F2D93E1784A4A40F3052D2460E459406F2D93E1784A4A40
13093	Буреть	5	50	1227	103.493745	103.528752	53.000014	52.981887999999998	0103000020E6100000010000000500000011E4A08499DF5940DC2A8881AE7D4A4011E4A08499DF594065C5707500804A4074ECA012D7E1594065C5707500804A4074ECA012D7E15940DC2A8881AE7D4A4011E4A08499DF5940DC2A8881AE7D4A40
13561	Большой Елань	5	50	1227	103.637574	103.688715	52.587136999999998	52.558590000000002	0103000020E61000000100000005000000EAB12D03CEE85940B3EF8AE07F474A40EAB12D03CEE85940C2A2224E274B4A40F05014E813EC5940C2A2224E274B4A40F05014E813EC5940B3EF8AE07F474A40EAB12D03CEE85940B3EF8AE07F474A40
13650	Большежилкина	5	50	1227	103.560211	103.601246	52.545585000000003	52.536093000000001	0103000020E6100000010000000500000001F73C7FDAE35940A94E07B29E444A4001F73C7FDAE359401618B2BAD5454A4074B680D07AE659401618B2BAD5454A4074B680D07AE65940A94E07B29E444A4001F73C7FDAE35940A94E07B29E444A40
12557	Белореченский	5	50	1227	103.50183	103.538769	52.821863	52.795811	0103000020E61000000100000005000000B58993FB1DE0594006668522DD654A40B58993FB1DE059406F6589CE32694A4050C6F8307BE259406F6589CE32694A4050C6F8307BE2594006668522DD654A40B58993FB1DE0594006668522DD654A40
13282	Бадай	5	50	1227	103.59100599999999	103.624441	52.880159999999997	52.873235999999999	0103000020E61000000100000005000000586FD40AD3E559404DD87E32C66F4A40586FD40AD3E55940A99F3715A9704A40055262D7F6E75940A99F3715A9704A40055262D7F6E759404DD87E32C66F4A40586FD40AD3E559404DD87E32C66F4A40
59257	п.1 отделение Государственной селекционной станции	5	50	307	99.237797	101.103696	55.078797999999999	53.233597000000003	0103000020E610000001000000050000009085E81038CF5840CCB8A981E69D4A409085E81038CF5840BF7E880D168A4B40772E8CF4A2465940BF7E880D168A4B40772E8CF4A2465940CCB8A981E69D4A409085E81038CF5840CCB8A981E69D4A40
59192	Шуба	5	50	307	100.878516	100.910172	54.454763	54.443857999999999	0103000020E61000000100000005000000D1402C9B39385940B308C556D0384B40D1402C9B3938594026378AAC353A4B40096F0F42403A594026378AAC353A4B40096F0F42403A5940B308C556D0384B40D1402C9B39385940B308C556D0384B40
9290	Шерагул	5	50	307	100.882334	100.933852	54.467328000000002	54.453767999999997	0103000020E61000000100000005000000878906297838594054FCDF11153A4B408789062978385940A7406667D13B4B4078D32D3BC43B5940A7406667D13B4B4078D32D3BC43B594054FCDF11153A4B40878906297838594054FCDF11153A4B40
9083	Центральные Мастерские	5	50	307	100.512767	100.533509	54.604191999999998	54.589733000000003	0103000020E61000000100000005000000F4DDAD2CD12059409D2FF65E7C4B4B40F4DDAD2CD12059409E40D829564D4B40C9C7EE02252259409E40D829564D4B40C9C7EE02252259409D2FF65E7C4B4B40F4DDAD2CD12059409D2FF65E7C4B4B40
10565	Целинные Земли	5	50	307	100.62221700000001	100.640804	54.704132999999999	54.692655999999999	0103000020E61000000100000005000000FA804067D227594068B0A9F3A8584B40FA804067D22759406684B707215A4B4058C9C7EE022959406684B707215A4B4058C9C7EE0229594068B0A9F3A8584B40FA804067D227594068B0A9F3A8584B40
9460	Харгажин	5	50	307	100.981786	101.008709	54.292757000000002	54.279043999999999	0103000020E61000000100000005000000EC6AF294D53E59409012BBB6B7234B40EC6AF294D53E59406956B60F79254B40938B31B08E4059406956B60F79254B40938B31B08E4059409012BBB6B7234B40EC6AF294D53E59409012BBB6B7234B40
9507	Уталай	5	50	307	100.889556	100.92636	54.343730000000001	54.333941000000003	0103000020E610000001000000050000007AFD497CEE38594093E52494BE2A4B407AFD497CEE385940B9533A58FF2B4B40A514747B493B5940B9533A58FF2B4B40A514747B493B594093E52494BE2A4B407AFD497CEE38594093E52494BE2A4B40
8827	Утай	5	50	307	100.29486199999999	100.349992	54.644733000000002	54.630111999999997	0103000020E6100000010000000500000052B5DD04DF12594098689082A7504B4052B5DD04DF12594074D3669C86524B402577D8446616594074D3669C86524B402577D8446616594098689082A7504B4052B5DD04DF12594098689082A7504B40
10659	Усть-Кульск	5	50	307	100.56254199999999	100.586006	54.887433999999999	54.874169999999999	0103000020E61000000100000005000000172829B000245940799274CDE46F4B40172829B000245940E2ADF36F97714B40A0504F1F81255940E2ADF36F97714B40A0504F1F81255940799274CDE46F4B40172829B000245940799274CDE46F4B40
10431	Умыган	5	50	307	100.206836	100.252318	54.75994	54.743738999999998	0103000020E61000000100000005000000ABE80FCD3C0D59403FE1ECD6325F4B40ABE80FCD3C0D59400C76C3B645614B404C8C65FA251059400C76C3B645614B404C8C65FA251059403FE1ECD6325F4B40ABE80FCD3C0D59403FE1ECD6325F4B40
9035	Уйгат	5	50	307	100.57997	100.607934	54.093378000000001	54.075567999999997	0103000020E6100000010000000500000050AA7D3A1E255940E34F5436AC094B4050AA7D3A1E2559403C1570CFF30B4B4018080264E82659403C1570CFF30B4B4018080264E8265940E34F5436AC094B4050AA7D3A1E255940E34F5436AC094B40
1419	Тулун	5	50	307	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
9331	Трактовая	5	50	307	101.04547700000001	101.07318100000001	54.487473999999999	54.48115	0103000020E6100000010000000500000018EE5C18E9425940363CBD52963D4B4018EE5C18E94259403DD34B8C653E4B40126C5CFFAE4459403DD34B8C653E4B40126C5CFFAE445940363CBD52963D4B4018EE5C18E9425940363CBD52963D4B40
8985	Сибиряк	5	50	307	100.50124099999999	100.523403	54.728180999999999	54.710687999999998	0103000020E61000000100000005000000849A2155142059406FD40AD3F75A4B40849A215514205940C748F608355D4B4036E84B6F7F215940C748F608355D4B4036E84B6F7F2159406FD40AD3F75A4B40849A2155142059406FD40AD3F75A4B40
8344	Северный Кадуй	5	50	307	100.089741	100.104123	54.676485	54.669888999999998	0103000020E6100000010000000500000010070951BE0559409E7939ECBE554B4010070951BE055940069E7B0F97564B40BBF083F3A9065940069E7B0F97564B40BBF083F3A90659409E7939ECBE554B4010070951BE0559409E7939ECBE554B40
9755	Петровск	5	50	307	100.38462199999999	100.40513	54.373887000000003	54.362231999999999	0103000020E610000001000000050000009DD497A59D18594047C8409E5D2E4B409DD497A59D18594025B37A87DB2F4B40392861A6ED19594025B37A87DB2F4B40392861A6ED19594047C8409E5D2E4B409DD497A59D18594047C8409E5D2E4B40
9693	Перфилово	5	50	307	100.476574	100.503846	54.420957000000001	54.398497999999996	0103000020E61000000100000005000000EE073C30801E5940BDC282FB01334B40EE073C30801E5940DA0242EBE1354B401B0E4B033F205940DA0242EBE1354B401B0E4B033F205940BDC282FB01334B40EE073C30801E5940BDC282FB01334B40
5037	Паберега	5	50	307	100.90700099999999	100.93830800000001	54.845559999999999	54.837203000000002	0103000020E610000001000000050000001D1CEC4D0C3A59407A8EC877296B4B401D1CEC4D0C3A59402367614F3B6C4B40D064FF3C0D3C59402367614F3B6C4B40D064FF3C0D3C59407A8EC877296B4B401D1CEC4D0C3A59407A8EC877296B4B40
10027	Одон	5	50	307	100.46680000000001	100.49118900000001	54.189677000000003	54.181879000000002	0103000020E6100000010000000500000076711B0DE01D5940236AA2CF47174B4076711B0DE01D5940D6E6FF5547184B40EBC9FCA36F1F5940D6E6FF5547184B40EBC9FCA36F1F5940236AA2CF47174B4076711B0DE01D5940236AA2CF47174B40
9360	Новотроицк	5	50	307	101.038371	101.063757	54.459735000000002	54.451616999999999	0103000020E610000001000000050000005987A3AB74425940A8A8FA95CE394B405987A3AB74425940CDE9B298D83A4B4007793D9814445940CDE9B298D83A4B4007793D9814445940A8A8FA95CE394B405987A3AB74425940A8A8FA95CE394B40
10467	Никитаево	5	50	307	100.67771500000001	100.70124199999999	54.637965000000001	54.628596000000002	0103000020E610000001000000050000008E40BCAE5F2B5940BE326FD575504B408E40BCAE5F2B59400F7F4DD6A8514B4039252026E12C59400F7F4DD6A8514B4039252026E12C5940BE326FD575504B408E40BCAE5F2B5940BE326FD575504B40
9667	Нижний Манут	5	50	307	100.516755	100.535251	54.478749000000001	54.456829999999997	0103000020E61000000100000005000000D94290831221594074EACA67793A4B40D94290831221594011FFB0A5473D4B40AF09698D4122594011FFB0A5473D4B40AF09698D4122594074EACA67793A4B40D94290831221594074EACA67793A4B40
10216	Нижний Бурбук	5	50	307	99.960392999999996	99.995722999999998	54.267378000000001	54.246208000000003	0103000020E61000000100000005000000AB93331477FD5840BD0166BE831F4B40AB93331477FD5840BFD53A7139224B400038F6ECB9FF5840BFD53A7139224B400038F6ECB9FF5840BD0166BE831F4B40AB93331477FD5840BD0166BE831F4B40
10307	Мугун	5	50	307	100.22729099999999	100.261831	54.485858	54.453648000000001	0103000020E6100000010000000500000035EB8CEF8B0E5940AAF23D23113A4B4035EB8CEF8B0E5940FF3F4E98303E4B400E85CFD6C1105940FF3F4E98303E4B400E85CFD6C1105940AAF23D23113A4B4035EB8CEF8B0E5940AAF23D23113A4B40
8896	Котик	5	50	307	100.444845	100.46909100000001	54.657428000000003	54.642597000000002	0103000020E6100000010000000500000081B22957781C5940FDC0559E40524B4081B22957781C5940C3BCC79926544B4045F64196051E5940C3BCC79926544B4045F64196051E5940FDC0559E40524B4081B22957781C5940FDC0559E40524B40
10277	Ишидей	5	50	307	99.704408999999998	99.724988999999994	54.123972000000002	54.115059000000002	0103000020E6100000010000000500000084807C0915ED5840240ED940BA0E4B4084807C0915ED584053CF8250DE0F4B406C3D433866EE584053CF8250DE0F4B406C3D433866EE5840240ED940BA0E4B4084807C0915ED5840240ED940BA0E4B40
10117	Икей	5	50	307	100.059881	100.103647	54.199643000000002	54.178491000000001	0103000020E61000000100000005000000B7291E17D5035940AFD007CBD8164B40B7291E17D50359400BF0DDE68D194B4006D50627A20659400BF0DDE68D194B4006D50627A2065940AFD007CBD8164B40B7291E17D5035940AFD007CBD8164B40
9964	Изегол	5	50	307	100.104896	100.13543799999999	54.320231	54.303927999999999	0103000020E61000000100000005000000CC5EB69DB60659405A2BDA1CE7264B40CC5EB69DB60659402B155454FD284B40AE282504AB0859402B155454FD284B40AE282504AB0859405A2BDA1CE7264B40CC5EB69DB60659405A2BDA1CE7264B40
59281	Заусаево	5	50	307	100.50010899999999	100.52494799999999	54.634718999999997	54.623987999999997	0103000020E61000000100000005000000DBDB2DC901205940588CBAD6DE4F4B40DBDB2DC9012059402D93E1783E514B4070067FBF982159402D93E1783E514B4070067FBF98215940588CBAD6DE4F4B40DBDB2DC901205940588CBAD6DE4F4B40
9910	Едогон	5	50	307	100.21199300000001	100.26988	54.261588000000003	54.245528999999998	0103000020E61000000100000005000000C87E164B910D59401B9C887E6D1F4B40C87E164B910D5940568330B77B214B400C76C3B645115940568330B77B214B400C76C3B6451159401B9C887E6D1F4B40C87E164B910D59401B9C887E6D1F4B40
59173	Евдокимовский	5	50	307	100.658294	100.684336	54.251463000000001	54.218294	0103000020E61000000100000005000000CB49287D212A5940DE74CB0EF11B4B40CB49287D212A5940B89388F02F204B406EDE3829CC2B5940B89388F02F204B406EDE3829CC2B5940DE74CB0EF11B4B40CB49287D212A5940DE74CB0EF11B4B40
10630	Гуран	5	50	307	100.622208	100.656273	54.768245999999998	54.748607999999997	0103000020E61000000100000005000000D0D38041D227594011C30E63D25F4B40D0D38041D227594033A48AE255624B40DC0F7860002A594033A48AE255624B40DC0F7860002A594011C30E63D25F4B40D0D38041D227594011C30E63D25F4B40
9551	Гадалей	5	50	307	100.70471000000001	100.76316300000001	54.413732000000003	54.383505	0103000020E6100000010000000500000082CAF8F7192D59401E6D1CB116314B4082CAF8F7192D594083A7902BF5344B401BA19FA9D730594083A7902BF5344B401BA19FA9D73059401E6D1CB116314B4082CAF8F7192D59401E6D1CB116314B40
10056	Владимировка	5	50	307	100.287442	100.32452499999999	54.180419999999998	54.169020000000003	0103000020E61000000100000005000000CC5F2173651259405A2F8672A2154B40CC5F217365125940ACC5A70018174B40006F8104C5145940ACC5A70018174B40006F8104C51459405A2F8672A2154B40CC5F2173651259405A2F8672A2154B40
8795	Бурхун	5	50	307	100.813541	100.831543	54.834682999999998	54.814548000000002	0103000020E61000000100000005000000213D450E11345940D882DE1B43684B40213D450E113459407AC37DE4D66A4B40EF8D2100383559407AC37DE4D66A4B40EF8D210038355940D882DE1B43684B40213D450E11345940D882DE1B43684B40
9168	Булюшкина	5	50	307	100.38751499999999	100.40501399999999	54.587657	54.576996999999999	0103000020E6100000010000000500000067EDB60BCD185940EF71A609DB494B4067EDB60BCD185940FB213658384B4B40041BD7BFEB195940FB213658384B4B40041BD7BFEB195940EF71A609DB494B4067EDB60BCD185940EF71A609DB494B40
7881	Будагово	5	50	307	100.11714000000001	100.144565	54.637455000000003	54.616909	0103000020E610000001000000050000006C43C5387F075940D5CDC5DFF64E4B406C43C5387F075940FAD51C2098514B405CC98E8D40095940FAD51C2098514B405CC98E8D40095940D5CDC5DFF64E4B406C43C5387F075940D5CDC5DFF64E4B40
9828	Бадар	5	50	307	100.585252	100.60981200000001	54.408503000000003	54.388632000000001	0103000020E61000000100000005000000CAFACDC474255940EC1681B1BE314B40CAFACDC474255940B1A888D349344B40562DE92807275940B1A888D349344B40562DE92807275940EC1681B1BE314B40CAFACDC474255940EC1681B1BE314B40
10529	Афанасьева	5	50	307	100.606452	100.630653	54.645406000000001	54.635235000000002	0103000020E6100000010000000500000001A60C1CD0265940252367614F514B4001A60C1CD02659403352EFA99C524B40F487669E5C2859403352EFA99C524B40F487669E5C285940252367614F514B4001A60C1CD0265940252367614F514B40
10162	Аршан	5	50	307	99.888518000000005	99.923355000000001	53.941288999999998	53.910075999999997	0103000020E6100000010000000500000012FA997ADDF85840EF6FD05E7DF44A4012FA997ADDF85840D28A6F287CF84A4047E6913F18FB5840D28A6F287CF84A4047E6913F18FB5840EF6FD05E7DF44A4012FA997ADDF85840EF6FD05E7DF44A40
10358	Алгатуй	5	50	307	100.167355	100.222027	54.420915000000001	54.390068999999997	0103000020E610000001000000050000009DF4BEF1B50A59407A17EFC7ED314B409DF4BEF1B50A5940ABB2EF8AE0354B400EF5BBB0350E5940ABB2EF8AE0354B400EF5BBB0350E59407A17EFC7ED314B409DF4BEF1B50A59407A17EFC7ED314B40
9242	Азей (Листвянка)	5	50	307	100.752707	100.776889	54.514054000000002	54.504280000000001	0103000020E61000000100000005000000191EFB592C30594071033E3F8C404B40191EFB592C30594062307F85CC414B40D1E7A38CB831594062307F85CC414B40D1E7A38CB831594071033E3F8C404B40191EFB592C30594071033E3F8C404B40
7443	Юрты	5	50	139	97.613544000000005	97.655503999999993	56.063116999999998	56.035254999999999	0103000020E610000001000000050000000DAA0D4E446758409F02603C83044C400DAA0D4E446758402B69C53714084C406B990CC7F36958402B69C53714084C406B990CC7F36958409F02603C83044C400DAA0D4E446758409F02603C83044C40
5254	Шиткино	5	50	139	98.329052000000004	98.375207000000003	56.382446999999999	56.356805999999999	0103000020E61000000100000005000000BDAB1E300F9558401F82AAD1AB2D4C40BDAB1E300F95584006BAF605F4304C40BD8E38640398584006BAF605F4304C40BD8E3864039858401F82AAD1AB2D4C40BDAB1E300F9558401F82AAD1AB2D4C40
52151	Шелехово	5	50	139	97.679946999999999	97.716139999999996	55.736240000000002	55.707830999999999	0103000020E61000000100000005000000DA006C40846B5840280CCA349ADA4B40DA006C40846B5840E700C11C3DDE4B40E0D6DD3CD56D5840E700C11C3DDE4B40E0D6DD3CD56D5840280CCA349ADA4B40DA006C40846B5840280CCA349ADA4B40
4930	Шелаево	5	50	139	97.682606000000007	97.708495999999997	56.935822000000002	56.918059999999997	0103000020E610000001000000050000006B8313D1AF6B584004E275FD82754C406B8313D1AF6B58404C70EA03C9774C4032569BFF576D58404C70EA03C9774C4032569BFF576D584004E275FD82754C406B8313D1AF6B584004E275FD82754C40
52134	Черчет	5	50	139	97.841509000000002	97.876031999999995	56.728873999999998	56.720503000000001	0103000020E610000001000000050000008A929048DB755840BFD53A71395C4C408A929048DB755840CD7344BE4B5D4C40F78F85E810785840CD7344BE4B5D4C40F78F85E810785840BFD53A71395C4C408A929048DB755840BFD53A71395C4C40
52203	Троицк	5	50	139	97.540115999999998	97.555351000000002	55.924622999999997	55.913342999999998	0103000020E61000000100000005000000F702B34291625840E883656CE8F44B40F702B342916258409010E50B5AF64B4042B3EBDE8A6358409010E50B5AF64B4042B3EBDE8A635840E883656CE8F44B40F702B34291625840E883656CE8F44B40
52125	Тремина	5	50	139	98.048642999999998	98.060438000000005	56.724608000000003	56.713267000000002	0103000020E610000001000000050000007A8B87F71C835840742843554C5B4C407A8B87F71C835840C23577F4BF5C4C40E25B5837DE835840C23577F4BF5C4C40E25B5837DE835840742843554C5B4C407A8B87F71C835840742843554C5B4C40
52205	Тимирязева	5	50	139	97.742165	97.766167999999993	55.947001	55.939045	0103000020E6100000010000000500000018CFA0A17F6F5840753C66A032F84B4018CFA0A17F6F5840C0232A5437F94B4078CF81E508715840C0232A5437F94B4078CF81E508715840753C66A032F84B4018CFA0A17F6F5840753C66A032F84B40
4332	Тамтачет	5	50	139	97.713651999999996	97.738534999999999	57.284210999999999	57.263316000000003	0103000020E61000000100000005000000662E7079AC6D5840BC41B456B4A14C40662E7079AC6D5840EC14AB0661A44C40E3FC4D28446F5840EC14AB0661A44C40E3FC4D28446F5840BC41B456B4A14C40662E7079AC6D5840BC41B456B4A14C40
52185	Талая	5	50	139	97.724305999999999	97.771279000000007	55.600805999999999	55.574145999999999	0103000020E61000000100000005000000FB928D075B6E58408A90BA9D7DC94B40FB928D075B6E5840CB9E0436E7CC4B40DD4598A25C715840CB9E0436E7CC4B40DD4598A25C7158408A90BA9D7DC94B40FB928D075B6E58408A90BA9D7DC94B40
59260	Тайшет	5	50	139	96.595096999999996	99.033798000000004	57.831882999999998	54.639496999999999	0103000020E61000000100000005000000A73CBA1116265840EF71A609DB514B40A73CBA1116265840978C63247BEA4C40E52A16BF29C25840978C63247BEA4C40E52A16BF29C25840EF71A609DB514B40A73CBA1116265840EF71A609DB514B40
52180	Старый Акульшет	5	50	139	98.053054000000003	98.078942999999995	56.023786999999999	56.006945000000002	0103000020E6100000010000000500000002BB9A3C6583584074EFE192E3004C4002BB9A3C65835840F488D1730B034C40E1CFF0660D855840F488D1730B034C40E1CFF0660D85584074EFE192E3004C4002BB9A3C6583584074EFE192E3004C40
52187	Соляная	5	50	139	97.805424000000002	97.836515000000006	55.542655000000003	55.519981999999999	0103000020E6100000010000000500000077DA1A118C7358401C412AC58EC24B4077DA1A118C735840650113B875C54B4043E7357689755840650113B875C54B4043E73576897558401C412AC58EC24B4077DA1A118C7358401C412AC58EC24B40
52191	Сереброво	5	50	139	97.861002999999997	97.866815000000003	55.419274000000001	55.397903999999997	0103000020E6100000010000000500000081B053AC1A7758404A79AD84EEB24B4081B053AC1A77584014083BC5AAB54B40AA2B9FE57977584014083BC5AAB54B40AA2B9FE5797758404A79AD84EEB24B4081B053AC1A7758404A79AD84EEB24B40
52200	Сафроновка	5	50	139	97.804759000000004	97.831619000000003	55.887810999999999	55.882776999999997	0103000020E61000000100000005000000598AE42B817358409B5434D6FEF04B40598AE42B81735840B80375CAA3F14B40DDEEE53E39755840B80375CAA3F14B40DDEEE53E397558409B5434D6FEF04B40598AE42B817358409B5434D6FEF04B40
52197	Рождественка	5	50	139	97.624934999999994	97.647589999999994	55.802027000000002	55.781869	0103000020E610000001000000050000000CC85EEFFE675840CC608C4814E44B400CC85EEFFE67584027C11BD2A8E64B40DDCD531D7269584027C11BD2A8E64B40DDCD531D72695840CC608C4814E44B400CC85EEFFE675840CC608C4814E44B40
59211	Разгон	5	50	139	98.378000999999998	98.402741000000006	55.724642000000003	55.709104000000004	0103000020E61000000100000005000000BD361B2B319858403DBB7CEBC3DA4B40BD361B2B319858406EA7AD11C1DC4B4089F02F82C69958406EA7AD11C1DC4B4089F02F82C69958403DBB7CEBC3DA4B40BD361B2B319858403DBB7CEBC3DA4B40
52209	Половино-Черемхово	5	50	139	97.606078999999994	97.641311000000002	56.078080999999997	56.063961999999997	0103000020E61000000100000005000000B6F292FFC9665840E71725E82F084C40B6F292FFC966584030B8E68EFE094C402AE44A3D0B69584030B8E68EFE094C402AE44A3D0B695840E71725E82F084C40B6F292FFC9665840E71725E82F084C40
59288	Полинчет	5	50	139	98.098517000000001	98.124262999999999	57.353583999999998	57.341594000000001	0103000020E6100000010000000500000067463F1A4E8658404241295AB9AB4C4067463F1A4E865840C631923D42AD4C409546CCECF3875840C631923D42AD4C409546CCECF38758404241295AB9AB4C4067463F1A4E8658404241295AB9AB4C40
430	Покровка	5	50	139	97.543402999999998	97.568691000000001	55.850161	55.840583000000002	0103000020E610000001000000050000001763601DC76258406B49473998EB4B401763601DC7625840D6AA5D13D2EC4B40E4A1EF6E65645840D6AA5D13D2EC4B40E4A1EF6E656458406B49473998EB4B401763601DC76258406B49473998EB4B40
52139	Пея	5	50	139	97.824882000000002	97.849458999999996	56.899920999999999	56.890726999999998	0103000020E61000000100000005000000C843DFDDCA7458400455A35703724C40C843DFDDCA745840E7FD7F9C30734C40BE1248895D765840E7FD7F9C30734C40BE1248895D7658400455A35703724C40C843DFDDCA7458400455A35703724C40
52212	Парижская Коммуна	5	50	139	98.113906	98.138349000000005	55.947011000000003	55.936776000000002	0103000020E610000001000000050000005D34643C4A875840BFD6A546E8F74B405D34643C4A875840E4F90CA837F94B40CC9BC3B5DA885840E4F90CA837F94B40CC9BC3B5DA885840BFD6A546E8F74B405D34643C4A875840BFD6A546E8F74B40
59291	Облепиха	5	50	139	98.441997000000001	98.462766000000002	55.672061999999997	55.661068999999998	0103000020E6100000010000000500000087FBC8AD499C584020B3B3E89DD44B4087FBC8AD499C58403271AB2006D64B40D9EC48F59D9D58403271AB2006D64B40D9EC48F59D9D584020B3B3E89DD44B4087FBC8AD499C584020B3B3E89DD44B40
59253	Новый Акульшет	5	50	139	98.064327000000006	98.086209999999994	55.914881999999999	55.905225000000002	0103000020E61000000100000005000000FD4FFEEE1D845840C442AD69DEF34B40FD4FFEEE1D8458407BD976DA1AF54B40A4A5F276848558407BD976DA1AF54B40A4A5F27684855840C442AD69DEF34B40FD4FFEEE1D845840C442AD69DEF34B40
52131	Новотремино	5	50	139	98.057967000000005	98.074218000000002	56.729477000000003	56.719906000000002	0103000020E61000000100000005000000D34F38BBB5835840DB183BE1255C4C40D34F38BBB5835840941799805F5D4C4092B1DAFCBF845840941799805F5D4C4092B1DAFCBF845840DB183BE1255C4C40D34F38BBB5835840DB183BE1255C4C40
4491	Новобирюсинский	5	50	139	97.686774999999997	97.742147000000003	56.969509000000002	56.944527000000001	0103000020E61000000100000005000000772D211FF46B58403198BF42E6784C40772D211FF46B5840BE16F4DE187C4C40C57421567F6F5840BE16F4DE187C4C40C57421567F6F58403198BF42E6784C40772D211FF46B58403198BF42E6784C40
6043	Николаевка	5	50	139	98.158462	98.196667000000005	55.797974000000004	55.783003000000001	0103000020E6100000010000000500000029EACC3D248A5840BFD53A7139E44B4029EACC3D248A58407787140324E64B40F54C2F31968C58407787140324E64B40F54C2F31968C5840BFD53A7139E44B4029EACC3D248A5840BFD53A7139E44B40
52147	Нижняя Заимка	5	50	139	98.224909999999994	98.239382000000006	56.155206999999997	56.130999000000003	0103000020E61000000100000005000000C6A2E9EC648E584084674293C4104C40C6A2E9EC648E58401D8EAED2DD134C401250E108528F58401D8EAED2DD134C401250E108528F584084674293C4104C40C6A2E9EC648E584084674293C4104C40
59336	Невельская	5	50	139	98.518874999999994	98.549048999999997	56.127803	56.109270000000002	0103000020E6100000010000000500000091ED7C3F35A158408B37328FFC0D4C4091ED7C3F35A1584054AA44D95B104C40B2B96A9E23A3584054AA44D95B104C40B2B96A9E23A358408B37328FFC0D4C4091ED7C3F35A158408B37328FFC0D4C40
52137	Мирный	5	50	139	97.695532999999998	97.718207000000007	56.886783999999999	56.871949999999998	0103000020E610000001000000050000007B12D89C836C5840A4DFBE0E9C6F4C407B12D89C836C5840DB4E5B2382714C4088307E1AF76D5840DB4E5B2382714C4088307E1AF76D5840A4DFBE0E9C6F4C407B12D89C836C5840A4DFBE0E9C6F4C40
52210	Конторка	5	50	139	97.846898999999993	97.877917999999994	56.032558999999999	56.025602999999997	0103000020E61000000100000005000000F700DD9733765840F9D687F546034C40F700DD97337658406118B0E42A044C4076A4FACE2F7858406118B0E42A044C4076A4FACE2F785840F9D687F546034C40F700DD9733765840F9D687F546034C40
52149	Коновалова	5	50	139	98.159961999999993	98.176670999999999	56.106268	56.097014999999999	0103000020E6100000010000000500000093A641D13C8A5840581CCEFC6A0C4C4093A641D13C8A5840404E98309A0D4C40B4C9E1934E8B5840404E98309A0D4C40B4C9E1934E8B5840581CCEFC6A0C4C4093A641D13C8A5840581CCEFC6A0C4C40
59305	Кондратьево	5	50	139	98.173822999999999	98.196190999999999	57.357326999999998	57.34545	0103000020E61000000100000005000000BA1281EA1F8B58409C33A2B437AC4C40BA1281EA1F8B5840287D21E4BCAD4C404031B2648E8C5840287D21E4BCAD4C404031B2648E8C58409C33A2B437AC4C40BA1281EA1F8B58409C33A2B437AC4C40
5525	Квиток	5	50	139	98.450873000000001	98.493020999999999	56.084310000000002	56.058478000000001	0103000020E6100000010000000500000090696D1ADB9C58408BC404357C074C4090696D1ADB9C5840E65C8AABCA0A4C4070CFF3A78D9F5840E65C8AABCA0A4C4070CFF3A78D9F58408BC404357C074C4090696D1ADB9C58408BC404357C074C40
52145	Иванов Мыс	5	50	139	98.399866000000003	98.412891999999999	56.516674999999999	56.505704000000001	0103000020E6100000010000000500000012329067979958406BBA9EE8BA404C40123290679799584095D4096822424C40EC3191D26C9A584095D4096822424C40EC3191D26C9A58406BBA9EE8BA404C4012329067979958406BBA9EE8BA404C40
52195	Заречное	5	50	139	97.643834999999996	97.684134	55.974739999999997	55.962522999999997	0103000020E610000001000000050000004A41B79734695840EB5223F433FB4B404A41B79734695840300DC347C4FC4B403A05F9D9C86B5840300DC347C4FC4B403A05F9D9C86B5840EB5223F433FB4B404A41B79734695840EB5223F433FB4B40
52124	Джогино	5	50	139	98.150915999999995	98.173365000000004	56.659063000000003	56.641396999999998	0103000020E610000001000000050000005C1C959BA88958405260014C19524C405C1C959BA88958407880272D5C544C4059518369188B58407880272D5C544C4059518369188B58405260014C19524C405C1C959BA88958405260014C19524C40
59326	Горевая	5	50	139	97.746863000000005	97.778906000000006	57.188640999999997	57.172151999999997	0103000020E61000000100000005000000EBE5779ACC6F584072F8A41309964C40EBE5779ACC6F5840A5D7666325984C40202A8D98D9715840A5D7666325984C40202A8D98D971584072F8A41309964C40EBE5779ACC6F584072F8A41309964C40
52143	Бузыканово	5	50	139	98.371093000000002	98.386868000000007	56.583886999999997	56.567022999999999	0103000020E6100000010000000500000092B1DAFCBF975840378AAC3594484C4092B1DAFCBF9758409FC728CFBC4A4C409DF7FF71C29858409FC728CFBC4A4C409DF7FF71C2985840378AAC3594484C4092B1DAFCBF975840378AAC3594484C40
52157	Борисово	5	50	139	98.285034999999993	98.309550000000002	56.172539999999998	56.158284999999999	0103000020E61000000100000005000000C8CD70033E9258404339D1AE42144C40C8CD70033E9258403CA06CCA15164C40849ECDAACF9358403CA06CCA15164C40849ECDAACF9358404339D1AE42144C40C8CD70033E9258404339D1AE42144C40
52216	Бирюсинск	5	50	139	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
52155	Бирюса	5	50	139	97.886325999999997	97.902703000000002	56.001458999999997	55.981147	0103000020E610000001000000050000000CE6AF90B9785840C5C8923996FD4B400CE6AF90B978584076A4FACE2F004C4012C0CDE2C579584076A4FACE2F004C4012C0CDE2C5795840C5C8923996FD4B400CE6AF90B9785840C5C8923996FD4B40
52174	Березовка	5	50	139	98.013661999999997	98.041465000000002	55.912954999999997	55.857826000000003	0103000020E61000000100000005000000ABCC94D6DF8058404AD40B3ECDED4B40ABCC94D6DF8058401EDC9DB5DBF44B406FBBD05CA78258401EDC9DB5DBF44B406FBBD05CA78258404AD40B3ECDED4B40ABCC94D6DF8058404AD40B3ECDED4B40
59216	Акульшет	5	50	139	98.101877000000002	98.116806999999994	55.964171	55.953946000000002	0103000020E61000000100000005000000BCCD1B278586584034130CE71AFA4B40BCCD1B2785865840356090F469FB4B40683C11C479875840356090F469FB4B40683C11C47987584034130CE71AFA4B40BCCD1B278586584034130CE71AFA4B40
3797	Утулик	5	50	235	104.04590399999999	104.07311300000001	51.551704999999998	51.532418999999997	0103000020E610000001000000050000005BB05417F0025A406F62484E26C449405BB05417F0025A401405FA449EC6494066FA25E2AD045A401405FA449EC6494066FA25E2AD045A406F62484E26C449405BB05417F0025A406F62484E26C44940
4079	Тибельти	5	50	235	103.237869	103.277242	51.777042999999999	51.747489000000002	0103000020E61000000100000005000000DDEEE53E39CF5940548F34B8ADDF4940DDEEE53E39CF5940F94A202576E34940F8C43A55BED15940F94A202576E34940F8C43A55BED15940548F34B8ADDF4940DDEEE53E39CF5940548F34B8ADDF4940
3565	Солзан	5	50	235	104.214427	104.242203	51.500568000000001	51.492919999999998	0103000020E610000001000000050000004818062CB90D5A40ACC5A70018BF49404818062CB90D5A404AB6BA9C12C049408FFF0241800F5A404AB6BA9C12C049408FFF0241800F5A40ACC5A70018BF49404818062CB90D5A40ACC5A70018BF4940
919	Слюдянка	5	50	235	103.652343	103.738527	51.690190999999999	51.633105999999998	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
59263	Новоснежная	5	50	235	104.618346	104.63246700000001	51.476778000000003	51.458649999999999	0103000020E6100000010000000500000032E719FB92275A40BB270F0BB5BA494032E719FB92275A40E5B9BE0F07BD49402733DE567A285A40E5B9BE0F07BD49402733DE567A285A40BB270F0BB5BA494032E719FB92275A40BB270F0BB5BA4940
3857	Мурино	5	50	235	104.398762	104.414788	51.485292000000001	51.470523	0103000020E61000000100000005000000CE380D5185195A40068200193ABC4940CE380D5185195A4056815A0C1EBE49407DB1F7E28B1A5A4056815A0C1EBE49407DB1F7E28B1A5A40068200193ABC4940CE380D5185195A40068200193ABC4940
4186	Маритуй	5	50	235	104.20468099999999	104.23271699999999	51.793418000000003	51.784989000000003	0103000020E610000001000000050000003447567E190D5A40215C01857AE449403447567E190D5A40640795B88EE54940490ED8D5E40E5A40640795B88EE54940490ED8D5E40E5A40215C01857AE449403447567E190D5A40215C01857AE44940
3599	Култук	5	50	235	103.64474300000001	103.73099000000001	51.742977000000003	51.703069999999997	0103000020E61000000100000005000000CCD4247843E959403C66A032FED94940CCD4247843E959401157CEDE19DF4940FFEC478AC8EE59401157CEDE19DF4940FFEC478AC8EE59403C66A032FED94940CCD4247843E959403C66A032FED94940
3971	Быстрая	5	50	235	103.422787	103.477998	51.748927000000002	51.735776999999999	0103000020E61000000100000005000000228B34F10EDB59401213D4F02DDE4940228B34F10EDB5940B30B06D7DCDF49406B63EC8497DE5940B30B06D7DCDF49406B63EC8497DE59401213D4F02DDE4940228B34F10EDB59401213D4F02DDE4940
3244	Байкальск	5	50	235	104.117661	104.159774	51.527970000000003	51.499721000000001	0103000020E61000000100000005000000F0C000C287075A40ED0F94DBF6BF4940F0C000C287075A4073A25D8594C349401230BABC390A5A4073A25D8594C349401230BABC390A5A40ED0F94DBF6BF4940F0C000C287075A40ED0F94DBF6BF4940
59312	Байкал	5	50	235	104.77565	104.81168099999999	51.881911000000002	51.870128999999999	0103000020E610000001000000050000001DC9E53FA4315A408D26176360EF49401DC9E53FA4315A40C87DAB75E2F049403672DD94F2335A40C87DAB75E2F049403672DD94F2335A408D26176360EF49401DC9E53FA4315A408D26176360EF4940
59255	Андрияновская	5	50	235	103.80945800000001	103.816339	51.808511000000003	51.796582000000001	0103000020E61000000100000005000000145FED28CEF35940884A2366F6E54940145FED28CEF3594067BAD7497DE74940C2DCEEE53EF4594067BAD7497DE74940C2DCEEE53EF45940884A2366F6E54940145FED28CEF35940884A2366F6E54940
59259	Ангасолка	5	50	235	103.747348	103.76419199999999	51.754162999999998	51.741788999999997	0103000020E61000000100000005000000C9AEB48CD4EF59402AC423F1F2DE4940C9AEB48CD4EF5940376DC66988E0494059F78F85E8F05940376DC66988E0494059F78F85E8F059402AC423F1F2DE4940C9AEB48CD4EF59402AC423F1F2DE4940
31692	Шотой	5	50	7	104.24223000000001	104.256882	53.437989999999999	53.413029999999999	0103000020E610000001000000050000000C0742B2800F5A402922C32ADEB44A400C0742B2800F5A40CEFC6A0E10B84A40973B33C170105A40CEFC6A0E10B84A40973B33C170105A402922C32ADEB44A400C0742B2800F5A402922C32ADEB44A40
31997	Хокта	5	50	7	103.962001	103.987154	53.474604999999997	53.456535000000002	0103000020E61000000100000005000000096EA46C91FD59405C3D27BD6FBA4A40096EA46C91FD594050C24CDBBFBC4A406687F8872DFF594050C24CDBBFBC4A406687F8872DFF59405C3D27BD6FBA4A40096EA46C91FD59405C3D27BD6FBA4A40
32264	Харай	5	50	7	103.872663	103.88857299999999	53.411479	53.395206999999999	0103000020E61000000100000005000000795BE9B5D9F759403C139A2496B24A40795BE9B5D9F75940D2FE0758ABB44A40F3C64961DEF85940D2FE0758ABB44A40F3C64961DEF859403C139A2496B24A40795BE9B5D9F759403C139A2496B24A40
464	Хайга	5	50	7	103.704589	103.73430500000001	53.710397999999998	53.693325000000002	0103000020E61000000100000005000000C40776FC17ED5940E63FA4DFBED84A40C40776FC17ED594068925852EEDA4A40841266DAFEEE594068925852EEDA4A40841266DAFEEE5940E63FA4DFBED84A40C40776FC17ED5940E63FA4DFBED84A40
32375	Усть-Алтан	5	50	7	103.610715	103.62948900000001	53.532440999999999	53.516398000000002	0103000020E610000001000000050000004E0B5EF415E7594023DC645419C24A404E0B5EF415E759405706D50627C44A40460C3B8C49E859405706D50627C44A40460C3B8C49E8594023DC645419C24A404E0B5EF415E7594023DC645419C24A40
709	Унгин	5	50	7	103.571243	103.59715	53.708736000000002	53.688723000000003	0103000020E6100000010000000500000069C4CC3E8FE459406380441328D84A4069C4CC3E8FE45940BABF7ADCB7DA4A409C33A2B437E65940BABF7ADCB7DA4A409C33A2B437E659406380441328D84A4069C4CC3E8FE459406380441328D84A40
31907	Русские Янгуты	5	50	7	103.978323	104.013205	53.358991000000003	53.337446	0103000020E610000001000000050000002D7B12D89CFE59404015376E31AB4A402D7B12D89CFE59407847C66AF3AD4A4032C9C859D8005A407847C66AF3AD4A4032C9C859D8005A404015376E31AB4A402D7B12D89CFE59404015376E31AB4A40
32431	Рассвет	5	50	7	103.430593	103.448497	53.568488000000002	53.552956000000002	0103000020E61000000100000005000000BD38F1D58EDB594041102043C7C64A40BD38F1D58EDB59409015FC36C4C84A40AAD6C22CB4DC59409015FC36C4C84A40AAD6C22CB4DC594041102043C7C64A40BD38F1D58EDB594041102043C7C64A40
31809	Прохоровка	5	50	7	104.030884	104.043577	53.361350000000002	53.340791000000003	0103000020E610000001000000050000000F7EE200FA015A40B5E21B0A9FAB4A400F7EE200FA015A406E3480B740AE4A40E6762FF7C9025A406E3480B740AE4A40E6762FF7C9025A40B5E21B0A9FAB4A400F7EE200FA015A40B5E21B0A9FAB4A40
335	Приморский	5	50	7	103.71491899999999	103.732275	53.591326000000002	53.575657999999997	0103000020E610000001000000050000007F129F3BC1ED594023D74D29AFC94A407F129F3BC1ED594023A30392B0CB4A406B2BF697DDEE594023A30392B0CB4A406B2BF697DDEE594023D74D29AFC94A407F129F3BC1ED594023D74D29AFC94A40
1070	Оса	5	50	7	103.855164	103.89228300000001	53.401826999999997	53.375878	0103000020E61000000100000005000000DC2DC901BBF6594098A432C51CB04A40DC2DC901BBF659402CD32F116FB34A40B7F1272A1BF959402CD32F116FB34A40B7F1272A1BF9594098A432C51CB04A40DC2DC901BBF6594098A432C51CB04A40
31729	Онгосор	5	50	7	104.234622	104.26589199999999	53.395603999999999	53.384757	0103000020E61000000100000005000000043BFE0B040F5A401BF4A5B73FB14A40043BFE0B040F5A405915E126A3B24A402711E15F04115A405915E126A3B24A402711E15F04115A401BF4A5B73FB14A40043BFE0B040F5A401BF4A5B73FB14A40
31942	Онгой	5	50	7	104.01872899999999	104.045086	53.518667999999998	53.497065999999997	0103000020E61000000100000005000000279F1EDB32015A400DFAD2DB9FBF4A40279F1EDB32015A40A9BD88B663C24A407AE063B0E2025A40A9BD88B663C24A407AE063B0E2025A400DFAD2DB9FBF4A40279F1EDB32015A400DFAD2DB9FBF4A40
547	Обуса	5	50	7	103.82567299999999	103.855524	53.728982999999999	53.713217	0103000020E610000001000000050000002C0C91D3D7F45940C2F9D4B14ADB4A402C0C91D3D7F45940842BA0504FDD4A405C3CBCE7C0F65940842BA0504FDD4A405C3CBCE7C0F65940C2F9D4B14ADB4A402C0C91D3D7F45940C2F9D4B14ADB4A40
32029	Мольта (Каха)	5	50	7	103.93163800000001	103.964669	53.442174000000001	53.428334	0103000020E610000001000000050000007F6DFDF49FFB5940E7E104A6D3B64A407F6DFDF49FFB59401D925A2899B84A40C39D0B23BDFD59401D925A2899B84A40C39D0B23BDFD5940E7E104A6D3B64A407F6DFDF49FFB5940E7E104A6D3B64A40
59217	Майск	5	50	7	103.34820000000001	104.755797	54.064895	53.229899000000003	0103000020E61000000100000005000000E71DA7E848D659400A3197546D9D4A40E71DA7E848D659404356B77A4E084B408E5A61FA5E305A404356B77A4E084B408E5A61FA5E305A400A3197546D9D4A40E71DA7E848D659400A3197546D9D4A40
32086	Лузгина	5	50	7	103.894295	103.927083	53.376130000000003	53.361834000000002	0103000020E610000001000000050000007C7E18213CF959405A4A969350AE4A407C7E18213CF95940B285200725B04A405D6BEF5355FB5940B285200725B04A405D6BEF5355FB59405A4A969350AE4A407C7E18213CF959405A4A969350AE4A40
300	Кутанка	5	50	7	103.825187	103.85586499999999	53.640605000000001	53.626077000000002	0103000020E61000000100000005000000668522DDCFF459408FE3874A23D04A40668522DDCFF45940B9533A58FFD14A40A032FE7DC6F65940B9533A58FFD14A40A032FE7DC6F659408FE3874A23D04A40668522DDCFF459408FE3874A23D04A40
32480	Ирхидей	5	50	7	103.791932	103.809494	53.443514999999998	53.426934000000003	0103000020E61000000100000005000000FA298E03AFF2594076C6F7C5A5B64A40FA298E03AFF2594089247A19C5B84A40BA13ECBFCEF3594089247A19C5B84A40BA13ECBFCEF3594076C6F7C5A5B64A40FA298E03AFF2594076C6F7C5A5B64A40
10	Жданово	5	50	7	103.693899	103.712242	53.547942999999997	53.540452000000002	0103000020E6100000010000000500000089EE59D768EC59406687F8872DC54A4089EE59D768EC59403B8908FF22C64A409C35785F95ED59403B8908FF22C64A409C35785F95ED59406687F8872DC54A4089EE59D768EC59406687F8872DC54A40
59184	Енисей (Бурятский Янгут)	5	50	7	104.131342	104.165954	53.370055000000001	53.350783999999997	0103000020E61000000100000005000000D7A546E867085A40E3FA777DE6AC4A40D7A546E867085A40535C55F65DAF4A40FCA886FD9E0A5A40535C55F65DAF4A40FCA886FD9E0A5A40E3FA777DE6AC4A40D7A546E867085A40E3FA777DE6AC4A40
31858	Грязнушка	5	50	7	104.039427	104.082357	53.331902999999997	53.313513	0103000020E6100000010000000500000015E5D2F885025A4078EFA83121A84A4015E5D2F885025A40DE3829CC7BAA4A4030664B5645055A40DE3829CC7BAA4A4030664B5645055A4078EFA83121A84A4015E5D2F885025A4078EFA83121A84A40
592	Горхон	5	50	7	103.92396599999999	103.946765	53.725957000000001	53.717022	0103000020E610000001000000050000006B274A4222FB59409A417C60C7DB4A406B274A4222FB5940B1A6B228ECDC4A40D6FF39CC97FC5940B1A6B228ECDC4A40D6FF39CC97FC59409A417C60C7DB4A406B274A4222FB59409A417C60C7DB4A40
673	Борохал	5	50	7	103.989355	104.00923400000001	53.723927000000003	53.717458999999998	0103000020E610000001000000050000009548A29751FF5940459C4EB2D5DB4A409548A29751FF594080D8D2A3A9DC4A40B900344A97005A4080D8D2A3A9DC4A40B900344A97005A40459C4EB2D5DB4A409548A29751FF5940459C4EB2D5DB4A40
157	Бильчир	5	50	7	103.699001	103.737188	53.572263	53.557636000000002	0103000020E61000000100000005000000C3B7B06EBCEC59404089CF9D60C74A40C3B7B06EBCEC5940FDDAFAE93FC94A403CC093162EEF5940FDDAFAE93FC94A403CC093162EEF59404089CF9D60C74A40C3B7B06EBCEC59404089CF9D60C74A40
32342	Абрамовка (Пахаленская)	5	50	7	103.774747	103.79238100000001	53.398739999999997	53.381239000000001	0103000020E6100000010000000500000025EB707495F15940D97A8670CCB04A4025EB707495F15940B3CD8DE909B34A40323ECC5EB6F25940B3CD8DE909B34A40323ECC5EB6F25940D97A8670CCB04A4025EB707495F15940D97A8670CCB04A40
31646	Ялга	5	50	516	107.180108	107.18780599999999	53.140320000000003	53.136031000000003	0103000020E61000000100000005000000DF6FB4E386CB5A40001FBC7669914A40DF6FB4E386CB5A40C47C7901F6914A4086FF740305CC5A40C47C7901F6914A4086FF740305CC5A40001FBC7669914A40DF6FB4E386CB5A40001FBC7669914A40
31389	Шара-Тогот	5	50	516	106.705061	106.723341	53.008592	52.996540000000003	0103000020E61000000100000005000000D82B2CB81FAD5A40F3936A9F8E7F4A40D82B2CB81FAD5A40ED80EB8A19814A40C8B60C384BAE5A40ED80EB8A19814A40C8B60C384BAE5A40F3936A9F8E7F4A40D82B2CB81FAD5A40F3936A9F8E7F4A40
31295	Хурай-Нур	5	50	516	106.458904	106.480024	52.811957999999997	52.805126000000001	0103000020E610000001000000050000003B00E2AE5E9D5A406494675E0E674A403B00E2AE5E9D5A40DFDC5F3DEE674A40E35295B6B89E5A40DFDC5F3DEE674A40E35295B6B89E5A406494675E0E674A403B00E2AE5E9D5A406494675E0E674A40
31585	Хужир	5	50	516	107.323272	107.363292	53.200172000000002	53.186976000000001	0103000020E610000001000000050000009AED0A7DB0D45A4086915ED4EE974A409AED0A7DB0D45A4097C9703C9F994A4080B9162D40D75A4097C9703C9F994A4080B9162D40D75A4086915ED4EE974A409AED0A7DB0D45A4086915ED4EE974A40
31537	Харанцы	5	50	516	107.41257400000001	107.427162	53.226793999999998	53.215327000000002	0103000020E61000000100000005000000844BC79C67DA5A401079CBD58F9B4A40844BC79C67DA5A40EA76F695079D4A400306499F56DB5A40EA76F695079D4A400306499F56DB5A401079CBD58F9B4A40844BC79C67DA5A401079CBD58F9B4A40
30426	Тонта	5	50	516	106.49824099999999	106.506434	52.883414999999999	52.875034999999997	0103000020E61000000100000005000000AF21382EE39F5A407CED992501704A40AF21382EE39F5A40DEE522BE13714A4047E5266A69A05A40DEE522BE13714A4047E5266A69A05A407CED992501704A40AF21382EE39F5A407CED992501704A40
31134	Таловка	5	50	516	106.214068	106.22976199999999	52.683954	52.667955999999997	0103000020E61000000100000005000000B0C7444AB38D5A405F950B957F554A40B0C7444AB38D5A40F4FBFECD8B574A4044F7AC6BB48E5A40F4FBFECD8B574A4044F7AC6BB48E5A405F950B957F554A40B0C7444AB38D5A405F950B957F554A40
31439	Сахюрта	5	50	516	106.88043	106.893249	53.018695999999998	53.014204999999997	0103000020E61000000100000005000000B51A12F758B85A4047382D78D1814A40B51A12F758B85A4073486AA164824A40D28BDAFD2AB95A4073486AA164824A40D28BDAFD2AB95A4047382D78D1814A40B51A12F758B85A4047382D78D1814A40
31181	Нарин-Кунта	5	50	516	106.354511	106.382943	52.763100000000001	52.754620000000003	0103000020E61000000100000005000000A0C4E74EB0965A402A745E6397604A40A0C4E74EB0965A40EFC9C342AD614A40DB4E5B2382985A40EFC9C342AD614A40DB4E5B2382985A402A745E6397604A40A0C4E74EB0965A402A745E6397604A40
30908	Куртун	5	50	516	105.804886	105.829616	52.623857000000001	52.610706999999998	0103000020E6100000010000000500000087C0914083735A401938A0A52B4E4A4087C0914083735A40BA30D28BDA4F4A40410FB56D18755A40BA30D28BDA4F4A40410FB56D18755A401938A0A52B4E4A4087C0914083735A401938A0A52B4E4A40
31106	Куреть	5	50	516	106.191152	106.22747099999999	52.824365999999998	52.809857000000001	0103000020E61000000100000005000000292499D53B8C5A40E5B7E864A9674A40292499D53B8C5A4098F738D384694A40757286E28E8E5A4098F738D384694A40757286E28E8E5A40E5B7E864A9674A40292499D53B8C5A40E5B7E864A9674A40
31049	Косая Степь	5	50	516	106.071236	106.09134	52.851163	52.837826	0103000020E61000000100000005000000109370218F845A4087DEE2E13D6B4A40109370218F845A405A48C0E8F26C4A404434BA83D8855A405A48C0E8F26C4A404434BA83D8855A4087DEE2E13D6B4A40109370218F845A4087DEE2E13D6B4A40
31228	Еланцы	5	50	516	106.38228700000001	106.424463	52.811773000000002	52.788322999999998	0103000020E61000000100000005000000E7ABE46377985A40A1D79FC4E7644A40E7ABE46377985A404E637B2DE8674A402CD7DB662A9B5A404E637B2DE8674A402CD7DB662A9B5A40A1D79FC4E7644A40E7ABE46377985A40A1D79FC4E7644A40
30940	Бугульдейка	5	50	516	106.057564	106.078728	52.554861000000002	52.534717999999998	0103000020E61000000100000005000000535BEA20AF835A40904AB1A371444A40535BEA20AF835A40B6696CAF05474A40E3512AE109855A40B6696CAF05474A40E3512AE109855A40904AB1A371444A40535BEA20AF835A40904AB1A371444A40
30999	Алагуй	5	50	516	105.984504	106.004321	52.782832999999997	52.769851000000003	0103000020E61000000100000005000000FFB1101D027F5A407EE5417A8A624A40FFB1101D027F5A40629D2ADF33644A40E86B96CB46805A40629D2ADF33644A40E86B96CB46805A407EE5417A8A624A40FFB1101D027F5A407EE5417A8A624A40
29574	Шараты	5	50	155	102.560934	102.57737400000001	53.834271999999999	53.817525000000003	0103000020E61000000100000005000000BA4DB857E6A35940CA54C1A8A4E84A40BA4DB857E6A35940F8FBC56CC9EA4A40E3E313B2F3A45940F8FBC56CC9EA4A40E3E313B2F3A45940CA54C1A8A4E84A40BA4DB857E6A35940CA54C1A8A4E84A40
30541	Шалоты	5	50	155	102.98008799999999	102.999797	53.595275000000001	53.574860999999999	0103000020E61000000100000005000000EECC04C3B9BE5940785F950B95C94A40EECC04C3B9BE59402E90A0F831CC4A40E4688EACFCBF59402E90A0F831CC4A40E4688EACFCBF5940785F950B95C94A40EECC04C3B9BE5940785F950B95C94A40
29382	Целинный	5	50	155	102.58049099999999	102.598754	53.646909000000001	53.635554999999997	0103000020E61000000100000005000000D427B9C326A5594096E7C1DD59D14A40D427B9C326A55940793E03EACDD24A4059164CFC51A65940793E03EACDD24A4059164CFC51A6594096E7C1DD59D14A40D427B9C326A5594096E7C1DD59D14A40
29780	Харёты	5	50	155	102.714466	102.737247	53.825817000000001	53.805695999999998	0103000020E61000000100000005000000A7069ACFB9AD59404E42E90B21E74A40A7069ACFB9AD59408CBD175FB4E94A40BE840A0E2FAF59408CBD175FB4E94A40BE840A0E2FAF59404E42E90B21E74A40A7069ACFB9AD59404E42E90B21E74A40
30337	Хамхар	5	50	155	102.92556999999999	102.938676	53.735753000000003	53.729004000000003	0103000020E61000000100000005000000280AF4893CBB59409C53C90050DD4A40280AF4893CBB59408A7780272DDE4A409162804413BC59408A7780272DDE4A409162804413BC59409C53C90050DD4A40280AF4893CBB59409C53C90050DD4A40
30078	Хадахан	5	50	155	103.286216	103.30680599999999	53.559637000000002	53.547685999999999	0103000020E61000000100000005000000E2E5E95C51D25940103D29931AC64A40E2E5E95C51D25940D7506A2FA2C74A40DC0DA2B5A2D35940D7506A2FA2C74A40DC0DA2B5A2D35940103D29931AC64A40E2E5E95C51D25940103D29931AC64A40
29441	Ункурлик	5	50	155	102.583518	102.59972399999999	53.654445000000003	53.644117999999999	0103000020E6100000010000000500000026A8E15B58A55940E961687572D24A4026A8E15B58A55940EF0390DAC4D34A4015A8C5E061A65940EF0390DAC4D34A4015A8C5E061A65940E961687572D24A4026A8E15B58A55940E961687572D24A40
29658	Тангуты	5	50	155	102.584632	102.60073	53.780670999999998	53.761066	0103000020E610000001000000050000007C0C569C6AA559407C0C569C6AE14A407C0C569C6AA55940C2F7FE06EDE34A4078EE3D5C72A65940C2F7FE06EDE34A4078EE3D5C72A659407C0C569C6AE14A407C0C569C6AA559407C0C569C6AE14A40
26776	Степное	5	50	155	103.021141	103.032685	53.790007000000003	53.782947999999998	0103000020E61000000100000005000000B4E6C75F5AC15940FB3BDBA337E44A40B4E6C75F5AC15940384E0AF31EE54A407784D38217C25940384E0AF31EE54A407784D38217C25940FB3BDBA337E44A40B4E6C75F5AC15940FB3BDBA337E44A40
22824	Первомайское	5	50	155	103.22752	103.249134	53.767698000000003	53.752485	0103000020E61000000100000005000000E6CB0BB08FCE594083DDB06D51E04A40E6CB0BB08FCE5940319A95ED43E24A409694BBCFF1CF5940319A95ED43E24A409694BBCFF1CF594083DDB06D51E04A40E6CB0BB08FCE594083DDB06D51E04A40
30283	Нукуты	5	50	155	102.79473	102.813029	53.727758000000001	53.713324	0103000020E610000001000000050000009BC937DBDCB25940D8B969334EDB4A409BC937DBDCB2594081B3942C27DD4A40C66CC9AA08B4594081B3942C27DD4A40C66CC9AA08B45940D8B969334EDB4A409BC937DBDCB25940D8B969334EDB4A40
30634	Новонукутский	5	50	155	102.67395999999999	102.72883899999999	53.710537000000002	53.688510000000001	0103000020E61000000100000005000000FAB31F2922AB5940077C7E1821D84A40FAB31F2922AB59408ACC5CE0F2DA4A402843554CA5AE59408ACC5CE0F2DA4A402843554CA5AE5940077C7E1821D84A40FAB31F2922AB5940077C7E1821D84A40
424	Новоленино	5	50	155	102.819047	102.849096	53.820597999999997	53.798470000000002	0103000020E61000000100000005000000C3B81B446BB45940276BD44334E64A40C3B81B446BB45940DD94F25A09E94A4086CABF9657B65940DD94F25A09E94A4086CABF9657B65940276BD44334E64A40C3B81B446BB45940276BD44334E64A40
29531	Наймодай	5	50	155	102.625703	102.637794	53.664178	53.657758999999999	0103000020E61000000100000005000000958098840BA8594028D3687231D44A40958098840BA85940815CE2C803D54A4071E5EC9DD1A85940815CE2C803D54A4071E5EC9DD1A8594028D3687231D44A40958098840BA8594028D3687231D44A40
30136	Мельхитуй (Русский Мельхитуй)	5	50	155	103.258368	103.274376	53.665126999999998	53.652700000000003	0103000020E610000001000000050000004F95EF1989D05940B30C71AC8BD34A404F95EF1989D05940E257ACE122D54A40ABB35A608FD15940E257ACE122D54A40ABB35A608FD15940B30C71AC8BD34A404F95EF1989D05940B30C71AC8BD34A40
59275	Макарьевская	5	50	155	102.817898	102.847371	53.570450000000001	53.562021999999999	0103000020E61000000100000005000000AF5DDA7058B45940F6D03E56F0C74A40AF5DDA7058B4594069006F8104C94A400B2593533BB6594069006F8104C94A400B2593533BB65940F6D03E56F0C74A40AF5DDA7058B45940F6D03E56F0C74A40
29624	Куйта	5	50	155	102.458787	102.482727	53.828459000000002	53.799757	0103000020E610000001000000050000001E3526C45C9D5940A0DFF76F5EE64A401E3526C45C9D5940D789CBF10AEA4A405B79C9FFE49E5940D789CBF10AEA4A405B79C9FFE49E5940A0DFF76F5EE64A401E3526C45C9D5940A0DFF76F5EE64A40
30590	Кирилловская (Вершина)	5	50	155	102.892476	102.914287	53.513271000000003	53.502651999999998	0103000020E61000000100000005000000C11DA8531EB959406EA296E656C04A40C11DA8531EB959401C7E37DDB2C14A401C0A9FAD83BA59401C7E37DDB2C14A401C0A9FAD83BA59406EA296E656C04A40C11DA8531EB959406EA296E656C04A40
29927	Зунгар	5	50	155	102.86539999999999	102.889628	54.032696999999999	54.024515000000001	0103000020E61000000100000005000000567DAEB662B7594077A1B94E23034B40567DAEB662B75940B2D6506A2F044B40C76647AAEFB85940B2D6506A2F044B40C76647AAEFB8594077A1B94E23034B40567DAEB662B7594077A1B94E23034B40
30007	Заходы	5	50	155	102.921976	102.93608	53.845615000000002	53.834957000000003	0103000020E610000001000000050000009AEC9FA701BB59407C48F8DEDFEA4A409AEC9FA701BB5940E700C11C3DEC4A40249C16BCE8BB5940E700C11C3DEC4A40249C16BCE8BB59407C48F8DEDFEA4A409AEC9FA701BB59407C48F8DEDFEA4A40
30849	Заречный	5	50	155	102.66880399999999	102.680024	53.685631000000001	53.679834	0103000020E61000000100000005000000C6DB4AAFCDAA5940BC5AEECC04D74A40C6DB4AAFCDAA5940D80FB1C1C2D74A40B01F628385AB5940D80FB1C1C2D74A40B01F628385AB5940BC5AEECC04D74A40C6DB4AAFCDAA5940BC5AEECC04D74A40
30190	Закулей	5	50	155	103.01032600000001	103.039242	53.699204999999999	53.681550999999999	0103000020E610000001000000050000001B13622EA9C059402EC72B103DD74A401B13622EA9C059408F19A88C7FD94A404CA8E0F082C259408F19A88C7FD94A404CA8E0F082C259402EC72B103DD74A401B13622EA9C059402EC72B103DD74A40
59194	Ей	5	50	155	102.33099300000001	103.377099	54.072498000000003	53.443396999999997	0103000020E610000001000000050000001E8D43FD2E9559407F129F3BC1B84A401E8D43FD2E95594041834D9D47094B40AD16D86322D8594041834D9D47094B40AD16D86322D859407F129F3BC1B84A401E8D43FD2E9559407F129F3BC1B84A40
30058	Дружный	5	50	155	103.039458	103.050408	53.878686000000002	53.867829999999998	0103000020E6100000010000000500000032E4D87A86C259406C3EAE0D15EF4A4032E4D87A86C25940FEB968C878F04A403CDD79E239C35940FEB968C878F04A403CDD79E239C359406C3EAE0D15EF4A4032E4D87A86C259406C3EAE0D15EF4A40
30382	Ворот-Онгой	5	50	155	102.82521	102.84045399999999	53.667085	53.655459	0103000020E6100000010000000500000042959A3DD0B45940376F9C14E6D34A4042959A3DD0B459407A53910A63D54A40B6F292FFC9B559407A53910A63D54A40B6F292FFC9B55940376F9C14E6D34A4042959A3DD0B45940376F9C14E6D34A40
29849	Васильевское	5	50	155	102.63421	102.651161	53.908113	53.887942000000002	0103000020E61000000100000005000000F4328AE596A85940575F5D15A8F14A40F4328AE596A859404609FA0B3DF44A4090DB2F9FACA959404609FA0B3DF44A4090DB2F9FACA95940575F5D15A8F14A40F4328AE596A85940575F5D15A8F14A40
29794	Большебаяновская	5	50	155	102.569019	102.59013899999999	53.907741999999999	53.895249	0103000020E610000001000000050000005EF3AACE6AA459406B63EC8497F24A405EF3AACE6AA45940529ACDE330F44A4006465ED6C4A55940529ACDE330F44A4006465ED6C4A559406B63EC8497F24A405EF3AACE6AA459406B63EC8497F24A40
30496	Алтарик	5	50	155	102.89455100000001	102.933511	53.487915999999998	53.472391999999999	0103000020E61000000100000005000000AA66D65240B959402E724F5777BC4A40AA66D65240B95940FA980F0874BE4A4033DDEBA4BEBB5940FA980F0874BE4A4033DDEBA4BEBB59402E724F5777BC4A40AA66D65240B959402E724F5777BC4A40
59214	станция Шеберта	5	50	282	99.777441999999994	99.909242000000006	54.663916999999998	54.587443	0103000020E610000001000000050000005B22179CC1F15840CFA10C55314B4B405B22179CC1F158401421753BFB544B4094895B0531FA58401421753BFB544B4094895B0531FA5840CFA10C55314B4B405B22179CC1F15840CFA10C55314B4B40
26992	Шумский	5	50	282	99.110245000000006	99.154352000000003	54.848359000000002	54.815404000000001	0103000020E610000001000000050000000B630B410EC75840888384285F684B400B630B410EC7584036221807976C4B409F0436E7E0C9584036221807976C4B409F0436E7E0C95840888384285F684B400B630B410EC75840888384285F684B40
27262	Шум	5	50	282	99.119291000000004	99.142781999999997	54.817743999999998	54.799750000000003	0103000020E6100000010000000500000042EDB776A2C75840EE7C3F355E664B4042EDB776A2C758400740DCD5AB684B40471D1D5723C958400740DCD5AB684B40471D1D5723C95840EE7C3F355E664B4042EDB776A2C75840EE7C3F355E664B40
28023	Шеберта	5	50	282	99.868162999999996	99.912315000000007	54.646957999999998	54.632244	0103000020E6100000010000000500000039268BFB8FF75840CE8B135FED504B4039268BFB8FF758405AF10D85CF524B409E29745E63FA58405AF10D85CF524B409E29745E63FA5840CE8B135FED504B4039268BFB8FF75840CE8B135FED504B40
27359	Швайкина	5	50	282	99.022919999999999	99.040563000000006	54.820483000000003	54.809479000000003	0103000020E61000000100000005000000289B728577C158403FE603029D674B40289B728577C1584045F6419605694B405F9B8D9598C2584045F6419605694B405F9B8D9598C258403FE603029D674B40289B728577C158403FE603029D674B40
27726	Чехово	5	50	282	99.373586000000003	99.392342999999997	54.482242999999997	54.462938000000001	0103000020E61000000100000005000000950F41D5E8D75840AF09698D413B4B40950F41D5E8D75840CADC7C23BA3D4B402174D0251CD95840CADC7C23BA3D4B402174D0251CD95840AF09698D413B4B40950F41D5E8D75840AF09698D413B4B40
27570	Чалоты	5	50	282	99.070656	99.092996999999997	54.656813	54.646394999999998	0103000020E610000001000000050000000951BEA085C4584022A64412BD524B400951BEA085C45840384BC97212544B401268B0A9F3C55840384BC97212544B401268B0A9F3C5584022A64412BD524B400951BEA085C4584022A64412BD524B40
28264	Худоеланское	5	50	282	99.611639999999994	99.654920000000004	54.721702000000001	54.692509999999999	0103000020E610000001000000050000003A3B191C25E758409413ED2AA4584B403A3B191C25E7584099BA2BBB605C4B40C45F9335EAE9584099BA2BBB605C4B40C45F9335EAE958409413ED2AA4584B403A3B191C25E758409413ED2AA4584B40
28450	Хингуй	5	50	282	99.326729999999998	99.352018000000001	54.796396999999999	54.787379999999999	0103000020E61000000100000005000000D027F224E9D4584022C32ADEC8644B40D027F224E9D45840F6D03E56F0654B409D66817687D65840F6D03E56F0654B409D66817687D6584022C32ADEC8644B40D027F224E9D4584022C32ADEC8644B40
26484	Усть-Кадуй	5	50	282	99.425580999999994	99.439639	55.154043999999999	55.143106000000003	0103000020E61000000100000005000000223317B83CDB584042EE224C51924B40223317B83CDB58409012BBB6B7934B40F4C29D0B23DC58409012BBB6B7934B40F4C29D0B23DC584042EE224C51924B40223317B83CDB584042EE224C51924B40
27924	Унгудул	5	50	282	99.677711000000002	99.697213000000005	54.307589	54.297548999999997	0103000020E61000000100000005000000ED48F59D5FEB58408FFAEB1516264B40ED48F59D5FEB5840FFCD8B135F274B40265646239FEC5840FFCD8B135F274B40265646239FEC58408FFAEB1516264B40ED48F59D5FEB58408FFAEB1516264B40
26708	Укар	5	50	282	99.254774999999995	99.277574000000001	55.064700000000002	55.058625999999997	0103000020E61000000100000005000000A835CD3B4ED05840FF58880E81874B40A835CD3B4ED058408E06F01648884B40130EBDC5C3D158408E06F01648884B40130EBDC5C3D15840FF58880E81874B40A835CD3B4ED05840FF58880E81874B40
59146	Ук	5	50	282	95.655395999999996	100.205399	55.952500000000001	52.970999999999997	0103000020E61000000100000005000000787B1002F2E957403F355EBA497C4A40787B1002F2E9574052B81E85EBF94B4064E8D841250D594052B81E85EBF94B4064E8D841250D59403F355EBA497C4A40787B1002F2E957403F355EBA497C4A40
27412	Уват	5	50	282	98.942555999999996	98.965113000000002	54.870092999999997	54.864325999999998	0103000020E6100000010000000500000082A966D652BC58408F8AFF3BA26E4B4082A966D652BC584040BD19355F6F4B4072FC5069C4BD584040BD19355F6F4B4072FC5069C4BD58408F8AFF3BA26E4B4082A966D652BC58408F8AFF3BA26E4B40
28357	Талый Ключ	5	50	282	99.709242000000003	99.734233000000003	54.634875000000001	54.622543999999998	0103000020E61000000100000005000000C7BC8E3864ED584017299485AF4F4B40C7BC8E3864ED58402506819543514B4037A968ACFDEE58402506819543514B4037A968ACFDEE584017299485AF4F4B40C7BC8E3864ED584017299485AF4F4B40
59210	Таежный	5	50	282	98.990778000000006	99.003497999999993	55.658026999999997	55.652075000000004	0103000020E610000001000000050000002AE620E868BF584005C58F3177D34B402AE620E868BF584047718E3A3AD44B407DE6AC4F39C0584047718E3A3AD44B407DE6AC4F39C0584005C58F3177D34B402AE620E868BF584005C58F3177D34B40
28849	Старый Алзамай	5	50	282	98.591027999999994	98.609695000000002	55.604498	55.589295	0103000020E610000001000000050000004CC11A67D3A558402159C0046ECB4B404CC11A67D3A55840AB3FC23060CD4B4039622D3E05A75840AB3FC23060CD4B4039622D3E05A758402159C0046ECB4B404CC11A67D3A558402159C0046ECB4B40
27447	Солонцы	5	50	282	99.180977999999996	99.200624000000005	54.676099999999998	54.661906000000002	0103000020E61000000100000005000000E9D2BF2495CB58405A83F755B9544B40E9D2BF2495CB5840AD69DE718A564B40BCB20B06D7CC5840AD69DE718A564B40BCB20B06D7CC58405A83F755B9544B40E9D2BF2495CB58405A83F755B9544B40
27124	Рубахина	5	50	282	99.083026000000004	99.095989000000003	54.873942	54.861829	0103000020E61000000100000005000000EFAD484C50C5584048DFA469506E4B40EFAD484C50C55840E84CDA54DD6F4B40A6F10BAF24C65840E84CDA54DD6F4B40A6F10BAF24C6584048DFA469506E4B40EFAD484C50C5584048DFA469506E4B40
27665	Привольное	5	50	282	99.254909999999995	99.269336999999993	54.573076999999998	54.549961000000003	0103000020E61000000100000005000000185B087250D05840A9893E1F65464B40185B087250D058407E8B4E965A494B4093A641D13CD158407E8B4E965A494B4093A641D13CD15840A9893E1F65464B40185B087250D05840A9893E1F65464B40
27645	Порог	5	50	282	99.242036999999996	99.266157000000007	54.566104000000003	54.539541999999997	0103000020E6100000010000000500000001DBC1887DCF5840C26856B60F454B4001DBC1887DCF584041118B1876484B407FA65EB708D1584041118B1876484B407FA65EB708D15840C26856B60F454B4001DBC1887DCF5840C26856B60F454B40
27079	Подгорный	5	50	282	98.985388	98.999851000000007	54.860362000000002	54.853282999999998	0103000020E61000000100000005000000BC77D49810BF5840CB9D9960386D4B40BC77D49810BF58404F5C8E57206E4B40DE770C8FFDBF58404F5C8E57206E4B40DE770C8FFDBF5840CB9D9960386D4B40BC77D49810BF5840CB9D9960386D4B40
28753	Первомайский (Алгашет)	5	50	282	98.591171000000003	98.613152999999997	55.449990999999997	55.444155000000002	0103000020E61000000100000005000000FED5E3BED5A558406DAD2F12DAB84B40FED5E3BED5A55840463F1A4E99B94B406F9C14E63DA75840463F1A4E99B94B406F9C14E63DA758406DAD2F12DAB84B40FED5E3BED5A558406DAD2F12DAB84B40
1192	Орик	5	50	282	99.557822000000002	99.587457000000001	54.318854999999999	54.308129999999998	0103000020E6100000010000000500000051BF0B5BB3E358404F75C8CD70274B4051BF0B5BB3E3584042959A3DD0284B409AB33EE598E5584042959A3DD0284B409AB33EE598E558404F75C8CD70274B4051BF0B5BB3E358404F75C8CD70274B40
28914	Новокиевск	5	50	282	98.661023999999998	98.680446000000003	55.670985999999999	55.663404999999997	0103000020E61000000100000005000000C0779B374EAA58405E807D74EAD44B40C0779B374EAA5840740987DEE2D54B406B2C616D8CAB5840740987DEE2D54B406B2C616D8CAB58405E807D74EAD44B40C0779B374EAA58405E807D74EAD44B40
28645	Новое Село (Большой Курят)	5	50	282	98.844217999999998	98.861744000000002	54.905186999999998	54.89676	0103000020E61000000100000005000000732CEFAA07B65840342E1C08C9724B40732CEFAA07B65840D6E1E82ADD734B408D614ED026B75840D6E1E82ADD734B408D614ED026B75840342E1C08C9724B40732CEFAA07B65840342E1C08C9724B40
59125	Нижнеудинск	5	50	282	95.655395999999996	100.205399	55.952500000000001	52.970999999999997	0103000020E61000000100000005000000787B1002F2E957403F355EBA497C4A40787B1002F2E9574052B81E85EBF94B4064E8D841250D594052B81E85EBF94B4064E8D841250D59403F355EBA497C4A40787B1002F2E957403F355EBA497C4A40
27052	Мельница	5	50	282	99.058043999999995	99.092988000000005	54.867621999999997	54.838996999999999	0103000020E61000000100000005000000A86E2EFEB6C358409738F240646B4B40A86E2EFEB6C3584022A5D93C0E6F4B40E9BAF083F3C5584022A5D93C0E6F4B40E9BAF083F3C558409738F240646B4B40A86E2EFEB6C358409738F240646B4B40
28016	Марга	5	50	282	99.831367999999998	99.851292000000001	54.604176000000002	54.594276999999998	0103000020E6100000010000000500000038BC202235F55840EBE1CB44114C4B4038BC202235F558409983A0A3554D4B402CD670917BF658409983A0A3554D4B402CD670917BF65840EBE1CB44114C4B4038BC202235F55840EBE1CB44114C4B40
28660	Мара	5	50	282	98.841307	98.850075000000004	55.003926	54.996521000000001	0103000020E6100000010000000500000056B950F9D7B558407C6308008E7F4B4056B950F9D7B5584053CDACA580804B406C09F9A067B6584053CDACA580804B406C09F9A067B658407C6308008E7F4B4056B950F9D7B558407C6308008E7F4B40
27290	Майский	5	50	282	99.005887999999999	99.019991000000005	54.831539999999997	54.824066999999999	0103000020E6100000010000000500000016DC0F7860C058403E5B07077B694B4016DC0F7860C058406DA818E76F6A4B40B8CD548847C158406DA818E76F6A4B40B8CD548847C158403E5B07077B694B4016DC0F7860C058403E5B07077B694B40
26569	Лесной	5	50	282	99.474547999999999	99.488696000000004	55.049931000000001	55.040193000000002	0103000020E61000000100000005000000761893FE5EDE58409A43520B25854B40761893FE5EDE58403E07962364864B40E86B96CB46DF58403E07962364864B40E86B96CB46DF58409A43520B25854B40761893FE5EDE58409A43520B25854B40
27501	Кушун	5	50	282	99.186718999999997	99.196331000000001	54.643098000000002	54.633353999999997	0103000020E61000000100000005000000ADA23F34F3CB584038656EBE11514B40ADA23F34F3CB5840BF0F070951524B40390CE6AF90CC5840BF0F070951524B40390CE6AF90CC584038656EBE11514B40ADA23F34F3CB584038656EBE11514B40
59317	Куряты	5	50	282	98.932235000000006	98.968670000000003	54.964033999999998	54.934049999999999	0103000020E61000000100000005000000F14BFDBCA9BB5840166A4DF38E774B40F14BFDBCA9BB5840B41D5377657B4B4072A774B0FEBD5840B41D5377657B4B4072A774B0FEBD5840166A4DF38E774B40F14BFDBCA9BB5840166A4DF38E774B40
27784	Кургатей	5	50	282	99.409572999999995	99.451245	54.384087000000001	54.369853999999997	0103000020E61000000100000005000000C614AC7136DA5840BB253960572F4B40C614AC7136DA5840CDE847C329314B40F25EB532E1DC5840CDE847C329314B40F25EB532E1DC5840BB253960572F4B40C614AC7136DA5840BB253960572F4B40
27593	Кирей-Муксут	5	50	282	99.288713000000001	99.321178000000003	54.634453000000001	54.622846000000003	0103000020E61000000100000005000000863B17467AD25840E338F06AB94F4B40863B17467AD25840AFEC82C135514B40768C2B2E8ED45840AFEC82C135514B40768C2B2E8ED45840E338F06AB94F4B40863B17467AD25840E338F06AB94F4B40
28974	Катарма	5	50	282	99.100713999999996	99.111215000000001	55.669285000000002	55.663837000000001	0103000020E61000000100000005000000F50F221972C65840F86F5E9CF8D44B40F50F221972C65840085A8121ABD54B40C7F484251EC75840085A8121ABD54B40C7F484251EC75840F86F5E9CF8D44B40F50F221972C65840F86F5E9CF8D44B40
27810	Катарбей	5	50	282	99.669329000000005	99.691760000000002	54.382508000000001	54.347361999999997	0103000020E61000000100000005000000EC504D49D6EA5840C3EFA65B762C4B40EC504D49D6EA5840AC3AAB05F6304B40952BBCCB45EC5840AC3AAB05F6304B40952BBCCB45EC5840C3EFA65B762C4B40EC504D49D6EA5840C3EFA65B762C4B40
26940	Камышет	5	50	282	98.787929000000005	98.802499999999995	55.217249000000002	55.190719000000001	0103000020E610000001000000050000007BA4C16D6DB25840E8DCED7A69984B407BA4C16D6DB258405B0BB3D0CE9B4B408FC2F5285CB358405B0BB3D0CE9B4B408FC2F5285CB35840E8DCED7A69984B407BA4C16D6DB25840E8DCED7A69984B40
28575	Каменка	5	50	282	98.817035000000004	98.834299999999999	54.938405000000003	54.92747	0103000020E61000000100000005000000FE2B2B4D4AB45840B4024356B7764B40FE2B2B4D4AB4584092B3B0A71D784B4061C3D32B65B5584092B3B0A71D784B4061C3D32B65B55840B4024356B7764B40FE2B2B4D4AB45840B4024356B7764B40
28381	Кадуй	5	50	282	99.483189999999993	99.537385	54.751595999999999	54.739429999999999	0103000020E6100000010000000500000045F0BF95ECDE584034D769A4A55E4B4045F0BF95ECDE5840F7E6374C34604B401A170E8464E25840F7E6374C34604B401A170E8464E2584034D769A4A55E4B4045F0BF95ECDE584034D769A4A55E4B40
27953	Иргей	5	50	282	99.986003999999994	100.012809	54.564872000000001	54.553386000000003	0103000020E61000000100000005000000696E85B01AFF58403A083A5AD5464B40696E85B01AFF58408B36C7B94D484B400C06D7DCD10059408B36C7B94D484B400C06D7DCD10059403A083A5AD5464B40696E85B01AFF58403A083A5AD5464B40
28717	Замзор	5	50	282	98.626133999999993	98.660414000000003	55.376969000000003	55.361297999999998	0103000020E61000000100000005000000793A579412A858401B0E4B033FAE4B40793A579412A858408C4D2B8540B04B4084F4143944AA58408C4D2B8540B04B4084F4143944AA58401B0E4B033FAE4B40793A579412A858401B0E4B033FAE4B40
59225	Загорье	5	50	282	98.675657999999999	98.685153	55.301172000000001	55.297055999999998	0103000020E61000000100000005000000F8510DFB3DAB5840508A56EE05A64B40F8510DFB3DAB5840473CD9CD8CA64B4067F0F78BD9AB5840473CD9CD8CA64B4067F0F78BD9AB5840508A56EE05A64B40F8510DFB3DAB5840508A56EE05A64B40
28137	Даур	5	50	282	99.870220000000003	99.912979000000007	54.759711000000003	54.743380000000002	0103000020E61000000100000005000000CF143AAFB1F7584010406A13275F4B40CF143AAFB1F75840ABB4C5353E614B40D4BB783F6EFA5840ABB4C5353E614B40D4BB783F6EFA584010406A13275F4B40CF143AAFB1F7584010406A13275F4B40
27189	Вознесенский	5	50	282	99.09863	99.109769	54.900798000000002	54.886325999999997	0103000020E61000000100000005000000E31934F44FC6584018CC5F2173714B40E31934F44FC65840AF264F594D734B4056478E7406C75840AF264F594D734B4056478E7406C7584018CC5F2173714B40E31934F44FC6584018CC5F2173714B40
26920	Водопадный	5	50	282	99.028848999999994	99.041353000000001	55.050164000000002	55.044603000000002	0103000020E610000001000000050000006DE179A9D8C15840D926158DB5854B406DE179A9D8C15840E1B721C66B864B40DBA50D87A5C25840E1B721C66B864B40DBA50D87A5C25840D926158DB5854B406DE179A9D8C15840D926158DB5854B40
28217	Вершина	5	50	282	99.804382000000004	99.828734999999995	54.633156	54.623654000000002	0103000020E610000001000000050000006EDFA3FE7AF358408202EFE4D34F4B406EDFA3FE7AF3584012A27C410B514B403C8386FE09F5584012A27C410B514B403C8386FE09F558408202EFE4D34F4B406EDFA3FE7AF358408202EFE4D34F4B40
28493	Верхний Хингуй	5	50	282	99.435892999999993	99.451524000000006	54.800175000000003	54.793152999999997	0103000020E610000001000000050000008AE3C0ABE5DB5840B5DC990986654B408AE3C0ABE5DB5840D50968226C664B40FC56EBC4E5DC5840D50968226C664B40FC56EBC4E5DC5840B5DC990986654B408AE3C0ABE5DB5840B5DC990986654B40
28090	Большеверстовск	5	50	282	99.884674000000004	99.910589999999999	54.697625000000002	54.688571000000003	0103000020E61000000100000005000000C767B27F9EF85840ADFC321823584B40C767B27F9EF858409EEFA7C64B594B402384471B47FA58409EEFA7C64B594B402384471B47FA5840ADFC321823584B40C767B27F9EF85840ADFC321823584B40
26414	Атагай	5	50	282	99.331795999999997	99.400588999999997	55.115779000000003	55.091298999999999	0103000020E61000000100000005000000643C4A253CD55840299485AFAF8B4B40643C4A253CD558402448A5D8D18E4B40CA880B40A3D958402448A5D8D18E4B40CA880B40A3D95840299485AFAF8B4B40643C4A253CD55840299485AFAF8B4B40
26096	Алзамай	5	50	282	98.634029999999996	98.690920000000006	55.583545999999998	55.527830000000002	0103000020E61000000100000005000000B4AB90F293A8584081ECF5EE8FC34B40B4AB90F293A8584016DBA4A2B1CA4B40C009850838AC584016DBA4A2B1CA4B40C009850838AC584081ECF5EE8FC34B40B4AB90F293A8584081ECF5EE8FC34B40
27203	Абалаково	5	50	282	99.098100000000002	99.120170999999999	54.749755999999998	54.738577999999997	0103000020E6100000010000000500000035EF384547C65840C5C551B9895E4B4035EF384547C6584069FD2D01F85F4B405EBBB4E1B0C7584069FD2D01F85F4B405EBBB4E1B0C75840C5C551B9895E4B4035EF384547C65840C5C551B9895E4B40
24758	Янгель	5	50	1713	103.64238	103.65190200000001	57.087335000000003	57.079816999999998	0103000020E61000000100000005000000B0E600C11CE9594019558671378A4C40B0E600C11CE95940E96514CB2D8B4C409C8C2AC3B8E95940E96514CB2D8B4C409C8C2AC3B8E9594019558671378A4C40B0E600C11CE9594019558671378A4C40
24146	Шестаково	5	50	1713	103.949119	103.97305900000001	56.500463000000003	56.473917999999998	0103000020E61000000100000005000000C8409E5DBEFC59402C7E5358A93C4C40C8409E5DBEFC5940D5EDEC2B0F404C400685419946FE5940D5EDEC2B0F404C400685419946FE59402C7E5358A93C4C40C8409E5DBEFC59402C7E5358A93C4C40
59256	Чёрная	5	50	1713	103.636685	103.646171	56.416744000000001	56.413024999999998	0103000020E61000000100000005000000A4367172BFE8594017B7D100DE344C40A4367172BFE85940F1660DDE57354C40E9279CDD5AE95940F1660DDE57354C40E9279CDD5AE9594017B7D100DE344C40A4367172BFE8594017B7D100DE344C40
24544	Чистополянский	5	50	1713	103.105538	103.119399	56.389015000000001	56.371865	0103000020E610000001000000050000000E9F7422C1C6594076C3B645992F4C400E9F7422C1C65940A453573ECB314C40350BB43BA4C75940A453573ECB314C40350BB43BA4C7594076C3B645992F4C400E9F7422C1C6594076C3B645992F4C40
24354	Хребтовая	5	50	1713	104.23965200000001	104.28278899999999	56.713064000000003	56.698334000000003	0103000020E61000000100000005000000F29A5775560F5A40AAD72D0263594C40F29A5775560F5A403CFA5FAE455B4C40C9AA083719125A403CFA5FAE455B4C40C9AA083719125A40AAD72D0263594C40F29A5775560F5A40AAD72D0263594C40
24236	Суворовский	5	50	1713	103.93239199999999	103.954195	56.506751999999999	56.492531999999997	0103000020E6100000010000000500000054C37E4FACFB5940E21DE0490B3F4C4054C37E4FACFB59405F97E13FDD404C406EC0E78711FD59405F97E13FDD404C406EC0E78711FD5940E21DE0490B3F4C4054C37E4FACFB5940E21DE0490B3F4C40
23980	Соцгородок	5	50	1713	103.44529900000001	103.464433	56.467896000000003	56.459104000000004	0103000020E61000000100000005000000427C60C77FDC59403DBB7CEBC33A4C40427C60C77FDC5940F1F62004E43B4C40B98B3045B9DD5940F1F62004E43B4C40B98B3045B9DD59403DBB7CEBC33A4C40427C60C77FDC59403DBB7CEBC33A4C40
24091	Семигорск	5	50	1713	104.625766	104.664618	56.688710999999998	56.672536999999998	0103000020E61000000100000005000000B83CD68C0C285A40CB2C42B115564C40B83CD68C0C285A409EB29AAE27584C404F95EF19892A5A409EB29AAE27584C404F95EF19892A5A40CB2C42B115564C40B83CD68C0C285A40CB2C42B115564C40
24291	Селезнёвский	5	50	1713	103.945786	103.95111300000001	56.444802000000003	56.438448000000001	0103000020E61000000100000005000000F0C000C287FC5940917F66101F384C40F0C000C287FC594003999D45EF384C403B730F09DFFC594003999D45EF384C403B730F09DFFC5940917F66101F384C40F0C000C287FC5940917F66101F384C40
24633	Рудногорск	5	50	1713	103.74324300000001	103.773561	57.275891000000001	57.259912999999997	0103000020E61000000100000005000000C87E164B91EF5940126745D444A14C40C87E164B91EF59406021736550A34C40821DFF0582F159406021736550A34C40821DFF0582F15940126745D444A14C40C87E164B91EF5940126745D444A14C40
23881	Речушка	5	50	1713	102.856768	102.87602800000001	56.537864999999996	56.527330999999997	0103000020E6100000010000000500000099107349D5B659405F950B957F434C4099107349D5B65940DE54A4C2D8444C405798BED710B85940DE54A4C2D8444C405798BED710B859405F950B957F434C4099107349D5B659405F950B957F434C40
24787	Радищев	5	50	1713	103.485867	103.497365	57.231357000000003	57.220686000000001	0103000020E6100000010000000500000029CDE67118DF5940B05758703F9C4C4029CDE67118DF5940B0592E1B9D9D4C40344B02D4D4DF5940B0592E1B9D9D4C40344B02D4D4DF5940B05758703F9C4C4029CDE67118DF5940B05758703F9C4C40
24849	Новоилимск	5	50	1713	103.674423	103.69203	57.301476000000001	57.290072000000002	0103000020E61000000100000005000000E52A16BF29EB59401FBE4C1421A54C40E52A16BF29EB5940B343FCC396A64C40757632384AEC5940B343FCC396A64C40757632384AEC59401FBE4C1421A54C40E52A16BF29EB59401FBE4C1421A54C40
24928	Новая Игирма	5	50	1713	103.877182	103.95611700000001	57.155416000000002	57.120362999999998	0103000020E61000000100000005000000F4A8F8BF23F859400053060E688F4C40F4A8F8BF23F8594038A3E6ABE4934C4094895B0531FD594038A3E6ABE4934C4094895B0531FD59400053060E688F4C40F4A8F8BF23F859400053060E688F4C40
24882	Коршуновский	5	50	1713	104.18718200000001	104.205822	56.495479000000003	56.486652999999997	0103000020E61000000100000005000000981936CAFA0B5A4009C03FA54A3E4C40981936CAFA0B5A406A6D1ADB6B3F4C4007B309302C0D5A406A6D1ADB6B3F4C4007B309302C0D5A4009C03FA54A3E4C40981936CAFA0B5A4009C03FA54A3E4C40
24628	Каймоновский	5	50	1713	103.09021300000001	103.10906799999999	56.385376999999998	56.373829000000001	0103000020E61000000100000005000000242BBF0CC6C55940F0A5F0A0D92F4C40242BBF0CC6C55940B7D0950854314C40914259F8FAC65940B7D0950854314C40914259F8FAC65940F0A5F0A0D92F4C40242BBF0CC6C55940F0A5F0A0D92F4C40
23855	Игирма	5	50	1713	103.61497300000001	103.63943399999999	56.987094999999997	56.975068	0103000020E6100000010000000500000013BBB6B75BE7594025B03907CF7C4C4013BBB6B75BE75940C6850321597E4C40D47C957CECE85940C6850321597E4C40D47C957CECE8594025B03907CF7C4C4013BBB6B75BE7594025B03907CF7C4C40
23939	Заярск	5	50	1713	102.826441	102.844128	56.198926	56.186720000000001	0103000020E61000000100000005000000B5C4CA68E4B459402BC1E270E6174C40B5C4CA68E4B459407C293C6876194C40D368723106B659407C293C6876194C40D368723106B659402BC1E270E6174C40B5C4CA68E4B459402BC1E270E6174C40
23761	Заморский	5	50	1713	103.19534299999999	103.223208	57.087452999999996	57.080134999999999	0103000020E610000001000000050000002920ED7F80CC5940EA211ADD418A4C402920ED7F80CC5940F277EFA8318B4C40280D350A49CE5940F277EFA8318B4C40280D350A49CE5940EA211ADD418A4C402920ED7F80CC5940EA211ADD418A4C40
23095	Железногорск-Илимский	5	50	1713	104.068873	104.15471599999999	56.597963	56.482253999999998	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
23678	Дальний	5	50	1713	102.776889	102.81276800000001	57.366148000000003	57.351467	0103000020E61000000100000005000000D1E7A38CB8B15940C64FE3DEFCAC4C40D1E7A38CB8B1594077BF0AF0DDAE4C4010CF126404B4594077BF0AF0DDAE4C4010CF126404B45940C64FE3DEFCAC4C40D1E7A38CB8B15940C64FE3DEFCAC4C40
24442	Видим	5	50	1713	103.097202	103.12089899999999	56.417143000000003	56.398217000000002	0103000020E61000000100000005000000C5C6BC8E38C659400ADB4FC6F8324C40C5C6BC8E38C65940AF601BF164354C409FC728CFBCC75940AF601BF164354C409FC728CFBCC759400ADB4FC6F8324C40C5C6BC8E38C659400ADB4FC6F8324C40
23708	Брусничный	5	50	1713	103.258072	103.280126	57.275891000000001	57.265242999999998	0103000020E61000000100000005000000DA006C4084D05940183F8D7BF3A14C40DA006C4084D059406021736550A34C4098309A95EDD159406021736550A34C4098309A95EDD15940183F8D7BF3A14C40DA006C4084D05940183F8D7BF3A14C40
23818	Березняки	5	50	1713	103.580477	103.60252199999999	56.946264999999997	56.933675000000001	0103000020E6100000010000000500000022C5008926E55940E10B93A982774C4022C5008926E55940BA2C26361F794C40B6476FB88FE65940BA2C26361F794C40B6476FB88FE65940E10B93A982774C4022C5008926E55940E10B93A982774C40
59334	п. Согдиондон	5	50	7474	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59337	п. Горно-Чуйский	5	50	7474	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59323	Мусковит	5	50	7474	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59265	Луговский	5	50	7474	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59195	станция Мингатуй	5	50	113	101.237357	101.369158	54.469226999999997	54.392386000000002	0103000020E61000000100000005000000821E6ADB304F594042B456B439324B40821E6ADB304F594039B35DA10F3C4B40A243E048A057594039B35DA10F3C4B40A243E048A057594042B456B439324B40821E6ADB304F594042B456B439324B40
22628	Чеботариха	5	50	113	101.214611	101.256266	54.395038	54.366171999999999	0103000020E610000001000000050000002997C62FBC4D5940FF5A5EB9DE2E4B402997C62FBC4D5940B056ED9A90324B40E94482A966505940B056ED9A90324B40E94482A966505940FF5A5EB9DE2E4B402997C62FBC4D5940FF5A5EB9DE2E4B40
21004	Харчев	5	50	113	101.86077	101.883793	54.232843000000003	54.222616000000002	0103000020E6100000010000000500000030D80DDB167759407EC85BAE7E1C4B4030D80DDB16775940200DA7CCCD1D4B40C2DB831090785940200DA7CCCD1D4B40C2DB8310907859407EC85BAE7E1C4B4030D80DDB167759407EC85BAE7E1C4B40
52140	Харик	5	50	113	101.597635	101.680055	54.253247000000002	54.167417999999998	0103000020E610000001000000050000007AFCDEA63F6659408061F9F36D154B407AFCDEA63F665940B267CF656A204B40CD1E6805866B5940B267CF656A204B40CD1E6805866B59408061F9F36D154B407AFCDEA63F6659408061F9F36D154B40
20497	Хаихта	5	50	113	101.75013300000001	101.78196	54.358234000000003	54.342312999999997	0103000020E61000000100000005000000A0A9D72D0270594071FF91E9D02B4B40A0A9D72D027059405B28999CDA2D4B40EEB1F4A10B7259405B28999CDA2D4B40EEB1F4A10B72594071FF91E9D02B4B40A0A9D72D0270594071FF91E9D02B4B40
22443	Уян	5	50	113	101.972987	102.02517	54.354225999999997	54.328622000000003	0103000020E61000000100000005000000B91B446B457E5940815F2349102A4B40B91B446B457E59404AB20E47572D4B40C8B5A1629C8159404AB20E47572D4B40C8B5A1629C815940815F2349102A4B40B91B446B457E5940815F2349102A4B40
22383	Уховский	5	50	113	101.108107	101.144767	54.417535999999998	54.390787000000003	0103000020E61000000100000005000000FF5D9F39EB465940DA59F44E05324B40FF5D9F39EB4659408A73D4D171354B4090A2CEDC434959408A73D4D171354B4090A2CEDC43495940DA59F44E05324B40FF5D9F39EB465940DA59F44E05324B40
22191	Усть-Када	5	50	113	102.005425	102.027173	54.507227999999998	54.486207999999998	0103000020E610000001000000050000002C6519E258805940DB8651103C3E4B402C6519E258805940C8CEDBD8EC404B406495D233BD815940C8CEDBD8EC404B406495D233BD815940DB8651103C3E4B402C6519E258805940DB8651103C3E4B40
1194	Урункуй	5	50	113	101.43902	101.45465900000001	53.957163999999999	53.946641	0103000020E610000001000000050000008E9257E7185C5940C00644882BF94A408E9257E7185C59404B74965984FA4A4041F50F22195D59404B74965984FA4A4041F50F22195D5940C00644882BF94A408E9257E7185C5940C00644882BF94A40
52497	Тулюшка	5	50	113	101.16761200000001	101.208395	54.458840000000002	54.443255999999998	0103000020E61000000100000005000000B39AAE27BA4A5940BDE0D39CBC384B40B39AAE27BA4A59405F0CE544BB3A4B409869FB57564D59405F0CE544BB3A4B409869FB57564D5940BDE0D39CBC384B40B39AAE27BA4A5940BDE0D39CBC384B40
20180	Тобино	5	50	113	101.305314	101.330207	54.458835000000001	54.450957000000002	0103000020E61000000100000005000000B340BB438A5359407E737FF5B8394B40B340BB438A5359404DA1F31ABB3A4B40427A8A1C225559404DA1F31ABB3A4B40427A8A1C225559407E737FF5B8394B40B340BB438A5359407E737FF5B8394B40
21629	Тихорут	5	50	113	101.63818499999999	101.650043	54.153331000000001	54.143006	0103000020E610000001000000050000000EF3E505D8685940DE9046054E124B400EF3E505D8685940433BA759A0134B40997FF44D9A695940433BA759A0134B40997FF44D9A695940DE9046054E124B400EF3E505D8685940DE9046054E124B40
20116	Сулкет	5	50	113	101.464541	101.48976500000001	54.447800999999998	54.431866999999997	0103000020E61000000100000005000000ACA92C0ABB5D59405E9CF86A47374B40ACA92C0ABB5D5940DC0E0D8B51394B406E6E4C4F585F5940DC0E0D8B51394B406E6E4C4F585F59405E9CF86A47374B40ACA92C0ABB5D59405E9CF86A47374B40
21856	Станица 3-я	5	50	113	101.328131	101.348874	54.219994999999997	54.204362000000003	0103000020E6100000010000000500000071732A1900555940C845B588281A4B4071732A19005559404A24D1CB281C4B402E1B9DF3535659404A24D1CB281C4B402E1B9DF353565940C845B588281A4B4071732A1900555940C845B588281A4B40
192	Сосновский	5	50	113	101.800214	101.831898	54.290785999999997	54.273949999999999	0103000020E6100000010000000500000049F3C7B4367359409E5E29CB10234B4049F3C7B4367359403C11C47938254B40E6E61BD13D7559403C11C47938254B40E6E61BD13D7559409E5E29CB10234B4049F3C7B4367359409E5E29CB10234B40
21166	Садовый	5	50	113	101.70093199999999	101.715844	54.200381	54.193744000000002	0103000020E61000000100000005000000122EE411DC6C5940EBE5779ACC184B40122EE411DC6C5940B1DEA815A6194B406C425A63D06D5940B1DEA815A6194B406C425A63D06D5940EBE5779ACC184B40122EE411DC6C5940EBE5779ACC184B40
22121	Панагино	5	50	113	102.186598	102.20451	54.637037999999997	54.624232999999997	0103000020E61000000100000005000000F0DFBC38F18B5940BF0AF0DDE64F4B40F0DFBC38F18B5940952710768A514B401E6D1CB1168D5940952710768A514B401E6D1CB1168D5940BF0AF0DDE64F4B40F0DFBC38F18B5940BF0AF0DDE64F4B40
6642	Октябрьский 2-й	5	50	113	100.968114	100.982541	54.908861999999999	54.888455	0103000020E610000001000000050000002F336C94F53D5940DD7BB8E4B8714B402F336C94F53D5940E0490B9755744B40AA7EA5F3E13E5940E0490B9755744B40AA7EA5F3E13E5940DD7BB8E4B8714B402F336C94F53D5940DD7BB8E4B8714B40
20744	Окинский	5	50	113	101.681951	101.70015100000001	54.621631999999998	54.614662000000003	0103000020E610000001000000050000005E9ECE15A56B5940070C923EAD4E4B405E9ECE15A56B5940D3122BA3914F4B40C0D02346CF6C5940D3122BA3914F4B40C0D02346CF6C5940070C923EAD4E4B405E9ECE15A56B5940070C923EAD4E4B40
22108	Новая Тельба	5	50	113	101.98408999999999	101.998257	54.785325	54.776493000000002	0103000020E6100000010000000500000085949F54FB7E59405649641F64634B4085949F54FB7E594098DD938785644B4032005471E37F594098DD938785644B4032005471E37F59405649641F64634B4085949F54FB7E59405649641F64634B40
22216	Новая Када	5	50	113	101.97908700000001	102.00344	54.531272000000001	54.509366	0103000020E61000000100000005000000153C855CA97E5940E0D8B3E732414B40153C855CA97E5940E8A38CB800444B40E3DF675C38805940E8A38CB800444B40E3DF675C38805940E0D8B3E732414B40153C855CA97E5940E0D8B3E732414B40
22034	Наратай	5	50	113	102.04549	102.066097	55.029812	55.021141999999998	0103000020E61000000100000005000000E292E34EE98259403849F3C7B4824B40E292E34EE9825940A1832EE1D0834B404757E9EE3A845940A1832EE1D0834B404757E9EE3A8459403849F3C7B4824B40E292E34EE98259403849F3C7B4824B40
21973	Мингатуй	5	50	113	101.542811	101.582373	54.743566999999999	54.721187999999998	0103000020E610000001000000050000002E3A596ABD62594042226DE34F5C4B402E3A596ABD62594042B115342D5F4B40B34467994565594042B115342D5F4B40B34467994565594042226DE34F5C4B402E3A596ABD62594042226DE34F5C4B40
20280	Малая Кочерма	5	50	113	101.37219399999999	101.391121	54.509967000000003	54.497613999999999	0103000020E610000001000000050000001D71C806D25759401004C8D0B13F4B401D71C806D25759400685419946414B40D8F15F20085959400685419946414B40D8F15F20085959401004C8D0B13F4B401D71C806D25759401004C8D0B13F4B40
22369	Майский	5	50	113	101.233278	101.246331	54.529882999999998	54.518470999999998	0103000020E610000001000000050000001538D906EE4E59405376FA415D424B401538D906EE4E59406ADAC534D3434B406C3F19E3C34F59406ADAC534D3434B406C3F19E3C34F59405376FA415D424B401538D906EE4E59405376FA415D424B40
21081	Листвянка	5	50	113	101.727316	101.750681	54.247149999999998	54.230606000000002	0103000020E61000000100000005000000E27668588C6E59407521567F841D4B40E27668588C6E59406B9A779CA21F4B40A12E52280B7059406B9A779CA21F4B40A12E52280B7059407521567F841D4B40E27668588C6E59407521567F841D4B40
21727	Лермонтовский	5	50	113	101.352413	101.383189	54.30791	54.296593000000001	0103000020E61000000100000005000000DB6B41EF8D5659407C9C69C2F6254B40DB6B41EF8D565940410E4A9869274B40F7CB272B86585940410E4A9869274B40F7CB272B865859407C9C69C2F6254B40DB6B41EF8D5659407C9C69C2F6254B40
21605	Ленинский	5	50	113	101.66279900000001	101.698615	54.095046000000004	54.084806	0103000020E6100000010000000500000094347F4C6B6A594096404AECDA0A4B4094347F4C6B6A5940CDCEA2772A0C4B40AF5FB01BB66C5940CDCEA2772A0C4B40AF5FB01BB66C594096404AECDA0A4B4094347F4C6B6A594096404AECDA0A4B40
21405	Кундуй	5	50	113	101.24374400000001	101.27611	54.355254000000002	54.326638000000003	0103000020E6100000010000000500000029266F80994F5940C0D02346CF294B4029266F80994F5940F8E28BF6782D4B404F0647C9AB515940F8E28BF6782D4B404F0647C9AB515940C0D02346CF294B4029266F80994F5940C0D02346CF294B40
18957	Куйтун	5	50	113	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
22461	Красный Яр (Подьяр)	5	50	113	102.04463699999999	102.06017799999999	54.392758000000001	54.376944999999999	0103000020E6100000010000000500000042CC2555DB82594003B2D7BB3F304B4042CC2555DB825940069FE6E445324B40137CD3F4D9835940069FE6E445324B40137CD3F4D983594003B2D7BB3F304B4042CC2555DB82594003B2D7BB3F304B40
20456	Ключи	5	50	113	101.583828	101.610068	54.412211999999997	54.397350000000003	0103000020E610000001000000050000004D9F1D705D6559406688635DDC324B404D9F1D705D6559406682E15CC3344B408315A75A0B6759406682E15CC3344B408315A75A0B6759406688635DDC324B404D9F1D705D6559406688635DDC324B40
21263	Карымск	5	50	113	101.809045	101.87835	54.112414999999999	54.090125	0103000020E6100000010000000500000082FFAD64C7735940A8C64B37890B4B4082FFAD64C7735940384A5E9D630E4B40431CEBE236785940384A5E9D630E4B40431CEBE236785940A8C64B37890B4B4082FFAD64C7735940A8C64B37890B4B40
21955	Каранцай	5	50	113	101.208629	101.251029	54.144145000000002	54.118679	0103000020E61000000100000005000000D2FF722D5A4D59406ADC9BDF300F4B40D2FF722D5A4D5940E370E65773124B403F56F0DB10505940E370E65773124B403F56F0DB105059406ADC9BDF300F4B40D2FF722D5A4D59406ADC9BDF300F4B40
21248	Каразей	5	50	113	101.098271	101.143618	54.365259000000002	54.343819000000003	0103000020E610000001000000050000004BC972124A465940295FD042022C4B404BC972124A465940EBC891CEC02E4B407C478D0931495940EBC891CEC02E4B407C478D0931495940295FD042022C4B404BC972124A465940295FD042022C4B40
21887	Или	5	50	113	101.355225	101.39255900000001	54.181125999999999	54.161403	0103000020E610000001000000050000002F6EA301BC565940F73C7FDAA8144B402F6EA301BC565940473A03232F174B4008B0C8AF1F595940473A03232F174B4008B0C8AF1F595940F73C7FDAA8144B402F6EA301BC565940F73C7FDAA8144B40
21551	Игнино	5	50	113	101.73632600000001	101.76897099999999	54.097110999999998	54.080374999999997	0103000020E61000000100000005000000734C16F71F6F59403F355EBA490A4B40734C16F71F6F59407A8A1C226E0C4B40A22424D2367159407A8A1C226E0C4B40A22424D2367159403F355EBA490A4B40734C16F71F6F59403F355EBA490A4B40
21800	Еланский	5	50	113	101.362537	101.37859	54.353774999999999	54.345981999999999	0103000020E61000000100000005000000C2A563CE3357594099805F23492C4B40C2A563CE335759403A92CB7F482D4B40EE258DD13A5859403A92CB7F482D4B40EE258DD13A58594099805F23492C4B40C2A563CE3357594099805F23492C4B40
20606	Бурук	5	50	113	101.550303	101.58425	54.518073999999999	54.506622	0103000020E6100000010000000500000001F9122A3863594091B75CFDD8404B4001F9122A386359403674B33F50424B4008AC1C5A646559403674B33F50424B4008AC1C5A6465594091B75CFDD8404B4001F9122A3863594091B75CFDD8404B40
20666	Броды	5	50	113	101.48934300000001	101.509546	54.619535999999997	54.609917000000003	0103000020E61000000100000005000000B3614D65515F59402123A0C2114E4B40B3614D65515F5940EA58A5F44C4F4B40B073D3669C605940EA58A5F44C4F4B40B073D3669C6059402123A0C2114E4B40B3614D65515F59402123A0C2114E4B40
1159	Боровое	5	50	113	101.51155799999999	101.530603	54.038117	54.025556999999999	0103000020E610000001000000050000007500C45DBD6059408997A77345034B407500C45DBD605940F8359204E1044B40350A4966F5615940F8359204E1044B40350A4966F56159408997A77345034B407500C45DBD6059408997A77345034B40
20757	Большой Кашелак	5	50	113	101.53681	101.56841300000001	54.081130000000002	54.062649	0103000020E610000001000000050000009C8A54185B6259404510E7E104084B409C8A54185B625940BC5CC477620A4B40C367EBE060645940BC5CC477620A4B40C367EBE0606459404510E7E104084B409C8A54185B6259404510E7E104084B40
20552	Березовский	5	50	113	101.868297	101.884252	54.408864000000001	54.399262999999998	0103000020E61000000100000005000000C18D942D927759405DC0CB0C1B334B40C18D942D927759408141D2A755344B400C5BB395977859408141D2A755344B400C5BB395977859405DC0CB0C1B334B40C18D942D927759405DC0CB0C1B334B40
9669	Барлук	5	50	113	101.69523700000001	101.743584	54.555861	54.519573000000001	0103000020E61000000100000005000000077E54C37E6C59403B71395E81424B40077E54C37E6C5940990F087426474B400C7558E1966F5940990F087426474B400C7558E1966F59403B71395E81424B40077E54C37E6C59403B71395E81424B40
21160	Ахтинский	5	50	113	101.548102	101.56641	54.241520000000001	54.229269000000002	0103000020E61000000100000005000000D237691A146359404A7EC4AF581D4B40D237691A146359403BAA9A20EA1E4B402788BA0F406459403BAA9A20EA1E4B402788BA0F406459404A7EC4AF581D4B40D237691A146359404A7EC4AF581D4B40
22561	Аршан	5	50	113	101.495739	101.51480100000001	54.199891000000001	54.192352999999997	0103000020E6100000010000000500000083161230BA5F5940CC24EA059F184B4083161230BA5F5940E3E13D0796194B40AEBCE47FF2605940E3E13D0796194B40AEBCE47FF2605940CC24EA059F184B4083161230BA5F5940CC24EA059F184B40
59328	Апраксина	5	50	113	101.4111	101.436136	54.109074	54.094883000000003	0103000020E61000000100000005000000AED85F764F5A594023F94A20250C4B40AED85F764F5A5940056C0723F60D4B40EE26F8A6E95B5940056C0723F60D4B40EE26F8A6E95B594023F94A20250C4B40AED85F764F5A594023F94A20250C4B40
20399	Андрюшино	5	50	113	101.60867500000001	101.67164699999999	54.371820999999997	54.356439999999999	0103000020E6100000010000000500000024B9FC87F46659403D7E6FD39F2D4B4024B9FC87F4665940A67B9DD4972F4B4037DDB243FC6A5940A67B9DD4972F4B4037DDB243FC6A59403D7E6FD39F2D4B4024B9FC87F46659403D7E6FD39F2D4B40
21487	Амур	5	50	113	101.106284	101.13430200000001	54.224696000000002	54.208964999999999	0103000020E61000000100000005000000A305685BCD4659401B81785DBF1A4B40A305685BCD46594061C5A9D6C21C4B4065726A679848594061C5A9D6C21C4B4065726A67984859401B81785DBF1A4B40A305685BCD4659401B81785DBF1A4B40
20066	Алкин	5	50	113	101.425185	101.455755	54.501854000000002	54.475997999999997	0103000020E61000000100000005000000FC6F253B365B59400F7BA180ED3C4B40FC6F253B365B5940F3AE7AC03C404B4043FF04172B5D5940F3AE7AC03C404B4043FF04172B5D59400F7BA180ED3C4B40FC6F253B365B59400F7BA180ED3C4B40
20298	Александро-Невский Завод	5	50	113	101.27013599999999	101.30266399999999	54.580267999999997	54.567289000000002	0103000020E61000000100000005000000395E81E849515940B6300BED9C484B40395E81E8495159402975C938464A4B404C6BD3D85E5359402975C938464A4B404C6BD3D85E535940B6300BED9C484B40395E81E849515940B6300BED9C484B40
21460	Александро-Невская Станица	5	50	113	101.274807	101.291372	54.302371999999998	54.285257000000001	0103000020E610000001000000050000008F6D19709651594040FA264D83244B408F6D197096515940F19C2D20B4264B4016BEBED6A5525940F19C2D20B4264B4016BEBED6A552594040FA264D83244B408F6D19709651594040FA264D83244B40
59322	с.Алымовка	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59338	Юбилейный	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59227	Сидорова	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59202	Макарово	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59215	Криволукское муниципальное образование	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59199	Киренск	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59219	Змеиново	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59302	Воронежский	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59382	Банщиково	5	50	7470	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
16530	Щапова	5	50	905	106.115056	106.15320699999999	53.994514000000002	53.980716999999999	0103000020E61000000100000005000000594DD7135D875A40CCD0782288FD4A40594DD7135D875A4003B5183C4CFF4A402BA1BB24CE895A4003B5183C4CFF4A402BA1BB24CE895A40CCD0782288FD4A40594DD7135D875A40CCD0782288FD4A40
16581	Шейна	5	50	905	106.12143399999999	106.13481	54.101086000000002	54.085372	0103000020E61000000100000005000000D6A71C93C5875A403FFF3D78ED0A4B40D6A71C93C5875A40AF0AD462F00C4B401F4B1FBAA0885A40AF0AD462F00C4B401F4B1FBAA0885A403FFF3D78ED0A4B40D6A71C93C5875A403FFF3D78ED0A4B40
17246	Харбатово	5	50	905	105.994439	106.012423	53.757573999999998	53.740791000000002	0103000020E610000001000000050000007CB779E3A47F5A40E8154F3DD2DE4A407CB779E3A47F5A406326512FF8E04A40F7ADD689CB805A406326512FF8E04A40F7ADD689CB805A40E8154F3DD2DE4A407CB779E3A47F5A40E8154F3DD2DE4A40
17445	Хальск	5	50	905	106.03551899999999	106.047943	53.805759999999999	53.798825999999998	0103000020E61000000100000005000000BED87BF145825A40E5982CEE3FE64A40BED87BF145825A406536C82423E74A409E44847F11835A406536C82423E74A409E44847F11835A40E5982CEE3FE64A40BED87BF145825A40E5982CEE3FE64A40
17048	Толмачева	5	50	905	105.521395	105.558927	54.102263999999998	54.089754999999997	0103000020E61000000100000005000000115322895E615A4084D382177D0B4B40115322895E615A4071C79BFC160D4B407D76C075C5635A4071C79BFC160D4B407D76C075C5635A4084D382177D0B4B40115322895E615A4084D382177D0B4B40
16266	Тимирязева	5	50	905	105.88658700000001	105.89897499999999	53.932135000000002	53.918137000000002	0103000020E61000000100000005000000C38366D7BD785A40B01F628385F54A40C38366D7BD785A407E3A1E3350F74A40FB3A70CE88795A407E3A1E3350F74A40FB3A70CE88795A40B01F628385F54A40C38366D7BD785A40B01F628385F54A40
17547	Полоскова	5	50	905	105.96484	106.002138	53.534945999999998	53.518180999999998	0103000020E61000000100000005000000D97745F0BF7D5A404C3448C153C24A40D97745F0BF7D5A4021904B1C79C44A400C056C0723805A4021904B1C79C44A400C056C0723805A404C3448C153C24A40D97745F0BF7D5A404C3448C153C24A40
17277	Никилей	5	50	905	105.951688	105.980417	53.683242	53.666401999999998	0103000020E61000000100000005000000B9FFC874E87C5A4097FE25A94CD54A40B9FFC874E87C5A4077A04E7974D74A4051DCF126BF7E5A4077A04E7974D74A4051DCF126BF7E5A4097FE25A94CD54A40B9FFC874E87C5A4097FE25A94CD54A40
17459	Манзурка	5	50	905	106.04732300000001	106.084576	53.497607000000002	53.465069999999997	0103000020E6100000010000000500000050560C5707835A40E42CEC6987BB4A4050560C5707835A405EA10F96B1BF4A40B28174B169855A405EA10F96B1BF4A40B28174B169855A40E42CEC6987BB4A4050560C5707835A40E42CEC6987BB4A40
16798	Малый Тарель	5	50	905	106.35182500000001	106.37908	53.838262	53.822941999999998	0103000020E61000000100000005000000933A014D84965A409E40D82956E94A40933A014D84965A4062BD512B4CEB4A4055A4C2D842985A4062BD512B4CEB4A4055A4C2D842985A409E40D82956E94A40933A014D84965A409E40D82956E94A40
15468	Малые Голы	5	50	905	106.024452	106.056585	53.939183999999997	53.925083000000001	0103000020E6100000010000000500000098141F9F90815A40F48AA71E69F64A4098141F9F90815A4096766A2E37F84A406D1CB1169F835A4096766A2E37F84A406D1CB1169F835A40F48AA71E69F64A4098141F9F90815A40F48AA71E69F64A40
17370	Литвинова	5	50	905	105.980614	105.99982	53.630316999999998	53.609920000000002	0103000020E61000000100000005000000FCFF3861C27E5A409296CADB11CE4A40FCFF3861C27E5A40718E3A3AAED04A40C078060DFD7F5A40718E3A3AAED04A40C078060DFD7F5A409296CADB11CE4A40FCFF3861C27E5A409296CADB11CE4A40
14982	Краснояр (Басай)	5	50	905	105.923095	105.93964200000001	53.955945999999997	53.945914999999999	0103000020E6100000010000000500000079060DFD137B5A40DEE522BE13F94A4079060DFD137B5A40FA5E43705CFA4A40ADFC3218237C5A40FA5E43705CFA4A40ADFC3218237C5A40DEE522BE13F94A4079060DFD137B5A40DEE522BE13F94A40
17347	Корсукова	5	50	905	106.205112	106.225351	53.748752000000003	53.741356000000003	0103000020E610000001000000050000001901158E208D5A40C158DFC0E4DE4A401901158E208D5A404568041BD7DF4A40BDC799266C8E5A404568041BD7DF4A40BDC799266C8E5A40C158DFC0E4DE4A401901158E208D5A40C158DFC0E4DE4A40
17653	Копылова	5	50	905	106.065541	106.08783699999999	53.367818999999997	53.352342999999998	0103000020E6100000010000000500000004E3E0D231845A40BDFC4E9319AD4A4004E3E0D231845A4078EC67B114AF4A403D98141F9F855A4078EC67B114AF4A403D98141F9F855A40BDFC4E9319AD4A4004E3E0D231845A40BDFC4E9319AD4A40
7090	Качуг	5	50	905	105.812423	105.938636	53.990766000000001	53.934466999999998	0103000020E610000001000000050000002AE109BDFE735A407A185A9D9CF74A402AE109BDFE735A408FFE976BD1FE4A404AB6BA9C127C5A408FFE976BD1FE4A404AB6BA9C127C5A407A185A9D9CF74A402AE109BDFE735A407A185A9D9CF74A40
17678	Карлук	5	50	905	105.975494	105.999982	53.430962999999998	53.416282000000002	0103000020E610000001000000050000006EDC627E6E7E5A40EDF483BA48B54A406EDC627E6E7E5A409D64ABCB29B74A40ADA580B4FF7F5A409D64ABCB29B74A40ADA580B4FF7F5A40EDF483BA48B54A406EDC627E6E7E5A40EDF483BA48B54A40
16386	Исеть	5	50	905	105.960842	105.9909	53.854962999999998	53.835186	0103000020E61000000100000005000000E3A7716F7E7D5A40DD09F65FE7EA4A40E3A7716F7E7D5A402025766D6FED4A40CF66D5E76A7F5A402025766D6FED4A40CF66D5E76A7F5A40DD09F65FE7EA4A40E3A7716F7E7D5A40DD09F65FE7EA4A40
17569	Заречное	5	50	905	106.095122	106.12527900000001	53.419438	53.407136000000001	0103000020E6100000010000000500000054C8957A16865A401B834E081DB44A4054C8957A16865A408E59F624B0B54A400AF8359204885A408E59F624B0B54A400AF8359204885A401B834E081DB44A4054C8957A16865A401B834E081DB44A40
16883	Залог	5	50	905	106.372001	106.400711	53.944944999999997	53.928477000000001	0103000020E61000000100000005000000134548DDCE975A404A0B9755D8F64A40134548DDCE975A4065C22FF5F3F84A407009C03FA5995A4065C22FF5F3F84A407009C03FA5995A404A0B9755D8F64A40134548DDCE975A404A0B9755D8F64A40
16988	Верхоленск	5	50	905	105.55142600000001	105.579471	54.118642000000001	54.083159000000002	0103000020E61000000100000005000000810A47904A635A401DAF40F4A40A4B40810A47904A635A404DF73AA92F0F4B40BF7E880D16655A404DF73AA92F0F4B40BF7E880D16655A401DAF40F4A40A4B40810A47904A635A401DAF40F4A40A4B40
16485	Бутаково	5	50	905	106.10999	106.125539	54.075313999999999	54.040146999999997	0103000020E61000000100000005000000C5387F130A875A402904728923054B40C5387F130A875A4029779FE3A3094B40D8D7BAD408885A4029779FE3A3094B40D8D7BAD408885A402904728923054B40C5387F130A875A402904728923054B40
59237	Босогол	5	50	905	105.893505	105.917867	53.885384000000002	53.873606000000002	0103000020E610000001000000050000000074982F2F795A4071CB4752D2EF4A400074982F2F795A406A334E4354F14A40F8C43A55BE7A5A406A334E4354F14A40F8C43A55BE7A5A4071CB4752D2EF4A400074982F2F795A4071CB4752D2EF4A40
16952	Большой Тарель	5	50	905	106.613908	106.636959	53.761912000000002	53.748778999999999	0103000020E610000001000000050000002DB0C7444AA75A403E7782FDD7DF4A402DB0C7444AA75A400937195586E14A402579AEEFC3A85A400937195586E14A402579AEEFC3A85A403E7782FDD7DF4A402DB0C7444AA75A403E7782FDD7DF4A40
16843	Большой Косогол	5	50	905	106.138268	106.16645800000001	53.846577000000003	53.837502999999998	0103000020E6100000010000000500000055850662D9885A40A4A65D4C33EB4A4055850662D9885A40DD4598A25CEC4A40168A743FA78A5A40DD4598A25CEC4A40168A743FA78A5A40A4A65D4C33EB4A4055850662D9885A40A4A65D4C33EB4A40
16224	Большие Голы	5	50	905	105.985546	106.01461500000001	53.87867	53.865143000000003	0103000020E6100000010000000500000008AD872F137F5A4082AE7D01BDEE4A4008AD872F137F5A40F8FC304278F04A40FDC1C073EF805A40F8FC304278F04A40FDC1C073EF805A4082AE7D01BDEE4A4008AD872F137F5A4082AE7D01BDEE4A40
16692	Бирюлька	5	50	905	106.320761	106.351358	53.876181000000003	53.852477999999998	0103000020E610000001000000050000004435255987945A409D47C5FF1DED4A404435255987945A403430F2B226F04A4008CC43A67C965A403430F2B226F04A4008CC43A67C965A409D47C5FF1DED4A404435255987945A409D47C5FF1DED4A40
17088	Белоусово	5	50	905	105.462214	105.47365000000001	54.038412999999998	54.029412999999998	0103000020E61000000100000005000000377007EA945D5A40E38920CEC3034B40377007EA945D5A40E15E99B7EA044B4007F01648505E5A40E15E99B7EA044B4007F01648505E5A40E38920CEC3034B40377007EA945D5A40E38920CEC3034B40
16647	Ацикяк	5	50	905	106.29575199999999	106.317536	54.195055000000004	54.182406	0103000020E6100000010000000500000080EECB99ED925A400E4C6E1459174B4080EECB99ED925A40EDF5EE8FF7184B405FD3838252945A40EDF5EE8FF7184B405FD3838252945A400E4C6E1459174B4080EECB99ED925A400E4C6E1459174B40
17753	Аргун	5	50	905	105.914247	105.945768	53.376055000000001	53.359082000000001	0103000020E61000000100000005000000D55DD905837A5A40884A2366F6AD4A40D55DD905837A5A40A73FFB9122B04A409D668176877C5A40A73FFB9122B04A409D668176877C5A40884A2366F6AD4A40D55DD905837A5A40884A2366F6AD4A40
16436	Анга	5	50	905	106.15583100000001	106.20599199999999	53.989198999999999	53.974739	0103000020E61000000100000005000000FE2C9622F9895A4060915F3FC4FC4A40FE2C9622F9895A40321EA5129EFE4A4035CF11F92E8D5A40321EA5129EFE4A4035CF11F92E8D5A4060915F3FC4FC4A40FE2C9622F9895A4060915F3FC4FC4A40
59373	Село Подволошино	5	50	7473	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59196	Село Ербогачен	5	50	7473	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
52067	Юхта	5	50	1344	107.768648	107.77994	55.905769999999997	55.891551999999997	0103000020E61000000100000005000000B188618731F15A4079573D601EF24B40B188618731F15A4055D97745F0F34B40E7357689EAF15A4055D97745F0F34B40E7357689EAF15A4079573D601EF24B40B188618731F15A4079573D601EF24B40
52268	Улькан	5	50	1344	107.78046999999999	107.81388699999999	55.938834	55.881050999999999	0103000020E6100000010000000500000095607138F3F15A40D68D7747C6F04B4095607138F3F15A40BA2F67B62BF84B40EEE87FB916F45A40BA2F67B62BF84B40EEE87FB916F45A40D68D7747C6F04B4095607138F3F15A40D68D7747C6F04B40
52273	Тарасово	5	50	1344	107.80986300000001	107.824918	55.863458999999999	55.857008	0103000020E6100000010000000500000064CF9ECBD4F35A4087342A70B2ED4B4064CF9ECBD4F35A40EB3713D385EE4B406EF8DD74CBF45A40EB3713D385EE4B406EF8DD74CBF45A4087342A70B2ED4B4064CF9ECBD4F35A4087342A70B2ED4B40
29487	Новоселово	5	50	1344	107.692471	107.70475999999999	56.071776	56.045921	0103000020E610000001000000050000006B9BE27151EC5A408D9944BDE0054C406B9BE27151EC5A40A051BAF42F094C40DAE1AFC91AED5A40A051BAF42F094C40DAE1AFC91AED5A408D9944BDE0054C406B9BE27151EC5A408D9944BDE0054C40
52287	Небель	5	50	1344	107.09979800000001	107.11120699999999	56.357638999999999	56.350093000000001	0103000020E61000000100000005000000338D261763C65A407EC7F0D8CF2C4C40338D261763C65A401763601DC72D4C408505F7031EC75A401763601DC72D4C408505F7031EC75A407EC7F0D8CF2C4C40338D261763C65A407EC7F0D8CF2C4C40
52158	Магистральный	5	50	1344	107.424629	107.488912	56.179955999999997	56.065655	0103000020E61000000100000005000000B9FB1C1F2DDB5A40D1E80E6267084C40B9FB1C1F2DDB5A40075C57CC08174C40CEA78E554ADF5A40075C57CC08174C40CEA78E554ADF5A40D1E80E6267084C40B9FB1C1F2DDB5A40D1E80E6267084C40
52264	Кунерма	5	50	1344	108.427993	108.453766	55.770547000000001	55.757874999999999	0103000020E61000000100000005000000AF7AC03C641B5B405EBA490C02E14B40AF7AC03C641B5B40F583BA48A1E24B405A828C800A1D5B40F583BA48A1E24B405A828C800A1D5B405EBA490C02E14B40AF7AC03C641B5B405EBA490C02E14B40
59153	Конец-Луг	5	50	1344	107.706637	107.711614	56.025879000000003	56.018801000000003	0103000020E610000001000000050000003049658A39ED5A40E910381268024C403049658A39ED5A409C53C90050034C400C5872158BED5A409C53C90050034C400C5872158BED5A40E910381268024C403049658A39ED5A40E910381268024C40
52294	Ключи	5	50	1344	107.480783	107.50351000000001	56.205554999999997	56.191237999999998	0103000020E61000000100000005000000425E0F26C5DE5A4050E09D7C7A184C40425E0F26C5DE5A40BF4351A04F1A4C4060CD018239E05A40BF4351A04F1A4C4060CD018239E05A4050E09D7C7A184C40425E0F26C5DE5A4050E09D7C7A184C40
15178	Казачинское	5	50	1344	107.55814599999999	107.59156299999999	56.278443000000003	56.254961999999999	0103000020E610000001000000050000002A1900AAB8E35A4083DC4598A2204C402A1900AAB8E35A406B662D05A4234C4083A10E2BDCE55A406B662D05A4234C4083A10E2BDCE55A4083DC4598A2204C402A1900AAB8E35A4083DC4598A2204C40
59120	рабочий поселок Маркова	5	50	425	103.835994	106.018092	53.049399999999999	51.797199999999997	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
59303	д. Столбова	5	50	425	103.835994	106.018092	53.049399999999999	51.797199999999997	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
6008	Ширяева	5	50	425	104.209963	104.23749599999999	52.564765000000001	52.539960000000001	0103000020E61000000100000005000000AF97A608700D5A40F792C6681D454A40AF97A608700D5A40757632384A484A40923B6C22330F5A40757632384A484A40923B6C22330F5A40F792C6681D454A40AF97A608700D5A40F792C6681D454A40
4460	Черемушка	5	50	425	104.560953	104.594792	52.654387999999997	52.637493999999997	0103000020E61000000100000005000000F56569A7E6235A40B7B2446799514A40F56569A7E6235A408A7269FCC2534A4009FB761211265A408A7269FCC2534A4009FB761211265A40B7B2446799514A40F56569A7E6235A40B7B2446799514A40
5616	Хомутово	5	50	425	104.31489500000001	104.428406	52.494847999999998	52.453519999999997	0103000020E6100000010000000500000022AB5B3D27145A407C0A80F10C3A4A4022AB5B3D27145A40D93EE42D573F4A4040DAFF006B1B5A40D93EE42D573F4A4040DAFF006B1B5A407C0A80F10C3A4A4022AB5B3D27145A407C0A80F10C3A4A40
5251	Усть-Куда	5	50	425	104.127354	104.173114	52.447378999999998	52.427906	0103000020E61000000100000005000000F240649126085A408FE1B19FC5364A40F240649126085A4066F50EB743394A40B41EBE4C140B5A4066F50EB743394A40B41EBE4C140B5A408FE1B19FC5364A40F240649126085A408FE1B19FC5364A40
5089	Усть-Балей	5	50	425	103.978629	104.00618	52.647308000000002	52.621822999999999	0103000020E61000000100000005000000B37A87DBA1FE5940477364E5974F4A40B37A87DBA1FE5940373811FDDA524A40EA78CC4065005A40373811FDDA524A40EA78CC4065005A40477364E5974F4A40B37A87DBA1FE5940477364E5974F4A40
4659	Урик	5	50	425	104.216404	104.26013399999999	52.478341	52.437542000000001	0103000020E610000001000000050000004FAE2990D90D5A402F50526001384A404FAE2990D90D5A4000AB23473A3D4A40F8A41309A6105A4000AB23473A3D4A40F8A41309A6105A402F50526001384A404FAE2990D90D5A402F50526001384A40
4089	Турская	5	50	425	104.439932	104.44619299999999	52.537545000000001	52.524501000000001	0103000020E61000000100000005000000B01D8CD8271C5A4012DC48D922434A40B01D8CD8271C5A406D904946CE444A4010AD156D8E1C5A406D904946CE444A4010AD156D8E1C5A4012DC48D922434A40B01D8CD8271C5A4012DC48D922434A40
6099	Тихонова Падь	5	50	425	104.130354	104.170509	52.634028999999998	52.628596000000002	0103000020E61000000100000005000000C7B94DB857085A40BE326FD575504A40C7B94DB857085A4098DBBDDC27514A401DAB949EE90A5A4098DBBDDC27514A401DAB949EE90A5A40BE326FD575504A40C7B94DB857085A40BE326FD575504A40
4602	Сосновый Бор	5	50	425	104.496633	104.526044	52.67268	52.650958000000003	0103000020E610000001000000050000005247C7D5C81F5A40E8887C9752534A405247C7D5C81F5A402E56D4601A564A40731074B4AA215A402E56D4601A564A40731074B4AA215A40E8887C9752534A405247C7D5C81F5A40E8887C9752534A40
4558	Смоленщина	5	50	425	104.10753699999999	104.15477	52.261997999999998	52.240721999999998	0103000020E610000001000000050000000987DEE2E1065A40BFB67EFACF1E4A400987DEE2E1065A4007CF842689214A40B9196EC0E7095A4007CF842689214A40B9196EC0E7095A40BFB67EFACF1E4A400987DEE2E1065A40BFB67EFACF1E4A40
2580	Сайгуты	5	50	425	104.150836	104.174902	52.846600000000002	52.837842999999999	0103000020E61000000100000005000000CEC3094CA7095A405D177E703E6B4A40CEC3094CA7095A40956588635D6C4A4052802898310B5A40956588635D6C4A4052802898310B5A405D177E703E6B4A40CEC3094CA7095A405D177E703E6B4A40
3795	Рязановщина	5	50	425	104.3228	104.339293	52.720771999999997	52.706091000000001	0103000020E6100000010000000500000086C954C1A8145A40FE7F9C30615A4A4086C954C1A8145A40AEEFC341425C4A40C0B0FCF9B6155A40AEEFC341425C4A40C0B0FCF9B6155A40FE7F9C30615A4A4086C954C1A8145A40FE7F9C30615A4A40
4383	Ревякина	5	50	425	104.60521300000001	104.644891	52.598112	52.579794	0103000020E610000001000000050000004D874ECFBB265A40613596B0364A4A404D874ECFBB265A402EAC1BEF8E4C4A40069FE6E445295A402EAC1BEF8E4C4A40069FE6E445295A40613596B0364A4A404D874ECFBB265A40613596B0364A4A40
5770	Позднякова	5	50	425	104.42855900000001	104.445025	52.493718999999999	52.471682000000001	0103000020E61000000100000005000000045ABA826D1B5A40520E6613603C4A40045ABA826D1B5A40F834272F323F4A40C139234A7B1C5A40F834272F323F4A40C139234A7B1C5A40520E6613603C4A40045ABA826D1B5A40520E6613603C4A40
59168	Плишкино	5	50	425	103.835994	106.018092	53.049399999999999	51.797199999999997	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
5356	Пивовариха	5	50	425	104.434119	104.465013	52.282558000000002	52.262498999999998	0103000020E610000001000000050000009FE40E9BC81B5A40C91D369199214A409FE40E9BC81B5A40919C4CDC2A244A40C0CDE2C5C21D5A40919C4CDC2A244A40C0CDE2C5C21D5A40C91D369199214A409FE40E9BC81B5A40C91D369199214A40
5531	Патроны	5	50	425	104.460629	104.481317	52.166442000000004	52.154060999999999	0103000020E61000000100000005000000B5A50EF27A1D5A40664B5645B8134A40B5A50EF27A1D5A402657B1F84D154A409180D1E5CD1E5A402657B1F84D154A409180D1E5CD1E5A40664B5645B8134A40B5A50EF27A1D5A40664B5645B8134A40
3246	Падь-Мельничная	5	50	425	104.366845	104.390192	52.171900000000001	52.156061999999999	0103000020E61000000100000005000000DF6C73637A175A40FD12F1D6F9134A40DF6C73637A175A405917B7D100164A404BCADDE7F8185A405917B7D100164A404BCADDE7F8185A40FD12F1D6F9134A40DF6C73637A175A40FD12F1D6F9134A40
3893	Оёк	5	50	425	104.436177	104.478622	52.614710000000002	52.565061	0103000020E610000001000000050000001D91EF52EA1B5A405E9F39EB53484A401D91EF52EA1B5A40184339D1AE4E4A405A492BBEA11E5A40184339D1AE4E4A405A492BBEA11E5A405E9F39EB53484A401D91EF52EA1B5A405E9F39EB53484A40
3701	Никольск	5	50	425	104.437901	104.468345	52.766016	52.741342000000003	0103000020E61000000100000005000000AF78EA91061C5A405C936E4BE45E4A40AF78EA91061C5A403B1BF2CF0C624A40B08F4E5DF91D5A403B1BF2CF0C624A40B08F4E5DF91D5A405C936E4BE45E4A40AF78EA91061C5A405C936E4BE45E4A40
4772	Московщина	5	50	425	104.151977	104.174318	52.532960000000003	52.509177999999999	0103000020E61000000100000005000000A12FBDFDB9095A40DDEBA4BE2C414A40A12FBDFDB9095A40C009850838444A40AA46AF06280B5A40C009850838444A40AA46AF06280B5A40DDEBA4BE2C414A40A12FBDFDB9095A40DDEBA4BE2C414A40
59123	Молодежный	5	50	425	103.835994	106.018092	53.049399999999999	51.797199999999997	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
3344	Маркова	5	50	425	104.18342699999999	104.23823299999999	52.224190999999998	52.194367999999997	0103000020E61000000100000005000000048D9944BD0B5A40C8B1F50CE1184A40048D9944BD0B5A405D876A4AB21C4A40FDF49F353F0F5A405D876A4AB21C4A40FDF49F353F0F5A40C8B1F50CE1184A40048D9944BD0B5A40C8B1F50CE1184A40
59150	Мамоны	5	50	425	103.835994	106.018092	53.049399999999999	51.797199999999997	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
2312	Малое Голоустное	5	50	425	105.304892	105.34415799999999	52.313186000000002	52.295068000000001	0103000020E61000000100000005000000F833BC5983535A404E0CC9C9C4254A40F833BC5983535A4054C8957A16284A4008AA46AF06565A4054C8957A16284A4008AA46AF06565A404E0CC9C9C4254A40F833BC5983535A404E0CC9C9C4254A40
3155	Малая Еланка	5	50	425	104.03907599999999	104.072062	52.373584999999999	52.354052000000003	0103000020E61000000100000005000000BE839F3880025A40AD8A7093512D4A40BE839F3880025A4059A31EA2D12F4A403352EFA99C045A4059A31EA2D12F4A403352EFA99C045A40AD8A7093512D4A40BE839F3880025A40AD8A7093512D4A40
3034	Максимовщина	5	50	425	104.507063	104.549418	52.619034999999997	52.591245999999998	0103000020E61000000100000005000000BF805EB873205A4006F2ECF2AD4B4A40BF805EB873205A40280AF4893C4F4A405C751DAA29235A40280AF4893C4F4A405C751DAA29235A4006F2ECF2AD4B4A40BF805EB873205A4006F2ECF2AD4B4A40
6038	Лыловщина	5	50	425	104.229366	104.24885999999999	52.528269999999999	52.504607	0103000020E610000001000000050000001E34BBEEAD0E5A40952A51F696404A401E34BBEEAD0E5A409DBAF2599E434A4015527E52ED0F5A409DBAF2599E434A4015527E52ED0F5A40952A51F696404A401E34BBEEAD0E5A40952A51F696404A40
2889	Листвянка	5	50	425	104.854432	104.88785	51.865017999999999	51.840440999999998	0103000020E61000000100000005000000FA298E03AF365A40D89B189293EB4940FA298E03AF365A40C539EAE8B8EE49403B70CE88D2385A40C539EAE8B8EE49403B70CE88D2385A40D89B189293EB4940FA298E03AF365A40D89B189293EB4940
3878	Кыцигировка (Майск)	5	50	425	104.53748899999999	104.555069	52.737754000000002	52.724038999999998	0103000020E610000001000000050000006C3D433866225A40A703594FAD5C4A406C3D433866225A40213F1BB96E5E4A408081204086235A40213F1BB96E5E4A408081204086235A40A703594FAD5C4A406C3D433866225A40A703594FAD5C4A40
5745	Куда	5	50	425	104.37677100000001	104.425011	52.460720000000002	52.427872999999998	0103000020E6100000010000000500000033C51C041D185A40B3EBDE8AC4364A4033C51C041D185A407B4E7ADFF83A4A402D5C5661331B5A407B4E7ADFF83A4A402D5C5661331B5A40B3EBDE8AC4364A4033C51C041D185A40B3EBDE8AC4364A40
3978	Коты	5	50	425	104.48897100000001	104.523089	52.558376000000003	52.544840000000001	0103000020E61000000100000005000000516C054D4B1F5A40BDC62E51BD454A40516C054D4B1F5A40876F61DD78474A406EF9484A7A215A40876F61DD78474A406EF9484A7A215A40BDC62E51BD454A40516C054D4B1F5A40BDC62E51BD454A40
2801	Карлук	5	50	425	104.277112	104.313422	52.429881999999999	52.416108999999999	0103000020E610000001000000050000001155F833BC115A401F49490F43354A401155F833BC115A40CD91955F06374A4034F6251B0F145A40CD91955F06374A4034F6251B0F145A401F49490F43354A401155F833BC115A401F49490F43354A40
5136	Зорино-Быково	5	50	425	103.94936199999999	103.963582	52.727071000000002	52.714821000000001	0103000020E610000001000000050000002B84D558C2FC59403CBF28417F5B4A402B84D558C2FC59405D6F9BA9105D4A40EA40D653ABFD59405D6F9BA9105D4A40EA40D653ABFD59403CBF28417F5B4A402B84D558C2FC59403CBF28417F5B4A40
4274	Жердовка	5	50	425	104.52692399999999	104.549876	52.659664999999997	52.648242000000003	0103000020E610000001000000050000008FDE701FB9215A4063F20698F9524A408FDE701FB9215A406DA818E76F544A40BD361B2B31235A406DA818E76F544A40BD361B2B31235A4063F20698F9524A408FDE701FB9215A4063F20698F9524A40
5007	Еловка	5	50	425	103.95792299999999	103.974362	52.707630000000002	52.693491000000002	0103000020E610000001000000050000008445459C4EFD594001892650C4584A408445459C4EFD594091D5AD9E935A4A40C51D6FF25BFE594091D5AD9E935A4A40C51D6FF25BFE594001892650C4584A408445459C4EFD594001892650C4584A40
3775	Егоровщина	5	50	425	104.43825200000001	104.45299300000001	52.672941999999999	52.653891000000002	0103000020E6100000010000000500000006DA1D520C1C5A400A1346B3B2534A4006DA1D520C1C5A406B0DA5F622564A4049145AD6FD1C5A406B0DA5F622564A4049145AD6FD1C5A400A1346B3B2534A4006DA1D520C1C5A400A1346B3B2534A40
4729	Грановщина	5	50	425	104.269063	104.31706	52.466431999999998	52.458815999999999	0103000020E610000001000000050000001364045438115A40D670917BBA3A4A401364045438115A4068E7340BB43B4A40AAB706B64A145A4068E7340BB43B4A40AAB706B64A145A40D670917BBA3A4A401364045438115A40D670917BBA3A4A40
6146	Горяшина	5	50	425	104.25119599999999	104.263323	52.587975	52.575892000000003	0103000020E61000000100000005000000B438639813105A4097033DD4B6494A40B438639813105A40CCEEC9C3424B4A403752B648DA105A40CCEEC9C3424B4A403752B648DA105A4097033DD4B6494A40B438639813105A4097033DD4B6494A40
5406	Горячий Ключ	5	50	425	104.900992	104.919785	52.282277000000001	52.270578999999998	0103000020E610000001000000050000004A7D59DAA9395A4000FE2955A2224A404A7D59DAA9395A40DDB419A721244A407D96E7C1DD3A5A40DDB419A721244A407D96E7C1DD3A5A4000FE2955A2224A404A7D59DAA9395A4000FE2955A2224A40
59181	Горохово	5	50	425	104.014049	104.043173	52.814053000000001	52.798952	0103000020E61000000100000005000000A8E2C62DE6005A407289230F44664A40A8E2C62DE6005A40F81A82E332684A407EC4AF58C3025A40F81A82E332684A407EC4AF58C3025A407289230F44664A40A8E2C62DE6005A407289230F44664A40
5890	Горный	5	50	425	104.364302	104.379187	52.399538999999997	52.392066	0103000020E6100000010000000500000083F755B950175A40D0EFFB372F324A4083F755B950175A40FF3C0D1824334A4060048D9944185A40FF3C0D1824334A4060048D9944185A40D0EFFB372F324A4083F755B950175A40D0EFFB372F324A40
3969	Галки	5	50	425	104.439105	104.455365	52.632809999999999	52.613971999999997	0103000020E61000000100000005000000A5A0DB4B1A1C5A4071546EA2964E4A40A5A0DB4B1A1C5A40774A07EBFF504A408EAF3DB3241D5A40774A07EBFF504A408EAF3DB3241D5A4071546EA2964E4A40A5A0DB4B1A1C5A4071546EA2964E4A40
2699	Верхний Кет	5	50	425	104.190883	104.21083400000001	52.973494000000002	52.956983999999999	0103000020E610000001000000050000003197546D370C5A40CB65A3737E7A4A403197546D370C5A40166D8E739B7C4A40A2B8E34D7E0D5A40166D8E739B7C4A40A2B8E34D7E0D5A40CB65A3737E7A4A403197546D370C5A40CB65A3737E7A4A40
5183	Быкова	5	50	425	104.006153	104.029788	52.749240999999998	52.730600000000003	0103000020E610000001000000050000006D718DCF64005A40933A014D845D4A406D718DCF64005A4042E90B21E75F4A400C74ED0BE8015A4042E90B21E75F4A400C74ED0BE8015A40933A014D845D4A406D718DCF64005A40933A014D845D4A40
59222	Бухун	5	50	425	104.181468	104.193838	52.900675999999997	52.894140999999998	0103000020E610000001000000050000005051F52B9D0B5A40A181583673724A405051F52B9D0B5A406325E65949734A4036AE7FD7670C5A406325E65949734A4036AE7FD7670C5A40A181583673724A405051F52B9D0B5A40A181583673724A40
4077	Бутырки	5	50	425	104.491692	104.524023	52.571426000000002	52.557845	0103000020E610000001000000050000001CEDB8E1771F5A405A9E077767474A401CEDB8E1771F5A40C40AB77C24494A4084D6C39789215A40C40AB77C24494A4084D6C39789215A405A9E077767474A401CEDB8E1771F5A405A9E077767474A40
5573	Бурдаковка	5	50	425	104.57211	104.594675	52.103440999999997	52.090373	0103000020E61000000100000005000000BBED42739D245A4080B8AB57910B4A40BBED42739D245A406308008E3D0D4A40EC2FBB270F265A406308008E3D0D4A40EC2FBB270F265A4080B8AB57910B4A40BBED42739D245A4080B8AB57910B4A40
4503	Бургаз	5	50	425	104.69301400000001	104.71631600000001	52.549550000000004	52.530510999999997	0103000020E61000000100000005000000E46A64575A2C5A408995D1C8E7434A40E46A64575A2C5A4027C286A757464A408066101FD82D5A4027C286A757464A408066101FD82D5A408995D1C8E7434A40E46A64575A2C5A408995D1C8E7434A40
2346	Большое Голоустное	5	50	425	105.40110199999999	105.420793	52.047296000000003	52.026924999999999	0103000020E610000001000000050000000D17B9A7AB595A40EF38454772034A400D17B9A7AB595A40A69D9ACB0D064A40B058C345EE5A5A40A69D9ACB0D064A40B058C345EE5A5A40EF38454772034A400D17B9A7AB595A40EF38454772034A40
59149	Большая Речка	5	50	425	104.717691	104.758537	51.962021999999997	51.939324999999997	0103000020E610000001000000050000008C683BA6EE2D5A4058A835CD3BF849408C683BA6EE2D5A402904728923FB494095F3C5DE8B305A402904728923FB494095F3C5DE8B305A4058A835CD3BF849408C683BA6EE2D5A4058A835CD3BF84940
2545	Баруй	5	50	425	104.041493	104.063546	52.833843999999999	52.814684999999997	0103000020E61000000100000005000000D48041D2A7025A4058C51B9947684A40D48041D2A7025A40A0FB7266BB6A4A40AAF23D2311045A40A0FB7266BB6A4A40AAF23D2311045A4058C51B9947684A40D48041D2A7025A4058C51B9947684A40
59212	Никулина	5	50	7471	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
59271	Черемшанка	5	50	10	102.25434799999999	102.27220699999999	54.211559999999999	54.201138999999998	0103000020E610000001000000050000006473D53C479059409E7939ECBE194B406473D53C479059402592E865141B4B4081AFE8D66B9159402592E865141B4B4081AFE8D66B9159409E7939ECBE194B406473D53C479059409E7939ECBE194B40
1076	Центральный Хазан	5	50	10	101.841869	101.86955500000001	53.906464	53.88091	0103000020E610000001000000050000000AA1832EE1755940145CACA8C1F04A400AA1832EE17559402C80290307F44A40B1C403CAA67759402C80290307F44A40B1C403CAA6775940145CACA8C1F04A400AA1832EE1755940145CACA8C1F04A40
911	Харайгун	5	50	10	102.217562	102.231082	54.07159	54.061587000000003	0103000020E610000001000000050000008DB62A89EC8D5940EC6D3315E2074B408DB62A89EC8D59403E5C72DC29094B406F2C280CCA8E59403E5C72DC29094B406F2C280CCA8E5940EC6D3315E2074B408DB62A89EC8D5940EC6D3315E2074B40
956	Филипповск	5	50	10	102.313682	102.326133	53.961545000000001	53.940466999999998	0103000020E6100000010000000500000002D6AA5D13945940CEFBFF3861F84A4002D6AA5D13945940F05014E813FB4A405E49F25CDF945940F05014E813FB4A405E49F25CDF945940CEFBFF3861F84A4002D6AA5D13945940CEFBFF3861F84A40
595	Ухтуй	5	50	10	102.068191	102.086974	53.959018	53.944504999999999	0103000020E610000001000000050000006BB8C83D5D84594049F4328AE5F84A406BB8C83D5D8459403E23111AC1FA4A408C6665FB908559403E23111AC1FA4A408C6665FB9085594049F4328AE5F84A406BB8C83D5D84594049F4328AE5F84A40
465	Услон	5	50	10	101.95222699999999	101.987387	53.943959999999997	53.921790999999999	0103000020E6100000010000000500000090D78349F17C5940A25F5B3FFDF54A4090D78349F17C5940B75D68AED3F84A40B75F3E59317F5940B75D68AED3F84A40B75F3E59317F5940A25F5B3FFDF54A4090D78349F17C5940A25F5B3FFDF54A40
32211	Сологубово	5	50	10	101.729418	101.756287	53.819253000000003	53.807281000000003	0103000020E6100000010000000500000047C7D5C8AE6E594052D7DAFB54E74A4047C7D5C8AE6E594030134548DDE84A40F5D896016770594030134548DDE84A40F5D896016770594052D7DAFB54E74A4047C7D5C8AE6E594052D7DAFB54E74A40
828	Саянск	5	50	10	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
552	Самара	5	50	10	101.995723	102.028153	53.856572999999997	53.843542999999997	0103000020E610000001000000050000000038F6ECB97F594086E28E37F9EB4A400038F6ECB97F59407CD11E2FA4ED4A4032923D42CD8159407CD11E2FA4ED4A4032923D42CD81594086E28E37F9EB4A400038F6ECB97F594086E28E37F9EB4A40
12	Перевоз	5	50	10	102.02493699999999	102.056746	54.117508000000001	54.091248999999998	0103000020E6100000010000000500000076DD5B91988159407765170CAE0B4B4076DD5B91988159405A828C800A0F4B40728BF9B9A18359405A828C800A0F4B40728BF9B9A18359407765170CAE0B4B4076DD5B91988159407765170CAE0B4B40
678	Норы	5	50	10	102.122979	102.13328199999999	53.967489	53.955908999999998	0103000020E6100000010000000500000011C64FE3DE875940DD79E2395BFA4A4011C64FE3DE875940B01EF7ADD6FB4A404FC939B187885940B01EF7ADD6FB4A404FC939B187885940DD79E2395BFA4A4011C64FE3DE875940DD79E2395BFA4A40
338	Новолетники	5	50	10	101.82886999999999	101.862872	53.626499000000003	53.612907	0103000020E61000000100000005000000ACA8C1340C755940A73E90BC73CE4A40ACA8C1340C75594005FD851E31D04A4095287B4B3977594005FD851E31D04A4095287B4B39775940A73E90BC73CE4A40ACA8C1340C755940A73E90BC73CE4A40
806	Мордино	5	50	10	102.077066	102.090639	53.986859000000003	53.974764999999998	0103000020E610000001000000050000008C683BA6EE84594089247A19C5FC4A408C683BA6EE845940B3614D6551FE4A407F2F8507CD855940B3614D6551FE4A407F2F8507CD85594089247A19C5FC4A408C683BA6EE84594089247A19C5FC4A40
202	Масляногорск	5	50	10	101.673067	101.735086	53.589466000000002	53.555481	0103000020E6100000010000000500000014419C87136B594052465C001AC74A4014419C87136B59404E0D349F73CB4A40D66F26A60B6F59404E0D349F73CB4A40D66F26A60B6F594052465C001AC74A4014419C87136B594052465C001AC74A40
32420	Кимильтей	5	50	10	101.945409	102.00778800000001	54.146023	54.118996000000003	0103000020E610000001000000050000000516C094817C59406B2DCC423B0F4B400516C094817C59405EBBB4E1B0124B4048533D997F8059405EBBB4E1B0124B4048533D997F8059406B2DCC423B0F4B400516C094817C59406B2DCC423B0F4B40
32382	Зулумай	5	50	10	101.304362	101.341103	53.699210000000001	53.670361	0103000020E610000001000000050000004A09C1AA7A535940C6C1A563CED54A404A09C1AA7A535940A18499B67FD94A405264ADA1D4555940A18499B67FD94A405264ADA1D4555940C6C1A563CED54A404A09C1AA7A535940C6C1A563CED54A40
1273	Зима	5	50	10	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
835	Глинки	5	50	10	102.240128	102.271057	53.867570000000001	53.851708000000002	0103000020E61000000100000005000000A6B6D4415E8F5940ECDE8AC404ED4A40A6B6D4415E8F5940D07EA4880CEF4A40859675FF58915940D07EA4880CEF4A40859675FF58915940ECDE8AC404ED4A40A6B6D4415E8F5940ECDE8AC404ED4A40
303	Верхнеокинский	5	50	10	101.313552	101.330305	53.471871999999998	53.460379000000003	0103000020E610000001000000050000001B66683C11545940F261F6B2EDBA4A401B66683C11545940F5F23B4D66BC4A40232D95B723555940F5F23B4D66BC4A40232D95B723555940F261F6B2EDBA4A401B66683C11545940F261F6B2EDBA4A40
32257	Буря	5	50	10	102.271084	102.317114	54.281498999999997	54.267378000000001	0103000020E61000000100000005000000029EB47059915940BFD53A7139224B40029EB47059915940A86DC32808244B40A4C684984B945940A86DC32808244B40A4C684984B945940BFD53A7139224B40029EB47059915940BFD53A7139224B40
59283	Большеворонежский	5	50	10	102.439258	102.44913	53.952495999999996	53.933782999999998	0103000020E61000000100000005000000682096CD1C9C5940C7478B3386F74A40682096CD1C9C594010C99063EBF94A40C269C18BBE9C594010C99063EBF94A40C269C18BBE9C5940C7478B3386F74A40682096CD1C9C5940C7478B3386F74A40
32132	Батама	5	50	10	101.60616899999999	101.643458	53.881307999999997	53.864325999999998	0103000020E6100000010000000500000056B60F79CB6659408F8AFF3BA2EE4A4056B60F79CB66594001DA56B3CEF04A405F96766A2E69594001DA56B3CEF04A405F96766A2E6959408F8AFF3BA2EE4A4056B60F79CB6659408F8AFF3BA2EE4A40
32169	Басалаевка	5	50	10	101.530917	101.566616	53.791268000000002	53.777850999999998	0103000020E61000000100000005000000FDF84B8BFA61594098141F9F90E34A40FDF84B8BFA615940882F134548E54A40FB58C16F43645940882F134548E54A40FB58C16F4364594098141F9F90E34A40FDF84B8BFA61594098141F9F90E34A40
32486	Баргадай (Кяхта, Обуздина)	5	50	10	102.043676	102.071577	54.224569000000002	54.194139	0103000020E61000000100000005000000B0E76B96CB82594067F0F78BD9184B40B0E76B96CB82594004594FADBE1C4B405589B2B79484594004594FADBE1C4B405589B2B79484594067F0F78BD9184B40B0E76B96CB82594067F0F78BD9184B40
30900	Щербакова	5	50	350	102.04814	102.068963	53.419517999999997	53.406562000000001	0103000020E610000001000000050000004968CBB914835940EFE53E390AB44A404968CBB914835940AA0A0DC4B2B54A409468C9E369845940AA0A0DC4B2B54A409468C9E369845940EFE53E390AB44A404968CBB914835940EFE53E390AB44A40
31329	Черемшанка	5	50	350	101.642865	101.659789	53.295062000000001	53.276446999999997	0103000020E610000001000000050000008EAF3DB324695940E509849D62A34A408EAF3DB3246959406C257497C4A54A40AD50A4FB396A59406C257497C4A54A40AD50A4FB396A5940E509849D62A34A408EAF3DB324695940E509849D62A34A40
31137	Чаданова	5	50	350	102.040424	102.067894	53.370381999999999	53.363596000000001	0103000020E610000001000000050000004E7E8B4E968259406C7A50508AAE4A404E7E8B4E96825940778368AD68AF4A400E66136058845940778368AD68AF4A400E661360588459406C7A50508AAE4A404E7E8B4E968259406C7A50508AAE4A40
31441	Хор-Тагна	5	50	350	101.522401	101.576156	53.429155000000002	53.410223000000002	0103000020E6100000010000000500000074999A046F6159409488F02F82B44A4074999A046F6159401BF5108DEEB64A403A596ABDDF6459401BF5108DEEB64A403A596ABDDF6459409488F02F82B44A4074999A046F6159409488F02F82B44A40
30690	Холмогой	5	50	350	102.280939	102.334613	53.500552999999996	53.482922000000002	0103000020E61000000100000005000000F14A92E7FA9159406C425A63D0BD4A40F14A92E7FA9159401475E61E12C04A4041F4A44C6A9559401475E61E12C04A4041F4A44C6A9559406C425A63D0BD4A40F14A92E7FA9159406C425A63D0BD4A40
31720	Ханжиново	5	50	350	102.208732	102.254465	53.627353999999997	53.609926000000002	0103000020E610000001000000050000003C6876DD5B8D5940747D1F0E12CE4A403C6876DD5B8D5940E481C8224DD04A40813E912749905940E481C8224DD04A40813E912749905940747D1F0E12CE4A403C6876DD5B8D5940747D1F0E12CE4A40
59279	Халты	5	50	350	102.11705000000001	102.129941	53.353326000000003	53.334800999999999	0103000020E61000000100000005000000CC7F48BF7D87594084D558C2DAAA4A40CC7F48BF7D875940CB694FC939AD4A40365A0EF450885940CB694FC939AD4A40365A0EF45088594084D558C2DAAA4A40CC7F48BF7D87594084D558C2DAAA4A40
31811	Тыреть 2-я	5	50	350	102.31278399999999	102.326241	53.730958999999999	53.709086999999997	0103000020E6100000010000000500000092AD2EA7049459406682E15CC3DA4A4092AD2EA704945940C2DB831090DD4A405167EE21E1945940C2DB831090DD4A405167EE21E19459406682E15CC3DA4A4092AD2EA7049459406682E15CC3DA4A40
1871	Тыреть 1-я	5	50	350	102.295024	102.33712800000001	53.685763999999999	53.654972999999998	0103000020E610000001000000050000003FE257ACE1925940AA61BF27D6D34A403FE257ACE19259401763601DC7D74A4038A45181939559401763601DC7D74A4038A4518193955940AA61BF27D6D34A403FE257ACE1925940AA61BF27D6D34A40
59132	Тыреть	5	50	350	102.295024	102.33712800000001	53.685763999999999	53.654972999999998	0103000020E610000001000000050000003FE257ACE1925940AA61BF27D6D34A403FE257ACE19259401763601DC7D74A4038A45181939559401763601DC7D74A4038A4518193955940AA61BF27D6D34A403FE257ACE1925940AA61BF27D6D34A40
30803	Троицк	5	50	350	102.133399	102.178594	53.471769999999999	53.453783999999999	0103000020E610000001000000050000006C94F59B898859405AB9179815BA4A406C94F59B89885940F19D98F562BC4A40C25087156E8B5940F19D98F562BC4A40C25087156E8B59405AB9179815BA4A406C94F59B898859405AB9179815BA4A40
31499	Тагна	5	50	350	101.860823	101.900026	53.599299000000002	53.576326000000002	0103000020E6100000010000000500000041295AB917775940D1EAE40CC5C94A4041295AB91777594044C362D4B5CC4A402EE3A6069A79594044C362D4B5CC4A402EE3A6069A795940D1EAE40CC5C94A4041295AB917775940D1EAE40CC5C94A40
59320	Среднепихтинский	5	50	350	101.660436	101.683864	53.383591000000003	53.378349	0103000020E6100000010000000500000078465B95446A5940B6BC72BD6DB04A4078465B95446A59401D05888219B14A405ABA826DC46B59401D05888219B14A405ABA826DC46B5940B6BC72BD6DB04A4078465B95446A5940B6BC72BD6DB04A40
30732	Сорты	5	50	350	102.210385	102.247449	53.48357	53.470070999999997	0103000020E610000001000000050000006AA4A5F2768D594025E659492BBC4A406AA4A5F2768D5940D2A92B9FE5BD4A40639B5434D68F5940D2A92B9FE5BD4A40639B5434D68F594025E659492BBC4A406AA4A5F2768D594025E659492BBC4A40
30636	Сенная Падь	5	50	350	102.322755	102.341126	53.565910000000002	53.555641000000001	0103000020E61000000100000005000000B6679604A89459408BA8893E1FC74A40B6679604A89459405C3D27BD6FC84A402E742502D59559405C3D27BD6FC84A402E742502D59559408BA8893E1FC74A40B6679604A89459408BA8893E1FC74A40
32036	Семеновское	5	50	350	102.487138	102.517366	53.745061999999997	53.723917	0103000020E61000000100000005000000E3A8DC442D9F59405C02F04FA9DC4A40E3A8DC442D9F594005BF0D315EDF4A40FD8348861CA1594005BF0D315EDF4A40FD8348861CA159405C02F04FA9DC4A40E3A8DC442D9F59405C02F04FA9DC4A40
30586	Романова	5	50	350	102.357771	102.378514	53.516627999999997	53.507558000000003	0103000020E61000000100000005000000431D56B8E59659405E6919A9F7C04A40431D56B8E59659405419C6DD20C24A4000C5C892399859405419C6DD20C24A4000C5C892399859405E6919A9F7C04A40431D56B8E59659405E6919A9F7C04A40
30996	Романенкина	5	50	350	102.346992	102.360242	53.401665999999999	53.389541999999999	0103000020E6100000010000000500000050FEEE1D359659408F352383DCB14A4050FEEE1D3596594023F59ECA69B34A40522976340E97594023F59ECA69B34A40522976340E9759408F352383DCB14A4050FEEE1D359659408F352383DCB14A40
59277	Ремезовский	5	50	350	102.528344	102.54145	53.404032999999998	53.385159999999999	0103000020E610000001000000050000006C425A63D0A159401ADD41EC4CB14A406C425A63D0A159409CC0745AB7B34A40D49AE61DA7A259409CC0745AB7B34A40D49AE61DA7A259401ADD41EC4CB14A406C425A63D0A159401ADD41EC4CB14A40
30489	Новочеремхово	5	50	350	102.453191	102.474121	53.413066999999998	53.392758000000001	0103000020E61000000100000005000000DCF5D214019D5940069FE6E445B24A40DCF5D214019D594046072461DFB44A4032569BFF579E594046072461DFB44A4032569BFF579E5940069FE6E445B24A40DCF5D214019D5940069FE6E445B24A40
59207	Николаевский	5	50	350	102.13251	102.14891299999999	53.645564	53.626494000000001	0103000020E610000001000000050000002619390B7B885940F39194F430D04A402619390B7B885940CBBC55D7A1D24A40C03C64CA87895940CBBC55D7A1D24A40C03C64CA87895940F39194F430D04A402619390B7B885940F39194F430D04A40
1762	Муруй	5	50	350	102.00581200000001	102.02455	53.354933000000003	53.336629000000002	0103000020E61000000100000005000000297B4B395F8059404EF1B8A816AB4A40297B4B395F805940B6A2CD716EAD4A407AC7293A92815940B6A2CD716EAD4A407AC7293A928159404EF1B8A816AB4A40297B4B395F8059404EF1B8A816AB4A40
31041	Мойган	5	50	350	102.220725	102.253468	53.347048000000001	53.334009999999999	0103000020E61000000100000005000000371AC05B208E5940BB44F5D6C0AA4A40371AC05B208E59403412A1116CAC4A4048A5D8D1389059403412A1116CAC4A4048A5D8D138905940BB44F5D6C0AA4A40371AC05B208E5940BB44F5D6C0AA4A40
31589	Моисеевка	5	50	350	101.98929200000001	102.023571	53.535105999999999	53.517645999999999	0103000020E61000000100000005000000728C648F507F5940DE73603942C24A40728C648F507F59405AF2785A7EC44A409488F02F828159405AF2785A7EC44A409488F02F82815940DE73603942C24A40728C648F507F5940DE73603942C24A40
30430	Минеева	5	50	350	102.489473	102.501583	53.514164999999998	53.505398999999997	0103000020E610000001000000050000009AD18F86539F59402E3718EAB0C04A409AD18F86539F5940B9DFA128D0C14A40B14E95EF19A05940B9DFA128D0C14A40B14E95EF19A059402E3718EAB0C04A409AD18F86539F59402E3718EAB0C04A40
59268	Мейеровка	5	50	350	102.392815	102.423582	53.715353999999998	53.706529000000003	0103000020E61000000100000005000000359886E1239959407A56D28A6FDA4A40359886E123995940098849B890DB4A40274BADF71B9B5940098849B890DB4A40274BADF71B9B59407A56D28A6FDA4A40359886E1239959407A56D28A6FDA4A40
28658	Красное Поле (Тарасова)	5	50	350	102.56243499999999	102.582611	53.627215	53.614269	0103000020E610000001000000050000000CC85EEFFEA359402BF9D85DA0CE4A400CC85EEFFEA35940C347C49448D04A408DD2A57F49A55940C347C49448D04A408DD2A57F49A559402BF9D85DA0CE4A400CC85EEFFEA359402BF9D85DA0CE4A40
1962	Корсунгай	5	50	350	102.46477899999999	102.475109	53.724347999999999	53.719147999999997	0103000020E6100000010000000500000086376BF0BE9D5940ED7DAA0A0DDC4A4086376BF0BE9D594025766D6FB7DC4A404242942F689E594025766D6FB7DC4A404242942F689E5940ED7DAA0A0DDC4A4086376BF0BE9D5940ED7DAA0A0DDC4A40
30390	Илганское	5	50	350	102.42113000000001	102.440264	53.561396000000002	53.551403999999998	0103000020E6100000010000000500000054573ECBF39A59401971016894C64A4054573ECBF39A5940780DFAD2DBC74A40CB660E492D9C5940780DFAD2DBC74A40CB660E492D9C59401971016894C64A4054573ECBF39A59401971016894C64A40
30085	Залари	5	50	350	102.467016	102.53517100000001	53.577737999999997	53.534320000000001	0103000020E610000001000000050000005CAD1397E39D5940A3CC069964C44A405CAD1397E39D594006D49B51F3C94A4021B1DD3D40A2594006D49B51F3C94A4021B1DD3D40A25940A3CC069964C44A405CAD1397E39D5940A3CC069964C44A40
30851	Заблагар	5	50	350	102.098482	102.123706	53.445306000000002	53.428871000000001	0103000020E61000000100000005000000A94F72874D865940F699B33EE5B64A40A94F72874D865940365B79C9FFB84A406A1492CCEA875940365B79C9FFB84A406A1492CCEA875940F699B33EE5B64A40A94F72874D865940F699B33EE5B64A40
31289	Жизневка	5	50	350	102.125647	102.14019999999999	53.310355000000001	53.299981000000002	0103000020E61000000100000005000000CBF5B6990A885940F03504C765A64A40CBF5B6990A88594036936FB6B9A74A408CB96B09F988594036936FB6B9A74A408CB96B09F9885940F03504C765A64A40CBF5B6990A885940F03504C765A64A40
30953	Дмитриевка	5	50	350	102.023724	102.047808	53.388640000000002	53.379241	0103000020E610000001000000050000005708ABB184815940B32616F88AB04A405708ABB1848159406FF59CF4BEB14A402E1F49490F8359406FF59CF4BEB14A402E1F49490F835940B32616F88AB04A405708ABB184815940B32616F88AB04A40
2351	Владимир	5	50	350	102.638845	102.669253	53.493557000000003	53.457323000000002	0103000020E61000000100000005000000A48D23D6E2A85940B45A608F89BA4A40A48D23D6E2A859401FDB32E02CBF4A40FEEF880AD5AA59401FDB32E02CBF4A40FEEF880AD5AA5940B45A608F89BA4A40A48D23D6E2A85940B45A608F89BA4A40
31783	Веренка	5	50	350	102.20389	102.234118	53.695200999999997	53.672894999999997	0103000020E61000000100000005000000D07EA4880C8D59402A52616C21D64A40D07EA4880C8D5940C092AB58FCD84A40EA5910CAFB8E5940C092AB58FCD84A40EA5910CAFB8E59402A52616C21D64A40D07EA4880C8D59402A52616C21D64A40
31645	Большая Заимка	5	50	350	102.129204	102.166556	53.556480999999998	53.539816000000002	0103000020E61000000100000005000000CBA0DAE044885940C4EDD0B018C54A40CBA0DAE04488594035ECF7C43AC74A40F73C7FDAA88A594035ECF7C43AC74A40F73C7FDAA88A5940C4EDD0B018C54A40CBA0DAE044885940C4EDD0B018C54A40
1841	Благодатный	5	50	350	101.94984700000001	101.973966	53.511938000000001	53.498223000000003	0103000020E610000001000000050000000A4D124BCA7C5940B98E71C5C5BF4A400A4D124BCA7C594032CA332F87C14A409F5A7D75557E594032CA332F87C14A409F5A7D75557E5940B98E71C5C5BF4A400A4D124BCA7C5940B98E71C5C5BF4A40
30343	Бажир	5	50	350	102.535782	102.555706	53.597541	53.583078	0103000020E6100000010000000500000045F295404AA259403082C64CA2CA4A4045F295404AA25940738236397CCC4A40390CE6AF90A35940738236397CCC4A40390CE6AF90A359403082C64CA2CA4A4045F295404AA259403082C64CA2CA4A40
31225	Бабагай	5	50	350	102.083597	102.117041	53.279778999999998	53.262067999999999	0103000020E61000000100000005000000CC423BA75985594000AAB8718BA14A40CC423BA759855940C58D5BCCCFA34A40A2D288997D875940C58D5BCCCFA34A40A2D288997D87594000AAB8718BA14A40CC423BA75985594000AAB8718BA14A40
59289	с.Луконово	5	50	426	103.970894	106.832594	55.872596999999999	53.762998000000003	0103000020E610000001000000050000007D78962023FE5940EB7420EBA9E14A407D78962023FE59403ACB2C42B1EF4B402236583849B55A403ACB2C42B1EF4B402236583849B55A40EB7420EBA9E14A407D78962023FE5940EB7420EBA9E14A40
52562	Якимовка	5	50	426	105.35545	105.37159200000001	54.826867999999997	54.819834	0103000020E610000001000000050000003F575BB1BF565A400E130D52F0684B403F575BB1BF565A40F10D85CFD6694B4023DDCF29C8575A40F10D85CFD6694B4023DDCF29C8575A400E130D52F0684B403F575BB1BF565A400E130D52F0684B40
52558	Чикан	5	50	426	105.638069	105.663724	54.908562000000003	54.897396999999998	0103000020E61000000100000005000000DAE55B1FD6685A40A643A7E7DD724B40DAE55B1FD6685A40B63176C24B744B4080643A747A6A5A40B63176C24B744B4080643A747A6A5A40A643A7E7DD724B40DAE55B1FD6685A40A643A7E7DD724B40
52585	Усть-Илга	5	50	426	105.066075	105.093582	55.013379	55.003445999999997	0103000020E610000001000000050000005305A3923A445A40A8A624EB70804B405305A3923A445A4002BA2F67B6814B40A25F5B3FFD455A4002BA2F67B6814B40A25F5B3FFD455A40A8A624EB70804B405305A3923A445A40A8A624EB70804B40
52574	Тыпта	5	50	426	104.51042200000001	104.544415	54.585773000000003	54.569648000000001	0103000020E610000001000000050000002C4A09C1AA205A40AC1DC539EA484B402C4A09C1AA205A409EF0129CFA4A4B40EB1C03B2D7225A409EF0129CFA4A4B40EB1C03B2D7225A40AC1DC539EA484B402C4A09C1AA205A40AC1DC539EA484B40
52564	Тутура	5	50	426	105.220496	105.23813	54.788834000000001	54.780943000000001	0103000020E610000001000000050000008639419B1C4E5A402385B2F0F5634B408639419B1C4E5A4087FC3383F8644B40938C9C853D4F5A4087FC3383F8644B40938C9C853D4F5A402385B2F0F5634B408639419B1C4E5A402385B2F0F5634B40
59301	Тимошино	5	50	426	104.714573	104.732423	54.401276000000003	54.383865999999998	0103000020E61000000100000005000000B2666490BB2D5A40EE05668522314B40B2666490BB2D5A40B95510035D334B40A5F5B704E02E5A40B95510035D334B40A5F5B704E02E5A40EE05668522314B40B2666490BB2D5A40EE05668522314B40
59267	Рудовка	5	50	426	105.195576	105.21701899999999	54.761237999999999	54.740380999999999	0103000020E610000001000000050000007BF83251844C5A4036CAFACDC45E4B407BF83251844C5A40793C2D3F70614B4014E7A8A3E34D5A40793C2D3F70614B4014E7A8A3E34D5A4036CAFACDC45E4B407BF83251844C5A4036CAFACDC45E4B40
52582	Пономарёва	5	50	426	105.21848300000001	105.233413	54.663848999999999	54.654631000000002	0103000020E61000000100000005000000D9EE1EA0FB4D5A4051F9D7F2CA534B40D9EE1EA0FB4D5A40BC3D0801F9544B40855D143DF04E5A40BC3D0801F9544B40855D143DF04E5A4051F9D7F2CA534B40D9EE1EA0FB4D5A4051F9D7F2CA534B40
52584	Петрово	5	50	426	105.219067	105.231078	54.507913000000002	54.483759999999997	0103000020E6100000010000000500000080289831054E5A40758E01D9EB3D4B4080289831054E5A404C1B0E4B03414B40CE3461FBC94E5A404C1B0E4B03414B40CE3461FBC94E5A40758E01D9EB3D4B4080289831054E5A40758E01D9EB3D4B40
52568	Нижняя Слобода	5	50	426	104.901729	104.947821	54.744861	54.730727999999999	0103000020E61000000100000005000000B5368DEDB5395A40C022BF7E885D4B40B5368DEDB5395A406E88F19A575F4B40925D6919A93C5A406E88F19A575F4B40925D6919A93C5A40C022BF7E885D4B40B5368DEDB5395A40C022BF7E885D4B40
52554	Коношаново	5	50	426	105.472949	105.479956	55.362065999999999	55.350709000000002	0103000020E6100000010000000500000042EBE1CB445E5A40D9B45208E4AC4B4042EBE1CB445E5A402C7FBE2D58AE4B4037E15E99B75E5A402C7FBE2D58AE4B4037E15E99B75E5A40D9B45208E4AC4B4042EBE1CB445E5A40D9B45208E4AC4B40
52577	Качень	5	50	426	104.765535	104.78640300000001	54.618181	54.602116000000002	0103000020E61000000100000005000000603C8386FE305A40FD321823124D4B40603C8386FE305A401901158E204F4B407C9E3F6D54325A401901158E204F4B407C9E3F6D54325A40FD321823124D4B40603C8386FE305A40FD321823124D4B40
52233	Знаменка	5	50	426	104.81234600000001	104.855214	54.707436999999999	54.684392000000003	0103000020E6100000010000000500000055C2137AFD335A4070D234289A574B4055C2137AFD335A407C7DAD4B8D5A4B40354580D3BB365A407C7DAD4B8D5A4B40354580D3BB365A4070D234289A574B4055C2137AFD335A4070D234289A574B40
52587	Жигалово	5	50	426	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
52570	Дальняя Закора	5	50	426	104.71275	104.765382	54.666978	54.648125	0103000020E61000000100000005000000560E2DB29D2D5A40295C8FC2F5524B40560E2DB29D2D5A406493FC885F554B409DBCC804FC305A406493FC885F554B409DBCC804FC305A40295C8FC2F5524B40560E2DB29D2D5A40295C8FC2F5524B40
52580	Головновка	5	50	426	105.216399	105.228329	54.777183000000001	54.763388999999997	0103000020E61000000100000005000000C6F8307BD94D5A40259012BBB6614B40C6F8307BD94D5A40EB0088BB7A634B409EEE3CF19C4E5A40EB0088BB7A634B409EEE3CF19C4E5A40259012BBB6614B40C6F8307BD94D5A40259012BBB6614B40
52583	Воробьева	5	50	426	105.20914999999999	105.23411400000001	54.582282999999997	54.577685000000002	0103000020E61000000100000005000000567DAEB6624D5A40E4310395F1494B40567DAEB6624D5A402502D53F884A4B404A6249B9FB4E5A402502D53F884A4B404A6249B9FB4E5A40E4310395F1494B40567DAEB6624D5A40E4310395F1494B40
54497	жилой район Энергетик	5	50	402	101.684206	101.816007	56.338569	56.265292000000002	0103000020E61000000100000005000000876EF607CA6B5940FAF19716F5214C40876EF607CA6B59403F389F3A562B4C40A7936C75397459403F389F3A562B4C40A7936C7539745940FAF19716F5214C40876EF607CA6B5940FAF19716F5214C40
2197	Шумилово	5	50	402	103.000345	103.02354	55.954667000000001	55.941021999999997	0103000020E61000000100000005000000E5ED08A705C059408368AD6873F84B40E5ED08A705C0594004C93B8732FA4B407689EAAD81C1594004C93B8732FA4B407689EAAD81C159408368AD6873F84B40E5ED08A705C059408368AD6873F84B40
23799	Худобок	5	50	402	100.85150299999999	100.88529800000001	55.478005000000003	55.461047999999998	0103000020E61000000100000005000000895C70067F3659406FF1F09E03BB4B40895C70067F365940892991442FBD4B40B64DF1B8A8385940892991442FBD4B40B64DF1B8A83859406FF1F09E03BB4B40895C70067F3659406FF1F09E03BB4B40
23515	Тэмь	5	50	402	100.71937	100.7457	55.341526000000002	55.324739999999998	0103000020E610000001000000050000004EEE77280A2E5940FDD98F1491A94B404EEE77280A2E5940EA5DBC1FB7AB4B4024287E8CB92F5940EA5DBC1FB7AB4B4024287E8CB92F5940FDD98F1491A94B404EEE77280A2E5940FDD98F1491A94B40
25189	Турма	5	50	402	100.86262499999999	100.913855	56.201273999999998	56.184936	0103000020E6100000010000000500000091ED7C3F3537594031ED9BFBAB174C4091ED7C3F353759407EC4AF58C3194C404F92AE997C3A59407EC4AF58C3194C404F92AE997C3A594031ED9BFBAB174C4091ED7C3F3537594031ED9BFBAB174C40
24845	Тарма	5	50	402	101.278437	101.30653599999999	55.987758999999997	55.974865999999999	0103000020E61000000100000005000000C43F6CE9D1515940BDFDB968C8FC4B40C43F6CE9D151594032AA0CE36EFE4B40FCC22B499E53594032AA0CE36EFE4B40FCC22B499E535940BDFDB968C8FC4B40C43F6CE9D1515940BDFDB968C8FC4B40
23644	Тангуй	5	50	402	101.01239200000001	101.052187	55.389591000000003	55.371259999999999	0103000020E61000000100000005000000DAAED007CB4059400F289B7285AF4B40DAAED007CB40594071E82D1EDEB14B40B09124085743594071E82D1EDEB14B40B0912408574359400F289B7285AF4B40DAAED007CB4059400F289B7285AF4B40
23890	Сосновый	5	50	402	101.086619	101.09755199999999	55.548619000000002	55.539496999999997	0103000020E61000000100000005000000950D6B2A8B45594022A5D93C0EC54B40950D6B2A8B4559406C7BBB2539C64B40336ABE4A3E4659406C7BBB2539C64B40336ABE4A3E46594022A5D93C0EC54B40950D6B2A8B45594022A5D93C0EC54B40
23350	Прибрежный	5	50	402	100.66619	100.722667	55.218604999999997	55.196576999999998	0103000020E6100000010000000500000006BB61DBA22A5940A912656F29994B4006BB61DBA22A5940FCDEA63FFB9B4B4080B9162D402E5940FCDEA63FFB9B4B4080B9162D402E5940A912656F29994B4006BB61DBA22A5940A912656F29994B40
23848	Покосное	5	50	402	101.024052	101.07126700000001	55.537194999999997	55.506999	0103000020E61000000100000005000000D15966118A415940670DDE57E5C04B40D15966118A415940904946CEC2C44B402E9276A38F445940904946CEC2C44B402E9276A38F445940670DDE57E5C04B40D15966118A415940670DDE57E5C04B40
23273	Новое Приречье	5	50	402	101.052627	101.070126	55.083998000000001	55.075561	0103000020E61000000100000005000000BEF8A23D5E43594031ED9BFBAB894B40BEF8A23D5E435940F7764B72C08A4B405B26C3F17C445940F7764B72C08A4B405B26C3F17C44594031ED9BFBAB894B40BEF8A23D5E43594031ED9BFBAB894B40
24793	Новодолоново	5	50	402	101.546853	101.562709	55.852651999999999	55.845430999999998	0103000020E610000001000000050000000CAEB9A3FF6259402503401537EC4B400CAEB9A3FF6259403B6F63B323ED4B408D0A9C6C036459403B6F63B323ED4B408D0A9C6C036459402503401537EC4B400CAEB9A3FF6259402503401537EC4B40
25571	Мамырь	5	50	402	102.648224	102.66660299999999	56.587575000000001	56.575498000000003	0103000020E61000000100000005000000DE1E84807CA95940EB7420EBA9494C40DE1E84807CA959403E7958A8354B4C40971AA19FA9AA59403E7958A8354B4C40971AA19FA9AA5940EB7420EBA9494C40DE1E84807CA95940EB7420EBA9494C40
23482	Луговой	5	50	402	100.478083	100.494342	55.257657999999999	55.248524000000003	0103000020E61000000100000005000000827170E9981E5940B4226AA2CF9F4B40827170E9981E5940C1C6F5EFFAA04B4083C2A04CA31F5940C1C6F5EFFAA04B4083C2A04CA31F5940B4226AA2CF9F4B40827170E9981E5940B4226AA2CF9F4B40
24661	Леонова	5	50	402	101.48959499999999	101.532229	55.579317000000003	55.560316	0103000020E610000001000000050000003F524486555F594078B6476FB8C74B403F524486555F59402882380F27CA4B40E63E390A106259402882380F27CA4B40E63E390A1062594078B6476FB8C74B403F524486555F594078B6476FB8C74B40
24598	Кумейка	5	50	402	101.766734	101.784018	55.543332999999997	55.524661000000002	0103000020E61000000100000005000000CDAE7B2B127159404B3E761728C34B40CDAE7B2B1271594035EB8CEF8BC54B406C5ED5592D72594035EB8CEF8BC54B406C5ED5592D7259404B3E761728C34B40CDAE7B2B127159404B3E761728C34B40
24897	Кузнецовка	5	50	402	101.226631	101.265124	56.093541000000002	56.080742999999998	0103000020E61000000100000005000000A0504F1F814E5940C23060C9550A4C40A0504F1F814E5940E6EAC726F90B4C409F58A7CAF7505940E6EAC726F90B4C409F58A7CAF7505940C23060C9550A4C40A0504F1F814E5940C23060C9550A4C40
24517	Куватка	5	50	402	101.94568700000001	101.977829	55.509492000000002	55.494140000000002	0103000020E610000001000000050000002750C422867C59409ED2C1FA3FBF4B402750C422867C59406DC9AA0837C14B40250516C0947E59406DC9AA0837C14B40250516C0947E59409ED2C1FA3FBF4B402750C422867C59409ED2C1FA3FBF4B40
23947	Кобь	5	50	402	101.345972	101.381473	55.444327999999999	55.425654999999999	0103000020E610000001000000050000003B55BE67245659407F30F0DC7BB64B403B55BE67245659403A596ABDDFB84B40A6D3BA0D6A5859403A596ABDDFB84B40A6D3BA0D6A5859407F30F0DC7BB64B403B55BE67245659407F30F0DC7BB64B40
25211	Кобляково	5	50	402	101.426883	101.442909	56.592996999999997	56.581909000000003	0103000020E61000000100000005000000FA0D130D525B5940C11F7EFE7B4A4C40FA0D130D525B594024D06053E74B4C40A986FD9E585C594024D06053E74B4C40A986FD9E585C5940C11F7EFE7B4A4C40FA0D130D525B5940C11F7EFE7B4A4C40
24534	Ключи-Булак	5	50	402	101.666715	101.71436199999999	55.533026999999997	55.511051999999999	0103000020E610000001000000050000002B306475AB6A59401747E5266AC14B402B306475AB6A594047718E3A3AC44B4054E0641BB86D594047718E3A3AC44B4054E0641BB86D59401747E5266AC14B402B306475AB6A59401747E5266AC14B40
25510	Кежемский	5	50	402	102.41633299999999	102.477463	56.569333999999998	56.544699000000001	0103000020E61000000100000005000000B7CF2A33A59A5940FB9463B2B8454C40B7CF2A33A59A59401C40BFEFDF484C403483F8C08E9E59401C40BFEFDF484C403483F8C08E9E5940FB9463B2B8454C40B7CF2A33A59A5940FB9463B2B8454C40
23435	Кардой	5	50	402	100.561976	100.592519	55.219802000000001	55.209144000000002	0103000020E61000000100000005000000C3482F6AF7235940CB13083BC59A4B40C3482F6AF723594036CCD078229C4B408DD0CFD4EB25594036CCD078229C4B408DD0CFD4EB255940CB13083BC59A4B40C3482F6AF7235940CB13083BC59A4B40
24697	Калтук	5	50	402	101.71843200000001	101.75275600000001	55.690187000000002	55.665888000000002	0103000020E61000000100000005000000981936CAFA6D5940416667D13BD54B40981936CAFA6D5940EB8F300C58D84B408A7780272D705940EB8F300C58D84B408A7780272D705940416667D13BD54B40981936CAFA6D5940416667D13BD54B40
23368	Илир	5	50	402	100.65754800000001	100.69922099999999	55.232180999999997	55.214933000000002	0103000020E6100000010000000500000037E33444152A594064EAAEEC829B4B4037E33444152A594054E0641BB89D4B404AEB6F09C02C594054E0641BB89D4B404AEB6F09C02C594064EAAEEC829B4B4037E33444152A594064EAAEEC829B4B40
25439	Зяба	5	50	402	102.117733	102.141583	56.383603000000001	56.374600999999998	0103000020E610000001000000050000003D2AFEEF888759404206F2ECF22F4C403D2AFEEF88875940E1D231E719314C40DAAA24B20F895940E1D231E719314C40DAAA24B20F8959404206F2ECF22F4C403D2AFEEF888759404206F2ECF22F4C40
23726	Зарбь	5	50	402	101.026881	101.039682	55.456412999999998	55.436534999999999	0103000020E6100000010000000500000090F8156BB84159409947FE60E0B74B4090F8156BB8415940103CBEBD6BBA4B405A0F5F268A425940103CBEBD6BBA4B405A0F5F268A4259409947FE60E0B74B4090F8156BB84159409947FE60E0B74B40
25355	Дубынино	5	50	402	101.775187	101.7961	56.614539999999998	56.600186999999998	0103000020E610000001000000050000003352EFA99C715940FF3D78EDD24C4C403352EFA99C715940BB0A293FA94E4C401E166A4DF3725940BB0A293FA94E4C401E166A4DF3725940FF3D78EDD24C4C403352EFA99C715940FF3D78EDD24C4C40
59228	Воронино	5	50	402	100.01459699999999	103.507094	56.883896999999997	54.917395999999997	0103000020E61000000100000005000000A9674128EF00594098BD6C3B6D754B40A9674128EF0059402904728923714C40DC7F643A74E059402904728923714C40DC7F643A74E0594098BD6C3B6D754B40A9674128EF00594098BD6C3B6D754B40
2232	Вихоревка	5	50	402	101.121887	101.218627	56.148318000000003	56.104953000000002	0103000020E61000000100000005000000AFB321FFCC475940FD4E93196F0D4C40AFB321FFCC4759403EB48F15FC124C4072C119FCFD4D59403EB48F15FC124C4072C119FCFD4D5940FD4E93196F0D4C40AFB321FFCC475940FD4E93196F0D4C40
59266	Васильевский	5	50	402	100.01459699999999	103.507094	56.883896999999997	54.917395999999997	0103000020E61000000100000005000000A9674128EF00594098BD6C3B6D754B40A9674128EF0059402904728923714C40DC7F643A74E059402904728923714C40DC7F643A74E0594098BD6C3B6D754B40A9674128EF00594098BD6C3B6D754B40
25350	Бурнинская Вихоря (Бурнинск)	5	50	402	101.589406	101.604822	56.368848	56.357917999999998	0103000020E610000001000000050000003C84F1D3B86559402A53CC41D02D4C403C84F1D3B8655940F6984869362F4C40AF795567B5665940F6984869362F4C40AF795567B56659402A53CC41D02D4C403C84F1D3B86559402A53CC41D02D4C40
2114	Братск	5	50	402	101.36801699999999	101.978359	56.379621	56.081105000000001	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
25487	Боровской	5	50	402	102.159558	102.177381	56.494022999999999	56.484699999999997	0103000020E610000001000000050000002CF4C132368A5940832F4CA60A3E4C402CF4C132368A5940643C4A253C3F4C40A27BD6355A8B5940643C4A253C3F4C40A27BD6355A8B5940832F4CA60A3E4C402CF4C132368A5940832F4CA60A3E4C40
24754	Большеокинское	5	50	402	101.727433	101.759359	55.755540000000003	55.732078000000001	0103000020E61000000100000005000000FF4124438E6E5940800F5EBBB4DD4B40FF4124438E6E5940F168E388B5E04B4017BB7D5699705940F168E388B5E04B4017BB7D5699705940800F5EBBB4DD4B40FF4124438E6E5940800F5EBBB4DD4B40
23584	Барчим	5	50	402	100.78302499999999	100.811609	55.373131999999998	55.364972000000002	0103000020E61000000100000005000000D3BCE3141D32594055FA0967B7AE4B40D3BCE3141D325940A88B14CAC2AF4B40EA08E066F1335940A88B14CAC2AF4B40EA08E066F133594055FA0967B7AE4B40D3BCE3141D32594055FA0967B7AE4B40
23657	Бада	5	50	402	101.145872	101.157856	55.407089999999997	55.389913	0103000020E61000000100000005000000BC5983F75549594083A44FABE8B14B40BC5983F755495940AA436E861BB44B408D5E0D501A4A5940AA436E861BB44B408D5E0D501A4A594083A44FABE8B14B40BC5983F75549594083A44FABE8B14B40
23769	Александровка	5	50	402	100.909139	100.936789	55.429077999999997	55.418281999999998	0103000020E61000000100000005000000292158552F3A5940B340BB438AB54B40292158552F3A59406FB72407ECB64B402A90D959F43B59406FB72407ECB64B402A90D959F43B5940B340BB438AB54B40292158552F3A5940B340BB438AB54B40
59295	д. Баргазово	5	50	441	103.351793	104.724599	53.538595999999998	52.678795000000001	0103000020E610000001000000050000008D7DC9C683D659401BD82AC1E2564A408D7DC9C683D65940D2E0B6B6F0C44A40B7ED7BD45F2E5A40D2E0B6B6F0C44A40B7ED7BD45F2E5A401BD82AC1E2564A408D7DC9C683D659401BD82AC1E2564A40
21949	Шунта	5	50	441	103.809898	103.835815	53.165197999999997	53.153190000000002	0103000020E6100000010000000500000022C66B5ED5F359408109DCBA9B934A4022C66B5ED5F35940ABAE433525954A4066A032FE7DF55940ABAE433525954A4066A032FE7DF559408109DCBA9B934A4022C66B5ED5F359408109DCBA9B934A40
21150	Чилим	5	50	441	104.27418299999999	104.283418	53.118226999999997	53.104011	0103000020E61000000100000005000000A087DA368C115A404EB6813B508D4A40A087DA368C115A408940F50F228F4A404146408523125A408940F50F228F4A404146408523125A404EB6813B508D4A40A087DA368C115A404EB6813B508D4A40
21857	Хохорск	5	50	441	103.90388900000001	103.94195000000001	53.166952999999999	53.156846000000002	0103000020E61000000100000005000000B58D3F51D9F9594014419C8713944A40B58D3F51D9F959400B7C45B75E954A40E71DA7E848FC59400B7C45B75E954A40E71DA7E848FC594014419C8713944A40B58D3F51D9F9594014419C8713944A40
21877	Харатирген	5	50	441	103.862494	103.890432	53.157952999999999	53.14584	0103000020E61000000100000005000000C2BF081A33F759406D3997E2AA924A40C2BF081A33F759400DA7CCCD37944A40F6D37FD6FCF859400DA7CCCD37944A40F6D37FD6FCF859406D3997E2AA924A40C2BF081A33F759406D3997E2AA924A40
21709	Харагун	5	50	441	104.29210500000001	104.31085299999999	53.179912000000002	53.162768999999997	0103000020E61000000100000005000000E17F2BD9B1125A40BCE6559DD5944A40E17F2BD9B1125A4038143E5B07974A404337FB03E5135A4038143E5B07974A404337FB03E5135A40BCE6559DD5944A40E17F2BD9B1125A40BCE6559DD5944A40
22281	Хандагай	5	50	441	103.61165800000001	103.64178699999999	53.173036000000003	53.162170000000003	0103000020E610000001000000050000008E95986725E7594038328FFCC1944A408E95986725E75940ED832C0B26964A40DEFFC70913E95940ED832C0B26964A40DEFFC70913E9594038328FFCC1944A408E95986725E7594038328FFCC1944A40
4611	Укыр	5	50	441	104.124174	104.147593	53.149296999999997	53.138235000000002	0103000020E61000000100000005000000DD408177F2075A40CF143AAFB1914A40DD408177F2075A400932022A1C934A409607E92972095A400932022A1C934A409607E92972095A40CF143AAFB1914A40DD408177F2075A40CF143AAFB1914A40
22968	Угольная	5	50	441	103.400689	103.40868399999999	53.224023000000003	53.214619999999996	0103000020E610000001000000050000007CB779E3A4D95940A4880CAB789B4A407CB779E3A4D95940A24621C9AC9C4A408099EFE027DA5940A24621C9AC9C4A408099EFE027DA5940A4880CAB789B4A407CB779E3A4D95940A4880CAB789B4A40
16487	Тихоновка	5	50	441	104.19636199999999	104.257627	53.190525999999998	53.159238000000002	0103000020E61000000100000005000000560BEC31910C5A40E62329E961944A40560BEC31910C5A40D384ED2763984A4043E4F4F57C105A40D384ED2763984A4043E4F4F57C105A40E62329E961944A40560BEC31910C5A40E62329E961944A40
22326	Тараса	5	50	441	103.75572099999999	103.80352000000001	53.098830999999997	53.072778	0103000020E61000000100000005000000A0F99CBB5DF0594024EF1CCA50894A40A0F99CBB5DF059405D6A847EA68C4A40A56B26DF6CF359405D6A847EA68C4A40A56B26DF6CF3594024EF1CCA50894A40A0F99CBB5DF0594024EF1CCA50894A40
2543	Середкино	5	50	441	103.397284	103.41674999999999	53.453178000000001	53.427905000000003	0103000020E6100000010000000500000057CEDE196DD95940BF654E97C5B64A4057CEDE196DD9594023A298BC01BA4A40E9263108ACDA594023A298BC01BA4A40E9263108ACDA5940BF654E97C5B64A4057CEDE196DD95940BF654E97C5B64A40
21803	Русиновка	5	50	441	103.966627	103.987037	53.139180000000003	53.125478999999999	0103000020E610000001000000050000008F1B7E37DDFD5940DAAA24B20F904A408F1B7E37DDFD5940EF2076A6D0914A4049BC3C9D2BFF5940EF2076A6D0914A4049BC3C9D2BFF5940DAAA24B20F904A408F1B7E37DDFD5940DAAA24B20F904A40
13089	Петрограновка	5	50	441	104.18080399999999	104.19099	53.074627999999997	53.055570000000003	0103000020E610000001000000050000001ABFF04A920B5A40C251F2EA1C874A401ABFF04A920B5A40D5AE09698D894A403CF71E2E390C5A40D5AE09698D894A403CF71E2E390C5A40C251F2EA1C874A401ABFF04A920B5A40C251F2EA1C874A40
22445	Олонки	5	50	441	103.69105999999999	103.721818	52.917577000000001	52.889626	0103000020E61000000100000005000000B8E4B8533AEC5940EDD5C743DF714A40B8E4B8533AEC5940E947C32973754A4081EA1F4432EE5940E947C32973754A4081EA1F4432EE5940EDD5C743DF714A40B8E4B8533AEC5940EDD5C743DF714A40
22372	Новый Алендарь	5	50	441	103.663706	103.682373	53.111930000000001	53.104930000000003	0103000020E610000001000000050000002D0ABB287AEA5940452FA3586E8D4A402D0ABB287AEA59407CB8E4B8538E4A4019ABCDFFABEB59407CB8E4B8538E4A4019ABCDFFABEB5940452FA3586E8D4A402D0ABB287AEA5940452FA3586E8D4A40
59316	Нововоскресенка	5	50	441	104.005174	104.04216700000001	53.15204	53.146774999999998	0103000020E61000000100000005000000873254C554005A40696FF085C9924A40873254C554005A4088D7F50B76934A401C7E37DDB2025A4088D7F50B76934A401C7E37DDB2025A40696FF085C9924A40873254C554005A40696FF085C9924A40
22209	Новая Ида	5	50	441	103.681439	103.699675	53.179907	53.172502000000001	0103000020E6100000010000000500000003CE52B29CEB59404F3FA88B14964A4003CE52B29CEB594026A94C3107974A400BB5A679C7EC594026A94C3107974A400BB5A679C7EC59404F3FA88B14964A4003CE52B29CEB59404F3FA88B14964A40
59298	Мутинова	5	50	441	103.487861	103.49788599999999	53.388983000000003	53.377678000000003	0103000020E610000001000000050000009BFF571D39DF59409835B1C057B04A409BFF571D39DF594099D9E731CAB14A40B8C83D5DDDDF594099D9E731CAB14A40B8C83D5DDDDF59409835B1C057B04A409BFF571D39DF59409835B1C057B04A40
59235	Морозова	5	50	441	103.505675	103.531807	53.200597999999999	53.193941000000002	0103000020E61000000100000005000000E8D9ACFA5CE05940412D060FD3984A40E8D9ACFA5CE059404ED2FC31AD994A402B323A2009E259404ED2FC31AD994A402B323A2009E25940412D060FD3984A40E8D9ACFA5CE05940412D060FD3984A40
14273	Манькова	5	50	441	104.05177	104.07802700000001	53.137273	53.130693000000001	0103000020E610000001000000050000007E3A1E3350035A407768588CBA904A407E3A1E3350035A40D9CF622992914A401F4DF564FE045A40D9CF622992914A401F4DF564FE045A407768588CBA904A407E3A1E3350035A407768588CBA904A40
59273	Логанова	5	50	441	103.55889999999999	103.56844	53.295692000000003	53.282702999999998	0103000020E61000000100000005000000006F8104C5E3594094BDA59C2FA44A40006F8104C5E359402CD8463CD9A54A403F6F2A5261E459402CD8463CD9A54A403F6F2A5261E4594094BDA59C2FA44A40006F8104C5E3594094BDA59C2FA44A40
59231	Крюкова	5	50	441	103.501048	103.533675	53.329358999999997	53.315961000000001	0103000020E610000001000000050000007A6EA12B11E05940DEE7F86871A84A407A6EA12B11E0594056D28A6F28AA4A4057EC2FBB27E2594056D28A6F28AA4A4057EC2FBB27E25940DEE7F86871A84A407A6EA12B11E05940DEE7F86871A84A40
22908	Каменка	5	50	441	103.366175	103.380674	53.174855000000001	53.139671999999997	0103000020E61000000100000005000000386744696FD759405D15A8C5E0914A40386744696FD7594063450DA661964A40001C7BF65CD8594063450DA661964A40001C7BF65CD859405D15A8C5E0914A40386744696FD759405D15A8C5E0914A40
22823	Калашникова	5	50	441	103.396395	103.407839	53.082402000000002	53.073670999999997	0103000020E61000000100000005000000115322895ED95940F1D4230D6E894A40115322895ED95940009013268C8A4A4022C2BF081ADA5940009013268C8A4A4022C2BF081ADA5940F1D4230D6E894A40115322895ED95940F1D4230D6E894A40
23152	Казачье	5	50	441	103.425186	103.450024	53.346322000000001	53.325906000000003	0103000020E61000000100000005000000E42D573F36DB5940FCC8AD49B7A94A40E42D573F36DB594052F17F4754AC4A40919A7631CDDC594052F17F4754AC4A40919A7631CDDC5940FCC8AD49B7A94A40E42D573F36DB5940FCC8AD49B7A94A40
22534	Захаровская	5	50	441	103.740216	103.753682	52.972844000000002	52.962907999999999	0103000020E6100000010000000500000076FEEDB25FEF59404487C091407B4A4076FEEDB25FEF59400F0EF626867C4A405E656D533CF059400F0EF626867C4A405E656D533CF059404487C091407B4A4076FEEDB25FEF59404487C091407B4A40
22122	Заглик	5	50	441	103.73935299999999	103.758892	53.181536999999999	53.169165999999997	0103000020E61000000100000005000000C4CC3E8F51EF59402DCC423BA7954A40C4CC3E8F51EF5940C901BB9A3C974A408C4CC0AF91F05940C901BB9A3C974A408C4CC0AF91F059402DCC423BA7954A40C4CC3E8F51EF59402DCC423BA7954A40
21632	Дундай	5	50	441	104.32725600000001	104.371776	53.224099000000002	53.206395999999998	0103000020E61000000100000005000000DE5A26C3F1145A403A03232F6B9A4A40DE5A26C3F1145A407D08AA46AF9C4A40035C902DCB175A407D08AA46AF9C4A40035C902DCB175A403A03232F6B9A4A40DE5A26C3F1145A403A03232F6B9A4A40
59209	Грязная	5	50	441	103.351793	104.724599	53.538595999999998	52.678795000000001	0103000020E610000001000000050000008D7DC9C683D659401BD82AC1E2564A408D7DC9C683D65940D2E0B6B6F0C44A40B7ED7BD45F2E5A40D2E0B6B6F0C44A40B7ED7BD45F2E5A401BD82AC1E2564A408D7DC9C683D659401BD82AC1E2564A40
22877	Гречехан	5	50	441	103.62639	103.637152	53.238765999999998	53.225181999999997	0103000020E61000000100000005000000A72215C616E85940EDD286C3D29C4A40A72215C616E85940C8B260E28F9E4A402FA52E19C7E85940C8B260E28F9E4A402FA52E19C7E85940EDD286C3D29C4A40A72215C616E85940EDD286C3D29C4A40
22563	Грехневка	5	50	441	103.762045	103.77697499999999	52.903858999999997	52.897308000000002	0103000020E6100000010000000500000024456458C5F05940373811FDDA724A4024456458C5F05940FE98D6A6B1734A40D0B359F5B9F15940FE98D6A6B1734A40D0B359F5B9F15940373811FDDA724A4024456458C5F05940373811FDDA724A40
22636	Воробьевка	5	50	441	103.668261	103.677702	53.010677999999999	52.997852000000002	0103000020E610000001000000050000004E0CC9C9C4EA5940C51F459DB97F4A404E0CC9C9C4EA5940B2648EE55D814A40C39B35785FEB5940B2648EE55D814A40C39B35785FEB5940C51F459DB97F4A404E0CC9C9C4EA5940C51F459DB97F4A40
21610	Вершина	5	50	441	104.389608	104.429664	53.257520999999997	53.230255	0103000020E61000000100000005000000A3906456EF185A40C85EEFFE789D4A40A3906456EF185A404084B872F6A04A4030116F9D7F1B5A404084B872F6A04A4030116F9D7F1B5A40C85EEFFE789D4A40A3906456EF185A40C85EEFFE789D4A40
2466	Буреть,красная Буреть	5	50	441	103.578052	103.58900199999999	53.030487000000001	53.019736000000002	0103000020E61000000100000005000000CBD8D0CDFEE45940E54691B586824A40CBD8D0CDFEE4594001FA7DFFE6834A40D4D17135B2E5594001FA7DFFE6834A40D4D17135B2E55940E54691B586824A40CBD8D0CDFEE45940E54691B586824A40
22195	Булык	5	50	441	103.80814599999999	103.823813	53.26182	53.252462999999999	0103000020E610000001000000050000002A1900AAB8F359409B3924B550A04A402A1900AAB8F3594028B8585183A14A404241295AB9F4594028B8585183A14A404241295AB9F459409B3924B550A04A402A1900AAB8F359409B3924B550A04A40
21976	Бохан	5	50	441	103.76191	103.803799	53.171671000000003	53.117330000000003	0103000020E61000000100000005000000B41F2922C3F059407B6B60AB048F4A40B41F2922C3F05940F855B950F9954A40AE635C7171F35940F855B950F9954A40AE635C7171F359407B6B60AB048F4A40B41F2922C3F059407B6B60AB048F4A40
22661	Александровское	5	50	441	103.820076	103.86342	52.805371000000001	52.783160000000002	0103000020E61000000100000005000000020F0C207CF4594087C43D963E644A40020F0C207CF45940CB129D6516674A4097ADF54542F75940CB129D6516674A4097ADF54542F7594087C43D963E644A40020F0C207CF4594087C43D963E644A40
59345	Шитхулун	5	50	1576	105.92943699999999	105.95382600000001	53.334398	53.306970999999997	0103000020E610000001000000050000004FAC53E57B7B5A4003E962D34AA74A404FAC53E57B7B5A4085ECBC8DCDAA4A40C504357C0B7D5A4085ECBC8DCDAA4A40C504357C0B7D5A4003E962D34AA74A404FAC53E57B7B5A4003E962D34AA74A40
19169	Шаманка	5	50	1576	105.592641	105.607705	53.135171999999997	53.119107999999997	0103000020E61000000100000005000000335184D4ED655A40925852EE3E8F4A40335184D4ED655A40DEAAEB504D914A40672783A3E4665A40DEAAEB504D914A40672783A3E4665A40925852EE3E8F4A40335184D4ED655A40925852EE3E8F4A40
20003	Хогот	5	50	1576	105.85185	105.893046	53.257710000000003	53.225521999999998	0103000020E610000001000000050000003FC6DCB584765A40A643A7E7DD9C4A403FC6DCB584765A4014ED2AA4FCA04A40B6F468AA27795A4014ED2AA4FCA04A40B6F468AA27795A40A643A7E7DD9C4A403FC6DCB584765A40A643A7E7DD9C4A40
19690	Хатар-Хадай	5	50	1576	105.22386400000001	105.245774	52.852342999999998	52.834214000000003	0103000020E610000001000000050000001DB0ABC9534E5A40C4EE3B86C76A4A401DB0ABC9534E5A40BDFC4E93196D4A40410DDFC2BA4F5A40BDFC4E93196D4A40410DDFC2BA4F5A40C4EE3B86C76A4A401DB0ABC9534E5A40C4EE3B86C76A4A40
19016	Харагун	5	50	1576	105.791878	105.826688	53.136316999999998	53.112448999999998	0103000020E61000000100000005000000001B1021AE725A40E4BB94BA648E4A40001B1021AE725A40C571E0D572914A40B9FFC874E8745A40C571E0D572914A40B9FFC874E8745A40E4BB94BA648E4A40001B1021AE725A40E4BB94BA648E4A40
20270	Хандагай	5	50	1576	105.835554	105.869879	53.171081999999998	53.158887	0103000020E61000000100000005000000B0027CB779755A403961C26856944A40B0027CB779755A409677D503E6954A408A1EF818AC775A409677D503E6954A408A1EF818AC775A403961C26856944A40B0027CB779755A403961C26856944A40
19242	Улан	5	50	1576	105.715467	105.736892	53.243028000000002	53.229571	0103000020E6100000010000000500000081971936CA6D5A40158E2095629D4A4081971936CA6D5A409301A08A1B9F4A40C72B103D296F5A409301A08A1B9F4A40C72B103D296F5A40158E2095629D4A4081971936CA6D5A40158E2095629D4A40
20398	Тухум	5	50	1576	105.70308	105.720237	53.429760999999999	53.417200000000001	0103000020E61000000100000005000000309E4143FF6C5A4013F241CF66B54A40309E4143FF6C5A40520C906802B74A40A017EE5C186E5A40520C906802B74A40A017EE5C186E5A4013F241CF66B54A40309E4143FF6C5A4013F241CF66B54A40
19061	Тургеневка	5	50	1576	105.64750100000001	105.68952400000001	53.031782	53.021459	0103000020E6100000010000000500000026C808A870695A40399A232BBF824A4026C808A870695A40FD4CBD6E11844A40A8734529216C5A40FD4CBD6E11844A40A8734529216C5A40399A232BBF824A4026C808A870695A40399A232BBF824A40
20074	Старый Хогот	5	50	1576	105.777236	105.811021	53.307336999999997	53.285136000000001	0103000020E610000001000000050000008751103CBE715A40C57421567FA44A408751103CBE715A40E5EC9DD156A74A40A1D79FC4E7735A40E5EC9DD156A74A40A1D79FC4E7735A40C57421567FA44A408751103CBE715A40C57421567FA44A40
19123	Половинка (Гоголевка)	5	50	1576	105.6309	105.671207	53.144992000000002	53.123572000000003	0103000020E61000000100000005000000F8C264AA60685A40C5591135D18F4A40F8C264AA60685A4040170D198F924A402976340EF56A5A4040170D198F924A402976340EF56A5A40C5591135D18F4A40F8C264AA60685A40C5591135D18F4A40
19268	Покровка	5	50	1576	105.521027	105.552549	53.092844999999997	53.068607	0103000020E610000001000000050000005055A18158615A406AA33A1DC8884A405055A18158615A406E4C4F58E28B4A40001C7BF65C635A406E4C4F58E28B4A40001C7BF65C635A406AA33A1DC8884A405055A18158615A406AA33A1DC8884A40
19485	Ользоны	5	50	1576	105.208162	105.229973	52.956153999999998	52.936619999999998	0103000020E610000001000000050000004791B586524D5A40C763062AE3774A404791B586524D5A4044F81741637A4A40A27DACE0B74E5A4044F81741637A4A40A27DACE0B74E5A40C763062AE3774A404791B586524D5A40C763062AE3774A40
59220	Нуху-Нур	5	50	1576	105.329677	105.34987099999999	53.156905000000002	53.145014000000003	0103000020E61000000100000005000000944F8F6D19555A4028BB99D18F924A40944F8F6D19555A4019CA897615944A4067B4554964565A4019CA897615944A4067B4554964565A4028BB99D18F924A40944F8F6D19555A4028BB99D18F924A40
19738	Наумовка	5	50	1576	105.151568	105.181895	52.848841	52.833812000000002	0103000020E61000000100000005000000B0C7444AB3495A409581035ABA6A4A40B0C7444AB3495A40814067D2A66C4A409413ED2AA44B5A40814067D2A66C4A409413ED2AA44B5A409581035ABA6A4A40B0C7444AB3495A409581035ABA6A4A40
19824	Нагалык	5	50	1576	105.276658	105.32096300000001	53.111330000000002	53.097236000000002	0103000020E61000000100000005000000508BC1C3B4515A4037FFAF3A728C4A40508BC1C3B4515A402788BA0F408E4A40780E65A88A545A402788BA0F408E4A40780E65A88A545A4037FFAF3A728C4A40508BC1C3B4515A4037FFAF3A728C4A40
19390	Люры	5	50	1576	105.449045	105.471045	53.010055000000001	52.992111999999999	0103000020E61000000100000005000000AB5B3D27BD5C5A400DFCA886FD7E4A40AB5B3D27BD5C5A40A514747B49814A40707CED99255E5A40A514747B49814A40707CED99255E5A400DFCA886FD7E4A40AB5B3D27BD5C5A400DFCA886FD7E4A40
59287	Кокорина	5	50	1576	105.134787	105.17041500000001	53.090774000000003	53.072144999999999	0103000020E61000000100000005000000433BA759A0485A40F3C81F0C3C894A40433BA759A0485A40DFA9807B9E8B4A40DDEF5014E84A5A40DFA9807B9E8B4A40DDEF5014E84A5A40F3C81F0C3C894A40433BA759A0485A40F3C81F0C3C894A40
59343	Кайзаран	5	50	1576	105.994044	106.008022	53.306815	53.297058999999997	0103000020E610000001000000050000003EB2B96A9E7F5A40C1FD800706A64A403EB2B96A9E7F5A400C76C3B645A74A4081E9B46E83805A400C76C3B645A74A4081E9B46E83805A40C1FD800706A64A403EB2B96A9E7F5A40C1FD800706A64A40
19580	Загатуй	5	50	1576	105.311378	105.360606	52.898107000000003	52.882300999999998	0103000020E6100000010000000500000069ACFD9DED535A40321D3A3DEF704A4069ACFD9DED535A4083A7902BF5724A40732F302B14575A4083A7902BF5724A40732F302B14575A40321D3A3DEF704A4069ACFD9DED535A40321D3A3DEF704A40
19964	Еленинск	5	50	1576	105.416769	105.44018800000001	53.203597000000002	53.192149999999998	0103000020E61000000100000005000000253FE257AC5A5A4094F6065F98984A40253FE257AC5A5A4028486C770F9A4A40DE054A0A2C5C5A4028486C770F9A4A40DE054A0A2C5C5A4094F6065F98984A40253FE257AC5A5A4094F6065F98984A40
18961	Васильевка	5	50	1576	105.741411	105.763797	53.088292000000003	53.065057000000003	0103000020E6100000010000000500000042791F47736F5A401DB0ABC953884A4042791F47736F5A40CD3FFA264D8B4A401BF2CF0CE2705A40CD3FFA264D8B4A401BF2CF0CE2705A401DB0ABC953884A4042791F47736F5A401DB0ABC953884A40
19430	Бохолдой	5	50	1576	105.47920999999999	105.503007	52.992669999999997	52.973641000000001	0103000020E61000000100000005000000A27A6B60AB5E5A40BA85AE44A07C4A40A27A6B60AB5E5A4033DC80CF0F7F4A402EAA454431605A4033DC80CF0F7F4A402EAA454431605A40BA85AE44A07C4A40A27A6B60AB5E5A40BA85AE44A07C4A40
19328	Баяндай	5	50	1576	105.496503	105.527657	53.076830000000001	53.044609000000001	0103000020E610000001000000050000006BD784B4C65F5A40BB0D6ABFB5854A406BD784B4C65F5A4004ADC090D5894A405AA0DD21C5615A4004ADC090D5894A405AA0DD21C5615A40BB0D6ABFB5854A406BD784B4C65F5A40BB0D6ABFB5854A40
19642	Бахай 1-й	5	50	1576	105.37139500000001	105.38426800000001	52.930225999999998	52.917740000000002	0103000020E6100000010000000500000078B988EFC4575A40931D1B8178754A4078B988EFC4575A40C7F143A511774A408F39CFD897585A40C7F143A511774A408F39CFD897585A40931D1B8178754A4078B988EFC4575A40931D1B8178754A40
20297	Байша	5	50	1576	105.613176	105.644626	53.382420000000003	53.360371999999998	0103000020E610000001000000050000004BAC8C463E675A40723271AB20AE4A404BAC8C463E675A400DAB7823F3B04A40AF09698D41695A400DAB7823F3B04A40AF09698D41695A40723271AB20AE4A404BAC8C463E675A40723271AB20AE4A40
19818	Бадагуй (Гахан)	5	50	1576	105.282659	105.306213	53.025516000000003	53.016458999999998	0103000020E61000000100000005000000E23AC61517525A40C85C19541B824A40E23AC61517525A402BC3B81B44834A400B2769FE98535A402BC3B81B44834A400B2769FE98535A40C85C19541B824A40E23AC61517525A40C85C19541B824A40
18693	Шарагай	5	50	398	103.052663	103.08425699999999	54.337179999999996	54.319831999999998	0103000020E6100000010000000500000064ADA1D45EC359406D1B4641F0284B4064ADA1D45EC35940C16ED8B6282B4B4061DD787764C55940C16ED8B6282B4B4061DD787764C559406D1B4641F0284B4064ADA1D45EC359406D1B4641F0284B40
2086	Ташлыкова	5	50	398	103.07649600000001	103.091515	53.898001999999998	53.885671000000002	0103000020E6100000010000000500000097917A4FE5C459400002D6AA5DF14A4097917A4FE5C459400DDFC2BAF1F24A40FB05BB61DBC559400DDFC2BAF1F24A40FB05BB61DBC559400002D6AA5DF14A4097917A4FE5C459400002D6AA5DF14A40
18444	Тарнополь	5	50	398	102.735675	102.79120899999999	54.059204000000001	54.041241999999997	0103000020E61000000100000005000000075F984C15AF59405E9CF86A47054B40075F984C15AF59406DE525FF93074B4041D3122BA3B259406DE525FF93074B4041D3122BA3B259405E9CF86A47054B40075F984C15AF59405E9CF86A47054B40
18666	Тарасовск	5	50	398	102.909086	102.92565	54.386194000000003	54.364865999999999	0103000020E6100000010000000500000018D00B772EBA59400FB6D8EDB32E4B4018D00B772EBA5940AAF413CE6E314B40B7627FD93DBB5940AAF413CE6E314B40B7627FD93DBB59400FB6D8EDB32E4B4018D00B772EBA59400FB6D8EDB32E4B40
18550	Метляева	5	50	398	102.83811900000001	102.87209300000001	54.129085000000003	54.117581999999999	0103000020E6100000010000000500000000CADFBDA3B55940944C4EED0C0F4B4000CADFBDA3B55940BCB376DB85104B408484285FD0B75940BCB376DB85104B408484285FD0B75940944C4EED0C0F4B4000CADFBDA3B55940944C4EED0C0F4B40
18768	Кумарейка	5	50	398	102.96634400000001	102.99918700000001	54.496839999999999	54.464345000000002	0103000020E61000000100000005000000E52B8194D8BD5940D3872EA86F3B4B40E52B8194D8BD59401DACFF73983F4B40A8E507AEF2BF59401DACFF73983F4B40A8E507AEF2BF5940D3872EA86F3B4B40E52B8194D8BD5940D3872EA86F3B4B40
18258	Коновалово	5	50	398	103.05664299999999	103.08158	53.990332000000002	53.974834000000001	0103000020E610000001000000050000000723F609A0C35940B2834A5CC7FC4A400723F609A0C359405517F032C3FE4A407E00529B38C559405517F032C3FE4A407E00529B38C55940B2834A5CC7FC4A400723F609A0C35940B2834A5CC7FC4A40
18581	Заславская	5	50	398	102.948324	102.979675	54.226680000000002	54.214325000000002	0103000020E61000000100000005000000C3802557B1BC59408CDB68006F1B4B40C3802557B1BC59402254A9D9031D4B405D6DC5FEB2BE59402254A9D9031D4B405D6DC5FEB2BE59408CDB68006F1B4B40C3802557B1BC59408CDB68006F1B4B40
18363	Бирит	5	50	398	102.88981699999999	102.937059	54.087463	54.064250000000001	0103000020E61000000100000005000000309B00C3F2B859404E62105839084B40309B00C3F2B85940164ED2FC310B4B400ADB4FC6F8BB5940164ED2FC310B4B400ADB4FC6F8BB59404E62105839084B40309B00C3F2B859404E62105839084B40
18787	Балаганск	5	50	398	103.024869	103.073199	54.022219	53.994444999999999	0103000020E61000000100000005000000CA6B257497C15940DA5548F949FF4A40CA6B257497C15940C72C7B12D8024B4065C6DB4AAFC45940C72C7B12D8024B4065C6DB4AAFC45940DA5548F949FF4A40CA6B257497C15940DA5548F949FF4A40
18473	Анучинск	5	50	398	102.57984399999999	102.59144999999999	54.064805	54.039485999999997	0103000020E610000001000000050000000932022A1CA559402E5393E00D054B400932022A1CA5594003CFBD874B084B4007CE1951DAA5594003CFBD874B084B4007CE1951DAA559402E5393E00D054B400932022A1CA559402E5393E00D054B40
17463	Савватеевка	5	50	1285	103.62833999999999	103.652918	52.340814999999999	52.320501999999998	0103000020E6100000010000000500000031B1F9B836E85940BB26A43506294A4031B1F9B836E859403D7E6FD39F2B4A40103E9468C9E959403D7E6FD39F2B4A40103E9468C9E95940BB26A43506294A4031B1F9B836E85940BB26A43506294A40
17578	Одинск	5	50	1285	103.66991400000001	103.73275099999999	52.466597	52.433655000000002	0103000020E610000001000000050000007C48F8DEDFEA59409A5FCD0182374A407C48F8DEDFEA5940B3B45373B93B4A401F477364E5EE5940B3B45373B93B4A401F477364E5EE59409A5FCD0182374A407C48F8DEDFEA59409A5FCD0182374A40
59111	Мегет	5	50	1285	104.03276099999999	104.07320300000001	52.441938999999998	52.400132999999997	0103000020E6100000010000000500000064E597C118025A407286E28E37334A4064E597C118025A40D9E9077591384A4006BEA25BAF045A40D9E9077591384A4006BEA25BAF045A407286E28E37334A4064E597C118025A407286E28E37334A40
13460	Биликтуй	5	50	1285	103.81890799999999	103.84972	52.606462999999998	52.588456000000001	0103000020E61000000100000005000000B29B19FD68F459404791B586524B4A40B29B19FD68F45940F59D5F94A04D4A4075B0FECF61F65940F59D5F94A04D4A4075B0FECF61F659404791B586524B4A40B29B19FD68F459404791B586524B4A40
59115	Ангарск	5	50	1285	103.199196	104.11049199999999	52.488399999999999	52.164796000000003	0103000020E610000001000000050000009E5F94A0BFCC59407D410B0918154A409E5F94A0BFCC5940E6AE25E4833E4A400E9E094D12075A40E6AE25E4833E4A400E9E094D12075A407D410B0918154A409E5F94A0BFCC59407D410B0918154A40
52030	Шаховская	5	50	1177	102.799958	102.819559	53.533790000000003	53.517394000000003	0103000020E610000001000000050000001C0B0A8332B35940C59272F739C24A401C0B0A8332B359404777103B53C44A401E8997A773B459404777103B53C44A401E8997A773B45940C59272F739C24A401C0B0A8332B35940C59272F739C24A40
51999	Шалоты	5	50	1177	102.31967400000001	102.33623	53.178736000000001	53.162422999999997	0103000020E610000001000000050000006BD8EF8975945940218FE046CA944A406BD8EF8975945940164F3DD2E0964A40C87BD5CA84955940164F3DD2E0964A40C87BD5CA84955940218FE046CA944A406BD8EF8975945940218FE046CA944A40
51956	Хуруй	5	50	1177	102.970378	102.98996099999999	53.383135000000003	53.373927999999999	0103000020E6100000010000000500000081B053AC1ABE5940838769DFDCAF4A4081B053AC1ABE5940FB7953910AB14A4030D461855BBF5940FB7953910AB14A4030D461855BBF5940838769DFDCAF4A4081B053AC1ABE5940838769DFDCAF4A40
51943	Халты	5	50	1177	102.25116800000001	102.261894	53.268531000000003	53.257758000000003	0103000020E610000001000000050000005073F222139059402524D236FEA04A405073F22213905940297B4B395FA24A4031410DDFC2905940297B4B395FA24A4031410DDFC29059402524D236FEA04A405073F222139059402524D236FEA04A40
51937	Угольная	5	50	1177	102.6995	102.72167	53.295256000000002	53.279105999999999	0103000020E6100000010000000500000054E3A59BC4AC5940060FD3BEB9A34A4054E3A59BC4AC594051F9D7F2CAA54A4047205ED72FAE594051F9D7F2CAA54A4047205ED72FAE5940060FD3BEB9A34A4054E3A59BC4AC5940060FD3BEB9A34A40
52040	Тютрина	5	50	1177	102.849779	102.86841	53.359054999999998	53.342838999999998	0103000020E61000000100000005000000F77475C762B659408C65FA25E2AB4A40F77475C762B659408E3BA583F5AD4A403D61890794B759408E3BA583F5AD4A403D61890794B759408C65FA25E2AB4A40F77475C762B659408C65FA25E2AB4A40
52068	Тыргетуй	5	50	1177	103.265097	103.280539	53.358334999999997	53.339592000000003	0103000020E6100000010000000500000022516859F7D05940DBFD2AC077AB4A4022516859F7D059408E01D9EBDDAD4A402A90D959F4D159408E01D9EBDDAD4A402A90D959F4D15940DBFD2AC077AB4A4022516859F7D05940DBFD2AC077AB4A40
52061	Табарсук	5	50	1177	102.89997700000001	102.92334200000001	53.443503999999997	53.419282000000003	0103000020E61000000100000005000000BE89213999B9594097E65608ABB54A40BE89213999B9594095D233BDC4B84A407D410B0918BB594095D233BDC4B84A407D410B0918BB594097E65608ABB54A40BE89213999B9594097E65608ABB54A40
51989	Отрадная	5	50	1177	102.34204200000001	102.361086	53.248330000000003	53.233888	0103000020E61000000100000005000000F1F62004E4955940A376BF0AF09D4A40F1F62004E4955940CF4E0647C99F4A40C84274081C975940CF4E0647C99F4A40C84274081C975940A376BF0AF09D4A40F1F62004E4955940A376BF0AF09D4A40
52057	Ныгда	5	50	1177	102.66895700000001	102.695825	53.024557000000001	53.009247999999999	0103000020E610000001000000050000008A5B0531D0AA5940D6C6D8092F814A408A5B0531D0AA5940A6F10BAF24834A404FAF946588AC5940A6F10BAF24834A404FAF946588AC5940D6C6D8092F814A408A5B0531D0AA5940D6C6D8092F814A40
52048	Нельхай	5	50	1177	103.119525	103.137249	53.363956000000002	53.351191999999998	0103000020E610000001000000050000007B832F4CA6C75940F44E05DCF3AC4A407B832F4CA6C759406C97361C96AE4A40289A07B0C8C859406C97361C96AE4A40289A07B0C8C85940F44E05DCF3AC4A407B832F4CA6C75940F44E05DCF3AC4A40
51965	Нарены (Левые Нарены)	5	50	1177	102.791828	102.806588	53.233601999999998	53.223537999999998	0103000020E61000000100000005000000A703594FADB25940E5B4A7E49C9C4A40A703594FADB25940DD239BABE69D4A40265646239FB35940DD239BABE69D4A40265646239FB35940E5B4A7E49C9C4A40A703594FADB25940E5B4A7E49C9C4A40
52046	Мольта	5	50	1177	103.047372	103.05952600000001	53.372627999999999	53.358007000000001	0103000020E61000000100000005000000C0AF912408C359409A5E622CD3AD4A40C0AF912408C3594075C93846B2AF4A40C0D02346CFC3594075C93846B2AF4A40C0D02346CFC359409A5E622CD3AD4A40C0AF912408C359409A5E622CD3AD4A40
52038	Могоенок	5	50	1177	102.852977	102.87691700000001	53.403319000000003	53.383527000000001	0103000020E610000001000000050000005FCFD72C97B659400611A96917B14A405FCFD72C97B659407F6DFDF49FB34A409D137B681FB859407F6DFDF49FB34A409D137B681FB859400611A96917B14A405FCFD72C97B659400611A96917B14A40
52025	Маниловская	5	50	1177	102.71827399999999	102.749033	53.510320999999998	53.486956999999997	0103000020E610000001000000050000004BE48233F8AD594075C7629B54BE4A404BE48233F8AD594023BBD23252C14A40FCA71B28F0AF594023BBD23252C14A40FCA71B28F0AF594075C7629B54BE4A404BE48233F8AD594075C7629B54BE4A40
52037	Малый Кутулик	5	50	1177	102.77092500000001	102.78522599999999	53.402611	53.389977000000002	0103000020E61000000100000005000000CEAACFD556B159409A982EC4EAB14A40CEAACFD556B159404301DBC188B34A40027E8D2441B259404301DBC188B34A40027E8D2441B259409A982EC4EAB14A40CEAACFD556B159409A982EC4EAB14A40
52031	Маломолева	5	50	1177	102.82729399999999	102.83909800000001	53.406002999999998	53.394246000000003	0103000020E61000000100000005000000548B8862F2B45940174A26A776B24A40548B8862F2B45940F88903E8F7B34A40E60819C8B3B55940F88903E8F7B34A40E60819C8B3B55940174A26A776B24A40548B8862F2B45940174A26A776B24A40
52008	Кутулик	5	50	1177	102.74261	102.807827	53.373804	53.334021	0103000020E61000000100000005000000AFEB17EC86AF5940AF963B33C1AA4A40AFEB17EC86AF5940978E39CFD8AF4A40DA740470B3B35940978E39CFD8AF4A40DA740470B3B35940AF963B33C1AA4A40AFEB17EC86AF5940AF963B33C1AA4A40
51932	Куркат	5	50	1177	102.41968300000001	102.43291600000001	53.179701999999999	53.167211999999999	0103000020E61000000100000005000000FBEB1516DC9A5940D7BFEB3367954A40FBEB1516DC9A59404D83A27900974A40927A4FE5B49B59404D83A27900974A40927A4FE5B49B5940D7BFEB3367954A40FBEB1516DC9A5940D7BFEB3367954A40
32296	Кундулун	5	50	1177	103.08852400000001	103.10760399999999	53.281491000000003	53.271718999999997	0103000020E61000000100000005000000503A9160AAC55940D5592DB0C7A24A40503A9160AAC55940268FA7E507A44A40CD3AE3FBE2C65940268FA7E507A44A40CD3AE3FBE2C65940D5592DB0C7A24A40503A9160AAC55940D5592DB0C7A24A40
51928	Кукунур	5	50	1177	102.506703	102.53566499999999	53.191437999999998	53.179070000000003	0103000020E610000001000000050000003F726BD26DA05940EDD808C4EB964A403F726BD26DA05940179B560A81984A402827DA5548A25940179B560A81984A402827DA5548A25940EDD808C4EB964A403F726BD26DA05940EDD808C4EB964A40
52002	Куйта	5	50	1177	102.732468	102.761403	53.192732999999997	53.179220999999998	0103000020E61000000100000005000000755776C1E0AE5940D2E0B6B6F0964A40755776C1E0AE594013EE9579AB984A40E204A6D3BAB0594013EE9579AB984A40E204A6D3BAB05940D2E0B6B6F0964A40755776C1E0AE5940D2E0B6B6F0964A40
52022	Корховская	5	50	1177	102.70312	102.723583	53.395422000000003	53.385900999999997	0103000020E61000000100000005000000774A07EBFFAC5940313F373465B14A40774A07EBFFAC5940390F27309DB24A40433C122F4FAE5940390F27309DB24A40433C122F4FAE5940313F373465B14A40774A07EBFFAC5940313F373465B14A40
59246	Кирюшина	5	50	1177	102.819541	102.84482	53.450975	53.441186999999999	0103000020E61000000100000005000000CB2E185C73B45940CE35CCD078B84A40CB2E185C73B4594024287E8CB9B94A406EC0E78711B6594024287E8CB9B94A406EC0E78711B65940CE35CCD078B84A40CB2E185C73B45940CE35CCD078B84A40
51984	Киркей	5	50	1177	102.39763000000001	102.413512	53.247765000000001	53.229861999999997	0103000020E61000000100000005000000257A19C572995940EC4B361E6C9D4A40257A19C572995940F60B76C3B69F4A403A2009FB769A5940F60B76C3B69F4A403A2009FB769A5940EC4B361E6C9D4A40257A19C572995940EC4B361E6C9D4A40
52064	Икинат (Зангей)	5	50	1177	103.265456	103.28689	53.397365000000001	53.386603999999998	0103000020E61000000100000005000000BAA1293BFDD059405B40683D7CB14A40BAA1293BFDD059409BC937DBDCB24A402AE3DF675CD259409BC937DBDCB24A402AE3DF675CD259405B40683D7CB14A40BAA1293BFDD059405B40683D7CB14A40
51998	Идеал	5	50	1177	102.68314100000001	102.706255	53.166606999999999	53.150744000000003	0103000020E61000000100000005000000A2630795B8AB5940BC0853944B934A40A2630795B8AB59407024D06053954A40BCE82B4833AD59407024D06053954A40BCE82B4833AD5940BC0853944B934A40A2630795B8AB5940BC0853944B934A40
51961	Иванова	5	50	1177	102.744936	102.768355	53.324534999999997	53.316665999999998	0103000020E610000001000000050000003C670B08ADAF5940A8E0F08288A84A403C670B08ADAF594024B4E55C8AA94A40F52D73BA2CB1594024B4E55C8AA94A40F52D73BA2CB15940A8E0F08288A84A403C670B08ADAF5940A8E0F08288A84A40
51978	Иваническое	5	50	1177	102.32978900000001	102.35522899999999	53.219538	53.182842999999998	0103000020E61000000100000005000000286552431B955940B9A6406667974A40286552431B955940581D39D2199C4A40CF656A12BC965940581D39D2199C4A40CF656A12BC965940B9A6406667974A40286552431B955940B9A6406667974A40
51970	Зоны	5	50	1177	102.51893800000001	102.553982	53.322991000000002	53.308590000000002	0103000020E61000000100000005000000B5A9BA4736A15940B3EF8AE07FA74A40B5A9BA4736A1594080F3E2C457A94A40A724EB7074A3594080F3E2C457A94A40A724EB7074A35940B3EF8AE07FA74A40B5A9BA4736A15940B3EF8AE07FA74A40
51996	Заречное	5	50	1177	102.623924	102.64278	53.169868000000001	53.161473000000001	0103000020E6100000010000000500000021CCED5EEEA75940F017B325AB944A4021CCED5EEEA759408751103CBE954A4077A1B94E23A959408751103CBE954A4077A1B94E23A95940F017B325AB944A4021CCED5EEEA75940F017B325AB944A40
52018	Занина	5	50	1177	102.594729	102.62833500000001	53.441524999999999	53.413550000000001	0103000020E61000000100000005000000E63E390A10A6594062A1D634EFB44A40E63E390A10A65940E6AE25E483B84A40A9FB00A436A85940E6AE25E483B84A40A9FB00A436A8594062A1D634EFB44A40E63E390A10A6594062A1D634EFB44A40
51960	Забитуй	5	50	1177	102.81222	102.845	53.285082000000003	53.259568000000002	0103000020E610000001000000050000000E4A9869FBB35940488B338639A14A400E4A9869FBB35940D25625917DA44A40AE47E17A14B65940D25625917DA44A40AE47E17A14B65940488B338639A14A400E4A9869FBB35940488B338639A14A40
59304	Егоровская	5	50	1177	103.00447800000001	103.027466	53.309392000000003	53.297542999999997	0103000020E610000001000000050000004CE3175E49C05940AD1397E315A64A404CE3175E49C0594070D234289AA74A4020F0C000C2C1594070D234289AA74A4020F0C000C2C15940AD1397E315A64A404CE3175E49C05940AD1397E315A64A40
52006	Головинское	5	50	1177	102.655725	102.678731	53.446277000000002	53.420032999999997	0103000020E61000000100000005000000DB8AFD65F7A95940D11E2FA4C3B54A40DB8AFD65F7A959407FFACF9A1FB94A4002F2255470AB59407FFACF9A1FB94A4002F2255470AB5940D11E2FA4C3B54A40DB8AFD65F7A95940D11E2FA4C3B54A40
51941	Высотская	5	50	1177	102.17714700000001	102.192679	53.281750000000002	53.268858999999999	0103000020E6100000010000000500000069E55E60568B59401D1EC2F869A24A4069E55E60568B5940F2D24D6210A44A4010E84CDA548C5940F2D24D6210A44A4010E84CDA548C59401D1EC2F869A24A4069E55E60568B59401D1EC2F869A24A40
51949	Быково	5	50	1177	103.317891	103.332587	53.508446999999997	53.499380000000002	0103000020E61000000100000005000000562C7E5358D45940642310AFEBBF4A40562C7E5358D45940E95F92CA14C14A40C904FC1A49D55940E95F92CA14C14A40C904FC1A49D55940642310AFEBBF4A40562C7E5358D45940642310AFEBBF4A40
59252	Бурятский Забитуй (Малиновка)	5	50	1177	102.860657	102.881399	53.227764999999998	53.213709000000001	0103000020E61000000100000005000000B404190115B7594031EE06D15A9B4A40B404190115B7594033164D67279D4A4089EE59D768B8594033164D67279D4A4089EE59D768B8594031EE06D15A9B4A40B404190115B7594031EE06D15A9B4A40
51967	Бурятская	5	50	1177	102.42775899999999	102.448133	53.369323999999999	53.343924999999999	0103000020E6100000010000000500000075E44867609B59406EA301BC05AC4A4075E44867609B59405FD0420246AF4A4089D00836AE9C59405FD0420246AF4A4089D00836AE9C59406EA301BC05AC4A4075E44867609B59406EA301BC05AC4A40
52051	Буркова	5	50	1177	102.596535	102.618903	53.027422000000001	53.019632999999999	0103000020E61000000100000005000000D7FA22A12DA6594010768A5583824A40D7FA22A12DA659407098689082834A405D19541B9CA759407098689082834A405D19541B9CA7594010768A5583824A40D7FA22A12DA6594010768A5583824A40
51950	Бахтай	5	50	1177	103.09562099999999	103.124933	53.513148000000001	53.495790999999997	0103000020E61000000100000005000000E4F38AA71EC659405853591476BF4A40E4F38AA71EC6594000016BD5AEC14A403C4CFBE6FEC7594000016BD5AEC14A403C4CFBE6FEC759405853591476BF4A40E4F38AA71EC659405853591476BF4A40
52045	Апхульта	5	50	1177	103.081867	103.101612	53.352938999999999	53.335914000000002	0103000020E61000000100000005000000C9E7154F3DC559406022DE3AFFAA4A40C9E7154F3DC55940D13DEB1A2DAD4A4065389ECF80C65940D13DEB1A2DAD4A4065389ECF80C659406022DE3AFFAA4A40C9E7154F3DC559406022DE3AFFAA4A40
51946	Апхайта	5	50	1177	103.207802	103.216579	53.417274999999997	53.409019999999998	0103000020E61000000100000005000000C782C2A04CCD594078B471C45AB44A40C782C2A04CCD59401D38674469B54A4006802A6EDCCD59401D38674469B54A4006802A6EDCCD594078B471C45AB44A40C782C2A04CCD594078B471C45AB44A40
51945	Ангарский	5	50	1177	103.340771	103.37135000000001	53.466265	53.458336000000003	0103000020E61000000100000005000000371B2B31CFD559402C4A09C1AABA4A40371B2B31CFD559407D224F92AEBB4A40A857CA32C4D759407D224F92AEBB4A40A857CA32C4D759402C4A09C1AABA4A40371B2B31CFD559402C4A09C1AABA4A40
51940	Аляты	5	50	1177	102.18606699999999	102.247027	53.228724	53.192593000000002	0103000020E6100000010000000500000059F78F85E88B594022382EE3A6984A4059F78F85E88B5940B8E7F9D3469D4A40A88E554ACF8F5940B8E7F9D3469D4A40A88E554ACF8F594022382EE3A6984A4059F78F85E88B594022382EE3A6984A40
51926	Алзобей	5	50	1177	102.623817	102.635468	53.116875999999998	53.111628000000003	0103000020E61000000100000005000000166C239EECA75940B1A888D3498E4A40166C239EECA75940F9D7F2CAF58E4A40E469F981ABA85940F9D7F2CAF58E4A40E469F981ABA85940B1A888D3498E4A40166C239EECA75940B1A888D3498E4A40
51934	Александровск	5	50	1177	102.643373	102.66902899999999	53.353203000000001	53.328890999999999	0103000020E610000001000000050000004888F2052DA959407079AC1919AA4A404888F2052DA95940AFEC82C135AD4A40D6C4025FD1AA5940AFEC82C135AD4A40D6C4025FD1AA59407079AC1919AA4A404888F2052DA959407079AC1919AA4A40
51923	Аларь	5	50	1177	102.525505	102.56018899999999	53.076852000000002	53.062291999999999	0103000020E610000001000000050000009B38B9DFA1A15940B6662B2FF9874A409B38B9DFA1A15940EC504D49D6894A400DA5F622DAA35940EC504D49D6894A400DA5F622DAA35940B6662B2FF9874A409B38B9DFA1A15940B6662B2FF9874A40
60046	Шилка	5	48	\N	115.972449	116.069503	51.875777999999997	51.837085000000002	0103000020E61000000100000005000000C901BB9A3CFE5C40707CED9925EB4940C901BB9A3CFE5C403447567E19F0494054FEB5BC72045D403447567E19F0494054FEB5BC72045D40707CED9925EB4940C901BB9A3CFE5C40707CED9925EB4940
50869	Чита	5	48	\N	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
54090	Чита	5	48	\N	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
29213	Петровск-Забайкальский	5	48	\N	108.772919	108.911907	51.336545999999998	51.221228000000004	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
60040	Нерчинск	5	48	\N	116.5086	116.610891	52.007510000000003	51.924886000000001	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
60023	Краснокаменск	5	48	\N	118.00953199999999	118.199499	50.151226000000001	50.059877	0103000020E61000000100000005000000FD101B2C9C805D402C64AE0CAA074940FD101B2C9C805D400727A25F5B1349406C257497C48C5D400727A25F5B1349406C257497C48C5D402C64AE0CAA074940FD101B2C9C805D402C64AE0CAA074940
60045	Балей	5	48	\N	116.58400399999999	116.722525	51.600928000000003	51.538722	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
51745	Чита	5	48	7101	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
557	Шилка	5	48	178	115.972449	116.069503	51.875777999999997	51.837085000000002	0103000020E61000000100000005000000C901BB9A3CFE5C40707CED9925EB4940C901BB9A3CFE5C403447567E19F0494054FEB5BC72045D403447567E19F0494054FEB5BC72045D40707CED9925EB4940C901BB9A3CFE5C40707CED9925EB4940
2226	Чирон	5	48	178	115.76881	115.785618	51.640607000000003	51.615375999999998	0103000020E610000001000000050000009EB5DB2E34F15C40245F09A4C4CE49409EB5DB2E34F15C405A4B0169FFD149408849B89047F25C405A4B0169FFD149408849B89047F25C40245F09A4C4CE49409EB5DB2E34F15C40245F09A4C4CE4940
1038	Холбон	5	48	178	116.216989	116.264402	51.911181999999997	51.896957	0103000020E61000000100000005000000DFA5D425E30D5D408A75AA7CCFF24940DFA5D425E30D5D40185A9D9CA1F44940CFBF5DF6EB105D40185A9D9CA1F44940CFBF5DF6EB105D408A75AA7CCFF24940DFA5D425E30D5D408A75AA7CCFF24940
2123	Усть-Теленгуй	5	48	178	115.95283000000001	115.974228	51.551648999999998	51.538386000000003	0103000020E610000001000000050000007429AE2AFBFC5C40E84F1BD5E9C449407429AE2AFBFC5C4080EF366F9CC649403DB665C059FE5C4080EF366F9CC649403DB665C059FE5C40E84F1BD5E9C449407429AE2AFBFC5C40E84F1BD5E9C44940
60220	Усть-Ножовая	5	48	178	115.757015	115.784234	51.474224999999997	51.460282999999997	0103000020E6100000010000000500000036E50AEF72F05C40CFF3A78DEABA494036E50AEF72F05C4009F9A067B3BC4940529ACDE330F25C4009F9A067B3BC4940529ACDE330F25C40CFF3A78DEABA494036E50AEF72F05C40CFF3A78DEABA4940
3145	Ульяновка	5	48	178	115.78303099999999	115.79739499999999	52.068061999999998	52.055764000000003	0103000020E6100000010000000500000044300E2E1DF25C40A725564623074A4044300E2E1DF25C40D80C7041B6084A409CBF098508F35C40D80C7041B6084A409CBF098508F35C40A725564623074A4044300E2E1DF25C40A725564623074A40
1995	Средняя Кия	5	48	178	115.63498800000001	115.649658	51.997225	51.989749000000003	0103000020E610000001000000050000008F56B5A4A3E85C40D61F6118B0FE49408F56B5A4A3E85C4076E09C11A5FF49406DE525FF93E95C4076E09C11A5FF49406DE525FF93E95C40D61F6118B0FE49408F56B5A4A3E85C40D61F6118B0FE4940
60217	Саввино	5	48	178	115.074709	115.09317799999999	51.770819000000003	51.756960999999997	0103000020E61000000100000005000000E1ED4108C8C45C4079AC1919E4E04940E1ED4108C8C45C4056116E32AAE249403AADDBA0F6C55C4056116E32AAE249403AADDBA0F6C55C4079AC1919E4E04940E1ED4108C8C45C4079AC1919E4E04940
2439	Размахнино	5	48	178	115.47922	115.500106	51.788091999999999	51.763461	0103000020E61000000100000005000000B4E55C8AABDE5C40BF620D17B9E14940B4E55C8AABDE5C409F1EDB32E0E4494023A298BC01E05C409F1EDB32E0E4494023A298BC01E05C40BF620D17B9E14940B4E55C8AABDE5C40BF620D17B9E14940
1166	Первомайский	5	48	178	115.59292000000001	115.649092	51.674599999999998	51.652718	0103000020E610000001000000050000003D49BA66F2E55C4059C16F438CD349403D49BA66F2E55C40D8F0F44A59D6494018062CB98AE95C40D8F0F44A59D6494018062CB98AE95C4059C16F438CD349403D49BA66F2E55C4059C16F438CD34940
60039	Первомайский	5	48	178	115.59292000000001	115.649092	51.674599999999998	51.652718	0103000020E610000001000000050000003D49BA66F2E55C4059C16F438CD349403D49BA66F2E55C40D8F0F44A59D6494018062CB98AE95C40D8F0F44A59D6494018062CB98AE95C4059C16F438CD349403D49BA66F2E55C4059C16F438CD34940
2896	Островки	5	48	178	115.96993399999999	115.98985	52.076830000000001	52.066040999999998	0103000020E61000000100000005000000D2510E6613FE5C40FA980F0874084A40D2510E6613FE5C4004ADC090D5094A40857CD0B359FF5C4004ADC090D5094A40857CD0B359FF5C40FA980F0874084A40D2510E6613FE5C40FA980F0874084A40
3153	Ононское	5	48	178	115.937918	115.96829	51.490502999999997	51.468755000000002	0103000020E610000001000000050000001A1538D906FC5C40126BF12900BC49401A1538D906FC5C4081CB63CDC8BE4940CEC29E76F8FD5C4081CB63CDC8BE4940CEC29E76F8FD5C40126BF12900BC49401A1538D906FC5C40126BF12900BC4940
2350	Номоконово	5	48	178	115.48257099999999	115.50767	51.645850000000003	51.631714000000002	0103000020E61000000100000005000000DFBF7971E2DE5C4072361D01DCD04940DFBF7971E2DE5C40910F7A36ABD2494043CA4FAA7DE05C40910F7A36ABD2494043CA4FAA7DE05C4072361D01DCD04940DFBF7971E2DE5C4072361D01DCD04940
2763	Новоберезовское	5	48	178	116.08517000000001	116.114994	52.11974	52.111572000000002	0103000020E610000001000000050000006C26DF6C73055D401D93C5FD470E4A406C26DF6C73055D40F302ECA3530F4A401E4FCB0F5C075D40F302ECA3530F4A401E4FCB0F5C075D401D93C5FD470E4A406C26DF6C73055D401D93C5FD470E4A40
2804	Нижняя Хила	5	48	178	116.146013	116.15807700000001	52.065398999999999	52.051654999999997	0103000020E610000001000000050000009DF2E84658095D4062D68BA19C064A409DF2E84658095D40761893FE5E084A40FD4FFEEE1D0A5D40761893FE5E084A40FD4FFEEE1D0A5D4062D68BA19C064A409DF2E84658095D4062D68BA19C064A40
1834	Митрофаново	5	48	178	115.94223	115.964589	51.824378000000003	51.815019999999997	0103000020E61000000100000005000000D8D30E7F4DFC5C40FFCA4A9352E84940D8D30E7F4DFC5C405DC5E23785E94940354580D3BBFD5C405DC5E23785E94940354580D3BBFD5C40FFCA4A9352E84940D8D30E7F4DFC5C40FFCA4A9352E84940
1735	Мирсаново	5	48	178	116.132188	116.174516	51.891689	51.881399000000002	0103000020E610000001000000050000001D3BA8C475085D4012DDB3AED1F049401D3BA8C475085D40FA997ADD22F249403D2828452B0B5D40FA997ADD22F249403D2828452B0B5D4012DDB3AED1F049401D3BA8C475085D4012DDB3AED1F04940
2091	Кыэкен	5	48	178	115.40704100000001	115.42627400000001	52.066462000000001	52.058931999999999	0103000020E6100000010000000500000065C8B1F50CDA5C400C5872158B074A4065C8B1F50CDA5C40A036AAD381084A40A648BE1248DB5C40A036AAD381084A40A648BE1248DB5C400C5872158B074A4065C8B1F50CDA5C400C5872158B074A40
2465	Красноярово	5	48	178	115.57842100000001	115.602721	51.770718000000002	51.764781999999997	0103000020E61000000100000005000000759483D904E55C40E4486760E4E14940759483D904E55C4022382EE3A6E2494032E719FB92E65C4022382EE3A6E2494032E719FB92E65C40E4486760E4E14940759483D904E55C40E4486760E4E14940
1870	Кокуй-Комогорцево	5	48	178	115.85857	115.868101	51.937514999999998	51.929141000000001	0103000020E61000000100000005000000E9D495CFF2F65C40B62FA017EEF64940E9D495CFF2F65C403541D47D00F84940FE277FF78EF75C403541D47D00F84940FE277FF78EF75C40B62FA017EEF64940E9D495CFF2F65C40B62FA017EEF64940
2316	Кироча	5	48	178	115.828422	115.845769	51.605823000000001	51.585490999999998	0103000020E610000001000000050000005D52B5DD04F55C40198D7C5EF1CA49405D52B5DD04F55C401215AA9B8BCD49401FBE4C1421F65C401215AA9B8BCD49401FBE4C1421F65C40198D7C5EF1CA49405D52B5DD04F55C40198D7C5EF1CA4940
1760	Кибасово (Выселок)	5	48	178	116.067931	116.08613099999999	51.866909	51.859378	0103000020E610000001000000050000009DD843FB58045D4071732A1900EE49409DD843FB58045D40D5CDC5DFF6EE4940FE0A992B83055D40D5CDC5DFF6EE4940FE0A992B83055D4071732A1900EE49409DD843FB58045D4071732A1900EE4940
1662	Казаново	5	48	178	115.847835	115.887657	51.799829000000003	51.751877	0103000020E61000000100000005000000DE59BBED42F65C40ABCE6A813DE04940DE59BBED42F65C403AB2F2CB60E6494031444E5FCFF85C403AB2F2CB60E6494031444E5FCFF85C40ABCE6A813DE04940DE59BBED42F65C40ABCE6A813DE04940
2660	Зубарево	5	48	178	115.256986	115.283073	51.788849999999996	51.782319999999999	0103000020E61000000100000005000000E961687572D05C40DC80CF0F23E44940E961687572D05C408CB96B09F9E449405C5837DE1DD25C408CB96B09F9E449405C5837DE1DD25C40DC80CF0F23E44940E961687572D05C40DC80CF0F23E44940
2576	Галкино	5	48	178	115.17506	115.195038	51.783355999999998	51.769804000000001	0103000020E610000001000000050000009EB5DB2E34CB5C403D2AFEEF88E249409EB5DB2E34CB5C400C90680245E449408BDEA9807BCC5C400C90680245E449408BDEA9807BCC5C403D2AFEEF88E249409EB5DB2E34CB5C403D2AFEEF88E24940
3000	Верхняя Хила	5	48	178	115.873392	115.906423	52.093693000000002	52.079901999999997	0103000020E61000000100000005000000A2258FA7E5F75C4047718E3A3A0A4A40A2258FA7E5F75C409C6ED921FE0B4A40E7559DD502FA5C409C6ED921FE0B4A40E7559DD502FA5C4047718E3A3A0A4A40A2258FA7E5F75C4047718E3A3A0A4A40
3043	Васильевка	5	48	178	115.933031	115.945832	52.031368999999998	52.022807999999998	0103000020E61000000100000005000000DEC9A7C7B6FB5C40280B5F5FEB024A40DEC9A7C7B6FB5C40DA8D3EE603044A40A8E0F08288FC5C40DA8D3EE603044A40A8E0F08288FC5C40280B5F5FEB024A40DEC9A7C7B6FB5C40280B5F5FEB024A40
50793	Богомягково	5	48	178	115.779509	115.807007	51.998994000000003	51.985207000000003	0103000020E61000000100000005000000037CB779E3F15C40286552431BFE4940037CB779E3F15C403B730F09DFFF49402829B000A6F35C403B730F09DFFF49402829B000A6F35C40286552431BFE4940037CB779E3F15C40286552431BFE4940
1067	Арбагар	5	48	178	116.264608	116.29595999999999	51.949506	51.935915000000001	0103000020E61000000100000005000000A3906456EF105D40FD6A0E10CCF74940A3906456EF105D408AADA06989F94940253B3602F1125D408AADA06989F94940253B3602F1125D40FD6A0E10CCF74940A3906456EF105D40FD6A0E10CCF74940
60175	Шивия	5	48	15	117.41261	117.438158	51.896157000000002	51.876033999999997	0103000020E610000001000000050000002A00C633685A5D408F17D2E121F049402A00C633685A5D406E8AC745B5F24940C51EDAC70A5C5D406E8AC745B5F24940C51EDAC70A5C5D408F17D2E121F049402A00C633685A5D408F17D2E121F04940
50952	Шелопугино	5	48	15	117.52985	117.58996500000001	51.668925000000002	51.634324999999997	0103000020E610000001000000050000004772F90FE9615D408104C58F31D149404772F90FE9615D40083D9B559FD5494038328FFCC1655D40083D9B559FD5494038328FFCC1655D408104C58F31D149404772F90FE9615D408104C58F31D14940
60205	Нижняя Шахтама	5	48	15	117.682419	117.695652	51.403440000000003	51.377355999999999	0103000020E61000000100000005000000D1CABDC0AC6B5D4085798F334DB04940D1CABDC0AC6B5D40FAF202ECA3B349406859F78F856C5D40FAF202ECA3B349406859F78F856C5D4085798F334DB04940D1CABDC0AC6B5D4085798F334DB04940
50976	Мироново	5	48	15	117.638357	117.654419	51.989578000000002	51.964751999999997	0103000020E610000001000000050000000D8B51D7DA685D40136058FE7CFB49400D8B51D7DA685D40A96BED7DAAFE494063B83A00E2695D40A96BED7DAAFE494063B83A00E2695D40136058FE7CFB49400D8B51D7DA685D40136058FE7CFB4940
51435	Малый Тонтой	5	48	15	117.778746	117.807725	51.845638000000001	51.826971999999998	0103000020E61000000100000005000000037976F9D6715D40965AEF37DAE94940037976F9D6715D409F20B1DD3DEC494058CA32C4B1735D409F20B1DD3DEC494058CA32C4B1735D40965AEF37DAE94940037976F9D6715D40965AEF37DAE94940
60216	Копунь	5	48	15	117.634539	117.65902699999999	51.899307999999998	51.853549000000001	0103000020E61000000100000005000000574277499C685D404A44F81741ED4940574277499C685D40FD8348861CF34940950B957F2D6A5D40FD8348861CF34940950B957F2D6A5D404A44F81741ED4940574277499C685D404A44F81741ED4940
60202	Копунское	5	48	15	117.28089900000001	118.656993	52.137796999999999	51.211795000000002	0103000020E61000000100000005000000AA9ECC3FFA515D40693A3B191C9B4940AA9ECC3FFA515D40533E0455A3114A40DC2C5E2C0CAA5D40533E0455A3114A40DC2C5E2C0CAA5D40693A3B191C9B4940AA9ECC3FFA515D40693A3B191C9B4940
51726	Глинянка	5	48	15	117.394626	117.41632	51.664641000000003	51.652757000000001	0103000020E61000000100000005000000AF09698D41595D40179E978A8DD34940AF09698D41595D40564ACFF412D54940ED2AA4FCA45A5D40564ACFF412D54940ED2AA4FCA45A5D40179E978A8DD34940AF09698D41595D40179E978A8DD34940
50786	Вершино-Шахтаминский	5	48	15	117.864912	117.914706	51.305970000000002	51.283306000000003	0103000020E61000000100000005000000C07ADCB75A775D405B61FA5E43A44940C07ADCB75A775D4050C763062AA749401EDD088B8A7A5D4050C763062AA749401EDD088B8A7A5D405B61FA5E43A44940C07ADCB75A775D405B61FA5E43A44940
7983	Яблоново	5	48	208	112.744389	112.772507	51.848346999999997	51.835521	0103000020E6100000010000000500000023A0C211A42F5C40840F255AF2EA494023A0C211A42F5C4071546EA296EC4940973B33C170315C4071546EA296EC4940973B33C170315C40840F255AF2EA494023A0C211A42F5C40840F255AF2EA4940
7308	Шишкино	5	48	208	113.571163	113.59345	52.319693000000001	52.297117	0103000020E61000000100000005000000DB6B41EF8D645C40F60A0BEE07264A40DB6B41EF8D645C404CE141B3EB284A40EB73B515FB655C404CE141B3EB284A40EB73B515FB655C40F60A0BEE07264A40DB6B41EF8D645C40F60A0BEE07264A40
50808	Чита	5	48	208	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
8621	Черново	5	48	208	113.24263999999999	113.251102	51.961194999999996	51.952475999999997	0103000020E61000000100000005000000E42CEC69874F5C40C91CCBBBEAF94940E42CEC69874F5C40130A117008FB4940747D1F0E12505C40130A117008FB4940747D1F0E12505C40C91CCBBBEAF94940E42CEC69874F5C40C91CCBBBEAF94940
60055	Угдан	5	48	208	113.440997	113.463751	52.165509	52.150402999999997	0103000020E6100000010000000500000095287B4B395C5C40321CCF6740134A4095287B4B395C5C40CA181F662F154A40309FAC18AE5D5C40CA181F662F154A40309FAC18AE5D5C40321CCF6740134A4095287B4B395C5C40321CCF6740134A40
7611	Тасей	5	48	208	112.944148	112.962958	52.219572999999997	52.210633999999999	0103000020E610000001000000050000005DA5BBEB6C3C5C407CB60E0EF61A4A405DA5BBEB6C3C5C40D40AD3F71A1C4A40FB5A971AA13D5C40D40AD3F71A1C4A40FB5A971AA13D5C407CB60E0EF61A4A405DA5BBEB6C3C5C407CB60E0EF61A4A40
8890	Танха	5	48	208	113.962559	113.978261	51.999974999999999	51.987037000000001	0103000020E610000001000000050000001C5E10919A7D5C409278793A57FE49401C5E10919A7D5C40A7E8482EFFFF4940F27C06D49B7E5C40A7E8482EFFFF4940F27C06D49B7E5C409278793A57FE49401C5E10919A7D5C409278793A57FE4940
9504	Сыпчегур	5	48	208	113.436954	113.457014	51.356499999999997	51.346859000000002	0103000020E61000000100000005000000CFF6E80DF75B5C4061A92EE065AC4940CFF6E80DF75B5C401283C0CAA1AD49401BF4A5B73F5D5C401283C0CAA1AD49401BF4A5B73F5D5C4061A92EE065AC4940CFF6E80DF75B5C4061A92EE065AC4940
7871	Сохондо	5	48	208	112.492789	112.54422700000001	51.837513999999999	51.807747999999997	0103000020E6100000010000000500000007B5DFDA891F5C4067B4554964E7494007B5DFDA891F5C4098F8A3A833EB49406AA67B9DD4225C4098F8A3A833EB49406AA67B9DD4225C4067B4554964E7494007B5DFDA891F5C4067B4554964E74940
795	Смоленка	5	48	208	113.48650499999999	113.52632800000001	52.149889000000002	52.129184000000002	0103000020E61000000100000005000000CA15DEE5225F5C404F95EF1989104A40CA15DEE5225F5C40DC8310902F134A4006BEA25BAF615C40DC8310902F134A4006BEA25BAF615C404F95EF1989104A40CA15DEE5225F5C404F95EF1989104A40
8665	Сивяково	5	48	208	113.22173600000001	113.243628	51.900596999999998	51.887542000000003	0103000020E61000000100000005000000231631EC304E5C40C9E9EBF99AF14940231631EC304E5C4017F032C346F34940F418E599974F5C4017F032C346F34940F418E599974F5C40C9E9EBF99AF14940231631EC304E5C40C9E9EBF99AF14940
7659	Преображенка	5	48	208	112.821303	112.834796	52.224263000000001	52.205219999999997	0103000020E61000000100000005000000D446753A90345C40183E22A6441A4A40D446753A90345C40F75965A6B41C4A4039B5334C6D355C40F75965A6B41C4A4039B5334C6D355C40183E22A6441A4A40D446753A90345C40183E22A6441A4A40
7196	Подволок	5	48	208	113.674244	113.687207	52.427323000000001	52.414076000000001	0103000020E610000001000000050000008D614ED0266B5C407D073F7100354A408D614ED0266B5C4010EA2285B2364A4044A51133FB6B5C4010EA2285B2364A4044A51133FB6B5C407D073F7100354A408D614ED0266B5C407D073F7100354A40
60052	Песчанка	5	48	208	112.214195	114.647093	53.057198999999997	50.957998000000003	0103000020E61000000100000005000000DFFDF15EB50D5C4014D1AFAD9F7A4940DFFDF15EB50D5C40942EFD4B52874A401D1EC2F869A95C40942EFD4B52874A401D1EC2F869A95C4014D1AFAD9F7A4940DFFDF15EB50D5C4014D1AFAD9F7A4940
9555	Оленгуй	5	48	208	113.398884	113.42758499999999	51.314196000000003	51.299781000000003	0103000020E6100000010000000500000073B9C15087595C40297B4B395FA6494073B9C15087595C405B44149337A84940A6D0798D5D5B5C405B44149337A84940A6D0798D5D5B5C40297B4B395FA6494073B9C15087595C40297B4B395FA64940
8833	Новотроицк	5	48	208	114.075351	114.105948	51.998367000000002	51.973768999999997	0103000020E61000000100000005000000232E008DD2845C40E76D6C76A4FC4940232E008DD2845C40EC33677DCAFF4940E7C41EDAC7865C40EC33677DCAFF4940E7C41EDAC7865C40E76D6C76A4FC4940232E008DD2845C40E76D6C76A4FC4940
60051	Новокручининский	5	48	208	113.73924599999999	113.829401	51.826371000000002	51.743729999999999	0103000020E61000000100000005000000B96C74CE4F6F5C40EC866D8B32DF4940B96C74CE4F6F5C4071AE6186C6E949404391EEE714755C4071AE6186C6E949404391EEE714755C40EC866D8B32DF4940B96C74CE4F6F5C40EC866D8B32DF4940
51414	Новокручининский	5	48	208	113.73924599999999	113.829401	51.826371000000002	51.743729999999999	0103000020E61000000100000005000000B96C74CE4F6F5C40EC866D8B32DF4940B96C74CE4F6F5C4071AE6186C6E949404391EEE714755C4071AE6186C6E949404391EEE714755C40EC866D8B32DF4940B96C74CE4F6F5C40EC866D8B32DF4940
8241	Новая Кука	5	48	208	113.041696	113.072957	51.806722999999998	51.782069	0103000020E61000000100000005000000F017B325AB425C40931B45D61AE44940F017B325AB425C402BF702B342E74940EA40D653AB445C402BF702B342E74940EA40D653AB445C40931B45D61AE44940F017B325AB425C40931B45D61AE44940
51867	Маккавеево	5	48	208	113.90084400000001	113.974569	51.765552	51.740819000000002	0103000020E6100000010000000500000010B3976DA7795C40B2A03028D3DE494010B3976DA7795C4096B1A19BFDE1494082ACA7565F7E5C4096B1A19BFDE1494082ACA7565F7E5C40B2A03028D3DE494010B3976DA7795C40B2A03028D3DE4940
50697	Лесной Городок	5	48	208	113.05073299999999	113.088902	51.743284000000003	51.715693999999999	0103000020E61000000100000005000000FDF49F353F435C40C2F869DC9BDB4940FDF49F353F435C40EED11BEE23DF494023A30392B0455C40EED11BEE23DF494023A30392B0455C40C2F869DC9BDB4940FDF49F353F435C40C2F869DC9BDB4940
4189	Лесная	5	48	208	112.99436300000001	113.024394	51.778976999999998	51.762245999999998	0103000020E610000001000000050000008F56B5A4A33F5C40DFC0E44691E149408F56B5A4A33F5C4008ABB184B5E34940FE0DDAAB8F415C4008ABB184B5E34940FE0DDAAB8F415C40DFC0E44691E149408F56B5A4A33F5C40DFC0E44691E14940
47729	Ленинский	5	48	208	113.06851	113.087609	51.135323	51.128754999999998	0103000020E61000000100000005000000BC5CC47762445C402619390B7B904940BC5CC47762445C40C4B29943529149407575C7629B455C40C4B29943529149407575C7629B455C402619390B7B904940BC5CC47762445C402619390B7B904940
8573	Колочное 1-е	5	48	208	113.158081	113.167316	51.965212999999999	51.957604000000003	0103000020E610000001000000050000009D47C5FF1D4A5C40684293C492FA49409D47C5FF1D4A5C4047567E198CFB49403E062B4EB54A5C4047567E198CFB49403E062B4EB54A5C40684293C492FA49409D47C5FF1D4A5C40684293C492FA4940
7522	Карповка	5	48	208	113.522869	113.538769	52.211903	52.198706999999999	0103000020E61000000100000005000000E7C589AF76615C403E3E213B6F194A40E7C589AF76615C404F7633A31F1B4A4050C6F8307B625C404F7633A31F1B4A4050C6F8307B625C403E3E213B6F194A40E7C589AF76615C403E3E213B6F194A40
7781	Иргень	5	48	208	112.575048	112.586699	51.989100999999998	51.974938999999999	0103000020E6100000010000000500000055682096CD245C40274C18CDCAFC494055682096CD245C406FB88FDC9AFE49402366F6798C255C406FB88FDC9AFE49402366F6798C255C40274C18CDCAFC494055682096CD245C40274C18CDCAFC4940
8340	Ингода	5	48	208	113.08906399999999	113.113435	51.864244999999997	51.837674999999997	0103000020E610000001000000050000000FD07D39B3455C40A1D634EF38EB49400FD07D39B3455C40A25D85949FEE494031CEDF8442475C40A25D85949FEE494031CEDF8442475C40A1D634EF38EB49400FD07D39B3455C40A1D634EF38EB4940
8799	Ильинка	5	48	208	114.161598	114.19020999999999	52.074412000000002	52.053820000000002	0103000020E610000001000000050000005646239F578A5C4074EFE192E3064A405646239F578A5C400937195586094A40D15790662C8C5C400937195586094A40D15790662C8C5C4074EFE192E3064A405646239F578A5C4074EFE192E3064A40
7587	Иван-Озеро	5	48	208	112.97455600000001	113.021762	52.275835999999998	52.249599000000003	0103000020E61000000100000005000000B80721205F3E5C40A20E2BDCF21F4A40B80721205F3E5C409C8713984E234A40EA92718C64415C409C8713984E234A40EA92718C64415C40A20E2BDCF21F4A40B80721205F3E5C40A20E2BDCF21F4A40
60060	Засопка	5	48	208	113.410167	113.42627299999999	52.014023000000002	52.006357000000001	0103000020E6100000010000000500000080B9162D405A5C40E38C614ED0004A4080B9162D405A5C4027327381CB014A40BD8A8C0E485B5C4027327381CB014A40BD8A8C0E485B5C40E38C614ED0004A4080B9162D405A5C40E38C614ED0004A40
8284	Жипковщина	5	48	208	112.99861199999999	113.02393600000001	51.810644000000003	51.797516999999999	0103000020E6100000010000000500000029594E42E93F5C4084807C0915E6494029594E42E93F5C406D59BE2EC3E749409D4CDC2A88415C406D59BE2EC3E749409D4CDC2A88415C4084807C0915E6494029594E42E93F5C4084807C0915E64940
8720	Ерёмино	5	48	208	113.331852	113.348551	51.961928	51.953758000000001	0103000020E610000001000000050000002EC72B103D555C403126FDBD14FA49402EC72B103D555C40A88DEA7420FB49403D7FDAA84E565C40A88DEA7420FB49403D7FDAA84E565C403126FDBD14FA49402EC72B103D555C403126FDBD14FA4940
9358	Елизаветино	5	48	208	113.596711	113.616995	51.667651999999997	51.651159	0103000020E61000000100000005000000768A558330665C407FBF982D59D34940768A558330665C40F38DE89E75D54940EAB298D87C675C40F38DE89E75D54940EAB298D87C675C407FBF982D59D34940768A558330665C407FBF982D59D34940
8385	Домно-Ключи	5	48	208	112.981194	113.00985900000001	51.974694999999997	51.952964000000001	0103000020E610000001000000050000000342EBE1CB3E5C40F7216FB9FAF949400342EBE1CB3E5C40904946CEC2FC494090A4A487A1405C40904946CEC2FC494090A4A487A1405C40F7216FB9FAF949400342EBE1CB3E5C40F7216FB9FAF94940
59034	Домна	5	48	208	113.13146399999999	113.179919	51.916888	51.879269999999998	0103000020E610000001000000050000007C26FBE769485C404D2D5BEB8BF049407C26FBE769485C40240C03965CF54940753BFBCA834B5C40240C03965CF54940753BFBCA834B5C404D2D5BEB8BF049407C26FBE769485C404D2D5BEB8BF04940
9452	Верхний-Нарым	5	48	208	113.424504	113.458595	51.587448999999999	51.576608999999998	0103000020E610000001000000050000005B41D3122B5B5C4025CADE52CEC949405B41D3122B5B5C40B188618731CB4940FCC6D79E595D5C40B188618731CB4940FCC6D79E595D5C4025CADE52CEC949405B41D3122B5B5C4025CADE52CEC94940
51816	Верх-Чита	5	48	208	113.491958	113.52401	52.245238000000001	52.217945	0103000020E610000001000000050000005B40683D7C5F5C40D2A92B9FE51B4A405B40683D7C5F5C4044DE72F5631F4A40BA313D6189615C4044DE72F5631F4A40BA313D6189615C40D2A92B9FE51B4A405B40683D7C5F5C40D2A92B9FE51B4A40
7159	Бургень	5	48	208	113.764956	113.78965100000001	52.430183999999997	52.413773999999997	0103000020E6100000010000000500000041B8020AF5705C40B1F7E28BF6344A4041B8020AF5705C4098A1F14410374A403D1059A489725C4098A1F14410374A403D1059A489725C40B1F7E28BF6344A4041B8020AF5705C40B1F7E28BF6344A40
7733	Беклемишево	5	48	208	112.662571	112.694102	52.130488999999997	52.108263999999998	0103000020E61000000100000005000000CB113290672A5C40C5AA4198DB0D4A40CB113290672A5C406EBE11DDB3104A40A585CB2A6C2C5C406EBE11DDB3104A40A585CB2A6C2C5C40C5AA4198DB0D4A40CB113290672A5C40C5AA4198DB0D4A40
60044	Атамановка	5	48	208	113.608694	113.665306	51.951982000000001	51.906292999999998	0103000020E610000001000000050000005FD1ADD7F4665C40FFCBB56801F449405FD1ADD7F4665C40BA30D28BDAF9494049F59D5F946A5C40BA30D28BDAF9494049F59D5F946A5C40FFCBB56801F449405FD1ADD7F4665C40FFCBB56801F44940
40314	Атамановка	5	48	208	113.608694	113.665306	51.951982000000001	51.906292999999998	0103000020E610000001000000050000005FD1ADD7F4665C40FFCBB56801F449405FD1ADD7F4665C40BA30D28BDAF9494049F59D5F946A5C40BA30D28BDAF9494049F59D5F946A5C40FFCBB56801F449405FD1ADD7F4665C40FFCBB56801F44940
7699	Арахлей	5	48	208	112.826199	112.847615	52.166972999999999	52.158703000000003	0103000020E610000001000000050000003A3FC571E0345C407863416150144A403A3FC571E0345C4052280B5F5F154A405726FC523F365C4052280B5F5F154A405726FC523F365C407863416150144A403A3FC571E0345C407863416150144A40
7254	Авдей	5	48	208	113.630487	113.642426	52.375228999999997	52.365105999999997	0103000020E61000000100000005000000676325E659685C4064C91CCBBB2E4A40676325E659685C4061C1FD8007304A406806F1811D695C4061C1FD8007304A406806F1811D695C4064C91CCBBB2E4A40676325E659685C4064C91CCBBB2E4A40
59093	Чернышевск	5	48	1886	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
51513	Чернышевск	5	48	1886	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
51648	Чернышевск	5	48	1886	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
59482	Утан	5	48	1886	116.97152	116.99457	52.584806999999998	52.560533	0103000020E610000001000000050000003CDA38622D3E5D4015AA9B8BBF474A403CDA38622D3E5D4066BCADF4DA4A4A404BE5ED08A73F5D4066BCADF4DA4A4A404BE5ED08A73F5D4015AA9B8BBF474A403CDA38622D3E5D4015AA9B8BBF474A40
51731	Урюм	5	48	1886	118.09264400000001	118.12521700000001	53.176653000000002	53.161354000000003	0103000020E61000000100000005000000EC8A19E1ED855D40168A743FA7944A40EC8A19E1ED855D40C2DEC4909C964A40CFF9298E03885D40C2DEC4909C964A40CFF9298E03885D40168A743FA7944A40EC8A19E1ED855D40168A743FA7944A40
60088	Укурей	5	48	1886	117.00381400000001	117.033333	52.356186000000001	52.339027000000002	0103000020E610000001000000050000001651137D3E405D4002BB9A3C652B4A401651137D3E405D4083A5BA80972D4A402A38BC2022425D4083A5BA80972D4A402A38BC2022425D4002BB9A3C652B4A401651137D3E405D4002BB9A3C652B4A40
50725	Старый Олов	5	48	1886	116.64819799999999	116.687535	52.463562000000003	52.444859000000001	0103000020E6100000010000000500000049D576137C295D40672AC423F1384A4049D576137C295D408DD5E6FF553B4A40BEF6CC92002C5D408DD5E6FF553B4A40BEF6CC92002C5D40672AC423F1384A4049D576137C295D40672AC423F1384A40
60153	Новый Олов	5	48	1886	116.509426	116.525542	52.619259	52.594856999999998	0103000020E61000000100000005000000DB6E826F9A205D40F9653046244C4A40DB6E826F9A205D40786000E1434F4A402AABE97AA2215D40786000E1434F4A402AABE97AA2215D40F9653046244C4A40DB6E826F9A205D40F9653046244C4A40
60192	Новоильинск	5	48	1886	116.752025	116.779127	52.524478999999999	52.501306	0103000020E610000001000000050000009031772D21305D40F0A485CB2A404A409031772D21305D402A38BC2022434A408F1B7E37DD315D402A38BC2022434A408F1B7E37DD315D40F0A485CB2A404A409031772D21305D40F0A485CB2A404A40
60114	Мильгидун	5	48	1886	116.914108	116.932712	52.668692999999998	52.649898	0103000020E61000000100000005000000C440D7BE803A5D402FDE8FDB2F534A40C440D7BE803A5D40350873BB97554A408D25AC8DB13B5D40350873BB97554A408D25AC8DB13B5D402FDE8FDB2F534A40C440D7BE803A5D402FDE8FDB2F534A40
51750	Курлыч	5	48	1886	117.239721	117.258765	52.382309999999997	52.367030999999997	0103000020E6100000010000000500000086CABF96574F5D4020CF2EDFFA2E4A4086CABF96574F5D408577B988EF304A405D16139B8F505D408577B988EF304A405D16139B8F505D4020CF2EDFFA2E4A4086CABF96574F5D4020CF2EDFFA2E4A40
51887	Комсомольское	5	48	1886	116.853247	116.882712	52.360436999999997	52.340451999999999	0103000020E610000001000000050000003F1A4E999B365D40CCED5EEE932B4A403F1A4E999B365D4059A2B3CC222E4A405AF2785A7E385D4059A2B3CC222E4A405AF2785A7E385D40CCED5EEE932B4A403F1A4E999B365D40CCED5EEE932B4A40
60191	Икшица	5	48	1886	117.187789	117.199764	52.473959000000001	52.464868000000003	0103000020E610000001000000050000001B6327BC044C5D407D7A6CCB803B4A401B6327BC044C5D408B5242B0AA3C4A40C3BAF1EEC84C5D408B5242B0AA3C4A40C3BAF1EEC84C5D407D7A6CCB803B4A401B6327BC044C5D407D7A6CCB803B4A40
59054	Жирекен	5	48	1886	117.266356	117.32019200000001	52.832929999999998	52.812142999999999	0103000020E61000000100000005000000FA4509FA0B515D407156444DF4674A40FA4509FA0B515D40BBED42739D6A4A40371C96067E545D40BBED42739D6A4A40371C96067E545D407156444DF4674A40FA4509FA0B515D407156444DF4674A40
60047	Жирекен	5	48	1886	117.266356	117.32019200000001	52.832929999999998	52.812142999999999	0103000020E61000000100000005000000FA4509FA0B515D407156444DF4674A40FA4509FA0B515D40BBED42739D6A4A40371C96067E545D40BBED42739D6A4A40371C96067E545D407156444DF4674A40FA4509FA0B515D407156444DF4674A40
60193	Гаур	5	48	1886	117.015232	117.032848	52.451813999999999	52.437156999999999	0103000020E610000001000000050000009276A38FF9405D40D61BB5C2F4374A409276A38FF9405D40FEEF880AD5394A404C6F7F2E1A425D40FEEF880AD5394A404C6F7F2E1A425D40D61BB5C2F4374A409276A38FF9405D40D61BB5C2F4374A40
50810	Бушулей	5	48	1886	117.26389399999999	117.28395399999999	52.755138000000002	52.734192999999998	0103000020E6100000010000000500000014E7A8A3E3505D40DFF94509FA5D4A4014E7A8A3E3505D40C2FBAA5CA8604A4060E4654D2C525D40C2FBAA5CA8604A4060E4654D2C525D40DFF94509FA5D4A4014E7A8A3E3505D40DFF94509FA5D4A40
60177	Букачача	5	48	1886	116.884158	116.971924	53.008625000000002	52.948830000000001	0103000020E61000000100000005000000CB9F6F0B96385D405ABBED4273794A40CB9F6F0B96385D40C976BE9F1A814A40A48CB800343E5D40C976BE9F1A814A40A48CB800343E5D405ABBED4273794A40CB9F6F0B96385D405ABBED4273794A40
50921	Букачача	5	48	1886	116.884158	116.971924	53.008625000000002	52.948830000000001	0103000020E61000000100000005000000CB9F6F0B96385D405ABBED4273794A40CB9F6F0B96385D40C976BE9F1A814A40A48CB800343E5D40C976BE9F1A814A40A48CB800343E5D405ABBED4273794A40CB9F6F0B96385D405ABBED4273794A40
60067	Байгул	5	48	1886	116.741353	116.761044	52.251539999999999	52.241433000000001	0103000020E61000000100000005000000A872DA53722F5D406C96CB46E71E4A40A872DA53722F5D4063D1747632204A404AB4E4F1B4305D4063D1747632204A404AB4E4F1B4305D406C96CB46E71E4A40A872DA53722F5D406C96CB46E71E4A40
51624	Багульный	5	48	1886	116.790401	116.80652600000001	52.412785	52.401853000000003	0103000020E61000000100000005000000726E13EE95325D4056664AEB6F334A40726E13EE95325D40C2A38D23D6344A40EB573A1F9E335D40C2A38D23D6344A40EB573A1F9E335D4056664AEB6F334A40726E13EE95325D4056664AEB6F334A40
51518	Алеур	5	48	1886	117.042118	117.074682	52.559930999999999	52.545009999999998	0103000020E61000000100000005000000AB24B20FB2425D4019FF3EE3C2454A40AB24B20FB2425D401F82AAD1AB474A4064E60297C7445D401F82AAD1AB474A4064E60297C7445D4019FF3EE3C2454A40AB24B20FB2425D4019FF3EE3C2454A40
51062	Аксеново-Зиловское	5	48	1886	117.47456699999999	117.531583	53.088827000000002	53.059466999999998	0103000020E61000000100000005000000B130444E5F5E5D407A185A9D9C874A40B130444E5F5E5D403B00E2AE5E8B4A400307B47405625D403B00E2AE5E8B4A400307B47405625D407A185A9D9C874A40B130444E5F5E5D407A185A9D9C874A40
60081	Аксеново-Зиловское	5	48	1886	117.47456699999999	117.531583	53.088827000000002	53.059466999999998	0103000020E61000000100000005000000B130444E5F5E5D407A185A9D9C874A40B130444E5F5E5D403B00E2AE5E8B4A400307B47405625D403B00E2AE5E8B4A400307B47405625D407A185A9D9C874A40B130444E5F5E5D407A185A9D9C874A40
60063	Хушенга	5	48	809	110.908987	110.937698	51.445627999999999	51.418204000000003	0103000020E610000001000000050000004E5FCFD72CBA5B4038876BB587B549404E5FCFD72CBA5B4048179B560AB9494093E1783E03BC5B4048179B560AB9494093E1783E03BC5B4038876BB587B549404E5FCFD72CBA5B4038876BB587B54940
50925	Хилок	5	48	809	110.406649	110.499257	51.378261999999999	51.336348999999998	0103000020E61000000100000005000000DFFC8689069A5B406A85E97B0DAB4940DFFC8689069A5B40E7A8A3E36AB0494024D3A1D3F39F5B40E7A8A3E36AB0494024D3A1D3F39F5B406A85E97B0DAB4940DFFC8689069A5B406A85E97B0DAB4940
6651	Хилогосон	5	48	809	110.63351900000001	110.640804	51.156511999999999	51.144190000000002	0103000020E61000000100000005000000429946938BA85B40833463D174924940429946938BA85B403DB7D0950894494058C9C7EE02A95B403DB7D0950894494058C9C7EE02A95B40833463D174924940429946938BA85B40833463D174924940
51545	Харагун	5	48	809	111.15463200000001	111.196951	51.565837999999999	51.542419000000002	0103000020E6100000010000000500000091BA9D7DE5C95B4051DD5CFC6DC5494091BA9D7DE5C95B40C26A2C616DC8494087FA5DD89ACC5B40C26A2C616DC8494087FA5DD89ACC5B4051DD5CFC6DC5494091BA9D7DE5C95B4051DD5CFC6DC54940
6049	Ушоты	5	48	809	109.635257	109.65030400000001	51.319831000000001	51.312911999999997	0103000020E6100000010000000500000086E3F90CA8685B4052431B800DA8494086E3F90CA8685B409D9FE238F0A84940501DAB949E695B409D9FE238F0A84940501DAB949E695B4052431B800DA8494086E3F90CA8685B4052431B800DA84940
6349	Тэрэпхэн	5	48	809	109.890361	109.902129	51.359875000000002	51.347268999999997	0103000020E610000001000000050000009128B4ACFB785B4012F5824F73AC49409128B4ACFB785B40F2D24D6210AE49407CF1457BBC795B40F2D24D6210AE49407CF1457BBC795B4012F5824F73AC49409128B4ACFB785B4012F5824F73AC4940
51009	Могзон	5	48	809	111.94682	111.997485	51.755389000000001	51.718935999999999	0103000020E61000000100000005000000B8CCE9B298FC5B4062F5471806DC4940B8CCE9B298FC5B400B613596B0E04940095053CBD6FF5B400B613596B0E04940095053CBD6FF5B4062F5471806DC4940B8CCE9B298FC5B4062F5471806DC4940
59031	Линево Озеро	5	48	809	110.63071600000001	110.67338599999999	51.372132999999998	51.347431999999998	0103000020E610000001000000050000001844A4A65DA85B40BCCADAA678AC49401844A4A65DA85B409561DC0DA2AF494064E597C118AB5B409561DC0DA2AF494064E597C118AB5B40BCCADAA678AC49401844A4A65DA85B40BCCADAA678AC4940
6313	Зурун	5	48	809	109.952623	109.98092	51.405042000000002	51.399349999999998	0103000020E61000000100000005000000B79A75C6F77C5B402CD49AE61DB34940B79A75C6F77C5B40D3C08F6AD8B3494082FFAD64C77E5B40D3C08F6AD8B3494082FFAD64C77E5B402CD49AE61DB34940B79A75C6F77C5B402CD49AE61DB34940
51543	Закульта	5	48	809	109.730344	109.746801	51.366021000000003	51.353963	0103000020E610000001000000050000001CB5C2F4BD6E5B403D7FDAA84EAD49401CB5C2F4BD6E5B401A53B0C6D9AE4940B0E76B96CB6F5B401A53B0C6D9AE4940B0E76B96CB6F5B403D7FDAA84EAD49401CB5C2F4BD6E5B403D7FDAA84EAD4940
60053	Жипхеген	5	48	809	110.158373	110.17973499999999	51.468671000000001	51.446660999999999	0103000020E6100000010000000500000071E481C8228A5B4007B309302CB9494071E481C8228A5B40B4CA4C69FDBB494094BC3AC7808B5B40B4CA4C69FDBB494094BC3AC7808B5B4007B309302CB9494071E481C8228A5B4007B309302CB94940
6777	Дайгур	5	48	809	111.044471	111.067046	51.491815000000003	51.478611999999998	0103000020E61000000100000005000000B5A7E49CD8C25B4090BC732843BD4940B5A7E49CD8C25B4054573ECBF3BE4940F8544E7B4AC45B4054573ECBF3BE4940F8544E7B4AC45B4090BC732843BD4940B5A7E49CD8C25B4090BC732843BD4940
6576	Гыршелун	5	48	809	110.64961700000001	110.670772	51.405884	51.392105999999998	0103000020E610000001000000050000003E7B2E5393A95B405E48878730B249403E7B2E5393A95B401EFCC401F4B34940A4C4AEEDEDAA5B401EFCC401F4B34940A4C4AEEDEDAA5B405E48878730B249403E7B2E5393A95B405E48878730B24940
6428	Глинка	5	48	809	110.04056799999999	110.051878	51.436056000000001	51.413378999999999	0103000020E61000000100000005000000E75086AA98825B4035ED629AE9B44940E75086AA98825B40BF9CD9AED0B7494071581AF851835B40BF9CD9AED0B7494071581AF851835B4035ED629AE9B44940E75086AA98825B4035ED629AE9B44940
58981	Бада	5	48	809	109.827416	109.909019	51.402619999999999	51.375056999999998	0103000020E61000000100000005000000FA0B3D62F4745B40649126DE01B04940FA0B3D62F4745B40965B5A0D89B34940541C075E2D7A5B40965B5A0D89B34940541C075E2D7A5B40649126DE01B04940FA0B3D62F4745B40649126DE01B04940
5408	Шехолан	5	48	214	111.92465900000001	111.94462799999999	51.041420000000002	51.021515000000001	0103000020E61000000100000005000000EF3CF19C2DFB5B40CDAFE600C1824940EF3CF19C2DFB5B403EB324404D854940B2B8FFC874FC5B403EB324404D854940B2B8FFC874FC5B40CDAFE600C1824940EF3CF19C2DFB5B40CDAFE600C1824940
5129	Шебартуй 2-й	5	48	214	111.372258	111.401606	51.038139999999999	51.024352999999998	0103000020E6100000010000000500000029EB3713D3D75B409D47C5FF1D83494029EB3713D3D75B40B05582C5E184494027F8A6E9B3D95B40B05582C5E184494027F8A6E9B3D95B409D47C5FF1D83494029EB3713D3D75B409D47C5FF1D834940
48451	Черемхово	5	48	214	112.704172	112.735298	51.465097	51.454003	0103000020E6100000010000000500000092B06F27112D5C4098A432C51CBA494092B06F27112D5C40DE3B6A4C88BB49401CB4571F0F2F5C40DE3B6A4C88BB49401CB4571F0F2F5C4098A432C51CBA494092B06F27112D5C4098A432C51CBA4940
21534	Хадакта	5	48	214	112.55022700000001	112.587247	51.432957000000002	51.417754000000002	0103000020E6100000010000000500000014984EEB36235C40F8E28BF678B5494014984EEB36235C4082C98D226BB7494025EB707495255C4082C98D226BB7494025EB707495255C40F8E28BF678B5494014984EEB36235C40F8E28BF678B54940
3267	Улеты	5	48	214	112.46444700000001	112.505608	51.383563000000002	51.332099999999997	0103000020E610000001000000050000006CEEE87FB91D5C403480B74082AA49406CEEE87FB91D5C40537AA69718B149402426A8E15B205C40537AA69718B149402426A8E15B205C403480B74082AA49406CEEE87FB91D5C403480B74082AA4940
45427	Татаурово	5	48	214	112.91534799999999	112.946214	51.614553999999998	51.586308000000002	0103000020E61000000100000005000000601DC70F953A5C400CB1FA230CCB4940601DC70F953A5C4020D099B4A9CE49401C412AC58E3C5C4020D099B4A9CE49401C412AC58E3C5C400CB1FA230CCB4940601DC70F953A5C400CB1FA230CCB4940
5249	Танга	5	48	214	111.524666	111.58344200000001	50.993279000000001	50.965854999999998	0103000020E61000000100000005000000AED4B32094E15B40CBD6FA22A17B4940AED4B32094E15B40DC662AC4237F494039471D1D57E55B40DC662AC4237F494039471D1D57E55B40CBD6FA22A17B4940AED4B32094E15B40CBD6FA22A17B4940
5181	Новосалия	5	48	214	111.407364	111.431421	50.981202000000003	50.973246000000003	0103000020E610000001000000050000005664744012DA5B403E7B2E53937C49405664744012DA5B408962F206987D4940B073D3669CDB5B408962F206987D4940B073D3669CDB5B403E7B2E53937C49405664744012DA5B403E7B2E53937C4940
47814	Николаевское	5	48	214	111.744861	111.79872400000001	51.071725000000001	51.042206999999998	0103000020E6100000010000000500000037C478CDABEF5B40C554FA096785494037C478CDABEF5B401EA7E8482E894940F1A1444B1EF35B401EA7E8482E894940F1A1444B1EF35B40C554FA096785494037C478CDABEF5B40C554FA0967854940
51571	Ленинский	5	48	214	111.4892	111.52819599999999	50.849221999999997	50.828454999999998	0103000020E61000000100000005000000014D840D4FDF5B40959A3DD00A6A4940014D840D4FDF5B409885764EB36C4940317898F6CDE15B409885764EB36C4940317898F6CDE15B40959A3DD00A6A4940014D840D4FDF5B40959A3DD00A6A4940
47888	Красная Речка	5	48	214	113.052089	113.06417999999999	51.646549	51.633927999999997	0103000020E61000000100000005000000CEDE196D55435C4064027E8D24D14940CEDE196D55435C4079211D1EC2D24940AA436E861B445C4079211D1EC2D24940AA436E861B445C4064027E8D24D14940CEDE196D55435C4064027E8D24D14940
23431	Дровяная	5	48	214	113.023038	113.062303	51.614950999999998	51.507660000000001	0103000020E610000001000000050000002D24607479415C4062BEBC00FBC049402D24607479415C403DD2E0B6B6CE494055DCB8C5FC435C403DD2E0B6B6CE494055DCB8C5FC435C4062BEBC00FBC049402D24607479415C4062BEBC00FBC04940
811	Доронинское	5	48	214	112.12403999999999	112.184622	51.133248999999999	51.116160000000001	0103000020E6100000010000000500000055D97745F0075C403B8DB454DE8E494055D97745F0075C40C39CA04D0E914940D107CBD8D00B5C40C39CA04D0E914940D107CBD8D00B5C403B8DB454DE8E494055D97745F0075C403B8DB454DE8E4940
5287	Дешулан	5	48	214	111.759512	111.795669	50.986781999999998	50.973256999999997	0103000020E61000000100000005000000DA3A38D89BF05B4031CD74AF937C4940DA3A38D89BF05B40072461DF4E7E49403A5CAB3DECF25B40072461DF4E7E49403A5CAB3DECF25B4031CD74AF937C4940DA3A38D89BF05B4031CD74AF937C4940
59072	Горный	5	48	214	113.023172	113.04961	51.566521000000002	51.545409999999997	0103000020E61000000100000005000000B58B69A67B415C40A774B0FECFC54940B58B69A67B415C40A5BF97C283C849407EE36BCF2C435C40A5BF97C283C849407EE36BCF2C435C40A774B0FECFC54940B58B69A67B415C40A774B0FECFC54940
58976	Горный	5	48	214	113.023172	113.04961	51.566521000000002	51.545409999999997	0103000020E61000000100000005000000B58B69A67B415C40A774B0FECFC54940B58B69A67B415C40A5BF97C283C849407EE36BCF2C435C40A5BF97C283C849407EE36BCF2C435C40A774B0FECFC54940B58B69A67B415C40A774B0FECFC54940
4612	Горекацан	5	48	214	111.927632	111.960438	51.131802	51.114745999999997	0103000020E6100000010000000500000047AE9B525EFB5B4064AC36FFAF8E494047AE9B525EFB5B4011C64FE3DE9049407BF5F1D077FD5B4011C64FE3DE9049407BF5F1D077FD5B4064AC36FFAF8E494047AE9B525EFB5B4064AC36FFAF8E4940
5449	Горека	5	48	214	111.97575500000001	111.995913	51.083739000000001	51.064270999999998	0103000020E61000000100000005000000257A19C572FE5B40658A39083A884940257A19C572FE5B402B33A5F5B78A4940522AE109BDFF5B402B33A5F5B78A4940522AE109BDFF5B40658A39083A884940257A19C572FE5B40658A39083A884940
5533	Голубичная	5	48	214	113.044687	113.049987	51.624977000000001	51.621203000000001	0103000020E610000001000000050000009BE3DC26DC425C40AB96749483CF49409BE3DC26DC425C4048E00F3FFFCF4940698EACFC32435C4048E00F3FFFCF4940698EACFC32435C40AB96749483CF49409BE3DC26DC425C40AB96749483CF4940
2756	Бальзой	5	48	214	112.346975	112.37973599999999	51.364953	51.348371999999998	0103000020E61000000100000005000000E561A1D634165C40CA6B257497AC4940E561A1D634165C40DEC9A7C7B6AE4940494739984D185C40DEC9A7C7B6AE4940494739984D185C40CA6B257497AC4940E561A1D634165C40CA6B257497AC4940
1414	Арта	5	48	214	112.38642	112.414573	51.261048000000002	51.240499999999997	0103000020E610000001000000050000004DA1F31ABB185C40105839B4C89E49404DA1F31ABB185C40D65757056AA149407F33315D881A5C40D65757056AA149407F33315D881A5C40105839B4C89E49404DA1F31ABB185C40105839B4C89E4940
47696	Арей	5	48	214	111.229973	111.252791	50.980873000000003	50.966411000000001	0103000020E61000000100000005000000A27DACE0B7CE5B4051BF0B5BB37B4940A27DACE0B7CE5B40C443183F8D7D4940486E4DBA2DD05B40C443183F8D7D4940486E4DBA2DD05B4051BF0B5BB37B4940A27DACE0B7CE5B4051BF0B5BB37B4940
31045	Аблатукан	5	48	214	112.109065	112.134523	51.251173000000001	51.240765000000003	0103000020E61000000100000005000000D908C4EBFA065C40BF823463D19E4940D908C4EBFA065C40B151D66F26A04940D4635B069C085C40B151D66F26A04940D4635B069C085C40BF823463D19E4940D908C4EBFA065C40BF823463D19E4940
29767	Аблатуйский Бор	5	48	214	112.20752	112.232996	51.191952000000001	51.182468	0103000020E610000001000000050000000551F701480D5C408448861C5B9749400551F701480D5C406E3315E29198494053060E68E90E5C406E3315E29198494053060E68E90E5C408448861C5B9749400551F701480D5C408448861C5B974940
60159	Усугли	5	48	614	115.240583	115.27280500000001	52.659042999999997	52.644784000000001	0103000020E610000001000000050000004F3E3DB665CF5C40F67D384888524A404F3E3DB665CF5C4030D461855B544A40DC4B1AA375D15C4030D461855B544A40DC4B1AA375D15C40F67D384888524A404F3E3DB665CF5C40F67D384888524A40
60082	Тунгокочен	5	48	614	115.5946	115.635276	53.538542	53.522511999999999	0103000020E61000000100000005000000E78C28ED0DE65C403FE257ACE1C24A40E78C28ED0DE65C40DFC2BAF1EEC44A40C2FBAA5CA8E85C40DFC2BAF1EEC44A40C2FBAA5CA8E85C403FE257ACE1C24A40E78C28ED0DE65C403FE257ACE1C24A40
51822	Нижний Стан	5	48	614	115.696451	115.72581700000001	52.297530000000002	52.283368000000003	0103000020E610000001000000050000000E1137A792EC5C40D15D126745244A400E1137A792EC5C4019CA897615264A40607825C973EE5C4019CA897615264A40607825C973EE5C40D15D126745244A400E1137A792EC5C40D15D126745244A40
60115	Нижнестанское	5	48	614	113.775026	118.23339199999999	56.000698	52.156095000000001	0103000020E610000001000000050000002EE3A6069A715C40D908C4EBFA134A402EE3A6069A715C4018963FDF16004C4079C9FFE4EF8E5D4018963FDF16004C4079C9FFE4EF8E5D40D908C4EBFA134A402EE3A6069A715C40D908C4EBFA134A40
60056	Вершино-Дарасунский	5	48	614	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
51774	Вершино-Дарасунский	5	48	614	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
54085	Вершино-Дарасунский	5	48	614	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
51866	Верхние Усугли	5	48	614	115.165223	115.211028	52.701872999999999	52.677593999999999	0103000020E6100000010000000500000002637D0393CA5C40A0FB7266BB564A4002637D0393CA5C40037976F9D6594A4094A2957B81CD5C40037976F9D6594A4094A2957B81CD5C40A0FB7266BB564A4002637D0393CA5C40A0FB7266BB564A40
60078	Тупик	5	48	586	119.920985	119.954016	54.439543999999998	54.420772999999997	0103000020E61000000100000005000000D2C6116BF1FA5D401805C1E3DB354B40D2C6116BF1FA5D40969350FA42384B4016F71F990EFD5D40969350FA42384B4016F71F990EFD5D401805C1E3DB354B40D2C6116BF1FA5D401805C1E3DB354B40
21883	Заречное	5	48	586	119.924453	119.940479	54.463115999999999	54.453699999999998	0103000020E610000001000000050000001A6CEA3C2AFB5D40FC1873D7123A4B401A6CEA3C2AFB5D408E209562473B4B40C9E4D4CE30FC5D408E209562473B4B40C9E4D4CE30FC5D40FC1873D7123A4B401A6CEA3C2AFB5D40FC1873D7123A4B40
51732	Шилкинский Завод	5	48	1840	118.649734	118.68791299999999	52.585687999999998	52.559384000000001	0103000020E610000001000000050000005A46EA3D95A95D40EDF318E599474A405A46EA3D95A95D406FD40AD3F74A4A40915F3FC406AC5D406FD40AD3F74A4A40915F3FC406AC5D40EDF318E599474A405A46EA3D95A95D40EDF318E599474A40
51690	Чикичей	5	48	1840	117.485652	117.499172	52.374481000000003	52.360844	0103000020E610000001000000050000002B4F20EC145F5D409A7ADD22302E4A402B4F20EC145F5D4098FC4FFEEE2F4A400DC51D6FF25F5D4098FC4FFEEE2F4A400DC51D6FF25F5D409A7ADD22302E4A402B4F20EC145F5D409A7ADD22302E4A40
52248	Чалбучи	5	48	1840	118.617296	118.633196	52.453811000000002	52.449359999999999	0103000020E61000000100000005000000E7FC14C781A75D40B610E4A084394A40E7FC14C781A75D4054C8957A163A4A4050FD834886A85D4054C8957A163A4A4050FD834886A85D40B610E4A084394A40E7FC14C781A75D40B610E4A084394A40
60146	Фирсово	5	48	1840	118.095941	118.149283	52.320281999999999	52.310586999999998	0103000020E610000001000000050000001D56B8E523865D4008C89750C1274A401D56B8E523865D40ADBF2500FF284A4052B648DA8D895D40ADBF2500FF284A4052B648DA8D895D4008C89750C1274A401D56B8E523865D4008C89750C1274A40
60156	Усть-Наринзор	5	48	1840	117.340799	117.373165	52.273516000000001	52.25826	0103000020E610000001000000050000009CE09BA6CF555D40B7EEE6A90E214A409CE09BA6CF555D406477819202234A40C2C073EFE1575D406477819202234A40C2C073EFE1575D40B7EEE6A90E214A409CE09BA6CF555D40B7EEE6A90E214A40
60139	Усть-Курлыч	5	48	1840	117.45331299999999	117.465692	52.166719000000001	52.159913000000003	0103000020E6100000010000000500000081768714035D5D40469A780778144A4081768714035D5D40984F560C57154A409180D1E5CD5D5D40984F560C57154A409180D1E5CD5D5D40469A780778144A4081768714035D5D40469A780778144A40
51678	Усть-Карск	5	48	1840	118.765311	118.82964	52.735050000000001	52.693758000000003	0103000020E610000001000000050000003811FDDAFAB05D4050ABE80FCD584A403811FDDAFAB05D4060764F1E165E4A4005DD5ED218B55D4060764F1E165E4A4005DD5ED218B55D4050ABE80FCD584A403811FDDAFAB05D4050ABE80FCD584A40
60096	Усть-Карск	5	48	1840	118.765311	118.82964	52.735050000000001	52.693758000000003	0103000020E610000001000000050000003811FDDAFAB05D4050ABE80FCD584A403811FDDAFAB05D4060764F1E165E4A4005DD5ED218B55D4060764F1E165E4A4005DD5ED218B55D4050ABE80FCD584A403811FDDAFAB05D4050ABE80FCD584A40
52244	Уктыча	5	48	1840	118.25161	118.29320199999999	52.333233	52.330342999999999	0103000020E610000001000000050000002E56D4601A905D4034BBEEAD482A4A402E56D4601A905D4057790261A72A4A40CB4752D2C3925D4057790261A72A4A40CB4752D2C3925D4034BBEEAD482A4A402E56D4601A905D4034BBEEAD482A4A40
50855	Сретенск	5	48	1840	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
52227	Нижняя Куэнга	5	48	1840	117.01413599999999	117.034842	52.098793999999998	52.084623000000001	0103000020E610000001000000050000008F6CAE9AE7405D40A5BE2CEDD40A4A408F6CAE9AE7405D4040852348A50C4A40BEA1F0D93A425D4040852348A50C4A40BEA1F0D93A425D40A5BE2CEDD40A4A408F6CAE9AE7405D40A5BE2CEDD40A4A40
51629	Молодовск	5	48	1840	117.855435	117.89535600000001	52.273935000000002	52.248949000000003	0103000020E61000000100000005000000A4367172BF765D409BAF928FDD1F4A40A4367172BF765D40691D554D10234A40C19140834D795D40691D554D10234A40C19140834D795D409BAF928FDD1F4A40A4367172BF765D409BAF928FDD1F4A40
51504	Ломы	5	48	1840	117.982349	118.01978200000001	52.289312000000002	52.282547000000001	0103000020E61000000100000005000000881057CEDE7E5D409D4A06802A244A40881057CEDE7E5D40912BF52C08254A402BC3B81B44815D40912BF52C08254A402BC3B81B44815D409D4A06802A244A40881057CEDE7E5D409D4A06802A244A40
52240	Кулан	5	48	1840	117.34500300000001	117.359071	52.408467999999999	52.394781000000002	0103000020E610000001000000050000006781768714565D40850A0E2F88324A406781768714565D4034BBEEAD48344A404A7CEE04FB565D4034BBEEAD48344A404A7CEE04FB565D40850A0E2F88324A406781768714565D40850A0E2F88324A40
52245	Кудея	5	48	1840	118.15797000000001	118.169854	52.390839999999997	52.382787999999998	0103000020E61000000100000005000000F2EF332E1C8A5D408FA67A32FF304A40F2EF332E1C8A5D40FCFB8C0B07324A4011C64FE3DE8A5D40FCFB8C0B07324A4011C64FE3DE8A5D408FA67A32FF304A40F2EF332E1C8A5D408FA67A32FF304A40
54087	Кокуй	5	48	1840	117.522043	117.592884	52.223281	52.194197000000003	0103000020E61000000100000005000000C4060B2769615D409CFD8172DB184A40C4060B2769615D40BA68C878941C4A409694BBCFF1655D40BA68C878941C4A409694BBCFF1655D409CFD8172DB184A40C4060B2769615D409CFD8172DB184A40
51843	Кокуй	5	48	1840	117.522043	117.592884	52.223281	52.194197000000003	0103000020E61000000100000005000000C4060B2769615D409CFD8172DB184A40C4060B2769615D40BA68C878941C4A409694BBCFF1655D40BA68C878941C4A409694BBCFF1655D409CFD8172DB184A40C4060B2769615D409CFD8172DB184A40
50914	Дунаево	5	48	1840	117.04059100000001	117.07091800000001	52.079028000000001	52.060260999999997	0103000020E61000000100000005000000C460FE0A99425D40B41CE8A1B6074A40C460FE0A99425D40F1BBE9961D0A4A40A8ACA6EB89445D40F1BBE9961D0A4A40A8ACA6EB89445D40B41CE8A1B6074A40C460FE0A99425D40B41CE8A1B6074A40
52234	Делюн	5	48	1840	117.443459	117.454921	52.215865000000001	52.202874999999999	0103000020E610000001000000050000007B87DBA1615C5D408716D9CEF7194A407B87DBA1615C5D40EFACDD76A11B4A40DF50F86C1D5D5D40EFACDD76A11B4A40DF50F86C1D5D5D408716D9CEF7194A407B87DBA1615C5D408716D9CEF7194A40
51422	Горбица	5	48	1840	119.205073	119.23151900000001	53.107551999999998	53.094056999999999	0103000020E61000000100000005000000BA1281EA1FCD5D40DD7A4D0F0A8C4A40BA1281EA1FCD5D40484F9143C48D4A40C5591135D1CE5D40484F9143C48D4A40C5591135D1CE5D40DD7A4D0F0A8C4A40BA1281EA1FCD5D40DD7A4D0F0A8C4A40
51762	Верхняя Кузнга	5	48	1840	117.049916	117.06402799999999	52.142567	52.118589999999998	0103000020E6100000010000000500000004E3E0D231435D40FAD005F52D0F4A4004E3E0D231435D40923EADA23F124A40CF81E50819445D40923EADA23F124A40CF81E50819445D40FAD005F52D0F4A4004E3E0D231435D40FAD005F52D0F4A40
60204	Верхние Куларки	5	48	1840	118.935363	118.95023	52.837788000000003	52.821150000000003	0103000020E61000000100000005000000DCB8C5FCDCBB5D40228E75711B694A40DCB8C5FCDCBB5D409A7D1EA33C6B4A40666B7D91D0BC5D409A7D1EA33C6B4A40666B7D91D0BC5D40228E75711B694A40DCB8C5FCDCBB5D40228E75711B694A40
60183	Ботовское	5	48	1840	116.896897	119.905292	53.374496999999998	51.900396999999998	0103000020E610000001000000050000005AB8ACC266395D4050357A3540F349405AB8ACC266395D409DB98784EFAF4A402655DB4DF0F95D409DB98784EFAF4A402655DB4DF0F95D4050357A3540F349405AB8ACC266395D4050357A3540F34940
51764	Бори	5	48	1840	118.10355	118.12230599999999	52.482565000000001	52.467123000000001	0103000020E610000001000000050000000DE02D90A0865D40CE1ABCAFCA3B4A400DE02D90A0865D40DD989EB0C43D4A40B1868BDCD3875D40DD989EB0C43D4A40B1868BDCD3875D40CE1ABCAFCA3B4A400DE02D90A0865D40CE1ABCAFCA3B4A40
51503	Болотово	5	48	1840	117.231375	117.24581999999999	52.091988999999998	52.081358000000002	0103000020E610000001000000050000002B8716D9CE4E5D404DA25EF0690A4A402B8716D9CE4E5D40BE4BA94BC60B4A40F92CCF83BB4F5D40BE4BA94BC60B4A40F92CCF83BB4F5D404DA25EF0690A4A402B8716D9CE4E5D404DA25EF0690A4A40
51654	Алия	5	48	1840	117.607392	117.633308	52.331923000000003	52.302315999999998	0103000020E6100000010000000500000088F6B182DF665D405D876A4AB2264A4088F6B182DF665D4026E5EE737C2A4A40E412471E88685D4026E5EE737C2A4A40E412471E88685D405D876A4AB2264A4088F6B182DF665D405D876A4AB2264A40
52238	Адом	5	48	1840	117.50282799999999	117.52130699999999	52.442625	52.430799	0103000020E61000000100000005000000D6E07D552E605D402313F06B24374A40D6E07D552E605D402DB29DEFA7384A40410B09185D615D402DB29DEFA7384A40410B09185D615D402313F06B24374A40D6E07D552E605D402313F06B24374A40
60121	Приаргунск	5	48	7503	119.069607	119.11287	50.376370999999999	50.354098999999998	0103000020E61000000100000005000000A724EB7074C45D40ED45B41D532D4940A724EB7074C45D40D714C8EC2C304940C5AC174339C75D40D714C8EC2C304940C5AC174339C75D40ED45B41D532D4940A724EB7074C45D40ED45B41D532D4940
27033	Усть-Тасуркай	5	48	1809	118.396355	118.42415800000001	50.364179	50.352404	0103000020E61000000100000005000000CAA65CE15D995D40637D03931B2D4940CAA65CE15D995D40EB71DF6A9D2E49408E959867259B5D40EB71DF6A9D2E49408E959867259B5D40637D03931B2D4940CAA65CE15D995D40637D03931B2D4940
51042	Урулюнгуй	5	48	1809	118.50247299999999	118.526081	50.473211999999997	50.459215999999998	0103000020E61000000100000005000000DF87838428A05D4064E60297C73A4940DF87838428A05D409109F835923C49400283A44FABA15D409109F835923C49400283A44FABA15D4064E60297C73A4940DF87838428A05D4064E60297C73A4940
27743	Улан	5	48	1809	118.920181	118.937096	50.480778000000001	50.473613	0103000020E61000000100000005000000A359D93EE4BA5D40F0FACC599F3C4940A359D93EE4BA5D4072512D228A3D4940984D8061F9BB5D4072512D228A3D4940984D8061F9BB5D40F0FACC599F3C4940A359D93EE4BA5D40F0FACC599F3C4940
27760	Талман-Борзя	5	48	1809	118.83194	118.848855	50.564819	50.555320000000002	0103000020E61000000100000005000000FE0E45813EB55D404968CBB914474940FE0E45813EB55D4068942EFD4B484940F302ECA353B65D4068942EFD4B484940F302ECA353B65D404968CBB914474940FE0E45813EB55D404968CBB914474940
60119	Староцурухайтуй	5	48	1809	119.31463100000001	119.337053	50.203226999999998	50.193193000000001	0103000020E61000000100000005000000B3D30FEA22D45D407768588CBA184940B3D30FEA22D45D400455A357031A49403201BF4692D55D400455A357031A49403201BF4692D55D407768588CBA184940B3D30FEA22D45D407768588CBA184940
27018	Селинда	5	48	1809	118.317519	118.33615899999999	50.569921999999998	50.560344000000001	0103000020E61000000100000005000000F436363B52945D404241295AB9474940F436363B52945D40ADA23F34F348494063D009A183955D40ADA23F34F348494063D009A183955D404241295AB9474940F436363B52945D404241295AB9474940
51696	Приаргунск	5	48	1809	119.069607	119.11287	50.376370999999999	50.354098999999998	0103000020E61000000100000005000000A724EB7074C45D40ED45B41D532D4940A724EB7074C45D40D714C8EC2C304940C5AC174339C75D40D714C8EC2C304940C5AC174339C75D40ED45B41D532D4940A724EB7074C45D40ED45B41D532D4940
27899	Приаргунск	5	48	1809	119.069607	119.11287	50.376370999999999	50.354098999999998	0103000020E61000000100000005000000A724EB7074C45D40ED45B41D532D4940A724EB7074C45D40D714C8EC2C304940C5AC174339C75D40D714C8EC2C304940C5AC174339C75D40ED45B41D532D4940A724EB7074C45D40ED45B41D532D4940
51645	Пограничный	5	48	1809	118.950068	118.97188800000001	50.596535000000003	50.585915999999997	0103000020E61000000100000005000000793E03EACDBC5D40001AA54BFF4A4940793E03EACDBC5D40AEF545425B4C4940FED7B96933BE5D40AEF545425B4C4940FED7B96933BE5D40001AA54BFF4A4940793E03EACDBC5D40001AA54BFF4A4940
27371	Погадаево	5	48	1809	118.660568	118.678956	50.337268000000002	50.325135000000003	0103000020E610000001000000050000002F3201BF46AA5D407AE40F069E2949402F3201BF46AA5D4061FE0A992B2B494012DBDD0374AB5D4061FE0A992B2B494012DBDD0374AB5D407AE40F069E2949402F3201BF46AA5D407AE40F069E294940
27556	Норинск	5	48	1809	119.030916	119.040223	50.671309000000001	50.664704	0103000020E61000000100000005000000153B1A87FAC15D409CC24A0515554940153B1A87FAC15D4057410C74ED55494002637D0393C25D4057410C74ED55494002637D0393C25D409CC24A0515554940153B1A87FAC15D409CC24A0515554940
51869	Новоцурухайтуй	5	48	1809	119.101551	119.13204	50.401629	50.380501000000002	0103000020E6100000010000000500000012F8C3CF7FC65D40338CBB41B430494012F8C3CF7FC65D4006103E9468334940E370E65773C85D4006103E9468334940E370E65773C85D40338CBB41B430494012F8C3CF7FC65D40338CBB41B4304940
27819	Новоивановка	5	48	1809	118.14631799999999	118.166872	50.382224000000001	50.370171999999997	0103000020E610000001000000050000003B342C465D895D408CF2CCCB612F49403B342C465D895D4087DF4DB7EC3049408FA7E507AE8A5D4087DF4DB7EC3049408FA7E507AE8A5D408CF2CCCB612F49403B342C465D895D408CF2CCCB612F4940
51720	Молодёжный	5	48	1809	118.97788	119.00328399999999	50.290501999999996	50.276480999999997	0103000020E6100000010000000500000066DAFE9595BE5D40917BBABA6323494066DAFE9595BE5D4017B6662B2F254940672618CE35C05D4017B6662B2F254940672618CE35C05D40917BBABA6323494066DAFE9595BE5D40917BBABA63234940
27632	Кути	5	48	1809	119.177953	119.183594	50.098412000000003	50.093938999999999	0103000020E6100000010000000500000068CEFA9463CB5D40D3687231060C494068CEFA9463CB5D4059C4B0C3980C49407A6F0C01C0CB5D4059C4B0C3980C49407A6F0C01C0CB5D40D3687231060C494068CEFA9463CB5D40D3687231060C4940
28111	Кличка	5	48	1809	117.981522	118.016161	50.453125	50.407043000000002	0103000020E610000001000000050000007D93A641D17E5D406A882AFC193449407D93A641D17E5D4000000000003A49401F9E25C808815D4000000000003A49401F9E25C808815D406A882AFC193449407D93A641D17E5D406A882AFC19344940
27304	Зоргол	5	48	1809	119.252854	119.28103400000001	50.611645000000003	50.602274999999999	0103000020E610000001000000050000006B2A8BC22ED05D406519E258174D49406B2A8BC22ED05D4087E123624A4E49401AC40776FCD15D4087E123624A4E49401AC40776FCD15D406519E258174D49406B2A8BC22ED05D406519E258174D4940
27256	Дурой	5	48	1809	118.92190600000001	118.94026700000001	50.021312000000002	50.001572000000003	0103000020E610000001000000050000001EFF058200BB5D406F4BE482330049401EFF058200BB5D409581035ABA02494084A0A3552DBC5D409581035ABA02494084A0A3552DBC5D406F4BE482330049401EFF058200BB5D406F4BE48233004940
27684	Досатуй	5	48	1809	118.61620000000001	118.65904999999999	50.403179000000002	50.385153000000003	0103000020E61000000100000005000000E5F21FD26FA75D40687A89B14C314940E5F21FD26FA75D408DB7955E9B334940711B0DE02DAA5D408DB7955E9B334940711B0DE02DAA5D40687A89B14C314940E5F21FD26FA75D40687A89B14C314940
27390	Горда	5	48	1809	118.882874	118.890052	50.172179999999997	50.165002000000001	0103000020E61000000100000005000000471FF30181B85D4026E318C91E154940471FF30181B85D403C8386FE0916494052EFA99CF6B85D403C8386FE0916494052EFA99CF6B85D4026E318C91E154940471FF30181B85D4026E318C91E154940
27111	Верхний Тасуркай	5	48	1809	118.322469	118.352069	50.434981000000001	50.424796000000001	0103000020E61000000100000005000000533E0455A3945D405EBC1FB75F364940533E0455A3945D40D1B01875AD374940DE3B6A4C88965D40D1B01875AD374940DE3B6A4C88965D405EBC1FB75F364940533E0455A3945D405EBC1FB75F364940
27477	Верея	5	48	1809	119.113328	119.12355100000001	50.593167000000001	50.586618999999999	0103000020E61000000100000005000000266E15C440C75D402A1BD654164B4940266E15C440C75D40810871E5EC4B4940D7187442E8C75D40810871E5EC4B4940D7187442E8C75D402A1BD654164B4940266E15C440C75D402A1BD654164B4940
26869	Бырка	5	48	1809	118.524967	118.57351199999999	50.657761000000001	50.631829000000003	0103000020E61000000100000005000000AC1E300F99A15D400BD5CDC5DF504940AC1E300F99A15D40C9CA2F833154494044F7AC6BB4A45D40C9CA2F833154494044F7AC6BB4A45D400BD5CDC5DF504940AC1E300F99A15D400BD5CDC5DF504940
3605	Хохотуй	5	48	427	109.552415	109.588176	51.296137999999999	51.275745000000001	0103000020E6100000010000000500000078B471C45A635B408C84B69C4BA3494078B471C45A635B402A8D98D9E7A54940B212F3ACA4655B402A8D98D9E7A54940B212F3ACA4655B408C84B69C4BA3494078B471C45A635B408C84B69C4BA34940
52246	Харауз	5	48	427	108.45737699999999	108.49128	51.253754999999998	51.236558000000002	0103000020E61000000100000005000000533C2EAA451D5B40B8CD5488479E4940533C2EAA451D5B402619390B7BA04940734BAB21711F5B402619390B7BA04940734BAB21711F5B40B8CD5488479E4940533C2EAA451D5B40B8CD5488479E4940
52239	Усть-Обор	5	48	427	108.559444	108.580752	50.941161000000001	50.922427999999996	0103000020E6100000010000000500000061FC34EECD235B401475E61E1276494061FC34EECD235B40A5A2B1F6777849408BC56F0A2B255B40A5A2B1F6777849408BC56F0A2B255B401475E61E1276494061FC34EECD235B401475E61E12764940
3572	Толбага	5	48	427	109.31529500000001	109.33893	51.211134999999999	51.202027000000001	0103000020E61000000100000005000000E96514CB2D545B405AF44E05DC994940E96514CB2D545B403E05C078069B494088687407B1555B403E05C078069B494088687407B1555B405AF44E05DC994940E96514CB2D545B405AF44E05DC994940
60072	Тарбагатай	5	48	427	109.07293900000001	109.113623	51.187527000000003	51.164160000000003	0103000020E6100000010000000500000097E65608AB445B40DBA7E3310395494097E65608AB445B40FA0E7EE200984940B344679945475B40FA0E7EE200984940B344679945475B40DBA7E3310395494097E65608AB445B40DBA7E33103954940
60085	Тарбагатай	5	48	427	109.07293900000001	109.113623	51.187527000000003	51.164160000000003	0103000020E6100000010000000500000097E65608AB445B40DBA7E3310395494097E65608AB445B40FA0E7EE200984940B344679945475B40FA0E7EE200984940B344679945475B40DBA7E3310395494097E65608AB445B40DBA7E33103954940
50784	Пески	5	48	427	108.109594	108.128675	50.777585999999999	50.760376000000001	0103000020E610000001000000050000009F758D9603075B40E7543200546149409F758D9603075B40EAE923F087634940053411363C085B40EAE923F087634940053411363C085B40E7543200546149409F758D9603075B40E754320054614940
52242	Орсук	5	48	427	108.79936600000001	108.814943	50.962775000000001	50.952471000000003	0103000020E6100000010000000500000033E202D028335B40B8B1D991EA79494033E202D028335B40053411363C7B4940AA46AF0628345B40053411363C7B4940AA46AF0628345B40B8B1D991EA79494033E202D028335B40B8B1D991EA794940
52241	Обор	5	48	427	108.54128	108.55179	50.978225000000002	50.961067	0103000020E61000000100000005000000A67EDE54A4225B40E621533E047B4940A67EDE54A4225B4097900F7A367D4940A110018750235B4097900F7A367D4940A110018750235B40E621533E047B4940A67EDE54A4225B40E621533E047B4940
60041	Новопавловка	5	48	427	109.182075	109.253761	51.230212999999999	51.199984000000001	0103000020E61000000100000005000000D49AE61DA74B5B4094DC611399994940D49AE61DA74B5B40990E9D9E779D49400400C79E3D505B40990E9D9E779D49400400C79E3D505B4094DC611399994940D49AE61DA74B5B4094DC611399994940
52230	Новая Зардама	5	48	427	108.15557	108.170734	50.795279000000001	50.785570999999997	0103000020E61000000100000005000000478FDFDBF4095B40CFD72C978D644940478FDFDBF4095B400919C8B3CB6549402D944C4EED0A5B400919C8B3CB6549402D944C4EED0A5B40CFD72C978D644940478FDFDBF4095B40CFD72C978D644940
51858	Малета	5	48	427	108.40398999999999	108.443561	50.846741999999999	50.8245	0103000020E610000001000000050000004E7ADFF8DA195B40A8C64B37896949404E7ADFF8DA195B402713B70A626C4940FD31AD4D631C5B402713B70A626C4940FD31AD4D631C5B40A8C64B37896949404E7ADFF8DA195B40A8C64B3789694940
52243	Лесоучасток Катангар	5	48	427	108.983197	109.00310399999999	51.002257999999998	50.994663000000003	0103000020E610000001000000050000009F211CB3EC3E5B4048C5FF1D517F49409F211CB3EC3E5B40C2137AFD49804940279F1EDB32405B40C2137AFD49804940279F1EDB32405B4048C5FF1D517F49409F211CB3EC3E5B4048C5FF1D517F4940
50967	Кули	5	48	427	109.023972	109.055224	51.152935999999997	51.129466999999998	0103000020E610000001000000050000004301DBC188415B40A374E95F929049404301DBC188415B40C630276893934940137D3ECA88435B40C630276893934940137D3ECA88435B40A374E95F929049404301DBC188415B40A374E95F92904940
50905	Катангар	5	48	427	108.953427	108.969228	51.014794999999999	51.008000000000003	0103000020E61000000100000005000000E607AEF2043D5B401B2FDD2406814940E607AEF2043D5B40799274CDE48149408597E0D4073E5B40799274CDE48149408597E0D4073E5B401B2FDD2406814940E607AEF2043D5B401B2FDD2406814940
51626	Катаево	5	48	427	108.648404	108.670395	50.956856999999999	50.939895999999997	0103000020E610000001000000050000001EA67D737F295B4013D21A834E7849401EA67D737F295B406EF9484A7A7A4940B9196EC0E72A5B406EF9484A7A7A4940B9196EC0E72A5B4013D21A834E7849401EA67D737F295B4013D21A834E784940
3490	Зугмара	5	48	427	109.203087	109.22039700000001	51.188293999999999	51.181983000000002	0103000020E6100000010000000500000089CF9D60FF4C5B40C8B60C384B97494089CF9D60FF4C5B403A048E041A984940BDC804FC1A4E5B403A048E041A984940BDC804FC1A4E5B40C8B60C384B97494089CF9D60FF4C5B40C8B60C384B974940
51556	Баляга-Катангар	5	48	427	108.969255	108.98424799999999	51.112653999999999	51.107484999999997	0103000020E61000000100000005000000029F1F46083E5B40C0E78711C28D4940029F1F46083E5B40BDE13E726B8E4940D1C952EBFD3E5B40BDE13E726B8E4940D1C952EBFD3E5B40C0E78711C28D4940029F1F46083E5B40C0E78711C28D4940
51767	Баляга	5	48	427	108.882756	108.949941	51.179904999999998	51.140985999999998	0103000020E61000000100000005000000429605137F385B40D09849D40B924940429605137F385B4085B18520079749404A0856D5CB3C5B4085B18520079749404A0856D5CB3C5B40D09849D40B924940429605137F385B40D09849D40B924940
50749	Чиндант 1-й	5	48	1785	115.401381	115.419617	50.580916999999999	50.570157000000002	0103000020E61000000100000005000000170FEF39B0D95C40F14A92E7FA484940170FEF39B0D95C406058FE7C5B4A49401FF64201DBDA5C406058FE7C5B4A49401FF64201DBDA5C40F14A92E7FA484940170FEF39B0D95C40F14A92E7FA484940
50813	Холуй-База	5	48	1785	115.76001599999999	115.77709299999999	50.495123	50.486172000000003	0103000020E61000000100000005000000F31B261AA4F05C408F1D54E23A3E4940F31B261AA4F05C40AB3FC230603F4940D53C47E4BBF15C40AB3FC230603F4940D53C47E4BBF15C408F1D54E23A3E4940F31B261AA4F05C408F1D54E23A3E4940
51819	Тут-Халтуй	5	48	1785	114.161248	114.17413000000001	50.466796000000002	50.447338000000002	0103000020E61000000100000005000000E8A221E3518A5C400821205F42394940E8A221E3518A5C40AAF3A8F8BF3B494029D027F2248B5C40AAF3A8F8BF3B494029D027F2248B5C400821205F42394940E8A221E3518A5C400821205F42394940
51016	Новый Дурулгуй	5	48	1785	114.39607700000001	114.43589900000001	50.351863000000002	50.340440999999998	0103000020E61000000100000005000000A96C585359995C40D89B1892932B4940A96C585359995C4013D6C6D8092D4940FC56EBC4E59B5C4013D6C6D8092D4940FC56EBC4E59B5C40D89B1892932B4940A96C585359995C40D89B1892932B4940
60092	Новая Заря	5	48	1785	115.54433	115.57257300000001	50.369827000000001	50.355500999999997	0103000020E61000000100000005000000D40E7F4DD6E25C40FF58880E812D4940D40E7F4DD6E25C40C216BB7D562F4940A6643909A5E45C40C216BB7D562F4940A6643909A5E45C40FF58880E812D4940D40E7F4DD6E25C40FF58880E812D4940
59128	Нижний Цасучей	5	48	1785	115.12079199999999	115.140367	50.518524999999997	50.504416999999997	0103000020E6100000010000000500000094675E0EBBC75C40F1457BBC9040494094675E0EBBC75C404694F6065F424940029CDEC5FBC85C404694F6065F424940029CDEC5FBC85C40F1457BBC9040494094675E0EBBC75C40F1457BBC90404940
51785	Кулусутай	5	48	1785	115.67287899999999	115.687028	50.237214999999999	50.226652999999999	0103000020E6100000010000000500000092CA147310EB5C4028452BF7021D494092CA147310EB5C40718FA50F5D1E4940ECDB4944F8EB5C40718FA50F5D1E4940ECDB4944F8EB5C4028452BF7021D494092CA147310EB5C4028452BF7021D4940
51878	Красная Ималка	5	48	1785	115.301857	115.31896999999999	50.264436000000003	50.258983000000001	0103000020E6100000010000000500000065C405A051D35C40289CDD5A2621494065C405A051D35C404AF1F109D9214940ED9925016AD45C404AF1F109D9214940ED9925016AD45C40289CDD5A2621494065C405A051D35C40289CDD5A26214940
60195	Ималкинское	5	48	1785	113.969691	115.924695	50.652695999999999	49.904651000000001	0103000020E610000001000000050000006F0ED76A0F7E5C4098A59D9ACBF348406F0ED76A0F7E5C40711DE38A8B53494095F1EF332EFB5C40711DE38A8B53494095F1EF332EFB5C4098A59D9ACBF348406F0ED76A0F7E5C4098A59D9ACBF34840
60048	Верхний Цасучей	5	48	1785	115.07914700000001	115.121188	50.515759000000003	50.501730000000002	0103000020E61000000100000005000000E62494BE10C55C4007B64AB038404940E62494BE10C55C4010CF126404424940BB2A508BC1C75C4010CF126404424940BB2A508BC1C75C4007B64AB038404940E62494BE10C55C4007B64AB038404940
51882	Буйлэсан	5	48	1785	114.85755	114.888335	50.248154999999997	50.241916000000003	0103000020E61000000100000005000000D42B6519E2B65C4088307E1AF71E4940D42B6519E2B65C4060AB048BC31F494019390B7BDAB85C4060AB048BC31F494019390B7BDAB85C4088307E1AF71E4940D42B6519E2B65C4088307E1AF71E4940
51639	Большевик	5	48	1785	114.648467	114.67344900000001	50.495260999999999	50.478668999999996	0103000020E610000001000000050000004162BB7B80A95C40F44D9A06453D49404162BB7B80A95C40FCFD62B6643F494088A1D5C919AB5C40FCFD62B6643F494088A1D5C919AB5C40F44D9A06453D49404162BB7B80A95C40F44D9A06453D4940
59078	Ясногорск	5	48	1190	115.675556	115.703323	50.884000999999998	50.865158999999998	0103000020E6100000010000000500000076A73B4F3CEB5C40876BB587BD6E494076A73B4F3CEB5C40CE50DCF12671494093E1783E03ED5C40CE50DCF12671494093E1783E03ED5C40876BB587BD6E494076A73B4F3CEB5C40876BB587BD6E4940
51616	Ясная	5	48	1190	115.78131500000001	115.869197	50.8628	50.814639	0103000020E61000000100000005000000F437A11001F25C40E8853B1746684940F437A11001F25C40917EFB3A706E4940013274ECA0F75C40917EFB3A706E4940013274ECA0F75C40E8853B1746684940F437A11001F25C40E8853B1746684940
50901	Хара-Бырка	5	48	1190	115.90018000000001	115.9288	50.961827	50.948301000000001	0103000020E61000000100000005000000DA20938C9CF95C40CEE15AED61794940DA20938C9CF95C4074B4AA251D7B494096218E7571FB5C4074B4AA251D7B494096218E7571FB5C40CEE15AED61794940DA20938C9CF95C40CEE15AED61794940
50850	Хада-Булак	5	48	1190	116.287156	116.31376400000001	50.657333000000001	50.634846000000003	0103000020E6100000010000000500000069368FC360125D408BFF3BA24251494069368FC360125D4071CADC7C2354494061AA99B514145D4071CADC7C2354494061AA99B514145D408BFF3BA24251494069368FC360125D408BFF3BA242514940
50790	Уртуйский	5	48	1190	115.957888	115.97795600000001	50.732706	50.723514000000002	0103000020E61000000100000005000000C64E78094EFD5C405D19541B9C5C4940C64E78094EFD5C409FCA694FC95D4940543BC3D496FE5C409FCA694FC95D4940543BC3D496FE5C405D19541B9C5C4940C64E78094EFD5C405D19541B9C5C4940
51863	Улятуй	5	48	1190	116.205499	116.267743	51.177577999999997	51.159064999999998	0103000020E61000000100000005000000161747E5260D5D401878EE3D5C944940161747E5260D5D409A3E3BE0BA964940E82E89B322115D409A3E3BE0BA964940E82E89B322115D401878EE3D5C944940161747E5260D5D401878EE3D5C944940
52096	Улан-Цацык	5	48	1190	116.21441900000001	116.23076	50.868616000000003	50.855379999999997	0103000020E610000001000000050000000729780AB90D5D4084D382177D6D49400729780AB90D5D40246420CF2E6F4940664E97C5C40E5D40246420CF2E6F4940664E97C5C40E5D4084D382177D6D49400729780AB90D5D4084D382177D6D4940
50853	Турга	5	48	1190	116.612149	116.649563	51.062618000000001	51.037495	0103000020E61000000100000005000000DDD1FF722D275D40BB61DBA2CC844940DDD1FF722D275D400A12DBDD03884940446CB07092295D400A12DBDD03884940446CB07092295D40BB61DBA2CC844940DDD1FF722D275D40BB61DBA2CC844940
24208	Тополевка	5	48	1190	115.599738	115.610482	50.908129000000002	50.901460999999998	0103000020E61000000100000005000000C80A7E1B62E65C404ACFF41263734940C80A7E1B62E65C404CC631923D744940FD32182312E75C404CC631923D744940FD32182312E75C404ACFF41263734940C80A7E1B62E65C404ACFF41263734940
60030	Степь	5	48	1190	115.38892199999999	115.458218	51.022607999999998	50.996912999999999	0103000020E6100000010000000500000079AC1919E4D85C4087FA5DD89A7F494079AC1919E4D85C406150A6D1E4824940111C977153DD5C406150A6D1E4824940111C977153DD5C4087FA5DD89A7F494079AC1919E4D85C4087FA5DD89A7F4940
51841	Победа	5	48	1190	116.202634	116.216593	51.069507000000002	51.057313999999998	0103000020E61000000100000005000000B1C398F4F70C5D402DCDAD1056874940B1C398F4F70C5D40EAEBF99AE5884940B9E2E2A8DC0D5D40EAEBF99AE5884940B9E2E2A8DC0D5D402DCDAD1056874940B1C398F4F70C5D402DCDAD1056874940
24288	Ононск	5	48	1190	115.563069	115.579751	50.990178	50.979585999999998	0103000020E610000001000000050000000D198F5209E45C404ACFF412637D49400D198F5209E45C40FE9B1727BE7E4940B134F0A31AE55C40FE9B1727BE7E4940B134F0A31AE55C404ACFF412637D49400D198F5209E45C404ACFF412637D4940
59027	Оловянная	5	48	1190	115.513392	115.598049	50.960079999999998	50.927742000000002	0103000020E61000000100000005000000CB811E6ADBE05C401590F63FC0764940CB811E6ADBE05C4097C5C4E6E37A4940F419506F46E65C4097C5C4E6E37A4940F419506F46E65C401590F63FC0764940CB811E6ADBE05C401590F63FC0764940
11404	Оловянная	5	48	1190	115.513392	115.598049	50.960079999999998	50.927742000000002	0103000020E61000000100000005000000CB811E6ADBE05C401590F63FC0764940CB811E6ADBE05C4097C5C4E6E37A4940F419506F46E65C4097C5C4E6E37A4940F419506F46E65C401590F63FC0764940CB811E6ADBE05C401590F63FC0764940
60028	Оловянная	5	48	1190	115.513392	115.598049	50.960079999999998	50.927742000000002	0103000020E61000000100000005000000CB811E6ADBE05C401590F63FC0764940CB811E6ADBE05C4097C5C4E6E37A4940F419506F46E65C4097C5C4E6E37A4940F419506F46E65C401590F63FC0764940CB811E6ADBE05C401590F63FC0764940
51730	Мирная	5	48	1190	116.026348	116.08605900000001	50.772635999999999	50.739694999999998	0103000020E61000000100000005000000299485AFAF015D40E2016553AE5E4940299485AFAF015D402BDB87BCE5624940B2A19BFD81055D402BDB87BCE5624940B2A19BFD81055D40E2016553AE5E4940299485AFAF015D40E2016553AE5E4940
50986	Кулинда	5	48	1190	115.606763	115.62280699999999	50.959001999999998	50.953572000000001	0103000020E61000000100000005000000105B7A34D5E65C40CF30B5A50E7A4940105B7A34D5E65C403866D993C07A4940122EE411DCE75C403866D993C07A4940122EE411DCE75C40CF30B5A50E7A4940105B7A34D5E65C40CF30B5A50E7A4940
60151	Комкай	5	48	1190	116.34613899999999	116.37046599999999	51.197783000000001	51.181474000000001	0103000020E61000000100000005000000B037312427165D4083893F8A3A974940B037312427165D40365A0EF450994940EA9106B7B5175D40365A0EF450994940EA9106B7B5175D4083893F8A3A974940B037312427165D4083893F8A3A974940
50989	Караксар	5	48	1190	115.946748	115.962945	51.267310000000002	51.260072999999998	0103000020E610000001000000050000006B63EC8497FC5C404BC972124AA149406B63EC8497FC5C4067F2CD3637A2494031B610E4A0FD5C4067F2CD3637A2494031B610E4A0FD5C404BC972124AA149406B63EC8497FC5C404BC972124AA14940
59084	Калангуй	5	48	1190	116.50749500000001	116.53351000000001	51.028596	51.001544000000003	0103000020E610000001000000050000008CF84ECC7A205D40A5C00298328049408CF84ECC7A205D40F165A208A9834940B285200725225D40F165A208A9834940B285200725225D40A5C00298328049408CF84ECC7A205D40A5C0029832804940
50883	Золотореченск	5	48	1190	116.72221	116.765913	51.062544000000003	51.045616000000003	0103000020E6100000010000000500000007B64AB0382E5D405116BEBED685494007B64AB0382E5D40D04719710188494033A5F5B704315D40D04719710188494033A5F5B704315D405116BEBED685494007B64AB0382E5D405116BEBED6854940
52081	Заря	5	48	1190	116.053612	116.063287	51.149987000000003	51.145646999999997	0103000020E6100000010000000500000015AB06616E035D4058E1968FA492494015AB06616E035D409FE925C632934940C4D0EAE40C045D409FE925C632934940C4D0EAE40C045D4058E1968FA492494015AB06616E035D4058E1968FA4924940
51897	Единение	5	48	1190	115.881755	115.891322	51.181361000000003	51.165441999999999	0103000020E61000000100000005000000680586AC6EF85C4042B115342D954940680586AC6EF85C408BE255D636974940240D6E6B0BF95C408BE255D636974940240D6E6B0BF95C4042B115342D954940680586AC6EF85C4042B115342D954940
51855	Долгокыча	5	48	1190	116.399975	116.429368	51.082369999999997	51.058446000000004	0103000020E61000000100000005000000ED0DBE3099195D40804A95287B874940ED0DBE3099195D40F415A4198B8A4940BB7CEBC37A1B5D40F415A4198B8A4940BB7CEBC37A1B5D40804A95287B874940ED0DBE3099195D40804A95287B874940
52077	Верхний Шаранай	5	48	1190	115.75361100000001	115.780596	51.088610000000003	51.068182	0103000020E61000000100000005000000FAB9A1293BF05C4083161230BA884940FAB9A1293BF05C409E0C8E92578B4940DCD8EC48F5F15C409E0C8E92578B4940DCD8EC48F5F15C4083161230BA884940FAB9A1293BF05C4083161230BA884940
51806	Бырка	5	48	1190	115.910133	115.959379	50.745086999999998	50.722146000000002	0103000020E61000000100000005000000AA807B9E3FFA5C40F777B6476F5C4940AA807B9E3FFA5C405ED6C4025F5F4940075E2D7766FD5C405ED6C4025F5F4940075E2D7766FD5C40F777B6476F5C4940AA807B9E3FFA5C40F777B6476F5C4940
52087	Бурулятуй	5	48	1190	116.31127600000001	116.34009399999999	51.098917	51.075274	0103000020E61000000100000005000000E7012CF2EB135D409B1E1494A2894940E7012CF2EB135D405C02F04FA98C494036E49F19C4155D405C02F04FA98C494036E49F19C4155D409B1E1494A2894940E7012CF2EB135D409B1E1494A2894940
51805	Булум	5	48	1190	116.538918	116.56601999999999	50.871174000000003	50.857517999999999	0103000020E61000000100000005000000724EECA17D225D409CDD5A26C36D4940724EECA17D225D4011902FA1826F49407138F3AB39245D4011902FA1826F49407138F3AB39245D409CDD5A26C36D4940724EECA17D225D409CDD5A26C36D4940
51894	Безречная	5	48	1190	116.147522	116.201223	50.750033999999999	50.707323000000002	0103000020E61000000100000005000000315C1D0071095D40B45A608F895A4940315C1D0071095D40AC71361D01604940FE0C6FD6E00C5D40AC71361D01604940FE0C6FD6E00C5D40B45A608F895A4940315C1D0071095D40B45A608F895A4940
51902	Аренда	5	48	1190	116.210144	116.24686699999999	51.289034999999998	51.271873999999997	0103000020E61000000100000005000000D7DCD1FF720D5D40FC5069C4CCA24940D7DCD1FF720D5D401E335019FFA449408BDD3EABCC0F5D401E335019FFA449408BDD3EABCC0F5D40FC5069C4CCA24940D7DCD1FF720D5D40FC5069C4CCA24940
52093	Антия	5	48	1190	116.568437	116.586439	50.953617999999999	50.947108999999998	0103000020E610000001000000050000008735954561245D40A65F22DE3A7949408735954561245D403F709527107A49405586713788255D403F709527107A49405586713788255D40A65F22DE3A7949408735954561245D40A65F22DE3A794940
60165	сельское поселение Булдуруйское	5	48	1684	118.83979100000001	120.76719799999999	52.642696000000001	50.914937999999999	0103000020E61000000100000005000000691EC022BFB55D400FEF39B01C754940691EC022BFB55D4090A2CEDC43524A409FE3A3C519315E4090A2CEDC43524A409FE3A3C519315E400FEF39B01C754940691EC022BFB55D400FEF39B01C754940
60190	Широкая	5	48	1684	119.588357	119.60485	51.372470999999997	51.366155999999997	0103000020E61000000100000005000000DA571EA4A7E55D40F99D2633DEAE4940DA571EA4A7E55D40ADDA3521ADAF4940143FC6DCB5E65D40ADDA3521ADAF4940143FC6DCB5E65D40F99D2633DEAE4940DA571EA4A7E55D40F99D2633DEAE4940
51795	Чашино-Ильдикан	5	48	1684	119.250501	119.268638	51.077905000000001	51.062804999999997	0103000020E6100000010000000500000061A7583508D05D403C8386FE0988494061A7583508D05D40F29881CAF88949409F1D705D31D15D40F29881CAF88949409F1D705D31D15D403C8386FE0988494061A7583508D05D403C8386FE09884940
60211	Уровские Ключи	5	48	1684	119.457463	119.476795	51.698447999999999	51.684925999999997	0103000020E610000001000000050000005308E41247DD5D400D17B9A7ABD749405308E41247DD5D4072FA7ABE66D949405DF92CCF83DE5D4072FA7ABE66D949405DF92CCF83DE5D400D17B9A7ABD749405308E41247DD5D400D17B9A7ABD74940
60150	Олочи	5	48	1684	119.89469099999999	119.904968	51.357270999999997	51.347911000000003	0103000020E61000000100000005000000A2410A9E42F95D409775FF5888AC4940A2410A9E42F95D4094675E0EBBAD49404CFBE6FEEAF95D4094675E0EBBAD49404CFBE6FEEAF95D409775FF5888AC4940A2410A9E42F95D409775FF5888AC4940
59106	Нерчинский Завод	5	48	1684	119.57953500000001	119.63465600000001	51.317494000000003	51.299624000000001	0103000020E61000000100000005000000CBF8F71917E55D40618C48145AA64940CBF8F71917E55D408F56B5A4A3A84940740D33349EE85D408F56B5A4A3A84940740D33349EE85D40618C48145AA64940CBF8F71917E55D40618C48145AA64940
22247	Михайловка	5	48	1684	119.42029100000001	119.440539	51.124243999999997	51.106931000000003	0103000020E6100000010000000500000067F3380CE6DA5D40DCF63DEAAF8D494067F3380CE6DA5D40B35C363AE78F494034677DCA31DC5D40B35C363AE78F494034677DCA31DC5D40DCF63DEAAF8D494067F3380CE6DA5D40DCF63DEAAF8D4940
60133	Ишага	5	48	1684	119.96457100000001	119.97377	51.486497999999997	51.475729000000001	0103000020E61000000100000005000000E2EA0088BBFD5D40206118B0E4BC4940E2EA0088BBFD5D40E2C8039145BE4940DCF4673F52FE5D40E2C8039145BE4940DCF4673F52FE5D40206118B0E4BC4940E2EA0088BBFD5D40206118B0E4BC4940
51872	Ивановка	5	48	1684	119.45070800000001	119.478071	51.265416000000002	51.253641999999999	0103000020E61000000100000005000000EB025E66D8DC5D402E724F5777A04940EB025E66D8DC5D40E6EAC726F9A14940A08A1BB798DE5D40E6EAC726F9A14940A08A1BB798DE5D402E724F5777A04940EB025E66D8DC5D402E724F5777A04940
51725	Горный Зерентуй	5	48	1684	119.503969	119.535725	51.224314	51.196711000000001	0103000020E61000000100000005000000A94C310741E05D40B9E177D32D994940A94C310741E05D4079043752B69C494093A9825149E25D4079043752B69C494093A9825149E25D40B9E177D32D994940A94C310741E05D40B9E177D32D994940
60168	Горбуновка	5	48	1684	119.749245	119.771038	51.233383000000003	51.225284000000002	0103000020E6100000010000000500000042EC4CA1F3EF5D40F2272A1BD69C494042EC4CA1F3EF5D40A038807EDF9D49404A7EC4AF58F15D40A038807EDF9D49404A7EC4AF58F15D40F2272A1BD69C494042EC4CA1F3EF5D40F2272A1BD69C4940
60187	Георгиевка	5	48	1684	119.43525699999999	119.451831	51.372093999999997	51.365673000000001	0103000020E61000000100000005000000B9162D40DBDB5D40DE03745FCEAE4940B9162D40DBDB5D40D784B4C6A0AF49406A1492CCEADC5D40D784B4C6A0AF49406A1492CCEADC5D40DE03745FCEAE4940B9162D40DBDB5D40DE03745FCEAE4940
60185	Булдуруй-1	5	48	1684	119.652497	119.671559	51.027718	51.015411999999998	0103000020E610000001000000050000003DEFC682C2E95D40A4FB3905F98149403DEFC682C2E95D4059C16F438C834940689599D2FAEA5D4059C16F438C834940689599D2FAEA5D40A4FB3905F98149403DEFC682C2E95D40A4FB3905F9814940
60103	Большой Зерентуй	5	48	1684	119.20601600000001	119.23614499999999	51.372329999999998	51.358187000000001	0103000020E61000000100000005000000FA9CBB5D2FCD5D401A6D5512D9AD4940FA9CBB5D2FCD5D40EBA86A82A8AF49404A07EBFF1CCF5D40EBA86A82A8AF49404A07EBFF1CCF5D401A6D5512D9AD4940FA9CBB5D2FCD5D401A6D5512D9AD4940
50685	Аргунск	5	48	1684	120.007277	120.02704900000001	51.583879000000003	51.571452999999998	0103000020E61000000100000005000000D540F33977005E40BD19355F25C94940D540F33977005E401DE90C8CBCCA4940EE98BA2BBB015E401DE90C8CBCCA4940EE98BA2BBB015E40BD19355F25C94940D540F33977005E40BD19355F25C94940
60113	городское поселение Нерчинское	5	48	1663	115.837998	117.08119499999999	52.906894999999999	51.567495999999998	0103000020E6100000010000000500000042075DC2A1F55C402F4E7CB5A3C8494042075DC2A1F55C40F5F3A62215744A405166834C32455D40F5F3A62215744A405166834C32455D402F4E7CB5A3C8494042075DC2A1F55C402F4E7CB5A3C84940
22335	Шивки	5	48	1663	116.695126	116.713092	51.922747999999999	51.912709999999997	0103000020E610000001000000050000005B26C3F17C2C5D40B75D68AED3F449405B26C3F17C2C5D408639419B1CF6494083C2A04CA32D5D408639419B1CF6494083C2A04CA32D5D40B75D68AED3F449405B26C3F17C2C5D40B75D68AED3F44940
22451	Савватеево	5	48	1663	116.50122500000001	116.52211	51.875321999999997	51.860446000000003	0103000020E6100000010000000500000002BC051214205D40ADFC321823EE494002BC051214205D4012BC218D0AF0494088BA0F406A215D4012BC218D0AF0494088BA0F406A215D40ADFC321823EE494002BC051214205D40ADFC321823EE4940
22181	Приисковый	5	48	1663	116.61205	116.63369899999999	51.929606999999997	51.911087999999999	0103000020E610000001000000050000001361C3D32B275D4097E315889EF449401361C3D32B275D40FB90B75CFDF64940812040868E285D40FB90B75CFDF64940812040868E285D4097E315889EF449401361C3D32B275D4097E315889EF44940
21796	Правые Кумаки	5	48	1663	116.347092	116.36345900000001	52.079774999999998	52.068344000000003	0103000020E61000000100000005000000022D5DC136165D405D70067FBF084A40022D5DC136165D40EA043411360A4A40F69B89E942175D40EA043411360A4A40F69B89E942175D405D70067FBF084A40022D5DC136165D405D70067FBF084A40
22470	Пешково	5	48	1663	116.44156700000001	116.479782	51.830055999999999	51.815297999999999	0103000020E610000001000000050000008BFF3BA2421C5D40423F53AF5BE849408BFF3BA2421C5D409EEC66463FEA494068CD8FBFB41E5D409EEC66463FEA494068CD8FBFB41E5D40423F53AF5BE849408BFF3BA2421C5D40423F53AF5BE84940
21457	Олинск	5	48	1663	116.19628299999999	116.221858	52.407814000000002	52.383606999999998	0103000020E61000000100000005000000B07092E68F0C5D4022C2BF081A314A40B07092E68F0C5D40EC6CC83F33344A40C896E5EB320E5D40EC6CC83F33344A40C896E5EB320E5D4022C2BF081A314A40B07092E68F0C5D4022C2BF081A314A40
21524	Олекан	5	48	1663	116.046623	116.08575399999999	52.372886999999999	52.360568999999998	0103000020E61000000100000005000000730F09DFFB025D40C879FF1F272E4A40730F09DFFB025D40410DDFC2BA2F4A40136058FE7C055D40410DDFC2BA2F4A40136058FE7C055D40C879FF1F272E4A40730F09DFFB025D40C879FF1F272E4A40
22109	Нижние Ключи	5	48	1663	116.80808	116.833377	51.995572000000003	51.973396999999999	0103000020E610000001000000050000004F232D95B7335D402383DC4598FC49404F232D95B7335D401B683EE76EFF4940450F7C0C56355D401B683EE76EFF4940450F7C0C56355D402383DC4598FC49404F232D95B7335D402383DC4598FC4940
40367	Нерчинск	5	48	1663	116.5086	116.610891	52.007510000000003	51.924886000000001	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
60138	Нагорный	5	48	1663	116.55736	116.57408700000001	52.021134000000004	52.015791	0103000020E610000001000000050000004F0647C9AB235D401B49827005024A404F0647C9AB235D40B66AD784B4024A40C38366D7BD245D40B66AD784B4024A40C38366D7BD245D401B49827005024A404F0647C9AB235D401B49827005024A40
21851	Левые Кумаки	5	48	1663	116.367825	116.38342	52.066682999999998	52.051611000000001	0103000020E61000000100000005000000AD69DE718A175D40938E72309B064A40AD69DE718A175D407E198C1189084A4078280AF489185D407E198C1189084A4078280AF489185D40938E72309B064A40AD69DE718A175D40938E72309B064A40
21404	Крупянка	5	48	1663	116.17139899999999	116.18362500000001	52.481395999999997	52.468747	0103000020E610000001000000050000004BE48233F80A5D408F8CD5E6FF3B4A404BE48233F80A5D406D3656629E3D4A40986E1283C00B5D406D3656629E3D4A40986E1283C00B5D408F8CD5E6FF3B4A404BE48233F80A5D408F8CD5E6FF3B4A40
21692	Кангил	5	48	1663	116.32179499999999	116.336932	52.250034999999997	52.239700999999997	0103000020E610000001000000050000000B410E4A98145D40C4E8B985AE1E4A400B410E4A98145D407CED992501204A40753E3C4B90155D407CED992501204A40753E3C4B90155D40C4E8B985AE1E4A400B410E4A98145D40C4E8B985AE1E4A40
22268	Калинино	5	48	1663	116.644542	116.671375	51.905399000000003	51.893994999999997	0103000020E6100000010000000500000080B9162D40295D40CDE49B6D6EF2494080B9162D40295D40626A4B1DE4F349408716D9CEF72A5D40626A4B1DE4F349408716D9CEF72A5D40CDE49B6D6EF2494080B9162D40295D40CDE49B6D6EF24940
21539	Илим	5	48	1663	116.029268	116.075181	52.214810999999997	52.205556999999999	0103000020E6100000010000000500000070B4E386DF015D40603B18B14F1A4A4070B4E386DF015D4018E945ED7E1B4A40F511F8C3CF045D4018E945ED7E1B4A40F511F8C3CF045D40603B18B14F1A4A4070B4E386DF015D40603B18B14F1A4A40
21304	Зюльзя	5	48	1663	116.188602	116.220636	52.544758000000002	52.519804999999998	0103000020E61000000100000005000000747D1F0E120C5D400DA661F888424A40747D1F0E120C5D40001E51A1BA454A407F1475E61E0E5D40001E51A1BA454A407F1475E61E0E5D400DA661F888424A40747D1F0E120C5D400DA661F888424A40
21604	Знаменка	5	48	1663	116.27474100000001	116.30527499999999	52.198669000000002	52.168447999999998	0103000020E61000000100000005000000B477465B95115D40CE893DB48F154A40B477465B95115D4051DD5CFC6D194A40545227A089135D4051DD5CFC6D194A40545227A089135D40CE893DB48F154A40B477465B95115D40CE893DB48F154A40
51479	Заречный	5	48	1663	116.493149	116.522649	52.035668999999999	52.025489999999998	0103000020E6100000010000000500000087C3D2C08F1F5D4001309E4143034A4087C3D2C08F1F5D40923D42CD90044A406092CA1473215D40923D42CD90044A406092CA1473215D4001309E4143034A4087C3D2C08F1F5D4001309E4143034A40
22024	Верхний Умыкэй	5	48	1663	116.540921	116.54631999999999	52.142606000000001	52.134171000000002	0103000020E610000001000000050000000E2E1D739E225D402B89EC832C114A400E2E1D739E225D40501BD5E940124A40A54929E8F6225D40501BD5E940124A40A54929E8F6225D402B89EC832C114A400E2E1D739E225D402B89EC832C114A40
22125	Верхние Ключи	5	48	1663	116.75785500000001	116.770477	51.971333000000001	51.958663999999999	0103000020E610000001000000050000000C0742B280305D4020ED7F80B5FA49400C0742B280305D404643C6A354FC49407E54C37E4F315D404643C6A354FC49407E54C37E4F315D4020ED7F80B5FA49400C0742B280305D4020ED7F80B5FA4940
51023	Бишигино	5	48	1663	116.420682	116.462166	51.859555999999998	51.849805000000003	0103000020E6100000010000000500000004013274EC1A5D40187D0569C6EC494004013274EC1A5D40508A56EE05EE4940AED4B320941D5D40508A56EE05EE4940AED4B320941D5D40187D0569C6EC494004013274EC1A5D40187D0569C6EC4940
21765	Березово	5	48	1663	116.443292	116.46557	52.160283	52.149619000000001	0103000020E6100000010000000500000005A568E55E1C5D401CEE23B726134A4005A568E55E1C5D40698D412784144A40EBFF1CE6CB1D5D40698D412784144A40EBFF1CE6CB1D5D401CEE23B726134A4005A568E55E1C5D401CEE23B726134A40
21625	Беломестново	5	48	1663	116.271795	116.28323899999999	52.176152000000002	52.165177	0103000020E61000000100000005000000D80DDB1665115D4094861A8524154A40D80DDB1665115D40009013268C164A40E97C789620125D40009013268C164A40E97C789620125D4094861A8524154A40D80DDB1665115D4094861A8524154A40
60129	Андронниково	5	48	1663	116.303371	116.324849	51.732871000000003	51.722434	0103000020E6100000010000000500000082E3326E6A135D405DC2A1B778DC494082E3326E6A135D40EA9788B7CEDD4940DAC87553CA145D40EA9788B7CEDD4940DAC87553CA145D405DC2A1B778DC494082E3326E6A135D405DC2A1B778DC4940
21066	Чалдонка	5	48	1622	119.21199	119.227791	53.786715000000001	53.777835000000003	0103000020E610000001000000050000000F45813E91CD5D409357E71890E34A400F45813E91CD5D40E622BE13B3E44A40AED4B32094CE5D40E622BE13B3E44A40AED4B32094CE5D409357E71890E34A400F45813E91CD5D409357E71890E34A40
20992	Таптугары	5	48	1622	120.038404	120.078154	53.689112999999999	53.676676	0103000020E6100000010000000500000047020D3675025E407AFEB4519DD64A4047020D3675025E40CD1FD3DA34D84A404D83A27900055E40CD1FD3DA34D84A404D83A27900055E407AFEB4519DD64A4047020D3675025E407AFEB4519DD64A40
20928	Семиозерный	5	48	1622	120.349535	120.379907	53.718162999999997	53.701396000000003	0103000020E61000000100000005000000AC730CC85E165E40CAC51858C7D94A40AC730CC85E165E403F19E3C3ECDB4A406021736550185E403F19E3C3ECDB4A406021736550185E40CAC51858C7D94A40AC730CC85E165E40CAC51858C7D94A40
21235	Сбега	5	48	1622	118.49604100000001	118.532235	53.325487000000003	53.303888000000001	0103000020E61000000100000005000000691EC022BF9F5D40CCD24ECDE5A64A40691EC022BF9F5D40F722DA8EA9A94A4057B2632310A25D40F722DA8EA9A94A4057B2632310A25D40CCD24ECDE5A64A40691EC022BF9F5D40CCD24ECDE5A64A40
20325	Могоча	5	48	1622	119.725898	119.802318	53.768208999999999	53.715834000000001	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
20821	Кудеча	5	48	1622	119.285481	119.310957	53.472563000000001	53.456690000000002	0103000020E6100000010000000500000048A8195245D25D40833463D174BA4A4048A8195245D25D405B26C3F17CBC4A40965D30B8E6D35D405B26C3F17CBC4A40965D30B8E6D35D40833463D174BA4A4048A8195245D25D40833463D174BA4A40
60059	Ксеньевка	5	48	1622	118.698836	118.749843	53.569963000000001	53.545321000000001	0103000020E610000001000000050000001E51A1BAB9AC5D4038691A14CDC54A401E51A1BAB9AC5D400C772E8CF4C84A409C887E6DFDAF5D400C772E8CF4C84A409C887E6DFDAF5D4038691A14CDC54A401E51A1BAB9AC5D4038691A14CDC54A40
60058	Ксеньевка	5	48	1622	118.698836	118.749843	53.569963000000001	53.545321000000001	0103000020E610000001000000050000001E51A1BAB9AC5D4038691A14CDC54A401E51A1BAB9AC5D400C772E8CF4C84A409C887E6DFDAF5D400C772E8CF4C84A409C887E6DFDAF5D4038691A14CDC54A401E51A1BAB9AC5D4038691A14CDC54A40
20886	Ключевский	5	48	1622	119.430352	119.476418	53.544004999999999	53.527158	0103000020E610000001000000050000002A711DE38ADB5D4092E9D0E979C34A402A711DE38ADB5D4024EEB1F4A1C54A40724EECA17DDE5D4024EEB1F4A1C54A40724EECA17DDE5D4092E9D0E979C34A402A711DE38ADB5D4092E9D0E979C34A40
21049	Итака (Главный Стан)	5	48	1622	118.694928	118.719461	53.900660000000002	53.884805999999998	0103000020E61000000100000005000000C8444AB379AC5D40FCA6B05241F14A40C8444AB379AC5D405E68AED348F34A40D66F26A60BAE5D405E68AED348F34A40D66F26A60BAE5D40FCA6B05241F14A40C8444AB379AC5D40FCA6B05241F14A40
60094	Давенда	5	48	1622	119.29851600000001	119.333505	53.561824000000001	53.528727000000003	0103000020E610000001000000050000004C55DAE21AD35D4090C18A53ADC34A404C55DAE21AD35D40D00D4DD9E9C74A405C035B2558D55D40D00D4DD9E9C74A405C035B2558D55D4090C18A53ADC34A404C55DAE21AD35D4090C18A53ADC34A40
58993	Амазар	5	48	1622	120.83926099999999	120.89162399999999	53.87574	53.847085999999997	0103000020E61000000100000005000000BAF3C473B6355E40217365506DEC4A40BAF3C473B6355E4047E6913F18F04A4009151C5E10395E4047E6913F18F04A4009151C5E10395E40217365506DEC4A40BAF3C473B6355E40217365506DEC4A40
60093	Цугол	5	48	692	115.61115599999999	115.635491	51.058418000000003	51.040751	0103000020E6100000010000000500000044300E2E1DE75C40C0232A543785494044300E2E1DE75C40B6BFB33D7A874940C07971E2ABE85C40B6BFB33D7A874940C07971E2ABE85C40C0232A543785494044300E2E1DE75C40C0232A5437854940
60123	Цаган-Челутай	5	48	692	115.057129	115.09705	51.094262000000001	51.059849999999997	0103000020E61000000100000005000000CEA96400A8C35C403255302AA9874940CEA96400A8C35C40B6A0F7C6108C4940EA04341136C65C40B6A0F7C6108C4940EA04341136C65C403255302AA9874940CEA96400A8C35C403255302AA9874940
60068	Цаган-Ола	5	48	692	115.462637	115.492345	51.368316	51.34939	0103000020E61000000100000005000000DA3A38D89BDD5C4054C6BFCFB8AC4940DA3A38D89BDD5C40F94B8BFA24AF494058569A9482DF5C40F94B8BFA24AF494058569A9482DF5C4054C6BFCFB8AC4940DA3A38D89BDD5C4054C6BFCFB8AC4940
50886	Харганаша	5	48	692	115.03801300000001	115.05005	51.265636000000001	51.258924	0103000020E61000000100000005000000AAF413CE6EC25C402313F06B24A14940AAF413CE6EC25C40F451465C00A249408C4AEA0434C35C40F451465C00A249408C4AEA0434C35C402313F06B24A14940AAF413CE6EC25C402313F06B24A14940
59058	Хара-Шибирь	5	48	692	115.176434	115.206411	51.542608999999999	51.524059000000001	0103000020E61000000100000005000000C2F9D4B14ACB5C405516855D14C34940C2F9D4B14ACB5C40F4C1323674C5494038A27BD635CD5C40F4C1323674C5494038A27BD635CD5C405516855D14C34940C2F9D4B14ACB5C405516855D14C34940
60080	Ушарбай	5	48	692	114.797803	114.850858	51.407356	51.387329000000001	0103000020E61000000100000005000000A56950340FB35C406DE525FF93B14940A56950340FB35C4029EACC3D24B449408FE21C7574B65C4029EACC3D24B449408FE21C7574B65C406DE525FF93B14940A56950340FB35C406DE525FF93B14940
60075	Ортуй	5	48	692	115.62217800000001	115.64433099999999	50.822690999999999	50.807968000000002	0103000020E610000001000000050000009B92ACC3D1E75C40761BD47E6B6749409B92ACC3D1E75C4055DB4DF04D694940223317B83CE95C4055DB4DF04D694940223317B83CE95C40761BD47E6B6749409B92ACC3D1E75C40761BD47E6B674940
59059	Могойтуй	5	48	692	114.902789	114.954487	51.302219999999998	51.259993999999999	0103000020E61000000100000005000000118C834BC7B95C40FF93BF7B47A14940118C834BC7B95C403B191C25AFA64940425DA45016BD5C403B191C25AFA64940425DA45016BD5C40FF93BF7B47A14940118C834BC7B95C40FF93BF7B47A14940
54089	Могойтуй	5	48	692	114.902789	114.954487	51.302219999999998	51.259993999999999	0103000020E61000000100000005000000118C834BC7B95C40FF93BF7B47A14940118C834BC7B95C403B191C25AFA64940425DA45016BD5C403B191C25AFA64940425DA45016BD5C40FF93BF7B47A14940118C834BC7B95C40FF93BF7B47A14940
51842	Могойтуй	5	48	692	114.902789	114.954487	51.302219999999998	51.259993999999999	0103000020E61000000100000005000000118C834BC7B95C40FF93BF7B47A14940118C834BC7B95C403B191C25AFA64940425DA45016BD5C403B191C25AFA64940425DA45016BD5C40FF93BF7B47A14940118C834BC7B95C40FF93BF7B47A14940
60117	Кусоча	5	48	692	115.62642700000001	115.651185	50.707236999999999	50.698183999999998	0103000020E610000001000000050000003695456117E85C40944BE3175E5949403695456117E85C40B5C2F4BD865A494054A9D903ADE95C40B5C2F4BD865A494054A9D903ADE95C40944BE3175E5949403695456117E85C40944BE3175E594940
51781	Курульжа	5	48	692	114.413899	115.919898	51.689694000000003	50.578698000000003	0103000020E6100000010000000500000037363B527D9A5C405C21ACC6124A494037363B527D9A5C40AC1F9BE447D84940F969DC9BDFFA5C40AC1F9BE447D84940F969DC9BDFFA5C405C21ACC6124A494037363B527D9A5C405C21ACC6124A4940
51766	Зугалай	5	48	692	115.007227	115.039207	51.476733000000003	51.460619000000001	0103000020E610000001000000050000007C293C6876C05C4047753A90F5BA49407C293C6876C05C4045F6419605BD49408EB1135E82C25C4045F6419605BD49408EB1135E82C25C4047753A90F5BA49407C293C6876C05C4047753A90F5BA4940
51059	Догой	5	48	692	114.64263699999999	114.67281199999999	51.360807999999999	51.343871	0103000020E61000000100000005000000C58CF0F620A95C407B8505F703AC4940C58CF0F620A95C404D11E0F42EAE4940CE16105A0FAB5C404D11E0F42EAE4940CE16105A0FAB5C407B8505F703AC4940C58CF0F620A95C407B8505F703AC4940
60203	Бурятская	5	48	692	114.691012	114.71311900000001	51.456169000000003	51.444432999999997	0103000020E610000001000000050000003049658A39AC5C40AF21382EE3B849403049658A39AC5C407A39ECBE63BA494000CADFBDA3AD5C407A39ECBE63BA494000CADFBDA3AD5C40AF21382EE3B849403049658A39AC5C40AF21382EE3B84940
5835	Бильчиртуй	5	48	692	115.148595	115.199943	51.079903000000002	51.057529000000002	0103000020E6100000010000000500000058569A9482C95C402AC93A1C5D87494058569A9482C95C4018EDF1423A8A49401B84B9DDCBCC5C4018EDF1423A8A49401B84B9DDCBCC5C402AC93A1C5D87494058569A9482C95C402AC93A1C5D874940
6007	Ара-Булак	5	48	692	115.080889	115.106842	51.202613999999997	51.185200999999999	0103000020E61000000100000005000000CB660E492DC55C40DF1797AAB4974940CB660E492DC55C401ADB6B41EF994940B6F5D37FD6C65C401ADB6B41EF994940B6F5D37FD6C65C40DF1797AAB4974940CB660E492DC55C40DF1797AAB4974940
60101	Ага (Хила)	5	48	692	115.15734500000001	115.193152	51.196179999999998	51.177990999999999	0103000020E610000001000000050000001B4CC3F011CA5C40BDFDB968C89649401B4CC3F011CA5C408C101E6D1C9949400CCA349A5CCC5C408C101E6D1C9949400CCA349A5CCC5C40BDFDB968C89649401B4CC3F011CA5C40BDFDB968C8964940
60109	Ульхун-Партия	5	48	283	112.75494399999999	112.77335100000001	49.864193999999998	49.848415000000003	0103000020E61000000100000005000000EE93A30051305C40CA37DBDC98EC4840EE93A30051305C4020B3B3E89DEE48400D5531957E315C4020B3B3E89DEE48400D5531957E315C40CA37DBDC98EC4840EE93A30051305C40CA37DBDC98EC4840
51002	Тырин	5	48	283	112.388881	112.416837	49.574584999999999	49.556075	0103000020E610000001000000050000004A42226DE3185C40C58F31772DC748404A42226DE3185C40D6E253008CC94840D1B01875AD1A5C40D6E253008CC94840D1B01875AD1A5C40C58F31772DC748404A42226DE3185C40C58F31772DC74840
60184	Тарбальджей	5	48	283	112.50238299999999	112.525937	49.739769000000003	49.732717999999998	0103000020E610000001000000050000003FC4060B27205C40639813B4C9DD48403FC4060B27205C401DCC26C0B0DE484068B0A9F3A8215C401DCC26C0B0DE484068B0A9F3A8215C40639813B4C9DD48403FC4060B27205C40639813B4C9DD4840
60132	Мордой	5	48	283	112.002156	112.05725	49.704546000000001	49.683667	0103000020E610000001000000050000005F5FEB5223005C405E2D776682D748405F5FEB5223005C40894336902EDA48408B6CE7FBA9035C40894336902EDA48408B6CE7FBA9035C405E2D776682D748405F5FEB5223005C405E2D776682D74840
60178	Михайло-Павловское	5	48	283	109.36179199999999	113.30949200000001	50.393596000000002	49.154963000000002	0103000020E6100000010000000500000015FDA19927575B40878BDCD3D593484015FDA19927575B4010EB8D5A61324940EA9788B7CE535C4010EB8D5A61324940EA9788B7CE535C40878BDCD3D593484015FDA19927575B40878BDCD3D5934840
51472	Мангут	5	48	283	112.657405	112.689269	49.706083999999997	49.685811000000001	0103000020E6100000010000000500000085CE6BEC122A5C40581EA4A7C8D7484085CE6BEC122A5C404B1DE4F560DA48406249B9FB1C2C5C404B1DE4F560DA48406249B9FB1C2C5C40581EA4A7C8D7484085CE6BEC122A5C40581EA4A7C8D74840
60043	Любовь	5	48	283	112.14116199999999	112.163296	49.647773000000001	49.632716000000002	0103000020E61000000100000005000000075C57CC08095C40F6D37FD6FCD04840075C57CC08095C40AC1DC539EAD2484054E41071730A5C40AC1DC539EAD2484054E41071730A5C40F6D37FD6FCD04840075C57CC08095C40F6D37FD6FCD04840
51591	Кыра	5	48	283	111.951842	111.98969700000001	49.587842999999999	49.570144999999997	0103000020E61000000100000005000000643DB5FAEAFC5B402C7DE882FAC84840643DB5FAEAFC5B405D177E703ECB4840C2FC153257FF5B405D177E703ECB4840C2FC153257FF5B402C7DE882FAC84840643DB5FAEAFC5B402C7DE882FAC84840
60213	Гавань	5	48	283	112.161266	112.182259	49.473728000000001	49.458967999999999	0103000020E610000001000000050000003BFDA02E520A5C408CF4A276BFBA48403BFDA02E520A5C4089997D1EA3BC4840B519A721AA0B5C4089997D1EA3BC4840B519A721AA0B5C408CF4A276BFBA48403BFDA02E520A5C408CF4A276BFBA4840
60097	Верхний Ульхун	5	48	283	112.530204	112.55285000000001	49.595388	49.565365	0103000020E61000000100000005000000560DC2DCEE215C40CAA65CE15DC84840560DC2DCEE215C4026378AAC35CC4840FE65F7E461235C4026378AAC35CC4840FE65F7E461235C40CAA65CE15DC84840560DC2DCEE215C40CAA65CE15DC84840
51588	Билютуй	5	48	283	111.68130499999999	111.701427	49.592526999999997	49.579883000000002	0103000020E610000001000000050000007B6649809AEB5B40D1402C9B39CA48407B6649809AEB5B409D7FBBECD7CB48400262122EE4EC5B409D7FBBECD7CB48400262122EE4EC5B40D1402C9B39CA48407B6649809AEB5B40D1402C9B39CA4840
51523	Алтан	5	48	283	111.519204	111.551885	49.521554000000002	49.502806999999997	0103000020E61000000100000005000000F4FC69A33AE15B409599D2FA5BC04840F4FC69A33AE15B408B8C0E48C2C24840CA89761552E35B408B8C0E48C2C24840CA89761552E35B409599D2FA5BC04840F4FC69A33AE15B409599D2FA5BC04840
51714	Ямаровка	5	48	34	110.243444	110.253702	50.619858000000001	50.611055999999998	0103000020E61000000100000005000000139A2496948F5B4025034015374E4940139A2496948F5B40FD14C781574F4940823B50A73C905B40FD14C781574F4940823B50A73C905B4025034015374E4940139A2496948F5B4025034015374E4940
52148	Ядрихино	5	48	34	110.335566	110.348457	50.608541000000002	50.600200000000001	0103000020E6100000010000000500000092E9D0E979955B409487855AD34C494092E9D0E979955B4038A3E6ABE44D4940FCC3961E4D965B4038A3E6ABE44D4940FCC3961E4D965B409487855AD34C494092E9D0E979955B409487855AD34C4940
52194	Этытэй	5	48	34	108.469055	108.487776	50.302166	50.290272000000002	0103000020E610000001000000050000009E4143FF041E5B40E67805A2272549409E4143FF041E5B4048FB1F60AD26494084F1D3B8371F5B4048FB1F60AD26494084F1D3B8371F5B40E67805A2272549409E4143FF041E5B40E67805A227254940
60142	Шимбилик	5	48	34	109.549684	109.607814	50.567439	50.553037000000003	0103000020E610000001000000050000009BC8CC052E635B402E3D9AEAC94649409BC8CC052E635B40CBBC55D7A14849404303B16CE6665B40CBBC55D7A14849404303B16CE6665B402E3D9AEAC94649409BC8CC052E635B402E3D9AEAC9464940
51698	Черемхово	5	48	34	110.12986100000001	110.186832	50.585607000000003	50.573881	0103000020E61000000100000005000000A80183A44F885B40DC65BFEE74494940A80183A44F885B4083A7902BF54A49402976340EF58B5B4083A7902BF54A49402976340EF58B5B40DC65BFEE74494940A80183A44F885B40DC65BFEE74494940
50737	Хилкотой	5	48	34	108.070994	108.109801	49.928716999999999	49.911340000000003	0103000020E61000000100000005000000950D6B2A8B045B40B1C403CAA6F44840950D6B2A8B045B409F1EDB32E0F648405C04C6FA06075B409F1EDB32E0F648405C04C6FA06075B40B1C403CAA6F44840950D6B2A8B045B40B1C403CAA6F44840
52169	Фомичево	5	48	34	109.254623	109.273568	50.513227000000001	50.503317000000003	0103000020E61000000100000005000000CD7344BE4B505B40AB4203B16C404940CD7344BE4B505B404C361E6CB1414940DB4E5B2382515B404C361E6CB1414940DB4E5B2382515B40AB4203B16C404940CD7344BE4B505B40AB4203B16C404940
52213	Усть-Урлук	5	48	34	107.79934299999999	107.812692	49.947983000000001	49.938319	0103000020E6100000010000000500000056D28A6F28F35A40931B45D61AF8484056D28A6F28F35A40FD14C78157F94840226E4E2503F45A40FD14C78157F94840226E4E2503F45A40931B45D61AF8484056D28A6F28F35A40931B45D61AF84840
51797	Урлук	5	48	34	107.84834600000001	107.94751100000001	50.075611000000002	50.038150999999999	0103000020E61000000100000005000000516C054D4BF65A40A4A7C821E2044940516C054D4BF65A40E31B0A9FAD0949406B662D05A4FC5A40E31B0A9FAD0949406B662D05A4FC5A40A4A7C821E2044940516C054D4BF65A40A4A7C821E2044940
52160	Осиновка	5	48	34	109.44672799999999	109.47666	50.561185999999999	50.552373000000003	0103000020E61000000100000005000000478D0931975C5B40C2189128B4464940478D0931975C5B408D7C5EF1D4474940EDD3F198815E5B408D7C5EF1D4474940EDD3F198815E5B40C2189128B4464940478D0931975C5B40C2189128B4464940
51724	Нижний Нарым	5	48	34	108.232331	108.261625	50.111382999999996	50.075611000000002	0103000020E6100000010000000500000035B6D782DE0E5B40E31B0A9FAD09494035B6D782DE0E5B40492A53CC410E494039B4C876BE105B40492A53CC410E494039B4C876BE105B40E31B0A9FAD09494035B6D782DE0E5B40E31B0A9FAD094940
51834	Малоархангельск	5	48	34	108.80470200000001	108.875013	50.413122000000001	50.386330999999998	0103000020E61000000100000005000000A741D13C80335B402A37514B73314940A741D13C80335B400AA1832EE1344940CAA4863600385B400AA1832EE1344940CAA4863600385B402A37514B73314940A741D13C80335B402A37514B73314940
59029	Красный Чикой	5	48	34	108.72089800000001	108.779854	50.388357999999997	50.348672999999998	0103000020E610000001000000050000001E705D31232E5B40C5FF1D51A12C49401E705D31232E5B40EA9106B7B5314940E869C020E9315B40EA9106B7B5314940E869C020E9315B40C5FF1D51A12C49401E705D31232E5B40C5FF1D51A12C4940
51856	Красные Речки (Дурново)	5	48	34	109.091381	109.110416	50.469405000000002	50.458458999999998	0103000020E61000000100000005000000739EB12FD9455B4047C7D5C8AE3A4940739EB12FD9455B4019CA8976153C4940213D450E11475B4019CA8976153C4940213D450E11475B4047C7D5C8AE3A4940739EB12FD9455B4047C7D5C8AE3A4940
51891	Коротково	5	48	34	108.938838	108.997094	50.449706999999997	50.433563999999997	0103000020E610000001000000050000007E8FFAEB153C5B40895C70067F3749407E8FFAEB153C5B4021E4BCFF8F3949406C425A63D03F5B4021E4BCFF8F3949406C425A63D03F5B40895C70067F3749407E8FFAEB153C5B40895C70067F374940
60106	Захарово	5	48	34	109.363598	109.405486	50.547272999999997	50.528672999999998	0103000020E6100000010000000500000006B98B3045575B409CA38E8EAB43494006B98B3045575B40ED7DAA0A0D464940183F8D7BF3595B40ED7DAA0A0D464940183F8D7BF3595B409CA38E8EAB43494006B98B3045575B409CA38E8EAB434940
50858	Жиндокон	5	48	34	108.045931	108.062307	50.083212000000003	50.067031	0103000020E61000000100000005000000D8B79388F0025B40BA68C87894084940D8B79388F0025B404051D9B0A60A4940F6D37FD6FC035B404051D9B0A60A4940F6D37FD6FC035B40BA68C87894084940D8B79388F0025B40BA68C87894084940
60141	Жиндо-1	5	48	34	107.956198	107.974209	49.947448999999999	49.941107000000002	0103000020E610000001000000050000000AA0185932FD5A40B284B53176F848400AA0185932FD5A405FD0420246F94840029EB47059FE5A405FD0420246F94840029EB47059FE5A40B284B53176F848400AA0185932FD5A40B284B53176F84840
52208	Гутай	5	48	34	108.185664	108.209236	50.007477000000002	49.982761000000004	0103000020E61000000100000005000000DA0242EBE10B5B406364C91CCBFD4840DA0242EBE10B5B40713C9F01F50049405649641F640D5B40713C9F01F50049405649641F640D5B406364C91CCBFD4840DA0242EBE10B5B406364C91CCBFD4840
51707	Верхний Шергольджин	5	48	34	108.31963	108.328181	50.204731000000002	50.179904000000001	0103000020E61000000100000005000000833463D174145B40B535221807174940833463D174145B401BBD1AA0341A4940CA8AE1EA00155B401BBD1AA0341A4940CA8AE1EA00155B40B535221807174940833463D174145B40B535221807174940
52175	Быково	5	48	34	109.00848499999999	109.03052	50.423240999999997	50.414121000000002	0103000020E610000001000000050000006B60AB048B405B401DCBBBEA013549406B60AB048B405B40C5A9D6C22C364940EE77280AF4415B40C5A9D6C22C364940EE77280AF4415B401DCBBBEA013549406B60AB048B405B401DCBBBEA01354940
52198	Бурсомон	5	48	34	108.25550800000001	108.273411	50.185550999999997	50.174360999999998	0103000020E6100000010000000500000073F7393E5A105B40535914765116494073F7393E5A105B40BB5E9A22C017494077D7D9907F115B40BB5E9A22C017494077D7D9907F115B40535914765116494073F7393E5A105B405359147651164940
60070	Большая речка	5	48	34	108.45457399999999	108.477401	50.137002000000003	50.127341000000001	0103000020E6100000010000000500000029E78BBD171D5B405038BBB54C10494029E78BBD171D5B4049BE124889114940F984ECBC8D1E5B4049BE124889114940F984ECBC8D1E5B405038BBB54C10494029E78BBD171D5B405038BBB54C104940
52179	Барахоево	5	48	34	108.87340500000001	108.94296199999999	50.437407999999998	50.407083	0103000020E610000001000000050000006DCA15DEE5375B40F8E0B54B1B3449406DCA15DEE5375B401F813FFCFC374940BAD7497D593C5B401F813FFCFC374940BAD7497D593C5B40F8E0B54B1B3449406DCA15DEE5375B40F8E0B54B1B344940
51706	Байхор	5	48	34	108.568804	108.599428	50.300013999999997	50.292406999999997	0103000020E610000001000000050000006075E44867245B408C0FB3976D2549406075E44867245B40CB2BD7DB66264940A11342075D265B40CB2BD7DB66264940A11342075D265B408C0FB3976D2549406075E44867245B408C0FB3976D254940
52164	Аца	5	48	34	109.53804100000001	109.562116	50.49926	50.476101	0103000020E610000001000000050000000FBA84436F625B40E44BA8E0F03C49400FBA84436F625B40B9196EC0E73F4940BC2363B5F9635B40B9196EC0E73F4940BC2363B5F9635B40E44BA8E0F03C49400FBA84436F625B40E44BA8E0F03C4940
51027	Афонькино	5	48	34	110.100728	110.126124	50.576735999999997	50.568424	0103000020E61000000100000005000000A872DA5372865B4079211D1EC2484940A872DA5372865B408236397CD249494068CF656A12885B408236397CD249494068CF656A12885B4079211D1EC2484940A872DA5372865B4079211D1EC2484940
51763	Архангельское (Качен)	5	48	34	108.73333100000001	108.77310799999999	50.328550999999997	50.308863000000002	0103000020E61000000100000005000000278925E5EE2E5B40E4F8A1D288274940278925E5EE2E5B40B7088CF50D2A4940A911FA997A315B40B7088CF50D2A4940A911FA997A315B40E4F8A1D288274940278925E5EE2E5B40E4F8A1D288274940
51900	Альбитуй	5	48	34	108.217096	108.24445	50.148935000000002	50.129939999999998	0103000020E61000000100000005000000EA059FE6E40D5B409B38B9DFA1104940EA059FE6E40D5B40691D554D1013494076E09C11A50F5B40691D554D1013494076E09C11A50F5B409B38B9DFA1104940EA059FE6E40D5B409B38B9DFA1104940
52183	Александровка (Карымка)	5	48	34	108.81297499999999	108.82391699999999	50.348610000000001	50.341406999999997	0103000020E61000000100000005000000CC5D4BC807345B400FD07D39B32B4940CC5D4BC807345B407F87A2409F2C494094675E0EBB345B407F87A2409F2C494094675E0EBB345B400FD07D39B32B4940CC5D4BC807345B400FD07D39B32B4940
51864	Юбилейный	5	48	1224	118.35011	118.36893000000001	50.272956999999998	50.257468000000003	0103000020E610000001000000050000002A00C63368965D401EE21FB6F42049402A00C63368965D406D1B4641F0224940DA20938C9C975D406D1B4641F0224940DA20938C9C975D401EE21FB6F42049402A00C63368965D401EE21FB6F4204940
60054	Целинный	5	48	1224	118.09853699999999	118.132763	50.270332000000003	50.260306999999997	0103000020E610000001000000050000008A1C226E4E865D40BEF561BD512149408A1C226E4E865D40F9872D3D9A2249409BC761307F885D40F9872D3D9A2249409BC761307F885D40BEF561BD512149408A1C226E4E865D40BEF561BD51214940
51530	Соктуй-Милозан	5	48	1224	117.763717	117.793873	50.083801999999999	50.071939	0103000020E610000001000000050000008D9944BDE0705D404A27124C350949408D9944BDE0705D4071AB2006BA0A49405B0BB3D0CE725D4071AB2006BA0A49405B0BB3D0CE725D404A27124C350949408D9944BDE0705D404A27124C35094940
51528	Октябрьский	5	48	1224	118.217043	118.24207	50.078305	50.064520999999999	0103000020E61000000100000005000000D9B45208E48D5D40DE73603942084940D9B45208E48D5D40800EF3E5050A4940EF552B137E8F5D40800EF3E5050A4940EF552B137E8F5D40DE73603942084940D9B45208E48D5D40DE73603942084940
60118	Маргуцек	5	48	1224	117.884055	117.907169	50.406652000000001	50.397696000000003	0103000020E6100000010000000500000061376C5B94785D4001E0D8B3E732494061376C5B94785D402F6D382C0D3449407BBC900E0F7A5D402F6D382C0D3449407BBC900E0F7A5D4001E0D8B3E732494061376C5B94785D4001E0D8B3E7324940
60176	Куйтун	5	48	1224	118.599357	118.614071	50.243673000000001	50.237278000000003	0103000020E610000001000000050000003C6876DD5BA65D40B80721205F1E49403C6876DD5BA65D4088F546AD301F4940029B73F04CA75D4088F546AD301F4940029B73F04CA75D40B80721205F1E49403C6876DD5BA65D40B80721205F1E4940
12362	Краснокаменск	5	48	1224	118.00953199999999	118.199499	50.151226000000001	50.059877	0103000020E61000000100000005000000FD101B2C9C805D402C64AE0CAA074940FD101B2C9C805D400727A25F5B1349406C257497C48C5D400727A25F5B1349406C257497C48C5D402C64AE0CAA074940FD101B2C9C805D402C64AE0CAA074940
51765	Ковыли	5	48	1224	117.593244	117.629383	50.380597999999999	50.365512000000003	0103000020E6100000010000000500000016A3AEB5F7655D40D525E318C92E494016A3AEB5F7655D4025766D6FB7304940236AA2CF47685D4025766D6FB7304940236AA2CF47685D40D525E318C92E494016A3AEB5F7655D40D525E318C92E4940
60200	Капцегайтуй	5	48	1224	118.586089	118.606669	49.961700999999998	49.949438000000001	0103000020E61000000100000005000000E7E26F7B82A55D4032CA332F87F94840E7E26F7B82A55D40E7C3B30419FB4840CF9F36AAD3A65D40E7C3B30419FB4840CF9F36AAD3A65D4032CA332F87F94840E7E26F7B82A55D4032CA332F87F94840
60120	Кайластуй	5	48	1224	118.38865699999999	118.411258	49.836593000000001	49.824477000000002	0103000020E6100000010000000500000022179CC1DF985D40F0A65B7688E9484022179CC1DF985D400188BB7A15EB4840FA0D130D529A5D400188BB7A15EB4840FA0D130D529A5D40F0A65B7688E9484022179CC1DF985D40F0A65B7688E94840
51770	Богдановка	5	48	1224	118.747139	118.766587	50.009450999999999	50.000546999999997	0103000020E610000001000000050000003CA41820D1AF5D40328E91EC110049403CA41820D1AF5D400EF5BBB0350149407BA2EBC20FB15D400EF5BBB0350149407BA2EBC20FB15D40328E91EC110049403CA41820D1AF5D40328E91EC11004940
51899	Урульга	5	48	1560	114.77446500000001	114.816749	51.783673999999998	51.752054999999999	0103000020E6100000010000000500000063B9A5D590B15C408AE5965643E0494063B9A5D590B15C40DD5CFC6D4FE449409B02999D45B45C40DD5CFC6D4FE449409B02999D45B45C408AE5965643E0494063B9A5D590B15C408AE5965643E04940
51746	Тыргетуй	5	48	1560	113.78030800000001	113.807941	51.450775	51.431187999999999	0103000020E61000000100000005000000A933F790F0715C40BD361B2B31B74940A933F790F0715C405D6DC5FEB2B949403E062B4EB5735C405D6DC5FEB2B949403E062B4EB5735C40BD361B2B31B74940A933F790F0715C40BD361B2B31B74940
60180	Новодоронинск	5	48	1560	113.85722199999999	113.873814	51.541853000000003	51.527169000000001	0103000020E6100000010000000500000059DAA9B9DC765C40863B17467AC3494059DAA9B9DC765C40A81E69705BC549405D328E91EC775C40A81E69705BC549405D328E91EC775C40863B17467AC3494059DAA9B9DC765C40863B17467AC34940
50837	Нарын-Талача	5	48	1560	114.851388	114.871447	51.936492999999999	51.921582000000001	0103000020E610000001000000050000003D0D18247DB65C40884A2366F6F549403D0D18247DB65C406AF7AB00DFF74940A14CA3C9C5B75C406AF7AB00DFF74940A14CA3C9C5B75C40884A2366F6F549403D0D18247DB65C40884A2366F6F54940
51498	Маяки	5	48	1560	114.311446	114.33738099999999	51.487766000000001	51.465344000000002	0103000020E61000000100000005000000151E34BBEE935C40E6B1666490BB4940151E34BBEE935C40E50CC51D6FBE4940AC527AA697955C40E50CC51D6FBE4940AC527AA697955C40E6B1666490BB4940151E34BBEE935C40E6B1666490BB4940
60174	Курорт-Дарасун	5	48	1560	113.700457	113.76383300000001	51.211129	51.185589999999998	0103000020E6100000010000000500000046D09849D46C5C40793BC269C197494046D09849D46C5C405C1E6B46069B4940C2A6CEA3E2705C405C1E6B46069B4940C2A6CEA3E2705C40793BC269C197494046D09849D46C5C40793BC269C1974940
59127	Карымское	5	48	1560	114.292546	114.369693	51.646174000000002	51.611275999999997	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
51903	Карымское	5	48	1560	114.292546	114.369693	51.646174000000002	51.611275999999997	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
60035	Карымское	5	48	1560	114.292546	114.369693	51.646174000000002	51.611275999999997	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
51000	Кайдалово	5	48	1560	114.55985699999999	114.595422	51.655583999999998	51.625675999999999	0103000020E61000000100000005000000F25B74B2D4A35C4030F2B22616D04940F25B74B2D4A35C40F3E32F2DEAD349406954E0641BA65C40F3E32F2DEAD349406954E0641BA65C4030F2B22616D04940F25B74B2D4A35C4030F2B22616D04940
51500	Кадахта	5	48	1560	114.237865	114.261222	51.619928000000002	51.606029999999997	0103000020E610000001000000050000003CF71E2E398F5C408B321B6492CD49403CF71E2E398F5C40F6EFFACC59CF4940BABF7ADCB7905C40F6EFFACC59CF4940BABF7ADCB7905C408B321B6492CD49403CF71E2E398F5C408B321B6492CD4940
60209	Жимбира	5	48	1560	113.992293	114.02607	51.521582000000002	51.508533999999997	0103000020E610000001000000050000002FC37FBA817F5C40B87361A417C149402FC37FBA817F5C405517F032C3C24940085A8121AB815C405517F032C3C24940085A8121AB815C40B87361A417C149402FC37FBA817F5C40B87361A417C14940
51508	Дарасун	5	48	1560	113.940352	113.998276	51.682457999999997	51.624065999999999	0103000020E610000001000000050000009BAE27BA2E7C5C40D4450A65E1CF49409BAE27BA2E7C5C406072A3C85AD749406E1805C1E37F5C406072A3C85AD749406E1805C1E37F5C40D4450A65E1CF49409BAE27BA2E7C5C40D4450A65E1CF4940
20093	Дарасун	5	48	1560	113.940352	113.998276	51.682457999999997	51.624065999999999	0103000020E610000001000000050000009BAE27BA2E7C5C40D4450A65E1CF49409BAE27BA2E7C5C406072A3C85AD749406E1805C1E37F5C406072A3C85AD749406E1805C1E37F5C40D4450A65E1CF49409BAE27BA2E7C5C40D4450A65E1CF4940
50819	Большая Тура	5	48	1560	114.05838199999999	114.11538899999999	51.637543999999998	51.612015	0103000020E61000000100000005000000342BDB87BC835C40AAD4EC8156CE4940342BDB87BC835C4069E1B20A9BD149405C548B8862875C4069E1B20A9BD149405C548B8862875C40AAD4EC8156CE4940342BDB87BC835C40AAD4EC8156CE4940
60105	Адриановка	5	48	1560	114.50553600000001	114.531516	51.573911000000003	51.549936000000002	0103000020E61000000100000005000000D8BCAAB35AA05C405072874D64C64940D8BCAAB35AA05C4047E867EA75C949403F53AF5B04A25C4047E867EA75C949403F53AF5B04A25C405072874D64C64940D8BCAAB35AA05C405072874D64C64940
50877	Явленка	5	48	1529	119.07594899999999	119.09617	51.040678	51.032322999999998	0103000020E610000001000000050000007DCA3159DCC45D404DF4F928238449407DCA3159DCC45D4056D5CBEF34854940CE3637A627C65D4056D5CBEF34854940CE3637A627C65D404DF4F928238449407DCA3159DCC45D404DF4F92823844940
51058	Шивия	5	48	1529	119.10867500000001	119.12817699999999	50.889485000000001	50.882159999999999	0103000020E6100000010000000500000024B9FC87F4C65D4070EB6E9EEA70494024B9FC87F4C65D402BA4FCA4DA7149405CC64D0D34C85D402BA4FCA4DA7149405CC64D0D34C85D4070EB6E9EEA70494024B9FC87F4C65D4070EB6E9EEA704940
50754	Чупрово	5	48	1529	118.984042	119.008584	50.995598000000001	50.977040000000002	0103000020E61000000100000005000000FDF84B8BFABE5D4022718FA50F7D4940FDF84B8BFABE5D4044FB58C16F7F494035D1E7A38CC05D4044FB58C16F7F494035D1E7A38CC05D4022718FA50F7D4940FDF84B8BFABE5D4022718FA50F7D4940
60212	Чингильтуй	5	48	1529	119.02798799999999	119.042154	50.801889000000003	50.789015999999997	0103000020E610000001000000050000008C2B2E8ECAC15D40A702EE79FE6449408C2B2E8ECAC15D40D6027B4CA466494051D9B0A6B2C25D40D6027B4CA466494051D9B0A6B2C25D40A702EE79FE6449408C2B2E8ECAC15D40A702EE79FE644940
50960	Средняя Борзя	5	48	1529	119.47848399999999	119.49681	50.917295000000003	50.906959000000001	0103000020E6100000010000000500000031EA5A7B9FDE5D400CE8853B1774494031EA5A7B9FDE5D4065E42CEC69754940D9942BBCCBDF5D4065E42CEC69754940D9942BBCCBDF5D400CE8853B1774494031EA5A7B9FDE5D400CE8853B17744940
60107	Нижний Калгукан	5	48	1529	118.881652	118.92888600000001	50.753276	50.735447999999998	0103000020E61000000100000005000000FE9C82FC6CB85D404DF4F928235E4940FE9C82FC6CB85D404C6E14596B60494096ED43DE72BB5D404C6E14596B60494096ED43DE72BB5D404DF4F928235E4940FE9C82FC6CB85D404DF4F928235E4940
51743	Козлово	5	48	1529	118.921331	118.94122900000001	51.210362000000003	51.202455999999998	0103000020E610000001000000050000009F724C16F7BA5D4082700514EA9949409F724C16F7BA5D401C295B24ED9A4940FF428F183DBC5D401C295B24ED9A4940FF428F183DBC5D4082700514EA9949409F724C16F7BA5D4082700514EA994940
51739	Калга	5	48	1529	118.86453899999999	118.931293	50.945219000000002	50.913178000000002	0103000020E6100000010000000500000075C7629B54B75D409EB64604E374494075C7629B54B75D406747AAEFFC784940997FF44D9ABB5D406747AAEFFC784940997FF44D9ABB5D409EB64604E374494075C7629B54B75D409EB64604E3744940
60090	Кадая	5	48	1529	119.276713	119.30713900000001	50.940497000000001	50.926749000000001	0103000020E61000000100000005000000325871AAB5D15D40E44C13B69F764940325871AAB5D15D40397EA83462784940E014562AA8D35D40397EA83462784940E014562AA8D35D40E44C13B69F764940325871AAB5D15D40E44C13B69F764940
60074	Доно	5	48	1529	118.575084	118.611358	50.906306000000001	50.878892	0103000020E61000000100000005000000FC1C1F2DCEA45D40A75B76887F704940FC1C1F2DCEA45D409415C3D50174494078094E7D20A75D409415C3D50174494078094E7D20A75D40A75B76887F704940FC1C1F2DCEA45D40A75B76887F704940
51047	Верхний Калгукан	5	48	1529	118.77411499999999	118.79601599999999	50.821944999999999	50.811917999999999	0103000020E61000000100000005000000F415A4198BB15D405184D4EDEC674940F415A4198BB15D402C0E677E35694940EFC517EDF1B25D402C0E677E35694940EFC517EDF1B25D405184D4EDEC674940F415A4198BB15D405184D4EDEC674940
60179	Бура	5	48	1529	119.438581	119.45575700000001	50.758884000000002	50.747258000000002	0103000020E6100000010000000500000068E90AB611DC5D4052D66F26A65F494068E90AB611DC5D4095BA641C23614940147B681F2BDD5D4095BA641C23614940147B681F2BDD5D4052D66F26A65F494068E90AB611DC5D4052D66F26A65F4940
31392	Чара	5	48	1907	118.240803	118.306245	56.929048999999999	56.889001999999998	0103000020E61000000100000005000000D671FC50698F5D400F0A4AD1CA714C40D671FC50698F5D40D5B0DF13EB764C4011E4A08499935D40D5B0DF13EB764C4011E4A08499935D400F0A4AD1CA714C40D671FC50698F5D400F0A4AD1CA714C40
31436	Чапо-Олого	5	48	1907	118.810667	118.835111	57.076500000000003	57.069586999999999	0103000020E61000000100000005000000923CD7F7E1B35D40069D103AE8884C40923CD7F7E1B35D406F1283C0CA894C40E961687572B55D406F1283C0CA894C40E961687572B55D40069D103AE8884C40923CD7F7E1B35D40069D103AE8884C40
31183	Удокан	5	48	1907	118.299858	118.31407	56.756408999999998	56.747732999999997	0103000020E610000001000000050000006ADC9BDF30935D40EA9106B7B55F4C406ADC9BDF30935D4035B39602D2604C40E7A90EB919945D4035B39602D2604C40E7A90EB919945D40EA9106B7B55F4C406ADC9BDF30935D40EA9106B7B55F4C40
60086	Новая Чара	5	48	1907	118.253649	118.287093	56.814084000000001	56.782483999999997	0103000020E6100000010000000500000070EA03C93B905D4056D28A6F28644C4070EA03C93B905D4033198EE733684C40467A51BB5F925D4033198EE733684C40467A51BB5F925D4056D28A6F28644C4070EA03C93B905D4056D28A6F28644C40
30995	Новая Чара	5	48	1907	118.253649	118.287093	56.814084000000001	56.782483999999997	0103000020E6100000010000000500000070EA03C93B905D4056D28A6F28644C4070EA03C93B905D4033198EE733684C40467A51BB5F925D4033198EE733684C40467A51BB5F925D4056D28A6F28644C4070EA03C93B905D4056D28A6F28644C40
31641	Кюсть-Кемда	5	48	1907	118.310917	118.32794	56.970191	56.957776000000003	0103000020E610000001000000050000004FB16A10E6935D4065726A67987A4C404FB16A10E6935D40D0EFFB372F7C4C4037C30DF8FC945D40D0EFFB372F7C4C4037C30DF8FC945D4065726A67987A4C404FB16A10E6935D4065726A67987A4C40
31287	Куанда	5	48	1907	116.065173	116.133194	56.337046999999998	56.318390999999998	0103000020E6100000010000000500000043E55FCB2B045D409D2B4A09C1284C4043E55FCB2B045D40821B295B242B4C408081204086085D40821B295B242B4C408081204086085D409D2B4A09C1284C4043E55FCB2B045D409D2B4A09C1284C40
31495	Икабья	5	48	1907	118.753939	118.782703	57.002951000000003	56.990375	0103000020E61000000100000005000000740B5D8940B05D4054E3A59BC47E4C40740B5D8940B05D40C93EC8B260804C40CADE52CE17B25D40C93EC8B260804C40CADE52CE17B25D4054E3A59BC47E4C40740B5D8940B05D4054E3A59BC47E4C40
50730	Чита	5	48	7086	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
51039	Черноозерский	5	48	1453	116.685936	116.701199	50.123725999999998	50.109718999999998	0103000020E610000001000000050000008AC91B60E62B5D40FA5FAE450B0E49408AC91B60E62B5D401BD5E940D60F49403A3FC571E02C5D401BD5E940D60F49403A3FC571E02C5D40FA5FAE450B0E49408AC91B60E62B5D40FA5FAE450B0E4940
51672	Степной	5	48	1453	117.457131	117.48081000000001	50.017457	50.006568000000001	0103000020E6100000010000000500000038BF61A2415D5D409E996038D700494038BF61A2415D5D400B0BEE073C024940BF654E97C55E5D400B0BEE073C024940BF654E97C55E5D409E996038D700494038BF61A2415D5D409E996038D7004940
51044	Рудник Абагайтуй	5	48	1453	117.88314800000001	117.89718000000001	49.710785000000001	49.696983000000003	0103000020E61000000100000005000000C861307F85785D401A6F2BBD36D94840C861307F85785D4062BEBC00FBDA484005A8A9656B795D4062BEBC00FBDA484005A8A9656B795D401A6F2BBD36D94840C861307F85785D401A6F2BBD36D94840
50761	Красный Великан	5	48	1453	117.05244	117.06567200000001	50.088558999999997	50.072181999999998	0103000020E6100000010000000500000025404D2D5B435D4010AE80423D09494025404D2D5B435D401B62BCE6550B4940D41055F833445D401B62BCE6550B4940D41055F833445D4010AE80423D09494025404D2D5B435D4010AE80423D094940
51610	Забайкальск	5	48	1453	117.296755	117.383065	49.667000000000002	49.63156	0103000020E610000001000000050000002BFBAE08FE525D401BBB44F5D6D048402BFBAE08FE525D404C37894160D5484081CF0F2384585D404C37894160D5484081CF0F2384585D401BBB44F5D6D048402BFBAE08FE525D401BBB44F5D6D04840
60042	Забайкальск	5	48	1453	117.296755	117.383065	49.667000000000002	49.63156	0103000020E610000001000000050000002BFBAE08FE525D401BBB44F5D6D048402BFBAE08FE525D404C37894160D5484081CF0F2384585D404C37894160D5484081CF0F2384585D401BBB44F5D6D048402BFBAE08FE525D401BBB44F5D6D04840
51492	Даурия	5	48	1453	116.831176	116.868267	49.943136000000003	49.909170000000003	0103000020E61000000100000005000000164ED2FC31355D408E40BCAE5FF44840164ED2FC31355D4013D731AEB8F848408C4CC0AF91375D4013D731AEB8F848408C4CC0AF91375D408E40BCAE5FF44840164ED2FC31355D408E40BCAE5FF44840
60110	Билитуй	5	48	1453	117.085354	117.115475	49.835349000000001	49.815154999999997	0103000020E610000001000000050000004CA59F7076455D40DF15C1FF56E848404CA59F7076455D4087DF4DB7ECEA48405C2041F163475D4087DF4DB7ECEA48405C2041F163475D40DF15C1FF56E848404CA59F7076455D40DF15C1FF56E84840
60076	Абагайтуй	5	48	1453	117.825952	117.845392	49.590629	49.571266000000001	0103000020E610000001000000050000003604C765DC745D408BA8893E1FC948403604C765DC745D40DB8827BB99CB484034130CE71A765D40DB8827BB99CB484034130CE71A765D408BA8893E1FC948403604C765DC745D408BA8893E1FC94840
4733	Чиндалей	5	48	631	113.847296	113.90658500000001	50.587197000000003	50.562466999999998	0103000020E61000000100000005000000068200193A765C40240A2DEBFE474940068200193A765C4098A77345294B4940D482177D057A5C4098A77345294B4940D482177D057A5C40240A2DEBFE474940068200193A765C40240A2DEBFE474940
4778	Узон	5	48	631	113.596046	113.611749	50.586837000000003	50.570168000000002	0103000020E61000000100000005000000583A1F9E25665C40E59CD843FB484940583A1F9E25665C40988A8D791D4B4940161747E526675C40988A8D791D4B4940161747E526675C40E59CD843FB484940583A1F9E25665C40E59CD843FB484940
4668	Токчин	5	48	631	114.10893	114.147243	50.520203000000002	50.506450000000001	0103000020E6100000010000000500000069E388B5F8865C409487855AD340494069E388B5F8865C40FB230C03964249402864E76D6C895C40FB230C03964249402864E76D6C895C409487855AD340494069E388B5F8865C409487855AD3404940
4554	Таптанай	5	48	631	113.80203899999999	113.81855	50.790922999999999	50.766266999999999	0103000020E6100000010000000500000075C7629B54735C4084807C091562494075C7629B54735C40BD5301F73C65494003098A1F63745C40BD5301F73C65494003098A1F63745C4084807C091562494075C7629B54735C4084807C0915624940
4455	Красноярово	5	48	631	113.520444	113.536039	50.960647000000002	50.955188999999997	0103000020E6100000010000000500000090D959F44E615C40DD3F16A2437A494090D959F44E615C4011001C7BF67A49405B9885764E625C4011001C7BF67A49405B9885764E625C40DD3F16A2437A494090D959F44E615C40DD3F16A2437A4940
4501	Иля	5	48	631	113.58479	113.597825	50.845326	50.830207000000001	0103000020E61000000100000005000000C84109336D655C4084F41439446A4940C84109336D655C40B03A72A4336C4940CCEEC9C342665C40B03A72A4336C4940CCEEC9C342665C4084F41439446A4940C84109336D655C4084F41439446A4940
4610	Зуткулей	5	48	631	114.169584	114.20383699999999	50.675916000000001	50.651428000000003	0103000020E61000000100000005000000317BD976DA8A5C406FD921FE61534940317BD976DA8A5C40EC6B5D6A84564940BE2D58AA0B8D5C40EC6B5D6A84564940BE2D58AA0B8D5C406FD921FE61534940317BD976DA8A5C406FD921FE61534940
4095	Дульдурга	5	48	631	113.573031	113.62101	50.692819999999998	50.659719000000003	0103000020E610000001000000050000000726378AAC645C4061C614AC715449400726378AAC645C40E2016553AE5849404B1FBAA0BE675C40E2016553AE5849404B1FBAA0BE675C4061C614AC715449400726378AAC645C4061C614AC71544940
51046	Бальзино	5	48	631	113.579948	113.611847	51.053232000000001	51.038418	0103000020E610000001000000050000005C5837DE1D655C40F3C98AE1EA8449405C5837DE1D655C40E38C614ED0864940F7C9518028675C40E38C614ED0864940F7C9518028675C40F3C98AE1EA8449405C5837DE1D655C40F3C98AE1EA844940
4337	Ара-Иля	5	48	631	113.26484600000001	113.29493100000001	50.945787000000003	50.927298999999998	0103000020E610000001000000050000007E1EA33CF3505C40874ECFBBB17649407E1EA33CF3505C40B1FD648C0F794940E7E44526E0525C40B1FD648C0F794940E7E44526E0525C40874ECFBBB17649407E1EA33CF3505C40874ECFBBB1764940
4273	Алханай	5	48	631	113.463365	113.485293	50.742801	50.717584000000002	0103000020E610000001000000050000001B47ACC5A75D5C400211E2CAD95B49401B47ACC5A75D5C40D237691A145F494093FE5E0A0F5F5C40D237691A145F494093FE5E0A0F5F5C400211E2CAD95B49401B47ACC5A75D5C400211E2CAD95B4940
16699	Широкая	5	48	1437	118.667224	118.70167499999999	51.603630000000003	51.590862999999999	0103000020E61000000100000005000000CEC64ACCB3AA5D404EB51666A1CB4940CEC64ACCB3AA5D40377172BF43CD4940EE5A423EE8AC5D40377172BF43CD4940EE5A423EE8AC5D404EB51666A1CB4940CEC64ACCB3AA5D404EB51666A1CB4940
16899	Ушмун	5	48	1437	118.349113	118.370816	51.689883999999999	51.669490000000003	0103000020E61000000100000005000000F1660DDE57965D40E17F2BD9B1D54940F1660DDE57965D404F04711E4ED8494059350873BB975D404F04711E4ED8494059350873BB975D40E17F2BD9B1D54940F1660DDE57965D40E17F2BD9B1D54940
16184	Трубачево	5	48	1437	118.188351	118.21397	51.420254	51.390537999999999	0103000020E61000000100000005000000CF4A5AF10D8C5D4031EC3026FDB14940CF4A5AF10D8C5D40B00111E2CAB54940CF143AAFB18D5D40B00111E2CAB54940CF143AAFB18D5D4031EC3026FDB14940CF4A5AF10D8C5D4031EC3026FDB14940
16631	Тайна	5	48	1437	118.434758	118.477734	51.599176999999997	51.58079	0103000020E6100000010000000500000029EB3713D39B5D4003ECA35357CA494029EB3713D39B5D40F8C1F9D4B1CC4940FC8BA031939E5D40F8C1F9D4B1CC4940FC8BA031939E5D4003ECA35357CA494029EB3713D39B5D4003ECA35357CA4940
16790	Солонечный	5	48	1437	118.896349	118.90773900000001	51.537131000000002	51.513730000000002	0103000020E61000000100000005000000593332C85DB95D40AF7C96E7C1C14940593332C85DB95D407A5567B5C0C449407193516518BA5D407A5567B5C0C449407193516518BA5D40AF7C96E7C1C14940593332C85DB95D40AF7C96E7C1C14940
51694	Новоширокинский	5	48	1437	118.642386	118.653902	51.579827000000002	51.570977999999997	0103000020E61000000100000005000000215A2BDA1CA95D40245E9ECE15C94940215A2BDA1CA95D403D2B69C537CA49407F32C687D9A95D403D2B69C537CA49407F32C687D9A95D40245E9ECE15C94940215A2BDA1CA95D40245E9ECE15C94940
17033	Луговское	5	48	1437	118.813659	118.82385499999999	52.062370000000001	52.047317999999997	0103000020E6100000010000000500000026C632FD12B45D408D4127840E064A4026C632FD12B45D4032207BBDFB074A405969520ABAB45D4032207BBDFB074A405969520ABAB45D408D4127840E064A4026C632FD12B45D408D4127840E064A40
16941	Кунгара	5	48	1437	118.43314100000001	118.448251	51.805526	51.796253	0103000020E61000000100000005000000A2630795B89B5D40C32B499EEBE54940A2630795B89B5D40F209D9791BE749408E59F624B09C5D40F209D9791BE749408E59F624B09C5D40C32B499EEBE54940A2630795B89B5D40C32B499EEBE54940
16289	Корабль	5	48	1437	118.28412	118.294792	51.530687999999998	51.523772999999998	0103000020E61000000100000005000000EE08A7052F925D408FC360FE0AC34940EE08A7052F925D4098309A95EDC34940D6C743DFDD925D4098309A95EDC34940D6C743DFDD925D408FC360FE0AC34940EE08A7052F925D408FC360FE0AC34940
16852	Калдага	5	48	1437	118.35932699999999	118.37229000000001	51.637113999999997	51.62538	0103000020E610000001000000050000007764AC36FF965D4047C9AB730CD049407764AC36FF965D4070E998F38CD149402FA86F99D3975D4070E998F38CD149402FA86F99D3975D4047C9AB730CD049407764AC36FF965D4047C9AB730CD04940
16349	Игдоча	5	48	1437	118.304143	118.32025	51.570909999999998	51.559674000000001	0103000020E61000000100000005000000AB93331477935D40F435CB65A3C74940AB93331477935D40CC7A319413C94940D122DBF97E945D40CC7A319413C94940D122DBF97E945D40F435CB65A3C74940AB93331477935D40F435CB65A3C74940
17171	Зерен	5	48	1437	119.530326	119.560267	52.039828999999997	52.028742999999999	0103000020E61000000100000005000000FC8D76DCF0E15D40957EC2D9AD034A40FC8D76DCF0E15D405837DE1D19054A40CB811E6ADBE35D405837DE1D19054A40CB811E6ADBE35D40957EC2D9AD034A40FC8D76DCF0E15D40957EC2D9AD034A40
17154	Закаменная	5	48	1437	118.909868	118.92761900000001	52.082375999999996	52.075645999999999	0103000020E6100000010000000500000053EBFD463BBA5D405F09A4C4AE094A4053EBFD463BBA5D40D6FCF84B8B0A4A407D09151C5EBB5D40D6FCF84B8B0A4A407D09151C5EBB5D405F09A4C4AE094A4053EBFD463BBA5D405F09A4C4AE094A40
16221	Догье	5	48	1437	118.21565	118.230329	51.498583000000004	51.491658000000001	0103000020E610000001000000050000007958A835CD8D5D408C683BA6EEBE49407958A835CD8D5D40B9AB5791D1BF49408194D8B5BD8E5D40B9AB5791D1BF49408194D8B5BD8E5D408C683BA6EEBE49407958A835CD8D5D408C683BA6EEBE4940
16441	Газимурский Завод	5	48	1437	118.316378	118.366675	51.562882000000002	51.530889999999999	0103000020E6100000010000000500000021CB82893F945D4000E31934F4C3494021CB82893F945D40E8C072840CC84940B1506B9A77975D40E8C072840CC84940B1506B9A77975D4000E31934F4C3494021CB82893F945D4000E31934F4C34940
16125	Газимурские Кавыкучи	5	48	1437	118.171121	118.188036	51.363242999999997	51.355460000000001	0103000020E610000001000000050000002AAA7EA5F38A5D40A18499B67FAD49402AAA7EA5F38A5D401EC022BF7EAE49401F9E25C8088C5D401EC022BF7EAE49401F9E25C8088C5D40A18499B67FAD49402AAA7EA5F38A5D40A18499B67FAD4940
16989	Бурукан	5	48	1437	118.517709	118.536636	51.848151999999999	51.834235999999997	0103000020E6100000010000000500000012F6ED2422A15D40AB92C83EC8EA494012F6ED2422A15D40BC04A73E90EC4940CD76853E58A25D40BC04A73E90EC4940CD76853E58A25D40AB92C83EC8EA494012F6ED2422A15D40AB92C83EC8EA4940
17085	Батакан	5	48	1437	118.833889	118.87932600000001	52.07967	52.066623	0103000020E61000000100000005000000A0DFF76F5EB55D40A9143B1A87084A40A0DFF76F5EB55D40753C66A0320A4A4071218FE046B85D40753C66A0320A4A4071218FE046B85D40A9143B1A87084A40A0DFF76F5EB55D40A9143B1A87084A40
60170	Южное	5	48	1136	116.554495	116.58049200000001	50.253926	50.243372999999998	0103000020E61000000100000005000000EAB298D87C235D405DDDB1D8261F4940EAB298D87C235D4053CDACA580204940BDE5EAC726255D4053CDACA580204940BDE5EAC726255D405DDDB1D8261F4940EAB298D87C235D405DDDB1D8261F4940
60208	Шоноктуй	5	48	1136	117.26496299999999	117.292901	50.779806999999998	50.765498000000001	0103000020E610000001000000050000009AE95E27F5505D40A393A5D6FB6149409AE95E27F5505D408F183DB7D0634940CEFDD5E3BE525D408F183DB7D0634940CEFDD5E3BE525D40A393A5D6FB6149409AE95E27F5505D40A393A5D6FB614940
59121	Шерловая Гора	5	48	1136	116.244702	116.409192	50.556550000000001	50.508082999999999	0103000020E6100000010000000500000003D19332A90F5D40A8531EDD0841494003D19332A90F5D405E4BC8073D4749403B72A433301A5D405E4BC8073D4749403B72A433301A5D40A8531EDD0841494003D19332A90F5D40A8531EDD08414940
51516	Шерловая Гора	5	48	1136	116.244702	116.409192	50.556550000000001	50.508082999999999	0103000020E6100000010000000500000003D19332A90F5D40A8531EDD0841494003D19332A90F5D405E4BC8073D4749403B72A433301A5D405E4BC8073D4749403B72A433301A5D40A8531EDD0841494003D19332A90F5D40A8531EDD08414940
60079	Чиндант 2-й	5	48	1136	116.369523	116.39078600000001	50.377692000000003	50.369781000000003	0103000020E61000000100000005000000AB07CC43A6175D4052D7DAFB542F4940AB07CC43A6175D40FDFA213658304940056F48A302195D40FDFA213658304940056F48A302195D4052D7DAFB542F4940AB07CC43A6175D4052D7DAFB542F4940
51515	Цаган-Олуй	5	48	1136	117.14442699999999	117.177036	50.483719000000001	50.457203	0103000020E61000000100000005000000336ABE4A3E495D400951BEA0853A4940336ABE4A3E495D4017BA1281EA3D4940BD8DCD8E544B5D4017BA1281EA3D4940BD8DCD8E544B5D400951BEA0853A4940336ABE4A3E495D400951BEA0853A4940
60064	Хада-Булак	5	48	1136	116.542062	116.57086200000001	50.616497000000003	50.601412000000003	0103000020E61000000100000005000000E199D024B1225D4003B68311FB4C4940E199D024B1225D40838AAA5FE94E4940DE21C50089245D40838AAA5FE94E4940DE21C50089245D4003B68311FB4C4940E199D024B1225D4003B68311FB4C4940
60206	Усть-Озёрная	5	48	1136	117.080934	117.103886	50.707738999999997	50.696123999999998	0103000020E610000001000000050000009BC8CC052E455D40F8FA5A971A5949409BC8CC052E455D40478D0931975A4940C9207711A6465D40478D0931975A4940C9207711A6465D40F8FA5A971A5949409BC8CC052E455D40F8FA5A971A594940
60062	Соловьёвск	5	48	1136	115.69353099999999	115.767921	49.901308999999998	49.886324999999999	0103000020E61000000100000005000000C7F0D8CF62EC5C404850FC1873F14840C7F0D8CF62EC5C40944BE3175EF34840583A1F9E25F15C40944BE3175EF34840583A1F9E25F15C404850FC1873F14840C7F0D8CF62EC5C404850FC1873F14840
51759	Приозерное	5	48	1136	116.267402	116.28494600000001	50.490572999999998	50.481161999999998	0103000020E61000000100000005000000A438471D1D115D40FA0967B7963D4940A438471D1D115D407AA69718CB3E494011C8258E3C125D407AA69718CB3E494011C8258E3C125D40FA0967B7963D4940A438471D1D115D40FA0967B7963D4940
60091	Передняя Бырка	5	48	1136	116.763245	116.805736	50.743763999999999	50.718964	0103000020E6100000010000000500000079758E01D9305D402C802903075C494079758E01D9305D4098F8A3A8335F49406E4DBA2D91335D4098F8A3A8335F49406E4DBA2D91335D402C802903075C494079758E01D9305D402C802903075C4940
10707	Олдонда	5	48	1136	116.92779	116.96005700000001	50.890234999999997	50.878568000000001	0103000020E6100000010000000500000093E34EE9603B5D40F4A78DEA7470494093E34EE9603B5D4095607138F3714940F052EA92713D5D4095607138F3714940F052EA92713D5D40F4A78DEA7470494093E34EE9603B5D40F4A78DEA74704940
51050	Новоборзинское	5	48	1136	116.56955000000001	116.580591	50.301820999999997	50.291504000000003	0103000020E61000000100000005000000F5DBD78173245D409C53C90050254940F5DBD78173245D407D1F0E12A22649408656276728255D407D1F0E12A22649408656276728255D409C53C90050254940F5DBD78173245D409C53C90050254940
51685	Курунзулай	5	48	1136	117.11443300000001	117.135705	50.950786000000001	50.929904999999998	0103000020E610000001000000050000005325CADE52475D4085B18520077749405325CADE52475D4051BF0B5BB3794940D6390664AF485D4051BF0B5BB3794940D6390664AF485D4085B18520077749405325CADE52475D4085B1852007774940
50772	Кондуй	5	48	1136	117.463123	117.47841200000001	50.563949000000001	50.541051000000003	0103000020E61000000100000005000000A0C1A6CEA35D5D40EB3BBF2841454940A0C1A6CEA35D5D4053CE177B2F484940E5805D4D9E5E5D4053CE177B2F484940E5805D4D9E5E5D40EB3BBF2841454940A0C1A6CEA35D5D40EB3BBF2841454940
50701	Ключевское	5	48	1136	116.843474	116.863156	50.386848000000001	50.368550999999997	0103000020E61000000100000005000000AF415F7AFB355D403CF4DDAD2C2F4940AF415F7AFB355D40F2423A3C8431494028D6A9F23D375D40F2423A3C8431494028D6A9F23D375D403CF4DDAD2C2F4940AF415F7AFB355D403CF4DDAD2C2F4940
50776	Борзя	5	48	1136	116.481938	116.563253	50.424750000000003	50.360472000000001	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
60124	Биликтуй	5	48	1136	116.909132	116.926334	50.727808000000003	50.712690000000002	0103000020E61000000100000005000000D0EFFB372F3A5D40D717096D395B4940D0EFFB372F3A5D4033E202D0285D494010CB660E493B5D4033E202D0285D494010CB660E493B5D40D717096D395B4940D0EFFB372F3A5D40D717096D395B4940
60196	Акурай	5	48	1136	117.150554	117.17309299999999	50.771816000000001	50.752729000000002	0103000020E610000001000000050000000C923EADA2495D401AE0826C596049400C923EADA2495D40C843DFDDCA624940A88AA9F4134B5D40C843DFDDCA624940A88AA9F4134B5D401AE0826C596049400C923EADA2495D401AE0826C59604940
51060	Ундино-Поселье	5	48	1099	116.214967	116.27139099999999	51.439509000000001	51.400433999999997	0103000020E6100000010000000500000008AEF204C20D5D406D1ADB6B41B3494008AEF204C20D5D401AA6B6D441B84940705B5B785E115D401AA6B6D441B84940705B5B785E115D406D1ADB6B41B3494008AEF204C20D5D406D1ADB6B41B34940
60087	Унда	5	48	1099	116.89006000000001	116.937545	51.718729000000003	51.702784999999999	0103000020E6100000010000000500000094DE37BEF6385D40478FDFDBF4D9494094DE37BEF6385D40E9D7D64FFFDB4940D061BEBC003C5D40E9D7D64FFFDB4940D061BEBC003C5D40478FDFDBF4D9494094DE37BEF6385D40478FDFDBF4D94940
51051	Подойницыно	5	48	1099	116.77966600000001	116.803121	51.659658	51.646749999999997	0103000020E6100000010000000500000067F3380CE6315D40105839B4C8D2494067F3380CE6315D40BB4560AC6FD44940C66E9F5566335D40BB4560AC6FD44940C66E9F5566335D40105839B4C8D2494067F3380CE6315D40105839B4C8D24940
50880	Нижний Кокуй	5	48	1099	116.61239999999999	116.625246	51.547834999999999	51.536687999999998	0103000020E610000001000000050000008104C58F31275D40EC134031B2C449408104C58F31275D40554D10751FC649401C7DCC0704285D40554D10751FC649401C7DCC0704285D40EC134031B2C449408104C58F31275D40EC134031B2C44940
60158	Нижний Ильдикан	5	48	1099	117.14661	117.163157	51.621358999999998	51.600127999999998	0103000020E610000001000000050000000FD1E80E62495D40FAB48AFED0CC49400FD1E80E62495D40A20914B188CF494043C70E2A714A5D40A20914B188CF494043C70E2A714A5D40FAB48AFED0CC49400FD1E80E62495D40FAB48AFED0CC4940
51520	Нижнее Гирюнино	5	48	1099	116.972678	116.985417	51.202981000000001	51.187758000000002	0103000020E610000001000000050000007AE2395B403E5D40FCC74274089849407AE2395B403E5D40CD5A0A48FB99494009FB7612113F5D40CD5A0A48FB99494009FB7612113F5D40FCC74274089849407AE2395B403E5D40FCC7427408984940
50995	Матусово	5	48	1099	116.331371	116.362067	51.477697999999997	51.466174000000002	0103000020E61000000100000005000000F1F5B52E35155D406D1FF296ABBB4940F1F5B52E35155D40ABAE433525BD49407EFD101B2C175D40ABAE433525BD49407EFD101B2C175D406D1FF296ABBB4940F1F5B52E35155D406D1FF296ABBB4940
51432	Казаковский Промысел	5	48	1099	117.013228	117.034132	51.782392999999999	51.762686000000002	0103000020E610000001000000050000000ED940BAD8405D40FC8EE1B19FE149400ED940BAD8405D4046CF2D7425E44940D0EFFB372F425D4046CF2D7425E44940D0EFFB372F425D40FC8EE1B19FE149400ED940BAD8405D40FC8EE1B19FE14940
60172	Жидка	5	48	1099	117.21219600000001	117.230109	51.777835000000003	51.761682999999998	0103000020E61000000100000005000000E415889E944D5D40A7751BD47EE14940E415889E944D5D409357E71890E34940FA60191BBA4E5D409357E71890E34940FA60191BBA4E5D40A7751BD47EE14940E415889E944D5D40A7751BD47EE14940
50945	Балей	5	48	1099	116.58400399999999	116.722525	51.600928000000003	51.538722	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
49682	Шаранча	5	48	1302	117.35045599999999	117.38355900000001	50.937347000000003	50.926924999999997	0103000020E61000000100000005000000F7AB00DF6D565D40226C787AA5764940F7AB00DF6D565D407A008BFCFA77494089450C3B8C585D407A008BFCFA77494089450C3B8C585D40226C787AA5764940F7AB00DF6D565D40226C787AA5764940
51433	Чиндагатай	5	48	1302	118.223735	118.252347	50.773605000000003	50.754700999999997	0103000020E610000001000000050000001EFE9AAC518E5D4016A1D80A9A6049401EFE9AAC518E5D40D482177D05634940990F087426905D40D482177D05634940990F087426905D4016A1D80A9A6049401EFE9AAC518E5D4016A1D80A9A604940
51579	Савво-Борзя	5	48	1302	118.335162	118.357755	50.713295000000002	50.693294000000002	0103000020E610000001000000050000002A37514B73955D40AB4198DBBD5849402A37514B73955D403EB324404D5B4940C03E3A75E5965D403EB324404D5B4940C03E3A75E5965D40AB4198DBBD5849402A37514B73955D40AB4198DBBD584940
50980	Онон-Борзя	5	48	1302	117.313652	117.336343	51.071385999999997	51.058508000000003	0103000020E61000000100000005000000CD94D6DF12545D40F646AD307D874940CD94D6DF12545D4035B22B2D23894940444FCAA486555D4035B22B2D23894940444FCAA486555D40F646AD307D874940CD94D6DF12545D40F646AD307D874940
60071	Новый Акатуй	5	48	1302	117.76310599999999	117.78525	51.066597000000002	51.042789999999997	0103000020E6100000010000000500000068588CBAD6705D40444C89247A85494068588CBAD6705D408081204086884940C74B378941725D408081204086884940C74B378941725D40444C89247A85494068588CBAD6705D40444C89247A854940
60135	Николаевка	5	48	1302	117.637953	117.66987899999999	51.020392999999999	51.008510000000001	0103000020E61000000100000005000000A5D8D138D4685D4030D80DDB16814940A5D8D138D4685D409E08E23C9C824940BD512B4CDF6A5D409E08E23C9C824940BD512B4CDF6A5D4030D80DDB16814940A5D8D138D4685D4030D80DDB16814940
60130	Маньково	5	48	1302	117.70251500000001	117.72577200000001	50.865380999999999	50.845354999999998	0103000020E61000000100000005000000C47C7901F66C5D404A41B797346C4940C47C7901F66C5D4036CAFACDC46E49409016670C736E5D4036CAFACDC46E49409016670C736E5D404A41B797346C4940C47C7901F66C5D404A41B797346C4940
60125	Манкечур	5	48	1302	117.89929100000001	117.925692	50.661214999999999	50.648287000000003	0103000020E6100000010000000500000094A5D6FB8D795D4003B68311FB52494094A5D6FB8D795D40F44F70B1A2544940CE8AA8893E7B5D40F44F70B1A2544940CE8AA8893E7B5D4003B68311FB52494094A5D6FB8D795D4003B68311FB524940
49681	Кутугай	5	48	1302	117.357418	117.382122	50.859025000000003	50.846020000000003	0103000020E610000001000000050000001C40BFEFDF565D4087E123624A6C49401C40BFEFDF565D4024B9FC87F46D49404145D5AF74585D4024B9FC87F46D49404145D5AF74585D4087E123624A6C49401C40BFEFDF565D4087E123624A6C4940
51738	Кузнецово	5	48	1302	118.304323	118.331497	51.118178	51.084225000000004	0103000020E61000000100000005000000EB1A2D077A935D40B84082E2C78A4940EB1A2D077A935D40A88DEA74208F4940376E313F37955D40A88DEA74208F4940376E313F37955D40B84082E2C78A4940EB1A2D077A935D40B84082E2C78A4940
50677	Кокуй 2-й	5	48	1302	117.988421	118.011095	51.060665	51.046017999999997	0103000020E610000001000000050000007F6B274A427F5D407F83F6EAE38549407F6B274A427F5D408481E7DEC38749408B89CDC7B5805D408481E7DEC38749408B89CDC7B5805D407F83F6EAE38549407F6B274A427F5D407F83F6EAE3854940
60171	Кокуй 1-й	5	48	1302	118.34128	118.365202	51.185600999999998	51.172485000000002	0103000020E61000000100000005000000D9B11188D7955D4079060DFD13964940D9B11188D7955D406D8D08C6C1974940C39B35785F975D406D8D08C6C1974940C39B35785F975D4079060DFD13964940D9B11188D7955D4079060DFD13964940
51813	Клин	5	48	1302	117.453412	117.47483699999999	50.999094999999997	50.986719999999998	0103000020E610000001000000050000004BE7C3B3045D5D40912749D74C7E49404BE7C3B3045D5D406E4C4F58E27F4940917BBABA635E5D406E4C4F58E27F4940917BBABA635E5D40912749D74C7E49404BE7C3B3045D5D40912749D74C7E4940
51562	Бутунтай	5	48	1302	118.110224	118.128226	50.662512	50.650450999999997	0103000020E61000000100000005000000FFCEF6E80D875D40435376FA41534940FFCEF6E80D875D40919A7631CD544940CD1FD3DA34885D40919A7631CD544940CD1FD3DA34885D40435376FA41534940FFCEF6E80D875D40435376FA41534940
51727	Бохто	5	48	1302	118.143174	118.192168	51.069178000000001	51.057398999999997	0103000020E61000000100000005000000CDE847C329895D405BE9B5D958874940CDE847C329895D4025CD1FD3DA8849409DD5027B4C8C5D4025CD1FD3DA8849409DD5027B4C8C5D405BE9B5D958874940CDE847C329895D405BE9B5D958874940
51712	Александровский Завод	5	48	1302	117.90734	117.95828299999999	50.933062	50.909849999999999	0103000020E610000001000000050000009296CADB117A5D40FF21FDF6757449409296CADB117A5D40F7915B936E77494004543882547D5D40F7915B936E77494004543882547D5D40FF21FDF6757449409296CADB117A5D40FF21FDF675744940
60164	Усть-Иля	5	48	1888	113.702658	113.732204	50.403982999999997	50.39649	0103000020E6100000010000000500000075914259F86C5C4074982F2FC032494075914259F86C5C40EA9106B7B533494006802A6EDC6E5C40EA9106B7B533494006802A6EDC6E5C4074982F2FC032494075914259F86C5C4074982F2FC0324940
60104	Урейск	5	48	1888	113.194059	113.24054700000001	50.304704000000001	50.293080000000003	0103000020E61000000100000005000000A59F70766B4C5C404C8E3BA583254940A59F70766B4C5C40EE7A698A00274940A9893E1F654F5C40EE7A698A00274940A9893E1F654F5C404C8E3BA583254940A59F70766B4C5C404C8E3BA583254940
51839	Улача	5	48	1888	113.259304	113.28646000000001	50.410625000000003	50.396540999999999	0103000020E6100000010000000500000035EECD6F98505C40F64201DBC132494035EECD6F98505C40C3F5285C8F3449402EE7525C55525C40C3F5285C8F3449402EE7525C55525C40F64201DBC132494035EECD6F98505C40F64201DBC1324940
51021	Убур-Тохтор	5	48	1888	113.617929	113.637422	50.112070000000003	50.101041000000002	0103000020E61000000100000005000000009013268C675C400F4757E9EE0C4940009013268C675C406E6E4C4F580E49400FF0A485CB685C406E6E4C4F580E49400FF0A485CB685C400F4757E9EE0C4940009013268C675C400F4757E9EE0C4940
60116	Тохтор	5	48	1888	113.339254	113.369958	50.085419999999999	50.071685000000002	0103000020E6100000010000000500000061C26856B6555C40904E5DF92C09494061C26856B6555C405036E50AEF0A494030B95164AD575C405036E50AEF0A494030B95164AD575C40904E5DF92C09494061C26856B6555C40904E5DF92C094940
30695	Такеча	5	48	1888	113.289011	113.300231	50.471595000000001	50.461990999999998	0103000020E61000000100000005000000CB4BFE277F525C40EE056685223B4940CB4BFE277F525C4083FA96395D3C4940B48F15FC36535C4083FA96395D3C4940B48F15FC36535C40EE056685223B4940CB4BFE277F525C40EE056685223B4940
60182	Орой	5	48	1888	113.72619400000001	113.748733	50.172848999999999	50.163277000000001	0103000020E610000001000000050000004B2366F6796E5C403198BF42E61449404B2366F6796E5C40BA1281EA1F164940E71BD13DEB6F5C40BA1281EA1F164940E71BD13DEB6F5C403198BF42E61449404B2366F6796E5C403198BF42E6144940
51018	Новокургатай	5	48	1888	113.434538	113.480487	50.320177999999999	50.305163999999998	0103000020E61000000100000005000000A2B77878CF5B5C4051F52B9D0F274940A2B77878CF5B5C400873BB97FB284940CDC98B4CC05E5C400873BB97FB284940CDC98B4CC05E5C4051F52B9D0F274940A2B77878CF5B5C4051F52B9D0F274940
30530	Новоказачинск	5	48	1888	113.533469	113.548265	50.409970000000001	50.407364000000001	0103000020E61000000100000005000000821B295B24625C40ACC8E88024344940821B295B24625C40AA2B9FE579344940A72215C616635C40AA2B9FE579344940A72215C616635C40ACC8E88024344940821B295B24625C40ACC8E88024344940
60089	Нарасун	5	48	1888	112.967827	112.991893	50.100088	50.077432000000002	0103000020E61000000100000005000000E44BA8E0F03D5C40FAD4B14AE9094940E44BA8E0F03D5C406C5CFFAECF0C49406808C72C7B3F5C406C5CFFAECF0C49406808C72C7B3F5C40FAD4B14AE9094940E44BA8E0F03D5C40FAD4B14AE9094940
51830	Могойтуй	5	48	1888	113.818011	113.844933	50.364167000000002	50.339889999999997	0103000020E610000001000000050000002B31CF4A5A745C40641EF983812B49402B31CF4A5A745C4027A435069D2E4940EA93DC6113765C4027A435069D2E4940EA93DC6113765C40641EF983812B49402B31CF4A5A745C40641EF983812B4940
51644	Курулга	5	48	1888	112.754396	112.76955100000001	50.124516999999997	50.111699999999999	0103000020E61000000100000005000000ED0E290648305C404A7B832F4C0E4940ED0E290648305C40E4654D2CF00F4940AA66D65240315C40E4654D2CF00F4940AA66D65240315C404A7B832F4C0E4940ED0E290648305C404A7B832F4C0E4940
30347	Дорожное	5	48	1888	113.16848400000001	113.184842	50.317445999999997	50.312286	0103000020E610000001000000050000008E791D71C84A5C40D47FD6FCF82749408E791D71C84A5C407D1F0E12A2284940583B8A73D44B5C407D1F0E12A2284940583B8A73D44B5C40D47FD6FCF82749408E791D71C84A5C40D47FD6FCF8274940
51013	Бытэв	5	48	1888	113.111926	113.145173	50.156703	50.147571999999997	0103000020E610000001000000050000009D64ABCB29475C4014E7A8A3E31249409D64ABCB29475C40B1170AD80E144940C8D0B1834A495C40B1170AD80E144940C8D0B1834A495C4014E7A8A3E31249409D64ABCB29475C4014E7A8A3E3124940
51637	Акша	5	48	1888	113.266149	113.30718400000001	50.297297999999998	50.257657999999999	0103000020E610000001000000050000003DB7D09508515C40C1C6F5EFFA2049403DB7D09508515C40469561DC0D264940B07614E7A8535C40469561DC0D264940B07614E7A8535C40C1C6F5EFFA2049403DB7D09508515C40C1C6F5EFFA204940
60157	Южный Аргалей	5	48	187	114.244091	114.270214	51.150213000000001	51.135278	0103000020E61000000100000005000000DE8FDB2F9F8F5C4024EF1CCA50914940DE8FDB2F9F8F5C408F37F92D3A934940F73AA92F4B915C408F37F92D3A934940F73AA92F4B915C4024EF1CCA50914940DE8FDB2F9F8F5C4024EF1CCA50914940
51019	Челутай	5	48	187	114.351457	114.381156	51.231476999999998	51.204526999999999	0103000020E61000000100000005000000D13C80457E965C401213D4F02D9A4940D13C80457E965C405A63D009A19D494026AB22DC64985C405A63D009A19D494026AB22DC64985C401213D4F02D9A4940D13C80457E965C401213D4F02D9A4940
60033	Цокто-Хангил	5	48	187	114.607208	114.64161300000001	50.913654999999999	50.896422000000001	0103000020E61000000100000005000000A777F17EDCA65C401CB5C2F4BD724940A777F17EDCA65C40D769A4A5F274494010ECF82F10A95C40D769A4A5F274494010ECF82F10A95C401CB5C2F4BD724940A777F17EDCA65C401CB5C2F4BD724940
60102	Хойто-Ага	5	48	187	114.07256599999999	114.096462	51.102158000000003	51.085436000000001	0103000020E610000001000000050000004C33DDEBA4845C4056F31C91EF8A49404C33DDEBA4845C402C836A83138D4940A2D3F36E2C865C402C836A83138D4940A2D3F36E2C865C4056F31C91EF8A49404C33DDEBA4845C4056F31C91EF8A4940
50706	Урда-Ага	5	48	187	114.267123	114.297774	51.014676000000001	50.991885000000003	0103000020E610000001000000050000009A40118B18915C404D327216F67E49409A40118B18915C409F0436E7E081494058E6ADBA0E935C409F0436E7E081494058E6ADBA0E935C404D327216F67E49409A40118B18915C404D327216F67E4940
60099	Судунтуй	5	48	187	114.44928400000001	114.47909900000001	50.767122000000001	50.744084000000001	0103000020E610000001000000050000006EA7AD11C19C5C400ABDFE243E5F49406EA7AD11C19C5C406405BF0D31624940F722DA8EA99E5C406405BF0D31624940F722DA8EA99E5C400ABDFE243E5F49406EA7AD11C19C5C400ABDFE243E5F4940
60111	Сахюрта (Дунда-Ага)	5	48	187	114.209991	114.23271800000001	51.038570999999997	51.017462999999999	0103000020E61000000100000005000000145D177E708D5C40EDF1423A3C824940145D177E708D5C4079C9FFE4EF84494032CC09DAE48E5C4079C9FFE4EF84494032CC09DAE48E5C40EDF1423A3C824940145D177E708D5C40EDF1423A3C824940
51636	Орловский	5	48	187	114.833017	114.871753	51.048470000000002	51.026704000000002	0103000020E61000000100000005000000C500892650B55C40115663096B834940C500892650B55C40276BD44334864940274C18CDCAB75C40276BD44334864940274C18CDCAB75C40115663096B834940C500892650B55C40115663096B834940
60127	Орловский	5	48	187	114.833017	114.871753	51.048470000000002	51.026704000000002	0103000020E61000000100000005000000C500892650B55C40115663096B834940C500892650B55C40276BD44334864940274C18CDCAB75C40276BD44334864940274C18CDCAB75C40115663096B834940C500892650B55C40115663096B834940
51846	Новоорловск	5	48	187	114.720108	114.74017600000001	51.065063000000002	51.057138000000002	0103000020E61000000100000005000000A165DD3F16AE5C40EFAD484C50874940A165DD3F16AE5C40FF9600FC538849402F52280B5FAF5C40FF9600FC538849402F52280B5FAF5C40EFAD484C50874940A165DD3F16AE5C40EFAD484C50874940
60108	Кункур	5	48	187	115.154506	115.177216	50.589021000000002	50.575020000000002	0103000020E610000001000000050000004A42226DE3C95C40E1455F419A4949404A42226DE3C95C4020D4450A654B4940FD14C78157CB5C4020D4450A654B4940FD14C78157CB5C40E1455F419A4949404A42226DE3C95C40E1455F419A494940
60112	Гунэй	5	48	187	114.541828	114.570916	50.523605000000003	50.510883999999997	0103000020E61000000100000005000000A703594FADA25C405B069CA564414940A703594FADA25C40D482177D05434940D73043E389A45C40D482177D05434940D73043E389A45C405B069CA564414940A703594FADA25C405B069CA564414940
60154	Будулан	5	48	187	114.89873799999999	114.92876	50.567582000000002	50.545698999999999	0103000020E61000000100000005000000096B63EC84B95C40DE3AFF76D9454940096B63EC84B95C402EE6E786A64849404F75C8CD70BB5C402EE6E786A64849404F75C8CD70BB5C40DE3AFF76D9454940096B63EC84B95C40DE3AFF76D9454940
59488	Амитхаша (Агинский Дацан)	5	48	187	114.456479	114.485845	51.091721999999997	51.073197	0103000020E61000000100000005000000E413B2F3369D5C402995F0845E894940E413B2F3369D5C406F29E78BBD8B4940357BA015189F5C406F29E78BBD8B4940357BA015189F5C402995F0845E894940E413B2F3369D5C402995F0845E894940
50842	Агинское	5	48	187	114.486932	114.57574	51.128608	51.083919999999999	0103000020E610000001000000050000000ED8D5E4299F5C407BBDFBE3BD8A49400ED8D5E4299F5C408200193A76904940F0BF95ECD8A45C408200193A76904940F0BF95ECD8A45C407BBDFBE3BD8A49400ED8D5E4299F5C407BBDFBE3BD8A4940
60050	Агинское	5	48	187	114.486932	114.57574	51.128608	51.083919999999999	0103000020E610000001000000050000000ED8D5E4299F5C407BBDFBE3BD8A49400ED8D5E4299F5C408200193A76904940F0BF95ECD8A45C408200193A76904940F0BF95ECD8A45C407BBDFBE3BD8A49400ED8D5E4299F5C407BBDFBE3BD8A4940
59381	пос.Бельмесево	5	47	\N	83.672085999999993	83.721862000000002	53.212274999999998	53.184579999999997	0103000020E610000001000000050000005D86FF7403EB544072BF4351A0974A405D86FF7403EB54401361C3D32B9B4A40698EACFC32EE54401361C3D32B9B4A40698EACFC32EE544072BF4351A0974A405D86FF7403EB544072BF4351A0974A40
1063	Яровое	5	47	\N	78.545472000000004	78.600071999999997	52.945709999999998	52.906227000000001	0103000020E610000001000000050000008F386403E9A2534048E00F3FFF734A408F386403E9A2534005C078060D794A40B3CF639467A6534005C078060D794A40B3CF639467A6534048E00F3FFF734A408F386403E9A2534048E00F3FFF734A40
59358	Угловское	5	47	\N	80.173839999999998	80.208145999999999	51.373741000000003	51.344946	0103000020E6100000010000000500000025AFCE31200B54406971C63027AC494025AFCE31200B54405116BEBED6AF4940C4B29943520D54405116BEBED6AF4940C4B29943520D54406971C63027AC494025AFCE31200B54406971C63027AC4940
59359	Троицкое	5	47	\N	84.644233999999997	84.706863999999996	52.999028000000003	52.960667999999998	0103000020E61000000100000005000000293E3E213B2955402828452BF77A4A40293E3E213B295540E7E44526E07F4A4010AE80423D2D5540E7E44526E07F4A4010AE80423D2D55402828452BF77A4A40293E3E213B2955402828452BF77A4A40
59357	Тальменка	5	47	\N	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
59356	Солтон	5	47	\N	86.457967999999994	86.492311000000001	52.856746999999999	52.818978999999999	0103000020E6100000010000000500000054A703594F9D55402E8ECA4DD4684A4054A703594F9D55401AF9BCE2A96D4A40821DFF05829F55401AF9BCE2A96D4A40821DFF05829F55402E8ECA4DD4684A4054A703594F9D55402E8ECA4DD4684A40
59374	Солонешное	5	47	\N	84.267021999999997	84.343800999999999	51.673532999999999	51.637253999999999	0103000020E61000000100000005000000005471E316115540629F008A91D14940005471E3161155406DE34F5436D6494041D5E8D5001655406DE34F5436D6494041D5E8D500165540629F008A91D14940005471E316115540629F008A91D14940
902	Славгород	5	47	\N	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
576	Рубцовск	5	47	\N	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
59370	Родино	5	47	\N	80.165970000000002	80.243109000000004	52.514806999999998	52.472988000000001	0103000020E610000001000000050000007F87A2409F0A544042B3EBDE8A3C4A407F87A2409F0A54403D601E32E5414A4040170D198F0F54403D601E32E5414A4040170D198F0F544042B3EBDE8A3C4A407F87A2409F0A544042B3EBDE8A3C4A40
59353	Поспелиха	5	47	\N	81.802736999999993	83.157684000000003	52.007581999999999	51.773482000000001	0103000020E610000001000000050000008192020B60735440B8054B7501E349408192020B60735440E6046D72F8004A408FC6A17E17CA5440E6046D72F8004A408FC6A17E17CA5440B8054B7501E349408192020B60735440B8054B7501E34940
59344	Новоалтайск	5	47	\N	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
59351	Михайловское	5	47	\N	79.645954000000003	79.775526999999997	51.832676999999997	51.800446999999998	0103000020E610000001000000050000001B2E724F57E9534035971B0C75E649401B2E724F57E95340D190F12895EA49408F8AFF3BA2F15340D190F12895EA49408F8AFF3BA2F1534035971B0C75E649401B2E724F57E9534035971B0C75E64940
59412	Марковка	5	47	\N	79.756670999999997	79.783827000000002	52.433418000000003	52.420256000000002	0103000020E6100000010000000500000039B5334C6DF0534051F9D7F2CA354A4039B5334C6DF05340B6BFB33D7A374A4032AEB8382AF25340B6BFB33D7A374A4032AEB8382AF2534051F9D7F2CA354A4039B5334C6DF0534051F9D7F2CA354A40
59390	Крестьянка	5	47	\N	81.537194999999997	81.599798000000007	52.443756	52.411664999999999	0103000020E61000000100000005000000C82423676162544034F44F70B1344A40C824236761625440AFB321FFCC384A40338D261763665440AFB321FFCC384A40338D26176366544034F44F70B1344A40C82423676162544034F44F70B1344A40
59342	Краснощеково	5	47	\N	82.704582000000002	82.773662999999999	51.682608999999999	51.652650999999999	0103000020E610000001000000050000006BD619DF17AD5440D15966118AD349406BD619DF17AD5440467A51BB5FD7494004C8D0B183B15440467A51BB5FD7494004C8D0B183B15440D15966118AD349406BD619DF17AD5440D15966118AD34940
59369	Ключи	5	47	\N	79.133967999999996	79.209138999999993	52.271642999999997	52.227395999999999	0103000020E6100000010000000500000079AD84EE92C85340E09EE74F1B1D4A4079AD84EE92C85340FA97A432C5224A405C548B8862CD5340FA97A432C5224A405C548B8862CD5340E09EE74F1B1D4A4079AD84EE92C85340E09EE74F1B1D4A40
59340	Камень-на-Оби	5	47	\N	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
19902	Змеиногорск	5	47	\N	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
59341	Заринск	5	47	\N	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
59372	Завьялово	5	47	\N	80.879242000000005	80.947478000000004	52.854832999999999	52.820698	0103000020E6100000010000000500000042D13C804538544041F2CEA10C694A4042D13C80453854405245F12A6B6D4A407DEBC37AA33C54405245F12A6B6D4A407DEBC37AA33C544041F2CEA10C694A4042D13C804538544041F2CEA10C694A40
59380	Дегтярка	5	47	\N	79.337445000000002	79.370960999999994	53.351455999999999	53.334575000000001	0103000020E61000000100000005000000B8CCE9B298D553409487855AD3AA4A40B8CCE9B298D55340D2FD9C82FCAC4A40DAC534D3BDD75340D2FD9C82FCAC4A40DAC534D3BDD753409487855AD3AA4A40B8CCE9B298D553409487855AD3AA4A40
59355	Горняк	5	47	\N	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
15194	Бийск	5	47	\N	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
59333	Белокуриха	5	47	\N	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
573	Барнаул	5	47	\N	83.505350000000007	83.864953999999997	53.452658	53.184579999999997	0103000020E6100000010000000500000027C286A757E0544072BF4351A0974A4027C286A757E05440EA2285B2F0B94A40D7A205685BF75440EA2285B2F0B94A40D7A205685BF7544072BF4351A0974A4027C286A757E0544072BF4351A0974A40
59365	Баево	5	47	\N	80.731226000000007	80.803010999999998	53.282536	53.253039000000001	0103000020E6100000010000000500000009FF2268CC2E544068CEFA9463A04A4009FF2268CC2E5440A9F8BF232AA44A4002D53F8864335440A9F8BF232AA44A4002D53F886433544068CEFA9463A04A4009FF2268CC2E544068CEFA9463A04A40
59368	Алтайское	5	47	\N	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
5685	Алейск	5	47	\N	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
5032	Аламбай	5	47	\N	85.863309999999998	85.904238000000007	54.037139000000003	54.020617000000001	0103000020E61000000100000005000000D313967840775540EE5EEE93A3024B40D313967840775540FD3383F8C0044B403B730F09DF795540FD3383F8C0044B403B730F09DF795540EE5EEE93A3024B40D313967840775540EE5EEE93A3024B40
23902	Эстония	5	47	458	82.533067000000003	82.561059	51.903286999999999	51.895828999999999	0103000020E61000000100000005000000EBE40CC51DA2544079E75086AAF24940EBE40CC51DA2544073F38DE89EF3494018080264E8A3544073F38DE89EF3494018080264E8A3544079E75086AAF24940EBE40CC51DA2544079E75086AAF24940
24969	Шипуново	5	47	458	82.205595000000002	82.258280999999997	52.168779000000001	52.149757000000001	0103000020E61000000100000005000000274EEE77288D54406DACC43C2B134A40274EEE77288D544034A0DE8C9A154A40670B08AD8790544034A0DE8C9A154A40670B08AD879054406DACC43C2B134A40274EEE77288D54406DACC43C2B134A40
24923	Хлопуново	5	47	458	82.000420000000005	82.039918999999998	52.079951999999999	52.065117000000001	0103000020E61000000100000005000000EB909BE106805440F2B4FCC055084A40EB909BE106805440F99FFCDD3B0A4A404CDF6B088E825440F99FFCDD3B0A4A404CDF6B088E825440F2B4FCC055084A40EB909BE106805440F2B4FCC055084A40
23709	Усть-Порозиха	5	47	458	82.810691000000006	82.834864999999994	52.134977999999997	52.118817	0103000020E61000000100000005000000570A815CE2B35440BB9A3C65350F4A40570A815CE2B35440F9D687F546114A40CDE49B6D6EB55440F9D687F546114A40CDE49B6D6EB55440BB9A3C65350F4A40570A815CE2B35440BB9A3C65350F4A40
24886	Урлапово	5	47	458	81.986774999999994	82.031124000000005	52.581316000000001	52.560395999999997	0103000020E61000000100000005000000AA605452277F544094675E0EBB474A40AA605452277F54401E520C90684A4A40BA8784EFFD8154401E520C90684A4A40BA8784EFFD81544094675E0EBB474A40AA605452277F544094675E0EBB474A40
24804	Тугозвоново	5	47	458	82.573194999999998	82.618146999999993	52.083826000000002	52.064613000000001	0103000020E61000000100000005000000C4CE143AAFA45440BFF2203D45084A40C4CE143AAFA45440FA4674CFBA0A4A40B6476FB88FA75440FA4674CFBA0A4A40B6476FB88FA75440BFF2203D45084A40C4CE143AAFA45440BFF2203D45084A40
24744	Самсоново	5	47	458	82.68844	82.713106999999994	52.138123	52.119092999999999	0103000020E610000001000000050000008750A5660FAC54405D177E703E0F4A408750A5660FAC5440A7E9B303AE114A401DE38A8BA3AD5440A7E9B303AE114A401DE38A8BA3AD54405D177E703E0F4A408750A5660FAC54405D177E703E0F4A40
24653	Родино	5	47	458	81.986011000000005	82.011450999999994	52.381095000000002	52.366399000000001	0103000020E61000000100000005000000C39FE1CD1A7F5440C0249529E62E4A40C39FE1CD1A7F5440A6D590B8C7304A406AA0F99CBB805440A6D590B8C7304A406AA0F99CBB805440C0249529E62E4A40C39FE1CD1A7F5440C0249529E62E4A40
40339	Порожнее	5	47	458	81.911253000000002	81.938832000000005	52.275494000000002	52.260945	0103000020E6100000010000000500000071581AF8517A5440018750A566214A4071581AF8517A5440431F2C6343234A400D1CD0D2157C5440431F2C6343234A400D1CD0D2157C5440018750A566214A4071581AF8517A5440018750A566214A40
24549	Первомайское	5	47	458	82.148031000000003	82.173587999999995	52.314678000000001	52.300669999999997	0103000020E61000000100000005000000D4F2035779895440B471C45A7C264A40D4F2035779895440A662635E47284A4098BED7101C8B5440A662635E47284A4098BED7101C8B5440B471C45A7C264A40D4F2035779895440B471C45A7C264A40
23845	Озерки	5	47	458	82.396423999999996	82.413878999999994	51.809730000000002	51.792760000000001	0103000020E610000001000000050000005ED6C4025F995440DAC9E02879E549405ED6C4025F995440884B8E3BA5E74940136058FE7C9A5440884B8E3BA5E74940136058FE7C9A5440DAC9E02879E549405ED6C4025F995440DAC9E02879E54940
24295	Новый Путь	5	47	458	82.445894999999993	82.452343999999997	52.172694999999997	52.167216000000003	0103000020E61000000100000005000000CB9C2E8B899C544019AF795567154A40CB9C2E8B899C54406397A8DE1A164A40ADA23F34F39C54406397A8DE1A164A40ADA23F34F39C544019AF795567154A40CB9C2E8B899C544019AF795567154A40
24843	Новосельское	5	47	458	82.548392000000007	82.575727999999998	52.051327999999998	52.040156000000003	0103000020E61000000100000005000000D658C2DA18A354407D5EF1D423054A40D658C2DA18A354403EAF78EA91064A400ED940BAD8A454403EAF78EA91064A400ED940BAD8A454407D5EF1D423054A40D658C2DA18A354407D5EF1D423054A40
24503	Новоивановка	5	47	458	81.995012000000003	82.011792999999997	52.328313000000001	52.314430000000002	0103000020E610000001000000050000002AC8CF46AE7F5440CE70033E3F284A402AC8CF46AE7F544003ED0E29062A4A4097546D37C180544003ED0E29062A4A4097546D37C1805440CE70033E3F284A402AC8CF46AE7F5440CE70033E3F284A40
24444	Нечунаево	5	47	458	82.388681000000005	82.411938000000006	52.274602000000002	52.256292000000002	0103000020E61000000100000005000000E7E44526E0985440FC1C1F2DCE204A40E7E44526E098544046B5882826234A40B37E33315D9A544046B5882826234A40B37E33315D9A5440FC1C1F2DCE204A40E7E44526E0985440FC1C1F2DCE204A40
23423	Метели	5	47	458	82.473742000000001	82.490405999999993	52.080128999999999	52.072412999999997	0103000020E61000000100000005000000772FF7C9519E5440126745D444094A40772FF7C9519E5440083BC5AA410A4A40C7F0D8CF629F5440083BC5AA410A4A40C7F0D8CF629F5440126745D444094A40772FF7C9519E5440126745D444094A40
24336	Кузнечиха	5	47	458	82.479420000000005	82.497619999999998	52.001106	51.987675000000003	0103000020E61000000100000005000000184339D1AE9E5440D50968226CFE4940184339D1AE9E544029EACC3D24004A4079758E01D99F544029EACC3D24004A4079758E01D99F5440D50968226CFE4940184339D1AE9E5440D50968226CFE4940
24238	Красный Яр	5	47	458	82.345319000000003	82.374433999999994	52.199359000000001	52.184679000000003	0103000020E61000000100000005000000FFEBDCB41996544006A1BC8FA3174A40FFEBDCB419965440E694809884194A40AB2006BAF6975440E694809884194A40AB2006BAF697544006A1BC8FA3174A40FFEBDCB41996544006A1BC8FA3174A40
23666	Кособоково	5	47	458	82.850711000000004	82.868506999999994	52.064684999999997	52.052751999999998	0103000020E610000001000000050000003DD68C0C72B654403866D993C0064A403DD68C0C72B6544058C51B9947084A403656629E95B7544058C51B9947084A403656629E95B754403866D993C0064A403DD68C0C72B654403866D993C0064A40
23995	Коробейниково	5	47	458	81.678769000000003	81.708279000000005	52.418937	52.402813999999999	0103000020E61000000100000005000000792288F3706B54407B2FBE688F334A40792288F3706B5440CC0A45BA9F354A40645C7171546D5440CC0A45BA9F354A40645C7171546D54407B2FBE688F334A40792288F3706B54407B2FBE688F334A40
24196	Комариха	5	47	458	82.688359000000005	82.743595999999997	51.936804000000002	51.909059999999997	0103000020E61000000100000005000000113AE8120EAC5440060DFD135CF44940113AE8120EAC544089618731E9F74940EE5BAD1397AF544089618731E9F74940EE5BAD1397AF5440060DFD135CF44940113AE8120EAC5440060DFD135CF44940
24401	Качусово	5	47	458	82.446900999999997	82.467454000000004	51.954312999999999	51.944853999999999	0103000020E610000001000000050000002EE3A6069A9C544055BFD2F9F0F849402EE3A6069A9C5440E692AAED26FA49409A982EC4EA9D5440E692AAED26FA49409A982EC4EA9D544055BFD2F9F0F849402EE3A6069A9C544055BFD2F9F0F84940
24144	Ильинка	5	47	458	82.356126000000003	82.379041999999998	51.963099	51.9437	0103000020E6100000010000000500000057D0B4C4CA9654401B9E5E29CBF8494057D0B4C4CA965440B8E7F9D346FB4940DE73603942985440B8E7F9D346FB4940DE736039429854401B9E5E29CBF8494057D0B4C4CA9654401B9E5E29CBF84940
23944	Зеркалы	5	47	458	81.819597999999999	81.847786999999997	52.493527	52.477128999999998	0103000020E610000001000000050000007D772B4B74745440917C2590123D4A407D772B4B74745440B4588AE42B3F4A4055BE672442765440B4588AE42B3F4A4055BE672442765440917C2590123D4A407D772B4B74745440917C2590123D4A40
2677	Ельцовка	5	47	458	82.385276000000005	82.408604999999994	51.922758999999999	51.891677000000001	0103000020E61000000100000005000000C2FBAA5CA898544036CCD07822F24940C2FBAA5CA89854407A8B87F71CF64940DAFE9595269A54407A8B87F71CF64940DAFE9595269A544036CCD07822F24940C2FBAA5CA898544036CCD07822F24940
23758	Горьковское (Осинники)	5	47	458	82.110570999999993	82.153690999999995	52.083632999999999	52.068576999999998	0103000020E61000000100000005000000B438639813875440FF209221C7084A40B438639813875440E5EE737CB40A4A4021ACC612D6895440E5EE737CB40A4A4021ACC612D6895440FF209221C7084A40B438639813875440FF209221C7084A40
29253	Гавриловский	5	47	458	82.133362000000005	82.157786999999999	51.980280999999998	51.961117000000002	0103000020E61000000100000005000000DE21C500898854409850C1E105FB4940DE21C50089885440F1F109D979FD4940F92EA52E198A5440F1F109D979FD4940F92EA52E198A54409850C1E105FB4940DE21C500898854409850C1E105FB4940
23627	Воробьево	5	47	458	82.969127	82.989546000000004	52.069583999999999	52.061584000000003	0103000020E61000000100000005000000EBAA402D06BE54407BFA08FCE1074A40EBAA402D06BE54409529E620E8084A40CFF8BEB854BF54409529E620E8084A40CFF8BEB854BF54407BFA08FCE1074A40EBAA402D06BE54407BFA08FCE1074A40
23535	Быково	5	47	458	82.162602000000007	82.190664999999996	52.145843999999997	52.128233000000002	0103000020E61000000100000005000000E9103812688A54404DA25EF069104A40E9103812688A5440AE282504AB124A407ADFF8DA338C5440AE282504AB124A407ADFF8DA338C54404DA25EF069104A40E9103812688A54404DA25EF069104A40
23473	Бобровка	5	47	458	82.111551000000006	82.158801999999994	52.422215999999999	52.403413	0103000020E610000001000000050000008335CEA62387544000E48409A3334A408335CEA62387544089EC832C0B364A408522DDCF298A544089EC832C0B364A408522DDCF298A544000E48409A3334A408335CEA62387544000E48409A3334A40
24096	Бестужево	5	47	458	82.461965000000006	82.478755000000007	52.048554000000003	52.025086000000002	0103000020E6100000010000000500000063B9A5D5909D544032CB9E0436034A4063B9A5D5909D5440850B790437064A40FAF202ECA39E5440850B790437064A40FAF202ECA39E544032CB9E0436034A4063B9A5D5909D544032CB9E0436034A40
23378	Белоглазово	5	47	458	82.553844999999995	82.587019999999995	52.124684000000002	52.106284000000002	0103000020E6100000010000000500000066834C3272A35440460BD0B69A0D4A4066834C3272A35440D02A33A5F50F4A40448655BC91A55440D02A33A5F50F4A40448655BC91A55440460BD0B69A0D4A4066834C3272A35440460BD0B69A0D4A40
23338	Баталово	5	47	458	81.857579000000001	81.890251000000006	52.223075999999999	52.209442000000003	0103000020E6100000010000000500000021AF0793E27654405534D6FECE1A4A4021AF0793E2765440E1421EC18D1C4A40CE8E54DFF9785440E1421EC18D1C4A40CE8E54DFF97854405534D6FECE1A4A4021AF0793E27654405534D6FECE1A4A40
24047	Андреевка	5	47	458	81.719076999999999	81.748082999999994	52.439106000000002	52.423231999999999	0103000020E610000001000000050000009293895B056E5440724F57772C364A409293895B056E54401BBD1AA034384A4063EC8497E06F54401BBD1AA034384A4063EC8497E06F5440724F57772C364A409293895B056E5440724F57772C364A40
22635	Шелаболиха	5	47	1700	82.581630000000004	82.651357000000004	53.425474000000001	53.401525999999997	0103000020E61000000100000005000000D717096D39A55440313F373465B34A40D717096D39A554402FA699EE75B64A40534145D5AFA954402FA699EE75B64A40534145D5AFA95440313F373465B34A40D717096D39A55440313F373465B34A40
23282	Чайкино	5	47	1700	81.867478000000006	81.893296000000007	53.504809999999999	53.494452000000003	0103000020E61000000100000005000000F8FF71C2847754408DB800344ABF4A40F8FF71C284775440CD58349D9DC04A407369FCC22B795440CD58349D9DC04A407369FCC22B7954408DB800344ABF4A40F8FF71C2847754408DB800344ABF4A40
23102	Селезнево	5	47	1700	82.152576999999994	82.173677999999995	53.500360000000001	53.492426999999999	0103000020E61000000100000005000000CB4752D2C38954406D5512D907BF4A40CB4752D2C3895440001DE6CB0BC04A403882548A1D8B5440001DE6CB0BC04A403882548A1D8B54406D5512D907BF4A40CB4752D2C38954406D5512D907BF4A40
59476	Подгорный	5	47	1700	81.663596999999996	82.683893999999995	53.680399000000001	53.248593999999997	0103000020E61000000100000005000000512E8D5F786A5440ACFD9DEDD19F4A40512E8D5F786A5440959D7E5017D74A408FFB56EBC4AB5440959D7E5017D74A408FFB56EBC4AB5440ACFD9DEDD19F4A40512E8D5F786A5440ACFD9DEDD19F4A40
23067	Омутское	5	47	1700	82.203474999999997	82.238446999999994	53.492491000000001	53.471378999999999	0103000020E610000001000000050000006EA301BC058D5440B682A62556BC4A406EA301BC058D54408449F1F109BF4A4013B534B7428F54408449F1F109BF4A4013B534B7428F5440B682A62556BC4A406EA301BC058D5440B682A62556BC4A40
59400	Новообинцево	5	47	1700	81.663596999999996	82.683893999999995	53.680399000000001	53.248593999999997	0103000020E61000000100000005000000512E8D5F786A5440ACFD9DEDD19F4A40512E8D5F786A5440959D7E5017D74A408FFB56EBC4AB5440959D7E5017D74A408FFB56EBC4AB5440ACFD9DEDD19F4A40512E8D5F786A5440ACFD9DEDD19F4A40
22969	Макарово	5	47	1700	81.964873999999995	82.007238000000001	53.303167000000002	53.277728000000003	0103000020E61000000100000005000000AFB0E07EC07D54407D9752978CA34A40AFB0E07EC07D5440FC1C1F2DCEA64A4076525F9676805440FC1C1F2DCEA64A4076525F96768054407D9752978CA34A40AFB0E07EC07D54407D9752978CA34A40
22787	Кучук	5	47	1700	82.449757000000005	82.484396000000004	53.452396	53.433188999999999	0103000020E610000001000000050000006A8995D1C89C544054FEB5BC72B74A406A8995D1C89C5440AD6BB41CE8B94A400C941458009F5440AD6BB41CE8B94A400C941458009F544054FEB5BC72B74A406A8995D1C89C544054FEB5BC72B74A40
23194	Крутишка	5	47	1700	81.806950000000001	81.844184999999996	53.470134999999999	53.452523999999997	0103000020E6100000010000000500000076E09C11A5735440DA53724EECB94A4076E09C11A57354403CDA38622DBC4A4085B18520077654403CDA38622DBC4A4085B1852007765440DA53724EECB94A4076E09C11A5735440DA53724EECB94A40
23147	Киприно	5	47	1700	82.055136000000005	82.086577000000005	53.537166999999997	53.519916000000002	0103000020E6100000010000000500000044352559878354406555849B8CC24A404435255987835440C6BE64E3C1C44A407EE5417A8A855440C6BE64E3C1C44A407EE5417A8A8554406555849B8CC24A4044352559878354406555849B8CC24A40
59449	Иня	5	47	1700	81.663596999999996	82.683893999999995	53.680399000000001	53.248593999999997	0103000020E61000000100000005000000512E8D5F786A5440ACFD9DEDD19F4A40512E8D5F786A5440959D7E5017D74A408FFB56EBC4AB5440959D7E5017D74A408FFB56EBC4AB5440ACFD9DEDD19F4A40512E8D5F786A5440ACFD9DEDD19F4A40
23011	Ильинка	5	47	1700	82.309899000000001	82.335222000000002	53.458754999999996	53.448357999999999	0103000020E610000001000000050000000A849D62D5935440327381CB63B94A400A849D62D593544030F0DC7BB8BA4A4095B9F9467495544030F0DC7BB8BA4A4095B9F94674955440327381CB63B94A400A849D62D5935440327381CB63B94A40
22916	Ивановка	5	47	1700	82.166932000000003	82.182903999999994	53.380487000000002	53.369227000000002	0103000020E61000000100000005000000FA298E03AF8A54406DE690D442AF4A40FA298E03AF8A5440CEC64ACCB3B04A40AF93FAB2B48B5440CEC64ACCB3B04A40AF93FAB2B48B54406DE690D442AF4A40FA298E03AF8A54406DE690D442AF4A40
22879	Верх-Кучук	5	47	1700	82.214830000000006	82.249289000000005	53.362161	53.345053999999998	0103000020E61000000100000005000000C80C54C6BF8D54404FADBEBA2AAC4A40C80C54C6BF8D54407E71A94A5BAE4A402A90D959F48F54407E71A94A5BAE4A402A90D959F48F54404FADBEBA2AAC4A40C80C54C6BF8D54404FADBEBA2AAC4A40
22826	Батурово	5	47	1700	82.385266999999999	82.412953000000002	53.432025000000003	53.417769	0103000020E61000000100000005000000984EEB36A89854402D24607479B54A40984EEB36A8985440F7065F984CB74A403F726BD26D9A5440F7065F984CB74A403F726BD26D9A54402D24607479B54A40984EEB36A89854402D24607479B54A40
59417	с.Первомайское	5	47	1664	82.924598000000003	84.588313999999997	51.803899999999999	50.639975999999997	0103000020E610000001000000050000009CFC169D2CBB5440C91CCBBBEA5149409CFC169D2CBB544090A0F831E6E64940DA71C3EFA625554090A0F831E6E64940DA71C3EFA6255540C91CCBBBEA5149409CFC169D2CBB5440C91CCBBBEA514940
22020	Щебнюха	5	47	1664	83.404127000000003	83.422883999999996	51.477910999999999	51.466977	0103000020E610000001000000050000008F1B7E37DDD95440FA7DFFE6C5BB49408F1B7E37DDD9544007B309302CBD49401B800D8810DB544007B309302CBD49401B800D8810DB5440FA7DFFE6C5BB49408F1B7E37DDD95440FA7DFFE6C5BB4940
21788	Чарышское	5	47	1664	83.540959000000001	83.573451000000006	51.423186000000001	51.385506999999997	0103000020E61000000100000005000000855E7F129FE2544085B01A4B58B14940855E7F129FE25440021077F52AB64940F2B6D26BB3E45440021077F52AB64940F2B6D26BB3E4544085B01A4B58B14940855E7F129FE2544085B01A4B58B14940
22352	Чайное	5	47	1664	83.595585	83.634985999999998	51.628376000000003	51.619598000000003	0103000020E610000001000000050000003E3F8C101EE654406155BDFC4ECF49403E3F8C101EE65440B0CBF09F6ED04940BEDA519CA3E85440B0CBF09F6ED04940BEDA519CA3E854406155BDFC4ECF49403E3F8C101EE654406155BDFC4ECF4940
21680	Усть-Тулатинка	5	47	1664	83.389790000000005	83.411000000000001	51.423802999999999	51.404710000000001	0103000020E61000000100000005000000B493C151F2D854409D2E8B89CDB34940B493C151F2D854402D793C2D3FB64940FCA9F1D24DDA54402D793C2D3FB64940FCA9F1D24DDA54409D2E8B89CDB34940B493C151F2D854409D2E8B89CDB34940
40342	Усть-Пихтовка	5	47	1664	83.560102000000001	83.568922999999998	51.702679000000003	51.695160000000001	0103000020E61000000100000005000000261B0FB6D8E3544062BEBC00FBD84940261B0FB6D8E35440024BAE62F1D949404DBC033C69E45440024BAE62F1D949404DBC033C69E4544062BEBC00FBD84940261B0FB6D8E3544062BEBC00FBD84940
21591	Тулата	5	47	1664	83.411250999999993	83.436260000000004	51.331086999999997	51.302878999999997	0103000020E61000000100000005000000A0DCB6EF51DA544095D233BDC4A64940A0DCB6EF51DA5440BC900E0F61AA4940642310AFEBDB5440BC900E0F61AA4940642310AFEBDB544095D233BDC4A64940A0DCB6EF51DA544095D233BDC4A64940
22258	Сосновка	5	47	1664	83.597830999999999	83.619499000000005	51.561526999999998	51.555340000000001	0103000020E610000001000000050000003D62F4DC42E654409014916115C749403D62F4DC42E654401669E21DE0C74940E73922DFA5E754401669E21DE0C74940E73922DFA5E754409014916115C749403D62F4DC42E654409014916115C74940
21305	Сентелек	5	47	1664	83.724287000000004	83.771179000000004	51.208691999999999	51.198341999999997	0103000020E61000000100000005000000C07ADCB75AEE54402CB6494563994940C07ADCB75AEE5440EA77616BB69A49402B172AFF5AF15440EA77616BB69A49402B172AFF5AF154402CB6494563994940C07ADCB75AEE54402CB6494563994940
21427	Покровка	5	47	1664	83.666436000000004	83.675669999999997	51.140070000000001	51.127574000000003	0103000020E6100000010000000500000022382EE3A6EA5440F3E846585490494022382EE3A6EA54404B9352D0ED914940DA38622D3EEB54404B9352D0ED914940DA38622D3EEB5440F3E846585490494022382EE3A6EA5440F3E8465854904940
22088	Озерки	5	47	1664	83.421914000000001	83.436197000000007	51.519699000000003	51.508690999999999	0103000020E610000001000000050000005FEE93A300DB5440806264C91CC149405FEE93A300DB5440C861307F85C249404167D2A6EADB5440C861307F85C249404167D2A6EADB5440806264C91CC149405FEE93A300DB5440806264C91CC14940
22237	Маяк	5	47	1664	83.427008000000001	83.441721999999999	51.624032	51.606388000000003	0103000020E6100000010000000500000058C85C1954DB5440EB573A1F9ECD494058C85C1954DB544028D4D347E0CF49401EFB592C45DC544028D4D347E0CF49401EFB592C45DC5440EB573A1F9ECD494058C85C1954DB5440EB573A1F9ECD4940
21363	Машенка	5	47	1664	83.853122999999997	83.865080000000006	51.256534000000002	51.253889999999998	0103000020E61000000100000005000000C91D369199F654400664AF777FA04940C91D369199F65440F2272A1BD6A049401E1B81785DF75440F2272A1BD6A049401E1B81785DF754400664AF777FA04940C91D369199F654400664AF777FA04940
22484	Маральи Рожки	5	47	1664	83.486313999999993	83.506715	51.738917000000001	51.723427000000001	0103000020E610000001000000050000009065C1C41FDF54408E05854199DC49409065C1C41FDF5440AEBA0ED594DE49402159C0046EE05440AEBA0ED594DE49402159C0046EE054408E05854199DC49409065C1C41FDF54408E05854199DC4940
22389	Маралиха	5	47	1664	83.352339999999998	83.377492000000004	51.712423999999999	51.683295000000001	0103000020E61000000100000005000000A64412BD8CD654409A42E73576D74940A64412BD8CD654405871AAB530DB49401BA034D428D854405871AAB530DB49401BA034D428D854409A42E73576D74940A64412BD8CD654409A42E73576D74940
21835	Малый Бащелак	5	47	1664	83.788588000000004	83.838553000000005	51.499166000000002	51.479481999999997	0103000020E610000001000000050000002881CD3978F25440A5828AAA5FBD49402881CD3978F2544038A3E6ABE4BF49409DBD33DAAAF5544038A3E6ABE4BF49409DBD33DAAAF55440A5828AAA5FBD49402881CD3978F25440A5828AAA5FBD4940
22532	Малая Маралиха	5	47	1664	83.593869999999995	83.608673999999993	51.777878999999999	51.770204999999997	0103000020E61000000100000005000000D50451F701E654409B1BD31396E24940D50451F701E65440629F008A91E349403BFBCA83F4E65440629F008A91E349403BFBCA83F4E654409B1BD31396E24940D50451F701E654409B1BD31396E24940
21438	Майорка	5	47	1664	83.503058999999993	83.515670999999998	51.243262999999999	51.233507000000003	0103000020E61000000100000005000000573D601E32E054408C31B08EE39D4940573D601E32E05440D6A9F23D239F4940B81FF0C000E15440D6A9F23D239F4940B81FF0C000E154408C31B08EE39D4940573D601E32E054408C31B08EE39D4940
21754	Красный Партизан	5	47	1664	83.569632999999996	83.590841999999995	51.386265999999999	51.365656000000001	0103000020E610000001000000050000003B6EF8DD74E4544008CBD8D0CDAE49403B6EF8DD74E4544043C70E2A71B149409BC6F65AD0E5544043C70E2A71B149409BC6F65AD0E5544008CBD8D0CDAE49403B6EF8DD74E4544008CBD8D0CDAE4940
22312	Красные Орлы	5	47	1664	83.488515000000007	83.506238999999994	51.599462000000003	51.587992	0103000020E61000000100000005000000C0266BD443DF5440A227655243CB4940C0266BD443DF5440EE98BA2BBBCC49406C3D433866E05440EE98BA2BBBCC49406C3D433866E05440A227655243CB4940C0266BD443DF5440A227655243CB4940
21536	Комендантка	5	47	1664	83.588470999999998	83.601118999999997	51.343933	51.331605000000003	0103000020E610000001000000050000003EE94482A9E5544055185B0872AA49403EE94482A9E55440F1811DFF05AC49404580D3BB78E65440F1811DFF05AC49404580D3BB78E6544055185B0872AA49403EE94482A9E5544055185B0872AA4940
21909	Ивановка	5	47	1664	83.812968999999995	83.828203999999999	51.543500000000002	51.536923999999999	0103000020E610000001000000050000005BEA20AF07F454400038F6ECB9C449405BEA20AF07F4544021B0726891C54940A69A594B01F5544021B0726891C54940A69A594B01F554400038F6ECB9C449405BEA20AF07F454400038F6ECB9C44940
21658	Долинское	5	47	1664	83.423378	83.436942999999999	51.389015000000001	51.379424999999998	0103000020E6100000010000000500000023F609A018DB5440742497FF90B0494023F609A018DB5440A453573ECBB14940D5CDC5DFF6DB5440A453573ECBB14940D5CDC5DFF6DB5440742497FF90B0494023F609A018DB5440742497FF90B04940
21929	Боровлянка	5	47	1664	83.743995999999996	83.767739000000006	51.407727000000001	51.402102999999997	0103000020E61000000100000005000000B51666A19DEF5440CE4F711C78B34940B51666A19DEF54401D59F96530B449404837C2A222F154401D59F96530B449404837C2A222F15440CE4F711C78B34940B51666A19DEF5440CE4F711C78B34940
22004	Большой Бащелак	5	47	1664	83.949189000000004	83.977476999999993	51.541674	51.528911999999998	0103000020E61000000100000005000000452E3883BFFC5440213B6F63B3C34940452E3883BFFC5440F88BD99255C54940E6E5B0FB8EFE5440F88BD99255C54940E6E5B0FB8EFE5440213B6F63B3C34940452E3883BFFC5440213B6F63B3C34940
59457	Большая Речка	5	47	1664	82.924598000000003	84.588313999999997	51.803899999999999	50.639975999999997	0103000020E610000001000000050000009CFC169D2CBB5440C91CCBBBEA5149409CFC169D2CBB544090A0F831E6E64940DA71C3EFA625554090A0F831E6E64940DA71C3EFA6255540C91CCBBBEA5149409CFC169D2CBB5440C91CCBBBEA514940
21515	Березовка	5	47	1664	83.602952000000002	83.621071000000001	51.284922999999999	51.264412999999998	0103000020E61000000100000005000000B343FCC396E6544091D10149D8A14940B343FCC396E6544069705B5B78A449409E5F94A0BFE7544069705B5B78A449409E5F94A0BFE7544091D10149D8A14940B343FCC396E6544091D10149D8A14940
22144	Алексеевка	5	47	1664	83.390203999999997	83.408277999999996	51.577773000000001	51.564506000000002	0103000020E610000001000000050000002DB1321AF9D85440A9328CBB41C849402DB1321AF9D8544083C13577F4C94940486B0C3A21DA544083C13577F4C94940486B0C3A21DA5440A9328CBB41C849402DB1321AF9D85440A9328CBB41C84940
21280	Аба	5	47	1664	83.801002999999994	83.816121999999993	51.300699000000002	51.293564000000003	0103000020E61000000100000005000000DD3F16A243F3544038A4518193A54940DD3F16A243F354404F78094E7DA64940F3E2C4573BF454404F78094E7DA64940F3E2C4573BF4544038A4518193A54940DD3F16A243F3544038A4518193A54940
20523	Шалап	5	47	1615	85.804004000000006	85.868063000000006	53.124161000000001	53.104584000000003	0103000020E610000001000000050000009B7631CD74735540AAD72D02638D4A409B7631CD747355402638F581E48F4A4088F71C588E7755402638F581E48F4A4088F71C588E775540AAD72D02638D4A409B7631CD74735540AAD72D02638D4A40
21057	Чесноково	5	47	1615	86.083810999999997	86.107769000000005	53.089286999999999	53.071928999999997	0103000020E61000000100000005000000E202D0285D85554026512FF834894A40E202D0285D8555409E7AA4C16D8B4A4073A1F2AFE58655409E7AA4C16D8B4A4073A1F2AFE586554026512FF834894A40E202D0285D85554026512FF834894A40
20138	Целинное	5	47	1615	85.632667999999995	85.686603000000005	53.097468999999997	53.056193	0103000020E61000000100000005000000724EECA17D685540CFA10C5531874A40724EECA17D685540D9AF3BDD798C4A407995B54DF16B5540D9AF3BDD798C4A407995B54DF16B5540CFA10C5531874A40724EECA17D685540CFA10C5531874A40
20382	Хомутино	5	47	1615	85.391434000000004	85.416848000000002	53.177920999999998	53.149895999999998	0103000020E61000000100000005000000B82231410D5955408EE6C8CA2F934A40B82231410D595540C422861DC6964A40CBD93BA3AD5A5540C422861DC6964A40CBD93BA3AD5A55408EE6C8CA2F934A40B82231410D5955408EE6C8CA2F934A40
21141	Сухая Чемровка	5	47	1615	85.372254999999996	85.411969999999997	52.732098999999998	52.714941000000003	0103000020E6100000010000000500000070B1A206D3575540E7C8CA2F835B4A4070B1A206D35755409737876BB55D4A40B83B6BB75D5A55409737876BB55D4A40B83B6BB75D5A5540E7C8CA2F835B4A4070B1A206D3575540E7C8CA2F835B4A40
21191	Сверчково	5	47	1615	85.350211000000002	85.370405000000005	52.786782000000002	52.767792	0103000020E61000000100000005000000C4EC65DB69565540B2101D0247624A40C4EC65DB695655406E8AC745B5644A4098512CB7B45755406E8AC745B5644A4098512CB7B4575540B2101D0247624A40C4EC65DB69565540B2101D0247624A40
59453	Поповичи	5	47	1615	86.244986999999995	86.280219000000002	53.021405000000001	52.993088	0103000020E610000001000000050000007D3CF4DDAD8F55406806F1811D7F4A407D3CF4DDAD8F5540467C2766BD824A40F12DAC1BEF915540467C2766BD824A40F12DAC1BEF9155406806F1811D7F4A407D3CF4DDAD8F55406806F1811D7F4A40
20980	Победа	5	47	1615	86.014218	86.063141000000002	53.127948000000004	53.112687000000001	0103000020E61000000100000005000000EE409DF2E880554099D711876C8E4A40EE409DF2E880554058CB9D9960904A405A828C800A84554058CB9D9960904A405A828C800A84554099D711876C8E4A40EE409DF2E880554099D711876C8E4A40
20815	Овсянниково	5	47	1615	86.061640999999995	86.125978000000003	52.940559999999998	52.917614999999998	0103000020E61000000100000005000000EFC517EDF1835540D6A8876874754A40EFC517EDF18355407FF6234564784A40FE800706108855407FF6234564784A40FE80070610885540D6A8876874754A40EFC517EDF1835540D6A8876874754A40
20773	Марушка	5	47	1615	85.466102000000006	85.514449999999997	52.884338999999997	52.858890000000002	0103000020E610000001000000050000006AA67B9DD45D5540446E861BF06D4A406AA67B9DD45D5540E6C9350532714A40575BB1BFEC605540E6C9350532714A40575BB1BFEC605540446E861BF06D4A406AA67B9DD45D5540446E861BF06D4A40
20876	Локоть	5	47	1615	86.207051000000007	86.222583	53.060338000000002	53.041155000000003	0103000020E61000000100000005000000AA66D652408D55409088299144854A40AA66D652408D5540605AD427B9874A405169C4CC3E8E5540605AD427B9874A405169C4CC3E8E55409088299144854A40AA66D652408D55409088299144854A40
21069	Ложкино	5	47	1615	85.426378999999997	85.469740999999999	52.850569999999998	52.826895999999998	0103000020E61000000100000005000000E02C25CB495B5540BB9866BAD7694A40E02C25CB495B5540B77A4E7ADF6C4A40C8258E3C105E5540B77A4E7ADF6C4A40C8258E3C105E5540BB9866BAD7694A40E02C25CB495B5540BB9866BAD7694A40
20622	Еланда	5	47	1615	85.703743000000003	85.768107000000001	53.200215	53.177073	0103000020E610000001000000050000007E7214200A6D55409700FC53AA964A407E7214200A6D5540969526A5A0994A40093543AA28715540969526A5A0994A40093543AA287155409700FC53AA964A407E7214200A6D55409700FC53AA964A40
20673	Дружба	5	47	1615	85.509770000000003	85.531006000000005	52.907259000000003	52.893993999999999	0103000020E61000000100000005000000D89E5912A0605540FD6838656E724A40D89E5912A060554037001B1021744A40B5FE9600FC61554037001B1021744A40B5FE9600FC615540FD6838656E724A40D89E5912A0605540FD6838656E724A40
20541	Воеводское	5	47	1615	85.581265999999999	85.625095000000002	52.806078999999997	52.777549	0103000020E61000000100000005000000B6114F7633655540CD04C3B986634A40B6114F7633655540067FBF982D674A402979758E01685540067FBF982D674A402979758E01685540CD04C3B986634A40B6114F7633655540CD04C3B986634A40
21220	Верх-Яминское	5	47	1615	85.794571000000005	85.806483	52.999597000000001	52.991624000000002	0103000020E6100000010000000500000067D65240DA725540E0F60489ED7E4A4067D65240DA725540011764CBF27F4A40EB71DF6A9D735540011764CBF27F4A40EB71DF6A9D735540E0F60489ED7E4A4067D65240DA725540E0F60489ED7E4A40
20309	Верх-Марушка	5	47	1615	85.609959000000003	85.639756000000006	52.924021000000003	52.909122000000004	0103000020E61000000100000005000000A8397991096755407D09151C5E744A40A8397991096755409BE8F35146764A40DE5A26C3F16855409BE8F35146764A40DE5A26C3F16855407D09151C5E744A40A8397991096755407D09151C5E744A40
20450	Бочкари	5	47	1615	85.755593000000005	85.790807000000001	52.901935999999999	52.874186999999999	0103000020E610000001000000050000008A05BEA25B7055404FCB0F5CE56F4A408A05BEA25B705540E38A8BA372734A40AA9CF6949C725540E38A8BA372734A40AA9CF6949C7255404FCB0F5CE56F4A408A05BEA25B7055404FCB0F5CE56F4A40
19035	Хабары	5	47	1581	79.508296000000001	79.569892999999993	53.638593	53.597738999999997	0103000020E61000000100000005000000022CF2EB87E05340994528B682CC4A40022CF2EB87E053402E3A596ABDD14A40094E7D2079E453402E3A596ABDD14A40094E7D2079E45340994528B682CC4A40022CF2EB87E05340994528B682CC4A40
19226	Утянка	5	47	1581	79.426989000000006	79.477394000000004	53.615865999999997	53.588279	0103000020E610000001000000050000001DB0ABC953DB534038F6ECB94CCB4A401DB0ABC953DB5340F25B74B2D4CE4A40A053909F8DDE5340F25B74B2D4CE4A40A053909F8DDE534038F6ECB94CCB4A401DB0ABC953DB534038F6ECB94CCB4A40
20036	Усть-Курья	5	47	1581	79.717692999999997	79.748019999999997	53.669027	53.657215000000001	0103000020E610000001000000050000005CE49EAEEEED534067B8019F1FD44A405CE49EAEEEED53400C923EADA2D54A404030478FDFEF53400C923EADA2D54A404030478FDFEF534067B8019F1FD44A405CE49EAEEEED534067B8019F1FD44A40
19433	Топольное	5	47	1581	78.869315	78.895780000000002	53.559086000000001	53.537337999999998	0103000020E6100000010000000500000006BB61DBA2B75340F372D87DC7C44A4006BB61DBA2B7534063D34A2190C74A404C1AA37554B9534063D34A2190C74A404C1AA37554B95340F372D87DC7C44A4006BB61DBA2B75340F372D87DC7C44A40
19602	Свердловское	5	47	1581	79.650471999999993	79.687095999999997	53.332973000000003	53.322620000000001	0103000020E61000000100000005000000ADBD4F55A1E953408C84B69C4BA94A40ADBD4F55A1E95340BBB9F8DB9EAA4A40984D8061F9EB5340BBB9F8DB9EAA4A40984D8061F9EB53408C84B69C4BA94A40ADBD4F55A1E953408C84B69C4BA94A40
19470	Рассвет	5	47	1581	79.313083000000006	79.332684	53.508805000000002	53.496974999999999	0103000020E61000000100000005000000C07B478D09D45340FDF675E09CBF4A40C07B478D09D453404985B18520C14A40C2F9D4B14AD553404985B18520C14A40C2F9D4B14AD55340FDF675E09CBF4A40C07B478D09D45340FDF675E09CBF4A40
19788	Поперечное	5	47	1581	79.826740000000001	79.841858000000002	53.472878999999999	53.461612000000002	0103000020E61000000100000005000000E292E34EE9F4534078B81D1A16BB4A40E292E34EE9F453408BFB8F4C87BC4A4010786000E1F553408BFB8F4C87BC4A4010786000E1F5534078B81D1A16BB4A40E292E34EE9F4534078B81D1A16BB4A40
22634	Полевое	5	47	1581	79.217564999999993	79.248683	53.394019999999998	53.373525000000001	0103000020E6100000010000000500000045F0BF95ECCD5340849ECDAACFAF4A4045F0BF95ECCD534026FC523F6FB24A408E041A6CEACF534026FC523F6FB24A408E041A6CEACF5340849ECDAACFAF4A4045F0BF95ECCD5340849ECDAACFAF4A40
19948	Плесо-Курья	5	47	1581	79.896169999999998	79.932669000000004	53.648617000000002	53.618617	0103000020E61000000100000005000000016A6AD95AF95340F4DF83D72ECF4A40016A6AD95AF953409850C1E105D34A408E3F51D9B0FB53409850C1E105D34A408E3F51D9B0FB5340F4DF83D72ECF4A40016A6AD95AF95340F4DF83D72ECF4A40
19373	Пионер Труда	5	47	1581	79.076476	79.098646000000002	53.549992000000003	53.542448	0103000020E6100000010000000500000073BB97FBE4C45340EBE3A1EF6EC54A4073BB97FBE4C45340E4874A2366C64A4066F84F3750C65340E4874A2366C64A4066F84F3750C65340EBE3A1EF6EC54A4073BB97FBE4C45340EBE3A1EF6EC54A40
22574	Орлово	5	47	1581	79.224069	79.255635999999996	53.327154	53.310451999999998	0103000020E6100000010000000500000009C3802557CE5340287D21E4BCA74A4009C3802557CE5340B760A92EE0A94A4089EB18575CD05340B760A92EE0A94A4089EB18575CD05340287D21E4BCA74A4009C3802557CE5340287D21E4BCA74A40
19749	Новоплотава	5	47	1581	79.746223999999998	79.763507000000004	53.522207000000002	53.506101000000001	0103000020E6100000010000000500000061DF4E22C2EF534088BCE5EAC7C04A4061DF4E22C2EF5340035FD1ADD7C24A4018D1764CDDF05340035FD1ADD7C24A4018D1764CDDF0534088BCE5EAC7C04A4061DF4E22C2EF534088BCE5EAC7C04A40
19290	Новоильинка	5	47	1581	79.244001999999995	79.308150999999995	53.581313999999999	53.554673000000001	0103000020E61000000100000005000000268A90BA9DCF5340B37C5D86FFC64A40268A90BA9DCF53407D5A457F68CA4A40B3CEF8BEB8D353407D5A457F68CA4A40B3CEF8BEB8D35340B37C5D86FFC64A40268A90BA9DCF5340B37C5D86FFC64A40
19706	Мичуринское	5	47	1581	79.725876999999997	79.739063999999999	53.483398999999999	53.467595000000003	0103000020E61000000100000005000000CAFACDC474EE5340F6622827DABB4A40CAFACDC474EE5340A5F5B704E0BD4A40A96917D34CEF5340A5F5B704E0BD4A40A96917D34CEF5340F6622827DABB4A40CAFACDC474EE5340F6622827DABB4A40
19540	Мартовка	5	47	1581	79.500876000000005	79.532964000000007	53.453211000000003	53.434981000000001	0103000020E610000001000000050000007CD6355A0EE05340D1B01875ADB74A407CD6355A0EE05340FF976BD102BA4A40817C09151CE25340FF976BD102BA4A40817C09151CE25340D1B01875ADB74A407CD6355A0EE05340D1B01875ADB74A40
19633	Малопавловка	5	47	1581	79.616309000000001	79.644767999999999	53.439605	53.424599999999998	0103000020E61000000100000005000000C0CE4D9B71E75340D8F0F44A59B64A40C0CE4D9B71E753403C1405FA44B84A40786000E143E953403C1405FA44B84A40786000E143E95340D8F0F44A59B64A40C0CE4D9B71E75340D8F0F44A59B64A40
22432	Красноармейский	5	47	1581	79.208383999999995	79.228236999999993	53.249353999999997	53.239364000000002	0103000020E610000001000000050000009E40D82956CD53407DEBC37AA39E4A409E40D82956CD53403A90F5D4EA9F4A402DAF5C6F9BCE53403A90F5D4EA9F4A402DAF5C6F9BCE53407DEBC37AA39E4A409E40D82956CD53407DEBC37AA39E4A40
20060	Коротояк	5	47	1581	79.656931	79.689199000000002	53.764510000000001	53.739801	0103000020E61000000100000005000000A12E52280BEA5340284696CCB1DE4A40A12E52280BEA534084BBB376DBE14A40E65B1FD61BEC534084BBB376DBE14A40E65B1FD61BEC5340284696CCB1DE4A40A12E52280BEA5340284696CCB1DE4A40
59408	Зятькова Речка	5	47	1581	79.927476999999996	79.957193000000004	53.485205000000001	53.462679000000001	0103000020E61000000100000005000000B3B27DC85BFB5340E3C5C21039BB4A40B3B27DC85BFB5340876D8B321BBE4A4073BD6DA642FD5340876D8B321BBE4A4073BD6DA642FD5340E3C5C21039BB4A40B3B27DC85BFB5340E3C5C21039BB4A40
19894	Васильевка	5	47	1581	79.822023000000002	79.840421000000006	53.588524999999997	53.572871999999997	0103000020E61000000100000005000000D4635B069CF45340A565A4DE53C94A40D4635B069CF453406FF085C954CB4A40C9772975C9F553406FF085C954CB4A40C9772975C9F55340A565A4DE53C94A40D4635B069CF45340A565A4DE53C94A40
19347	Богатское	5	47	1581	79.032736999999997	79.060045000000002	53.473367000000003	53.457500000000003	0103000020E61000000100000005000000A017EE5C18C25340C3F5285C8FBA4A40A017EE5C18C25340B900344A97BC4A4074D2FBC6D7C35340B900344A97BC4A4074D2FBC6D7C35340C3F5285C8FBA4A40A017EE5C18C25340C3F5285C8FBA4A40
59430	Александровка	5	47	1581	79.160414000000003	79.176475999999994	53.314207000000003	53.302058000000002	0103000020E6100000010000000500000084F4143944CA534062BF27D6A9A64A4084F4143944CA53404F965AEF37A84A40D921FE614BCB53404F965AEF37A84A40D921FE614BCB534062BF27D6A9A64A4084F4143944CA534062BF27D6A9A64A40
59448	с.Коловый Мыс	5	47	1523	83.207801000000003	84.122995000000003	52.668998999999999	51.925097000000001	0103000020E61000000100000005000000DFC4909C4CCD54405950189469F64940DFC4909C4CCD544042075DC2A1554A4094A46B26DF07554042075DC2A1554A4094A46B26DF0755405950189469F64940DFC4909C4CCD54405950189469F64940
18900	Чеканиха	5	47	1523	83.836225999999996	83.865106999999995	52.372579000000002	52.360959999999999	0103000020E6100000010000000500000027840EBA84F554400395F1EF332E4A4027840EBA84F5544094162EABB02F4A409A22C0E95DF7544094162EABB02F4A409A22C0E95DF754400395F1EF332E4A4027840EBA84F554400395F1EF332E4A40
59363	Усть-Чарышская Пристань	5	47	1523	83.631985	83.681042000000005	52.411279999999998	52.38165	0103000020E6100000010000000500000001A4367172E854405B423EE8D9304A4001A4367172E85440DBBFB2D2A4344A40F54C2F3196EB5440DBBFB2D2A4344A40F54C2F3196EB54405B423EE8D9304A4001A4367172E854405B423EE8D9304A40
18396	Усть-Чарыш	5	47	1523	83.738722999999993	83.755746000000002	52.340792999999998	52.325049	0103000020E610000001000000050000006473D53C47EF54407B4CA4349B294A406473D53C47EF544055DAE21A9F2B4A404D8578245EF0544055DAE21A9F2B4A404D8578245EF054407B4CA4349B294A406473D53C47EF54407B4CA4349B294A40
18577	Усть-Журавлиха	5	47	1523	83.374949999999998	83.412940000000006	52.230010999999998	52.216842	0103000020E61000000100000005000000A7E8482EFFD754401A33897AC11B4A40A7E8482EFFD75440315C1D00711D4A4075CDE49B6DDA5440315C1D00711D4A4075CDE49B6DDA54401A33897AC11B4A40A7E8482EFFD754401A33897AC11B4A40
18172	Троицкое (Барчиха)	5	47	1523	83.501900000000006	83.534608000000006	52.381667	52.367977000000003	0103000020E6100000010000000500000032772D211FE054401157CEDE192F4A4032772D211FE05440317BD976DA304A40850B790437E25440317BD976DA304A40850B790437E254401157CEDE192F4A4032772D211FE054401157CEDE192F4A40
18126	Романово	5	47	1523	83.356993000000003	83.375389999999996	52.423282	52.410978	0103000020E61000000100000005000000A9F92AF9D8D6544010B056ED9A344A40A9F92AF9D8D65440247EC51A2E364A40B54FC76306D85440247EC51A2E364A40B54FC76306D8544010B056ED9A344A40A9F92AF9D8D6544010B056ED9A344A40
18664	Нижняя Гусиха	5	47	1523	83.365409999999997	83.389718000000002	52.311599999999999	52.291272999999997	0103000020E6100000010000000500000068E89FE062D75440999A046F48254A4068E89FE062D7544080B74082E2274A40672AC423F1D8544080B74082E2274A40672AC423F1D85440999A046F48254A4068E89FE062D75440999A046F48254A40
18824	Нижнеозерное	5	47	1523	83.722769	83.777117000000004	52.227330000000002	52.209172000000002	0103000020E610000001000000050000000264E8D841EE5440959EE925C61A4A400264E8D841EE544029B34126191D4A409A0AF148BCF1544029B34126191D4A409A0AF148BCF15440959EE925C61A4A400264E8D841EE5440959EE925C61A4A40
18567	Красноярка	5	47	1523	83.455483999999998	83.490761000000006	52.232934	52.219180999999999	0103000020E610000001000000050000007BF65CA626DD5440C9737D1F0E1C4A407BF65CA626DD5440301004C8D01D4A40BF49D3A068DF5440301004C8D01D4A40BF49D3A068DF5440C9737D1F0E1C4A407BF65CA626DD5440C9737D1F0E1C4A40
18885	Краснодарское	5	47	1523	83.783145000000005	83.805188999999999	52.122548999999999	52.109408999999999	0103000020E61000000100000005000000A9C1340C1FF25440AC71361D010E4A40A9C1340C1FF25440299485AFAF0F4A405586713788F35440299485AFAF0F4A405586713788F35440AC71361D010E4A40A9C1340C1FF25440AC71361D010E4A40
18718	Коробейниково	5	47	1523	83.683565999999999	83.733341999999993	52.203355000000002	52.177841999999998	0103000020E6100000010000000500000015AA9B8BBFEB544078EDD286C3164A4015AA9B8BBFEB5440323D6189071A4A4020B24813EFEE5440323D6189071A4A4020B24813EFEE544078EDD286C3164A4015AA9B8BBFEB544078EDD286C3164A40
18965	Клепиково	5	47	1523	83.745217999999994	83.779713000000001	52.548766999999998	52.528483999999999	0103000020E61000000100000005000000FE98D6A6B1EF5440C93A1C5DA5434A40FE98D6A6B1EF5440E00F3FFF3D464A4007D15AD1E6F15440E00F3FFF3D464A4007D15AD1E6F15440C93A1C5DA5434A40FE98D6A6B1EF5440C93A1C5DA5434A40
18422	Елбанка	5	47	1523	83.595280000000002	83.620029000000002	52.236663	52.221547999999999	0103000020E61000000100000005000000A0FD481119E65440423F53AF5B1C4A40A0FD481119E654402D9622F94A1E4A4095641D8EAEE754402D9622F94A1E4A4095641D8EAEE75440423F53AF5B1C4A40A0FD481119E65440423F53AF5B1C4A40
18041	Вяткино	5	47	1523	83.603131000000005	83.639889999999994	52.545442000000001	52.506810000000002	0103000020E610000001000000050000000B0DC4B299E6544094A46B26DF404A400B0DC4B299E65440B3EE1F0BD1454A4065C22FF5F3E85440B3EE1F0BD1454A4065C22FF5F3E8544094A46B26DF404A400B0DC4B299E6544094A46B26DF404A40
18090	Брусенцево	5	47	1523	83.429388000000003	83.469443999999996	52.450902999999997	52.430728000000002	0103000020E61000000100000005000000DF52CE177BDB54405ABC581822374A40DF52CE177BDB54408A558330B7394A406BD3D85E0BDE54408A558330B7394A406BD3D85E0BDE54405ABC581822374A40DF52CE177BDB54405ABC581822374A40
17976	Белово	5	47	1523	83.614163000000005	83.634743	52.630766000000001	52.617859000000003	0103000020E6100000010000000500000073DA53724EE754400745F300164F4A4073DA53724EE75440E1B6B6F0BC504A405B971AA19FE85440E1B6B6F0BC504A405B971AA19FE854400745F300164F4A4073DA53724EE754400745F300164F4A40
17591	Усть-Камышенка	5	47	1466	83.182297000000005	83.219380000000001	52.058228999999997	52.048836000000001	0103000020E610000001000000050000002C4A09C1AACB5440096F0F4240064A402C4A09C1AACB5440E256410C74074A40605969520ACE5440E256410C74074A40605969520ACE5440096F0F4240064A402C4A09C1AACB5440096F0F4240064A40
16734	Усть-Калманка	5	47	1466	83.281220000000005	83.333143000000007	52.138665000000003	52.101382999999998	0103000020E61000000100000005000000CBBE2B82FFD1544068AF3E1EFA0C4A40CBBE2B82FFD15440C80C54C6BF114A400C79043752D55440C80C54C6BF114A400C79043752D5544068AF3E1EFA0C4A40CBBE2B82FFD1544068AF3E1EFA0C4A40
17444	Усть-Ермилиха	5	47	1466	82.871803999999997	82.891898999999995	52.025424000000001	52.018169	0103000020E61000000100000005000000682101A3CBB7544088669E5C53024A40682101A3CBB754404A44F81741034A4072158BDF14B954404A44F81741034A4072158BDF14B9544088669E5C53024A40682101A3CBB7544088669E5C53024A40
17138	Степной	5	47	1466	83.176360000000003	83.194640000000007	52.161178	52.156283000000002	0103000020E61000000100000005000000A514747B49CB5440DCF5D21401144A40A514747B49CB5440D76A0F7BA1144A40959F54FB74CC5440D76A0F7BA1144A40959F54FB74CC5440DCF5D21401144A40A514747B49CB5440DCF5D21401144A40
17892	Слюдянка	5	47	1466	83.651200000000003	83.665447	51.890231999999997	51.876601000000001	0103000020E61000000100000005000000EFC9C342ADE954400952297634F04940EFC9C342ADE9544024ED461FF3F149402A8E03AF96EA544024ED461FF3F149402A8E03AF96EA54400952297634F04940EFC9C342ADE954400952297634F04940
16986	Приозерный	5	47	1466	83.484337999999994	83.506473	52.167028000000002	52.153984000000001	0103000020E61000000100000005000000718DCF64FFDE5440BB0D6ABFB5134A40718DCF64FFDE544016C26A2C61154A40A6D3BA0D6AE0544016C26A2C61154A40A6D3BA0D6AE05440BB0D6ABFB5134A40718DCF64FFDE5440BB0D6ABFB5134A40
17176	Пономарево	5	47	1466	83.131264000000002	83.177706999999998	52.077655	52.066882999999997	0103000020E6100000010000000500000019C91EA166C8544045D4449F8F084A4019C91EA166C8544079AF5A99F0094A404C512E8D5FCB544079AF5A99F0094A404C512E8D5FCB544045D4449F8F084A4019C91EA166C8544045D4449F8F084A40
17746	Огни	5	47	1466	83.517082000000002	83.560156000000006	51.933554999999998	51.897691000000002	0103000020E610000001000000050000006BD619DF17E15440EF74E789E7F249406BD619DF17E154403602F1BA7EF74940202A8D98D9E354403602F1BA7EF74940202A8D98D9E35440EF74E789E7F249406BD619DF17E15440EF74E789E7F24940
16890	Новый Чарыш	5	47	1466	83.359796000000003	83.383942000000005	52.181061999999997	52.169746000000004	0103000020E61000000100000005000000D34ECDE506D754403C50A73CBA154A40D34ECDE506D754403046240A2D174A40E563778192D854403046240A2D174A40E563778192D854403C50A73CBA154A40D34ECDE506D754403C50A73CBA154A40
59450	Новотроенка	5	47	1466	83.308277000000004	83.330555000000004	51.847183999999999	51.83128	0103000020E61000000100000005000000FA4674CFBAD35440D1E80E6267EA4940FA4674CFBAD35440E4D87A8670EC4940E0A128D027D55440E4D87A8670EC4940E0A128D027D55440D1E80E6267EA4940FA4674CFBAD35440D1E80E6267EA4940
17635	Новокалманка	5	47	1466	83.352052	83.378929999999997	51.966211999999999	51.938369999999999	0103000020E61000000100000005000000739F1C0588D6544015C616821CF84940739F1C0588D654405A80B6D5ACFB49404A5E9D6340D854405A80B6D5ACFB49404A5E9D6340D8544015C616821CF84940739F1C0588D6544015C616821CF84940
17473	Новобураново	5	47	1466	83.027500000000003	83.050612999999998	51.952719999999999	51.935437999999998	0103000020E61000000100000005000000F6285C8FC2C15440C3B7B06EBCF74940F6285C8FC2C15440601F9DBAF2F9494028F04E3E3DC35440601F9DBAF2F9494028F04E3E3DC35440C3B7B06EBCF74940F6285C8FC2C15440C3B7B06EBCF74940
17796	Михайловка	5	47	1466	83.771142999999995	83.837734999999995	51.972237	51.942250999999999	0103000020E6100000010000000500000084622B685AF15440C8CF46AE9BF8494084622B685AF15440077B134372FC4940BBED42739DF55440077B134372FC4940BBED42739DF55440C8CF46AE9BF8494084622B685AF15440C8CF46AE9BF84940
17287	Кабаново	5	47	1466	83.082116999999997	83.12415	52.048692000000003	52.033203	0103000020E61000000100000005000000855CA96741C554408690F3FE3F044A40855CA96741C55440D6C9198A3B064A401973D712F2C75440D6C9198A3B064A401973D712F2C754408690F3FE3F044A40855CA96741C554408690F3FE3F044A40
17239	Западный	5	47	1466	83.048179000000005	83.059102999999993	52.136045000000003	52.126801	0103000020E61000000100000005000000A8565F5D15C35440D00CE2033B104A40A8565F5D15C3544065E42CEC69114A401C06F357C8C3544065E42CEC69114A401C06F357C8C35440D00CE2033B104A40A8565F5D15C35440D00CE2033B104A40
17544	Ельцовка	5	47	1466	83.176288	83.21002	51.966151000000004	51.949789000000003	0103000020E6100000010000000500000058AB764D48CB5440DF8C9AAF92F9494058AB764D48CB5440B5FF01D6AAFB494061E0B9F770CD5440B5FF01D6AAFB494061E0B9F770CD5440DF8C9AAF92F9494058AB764D48CB5440DF8C9AAF92F94940
17084	Дружба	5	47	1466	83.293301999999997	83.310370000000006	52.240682999999997	52.236282000000003	0103000020E610000001000000050000007D76C075C5D254401651137D3E1E4A407D76C075C5D2544001DA56B3CE1E4A4036EA211ADDD3544001DA56B3CE1E4A4036EA211ADDD354401651137D3E1E4A407D76C075C5D254401651137D3E1E4A40
16966	Восточный	5	47	1466	83.498513000000003	83.518393000000003	52.057647000000003	52.046869999999998	0103000020E6100000010000000500000060E811A3E7DF5440EE940ED6FF054A4060E811A3E7DF544034DB15FA60074A406C5ED5592DE1544034DB15FA60074A406C5ED5592DE15440EE940ED6FF054A4060E811A3E7DF5440EE940ED6FF054A40
17963	Верх-Слюдянка	5	47	1466	83.753842000000006	83.799843999999993	51.797601	51.782192000000002	0103000020E610000001000000050000007B1684F23EF05440AF9811DE1EE449407B1684F23EF05440E22021CA17E64940B779E3A430F35440E22021CA17E64940B779E3A430F35440AF9811DE1EE449407B1684F23EF05440AF9811DE1EE44940
17331	Бураново	5	47	1466	82.926564999999997	82.949130999999994	52.025052000000002	52.015836	0103000020E61000000100000005000000912749D74CBB5440BB0CFFE906024A40912749D74CBB5440865968E734034A40AA27F38FBEBC5440865968E734034A40AA27F38FBEBC5440BB0CFFE906024A40912749D74CBB5440BB0CFFE906024A40
16017	Шадруха	5	47	1411	79.953456000000003	79.972204000000005	51.181716999999999	51.149151000000003	0103000020E61000000100000005000000338B506C05FD53403695456117934940338B506C05FD53404910AE80429749409642209738FE53404910AE80429749409642209738FE53403695456117934940338B506C05FD53403695456117934940
16245	Угловское	5	47	1411	80.173839999999998	80.208145999999999	51.373741000000003	51.344946	0103000020E6100000010000000500000025AFCE31200B54406971C63027AC494025AFCE31200B54405116BEBED6AF4940C4B29943520D54405116BEBED6AF4940C4B29943520D54406971C63027AC494025AFCE31200B54406971C63027AC4940
16715	Топольное	5	47	1411	80.093512000000004	80.120290999999995	50.953215	50.922989999999999	0103000020E610000001000000050000002672C119FC0554407C444C89247649402672C119FC0554404087F9F2027A494033C005D9B20754404087F9F2027A494033C005D9B20754407C444C89247649402672C119FC0554407C444C8924764940
15636	Симоново	5	47	1411	80.373121999999995	80.396558999999996	51.693575000000003	51.676091	0103000020E61000000100000005000000C2DA183BE11754405A0F5F268AD64940C2DA183BE11754405F29CB10C7D84940CEFBFF38611954405F29CB10C7D84940CEFBFF38611954405A0F5F268AD64940C2DA183BE11754405A0F5F268AD64940
15945	Павловка	5	47	1411	79.780907999999997	79.810372000000001	51.408087000000002	51.386406999999998	0103000020E61000000100000005000000D34B8C65FAF1534005F9D9C875B14940D34B8C65FAF153401D76DF313CB4494006668522DDF353401D76DF313CB4494006668522DDF3534005F9D9C875B14940D34B8C65FAF1534005F9D9C875B14940
59458	Озерно-Кузнецовский лесхоз	5	47	1411	79.539323999999993	80.704393999999994	51.818098999999997	50.737842000000001	0103000020E61000000100000005000000AA7CCF4884E25340C0CE4D9B715E4940AA7CCF4884E25340F5F1D077B7E84940E95F92CA142D5440F5F1D077B7E84940E95F92CA142D5440C0CE4D9B715E4940AA7CCF4884E25340C0CE4D9B715E4940
15861	Озерно-Кузнецово	5	47	1411	80.327973	80.375636999999998	51.525297999999999	51.481372	0103000020E61000000100000005000000253E7782FD145440E59A02999DBD4940253E7782FD145440BD5301F73CC34940B98AC56F0A185440BD5301F73CC34940B98AC56F0A185440E59A02999DBD4940253E7782FD145440E59A02999DBD4940
16329	Новоугловский	5	47	1411	80.278664000000006	80.291168999999996	51.450572999999999	51.443792999999999	0103000020E61000000100000005000000A5A487A1D5115440CC988235CEB84940A5A487A1D5115440F5BA4560ACB94940FA264D83A2125440F5BA4560ACB94940FA264D83A2125440CC988235CEB84940A5A487A1D5115440CC988235CEB84940
16481	Наумовка	5	47	1411	80.430550999999994	80.458094000000003	51.036639999999998	51.023904999999999	0103000020E61000000100000005000000A510C8258E1B5440FE9AAC510F834940A510C8258E1B5440DBDC989EB08449409B1F7F69511D5440DBDC989EB08449409B1F7F69511D5440FE9AAC510F834940A510C8258E1B5440FE9AAC510F834940
16093	Мирный	5	47	1411	79.950743000000003	79.979247000000001	51.435298000000003	51.417310999999998	0103000020E61000000100000005000000A9F92AF9D8FC53406AA164726AB54940A9F92AF9D8FC5340D20149D8B7B7494031ED9BFBABFE5340D20149D8B7B7494031ED9BFBABFE53406AA164726AB54940A9F92AF9D8FC53406AA164726AB54940
16172	Ляпуново	5	47	1411	80.124684000000002	80.149620999999996	51.298976000000003	51.284585	0103000020E61000000100000005000000689599D2FA07544051F701486DA44940689599D2FA075440FB2477D844A64940DE72F56393095440FB2477D844A64940DE72F5639309544051F701486DA44940689599D2FA07544051F701486DA44940
16572	Лаптев Лог	5	47	1411	80.159305000000003	80.204408999999998	51.075924000000001	51.039555999999997	0103000020E61000000100000005000000B745990D320A5440272EC72B10854940B745990D320A5440A27DACE0B789494084807C09150D5440A27DACE0B789494084807C09150D5440272EC72B10854940B745990D320A5440272EC72B10854940
32500	Куйбышево	5	47	1411	80.561848999999995	80.585457000000005	51.359520000000003	51.345565000000001	0103000020E6100000010000000500000094128255F523544035D252793BAC494094128255F5235440042159C004AE4940B70DA32078255440042159C004AE4940B70DA3207825544035D252793BAC494094128255F523544035D252793BAC4940
16393	Круглое	5	47	1411	80.420364000000006	80.461426000000003	51.296683999999999	51.278061000000001	0103000020E610000001000000050000009C1A683EE71A544083A5BA8097A349409C1A683EE71A54408C9FC6BDF9A549408BE1EA00881D54408C9FC6BDF9A549408BE1EA00881D544083A5BA8097A349409C1A683EE71A544083A5BA8097A34940
15742	Кормиха (Кроликово)	5	47	1411	80.531898999999996	80.542552999999998	51.700318000000003	51.689051999999997	0103000020E610000001000000050000009B711AA20A225440279F1EDB32D849409B711AA20A2254406B662D05A4D9494030D63730B92254406B662D05A4D9494030D63730B9225440279F1EDB32D849409B711AA20A225440279F1EDB32D84940
15707	Валовой Кордон	5	47	1411	80.35812	80.372052999999994	51.789116999999997	51.769364000000003	0103000020E61000000100000005000000C9022670EB165440215C01857AE24940C9022670EB165440DBDB2DC901E549403CD862B7CF175440DBDB2DC901E549403CD862B7CF175440215C01857AE24940C9022670EB165440215C01857AE24940
16554	Борисовка	5	47	1411	80.221351999999996	80.239444000000006	51.135961999999999	51.120609000000002	0103000020E61000000100000005000000DE3994A12A0E5440384D9F1D708F4940DE3994A12A0E5440D7BFEB33679149404D4EED0C530F5440D7BFEB33679149404D4EED0C530F5440384D9F1D708F4940DE3994A12A0E5440384D9F1D708F4940
16116	Бор-Кособулат	5	47	1411	79.823694000000003	79.834016000000005	51.416384000000001	51.410856000000003	0103000020E6100000010000000500000055FA0967B7F45340C5AEEDED96B4494055FA0967B7F45340F14927124CB54940CF15A58460F55340F14927124CB54940CF15A58460F55340C5AEEDED96B4494055FA0967B7F45340C5AEEDED96B44940
16651	Беленькое	5	47	1411	80.119923	80.136021	50.999696	50.982903	0103000020E6100000010000000500000072C284D1AC075440F511F8C3CF7D494072C284D1AC07544094F8DC09F67F49406EA46C91B408544094F8DC09F67F49406EA46C91B4085440F511F8C3CF7D494072C284D1AC075440F511F8C3CF7D4940
15985	Алексеевка	5	47	1411	79.704470000000001	79.723882000000003	51.381314000000003	51.3703	0103000020E61000000100000005000000D7C0560916ED5340BADA8AFD65AF4940D7C0560916ED5340E4C0ABE5CEB04940700A2B1554EE5340E4C0ABE5CEB04940700A2B1554EE5340BADA8AFD65AF4940D7C0560916ED5340BADA8AFD65AF4940
15602	Юдиха	5	47	1360	81.931043000000003	81.954121000000001	53.437862000000003	53.422747999999999	0103000020E61000000100000005000000DD0A6135967B54408639419B1CB64A40DD0A6135967B5440A114ADDC0BB84A4051DB8651107D5440A114ADDC0BB84A4051DB8651107D54408639419B1CB64A40DD0A6135967B54408639419B1CB64A40
15163	Шарчино	5	47	1360	81.723873999999995	81.778661999999997	53.152099999999997	53.127965000000003	0103000020E610000001000000050000002E1B9DF3536E54402E04392861904A402E1B9DF3536E54405DDC460378934A40D4282499D57154405DDC460378934A40D4282499D57154402E04392861904A402E1B9DF3536E54402E04392861904A40
15001	Черемшанка	5	47	1360	81.235800999999995	81.269191000000006	53.266348999999998	53.254143999999997	0103000020E610000001000000050000004DD7135D174F5440C03C64CA87A04A404DD7135D174F544041295AB917A24A402A58E36C3A51544041295AB917A24A402A58E36C3A515440C03C64CA87A04A404DD7135D174F5440C03C64CA87A04A40
59467	Урывка	5	47	1360	81.760552000000004	81.783665999999997	53.051153999999997	53.034965999999997	0103000020E6100000010000000500000013BA4BE2AC705440683C11C479844A4013BA4BE2AC705440A087DA368C864A402D3F709527725440A087DA368C864A402D3F709527725440683C11C479844A4013BA4BE2AC705440683C11C479844A40
14678	Тюменцево	5	47	1360	81.478561999999997	81.525310000000005	53.334682999999998	53.298457999999997	0103000020E61000000100000005000000EFC682C2A05E5440629D2ADF33A64A40EFC682C2A05E54407AC37DE4D6AA4A40C190D5AD9E6154407AC37DE4D6AA4A40C190D5AD9E615440629D2ADF33A64A40EFC682C2A05E5440629D2ADF33A64A40
15208	Трубачево	5	47	1360	81.596457000000001	81.622686999999999	53.104351000000001	53.093429	0103000020E61000000100000005000000191EFB592C665440BEBF417BF58B4A40191EFB592C6654400727A25F5B8D4A403D29931ADA6754400727A25F5B8D4A403D29931ADA675440BEBF417BF58B4A40191EFB592C665440BEBF417BF58B4A40
15364	Свободный	5	47	1360	81.598882000000003	81.618078999999994	53.299754999999998	53.287633999999997	0103000020E61000000100000005000000700A2B1554665440DC9BDF30D1A44A40700A2B1554665440FFE7305F5EA64A400AD6389B8E675440FFE7305F5EA64A400AD6389B8E675440DC9BDF30D1A44A40700A2B1554665440DC9BDF30D1A44A40
15552	Мезенцево	5	47	1360	81.678527000000003	81.715951000000004	53.361414000000003	53.352687000000003	0103000020E61000000100000005000000FE9C82FC6C6B5440B85CFDD824AD4A40FE9C82FC6C6B544085285FD042AE4A4077A22424D26D544085285FD042AE4A4077A22424D26D5440B85CFDD824AD4A40FE9C82FC6C6B5440B85CFDD824AD4A40
15035	Кулундинский	5	47	1360	81.167312999999993	81.186349000000007	53.234744999999997	53.221673000000003	0103000020E6100000010000000500000085CC9541B54A5440FFB3E6C75F9C4A4085CC9541B54A544023F3C81F0C9E4A401C295B24ED4B544023F3C81F0C9E4A401C295B24ED4B5440FFB3E6C75F9C4A4085CC9541B54A5440FFB3E6C75F9C4A40
15059	Королевский	5	47	1360	81.445414	81.465688999999998	53.183598000000003	53.170817999999997	0103000020E610000001000000050000008ECBB8A9815C5440B8C83D5DDD954A408ECBB8A9815C544036CEA62380974A40D8463CD9CD5D544036CEA62380974A40D8463CD9CD5D5440B8C83D5DDD954A408ECBB8A9815C5440B8C83D5DDD954A40
14840	Ключи	5	47	1360	81.402716999999996	81.436197000000007	53.451242999999998	53.438918000000001	0103000020E61000000100000005000000C422861DC659544018D00B772EB84A40C422861DC659544043C6A354C2B94A404167D2A6EA5B544043C6A354C2B94A404167D2A6EA5B544018D00B772EB84A40C422861DC659544018D00B772EB84A40
15412	Карповский	5	47	1360	81.588740000000001	81.625867	53.213918999999997	53.199406000000003	0103000020E61000000100000005000000367689EAAD6554402750C42286994A40367689EAAD6554401B7FA2B2619B4A40522976340E6854401B7FA2B2619B4A40522976340E6854402750C42286994A40367689EAAD6554402750C42286994A40
15305	Заводской	5	47	1360	81.635210000000001	81.658152999999999	53.307702999999997	53.290787999999999	0103000020E61000000100000005000000E605D847A7685440DD088B8A38A54A40E605D847A7685440C7F0D8CF62A74A40EAB0C22D1F6A5440C7F0D8CF62A74A40EAB0C22D1F6A5440DD088B8A38A54A40E605D847A7685440DD088B8A38A54A40
14907	Грязново	5	47	1360	81.248889000000005	81.284695999999997	53.389423999999998	53.376517	0103000020E6100000010000000500000063D520CCED4F5440ABB184B531B04A4063D520CCED4F5440852348A5D8B14A405453927538525440852348A5D8B14A405453927538525440ABB184B531B04A4063D520CCED4F5440ABB184B531B04A40
15110	Вылково	5	47	1360	81.402861000000001	81.456607000000005	53.094251	53.064922000000003	0103000020E610000001000000050000005EF58079C85954403D65355D4F884A405EF58079C8595440C24EB16A108C4A40FB07910C395D5440C24EB16A108C4A40FB07910C395D54403D65355D4F884A405EF58079C85954403D65355D4F884A40
15453	Березовка	5	47	1360	81.798524	81.831680000000006	53.252926000000002	53.237918999999998	0103000020E610000001000000050000008D4468041B7354406B0C3A21749E4A408D4468041B735440702711E15FA04A40302FC03E3A755440702711E15FA04A40302FC03E3A7554406B0C3A21749E4A408D4468041B7354406B0C3A21749E4A40
14925	Андроново	5	47	1360	81.172118999999995	81.194721000000001	53.328035999999997	53.311188999999999	0103000020E610000001000000050000004B0169FF034B5440FEEF880AD5A74A404B0169FF034B544090F46915FDA94A400BB6114F764C544090F46915FDA94A400BB6114F764C5440FEEF880AD5A74A404B0169FF034B5440FEEF880AD5A74A40
14589	Южаково	5	47	1138	84.459423000000001	84.488761999999994	52.809035000000002	52.785539999999997	0103000020E61000000100000005000000EF01BA2F671D554094D920938C644A40EF01BA2F671D5540E12879758E674A40C36169E0471F5540E12879758E674A40C36169E0471F554094D920938C644A40EF01BA2F671D554094D920938C644A40
13102	Червянка	5	47	1138	84.059386000000003	84.078484000000003	52.604571	52.597783	0103000020E61000000100000005000000C7F5EFFACC035540698D4127844C4A40C7F5EFFACC035540158E2095624D4A409850C1E105055540158E2095624D4A409850C1E105055540698D4127844C4A40C7F5EFFACC035540698D4127844C4A40
13668	Хайрюзовка	5	47	1138	84.896749999999997	84.939492000000001	52.974654999999998	52.950208000000003	0103000020E6100000010000000500000008AC1C5A64395540E4326E6AA0794A4008AC1C5A6439554002F1BA7EC17C4A40A2B60DA3203C554002F1BA7EC17C4A40A2B60DA3203C5540E4326E6AA0794A4008AC1C5A64395540E4326E6AA0794A40
13120	Уткуль	5	47	1138	84.595248999999995	84.616314000000003	52.722065000000001	52.712015999999998	0103000020E6100000010000000500000082FE428F18265540471D1D57235B4A4082FE428F182655400A4B3CA06C5C4A40498446B0712755400A4B3CA06C5C4A40498446B071275540471D1D57235B4A4082FE428F18265540471D1D57235B4A40
13683	Усть-Гавриловка	5	47	1138	85.008617000000001	85.053668000000002	52.945107999999998	52.934019999999997	0103000020E61000000100000005000000234C512E8D405540ABE7A4F78D774A40234C512E8D4055400F98874CF9784A40DF35E84B6F4355400F98874CF9784A40DF35E84B6F435540ABE7A4F78D774A40234C512E8D405540ABE7A4F78D774A40
13247	Тюмень	5	47	1138	84.584351999999996	84.611535000000003	52.951467000000001	52.927712999999997	0103000020E610000001000000050000008A56EE05662555407A89B14CBF764A408A56EE0566255540931CB0ABC9794A400057B26323275540931CB0ABC9794A400057B263232755407A89B14CBF764A408A56EE05662555407A89B14CBF764A40
12871	Троицкое	5	47	1138	84.644233999999997	84.706863999999996	52.999028000000003	52.960667999999998	0103000020E61000000100000005000000293E3E213B2955402828452BF77A4A40293E3E213B295540E7E44526E07F4A4010AE80423D2D5540E7E44526E07F4A4010AE80423D2D55402828452BF77A4A40293E3E213B2955402828452BF77A4A40
13885	Талдинка	5	47	1138	85.073233000000002	85.091891000000004	53.138294000000002	53.122495999999998	0103000020E610000001000000050000003BFF76D9AF44554006F2ECF2AD8F4A403BFF76D9AF445540D49D279EB3914A40FEF2C98AE1455540D49D279EB3914A40FEF2C98AE145554006F2ECF2AD8F4A403BFF76D9AF44554006F2ECF2AD8F4A40
13464	Степной	5	47	1138	84.754222999999996	84.767967999999996	52.87135	52.860298	0103000020E6100000010000000500000006B98B30453055403868AF3E1E6E4A4006B98B30453055404FAF9465886F4A40F8174163263155404FAF9465886F4A40F8174163263155403868AF3E1E6E4A4006B98B30453055403868AF3E1E6E4A40
10579	Раздольный	5	47	1138	84.880392000000001	84.892985999999993	53.140087999999999	53.131540999999999	0103000020E610000001000000050000003EEAAF5758385540A48AE255D6904A403EEAAF5758385540F1475167EE914A404B72C0AE26395540F1475167EE914A404B72C0AE26395540A48AE255D6904A403EEAAF5758385540A48AE255D6904A40
14087	Петровка	5	47	1138	84.612343999999993	84.653836999999996	53.081125	53.052723	0103000020E61000000100000005000000B779E3A4302755409E5F94A0BF864A40B779E3A430275540AAF1D24D628A4A408BFA2477D8295540AAF1D24D628A4A408BFA2477D82955409E5F94A0BF864A40B779E3A4302755409E5F94A0BF864A40
14162	Песьянка	5	47	1138	84.538501999999994	84.558560999999997	53.119897000000002	53.111660000000001	0103000020E6100000010000000500000028B517D176225540BC22F8DF4A8E4A4028B517D176225540BBF1EEC8588F4A408CF4A276BF235540BBF1EEC8588F4A408CF4A276BF235540BC22F8DF4A8E4A4028B517D176225540BC22F8DF4A8E4A40
14317	Октябрьский	5	47	1138	84.673788000000002	84.699561000000003	53.133146000000004	53.116168000000002	0103000020E61000000100000005000000FC1BB4571F2B5540BE6BD097DE8E4A40FC1BB4571F2B5540EFCB99ED0A914A40A723809BC52C5540EFCB99ED0A914A40A723809BC52C5540BE6BD097DE8E4A40FC1BB4571F2B5540BE6BD097DE8E4A40
59456	Озеро-Петровское	5	47	1138	84.280955000000006	84.321405999999996	52.959279000000002	52.938254000000001	0103000020E610000001000000050000007429AE2AFB115540ACAB02B518784A407429AE2AFB115540AB5E7EA7C97A4A403EAF78EA91145540AB5E7EA7C97A4A403EAF78EA91145540ACAB02B518784A407429AE2AFB115540ACAB02B518784A40
13741	Новоеловка	5	47	1138	84.934505999999999	84.996823000000006	53.064137000000002	53.051034999999999	0103000020E610000001000000050000009CFA40F2CE3B5540C6F99B5088864A409CFA40F2CE3B554056BB26A435884A40A439B2F2CB3F554056BB26A435884A40A439B2F2CB3F5540C6F99B5088864A409CFA40F2CE3B5540C6F99B5088864A40
14551	Многоозерный	5	47	1138	84.358722	84.397295999999997	52.744166	52.727186000000003	0103000020E61000000100000005000000C4961E4DF5165540F60D4C6E145D4A40C4961E4DF5165540C765DCD4405F4A4039B5334C6D195540C765DCD4405F4A4039B5334C6D195540F60D4C6E145D4A40C4961E4DF5165540F60D4C6E145D4A40
14637	Лесной	5	47	1138	84.479913999999994	84.486705000000001	52.853000999999999	52.838887	0103000020E610000001000000050000001FB935E9B61E5540100533A6606B4A401FB935E9B61E5540473A03232F6D4A402E73BA2C261F5540473A03232F6D4A402E73BA2C261F5540100533A6606B4A401FB935E9B61E5540100533A6606B4A40
13317	Ленинский	5	47	1138	84.525090000000006	84.549632000000003	52.769601000000002	52.739263999999999	0103000020E610000001000000050000003A5D16139B215540198EE733A05E4A403A5D16139B21554005FC1A4982624A407235B22B2D23554005FC1A4982624A407235B22B2D235540198EE733A05E4A403A5D16139B215540198EE733A05E4A40
13956	Краснояры	5	47	1138	85.280581999999995	85.306866999999997	53.171207000000003	53.157677999999997	0103000020E610000001000000050000002976340EF55155403BA6EECA2E944A402976340EF551554053EC681CEA954A402F4E7CB5A353554053EC681CEA954A402F4E7CB5A35355403BA6EECA2E944A402976340EF55155403BA6EECA2E944A40
14372	Клюквенный	5	47	1138	84.942430000000002	84.956092999999996	53.177785999999998	53.152591000000001	0103000020E610000001000000050000003C31EBC5503C5540FC54151A88934A403C31EBC5503C5540E4D70FB1C1964A40CFBBB1A0303D5540E4D70FB1C1964A40CFBBB1A0303D5540FC54151A88934A403C31EBC5503C5540FC54151A88934A40
13598	Кипешино	5	47	1138	84.800487000000004	84.824184000000002	52.947701000000002	52.936087999999998	0103000020E61000000100000005000000E277D32D3B335540CA1649BBD1774A40E277D32D3B33554079B130444E794A40BC783F6EBF34554079B130444E794A40BC783F6EBF345540CA1649BBD1774A40E277D32D3B335540CA1649BBD1774A40
13401	Зеленая Поляна	5	47	1138	84.729788999999997	84.762855999999999	52.891359000000001	52.879159999999999	0103000020E61000000100000005000000C1FEEBDCB42E5540C6F99B5088704A40C1FEEBDCB42E554065FF3C0D18724A40ACE3F8A1D230554065FF3C0D18724A40ACE3F8A1D2305540C6F99B5088704A40C1FEEBDCB42E5540C6F99B5088704A40
13383	Загайново	5	47	1138	84.496964000000006	84.552955999999995	52.876041000000001	52.854669999999999	0103000020E6100000010000000500000085D21742CE1F5540A86F99D3656D4A4085D21742CE1F5540427A8A1C22704A40200890A163235540427A8A1C22704A40200890A163235540A86F99D3656D4A4085D21742CE1F5540A86F99D3656D4A40
14401	Заводское	5	47	1138	84.401302000000001	84.447727	53.079751000000002	53.060344000000001	0103000020E61000000100000005000000717495EEAE1955404241295AB9874A40717495EEAE1955406269E047358A4A4051A2258FA71C55406269E047358A4A4051A2258FA71C55404241295AB9874A40717495EEAE1955404241295AB9874A40
13975	Еремино	5	47	1138	85.226772999999994	85.243077999999997	53.166494	53.156025	0103000020E6100000010000000500000069A7E672834E5540E02D90A0F8934A4069A7E672834E5540787DE6AC4F954A40221807978E4F5540787DE6AC4F954A40221807978E4F5540E02D90A0F8934A4069A7E672834E5540E02D90A0F8934A40
13827	Ельцовка	5	47	1138	85.092978000000002	85.143103999999994	53.064348000000003	53.047044999999997	0103000020E61000000100000005000000D74FFF59F34555405C38109205864A40D74FFF59F345554011C8258E3C884A4050FBAD9D2849554011C8258E3C884A4050FBAD9D284955405C38109205864A40D74FFF59F34555405C38109205864A40
14038	Горновое	5	47	1138	85.312922	85.365966999999998	53.083683999999998	53.065424999999998	0103000020E61000000100000005000000BB0CFFE9065455409FABADD85F884A40BB0CFFE90654554067994528B68A4A40931ADA006C57554067994528B68A4A40931ADA006C5755409FABADD85F884A40BB0CFFE9065455409FABADD85F884A40
14263	Гордеевский	5	47	1138	84.665102000000005	84.694952999999998	53.119729	53.099556	0103000020E6100000010000000500000045A0FA07912A55406F0F4240BE8C4A4045A0FA07912A5540FFB0A547538F4A4074D0251C7A2C5540FFB0A547538F4A4074D0251C7A2C55406F0F4240BE8C4A4045A0FA07912A55406F0F4240BE8C4A40
13798	Гордеевка	5	47	1138	84.923115999999993	84.966873000000007	53.087189000000002	53.071939999999998	0103000020E61000000100000005000000849A2155143B55401AA3755435894A40849A2155143B554015C95702298B4A40AB984A3FE13D554015C95702298B4A40AB984A3FE13D55401AA3755435894A40849A2155143B55401AA3755435894A40
13516	Вершинино	5	47	1138	84.659621999999999	84.693703999999997	52.732945000000001	52.71613	0103000020E61000000100000005000000376E313F372A55409DD7D825AA5B4A40376E313F372A554024624A24D15D4A40AE4676A5652C554024624A24D15D4A40AE4676A5652C55409DD7D825AA5B4A40376E313F372A55409DD7D825AA5B4A40
13274	Боровлянский	5	47	1138	84.687092000000007	84.704654000000005	52.869979999999998	52.857275000000001	0103000020E61000000100000005000000F855B950F92B5540D656EC2FBB6D4A40F855B950F92B5540481630815B6F4A40B83F170D192D5540481630815B6F4A40B83F170D192D5540D656EC2FBB6D4A40F855B950F92B5540D656EC2FBB6D4A40
12990	Боровлянка	5	47	1138	84.421919000000003	84.471874	52.645007999999997	52.619351999999999	0103000020E61000000100000005000000E8A38CB8001B5540295B24ED464F4A40E8A38CB8001B554045D4449F8F524A404B75012F331E554045D4449F8F524A404B75012F331E5540295B24ED464F4A40E8A38CB8001B5540295B24ED464F4A40
13549	Белое	5	47	1138	84.694637999999998	84.763045000000005	52.933700000000002	52.912466999999999	0103000020E61000000100000005000000C423F1F2742C5540F1D6F9B7CB744A40C423F1F2742C55403A234A7B83774A401618B2BAD53055403A234A7B83774A401618B2BAD5305540F1D6F9B7CB744A40C423F1F2742C5540F1D6F9B7CB744A40
13188	Беловский	5	47	1138	84.613826000000003	84.670176999999995	52.906351999999998	52.883986	0103000020E61000000100000005000000CFDBD8EC48275540990F087426714A40CFDBD8EC482755400455A35703744A400262122EE42A55400455A35703744A400262122EE42A5540990F087426714A40CFDBD8EC48275540990F087426714A40
12666	Шипуниха	5	47	1217	82.369339999999994	82.394277000000002	50.948715	50.922468000000002	0103000020E61000000100000005000000B2463D44A3975440A3CD716E13764940B2463D44A3975440C11C3D7E6F794940292499D53B995440C11C3D7E6F794940292499D53B995440A3CD716E13764940B2463D44A3975440A3CD716E13764940
12402	Третьяково	5	47	1217	81.886324999999999	81.910381999999998	50.879347000000003	50.851058999999999	0103000020E6100000010000000500000024287E8CB9785440B5FB5580EF6C494024287E8CB9785440F96A47718E7049407E37DDB2437A5440F96A47718E7049407E37DDB2437A5440B5FB5580EF6C494024287E8CB9785440B5FB5580EF6C4940
25566	Степной	5	47	1217	81.880539999999996	81.892208999999994	50.977238	50.968418999999997	0103000020E6100000010000000500000078B471C45A7854409AE95E27F57B494078B471C45A78544048348122167D4940990CC7F31979544048348122167D4940990CC7F3197954409AE95E27F57B494078B471C45A7854409AE95E27F57B4940
12125	Староалейское	5	47	1217	81.965654999999998	82.020408000000003	51.025022	50.987746000000001	0103000020E61000000100000005000000020EA14ACD7D54409E60FF756E7E4940020EA14ACD7D54401BD7BFEB33834940EA245B5D4E8154401BD7BFEB33834940EA245B5D4E8154409E60FF756E7E4940020EA14ACD7D54409E60FF756E7E4940
12691	Семеновка	5	47	1217	82.463258999999994	82.491654999999994	50.972859999999997	50.949475	0103000020E61000000100000005000000F8A41309A69D54404FAF946588794940F8A41309A69D544014CB2DAD867C49408D7A8846779F544014CB2DAD867C49408D7A8846779F54404FAF946588794940F8A41309A69D54404FAF946588794940
12206	Садовый	5	47	1217	81.911019999999994	81.931967999999998	50.990025000000003	50.977215999999999	0103000020E610000001000000050000001F80D4264E7A54406090F469157D49401F80D4264E7A5440789CA223B97E4940C93A1C5DA57B5440789CA223B97E4940C93A1C5DA57B54406090F469157D49401F80D4264E7A54406090F469157D4940
12848	Плоское	5	47	1217	82.138823000000002	82.161891999999995	50.860066000000003	50.840041999999997	0103000020E61000000100000005000000B03BDD79E28854401AA20A7F866B4940B03BDD79E2885440663387A4166E4940FA5E43705C8A5440663387A4166E4940FA5E43705C8A54401AA20A7F866B4940B03BDD79E28854401AA20A7F866B4940
12530	Первомайский	5	47	1217	81.915627999999998	81.943161000000003	50.885558000000003	50.873759999999997	0103000020E6100000010000000500000052D32EA6997A5440C746205ED76F494052D32EA6997A5440085BECF6597149403677F4BF5C7C5440085BECF6597149403677F4BF5C7C5440C746205ED76F494052D32EA6997A5440C746205ED76F4940
12639	Первокаменка	5	47	1217	82.250259	82.297475000000006	50.979636999999997	50.955075999999998	0103000020E61000000100000005000000E621533E04905440E5982CEE3F7A4940E621533E04905440CC79C6BE647D49402B1895D409935440CC79C6BE647D49402B1895D409935440E5982CEE3F7A4940E621533E04905440E5982CEE3F7A4940
12378	Новокамышенка	5	47	1217	82.093872000000005	82.129273999999995	50.941370999999997	50.926976000000003	0103000020E61000000100000005000000A680B4FF01865440A5164A26A7764940A680B4FF018654408F334DD87E784940478E7406468854408F334DD87E784940478E740646885440A5164A26A7764940A680B4FF01865440A5164A26A7764940
12748	Новоалейское	5	47	1217	82.399928000000003	82.418549999999996	50.862988000000001	50.826098999999999	0103000020E610000001000000050000004D309C6B989954401021AE9CBD6949404D309C6B98995440946B0A64766E4940696FF085C99A5440946B0A64766E4940696FF085C99A54401021AE9CBD6949404D309C6B989954401021AE9CBD694940
12462	Михайловка	5	47	1217	81.952754999999996	81.968072000000006	50.824506	50.803158000000003	0103000020E610000001000000050000006E861BF0F97C5440A9C29FE1CD6649406E861BF0F97C54408AADA06989694940180B43E4F47D54408AADA06989694940180B43E4F47D5440A9C29FE1CD6649406E861BF0F97C5440A9C29FE1CD664940
12293	Корболиха	5	47	1217	81.956798000000006	81.974018999999998	51.112496	51.092807999999998	0103000020E6100000010000000500000035B8AD2D3C7D54405167EE21E18B494035B8AD2D3C7D54402577D844668E4940B0ABC953567E54402577D844668E4940B0ABC953567E54405167EE21E18B494035B8AD2D3C7D54405167EE21E18B4940
12299	Екатерининское	5	47	1217	82.006024999999994	82.028779999999998	50.922814000000002	50.895927	0103000020E61000000100000005000000567DAEB6628054403C4D66BCAD724940567DAEB6628054403E25E7C41E764940D9B11188D78154403E25E7C41E764940D9B11188D78154403C4D66BCAD724940567DAEB6628054403C4D66BCAD724940
59461	Верх-Алейка	5	47	1217	82.438654	82.450997000000001	50.859428999999999	50.849739	0103000020E610000001000000050000009D103AE8129C544060915F3FC46C49409D103AE8129C5440F31DFCC4016E494006668522DD9C5440F31DFCC4016E494006668522DD9C544060915F3FC46C49409D103AE8129C544060915F3FC46C4940
12062	Чистюнька	5	47	1154	83.187301000000005	83.238110000000006	52.689489999999999	52.667765000000003	0103000020E61000000100000005000000856055BDFCCB5440EC34D25279554A40856055BDFCCB5440A375543541584A4070B6B9313DCF5440A375543541584A4070B6B9313DCF5440EC34D25279554A40856055BDFCCB5440EC34D25279554A40
12054	Чаузово  (Большая Речка)	5	47	1154	83.747660999999994	83.781564000000003	52.747028	52.728865999999996	0103000020E61000000100000005000000A8DF85ADD9EF54404A95287B4B5D4A40A8DF85ADD9EF544020990E9D9E5F4A40C8EE022505F2544020990E9D9E5F4A40C8EE022505F254404A95287B4B5D4A40A8DF85ADD9EF54404A95287B4B5D4A40
11967	Хабазино	5	47	1154	83.364160999999996	83.393535999999997	52.75244	52.735686999999999	0103000020E61000000100000005000000A25EF0694ED75440D28BDAFD2A5E4A40A25EF0694ED75440E31934F44F604A401D739EB12FD95440E31934F44F604A401D739EB12FD95440D28BDAFD2A5E4A40A25EF0694ED75440D28BDAFD2A5E4A40
11911	Фунтики	5	47	1154	83.001178999999993	83.071085999999994	52.80039	52.771453000000001	0103000020E61000000100000005000000499C155113C0544057B3CEF8BE624A40499C155113C05440D105F52D73664A40054D4BAC8CC45440D105F52D73664A40054D4BAC8CC4544057B3CEF8BE624A40499C155113C0544057B3CEF8BE624A40
11589	Труд	5	47	1154	83.208806999999993	83.230860000000007	52.884399000000002	52.871850000000002	0103000020E61000000100000005000000410B09185DCD54404182E2C7986F4A40410B09185DCD5440BCCE86FC33714A40187D0569C6CE5440BCCE86FC33714A40187D0569C6CE54404182E2C7986F4A40410B09185DCD54404182E2C7986F4A40
10885	Топчиха	5	47	1154	83.080348000000001	83.144137000000001	52.838887	52.795037000000001	0103000020E610000001000000050000002313F06B24C55440130EBDC5C3654A402313F06B24C55440100533A6606B4A403049658A39C95440100533A6606B4A403049658A39C95440130EBDC5C3654A402313F06B24C55440130EBDC5C3654A40
11197	Топольный	5	47	1154	83.254638999999997	83.268832000000003	52.471972999999998	52.463403	0103000020E61000000100000005000000505260014CD0544024EF1CCA503B4A40505260014CD0544029CC7B9C693C4A409207228B34D1544029CC7B9C693C4A409207228B34D1544024EF1CCA503B4A40505260014CD0544024EF1CCA503B4A40
11895	Сидоровка	5	47	1154	82.977095000000006	83.004655999999997	53.003574999999998	52.990448000000001	0103000020E61000000100000005000000738577B988BE5440BE310400C77E4A40738577B988BE5440A60A462575804A40BBEEAD484CC05440A60A462575804A40BBEEAD484CC05440BE310400C77E4A40738577B988BE5440BE310400C77E4A40
11833	Покровка	5	47	1154	83.369488000000004	83.393580999999998	52.719118999999999	52.706947999999997	0103000020E61000000100000005000000ED10FFB0A5D754407EFCA5457D5A4A40ED10FFB0A5D75440537765170C5C4A40EDD45C6E30D95440537765170C5C4A40EDD45C6E30D954407EFCA5457D5A4A40ED10FFB0A5D754407EFCA5457D5A4A40
11625	Победим	5	47	1154	82.990883999999994	83.012049000000005	52.668404000000002	52.656584000000002	0103000020E610000001000000050000004C88B9A46ABF5440D789CBF10A544A404C88B9A46ABF5440FF4124438E554A40C53C2B69C5C05440FF4124438E554A40C53C2B69C5C05440D789CBF10A544A404C88B9A46ABF5440D789CBF10A544A40
11497	Песчаное	5	47	1154	82.485016000000002	82.522925000000001	52.797024999999998	52.784412000000003	0103000020E610000001000000050000005A828C800A9F5440844BC79C67644A405A828C800A9F5440158C4AEA04664A40B1506B9A77A15440158C4AEA04664A40B1506B9A77A15440844BC79C67644A405A828C800A9F5440844BC79C67644A40
11541	Переяславка	5	47	1154	83.086402000000007	83.117637000000002	52.890690999999997	52.872703000000001	0103000020E61000000100000005000000C713419C87C55440800F5EBBB46F4A40C713419C87C55440B7EBA52902724A402CF3565D87C75440B7EBA52902724A402CF3565D87C75440800F5EBBB46F4A40C713419C87C55440800F5EBBB46F4A40
11451	Парфеново	5	47	1154	82.696011999999996	82.766557000000006	52.820360999999998	52.797508999999998	0103000020E61000000100000005000000E867EA758BAC544001A260C614664A40E867EA758BAC5440F9F4D89601694A40466117450FB15440F9F4D89601694A40466117450FB1544001A260C614664A40E867EA758BAC544001A260C614664A40
11418	Макарьевка	5	47	1154	83.026214999999993	83.052014999999997	52.879474999999999	52.866767000000003	0103000020E6100000010000000500000089EAAD81ADC1544043209738F26E4A4089EAAD81ADC15440265305A392704A40B1F9B83654C35440265305A392704A40B1F9B83654C3544043209738F26E4A4089EAAD81ADC1544043209738F26E4A40
11352	Листвянка	5	47	1154	83.946844999999996	84.006474999999995	52.759127999999997	52.747076999999997	0103000020E610000001000000050000006458C51B99FC5440014C1938A05F4A406458C51B99FC54402BBD361B2B614A40764F1E166A0055402BBD361B2B614A40764F1E166A005540014C1938A05F4A406458C51B99FC5440014C1938A05F4A40
11296	Красноярка	5	47	1154	83.452313000000004	83.483870999999994	52.760305000000002	52.747807000000002	0103000020E6100000010000000500000090A339B2F2DC5440255CC823B85F4A4090A339B2F2DC54401EFE9AAC51614A40E61E12BEF7DE54401EFE9AAC51614A40E61E12BEF7DE5440255CC823B85F4A4090A339B2F2DC5440255CC823B85F4A40
11746	Колпаково	5	47	1154	83.020932999999999	83.042996000000002	52.628711000000003	52.608010999999998	0103000020E610000001000000050000000F9A5DF756C15440DB4DF04DD34D4A400F9A5DF756C1544057D11F9A79504A40F7764B72C0C2544057D11F9A79504A40F7764B72C0C25440DB4DF04DD34D4A400F9A5DF756C15440DB4DF04DD34D4A40
11260	Ключи	5	47	1154	83.381058999999993	83.401072999999997	52.624217000000002	52.612129000000003	0103000020E610000001000000050000002CB6494563D8544073F7393E5A4E4A402CB6494563D85440BA4DB857E64F4A40C093162EABD95440BA4DB857E64F4A40C093162EABD9544073F7393E5A4E4A402CB6494563D8544073F7393E5A4E4A40
59401	Кировскаий	5	47	1154	83.153739999999999	83.177499999999995	52.557478000000003	52.537654000000003	0103000020E6100000010000000500000092054CE0D6C954402448A5D8D1444A4092054CE0D6C95440A81E69705B474A408FC2F5285CCB5440A81E69705B474A408FC2F5285CCB54402448A5D8D1444A4092054CE0D6C954402448A5D8D1444A40
11132	Зимино	5	47	1154	83.133357000000004	83.182485999999997	52.638635999999998	52.613332	0103000020E61000000100000005000000556CCCEB88C854408ECBB8A9814E4A40556CCCEB88C854402D060FD3BE514A40957EC2D9ADCB54402D060FD3BE514A40957EC2D9ADCB54408ECBB8A9814E4A40556CCCEB88C854408ECBB8A9814E4A40
11694	Зеленый	5	47	1154	82.968677999999997	82.985017999999997	52.691383999999999	52.676507000000001	0103000020E61000000100000005000000B39602D2FEBD5440EE4108C897564A40B39602D2FEBD5440247D5A457F584A402AFEEF880ABF5440247D5A457F584A402AFEEF880ABF5440EE4108C897564A40B39602D2FEBD5440EE4108C897564A40
11789	Дружба	5	47	1154	83.045124999999999	83.067905999999994	52.699891999999998	52.680864	0103000020E61000000100000005000000D9CEF753E3C254400A83328D26574A40D9CEF753E3C25440B35DA10F96594A40F04C689258C45440B35DA10F96594A40F04C689258C454400A83328D26574A40D9CEF753E3C254400A83328D26574A40
11088	Володарка	5	47	1154	83.601218000000003	83.637608999999998	52.727392999999999	52.695548000000002	0103000020E610000001000000050000000FF10F5B7AE654402C6684B707594A400FF10F5B7AE654406F2BBD361B5D4A40A8A8FA95CEE854406F2BBD361B5D4A40A8A8FA95CEE854402C6684B707594A400FF10F5B7AE654402C6684B707594A40
11014	Белояровка	5	47	1154	83.149553999999995	83.181551999999996	52.775730000000003	52.765051	0103000020E610000001000000050000001ABFF04A92C95440D462F030ED614A401ABFF04A92C954405743E21E4B634A407FA1478C9ECB54405743E21E4B634A407FA1478C9ECB5440D462F030ED614A401ABFF04A92C95440D462F030ED614A40
10453	Шумиха	5	47	1119	85.988355999999996	86.004300999999998	53.622275000000002	53.613505000000004	0103000020E610000001000000050000008B338639417F55405C77F35487CE4A408B338639417F5540280F0BB5A6CF4A40C495B37746805540280F0BB5A6CF4A40C495B377468055405C77F35487CE4A408B338639417F55405C77F35487CE4A40
10712	Уксунай	5	47	1119	86.002180999999993	86.026381999999998	53.504516000000002	53.487518999999999	0103000020E610000001000000050000000BEBC6BB23805540DD96C80567BE4A400BEBC6BB238055408527F4FA93C04A40FFCC203EB08155408527F4FA93C04A40FFCC203EB0815540DD96C80567BE4A400BEBC6BB23805540DD96C80567BE4A40
10662	Топтушка	5	47	1119	86.084160999999995	86.107212000000004	53.377811999999999	53.369731999999999	0103000020E6100000010000000500000050A6D1E4628555407024D06053AF4A4050A6D1E462855540A704C4245CB04A40486FB88FDC865540A704C4245CB04A40486FB88FDC8655407024D06053AF4A4050A6D1E4628555407024D06053AF4A40
10158	Тогул	5	47	1119	85.883505	85.936702999999994	53.485982	53.449719999999999	0103000020E610000001000000050000008F368E588B785540B62DCA6C90B94A408F368E588B785540EB387EA834BE4A402AC423F1F27B5540EB387EA834BE4A402AC423F1F27B5540B62DCA6C90B94A408F368E588B785540B62DCA6C90B94A40
10439	Титово	5	47	1119	85.749206000000001	85.770370999999997	53.418320999999999	53.405585000000002	0103000020E61000000100000005000000E3FDB8FDF26F5540C45F9335EAB34A40E3FDB8FDF26F5540711DE38A8BB54A405BB22AC24D715540711DE38A8BB54A405BB22AC24D715540C45F9335EAB34A40E3FDB8FDF26F5540C45F9335EAB34A40
10728	Старый Тогул	5	47	1119	85.880621000000005	85.912880000000001	53.443300000000001	53.419497	0103000020E61000000100000005000000EFCA2E185C78554093E2E313B2B54A40EFCA2E185C7855408D28ED0DBEB84A400A4B3CA06C7A55408D28ED0DBEB84A400A4B3CA06C7A554093E2E313B2B54A40EFCA2E185C78554093E2E313B2B54A40
10535	Новоиушино	5	47	1119	85.800787999999997	85.825429	53.643450000000001	53.619781000000003	0103000020E61000000100000005000000DFC14F1C4073554052D7DAFB54CF4A40DFC14F1C407355403C4ED1915CD24A40E10A28D4D37455403C4ED1915CD24A40E10A28D4D374554052D7DAFB54CF4A40DFC14F1C4073554052D7DAFB54CF4A40
10365	Льнозавод	5	47	1119	85.947149999999993	85.956601000000006	53.462223000000002	53.453200000000002	0103000020E61000000100000005000000029A081B9E7C55400B46257502BA4A40029A081B9E7C5540C13A8E1F2ABB4A408A9466F3387D5540C13A8E1F2ABB4A408A9466F3387D55400B46257502BA4A40029A081B9E7C55400B46257502BA4A40
10825	Колонково	5	47	1119	85.861918000000003	85.879228999999995	53.332611999999997	53.321990999999997	0103000020E610000001000000050000005C751DAA297755409C4D470037A94A405C751DAA29775540EA20AF0793AA4A40772CB64945785540EA20AF0793AA4A40772CB649457855409C4D470037A94A405C751DAA297755409C4D470037A94A40
59452	Верх-Коптелка	5	47	1119	86.182508999999996	86.198535000000007	53.472810000000003	53.461703	0103000020E61000000100000005000000718E3A3AAE8B554088BB7A1519BB4A40718E3A3AAE8B5540639CBF0985BC4A40210725CCB48C5540639CBF0985BC4A40210725CCB48C554088BB7A1519BB4A40718E3A3AAE8B554088BB7A1519BB4A40
10857	Бураново	5	47	1119	85.795074	85.824242999999996	53.39969	53.374712000000002	0103000020E6100000010000000500000098F90E7EE27255409AB51490F6AF4A4098F90E7EE2725540E544BB0A29B34A403E3DB665C0745540E544BB0A29B34A403E3DB665C07455409AB51490F6AF4A4098F90E7EE27255409AB51490F6AF4A40
10741	Антипино	5	47	1119	85.828528000000006	85.85369	53.316606	53.286180999999999	0103000020E6100000010000000500000080F44D9A0675554048DE3994A1A44A4080F44D9A06755540D3DB9F8B86A84A4006BB61DBA2765540D3DB9F8B86A84A4006BB61DBA276554048DE3994A1A44A4080F44D9A0675554048DE3994A1A44A40
59384	станция Озерки	5	47	975	83.625392000000005	83.757192000000003	53.708964999999999	53.630696	0103000020E6100000010000000500000086CB2A6C06E85440E8DB82A5BAD04A4086CB2A6C06E854401B81785DBFDA4A40BE326FD575F054401B81785DBFDA4A40BE326FD575F05440E8DB82A5BAD04A4086CB2A6C06E85440E8DB82A5BAD04A40
9474	Язово	5	47	975	83.166739000000007	83.201468000000006	53.604204000000003	53.580827999999997	0103000020E61000000100000005000000F0FD0DDAABCA5440F04C689258CA4A40F0FD0DDAABCA5440630E828E56CD4A4032CC09DAE4CC5440630E828E56CD4A4032CC09DAE4CC5440F04C689258CA4A40F0FD0DDAABCA5440F04C689258CA4A40
9423	Шишкино	5	47	975	83.213172999999998	83.231965000000002	53.643433999999999	53.624901999999999	0103000020E61000000100000005000000F9D85DA0A4CD54403D9AEAC9FCCF4A40F9D85DA0A4CD54403691990B5CD24A404434BA83D8CE54403691990B5CD24A404434BA83D8CE54403D9AEAC9FCCF4A40F9D85DA0A4CD54403D9AEAC9FCCF4A40
8659	Шипицыно	5	47	975	83.110881000000006	83.136105999999998	53.617109999999997	53.598075000000001	0103000020E61000000100000005000000DC2F9FAC18C7544011C7BAB88DCC4A40DC2F9FAC18C754406C04E275FDCE4A4085B2F0F5B5C854406C04E275FDCE4A4085B2F0F5B5C8544011C7BAB88DCC4A40DC2F9FAC18C7544011C7BAB88DCC4A40
9351	Шадринцево	5	47	975	83.943961000000002	83.979651000000004	53.953842000000002	53.937626000000002	0103000020E61000000100000005000000C4EC65DB69FC54408DF0F62004F84A40C4EC65DB69FC54408FC6A17E17FA4A40999F1B9AB2FE54408FC6A17E17FA4A40999F1B9AB2FE54408DF0F62004F84A40C4EC65DB69FC54408DF0F62004F84A40
8983	Таскаево	5	47	975	83.672354999999996	83.694767999999996	53.865456999999999	53.848723	0103000020E61000000100000005000000551344DD07EB5440772E8CF4A2EC4A40551344DD07EB5440118C834BC7EE4A40AB93331477EC5440118C834BC7EE4A40AB93331477EC5440772E8CF4A2EC4A40551344DD07EB5440772E8CF4A2EC4A40
9490	Тальменка	5	47	975	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
9348	Староперуново	5	47	975	83.450767999999997	83.476954000000006	53.779974000000003	53.764563000000003	0103000020E6100000010000000500000055850662D9DC5440A75D4C33DDE14A4055850662D9DC54407BDD2230D6E34A4092EC116A86DE54407BDD2230D6E34A4092EC116A86DE5440A75D4C33DDE14A4055850662D9DC5440A75D4C33DDE14A40
9287	Среднесибирский	5	47	975	83.625355999999996	83.656806000000003	53.766240000000003	53.734026999999998	0103000020E61000000100000005000000DF162CD505E85440C4B0C398F4DD4A40DF162CD505E854408B71FE2614E24A404374081C09EA54408B71FE2614E24A404374081C09EA5440C4B0C398F4DD4A40DF162CD505E85440C4B0C398F4DD4A40
8606	Сандалово	5	47	975	83.000236000000001	83.014519000000007	53.749285	53.739753	0103000020E610000001000000050000000A12DBDD03C05440170FEF39B0DE4A400A12DBDD03C0544012312592E8DF4A40EC8A19E1EDC0544012312592E8DF4A40EC8A19E1EDC05440170FEF39B0DE4A400A12DBDD03C05440170FEF39B0DE4A40
9230	Речкуново	5	47	975	83.333250000000007	83.349671999999998	53.502876999999998	53.490391000000002	0103000020E6100000010000000500000017D9CEF753D554405AA0DD21C5BE4A4017D9CEF753D554408E7406465EC04A40EC14AB0661D654408E7406465EC04A40EC14AB0661D654405AA0DD21C5BE4A4017D9CEF753D554405AA0DD21C5BE4A40
9045	Озерки	5	47	975	83.684438	83.726623000000004	53.640236999999999	53.615155000000001	0103000020E61000000100000005000000F0880AD5CDEB5440467C2766BDCE4A40F0880AD5CDEB544036583849F3D14A405F61C1FD80EE544036583849F3D14A405F61C1FD80EE5440467C2766BDCE4A40F0880AD5CDEB5440467C2766BDCE4A40
8927	Новотроицк	5	47	975	83.713488999999996	83.759276	53.906793	53.883451999999998	0103000020E610000001000000050000009143C4CDA9ED5440FBCA83F414F14A409143C4CDA9ED5440F19E03CB11F44A40D0285DFA97F05440F19E03CB11F44A40D0285DFA97F05440FBCA83F414F14A409143C4CDA9ED5440FBCA83F414F14A40
8876	Новоперуново	5	47	975	83.486340999999996	83.521428999999998	53.888897	53.861856000000003	0103000020E610000001000000050000000D6D003620DF544042EE224C51EE4A400D6D003620DF54409A417C60C7F14A40E78BBD175FE154409A417C60C7F14A40E78BBD175FE1544042EE224C51EE4A400D6D003620DF544042EE224C51EE4A40
8524	Новоеловка	5	47	975	83.310666999999995	83.340301999999994	53.919611000000003	53.901201999999998	0103000020E61000000100000005000000923CD7F7E1D354407E8B4E965AF34A40923CD7F7E1D354405C0531D0B5F54A40DB300A82C7D554405C0531D0B5F54A40DB300A82C7D554407E8B4E965AF34A40923CD7F7E1D354407E8B4E965AF34A40
8454	Наумово	5	47	975	83.565770000000001	83.588363000000001	53.786639999999998	53.774285999999996	0103000020E61000000100000005000000B5C35F9335E4544015E0BBCD1BE34A40B5C35F9335E45440DBDC989EB0E44A404BCB48BDA7E55440DBDC989EB0E44A404BCB48BDA7E5544015E0BBCD1BE34A40B5C35F9335E4544015E0BBCD1BE34A40
8794	Лушниково	5	47	975	83.506302000000005	83.529567999999998	54.03275	54.003675000000001	0103000020E6100000010000000500000090F9804067E054400A68226C78004B4090F9804067E05440D578E92631044B4085402E71E4E15440D578E92631044B4085402E71E4E154400A68226C78004B4090F9804067E054400A68226C78004B40
8731	Луговое	5	47	975	83.595388	83.646915000000007	53.801490000000001	53.782735000000002	0103000020E61000000100000005000000931B45D61AE65440A03715A930E44A40931B45D61AE6544018096D3997E64A40AE122C0E67E9544018096D3997E64A40AE122C0E67E95440A03715A930E44A40931B45D61AE65440A03715A930E44A40
27730	Лесная Поляна	5	47	975	83.707480000000004	83.724520999999996	53.574235999999999	53.566135000000003	0103000020E61000000100000005000000BEA4315A47ED54407C0F971C77C84A40BEA4315A47ED5440CA17B49080C94A40F910548D5EEE5440CA17B49080C94A40F910548D5EEE54407C0F971C77C84A40BEA4315A47ED54407C0F971C77C84A40
8577	Ларичиха	5	47	975	83.022281000000007	83.063395999999997	53.77816	53.765999999999998	0103000020E610000001000000050000009F94490D6DC15440355EBA490CE24A409F94490D6DC15440168733BF9AE34A409FAC18AE0EC45440168733BF9AE34A409FAC18AE0EC45440355EBA490CE24A409F94490D6DC15440355EBA490CE24A40
8459	Курочкино	5	47	975	83.309741000000002	83.343608000000003	53.888737999999996	53.850141000000001	0103000020E61000000100000005000000BE4EEACBD2D354408FFE976BD1EC4A40BE4EEACBD2D35440315BB22AC2F14A4037A968ACFDD55440315BB22AC2F14A4037A968ACFDD554408FFE976BD1EC4A40BE4EEACBD2D354408FFE976BD1EC4A40
8838	Кошелево	5	47	975	83.517908000000006	83.537985000000006	53.971307000000003	53.956878000000003	0103000020E610000001000000050000008E95986725E15440862172FA7AFA4A408E95986725E154401DB0ABC953FC4A40452FA3586EE254401DB0ABC953FC4A40452FA3586EE25440862172FA7AFA4A408E95986725E15440862172FA7AFA4A40
8371	Кашкарагаиха	5	47	975	83.445351000000002	83.501728999999997	53.737580000000001	53.717992000000002	0103000020E610000001000000050000006B0F7BA180DC544013656F29E7DB4A406B0F7BA180DC544083177D0569DE4A401B9DF3531CE0544083177D0569DE4A401B9DF3531CE0544013656F29E7DB4A406B0F7BA180DC544013656F29E7DB4A40
8366	Казанцево	5	47	975	83.251917000000006	83.298323999999994	54.038915000000003	54.007829000000001	0103000020E610000001000000050000009D137B681FD05440EE7A698A00014B409D137B681FD054407429AE2AFB044B4029E78BBD17D354407429AE2AFB044B4029E78BBD17D35440EE7A698A00014B409D137B681FD05440EE7A698A00014B40
8295	Зайцево	5	47	975	83.305097000000004	83.335684999999998	53.702553000000002	53.677748000000001	0103000020E61000000100000005000000E54691B586D35440F7764B72C0D64A40E54691B586D35440755AB741EDD94A407F30F0DC7BD55440755AB741EDD94A407F30F0DC7BD55440F7764B72C0D64A40E54691B586D35440F7764B72C0D64A40
8222	Загайново	5	47	975	83.785551999999996	83.860399999999998	54.086342999999999	54.051513	0103000020E61000000100000005000000AC53E57B46F25440D0285DFA97064B40AC53E57B46F25440889E94490D0B4B409E5E29CB10F75440889E94490D0B4B409E5E29CB10F75440D0285DFA97064B40AC53E57B46F25440D0285DFA97064B40
8201	Забродино	5	47	975	83.659321000000006	83.672507999999993	53.811114000000003	53.797879000000002	0103000020E610000001000000050000003A24B55032EA5440259529E620E64A403A24B55032EA5440F4A96395D2E74A401893FE5E0AEB5440F4A96395D2E74A401893FE5E0AEB5440259529E620E64A403A24B55032EA5440259529E620E64A40
8746	Выползово	5	47	975	83.723928000000001	83.752189000000001	53.853555999999998	53.831556999999997	0103000020E61000000100000005000000282A1BD654EE544043E1B37570EA4A40282A1BD654EE5440FCA6B05241ED4A404DDA54DD23F05440FCA6B05241ED4A404DDA54DD23F0544043E1B37570EA4A40282A1BD654EE544043E1B37570EA4A40
9209	Восточный	5	47	975	83.813077000000007	83.829480000000004	53.735162000000003	53.727336999999999	0103000020E610000001000000050000004F081D7409F45440DB15FA6019DD4A404F081D7409F4544088A1D5C919DE4A40E92B483316F5544088A1D5C919DE4A40E92B483316F55440DB15FA6019DD4A404F081D7409F45440DB15FA6019DD4A40
8144	Анисимово	5	47	975	83.591103000000004	83.641893999999994	54.041110000000003	54.003860000000003	0103000020E610000001000000050000005264ADA1D4E554409CE1067C7E004B405264ADA1D4E55440F0C4AC1743054B40E95F92CA14E95440F0C4AC1743054B40E95F92CA14E954409CE1067C7E004B405264ADA1D4E554409CE1067C7E004B40
7869	Хорошее	5	47	918	79.205670999999995	79.218382000000005	52.946067999999997	52.934095999999997	0103000020E6100000010000000500000014AFB2B629CD534086A92D7590774A4014AFB2B629CD534064E597C118794A403F027FF8F9CD534064E597C118794A403F027FF8F9CD534086A92D7590774A4014AFB2B629CD534086A92D7590774A40
7774	Успенка	5	47	918	79.335002000000003	79.353965000000002	52.932191000000003	52.917870000000001	0103000020E610000001000000050000000E863AAC70D5534061FD9FC37C754A400E863AAC70D553401250E10852774A406FBBD05CA7D653401250E10852774A406FBBD05CA7D6534061FD9FC37C754A400E863AAC70D5534061FD9FC37C754A40
7441	Удальное	5	47	918	78.852920999999995	78.870788000000005	52.823653	52.815342999999999	0103000020E610000001000000050000009544F64196B65340E202D0285D684A409544F64196B653404B2025766D694A40F46F97FDBAB753404B2025766D694A40F46F97FDBAB75340E202D0285D684A409544F64196B65340E202D0285D684A40
7304	Табуны	5	47	918	78.762513999999996	78.803145000000001	52.787712999999997	52.757651000000003	0103000020E610000001000000050000007F2F8507CDB053400F643DB5FA604A407F2F8507CDB0534028D192C7D3644A408A3C49BA66B3534028D192C7D3644A408A3C49BA66B353400F643DB5FA604A407F2F8507CDB053400F643DB5FA604A40
7693	Сереброполь	5	47	918	79.187939	79.220124999999996	52.889952000000001	52.880991999999999	0103000020E6100000010000000500000026A94C3107CC5340D1048A58C4704A4026A94C3107CC5340418177F2E9714A400C022B8716CE5340418177F2E9714A400C022B8716CE5340D1048A58C4704A4026A94C3107CC5340D1048A58C4704A40
7746	Саратовка	5	47	918	79.111949999999993	79.130267000000003	52.882888000000001	52.876291000000002	0103000020E61000000100000005000000613255302AC75340BB63B14D2A704A40613255302AC75340F303577902714A40E02F664B56C85340F303577902714A40E02F664B56C85340BB63B14D2A704A40613255302AC75340BB63B14D2A704A40
7378	Самбор	5	47	918	78.889365999999995	78.896247000000002	52.782158000000003	52.765993999999999	0103000020E61000000100000005000000280B5F5FEBB85340537765170C624A40280B5F5FEBB853400327DBC01D644A40D788601C5CB953400327DBC01D644A40D788601C5CB95340537765170C624A40280B5F5FEBB85340537765170C624A40
16383	Орловка	5	47	918	78.582033999999993	78.603566999999998	52.615879999999997	52.606349000000002	0103000020E610000001000000050000003ECA880B40A553402D7B12D89C4D4A403ECA880B40A553405721E527D54E4A40787C7BD7A0A653405721E527D54E4A40787C7BD7A0A653402D7B12D89C4D4A403ECA880B40A553402D7B12D89C4D4A40
7588	Новокиевка	5	47	918	78.709019999999995	78.725269999999995	52.736804999999997	52.729748999999998	0103000020E610000001000000050000006F0D6C9560AD5340F4A44C6A685D4A406F0D6C9560AD5340BF4351A04F5E4A4046B1DCD26AAE5340BF4351A04F5E4A4046B1DCD26AAE5340F4A44C6A685D4A406F0D6C9560AD5340F4A44C6A685D4A40
7851	Николаевка	5	47	918	79.116864000000007	79.127274999999997	52.952612000000002	52.942290999999997	0103000020E610000001000000050000001B8524B37AC753405628D2FD9C784A401B8524B37AC753407AE3A430EF794A404CA60A4625C853407AE3A430EF794A404CA60A4625C853405628D2FD9C784A401B8524B37AC753405628D2FD9C784A40
8020	Лебедино	5	47	918	79.284048999999996	79.307432000000006	52.792625000000001	52.779406999999999	0103000020E61000000100000005000000895DDBDB2DD2534001A3CB9BC3634A40895DDBDB2DD25340FA7E6ABC74654A409C6F44F7ACD35340FA7E6ABC74654A409C6F44F7ACD3534001A3CB9BC3634A40895DDBDB2DD2534001A3CB9BC3634A40
7968	Канны	5	47	918	78.866405	78.879312999999996	52.896830000000001	52.889045000000003	0103000020E61000000100000005000000D105F52D73B753400FD6FF39CC714A40D105F52D73B753402D095053CB724A40A67C08AA46B853402D095053CB724A40A67C08AA46B853400FD6FF39CC714A40D105F52D73B753400FD6FF39CC714A40
7663	Камышенка	5	47	918	78.431017999999995	78.452181999999993	52.763117000000001	52.753242	0103000020E61000000100000005000000307F85CC959B5340A0FCDD3B6A604A40307F85CC959B5340C5025FD1AD614A40C075C58CF09C5340C5025FD1AD614A40C075C58CF09C5340A0FCDD3B6A604A40307F85CC959B5340A0FCDD3B6A604A40
7489	Забавное	5	47	918	78.780319000000006	78.797754999999995	52.834688	52.822254999999998	0103000020E61000000100000005000000A35C1ABFF0B153407AFCDEA63F694A40A35C1ABFF0B153408C2E6F0ED76A4A401CCEFC6A0EB353408C2E6F0ED76A4A401CCEFC6A0EB353407AFCDEA63F694A40A35C1ABFF0B153407AFCDEA63F694A40
7934	Большеромановка	5	47	918	78.839949000000004	78.873554999999996	53.005932000000001	52.984533999999996	0103000020E61000000100000005000000B55373B9C1B5534068E6C935057E4A40B55373B9C1B55340FCFF3861C2804A4077103B53E8B75340FCFF3861C2804A4077103B53E8B7534068E6C935057E4A40B55373B9C1B5534068E6C935057E4A40
7512	Алтайское	5	47	918	78.745751999999996	78.772009999999995	52.792963	52.778170000000003	0103000020E610000001000000050000004DBB9866BAAF53403A5D16139B634A404DBB9866BAAF534012F8C3CF7F654A40D68BA19C68B1534012F8C3CF7F654A40D68BA19C68B153403A5D16139B634A404DBB9866BAAF53403A5D16139B634A40
7597	Александровка	5	47	918	78.686733000000004	78.706100000000006	52.719692000000002	52.708627999999997	0103000020E610000001000000050000006005F86EF3AB5340D3838252B45A4A406005F86EF3AB5340AF9811DE1E5C4A4029ED0DBE30AD5340AF9811DE1E5C4A4029ED0DBE30AD5340D3838252B45A4A406005F86EF3AB5340D3838252B45A4A40
7055	имени Владимира Ильича	5	47	900	79.704650000000001	79.716318999999999	53.241529999999997	53.231758999999997	0103000020E61000000100000005000000174850FC18ED5340DEC66647AA9D4A40174850FC18ED53405E807D74EA9E4A4038A0A52BD8ED53405E807D74EA9E4A4038A0A52BD8ED5340DEC66647AA9D4A40174850FC18ED5340DEC66647AA9D4A40
7243	Осиновский	5	47	900	80.015079999999998	80.032049999999998	53.256525000000003	53.248578000000002	0103000020E61000000100000005000000B7B41A12F7005440A7406667D19F4A40B7B41A12F70054409FCDAACFD5A04A408E75711B0D0254409FCDAACFD5A04A408E75711B0D025440A7406667D19F4A40B7B41A12F7005440A7406667D19F4A40
7206	Октябрьский	5	47	900	79.916886000000005	79.931025000000005	53.325679999999998	53.313341000000001	0103000020E61000000100000005000000420A9E42AEFA53407BBFD18E1BA84A40420A9E42AEFA53400B7BDAE1AFA94A408AB0E1E995FB53400B7BDAE1AFA94A408AB0E1E995FB53407BBFD18E1BA84A40420A9E42AEFA53407BBFD18E1BA84A40
7161	Нижняя Суетка	5	47	900	79.872617000000005	79.918152000000006	53.232275999999999	53.212479999999999	0103000020E61000000100000005000000C13BF9F4D8F75340EC866D8B329B4A40C13BF9F4D8F75340A6D24F38BB9D4A4073309B00C3FA5340A6D24F38BB9D4A4073309B00C3FA5340EC866D8B329B4A40C13BF9F4D8F75340EC866D8B329B4A40
31655	Мельниковка	5	47	900	79.950878000000003	79.968844000000004	53.157921000000002	53.144689999999997	0103000020E61000000100000005000000191F662FDBFC53407407B13385924A40191F662FDBFC5340022D5DC136944A4041BB438A01FE5340022D5DC136944A4041BB438A01FE53407407B13385924A40191F662FDBFC53407407B13385924A40
7000	Верхняя Суетка	5	47	900	80.026004	80.069940000000003	53.321258999999998	53.283903000000002	0103000020E610000001000000050000002C64AE0CAA0154403F1EFAEE56A44A402C64AE0CAA015440D845D1031FA94A40AA2B9FE579045440D845D1031FA94A40AA2B9FE5790454403F1EFAEE56A44A402C64AE0CAA0154403F1EFAEE56A44A40
6967	Боронск	5	47	900	80.081214000000003	80.098561000000004	53.177073	53.165652000000001	0103000020E610000001000000050000008D7E349C320554402D42B11534954A408D7E349C320554409700FC53AA964A404FEACBD24E0654409700FC53AA964A404FEACBD24E0654402D42B11534954A408D7E349C320554402D42B11534954A40
59454	Шатабол	5	47	513	86.550709999999995	86.564158000000006	52.862189999999998	52.855741000000002	0103000020E6100000010000000500000021E527D53EA35540556CCCEB886D4A4021E527D53EA355401878EE3D5C6E4A40B7F1272A1BA455401878EE3D5C6E4A40B7F1272A1BA45540556CCCEB886D4A4021E527D53EA35540556CCCEB886D4A40
6566	Усть-Куют	5	47	513	86.629779999999997	86.653765000000007	52.531677999999999	52.522374999999997	0103000020E6100000010000000500000031EBC5504EA85540BE9F1A2FDD424A4031EBC5504EA85540580053060E444A403F912749D7A95540580053060E444A403F912749D7A95540BE9F1A2FDD424A4031EBC5504EA85540BE9F1A2FDD424A40
6668	Урунск	5	47	513	86.524092999999993	86.543307999999996	52.898834000000001	52.879964999999999	0103000020E6100000010000000500000000C45DBD8AA15540F44F70B1A2704A4000C45DBD8AA15540354415FE0C734A40EEE9EA8EC5A25540354415FE0C734A40EEE9EA8EC5A25540F44F70B1A2704A4000C45DBD8AA15540F44F70B1A2704A40
6861	Тосток	5	47	513	86.517437000000001	86.538269	52.752822000000002	52.741134000000002	0103000020E61000000100000005000000622F14B01DA1554012FA997ADD5E4A40622F14B01DA15540CBDAA6785C604A40D7DCD1FF72A25540CBDAA6785C604A40D7DCD1FF72A2554012FA997ADD5E4A40622F14B01DA1554012FA997ADD5E4A40
6803	Сузоп	5	47	513	86.615658999999994	86.641647000000006	52.791639000000004	52.770553999999997	0103000020E610000001000000050000003C9F01F566A75540A7E67283A1624A403C9F01F566A755407C9E3F6D54654A40E62494BE10A955407C9E3F6D54654A40E62494BE10A95540A7E67283A1624A403C9F01F566A75540A7E67283A1624A40
3147	Солтон	5	47	513	86.457967999999994	86.492311000000001	52.856746999999999	52.818978999999999	0103000020E6100000010000000500000054A703594F9D55402E8ECA4DD4684A4054A703594F9D55401AF9BCE2A96D4A40821DFF05829F55401AF9BCE2A96D4A40821DFF05829F55402E8ECA4DD4684A4054A703594F9D55402E8ECA4DD4684A40
6511	Сайдып	5	47	513	86.564876999999996	86.578792000000007	52.582607000000003	52.556787999999997	0103000020E61000000100000005000000CE50DCF126A45540126745D444474A40CE50DCF126A45540D9B5BDDD924A4A40EFCB99ED0AA55540D9B5BDDD924A4A40EFCB99ED0AA55540126745D444474A40CE50DCF126A45540126745D444474A40
32835	Новотроицк	5	47	513	86.730867000000003	86.751644999999996	52.794139000000001	52.786563999999998	0103000020E6100000010000000500000071AE6186C6AE5540001B1021AE644A4071AE6186C6AE554034BDC458A6654A40EC4CA1F31AB0554034BDC458A6654A40EC4CA1F31AB05540001B1021AE644A4071AE6186C6AE5540001B1021AE644A40
6339	Новая Ажинка	5	47	513	86.314965000000001	86.330344999999994	52.557194000000003	52.544483999999997	0103000020E610000001000000050000009E98F56228945540FE98D6A6B1454A409E98F5622894554083C30B2252474A406AD95A5F2495554083C30B2252474A406AD95A5F24955540FE98D6A6B1454A409E98F56228945540FE98D6A6B1454A40
6430	Нижняя Ненинка	5	47	513	86.384198999999995	86.421829000000002	52.743980000000001	52.717422999999997	0103000020E61000000100000005000000FA0967B796985540F8325184D45B4A40FA0967B796985540657094BC3A5F4A4048E00F3FFF9A5540657094BC3A5F4A4048E00F3FFF9A5540F8325184D45B4A40FA0967B796985540F8325184D45B4A40
6326	Ненинка	5	47	513	86.175061999999997	86.217534000000001	52.681781999999998	52.661861000000002	0103000020E610000001000000050000006E313F37348B5540BABF7ADCB7544A406E313F37348B55403080F0A144574A4028F1B913EC8D55403080F0A144574A4028F1B913EC8D5540BABF7ADCB7544A406E313F37348B5540BABF7ADCB7544A40
6263	Макарьевка	5	47	513	86.530659999999997	86.573239999999998	52.995348	52.986446999999998	0103000020E61000000100000005000000E7525C55F6A15540601E32E5437E4A40E7525C55F6A15540CB113290677F4A409430D3F6AFA45540CB113290677F4A409430D3F6AFA45540601E32E5437E4A40E7525C55F6A15540601E32E5437E4A40
6110	Караган	5	47	513	86.336471000000003	86.367445000000004	52.807059000000002	52.800503999999997	0103000020E610000001000000050000005B43A9BD88955540992842EA76664A405B43A9BD88955540A37895B54D674A400A85083884975540A37895B54D674A400A85083884975540992842EA76664A405B43A9BD88955540992842EA76664A40
6129	Карабинка	5	47	513	86.213194999999999	86.278602000000006	52.700242000000003	52.676720000000003	0103000020E61000000100000005000000ED2AA4FCA48D55404A46CEC29E564A40ED2AA4FCA48D554090A4A487A1594A406AA67B9DD491554090A4A487A1594A406AA67B9DD49155404A46CEC29E564A40ED2AA4FCA48D55404A46CEC29E564A40
6216	Излап	5	47	513	86.611868000000001	86.625720000000001	52.925905	52.904820000000001	0103000020E61000000100000005000000035E66D828A7554024624A24D1734A40035E66D828A75540F819170E84764A40001DE6CB0BA85540F819170E84764A40001DE6CB0BA8554024624A24D1734A40035E66D828A7554024624A24D1734A40
15514	Вознесенка	5	47	513	86.690533000000002	86.694764000000006	52.789597000000001	52.786895999999999	0103000020E61000000100000005000000C3F352B131AC554036AD1402B9644A40C3F352B131AC55408602B68311654A400B9C6C0377AC55408602B68311654A400B9C6C0377AC554036AD1402B9644A40C3F352B131AC554036AD1402B9644A40
6040	Березово	5	47	513	86.298328999999995	86.331207000000006	52.88767	52.876007999999999	0103000020E61000000100000005000000B29C84D2179355406684B70721704A40B29C84D217935540F6D1A92B9F714A40344DD87E32955540F6D1A92B9F714A40344DD87E329555406684B70721704A40B29C84D2179355406684B70721704A40
6489	Акатьево	5	47	513	86.451365999999993	86.468756999999997	52.77646	52.770026000000001	0103000020E61000000100000005000000AF21382EE39C5540EC88433690624A40AF21382EE39C55407A53910A63634A4059315C1D009E55407A53910A63634A4059315C1D009E5540EC88433690624A40AF21382EE39C5540EC88433690624A40
5028	Юртное	5	47	714	84.221279999999993	84.246225999999993	51.824044000000001	51.80424	0103000020E6100000010000000500000091D09673290E554049111956F1E6494091D09673290E5540863B17467AE94940315BB22AC20F5540863B17467AE94940315BB22AC20F554049111956F1E6494091D09673290E554049111956F1E64940
5206	Черемшанка	5	47	714	84.276157999999995	84.303439999999995	51.759090999999998	51.739241	0103000020E61000000100000005000000D7A19A92AC115540616EF7729FDE4940D7A19A92AC1155400ED8D5E429E1494016139B8F6B1355400ED8D5E429E1494016139B8F6B135540616EF7729FDE4940D7A19A92AC115540616EF7729FDE4940
5738	Туманово	5	47	714	84.637460000000004	84.659369999999996	51.607875999999997	51.584372000000002	0103000020E6100000010000000500000086200725CC2855405C59A2B3CCCA494086200725CC285540FB027AE1CECD4940AA7D3A1E332A5540FB027AE1CECD4940AA7D3A1E332A55405C59A2B3CCCA494086200725CC2855405C59A2B3CCCA4940
5944	Топольное	5	47	714	84.455444	84.513834000000003	51.520198000000001	51.499395999999997	0103000020E61000000100000005000000344A97FE251D554069E04735ECBF4940344A97FE251D5540E9B81AD995C24940AA6400A8E2205540E9B81AD995C24940AA6400A8E220554069E04735ECBF4940344A97FE251D554069E04735ECBF4940
5448	Тележиха	5	47	714	84.271675000000002	84.302964000000003	51.544167000000002	51.517933999999997	0103000020E6100000010000000500000003098A1F6311554044BE4BA94BC2494003098A1F63115540FE47A643A7C5494062F71DC363135540FE47A643A7C5494062F71DC36313554044BE4BA94BC2494003098A1F6311554044BE4BA94BC24940
5134	Тальменка	5	47	714	84.098202000000001	84.127082999999999	51.635196999999998	51.626536999999999	0103000020E61000000100000005000000B7990AF148065540F25D4A5D32D04940B7990AF14806554037C2A2224ED149402A38BC202208554037C2A2224ED149402A38BC2022085540F25D4A5D32D04940B7990AF148065540F25D4A5D32D04940
5880	Степное	5	47	714	84.609604000000004	84.631990000000002	51.511465999999999	51.491809000000003	0103000020E61000000100000005000000B1E07EC0032755407270E998F3BE4940B1E07EC0032755400A82C7B777C149408A592F86722855400A82C7B777C149408A592F86722855407270E998F3BE4940B1E07EC0032755407270E998F3BE4940
5236	Солонешное	5	47	714	84.267021999999997	84.343800999999999	51.673532999999999	51.637253999999999	0103000020E61000000100000005000000005471E316115540629F008A91D14940005471E3161155406DE34F5436D6494041D5E8D5001655406DE34F5436D6494041D5E8D500165540629F008A91D14940005471E316115540629F008A91D14940
5078	Сибирячиха	5	47	714	84.040108000000004	84.072573000000006	51.760139000000002	51.730612000000001	0103000020E61000000100000005000000B6132521910255405708ABB184DD4940B61325219102554003B5183C4CE14940A6643909A504554003B5183C4CE14940A6643909A50455405708ABB184DD4940B6132521910255405708ABB184DD4940
6001	Рыбное	5	47	714	84.404347999999999	84.420265999999998	51.386794999999999	51.377839999999999	0103000020E61000000100000005000000FE0C6FD6E0195540718FA50F5DB04940FE0C6FD6E0195540CFA0A17F82B14940BA675DA3E51A5540CFA0A17F82B14940BA675DA3E51A5540718FA50F5DB04940FE0C6FD6E0195540718FA50F5DB04940
5692	Новая Жизнь	5	47	714	84.688242000000002	84.695589999999996	51.704090999999998	51.697761	0103000020E61000000100000005000000F46E2C280C2C55404EB6813B50D94940F46E2C280C2C5540373465A71FDA49402D5BEB8B842C5540373465A71FDA49402D5BEB8B842C55404EB6813B50D94940F46E2C280C2C55404EB6813B50D94940
5535	Лютаево	5	47	714	84.403970000000001	84.442965999999998	51.894973	51.875695	0103000020E610000001000000050000002BA4FCA4DA195540A72215C616F049402BA4FCA4DA195540C9E6AA798EF249405BCF108E591C5540C9E6AA798EF249405BCF108E591C5540A72215C616F049402BA4FCA4DA195540A72215C616F04940
5556	Карпово	5	47	714	84.54992	84.581765000000004	51.863683000000002	51.818677999999998	0103000020E61000000100000005000000A5DAA7E33123554033FAD170CAE84940A5DAA7E3312355403B8E1F2A8DEE4940473D44A33B2555403B8E1F2A8DEE4940473D44A33B25554033FAD170CAE84940A5DAA7E33123554033FAD170CAE84940
5392	Искра	5	47	714	84.396046999999996	84.412693000000004	51.571021999999999	51.557574000000002	0103000020E61000000100000005000000732B84D558195540CA8CB7955EC74940732B84D558195540F4A5B73F17C949407192E68F691A5540F4A5B73F17C949407192E68F691A5540CA8CB7955EC74940732B84D558195540CA8CB7955EC74940
5848	Демино	5	47	714	84.732915000000006	84.75788	51.569074000000001	51.554645000000001	0103000020E61000000100000005000000DDEF5014E82E5540E9F17B9BFEC64940DDEF5014E82E55408080B56AD7C84940B8921D1B813055408080B56AD7C84940B8921D1B81305540E9F17B9BFEC64940DDEF5014E82E5540E9F17B9BFEC64940
5633	Большая Тихая	5	47	714	84.658212000000006	84.670815000000005	51.796731999999999	51.785601999999997	0103000020E610000001000000050000006D753925202A55400AD6389B8EE449406D753925202A55409DD66D50FBE54940A4AA09A2EE2A55409DD66D50FBE54940A4AA09A2EE2A55400AD6389B8EE449406D753925202A55400AD6389B8EE44940
4985	Березовка	5	47	714	84.031125000000003	84.065835000000007	51.847279	51.824261	0103000020E61000000100000005000000A245B6F3FD015540232F6B6281E94940A245B6F3FD01554036CB65A373EC4940A9FB00A43604554036CB65A373EC4940A9FB00A436045540232F6B6281E94940A245B6F3FD015540232F6B6281E94940
32610	Александровка	5	47	714	83.942676000000006	83.967828999999995	51.682262000000001	51.662970000000001	0103000020E6100000010000000500000058AEB7CD54FC5440541D7233DCD4494058AEB7CD54FC5440DBA6785C54D74940B4C70BE9F0FD5440DBA6785C54D74940B4C70BE9F0FD5440541D7233DCD4494058AEB7CD54FC5440541D7233DCD44940
4940	Шульгинка	5	47	559	85.301360000000003	85.327645000000004	52.441253000000003	52.428241	0103000020E61000000100000005000000A514747B4953554036E7E099D0364A40A514747B49535540862172FA7A384A40ABECBB22F8545540862172FA7A384A40ABECBB22F854554036E7E099D0364A40A514747B4953554036E7E099D0364A40
4513	Шульгин Лог	5	47	559	85.843879999999999	85.860472000000001	52.187682000000002	52.154608000000003	0103000020E61000000100000005000000E76F42210276554099D9E731CA134A40E76F4221027655402106BAF605184A40EBC726F9117755402106BAF605184A40EBC726F91177554099D9E731CA134A40E76F42210276554099D9E731CA134A40
4613	Хуторки	5	47	559	85.794597999999993	85.815376000000001	52.270468999999999	52.248578999999999	0103000020E61000000100000005000000E3DD91B1DA72554077BCC96FD11F4A40E3DD91B1DA72554079CA6ABA9E224A405F7CD11E2F74554079CA6ABA9E224A405F7CD11E2F74554077BCC96FD11F4A40E3DD91B1DA72554077BCC96FD11F4A40
4544	Урожайное	5	47	559	85.636647999999994	85.657857000000007	52.310718999999999	52.300058	0103000020E6100000010000000500000015C440D7BE6855409B73F04C68264A4015C440D7BE685540779FE3A3C5274A40761C3F541A6A5540779FE3A3C5274A40761C3F541A6A55409B73F04C68264A4015C440D7BE6855409B73F04C68264A40
4731	Талица	5	47	559	85.651425000000003	85.684850999999995	52.397001000000003	52.386135000000003	0103000020E61000000100000005000000FFB27BF2B0695540A56B26DF6C314A40FFB27BF2B06955405ABDC3EDD0324A4081E84999D46B55405ABDC3EDD0324A4081E84999D46B5540A56B26DF6C314A40FFB27BF2B0695540A56B26DF6C314A40
3992	Советское	5	47	559	85.395027999999996	85.437392000000003	52.302950000000003	52.267256000000003	0103000020E61000000100000005000000464085234859554074D4D17135224A4046408523485955405F29CB10C7264A400DE2033BFE5B55405F29CB10C7264A400DE2033BFE5B554074D4D17135224A40464085234859554074D4D17135224A40
4287	Сетовка	5	47	559	85.450255999999996	85.508431000000002	52.214387000000002	52.18215	0103000020E61000000100000005000000FAB48AFED05C5540B37BF2B050174A40FAB48AFED05C554002D88008711B4A4072512D228A60554002D88008711B4A4072512D228A605540B37BF2B050174A40FAB48AFED05C5540B37BF2B050174A40
4649	Семилетка	5	47	559	85.608350999999999	85.627915999999999	52.304479999999998	52.295271999999997	0103000020E610000001000000050000004A5F0839EF66554056B60F79CB254A404A5F0839EF6655409E245D33F9264A40A62897C62F6855409E245D33F9264A40A62897C62F68554056B60F79CB254A404A5F0839EF66554056B60F79CB254A40
4354	Половинка	5	47	559	85.591866999999993	85.636441000000005	52.194721999999999	52.181150000000002	0103000020E6100000010000000500000039252026E1655540D0D556EC2F174A4039252026E1655540E6E786A6EC184A4059350873BB685540E6E786A6EC184A4059350873BB685540D0D556EC2F174A4039252026E1655540D0D556EC2F174A40
4465	Платово	5	47	559	85.895703999999995	85.909789000000004	52.091773000000003	52.065885999999999	0103000020E610000001000000050000005EB9DE3653795540D3A1D3F36E084A405EB9DE3653795540F2D3B837BF0B4A40AD50A4FB397A5540F2D3B837BF0B4A40AD50A4FB397A5540D3A1D3F36E084A405EB9DE3653795540D3A1D3F36E084A40
4128	Никольское	5	47	559	85.252869000000004	85.278705000000002	52.219754999999999	52.200119999999998	0103000020E61000000100000005000000064B75012F50554044A33B889D194A40064B75012F505540F5108DEE201C4A40D40E7F4DD6515540F5108DEE201C4A40D40E7F4DD651554044A33B889D194A40064B75012F50554044A33B889D194A40
3474	Ленинское	5	47	559	85.295610999999994	85.309921000000003	52.293939000000002	52.287258000000001	0103000020E610000001000000050000009F55664AEB525540D7C1C1DEC4244A409F55664AEB5255406D020CCB9F254A40FED5E3BED55355406D020CCB9F254A40FED5E3BED5535540D7C1C1DEC4244A409F55664AEB525540D7C1C1DEC4244A40
4881	Красный Яр	5	47	559	85.315832	85.363093000000006	52.368625999999999	52.345927000000003	0103000020E61000000100000005000000F0C16B9736545540D6E6FF55472C4A40F0C16B9736545540473A03232F2F4A40051A6CEA3C575540473A03232F2F4A40051A6CEA3C575540D6E6FF55472C4A40F0C16B9736545540D6E6FF55472C4A40
4368	Колово	5	47	559	85.611925999999997	85.634887000000006	52.094555999999997	52.075701000000002	0103000020E610000001000000050000009D64ABCB2967554023A30392B0094A409D64ABCB29675540FED137691A0C4A40F56915FDA1685540FED137691A0C4A40F56915FDA168554023A30392B0094A409D64ABCB2967554023A30392B0094A40
4173	Колбаны	5	47	559	85.245763999999994	85.268158999999997	52.174616999999998	52.152071999999997	0103000020E610000001000000050000002FA2ED98BA4F55409351651877134A402FA2ED98BA4F5540AE2990D959164A4032C85D8429515540AE2990D959164A4032C85D84295155409351651877134A402FA2ED98BA4F55409351651877134A40
4789	Кокши	5	47	559	85.519220000000004	85.560929000000002	52.399918999999997	52.365622999999999	0103000020E6100000010000000500000077DB85E63A6155402CD505BCCC2E4A4077DB85E63A6155404606B98B30334A403198BF42E66355404606B98B30334A403198BF42E66355402CD505BCCC2E4A4077DB85E63A6155402CD505BCCC2E4A40
4818	Карасук	5	47	559	85.576909999999998	85.607613999999998	52.389505	52.380291999999997	0103000020E6100000010000000500000010AFEB17EC64554018778368AD304A4010AFEB17EC6455407250C24CDB314A40DFA5D425E36655407250C24CDB314A40DFA5D425E366554018778368AD304A4010AFEB17EC64554018778368AD304A40
4218	Глинка	5	47	559	85.330583000000004	85.339619999999996	52.207064000000003	52.185462999999999	0103000020E6100000010000000500000045679945285555401CCF6740BD174A404567994528555540E816BA12811A4A4052448655BC555540E816BA12811A4A4052448655BC5555401CCF6740BD174A4045679945285555401CCF6740BD174A40
3390	Южный	5	47	365	84.791242999999994	84.801636999999999	52.145119999999999	52.139907999999998	0103000020E61000000100000005000000170CAEB9A332554071395E81E8114A40170CAEB9A33255406DFFCA4A93124A40DE9046054E3355406DFFCA4A93124A40DE9046054E33554071395E81E8114A40170CAEB9A332554071395E81E8114A40
3903	Черновая	5	47	365	84.745931999999996	84.758221000000006	51.978650999999999	51.952165000000001	0103000020E610000001000000050000008D429259BD2F5540ABB2EF8AE0F949408D429259BD2F55404E999B6F44FD4940FD885FB1863055404E999B6F44FD4940FD885FB186305540ABB2EF8AE0F949408D429259BD2F5540ABB2EF8AE0F94940
2762	Усть-Катунь	5	47	365	85.047963999999993	85.067285999999996	52.421897999999999	52.415768	0103000020E61000000100000005000000A9D898D711435540965CC5E237354A40A9D898D711435540B81FF0C000364A40A25EF0694E445540B81FF0C000364A40A25EF0694E445540965CC5E237354A40A9D898D711435540965CC5E237354A40
3869	Точильное	5	47	365	85.015579000000002	85.058132999999998	52.171816999999997	52.141129999999997	0103000020E6100000010000000500000048E00F3FFF405540033E3F8C10124A4048E00F3FFF405540CBF27519FE154A4060747973B8435540CBF27519FE154A4060747973B8435540033E3F8C10124A4048E00F3FFF405540033E3F8C10124A40
3784	Сычевка	5	47	365	84.738861999999997	84.806145999999998	52.066850000000002	52.035252999999997	0103000020E610000001000000050000007590D783492F5540FE0A992B83044A407590D783492F55406ADE718A8E084A40477364E5973355406ADE718A8E084A40477364E597335540FE0A992B83044A407590D783492F5540FE0A992B83044A40
2985	Степное	5	47	365	84.891800000000003	84.903037999999995	52.192540999999999	52.187572000000003	0103000020E61000000100000005000000A9A44E40133955409AD2FA5B02184A40A9A44E4013395540CF11F92EA5184A40E542E55FCB395540CF11F92EA5184A40E542E55FCB3955409AD2FA5B02184A40A9A44E40133955409AD2FA5B02184A40
2666	Старотырышкино	5	47	365	84.812299999999993	84.835216000000003	52.360002999999999	52.341816999999999	0103000020E610000001000000050000009CA223B9FC335540C11BD2A8C02B4A409CA223B9FC3355401FBB0B94142E4A402446CF2D743555401FBB0B94142E4A402446CF2D74355540C11BD2A8C02B4A409CA223B9FC335540C11BD2A8C02B4A40
3780	Солоновка	5	47	365	84.591241999999994	84.663888999999998	52.015559000000003	51.984214000000001	0103000020E610000001000000050000006281AFE8D6255540F7216FB9FAFD49406281AFE8D625554049145AD6FD014A4025CB49287D2A554049145AD6FD014A4025CB49287D2A5540F7216FB9FAFD49406281AFE8D6255540F7216FB9FAFD4940
3577	Смоленское	5	47	365	85.047972999999999	85.124634999999998	52.317425	52.282184000000001	0103000020E61000000100000005000000D38558FD114355402CBAF59A1E244A40D38558FD1143554066F7E461A1284A40F73B1405FA47554066F7E461A1284A40F73B1405FA4755402CBAF59A1E244A40D38558FD114355402CBAF59A1E244A40
3135	Песчаное	5	47	365	84.860701000000006	84.889545999999996	52.399864000000001	52.383453000000003	0103000020E610000001000000050000009CA8A5B915375540CC46E7FC14314A409CA8A5B915375540836C59BE2E334A4068925852EE385540836C59BE2E334A4068925852EE385540CC46E7FC14314A409CA8A5B915375540CC46E7FC14314A40
3470	Первомайское	5	47	365	85.199922999999998	85.226934999999997	52.290298	52.276860999999997	0103000020E61000000100000005000000F7ADD689CB4C5540D844662E70234A40F7ADD689CB4C55400F0C207C28254A4056D4601A864E55400F0C207C28254A4056D4601A864E5540D844662E70234A40F7ADD689CB4C5540D844662E70234A40
1978	Новотырышкино	5	47	365	84.884838999999999	84.940956	52.100968000000002	52.074444999999997	0103000020E610000001000000050000006CCEC133A1385540E42CEC6987094A406CCEC133A1385540A5F8F884EC0C4A4066BE839F383C5540A5F8F884EC0C4A4066BE839F383C5540E42CEC6987094A406CCEC133A1385540E42CEC6987094A40
3037	Линевский	5	47	365	84.961393000000001	84.986618000000007	52.371853000000002	52.358539999999998	0103000020E610000001000000050000009D668176873D5540672783A3E42D4A409D668176873D5540B2F50CE1982F4A4047E9D2BF243F5540B2F50CE1982F4A4047E9D2BF243F5540672783A3E42D4A409D668176873D5540672783A3E42D4A40
59451	Красный Городок	5	47	365	84.656576999999999	84.665604999999999	51.985407000000002	51.972548000000003	0103000020E610000001000000050000009293895B052A554026E5EE737CFC49409293895B052A5540EF1F0BD121FE494076C3B645992A5540EF1F0BD121FE494076C3B645992A554026E5EE737CFC49409293895B052A554026E5EE737CFC4940
1868	Кировский	5	47	365	85.014878999999993	85.035889999999995	52.299700000000001	52.286189	0103000020E610000001000000050000006B990CC7F3405540CBBC55D7A1244A406B990CC7F34055403C4ED1915C264A40381092054C4255403C4ED1915C264A40381092054C425540CBBC55D7A1244A406B990CC7F3405540CBBC55D7A1244A40
2821	Катунское	5	47	365	85.095124999999996	85.132199	52.416871999999998	52.402698999999998	0103000020E610000001000000050000000C022B8716465540E2900DA48B334A400C022B87164655401E4FCB0F5C354A401764CBF2754855401E4FCB0F5C354A401764CBF275485540E2900DA48B334A400C022B8716465540E2900DA48B334A40
2676	Верх-Обский	5	47	365	84.996840000000006	85.032189000000002	52.423408000000002	52.413533000000001	0103000020E610000001000000050000000FD6FF39CC3F55408C683BA6EE344A400FD6FF39CC3F5540B16EBC3B32364A409F9273620F425540B16EBC3B32364A409F9273620F4255408C683BA6EE344A400FD6FF39CC3F55408C683BA6EE344A40
8225	Белокуриха	5	47	365	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
2579	Ануйское	5	47	365	84.845528000000002	84.875675999999999	52.313851999999997	52.287576999999999	0103000020E610000001000000050000008CF678211D365540780AB952CF244A408CF678211D36554060E4654D2C284A40187959130B38554060E4654D2C284A40187959130B385540780AB952CF244A408CF678211D365540780AB952CF244A40
2930	Александровка	5	47	365	85.038864000000004	85.054125999999997	52.233144000000003	52.218916999999998	0103000020E61000000100000005000000793F6EBF7C425540EBC4E578051C4A40793F6EBF7C4255401BA19FA9D71D4A4040F7E5CC764355401BA19FA9D71D4A4040F7E5CC76435540EBC4E578051C4A40793F6EBF7C425540EBC4E578051C4A40
59397	Славгород	5	47	1687	78.190996999999996	79.633197999999993	53.377397999999999	52.802497000000002	0103000020E6100000010000000500000095287B4B398C5340AE11C138B8664A4095287B4B398C5340B4C9E1934EB04A402079E75086E85340B4C9E1934EB04A402079E75086E85340AE11C138B8664A4095287B4B398C5340AE11C138B8664A40
59375	Селекционное	5	47	1687	78.581136000000001	78.613906	52.986593999999997	52.972242000000001	0103000020E61000000100000005000000CFA10C5531A5534019E6046D727C4A40CFA10C5531A55340043752B6487E4A405D34643C4AA75340043752B6487E4A405D34643C4AA7534019E6046D727C4A40CFA10C5531A5534019E6046D727C4A40
59435	Райгород	5	47	1687	78.396710999999996	78.415091000000004	52.866441000000002	52.858373	0103000020E61000000100000005000000A9BD88B6639953407C629D2ADF6D4A40A9BD88B663995340EF74E789E76E4A404B77D7D9909A5340EF74E789E76E4A404B77D7D9909A53407C629D2ADF6D4A40A9BD88B6639953407C629D2ADF6D4A40
32590	Покровка	5	47	1687	78.395041000000006	78.408047999999994	52.973066000000003	52.959463	0103000020E6100000010000000500000011E50B5A489953406C5CFFAECF7A4A4011E50B5A48995340BE6C3B6D8D7C4A40AFCC5B751D9A5340BE6C3B6D8D7C4A40AFCC5B751D9A53406C5CFFAECF7A4A4011E50B5A489953406C5CFFAECF7A4A40
59416	Максимовка	5	47	1687	78.756478000000001	78.785061999999996	53.092861999999997	53.087750999999997	0103000020E610000001000000050000002F89B3226AB053407C98BD6C3B8B4A402F89B3226AB053404485EAE6E28B4A4045D5AF743EB253404485EAE6E28B4A4045D5AF743EB253407C98BD6C3B8B4A402F89B3226AB053407C98BD6C3B8B4A40
22318	Гришковка	5	47	1687	78.740784000000005	78.765353000000005	53.156391999999997	53.143610000000002	0103000020E610000001000000050000009B594B0169AF534075B0FECF61924A409B594B0169AF534092AD2EA704944A405039268BFBB0534092AD2EA704944A405039268BFBB0534075B0FECF61924A409B594B0169AF534075B0FECF61924A40
59418	Балластный Карьер	5	47	1687	78.511596999999995	78.527264000000002	53.132536000000002	53.121150999999998	0103000020E61000000100000005000000D4EE5701BEA0534058703FE0818F4A40D4EE5701BEA0534076C58CF0F6904A40EC1681B1BEA1534076C58CF0F6904A40EC1681B1BEA1534058703FE0818F4A40D4EE5701BEA0534058703FE0818F4A40
59424	Архангельское	5	47	1687	78.637235000000004	78.651634999999999	53.091839999999998	53.083711000000001	0103000020E6100000010000000500000076374F75C8A8534061A8C30AB78A4A4076374F75C8A85340793BC269C18B4A40747B4963B4A95340793BC269C18B4A40747B4963B4A9534061A8C30AB78A4A4076374F75C8A8534061A8C30AB78A4A40
1974	Тишинка	5	47	160	81.311834000000005	81.331669000000005	51.814368999999999	51.795022000000003	0103000020E61000000100000005000000FAF19716F5535440DECCE847C3E54940FAF19716F553544028F04E3E3DE8494036069D103A55544028F04E3E3DE8494036069D103A555440DECCE847C3E54940FAF19716F5535440DECCE847C3E54940
1875	Саратовка	5	47	160	81.635784999999998	81.652277999999995	51.387963999999997	51.375805	0103000020E61000000100000005000000649291B3B06854402E56D4601AB04940649291B3B06854403E03EACDA8B149409E7939ECBE6954403E03EACDA8B149409E7939ECBE6954402E56D4601AB04940649291B3B06854402E56D4601AB04940
1824	Самарка	5	47	160	81.250623000000004	81.280608999999998	51.381449000000003	51.364514	0103000020E6100000010000000500000007280D350A50544092770E65A8AE494007280D350A505440C40B2252D3B04940A67D737FF5515440C40B2252D3B04940A67D737FF551544092770E65A8AE494007280D350A50544092770E65A8AE4940
1295	Романовка	5	47	160	81.501486999999997	81.513255000000001	51.389212000000001	51.373353000000002	0103000020E61000000100000005000000A017EE5C18605440876EF607CAAF4940A017EE5C18605440FA9AE5B2D1B149408BE07F2BD9605440FA9AE5B2D1B149408BE07F2BD9605440876EF607CAAF4940A017EE5C18605440876EF607CAAF4940
1777	Ракиты	5	47	160	80.680642000000006	80.718936999999997	51.457757000000001	51.424886999999998	0103000020E610000001000000050000002E9276A38F2B54406EBF7CB262B649402E9276A38F2B5440EE4108C897BA494099B85510032E5440EE4108C897BA494099B85510032E54406EBF7CB262B649402E9276A38F2B54406EBF7CB262B64940
1728	Пушкино	5	47	160	81.110979999999998	81.122425000000007	51.534565000000001	51.524317000000003	0103000020E61000000100000005000000A5A0DB4B1A47544051DEC7D11CC34940A5A0DB4B1A4754400A4B3CA06CC449409FCDAACFD54754400A4B3CA06CC449409FCDAACFD547544051DEC7D11CC34940A5A0DB4B1A47544051DEC7D11CC34940
25670	Приозерный	5	47	160	81.195188000000002	81.206964999999997	51.576866000000003	51.569907999999998	0103000020E610000001000000050000009624CFF57D4C544048DDCEBEF2C849409624CFF57D4C54405116BEBED6C94940AA9A20EA3E4D54405116BEBED6C94940AA9A20EA3E4D544048DDCEBEF2C849409624CFF57D4C544048DDCEBEF2C84940
1486	Половинкино	5	47	160	81.226979999999998	81.241065000000006	51.433889000000001	51.407632	0103000020E6100000010000000500000026361FD7864E5440CB660E492DB4494026361FD7864E54400D8CBCAC89B7494075CDE49B6D4F54400D8CBCAC89B7494075CDE49B6D4F5440CB660E492DB4494026361FD7864E5440CB660E492DB44940
1436	Новосклюиха	5	47	160	81.393778999999995	81.413720999999995	51.550524000000003	51.535634999999999	0103000020E6100000010000000500000080B6D5AC33595440E6CB0BB08FC4494080B6D5AC33595440E1D4079277C64940C72AA5677A5A5440E1D4079277C64940C72AA5677A5A5440E6CB0BB08FC4494080B6D5AC33595440E6CB0BB08FC44940
1284	Новониколаевка	5	47	160	81.464404000000002	81.490005999999994	51.373100000000001	51.337502000000001	0103000020E610000001000000050000006C088ECBB85D5440D42AFA4333AB49406C088ECBB85D54409D11A5BDC1AF4940003620425C5F54409D11A5BDC1AF4940003620425C5F5440D42AFA4333AB49406C088ECBB85D5440D42AFA4333AB4940
1182	Новоалександровка	5	47	160	81.153057000000004	81.183105999999995	51.388311999999999	51.359599000000003	0103000020E61000000100000005000000215B96AFCB49544050560C5707AE4940215B96AFCB4954407A522635B4B14940E36C3A02B84B54407A522635B4B14940E36C3A02B84B544050560C5707AE4940215B96AFCB49544050560C5707AE4940
1630	Мичуринский	5	47	160	81.148511999999997	81.161734999999993	51.468183000000003	51.461337999999998	0103000020E6100000010000000500000011C47938814954407633A31F0DBB494011C479388149544087C5A86BEDBB494096E7C1DD594A544087C5A86BEDBB494096E7C1DD594A54407633A31F0DBB494011C47938814954407633A31F0DBB4940
1169	Мамонтово	5	47	160	81.391569000000004	81.413505999999998	51.760033	51.744304999999997	0103000020E6100000010000000500000028486C770F595440E89FE06245DF494028486C770F595440BD70E7C248E14940C9ACDEE1765A5440BD70E7C248E14940C9ACDEE1765A5440E89FE06245DF494028486C770F595440E89FE06245DF4940
1052	Куйбышево	5	47	160	81.121526000000003	81.146122000000005	51.587394000000003	51.574958000000002	0103000020E6100000010000000500000047E7FC14C74754406B49473998C9494047E7FC14C7475440EEEE01BA2FCB494079CE16105A495440EEEE01BA2FCB494079CE16105A4954406B49473998C9494047E7FC14C74754406B49473998C94940
1645	Колос	5	47	160	81.133787999999996	81.142825000000002	51.426465	51.420417	0103000020E6100000010000000500000039268BFB8F4854405AD76839D0B5494039268BFB8F485440BFF1B56796B649404703780B24495440BFF1B56796B649404703780B244954405AD76839D0B5494039268BFB8F4854405AD76839D0B54940
720	Катково	5	47	160	81.440050999999997	81.470082000000005	51.658507	51.652248999999998	0103000020E610000001000000050000009D64ABCB295C5440A2EC2DE57CD349409D64ABCB295C5440F29716F549D449400D1CD0D2155E5440F29716F549D449400D1CD0D2155E5440A2EC2DE57CD349409D64ABCB295C5440A2EC2DE57CD34940
1537	Зеленая Дубрава	5	47	160	81.176942999999994	81.194136999999998	51.463526000000002	51.450248000000002	0103000020E610000001000000050000006490BB08534B5440728BF9B9A1B949406490BB08534B5440406CE9D154BB4940637C98BD6C4C5440406CE9D154BB4940637C98BD6C4C5440728BF9B9A1B949406490BB08534B5440728BF9B9A1B94940
471	Захарово	5	47	160	81.317960999999997	81.349913999999998	51.665014999999997	51.644877999999999	0103000020E61000000100000005000000D21918795954544077F4BF5C8BD24940D219187959545440BA2C26361FD54940679AB0FD64565440BA2C26361FD54940679AB0FD6456544077F4BF5C8BD24940D21918795954544077F4BF5C8BD24940
1046	Дальний	5	47	160	81.681445999999994	81.694785999999993	51.485736000000003	51.472968999999999	0103000020E610000001000000050000005CFFAECF9C6B5440CB82893F8ABC49405CFFAECF9C6B5440B43EE5982CBE4940FEEDB25F776C5440B43EE5982CBE4940FEEDB25F776C5440CB82893F8ABC49405CFFAECF9C6B5440CB82893F8ABC4940
961	Вишневка	5	47	160	81.531121999999996	81.542207000000005	51.367224999999998	51.350645	0103000020E61000000100000005000000E90B21E7FD615440C2C073EFE1AC4940E90B21E7FD61544005A3923A01AF4940632AFD84B362544005A3923A01AF4940632AFD84B3625440C2C073EFE1AC4940E90B21E7FD615440C2C073EFE1AC4940
841	Веселоярск	5	47	160	81.076286999999994	81.134669000000002	51.312387999999999	51.252153999999997	0103000020E610000001000000050000000987DEE2E14454401DC70F9546A049400987DEE2E1445440D8D47954FCA749403EB2B96A9E485440D8D47954FCA749403EB2B96A9E4854401DC70F9546A049400987DEE2E14454401DC70F9546A04940
788	Большая Шелковка	5	47	160	80.636077	80.662926999999996	51.429003999999999	51.410350999999999	0103000020E61000000100000005000000382F4E7CB5285440C170AE6186B44940382F4E7CB528544035ED629AE9B64940AA285E656D2A544035ED629AE9B64940AA285E656D2A5440C170AE6186B44940382F4E7CB5285440C170AE6186B44940
683	Бобково	5	47	160	81.383887999999999	81.412229999999994	51.678888999999998	51.660584999999998	0103000020E61000000100000005000000EB54F99E91585440349D9D0C8ED44940EB54F99E915854409C4EB2D5E5D64940861BF0F9615A54409C4EB2D5E5D64940861BF0F9615A5440349D9D0C8ED44940EB54F99E91585440349D9D0C8ED44940
570	Березовка	5	47	160	81.288899999999998	81.305367000000004	51.567137000000002	51.555984000000002	0103000020E610000001000000050000001FF46C567D525440B58CD47B2AC749401FF46C567D52544000ADF9F197C84940C59107228B53544000ADF9F197C84940C59107228B535440B58CD47B2AC749401FF46C567D525440B58CD47B2AC74940
565	Безрукавка	5	47	160	81.265435999999994	81.294011999999995	51.600955999999996	51.570143999999999	0103000020E6100000010000000500000096CB46E7FC5054405C01857AFAC8494096CB46E7FC505440E02A4F20ECCC49406B28B517D1525440E02A4F20ECCC49406B28B517D15254405C01857AFAC8494096CB46E7FC5054405C01857AFAC84940
411	Тамбовский	5	47	43	80.976421000000002	80.994792000000004	52.661320000000003	52.645783000000002	0103000020E610000001000000050000002B8881AE7D3E544009A87004A9524A402B8881AE7D3E54406A183E22A6544A40A39410ACAA3F54406A183E22A6544A40A39410ACAA3F544009A87004A9524A402B8881AE7D3E544009A87004A9524A40
334	Сидоровка	5	47	43	80.730714000000006	80.774489000000003	52.565581000000002	52.530434	0103000020E61000000100000005000000AE2EA704C42E5440DE57E542E5434A40AE2EA704C42E5440971E4DF564484A4027874F3A91315440971E4DF564484A4027874F3A91315440DE57E542E5434A40AE2EA704C42E5440DE57E542E5434A40
180	Романово	5	47	43	81.190211000000005	81.272640999999993	52.635739999999998	52.606774999999999	0103000020E61000000100000005000000BA15C26A2C4C5440E4839ECDAA4D4A40BA15C26A2C4C54402861A6ED5F514A401EA33CF3725154402861A6ED5F514A401EA33CF372515440E4839ECDAA4D4A40BA15C26A2C4C5440E4839ECDAA4D4A40
51	Рассвет	5	47	43	81.428768000000005	81.453767999999997	52.742322999999999	52.729204000000003	0103000020E61000000100000005000000916456EF705B5440630E828E565D4A40916456EF705B5440C808A870045F4A402AFEEF880A5D5440C808A870045F4A402AFEEF880A5D5440630E828E565D4A40916456EF705B5440630E828E565D4A40
32442	Мормыши	5	47	43	81.199635000000001	81.223376999999999	52.462119000000001	52.444732999999999	0103000020E61000000100000005000000C408E1D1C64C5440DA39CD02ED384A40C408E1D1C64C54401CEE23B7263B4A406E6B0BCF4B4E54401CEE23B7263B4A406E6B0BCF4B4E5440DA39CD02ED384A40C408E1D1C64C5440DA39CD02ED384A40
32339	Майский	5	47	43	81.344560000000001	81.359751000000003	52.774459999999998	52.760914999999997	0103000020E61000000100000005000000A0E062450D5654409604A8A965614A40A0E062450D565440B3075A8121634A4003ED0E2906575440B3075A8121634A4003ED0E29065754409604A8A965614A40A0E062450D5654409604A8A965614A40
32371	Казанцево	5	47	43	81.418859999999995	81.450210999999996	52.668022000000001	52.654896000000001	0103000020E6100000010000000500000090662C9ACE5A5440FF23D3A1D3534A4090662C9ACE5A54401781B1BE81554A402A53CC41D05C54401781B1BE81554A402A53CC41D05C5440FF23D3A1D3534A4090662C9ACE5A5440FF23D3A1D3534A40
32313	Закладное	5	47	43	80.977877000000007	81.016226000000003	52.599556	52.572159999999997	0103000020E61000000100000005000000AEA06989953E5440280AF4893C494A40AEA06989953E54406F0F4240BE4C4A4013D6C6D8094154406F0F4240BE4C4A4013D6C6D809415440280AF4893C494A40AEA06989953E5440280AF4893C494A40
32265	Дубровино	5	47	43	80.863539000000003	80.893848000000006	52.690516000000002	52.663941999999999	0103000020E6100000010000000500000084F41439443754406D382C0DFC544A4084F4143944375440B0AE0AD462584A4015E63DCE34395440B0AE0AD462584A4015E63DCE343954406D382C0DFC544A4084F41439443754406D382C0DFC544A40
32199	Гуселетово	5	47	43	81.335639999999998	81.397120000000001	52.569504999999999	52.532865999999999	0103000020E61000000100000005000000AFCE31207B5554403E93FDF334444A40AFCE31207B55544049F4328AE5484A409A25016A6A59544049F4328AE5484A409A25016A6A5954403E93FDF334444A40AFCE31207B5554403E93FDF334444A40
32181	Грановка	5	47	43	80.949319000000003	80.985414000000006	52.415520999999998	52.404677	0103000020E610000001000000050000002C9E7AA4C13C5440C138B874CC334A402C9E7AA4C13C54408EE6C8CA2F354A4051C1E105113F54408EE6C8CA2F354A4051C1E105113F5440C138B874CC334A402C9E7AA4C13C5440C138B874CC334A40
32127	Гилев Лог	5	47	43	81.060046	81.106847999999999	52.789923999999999	52.756385999999999	0103000020E610000001000000050000005C902DCBD74354407D93A641D1604A405C902DCBD7435440AA29C93A1C654A402769FE98D6465440AA29C93A1C654A402769FE98D64654407D93A641D1604A405C902DCBD74354407D93A641D1604A40
32457	Бурановка	5	47	43	81.143013999999994	81.166837000000001	52.442701999999997	52.429789	0103000020E61000000100000005000000B0373124274954401C97715303374A40B037312427495440D8EF8975AA384A40D1B01875AD4A5440D8EF8975AA384A40D1B01875AD4A54401C97715303374A40B0373124274954401C97715303374A40
32072	Ярославцев Лог	5	47	180	80.071422999999996	80.115331999999995	52.280127999999998	52.258001	0103000020E61000000100000005000000A94BC63192045440EBAA402D06214A40A94BC63192045440D158FB3BDB234A40AA0B789961075440D158FB3BDB234A40AA0B789961075440EBAA402D06214A40A94BC63192045440EBAA402D06214A40
32050	Шаталовка	5	47	180	79.947176999999996	79.975320999999994	52.408627000000003	52.393571999999999	0103000020E610000001000000050000007FA1478C9EFC5340874F3A9160324A407FA1478C9EFC53409DA1B8E34D344A408786C5A86BFE53409DA1B8E34D344A408786C5A86BFE5340874F3A9160324A407FA1478C9EFC5340874F3A9160324A40
31941	Центральное	5	47	180	80.396118999999999	80.415406000000004	52.306953	52.294699000000001	0103000020E61000000100000005000000C09481035A195440FB9463B2B8254A40C09481035A1954405D34643C4A274A40FB230C03961A54405D34643C4A274A40FB230C03961A5440FB9463B2B8254A40C09481035A195440FB9463B2B8254A40
31790	Тизек	5	47	180	79.833072999999999	79.862825000000001	52.595978000000002	52.587995999999997	0103000020E610000001000000050000008F8B6A1151F55340E316F373434B4A408F8B6A1151F553405891D101494C4A40F54A598638F753405891D101494C4A40F54A598638F75340E316F373434B4A408F8B6A1151F55340E316F373434B4A40
31865	Степной Кучук	5	47	180	80.325269000000006	80.373760000000004	52.608705999999998	52.585287999999998	0103000020E61000000100000005000000C5591135D1145440E15E99B7EA4A4A40C5591135D114544082700514EA4D4A40642310AFEB17544082700514EA4D4A40642310AFEB175440E15E99B7EA4A4A40C5591135D1145440E15E99B7EA4A4A40
31929	Степное	5	47	180	80.459100000000007	80.497853000000006	52.642018999999998	52.626370999999999	0103000020E61000000100000005000000FE65F7E4611D5440D714C8EC2C504A40FE65F7E4611D54408F34B8AD2D524A40CB4DD4D2DC1F54408F34B8AD2D524A40CB4DD4D2DC1F5440D714C8EC2C504A40FE65F7E4611D5440D714C8EC2C504A40
22233	Родино	5	47	180	80.165970000000002	80.243109000000004	52.514806999999998	52.472988000000001	0103000020E610000001000000050000007F87A2409F0A544042B3EBDE8A3C4A407F87A2409F0A54403D601E32E5414A4040170D198F0F54403D601E32E5414A4040170D198F0F544042B3EBDE8A3C4A407F87A2409F0A544042B3EBDE8A3C4A40
31721	Разумовка	5	47	180	79.715536999999998	79.743752999999998	52.567551000000002	52.547314999999998	0103000020E61000000100000005000000FD84B35BCBED53401CCEFC6A0E464A40FD84B35BCBED5340F3E7DB82A5484A4052D32EA699EF5340F3E7DB82A5484A4052D32EA699EF53401CCEFC6A0E464A40FD84B35BCBED53401CCEFC6A0E464A40
567	Раздольное	5	47	180	79.934680999999998	79.965592000000001	52.498838999999997	52.487391000000002	0103000020E6100000010000000500000053CC41D0D1FB5340B0AE0AD4623E4A4053CC41D0D1FB5340137CD3F4D93F4A40DF516342CCFD5340137CD3F4D93F4A40DF516342CCFD5340B0AE0AD4623E4A4053CC41D0D1FB5340B0AE0AD4623E4A40
31591	Покровка	5	47	180	80.370759000000007	80.397125000000003	52.772106999999998	52.760326999999997	0103000020E61000000100000005000000A7ECF483BA17544005A2276552614A40A7ECF483BA1754409F01F566D4624A4023DBF97E6A1954409F01F566D4624A4023DBF97E6A19544005A2276552614A40A7ECF483BA17544005A2276552614A40
27453	Новотроицк	5	47	180	80.135795999999999	80.160921999999999	52.660834000000001	52.645296999999999	0103000020E610000001000000050000005EBBB4E1B00854407C9A931799524A405EBBB4E1B0085440DD0A613596544A403ECDC98B4C0A5440DD0A613596544A403ECDC98B4C0A54407C9A931799524A405EBBB4E1B00854407C9A931799524A40
31514	Мирный	5	47	180	80.148928999999995	80.179902999999996	52.567945000000002	52.549199000000002	0103000020E61000000100000005000000431B800D880954407AFF1F274C464A40431B800D880954409F76F86BB2484A40F25CDF87830B54409F76F86BB2484A40F25CDF87830B54407AFF1F274C464A40431B800D880954407AFF1F274C464A40
59462	Красный Алтай	5	47	180	80.291905	80.307041999999996	52.294671999999998	52.280149999999999	0103000020E610000001000000050000007D224F92AE125440B9FC87F4DB234A407D224F92AE1254400186E5CFB7254A40E61F7D93A61354400186E5CFB7254A40E61F7D93A6135440B9FC87F4DB234A407D224F92AE125440B9FC87F4DB234A40
31435	Кочки	5	47	180	80.635339999999999	80.673725000000005	52.406818999999999	52.372529	0103000020E61000000100000005000000CD751A69A9285440E2E7BF07AF2F4A40CD751A69A92854401A321EA512344A40D95F764F1E2B54401A321EA512344A40D95F764F1E2B5440E2E7BF07AF2F4A40CD751A69A9285440E2E7BF07AF2F4A40
31337	Каяушка	5	47	180	80.440782999999996	80.470095000000001	52.507139000000002	52.479877000000002	0103000020E610000001000000050000007F68E6C9351C5440228D0A9C6C3D4A407F68E6C9351C544059C345EEE9404A40D7C05609161E544059C345EEE9404A40D7C05609161E5440228D0A9C6C3D4A407F68E6C9351C5440228D0A9C6C3D4A40
31272	Зеленый Луг	5	47	180	80.126902999999999	80.155693999999997	52.381436000000001	52.360447999999998	0103000020E61000000100000005000000EAB0C22D1F0854404DF4F928232E4A40EAB0C22D1F0854402FC214E5D2304A40BD8BF7E3F60954402FC214E5D2304A40BD8BF7E3F60954404DF4F928232E4A40EAB0C22D1F0854404DF4F928232E4A40
28349	Зеленая Дубрава	5	47	180	80.584010000000006	80.592751000000007	52.494990999999999	52.481737000000003	0103000020E610000001000000050000005EA27A6B60255440F722DA8EA93D4A405EA27A6B602554403C6876DD5B3F4A40F7EAE3A1EF2554403C6876DD5B3F4A40F7EAE3A1EF255440F722DA8EA93D4A405EA27A6B60255440F722DA8EA93D4A40
31660	Вячеславка (Красная Нива)	5	47	180	80.432258000000004	80.450045000000003	52.826357999999999	52.813101000000003	0103000020E61000000100000005000000CD5B751DAA1B544026AC8DB113684A40CD5B751DAA1B5440DC645419C6694A409D2E8B89CD1C5440DC645419C6694A409D2E8B89CD1C544026AC8DB113684A40CD5B751DAA1B544026AC8DB113684A40
31237	Вознесенка	5	47	180	80.432571999999993	80.465478000000004	52.353788000000002	52.321966000000003	0103000020E61000000100000005000000944A7842AF1B54404436902E36294A40944A7842AF1B5440CFDBD8EC482D4A407BC03C64CA1D5440CFDBD8EC482D4A407BC03C64CA1D54404436902E36294A40944A7842AF1B54404436902E36294A40
59377	станция Ребриха	5	47	118	82.238338999999996	82.370140000000006	53.049757	52.970261999999998	0103000020E61000000100000005000000209738F2408F54409946938B317C4A40209738F2408F5440A0DFF76F5E864A4041BCAE5FB0975440A0DFF76F5E864A4041BCAE5FB09754409946938B317C4A40209738F2408F54409946938B317C4A40
328	Ясная Поляна	5	47	118	82.222762000000003	82.235123000000002	53.230988000000004	53.216082	0103000020E61000000100000005000000A9328CBB418E54408CA03193A89B4A40A9328CBB418E54405DE2C803919D4A4065E256410C8F54405DE2C803919D4A4065E256410C8F54408CA03193A89B4A40A9328CBB418E54408CA03193A89B4A40
276	Шумилиха	5	47	118	81.936514000000003	81.961083000000002	53.132416999999997	53.109428000000001	0103000020E61000000100000005000000C18F6AD8EF7B544023A298BC018E4A40C18F6AD8EF7B54409B374E0AF3904A40766F4562827D54409B374E0AF3904A40766F4562827D544023A298BC018E4A40C18F6AD8EF7B544023A298BC018E4A40
27345	Усть-Мосиха	5	47	118	81.996898999999999	82.061209000000005	53.273738000000002	53.235990000000001	0103000020E61000000100000005000000919A7631CD7F54406E179AEB349E4A40919A7631CD7F544013D6C6D809A34A40234E27D9EA83544013D6C6D809A34A40234E27D9EA8354406E179AEB349E4A40919A7631CD7F54406E179AEB349E4A40
27397	Рожнев Лог	5	47	118	82.412943999999996	82.489984000000007	52.868772999999997	52.857846000000002	0103000020E6100000010000000500000015C5ABAC6D9A54409180D1E5CD6D4A4015C5ABAC6D9A5440EB5223F4336F4A400DE4D9E55B9F5440EB5223F4336F4A400DE4D9E55B9F54409180D1E5CD6D4A4015C5ABAC6D9A54409180D1E5CD6D4A40
29957	Ребриха	5	47	118	82.300923999999995	82.386678000000003	53.092433999999997	53.055056	0103000020E6100000010000000500000037A5BC56429354406BB933130C874A4037A5BC5642935440EC8497E0D48B4A404B051555BF985440EC8497E0D48B4A404B051555BF9854406BB933130C874A4037A5BC56429354406BB933130C874A40
30368	Подстепное	5	47	118	82.054075999999995	82.123220000000003	52.979871000000003	52.947158999999999	0103000020E61000000100000005000000E7DF2EFB75835440588E90813C794A40E7DF2EFB7583544040A6B5696C7D4A40A48D23D6E287544040A6B5696C7D4A40A48D23D6E2875440588E90813C794A40E7DF2EFB75835440588E90813C794A40
31119	Плоскосеминский	5	47	118	82.478018000000006	82.504554999999996	53.004707000000003	52.989597000000003	0103000020E610000001000000050000008F39CFD8979E5440209C4F1DAB7E4A408F39CFD8979E5440F9872D3D9A804A4021020EA14AA05440F9872D3D9A804A4021020EA14AA05440209C4F1DAB7E4A408F39CFD8979E5440209C4F1DAB7E4A40
31202	Пеньки	5	47	118	82.388339000000002	82.403493999999995	52.943116000000003	52.933456	0103000020E61000000100000005000000BA30D28BDA985440A320787C7B774A40BA30D28BDA985440CC2A6C06B8784A4076887FD8D2995440CC2A6C06B8784A4076887FD8D2995440A320787C7B774A40BA30D28BDA985440A320787C7B774A40
27305	Паново	5	47	118	82.122653999999997	82.170874999999995	52.997635000000002	52.976422999999997	0103000020E610000001000000050000004FAE2990D9875440F607CA6DFB7C4A404FAE2990D9875440282CF180B27F4A400E2DB29DEF8A5440282CF180B27F4A400E2DB29DEF8A5440F607CA6DFB7C4A404FAE2990D9875440F607CA6DFB7C4A40
30834	Орел	5	47	118	82.613016999999999	82.626636000000005	53.122512	53.108108999999999	0103000020E6100000010000000500000017B9A7AB3BA754409EB30584D68D4A4017B9A7AB3BA754400CAF2479AE8F4A40C39FE1CD1AA854400CAF2479AE8F4A40C39FE1CD1AA854409EB30584D68D4A4017B9A7AB3BA754409EB30584D68D4A40
30501	Молодежный	5	47	118	82.126687000000004	82.145740000000004	53.001553000000001	52.995260999999999	0103000020E610000001000000050000000475CAA31B885440FCFD62B6647F4A400475CAA31B885440F81A82E332804A40056EDDCD53895440F81A82E332804A40056EDDCD53895440FCFD62B6647F4A400475CAA31B885440FCFD62B6647F4A40
59426	Куликово	5	47	118	81.837196000000006	82.797297999999998	53.336897999999998	52.695799000000001	0103000020E61000000100000005000000E415889E9475544075CB0EF10F594A40E415889E947554403D0B42791FAB4A40A3CA30EE06B354403D0B42791FAB4A40A3CA30EE06B3544075CB0EF10F594A40E415889E9475544075CB0EF10F594A40
30960	Ключевка	5	47	118	82.416268000000002	82.427307999999996	53.030287000000001	53.020847000000003	0103000020E61000000100000005000000C4978922A49A5440209C4F1DAB824A40C4978922A49A54403A3FC571E0834A406D54A703599B54403A3FC571E0834A406D54A703599B5440209C4F1DAB824A40C4978922A49A5440209C4F1DAB824A40
30820	Клочки	5	47	118	82.552102000000005	82.596622999999994	53.187947000000001	53.164524	0103000020E610000001000000050000009983A0A355A354401CB4571F0F954A409983A0A355A35440CF30B5A50E984A40A6423C122FA65440CF30B5A50E984A40A6423C122FA654401CB4571F0F954A409983A0A355A354401CB4571F0F954A40
476	Зимино	5	47	118	82.687370999999999	82.723823999999993	52.968716999999998	52.939946999999997	0103000020E61000000100000005000000014EEFE2FDAB5440957CEC2E50784A40014EEFE2FDAB5440240A2DEBFE7B4A40D503E62153AE5440240A2DEBFE7B4A40D503E62153AE5440957CEC2E50784A40014EEFE2FDAB5440957CEC2E50784A40
59413	Зеленая Роща	5	47	118	82.494943000000006	82.533407999999994	53.083868000000002	53.055515999999997	0103000020E6100000010000000500000096986725AD9F5440CE33F6251B874A4096986725AD9F54402997C62FBC8A4A402FDB4E5B23A254402997C62FBC8A4A402FDB4E5B23A25440CE33F6251B874A4096986725AD9F5440CE33F6251B874A40
30349	Георгиевка	5	47	118	82.018404000000004	82.069446999999997	52.869979999999998	52.842483000000001	0103000020E610000001000000050000006687F8872D815440CE37A27BD66B4A406687F8872D815440481630815B6F4A408A73D4D171845440481630815B6F4A408A73D4D171845440CE37A27BD66B4A406687F8872D815440CE37A27BD66B4A40
27263	Ворониха	5	47	118	82.189659000000006	82.243639000000002	52.766494999999999	52.747354999999999	0103000020E610000001000000050000001899805F238C544044C02154A95F4A401899805F238C544015C616821C624A40EE4108C8978F544015C616821C624A40EE4108C8978F544044C02154A95F4A401899805F238C544044C02154A95F4A40
401	Боровлянка	5	47	118	82.441824999999994	82.473247999999998	53.199675999999997	53.174213000000002	0103000020E6100000010000000500000088635DDC469C5440DFC4909C4C964A4088635DDC469C5440E6E5B0FB8E994A406FB9FAB1499E5440E6E5B0FB8E994A406FB9FAB1499E5440DFC4909C4C964A4088635DDC469C5440DFC4909C4C964A40
213	Белово	5	47	118	82.234575000000007	82.286866000000003	52.966996999999999	52.92812	0103000020E61000000100000005000000645DDC46038F5440BB61DBA2CC764A40645DDC46038F5440412AC58EC67B4A40661536035C925440412AC58EC67B4A40661536035C925440BB61DBA2CC764A40645DDC46038F5440BB61DBA2CC764A40
29701	Хлебороб	5	47	112	81.713768000000002	81.732883999999999	52.014594000000002	51.998528	0103000020E610000001000000050000009B3BFA5FAE6D5440F511F8C3CFFF49409B3BFA5FAE6D5440E25B5837DE014A40BFF04A92E76E5440E25B5837DE014A40BFF04A92E76E5440F511F8C3CFFF49409B3BFA5FAE6D5440F511F8C3CFFF4940
29864	Факел Социализма	5	47	112	81.880826999999996	81.901677000000007	52.000269000000003	51.989283999999998	0103000020E61000000100000005000000C39B35785F785440603AADDBA0FE4940C39B35785F785440F01989D008004A408CA37213B5795440F01989D008004A408CA37213B5795440603AADDBA0FE4940C39B35785F785440603AADDBA0FE4940
29343	Поспелихинский	5	47	112	81.838336999999996	81.864056000000005	51.881199000000002	51.867849	0103000020E61000000100000005000000B6813B50A7755440E36E10AD15EF4940B6813B50A77554404B22FB20CBF04940687A89B14C7754404B22FB20CBF04940687A89B14C775440E36E10AD15EF4940B6813B50A7755440E36E10AD15EF4940
29002	Поспелиха	5	47	112	81.802736999999993	83.157684000000003	52.007581999999999	51.773482000000001	0103000020E610000001000000050000008192020B60735440B8054B7501E349408192020B60735440E6046D72F8004A408FC6A17E17CA5440E6046D72F8004A408FC6A17E17CA5440B8054B7501E349408192020B60735440B8054B7501E34940
29579	Поломошное	5	47	112	81.658719000000005	81.677287000000007	51.814881	51.801366000000002	0103000020E610000001000000050000003F90BC73286A54402C103D2993E649403F90BC73286A5440DE9046054EE8494062C092AB586B5440DE9046054EE8494062C092AB586B54402C103D2993E649403F90BC73286A54402C103D2993E64940
29605	Озимая	5	47	112	81.525605999999996	81.559455	51.855791000000004	51.839149999999997	0103000020E6100000010000000500000035255987A36154401D38674469EB494035255987A3615440079B3A8F8AED49405B25581CCE635440079B3A8F8AED49405B25581CCE6354401D38674469EB494035255987A36154401D38674469EB4940
1388	Новороссийский	5	47	112	81.368329000000003	81.391506000000007	51.847830000000002	51.834564	0103000020E61000000100000005000000C74ACCB392575440A0353FFED2EA4940C74ACCB392575440AA4885B185EC4940058C2E6F0E595440AA4885B185EC4940058C2E6F0E595440A0353FFED2EA4940C74ACCB392575440A0353FFED2EA4940
29227	Николаевка	5	47	112	82.044185999999996	82.080585999999997	51.892589000000001	51.862599000000003	0103000020E610000001000000050000003A3C84F1D3825440FA47DFA469EE49403A3C84F1D38254407AE2395B40F24940FDA02E52288554407AE2395B40F24940FDA02E5228855440FA47DFA469EE49403A3C84F1D3825440FA47DFA469EE4940
59371	Мамонтово	5	47	112	81.306794999999994	82.396091999999996	52.229796	51.529898000000003	0103000020E61000000100000005000000E2E47E87A2535440A01B9AB2D3C34940E2E47E87A2535440356090F4691D4A40438D429259995440356090F4691D4A40438D429259995440A01B9AB2D3C34940E2E47E87A2535440A01B9AB2D3C34940
26688	Красноярское	5	47	112	81.578965999999994	81.613219000000001	51.758996000000003	51.740206000000001	0103000020E61000000100000005000000BDDF68C70D655440C826F911BFDE4940BDDF68C70D655440BDE5EAC726E149404B92E7FA3E675440BDE5EAC726E149404B92E7FA3E675440C826F911BFDE4940BDDF68C70D655440C826F911BFDE4940
29770	Котляровка	5	47	112	81.835955999999996	81.866804999999999	52.116992000000003	52.105344000000002	0103000020E610000001000000050000004739984D80755440386A85E97B0D4A404739984D8075544063F20698F90E4A4098C0ADBB7977544063F20698F90E4A4098C0ADBB79775440386A85E97B0D4A404739984D80755440386A85E97B0D4A40
29799	Клепечиха	5	47	112	81.657128999999998	81.739648000000003	52.166034000000003	52.141561000000003	0103000020E610000001000000050000003410CB660E6A5440CDB1BCAB1E124A403410CB660E6A54401503249A40154A4051A39064566F54401503249A40154A4051A39064566F5440CDB1BCAB1E124A403410CB660E6A5440CDB1BCAB1E124A40
29308	Калмыцкие Мысы	5	47	112	82.256826000000004	82.303628000000003	51.907331999999997	51.875788999999997	0103000020E61000000100000005000000CDB051D66F90544028999CDA19F04940CDB051D66F905440A04E797423F44940988922A46E935440A04E797423F44940988922A46E93544028999CDA19F04940CDB051D66F90544028999CDA19F04940
174	Вавилонский	5	47	112	81.894615999999999	81.925113999999994	51.965152000000003	51.954779000000002	0103000020E610000001000000050000009D9E7763417954402CF4C13236FA49409D9E776341795440A2D5C9198AFB494097C45911357B5440A2D5C9198AFB494097C45911357B54402CF4C13236FA49409D9E7763417954402CF4C13236FA4940
29379	Большевик	5	47	112	81.731752	81.741624000000002	51.849843999999997	51.839160999999997	0103000020E6100000010000000500000016325706D56E5440118AADA069EB494016325706D56E5440D5592DB0C7EC4940707B82C4766F5440D5592DB0C7EC4940707B82C4766F5440118AADA069EB494016325706D56E5440118AADA069EB4940
29420	12 Лет Октября	5	47	112	81.809877999999998	81.839710999999994	51.726216000000001	51.704470999999998	0103000020E61000000100000005000000FEEF880AD57354407EFD101B2CDA4940FEEF880AD57354407DEA58A5F4DC4940DAC534D3BD7554407DEA58A5F4DC4940DAC534D3BD7554407EFD101B2CDA4940FEEF880AD57354407EFD101B2CDA4940
28952	Соловьиха	5	47	1848	84.09742	84.161219000000003	51.979222	51.959330000000001	0103000020E610000001000000050000007C7E18213C0655402D095053CBFA49407C7E18213C06554009C3802557FD49409B1F7F69510A554009C3802557FD49409B1F7F69510A55402D095053CBFA49407C7E18213C0655402D095053CBFA4940
28864	Петропавловское	5	47	1848	84.072689999999994	84.135679999999994	52.089089000000001	52.060039000000003	0103000020E61000000100000005000000C22FF5F3A604554006BEA25BAF074A40C22FF5F3A604554078B7B244670B4A4029AE2AFBAE08554078B7B244670B4A4029AE2AFBAE08554006BEA25BAF074A40C22FF5F3A604554006BEA25BAF074A40
28823	Паутово	5	47	1848	84.231161	84.296279999999996	52.224736999999998	52.203806999999998	0103000020E6100000010000000500000015C78157CB0E554012D90759161A4A4015C78157CB0E5540BF99982EC41C4A405E9D6340F6125540BF99982EC41C4A405E9D6340F612554012D90759161A4A4015C78157CB0E554012D90759161A4A40
28750	Новообинка	5	47	1848	83.997203999999996	84.090153000000001	52.241852000000002	52.217498999999997	0103000020E610000001000000050000002FDCB930D2FF5440D3F4D901D71B4A402FDCB930D2FF5440713C9F01F51E4A40B9A81611C5055540713C9F01F51E4A40B9A81611C5055540D3F4D901D71B4A402FDCB930D2FF5440D3F4D901D71B4A40
28730	Николаевка	5	47	1848	84.105811000000003	84.145705000000007	52.200899	52.179394000000002	0103000020E61000000100000005000000A723809BC5065540A08CF161F6164A40A723809BC50655404966F50EB7194A404777103B530955404966F50EB7194A404777103B53095540A08CF161F6164A40A723809BC5065540A08CF161F6164A40
28682	Камышенка	5	47	1848	84.363788999999997	84.427065999999996	52.025101999999997	51.992539000000001	0103000020E610000001000000050000004069A85148175540958098840BFF49404069A851481755403788D68A36034A40F2CEA10C551B55403788D68A36034A40F2CEA10C551B5540958098840BFF49404069A85148175540958098840BFF4940
28626	Зеленый Дол	5	47	1848	84.120892999999995	84.152953999999994	52.131185000000002	52.109011000000002	0103000020E610000001000000050000002E54FEB5BC075540BFF38B12F40D4A402E54FEB5BC075540E65C8AABCA104A40B6F292FFC9095540E65C8AABCA104A40B6F292FFC9095540BFF38B12F40D4A402E54FEB5BC075540BFF38B12F40D4A40
28557	Антоньевка	5	47	1848	83.962070999999995	83.999279000000001	52.027695999999999	51.977097000000001	0103000020E61000000100000005000000855B3E9292FD54408602B68311FD4940855B3E9292FD5440711DE38A8B034A401825E82FF4FF5440711DE38A8B034A401825E82FF4FF54408602B68311FD4940855B3E9292FD54408602B68311FD4940
28541	Алексеевка	5	47	1848	84.085409999999996	84.147681000000006	52.072589999999998	52.046138999999997	0103000020E610000001000000050000001630815B77055540FA08FCE1E7054A401630815B7705554021020EA14A094A40664F029B7309554021020EA14A094A40664F029B73095540FA08FCE1E7054A401630815B77055540FA08FCE1E7054A40
28193	Фирсово	5	47	1667	83.932677999999996	83.971575000000001	53.319920000000003	53.313313999999998	0103000020E61000000100000005000000B7EC10FFB0FB544081B053AC1AA84A40B7EC10FFB0FB54400DAB7823F3A84A401EA7E8482EFE54400DAB7823F3A84A401EA7E8482EFE544081B053AC1AA84A40B7EC10FFB0FB544081B053AC1AA84A40
27044	Таловка	5	47	1667	84.115538999999998	84.136568999999994	53.766314000000001	53.760300000000001	0103000020E61000000100000005000000679AB0FD640755400C93A98251E14A40679AB0FD64075540C53BC09316E24A406F29E78BBD085540C53BC09316E24A406F29E78BBD0855400C93A98251E14A40679AB0FD640755400C93A98251E14A40
26477	Старокрайчиково	5	47	1667	83.891436999999996	83.916822999999994	53.906675999999997	53.896282999999997	0103000020E61000000100000005000000705CC64D0DF95440FA7ABE66B9F24A40705CC64D0DF95440B7088CF50DF44A401E4E603AADFA5440B7088CF50DF44A401E4E603AADFA5440FA7ABE66B9F24A40705CC64D0DF95440FA7ABE66B9F24A40
28354	Сосновка	5	47	1667	84.025599999999997	84.035355999999993	53.125067999999999	53.117108000000002	0103000020E61000000100000005000000C4B12E6EA3015540CC0C1B65FD8E4A40C4B12E6EA301554058E36C3A02904A40E9EDCF454302554058E36C3A02904A40E9EDCF4543025540CC0C1B65FD8E4A40C4B12E6EA3015540CC0C1B65FD8E4A40
27492	Сорочий Лог	5	47	1667	84.133694000000006	84.173507999999998	53.585836	53.567695999999998	0103000020E61000000100000005000000F96A47718E085540F6083543AAC84A40F96A47718E085540E4688EACFCCA4A400A664CC11A0B5540E4688EACFCCA4A400A664CC11A0B5540F6083543AAC84A40F96A47718E085540F6083543AAC84A40
28116	Солнечное	5	47	1667	83.991804999999999	84.002899999999997	53.393622999999998	53.388010999999999	0103000020E6100000010000000500000098C0ADBB79FF54407FBE2D58AAB14A4098C0ADBB79FF544009FA0B3D62B24A40234A7B832F00554009FA0B3D62B24A40234A7B832F0055407FBE2D58AAB14A4098C0ADBB79FF54407FBE2D58AAB14A40
25361	Сибирский	5	47	1667	83.744956999999999	83.776488000000001	53.584169000000003	53.572615999999996	0103000020E6100000010000000500000048FB1F60ADEF54404A95287B4BC94A4048FB1F60ADEF5440242BBF0CC6CA4A40226FB9FAB1F15440242BBF0CC6CA4A40226FB9FAB1F154404A95287B4BC94A4048FB1F60ADEF54404A95287B4BC94A40
26621	Северный	5	47	1667	83.980863999999997	84.006798000000003	53.837088000000001	53.821469999999998	0103000020E61000000100000005000000B874CC79C6FE54409352D0ED25E94A40B874CC79C6FE5440E1EF17B325EB4A4068EBE0606F005540E1EF17B325EB4A4068EBE0606F0055409352D0ED25E94A40B874CC79C6FE54409352D0ED25E94A40
28163	Санниково	5	47	1667	83.950348000000005	83.984915000000001	53.356852000000003	53.336537999999997	0103000020E610000001000000050000006BF46A80D2FC54403DEE5BAD13AB4A406BF46A80D2FC544090C18A53ADAD4A40C095ECD808FF544090C18A53ADAD4A40C095ECD808FF54403DEE5BAD13AB4A406BF46A80D2FC54403DEE5BAD13AB4A40
59437	Рогуличный	5	47	1667	83.705476000000004	84.439858000000001	53.942847	52.909480000000002	0103000020E610000001000000050000003A07CF8426ED5440DC2E34D769744A403A07CF8426ED5440DC10E335AFF84A4093382BA2261C5540DC10E335AFF84A4093382BA2261C5540DC2E34D769744A403A07CF8426ED5440DC2E34D769744A40
28440	Рассказиха	5	47	1667	83.825158999999999	83.856654000000006	53.105525	53.075899999999997	0103000020E6100000010000000500000001C0B167CFF4544019E25817B7894A4001C0B167CFF4544088F4DBD7818D4A40357F4C6BD3F6544088F4DBD7818D4A40357F4C6BD3F6544019E25817B7894A4001C0B167CFF4544019E25817B7894A40
26533	Пурысево	5	47	1667	84.074127000000004	84.103133999999997	53.942847	53.930576000000002	0103000020E610000001000000050000000A302C7FBE045540A438471D1DF74A400A302C7FBE045540DC10E335AFF84A40C34659BF99065540DC10E335AFF84A40C34659BF99065540A438471D1DF74A400A302C7FBE045540A438471D1DF74A40
28083	Правда	5	47	1667	84.119977000000006	84.141976999999997	53.439321	53.431859000000003	0103000020E610000001000000050000006CD102B4AD075540DCBDDC2747B74A406CD102B4AD07554017B9A7AB3BB84A4030F2B2261609554017B9A7AB3BB84A4030F2B22616095540DCBDDC2747B74A406CD102B4AD075540DCBDDC2747B74A40
27177	Повалиха	5	47	1667	83.750078000000002	83.795218000000006	53.528410999999998	53.492747999999999	0103000020E61000000100000005000000BEDC274701F05440AF95D05D12BF4A40BEDC274701F054405FECBDF8A2C34A4032CC09DAE4F254405FECBDF8A2C34A4032CC09DAE4F25440AF95D05D12BF4A40BEDC274701F05440AF95D05D12BF4A40
26763	Первомайское	5	47	1667	83.993063000000006	84.043953000000002	53.735492000000001	53.708655999999998	0103000020E6100000010000000500000088F71C588EFF54409D0E643DB5DA4A4088F71C588EFF54401D3C139A24DE4A40E9633E20D00255401D3C139A24DE4A40E9633E20D00255409D0E643DB5DA4A4088F71C588EFF54409D0E643DB5DA4A40
27766	Октябрьское	5	47	1667	83.839730000000003	83.868223999999998	53.578304000000003	53.564942000000002	0103000020E6100000010000000500000016DEE522BEF554408411FB0450C84A4016DEE522BEF55440B0928FDD05CA4A408C6665FB90F75440B0928FDD05CA4A408C6665FB90F754408411FB0450C84A4016DEE522BEF554408411FB0450C84A40
27906	Новочесноковка (Демино)	5	47	1667	84.395041000000006	84.439858000000001	53.506743999999998	53.496369000000001	0103000020E6100000010000000500000011E50B5A48195540C6DFF60489BF4A4011E50B5A48195540DCB8C5FCDCC04A4093382BA2261C5540DCB8C5FCDCC04A4093382BA2261C5540C6DFF60489BF4A4011E50B5A48195540C6DFF60489BF4A40
26916	Новоповалиха	5	47	1667	84.075546000000003	84.112403999999998	53.747107	53.721145999999997	0103000020E61000000100000005000000FED5E3BED504554013D21A834EDC4A40FED5E3BED50455406CCEC133A1DF4A4022FC8BA0310755406CCEC133A1DF4A4022FC8BA03107554013D21A834EDC4A40FED5E3BED504554013D21A834EDC4A40
26683	Новокраюшкино	5	47	1667	83.923479	83.958001999999993	53.779038	53.764026000000001	0103000020E61000000100000005000000BDE2A9471AFB544098A59D9ACBE14A40BDE2A9471AFB5440AE2B6684B7E34A402AE09EE74FFD5440AE2B6684B7E34A402AE09EE74FFD544098A59D9ACBE14A40BDE2A9471AFB544098A59D9ACBE14A40
27869	Новокопылово	5	47	1667	84.313222999999994	84.347026	53.511198999999998	53.497225999999998	0103000020E61000000100000005000000B8567BD80B145540465C001AA5BF4A40B8567BD80B145540BB5F05F86EC14A4026378AAC35165540BB5F05F86EC14A4026378AAC35165540465C001AA5BF4A40B8567BD80B145540465C001AA5BF4A40
27085	Новоберезовка	5	47	1667	83.989883000000006	84.021692000000002	53.415295	53.394486999999998	0103000020E6100000010000000500000073F7393E5AFF54403CD9CD8C7EB24A4073F7393E5AFF54409E98F56228B54A406EA5D766630155409E98F56228B54A406EA5D766630155403CD9CD8C7EB24A4073F7393E5AFF54403CD9CD8C7EB24A40
21432	Новоалтайск	5	47	1667	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
28486	Нижняя Петровка	5	47	1667	83.837412	83.855395999999999	52.918809000000003	52.909480000000002	0103000020E61000000100000005000000CA51802898F55440DC2E34D769744A40CA51802898F554409F2287889B754A404548DDCEBEF654409F2287889B754A404548DDCEBEF65440DC2E34D769744A40CA51802898F55440DC2E34D769744A40
59444	Малая Повалиха	5	47	1667	83.705476000000004	84.439858000000001	53.942847	52.909480000000002	0103000020E610000001000000050000003A07CF8426ED5440DC2E34D769744A403A07CF8426ED5440DC10E335AFF84A4093382BA2261C5540DC10E335AFF84A4093382BA2261C5540DC2E34D769744A403A07CF8426ED5440DC2E34D769744A40
27550	Логовское	5	47	1667	84.185310999999999	84.216060999999996	53.505394000000003	53.492127000000004	0103000020E61000000100000005000000B325AB22DC0B5540433D7D04FEBE4A40B325AB22DC0B55401DCC26C0B0C04A403A3C84F1D30D55401DCC26C0B0C04A403A3C84F1D30D5540433D7D04FEBE4A40B325AB22DC0B5540433D7D04FEBE4A40
28404	Лесной	5	47	1667	83.959222999999994	83.987600999999998	53.251142999999999	53.234000999999999	0103000020E610000001000000050000008BA4DDE863FD54409B1DA9BEF39D4A408BA4DDE863FD544046CF2D7425A04A40CD1FD3DA34FF544046CF2D7425A04A40CD1FD3DA34FF54409B1DA9BEF39D4A408BA4DDE863FD54409B1DA9BEF39D4A40
26727	Лебяжье	5	47	1667	84.131296000000006	84.149405999999999	53.839739000000002	53.831445000000002	0103000020E610000001000000050000001F865627670855401CB62DCA6CEA4A401F865627670855407F164B917CEB4A40E0F42EDE8F0955407F164B917CEB4A40E0F42EDE8F0955401CB62DCA6CEA4A401F865627670855401CB62DCA6CEA4A40
27294	Казачий	5	47	1667	83.827189000000004	83.858765000000005	53.539495000000002	53.527849000000003	0103000020E610000001000000050000001AA721AAF0F45440F81C588E90C34A401AA721AAF0F4544082AD122C0EC54A40C47C7901F6F6544082AD122C0EC54A40C47C7901F6F65440F81C588E90C34A401AA721AAF0F45440F81C588E90C34A40
27457	Ильича (Черемшаека)	5	47	1667	84.008540999999994	84.022384000000002	53.554330999999998	53.5443	0103000020E6100000010000000500000035EB8CEF8B0055403D9B559FABC54A4035EB8CEF8B00554059147651F4C64A4009FD4CBD6E01554059147651F4C64A4009FD4CBD6E0155403D9B559FABC54A4035EB8CEF8B0055403D9B559FABC54A40
27347	Зудилово	5	47	1667	83.867729999999995	83.914935999999997	53.505538999999999	53.471020000000003	0103000020E6100000010000000500000084F068E388F7544087E123624ABC4A4084F068E388F7544020ED7F80B5C04A40B77BB94F8EFA544020ED7F80B5C04A40B77BB94F8EFA544087E123624ABC4A4084F068E388F7544087E123624ABC4A40
26993	Журавлиха	5	47	1667	84.211236999999997	84.258937000000003	53.789678000000002	53.772190000000002	0103000020E6100000010000000500000021AD31E8840D55402D26361FD7E24A4021AD31E8840D5540732F302B14E54A405CAE7E6C92105540732F302B14E54A405CAE7E6C921055402D26361FD7E24A4021AD31E8840D55402D26361FD7E24A40
27822	Жилино	5	47	1667	84.280551000000003	84.324757000000005	53.411150999999997	53.395325	0103000020E610000001000000050000000C772E8CF4115540462575029AB24A400C772E8CF4115540DD5B9198A0B44A406A8995D1C8145540DD5B9198A0B44A406A8995D1C8145540462575029AB24A400C772E8CF4115540462575029AB24A40
26856	Голышево	5	47	1667	83.912367000000003	83.930234999999996	53.686419999999998	53.673592999999997	0103000020E61000000100000005000000C7BC8E3864FA544042E8A04B38D64A40C7BC8E3864FA544000A94D9CDCD74A400DA661F888FB544000A94D9CDCD74A400DA661F888FB544042E8A04B38D64A40C7BC8E3864FA544042E8A04B38D64A40
59446	Волга	5	47	1667	83.978662999999997	84.001022000000006	53.634107999999998	53.627695000000003	0103000020E6100000010000000500000089B3226AA2FE54406E6E4C4F58D04A4089B3226AA2FE5440E41071732AD14A40E62494BE10005540E41071732AD14A40E62494BE100055406E6E4C4F58D04A4089B3226AA2FE54406E6E4C4F58D04A40
27213	Боровиха	5	47	1667	83.810875999999993	83.862258999999995	53.520043999999999	53.492083999999998	0103000020E610000001000000050000001F477364E5F354404371C79BFCBE4A401F477364E5F35440923D42CD90C24A40A06B5F402FF75440923D42CD90C24A40A06B5F402FF754404371C79BFCBE4A401F477364E5F354404371C79BFCBE4A40
28260	Бобровка	5	47	1667	83.857129999999998	83.906330999999994	53.196331000000001	53.161850999999999	0103000020E61000000100000005000000E99AC937DBF6544096E99788B7944A40E99AC937DBF654407218CC5F21994A407616BD5301FA54407218CC5F21994A407616BD5301FA544096E99788B7944A40E99AC937DBF6544096E99788B7944A40
27598	Бешенцево	5	47	1667	84.163230999999996	84.193549000000004	53.520890000000001	53.514273000000003	0103000020E6100000010000000500000060AC6F60720A5540A01B9AB2D3C14A4060AC6F60720A55401F680586ACC24A401B4B581B630C55401F680586ACC24A401B4B581B630C5540A01B9AB2D3C14A4060AC6F60720A5540A01B9AB2D3C14A40
27959	Баюновские Ключи	5	47	1667	84.155990000000003	84.214991999999995	53.341140000000003	53.320360999999998	0103000020E6100000010000000500000032207BBDFB095540F9F4D89601A94A4032207BBDFB095540C1ADBB79AAAB4A40B439CE6DC20D5540C1ADBB79AAAB4A40B439CE6DC20D5540F9F4D89601A94A4032207BBDFB095540F9F4D89601A94A40
26444	Акулово	5	47	1667	83.995129000000006	84.042901999999998	53.922007999999998	53.912097000000003	0103000020E6100000010000000500000047938B31B0FF5440CEE33098BFF44A4047938B31B0FF54403F53AF5B04F64A40B6BB07E8BE0255403F53AF5B04F64A40B6BB07E8BE025540CEE33098BFF44A4047938B31B0FF5440CEE33098BFF44A40
26117	Урываево	5	47	381	79.919949000000003	79.955010000000001	53.807605000000002	53.782597000000003	0103000020E610000001000000050000003A3FC571E0FA53404F7974232CE44A403A3FC571E0FA5340058BC3995FE74A40975643E21EFD5340058BC3995FE74A40975643E21EFD53404F7974232CE44A403A3FC571E0FA53404F7974232CE44A40
25961	Романово	5	47	381	80.482285000000005	80.532995	53.975310999999998	53.959198999999998	0103000020E610000001000000050000007D96E7C1DD1E54408EAD6708C7FA4A407D96E7C1DD1E5440EB36A8FDD6FC4A409E7B0F971C225440EB36A8FDD6FC4A409E7B0F971C2254408EAD6708C7FA4A407D96E7C1DD1E54408EAD6708C7FA4A40
25671	Подойниково	5	47	381	80.446855999999997	80.494906	53.873998999999998	53.853290000000001	0103000020E610000001000000050000005E81E849991C54407E00529B38ED4A405E81E849991C54404CDE0033DFEF4A400726378AAC1F54404CDE0033DFEF4A400726378AAC1F54407E00529B38ED4A405E81E849991C54407E00529B38ED4A40
25733	Первомайский	5	47	381	80.638035000000002	80.660268000000002	53.734315000000002	53.724263000000001	0103000020E6100000010000000500000004ADC090D5285440F75965A6B4DC4A4004ADC090D52854402BFBAE08FEDD4A401AA6B6D4412A54402BFBAE08FEDD4A401AA6B6D4412A5440F75965A6B4DC4A4004ADC090D5285440F75965A6B4DC4A40
25529	Панкрушиха	5	47	381	80.308352999999997	80.381611000000007	53.840243999999998	53.812156000000002	0103000020E61000000100000005000000E7A7380EBC13544006A051BAF4E74A40E7A7380EBC13544082548A1D8DEB4A40CF328B506C18544082548A1D8DEB4A40CF328B506C18544006A051BAF4E74A40E7A7380EBC13544006A051BAF4E74A40
26244	Павловский	5	47	381	80.504429000000002	80.517489999999995	53.645671	53.632928	0103000020E61000000100000005000000DB89929048205440815CE2C803D14A40DB89929048205440E17CEA58A5D24A407380608E1E215440E17CEA58A5D24A407380608E1E215440815CE2C803D14A40DB89929048205440815CE2C803D14A40
25859	Луковка	5	47	381	80.253906000000001	80.282966999999999	53.926451	53.908203999999998	0103000020E610000001000000050000008690F3FE3F105440560C570740F44A408690F3FE3F1054405A2C45F295F64A4039B69E211C1254405A2C45F295F64A4039B69E211C125440560C570740F44A408690F3FE3F105440560C570740F44A40
25902	Ленский	5	47	381	80.131843000000003	80.144437999999994	54.012369	54.001975999999999	0103000020E61000000100000005000000384D9F1D700854403EB0E3BF40004B40384D9F1D70085440FB3DB14E95014B402D93E1783E095440FB3DB14E95014B402D93E1783E0954403EB0E3BF40004B40384D9F1D700854403EB0E3BF40004B40
26004	Кызылту	5	47	381	80.414857999999995	80.425591999999995	53.995905999999998	53.988241000000002	0103000020E61000000100000005000000F99E91088D1A54407EC85BAE7EFE4A40F99E91088D1A5440F1F109D979FF4A401C5C3AE63C1B5440F1F109D979FF4A401C5C3AE63C1B54407EC85BAE7EFE4A40F99E91088D1A54407EC85BAE7EFE4A40
26340	Кривое	5	47	381	80.139415999999997	80.170516000000006	53.692824000000002	53.676217999999999	0103000020E6100000010000000500000081221631EC085440B77BB94F8ED64A4081221631EC08544024F1F274AED84A4077DCF0BBE90A544024F1F274AED84A4077DCF0BBE90A5440B77BB94F8ED64A4081221631EC085440B77BB94F8ED64A40
25810	Конево	5	47	381	80.542769000000007	80.568406999999993	53.873548	53.863216000000001	0103000020E61000000100000005000000171230BABC22544025B1A4DC7DEE4A40171230BABC2254403CBEBD6BD0EF4A4051F4C0C7602454403CBEBD6BD0EF4A4051F4C0C76024544025B1A4DC7DEE4A40171230BABC22544025B1A4DC7DEE4A40
26195	Зятьково	5	47	381	80.323131000000004	80.359530000000007	53.608632999999998	53.583308000000002	0103000020E61000000100000005000000B954A52DAE14544062BF27D6A9CA4A40B954A52DAE1454401822A7AFE7CD4A4094FB1D8A021754401822A7AFE7CD4A4094FB1D8A0217544062BF27D6A9CA4A40B954A52DAE14544062BF27D6A9CA4A40
26159	Зыково	5	47	381	80.060580000000002	80.090395000000001	53.830111000000002	53.816552999999999	0103000020E61000000100000005000000ABB2EF8AE0035440B03907CF84E84A40ABB2EF8AE00354406286C61341EA4A40342E1C08C90554406286C61341EA4A40342E1C08C9055440B03907CF84E84A40ABB2EF8AE0035440B03907CF84E84A40
1972	Заречный	5	47	381	80.429303000000004	80.436605999999998	53.816488999999997	53.811497000000003	0103000020E61000000100000005000000C8444AB3791B5440ACE63922DFE74A40C8444AB3791B5440994528B682E84A4031CF4A5AF11B5440994528B682E84A4031CF4A5AF11B5440ACE63922DFE74A40C8444AB3791B5440ACE63922DFE74A40
25785	Высокая Грива	5	47	381	80.613978000000003	80.661248000000001	53.925237000000003	53.909880000000001	0103000020E61000000100000005000000AA9D616A4B2754406AA4A5F276F44A40AA9D616A4B2754404B06802A6EF64A40E8A221E3512A54404B06802A6EF64A40E8A221E3512A54406AA4A5F276F44A40AA9D616A4B2754406AA4A5F276F44A40
26044	Велижанка	5	47	381	80.144679999999994	80.182777999999999	53.879413	53.854607999999999	0103000020E61000000100000005000000A818E76F42095440327381CB63ED4A40A818E76F42095440B056ED9A90F04A40691B7FA2B20B5440B056ED9A90F04A40691B7FA2B20B5440327381CB63ED4A40A818E76F42095440327381CB63ED4A40
26289	Борисовский	5	47	381	80.168225000000007	80.188186000000002	53.562871999999999	53.551442000000002	0103000020E61000000100000005000000A857CA32C40A544007D2C5A695C64A40A857CA32C40A5440C4EA8F300CC84A402AE44A3D0B0C5440C4EA8F300CC84A402AE44A3D0B0C544007D2C5A695C64A40A857CA32C40A544007D2C5A695C64A40
25628	Березовский	5	47	381	80.253871000000004	80.276589000000001	53.753241000000003	53.74306	0103000020E61000000100000005000000C899266C3F1054409E7B0F971CDF4A40C899266C3F105440D0807A336AE04A40BC5B59A2B3115440D0807A336AE04A40BC5B59A2B31154409E7B0F971CDF4A40C899266C3F1054409E7B0F971CDF4A40
26399	Береговое	5	47	381	80.120489000000006	80.144411000000005	53.769002	53.756898	0103000020E61000000100000005000000C7A17E17B607544033349E08E2E04A40C7A17E17B6075440804754A86EE24A40B18BA2073E095440804754A86EE24A40B18BA2073E09544033349E08E2E04A40C7A17E17B607544033349E08E2E04A40
26092	Алексеевский	5	47	381	80.018494000000004	80.025994999999995	53.928614000000003	53.918948999999998	0103000020E61000000100000005000000064B75012F01544090D8EE1EA0F54A40064B75012F015440CB4DD4D2DCF64A4002B7EEE6A9015440CB4DD4D2DCF64A4002B7EEE6A901544090D8EE1EA0F54A40064B75012F01544090D8EE1EA0F54A40
24509	имени Мамонтова	5	47	1693	82.800082000000003	82.809118999999995	53.099615	53.090282000000002	0103000020E610000001000000050000009207228B34B3544070B54E5C8E8B4A409207228B34B3544074982F2FC08C4A409FE40E9BC8B3544074982F2FC08C4A409FE40E9BC8B3544070B54E5C8E8B4A409207228B34B3544070B54E5C8E8B4A40
25142	Шахи	5	47	1693	83.350910999999996	83.375973999999999	53.345166999999996	53.328563000000003	0103000020E61000000100000005000000A033695375D654407CD6355A0EAA4A40A033695375D654404754A86E2EAC4A405D8940F50FD854404754A86E2EAC4A405D8940F50FD854407CD6355A0EAA4A40A033695375D654407CD6355A0EAA4A40
25272	Чернопятово	5	47	1693	83.156507000000005	83.188298000000003	53.403910000000003	53.377789999999997	0103000020E6100000010000000500000016A6EF3504CA5440BF60376C5BB04A4016A6EF3504CA54408143A852B3B34A40BEF90D130DCC54408143A852B3B34A40BEF90D130DCC5440BF60376C5BB04A4016A6EF3504CA5440BF60376C5BB04A40
24747	Черемное	5	47	1693	83.168508000000003	83.241828999999996	53.184407	53.152456000000001	0103000020E610000001000000050000005247C7D5C8CA54401C0A9FAD83934A405247C7D5C8CA5440A51309A69A974A405C8E57207ACF5440A51309A69A974A405C8E57207ACF54401C0A9FAD83934A405247C7D5C8CA54401C0A9FAD83934A40
25063	Урожайный	5	47	1693	83.152240000000006	83.171428000000006	53.279541999999999	53.268956000000003	0103000020E610000001000000050000002849D74CBEC95440100874266DA24A402849D74CBEC95440E1ED4108C8A34A40996725ADF8CA5440E1ED4108C8A34A40996725ADF8CA5440100874266DA24A402849D74CBEC95440100874266DA24A40
24887	Стуково	5	47	1693	83.308205000000001	83.363757000000007	53.226562999999999	53.197285999999998	0103000020E61000000100000005000000ADDD76A1B9D35440B5FAEAAA40994A40ADDD76A1B9D35440E8BD3104009D4A403BAC70CB47D75440E8BD3104009D4A403BAC70CB47D75440B5FAEAAA40994A40ADDD76A1B9D35440B5FAEAAA40994A40
24551	Советский	5	47	1693	82.897379000000001	82.907925000000006	53.157721000000002	53.148735000000002	0103000020E61000000100000005000000804754A86EB95440A2629CBF09934A40804754A86EB954403B72A43330944A40228E75711BBA54403B72A43330944A40228E75711BBA5440A2629CBF09934A40804754A86EB95440A2629CBF09934A40
25431	Сибирские Огни	5	47	1693	83.026124999999993	83.045331000000004	53.314987000000002	53.300857999999998	0103000020E61000000100000005000000E9263108ACC15440B75ED38382A64A40E9263108ACC1544024D5777E51A84A40AE9FFEB3E6C2544024D5777E51A84A40AE9FFEB3E6C25440B75ED38382A64A40E9263108ACC15440B75ED38382A64A40
24929	Сараи	5	47	1693	83.244290000000007	83.275425999999996	53.194513000000001	53.179366999999999	0103000020E610000001000000050000005A2F8672A2CF5440A67D737FF5964A405A2F8672A2CF5440CCD24ECDE5984A40F59D5F94A0D15440CCD24ECDE5984A40F59D5F94A0D15440A67D737FF5964A405A2F8672A2CF5440A67D737FF5964A40
24195	Рогозиха	5	47	1693	82.744459000000006	82.805068000000006	53.266914999999997	53.244332	0103000020E61000000100000005000000A08D5C37A5AF5440E2AE5E45469F4A40A08D5C37A5AF5440EAE74D452AA24A4098C3EE3B86B35440EAE74D452AA24A4098C3EE3B86B35440E2AE5E45469F4A40A08D5C37A5AF5440E2AE5E45469F4A40
25231	Прутской	5	47	1693	83.218373999999997	83.251566999999994	53.320022000000002	53.305394	0103000020E61000000100000005000000FD12F1D6F9CD544083328D2617A74A40FD12F1D6F9CD544011001C7BF6A84A402E7079AC19D0544011001C7BF6A84A402E7079AC19D0544083328D2617A74A40FD12F1D6F9CD544083328D2617A74A40
23716	Павловск	5	47	1693	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
25107	Озерный	5	47	1693	83.053927999999999	83.063873000000001	53.226734999999998	53.218654000000001	0103000020E61000000100000005000000AD156D8E73C35440DE91B1DAFC9B4A40AD156D8E73C35440E5ED08A7059D4A403C86C77E16C45440E5ED08A7059D4A403C86C77E16C45440DE91B1DAFC9B4A40AD156D8E73C35440DE91B1DAFC9B4A40
25175	Нагорный	5	47	1693	83.255519000000007	83.272839000000005	53.437367999999999	53.429755999999998	0103000020E610000001000000050000006D205D6C5AD0544040A19E3E02B74A406D205D6C5AD054409128B4ACFBB74A40B284B53176D154409128B4ACFBB74A40B284B53176D1544040A19E3E02B74A406D205D6C5AD0544040A19E3E02B74A40
24705	Молодежный	5	47	1693	82.727470999999994	82.741906999999998	53.061275000000002	53.052793999999999	0103000020E61000000100000005000000757286E28EAE544067B62BF4C1864A40757286E28EAE5440FD87F4DBD7874A401A6B7F677BAF5440FD87F4DBD7874A401A6B7F677BAF544067B62BF4C1864A40757286E28EAE544067B62BF4C1864A40
24294	Лебяжье	5	47	1693	82.774184000000005	82.801653999999999	53.185578	53.143149999999999	0103000020E6100000010000000500000089450C3B8CB1544011363CBD52924A4089450C3B8CB15440B56D1805C1974A40492D944C4EB35440B56D1805C1974A40492D944C4EB3544011363CBD52924A4089450C3B8CB1544011363CBD52924A40
22434	Красный Май	5	47	1693	83.101179999999999	83.115444999999994	53.341844000000002	53.335419000000002	0103000020E6100000010000000500000098C0ADBB79C6544080BA8102EFAA4A4098C0ADBB79C65440BB2A508BC1AB4A4026DF6C7363C75440BB2A508BC1AB4A4026DF6C7363C7544080BA8102EFAA4A4098C0ADBB79C6544080BA8102EFAA4A40
24137	Красная Дубрава	5	47	1693	82.811733000000004	82.830104000000006	53.287644999999998	53.274293	0103000020E610000001000000050000006005F86EF3B35440C84274081CA34A406005F86EF3B35440D0ED258DD1A44A40D811876C20B55440D0ED258DD1A44A40D811876C20B55440C84274081CA34A406005F86EF3B35440C84274081CA34A40
25007	Комсомольский	5	47	1693	83.369389999999996	83.402518999999998	53.277653000000001	53.260855999999997	0103000020E610000001000000050000000B5EF415A4D75440917BBABA63A14A400B5EF415A4D7544072512D228AA34A4031410DDFC2D9544072512D228AA34A4031410DDFC2D95440917BBABA63A14A400B5EF415A4D75440917BBABA63A14A40
24647	Колыванское	5	47	1693	82.858553999999998	82.913089999999997	53.043503999999999	53.016795000000002	0103000020E6100000010000000500000066F6798CF2B6544040DEAB5626824A4066F6798CF2B65440629F008A91854A407F130A1170BA5440629F008A91854A407F130A1170BA544040DEAB5626824A4066F6798CF2B6544040DEAB5626824A40
25338	Касмала	5	47	1693	83.237741999999997	83.254818	53.444588000000003	53.435431999999999	0103000020E61000000100000005000000AEB8382A37CF5440E1D05B3CBCB74A40AEB8382A37CF5440D7187442E8B84A40A81B28F04ED05440D7187442E8B84A40A81B28F04ED05440E1D05B3CBCB74A40AEB8382A37CF5440E1D05B3CBCB74A40
25475	Жуковка	5	47	1693	82.974480999999997	82.985547999999994	53.209411000000003	53.198591	0103000020E61000000100000005000000B2648EE55DBE5440D5230D6E6B994A40B2648EE55DBE54401A36CAFACD9A4A40D828EB3713BF54401A36CAFACD9A4A40D828EB3713BF5440D5230D6E6B994A40B2648EE55DBE5440D5230D6E6B994A40
24102	Елунино	5	47	1693	82.984973999999994	83.011627000000004	53.445262999999997	53.429057999999998	0103000020E61000000100000005000000425A63D009BF5440280B5F5FEBB64A40425A63D009BF5440368FC360FEB84A400A302C7FBEC05440368FC360FEB84A400A302C7FBEC05440280B5F5FEBB64A40425A63D009BF5440280B5F5FEBB64A40
24246	Бурановка	5	47	1693	82.721489000000005	82.749865999999997	53.246400999999999	53.229889	0103000020E610000001000000050000001FDB32E02CAE5440E65AB4006D9D4A401FDB32E02CAE5440D15966118A9F4A407898F6CDFDAF5440D15966118A9F4A407898F6CDFDAF5440E65AB4006D9D4A401FDB32E02CAE5440E65AB4006D9D4A40
24048	Боровиково	5	47	1693	82.839905000000002	82.859900999999994	53.414167999999997	53.405127999999998	0103000020E61000000100000005000000CDAFE600C1B55440D158FB3BDBB34A40CDAFE600C1B554405D86FF7403B54A400D33349E08B754405D86FF7403B54A400D33349E08B75440D158FB3BDBB34A40CDAFE600C1B55440D158FB3BDBB34A40
59415	Арбузовка	5	47	1693	82.515091999999996	83.474492999999995	53.744796000000001	52.983699000000001	0103000020E61000000100000005000000999B6F44F7A05440D00D4DD9E97D4A40999B6F44F7A054408718AF7955DF4A40944BE3175EDE54408718AF7955DF4A40944BE3175EDE5440D00D4DD9E97D4A40999B6F44F7A05440D00D4DD9E97D4A40
23415	Токарево	5	47	1710	81.194164000000001	81.242934000000005	52.078429999999997	52.047141000000003	0103000020E61000000100000005000000E083D72E6D4C54407FA65EB708064A40E083D72E6D4C54403C8386FE090A4A4089450C3B8C4F54403C8386FE090A4A4089450C3B8C4F54407FA65EB708064A40E083D72E6D4C54407FA65EB708064A40
23382	Солоновка	5	47	1710	81.383043999999998	81.416865000000001	51.995832999999998	51.974733999999998	0103000020E61000000100000005000000753BFBCA835854404E266E15C4FC4940753BFBCA8358544087A3AB7477FF4940367689EAAD5A544087A3AB7477FF4940367689EAAD5A54404E266E15C4FC4940753BFBCA835854404E266E15C4FC4940
23009	Поломошное	5	47	1710	81.470269999999999	81.510209000000003	52.294738000000002	52.269311000000002	0103000020E610000001000000050000008E9257E7185E5440FEB968C878224A408E9257E7185E5440B9718BF9B9254A40FE47A643A7605440B9718BF9B9254A40FE47A643A7605440FEB968C878224A408E9257E7185E5440FEB968C878224A40
23104	Петровский	5	47	1710	81.621223000000001	81.633287999999993	52.262703000000002	52.256998000000003	0103000020E6100000010000000500000079211D1EC267544097917A4FE5204A4079211D1EC2675440D2C77C40A0214A40C03C64CA87685440D2C77C40A0214A40C03C64CA8768544097917A4FE5204A4079211D1EC267544097917A4FE5204A40
23242	Павловка	5	47	1710	81.490185999999994	81.532990999999996	52.086931	52.071472	0103000020E6100000010000000500000040BD19355F5F5440344A97FE25094A4040BD19355F5F54401901158E200B4A40FD8348861C6254401901158E200B4A40FD8348861C625440344A97FE25094A4040BD19355F5F5440344A97FE25094A40
22880	Новичиха	5	47	1710	81.363648999999995	81.405511000000004	52.221283	52.190012000000003	0103000020E61000000100000005000000478E7406465754407DEC2E5052184A40478E74064657544094145800531C4A40C5CA68E4F359544094145800531C4A40C5CA68E4F35954407DEC2E5052184A40478E7406465754407DEC2E5052184A40
23155	Невский	5	47	1710	81.702556999999999	81.715214000000003	52.303384999999999	52.291305999999999	0103000020E61000000100000005000000DBA4A2B1F66C54407590D78349254A40DBA4A2B1F66C5440698CD651D5264A400CE9F010C66D5440698CD651D5264A400CE9F010C66D54407590D78349254A40DBA4A2B1F66C54407590D78349254A40
23469	Мельниково	5	47	1710	81.189627999999999	81.230994999999993	52.217024000000002	52.193778000000002	0103000020E61000000100000005000000FA997ADD224C54409757AEB7CD184A40FA997ADD224C54403B394371C71B4A4087A2409FC84E54403B394371C71B4A4087A2409FC84E54409757AEB7CD184A40FA997ADD224C54409757AEB7CD184A40
23203	Мамонтово	5	47	1710	81.551333999999997	81.559886000000006	52.157609000000001	52.148530000000001	0103000020E6100000010000000500000010CB660E49635440C93CF20703134A4010CB660E4963544013471E882C144A4040DF162CD563544013471E882C144A4040DF162CD5635440C93CF20703134A4010CB660E49635440C93CF20703134A40
23057	Лобаниха	5	47	1710	81.692234999999997	81.709356999999997	52.241168000000002	52.224229999999999	0103000020E61000000100000005000000618907944D6C54401B649291B31C4A40618907944D6C5440BE6BD097DE1E4A40130CE71A666D5440BE6BD097DE1E4A40130CE71A666D54401B649291B31C4A40618907944D6C54401B649291B31C4A40
23278	Красноярка	5	47	1710	81.449465000000004	81.468528000000006	52.093167000000001	52.085348000000003	0103000020E6100000010000000500000096ECD808C45C5440B763EAAEEC0A4A4096ECD808C45C5440810871E5EC0B4A40A950DD5CFC5D5440810871E5EC0B4A40A950DD5CFC5D5440B763EAAEEC0A4A4096ECD808C45C5440B763EAAEEC0A4A40
23623	Ильинский	5	47	1710	81.222515000000001	81.245762999999997	52.390483000000003	52.373117999999998	0103000020E61000000100000005000000A5F78DAF3D4E544043C6A354C22F4A40A5F78DAF3D4E54406E52D158FB314A4047E4BB94BA4F54406E52D158FB314A4047E4BB94BA4F544043C6A354C22F4A40A5F78DAF3D4E544043C6A354C22F4A40
23572	Долгово	5	47	1710	81.173062999999999	81.209767999999997	52.357269000000002	52.333849000000001	0103000020E610000001000000050000007349D576134B5440B2666490BB2A4A407349D576134B5440F46F97FDBA2D4A40D4EFC2D66C4D5440F46F97FDBA2D4A40D4EFC2D66C4D5440B2666490BB2A4A407349D576134B5440B2666490BB2A4A40
23335	10 Лет Октября	5	47	1710	81.477394000000004	81.508304999999993	52.016916999999999	52.006135	0103000020E61000000100000005000000A053909F8D5E5440342E1C08C9004A40A053909F8D5E54408BDF14562A024A402BD9B111886054408BDF14562A024A402BD9B11188605440342E1C08C9004A40A053909F8D5E5440342E1C08C9004A40
59405	Николаевка	5	47	7480	78.715271999999999	78.738007999999994	53.228886000000003	53.214081	0103000020E61000000100000005000000A6EF3504C7AD5340F5D89601679B4A40A6EF3504C7AD53409241EE224C9D4A40ED0BE8853BAF53409241EE224C9D4A40ED0BE8853BAF5340F5D89601679B4A40A6EF3504C7AD5340F5D89601679B4A40
22785	Шумановка	5	47	1685	78.910044999999997	78.936077999999995	53.265202000000002	53.253740000000001	0103000020E61000000100000005000000DA38622D3EBA5340F1D7648D7AA04A40DA38622D3EBA5340BA6A9E23F2A14A405320B3B3E8BB5340BA6A9E23F2A14A405320B3B3E8BB5340F1D7648D7AA04A40DA38622D3EBA5340F1D7648D7AA04A40
22749	Редкая Дубрава	5	47	1685	79.033904000000007	79.057862999999998	53.289124999999999	53.269311999999999	0103000020E6100000010000000500000008CDAE7B2BC25340CE35CCD078A24A4008CDAE7B2BC253405EBA490C02A54A4080290307B4C353405EBA490C02A54A4080290307B4C35340CE35CCD078A24A4008CDAE7B2BC25340CE35CCD078A24A40
59399	Протасово	5	47	1685	78.557591000000002	79.371195	53.426295000000003	53.128300000000003	0103000020E61000000100000005000000D0622992AFA35340D50968226C904A40D0622992AFA3534063B9A5D590B64A40145CACA8C1D7534063B9A5D590B64A40145CACA8C1D75340D50968226C904A40D0622992AFA35340D50968226C904A40
22711	Подсосново	5	47	1685	78.901725999999996	78.934048000000004	53.383735999999999	53.362521000000001	0103000020E61000000100000005000000FCFCF7E0B5B953407E8E8F1667AE4A40FCFCF7E0B5B953402026E1421EB14A403B394371C7BB53402026E1421EB14A403B394371C7BB53407E8E8F1667AE4A40FCFCF7E0B5B953407E8E8F1667AE4A40
22394	Кусак	5	47	1685	78.923716999999996	78.945852000000002	53.229069000000003	53.215591000000003	0103000020E610000001000000050000009770E82D1EBB5340EE27637C989B4A409770E82D1EBB534083C30B22529D4A40CCB6D3D688BC534083C30B22529D4A40CCB6D3D688BC5340EE27637C989B4A409770E82D1EBB5340EE27637C989B4A40
22469	Камыши	5	47	1685	78.769108000000003	78.801186999999999	53.340662000000002	53.330305000000003	0103000020E61000000100000005000000E3C5C21039B15340475A2A6F47AA4A40E3C5C21039B15340B77EFACF9AAB4A40BEBED6A546B35340B77EFACF9AAB4A40BEBED6A546B35340475A2A6F47AA4A40E3C5C21039B15340475A2A6F47AA4A40
22261	Гальбштадт	5	47	1685	78.978477999999996	78.998429999999999	53.236258999999997	53.216783	0103000020E61000000100000005000000C07630629FBE534015AA9B8BBF9B4A40C07630629FBE53405D3123BC3D9E4A401956F146E6BF53405D3123BC3D9E4A401956F146E6BF534015AA9B8BBF9B4A40C07630629FBE534015AA9B8BBF9B4A40
21911	Ракиты	5	47	1674	79.862088	79.911890999999997	51.856324999999998	51.834308	0103000020E610000001000000050000008A9125732CF753404565C39ACAEA49408A9125732CF75340A4DFBE0E9CED494012A1116C5CFA5340A4DFBE0E9CED494012A1116C5CFA53404565C39ACAEA49408A9125732CF753404565C39ACAEA4940
21926	Полуямки	5	47	1674	79.678085999999993	79.716641999999993	52.084761999999998	52.062514	0103000020E610000001000000050000000778D2C265EB534065C5707500084A400778D2C265EB5340C6F8307BD90A4A40293C6876DDED5340C6F8307BD90A4A40293C6876DDED534065C5707500084A400778D2C265EB534065C5707500084A40
22147	Николаевка	5	47	1674	79.398414000000002	79.429063999999997	51.934565999999997	51.917577000000001	0103000020E6100000010000000500000030116F9D7FD95340E947C32973F5494030116F9D7FD953400DFAD2DB9FF7494005F9D9C875DB53400DFAD2DB9FF7494005F9D9C875DB5340E947C32973F5494030116F9D7FD95340E947C32973F54940
22163	Неводное	5	47	1674	79.212534000000005	79.247380000000007	51.966056000000002	51.956299999999999	0103000020E6100000010000000500000070D234289ACD53401895D40968FA494070D234289ACD5340630D17B9A7FB4940CF6BEC12D5CF5340630D17B9A7FB4940CF6BEC12D5CF53401895D40968FA494070D234289ACD53401895D40968FA4940
21995	Назаровка	5	47	1674	79.625050000000002	79.653248000000005	52.033320000000003	52.019643000000002	0103000020E610000001000000050000005917B7D100E85340344C6DA983024A405917B7D100E85340C0266BD443044A405B0BB3D0CEE95340C0266BD443044A405B0BB3D0CEE95340344C6DA983024A405917B7D100E85340344C6DA983024A40
21649	Михайловское	5	47	1674	79.645954000000003	79.775526999999997	51.832676999999997	51.800446999999998	0103000020E610000001000000050000001B2E724F57E9534035971B0C75E649401B2E724F57E95340D190F12895EA49408F8AFF3BA2F15340D190F12895EA49408F8AFF3BA2F1534035971B0C75E649401B2E724F57E9534035971B0C75E64940
59391	Малиновое Озеро	5	47	1674	79.758279000000002	79.821251000000004	51.683172999999996	51.663902999999998	0103000020E61000000100000005000000978FA4A487F05340AF5B04C6FAD44940978FA4A487F053404E417E3672D74940ABB35A608FF453404E417E3672D74940ABB35A608FF45340AF5B04C6FAD44940978FA4A487F05340AF5B04C6FAD44940
22094	Бастан	5	47	1674	79.461853000000005	79.494022000000001	51.868766000000001	51.845654000000003	0103000020E61000000100000005000000CFA3E2FF8EDD5340A5DDE8633EEC4940CFA3E2FF8EDD534039F06AB933EF49404A60730E9EDF534039F06AB933EF49404A60730E9EDF5340A5DDE8633EEC4940CFA3E2FF8EDD5340A5DDE8633EEC4940
22019	Ащегуль	5	47	1674	79.766003999999995	79.788408000000004	52.135956	52.122256	0103000020E61000000100000005000000BB26A43506F15340B1DEA815A60F4A40BB26A43506F15340F5D8960167114A40E8F9D34675F25340F5D8960167114A40E8F9D34675F25340B1DEA815A60F4A40BB26A43506F15340B1DEA815A60F4A40
21514	Черная Курья	5	47	1630	81.484319999999997	81.522875999999997	52.566484000000003	52.539155000000001	0103000020E610000001000000050000001E335019FF5E5440C93CF20703454A401E335019FF5E544088DA368C82484A4040F7E5CC7661544088DA368C82484A4040F7E5CC76615440C93CF20703454A401E335019FF5E5440C93CF20703454A40
21440	Украинка	5	47	1630	81.463093000000001	81.485648999999995	52.854719000000003	52.836592000000003	0103000020E610000001000000050000006B80D250A35D5440310C5872156B4A406B80D250A35D54408A22A46E676D4A4072158BDF145F54408A22A46E676D4A4072158BDF145F5440310C5872156B4A406B80D250A35D5440310C5872156B4A40
21429	Травное	5	47	1630	81.850554000000002	81.895460999999997	52.593265000000002	52.573172	0103000020E61000000100000005000000D95E0B7A6F765440D07D39B35D494A40D95E0B7A6F765440446E861BF04B4A40FB75A73B4F795440446E861BF04B4A40FB75A73B4F795440D07D39B35D494A40D95E0B7A6F765440D07D39B35D494A40
21359	Суслово	5	47	1630	81.632667999999995	81.675157999999996	52.620379999999997	52.591617999999997	0103000020E61000000100000005000000724EECA17D685440CADC7C23BA4B4A40724EECA17D685440D68BA19C684F4A407F68E6C9356B5440D68BA19C684F4A407F68E6C9356B5440CADC7C23BA4B4A40724EECA17D685440CADC7C23BA4B4A40
21275	Покровка	5	47	1630	81.85633	81.900788000000006	52.784941000000003	52.764642000000002	0103000020E610000001000000050000005B25581CCE765440F392FFC9DF614A405B25581CCE76544010255AF278644A404628B682A679544010255AF278644A404628B682A6795440F392FFC9DF614A405B25581CCE765440F392FFC9DF614A40
21298	Первомайский	5	47	1630	81.652097999999995	81.672499000000002	52.922365999999997	52.910555000000002	0103000020E610000001000000050000005EF23FF9BB695440CA1AF5108D744A405EF23FF9BB6954409E78CE1610764A40EFE53E390A6B54409E78CE1610764A40EFE53E390A6B5440CA1AF5108D744A405EF23FF9BB695440CA1AF5108D744A40
21222	Островное (Семеновка)	5	47	1630	81.692639	81.775346999999996	52.719009999999997	52.671106999999999	0103000020E61000000100000005000000C93B8732546C5440EF8E8CD5E6554A40C93B8732546C54409CBF0985085C4A404F0306499F7154409CBF0985085C4A404F0306499F715440EF8E8CD5E6554A40C93B8732546C5440EF8E8CD5E6554A40
21184	Малые Бутырки	5	47	1630	81.646771000000001	81.679218000000006	52.740785000000002	52.722718999999998	0103000020E61000000100000005000000144031B2646954405299620E825C4A40144031B264695440062FFA0AD25E4A40B136C64E786B5440062FFA0AD25E4A40B136C64E786B54405299620E825C4A40144031B2646954405299620E825C4A40
20873	Костин Лог	5	47	1630	82.010992999999999	82.058396999999999	52.678271000000002	52.651023000000002	0103000020E6100000010000000500000009DFFB1BB4805440CFF8BEB854534A4009DFFB1BB4805440A1698995D1564A40CF4BC5C6BC835440A1698995D1564A40CF4BC5C6BC835440CFF8BEB854534A4009DFFB1BB4805440CFF8BEB854534A40
20772	Корчино	5	47	1630	81.666416999999996	81.703373999999997	52.996361	52.976097000000003	0103000020E61000000100000005000000E61F7D93A66A5440A35C1ABFF07C4A40E61F7D93A66A54404301DBC1887F4A40D4B66114046D54404301DBC1887F4A40D4B66114046D5440A35C1ABFF07C4A40E61F7D93A66A5440A35C1ABFF07C4A40
20819	Комсомольский	5	47	1630	81.600481000000002	81.648927	52.977739999999997	52.963700000000003	0103000020E61000000100000005000000A437DC476E665440DE9387855A7B4A40A437DC476E665440DAFE9595267D4A40739F1C0588695440DAFE9595267D4A40739F1C0588695440DE9387855A7B4A40A437DC476E665440DE9387855A7B4A40
20672	Кадниково	5	47	1630	81.900032999999993	81.960669999999993	52.889892000000003	52.855708999999997	0103000020E61000000100000005000000871403249A79544049F25CDF876D4A40871403249A7954406C7C26FBE7714A40E40F069E7B7D54406C7C26FBE7714A40E40F069E7B7D544049F25CDF876D4A40871403249A79544049F25CDF876D4A40
20628	Ермачиха	5	47	1630	81.615761000000006	81.655942999999994	53.043596000000001	53.016112	0103000020E61000000100000005000000BF49D3A0686754405D8940F50F824A40BF49D3A068675440431EC18D94854A40914259F8FA695440431EC18D94854A40914259F8FA6954405D8940F50F824A40BF49D3A0686754405D8940F50F824A40
20549	Гришенское	5	47	1630	81.415167999999994	81.478211000000002	53.021768000000002	52.994833	0103000020E610000001000000050000002096CD1C925A5440A4FD0FB0567F4A402096CD1C925A5440B70C384BC9824A4099654F029B5E5440B70C384BC9824A4099654F029B5E5440A4FD0FB0567F4A402096CD1C925A5440A4FD0FB0567F4A40
20517	Буканское	5	47	1630	81.775778000000003	81.820344000000006	52.814129000000001	52.790719000000003	0103000020E6100000010000000500000034BDC458A6715440B5A9BA4736654A4034BDC458A6715440D3DC0A6135684A4012DE1E8480745440D3DC0A6135684A4012DE1E8480745440B5A9BA4736654A4034BDC458A6715440B5A9BA4736654A40
20259	Устьянка	5	47	1231	81.586539000000002	81.620028000000005	51.156923999999997	51.12988	0103000020E6100000010000000500000007B5DFDA89655440C63368E89F90494007B5DFDA896554408FFAEB1516944940ADA6EB89AE6754408FFAEB1516944940ADA6EB89AE675440C63368E89F90494007B5DFDA89655440C63368E89F904940
19547	Успенка	5	47	1231	81.525318999999996	81.545298000000003	50.978718000000001	50.956290000000003	0103000020E61000000100000005000000EA3D95D39E615440F5BEF1B5677A4940EA3D95D39E615440D600A5A1467D4940C0249529E6625440D600A5A1467D4940C0249529E6625440F5BEF1B5677A4940EA3D95D39E615440F5BEF1B5677A4940
19952	Советский Путь	5	47	1231	81.266469000000001	81.293841	51.136696000000001	51.126387000000001	0103000020E610000001000000050000007619FED30D515440DDD1FF722D9049407619FED30D5154403CBF28417F914940554E7B4ACE5254403CBF28417F914940554E7B4ACE525440DDD1FF722D9049407619FED30D515440DDD1FF722D904940
19645	Самарка	5	47	1231	81.525812999999999	81.546662999999995	50.915052000000003	50.897416	0103000020E61000000100000005000000F2B391EBA66154401D740987DE724940F2B391EBA6615440D811876C20754940BABBCE86FC625440D811876C20754940BABBCE86FC6254401D740987DE724940F2B391EBA66154401D740987DE724940
20005	Ремовский	5	47	1231	81.216684999999998	81.239709000000005	51.133164000000001	51.119087999999998	0103000020E610000001000000050000002922C32ADE4D54404BAC8C463E8F49402922C32ADE4D5440958098840B914940A4E36A64574F5440958098840B914940A4E36A64574F54404BAC8C463E8F49402922C32ADE4D54404BAC8C463E8F4940
20190	Покровка	5	47	1231	81.409319999999994	81.461924999999994	51.194457999999997	51.172817999999999	0103000020E610000001000000050000005166834C325A54407F1475E61E9649405166834C325A54400839EFFFE39849401B0DE02D905D54400839EFFFE39849401B0DE02D905D54407F1475E61E9649405166834C325A54407F1475E61E964940
20075	Новенькое	5	47	1231	81.128461000000001	81.167978000000005	51.068080000000002	51.035376999999997	0103000020E61000000100000005000000EF737CB438485440EA03C93B87844940EF737CB4384854407FC16ED8B6884940A41CCC26C04A54407FC16ED8B6884940A41CCC26C04A5440EA03C93B87844940EF737CB438485440EA03C93B87844940
19901	Николаевка	5	47	1231	81.391919000000001	81.425147999999993	51.090499999999999	51.059894999999997	0103000020E6100000010000000500000096EB6D3315595440D218ADA3AA87494096EB6D3315595440DD240681958B49406DFDF49F355B5440DD240681958B49406DFDF49F355B5440D218ADA3AA87494096EB6D3315595440D218ADA3AA874940
19737	Масальский	5	47	1231	81.766058999999998	81.808531000000002	50.974668999999999	50.948965000000001	0103000020E610000001000000050000009DF3531C077154403A0664AF777949409DF3531C0771544067B62BF4C17C494057B3CEF8BE73544067B62BF4C17C494057B3CEF8BE7354403A0664AF777949409DF3531C077154403A0664AF77794940
20142	Локоть	5	47	1231	81.183357000000001	81.207539999999995	51.203279999999999	51.174523999999998	0103000020E61000000100000005000000889FFF1EBC4B5440FD2E6CCD56964940889FFF1EBC4B544027F73B14059A49402827DA55484D544027F73B14059A49402827DA55484D5440FD2E6CCD56964940889FFF1EBC4B5440FD2E6CCD56964940
12544	Крючки	5	47	1231	81.792001999999997	81.803472999999997	50.857365000000001	50.836942000000001	0103000020E6100000010000000500000076172829B07254400D535BEA206B494076172829B072544016DEE522BE6D4940048E041A6C73544016DEE522BE6D4940048E041A6C7354400D535BEA206B494076172829B07254400D535BEA206B4940
19479	Кировский	5	47	1231	81.489512000000005	81.516174000000007	51.017747	51.001153000000002	0103000020E61000000100000005000000F9BF232A545F54406AA510C825804940F9BF232A545F5440124DA08845824940EA42ACFE08615440124DA08845824940EA42ACFE086154406AA510C825804940F9BF232A545F54406AA510C825804940
19708	Золотуха	5	47	1231	81.520459000000002	81.537716000000003	50.829126000000002	50.798096999999999	0103000020E610000001000000050000002BFA43334F6154409204E10A286649402BFA43334F615440B421FFCC206A49404DA25EF069625440B421FFCC206A49404DA25EF0696254409204E10A286649402BFA43334F6154409204E10A28664940
19796	Ермошиха	5	47	1231	81.684572000000003	81.710812000000004	50.788868000000001	50.778446000000002	0103000020E6100000010000000500000078F01307D06B5440DCD9571EA463494078F01307D06B5440336E6AA0F9644940AE669DF17D6D5440336E6AA0F9644940AE669DF17D6D5440DCD9571EA463494078F01307D06B5440DCD9571EA4634940
19074	Горняк	5	47	1231	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
20442	Гилево	5	47	1231	81.770100999999997	81.811154000000002	51.142946000000002	51.117041999999998	0103000020E610000001000000050000007B67B455497154401421753BFB8E49407B67B45549715440098CF50D4C924940418177F2E9735440098CF50D4C924940418177F2E97354401421753BFB8E49407B67B455497154401421753BFB8E4940
19844	Георгиевка	5	47	1231	81.493662	81.527321999999998	51.150213000000001	51.131433999999999	0103000020E61000000100000005000000CA518028985F54408ECA4DD4D2904940CA518028985F54408F37F92D3A934940861DC6A4BF6154408F37F92D3A934940861DC6A4BF6154408ECA4DD4D2904940CA518028985F54408ECA4DD4D2904940
20391	Вторая Каменка	5	47	1231	81.736980000000003	81.765780000000007	51.065556000000001	51.041012000000002	0103000020E61000000100000005000000977329AE2A6F54402D5F97E13F854940977329AE2A6F54403E0796236488494094FB1D8A027154403E0796236488494094FB1D8A027154402D5F97E13F854940977329AE2A6F54402D5F97E13F854940
20303	Александровка	5	47	1231	81.678822999999994	81.705701000000005	51.141421000000001	51.129201999999999	0103000020E61000000100000005000000723106D6716B5440F549EEB089904940723106D6716B5440DBFB54151A9249404AF086342A6D5440DBFB54151A9249404AF086342A6D5440F549EEB089904940723106D6716B5440F549EEB089904940
18478	Черкасово	5	47	775	85.259957	85.288784000000007	53.262649000000003	53.256923	0103000020E610000001000000050000007157AF22A35055408C4B55DAE2A04A407157AF22A3505540DFA9807B9EA14A40EBE6E26F7B525540DFA9807B9EA14A40EBE6E26F7B5255408C4B55DAE2A04A407157AF22A35055408C4B55DAE2A04A40
18169	Червово	5	47	775	84.987219999999994	85.030051	53.496760000000002	53.471330999999999	0103000020E61000000100000005000000417DCB9C2E3F5540A54BFF9254BC4A40417DCB9C2E3F554001FBE8D495BF4A40938D075BEC41554001FBE8D495BF4A40938D075BEC415540A54BFF9254BC4A40417DCB9C2E3F5540A54BFF9254BC4A40
18040	Улус-Тараба	5	47	775	85.567216999999999	85.589522000000002	53.409385	53.398524999999999	0103000020E610000001000000050000000E2F88484D645540B7D100DE02B34A400E2F88484D6455408A3C49BA66B44A4071917BBABA6555408A3C49BA66B44A4071917BBABA655540B7D100DE02B34A400E2F88484D645540B7D100DE02B34A40
18596	Тяхта	5	47	775	85.460217999999998	85.490662	53.587204999999997	53.569347999999998	0103000020E61000000100000005000000F4C13236745D554081053065E0C84A40F4C13236745D55401A868F8829CB4A40F5D89601675F55401A868F8829CB4A40F5D89601675F554081053065E0C84A40F4C13236745D554081053065E0C84A40
18795	Тягун	5	47	775	85.460380000000001	85.496033999999995	53.473083000000003	53.461210000000001	0103000020E61000000100000005000000E1EEACDD765D5540494BE5ED08BB4A40E1EEACDD765D554094A5D6FB8DBC4A400FED6305BF5F554094A5D6FB8DBC4A400FED6305BF5F5540494BE5ED08BB4A40E1EEACDD765D5540494BE5ED08BB4A40
18553	Сунгай	5	47	775	85.526864000000003	85.550777999999994	53.655838000000003	53.642964999999997	0103000020E61000000100000005000000255CC823B86155407FBC57AD4CD24A40255CC823B8615540AEBCE47FF2D34A40CD565EF23F635540AEBCE47FF2D34A40CD565EF23F6355407FBC57AD4CD24A40255CC823B86155407FBC57AD4CD24A40
17983	Старая Тараба	5	47	775	85.462311999999997	85.513731000000007	53.407625000000003	53.394835999999998	0103000020E6100000010000000500000018231285965D554048A46DFC89B24A4018231285965D55401904560E2DB44A4040FCFCF7E06055401904560E2DB44A4040FCFCF7E060554048A46DFC89B24A4018231285965D554048A46DFC89B24A40
19015	Сосновый Лог	5	47	775	85.426675000000003	85.455663999999999	53.337784999999997	53.319291	0103000020E6100000010000000500000055C1A8A44E5B55401D740987DEA84A4055C1A8A44E5B5540280AF4893CAB4A40BB7D5699295D5540280AF4893CAB4A40BB7D5699295D55401D740987DEA84A4055C1A8A44E5B55401D740987DEA84A40
18657	Семено-Красилово	5	47	775	85.599044000000006	85.623586000000003	53.565716999999999	53.554485999999997	0103000020E610000001000000050000005D37A5BC56665540800BB265F9C64A405D37A5BC5666554047E5266A69C84A40950F41D5E867554047E5266A69C84A40950F41D5E8675540800BB265F9C64A405D37A5BC56665540800BB265F9C64A40
18366	Порошино	5	47	775	85.113945000000001	85.151926000000003	53.234864000000002	53.223807999999998	0103000020E61000000100000005000000BC22F8DF4A475540A54A94BDA59C4A40BC22F8DF4A475540FE800706109E4A40605AD427B9495540FE800706109E4A40605AD427B9495540A54A94BDA59C4A40BC22F8DF4A475540A54A94BDA59C4A40
18080	Петрушиха	5	47	775	85.337023000000002	85.351467999999997	53.507460999999999	53.490332000000002	0103000020E61000000100000005000000FDBFEAC8915555405517F032C3BE4A40FDBFEAC8915555406B7F677BF4C04A40CB65A3737E5655406B7F677BF4C04A40CB65A3737E5655405517F032C3BE4A40FDBFEAC8915555405517F032C3BE4A40
18270	Отрадное	5	47	775	85.645325	85.670038000000005	53.691091	53.680937999999998	0103000020E61000000100000005000000A3923A014D695540444DF4F928D74A40A3923A014D695540ACC77DAB75D84A40F24410E7E16A5540ACC77DAB75D84A40F24410E7E16A5540444DF4F928D74A40A3923A014D695540444DF4F928D74A40
18439	Октябрьский	5	47	775	85.316820000000007	85.349159999999998	53.292979000000003	53.277915999999998	0103000020E6100000010000000500000000AE64C7465455407F8461C092A34A4000AE64C74654554018B5FB5580A54A4091442FA35856554018B5FB5580A54A4091442FA3585655407F8461C092A34A4000AE64C7465455407F8461C092A34A40
6723	Озерное	5	47	775	85.195511999999994	85.213361000000006	53.686697000000002	53.668013999999999	0103000020E610000001000000050000006F7EC344834C554094A2957B81D54A406F7EC344834C554073A1F2AFE5D74A407B4FE5B4A74D554073A1F2AFE5D74A407B4FE5B4A74D554094A2957B81D54A406F7EC344834C554094A2957B81D54A40
59463	Новохмелевка	5	47	775	85.690537000000006	85.709860000000006	53.624935000000001	53.612378	0103000020E6100000010000000500000064EB19C2316C55401B65FD6662CE4A4064EB19C2316C55401990BDDEFDCF4A40452FA3586E6D55401990BDDEFDCF4A40452FA3586E6D55401B65FD6662CE4A4064EB19C2316C55401B65FD6662CE4A40
18972	Новоозерное	5	47	775	85.609447000000003	85.623864999999995	53.486319000000002	53.472803999999996	0103000020E610000001000000050000004D69FD2D0167554080B56AD784BC4A404D69FD2D01675540333674B33FBE4A409E077767ED675540333674B33FBE4A409E077767ED67554080B56AD784BC4A404D69FD2D0167554080B56AD784BC4A40
18228	Новая Тараба	5	47	775	85.253704999999997	85.305914999999999	53.387458000000002	53.373379999999997	0103000020E610000001000000050000003A75E5B33C505540807D74EACAAF4A403A75E5B33C5055406B49473998B14A40C616821C945355406B49473998B14A40C616821C94535540807D74EACAAF4A403A75E5B33C505540807D74EACAAF4A40
18868	Кытманушка	5	47	775	85.432191000000003	85.450605999999993	53.478045999999999	53.46969	0103000020E6100000010000000500000009A87004A95B55400EA14ACD1EBC4A4009A87004A95B5540E7FD7F9C30BD4A4068588CBAD65C5540E7FD7F9C30BD4A4068588CBAD65C55400EA14ACD1EBC4A4009A87004A95B55400EA14ACD1EBC4A40
17874	Кытманово	5	47	775	85.422794999999994	85.474564999999998	53.468034000000003	53.448079	0103000020E61000000100000005000000637AC2120F5B55401F8315A75AB94A40637AC2120F5B554042B5C189E8BB4A40E1B4E0455F5E554042B5C189E8BB4A40E1B4E0455F5E55401F8315A75AB94A40637AC2120F5B55401F8315A75AB94A40
18147	Курья	5	47	775	85.359418000000005	85.378812999999994	53.480693000000002	53.469571999999999	0103000020E6100000010000000500000000E65AB400575540048F6FEF1ABC4A4000E65AB4005755404435255987BD4A402D93E1783E5855404435255987BD4A402D93E1783E585540048F6FEF1ABC4A4000E65AB400575540048F6FEF1ABC4A40
18761	Каменка	5	47	775	85.700643999999997	85.729920000000007	53.547626999999999	53.532639000000003	0103000020E61000000100000005000000DF88EE59D76C55407EC9C6832DC44A40DF88EE59D76C55400BB43BA418C64A40912C6002B76E55400BB43BA418C64A40912C6002B76E55407EC9C6832DC44A40DF88EE59D76C55407EC9C6832DC44A40
17782	Калиновский	5	47	775	85.332127999999997	85.342979	53.544925999999997	53.534930000000003	0103000020E610000001000000050000007F85CC95415555401CD3139678C44A407F85CC9541555540BB5E9A22C0C54A40BF0D315EF3555540BB5E9A22C0C54A40BF0D315EF35555401CD3139678C44A407F85CC95415555401CD3139678C44A40
17842	Заречное	5	47	775	85.319344999999998	85.335909999999998	53.597546000000001	53.582886000000002	0103000020E6100000010000000500000008C9022670545540ECA529029CCA4A4008C902267054554085ED27637CCC4A408F19A88C7F55554085ED27637CCC4A408F19A88C7F555540ECA529029CCA4A4008C9022670545540ECA529029CCA4A40
5462	Жуланиха	5	47	775	85.500731999999999	85.538632000000007	53.797890000000002	53.775249000000002	0103000020E61000000100000005000000E2033BFE0B605540DCA0F65B3BE34A40E2033BFE0B60554019E76F4221E64A4010255AF27862554019E76F4221E64A4010255AF278625540DCA0F65B3BE34A40E2033BFE0B605540DCA0F65B3BE34A40
17741	Дмитро-Титово	5	47	775	85.223144000000005	85.250919999999994	53.596696000000001	53.570236000000001	0103000020E610000001000000050000001D93C5FD474E55403D80457EFDC84A401D93C5FD474E5540B7D3D68860CC4A40637AC2120F505540B7D3D68860CC4A40637AC2120F5055403D80457EFDC84A401D93C5FD474E55403D80457EFDC84A40
18906	Беспалово	5	47	775	85.388334999999998	85.408349999999999	53.490380000000002	53.477397000000003	0103000020E6100000010000000500000019390B7BDA585540B11A4B581BBD4A4019390B7BDA585540664E97C5C4BE4A4095D40968225A5540664E97C5C4BE4A4095D40968225A5540B11A4B581BBD4A4019390B7BDA585540B11A4B581BBD4A40
17003	имени 8 Марта	5	47	1477	82.626042999999996	82.641807999999997	51.311239999999998	51.294944000000001	0103000020E61000000100000005000000F1B8A81611A85440621399B9C0A54940F1B8A81611A85440809A5AB6D6A74940EA93DC6113A95440809A5AB6D6A74940EA93DC6113A95440621399B9C0A54940F1B8A81611A85440621399B9C0A54940
17284	Усть-Таловка	5	47	1477	82.277154999999993	82.300188000000006	51.506807000000002	51.463890999999997	0103000020E61000000100000005000000103B53E8BC91544051F4C0C760BB4940103B53E8BC9154402331410DDFC04940B5A9BA47369354402331410DDFC04940B5A9BA473693544051F4C0C760BB4940103B53E8BC91544051F4C0C760BB4940
17348	Трусово	5	47	1477	82.463995999999995	82.505928999999995	51.714889999999997	51.698402999999999	0103000020E61000000100000005000000635E471CB29D5440D236FE4465D94940635E471CB29D5440641EF98381DB49404546072461A05440641EF98381DB49404546072461A05440D236FE4465D94940635E471CB29D5440D236FE4465D94940
17229	Ручьёво	5	47	1477	82.328027000000006	82.351552999999996	51.415075000000002	51.390329999999999	0103000020E610000001000000050000001F4DF564FE945440E7525C55F6B149401F4DF564FE9454409031772D21B54940E27327D87F9654409031772D21B54940E27327D87F965440E7525C55F6B149401F4DF564FE945440E7525C55F6B14940
17090	Подхоз	5	47	1477	82.530012999999997	82.539660999999995	51.335380999999998	51.328887000000002	0103000020E610000001000000050000001C5DA5BBEBA154402F8A1EF818AA49401C5DA5BBEBA154409259BDC3EDAA49404E7B4ACE89A254409259BDC3EDAA49404E7B4ACE89A254402F8A1EF818AA49401C5DA5BBEBA154402F8A1EF818AA4940
17529	Новофирсово	5	47	1477	82.181681999999995	82.203421000000006	51.760992000000002	51.739007000000001	0103000020E6100000010000000500000066118AADA08B5440EE4108C897DE494066118AADA08B54404242942F68E14940759483D9048D54404242942F68E14940759483D9048D5440EE4108C897DE494066118AADA08B5440EE4108C897DE4940
17665	Новознаменка	5	47	1477	82.274595000000005	82.283361999999997	51.663556999999997	51.655523000000002	0103000020E610000001000000050000004A29E8F6929154404E637B2DE8D349404A29E8F69291544014048F6FEFD4494077BB5E9A2292544014048F6FEFD4494077BB5E9A229254404E637B2DE8D349404A29E8F6929154404E637B2DE8D34940
17185	Курья	5	47	1477	82.270409000000001	82.311192000000005	51.620604	51.578713	0103000020E61000000100000005000000D2E28C614E9154409162804413CA4940D2E28C614E91544026E2ADF36FCF4940B8B1D991EA93544026E2ADF36FCF4940B8B1D991EA9354409162804413CA4940D2E28C614E9154409162804413CA4940
17490	Кузнецово	5	47	1477	81.998480000000001	82.029938999999999	51.695276999999997	51.662925999999999	0103000020E61000000100000005000000726DA818E77F544084D558C2DAD44940726DA818E77F54409B5434D6FED84940FF774485EA8154409B5434D6FED84940FF774485EA81544084D558C2DAD44940726DA818E77F544084D558C2DAD44940
17582	Краснознаменка	5	47	1477	82.260706999999996	82.271765000000002	51.691212999999998	51.678029000000002	0103000020E61000000100000005000000A6B5696CAF905440AB5E7EA7C9D64940A6B5696CAF905440F7C8E6AA79D84940A3CC069964915440F7C8E6AA79D84940A3CC069964915440AB5E7EA7C9D64940A6B5696CAF905440AB5E7EA7C9D64940
17035	Колывань	5	47	1477	82.346146000000005	82.594511999999995	51.330855999999997	51.084961	0103000020E610000001000000050000000A698D4127965440BD378600E08A49400A698D4127965440BAD7497D59AA494017450F7C0CA65440BAD7497D59AA494017450F7C0CA65440BD378600E08A49400A698D4127965440BD378600E08A4940
17125	Казанцево	5	47	1477	82.357805999999997	82.376383000000004	51.372757999999997	51.358840000000001	0103000020E610000001000000050000000114234BE6965440923F1878EEAD49400114234BE696544043A9BD88B6AF49404EF1B8A81698544043A9BD88B6AF49404EF1B8A816985440923F1878EEAD49400114234BE6965440923F1878EEAD4940
17369	Ивановка	5	47	1477	82.000024999999994	82.035373000000007	51.579335	51.544234000000003	0103000020E61000000100000005000000AC8BDB680080544086AFAF75A9C54940AC8BDB6800805440CE3637A627CA4940558A1D8D43825440CE3637A627CA4940558A1D8D4382544086AFAF75A9C54940AC8BDB680080544086AFAF75A9C54940
17439	Горновка	5	47	1477	82.087440000000001	82.104759000000001	51.507693000000003	51.500360000000001	0103000020E610000001000000050000002F17F19D98855440001DE6CB0BC049402F17F19D988554403EB48F15FCC049408CBD175FB48654403EB48F15FCC049408CBD175FB4865440001DE6CB0BC049402F17F19D98855440001DE6CB0BC04940
16955	Бугрышиха	5	47	1477	82.775406000000004	82.796058000000002	51.284281	51.273739999999997	0103000020E61000000100000005000000D2C77C40A0B15440B3CD8DE909A34940D2C77C40A0B15440E5EFDE5163A4494007EE409DF2B25440E5EFDE5163A4494007EE409DF2B25440B3CD8DE909A34940D2C77C40A0B15440B3CD8DE909A34940
16456	Троицк	5	47	1416	78.767831999999999	78.785008000000005	52.626306	52.610498999999997	0103000020E61000000100000005000000A034D42824B15340CF9ECBD4244E4A40A034D42824B15340F0A485CB2A504A404CC631923DB25340F0A485CB2A504A404CC631923DB25340CF9ECBD4244E4A40A034D42824B15340CF9ECBD4244E4A40
16258	Смирненькое	5	47	1416	79.233868999999999	79.258402000000004	52.534427999999998	52.519832000000001	0103000020E6100000010000000500000016A3AEB5F7CE534007B5DFDA89424A4016A3AEB5F7CE53408908FF2268444A4025CE8AA889D053408908FF2268444A4025CE8AA889D0534007B5DFDA89424A4016A3AEB5F7CE534007B5DFDA89424A40
16021	Сергеевка	5	47	1416	79.301180000000002	79.320565999999999	52.657299999999999	52.645029000000001	0103000020E61000000100000005000000658D7A8846D353405DFC6D4F90524A40658D7A8846D3534095D4096822544A40698D412784D4534095D4096822544A40698D412784D453405DFC6D4F90524A40658D7A8846D353405DFC6D4F90524A40
16246	Семеновка	5	47	1416	79.314700000000002	79.329783000000006	52.567283000000003	52.549045999999997	0103000020E610000001000000050000004703780B24D45340F3FFAA2347464A404703780B24D45340D449B6BA9C484A40B7F1272A1BD55340D449B6BA9C484A40B7F1272A1BD55340F3FFAA2347464A404703780B24D45340F3FFAA2347464A40
16178	Попасное	5	47	1416	78.709146000000004	78.730418	52.472619999999999	52.463568000000002	0103000020E61000000100000005000000B685E7A562AD53406FBC3B32563B4A40B685E7A562AD5340BFB7E9CF7E3C4A40399A232BBFAE5340BFB7E9CF7E3C4A40399A232BBFAE53406FBC3B32563B4A40B685E7A562AD53406FBC3B32563B4A40
16326	Октябрьский	5	47	1416	78.865595999999996	78.887119999999996	52.575887000000002	52.559252000000001	0103000020E6100000010000000500000019E3C3EC65B753407E1CCD9195474A4019E3C3EC65B7534085984BAAB6494A4029E8F692C6B8534085984BAAB6494A4029E8F692C6B853407E1CCD9195474A4019E3C3EC65B753407E1CCD9195474A40
16472	Новопетровка	5	47	1416	78.903791999999996	78.925702000000001	52.546126999999998	52.526265000000002	0103000020E61000000100000005000000BB9866BAD7B95340C503CAA65C434A40BB9866BAD7B95340363B527DE7454A40E0F599B33EBB5340363B527DE7454A40E0F599B33EBB5340C503CAA65C434A40BB9866BAD7B95340C503CAA65C434A40
16861	Мирабилит	5	47	1416	79.016701999999995	79.028199999999998	52.570014	52.558902000000003	0103000020E61000000100000005000000C7F143A511C15340A2D5C9198A474A40C7F143A511C153408E210038F6484A40D26F5F07CEC153408E210038F6484A40D26F5F07CEC15340A2D5C9198A474A40C7F143A511C15340A2D5C9198A474A40
16094	Курск	5	47	1416	78.90249	78.936886000000001	52.451791999999998	52.436537000000001	0103000020E61000000100000005000000E4BD6A65C2B953403A3FC571E0374A40E4BD6A65C2B95340164CFC51D4394A402385B2F0F5BB5340164CFC51D4394A402385B2F0F5BB53403A3FC571E0374A40E4BD6A65C2B953403A3FC571E0374A40
15736	Кулунда	5	47	1416	78.904591999999994	78.964995000000002	52.585124	52.550770999999997	0103000020E61000000100000005000000490ED8D5E4B95340E84A04AA7F464A40490ED8D5E4B95340670DDE57E54A4A406D73637AC2BD5340670DDE57E54A4A406D73637AC2BD5340E84A04AA7F464A40490ED8D5E4B95340E84A04AA7F464A40
16710	Константиновка	5	47	1416	79.052778000000004	79.083967999999999	52.621822999999999	52.610773000000002	0103000020E61000000100000005000000B1FCF9B660C35340D12346CF2D4E4A40B1FCF9B660C35340477364E5974F4A40467A51BB5FC55340477364E5974F4A40467A51BB5FC55340D12346CF2D4E4A40B1FCF9B660C35340D12346CF2D4E4A40
16874	Кирей	5	47	1416	79.072640000000007	79.086600000000004	52.521602000000001	52.515064000000002	0103000020E610000001000000050000006A183E22A6C4534069ACFD9DED414A406A183E22A6C453409CC3B5DAC3424A405AF5B9DA8AC553409CC3B5DAC3424A405AF5B9DA8AC5534069ACFD9DED414A406A183E22A6C4534069ACFD9DED414A40
15990	Златополь	5	47	1416	79.246437	79.278605999999996	52.638826999999999	52.622534000000002	0103000020E610000001000000050000008FE1B19FC5CF5340F452B131AF4F4A408FE1B19FC5CF5340A1664815C5514A400A9E42AED4D15340A1664815C5514A400A9E42AED4D15340F452B131AF4F4A408FE1B19FC5CF5340F452B131AF4F4A40
16599	Екатериновка	5	47	1416	79.602044000000006	79.619812999999994	52.571809999999999	52.562733999999999	0103000020E6100000010000000500000032B08EE387E65340732CEFAA07484A4032B08EE387E653404CC3F01131494A40AE282504ABE753404CC3F01131494A40AE282504ABE75340732CEFAA07484A4032B08EE387E65340732CEFAA07484A40
16808	Городецк	5	47	1416	78.973896999999994	78.983518000000004	52.712479999999999	52.701518	0103000020E610000001000000050000000A2B155454BE534015C78157CB594A400A2B155454BE5340EC866D8B325B4A40C0417BF5F1BE5340EC866D8B325B4A40C0417BF5F1BE534015C78157CB594A400A2B155454BE534015C78157CB594A40
16738	Воздвиженка	5	47	1416	79.057377000000002	79.079952000000006	52.766593	52.750456	0103000020E61000000100000005000000BAA29410ACC35340228B34F10E604A40BAA29410ACC35340D82B2CB81F624A40FD4FFEEE1DC55340D82B2CB81F624A40FD4FFEEE1DC55340228B34F10E604A40BAA29410ACC35340228B34F10E604A40
16122	Виноградовка	5	47	1416	79.065938000000003	79.090804000000006	52.465170000000001	52.457987000000003	0103000020E610000001000000050000001364045438C45340207F69519F3A4A401364045438C45340488AC8B08A3B4A40259694BBCFC55340488AC8B08A3B4A40259694BBCFC55340207F69519F3A4A401364045438C45340207F69519F3A4A40
16635	Белоцерковка	5	47	1416	79.237596999999994	79.259534000000002	52.732579000000001	52.724361000000002	0103000020E610000001000000050000002C280CCA34CF5340BABF7ADCB75C4A402C280CCA34CF5340425E0F26C55D4A40CE8C7E349CD05340425E0F26C55D4A40CE8C7E349CD05340BABF7ADCB75C4A402C280CCA34CF5340BABF7ADCB75C4A40
16540	Ананьевка	5	47	1416	79.567808999999997	79.588820999999996	52.586432000000002	52.570272000000003	0103000020E61000000100000005000000F7578FFB56E453408AE942ACFE484A40F7578FFB56E45340F8A92A34104B4A40AC8C463EAFE55340F8A92A34104B4A40AC8C463EAFE553408AE942ACFE484A40F7578FFB56E453408AE942ACFE484A40
15648	Радостный	5	47	352	81.081999999999994	81.099230000000006	53.954307999999997	53.945554999999999	0103000020E610000001000000050000006891ED7C3F455440DEC83CF207F94A406891ED7C3F455440D427B9C326FA4A400E32C9C859465440D427B9C326FA4A400E32C9C859465440DEC83CF207F94A406891ED7C3F455440DEC83CF207F94A40
15160	Прыганка	5	47	352	80.781388000000007	80.829061999999993	53.973452000000002	53.951256999999998	0103000020E61000000100000005000000295FD04202325440A88B14CAC2F94A40295FD04202325440E71C3C139AFC4A40CE16105A0F355440E71C3C139AFC4A40CE16105A0F355440A88B14CAC2F94A40295FD04202325440A88B14CAC2F94A40
15418	Подборный	5	47	352	80.995249999999999	81.009478999999999	54.009352999999997	53.992427999999997	0103000020E6100000010000000500000004560E2DB23F54403DD175E107FF4A4004560E2DB23F54404B8FA67A32014B40ECBFCE4D9B4054404B8FA67A32014B40ECBFCE4D9B4054403DD175E107FF4A4004560E2DB23F54403DD175E107FF4A40
15607	Московский	5	47	352	80.617553000000001	80.636624999999995	54.012644000000002	54.003552999999997	0103000020E61000000100000005000000FDA204FD85275440BE66B96C74004B40FDA204FD85275440CD3E8F519E014B4039B4C876BE285440CD3E8F519E014B4039B4C876BE285440BE66B96C74004B40FDA204FD85275440BE66B96C74004B40
15557	Масляха	5	47	352	81.248853999999994	81.272012000000004	54.059986000000002	54.048304999999999	0103000020E61000000100000005000000A4DE5339ED4F5440DC9DB5DB2E064B40A4DE5339ED4F5440E31B0A9FAD074B40A70705A568515440E31B0A9FAD074B40A70705A568515440DC9DB5DB2E064B40A4DE5339ED4F5440DC9DB5DB2E064B40
15517	Маловолчанка	5	47	352	80.882925	80.935610999999994	54.085656999999998	54.059114000000001	0103000020E6100000010000000500000088F4DBD7813854402D5E2C0C91074B4088F4DBD78138544034D6FECEF60A4B40C8B1F50CE13B544034D6FECEF60A4B40C8B1F50CE13B54402D5E2C0C91074B4088F4DBD7813854402D5E2C0C91074B40
15460	Крутиха	5	47	352	81.187731999999997	81.232270999999997	53.989173000000001	53.945687	0103000020E61000000100000005000000691A14CD034C54404DA088450CF94A40691A14CD034C5440098B8A389DFE4A40CA332F87DD4E5440098B8A389DFE4A40CA332F87DD4E54404DA088450CF94A40691A14CD034C54404DA088450CF94A40
15362	Караси	5	47	352	81.224553999999998	81.249734000000004	53.848042999999997	53.828989999999997	0103000020E61000000100000005000000E78BBD175F4E5440035B25581CEA4A40E78BBD175F4E5440054D4BAC8CEC4A40C1AC50A4FB4F5440054D4BAC8CEC4A40C1AC50A4FB4F5440035B25581CEA4A40E78BBD175F4E5440035B25581CEA4A40
15300	Заковряшино	5	47	352	81.178830000000005	81.210494999999995	53.906326	53.879668000000002	0103000020E61000000100000005000000CC6262F3714B54403BAB05F698F04A40CC6262F3714B5440DBC1887D02F44A402D3E05C0784D5440DBC1887D02F44A402D3E05C0784D54403BAB05F698F04A40CC6262F3714B54403BAB05F698F04A40
15249	Долганка	5	47	352	81.024005000000002	81.064590999999993	54.150758000000003	54.106197000000002	0103000020E61000000100000005000000317C444C8941544077F700DD970D4B40317C444C8941544021CEC3094C134B406B274A422244544021CEC3094C134B406B274A422244544077F700DD970D4B40317C444C8941544077F700DD970D4B40
15207	Волчно-Бурлинская	5	47	352	80.749731999999995	80.811526999999998	54.065840999999999	54.028185999999998	0103000020E61000000100000005000000F030ED9BFB2F54403F1A4E999B034B40F030ED9BFB2F544033DE567A6D084B408B34F10EF033544033DE567A6D084B408B34F10EF03354403F1A4E999B034B40F030ED9BFB2F54403F1A4E999B034B40
1816	Буян	5	47	352	80.996086000000005	81.017295000000004	53.829165000000003	53.812454000000002	0103000020E6100000010000000500000039807EDFBF3F544090C01F7EFEE74A4039807EDFBF3F544072FE261422EA4A4099D87C5C1B41544072FE261422EA4A4099D87C5C1B41544090C01F7EFEE74A4039807EDFBF3F544090C01F7EFEE74A40
15057	Боровое	5	47	352	81.177167999999995	81.194541000000001	54.037455999999999	54.025187000000003	0103000020E61000000100000005000000747973B8564B544066A4DE5339034B40747973B8564B5440FD84B35BCB044B40CB2E185C734C5440FD84B35BCB044B40CB2E185C734C544066A4DE5339034B40747973B8564B544066A4DE5339034B40
1768	Большой Лог	5	47	352	81.080904000000004	81.102059999999994	53.882741000000003	53.879157999999997	0103000020E610000001000000050000006687F8872D4554402502D53F88F04A406687F8872D4554404FEB36A8FDF04A40B48EAA26884654404FEB36A8FDF04A40B48EAA26884654402502D53F88F04A406687F8872D4554402502D53F88F04A40
14924	Чинета	5	47	316	83.036886999999993	83.066468999999998	51.345767000000002	51.318952000000003	0103000020E6100000010000000500000071A94A5B5CC25440357F4C6BD3A8494071A94A5B5CC254409D84D21742AC4940A94C310741C454409D84D21742AC4940A94C310741C45440357F4C6BD3A8494071A94A5B5CC25440357F4C6BD3A84940
14456	Харлово	5	47	316	82.838836000000001	82.883536000000007	51.698352999999997	51.672058999999997	0103000020E6100000010000000500000047AD307DAFB55440C1FD800706D6494047AD307DAFB55440200890A163D94940AD3594DA8BB85440200890A163D94940AD3594DA8BB85440C1FD800706D6494047AD307DAFB55440C1FD800706D64940
14995	Усть-Чагырка	5	47	316	83.110844999999998	83.141064999999998	51.435242000000002	51.426442999999999	0103000020E61000000100000005000000357BA01518C75440D74D29AF95B64940357BA01518C754403EEC8502B6B749400E677E3507C954403EEC8502B6B749400E677E3507C95440D74D29AF95B64940357BA01518C75440D74D29AF95B64940
14901	Усть-Пустынка	5	47	316	83.178254999999993	83.205663000000001	51.477573999999997	51.458201000000003	0103000020E610000001000000050000004DD6A88768CB54404CFF9254A6BA49404DD6A88768CB5440BFB5132521BD4940D3BF249529CD5440BFB5132521BD4940D3BF249529CD54404CFF9254A6BA49404DD6A88768CB54404CFF9254A6BA4940
14680	Усть-Козлуха	5	47	316	83.11063	83.165543999999997	51.63532	51.608099000000003	0103000020E6100000010000000500000037FDD98F14C754407BDD2230D6CD494037FDD98F14C75440533F6F2A52D149402383DC4598CA5440533F6F2A52D149402383DC4598CA54407BDD2230D6CD494037FDD98F14C754407BDD2230D6CD4940
1532	Усть-Белое	5	47	316	82.928073999999995	82.951286999999994	51.468290000000003	51.453491999999997	0103000020E6100000010000000500000025917D9065BB5440B27F9E060CBA494025917D9065BB54409D853DEDF0BB49400987DEE2E1BC54409D853DEDF0BB49400987DEE2E1BC5440B27F9E060CBA494025917D9065BB5440B27F9E060CBA4940
1479	Суетка	5	47	316	82.678072999999998	82.717392000000004	51.471628000000003	51.451622999999998	0103000020E610000001000000050000003DD34B8C65AB54408A8F4FC8CEB949403DD34B8C65AB54405FF0694E5EBC49405F9A22C0E9AD54405FF0694E5EBC49405F9A22C0E9AD54408A8F4FC8CEB949403DD34B8C65AB54408A8F4FC8CEB94940
1731	Новошипуново	5	47	316	83.237067999999994	83.280313000000007	51.710352999999998	51.677052000000003	0103000020E6100000010000000500000066BB421F2CCF544080D8D2A3A9D6494066BB421F2CCF5440C8CEDBD8ECDA494032E9EFA5F0D15440C8CEDBD8ECDA494032E9EFA5F0D1544080D8D2A3A9D6494066BB421F2CCF544080D8D2A3A9D64940
14735	Маралиха	5	47	316	82.922872999999996	82.967276999999996	51.630048000000002	51.592042999999997	0103000020E610000001000000050000002157EA5910BB5440B169A510C8CB49402157EA5910BB54408274B169A5D04940124BCADDE7BD54408274B169A5D04940124BCADDE7BD5440B169A510C8CB49402157EA5910BB5440B169A510C8CB4940
14844	Куйбышево	5	47	316	82.978729999999999	83.006873999999996	51.564791	51.548938999999997	0103000020E610000001000000050000004D672783A3BE5440DD3F16A243C649404D672783A3BE54409E094D124BC84940554CA59F70C054409E094D124BC84940554CA59F70C05440DD3F16A243C649404D672783A3BE5440DD3F16A243C64940
1434	Краснощеково	5	47	316	82.704582000000002	82.773662999999999	51.682608999999999	51.652650999999999	0103000020E610000001000000050000006BD619DF17AD5440D15966118AD349406BD619DF17AD5440467A51BB5FD7494004C8D0B183B15440467A51BB5FD7494004C8D0B183B15440D15966118AD349406BD619DF17AD5440D15966118AD34940
14364	Карпово 2-е	5	47	316	82.638052999999999	82.656585000000007	51.726835999999999	51.714348999999999	0103000020E61000000100000005000000570740DCD5A854401477BCC96FDB4940570740DCD5A8544019C748F608DD4940D482177D05AA544019C748F608DD4940D482177D05AA54401477BCC96FDB4940570740DCD5A854401477BCC96FDB4940
1628	Карпово 1-е	5	47	316	82.638052999999999	82.656585000000007	51.726835999999999	51.714348999999999	0103000020E61000000100000005000000570740DCD5A854401477BCC96FDB4940570740DCD5A8544019C748F608DD4940D482177D05AA544019C748F608DD4940D482177D05AA54401477BCC96FDB4940570740DCD5A854401477BCC96FDB4940
1649	Березовка	5	47	316	82.932449000000005	82.983176999999998	51.870607	51.821818	0103000020E61000000100000005000000070C923EADBB5440CFA10C5531E94940070C923EADBB54409755D80C70EF49407B4B395FECBE54409755D80C70EF49407B4B395FECBE5440CFA10C5531E94940070C923EADBB5440CFA10C5531E94940
14234	Акимовка	5	47	316	82.572539000000006	82.599911000000006	51.598013000000002	51.574812000000001	0103000020E61000000100000005000000D02B9E7AA4A4544097AC8A7093C94940D02B9E7AA4A454409BCAA2B08BCC4940AF601BF164A654409BCAA2B08BCC4940AF601BF164A6544097AC8A7093C94940D02B9E7AA4A4544097AC8A7093C94940
14035	имени Фрунзе	5	47	206	86.329383000000007	86.344690999999997	52.590961999999998	52.578459000000002	0103000020E61000000100000005000000F0366F9C14955540D789CBF10A4A4A40F0366F9C14955540E1968FA4A44B4A406F0ED76A0F965540E1968FA4A44B4A406F0ED76A0F965540D789CBF10A4A4A40F0366F9C14955540D789CBF10A4A4A40
1379	Усть-Кажа	5	47	206	86.314642000000006	86.358444000000006	52.557099999999998	52.535096000000003	0103000020E61000000100000005000000ADFC321823945540371C96067E444A40ADFC321823945540014D840D4F474A40A35C1ABFF0965540014D840D4F474A40A35C1ABFF0965540371C96067E444A40ADFC321823945540371C96067E444A40
1293	Усть-Иша	5	47	206	85.951273999999998	85.980406000000002	52.193882000000002	52.163454000000002	0103000020E610000001000000050000003FE257ACE17C55404033880FEC144A403FE257ACE17C55403CA41820D1184A4057B3CEF8BE7E55403CA41820D1184A4057B3CEF8BE7E55404033880FEC144A403FE257ACE17C55404033880FEC144A40
13240	Ужлеп	5	47	206	86.183479000000005	86.202370999999999	52.255536999999997	52.246715999999999	0103000020E610000001000000050000002E20B41EBE8B554031B3CF63941F4A402E20B41EBE8B55407FF5B86FB5204A402AAA7EA5F38C55407FF5B86FB5204A402AAA7EA5F38C554031B3CF63941F4A402E20B41EBE8B554031B3CF63941F4A40
13387	Талый	5	47	206	86.034817000000004	86.055119000000005	52.323799000000001	52.316896	0103000020E61000000100000005000000121615713A825540DA1D520C90284A40121615713A8255401FBDE13E72294A40D998D711878355401FBDE13E72294A40D998D71187835540DA1D520C90284A40121615713A825540DA1D520C90284A40
13320	Тайна	5	47	206	86.332294000000005	86.354752000000005	52.199948999999997	52.179929999999999	0103000020E610000001000000050000000DAA0D4E44955540DEC83CF207174A400DAA0D4E4495554017EFC7ED97194A40338CBB41B496554017EFC7ED97194A40338CBB41B4965540DEC83CF207174A400DAA0D4E44955540DEC83CF207174A40
12956	Старая Суртайка	5	47	206	85.873047999999997	85.882238000000001	52.239016999999997	52.226309000000001	0103000020E61000000100000005000000A5F5B704E07755402EE57CB1F71C4A40A5F5B704E07755401118EB1B981E4A4076525F96767855401118EB1B981E4A4076525F96767855402EE57CB1F71C4A40A5F5B704E07755402EE57CB1F71C4A40
1279	Соусканиха	5	47	206	85.950896	85.9726	52.576931999999999	52.550809000000001	0103000020E610000001000000050000006C79E57ADB7C5540D6ABC8E880464A406C79E57ADB7C5540080264E8D8494A40BC0512143F7E5540080264E8D8494A40BC0512143F7E5540D6ABC8E880464A406C79E57ADB7C5540D6ABC8E880464A40
59442	Сосновка	5	47	206	85.779793999999995	86.805598000000003	52.630099000000001	52.014899	0103000020E610000001000000050000007DE71725E87155401EDFDE35E8014A407DE71725E8715540041F8315A7504A4046EEE9EA8EB35540041F8315A7504A4046EEE9EA8EB355401EDFDE35E8014A407DE71725E87155401EDFDE35E8014A40
831	Новозыково	5	47	206	86.171028000000007	86.199208999999996	52.163083999999998	52.152099999999997	0103000020E61000000100000005000000D2AC6C1FF28A55405DDC460378134A40D2AC6C1FF28A55401C40BFEFDF144A4068041BD7BF8C55401C40BFEFDF144A4068041BD7BF8C55405DDC460378134A40D2AC6C1FF28A55405DDC460378134A40
12985	Новая Суртайка	5	47	206	85.938715000000002	85.962277999999998	52.228785999999999	52.219909999999999	0103000020E61000000100000005000000F05014E8137C55401C08C902261C4A40F05014E8137C55402EE411DC481D4A4042EA76F6957D55402EE411DC481D4A4042EA76F6957D55401C08C902261C4A40F05014E8137C55401C08C902261C4A40
12914	Мост-Иша	5	47	206	85.881096999999997	85.895075000000006	52.209271000000001	52.203795999999997	0103000020E61000000100000005000000A3E6ABE4637855401E87C1FC151A4A40A3E6ABE46378554028806264C91A4A40E71DA7E84879554028806264C91A4A40E71DA7E8487955401E87C1FC151A4A40A3E6ABE4637855401E87C1FC151A4A40
13405	Мануильское	5	47	206	86.115486000000004	86.130649000000005	52.313834999999997	52.304541	0103000020E610000001000000050000005649641F6487554044A51133FB264A405649641F648755408AABCABE2B284A4054909F8D5C8855408AABCABE2B284A4054909F8D5C88554044A51133FB264A405649641F6487554044A51133FB264A40
13883	Макарьевское	5	47	206	86.448562999999993	86.469798999999995	52.558464000000001	52.542243999999997	0103000020E6100000010000000500000085CC9541B59C5540E2395B4068454A4085CC9541B59C554026FF93BF7B474A40622CD32F119E554026FF93BF7B474A40622CD32F119E5540E2395B4068454A4085CC9541B59C5540E2395B4068454A40
13465	Луговое	5	47	206	86.114487999999994	86.144429000000002	52.345283000000002	52.339440000000003	0103000020E6100000010000000500000034F279C553875540257A19C5722B4A4034F279C553875540B16EBC3B322C4A4004E621533E895540B16EBC3B322C4A4004E621533E895540257A19C5722B4A4034F279C553875540257A19C5722B4A40
13599	Лебяжье	5	47	206	86.119600000000005	86.143907999999996	52.60642	52.580112	0103000020E610000001000000050000008126C286A787554032022A1C414A4A408126C286A7875540F6D1A92B9F4D4A407F68E6C935895540F6D1A92B9F4D4A407F68E6C93589554032022A1C414A4A408126C286A787554032022A1C414A4A40
13036	Красногорское	5	47	206	86.161164999999997	86.222797999999997	52.314000999999998	52.279164000000002	0103000020E61000000100000005000000A1100187508A55403B1C5DA5BB234A40A1100187508A5540A5F44C2F31284A404FE78A52428E5540A5F44C2F31284A404FE78A52428E55403B1C5DA5BB234A40A1100187508A55403B1C5DA5BB234A40
13749	Карагуж	5	47	206	86.071612000000002	86.090727999999999	52.152304000000001	52.128205999999999	0103000020E6100000010000000500000013807F4A958455405393E00D69104A4013807F4A9584554066868DB27E134A403735D07CCE85554066868DB27E134A403735D07CCE8555405393E00D69104A4013807F4A958455405393E00D69104A40
13181	Карагайка	5	47	206	86.296936000000002	86.313428999999999	52.257168999999998	52.245547000000002	0103000020E610000001000000050000005340DAFF00935540C25087156E1F4A405340DAFF00935540C345EEE9EA204A408D2782380F945540C345EEE9EA204A408D2782380F945540C25087156E1F4A405340DAFF00935540C25087156E1F4A40
13543	Каменка	5	47	206	86.071109000000007	86.085239000000001	52.479992000000003	52.467435999999999	0103000020E61000000100000005000000E25CC30C8D8455408D7C5EF1D43B4A40E25CC30C8D845540BB2BBB60703D4A400056478E74855540BB2BBB60703D4A400056478E748555408D7C5EF1D43B4A40E25CC30C8D8455408D7C5EF1D43B4A40
13821	Кажа	5	47	206	86.380875000000003	86.412764999999993	52.467517999999998	52.450524000000001	0103000020E610000001000000050000004C3789416098554014083BC5AA394A404C378941609855404A253CA1D73B4A40BDFBE3BD6A9A55404A253CA1D73B4A40BDFBE3BD6A9A554014083BC5AA394A404C3789416098554014083BC5AA394A40
13684	Горный	5	47	206	86.061892	86.071871999999999	52.163504000000003	52.158239000000002	0103000020E6100000010000000500000094F8DC09F6835540D3F9F02C41144A4094F8DC09F6835540F261F6B2ED144A40E15F048D99845540F261F6B2ED144A40E15F048D99845540D3F9F02C41144A4094F8DC09F6835540D3F9F02C41144A40
12862	Быстрянка	5	47	206	85.818089000000001	85.853257999999997	52.30312	52.263761000000002	0103000020E61000000100000005000000E90DF7915B745540EA7AA2EBC2214A40E90DF7915B745540BB61DBA2CC264A40394371C79B765540BB61DBA2CC264A40394371C79B765540EA7AA2EBC2214A40E90DF7915B745540EA7AA2EBC2214A40
778	Березовка	5	47	206	85.803805999999994	85.846539000000007	52.359507999999998	52.337254999999999	0103000020E610000001000000050000000795B88E71735540CCB4FD2B2B2B4A400795B88E717355403F53AF5B042E4A4078F2E9B12D7655403F53AF5B042E4A4078F2E9B12D765540CCB4FD2B2B2B4A400795B88E71735540CCB4FD2B2B2B4A40
13971	Балыкса	5	47	206	86.551034000000001	86.569422000000003	52.554898999999999	52.533683000000003	0103000020E61000000100000005000000FB3E1C2444A3554031B77BB94F444A40FB3E1C2444A35540A3CA30EE06474A40DEE7F86871A45540A3CA30EE06474A40DEE7F86871A4554031B77BB94F444A40FB3E1C2444A3554031B77BB94F444A40
59439	Филатово	5	47	188	84.206097999999997	85.125793999999999	53.557695000000002	53.090795999999997	0103000020E610000001000000050000005871AAB5300D5540C64D0D349F8B4A405871AAB5300D55404512BD8C62C74A401D0247020D4855404512BD8C62C74A401D0247020D485540C64D0D349F8B4A405871AAB5300D5540C64D0D349F8B4A40
12178	Украинский	5	47	188	84.322888000000006	84.348769000000004	53.314073	53.302149999999997	0103000020E6100000010000000500000056116E32AA145540423EE8D9ACA64A4056116E32AA1455403FC7478B33A84A40F436363B521655403FC7478B33A84A40F436363B52165540423EE8D9ACA64A4056116E32AA145540423EE8D9ACA64A40
59471	Сохарево	5	47	188	84.851376000000002	84.872729000000007	53.321275	53.306297999999998	0103000020E610000001000000050000005B26C3F17C365540446ADAC534A74A405B26C3F17C365540DE02098A1FA94A405551BCCADA375540DE02098A1FA94A405551BCCADA375540446ADAC534A74A405B26C3F17C365540446ADAC534A74A40
12687	Романово	5	47	188	84.351015000000004	84.379069000000001	53.251573999999998	53.242747999999999	0103000020E61000000100000005000000F3599E0777165540AF95D05D129F4A40F3599E07771655400F43AB9333A04A405B7B9FAA421855400F43AB9333A04A405B7B9FAA42185540AF95D05D129F4A40F3599E0777165540AF95D05D129F4A40
11786	Пустынь	5	47	188	84.476913999999994	84.498616999999996	53.361097000000001	53.351132999999997	0103000020E610000001000000050000004A404CC2851E5540EFC517EDF1AC4A404A404CC2851E554084D72E6D38AE4A40B20E4757E91F554084D72E6D38AE4A40B20E4757E91F5540EFC517EDF1AC4A404A404CC2851E5540EFC517EDF1AC4A40
11902	Полковниково	5	47	188	84.620590000000007	84.670293999999998	53.223894000000001	53.197194000000003	0103000020E61000000100000005000000618E1EBFB7275540D57B2AA73D994A40618E1EBFB7275540A4E2FF8EA89C4A401F2DCE18E62A5540A4E2FF8EA89C4A401F2DCE18E62A5540D57B2AA73D994A40618E1EBFB7275540D57B2AA73D994A40
12672	Плотниково	5	47	188	84.728711000000004	84.763026999999994	53.424084999999998	53.410904000000002	0103000020E61000000100000005000000124F7633A32E5540D6E5948098B44A40124F7633A32E5540B1DCD26A48B64A40C2BD326FD5305540B1DCD26A48B64A40C2BD326FD5305540D6E5948098B44A40124F7633A32E5540D6E5948098B44A40
12139	Озеро-Красилово	5	47	188	84.346801999999997	84.384862999999996	53.183258000000002	53.167529999999999	0103000020E61000000100000005000000FE0B040132165540A88C7F9F71954A40FE0B0401321655407D5D86FF74974A40309C6B98A11855407D5D86FF74974A40309C6B98A1185540A88C7F9F71954A40FE0B040132165540A88C7F9F71954A40
12065	Овчинниково	5	47	188	84.489453999999995	84.515495999999999	53.221344000000002	53.208359000000002	0103000020E610000001000000050000005EB9DE36531F5540E469F981AB9A4A405EB9DE36531F55403A950C00559C4A40014EEFE2FD2055403A950C00559C4A40014EEFE2FD205540E469F981AB9A4A405EB9DE36531F5540E469F981AB9A4A40
685	Налобиха	5	47	188	84.574838999999997	84.615560000000002	53.212964999999997	53.186290999999997	0103000020E61000000100000005000000C85D8429CA24554002452C62D8974A40C85D8429CA245540A818E76F429B4A40732EC55565275540A818E76F429B4A40732EC5556527554002452C62D8974A40C85D8429CA24554002452C62D8974A40
11973	Малахово	5	47	188	84.379688999999999	84.423805000000002	53.364401999999998	53.345827999999997	0103000020E61000000100000005000000A96917D34C1855404205871744AC4A40A96917D34C1855406A4C88B9A4AE4A4067B8019F1F1B55406A4C88B9A4AE4A4067B8019F1F1B55404205871744AC4A40A96917D34C1855404205871744AC4A40
12536	Лучевое	5	47	188	84.668442999999996	84.681612999999999	53.330998999999998	53.324641999999997	0103000020E610000001000000050000005E0F26C5C72A55403A747ADE8DA94A405E0F26C5C72A55401D01DC2C5EAA4A40D2E1218C9F2B55401D01DC2C5EAA4A40D2E1218C9F2B55403A747ADE8DA94A405E0F26C5C72A55403A747ADE8DA94A40
12302	Лосиха	5	47	188	84.941917000000004	84.993148000000005	53.394396	53.379224999999998	0103000020E61000000100000005000000F9A23D5E483C5540AD69DE718AB04A40F9A23D5E483C55402CD670917BB24A409F05A1BC8F3F55402CD670917BB24A409F05A1BC8F3F5540AD69DE718AB04A40F9A23D5E483C5540AD69DE718AB04A40
12297	Логовое	5	47	188	84.366690000000006	84.380902000000006	53.291370000000001	53.284441999999999	0103000020E610000001000000050000004C7155D977175540EECD6F9868A44A404C7155D9771755408C84B69C4BA54A40C93EC8B2601855408C84B69C4BA54A40C93EC8B260185540EECD6F9868A44A404C7155D977175540EECD6F9868A44A40
11629	Косиха	5	47	188	84.548616999999993	84.613061999999999	53.379680999999998	53.341709999999999	0103000020E61000000100000005000000E5417A8A1C235540AB5B3D27BDAB4A40E5417A8A1C235540CFF4126399B04A40E71A66683C275540CFF4126399B04A40E71A66683C275540AB5B3D27BDAB4A40E5417A8A1C235540AB5B3D27BDAB4A40
12042	Контошино	5	47	188	84.408497999999994	84.440989999999999	53.225177000000002	53.213267000000002	0103000020E61000000100000005000000CF9ECBD4241A5540742843554C9B4A40CF9ECBD4241A5540DC679599D29C4A403CF71E2E391C5540DC679599D29C4A403CF71E2E391C5540742843554C9B4A40CF9ECBD4241A5540742843554C9B4A40
12405	Каркавино	5	47	188	84.763225000000006	84.800647999999995	53.346193	53.334290000000003	0103000020E61000000100000005000000569FABADD83055409FB0C403CAAA4A40569FABADD8305540548D5E0D50AC4A40E6E61BD13D335540548D5E0D50AC4A40E6E61BD13D3355409FB0C403CAAA4A40569FABADD83055409FB0C403CAAA4A40
12778	Глушинка	5	47	188	84.483732000000003	84.536696000000006	53.466346000000001	53.449193999999999	0103000020E61000000100000005000000D6011077F51E55409BC761307FB94A40D6011077F51E55406A4FC939B1BB4A4038F92D3A592255406A4FC939B1BB4A4038F92D3A592255409BC761307FB94A40D6011077F51E55409BC761307FB94A40
12207	Восход	5	47	188	84.353601999999995	84.370633999999995	53.345574999999997	53.338538	0103000020E610000001000000050000003673486AA1165540043A933655AB4A403673486AA116554058A835CD3BAC4A404832AB77B817554058A835CD3BAC4A404832AB77B8175540043A933655AB4A403673486AA1165540043A933655AB4A40
12539	Верх-Жилино	5	47	188	84.621947000000006	84.668137999999999	53.503304999999997	53.479101	0103000020E610000001000000050000001A36CAFACD2755408E3D7B2E53BD4A401A36CAFACD275540E674594C6CC04A40C0CDE2C5C22A5540E674594C6CC04A40C0CDE2C5C22A55408E3D7B2E53BD4A401A36CAFACD2755408E3D7B2E53BD4A40
12640	Верх-Бобровка	5	47	188	84.747620999999995	84.792518999999999	53.198306000000002	53.178401000000001	0103000020E610000001000000050000006133C005D92F55406F490ED8D5964A406133C005D92F5540E04C4C1762994A405A9D9CA1B8325540E04C4C1762994A405A9D9CA1B83255406F490ED8D5964A406133C005D92F55406F490ED8D5964A40
12744	Баюново	5	47	188	84.304293000000001	84.328897999999995	53.288048000000003	53.280074999999997	0103000020E61000000100000005000000B6D9588979135540AEB6627FD9A34A40B6D9588979135540D0D6C1C1DEA44A40116E32AA0C155540D0D6C1C1DEA44A40116E32AA0C155540AEB6627FD9A34A40B6D9588979135540AEB6627FD9A34A40
10995	Целинный	5	47	1153	79.222874000000004	79.246292999999994	52.262587000000003	52.246533999999997	0103000020E610000001000000050000003D484F9143CE534010AD156D8E1F4A403D484F9143CE534069AD68739C214A40F50EB743C3CF534069AD68739C214A40F50EB743C3CF534010AD156D8E1F4A403D484F9143CE534010AD156D8E1F4A40
11018	Северка	5	47	1153	79.243841000000003	79.292529000000002	52.140084999999999	52.120266000000001	0103000020E61000000100000005000000221B48179BCF53400E6954E0640F4A40221B48179BCF534080D4264EEE114A406C088ECBB8D2534080D4264EEE114A406C088ECBB8D253400E6954E0640F4A40221B48179BCF53400E6954E0640F4A40
11586	Покровка	5	47	1153	79.335145999999995	79.395476000000002	52.056224	52.038964999999997	0103000020E61000000100000005000000A758350873D5534025581CCEFC044A40A758350873D553400AA0185932074A409696917A4FD953400AA0185932074A409696917A4FD9534025581CCEFC044A40A758350873D5534025581CCEFC044A40
11139	Платовка	5	47	1153	79.051691000000005	79.061841999999999	52.356675000000003	52.347009999999997	0103000020E61000000100000005000000D89FC4E74EC3534046B1DCD26A2C4A40D89FC4E74EC353408126C286A72D4A403BE12538F5C353408126C286A72D4A403BE12538F5C3534046B1DCD26A2C4A40D89FC4E74EC3534046B1DCD26A2C4A40
11484	Петухи	5	47	1153	79.524186999999998	79.560074999999998	52.250669000000002	52.231361999999997	0103000020E61000000100000005000000417FA1478CE15340C1C41F459D1D4A40417FA1478CE153407E8FFAEB15204A40A913D044D8E353407E8FFAEB15204A40A913D044D8E35340C1C41F459D1D4A40417FA1478CE15340C1C41F459D1D4A40
11263	Петровка	5	47	1153	79.324572000000003	79.338667000000001	52.463892000000001	52.451808	0103000020E61000000100000005000000A14CA3C9C5D453401C0934D8D4394A40A14CA3C9C5D45340227024D0603B4A40014F5AB8ACD55340227024D0603B4A40014F5AB8ACD553401C0934D8D4394A40A14CA3C9C5D453401C0934D8D4394A40
11195	Новополтава	5	47	1153	79.326324	79.347730999999996	52.430294000000004	52.402495999999999	0103000020E6100000010000000500000098F90E7EE2D45340AA622AFD84334A4098F90E7EE2D4534020D5B0DF13374A408B33863941D6534020D5B0DF13374A408B33863941D65340AA622AFD84334A4098F90E7EE2D45340AA622AFD84334A40
11358	Красный Яр	5	47	1153	79.592764000000003	79.611647000000005	52.465933	52.453119999999998	0103000020E61000000100000005000000C18F6AD8EFE55340EE940ED6FF394A40C18F6AD8EFE5534047904AB1A33B4A40946C753925E7534047904AB1A33B4A40946C753925E75340EE940ED6FF394A40C18F6AD8EFE55340EE940ED6FF394A40
10859	Ключи	5	47	1153	79.133967999999996	79.209138999999993	52.271642999999997	52.227395999999999	0103000020E6100000010000000500000079AD84EE92C85340E09EE74F1B1D4A4079AD84EE92C85340FA97A432C5224A405C548B8862CD5340FA97A432C5224A405C548B8862CD5340E09EE74F1B1D4A4079AD84EE92C85340E09EE74F1B1D4A40
11448	Каип	5	47	1153	79.766560999999996	79.808269999999993	52.259776000000002	52.235405	0103000020E61000000100000005000000E658DE550FF153404E2844C0211E4A40E658DE550FF153409224085740214A40A01518B2BAF353409224085740214A40A01518B2BAF353404E2844C0211E4A40E658DE550FF153404E2844C0211E4A40
11158	Истимис	5	47	1153	79.279037000000002	79.307962000000003	52.379005999999997	52.359909000000002	0103000020E61000000100000005000000EF5701BEDBD153409E44847F112E4A40EF5701BEDBD153406F7EC34483304A404A9A3FA6B5D353406F7EC34483304A404A9A3FA6B5D353409E44847F112E4A40EF5701BEDBD153409E44847F112E4A40
11295	Зеленая Поляна	5	47	1153	79.628337999999999	79.645270999999994	52.406325000000002	52.395819000000003	0103000020E61000000100000005000000613596B036E8534056116E32AA324A40613596B036E853400B46257502344A40A983BC1E4CE953400B46257502344A40A983BC1E4CE9534056116E32AA324A40613596B036E8534056116E32AA324A40
11534	Западный Угол	5	47	1153	79.567072999999993	79.583566000000005	52.130947999999997	52.123871000000001	0103000020E61000000100000005000000745C8DEC4AE453401FF64201DB0F4A40745C8DEC4AE4534001BD70E7C2104A40AF43352559E5534001BD70E7C2104A40AF43352559E553401FF64201DB0F4A40745C8DEC4AE453401FF64201DB0F4A40
11087	Васильчуки	5	47	1153	78.928712000000004	78.974005000000005	52.283251999999997	52.260503999999997	0103000020E61000000100000005000000C7D9740470BB5340143DF03158214A40C7D9740470BB53406743FE9941244A40FE48111956BE53406743FE9941244A40FE48111956BE5340143DF03158214A40C7D9740470BB5340143DF03158214A40
10614	Филипповский	5	47	1085	80.672332999999995	80.695536000000004	53.637065999999997	53.625895999999997	0103000020E6100000010000000500000061C1FD80072B54403E59315C1DD04A4061C1FD80072B54405FB2F1608BD14A40344C6DA9832C54405FB2F1608BD14A40344C6DA9832C54403E59315C1DD04A4061C1FD80072B54403E59315C1DD04A40
10746	Толстовский	5	47	1085	80.914321000000001	80.954663999999994	53.689357999999999	53.666434000000002	0103000020E61000000100000005000000F2423A3C843A5440A37895B54DD54A40F2423A3C843A5440349E08E23CD84A40C9AA0837193D5440349E08E23CD84A40C9AA0837193D5440A37895B54DD54A40F2423A3C843A5440A37895B54DD54A40
10827	Тамбовский	5	47	1085	80.876115999999996	80.898060999999998	53.717928000000001	53.710084000000002	0103000020E6100000010000000500000026E0D74812385440D9B45208E4DA4A4026E0D74812385440FC709010E5DB4A400934D8D479395440FC709010E5DB4A400934D8D479395440D9B45208E4DA4A4026E0D74812385440D9B45208E4DA4A40
9826	Столбово	5	47	1085	81.444299999999998	81.497524999999996	53.932876999999998	53.911772999999997	0103000020E61000000100000005000000386744696F5C54401A3048FAB4F44A40386744696F5C54406518778368F74A4050FC1873D75F54406518778368F74A4050FC1873D75F54401A3048FAB4F44A40386744696F5C54401A3048FAB4F44A40
10360	Самарский	5	47	1085	81.314960999999997	81.340903999999995	53.522266000000002	53.506438000000003	0103000020E61000000100000005000000FDA02E5228545440D0B9DBF5D2C04A40FDA02E522854544008E8BE9CD9C24A40D6C4025FD155544008E8BE9CD9C24A40D6C4025FD1555440D0B9DBF5D2C04A40FDA02E5228545440D0B9DBF5D2C04A40
10297	Рыбное	5	47	1085	81.383430000000004	81.429226	53.580117000000001	53.553190999999998	0103000020E610000001000000050000008A93FB1D8A58544084B872F6CEC64A408A93FB1D8A585440446D1B4641CA4A40F2255470785B5440446D1B4641CA4A40F2255470785B544084B872F6CEC64A408A93FB1D8A58544084B872F6CEC64A40
10538	Поперечное	5	47	1085	80.744637999999995	80.789400999999998	53.568401999999999	53.550811000000003	0103000020E61000000100000005000000F7562426A82F544077A38FF980C64A40F7562426A82F5440917D9065C1C84A40809BC58B85325440917D9065C1C84A40809BC58B8532544077A38FF980C64A40F7562426A82F544077A38FF980C64A40
10281	Плотниково	5	47	1085	81.513596000000007	81.533314000000004	53.547958999999999	53.538012000000002	0103000020E61000000100000005000000D0D6C1C1DE605440836DC493DDC44A40D0D6C1C1DE6054404146408523C64A40EF1F0BD1216254404146408523C64A40EF1F0BD121625440836DC493DDC44A40D0D6C1C1DE605440836DC493DDC44A40
9744	Октябрьский	5	47	1085	81.110710999999995	81.132890000000003	53.723495999999997	53.708570000000002	0103000020E61000000100000005000000AD1397E3154754409F76F86BB2DA4A40AD1397E315475440B66455849BDC4A40CAFD0E4581485440B66455849BDC4A40CAFD0E45814854409F76F86BB2DA4A40AD1397E3154754409F76F86BB2DA4A40
10059	Обское	5	47	1085	81.667710999999997	81.687545999999998	53.664306000000003	53.649540999999999	0103000020E610000001000000050000007C0BEBC6BB6A5440A034D42824D34A407C0BEBC6BB6A5440AF44A0FA07D54A40B81FF0C0006C5440AF44A0FA07D54A40B81FF0C0006C5440A034D42824D34A407C0BEBC6BB6A5440A034D42824D34A40
10726	Новоярки	5	47	1085	80.849714000000006	80.890344999999996	53.609091999999997	53.586044999999999	0103000020E61000000100000005000000043DD4B661365440FE7DC68503CB4A40043DD4B661365440AB2006BAF6CD4A400E4A9869FB385440AB2006BAF6CD4A400E4A9869FB385440FE7DC68503CB4A40043DD4B661365440FE7DC68503CB4A40
10108	Мыски	5	47	1085	81.532452000000006	81.547264999999996	53.694823	53.684170000000002	0103000020E6100000010000000500000026AC8DB113625440C173EFE192D74A4026AC8DB1136254401AC1C6F5EFD84A40B54FC763066354401AC1C6F5EFD84A40B54FC76306635440C173EFE192D74A4026AC8DB113625440C173EFE192D74A40
9967	Малетино	5	47	1085	81.386628000000002	81.412966999999995	54.045603	54.036408999999999	0103000020E61000000100000005000000F2ED5D83BE585440D923D40CA9044B40F2ED5D83BE585440BCCCB051D6054B40F1D4230D6E5A5440BCCCB051D6054B40F1D4230D6E5A5440D923D40CA9044B40F2ED5D83BE585440D923D40CA9044B40
10159	Луговое	5	47	1085	81.606894999999994	81.632891999999998	53.518973000000003	53.505367	0103000020E61000000100000005000000C746205ED766544023BDA8DDAFC04A40C746205ED7665440E6400FB56DC24A409A79724D81685440E6400FB56DC24A409A79724D8168544023BDA8DDAFC04A40C746205ED766544023BDA8DDAFC04A40
10447	Корнилово	5	47	1085	81.050200000000004	81.100335000000001	53.539757000000002	53.496980000000001	0103000020E6100000010000000500000097900F7A364354400F62670A9DBF4A4097900F7A36435440BF64E3C116C54A403AE97DE36B465440BF64E3C116C54A403AE97DE36B4654400F62670A9DBF4A4097900F7A364354400F62670A9DBF4A40
9899	Ключи	5	47	1085	81.469345000000004	81.487634999999997	53.977122000000001	53.962361000000001	0103000020E61000000100000005000000A2629CBF095E544012F92EA52EFB4A40A2629CBF095E5440DF196D5512FD4A40A3586E69355F5440DF196D5512FD4A40A3586E69355F544012F92EA52EFB4A40A2629CBF095E544012F92EA52EFB4A40
20390	Камень-на-Оби	5	47	1085	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
10199	Калиновка	5	47	1085	81.565338999999994	81.576676000000006	53.466661999999999	53.461300999999999	0103000020E61000000100000005000000D009A1832E645440594E42E90BBB4A40D009A1832E6454409A249694BBBB4A40D7187442E86454409A249694BBBB4A40D7187442E8645440594E42E90BBB4A40D009A1832E645440594E42E90BBB4A40
10656	Зеленая Дубрава	5	47	1085	80.701284999999999	80.717095999999998	53.683518999999997	53.676403999999998	0103000020E61000000100000005000000390B7BDAE12C54401971016894D64A40390B7BDAE12C5440E998F38C7DD74A40EA059FE6E42D5440E998F38C7DD74A40EA059FE6E42D54401971016894D64A40390B7BDAE12C54401971016894D64A40
9598	Духовая	5	47	1085	81.685874999999996	81.698361000000006	53.801900000000003	53.796953999999999	0103000020E6100000010000000500000037894160E56B54404C35B39602E64A4037894160E56B5440CA54C1A8A4E64A4052F355F2B16C5440CA54C1A8A4E64A4052F355F2B16C54404C35B39602E64A4037894160E56B54404C35B39602E64A40
9871	Дресвянка	5	47	1085	81.323646999999994	81.353211000000002	53.890107	53.866889999999998	0103000020E61000000100000005000000B41CE8A1B65454405E9D6340F6EE4A40B41CE8A1B65454406878B306EFF14A4099654F029B5654406878B306EFF14A4099654F029B5654405E9D6340F6EE4A40B41CE8A1B65454405E9D6340F6EE4A40
10016	Гонохово	5	47	1085	81.517027999999996	81.564081000000002	53.652172	53.636189999999999	0103000020E6100000010000000500000071C79BFC16615440680586AC6ED14A4071C79BFC16615440F7AE415F7AD34A40E1D231E719645440F7AE415F7AD34A40E1D231E719645440680586AC6ED14A4071C79BFC16615440680586AC6ED14A40
59445	Ветренотелеутское	5	47	1085	81.16328	81.194801999999996	53.464582	53.454262	0103000020E61000000100000005000000D105F52D734A544064E8D84125BA4A40D105F52D734A5440B727486C77BB4A4081CCCEA2774C5440B727486C77BB4A4081CCCEA2774C544064E8D84125BA4A40D105F52D734A544064E8D84125BA4A40
9665	Верх-Аллак	5	47	1085	81.645002000000005	81.677197000000007	53.898623000000001	53.880007999999997	0103000020E61000000100000005000000B2F677B647695440F31B261AA4F04A40B2F677B6476954407A37161406F34A40C2FC1532576B54407A37161406F34A40C2FC1532576B5440F31B261AA4F04A40B2F677B647695440F31B261AA4F04A40
9558	Аллак	5	47	1085	81.514439999999993	81.548406	53.810205000000003	53.789304999999999	0103000020E6100000010000000500000045F0BF95EC605440DEC83CF207E54A4045F0BF95EC605440210725CCB4E74A4088BB7A1519635440210725CCB4E74A4088BB7A1519635440DEC83CF207E54A4045F0BF95EC605440DEC83CF207E54A40
9712	III Интернационал	5	47	1085	81.582209000000006	81.604343999999998	53.882699000000002	53.876429999999999	0103000020E61000000100000005000000F69B89E942655440DC9DB5DB2EF04A40F69B89E942655440209BE447FCF04A402AE27492AD665440209BE447FCF04A402AE27492AD665440DC9DB5DB2EF04A40F69B89E942655440DC9DB5DB2EF04A40
9499	Шилово	5	47	1008	83.232864000000006	83.274977000000007	52.933950000000003	52.921442999999996	0103000020E610000001000000050000009C1A683EE7CE544066101FD8F1754A409C1A683EE7CE5440B30C71AC8B774A40BE89213999D15440B30C71AC8B774A40BE89213999D1544066101FD8F1754A409C1A683EE7CE544066101FD8F1754A40
9473	Шадрино	5	47	1008	83.607174000000001	83.653373999999999	53.124749999999999	53.105680999999997	0103000020E61000000100000005000000D13E56F0DBE654407F677BF4868D4A40D13E56F0DBE654408716D9CEF78F4A40A1832EE1D0E954408716D9CEF78F4A40A1832EE1D0E954407F677BF4868D4A40D13E56F0DBE654407F677BF4868D4A40
9422	Усть-Алейка	5	47	1008	83.566687000000002	83.594246999999996	52.831848000000001	52.813923000000003	0103000020E6100000010000000500000060048D9944E454402A3BFDA02E684A4060048D9944E454401B9FC9FE796A4A40C0AF912408E654401B9FC9FE796A4A40C0AF912408E654402A3BFDA02E684A4060048D9944E454402A3BFDA02E684A40
9349	Троицк	5	47	1008	83.530762999999993	83.567109000000002	52.896211000000001	52.877822999999999	0103000020E6100000010000000500000051BB5F05F8E154409B560A815C704A4051BB5F05F8E1544061A8C30AB7724A401B118C834BE4544061A8C30AB7724A401B118C834BE454409B560A815C704A4051BB5F05F8E154409B560A815C704A40
9293	Панфилово	5	47	1008	83.337068000000002	83.378551999999999	53.157083999999998	53.137813999999999	0103000020E61000000100000005000000CD21A98592D5544029779FE3A3914A40CD21A98592D55440C85C19541B944A4077F52A323AD85440C85C19541B944A4077F52A323AD8544029779FE3A3914A40CD21A98592D5544029779FE3A3914A40
24977	Новые Зори	5	47	1008	83.414008999999993	83.465905000000006	53.254385999999997	53.234189999999998	0103000020E61000000100000005000000FACF9A1F7FDA54406E861BF0F99D4A40FACF9A1F7FDA5440B6476FB88FA04A40BF823463D1DD5440B6476FB88FA04A40BF823463D1DD54406E861BF0F99D4A40FACF9A1F7FDA54406E861BF0F99D4A40
9210	Новороманово	5	47	1008	83.355249999999998	83.389099000000002	53.107146	53.073514000000003	0103000020E61000000100000005000000DBF97E6ABCD654402AE620E868894A40DBF97E6ABCD65440D8F2CAF5B68D4A4001FA7DFFE6D85440D8F2CAF5B68D4A4001FA7DFFE6D854402AE620E868894A40DBF97E6ABCD654402AE620E868894A40
9173	Новобарнаулка	5	47	1008	83.069396999999995	83.096948999999995	53.045572	53.034039999999997	0103000020E61000000100000005000000315C1D0071C45440BF60376C5B844A40315C1D0071C4544081CEA44DD5854A405018946934C6544081CEA44DD5854A405018946934C65440BF60376C5B844A40315C1D0071C45440BF60376C5B844A40
9107	Логовской	5	47	1008	83.359481000000002	83.376009999999994	52.859161999999998	52.853284000000002	0103000020E6100000010000000500000023A298BC01D754409C19FD68386D4A4023A298BC01D75440A4FB3905F96D4A40033E3F8C10D85440A4FB3905F96D4A40033E3F8C10D854409C19FD68386D4A4023A298BC01D754409C19FD68386D4A40
9097	Кубанка	5	47	1008	83.346446999999998	83.375489000000002	52.830063000000003	52.81906	0103000020E6100000010000000500000007B309302CD654401BBB44F5D6684A4007B309302CD65440514F1F813F6A4A407FC0030308D85440514F1F813F6A4A407FC0030308D854401BBB44F5D6684A4007B309302CD654401BBB44F5D6684A40
8970	Калманка	5	47	1008	83.503652000000002	83.575795999999997	52.913362999999997	52.890549999999998	0103000020E61000000100000005000000292499D53BE05440F5B9DA8AFD714A40292499D53BE054402F302B14E9744A40BA4A77D7D9E454402F302B14E9744A40BA4A77D7D9E45440F5B9DA8AFD714A40292499D53BE05440F5B9DA8AFD714A40
9040	Калистратиха	5	47	1008	83.567091000000005	83.611305999999999	52.997450999999998	52.976325000000003	0103000020E61000000100000005000000C8B60C384BE4544034A2B437F87C4A40C8B60C384BE45440662E7079AC7F4A404F7633A31FE75440662E7079AC7F4A404F7633A31FE7544034A2B437F87C4A40C8B60C384BE4544034A2B437F87C4A40
8929	Ивановка	5	47	1008	83.173745999999994	83.193714999999997	53.013007999999999	53.005465999999998	0103000020E61000000100000005000000E4F38AA71ECB5440B69E211CB3804A40E4F38AA71ECB54400E4B033FAA814A40A86F99D365CC54400E4B033FAA814A40A86F99D365CC5440B69E211CB3804A40E4F38AA71ECB5440B69E211CB3804A40
8883	Зимари	5	47	1008	83.447830999999994	83.479460000000003	53.192279999999997	53.178778999999999	0103000020E61000000100000005000000A3C85A43A9DC5440151BF33AE2964A40A3C85A43A9DC544062D68BA19C984A405FEFFE78AFDE544062D68BA19C984A405FEFFE78AFDE5440151BF33AE2964A40A3C85A43A9DC5440151BF33AE2964A40
8848	Бураново	5	47	1008	83.576137000000003	83.620971999999995	53.061101000000001	53.037672999999998	0103000020E61000000100000005000000FF40B96DDFE454409A780778D2844A40FF40B96DDFE454405F605628D2874A40D4EE5701BEE754405F605628D2874A40D4EE5701BEE754409A780778D2844A40FF40B96DDFE454409A780778D2844A40
59410	Алтай	5	47	1008	83.367997000000003	83.392674	53.009431999999997	52.996968000000003	0103000020E61000000100000005000000AC014A438DD754404B94BDA59C7F4A40AC014A438DD7544097C4591135814A4054FF209221D9544097C4591135814A4054FF209221D954404B94BDA59C7F4A40AC014A438DD754404B94BDA59C7F4A40
8743	Александровка	5	47	1008	83.382766000000004	83.411277999999996	53.054952999999998	53.044981999999997	0103000020E610000001000000050000005401F73C7FD854404F745DF8C1854A405401F73C7FD8544096E82CB308874A401DE4F56052DA544096E82CB308874A401DE4F56052DA54404F745DF8C1854A405401F73C7FD854404F745DF8C1854A40
1170	Шубенка	5	47	277	85.080940999999996	85.124446000000006	52.669234000000003	52.632941000000002	0103000020E61000000100000005000000F4F928232E45554016A6EF3504514A40F4F928232E45554086AFAF75A9554A408E075BECF647554086AFAF75A9554A408E075BECF647554016A6EF3504514A40F4F928232E45554016A6EF3504514A40
8286	Урожайный	5	47	277	84.919037000000003	84.932053999999994	52.714858999999997	52.708573999999999	0103000020E6100000010000000500000018B49080D13A5540E065868DB25A4A4018B49080D13A55402920ED7F805B4A40C806D2C5A63B55402920ED7F805B4A40C806D2C5A63B5540E065868DB25A4A4018B49080D13A5540E065868DB25A4A40
8602	Соколово	5	47	277	84.751069999999999	84.810799000000003	52.544134	52.518265	0103000020E610000001000000050000006EC0E78711305540AAD4EC8156424A406EC0E787113055402252D32EA6454A404A287D21E43355402252D32EA6454A404A287D21E4335540AAD4EC8156424A406EC0E78711305540AAD4EC8156424A40
8585	Савиново	5	47	277	84.843892999999994	84.871821999999995	52.521383	52.510762	0103000020E61000000100000005000000B114C95702365540100533A660414A40B114C957023655405ED89AADBC424A40BB7B80EECB3755405ED89AADBC424A40BB7B80EECB375540100533A660414A40B114C95702365540100533A660414A40
8461	Плешково	5	47	277	84.766890000000004	84.828218000000007	52.752713	52.735644000000001	0103000020E610000001000000050000004968CBB914315540D3BF2495295E4A404968CBB91431554014234BE658604A4059FD11860135554014234BE658604A4059FD118601355540D3BF2495295E4A404968CBB914315540D3BF2495295E4A40
8455	Октябрьский (Степной)	5	47	277	84.999751000000003	85.019388000000006	52.742257000000002	52.727977000000003	0103000020E610000001000000050000002C499EEBFB3F5540BF9EAF592E5D4A402C499EEBFB3F5540111D0247025F4A40D57B2AA73D415540111D0247025F4A40D57B2AA73D415540BF9EAF592E5D4A402C499EEBFB3F5540BF9EAF592E5D4A40
8368	Новая Чемровка	5	47	277	85.022299000000004	85.068481000000006	52.623604999999998	52.585720000000002	0103000020E61000000100000005000000F2EEC8586D4155407B4E7ADFF84A4A40F2EEC8586D415540A04FE449D24F4A406FD921FE61445540A04FE449D24F4A406FD921FE614455407B4E7ADFF84A4A40F2EEC8586D4155407B4E7ADFF84A4A40
8226	Новая Михайловка	5	47	277	84.843462000000002	84.870339999999999	52.664088999999997	52.653289999999998	0103000020E61000000100000005000000CD5A0A48FB355540E466B8019F534A40CD5A0A48FB35554011514CDE00554A40A4198BA6B337554011514CDE00554A40A4198BA6B3375540E466B8019F534A40CD5A0A48FB355540E466B8019F534A40
2531	Мирный	5	47	277	85.010513000000003	85.035871999999998	52.590589999999999	52.564003999999997	0103000020E61000000100000005000000B4CBB73EAC4055401668774831484A40B4CBB73EAC4055401DACFF73984B4A40E5B512BA4B4255401DACFF73984B4A40E5B512BA4B4255401668774831484A40B4CBB73EAC4055401668774831484A40
8354	Луговское	5	47	277	85.146220999999997	85.194864999999993	52.774977999999997	52.748249000000001	0103000020E61000000100000005000000423F53AF5B495540E2218C9FC65F4A40423F53AF5B4955404B8FA67A32634A40A4880CAB784C55404B8FA67A32634A40A4880CAB784C5540E2218C9FC65F4A40423F53AF5B495540E2218C9FC65F4A40
8527	Комарово	5	47	277	84.714374000000007	84.737452000000005	52.570031	52.552945000000001	0103000020E6100000010000000500000037C7B94DB82D55404DBED9E6C6464A4037C7B94DB82D5540645A9BC6F6484A40AB97DF69322F5540645A9BC6F6484A40AB97DF69322F55404DBED9E6C6464A4037C7B94DB82D55404DBED9E6C6464A40
8199	Зональное	5	47	277	84.918443999999994	84.954350000000005	52.678472999999997	52.654753999999997	0103000020E6100000010000000500000046CD57C9C73A55406C76A4FACE534A4046CD57C9C73A5540081C0934D8564A4002BC0512143D5540081C0934D8564A4002BC0512143D55406C76A4FACE534A4046CD57C9C73A55406C76A4FACE534A40
8133	Буланиха	5	47	277	84.908158999999998	84.960773000000003	52.820915999999997	52.782609999999998	0103000020E610000001000000050000005B24ED461F3A5540E3C281902C644A405B24ED461F3A5540AE6186C613694A404F78094E7D3D5540AE6186C613694A404F78094E7D3D5540E3C281902C644A405B24ED461F3A5540E3C281902C644A40
59455	Черепановск	5	47	48	82.297044	82.337260999999998	51.198393000000003	51.177612000000003	0103000020E61000000100000005000000465ED6C40293544047B071FDBB964940465ED6C402935440AF601BF164994940D74D29AF95955440AF601BF164994940D74D29AF9595544047B071FDBB964940465ED6C40293544047B071FDBB964940
7585	Утка	5	47	48	82.050178000000002	82.062521000000004	51.342256999999996	51.327108000000003	0103000020E61000000100000005000000A33EC91D368354404721C9ACDEA94940A33EC91D36835440DDE9CE13CFAB49400C94145800845440DDE9CE13CFAB49400C941458008454404721C9ACDEA94940A33EC91D368354404721C9ACDEA94940
7689	Тушканиха	5	47	48	81.707740000000001	81.716328000000004	51.264825000000002	51.253844999999998	0103000020E610000001000000050000008C84B69C4B6D544066A032FE7DA049408C84B69C4B6D5440E4141DC9E5A14940624D6551D86D5440E4141DC9E5A14940624D6551D86D544066A032FE7DA049408C84B69C4B6D544066A032FE7DA04940
56	Таловка	5	47	48	81.898353	81.930027999999993	51.468671000000001	51.429751000000003	0103000020E61000000100000005000000DDD0949D7E7954402F36AD1402B74940DDD0949D7E795440B4CA4C69FDBB494050172994857B5440B4CA4C69FDBB494050172994857B54402F36AD1402B74940DDD0949D7E7954402F36AD1402B74940
7864	Саввушка	5	47	48	82.134349999999998	82.159107000000006	51.36777	51.340601999999997	0103000020E61000000100000005000000ED0DBE3099885440E179A9D898AB4940ED0DBE309988544097395D1613AF4940246420CF2E8A544097395D1613AF4940246420CF2E8A5440E179A9D898AB4940ED0DBE3099885440E179A9D898AB4940
7595	Предгорный	5	47	48	81.891831999999994	81.904084999999995	51.232717999999998	51.225312000000002	0103000020E61000000100000005000000AE6186C613795440BCB20B06D79C4940AE6186C613795440639813B4C99D494077F35487DC795440639813B4C99D494077F35487DC795440BCB20B06D79C4940AE6186C613795440BCB20B06D79C4940
7841	Отрада	5	47	48	81.790043999999995	81.803375000000003	51.310974999999999	51.298603999999997	0103000020E61000000100000005000000AA99B51490725440363AE7A738A64940AA99B51490725440D26F5F07CEA7494023DBF97E6A735440D26F5F07CEA7494023DBF97E6A735440363AE7A738A64940AA99B51490725440363AE7A738A64940
7738	Октябрьский	5	47	48	81.697535000000002	81.725005999999993	51.287131000000002	51.275024000000002	0103000020E610000001000000050000002F34D769A46C5440BCCE86FC33A349402F34D769A46C54407A5567B5C0A44940D7D9907F666E54407A5567B5C0A44940D7D9907F666E5440BCCE86FC33A349402F34D769A46C5440BCCE86FC33A34940
7939	Новохарьковка	5	47	48	82.144679999999994	82.159844000000007	51.304679999999998	51.295310000000001	0103000020E61000000100000005000000A818E76F428954404417D4B7CCA54940A818E76F4289544065DF15C1FFA649408F1D54E23A8A544065DF15C1FFA649408F1D54E23A8A54404417D4B7CCA54940A818E76F428954404417D4B7CCA54940
7447	Новокузнецовка	5	47	48	82.055864	82.064739000000003	51.239230999999997	51.227218000000001	0103000020E6100000010000000500000085419946938354400188BB7A159D494085419946938354403D98141F9F9E4940A6F10BAF248454403D98141F9F9E4940A6F10BAF248454400188BB7A159D494085419946938354400188BB7A159D4940
3943	Никольск	5	47	48	81.899484999999999	81.916669999999996	51.362248000000001	51.346594000000003	0103000020E61000000100000005000000868F882991795440B37E33315DAC4940868F8829917954404D8578245EAE49405BCEA5B8AA7A54404D8578245EAE49405BCEA5B8AA7A5440B37E33315DAC4940868F882991795440B37E33315DAC4940
7776	Локоток	5	47	48	81.814666000000003	81.824969999999993	51.26173	51.253456	0103000020E6100000010000000500000071CADC7C23745440CC7C073F71A0494071CADC7C23745440E8305F5E80A14940978BF84ECC745440E8305F5E80A14940978BF84ECC745440CC7C073F71A0494071CADC7C23745440CC7C073F71A04940
7514	Кузьминка	5	47	48	81.939145999999994	81.958674999999999	51.322003000000002	51.305852000000002	0103000020E61000000100000005000000D40AD3F71A7C544046B5882826A74940D40AD3F71A7C5440611BF16437A949408A1F63EE5A7D5440611BF16437A949408A1F63EE5A7D544046B5882826A74940D40AD3F71A7C544046B5882826A74940
7368	Карамышево	5	47	48	82.072688999999997	82.098084999999998	51.185245999999999	51.167271999999997	0103000020E61000000100000005000000DA71C3EFA6845440ACC43C2B69954940DA71C3EFA68454407FDB1324B69749409ACE4E06478654407FDB1324B69749409ACE4E0647865440ACC43C2B69954940DA71C3EFA6845440ACC43C2B69954940
7309	Гальцовка	5	47	48	82.325439000000003	82.353458000000003	51.070292999999999	51.060603	0103000020E61000000100000005000000F37519FED39454400E85CFD6C1874940F37519FED3945440A1116C5CFF8849409DA04D0E9F965440A1116C5CFF8849409DA04D0E9F9654400E85CFD6C1874940F37519FED39454400E85CFD6C1874940
7492	Воронеж	5	47	48	82.004570000000001	82.016041999999999	51.203133000000001	51.185212	0103000020E61000000100000005000000BC22F8DF4A805440D369DD06B5974940BC22F8DF4A80544083DE1B43009A4940325706D50681544083DE1B43009A4940325706D506815440D369DD06B5974940BC22F8DF4A805440D369DD06B5974940
8017	Беспаловский	5	47	48	82.233479000000003	82.259924999999996	51.207320000000003	51.190502000000002	0103000020E610000001000000050000006153E751F18E54404BE9995E629849406153E751F18E544043E73576899A49406B9A779CA290544043E73576899A49406B9A779CA29054404BE9995E629849406153E751F18E54404BE9995E62984940
7380	Березовка	5	47	48	82.077702000000002	82.086577000000005	51.151710000000001	51.141285000000003	0103000020E610000001000000050000005D35CF11F98454402B357BA0159249405D35CF11F9845440F33CB83B6B9349407EE5417A8A855440F33CB83B6B9349407EE5417A8A8554402B357BA0159249405D35CF11F98454402B357BA015924940
7241	Барановка	5	47	48	82.189408	82.221530999999999	51.071373999999999	51.037517000000001	0103000020E610000001000000050000007366BB421F8C5440A305685BCD8449407366BB421F8C544071E481C82289494036035C902D8E544071E481C82289494036035C902D8E5440A305685BCD8449407366BB421F8C5440A305685BCD844940
59428	станция Шпагино	5	47	730	84.455076000000005	84.586876000000004	53.585034999999998	53.506535	0103000020E61000000100000005000000734C16F71F1D5540C2A38D23D6C04A40734C16F71F1D5540F701486DE2CA4A40ABB35A608F255540F701486DE2CA4A40ABB35A608F255540C2A38D23D6C04A40734C16F71F1D5540C2A38D23D6C04A40
7165	Яново	5	47	730	85.204001000000005	85.226836000000006	53.907037000000003	53.887118999999998	0103000020E610000001000000050000007CD6355A0E4D554082548A1D8DF14A407CD6355A0E4D554088A1D5C919F44A408D63247B844E554088A1D5C919F44A408D63247B844E554082548A1D8DF14A407CD6355A0E4D554082548A1D8DF14A40
6439	Шпагино	5	47	730	84.537369999999996	84.569117000000006	53.595835999999998	53.577100999999999	0103000020E610000001000000050000007FF623456422554094BE1072DEC94A407FF6234564225540C5E3A25A44CC4A4040A6B5696C245540C5E3A25A44CC4A4040A6B5696C24554094BE1072DEC94A407FF623456422554094BE1072DEC94A40
5847	Широкий Луг	5	47	730	84.997191000000001	85.005787999999995	53.866481	53.856504000000001	0103000020E61000000100000005000000653733FAD13F554054724EECA1ED4A40653733FAD13F55407DCD72D9E8EE4A4064ADA1D45E4055407DCD72D9E8EE4A4064ADA1D45E40554054724EECA1ED4A40653733FAD13F554054724EECA1ED4A40
6920	Хмелевка	5	47	730	85.167762999999994	85.201449999999994	53.965978999999997	53.941813000000003	0103000020E61000000100000005000000A59E05A1BC4A55404DF910548DF84A40A59E05A1BC4A5540B7CF2A33A5FB4A40DE718A8EE44C5540B7CF2A33A5FB4A40DE718A8EE44C55404DF910548DF84A40A59E05A1BC4A55404DF910548DF84A40
6802	Тягун	5	47	730	85.636189000000002	85.704632000000004	53.982142000000003	53.935462999999999	0103000020E61000000100000005000000CC441152B76855401CCF6740BDF74A40CC441152B768554097033DD4B6FD4A40C4EDD0B0186D554097033DD4B6FD4A40C4EDD0B0186D55401CCF6740BDF74A40CC441152B76855401CCF6740BDF74A40
5883	Старокопылово	5	47	730	84.781217999999996	84.801249999999996	53.802670999999997	53.789544999999997	0103000020E61000000100000005000000FA42C879FF31554033DC80CF0FE54A40FA42C879FF3155404B395FECBDE64A40E17A14AE473355404B395FECBDE64A40E17A14AE4733554033DC80CF0FE54A40FA42C879FF31554033DC80CF0FE54A40
6654	Стародраченино	5	47	730	85.055141000000006	85.089258999999998	53.694870999999999	53.670921	0103000020E61000000100000005000000CDEA1D6E874355408D9944BDE0D54A40CDEA1D6E874355402BF86D88F1D84A40EA77616BB64555402BF86D88F1D84A40EA77616BB64555408D9944BDE0D54A40CDEA1D6E874355408D9944BDE0D54A40
5301	Староглушинка	5	47	730	84.669953000000007	84.703873000000002	53.800064999999996	53.789715000000001	0103000020E61000000100000005000000DB368C82E02A55409014916115E54A40DB368C82E02A55404DD6A88768E64A4065E256410C2D55404DD6A88768E64A4065E256410C2D55409014916115E54A40DB368C82E02A55409014916115E54A40
5237	Среднекрасилово	5	47	730	84.592202999999998	84.611984000000007	53.804569000000001	53.783369	0103000020E61000000100000005000000F56569A7E6255540A1D9756F45E44A40F56569A7E62555400E30F31DFCE64A40386BF0BE2A2755400E30F31DFCE64A40386BF0BE2A275540A1D9756F45E44A40F56569A7E6255540A1D9756F45E44A40
6481	Сосновка	5	47	730	85.367818	85.388397999999995	53.891646000000001	53.871763999999999	0103000020E61000000100000005000000543882548A57554042EA76F695EF4A40543882548A575540FBCDC47421F24A403CF54883DB585540FBCDC47421F24A403CF54883DB58554042EA76F695EF4A40543882548A57554042EA76F695EF4A40
6223	Смирново	5	47	730	84.656306999999998	84.679969	53.695568999999999	53.674463000000003	0103000020E61000000100000005000000B24813EF002A554058AEB7CD54D64A40B24813EF002A5540438EAD6708D94A40CE52B29C842B5540438EAD6708D94A40CE52B29C842B554058AEB7CD54D64A40B24813EF002A554058AEB7CD54D64A40
59379	Смазнево	5	47	730	85.184319000000002	85.217691000000002	53.847245999999998	53.833193000000001	0103000020E610000001000000050000000342EBE1CB4B5540C9207711A6EA4A400342EBE1CB4B55405AD5928E72EC4A408C683BA6EE4D55405AD5928E72EC4A408C683BA6EE4D5540C9207711A6EA4A400342EBE1CB4B5540C9207711A6EA4A40
6252	Новоманошкино	5	47	730	84.477641000000006	84.506970999999993	53.629756999999998	53.605898000000003	0103000020E61000000100000005000000A48E8EAB911E55401D5BCF108ECD4A40A48E8EAB911E5540AAB69BE09BD04A404E417E3672205540AAB69BE09BD04A404E417E36722055401D5BCF108ECD4A40A48E8EAB911E55401D5BCF108ECD4A40
5376	Новокрасилово	5	47	730	84.717132000000007	84.740990999999994	53.781522000000002	53.762061000000003	0103000020E6100000010000000500000091BA9D7DE52D55404E4700378BE14A4091BA9D7DE52D5540618DB3E908E44A4057E883656C2F5540618DB3E908E44A4057E883656C2F55404E4700378BE14A4091BA9D7DE52D55404E4700378BE14A40
6137	Новокопылово	5	47	730	84.730767999999998	84.758041000000006	53.678137999999997	53.651958	0103000020E61000000100000005000000A73D25E7C42E5540CB2E185C73D34A40A73D25E7C42E55406116DA39CDD64A40BD0166BE833055406116DA39CDD64A40BD0166BE83305540CB2E185C73D34A40A73D25E7C42E5540CB2E185C73D34A40
5778	Новозыряново	5	47	730	84.885548	84.939796999999999	53.817158999999997	53.799931999999998	0103000020E6100000010000000500000072C284D1AC3855400E83F92B64E64A4072C284D1AC385540E75086AA98E84A4040F850A2253C5540E75086AA98E84A4040F850A2253C55400E83F92B64E64A4072C284D1AC3855400E83F92B64E64A40
6959	Новодресвянка	5	47	730	85.162830999999997	85.181057999999993	53.991045999999997	53.982089000000002	0103000020E6100000010000000500000099F1B6D26B4A55407461A417B5FD4A4099F1B6D26B4A5540726A6798DAFE4A40772B4B74964B5540726A6798DAFE4A40772B4B74964B55407461A417B5FD4A4099F1B6D26B4A55407461A417B5FD4A40
5935	Новодраченино	5	47	730	85.105896000000001	85.129080999999999	53.804558	53.786071	0103000020E61000000100000005000000BE310400C7465540C1AA7AF99DE44A40BE310400C74655401ADEACC1FBE64A403D62F4DC424855401ADEACC1FBE64A403D62F4DC42485540C1AA7AF99DE44A40BE310400C7465540C1AA7AF99DE44A40
59459	Мостовой	5	47	730	85.416318000000004	85.436897999999999	53.764913999999997	53.742325000000001	0103000020E610000001000000050000001DAF40F4A45A554069006F8104DF4A401DAF40F4A45A55405320B3B3E8E14A40056C0723F65B55405320B3B3E8E14A40056C0723F65B554069006F8104DF4A401DAF40F4A45A554069006F8104DF4A40
5681	Мироновка	5	47	730	85.432244999999995	85.456436999999994	53.818344000000003	53.800894999999997	0103000020E6100000010000000500000002B7EEE6A95B5540D44334BA83E64A4002B7EEE6A95B55405D70067FBFE84A40CCEB8843365D55405D70067FBFE84A40CCEB8843365D5540D44334BA83E64A4002B7EEE6A95B5540D44334BA83E64A40
6573	Малиновка	5	47	730	85.395332999999994	85.413370999999998	53.917256999999999	53.908611999999998	0103000020E61000000100000005000000E481C8224D5955406760E4654DF44A40E481C8224D595540778368AD68F54A405987A3AB745A5540778368AD68F54A405987A3AB745A55406760E4654DF44A40E481C8224D5955406760E4654DF44A40
5739	Комарское	5	47	730	85.073143000000002	85.102374999999995	53.648083	53.633904999999999	0103000020E610000001000000050000009B3BFA5FAE445540ACE28DCC23D14A409B3BFA5FAE445540FA0B3D62F4D24A40643BDF4F8D465540FA0B3D62F4D24A40643BDF4F8D465540ACE28DCC23D14A409B3BFA5FAE445540ACE28DCC23D14A40
6667	Кокорское	5	47	730	85.027158999999997	85.040687000000005	53.750483000000003	53.742047999999997	0103000020E61000000100000005000000B1321AF9BC415540F607CA6DFBDE4A40B1321AF9BC4155401C9AB2D30FE04A40D597A59D9A4255401C9AB2D30FE04A40D597A59D9A425540F607CA6DFBDE4A40B1321AF9BC415540F607CA6DFBDE4A40
7004	Клабуковка	5	47	730	85.258303999999995	85.264520000000005	54.076169999999998	54.066819000000002	0103000020E61000000100000005000000431B800D885055402FE065868D084B40431B800D88505540D97745F0BF094B40D4484BE5ED505540D97745F0BF094B40D4484BE5ED5055402FE065868D084B40431B800D885055402FE065868D084B40
7214	Каменушка	5	47	730	85.141469000000001	85.153327000000004	53.907980999999999	53.898363000000003	0103000020E610000001000000050000007619FED30D495540DE770C8FFDF24A407619FED30D495540D731AEB838F44A4001A60C1CD0495540D731AEB838F44A4001A60C1CD0495540DE770C8FFDF24A407619FED30D495540DE770C8FFDF24A40
6045	Казанцево	5	47	730	85.195780999999997	85.206048999999993	53.868609999999997	53.849497999999997	0103000020E61000000100000005000000670B08AD874C55403A02B859BCEC4A40670B08AD874C5540417DCB9C2EEF4A40E71725E82F4D5540417DCB9C2EEF4A40E71725E82F4D55403A02B859BCEC4A40670B08AD874C55403A02B859BCEC4A40
6317	Инюшево	5	47	730	84.332159000000004	84.352334999999997	53.640065999999997	53.630488	0103000020E610000001000000050000009D84D217421555409E42AED4B3D04A409D84D2174215554009A4C4AEEDD14A401D8F19A88C16554009A4C4AEEDD14A401D8F19A88C1655409E42AED4B3D04A409D84D217421555409E42AED4B3D04A40
5554	Зыряновка	5	47	730	85.408754000000002	85.426890999999998	53.787438000000002	53.767676999999999	0103000020E61000000100000005000000FD868906295A554019726C3D43E24A40FD868906295A554057D0B4C4CAE44A403BFDA02E525B554057D0B4C4CAE44A403BFDA02E525B554019726C3D43E24A40FD868906295A554019726C3D43E24A40
6122	Змазнево	5	47	730	85.205798000000001	85.227474000000001	53.812995999999998	53.805616999999998	0103000020E6100000010000000500000043E55FCB2B4D5540020D36751EE74A4043E55FCB2B4D5540B0E3BF4010E84A402EAC1BEF8E4E5540B0E3BF4010E84A402EAC1BEF8E4E5540020D36751EE74A4043E55FCB2B4D5540020D36751EE74A40
19237	Заринск	5	47	730	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
5395	Гришино	5	47	730	84.895250000000004	84.934578000000002	53.593494999999997	53.576005000000002	0103000020E610000001000000050000009EEFA7C64B3955408FAA2688BAC94A409EEFA7C64B39554075ABE7A4F7CB4A40E9633E20D03B554075ABE7A4F7CB4A40E9633E20D03B55408FAA2688BAC94A409EEFA7C64B3955408FAA2688BAC94A40
5203	Гоношиха	5	47	730	84.791099000000003	84.816585000000003	53.774206	53.755460999999997	0103000020E610000001000000050000007E39B35DA1325540A43330F2B2E04A407E39B35DA1325540F92EA52E19E34A40DE59BBED42345540F92EA52E19E34A40DE59BBED42345540A43330F2B2E04A407E39B35DA1325540A43330F2B2E04A40
5540	Голуха	5	47	730	85.419049000000001	85.457972999999996	53.851458000000001	53.837572000000002	0103000020E61000000100000005000000FA9AE5B2D15A5540CD052E8F35EB4A40FA9AE5B2D15A554073F56393FCEC4A40DD5CFC6D4F5D554073F56393FCEC4A40DD5CFC6D4F5D5540CD052E8F35EB4A40FA9AE5B2D15A5540CD052E8F35EB4A40
6337	Голубцово	5	47	730	84.372152	84.386758999999998	53.569310999999999	53.557608999999999	0103000020E6100000010000000500000006499F56D1175540467A51BB5FC74A4006499F56D11755406420CF2EDFC84A40C11BD2A8C01855406420CF2EDFC84A40C11BD2A8C0185540467A51BB5FC74A4006499F56D1175540467A51BB5FC74A40
5138	Воскресенка	5	47	730	84.985727999999995	85.013495000000006	53.921090999999997	53.896528000000004	0103000020E6100000010000000500000018B0E42A163F554062F9F36DC1F24A4018B0E42A163F5540E9D1544FE6F54A4036EA211ADD405540E9D1544FE6F54A4036EA211ADD40554062F9F36DC1F24A4018B0E42A163F554062F9F36DC1F24A40
5073	Верх-Камышенка	5	47	730	84.785269	84.825198999999998	53.604722000000002	53.585093000000001	0103000020E610000001000000050000000264E8D8413255402C0FD253E4CA4A400264E8D841325540FB95CE8767CD4A40486C770FD0345540FB95CE8767CD4A40486C770FD03455402C0FD253E4CA4A400264E8D8413255402C0FD253E4CA4A40
6506	Боровлянка	5	47	730	85.451244000000003	85.489008999999996	53.882826000000001	53.867432000000001	0103000020E610000001000000050000000AA1832EE15C55407FC0030308EF4A400AA1832EE15C55407D073F7100F14A40C79C67EC4B5F55407D073F7100F14A40C79C67EC4B5F55407FC0030308EF4A400AA1832EE15C55407FC0030308EF4A40
7075	Батунный	5	47	730	84.810789999999997	84.827571000000006	53.668407999999999	53.661552999999998	0103000020E61000000100000005000000207BBDFBE33355400CC9C9C4ADD44A40207BBDFBE33355404031B2648ED54A408E075BECF63455404031B2648ED54A408E075BECF63455400CC9C9C4ADD44A40207BBDFBE33355400CC9C9C4ADD44A40
5990	Афонино	5	47	730	85.230222999999995	85.261106999999996	53.774344999999997	53.762455000000003	0103000020E610000001000000050000005EF23FF9BB4E5540FAD51C2098E14A405EF23FF9BB4E55401A69A9BC1DE34A406D7022FAB55055401A69A9BC1DE34A406D7022FAB5505540FAD51C2098E14A405EF23FF9BB4E5540FAD51C2098E14A40
4944	Шатуново	5	47	598	84.503342000000004	84.545993999999993	53.912897999999998	53.890351000000003	0103000020E61000000100000005000000022D5DC136205540FF7A8505F7F14A40022D5DC136205540BA4A77D7D9F44A40FB73D190F1225540BA4A77D7D9F44A40FB73D190F1225540FF7A8505F7F14A40022D5DC136205540FF7A8505F7F14A40
4796	Черемушкино	5	47	598	84.269439000000006	84.320875999999998	54.022838	54.002198999999997	0103000020E610000001000000050000001651137D3E115540BD8A8C0E48004B401651137D3E115540938D075BEC024B4090847D3B89145540938D075BEC024B4090847D3B89145540BD8A8C0E48004B401651137D3E115540BD8A8C0E48004B40
4604	Тундриха	5	47	598	84.525423000000004	84.563007999999996	54.001474000000002	53.988394	0103000020E610000001000000050000003D64CA87A021554004C8D0B183FE4A403D64CA87A0215540ACE5CE4C30004B40BAD8B45208245540ACE5CE4C30004B40BAD8B4520824554004C8D0B183FE4A403D64CA87A021554004C8D0B183FE4A40
3873	Талица	5	47	598	84.297546999999994	84.324155000000005	54.108888999999998	54.092326999999997	0103000020E61000000100000005000000778192020B135540D6C4025FD10B4B40778192020B13554073F22213F00D4B406FF59CF4BE14554073F22213F00D4B406FF59CF4BE145540D6C4025FD10B4B40778192020B135540D6C4025FD10B4B40
3988	Пролетарская Крепость	5	47	598	84.838441000000003	84.859228000000002	54.017305	54.006563999999997	0103000020E6100000010000000500000009A87004A93555405CAAD216D7004B4009A87004A93555405587DC0C37024B40AEF36F97FD3655405587DC0C37024B40AEF36F97FD3655405CAAD216D7004B4009A87004A93555405CAAD216D7004B40
4516	Пещерка	5	47	598	84.755257	84.823815999999994	54.099961999999998	54.083708000000001	0103000020E61000000100000005000000CEC4742156305540F03499F1B60A4B40CEC4742156305540DF6B088ECB0C4B40FA7ABE66B9345540DF6B088ECB0C4B40FA7ABE66B9345540F03499F1B60A4B40CEC4742156305540F03499F1B60A4B40
4379	Муравей	5	47	598	84.718487999999994	84.731657999999996	53.898803999999998	53.887528000000003	0103000020E6100000010000000500000061A417B5FB2D554064247B849AF14A4061A417B5FB2D5540CAC16C020CF34A40D576137CD32E5540CAC16C020CF34A40D576137CD32E554064247B849AF14A4061A417B5FB2D554064247B849AF14A40
4886	Малый Калтай	5	47	598	84.166922999999997	84.180541000000005	53.996816000000003	53.986631000000003	0103000020E61000000100000005000000D07CCEDDAE0A5540221CB3EC49FE4A40D07CCEDDAE0A55409510ACAA97FF4A4094A5D6FB8D0B55409510ACAA97FF4A4094A5D6FB8D0B5540221CB3EC49FE4A40D07CCEDDAE0A5540221CB3EC49FE4A40
4458	Кордон	5	47	598	84.949399999999997	84.986321000000004	54.193891000000001	54.173394999999999	0103000020E61000000100000005000000A2B437F8C23C55401C25AFCE31164B40A2B437F8C23C55408FFE976BD1184B40EA961DE21F3F55408FFE976BD1184B40EA961DE21F3F55401C25AFCE31164B40A2B437F8C23C55401C25AFCE31164B40
4993	Калиновка	5	47	598	84.553881000000004	84.564975000000004	53.865482999999998	53.855637999999999	0103000020E610000001000000050000000D384BC972235540809BC58B85ED4A400D384BC9722355403A1F9E25C8EE4A40B003E78C282455403A1F9E25C8EE4A40B003E78C28245540809BC58B85ED4A400D384BC972235540809BC58B85ED4A40
4654	Заплывино	5	47	598	84.567076999999998	84.583014000000006	53.943503999999997	53.930486000000002	0103000020E61000000100000005000000155454FD4A24554064B14D2A1AF74A40155454FD4A24554095D233BDC4F84A400DC7F3195025554095D233BDC4F84A400DC7F3195025554064B14D2A1AF74A40155454FD4A24554064B14D2A1AF74A40
4123	Залесово	5	47	598	84.680616000000001	84.769405000000006	54.008940000000003	53.966625000000001	0103000020E61000000100000005000000994869368F2B55407D3F355EBAFB4A40994869368F2B554029D027F224014B40401878EE3D31554029D027F224014B40401878EE3D3155407D3F355EBAFB4A40994869368F2B55407D3F355EBAFB4A40
4085	Думчево	5	47	598	84.263266999999999	84.308550999999994	53.964337	53.947076000000003	0103000020E610000001000000050000006DC7D45DD9105540CB694FC939F94A406DC7D45DD910554050A912656FFB4A407A89B14CBF13554050A912656FFB4A407A89B14CBF135540CB694FC939F94A406DC7D45DD9105540CB694FC939F94A40
4542	Гуниха	5	47	598	84.633571000000003	84.661238999999995	54.208964999999999	54.188955	0103000020E610000001000000050000006B2C616D8C28554035B56CAD2F184B406B2C616D8C2855401B81785DBF1A4B40BEF561BD512A55401B81785DBF1A4B40BEF561BD512A554035B56CAD2F184B406B2C616D8C28554035B56CAD2F184B40
4820	Видоново	5	47	598	84.048929000000001	84.063473000000002	53.996149000000003	53.971364999999999	0103000020E61000000100000005000000DDB419A72103554051BD35B055FC4A40DDB419A721035540B87878CF81FF4A4075CB0EF10F045540B87878CF81FF4A4075CB0EF10F04554051BD35B055FC4A40DDB419A72103554051BD35B055FC4A40
3909	Борисово	5	47	598	84.984416999999993	85.017393999999996	54.044583000000003	54.026927000000001	0103000020E61000000100000005000000172829B0003F554090300C5872034B40172829B0003F5540927A4FE5B4054B406249B9FB1C415540927A4FE5B4054B406249B9FB1C41554090300C5872034B40172829B0003F554090300C5872034B40
3779	Большой Калтай	5	47	598	84.225879000000006	84.274693999999997	54.139038999999997	54.118484000000002	0103000020E610000001000000050000009B7631CD740E5540B58CD47B2A0F4B409B7631CD740E55402CEFAA07CC114B40139A2496941155402CEFAA07CC114B40139A249694115540B58CD47B2A0F4B409B7631CD740E5540B58CD47B2A0F4B40
59393	Чистоозёрка	5	47	504	80.434197999999995	81.481993000000003	53.134599000000001	52.584297999999997	0103000020E61000000100000005000000457F68E6C91B5440218FE046CA4A4A40457F68E6C91B544083893F8A3A914A40A9F92AF9D85E544083893F8A3A914A40A9F92AF9D85E5440218FE046CA4A4A40457F68E6C91B5440218FE046CA4A4A40
3255	Чернавка	5	47	504	80.598087000000007	80.621298999999993	52.670222000000003	52.655852000000003	0103000020E610000001000000050000006B4AB20E47265440138255F5F2534A406B4AB20E47265440A587A1D5C9554A406682E15CC3275440A587A1D5C9554A406682E15CC3275440138255F5F2534A406B4AB20E47265440138255F5F2534A40
3482	Харитоново	5	47	504	80.927221000000003	80.955302000000003	53.049568000000001	53.020299999999999	0103000020E6100000010000000500000086CABF96573B5440ED0DBE3099824A4086CABF96573B5440CD76853E58864A406BF3FFAA233D5440CD76853E58864A406BF3FFAA233D5440ED0DBE3099824A4086CABF96573B5440ED0DBE3099824A40
3335	Тумановский	5	47	504	80.674929000000006	80.701922999999994	52.862265999999998	52.849362999999997	0103000020E61000000100000005000000CF876709322B54405AB741EDB76C4A40CF876709322B5440F33977BB5E6E4A40DA53724EEC2C5440F33977BB5E6E4A40DA53724EEC2C54405AB741EDB76C4A40CF876709322B54405AB741EDB76C4A40
59409	Светлый	5	47	504	81.044252999999998	81.073196999999993	52.916148999999997	52.898878000000003	0103000020E61000000100000005000000FEEF880AD5425440058C2E6F0E734A40FEEF880AD5425440ADA1D45E44754A40944A7842AF445440ADA1D45E44754A40944A7842AF445440058C2E6F0E734A40FEEF880AD5425440058C2E6F0E734A40
3573	Овечкино	5	47	504	81.191666999999995	81.237363999999999	53.006241000000003	52.987575	0103000020E610000001000000050000003C2EAA45444C544071AC8BDB687E4A403C2EAA45444C54407A724D81CC804A40DB4FC6F8304F54407A724D81CC804A40DB4FC6F8304F544071AC8BDB687E4A403C2EAA45444C544071AC8BDB687E4A40
3391	Малиновский	5	47	504	80.789930999999996	80.844791000000001	52.970326999999997	52.953083999999997	0103000020E610000001000000050000002EC6C03A8E325440A12B11A8FE794A402EC6C03A8E32544080B6D5AC337C4A40213D450E1136544080B6D5AC337C4A40213D450E11365440A12B11A8FE794A402EC6C03A8E325440A12B11A8FE794A40
3146	Камышенка	5	47	504	80.585457000000005	80.622332	52.713527999999997	52.694451000000001	0103000020E61000000100000005000000B70DA3207825544056D636C5E3584A40B70DA32078255440E063B0E2545B4A4046D09849D4275440E063B0E2545B4A4046D09849D427544056D636C5E3584A40B70DA3207825544056D636C5E3584A40
3040	Завьялово	5	47	504	80.879242000000005	80.947478000000004	52.854832999999999	52.820698	0103000020E6100000010000000500000042D13C804538544041F2CEA10C694A4042D13C80453854405245F12A6B6D4A407DEBC37AA33C54405245F12A6B6D4A407DEBC37AA33C544041F2CEA10C694A4042D13C804538544041F2CEA10C694A40
3664	Гонохово	5	47	504	81.268185000000003	81.330393999999998	52.962370999999997	52.926839000000001	0103000020E61000000100000005000000C7116BF12951544024D40CA9A2764A40C7116BF12951544035CF11F92E7B4A40DB32E02C2555544035CF11F92E7B4A40DB32E02C2555544024D40CA9A2764A40C7116BF12951544024D40CA9A2764A40
3467	Глубокое	5	47	504	80.654231999999993	80.712371000000005	53.005828999999999	52.972718999999998	0103000020E61000000100000005000000C9FFE4EFDE2954405299620E827C4A40C9FFE4EFDE295440272F3201BF804A409BE7887C972D5440272F3201BF804A409BE7887C972D54405299620E827C4A40C9FFE4EFDE2954405299620E827C4A40
3702	Гилевка	5	47	504	81.076673	81.126987999999997	52.873432000000001	52.852652999999997	0103000020E610000001000000050000001EDFDE35E84454400BEBC6BB236D4A401EDFDE35E8445440D3A3A99ECC6F4A4001BF469220485440D3A3A99ECC6F4A4001BF4692204854400BEBC6BB236D4A401EDFDE35E84454400BEBC6BB236D4A40
2827	Черемшанка	5	47	470	86.129813999999996	86.182400999999999	53.212392999999999	53.19126	0103000020E61000000100000005000000072461DF4E88554038842A357B984A40072461DF4E8855401D739EB12F9B4A407E703E75AC8B55401D739EB12F9B4A407E703E75AC8B554038842A357B984A40072461DF4E88554038842A357B984A40
2917	Пуштулим	5	47	470	86.411794999999998	86.453035999999997	53.213147999999997	53.189214999999997	0103000020E61000000100000005000000016A6AD95A9A5540D174763238984A40016A6AD95A9A5540999A046F489B4A4048FAB48AFE9C5540999A046F489B4A4048FAB48AFE9C5540D174763238984A40016A6AD95A9A5540D174763238984A40
2877	Новокаменка	5	47	470	86.293432999999993	86.331700999999995	53.375019000000002	53.351854000000003	0103000020E610000001000000050000004CA4349BC7925540C07B478D09AD4A404CA4349BC79255407730629F00B04A403BC3D4963A9555407730629F00B04A403BC3D4963A955540C07B478D09AD4A404CA4349BC7925540C07B478D09AD4A40
2772	Мартыново	5	47	470	85.884583000000006	85.938697000000005	53.273113000000002	53.244396999999999	0103000020E610000001000000050000003FE603029D785540C91EA166489F4A403FE603029D785540658EE55DF5A24A409DF6949C137C5540658EE55DF5A24A409DF6949C137C5540C91EA166489F4A403FE603029D785540C91EA166489F4A40
2993	Верх-Неня	5	47	470	86.417220999999998	86.445248000000007	53.080508999999999	53.064857000000003	0103000020E61000000100000005000000158DB5BFB39A554056F5F23B4D884A40158DB5BFB39A55404F04711E4E8A4A4001A777F17E9C55404F04711E4E8A4A4001A777F17E9C554056F5F23B4D884A40158DB5BFB39A554056F5F23B4D884A40
2185	Шубинка (Бугор)	5	47	385	80.785188000000005	80.804556000000005	51.619340999999999	51.578764	0103000020E610000001000000050000008C4D2B8540325440130D52F014CA49408C4D2B85403254403509DE9046CF49403DF372D87D3354403509DE9046CF49403DF372D87D335440130D52F014CA49408C4D2B8540325440130D52F014CA4940
2661	Титовка	5	47	385	81.115021999999996	81.170250999999993	52.027273999999998	51.982166999999997	0103000020E6100000010000000500000083143C855C475440EF1AF4A5B7FD494083143C855C475440FB03E5B67D034A401F477364E54A5440FB03E5B67D034A401F477364E54A5440EF1AF4A5B7FD494083143C855C475440EF1AF4A5B7FD4940
2582	Сросты	5	47	385	80.986833000000004	81.037730999999994	51.903326	51.865830000000003	0103000020E6100000010000000500000045679945283F5440A6F27684D3EE494045679945283F544031D0B52FA0F34940E7C2482F6A42544031D0B52FA0F34940E7C2482F6A425440A6F27684D3EE494045679945283F5440A6F27684D3EE4940
2324	Перешеечный	5	47	385	80.831173000000007	80.853100999999995	51.736798	51.715235999999997	0103000020E610000001000000050000005E143DF031355440FF756EDA8CDB49405E143DF0313554400DE198654FDE4940D5CBEF34993654400DE198654FDE4940D5CBEF3499365440FF756EDA8CDB49405E143DF031355440FF756EDA8CDB4940
2475	Первомайское	5	47	385	81.17989	81.203372000000002	51.743524000000001	51.733255999999997	0103000020E6100000010000000500000028B85851834B544042CC2555DBDD494028B85851834B544043E55FCB2BDF4940043BFE0B044D544043E55FCB2BDF4940043BFE0B044D544042CC2555DBDD494028B85851834B544042CC2555DBDD4940
2336	Новоегорьевское	5	47	385	80.868928999999994	80.919647999999995	51.781160999999997	51.732208	0103000020E61000000100000005000000F16261889C3754404EEFE2FDB8DD4940F16261889C37544090F46915FDE349403CF54883DB3A544090F46915FDE349403CF54883DB3A54404EEFE2FDB8DD4940F16261889C3754404EEFE2FDB8DD4940
59419	Мирный	5	47	385	80.503899000000004	81.276494999999997	52.102296000000003	51.335498999999999	0103000020E610000001000000050000002D5F97E13F2054409C6B98A1F1AA49402D5F97E13F2054407D410B09180D4A407BA01518B25154407D410B09180D4A407BA01518B25154409C6B98A1F1AA49402D5F97E13F2054409C6B98A1F1AA4940
2134	Малая Шелковка	5	47	385	80.742643999999999	80.760413	51.509144999999997	51.484983999999997	0103000020E610000001000000050000008524B37A872F5440A88AA9F413BE49408524B37A872F544001F6D1A92BC14940029D499BAA30544001F6D1A92BC14940029D499BAA305440A88AA9F413BE49408524B37A872F5440A88AA9F413BE4940
2235	Лебяжье	5	47	385	80.831648999999999	80.860754	51.714677999999999	51.668199000000001	0103000020E610000001000000050000001230BABC39355440261C7A8B87D549401230BABC39355440D99596917ADB4940ADF9F19716375440D99596917ADB4940ADF9F19716375440261C7A8B87D549401230BABC39355440261C7A8B87D54940
1981	Кругло-Семенцы	5	47	385	80.888700999999998	80.903334000000001	51.541477999999998	51.521521	0103000020E610000001000000050000000ABB287AE0385440AF963B33C1C249400ABB287AE038544072C0AE264FC549405AD76839D039544072C0AE264FC549405AD76839D0395440AF963B33C1C249400ABB287AE0385440AF963B33C1C24940
2092	Борисовка	5	47	385	80.765810999999999	80.781721000000005	51.566090000000003	51.540346	0103000020E61000000100000005000000B1FA230C033154402043C70E2AC54940B1FA230C03315440DC4B1AA375C849402C6684B707325440DC4B1AA375C849402C6684B7073254402043C70E2AC54940B1FA230C033154402043C70E2AC54940
1973	Усть-Кормиха	5	47	242	80.347879000000006	80.365404999999996	51.828648000000001	51.822180000000003	0103000020E61000000100000005000000C6FD47A64316544070B6B9313DE94940C6FD47A643165440AAF23D2311EA4940DF32A7CB62175440AAF23D2311EA4940DF32A7CB6217544070B6B9313DE94940C6FD47A64316544070B6B9313DE94940
1863	Усть-Волчиха	5	47	242	80.243269999999995	80.274827999999999	51.906882000000003	51.887169999999998	0103000020E61000000100000005000000448655BC910F544004FF5BC98EF14940448655BC910F544061AA99B514F449409B012EC89611544061AA99B514F449409B012EC89611544004FF5BC98EF14940448655BC910F544004FF5BC98EF14940
1424	Солоновка	5	47	242	80.788152999999994	80.823232000000004	52.229145000000003	52.203951000000004	0103000020E61000000100000005000000A2CF471971325440467EFD101B1A4A40A2CF4719713254405E85949F541D4A40534145D5AF3454405E85949F541D4A40534145D5AF345440467EFD101B1A4A40A2CF471971325440467EFD101B1A4A40
1540	Селиверстово (Белгачи)	5	47	242	80.910539	80.981433999999993	52.311149	52.285989999999998	0103000020E61000000100000005000000E2AE5E45463A5440D47D00529B244A40E2AE5E45463A54407097FDBAD3274A40AD4B8DD0CF3E54407097FDBAD3274A40AD4B8DD0CF3E5440D47D00529B244A40E2AE5E45463A5440D47D00529B244A40
1635	Пятков Лог	5	47	242	80.271153999999996	80.293521999999996	52.236750999999998	52.216450000000002	0103000020E610000001000000050000007E8B4E965A1154400F9C33A2B41B4A407E8B4E965A115440CC2555DB4D1E4A4004AA7F10C9125440CC2555DB4D1E4A4004AA7F10C91254400F9C33A2B41B4A407E8B4E965A1154400F9C33A2B41B4A40
1385	Приборовое	5	47	242	80.667392000000007	80.690515000000005	52.163469999999997	52.146861000000001	0103000020E610000001000000050000002C67EF8CB62A544068075C57CC124A402C67EF8CB62A544045F0BF95EC144A407099D365312C544045F0BF95EC144A407099D365312C544068075C57CC124A402C67EF8CB62A544068075C57CC124A40
1274	Правда	5	47	242	80.491178000000005	80.517741999999998	52.09496	52.085000000000001	0103000020E61000000100000005000000F1A0D9756F1F54407B14AE47E10A4A40F1A0D9756F1F5440CE3637A6270C4A40007157AF22215440CE3637A6270C4A40007157AF222154407B14AE47E10A4A40F1A0D9756F1F54407B14AE47E10A4A40
26199	Плодосовхоз	5	47	242	80.291555000000002	80.300601	52.000014	51.992378000000002	0103000020E610000001000000050000000F7F4DD6A81254408CA2073E06FF49400F7F4DD6A812544065C5707500004A404609FA0B3D13544065C5707500004A404609FA0B3D1354408CA2073E06FF49400F7F4DD6A81254408CA2073E06FF4940
1733	Новокормиха	5	47	242	80.069374999999994	80.111164000000002	52.177014	52.151006000000002	0103000020E610000001000000050000003D0AD7A370045440F9BF232A54134A403D0AD7A37004544092770E65A8164A40861F9C4F1D07544092770E65A8164A40861F9C4F1D075440F9BF232A54134A403D0AD7A370045440F9BF232A54134A40
1476	Малышев Лог	5	47	242	80.890839	80.931021000000001	52.180681	52.148558000000001	0103000020E6100000010000000500000016C094810339544093C7D3F203134A4016C09481033954401901158E20174A40E9B81AD9953B54401901158E20174A40E9B81AD9953B544093C7D3F203134A4016C094810339544093C7D3F203134A40
1640	Коминтерн	5	47	242	80.206529000000003	80.220669000000001	52.185805000000002	52.171081999999998	0103000020E610000001000000050000003D2B69C5370D54409677D503E6154A403D2B69C5370D544076374F75C8174A406D8FDE701F0E544076374F75C8174A406D8FDE701F0E54409677D503E6154A403D2B69C5370D54409677D503E6154A40
1297	Вострово	5	47	242	80.605821000000006	80.649291000000005	52.149878000000001	52.128255000000003	0103000020E61000000100000005000000B98E71C5C52654403546EBA86A104A40B98E71C5C5265440E831CA332F134A4094A5D6FB8D295440E831CA332F134A4094A5D6FB8D2954403546EBA86A104A40B98E71C5C52654403546EBA86A104A40
960	Волчиха	5	47	242	80.335239999999999	80.394439000000006	52.036665999999997	51.999935999999998	0103000020E61000000100000005000000E813799274155440E90B21E7FDFF4940E8137992741554400470B378B1044A401651137D3E1954400470B378B1044A401651137D3E195440E90B21E7FDFF4940E813799274155440E90B21E7FDFF4940
59440	Веселая Дубрава	5	47	242	81.026565000000005	81.051709000000002	52.273549000000003	52.260767999999999	0103000020E61000000100000005000000F88DAF3DB3415440F2EB87D860214A40F88DAF3DB3415440406D54A703234A402BFA43334F435440406D54A703234A402BFA43334F435440F2EB87D860214A40F88DAF3DB3415440F2EB87D860214A40
1823	Бор-Форпост	5	47	242	80.096853999999993	80.134924999999996	51.882606000000003	51.862609999999997	0103000020E61000000100000005000000279F1EDB32065440ED9925016AEE4940279F1EDB320654406FA0C03BF9F049406B9A779CA20854406FA0C03BF9F049406B9A779CA2085440ED9925016AEE4940279F1EDB32065440ED9925016AEE4940
1785	Березовский	5	47	242	80.098498000000006	80.118369000000001	52.080610999999998	52.068238999999998	0103000020E610000001000000050000002C2E8ECA4D065440E7A7380EBC084A402C2E8ECA4D06544053591476510A4A400EF7915B9307544053591476510A4A400EF7915B93075440E7A7380EBC084A402C2E8ECA4D065440E7A7380EBC084A40
840	Хлеборобное	5	47	142	84.616269000000003	84.648617999999999	52.221575999999999	52.210000000000001	0103000020E61000000100000005000000792288F3702755407B14AE47E11A4A40792288F3702755400CCA349A5C1C4A40346612F5822955400CCA349A5C1C4A40346612F5822955407B14AE47E11A4A40792288F3702755407B14AE47E11A4A40
901	Усть-Ануй	5	47	142	84.749381999999997	84.776223000000002	52.403374999999997	52.37303	0103000020E61000000100000005000000828DEBDFF52F5540A4367172BF2F4A40828DEBDFF52F55401283C0CAA1334A40CBD93BA3AD3155401283C0CAA1334A40CBD93BA3AD315540A4367172BF2F4A40828DEBDFF52F5540A4367172BF2F4A40
59406	Приобский	5	47	142	84.446640000000002	84.469268999999997	52.351345000000002	52.340027999999997	0103000020E610000001000000050000007845F0BF951C5540B5DC9909862B4A407845F0BF951C55407B4E7ADFF82C4A40B401D880081E55407B4E7ADFF82C4A40B401D880081E5540B5DC9909862B4A407845F0BF951C5540B5DC9909862B4A40
734	Новопокровка	5	47	142	84.395356000000007	84.470337999999998	52.227032000000001	52.213929	0103000020E61000000100000005000000C19140834D1955403F558506621B4A40C19140834D1955409F9273620F1D4A403A048E041A1E55409F9273620F1D4A403A048E041A1E55403F558506621B4A40C19140834D1955403F558506621B4A40
675	Верх-Озерное	5	47	142	84.255075000000005	84.285510000000002	52.335748000000002	52.319136999999998	0103000020E61000000100000005000000BEC1172653105540C6F8307BD9284A40BEC117265310554045D95BCAF92A4A40952BBCCB4512554045D95BCAF92A4A40952BBCCB45125540C6F8307BD9284A40BEC1172653105540C6F8307BD9284A40
792	Верх-Ануйское	5	47	142	84.563861000000003	84.610763000000006	52.224108000000001	52.196261999999997	0103000020E610000001000000050000005A9F724C1624554049B9FB1C1F194A405A9F724C16245540D0622992AF1C4A40D7A6B1BD16275540D0622992AF1C4A40D7A6B1BD1627554049B9FB1C1F194A405A9F724C1624554049B9FB1C1F194A40
415	Быстрый Исток	5	47	142	84.295192999999998	84.423732999999999	52.385399	52.357649000000002	0103000020E6100000010000000500000085402E71E41255403B394371C72D4A4085402E71E41255409F7422C154314A401A4F04711E1B55409F7422C154314A401A4F04711E1B55403B394371C72D4A4085402E71E41255403B394371C72D4A40
339	Акутиха	5	47	142	84.433121	84.492517000000007	52.444749999999999	52.424644000000001	0103000020E610000001000000050000007E8D2441B81B5540A8380EBC5A364A407E8D2441B81B5540B0726891ED384A4057EE0566851F5540B0726891ED384A4057EE0566851F5540A8380EBC5A364A407E8D2441B81B5540A8380EBC5A364A40
32129	Чернавка	5	47	111	78.144796999999997	78.167596000000003	53.177559000000002	53.170957999999999	0103000020E61000000100000005000000C5E3A25A44895340AA7EA5F3E1954A40C5E3A25A44895340240ED940BA964A4030BC92E4B98A5340240ED940BA964A4030BC92E4B98A5340AA7EA5F3E1954A40C5E3A25A44895340AA7EA5F3E1954A40
32047	Цветополь	5	47	111	78.233576999999997	78.254113000000004	53.202060000000003	53.189917000000001	0103000020E610000001000000050000004206F2ECF28E53402BFA43334F984A404206F2ECF28E534036EA211ADD994A40431F2C634390534036EA211ADD994A40431F2C63439053402BFA43334F984A404206F2ECF28E53402BFA43334F984A40
212	Устьянка	5	47	111	78.725926000000001	78.760592000000003	53.460261000000003	53.442425999999998	0103000020E610000001000000050000003B54539275AE53403673486AA1B84A403B54539275AE5340E84F1BD5E9BA4A405A66118AADB05340E84F1BD5E9BA4A405A66118AADB053403673486AA1B84A403B54539275AE53403673486AA1B84A40
31940	Притыка	5	47	111	78.225950999999995	78.247169	53.271158999999997	53.261533999999997	0103000020E61000000100000005000000E7DF2EFB758E5340626534F279A14A40E7DF2EFB758E53400E828E56B5A24A4071E5EC9DD18F53400E828E56B5A24A4071E5EC9DD18F5340626534F279A14A40E7DF2EFB758E5340626534F279A14A40
32302	Петровка	5	47	111	78.050995	78.061739000000003	53.369968999999998	53.351424000000002	0103000020E610000001000000050000009C50888043835340C7832D76FBAC4A409C5088804383534054C4E9245BAF4A40D1782288F383534054C4E9245BAF4A40D1782288F3835340C7832D76FBAC4A409C50888043835340C7832D76FBAC4A40
22170	Первомайское	5	47	111	78.241940999999997	78.257643000000002	53.359898999999999	53.347875999999999	0103000020E61000000100000005000000F0A31AF67B8F53401A88653387AC4A40F0A31AF67B8F53407A6EA12B11AE4A40C6C210397D9053407A6EA12B11AE4A40C6C210397D9053401A88653387AC4A40F0A31AF67B8F53401A88653387AC4A40
32370	Партизанское	5	47	111	78.349703000000005	78.359099000000001	53.338436000000002	53.333891999999999	0103000020E610000001000000050000000A14B18861965340B1321AF9BCAA4A400A14B1886196534000E5EFDE51AB4A40AF415F7AFB96534000E5EFDE51AB4A40AF415F7AFB965340B1321AF9BCAA4A400A14B18861965340B1321AF9BCAA4A40
32070	Орехово	5	47	111	78.194913999999997	78.223202000000001	53.140180000000001	53.123415000000001	0103000020E6100000010000000500000015E29178798C5340FD6A0E10CC8F4A4015E29178798C5340D2C6116BF1914A40B7990AF1488E5340D2C6116BF1914A40B7990AF1488E5340FD6A0E10CC8F4A4015E29178798C5340FD6A0E10CC8F4A40
32198	Новосельское	5	47	111	78.136765999999994	78.155064999999993	53.528052000000002	53.511476999999999	0103000020E610000001000000050000001A4D2EC6C0885340FED30D1478C14A401A4D2EC6C0885340304B3B3597C34A4045F0BF95EC895340304B3B3597C34A4045F0BF95EC895340FED30D1478C14A401A4D2EC6C0885340FED30D1478C14A40
32456	Новопесчаное	5	47	111	78.499578	78.536921000000007	53.436520999999999	53.394213999999998	0103000020E6100000010000000500000045F30016F99F53400BD0B69A75B24A4045F30016F99F534034828DEBDFB74A4048E2E5E95CA2534034828DEBDFB74A4048E2E5E95CA253400BD0B69A75B24A4045F30016F99F53400BD0B69A75B24A40
32178	Новоандреевка	5	47	111	78.364892999999995	78.389973999999995	53.046357	53.032404	0103000020E6100000010000000500000084622B685A9753403A2174D025844A4084622B685A9753406878B306EF854A4094128255F59853406878B306EF854A4094128255F59853403A2174D025844A4084622B685A9753403A2174D025844A40
170	Новоалексеевка	5	47	111	78.561732000000006	78.590046999999998	53.389997999999999	53.379370000000002	0103000020E610000001000000050000007847C66AF3A35340B18A37328FB04A407847C66AF3A35340B1C05774EBB14A4096067E54C3A55340B1C05774EBB14A4096067E54C3A55340B18A37328FB04A407847C66AF3A35340B18A37328FB04A40
31998	Михайловка	5	47	111	78.129193000000001	78.16977	53.256869000000002	53.239660000000001	0103000020E61000000100000005000000D177B7B2448853406614CB2DAD9E4A40D177B7B244885340992D5915E1A04A40E275FD82DD8A5340992D5915E1A04A40E275FD82DD8A53406614CB2DAD9E4A40D177B7B2448853406614CB2DAD9E4A40
288	Лесное	5	47	111	78.691844000000003	78.725476999999998	53.536181999999997	53.520960000000002	0103000020E61000000100000005000000C47B0E2C47AC5340184339D1AEC24A40C47B0E2C47AC5340185A9D9CA1C44A40034015376EAE5340185A9D9CA1C44A40034015376EAE5340184339D1AEC24A40C47B0E2C47AC5340184339D1AEC24A40
32445	Гусиная Ляга	5	47	111	78.387107999999998	78.401751000000004	53.412944000000003	53.400351000000001	0103000020E610000001000000050000004701A260C6985340E0F599B33EB34A404701A260C69853402B8A5759DBB44A40A988D349B69953402B8A5759DBB44A40A988D349B6995340E0F599B33EB34A404701A260C6985340E0F599B33EB34A40
31801	Бурла	5	47	111	78.318180999999996	78.361604999999997	53.350580000000001	53.318219999999997	0103000020E61000000100000005000000594DD7135D9453407077D66EBBA84A40594DD7135D945340DB5031CEDFAC4A407C444C8924975340DB5031CEDFAC4A407C444C89249753407077D66EBBA84A40594DD7135D9453407077D66EBBA84A40
32335	Асямовка	5	47	111	78.458983000000003	78.477137999999997	53.277555999999997	53.257914999999997	0103000020E61000000100000005000000E19A3BFA5F9D5340EC12D55B03A14A40E19A3BFA5F9D53407F677BF486A34A40726BD26D899E53407F677BF486A34A40726BD26D899E5340EC12D55B03A14A40E19A3BFA5F9D5340EC12D55B03A14A40
31673	Яготино	5	47	968	79.611863	79.649448000000007	52.755099999999999	52.738948000000001	0103000020E610000001000000050000007AA86DC328E75340E9B81AD9955E4A407AA86DC328E75340D49AE61DA7604A40F81C588E90E95340D49AE61DA7604A40F81C588E90E95340E9B81AD9955E4A407AA86DC328E75340E9B81AD9955E4A40
31583	Шимолино	5	47	968	79.964648999999994	79.988040999999996	53.012937000000001	52.991596999999999	0103000020E610000001000000050000009FC728CFBCFD5340E6E786A6EC7E4A409FC728CFBCFD534045F46BEBA7814A40DB8651103CFF534045F46BEBA7814A40DB8651103CFF5340E6E786A6EC7E4A409FC728CFBCFD5340E6E786A6EC7E4A40
31728	Тельманский	5	47	968	79.535083999999998	79.554908999999995	52.801282999999998	52.79372	0103000020E610000001000000050000003927F6D03EE253402F17F19D98654A403927F6D03EE253409EEBFB7090664A4063D009A183E353409EEBFB7090664A4063D009A183E353402F17F19D98654A403927F6D03EE253402F17F19D98654A40
31336	Татьяновка	5	47	968	80.227414999999993	80.242200999999994	52.990414999999999	52.975999999999999	0103000020E61000000100000005000000ABE7A4F78D0E5440B0726891ED7C4A40ABE7A4F78D0E5440E23B31EBC57E4A40BE839F38800F5440E23B31EBC57E4A40BE839F38800F5440B0726891ED7C4A40ABE7A4F78D0E5440B0726891ED7C4A40
31530	Суворовка	5	47	968	80.112870999999998	80.137251000000006	52.811669000000002	52.791378000000002	0103000020E61000000100000005000000AD6A4947390754400F63D2DF4B654A40AD6A494739075440A91611C5E4674A40F9156BB8C8085440A91611C5E4674A40F9156BB8C80854400F63D2DF4B654A40AD6A4947390754400F63D2DF4B654A40
59347	Степное Озеро	5	47	968	79.841821999999993	79.868853000000001	52.786459999999998	52.768124	0103000020E6100000010000000500000069C36169E0F55340E8A221E351624A4069C36169E0F553405BCEA5B8AA644A4004029D499BF753405BCEA5B8AA644A4004029D499BF75340E8A221E351624A4069C36169E0F55340E8A221E351624A40
31442	Орлеан	5	47	968	79.578256999999994	79.609589999999997	52.692065999999997	52.676850999999999	0103000020E61000000100000005000000B7EBA52902E55340E8A1B60DA3564A40B7EBA52902E553403656629E95584A40FE7DC68503E753403656629E95584A40FE7DC68503E75340E8A1B60DA3564A40B7EBA52902E55340E8A1B60DA3564A40
31387	Новокулундинка	5	47	968	80.135543999999996	80.180342999999993	53.054526000000003	53.034802999999997	0103000020E61000000100000005000000D1CABDC0AC085440BE66B96C74844A40D1CABDC0AC0854400F643DB5FA864A4000C45DBD8A0B54400F643DB5FA864A4000C45DBD8A0B5440BE66B96C74844A40D1CABDC0AC085440BE66B96C74844A40
31278	Николаевка	5	47	968	80.159754000000007	80.183100999999994	52.965099000000002	52.952010000000001	0103000020E61000000100000005000000EF59D768390A544084BBB376DB794A40EF59D768390A54407F33315D887B4A405AB741EDB70B54407F33315D887B4A405AB741EDB70B544084BBB376DB794A40EF59D768390A544084BBB376DB794A40
31247	Нижний Кучук	5	47	968	79.923514999999995	79.960623999999996	52.719042999999999	52.691951000000003	0103000020E610000001000000050000006397A8DE1AFB53409EB7B1D991584A406397A8DE1AFB534078B5DC99095C4A402CF015DD7AFD534078B5DC99095C4A402CF015DD7AFD53409EB7B1D991584A406397A8DE1AFB53409EB7B1D991584A40
30378	Леньки	5	47	968	80.406422000000006	80.489992999999998	52.955204999999999	52.917354000000003	0103000020E61000000100000005000000FF976BD1021A54406A6D1ADB6B754A40FF976BD1021A5440E3FC4D28447A4A403691990B5C1F5440E3FC4D28447A4A403691990B5C1F54406A6D1ADB6B754A40FF976BD1021A54406A6D1ADB6B754A40
8064	Елизаветград	5	47	968	79.357845999999995	79.378012999999996	52.788970999999997	52.781052000000003	0103000020E6100000010000000500000048C0E8F2E6D65340DA3C0E83F9634A4048C0E8F2E6D65340073F7100FD644A409F1D705D31D85340073F7100FD644A409F1D705D31D85340DA3C0E83F9634A4048C0E8F2E6D65340DA3C0E83F9634A40
31190	Дмитриевка	5	47	968	80.411344999999997	80.431736999999998	53.048793000000003	53.036991	0103000020E61000000100000005000000E197FA79531A5440889FFF1EBC844A40E197FA79531A54400AA359D93E864A4048DE3994A11B54400AA359D93E864A4048DE3994A11B5440889FFF1EBC844A40E197FA79531A5440889FFF1EBC844A40
30978	Глядень 1-й	5	47	968	80.244913999999994	80.272897	52.772815000000001	52.757536000000002	0103000020E610000001000000050000004815C5ABAC0F544076C58CF0F6604A404815C5ABAC0F5440DB6D179AEB624A404C8BFA2477115440DB6D179AEB624A404C8BFA247711544076C58CF0F6604A404815C5ABAC0F544076C58CF0F6604A40
29803	Благовещенка	5	47	968	79.843384999999998	79.949387000000002	52.851042999999997	52.811680000000003	0103000020E61000000100000005000000F73B1405FAF553409D685721E5674A40F73B1405FAF55340AF3E1EFAEE6C4A40D80FB1C1C2FC5340AF3E1EFAEE6C4A40D80FB1C1C2FC53409D685721E5674A40F73B1405FAF553409D685721E5674A40
31506	Байгамут	5	47	968	79.696295000000006	79.707460999999995	52.644329999999997	52.636685	0103000020E610000001000000050000009357E71890EC5340486DE2E47E514A409357E71890EC534074EACA6779524A40828C800A47ED534074EACA6779524A40828C800A47ED5340486DE2E47E514A409357E71890EC5340486DE2E47E514A40
30962	Алексеевка	5	47	968	80.525243000000003	80.552532999999997	52.900523999999997	52.889538999999999	0103000020E61000000100000005000000FDDCD0949D2154401EC2F869DC714A40FDDCD0949D215440ADA1D45E44734A407D3D5FB35C235440ADA1D45E44734A407D3D5FB35C2354401EC2F869DC714A40FDDCD0949D2154401EC2F869DC714A40
29764	Ясная Поляна	5	47	1833	85.427619000000007	85.443383999999995	52.683086000000003	52.677348000000002	0103000020E610000001000000050000007D09151C5E5B55406901DA56B3564A407D09151C5E5B5540802DAF5C6F574A4075E44867605C5540802DAF5C6F574A4075E44867605C55406901DA56B3564A407D09151C5E5B55406901DA56B3564A40
30022	Шебалино	5	47	1833	85.763337000000007	85.823307999999997	52.726165999999999	52.702959	0103000020E61000000100000005000000EAB46E83DA705540E5B67D8FFA594A40EAB46E83DA705540CBBBEA01F35C4A4040A20914B1745540CBBBEA01F35C4A4040A20914B1745540E5B67D8FFA594A40EAB46E83DA705540E5B67D8FFA594A40
28997	Чуйский	5	47	1833	85.487482	85.498531999999997	52.443376999999998	52.439013000000003	0103000020E61000000100000005000000E0D8B3E7325F55406AC2F69331384A40E0D8B3E7325F55403866D993C0384A409B00C3F2E75F55403866D993C0384A409B00C3F2E75F55406AC2F69331384A40E0D8B3E7325F55406AC2F69331384A40
30359	Усятское	5	47	1833	85.733980000000003	85.805341999999996	52.574047999999998	52.555759000000002	0103000020E61000000100000005000000C2FA3F87F96E554095BA641C23474A40C2FA3F87F96E5540C72AA5677A494A4018062CB98A735540C72AA5677A494A4018062CB98A73554095BA641C23474A40C2FA3F87F96E554095BA641C23474A40
29099	Усть-Катунь	5	47	1833	85.159400000000005	85.180267000000001	52.463847999999999	52.452762999999997	0103000020E61000000100000005000000E0BE0E9C334A55405FEB5223F4394A40E0BE0E9C334A554052280B5F5F3B4A401363997E894B554052280B5F5F3B4A401363997E894B55405FEB5223F4394A40E0BE0E9C334A55405FEB5223F4394A40
29259	Студенческий	5	47	1833	85.200659000000002	85.206048999999993	52.607638999999999	52.605277000000001	0103000020E610000001000000050000007AA9D898D74C5540B0027CB7794D4A407AA9D898D74C55401763601DC74D4A40E71725E82F4D55401763601DC74D4A40E71725E82F4D5540B0027CB7794D4A407AA9D898D74C5540B0027CB7794D4A40
29235	Старая Чемровка	5	47	1833	85.171229999999994	85.200911000000005	52.667017000000001	52.641576000000001	0103000020E610000001000000050000000586AC6EF54A554002F390291F524A400586AC6EF54A5540227024D060554A40079ACFB9DB4C5540227024D060554A40079ACFB9DB4C554002F390291F524A400586AC6EF54A554002F390291F524A40
29319	Стан-Бехтемир	5	47	1833	85.604828999999995	85.636989	52.613807999999999	52.593577000000003	0103000020E6100000010000000500000008ABB184B56655403354C554FA4B4A4008ABB184B5665540F702B342914E4A405ABA826DC4685540F702B342914E4A405ABA826DC46855403354C554FA4B4A4008ABB184B56655403354C554FA4B4A40
29949	Сростки	5	47	1833	85.677385999999998	85.716965999999999	52.431260999999999	52.404544999999999	0103000020E610000001000000050000002B31CF4A5A6B554052616C21C8334A402B31CF4A5A6B55402785798F33374A4003965CC5E26D55402785798F33374A4003965CC5E26D554052616C21C8334A402B31CF4A5A6B554052616C21C8334A40
29493	Семеновод	5	47	1833	85.410739000000007	85.426935999999998	52.550229000000002	52.544561000000002	0103000020E61000000100000005000000460C3B8C495A5540AAD6C22CB4454A40460C3B8C495A5540C82764E76D464A400B5F5FEB525B5540C82764E76D464A400B5F5FEB525B5540AAD6C22CB4454A40460C3B8C495A5540AAD6C22CB4454A40
29766	Светлоозерское	5	47	1833	85.512258000000003	85.548343000000003	52.533743000000001	52.520620999999998	0103000020E610000001000000050000005247C7D5C86055402F4E7CB5A3424A405247C7D5C860554006BCCCB051444A4065FF3C0D1863554006BCCCB051444A4065FF3C0D186355402F4E7CB5A3424A405247C7D5C86055402F4E7CB5A3424A40
29614	Пригородный	5	47	1833	85.241603999999995	85.250624000000002	52.575859999999999	52.571354999999997	0103000020E610000001000000050000004CA59F70764F5540FAB31F2922494A404CA59F70764F55408B89CDC7B5494A40EFE53E390A5055408B89CDC7B5494A40EFE53E390A505540FAB31F2922494A404CA59F70764F5540FAB31F2922494A40
28038	Полеводка	5	47	1833	85.561971	85.580099000000004	52.430508000000003	52.418667999999997	0103000020E610000001000000050000003A933655F7635540DCF0BBE996354A403A933655F76355404C55DAE21A374A404F5C8E57206555404C55DAE21A374A404F5C8E5720655540DCF0BBE996354A403A933655F7635540DCF0BBE996354A40
29861	Первомайское	5	47	1833	85.241577000000007	85.270566000000002	52.604045999999997	52.582754999999999	0103000020E61000000100000005000000D09D60FF754F55404D4A41B7974A4A40D09D60FF754F5540CAA31B61514D4A40365A0EF450515540CAA31B61514D4A40365A0EF4505155404D4A41B7974A4A40D09D60FF754F55404D4A41B7974A4A40
29667	Новиково	5	47	1833	85.950796999999994	85.986101000000005	52.624715000000002	52.605988000000004	0103000020E61000000100000005000000A208A9DBD97C55405DE2C803914D4A40A208A9DBD97C55400B293FA9F64F4A4063635E471C7F55400B293FA9F64F4A4063635E471C7F55405DE2C803914D4A40A208A9DBD97C55405DE2C803914D4A40
30287	Мальцева Курья	5	47	1833	85.686818000000002	85.710193000000004	52.582371999999999	52.57349	0103000020E6100000010000000500000077137CD3F46B5540A14ACD1E68494A4077137CD3F46B5540950D6B2A8B4A4A40483657CD736D5540950D6B2A8B4A4A40483657CD736D5540A14ACD1E68494A4077137CD3F46B5540A14ACD1E68494A40
59386	Малоугренево	5	47	1833	85.008195000000001	86.114596000000006	52.884399000000002	52.357599	0103000020E61000000100000005000000683F524486405540890AD5CDC52D4A40683F524486405540BCCE86FC33714A402810768A55875540BCCE86FC33714A402810768A55875540890AD5CDC52D4A40683F524486405540890AD5CDC52D4A40
29424	Малоенисейское	5	47	1833	85.476613	85.531356000000002	52.572958999999997	52.561118999999998	0103000020E610000001000000050000004DF6CFD3805E5540051555BFD2474A404DF6CFD3805E5540747973B856494A4023A298BC01625540747973B856494A4023A298BC01625540051555BFD2474A404DF6CFD3805E5540051555BFD2474A40
29339	Лесное	5	47	1833	85.240356000000006	85.263703000000007	52.475456000000001	52.461582	0103000020E610000001000000050000006FD921FE614F55400D36751E153B4A406FD921FE614F5540EF5701BEDB3C4A40DB368C82E0505540EF5701BEDB3C4A40DB368C82E05055400D36751E153B4A406FD921FE614F55400D36751E153B4A40
30220	Ключи	5	47	1833	85.635704000000004	85.658152999999999	52.598422999999997	52.583756000000001	0103000020E61000000100000005000000EE7BD45FAF685540016C4084B84A4A40EE7BD45FAF6855404C16F71F994C4A40EAB0C22D1F6A55404C16F71F994C4A40EAB0C22D1F6A5540016C4084B84A4A40EE7BD45FAF685540016C4084B84A4A40
29176	Заря	5	47	1833	85.165625000000006	85.182216999999994	52.599944000000001	52.593380000000003	0103000020E610000001000000050000009A999999994A5540DD0C37E0F34B4A409A999999994A554039B709F7CA4C4A409DF17D71A94B554039B709F7CA4C4A409DF17D71A94B5540DD0C37E0F34B4A409A999999994A5540DD0C37E0F34B4A40
30098	Заозерный	5	47	1833	85.479380000000006	85.495091000000002	52.534855	52.531633999999997	0103000020E61000000100000005000000D1967329AE5E554088B839950C444A40D1967329AE5E5540118DEE2076444A40D0622992AF5F5540118DEE2076444A40D0622992AF5F554088B839950C444A40D1967329AE5E554088B839950C444A40
29124	Енисейское	5	47	1833	85.470675	85.531401000000002	52.585135000000001	52.570075000000003	0103000020E61000000100000005000000DE02098A1F5E554034A2B437F8484A40DE02098A1F5E55405B5F24B4E54A4A40F3035779026255405B5F24B4E54A4A40F30357790262554034A2B437F8484A40DE02098A1F5E554034A2B437F8484A40
29801	Восточный	5	47	1833	85.349806999999998	85.361035000000001	52.639789	52.633285999999998	0103000020E610000001000000050000005C3AE63C63565540E08101840F514A405C3AE63C6356554097AB1F9BE4514A40876D8B321B57554097AB1F9BE4514A40876D8B321B575540E08101840F514A405C3AE63C63565540E08101840F514A40
29040	Верх-Катунское	5	47	1833	85.38494	85.468239999999994	52.466343999999999	52.433166	0103000020E6100000010000000500000006BB61DBA25855409CDEC5FB71374A4006BB61DBA2585540C9570229B13B4A4075ABE7A4F75D5540C9570229B13B4A4075ABE7A4F75D55409CDEC5FB71374A4006BB61DBA25855409CDEC5FB71374A40
28956	Верх-Бехтемир	5	47	1833	85.882075999999998	85.929569999999998	52.773800999999999	52.752499999999998	0103000020E610000001000000050000008925E5EE73785540B81E85EB51604A408925E5EE73785540594E42E90B634A40EF552B137E7B5540594E42E90B634A40EF552B137E7B5540B81E85EB51604A408925E5EE73785540B81E85EB51604A40
32506	Боровой	5	47	1833	85.298548999999994	85.318150000000003	52.575963999999999	52.568886999999997	0103000020E6100000010000000500000039D0436D1B5355404D0F0A4AD1484A4039D0436D1B53554030D63730B9494A403C4ED1915C54554030D63730B9494A403C4ED1915C5455404D0F0A4AD1484A4039D0436D1B5355404D0F0A4AD1484A40
28917	Большеугренево	5	47	1833	85.740195999999997	85.776658999999995	52.611483999999997	52.593916	0103000020E6100000010000000500000052280B5F5F6F55401B498270054C4A4052280B5F5F6F55407D03931B454E4A403849F3C7B47155407D03931B454E4A403849F3C7B47155401B498270054C4A4052280B5F5F6F55401B498270054C4A40
33048	Бехтемир-Аникино	5	47	1833	85.788219999999995	85.813722999999996	52.657874	52.649821000000003	0103000020E6100000010000000500000066834C327272554084A0A3552D534A4066834C3272725540C171193735544A403140A20914745540C171193735544A403140A2091474554084A0A3552D534A4066834C327272554084A0A3552D534A40
29395	Амурский	5	47	1833	85.298530999999997	85.314430999999999	52.484620999999997	52.477508	0103000020E61000000100000005000000E675C4211B53554008CA6DFB1E3D4A40E675C4211B53554037FA980F083E4A404F7633A31F54554037FA980F083E4A404F7633A31F54554008CA6DFB1E3D4A40E675C4211B53554008CA6DFB1E3D4A40
28866	Чуманка	5	47	1839	80.447134000000005	80.479922999999999	53.517940000000003	53.500976000000001	0103000020E6100000010000000500000080BBECD79D1C54405B0A48FB1FC04A4080BBECD79D1C544027A5A0DB4BC24A404966F50EB71E544027A5A0DB4BC24A404966F50EB71E54405B0A48FB1FC04A4080BBECD79D1C54405B0A48FB1FC04A40
28481	Ситниково	5	47	1839	80.917079000000001	80.970411999999996	53.142805000000003	53.124198	0103000020E610000001000000050000004C361E6CB13A5440431D56B8E58F4A404C361E6CB13A5440475A2A6F47924A4057E9EE3A1B3E5440475A2A6F47924A4057E9EE3A1B3E5440431D56B8E58F4A404C361E6CB13A5440431D56B8E58F4A40
28444	Сафроново	5	47	1839	81.095833999999996	81.129790999999997	53.198591	53.184353000000002	0103000020E6100000010000000500000012F6ED2422465440B2F50CE198974A4012F6ED2422465440D5230D6E6B994A402B14E97E4E485440D5230D6E6B994A402B14E97E4E485440B2F50CE198974A4012F6ED2422465440B2F50CE198974A40
28348	Прослауха	5	47	1839	80.951151999999993	80.982566000000006	53.347386999999998	53.329380999999998	0103000020E610000001000000050000009961A3ACDF3C54403E76172829AA4A409961A3ACDF3C54401C075E2D77AC4A40570A815CE23E54401C075E2D77AC4A40570A815CE23E54403E76172829AA4A409961A3ACDF3C54403E76172829AA4A40
28563	Покровка	5	47	1839	80.477012000000002	80.497304999999997	53.134464000000001	53.124523000000003	0103000020E610000001000000050000002CF3565D871E5440C74CA25EF08F4A402CF3565D871E5440A33EC91D36914A40C9C859D8D31F5440A33EC91D36914A40C9C859D8D31F5440C74CA25EF08F4A402CF3565D871E5440C74CA25EF08F4A40
28822	Плотава	5	47	1839	80.709603999999999	80.756388000000001	53.472836999999998	53.451838000000002	0103000020E610000001000000050000001747E5266A2D5440878BDCD3D5B94A401747E5266A2D54405CAB3DEC85BC4A408FC536A9683054405CAB3DEC85BC4A408FC536A968305440878BDCD3D5B94A401747E5266A2D5440878BDCD3D5B94A40
28409	Паклино	5	47	1839	81.084560999999994	81.122136999999995	53.152461000000002	53.132205999999996	0103000020E6100000010000000500000017618A7269455440E02A4F20EC904A4017618A72694554402E7590D783934A406B28B517D14754402E7590D783934A406B28B517D1475440E02A4F20EC904A4017618A7269455440E02A4F20EC904A40
28628	Павловка	5	47	1839	80.365889999999993	80.383713	53.237499	53.227085000000002	0103000020E61000000100000005000000BDFBE3BD6A175440C2340C1F119D4A40BDFBE3BD6A17544096EA025E669E4A403483F8C08E18544096EA025E669E4A403483F8C08E185440C2340C1F119D4A40BDFBE3BD6A175440C2340C1F119D4A40
28543	Нижнечуманка	5	47	1839	80.576222000000001	80.602425999999994	53.227651000000002	53.209508	0103000020E61000000100000005000000164F3DD2E02454400C207C28D19A4A40164F3DD2E02454406BF3FFAA239D4A40A510C8258E2654406BF3FFAA239D4A40A510C8258E2654400C207C28D19A4A40164F3DD2E02454400C207C28D19A4A40
28680	Нижнепайва	5	47	1839	80.330533000000003	80.369204999999994	53.327703	53.30809	0103000020E61000000100000005000000EC4FE27327155440C11C3D7E6FA74A40EC4FE273271554408AE6012CF2A94A404221020EA11754408AE6012CF2A94A404221020EA1175440C11C3D7E6FA74A40EC4FE27327155440C11C3D7E6FA74A40
28756	Верх-Чуманка	5	47	1839	80.573212999999996	80.611210999999997	53.410158000000003	53.387957999999998	0103000020E6100000010000000500000017299485AF2454405C1C959BA8B14A4017299485AF245440AD18AE0E80B44A4026FDBD141E275440AD18AE0E80B44A4026FDBD141E2754405C1C959BA8B14A4017299485AF2454405C1C959BA8B14A40
28735	Верх-Пайва	5	47	1839	80.287036000000001	80.320291999999995	53.415643000000003	53.39387	0103000020E6100000010000000500000094313ECC5E125440117008556AB24A4094313ECC5E125440DAE731CA33B54A40E84A04AA7F145440DAE731CA33B54A40E84A04AA7F145440117008556AB24A4094313ECC5E125440117008556AB24A40
28199	Баево	5	47	1839	80.731226000000007	80.803010999999998	53.282536	53.253039000000001	0103000020E6100000010000000500000009FF2268CC2E544068CEFA9463A04A4009FF2268CC2E5440A9F8BF232AA44A4002D53F8864335440A9F8BF232AA44A4002D53F886433544068CEFA9463A04A4009FF2268CC2E544068CEFA9463A04A40
28119	Тоурак	5	47	409	84.999651999999998	85.024463999999995	51.586129	51.558715999999997	0103000020E6100000010000000500000062D8614CFA3F55403FE0810184C7494062D8614CFA3F55405C1E6B4606CB49407AFB73D1904155405C1E6B4606CB49407AFB73D1904155403FE0810184C7494062D8614CFA3F55403FE0810184C74940
27637	Старобелокуриха	5	47	409	85.052464000000001	85.125928000000002	52.067863000000003	52.046427000000001	0103000020E61000000100000005000000E90DF7915B4355406153E751F1054A40E90DF7915B435540E2CD1ABCAF084A40A56950340F485540E2CD1ABCAF084A40A56950340F4855406153E751F1054A40E90DF7915B4355406153E751F1054A40
28029	Сараса	5	47	409	85.342009000000004	85.370143999999996	51.888370000000002	51.840640999999998	0103000020E61000000100000005000000037CB779E35555409F56D11F9AEB4940037CB779E3555540AF5FB01BB6F14940E1B37570B0575540AF5FB01BB6F14940E1B37570B05755409F56D11F9AEB4940037CB779E35555409F56D11F9AEB4940
27592	Россоши	5	47	409	85.220674000000002	85.256894000000003	52.097228000000001	52.073054999999997	0103000020E61000000100000005000000F644D7851F4E554096E7C1DD59094A40F644D7851F4E5540B42094F7710C4A40792288F370505540B42094F7710C4A40792288F37050554096E7C1DD59094A40F644D7851F4E554096E7C1DD59094A40
28007	Пролетарка	5	47	409	85.355232000000001	85.366748999999999	51.807274999999997	51.789262000000001	0103000020E61000000100000005000000889FFF1EBC565540DFFC868906E54940889FFF1EBC5655406FF085C954E74940CE35CCD0785755406FF085C954E74940CE35CCD078575540DFFC868906E54940889FFF1EBC565540DFFC868906E54940
27862	Нижнекаянча	5	47	409	85.699466999999999	85.726918999999995	51.875472000000002	51.848297000000002	0103000020E6100000010000000500000066683C11C46C5540C02500FF94EC494066683C11C46C554028486C770FF04940D3F544D7856E554028486C770FF04940D3F544D7856E5540C02500FF94EC494066683C11C46C5540C02500FF94EC4940
27549	Нижнекаменка	5	47	409	85.355339999999998	85.402806999999996	52.069197000000003	52.014073000000003	0103000020E610000001000000050000007BBDFBE3BD565540D960E124CD014A407BBDFBE3BD5655409CFD8172DB084A4064E60297C75955409CFD8172DB084A4064E60297C7595540D960E124CD014A407BBDFBE3BD565540D960E124CD014A40
27678	Макарьевка	5	47	409	85.213721000000007	85.242502999999999	51.992362	51.973303000000001	0103000020E61000000100000005000000FB5DD89AAD4D5540A20C553195FC4940FB5DD89AAD4D554086E5CFB705FF4940A48B4D2B854F554086E5CFB705FF4940A48B4D2B854F5540A20C553195FC4940FB5DD89AAD4D5540A20C553195FC4940
28168	Куяча	5	47	409	85.065731999999997	85.116972000000004	51.680252000000003	51.653315999999997	0103000020E610000001000000050000003E93FDF3344455400DFAD2DB9FD349403E93FDF334445540F1845E7F12D749400EA320787C475540F1845E7F12D749400EA320787C4755400DFAD2DB9FD349403E93FDF3344455400DFAD2DB9FD34940
28084	Куяган	5	47	409	84.895518999999993	84.932008999999994	51.716318999999999	51.681553000000001	0103000020E61000000100000005000000957CEC2E50395540CFBEF2203DD74940957CEC2E5039554070404B57B0DB4940F8A41309A63B554070404B57B0DB4940F8A41309A63B5540CFBEF2203DD74940957CEC2E50395540CFBEF2203DD74940
27961	Комар	5	47	409	85.376846	85.405501999999998	51.726685000000003	51.702551	0103000020E610000001000000050000003868AF3E1E585540D462F030EDD949403868AF3E1E58554034BF9A0304DD49409B1DA9BEF359554034BF9A0304DD49409B1DA9BEF3595540D462F030EDD949403868AF3E1E585540D462F030EDD94940
27770	Катунь	5	47	409	85.843035	85.860579999999999	51.917949	51.909770999999999	0103000020E6100000010000000500000089981249F4755540B3EC496073F4494089981249F4755540AD32535A7FF54940DEE522BE13775540AD32535A7FF54940DEE522BE13775540B3EC496073F4494089981249F4755540B3EC496073F44940
27820	Верх-Ая	5	47	409	85.656689	85.683871999999994	51.961190000000002	51.952604000000001	0103000020E6100000010000000500000026A94C31076A5540F70489EDEEF9494026A94C31076A5540029F1F4608FB49409BA9108FC46B5540029F1F4608FB49409BA9108FC46B5540F70489EDEEF9494026A94C31076A5540F70489EDEEF94940
27908	Белое	5	47	409	85.328875999999994	85.363523999999998	51.633440999999998	51.616588999999998	0103000020E610000001000000050000001D1CEC4D0C55554063096B63ECCE49401D1CEC4D0C55554007793D9814D14940E9D32AFA4357554007793D9814D14940E9D32AFA4357554063096B63ECCE49401D1CEC4D0C55554063096B63ECCE4940
2181	Алтайское	5	47	409	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
26816	Чернышевский	5	47	278	82.339192999999995	82.360635000000002	52.619959000000001	52.612341999999998	0103000020E610000001000000050000000E828E56B5955440CEFBFF38614E4A400E828E56B595544031EE06D15A4F4A40C0B2D2A41497544031EE06D15A4F4A40C0B2D2A414975440CEFBFF38614E4A400E828E56B5955440CEFBFF38614E4A40
27046	Урюпино	5	47	278	82.669279000000003	82.714374000000007	52.432319999999997	52.412537999999998	0103000020E6100000010000000500000093399677D5AA5440BA2D910BCE344A4093399677D5AA54400FB4024356374A4037C7B94DB8AD54400FB4024356374A4037C7B94DB8AD5440BA2D910BCE344A4093399677D5AA5440BA2D910BCE344A40
26157	Уржум	5	47	278	83.021417999999997	83.048537999999994	52.250211	52.231670999999999	0103000020E61000000100000005000000ED629AE95EC154403F373465A71D4A40ED629AE95EC15440BB0CFFE906204A403FA7203F1BC35440BB0CFFE906204A403FA7203F1BC354403F373465A71D4A40ED629AE95EC154403F373465A71D4A40
26293	Троицкий	5	47	278	82.679151000000005	82.704627000000002	52.599763000000003	52.587657	0103000020E61000000100000005000000ED82C13577AB5440FB213658384B4A40ED82C13577AB5440E92CB308C54C4A403B38D89B18AD5440E92CB308C54C4A403B38D89B18AD5440FB213658384B4A40ED82C13577AB5440FB213658384B4A40
27604	Толстая Дуброва	5	47	278	83.150550999999993	83.184911999999997	52.270677999999997	52.251897999999997	0103000020E610000001000000050000005358A9A0A2C95440C2F693313E204A405358A9A0A2C9544093DFA293A5224A40D4282499D5CB544093DFA293A5224A40D4282499D5CB5440C2F693313E204A405358A9A0A2C95440C2F693313E204A40
26245	Солнечный	5	47	278	82.746965000000003	82.787199999999999	52.518675999999999	52.507905999999998	0103000020E610000001000000050000006D904946CEAF544099B8551003414A406D904946CEAF54402C9CA4F963424A4051DA1B7C61B254402C9CA4F963424A4051DA1B7C61B2544099B8551003414A406D904946CEAF544099B8551003414A40
26996	Совхозный	5	47	278	82.817914000000002	82.841243000000006	52.384920999999999	52.375470999999997	0103000020E61000000100000005000000323CF6B358B4544057CC086F0F304A40323CF6B358B454409545611745314A404B3FE1ECD6B554409545611745314A404B3FE1ECD6B5544057CC086F0F304A40323CF6B358B4544057CC086F0F304A40
25958	Серебренниково	5	47	278	82.283794	82.375871000000004	52.740665	52.700383000000002	0103000020E6100000010000000500000044334FAE2992544052D66F26A6594A4044334FAE299254405B25581CCE5E4A40F3203D450E9854405B25581CCE5E4A40F3203D450E98544052D66F26A6594A4044334FAE2992544052D66F26A6594A40
2093	Савинка (Совинское)	5	47	278	82.602902	82.637568000000002	52.656829999999999	52.637991	0103000020E610000001000000050000005A2C45F295A65440381268B0A9514A405A2C45F295A654400E84640113544A40793E03EACDA854400E84640113544A40793E03EACDA85440381268B0A9514A405A2C45F295A65440381268B0A9514A40
26119	Приятельский	5	47	278	83.074374000000006	83.096688	52.223064999999998	52.203668999999998	0103000020E610000001000000050000000E6B2A8BC2C45440C11A67D3111A4A400E6B2A8BC2C45440EDF0D7648D1C4A409A7ADD2230C65440EDF0D7648D1C4A409A7ADD2230C65440C11A67D3111A4A400E6B2A8BC2C45440C11A67D3111A4A40
26913	Плотава	5	47	278	82.753011000000001	82.780409000000006	52.291648000000002	52.280844999999999	0103000020E61000000100000005000000CFA10C5531B05440601F9DBAF2234A40CFA10C5531B05440CFF8BEB854254A4043209738F2B15440CFF8BEB854254A4043209738F2B15440601F9DBAF2234A40CFA10C5531B05440601F9DBAF2234A40
25673	Первомайский	5	47	278	82.618307999999999	82.632879000000003	52.493350999999997	52.485576000000002	0103000020E61000000100000005000000BBB6B75B92A754407BDCB75A273E4A40BBB6B75B92A7544075392520263F4A40D0D4EB1681A8544075392520263F4A40D0D4EB1681A854407BDCB75A273E4A40BBB6B75B92A754407BDCB75A273E4A40
26846	Осколково	5	47	278	83.146957999999998	83.180160000000001	52.333292999999998	52.307426	0103000020E61000000100000005000000ADF886C267C9544055F833BC59274A40ADF886C267C954402C7E5358A92A4A400803CFBD87CB54402C7E5358A92A4A400803CFBD87CB544055F833BC59274A40ADF886C267C9544055F833BC59274A40
25630	Октябрьский	5	47	278	82.755731999999995	82.769306	52.346668999999999	52.341068	0103000020E610000001000000050000009A22C0E95DB0544027DBC01DA82B4A409A22C0E95DB05440BDC458A65F2C4A4076A73B4F3CB15440BDC458A65F2C4A4076A73B4F3CB1544027DBC01DA82B4A409A22C0E95DB0544027DBC01DA82B4A40
26615	Новоникольский	5	47	278	82.818281999999996	82.846363999999994	52.768909000000001	52.760899000000002	0103000020E61000000100000005000000F33977BB5EB454409147702365614A40F33977BB5EB45440CF4C309C6B624A40C020E9D32AB65440CF4C309C6B624A40C020E9D32AB654409147702365614A40F33977BB5EB454409147702365614A40
25858	Новоколпаково	5	47	278	82.963953000000004	82.991414000000006	52.571945999999997	52.558146000000001	0103000020E610000001000000050000006478EC67B1BD54405532005471474A406478EC67B1BD5440FC89CA8635494A40FBB2B45373BF5440FC89CA8635494A40FBB2B45373BF54405532005471474A406478EC67B1BD54405532005471474A40
26768	Моховское	5	47	278	82.455498000000006	82.501904999999994	52.631526000000001	52.609149000000002	0103000020E610000001000000050000002E5915E1269D544010B22C98F84D4A402E5915E1269D54406F490ED8D5504A40BA2C26361FA054406F490ED8D5504A40BA2C26361FA0544010B22C98F84D4A402E5915E1269D544010B22C98F84D4A40
25569	Мамонтовский	5	47	278	82.696776	82.704213999999993	52.329501	52.323953000000003	0103000020E61000000100000005000000D0285DFA97AC54407638BA4A77294A40D0285DFA97AC5440E97FB9162D2A4A40A9D898D711AD5440E97FB9162D2A4A40A9D898D711AD54407638BA4A77294A40D0285DFA97AC54407638BA4A77294A40
26735	Малиновка	5	47	278	82.214264	82.268315999999999	52.484172000000001	52.471561999999999	0103000020E61000000100000005000000732D5A80B68D5440A704C4245C3C4A40732D5A80B68D5440C8D11C59F93D4A40963FDF162C915440C8D11C59F93D4A40963FDF162C915440A704C4245C3C4A40732D5A80B68D5440A704C4245C3C4A40
25521	Малахово	5	47	278	82.739123000000006	82.758544000000001	52.414175	52.404269999999997	0103000020E610000001000000050000002C2E8ECA4DAF544080608E1EBF334A402C2E8ECA4DAF544010E9B7AF03354A40EE2422FC8BB0544010E9B7AF03354A40EE2422FC8BB0544080608E1EBF334A402C2E8ECA4DAF544080608E1EBF334A40
2138	Красный Яр	5	47	278	82.603306000000003	82.631018999999995	52.395961999999997	52.376047999999997	0103000020E61000000100000005000000C2DEC4909CA65440F4DC425722304A40C2DEC4909CA65440B83A00E2AE324A40E509849D62A85440B83A00E2AE324A40E509849D62A85440F4DC425722304A40C2DEC4909CA65440F4DC425722304A40
26582	Краснодубровский	5	47	278	82.740183000000002	82.766863000000001	52.703325	52.678674999999998	0103000020E61000000100000005000000888384285FAF544070CE88D2DE564A40888384285FAF5440C7BAB88D065A4A40CC608C4814B15440C7BAB88D065A4A40CC608C4814B1544070CE88D2DE564A40888384285FAF544070CE88D2DE564A40
26531	Кондратьевский	5	47	278	82.846552000000003	82.872720000000001	52.717112	52.706063999999998	0103000020E61000000100000005000000429770E82DB6544004711E4E605A4A40429770E82DB65440DAC87553CA5B4A402BA4FCA4DAB75440DAC87553CA5B4A402BA4FCA4DAB7544004711E4E605A4A40429770E82DB6544004711E4E605A4A40
26441	Кировское	5	47	278	82.716898	82.744125999999994	52.737312000000003	52.724497	0103000020E61000000100000005000000572426A8E1AD54406A865451BC5C4A40572426A8E1AD54406479573D605E4A409C86A8C29FAF54406479573D605E4A409C86A8C29FAF54406A865451BC5C4A40572426A8E1AD54406A865451BC5C4A40
26403	Кашино	5	47	278	82.536147999999997	82.587586000000002	52.379567000000002	52.357923999999997	0103000020E610000001000000050000003674B33F50A254400C3A2174D02D4A403674B33F50A2544007D2C5A695304A4099654F029BA5544007D2C5A695304A4099654F029BA554400C3A2174D02D4A403674B33F50A254400C3A2174D02D4A40
26345	Кабаково	5	47	278	82.471281000000005	82.510052000000002	52.315123999999997	52.299866000000002	0103000020E610000001000000050000007A8EC877299E54405797530262264A407A8EC877299E5440A417B5FB55284A409AD024B1A4A05440A417B5FB55284A409AD024B1A4A054405797530262264A407A8EC877299E54405797530262264A40
26193	Заветы Ильича	5	47	278	82.679653999999999	82.701744000000005	52.514642000000002	52.503148000000003	0103000020E610000001000000050000001EA67D737FAB54401F86562767404A401EA67D737FAB5440F392FFC9DF414A40838AAA5FE9AC5440F392FFC9DF414A40838AAA5FE9AC54401F86562767404A401EA67D737FAB54401F86562767404A40
1185	Дубровский	5	47	278	82.843597000000003	82.861608000000004	52.658659999999998	52.645837999999998	0103000020E610000001000000050000003D80457EFDB55440CC41D0D1AA524A403D80457EFDB5544078978BF84E544A40357EE19524B7544078978BF84E544A40357EE19524B75440CC41D0D1AA524A403D80457EFDB55440CC41D0D1AA524A40
26038	Дружба	5	47	278	82.488186999999996	82.517688000000007	52.582661999999999	52.570785999999998	0103000020E6100000010000000500000045D5AF743E9F5440E08101840F494A4045D5AF743E9F54409C4F1DAB944A4A400762D9CC21A154409C4F1DAB944A4A400762D9CC21A15440E08101840F494A4045D5AF743E9F5440E08101840F494A40
26007	Ветелки	5	47	278	82.889465000000001	82.909002999999998	52.236275999999997	52.212967999999996	0103000020E61000000100000005000000F27B9BFEECB85440198C1189421B4A40F27B9BFEECB85440336ABE4A3E1E4A40D13DEB1A2DBA5440336ABE4A3E1E4A40D13DEB1A2DBA5440198C1189421B4A40F27B9BFEECB85440198C1189421B4A40
59403	Вавилон	5	47	278	82.002296999999999	83.317701	52.789396000000004	52.143197000000001	0103000020E6100000010000000500000040F850A22580544052F17F4754124A4040F850A225805440EFCB99ED0A654A40043A933655D45440EFCB99ED0A654A40043A933655D4544052F17F4754124A4040F850A22580544052F17F4754124A40
25904	Боровское	5	47	278	82.154759999999996	82.207831999999996	52.665182000000001	52.636536999999997	0103000020E61000000100000005000000A7AE7C96E7895440D3D85E0B7A514A40A7AE7C96E7895440A6F10BAF24554A40FCC3961E4D8D5440A6F10BAF24554A40FCC3961E4D8D5440D3D85E0B7A514A40A7AE7C96E7895440D3D85E0B7A514A40
26685	Бориха	5	47	278	82.635035000000002	82.663493000000003	52.296709999999997	52.278326999999997	0103000020E610000001000000050000002F34D769A4A85440014C1938A0234A402F34D769A4A85440B532E197FA254A40FF0758AB76AA5440B532E197FA254A40FF0758AB76AA5440014C1938A0234A402F34D769A4A85440014C1938A0234A40
25807	Большепанюшево	5	47	278	82.853442000000001	82.883679999999998	52.525903	52.510421999999998	0103000020E610000001000000050000001AC231CB9EB654405794128255414A401AC231CB9EB6544024EF1CCA50434A4046088F368EB8544024EF1CCA50434A4046088F368EB854405794128255414A401AC231CB9EB654405794128255414A40
25783	Безголосово	5	47	278	82.950523000000004	82.989483000000007	52.537846000000002	52.505774000000002	0103000020E6100000010000000500000022C66B5ED5BC54406495D233BD404A4022C66B5ED5BC544068244223D8444A40AC3C81B053BF544068244223D8444A40AC3C81B053BF54406495D233BD404A4022C66B5ED5BC54406495D233BD404A40
25727	Александровский	5	47	278	82.916684000000004	82.943184000000002	52.396577999999998	52.380265000000001	0103000020E610000001000000050000000E315EF3AABA54401F680586AC304A400E315EF3AABA544013286211C3324A4012876C205DBC544013286211C3324A4012876C205DBC54401F680586AC304A400E315EF3AABA54401F680586AC304A40
1173	Алейский	5	47	278	82.675207	82.736723999999995	52.483024999999998	52.465207999999997	0103000020E61000000100000005000000F0C16B9736AB544035EB8CEF8B3B4A40F0C16B9736AB5440401361C3D33D4A40698B6B7C26AF5440401361C3D33D4A40698B6B7C26AF544035EB8CEF8B3B4A40F0C16B9736AB544035EB8CEF8B3B4A40
57828	с. Нижний Нойбер	8	80	\N	44.833398000000003	46.660426999999999	44.009798000000004	42.475405000000002	0103000020E61000000100000005000000A24621C9AC6A46406DAD2F12DA3C4540A24621C9AC6A46407AC8940F410146409C3237DF885447407AC8940F410146409C3237DF885447406DAD2F12DA3C4540A24621C9AC6A46406DAD2F12DA3C4540
57767	Курчалой	8	80	\N	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
57768	Гудермес	8	80	\N	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
28733	Грозный	8	80	\N	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60679	Ассиновская	8	80	\N	44.833398000000003	46.660426999999999	44.009798000000004	42.475405000000002	0103000020E61000000100000005000000A24621C9AC6A46406DAD2F12DA3C4540A24621C9AC6A46407AC8940F410146409C3237DF885447407AC8940F410146409C3237DF885447406DAD2F12DA3C4540A24621C9AC6A46406DAD2F12DA3C4540
32988	Аргун	8	80	\N	45.852024	45.913694	43.312002999999997	43.258360000000003	0103000020E610000001000000050000001CB4571F0FED46401B4CC3F011A145401CB4571F0FED46407FA0DCB6EFA745409546CCECF3F446407FA0DCB6EFA745409546CCECF3F446401B4CC3F011A145401CB4571F0FED46401B4CC3F011A14540
57745	Шелковская	8	80	972	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
32589	Харьковское	8	80	972	46.331463999999997	46.341048999999998	43.484147	43.468131999999997	0103000020E6100000010000000500000092E68F696D2A4740041BD7BFEBBB454092E68F696D2A47406FBA6587F8BD4540B0AA5E7EA72B47406FBA6587F8BD4540B0AA5E7EA72B4740041BD7BFEBBB454092E68F696D2A4740041BD7BFEBBB4540
57754	Старощедринская	8	80	972	46.099671999999998	46.115976000000003	43.47334	43.461131000000002	0103000020E61000000100000005000000D829560DC20C4740FD15325706BB4540D829560DC20C4740BFF1B56796BC45407A8F334DD80E4740BFF1B56796BC45407A8F334DD80E4740FD15325706BB4540D829560DC20C4740FD15325706BB4540
57806	Старогладковская	8	80	972	46.406086999999999	46.42841	43.642477999999997	43.630532000000002	0103000020E61000000100000005000000562AA8A8FA3347406E8AC745B5D04540562AA8A8FA334740223317B83CD24540C2A38D23D6364740223317B83CD24540C2A38D23D63647406E8AC745B5D04540562AA8A8FA3347406E8AC745B5D04540
8126	ОТФ Колхоза Имени Ленина	8	80	972	46.049995000000003	46.055734999999999	43.907803999999999	43.903126999999998	0103000020E6100000010000000500000055FB743C660647403A9160AA99F3454055FB743C66064740C896E5EB32F445400C1F115322074740C896E5EB32F445400C1F1153220747403A9160AA99F3454055FB743C660647403A9160AA99F34540
32597	Коби	8	80	972	46.233898000000003	46.252232999999997	43.512442999999998	43.504387999999999	0103000020E61000000100000005000000C74CA25EF01D4740573F36C98FC04540C74CA25EF01D4740350873BB97C1454069FCC22B49204740350873BB97C1454069FCC22B49204740573F36C98FC04540C74CA25EF01D4740573F36C98FC04540
24966	Дубовская	8	80	972	46.535210999999997	46.568385999999997	43.799348000000002	43.784238000000002	0103000020E61000000100000005000000CFBA46CB81444740E62329E961E44540CFBA46CB81444740BF0F070951E645408BC058DFC0484740BF0F070951E645408BC058DFC0484740E62329E961E44540CFBA46CB81444740E62329E961E44540
32548	Воскресенское	8	80	972	46.380710000000001	46.390124	43.560156999999997	43.548639000000001	0103000020E610000001000000050000004DA1F31ABB304740B32781CD39C645404DA1F31ABB3047400FD07D39B3C745403EB14E95EF3147400FD07D39B3C745403EB14E95EF314740B32781CD39C645404DA1F31ABB304740B32781CD39C64540
57766	Бурунское	8	80	972	45.771858999999999	45.786141999999998	43.865158000000001	43.852826999999998	0103000020E61000000100000005000000C70F9546CCE24640A912656F29ED4540C70F9546CCE24640B7EF517FBDEE45408A01124DA0E44640B7EF517FBDEE45408A01124DA0E44640A912656F29ED4540C70F9546CCE24640A912656F29ED4540
24245	Юкерч-Келой	8	80	1728	45.719549999999998	45.750864999999997	42.856985000000002	42.845782	0103000020E610000001000000050000001CEBE2361ADC4640D2C5A695426C45401CEBE2361ADC4640CF143AAFB16D4540035B25581CE04640CF143AAFB16D4540035B25581CE04640D2C5A695426C45401CEBE2361ADC4640D2C5A695426C4540
57821	Шикарой	8	80	1728	45.759793999999999	45.762714000000003	42.627276999999999	42.624032999999997	0103000020E6100000010000000500000038D906EE40E14640F84F3750E04F454038D906EE40E146403944DC9C4A504540C619C39CA0E146403944DC9C4A504540C619C39CA0E14640F84F3750E04F454038D906EE40E14640F84F3750E04F4540
23937	Шатой	8	80	1728	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
23536	Шарой	8	80	1728	45.805140999999999	45.810988999999999	42.63147	42.628397999999997	0103000020E6100000010000000500000099D53BDC0EE74640976F7D586F50454099D53BDC0EE74640DB334B02D45045403735D07CCEE74640DB334B02D45045403735D07CCEE74640976F7D586F50454099D53BDC0EE74640976F7D586F504540
23628	Хуландой	8	80	1728	45.749509000000003	45.756335999999997	42.557265000000001	42.552396999999999	0103000020E61000000100000005000000628731E9EFDF46404AB4E4F1B4464540628731E9EFDF46404C1AA37554474540CB64389ECFE046404C1AA37554474540CB64389ECFE046404AB4E4F1B4464540628731E9EFDF46404AB4E4F1B4464540
23477	Хакмадой	8	80	1728	45.822667000000003	45.831929000000002	42.626919000000001	42.621319999999997	0103000020E61000000100000005000000CD3FFA264DE94640E42CEC69874F4540CD3FFA264DE94640DA1EBDE13E50454008CC43A67CEA4640DA1EBDE13E50454008CC43A67CEA4640E42CEC69874F4540CD3FFA264DE94640E42CEC69874F4540
57803	Урдюхой	8	80	1728	45.693849	45.710718999999997	42.846766000000002	42.837955000000001	0103000020E6100000010000000500000060AE450BD0D846408542041C426B454060AE450BD0D84640B0AE0AD4626C4540AAD216D7F8DA4640B0AE0AD4626C4540AAD216D7F8DA46408542041C426B454060AE450BD0D846408542041C426B4540
60633	Улус-Керт	8	80	1728	45.758536999999997	45.771543999999999	42.990670999999999	42.984709000000002	0103000020E6100000010000000500000029E78BBD17E14640D789CBF10A7E454029E78BBD17E146403D0CAD4ECE7E454067B62BF4C1E246403D0CAD4ECE7E454067B62BF4C1E24640D789CBF10A7E454029E78BBD17E14640D789CBF10A7E4540
24097	Памятой	8	80	1728	45.688980000000001	45.698034999999997	42.860461000000001	42.848941000000003	0103000020E610000001000000050000008ECC237F30D84640E59D4319AA6C45408ECC237F30D84640E23D0796236E45404F3BFC3559D94640E23D0796236E45404F3BFC3559D94640E59D4319AA6C45408ECC237F30D84640E59D4319AA6C4540
24448	Мусолт-Аул	8	80	1728	45.770125	45.774787000000003	42.836545999999998	42.831144999999999	0103000020E610000001000000050000007F6ABC7493E24640F19D98F5626A45407F6ABC7493E24640C0CC77F0136B4540D82E6D382CE34640C0CC77F0136B4540D82E6D382CE34640F19D98F5626A45407F6ABC7493E24640F19D98F5626A4540
23674	Кири	8	80	1728	45.907783000000002	45.921419	42.678249000000001	42.670645999999998	0103000020E61000000100000005000000B16EBC3B32F44640BB9866BAD7554540B16EBC3B32F44640B9C5FCDCD0564540DE74CB0EF1F54640B9C5FCDCD0564540DE74CB0EF1F54640BB9866BAD7554540B16EBC3B32F44640BB9866BAD7554540
23753	Кенхи	8	80	1728	45.943939999999998	45.952689999999997	42.643932	42.637239999999998	0103000020E6100000010000000500000070B1A206D3F84640FDD98F149151454070B1A206D3F84640876C205D6C524540F59CF4BEF1F94640876C205D6C524540F59CF4BEF1F94640FDD98F149151454070B1A206D3F84640FDD98F1491514540
57772	Бутти	8	80	1728	45.976010000000002	45.986367000000001	42.663035999999998	42.659421999999999	0103000020E61000000100000005000000D4484BE5EDFC4640A721AAF067544540D4484BE5EDFC46400B09185DDE544540446D1B4641FE46400B09185DDE544540446D1B4641FE4640A721AAF067544540D4484BE5EDFC4640A721AAF067544540
24881	Борзой	8	80	1728	45.611877999999997	45.642214000000003	42.847242000000001	42.831581	0103000020E610000001000000050000002992AF0452CE4640CC7C073F716A45402992AF0452CE464019E6046D726C454045847F1134D2464019E6046D726C454045847F1134D24640CC7C073F716A45402992AF0452CE4640CC7C073F716A4540
57795	Шарой	8	80	7450	45.805140999999999	45.810988999999999	42.63147	42.628397999999997	0103000020E6100000010000000500000099D53BDC0EE74640976F7D586F50454099D53BDC0EE74640DB334B02D45045403735D07CCEE74640DB334B02D45045403735D07CCEE74640976F7D586F50454099D53BDC0EE74640976F7D586F504540
23331	Шали	8	80	1161	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
60634	Цоцкин-Юрт	8	80	1161	45.983860999999997	46.017090000000003	43.256345000000003	43.224637000000001	0103000020E61000000100000005000000A9674128EFFD46405C3CBCE7C09C4540A9674128EFFD46401FBFB7E9CFA04540598B4F01300247401FBFB7E9CFA04540598B4F01300247405C3CBCE7C09C4540A9674128EFFD46405C3CBCE7C09C4540
57770	Центорой	8	80	1161	45.717699000000003	46.361091000000002	43.352496000000002	42.988295999999998	0103000020E610000001000000050000009BAF928FDDDB46404162BB7B807E45409BAF928FDDDB464044FCC3961EAD4540A2F0D93A382E474044FCC3961EAD4540A2F0D93A382E47404162BB7B807E45409BAF928FDDDB46404162BB7B807E4540
10997	Совхоз Южный	8	80	1161	45.840246999999998	45.844200000000001	43.264079000000002	43.260120000000001	0103000020E61000000100000005000000F3C7B4368DEB46408C84B69C4BA14540F3C7B4368DEB4640BB473657CDA1454040A4DFBE0EEC4640BB473657CDA1454040A4DFBE0EEC46408C84B69C4BA14540F3C7B4368DEB46408C84B69C4BA14540
60636	Новые Атаги	8	80	1161	45.760091000000003	45.799256999999997	43.149951000000001	43.115602000000003	0103000020E61000000100000005000000F27D71A94AE1464015ADDC0BCC8E4540F27D71A94AE146405280289831934540AE0CAA0D4EE646405280289831934540AE0CAA0D4EE6464015ADDC0BCC8E4540F27D71A94AE1464015ADDC0BCC8E4540
16602	Ники-Хита	8	80	1161	46.063181999999998	46.076054999999997	43.123735000000003	43.107532999999997	0103000020E6100000010000000500000012D9075916084740D11E2FA4C38D454012D90759160847406F2F698CD68F454040D9942BBC0947406F2F698CD68F454040D9942BBC094740D11E2FA4C38D454012D9075916084740D11E2FA4C38D4540
57747	Курчалой	8	80	1161	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
57757	Шалажи	8	80	1644	45.343406999999999	45.370123	43.108994000000003	43.072988000000002	0103000020E61000000100000005000000D61BB5C2F4AB46400F80B8AB57894540D61BB5C2F4AB4640E9BAF083F38D4540AB3FC23060AF4640E9BAF083F38D4540AB3FC23060AF46400F80B8AB57894540D61BB5C2F4AB46400F80B8AB57894540
22260	Урус-Мартан	8	80	1644	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
57760	Гойское	8	80	1644	45.591728000000003	45.608392000000002	43.105071000000002	43.073923000000001	0103000020E6100000010000000500000052103CBEBDCB46400BB6114F7689454052103CBEBDCB464007616EF7728D4540F392FFC9DFCD464007616EF7728D4540F392FFC9DFCD46400BB6114F7689454052103CBEBDCB46400BB6114F76894540
57835	Гехи	8	80	1644	45.446561000000003	45.490758	43.177996999999998	43.142907000000001	0103000020E61000000100000005000000A4552DE928B946404BAFCDC64A924540A4552DE928B946409FE40E9BC89645400C207C28D1BE46409FE40E9BC89645400C207C28D1BE46404BAFCDC64A924540A4552DE928B946404BAFCDC64A924540
32698	Алхан-Юрт	8	80	1644	45.540489000000001	45.580373999999999	43.240820999999997	43.219940000000001	0103000020E61000000100000005000000836C59BE2EC54640878A71FE269C4540836C59BE2EC546405298F738D39E45406FB9FAB149CA46405298F738D39E45406FB9FAB149CA4640878A71FE269C4540836C59BE2EC54640878A71FE269C4540
60645	Алхазурово	8	80	1644	45.630220999999999	45.671956999999999	43.076945000000002	43.048662	0103000020E610000001000000050000004F20EC14ABD046406B47718E3A8645404F20EC14ABD046409D4B7155D9894540BDA8DDAF02D646409D4B7155D9894540BDA8DDAF02D646406B47718E3A8645404F20EC14ABD046406B47718E3A864540
16625	Эникали	8	80	1303	46.141838999999997	46.163685999999998	43.077945999999997	43.070695999999998	0103000020E610000001000000050000000F26C5C727124740A0FA07910C8945400F26C5C727124740506D7022FA8945401268B0A9F3144740506D7022FA8945401268B0A9F3144740A0FA07910C8945400F26C5C727124740A0FA07910C894540
57812	Шовхол-Берди	8	80	1303	46.314576000000002	46.325885999999997	43.117891999999998	43.107545999999999	0103000020E61000000100000005000000A20DC0064428474066683C11C48D4540A20DC00644284740E23AC615178F4540B41CE8A1B6294740E23AC615178F4540B41CE8A1B629474066683C11C48D4540A20DC0064428474066683C11C48D4540
18796	Чурч-Ирзу	8	80	1303	46.390042999999999	46.402090000000001	43.088811	43.073698999999998	0103000020E610000001000000050000005184D4EDEC314740BB5F05F86E8945405184D4EDEC3147403543AA285E8B45403A0664AF773347403543AA285E8B45403A0664AF77334740BB5F05F86E8945405184D4EDEC314740BB5F05F86E894540
40437	Центорой	8	80	1303	46.209437000000001	46.234796000000003	43.017266999999997	42.997475999999999	0103000020E6100000010000000500000043C9E4D4CE1A4740BF45274BAD7F454043C9E4D4CE1A4740672618CE35824540A69D9ACB0D1E4740672618CE35824540A69D9ACB0D1E4740BF45274BAD7F454043C9E4D4CE1A4740BF45274BAD7F4540
60658	Хочч-Ара	8	80	1303	46.313066999999997	46.328015000000001	43.060110999999999	43.043543	0103000020E61000000100000005000000793A579412284740207C28D192854540793A5794122847409F909DB7B187454079CC4065FC2947409F909DB7B187454079CC4065FC294740207C28D192854540793A579412284740207C28D192854540
16709	Хиди-Хутор	8	80	1303	46.138191999999997	46.155591999999999	43.121991000000001	43.104900000000001	0103000020E61000000100000005000000CF488446B0114740DAACFA5C6D8D4540CF488446B011474003B4AD669D8F454076C24B70EA13474003B4AD669D8F454076C24B70EA134740DAACFA5C6D8D4540CF488446B0114740DAACFA5C6D8D4540
60660	Турни-Хутор	8	80	1303	46.263047999999998	46.280870999999998	43.099449999999997	43.086862000000004	0103000020E610000001000000050000009CA38E8EAB214740F1A1444B1E8B45409CA38E8EAB21474029CB10C7BA8C454089B2B794F323474029CB10C7BA8C454089B2B794F3234740F1A1444B1E8B45409CA38E8EAB214740F1A1444B1E8B4540
57796	Татай-Хутор	8	80	1303	46.059122000000002	46.532156999999998	43.202007999999999	42.841498000000001	0103000020E61000000100000005000000B03C484F9107474020D3DA34B66B4540B03C484F91074740E3C3EC65DB99454032AB77B81D444740E3C3EC65DB99454032AB77B81D44474020D3DA34B66B4540B03C484F9107474020D3DA34B66B4540
40443	Саясан	8	80	1303	46.277977999999997	46.292656999999998	43.069602000000003	43.051594000000001	0103000020E61000000100000005000000F58079C894234740BD55D7A19A864540F58079C8942347403CDEE4B7E888454005F9D9C8752547403CDEE4B7E888454005F9D9C875254740BD55D7A19A864540F58079C894234740BD55D7A19A864540
40445	Рогун-Кажа	8	80	1303	46.341444000000003	46.354722000000002	43.083734	43.068246000000002	0103000020E610000001000000050000002DB5DE6FB42B47409A0AF148BC8845402DB5DE6FB42B474019C8B3CBB78A4540FB95CE87672D474019C8B3CBB78A4540FB95CE87672D47409A0AF148BC8845402DB5DE6FB42B47409A0AF148BC884540
57748	Ножайт-Юрт	8	80	1303	46.361297	46.391274000000003	43.107703999999998	43.083879000000003	0103000020E610000001000000050000004B92E7FA3E2E47401DE90C8CBC8A45404B92E7FA3E2E4740FED2A23EC98D454037E3344415324740FED2A23EC98D454037E33444153247401DE90C8CBC8A45404B92E7FA3E2E47401DE90C8CBC8A4540
57763	Морзой-Мохк	8	80	1303	46.088208999999999	46.111277999999999	43.092537	43.080745	0103000020E610000001000000050000003F1BB96E4A0B4740632827DA558A45403F1BB96E4A0B4740C1559E40D88B4540D461855B3E0E4740C1559E40D88B4540D461855B3E0E4740632827DA558A45403F1BB96E4A0B4740632827DA558A4540
40448	Мескеты	8	80	1303	46.347651999999997	46.372669999999999	43.172671999999999	43.146017999999998	0103000020E61000000100000005000000CA3159DC7F2C47404C50C3B7B0924540CA3159DC7F2C4740AB77B81D1A964540A4198BA6B32F4740AB77B81D1A964540A4198BA6B32F47404C50C3B7B0924540CA3159DC7F2C47404C50C3B7B0924540
14507	Малые Шуани	8	80	1303	46.229982	46.243555000000001	43.081206000000002	43.066414999999999	0103000020E610000001000000050000009755D80C701D47405F7B6649808845409755D80C701D4740971E4DF5648A45407EE36BCF2C1F4740971E4DF5648A45407EE36BCF2C1F47405F7B6649808845409755D80C701D47405F7B664980884540
60641	Зандакское сельское поселение	8	80	1303	46.059122000000002	46.532156999999998	43.202007999999999	42.841498000000001	0103000020E61000000100000005000000B03C484F9107474020D3DA34B66B4540B03C484F91074740E3C3EC65DB99454032AB77B81D444740E3C3EC65DB99454032AB77B81D44474020D3DA34B66B4540B03C484F9107474020D3DA34B66B4540
40438	Замай-Юрт	8	80	1303	46.366840000000003	46.384796999999999	43.157383000000003	43.143709000000001	0103000020E61000000100000005000000AD6EF59CF42E47400892770E65924540AD6EF59CF42E474023F94A2025944540A94C31074131474023F94A2025944540A94C3107413147400892770E65924540AD6EF59CF42E47400892770E65924540
16542	Джагларги	8	80	1303	46.096977000000003	46.112876999999997	43.115411000000002	43.098087	0103000020E610000001000000050000006BBB09BE690C4740D594641D8E8C45406BBB09BE690C4740A14CA3C9C58E45403CBCE7C0720E4740A14CA3C9C58E45403CBCE7C0720E4740D594641D8E8C45406BBB09BE690C4740D594641D8E8C4540
57784	Даттых	8	80	1303	46.385516000000003	46.415923999999997	43.027799999999999	42.996116999999998	0103000020E61000000100000005000000D90A9A9658314740ACFE08C3807F4540D90A9A9658314740166A4DF38E8345408DCF64FF3C354740166A4DF38E8345408DCF64FF3C354740ACFE08C3807F4540D90A9A9658314740ACFE08C3807F4540
13734	Гордали	8	80	1303	46.218581999999998	46.235030000000002	43.052028	43.032215000000001	0103000020E6100000010000000500000044BFB67EFA1B474067B8019F1F84454044BFB67EFA1B4740F73C7FDAA886454019CA8976151E4740F73C7FDAA886454019CA8976151E474067B8019F1F84454044BFB67EFA1B474067B8019F1F844540
19286	Гендерген	8	80	1303	46.327582999999997	46.340825000000002	43.029967999999997	43.017676000000002	0103000020E61000000100000005000000DFDC5F3DEE29474049F6083543824540DFDC5F3DEE29474098F6CDFDD583454061545227A02B474098F6CDFDD583454061545227A02B474049F6083543824540DFDC5F3DEE29474049F6083543824540
40441	Гансолчу	8	80	1303	46.230286999999997	46.250903000000001	43.132519000000002	43.116464000000001	0103000020E61000000100000005000000D3D85E0B7A1D4740A794D74AE88E4540D3D85E0B7A1D4740A08CF161F6904540F1BBE9961D204740A08CF161F6904540F1BBE9961D204740A794D74AE88E4540D3D85E0B7A1D4740A794D74AE88E4540
40450	Галайты	8	80	1303	46.381087000000001	46.399009	43.179890999999998	43.168365000000001	0103000020E6100000010000000500000023F77475C73047404165FCFB8C95454023F77475C730474020EC14AB06974540A3E716BA1233474020EC14AB06974540A3E716BA123347404165FCFB8C95454023F77475C73047404165FCFB8C954540
57756	Булгат-Изру	8	80	1303	46.360058000000002	46.384079	42.991950000000003	42.971786999999999	0103000020E61000000100000005000000E3546B61162E4740C7D63384637C4540E3546B61162E474034A2B437F87E45404A0A2C802931474034A2B437F87E45404A0A2C8029314740C7D63384637C4540E3546B61162E4740C7D63384637C4540
57822	Бильты	8	80	1303	46.338794	46.356957999999999	43.061771	43.050434000000003	0103000020E610000001000000050000005F0A0F9A5D2B4740A14D0E9F748645405F0A0F9A5D2B4740AD6BB41CE8874540D505BCCCB02D4740AD6BB41CE8874540D505BCCCB02D4740A14D0E9F748645405F0A0F9A5D2B4740A14D0E9F74864540
57814	Бешил-Ирзой	8	80	1303	46.300302000000002	46.308152999999997	43.128124	43.12182	0103000020E610000001000000050000003276C24B70264740D6FF39CC978F45403276C24B7026474096EA025E669045400795B88E7127474096EA025E669045400795B88E71274740D6FF39CC978F45403276C24B70264740D6FF39CC978F4540
40449	Бетти-Мохк	8	80	1303	46.332056999999999	46.339657000000003	43.119537000000001	43.105499000000002	0103000020E6100000010000000500000035B401D8802A47405F61C1FD808D454035B401D8802A4740BBD408FD4C8F4540C26D6DE1792B4740BBD408FD4C8F4540C26D6DE1792B47405F61C1FD808D454035B401D8802A47405F61C1FD808D4540
40451	Беной-Ведено	8	80	1303	46.267916999999997	46.291497999999997	42.972005000000003	42.935845	0103000020E610000001000000050000006E85B01A4B2247400490DAC4C97745406E85B01A4B2247403546EBA86A7C4540B96C74CE4F2547403546EBA86A7C4540B96C74CE4F2547400490DAC4C97745406E85B01A4B2247400490DAC4C9774540
57825	Беной	8	80	1303	46.289935	46.328904000000001	42.994680000000002	42.960175999999997	0103000020E610000001000000050000009E7B0F971C254740B933130CE77A45409E7B0F971C2547401EFE9AAC517F454005C3B986192A47401EFE9AAC517F454005C3B986192A4740B933130CE77A45409E7B0F971C254740B933130CE77A4540
20308	Балансу	8	80	1303	46.380907000000001	46.398110000000003	43.125433000000001	43.114916999999998	0103000020E61000000100000005000000A3E8818FC13047409160AA99B58E4540A3E8818FC13047406A6B44300E904540F41ABB44F53247406A6B44300E904540F41ABB44F53247409160AA99B58E4540A3E8818FC13047409160AA99B58E4540
40439	Аллерой	8	80	1303	46.293779999999998	46.309491000000001	43.095360999999997	43.080956	0103000020E61000000100000005000000041C42959A2547401E3526C45C8A4540041C42959A2547402C280CCA348C454003B4AD669D2747402C280CCA348C454003B4AD669D2747401E3526C45C8A4540041C42959A2547401E3526C45C8A4540
40446	Айти-Мохк	8	80	1303	46.340896000000001	46.353822999999998	43.094926999999998	43.085287999999998	0103000020E610000001000000050000002AABE97AA22B4740E15E99B7EA8A45402AABE97AA22B4740F2406491268C45404BC972124A2D4740F2406491268C45404BC972124A2D4740E15E99B7EA8A45402AABE97AA22B4740E15E99B7EA8A4540
9930	Центральная Усадьба Колхоза Имени Мичурина	8	80	1109	45.441772999999998	45.453065000000002	43.944901999999999	43.940696000000003	0103000020E61000000100000005000000BEA085048CB8464030BDFDB968F84540BEA085048CB8464066F6798CF2F845402BFBAE08FEB9464066F6798CF2F845402BFBAE08FEB9464030BDFDB968F84540BEA085048CB8464030BDFDB968F84540
32961	Фрунзенское	8	80	1109	45.656253999999997	45.670358	43.641857999999999	43.631405999999998	0103000020E6100000010000000500000041EF8D2100D44640C43F6CE9D1D0454041EF8D2100D446408656276728D24540554E7B4ACED546408656276728D24540554E7B4ACED54640C43F6CE9D1D0454041EF8D2100D44640C43F6CE9D1D04540
57777	Савельевская	8	80	1109	45.442841999999999	45.480769000000002	43.640161999999997	43.614973999999997	0103000020E61000000100000005000000CAA5F10BAFB84640F5F1D077B7CE4540CAA5F10BAFB846402B1213D4F0D145401FF7ADD689BD46402B1213D4F0D145401FF7ADD689BD4640F5F1D077B7CE4540CAA5F10BAFB84640F5F1D077B7CE4540
60650	Новотерское	8	80	1109	45.581828999999999	45.608347000000002	43.609699999999997	43.595658	0103000020E61000000100000005000000A46E675F79CA4640E6CC76853ECC4540A46E675F79CA4640832F4CA60ACE454053CF8250DECD4640832F4CA60ACE454053CF8250DECD4640E6CC76853ECC4540A46E675F79CA4640E6CC76853ECC4540
60635	Николаевское сельское поселение	8	80	1109	45.053314	45.854692	44.009810999999999	43.508899	0103000020E61000000100000005000000A0353FFED2864640CAFB389A23C14540A0353FFED28646400E12A27C410146409013268C66ED46400E12A27C410146409013268C66ED4640CAFB389A23C14540A0353FFED2864640CAFB389A23C14540
57751	Наурская	8	80	1109	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
60651	Ищерская	8	80	1109	45.113923999999997	45.154401999999997	43.728248000000001	43.707320000000003	0103000020E61000000100000005000000601DC70F958E464043E7357689DA4540601DC70F958E46404FB0FF3A37DD4540EF37DA71C39346404FB0FF3A37DD4540EF37DA71C393464043E7357689DA4540601DC70F958E464043E7357689DA4540
57785	Алпатово	8	80	1109	45.231549000000001	45.268092000000003	43.719258000000004	43.688302	0103000020E61000000100000005000000F435CB65A39D4640BDE2A9471AD84540F435CB65A39D464075B169A510DC4540DD28B2D650A2464075B169A510DC4540DD28B2D650A24640BDE2A9471AD84540F435CB65A39D4640BDE2A9471AD84540
57746	с. Братское	8	80	1417	44.833398000000003	45.489096000000004	43.728698000000001	43.446399999999997	0103000020E61000000100000005000000A24621C9AC6A46409A779CA223B94540A24621C9AC6A46408F54DFF945DD45405E4D9EB29ABE46408F54DFF945DD45405E4D9EB29ABE46409A779CA223B94540A24621C9AC6A46409A779CA223B94540
57774	Лакха-Невре	8	80	1417	45.227263999999998	45.273428000000003	43.626367999999999	43.598505000000003	0103000020E6100000010000000500000071C79BFC169D46400ABFD4CF9BCC454071C79BFC169D464066A19DD32CD04540C5E74EB0FFA2464066A19DD32CD04540C5E74EB0FFA246400ABFD4CF9BCC454071C79BFC169D46400ABFD4CF9BCC4540
45555	Знаменское	8	80	1417	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
57833	Горагорский	8	80	1417	45.069529000000003	45.116008000000001	43.514032	43.463270999999999	0103000020E61000000100000005000000D28F8653E6884640B517D1764CBB4540D28F8653E68846407A8CF2CCCBC145408509A359D98E46407A8CF2CCCBC145408509A359D98E4640B517D1764CBB4540D28F8653E6884640B517D1764CBB4540
60688	Братское	8	80	1417	44.833398000000003	45.489096000000004	43.728698000000001	43.446399999999997	0103000020E61000000100000005000000A24621C9AC6A46409A779CA223B94540A24621C9AC6A46408F54DFF945DD45405E4D9EB29ABE46408F54DFF945DD45405E4D9EB29ABE46409A779CA223B94540A24621C9AC6A46409A779CA223B94540
60630	Бено-Юрт	8	80	1417	45.032249	45.067247000000002	43.700347000000001	43.681978999999998	0103000020E61000000100000005000000132A38BC2084464086C77E164BD74540132A38BC20844640056D72F8A4D9454087E0B88C9B884640056D72F8A4D9454087E0B88C9B88464086C77E164BD74540132A38BC2084464086C77E164BD74540
57749	Банкин-Юрт	8	80	1417	45.089641999999998	45.109727999999997	43.567297000000003	43.554910999999997	0103000020E610000001000000050000008C2C9963798B46406798DA5207C745408C2C9963798B4640390F27309DC845404DBA2D910B8E4640390F27309DC845404DBA2D910B8E46406798DA5207C745408C2C9963798B46406798DA5207C74540
14831	Кокадой	8	80	1363	45.561140999999999	45.589976999999998	42.755657999999997	42.747177999999998	0103000020E61000000100000005000000EDB8E177D3C7464035255987A35F4540EDB8E177D3C74640FA7ABE66B96045403332C85D84CB4640FA7ABE66B96045403332C85D84CB464035255987A35F4540EDB8E177D3C7464035255987A35F4540
57790	Итум-Кале	8	80	1363	45.563800000000001	45.586545000000001	42.743760999999999	42.721623000000001	0103000020E610000001000000050000000EBE30992AC846404D8578245E5C45400EBE30992AC846402785798F335F4540F05014E813CB46402785798F335F4540F05014E813CB46404D8578245E5C45400EBE30992AC846404D8578245E5C4540
13878	Энгель-Юрт	8	80	1178	46.346528999999997	46.371932999999999	43.336590999999999	43.314495999999998	0103000020E61000000100000005000000CB0EF10F5B2C4740855CA96741A84540CB0EF10F5B2C47406090F46915AB4540CEA623809B2F47406090F46915AB4540CEA623809B2F4740855CA96741A84540CB0EF10F5B2C4740855CA96741A84540
57807	Хангаш-Юрт	8	80	1178	46.230350000000001	46.242728999999997	43.418458999999999	43.409467999999997	0103000020E610000001000000050000001A51DA1B7C1D474017618A7269B445401A51DA1B7C1D4740C2DB831090B5454038656EBE111F4740C2DB831090B5454038656EBE111F474017618A7269B445401A51DA1B7C1D474017618A7269B44540
60662	Новый Энгеной	8	80	1178	45.915301999999997	46.422446000000001	43.462898000000003	43.176597000000001	0103000020E6100000010000000500000050FBAD9D28F546402EC901BB9A96454050FBAD9D28F5464021B1DD3D40BB4540BB29E5B51236474021B1DD3D40BB4540BB29E5B5123647402EC901BB9A96454050FBAD9D28F546402EC901BB9A964540
57810	Новогрозненский	8	80	1178	46.234617	46.260210000000001	43.275264	43.253863000000003	0103000020E61000000100000005000000F60A0BEE071E47400D5531957EA04540F60A0BEE071E474011E2CAD93BA34540CC0BB08F4E21474011E2CAD93BA34540CC0BB08F4E2147400D5531957EA04540F60A0BEE071E47400D5531957EA04540
57801	Мелчу-Хе	8	80	1178	46.176738	46.198442	43.315610999999997	43.304459000000001	0103000020E61000000100000005000000F0FACC599F16474087FC3383F8A64540F0FACC599F16474001A1F5F065A845409013268C6619474001A1F5F065A845409013268C6619474087FC3383F8A64540F0FACC599F16474087FC3383F8A64540
13656	Кошкельды	8	80	1178	46.340052	46.369598000000003	43.260677999999999	43.247362000000003	0103000020E610000001000000050000003E78EDD2862B4740F722DA8EA99F45403E78EDD2862B4740B2648EE55DA145406155BDFC4E2F4740B2648EE55DA145406155BDFC4E2F4740F722DA8EA99F45403E78EDD2862B4740F722DA8EA99F4540
48959	Комсомольское	8	80	1178	46.150812999999999	46.168770000000002	43.395083999999997	43.382812999999999	0103000020E61000000100000005000000E46723D74D134740E8BD310400B14540E46723D74D1347402096CD1C92B24540E1455F419A1547402096CD1C92B24540E1455F419A154740E8BD310400B14540E46723D74D134740E8BD310400B14540
13848	Кади-Юрт	8	80	1178	46.302951999999998	46.322884999999999	43.322898000000002	43.312640000000002	0103000020E61000000100000005000000FF209221C7264740F2B5679604A84540FF209221C7264740CFF8BEB854A945403AAFB14B54294740CFF8BEB854A945403AAFB14B54294740F2B5679604A84540FF209221C7264740F2B5679604A84540
57779	Ишхойюрт	8	80	1178	46.379021000000002	46.403365000000001	43.227953999999997	43.202388999999997	0103000020E61000000100000005000000A5BF97C283304740FA08FCE1E7994540A5BF97C283304740067FBF982D9D4540EFACDD76A1334740067FBF982D9D4540EFACDD76A1334740FA08FCE1E7994540A5BF97C283304740FA08FCE1E7994540
57829	Ислахан-Юрт	8	80	1178	46.091138000000001	46.114539000000001	43.287694999999999	43.26784	0103000020E6100000010000000500000020B6F468AA0B4740C347C49448A2454020B6F468AA0B4740821C9430D3A44540EB8EC536A90E4740821C9430D3A44540EB8EC536A90E4740C347C49448A2454020B6F468AA0B4740C347C49448A24540
14290	Джалка	8	80	1178	45.978884000000001	45.997928999999999	43.326695000000001	43.314495999999998	0103000020E61000000100000005000000F14927124CFD4640855CA96741A84540F14927124CFD464024624A24D1A94540705D3123BCFF464024624A24D1A94540705D3123BCFF4640855CA96741A84540F14927124CFD4640855CA96741A84540
14584	Дарбанхи	8	80	1178	46.019928	46.041829	43.399951000000001	43.391998999999998	0103000020E6100000010000000500000029232E008D0247404888F2052DB2454029232E008D0247405280289831B345401F8315A75A0547405280289831B345401F8315A75A0547404888F2052DB2454029232E008D0247404888F2052DB24540
13174	Гудермес	8	80	1178	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
11207	Герзель-Аул	8	80	1178	46.395451000000001	46.409500999999999	43.253698999999997	43.241458000000002	0103000020E61000000100000005000000D3156C239E324740C5AD8218E89E4540D3156C239E3247409203763579A04540F3565D876A3447409203763579A04540F3565D876A344740C5AD8218E89E4540D3156C239E324740C5AD8218E89E4540
57817	Верхний Суворов-Юрт	8	80	1178	46.277484000000001	46.296708000000002	43.260933999999999	43.247611999999997	0103000020E61000000100000005000000E6948098842347406F0C01C0B19F4540E6948098842347400D350A4966A14540153B1A87FA2547400D350A4966A14540153B1A87FA2547406F0C01C0B19F4540E6948098842347406F0C01C0B19F4540
14559	Брагуны	8	80	1178	46.080798000000001	46.111142999999998	43.443486999999998	43.432765000000003	0103000020E6100000010000000500000086CABF96570A47403EEDF0D764B7454086CABF96570A4740BF99982EC4B84540F4160FEF390E4740BF99982EC4B84540F4160FEF390E47403EEDF0D764B7454086CABF96570A47403EEDF0D764B74540
14420	Азамат-Юрт	8	80	1178	46.276010999999997	46.293025	43.421438000000002	43.413697999999997	0103000020E610000001000000050000000A2B155454234740D6355A0EF4B445400A2B15545423474055A52DAEF1B5454088F4DBD78125474055A52DAEF1B5454088F4DBD781254740D6355A0EF4B445400A2B155454234740D6355A0EF4B44540
57830	ст.Ассиновская	8	80	1069	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
60646	с.Серноводск	8	80	1069	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
27326	Старая Сунжа	8	80	1069	45.725721	45.761006999999999	43.343423000000001	43.325600000000001	0103000020E610000001000000050000009D82FC6CE4DC4640EFC9C342ADA945409D82FC6CE4DC4640DCD8EC48F5AB4540778368AD68E14640DCD8EC48F5AB4540778368AD68E14640EFC9C342ADA945409D82FC6CE4DC4640EFC9C342ADA94540
60656	Серноводск	8	80	1069	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
57750	Садовое	8	80	1069	45.588197999999998	45.603290000000001	43.413317999999997	43.403606000000003	0103000020E610000001000000050000004BC972124ACB4640153C855CA9B345404BC972124ACB46408F6CAE9AE7B445407E00529B38CD46408F6CAE9AE7B445407E00529B38CD4640153C855CA9B345404BC972124ACB4640153C855CA9B34540
12524	Радужное	8	80	1069	45.379114999999999	45.410007999999998	43.411518000000001	43.397095	0103000020E6100000010000000500000026361FD786B04640DB334B02D4B2454026361FD786B0464090DB2F9FACB44540978C63247BB4464090DB2F9FACB44540978C63247BB44640DB334B02D4B2454026361FD786B04640DB334B02D4B24540
60653	Пригородное	8	80	1069	45.745628000000004	45.772739000000001	43.260874999999999	43.246842999999998	0103000020E61000000100000005000000AF7D01BD70DF46408E1F2A8D989F4540AF7D01BD70DF464008AC1C5A64A1454000AC8E1CE9E2464008AC1C5A64A1454000AC8E1CE9E246408E1F2A8D989F4540AF7D01BD70DF46408E1F2A8D989F4540
40254	Побединское	8	80	1069	45.411454999999997	45.453325	43.406992000000002	43.394088000000004	0103000020E610000001000000050000004963B48EAAB446407FDFBF7971B245404963B48EAAB44640E8DD585018B44540C7BAB88D06BA4640E8DD585018B44540C7BAB88D06BA46407FDFBF7971B245404963B48EAAB446407FDFBF7971B24540
9453	Октябрьское	8	80	1069	45.554098000000003	45.581612999999997	43.320393000000003	43.301678000000003	0103000020E61000000100000005000000B763EAAEECC646401BF67B629DA64540B763EAAEECC64640056F48A302A94540D7F6764B72CA4640056F48A302A94540D7F6764B72CA46401BF67B629DA64540B763EAAEECC646401BF67B629DA64540
12652	Нагорное	8	80	1069	45.170140000000004	45.190451000000003	43.423160000000003	43.410966999999999	0103000020E61000000100000005000000E8DEC325C79546401C5E10919AB44540E8DEC325C7954640D97C5C1B2AB64540C93EC8B260984640D97C5C1B2AB64540C93EC8B2609846401C5E10919AB44540E8DEC325C79546401C5E10919AB44540
57761	Керлаюрт	8	80	1069	45.298617	45.314194000000001	43.405053000000002	43.396106000000003	0103000020E61000000100000005000000CB83F41439A64640ECDFF599B3B24540CB83F41439A64640C712D6C6D8B34540BA4C4D8237A84640C712D6C6D8B34540BA4C4D8237A84640ECDFF599B3B24540CB83F41439A64640ECDFF599B3B24540
12556	Долинский	8	80	1069	45.370797000000003	45.396631999999997	43.409880000000001	43.401910000000001	0103000020E610000001000000050000003B3AAE4676AF4640BAF770C971B345403B3AAE4676AF46406AA4A5F276B4454006465ED6C4B246406AA4A5F276B4454006465ED6C4B24640BAF770C971B345403B3AAE4676AF4640BAF770C971B34540
57755	Грозный	8	80	1069	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
57783	Гикаловский	8	80	1069	45.708851000000003	45.744791999999997	43.241314000000003	43.218094000000001	0103000020E61000000100000005000000535E2BA1BBDA464017BA1281EA9B4540535E2BA1BBDA464092088D60E39E45404529215855DF464092088D60E39E45404529215855DF464017BA1281EA9B4540535E2BA1BBDA464017BA1281EA9B4540
57753	Виноградное	8	80	1069	45.847524	45.872138	43.471488999999998	43.458775000000003	0103000020E610000001000000050000009D499BAA7BEC4640789CA223B9BA45409D499BAA7BEC46403DB665C059BC4540A7CCCD37A2EF46403DB665C059BC4540A7CCCD37A2EF4640789CA223B9BA45409D499BAA7BEC4640789CA223B9BA4540
57794	Алхан-Чуртский	8	80	1069	45.713028000000001	45.724131	43.371569000000001	43.364727000000002	0103000020E61000000100000005000000EF90628044DB4640EE7BD45FAFAE4540EF90628044DB46408D9AAF928FAF454088821953B0DC46408D9AAF928FAF454088821953B0DC4640EE7BD45FAFAE4540EF90628044DB4640EE7BD45FAFAE4540
12221	Алхан-Кала	8	80	1069	45.492465000000003	45.564402000000001	43.266756999999998	43.250566999999997	0103000020E610000001000000050000005BB6D61709BF4640793A579412A045405BB6D61709BF4640527DE71725A2454004E621533EC84640527DE71725A2454004E621533EC84640793A579412A045405BB6D61709BF4640793A579412A04540
10838	разрушенный Хой	8	80	1066	46.061323000000002	46.193123999999997	42.799531999999999	42.702398000000002	0103000020E610000001000000050000000EBF9B6ED90747404E637B2DE85945400EBF9B6ED9074740800D8810576645404E098849B8184740800D8810576645404E098849B81847404E637B2DE85945400EBF9B6ED90747404E637B2DE8594540
57769	Эшилхотой	8	80	1066	46.043886999999998	46.063738999999998	42.970871000000002	42.956243999999998	0103000020E610000001000000050000001ADCD6169E054740847F1134667A45401ADCD6169E05474042D13C80457C4540683D7C992808474042D13C80457C4540683D7C9928084740847F1134667A45401ADCD6169E054740847F1134667A4540
57771	Эрсеной	8	80	1066	46.139333000000001	46.154612999999998	43.00103	42.992398000000001	0103000020E610000001000000050000007520EBA9D5114740D34ECDE5067F45407520EBA9D51147404E2844C021804540AA44D95BCA1347404E2844C021804540AA44D95BCA134740D34ECDE5067F45407520EBA9D5114740D34ECDE5067F4540
10353	Элистанжи	8	80	1066	46.008583000000002	46.028641999999998	42.977756999999997	42.961897999999998	0103000020E610000001000000050000009A266C3F190147403D0B42791F7B45409A266C3F19014740B0373124277D454061A5828AAA034740B0373124277D454061A5828AAA0347403D0B42791F7B45409A266C3F190147403D0B42791F7B4540
9844	Ца-Ведено	8	80	1066	46.036071	46.071095999999997	43.032901000000003	43.001854000000002	0103000020E61000000100000005000000C1AA7AF99D044740F3AE7AC03C804540C1AA7AF99D044740BB809719368445402E7079AC19094740BB809719368445402E7079AC19094740F3AE7AC03C804540C1AA7AF99D044740F3AE7AC03C804540
57741	Хатуни	8	80	1066	45.921320000000001	45.945565999999999	42.993915000000001	42.974471999999999	0103000020E610000001000000050000004B9352D0EDF54640116F9D7FBB7C45404B9352D0EDF546407E00529B387F4540D21A834E08F946407E00529B387F4540D21A834E08F94640116F9D7FBB7C45404B9352D0EDF54640116F9D7FBB7C4540
10457	Тевзана	8	80	1066	45.900478999999997	45.916145999999998	42.982340999999998	42.972599000000002	0103000020E610000001000000050000000DDE57E542F34640A88FC01F7E7C45400DDE57E542F346408D429259BD7D45403C2EAA4544F546408D429259BD7D45403C2EAA4544F54640A88FC01F7E7C45400DDE57E542F34640A88FC01F7E7C4540
10555	Сельментаузен	8	80	1066	45.842179000000002	45.875380999999997	42.957649000000004	42.923797999999998	0103000020E6100000010000000500000062307F85CCEB46401B0E4B033F76454062307F85CCEB46400806103E947A454017450F7C0CF046400806103E947A454017450F7C0CF046401B0E4B033F76454062307F85CCEB46401B0E4B033F764540
10036	Первомайское	8	80	1066	46.063271999999998	46.087482000000001	43.048622000000002	43.033526999999999	0103000020E610000001000000050000005260014C190847403944DC9C4A8445405260014C19084740DDEEE53E398645408D7E349C320B4740DDEEE53E398645408D7E349C320B47403944DC9C4A8445405260014C190847403944DC9C4A844540
10748	Нижние Курчали	8	80	1066	46.159768999999997	46.175201999999999	43.034232000000003	43.022165000000001	0103000020E6100000010000000500000012F5824F73144740D40E7F4DD682454012F5824F73144740043DD4B661844540CE18E6046D164740043DD4B661844540CE18E6046D164740D40E7F4DD682454012F5824F73144740D40E7F4DD6824540
9526	Нефтянка	8	80	1066	46.080249999999999	46.090761000000001	42.961773000000001	42.951518999999998	0103000020E6100000010000000500000083C0CAA1450A4740E542E55FCB79454083C0CAA1450A47408196AE601B7B45404A60730E9E0B47408196AE601B7B45404A60730E9E0B4740E542E55FCB79454083C0CAA1450A4740E542E55FCB794540
10221	Меседой	8	80	1066	46.118077999999997	46.133322999999997	43.022382	43.010523999999997	0103000020E6100000010000000500000044300E2E1D0F47405BE9B5D95881454044300E2E1D0F47407102D369DD824540FD6662BA101147407102D369DD824540FD6662BA101147405BE9B5D95881454044300E2E1D0F47405BE9B5D958814540
10534	Махкеты	8	80	1066	45.891595000000002	45.920979000000003	42.978772999999997	42.953862000000001	0103000020E610000001000000050000007923F3C81FF24640D6726726187A45407923F3C81FF24640999A046F487D4540C2A6CEA3E2F54640999A046F487D4540C2A6CEA3E2F54640D6726726187A45407923F3C81FF24640D6726726187A4540
9684	Дышне-Ведено	8	80	1066	46.11647	46.133071000000001	42.970356000000002	42.940677000000001	0103000020E61000000100000005000000897B2C7DE80E4740B98C9B1A68784540897B2C7DE80E47401BBD1AA0347C4540E4857478081147401BBD1AA0347C4540E485747808114740B98C9B1A68784540897B2C7DE80E4740B98C9B1A68784540
10650	Дарго	8	80	1066	46.227474999999998	46.256858999999999	42.980975999999998	42.929085999999998	0103000020E610000001000000050000002CD49AE61D1D4740F295404AEC7645402CD49AE61D1D474098141F9F907D4540755776C1E020474098141F9F907D4540755776C1E0204740F295404AEC7645402CD49AE61D1D4740F295404AEC764540
10152	Гуни	8	80	1066	46.094110999999998	46.113218000000003	43.063904999999998	43.046402	0103000020E61000000100000005000000D09849D40B0C4740083C3080F0854540D09849D40B0C47408386FE092E884540C6A86BED7D0E47408386FE092E884540C6A86BED7D0E4740083C3080F0854540D09849D40B0C4740083C3080F0854540
9860	Верхатой	8	80	1066	46.021545000000003	46.038074000000002	43.038957000000003	43.022784000000001	0103000020E6100000010000000500000038328FFCC1024740A06F0B96EA82454038328FFCC1024740A379008BFC844540F969DC9BDF044740A379008BFC844540F969DC9BDF044740A06F0B96EA82454038328FFCC1024740A06F0B96EA824540
9416	Ведено	8	80	1066	46.085028999999999	46.122641999999999	42.977111000000001	42.946088000000003	0103000020E61000000100000005000000151BF33AE20A4740AC915D6919794540151BF33AE20A4740EBC726F9117D4540DA8EA9BBB20F4740EBC726F9117D4540DA8EA9BBB20F4740AC915D6919794540151BF33AE20A4740AC915D6919794540
9959	Беной	8	80	1066	46.012993000000002	46.020881000000003	43.066118000000003	43.055124999999997	0103000020E61000000100000005000000D9092FC1A9014740931804560E874540D9092FC1A9014740A6D6FB8D76884540CC0D863AAC024740A6D6FB8D76884540CC0D863AAC024740931804560E874540D9092FC1A9014740931804560E874540
10271	Агишбатой	8	80	1066	46.099958999999998	46.115931000000003	43.017629999999997	43.007404999999999	0103000020E610000001000000050000006EF8DD74CB0C4740D769A4A5F28045406EF8DD74CB0C4740D8B628B341824540DACBB6D3D60E4740D8B628B341824540DACBB6D3D60E4740D769A4A5F28045406EF8DD74CB0C4740D769A4A5F2804540
57764	Катыр-Юрт	8	80	990	45.355508	45.383769000000001	43.18515	43.150399	0103000020E61000000100000005000000B2BB404981AD4640F12C414640934540B2BB404981AD46405D6DC5FEB2974540FC1BB4571FB146405D6DC5FEB2974540FC1BB4571FB14640F12C414640934540B2BB404981AD4640F12C414640934540
57758	Закан-Юрт	8	80	990	45.404789000000001	45.434092	43.268425000000001	43.253613000000001	0103000020E61000000100000005000000E9633E20D0B34640946B0A6476A04540E9633E20D0B34640E3361AC05BA2454045BA9F5390B74640E3361AC05BA2454045BA9F5390B74640946B0A6476A04540E9633E20D0B34640946B0A6476A04540
57775	Бамут	8	80	990	45.18074	45.224578000000001	43.191637	43.131518999999997	0103000020E610000001000000050000001E8A027D22974640BCE6559DD59045401E8A027D229746400EDAAB8F8798454057B3CEF8BE9C46400EDAAB8F8798454057B3CEF8BE9C4640BCE6559DD59045401E8A027D22974640BCE6559DD5904540
33028	Ачхой-Мартан	8	80	990	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
57765	Курчалой	8	80	7448	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
57688	Троицкое	8	79	\N	44.650284999999997	44.696494000000001	43.773954000000003	43.752867000000002	0103000020E61000000100000005000000280AF4893C5346406B9E23F25DE04540280AF4893C534640E04DB7EC10E345401CEE23B726594640E04DB7EC10E345401CEE23B7265946406B9E23F25DE04540280AF4893C5346406B9E23F25DE04540
57686	Моздок	8	79	\N	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
1856	Владикавказ	8	79	\N	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
57689	Ардон	8	79	\N	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
32573	Чермен	8	79	8	44.694473000000002	44.737223999999998	43.166674999999998	43.117879000000002	0103000020E610000001000000050000003E7AC37DE45846404EF1B8A8168F45403E7AC37DE4584640C8073D9B55954540C4E9245B5D5E4640C8073D9B55954540C4E9245B5D5E46404EF1B8A8168F45403E7AC37DE45846404EF1B8A8168F4540
57707	Сунжа	8	79	8	44.796126999999998	44.844672000000003	43.080007000000002	43.044524000000003	0103000020E61000000100000005000000363B527DE76546408DF161F6B2854540363B527DE7654640BD395CAB3D8A454068EC4B361E6C4640BD395CAB3D8A454068EC4B361E6C46408DF161F6B2854540363B527DE76546408DF161F6B2854540
57725	Первомайский	8	79	8	44.629534	44.660032000000001	43.164242000000002	43.148097	0103000020E610000001000000050000002BDCF291945046405FD1ADD7F49245402BDCF291945046409850C1E1059545402028B7ED7B5446409850C1E1059545402028B7ED7B5446405FD1ADD7F49245402BDCF291945046405FD1ADD7F4924540
57693	Октябрьское	8	79	8	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
57719	Кобан	8	79	8	44.459302999999998	44.509753000000003	42.927066000000003	42.905633999999999	0103000020E6100000010000000500000033FAD170CA3A4640A5129ED0EB73454033FAD170CA3A4640E59D4319AA764540DA0418963F414640E59D4319AA764540DA0418963F414640A5129ED0EB73454033FAD170CA3A4640A5129ED0EB734540
57717	Кармадон	8	79	8	44.505583999999999	44.511450000000004	42.846587999999997	42.834972999999998	0103000020E61000000100000005000000C0B0FCF9B640464081053065E06A4540C0B0FCF9B6404640D097DEFE5C6C454005C58F3177414640D097DEFE5C6C454005C58F317741464081053065E06A4540C0B0FCF9B640464081053065E06A4540
57695	Камбилеевское	8	79	8	44.740287000000002	44.771521999999997	43.090311999999997	43.048839999999998	0103000020E61000000100000005000000B55373B9C15E46404A5E9D6340864540B55373B9C15E4640DA37F7578F8B45407F129F3BC1624640DA37F7578F8B45407F129F3BC16246404A5E9D6340864540B55373B9C15E46404A5E9D6340864540
57692	Владикавказ	8	79	8	44.313192000000001	44.957554000000002	43.27852	42.697687000000002	0103000020E6100000010000000500000036AFEAAC1628464014ECBFCE4D59454036AFEAAC1628464016A4198BA6A34540B6132521917A464016A4198BA6A34540B6132521917A464014ECBFCE4D59454036AFEAAC1628464014ECBFCE4D594540
32826	Верхняя Саниба	8	79	8	44.551730999999997	44.564981000000003	43.020589000000001	43.003402999999999	0103000020E610000001000000050000003D98141F9F464640A9DA6E826F8045403D98141F9F46464024D40CA9A282454042EE224C5148464024D40CA9A282454042EE224C51484640A9DA6E826F8045403D98141F9F464640A9DA6E826F804540
57734	Архонская	8	79	8	44.493564999999997	44.541660999999998	43.120247999999997	43.098461999999998	0103000020E61000000100000005000000A1B94E232D3F46400AF31E679A8C4540A1B94E232D3F464067B45549648F45406342CC255545464067B45549648F45406342CC25554546400AF31E679A8C4540A1B94E232D3F46400AF31E679A8C4540
2332	Алханчурт	8	79	8	44.584465999999999	44.597391999999999	43.144537999999997	43.135354999999997	0103000020E61000000100000005000000DDCF29C8CF4A4640CF2C095053914540DDCF29C8CF4A4640BE839F38809245402E724F57774C4640BE839F38809245402E724F57774C4640CF2C095053914540DDCF29C8CF4A4640CF2C095053914540
57713	Хумалаг	8	79	1004	44.456122999999998	44.493861000000003	43.250396000000002	43.228400999999998	0103000020E6100000010000000500000009FA0B3D623A4640D5AF743E3C9D454009FA0B3D623A46404D86E3F90CA045408BE255D6363F46404D86E3F90CA045408BE255D6363F4640D5AF743E3C9D454009FA0B3D623A4640D5AF743E3C9D4540
57738	Раздзог	8	79	1004	44.466498999999999	44.476604999999999	43.363829000000003	43.352313000000002	0103000020E61000000100000005000000F04E3E3DB63B4640537AA69718AD4540F04E3E3DB63B46400F2BDCF291AE4540170E8464013D46400F2BDCF291AE4540170E8464013D4640537AA69718AD4540F04E3E3DB63B4640537AA69718AD4540
33012	Беслан	8	79	1004	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
57712	Батако	8	79	1004	44.524728000000003	44.548901000000001	43.389575000000001	43.366889999999998	0103000020E61000000100000005000000D3A57F492A4346405E9D6340F6AE4540D3A57F492A4346406B2BF697DDB14540F0DE5163424646406B2BF697DDB14540F0DE5163424646405E9D6340F6AE4540D3A57F492A4346405E9D6340F6AE4540
47622	Черноярский	8	79	1592	44.336601999999999	44.357156000000003	43.767653000000003	43.757770000000001	0103000020E6100000010000000500000054E23AC6152B4640E9F17B9BFEE0454054E23AC6152B464091D6187442E24540FCC8AD49B72D464091D6187442E24540FCC8AD49B72D4640E9F17B9BFEE0454054E23AC6152B4640E9F17B9BFEE04540
30409	Хурикау	8	79	1592	44.451110999999997	44.467927000000003	43.468229999999998	43.442675999999999	0103000020E61000000100000005000000D4EE5701BE394640AF5C6F9BA9B84540D4EE5701BE394640C780ECF5EEBB45402CF52C08E53B4640C780ECF5EEBB45402CF52C08E53B4640AF5C6F9BA9B84540D4EE5701BE394640AF5C6F9BA9B84540
47239	Троицкое	8	79	1592	44.650284999999997	44.696494000000001	43.773954000000003	43.752867000000002	0103000020E61000000100000005000000280AF4893C5346406B9E23F25DE04540280AF4893C534640E04DB7EC10E345401CEE23B726594640E04DB7EC10E345401CEE23B7265946406B9E23F25DE04540280AF4893C5346406B9E23F25DE04540
47321	Терская	8	79	1592	44.711495999999997	44.739550999999999	43.728319999999997	43.712643999999997	0103000020E610000001000000050000000E9E094D125B464066D828EB37DB45400E9E094D125B4640E882FA9639DD4540AF5C6F9BA95E4640E882FA9639DD4540AF5C6F9BA95E464066D828EB37DB45400E9E094D125B464066D828EB37DB4540
57710	Тельман	8	79	1592	44.325059000000003	44.340223000000002	43.807434999999998	43.800936	0103000020E610000001000000050000009F2287889B2946403318231285E645409F2287889B294640A852B3075AE745406B2C616D8C2B4640A852B3075AE745406B2C616D8C2B46403318231285E645409F2287889B2946403318231285E64540
30258	Сухотское	8	79	1592	44.430098999999998	44.449942999999998	43.684950999999998	43.670197000000002	0103000020E610000001000000050000006A85E97B0D3746404C70EA03C9D545406A85E97B0D374640662E7079ACD74540350873BB97394640662E7079ACD74540350873BB973946404C70EA03C9D545406A85E97B0D3746404C70EA03C9D54540
30936	Советский	8	79	1592	44.541490000000003	44.555145000000003	43.734462000000001	43.724926000000004	0103000020E61000000100000005000000378E588B4F45464093020B60CADC4540378E588B4F454640CF13CFD902DE4540DBC4C9FD0E474640CF13CFD902DE4540DBC4C9FD0E47464093020B60CADC4540378E588B4F45464093020B60CADC4540
32974	Садовый	8	79	1592	44.562924000000002	44.572122999999998	43.820132999999998	43.817076	0103000020E610000001000000050000001711C5E40D4846405A2C45F295E845401711C5E40D48464068AF3E1EFAE845400B2593533B49464068AF3E1EFAE845400B2593533B4946405A2C45F295E845401711C5E40D4846405A2C45F295E84540
57704	Раздольное	8	79	1592	44.523631999999999	44.543447999999998	43.704765999999999	43.686945999999999	0103000020E61000000100000005000000CD91955F064346401B0FB6D8EDD74540CD91955F0643464097AAB4C535DA4540CE893DB48F45464097AAB4C535DA4540CE893DB48F4546401B0FB6D8EDD74540CD91955F064346401B0FB6D8EDD74540
30620	Притеречный	8	79	1592	44.289485999999997	44.315806000000002	43.748705999999999	43.736469	0103000020E610000001000000050000002E5393E00D25464048C2BE9D44DE45402E5393E00D254640D4282499D5DF4540B7F0BC546C284640D4282499D5DF4540B7F0BC546C28464048C2BE9D44DE45402E5393E00D25464048C2BE9D44DE4540
32969	Предгорное	8	79	1592	44.687682000000002	44.700788000000003	43.572671999999997	43.555563999999997	0103000020E610000001000000050000002106BAF605584640DF6A9DB81CC745402106BAF605584640DEAAEB504DC94540F2B6D26BB3594640DEAAEB504DC94540F2B6D26BB3594640DF6A9DB81CC745402106BAF605584640DF6A9DB81CC74540
30124	Павлодольская	8	79	1592	44.455863000000001	44.499296000000001	43.729610000000001	43.711426000000003	0103000020E610000001000000050000006D3A02B8593A464016C3D50110DB45406D3A02B8593A4640D36A48DC63DD454006836BEEE83F4640D36A48DC63DD454006836BEEE83F464016C3D50110DB45406D3A02B8593A464016C3D50110DB4540
57705	Новоосетинская	8	79	1592	44.373496000000003	44.411952999999997	43.708883999999998	43.697864000000003	0103000020E61000000100000005000000EA9788B7CE2F46402387889B53D94540EA9788B7CE2F46402E54FEB5BCDA45409A3E3BE0BA3446402E54FEB5BCDA45409A3E3BE0BA3446402387889B53D94540EA9788B7CE2F46402387889B53D94540
28278	Моздок	8	79	1592	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
30322	Малгобек	8	79	1592	44.444544	44.462384	43.624841000000004	43.609183999999999	0103000020E6100000010000000500000007D15AD1E63846408C9FC6BDF9CD454007D15AD1E6384640981936CAFACF4540CA181F662F3B4640981936CAFACF4540CA181F662F3B46408C9FC6BDF9CD454007D15AD1E63846408C9FC6BDF9CD4540
47207	Луковская	8	79	1592	44.623668000000002	44.647734	43.737648	43.718378000000001	0103000020E61000000100000005000000E7C75F5AD44F46403C1570CFF3DB4540E7C75F5AD44F4640DBFAE93F6BDE4540EE409DF2E8524640DBFAE93F6BDE4540EE409DF2E85246403C1570CFF3DB4540E7C75F5AD44F46403C1570CFF3DB4540
19306	Кизляр	8	79	1592	44.552143999999998	44.618133999999998	43.714117000000002	43.695557000000001	0103000020E61000000100000005000000605793A7AC4646407FC0030308D94540605793A7AC4646404242942F68DB4540D845D1031F4F46404242942F68DB4540D845D1031F4F46407FC0030308D94540605793A7AC4646407FC0030308D94540
29837	Киевское	8	79	1592	44.633271000000001	44.656609000000003	43.716202000000003	43.698027000000003	0103000020E61000000100000005000000AB402D060F514640CD5CE0F258D94540AB402D060F51464037AAD381ACDB454030A182C30B54464037AAD381ACDB454030A182C30B544640CD5CE0F258D94540AB402D060F514640CD5CE0F258D94540
47299	Калининский	8	79	1592	44.675510000000003	44.696449999999999	43.733778999999998	43.718677999999997	0103000020E610000001000000050000007C0F971C77564640662D05A4FDDB45407C0F971C77564640ECBE6378ECDD45404CA60A4625594640ECBE6378ECDD45404CA60A4625594640662D05A4FDDB45407C0F971C77564640662D05A4FDDB4540
30567	Елбаево	8	79	1592	44.353140000000003	44.376010999999998	43.808371999999999	43.802061999999999	0103000020E61000000100000005000000697407B1332D4640A3AEB5F7A9E64540697407B1332D46404580D3BB78E74540D7F7E120213046404580D3BB78E74540D7F7E12021304640A3AEB5F7A9E64540697407B1332D4640A3AEB5F7A9E64540
47519	Виноградное	8	79	1592	44.468780000000002	44.507480000000001	43.705131000000002	43.689475000000002	0103000020E610000001000000050000006B82A8FB003C46406E3480B740D845406B82A8FB003C4640A9328CBB41DA4540E2AFC91AF5404640A9328CBB41DA4540E2AFC91AF54046406E3480B740D845406B82A8FB003C46406E3480B740D84540
57698	Веселовское	8	79	1592	44.705962999999997	44.745938000000002	43.776935999999999	43.763415000000002	0103000020E61000000100000005000000D097DEFE5C5A46404F232D95B7E14540D097DEFE5C5A4640E38A8BA372E34540FD6B79E57A5F4640E38A8BA372E34540FD6B79E57A5F46404F232D95B7E14540D097DEFE5C5A46404F232D95B7E14540
55030	Эльхотово	8	79	1834	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
32728	Комсомольское	8	79	1834	44.282406999999999	44.305072000000003	43.379131000000001	43.364550000000001	0103000020E61000000100000005000000AB949EE925244640DFE00B93A9AE4540AB949EE9252446402CF3565D87B0454071766B990C2746402CF3565D87B0454071766B990C274640DFE00B93A9AE4540AB949EE925244640DFE00B93A9AE4540
57728	Иран	8	79	1834	44.076576000000003	44.094532999999998	43.314712999999998	43.302214999999997	0103000020E610000001000000050000004AD40B3ECD09464029AE2AFBAEA645404AD40B3ECD0946402250FD8348A8454046B247A8190C46402250FD8348A8454046B247A8190C464029AE2AFBAEA645404AD40B3ECD09464029AE2AFBAEA64540
57729	Змейская	8	79	1834	44.141191999999997	44.174779999999998	43.358972000000001	43.322026000000001	0103000020E61000000100000005000000793A579412124640193BE12538A94540793A579412124640011764CBF2AD454058FFE7305F164640011764CBF2AD454058FFE7305F164640193BE12538A94540793A579412124640193BE12538A94540
26067	Чикола	8	79	1040	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
57706	Хазнидон	8	79	1040	43.828839000000002	43.856892999999999	43.215274999999998	43.196171999999997	0103000020E610000001000000050000001E53776517EA45400932022A1C9945401E53776517EA4540BD5296218E9B4540EE9579ABAEED4540BD5296218E9B4540EE9579ABAEED45400932022A1C9945401E53776517EA45400932022A1C994540
57722	Толдзгун	8	79	1040	43.812417000000003	43.835028000000001	43.239035000000001	43.220182999999999	0103000020E6100000010000000500000073DBBE47FDE745404D11E0F42E9C454073DBBE47FDE74540B8CCE9B2989E4540459F8F32E2EA4540B8CCE9B2989E4540459F8F32E2EA45404D11E0F42E9C454073DBBE47FDE745404D11E0F42E9C4540
32560	Сурх-Дигора	8	79	1040	43.975982999999999	44.010379	43.178786000000002	43.164538	0103000020E61000000100000005000000DA39CD02EDFC45408179C8940F954540DA39CD02EDFC4540C87DAB75E296454058C85C1954014640C87DAB75E296454058C85C19540146408179C8940F954540DA39CD02EDFC45408179C8940F954540
57718	Стур-Дигора	8	79	1040	43.647297999999999	43.659784999999999	42.908909000000001	42.900272000000001	0103000020E6100000010000000500000013622EA9DAD2454094C0E61C3C73454013622EA9DAD2454021054F215774454018B2BAD573D4454021054F215774454018B2BAD573D4454094C0E61C3C73454013622EA9DAD2454094C0E61C3C734540
57715	Средний Урух	8	79	1040	43.980455999999997	44.001674999999999	43.275750000000002	43.252011000000003	0103000020E610000001000000050000005F950B957FFD4540BB9D7DE541A045405F950B957FFD45409EEFA7C64BA34540431CEBE2360046409EEFA7C64BA34540431CEBE236004640BB9D7DE541A045405F950B957FFD4540BB9D7DE541A04540
52154	Советский	8	79	1040	43.884605999999998	43.902599000000002	43.197446999999997	43.187904000000003	0103000020E6100000010000000500000035ECF7C43AF14540D064FF3C0D98454035ECF7C43AF14540BED87BF1459945407F33315D88F34540BED87BF1459945407F33315D88F34540D064FF3C0D98454035ECF7C43AF14540D064FF3C0D984540
57732	Новый Урух	8	79	1040	43.909740999999997	43.958258999999998	43.241149999999998	43.228329000000002	0103000020E61000000100000005000000486AA16472F445403CDD79E2399D4540486AA16472F4454017B7D100DE9E4540800C1D3BA8FA454017B7D100DE9E4540800C1D3BA8FA45403CDD79E2399D4540486AA16472F445403CDD79E2399D4540
27946	Мацута	8	79	1040	43.769199	43.772505000000002	42.983581000000001	42.977466999999997	0103000020E61000000100000005000000D68EE21C75E24540A9F57EA31D7D4540D68EE21C75E24540C6FB71FBE57D45408D7F9F71E1E24540C6FB71FBE57D45408D7F9F71E1E24540A9F57EA31D7D4540D68EE21C75E24540A9F57EA31D7D4540
57720	Махческ	8	79	1040	43.779781999999997	43.787705000000003	42.964551	42.960327999999997	0103000020E61000000100000005000000360186E5CFE345406FB72407EC7A4540360186E5CFE345407C293C68767B4540A6F27684D3E445407C293C68767B4540A6F27684D3E445406FB72407EC7A4540360186E5CFE345406FB72407EC7A4540
32596	Лескен	8	79	1040	43.799813999999998	43.842044000000001	43.289459999999998	43.259621000000003	0103000020E6100000010000000500000004711E4E60E645406B2DCC423BA1454004711E4E60E6454005C078060DA5454082E50819C8EB454005C078060DA5454082E50819C8EB45406B2DCC423BA1454004711E4E60E645406B2DCC423BA14540
27801	Камунта	8	79	1040	43.841755999999997	43.856659000000001	42.912264	42.906308000000003	0103000020E610000001000000050000001B9B1DA9BEEB4540350D8AE6017445401B9B1DA9BEEB4540B9A81611C57445407B698A00A7ED4540B9A81611C57445407B698A00A7ED4540350D8AE6017445401B9B1DA9BEEB4540350D8AE601744540
28022	Дзинага	8	79	1040	43.699435999999999	43.720528999999999	42.907026999999999	42.894618000000001	0103000020E6100000010000000500000091D26C1E87D94540DB34B6D78272454091D26C1E87D9454064CBF27519744540E868554B3ADC454064CBF27519744540E868554B3ADC4540DB34B6D78272454091D26C1E87D94540DB34B6D782724540
57716	Дзагепбарз	8	79	1040	43.929881000000002	43.939242	43.230417000000003	43.226325000000003	0103000020E61000000100000005000000FD15325706F7454034A2B437F89C4540FD15325706F74540A2B8E34D7E9D4540CB83F41439F84540A2B8E34D7E9D4540CB83F41439F8454034A2B437F89C4540FD15325706F7454034A2B437F89C4540
27947	Ахсау	8	79	1040	43.713341999999997	43.723636999999997	42.959926000000003	42.953631000000001	0103000020E610000001000000050000007E6E68CA4EDB4540D4B9A294107A45407E6E68CA4EDB4540414AECDADE7A454078962023A0DC4540414AECDADE7A454078962023A0DC4540D4B9A294107A45407E6E68CA4EDB4540D4B9A294107A4540
57726	Ахсарисар	8	79	1040	43.811995000000003	43.824572000000003	43.144675999999997	43.131098000000001	0103000020E61000000100000005000000FDC1C073EFE745401749BBD1C7904540FDC1C073EFE745400F4240BE84924540429946938BE945400F4240BE84924540429946938BE945401749BBD1C7904540FDC1C073EFE745401749BBD1C7904540
33098	Дур-Дур	8	79	1061	44.008806999999997	44.043132	43.135539000000001	43.115107999999999	0103000020E61000000100000005000000E97C78962001464005C1E3DBBB8E4540E97C789620014640912A8A57599145409EB4705985054640912A8A57599145409EB470598505464005C1E3DBBB8E4540E97C78962001464005C1E3DBBB8E4540
26265	Дигора	8	79	1061	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
57703	Чми	8	79	628	44.631906000000001	44.640242000000001	42.855755000000002	42.846218	0103000020E61000000100000005000000B612BA4BE2504640ADA415DF506C4540B612BA4BE2504640BA313D61896D454048C32973F3514640BA313D61896D454048C32973F3514640ADA415DF506C4540B612BA4BE2504640ADA415DF506C4540
52304	Заводской	8	79	628	44.633378999999998	44.672635	43.113877000000002	43.082134000000003	0103000020E61000000100000005000000917C259012514640E1F1ED5D838A4540917C25901251464020628385938E45408E9257E71856464020628385938E45408E9257E718564640E1F1ED5D838A4540917C259012514640E1F1ED5D838A4540
57701	Балта	8	79	628	44.622680000000003	44.638499000000003	42.931851999999999	42.911893999999997	0103000020E61000000100000005000000C8EF6DFAB34F464095B54DF1B8744540C8EF6DFAB34F4640295B24ED46774540ADC3D155BA514640295B24ED46774540ADC3D155BA51464095B54DF1B8744540C8EF6DFAB34F464095B54DF1B8744540
25843	Бекан	8	79	1777	44.261063	44.266004000000002	43.264144000000002	43.261071999999999	0103000020E610000001000000050000000B992B836A2146405EF3AACE6AA145400B992B836A214640A2B77878CFA14540774D486B0C224640A2B77878CFA14540774D486B0C2246405EF3AACE6AA145400B992B836A2146405EF3AACE6AA14540
33055	Ардон	8	79	1777	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
57723	Цейское сельское поселение	8	79	754	43.713467999999999	44.510795000000002	43.148195000000001	42.547130000000003	0103000020E610000001000000050000000B5F5FEB52DB45408B54185B084645400B5F5FEB52DB45402237C30DF8924540ECFA05BB614146402237C30DF8924540ECFA05BB614146408B54185B084645400B5F5FEB52DB45408B54185B08464540
57714	Цаликово	8	79	754	44.259391999999998	44.274330999999997	43.074205999999997	43.061388999999998	0103000020E61000000100000005000000096CCEC133214640C5AA4198DB874540096CCEC1332146405F950B957F894540B5A338471D2346405F950B957F894540B5A338471D234640C5AA4198DB874540096CCEC133214640C5AA4198DB874540
32899	Хаталдон	8	79	754	44.348739000000002	44.376280999999999	43.042310000000001	43.024386	0103000020E610000001000000050000007DEBC37AA32C4640793D98141F8345407DEBC37AA32C46409A25016A6A854540978DCEF9293046409A25016A6A854540978DCEF929304640793D98141F8345407DEBC37AA32C4640793D98141F834540
32836	Рамоново	8	79	754	44.259644000000002	44.264305999999998	43.126992000000001	43.121589999999998	0103000020E61000000100000005000000234DBC033C214640A4C2D842908F4540234DBC033C214640446D1B46419045407B116DC7D4214640446D1B46419045407B116DC7D4214640A4C2D842908F4540234DBC033C214640A4C2D842908F4540
25178	Нузал	8	79	754	44.017045000000003	44.026009999999999	42.833188	42.820372999999996	0103000020E61000000100000005000000B9C7D2872E024640BDC282FB01694540B9C7D2872E024640B7B585E7A56A45403AAFB14B54034640B7B585E7A56A45403AAFB14B54034640BDC282FB01694540B9C7D2872E024640BDC282FB01694540
57727	Нижний Унал	8	79	754	44.145935000000001	44.156661	42.867710000000002	42.854731000000001	0103000020E61000000100000005000000BF2B82FFAD1246404EF04DD3676D4540BF2B82FFAD124640C2340C1F116F454082C7B7770D144640C2340C1F116F454082C7B7770D1446404EF04DD3676D4540BF2B82FFAD1246404EF04DD3676D4540
57735	Нижний Зарамах	8	79	754	43.965023000000002	43.975757999999999	42.697235999999997	42.692399000000002	0103000020E61000000100000005000000A471A8DF85FB45403D64CA87A0584540A471A8DF85FB454003CC7C073F594540BA675DA3E5FC454003CC7C073F594540BA675DA3E5FC45403D64CA87A0584540A471A8DF85FB45403D64CA87A0584540
24580	Нижний Бирагзанг	8	79	754	44.237445999999998	44.249671999999997	43.042357000000003	43.027225999999999	0103000020E6100000010000000500000073486AA1641E4640EACC3D247C83454073486AA1641E4640DBE044F46B8545400B5D8940F51F4640DBE044F46B8545400B5D8940F51F4640EACC3D247C83454073486AA1641E4640EACC3D247C834540
57709	Нар	8	79	754	44.019326	44.026423000000001	42.682828999999998	42.678567999999999	0103000020E6100000010000000500000033FB3C46790246405A0EF450DB56454033FB3C467902464054E1CFF0665745405D6E30D46103464054E1CFF0665745405D6E30D4610346405A0EF450DB56454033FB3C46790246405A0EF450DB564540
32954	Мизур	8	79	754	44.047668000000002	44.073324	42.856363999999999	42.842475999999998	0103000020E610000001000000050000006A882AFC190646401BD5E940D66B45406A882AFC1906464062BCE6559D6D454086014BAE6209464062BCE6559D6D454086014BAE620946401BD5E940D66B45406A882AFC190646401BD5E940D66B4540
32913	Майрамадаг	8	79	754	44.469248	44.488174999999998	43.027681000000001	43.010793999999997	0103000020E6100000010000000500000051DB8651103C46401B7FA2B26181454051DB8651103C46403CDC0E0D8B834540C6DCB5847C3E46403CDC0E0D8B834540C6DCB5847C3E46401B7FA2B26181454051DB8651103C46401B7FA2B261814540
5321	Карца	8	79	754	44.278292999999998	44.307442999999999	42.928314	42.918602	0103000020E6100000010000000500000055DAE21A9F234640250516C09475454055DAE21A9F234640A0353FFED27645402B31CF4A5A274640A0353FFED27645402B31CF4A5A274640250516C09475454055DAE21A9F234640250516C094754540
25002	Зинцар	8	79	754	44.166578000000001	44.172175000000003	42.888269999999999	42.879292999999997	0103000020E61000000100000005000000D61D8B6D52154640054D4BAC8C704540D61D8B6D521546404B02D4D4B27145402B1895D4091646404B02D4D4B27145402B1895D409164640054D4BAC8C704540D61D8B6D52154640054D4BAC8C704540
57711	Дзуарикау	8	79	754	44.327691000000002	44.336441000000001	42.849919	42.842080000000003	0103000020E61000000100000005000000C61858C7F1294640CF4E0647C96B4540C61858C7F1294640E09F5225CA6C45404B04AA7F102B4640E09F5225CA6C45404B04AA7F102B4640CF4E0647C96B4540C61858C7F1294640CF4E0647C96B4540
57694	Верхний Фиагдон	8	79	754	44.299160999999998	44.311387000000003	42.836381000000003	42.830615999999999	0103000020E610000001000000050000008C9E5BE84A26464065C405A0516A45408C9E5BE84A26464076FF58880E6B454025B37A87DB27464076FF58880E6B454025B37A87DB27464065C405A0516A45408C9E5BE84A26464065C405A0516A4540
32981	Бурон	8	79	754	43.999456000000002	44.010649000000001	42.797964999999998	42.785750999999998	0103000020E610000001000000050000003FE5982CEEFF45404FE61F7D936445403FE5982CEEFF4540232D95B723664540185E49F25C014640232D95B723664540185E49F25C0146404FE61F7D936445403FE5982CEEFF45404FE61F7D93644540
32857	Алагир	8	79	754	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
57861	Черкесск	8	78	\N	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
188	Черкесск	8	78	\N	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
57856	Хабез	8	78	\N	41.752248000000002	41.781075000000001	44.063034999999999	44.023851999999998	0103000020E610000001000000050000009F3D97A949E04440DBF813950D0346409F3D97A949E044406EC0E78711084640925CFE43FAE344406EC0E78711084640925CFE43FAE34440DBF813950D0346409F3D97A949E04440DBF813950D034640
57854	Усть-Джегута	8	78	\N	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
57851	Теберда	8	78	\N	41.729565999999998	41.753937000000001	43.480300999999997	43.420928000000004	0103000020E6100000010000000500000003232F6B62DD444040FCFCF7E0B5454003232F6B62DD4440389ECF807ABD4540471FF30181E04440389ECF807ABD4540471FF30181E0444040FCFCF7E0B5454003232F6B62DD444040FCFCF7E0B54540
3363	Карачаевск	8	78	\N	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
4338	Эльбурган	8	78	645	41.787084999999998	41.818418000000001	44.096390999999997	44.066630000000004	0103000020E6100000010000000500000009168733BFE444405C77F3548708464009168733BFE444407A50508A560C4640973AC8EBC1E844407A50508A560C4640973AC8EBC1E844405C77F3548708464009168733BFE444405C77F35487084640
57870	Хабез	8	78	645	41.752248000000002	41.781075000000001	44.063034999999999	44.023851999999998	0103000020E610000001000000050000009F3D97A949E04440DBF813950D0346409F3D97A949E044406EC0E78711084640925CFE43FAE344406EC0E78711084640925CFE43FAE34440DBF813950D0346409F3D97A949E04440DBF813950D034640
57871	Псаучье-Дахе	8	78	645	41.869532	41.891953999999998	44.229627000000001	44.203242000000003	0103000020E61000000100000005000000A96917D34CEF44403A9677D5031A4640A96917D34CEF4440A9A3E36A641D4640A8C4758C2BF24440A9A3E36A641D4640A8C4758C2BF244403A9677D5031A4640A96917D34CEF44403A9677D5031A4640
57962	Новохумаринский	8	78	645	41.894891999999999	41.901952000000001	44.227980000000002	44.215628000000002	0103000020E61000000100000005000000DCB930D28BF244400B0DC4B2991B4640DCB930D28BF244403012DA722E1D4640E947C32973F344403012DA722E1D4640E947C32973F344400B0DC4B2991B4640DCB930D28BF244400B0DC4B2991B4640
57857	Малый Зеленчук	8	78	645	41.853003000000001	41.879790999999997	44.171064999999999	44.146619999999999	0103000020E61000000100000005000000E831CA332FED44404278B471C4124640E831CA332FED4440C03E3A75E51546405628D2FD9CF04440C03E3A75E51546405628D2FD9CF044404278B471C4124640E831CA332FED44404278B471C4124640
57988	Кызыл-Юрт	8	78	645	41.865616000000003	41.878399000000002	44.187427	44.174013000000002	0103000020E610000001000000050000007A724D81CCEE4440180AD80E461646407A724D81CCEE444096B1A19BFD17464068EBE0606FF0444096B1A19BFD17464068EBE0606FF04440180AD80E461646407A724D81CCEE4440180AD80E46164640
57867	Кош-Хабль	8	78	645	41.836627	41.860405	44.148902999999997	44.130861000000003	0103000020E61000000100000005000000ADF9F19716EB444033A9A10DC0104640ADF9F19716EB44405DA3E5400F1346404E2844C021EE44405DA3E5400F1346404E2844C021EE444033A9A10DC0104640ADF9F19716EB444033A9A10DC0104640
4266	Инжич-Чукун	8	78	645	41.774697000000003	41.792565000000003	44.068410999999998	44.033172	0103000020E6100000010000000500000098A7734529E344404B92E7FA3E04464098A7734529E34440E4D70FB1C1084640257A19C572E54440E4D70FB1C1084640257A19C572E544404B92E7FA3E04464098A7734529E344404B92E7FA3E044640
57881	Зеюко	8	78	645	41.815480999999998	41.839295	44.131960999999997	44.100534000000003	0103000020E6100000010000000500000033C170AE61E844406B11514CDE0C464033C170AE61E8444079AC1919E41046402159C0046EEB444079AC1919E41046402159C0046EEB44406B11514CDE0C464033C170AE61E844406B11514CDE0C4640
57880	Жако	8	78	645	41.725847000000002	41.750272000000002	43.966025000000002	43.945771999999998	0103000020E610000001000000050000002A73F38DE8DC44407BBC900E0FF945402A73F38DE8DC4440280F0BB5A6FB4540618DB3E908E04440280F0BB5A6FB4540618DB3E908E044407BBC900E0FF945402A73F38DE8DC44407BBC900E0FF94540
57873	Бесленей	8	78	645	41.727338000000003	41.750208999999998	44.260086999999999	44.229356000000003	0103000020E61000000100000005000000AC915D6919DD4440199293895B1D4640AC915D6919DD4440B08EE3874A2146401A1538D906E04440B08EE3874A2146401A1538D906E04440199293895B1D4640AC915D6919DD4440199293895B1D4640
12562	Бавуко	8	78	645	41.883761	41.900604999999999	44.214866000000001	44.197439000000003	0103000020E61000000100000005000000793D98141FF144403CFA5FAE45194640793D98141FF14440DC82A5BA801B46409ACE4E0647F34440DC82A5BA801B46409ACE4E0647F344403CFA5FAE45194640793D98141FF144403CFA5FAE45194640
57855	Али-Бердуковский	8	78	645	41.728191000000002	41.755625999999999	44.008409999999998	43.97287	0103000020E61000000100000005000000EB1ED95C35DD444038A1100187FC4540EB1ED95C35DD4440CC7A319413014640EF004F5AB8E04440CC7A319413014640EF004F5AB8E0444038A1100187FC4540EB1ED95C35DD444038A1100187FC4540
57981	Абазакт	8	78	645	41.887830999999998	41.908195999999997	44.261958999999997	44.244714000000002	0103000020E61000000100000005000000FFAF3A72A4F14440CA6FD1C9521F4640FFAF3A72A4F1444049F25CDF87214640D32D3BC43FF4444049F25CDF87214640D32D3BC43FF44440CA6FD1C9521F4640FFAF3A72A4F14440CA6FD1C9521F4640
57875	аул Джегута	8	78	1159	41.805993999999998	42.337598999999997	44.165393999999999	43.775295	0103000020E61000000100000005000000D862B7CF2AE744404CE0D6DD3CE34540D862B7CF2AE74440317A6EA12B154640C614AC71362B4540317A6EA12B154640C614AC71362B45404CE0D6DD3CE34540D862B7CF2AE744404CE0D6DD3CE34540
57884	Эльтаркач	8	78	1159	42.112841000000003	42.148082000000002	43.995513000000003	43.967154000000001	0103000020E61000000100000005000000F052EA92710E45400919C8B3CBFB4540F052EA92710E454016DF50F86CFF45402A90D959F412454016DF50F86CFF45402A90D959F41245400919C8B3CBFB4540F052EA92710E45400919C8B3CBFB4540
32983	Усть-Джегута	8	78	1159	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
57878	Новая Джегута	8	78	1159	42.021725000000004	42.059759	44.023969000000001	43.990701000000001	0103000020E61000000100000005000000B84082E2C7024540A88E554ACFFE4540B84082E2C7024540158F8B6A110346402252D32EA6074540158F8B6A110346402252D32EA6074540A88E554ACFFE4540B84082E2C7024540A88E554ACFFE4540
57868	Кызыл-Кала	8	78	1159	42.006273999999998	42.038621999999997	43.931128000000001	43.899529000000001	0103000020E6100000010000000500000055682096CD004540DC662AC423F3454055682096CD004540E831CA332FF74540FB73D190F1044540E831CA332FF74540FB73D190F1044540DC662AC423F3454055682096CD004540DC662AC423F34540
57876	Кубина	8	78	1159	41.935927	41.962282999999999	44.076151000000003	44.043016000000001	0103000020E61000000100000005000000C138B874CCF74440359A5C8C81054640C138B874CCF744406347E350BF094640963FDF162CFB44406347E350BF094640963FDF162CFB4440359A5C8C81054640C138B874CCF74440359A5C8C81054640
57894	Красногорская	8	78	1159	41.873187999999999	41.903559999999999	43.952275	43.928387999999998	0103000020E610000001000000050000003CA1D79FC4EF4440DAFF006BD5F645403CA1D79FC4EF444032E6AE25E4F94540A4FCA4DAA7F3444032E6AE25E4F94540A4FCA4DAA7F34440DAFF006BD5F645403CA1D79FC4EF4440DAFF006BD5F64540
12076	Койдан	8	78	1159	42.146599999999999	42.183304999999997	44.111531999999997	44.100431	0103000020E61000000100000005000000FBCBEEC9C312454096404AECDA0C4640FBCBEEC9C31245408E3A3AAE460E4640BD18CA89761745408E3A3AAE460E4640BD18CA897617454096404AECDA0C4640FBCBEEC9C312454096404AECDA0C4640
57993	Гюрюльдеук	8	78	1159	42.048611000000001	42.079334000000003	43.990032999999997	43.971007999999998	0103000020E61000000100000005000000E99C9FE238064540C2137AFD49FC4540E99C9FE238064540FA7ABE66B9FE4540FEBAD39D270A4540FA7ABE66B9FE4540FEBAD39D270A4540C2137AFD49FC4540E99C9FE238064540C2137AFD49FC4540
57879	Гюрюльдеук	8	78	1159	42.048611000000001	42.079334000000003	43.990032999999997	43.971007999999998	0103000020E61000000100000005000000E99C9FE238064540C2137AFD49FC4540E99C9FE238064540FA7ABE66B9FE4540FEBAD39D270A4540FA7ABE66B9FE4540FEBAD39D270A4540C2137AFD49FC4540E99C9FE238064540C2137AFD49FC4540
11813	Важное	8	78	1159	41.926755	41.953237000000001	43.999682999999997	43.980530999999999	0103000020E61000000100000005000000C63368E89FF644406ADB300A82FD4540C63368E89FF64440FFAECF9CF5FF4540282B86AB03FA4440FFAECF9CF5FF4540282B86AB03FA44406ADB300A82FD4540C63368E89FF644406ADB300A82FD4540
10328	Уруп	8	78	796	41.136166000000003	41.173392	43.860602	43.817486000000002	0103000020E61000000100000005000000E06932E36D9144400C789961A3E84540E06932E36D914440A46FD23428EE4540ABB184B531964440A46FD23428EE4540ABB184B5319644400C789961A3E84540E06932E36D9144400C789961A3E84540
10675	Пхия	8	78	796	40.939219000000001	40.95158	43.595286000000002	43.585329000000002	0103000020E6100000010000000500000013640454387844404033880FECCA4540136404543878444022E2E65432CC45408BC3995FCD79444022E2E65432CC45408BC3995FCD7944404033880FECCA454013640454387844404033880FECCA4540
10757	Псемен	8	78	796	40.962943000000003	40.997987000000002	43.996096999999999	43.963579000000003	0103000020E61000000100000005000000C1745AB7417B4440630E828E56FB4540C1745AB7417B44406552431B80FF4540A56ABB09BE7F44406552431B80FF4540A56ABB09BE7F4440630E828E56FB4540C1745AB7417B4440630E828E56FB4540
10941	Предгорное	8	78	796	40.929481000000003	40.943046000000002	44.071545999999998	44.056083999999998	0103000020E610000001000000050000006FA0C03BF976444018EAB0C22D0746406FA0C03BF97644406E14596B28094640D34F38BBB57844406E14596B28094640D34F38BBB578444018EAB0C22D0746406FA0C03BF976444018EAB0C22D074640
10410	Преградная	8	78	796	41.159944000000003	41.214219999999997	43.981005000000003	43.917693999999997	0103000020E610000001000000050000008198840B7994444022DE3AFF76F545408198840B79944440331B649291FD454016139B8F6B9B4440331B649291FD454016139B8F6B9B444022DE3AFF76F545408198840B7994444022DE3AFF76F54540
5609	Медногорский	8	78	796	41.174900999999998	41.191861000000003	43.922784999999998	43.909129	0103000020E61000000100000005000000D384ED27639644402F6CCD565EF44540D384ED2763964440A31EA2D11DF645405E30B8E68E984440A31EA2D11DF645405E30B8E68E9844402F6CCD565EF44540D384ED27639644402F6CCD565EF44540
57890	Кызыл-Уруп	8	78	796	41.211606000000003	41.236120999999997	44.013584000000002	43.999896999999997	0103000020E6100000010000000500000096D1C8E7159B44402B2FF99FFCFF454096D1C8E7159B4440DBDFD91EBD0146400C738236399E4440DBDFD91EBD0146400C738236399E44402B2FF99FFCFF454096D1C8E7159B44402B2FF99FFCFF4540
57853	Курджиново	8	78	796	40.929616000000003	40.962575000000001	44.041338000000003	43.950172000000002	0103000020E610000001000000050000004FEB36A8FD76444097C9703C9FF945404FEB36A8FD764440810A47904A0546403E7958A8357B4440810A47904A0546403E7958A8357B444097C9703C9FF945404FEB36A8FD76444097C9703C9FF94540
10706	Курджиново	8	78	796	40.929616000000003	40.962575000000001	44.041338000000003	43.950172000000002	0103000020E610000001000000050000004FEB36A8FD76444097C9703C9FF945404FEB36A8FD764440810A47904A0546403E7958A8357B4440810A47904A0546403E7958A8357B444097C9703C9FF945404FEB36A8FD76444097C9703C9FF94540
10226	Чапаевское	8	78	656	42.039169999999999	42.076881	44.333198000000003	44.267516999999998	0103000020E61000000100000005000000FE7DC68503054540E00F3FFF3D224640FE7DC68503054540DB8B683BA62A46408657923CD7094540DB8B683BA62A46408657923CD7094540E00F3FFF3D224640FE7DC68503054540E00F3FFF3D224640
9686	Холоднородниковское	8	78	656	42.236072	42.307532999999999	44.142854999999997	44.116677000000003	0103000020E610000001000000050000002BC0779B371E454003999D45EF0E46402BC0779B371E4540F8889812491246406BB8C83D5D274540F8889812491246406BB8C83D5D27454003999D45EF0E46402BC0779B371E454003999D45EF0E4640
9444	Ударный	8	78	656	42.497588999999998	42.521906999999999	44.358584	44.342205	0103000020E61000000100000005000000B7EC10FFB03F45408BC3995FCD2B4640B7EC10FFB03F4540376F9C14E62D4640D8463CD9CD424540376F9C14E62D4640D8463CD9CD4245408BC3995FCD2B4640B7EC10FFB03F45408BC3995FCD2B4640
32680	Таллык	8	78	656	42.329236000000002	42.361953	44.156773999999999	44.145960000000002	0103000020E610000001000000050000003B55BE67242A4540184339D1AE1246403B55BE67242A45407A6EA12B1114464034D8D479542E45407A6EA12B1114464034D8D479542E4540184339D1AE1246403B55BE67242A4540184339D1AE124640
9766	Счастливое	8	78	656	42.248486	42.296196000000002	44.177013000000002	44.146982000000001	0103000020E61000000100000005000000C6C1A563CE1F4540E38C614ED0124640C6C1A563CE1F4540C2FBAA5CA81646405F9A22C0E9254540C2FBAA5CA81646405F9A22C0E9254540E38C614ED0124640C6C1A563CE1F4540E38C614ED0124640
9563	Солнечный	8	78	656	42.460112000000002	42.475617	44.217883	44.206001000000001	0103000020E61000000100000005000000A33F34F3E43A4540BEF8A23D5E1A4640A33F34F3E43A45405CAD1397E31B4640F8359204E13C45405CAD1397E31B4640F8359204E13C4540BEF8A23D5E1A4640A33F34F3E43A4540BEF8A23D5E1A4640
9823	Светлое	8	78	656	42.200291999999997	42.248531	44.166001999999999	44.144162000000001	0103000020E6100000010000000500000041D3122BA3194540B9A981E67312464041D3122BA31945400989B48D3F154640668522DDCF1F45400989B48D3F154640668522DDCF1F4540B9A981E67312464041D3122BA3194540B9A981E673124640
9436	Родниковский	8	78	656	42.361342	42.408458000000003	44.300001999999999	44.279367000000001	0103000020E61000000100000005000000EB556474402E4540734A404CC2234640EB556474402E4540075E2D776626464011E50B5A48344540075E2D776626464011E50B5A48344540734A404CC2234640EB556474402E4540734A404CC2234640
4451	Псыж	8	78	656	42.010728999999998	42.028821000000001	44.262805	44.217683000000001	0103000020E61000000100000005000000340F60915F01454095F25A09DD1B4640340F60915F014540D61C2098A321464011381268B0034540D61C2098A321464011381268B003454095F25A09DD1B4640340F60915F01454095F25A09DD1B4640
9934	Пристань	8	78	656	42.184058999999998	42.210056999999999	44.109350999999997	44.096209999999999	0103000020E6100000010000000500000069C4CC3E8F1745402AC6F99B500C464069C4CC3E8F1745407764AC36FF0D4640DFA5D425E31A45407764AC36FF0D4640DFA5D425E31A45402AC6F99B500C464069C4CC3E8F1745402AC6F99B500C4640
10042	Пригородное	8	78	656	42.109014000000002	42.136062000000003	44.242885999999999	44.233722	0103000020E610000001000000050000003067B62BF40D4540882D3D9AEA1D46403067B62BF40D4540005471E3161F46403B1DC87A6A114540005471E3161F46403B1DC87A6A114540882D3D9AEA1D46403067B62BF40D4540882D3D9AEA1D4640
57891	Привольный	8	78	656	42.138675999999997	42.163766000000003	44.165678999999997	44.153579000000001	0103000020E61000000100000005000000BB5E9A22C01145401B2D077AA8134640BB5E9A22C011454026512FF8341546402F19C748F614454026512FF8341546402F19C748F61445401B2D077AA8134640BB5E9A22C01145401B2D077AA8134640
9509	Октябрьский	8	78	656	42.472365000000003	42.500123000000002	44.265205999999999	44.243977999999998	0103000020E610000001000000050000003563D174763C4540C478CDAB3A1F46403563D174763C4540FB592C45F22146401C7DCC0704404540FB592C45F22146401C7DCC0704404540C478CDAB3A1F46403563D174763C4540C478CDAB3A1F4640
40393	Новый	8	78	656	42.529156	42.552700999999999	44.266832999999998	44.248117000000001	0103000020E61000000100000005000000B83D4162BB434540734A404CC21F4640B83D4162BB4345402D3F709527224640B6BB07E8BE4645402D3F709527224640B6BB07E8BE464540734A404CC21F4640B83D4162BB434540734A404CC21F4640
9947	Николаевское	8	78	656	42.101253	42.150075999999999	44.130240000000001	44.107731999999999	0103000020E610000001000000050000009ACFB9DBF50C4540C85D8429CA0D46409ACFB9DBF50C4540C6504EB4AB1046400EF5BBB035134540C6504EB4AB1046400EF5BBB035134540C85D8429CA0D46409ACFB9DBF50C4540C85D8429CA0D4640
9295	Мичуринский	8	78	656	42.307577999999999	42.325068000000002	44.283206999999997	44.268794999999997	0103000020E610000001000000050000000B7C45B75E274540062AE3DF672246400B7C45B75E274540C77F812040244640F27C06D49B294540C77F812040244640F27C06D49B294540062AE3DF672246400B7C45B75E274540062AE3DF67224640
9368	Майский	8	78	656	42.403157999999998	42.442746999999997	44.307969	44.295931000000003	0103000020E61000000100000005000000758F6CAE9A334540B16F2711E1254640758F6CAE9A334540469737876B27464078B306EFAB384540469737876B27464078B306EFAB384540B16F2711E1254640758F6CAE9A334540B16F2711E1254640
4406	Кара-Паго	8	78	656	41.935279999999999	41.950029999999998	44.138081	44.124941	0103000020E610000001000000050000002B4D4A41B7F74440FB761211FE0F46402B4D4A41B7F74440789961A3AC114640041C42959AF94440789961A3AC114640041C42959AF94440FB761211FE0F46402B4D4A41B7F74440FB761211FE0F4640
9231	Кавказский	8	78	656	42.217063000000003	42.242998	44.274887999999997	44.261920000000003	0103000020E61000000100000005000000F9156BB8C81B45408C15359886214640F9156BB8C81B45400B08AD872F234640287FF78E1A1F45400B08AD872F234640287FF78E1A1F45408C15359886214640F9156BB8C81B45408C15359886214640
10075	Ильичевское	8	78	656	42.139825999999999	42.154603999999999	44.196075	44.181299000000003	0103000020E61000000100000005000000B49080D1E511454015E63DCE34174640B49080D1E5114540174850FC1819464057EA5910CA134540174850FC1819464057EA5910CA13454015E63DCE34174640B49080D1E511454015E63DCE34174640
10109	Знаменка	8	78	656	42.041370999999998	42.075471	44.151955999999998	44.138055000000001	0103000020E610000001000000050000005C001AA54B0545404F0647C9AB1146405C001AA54B0545402A37514B73134640F165A208A90945402A37514B73134640F165A208A90945404F0647C9AB1146405C001AA54B0545404F0647C9AB114640
10167	Дружба	8	78	656	42.007548999999997	42.028362999999999	44.218089999999997	44.178809999999999	0103000020E610000001000000050000000A0F9A5DF70045405019FF3EE31646400A0F9A5DF7004540D5CA845FEA1B46404EB51666A1034540D5CA845FEA1B46404EB51666A10345405019FF3EE31646400A0F9A5DF70045405019FF3EE3164640
9323	Водораздельный	8	78	656	42.332909999999998	42.356966999999997	44.256419999999999	44.241149	0103000020E6100000010000000500000074417DCB9C2A4540473B6EF8DD1E464074417DCB9C2A45402905DD5ED220464028603B18B12D45402905DD5ED220464028603B18B12D4540473B6EF8DD1E464074417DCB9C2A4540473B6EF8DD1E4640
58036	Эркен-Шахар	8	78	7455	41.935442000000002	41.976162000000002	44.389884000000002	44.357635999999999	0103000020E6100000010000000500000005A73E90BCF74440A6EF3504C72D464005A73E90BCF74440E99D0AB8E73146408ACC5CE0F2FC4440E99D0AB8E73146408ACC5CE0F2FC4440A6EF3504C72D464005A73E90BCF74440A6EF3504C72D4640
8148	Элькуш	8	78	967	42.631940999999998	42.650069000000002	43.871130000000001	43.856538999999998	0103000020E6100000010000000500000032005471E3504540D05FE811A3ED454032005471E35045404148163081EF45405C920376355345404148163081EF45405C92037635534540D05FE811A3ED454032005471E3504540D05FE811A3ED4540
8343	Учкекен	8	78	967	42.485678	42.552396000000002	43.962398	43.912920999999997	0103000020E610000001000000050000007F315BB22A3E4540726A6798DAF445407F315BB22A3E45402FDE8FDB2FFB45407A3881E9B44645402FDE8FDB2FFB45407A3881E9B4464540726A6798DAF445407F315BB22A3E4540726A6798DAF44540
8670	Терезе	8	78	967	42.422679000000002	42.458027000000001	43.942214999999997	43.920636000000002	0103000020E610000001000000050000005EDA70581A36454098C28366D7F545405EDA70581A3645407B6649809AF84540AED7F4A0A03A45407B6649809AF84540AED7F4A0A03A454098C28366D7F545405EDA70581A36454098C28366D7F54540
57869	Рим-Горский	8	78	967	42.498344000000003	42.532209999999999	43.960244000000003	43.945486000000002	0103000020E61000000100000005000000341477BCC93F4540B6696CAF05F94540341477BCC93F454012178046E9FA4540554D10751F44454012178046E9FA4540554D10751F444540B6696CAF05F94540341477BCC93F4540B6696CAF05F94540
8575	Первомайское	8	78	967	42.435606	42.495370000000001	43.946745999999997	43.928213	0103000020E610000001000000050000007FF8F9EFC13745406C5CFFAECFF645407FF8F9EFC137454035CF11F92EF94540B3B5BE48683F454035CF11F92EF94540B3B5BE48683F45406C5CFFAECFF645407FF8F9EFC13745406C5CFFAECFF64540
57886	Кызыл-Покун	8	78	967	42.308906999999998	42.337563000000003	43.934848000000002	43.923558	0103000020E61000000100000005000000B340BB438A274540C6FA062637F64540B340BB438A274540925D6919A9F745407AABAE43352B4540925D6919A9F745407AABAE43352B4540C6FA062637F64540B340BB438A274540C6FA062637F64540
49683	Красный Курган	8	78	967	42.587493000000002	42.628079	43.950685	43.936275999999999	0103000020E6100000010000000500000081D07AF8324B4540CD0358E4D7F7454081D07AF8324B45401DE6CB0BB0F94540F62686E4645045401DE6CB0BB0F94540F62686E464504540CD0358E4D7F7454081D07AF8324B4540CD0358E4D7F74540
57946	Красновосточный	8	78	967	42.275480999999999	42.316946999999999	43.986485999999999	43.945447999999999	0103000020E61000000100000005000000AED51EF642234540C808A87004F94540AED51EF6422345401EFB592C45FE45405CC823B8912845401EFB592C45FE45405CC823B891284540C808A87004F94540AED51EF642234540C808A87004F94540
8063	Кичи-Балык	8	78	967	42.642226999999998	42.661378999999997	43.800572000000003	43.780613000000002	0103000020E61000000100000005000000D9CD8C7E345245408EEA7420EBE34540D9CD8C7E34524540F20BAF2479E645406EA12B11A8544540F20BAF2479E645406EA12B11A85445408EEA7420EBE34540D9CD8C7E345245408EEA7420EBE34540
8238	Джага	8	78	967	42.541921000000002	42.575544999999998	43.957901	43.946556999999999	0103000020E610000001000000050000000002D6AA5D45454062669FC728F945400002D6AA5D45454021E7FD7F9CFA45402B306475AB49454021E7FD7F9CFA45402B306475AB49454062669FC728F945400002D6AA5D45454062669FC728F94540
3259	Эльбрусский	8	78	534	42.128633000000001	42.141776	43.600364999999996	43.553185999999997	0103000020E61000000100000005000000DB17D00B77104540724D81CCCEC64540DB17D00B77104540DE54A4C2D8CC4540C9AD49B725124540DE54A4C2D8CC4540C9AD49B725124540724D81CCCEC64540DB17D00B77104540724D81CCCEC64540
58010	Хурзук	8	78	534	42.135855999999997	42.166514999999997	43.442427000000002	43.422871999999998	0103000020E61000000100000005000000917BBABA63114540723271AB20B64540917BBABA6311454007EFAB72A1B845408FA50F5D5015454007EFAB72A1B845408FA50F5D50154540723271AB20B64540917BBABA63114540723271AB20B64540
58001	Учкулан	8	78	534	42.037823000000003	42.111151999999997	43.478245999999999	43.433413000000002	0103000020E61000000100000005000000B0045262D7044540A454C2137AB74540B0045262D7044540AEB8382A37BD454047718E3A3A0E4540AEB8382A37BD454047718E3A3A0E4540A454C2137AB74540B0045262D7044540A454C2137AB74540
3972	Теберда	8	78	534	41.729565999999998	41.753937000000001	43.480300999999997	43.420928000000004	0103000020E6100000010000000500000003232F6B62DD444040FCFCF7E0B5454003232F6B62DD4440389ECF807ABD4540471FF30181E04440389ECF807ABD4540471FF30181E0444040FCFCF7E0B5454003232F6B62DD444040FCFCF7E0B54540
57852	Правокубанский	8	78	534	41.879539000000001	41.890005000000002	43.928173999999999	43.904439000000004	0103000020E610000001000000050000003D47E4BB94F044400D1D3BA8C4F345403D47E4BB94F04440AE7FD767CEF64540642310AFEBF14440AE7FD767CEF64540642310AFEBF144400D1D3BA8C4F345403D47E4BB94F044400D1D3BA8C4F34540
57943	Новый Карачай	8	78	534	41.894775000000003	41.916271999999999	43.830824999999997	43.806114999999998	0103000020E61000000100000005000000A323B9FC87F2444053E8BCC62EE74540A323B9FC87F244407FD93D7958EA4540C91EA16648F544407FD93D7958EA4540C91EA16648F5444053E8BCC62EE74540A323B9FC87F2444053E8BCC62EE74540
33063	Новая Теберда	8	78	534	41.888972000000003	41.902168000000003	43.680622999999997	43.665331999999999	0103000020E61000000100000005000000A587A1D5C9F14440BB7D569929D54540A587A1D5C9F14440E4F38AA71ED74540B6BFB33D7AF34440E4F38AA71ED74540B6BFB33D7AF34440BB7D569929D54540A587A1D5C9F14440BB7D569929D54540
33082	Нижняя Мара	8	78	534	42.073953000000003	42.094802999999999	43.768186999999998	43.756318	0103000020E610000001000000050000007638BA4A7709454025B03907CFE045407638BA4A770945402E1B9DF353E2454006483481220C45402E1B9DF353E2454006483481220C454025B03907CFE045407638BA4A7709454025B03907CFE04540
60659	Кумышское	8	78	534	41.510052999999999	42.436881	43.928179999999998	43.187358000000003	0103000020E61000000100000005000000041DAD6A49C144406E52D158FB974540041DAD6A49C1444090662C9ACEF64540349F73B7EB37454090662C9ACEF64540349F73B7EB3745406E52D158FB974540041DAD6A49C144406E52D158FB974540
7892	Кубрань	8	78	534	41.928398999999999	41.936115000000001	43.840598	43.835897000000003	0103000020E61000000100000005000000CE5147C7D5F644408AE942ACFEEA4540CE5147C7D5F64440A08A1BB798EB4540C425C79DD2F74440A08A1BB798EB4540C425C79DD2F744408AE942ACFEEA4540CE5147C7D5F644408AE942ACFEEA4540
58034	Карт-Джурт	8	78	534	42.094515000000001	42.132469	43.540770999999999	43.480587999999997	0103000020E61000000100000005000000A0FD4811190C4540CE6C57E883BD4540A0FD4811190C454007D0EFFB37C54540EE5D83BEF410454007D0EFFB37C54540EE5D83BEF4104540CE6C57E883BD4540A0FD4811190C4540CE6C57E883BD4540
60665	Джингирик	8	78	534	41.880806	41.895843999999997	43.747228	43.724879999999999	0103000020E610000001000000050000006F0F4240BEF0444022C32ADEC8DC45406F0F4240BEF04440E753C72AA5DF4540AE282504ABF24440E753C72AA5DF4540AE282504ABF2444022C32ADEC8DC45406F0F4240BEF0444022C32ADEC8DC4540
3882	Орджоникидзевский	8	78	612	41.887346000000001	41.902132000000002	43.855277999999998	43.830128999999999	0103000020E61000000100000005000000431EC18D94F14440083BC5AA41EA4540431EC18D94F14440807EDFBF79ED45406956B60F79F34440807EDFBF79ED45406956B60F79F34440083BC5AA41EA4540431EC18D94F14440083BC5AA41EA4540
57995	Хусы-Кардоник	8	78	747	41.563493999999999	41.584847000000003	43.794474999999998	43.778472000000001	0103000020E6100000010000000500000001BF469220C84440056D72F8A4E3454001BF469220C84440AB3E575BB1E54540F5143944DCCA4440AB3E575BB1E54540F5143944DCCA4440056D72F8A4E3454001BF469220C84440056D72F8A4E34540
7194	Хасаут-Греческое	8	78	747	41.660341000000003	41.676763000000001	43.723830999999997	43.703704000000002	0103000020E610000001000000050000009E9ACB0D86D444403E0801F912DA45409E9ACB0D86D444405D6A847EA6DC45404912842BA0D644405D6A847EA6DC45404912842BA0D644403E0801F912DA45409E9ACB0D86D444403E0801F912DA4540
57969	Фроловский	8	78	747	41.683346999999998	41.702849999999998	44.169519999999999	44.155687999999998	0103000020E61000000100000005000000EC681CEA77D7444098309A95ED134640EC681CEA77D744404B02D4D4B21546402EFF21FDF6D944404B02D4D4B21546402EFF21FDF6D9444098309A95ED134640EC681CEA77D7444098309A95ED134640
57888	Сторожевая 2	8	78	747	41.423357000000003	41.472296999999998	43.906427000000001	43.855623000000001	0103000020E610000001000000050000002FC4EA8F30B644404B5AF10D85ED45402FC4EA8F30B644400F9BC8CC05F44540DC7F643A74BC44400F9BC8CC05F44540DC7F643A74BC44404B5AF10D85ED45402FC4EA8F30B644404B5AF10D85ED4540
6009	Сторожевая	8	78	747	41.423357000000003	41.472296999999998	43.906427000000001	43.855623000000001	0103000020E610000001000000050000002FC4EA8F30B644404B5AF10D85ED45402FC4EA8F30B644400F9BC8CC05F44540DC7F643A74BC44400F9BC8CC05F44540DC7F643A74BC44404B5AF10D85ED45402FC4EA8F30B644404B5AF10D85ED4540
58015	Ново-Исправненский	8	78	747	41.063932000000001	41.795565000000003	44.169519999999999	43.334093000000003	0103000020E610000001000000050000007D957CEC2E8844404969368FC3AA45407D957CEC2E8844404B02D4D4B2154640CF6BEC12D5E544404B02D4D4B2154640CF6BEC12D5E544404969368FC3AA45407D957CEC2E8844404969368FC3AA4540
6845	Нижняя Ермоловка	8	78	747	41.502867000000002	41.521245999999998	43.768610000000002	43.727961999999998	0103000020E610000001000000050000006B9E23F25DC04440895DDBDB2DDD45406B9E23F25DC0444075B0FECF61E24540DD955D30B8C2444075B0FECF61E24540DD955D30B8C24440895DDBDB2DDD45406B9E23F25DC04440895DDBDB2DDD4540
6965	Нижний Архыз	8	78	747	41.452058000000001	41.479052000000003	43.688198	43.673966	0103000020E6100000010000000500000095F25A09DDB94440D74E948444D6454095F25A09DDB9444018963FDF16D84540AD8A709351BD444018963FDF16D84540AD8A709351BD4440D74E948444D6454095F25A09DDB94440D74E948444D64540
7104	Маруха	8	78	747	41.612335999999999	41.657350000000001	43.790278000000001	43.739569000000003	0103000020E61000000100000005000000EC14AB0661CE444056116E32AADE4540EC14AB0661CE4440C85F5AD427E545404703780B24D44440C85F5AD427E545404703780B24D4444056116E32AADE4540EC14AB0661CE444056116E32AADE4540
57996	Лесо-Кефарь	8	78	747	41.443533000000002	41.458930000000002	43.804586	43.779032000000001	0103000020E6100000010000000500000030D978B0C5B84440CC441152B7E3454030D978B0C5B84440E4688EACFCE645409F93DE37BEBA4440E4688EACFCE645409F93DE37BEBA4440CC441152B7E3454030D978B0C5B84440CC441152B7E34540
57896	Кызыл-Октябрьский	8	78	747	41.772908999999999	41.795565000000003	43.839830999999997	43.803674999999998	0103000020E610000001000000050000005CE49EAEEEE2444070CE88D2DEE645405CE49EAEEEE244405F950B957FEB4540CF6BEC12D5E544405F950B957FEB4540CF6BEC12D5E5444070CE88D2DEE645405CE49EAEEEE2444070CE88D2DEE64540
57892	Кобу-Баши	8	78	747	41.300575000000002	41.335160000000002	43.940313000000003	43.922863	0103000020E61000000100000005000000637FD93D79A644401FD8F15F20F64540637FD93D79A644407880272D5CF84540B476DB85E6AA44407880272D5CF84540B476DB85E6AA44401FD8F15F20F64540637FD93D79A644401FD8F15F20F64540
6233	Кардоникская	8	78	747	41.689886999999999	41.741325000000003	43.887478999999999	43.840527000000002	0103000020E61000000100000005000000C0779B374ED84440D733846396EB4540C0779B374ED84440827170E998F14540865AD3BCE3DE4440827170E998F14540865AD3BCE3DE4440D733846396EB4540C0779B374ED84440D733846396EB4540
6553	Исправная	8	78	747	41.584847000000003	41.630706000000004	44.106476999999998	44.037073999999997	0103000020E61000000100000005000000F5143944DCCA444015C440D7BE044640F5143944DCCA44405A63D009A10D46400CB265F9BAD044405A63D009A10D46400CB265F9BAD0444015C440D7BE044640F5143944DCCA444015C440D7BE044640
57978	Ильич	8	78	747	41.522889999999997	41.533095000000003	43.960211999999999	43.943838	0103000020E61000000100000005000000E5B33C0FEEC244406C5CFFAECFF84540E5B33C0FEEC24440069D103AE8FA4540A054FB743CC44440069D103AE8FA4540A054FB743CC444406C5CFFAECFF84540E5B33C0FEEC244406C5CFFAECFF84540
5280	Зеленчукская	8	78	747	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
6766	Даусуз	8	78	747	41.535466999999997	41.567501	43.811045999999997	43.784433999999997	0103000020E610000001000000050000002A8BC22E8AC444406BEF535568E445402A8BC22E8AC444409BC6F65AD0E7454041B96DDFA3C844409BC6F65AD0E7454041B96DDFA3C844406BEF535568E445402A8BC22E8AC444406BEF535568E44540
6898	Архыз	8	78	747	41.271461000000002	41.288294999999998	43.570321	43.558706999999998	0103000020E61000000100000005000000DA91EA3BBFA24440EC8502B683C74540DA91EA3BBFA244406B9C4D4700C94540D74CBED9E6A444406B9C4D4700C94540D74CBED9E6A44440EC8502B683C74540DA91EA3BBFA24440EC8502B683C74540
5121	Эрсакон	8	78	576	41.759273	41.784857000000002	44.444153999999997	44.417414999999998	0103000020E610000001000000050000002FDE8FDB2FE144400FEECEDA6D3546402FDE8FDB2FE144409C31CC09DA384640B284B53176E444409C31CC09DA384640B284B53176E444400FEECEDA6D3546402FDE8FDB2FE144400FEECEDA6D354640
57874	Эркен-Юрт	8	78	576	41.903739999999999	41.923727999999997	44.468423000000001	44.429935999999998	0103000020E61000000100000005000000240B98C0ADF34440C0AF912408374640240B98C0ADF34440DCD8EC48F53B4640223317B83CF64440DCD8EC48F53B4640223317B83CF64440C0AF912408374640240B98C0ADF34440C0AF912408374640
57994	Эркен-Шахар	8	78	576	41.935442000000002	41.976162000000002	44.389884000000002	44.357635999999999	0103000020E6100000010000000500000005A73E90BCF74440A6EF3504C72D464005A73E90BCF74440E99D0AB8E73146408ACC5CE0F2FC4440E99D0AB8E73146408ACC5CE0F2FC4440A6EF3504C72D464005A73E90BCF74440A6EF3504C72D4640
57889	Эркен-Халк	8	78	576	41.933591	41.946292999999997	44.383778	44.360201000000004	0103000020E61000000100000005000000836BEEE87FF74440467EFD101B2E4640836BEEE87FF744404F7633A31F31464084B7072120F944404F7633A31F31464084B7072120F94440467EFD101B2E4640836BEEE87FF74440467EFD101B2E4640
24644	Тапанта	8	78	576	41.659891999999999	41.679718000000001	44.354664999999997	44.345517999999998	0103000020E610000001000000050000002E724F5777D44440F4160FEF392C46402E724F5777D444409604A8A9652D46405340DAFF00D744409604A8A9652D46405340DAFF00D74440F4160FEF392C46402E724F5777D44440F4160FEF392C4640
57898	Старокувинский	8	78	576	41.759596000000002	41.793059	44.362541	44.328923000000003	0103000020E61000000100000005000000121615713AE144407CF31B261A2A4640121615713AE14440C53A55BE672E4640346612F582E54440C53A55BE672E4640346612F582E544407CF31B261A2A4640121615713AE144407CF31B261A2A4640
4844	Спарта	8	78	576	41.793238000000002	41.807737000000003	44.426692000000003	44.404761999999998	0103000020E61000000100000005000000E4F8A1D288E54440EF54C03DCF334640E4F8A1D288E5444080BBECD79D36464074620FED63E7444080BBECD79D36464074620FED63E74440EF54C03DCF334640E4F8A1D288E54440EF54C03DCF334640
57885	Садовое	8	78	576	42.024535999999998	42.053677999999998	44.349572999999999	44.304879	0103000020E610000001000000050000008EC9E2FE230345405C1E6B46062746408EC9E2FE230345404548DDCEBE2C4640E141B3EBDE0645404548DDCEBE2C4640E141B3EBDE0645405C1E6B46062746408EC9E2FE230345405C1E6B4606274640
58004	Новокувинский	8	78	576	41.773412	41.788252999999997	44.410352000000003	44.390954000000001	0103000020E61000000100000005000000BF2A172AFFE24440C51EDAC70A324640BF2A172AFFE2444092EC116A86344640A8FC6B79E5E4444092EC116A86344640A8FC6B79E5E44440C51EDAC70A324640BF2A172AFFE24440C51EDAC70A324640
57893	Кызыл-Тогай	8	78	576	41.782342	41.796706	44.338227000000003	44.321688000000002	0103000020E61000000100000005000000C4245CC823E4444001C287122D294640C4245CC823E44440E6CFB7054B2B464074435376FAE54440E6CFB7054B2B464074435376FAE5444001C287122D294640C4245CC823E4444001C287122D294640
58002	Киево-Жураковский	8	78	576	41.776521000000002	41.790382000000001	44.47081	44.458767000000002	0103000020E6100000010000000500000020D4450A65E34440F5BD86E0B83A464020D4450A65E344409C508880433C46406DACC43C2BE544409C508880433C46406DACC43C2BE54440F5BD86E0B83A464020D4450A65E34440F5BD86E0B83A4640
60670	Икон-Халк	8	78	576	41.898232999999998	41.928192000000003	44.326994999999997	44.290349999999997	0103000020E610000001000000050000000F98874CF9F24440613255302A2546400F98874CF9F244404E7ADFF8DA2946405534D6FECEF644404E7ADFF8DA2946405534D6FECEF64440613255302A2546400F98874CF9F24440613255302A254640
57980	Евсеевский	8	78	576	41.910854999999998	41.920467000000002	44.496468999999998	44.485847	0103000020E61000000100000005000000F4328AE596F444400BEE073C303E4640F4328AE596F44440293DD34B8C3F46400C06D7DCD1F54440293DD34B8C3F46400C06D7DCD1F544400BEE073C303E4640F4328AE596F444400BEE073C303E4640
4937	Дубянский	8	78	576	41.792394000000002	41.815831000000003	44.483345	44.463771999999999	0103000020E61000000100000005000000F8C5A52A6DE54440776682E15C3B4640F8C5A52A6DE54440B2D7BB3FDE3D4640100874266DE84440B2D7BB3FDE3D4640100874266DE84440776682E15C3B4640F8C5A52A6DE54440776682E15C3B4640
3594	Грушка	8	78	576	41.655203	41.663243000000001	44.379159000000001	44.371065999999999	0103000020E61000000100000005000000DC9E20B1DDD344402A5437177F2F4640DC9E20B1DDD34440F67D38488830464085268925E5D44440F67D38488830464085268925E5D444402A5437177F2F4640DC9E20B1DDD344402A5437177F2F4640
5103	Вако-Жиле	8	78	576	41.732647	41.753739000000003	44.31729	44.293382999999999	0103000020E610000001000000050000009A417C60C7DD4440E719FB928D2546409A417C60C7DD444086AC6EF59C284640215C01857AE0444086AC6EF59C284640215C01857AE04440E719FB928D2546409A417C60C7DD4440E719FB928D254640
4866	Баралки	8	78	576	41.795996000000002	41.809327000000003	44.361032999999999	44.344326000000002	0103000020E6100000010000000500000098DF6932E3E54440CD94D6DF122C464098DF6932E3E544406DE34F54362E46408962F20698E744406DE34F54362E46408962F20698E74440CD94D6DF122C464098DF6932E3E54440CD94D6DF122C4640
4776	Апсуа	8	78	576	41.787264	41.810395999999997	44.457827000000002	44.441476999999999	0103000020E61000000100000005000000B9A81611C5E44440D5777E5182384640B9A81611C5E44440E71C3C139A3A464094675E0EBBE74440E71C3C139A3A464094675E0EBBE74440D5777E5182384640B9A81611C5E44440D5777E5182384640
4684	Адыге-Хабль	8	78	576	41.928569000000003	41.952598999999999	44.343881000000003	44.320140000000002	0103000020E610000001000000050000002B8A5759DBF644401B12F758FA2846402B8A5759DBF644409F5BE84A042C4640E59997C3EEF944409F5BE84A042C4640E59997C3EEF944401B12F758FA2846402B8A5759DBF644401B12F758FA284640
58005	Адиль-Халк	8	78	576	41.916055999999998	41.932144999999998	44.366213999999999	44.342295	0103000020E61000000100000005000000FCA6B05241F54440CB4A9352D02B4640FCA6B05241F544402EABB019E02E4640A110018750F744402EABB019E02E4640A110018750F74440CB4A9352D02B4640FCA6B05241F54440CB4A9352D02B4640
4989	Абаза-Хабль	8	78	576	41.626106999999998	41.649669000000003	44.374519999999997	44.367677	0103000020E61000000100000005000000F965304624D04440E63E390A102F4640F965304624D0444055D97745F02F4640CE1C925A28D3444055D97745F02F4640CE1C925A28D34440E63E390A102F4640F965304624D04440E63E390A102F4640
58021	Псыж	8	78	7454	42.010728999999998	42.028821000000001	44.262805	44.217683000000001	0103000020E61000000100000005000000340F60915F01454095F25A09DD1B4640340F60915F014540D61C2098A321464011381268B0034540D61C2098A321464011381268B003454095F25A09DD1B4640340F60915F01454095F25A09DD1B4640
57961	ст. Александровская	8	77	\N	42.398083	44.475527	44.020572000000001	42.888719000000002	0103000020E61000000100000005000000FA0B3D62F4324540BB2A508BC1714540FA0B3D62F43245404E9B711AA2024640B8AE9811DE3C46404E9B711AA2024640B8AE9811DE3C4640BB2A508BC1714540FA0B3D62F4324540BB2A508BC1714540
57944	Хасанья	8	77	\N	43.563647000000003	43.591064000000003	43.448743	43.423375999999998	0103000020E6100000010000000500000088BEBB9525C84540A5F44C2F31B6454088BEBB9525C845408BA71E6970B94540E6EB32FCA7CB45408BA71E6970B94540E6EB32FCA7CB4540A5F44C2F31B6454088BEBB9525C84540A5F44C2F31B64540
57837	Тырныауз	8	77	\N	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
57845	Терек	8	77	\N	44.120790999999997	44.154747	43.499307000000002	43.459777000000003	0103000020E6100000010000000500000058535914760F4640FC3905F9D9BA454058535914760F4640FAD4B14AE9BF4540BA13ECBFCE134640FAD4B14AE9BF4540BA13ECBFCE134640FC3905F9D9BA454058535914760F4640FC3905F9D9BA4540
57836	Прохладный	8	77	\N	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
32538	Нальчик	8	77	\N	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
57824	Майский	8	77	\N	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
57839	Баксан	8	77	\N	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
52917	Эльбрус	8	77	1604	42.636944999999997	42.661577000000001	43.262424000000003	43.250743999999997	0103000020E61000000100000005000000E42CEC698751454088D51F6118A04540E42CEC6987514540BFD7101C97A1454095641D8EAE544540BFD7101C97A1454095641D8EAE54454088D51F6118A04540E42CEC698751454088D51F6118A04540
32679	Эльбрус	8	77	1604	42.636944999999997	42.661577000000001	43.262424000000003	43.250743999999997	0103000020E61000000100000005000000E42CEC698751454088D51F6118A04540E42CEC6987514540BFD7101C97A1454095641D8EAE544540BFD7101C97A1454095641D8EAE54454088D51F6118A04540E42CEC698751454088D51F6118A04540
32613	Тырныауз	8	77	1604	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
57992	Сельское поселение Кенделен	8	77	1604	42.398083	43.271496999999997	43.662194999999997	43.133940000000003	0103000020E61000000100000005000000FA0B3D62F432454029D027F224914540FA0B3D62F4324540904946CEC2D4454026FBE769C0A24540904946CEC2D4454026FBE769C0A2454029D027F224914540FA0B3D62F432454029D027F224914540
57976	Кенделен	8	77	1604	42.398083	43.271496999999997	43.662194999999997	43.133940000000003	0103000020E61000000100000005000000FA0B3D62F432454029D027F224914540FA0B3D62F4324540904946CEC2D4454026FBE769C0A24540904946CEC2D4454026FBE769C0A2454029D027F224914540FA0B3D62F432454029D027F224914540
57979	Гунделен	8	77	1604	43.144303999999998	43.217652000000001	43.608981999999997	43.582977999999997	0103000020E610000001000000050000004B57B08D78924540CC24EA059FCA45404B57B08D7892454024ED461FF3CD45405AF44E05DC9B454024ED461FF3CD45405AF44E05DC9B4540CC24EA059FCA45404B57B08D78924540CC24EA059FCA4540
57984	Верхний Баксан	8	77	1604	42.741742000000002	42.760508000000002	43.315165	43.300443999999999	0103000020E61000000100000005000000EA08E066F15E4540C423F1F274A64540EA08E066F15E454003ECA35357A84540562C7E535861454003ECA35357A84540562C7E5358614540C423F1F274A64540EA08E066F15E4540C423F1F274A64540
52890	Былым	8	77	1604	43.024594999999998	43.055200999999997	43.467668000000003	43.441870999999999	0103000020E610000001000000050000009352D0ED2583454081069B3A8FB845409352D0ED2583454060B1868BDCBB45406EDA8CD31087454060B1868BDCBB45406EDA8CD31087454081069B3A8FB845409352D0ED2583454081069B3A8FB84540
52889	Бедык	8	77	1604	43.141869999999997	43.159422999999997	43.515529000000001	43.508507000000002	0103000020E610000001000000050000004A24D1CB28924540BF64E3C116C145404A24D1CB28924540DE91B1DAFCC14540779D0DF967944540DE91B1DAFCC14540779D0DF967944540BF64E3C116C145404A24D1CB28924540BF64E3C116C14540
57990	Советское	8	77	1563	43.589509	43.624068000000001	43.325468999999998	43.305489000000001	0103000020E610000001000000050000004DD9E90775CB4540D52478431AA745404DD9E90775CB4540506EDBF7A8A94540753DD175E1CF4540506EDBF7A8A94540753DD175E1CF4540D52478431AA745404DD9E90775CB4540D52478431AA74540
57958	Советское	8	77	1563	43.589509	43.624068000000001	43.325468999999998	43.305489000000001	0103000020E610000001000000050000004DD9E90775CB4540D52478431AA745404DD9E90775CB4540506EDBF7A8A94540753DD175E1CF4540506EDBF7A8A94540753DD175E1CF4540D52478431AA745404DD9E90775CB4540D52478431AA74540
57942	Кашхатау	8	77	1563	43.016483000000001	43.789994999999998	43.506093999999997	42.888725999999998	0103000020E6100000010000000500000051F86C1D1C8245406D8D08C6C171454051F86C1D1C824540D5592DB0C7C045407380608E1EE54540D5592DB0C7C045407380608E1EE545406D8D08C6C171454051F86C1D1C8245406D8D08C6C1714540
52886	Карасу	8	77	1563	43.405265	43.428117999999998	43.301434999999998	43.291257999999999	0103000020E61000000100000005000000529B38B9DFB34540645930F147A54540529B38B9DFB34540546F0D6C95A645401A6A1492CCB64540546F0D6C95A645401A6A1492CCB64540645930F147A54540529B38B9DFB34540645930F147A54540
52831	Зарагиж	8	77	1563	43.693866999999997	43.725568000000003	43.342728000000001	43.324084999999997	0103000020E61000000100000005000000066344A2D0D84540E40F069E7BA94540066344A2D0D8454035B6D782DEAB454017838769DFDC454035B6D782DEAB454017838769DFDC4540E40F069E7BA94540066344A2D0D84540E40F069E7BA94540
52834	Жемтала	8	77	1563	43.630122	43.675496000000003	43.297432000000001	43.267118000000004	0103000020E61000000100000005000000BC3E73D6A7D04540231631EC30A24540BC3E73D6A7D045405664744012A64540174A26A776D645405664744012A64540174A26A776D64540231631EC30A24540BC3E73D6A7D04540231631EC30A24540
33089	Герпегеж	8	77	1563	43.647226000000003	43.664025000000002	43.379393	43.366962000000001	0103000020E610000001000000050000007A8F334DD8D24540F86F5E9CF8AE45407A8F334DD8D2454069AA27F38FB04540FB5C6DC5FED4454069AA27F38FB04540FB5C6DC5FED44540F86F5E9CF8AE45407A8F334DD8D24540F86F5E9CF8AE4540
32774	Верхняя Жемтала	8	77	1563	43.660719	43.680059999999997	43.247473999999997	43.22354	0103000020E61000000100000005000000446CB07092D4454086AC6EF59C9C4540446CB07092D445401E4E603AAD9F4540ACA8C1340CD745401E4E603AAD9F4540ACA8C1340CD7454086AC6EF59C9C4540446CB07092D4454086AC6EF59C9C4540
33122	Верхняя Балкария	8	77	1563	43.426186999999999	43.483392000000002	43.154693000000002	43.097434999999997	0103000020E610000001000000050000007C7DAD4B8DB645402D3E05C0788C45407C7DAD4B8DB64540C7F5EFFACC934540F392FFC9DFBD4540C7F5EFFACC934540F392FFC9DFBD45402D3E05C0788C45407C7DAD4B8DB645402D3E05C0788C4540
33144	Безенги	8	77	1563	43.275432000000002	43.295831999999997	43.220359999999999	43.209538999999999	0103000020E61000000100000005000000CD22145B41A34540471E882CD29A4540CD22145B41A345405CACA8C1349C45401D8EAED2DDA545405CACA8C1349C45401D8EAED2DDA54540471E882CD29A4540CD22145B41A34540471E882CD29A4540
52864	Бабугент	8	77	1563	43.534568999999998	43.562649999999998	43.282668000000001	43.261609999999997	0103000020E610000001000000050000004B3ACAC16CC445403D27BD6F7CA145404B3ACAC16CC4454018D00B772EA44540158C4AEA04C8454018D00B772EA44540158C4AEA04C845403D27BD6F7CA145404B3ACAC16CC445403D27BD6F7CA14540
33092	Аушигер	8	77	1563	43.712381000000001	43.758420000000001	43.412852999999998	43.375323999999999	0103000020E6100000010000000500000059A5F44C2FDB4540B3B3E89D0AB0454059A5F44C2FDB45401A87FA5DD8B44540F05014E813E145401A87FA5DD8B44540F05014E813E14540B3B3E89D0AB0454059A5F44C2FDB4540B3B3E89D0AB04540
52841	Яникой	8	77	1519	43.484712000000002	43.522917	43.554611000000001	43.529400000000003	0103000020E6100000010000000500000048FDF50A0BBE45404F401361C3C3454048FDF50A0BBE45403D80457EFDC64540DFC2BAF1EEC245403D80457EFDC64540DFC2BAF1EEC245404F401361C3C3454048FDF50A0BBE45404F401361C3C34540
52801	Шалушка	8	77	1519	43.533329000000002	43.601331000000002	43.541823999999998	43.518535999999997	0103000020E610000001000000050000001381EA1F44C445403AE63C635FC245401381EA1F44C445400D18247D5AC545401689096AF8CC45400D18247D5AC545401689096AF8CC45403AE63C635FC245401381EA1F44C445403AE63C635FC24540
52792	Чегем 2-й	8	77	1519	43.577714999999998	43.619253	43.59919	43.579020999999997	0103000020E610000001000000050000004EB4AB90F2C945403E59315C1DCA45404EB4AB90F2C945408D0B0742B2CC45409679ABAE43CF45408D0B0742B2CC45409679ABAE43CF45403E59315C1DCA45404EB4AB90F2C945403E59315C1DCA4540
33017	Чегем 1-й	8	77	1519	43.549669000000002	43.618488999999997	43.579047000000003	43.556204999999999	0103000020E610000001000000050000000150C58D5BC64540936FB6B931C745400150C58D5BC6454068EC4B361ECA4540C6F7C5A52ACF454068EC4B361ECA4540C6F7C5A52ACF4540936FB6B931C745400150C58D5BC64540936FB6B931C74540
57972	Хуштосырт	8	77	1519	43.230730999999999	43.244044000000002	43.443075	43.425963000000003	0103000020E610000001000000050000003196E997889D45402D27A1F485B645403196E997889D45406D567DAEB6B845407C6473D53C9F45406D567DAEB6B845407C6473D53C9F45402D27A1F485B645403196E997889D45402D27A1F485B64540
57951	Сельское поселение Звездный	8	77	1519	42.862313999999998	43.806793999999996	43.647297999999999	43.088396000000003	0103000020E6100000010000000500000004711E4E606E4540728C648F508B454004711E4E606E454013622EA9DAD24540F44D9A0645E7454013622EA9DAD24540F44D9A0645E74540728C648F508B454004711E4E606E4540728C648F508B4540
52790	Нижний Чегем	8	77	1519	43.282662999999999	43.310026000000001	43.510697	43.482047000000001	0103000020E6100000010000000500000006651A4D2EA44540451152B7B3BD454006651A4D2EA445402995F0845EC14540717495EEAEA745402995F0845EC14540717495EEAEA74540451152B7B3BD454006651A4D2EA44540451152B7B3BD4540
52814	Нартан	8	77	1519	43.670762000000003	43.738630000000001	43.533144999999998	43.491118999999998	0103000020E6100000010000000500000025B37A87DBD54540DCB8C5FCDCBE454025B37A87DBD54540518369183EC4454018EC866D8BDE4540518369183EC4454018EC866D8BDE4540DCB8C5FCDCBE454025B37A87DBD54540DCB8C5FCDCBE4540
52791	Лечинкай	8	77	1519	43.408597999999998	43.467742999999999	43.568818999999998	43.556739999999998	0103000020E61000000100000005000000029B73F04CB4454001309E4143C74540029B73F04CB44540F52B9D0FCFC845406AF7AB00DFBB4540F52B9D0FCFC845406AF7AB00DFBB454001309E4143C74540029B73F04CB4454001309E4143C74540
57948	Адиюх	8	77	1519	42.862313999999998	43.806793999999996	43.647297999999999	43.088396000000003	0103000020E6100000010000000500000004711E4E606E4540728C648F508B454004711E4E606E454013622EA9DAD24540F44D9A0645E7454013622EA9DAD24540F44D9A0645E74540728C648F508B454004711E4E606E4540728C648F508B4540
32900	Шитхала	8	77	1461	43.790695999999997	43.803102000000003	43.561967000000003	43.545397999999999	0103000020E61000000100000005000000FC89CA8635E54540E3A6069ACFC54540FC89CA8635E545403337DF88EEC7454015ADDC0BCCE645403337DF88EEC7454015ADDC0BCCE64540E3A6069ACFC54540FC89CA8635E54540E3A6069ACFC54540
16753	Черная Речка	8	77	1461	43.820870999999997	43.856856999999998	43.614752000000003	43.597676	0103000020E610000001000000050000000E9E094D12E9454053CDACA580CC45400E9E094D12E9454047938B31B0CE4540A12C7C7DADED454047938B31B0CE4540A12C7C7DADED454053CDACA580CC45400E9E094D12E9454053CDACA580CC4540
52372	Хатуей	8	77	1461	44.007773999999998	44.027582000000002	43.361567999999998	43.320962999999999	0103000020E610000001000000050000002AE109BDFE004640EF1CCA5015A945402AE109BDFE004640DBA337DC47AE4540A9FA95CE87034640DBA337DC47AE4540A9FA95CE87034640EF1CCA5015A945402AE109BDFE004640EF1CCA5015A94540
52374	Урух	8	77	1461	44.012948000000002	44.037965999999997	43.312455999999997	43.276058999999997	0103000020E610000001000000050000003946B247A80146401B62BCE655A345403946B247A801464030B8E68EFEA74540122EE411DC04464030B8E68EFEA74540122EE411DC0446401B62BCE655A345403946B247A80146401B62BCE655A34540
52741	Урвань	8	77	1461	43.749374000000003	43.775748	43.504165	43.474589999999999	0103000020E61000000100000005000000823CBB7CEBDF45401B81785DBFBC4540823CBB7CEBDF4540D8648D7A88C04540FDF7E0B54BE34540D8648D7A88C04540FDF7E0B54BE345401B81785DBFBC4540823CBB7CEBDF45401B81785DBFBC4540
52369	Ташлы-Тала	8	77	1461	43.685063	43.710287999999998	43.149498000000001	43.141604000000001	0103000020E610000001000000050000008E59F624B0D74540CC7D7214209245408E59F624B0D74540A1681EC022934540E15E99B7EADA4540A1681EC022934540E15E99B7EADA4540CC7D7214209245408E59F624B0D74540CC7D721420924540
52752	Старый Черек	8	77	1461	43.828541999999999	43.882728999999998	43.490079000000001	43.451720999999999	0103000020E6100000010000000500000064AE0CAA0DEA45404DF564FED1B9454064AE0CAA0DEA45406BBA9EE8BABE45408A1D8D43FDF045406BBA9EE8BABE45408A1D8D43FDF045404DF564FED1B9454064AE0CAA0DEA45404DF564FED1B94540
52762	Псынабо	8	77	1461	43.908374999999999	43.931283000000001	43.542490000000001	43.530112000000003	0103000020E6100000010000000500000083C0CAA145F44540CC9BC3B5DAC3454083C0CAA145F445401A34F44F70C545400F29064834F745401A34F44F70C545400F29064834F74540CC9BC3B5DAC3454083C0CAA145F44540CC9BC3B5DAC34540
52759	Псыкод	8	77	1461	43.989753999999998	44.000658999999999	43.608989000000001	43.599269	0103000020E61000000100000005000000E78A5242B0FE4540D940BAD8B4CC4540E78A5242B0FE4540D74FFF59F3CD45405AB9179815004640D74FFF59F3CD45405AB9179815004640D940BAD8B4CC4540E78A5242B0FE4540D940BAD8B4CC4540
52747	Псыгансу	8	77	1461	43.769235000000002	43.807423	43.435049999999997	43.391547000000003	0103000020E6100000010000000500000023F8DF4A76E2454068EC4B361EB2454023F8DF4A76E24540F90FE9B7AFB74540E48409A359E74540F90FE9B7AFB74540E48409A359E7454068EC4B361EB2454023F8DF4A76E2454068EC4B361EB24540
32932	Озрек	8	77	1461	44.009822	44.028714000000001	43.411785999999999	43.395235	0103000020E610000001000000050000000264E8D841014640069E7B0F97B245400264E8D841014640AF795567B5B44540FB777DE6AC034640AF795567B5B44540FB777DE6AC034640069E7B0F97B245400264E8D841014640069E7B0F97B24540
52755	Нижний Черек	8	77	1461	43.901727999999999	43.944605000000003	43.520294	43.498443999999999	0103000020E6100000010000000500000099F1B6D26BF3454097715303CDBF454099F1B6D26BF345400B2769FE98C24540AD510FD1E8F845400B2769FE98C24540AD510FD1E8F8454097715303CDBF454099F1B6D26BF3454097715303CDBF4540
57832	Нарткала	8	77	1461	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
32881	Морзох	8	77	1461	43.835279999999997	43.846868000000001	43.573357999999999	43.560777999999999	0103000020E610000001000000050000005E807D74EAEA45407C28D192C7C745405E807D74EAEA4540327381CB63C94540B403AE2B66EC4540327381CB63C94540B403AE2B66EC45407C28D192C7C745405E807D74EAEA45407C28D192C7C74540
52764	Кахун	8	77	1461	43.857126999999998	43.899267000000002	43.553055999999998	43.520693000000001	0103000020E6100000010000000500000061C26856B6ED4540C9207711A6C2454061C26856B6ED4540A46DFC89CAC645409FAF592E1BF34540A46DFC89CAC645409FAF592E1BF34540C9207711A6C2454061C26856B6ED4540C9207711A6C24540
32884	Ерокко	8	77	1461	43.869307999999997	43.888083000000002	43.325291999999997	43.30894	0103000020E6100000010000000500000059130B7C45EF45408F368E588BA7454059130B7C45EF454041D3122BA3A94540199128B4ACF1454041D3122BA3A94540199128B4ACF145408F368E588BA7454059130B7C45EF45408F368E588BA74540
52733	Герменчик	8	77	1461	43.744782999999998	43.788108999999999	43.598590000000002	43.577368	0103000020E61000000100000005000000F2CEA10C55DF4540E3E0D231E7C94540F2CEA10C55DF454038DBDC989ECC4540755776C1E0E4454038DBDC989ECC4540755776C1E0E44540E3E0D231E7C94540F2CEA10C55DF4540E3E0D231E7C94540
40382	Верхний Лескен	8	77	1461	43.729700999999999	43.750639999999997	43.222087999999999	43.211734	0103000020E61000000100000005000000E36DA5D766DD4540C3B986191A9B4540E36DA5D766DD4540C26A2C616D9C4540E388B5F814E04540C26A2C616D9C4540E388B5F814E04540C3B986191A9B4540E36DA5D766DD4540C3B986191A9B4540
52367	Аргудан	8	77	1461	43.880070000000003	43.934587999999998	43.437359999999998	43.396008000000002	0103000020E610000001000000050000006A183E22A6F04540297AE063B0B245406A183E22A6F045400E4A9869FBB74540F59D5F94A0F745400E4A9869FBB74540F59D5F94A0F74540297AE063B0B245406A183E22A6F04540297AE063B0B24540
52370	Анзорей	8	77	1461	43.91178	43.964215000000003	43.370488000000002	43.340394000000003	0103000020E61000000100000005000000CD920035B5F4454098E0D40792AB4540CD920035B5F44540BDC799266CAF454005A8A9656BFB4540BDC799266CAF454005A8A9656BFB454098E0D40792AB4540CD920035B5F4454098E0D40792AB4540
52722	Урожайное	8	77	1408	44.193896000000002	44.232576999999999	43.706597000000002	43.693021000000002	0103000020E61000000100000005000000A1698995D11846407A3881E9B4D84540A1698995D1184640D2393FC571DA4540A1664815C51D4640D2393FC571DA4540A1664815C51D46407A3881E9B4D84540A1698995D11846407A3881E9B4D84540
52726	Терекское	8	77	1408	44.289476999999998	44.319021999999997	43.681717999999996	43.665163	0103000020E61000000100000005000000DBF813950D2546402FC1A90F24D54540DBF813950D254640198C118942D745402D5A80B6D5284640198C118942D745402D5A80B6D52846402FC1A90F24D54540DBF813950D2546402FC1A90F24D54540
57819	Терек	8	77	1408	44.120790999999997	44.154747	43.499307000000002	43.459777000000003	0103000020E6100000010000000500000058535914760F4640FC3905F9D9BA454058535914760F4640FAD4B14AE9BF4540BA13ECBFCE134640FAD4B14AE9BF4540BA13ECBFCE134640FC3905F9D9BA454058535914760F4640FC3905F9D9BA4540
52696	Тамбовское	8	77	1408	44.201244000000003	44.216417	43.517358999999999	43.496135000000002	0103000020E610000001000000050000001442075DC219464053B3075A81BF45401442075DC219464048A5D8D138C2454033A6608DB31B464048A5D8D138C2454033A6608DB31B464053B3075A81BF45401442075DC219464053B3075A81BF4540
57974	Сельское поселение Нижний Курп	8	77	1408	44.070692000000001	44.475518000000001	43.730696999999999	43.350391999999999	0103000020E610000001000000050000005F0B7A6F0C094640D86322A5D9AC45405F0B7A6F0C0946408524B37A87DD4540655419C6DD3C46408524B37A87DD4540655419C6DD3C4640D86322A5D9AC45405F0B7A6F0C094640D86322A5D9AC4540
52681	Плановское	8	77	1408	44.182496	44.210496999999997	43.416356999999998	43.376719999999999	0103000020E610000001000000050000004ED367075C174640E3DF675C38B045404ED367075C174640F73AA92F4BB54540FB73D190F11A4640F73AA92F4BB54540FB73D190F11A4640E3DF675C38B045404ED367075C174640E3DF675C38B04540
32864	Новое Хамидие	8	77	1408	44.346680999999997	44.363793999999999	43.622413999999999	43.602428000000003	0103000020E610000001000000050000008192020B602C4640EC18575C1CCD45408192020B602C464049490F43ABCF4540923D42CD902E464049490F43ABCF4540923D42CD902E4640EC18575C1CCD45408192020B602C4640EC18575C1CCD4540
57966	Ново-Хамидие	8	77	1408	44.070692000000001	44.475518000000001	43.730696999999999	43.350391999999999	0103000020E610000001000000050000005F0B7A6F0C094640D86322A5D9AC45405F0B7A6F0C0946408524B37A87DD4540655419C6DD3C46408524B37A87DD4540655419C6DD3C4640D86322A5D9AC45405F0B7A6F0C094640D86322A5D9AC4540
32837	Новая Балкария	8	77	1408	44.163882999999998	44.183458000000002	43.657153999999998	43.645432999999997	0103000020E6100000010000000500000068AF3E1EFA1446402C616D8C9DD2454068AF3E1EFA144640C1374D9F1DD4454044183F8D7B174640C1374D9F1DD4454044183F8D7B1746402C616D8C9DD2454068AF3E1EFA1446402C616D8C9DD24540
52711	Красноармейское	8	77	1408	44.111699999999999	44.131489999999999	43.643853999999997	43.628163000000001	0103000020E610000001000000050000004A7B832F4C0E464054C72AA567D045404A7B832F4C0E46400BB3D0CE69D2454022E010AAD41046400BB3D0CE69D2454022E010AAD410464054C72AA567D045404A7B832F4C0E464054C72AA567D04540
40363	Интернациональное	8	77	1408	44.070692000000001	44.475518000000001	43.730696999999999	43.350391999999999	0103000020E610000001000000050000005F0B7A6F0C094640D86322A5D9AC45405F0B7A6F0C0946408524B37A87DD4540655419C6DD3C46408524B37A87DD4540655419C6DD3C4640D86322A5D9AC45405F0B7A6F0C094640D86322A5D9AC4540
32804	Инаркой	8	77	1408	44.400202999999998	44.417881999999999	43.570993999999999	43.540208999999997	0103000020E610000001000000050000006B6116DA393346409F008A9125C545406B6116DA393346402A1BD65416C9454025CB49287D3546402A1BD65416C9454025CB49287D3546409F008A9125C545406B6116DA393346409F008A9125C54540
52714	Джулат	8	77	1408	44.085811	44.094956000000003	43.617102000000003	43.612755	0103000020E610000001000000050000008B51D7DAFB0A4640F1BA7EC16ECE45408B51D7DAFB0A4640EA25C632FDCE45408D47A984270C4640EA25C632FDCE45408D47A984270C4640F1BA7EC16ECE45408B51D7DAFB0A4640F1BA7EC16ECE4540
52677	Дейское	8	77	1408	44.152636000000001	44.175111999999999	43.499222000000003	43.451740999999998	0103000020E610000001000000050000009C1892938913464094A12AA6D2B945409C18929389134640CCB8A981E6BF45408E91EC116A164640CCB8A981E6BF45408E91EC116A16464094A12AA6D2B945409C1892938913464094A12AA6D2B94540
52698	Верхний Курп	8	77	1408	44.353158000000001	44.387599999999999	43.500562000000002	43.456288999999998	0103000020E610000001000000050000000F290648342D464024438EAD67BA45400F290648342D464068CF656A12C04540FDF675E09C31464068CF656A12C04540FDF675E09C31464024438EAD67BA45400F290648342D464024438EAD67BA4540
52692	Верхний Акбаш	8	77	1408	44.219991999999998	44.247238000000003	43.487200999999999	43.458388999999997	0103000020E61000000100000005000000D9B0A6B2281C46404EECA17DACBA4540D9B0A6B2281C46400CCA349A5CBE45400B2AAA7EA51F46400CCA349A5CBE45400B2AAA7EA51F46404EECA17DACBA4540D9B0A6B2281C46404EECA17DACBA4540
52685	Белоглинское	8	77	1408	44.205745	44.217081999999998	43.463022000000002	43.451321999999998	0103000020E61000000100000005000000632827DA551A46408FFB56EBC4B94540632827DA551A46400DAA0D4E44BB45406F46CD57C91B46400DAA0D4E44BB45406F46CD57C91B46408FFB56EBC4B94540632827DA551A46408FFB56EBC4B94540
52705	Арик	8	77	1408	44.095889999999997	44.149231999999998	43.593764999999998	43.566074999999998	0103000020E61000000100000005000000B8019F1F460C4640A60A462575C84540B8019F1F460C46403541D47D00CC454022C2BF081A1346403541D47D00CC454022C2BF081A134640A60A462575C84540B8019F1F460C4640A60A462575C84540
13408	старая Солдатская	8	77	669	43.831829999999997	43.844487000000001	43.846411000000003	43.837587999999997	0103000020E6100000010000000500000074EACA6779EA4540D2C2651536EB454074EACA6779EA4540C2FC153257EC4540D672672618EC4540C2FC153257EC4540D672672618EC4540D2C2651536EB454074EACA6779EA4540D2C2651536EB4540
58011	сельское поселение Малакановское	8	77	669	43.639195000000001	44.419220000000003	44.019671000000002	43.636096999999999	0103000020E6100000010000000500000024624A24D1D14540B70A62A06BD1454024624A24D1D14540FED64E948402464021EA3E00A9354640FED64E948402464021EA3E00A9354640B70A62A06BD1454024624A24D1D14540B70A62A06BD14540
57968	Янтарное	8	77	669	43.868895000000002	43.893453999999998	43.766025999999997	43.752130999999999	0103000020E6100000010000000500000037548CF337EF454065A71FD445E0454037548CF337EF45405EF1D4230DE245407D3D5FB35CF245405EF1D4230DE245407D3D5FB35CF2454065A71FD445E0454037548CF337EF454065A71FD445E04540
57985	Черниговское	8	77	669	43.838379000000003	43.863945000000001	43.769371999999997	43.756174999999999	0103000020E610000001000000050000009C53C90050EB4540C286A757CAE045409C53C90050EB4540A33A1DC87AE245407845F0BF95EE4540A33A1DC87AE245407845F0BF95EE4540C286A757CAE045409C53C90050EB4540C286A757CAE04540
57973	Учебный	8	77	669	43.922379999999997	43.933554999999998	43.781336000000003	43.772495999999997	0103000020E61000000100000005000000033E3F8C10F6454039252026E1E24540033E3F8C10F64540FF976BD102E445403602F1BA7EF74540FF976BD102E445403602F1BA7EF7454039252026E1E24540033E3F8C10F6454039252026E1E24540
57997	Ульяновское	8	77	669	44.106400000000001	44.122281999999998	43.883912000000002	43.872377999999998	0103000020E61000000100000005000000AF25E4839E0D4640FCDF1115AAEF4540AF25E4839E0D46405F45460724F14540DA71C3EFA60F46405F45460724F14540DA71C3EFA60F4640FCDF1115AAEF4540AF25E4839E0D4640FCDF1115AAEF4540
57844	Солдатская	8	77	669	43.796894999999999	43.847011999999999	43.822916999999997	43.798366000000001	0103000020E6100000010000000500000047ACC5A700E64540821E6ADB30E6454047ACC5A700E645404529215855E94540E7A8A3E36AEC45404529215855E94540E7A8A3E36AEC4540821E6ADB30E6454047ACC5A700E64540821E6ADB30E64540
57940	Солдатская	8	77	669	43.831829999999997	43.844487000000001	43.846411000000003	43.837587999999997	0103000020E6100000010000000500000074EACA6779EA4540D2C2651536EB454074EACA6779EA4540C2FC153257EC4540D672672618EC4540C2FC153257EC4540D672672618EC4540D2C2651536EB454074EACA6779EA4540D2C2651536EB4540
48293	Саратовский	8	77	669	43.767924000000001	43.788773999999997	43.735517999999999	43.725610000000003	0103000020E6100000010000000500000021E868554BE2454046D3D9C9E0DC454021E868554BE2454046CF2D7425DE4540B1F7E28BF6E4454046CF2D7425DE4540B1F7E28BF6E4454046D3D9C9E0DC454021E868554BE2454046D3D9C9E0DC4540
57991	Псыншоко	8	77	669	43.707197999999998	43.722836999999998	43.760497999999998	43.752938999999998	0103000020E61000000100000005000000F7E5CC7685DA454004711E4E60E04540F7E5CC7685DA454032569BFF57E145405CAB3DEC85DC454032569BFF57E145405CAB3DEC85DC454004711E4E60E04540F7E5CC7685DA454004711E4E60E04540
14545	Прохладный	8	77	669	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
57964	Пролетарское	8	77	669	44.014242000000003	44.068553999999999	43.857104999999997	43.841366000000001	0103000020E61000000100000005000000651D8EAED2014640B1FB8EE1B1EB4540651D8EAED2014640791EDC9DB5ED45404701A260C6084640791EDC9DB5ED45404701A260C6084640B1FB8EE1B1EB4540651D8EAED2014640B1FB8EE1B1EB4540
57947	Прималкинское	8	77	669	43.989950999999998	44.025606000000003	43.753219000000001	43.738858999999998	0103000020E610000001000000050000003DD2E0B6B6FE454079AD84EE92DE45403DD2E0B6B6FE4540E8DCED7A69E045406B4AB20E47034640E8DCED7A69E045406B4AB20E4703464079AD84EE92DE45403DD2E0B6B6FE454079AD84EE92DE4540
8924	Приближная	8	77	669	44.108601	44.138325999999999	43.779246000000001	43.759729999999998	0103000020E610000001000000050000000DA837A3E60D464021E527D53EE145400DA837A3E60D4640F8C43A55BEE34540DF1797AAB4114640F8C43A55BEE34540DF1797AAB411464021E527D53EE145400DA837A3E60D464021E527D53EE14540
57970	Новополтавское	8	77	669	43.948538999999997	43.988568000000001	43.698307	43.685139999999997	0103000020E6100000010000000500000082FDD7B969F945403997E2AAB2D7454082FDD7B969F94540B0C8AF1F62D94540A2EF6E6589FE4540B0C8AF1F62D94540A2EF6E6589FE45403997E2AAB2D7454082FDD7B969F945403997E2AAB2D74540
57963	Новопокровский	8	77	669	44.034067999999998	44.046940999999997	43.744160000000001	43.735523999999998	0103000020E6100000010000000500000089EB18575C04464028B682A625DE454089EB18575C044640E57E87A240DF4540B7EBA52902064640E57E87A240DF4540B7EBA5290206464028B682A625DE454089EB18575C04464028B682A625DE4540
57965	Лесное	8	77	669	43.881371999999999	43.905949999999997	43.782032000000001	43.769176000000002	0103000020E6100000010000000500000018CE35CCD0F045401E6FF25B74E2454018CE35CCD0F045407636E49F19E44540D5E76A2BF6F345407636E49F19E44540D5E76A2BF6F345401E6FF25B74E2454018CE35CCD0F045401E6FF25B74E24540
57955	Красносельское	8	77	669	44.024591000000001	44.043751999999998	43.941727999999998	43.927570000000003	0103000020E61000000100000005000000526342CC2503464018601F9DBAF64540526342CC250346401EDD088B8AF845403A9160AA990546401EDD088B8AF845403A9160AA9905464018601F9DBAF64540526342CC2503464018601F9DBAF64540
57989	Комсомольское	8	77	669	43.922739999999997	43.943112999999997	43.865769	43.859217000000001	0103000020E61000000100000005000000035B25581CF64540689599D2FAED4540035B25581CF645400072C284D1EE45405AB741EDB7F845400072C284D1EE45405AB741EDB7F84540689599D2FAED4540035B25581CF64540689599D2FAED4540
57939	Карагач	8	77	669	43.750335	43.802042	43.812750000000001	43.793335999999996	0103000020E61000000100000005000000A7052FFA0AE04540A65EB7088CE54540A7052FFA0AE0454079E9263108E845405C02F04FA9E6454079E9263108E845405C02F04FA9E64540A65EB7088CE54540A7052FFA0AE04540A65EB7088CE54540
57977	Заречное	8	77	669	43.849724000000002	43.862948000000003	43.941572999999998	43.929679999999998	0103000020E610000001000000050000002B508BC1C3EC454065DF15C1FFF645402B508BC1C3EC4540F7E5CC7685F8454006137F1475EE4540F7E5CC7685F8454006137F1475EE454065DF15C1FFF645402B508BC1C3EC454065DF15C1FFF64540
12835	Екатериноградская	8	77	669	44.210155999999998	44.247211	43.779474	43.751792999999999	0103000020E6100000010000000500000072874D64E61A46404D2EC6C03AE0454072874D64E61A4640890AD5CDC5E34540111B2C9CA41F4640890AD5CDC5E34540111B2C9CA41F46404D2EC6C03AE0454072874D64E61A46404D2EC6C03AE04540
57975	Дальное	8	77	669	44.278877000000001	44.403185999999998	44.009338	43.921292000000001	0103000020E61000000100000005000000A54DD53DB2234640810871E5ECF54540A54DD53DB2234640164ED2FC310146403F1A4E999B334640164ED2FC310146403F1A4E999B334640810871E5ECF54540A54DD53DB2234640810871E5ECF54540
57998	Граничное	8	77	669	44.025354	44.042825999999998	43.960451999999997	43.948594999999997	0103000020E610000001000000050000005169C4CC3E03464016139B8F6BF945405169C4CC3E0346405BB05417F0FA454091B586527B0546405BB05417F0FA454091B586527B05464016139B8F6BF945405169C4CC3E03464016139B8F6BF94540
13777	Грабовец	8	77	669	43.732987999999999	43.750585999999998	43.679259999999999	43.673496	0103000020E61000000100000005000000232E008DD2DD454050FEEE1D35D64540232E008DD2DD454090BDDEFDF1D64540F06AB93313E0454090BDDEFDF1D64540F06AB93313E0454050FEEE1D35D64540232E008DD2DD454050FEEE1D35D64540
57986	Гвардейское	8	77	669	44.099797000000002	44.116030000000002	43.928731999999997	43.919383000000003	0103000020E61000000100000005000000959EE925C60C4640CBBF9657AEF54540959EE925C60C4640D45FAFB0E0F645406DAD2F12DA0E4640D45FAFB0E0F645406DAD2F12DA0E4640CBBF9657AEF54540959EE925C60C4640CBBF9657AEF54540
57982	Виноградное	8	77	669	44.095396000000001	44.126944999999999	43.851930000000003	43.838687	0103000020E61000000100000005000000A915A6EF350C4640494A7A185AEB4540A915A6EF350C46409B3DD00A0CED454003B2D7BB3F1046409B3DD00A0CED454003B2D7BB3F104640494A7A185AEB4540A915A6EF350C4640494A7A185AEB4540
57967	Благовещенка	8	77	669	43.759821000000002	43.773718000000002	43.692722000000003	43.688563000000002	0103000020E6100000010000000500000032E884D041E145402A1E17D522D8454032E884D041E14540209C4F1DABD84540CC29013109E34540209C4F1DABD84540CC29013109E345402A1E17D522D8454032E884D041E145402A1E17D522D84540
57956	Алтуд	8	77	669	43.846580000000003	43.896966999999997	43.731530999999997	43.702759	0103000020E610000001000000050000004EB9C2BB5CEC45401EFCC401F4D945404EB9C2BB5CEC45404D81CCCEA2DD4540AD4B8DD0CFF245404D81CCCEA2DD4540AD4B8DD0CFF245401EFCC401F4D945404EB9C2BB5CEC45401EFCC401F4D94540
57950	Нальчик	8	77	969	43.468083999999998	43.693651000000003	43.547089999999997	43.421064999999999	0103000020E61000000100000005000000F3E32F2DEABB4540C03E3A75E5B54540F3E32F2DEABB4540FCFB8C0B07C645403AEB538EC9D84540FCFB8C0B07C645403AEB538EC9D84540C03E3A75E5B54540F3E32F2DEABB4540C03E3A75E5B54540
57938	Нальчик	8	77	969	43.468083999999998	43.693651000000003	43.547089999999997	43.421064999999999	0103000020E61000000100000005000000F3E32F2DEABB4540C03E3A75E5B54540F3E32F2DEABB4540FCFB8C0B07C645403AEB538EC9D84540FCFB8C0B07C645403AEB538EC9D84540C03E3A75E5B54540F3E32F2DEABB4540C03E3A75E5B54540
40233	станция Котляревская	8	77	346	44.065939999999998	44.066192000000001	43.621637	43.619875	0103000020E61000000100000005000000C6BFCFB870084640D34D621058CF4540C6BFCFB870084640E57D1CCD91CF4540E0A0BDFA78084640E57D1CCD91CF4540E0A0BDFA78084640D34D621058CF4540C6BFCFB870084640D34D621058CF4540
7785	Сарский	8	77	346	44.088326000000002	44.111862000000002	43.723531999999999	43.713569999999997	0103000020E6100000010000000500000079B130444E0B46400FB4024356DB454079B130444E0B464003CE52B29CDC454024D5777E510E464003CE52B29CDC454024D5777E510E46400FB4024356DB454079B130444E0B46400FB4024356DB4540
45731	Новоивановское	8	77	346	43.934821999999997	43.979962	43.646515999999998	43.633865999999998	0103000020E6100000010000000500000068CA4E3FA8F74540EE05668522D1454068CA4E3FA8F745409D2B4A09C1D2454050A912656FFD45409D2B4A09C1D2454050A912656FFD4540EE05668522D1454068CA4E3FA8F74540EE05668522D14540
1725	Майский	8	77	346	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
57983	Колдрасинский	8	77	346	43.916316999999999	43.929251999999998	43.624384999999997	43.615222000000003	0103000020E6100000010000000500000069E21DE049F54540CEE33098BFCE454069E21DE049F54540758E01D9EBCF45400DDFC2BAF1F64540758E01D9EBCF45400DDFC2BAF1F64540CEE33098BFCE454069E21DE049F54540CEE33098BFCE4540
57850	Второй Лескен	8	77	7451	43.896248	43.925192000000003	43.365763000000001	43.337744999999998	0103000020E610000001000000050000007E8D2441B8F245409AB1683A3BAB45407E8D2441B8F245401E8B6D52D1AE4540AB4203B16CF645401E8B6D52D1AE4540AB4203B16CF645409AB1683A3BAB45407E8D2441B8F245409AB1683A3BAB4540
32651	Этоко	8	77	774	43.162593999999999	43.186013000000003	43.948258000000003	43.943019999999997	0103000020E610000001000000050000004E4354E1CF944540A9BC1DE1B4F845404E4354E1CF944540CF15A58460F94540C0D02346CF974540CF15A58460F94540C0D02346CF974540A9BC1DE1B4F845404E4354E1CF944540A9BC1DE1B4F84540
57960	Шардаково	8	77	774	43.077407000000001	43.130605000000003	43.886192000000001	43.870071000000003	0103000020E61000000100000005000000A1BDFA78E889454059198D7C5EEF4540A1BDFA78E889454009FD4CBD6EF14540D8D825AAB790454009FD4CBD6EF14540D8D825AAB790454059198D7C5EEF4540A1BDFA78E889454059198D7C5EEF4540
32800	Хабаз	8	77	774	42.908811	42.954005000000002	43.733823999999998	43.723668000000004	0103000020E610000001000000050000005E9F39EB53744540B4942C27A1DC45405E9F39EB537445408C82E0F1EDDD4540399CF9D51C7A45408C82E0F1EDDD4540399CF9D51C7A4540B4942C27A1DC45405E9F39EB53744540B4942C27A1DC4540
32788	Совхозное	8	77	774	43.139606000000001	43.155192	43.810141999999999	43.793576999999999	0103000020E61000000100000005000000A629029CDE914540CCED5EEE93E54540A629029CDE914540DA8EA9BBB2E74540E84CDA54DD934540DA8EA9BBB2E74540E84CDA54DD934540CCED5EEE93E54540A629029CDE914540CCED5EEE93E54540
57957	Сельское поселение Камлюково	8	77	774	42.404766000000002	43.418999999999997	43.960296	43.345796	0103000020E6100000010000000500000031444E5FCF334540378B170B43AC454031444E5FCF334540643DB5FAEAFA45401283C0CAA1B54540643DB5FAEAFA45401283C0CAA1B54540378B170B43AC454031444E5FCF334540378B170B43AC4540
52314	Светловодское	8	77	774	43.159432000000002	43.215676000000002	43.901522999999997	43.885789000000003	0103000020E61000000100000005000000CBF78C44689445400A14B18861F14540CBF78C4468944540C0CB0C1B65F345401C446B459B9B4540C0CB0C1B65F345401C446B459B9B45400A14B18861F14540CBF78C44689445400A14B18861F14540
32710	Сармаково	8	77	774	43.156674000000002	43.240684999999999	43.755822999999999	43.721434000000002	0103000020E610000001000000050000001711C5E40D9445407A1C06F357DC45401711C5E40D9445404548DDCEBEE04540A2D11DC4CE9E45404548DDCEBEE04540A2D11DC4CE9E45407A1C06F357DC45401711C5E40D9445407A1C06F357DC4540
57959	Псынодаха	8	77	774	43.223562999999999	43.266817000000003	43.866757	43.853529000000002	0103000020E610000001000000050000003ECC5EB69D9C45400398327040ED45403ECC5EB69D9C45401F4AB4E4F1EE45402882380F27A245401F4AB4E4F1EE45402882380F27A245400398327040ED45403ECC5EB69D9C45400398327040ED4540
32730	Приречное	8	77	774	43.290953999999999	43.318479000000004	43.813225000000003	43.790154000000001	0103000020E61000000100000005000000F8510DFB3DA54540DC662AC423E54540F8510DFB3DA5454012A5BDC117E845403DBB7CEBC3A8454012A5BDC117E845403DBB7CEBC3A84540DC662AC423E54540F8510DFB3DA54540DC662AC423E54540
57971	Октябрьское	8	77	774	43.137019000000002	43.167661000000003	43.896470000000001	43.887712999999998	0103000020E610000001000000050000001FF7ADD689914540F59D5F94A0F145401FF7ADD6899145402DEC6987BFF2454047E867EA759545402DEC6987BFF2454047E867EA75954540F59D5F94A0F145401FF7ADD689914540F59D5F94A0F14540
52335	Малка	8	77	774	43.281567000000003	43.363169999999997	43.823925000000003	43.772854000000002	0103000020E61000000100000005000000015130630AA44540994A3FE1ECE24540015130630AA44540ACADD85F76E94540B471C45A7CAE4540ACADD85F76E94540B471C45A7CAE4540994A3FE1ECE24540015130630AA44540994A3FE1ECE24540
52362	Кичмалка	8	77	774	42.920228999999999	42.966572999999997	43.802101	43.782330999999999	0103000020E6100000010000000500000057EA5910CA754540D0D2156C23E4454057EA5910CA754540618BDD3EABE645402A1900AAB87B4540618BDD3EABE645402A1900AAB87B4540D0D2156C23E4454057EA5910CA754540D0D2156C23E44540
32726	Каменномостское	8	77	774	43.016222999999997	43.086435000000002	43.745260999999999	43.724345999999997	0103000020E61000000100000005000000B438639813824540847EA65EB7DC4540B438639813824540FCFD62B664DF4540691D554D108B4540FCFD62B664DF4540691D554D108B4540847EA65EB7DC4540B438639813824540847EA65EB7DC4540
32708	Зольское	8	77	774	43.187846	43.216385000000002	43.849361999999999	43.830779999999997	0103000020E610000001000000050000009B5775560B984540DF15C1FF56EA45409B5775560B9845408A3BDEE4B7EC4540282CF180B29B45408A3BDEE4B7EC4540282CF180B29B4540DF15C1FF56EA45409B5775560B984540DF15C1FF56EA4540
57849	Залукокоаже	8	77	774	43.202668000000003	43.233831000000002	43.907674	43.893442	0103000020E610000001000000050000000EF96706F1994540B96FB54E5CF245400EF96706F1994540FAB660A92EF445403FE5982CEE9D4540FAB660A92EF445403FE5982CEE9D4540B96FB54E5CF245400EF96706F1994540B96FB54E5CF24540
52324	Залукодес	8	77	774	43.133893	43.173931000000003	43.839838	43.820737999999999	0103000020E61000000100000005000000E814E46723914540CF4A5AF10DE94540E814E4672391454012F8C3CF7FEB45405B61FA5E4396454012F8C3CF7FEB45405B61FA5E43964540CF4A5AF10DE94540E814E46723914540CF4A5AF10DE94540
52319	Дженал	8	77	774	43.104661999999998	43.118828000000001	43.829245	43.818292	0103000020E6100000010000000500000025917D90658D45400A4AD1CABDE8454025917D90658D45408EAF3DB324EA4540AFEC82C1358F45408EAF3DB324EA4540AFEC82C1358F45400A4AD1CABDE8454025917D90658D45400A4AD1CABDE84540
40234	Белокаменское	8	77	774	43.010482000000003	43.034602	43.885931999999997	43.877693999999998	0103000020E610000001000000050000002D996379578145409DF2E84658F045402D996379578145406C3D433866F1454027309DD66D8445406C3D433866F1454027309DD66D8445409DF2E84658F045402D996379578145409DF2E84658F04540
32748	Псычох	8	77	533	43.519494999999999	43.529673000000003	43.720723999999997	43.712806999999998	0103000020E61000000100000005000000BFB7E9CF7EC2454010AE80423DDB4540BFB7E9CF7EC245409DB81CAF40DC454080492A53CCC345409DB81CAF40DC454080492A53CCC3454010AE80423DDB4540BFB7E9CF7EC2454010AE80423DDB4540
32740	Псыхурей	8	77	533	43.539878000000002	43.597324999999998	43.843263999999998	43.830669	0103000020E610000001000000050000003AEAE8B81AC5454088669E5C53EA45403AEAE8B81AC5454073F22213F0EB4540A60A462575CC454073F22213F0EB4540A60A462575CC454088669E5C53EA45403AEAE8B81AC5454088669E5C53EA4540
52275	Нижний Куркужин	8	77	533	43.305157000000001	43.386868	43.777521	43.701475000000002	0103000020E610000001000000050000009F9273620FA7454016FBCBEEC9D945409F9273620FA74540037AE1CE85E3454039EFFFE384B14540037AE1CE85E3454039EFFFE384B1454016FBCBEEC9D945409F9273620FA7454016FBCBEEC9D94540
32588	Лашкута	8	77	533	43.198059999999998	43.225234	43.563423	43.545547999999997	0103000020E61000000100000005000000A852B3075A994540F8325184D4C54540A852B3075A9945403868AF3E1EC8454040F9BB77D49C45403868AF3E1EC8454040F9BB77D49C4540F8325184D4C54540A852B3075A994540F8325184D4C54540
32700	Куба-Таба	8	77	533	43.414706000000002	43.468848000000001	43.786028000000002	43.767691999999997	0103000020E610000001000000050000003DBA111615B545404EB340BB43E245403DBA111615B54540C2DEC4909CE44540C365153603BC4540C2DEC4909CE44540C365153603BC45404EB340BB43E245403DBA111615B545404EB340BB43E24540
32759	Куба	8	77	533	43.427247000000001	43.480454000000002	43.864500999999997	43.853341	0103000020E6100000010000000500000035289A07B0B6454000AB23473AED454035289A07B0B64540FD2D01F8A7EE4540BF9D44847FBD4540FD2D01F8A7EE4540BF9D44847FBD454000AB23473AED454035289A07B0B6454000AB23473AED4540
52293	Кременчуг-Константиновское	8	77	533	43.618875000000003	43.674759999999999	43.802171999999999	43.781986000000003	0103000020E61000000100000005000000F0A7C64B37CF454006F7031E18E44540F0A7C64B37CF45402AE27492ADE64540115322895ED645402AE27492ADE64540115322895ED6454006F7031E18E44540F0A7C64B37CF454006F7031E18E44540
32705	Кишпек	8	77	533	43.618121000000002	43.673394000000002	43.653520999999998	43.642184	0103000020E6100000010000000500000044FCC3961ECF4540DA01D71533D2454044FCC3961ECF4540E61F7D93A6D345404CA94BC631D64540E61F7D93A6D345404CA94BC631D64540DA01D71533D2454044FCC3961ECF4540DA01D71533D24540
52250	Исламей	8	77	533	43.408436000000002	43.493453000000002	43.683464999999998	43.660753999999997	0103000020E6100000010000000500000029417FA147B44540C0594A9693D4454029417FA147B44540F67AF7C77BD745407A8EC87729BF4540F67AF7C77BD745407A8EC87729BF4540C0594A9693D4454029417FA147B44540C0594A9693D44540
52257	Заюково	8	77	533	43.262891000000003	43.377488999999997	43.641095	43.597734000000003	0103000020E61000000100000005000000D5B48B69A6A1454088DA368C82CC4540D5B48B69A6A145408750A5660FD24540C4CC3E8F51B045408750A5660FD24540C4CC3E8F51B0454088DA368C82CC4540D5B48B69A6A1454088DA368C82CC4540
32681	Жанхотеко	8	77	533	43.198751000000001	43.224192000000002	43.571882000000002	43.553486999999997	0103000020E610000001000000050000000E863AAC709945406DE179A9D8C645400E863AAC70994540E695EB6D33C945402E03CE52B29C4540E695EB6D33C945402E03CE52B29C45406DE179A9D8C645400E863AAC709945406DE179A9D8C64540
33139	Верхний Куркужин	8	77	533	43.24868	43.309370000000001	43.708655999999998	43.676737000000003	0103000020E61000000100000005000000AB9509BFD49F4540207F69519FD64540AB9509BFD49F45409D0E643DB5DA4540882EA86F99A745409D0E643DB5DA4540882EA86F99A74540207F69519FD64540AB9509BFD49F4540207F69519FD64540
52263	Баксаненок	8	77	533	43.624589	43.685476999999999	43.691977999999999	43.677415000000003	0103000020E610000001000000050000007E384888F2CF4540F168E388B5D645407E384888F2CF454097C62FBC92D845408194D8B5BDD7454097C62FBC92D845408194D8B5BDD74540F168E388B5D645407E384888F2CF4540F168E388B5D64540
3280	Баксан	8	77	533	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
52269	Атажукино	8	77	533	43.379258999999998	43.418847999999997	43.659678	43.629787999999998	0103000020E6100000010000000500000059DB148F8BB04540E5B4A7E49CD0454059DB148F8BB0454002F2255470D445405CFFAECF9CB5454002F2255470D445405CFFAECF9CB54540E5B4A7E49CD0454059DB148F8BB04540E5B4A7E49CD04540
57730	Малгобек	8	76	\N	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
52961	Чемульга	8	76	719	45.112855000000003	45.137262	43.194693999999998	43.170430000000003	0103000020E6100000010000000500000055185B08728E4640EF2076A6D095454055185B08728E46401C5DA5BBEB984540E57D1CCD919146401C5DA5BBEB984540E57D1CCD91914640EF2076A6D095454055185B08728E4640EF2076A6D0954540
52932	Троицкая	8	76	719	44.950879	45.023876000000001	43.320019000000002	43.291822000000003	0103000020E6100000010000000500000002BA2F67B67946406D205D6C5AA5454002BA2F67B6794640A08CF161F6A845406494675E0E834640A08CF161F6A845406494675E0E8346406D205D6C5AA5454002BA2F67B67946406D205D6C5AA54540
57736	Орджоникидзевская	8	76	719	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
52940	Нестеровская	8	76	719	45.022080000000003	45.071595000000002	43.250309999999999	43.218631999999999	0103000020E61000000100000005000000A6F27684D3824640F6ED2422FC9B4540A6F27684D38246404EEE77280AA0454050C763062A8946404EEE77280AA0454050C763062A894640F6ED2422FC9B4540A6F27684D3824640F6ED2422FC9B4540
5003	Карабулак	8	76	719	44.875923999999998	44.942588000000001	43.317244000000002	43.293981000000002	0103000020E6100000010000000500000008E412471E7046409C525E2BA1A5454008E412471E704640166D8E739BA8454010CD3CB9A6784640166D8E739BA8454010CD3CB9A67846409C525E2BA1A5454008E412471E7046409C525E2BA1A54540
57740	Даттых	8	76	719	45.092013999999999	45.107447000000001	43.033678000000002	43.027009	0103000020E610000001000000050000001763601DC78B46404DD9E907758345401763601DC78B46401F4C8A8F4F844540D386C3D2C08D46401F4C8A8F4F844540D386C3D2C08D46404DD9E907758345401763601DC78B46404DD9E90775834540
32554	Галашки	8	76	719	44.975251	44.995409000000002	43.125498999999998	43.066270000000003	0103000020E6100000010000000500000016325706D57C46405C5A0D897B88454016325706D57C46402157EA59109045407192E68F697F46402157EA59109045407192E68F697F46405C5A0D897B88454016325706D57C46405C5A0D897B884540
52956	Верхний Алкун	8	76	719	45.017409000000001	45.026688	42.972335000000001	42.961911999999998	0103000020E61000000100000005000000FAD346753A824640A2D0B2EE1F7B4540FAD346753A824640CAE02879757C45400B992B836A834640CAE02879757C45400B992B836A834640A2D0B2EE1F7B4540FAD346753A824640A2D0B2EE1F7B4540
57743	Берд-Юрт	8	76	719	44.833694000000001	45.277524999999997	43.521791	42.823905000000003	0103000020E610000001000000050000008B6F287CB66A4640650113B8756945408B6F287CB66A46406F2C280CCAC2454044696FF085A346406F2C280CCAC2454044696FF085A34640650113B8756945408B6F287CB66A4640650113B875694540
57733	Яндырка	8	76	762	44.896388000000002	44.933999999999997	43.289768000000002	43.252845000000001	0103000020E6100000010000000500000070438CD7BC72464083FA96395DA0454070438CD7BC724640B3B6291E17A54540643BDF4F8D774640B3B6291E17A54540643BDF4F8D77464083FA96395DA0454070438CD7BC72464083FA96395DA04540
9289	Экажево	8	76	762	44.806502000000002	44.836973	43.223067	43.188009000000001	0103000020E610000001000000050000004D1421753B674640452DCDAD109845404D1421753B6746408EE89E758D9C4540485167EE216B46408EE89E758D9C4540485167EE216B4640452DCDAD109845404D1421753B674640452DCDAD10984540
32980	Сурхахи	8	76	762	44.884816999999998	44.928106999999997	43.201338	43.168469999999999	0103000020E61000000100000005000000F0F8F6AE41714640B62DCA6C90954540F0F8F6AE4171464095B88E71C59945402618CE35CC76464095B88E71C59945402618CE35CC764640B62DCA6C90954540F0F8F6AE41714640B62DCA6C90954540
52894	Плиево	8	76	762	44.816411000000002	44.859997	43.295181999999997	43.265667000000001	0103000020E610000001000000050000001E8CD827806846402F50526001A245401E8CD82780684640162F1686C8A545403DD4B661146E4640162F1686C8A545403DD4B661146E46402F50526001A245401E8CD827806846402F50526001A24540
52651	Ольгети	8	76	762	44.753788999999998	44.760212000000003	42.803865000000002	42.795391000000002	0103000020E61000000100000005000000D28A6F287C60464031444E5FCF654540D28A6F287C60464014B35E0CE56645406D0377A04E61464014B35E0CE56645406D0377A04E61464031444E5FCF654540D28A6F287C60464031444E5FCF654540
57731	Насыр Корт	8	76	762	44.795712999999999	44.815243000000002	43.221943000000003	43.190900999999997	0103000020E61000000100000005000000430070ECD965464008E3A7716F984540430070ECD9654640BF49D3A0689C45407FA5F3E159684640BF49D3A0689C45407FA5F3E15968464008E3A7716F984540430070ECD965464008E3A7716F984540
7390	Назрань	8	76	762	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
5358	Магас	8	76	762	44.810527	44.822806999999997	43.177549999999997	43.168595000000003	0103000020E6100000010000000500000033C34659BF67464073A25D859495454033C34659BF674640D0B359F5B9964540BEF561BD51694640D0B359F5B9964540BEF561BD5169464073A25D859495454033C34659BF67464073A25D8594954540
52647	Ляжги	8	76	762	44.726112000000001	44.739469999999997	42.810771000000003	42.806061	0103000020E61000000100000005000000D89DEE3CF15C464060CAC0012D674540D89DEE3CF15C4640CAC51858C7674540C22FF5F3A65E4640CAC51858C7674540C22FF5F3A65E464060CAC0012D674540D89DEE3CF15C464060CAC0012D674540
52857	Кантышево	8	76	762	44.597464000000002	44.678142000000001	43.242483	43.210807000000003	0103000020E61000000100000005000000C8444AB3794C46404A6249B9FB9A4540C8444AB3794C4640016BD5AE099F4540A305685BCD564640016BD5AE099F4540A305685BCD5646404A6249B9FB9A4540C8444AB3794C46404A6249B9FB9A4540
33110	Гули	8	76	762	44.791339000000001	44.805765000000001	42.813462000000001	42.808072000000003	0103000020E610000001000000050000005186AA984A6546401B683EE76E6745405186AA984A654640F644D7851F68454077A1B94E23674640F644D7851F68454077A1B94E236746401B683EE76E6745405186AA984A6546401B683EE76E674540
57737	Гамурзиево	8	76	762	44.767425000000003	44.817523999999999	43.254945999999997	43.197014000000003	0103000020E6100000010000000500000000917EFB3A624640556D37C13799454000917EFB3A6246407D1F0E12A2A04540F9D85DA0A46846407D1F0E12A2A04540F9D85DA0A4684640556D37C13799454000917EFB3A624640556D37C137994540
60643	Гайрбек-Юрт	8	76	762	44.590403000000002	44.601515999999997	43.403042999999997	43.397455000000001	0103000020E61000000100000005000000EB3A5453924B4640DB5031CEDFB24540EB3A5453924B4640DCF0BBE996B34540A702EE79FE4C4640DCF0BBE996B34540A702EE79FE4C4640DB5031CEDFB24540EB3A5453924B4640DB5031CEDFB24540
32968	Гази-Юрт	8	76	762	44.830469000000001	44.848731999999998	43.266756999999998	43.253613000000001	0103000020E61000000100000005000000C1ABE5CE4C6A4640946B0A6476A04540C1ABE5CE4C6A4640527DE71725A24540CA880B40A36C4640527DE71725A24540CA880B40A36C4640946B0A6476A04540C1ABE5CE4C6A4640946B0A6476A04540
52649	Бейни	8	76	762	44.712879999999998	44.721215999999998	42.837062000000003	42.831316999999999	0103000020E610000001000000050000007AFCDEA63F5B4640EECD6F98686A45407AFCDEA63F5B4640B85CFDD8246B45400CAD4ECE505C4640B85CFDD8246B45400CAD4ECE505C4640EECD6F98686A45407AFCDEA63F5B4640EECD6F98686A4540
33062	Барсуки	8	76	762	44.794500999999997	44.827145000000002	43.272258000000001	43.250317000000003	0103000020E61000000100000005000000D4D17135B2654640015130630AA04540D4D17135B26546408509A359D9A2454064062AE3DF6946408509A359D9A2454064062AE3DF694640015130630AA04540D4D17135B2654640015130630AA04540
57739	Альтиево	8	76	762	44.763635000000001	44.797142000000001	43.245885000000001	43.227291000000001	0103000020E610000001000000050000005D8AABCABE6146406BD619DF179D45405D8AABCABE614640DAC9E028799F45404F22C2BF08664640DAC9E028799F45404F22C2BF086646406BD619DF179D45405D8AABCABE6146406BD619DF179D4540
52853	Али-Юрт	8	76	762	44.84442	44.863500000000002	43.152766	43.130775999999997	0103000020E610000001000000050000004E0B5EF4156C4640048D9944BD9045404E0B5EF4156C46406AF816D68D9345404A0C022B876E46406AF816D68D9345404A0C022B876E4640048D9944BD9045404E0B5EF4156C4640048D9944BD904540
52761	Южное	8	76	767	44.720677000000002	44.752882	43.523439000000003	43.511037000000002	0103000020E610000001000000050000005DFDD8243F5C4640E20511A969C145405DFDD8243F5C4640B939950C00C34540A0DFF76F5E604640B939950C00C34540A0DFF76F5E604640E20511A969C145405DFDD8243F5C4640E20511A969C14540
32767	Средние Ачалуки	8	76	767	44.724603000000002	44.743099000000001	43.378017	43.361784	0103000020E61000000100000005000000B0CA85CABF5C4640A81B28F04EAE4540B0CA85CABF5C4640802A6EDC62B045405C5837DE1D5F4640802A6EDC62B045405C5837DE1D5F4640A81B28F04EAE4540B0CA85CABF5C4640A81B28F04EAE4540
52734	Сагопши	8	76	767	44.577423000000003	44.607579000000001	43.494677000000003	43.470913000000003	0103000020E61000000100000005000000A77A32FFE849464071218FE046BC4540A77A32FFE8494640AD8A709351BF4540425E0F26C54D4640AD8A709351BF4540425E0F26C54D464071218FE046BC4540A77A32FFE849464071218FE046BC4540
52742	Пседах	8	76	767	44.557633000000003	44.582346000000001	43.480823999999998	43.452204999999999	0103000020E61000000100000005000000CF15A58460474640390B7BDAE1B94540CF15A58460474640E2900DA48BBD45406C7A50508A4A4640E2900DA48BBD45406C7A50508A4A4640390B7BDAE1B94540CF15A58460474640390B7BDAE1B94540
52766	Новый Редант	8	76	767	44.796872	44.822141999999999	43.479953999999999	43.463355999999997	0103000020E610000001000000050000008F8CD5E6FF654640E333D93F4FBB45408F8CD5E6FF654640CDCAF6216FBD45408255F5F23B694640CDCAF6216FBD45408255F5F23B694640E333D93F4FBB45408F8CD5E6FF654640E333D93F4FBB4540
52767	Нижние Ачалуки	8	76	767	44.747914000000002	44.773408000000003	43.415899000000003	43.386063	0103000020E610000001000000050000003B1C5DA5BB5F46400B992B836AB145403B1C5DA5BB5F464035B8AD2D3CB545407E3B8908FF62464035B8AD2D3CB545407E3B8908FF6246400B992B836AB145403B1C5DA5BB5F46400B992B836AB14540
5401	Малгобек	8	76	767	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
52751	Инарки	8	76	767	44.525509	44.557884000000001	43.480654000000001	43.460856	0103000020E61000000100000005000000786000E1434346402B155454FDBA4540786000E1434346408658FD1186BD4540187B2FBE684746408658FD1186BD4540187B2FBE684746402B155454FDBA4540786000E1434346402B155454FDBA4540
52777	Верхние Ачалуки	8	76	767	44.676901999999998	44.727027999999997	43.361634000000002	43.329009999999997	0103000020E610000001000000050000006A4C88B9A45646404A07EBFF1CAA45406A4C88B9A4564640938FDD054AAE45405DA3E5400F5D4640938FDD054AAE45405DA3E5400F5D46404A07EBFF1CAA45406A4C88B9A45646404A07EBFF1CAA4540
52785	Вежарий	8	76	767	44.565682000000002	44.583010000000002	43.602148	43.592967999999999	0103000020E61000000100000005000000CBF78C44684846408AC91B60E6CB4540CBF78C446848464008AD872F13CD4540D89E5912A04A464008AD872F13CD4540D89E5912A04A46408AC91B60E6CB4540CBF78C44684846408AC91B60E6CB4540
57762	Джайрах	8	76	7446	44.665664	44.690672999999997	42.828884000000002	42.816603999999998	0103000020E61000000100000005000000F10F5B7A3455464032E4D87A86684540F10F5B7A34554640BE16F4DE186A4540779D0DF967584640BE16F4DE186A4540779D0DF96758464032E4D87A86684540F10F5B7A3455464032E4D87A86684540
57742	Армхи	8	76	7446	44.477305000000001	45.293892	43.615417999999998	42.614910999999999	0103000020E61000000100000005000000D09B8A54183D4640AF795567B54E4540D09B8A54183D464053AF5B04C6CE45402C47C8409EA5464053AF5B04C6CE45402C47C8409EA54640AF795567B54E4540D09B8A54183D4640AF795567B54E4540
16348	Южно-Сухокумск	8	75	\N	45.625523000000001	45.668138999999996	44.676462000000001	44.648836000000003	0103000020E61000000100000005000000AAF23D2311D04640D63BDC0E0D534640AAF23D2311D046404E7E8B4E965646405017299485D546404E7E8B4E965646405017299485D54640D63BDC0E0D534640AAF23D2311D04640D63BDC0E0D534640
953	Хасавюрт	8	75	\N	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
6655	Махачкала	8	75	\N	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
28634	Кизляр	8	75	\N	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
25217	Кизилюрт	8	75	\N	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
18679	Каспийск	8	75	\N	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
15675	Избербаш	8	75	\N	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
12017	Дербент	8	75	\N	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
41025	Дагестанские Огни	8	75	\N	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
8650	Дагестанские Огни	8	75	\N	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
53419	Дагестанские Огни	8	75	\N	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
2445	Буйнакск	8	75	\N	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
53672	Алтунчик	8	75	\N	45.103879999999997	48.591796000000002	44.992620000000002	41.185778999999997	0103000020E61000000100000005000000AF5A99F04B8D46404CA4349BC7974440AF5A99F04B8D464082AD122C0E7F4640AAF3A8F8BF4B484082AD122C0E7F4640AAF3A8F8BF4B48404CA4349BC7974440AF5A99F04B8D46404CA4349BC7974440
16290	Цекоб	8	75	1330	46.446663999999998	46.455899000000002	42.429955999999997	42.421677000000003	0103000020E61000000100000005000000782634492C394740DA3C0E83F9354540782634492C394740075C57CC08374540BAA3FFE55A3A4740075C57CC08374540BAA3FFE55A3A4740DA3C0E83F9354540782634492C394740DA3C0E83F9354540
16216	Хучада	8	75	1330	46.465870000000002	46.475346999999999	42.403677000000002	42.399583	0103000020E610000001000000050000000118CFA0A13B4740CF842689253345400118CFA0A13B4740DE921CB0AB33454038A0A52BD83C4740DE921CB0AB33454038A0A52BD83C4740CF842689253345400118CFA0A13B4740CF84268925334540
16128	Хотода	8	75	1330	46.547472999999997	46.561315999999998	42.398083999999997	42.391060000000003	0103000020E61000000100000005000000B4386398134647400B630B410E324540B438639813464740CA87A06AF43245405B5CE333D9474740CA87A06AF43245405B5CE333D94747400B630B410E324540B4386398134647400B630B410E324540
16173	Хорода	8	75	1330	46.660938999999999	46.675761000000001	42.418123000000001	42.411991999999998	0103000020E6100000010000000500000052D32EA699544740581B6327BC34454052D32EA6995447404B5AF10D85354540C57421567F5647404B5AF10D85354540C57421567F564740581B6327BC34454052D32EA699544740581B6327BC344540
16097	Хонох	8	75	1330	46.506653999999997	46.513444999999997	42.319608000000002	42.313487000000002	0103000020E610000001000000050000009C31CC09DA4047404F5C8E57202845409C31CC09DA4047401EC539EAE8284540B9A5D590B84147401EC539EAE8284540B9A5D590B84147404F5C8E57202845409C31CC09DA4047404F5C8E5720284540
16034	Хебда	8	75	1330	46.538274000000001	46.559680999999998	42.453702999999997	42.433909	0103000020E61000000100000005000000C0249529E6444740543882548A374540C0249529E64447406D8C9DF0123A4540A69883A0A34747406D8C9DF0123A4540A69883A0A3474740543882548A374540C0249529E6444740543882548A374540
15969	Урчух	8	75	1330	46.491858000000001	46.498165	42.329512999999999	42.324834000000003	0103000020E610000001000000050000005323F433F53E47407F501729942945405323F433F53E4740AD4D637B2D2A45408481E7DEC33F4740AD4D637B2D2A45408481E7DEC33F47407F501729942945405323F433F53E47407F50172994294540
15949	Уриб	8	75	1330	46.669589999999999	46.678313000000003	42.458978000000002	42.453755999999998	0103000020E6100000010000000500000044DD0720B5554740902E36AD143A454044DD0720B5554740B0CA85CABF3A4540D0B9DBF5D2564740B0CA85CABF3A4540D0B9DBF5D2564740902E36AD143A454044DD0720B5554740902E36AD143A4540
15891	Урада	8	75	1330	46.553294000000001	46.567137000000002	42.390520000000002	42.381875999999998	0103000020E6100000010000000500000059897956D24647404B901150E130454059897956D24647408B37328FFC31454000ADF9F1974847408B37328FFC31454000ADF9F1974847404B901150E130454059897956D24647404B901150E1304540
15797	Тлях	8	75	1330	46.537267999999997	46.552567000000003	42.393403999999997	42.382241999999998	0103000020E61000000100000005000000FA97A432C54447402D944C4EED304540FA97A432C5444740CB0EF10F5B324540A7ECF483BA464740CB0EF10F5B324540A7ECF483BA4647402D944C4EED304540FA97A432C54447402D944C4EED304540
15745	Тлянуб	8	75	1330	46.453463999999997	46.462214000000003	42.440396	42.431759	0103000020E61000000100000005000000E8F4BC1B0B3A4740786000E143374540E8F4BC1B0B3A474005A568E55E3845406EE00ED4293B474005A568E55E3845406EE00ED4293B4740786000E143374540E8F4BC1B0B3A4740786000E143374540
15680	Тидиб	8	75	1330	46.564712	46.587294999999997	42.401299999999999	42.385824999999997	0103000020E6100000010000000500000052D4997B48484740567DAEB66231454052D4997B4848474041F163CC5D3345405A0D897B2C4B474041F163CC5D3345405A0D897B2C4B4740567DAEB66231454052D4997B48484740567DAEB662314540
15666	Телетль	8	75	1330	46.727567000000001	46.755243999999998	42.435825000000001	42.423900000000003	0103000020E610000001000000050000000D535BEA205D47402063EE5A423645400D535BEA205D4740BDE3141DC93745400740DCD5AB604740BDE3141DC93745400740DCD5AB6047402063EE5A423645400D535BEA205D47402063EE5A42364540
15614	Сомода	8	75	1330	46.534052000000003	46.540115999999998	42.305559000000002	42.300338000000004	0103000020E61000000100000005000000842EE1D05B4447407FDFBF7971264540842EE1D05B444740CEFFAB8E1C274540EE05668522454740CEFFAB8E1C274540EE056685224547407FDFBF7971264540842EE1D05B4447407FDFBF7971264540
15528	Ругельда	8	75	1330	46.519266000000002	46.528725000000001	42.321227999999998	42.312047	0103000020E610000001000000050000005EF6EB4E774247404FE8F527F12745405EF6EB4E774247409D47C5FF1D294540EFC9C342AD4347409D47C5FF1D294540EFC9C342AD4347404FE8F527F12745405EF6EB4E774247404FE8F527F1274540
15480	Ратлуб	8	75	1330	46.424619	46.437725999999998	42.365504000000001	42.357036000000001	0103000020E610000001000000050000004F2157EA5936474051BF0B5BB32D45404F2157EA593647405247C7D5C82E4540F04DD367073847405247C7D5C82E4540F04DD3670738474051BF0B5BB32D45404F2157EA5936474051BF0B5BB32D4540
15320	Нитаб	8	75	1330	46.624737000000003	46.635193999999998	42.522216999999998	42.515737000000001	0103000020E61000000100000005000000F3CCCB61F74F4740282B86AB03424540F3CCCB61F74F47402635B401D8424540C64E78094E5147402635B401D8424540C64E78094E514740282B86AB03424540F3CCCB61F74F4740282B86AB03424540
15379	Нижний Батлух	8	75	1330	46.511082000000002	46.530540000000002	42.491157000000001	42.483784	0103000020E6100000010000000500000082C98D226B414740FE2955A2EC3D454082C98D226B414740CA198A3BDE3E4540249C16BCE8434740CA198A3BDE3E4540249C16BCE8434740FE2955A2EC3D454082C98D226B414740FE2955A2EC3D4540
15250	Накитль	8	75	1330	46.596772999999999	46.618153	42.402358999999997	42.393543000000001	0103000020E610000001000000050000006211C30E634C4740ED48F59D5F3245406211C30E634C47402920ED7F803345404F7633A31F4F47402920ED7F803345404F7633A31F4F4740ED48F59D5F3245406211C30E634C4740ED48F59D5F324540
15216	Мусрух	8	75	1330	46.514657999999997	46.518790000000003	42.331493000000002	42.328426999999998	0103000020E61000000100000005000000F84F3750E0414740CB0F5CE5092A4540F84F3750E04147402DEDD45C6E2A4540F5BEF1B5674247402DEDD45C6E2A4540F5BEF1B567424740CB0F5CE5092A4540F84F3750E0414740CB0F5CE5092A4540
15188	Могох	8	75	1330	46.571665000000003	46.577252000000001	42.502651	42.498510000000003	0103000020E6100000010000000500000049A297512C4947404F5DF92CCF3F454049A297512C4947409E2633DE564045407AC6BE64E34947409E2633DE564045407AC6BE64E34947404F5DF92CCF3F454049A297512C4947404F5DF92CCF3F4540
53852	Митлиуриб	8	75	1330	46.681421	46.692605	42.449412000000002	42.432844000000003	0103000020E6100000010000000500000060E7A6CD385747408A22A46E6737454060E7A6CD385747400937195586394540E605D847A75847400937195586394540E605D847A75847408A22A46E6737454060E7A6CD385747408A22A46E67374540
15085	Мачада	8	75	1330	46.528761000000003	46.543080000000003	42.380631000000001	42.370367000000002	0103000020E610000001000000050000003C33C170AE4347404242942F682F45403C33C170AE434740016C4084B83045404C8E3BA583454740016C4084B83045404C8E3BA5834547404242942F682F45403C33C170AE4347404242942F682F4540
15024	Куаниб	8	75	1330	46.607436	46.615709000000003	42.512700000000002	42.505861000000003	0103000020E61000000100000005000000DF347D76C04D474033A9A10DC0404540DF347D76C04D474061545227A04145402B6D718DCF4E474061545227A04145402B6D718DCF4E474033A9A10DC0404540DF347D76C04D474033A9A10DC0404540
14935	Кахиб	8	75	1330	46.589055999999999	46.604857000000003	42.433143999999999	42.42577	0103000020E610000001000000050000009CC1DF2F664B474018CFA0A17F3645409CC1DF2F664B4740B43A394371374540DBE044F46B4D4740B43A394371374540DBE044F46B4D474018CFA0A17F3645409CC1DF2F664B474018CFA0A17F364540
14898	Зиуриб	8	75	1330	46.700555000000001	46.708074000000003	42.422015999999999	42.414994	0103000020E610000001000000050000004F0647C9AB594740A304FD851E3545404F0647C9AB594740C231CB9E04364540EF92382BA25A4740C231CB9E04364540EF92382BA25A4740A304FD851E3545404F0647C9AB594740A304FD851E354540
14828	Заната	8	75	1330	46.55218	46.559474999999999	42.487008000000003	42.481603	0103000020E61000000100000005000000ADC090D5AD464740E753C72AA53D4540ADC090D5AD464740F8713447563E4540FDF675E09C474740F8713447563E4540FDF675E09C474740E753C72AA53D4540ADC090D5AD464740E753C72AA53D4540
14814	Датуна	8	75	1330	46.640448999999997	46.646521	42.478456999999999	42.473236999999997	0103000020E61000000100000005000000C1E09A3BFA514740EA20AF07933C4540C1E09A3BFA51474069C537143E3D4540AF963B33C152474069C537143E3D4540AF963B33C1524740EA20AF07933C4540C1E09A3BFA514740EA20AF07933C4540
14756	Дагбаш	8	75	1330	46.334527000000001	46.355162	42.384160000000001	42.372798000000003	0103000020E610000001000000050000008350DEC7D12A4740D20149D8B72F45408350DEC7D12A47403737A6272C3145401764CBF2752D47403737A6272C3145401764CBF2752D4740D20149D8B72F45408350DEC7D12A4740D20149D8B72F4540
14712	Гоор-Хиндах	8	75	1330	46.562843000000001	46.582031000000001	42.454414	42.441088000000001	0103000020E610000001000000050000002AE44A3D0B4847403B545392753845402AE44A3D0B4847401A6CEA3C2A3A45400C21E7FD7F4A47401A6CEA3C2A3A45400C21E7FD7F4A47403B545392753845402AE44A3D0B4847403B54539275384540
14631	Гоор	8	75	1330	46.561604000000003	46.578617999999999	42.440736000000001	42.430467999999998	0103000020E61000000100000005000000C2A6CEA3E2474740BDFC4E9319374540C2A6CEA3E2474740BE1589096A3845403F709527104A4740BE1589096A3845403F709527104A4740BDFC4E9319374540C2A6CEA3E2474740BDFC4E9319374540
14613	Голотль	8	75	1330	46.721935000000002	46.748229000000002	42.493755999999998	42.481715999999999	0103000020E610000001000000050000003C6BB75D685C4740DFFAB0DEA83D45403C6BB75D685C4740151A8865333F45409B75C6F7C55F4740151A8865333F45409B75C6F7C55F4740DFFAB0DEA83D45403C6BB75D685C4740DFFAB0DEA83D4540
14562	Гоготль	8	75	1330	46.761200000000002	46.771630000000002	42.457706999999999	42.447794999999999	0103000020E610000001000000050000008CDB68006F614740FA27B858513945408CDB68006F6147403C139A24963A4540664E97C5C46247403C139A24963A4540664E97C5C4624740FA27B858513945408CDB68006F614740FA27B85851394540
14490	Гента	8	75	1330	46.545991000000001	46.573909999999998	42.377560000000003	42.367296000000003	0103000020E6100000010000000500000086747808E3454740CFF9298E032F454086747808E34547408E23D6E253304540766C04E2754947408E23D6E253304540766C04E275494740CFF9298E032F454086747808E3454740CFF9298E032F4540
53955	Геницориб	8	75	1330	46.267395999999998	46.805999	42.539498000000002	42.191096999999999	0103000020E61000000100000005000000658A39083A2247408EAED2DD75184540658A39083A224740F3203D450E454540EACDA8F92A674740F3203D450E454540EACDA8F92A6747408EAED2DD75184540658A39083A2247408EAED2DD75184540
15827	Верхний Тогох	8	75	1330	46.696207000000001	46.700356999999997	42.431745999999997	42.427427000000002	0103000020E61000000100000005000000861F9C4F1D594740B5368DEDB5364540861F9C4F1D594740E316F373433745402843554CA5594740E316F373433745402843554CA5594740B5368DEDB5364540861F9C4F1D594740B5368DEDB5364540
14404	Верхний Колоб	8	75	1330	46.667774999999999	46.672626000000001	42.425856000000003	42.422255999999997	0103000020E610000001000000050000000F0BB5A67955474017450F7C0C3645400F0BB5A67955474017670C73823645403B38D89B1856474017670C73823645403B38D89B1856474017450F7C0C3645400F0BB5A67955474017450F7C0C364540
14347	Верхний Батлух	8	75	1330	46.498677000000001	46.505727999999998	42.498728999999997	42.495125999999999	0103000020E610000001000000050000003A22DFA5D43F47401CB3EC49603F45403A22DFA5D43F47408C48145AD63F4540F355F2B1BB4047408C48145AD63F4540F355F2B1BB4047401CB3EC49603F45403A22DFA5D43F47401CB3EC49603F4540
53766	Асаб	8	75	1330	46.490645999999998	46.504263999999999	42.473882000000003	42.464703999999998	0103000020E61000000100000005000000E4F4F57CCD3E47400229B16B7B3B4540E4F4F57CCD3E4740E014562AA83C45406B4606B98B404740E014562AA83C45406B4606B98B4047400229B16B7B3B4540E4F4F57CCD3E47400229B16B7B3B4540
14235	Андых	8	75	1330	46.589927000000003	46.599170999999998	42.518295999999999	42.510015000000003	0103000020E6100000010000000500000082035ABA824B474017BCE82B4841454082035ABA824B4740E5D2F8855742454016DBA4A2B14C4740E5D2F8855742454016DBA4A2B14C474017BCE82B4841454082035ABA824B474017BCE82B48414540
13871	Шалиб	8	75	1208	46.913913999999998	46.922843	42.092745000000001	42.087505999999998	0103000020E61000000100000005000000A3AD4A22FB744740151A8865330B4540A3AD4A22FB7447400BEF7211DF0B4540D82B2CB81F7647400BEF7211DF0B4540D82B2CB81F764740151A8865330B4540A3AD4A22FB744740151A8865330B4540
13414	Чуниб	8	75	1208	46.820695999999998	46.826247000000002	42.210960999999998	42.203567	0103000020E61000000100000005000000A0FA07910C694740BDC5C37B0E1A4540A0FA07910C694740A0DD21C5001B454085B53176C2694740A0DD21C5001B454085B53176C2694740BDC5C37B0E1A4540A0FA07910C694740BDC5C37B0E1A4540
12924	Читаб	8	75	1208	46.868046	46.871181	42.105510000000002	42.100827000000002	0103000020E6100000010000000500000039B69E211C6F4740E3C62DE6E70C454039B69E211C6F474053B3075A810D4540C3F2E7DB826F474053B3075A810D4540C3F2E7DB826F4740E3C62DE6E70C454039B69E211C6F4740E3C62DE6E70C4540
53491	Чильдаб	8	75	1208	46.916896000000001	46.933587000000003	42.142412	42.138607	0103000020E61000000100000005000000A7EA1ED95C75474093FFC9DFBD114540A7EA1ED95C7547406B47718E3A124540427C60C77F7747406B47718E3A124540427C60C77F77474093FFC9DFBD114540A7EA1ED95C75474093FFC9DFBD114540
12867	Чвадаб	8	75	1208	46.868091	46.873651000000002	42.154657999999998	42.151950999999997	0103000020E61000000100000005000000D9791B9B1D6F474018CC5F2173134540D9791B9B1D6F47404A0856D5CB134540118FC4CBD36F47404A0856D5CB134540118FC4CBD36F474018CC5F2173134540D9791B9B1D6F474018CC5F2173134540
13838	Чарода	8	75	1208	46.788868000000001	46.828107000000003	42.300857999999998	42.273116999999999	0103000020E61000000100000005000000336E6AA0F9644740A67D737FF5224540336E6AA0F9644740B75ED383822645405A4B0169FF694740B75ED383822645405A4B0169FF694740A67D737FF5224540336E6AA0F9644740A67D737FF5224540
13666	Цуриб	8	75	1208	46.827863999999998	46.838526999999999	42.243876	42.233421999999997	0103000020E6100000010000000500000093C49272F76947405D15A8C5E01D454093C49272F7694740C0232A54371F454010E84CDA546B4740C0232A54371F454010E84CDA546B47405D15A8C5E01D454093C49272F76947405D15A8C5E01D4540
13501	Цулда	8	75	1208	46.714613999999997	46.724783000000002	42.275826000000002	42.270415	0103000020E61000000100000005000000C2A1B778785B474086AC6EF59C224540C2A1B778785B474079B130444E23454030D978B0C55C474079B130444E23454030D978B0C55C474086AC6EF59C224540C2A1B778785B474086AC6EF59C224540
13191	Ценеб	8	75	1208	46.840539	46.845866000000001	42.208382999999998	42.204782999999999	0103000020E610000001000000050000009B012EC8966B47406DE34F54361A45409B012EC8966B47406C054D4BAC1A454030664B56456C47406C054D4BAC1A454030664B56456C47406DE34F54361A45409B012EC8966B47406DE34F54361A4540
12187	Цемер	8	75	1208	46.753250000000001	46.755432999999996	42.154263999999998	42.151563000000003	0103000020E6100000010000000500000023DBF97E6A6047404F24986A6613454023DBF97E6A6047409E7939ECBE134540DAA84E07B26047409E7939ECBE134540DAA84E07B26047404F24986A6613454023DBF97E6A6047404F24986A66134540
13391	Хурух	8	75	1208	46.855190999999998	46.859799000000002	42.186373000000003	42.183681	0103000020E61000000100000005000000B16A10E6766D4740C3F2E7DB82174540B16A10E6766D4740C0ED0912DB1745401711C5E40D6E4740C0ED0912DB1745401711C5E40D6E4740C3F2E7DB82174540B16A10E6766D4740C3F2E7DB82174540
12031	Хитаб	8	75	1208	46.861344000000003	46.866914000000001	42.077621999999998	42.074564000000002	0103000020E610000001000000050000008C4D2B85406E4740BFBA2A508B0945408C4D2B85406E47409DB98784EF094540E738B709F76E47409DB98784EF094540E738B709F76E4740BFBA2A508B0945408C4D2B85406E4740BFBA2A508B094540
13004	Хинуб	8	75	1208	46.821486	46.826337000000002	42.176938999999997	42.172969999999999	0103000020E61000000100000005000000990F087426694740359886E123164540990F0874266947408731E9EFA5164540C53C2B69C56947408731E9EFA5164540C53C2B69C5694740359886E123164540990F087426694740359886E123164540
11929	Хилих	8	75	1208	46.884216000000002	46.896549	42.060963000000001	42.057395	0103000020E61000000100000005000000CB4C69FD2D7147401AFA27B858074540CB4C69FD2D7147400EA2B5A2CD07454079211D1EC27247400EA2B5A2CD07454079211D1EC27247401AFA27B858074540CB4C69FD2D7147401AFA27B858074540
13565	Утлух	8	75	1208	46.724539999999998	46.731555999999998	42.270941999999998	42.266078	0103000020E6100000010000000500000069520ABABD5C4740B1170AD80E22454069520ABABD5C4740718E3A3AAE224540A69883A0A35D4740718E3A3AAE224540A69883A0A35D4740B1170AD80E22454069520ABABD5C4740B1170AD80E224540
12637	Тлярош	8	75	1208	46.743000000000002	46.752918000000001	42.282609999999998	42.271943	0103000020E61000000100000005000000C976BE9F1A5F474025B03907CF224540C976BE9F1A5F4740E3C281902C244540ED48F59D5F604740E3C281902C244540ED48F59D5F60474025B03907CF224540C976BE9F1A5F474025B03907CF224540
53430	Тляробазутль	8	75	1208	46.772545999999998	46.778008	42.142136999999998	42.139971000000003	0103000020E61000000100000005000000EB538EC9E2624740B8B1D991EA114540EB538EC9E26247409946938B31124540600322C4956347409946938B31124540600322C495634740B8B1D991EA114540EB538EC9E2624740B8B1D991EA114540
12551	Талух	8	75	1208	46.737547999999997	46.750169	42.258124000000002	42.245356999999998	0103000020E61000000100000005000000779D0DF9675E47401E6CB1DB671F4540779D0DF9675E474007280D350A2145408CBCAC890560474007280D350A2145408CBCAC89056047401E6CB1DB671F4540779D0DF9675E47401E6CB1DB671F4540
13479	Сумета	8	75	1208	46.696890000000003	46.709564999999998	42.267218999999997	42.260547000000003	0103000020E61000000100000005000000697407B1335947401409A69A59214540697407B13359474056EF703B3422454070B1A206D35A474056EF703B3422454070B1A206D35A47401409A69A59214540697407B1335947401409A69A59214540
13787	Содаб	8	75	1208	46.797958999999999	46.814183	42.217826000000002	42.212083	0103000020E610000001000000050000004146408523664740CF842689251B45404146408523664740F81BEDB8E11B4540C6FA062637684740F81BEDB8E11B4540C6FA062637684740CF842689251B45404146408523664740CF842689251B4540
53427	Село Урух-сота	8	75	1208	46.539191000000002	46.981898000000001	42.370193	41.883592999999998	0103000020E6100000010000000500000016A6EF3504454740BDFC4E9319F1444016A6EF3504454740A41AF67B622F454000016BD5AE7D4740A41AF67B622F454000016BD5AE7D4740BDFC4E9319F1444016A6EF3504454740BDFC4E9319F14440
13595	Сачада	8	75	1208	46.677728999999999	46.701237999999996	42.261100999999996	42.256062	0103000020E610000001000000050000008046E9D2BF564740CADFBDA3C62045408046E9D2BF564740F8F9EFC16B214540315BB22AC2594740F8F9EFC16B214540315BB22AC2594740CADFBDA3C62045408046E9D2BF564740CADFBDA3C6204540
12431	Ритляб	8	75	1208	46.712628000000002	46.726399999999998	42.052427000000002	42.045758999999997	0103000020E61000000100000005000000611BF164375B4740B33F506EDB054540611BF164375B4740B5368DEDB50645403EE8D9ACFA5C4740B5368DEDB50645403EE8D9ACFA5C4740B33F506EDB054540611BF164375B4740B33F506EDB054540
13026	Нукуш	8	75	1208	46.799612000000003	46.808056000000001	42.156830999999997	42.149076999999998	0103000020E610000001000000050000009DBE9EAF59664740FBCA83F4141345409DBE9EAF59664740DEFFC7091314454015AB06616E674740DEFFC7091314454015AB06616E674740FBCA83F4141345409DBE9EAF59664740FBCA83F414134540
13215	Мукутль	8	75	1208	46.848472000000001	46.864938000000002	42.196466999999998	42.189973999999999	0103000020E610000001000000050000002EC901BB9A6C47408F8B6A11511845402EC901BB9A6C474022DFA5D425194540A988D349B66E474022DFA5D425194540A988D349B66E47408F8B6A11511845402EC901BB9A6C47408F8B6A1151184540
12731	Мугурух	8	75	1208	46.861919	46.867255	42.263036	42.258899	0103000020E6100000010000000500000088669E5C536E4740CAFB389A2321454088669E5C536E4740D8D5E429AB21454070253B36026F4740D8D5E429AB21454070253B36026F4740CAFB389A2321454088669E5C536E4740CAFB389A23214540
53564	Мощоб	8	75	1208	46.539191000000002	46.981898000000001	42.370193	41.883592999999998	0103000020E6100000010000000500000016A6EF3504454740BDFC4E9319F1444016A6EF3504454740A41AF67B622F454000016BD5AE7D4740A41AF67B622F454000016BD5AE7D4740BDFC4E9319F1444016A6EF3504454740BDFC4E9319F14440
13117	Магар	8	75	1208	46.837332000000004	46.845326999999997	42.197589999999998	42.192366	0103000020E6100000010000000500000078F2E9B12D6B4740616EF7729F18454078F2E9B12D6B474021020EA14A19454080B6D5AC336C474021020EA14A19454080B6D5AC336C4740616EF7729F18454078F2E9B12D6B4740616EF7729F184540
13313	Кучраб	8	75	1208	46.898237999999999	46.903573999999999	42.177588	42.173811999999998	0103000020E6100000010000000500000021037976F972474080D3BB783F16454021037976F9724740BE141E34BB16454009C21550A8734740BE141E34BB16454009C21550A873474080D3BB783F16454021037976F972474080D3BB783F164540
12127	Кутих	8	75	1208	46.783504999999998	46.790036000000001	42.128056000000001	42.124471999999997	0103000020E6100000010000000500000051A04FE44964474044A2D0B2EE0F454051A04FE4496447403E07962364104540D2544FE61F6547403E07962364104540D2544FE61F65474044A2D0B2EE0F454051A04FE44964474044A2D0B2EE0F4540
11829	Кубатль	8	75	1208	46.855567999999998	46.862305999999997	42.039478000000003	42.024355	0103000020E6100000010000000500000087C09140836D47403E3F8C101E03454087C09140836D4740AC74779D0D0545408192020B606E4740AC74779D0D0545408192020B606E47403E3F8C101E03454087C09140836D47403E3F8C101E034540
12847	Косрода	8	75	1208	46.854894999999999	46.868701999999999	42.135224000000001	42.130924999999998	0103000020E61000000100000005000000C84109336D6D4740499D8026C2104540C84109336D6D474031D120054F11454022FC8BA0316F474031D120054F11454022FC8BA0316F4740499D8026C2104540C84109336D6D4740499D8026C2104540
11980	Кесериб	8	75	1208	46.875286000000003	46.882328999999999	42.065868999999999	42.060481000000003	0103000020E61000000100000005000000C652245F09704740C38366D7BD074540C652245F09704740FD6838656E084540FCA71B28F0704740FD6838656E084540FCA71B28F0704740C38366D7BD074540C652245F09704740C38366D7BD074540
12316	Карануб	8	75	1208	46.813958	46.821935000000003	42.124392	42.119697000000002	0103000020E61000000100000005000000A62897C62F684740F436363B520F4540A62897C62F68474028F1B913EC0F45400938842A3569474028F1B913EC0F45400938842A35694740F436363B520F4540A62897C62F684740F436363B520F4540
12946	Ириб	8	75	1208	46.813904000000001	46.821171999999997	42.162545000000001	42.157859999999999	0103000020E61000000100000005000000B30A9B012E6847405CACA8C134144540B30A9B012E6847406D904946CE1445400932022A1C6947406D904946CE1445400932022A1C6947405CACA8C134144540B30A9B012E6847405CACA8C134144540
12792	Дусрах	8	75	1208	46.874234999999999	46.881717999999999	42.130155999999999	42.125467999999998	0103000020E610000001000000050000006002B7EEE66F4740E658DE550F1045406002B7EEE66F474068B0A9F3A8104540B325AB22DC70474068B0A9F3A8104540B325AB22DC704740E658DE550F1045406002B7EEE66F4740E658DE550F104540
12273	Доронуб	8	75	1208	46.808407000000003	46.811802	42.126384000000002	42.124405000000003	0103000020E61000000100000005000000C26D6DE179674740BD3AC780EC0F4540C26D6DE1796747406C5ED5592D104540E869C020E96747406C5ED5592D104540E869C020E9674740BD3AC780EC0F4540C26D6DE179674740BD3AC780EC0F4540
53967	Гунух - Мурух	8	75	1208	46.539191000000002	46.981898000000001	42.370193	41.883592999999998	0103000020E6100000010000000500000016A6EF3504454740BDFC4E9319F1444016A6EF3504454740A41AF67B622F454000016BD5AE7D4740A41AF67B622F454000016BD5AE7D4740BDFC4E9319F1444016A6EF3504454740BDFC4E9319F14440
12643	Гочоб	8	75	1208	46.658765000000002	46.680334000000002	42.244036000000001	42.235418000000003	0103000020E61000000100000005000000EE5F596952544740E371512D221E4540EE5F596952544740F98557923C1F4540AE2D3C2F15574740F98557923C1F4540AE2D3C2F15574740E371512D221E4540EE5F596952544740E371512D221E4540
53918	Гочада	8	75	1208	46.763328999999999	46.772275999999998	42.275365999999998	42.266886	0103000020E61000000100000005000000508BC1C3B461474050E1085229224540508BC1C3B461474015376E313F2345402BBEA1F0D962474015376E313F2345402BBEA1F0D962474050E1085229224540508BC1C3B461474050E1085229224540
12368	Гоаб	8	75	1208	46.736721000000003	46.742524000000003	42.099007999999998	42.096311	0103000020E6100000010000000500000062A3ACDF4C5E47405E9F39EB530C454062A3ACDF4C5E47406C054D4BAC0C4540603FC4060B5F47406C054D4BAC0C4540603FC4060B5F47405E9F39EB530C454062A3ACDF4C5E47405E9F39EB530C4540
12092	Гилиб	8	75	1208	46.770156	46.780810000000002	42.120345999999998	42.113329999999998	0103000020E61000000100000005000000BA68C87894624740EDD3F198810E4540BA68C878946247402A1A6B7F670F4540E4310395F16347402A1A6B7F670F4540E4310395F1634740EDD3F198810E4540BA68C87894624740EDD3F198810E4540
13780	Гидиб	8	75	1208	46.804327999999998	46.808208999999998	42.231699999999996	42.228642000000001	0103000020E61000000100000005000000E8A04B38F4664740FB3E1C24441D4540E8A04B38F4664740D93D7958A81D45409BAA7B6473674740D93D7958A81D45409BAA7B6473674740FB3E1C24441D4540E8A04B38F4664740FB3E1C24441D4540
13284	Багинуб	8	75	1208	46.873291999999999	46.883946000000002	42.176758999999997	42.172269	0103000020E61000000100000005000000E1ED4108C86F4740AC8E1CE90C164540E1ED4108C86F47400723F609A01645400BB77C24257147400723F609A01645400BB77C2425714740AC8E1CE90C164540E1ED4108C86F4740AC8E1CE90C164540
11795	Арчиб	8	75	1208	46.865647000000003	46.873857999999998	42.068613999999997	42.063915000000001	0103000020E61000000100000005000000B5705985CD6E4740A75CE15D2E084540B5705985CD6E47401C06F357C80845408AAC3594DA6F47401C06F357C80845408AAC3594DA6F4740A75CE15D2E084540B5705985CD6E4740A75CE15D2E084540
11870	Алчуниб	8	75	1208	46.866770000000002	46.871611999999999	42.054020999999999	42.050612999999998	0103000020E61000000100000005000000B493C151F26E474050E09D7C7A064540B493C151F26E47400B26FE28EA0645408C6665FB906F47400B26FE28EA0645408C6665FB906F474050E09D7C7A064540B493C151F26E474050E09D7C7A064540
53941	с.Мекали	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
53938	с.Азильта	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
9817	Эльбок	8	75	1090	45.902177000000002	45.911141999999998	42.185524999999998	42.179779000000003	0103000020E61000000100000005000000091A33897AF34640F9C08EFF02174540091A33897AF3464092CB7F48BF1745408A01124DA0F4464092CB7F48BF1745408A01124DA0F44640F9C08EFF02174540091A33897AF34640F9C08EFF02174540
10762	Шаури	8	75	1090	45.936672999999999	45.946859000000003	42.273077000000001	42.268026999999996	0103000020E61000000100000005000000EA059FE6E4F74640F5B86FB54E224540EA059FE6E4F746401825E82FF42245402E76FBAC32F946401825E82FF42245402E76FBAC32F94640F5B86FB54E224540EA059FE6E4F74640F5B86FB54E224540
10046	Шапих	8	75	1090	45.854745999999999	45.861770999999997	42.226579000000001	42.221718000000003	0103000020E610000001000000050000008331225168ED46409F776341611C45408331225168ED4640EE7A698A001D454013D21A834EEE4640EE7A698A001D454013D21A834EEE46409F776341611C45408331225168ED46409F776341611C4540
11339	Шаитли	8	75	1090	46.046537000000001	46.055053000000001	42.243147999999998	42.235598000000003	0103000020E61000000100000005000000E886A6ECF405474063804413281E4540E886A6ECF40547403D0B42791F1F4540FA4509FA0B0747403D0B42791F1F4540FA4509FA0B07474063804413281E4540E886A6ECF405474063804413281E4540
53579	Чатли	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
10210	Чалях	8	75	1090	45.836897	45.840767999999997	42.242494000000001	42.237620999999997	0103000020E610000001000000050000006D8FDE701FEB4640E1EB6B5D6A1E45406D8FDE701FEB4640F5BC1B0B0A1F4540FCC22B499EEB4640F5BC1B0B0A1F4540FCC22B499EEB4640E1EB6B5D6A1E45406D8FDE701FEB4640E1EB6B5D6A1E4540
53552	Цутрах	8	75	1090	45.795636999999999	45.804099000000001	42.222999999999999	42.215961999999998	0103000020E61000000100000005000000683EE76ED7E54640E1968FA4A41B4540683EE76ED7E54640068195438B1C454087DF4DB7ECE64640068195438B1C454087DF4DB7ECE64640E1968FA4A41B4540683EE76ED7E54640E1968FA4A41B4540
53843	Цохок	8	75	1090	45.793463000000003	45.796877000000002	42.277740999999999	42.274852000000003	0103000020E6100000010000000500000004CB113290E54640BF9EAF592E23454004CB113290E5464011E15F048D234540A1F7C61000E6464011E15F048D234540A1F7C61000E64640BF9EAF592E23454004CB113290E54640BF9EAF592E234540
53513	Цибари	8	75	1090	45.873565999999997	45.881309000000002	42.256048999999997	42.251798000000001	0103000020E61000000100000005000000E272BC02D1EF46405F99B7EA3A204540E272BC02D1EF46403596B036C6204540D255BABBCEF046403596B036C6204540D255BABBCEF046405F99B7EA3A204540E272BC02D1EF46405F99B7EA3A204540
53854	Цехок	8	75	1090	45.983277000000001	45.988362000000002	42.249115000000003	42.245517999999997	0103000020E610000001000000050000005AF44E05DCFD4640274A42226D1F45405AF44E05DCFD4640B6F81400E31F4540F94D61A582FE4640B6F81400E31F4540F94D61A582FE4640274A42226D1F45405AF44E05DCFD4640274A42226D1F4540
53814	Хупри	8	75	1090	45.837426999999998	45.844451999999997	42.203220000000002	42.199814000000003	0103000020E61000000100000005000000C9E4D4CE30EB464038A4518193194540C9E4D4CE30EB464052F2EA1C031A45405985CD0017EC464052F2EA1C031A45405985CD0017EC464038A4518193194540C9E4D4CE30EB464038A4518193194540
53850	Хибиятль	8	75	1090	45.869307999999997	45.877051000000002	42.190696000000003	42.186013000000003	0103000020E6100000010000000500000059130B7C45EF4640C0D02346CF17454059130B7C45EF464030BDFDB96818454049F6083543F0464030BDFDB96818454049F6083543F04640C0D02346CF17454059130B7C45EF4640C0D02346CF174540
53591	Хетох	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
10841	Хебатли	8	75	1090	45.922694999999997	45.929504000000001	42.284664999999997	42.280329000000002	0103000020E610000001000000050000006397A8DE1AF64640698F17D2E12345406397A8DE1AF646406DA818E76F24454027C0B0FCF9F646406DA818E76F24454027C0B0FCF9F64640698F17D2E12345406397A8DE1AF64640698F17D2E1234540
11304	Хамаитли	8	75	1090	45.953453000000003	45.965347000000001	42.313321000000002	42.306660000000001	0103000020E61000000100000005000000F5A276BF0AFA4640E57E87A240274540F5A276BF0AFA464034130CE71A2845405725917D90FB464034130CE71A2845405725917D90FB4640E57E87A240274540F5A276BF0AFA4640E57E87A240274540
10566	Удок	8	75	1090	45.793688000000003	45.805537000000001	42.273231000000003	42.265237999999997	0103000020E61000000100000005000000249D819197E5464006D49B51F3214540249D819197E546406FA0C03BF9224540E65B1FD61BE746406FA0C03BF9224540E65B1FD61BE7464006D49B51F3214540249D819197E5464006D49B51F3214540
11174	Тляцуда	8	75	1090	45.921939999999999	45.928739999999998	42.351458999999998	42.347315000000002	0103000020E61000000100000005000000E76F422102F64640833463D1742C4540E76F422102F646404371C79BFC2C4540573ECBF3E0F646404371C79BFC2C4540573ECBF3E0F64640833463D1742C4540E76F422102F64640833463D1742C4540
10486	Терутли	8	75	1090	45.786977	45.801045000000002	42.293588999999997	42.283864000000001	0103000020E6100000010000000500000023DA8EA9BBE446408141D2A75524454023DA8EA9BBE4464090BB085394254540EACF7EA488E6464090BB085394254540EACF7EA488E646408141D2A75524454023DA8EA9BBE446408141D2A755244540
53503	Село Берих	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
11274	Сагада	8	75	1090	45.911043999999997	45.920997	42.392184999999998	42.387317000000003	0103000020E61000000100000005000000C79BFC169DF44640A9177C9A93314540C79BFC169DF44640AA7D3A1E33324540685BCD3AE3F54640AA7D3A1E33324540685BCD3AE3F54640A9177C9A93314540C79BFC169DF44640A9177C9A93314540
10331	Ретлоб	8	75	1090	45.827725000000001	45.841289000000003	42.246805999999999	42.242147000000003	0103000020E61000000100000005000000728A8EE4F2E946408AE942ACFE1E4540728A8EE4F2E94640713AC956971F454006BEA25BAFEB4640713AC956971F454006BEA25BAFEB46408AE942ACFE1E4540728A8EE4F2E946408AE942ACFE1E4540
10911	Мокок	8	75	1090	45.898322999999998	45.904881000000003	42.266204999999999	42.260452999999998	0103000020E610000001000000050000004F1F813FFCF2464092921E86562145404F1F813FFCF246400E84640113224540CAE2FE23D3F346400E84640113224540CAE2FE23D3F3464092921E86562145404F1F813FFCF2464092921E8656214540
53544	Махалотли	8	75	1090	45.793849000000002	45.799391999999997	42.305286000000002	42.29663	0103000020E610000001000000050000002D7B12D89CE546409981CAF8F72545402D7B12D89CE546409DF6949C132745408E57207A52E646409DF6949C132745408E57207A52E646409981CAF8F72545402D7B12D89CE546409981CAF8F7254540
11458	Китури	8	75	1090	46.015985000000001	46.022767000000002	42.247159000000003	42.243020999999999	0103000020E61000000100000005000000001DE6CB0B024740E09EE74F1B1F4540001DE6CB0B024740BFF4F6E7A21F4540CA367007EA024740BFF4F6E7A21F4540CA367007EA024740E09EE74F1B1F4540001DE6CB0B024740E09EE74F1B1F4540
53909	Китлярта	8	75	1090	45.836500999999998	45.845466999999999	42.211340999999997	42.207568000000002	0103000020E610000001000000050000002009FB7612EB46401BD99596911A45402009FB7612EB4640E7A6CD380D1B4540726C3D4338EC4640E7A6CD380D1B4540726C3D4338EC46401BD99596911A45402009FB7612EB46401BD99596911A4540
10282	Кимятли	8	75	1090	45.822190999999997	45.827258	42.251531	42.247587000000003	0103000020E610000001000000050000006308008E3DE9464017F549EEB01F45406308008E3DE946401077F52A322045405CAD1397E3E946401077F52A322045405CAD1397E3E9464017F549EEB01F45406308008E3DE9464017F549EEB01F4540
9660	Кидеро	8	75	1090	45.952133000000003	45.966380000000001	42.197229	42.188564999999997	0103000020E61000000100000005000000A038807EDFF94640CA15DEE522184540A038807EDFF946405169C4CC3E19454016C1FF56B2FB46405169C4CC3E19454016C1FF56B2FB4640CA15DEE522184540A038807EDFF94640CA15DEE522184540
53767	Качалайский	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
10355	Ицирах	8	75	1090	45.844684999999998	45.852913999999998	42.246786	42.242987999999997	0103000020E61000000100000005000000FC3559A31EEC464004A9143B1A1F4540FC3559A31EEC46402A8E03AF961F4540782634492CED46402A8E03AF961F4540782634492CED464004A9143B1A1F4540FC3559A31EEC464004A9143B1A1F4540
9697	Зехида	8	75	1090	45.941262999999999	45.950426	42.200335000000003	42.191684000000002	0103000020E61000000100000005000000A9F7544E7BF846404F95EF1989184540A9F7544E7BF84640419FC893A419454051A2258FA7F94640419FC893A419454051A2258FA7F946404F95EF1989184540A9F7544E7BF846404F95EF1989184540
9775	Гутатли	8	75	1090	45.930905000000003	45.940598000000001	42.211168000000001	42.204155	0103000020E61000000100000005000000695721E527F746404E2844C0211A4540695721E527F746401AFB928D071B45406D57E88365F846401AFB928D071B45406D57E88365F846404E2844C0211A4540695721E527F746404E2844C0211A4540
9617	Генух	8	75	1090	45.985881999999997	45.991675999999998	42.178356000000001	42.174387000000003	0103000020E6100000010000000500000087DBA16131FE46407DEC2E505216454087DBA16131FE4640CF85915ED4164540321D3A3DEFFE4640CF85915ED4164540321D3A3DEFFE46407DEC2E505216454087DBA16131FE46407DEC2E5052164540
11408	Гениятль	8	75	1090	46.02937	46.040500000000002	42.240932000000001	42.233716000000001	0103000020E61000000100000005000000E4BD6A65C2034740A646E867EA1D4540E4BD6A65C2034740AA471ADCD61E454077BE9F1A2F054740AA471ADCD61E454077BE9F1A2F054740A646E867EA1D4540E4BD6A65C2034740A646E867EA1D4540
9904	Вициятль	8	75	1090	45.880986	45.892592	42.199840999999999	42.193902000000001	0103000020E61000000100000005000000EF1D3526C4F046408350DEC7D1184540EF1D3526C4F0464031B3CF6394194540EB55647440F2464031B3CF6394194540EB55647440F246408350DEC7D1184540EF1D3526C4F046408350DEC7D1184540
53420	Бежта	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
53929	Ачи-Чунгур	8	75	1090	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
53660	Акды	8	75	1090	45.825614000000002	45.831443999999998	42.260179999999998	42.256376000000003	0103000020E61000000100000005000000548F34B8ADE946405ABDC3EDD0204540548F34B8ADE94640618907944D2145404B3ACAC16CEA4640618907944D2145404B3ACAC16CEA46405ABDC3EDD0204540548F34B8ADE946405ABDC3EDD0204540
8571	Эчеда	8	75	894	45.985002000000001	45.995933999999998	42.441375000000001	42.432538000000001	0103000020E610000001000000050000004F3FA88B14FE46407D23BA675D3745404F3FA88B14FE4640D122DBF97E384540BB7CEBC37AFF4640D122DBF97E384540BB7CEBC37AFF46407D23BA675D3745404F3FA88B14FE46407D23BA675D374540
60668	Эгдада	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
8358	Цумада-Урух	8	75	894	46.062167000000002	46.068958000000002	42.477440000000001	42.473477000000003	0103000020E61000000100000005000000FAF19716F50747404034F3E49A3C4540FAF19716F5074740B0E600C11C3D45401766A19DD3084740B0E600C11C3D45401766A19DD30847404034F3E49A3C4540FAF19716F50747404034F3E49A3C4540
8275	Цумада	8	75	894	46.050677999999998	46.055053000000001	42.484588000000002	42.481164	0103000020E610000001000000050000003750E09D7C0647409B012EC8963D45403750E09D7C0647405C04C6FA063E4540FA4509FA0B0747405C04C6FA063E4540FA4509FA0B0747409B012EC8963D45403750E09D7C0647409B012EC8963D4540
60640	Цедатли	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
32629	Хуштада	8	75	894	46.163344000000002	46.176234999999998	42.522601999999999	42.513956	0103000020E61000000100000005000000B9FFC874E81447409FCA694FC9414540B9FFC874E81447407F69519FE44245408DB454DE8E1647407F69519FE44245408DB454DE8E1647409FCA694FC9414540B9FFC874E81447409FCA694FC9414540
60669	Хушет	8	75	894	45.768076999999998	45.778497000000002	42.40166	42.395181000000001	0103000020E61000000100000005000000A7E7DD5850E2464013807F4A95324540A7E7DD5850E24640410E4A98693345405E8429CAA5E34640410E4A98693345405E8429CAA5E3464013807F4A95324540A7E7DD5850E2464013807F4A95324540
8987	Хонох	8	75	894	46.128157000000002	46.133007999999997	42.333632999999999	42.330207000000001	0103000020E6100000010000000500000072E0D5726710474084F41439442A454072E0D57267104740E5EE737CB42A45409D0DF96706114740E5EE737CB42A45409D0DF9670611474084F41439442A454072E0D5726710474084F41439442A4540
8936	Хварши	8	75	894	46.103526000000002	46.109355999999998	42.354430999999998	42.350473000000001	0103000020E6100000010000000500000092240857400D4740C5909C4CDC2C454092240857400D474023D8B8FE5D2D454089CF9D60FF0D474023D8B8FE5D2D454089CF9D60FF0D4740C5909C4CDC2C454092240857400D4740C5909C4CDC2C4540
8630	Хвайни	8	75	894	45.967081	45.971949000000002	42.416804999999997	42.413203000000003	0103000020E610000001000000050000009FCA694FC9FB4640F7CDFDD5E33445409FCA694FC9FB464096E7C1DD59354540A13028D368FC464096E7C1DD59354540A13028D368FC4640F7CDFDD5E33445409FCA694FC9FB4640F7CDFDD5E3344540
60638	Ургалай	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
32621	Тлондода	8	75	894	46.193986000000002	46.201279999999997	42.527532000000001	42.522481999999997	0103000020E61000000100000005000000E1F08288D4184740D45FAFB0E0424540E1F08288D4184740F7CB272B8643454060AB048BC3194740F7CB272B8643454060AB048BC3194740D45FAFB0E0424540E1F08288D4184740D45FAFB0E0424540
60622	Тленхора	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
7834	Тисси-Ахитли	8	75	894	46.102851999999999	46.112113999999998	42.506034	42.498655999999997	0103000020E61000000100000005000000022A1C412A0D474022FAB5F5D33F4540022A1C412A0D47400055DCB8C54045403DB665C0590E47400055DCB8C54045403DB665C0590E474022FAB5F5D33F4540022A1C412A0D474022FAB5F5D33F4540
32965	Тисси	8	75	894	46.141101999999997	46.148414000000002	42.494441000000002	42.487780000000001	0103000020E6100000010000000500000039B35DA10F1247404AD235936F3E454039B35DA10F1247409966BAD7493F45406022DE3AFF1247409966BAD7493F45406022DE3AFF1247404AD235936F3E454039B35DA10F1247404AD235936F3E4540
32669	Тинди	8	75	894	46.128695999999998	46.150499000000003	42.466700000000003	42.446877000000001	0103000020E6100000010000000500000021904B1C79104740D42AFA433339454021904B1C7910474088855AD3BC3B4540558A1D8D4313474088855AD3BC3B4540558A1D8D43134740D42AFA433339454021904B1C79104740D42AFA4333394540
60618	Тенли	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
8729	Сильди	8	75	894	45.922659000000003	45.945970000000003	42.456949000000002	42.445292999999999	0103000020E61000000100000005000000172EABB019F64640A1116C5CFF384540172EABB019F646404F78094E7D3A4540A27F828B15F946404F78094E7D3A4540A27F828B15F94640A1116C5CFF384540172EABB019F64640A1116C5CFF384540
8443	Саситли	8	75	894	45.992753999999998	46.000920000000001	42.498995000000001	42.492088000000003	0103000020E61000000100000005000000917C259012FF4640856055BDFC3E4540917C259012FF46400BEF7211DF3F4540C7F484251E0047400BEF7211DF3F4540C7F484251E004740856055BDFC3E4540917C259012FF4640856055BDFC3E4540
8847	Сантлада	8	75	894	46.072974000000002	46.084868	42.392997000000001	42.377927	0103000020E61000000100000005000000AABA47365709474040A374E95F304540AABA4736570947408B36C7B94D3245400C3D62F4DC0A47408B36C7B94D3245400C3D62F4DC0A474040A374E95F304540AABA47365709474040A374E95F304540
8396	Ричаганих	8	75	894	46.054701999999999	46.061107	42.500630000000001	42.496130000000001	0103000020E610000001000000050000004D83A2790007474041481630813F45404D83A27900074740C0B2D2A4144045404147AB5AD2074740C0B2D2A4144045404147AB5AD207474041481630813F45404D83A2790007474041481630813F4540
60619	Ново-Хуштада	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
32925	Нижние Хваршини	8	75	894	45.860846000000002	45.875236999999998	42.415953000000002	42.399576000000003	0103000020E610000001000000050000003B72A43330EE46401D226E4E253345403B72A43330EE464028D6A9F23D354540E49F19C407F0464028D6A9F23D354540E49F19C407F046401D226E4E253345403B72A43330EE46401D226E4E25334540
32758	Нижние Гаквари	8	75	894	46.046374999999998	46.056857999999998	42.542001999999997	42.533911000000003	0103000020E610000001000000050000000E2DB29DEF054740C2FC1532574445400E2DB29DEF054740EC2E5052604545400B42791F47074740EC2E5052604545400B42791F47074740C2FC1532574445400E2DB29DEF054740C2FC153257444540
32912	Метрада	8	75	894	45.866855999999999	45.901881000000003	42.402704999999997	42.385266000000001	0103000020E61000000100000005000000B22B2D23F5EE46406021736550314540B22B2D23F5EE4640C47762D68B33454020F12BD670F34640C47762D68B33454020F12BD670F346406021736550314540B22B2D23F5EE46406021736550314540
60625	Маштихи	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
7044	Кочали	8	75	894	46.111457999999999	46.119255000000003	42.528728000000001	42.525134000000001	0103000020E6100000010000000500000054707841440E4740430246973743454054707841440E4740603DEE5BAD434540377172BF430F4740603DEE5BAD434540377172BF430F4740430246973743454054707841440E47404302469737434540
60667	Колих	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
8513	Кеди	8	75	894	45.960864000000001	45.969873999999997	42.528973999999998	42.521963999999997	0103000020E61000000100000005000000AEF36F97FDFA46403CD862B7CF424540AEF36F97FDFA46409737876BB5434540CF9ECBD424FC46409737876BB5434540CF9ECBD424FC46403CD862B7CF424540AEF36F97FDFA46403CD862B7CF424540
8887	Квантлада	8	75	894	46.061987999999999	46.065885999999999	42.393296999999997	42.390467000000001	0103000020E610000001000000050000004A5F0839EF074740689599D2FA3145404A5F0839EF074740B54E5C8E57324540D3A1D3F36E084740B54E5C8E57324540D3A1D3F36E084740689599D2FA3145404A5F0839EF074740689599D2FA314540
32608	Кванада	8	75	894	46.167242999999999	46.177258999999999	42.567419000000001	42.556992999999999	0103000020E6100000010000000500000012BEF73768154740EB8CEF8B4B47454012BEF737681547408410902FA1484540F9F5436CB01647408410902FA1484540F9F5436CB0164740EB8CEF8B4B47454012BEF73768154740EB8CEF8B4B474540
32868	Инхоквари	8	75	894	46.041685999999999	46.065733999999999	42.418182000000002	42.410060999999999	0103000020E61000000100000005000000BC5983F755054740BA2EFCE07C344540BC5983F75505474050E3DEFC863545401D1EC2F86908474050E3DEFC863545401D1EC2F869084740BA2EFCE07C344540BC5983F755054740BA2EFCE07C344540
7191	Гимерсо	8	75	894	46.221815999999997	46.231563000000001	42.564138999999997	42.558380999999997	0103000020E6100000010000000500000061DD7877641C474098DA52077947454061DD7877641C4740F6B2EDB43548454059FB3BDBA31D4740F6B2EDB43548454059FB3BDBA31D474098DA52077947454061DD7877641C474098DA520779474540
32607	Гигих	8	75	894	46.101692999999997	46.105339999999998	42.533738	42.530847999999999	0103000020E61000000100000005000000B69DB646040D4740D192C7D3F2434540B69DB646040D4740F450DB8651444540F67AF7C77B0D4740F450DB8651444540F67AF7C77B0D4740D192C7D3F2434540B69DB646040D4740D192C7D3F2434540
57895	Гигатль	8	75	894	46.091641000000003	46.102609000000001	42.584660999999997	42.578719999999997	0103000020E6100000010000000500000083FC6CE4BA0B474043C5387F134A454083FC6CE4BA0B4740921FF12BD64A45403CA3AD4A220D4740921FF12BD64A45403CA3AD4A220D474043C5387F134A454083FC6CE4BA0B474043C5387F134A4540
7979	Гигатли-Урух	8	75	894	46.138883	46.151333999999999	42.595061999999999	42.579051	0103000020E61000000100000005000000357C0BEBC6114740A9DBD9571E4A4540357C0BEBC6114740D28BDAFD2A4C4540ED629AE95E134740D28BDAFD2A4C4540ED629AE95E134740A9DBD9571E4A4540357C0BEBC6114740A9DBD9571E4A4540
60632	Гвинайчи	8	75	894	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
7921	Гачитли	8	75	894	46.087463999999997	46.091352999999998	42.552410999999999	42.549168999999999	0103000020E61000000100000005000000E6C93505320B47400F7D772B4B464540E6C93505320B4740AF795567B54645401CB28174B10B4740AF795567B54645401CB28174B10B47400F7D772B4B464540E6C93505320B47400F7D772B4B464540
8652	Гакко	8	75	894	45.880465000000001	45.886304000000003	42.473503000000001	42.468820999999998	0103000020E61000000100000005000000E622BE13B3F04640C9569753023C4540E622BE13B3F0464069C70DBF9B3C45403128D36872F1464069C70DBF9B3C45403128D36872F14640C9569753023C4540E622BE13B3F04640C9569753023C4540
7879	Гадири	8	75	894	46.064717999999999	46.075398999999997	42.572876999999998	42.562047	0103000020E6100000010000000500000034BBEEAD480847404FE8F527F147454034BBEEAD48084740B7D09508544945405793A7ACA6094740B7D09508544945405793A7ACA60947404FE8F527F147454034BBEEAD480847404FE8F527F1474540
60671	Гадаичи	8	75	894	46.064169999999997	46.075614999999999	42.471701000000003	42.461438999999999	0103000020E6100000010000000500000031B1F9B836084740AA0CE36E103B454031B1F9B836084740C93EC8B2603C4540240B98C0AD094740C93EC8B2603C4540240B98C0AD094740AA0CE36E103B454031B1F9B836084740AA0CE36E103B4540
32930	Верхние Хваршини	8	75	894	45.830824	45.850954999999999	42.419840000000001	42.406312999999997	0103000020E61000000100000005000000AF5DDA7058EA464046787B1002344540AF5DDA7058EA4640BDC62E51BD35454010AFEB17ECEC4640BDC62E51BD35454010AFEB17ECEC464046787B1002344540AF5DDA7058EA464046787B1002344540
8197	Верхние Гаквари	8	75	894	46.023459000000003	46.040266000000003	42.552404000000003	42.542493999999998	0103000020E6100000010000000500000000E65AB4000347405B2382717045454000E65AB400034740FD169D2CB54645400492B06F27054740FD169D2CB54645400492B06F270547405B2382717045454000E65AB4000347405B23827170454540
7775	Акнада	8	75	894	46.167836000000001	46.173665999999997	42.403604000000001	42.397112	0103000020E61000000100000005000000B58B69A67B154740B16CE690D4324540B58B69A67B1547407444BE4BA9334540AC36FFAF3A1647407444BE4BA9334540AC36FFAF3A164740B16CE690D4324540B58B69A67B154740B16CE690D4324540
6904	Агвали	8	75	894	46.113793000000001	46.131607000000002	42.544938000000002	42.535432	0103000020E61000000100000005000000C2C1DEC4900E4740AE9D280989444540C2C1DEC4900E4740802C4487C04545405C76887FD8104740802C4487C04545405C76887FD8104740AE9D280989444540C2C1DEC4900E4740AE9D280989444540
53603	кутан СПК Тлайлухский	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
5404	Эбута	8	75	621	46.661684999999999	46.672877999999997	42.596330000000002	42.588033000000003	0103000020E610000001000000050000007BA01518B254474001FC53AA444B45407BA01518B2544740D5CF9B8A544C45405419C6DD20564740D5CF9B8A544C45405419C6DD2056474001FC53AA444B45407BA01518B254474001FC53AA444B4540
53893	Шотода	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
6103	Цельмес	8	75	621	46.538435999999997	46.548425000000002	42.624538000000001	42.619495000000001	0103000020E61000000100000005000000997E8978EB4447408C84B69C4B4F4540997E8978EB444740FC8D76DCF04F454087A757CA32464740FC8D76DCF04F454087A757CA324647408C84B69C4B4F4540997E8978EB4447408C84B69C4B4F4540
5670	Цалкита	8	75	621	46.572068999999999	46.575240000000001	42.619295999999999	42.616774999999997	0103000020E610000001000000050000001807978E39494740C5FEB27BF24E45401807978E3949474095456117454F4540EFACDD76A149474095456117454F4540EFACDD76A1494740C5FEB27BF24E45401807978E39494740C5FEB27BF24E4540
3966	Хунзах	8	75	621	46.696818	46.713400999999998	42.550172000000003	42.535252999999997	0103000020E61000000100000005000000CFA10C5531594740FE0A992B83444540CFA10C553159474064963D096C46454083F755B9505B474064963D096C46454083F755B9505B4740FE0A992B83444540CFA10C5531594740FE0A992B83444540
4194	Хини	8	75	621	46.702872999999997	46.709457	42.533079999999998	42.525333000000003	0103000020E61000000100000005000000E61E12BEF75947403A419B1C3E434540E61E12BEF75947406A1327F73B4445408A75AA7CCF5A47406A1327F73B4445408A75AA7CCF5A47403A419B1C3E434540E61E12BEF75947403A419B1C3E434540
6647	Хиндах	8	75	621	46.570667999999998	46.582858000000002	42.664481000000002	42.658534000000003	0103000020E61000000100000005000000D66F26A60B494740ECA694D74A544540D66F26A60B4947401DE8A1B60D554540221B48179B4A47401DE8A1B60D554540221B48179B4A4740ECA694D74A544540D66F26A60B494740ECA694D74A544540
5610	Химакоро	8	75	621	46.579326999999999	46.588104000000001	42.587741000000001	42.583652000000001	0103000020E610000001000000050000004B581B63274A47405C1FD61BB54A45404B581B63274A474059C2DA183B4B4540CA52EBFD464B474059C2DA183B4B4540CA52EBFD464B47405C1FD61BB54A45404B581B63274A47405C1FD61BB54A4540
53439	Хачта	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
4605	Хариколо	8	75	621	46.803232000000001	46.812978999999999	42.548856999999998	42.542009	0103000020E61000000100000005000000E38C614ED06647409F91088D60454540E38C614ED0664740209738F240464540DAAA24B20F684740209738F240464540DAAA24B20F6847409F91088D60454540E38C614ED06647409F91088D60454540
6437	Харахи	8	75	621	46.514316000000001	46.527242999999999	42.649389999999997	42.639488999999998	0103000020E610000001000000050000009FE74F1BD54147406C938AC6DA5145409FE74F1BD5414740BA2C26361F534540C005D9B27C434740BA2C26361F534540C005D9B27C4347406C938AC6DA5145409FE74F1BD54147406C938AC6DA514540
5027	Уздалросо	8	75	621	46.850852000000003	46.858145999999998	42.488244999999999	42.483930000000001	0103000020E610000001000000050000003CDEE4B7E86C4740D2C6116BF13D45403CDEE4B7E86C4740BFB7E9CF7E3E4540BB9866BAD76D4740BFB7E9CF7E3E4540BB9866BAD76D4740D2C6116BF13D45403CDEE4B7E86C4740D2C6116BF13D4540
6031	Тлайлух	8	75	621	46.519427999999998	46.529173999999998	42.624186000000002	42.617345999999998	0103000020E610000001000000050000003750E09D7C42474080289831054F45403750E09D7C4247407F4FAC53E54F45405EF23FF9BB4347407F4FAC53E54F45405EF23FF9BB43474080289831054F45403750E09D7C42474080289831054F4540
5365	Тануси	8	75	621	46.688679	46.696970999999998	42.585662999999997	42.579231	0103000020E6100000010000000500000093382BA22658474029EACC3D244A454093382BA22658474016BD5301F74A454055A181583659474016BD5301F74A454055A181583659474029EACC3D244A454093382BA22658474029EACC3D244A4540
53972	Тадколо	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
5087	Тагада	8	75	621	46.863078000000002	46.871854999999996	42.501348	42.495770999999998	0103000020E61000000100000005000000D4F20357796E474011A7936C753F4540D4F20357796E47401FF5D72B2C40454052EDD3F1986F47401FF5D72B2C40454052EDD3F1986F474011A7936C753F4540D4F20357796E474011A7936C753F4540
5832	Сиух	8	75	621	46.542802000000002	46.551569000000001	42.602933	42.597352000000001	0103000020E61000000100000005000000091A33897A454740A019C407764C4540091A33897A454740EF5696E82C4D4540643E20D099464740EF5696E82C4D4540643E20D099464740A019C407764C4540091A33897A454740A019C407764C4540
6774	Очло	8	75	621	46.640124999999998	46.652557999999999	42.645325	42.639011000000004	0103000020E610000001000000050000000E2DB29DEF5147406364C91CCB5145400E2DB29DEF514740462575029A524540205F420587534740462575029A524540205F4205875347406364C91CCB5145400E2DB29DEF5147406364C91CCB514540
6522	Орота	8	75	621	46.528230999999998	46.543852999999999	42.663784999999997	42.655318000000001	0103000020E61000000100000005000000DFDDCA129D434740753DD175E1534540DFDDCA129D434740A54929E8F65445406E6AA0F99C454740A54929E8F65445406E6AA0F99C454740753DD175E1534540DFDDCA129D434740753DD175E1534540
4880	Оркачи	8	75	621	46.812952000000003	46.819392999999998	42.607684999999996	42.601925000000001	0103000020E61000000100000005000000E19BA6CF0E68474089D2DEE00B4D4540E19BA6CF0E68474087A2409FC84D454021C9ACDEE168474087A2409FC84D454021C9ACDEE168474089D2DEE00B4D4540E19BA6CF0E68474089D2DEE00B4D4540
53786	Ондокоро	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
5191	Обода	8	75	621	46.655298000000002	46.680154000000002	42.582284000000001	42.572034000000002	0103000020E610000001000000050000002E910BCEE05347409C19FD68384945402E910BCEE0534740F67D3848884A45402E1F49490F574740F67D3848884A45402E1F49490F5747409C19FD68384945402E910BCEE05347409C19FD6838494540
4269	Накитль	8	75	621	46.652431999999997	46.665089000000002	42.510114999999999	42.503461999999999	0103000020E61000000100000005000000936E4BE482534740AE635C7171404540936E4BE4825347407A19C5724B414540F5F6E7A2215547407A19C5724B414540F5F6E7A221554740AE635C7171404540936E4BE482534740AE635C7171404540
6218	Мушули	8	75	621	46.496268999999998	46.504803000000003	42.636617000000001	42.630673999999999	0103000020E6100000010000000500000062821ABE853F47400038F6ECB950454062821ABE853F4740F08975AA7C5145401BF67B629D404740F08975AA7C5145401BF67B629D4047400038F6ECB950454062821ABE853F47400038F6ECB9504540
6722	Мочох	8	75	621	46.608406000000002	46.617676000000003	42.634202000000002	42.628616999999998	0103000020E610000001000000050000005858703FE04D4740D55A9885765045405858703FE04D47406687F8872D51454016C3D501104F47406687F8872D51454016C3D501104F4740D55A9885765045405858703FE04D4740D55A988576504540
5004	Малый Гоцатль	8	75	621	46.882804999999998	46.890116999999996	42.506678999999998	42.500377	0103000020E6100000010000000500000065DF15C1FF704740D655815A0C40454065DF15C1FF704740F54883DBDA4045408B4E965AEF714740F54883DBDA4045408B4E965AEF714740D655815A0C40454065DF15C1FF704740D655815A0C404540
53459	Малая Амуша	8	75	621	46.485795000000003	46.491643000000003	42.652275000000003	42.648136999999998	0103000020E61000000100000005000000B9C7D2872E3E4740ED293927F6524540B9C7D2872E3E4740CC7F48BF7D53454057276728EE3E4740CC7F48BF7D53454057276728EE3E4740ED293927F6524540B9C7D2872E3E4740ED293927F6524540
6673	Коло	8	75	621	46.562609999999999	46.575051000000002	42.659621000000001	42.653680000000001	0103000020E610000001000000050000008733BF9A034847404F0647C9AB5345408733BF9A034847409E60FF756E5445401C446B459B4947409E60FF756E5445401C446B459B4947404F0647C9AB5345408733BF9A034847404F0647C9AB534540
53939	Кахикал	8	75	621	46.869141999999997	46.876947999999999	42.500968999999998	42.493949000000001	0103000020E610000001000000050000003ECA880B406F47402A7288B8393F45403ECA880B406F4740A8A78FC01F404540742502D53F704740A8A78FC01F404540742502D53F7047402A7288B8393F45403ECA880B406F47402A7288B8393F4540
4203	Заиб	8	75	621	46.703223000000001	46.714424999999999	42.494540999999998	42.488072000000003	0103000020E61000000100000005000000C3651536035A4740F20BAF24793E4540C3651536035A4740FCC3961E4D3F4540EF384547725B4740FCC3961E4D3F4540EF384547725B4740F20BAF24793E4540C3651536035A4740F20BAF24793E4540
5253	Гортколо	8	75	621	46.633622000000003	46.641669999999998	42.578003000000002	42.570087999999998	0103000020E61000000100000005000000580394861A514740C8EBC1A4F8484540580394861A514740B5FE9600FC4945408369183E22524740B5FE9600FC4945408369183E22524740C8EBC1A4F8484540580394861A514740C8EBC1A4F8484540
4094	Гонох	8	75	621	46.684969000000002	46.692506000000002	42.564430999999999	42.555425999999997	0103000020E610000001000000050000000DE36E10AD5747408EACFC32184745400DE36E10AD5747409EEC66463F48454053245F09A45847409EEC66463F48454053245F09A45847408EACFC32184745400DE36E10AD5747408EACFC3218474540
4084	Геничутль	8	75	621	46.735131000000003	46.743414000000001	42.566304000000002	42.561442999999997	0103000020E610000001000000050000004DA3C9C5185E4740B8C83D5DDD4745404DA3C9C5185E474008CC43A67C484540BCB1A030285F474008CC43A67C484540BCB1A030285F4740B8C83D5DDD4745404DA3C9C5185E4740B8C83D5DDD474540
5520	Гацалух	8	75	621	46.645848000000001	46.654867000000003	42.594192999999997	42.590415999999998	0103000020E61000000100000005000000F017B325AB5247407F8461C0924B4540F017B325AB5247408D4127840E4C4540651D8EAED25347408D4127840E4C4540651D8EAED25347407F8461C0924B4540F017B325AB5247407F8461C0924B4540
4773	Буцра	8	75	621	46.763005999999997	46.773713999999998	42.592334000000001	42.584243000000001	0103000020E610000001000000050000006D533C2EAA6147405EF58079C84A45406D533C2EAA6147408927BB99D14B45408A3A730F096347408927BB99D14B45408A3A730F096347405EF58079C84A45406D533C2EAA6147405EF58079C84A4540
4933	Большой Гоцатль	8	75	621	46.875878999999998	46.893351000000003	42.526860999999997	42.512453999999998	0103000020E61000000100000005000000682096CD1C704740295AB91798414540682096CD1C704740D844662E70434540A96C585359724740D844662E70434540A96C585359724740295AB91798414540682096CD1C704740295AB91798414540
4500	Батлаич	8	75	621	46.742883999999997	46.759700000000002	42.559085000000003	42.547376	0103000020E610000001000000050000005F5CAAD2165F4740C24EB16A104645405F5CAAD2165F47409357E71890474540B7627FD93D6147409357E71890474540B7627FD93D614740C24EB16A104645405F5CAAD2165F4740C24EB16A10464540
3980	Баитль	8	75	621	46.669589999999999	46.678358000000003	42.550955999999999	42.545549000000001	0103000020E6100000010000000500000044DD0720B5554740C9AEB48CD445454044DD0720B55547407AC4E8B985464540707D586FD45647407AC4E8B985464540707D586FD4564740C9AEB48CD445454044DD0720B5554740C9AEB48CD4454540
53802	Ахтини	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
5561	Ахалчи	8	75	621	46.627333	46.635615999999999	42.598897999999998	42.590974000000003	0103000020E61000000100000005000000CD599F724C504740A6643909A54B4540CD599F724C504740E5D18DB0A84C45403C6876DD5B514740E5D18DB0A84C45403C6876DD5B514740A6643909A54B4540CD599F724C504740A6643909A54B4540
4450	Арани	8	75	621	46.717821000000001	46.732894000000002	42.560758999999997	42.550119000000002	0103000020E61000000100000005000000E6B0FB8EE15B474041F4A44C6A464540E6B0FB8EE15B474005F86EF3C6474540A2B77878CF5D474005F86EF3C6474540A2B77878CF5D474041F4A44C6A464540E6B0FB8EE15B474041F4A44C6A464540
53935	Арада	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
53599	Амущи	8	75	621	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
53449	Амишти	8	75	621	46.542828999999998	46.558190000000003	42.634971999999998	42.626156000000002	0103000020E610000001000000050000000229B16B7B454740DB183BE1255045400229B16B7B45474017F032C346514540257A19C57247474017F032C346514540257A19C572474740DB183BE1255045400229B16B7B454740DB183BE125504540
53829	Юхари-Ярак	8	75	416	47.945593000000002	47.950865999999998	41.839064	41.833851000000003	0103000020E61000000100000005000000CC29013109F94740535E2BA1BBEA4440CC29013109F947401FA0FB7266EB44406D7022FAB5F947401FA0FB7266EB44406D7022FAB5F94740535E2BA1BBEA4440CC29013109F94740535E2BA1BBEA4440
17157	Юхари-Захит	8	75	416	47.934660999999998	47.945287999999998	41.701248999999997	41.690477000000001	0103000020E610000001000000050000005FECBDF8A2F74740F2D1E28C61D844405FECBDF8A2F7474025ADF886C2D944408FA67A32FFF8474025ADF886C2D944408FA67A32FFF84740F2D1E28C61D844405FECBDF8A2F74740F2D1E28C61D84440
3863	Юхари-Архит	8	75	416	47.954943999999998	47.963603999999997	41.743116999999998	41.736443000000001	0103000020E6100000010000000500000076C1E09A3BFA47401F2FA4C343DE444076C1E09A3BFA4740020D36751EDF4440BB25396057FB4740020D36751EDF4440BB25396057FB47401F2FA4C343DE444076C1E09A3BFA47401F2FA4C343DE4440
3767	Чувек	8	75	416	47.896042000000001	47.904477	41.812973999999997	41.805062999999997	0103000020E61000000100000005000000D5EB1681B1F247401D1CEC4D0CE74440D5EB1681B1F24740C83F33880FE84440FA7DFFE6C5F34740C83F33880FE84440FA7DFFE6C5F347401D1CEC4D0CE74440D5EB1681B1F247401D1CEC4D0CE74440
3700	Чиликар	8	75	416	48.059579999999997	48.071500999999998	41.746285999999998	41.740439000000002	0103000020E6100000010000000500000072BF4351A00748406BD784B4C6DE444072BF4351A007484038BBB54C86DF4440CE50DCF12609484038BBB54C86DF4440CE50DCF1260948406BD784B4C6DE444072BF4351A00748406BD784B4C6DE4440
3674	Чере	8	75	416	48.036889000000002	48.046348000000002	41.812173999999999	41.804122	0103000020E61000000100000005000000844A5CC7B80448403FFF3D78EDE64440844A5CC7B8044840AC545051F5E74440151E34BBEE054840AC545051F5E74440151E34BBEE0548403FFF3D78EDE64440844A5CC7B80448403FFF3D78EDE64440
3593	Цудук	8	75	416	47.892287000000003	47.899258000000003	41.785111999999998	41.780774999999998	0103000020E61000000100000005000000AFD2DD7536F247406744696FF0E34440AFD2DD7536F247403CD9CD8C7EE444404C55DAE21AF347403CD9CD8C7EE444404C55DAE21AF347406744696FF0E34440AFD2DD7536F247406744696FF0E34440
32423	Цнал	8	75	416	47.991847	48.003166	41.700327000000001	41.69218	0103000020E610000001000000050000005FD1ADD7F4FE4740FF78AF5A99D844405FD1ADD7F4FE4740BEC0AC50A4D94440C53A55BE67004840BEC0AC50A4D94440C53A55BE67004840FF78AF5A99D844405FD1ADD7F4FE4740FF78AF5A99D84440
3567	Цлак	8	75	416	47.933852000000002	47.948746	41.715291000000001	41.708835999999998	0103000020E61000000100000005000000F0A65B7688F747401D1D5723BBDA4440F0A65B7688F74740C30FCEA78EDB4440FC1A498270F94740C30FCEA78EDB4440FC1A498270F947401D1D5723BBDA4440F0A65B7688F747401D1D5723BBDA4440
3459	Хоредж	8	75	416	47.863872999999998	47.87574	41.752797999999999	41.745787999999997	0103000020E61000000100000005000000DE72F56393EE4740E7DF2EFB75DF4440DE72F56393EE4740423F53AF5BE0444047E6913F18F04740423F53AF5BE0444047E6913F18F04740E7DF2EFB75DF4440DE72F56393EE4740E7DF2EFB75DF4440
3387	Хив	8	75	416	47.920692000000003	47.937742	41.760862000000003	41.749380000000002	0103000020E610000001000000050000002CD8463CD9F54740642310AFEBDF44402CD8463CD9F5474074620FED63E14440F60A0BEE07F8474074620FED63E14440F60A0BEE07F84740642310AFEBDF44402CD8463CD9F54740642310AFEBDF4440
3804	Фурдаг	8	75	416	47.859336999999996	47.863926999999997	41.865110000000001	41.861691999999998	0103000020E61000000100000005000000129F3BC1FEED4740C79C67EC4BEE4440129F3BC1FEED4740A6B8AAECBBEE4440D190F12895EE4740A6B8AAECBBEE4440D190F12895EE4740C79C67EC4BEE4440129F3BC1FEED4740C79C67EC4BEE4440
3364	Уртиль	8	75	416	47.891784000000001	47.896841000000002	41.893070999999999	41.889111	0103000020E610000001000000050000004C8C65FA25F24740C6C1A563CEF144404C8C65FA25F24740C500892650F24440215B96AFCBF24740C500892650F24440215B96AFCBF24740C6C1A563CEF144404C8C65FA25F24740C6C1A563CEF14440
53584	Урга	8	75	416	47.719693999999997	48.165590000000002	41.904694999999997	41.659799	0103000020E610000001000000050000004F90D8EE1EDC47407D772B4B74D444404F90D8EE1EDC474067EDB60BCDF34440B745990D3215484067EDB60BCDF34440B745990D321548407D772B4B74D444404F90D8EE1EDC47407D772B4B74D44440
3038	Межгюль	8	75	416	48.001342000000001	48.012912999999998	41.810481000000003	41.801461000000003	0103000020E610000001000000050000003D0E83F92B0048407E02284696E644403D0E83F92B004840C38366D7BDE74440BC581822A7014840C38366D7BDE74440BC581822A70148407E02284696E644403D0E83F92B0048407E02284696E64440
3008	Ляхля	8	75	416	47.866694000000003	47.878236999999999	41.885069999999999	41.879779999999997	0103000020E61000000100000005000000D9D138D4EFEE474062D68BA19CF04440D9D138D4EFEE4740DA5548F949F144408E91EC116AF04740DA5548F949F144408E91EC116AF0474062D68BA19CF04440D9D138D4EFEE474062D68BA19CF04440
2916	Лака	8	75	416	47.875048	47.885154	41.760499000000003	41.754029000000003	0103000020E610000001000000050000001137A79201F04740289EB30584E044401137A79201F0474003D2FE0758E1444038F6ECB94CF1474003D2FE0758E1444038F6ECB94CF14740289EB30584E044401137A79201F04740289EB30584E04440
2882	Куштиль	8	75	416	47.881740999999998	47.890895	41.833905000000001	41.825614000000002	0103000020E610000001000000050000006B459BE3DCF04740548F34B8ADE944406B459BE3DCF04740467C2766BDEA4440C095ECD808F24740467C2766BDEA4440C095ECD808F24740548F34B8ADE944406B459BE3DCF04740548F34B8ADE94440
53510	Куг	8	75	416	47.957846000000004	47.970368999999998	41.776552000000002	41.766122000000003	0103000020E610000001000000050000005E4D9EB29AFA4740815F234910E244405E4D9EB29AFA47405BD2510E66E34440AF06280D35FC47405BD2510E66E34440AF06280D35FC4740815F234910E244405E4D9EB29AFA4740815F234910E24440
2774	Кувиг	8	75	416	47.884768000000001	47.889088999999998	41.886257999999998	41.881760999999997	0103000020E610000001000000050000000F46EC1340F14740B2F1608BDDF044400F46EC1340F14740C0E8F2E670F14440DE1D19ABCDF14740C0E8F2E670F14440DE1D19ABCDF14740B2F1608BDDF044400F46EC1340F14740B2F1608BDDF04440
2686	Кошкент	8	75	416	48.033808000000001	48.046716000000004	41.743675000000003	41.738253	0103000020E61000000100000005000000ED2B0FD253044840429605137FDE4440ED2B0FD25304484029ED0DBE30DF4440981936CAFA05484029ED0DBE30DF4440981936CAFA054840429605137FDE4440ED2B0FD253044840429605137FDE4440
2671	Конциль	8	75	416	48.015832000000003	48.026325	41.757136000000003	41.748888999999998	0103000020E610000001000000050000007A1D71C806024840C5AA4198DBDF44407A1D71C806024840E84F1BD5E9E044409A081B9E5E034840E84F1BD5E9E044409A081B9E5E034840C5AA4198DBDF44407A1D71C806024840C5AA4198DBDF4440
53788	Конди	8	75	416	47.870987999999997	47.880609	41.804780999999998	41.79363	0103000020E61000000100000005000000AE9AE7887CEF4740EF8FF7AA95E54440AE9AE7887CEF474099B8551003E7444019C8B3CBB7F0474099B8551003E7444019C8B3CBB7F04740EF8FF7AA95E54440AE9AE7887CEF4740EF8FF7AA95E54440
2549	Зильдик	8	75	416	47.984571000000003	47.994442999999997	41.815857000000001	41.808833999999997	0103000020E6100000010000000500000086CB2A6C06FE474049F25CDF87E7444086CB2A6C06FE4740399B8E006EE84440395E81E849FF4740399B8E006EE84440395E81E849FF474049F25CDF87E7444086CB2A6C06FE474049F25CDF87E74440
53927	Дардакент	8	75	416	48.013064999999997	48.026387	41.74494	41.738427000000001	0103000020E6100000010000000500000072DC291DAC014840E0BDA3C684DE444072DC291DAC014840BABDA4315ADF4440100533A660034840BABDA4315ADF4440100533A660034840E0BDA3C684DE444072DC291DAC014840E0BDA3C684DE4440
23361	Вертиль	8	75	416	47.856741	47.861097000000001	41.875019999999999	41.869447000000001	0103000020E61000000100000005000000381268B0A9ED47407B4D0F0A4AEF4440381268B0A9ED474047ACC5A700F0444084D72E6D38EE474047ACC5A700F0444084D72E6D38EE47407B4D0F0A4AEF4440381268B0A9ED47407B4D0F0A4AEF4440
3489	Ашага-Цинит	8	75	416	48.001486	48.015320000000003	41.728233000000003	41.721234000000003	0103000020E6100000010000000500000070B378B130004840B3614D6551DC444070B378B1300048401A6F2BBD36DD4440C47C7901F60148401A6F2BBD36DD4440C47C7901F6014840B3614D6551DC444070B378B130004840B3614D6551DC4440
2431	Ашага-Архит	8	75	416	47.962122000000001	47.981813000000002	41.742175000000003	41.731153999999997	0103000020E610000001000000050000008D614ED026FB4740772B4B7496DD44408D614ED026FB474054742497FFDE4440D2E4620CACFD474054742497FFDE4440D2E4620CACFD4740772B4B7496DD44408D614ED026FB4740772B4B7496DD4440
2224	Атрик	8	75	416	47.778542000000002	47.782404999999997	41.881385000000002	41.879035000000002	0103000020E61000000100000005000000FE47A643A7E347400A85083884F04440FE47A643A7E34740AD174339D1F044400A9DD7D825E44740AD174339D1F044400A9DD7D825E447400A85083884F04440FE47A643A7E347400A85083884F04440
2339	Асакент	8	75	416	48.003858000000001	48.013074000000003	41.757989999999999	41.754519999999999	0103000020E61000000100000005000000FBE93F6B7E004840C616821C94E04440FBE93F6B7E004840F758FAD005E14440C636A968AC014840F758FAD005E14440C636A968AC014840C616821C94E04440FBE93F6B7E004840C616821C94E04440
2317	Арчуг	8	75	416	47.856965000000002	47.862713999999997	41.786490000000001	41.781621999999999	0103000020E6100000010000000500000088687407B1ED4740C4EA8F300CE4444088687407B1ED4740C6504EB4ABE4444092E68F696DEE4740C6504EB4ABE4444092E68F696DEE4740C4EA8F300CE4444088687407B1ED4740C4EA8F300CE44440
706	Эндирей	8	75	22	46.641948999999997	46.663849999999996	43.181224999999998	43.155042000000002	0103000020E61000000100000005000000965984622B524740D3C08F6AD8934540965984622B524740DA1B7C61329745408CB96B09F9544740DA1B7C61329745408CB96B09F9544740D3C08F6AD8934540965984622B524740D3C08F6AD8934540
31910	Шагада	8	75	22	46.717478999999997	46.731896999999996	43.481681000000002	43.474851000000001	0103000020E610000001000000050000008C48145AD65B474088BCE5EAC7BC45408C48145AD65B4740630D17B9A7BD45402F8507CDAE5D4740630D17B9A7BD45402F8507CDAE5D474088BCE5EAC7BC45408C48145AD65B474088BCE5EAC7BC4540
30844	Чагаротар	8	75	22	46.527414	46.543475999999998	43.474891	43.463016000000003	0103000020E61000000100000005000000EDB94C4D824347402BC3B81B44BB4540EDB94C4D824347401615713AC9BC454098141F9F904547401615713AC9BC454098141F9F904547402BC3B81B44BB4540EDB94C4D824347402BC3B81B44BB4540
53640	Цияб Ичичали	8	75	22	46.328139999999998	47.011893000000001	43.547195000000002	43.112495000000003	0103000020E610000001000000050000003541D47D002A474055FB743C668E45403541D47D002A474072C45A7C0AC645409206B7B58581474072C45A7C0AC645409206B7B58581474055FB743C668E45403541D47D002A474055FB743C668E4540
31105	Хамавюрт	8	75	22	46.420307999999999	46.431635	43.279091000000001	43.265050000000002	0103000020E61000000100000005000000A31F0DA7CC35474004E78C28EDA14540A31F0DA7CC354740D1CDFE40B9A345408C67D0D03F374740D1CDFE40B9A345408C67D0D03F37474004E78C28EDA14540A31F0DA7CC35474004E78C28EDA14540
31326	Тукита	8	75	22	46.607759000000001	46.619204000000003	43.495016999999997	43.483688999999998	0103000020E61000000100000005000000C26C020CCB4D4740AC376A85E9BD4540C26C020CCB4D474065FB90B75CBF4540B5C6A013424F474065FB90B75CBF4540B5C6A013424F4740AC376A85E9BD4540C26C020CCB4D4740AC376A85E9BD4540
30329	Теречное	8	75	22	46.392037999999999	46.407507000000003	43.442466000000003	43.426991000000001	0103000020E6100000010000000500000006651A4D2E324740DA571EA4A7B6454006651A4D2E324740C5CBD3B9A2B845400FF27A3029344740C5CBD3B9A2B845400FF27A3029344740DA571EA4A7B6454006651A4D2E324740DA571EA4A7B64540
53705	Темир-Аул	8	75	22	46.818001000000002	46.834943000000003	43.261485999999998	43.244052000000003	0103000020E61000000100000005000000338CBB41B4684740FF428F183D9F4540338CBB41B4684740512E8D5F78A1454017838769DF6A4740512E8D5F78A1454017838769DF6A4740FF428F183D9F4540338CBB41B4684740FF428F183D9F4540
31950	Сулевкент	8	75	22	46.747366	46.760688000000002	43.477258999999997	43.465671999999998	0103000020E61000000100000005000000381268B0A95F4740DA54DD239BBB4540381268B0A95F47405F5CAAD216BD4540D63A71395E6147405F5CAAD216BD4540D63A71395E614740DA54DD239BBB4540381268B0A95F4740DA54DD239BBB4540
53549	Солнечное	8	75	22	46.328139999999998	47.011893000000001	43.547195000000002	43.112495000000003	0103000020E610000001000000050000003541D47D002A474055FB743C668E45403541D47D002A474072C45A7C0AC645409206B7B58581474072C45A7C0AC645409206B7B58581474055FB743C668E45403541D47D002A474055FB743C668E4540
30429	Советское	8	75	22	46.333565999999998	46.352072	43.415899000000003	43.404057999999999	0103000020E610000001000000050000005D876A4AB22A4740F5D72B2CB8B345405D876A4AB22A474035B8AD2D3CB545402DEBFEB1102D474035B8AD2D3CB545402DEBFEB1102D4740F5D72B2CB8B345405D876A4AB22A4740F5D72B2CB8B34540
31727	Сиух	8	75	22	46.587493000000002	46.611702999999999	43.414732999999998	43.399912	0103000020E6100000010000000500000081D07AF8324B474094A3005130B3454081D07AF8324B474036C98FF815B54540BBEEAD484C4E474036C98FF815B54540BBEEAD484C4E474094A3005130B3454081D07AF8324B474094A3005130B34540
53643	Село Тотурбийкала	8	75	22	46.328139999999998	47.011893000000001	43.547195000000002	43.112495000000003	0103000020E610000001000000050000003541D47D002A474055FB743C668E45403541D47D002A474072C45A7C0AC645409206B7B58581474072C45A7C0AC645409206B7B58581474055FB743C668E45403541D47D002A474055FB743C668E4540
32260	Садовое	8	75	22	46.767353999999997	46.778637000000003	43.343128	43.335089000000004	0103000020E61000000100000005000000363AE7A738624740EB1F4432E4AA4540363AE7A738624740C32B499EEBAB4540503A9160AA634740C32B499EEBAB4540503A9160AA634740EB1F4432E4AA4540363AE7A738624740EB1F4432E4AA4540
53695	Покровское	8	75	22	46.652853999999998	46.675806000000001	43.296225	43.279504000000003	0103000020E61000000100000005000000098849B890534740F48C7DC9C6A34540098849B890534740F9A067B3EAA5454065389ECF80564740F9A067B3EAA5454065389ECF80564740F48C7DC9C6A34540098849B890534740F48C7DC9C6A34540
30479	Первомайское	8	75	22	46.335965000000002	46.350040999999997	43.442591	43.435560000000002	0103000020E61000000100000005000000E2CCAFE6002B47400FB9196EC0B74540E2CCAFE6002B4740814067D2A6B845402BA1BB24CE2C4740814067D2A6B845402BA1BB24CE2C47400FB9196EC0B74540E2CCAFE6002B47400FB9196EC0B74540
53661	Османюрт	8	75	22	46.520335000000003	46.536099999999998	43.311315	43.297249000000001	0103000020E610000001000000050000006AFB57569A42474065E256410CA645406AFB57569A4247408BE07F2BD9A745405BB1BFEC9E4447408BE07F2BD9A745405BB1BFEC9E44474065E256410CA645406AFB57569A42474065E256410CA64540
53454	Октябрьское	8	75	22	46.424593000000002	46.446835	43.490000999999999	43.476872999999998	0103000020E61000000100000005000000268E3C105936474036ACA92C0ABD4540268E3C1059364740EF004F5AB8BE4540A5DAA7E331394740EF004F5AB8BE4540A5DAA7E33139474036ACA92C0ABD4540268E3C105936474036ACA92C0ABD4540
31140	Нурадилово	8	75	22	46.44838	46.467343	43.288463	43.277306000000003	0103000020E610000001000000050000001A170E8464394740077E54C37EA345401A170E8464394740938D075BECA44540DC813AE5D13B4740938D075BECA44540DC813AE5D13B4740077E54C37EA345401A170E8464394740077E54C37EA34540
32204	Новый Костек	8	75	22	46.817856999999997	46.835310999999997	43.338898999999998	43.327364000000003	0103000020E61000000100000005000000FFE6C589AF684740A2F14410E7A94540FFE6C589AF684740D4D2DC0A61AB4540997E8978EB6A4740D4D2DC0A61AB4540997E8978EB6A4740A2F14410E7A94540FFE6C589AF684740A2F14410E7A94540
53700	Новососитли	8	75	22	46.328139999999998	47.011893000000001	43.547195000000002	43.112495000000003	0103000020E610000001000000050000003541D47D002A474055FB743C668E45403541D47D002A474072C45A7C0AC645409206B7B58581474072C45A7C0AC645409206B7B58581474055FB743C668E45403541D47D002A474055FB743C668E4540
53734	Новосельское	8	75	22	46.462671999999998	46.480710000000002	43.438904999999998	43.410136000000001	0103000020E6100000010000000500000030630AD6383B4740C57421567FB4454030630AD6383B47408386FE092EB845401A6EC0E7873D47408386FE092EB845401A6EC0E7873D4740C57421567FB4454030630AD6383B4740C57421567FB44540
53423	Новогагатлинское	8	75	22	46.470954999999996	46.490340000000003	43.468420000000002	43.443944999999999	0103000020E610000001000000050000009F71E140483C4740821C9430D3B845409F71E140483C47406B65C22FF5BB4540D8F50B76C33E47406B65C22FF5BB4540D8F50B76C33E4740821C9430D3B845409F71E140483C4740821C9430D3B84540
53621	Муцалаул	8	75	22	46.328139999999998	47.011893000000001	43.547195000000002	43.112495000000003	0103000020E610000001000000050000003541D47D002A474055FB743C668E45403541D47D002A474072C45A7C0AC645409206B7B58581474072C45A7C0AC645409206B7B58581474055FB743C668E45403541D47D002A474055FB743C668E4540
53692	Муцал-Аул	8	75	22	46.714111000000003	46.73903	43.286402000000002	43.250782999999998	0103000020E61000000100000005000000605B3FFD675B474046B247A819A04540605B3FFD675B474027C11BD2A8A44540A661F888985E474027C11BD2A8A44540A661F888985E474046B247A819A04540605B3FFD675B474046B247A819A04540
30806	Моксоб	8	75	22	46.479219000000001	46.492811000000003	43.437963000000003	43.429701000000001	0103000020E61000000100000005000000984F560C573D47407D073F7100B74540984F560C573D4740D5EDEC2B0FB84540F60D4C6E143F4740D5EDEC2B0FB84540F60D4C6E143F47407D073F7100B74540984F560C573D47407D073F7100B74540
15831	Куруш	8	75	22	46.744249000000003	46.774189999999997	43.394526999999997	43.374498000000003	0103000020E61000000100000005000000558A1D8D435F47406E35EB8CEFAF4540558A1D8D435F4740CA3159DC7FB24540F3716DA818634740CA3159DC7FB24540F3716DA8186347406E35EB8CEFAF4540558A1D8D435F47406E35EB8CEFAF4540
53730	Костек	8	75	22	46.839497000000001	46.862225000000002	43.347087999999999	43.336145000000002	0103000020E61000000100000005000000890B40A3746B474062DBA2CC06AB4540890B40A3746B4740C26A2C616DAC4540956588635D6E4740C26A2C616DAC4540956588635D6E474062DBA2CC06AB4540890B40A3746B474062DBA2CC06AB4540
53509	Кокрек	8	75	22	46.712564999999998	46.732463000000003	43.244374000000001	43.229346999999997	0103000020E610000001000000050000001AA37554355B4740C537143E5B9D45401AA37554355B474011FFB0A5479F4540D943FB58C15D474011FFB0A5479F4540D943FB58C15D4740C537143E5B9D45401AA37554355B4740C537143E5B9D4540
53704	Карланюрт	8	75	22	46.717264	46.739882999999999	43.251314999999998	43.231856000000001	0103000020E61000000100000005000000904C874ECF5B4740D1B01875AD9D4540904C874ECF5B474043FF04172BA04540E5EE737CB45E474043FF04172BA04540E5EE737CB45E4740D1B01875AD9D4540904C874ECF5B4740D1B01875AD9D4540
31642	Кандаураул	8	75	22	46.558647999999998	46.569508999999996	43.348674000000003	43.334314999999997	0103000020E61000000100000005000000E7FC14C781474740F7C77BD5CAAA4540E7FC14C781474740967B8159A1AC45408AE3C0ABE5484740967B8159A1AC45408AE3C0ABE5484740F7C77BD5CAAA4540E7FC14C781474740F7C77BD5CAAA4540
53486	Казма-Аул	8	75	22	46.753636	46.769841999999997	43.434970999999997	43.423115000000003	0103000020E610000001000000050000004C8BFA247760474039B9DFA128B645404C8BFA2477604740ADDA3521ADB745402A8BC22E8A624740ADDA3521ADB745402A8BC22E8A62474039B9DFA128B645404C8BFA247760474039B9DFA128B64540
30526	Дзержинское	8	75	22	46.4619	46.486882000000001	43.522053	43.512873999999996	0103000020E61000000100000005000000DE02098A1F3B4740FE7BF0DAA5C14540DE02098A1F3B4740ACE3F8A1D2C245406B813D26523E4740ACE3F8A1D2C245406B813D26523E4740FE7BF0DAA5C14540DE02098A1F3B4740FE7BF0DAA5C14540
53595	Боташ-Юрт	8	75	22	46.501595999999999	46.518600999999997	43.315643999999999	43.300522999999998	0103000020E61000000100000005000000F7E6374C344047401059A48977A64540F7E6374C34404740DD96C80567A8454021567F8461424740DD96C80567A8454021567F84614247401059A48977A64540F7E6374C344047401059A48977A64540
53589	Бота-Юрт	8	75	22	46.650905000000002	46.694617000000001	43.330452999999999	43.309714	0103000020E61000000100000005000000C5E6E3DA50534740828E56B5A4A74540C5E6E3DA50534740BBEEAD484CAA4540711FB935E9584740BBEEAD484CAA4540711FB935E9584740828E56B5A4A74540C5E6E3DA50534740828E56B5A4A74540
31184	Борагангечув	8	75	22	46.430126000000001	46.441462999999999	43.313479000000001	43.304112000000003	0103000020E610000001000000050000006494675E0E3747401C295B24EDA645406494675E0E374740CC7D721420A8454070B20DDC81384740CC7D721420A8454070B20DDC813847401C295B24EDA645406494675E0E3747401C295B24EDA64540
53731	Баташ-Юрт	8	75	22	46.328139999999998	47.011893000000001	43.547195000000002	43.112495000000003	0103000020E610000001000000050000003541D47D002A474055FB743C668E45403541D47D002A474072C45A7C0AC645409206B7B58581474072C45A7C0AC645409206B7B58581474055FB743C668E45403541D47D002A474055FB743C668E4540
53652	Баммат-Юрт	8	75	22	46.596134999999997	46.617100999999998	43.35228	43.334833000000003	0103000020E610000001000000050000001F80D4264E4C4740904FC8CEDBAA45401F80D4264E4C47407784D38217AD454019AA622AFD4E47407784D38217AD454019AA622AFD4E4740904FC8CEDBAA45401F80D4264E4C4740904FC8CEDBAA4540
53694	Байрамаул	8	75	22	46.715313999999999	46.736694	43.309241999999998	43.288553999999998	0103000020E610000001000000050000007B2FBE688F5B4740A3906456EFA445407B2FBE688F5B47405A46EA3D95A7454068942EFD4B5E47405A46EA3D95A7454068942EFD4B5E4740A3906456EFA445407B2FBE688F5B4740A3906456EFA44540
6859	Архида	8	75	22	46.782966000000002	46.790880999999999	43.432234999999999	43.427010000000003	0103000020E61000000100000005000000A2F0D93A3864474051888043A8B64540A2F0D93A38644740E197FA7953B745408E03AF963B654740E197FA7953B745408E03AF963B65474051888043A8B64540A2F0D93A3864474051888043A8B64540
30904	Аксай	8	75	22	46.416310000000003	46.463903000000002	43.384543000000001	43.359884000000001	0103000020E61000000100000005000000B77F65A549354740452DCDAD10AE4540B77F65A549354740EF737CB438B1454016C26A2C613B4740EF737CB438B1454016C26A2C613B4740452DCDAD10AE4540B77F65A549354740452DCDAD10AE4540
53958	Акбулатьюрт	8	75	22	46.381276	46.390771000000001	43.462387	43.457008999999999	0103000020E61000000100000005000000F65FE7A6CD304740247D5A457FBA4540F65FE7A6CD3047403B8C497F2FBB4540D49CBCC8043247403B8C497F2FBB4540D49CBCC804324740247D5A457FBA4540F65FE7A6CD304740247D5A457FBA4540
53625	Адиль-Отар	8	75	22	46.668171000000001	46.680109000000002	43.465972999999998	43.453521000000002	0103000020E610000001000000050000005C9198A0865547404D86E3F90CBA45405C9198A086554740D5E8D500A5BB45408E5BCCCF0D574740D5E8D500A5BB45408E5BCCCF0D5747404D86E3F90CBA45405C9198A0865547404D86E3F90CBA4540
31397	Аджимажагатюрт	8	75	22	46.498792999999999	46.514513999999998	43.359366000000001	43.339561000000003	0103000020E61000000100000005000000A33CF372D83F4740A0FF1EBC76AB4540A33CF372D83F4740ADA580B4FFAD4540C5AA4198DB414740ADA580B4FFAD4540C5AA4198DB414740A0FF1EBC76AB4540A33CF372D83F4740A0FF1EBC76AB4540
53473	с.Хинтлимита	8	75	1858	46.631492000000001	47.144395000000003	42.879894	42.572392000000001	0103000020E61000000100000005000000C3D7D7BAD4504740FB3E1C2444494540C3D7D7BAD45047402BF9D85DA07045405C5A0D897B9247402BF9D85DA07045405C5A0D897B924740FB3E1C2444494540C3D7D7BAD4504740FB3E1C2444494540
28966	Шамилькала	8	75	1858	46.860903999999998	46.879517	42.693956	42.681795000000001	0103000020E610000001000000050000006F7F2E1A326E4740C5C9FD0E455745406F7F2E1A326E4740766EDA8CD358454055A3570394704740766EDA8CD358454055A3570394704740C5C9FD0E455745406F7F2E1A326E4740C5C9FD0E45574540
30223	Цатаних	8	75	1858	46.719526999999999	46.734709000000002	42.678939	42.665177	0103000020E6100000010000000500000064CBF275195C474094861A852455454064CBF275195C47404E7D2079E7564540D789CBF10A5E47404E7D2079E7564540D789CBF10A5E474094861A852455454064CBF275195C474094861A8524554540
29261	Харачи	8	75	1858	46.814830000000001	46.824297999999999	42.681198999999999	42.674596999999999	0103000020E610000001000000050000005CE674594C684740677DCA31595645405CE674594C684740B1886187315745404014CC9882694740B1886187315745404014CC9882694740677DCA31595645405CE674594C684740677DCA3159564540
29118	Унцукуль	8	75	1858	46.779283	46.802909	42.720404000000002	42.703643999999997	0103000020E6100000010000000500000015AA9B8BBF6347406803B001115A454015AA9B8BBF6347402CF4C132365C45400055DCB8C56647402CF4C132365C45400055DCB8C56647406803B001115A454015AA9B8BBF6347406803B001115A4540
29300	Моксох	8	75	1858	46.801597000000001	46.808937	42.658839	42.651645000000002	0103000020E610000001000000050000002EC901BB9A6647400CCD751A695345402EC901BB9A664740282A1BD6545445401EC3633F8B674740282A1BD6545445401EC3633F8B6747400CCD751A695345402EC901BB9A6647400CCD751A69534540
53729	Майданский	8	75	1858	46.956000000000003	46.966726000000001	42.606650000000002	42.594763999999998	0103000020E61000000100000005000000EE7C3F355E7A4740486B0C3A214C4540EE7C3F355E7A4740280F0BB5A64D4540B11875ADBD7B4740280F0BB5A64D4540B11875ADBD7B4740486B0C3A214C4540EE7C3F355E7A4740486B0C3A214C4540
30061	Колоб	8	75	1858	46.682749999999999	46.687646000000001	42.680456999999997	42.676009000000001	0103000020E6100000010000000500000008AC1C5A645747409D6681768756454008AC1C5A64574740C9AA083719574540D49CBCC804584740C9AA083719574540D49CBCC8045847409D6681768756454008AC1C5A645747409D66817687564540
29920	Кахабросо	8	75	1858	46.693655999999997	46.710040999999997	42.741979999999998	42.731206	0103000020E610000001000000050000004B5645B8C9584740CA518028985D45404B5645B8C95847409E245D33F95E4540D9E89C9FE25A47409E245D33F95E4540D9E89C9FE25A4740CA518028985D45404B5645B8C9584740CA518028985D4540
30002	Иштибури	8	75	1858	46.699342000000001	46.708441999999998	42.681821999999997	42.676645000000001	0103000020E61000000100000005000000105CE509845947403F00A94D9C564540105CE50984594740BED87BF145574540718E3A3AAE5A4740BED87BF145574540718E3A3AAE5A47403F00A94D9C564540105CE509845947403F00A94D9C564540
29620	Ирганай	8	75	1858	46.904930999999998	46.915145000000003	42.654178000000002	42.642288000000001	0103000020E610000001000000050000007B116DC7D47347407F4E417E365245407B116DC7D4734740A0E1CD1ABC534540890CAB7823754740A0E1CD1ABC534540890CAB78237547407F4E417E365245407B116DC7D47347407F4E417E36524540
30184	Инквалита	8	75	1858	46.685499	46.692577999999997	42.702596999999997	42.698813000000001	0103000020E610000001000000050000006938656EBE574740848252B4725945406938656EBE57474044A2D0B2EE594540ECF65965A658474044A2D0B2EE594540ECF65965A6584740848252B4725945406938656EBE574740848252B472594540
29377	Зирани	8	75	1858	46.942264999999999	46.948363999999998	42.620370999999999	42.615349000000002	0103000020E610000001000000050000002D95B7239C7847402B508BC1C34E45402D95B7239C78474083312251684F4540145AD6FD6379474083312251684F4540145AD6FD637947402B508BC1C34E45402D95B7239C7847402B508BC1C34E4540
29715	Гимры	8	75	1858	46.833461	46.847366999999998	42.763064999999997	42.754784000000001	0103000020E61000000100000005000000E8BE9CD9AE6A4740A4C519C39C604540E8BE9CD9AE6A474072DC291DAC614540D55A9885766C474072DC291DAC614540D55A9885766C4740A4C519C39C604540E8BE9CD9AE6A4740A4C519C39C604540
29929	Бетли	8	75	1858	46.730477999999998	46.73903	42.725907999999997	42.721060000000001	0103000020E610000001000000050000004739984D805D4740153AAFB14B5C45404739984D805D4740CFF3A78DEA5C4540A661F888985E4740CFF3A78DEA5C4540A661F888985E4740153AAFB14B5C45404739984D805D4740153AAFB14B5C4540
29351	Балахани	8	75	1858	46.880955	46.896054999999997	42.636443999999997	42.629758000000002	0103000020E61000000100000005000000B41F2922C37047407B32FFE89B504540B41F2922C370474022DE3AFF76514540693524EEB172474022DE3AFF76514540693524EEB17247407B32FFE89B504540B41F2922C37047407B32FFE89B504540
29845	Ашильта	8	75	1858	46.722850999999999	46.734098000000003	42.774693999999997	42.766956999999998	0103000020E61000000100000005000000C170AE61865C47401938A0A52B624540C170AE61865C47402634492C296345408E075BECF65D47402634492C296345408E075BECF65D47401938A0A52B624540C170AE61865C47401938A0A52B624540
29485	Аракани	8	75	1858	46.983848000000002	47.001202999999997	42.616602999999998	42.601281	0103000020E61000000100000005000000151E34BBEE7D4740645A9BC6F64C4540151E34BBEE7D4740C8CEDBD8EC4E45401BD47E6B27804740C8CEDBD8EC4E45401BD47E6B27804740645A9BC6F64C4540151E34BBEE7D4740645A9BC6F64C4540
53656	селение Чадаколоб	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53484	селение Калининаул	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53658	селение Ибрагимотар	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53657	селение Верхняя-Тохота	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53819	селение Бежуда	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53635	селение Акнада	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53959	населенный пункт Тельмана	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53585	населенный пункт Гутанаул	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53641	колхоза имени Дахадаева	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53604	Янгибина	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53653	Шидиб	8	75	1782	46.378247999999999	46.384546	42.234050000000003	42.231346000000002	0103000020E6100000010000000500000082E3326E6A304740BC07E8BE9C1D454082E3326E6A3047407DD0B359F51D454060E7A6CD383147407DD0B359F51D454060E7A6CD38314740BC07E8BE9C1D454082E3326E6A304740BC07E8BE9C1D4540
53957	Чодода	8	75	1782	46.310273000000002	46.316578999999997	42.198852000000002	42.191837999999997	0103000020E6100000010000000500000079EA9106B7274740A510C8258E18454079EA9106B7274740425F7AFB73194540D9CC21A985284740425F7AFB73194540D9CC21A985284740A510C8258E18454079EA9106B7274740A510C8258E184540
53525	Цумилух	8	75	1782	46.405135000000001	46.416246999999998	42.062863999999998	42.052245999999997	0103000020E6100000010000000500000084BBB376DB33474064AC36FFAF06454084BBB376DB334740410C74ED0B0845407007EA9447354740410C74ED0B0845407007EA944735474064AC36FFAF06454084BBB376DB33474064AC36FFAF064540
53811	Цимгуда	8	75	1782	46.562601000000001	46.568151999999998	42.015172	42.010134000000001	0103000020E6100000010000000500000034D93F4F03484740F14927124C01454034D93F4F034847404FE8F527F101454018946934B94847404FE8F527F101454018946934B9484740F14927124C01454034D93F4F03484740F14927124C014540
53946	Хиндах	8	75	1782	46.389774000000003	46.393655000000003	42.297964	42.295983	0103000020E61000000100000005000000626A4B1DE431474003965CC5E2254540626A4B1DE431474053B131AF2326454015747B496332474053B131AF2326454015747B496332474003965CC5E2254540626A4B1DE431474003965CC5E2254540
53469	Хидиб	8	75	1782	46.362124000000001	46.374709000000003	42.181114999999998	42.177681	0103000020E61000000100000005000000618C48145A2E47406F0F4240BE164540618C48145A2E474053E8BCC62E1745402942EA76F62F474053E8BCC62E1745402942EA76F62F47406F0F4240BE164540618C48145A2E47406F0F4240BE164540
53947	Харада	8	75	1782	46.254936999999998	46.261763999999999	42.224328999999997	42.220537	0103000020E610000001000000050000002AC58EC6A12047406B47718E3A1C45402AC58EC6A1204740AE450BD0B61C454094A2957B81214740AE450BD0B61C454094A2957B812147406B47718E3A1C45402AC58EC6A12047406B47718E3A1C4540
53499	Хамар	8	75	1782	46.382371999999997	46.387681000000001	42.097408999999999	42.091106000000003	0103000020E61000000100000005000000FB73D190F1304740153C855CA90B4540FB73D190F130474004ABEAE5770C4540EA23F0879F31474004ABEAE5770C4540EA23F0879F314740153C855CA90B4540FB73D190F1304740153C855CA90B4540
53516	Хадиял	8	75	1782	46.460434999999997	46.468412000000001	42.104661	42.096558999999999	0103000020E610000001000000050000008577B988EF3A47403691990B5C0C45408577B988EF3A474055151A88650D4540E886A6ECF43B474055151A88650D4540E886A6ECF43B47403691990B5C0C45408577B988EF3A47403691990B5C0C4540
53847	Фрунзе	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53954	Укал	8	75	1782	46.339512999999997	46.348945000000001	42.125441000000002	42.120232000000001	0103000020E610000001000000050000008EC87729752B474062F71DC3630F45408EC87729752B4740ED4960730E104540268DD13AAA2C4740ED4960730E104540268DD13AAA2C474062F71DC3630F45408EC87729752B474062F71DC3630F4540
53504	Тохота	8	75	1782	46.462178000000002	46.469175999999997	42.023651999999998	42.015728000000003	0103000020E61000000100000005000000217711A6283B4740D5D0066003024540217711A6283B4740143E5B0707034540B7088CF50D3C4740143E5B0707034540B7088CF50D3C4740D5D0066003024540217711A6283B4740D5D0066003024540
53541	Тлярата	8	75	1782	46.348981000000002	46.359375	42.114299000000003	42.097375	0103000020E6100000010000000500000073F6CE68AB2C47405839B4C8760C454073F6CE68AB2C4740967B8159A10E454000000000002E4740967B8159A10E454000000000002E47405839B4C8760C454073F6CE68AB2C47405839B4C8760C4540
53914	Тлянада	8	75	1782	46.506841999999999	46.514324999999999	42.031213999999999	42.025454000000003	0103000020E610000001000000050000009F1EDB32E0404740B5C6A013420345409F1EDB32E0404740B39602D2FE034540F241CF66D5414740B39602D2FE034540F241CF66D5414740B5C6A013420345409F1EDB32E0404740B5C6A01342034540
53601	Тельмана-Теречный	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53444	Талсух	8	75	1782	46.403464	46.411441000000003	42.049542000000002	42.043782999999998	0103000020E61000000100000005000000828E56B5A4334740758F6CAE9A054540828E56B5A4334740A4E36A6457064540E59D4319AA344740A4E36A6457064540E59D4319AA344740758F6CAE9A054540828E56B5A4334740758F6CAE9A054540
53841	Сикар	8	75	1782	46.400768999999997	46.414288999999997	42.083036	42.074745	0103000020E6100000010000000500000014200A664C3347400F45813E9109454014200A664C334740013274ECA00A4540D80B056C07354740013274ECA00A4540D80B056C073547400F45813E9109454014200A664C3347400F45813E91094540
53951	Саниорта	8	75	1782	46.439954	46.447921999999998	42.034802999999997	42.031381000000003	0103000020E6100000010000000500000048DFA469503847409F5BE84A0404454048DFA46950384740BE66B96C740445405794128255394740BE66B96C7404454057941282553947409F5BE84A0404454048DFA469503847409F5BE84A04044540
53445	Салда	8	75	1782	46.506329999999998	46.513804	41.976123999999999	41.972880000000004	0103000020E61000000100000005000000E97DE36BCF4047405C77F35487FC4440E97DE36BCF4047409C6B98A1F1FC4440E9465854C44147409C6B98A1F1FC4440E9465854C44147405C77F35487FC4440E97DE36BCF4047405C77F35487FC4440
53662	Росноб	8	75	1782	46.366328000000003	46.372633999999998	42.256535999999997	42.250957	0103000020E61000000100000005000000F7CDFDD5E32E4740E4D9E55B1F204540F7CDFDD5E32E4740921FF12BD620454057B08D78B22F4740921FF12BD620454057B08D78B22F4740E4D9E55B1F204540F7CDFDD5E32E4740E4D9E55B1F204540
53822	Орджоникидзе	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53678	Нойрух	8	75	1782	46.372742000000002	46.387762000000002	42.198397999999997	42.191209999999998	0103000020E610000001000000050000003EEC8502B62F47408655BC91791845403EEC8502B62F4740C0CB0C1B65194540D7506A2FA2314740C0CB0C1B65194540D7506A2FA23147408655BC91791845403EEC8502B62F47408655BC9179184540
53919	Нитилсух	8	75	1782	46.427619999999997	46.431240000000003	42.049019000000001	42.046495	0103000020E61000000100000005000000C98E8D40BC364740B936548CF3054540C98E8D40BC364740FAF02C4146064540105D50DF32374740FAF02C4146064540105D50DF32374740B936548CF3054540C98E8D40BC364740B936548CF3054540
53812	Никлида	8	75	1782	46.395738999999999	46.408090000000001	42.202018000000002	42.197882999999997	0103000020E6100000010000000500000039605793A732474099B7EA3A5419454039605793A7324740079ACFB9DB1945408EE9094B3C344740079ACFB9DB1945408EE9094B3C34474099B7EA3A5419454039605793A732474099B7EA3A54194540
53902	Никар	8	75	1782	46.408495000000002	46.414540000000002	42.07799	42.072769999999998	0103000020E610000001000000050000002ECA6C9049344740A1100187500945402ECA6C904934474020B58993FB09454022718FA50F35474020B58993FB09454022718FA50F354740A1100187500945402ECA6C9049344740A110018750094540
53460	Начада	8	75	1782	46.443438999999998	46.457479999999997	42.200614999999999	42.197007999999997	0103000020E61000000100000005000000AE62F19BC23847407286E28E37194540AE62F19BC2384740240B98C0AD1945407B4963B48E3A4740240B98C0AD1945407B4963B48E3A47407286E28E37194540AE62F19BC23847407286E28E37194540
53648	Надар	8	75	1782	46.358432000000001	46.362060999999997	42.099542999999997	42.096665999999999	0103000020E6100000010000000500000081EB8A19E12D47404C512E8D5F0C454081EB8A19E12D4740DAC534D3BD0C45401A14CD03582E4740DAC534D3BD0C45401A14CD03582E47404C512E8D5F0C454081EB8A19E12D47404C512E8D5F0C4540
53639	Мазада	8	75	1782	46.388229000000003	46.394534999999998	42.20111	42.196254000000003	0103000020E61000000100000005000000ED2DE57CB1314740C7DADFD91E194540ED2DE57CB13147400473F4F8BD1945404D10751F803247400473F4F8BD1945404D10751F80324740C7DADFD91E194540ED2DE57CB1314740C7DADFD91E194540
53762	Ленина	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53969	Ланда	8	75	1782	46.273155000000003	46.279955000000001	42.222914000000003	42.212837	0103000020E6100000010000000500000094DE37BEF62247407B30293E3E1B454094DE37BEF622474008E92972881C454004ADC090D523474008E92972881C454004ADC090D52347407B30293E3E1B454094DE37BEF62247407B30293E3E1B4540
27260	Кутлаб	8	75	1782	46.327736000000002	46.335228000000001	42.098967999999999	42.094284000000002	0103000020E6100000010000000500000066DCD440F32947409E44847F110C454066DCD440F3294740DEACC1FBAA0C45400C5A48C0E82A4740DEACC1FBAA0C45400C5A48C0E82A47409E44847F110C454066DCD440F32947409E44847F110C4540
53447	Кособ	8	75	1782	46.362968000000002	46.368295000000003	42.24483	42.240330999999998	0103000020E610000001000000050000004DBF44BC752E4740849B8C2AC31E45404DBF44BC752E4740338AE596561F4540E223624A242F4740338AE596561F4540E223624A242F4740849B8C2AC31E45404DBF44BC752E4740849B8C2AC31E4540
53663	Качалай	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53903	Кардиб	8	75	1782	46.507336000000002	46.526919999999997	42.114567000000001	42.108626999999998	0103000020E61000000100000005000000AF0AD462F0404740363B527DE70D4540AF0AD462F0404740B519A721AA0E4540DDCD531D72434740B519A721AA0E4540DDCD531D72434740363B527DE70D4540AF0AD462F0404740363B527DE70D4540
53815	Каратюбе	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53899	Камилух	8	75	1782	46.624153	46.645119999999999	41.912660000000002	41.905447000000002	0103000020E61000000100000005000000A359D93EE44F474073A1F2AFE5F34440A359D93EE44F4740062FFA0AD2F444406DFFCA4A93524740062FFA0AD2F444406DFFCA4A9352474073A1F2AFE5F34440A359D93EE44F474073A1F2AFE5F34440
53851	Калоб	8	75	1782	46.518906999999999	46.529533999999998	42.020952999999999	42.015552999999997	0103000020E610000001000000050000002E55698B6B424740662D05A4FD0145402E55698B6B42474065E08096AE0245405E0F26C5C743474065E08096AE0245405E0F26C5C7434740662D05A4FD0145402E55698B6B424740662D05A4FD014540
53910	Жданова	8	75	1782	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
53844	Жажада	8	75	1782	46.420684999999999	46.434474000000002	42.202044999999998	42.195379000000003	0103000020E6100000010000000500000079758E01D9354740A0A9D72D0219454079758E01D935474000A94D9CDC1945402D7B12D89C37474000A94D9CDC1945402D7B12D89C374740A0A9D72D0219454079758E01D9354740A0A9D72D02194540
53424	Гортноб	8	75	1782	46.522005999999998	46.528519000000003	41.965318000000003	41.960456999999998	0103000020E610000001000000050000006B28B517D14247406D1B4641F0FA44406B28B517D1424740BD1E4C8A8FFB44404628B682A6434740BD1E4C8A8FFB44404628B682A64347406D1B4641F0FA44406B28B517D14247406D1B4641F0FA4440
53489	Гиндиб	8	75	1782	46.501291000000002	46.509995000000004	42.119790000000002	42.109349999999999	0103000020E61000000100000005000000BB63B14D2A404740A7E8482EFF0D4540BB63B14D2A404740A5315A47550F4540D00F238447414740A5315A47550F4540D00F238447414740A7E8482EFF0D4540BB63B14D2A404740A7E8482EFF0D4540
53897	Герель	8	75	1782	46.547311000000001	46.556708	41.946582999999997	41.939017999999997	0103000020E61000000100000005000000DBDE6E490E4647407B2DE8BD31F84440DBDE6E490E4647408BF9B9A129F94440F6B52E35424747408BF9B9A129F94440F6B52E35424747407B2DE8BD31F84440DBDE6E490E4647407B2DE8BD31F84440
53631	Генеколоб	8	75	1782	46.596933999999997	46.600555	41.918095000000001	41.915036000000001	0103000020E610000001000000050000006BEF5355684C4740D2544FE61FF544406BEF5355684C474081CF0F2384F5444082397AFCDE4C474081CF0F2384F5444082397AFCDE4C4740D2544FE61FF544406BEF5355684C4740D2544FE61FF54440
53615	Гендух	8	75	1782	46.399709000000001	46.404550999999998	42.135953000000001	42.132530000000003	0103000020E610000001000000050000005C751DAA2933474094DE37BEF61045405C751DAA2933474084656CE8661145403448C153C833474084656CE8661145403448C153C833474094DE37BEF61045405C751DAA2933474094DE37BEF6104540
53472	Гведыш	8	75	1782	46.405754999999999	46.417603999999997	42.139021999999997	42.132717	0103000020E610000001000000050000002098A3C7EF334740C64FE3DEFC1045402098A3C7EF33474056B60F79CB114540E256410C7435474056B60F79CB114540E256410C74354740C64FE3DEFC1045402098A3C7EF334740C64FE3DEFC104540
53433	Гараколоб	8	75	1782	46.45129	46.458055000000002	42.051549999999999	42.048310000000001	0103000020E610000001000000050000008481E7DEC3394740EE08A7052F0645408481E7DEC3394740ED0DBE30990645407862D68BA13A4740ED0DBE30990645407862D68BA13A4740EE08A7052F0645408481E7DEC3394740EE08A7052F064540
53813	Гагар	8	75	1782	46.588875999999999	46.597833000000001	42.002012999999998	41.998033	0103000020E610000001000000050000001CB3EC49604B474015AA9B8BBFFF44401CB3EC49604B47405B9544F6410045401BBCAFCA854C47405B9544F6410045401BBCAFCA854C474015AA9B8BBFFF44401CB3EC49604B474015AA9B8BBFFF4440
53578	Бетельда	8	75	1782	46.537672000000001	46.543700000000001	41.952886999999997	41.949105000000003	0103000020E61000000100000005000000CAFCA36FD24447402CBCCB457CF94440CAFCA36FD24447404BE48233F8F94440E86A2BF6974547404BE48233F8F94440E86A2BF6974547402CBCCB457CF94440CAFCA36FD24447402CBCCB457CF94440
53816	Барнаб	8	75	1782	46.376837999999999	46.383602000000003	42.081564	42.078138000000003	0103000020E61000000100000005000000EDF1423A3C30474095490D6D000A4540EDF1423A3C304740F6436CB0700A45401157CEDE19314740F6436CB0700A45401157CEDE1931474095490D6D000A4540EDF1423A3C30474095490D6D000A4540
53651	Анцух	8	75	1782	46.334743000000003	46.347104000000002	42.191330000000001	42.185397999999999	0103000020E6100000010000000500000050C8CEDBD82A4740355F251FBB17454050C8CEDBD82A4740315F5E807D184540C82764E76D2C4740315F5E807D184540C82764E76D2C4740355F251FBB17454050C8CEDBD82A4740355F251FBB174540
53924	колхоза имени 40 лет Октября	8	75	535	46.487141999999999	46.494176000000003	44.427542000000003	44.424844	0103000020E61000000100000005000000074147AB5A3E47406FF3C64961364640074147AB5A3E47404ED53DB2B9364640EB3BBF28413F47404ED53DB2B9364640EB3BBF28413F47406FF3C64961364640074147AB5A3E47406FF3C64961364640
53642	Юрковка	8	75	535	46.672204000000001	46.688203000000001	44.185152000000002	44.167231000000001	0103000020E61000000100000005000000C51EDAC70A5647404EF04DD367154640C51EDAC70A564740FE648C0FB31746402A01310917584740FE648C0FB31746402A013109175847404EF04DD367154640C51EDAC70A5647404EF04DD367154640
25861	Тарумовка	8	75	535	46.521870999999997	46.547581000000001	44.090189000000002	44.059866999999997	0103000020E610000001000000050000008BDD3EABCC424740088ECBB8A90746408BDD3EABCC424740BFBA2A508B0B46409B745B2217464740BFBA2A508B0B46409B745B2217464740088ECBB8A90746408BDD3EABCC424740088ECBB8A9074640
53723	Таловка	8	75	535	46.582534000000003	46.609538000000001	44.245384999999999	44.228264000000003	0103000020E610000001000000050000006F675F79904A4740556D37C1371D46406F675F79904A4740E8F692C6681F4640AAD55757054E4740E8F692C6681F4640AAD55757054E4740556D37C1371D46406F675F79904A4740556D37C1371D4640
25739	Рассвет	8	75	535	46.705199	46.715727999999999	43.986472999999997	43.970281	0103000020E610000001000000050000000116F9F5435A47401077F52A32FC45400116F9F5435A474089B14CBF44FE45406E6AA0F99C5B474089B14CBF44FE45406E6AA0F99C5B47401077F52A32FC45400116F9F5435A47401077F52A32FC4540
25653	Раздолье	8	75	535	46.572212999999998	46.594400999999998	44.204534000000002	44.188875000000003	0103000020E610000001000000050000004BAC8C463E4947401904560E2D1846404BAC8C463E494740C5758C2B2E1A4640D7DAFB54154C4740C5758C2B2E1A4640D7DAFB54154C47401904560E2D1846404BAC8C463E4947401904560E2D184640
53898	Привольный	8	75	535	46.65175	46.663473000000003	44.104036000000001	44.096449999999997	0103000020E610000001000000050000008195438B6C5347407FD93D79580C46408195438B6C534740A7CD380D510D4640B763EAAEEC544740A7CD380D510D4640B763EAAEEC5447407FD93D79580C46408195438B6C5347407FD93D79580C4640
32845	Новоромановка	8	75	535	46.636155000000002	46.651587999999997	43.965460999999998	43.950062000000003	0103000020E61000000100000005000000EC17EC866D5147401096B1A19BF94540EC17EC866D5147401F48DE3994FB4540A73B4F3C675347401F48DE3994FB4540A73B4F3C675347401096B1A19BF94540EC17EC866D5147401096B1A19BF94540
53434	Новониколаевка	8	75	535	46.692461000000002	46.702747000000002	43.999566000000002	43.990682	0103000020E61000000100000005000000B360E28FA2584740315EF3AACEFE4540B360E28FA2584740C61858C7F1FF45405A2E1B9DF3594740C61858C7F1FF45405A2E1B9DF3594740315EF3AACEFE4540B360E28FA2584740315EF3AACEFE4540
25484	Новодмитриевка	8	75	535	46.472949	46.498730000000002	44.103071999999997	44.073554000000001	0103000020E6100000010000000500000084D6C397893C4740B83EAC376A09464084D6C397893C474010919A76310D46405DC47762D63F474010919A76310D46405DC47762D63F4740B83EAC376A09464084D6C397893C4740B83EAC376A094640
53699	Новогеоргиевка	8	75	535	46.621611000000001	46.643467000000001	43.939827000000001	43.922032000000002	0103000020E61000000100000005000000BCEA01F3904F4740C8EE022505F64540BCEA01F3904F4740EB724A404CF8454012876C205D524740EB724A404CF8454012876C205D524740C8EE022505F64540BCEA01F3904F4740C8EE022505F64540
3260	Кутан	8	75	535	46.604875	46.611271000000002	44.675949000000003	44.670166999999999	0103000020E610000001000000050000008195438B6C4D4740E1ED4108C85546408195438B6C4D4740C861307F8556464022FFCC203E4E4740C861307F8556464022FFCC203E4E4740E1ED4108C85546408195438B6C4D4740E1ED4108C8554640
25270	Кочубей	8	75	535	46.529308999999998	46.598309	44.403230000000001	44.371414000000001	0103000020E610000001000000050000003E3DB665C043474066A3737E8A2F46403E3DB665C04347400F62670A9D33464084F3A963954C47400F62670A9D33464084F3A963954C474066A3737E8A2F46403E3DB665C043474066A3737E8A2F4640
25219	Коктюбей	8	75	535	46.734062000000002	46.746360000000003	44.273674999999997	44.258654	0103000020E61000000100000005000000419E5DBEF55D4740637D03931B214640419E5DBEF55D4740CC5D4BC807234640738577B9885F4740CC5D4BC807234640738577B9885F4740637D03931B214640419E5DBEF55D4740637D03931B214640
25182	Карабаглы	8	75	535	46.584313000000002	46.601883999999998	44.013584000000002	44.005122999999998	0103000020E6100000010000000500000057D0B4C4CA4A47408CBAD6DEA700464057D0B4C4CA4A4740DBDFD91EBD0146402AFEEF880A4D4740DBDFD91EBD0146402AFEEF880A4D47408CBAD6DEA700464057D0B4C4CA4A47408CBAD6DEA7004640
53634	Калиновка	8	75	535	46.563094999999997	46.582237999999997	43.974536999999998	43.958959	0103000020E6100000010000000500000043C5387F13484740399A232BBFFA454043C5387F13484740F8DEDFA0BDFC4540853E58C6864A4740F8DEDFA0BDFC4540853E58C6864A4740399A232BBFFA454043C5387F13484740399A232BBFFA4540
27682	Вышеталовка	8	75	535	46.716966999999997	46.738410000000002	44.049579999999999	44.028500000000001	0103000020E61000000100000005000000D6A71C93C55B4740CFF753E3A5034640D6A71C93C55B474091442FA3580646400A850838845E474091442FA3580646400A850838845E4740CFF753E3A5034640D6A71C93C55B4740CFF753E3A5034640
24996	Александро-Невское	8	75	535	46.550635	46.565116000000003	43.927908000000002	43.913986000000001	0103000020E6100000010000000500000038842A357B4647403D80457EFDF4454038842A357B46474030D978B0C5F64540223999B85548474030D978B0C5F64540223999B8554847403D80457EFDF4454038842A357B4647403D80457EFDF44540
53839	с Ново-Лидже	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
53773	с Джугдиль	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
53468	с Гелинбатан	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
24980	Ягдыг	8	75	1447	47.953857999999997	47.963028999999999	41.981721	41.976318999999997	0103000020E610000001000000050000009483D90418FA474051BB5F05F8FC44409483D90418FA4740F165A208A9FD4440BF0CC68844FB4740F165A208A9FD4440BF0CC68844FB474051BB5F05F8FC44409483D90418FA474051BB5F05F8FC4440
24919	Чурдаф	8	75	1447	47.862544	47.867609999999999	41.955522000000002	41.952202999999997	0103000020E6100000010000000500000036AE7FD767EE47409813B4C9E1F9444036AE7FD767EE4740E44D7E8B4EFA44405ED72FD80DEF4740E44D7E8B4EFA44405ED72FD80DEF47409813B4C9E1F9444036AE7FD767EE47409813B4C9E1F94440
24892	Чулат	8	75	1447	48.146456000000001	48.157981999999997	41.888050999999997	41.876731999999997	0103000020E61000000100000005000000C826F911BF124840A7AD11C138F04440C826F911BF1248400D17B9A7ABF14440A7AD11C1381448400D17B9A7ABF14440A7AD11C138144840A7AD11C138F04440C826F911BF124840A7AD11C138F04440
24842	Цухтыг	8	75	1447	47.979612000000003	47.985838000000001	41.943820000000002	41.936785	0103000020E6100000010000000500000074620FED63FD474012312592E8F7444074620FED63FD4740C6A70018CFF84440B89388F02FFE4740C6A70018CFF84440B89388F02FFE474012312592E8F7444074620FED63FD474012312592E8F74440
24794	Цуртиль	8	75	1447	47.929307000000001	47.935316	41.918666000000002	41.913989000000001	0103000020E61000000100000005000000D1782288F3F64740AEF36F97FDF44440D1782288F3F647403CF9F4D896F5444078B6476FB8F747403CF9F4D896F5444078B6476FB8F74740AEF36F97FDF44440D1782288F3F64740AEF36F97FDF44440
53474	Цантиль	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
53862	Цантиль	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
24702	Цанак	8	75	1447	48.033304999999999	48.045054	41.947206999999999	41.938440999999997	0103000020E610000001000000050000008AE5965643044840DE1CAED51EF844408AE596564304484069C537143EF94440E9465854C405484069C537143EF94440E9465854C4054840DE1CAED51EF844408AE5965643044840DE1CAED51EF84440
24602	Хучни	8	75	1447	47.939107	47.953220000000002	41.959451000000001	41.937159999999999	0103000020E61000000100000005000000EB387EA834F84740478FDFDBF4F74440EB387EA834F84740A88E554ACFFA444052F2EA1C03FA4740A88E554ACFFA444052F2EA1C03FA4740478FDFDBF4F74440EB387EA834F84740478FDFDBF4F74440
24539	Хустиль	8	75	1447	47.931283000000001	47.941648999999998	42.005550999999997	42.001584000000001	0103000020E610000001000000050000000F29064834F7474033198EE7330045400F29064834F74740E4BA29E5B5004540D2A755F487F84740E4BA29E5B5004540D2A755F487F8474033198EE7330045400F29064834F7474033198EE733004540
24513	Хуряк	8	75	1447	48.064960999999997	48.077331000000001	41.884827999999999	41.879693000000003	0103000020E61000000100000005000000FA415DA45008484094C2BCC799F04440FA415DA450084840E44A3D0B42F14440C6FB71FBE5094840E44A3D0B42F14440C6FB71FBE509484094C2BCC799F04440FA415DA45008484094C2BCC799F04440
24430	Хурик	8	75	1447	47.894596	47.903748999999998	41.990775999999997	41.981580000000001	0103000020E61000000100000005000000F390291F82F247402F34D769A4FD4440F390291F82F24740B2D47ABFD1FE44407765170CAEF34740B2D47ABFD1FE44407765170CAEF347402F34D769A4FD4440F390291F82F247402F34D769A4FD4440
53613	Хужник	8	75	1447	47.817475000000002	47.825676999999999	41.958278	41.952699000000003	0103000020E6100000010000000500000018265305A3E8474049F7730AF2F9444018265305A3E84740F73C7FDAA8FA44409A07B0C8AFE94740F73C7FDAA8FA44409A07B0C8AFE9474049F7730AF2F9444018265305A3E8474049F7730AF2F94440
53535	Хели-Пенджик	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
24342	Хапиль	8	75	1447	47.972740000000002	47.980978	41.991880999999999	41.986305999999999	0103000020E610000001000000050000006AC18BBE82FC47409EEC66463FFE44406AC18BBE82FC47400B43E4F4F5FE4440390CE6AF90FD47400B43E4F4F5FE4440390CE6AF90FD47409EEC66463FFE44406AC18BBE82FC47409EEC66463FFE4440
24254	Ханак	8	75	1447	47.864232999999999	47.872892	41.915484999999997	41.909171000000001	0103000020E61000000100000005000000DE8FDB2F9FEE47405EBC1FB75FF44440DE8FDB2F9FEE4740417DCB9C2EF544405378D0ECBAEF4740417DCB9C2EF544405378D0ECBAEF47405EBC1FB75FF44440DE8FDB2F9FEE47405EBC1FB75FF44440
24197	Халаг	8	75	1447	47.873556999999998	47.893329000000001	41.908029999999997	41.901051000000002	0103000020E610000001000000050000008F183DB7D0EF47409983A0A355F344408F183DB7D0EF4740B8E4B8533AF44440C1C8CB9A58F24740B8E4B8533AF44440C1C8CB9A58F247409983A0A355F344408F183DB7D0EF47409983A0A355F34440
53952	Фиргиль	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
24105	Ушниг	8	75	1447	47.999868999999997	48.006830999999998	41.929265000000001	41.923274999999997	0103000020E6100000010000000500000061A417B5FBFF4740711B0DE02DF6444061A417B5FBFF4740A228D027F2F64440ABCC94D6DF004840A228D027F2F64440ABCC94D6DF004840711B0DE02DF6444061A417B5FBFF4740711B0DE02DF64440
53949	Урзиг	8	75	1447	47.847811	47.851422999999997	41.948776000000002	41.946496000000003	0103000020E610000001000000050000003318231285EC4740BDE5EAC726F944403318231285EC4740679DF17D71F94440F607CA6DFBEC4740679DF17D71F94440F607CA6DFBEC4740BDE5EAC726F944403318231285EC4740BDE5EAC726F94440
53488	Улуз	8	75	1447	47.837741000000001	47.842314000000002	41.958767000000002	41.954805	0103000020E6100000010000000500000059C2DA183BEB47405587DC0C37FA444059C2DA183BEB4740F5BD86E0B8FA4440427BF5F1D0EB4740F5BD86E0B8FA4440427BF5F1D0EB47405587DC0C37FA444059C2DA183BEB47405587DC0C37FA4440
23950	Туруф	8	75	1447	48.001980000000003	48.010838	41.908903000000002	41.901924000000001	0103000020E61000000100000005000000809F71E1400048401FBDE13E72F34440809F71E1400048403F1EFAEE56F44440EBC6BB23630148403F1EFAEE56F44440EBC6BB23630148401FBDE13E72F34440809F71E1400048401FBDE13E72F34440
23888	Тураг	8	75	1447	47.970053999999998	47.978704999999998	41.863779999999998	41.85736	0103000020E610000001000000050000004FADBEBA2AFC47400473F4F8BDED44404FADBEBA2AFC47402D78D15790EE444041B7973446FD47402D78D15790EE444041B7973446FD47400473F4F8BDED44404FADBEBA2AFC47400473F4F8BDED4440
23847	Тинит	8	75	1447	48.042413000000003	48.060568000000004	41.919429999999998	41.902185000000003	0103000020E610000001000000050000006FF607CA6D0548408CF84ECC7AF344406FF607CA6D0548400B7BDAE1AFF54440929735B1C00748400B7BDAE1AFF54440929735B1C00748408CF84ECC7AF344406FF607CA6D0548408CF84ECC7AF34440
23790	Татиль	8	75	1447	47.985793000000001	47.994731000000002	41.995077999999999	41.990749000000001	0103000020E6100000010000000500000018D00B772EFE4740B9C5FCDCD0FE444018D00B772EFE47400B7C45B75EFF4440A0A86C5853FF47400B7C45B75EFF4440A0A86C5853FF4740B9C5FCDCD0FE444018D00B772EFE4740B9C5FCDCD0FE4440
23659	Сиртич	8	75	1447	48.212276000000003	48.241093999999997	41.842449999999999	41.822839000000002	0103000020E61000000100000005000000E4DC26DC2B1B4840CA6FD1C952E94440E4DC26DC2B1B4840F241CF66D5EB444083A10E2BDC1E4840F241CF66D5EB444083A10E2BDC1E4840CA6FD1C952E94440E4DC26DC2B1B4840CA6FD1C952E94440
23636	Сикух	8	75	1447	47.841532000000001	47.847783999999997	41.906016999999999	41.901876999999999	0103000020E61000000100000005000000CC441152B7EB4740DE019EB470F34440CC441152B7EB47405D4F745DF8F344403909A52F84EC47405D4F745DF8F344403909A52F84EC4740DE019EB470F34440CC441152B7EB4740DE019EB470F34440
23522	Рушуль	8	75	1447	48.007297999999999	48.016900999999997	41.959705999999997	41.954275000000003	0103000020E61000000100000005000000C1A90F24EF004840F931E6AE25FA4440C1A90F24EF00484032E36DA5D7FA44408522DDCF2902484032E36DA5D7FA44408522DDCF29024840F931E6AE25FA4440C1A90F24EF004840F931E6AE25FA4440
23491	Пилиг	8	75	1447	47.863621999999999	47.873755000000003	41.977733000000001	41.968387999999997	0103000020E61000000100000005000000950D6B2A8BEE47405FEB5223F4FB4440950D6B2A8BEE4740289CDD5A26FD4440B6DB2E34D7EF4740289CDD5A26FD4440B6DB2E34D7EF47405FEB5223F4FB4440950D6B2A8BEE47405FEB5223F4FB4440
53550	Ниграс	8	75	1447	48.008429999999997	48.016748999999997	41.847580999999998	41.840226000000001	0103000020E610000001000000050000001327F73B14014840DC9F8B868CEB44401327F73B1401484001DBC1887DEC4440CF9ECBD42402484001DBC1887DEC4440CF9ECBD424024840DC9F8B868CEB44401327F73B14014840DC9F8B868CEB4440
23277	Марага	8	75	1447	48.112707	48.131166999999998	41.968516000000001	41.958499000000003	0103000020E61000000100000005000000E083D72E6D0E4840D61F6118B0FA4440E083D72E6D0E48408DD31055F8FB44403FA88B14CA1048408DD31055F8FB44403FA88B14CA104840D61F6118B0FA4440E083D72E6D0E4840D61F6118B0FA4440
23263	Лидже	8	75	1447	47.977213999999996	47.984453999999999	41.975997	41.970286000000002	0103000020E61000000100000005000000BF982D5915FD474022E2E65432FC4440BF982D5915FD47403FFF3D78EDFC44404C35B39602FE47403FFF3D78EDFC44404C35B39602FE474022E2E65432FC4440BF982D5915FD474022E2E65432FC4440
23202	Кюряг	8	75	1447	47.850946999999998	47.860818999999999	41.909956000000001	41.903641999999998	0103000020E610000001000000050000008DD0CFD4EBEC474061A5828AAAF344408DD0CFD4EBEC474045662E7079F44440416326512FEE474045662E7079F44440416326512FEE474061A5828AAAF344408DD0CFD4EBEC474061A5828AAAF34440
53888	Куркак	8	75	1447	47.968499999999999	47.979855000000001	41.914163000000002	41.907507000000003	0103000020E610000001000000050000008716D9CEF7FB47400FF27A3029F444408716D9CEF7FB47404C1B0E4B03F544403AE97DE36BFD47404C1B0E4B03F544403AE97DE36BFD47400FF27A3029F444408716D9CEF7FB47400FF27A3029F44440
53493	Караг	8	75	1447	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
22979	Зиль	8	75	1447	48.029046999999998	48.040868000000003	41.998300999999998	41.993248999999999	0103000020E610000001000000050000000186E5CFB703484071E481C822FF44400186E5CFB70348403448C153C8FF4440FAB9A1293B0548403448C153C8FF4440FAB9A1293B05484071E481C822FF44400186E5CFB703484071E481C822FF4440
22920	Ерси	8	75	1447	48.001036999999997	48.015275000000003	42.026398	42.017207999999997	0103000020E61000000100000005000000008BFCFA21004840629D2ADF33024540008BFCFA21004840045779026103454024B9FC87F4014840045779026103454024B9FC87F4014840629D2ADF33024540008BFCFA21004840629D2ADF33024540
22871	Дюбек	8	75	1447	47.962805000000003	47.97486	42.031689	42.018374000000001	0103000020E6100000010000000500000070B6B9313DFB4740618C48145A02454070B6B9313DFB47404C5299620E044540DB166536C8FC47404C5299620E044540DB166536C8FC4740618C48145A02454070B6B9313DFB4740618C48145A024540
22740	Джульджаг	8	75	1447	47.883564	47.892699999999998	41.960216000000003	41.952297000000002	0103000020E6100000010000000500000023F609A018F147401A8A3BDEE4F9444023F609A018F14740488C9E5BE8FA4440D1915CFE43F24740488C9E5BE8FA4440D1915CFE43F247401A8A3BDEE4F9444023F609A018F147401A8A3BDEE4F94440
22843	Джули	8	75	1447	47.850309000000003	47.857064000000001	41.884036000000002	41.878995000000003	0103000020E610000001000000050000004B3FE1ECD6EC47407C2C7DE882F044404B3FE1ECD6EC47404B3E761728F144401B4AED45B4ED47404B3E761728F144401B4AED45B4ED47407C2C7DE882F044404B3FE1ECD6EC47407C2C7DE882F04440
22678	Дарваг	8	75	1447	48.062105000000003	48.075400000000002	42.023384	42.009008000000001	0103000020E6100000010000000500000084F57F0EF307484081B3942C2701454084F57F0EF3074840F59F353FFE024540280F0BB5A6094840F59F353FFE024540280F0BB5A609484081B3942C2701454084F57F0EF307484081B3942C27014540
22617	Дагни	8	75	1447	47.908608999999998	47.913513999999999	41.933323999999999	41.929895999999999	0103000020E61000000100000005000000F6ECB94C4DF44740325706D506F74440F6ECB94C4DF4474034492C2977F744401538D906EEF4474034492C2977F744401538D906EEF44740325706D506F74440F6ECB94C4DF44740325706D506F74440
22591	Гюхряг	8	75	1447	47.902689000000002	47.906795000000002	41.937657000000002	41.934598000000001	0103000020E61000000100000005000000BFBA2A508BF34740197442E8A0F74440BFBA2A508BF34740C8EE022505F844409296CADB11F44740C8EE022505F844409296CADB11F44740197442E8A0F74440BFBA2A508BF34740197442E8A0F74440
53560	Гурхунь	8	75	1447	47.915742000000002	47.922964	42.020899	42.017676999999999	0103000020E610000001000000050000006DC9AA0837F5474019726C3D430245406DC9AA0837F5474072C284D1AC02454053B131AF23F6474072C284D1AC02454053B131AF23F6474019726C3D430245406DC9AA0837F5474019726C3D43024540
21236	Гурик	8	75	1447	47.912032000000004	47.921427999999999	41.964064	41.958317999999998	0103000020E61000000100000005000000E773EE76BDF4474085950A2AAAFA4440E773EE76BDF447401FA0FB7266FB444031CF4A5AF1F547401FA0FB7266FB444031CF4A5AF1F5474085950A2AAAFA4440E773EE76BDF4474085950A2AAAFA4440
22463	Гуми	8	75	1447	47.865850000000002	47.870395000000002	41.895862999999999	41.892097999999997	0103000020E61000000100000005000000ED9E3C2CD4EE4740DB696B4430F24440ED9E3C2CD4EE4740255987A3ABF244400CCD751A69EF4740255987A3ABF244400CCD751A69EF4740DB696B4430F24440ED9E3C2CD4EE4740DB696B4430F24440
22449	Гисик	8	75	1447	47.911330999999997	47.917907	41.947515000000003	41.939421000000003	0103000020E610000001000000050000005D6A847EA6F447407B1684F23EF844405D6A847EA6F4474017BCE82B48F944407EE200FA7DF5474017BCE82B48F944407EE200FA7DF547407B1684F23EF844405D6A847EA6F447407B1684F23EF84440
53478	Гасих	8	75	1447	47.882846000000001	47.888649000000001	41.926394000000002	41.919564999999999	0103000020E61000000100000005000000C4B3041901F14740EBC5504EB4F54440C4B3041901F14740F69A1E1494F64440C24F1C40BFF14740F69A1E1494F64440C24F1C40BFF14740EBC5504EB4F54440C4B3041901F14740EBC5504EB4F54440
22337	Вечрик	8	75	1447	47.958933000000002	47.964485000000003	41.919255999999997	41.915841	0103000020E6100000010000000500000010070951BEFA474000AB23473AF5444010070951BEFA47406D533C2EAAF54440C53D963E74FB47406D533C2EAAF54440C53D963E74FB474000AB23473AF5444010070951BEFA474000AB23473AF54440
22257	Бурганкент	8	75	1447	48.057091999999997	48.070754999999998	41.903373000000002	41.895466999999996	0103000020E610000001000000050000007E6E68CA4E074840D8D2A3A99EF244407E6E68CA4E074840728BF9B9A1F34440A583F57F0E094840728BF9B9A1F34440A583F57F0E094840D8D2A3A99EF244407E6E68CA4E074840D8D2A3A99EF24440
22231	Афна	8	75	1447	47.859588000000002	47.862957000000002	41.903621999999999	41.899842999999997	0103000020E610000001000000050000005C04C6FA06EE47406B44300E2EF344405C04C6FA06EE47401AF9BCE2A9F34440596DFE5F75EE47401AF9BCE2A9F34440596DFE5F75EE47406B44300E2EF344405C04C6FA06EE47406B44300E2EF34440
22179	Аркит	8	75	1447	48.009301999999998	48.018715999999998	41.950513000000001	41.942942000000002	0103000020E61000000100000005000000C9E4D4CE300148402E03CE52B2F84440C9E4D4CE3001484020B6F468AAF94440BAF42F496502484020B6F468AAF94440BAF42F49650248402E03CE52B2F84440C9E4D4CE300148402E03CE52B2F84440
22130	Арак	8	75	1447	47.986986999999999	47.993023999999998	41.963580999999998	41.958184000000003	0103000020E61000000100000005000000E0490B9755FE474076C6F7C5A5FA4440E0490B9755FE47400306499F56FB4440511212691BFF47400306499F56FB4440511212691BFF474076C6F7C5A5FA4440E0490B9755FE474076C6F7C5A5FA4440
22111	Акка	8	75	1447	47.923341999999998	47.930788999999997	41.928936999999998	41.921919000000003	0103000020E61000000100000005000000F982161230F64740D047197101F64440F982161230F64740AD855968E7F64440FF3C0D1824F74740AD855968E7F64440FF3C0D1824F74740D047197101F64440F982161230F64740D047197101F64440
20364	Юхари-Стал	8	75	782	48.144883999999998	48.155870999999998	41.712909000000003	41.702655999999998	0103000020E6100000010000000500000059DB148F8B124840492BBEA1F0D9444059DB148F8B1248401503249A40DB444089B2B794F31348401503249A40DB444089B2B794F3134840492BBEA1F0D9444059DB148F8B124840492BBEA1F0D94440
21602	Юхари-Картас	8	75	782	48.094676999999997	48.105206000000003	41.627124999999999	41.620438999999998	0103000020E6100000010000000500000079573D601E0C4840DB148F8B6ACF444079573D601E0C484083C0CAA145D04440E7ABE463770D484083C0CAA145D04440E7ABE463770D4840DB148F8B6ACF444079573D601E0C4840DB148F8B6ACF4440
53724	Эминхюр	8	75	782	47.830294000000002	48.403626000000003	41.829900000000002	41.541395000000001	0103000020E610000001000000050000005308E41247EA4740E59B6D6E4CC544405308E41247EA4740A779C7293AEA44405CE84A04AA334840A779C7293AEA44405CE84A04AA334840E59B6D6E4CC544405308E41247EA4740E59B6D6E4CC54440
21070	Экендиль	8	75	782	48.125301	48.136628999999999	41.760438999999998	41.751089	0103000020E61000000100000005000000FB93F8DC0910484053B131AF23E04440FB93F8DC091048402DCDAD1056E14440B4571F0F7D1148402DCDAD1056E14440B4571F0F7D11484053B131AF23E04440FB93F8DC0910484053B131AF23E04440
21707	Шихикент	8	75	782	48.158538999999998	48.169201999999999	41.608736	41.601312	0103000020E61000000100000005000000FD1186014B1448409F58A7CAF7CC4440FD1186014B144840EDF2AD0FEBCD44407A354069A8154840EDF2AD0FEBCD44407A354069A81548409F58A7CAF7CC4440FD1186014B1448409F58A7CAF7CC4440
53702	Чухверкент	8	75	782	47.955708000000001	48.087508999999997	41.698435000000003	41.599578999999999	0103000020E610000001000000050000004643C6A354FA4740272F3201BFCC44404643C6A354FA4740DEB06D5166D94440868DB27E330B4840DEB06D5166D94440868DB27E330B4840272F3201BFCC44404643C6A354FA4740272F3201BFCC4440
21281	Цмур	8	75	782	48.049241000000002	48.060200000000002	41.686900999999999	41.682107000000002	0103000020E61000000100000005000000A94F72874D064840B4AF3C484FD74440A94F72874D0648407B4B395FECD744400F9C33A2B40748407B4B395FECD744400F9C33A2B4074840B4AF3C484FD74440A94F72874D064840B4AF3C484FD74440
21873	Хтун	8	75	782	48.16798	48.177781000000003	41.585633000000001	41.579495999999999	0103000020E61000000100000005000000E8305F5E80154840D714C8EC2CCA4440E8305F5E80154840AC3AAB05F6CA4440D36C1E87C1164840AC3AAB05F6CA4440D36C1E87C1164840D714C8EC2CCA4440E8305F5E80154840D714C8EC2CCA4440
21397	Уллугатаг	8	75	782	48.119902000000003	48.132055999999999	41.612572	41.601036000000001	0103000020E61000000100000005000000CD5CE0F2580F4840FDDB65BFEECC4440CD5CE0F2580F4840003961C268CE4440CB9E0436E7104840003961C268CE4440CB9E0436E7104840FDDB65BFEECC4440CD5CE0F2580F4840FDDB65BFEECC4440
53435	Татарханкент	8	75	782	48.089449000000002	48.097813000000002	41.586530000000003	41.580568	0103000020E6100000010000000500000078D49810730B4840548D5E0D50CA444078D49810730B4840BB0F406A13CB4440D40FEA22850C4840BB0F406A13CB4440D40FEA22850C4840548D5E0D50CA444078D49810730B4840548D5E0D50CA4440
20091	Сийидкент	8	75	782	48.103580000000001	48.115293999999999	41.706775999999998	41.699916000000002	0103000020E610000001000000050000008542041C420D48403CF9F4D896D944408542041C420D484081CCCEA277DA444067B62BF4C10E484081CCCEA277DA444067B62BF4C10E48403CF9F4D896D944408542041C420D48403CF9F4D896D94440
21171	Сардаркент	8	75	782	48.052807000000001	48.064960999999997	41.728771999999999	41.719510999999997	0103000020E61000000100000005000000FCFF3861C20648405E0EBBEF18DC4440FCFF3861C2064840C91EA16648DD4440FA415DA450084840C91EA16648DD4440FA415DA4500848405E0EBBEF18DC4440FCFF3861C20648405E0EBBEF18DC4440
21443	Сайтаркент	8	75	782	48.120790999999997	48.130341000000001	41.591392999999997	41.583745	0103000020E6100000010000000500000058535914760F48400D1AFA27B8CA444058535914760F4840AA0A0DC4B2CB4440FA298E03AF104840AA0A0DC4B2CB4440FA298E03AF1048400D1AFA27B8CA444058535914760F48400D1AFA27B8CA4440
21518	Птикент	8	75	782	48.103552999999998	48.112186000000001	41.587609	41.581249	0103000020E610000001000000050000008B338639410D484096EA025E66CA44408B338639410D4840EAEA8EC536CB4440D788601C5C0E4840EAEA8EC536CB4440D788601C5C0E484096EA025E66CA44408B338639410D484096EA025E66CA4440
21850	Пиперкент	8	75	782	48.138694999999998	48.148774000000003	41.595776000000001	41.589112999999998	0103000020E61000000100000005000000328FFCC1C01148400053060E68CB4440328FFCC1C0114840F0DE516342CC4440603FC4060B134840F0DE516342CC4440603FC4060B1348400053060E68CB4440328FFCC1C01148400053060E68CB4440
20332	Орта Стал	8	75	782	48.150463000000002	48.179504999999999	41.711736999999999	41.697896999999998	0103000020E610000001000000050000000821205F42134840FE7C5BB054D944400821205F42134840342DB1321ADB4440F73B1405FA164840342DB1321ADB4440F73B1405FA164840FE7C5BB054D944400821205F42134840FE7C5BB054D94440
20982	Нютюг	8	75	782	48.110101	48.120790999999997	41.759625	41.751223000000003	0103000020E61000000100000005000000E22021CA170E48406380441328E04440E22021CA170E4840AC1C5A643BE1444058535914760F4840AC1C5A643BE1444058535914760F48406380441328E04440E22021CA170E48406380441328E04440
22001	Новый Испик	8	75	782	48.185524000000001	48.193052000000002	41.641190000000002	41.630940000000002	0103000020E61000000100000005000000C24F1C40BF1748407FDE54A4C2D04440C24F1C40BF174840D942908312D24440B5368DEDB5184840D942908312D24440B5368DEDB51848407FDE54A4C2D04440C24F1C40BF1748407FDE54A4C2D04440
53722	Новомака	8	75	782	47.830294000000002	48.403626000000003	41.829900000000002	41.541395000000001	0103000020E610000001000000050000005308E41247EA4740E59B6D6E4CC544405308E41247EA4740A779C7293AEA44405CE84A04AA334840A779C7293AEA44405CE84A04AA334840E59B6D6E4CC544405308E41247EA4740E59B6D6E4CC54440
20791	Куркент	8	75	782	48.100346000000002	48.124951000000003	41.718327000000002	41.706648000000001	0103000020E6100000010000000500000068244223D80C484054E4107173DA444068244223D80C4840BA6A9E23F2DB44401F4DF564FE0F4840BA6A9E23F2DB44401F4DF564FE0F484054E4107173DA444068244223D80C484054E4107173DA4440
21312	Качалкент	8	75	782	48.040284	48.047417000000003	41.671371999999998	41.667391000000002	0103000020E61000000100000005000000AA46AF062805484087527B116DD54440AA46AF06280548409DB98784EFD544402123A0C2110648409DB98784EFD544402123A0C21106484087527B116DD54440AA46AF062805484087527B116DD54440
20160	Кахцуг	8	75	782	48.052888000000003	48.064072000000003	41.603645	41.597327	0103000020E61000000100000005000000E92CB308C506484047020D3675CC4440E92CB308C50648406CB2463D44CD44406F4BE482330848406CB2463D44CD44406F4BE4823308484047020D3675CC4440E92CB308C506484047020D3675CC4440
19801	Касумкент	8	75	782	48.128804000000002	48.190320999999997	41.687797000000003	41.670178999999997	0103000020E6100000010000000500000008CC43A67C104840A5BBEB6CC8D5444008CC43A67C104840BAA46ABB09D84440FA5E43705C184840BAA46ABB09D84440FA5E43705C184840A5BBEB6CC8D5444008CC43A67C104840A5BBEB6CC8D54440
20922	Карчаг	8	75	782	48.150632999999999	48.169130000000003	41.781427000000001	41.770749000000002	0103000020E61000000100000005000000645930F1471348405D363AE7A7E24440645930F1471348400F9BC8CC05E44440E162450DA61548400F9BC8CC05E44440E162450DA61548405D363AE7A7E24440645930F1471348405D363AE7A7E24440
5515	Картас-Казмаляр	8	75	782	48.389603000000001	48.408287999999999	41.824142000000002	41.800654000000002	0103000020E6100000010000000500000035B6D782DE314840AFB48CD47BE6444035B6D782DE31484049A12C7C7DE94440B4ACFBC74234484049A12C7C7DE94440B4ACFBC742344840AFB48CD47BE6444035B6D782DE314840AFB48CD47BE64440
21373	Ичин	8	75	782	47.987158000000001	47.995809000000001	41.685386000000001	41.680349	0103000020E610000001000000050000000DFE7E315BFE4740E36E10AD15D744400DFE7E315BFE474071917BBABAD74440FF0758AB76FF474071917BBABAD74440FF0758AB76FF4740E36E10AD15D744400DFE7E315BFE4740E36E10AD15D74440
21933	Испик	8	75	782	48.185505999999997	48.194327999999999	41.616622999999997	41.610232000000003	0103000020E610000001000000050000001B9B1DA9BE174840817C09151CCE44401B9B1DA9BE1748400F7BA180EDCE44403A596ABDDF1848400F7BA180EDCE44403A596ABDDF184840817C09151CCE44401B9B1DA9BE174840817C09151CCE4440
21787	Зухрабкент	8	75	782	48.144741000000003	48.157622000000003	41.569963999999999	41.562280000000001	0103000020E61000000100000005000000F7B182DF86124840F29881CAF8C74440F7B182DF86124840DCF29194F4C84440A8902BF52C144840DCF29194F4C84440A8902BF52C144840F29881CAF8C74440F7B182DF86124840F29881CAF8C74440
21053	Зизик	8	75	782	48.101523	48.115473000000001	41.773868999999998	41.762186999999997	0103000020E610000001000000050000005A65A6B4FE0C4840DA37F7578FE144405A65A6B4FE0C4840B131AF230EE344401749BBD1C70E4840B131AF230EE344401749BBD1C70E4840DA37F7578FE144405A65A6B4FE0C4840DA37F7578FE14440
53696	Даркуш	8	75	782	48.377161999999998	48.392603999999999	41.809499000000002	41.796863000000002	0103000020E61000000100000005000000A0A52BD8463048403C32569BFFE54440A0A52BD8463048408692C9A99DE74440AF230ED9403248408692C9A99DE74440AF230ED9403248403C32569BFFE54440A0A52BD8463048403C32569BFFE54440
20459	Герейхановское	8	75	782	48.207362000000003	48.247553000000003	41.689864	41.678356000000001	0103000020E61000000100000005000000723788D68A1A4840CF85915ED4D64440723788D68A1A48400858AB764DD844406B8313D1AF1F48400858AB764DD844406B8313D1AF1F4840CF85915ED4D64440723788D68A1A4840CF85915ED4D64440
21758	Буткент	8	75	782	48.174475000000001	48.182811000000001	41.602715000000003	41.595168999999999	0103000020E610000001000000050000001C7C613255164840E84B6F7F2ECC44401C7C61325516484082E7DEC325CD4440AE2CD1596617484082E7DEC325CD4440AE2CD15966174840E84B6F7F2ECC44401C7C613255164840E84B6F7F2ECC4440
20176	Ашага-Стал	8	75	782	48.185496999999998	48.202736000000002	41.703431000000002	41.686511000000003	0103000020E61000000100000005000000C8409E5DBE17484011ACAA97DFD74440C8409E5DBE1748400DFFE9060ADA444066DCD440F31948400DFFE9060ADA444066DCD440F319484011ACAA97DFD74440C8409E5DBE17484011ACAA97DFD74440
21624	Ашага-Картас	8	75	782	48.114457999999999	48.122416999999999	41.634101000000001	41.628405999999998	0103000020E61000000100000005000000FE614B8FA60E48401A4E999B6FD04440FE614B8FA60E484032AEB8382AD14440BABC395CAB0F484032AEB8382AD14440BABC395CAB0F48401A4E999B6FD04440FE614B8FA60E48401A4E999B6FD04440
22018	Асаликент	8	75	782	48.160542	48.169606000000002	41.634256000000001	41.626579	0103000020E6100000010000000500000035D1E7A38C14484021AE9CBD33D0444035D1E7A38C14484059A5F44C2FD144404A9A3FA6B515484059A5F44C2FD144404A9A3FA6B515484021AE9CBD33D0444035D1E7A38C14484021AE9CBD33D04440
21148	Алкадар	8	75	782	48.078589000000001	48.091200999999998	41.719794	41.713360000000002	0103000020E61000000100000005000000A56950340F0A4840252367614FDB4440A56950340F0A4840B3EDB43522DC4440662E7079AC0B4840B3EDB43522DC4440662E7079AC0B4840252367614FDB4440A56950340F0A4840252367614FDB4440
53718	Тарки	8	75	7291	47.551808000000001	47.553029000000002	42.899776000000003	42.896177000000002	0103000020E61000000100000005000000E9D500A5A1C64740B5368DEDB5724540E9D500A5A1C64740E4DC26DC2B734540AB5E7EA7C9C64740E4DC26DC2B734540AB5E7EA7C9C64740B5368DEDB5724540E9D500A5A1C64740B5368DEDB5724540
19723	Урахи	8	75	1539	47.585126000000002	47.611562999999997	42.340696999999999	42.330260000000003	0103000020E610000001000000050000000805A568E5CA4740A796ADF5452A45400805A568E5CA4740336C94F59B2B4540C93846B247CE4740336C94F59B2B4540C93846B247CE4740A796ADF5452A45400805A568E5CA4740A796ADF5452A4540
19250	Сергокала	8	75	1539	47.653092999999998	47.679817	42.458306	42.439771	0103000020E610000001000000050000008E1F2A8D98D34740575D876A4A3845408E1F2A8D98D34740C1C760C5A93A4540E621533E04D74740C1C760C5A93A4540E621533E04D74740575D876A4A3845408E1F2A8D98D34740575D876A4A384540
19166	Новые Мугри	8	75	1539	47.752347	47.764232	42.479520999999998	42.46799	0103000020E61000000100000005000000321F10E84CE04740726DA818E73B4540321F10E84CE04740635FB2F1603D45404147AB5AD2E14740635FB2F1603D45404147AB5AD2E14740726DA818E73B4540321F10E84CE04740726DA818E73B4540
53438	Нижние Мулебки	8	75	1539	47.563772999999998	47.574930000000002	42.330280000000002	42.325786999999998	0103000020E6100000010000000500000014AFB2B629C84740213B6F63B329454014AFB2B629C84740EE42739D462A4540A1BE654E97C94740EE42739D462A4540A1BE654E97C94740213B6F63B329454014AFB2B629C84740213B6F63B3294540
18434	Нижние Махаргимахи	8	75	1539	47.631686000000002	47.643552	42.332912999999998	42.324446999999999	0103000020E61000000100000005000000A8AB3B16DBD047408524B37A87294540A8AB3B16DBD04740E5B4A7E49C2A454040A374E95FD24740E5B4A7E49C2A454040A374E95FD247408524B37A87294540A8AB3B16DBD047408524B37A87294540
18917	Мюрего	8	75	1539	47.680168000000002	47.699598000000002	42.412678	42.399403	0103000020E6100000010000000500000093E4B9BE0FD747404F7633A31F33454093E4B9BE0FD74740ACE3F8A1D23445406B2C616D8CD94740ACE3F8A1D23445406B2C616D8CD947404F7633A31F33454093E4B9BE0FD747404F7633A31F334540
18860	Мургук	8	75	1539	47.687506999999997	47.701799000000001	42.271109000000003	42.262101999999999	0103000020E61000000100000005000000B262B83A00D84740AC1BEF8E8C214540B262B83A00D847405D5320B3B3224540C9AEB48CD4D947405D5320B3B3224540C9AEB48CD4D94740AC1BEF8E8C214540B262B83A00D84740AC1BEF8E8C214540
18811	Миглакасимахи	8	75	1539	47.547280000000001	47.566693000000001	42.343249999999998	42.328493999999999	0103000020E61000000100000005000000A0E062450DC64740537765170C2A4540A0E062450DC647400E2DB29DEF2B4540A2EF6E6589C847400E2DB29DEF2B4540A2EF6E6589C84740537765170C2A4540A0E062450DC64740537765170C2A4540
53507	Мамаул	8	75	1539	47.749175999999999	47.757233999999997	42.318308000000002	42.312894	0103000020E610000001000000050000005B79C9FFE4DF4740AC8E1CE90C2845405B79C9FFE4DF474010070951BE284540AAB5300BEDE0474010070951BE284540AAB5300BEDE04740AC8E1CE90C2845405B79C9FFE4DF4740AC8E1CE90C284540
53764	Краснопартизанск	8	75	1539	47.485897999999999	47.851297000000002	42.514501000000003	42.222799999999999	0103000020E610000001000000050000008D98D9E731BE47403FC6DCB5841C45408D98D9E731BE47403161342BDB4145406A17D34CF7EC47403161342BDB4145406A17D34CF7EC47403FC6DCB5841C45408D98D9E731BE47403FC6DCB5841C4540
18683	Кичи-Гамри	8	75	1539	47.704135000000001	47.717466000000002	42.316228000000002	42.308146999999998	0103000020E61000000100000005000000077C7E1821DA474025AE635C71274540077C7E1821DA47402D0ABB287A284540F8FE06EDD5DB47402D0ABB287A284540F8FE06EDD5DB474025AE635C71274540077C7E1821DA474025AE635C71274540
18590	Канасираги	8	75	1539	47.634892999999998	47.642896999999998	42.257150000000003	42.251750999999999	0103000020E61000000100000005000000CBBA7F2C44D147401EDE736039204540CBBA7F2C44D147404D158C4AEA20454027D9EA724AD247404D158C4AEA20454027D9EA724AD247401EDE736039204540CBBA7F2C44D147401EDE736039204540
19657	Кадиркент	8	75	1539	47.601447999999998	47.617491999999999	42.499580000000002	42.492553000000001	0103000020E610000001000000050000004F1F813FFCCC4740FA4509FA0B3F45404F1F813FFCCC47402BDEC83CF23F454054C554FA09CF47402BDEC83CF23F454054C554FA09CF4740FA4509FA0B3F45404F1F813FFCCC4740FA4509FA0B3F4540
18543	Дегва	8	75	1539	47.524794999999997	47.542760999999999	42.423161	42.412717999999998	0103000020E610000001000000050000005A0D897B2CC347403A3C84F1D33445405A0D897B2CC34740A9F8BF232A364540AA45443179C54740A9F8BF232A364540AA45443179C547403A3C84F1D33445405A0D897B2CC347403A3C84F1D3344540
53617	Ванаши-Махи	8	75	1539	47.601016999999999	47.612174000000003	42.410321000000003	42.396645999999997	0103000020E6100000010000000500000086AB0320EECC47406B0BCF4BC532454086AB0320EECC474057EE05668534454013BBB6B75BCE474057EE05668534454013BBB6B75BCE47406B0BCF4BC532454086AB0320EECC47406B0BCF4BC5324540
19142	Бурхимахи	8	75	1539	47.583382999999998	47.589680000000001	42.307053000000003	42.303091999999999	0103000020E610000001000000050000006C054D4BACCA4740F1D6F9B7CB2645406C054D4BACCA4740C19140834D2745407A8D5DA27ACB4740C19140834D2745407A8D5DA27ACB4740F1D6F9B7CB2645406C054D4BACCA4740F1D6F9B7CB264540
18378	Бурдеки	8	75	1539	47.663127000000003	47.671221000000003	42.307673000000001	42.301738999999998	0103000020E610000001000000050000001C0C7558E1D44740C07630629F2645401C0C7558E1D447405D6E30D461274540B8B1D991EAD547405D6E30D461274540B8B1D991EAD54740C07630629F2645401C0C7558E1D44740C07630629F264540
18699	Балтамахи	8	75	1539	47.721769000000002	47.728802999999999	42.300004999999999	42.294429000000001	0103000020E61000000100000005000000212235ED62DC47403BFF76D9AF254540212235ED62DC474078D1579066264540041DAD6A49DD474078D1579066264540041DAD6A49DD47403BFF76D9AF254540212235ED62DC47403BFF76D9AF254540
53475	Аялизмахи	8	75	1539	47.595142000000003	47.613342000000003	42.380097999999997	42.372897999999999	0103000020E61000000100000005000000EF3CF19C2DCC4740355F251FBB2F4540EF3CF19C2DCC474033A31F0DA7304540B2A19BFD81CE474033A31F0DA7304540B2A19BFD81CE4740355F251FBB2F4540EF3CF19C2DCC4740355F251FBB2F4540
18291	Аймаумахи	8	75	1539	47.565030999999998	47.596561999999999	42.367708999999998	42.355097000000001	0103000020E61000000100000005000000F31C91EF52C8474030F488D1732D4540F31C91EF52C84740F1B8A816112F4540A704C4245CCC4740F1B8A816112F4540A704C4245CCC474030F488D1732D4540F31C91EF52C8474030F488D1732D4540
53950	с. Согют	8	75	1410	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
53649	с. Дженых	8	75	1410	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
53553	с. Асталай	8	75	1410	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
53789	прикутан Правда	8	75	1410	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
53463	прикутан Камбулат	8	75	1410	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
16115	Шиназ	8	75	1410	47.365569000000001	47.380966000000001	41.624200000000002	41.601872	0103000020E6100000010000000500000039B709F7CAAE4740663046240ACD444039B709F7CAAE4740E4141DC9E5CF4440A8716F7EC3B04740E4141DC9E5CF4440A8716F7EC3B04740663046240ACD444039B709F7CAAE4740663046240ACD4440
53626	Цахур	8	75	1410	47.132680999999998	47.141080000000002	41.654147000000002	41.648743000000003	0103000020E6100000010000000500000079E6E5B0FB9047402541B8020AD3444079E6E5B0FB90474065E3C116BBD34440520FD1E80E92474065E3C116BBD34440520FD1E80E9247402541B8020AD3444079E6E5B0FB9047402541B8020AD34440
53810	Хнях	8	75	1410	47.151428000000003	47.154788000000003	41.649335999999998	41.646802999999998	0103000020E610000001000000050000006FD921FE6193474033FAD170CAD244406FD921FE61934740C70E2A711DD3444019E8DA17D0934740C70E2A711DD3444019E8DA17D093474033FAD170CAD244406FD921FE6193474033FAD170CAD24440
32882	Хлют	8	75	1410	47.523780000000002	47.536464000000002	41.498983000000003	41.493572999999998	0103000020E61000000100000005000000422619390BC3474024986A662DBF4440422619390BC347404721C9ACDEBF44409DBD33DAAAC447404721C9ACDEBF44409DBD33DAAAC4474024986A662DBF4440422619390BC3474024986A662DBF4440
32905	Рутул	8	75	1410	47.412398000000003	47.437325999999999	41.547913999999999	41.530817999999996	0103000020E61000000100000005000000C9772975C9B4474066101FD8F1C34440C9772975C9B44740A182C30B22C6444062D8614CFAB74740A182C30B22C6444062D8614CFAB7474066101FD8F1C34440C9772975C9B4474066101FD8F1C34440
53849	Новый Борч	8	75	1410	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
16849	Нижний Катрух	8	75	1410	47.198770000000003	47.208364000000003	41.747396000000002	41.740721999999998	0103000020E6100000010000000500000085B69C4B71994740BFB67EFACFDE444085B69C4B71994740A39410ACAADF4440F6D4EAABAB9A4740A39410ACAADF4440F6D4EAABAB9A4740BFB67EFACFDE444085B69C4B71994740BFB67EFACFDE4440
53806	Мухух	8	75	1410	46.988869000000001	46.994627000000001	41.702455	41.699041000000001	0103000020E610000001000000050000009D836742937E474015C8EC2C7AD944409D836742937E4740B2F4A10BEAD94440FB5B02F04F7F4740B2F4A10BEAD94440FB5B02F04F7F474015C8EC2C7AD944409D836742937E474015C8EC2C7AD94440
17330	Муслах	8	75	1410	47.109369000000001	47.114409000000002	41.660722	41.656222	0103000020E610000001000000050000001E19ABCDFF8D474036751E15FFD344401E19ABCDFF8D4740B5DFDA8992D444401DAF40F4A48E4740B5DFDA8992D444401DAF40F4A48E474036751E15FFD344401E19ABCDFF8D474036751E15FFD34440
17387	Мишлеш	8	75	1410	47.085087999999999	47.093972000000001	41.667478000000003	41.663167000000001	0103000020E610000001000000050000001AA4E029E48A4740AA6400A8E2D444401AA4E029E48A474056664AEB6FD54440AF5E4546078C474056664AEB6FD54440AF5E4546078C4740AA6400A8E2D444401AA4E029E48A4740AA6400A8E2D44440
53925	Михрек	8	75	1410	47.274254999999997	47.302515999999997	41.685110000000002	41.661321999999998	0103000020E61000000100000005000000DAE1AFC91AA347400A100533A6D44440DAE1AFC91AA34740CF143AAFB1D74440244223D8B8A64740CF143AAFB1D74440244223D8B8A647400A100533A6D44440DAE1AFC91AA347400A100533A6D44440
53647	Миких	8	75	1410	47.164876	47.169826	41.639465000000001	41.635151999999998	0103000020E6100000010000000500000099F221A81A95474097FE25A94CD1444099F221A81A954740E4F736FDD9D144405801BEDBBC954740E4F736FDD9D144405801BEDBBC95474097FE25A94CD1444099F221A81A95474097FE25A94CD14440
53593	Лучек	8	75	1410	47.300773	47.311121999999997	41.620323999999997	41.607016000000002	0103000020E610000001000000050000008942CBBA7FA647400A1346B3B2CD44408942CBBA7FA647404276DEC666CF444076887FD8D2A747404276DEC666CF444076887FD8D2A747400A1346B3B2CD44408942CBBA7FA647400A1346B3B2CD4440
53655	Куфа	8	75	1410	47.373069999999998	47.382179000000001	41.566240000000001	41.561565000000002	0103000020E61000000100000005000000328FFCC1C0AF474004CAA65CE1C74440328FFCC1C0AF4740F1D7648D7AC84440E71BD13DEBB04740F1D7648D7AC84440E71BD13DEBB0474004CAA65CE1C74440328FFCC1C0AF474004CAA65CE1C74440
53646	Кусур	8	75	1410	46.941160000000004	46.952452000000001	41.785299999999999	41.780217	0103000020E61000000100000005000000D5264EEE7778474041649126DEE34440D5264EEE777847403FC6DCB584E44440418177F2E97947403FC6DCB584E44440418177F2E979474041649126DEE34440D5264EEE7778474041649126DEE34440
53576	Курдул	8	75	1410	47.175027	47.179814999999998	41.587116999999999	41.579199000000003	0103000020E610000001000000050000006075E448679647401E705D3123CA44406075E448679647407BF65CA626CB4440452A8C2D049747407BF65CA626CB4440452A8C2D049747401E705D3123CA44406075E448679647401E705D3123CA4440
53455	Корш	8	75	1410	47.060088	47.065126999999997	41.672072	41.668475000000001	0103000020E61000000100000005000000E770ADF6B0874740C898BB9690D54440E770ADF6B087474056478E7406D64440158BDF145688474056478E7406D64440158BDF1456884740C898BB9690D54440E770ADF6B0874740C898BB9690D54440
53628	Кича	8	75	1410	47.477803999999999	47.483795999999998	41.534982999999997	41.529218	0103000020E61000000100000005000000F1F274AE28BD47402E3A596ABDC34440F1F274AE28BD47403E75AC527AC44440C2F7FE06EDBD47403E75AC527AC44440C2F7FE06EDBD47402E3A596ABDC34440F1F274AE28BD47402E3A596ABDC34440
16434	Кина	8	75	1410	47.263618999999998	47.273231000000003	41.619737000000001	41.614317999999997	0103000020E6100000010000000500000057CD7344BEA147400CACE3F8A1CE444057CD7344BEA14740828FC18A53CF44406FA0C03BF9A24740828FC18A53CF44406FA0C03BF9A247400CACE3F8A1CE444057CD7344BEA147400CACE3F8A1CE4440
53458	Кальял	8	75	1410	47.002110000000002	47.006449000000003	41.686065999999997	41.682464000000003	0103000020E610000001000000050000004E7FF623458047404359F8FA5AD744404E7FF62345804740E272BC02D1D74440C40B2252D3804740E272BC02D1D74440C40B2252D38047404359F8FA5AD744404E7FF623458047404359F8FA5AD74440
53418	Кала	8	75	1410	47.350512999999999	47.359146000000003	41.579718	41.575394000000003	0103000020E6100000010000000500000053E9279CDDAC47404628B682A6C9444053E9279CDDAC474086730D3334CA44409F3E027FF8AD474086730D3334CA44409F3E027FF8AD47404628B682A6C9444053E9279CDDAC47404628B682A6C94440
53630	Ихрек	8	75	1410	47.241556000000003	47.251652999999997	41.677453	41.670805999999999	0103000020E610000001000000050000008813984EEB9E4740F4FA93F8DCD544408813984EEB9E4740DEC9A7C7B6D644405B785E2A36A04740DEC9A7C7B6D644405B785E2A36A04740F4FA93F8DCD544408813984EEB9E4740F4FA93F8DCD54440
33018	Ихрек	8	75	1410	47.205471000000003	47.217958000000003	41.700071000000001	41.691426	0103000020E6100000010000000500000062A3ACDF4C9A474053CDACA580D8444062A3ACDF4C9A474063F030ED9BD9444067F3380CE69B474063F030ED9BD9444067F3380CE69B474053CDACA580D8444062A3ACDF4C9A474053CDACA580D84440
53571	Гельмец	8	75	1410	47.176015	47.181531	41.627077999999997	41.623485000000002	0103000020E610000001000000050000007F4DD6A887964740F645425BCECF44407F4DD6A8879647404205871744D04440E71A66683C9747404205871744D04440E71A66683C974740F645425BCECF44407F4DD6A887964740F645425BCECF4440
53818	Вруш	8	75	1410	47.304771000000002	47.312944999999999	41.649490999999998	41.644275999999998	0103000020E6100000010000000500000076E272BC02A7474081CCCEA277D2444076E272BC02A74740EE05668522D344402E39EE940EA84740EE05668522D344402E39EE940EA8474081CCCEA277D2444076E272BC02A7474081CCCEA277D24440
16933	Верхний Катрух	8	75	1410	47.218711999999996	47.226393000000002	41.748148999999998	41.744535999999997	0103000020E61000000100000005000000129F3BC1FE9B4740EA58A5F44CDF4440129F3BC1FE9B47407EC4AF58C3DF44408C852172FA9C47407EC4AF58C3DF44408C852172FA9C4740EA58A5F44CDF4440129F3BC1FE9B4740EA58A5F44CDF4440
53797	Борч	8	75	1410	47.321838999999997	47.331415	41.455306999999998	41.449731	0103000020E61000000100000005000000E6C9350532A94740AA7F10C990B94440E6C9350532A94740E751F17F47BA4440B13385CE6BAA4740E751F17F47BA4440B13385CE6BAA4740AA7F10C990B94440E6C9350532A94740AA7F10C990B94440
53901	Аран	8	75	1410	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
40251	Амсар	8	75	1410	47.324561000000003	47.336077000000003	41.606504000000001	41.600752	0103000020E610000001000000050000004E4700378BA94740D8800871E5CC44404E4700378BA9474054724EECA1CD44400AF8359204AB474054724EECA1CD44400AF8359204AB4740D8800871E5CC44404E4700378BA94740D8800871E5CC4440
15400	Эдиге	8	75	1355	46.345658	46.369858000000001	44.080114000000002	44.065359999999998	0103000020E61000000100000005000000E6CC76853E2C4740B83B6BB75D084640E6CC76853E2C4740D3F9F02C410A4640FD14C781572F4740D3F9F02C410A4640FD14C781572F4740B83B6BB75D084640E6CC76853E2C4740B83B6BB75D084640
53768	Шумлелик	8	75	1355	45.103907	46.449089999999998	44.993327000000001	43.816614000000001	0103000020E61000000100000005000000A96917D34C8D464056BABBCE86E84540A96917D34C8D4640ED9DD156257F4640F67AF7C77B394740ED9DD156257F4640F67AF7C77B39474056BABBCE86E84540A96917D34C8D464056BABBCE86E84540
14824	Червленные Буруны	8	75	1355	45.614320999999997	45.633077999999998	44.168142000000003	44.153016999999998	0103000020E610000001000000050000007D1F0E12A2CE4640B35DA10F961346407D1F0E12A2CE4640C28A53AD8515464096E82CB308D14640C28A53AD8515464096E82CB308D14640B35DA10F961346407D1F0E12A2CE4640B35DA10F96134640
53623	Уй-Салган	8	75	1355	45.148975999999998	45.161974000000001	44.224891999999997	44.211390000000002	0103000020E61000000100000005000000C7F143A511934640C959D8D30E1B4640C7F143A511934640E690D442C91C4640B2666490BB944640E690D442C91C4640B2666490BB944640C959D8D30E1B4640C7F143A511934640C959D8D30E1B4640
15483	Терекли-Мектеб	8	75	1355	45.834353999999998	45.893813999999999	44.175449	44.156399	0103000020E61000000100000005000000B5A4A31CCCEA46404510E7E104144640B5A4A31CCCEA4640D68EE21C751646407D5A457F68F24640D68EE21C751646407D5A457F68F246404510E7E104144640B5A4A31CCCEA46404510E7E104144640
53778	Ортатюбе	8	75	1355	45.273761	45.292274999999997	44.249718000000001	44.239632	0103000020E61000000100000005000000CBF5B6990AA346409C89E942AC1E4640CBF5B6990AA346407C9C69C2F61F46401D38674469A546407C9C69C2F61F46401D38674469A546409C89E942AC1E4640CBF5B6990AA346409C89E942AC1E4640
15027	Нариман	8	75	1355	45.825695000000003	45.846221	44.196869999999997	44.183717000000001	0103000020E6100000010000000500000041BCAE5FB0E94640105CE5098417464041BCAE5FB0E9464021C84109331946401E1840F850EC464021C84109331946401E1840F850EC4640105CE5098417464041BCAE5FB0E94640105CE50984174640
15312	Ленинаул	8	75	1355	46.016137999999998	46.027627000000003	44.202893000000003	44.194246	0103000020E61000000100000005000000861C5BCF100247407DB08C0DDD184640861C5BCF100247402ECBD765F819464049BE1248890347402ECBD765F819464049BE1248890347407DB08C0DDD184640861C5BCF100247407DB08C0DDD184640
14812	Кунбатар	8	75	1355	45.574454000000003	45.594253000000002	44.298138000000002	44.288407999999997	0103000020E6100000010000000500000038876BB587C94640CFF3A78DEA24464038876BB587C94640F1D8CF62292646406346787B10CC4640F1D8CF62292646406346787B10CC4640CFF3A78DEA24464038876BB587C94640CFF3A78DEA244640
15177	Кумли	8	75	1355	46.054532000000002	46.074798000000001	43.994695999999998	43.985292000000001	0103000020E61000000100000005000000F14A92E7FA06474056815A0C1EFE4540F14A92E7FA06474023BBD23252FF454032E719FB9209474023BBD23252FF454032E719FB9209474056815A0C1EFE4540F14A92E7FA06474056815A0C1EFE4540
53779	Карасу	8	75	1355	45.899141	45.911538	44.087049	44.078786000000001	0103000020E6100000010000000500000012BF620D17F34640FBB0DEA8150A464012BF620D17F346402313F06B240B4640D787F546ADF446402313F06B240B4640D787F546ADF44640FBB0DEA8150A464012BF620D17F34640FBB0DEA8150A4640
14710	Карагас	8	75	1355	45.370581000000001	45.395653000000003	44.262269000000003	44.246257	0103000020E610000001000000050000006EC2BD326FAF46409EB47059851F46406EC2BD326FAF464098E0D407922146403BC8EBC1A4B2464098E0D407922146403BC8EBC1A4B246409EB47059851F46406EC2BD326FAF46409EB47059851F4640
15381	Калининаул	8	75	1355	45.992539000000001	46.004432000000001	44.164250000000003	44.158352000000001	0103000020E61000000100000005000000958098840BFF4640CBA0DAE044144640958098840BFF46401B2FDD240615464027874F3A910047401B2FDD240615464027874F3A91004740CBA0DAE044144640958098840BFF4640CBA0DAE044144640
53975	Иммунный	8	75	1355	45.103907	46.449089999999998	44.993327000000001	43.816614000000001	0103000020E61000000100000005000000A96917D34C8D464056BABBCE86E84540A96917D34C8D4640ED9DD156257F4640F67AF7C77B394740ED9DD156257F4640F67AF7C77B39474056BABBCE86E84540A96917D34C8D464056BABBCE86E84540
53470	Восточно-Сухокумск	8	75	1355	45.942160999999999	45.949733999999999	44.694893	44.686857000000003	0103000020E6100000010000000500000088484DBB98F84640AC0320EEEA57464088484DBB98F84640139CFA40F25846401BF33AE290F94640139CFA40F25846401BF33AE290F94640AC0320EEEA57464088484DBB98F84640AC0320EEEA574640
14751	Боранчи	8	75	1355	45.527337000000003	45.538845000000002	44.222017999999998	44.214452999999999	0103000020E61000000100000005000000427C60C77FC34640B9C32632731B4640427C60C77FC34640C98FF8156B1C46407B4E7ADFF8C44640C98FF8156B1C46407B4E7ADFF8C44640B9C32632731B4640427C60C77FC34640B9C32632731B4640
15090	Батыр-Мурза	8	75	1355	45.691611999999999	45.700119000000001	44.179378999999997	44.173076000000002	0103000020E61000000100000005000000B5C2F4BD86D846407BDCB75A27164640B5C2F4BD86D846406A4B1DE4F51646407427D87F9DD946406A4B1DE4F51646407427D87F9DD946407BDCB75A27164640B5C2F4BD86D846407BDCB75A27164640
53750	Ямансу	8	75	1287	46.387250000000002	46.591095000000003	43.261906000000003	43.082996999999999	0103000020E6100000010000000500000021B072689131474043554CA59F8A454021B07268913147402750C42286A1454021EA3E00A94B47402750C42286A1454021EA3E00A94B474043554CA59F8A454021B072689131474043554CA59F8A4540
14498	Шушия	8	75	1287	46.415770999999999	46.437888000000001	43.144103999999999	43.126815000000001	0103000020E6100000010000000500000007D0EFFB3735474035D252793B90454007D0EFFB37354740849CF7FF71924540CAA7C7B60C384740849CF7FF71924540CAA7C7B60C38474035D252793B90454007D0EFFB3735474035D252793B904540
13562	Чапаево	8	75	1287	46.477224999999997	46.499090000000002	43.116931000000001	43.102713999999999	0103000020E61000000100000005000000B3EA73B5153D4740B16B7BBB258D4540B3EA73B5153D4740BD715298F78E45405DE15D2EE23F4740BD715298F78E45405DE15D2EE23F4740B16B7BBB258D4540B3EA73B5153D4740B16B7BBB258D4540
13959	Тухчар	8	75	1287	46.400922000000001	46.418619	43.231566999999998	43.211391999999996	0103000020E610000001000000050000009B1F7F695133474069519FE40E9B45409B1F7F69513347409AEAC9FCA39D4540FB3DB14E953547409AEAC9FCA39D4540FB3DB14E9535474069519FE40E9B45409B1F7F695133474069519FE40E9B4540
13863	Новочуртах	8	75	1287	46.525185999999998	46.549072000000002	43.220950999999999	43.196843000000001	0103000020E6100000010000000500000095287B4B3943474028B9C3263299454095287B4B394347405E82531F489C45401D93C5FD474647405E82531F489C45401D93C5FD4746474028B9C3263299454095287B4B3943474028B9C32632994540
13768	Новолакское	8	75	1287	46.470101	46.490493000000001	43.129353999999999	43.110995000000003	0103000020E61000000100000005000000906802452C3C474080828B15358E4540906802452C3C4740ABCDFFAB8E9045405EF58079C83E4740ABCDFFAB8E9045405EF58079C83E474080828B15358E4540906802452C3C474080828B15358E4540
53592	Новокули	8	75	1287	46.501803000000002	46.529344999999999	43.175426999999999	43.155022000000002	0103000020E610000001000000050000007104A9143B4047408C14CAC2D79345407104A9143B404740EEEA5564749645408BA6B393C1434740EEEA5564749645408BA6B393C14347408C14CAC2D79345407104A9143B4047408C14CAC2D7934540
53573	Дучи	8	75	1287	46.479182999999999	46.495910000000002	43.173993000000003	43.161394999999999	0103000020E610000001000000050000004BE658DE553D4740745E6397A89445404BE658DE553D4740D15D12674596454033E197FA793F4740D15D12674596454033E197FA793F4740745E6397A89445404BE658DE553D4740745E6397A8944540
13682	Гамиях	8	75	1287	46.479047999999999	46.494678999999998	43.214131999999999	43.201351000000003	0103000020E610000001000000050000006B9BE271513D47402A029CDEC59945406B9BE271513D4740778368AD689B45404D8237A4513F4740778368AD689B45404D8237A4513F47402A029CDEC59945406B9BE271513D47402A029CDEC5994540
53787	Банайюрт	8	75	1287	46.387250000000002	46.591095000000003	43.261906000000003	43.082996999999999	0103000020E6100000010000000500000021B072689131474043554CA59F8A454021B07268913147402750C42286A1454021EA3E00A94B47402750C42286A1454021EA3E00A94B474043554CA59F8A454021B072689131474043554CA59F8A4540
13484	Ахар	8	75	1287	46.442559000000003	46.465420999999999	43.153647999999997	43.142485999999998	0103000020E6100000010000000500000076C6F7C5A5384740A51133FB3C92454076C6F7C5A5384740438CD7BCAA93454091EF52EA923B4740438CD7BCAA93454091EF52EA923B4740A51133FB3C92454076C6F7C5A5384740A51133FB3C924540
53721	Шамхал Термен	8	75	7294	47.300944000000001	47.319161999999999	43.043436999999997	43.024715	0103000020E61000000100000005000000B6F63E5585A647403E5C72DC29834540B6F63E5585A64740DA37F7578F8545401F10E84CDAA84740DA37F7578F8545401F10E84CDAA847403E5C72DC29834540B6F63E5585A647403E5C72DC29834540
53629	Шамхал	8	75	7294	47.321559999999998	47.347099	43.068483000000001	43.048496999999998	0103000020E61000000100000005000000D3D9C9E028A94740207A522635864540D3D9C9E028A947407EAA0A0DC4884540B6BC72BD6DAC47407EAA0A0DC4884540B6BC72BD6DAC4740207A522635864540D3D9C9E028A94740207A522635864540
53691	Сулак	8	75	7294	47.494621000000002	47.531801999999999	43.282910999999999	43.265956000000003	0103000020E610000001000000050000001975ADBD4FBF47406616A1D80AA245401975ADBD4FBF4740DE567A6D36A4454044F9821612C44740DE567A6D36A4454044F9821612C447406616A1D80AA245401975ADBD4FBF47406616A1D80AA24540
53732	Семендер	8	75	7294	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
53726	Ленинкент	8	75	7294	47.342328999999999	47.362721000000001	42.973905000000002	42.960360999999999	0103000020E6100000010000000500000077BCC96FD1AB47404BADF71BED7A454077BCC96FD1AB4740983446EBA87C4540454948A46DAE4740983446EBA87C4540454948A46DAE47404BADF71BED7A454077BCC96FD1AB47404BADF71BED7A4540
53737	Красноармейское	8	75	7294	47.408239000000002	47.419260999999999	43.021768999999999	43.009535	0103000020E61000000100000005000000D3F9F02C41B447406C95607138814540D3F9F02C41B4474087889B53C98245407FBE2D58AAB5474087889B53C98245407FBE2D58AAB547406C95607138814540D3F9F02C41B447406C95607138814540
53719	Альбурикент	8	75	7294	47.486697999999997	47.536400999999998	42.959713999999998	42.900323999999998	0103000020E61000000100000005000000A983BC1E4CBE4740E6E61BD13D734540A983BC1E4CBE4740B5C189E8D77A45405645B8C9A8C44740B5C189E8D77A45405645B8C9A8C44740E6E61BD13D734540A983BC1E4CBE4740E6E61BD13D734540
53720	Альбурикент	8	75	7301	47.486697999999997	47.536400999999998	42.959713999999998	42.900323999999998	0103000020E61000000100000005000000A983BC1E4CBE4740E6E61BD13D734540A983BC1E4CBE4740B5C189E8D77A45405645B8C9A8C44740B5C189E8D77A45405645B8C9A8C44740E6E61BD13D734540A983BC1E4CBE4740E6E61BD13D734540
5926	Яруквалар	8	75	674	48.408054999999997	48.415044000000002	41.801057	41.794227999999997	0103000020E6100000010000000500000011FC6F253B344840A3C85A43A9E5444011FC6F253B344840AE9D280989E6444055336B2920354840AE9D280989E6444055336B2920354840A3C85A43A9E5444011FC6F253B344840A3C85A43A9E54440
5260	Яраг-Казмаляр	8	75	674	48.376837999999999	48.394624999999998	41.654167000000001	41.638697000000001	0103000020E61000000100000005000000EDF1423A3C304840D386C3D2C0D14440EDF1423A3C304840AC8F87BEBBD344408D976E1283324840AC8F87BEBBD344408D976E1283324840D386C3D2C0D14440EDF1423A3C304840D386C3D2C0D14440
6226	Чахчах Казмаляр	8	75	674	48.492711999999997	48.504686	41.792923999999999	41.782381999999998	0103000020E61000000100000005000000622CD32F113F4840527DE71725E44440622CD32F113F4840541B9C887EE54440E15F048D99404840541B9C887EE54440E15F048D99404840527DE71725E44440622CD32F113F4840527DE71725E44440
5386	Целягюн	8	75	674	48.284114000000002	48.298838000000003	41.663511	41.651902999999997	0103000020E61000000100000005000000FA2AF9D85D2448400795B88E71D34440FA2AF9D85D244840A4C4AEEDEDD44440AA66D65240264840A4C4AEEDEDD44440AA66D652402648400795B88E71D34440FA2AF9D85D2448400795B88E71D34440
6372	Хтун Казмаляр	8	75	674	48.515269000000004	48.527773000000003	41.814881999999997	41.803907000000002	0103000020E6100000010000000500000042D2A755F44148404303B16CE6E6444042D2A755F4414840AE0CAA0D4EE844401D5BCF108E434840AE0CAA0D4EE844401D5BCF108E4348404303B16CE6E6444042D2A755F44148404303B16CE6E64440
4843	Хорель	8	75	674	48.193204999999999	48.202914999999997	41.566192999999998	41.535158000000003	0103000020E610000001000000050000003B3602F1BA184840AD18AE0E80C444403B3602F1BA184840B01C210379C84440156F641EF9194840B01C210379C84440156F641EF9194840AD18AE0E80C444403B3602F1BA184840AD18AE0E80C44440
53741	Ходжаказмаляр	8	75	674	48.435085000000001	48.443061999999998	41.732500000000002	41.722816000000002	0103000020E6100000010000000500000076FD82DDB03748404583143C85DC444076FD82DDB0374840F6285C8FC2DD4440D80C7041B6384840F6285C8FC2DD4440D80C7041B63848404583143C85DC444076FD82DDB03748404583143C85DC4440
6050	Филя	8	75	674	47.971508999999998	47.978713999999997	41.488244000000002	41.479719000000003	0103000020E6100000010000000500000084622B685AFC47408A22A46E67BD444084622B685AFC4740EF3B86C77EBE44409411178046FD4740EF3B86C77EBE44409411178046FD47408A22A46E67BD444084622B685AFC47408A22A46E67BD4440
6242	Тагиркент-Казмаляр	8	75	674	48.498900999999996	48.515025999999999	41.820540999999999	41.810561	0103000020E610000001000000050000008978EBFCDB3F4840DF347D76C0E744408978EBFCDB3F48407903CC7C07E944407B4B395FEC4148407903CC7C07E944407B4B395FEC414840DF347D76C0E744408978EBFCDB3F4840DF347D76C0E74440
5171	Тагиркент	8	75	674	48.302143000000001	48.30827	41.610556000000003	41.603915000000001	0103000020E6100000010000000500000090DB2F9FAC2648402C4833164DCD444090DB2F9FAC2648403430F2B226CE4440412B3064752748403430F2B226CE4440412B3064752748402C4833164DCD444090DB2F9FAC2648402C4833164DCD4440
5460	Советское	8	75	674	48.307676999999998	48.334034000000003	41.734901999999998	41.715527000000002	0103000020E610000001000000050000009E5DBEF561274840D733846396DB44409E5DBEF561274840EBE1CB4411DE444044E048A0C12A4840EBE1CB4411DE444044E048A0C12A4840D733846396DB44409E5DBEF561274840D733846396DB4440
6420	Самур	8	75	674	48.474412999999998	48.490906000000003	41.831412	41.819882	0103000020E610000001000000050000000CE6AF90B93C48401F4AB4E4F1E844400CE6AF90B93C484040C05AB56BEA444081B4FF01D63E484040C05AB56BEA444081B4FF01D63E48401F4AB4E4F1E844400CE6AF90B93C48401F4AB4E4F1E84440
6558	Приморский	8	75	674	48.577359999999999	48.588706000000002	41.847534000000003	41.840871	0103000020E610000001000000050000006002B7EEE6494840D19332A9A1EB44406002B7EEE6494840C11F7EFE7BEC4440C07ADCB75A4B4840C11F7EFE7BEC4440C07ADCB75A4B4840D19332A9A1EB44406002B7EEE6494840D19332A9A1EB4440
5909	Оружба	8	75	674	48.428733999999999	48.441758999999998	41.778582999999998	41.769934999999997	0103000020E61000000100000005000000755776C1E0364840DB85E63A8DE24440755776C1E03648405C1C959BA8E3444059DB148F8B3848405C1C959BA8E3444059DB148F8B384840DB85E63A8DE24440755776C1E0364840DB85E63A8DE24440
5688	Новый Аул	8	75	674	48.386783000000001	48.401361999999999	41.736066000000001	41.722532999999999	0103000020E610000001000000050000000BD3F71A82314840F0A31AF67BDC44400BD3F71A8231484049D9226937DE4440B7ED7BD45F33484049D9226937DE4440B7ED7BD45F334840F0A31AF67BDC44400BD3F71A82314840F0A31AF67BDC4440
4741	Мугерган	8	75	674	48.165886999999998	48.187086999999998	41.536090000000002	41.515276999999998	0103000020E6100000010000000500000070EA03C93B154840C4B0C398F4C1444070EA03C93B15484038DBDC989EC44440DD408177F217484038DBDC989EC44440DD408177F2174840C4B0C398F4C1444070EA03C93B154840C4B0C398F4C14440
4647	Мака-Казмаляр	8	75	674	48.014808000000002	48.020215999999998	41.480192000000002	41.471187	0103000020E610000001000000050000000EDC813AE501484072A609DB4FBC44400EDC813AE501484082E673EE76BD44408F6D19709602484082E673EE76BD44408F6D19709602484072A609DB4FBC44400EDC813AE501484072A609DB4FBC4440
5049	Магарамкент	8	75	674	48.334968000000003	48.360992000000003	41.625683000000002	41.605722	0103000020E61000000100000005000000709A3E3BE02A4840DE3B6A4C88CD4440709A3E3BE02A4840E3546B6116D044400F0F61FC342E4840E3546B6116D044400F0F61FC342E4840DE3B6A4C88CD4440709A3E3BE02A4840DE3B6A4C88CD4440
53757	КчунКазмаляр	8	75	674	48.483440999999999	48.494329	41.765529999999998	41.759416000000002	0103000020E61000000100000005000000D4450A65E13D48409207228B34E14440D4450A65E13D4840AE0D15E3FCE14440713B342C463F4840AE0D15E3FCE14440713B342C463F48409207228B34E14440D4450A65E13D48409207228B34E14440
4916	Куйсун	8	75	674	48.278157999999998	48.292675000000003	41.578786999999998	41.566738999999998	0103000020E61000000100000005000000758F6CAE9A234840122F4FE78AC84440758F6CAE9A234840CB2C42B115CA4440ACADD85F76254840CB2C42B115CA4440ACADD85F76254840122F4FE78AC84440758F6CAE9A234840122F4FE78AC84440
4758	Кирка	8	75	674	48.181356000000001	48.193204999999999	41.541294000000001	41.532479000000002	0103000020E61000000100000005000000797764AC361748404567994528C44440797764AC36174840B1C22D1F49C544403B3602F1BA184840B1C22D1F49C544403B3602F1BA1848404567994528C44440797764AC361748404567994528C44440
53840	Киличхай	8	75	674	48.418833999999997	48.426335000000002	41.763942999999998	41.756571000000001	0103000020E61000000100000005000000F7393E5A9C3548400F0D8B51D7E04440F7393E5A9C3548400A815CE2C8E14440F1113125923648400A815CE2C8E14440F1113125923648400F0D8B51D7E04440F7393E5A9C3548400F0D8B51D7E04440
6083	Кабир-Казмаляр	8	75	674	48.479101999999997	48.496997	41.752239000000003	41.738104999999997	0103000020E610000001000000050000005EB9DE36533D4840CD0182397ADE44405EB9DE36533D48404CE3175E49E04440E59A02999D3F48404CE3175E49E04440E59A02999D3F4840CD0182397ADE44405EB9DE36533D4840CD0182397ADE4440
4896	Джепель	8	75	674	48.211117000000002	48.221052	41.554398999999997	41.547111000000001	0103000020E610000001000000050000009850C1E1051B48401424B6BB07C644409850C1E1051B4840B1F7E28BF6C64440925B936E4B1C4840B1F7E28BF6C64440925B936E4B1C48401424B6BB07C644409850C1E1051B48401424B6BB07C64440
4626	Гарах	8	75	674	48.041550999999998	48.053193	41.486176999999998	41.478253000000002	0103000020E61000000100000005000000DC0E0D8B51054840611BF16437BD4440DC0E0D8B51054840A088450C3BBE444025B03907CF064840A088450C3BBE444025B03907CF064840611BF16437BD4440DC0E0D8B51054840611BF16437BD4440
5271	Гапцах	8	75	674	48.369166999999997	48.383305999999997	41.677183999999997	41.658842999999997	0103000020E6100000010000000500000097E13FDD402F48406919A9F754D4444097E13FDD402F4840EEAF1EF7ADD64440272EC72B10314840EEAF1EF7ADD64440272EC72B103148406919A9F754D4444097E13FDD402F48406919A9F754D44440
53689	Бутказмаляр	8	75	674	48.395612999999997	48.405817999999996	41.705531000000001	41.693635	0103000020E61000000100000005000000AC6F6072A3324840342E1C08C9D84440AC6F6072A332484037A8FDD64EDA444066101FD8F133484037A8FDD64EDA444066101FD8F1334840342E1C08C9D84440AC6F6072A3324840342E1C08C9D84440
6536	Бильбиль Казмаляр	8	75	674	48.533307000000001	48.549664999999997	41.822448999999999	41.813806999999997	0103000020E610000001000000050000002BDD5D6743444840C020E9D32AE844402BDD5D67434448405FD0420246E94440BF60376C5B4648405FD0420246E94440BF60376C5B464840C020E9D32AE844402BDD5D6743444840C020E9D32AE84440
53680	Азад-Оглы	8	75	674	48.434958999999999	48.452863000000001	41.832788999999998	41.823934000000001	0103000020E61000000100000005000000E90C8CBCAC374840FF0758AB76E94440E90C8CBCAC374840F9BB77D498EA4440C3482F6AF7394840F9BB77D498EA4440C3482F6AF7394840FF0758AB76E94440E90C8CBCAC374840FF0758AB76E94440
4487	Эбдалая	8	75	341	47.336678999999997	47.348329999999997	42.371611999999999	42.362439000000002	0103000020E61000000100000005000000FF1F274C18AB4740C1E5B166642E4540FF1F274C18AB47408C6665FB902F45409B1BD31396AC47408C6665FB902F45409B1BD31396AC4740C1E5B166642E4540FF1F274C18AB4740C1E5B166642E4540
4473	Чуни	8	75	341	47.298383999999999	47.306379	42.355730000000001	42.345649000000002	0103000020E6100000010000000500000028D3687231A647409372F7393E2C454028D3687231A64740611A868F882D45403197546D37A74740611A868F882D45403197546D37A747409372F7393E2C454028D3687231A647409372F7393E2C4540
2117	Чахимахи	8	75	341	47.546885000000003	47.569719999999997	42.418455000000002	42.411273000000001	0103000020E6100000010000000500000024D6E25300C64740295DFA97A434454024D6E25300C6474081ECF5EE8F35454045F0BF95ECC8474081ECF5EE8F35454045F0BF95ECC84740295DFA97A434454024D6E25300C64740295DFA97A4344540
4200	Цудахар	8	75	341	47.154330000000002	47.164237999999997	42.345689	42.334439000000003	0103000020E610000001000000050000005665DF15C1934740E4C0ABE5CE2A45405665DF15C193474021CB82893F2C4540566133C00595474021CB82893F2C4540566133C005954740E4C0ABE5CE2A45405665DF15C1934740E4C0ABE5CE2A4540
4114	Хахита	8	75	341	47.259881999999998	47.276401999999997	42.470663999999999	42.462749000000002	0103000020E61000000100000005000000D76839D043A14740DCA0F65B3B3B4540D76839D043A14740C8B3CBB73E3C45404546072461A34740C8B3CBB73E3C45404546072461A34740DCA0F65B3B3B4540D76839D043A14740DCA0F65B3B3B4540
53739	Хаджамахи	8	75	341	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
53769	Хаджалмахи	8	75	341	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
53558	Хаджал-Махи	8	75	341	47.175234000000003	47.193964000000001	42.427993000000001	42.409469000000001	0103000020E61000000100000005000000DA9255116E964740E8DCED7A69344540DA9255116E9647405EF58079C8364540F94CF6CFD39847405EF58079C8364540F94CF6CFD3984740E8DCED7A69344540DA9255116E964740E8DCED7A69344540
3763	Урма	8	75	341	47.275700999999998	47.300764000000001	42.542865999999997	42.532787999999996	0103000020E61000000100000005000000BC3C9D2B4AA34740C2D9AD6532444540BC3C9D2B4AA347401F0E12A27C45454036E84B6F7FA647401F0E12A27C45454036E84B6F7FA64740C2D9AD6532444540BC3C9D2B4AA34740C2D9AD6532444540
53703	Уллу-Ая	8	75	341	47.373069999999998	47.382286000000001	42.377054000000001	42.368594999999999	0103000020E61000000100000005000000328FFCC1C0AF47400C3CF71E2E2F4540328FFCC1C0AF4740BA69334E43304540FDDB65BFEEB04740BA69334E43304540FDDB65BFEEB047400C3CF71E2E2F4540328FFCC1C0AF47400C3CF71E2E2F4540
2898	Телагу	8	75	341	47.105246000000001	47.117669999999997	42.425623000000002	42.421950000000002	0103000020E61000000100000005000000750470B3788D47400B46257502364540750470B3788D474074B680D07A36454033DC80CF0F8F474074B680D07A36454033DC80CF0F8F47400B46257502364540750470B3788D47400B46257502364540
4072	Ташкапур	8	75	341	47.169519999999999	47.176554000000003	42.410887000000002	42.402065999999998	0103000020E610000001000000050000004B02D4D4B2954740B16A10E6763345404B02D4D4B295474000ADF9F1973445402FFD4B529996474000ADF9F1973445402FFD4B5299964740B16A10E6763345404B02D4D4B2954740B16A10E676334540
4325	Тарлимахи	8	75	341	47.172187999999998	47.175584000000001	42.357429000000003	42.354723999999997	0103000020E61000000100000005000000BF61A2410A9647409B8D9598672D4540BF61A2410A9647402DD2C43BC02D4540B6D95889799647402DD2C43BC02D4540B6D95889799647409B8D9598672D4540BF61A2410A9647409B8D9598672D4540
4583	Тагиркент	8	75	341	47.358525999999998	47.365560000000002	42.366056999999998	42.362105999999997	0103000020E610000001000000050000000262122EE4AD4740BAD7497D592E45400262122EE4AD474066BCADF4DA2E4540E65C8AABCAAE474066BCADF4DA2E4540E65C8AABCAAE4740BAD7497D592E45400262122EE4AD4740BAD7497D592E4540
2649	Сулейбакент	8	75	341	47.370905	47.377948000000004	42.361933000000001	42.355817000000002	0103000020E610000001000000050000002176A6D079AF4740302E55698B2D45402176A6D079AF4740ED2B0FD2532E454058CB9D9960B04740ED2B0FD2532E454058CB9D9960B04740302E55698B2D45402176A6D079AF4740302E55698B2D4540
3601	Охли	8	75	341	47.198473	47.213070999999999	42.55874	42.552602999999998	0103000020E61000000100000005000000CB11329067994740F355F2B1BB464540CB11329067994740C87BD5CA84474540EE5C18E9459B4740C87BD5CA84474540EE5C18E9459B4740F355F2B1BB464540CB11329067994740F355F2B1BB464540
1656	Орада Чугли	8	75	341	47.218200000000003	47.229644999999998	42.496488999999997	42.489668000000002	0103000020E610000001000000050000005DFE43FAED9B4740E9F2E670AD3E45405DFE43FAED9B474070E998F38C3F45404F58E201659D474070E998F38C3F45404F58E201659D4740E9F2E670AD3E45405DFE43FAED9B4740E9F2E670AD3E4540
3561	Нижние Чугли	8	75	341	47.288826	47.307529000000002	42.468023000000002	42.459031000000003	0103000020E61000000100000005000000041E1840F8A44740D36C1E87C13A4540041E1840F8A447404E637B2DE83B45402AC93A1C5DA747404E637B2DE83B45402AC93A1C5DA74740D36C1E87C13A4540041E1840F8A44740D36C1E87C13A4540
4006	Нижние Убекимахи	8	75	341	47.190190999999999	47.209882	42.398870000000002	42.389913999999997	0103000020E610000001000000050000002C7FBE2D589847405320B3B3E83145402C7FBE2D5898474082AD122C0E3345407102D369DD9A474082AD122C0E3345407102D369DD9A47405320B3B3E83145402C7FBE2D589847405320B3B3E8314540
2229	Нижние Лабкомахи	8	75	341	47.413144000000003	47.425513000000002	42.355356999999998	42.345229000000003	0103000020E61000000100000005000000F24410E7E1B44740BE50C076302C4540F24410E7E1B44740CCB392567C2D4540ED82C13577B64740CCB392567C2D4540ED82C13577B64740BE50C076302C4540F24410E7E1B44740BE50C076302C4540
53912	Нижнее Аршимахи	8	75	341	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
3464	Наскент	8	75	341	47.329591000000001	47.348303000000001	42.387622999999998	42.374142999999997	0103000020E610000001000000050000002907B30930AA47407F83F6EAE32F45402907B30930AA4740B51666A19D314540A20C553195AC4740B51666A19D314540A20C553195AC47407F83F6EAE32F45402907B30930AA47407F83F6EAE32F4540
3276	Мусультемахи	8	75	341	47.191332000000003	47.194251000000001	42.361980000000003	42.358561999999999	0103000020E61000000100000005000000D25625917D9847404FCB0F5CE52D4540D25625917D9847402EE7525C552E45408F1B7E37DD9847402EE7525C552E45408F1B7E37DD9847404FCB0F5CE52D4540D25625917D9847404FCB0F5CE52D4540
3160	Мекеги	8	75	341	47.454115999999999	47.468685999999998	42.403377999999996	42.391499000000003	0103000020E61000000100000005000000904B1C7920BA474057B5A4A31C324540904B1C7920BA474083F6EAE3A1334540E90B21E7FDBB474083F6EAE3A1334540E90B21E7FDBB474057B5A4A31C324540904B1C7920BA474057B5A4A31C324540
3004	Леваши	8	75	341	47.313924999999998	47.337963999999999	42.443956	42.422880999999997	0103000020E61000000100000005000000CA32C4B12EA84740C58CF0F620364540CA32C4B12EA84740766EDA8CD3384540D89C836742AB4740766EDA8CD3384540D89C836742AB4740C58CF0F620364540CA32C4B12EA84740C58CF0F620364540
2928	Кутиша	8	75	341	47.273878000000003	47.287972000000003	42.427680000000002	42.418149	0103000020E61000000100000005000000058C2E6F0EA3474074ED0BE885354540058C2E6F0EA347409F93DE37BE364540F5143944DCA447409F93DE37BE364540F5143944DCA4474074ED0BE885354540058C2E6F0EA3474074ED0BE885354540
2771	Куппа	8	75	341	47.117697	47.131889999999999	42.428424999999997	42.418295999999998	0103000020E610000001000000050000002DEBFEB1108F474018062CB98A3545402DEBFEB1108F4740F7E461A1D6364540B05582C5E1904740F7E461A1D6364540B05582C5E190474018062CB98A3545402DEBFEB1108F474018062CB98A354540
4291	Кулибухна	8	75	341	47.181108999999999	47.187666	42.317148000000003	42.313547	0103000020E61000000100000005000000710168942E9747402461DF4E22284540710168942E974740F4FE3F4E982845401B49827005984740F4FE3F4E982845401B498270059847402461DF4E22284540710168942E9747402461DF4E22284540
2689	Кулецма	8	75	341	47.222566	47.278557999999997	42.561853999999997	42.551938999999997	0103000020E61000000100000005000000CC99ED0A7D9C47408731E9EFA5464540CC99ED0A7D9C47403A90F5D4EA4745400305DEC9A7A347403A90F5D4EA4745400305DEC9A7A347408731E9EFA5464540CC99ED0A7D9C47408731E9EFA5464540
2571	Карлабко	8	75	341	47.390326000000002	47.400765	42.359254999999997	42.350259999999999	0103000020E61000000100000005000000A663CE33F6B14740698CD651D52C4540A663CE33F6B1474055F65D11FC2D4540D3307C444CB3474055F65D11FC2D4540D3307C444CB34740698CD651D52C4540A663CE33F6B14740698CD651D52C4540
4207	Карекадани	8	75	341	47.122449000000003	47.136265000000002	42.358201999999999	42.351719000000003	0103000020E61000000100000005000000C636A968AC8F4740E030D120052D4540C636A968AC8F47404FAE2990D92D4540734BAB21719147404FAE2990D92D4540734BAB2171914740E030D120052D4540C636A968AC8F4740E030D120052D4540
2458	Какамахи	8	75	341	47.303100000000001	47.318156000000002	42.404516000000001	42.390121000000001	0103000020E6100000010000000500000074B515FBCBA64740CD3D247CEF31454074B515FBCBA64740B85A272EC73345405A83F755B9A84740B85A272EC73345405A83F755B9A84740CD3D247CEF31454074B515FBCBA64740CD3D247CEF314540
2796	Иргали	8	75	341	47.134010000000004	47.145688	42.416179	42.409182999999999	0103000020E6100000010000000500000022AB5B3D27914740228AC91B6034454022AB5B3D2791474018247D5A45354540B7B585E7A592474018247D5A45354540B7B585E7A5924740228AC91B6034454022AB5B3D27914740228AC91B60344540
53882	Зуримахи	8	75	341	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
2532	Дитуншимахи	8	75	341	47.287118999999997	47.294646999999998	42.383420999999998	42.378926	0103000020E61000000100000005000000B587BD50C0A4474053CDACA580304540B587BD50C0A44740C0CC77F013314540A86E2EFEB6A54740C0CC77F013314540A86E2EFEB6A5474053CDACA580304540B587BD50C0A4474053CDACA580304540
2433	Джангамахи	8	75	341	47.377803999999998	47.389229999999998	42.447788000000003	42.442745000000002	0103000020E610000001000000050000002426A8E15BB04740D8BB3FDEAB3845402426A8E15BB0474048C5FF1D51394540A04FE449D2B1474048C5FF1D51394540A04FE449D2B14740D8BB3FDEAB3845402426A8E15BB04740D8BB3FDEAB384540
3383	Гургумахи	8	75	341	47.181117999999998	47.190837000000002	42.366630000000001	42.360886999999998	0103000020E61000000100000005000000C45BE7DF2E9747409946938B312E4540C45BE7DF2E974740C2DD59BBED2E4540F2EEC8586D984740C2DD59BBED2E4540F2EEC8586D9847409946938B312E4540C45BE7DF2E9747409946938B312E4540
4394	Верхняя Цухта	8	75	341	47.328252999999997	47.340128999999997	42.346049000000001	42.337772000000001	0103000020E610000001000000050000002DE8BD3104AA474094C0E61C3C2B45402DE8BD3104AA474021E868554B2C4540E9B5D95889AB474021E868554B2C4540E9B5D95889AB474094C0E61C3C2B45402DE8BD3104AA474094C0E61C3C2B4540
2203	Верхние Лабкомахи	8	75	341	47.429403000000001	47.442501	42.344163000000002	42.337685	0103000020E61000000100000005000000F3E670ADF6B64740C5AC1743392B4540F3E670ADF6B6474023BF7E880D2C454041B96DDFA3B8474023BF7E880D2C454041B96DDFA3B84740C5AC1743392B4540F3E670ADF6B64740C5AC1743392B4540
53644	Верхнее-Убекимахи	8	75	341	47.239113000000003	47.248095999999997	42.370733000000001	42.363359000000003	0103000020E61000000100000005000000348639419B9E474088DA368C822E4540348639419B9E47402446CF2D742F45405B22179CC19F47402446CF2D742F45405B22179CC19F474088DA368C822E4540348639419B9E474088DA368C822E4540
53745	Верхнее Аршимахи	8	75	341	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
1837	Буртанимахи	8	75	341	47.148086999999997	47.154634999999999	42.372484999999998	42.368167999999997	0103000020E610000001000000050000003BFBCA83F492474084B70721202F45403BFBCA83F492474012A0A696AD2F454092E86514CB93474012A0A696AD2F454092E86514CB93474084B70721202F45403BFBCA83F492474084B70721202F4540
1993	Аялакаб	8	75	341	47.445366	47.465767	42.426409	42.417589999999997	0103000020E610000001000000050000000B60CAC001B947407D91D096733545400B60CAC001B947402BDCF291943645402C47C8409EBB47402BDCF291943645402C47C8409EBB47407D91D096733545400B60CAC001B947407D91D09673354540
1969	Ахкент	8	75	341	47.178665000000002	47.188654999999997	42.576489000000002	42.569650000000003	0103000020E610000001000000050000004DF8A57EDE9647404D158C4AEA4845404DF8A57EDE9647407BC03C64CA4945400A9DD7D8259847407BC03C64CA4945400A9DD7D8259847404D158C4AEA4845404DF8A57EDE9647404D158C4AEA484540
53744	Аллатемахи	8	75	341	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
53514	Айнакаб	8	75	341	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
1119	Шовкра	8	75	9	47.121766000000001	47.128763999999997	42.141314999999999	42.136975999999997	0103000020E61000000100000005000000E3E13D07968F47401F2BF86D88114540E3E13D07968F474095B7239C161245407973B8567B90474095B7239C161245407973B8567B9047401F2BF86D88114540E3E13D07968F47401F2BF86D88114540
647	Шахува	8	75	9	47.158408000000001	47.164228999999999	42.251918000000003	42.249769000000001	0103000020E610000001000000050000005FB69DB646944740FE463B6EF81F45405FB69DB6469447400AA359D93E2045400307B474059547400AA359D93E2045400307B47405954740FE463B6EF81F45405FB69DB646944740FE463B6EF81F4540
1206	Шара	8	75	9	47.132285000000003	47.138815999999998	42.117221999999998	42.112447000000003	0103000020E610000001000000050000002D6002B7EE90474044C4CDA9640E45402D6002B7EE904740942F6821010F4540AD1402B9C4914740942F6821010F4540AD1402B9C491474044C4CDA9640E45402D6002B7EE90474044C4CDA9640E4540
31776	Чуртах	8	75	9	47.082743000000001	47.090010999999997	42.115074999999997	42.108874999999998	0103000020E61000000100000005000000897C9752978A47400E2DB29DEF0D4540897C9752978A474029CB10C7BA0E4540DFA3FE7A858B474029CB10C7BA0E4540DFA3FE7A858B47400E2DB29DEF0D4540897C9752978A47400E2DB29DEF0D4540
367	Чукна	8	75	9	47.116205000000001	47.12518	42.302731999999999	42.298243999999997	0103000020E61000000100000005000000DB5031CEDF8E4740361D01DC2C264540DB5031CEDF8E4740F1B913ECBF264540800EF3E505904740F1B913ECBF264540800EF3E505904740361D01DC2C264540DB5031CEDF8E4740361D01DC2C264540
1648	Хурхи	8	75	9	47.122449000000003	47.129429000000002	42.108908	42.102781	0103000020E61000000100000005000000C636A968AC8F474039D384ED270D4540C636A968AC8F4740EA2285B2F00D4540B613252191904740EA2285B2F00D4540B61325219190474039D384ED270D4540C636A968AC8F474039D384ED270D4540
1312	Хурукра	8	75	9	47.130372000000001	47.137864	42.158261000000003	42.153748999999998	0103000020E6100000010000000500000035289A07B09047407765170CAE13454035289A07B0904740BB9D7DE541144540DBA50D87A5914740BB9D7DE541144540DBA50D87A59147407765170CAE13454035289A07B09047407765170CAE134540
1275	Хури	8	75	9	47.122062	47.143594999999998	42.175682999999999	42.165599	0103000020E61000000100000005000000CC0A45BA9F8F47400AA0185932154540CC0A45BA9F8F474049BBD1C77C1645403F6F2A526192474049BBD1C77C1645403F6F2A52619247400AA0185932154540CC0A45BA9F8F47400AA0185932154540
1501	Хуна	8	75	9	47.158057999999997	47.163645000000002	42.181215999999999	42.175615999999998	0103000020E61000000100000005000000826F9A3E3B944740C153C8957A164540826F9A3E3B94474087C1FC1532174540B493C151F294474087C1FC1532174540B493C151F2944740C153C8957A164540826F9A3E3B944740C153C8957A164540
32208	Хулисма	8	75	9	47.054355999999999	47.060392999999998	42.095166999999996	42.091340000000002	0103000020E61000000100000005000000B22B2D23F586474088687407B10B4540B22B2D23F58647404754A86E2E0C454023F433F5BA8747404754A86E2E0C454023F433F5BA87474088687407B10B4540B22B2D23F586474088687407B10B4540
53860	Харазма	8	75	9	46.925995999999998	47.274794	42.344996000000002	41.900292999999998	0103000020E61000000100000005000000081D740987764740ABE80FCD3CF34440081D7409877647401BA034D4282C45408A9125732CA347401BA034D4282C45408A9125732CA34740ABE80FCD3CF34440081D740987764740ABE80FCD3CF34440
908	Ури	8	75	9	47.011811999999999	47.017983999999998	42.206966999999999	42.203947999999997	0103000020E61000000100000005000000A5D93C0E83814740D40AD3F71A1A4540A5D93C0E83814740F52C08E57D1A4540F6ECB94C4D824740F52C08E57D1A4540F6ECB94C4D824740D40AD3F71A1A4540A5D93C0E83814740D40AD3F71A1A4540
666	Унчукатль	8	75	9	47.147916000000002	47.155659	42.223815000000002	42.217517999999998	0103000020E610000001000000050000000F4757E9EE9247404A253CA1D71B45400F4757E9EE92474058AD4CF8A51C4540FE2955A2EC93474058AD4CF8A51C4540FE2955A2EC9347404A253CA1D71B45400F4757E9EE9247404A253CA1D71B4540
1542	Курла	8	75	9	47.184584999999998	47.190649000000001	42.199981000000001	42.195304999999998	0103000020E61000000100000005000000842A357BA097474065DF15C1FF184540842A357BA0974740236937FA98194540EF01BA2F67984740236937FA98194540EF01BA2F6798474065DF15C1FF184540842A357BA097474065DF15C1FF184540
380	Куркли	8	75	9	47.125036000000001	47.130614000000001	42.284405	42.280436000000002	0103000020E610000001000000050000004D69FD2D019047407F4FAC53E52345404D69FD2D01904740D1E80E62672445402B33A5F5B7904740D1E80E62672445402B33A5F5B79047407F4FAC53E52345404D69FD2D019047407F4FAC53E5234540
472	Кунды	8	75	9	47.157814999999999	47.169727000000002	42.274245000000001	42.265438000000003	0103000020E61000000100000005000000BCE82B4833944740CE8E54DFF9214540BCE82B4833944740B70BCD751A234540C51F459DB9954740B70BCD751A234540C51F459DB9954740CE8E54DFF9214540BCE82B4833944740CE8E54DFF9214540
11	Кумух	8	75	9	47.112864000000002	47.121792999999997	42.174581000000003	42.163949000000002	0103000020E61000000100000005000000A872DA53728E4740209BE447FC144540A872DA53728E474062C092AB58164540DCF0BBE9968F474062C092AB58164540DCF0BBE9968F4740209BE447FC144540A872DA53728E4740209BE447FC144540
207	Кума	8	75	9	47.133578999999997	47.139885	42.274712000000001	42.270207999999997	0103000020E610000001000000050000005837DE1D199147400C8FFD2C962245405837DE1D19914740CDE847C329234540B9196EC0E7914740CDE847C329234540B9196EC0E79147400C8FFD2C962245405837DE1D199147400C8FFD2C96224540
32374	Кулушац	8	75	9	47.095463000000002	47.099083999999998	42.130952000000001	42.127527999999998	0103000020E61000000100000005000000317DAF21388C474082A966D652104540317DAF21388C474043ACFE08C310454047C7D5C8AE8C474043ACFE08C310454047C7D5C8AE8C474082A966D652104540317DAF21388C474082A966D652104540
1339	Кукни	8	75	9	47.158569999999997	47.162683999999999	42.129353000000002	42.125929999999997	0103000020E61000000100000005000000381092054C944740EACA67791E104540381092054C944740DB519CA38E1045408ECA4DD4D2944740DB519CA38E1045408ECA4DD4D2944740EACA67791E104540381092054C944740EACA67791E104540
32478	Кубра	8	75	9	47.079158999999997	47.084243000000001	42.145473000000003	42.142592	0103000020E610000001000000050000008F17D2E1218A4740EB556474401245408F17D2E1218A4740BBB9F8DB9E1245405EF58079C88A4740BBB9F8DB9E1245405EF58079C88A4740EB556474401245408F17D2E1218A4740EB55647440124540
32291	Куба	8	75	9	47.113888000000003	47.124084000000003	42.326481000000001	42.320908000000003	0103000020E6100000010000000500000014B4C9E1938E47402C836A831329454014B4C9E1938E4740F8E12021CA2945407BFA08FCE18F4740F8E12021CA2945407BFA08FCE18F47402C836A831329454014B4C9E1938E47402C836A8313294540
757	Караша	8	75	9	47.174290999999997	47.18083	42.224795999999998	42.218133000000002	0103000020E610000001000000050000005A7EE02A4F964740D5963AC8EB1B45405A7EE02A4F964740C422861DC61C45405E11FC6F25974740C422861DC61C45405E11FC6F25974740D5963AC8EB1B45405A7EE02A4F964740D5963AC8EB1B4540
32266	Кара	8	75	9	47.166457000000001	47.176644000000003	42.290467999999997	42.281483000000001	0103000020E610000001000000050000005B9885764E954740A3B08BA2072445405B9885764E9547406B44300E2E2545406F8445459C9647406B44300E2E2545406F8445459C964740A3B08BA2072445405B9885764E954740A3B08BA207244540
1001	Камахал	8	75	9	46.994241000000002	47.002560000000003	42.230083999999998	42.225244000000004	0103000020E61000000100000005000000D2AB014A437F474064CF9ECBD41C4540D2AB014A437F47409BAA7B64731D45408E23D6E2538047409BAA7B64731D45408E23D6E25380474064CF9ECBD41C4540D2AB014A437F474064CF9ECBD41C4540
1623	Иниша	8	75	9	47.201985999999998	47.207061000000003	42.151797000000002	42.148187999999998	0103000020E61000000100000005000000FB1F60ADDA9947406FD40AD3F7124540FB1F60ADDA994740C25087156E13454077A38FF9809A4740C25087156E13454077A38FF9809A47406FD40AD3F7124540FB1F60ADDA9947406FD40AD3F7124540
32125	Бурши	8	75	9	47.061031	47.065648000000003	42.035614000000002	42.029131	0103000020E61000000100000005000000668522DDCF8747405F268A90BA034540668522DDCF874740CFA3E2FF8E0445401F86562767884740CFA3E2FF8E0445401F865627678847405F268A90BA034540668522DDCF8747405F268A90BA034540
53872	Балисма	8	75	9	46.925995999999998	47.274794	42.344996000000002	41.900292999999998	0103000020E61000000100000005000000081D740987764740ABE80FCD3CF34440081D7409877647401BA034D4282C45408A9125732CA347401BA034D4282C45408A9125732CA34740ABE80FCD3CF34440081D740987764740ABE80FCD3CF34440
244	Багикла	8	75	9	47.130775999999997	47.135860999999998	42.255808999999999	42.251117000000001	0103000020E61000000100000005000000048D9944BD9047401D3C139A24204540048D9944BD904740E0826C59BE204540A3E6ABE463914740E0826C59BE204540A3E6ABE4639147401D3C139A24204540048D9944BD9047401D3C139A24204540
53857	Арусси	8	75	9	46.925995999999998	47.274794	42.344996000000002	41.900292999999998	0103000020E61000000100000005000000081D740987764740ABE80FCD3CF34440081D7409877647401BA034D4282C45408A9125732CA347401BA034D4282C45408A9125732CA34740ABE80FCD3CF34440081D740987764740ABE80FCD3CF34440
32033	Штул	8	75	1648	47.913586000000002	47.932324999999999	41.565443999999999	41.551268	0103000020E61000000100000005000000AF0AD462F0F4474069AA27F38FC64440AF0AD462F0F4474016DC0F7860C84440211FF46C56F7474016DC0F7860C84440211FF46C56F7474069AA27F38FC64440AF0AD462F0F4474069AA27F38FC64440
31996	Шимихюр	8	75	1648	47.695914999999999	47.704323000000002	41.657710999999999	41.649788000000001	0103000020E61000000100000005000000DEE522BE13D94740A8AAD0402CD34440DEE522BE13D94740179CC1DF2FD444400A698D4127DA4740179CC1DF2FD444400A698D4127DA4740A8AAD0402CD34440DEE522BE13D94740A8AAD0402CD34440
31943	Хюрехюр	8	75	1648	47.738864	47.745691000000001	41.561881999999997	41.557198999999997	0103000020E610000001000000050000008B18761893DE4740942EFD4B52C744408B18761893DE4740041BD7BFEBC74440F5F57CCD72DF4740041BD7BFEBC74440F5F57CCD72DF4740942EFD4B52C744408B18761893DE4740942EFD4B52C74440
20890	Хпюк	8	75	1648	47.669333999999999	47.675334999999997	41.674315	41.670704999999998	0103000020E61000000100000005000000E90C8CBCACD54740C02154A9D9D54440E90C8CBCACD54740E31934F44FD644400D6C956071D64740E31934F44FD644400D6C956071D64740C02154A9D9D54440E90C8CBCACD54740C02154A9D9D54440
31862	Хпедж	8	75	1648	47.724103999999997	47.739168999999997	41.624893999999998	41.607239	0103000020E610000001000000050000008E739B70AFDC474089EDEE01BACD44408E739B70AFDC4740BABBCE86FCCF4440C79BFC169DDE4740BABBCE86FCCF4440C79BFC169DDE474089EDEE01BACD44408E739B70AFDC474089EDEE01BACD4440
31810	Хвередж	8	75	1648	47.570087999999998	47.575288999999998	41.703586000000001	41.697823	0103000020E61000000100000005000000C8EBC1A4F8C84740C4B2994352D94440C8EBC1A4F8C8474034F6251B0FDA4440D05FE811A3C9474034F6251B0FDA4440D05FE811A3C94740C4B2994352D94440C8EBC1A4F8C84740C4B2994352D94440
31731	Усуг	8	75	1648	47.589168000000001	47.597324999999998	41.675311999999998	41.669370999999998	0103000020E61000000100000005000000C4EC65DB69CB474006F2ECF2ADD54440C4EC65DB69CB4740554CA59F70D64440A60A462575CC4740554CA59F70D64440A60A462575CC474006F2ECF2ADD54440C4EC65DB69CB474006F2ECF2ADD54440
31683	Урсун	8	75	1648	47.687542999999998	47.691620999999998	41.662756000000002	41.659523	0103000020E61000000100000005000000FFCBB56801D84740DBFAE93F6BD44440FFCBB56801D84740289D4830D5D44440081D740987D84740289D4830D5D44440081D740987D84740DBFAE93F6BD44440FFCBB56801D84740DBFAE93F6BD44440
53858	УКУЗ	8	75	1648	47.466997999999997	48.111494	41.746696	41.482596999999998	0103000020E6100000010000000500000011A62897C6BB4740E8120EBDC5BD444011A62897C6BB4740EA060ABC93DF4440A1D9756F450E4840EA060ABC93DF4440A1D9756F450E4840E8120EBDC5BD444011A62897C6BB4740E8120EBDC5BD4440
31602	Сараг	8	75	1648	48.013775000000003	48.017907000000001	41.603833999999999	41.59966	0103000020E610000001000000050000004F401361C3014840145CACA8C1CC44404F401361C30148403F1BB96E4ACD44404BAFCDC64A0248403F1BB96E4ACD44404BAFCDC64A024840145CACA8C1CC44404F401361C3014840145CACA8C1CC4440
31548	Ругун	8	75	1648	47.990544999999997	47.998477000000001	41.600078000000003	41.593435999999997	0103000020E61000000100000005000000B01BB62DCAFE47407022FAB5F5CB4440B01BB62DCAFE474049861C5BCFCC444073672618CEFF474049861C5BCFCC444073672618CEFF47407022FAB5F5CB4440B01BB62DCAFE47407022FAB5F5CB4440
53746	Моллакент	8	75	1648	47.466997999999997	48.111494	41.746696	41.482596999999998	0103000020E6100000010000000500000011A62897C6BB4740E8120EBDC5BD444011A62897C6BB4740EA060ABC93DF4440A1D9756F450E4840EA060ABC93DF4440A1D9756F450E4840E8120EBDC5BD444011A62897C6BB4740E8120EBDC5BD4440
31448	Кутул	8	75	1648	47.962383000000003	47.975102999999997	41.550882999999999	41.544255999999997	0103000020E61000000100000005000000FA9CBB5D2FFB47406D533C2EAAC54440FA9CBB5D2FFB474010768A5583C64440A19DD32CD0FC474010768A5583C64440A19DD32CD0FC47406D533C2EAAC54440FA9CBB5D2FFB47406D533C2EAAC54440
31286	Курах	8	75	1648	47.770977999999999	47.798493999999998	41.592917	41.577047	0103000020E61000000100000005000000BEF73768AFE24740A1A014ADDCC94440BEF73768AFE24740081F4AB4E4CB4440AF06280D35E64740081F4AB4E4CB4440AF06280D35E64740A1A014ADDCC94440BEF73768AFE24740A1A014ADDCC94440
53436	Кумук	8	75	1648	47.466997999999997	48.111494	41.746696	41.482596999999998	0103000020E6100000010000000500000011A62897C6BB4740E8120EBDC5BD444011A62897C6BB4740EA060ABC93DF4440A1D9756F450E4840EA060ABC93DF4440A1D9756F450E4840E8120EBDC5BD444011A62897C6BB4740E8120EBDC5BD4440
31200	Кукваз	8	75	1648	47.688513	47.71125	41.602809000000001	41.584837	0103000020E6100000010000000500000078EFA83121D84740D13E56F0DBCA444078EFA83121D84740035E66D828CD4440D7A3703D0ADB4740035E66D828CD4440D7A3703D0ADB4740D13E56F0DBCA444078EFA83121D84740D13E56F0DBCA4440
53759	Кочхюр	8	75	1648	47.861680999999997	47.869101000000001	41.525708000000002	41.520144999999999	0103000020E61000000100000005000000D34A21904BEE4740C616821C94C24440D34A21904BEE47406F9F55664AC34440E0F599B33EEF47406F9F55664AC34440E0F599B33EEF4740C616821C94C24440D34A21904BEE4740C616821C94C24440
31144	Квардал	8	75	1648	47.558931000000001	47.567329999999998	41.681635	41.678395999999999	0103000020E610000001000000050000003CDC0E0D8BC747405DDE1CAED5D644403CDC0E0D8BC747408C67D0D03FD744401405FA449EC847408C67D0D03FD744401405FA449EC847405DDE1CAED5D644403CDC0E0D8BC747405DDE1CAED5D64440
31039	Кабир	8	75	1648	48.037230000000001	48.051045999999999	41.567413999999999	41.550209000000002	0103000020E610000001000000050000000D37E0F3C3044840817B9E3F6DC644400D37E0F3C304484072A59E05A1C84440BA4BE2AC8806484072A59E05A1C84440BA4BE2AC88064840817B9E3F6DC644400D37E0F3C3044840817B9E3F6DC64440
31076	Икра	8	75	1648	48.000838999999999	48.026082000000002	41.567812000000004	41.555073999999998	0103000020E61000000100000005000000DAC70A7E1B004840116E32AA0CC74440DAC70A7E1B00484060234910AEC84440D481ACA75603484060234910AEC84440D481ACA756034840116E32AA0CC74440DAC70A7E1B004840116E32AA0CC74440
53808	Гельхен	8	75	1648	47.595385	47.608330000000002	41.663969000000002	41.654961999999998	0103000020E61000000100000005000000B5C35F9335CC4740B60F79CBD5D34440B5C35F9335CC47406747AAEFFCD444407D96E7C1DDCD47406747AAEFFCD444407D96E7C1DDCD4740B60F79CBD5D34440B5C35F9335CC4740B60F79CBD5D34440
30850	Бахцуг	8	75	1648	47.948476999999997	47.953884000000002	41.511051000000002	41.507958000000002	0103000020E610000001000000050000000C01C0B167F94740ECDE8AC404C144400C01C0B167F9474047CB811E6AC14440BE16F4DE18FA474047CB811E6AC14440BE16F4DE18FA4740ECDE8AC404C144400C01C0B167F94740ECDE8AC404C14440
30802	Ашар	8	75	1648	47.661321000000001	47.670124999999999	41.619259	41.613137999999999	0103000020E610000001000000050000003A94A12AA6D44740A9F7544E7BCE44403A94A12AA6D44740786000E143CF4440B29DEFA7C6D54740786000E143CF4440B29DEFA7C6D54740A9F7544E7BCE44403A94A12AA6D44740A9F7544E7BCE4440
30741	Ашакент	8	75	1648	47.869515	47.876468000000003	41.596781	41.593361999999999	0103000020E61000000100000005000000D3307C444CEF474036583849F3CB4440D3307C444CEF4740E5EFDE5163CC4440CAFE791A30F04740E5EFDE5163CC4440CAFE791A30F0474036583849F3CB4440D3307C444CEF474036583849F3CB4440
53809	Ахнит	8	75	1648	47.990966999999998	47.998387000000001	41.528306999999998	41.520381999999998	0103000020E610000001000000050000002635B401D8FE4740AAB69BE09BC244402635B401D8FE4740BA9F53909FC3444033E02C25CBFF4740BA9F53909FC3444033E02C25CBFF4740AAB69BE09BC244402635B401D8FE4740AAB69BE09BC24440
53895	с. Ново-Шангода	8	75	650	46.936596000000002	47.508868	43.368797000000001	42.8994	0103000020E610000001000000050000003FC8B260E2774740DE02098A1F7345403FC8B260E277474074EE76BD34AF45408FFD2C9622C1474074EE76BD34AF45408FFD2C9622C14740DE02098A1F7345403FC8B260E2774740DE02098A1F734540
30535	Шамхал-Янги-Юрт	8	75	650	47.209487000000003	47.235466000000002	43.304203000000001	43.2911	0103000020E61000000100000005000000F5F75278D09A4740CCEEC9C342A54540F5F75278D09A47402C2CB81FF0A64540F4A8F8BF239E47402C2CB81FF0A64540F4A8F8BF239E4740CCEEC9C342A54540F5F75278D09A4740CCEEC9C342A54540
30332	Учкент	8	75	650	47.068657999999999	47.092489999999998	43.121662000000001	43.106776000000004	0103000020E61000000100000005000000EC4D0CC9C9884740B5FF01D6AA8D4540EC4D0CC9C98847403E95D39E928F4540809A5AB6D68B47403E95D39E928F4540809A5AB6D68B4740B5FF01D6AA8D4540EC4D0CC9C9884740B5FF01D6AA8D4540
8355	Уллубиевка	8	75	650	47.137028000000001	47.151788000000003	43.147261	43.138821999999998	0103000020E6100000010000000500000072512D228A9147408FFB56EBC491454072512D228A914740F67CCD72D99245406FF607CA6D934740F67CCD72D99245406FF607CA6D9347408FFB56EBC491454072512D228A9147408FFB56EBC4914540
30280	Тюбе	8	75	650	47.273716	47.309316000000003	43.057251999999998	43.045195999999997	0103000020E610000001000000050000002B323A2009A347407BF486FBC88545402B323A2009A34740B7D09508548745409510ACAA97A74740B7D09508548745409510ACAA97A747407BF486FBC88545402B323A2009A347407BF486FBC8854540
30419	Темиргое	8	75	650	47.132455999999998	47.150638000000001	43.132663999999998	43.122405999999998	0103000020E6100000010000000500000059147651F4904740C66AF3FFAA8F454059147651F4904740A3AD4A22FB90454076C4211B48934740A3AD4A22FB90454076C4211B48934740C66AF3FFAA8F454059147651F4904740C66AF3FFAA8F4540
53524	Сафар-Али	8	75	650	47.215271999999999	47.222889000000002	43.124597000000001	43.119734000000001	0103000020E610000001000000050000004CDF6B088E9B4740111C9771538F45404CDF6B088E9B4740011764CBF28F4540AFD172A0879C4740011764CBF28F4540AFD172A0879C4740111C9771538F45404CDF6B088E9B4740111C9771538F4540
4334	Самилах	8	75	650	47.050286999999997	47.066096999999999	43.325679000000001	43.312390000000001	0103000020E61000000100000005000000FC34EECD6F86474079CC4065FCA74540FC34EECD6F8647403BFF76D9AFA945408EAED2DD758847403BFF76D9AFA945408EAED2DD7588474079CC4065FCA74540FC34EECD6F86474079CC4065FCA74540
53562	Новая Урада	8	75	650	47.124882999999997	47.136902999999997	43.079203999999997	43.073146000000001	0103000020E61000000100000005000000C669882AFC8F4740A7EA1ED95C894540C669882AFC8F47402FDB4E5B238A4540B5DC9909869147402FDB4E5B238A4540B5DC990986914740A7EA1ED95C894540C669882AFC8F4740A7EA1ED95C894540
53527	Красное Село	8	75	650	47.092785999999997	47.101635000000002	43.265529999999998	43.259582000000002	0103000020E6100000010000000500000069C36169E08B4740AD50A4FB39A1454069C36169E08B4740AE0D15E3FCA1454082902C60028D4740AE0D15E3FCA1454082902C60028D4740AD50A4FB39A1454069C36169E08B4740AD50A4FB39A14540
53428	Коркмаскала	8	75	650	47.277974	47.300305999999999	43.033856	43.018037999999997	0103000020E61000000100000005000000B491EBA694A34740E90AB6114F824540B491EBA694A34740FE62B664558445407365506D70A64740FE62B664558445407365506D70A64740E90AB6114F824540B491EBA694A34740E90AB6114F824540
5296	Квами	8	75	650	47.013016	47.022385	43.295307000000001	43.291139999999999	0103000020E6100000010000000500000091291F82AA8147405A47551344A5454091291F82AA814740D3A3A99ECCA54540E275FD82DD824740D3A3A99ECCA54540E275FD82DD8247405A47551344A5454091291F82AA8147405A47551344A54540
30392	Алмало	8	75	650	47.208973999999998	47.230606000000002	43.103537000000003	43.095111000000003	0103000020E610000001000000050000006EDBF7A8BF9A4740B43EE5982C8C45406EDBF7A8BF9A474086764EB3408D45407521567F849D474086764EB3408D45407521567F849D4740B43EE5982C8C45406EDBF7A8BF9A4740B43EE5982C8C4540
4839	Аджидада	8	75	650	47.065289	47.087485999999998	43.290863999999999	43.279688	0103000020E61000000100000005000000EFE4D3635B884740B58AFED0CCA34540EFE4D3635B884740B8CA13083BA54540CE6DC2BD328B4740B8CA13083BA54540CE6DC2BD328B4740B58AFED0CCA34540EFE4D3635B884740B58AFED0CCA34540
53517	Цыйша	8	75	1867	47.058793999999999	47.4054	42.166694999999997	41.804996000000003	0103000020E61000000100000005000000BB99D18F8687474096B4E21B0AE74440BB99D18F868747400FB402435615454032E6AE25E4B347400FB402435615454032E6AE25E4B3474096B4E21B0AE74440BB99D18F8687474096B4E21B0AE74440
53855	Цущар	8	75	1867	47.136364	47.143856	42.080882000000003	42.075648000000001	0103000020E61000000100000005000000062D24607491474000016BD5AE094540062D246074914740E46A64575A0A4540ACAA97DF69924740E46A64575A0A4540ACAA97DF6992474000016BD5AE094540062D24607491474000016BD5AE094540
29993	Цовкра 2-я	8	75	1867	47.148418999999997	47.154195000000001	42.042932999999998	42.037166999999997	0103000020E61000000100000005000000718DCF64FF924740C6BE64E3C1044540718DCF64FF924740A7751BD47E054540761A69A9BC934740A7751BD47E054540761A69A9BC934740C6BE64E3C1044540718DCF64FF924740C6BE64E3C1044540
29539	Цовкра 1-я	8	75	1867	47.265918999999997	47.274380999999998	42.062302000000003	42.055821999999999	0103000020E61000000100000005000000483140A209A24740DB32E02C25074540483140A209A24740DA3C0E83F907454067D2A6EA1EA34740DA3C0E83F907454067D2A6EA1EA34740DB32E02C25074540483140A209A24740DB32E02C25074540
29389	Хосрех	8	75	1867	47.268380000000001	47.280938999999996	41.997169	41.987457999999997	0103000020E6100000010000000500000043739D465AA247403716140665FE444043739D465AA24740E2CAD93BA3FF4440E19524CFF5A34740E2CAD93BA3FF4440E19524CFF5A347403716140665FE444043739D465AA247403716140665FE4440
29913	Хойхи	8	75	1867	47.182051999999999	47.187396999999997	42.12294	42.117542999999998	0103000020E61000000100000005000000F015DD7A4D974740D66F26A60B0F4540F015DD7A4D97474064AF777FBC0F45402B2FF99FFC97474064AF777FBC0F45402B2FF99FFC974740D66F26A60B0F4540F015DD7A4D974740D66F26A60B0F4540
53501	Хойми	8	75	1867	47.205157	47.207807000000003	42.094738999999997	42.092578000000003	0103000020E61000000100000005000000D2C5A695429A4740202A8D98D90B4540D2C5A695429A4740EF535568200C4540A070766B999A4740EF535568200C4540A070766B999A4740202A8D98D90B4540D2C5A695429A4740202A8D98D90B4540
53807	Сумбаталь	8	75	1867	47.214058999999999	47.224938000000002	42.050144000000003	42.043475000000001	0103000020E610000001000000050000000D350A49669B4740C898BB96900545400D350A49669B47409A0B5C1E6B06454057D0B4C4CA9C47409A0B5C1E6B06454057D0B4C4CA9C4740C898BB96900545400D350A49669B4740C898BB9690054540
29808	Сукиях	8	75	1867	47.234271	47.239122000000002	42.12397	42.119107999999997	0103000020E610000001000000050000005BB39597FC9D4740925852EE3E0F45405BB39597FC9D4740B2D7BB3FDE0F454087E0B88C9B9E4740B2D7BB3FDE0F454087E0B88C9B9E4740925852EE3E0F45405BB39597FC9D4740925852EE3E0F4540
29437	Кули	8	75	1867	47.233732000000003	47.256909	42.021743000000001	42.012591999999998	0103000020E61000000100000005000000AC0320EEEA9D47407A185A9D9C014540AC0320EEEA9D47405EF58079C80245402786E464E2A047405EF58079C80245402786E464E2A047407A185A9D9C014540AC0320EEEA9D47407A185A9D9C014540
53894	Кая	8	75	1867	47.198222000000001	47.206916999999997	42.079248999999997	42.073492999999999	0103000020E6100000010000000500000082ACA7565F99474012BEF7376809454082ACA7565F994740CF9ECBD4240A454043FE99417C9A4740CF9ECBD4240A454043FE99417C9A474012BEF7376809454082ACA7565F99474012BEF73768094540
29848	Кани	8	75	1867	47.185842999999998	47.192374000000001	42.141849999999998	42.137357000000002	0103000020E61000000100000005000000639813B4C9974740377007EA94114540639813B4C997474003780B2428124540E44C13B69F98474003780B2428124540E44C13B69F984740377007EA94114540639813B4C9974740377007EA94114540
53583	Вихли	8	75	1867	47.215397000000003	47.223607999999999	42.131306000000002	42.123930000000001	0103000020E610000001000000050000000954FF20929B4740247F30F0DC0F45400954FF20929B474061E28FA2CE104540DE8FDB2F9F9C474061E28FA2CE104540DE8FDB2F9F9C4740247F30F0DC0F45400954FF20929B4740247F30F0DC0F4540
29573	Вачи	8	75	1867	47.206702	47.218299000000002	42.075688	42.068848000000003	0103000020E6100000010000000500000047020D36759A47409032E202D008454047020D36759A47408E59F624B0094540F0DFBC38F19B47408E59F624B0094540F0DFBC38F19B47409032E202D008454047020D36759A47409032E202D0084540
53738	Ленинкент	8	75	7297	47.342328999999999	47.362721000000001	42.973905000000002	42.960360999999999	0103000020E6100000010000000500000077BCC96FD1AB47404BADF71BED7A454077BCC96FD1AB4740983446EBA87C4540454948A46DAE4740983446EBA87C4540454948A46DAE47404BADF71BED7A454077BCC96FD1AB47404BADF71BED7A4540
53682	Богатыревка	8	75	7297	47.357250000000001	47.385026000000003	43.128794999999997	43.106136999999997	0103000020E610000001000000050000007D3F355EBAAD4740A1F2AFE5958D45407D3F355EBAAD4740B471C45A7C9045400B0E2F8848B14740B471C45A7C9045400B0E2F8848B14740A1F2AFE5958D45407D3F355EBAAD4740A1F2AFE5958D4540
53890	кутан Арбакол	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
28495	имени Кирова	8	75	677	46.702046000000003	46.710265999999997	43.865924999999997	43.859276000000001	0103000020E61000000100000005000000D124B1A4DC5947406D1E87C1FCED4540D124B1A4DC594740F7E461A1D6EE4540F9BA0CFFE95A4740F7E461A1D6EE4540F9BA0CFFE95A47406D1E87C1FCED4540D124B1A4DC5947406D1E87C1FCED4540
27252	имени Жданова	8	75	677	46.683855000000001	46.693072000000001	43.854745000000001	43.842978000000002	0103000020E61000000100000005000000611A868F88574740AE9FFEB3E6EB4540611A868F88574740B3B5BE4868ED4540FCE25295B6584740B3B5BE4868ED4540FCE25295B6584740AE9FFEB3E6EB4540611A868F88574740AE9FFEB3E6EB4540
28522	Ясная Поляна	8	75	677	46.762422000000001	46.776876000000001	43.957155	43.945681	0103000020E610000001000000050000001EE0490B976147406BB933130CF945401EE0490B97614740F819170E84FA45400E863AAC70634740F819170E84FA45400E863AAC706347406BB933130CF945401EE0490B976147406BB933130CF94540
28388	Южное	8	75	677	46.716293	46.729463000000003	43.820366999999997	43.812327000000003	0103000020E6100000010000000500000047AD307DAF5B47403354C554FAE7454047AD307DAF5B4740DBDB2DC901E945402F52280B5F5D4740DBDB2DC901E945402F52280B5F5D47403354C554FAE7454047AD307DAF5B47403354C554FAE74540
53563	Юбилейное	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
28103	Черняевка	8	75	677	47.012278999999999	47.046784000000002	43.951307999999997	43.937638999999997	0103000020E61000000100000005000000BBB6B75B92814740213A048E04F84540BBB6B75B928147402A36E675C4F94540F0FCA204FD8547402A36E675C4F94540F0FCA204FD854740213A048E04F84540BBB6B75B92814740213A048E04F84540
28294	Цветковка	8	75	677	46.824109	46.843809	43.950730999999998	43.930725000000002	0103000020E610000001000000050000006DAB59677C694740E9482EFF21F745406DAB59677C6947408D25AC8DB1F945400589EDEE016C47408D25AC8DB1F945400589EDEE016C4740E9482EFF21F745406DAB59677C694740E9482EFF21F74540
28571	Хуцеевка	8	75	677	46.775995000000002	46.786344	43.934801999999998	43.923161999999998	0103000020E61000000100000005000000056EDDCD536347407974232C2AF64540056EDDCD53634740211E8997A7F74540F2B391EBA6644740211E8997A7F74540F2B391EBA66447407974232C2AF64540056EDDCD536347407974232C2AF64540
28024	Тушиловка	8	75	677	46.874361	46.887881	44.316566999999999	44.305408	0103000020E61000000100000005000000EDF2AD0FEB6F4740E8F7FD9B17274640EDF2AD0FEB6F474015FF774485284640B1DEA815A671474015FF774485284640B1DEA815A6714740E8F7FD9B17274640EDF2AD0FEB6F4740E8F7FD9B17274640
27897	Степное	8	75	677	46.484411000000001	46.506815000000003	43.901237000000002	43.888809999999999	0103000020E610000001000000050000004D69FD2D013E4740CB2DAD86C4F145404D69FD2D013E4740FB78E8BB5BF34540A60F5D50DF404740FB78E8BB5BF34540A60F5D50DF404740CB2DAD86C4F145404D69FD2D013E4740CB2DAD86C4F14540
53846	Старый Терек	8	75	677	47.148994000000002	47.381424000000003	43.995480999999998	43.875763999999997	0103000020E610000001000000050000006EA6423C12934740CF81E50819F045406EA6423C129347400A65E1EB6BFF45406BF46A80D2B047400A65E1EB6BFF45406BF46A80D2B04740CF81E50819F045406EA6423C12934740CF81E50819F04540
53848	Серебряковка	8	75	677	46.829939000000003	46.838878000000001	43.985156000000003	43.976756000000002	0103000020E610000001000000050000006556EF703B6A4740FD15325706FD45406556EF703B6A4740A6BA809719FE4540BDAAB35A606B4740A6BA809719FE4540BDAAB35A606B4740FD15325706FD45406556EF703B6A4740FD15325706FD4540
28206	Сар-Сар	8	75	677	47.069619000000003	47.081170999999998	43.982951	43.961340999999997	0103000020E6100000010000000500000012178046E9884740E7A6CD380DFB454012178046E988474006499F56D1FD45401A31B3CF638A474006499F56D1FD45401A31B3CF638A4740E7A6CD380DFB454012178046E9884740E7A6CD380DFB4540
26297	Сангиши	8	75	677	47.028906999999997	47.038877999999997	43.903426000000003	43.896735999999997	0103000020E610000001000000050000000FD07D39B3834740AB92C83EC8F245400FD07D39B3834740952D9276A3F3454056444DF4F9844740952D9276A3F3454056444DF4F9844740AB92C83EC8F245400FD07D39B3834740AB92C83EC8F24540
27381	Рыбалко	8	75	677	46.642614000000002	46.668719000000003	43.785735000000003	43.773524999999999	0103000020E61000000100000005000000D3F9F02C41524740B7D100DE02E34540D3F9F02C415247404A29E8F692E445405F9B8D95985547404A29E8F692E445405F9B8D9598554740B7D100DE02E34540D3F9F02C41524740B7D100DE02E34540
28445	Речное	8	75	677	46.718691999999997	46.726363999999997	43.790258000000001	43.783476999999998	0103000020E61000000100000005000000CBF27519FE5B474087156EF948E44540CBF27519FE5B474081B3942C27E54540F17EDC7EF95C474081B3942C27E54540F17EDC7EF95C474087156EF948E44540CBF27519FE5B474087156EF948E44540
53679	Пролетарское	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
53834	Персидское	8	75	677	46.891663000000001	46.899746999999998	43.886595	43.879260000000002	0103000020E61000000100000005000000D1066003227247402A5778978BF04540D10660032272474008E6E8F17BF1454049D6E1E82A73474008E6E8F17BF1454049D6E1E82A7347402A5778978BF04540D1066003227247402A5778978BF04540
26871	Первомайское	8	75	677	46.702019	46.721817999999999	43.923473000000001	43.913609999999998	0103000020E61000000100000005000000D71533C2DB59474037A6272CF1F44540D71533C2DB59474098DEFE5C34F6454002D53F88645C474098DEFE5C34F6454002D53F88645C474037A6272CF1F44540D71533C2DB59474037A6272CF1F44540
26949	Первокизлярское	8	75	677	46.675868999999999	46.681519999999999	43.888291000000002	43.883248999999999	0103000020E61000000100000005000000ABB019E082564740C39CA04D0EF14540ABB019E082564740632AFD84B3F14540F3C81F0C3C574740632AFD84B3F14540F3C81F0C3C574740C39CA04D0EF14540ABB019E082564740C39CA04D0EF14540
27962	Огузер	8	75	677	47.049272000000002	47.074936999999998	44.055734000000001	44.044888999999998	0103000020E61000000100000005000000E44D7E8B4E8647409E7939ECBE054640E44D7E8B4E8647403CA3AD4A2207464053211E89978947403CA3AD4A2207464053211E89978947409E7939ECBE054640E44D7E8B4E8647409E7939ECBE054640
27221	Новый Бирюзяк	8	75	677	47.272342000000002	47.321731	43.781908000000001	43.752405000000003	0103000020E61000000100000005000000E3A9471ADCA24740672C9ACE4EE04540E3A9471ADCA247408A3DB48F15E44540008E3D7B2EA947408A3DB48F15E44540008E3D7B2EA94740672C9ACE4EE04540E3A9471ADCA24740672C9ACE4EE04540
6715	Новые Бухты	8	75	677	46.958201000000003	46.977479000000002	44.148476000000002	44.139361999999998	0103000020E610000001000000050000004CFF9254A67A47400F27309DD61146404CFF9254A67A4740D61EF642011346406EC328081E7D4740D61EF642011346406EC328081E7D47400F27309DD61146404CFF9254A67A47400F27309DD6114640
53747	Новомонастырское	8	75	677	46.598847999999997	46.615988000000002	43.872807000000002	43.858514999999997	0103000020E6100000010000000500000033A31F0DA74C47400E10CCD1E3ED454033A31F0DA74C4740255CC823B8EF45403E5DDDB1D84E4740255CC823B8EF45403E5DDDB1D84E47400E10CCD1E3ED454033A31F0DA74C47400E10CCD1E3ED4540
53776	Новокрестьяновское	8	75	677	46.563876	46.575986	43.894539999999999	43.876542999999998	0103000020E61000000100000005000000E97FB9162D484740D4449F8F32F04540E97FB9162D4847405F7B664980F24540187AC4E8B94947405F7B664980F24540187AC4E8B9494740D4449F8F32F04540E97FB9162D484740D4449F8F32F04540
32883	Новокохановское	8	75	677	46.645981999999997	46.653708000000002	43.869973999999999	43.859315000000002	0103000020E61000000100000005000000FFE6C589AF5247402BFBAE08FEED4540FFE6C589AF524740662FDB4E5BEF4540199128B4AC534740662FDB4E5BEF4540199128B4AC5347402BFBAE08FEED4540FFE6C589AF5247402BFBAE08FEED4540
53937	Новогладковка	8	75	677	46.886488	46.903691000000002	43.852600000000002	43.845455000000001	0103000020E61000000100000005000000F225547078714740AE9E93DE37EC4540F225547078714740E9482EFF21ED454043588D25AC734740E9482EFF21ED454043588D25AC734740AE9E93DE37EC4540F225547078714740AE9E93DE37EC4540
53963	Нововладимирское	8	75	677	46.944924	46.956395000000001	43.917110000000001	43.905849000000003	0103000020E610000001000000050000004E9A0645F3784740A20E2BDCF2F345404E9A0645F3784740D36A48DC63F545406A87BF266B7A4740D36A48DC63F545406A87BF266B7A4740A20E2BDCF2F345404E9A0645F3784740A20E2BDCF2F34540
28013	Новая Серебряковка	8	75	677	46.968953999999997	46.988438000000002	43.993957000000002	43.985162000000003	0103000020E6100000010000000500000008AA46AF067C474088A1D5C919FE454008AA46AF067C4740AD50A4FB39FF4540D40FEA22857E4740AD50A4FB39FF4540D40FEA22857E474088A1D5C919FE454008AA46AF067C474088A1D5C919FE4540
27615	Некрасовка	8	75	677	46.939191999999998	46.960194999999999	43.835143000000002	43.820008999999999	0103000020E6100000010000000500000019558671377847407CB60E0EF6E845401955867137784740DE3D40F7E5EA4540306475ABE77A4740DE3D40F7E5EA4540306475ABE77A47407CB60E0EF6E8454019558671377847407CB60E0EF6E84540
53835	Михеевское	8	75	677	46.663949000000002	46.672186000000004	43.933478000000001	43.923577000000002	0103000020E61000000100000005000000209BE447FC5447403D2B69C537F64540209BE447FC5447408BC404357CF745401F6ADB300A5647408BC404357CF745401F6ADB300A5647403D2B69C537F64540209BE447FC5447403D2B69C537F64540
53597	Малое Козыревское	8	75	677	46.811523999999999	46.820929	43.904712000000004	43.896540999999999	0103000020E61000000100000005000000A5F5B704E0674740F64201DBC1F24540A5F5B704E06747403E26529ACDF3454043AB9333146947403E26529ACDF3454043AB933314694740F64201DBC1F24540A5F5B704E0674740F64201DBC1F24540
27633	Малая Арешевка	8	75	677	46.798929000000001	46.827827999999997	44.029349000000003	44.013351	0103000020E61000000100000005000000BA69334E43664740382F4E7CB5014640BA69334E43664740CD9541B5C1034640465B9544F6694740CD9541B5C1034640465B9544F6694740382F4E7CB5014640BA69334E43664740382F4E7CB5014640
53833	Макаровское	8	75	677	46.889865999999998	46.901130999999999	44.126480999999998	44.118572999999998	0103000020E6100000010000000500000042E90B21E771474024986A662D0F464042E90B21E77147405E48878730104640B534B742587347405E48878730104640B534B7425873474024986A662D0F464042E90B21E771474024986A662D0F4640
53605	Курдюковское	8	75	677	46.939300000000003	46.959538999999999	43.942591999999998	43.930835999999999	0103000020E6100000010000000500000000917EFB3A78474040F850A225F7454000917EFB3A78474051BCCADAA6F84540471E882CD27A474051BCCADAA6F84540471E882CD27A474040F850A225F7454000917EFB3A78474040F850A225F74540
27297	Красный Восход	8	75	677	46.671764000000003	46.702531	43.867756999999997	43.852535000000003	0103000020E61000000100000005000000A950DD5CFC55474002D9EBDD1FED4540A950DD5CFC55474002F04FA912EF45408DB62A89EC59474002F04FA912EF45408DB62A89EC59474002D9EBDD1FED4540A950DD5CFC55474002D9EBDD1FED4540
32830	Краснооктябрьское	8	75	677	46.650761000000003	46.665422	43.851443000000003	43.840812999999997	0103000020E610000001000000050000009241EE224C5347409C86A8C29FEB45409241EE224C5347403EB48F15FCEC4540FB04508C2C5547403EB48F15FCEC4540FB04508C2C5547409C86A8C29FEB45409241EE224C5347409C86A8C29FEB4540
7544	Крайновка	8	75	677	47.364724000000002	47.381199000000002	43.984293000000001	43.967244999999998	0103000020E610000001000000050000007D08AA46AFAE4740191C25AFCEFB45407D08AA46AFAE474043572250FDFD45404B22FB20CBB0474043572250FDFD45404B22FB20CBB04740191C25AFCEFB45407D08AA46AFAE4740191C25AFCEFB4540
26759	Косякино	8	75	677	46.669096000000003	46.688257	43.905557000000002	43.895307000000003	0103000020E6100000010000000500000035F10EF0A4554740A070766B99F2454035F10EF0A4554740FAD4B14AE9F345401D1F2DCE18584740FAD4B14AE9F345401D1F2DCE18584740A070766B99F2454035F10EF0A4554740A070766B99F24540
53685	Комсомольский	8	75	677	46.691795999999997	46.704704999999997	43.985967000000002	43.967607999999998	0103000020E6100000010000000500000076C075C58C5847408AAC3594DAFB454076C075C58C584740B6F7A92A34FE4540F12900C6335A4740B6F7A92A34FE4540F12900C6335A47408AAC3594DAFB454076C075C58C5847408AAC3594DAFB4540
27110	Коллективизатор	8	75	677	47.386949000000001	47.396911000000003	43.961834000000003	43.955598000000002	0103000020E61000000100000005000000261C7A8B87B14740BF0F070951FA4540261C7A8B87B14740271763601DFB45401A36CAFACDB24740271763601DFB45401A36CAFACDB24740BF0F070951FA4540261C7A8B87B14740BF0F070951FA4540
27474	Кардоновка	8	75	677	46.837539	46.852998999999997	43.823183	43.809348	0103000020E61000000100000005000000F10F5B7A346B4740A08A1BB798E74540F10F5B7A346B4740C4CF7F0F5EE94540A6423C122F6D4740C4CF7F0F5EE94540A6423C122F6D4740A08A1BB798E74540F10F5B7A346B4740A08A1BB798E74540
53928	Калантар	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
26402	Имени Карла Маркса	8	75	677	46.771099999999997	46.807419000000003	43.899242999999998	43.888356000000002	0103000020E6100000010000000500000009F9A067B36247404A9A3FA6B5F1454009F9A067B3624740161406651AF34540A3957B8159674740161406651AF34540A3957B81596747404A9A3FA6B5F1454009F9A067B36247404A9A3FA6B5F14540
53889	Зеленый бугор	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
27450	Заречное	8	75	677	46.576273	46.597634999999997	43.767659999999999	43.758485999999998	0103000020E61000000100000005000000AE484C50C3494740A73CBA1116E14540AE484C50C34947404339D1AE42E24540F4F8BD4D7F4C47404339D1AE42E24540F4F8BD4D7F4C4740A73CBA1116E14540AE484C50C3494740A73CBA1116E14540
26184	Ефимовка	8	75	677	46.791733999999998	46.803151999999997	43.844667999999999	43.837432	0103000020E61000000100000005000000CD902A8A57654740DB4FC6F830EB4540CD902A8A5765474026FDBD141EEC4540C6DB4AAFCD66474026FDBD141EEC4540C6DB4AAFCD664740DB4FC6F830EB4540CD902A8A57654740DB4FC6F830EB4540
53529	Дагестанское	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
53743	Вышеталовка	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
26741	Вперед	8	75	677	46.706673000000002	46.725572999999997	43.906770999999999	43.892162999999996	0103000020E61000000100000005000000ADFBC742745A4740C2D9AD6532F24540ADFBC742745A474009FB761211F4454028EE7893DF5C474009FB761211F4454028EE7893DF5C4740C2D9AD6532F24540ADFBC742745A4740C2D9AD6532F24540
28089	Брянск	8	75	677	46.975214999999999	46.990755999999998	44.332740000000001	44.325512000000003	0103000020E61000000100000005000000C9C859D8D37C4740503A9160AA294640C9C859D8D37C474018096D39972A46406B28B517D17E474018096D39972A46406B28B517D17E4740503A9160AA294640C9C859D8D37C4740503A9160AA294640
53609	Бондареновка	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
53708	Большой Бредихин	8	75	677	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
53735	Большезадоевское	8	75	677	46.814999999999998	46.838878000000001	43.878011999999998	43.861030999999997	0103000020E61000000100000005000000B81E85EB51684740CCEB884336EE4540B81E85EB516847406EBF7CB262F04540BDAAB35A606B47406EBF7CB262F04540BDAAB35A606B4740CCEB884336EE4540B81E85EB51684740CCEB884336EE4540
26469	Большая Арешевка	8	75	677	46.907266	46.930371000000001	44.128337999999999	44.101719000000003	0103000020E61000000100000005000000E962D34A21744740E030D120050D4640E962D34A21744740C26A2C616D104640CB129D6516774740C26A2C616D104640CB129D6516774740E030D120050D4640E962D34A21744740E030D120050D4640
53686	Александрийская	8	75	677	47.116753000000003	47.1432	43.913753	43.894300000000001	0103000020E61000000100000005000000DE5A26C3F18E47400A68226C78F24540DE5A26C3F18E47409ACFB9DBF5F44540C364AA60549247409ACFB9DBF5F44540C364AA60549247400A68226C78F24540DE5A26C3F18E47400A68226C78F24540
25857	Аверьяновка	8	75	677	46.743270000000003	46.765925000000003	43.853042000000002	43.836137999999998	0103000020E61000000100000005000000890CAB78235F4740AF78EA9106EB4540890CAB78235F4740A60EF27A30ED45402B1895D409624740A60EF27A30ED45402B1895D409624740AF78EA9106EB4540890CAB78235F4740AF78EA9106EB4540
25066	Шушановка	8	75	653	46.976148999999999	46.997987000000002	43.205148999999999	43.194983000000001	0103000020E61000000100000005000000F5824F73F27C47405323F433F5984540F5824F73F27C47404FE78A52429A4540A56ABB09BE7F47404FE78A52429A4540A56ABB09BE7F47405323F433F5984540F5824F73F27C47405323F433F5984540
25185	Чонтаул	8	75	653	46.847321999999998	46.874243999999997	43.315899999999999	43.293954999999997	0103000020E6100000010000000500000035971B0C756C474072BF4351A0A5454035971B0C756C4740386744696FA84540B35C363AE76F4740386744696FA84540B35C363AE76F474072BF4351A0A5454035971B0C756C474072BF4351A0A54540
53532	Ханар	8	75	653	46.733792999999999	47.12359	43.415393999999999	43.074252000000001	0103000020E610000001000000050000005184D4EDEC5D4740D0D4EB16818945405184D4EDEC5D4740317A6EA12BB545406B0E10CCD18F4740317A6EA12BB545406B0E10CCD18F4740D0D4EB16818945405184D4EDEC5D4740D0D4EB1681894540
53684	Султан-Янгиюрт	8	75	653	46.855164000000002	46.874153999999997	43.232579000000001	43.212266	0103000020E61000000100000005000000B85B9203766D4740C00644882B9B4540B85B9203766D4740425E0F26C59D454073D53C47E46F4740425E0F26C59D454073D53C47E46F4740C00644882B9B4540B85B9203766D4740C00644882B9B4540
24414	Старый Миатли	8	75	653	46.821154	46.836936999999999	43.086374999999997	43.075451000000001	0103000020E61000000100000005000000637D03931B694740AAB9DC60A8894540637D03931B694740931804560E8B4540FBE769C0206B4740931804560E8B4540FBE769C0206B4740AAB9DC60A8894540637D03931B694740AAB9DC60A8894540
53556	Стальское	8	75	653	46.958784999999999	46.983623000000001	43.194949999999999	43.179397000000002	0103000020E610000001000000050000009B728577B97A474011001C7BF69645409B728577B97A4740772D211FF4984540F54BC45BE77D4740772D211FF4984540F54BC45BE77D474011001C7BF69645409B728577B97A474011001C7BF6964540
24833	Новый Чиркей	8	75	653	47.038609000000001	47.068047	43.172547000000002	43.143583999999997	0103000020E61000000100000005000000672AC423F18447404B1DE4F560924540672AC423F1844740EF02250516964540A3CB9BC3B5884740EF02250516964540A3CB9BC3B58847404B1DE4F560924540672AC423F18447404B1DE4F560924540
24255	Новые Гадари	8	75	653	46.760868000000002	46.776345999999997	43.197526000000003	43.189475000000002	0103000020E610000001000000050000005649641F646147406E3480B7409845405649641F646147400B0E2F8848994540B130444E5F6347400B0E2F8848994540B130444E5F6347406E3480B7409845405649641F646147406E3480B740984540
24667	Нечаевка	8	75	653	46.895130000000002	46.926732999999999	43.277555	43.258918000000001	0103000020E6100000010000000500000091D5AD9E93724740412C9B3924A1454091D5AD9E93724740AFEB17EC86A34540DE8FDB2F9F764740AFEB17EC86A34540DE8FDB2F9F764740412C9B3924A1454091D5AD9E93724740412C9B3924A14540
24687	Мацеевка	8	75	653	46.976464	46.987791000000001	43.274850999999998	43.267964999999997	0103000020E6100000010000000500000055DCB8C5FC7C47407FBC57AD4CA2454055DCB8C5FC7C4740EE224C512EA345403E247CEF6F7E4740EE224C512EA345403E247CEF6F7E47407FBC57AD4CA2454055DCB8C5FC7C47407FBC57AD4CA24540
24610	Кульзеб	8	75	653	46.992193	47.019089000000001	43.180962000000001	43.167516999999997	0103000020E61000000100000005000000FA28232E007F47401343723271954540FA28232E007F4740CDE847C3299745404F5B238271824740CDE847C3299745404F5B2382718247401343723271954540FA28232E007F47401343723271954540
53557	Комсомольское	8	75	653	46.886038999999997	46.903790000000001	43.202941000000003	43.190356000000001	0103000020E6100000010000000500000082FDD7B969714740774CDD955D98454082FDD7B9697147403F027FF8F9994540D6390664AF7347403F027FF8F9994540D6390664AF734740774CDD955D98454082FDD7B969714740774CDD955D984540
24439	Кироваул	8	75	653	46.844473999999998	46.853655000000003	43.250258000000002	43.228309000000003	0103000020E6100000010000000500000041295AB9176C4740F530B43A399D454041295AB9176C4740FCC7427408A0454090882991446D4740FCC7427408A0454090882991446D4740F530B43A399D454041295AB9176C4740F530B43A399D4540
6256	Аркида	8	75	653	47.054535999999999	47.059691999999998	43.208309999999997	43.204906000000001	0103000020E61000000100000005000000323A2009FB86474089601C5C3A9A4540323A2009FB86474002B7EEE6A99A45409AEAC9FCA387474002B7EEE6A99A45409AEAC9FCA387474089601C5C3A9A4540323A2009FB86474089601C5C3A9A4540
24121	Акнада	8	75	653	46.897734999999997	46.922941999999999	43.387431999999997	43.370114000000001	0103000020E61000000100000005000000BEBC00FBE872474058E542E55FAF4540BEBC00FBE872474041B62C5F97B145406B0DA5F62276474041B62C5F97B145406B0DA5F62276474058E542E55FAF4540BEBC00FBE872474058E542E55FAF4540
4382	Акаро	8	75	653	46.974432999999998	46.981413000000003	43.356907999999997	43.350470000000001	0103000020E6100000010000000500000053927538BA7C4740541D7233DCAC454053927538BA7C474023D74D29AFAD4540446FF1F09E7D474023D74D29AFAD4540446FF1F09E7D4740541D7233DCAC454053927538BA7C4740541D7233DCAC4540
53566	cело Новозубутли	8	75	653	46.733792999999999	47.12359	43.415393999999999	43.074252000000001	0103000020E610000001000000050000005184D4EDEC5D4740D0D4EB16818945405184D4EDEC5D4740317A6EA12BB545406B0E10CCD18F4740317A6EA12BB545406B0E10CCD18F4740D0D4EB16818945405184D4EDEC5D4740D0D4EB1681894540
53683	cело Нижнечирюрт	8	75	653	46.733792999999999	47.12359	43.415393999999999	43.074252000000001	0103000020E610000001000000050000005184D4EDEC5D4740D0D4EB16818945405184D4EDEC5D4740317A6EA12BB545406B0E10CCD18F4740317A6EA12BB545406B0E10CCD18F4740D0D4EB16818945405184D4EDEC5D4740D0D4EB1681894540
53554	cело Комсомолец	8	75	653	46.733792999999999	47.12359	43.415393999999999	43.074252000000001	0103000020E610000001000000050000005184D4EDEC5D4740D0D4EB16818945405184D4EDEC5D4740317A6EA12BB545406B0E10CCD18F4740317A6EA12BB545406B0E10CCD18F4740D0D4EB16818945405184D4EDEC5D4740D0D4EB1681894540
53587	cело Зубутли-Миатли	8	75	653	46.733792999999999	47.12359	43.415393999999999	43.074252000000001	0103000020E610000001000000050000005184D4EDEC5D4740D0D4EB16818945405184D4EDEC5D4740317A6EA12BB545406B0E10CCD18F4740317A6EA12BB545406B0E10CCD18F4740D0D4EB16818945405184D4EDEC5D4740D0D4EB1681894540
53713	cело Гельбах	8	75	653	46.733792999999999	47.12359	43.415393999999999	43.074252000000001	0103000020E610000001000000050000005184D4EDEC5D4740D0D4EB16818945405184D4EDEC5D4740317A6EA12BB545406B0E10CCD18F4740317A6EA12BB545406B0E10CCD18F4740D0D4EB16818945405184D4EDEC5D4740D0D4EB1681894540
53736	с.Сагаси-Дейбук	8	75	1709	47.697290000000002	48.111727000000002	42.607506000000001	42.221698000000004	0103000020E61000000100000005000000F7E978CC40D9474058CB9D99601C4540F7E978CC40D94740D80FB1C1C24D4540448A01124D0E4840D80FB1C1C24D4540448A01124D0E484058CB9D99601C4540F7E978CC40D9474058CB9D99601C4540
53674	с.Кулкам	8	75	1709	47.697290000000002	48.111727000000002	42.607506000000001	42.221698000000004	0103000020E61000000100000005000000F7E978CC40D9474058CB9D99601C4540F7E978CC40D94740D80FB1C1C24D4540448A01124D0E4840D80FB1C1C24D4540448A01124D0E484058CB9D99601C4540F7E978CC40D9474058CB9D99601C4540
23516	Утамыш	8	75	1709	47.737713999999997	47.759112000000002	42.414036000000003	42.400374999999997	0103000020E6100000010000000500000092E68F696DDE47406891ED7C3F33454092E68F696DDE4740EFAEB321FF3445402600FF942AE14740EFAEB321FF3445402600FF942AE147406891ED7C3F33454092E68F696DDE47406891ED7C3F334540
23362	Усемикент	8	75	1709	47.862059000000002	47.873809000000001	42.391005999999997	42.380037999999999	0103000020E610000001000000050000007A1C06F357EE47405E9ECE15A53045407A1C06F357EE474017450F7C0C324540A9F92AF9D8EF474017450F7C0C324540A9F92AF9D8EF47405E9ECE15A53045407A1C06F357EE47405E9ECE15A5304540
23661	Первомайское	8	75	1709	47.885917999999997	47.911403	42.505369000000002	42.484507999999998	0103000020E610000001000000050000000778D2C265F147403F53AF5B043E45400778D2C265F14740C4B46FEEAF404540F73C7FDAA8F44740C4B46FEEAF404540F73C7FDAA8F447403F53AF5B043E45400778D2C265F147403F53AF5B043E4540
23649	Новый Дейбук	8	75	1709	47.835424000000003	47.956732000000002	42.512368000000002	42.402219000000002	0103000020E610000001000000050000009225732CEFEA4740386A85E97B3345409225732CEFEA47402BC24D4695414540B284B53176FA47402BC24D4695414540B284B53176FA4740386A85E97B3345409225732CEFEA4740386A85E97B334540
23844	Новые Викри	8	75	1709	47.986511	48.004207999999998	42.303106	42.291561999999999	0103000020E61000000100000005000000771211FE45FE4740D06053E751254540771211FE45FE4740569C6A2DCC264540D73043E389004840569C6A2DCC264540D73043E389004840D06053E751254540771211FE45FE4740D06053E751254540
22875	Новокаякент	8	75	1709	47.954397	47.998342000000001	42.395780999999999	42.378152999999998	0103000020E6100000010000000500000044334FAE29FA474030F147516730454044334FAE29FA474068B0A9F3A8324540931CB0ABC9FF474068B0A9F3A8324540931CB0ABC9FF474030F147516730454044334FAE29FA474030F1475167304540
53793	МУП Тпигский	8	75	1709	47.697290000000002	48.111727000000002	42.607506000000001	42.221698000000004	0103000020E61000000100000005000000F7E978CC40D9474058CB9D99601C4540F7E978CC40D94740D80FB1C1C24D4540448A01124D0E4840D80FB1C1C24D4540448A01124D0E484058CB9D99601C4540F7E978CC40D9474058CB9D99601C4540
53859	МУП Агульский	8	75	1709	47.697290000000002	48.111727000000002	42.607506000000001	42.221698000000004	0103000020E61000000100000005000000F7E978CC40D9474058CB9D99601C4540F7E978CC40D94740D80FB1C1C24D4540448A01124D0E4840D80FB1C1C24D4540448A01124D0E484058CB9D99601C4540F7E978CC40D9474058CB9D99601C4540
23201	Каякент	8	75	1709	47.892476000000002	47.919029999999999	42.397185999999998	42.377181	0103000020E61000000100000005000000823B50A73CF2474017D68D7747304540823B50A73CF24740EB36A8FDD63245407D0569C6A2F54740EB36A8FDD63245407D0569C6A2F5474017D68D7747304540823B50A73CF2474017D68D7747304540
53612	Каранай-Аул	8	75	1709	47.850515000000001	47.876333000000002	42.524183000000001	42.510174999999997	0103000020E61000000100000005000000F4E0EEACDDEC47404F1E166A4D414540F4E0EEACDDEC4740410FB56D18434540EAB303AE2BF04740410FB56D18434540EAB303AE2BF047404F1E166A4D414540F4E0EEACDDEC47404F1E166A4D414540
24040	Капкайкент	8	75	1709	47.793013999999999	47.811214	42.255909000000003	42.243341999999998	0103000020E6100000010000000500000094A2957B81E5474022DFA5D4251F454094A2957B81E5474044E048A0C1204540570740DCD5E7474044E048A0C1204540570740DCD5E7474022DFA5D4251F454094A2957B81E5474022DFA5D4251F4540
23124	Инчхе	8	75	1709	47.937742	47.943114000000001	42.472245999999998	42.466686000000003	0103000020E61000000100000005000000F60A0BEE07F8474023C0E95DBC3B4540F60A0BEE07F847405AD5928E723C45402B33A5F5B7F847405AD5928E723C45402B33A5F5B7F8474023C0E95DBC3B4540F60A0BEE07F8474023C0E95DBC3B4540
23886	Дружба	8	75	1709	47.979675	48.012597999999997	42.245891	42.237774999999999	0103000020E61000000100000005000000BADA8AFD65FD4740386744696F1E4540BADA8AFD65FD4740BCB0355B791F45405CFFAECF9C014840BCB0355B791F45405CFFAECF9C014840386744696F1E4540BADA8AFD65FD4740386744696F1E4540
24016	Джаванкент	8	75	1709	47.805950000000003	47.813459999999999	42.265965000000001	42.260033	0103000020E61000000100000005000000091B9E5E29E74740BD70E7C248214540091B9E5E29E74740B97020240B224540554D10751FE84740B97020240B224540554D10751FE84740BD70E7C248214540091B9E5E29E74740BD70E7C248214540
23793	Герга	8	75	1709	47.953344999999999	47.974868999999998	42.355784	42.338805000000001	0103000020E610000001000000050000000E677E3507FA4740535C55F65D2B45400E677E3507FA4740543882548A2D45402E71E481C8FC4740543882548A2D45402E71E481C8FC4740535C55F65D2B45400E677E3507FA4740535C55F65D2B4540
23951	Башлыкент	8	75	1709	47.831363000000003	47.849518000000003	42.263897	42.254733999999999	0103000020E610000001000000050000005F0D501A6AEA4740F296AB1F9B2045405F0D501A6AEA47409A417C60C721454082AE7D01BDEC47409A417C60C721454082AE7D01BDEC4740F296AB1F9B2045405F0D501A6AEA4740F296AB1F9B204540
23430	Алхаджакент	8	75	1709	47.784264999999998	47.798566000000001	42.348241000000002	42.336905000000002	0103000020E61000000100000005000000DF32A7CB62E44740F06DFAB31F2B4540DF32A7CB62E447402C103D29932C454049D9226937E647402C103D29932C454049D9226937E64740F06DFAB31F2B4540DF32A7CB62E44740F06DFAB31F2B4540
53676	Уллубийаул	8	75	1621	47.256594	47.811599999999999	42.928597000000003	42.445892000000001	0103000020E61000000100000005000000C72C7B12D8A0474026C632FD12394540C72C7B12D8A04740F5143944DC76454080B74082E2E74740F5143944DC76454080B74082E2E7474026C632FD12394540C72C7B12D8A0474026C632FD12394540
20782	Параул	8	75	1621	47.338287000000001	47.363422	42.746211000000002	42.734332000000002	0103000020E61000000100000005000000BBD408FD4CAB474001344A97FE5D4540BBD408FD4CAB47402E7590D7835F4540CE52B29C84AE47402E7590D7835F4540CE52B29C84AE474001344A97FE5D4540BBD408FD4CAB474001344A97FE5D4540
21687	Манаскент	8	75	1621	47.670762000000003	47.701062999999998	42.748646999999998	42.717542000000002	0103000020E6100000010000000500000025B37A87DBD54740D3C08F6AD85B454025B37A87DBD54740CF9F36AAD35F4540C3B7B06EBCD94740CF9F36AAD35F4540C3B7B06EBCD94740D3C08F6AD85B454025B37A87DBD54740D3C08F6AD85B4540
53677	Манас	8	75	1621	47.256594	47.811599999999999	42.928597000000003	42.445892000000001	0103000020E61000000100000005000000C72C7B12D8A0474026C632FD12394540C72C7B12D8A04740F5143944DC76454080B74082E2E74740F5143944DC76454080B74082E2E7474026C632FD12394540C72C7B12D8A0474026C632FD12394540
21450	Ленинкент	8	75	1621	47.746786999999998	47.761645000000001	42.490305999999997	42.479348000000002	0103000020E61000000100000005000000FA0967B796DF474096B377465B3D4540FA0967B796DF47402B84D558C23E4540BA1457957DE147402B84D558C23E4540BA1457957DE1474096B377465B3D4540FA0967B796DF474096B377465B3D4540
20322	Карабудахкент	8	75	1621	47.544316000000002	47.585791	42.717309999999998	42.691577000000002	0103000020E6100000010000000500000043588D25ACC5474039D55A988558454043588D25ACC54740008C67D0D05B454044A51133FBCA4740008C67D0D05B454044A51133FBCA474039D55A988558454043588D25ACC5474039D55A9885584540
21170	Какамахи	8	75	1621	47.426986999999997	47.448196000000003	42.653374999999997	42.626873000000003	0103000020E6100000010000000500000098689082A7B647406ADFDC5F3D50454098689082A7B647401283C0CAA153454059198D7C5EB947401283C0CAA153454059198D7C5EB947406ADFDC5F3D50454098689082A7B647406ADFDC5F3D504540
53675	Кака-Шура	8	75	1621	47.368713	47.395769999999999	42.656001000000003	42.644841	0103000020E61000000100000005000000164ED2FC31AF47405A0F5F268A524540164ED2FC31AF474058923CD7F7534540745E6397A8B2474058923CD7F7534540745E6397A8B247405A0F5F268A524540164ED2FC31AF47405A0F5F268A524540
21753	Зеленоморск	8	75	1621	47.684255	47.696984	42.777267999999999	42.764310000000002	0103000020E61000000100000005000000EF8FF7AA95D74740BD00FBE8D4614540EF8FF7AA95D74740191D90847D634540EAEA8EC536D94740191D90847D634540EAEA8EC536D94740BD00FBE8D4614540EF8FF7AA95D74740BD00FBE8D4614540
20933	Доргели	8	75	1621	47.280678000000002	47.305551999999999	42.675756999999997	42.655715999999998	0103000020E61000000100000005000000755AB741EDA3474062BB7B80EE534540755AB741EDA34740838593347F5645401B9DF3531CA74740838593347F5645401B9DF3531CA7474062BB7B80EE534540755AB741EDA3474062BB7B80EE534540
21375	Джанга	8	75	1621	47.760567000000002	47.772497000000001	42.523021	42.511516999999998	0103000020E610000001000000050000005BB56B425AE147408C2C9963794145405BB56B425AE14740840F255AF24245400AA1832EE1E24740840F255AF24245400AA1832EE1E247408C2C9963794145405BB56B425AE147408C2C996379414540
21231	Гурбуки	8	75	1621	47.590713999999998	47.614106	42.618706000000003	42.600524	0103000020E6100000010000000500000009A52F849CCB4740473B6EF8DD4C454009A52F849CCB474064EB19C2314F4540812381069BCE474064EB19C2314F4540812381069BCE4740473B6EF8DD4C454009A52F849CCB4740473B6EF8DD4C4540
21309	Губден	8	75	1621	47.548268	47.589168000000001	42.575724999999998	42.555219999999998	0103000020E61000000100000005000000BFB854A52DC64740E50AEF7211474540BFB854A52DC64740AB3E575BB1494540C4EC65DB69CB4740AB3E575BB1494540C4EC65DB69CB4740E50AEF7211474540BFB854A52DC64740E50AEF7211474540
53522	Гели	8	75	1621	47.256594	47.811599999999999	42.928597000000003	42.445892000000001	0103000020E61000000100000005000000C72C7B12D8A0474026C632FD12394540C72C7B12D8A04740F5143944DC76454080B74082E2E74740F5143944DC76454080B74082E2E7474026C632FD12394540C72C7B12D8A0474026C632FD12394540
53588	Ачису	8	75	1621	47.675631000000003	47.684640999999999	42.654755000000002	42.648454999999998	0103000020E61000000100000005000000F7949C137BD64740BEF6CC9200534540F7949C137BD647403DF20703CF5345401840F850A2D747403DF20703CF5345401840F850A2D74740BEF6CC9200534540F7949C137BD64740BEF6CC9200534540
20652	Аданак	8	75	1621	47.450333999999998	47.464005999999998	42.756731000000002	42.748634000000003	0103000020E610000001000000050000007023658BA4B947403B56293DD35F45407023658BA4B94740486FB88FDC604540EA92718C64BB4740486FB88FDC604540EA92718C64BB47403B56293DD35F45407023658BA4B947403B56293DD35F4540
20086	Янгикент	8	75	1533	47.819685	47.849716000000001	42.213064000000003	42.200614999999999	0103000020E61000000100000005000000C9022670EBE84740240B98C0AD194540C9022670EBE847403CFA5FAE451B4540A8716F7EC3EC47403CFA5FAE451B4540A8716F7EC3EC4740240B98C0AD194540C9022670EBE84740240B98C0AD194540
19808	Шиляги	8	75	1533	47.787157000000001	47.793301999999997	42.052970000000002	42.045597999999998	0103000020E61000000100000005000000A3E8818FC1E44740AA61BF27D6054540A3E8818FC1E44740A6D590B8C7064540FAEC80EB8AE54740A6D590B8C7064540FAEC80EB8AE54740AA61BF27D6054540A3E8818FC1E44740AA61BF27D6054540
19727	Чумли	8	75	1533	47.764761999999997	47.778784999999999	42.209932000000002	42.197870000000002	0103000020E610000001000000050000009D9CA1B8E3E14740056EDDCD531945409D9CA1B8E3E147402331410DDF1A4540C4CE143AAFE347402331410DDF1A4540C4CE143AAFE34740056EDDCD531945409D9CA1B8E3E14740056EDDCD53194540
18238	Чахдикна	8	75	1533	47.758195000000001	47.763756000000001	42.143560999999998	42.13852	0103000020E61000000100000005000000D07EA4880CE14740C4EBFA05BB114540D07EA4880CE1474093FDF33460124540D80FB1C1C2E1474093FDF33460124540D80FB1C1C2E14740C4EBFA05BB114540D07EA4880CE14740C4EBFA05BB114540
19584	Хунгия	8	75	1533	47.801225000000002	47.806552000000003	42.096846999999997	42.091982999999999	0103000020E610000001000000050000006ADE718A8EE64740DC645419C60B45406ADE718A8EE647409CDB847B650C4540FF428F183DE747409CDB847B650C4540FF428F183DE74740DC645419C60B45406ADE718A8EE64740DC645419C60B4540
18769	Хадаги	8	75	1533	47.894623000000003	47.902366000000001	42.084482000000001	42.078740000000003	0103000020E61000000100000005000000ED9FA70183F247408B71FE26140A4540ED9FA70183F24740E38C614ED00A4540DC82A5BA80F34740E38C614ED00A4540DC82A5BA80F347408B71FE26140A4540ED9FA70183F247408B71FE26140A4540
20178	Тумеллер	8	75	1533	47.833843000000002	47.844253999999999	42.186340000000001	42.182392	0103000020E61000000100000005000000D07F0F5EBBEA4740A986FD9E58174540D07F0F5EBBEA4740E4F736FDD917454033C2DB8310EC4740E4F736FDD917454033C2DB8310EC4740A986FD9E58174540D07F0F5EBBEA4740A986FD9E58174540
53930	Сурхачи	8	75	1533	47.738180999999997	47.742564999999999	42.164476999999998	42.156744000000003	0103000020E61000000100000005000000A8C30AB77CDE474010ECF82F10144540A8C30AB77CDE4740DBF813950D154540BE13B35E0CDF4740DBF813950D154540BE13B35E0CDF474010ECF82F10144540A8C30AB77CDE474010ECF82F10144540
19080	Сургия	8	75	1533	47.715175000000002	47.725560000000002	42.078685999999998	42.075440999999998	0103000020E610000001000000050000005AF5B9DA8ADB474086E3F90CA80945405AF5B9DA8ADB474097530262120A454094A46B26DFDC474097530262120A454094A46B26DFDC474086E3F90CA80945405AF5B9DA8ADB474086E3F90CA8094540
19719	Санчи	8	75	1533	47.814484	47.832118000000001	42.134776000000002	42.127555000000001	0103000020E61000000100000005000000C18EFF0241E847407CB8E4B853104540C18EFF0241E847409224085740114540DB34B6D782EA47409224085740114540DB34B6D782EA47407CB8E4B853104540C18EFF0241E847407CB8E4B853104540
18597	Рука	8	75	1533	47.917816999999999	47.928686999999996	42.049661999999998	42.045014999999999	0103000020E610000001000000050000003E5B07077BF547402B6A300DC30545403E5B07077BF547404EED0C535B064540349C3237DFF647404EED0C535B064540349C3237DFF647402B6A300DC30545403E5B07077BF547402B6A300DC3054540
19651	Родниковый	8	75	1533	47.941747999999997	47.966281000000002	42.153154000000001	42.147292	0103000020E610000001000000050000006589CE328BF84740317BD976DA1245406589CE328BF8474034A0DE8C9A13454083DF8618AFFB474034A0DE8C9A13454083DF8618AFFB4740317BD976DA1245406589CE328BF84740317BD976DA124540
19393	Пиляки	8	75	1533	47.853884000000001	47.860638999999999	42.007615000000001	42.002583000000001	0103000020E61000000100000005000000F14927124CED47404643C6A354004540F14927124CED4740C2FA3F87F9004540C154336B29EE4740C2FA3F87F9004540C154336B29EE47404643C6A354004540F14927124CED47404643C6A354004540
20152	Новая Барша	8	75	1533	47.826548000000003	47.835037	42.181690000000003	42.175229000000002	0103000020E6100000010000000500000080492A53CCE94740C82764E76D16454080492A53CCE947405001309E4117454098F90E7EE2EA47405001309E4117454098F90E7EE2EA4740C82764E76D16454080492A53CCE94740C82764E76D164540
19873	Мижигли	8	75	1533	47.797756999999997	47.803075	42.071129999999997	42.068406000000003	0103000020E61000000100000005000000D993C0E61CE64740D36C1E87C1084540D993C0E61CE64740DAE1AFC91A0945401B9E5E29CBE64740DAE1AFC91A0945401B9E5E29CBE64740D36C1E87C1084540D993C0E61CE64740D36C1E87C1084540
18817	Машаты	8	75	1533	47.878039999999999	47.885289	42.057200999999999	42.052173000000003	0103000020E61000000100000005000000384A5E9D63F04740FB5DD89AAD064540384A5E9D63F047403526C45C520745401841632651F147403526C45C520745401841632651F14740FB5DD89AAD064540384A5E9D63F04740FB5DD89AAD064540
20268	Маллакент	8	75	1533	47.787830999999997	47.797505999999998	42.175142000000001	42.169763000000003	0103000020E6100000010000000500000032E36DA5D7E44740128942CBBA15454032E36DA5D7E44740F913950D6B164540902E36AD14E64740F913950D6B164540902E36AD14E64740128942CBBA15454032E36DA5D7E44740128942CBBA154540
33071	Маджалис	8	75	1533	47.822650000000003	47.844425000000001	42.131833999999998	42.110258999999999	0103000020E61000000100000005000000F7065F984CE947407A8B87F71C0E4540F7065F984CE947401C40BFEFDF10454060764F1E16EC47401C40BFEFDF10454060764F1E16EC47407A8B87F71C0E4540F7065F984CE947407A8B87F71C0E4540
19007	Лища	8	75	1533	47.736887000000003	47.742950999999998	42.076664999999998	42.071097000000002	0103000020E610000001000000050000007DEC2E5052DE4740FFEBDCB4190945407DEC2E5052DE4740B9DFA128D0094540E7C3B30419DF4740B9DFA128D0094540E7C3B30419DF4740FFEBDCB4190945407DEC2E5052DE4740FFEBDCB419094540
20007	Кулиджа	8	75	1533	47.770628000000002	47.781255000000002	42.055185999999999	42.051383000000001	0103000020E61000000100000005000000E2B034F0A3E247400249D8B793064540E2B034F0A3E247403999B85510074540126BF12900E447403999B85510074540126BF12900E447400249D8B793064540E2B034F0A3E247400249D8B793064540
19334	Кирцик	8	75	1533	47.838433000000002	47.84252	42.004258	41.999955999999997	0103000020E610000001000000050000008F71C5C551EB474030B8E68EFEFF44408F71C5C551EB4740895FB1868B004540EB1C03B2D7EB4740895FB1868B004540EB1C03B2D7EB474030B8E68EFEFF44408F71C5C551EB474030B8E68EFEFF4440
19296	Кирки	8	75	1533	47.810738000000001	47.816712000000003	41.971438999999997	41.967336000000003	0103000020E61000000100000005000000EECF4543C6E747402A1F82AAD1FB4440EECF4543C6E747408B87F71C58FC44401920D1048AE847408B87F71C58FC44401920D1048AE847402A1F82AAD1FB4440EECF4543C6E747402A1F82AAD1FB4440
19264	Карталай	8	75	1533	47.851925999999999	47.861339999999998	42.090209999999999	42.084280999999997	0103000020E61000000100000005000000594E42E90BED47404B5645B8C90A4540594E42E90BED4740D6E253008C0B45404A5E9D6340EE4740D6E253008C0B45404A5E9D6340EE47404B5645B8C90A4540594E42E90BED47404B5645B8C90A4540
19168	Карацан	8	75	1533	47.861834000000002	47.873189000000004	42.091079000000001	42.085318000000001	0103000020E610000001000000050000005A4A969350EE47404CE141B3EB0A45405A4A969350EE47401B2D077AA80B45400D1D3BA8C4EF47401B2D077AA80B45400D1D3BA8C4EF47404CE141B3EB0A45405A4A969350EE47404CE141B3EB0A4540
19988	Дуреги	8	75	1533	47.761861000000003	47.768858000000002	42.038828000000002	42.033779000000003	0103000020E61000000100000005000000878C47A984E147405325CADE52044540878C47A984E14740A515DF50F80445404DA25EF069E24740A515DF50F80445404DA25EF069E247405325CADE52044540878C47A984E147405325CADE52044540
18914	Джирабачи	8	75	1533	47.732610999999999	47.740112000000003	42.093414000000003	42.088189	0103000020E610000001000000050000004DD87E32C6DD4740F86EF3C6490B45404DD87E32C6DD4740897E6DFDF40B454047B071FDBBDE4740897E6DFDF40B454047B071FDBBDE4740F86EF3C6490B45404DD87E32C6DD4740F86EF3C6490B4540
18847	Джинаби	8	75	1533	47.857413999999999	47.865859	42.077067	42.069322999999997	0103000020E61000000100000005000000F790F0BDBFED474028EE7893DF084540F790F0BDBFED4740E84CDA54DD09454040F9BB77D4EE4740E84CDA54DD09454040F9BB77D4EE474028EE7893DF084540F790F0BDBFED474028EE7893DF084540
18695	Джибахни	8	75	1533	47.901971000000003	47.914790000000004	42.064832000000003	42.057474999999997	0103000020E61000000100000005000000607825C973F3474036AB3E575B074540607825C973F34740FDDD3B6A4C0845409B5AB6D617F54740FDDD3B6A4C0845409B5AB6D617F5474036AB3E575B074540607825C973F3474036AB3E575B074540
18534	Джавгат	8	75	1533	47.928229000000002	47.940804999999997	42.054831	42.047485999999999	0103000020E6100000010000000500000072193735D0F64740498270051406454072193735D0F647404BE7C3B304074540E674594C6CF847404BE7C3B304074540E674594C6CF84740498270051406454072193735D0F647404982700514064540
18980	Дакниса	8	75	1533	47.723906999999997	47.731389999999998	42.089112	42.085686000000003	0103000020E61000000100000005000000382C0DFCA8DC4740CFDC43C2F70A4540382C0DFCA8DC474030D7A205680B45408B4F01309EDD474030D7A205680B45408B4F01309EDD4740CFDC43C2F70A4540382C0DFCA8DC4740CFDC43C2F70A4540
18488	Гулли	8	75	1533	47.759524999999996	47.770197000000003	42.234777000000001	42.223087	0103000020E6100000010000000500000048BF7D1D38E14740D594641D8E1C454048BF7D1D38E147402F6D382C0D1E4540193DB7D095E247402F6D382C0D1E4540193DB7D095E24740D594641D8E1C454048BF7D1D38E14740D594641D8E1C4540
53933	Гулды	8	75	1533	47.622990000000001	48.059894999999997	42.262194999999998	41.929493000000001	0103000020E6100000010000000500000016DEE522BECF4740336E6AA0F9F6444016DEE522BECF47405D16139B8F214540D218ADA3AA0748405D16139B8F214540D218ADA3AA074840336E6AA0F9F6444016DEE522BECF4740336E6AA0F9F64440
18320	Газия	8	75	1533	47.815238000000001	47.819828999999999	42.094104000000002	42.089078999999998	0103000020E610000001000000050000006D3A02B859E8474054E1CFF0660B45406D3A02B859E847401E3691990B0C4540FCA71B28F0E847401E3691990B0C4540FCA71B28F0E8474054E1CFF0660B45406D3A02B859E8474054E1CFF0660B4540
18369	Варсит	8	75	1533	47.819119000000001	47.823970000000003	41.997509999999998	41.98977	0103000020E61000000100000005000000204432E4D8E84740ED478AC8B0FE4440204432E4D8E847406BB75D68AEFF44404C7155D977E947406BB75D68AEFF44404C7155D977E94740ED478AC8B0FE4440204432E4D8E84740ED478AC8B0FE4440
18286	Баршамай	8	75	1533	47.841954000000001	47.855195999999999	42.112533999999997	42.104446000000003	0103000020E61000000100000005000000425E0F26C5EB474059198D7C5E0D4540425E0F26C5EB474012D89C83670E4540C3D5011077ED474012D89C83670E4540C3D5011077ED474059198D7C5E0D4540425E0F26C5EB474059198D7C5E0D4540
18435	Бажлук	8	75	1533	47.805805999999997	47.811833999999998	42.041587	42.037273999999996	0103000020E61000000100000005000000D575A8A624E74740DC7EF964C5044540D575A8A624E7474029780AB952054540F3E32F2DEAE7474029780AB952054540F3E32F2DEAE74740DC7EF964C5044540D575A8A624E74740DC7EF964C5044540
18149	Ахмедкент	8	75	1533	47.806696000000002	47.813442000000002	42.128323999999999	42.118960999999999	0103000020E6100000010000000500000032E884D041E74740EE3F321D3A0F454032E884D041E747405DA5BBEB6C104540AF9811DE1EE847405DA5BBEB6C104540AF9811DE1EE84740EE3F321D3A0F454032E884D041E74740EE3F321D3A0F4540
19906	Адага	8	75	1533	47.711320999999998	47.716873	42.011037999999999	42.007260000000002	0103000020E61000000100000005000000A0FA07910CDB4740D4484BE5ED004540A0FA07910CDB4740B28174B1690145405531957EC2DB4740B28174B1690145405531957EC2DB4740D4484BE5ED004540A0FA07910CDB4740D4484BE5ED004540
53711	Абдашка	8	75	1533	47.622990000000001	48.059894999999997	42.262194999999998	41.929493000000001	0103000020E6100000010000000500000016DEE522BECF4740336E6AA0F9F6444016DEE522BECF47405D16139B8F214540D218ADA3AA0748405D16139B8F214540D218ADA3AA074840336E6AA0F9F6444016DEE522BECF4740336E6AA0F9F64440
18048	Хубар	8	75	1469	46.744501	46.762925000000003	43.055421000000003	43.046422	0103000020E610000001000000050000006E6B0BCF4B5F47404FE8F527F18545406E6B0BCF4B5F47407D410B09188745408126C286A76147407D410B09188745408126C286A76147404FE8F527F18545406E6B0BCF4B5F47404FE8F527F1854540
17561	Калининаул	8	75	1469	46.550150000000002	46.578401999999997	43.084859999999999	43.062514999999998	0103000020E610000001000000050000007CF2B0506B4647403541D47D008845407CF2B0506B464740895E46B1DC8A454072F8A413094A4740895E46B1DC8A454072F8A413094A47403541D47D008845407CF2B0506B4647403541D47D00884540
17479	Инчха	8	75	1469	46.748866	46.777864000000001	43.101286000000002	43.087651999999999	0103000020E610000001000000050000000D8B51D7DA5F4740E9B6442E388B45400D8B51D7DA5F474076C58CF0F68C45402D5E2C0C9163474076C58CF0F68C45402D5E2C0C91634740E9B6442E388B45400D8B51D7DA5F4740E9B6442E388B4540
53878	Имросов	8	75	1469	46.469642999999998	46.887898999999997	43.148497999999996	42.842799999999997	0103000020E61000000100000005000000CDE506431D3C4740CE88D2DEE06B4540CDE506431D3C4740BDC282FB019345405793A7ACA6714740BDC282FB019345405793A7ACA6714740CE88D2DEE06B4540CDE506431D3C4740CE88D2DEE06B4540
17274	Дылым	8	75	1469	46.612772	46.650474000000003	43.077781999999999	43.064999	0103000020E61000000100000005000000C7F319506F4E4740E8A221E351884540C7F319506F4E4740D61BB5C2F4894540FC7266BB42534740D61BB5C2F4894540FC7266BB42534740E8A221E351884540C7F319506F4E4740E8A221E351884540
17167	Дубки	8	75	1469	46.825816000000003	46.848120999999999	43.026257999999999	43.017029999999998	0103000020E61000000100000005000000BC41B456B46947408386FE092E824540BC41B456B469474012A1116C5C83454081069B3A8F6C474012A1116C5C83454081069B3A8F6C47408386FE092E824540BC41B456B46947408386FE092E824540
17082	Гуни	8	75	1469	46.690736000000001	46.704912	43.035747000000001	43.027740000000001	0103000020E61000000100000005000000BE1589096A5847404165FCFB8C834540BE1589096A5847400EF7915B938445406B47718E3A5A47400EF7915B938445406B47718E3A5A47404165FCFB8C834540BE1589096A5847404165FCFB8C834540
17034	Гостала	8	75	1469	46.687637000000002	46.698444000000002	43.077874000000001	43.069780000000002	0103000020E6100000010000000500000081423D7D045847401BF5108DEE88454081423D7D04584740B79A75C6F7894540310BED9C66594740B79A75C6F7894540310BED9C665947401BF5108DEE88454081423D7D045847401BF5108DEE884540
16994	Гертма	8	75	1469	46.739614000000003	46.748677999999998	43.002718000000002	42.990696999999997	0103000020E61000000100000005000000F6D4EAABAB5E4740669FC728CF7E4540F6D4EAABAB5E4740268E3C10598045400A9E42AED45F4740268E3C10598045400A9E42AED45F4740669FC728CF7E4540F6D4EAABAB5E4740669FC728CF7E4540
16943	Буртунай	8	75	1469	46.620910000000002	46.641832000000001	43.005974999999999	42.975375999999997	0103000020E6100000010000000500000033E197FA794F4740D2A6EA1ED97C454033E197FA794F4740FBCBEEC9C38045405DC30C8D27524740FBCBEEC9C38045405DC30C8D27524740D2A6EA1ED97C454033E197FA794F4740D2A6EA1ED97C4540
53636	Ахтачикан	8	75	1469	46.469642999999998	46.887898999999997	43.148497999999996	42.842799999999997	0103000020E61000000100000005000000CDE506431D3C4740CE88D2DEE06B4540CDE506431D3C4740BDC282FB019345405793A7ACA6714740BDC282FB019345405793A7ACA6714740CE88D2DEE06B4540CDE506431D3C4740CE88D2DEE06B4540
53545	Артлух	8	75	1469	46.659815999999999	46.67445	42.868774000000002	42.858682999999999	0103000020E6100000010000000500000053B0C6D974544740CA501553E96D454053B0C6D974544740BCCE86FC336F4540C364AA6054564740BCCE86FC336F4540C364AA6054564740CA501553E96D454053B0C6D974544740CA501553E96D4540
16785	Алмак	8	75	1469	46.554983	46.587330999999999	42.997680000000003	42.970388999999997	0103000020E61000000100000005000000016BD5AE09474740F6B2EDB4357C4540016BD5AE09474740C8EF6DFAB37F4540A77686A92D4B4740C8EF6DFAB37F4540A77686A92D4B4740F6B2EDB4357C4540016BD5AE09474740F6B2EDB4357C4540
15885	Усухчай	8	75	1407	47.905797999999997	47.923997999999997	41.428592999999999	41.415435000000002	0103000020E610000001000000050000001F645930F1F34740904E5DF92CB544401F645930F1F34740B325AB22DCB64440E2C8039145F64740B325AB22DCB64440E2C8039145F64740904E5DF92CB544401F645930F1F34740904E5DF92CB54440
53948	Текипиркент	8	75	1407	47.880446999999997	47.889062000000003	41.344825	41.339585	0103000020E610000001000000050000003F6EBF7CB2F04740289B728577AB44403F6EBF7CB2F04740EEEBC03923AC4440E50E9BC8CCF14740EEEBC03923AC4440E50E9BC8CCF14740289B728577AB44403F6EBF7CB2F04740289B728577AB4440
53758	Новое Каракюре	8	75	1407	47.705806000000003	48.018231	41.480995999999998	41.185778999999997	0103000020E6100000010000000500000009A9DBD957DA47404CA4349BC797444009A9DBD957DA4740DFC0E44691BD4440FE62B66455024840DFC0E44691BD4440FE62B664550248404CA4349BC797444009A9DBD957DA47404CA4349BC7974440
53466	Мискинджи	8	75	1407	47.837454000000001	47.857765000000001	41.432034999999999	41.416550999999998	0103000020E61000000100000005000000C3F352B131EB4740DC0E0D8B51B54440C3F352B131EB47401ADD41EC4CB74440A453573ECBED47401ADD41EC4CB74440A453573ECBED4740DC0E0D8B51B54440C3F352B131EB4740DC0E0D8B51B54440
53530	Микрах	8	75	1407	47.875866000000002	47.889251000000002	41.378833999999998	41.363534000000001	0103000020E61000000100000005000000D4D688601CF04740F67D384888AE4440D4D688601CF04740724EECA17DB04440B8770DFAD2F14740724EECA17DB04440B8770DFAD2F14740F67D384888AE4440D4D688601CF04740F67D384888AE4440
53800	Куруш	8	75	1407	47.705806000000003	48.018231	41.480995999999998	41.185778999999997	0103000020E6100000010000000500000009A9DBD957DA47404CA4349BC797444009A9DBD957DA4740DFC0E44691BD4440FE62B66455024840DFC0E44691BD4440FE62B664550248404CA4349BC797444009A9DBD957DA47404CA4349BC7974440
53569	Килер	8	75	1407	47.897165000000001	47.910333999999999	41.387737999999999	41.374625000000002	0103000020E61000000100000005000000D40E7F4DD6F24740CBA145B6F3AF4440D40E7F4DD6F247404EB51666A1B14440EB3713D385F447404EB51666A1B14440EB3713D385F44740CBA145B6F3AF4440D40E7F4DD6F24740CBA145B6F3AF4440
15802	Кара-Кюре	8	75	1407	47.954289000000003	47.965741999999999	41.424962999999998	41.412730000000003	0103000020E610000001000000050000005EF7562426FA4740FF092E56D4B444405EF7562426FA47404981053065B64440D32F116F9DFB47404981053065B64440D32F116F9DFB4740FF092E56D4B444405EF7562426FA4740FF092E56D4B44440
15750	Каладжух	8	75	1407	47.902096999999998	47.913074000000002	41.369936000000003	41.362904999999998	0103000020E61000000100000005000000EC681CEA77F347400647C9AB73AE4440EC681CEA77F3474079CE16105AAF4440F969DC9BDFF4474079CE16105AAF4440F969DC9BDFF447400647C9AB73AE4440EC681CEA77F347400647C9AB73AE4440
53495	Авадан	8	75	1407	47.705806000000003	48.018231	41.480995999999998	41.185778999999997	0103000020E6100000010000000500000009A9DBD957DA47404CA4349BC797444009A9DBD957DA4740DFC0E44691BD4440FE62B66455024840DFC0E44691BD4440FE62B664550248404CA4349BC797444009A9DBD957DA47404CA4349BC7974440
12800	Чинар	8	75	1122	48.135415999999999	48.150427000000001	42.113784000000003	42.101931	0103000020E6100000010000000500000075ADBD4F551148406BB933130C0D454075ADBD4F551148406F675F79900E4540BBB72231411348406F675F79900E4540BBB72231411348406BB933130C0D454075ADBD4F551148406BB933130C0D4540
13187	Хазар	8	75	1122	48.332417	48.337249	42.003213000000002	42.000357999999999	0103000020E6100000010000000500000035D1E7A38C2A48405F251FBB0B00454035D1E7A38C2A484006F6984869004540EACDA8F92A2B484006F6984869004540EACDA8F92A2B48405F251FBB0B00454035D1E7A38C2A48405F251FBB0B004540
53760	Уллутеркеме	8	75	1122	48.003382000000002	48.010649000000001	42.218539999999997	42.210807000000003	0103000020E6100000010000000500000092B245D26E0048404A6249B9FB1A454092B245D26E004840156F641EF91B4540185E49F25C014840156F641EF91B4540185E49F25C0148404A6249B9FB1A454092B245D26E0048404A6249B9FB1A4540
12196	Татляр	8	75	1122	48.017502999999998	48.030088999999997	42.205117000000001	42.193795000000001	0103000020E610000001000000050000007B4ACE893D0248406D904946CE1845407B4ACE893D024840446D1B46411A4540137CD3F4D9034840446D1B46411A4540137CD3F4D90348406D904946CE1845407B4ACE893D0248406D904946CE184540
12361	Салик	8	75	1122	48.076746999999997	48.092333000000004	42.180720999999998	42.172080999999999	0103000020E6100000010000000500000076887FD8D2094840A9A10DC00616454076887FD8D2094840A759A0DD21174540B9AB5791D10B4840A759A0DD21174540B9AB5791D10B4840A9A10DC00616454076887FD8D2094840A9A10DC006164540
12944	Сабнова	8	75	1122	48.242584999999998	48.259824000000002	42.086362000000001	42.058123999999999	0103000020E6100000010000000500000005C078060D1F48406D8E739B7007454005C078060D1F4840FFCEF6E80D0B4540A35BAFE941214840FFCEF6E80D0B4540A35BAFE9412148406D8E739B7007454005C078060D1F48406D8E739B70074540
53943	Рыбзавод - 51	8	75	1122	47.983592000000002	48.486198999999999	42.323594	41.814095999999999	0103000020E61000000100000005000000BA4DB857E6FD4740F7E6374C34E84440BA4DB857E6FD4740469737876B294540882CD2C43B3E4840469737876B294540882CD2C43B3E4840F7E6374C34E84440BA4DB857E6FD4740F7E6374C34E84440
13113	Рукель	8	75	1122	48.216839	48.230071000000002	41.990842999999998	41.980916999999998	0103000020E61000000100000005000000A9BF5E61C11B4840938B31B08EFD4440A9BF5E61C11B48403A3C84F1D3FE444007616EF7721D48403A3C84F1D3FE444007616EF7721D4840938B31B08EFD4440A9BF5E61C11B4840938B31B08EFD4440
13324	Рубас	8	75	1122	48.318762	48.336764000000002	41.899729000000001	41.884540000000001	0103000020E61000000100000005000000919A7631CD2848407E00529B38F14440919A7631CD284840A321E3512AF344402E3C2F151B2B4840A321E3512AF344402E3C2F151B2B48407E00529B38F14440919A7631CD2848407E00529B38F14440
12426	Падар	8	75	1122	48.046573000000002	48.063496999999998	42.205424000000001	42.195892999999998	0103000020E6100000010000000500000035F0A31AF6054840F64196051319454035F0A31AF605484021E868554B1A4540723271AB2008484021E868554B1A4540723271AB20084840F64196051319454035F0A31AF6054840F641960513194540
13769	Нюгди	8	75	1122	48.427197999999997	48.439064999999999	41.864337999999996	41.856245000000001	0103000020E6100000010000000500000053758F6CAE364840882EA86F99ED444053758F6CAE3648405358A9A0A2EE4440BCE82B48333848405358A9A0A2EE4440BCE82B4833384840882EA86F99ED444053758F6CAE364840882EA86F99ED4440
53725	Новофриг	8	75	1122	48.349341000000003	48.362392999999997	41.857978000000003	41.845894999999999	0103000020E610000001000000050000007313B534B72C4840CA6C904946EC44407313B534B72C484000581D39D2ED444050A6D1E4622E484000581D39D2ED444050A6D1E4622E4840CA6C904946EC44407313B534B72C4840CA6C904946EC4440
53441	Нижний Джалган	8	75	1122	47.983592000000002	48.486198999999999	42.323594	41.814095999999999	0103000020E61000000100000005000000BA4DB857E6FD4740F7E6374C34E84440BA4DB857E6FD4740469737876B294540882CD2C43B3E4840469737876B294540882CD2C43B3E4840F7E6374C34E84440BA4DB857E6FD4740F7E6374C34E84440
13283	Музаим	8	75	1122	48.279505999999998	48.291677999999997	41.916418	41.903990999999998	0103000020E61000000100000005000000948444DAC62348406D7022FAB5F34440948444DAC62348409DBB5D2F4DF54440397B67B4552548409DBB5D2F4DF54440397B67B4552548406D7022FAB5F34440948444DAC62348406D7022FAB5F34440
13092	Мугарты	8	75	1122	48.149942000000003	48.164135000000002	41.999467000000003	41.987243999999997	0103000020E61000000100000005000000FF25A94C311348400B96EA025EFE4440FF25A94C311348403337DF88EEFF444082902C60021548403337DF88EEFF444082902C60021548400B96EA025EFE4440FF25A94C311348400B96EA025EFE4440
12843	Митаги-Казмаляр	8	75	1122	48.199312999999997	48.206328999999997	42.039470999999999	42.031019000000001	0103000020E610000001000000050000007555A01683194840FE463B6EF80345407555A01683194840F911BF620D054540B29B19FD681A4840F911BF620D054540B29B19FD681A4840FE463B6EF80345407555A01683194840FE463B6EF8034540
12868	Митаги	8	75	1122	48.187105000000003	48.194111999999997	42.020007999999997	42.013711000000001	0103000020E6100000010000000500000084F57F0EF3174840384C3448C101454084F57F0EF317484045D4449F8F0245406DE179A9D818484045D4449F8F0245406DE179A9D8184840384C3448C101454084F57F0EF3174840384C3448C1014540
12527	Мамедкала	8	75	1122	48.103140000000003	48.160398000000001	42.186673999999996	42.160687000000003	0103000020E61000000100000005000000697407B1330D484039F2406491144540697407B1330D4840BA8102EFE4174540022CF2EB87144840BA8102EFE4174540022CF2EB8714484039F2406491144540697407B1330D484039F2406491144540
53487	Мамедкала	8	75	1122	48.103140000000003	48.160398000000001	42.186673999999996	42.160687000000003	0103000020E61000000100000005000000697407B1330D484039F2406491144540697407B1330D4840BA8102EFE4174540022CF2EB87144840BA8102EFE4174540022CF2EB8714484039F2406491144540697407B1330D484039F2406491144540
13832	Куллар	8	75	1122	48.382227999999998	48.397410000000001	41.838889000000002	41.823208000000001	0103000020E61000000100000005000000C8CEDBD8EC3048401DE736E15EE94440C8CEDBD8EC304840B1FCF9B660EB44403B8DB454DE324840B1FCF9B660EB44403B8DB454DE3248401DE736E15EE94440C8CEDBD8EC3048401DE736E15EE94440
13385	Коммуна	8	75	1122	48.294319000000002	48.315671999999999	41.884365000000003	41.874442999999999	0103000020E61000000100000005000000B4CBB73EAC254840AA9B8BBFEDEF4440B4CBB73EAC254840105D50DF32F14440A721AAF067284840105D50DF32F14440A721AAF067284840AA9B8BBFEDEF4440B4CBB73EAC254840AA9B8BBFEDEF4440
12124	Карадаглы	8	75	1122	48.031633999999997	48.041767	42.195472000000002	42.189700000000002	0103000020E6100000010000000500000088B839950C0448408E06F0164818454088B839950C04484051A4FB3905194540A986FD9E5805484051A4FB3905194540A986FD9E580548408E06F0164818454088B839950C0448408E06F01648184540
12319	Кала	8	75	1122	48.101036999999998	48.122112000000001	42.164430000000003	42.155059000000001	0103000020E61000000100000005000000CD57C9C7EE0C4840A9F92AF9D8134540CD57C9C7EE0C48409B3DD00A0C1545407E39B35DA10F48409B3DD00A0C1545407E39B35DA10F4840A9F92AF9D8134540CD57C9C7EE0C4840A9F92AF9D8134540
12240	Имени Мичурина	8	75	1122	48.191139	48.207120000000003	42.183781000000003	42.175308999999999	0103000020E61000000100000005000000BDFE243E77184840E4D87A8670164540BDFE243E771848402750C422861745407C2C7DE8821A48402750C422861745407C2C7DE8821A4840E4D87A8670164540BDFE243E77184840E4D87A8670164540
12927	Зидьян-Казмаляр	8	75	1122	48.150094000000003	48.159041999999999	42.081992	42.074069000000001	0103000020E61000000100000005000000B5A9BA4736134840DF52CE177B094540B5A9BA47361348404E44BFB67E0A45406058FE7C5B1448404E44BFB67E0A45406058FE7C5B144840DF52CE177B094540B5A9BA4736134840DF52CE177B094540
53519	Дюзляр	8	75	1122	47.983592000000002	48.486198999999999	42.323594	41.814095999999999	0103000020E61000000100000005000000BA4DB857E6FD4740F7E6374C34E84440BA4DB857E6FD4740469737876B294540882CD2C43B3E4840469737876B294540882CD2C43B3E4840F7E6374C34E84440BA4DB857E6FD4740F7E6374C34E84440
11930	Джемикент	8	75	1122	48.031364000000004	48.052807000000001	42.244456	42.229917	0103000020E61000000100000005000000C9224DBC03044840B0E595EB6D1D4540C9224DBC03044840CEA78E554A1F4540FCFF3861C2064840CEA78E554A1F4540FCFF3861C2064840B0E595EB6D1D4540C9224DBC03044840B0E595EB6D1D4540
12997	Джалган	8	75	1122	48.258493999999999	48.266229000000003	42.027925000000003	42.022165000000001	0103000020E610000001000000050000002A1BD65416214840D40E7F4DD60245402A1BD65416214840D3DEE00B93034540971FB8CA13224840D3DEE00B93034540971FB8CA13224840D40E7F4DD60245402A1BD65416214840D40E7F4DD6024540
10204	Деличобан	8	75	1122	48.089619999999996	48.099294999999998	42.205022999999997	42.196019999999997	0103000020E61000000100000005000000A4880CAB780B484053AEF02E17194540A4880CAB780B4840C2F693313E1A454002D4D4B2B50C4840C2F693313E1A454002D4D4B2B50C484053AEF02E17194540A4880CAB780B484053AEF02E17194540
12645	Геджух	8	75	1122	48.051963000000001	48.074393000000001	42.136020000000002	42.118820999999997	0103000020E6100000010000000500000010CD3CB9A6064840FC89CA86350F454010CD3CB9A60648400CCD751A691145409206B7B5850948400CCD751A691145409206B7B585094840FC89CA86350F454010CD3CB9A6064840FC89CA86350F4540
11984	Великент	8	75	1122	48.055385000000001	48.071841999999997	42.193615000000001	42.178322000000001	0103000020E6100000010000000500000030D80DDB1607484023145B41D316454030D80DDB16074840ED815660C8184540573D601E32094840ED815660C8184540573D601E3209484023145B41D316454030D80DDB1607484023145B41D3164540
53891	Бильгады	8	75	1122	48.131220999999996	48.138694999999998	42.088763999999998	42.081744999999998	0103000020E6100000010000000500000032C687D9CB10484046CEC29E760A454032C687D9CB104840F487669E5C0B4540328FFCC1C0114840F487669E5C0B4540328FFCC1C011484046CEC29E760A454032C687D9CB10484046CEC29E760A4540
12451	Берикей	8	75	1122	48.051513	48.083907000000004	42.234242999999999	42.215674999999997	0103000020E61000000100000005000000D0285DFA970648404BC8073D9B1B4540D0285DFA970648409128B4ACFB1D4540E773EE76BD0A48409128B4ACFB1D4540E773EE76BD0A48404BC8073D9B1B4540D0285DFA970648404BC8073D9B1B4540
13490	Белиджи	8	75	1122	48.369104	48.413094000000001	41.890675000000002	41.858139000000001	0103000020E610000001000000050000005169C4CC3E2F48400936AE7FD7ED44405169C4CC3E2F4840B22E6EA301F244404016A243E0344840B22E6EA301F244404016A243E03448400936AE7FD7ED44405169C4CC3E2F48400936AE7FD7ED4440
53600	Белиджи	8	75	1122	48.369104	48.413094000000001	41.890675000000002	41.858139000000001	0103000020E610000001000000050000005169C4CC3E2F48400936AE7FD7ED44405169C4CC3E2F4840B22E6EA301F244404016A243E0344840B22E6EA301F244404016A243E03448400936AE7FD7ED44405169C4CC3E2F48400936AE7FD7ED4440
13754	Белиджи	8	75	1122	48.402692000000002	48.419893999999999	41.894815999999999	41.886136999999998	0103000020E61000000100000005000000302E55698B3348404563EDEF6CF14440302E55698B33484001F8A75489F24440B0E42A16BF35484001F8A75489F24440B0E42A16BF3548404563EDEF6CF14440302E55698B3348404563EDEF6CF14440
30645	Арабляр	8	75	1122	48.351362000000002	48.379524000000004	41.953940000000003	41.927669000000002	0103000020E610000001000000050000005187156EF92C4840AB4198DBBDF644405187156EF92C4840522CB7B41AFA44400806103E94304840522CB7B41AFA44400806103E94304840AB4198DBBDF644405187156EF92C4840AB4198DBBDF64440
53559	Араблинский	8	75	1122	48.324278	48.336917	41.969555	41.962026000000002	0103000020E61000000100000005000000F96706F1812948406BF3FFAA23FB4440F96706F1812948402E56D4601AFC4440B43BA418202B48402E56D4601AFC4440B43BA418202B48406BF3FFAA23FB4440F96706F1812948406BF3FFAA23FB4440
53770	Аладаш	8	75	1122	48.351756999999999	48.357776000000001	41.908969999999997	41.90446	0103000020E61000000100000005000000CD91955F062D484024456458C5F34440CD91955F062D4840C685032159F4444098A59D9ACB2D4840C685032159F4444098A59D9ACB2D484024456458C5F34440CD91955F062D484024456458C5F34440
13402	Аглоби	8	75	1122	48.337169000000003	48.354469999999999	41.905695000000001	41.895023999999999	0103000020E61000000100000005000000CE1C925A282B48404B917C2590F24440CE1C925A282B48404B9352D0EDF34440E1B4E0455F2D48404B9352D0EDF34440E1B4E0455F2D48404B917C2590F24440CE1C925A282B48404B917C2590F24440
53716	Дербент	8	75	7292	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
10357	Шулерчи	8	75	1047	47.560647000000003	47.565480000000001	42.138995000000001	42.135036999999997	0103000020E61000000100000005000000DECCE847C3C74740FE5F75E448114540DECCE847C3C747405DA79196CA11454063450DA661C847405DA79196CA11454063450DA661C84740FE5F75E448114540DECCE847C3C74740FE5F75E448114540
9977	Шадни	8	75	1047	47.645645999999999	47.652661000000002	42.193621999999998	42.190555000000003	0103000020E6100000010000000500000088653387A4D247406E8B321B6418454088653387A4D247409FE40E9BC8184540F52F49658AD347409FE40E9BC8184540F52F49658AD347406E8B321B6418454088653387A4D247406E8B321B64184540
53618	Чищили	8	75	1047	47.662947000000003	47.673107000000002	42.155614	42.148060999999998	0103000020E610000001000000050000009CFD8172DBD447401268B0A9F31245409CFD8172DBD447405E66D828EB134540B6DAC35E28D647405E66D828EB134540B6DAC35E28D647401268B0A9F31245409CFD8172DBD447401268B0A9F3124540
10057	Цураи	8	75	1047	47.657134999999997	47.663674999999998	42.237507999999998	42.234270000000002	0103000020E610000001000000050000004A07EBFF1CD447408B37328FFC1D45404A07EBFF1CD44740E94482A9661E45401E166A4DF3D44740E94482A9661E45401E166A4DF3D447408B37328FFC1D45404A07EBFF1CD447408B37328FFC1D4540
10040	Цизгари	8	75	1047	47.643768000000001	47.652500000000003	42.225644000000003	42.216824000000003	0103000020E610000001000000050000000D1B65FD66D24740747E8AE3C01B45400D1B65FD66D24740F24410E7E11C4540EC51B81E85D34740F24410E7E11C4540EC51B81E85D34740747E8AE3C01B45400D1B65FD66D24740747E8AE3C01B4540
10481	Хуршни	8	75	1047	47.486418999999998	47.505032	42.148375000000001	42.137036000000002	0103000020E61000000100000005000000969350FA42BE4740F52F49658A114540969350FA42BE4740A245B6F3FD1245407CB779E3A4C04740A245B6F3FD1245407CB779E3A4C04740F52F49658A114540969350FA42BE4740F52F49658A114540
10963	Хулабаркмахи	8	75	1047	47.454546999999998	47.458894999999998	42.055506999999999	42.052447000000001	0103000020E6100000010000000500000059BF99982EBA4740FCE25295B606454059BF99982EBA47407BD976DA1A07454022A64412BDBA47407BD976DA1A07454022A64412BDBA4740FCE25295B606454059BF99982EBA4740FCE25295B6064540
11350	Худуц	8	75	1047	47.509146999999999	47.523375999999999	41.970869	41.962950999999997	0103000020E61000000100000005000000A2ED98BA2BC14740435376FA41FB4440A2ED98BA2BC14740A1D9756F45FC444072C119FCFDC24740A1D9756F45FC444072C119FCFDC24740435376FA41FB4440A2ED98BA2BC14740435376FA41FB4440
10435	Харбук	8	75	1047	47.52413	47.537937999999997	42.162398000000003	42.151603000000001	0103000020E610000001000000050000001E6D1CB116C34740DD7C23BA671345401E6D1CB116C34740C9772975C914454048A30227DBC44740C9772975C914454048A30227DBC44740DD7C23BA671345401E6D1CB116C34740DD7C23BA67134540
11700	Урцаки	8	75	1047	47.561087000000001	47.565919999999998	42.100659999999998	42.096164000000002	0103000020E61000000100000005000000FA9AE5B2D1C74740BA86191A4F0C4540FA9AE5B2D1C74740F701486DE20C45407F130A1170C84740F701486DE20C45407F130A1170C84740BA86191A4F0C4540FA9AE5B2D1C74740BA86191A4F0C4540
53876	Урхнища	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
53932	Уркудта	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
9178	Уркарах	8	75	1047	47.620914999999997	47.640965000000001	42.174748000000001	42.152599000000002	0103000020E61000000100000005000000444C89247ACF47407F33315D88134540444C89247ACF47404D8578245E164540B97020240BD247404D8578245E164540B97020240BD247407F33315D88134540444C89247ACF47407F33315D88134540
10646	Урари	8	75	1047	47.453316000000001	47.459110000000003	42.101396000000001	42.096532000000003	0103000020E610000001000000050000007460394206BA47403D821B295B0C45407460394206BA4740FDF84B8BFA0C45401FA2D11DC4BA4740FDF84B8BFA0C45401FA2D11DC4BA47403D821B295B0C45407460394206BA47403D821B295B0C4540
11554	Ураги	8	75	1047	47.564680000000003	47.570951000000001	42.068626999999999	42.062690000000003	0103000020E61000000100000005000000475A2A6F47C84740A4E4D53906084540475A2A6F47C84740B14F00C5C80845402B4F20EC14C94740B14F00C5C80845402B4F20EC14C94740A4E4D53906084540475A2A6F47C84740A4E4D53906084540
9451	Трисанчи	8	75	1047	47.700578	47.714097000000002	42.121904000000001	42.112713999999997	0103000020E610000001000000050000000726378AACD9474092E68F696D0E45400726378AACD9474034A0DE8C9A0F4540FB95CE8767DB474034A0DE8C9A0F4540FB95CE8767DB474092E68F696D0E45400726378AACD9474092E68F696D0E4540
11750	Сутбук	8	75	1047	47.536203999999998	47.541037000000003	42.105176	42.101215000000003	0103000020E6100000010000000500000000FE2955A2C44740AD6EF59CF40C454000FE2955A2C447407C293C68760D454086764EB340C547407C293C68760D454086764EB340C54740AD6EF59CF40C454000FE2955A2C44740AD6EF59CF40C4540
53751	Новый Уркарах	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
53596	Морское	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
53883	Мирзидты	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
10164	Меусиша	8	75	1047	47.590004	47.598708999999999	42.205016999999998	42.196013000000001	0103000020E610000001000000050000002D41464085CB4740A14B38F4161945402D41464085CB4740E00F3FFF3D1A454012691B7FA2CC4740E00F3FFF3D1A454012691B7FA2CC4740A14B38F4161945402D41464085CB4740A14B38F416194540
11187	Кунки	8	75	1047	47.469351000000003	47.478037999999998	41.961523	41.957379000000003	0103000020E6100000010000000500000026AC8DB113BC4740487023658BFA444026AC8DB113BC474008AD872F13FB4440641F645930BD474008AD872F13FB4440641F645930BD4740487023658BFA444026AC8DB113BC4740487023658BFA4440
9636	Кудагу	8	75	1047	47.726494000000002	47.733015999999999	42.135719000000002	42.131573000000003	0103000020E61000000100000005000000C05E61C1FDDC4740B0045262D7104540C05E61C1FDDC474011397D3D5F114540EDB8E177D3DD474011397D3D5F114540EDB8E177D3DD4740B0045262D7104540C05E61C1FDDC4740B0045262D7104540
11596	Кубачи	8	75	1047	47.592492	47.612290999999999	42.097575999999997	42.080835	0103000020E61000000100000005000000219221C7D6CB4740A3AF20CD580A4540219221C7D6CB4740EF6FD05E7D0C45404C512E8D5FCE4740EF6FD05E7D0C45404C512E8D5FCE4740A3AF20CD580A4540219221C7D6CB4740A3AF20CD580A4540
10988	Кищамахи	8	75	1047	47.439580999999997	47.443928999999997	42.054595999999997	42.049019000000001	0103000020E61000000100000005000000B378B13044B84740FAF02C4146064540B378B13044B84740073F7100FD0645407C5F5CAAD2B84740073F7100FD0645407C5F5CAAD2B84740FAF02C4146064540B378B13044B84740FAF02C4146064540
10291	Кища	8	75	1047	47.573743999999998	47.592852000000001	42.180914999999999	42.167048999999999	0103000020E610000001000000050000005B23827170C947402DEA93DC611545405B23827170C947408C2D04392817454021AF0793E2CB47408C2D04392817454021AF0793E2CB47402DEA93DC611545405B23827170C947402DEA93DC61154540
53794	Карбучимахи	8	75	1047	47.427553000000003	47.435045000000002	42.011037999999999	42.004379	0103000020E610000001000000050000004227840EBAB6474004E5B67D8F0045404227840EBAB64740B28174B169014540E8A4F78DAFB74740B28174B169014540E8A4F78DAFB7474004E5B67D8F0045404227840EBAB6474004E5B67D8F004540
9811	Калкни	8	75	1047	47.700048000000002	47.708258000000001	42.180387000000003	42.173724999999997	0103000020E61000000100000005000000ABD0402C9BD94740B1BFEC9E3C164540ABD0402C9BD94740D1CFD4EB16174540B090B932A8DA4740D1CFD4EB16174540B090B932A8DA4740B1BFEC9E3C164540ABD0402C9BD94740B1BFEC9E3C164540
53575	Ицари	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
9705	Ираки	8	75	1047	47.713540000000002	47.719819000000001	42.166147000000002	42.159671000000003	0103000020E61000000100000005000000A5315A4755DB4740508F6D1970144540A5315A4755DB47400DAA0D4E441545400C056C0723DC47400DAA0D4E441545400C056C0723DC4740508F6D1970144540A5315A4755DB4740508F6D1970144540
9661	Ираги	8	75	1047	47.753748999999999	47.758833000000003	42.123061	42.116940999999997	0103000020E610000001000000050000004432E4D87AE04740E04735ECF70E45404432E4D87AE04740DF347D76C00F45401310937021E14740DF347D76C00F45401310937021E14740E04735ECF70E45404432E4D87AE04740E04735ECF70E4540
9518	Зубанчи	8	75	1047	47.699894999999998	47.710531000000003	42.137197	42.130189000000001	0103000020E6100000010000000500000024D1CB2896D9474044A67C08AA10454024D1CB2896D94740FE0DDAAB8F114540A8E507AEF2DA4740FE0DDAAB8F114540A8E507AEF2DA474044A67C08AA10454024D1CB2896D9474044A67C08AA104540
9547	Зильбачи	8	75	1047	47.716594000000001	47.722639999999998	42.144430999999997	42.136809	0103000020E610000001000000050000004241295AB9DB4740346612F5821145404241295AB9DB4740A8C30AB77C1245400664AF777FDC4740A8C30AB77C1245400664AF777FDC4740346612F5821145404241295AB9DB4740346612F582114540
10922	Дуакар	8	75	1047	47.457447999999999	47.461787000000001	42.064684999999997	42.061444999999999	0103000020E6100000010000000500000070CFF3A78DBA474059C0046EDD07454070CFF3A78DBA474058C51B9947084540E65B1FD61BBB474058C51B9947084540E65B1FD61BBB474059C0046EDD07454070CFF3A78DBA474059C0046EDD074540
53521	Дирбакмахи	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
9778	Дибгаши	8	75	1047	47.687902000000001	47.702427999999998	42.167256999999999	42.159717999999998	0103000020E610000001000000050000002F6D382C0DD84740904AB1A3711445402F6D382C0DD84740778368AD68154540B8E52329E9D94740778368AD68154540B8E52329E9D94740904AB1A3711445402F6D382C0DD84740904AB1A371144540
9352	Дибгалик	8	75	1047	47.650298999999997	47.657791000000003	42.122532	42.113703999999998	0103000020E610000001000000050000008DCF64FF3CD3474052B648DA8D0E45408DCF64FF3CD34740535BEA20AF0F4540344DD87E32D44740535BEA20AF0F4540344DD87E32D4474052B648DA8D0E45408DCF64FF3CD3474052B648DA8D0E4540
11465	Дзилебки	8	75	1047	47.554519999999997	47.560315000000003	42.051175000000001	42.046140000000001	0103000020E610000001000000050000002C7DE882FAC64740CB845FEAE70545402C7DE882FAC64740B8AF03E78C064540A83AE466B8C74740B8AF03E78C064540A83AE466B8C74740CB845FEAE70545402C7DE882FAC64740CB845FEAE7054540
9431	Джурмачи	8	75	1047	47.693219999999997	47.699984999999998	42.094686000000003	42.090356999999997	0103000020E610000001000000050000007077D66EBBD847407AFB73D1900B45407077D66EBBD84740CDB1BCAB1E0C45406458C51B99D94740CDB1BCAB1E0C45406458C51B99D947407AFB73D1900B45407077D66EBBD847407AFB73D1900B4540
9879	Гунакари	8	75	1047	47.686985999999997	47.695681999999998	42.180593999999999	42.176631999999998	0103000020E61000000100000005000000A9674128EFD74740AAB69BE09B164540A9674128EFD747404AED45B41D1745403B35971B0CD947404AED45B41D1745403B35971B0CD94740AAB69BE09B164540A9674128EFD74740AAB69BE09B164540
10574	Гуладты	8	75	1047	47.442670999999997	47.455238999999999	42.117770999999998	42.111831000000002	0103000020E610000001000000050000009DF17D71A9B84740E9D66B7A500E45409DF17D71A9B8474067B5C01E130F45408F6E844545BA474067B5C01E130F45408F6E844545BA4740E9D66B7A500E45409DF17D71A9B84740E9D66B7A500E4540
53590	Губа-Кутан	8	75	1047	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
9911	Бускри	8	75	1047	47.665669000000001	47.674624999999999	42.175403000000003	42.165872999999998	0103000020E61000000100000005000000037B4CA434D547400B2593533B154540037B4CA434D54740664F029B731645403108AC1C5AD64740664F029B731645403108AC1C5AD647400B2593533B154540037B4CA434D547400B2593533B154540
11797	Бакни	8	75	1047	47.522917999999997	47.533310999999998	42.117597000000004	42.113636999999997	0103000020E61000000100000005000000AF3E1EFAEEC24740CA4E3FA88B0E4540AF3E1EFAEEC24740CA8D226B0D0F45406CCCEB8843C44740CA8D226B0D0F45406CCCEB8843C44740CA4E3FA88B0E4540AF3E1EFAEEC24740CA4E3FA88B0E4540
10664	Аяцури	8	75	1047	47.448501	47.457925000000003	42.074939000000001	42.070622	0103000020E61000000100000005000000959C137B68B94740663046240A094540959C137B68B94740F418E59997094540AA8251499DBA4740F418E59997094540AA8251499DBA4740663046240A094540959C137B68B94740663046240A094540
11184	Аяцимахи	8	75	1047	47.459173	47.463754999999999	42.007092	42.002951000000003	0103000020E61000000100000005000000651A4D2EC6BA4740C93EC8B260004540651A4D2EC6BA474018080264E8004540A12DE7525CBB474018080264E8004540A12DE7525CBB4740C93EC8B260004540651A4D2EC6BA4740C93EC8B260004540
11268	Ашты	8	75	1047	47.490803	47.507205999999996	41.962777000000003	41.912030000000001	0103000020E61000000100000005000000ACE3F8A1D2BE4740467C2766BDF44440ACE3F8A1D2BE4740A62BD8463CFB4440E02A4F20ECC04740A62BD8463CFB4440E02A4F20ECC04740467C2766BDF44440ACE3F8A1D2BE4740467C2766BDF44440
53832	Шулани	8	75	870	46.926462999999998	46.934243000000002	42.310313999999998	42.304732999999999	0103000020E610000001000000050000001EFAEE56967647408881AE7D012745401EFAEE5696764740D7BE805EB82745402BC24D4695774740D7BE805EB82745402BC24D46957747408881AE7D012745401EFAEE56967647408881AE7D01274540
7728	Хутни	8	75	870	46.951265999999997	46.955883	42.350360000000002	42.347295000000003	0103000020E61000000100000005000000FBE59315C37947403C889D29742C4540FBE59315C3794740CDE9B298D82C4540B4E6C75F5A7A4740CDE9B298D82C4540B4E6C75F5A7A47403C889D29742C4540FBE59315C37947403C889D29742C4540
8078	Хоточ	8	75	870	46.948535	46.958488000000003	42.410488000000001	42.404542999999997	0103000020E61000000100000005000000410E4A9869794740B169A510C8334540410E4A986979474042B3EBDE8A344540E2CD1ABCAF7A474042B3EBDE8A344540E2CD1ABCAF7A4740B169A510C8334540410E4A9869794740B169A510C8334540
8011	Хиндах	8	75	870	46.963788000000001	46.979095999999998	42.405341	42.395826999999997	0103000020E610000001000000050000007D23BA675D7B4740D8EF8975AA3245407D23BA675D7B47402D5DC136E23345407CD28904537D47402D5DC136E23345407CD28904537D4740D8EF8975AA3245407D23BA675D7B4740D8EF8975AA324540
53870	Унты	8	75	870	46.944178000000001	46.951453999999998	42.312033999999997	42.305199000000002	0103000020E6100000010000000500000025CD1FD3DA784740CEE2C5C21027454025CD1FD3DA784740BA9EE8BAF0274540FED2A23EC9794740BA9EE8BAF0274540FED2A23EC9794740CEE2C5C21027454025CD1FD3DA784740CEE2C5C210274540
7356	Тлогоб	8	75	870	46.810364999999997	46.818629999999999	42.422662000000003	42.416725	0103000020E610000001000000050000005969520ABA6747407A36AB3E573545405969520ABA67474088A1D5C91936454022C32ADEC868474088A1D5C91936454022C32ADEC86847407A36AB3E573545405969520ABA6747407A36AB3E57354540
32885	Согратль	8	75	870	46.986182999999997	46.997537999999999	42.287559999999999	42.278381000000003	0103000020E61000000100000005000000826F9A3E3B7E4740F56915FDA1234540826F9A3E3B7E4740A2D11DC4CE24454035423F53AF7F4740A2D11DC4CE24454035423F53AF7F4740F56915FDA1234540826F9A3E3B7E4740F56915FDA1234540
53669	Силта	8	75	870	47.065207999999998	47.072978999999997	42.388423000000003	42.384647000000001	0103000020E6100000010000000500000002B859BC5888474094C0E61C3C31454002B859BC58884740D20149D8B7314540BB25396057894740D20149D8B7314540BB2539605789474094C0E61C3C31454002B859BC5888474094C0E61C3C314540
7790	Салта	8	75	870	47.065145000000001	47.074865000000003	42.398684000000003	42.392924000000001	0103000020E61000000100000005000000BC3FDEAB5688474021E868554B324540BC3FDEAB5688474020B8CA1308334540BA4E232D9589474020B8CA1308334540BA4E232D9589474021E868554B324540BC3FDEAB5688474021E868554B324540
32853	Ругуджа	8	75	870	46.909350000000003	46.921495999999998	42.364724000000002	42.358262000000003	0103000020E610000001000000050000000E4FAF946574474025B37A87DB2D45400E4FAF94657447407D08AA46AF2E454089B2B794F37547407D08AA46AF2E454089B2B794F375474025B37A87DB2D45400E4FAF946574474025B37A87DB2D4540
7591	Обох	8	75	870	47.034368999999998	47.040180999999997	42.288406999999999	42.281196000000001	0103000020E61000000100000005000000847F1134668447400DE2033BFE234540847F113466844740FF774485EA244540D575A8A624854740FF774485EA244540D575A8A6248547400DE2033BFE234540847F1134668447400DE2033BFE234540
7944	Наказух	8	75	870	46.904840999999998	46.916491999999998	42.266105000000003	42.260005999999997	0103000020E610000001000000050000003B8A73D4D1734740C36169E0472145403B8A73D4D1734740AB2688BA0F224540D7851F9C4F754740AB2688BA0F224540D7851F9C4F754740C36169E0472145403B8A73D4D1734740C36169E047214540
53622	Н.Кегер	8	75	870	46.745893000000002	47.117499000000002	42.497798000000003	42.177593999999999	0103000020E610000001000000050000005DA8FC6B795F4740A0FB7266BB1645405DA8FC6B795F4740D20149D8B73F454007280D350A8F4740D20149D8B73F454007280D350A8F4740A0FB7266BB1645405DA8FC6B795F4740A0FB7266BB164540
7485	Мегеб	8	75	870	47.037765	47.051096000000001	42.257117000000001	42.247225999999998	0103000020E610000001000000050000007BF7C77BD5844740465C001AA51F45407BF7C77BD5844740711FB935E92045406C7A50508A864740711FB935E92045406C7A50508A864740465C001AA51F45407BF7C77BD5844740465C001AA51F4540
7208	Кудали	8	75	870	47.068207999999998	47.087145	42.375649000000003	42.363619	0103000020E61000000100000005000000ACA92C0ABB884740249A40118B2E4540ACA92C0ABB88474037E334441530454045813E91278B474037E334441530454045813E91278B4740249A40118B2E4540ACA92C0ABB884740249A40118B2E4540
7052	Корода	8	75	870	46.841661999999999	46.86112	42.457647000000001	42.444715000000002	0103000020E610000001000000050000009A249694BB6B47403485CE6BEC3845409A249694BB6B4740670E492D943A45403CF71E2E396E4740670E492D943A45403CF71E2E396E47403485CE6BEC3845409A249694BB6B47403485CE6BEC384540
53452	Коммуна	8	75	870	46.963051999999998	46.973239	42.372984000000002	42.363086000000003	0103000020E61000000100000005000000772CB649457B474057D11F9A792E4540772CB649457B474034F790F0BD2F45408B187618937C474034F790F0BD2F45408B187618937C474057D11F9A792E4540772CB649457B474057D11F9A792E4540
6916	Кегер	8	75	870	47.021585999999999	47.029581	42.379804999999998	42.373137999999997	0103000020E6100000010000000500000096067E54C38247408A7269FCC22F454096067E54C3824740BBED42739D3045409FCA694FC9834740BBED42739D3045409FCA694FC98347408A7269FCC22F454096067E54C38247408A7269FCC22F4540
7112	Карадах	8	75	870	46.857545000000002	46.869473999999997	42.472552	42.466633000000002	0103000020E6100000010000000500000096ECD808C46D4740001E51A1BA3B454096ECD808C46D474067D47C957C3C4540745C8DEC4A6F474067D47C957C3C4540745C8DEC4A6F4740001E51A1BA3B454096ECD808C46D4740001E51A1BA3B4540
53432	Гуниб	8	75	870	46.952765999999997	46.966115000000002	42.391452000000001	42.382682000000003	0103000020E61000000100000005000000D05E7D3CF47947404A6249B9FB304540D05E7D3CF479474016FA60191B324540689604A8A97B474016FA60191B324540689604A8A97B47404A6249B9FB304540D05E7D3CF47947404A6249B9FB304540
32701	Гонода	8	75	870	46.777800999999997	46.795534000000004	42.475118999999999	42.463214999999998	0103000020E61000000100000005000000E6E5B0FB8E63474021020EA14A3B4540E6E5B0FB8E634740A75A0BB3D03C4540946DE00ED4654740A75A0BB3D03C4540946DE00ED465474021020EA14A3B4540E6E5B0FB8E63474021020EA14A3B4540
6682	Бухты	8	75	870	46.972538	46.988779000000001	42.244396000000002	42.238455999999999	0103000020E61000000100000005000000020F0C207C7C47407AC4E8B9851E4540020F0C207C7C4740F9A23D5E481F45405DFC6D4F907E4740F9A23D5E481F45405DFC6D4F907E47407AC4E8B9851E4540020F0C207C7C47407AC4E8B9851E4540
32667	Бацада	8	75	870	46.903897999999998	46.918171999999998	42.310046999999997	42.297590999999997	0103000020E61000000100000005000000BC75FEEDB2734740BE4A3E7617264540BC75FEEDB2734740889CBE9EAF2745402C0DFCA886754740889CBE9EAF2745402C0DFCA886754740BE4A3E7617264540BC75FEEDB2734740BE4A3E7617264540
53754	Агада	8	75	870	46.745893000000002	47.117499000000002	42.497798000000003	42.177593999999999	0103000020E610000001000000050000005DA8FC6B795F4740A0FB7266BB1645405DA8FC6B795F4740D20149D8B73F454007280D350A8F4740D20149D8B73F454007280D350A8F4740A0FB7266BB1645405DA8FC6B795F4740A0FB7266BB164540
53526	Шпрингель	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
5912	Шабдух	8	75	704	46.418196999999999	46.423082999999998	42.758889000000003	42.753666000000003	0103000020E610000001000000050000008524B37A87354740B70DA320786045408524B37A87354740A7255646236145402D3F709527364740A7255646236145402D3F709527364740B70DA320786045408524B37A87354740B70DA32078604540
6473	Читль	8	75	704	46.495739	46.506860000000003	42.724536999999998	42.718879999999999	0103000020E61000000100000005000000062D2460743F4740CEDF8442045C4540062D2460743F4740F8DEDFA0BD5C454046D3D9C9E0404740F8DEDFA0BD5C454046D3D9C9E0404740CEDF8442045C4540062D2460743F4740CEDF8442045C4540
6541	Чирката	8	75	704	46.698946999999997	46.723148000000002	42.790019000000001	42.780867999999998	0103000020E610000001000000050000009351651877594740183F8D7BF36345409351651877594740FC1BB4571F6545407B15191D905C4740FC1BB4571F6545407B15191D905C4740183F8D7BF36345409351651877594740183F8D7BF3634540
53624	Цияб-Цилитль	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
6153	Цилитль	8	75	704	46.411287999999999	46.423506000000003	42.815049999999999	42.806947999999998	0103000020E610000001000000050000005E9ECE15A53447404BC972124A6745405E9ECE15A53447406A4DF38E5368454074D4D171353647406A4DF38E5368454074D4D171353647404BC972124A6745405E9ECE15A53447404BC972124A674540
5281	Цанатль	8	75	704	46.616230000000002	46.626964999999998	42.725014000000002	42.715640999999998	0103000020E610000001000000050000003468E89FE04E47409F56D11F9A5B45403468E89FE04E474032923D42CD5C45404A5E9D634050474032923D42CD5C45404A5E9D63405047409F56D11F9A5B45403468E89FE04E47409F56D11F9A5B4540
5085	Тлярата	8	75	704	46.525697999999998	46.536451	42.797792999999999	42.792394000000002	0103000020E610000001000000050000004BC972124A434740F8C5A52A6D6545404BC972124A43474026FDBD141E6645400874266DAA44474026FDBD141E6645400874266DAA444740F8C5A52A6D6545404BC972124A434740F8C5A52A6D654540
5267	Тантари	8	75	704	46.642451999999999	46.651130000000002	42.766016999999998	42.759152999999998	0103000020E61000000100000005000000F99FFCDD3B52474084D4EDEC2B614540F99FFCDD3B5247400B9755D80C624540E5B8533A585347400B9755D80C624540E5B8533A5853474084D4EDEC2B614540F99FFCDD3B52474084D4EDEC2B614540
5607	Средний Арадирих	8	75	704	46.575518000000002	46.592244999999998	42.684426999999999	42.672840999999998	0103000020E610000001000000050000003221E692AA494740373465A71F5645403221E692AA494740ECBFCE4D9B574540191C25AFCE4B4740ECBFCE4D9B574540191C25AFCE4B4740373465A71F5645403221E692AA494740373465A71F564540
53923	Первомайск	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
53965	Отавтюбе	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
5398	Новые Аргвани	8	75	704	46.597042000000002	46.612188000000003	42.786822999999998	42.777400999999998	0103000020E61000000100000005000000522B4CDF6B4C474058703FE081634540522B4CDF6B4C4740CC5EB69DB66445407880272D5C4E4740CC5EB69DB66445407880272D5C4E474058703FE081634540522B4CDF6B4C474058703FE081634540
5584	Нижний Арадирих	8	75	704	46.557614999999998	46.573963999999997	42.698058000000003	42.687249999999999	0103000020E610000001000000050000002861A6ED5F4747408716D9CEF75745402861A6ED5F474740085BECF659594540698A00A777494740085BECF659594540698A00A7774947408716D9CEF75745402861A6ED5F4747408716D9CEF7574540
6366	Нижнее Инхо	8	75	704	46.500024000000003	46.508809999999997	42.706710999999999	42.700198	0103000020E61000000100000005000000899B53C900404740C05C8B16A0594540899B53C9004047409A5C8C81755A45405AF0A2AF204147409A5C8C81755A45405AF0A2AF20414740C05C8B16A0594540899B53C900404740C05C8B16A0594540
53602	Нарыш	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
53761	Нанибика	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
4906	Мехельта	8	75	704	46.480234000000003	46.508341999999999	42.803553999999998	42.786096000000001	0103000020E61000000100000005000000B136C64E783D47401AC231CB9E644540B136C64E783D4740F54883DBDA6645407497C45911414740F54883DBDA6645407497C459114147401AC231CB9E644540B136C64E783D47401AC231CB9E644540
53616	Кучкаркум	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
5176	Кунзах	8	75	704	46.646062999999998	46.670749000000001	42.752493999999999	42.738835000000002	0103000020E61000000100000005000000EC134031B2524740F1113125925E4540EC134031B2524740D63730B95160454090696D1ADB554740D63730B95160454090696D1ADB554740F1113125925E4540EC134031B2524740F1113125925E4540
53742	Килятль	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
5923	Ичичали	8	75	704	46.399422000000001	46.408459000000001	42.737980999999998	42.730981	0103000020E61000000100000005000000C6A6954220334740AA7F10C9905D4540C6A6954220334740E1085229765E4540E1606F6248344740E1085229765E4540E1606F6248344740AA7F10C9905D4540C6A6954220334740AA7F10C9905D4540
6059	Ингиши	8	75	704	46.537412000000003	46.548174000000003	42.783925000000004	42.771146999999999	0103000020E610000001000000050000002E3D9AEAC94447404AB4E4F1B46245402E3D9AEAC944474027C286A7576445403E42CD902A46474027C286A7576445403E42CD902A4647404AB4E4F1B46245402E3D9AEAC94447404AB4E4F1B4624540
5149	Игали	8	75	704	46.576920000000001	46.591076999999999	42.732059999999997	42.713335999999998	0103000020E610000001000000050000004434BA83D84947409C8713984E5B45404434BA83D8494740D95A5F24B45D45407A354069A84B4740D95A5F24B45D45407A354069A84B47409C8713984E5B45404434BA83D84947409C8713984E5B4540
5781	Данух	8	75	704	46.623803000000002	46.630890999999998	42.846502000000001	42.840738000000002	0103000020E61000000100000005000000C712D6C6D84F47409240834D9D6B4540C712D6C6D84F4740D2FF722D5A6C45409D2B4A09C1504740D2FF722D5A6C45409D2B4A09C15047409240834D9D6B4540C712D6C6D84F47409240834D9D6B4540
6234	Гадари	8	75	704	46.625940999999997	46.634402999999999	42.815353999999999	42.810274999999997	0103000020E61000000100000005000000DE1CAED51E50474019E25817B7674540DE1CAED51E504740D65416855D684540FDBD141E34514740D65416855D684540FDBD141E3451474019E25817B7674540DE1CAED51E50474019E25817B7674540
53542	Верхний Арадерих	8	75	704	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
53498	Верннее Инхо	8	75	704	46.499054000000001	46.506618000000003	42.710852000000003	42.705272999999998	0103000020E6100000010000000500000010786000E13F47403BE0BA62465A454010786000E13F4740EA25C632FD5A454050C8CEDBD8404740EA25C632FD5A454050C8CEDBD84047403BE0BA62465A454010786000E13F47403BE0BA62465A4540
5372	Аргвани	8	75	704	46.573371999999999	46.584133000000001	42.812615999999998	42.803348999999997	0103000020E610000001000000050000009738F240644947401C23D923D46645409738F24064494740691A14CD03684540D7C1C1DEC44A4740691A14CD03684540D7C1C1DEC44A47401C23D923D46645409738F240644947401C23D923D4664540
4064	Чалда	8	75	609	46.916626999999998	46.925142999999998	42.541829	42.535718000000003	0103000020E61000000100000005000000B7D095085475474074F04C6892444540B7D09508547547401F8315A75A454540C98FF8156B7647401F8315A75A454540C98FF8156B76474074F04C6892444540B7D095085475474074F04C6892444540
4627	Хвартикуни	8	75	609	47.000556000000003	47.011991999999999	42.460368000000003	42.454973000000003	0103000020E6100000010000000500000086E810381280474011C8258E3C3A454086E8103812804740FE0FB056ED3A454025E82FF488814740FE0FB056ED3A454025E82FF48881474011C8258E3C3A454086E810381280474011C8258E3C3A4540
4749	Хварада	8	75	609	46.992013	46.998103999999998	42.470962999999998	42.464118999999997	0103000020E610000001000000050000007A1A3048FA7E4740E2395B40683B45407A1A3048FA7E47402250FD83483C4540DE0033DFC17F47402250FD83483C4540DE0033DFC17F4740E2395B40683B45407A1A3048FA7E4740E2395B40683B4540
53875	Тунзы	8	75	609	46.969385000000003	46.982779000000001	42.473216999999998	42.465801999999996	0103000020E61000000100000005000000D21DC4CE147C4740A83462669F3B4540D21DC4CE147C4740A374E95F923C45400919C8B3CB7D4740A374E95F923C45400919C8B3CB7D4740A83462669F3B4540D21DC4CE147C4740A83462669F3B4540
4482	Мурада	8	75	609	46.933523999999998	46.957814999999997	42.453755999999998	42.442878	0103000020E61000000100000005000000FB03E5B67D774740170FEF39B0384540FB03E5B67D774740902E36AD143A4540224F92AE997A4740902E36AD143A4540224F92AE997A4740170FEF39B0384540FB03E5B67D774740170FEF39B0384540
4313	Могох	8	75	609	46.909475999999998	46.917732000000001	42.565440000000002	42.558228	0103000020E610000001000000050000009A3FA6B56974474012DBDD03744745409A3FA6B569744740D5EC815660484540103FFF3D78754740D5EC815660484540103FFF3D7875474012DBDD03744745409A3FA6B56974474012DBDD0374474540
4281	Маали	8	75	609	46.91554	46.928151999999997	42.491602	42.482959000000001	0103000020E6100000010000000500000005172B6A307547408927BB99D13D454005172B6A30754740F85278D0EC3E4540C6DB4AAFCD764740F85278D0EC3E4540C6DB4AAFCD7647408927BB99D13D454005172B6A307547408927BB99D13D4540
53668	Курми	8	75	609	46.836793	47.202793999999997	42.621499	42.426096000000001	0103000020E61000000100000005000000C84274081C6B47406C7A50508A364540C84274081C6B474094BF7B478D4F45409AE95E27F599474094BF7B478D4F45409AE95E27F59947406C7A50508A364540C84274081C6B47406C7A50508A364540
4209	Кудутль	8	75	609	47.014983000000001	47.023266	42.581169000000003	42.574509999999997	0103000020E610000001000000050000007C7F83F6EA814740CB9C2E8B894945407C7F83F6EA8147407A39ECBE634A4540EB8D5A61FA8247407A39ECBE634A4540EB8D5A61FA824740CB9C2E8B894945407C7F83F6EA814740CB9C2E8B89494540
53574	Кикуни	8	75	609	47.021793000000002	47.037602999999997	42.516947000000002	42.509936000000003	0103000020E610000001000000050000001024EF1CCA824740CB863595454145401024EF1CCA824740F661BD512B424540A19DD32CD0844740F661BD512B424540A19DD32CD0844740CB863595454145401024EF1CCA824740CB86359545414540
4117	Ипута	8	75	609	46.961210000000001	46.974801999999997	42.480998	42.475738	0103000020E61000000100000005000000494BE5ED087B474073BB97FBE43C4540494BE5ED087B474080B8AB57913D4540A609DB4FC67C474080B8AB57913D4540A609DB4FC67C474073BB97FBE43C4540494BE5ED087B474073BB97FBE43C4540
4472	Дарада	8	75	609	46.932409999999997	46.955964000000002	42.467238000000002	42.458371999999997	0103000020E610000001000000050000004F3BFC355977474078B306EFAB3A45404F3BFC355977474067B96C74CE3B4540A11342075D7A474067B96C74CE3B4540A11342075D7A474078B306EFAB3A45404F3BFC355977474078B306EFAB3A4540
4389	Гоцоб	8	75	609	46.864595999999999	46.869016000000002	42.593674999999998	42.588450999999999	0103000020E610000001000000050000004F20EC14AB6E47403526C45C524B45404F20EC14AB6E4740F5B9DA8AFD4B4540B2D991EA3B6F4740F5B9DA8AFD4B4540B2D991EA3B6F47403526C45C524B45404F20EC14AB6E47403526C45C524B4540
53867	Горбони	8	75	609	46.836793	47.202793999999997	42.621499	42.426096000000001	0103000020E61000000100000005000000C84274081C6B47406C7A50508A364540C84274081C6B474094BF7B478D4F45409AE95E27F599474094BF7B478D4F45409AE95E27F59947406C7A50508A364540C84274081C6B47406C7A50508A364540
3876	Гергебиль	8	75	609	47.052774999999997	47.078764	42.510280999999999	42.499799000000003	0103000020E61000000100000005000000F085C954C186474069C9E369F93F4540F085C954C1864740956247E350414540130D52F0148A4740956247E350414540130D52F0148A474069C9E369F93F4540F085C954C186474069C9E369F93F4540
3960	Аймаки	8	75	609	47.126204000000001	47.144547000000003	42.543942000000001	42.528848000000004	0103000020E61000000100000005000000EC4FE273279047400B47904AB1434540EC4FE27327904740DE7536E49F45454012DE1E8480924740DE7536E49F45454012DE1E84809247400B47904AB1434540EC4FE273279047400B47904AB1434540
53479	Эрпели	8	75	223	46.966169000000001	46.996262000000002	42.813667000000002	42.801490000000001	0103000020E610000001000000050000005BB4006DAB7B474018096D39976645405BB4006DAB7B4740CF6A813D26684540B01F6283857F4740CF6A813D26684540B01F6283857F474018096D39976645405BB4006DAB7B474018096D3997664540
2638	Чиркей	8	75	223	46.964390000000002	46.987495000000003	42.974426000000001	42.949559000000001	0103000020E61000000100000005000000734BAB21717B4740AD4F39268B794540734BAB21717B4740A12FBDFDB97C454055FB743C667E4740A12FBDFDB97C454055FB743C667E4740AD4F39268B794540734BAB21717B4740AD4F39268B794540
2586	Чанкурбе	8	75	223	47.29515	47.323895999999998	42.636862000000001	42.624431000000001	0103000020E610000001000000050000000BB5A679C7A54740E6CDE15AED4F45400BB5A679C7A547405708ABB18451454011A7936C75A947405708ABB18451454011A7936C75A94740E6CDE15AED4F45400BB5A679C7A54740E6CDE15AED4F4540
2010	Чабанмахи	8	75	223	47.245725	47.293677000000002	42.641432000000002	42.629618999999998	0103000020E61000000100000005000000A167B3EA739F474059F8FA5A97504540A167B3EA739F4740CF4D9B711A524540304B3B3597A54740CF4D9B711A524540304B3B3597A5474059F8FA5A97504540A167B3EA739F474059F8FA5A97504540
2551	Халимбекаул	8	75	223	47.136040000000001	47.154105000000001	42.848703	42.835197999999998	0103000020E6100000010000000500000053793BC269914740A1D79FC4E76A454053793BC2699147403082C64CA26C454036936FB6B99347403082C64CA26C454036936FB6B9934740A1D79FC4E76A454053793BC269914740A1D79FC4E76A4540
53483	Талги	8	75	223	47.454655000000002	47.467869	42.877654	42.856965000000002	0103000020E6100000010000000500000040FB912232BA474088687407B16D454040FB912232BA47400F9A5DF756704540F7E7A221E3BB47400F9A5DF756704540F7E7A221E3BB474088687407B16D454040FB912232BA474088687407B16D4540
1896	Такалай	8	75	223	47.157347999999999	47.171047999999999	42.905819000000001	42.893039000000002	0103000020E61000000100000005000000A60BB1FA23944740BA86191A4F724540A60BB1FA23944740378C82E0F1734540EA059FE6E4954740378C82E0F1734540EA059FE6E4954740BA86191A4F724540A60BB1FA23944740BA86191A4F724540
1849	Новый Кумух	8	75	223	47.175350999999999	47.193434000000003	42.859985000000002	42.849528999999997	0103000020E610000001000000050000001329CDE6719647407500C45DBD6C45401329CDE67196474079060DFD136E45409DF7FF71C298474079060DFD136E45409DF7FF71C29847407500C45DBD6C45401329CDE6719647407500C45DBD6C4540
1510	Нижний Каранай	8	75	223	46.938868999999997	46.946674999999999	42.851281	42.839937999999997	0103000020E61000000100000005000000361D01DC2C7847407555A016836B4540361D01DC2C784740645A9BC6F66C45406C787AA52C794740645A9BC6F66C45406C787AA52C7947407555A016836B4540361D01DC2C7847407555A016836B4540
2107	Нижний Дженгутай	8	75	223	47.231513	47.258623999999998	42.71058	42.691147000000001	0103000020E61000000100000005000000A7CCCD37A29D474040DD408177584540A7CCCD37A29D474089981249F45A4540F8FA5A971AA1474089981249F45A4540F8FA5A971AA1474040DD408177584540A7CCCD37A29D474040DD408177584540
2244	Нижнее Казанище	8	75	223	47.147475999999997	47.173589999999997	42.771306000000003	42.753188999999999	0103000020E61000000100000005000000F2785A7EE09247407D5A457F68604540F2785A7EE0924740B39AAE27BA624540D174763238964740B39AAE27BA624540D1747632389647407D5A457F68604540F2785A7EE09247407D5A457F68604540
53771	Манасаул	8	75	223	46.636297999999996	47.540992000000003	43.128991999999997	42.579098000000002	0103000020E610000001000000050000004E417E3672514740EA961DE21F4A45404E417E36725147400AB952CF82904540E6B2D1393FC547400AB952CF82904540E6B2D1393FC54740EA961DE21F4A45404E417E3672514740EA961DE21F4A4540
1748	Кафыр-Кумух	8	75	223	47.151698000000003	47.160519000000001	42.841538	42.830748	0103000020E610000001000000050000002F6F0ED76A934740D49B51F3556A45402F6F0ED76A934740AE2B6684B76B45407DB1F7E28B944740AE2B6684B76B45407DB1F7E28B944740D49B51F3556A45402F6F0ED76A934740D49B51F3556A4540
53568	Кара-Махи	8	75	223	47.248168	47.280569999999997	42.624192999999998	42.600955999999996	0103000020E61000000100000005000000F5F411F8C39F4740E02A4F20EC4C4540F5F411F8C39F474031B2648EE54F45408E1EBFB7E9A3474031B2648EE54F45408E1EBFB7E9A34740E02A4F20EC4C4540F5F411F8C39F4740E02A4F20EC4C4540
1736	Кадар	8	75	223	47.281792000000003	47.293945999999998	42.626739999999998	42.611075999999997	0103000020E610000001000000050000002123A0C211A447406CAF05BD374E45402123A0C211A447402A8C2D04395045401F65C405A0A547402A8C2D04395045401F65C405A0A547406CAF05BD374E45402123A0C211A447406CAF05BD374E4540
1544	Дуранги	8	75	223	47.221280999999998	47.230049000000001	42.637227000000003	42.631363999999998	0103000020E61000000100000005000000F31C91EF529C474095EF1989D0504540F31C91EF529C4740699082A7905145401FBDE13E729D4740699082A7905145401FBDE13E729D474095EF1989D0504540F31C91EF529C474095EF1989D0504540
53627	Верхний Каранай	8	75	223	46.897599999999997	46.911309000000003	42.830582999999997	42.820472000000002	0103000020E61000000100000005000000DE718A8EE472474051A4FB3905694540DE718A8EE472474089CE328B506A454076C6F7C5A574474089CE328B506A454076C6F7C5A574474051A4FB3905694540DE718A8EE472474051A4FB3905694540
1391	Верхний Дженгутай	8	75	223	47.228216000000003	47.240622000000002	42.684094999999999	42.668126999999998	0103000020E610000001000000050000004436902E369D47408C497F2F855545404436902E369D4740B62DCA6C905745405C59A2B3CC9E4740B62DCA6C905745405C59A2B3CC9E47408C497F2F855545404436902E369D47408C497F2F85554540
53782	Верхние Ишкарты	8	75	223	46.949109999999997	46.958677000000002	42.858074999999999	42.845120000000001	0103000020E610000001000000050000003D27BD6F7C794740079964E42C6C45403D27BD6F7C794740F241CF66D56D4540B5368DEDB57A4740F241CF66D56D4540B5368DEDB57A4740079964E42C6C45403D27BD6F7C794740079964E42C6C4540
1197	Верхнее Казанище	8	75	223	47.128351000000002	47.143047000000003	42.738537000000001	42.722033000000003	0103000020E6100000010000000500000057B439CE6D904740FFD0CC936B5C454057B439CE6D90474067F16261885E45403D65355D4F92474067F16261885E45403D65355D4F924740FFD0CC936B5C454057B439CE6D904740FFD0CC936B5C4540
1138	Буглен	8	75	223	47.190953999999998	47.202694999999999	42.763548999999998	42.748607999999997	0103000020E610000001000000050000002B85402E7198474011C30E63D25F45402B85402E719847405EF23FF9BB6145400708E6E8F19947405EF23FF9BB6145400708E6E8F199474011C30E63D25F45402B85402E7198474011C30E63D25F4540
1017	Атланаул	8	75	223	47.141125000000002	47.15945	42.807364	42.799942999999999	0103000020E61000000100000005000000F2D24D621092474002D53F8864664540F2D24D6210924740DFFB1BB45767454071AC8BDB68944740DFFB1BB45767454071AC8BDB6894474002D53F8864664540F2D24D621092474002D53F8864664540
854	Аркас	8	75	223	47.132959	47.141978000000002	42.654648000000002	42.649078000000003	0103000020E61000000100000005000000BC5AEECC04914740CC46E7FC14534540BC5AEECC0491474027327381CB5345403160C9552C92474027327381CB5345403160C9552C924740CC46E7FC14534540BC5AEECC04914740CC46E7FC14534540
53572	Акайтала	8	75	223	46.636297999999996	47.540992000000003	43.128991999999997	42.579098000000002	0103000020E610000001000000050000004E417E3672514740EA961DE21F4A45404E417E36725147400AB952CF82904540E6B2D1393FC547400AB952CF82904540E6B2D1393FC54740EA961DE21F4A45404E417E3672514740EA961DE21F4A4540
53707	Агачаул	8	75	223	47.455660999999999	47.465460999999998	42.926240999999997	42.919764000000001	0103000020E610000001000000050000000588821953BA4740E204A6D3BA7545400588821953BA47406F9BA9108F7645401F48DE3994BB47406F9BA9108F7645401F48DE3994BB4740E204A6D3BA7545400588821953BA4740E204A6D3BA754540
53482	участок Чиртинский	8	75	21	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
53451	кутан Старокаратюбинский	8	75	21	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
53887	кутан Прикутанский	8	75	21	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
53966	кутан Комархуторский	8	75	21	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
53477	кутан Джугутский	8	75	21	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
53826	Чанко	8	75	21	46.242235000000001	46.247596999999999	42.721012999999999	42.716329999999999	0103000020E610000001000000050000002979758E011F4740649291B3B05B45402979758E011F4740D47E6B274A5C45403ACB2C42B11F4740D47E6B274A5C45403ACB2C42B11F4740649291B3B05B45402979758E011F4740649291B3B05B4540
53620	Цибилта	8	75	21	46.235802999999997	46.247256	42.743523000000003	42.736676000000003	0103000020E610000001000000050000003BA6EECA2E1E4740C2DF2F664B5E45403BA6EECA2E1E47407369FCC22B5F4540B1DEA815A61F47407369FCC22B5F4540B1DEA815A61F4740C2DF2F664B5E45403BA6EECA2E1E4740C2DF2F664B5E4540
53905	Хелетури	8	75	21	46.221851999999998	46.231113000000001	42.615268999999998	42.608428000000004	0103000020E61000000100000005000000AE4676A5651C474040FCFCF7E04D4540AE4676A5651C47400E9F7422C14E454019575C1C951D47400E9F7422C14E454019575C1C951D474040FCFCF7E04D4540AE4676A5651C474040FCFCF7E04D4540
172	Тлох	8	75	21	46.452655999999998	46.476120000000002	42.679170999999997	42.646332999999998	0103000020E61000000100000005000000492BBEA1F0394740ACA92C0ABB524540492BBEA1F039474020B24813EF5645405B7C0A80F13C474020B24813EF5645405B7C0A80F13C4740ACA92C0ABB524540492BBEA1F0394740ACA92C0ABB524540
31279	Тасута	8	75	21	46.219031000000001	46.230763000000003	42.722397000000001	42.714666999999999	0103000020E61000000100000005000000B4E73235091C4740E54350357A5B4540B4E73235091C474040DD4081775C45403D1059A4891D474040DD4081775C45403D1059A4891D4740E54350357A5B4540B4E73235091C4740E54350357A5B4540
26	Тандо	8	75	21	46.170270000000002	46.181624999999997	42.710222000000002	42.703014000000003	0103000020E61000000100000005000000B6BE4868CB154740A950DD5CFC594540B6BE4868CB1547402A73F38DE85A45406891ED7C3F1747402A73F38DE85A45406891ED7C3F174740A950DD5CFC594540B6BE4868CB154740A950DD5CFC594540
53555	Село Беледи	8	75	21	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
32174	Рушуха	8	75	21	46.279353	46.283988000000001	42.715515000000003	42.712985000000003	0103000020E610000001000000050000000E85CFD6C1234740F0C4AC17435B45400E85CFD6C12347401366DAFE955B45406D3A02B8592447401366DAFE955B45406D3A02B859244740F0C4AC17435B45400E85CFD6C1234740F0C4AC17435B4540
53827	Риквани	8	75	21	46.311619999999998	46.321160999999996	42.784157	42.778028999999997	0103000020E61000000100000005000000C763062AE3274740772B4B7496634540C763062AE3274740F9F6AE415F64454015E0BBCD1B294740F9F6AE415F64454015E0BBCD1B294740772B4B7496634540C763062AE3274740772B4B7496634540
32267	Рахата	8	75	21	46.134230000000002	46.153562000000001	42.694432999999997	42.682060999999997	0103000020E610000001000000050000003012DA722E11474043705CC64D5745403012DA722E114740AF21382EE358454045F46BEBA7134740AF21382EE358454045F46BEBA713474043705CC64D5745403012DA722E11474043705CC64D574540
53880	Ортаколо	8	75	21	46.385866	46.392738000000001	42.673431000000001	42.669578999999999	0103000020E61000000100000005000000B5519D0E64314740508BC1C3B4554540B5519D0E64314740698EACFC32564540BFF2203D45324740698EACFC32564540BFF2203D45324740508BC1C3B4554540B5519D0E64314740508BC1C3B4554540
32197	Нижнее Инхело	8	75	21	46.255600999999999	46.265841999999999	42.648474999999998	42.644143999999997	0103000020E6100000010000000500000096E99788B720474012F5824F7352454096E99788B720474005A3923A015345409DF3531C0722474005A3923A015345409DF3531C0722474012F5824F7352454096E99788B720474012F5824F73524540
53465	Муни	8	75	21	46.304352999999999	46.314602999999998	42.687474999999999	42.680636	0103000020E6100000010000000500000041B8020AF5264740793D98141F57454041B8020AF5264740A7E8482EFF5745409B1C3EE944284740A7E8482EFF5745409B1C3EE944284740793D98141F57454041B8020AF5264740793D98141F574540
32009	Миарсо	8	75	21	46.177996	46.192863000000003	42.665953000000002	42.657997000000002	0103000020E61000000100000005000000CF68AB92C8164740DDEEE53E39544540CF68AB92C816474028D6A9F23D554540E2CD1ABCAF18474028D6A9F23D554540E2CD1ABCAF184740DDEEE53E39544540CF68AB92C8164740DDEEE53E39544540
31925	Кижани	8	75	21	46.368150999999997	46.375230000000002	42.744264000000001	42.740490000000001	0103000020E61000000100000005000000AE7E6C921F2F4740ED815660C85E4540AE7E6C921F2F47408ACBF10A445F4540323D6189073047408ACBF10A445F4540323D618907304740ED815660C85E4540AE7E6C921F2F4740ED815660C85E4540
53869	Кванхидатли	8	75	21	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
31773	Зило	8	75	21	46.310785000000003	46.325194000000003	42.735742000000002	42.729067000000001	0103000020E610000001000000050000002F8B89CDC7274740E2CB4411525D45402F8B89CDC727474096253ACB2C5E45407F6DFDF49F29474096253ACB2C5E45407F6DFDF49F294740E2CB4411525D45402F8B89CDC7274740E2CB4411525D4540
53881	Зиберхали	8	75	21	46.004548999999997	46.13635	42.718336999999998	42.621074	0103000020E61000000100000005000000601DC70F95004740AD32535A7F4F4540601DC70F95004740DD408177F25B4540A167B3EA73114740DD408177F25B4540A167B3EA73114740AD32535A7F4F4540601DC70F95004740AD32535A7F4F4540
30631	Гунха	8	75	21	46.278356000000002	46.285929000000003	42.792195999999997	42.787332999999997	0103000020E610000001000000050000009C525E2BA1234740E107E753C76445409C525E2BA1234740D102B4AD666545402FFD4B5299244740D102B4AD666545402FFD4B5299244740E107E753C76445409C525E2BA1234740E107E753C7644540
31394	Гагатли	8	75	21	46.284194999999997	46.295665999999997	42.804096999999999	42.794722999999998	0103000020E61000000100000005000000E6577380602447408330B77BB9654540E657738060244740E6E786A6EC66454002452C62D8254740E6E786A6EC66454002452C62D82547408330B77BB9654540E6577380602447408330B77BB9654540
32647	Ботлих	8	75	21	46.211027000000001	46.233179999999997	42.671999	42.642811000000002	0103000020E6100000010000000500000058C9C7EE021B474029417FA14752454058C9C7EE021B4740ECF82F1004564540670A9DD7D81D4740ECF82F1004564540670A9DD7D81D474029417FA14752454058C9C7EE021B474029417FA147524540
31330	Ашино	8	75	21	46.156238999999999	46.163569000000003	42.684426999999999	42.680112000000001	0103000020E610000001000000050000000CAEB9A3FF134740FFCEF6E80D5745400CAEB9A3FF134740ECBFCE4D9B574540D9D138D4EF144740ECBFCE4D9B574540D9D138D4EF144740FFCEF6E80D5745400CAEB9A3FF134740FFCEF6E80D574540
31040	Ашали	8	75	21	46.301892000000002	46.321914999999997	42.773496000000002	42.761099000000002	0103000020E610000001000000050000004776A565A4264740580229B16B6145404776A565A42647401DCBBBEA01634540C18BBE82342947401DCBBBEA01634540C18BBE8234294740580229B16B6145404776A565A4264740580229B16B614540
53502	Ансалта	8	75	21	46.109561999999997	46.122515999999997	42.699595000000002	42.681418000000001	0103000020E610000001000000050000003271AB20060E4740EF737CB4385745403271AB20060E4740FAB836548C5945404D9EB29AAE0F4740FAB836548C5945404D9EB29AAE0F4740EF737CB4385745403271AB20060E4740EF737CB438574540
53710	Анди	8	75	21	46.248801	46.270800999999999	42.788173	42.776685999999998	0103000020E61000000100000005000000261B0FB6D81F47406AA164726A634540261B0FB6D81F47408C4B55DAE2644540AF5C6F9BA92247408C4B55DAE2644540AF5C6F9BA92247406AA164726A634540261B0FB6D81F47406AA164726A634540
30425	Алак	8	75	21	46.144480000000001	46.216129000000002	42.639336	42.605840000000001	0103000020E610000001000000050000008A7615527E124740E84D452A8C4D45408A7615527E124740E69315C3D5514540CD5B751DAA1B4740E69315C3D5514540CD5B751DAA1B4740E84D452A8C4D45408A7615527E124740E84D452A8C4D4540
11646	Тлядал	8	75	1200	46.233601999999998	46.240132000000003	42.128155999999997	42.118231999999999	0103000020E61000000100000005000000DD239BABE61D47409BABE639220F4540DD239BABE61D4740A164726A671045408E5C37A5BC1E4740A164726A671045408E5C37A5BC1E47409BABE639220F4540DD239BABE61D47409BABE639220F4540
53962	Гунзиб	8	75	1200	46.252592	46.263506999999997	42.144644	42.135111000000002	0103000020E61000000100000005000000999D45EF54204740392A37514B114540999D45EF5420474004C8D0B1831245402FA2ED98BA21474004C8D0B1831245402FA2ED98BA214740392A37514B114540999D45EF54204740392A37514B114540
11599	Бежта	8	75	1200	46.112841000000003	46.139710000000001	42.137551000000002	42.129486999999997	0103000020E61000000100000005000000F052EA92710E4740EA20AF0793104540F052EA92710E47401C446B459B1145404B766C04E21147401C446B459B1145404B766C04E2114740EA20AF0793104540F052EA92710E4740EA20AF0793104540
29352	Чанкаюрт	8	75	256	46.559645000000003	46.572023999999999	43.573881	43.566304000000002	0103000020E610000001000000050000005A2F8672A247474008CC43A67CC845405A2F8672A2474740DC65BFEE74C9454078431A1538494740DC65BFEE74C9454078431A153849474008CC43A67CC845405A2F8672A247474008CC43A67CC84540
53538	Цадах	8	75	256	47.033551000000003	47.052847	43.587490000000003	43.579529999999998	0103000020E61000000100000005000000C2DF2F664B8447408386FE092ECA4540C2DF2F664B844740105D50DF32CB45408A58C4B0C3864740105D50DF32CB45408A58C4B0C38647408386FE092ECA4540C2DF2F664B8447408386FE092ECA4540
29577	Хасанай	8	75	256	46.700491999999997	46.715367999999998	43.642555999999999	43.622283000000003	0103000020E61000000100000005000000088ECBB8A9594740ABED26F8A6CF4540088ECBB8A95947409EEC66463FD245406E4DBA2D915B47409EEC66463FD245406E4DBA2D915B4740ABED26F8A6CF4540088ECBB8A9594740ABED26F8A6CF4540
53828	Хамзаюрт	8	75	256	46.976140000000001	46.991824999999999	43.456556999999997	43.445509999999999	0103000020E61000000100000005000000A228D027F27C47403E05C07806B94540A228D027F27C474043E1B37570BA4540772D211FF47E474043E1B37570BA4540772D211FF47E47403E05C07806B94540A228D027F27C47403E05C07806B94540
53464	Хамамат-Юрт	8	75	256	46.489109999999997	46.510516000000003	43.615999000000002	43.593687000000003	0103000020E61000000100000005000000C2120F289B3E4740BA8784EFFDCB4540C2120F289B3E474032AF230ED9CE4540D90A9A965841474032AF230ED9CE4540D90A9A9658414740BA8784EFFDCB4540C2120F289B3E4740BA8784EFFDCB4540
29264	Уцмиюрт	8	75	256	46.458181000000003	46.478464000000002	43.545267000000003	43.523491	0103000020E610000001000000050000000553CDACA53A47400B60CAC001C345400553CDACA53A4740454B1E4FCBC545401C28F04E3E3D4740454B1E4FCBC545401C28F04E3E3D47400B60CAC001C345400553CDACA53A47400B60CAC001C34540
53476	Тюпкутан (Алимпашаюрт)	8	75	256	46.811217999999997	46.831753999999997	43.58907	43.579144999999997	0103000020E6100000010000000500000098F6CDFDD56747402A52616C21CA454098F6CDFDD5674740018750A566CB4540992842EA766A4740018750A566CB4540992842EA766A47402A52616C21CA454098F6CDFDD56747402A52616C21CA4540
17868	Турщунай	8	75	256	46.654291999999998	46.675088000000002	43.604340999999998	43.589115999999997	0103000020E6100000010000000500000068041BD7BF53474071C6302768CB454068041BD7BF534740E350BF0B5BCD454006F6984869564740E350BF0B5BCD454006F698486956474071C6302768CB454068041BD7BF53474071C6302768CB4540
30135	Татаюрт	8	75	256	46.984566000000001	47.010230999999997	43.566115000000003	43.555225	0103000020E6100000010000000500000074603942067E4740F775E09C11C7454074603942067E47403563D17476C84540E333D93F4F8147403563D17476C84540E333D93F4F814740F775E09C11C7454074603942067E4740F775E09C11C74540
53537	Тамаза-Тюбе	8	75	256	47.145373999999997	47.174317000000002	43.583911999999998	43.571654000000002	0103000020E6100000010000000500000027D87F9D9B924740555051F52BC9454027D87F9D9B924740F8DEDFA0BDCA45408411FB0450964740F8DEDFA0BDCA45408411FB0450964740555051F52BC9454027D87F9D9B924740555051F52BC94540
30226	Старое Тамазатюбе	8	75	256	47.165315999999997	47.176707	43.667620999999997	43.657532000000003	0103000020E61000000100000005000000B5C01E1329954740680932022AD44540B5C01E1329954740B88FDC9A74D54540B5FCC0559E964740B88FDC9A74D54540B5FCC0559E964740680932022AD44540B5C01E1329954740680932022AD44540
29540	Советское	8	75	256	46.6877	46.697384	43.602141000000003	43.594926999999998	0103000020E61000000100000005000000C7BAB88D06584740F240649126CC4540C7BAB88D06584740564ACFF412CD4540786000E143594740564ACFF412CD4540786000E143594740F240649126CC4540C7BAB88D06584740F240649126CC4540
1071	Сангар	8	75	256	47.168343999999998	47.173589999999997	43.595148999999999	43.589547000000003	0103000020E61000000100000005000000293DD34B8C9547403B3AAE4676CB4540293DD34B8C954740A19FA9D72DCC4540D174763238964740A19FA9D72DCC4540D1747632389647403B3AAE4676CB4540293DD34B8C9547403B3AAE4676CB4540
30183	Новокаре	8	75	256	46.955910000000003	46.977595000000001	43.605809999999998	43.595939000000001	0103000020E61000000100000005000000AEF545425B7A47409AB4A9BA47CC4540AEF545425B7A47407DCB9C2E8BCD4540D7DD3CD5217D47407DCB9C2E8BCD4540D7DD3CD5217D47409AB4A9BA47CC4540AEF545425B7A47409AB4A9BA47CC4540
30339	Новая Коса	8	75	256	47.362577000000002	47.375216999999999	43.556674999999998	43.544960000000003	0103000020E6100000010000000500000012A452EC68AE474068D0D03FC1C5454012A452EC68AE47401AC05B2041C745409DF3531C07B047401AC05B2041C745409DF3531C07B0474068D0D03FC1C5454012A452EC68AE474068D0D03FC1C54540
29999	Мужукай	8	75	256	46.887251999999997	46.910311999999998	43.631307999999997	43.625168000000002	0103000020E61000000100000005000000C1A7397991714740BC40498105D04540C1A739799171474001DA56B3CED045400394861A8574474001DA56B3CED045400394861A85744740BC40498105D04540C1A7397991714740BC40498105D04540
29627	Люксембург	8	75	256	46.733387999999998	46.754902999999999	43.674728999999999	43.651721000000002	0103000020E61000000100000005000000B1A371A8DF5D4740E78EFE976BD34540B1A371A8DF5D4740D65416855DD645407E5358A9A0604740D65416855DD645407E5358A9A0604740E78EFE976BD34540B1A371A8DF5D4740E78EFE976BD34540
53633	Львовский 7-й	8	75	256	47.199191999999996	47.208452999999999	43.435744	43.429569999999998	0103000020E61000000100000005000000FACF9A1F7F994740DEAB5626FCB64540FACF9A1F7F994740D0B69A75C6B7454065E08096AE9A4740D0B69A75C6B7454065E08096AE9A4740DEAB5626FCB64540FACF9A1F7F994740DEAB5626FCB64540
53508	Львовский 6-й	8	75	256	47.251761000000002	47.260682000000003	43.368777000000001	43.364235999999998	0103000020E6100000010000000500000042B456B439A047404F0306499FAE454042B456B439A047402D42B11534AF4540F4531C075EA147402D42B11534AF4540F4531C075EA147404F0306499FAE454042B456B439A047404F0306499FAE4540
6979	Львовский 1-й	8	75	256	47.140405999999999	47.156126999999998	43.395477	43.381220999999996	0103000020E61000000100000005000000C214E5D2F891474032C687D9CBB04540C214E5D2F8914740FCA886FD9EB24540E48233F8FB934740FCA886FD9EB24540E48233F8FB93474032C687D9CBB04540C214E5D2F891474032C687D9CBB04540
53765	Кутан-Бутуш	8	75	256	46.729705000000003	46.744545000000002	43.494762000000001	43.479784000000002	0103000020E61000000100000005000000255D33F9665D47407192E68F69BD4540255D33F9665D4740DBA6785C54BF45403EB324404D5F4740DBA6785C54BF45403EB324404D5F47407192E68F69BD4540255D33F9665D47407192E68F69BD4540
53874	Кородинский кутан	8	75	256	46.416336999999999	47.669288999999999	43.897106000000001	43.273696000000001	0103000020E61000000100000005000000B08EE3874A354740E485747808A34540B08EE3874A354740CF85915ED4F2454049490F43ABD54740CF85915ED4F2454049490F43ABD54740E485747808A34540B08EE3874A354740E485747808A34540
29655	Герменчик	8	75	256	46.714488000000003	46.735759999999999	43.545822999999999	43.534570000000002	0103000020E6100000010000000500000036B1C057745B47401CB62DCA6CC4454036B1C057745B4740CA332F87DDC545403CDA38622D5E4740CA332F87DDC545403CDA38622D5E47401CB62DCA6CC4454036B1C057745B47401CB62DCA6CC44540
53664	Геметюбе	8	75	256	46.416336999999999	47.669288999999999	43.897106000000001	43.273696000000001	0103000020E61000000100000005000000B08EE3874A354740E485747808A34540B08EE3874A354740CF85915ED4F2454049490F43ABD54740CF85915ED4F2454049490F43ABD54740E485747808A34540B08EE3874A354740E485747808A34540
29708	Бабаюрт	8	75	256	46.75705	46.797986000000002	43.617244999999997	43.593145	0103000020E61000000100000005000000E9B7AF03E76047409964E42CECCB4540E9B7AF03E76047404C4F58E201CF45403B55BE67246647404C4F58E201CF45403B55BE67246647409964E42CECCB4540E9B7AF03E76047409964E42CECCB4540
53913	Ахайотар	8	75	256	46.810572000000001	46.824962999999997	43.655496999999997	43.645941999999998	0103000020E61000000100000005000000D386C3D2C0674740718E3A3AAED24540D386C3D2C067474024D06053E7D345407CB438639869474024D06053E7D345407CB4386398694740718E3A3AAED24540D386C3D2C0674740718E3A3AAED24540
53942	Арцалу	8	75	256	47.204850999999998	47.216493	43.378599999999999	43.372487	0103000020E61000000100000005000000C5C6BC8E389A4740B3976DA7ADAF4540C5C6BC8E389A4740FF21FDF675B045400E68E90AB69B4740FF21FDF675B045400E68E90AB69B4740B3976DA7ADAF4540C5C6BC8E389A4740B3976DA7ADAF4540
53671	Анхвала	8	75	256	46.899577000000001	46.907274999999998	43.658628	43.651949000000002	0103000020E61000000100000005000000ED9DD1562573474078D4981073D34540ED9DD156257347406D1D1CEC4DD445403CBD5296217447406D1D1CEC4DD445403CBD52962174474078D4981073D34540ED9DD1562573474078D4981073D34540
53715	Адиль-Янги-Юрт	8	75	256	46.571674000000002	46.595272000000001	43.570608	43.551174000000003	0103000020E610000001000000050000009CFC169D2C494740E833A0DE8CC645409CFC169D2C494740016BD5AE09C94540BD1C76DF314C4740016BD5AE09C94540BD1C76DF314C4740E833A0DE8CC645409CFC169D2C494740E833A0DE8CC64540
29217	Ялак	8	75	1817	47.598035000000003	47.610979999999998	41.536718	41.526105999999999	0103000020E61000000100000005000000836E2F698CCC47405C1D007157C34440836E2F698CCC47405796E82CB3C444404A41B79734CE47405796E82CB3C444404A41B79734CE47405C1D007157C34440836E2F698CCC47405C1D007157C34440
29121	Хрюг	8	75	1817	47.594620999999997	47.617106	41.491790000000002	41.481462000000001	0103000020E61000000100000005000000E5417A8A1CCC47402522FC8BA0BD4440E5417A8A1CCC4740FB3F87F9F2BE44402B155454FDCE4740FB3F87F9F2BE44402B155454FDCE47402522FC8BA0BD4440E5417A8A1CCC47402522FC8BA0BD4440
29037	Хнов	8	75	1817	47.435789999999997	47.450845999999999	41.380538999999999	41.373888000000001	0103000020E6100000010000000500000040F67AF7C7B74740F52EDE8FDBAF444040F67AF7C7B7474020ED7F80B5B0444026C45C52B5B9474020ED7F80B5B0444026C45C52B5B94740F52EDE8FDBAF444040F67AF7C7B74740F52EDE8FDBAF4440
28912	Ухул	8	75	1817	47.738675000000001	47.743454	41.354925000000001	41.351140999999998	0103000020E61000000100000005000000B8AF03E78CDE474072A43330F2AC4440B8AF03E78CDE474033C4B12E6EAD44404A0A2C8029DF474033C4B12E6EAD44404A0A2C8029DF474072A43330F2AC4440B8AF03E78CDE474072A43330F2AC4440
53582	Усур	8	75	1817	47.687120999999998	47.694065000000002	41.528145000000002	41.524183000000001	0103000020E6100000010000000500000089B2B794F3D74740410FB56D18C3444089B2B794F3D74740E1455F419AC344402D26361FD7D84740E1455F419AC344402D26361FD7D84740410FB56D18C3444089B2B794F3D74740410FB56D18C34440
28994	Старый Хкем	8	75	1817	47.772928	47.783940999999999	41.4925	41.486041999999998	0103000020E61000000100000005000000D314014EEFE24740C03DCF9F36BE4440D314014EEFE24740D7A3703D0ABF44402C7FBE2D58E44740D7A3703D0ABF44402C7FBE2D58E44740C03DCF9F36BE4440D314014EEFE24740C03DCF9F36BE4440
28830	Смугул	8	75	1817	47.628146000000001	47.637228	41.384070999999999	41.377420000000001	0103000020E610000001000000050000007E8E8F1667D047409C6D6E4C4FB044407E8E8F1667D04740C72B103D29B14440390CE6AF90D14740C72B103D29B14440390CE6AF90D147409C6D6E4C4FB044407E8E8F1667D047409C6D6E4C4FB04440
53546	Село Фий	8	75	1817	47.257689999999997	47.840390999999997	41.608896999999999	41.19838	0103000020E61000000100000005000000CC4065FCFBA047401A170E8464994440CC4065FCFBA04740F6D03E56F0CD4440266DAAEE91EB4740F6D03E56F0CD4440266DAAEE91EB47401A170E8464994440CC4065FCFBA047401A170E8464994440
27373	Миджах	8	75	1817	47.639178000000001	47.644432999999999	41.397559999999999	41.393419999999999	0103000020E610000001000000050000004E29AF95D0D14740D1CB28965BB244404E29AF95D0D147405019FF3EE3B2444049BBD1C77CD247405019FF3EE3B2444049BBD1C77CD24740D1CB28965BB244404E29AF95D0D14740D1CB28965BB24440
28638	Луткун	8	75	1817	47.675981999999998	47.691783000000001	41.490189999999998	41.477590999999997	0103000020E61000000100000005000000A357039486D6474095EEAEB321BD4440A357039486D64740C269C18BBEBE4440E27668588CD84740C269C18BBEBE4440E27668588CD8474095EEAEB321BD4440A357039486D6474095EEAEB321BD4440
32724	Куркал	8	75	1817	47.678002999999997	47.694755999999998	41.438876	41.429890999999998	0103000020E6100000010000000500000081CB63CDC8D6474020EC14AB06B7444081CB63CDC8D64740E97FB9162DB844409259BDC3EDD84740E97FB9162DB844409259BDC3EDD8474020EC14AB06B7444081CB63CDC8D6474020EC14AB06B74440
28490	Калук	8	75	1817	47.652023999999997	47.673565000000004	41.474038	41.468814999999999	0103000020E61000000100000005000000821ABE8575D34740E76F422102BC4440821ABE8575D34740D787F546ADBC4440795DBF6037D64740D787F546ADBC4440795DBF6037D64740E76F422102BC4440821ABE8575D34740E76F422102BC4440
28446	Кака	8	75	1817	47.627634	47.645097999999997	41.483604	41.474057999999999	0103000020E61000000100000005000000C8ED974F56D047401E34BBEEADBC4440C8ED974F56D047407E1B62BCE6BD4440855B3E9292D247407E1B62BCE6BD4440855B3E9292D247401E34BBEEADBC4440C8ED974F56D047401E34BBEEADBC4440
28386	Зрых	8	75	1817	47.547953999999997	47.566243	41.499679	41.492310000000003	0103000020E610000001000000050000002FDB4E5B23C6474034BF9A0304BF44402FDB4E5B23C64740BEBF417BF5BF4440624B8FA67AC84740BEBF417BF5BF4440624B8FA67AC8474034BF9A0304BF44402FDB4E5B23C6474034BF9A0304BF4440
28352	Джаба	8	75	1817	47.771203	47.785809999999998	41.426828999999998	41.420000000000002	0103000020E61000000100000005000000DEC9A7C7B6E24740F6285C8FC2B54440DEC9A7C7B6E2474000FE2955A2B64440546F0D6C95E4474000FE2955A2B64440546F0D6C95E44740F6285C8FC2B54440DEC9A7C7B6E24740F6285C8FC2B54440
28292	Гогаз	8	75	1817	47.673996000000002	47.679485	41.539983999999997	41.536217999999998	0103000020E6100000010000000500000042D13C8045D6474065C39ACAA2C4444042D13C8045D647407F2E1A321EC54440B08F4E5DF9D647407F2E1A321EC54440B08F4E5DF9D6474065C39ACAA2C4444042D13C8045D6474065C39ACAA2C44440
28257	Гдынк	8	75	1817	47.651988000000003	47.663001000000001	41.460355	41.454962000000002	0103000020E6100000010000000500000036B1C05774D347401D76DF313CBA444036B1C05774D3474069C6A2E9ECBA44408F1B7E37DDD4474069C6A2E9ECBA44408F1B7E37DDD447401D76DF313CBA444036B1C05774D347401D76DF313CBA4440
28211	Гдым	8	75	1817	47.464365999999998	47.469377999999999	41.311461999999999	41.306063999999999	0103000020E61000000100000005000000EAAF575870BB4740D13DEB1A2DA74440EAAF575870BB47402FF99FFCDDA744401FBB0B9414BC47402FF99FFCDDA744401FBB0B9414BC4740D13DEB1A2DA74440EAAF575870BB4740D13DEB1A2DA74440
27823	Ахты	8	75	1817	47.700029999999998	47.761806999999997	41.475186000000001	41.443174999999997	0103000020E61000000100000005000000041C42959AD94740D0B359F5B9B84440041C42959AD947402FC214E5D2BC4440936E4BE482E147402FC214E5D2BC4440936E4BE482E14740D0B359F5B9B84440041C42959AD94740D0B359F5B9B84440
32586	Цолода	8	75	1796	46.361207	46.370226000000002	42.640695999999998	42.633671999999997	0103000020E610000001000000050000000B0BEE073C2E47400932022A1C5145400B0BEE073C2E4740C9569753025245408010C990632F4740C9569753025245408010C990632F47400932022A1C5145400B0BEE073C2E47400932022A1C514540
53539	Цвакилколо	8	75	1796	46.349682000000001	46.357478999999998	42.554636000000002	42.549773999999999	0103000020E61000000100000005000000FCFF3861C22C4740761893FE5E464540FCFF3861C22C47409697FC4FFE464540DE0033DFC12D47409697FC4FFE464540DE0033DFC12D4740761893FE5E464540FCFF3861C22C4740761893FE5E464540
26760	Тукита	8	75	1796	46.366193000000003	46.373756999999998	42.577511000000001	42.569417999999999	0103000020E6100000010000000500000017838769DF2E47407AE063B0E248454017838769DF2E4740460A65E1EB49454056D3F544D72F4740460A65E1EB49454056D3F544D72F47407AE063B0E248454017838769DF2E47407AE063B0E2484540
53670	Тлиси	8	75	1796	46.272472	46.277583	42.562983000000003	42.559742999999997	0103000020E61000000100000005000000B189CC5CE02247401C959BA8A5474540B189CC5CE02247401C9AB2D30F4845407976F9D6872347401C9AB2D30F4845407976F9D6872347401C959BA8A5474540B189CC5CE02247401C959BA8A5474540
53511	Тлибишо	8	75	1796	46.293653999999997	46.306804999999997	42.562849999999997	42.557445000000001	0103000020E61000000100000005000000772B4B7496254740CC28965B5A474540772B4B7496254740DC4603780B484540E89FE06245274740DC4603780B484540E89FE06245274740CC28965B5A474540772B4B7496254740CC28965B5A474540
53440	Тад-Магитль	8	75	1796	46.326793000000002	46.353104999999999	42.555864	42.544187999999998	0103000020E61000000100000005000000E7C75F5AD42947401570CFF3A7454540E7C75F5AD42947400A83328D26474540EC866D8B322D47400A83328D26474540EC866D8B322D47401570CFF3A7454540E7C75F5AD42947401570CFF3A7454540
53533	Рачабулда	8	75	1796	46.300615999999998	46.308171000000002	42.621360000000003	42.614519000000001	0103000020E61000000100000005000000C153C8957A264740A4E2FF8EA84E4540C153C8957A264740738577B9884F4540AE49B72572274740738577B9884F4540AE49B72572274740A4E2FF8EA84E4540C153C8957A264740A4E2FF8EA84E4540
53805	Рацитль	8	75	1796	46.325606999999998	46.338039999999999	42.642631999999999	42.635257000000003	0103000020E61000000100000005000000A12C7C7DAD2947400DC7F31950514540A12C7C7DAD29474079AEEFC341524540B35E0CE5442B474079AEEFC341524540B35E0CE5442B47400DC7F31950514540A12C7C7DAD2947400DC7F31950514540
26747	Местерух	8	75	1796	46.392010999999997	46.399808	42.578440999999998	42.573036000000002	0103000020E610000001000000050000000C569C6A2D32474020B75F3E594945400C569C6A2D32474030D5CC5A0A4A4540EF5696E82C33474030D5CC5A0A4A4540EF5696E82C33474020B75F3E594945400C569C6A2D32474020B75F3E59494540
27013	Лологонитль	8	75	1796	46.326892000000001	46.333944000000002	42.517346000000003	42.511038999999997	0103000020E610000001000000050000007AA9D898D729474082FDD7B9694145407AA9D898D7294740B45BCB643842454004594FADBE2A4740B45BCB643842454004594FADBE2A474082FDD7B9694145407AA9D898D729474082FDD7B969414540
26872	Кудиябросо	8	75	1796	46.374780999999999	46.382812000000001	42.543503000000001	42.536661000000002	0103000020E61000000100000005000000C214E5D2F82F4740F304C24EB1444540C214E5D2F82F474092239D81914545401842CEFBFF30474092239D81914545401842CEFBFF304740F304C24EB1444540C214E5D2F82F4740F304C24EB1444540
53506	Карата	8	75	1796	46.324492999999997	46.346905999999997	42.602144000000003	42.587747999999998	0103000020E61000000100000005000000F56393FC882947400B2593533B4B4540F56393FC88294740C7BDF90D134D4540A164726A672C4740C7BDF90D134D4540A164726A672C47400B2593533B4B4540F56393FC882947400B2593533B4B4540
53443	Ингердах	8	75	1796	46.388345999999999	46.401738999999999	42.593197000000004	42.585099	0103000020E6100000010000000500000026C45C52B53147400EF62686E44A454026C45C52B5314740EC8A19E1ED4B45408D43FD2E6C334740EC8A19E1ED4B45408D43FD2E6C3347400EF62686E44A454026C45C52B53147400EF62686E44A4540
26809	Изано	8	75	1796	46.398657999999998	46.410345	42.529479000000002	42.524442999999998	0103000020E61000000100000005000000F624B03907334740DDCEBEF220434540F624B039073347409B75C6F7C5434540DF89592F863447409B75C6F7C5434540DF89592F86344740DDCEBEF220434540F624B03907334740DDCEBEF220434540
32524	Верхнее Инхело	8	75	1796	46.322975	46.335399000000002	42.623190999999998	42.616895	0103000020E610000001000000050000007A36AB3E572947407008556AF64E45407A36AB3E57294740AD1402B9C44F4540390EBC5AEE2A4740AD1402B9C44F4540390EBC5AEE2A47407008556AF64E45407A36AB3E572947407008556AF64E4540
26304	Арчо	8	75	1796	46.296951	46.308647000000001	42.602462000000003	42.595433999999997	0103000020E61000000100000005000000DBC1887D0226474096766A2E374C4540DBC1887D02264740988A8D791D4D45401781B1BE81274740988A8D791D4D45401781B1BE8127474096766A2E374C4540DBC1887D0226474096766A2E374C4540
53518	Анчик	8	75	1796	46.272948	46.287509999999997	42.637326999999999	42.605415000000001	0103000020E610000001000000050000001AC1C6F5EF22474001C11C3D7E4D45401AC1C6F5EF224740CCED5EEE93514540F0A2AF20CD244740CCED5EEE93514540F0A2AF20CD24474001C11C3D7E4D45401AC1C6F5EF22474001C11C3D7E4D4540
53688	с. Панжи	8	75	1736	47.188249999999996	47.559694999999998	42.370292999999997	41.988497000000002	0103000020E610000001000000050000006ABC749318984740D998D71187FE44406ABC7493189847400778D2C2652F45400B5EF415A4C747400778D2C2652F45400B5EF415A4C74740D998D71187FE44406ABC749318984740D998D71187FE4440
53437	Шумхримахи	8	75	1736	47.265828999999997	47.276491999999998	42.293408999999997	42.289794000000001	0103000020E6100000010000000500000008AA46AF06A24740DC4944F81725454008AA46AF06A2474010AD156D8E25454085CD001764A3474010AD156D8E25454085CD001764A34740DC4944F81725454008AA46AF06A24740DC4944F817254540
53667	Шукты	8	75	1736	47.300207	47.309891	42.227046000000001	42.221651999999999	0103000020E61000000100000005000000E083D72E6DA64740E78BBD175F1C4540E083D72E6DA647400458E4D70F1D454091291F82AAA747400458E4D70F1D454091291F82AAA74740E78BBD175F1C4540E083D72E6DA64740E78BBD175F1C4540
33040	Цугни	8	75	1736	47.401581999999998	47.410178999999999	42.110011999999998	42.106586999999998	0103000020E61000000100000005000000C554FA0967B34740E1968FA4A40D4540C554FA0967B3474072158BDF140E4540C440D7BE80B4474072158BDF140E4540C440D7BE80B44740E1968FA4A40D4540C554FA0967B34740E1968FA4A40D4540
53598	Уцулимахи	8	75	1736	47.420248999999998	47.428226000000002	42.069163000000003	42.061250999999999	0103000020E610000001000000050000009E961FB8CAB5474074ECA012D70745409E961FB8CAB54740F08B4B55DA08454001A60C1CD0B64740F08B4B55DA08454001A60C1CD0B6474074ECA012D70745409E961FB8CAB5474074ECA012D7074540
33031	Усиша	8	75	1736	47.380561999999998	47.401626999999998	42.255414999999999	42.241191999999998	0103000020E61000000100000005000000D80C7041B6B0474046072461DF1E4540D80C7041B6B0474034F44F70B12045406518778368B3474034F44F70B12045406518778368B3474046072461DF1E4540D80C7041B6B0474046072461DF1E4540
33015	Урхучимахи	8	75	1736	47.253639	47.264068000000002	42.312454000000002	42.30742	0103000020E61000000100000005000000BDFE243E77A047407311DF8959274540BDFE243E77A0474090C01F7EFE274540C7F5EFFACCA1474090C01F7EFE274540C7F5EFFACCA147407311DF8959274540BDFE243E77A047407311DF8959274540
53795	Ургубамахи	8	75	1736	47.308489999999999	47.333947999999999	42.293649000000002	42.283763999999998	0103000020E610000001000000050000004F92AE997CA747401DE4F560522445404F92AE997CA7474066C0594A962545404548DDCEBEAA474066C0594A962545404548DDCEBEAA47401DE4F560522445404F92AE997CA747401DE4F56052244540
53865	Ургани	8	75	1736	47.360196999999999	47.364626000000001	42.139476999999999	42.133004	0103000020E61000000100000005000000048F6FEF1AAE47405C1E6B4606114540048F6FEF1AAE4740A8C5E061DA114540BAA29410ACAE4740A8C5E061DA114540BAA29410ACAE47405C1E6B4606114540048F6FEF1AAE47405C1E6B4606114540
25741	Уллучара	8	75	1736	47.270491	47.279941000000001	42.205931999999997	42.198565000000002	0103000020E61000000100000005000000616EF7729FA24740AC90F2936A194540616EF7729FA247409599D2FA5B1A45409FE74F1BD5A347409599D2FA5B1A45409FE74F1BD5A34740AC90F2936A194540616EF7729FA24740AC90F2936A194540
53697	Узнимахи	8	75	1736	47.380229	47.387073999999998	42.302199000000002	42.296436999999997	0103000020E61000000100000005000000D2FE0758ABB047408429CAA5F1254540D2FE0758ABB0474024F1F274AE264540E2900DA48BB1474024F1F274AE264540E2900DA48BB147408429CAA5F1254540D2FE0758ABB047408429CAA5F1254540
53528	Тебекмахи	8	75	1736	47.204276	47.212271000000001	42.348160999999998	42.338805000000001	0103000020E61000000100000005000000C9AD49B7259A4740535C55F65D2B4540C9AD49B7259A47400F5F268A902C4540D27135B22B9B47400F5F268A902C4540D27135B22B9B4740535C55F65D2B4540C9AD49B7259A4740535C55F65D2B4540
25512	Танты	8	75	1736	47.312370999999999	47.319493999999999	42.170009999999998	42.158675000000002	0103000020E61000000100000005000000029CDEC5FBA74740AED85F764F144540029CDEC5FBA7474019FF3EE3C215454055A2EC2DE5A8474019FF3EE3C215454055A2EC2DE5A84740AED85F764F144540029CDEC5FBA74740AED85F764F144540
53421	Семгамахи	8	75	1736	47.352623999999999	47.363053999999998	42.286326000000003	42.280214999999998	0103000020E6100000010000000500000071E481C822AD4740A06CCA15DE23454071E481C822AD47404CFF9254A62445404B57B08D78AE47404CFF9254A62445404B57B08D78AE4740A06CCA15DE23454071E481C822AD4740A06CCA15DE234540
53804	Наци	8	75	1736	47.386175999999999	47.390039000000002	42.075614999999999	42.073092000000003	0103000020E61000000100000005000000034015376EB14740B4CC22145B094540034015376EB14740240B98C0AD094540109546CCECB14740240B98C0AD094540109546CCECB14740B4CC22145B094540034015376EB14740B4CC22145B094540
53803	Нахки	8	75	1736	47.398249999999997	47.402605999999999	42.076706000000001	42.072749999999999	0103000020E61000000100000005000000E5D022DBF9B247405A643BDF4F094540E5D022DBF9B2474018B49080D10945403196E99788B3474018B49080D10945403196E99788B347405A643BDF4F094540E5D022DBF9B247405A643BDF4F094540
25213	Муги	8	75	1736	47.407618999999997	47.432844000000003	42.304918999999998	42.287466000000002	0103000020E61000000100000005000000361D01DC2CB44740215B96AFCB244540361D01DC2CB44740EA76F695072745408A22A46E67B74740EA76F695072745408A22A46E67B74740215B96AFCB244540361D01DC2CB44740215B96AFCB244540
25126	Куркимахи	8	75	1736	47.417167999999997	47.423707999999998	42.217638999999998	42.211340999999997	0103000020E610000001000000050000000778D2C265B54740E7A6CD380D1B45400778D2C265B54740C5AA4198DB1B4540DB8651103CB64740C5AA4198DB1B4540DB8651103CB64740E7A6CD380D1B45400778D2C265B54740E7A6CD380D1B4540
53594	Кулиямахи	8	75	1736	47.33278	47.338574000000001	42.080781000000002	42.076450999999999	0103000020E61000000100000005000000A661F88898AA47408D5F7825C9094540A661F88898AA4740B0912408570A454051A3906456AB4740B0912408570A454051A3906456AB47408D5F7825C9094540A661F88898AA47408D5F7825C9094540
53920	Кули	8	75	1736	47.208587999999999	47.215856000000002	42.302804999999999	42.297770999999997	0103000020E61000000100000005000000452BF702B39A47403E59315C1D264540452BF702B39A47405B087250C22645409C525E2BA19B47405B087250C22645409C525E2BA19B47403E59315C1D264540452BF702B39A47403E59315C1D264540
53494	Кассагумахи	8	75	1736	47.367877	47.375126999999999	42.045001999999997	42.042302999999997	0103000020E61000000100000005000000ADF9F19716AF4740E7C2482F6A054540ADF9F19716AF4740962023A0C20545405D6C5A2904B04740962023A0C20545405D6C5A2904B04740E7C2482F6A054540ADF9F19716AF4740E7C2482F6A054540
53608	Карша	8	75	1736	47.339086000000002	47.346604999999997	42.271016000000003	42.263095999999997	0103000020E610000001000000050000000744882B67AB4740ADDA3521AD2145400744882B67AB4740AC58FCA6B0224540A6D0798D5DAC4740AC58FCA6B0224540A6D0798D5DAC4740ADDA3521AD2145400744882B67AB4740ADDA3521AD214540
24981	Кавкамахи	8	75	1736	47.285358000000002	47.313484000000003	42.324221000000001	42.309640000000002	0103000020E6100000010000000500000074D3669C86A4474048C49448A227454074D3669C86A4474095D6DF1280294540DEE8633E20A8474095D6DF1280294540DEE8633E20A8474048C49448A227454074D3669C86A4474048C49448A2274540
53922	Зильмукмахи	8	75	1736	47.394063000000003	47.398913999999998	42.285465000000002	42.282589999999999	0103000020E6100000010000000500000026C808A870B247409C16BCE82B24454026C808A870B247408A93FB1D8A24454051F52B9D0FB347408A93FB1D8A24454051F52B9D0FB347409C16BCE82B24454026C808A870B247409C16BCE82B244540
53442	Дубримахи	8	75	1736	47.280903000000002	47.295724999999997	42.278126999999998	42.258884999999999	0103000020E61000000100000005000000952C27A1F4A347406536C82423214540952C27A1F4A347403A9160AA9923454007CE1951DAA547403A9160AA9923454007CE1951DAA547406536C82423214540952C27A1F4A347406536C82423214540
53792	Гумрамахи	8	75	1736	47.346398999999998	47.357053000000001	42.253914000000002	42.246011000000003	0103000020E61000000100000005000000FD2E6CCD56AC474067BAD7497D1F4540FD2E6CCD56AC47408FFF02418020454027F8A6E9B3AD47408FFF02418020454027F8A6E9B3AD474067BAD7497D1F4540FD2E6CCD56AC474067BAD7497D1F4540
53496	Гуладтымахи	8	75	1736	47.231656999999998	47.246228000000002	42.351818999999999	42.343015999999999	0103000020E61000000100000005000000DA71C3EFA69D47409B00C3F2E72B4540DA71C3EFA69D4740438EAD67082D454004AE2B66849F4740438EAD67082D454004AE2B66849F47409B00C3F2E72B4540DA71C3EFA69D47409B00C3F2E72B4540
24836	Гинта	8	75	1736	47.409675999999997	47.425415000000001	42.207554999999999	42.197488999999997	0103000020E6100000010000000500000061FA5E4370B44740ED28CE514719454061FA5E4370B44740868F8829911A45402A1DACFF73B64740868F8829911A45402A1DACFF73B64740ED28CE514719454061FA5E4370B44740ED28CE5147194540
53490	Гиба	8	75	1736	47.386428000000002	47.394655999999998	42.218699999999998	42.209338000000002	0103000020E610000001000000050000001D21037976B14740B0E76B96CB1A45401D21037976B147404ED1915CFE1B4540C8957A1684B247404ED1915CFE1B4540C8957A1684B24740B0E76B96CB1A45401D21037976B14740B0E76B96CB1A4540
24790	Герхмахи	8	75	1736	47.523960000000002	47.535592999999999	42.268219999999999	42.260480000000001	0103000020E61000000100000005000000C2340C1F11C347408CA19C6857214540C2340C1F11C347400A11700855224540B77BB94F8EC447400A11700855224540B77BB94F8EC447408CA19C6857214540C2340C1F11C347408CA19C6857214540
24692	Гапшима	8	75	1736	47.318739999999998	47.329304	42.216102999999997	42.205651000000003	0103000020E61000000100000005000000A9F6E978CCA84740E2B19FC5521A4540A9F6E978CCA84740A3C85A43A91B454093382BA226AA4740A3C85A43A91B454093382BA226AA4740E2B19FC5521A4540A9F6E978CCA84740E2B19FC5521A4540
24658	Верхние Мулебки	8	75	1736	47.513809000000002	47.52617	42.313754000000003	42.305653	0103000020E61000000100000005000000FBB1497EC4C147404F7633A31F274540FBB1497EC4C147409E7E5017292845407311DF8959C347409E7E5017292845407311DF8959C347404F7633A31F274540FBB1497EC4C147404F7633A31F274540
53748	Бутри	8	75	1736	47.188249999999996	47.559694999999998	42.370292999999997	41.988497000000002	0103000020E610000001000000050000006ABC749318984740D998D71187FE44406ABC7493189847400778D2C2652F45400B5EF415A4C747400778D2C2652F45400B5EF415A4C74740D998D71187FE44406ABC749318984740D998D71187FE4440
53712	Бургимакмахи	8	75	1736	47.363017999999997	47.374175000000001	42.298757999999999	42.292642000000001	0103000020E61000000100000005000000FEEDB25F77AE4740D0B7054B75254540FEEDB25F77AE47408DB5BFB33D2645408BFD65F7E4AF47408DB5BFB33D2645408BFD65F7E4AF4740D0B7054B75254540FEEDB25F77AE4740D0B7054B75254540
32812	Балхар	8	75	1736	47.225396000000003	47.243361999999998	42.281982999999997	42.269942	0103000020E610000001000000050000001A53B0C6D99C47408EE89E758D2245401A53B0C6D99C47409483D90418244540698B6B7C269F47409483D90418244540698B6B7C269F47408EE89E758D2245401A53B0C6D99C47408EE89E758D224540
53534	Аметеркамахи	8	75	1736	47.210617999999997	47.216465999999997	42.333953000000001	42.327120000000001	0103000020E6100000010000000500000076F9D687F59A47400BEF7211DF29454076F9D687F59A474057B3CEF8BE2A454014596B28B59B474057B3CEF8BE2A454014596B28B59B47400BEF7211DF29454076F9D687F59A47400BEF7211DF294540
32789	Алиханмахи	8	75	1736	47.261085999999999	47.271020999999998	42.333339000000002	42.328479999999999	0103000020E61000000100000005000000C3B81B446BA14740EEB1F4A10B2A4540C3B81B446BA147409DBD33DAAA2A4540BDC3EDD0B0A247409DBD33DAAA2A4540BDC3EDD0B0A24740EEB1F4A10B2A4540C3B81B446BA14740EEB1F4A10B2A4540
32764	Акуша	8	75	1736	47.338098000000002	47.349739999999997	42.280375999999997	42.269761000000003	0103000020E61000000100000005000000E86B96CB46AB47403E5E488787224540E86B96CB46AB4740A94A5B5CE3234540300DC347C4AC4740A94A5B5CE3234540300DC347C4AC47403E5E488787224540E86B96CB46AB47403E5E488787224540
23643	Яркуг	8	75	1706	47.681255	47.686537000000001	41.800801999999997	41.797018000000001	0103000020E61000000100000005000000459E245D33D74740632992AF04E64440459E245D33D74740234910AE80E644403A3FC571E0D74740234910AE80E644403A3FC571E0D74740632992AF04E64440459E245D33D74740632992AF04E64440
53570	Шари	8	75	1706	47.586410999999998	47.591720000000002	42.062314999999998	42.058351999999999	0103000020E61000000100000005000000E08101840FCB4740FED30D1478074540E08101840FCB47406E861BF0F9074540CF31207BBDCB47406E861BF0F9074540CF31207BBDCB4740FED30D1478074540E08101840FCB4740FED30D1478074540
23519	Чираг	8	75	1706	47.426043	47.437595999999999	41.840387	41.833191999999997	0103000020E6100000010000000500000049D8B79388B64740F8A41309A6EA444049D8B79388B64740E57D1CCD91EB4440226E4E2503B84740E57D1CCD91EB4440226E4E2503B84740F8A41309A6EA444049D8B79388B64740F8A41309A6EA4440
23596	Цирхе	8	75	1706	47.595367000000003	47.598744000000003	41.916465000000002	41.913981999999997	0103000020E610000001000000050000000F0F61FC34CC4740FB90B75CFDF444400F0F61FC34CC4740DE76A1B94EF544408F56B5A4A3CC4740DE76A1B94EF544408F56B5A4A3CC4740FB90B75CFDF444400F0F61FC34CC4740FB90B75CFDF44440
23440	Хутхул	8	75	1706	47.612920000000003	47.621094999999997	41.786684999999999	41.782905999999997	0103000020E610000001000000050000003C889D2974CE4740CCEB884336E444403C889D2974CE47407BA01518B2E44440C45A7C0A80CF47407BA01518B2E44440C45A7C0A80CF4740CCEB884336E444403C889D2974CE4740CCEB884336E44440
53480	Худиг	8	75	1706	47.653497000000002	47.662165999999999	41.854827999999998	41.849966000000002	0103000020E610000001000000050000005E8429CAA5D34740215B96AFCBEC44405E8429CAA5D3474040DAFF006BED4440F64201DBC1D4474040DAFF006BED4440F64201DBC1D44740215B96AFCBEC44405E8429CAA5D34740215B96AFCBEC4440
23490	Фите	8	75	1706	47.737417000000001	47.742780000000003	41.793488000000004	41.789535000000001	0103000020E61000000100000005000000D94125AE63DE474010069E7B0FE54440D94125AE63DE47405DE2C80391E54440BB0F406A13DF47405DE2C80391E54440BB0F406A13DF474010069E7B0FE54440D94125AE63DE474010069E7B0FE54440
23269	Тпиг	8	75	1706	47.579970000000003	47.599445000000003	41.785629	41.778252999999999	0103000020E61000000100000005000000A054FB743CCA4740C78157CB9DE34440A054FB743CCA474004E5B67D8FE4444018601F9DBACC474004E5B67D8FE4444018601F9DBACC4740C78157CB9DE34440A054FB743CCA4740C78157CB9DE34440
32625	Рича	8	75	1706	47.498213999999997	47.508310999999999	41.768590000000003	41.760486	0103000020E610000001000000050000006534F279C5BF47406E88F19A57E144406534F279C5BF47402E04392861E244403999B85510C147402E04392861E244403999B85510C147406E88F19A57E144406534F279C5BF47406E88F19A57E14440
53907	Миси	8	75	1706	47.601179000000002	47.606236000000003	41.810997999999998	41.808073999999998	0103000020E610000001000000050000006005F86EF3CC4740BB5F05F86EE744406005F86EF3CC47408A8F4FC8CEE7444035D4282499CD47408A8F4FC8CEE7444035D4282499CD4740BB5F05F86EE744406005F86EF3CC4740BB5F05F86EE74440
23151	Кураг	8	75	1706	47.658267000000002	47.663082000000003	41.838633999999999	41.833770000000001	0103000020E610000001000000050000009D84D21742D447406631B1F9B8EA44409D84D21742D4474026A8E15B58EB44407C48F8DEDFD4474026A8E15B58EB44407C48F8DEDFD447406631B1F9B8EA44409D84D21742D447406631B1F9B8EA4440
53873	Дулдуг	8	75	1706	47.668183999999997	47.687021999999999	41.772928	41.765886999999999	0103000020E61000000100000005000000F0DAA50D87D547403DB7D09508E24440F0DAA50D87D54740D314014EEFE24440F6D03E56F0D74740D314014EEFE24440F6D03E56F0D747403DB7D09508E24440F0DAA50D87D547403DB7D09508E24440
23073	Гоа	8	75	1706	47.695286000000003	47.705140999999998	41.756672000000002	41.750920999999998	0103000020E61000000100000005000000EFAEB321FFD847409770E82D1EE04440EFAEB321FFD8474043E6CAA0DAE04440CC086F0F42DA474043E6CAA0DAE04440CC086F0F42DA47409770E82D1EE04440EFAEB321FFD847409770E82D1EE04440
23002	Буршаг	8	75	1706	47.639411000000003	47.643614999999997	41.896971000000001	41.894266000000002	0103000020E61000000100000005000000F1D93A38D8D147405EF6EB4E77F24440F1D93A38D8D14740EF3A1BF2CFF24440861BF0F961D24740EF3A1BF2CFF24440861BF0F961D247405EF6EB4E77F24440F1D93A38D8D147405EF6EB4E77F24440
22985	Буркихан	8	75	1706	47.537433999999998	47.543202000000001	41.807631000000001	41.802227000000002	0103000020E6100000010000000500000015E126A3CAC44740EE7BD45FAFE6444015E126A3CAC447402E1EDE7360E74440978FA4A487C547402E1EDE7360E74440978FA4A487C54740EE7BD45FAFE6444015E126A3CAC44740EE7BD45FAFE64440
22921	Бедюк	8	75	1706	47.525342999999999	47.529907000000001	41.716926999999998	41.713346000000001	0103000020E610000001000000050000005D177E703EC34740C05DF6EB4EDB44405D177E703EC34740484F9143C4DB4440F37519FED3C34740484F9143C4DB4440F37519FED3C34740C05DF6EB4EDB44405D177E703EC34740C05DF6EB4EDB4440
53960	Арсуг	8	75	1706	47.648232999999998	47.654494	41.866359000000003	41.860779000000001	0103000020E610000001000000050000000F98874CF9D24740B30A9B012EEE44400F98874CF9D2474032CC09DAE4EE4440D0B69A75C6D3474032CC09DAE4EE4440D0B69A75C6D34740B30A9B012EEE44400F98874CF9D24740B30A9B012EEE4440
53879	Амух	8	75	1706	47.541395999999999	47.547423999999999	41.917948000000003	41.912191	0103000020E61000000100000005000000B517D1764CC547404F5AB8ACC2F44440B517D1764CC54740DDB6EF517FF54440D38558FD11C64740DDB6EF517FF54440D38558FD11C647404F5AB8ACC2F44440B517D1764CC547404F5AB8ACC2F44440
53429	Шамхал Термен	8	75	7288	47.300944000000001	47.319161999999999	43.043436999999997	43.024715	0103000020E61000000100000005000000B6F63E5585A647403E5C72DC29834540B6F63E5585A64740DA37F7578F8545401F10E84CDAA84740DA37F7578F8545401F10E84CDAA847403E5C72DC29834540B6F63E5585A647403E5C72DC29834540
818	Ставрополь	8	81	\N	41.887462999999997	42.134444999999999	45.121214999999999	44.968142999999998	0103000020E610000001000000050000007CB4386398F14440F86C1D1CEC7B46407CB4386398F144406F641EF9838F46402C0E677E351145406F641EF9838F46402C0E677E35114540F86C1D1CEC7B46407CB4386398F14440F86C1D1CEC7B4640
57588	Свободы	8	81	\N	43.015467999999998	43.073571000000001	44.030191000000002	44.016993999999997	0103000020E610000001000000050000003811FDDAFA814540361D01DC2C0246403811FDDAFA81454018D1764CDD0346408E7747C66A89454018D1764CDD0346408E7747C66A894540361D01DC2C0246403811FDDAFA814540361D01DC2C024640
57585	Светлоград	8	81	\N	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
2177	Пятигорск	8	81	\N	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
57604	Новопавловск	8	81	\N	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
57596	Нефтекумск	8	81	\N	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
6327	Невинномысск	8	81	\N	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
57587	Михайловск	8	81	\N	41.956516000000001	42.094282	45.161014000000002	45.105764999999998	0103000020E61000000100000005000000E50CC51D6FFA4440DD0720B5898D4640E50CC51D6FFA44405D19541B9C944640FD4CBD6E110C45405D19541B9C944640FD4CBD6E110C4540DD0720B5898D4640E50CC51D6FFA4440DD0720B5898D4640
13776	Минеральные Воды	8	81	\N	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
19616	Лермонтов	8	81	\N	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
57620	Констатиновская	8	81	\N	43.102623000000001	43.178933999999998	44.055942000000002	44.036600999999997	0103000020E61000000100000005000000A1681EC0228D45401D007157AF044640A1681EC0228D4540863C821B290746403C122F4FE7964540863C821B290746403C122F4FE79645401D007157AF044640A1681EC0228D45401D007157AF044640
10968	Кисловодск	8	81	\N	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
57586	Зеленокумск	8	81	\N	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
3652	Железноводск	8	81	\N	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
1708	Ессентуки	8	81	\N	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
16251	Георгиевск	8	81	\N	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
57610	Верхнерусское	8	81	\N	40.90025	45.717699000000003	46.236939	43.658569	0103000020E61000000100000005000000AC1C5A643B73444068942EFD4BD44540AC1C5A643B734440CF126404541E47409BAF928FDDDB4640CF126404541E47409BAF928FDDDB464068942EFD4BD44540AC1C5A643B73444068942EFD4BD44540
25611	Буденновск	8	81	\N	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
57578	Буденновск	8	81	\N	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
57589	Балахоновское	8	81	\N	41.762579000000002	41.796652000000002	44.804895000000002	44.748959999999997	0103000020E61000000100000005000000E6CE4C309CE144408E01D9EBDD5F4640E6CE4C309CE1444062DBA2CC06674640812557B1F8E5444062DBA2CC06674640812557B1F8E544408E01D9EBDD5F4640E6CE4C309CE144408E01D9EBDD5F4640
12540	Цимлянский	8	81	1126	42.117485000000002	42.167000000000002	44.892417000000002	44.870517	0103000020E61000000100000005000000A2629CBF090F454057CEDE196D6F4640A2629CBF090F45407DB262B83A7246404C378941601545407DB262B83A7246404C3789416015454057CEDE196D6F4640A2629CBF090F454057CEDE196D6F4640
11472	Холодногорский	8	81	1126	42.090885999999998	42.111763000000003	44.965586000000002	44.951853999999997	0103000020E6100000010000000500000006D50627A20B45408C48145AD679464006D50627A20B4540DCBC7152987B464091F3FE3F4E0E4540DCBC7152987B464091F3FE3F4E0E45408C48145AD679464006D50627A20B45408C48145AD6794640
12354	Темнореченский	8	81	1126	41.919244999999997	41.929046	44.884115000000001	44.865214999999999	0103000020E610000001000000050000007901F6D1A9F544401B81785DBF6E46407901F6D1A9F54440977329AE2A714640643DB5FAEAF64440977329AE2A714640643DB5FAEAF644401B81785DBF6E46407901F6D1A9F544401B81785DBF6E4640
12482	Темнолесская	8	81	1126	42.017223999999999	42.084822000000003	44.883955999999998	44.832546999999998	0103000020E61000000100000005000000685A62653402454003B16CE6906A4640685A6265340245402E8D5F78257146409CFD8172DB0A45402E8D5F78257146409CFD8172DB0A454003B16CE6906A4640685A62653402454003B16CE6906A4640
11720	Ташла	8	81	1126	42.108089	42.144983000000003	45.084792999999998	45.076692000000001	0103000020E61000000100000005000000570740DCD50D4540B3EE1F0BD1894640570740DCD50D454001F73C7FDA8A4640EDBC8DCD8E12454001F73C7FDA8A4640EDBC8DCD8E124540B3EE1F0BD1894640570740DCD50D4540B3EE1F0BD1894640
12254	Татарка	8	81	1126	41.882657000000002	41.984543000000002	44.971975999999998	44.943057000000003	0103000020E61000000100000005000000F14A92E7FAF04440C7A17E17B6784640F14A92E7FAF044409A3FA6B5697C4640BC40498105FE44409A3FA6B5697C4640BC40498105FE4440C7A17E17B6784640F14A92E7FAF04440C7A17E17B6784640
12117	Сенгилеевское	8	81	1126	41.594962000000002	41.630535000000002	45.057746999999999	45.037036999999998	0103000020E610000001000000050000006F2EFEB627CC4440F8DEDFA0BD8446406F2EFEB627CC44409738F24064874640DFFDF15EB5D044409738F24064874640DFFDF15EB5D04440F8DEDFA0BD8446406F2EFEB627CC4440F8DEDFA0BD844640
57675	Садовый	8	81	1126	41.748637000000002	41.765058000000003	44.987972999999997	44.97401	0103000020E61000000100000005000000ACC95356D3DF44400DFD135CAC7C4640ACC95356D3DF44405E2A36E6757E464087C5A86BEDE144405E2A36E6757E464087C5A86BEDE144400DFD135CAC7C4640ACC95356D3DF44400DFD135CAC7C4640
12156	Приозерный	8	81	1126	41.659137999999999	41.668596999999998	45.023322999999998	45.012650000000001	0103000020E6100000010000000500000082C64CA25ED44440AF25E4839E81464082C64CA25ED444404F1F813FFC824640139A249694D544404F1F813FFC824640139A249694D54440AF25E4839E81464082C64CA25ED44440AF25E4839E814640
11718	Петропавловка	8	81	1126	42.117781999999998	42.135477999999999	45.296151999999999	45.270780000000002	0103000020E610000001000000050000005B07077B130F4540983446EBA8A246405B07077B130F45408F52094FE8A54640EBA9D557571145408F52094FE8A54640EBA9D55757114540983446EBA8A246405B07077B130F4540983446EBA8A24640
11999	Пелагиада	8	81	1126	41.970117000000002	42.050085000000003	45.252344000000001	45.184099000000003	0103000020E6100000010000000500000096253ACB2CFC4440F81C588E9097464096253ACB2CFC4440C1ABE5CE4CA0464095826E2F69064540C1ABE5CE4CA0464095826E2F69064540F81C588E9097464096253ACB2CFC4440F81C588E90974640
12605	Новый Бешпагир	8	81	1126	42.354443000000003	42.372489999999999	44.949621999999998	44.936990000000002	0103000020E61000000100000005000000E8A562635E2D4540EB56CF49EF774640E8A562635E2D4540F3C7B4368D794640240B98C0AD2F4540F3C7B4368D794640240B98C0AD2F4540EB56CF49EF774640E8A562635E2D4540EB56CF49EF774640
11903	Новомарьевская	8	81	1126	41.787354000000001	41.837355000000002	45.146872000000002	45.121813000000003	0103000020E61000000100000005000000F92F1004C8E44440249D8191978F4640F92F1004C8E444405C59A2B3CC9246403012DA722EEB44405C59A2B3CC9246403012DA722EEB4440249D8191978F4640F92F1004C8E44440249D8191978F4640
11321	Нижнерусский	8	81	1126	41.838189999999997	41.891927000000003	45.180579000000002	45.150469999999999	0103000020E61000000100000005000000C8EA56CF49EB4440BA83D89942934640C8EA56CF49EB444015AC71361D974640AFB5F7A92AF2444015AC71361D974640AFB5F7A92AF24440BA83D89942934640C8EA56CF49EB4440BA83D89942934640
11781	Надежда	8	81	1126	42.038989999999998	42.172443999999999	45.065928	45.018951999999999	0103000020E610000001000000050000007E6FD39FFD044540CE18E6046D8246407E6FD39FFD04454002F22554708846401A321EA51216454002F22554708846401A321EA512164540CE18E6046D8246407E6FD39FFD044540CE18E6046D824640
10340	Михайловск	8	81	1126	41.972776000000003	42.091461000000002	45.167979000000003	45.111567000000001	0103000020E61000000100000005000000B72A89EC83FC44400B28D4D3478E4640B72A89EC83FC444018B5FB558095464003EE79FEB40B454018B5FB558095464003EE79FEB40B45400B28D4D3478E4640B72A89EC83FC44400B28D4D3478E4640
57681	Липовчанский	8	81	1126	42.069020999999999	42.082163000000001	44.822727999999998	44.808636	0103000020E610000001000000050000005DDE1CAED5084540232F6B62816746405DDE1CAED508454072C0AE264F6946407BF83251840A454072C0AE264F6946407BF83251840A4540232F6B62816746405DDE1CAED5084540232F6B6281674640
57659	Кожевников	8	81	1126	42.147067	42.174717000000001	45.194502999999997	45.186379000000002	0103000020E6100000010000000500000011A96917D3124540A2D45E44DB97464011A96917D3124540A8FC6B79E598464012876C205D164540A8FC6B79E598464012876C205D164540A2D45E44DB97464011A96917D3124540A2D45E44DB974640
57657	Калиновка	8	81	1126	42.217314999999999	42.257550000000002	45.215148999999997	45.202080000000002	0103000020E6100000010000000500000012F758FAD01B45407D96E7C1DD99464012F758FAD01B454030629F008A9B4640DB8AFD65F720454030629F008A9B4640DB8AFD65F72045407D96E7C1DD99464012F758FAD01B45407D96E7C1DD994640
11658	Казинка	8	81	1126	42.193572000000003	42.214646999999999	45.315252000000001	45.280571999999999	0103000020E61000000100000005000000EEB5A0F7C61845402F1686C8E9A34640EEB5A0F7C6184540D2FF722D5AA846409E978A8D791B4540D2FF722D5AA846409E978A8D791B45402F1686C8E9A34640EEB5A0F7C61845402F1686C8E9A34640
11476	Дубовка	8	81	1126	42.138145999999999	42.192458999999999	45.233305000000001	45.210101000000002	0103000020E610000001000000050000005F09A4C4AE114540AFEDED96E49A46405F09A4C4AE114540247F30F0DC9D464012691B7FA2184540247F30F0DC9D464012691B7FA2184540AFEDED96E49A46405F09A4C4AE114540AFEDED96E49A4640
11388	Демино	8	81	1126	42.024383999999998	42.041542	44.989387999999998	44.977879999999999	0103000020E61000000100000005000000D845D1031F034540CCB4FD2B2B7D4640D845D1031F03454005871744A47E464089B48D3F5105454005871744A47E464089B48D3F51054540CCB4FD2B2B7D4640D845D1031F034540CCB4FD2B2B7D4640
11342	Вязники	8	81	1126	41.954441000000003	41.998593	45.125152	45.104798000000002	0103000020E61000000100000005000000147B681F2BFA4440D65757056A8D4640147B681F2BFA4440B68311FB04904640DC813AE5D1FF4440B68311FB04904640DC813AE5D1FF4440D65757056A8D4640147B681F2BFA4440D65757056A8D4640
57685	Верхнеегорлыкский	8	81	1126	41.844423999999997	41.874257	44.923243999999997	44.913944999999998	0103000020E610000001000000050000008FFAEB1516EC4440DEAB5626FC7446408FFAEB1516EC4440361D01DC2C76464048A643A7E7EF4440361D01DC2C76464048A643A7E7EF4440DEAB5626FC7446408FFAEB1516EC4440DEAB5626FC744640
11577	Верхнедубовский	8	81	1126	42.279164000000002	42.296295000000001	45.248497999999998	45.236358000000003	0103000020E610000001000000050000003B1C5DA5BB234540F1129CFA409E46403B1C5DA5BB2345408A8F4FC8CE9F4640F27B9BFEEC2545408A8F4FC8CE9F4640F27B9BFEEC254540F1129CFA409E46403B1C5DA5BB234540F1129CFA409E4640
46379	Ясный	8	81	100	43.527247000000003	43.547001000000002	45.619331000000003	45.610284999999998	0103000020E6100000010000000500000002F566D47CC34540A31EA2D11DCE464002F566D47CC345401233FB3C46CF46408DF0F62004C645401233FB3C46CF46408DF0F62004C64540A31EA2D11DCE464002F566D47CC34540A31EA2D11DCE4640
57608	Шарахалсун	8	81	100	43.689976999999999	43.716639000000001	45.422662000000003	45.404617000000002	0103000020E6100000010000000500000000FF942A51D84540EC33677DCAB3464000FF942A51D8454088A1D5C919B64640E204A6D3BADB454088A1D5C919B64640E204A6D3BADB4540EC33677DCAB3464000FF942A51D84540EC33677DCAB34640
57642	Чур	8	81	100	43.415999999999997	43.427506999999999	45.416519000000001	45.404839000000003	0103000020E610000001000000050000006891ED7C3FB545409B92ACC3D1B346406891ED7C3FB54540D1949D7E50B54640D1E7A38CB8B64540D1949D7E50B54640D1E7A38CB8B645409B92ACC3D1B346406891ED7C3FB545409B92ACC3D1B34640
10099	Троицкий	8	81	100	43.769351999999998	43.781219	45.321747999999999	45.308951999999998	0103000020E610000001000000050000005C8E57207AE24540530438BD8BA746405C8E57207AE24540D6C6D8092FA94640C501F4FBFEE34540D6C6D8092FA94640C501F4FBFEE34540530438BD8BA746405C8E57207AE24540530438BD8BA74640
10202	Таврический	8	81	100	43.579763	43.59975	45.301782000000003	45.284244000000001	0103000020E6100000010000000500000026378AAC35CA4540C80A7E1B62A4464026378AAC35CA4540C042E6CAA0A6464054E3A59BC4CC4540C042E6CAA0A6464054E3A59BC4CC4540C80A7E1B62A4464026378AAC35CA4540C80A7E1B62A44640
57636	Сабан-Антуста	8	81	100	43.824427999999997	43.847020999999998	45.505173999999997	45.500625999999997	0103000020E610000001000000050000000EF450DB86E945407EC3448314C046400EF450DB86E945400E65A88AA9C046403A03232F6BEC45400E65A88AA9C046403A03232F6BEC45407EC3448314C046400EF450DB86E945407EC3448314C04640
48160	Поперечный	8	81	100	43.249882999999997	43.265011000000001	45.424230999999999	45.420068000000001	0103000020E61000000100000005000000C669882AFC9F45404E0CC9C9C4B54640C669882AFC9F454085798F334DB64640460A65E1EBA1454085798F334DB64640460A65E1EBA145404E0CC9C9C4B54640C669882AFC9F45404E0CC9C9C4B54640
26077	Овощи	8	81	100	43.298347999999997	43.341304999999998	45.386060999999998	45.351627000000001	0103000020E61000000100000005000000DB696B4430A64540FFB1101D02AD4640DB696B4430A645406AA164726AB146400B7BDAE1AFAB45406AA164726AB146400B7BDAE1AFAB4540FFB1101D02AD4640DB696B4430A64540FFB1101D02AD4640
135	Новокучерлинский	8	81	100	43.770178999999999	43.787624000000001	45.580669999999998	45.570860000000003	0103000020E610000001000000050000007288B83995E245401B4CC3F011C946407288B83995E2454058E2016553CA4640B9C5FCDCD0E4454058E2016553CA4640B9C5FCDCD0E445401B4CC3F011C946407288B83995E245401B4CC3F011C94640
28935	Малые Ягуры	8	81	100	42.984493999999998	43.047313000000003	45.452784000000001	45.431776999999997	0103000020E61000000100000005000000DA8D3EE6037E45401E15FF7744B74640DA8D3EE6037E454077137CD3F4B946407CD6355A0E86454077137CD3F4B946407CD6355A0E8645401E15FF7744B74640DA8D3EE6037E45401E15FF7744B74640
4357	Летняя Ставка	8	81	100	43.424148000000002	43.463521	45.444248000000002	45.415640000000003	0103000020E61000000100000005000000F8544E7B4AB64540697407B133B54640F8544E7B4AB645401EA8531EDDB846402E01F8A754BB45401EA8531EDDB846402E01F8A754BB4540697407B133B54640F8544E7B4AB64540697407B133B54640
10041	Кучерла	8	81	100	43.663980000000002	43.710242999999998	45.383629999999997	45.352381000000001	0103000020E610000001000000050000005B99F04BFDD44540AB5D13D21AAD46405B99F04BFDD44540DAE1AFC91AB14640419B1C3EE9DA4540DAE1AFC91AB14640419B1C3EE9DA4540AB5D13D21AAD46405B99F04BFDD44540AB5D13D21AAD4640
57615	Куликовы Копани	8	81	100	43.552247000000001	43.581290000000003	45.325791000000002	45.308881999999997	0103000020E6100000010000000500000035289A07B0C645405A29047289A7464035289A07B0C64540632AFD84B3A94640F5BEF1B567CA4540632AFD84B3A94640F5BEF1B567CA45405A29047289A7464035289A07B0C645405A29047289A74640
5710	Красный Маныч	8	81	100	43.889052999999997	43.906759000000001	45.580159000000002	45.566374000000003	0103000020E6100000010000000500000091B41B7DCCF1454001A777F17EC8464091B41B7DCCF1454073BD6DA642CA4640452DCDAD10F4454073BD6DA642CA4640452DCDAD10F4454001A777F17EC8464091B41B7DCCF1454001A777F17EC84640
57670	Красная Поляна	8	81	100	43.377820999999997	43.395589999999999	45.343449999999997	45.327883	0103000020E61000000100000005000000FA5E43705CB045400AF5F411F8A94640FA5E43705CB04540D5E76A2BF6AB4640F44F70B1A2B24540D5E76A2BF6AB4640F44F70B1A2B245400AF5F411F8A94640FA5E43705CB045400AF5F411F8A94640
7758	Кендже-Кулак	8	81	100	43.789411999999999	43.830492	45.479016999999999	45.451892999999998	0103000020E61000000100000005000000F488D1730BE545404A253CA1D7B94640F488D1730BE54540309DD66D50BD464079CBD58F4DEA4540309DD66D50BD464079CBD58F4DEA45404A253CA1D7B94640F488D1730BE545404A253CA1D7B94640
49222	Камбулат	8	81	100	43.035384000000001	43.088366000000001	45.398308	45.360075999999999	0103000020E610000001000000050000009D6681768784454089096AF816AE46409D668176878445401ADEACC1FBB24640070ABC934F8B45401ADEACC1FBB24640070ABC934F8B454089096AF816AE46409D6681768784454089096AF816AE4640
29550	Казгулак	8	81	100	43.199568999999997	43.261831000000001	45.516018000000003	45.493575	0103000020E61000000100000005000000D0251C7A8B994540C58F31772DBF4640D0251C7A8B994540DC12B9E00CC246401C0A9FAD83A14540DC12B9E00CC246401C0A9FAD83A14540C58F31772DBF4640D0251C7A8B994540C58F31772DBF4640
47683	Березовский	8	81	100	43.327120999999998	43.340406999999999	45.482998000000002	45.473050999999998	0103000020E61000000100000005000000DB6AD619DFA94540882B67EF8CBC4640DB6AD619DFA945404704E3E0D2BD46402C2AE27492AB45404704E3E0D2BD46402C2AE27492AB4540882B67EF8CBC4640DB6AD619DFA94540882B67EF8CBC4640
9307	Труновское	8	81	874	42.071472999999997	42.181814000000003	45.521576000000003	45.460003999999998	0103000020E6100000010000000500000004C6FA0626094540BC033C69E1BA464004C6FA062609454073309B00C3C246403CFA5FAE4517454073309B00C3C246403CFA5FAE45174540BC033C69E1BA464004C6FA0626094540BC033C69E1BA4640
9894	Сухой Лог	8	81	874	42.243572999999998	42.253076999999998	45.433743999999997	45.420423	0103000020E6100000010000000500000024986A662D1F45403CBEBD6BD0B5464024986A662D1F4540096B63EC84B74640552FBFD364204540096B63EC84B74640552FBFD3642045403CBEBD6BD0B5464024986A662D1F45403CBEBD6BD0B54640
9737	Правоегорлыкский	8	81	874	42.322417999999999	42.338802999999999	45.594816999999999	45.588403	0103000020E6100000010000000500000024D236FE4429454024EF1CCA50CB464024D236FE442945406B0DA5F622CC4640B2648EE55D2B45406B0DA5F622CC4640B2648EE55D2B454024EF1CCA50CB464024D236FE4429454024EF1CCA50CB4640
6563	Подлесное	8	81	874	42.082199000000003	42.122956000000002	45.773080999999998	45.739181000000002	0103000020E61000000100000005000000C861307F850A45408C69A67B9DDE4640C861307F850A454059147651F4E246406A6CAF05BD0F454059147651F4E246406A6CAF05BD0F45408C69A67B9DDE4640C861307F850A45408C69A67B9DDE4640
9810	Новотерновский	8	81	874	42.272894000000001	42.285451999999999	45.559527000000003	45.547826000000001	0103000020E6100000010000000500000027A3CA30EE22454002F390291FC6464027A3CA30EE224540501DAB949EC74640F549EEB089244540501DAB949EC74640F549EEB08924454002F390291FC6464027A3CA30EE22454002F390291FC64640
9887	Нижняя Терновка	8	81	874	42.321879000000003	42.329343999999999	45.497202000000001	45.486221	0103000020E610000001000000050000007522C1543329454070D05E7D3CBE46407522C15433294540BEC0AC50A4BF46402191B6F1272A4540BEC0AC50A4BF46402191B6F1272A454070D05E7D3CBE46407522C1543329454070D05E7D3CBE4640
8960	Невдахин	8	81	874	41.963244000000003	41.977257999999999	45.534455999999999	45.514471	0103000020E61000000100000005000000BC0853944BFB4440C6DE8B2FDAC14640BC0853944BFB44405393E00D69C446408FE046CA16FD44405393E00D69C446408FE046CA16FD4440C6DE8B2FDAC14640BC0853944BFB4440C6DE8B2FDAC14640
9229	Ключевское	8	81	874	42.086025999999997	42.118572	45.369309000000001	45.348396999999999	0103000020E61000000100000005000000874D64E6020B45402383DC4598AC4640874D64E6020B45402A8F6E8445AF4640541C075E2D0F45402A8F6E8445AF4640541C075E2D0F45402383DC4598AC4640874D64E6020B45402383DC4598AC4640
9730	Имени Кирова	8	81	874	42.239871999999998	42.253185000000002	45.514843999999997	45.491824999999999	0103000020E61000000100000005000000F19C2D20B41E4540772D211FF4BE4640F19C2D20B41E45405A457F68E6C146403C6BB75D682045405A457F68E6C146403C6BB75D68204540772D211FF4BE4640F19C2D20B41E4540772D211FF4BE4640
8965	Донское	8	81	874	41.932898999999999	42.019891999999999	45.496139999999997	45.383541000000001	0103000020E610000001000000050000004DBC033C69F744406BD619DF17B146404DBC033C69F74440641EF98381BF4640DCB930D28B024540641EF98381BF4640DCB930D28B0245406BD619DF17B146404DBC033C69F744406BD619DF17B14640
9487	Безопасное	8	81	874	41.901386000000002	41.968139999999998	45.680349999999997	45.588169999999998	0103000020E610000001000000050000004089CF9D60F34440813E912749CB46404089CF9D60F34440B3EA73B515D7464087F9F202ECFB4440B3EA73B515D7464087F9F202ECFB4440813E912749CB46404089CF9D60F34440813E912749CB4640
8217	Сунженский	8	81	980	44.800331	44.807381999999997	44.197335000000002	44.178429000000001	0103000020E61000000100000005000000CC7C073F7166464039D4EFC2D6164640CC7C073F7166464097ADF5454219464085B01A4B5867464097ADF5454219464085B01A4B5867464039D4EFC2D6164640CC7C073F7166464039D4EFC2D6164640
8770	Степное	8	81	980	44.538229000000001	44.619149	44.288981999999997	44.253844000000001	0103000020E61000000100000005000000206118B0E44446409624CFF57D204640206118B0E4444640FB90B75CFD244640F12C4146404F4640FB90B75CFD244640F12C4146404F46409624CFF57D204640206118B0E44446409624CFF57D204640
8698	Соломенское	8	81	980	44.314467999999998	44.387284999999999	44.223922999999999	44.204689999999999	0103000020E61000000100000005000000BBD1C77C40284640BCE82B48331A4640BBD1C77C402846403EE94482A91C46409D9D0C8E923146403EE94482A91C46409D9D0C8E92314640BCE82B48331A4640BBD1C77C40284640BCE82B48331A4640
8600	Ольгино	8	81	980	44.387779000000002	44.422158000000003	44.346916999999998	44.317767000000003	0103000020E61000000100000005000000AD8905BEA2314640C05FCC96AC284640AD8905BEA231464095B6B8C6672C464055DFF9450936464095B6B8C6672C464055DFF94509364640C05FCC96AC284640AD8905BEA2314640C05FCC96AC284640
8499	Озерное	8	81	980	44.324601000000001	44.332056999999999	44.105291999999999	44.093587999999997	0103000020E61000000100000005000000DC9F8B868C29464026A60BB1FA0B4640DC9F8B868C294640E54350357A0D464035B401D8802A4640E54350357A0D464035B401D8802A464026A60BB1FA0B4640DC9F8B868C29464026A60BB1FA0B4640
8373	Новоникольский	8	81	980	44.352781	44.365861000000002	44.388989000000002	44.374597000000001	0103000020E6100000010000000500000039D384ED272D4640011764CBF22F464039D384ED272D46407BC03C64CA314640E1F08288D42E46407BC03C64CA314640E1F08288D42E4640011764CBF22F464039D384ED272D4640011764CBF22F4640
8595	Новоиргаклинский	8	81	980	44.688786999999998	44.708595000000003	44.358666999999997	44.350720000000003	0103000020E610000001000000050000007974232C2A584640CD069964E42C46407974232C2A584640C493DDCCE82D4640F88DAF3DB35A4640C493DDCCE82D4640F88DAF3DB35A4640CD069964E42C46407974232C2A584640CD069964E42C4640
8367	Никольское	8	81	980	44.259877000000003	44.291094000000001	44.439990000000002	44.421799	0103000020E61000000100000005000000C6FD47A643214640253E7782FD354640C6FD47A6432146409548A29751384640EA077591422546409548A29751384640EA07759142254640253E7782FD354640C6FD47A643214640253E7782FD354640
8504	Иргаклы	8	81	980	44.729418000000003	44.767111	44.371524000000001	44.335526000000002	0103000020E610000001000000050000008F8EAB915D5D4640967A1684F22A46408F8EAB915D5D4640EDD632198E2F464070B378B130624640EDD632198E2F464070B378B130624640967A1684F22A46408F8EAB915D5D4640967A1684F22A4640
8661	Зеленая Роща	8	81	980	44.424475999999999	44.446269000000001	44.298886000000003	44.281070999999997	0103000020E61000000100000005000000ECF7C43A55364640506D7022FA234640ECF7C43A55364640BB9D7DE541264640FC1BB4571F394640BB9D7DE541264640FC1BB4571F394640506D7022FA234640ECF7C43A55364640506D7022FA234640
8873	Восточный	8	81	980	44.715772000000001	44.734986999999997	44.249189000000001	44.234012999999997	0103000020E610000001000000050000003EB2B96A9E5B46405FEB5223F41D46403EB2B96A9E5B4640F0C2D66CE51F464019FED30D145E4640F0C2D66CE51F464019FED30D145E46405FEB5223F41D46403EB2B96A9E5B46405FEB5223F41D4640
8432	Верхнестепной	8	81	980	44.413597000000003	44.438319	44.197187	44.180374999999998	0103000020E61000000100000005000000A35C1ABFF03446400C022B8716174640A35C1ABFF03446402219726C3D194640931B45D61A3846402219726C3D194640931B45D61A3846400C022B8716174640A35C1ABFF03446400C022B8716174640
8306	Варениковское	8	81	980	44.292530999999997	44.380718999999999	44.470320999999998	44.450653000000003	0103000020E610000001000000050000007808E3A771254640126C5CFFAE3946407808E3A7712546409ECF807A333C4640A0FB7266BB3046409ECF807A333C4640A0FB7266BB304640126C5CFFAE3946407808E3A771254640126C5CFFAE394640
8210	Богдановка	8	81	980	44.717129	44.733164000000002	44.152338	44.133623999999998	0103000020E61000000100000005000000B00111E2CA5B4640F8FA5A971A114640B00111E2CA5B464012F8C3CF7F134640624D6551D85D464012F8C3CF7F134640624D6551D85D4640F8FA5A971A114640B00111E2CA5B4640F8FA5A971A114640
7756	Солдато-Александровское	8	81	857	43.706847000000003	43.789250000000003	44.287931	44.250047000000002	0103000020E610000001000000050000004B2366F679DA454041BB438A012046404B2366F679DA454096404AECDA2446401B2FDD2406E5454096404AECDA2446401B2FDD2406E5454041BB438A012046404B2366F679DA454041BB438A01204640
7630	Селивановка	8	81	857	44.009704999999997	44.048360000000002	44.508755000000001	44.488675999999998	0103000020E61000000100000005000000C8CD70033E014640882B67EF8C3E4640C8CD70033E014640975643E21E414640A03715A930064640975643E21E414640A03715A930064640882B67EF8C3E4640C8CD70033E014640882B67EF8C3E4640
7683	Правокумское	8	81	857	44.072758	44.104469000000002	44.386380000000003	44.371324000000001	0103000020E61000000100000005000000DD42572250094640261C7A8B872F4640DD425722500946400CEA5BE67431464011397D3D5F0D46400CEA5BE67431464011397D3D5F0D4640261C7A8B872F4640DD42572250094640261C7A8B872F4640
7637	Отказное	8	81	857	43.825631999999999	43.872047999999999	44.352440999999999	44.304563000000002	0103000020E61000000100000005000000FA43334FAEE945402C499EEBFB264640FA43334FAEE94540806264C91C2D46406745D4449FEF4540806264C91C2D46406745D4449FEF45402C499EEBFB264640FA43334FAEE945402C499EEBFB264640
7508	Нины	8	81	857	43.916936	43.970709999999997	44.502949999999998	44.469079000000001	0103000020E610000001000000050000003543AA285EF54540C51EDAC70A3C46403543AA285EF54540F8C264AA6040464038F3AB3940FC4540F8C264AA6040464038F3AB3940FC4540C51EDAC70A3C46403543AA285EF54540C51EDAC70A3C4640
8045	Михайловка	8	81	857	43.703451999999999	43.729241999999999	44.224479000000002	44.211713000000003	0103000020E61000000100000005000000242713B70ADA4540AC915D69191B4640242713B70ADA4540C4D155BABB1C4640506F46CD57DD4540C4D155BABB1C4640506F46CD57DD4540AC915D69191B4640242713B70ADA4540AC915D69191B4640
57668	Кононов	8	81	857	44.171950000000002	44.200749999999999	44.239643999999998	44.227553999999998	0103000020E610000001000000050000000B4625750216464078094E7D201D46400B46257502164640605793A7AC1E464004560E2DB2194640605793A7AC1E464004560E2DB219464078094E7D201D46400B4625750216464078094E7D201D4640
57651	Колесников	8	81	857	43.78642	43.807009999999998	44.255980999999998	44.241962999999998	0103000020E61000000100000005000000CD751A69A9E44540C8EBC1A4F81E4640CD751A69A9E44540DDB243FCC3204640C1C58A1A4CE74540DDB243FCC3204640C1C58A1A4CE74540C8EBC1A4F81E4640CD751A69A9E44540C8EBC1A4F81E4640
57646	Ковганский	8	81	857	43.772298999999997	43.782522	44.377715000000002	44.369242999999997	0103000020E61000000100000005000000E3DD91B1DAE2454072A3C85A432F4640E3DD91B1DAE24540B51A12F75830464044334FAE29E44540B51A12F75830464044334FAE29E4454072A3C85A432F4640E3DD91B1DAE2454072A3C85A432F4640
6603	Зеленокумск	8	81	857	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
6499	Горькая Балка	8	81	857	43.949536000000002	44.004809999999999	44.283000999999999	44.255083999999997	0103000020E61000000100000005000000F52F49658AF94540CEDDAE97A6204640F52F49658AF945401EDE736039244640CD58349D9D0046401EDE736039244640CD58349D9D004640CEDDAE97A6204640F52F49658AF94540CEDDAE97A6204640
6406	Восточный	8	81	857	44.174743999999997	44.204577	44.323152	44.308408	0103000020E610000001000000050000000B96EA025E16464092E9D0E9792746400B96EA025E16464089D1730B5D294640C44142942F1A464089D1730B5D294640C44142942F1A464092E9D0E9792746400B96EA025E16464092E9D0E979274640
8122	Андреевский	8	81	857	43.614635	43.637425999999998	44.230913000000001	44.221390999999997	0103000020E610000001000000050000000DFD135CACCE45407A50508A561C46400DFD135CACCE4540529CA38E8E1D46405FCFD72C97D14540529CA38E8E1D46405FCFD72C97D145407A50508A561C46400DFD135CACCE45407A50508A561C4640
4599	Свободы	8	81	437	43.015467999999998	43.073571000000001	44.030191000000002	44.016993999999997	0103000020E610000001000000050000003811FDDAFA814540361D01DC2C0246403811FDDAFA81454018D1764CDD0346408E7747C66A89454018D1764CDD0346408E7747C66A894540361D01DC2C0246403811FDDAFA814540361D01DC2C024640
57598	Свободы	8	81	437	43.015467999999998	43.073571000000001	44.030191000000002	44.016993999999997	0103000020E610000001000000050000003811FDDAFA814540361D01DC2C0246403811FDDAFA81454018D1764CDD0346408E7747C66A89454018D1764CDD0346408E7747C66A894540361D01DC2C0246403811FDDAFA814540361D01DC2C024640
2411	Нижнеподкумский	8	81	437	43.197978999999997	43.226491000000003	44.084251999999999	44.068463000000001	0103000020E61000000100000005000000BB2539605799454037FE4465C3084640BB25396057994540B14F00C5C80A46404FEB36A8FD9C4540B14F00C5C80A46404FEB36A8FD9C454037FE4465C3084640BB2539605799454037FE4465C3084640
57614	Констатиновская	8	81	437	43.102623000000001	43.178933999999998	44.055942000000002	44.036600999999997	0103000020E61000000100000005000000A1681EC0228D45401D007157AF044640A1681EC0228D4540863C821B290746403C122F4FE7964540863C821B290746403C122F4FE79645401D007157AF044640A1681EC0228D45401D007157AF044640
3540	Горячеводский	8	81	437	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
57595	Горячеводский	8	81	437	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
1982	Ясная Поляна	8	81	18	42.727037000000003	42.767937000000003	44.032330000000002	44.017797999999999	0103000020E61000000100000005000000B1FD648C0F5D454094F7713447024640B1FD648C0F5D45400057B26323044640B63176C24B6245400057B26323044640B63176C24B62454094F7713447024640B1FD648C0F5D454094F7713447024640
1749	Юца	8	81	18	42.944546000000003	43.031520999999998	43.985999	43.934887000000003	0103000020E61000000100000005000000A8C821E2E6784540503A9160AAF74540A8C821E2E6784540C171193735FE4540901150E108844540C171193735FE4540901150E108844540503A9160AAF74540A8C821E2E6784540503A9160AAF74540
1589	Этока	8	81	18	43.006610999999999	43.107024000000003	43.925479000000003	43.909745999999998	0103000020E610000001000000050000009D6516A1D88045405AD5928E72F445409D6516A1D880454041118B1876F645408DF161F6B28D454041118B1876F645408DF161F6B28D45405AD5928E72F445409D6516A1D88045405AD5928E72F44540
1357	Урожайный	8	81	18	42.757714	42.770363000000003	44.121381999999997	44.109642000000001	0103000020E6100000010000000500000055DCB8C5FC6045404F22C2BF080E464055DCB8C5FC6045405A290472890F4640348639419B6245405A290472890F4640348639419B6245404F22C2BF080E464055DCB8C5FC6045404F22C2BF080E4640
1517	Тамбукан	8	81	18	43.131027000000003	43.150708999999999	43.937469999999998	43.923285	0103000020E610000001000000050000004EF2237EC590454095F1EF332EF645404EF2237EC5904540957D5704FFF745403F1BB96E4A934540957D5704FFF745403F1BB96E4A93454095F1EF332EF645404EF2237EC590454095F1EF332EF64540
894	Суворовская	8	81	18	42.587825000000002	42.730117999999997	44.210084999999999	44.158805000000001	0103000020E61000000100000005000000B7627FD93D4B45407CB8E4B853144640B7627FD93D4B4540A930B610E41A4640471CB281745D4540A930B610E41A4640471CB281745D45407CB8E4B853144640B7627FD93D4B45407CB8E4B853144640
1177	Свобода	8	81	18	42.761532000000003	42.774019000000003	44.165272000000002	44.143664000000001	0103000020E61000000100000005000000C26D6DE17961454068CEFA9463124640C26D6DE179614540E67805A227154640C7BDF90D13634540E67805A227154640C7BDF90D1363454068CEFA9463124640C26D6DE17961454068CEFA9463124640
1296	Санамер	8	81	18	42.844078000000003	42.867021000000001	44.081409000000001	44.070186	0103000020E61000000100000005000000F5A276BF0A6C45408B51D7DAFB084640F5A276BF0A6C4540CF4C309C6B0A4640FDF84B8BFA6E4540CF4C309C6B0A4640FDF84B8BFA6E45408B51D7DAFB084640F5A276BF0A6C45408B51D7DAFB084640
1938	Садовое	8	81	18	42.950699999999998	42.995831000000003	44.019308000000002	44.012754000000001	0103000020E610000001000000050000005227A089B079454054724EECA10146405227A089B07945408D463EAF78024640E7ABE463777F45408D463EAF78024640E7ABE463777F454054724EECA10146405227A089B079454054724EECA1014640
652	Пятигорский	8	81	18	43.245885999999999	43.275809000000002	43.991278000000001	43.964441999999998	0103000020E61000000100000005000000AA454431799F4540C571E0D572FB4540AA454431799F4540459F8F32E2FE4540A37895B54DA34540459F8F32E2FE4540A37895B54DA34540C571E0D572FB4540AA454431799F4540C571E0D572FB4540
57655	Привольное	8	81	18	42.935023999999999	42.947591000000003	44.010550000000002	44.000455000000002	0103000020E61000000100000005000000D07CCEDDAE774540520FD1E80E004640D07CCEDDAE774540857CD0B359014640F27D71A94A794540857CD0B359014640F27D71A94A794540520FD1E80E004640D07CCEDDAE774540520FD1E80E004640
443	Подкумок	8	81	18	42.753869999999999	42.787852999999998	43.989994000000003	43.947764999999997	0103000020E61000000100000005000000BFB7E9CF7E6045408FA50F5D50F94540BFB7E9CF7E6045403D9E961FB8FE45401A87FA5DD86445403D9E961FB8FE45401A87FA5DD86445408FA50F5D50F94540BFB7E9CF7E6045408FA50F5D50F94540
1474	Новоборгустанский	8	81	18	42.635596999999997	42.665295999999998	44.056077999999999	44.049962000000001	0103000020E61000000100000005000000C537143E5B5145407905A22765064640C537143E5B51454036035C902D0746406E14596B2855454036035C902D0746406E14596B285545407905A22765064640C537143E5B5145407905A22765064640
396	Новоблагодарное	8	81	18	42.865412999999997	42.893099999999997	44.161695999999999	44.127018	0103000020E6100000010000000500000041446ADAC56E45406D0036204210464041446ADAC56E45406FF25B74B21446405F07CE19517245406FF25B74B21446405F07CE19517245406D0036204210464041446ADAC56E45406D00362042104640
768	Нижнеэтокский	8	81	18	43.363214999999997	43.386606999999998	44.013137	43.993988999999999	0103000020E61000000100000005000000543541D47DAE4540B8CA13083BFF4540543541D47DAE45400CAF2479AE014640CCB392567CB145400CAF2479AE014640CCB392567CB14540B8CA13083BFF4540543541D47DAE4540B8CA13083BFF4540
323	Нежинский	8	81	18	42.680334000000002	42.691302	43.932958999999997	43.926310999999998	0103000020E61000000100000005000000AE2D3C2F155745406876DD5B91F64540AE2D3C2F1557454022C154336BF7454067D47C957C58454022C154336BF7454067D47C957C5845406876DD5B91F64540AE2D3C2F155745406876DD5B91F64540
179	Мирный	8	81	18	42.621125999999997	42.687348999999998	43.950665999999998	43.934958000000002	0103000020E61000000100000005000000FF58880E814F4540199128B4ACF74540FF58880E814F4540A6B5696CAFF945401AF8510DFB574540A6B5696CAFF945401AF8510DFB574540199128B4ACF74540FF58880E814F4540199128B4ACF74540
267	Левоберезовский	8	81	18	42.658540000000002	42.664262999999998	43.869298000000001	43.864443000000001	0103000020E61000000100000005000000CE8DE9094B544540C9207711A6EE4540CE8DE9094B544540363D282845EF4540AF78EA9106554540363D282845EF4540AF78EA9106554540C9207711A6EE4540CE8DE9094B544540C9207711A6EE4540
1404	Имени Чкалова	8	81	18	42.698380999999998	42.718099000000002	44.101692999999997	44.089120999999999	0103000020E61000000100000005000000EA92718C6459454083312251680B4640EA92718C64594540B69DB646040D4640292504ABEA5B4540B69DB646040D4640292504ABEA5B454083312251680B4640EA92718C6459454083312251680B4640
32237	Ессентукская	8	81	18	42.845236999999997	42.897205	44.038972000000001	44.012605000000001	0103000020E61000000100000005000000402FDCB9306C45400F62670A9D014640402FDCB9306C4540D8BAD408FD04464062670A9DD7724540D8BAD408FD04464062670A9DD77245400F62670A9D014640402FDCB9306C45400F62670A9D014640
1707	Джуца	8	81	18	43.013061	43.042237999999998	43.996298000000003	43.984994	0103000020E6100000010000000500000031ED9BFBAB814540CC608C4814FE454031ED9BFBAB814540FD885FB186FF45400053060E68854540FD885FB186FF45400053060E68854540CC608C4814FE454031ED9BFBAB814540CC608C4814FE4540
22	Горный	8	81	18	42.842847999999996	42.900627	43.968043000000002	43.945875999999998	0103000020E61000000100000005000000DFBF7971E26B45402009FB7612F94540DFBF7971E26B4540950F41D5E8FB45408272DBBE47734540950F41D5E8FB45408272DBBE477345402009FB7612F94540DFBF7971E26B45402009FB7612F94540
13717	Винсады	8	81	18	42.939515	42.978555999999998	44.093938000000001	44.064233000000002	0103000020E61000000100000005000000FC8C0B0742784540782975C938084640FC8C0B074278454003ED0E29060C4640FCA6B052417D454003ED0E29060C4640FCA6B052417D4540782975C938084640FC8C0B0742784540782975C938084640
696	Верхнетамбуканский	8	81	18	43.314399999999999	43.336077000000003	43.988185000000001	43.977359	0103000020E6100000010000000500000063EE5A423EA84540C3B986191AFD454063EE5A423EA84540EAB298D87CFE45400AF8359204AB4540EAB298D87CFE45400AF8359204AB4540C3B986191AFD454063EE5A423EA84540C3B986191AFD4540
580	Быкогорка	8	81	18	42.93497	42.973418000000002	44.18777	44.174064999999999	0103000020E61000000100000005000000DD5ED218AD7745406A300DC347164640DD5ED218AD774540C095ECD8081846403BAB05F6987C4540C095ECD8081846403BAB05F6987C45406A300DC347164640DD5ED218AD7745406A300DC347164640
31982	Боргустанская	8	81	18	42.495908999999997	42.566507999999999	44.066941	44.036782000000002	0103000020E61000000100000005000000626534F2793F45406E8AC745B5044640626534F2793F45407AE1CE859108464010768A55834845407AE1CE859108464010768A55834845406E8AC745B5044640626534F2793F45406E8AC745B5044640
13675	Бекешевская	8	81	18	42.394039999999997	42.471673000000003	44.132964000000001	44.091898	0103000020E610000001000000050000006DA818E76F324540AE484C50C30B46406DA818E76F324540CEC5DFF604114640FFB3E6C75F3C4540CEC5DFF604114640FFB3E6C75F3C4540AE484C50C30B46406DA818E76F324540AE484C50C30B4640
31434	Шведино	8	81	1295	42.845965	42.923858000000003	45.426437999999997	45.391858999999997	0103000020E61000000100000005000000C347C494486C454056D28A6F28B24640C347C494486C4540C5E2378595B64640F1129CFA40764540C5E2378595B64640F1129CFA4076454056D28A6F28B24640C347C494486C454056D28A6F28B24640
31310	Шангала	8	81	1295	42.644832000000001	42.686791999999997	45.540219999999998	45.512103000000003	0103000020E6100000010000000500000007B5DFDA895245407D9752978CC1464007B5DFDA895245409352D0ED25C54640C493DDCCE85745409352D0ED25C54640C493DDCCE85745407D9752978CC1464007B5DFDA895245407D9752978CC14640
31663	Сухая Буйвола	8	81	1295	42.954230000000003	43.033650000000002	45.171371999999998	45.141441999999998	0103000020E61000000100000005000000596E6935247A4540F2237EC51A924640596E6935247A45409DB98784EF95464055C1A8A44E8445409DB98784EF95464055C1A8A44E844540F2237EC51A924640596E6935247A4540F2237EC51A924640
57622	Соленое Озеро	8	81	1295	42.827917999999997	42.866042	45.272993	45.252051999999999	0103000020E6100000010000000500000086E28E37F969454019726C3D43A0464086E28E37F9694540BA84436FF1A24640317BD976DA6E4540BA84436FF1A24640317BD976DA6E454019726C3D43A0464086E28E37F969454019726C3D43A04640
13588	Светлоград	8	81	1295	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
31525	Рогатая Балка	8	81	1295	43.017767999999997	43.069349000000003	45.214711000000001	45.187973999999997	0103000020E610000001000000050000002975C93846824540C83F33880F9846402975C93846824540B58B69A67B9B46405281936DE0884540B58B69A67B9B46405281936DE0884540C83F33880F9846402975C93846824540C83F33880F984640
31527	Пшеничный	8	81	1295	43.120499000000002	43.141097000000002	45.197940000000003	45.182650000000002	0103000020E61000000100000005000000B119E0826C8F4540A54E401361974640B119E0826C8F4540FE4811195699464028486C770F924540FE4811195699464028486C770F924540A54E401361974640B119E0826C8F4540A54E401361974640
31934	Просянка	8	81	1295	42.833640000000003	42.860922000000002	45.131219000000002	45.113965	0103000020E6100000010000000500000098512CB7B46A4540BFF1B567968E464098512CB7B46A454092CEC0C8CB90464016342DB1326E454092CEC0C8CB90464016342DB1326E4540BFF1B567968E464098512CB7B46A4540BFF1B567968E4640
31321	Прикалаусский	8	81	1295	42.803249999999998	42.824226000000003	45.484104000000002	45.473669999999998	0103000020E61000000100000005000000894160E5D0664540548CF337A1BC4640894160E5D066454070EEAF1EF7BD4640A741D13C8069454070EEAF1EF7BD4640A741D13C80694540548CF337A1BC4640894160E5D0664540548CF337A1BC4640
31797	Ореховка	8	81	1295	42.926426999999997	42.963068999999997	45.054690000000001	45.014135000000003	0103000020E61000000100000005000000D190F128957645404F5DF92CCF814640D190F1289576454089B5F814008746404D6551D8457B454089B5F814008746404D6551D8457B45404F5DF92CCF814640D190F128957645404F5DF92CCF814640
30928	Носачев	8	81	1295	42.722940999999999	42.766005999999997	45.447043000000001	45.438859999999998	0103000020E6100000010000000500000001F8A754895C4540E3C281902CB8464001F8A754895C4540EF737CB438B9464017450F7C0C624540EF737CB438B9464017450F7C0C624540E3C281902CB8464001F8A754895C4540E3C281902CB84640
31366	Николина Балка	8	81	1295	42.847949999999997	42.893351000000003	45.476874000000002	45.449648000000003	0103000020E61000000100000005000000545227A0896C45401D5BCF108EB94640545227A0896C454007280D350ABD4640A96C58535972454007280D350ABD4640A96C5853597245401D5BCF108EB94640545227A0896C45401D5BCF108EB94640
31135	Кугуты	8	81	1295	42.649979000000002	42.681564000000002	45.230341000000003	45.214005999999998	0103000020E610000001000000050000001C0B0A8332534540EA92718C649B46401C0B0A8332534540C7F65AD07B9D4640C310397D3D574540C7F65AD07B9D4640C310397D3D574540EA92718C649B46401C0B0A8332534540EA92718C649B4640
31022	Константиновское	8	81	1295	42.595092000000001	42.666922	45.316215999999997	45.281098999999998	0103000020E610000001000000050000003D0E83F92B4C45401AF8510DFBA346403D0E83F92B4C4540683C11C479A84640D07D39B35D554540683C11C479A84640D07D39B35D5545401AF8510DFBA346403D0E83F92B4C45401AF8510DFBA34640
31884	Донская Балка	8	81	1295	42.852065000000003	42.897483000000001	45.212513999999999	45.176653000000002	0103000020E610000001000000050000007B884677106D4540C2DEC4909C9646407B884677106D454098F8A3A8339B4640A5DB12B9E072454098F8A3A8339B4640A5DB12B9E0724540C2DEC4909C9646407B884677106D4540C2DEC4909C964640
31666	Гофицкое	8	81	1295	43.005560000000003	43.067382000000002	45.091214000000001	45.063986	0103000020E610000001000000050000003815A930B680454070B378B1308846403815A930B6804540FB777DE6AC8B4640672B2FF99F884540FB777DE6AC8B4640672B2FF99F88454070B378B1308846403815A930B680454070B378B130884640
31614	Горный	8	81	1295	43.129770000000001	43.144016999999998	45.335631999999997	45.32479	0103000020E610000001000000050000003F00A94D9C904540AF08FEB792A946403F00A94D9C904540DBBE47FDF5AA4640B58828266F924540DBBE47FDF5AA4640B58828266F924540AF08FEB792A946403F00A94D9C904540AF08FEB792A94640
31796	Высоцкое	8	81	1295	42.871513	42.925628000000003	45.036025000000002	45.011719999999997	0103000020E61000000100000005000000F984ECBC8D6F4540C45A7C0A80814640F984ECBC8D6F4540516B9A779C844640862172FA7A764540516B9A779C844640862172FA7A764540C45A7C0A80814640F984ECBC8D6F4540C45A7C0A80814640
31209	Благодатное	8	81	1295	42.557740000000003	42.613363999999997	45.421770000000002	45.375134000000003	0103000020E61000000100000005000000E5D539066447454010CF126404B04640E5D53906644745408B37328FFCB54640994528B6824E45408B37328FFCB54640994528B6824E454010CF126404B04640E5D539066447454010CF126404B04640
29603	Щелкан	8	81	1866	43.438808000000002	43.472737000000002	44.890022999999999	44.878227000000003	0103000020E61000000100000005000000919C4CDC2AB845406BBB09BE69704640919C4CDC2AB845400AD80E46EC714640F94D61A582BC45400AD80E46EC714640F94D61A582BC45406BBB09BE69704640919C4CDC2AB845406BBB09BE69704640
29381	Чернолесское	8	81	1866	43.673735999999998	43.745403000000003	44.736367000000001	44.697276000000002	0103000020E61000000100000005000000A51133FB3CD645409224085740594640A51133FB3CD64540446D1B46415E46408FAB915D69DF4540446D1B46415E46408FAB915D69DF45409224085740594640A51133FB3CD645409224085740594640
29734	Падинское	8	81	1866	43.129078	43.183982999999998	44.851534999999998	44.836261	0103000020E610000001000000050000000951BEA085904540CBF5B6990A6B46400951BEA0859045401E335019FF6C46408E0244C18C9745401E335019FF6C46408E0244C18C974540CBF5B6990A6B46400951BEA085904540CBF5B6990A6B4640
29833	Новый Маяк	8	81	1866	43.173751000000003	43.224649999999997	44.832017	44.808897999999999	0103000020E61000000100000005000000DB5207793D96454060E63BF889674640DB5207793D964540A75B76887F6A4640F085C954C19C4540A75B76887F6A4640F085C954C19C454060E63BF889674640DB5207793D96454060E63BF889674640
29284	Новоселицкое	8	81	1866	43.398446999999997	43.470995000000002	44.769627	44.737462000000001	0103000020E610000001000000050000003B18B14F00B345407905A227655E46403B18B14F00B345402E8F3523836246402ECA6C9049BC45402E8F3523836246402ECA6C9049BC45407905A227655E46403B18B14F00B345407905A227655E4640
29567	Китаевское	8	81	1866	43.296039	43.353090999999999	44.793253999999997	44.774214999999998	0103000020E6100000010000000500000097AB1F9BE4A545404C89247A1963464097AB1F9BE4A54540E9B5D9588965464087C1FC1532AD4540E9B5D9588965464087C1FC1532AD45404C89247A1963464097AB1F9BE4A545404C89247A19634640
29657	Журавское	8	81	1866	43.268675999999999	43.327579	44.857976000000001	44.829389999999997	0103000020E610000001000000050000002C9CA4F963A2454091D09673296A46402C9CA4F963A245405F605628D26D46409EEDD11BEEA945405F605628D26D46409EEDD11BEEA9454091D09673296A46402C9CA4F963A2454091D09673296A4640
29843	Жуковский	8	81	1866	43.138294999999999	43.157698000000003	44.774304000000001	44.763547000000003	0103000020E61000000100000005000000A4198BA6B3914540BEFA78E8BB614640A4198BA6B3914540BC94BA641C6346408352B4722F944540BC94BA641C6346408352B4722F944540BEFA78E8BB614640A4198BA6B3914540BEFA78E8BB614640
29470	Долиновка	8	81	1866	43.335951000000001	43.418559999999999	44.615499999999997	44.597248999999998	0103000020E610000001000000050000007D073F7100AB4540CB48BDA7724C46407D073F7100AB4540105839B4C84E4640F6B4C35F93B54540105839B4C84E4640F6B4C35F93B54540CB48BDA7724C46407D073F7100AB4540CB48BDA7724C4640
29731	Артезианский	8	81	1866	43.345419	43.366053999999998	44.857911999999999	44.843725999999997	0103000020E61000000100000005000000613596B036AC45407764AC36FF6B4640613596B036AC4540486C770FD06D4640F54883DBDAAE4540486C770FD06D4640F54883DBDAAE45407764AC36FF6B4640613596B036AC45407764AC36FF6B4640
28654	Южный	8	81	1413	41.079608	41.097349000000001	45.485411999999997	45.476596000000001	0103000020E61000000100000005000000FF3F4E98308A4440C4B3041901BD4640FF3F4E98308A4440008BFCFA21BE46402FA699EE758C4440008BFCFA21BE46402FA699EE758C4440C4B3041901BD4640FF3F4E98308A4440C4B3041901BD4640
28570	Чапцев	8	81	1413	41.165208	41.203592999999998	45.417366999999999	45.399979000000002	0103000020E61000000100000005000000CF842689259544401C0B0A8332B34640CF84268925954440FEB627486CB54640E658DE550F9A4440FEB627486CB54640E658DE550F9A44401C0B0A8332B34640CF842689259544401C0B0A8332B34640
28032	Фельдмаршальский	8	81	1413	41.168882000000004	41.247790000000002	45.356712999999999	45.338337000000003	0103000020E610000001000000050000000971E5EC9D9544406D0377A04EAB46400971E5EC9D9544406E8786C5A8AD46404F232D95B79F44406E8786C5A8AD46404F232D95B79F44406D0377A04EAB46400971E5EC9D9544406D0377A04EAB4640
27657	Ударный	8	81	1413	41.285527999999999	41.301122999999997	45.412742000000001	45.403756999999999	0103000020E61000000100000005000000D00B772E8CA44440FA43334FAEB34640D00B772E8CA44440C3D7D7BAD4B446406589CE328BA64440C3D7D7BAD4B446406589CE328BA64440FA43334FAEB34640D00B772E8CA44440FA43334FAEB34640
28858	Темижбекский	8	81	1413	41.021845999999996	41.058945999999999	45.457545000000003	45.434654999999999	0103000020E6100000010000000500000032C687D9CB8244407D0569C6A2B7464032C687D9CB82444063B9A5D590BA4640711DE38A8B87444063B9A5D590BA4640711DE38A8B8744407D0569C6A2B7464032C687D9CB8244407D0569C6A2B74640
28652	Славенский	8	81	1413	40.967892999999997	40.987898999999999	45.484969999999997	45.472217000000001	0103000020E610000001000000050000007F83F6EAE37B4440C0CE4D9B71BC46407F83F6EAE37B444043C5387F13BE464024607479737E444043C5387F13BE464024607479737E4440C0CE4D9B71BC46407F83F6EAE37B4440C0CE4D9B71BC4640
27426	Светлый	8	81	1413	41.304034000000001	41.331890000000001	45.555065999999997	45.538502999999999	0103000020E61000000100000005000000A06F0B96EAA6444021E692AAEDC44640A06F0B96EAA644408E8F16670CC746404AEF1B5F7BAA44408E8F16670CC746404AEF1B5F7BAA444021E692AAEDC44640A06F0B96EAA6444021E692AAEDC44640
27940	Румяная Балка	8	81	1413	41.331710999999999	41.361148999999997	45.256112999999999	45.242660000000001	0103000020E610000001000000050000009A5C8C8175AA444010069E7B0F9F46409A5C8C8175AA44404C8A8F4FC8A04640D6FD63213AAE44404C8A8F4FC8A04640D6FD63213AAE444010069E7B0F9F46409A5C8C8175AA444010069E7B0F9F4640
27846	Родионов	8	81	1413	41.471164999999999	41.481352000000001	45.268895999999998	45.254786000000003	0103000020E610000001000000050000008A027D224FBC444045BDE0D39CA046408A027D224FBC44403A03232F6BA246409EEE3CF19CBD44403A03232F6BA246409EEE3CF19CBD444045BDE0D39CA046408A027D224FBC444045BDE0D39CA04640
29031	Расшеватская	8	81	1413	41.001041000000001	41.068027999999998	45.606723000000002	45.556277000000001	0103000020E61000000100000005000000427A8A1C228044402D42B11534C74640427A8A1C22804440925D6919A9CD46402C9B3924B5884440925D6919A9CD46402C9B3924B58844402D42B11534C74640427A8A1C228044402D42B11534C74640
29197	Рассвет	8	81	1413	41.182167999999997	41.204490999999997	45.646014999999998	45.625666000000002	0103000020E610000001000000050000005930F147519744400D1CD0D215D046405930F14751974440DBDC989EB0D24640C5A9D6C22C9A4440DBDC989EB0D24640C5A9D6C22C9A44400D1CD0D215D046405930F147519744400D1CD0D215D04640
27989	Раздольное	8	81	1413	41.279958999999998	41.313448000000001	45.341904	45.319960999999999	0103000020E61000000100000005000000459C4EB2D5A344406B7F677BF4A84640459C4EB2D5A34440902FA182C3AB4640917F66101FA84440902FA182C3AB4640917F66101FA844406B7F677BF4A84640459C4EB2D5A344406B7F677BF4A84640
28946	Радуга	8	81	1413	40.90025	40.911605000000002	45.581659999999999	45.562246999999999	0103000020E61000000100000005000000AC1C5A643B73444016A3AEB5F7C74640AC1C5A643B73444018B2BAD573CA46405FEFFE78AF74444018B2BAD573CA46405FEFFE78AF74444016A3AEB5F7C74640AC1C5A643B73444016A3AEB5F7C74640
27768	Равнинный	8	81	1413	41.382007000000002	41.402112000000002	45.279209000000002	45.266618000000001	0103000020E61000000100000005000000EAEBF99AE5B044403143E38920A24640EAEBF99AE5B04440DBDFD91EBDA3464022AAF06778B34440DBDFD91EBDA3464022AAF06778B344403143E38920A24640EAEBF99AE5B044403143E38920A24640
27576	Присадовый	8	81	1413	41.297440000000002	41.322189000000002	45.458126999999998	45.446424	0103000020E61000000100000005000000D942908312A644402313F06B24B94640D942908312A644401135D1E7A3BA4640C310397D3DA944401135D1E7A3BA4640C310397D3DA944402313F06B24B94640D942908312A644402313F06B24B94640
46644	Первомайский	8	81	1413	41.030298999999999	41.060195	45.427532999999997	45.415101999999997	0103000020E61000000100000005000000FE0C6FD6E08344408940F50F22B54640FE0C6FD6E0834440FA7ABE66B9B64640FD304278B4874440FA7ABE66B9B64640FD304278B48744408940F50F22B54640FE0C6FD6E08344408940F50F22B54640
28796	Озерный	8	81	1413	40.974065000000003	41.001921000000003	45.452689999999997	45.447845999999998	0103000020E61000000100000005000000D1967329AE7C44407CD2890453B94640D1967329AE7C4440F59CF4BEF1B946407B1684F23E804440F59CF4BEF1B946407B1684F23E8044407CD2890453B94640D1967329AE7C44407CD2890453B94640
15684	Новоалександровск	8	81	1413	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
27483	Мокрая Балка	8	81	1413	41.350485999999997	41.382708000000001	45.495066000000001	45.482480000000002	0103000020E6100000010000000500000059DAA9B9DCAC4440AF7C96E7C1BD464059DAA9B9DCAC444047AE9B525EBF464073F56393FCB0444047AE9B525EBF464073F56393FCB04440AF7C96E7C1BD464059DAA9B9DCAC4440AF7C96E7C1BD4640
29023	Лиманный	8	81	1413	40.917749000000001	40.922528	45.548690999999998	45.532682000000001	0103000020E61000000100000005000000E6779ACC787544407D957CEC2EC44640E6779ACC78754440054EB6813BC6464078D2C26515764440054EB6813BC6464078D2C265157644407D957CEC2EC44640E6779ACC787544407D957CEC2EC44640
28100	Курганный	8	81	1413	41.202559999999998	41.213915	45.287211999999997	45.280673999999998	0103000020E6100000010000000500000027BD6F7CED994440336B2920EDA3464027BD6F7CED9944406682E15CC3A44640DA8F1491619B44406682E15CC3A44640DA8F1491619B4440336B2920EDA3464027BD6F7CED994440336B2920EDA34640
28512	Красночервонный	8	81	1413	41.124792999999997	41.163986000000001	45.455415000000002	45.425021999999998	0103000020E6100000010000000500000086E28E37F98F44404E0AF31E67B6464086E28E37F98F4440CE8DE9094BBA46403D80457EFD944440CE8DE9094BBA46403D80457EFD9444404E0AF31E67B6464086E28E37F98F44404E0AF31E67B64640
57652	Краснокубанский	8	81	1413	40.940925999999997	40.944896	45.445253999999998	45.444982000000003	0103000020E6100000010000000500000061FA5E437078444083A7902BF5B8464061FA5E4370784440E3344415FEB84640840F255AF2784440E3344415FEB84640840F255AF278444083A7902BF5B8464061FA5E437078444083A7902BF5B84640
27713	Краснозоринский	8	81	1413	41.355111999999998	41.384289000000003	45.368251000000001	45.355103999999997	0103000020E6100000010000000500000065355D4F74AD4440E256410C74AD464065355D4F74AD444012DC48D922AF4640359BC76130B1444012DC48D922AF4640359BC76130B14440E256410C74AD464065355D4F74AD4440E256410C74AD4640
28107	Краснодарский	8	81	1413	41.206701000000002	41.230947	45.398744999999998	45.386194000000003	0103000020E610000001000000050000007786A92D759A4440AAF413CE6EB146407786A92D759A4440C5387F130AB34640FE0DDAAB8F9D4440C5387F130AB34640FE0DDAAB8F9D4440AAF413CE6EB146407786A92D759A4440AAF413CE6EB14640
28375	Керамик	8	81	1413	41.008380000000002	41.038491999999998	45.362437999999997	45.347763	0103000020E6100000010000000500000062F888981281444022E17B7F83AC464062F8889812814440F0694E5E64AE46402D944C4EED844440F0694E5E64AE46402D944C4EED84444022E17B7F83AC464062F888981281444022E17B7F83AC4640
27673	Кармалиновская	8	81	1413	41.340487000000003	41.371550999999997	45.440739000000001	45.388737999999996	0103000020E6100000010000000500000049DBF81395AB4440315BB22AC2B1464049DBF81395AB44402F89B3226AB84640E6E5B0FB8EAF44402F89B3226AB84640E6E5B0FB8EAF4440315BB22AC2B1464049DBF81395AB4440315BB22AC2B14640
29196	Заречный	8	81	1413	41.282366000000003	41.300080999999999	45.647658999999997	45.637419999999999	0103000020E610000001000000050000004DC0AF9124A444407DE882FA96D146404DC0AF9124A44440E3FA777DE6D246405393E00D69A64440E3FA777DE6D246405393E00D69A644407DE882FA96D146404DC0AF9124A444407DE882FA96D14640
28188	Григорополисская	8	81	1413	41.030506000000003	41.085545000000003	45.323238000000003	45.276100999999997	0103000020E61000000100000005000000782AE09EE78344404AB20E4757A34640782AE09EE78344408869DFDC5FA946400DAB7823F38A44408869DFDC5FA946400DAB7823F38A44404AB20E4757A34640782AE09EE78344404AB20E4757A34640
29127	Горьковский	8	81	1413	41.186669000000002	41.206395999999998	45.665815000000002	45.646929	0103000020E61000000100000005000000A91611C5E4974440C0EAC891CED24640A91611C5E4974440D717096D39D546403A03232F6B9A4440D717096D39D546403A03232F6B9A4440C0EAC891CED24640A91611C5E4974440C0EAC891CED24640
28739	Восточный	8	81	1413	41.058909999999997	41.078313999999999	45.423073000000002	45.414468999999997	0103000020E6100000010000000500000024B4E55C8A874440581AF8510DB5464024B4E55C8A8744400A698D4127B64640D3687231068A44400A698D4127B64640D3687231068A4440581AF8510DB5464024B4E55C8A874440581AF8510DB54640
27948	Воскресенская	8	81	1413	41.280624000000003	41.306648000000003	45.27657	45.256993999999999	0103000020E61000000100000005000000823CBB7CEBA3444055A2EC2DE5A04640823CBB7CEBA34440018750A566A3464021B1DD3D40A74440018750A566A3464021B1DD3D40A7444055A2EC2DE5A04640823CBB7CEBA3444055A2EC2DE5A04640
57690	Воровский	8	81	1413	40.983254000000002	41.018836999999998	45.423091999999997	45.414026	0103000020E61000000100000005000000A2D45E44DB7D4440CBD8D0CDFEB44640A2D45E44DB7D44408099EFE027B64640357A3540698244408099EFE027B64640357A354069824440CBD8D0CDFEB44640A2D45E44DB7D4440CBD8D0CDFEB44640
27573	Виноградный	8	81	1413	41.279896000000001	41.283489000000003	45.483232000000001	45.478915999999998	0103000020E61000000100000005000000FF23D3A1D3A34440FCC3961E4DBD4640FF23D3A1D3A34440BA30D28BDABD46404CE3175E49A44440BA30D28BDABD46404CE3175E49A44440FCC3961E4DBD4640FF23D3A1D3A34440FCC3961E4DBD4640
57679	Ямангой	8	81	1312	44.829715	44.858694	44.421497000000002	44.405084000000002	0103000020E610000001000000050000001500E319346A46400211E2CAD93346401500E319346A46405A2E1B9DF3354640BEA25BAFE96D46405A2E1B9DF3354640BEA25BAFE96D46400211E2CAD93346401500E319346A46400211E2CAD9334640
57680	Уч-Тюбе	8	81	1312	44.998956999999997	45.022233	44.405599000000002	44.391759	0103000020E610000001000000050000001D8EAED2DD7F4640F374AE28253246401D8EAED2DD7F4640292504ABEA3346402CF2EB87D8824640292504ABEA3346402CF2EB87D8824640F374AE28253246401D8EAED2DD7F4640F374AE2825324640
57629	Уллуби-Юрт	8	81	1312	44.977001999999999	44.995103	44.481641000000003	44.473672000000001	0103000020E610000001000000050000003410CB660E7D4640F583BA48A13C46403410CB660E7D4640D5B48B69A63D46406493FC885F7F4640D5B48B69A63D46406493FC885F7F4640F583BA48A13C46403410CB660E7D4640F583BA48A13C4640
57599	Тукуй-Мектеб	8	81	1312	45.163843	45.206944	44.341631	44.323829000000003	0103000020E61000000100000005000000DA56B3CEF89446408A3F8A3A73294640DA56B3CEF89446405F268A90BA2B46403D0D18247D9A46405F268A90BA2B46403D0D18247D9A46408A3F8A3A73294640DA56B3CEF89446408A3F8A3A73294640
25751	Озек-Суат	8	81	1312	45.105955999999999	45.149954999999999	44.84395	44.801977999999998	0103000020E61000000100000005000000516859F78F8D4640450E1137A7664640516859F78F8D4640C7BAB88D066C4640936FB6B931934640C7BAB88D066C4640936FB6B931934640450E1137A7664640516859F78F8D4640450E1137A7664640
57609	Новкус-Артезиан	8	81	1312	44.759808	44.787269000000002	44.461101999999997	44.419539999999998	0103000020E610000001000000050000009D9E77634161464092AE997CB33546409D9E776341614640620FED63053B4640CB13083BC5644640620FED63053B4640CB13083BC564464092AE997CB33546409D9E77634161464092AE997CB3354640
25044	Нефтекумск	8	81	1312	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
57613	Махмуд-Мектеб	8	81	1312	45.189363999999998	45.220706	44.452531999999998	44.428173000000001	0103000020E6100000010000000500000016855D143D984640DE03745FCE36464016855D143D9846405D328E91EC394640F7031E18409C46405D328E91EC394640F7031E18409C4640DE03745FCE36464016855D143D984640DE03745FCE364640
57650	Кунай	8	81	1312	45.098121999999996	45.111417000000003	44.410487000000003	44.404755999999999	0103000020E610000001000000050000005182FE428F8C46400D6E6B0BCF3346405182FE428F8C4640723788D68A344640F69B89E9428E4640723788D68A344640F69B89E9428E46400D6E6B0BCF3346405182FE428F8C46400D6E6B0BCF334640
57674	Кок-Бас	8	81	1312	44.758828999999999	44.765593000000003	44.403480999999999	44.397337	0103000020E61000000100000005000000D120054F21614640D13E56F0DB324640D120054F2161464058C7F143A5334640F58590F3FE61464058C7F143A5334640F58590F3FE614640D13E56F0DB324640D120054F21614640D13E56F0DB324640
26511	Каясула	8	81	1312	44.973095000000001	45.016097000000002	44.338524	44.313277999999997	0103000020E61000000100000005000000587380608E7C46403447567E19284640587380608E7C46409F7422C1542B464028486C770F8246409F7422C1542B464028486C770F8246403447567E19284640587380608E7C46403447567E19284640
57618	Каратюбе	8	81	1312	44.619104999999998	44.700133000000001	44.537495	44.512740000000001	0103000020E6100000010000000500000021E527D53E4F4640EFACDD76A141464021E527D53E4F4640BB61DBA2CC444640D9EC48F59D594640BB61DBA2CC444640D9EC48F59D594640EFACDD76A141464021E527D53E4F4640EFACDD76A1414640
26417	Зункарь	8	81	1312	44.880892000000003	44.899684000000001	44.308698	44.299919000000003	0103000020E610000001000000050000006EA7AD11C17046407A39ECBE632646406EA7AD11C1704640992B836A83274640035E66D828734640992B836A83274640035E66D8287346407A39ECBE632646406EA7AD11C17046407A39ECBE63264640
13858	Зимняя Ставка	8	81	1312	45.320976000000002	45.336688000000002	44.920302	44.909686999999998	0103000020E610000001000000050000008466D7BD15A94640554CA59F707446408466D7BD15A94640C138B874CC754640537AA69718AB4640C138B874CC754640537AA69718AB4640554CA59F707446408466D7BD15A94640554CA59F70744640
25456	Затеречный	8	81	1312	45.190863999999998	45.236696000000002	44.803621999999997	44.780811	0103000020E61000000100000005000000EBFD463B6E984640B4AD669DF1634640EBFD463B6E9846404D2CF015DD664640098CF50D4C9E46404D2CF015DD664640098CF50D4C9E4640B4AD669DF1634640EBFD463B6E984640B4AD669DF1634640
57643	Бияш	8	81	1312	44.690206000000003	44.710661000000002	44.602454000000002	44.593333999999999	0103000020E6100000010000000500000062C092AB585846406CCD565EF24B464062C092AB5858464015AC71361D4D464076C58CF0F65A464015AC71361D4D464076C58CF0F65A46406CCD565EF24B464062C092AB585846406CCD565EF24B4640
57647	Бейсей	8	81	1312	44.923471999999997	44.940809000000002	44.414904	44.407473000000003	0103000020E61000000100000005000000C7629B54347646406380441328344640C7629B5434764640637D03931B3546402864E76D6C784640637D03931B3546402864E76D6C7846406380441328344640C7629B54347646406380441328344640
13868	Ачикулак	8	81	1312	44.807139999999997	44.862665	44.565944000000002	44.531654000000003	0103000020E610000001000000050000008FA50F5D50674640D064FF3C0D4446408FA50F5D5067464008AF5DDA70484640B13385CE6B6E464008AF5DDA70484640B13385CE6B6E4640D064FF3C0D4446408FA50F5D50674640D064FF3C0D444640
57677	Артезиан-Мангит	8	81	1312	44.751373000000001	44.765493999999997	44.518352	44.507373000000001	0103000020E61000000100000005000000780C8FFD2C604640CCEF3499F1404640780C8FFD2C60464079E8BB5B5942464061A417B5FB61464079E8BB5B5942464061A417B5FB614640CCEF3499F1404640780C8FFD2C604640CCEF3499F1404640
25935	Андрей-Курган	8	81	1312	44.881726999999998	44.898902999999997	44.623821999999997	44.597377000000002	0103000020E6100000010000000500000006802A6EDC704640F9307BD9764C464006802A6EDC7046403D433866D94F46405DA3E5400F7346403D433866D94F46405DA3E5400F734640F9307BD9764C464006802A6EDC704640F9307BD9764C4640
57633	Абрам-Тюбе	8	81	1312	45.265002000000003	45.289031999999999	44.311059	44.300828000000003	0103000020E61000000100000005000000F3AFE595EBA146404DDC2A8881264640F3AFE595EBA14640301004C8D0274640ADBF2500FFA44640301004C8D0274640ADBF2500FFA446404DDC2A8881264640F3AFE595EBA146404DDC2A8881264640
57666	Абдул-Газы	8	81	1312	45.104869000000001	45.115487000000002	44.733165	44.726703999999998	0103000020E610000001000000050000009FAEEE586C8D4640AAEFFCA2045D46409FAEEE586C8D464032C9C859D85D46407C0E2C47C88E464032C9C859D85D46407C0E2C47C88E4640AAEFFCA2045D46409FAEEE586C8D4640AAEFFCA2045D4640
15597	Усть-Невинский	8	81	216	41.941191000000003	41.962291999999998	44.546360999999997	44.530310999999998	0103000020E6100000010000000500000010255AF278F84440C2DA183BE143464010255AF278F84440A9674128EF454640E9995E622CFB4440A9674128EF454640E9995E622CFB4440C2DA183BE143464010255AF278F84440C2DA183BE1434640
57662	Степной	8	81	216	41.560502999999997	41.599075999999997	44.670378999999997	44.636125	0103000020E61000000100000005000000AA27F38FBEC744408195438B6C514640AA27F38FBEC744406C76A4FACE554640C4E8B985AECC44406C76A4FACE554640C4E8B985AECC44408195438B6C514640AA27F38FBEC744408195438B6C514640
15204	Стародворцовский	8	81	216	42.118878000000002	42.149833000000001	44.727786000000002	44.715131	0103000020E61000000100000005000000611BF164370F45408AADA069895B4640611BF164370F45404B3E7617285D4640486E4DBA2D1345404B3E7617285D4640486E4DBA2D1345408AADA069895B4640611BF164370F45408AADA069895B4640
15098	Свистуха	8	81	216	41.891818999999998	41.902104999999999	44.749523000000003	44.739421	0103000020E61000000100000005000000C879FF1F27F24440E17CEA58A55E4640C879FF1F27F24440C74CA25EF05F46406F47382D78F34440C74CA25EF05F46406F47382D78F34440E17CEA58A55E4640C879FF1F27F24440E17CEA58A55E4640
57676	Саратовский	8	81	216	41.761285000000001	41.779161999999999	44.589391999999997	44.576282999999997	0103000020E61000000100000005000000BAF770C971E14440D11E2FA4C3494640BAF770C971E1444013437232714B46409A249694BBE3444013437232714B46409A249694BBE34440D11E2FA4C3494640BAF770C971E14440D11E2FA4C3494640
15406	Рощинский	8	81	216	42.118248999999999	42.189107999999997	44.399242999999998	44.369171999999999	0103000020E6100000010000000500000071E481C8220F4540A94C3107412F464071E481C8220F4540161406651A334640BBB4E1B034184540161406651A334640BBB4E1B034184540A94C3107412F464071E481C8220F4540A94C3107412F4640
825	Родниковский	8	81	216	42.004190000000001	42.028992000000002	44.529958000000001	44.506962000000001	0103000020E61000000100000005000000317C444C890045404A287D21E4404640317C444C890045407520EBA9D54346403EEC8502B60345407520EBA9D54346403EEC8502B60345404A287D21E4404640317C444C890045404A287D21E4404640
57667	Петровский	8	81	216	41.801557000000003	41.815759	44.535997999999999	44.523114	0103000020E61000000100000005000000A070766B99E64440350A4966F5424640A070766B99E64440575C1C959B444640763579CA6AE84440575C1C959B444640763579CA6AE84440350A4966F5424640A070766B99E64440350A4966F5424640
57631	Новая Деревня	8	81	216	41.846238999999997	41.860126999999999	44.543475999999998	44.521520000000002	0103000020E61000000100000005000000C4CC3E8F51EC4440DF1AD82AC1424640C4CC3E8F51EC444098141F9F904546400BB43BA418EE444098141F9F904546400BB43BA418EE4440DF1AD82AC1424640C4CC3E8F51EC4440DF1AD82AC1424640
57579	Невинномысск	8	81	216	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
14932	Надзорное	8	81	216	41.674219999999998	41.708033	44.880366000000002	44.863591999999997	0103000020E61000000100000005000000912749D74CD644402A8BC22E8A6E4640912749D74CD64440534145D5AF70464090BE49D3A0DA4440534145D5AF70464090BE49D3A0DA44402A8BC22E8A6E4640912749D74CD644402A8BC22E8A6E4640
13025	Кочубеевское	8	81	216	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
14246	Казьминское	8	81	216	41.652841000000002	41.705212000000003	44.605798	44.566778999999997	0103000020E61000000100000005000000753E3C4B90D34440A087DA368C484640753E3C4B90D34440B9FDF2C98A4D4640965F066344DA4440B9FDF2C98A4D4640965F066344DA4440A087DA368C484640753E3C4B90D34440A087DA368C484640
14640	Заветное	8	81	216	41.584254000000001	41.655490999999998	44.764443	44.724738000000002	0103000020E610000001000000050000005247C7D5C8CA44409015FC36C45C46405247C7D5C8CA4440FC53AA44D961464042E90B21E7D34440FC53AA44D961464042E90B21E7D344409015FC36C45C46405247C7D5C8CA44409015FC36C45C4640
15681	Дегтяревский	8	81	216	41.912489999999998	41.935153999999997	44.546610999999999	44.534917999999998	0103000020E61000000100000005000000A9F6E978CCF4444057056A3178444640A9F6E978CCF4444022516859F74546409E5C5320B3F7444022516859F74546409E5C5320B3F7444057056A3178444640A9F6E978CCF4444057056A3178444640
15451	Георгиевская	8	81	216	42.082414999999997	42.119847999999998	44.463489000000003	44.413789999999999	0103000020E6100000010000000500000094D920938C0A4540B7B41A12F734464094D920938C0A45402387889B533B4640D93EE42D570F45402387889B533B4640D93EE42D570F4540B7B41A12F734464094D920938C0A4540B7B41A12F7344640
14074	Веселое	8	81	216	41.79278	41.816504999999999	44.513010000000001	44.486226000000002	0103000020E610000001000000050000002176A6D079E54440823B50A73C3E46402176A6D079E54440AF42CA4FAA4146409F02603C83E84440AF42CA4FAA4146409F02603C83E84440823B50A73C3E46402176A6D079E54440823B50A73C3E4640
14296	Беловский	8	81	216	41.645707999999999	41.669612000000001	44.647931999999997	44.624341000000001	0103000020E61000000100000005000000FE614B8FA6D24440A646E867EA4F4640FE614B8FA6D2444014048F6FEF5246402C8194D8B5D5444014048F6FEF5246402C8194D8B5D54440A646E867EA4F4640FE614B8FA6D24440A646E867EA4F4640
15288	Барсуковский	8	81	216	42.094676999999997	42.147803000000003	44.637324	44.624764999999996	0103000020E6100000010000000500000079573D601E0C4540BC57AD4CF84F464079573D601E0C45405B7A34D59351464017A06D35EB1245405B7A34D59351464017A06D35EB124540BC57AD4CF84F464079573D601E0C4540BC57AD4CF84F4640
57625	Барсуковская	8	81	216	41.794010999999998	41.837336999999998	44.787227999999999	44.741252000000003	0103000020E6100000010000000500000006D50627A2E544401C0C7558E15E464006D50627A2E544406C3F19E3C3644640895DDBDB2DEB44406C3F19E3C3644640895DDBDB2DEB44401C0C7558E15E464006D50627A2E544401C0C7558E15E4640
14724	Балахоновское	8	81	216	41.762579000000002	41.796652000000002	44.804895000000002	44.748959999999997	0103000020E61000000100000005000000E6CE4C309CE144408E01D9EBDD5F4640E6CE4C309CE1444062DBA2CC06674640812557B1F8E5444062DBA2CC06674640812557B1F8E544408E01D9EBDD5F4640E6CE4C309CE144408E01D9EBDD5F4640
14434	Андреевский	8	81	216	41.639688999999997	41.657952000000002	44.710397	44.696795999999999	0103000020E61000000100000005000000334E4354E1D14440E7FD7F9C30594640334E4354E1D144409816F549EE5A46403D2B69C537D444409816F549EE5A46403D2B69C537D44440E7FD7F9C30594640334E4354E1D14440E7FD7F9C30594640
57597	Вревское	8	81	7442	41.523420000000002	41.548949999999998	44.714950999999999	44.687043000000003	0103000020E610000001000000050000004209336DFFC244400EF96706F15746404209336DFFC244400A9FAD83835B4640D1915CFE43C644400A9FAD83835B4640D1915CFE43C644400EF96706F15746404209336DFFC244400EF96706F1574640
15728	Фруктовый	8	81	1320	42.733666999999997	42.74494	44.255108999999997	44.249712000000002	0103000020E61000000100000005000000C493DDCCE85D45409AB51490F61F4640C493DDCCE85D454027F56569A7204640BABDA4315A5F454027F56569A7204640BABDA4315A5F45409AB51490F61F4640C493DDCCE85D45409AB51490F61F4640
22991	Ульяновка	8	81	1320	42.912315	42.943925999999998	44.314335999999997	44.291801999999997	0103000020E610000001000000050000003B53E8BCC6744540257497C4592546403B53E8BCC67445404CFA7B293C2846400BEC3191D27845404CFA7B293C2846400BEC3191D2784540257497C4592546403B53E8BCC6744540257497C459254640
22116	Сухая Падина	8	81	1320	43.197763000000002	43.244278000000001	44.409810999999998	44.389369000000002	0103000020E61000000100000005000000EFAD484C50994540C289E8D7D6314640EFAD484C509945404145D5AF74344640EF906280449F45404145D5AF74344640EF906280449F4540C289E8D7D6314640EFAD484C50994540C289E8D7D6314640
23261	Сунжа	8	81	1320	42.801130000000001	42.833936999999999	44.241059	44.227263000000001	0103000020E6100000010000000500000018EC866D8B664540A14B38F4161D464018EC866D8B66454007B47405DB1E464051F69672BE6A454007B47405DB1E464051F69672BE6A4540A14B38F4161D464018EC866D8B664540A14B38F4161D4640
57649	Старотарский	8	81	1320	43.062603000000003	43.081153	44.399842	44.385252999999999	0103000020E61000000100000005000000D5D0066003884540CBD765F84F314640D5D00660038845409BC8CC052E334640747CB438638A45409BC8CC052E334640747CB438638A4540CBD765F84F314640D5D0066003884540CBD765F84F314640
57623	Славянский	8	81	1320	43.076687999999997	43.092489999999998	44.250163999999998	44.239922	0103000020E6100000010000000500000071FF91E9D0894540A3CB9BC3B51E464071FF91E9D08945407A51BB5F05204640809A5AB6D68B45407A51BB5F05204640809A5AB6D68B4540A3CB9BC3B51E464071FF91E9D0894540A3CB9BC3B51E4640
22198	Розовка	8	81	1320	43.124972999999997	43.164659999999998	44.448825999999997	44.441110000000002	0103000020E6100000010000000500000006F1811DFF8F454023F8DF4A7638464006F1811DFF8F454018CC5F2173394640CC7A31941395454018CC5F2173394640CC7A31941395454023F8DF4A7638464006F1811DFF8F454023F8DF4A76384640
13965	Прикумское	8	81	1320	42.888015000000003	42.919069999999998	44.243912999999999	44.230389000000002	0103000020E61000000100000005000000C1ADBB79AA714540D82D02637D1D4640C1ADBB79AA714540DD088B8A381F46400B5EF415A4754540DD088B8A381F46400B5EF415A4754540D82D02637D1D4640C1ADBB79AA714540D82D02637D1D4640
22655	Побегайловка	8	81	1320	42.996369999999999	43.030335000000001	44.248213999999997	44.232177999999998	0103000020E61000000100000005000000965B5A0D897F4540E36C3A02B81D4640965B5A0D897F45406534F279C51F46404B766C04E28345406534F279C51F46404B766C04E2834540E36C3A02B81D4640965B5A0D897F4540E36C3A02B81D4640
57594	Перевальный	8	81	1320	42.775905000000002	42.813015	44.402714000000003	44.388120000000001	0103000020E61000000100000005000000C5E6E3DA50634540367689EAAD314640C5E6E3DA5063454018D2E1218C334640271422E01068454018D2E1218C334640271422E010684540367689EAAD314640C5E6E3DA50634540367689EAAD314640
21822	Первомайский	8	81	1320	43.105839000000003	43.132877999999998	44.244152	44.223658999999998	0103000020E6100000010000000500000018D2E1218C8D4540603AADDBA01C464018D2E1218C8D454062A06B5F401F4640CF2D74250291454062A06B5F401F4640CF2D742502914540603AADDBA01C464018D2E1218C8D4540603AADDBA01C4640
22828	Орбельяновка	8	81	1320	42.861711999999997	42.892507000000002	44.241117000000003	44.223070999999997	0103000020E610000001000000050000000E492D944C6E4540CFD72C978D1C46400E492D944C6E45403CC1FEEBDC1E4640BD395CAB3D7245403CC1FEEBDC1E4640BD395CAB3D724540CFD72C978D1C46400E492D944C6E4540CFD72C978D1C4640
22381	Новотерский	8	81	1320	43.079410000000003	43.105156000000001	44.152634999999997	44.144181000000003	0103000020E61000000100000005000000D97C5C1B2A8A454030DAE38574124640D97C5C1B2A8A4540CB9C2E8B89134640357D76C0758D4540CB9C2E8B89134640357D76C0758D454030DAE38574124640D97C5C1B2A8A454030DAE38574124640
22310	Нижняя Александровка	8	81	1320	42.879095	42.940899000000002	44.493814	44.485429000000003	0103000020E61000000100000005000000DF89592F86704540D7C39789223E4640DF89592F867045404A27124C353F464068EBE0606F7845404A27124C353F464068EBE0606F784540D7C39789223E4640DF89592F86704540D7C39789223E4640
23183	Нижнебалковский	8	81	1320	42.758181999999998	42.777369999999998	44.289969999999997	44.283819999999999	0103000020E610000001000000050000003B35971B0C614540B1F9B836542446403B35971B0C6145401A69A9BC1D2546401D7233DC806345401A69A9BC1D2546401D7233DC80634540B1F9B836542446403B35971B0C614540B1F9B83654244640
22254	Нагутское	8	81	1320	42.836137000000001	42.918970999999999	44.455531000000001	44.428237000000003	0103000020E61000000100000005000000DFFC8689066B4540F5F75278D0364640DFFC8689066B454037A8FDD64E3A4640787C7BD7A075454037A8FDD64E3A4640787C7BD7A0754540F5F75278D0364640DFFC8689066B4540F5F75278D0364640
22031	Марьины Колодцы	8	81	1320	43.109315000000002	43.155901999999998	44.397922999999999	44.371091999999997	0103000020E610000001000000050000002BFBAE08FE8D454053E751F17F2F46402BFBAE08FE8D4540C1A90F24EF324640C4B0C398F4934540C1A90F24EF324640C4B0C398F493454053E751F17F2F46402BFBAE08FE8D454053E751F17F2F4640
22465	Ленинский	8	81	1320	43.137189999999997	43.161633000000002	44.198227000000003	44.181621999999997	0103000020E610000001000000050000004BAB21718F914540F71DC3633F1746404BAB21718F914540941799805F194640297AE063B0944540941799805F194640297AE063B0944540F71DC3633F1746404BAB21718F914540F71DC3633F174640
21626	Левокумка	8	81	1320	43.125584000000003	43.157356999999998	44.240470999999999	44.223568	0103000020E610000001000000050000005073F22213904540503750E09D1C46405073F222139045407651F4C0C71E4640F9653046249445407651F4C0C71E4640F965304624944540503750E09D1C46405073F22213904540503750E09D1C4640
22569	Кумской	8	81	1320	43.062413999999997	43.074182	44.252637	44.246153999999997	0103000020E610000001000000050000000168942EFD874540C9E369F9811F46400168942EFD8745403961C26856204640D7F9B7CB7E8945403961C26856204640D7F9B7CB7E894540C9E369F9811F46400168942EFD874540C9E369F9811F4640
22779	Кумагорск	8	81	1320	43.023300999999996	43.035563000000003	44.289712000000002	44.282684000000003	0103000020E61000000100000005000000677BF486FB8245401E8D43FD2E244640677BF486FB8245401FA16648152546404DF910548D8445401FA16648152546404DF910548D8445401E8D43FD2E244640677BF486FB8245401E8D43FD2E244640
22513	Красный Пахарь	8	81	1320	43.095534999999998	43.112872000000003	44.205491000000002	44.194122999999998	0103000020E61000000100000005000000CA4FAA7D3A8C45406133C005D9184640CA4FAA7D3A8C4540A94F72874D1A46402B51F696728E4540A94F72874D1A46402B51F696728E45406133C005D9184640CA4FAA7D3A8C45406133C005D9184640
22730	Канглы	8	81	1320	43.009017999999998	43.045839999999998	44.264631999999999	44.249447000000004	0103000020E61000000100000005000000A489778027814540EC8A19E1ED1F4640A489778027814540CFBC1C76DF214640A06CCA15DE854540CFBC1C76DF214640A06CCA15DE854540EC8A19E1ED1F4640A489778027814540EC8A19E1ED1F4640
21931	Загорский	8	81	1320	43.114668999999999	43.136811999999999	44.265031999999998	44.246909000000002	0103000020E61000000100000005000000B96E4A79AD8E4540460BD0B69A1F4640B96E4A79AD8E45405D328E91EC214640A5D93C0E839145405D328E91EC214640A5D93C0E83914540460BD0B69A1F4640B96E4A79AD8E4540460BD0B69A1F4640
57626	Евдокимовский	8	81	1320	43.188510999999998	43.202551	44.216493999999997	44.211649000000001	0103000020E61000000100000005000000D7F7E12021984540959D7E50171B4640D7F7E12021984540DEE34C13B61B4640D462F030ED994540DEE34C13B61B4640D462F030ED994540959D7E50171B4640D7F7E12021984540959D7E50171B4640
22901	Долина	8	81	1320	42.926094999999997	42.941564	44.240394000000002	44.232236999999998	0103000020E610000001000000050000009BFEEC478A764540E8F527F1B91D46409BFEEC478A764540CB13083BC51E4640A48B4D2B85784540CB13083BC51E4640A48B4D2B85784540E8F527F1B91D46409BFEEC478A764540E8F527F1B91D4640
22211	Греческое	8	81	1320	42.987152999999999	43.021154000000003	44.431944999999999	44.419725999999997	0103000020E61000000100000005000000FB928D075B7E4540F4A3E194B9354640FB928D075B7E4540DA5548F949374640FD169D2CB5824540DA5548F949374640FD169D2CB5824540F4A3E194B9354640FB928D075B7E4540F4A3E194B9354640
14015	Гражданское	8	81	1320	42.743772999999997	42.813975999999997	44.248142999999999	44.212637000000001	0103000020E61000000100000005000000EB5223F4335F4540B47570B0371B4640EB5223F4335F45409CDD5A26C31F46404CDD955D306845409CDD5A26C31F46404CDD955D30684540B47570B0371B4640EB5223F4335F4540B47570B0371B4640
22455	Бородыновка	8	81	1320	43.125484999999998	43.139885	44.155861999999999	44.131379000000003	0103000020E61000000100000005000000BC9179E40F904540CB30EE06D1104640BC9179E40F90454036583849F3134640B9196EC0E791454036583849F3134640B9196EC0E7914540CB30EE06D1104640BC9179E40F904540CB30EE06D1104640
21528	Анджиевский	8	81	1320	43.068962999999997	43.107069000000003	44.245424	44.229129999999998	0103000020E6100000010000000500000028D192C7D38845402844C021541D464028D192C7D3884540A6D3BA0D6A1F46402DB5DE6FB48D4540A6D3BA0D6A1F46402DB5DE6FB48D45402844C021541D464028D192C7D38845402844C021541D4640
57593	Острогорка	8	81	7443	42.973489999999998	42.993899999999996	44.125942999999999	44.112935999999998	0103000020E61000000100000005000000D47D00529B7C45404145D5AF740E4640D47D00529B7C45407F1475E61E10464048BF7D1D387F45407F1475E61E10464048BF7D1D387F45404145D5AF740E4640D47D00529B7C45404145D5AF740E4640
19010	Урожайное	8	81	1275	44.897888000000002	44.941088000000001	44.799529	44.780414999999998	0103000020E6100000010000000500000045BC75FEED724640672783A3E463464045BC75FEED7246400F9A5DF7566646403B545392757846400F9A5DF7566646403B54539275784640672783A3E463464045BC75FEED724640672783A3E4634640
19203	Турксад	8	81	1275	44.867570000000001	44.892533999999998	45.225909999999999	45.209110000000003	0103000020E61000000100000005000000D07EA4880C6F46401FA2D11DC49A4640D07EA4880C6F464070EB6E9EEA9C4640B648DA8D3E72464070EB6E9EEA9C4640B648DA8D3E7246401FA2D11DC49A4640D07EA4880C6F46401FA2D11DC49A4640
19211	Приозерское	8	81	1275	44.807544	44.839066000000003	45.260604000000001	45.236649999999997	0103000020E610000001000000050000005F0A0F9A5D674640984C158C4A9E46405F0A0F9A5D674640789ACC785BA14640C097C283666B4640789ACC785BA14640C097C283666B4640984C158C4A9E46405F0A0F9A5D674640984C158C4A9E4640
18894	Правокумское	8	81	1275	44.625185999999999	44.672438	44.789408999999999	44.754266000000001	0103000020E6100000010000000500000062F54718065046400C3ECDC98B60464062F54718065046408315A75A0B654640384BC972125646408315A75A0B654640384BC972125646400C3ECDC98B60464062F54718065046400C3ECDC98B604640
18797	Новокумский	8	81	1275	44.686881999999997	44.713166999999999	44.804977999999998	44.789498999999999	0103000020E61000000100000005000000041BD7BFEB574640C39CA04D0E654640041BD7BFEB574640EFFFE3840967464010CB660E495B4640EFFFE3840967464010CB660E495B4640C39CA04D0E654640041BD7BFEB574640C39CA04D0E654640
19352	Николо-Александровское	8	81	1275	44.486891	44.558593999999999	44.966211000000001	44.914372999999998	0103000020E61000000100000005000000BEDBBC71523E464036ACA92C0A754640BEDBBC71523E46408A0453CDAC7B4640F4DE1802804746408A0453CDAC7B4640F4DE18028047464036ACA92C0A754640BEDBBC71523E464036ACA92C0A754640
13304	Ленинский	8	81	1275	44.507651000000003	44.533566999999998	45.108068000000003	45.094541999999997	0103000020E610000001000000050000000F643DB5FA404640990CC7F3198C46400F643DB5FA40464040DF162CD58D4640C79C67EC4B44464040DF162CD58D4640C79C67EC4B444640990CC7F3198C46400F643DB5FA404640990CC7F3198C4640
18579	Левокумское	8	81	1275	44.635652	44.686694000000003	44.838344999999997	44.806660000000001	0103000020E6100000010000000500000089D1730B5D514640E57E87A24067464089D1730B5D514640EFE192E34E6B4640022EC896E5574640EFE192E34E6B4640022EC896E5574640E57E87A24067464089D1730B5D514640E57E87A240674640
13306	Кумская Долина	8	81	1275	44.405799999999999	44.43309	44.831364999999998	44.82253	0103000020E61000000100000005000000C05B2041F13346404CFDBCA948694640C05B2041F1334640FF04172B6A6A4640C11C3D7E6F374640FF04172B6A6A4640C11C3D7E6F3746404CFDBCA948694640C05B2041F13346404CFDBCA948694640
19526	Заря	8	81	1275	44.510983000000003	44.530450000000002	44.828161999999999	44.809269	0103000020E61000000100000005000000EFE714E4674146405455682096674640EFE714E4674146401DE56036016A4640E4141DC9E54346401DE56036016A4640E4141DC9E54346405455682096674640EFE714E4674146405455682096674640
18996	Владимировка	8	81	1275	44.757688000000002	44.794114	44.758721000000001	44.736418	0103000020E610000001000000050000002C499EEBFB604640C617EDF1425E46402C499EEBFB604640EBE40CC51D614640DBA50D87A5654640EBE40CC51D614640DBA50D87A5654640C617EDF1425E46402C499EEBFB604640C617EDF1425E4640
19055	Величаевское	8	81	1275	45.109827000000003	45.167462999999998	44.962530999999998	44.935642999999999	0103000020E61000000100000005000000E19BA6CF0E8E46409CDD5A26C3774640E19BA6CF0E8E46406E313F37347B46402025766D6F9546406E313F37347B46402025766D6F9546409CDD5A26C3774640E19BA6CF0E8E46409CDD5A26C3774640
19515	Бургун-Маджары	8	81	1275	44.460408000000001	44.494841000000001	44.834637999999998	44.822217000000002	0103000020E610000001000000050000008C683BA6EE3A46408D9B1A683E6946408C683BA6EE3A4640DAFF006BD56A464027DC2BF3563F4640DAFF006BD56A464027DC2BF3563F46408D9B1A683E6946408C683BA6EE3A46408D9B1A683E694640
17585	Эдиссия	8	81	1268	44.524996999999999	44.57056	44.055546	44.030554000000002	0103000020E61000000100000005000000C2BF081A3343464089618731E9034640C2BF081A3343464039B69E211C074640F0332E1C0849464039B69E211C074640F0332E1C0849464089618731E9034640C2BF081A3343464089618731E9034640
17768	Уваровское	8	81	1268	44.380476000000002	44.494562000000002	43.821226000000003	43.807487000000002	0103000020E61000000100000005000000DA740470B3304640FB78E8BB5BE74540DA740470B3304640FD4FFEEE1DE9454014ECBFCE4D3F4640FD4FFEEE1DE9454014ECBFCE4D3F4640FB78E8BB5BE74540DA740470B3304640FB78E8BB5BE74540
18064	Стодеревская	8	81	1268	44.824648000000003	44.853510999999997	43.730052999999998	43.713321999999998	0103000020E610000001000000050000001D5BCF108E69464037C2A2224EDB45401D5BCF108E69464060AC6F6072DD45405CE333D93F6D464060AC6F6072DD45405CE333D93F6D464037C2A2224EDB45401D5BCF108E69464037C2A2224EDB4540
17977	Серноводское	8	81	1268	44.757004999999999	44.819446999999997	43.866809000000003	43.853411999999999	0103000020E6100000010000000500000049F4328AE5604640C901BB9A3CED454049F4328AE56046407270E998F3EE454014E7A8A3E36846407270E998F3EE454014E7A8A3E3684640C901BB9A3CED454049F4328AE5604640C901BB9A3CED4540
17777	Русское	8	81	1268	44.522508999999999	44.627872000000004	43.848173000000003	43.820861999999998	0103000020E61000000100000005000000CE6E2D93E1424640BB438A0112E94540CE6E2D93E1424640D42CD0EE90EC45407D09151C5E504640D42CD0EE90EC45407D09151C5E504640BB438A0112E94540CE6E2D93E1424640BB438A0112E94540
18576	Рощино	8	81	1268	45.190918000000003	45.213160000000002	44.152861000000001	44.145999000000003	0103000020E61000000100000005000000DF1B430070984640D61F6118B0124640DF1B430070984640BCEA01F3901346405E68AED3489B4640BCEA01F3901346405E68AED3489B4640D61F6118B0124640DF1B430070984640D61F6118B0124640
17456	Ростовановское	8	81	1268	44.207748000000002	44.257199999999997	43.990591000000002	43.970306999999998	0103000020E610000001000000050000009BE7887C971A4640390A100533FC45409BE7887C971A4640215B96AFCBFE4540FE43FAEDEB204640215B96AFCBFE4540FE43FAEDEB204640390A100533FC45409BE7887C971A4640390A100533FC4540
17363	Ровный	8	81	1268	44.468358000000002	44.483567000000001	43.986466	43.974226000000002	0103000020E61000000100000005000000F568AA27F33B4640DA740470B3FC4540F568AA27F33B4640D74E948444FE454061360186E53D4640D74E948444FE454061360186E53D4640DA740470B3FC4540F568AA27F33B4640DA740470B3FC4540
57616	Пролетарский	8	81	1268	44.098197999999996	44.130107000000002	44.013727000000003	44.000241000000003	0103000020E610000001000000050000002C4487C0910C4640268FA7E5070046402C4487C0910C46403E096CCEC101464087FD9E58A71046403E096CCEC101464087FD9E58A7104640268FA7E5070046402C4487C0910C4640268FA7E507004640
57653	Привольный	8	81	1268	44.614721000000003	44.636432999999997	44.042692000000002	44.030994999999997	0103000020E610000001000000050000000C957F2DAF4E464075ABE7A4F70346400C957F2DAF4E464082E673EE760546402E8CF4A27651464082E673EE760546402E8CF4A27651464075ABE7A4F70346400C957F2DAF4E464075ABE7A4F7034640
18256	Полтавское	8	81	1268	44.743881000000002	44.779345999999997	44.031131000000002	44.009351000000002	0103000020E61000000100000005000000D28E1B7E375F4640AB97DF6932014640D28E1B7E375F46402672C119FC0346405B22179CC16346402672C119FC0346405B22179CC1634640AB97DF6932014640D28E1B7E375F4640AB97DF6932014640
57635	Новая Деревня	8	81	1268	44.389181000000001	44.423586	44.036710999999997	44.023288000000001	0103000020E61000000100000005000000BF9CD9AED0314640D331E719FB024640BF9CD9AED0314640A43330F2B20446409085E81038364640A43330F2B20446409085E81038364640D331E719FB024640BF9CD9AED0314640D331E719FB024640
18365	Мирный	8	81	1268	44.939515999999998	44.961452999999999	44.094093000000001	44.074815999999998	0103000020E61000000100000005000000CC086F0F42784640D89B189293094640CC086F0F427846402AE44A3D0B0C46400FD253E4107B46402AE44A3D0B0C46400FD253E4107B4640D89B189293094640CC086F0F42784640D89B189293094640
16928	Курская	8	81	1268	44.423828999999998	44.505189000000001	44.057892000000002	44.027287999999999	0103000020E61000000100000005000000560C57074036464060C9552C7E034640560C5707403646409B594B016907464044A67C08AA4046409B594B016907464044A67C08AA40464060C9552C7E034640560C57074036464060C9552C7E034640
13212	Кировский	8	81	1268	44.722546000000001	44.732363999999997	44.115977999999998	44.107143000000001	0103000020E6100000010000000500000085ED27637C5C4640677FA0DCB60D464085ED27637C5C46401A87FA5DD80E46404562821ABE5D46401A87FA5DD80E46404562821ABE5D4640677FA0DCB60D464085ED27637C5C4640677FA0DCB60D4640
17524	Каново	8	81	1268	44.310884000000001	44.340564000000001	44.023398999999998	44.008462000000002	0103000020E61000000100000005000000C26C020CCB2746401FA1664815014640C26C020CCB2746402AE109BDFE024640F418E599972B46402AE109BDFE024640F418E599972B46401FA1664815014640C26C020CCB2746401FA1664815014640
57661	Зайцев	8	81	1268	44.258665000000001	44.296816	44.005136	43.990358000000001	0103000020E6100000010000000500000057CF49EF1B2146407EAA0A0DC4FE454057CF49EF1B2146402104E44BA8004640FB761211FE2546402104E44BA8004640FB761211FE2546407EAA0A0DC4FE454057CF49EF1B2146407EAA0A0DC4FE4540
18261	Дыдымкин	8	81	1268	44.831394000000003	44.850295000000003	43.953943000000002	43.935029	0103000020E610000001000000050000009A0B5C1E6B6A4640E2E7BF07AFF745409A0B5C1E6B6A4640C39FE1CD1AFA4540E6797077D66C4640C39FE1CD1AFA4540E6797077D66C4640E2E7BF07AFF745409A0B5C1E6B6A4640E2E7BF07AFF74540
17270	Добровольное	8	81	1268	44.512672000000002	44.528661999999997	44.139608000000003	44.124662000000001	0103000020E6100000010000000500000097C9703C9F414640E886A6ECF40F464097C9703C9F4146404721C9ACDE114640A8514832AB4346404721C9ACDE114640A8514832AB434640E886A6ECF40F464097C9703C9F414640E886A6ECF40F4640
17967	Графский	8	81	1268	44.693601999999998	44.747895999999997	43.872508000000003	43.853588000000002	0103000020E61000000100000005000000583849F3C75846400821205F42ED4540583849F3C7584640CBBF9657AEEF454094675E0EBB5F4640CBBF9657AEEF454094675E0EBB5F46400821205F42ED4540583849F3C75846400821205F42ED4540
18077	Галюгаевская	8	81	1268	44.911856999999998	44.953609999999998	43.705952000000003	43.684938000000002	0103000020E6100000010000000500000078D0ECBAB7744640D2E4620CACD7454078D0ECBAB7744640DD4598A25CDA4540BC9179E40F7A4640DD4598A25CDA4540BC9179E40F7A4640D2E4620CACD7454078D0ECBAB7744640D2E4620CACD74540
18419	Бурунный	8	81	1268	45.047286999999997	45.055281999999998	44.045971000000002	44.038038999999998	0103000020E6100000010000000500000052431B800D8646407C7C4276DE04464052431B800D8646403FC8B260E20546405B07077B138746403FC8B260E20546405B07077B138746407C7C4276DE04464052431B800D8646407C7C4276DE044640
17876	Бугулов	8	81	1268	44.664703000000003	44.680872999999998	43.860517000000002	43.854947000000003	0103000020E61000000100000005000000CC46E7FC145546401B683EE76EED4540CC46E7FC145546407653CA6B25EE45405DDDB1D8265746407653CA6B25EE45405DDDB1D8265746401B683EE76EED4540CC46E7FC145546401B683EE76EED4540
18480	Березкин	8	81	1268	45.052416000000001	45.077694999999999	44.255200000000002	44.242434000000003	0103000020E61000000100000005000000C1E44691B586464020B8CA13081F4640C1E44691B586464038F8C264AA2046400708E6E8F189464038F8C264AA2046400708E6E8F189464020B8CA13081F4640C1E44691B586464020B8CA13081F4640
17674	Балтийский	8	81	1268	44.307955	44.332838000000002	43.877616000000003	43.852592999999999	0103000020E61000000100000005000000E1D1C6116B27464036E675C421ED4540E1D1C6116B274640223999B855F04540DB6E826F9A2A4640223999B855F04540DB6E826F9A2A464036E675C421ED4540E1D1C6116B27464036E675C421ED4540
18353	Ага-Батыр	8	81	1268	44.804704999999998	44.830585999999997	44.019106999999998	44.004519999999999	0103000020E61000000100000005000000BEF6CC9200674640C616821C94004640BEF6CC9200674640F50F221972024640FA415DA4506A4640F50F221972024640FA415DA4506A4640C616821C94004640BEF6CC9200674640C616821C94004640
16882	Штурм	8	81	745	41.263331000000001	41.289561999999997	45.804290000000002	45.781830999999997	0103000020E61000000100000005000000F18288D4B4A14440DEFFC70913E44640F18288D4B4A14440FB3F87F9F2E6464009151C5E10A54440FB3F87F9F2E6464009151C5E10A54440DEFFC70913E44640F18288D4B4A14440DEFFC70913E44640
57673	Средний	8	81	745	41.804997	41.833078999999998	45.977260000000001	45.967951999999997	0103000020E61000000100000005000000663046240AE74440840CE4D9E5FB4640663046240AE7444030D80DDB16FD464000FE2955A2EA444030D80DDB16FD464000FE2955A2EA4440840CE4D9E5FB4640663046240AE74440840CE4D9E5FB4640
16473	Родыки	8	81	745	41.930275999999999	41.979970999999999	45.962570999999997	45.930812000000003	0103000020E610000001000000050000007920B24813F74440B85CFDD824F746407920B24813F74440FC89CA8635FB4640A30392B06FFD4440FC89CA8635FB4640A30392B06FFD4440B85CFDD824F746407920B24813F74440B85CFDD824F74640
5220	Привольное	8	81	745	41.279347999999999	41.333202	45.939793999999999	45.900244999999998	0103000020E61000000100000005000000FC19DEACC1A344409AB1683A3BF34640FC19DEACC1A344400F7D772B4BF846401C7BF65CA6AA44400F7D772B4BF846401C7BF65CA6AA44409AB1683A3BF34640FC19DEACC1A344409AB1683A3BF34640
13159	Преградное	8	81	745	41.702005	41.775730000000003	45.828988000000003	45.80162	0103000020E610000001000000050000007250C24CDBD94440E6E8F17B9BE646407250C24CDBD9444063635E471CEA46405743E21E4BE3444063635E471CEA46405743E21E4BE34440E6E8F17B9BE646407250C24CDBD94440E6E8F17B9BE64640
16786	Покровское	8	81	745	41.554600999999998	41.615434999999998	45.983241	45.969737000000002	0103000020E6100000010000000500000019AA622AFDC644404F5C8E5720FC464019AA622AFDC644400D8B51D7DAFD464029E8F692C6CE44400D8B51D7DAFD464029E8F692C6CE44404F5C8E5720FC464019AA622AFDC644404F5C8E5720FC4640
16773	Новомихайловское	8	81	745	41.436678999999998	41.475710999999997	45.732726999999997	45.699092	0103000020E61000000100000005000000CCECF318E5B744409772BED87BD94640CCECF318E5B74440B6F292FFC9DD464079AC1919E4BC4440B6F292FFC9DD464079AC1919E4BC44409772BED87BD94640CCECF318E5B744409772BED87BD94640
16680	Медвеженский	8	81	745	41.590237000000002	41.612577999999999	45.737005000000003	45.721710999999999	0103000020E61000000100000005000000D0F1D1E28CCB4440EC14AB0661DC4640D0F1D1E28CCB444087FE092E56DE4640E21FB6F468CE444087FE092E56DE4640E21FB6F468CE4440EC14AB0661DC4640D0F1D1E28CCB4440EC14AB0661DC4640
16261	Ладовская Балка	8	81	745	41.351635000000002	41.436508000000003	45.653196999999999	45.602656000000003	0103000020E6100000010000000500000082902C6002AD44407D5EF1D423CD464082902C6002AD4440336C94F59BD34640A038807EDFB74440336C94F59BD34640A038807EDFB744407D5EF1D423CD464082902C6002AD44407D5EF1D423CD4640
12811	Красногвардейское	8	81	745	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
16871	Коммунар	8	81	745	41.259971	41.283642	45.868889000000003	45.846204999999998	0103000020E610000001000000050000004774CFBA46A14440185B087250EC46404774CFBA46A14440556D37C137EF4640D2E28C614EA44440556D37C137EF4640D2E28C614EA44440185B087250EC46404774CFBA46A14440185B087250EC4640
16578	Дмитриевское	8	81	745	41.850181999999997	41.929152999999999	45.832265999999997	45.792678000000002	0103000020E61000000100000005000000EDD286C3D2EC44401D21037976E54640EDD286C3D2EC44404FC939B187EA46407AFD497CEEF644404FC939B187EA46407AFD497CEEF644401D21037976E54640EDD286C3D2EC44401D21037976E54640
57687	Цветное	8	81	7441	40.90025	45.717699000000003	46.236939	43.658569	0103000020E61000000100000005000000AC1C5A643B73444068942EFD4BD44540AC1C5A643B734440CF126404541E47409BAF928FDDDB4640CF126404541E47409BAF928FDDDB464068942EFD4BD44540AC1C5A643B73444068942EFD4BD44540
57658	Прогресс	8	81	7441	43.320903999999999	43.338017000000001	43.820594999999997	43.808574	0103000020E61000000100000005000000EA93DC6113A94540AD32535A7FE74540EA93DC6113A945406C21C84109E94540FB3E1C2444AB45406C21C84109E94540FB3E1C2444AB4540AD32535A7FE74540EA93DC6113A94540AD32535A7FE74540
57582	Невинномысск	8	81	7441	41.523420000000002	42.343617999999999	44.931182999999997	44.315258	0103000020E610000001000000050000004209336DFFC24440B4E6C75F5A2846404209336DFFC24440ABCB2901317746409128B4ACFB2B4540ABCB2901317746409128B4ACFB2B4540B4E6C75F5A2846404209336DFFC24440B4E6C75F5A284640
57581	Кочубеевское	8	81	7441	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
57606	Ивановское	8	81	7441	41.841478000000002	41.898018	44.591569	44.562984	0103000020E61000000100000005000000D926158DB5EB4440EC1516DC0F484640D926158DB5EB4440E9297288B84B4640139CFA40F2F24440E9297288B84B4640139CFA40F2F24440EC1516DC0F484640D926158DB5EB4440EC1516DC0F484640
57584	Заветное	8	81	7441	41.584254000000001	41.655490999999998	44.764443	44.724738000000002	0103000020E610000001000000050000005247C7D5C8CA44409015FC36C45C46405247C7D5C8CA4440FC53AA44D961464042E90B21E7D34440FC53AA44D961464042E90B21E7D344409015FC36C45C46405247C7D5C8CA44409015FC36C45C4640
57627	Воронежское	8	81	7441	41.818786000000003	41.842573999999999	44.541716000000001	44.514243999999998	0103000020E610000001000000050000001A36CAFACDE84440051555BFD24146401A36CAFACDE8444027DC2BF356454640DE3AFF76D9EB444027DC2BF356454640DE3AFF76D9EB4440051555BFD24146401A36CAFACDE84440051555BFD2414640
57621	Барсуковская	8	81	7441	41.794010999999998	41.837336999999998	44.787227999999999	44.741252000000003	0103000020E6100000010000000500000006D50627A2E544401C0C7558E15E464006D50627A2E544406C3F19E3C3644640895DDBDB2DEB44406C3F19E3C3644640895DDBDB2DEB44401C0C7558E15E464006D50627A2E544401C0C7558E15E4640
12255	Аликоновка	8	81	1221	42.679057999999998	42.690753999999998	43.916778999999998	43.908979000000002	0103000020E61000000100000005000000280B5F5FEB5645401AE0826C59F44540280B5F5FEB5645406D54A70359F5454064CA87A06A5845406D54A70359F5454064CA87A06A5845401AE0826C59F44540280B5F5FEB5645401AE0826C59F44540
10961	Фазанный	8	81	1087	43.578899999999997	43.600568000000003	44.056376	44.020015000000001	0103000020E61000000100000005000000C3D32B6519CA4540F836FDD98F024640C3D32B6519CA4540C0232A543707464017838769DFCC4540C0232A543707464017838769DFCC4540F836FDD98F024640C3D32B6519CA4540F836FDD98F024640
10497	Старопавловская	8	81	1087	43.618955999999997	43.652535	43.851872	43.838901	0103000020E61000000100000005000000DCD440F339CF454075CAA31B61EB4540DCD440F339CF4540663046240AED4540683F524486D34540663046240AED4540683F524486D3454075CAA31B61EB4540DCD440F339CF454075CAA31B61EB4540
57602	Советская	8	81	1087	44.013263000000002	44.082360999999999	44.035744999999999	44.009357000000001	0103000020E61000000100000005000000999F1B9AB20146408D7E349C32014640999F1B9AB20146406DFFCA4A93044640A1BB24CE8A0A46406DFFCA4A93044640A1BB24CE8A0A46408D7E349C32014640999F1B9AB20146408D7E349C32014640
10870	Прогресс	8	81	1087	43.320903999999999	43.338017000000001	43.820594999999997	43.808574	0103000020E61000000100000005000000EA93DC6113A94540AD32535A7FE74540EA93DC6113A945406C21C84109E94540FB3E1C2444AB45406C21C84109E94540FB3E1C2444AB4540AD32535A7FE74540EA93DC6113A94540AD32535A7FE74540
10398	Орловка	8	81	1087	43.764519	43.801879999999997	43.997717999999999	43.976308000000003	0103000020E61000000100000005000000D71533C2DBE145405E6919A9F7FC4540D71533C2DBE14540B5503239B5FF454082A8FB00A4E64540B5503239B5FF454082A8FB00A4E645405E6919A9F7FC4540D71533C2DBE145405E6919A9F7FC4540
9803	Новопавловск	8	81	1087	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
10547	Марьинская	8	81	1087	43.456316000000001	43.510295999999997	43.896631999999997	43.86506	0103000020E610000001000000050000001E520C9068BA4540F4893C49BAEE45401E520C9068BA454006465ED6C4F24540CAA31B6151C1454006465ED6C4F24540CAA31B6151C14540F4893C49BAEE45401E520C9068BA4540F4893C49BAEE4540
10874	Комсомолец	8	81	1087	43.541198000000001	43.582861999999999	44.032271999999999	44.000416000000001	0103000020E610000001000000050000008F54DFF945C545409432A9A10D0046408F54DFF945C54540CB49287D21044640630AD6389BCA4540CB49287D21044640630AD6389BCA45409432A9A10D0046408F54DFF945C545409432A9A10D004640
10399	Коммаяк	8	81	1087	43.846193999999997	43.872452000000003	44.115803	44.095982999999997	0103000020E610000001000000050000002409C21550EC454069FCC22B490C46402409C21550EC4540ACE3F8A1D20E464037AAD381ACEF4540ACE3F8A1D20E464037AAD381ACEF454069FCC22B490C46402409C21550EC454069FCC22B490C4640
10685	Зольская	8	81	1087	43.268380000000001	43.327857000000002	43.914206999999998	43.895767999999997	0103000020E6100000010000000500000043739D465AA24540D3669C86A8F2454043739D465AA245401B6327BC04F54540E161DA37F7A945401B6327BC04F54540E161DA37F7A94540D3669C86A8F2454043739D465AA24540D3669C86A8F24540
10338	Горнозаводское	8	81	1087	43.922308000000001	43.96125	44.037916000000003	44.014887000000002	0103000020E610000001000000050000006A6B44300EF645405A1135D1E70146406A6B44300EF6454061FF756EDA044640D7A3703D0AFB454061FF756EDA044640D7A3703D0AFB45405A1135D1E70146406A6B44300EF645405A1135D1E7014640
57632	Юсуп-Кулакский	8	81	965	43.153044999999999	43.197952000000001	45.634143000000002	45.626094999999999	0103000020E610000001000000050000007DE882FA96934540359886E123D046407DE882FA9693454061FE0A992BD14640C216BB7D5699454061FE0A992BD14640C216BB7D56994540359886E123D046407DE882FA96934540359886E123D04640
9738	Тахта	8	81	965	42.092098999999997	42.163111000000001	45.914530999999997	45.889726000000003	0103000020E61000000100000005000000457F68E6C90B45405133A48AE2F14640457F68E6C90B4540CE16105A0FF54640164F3DD2E0144540CE16105A0FF54640164F3DD2E01445405133A48AE2F14640457F68E6C90B45405133A48AE2F14640
9055	Софиевский Городок	8	81	965	42.369273999999997	42.387492000000002	45.699179999999998	45.691052999999997	0103000020E61000000100000005000000ADA1D45E442F4540BE66B96C74D84640ADA1D45E442F45403602F1BA7ED9464017BB7D56993145403602F1BA7ED9464017BB7D5699314540BE66B96C74D84640ADA1D45E442F4540BE66B96C74D84640
8963	Софиевка	8	81	965	42.441929999999999	42.510696000000003	45.686526000000001	45.656706	0103000020E61000000100000005000000868F882991384540228B34F10ED44640868F88299138454046ED7E15E0D7464059198D7C5E41454046ED7E15E0D7464059198D7C5E414540228B34F10ED44640868F882991384540228B34F10ED44640
9731	Советское Руно	8	81	965	43.221074000000002	43.241439	45.721169000000003	45.706803000000001	0103000020E610000001000000050000007AFF1F274C9C45407BDB4C8578DA46407AFF1F274C9C4540CCF10A444FDC46404E7D2079E79E4540CCF10A444FDC46404E7D2079E79E45407BDB4C8578DA46407AFF1F274C9C45407BDB4C8578DA4640
8875	Родники	8	81	965	42.553275999999997	42.592218000000003	45.6357	45.618341999999998	0103000020E61000000100000005000000B2D47ABFD146454022DFA5D425CF4640B2D47ABFD14645409A081B9E5ED14640200DA7CCCD4B45409A081B9E5ED14640200DA7CCCD4B454022DFA5D425CF4640B2D47ABFD146454022DFA5D425CF4640
9642	Первомайское	8	81	965	42.182290000000002	42.256813999999999	46.075170999999997	46.037309	0103000020E61000000100000005000000A5315A4755174540596C938AC6044740A5315A4755174540C64D0D349F094740D593F947DF204540C64D0D349F094740D593F947DF204540596C938AC6044740A5315A4755174540596C938AC6044740
9586	Октябрьское	8	81	965	42.787314000000002	42.864012000000002	45.635618000000001	45.613733000000003	0103000020E610000001000000050000006BD784B4C6644540EDBC8DCD8ECE46406BD784B4C6644540DD5F3DEE5BD1464000ADF9F1976E4540DD5F3DEE5BD1464000ADF9F1976E4540EDBC8DCD8ECE46406BD784B4C6644540EDBC8DCD8ECE4640
57641	Нижний Барханчак	8	81	965	42.967759000000001	42.982813999999998	45.626404000000001	45.616658999999999	0103000020E6100000010000000500000070B4E386DF7B45405CE49EAEEECE464070B4E386DF7B4540B30A9B012ED04640850662D9CC7D4540B30A9B012ED04640850662D9CC7D45405CE49EAEEECE464070B4E386DF7B45405CE49EAEEECE4640
9309	Мелиорация	8	81	965	42.951839999999997	42.965701000000003	45.653815000000002	45.641018000000003	0103000020E610000001000000050000002783A3E4D5794540DC12B9E00CD246402783A3E4D57945402F51BD35B0D34640755B22179C7B45402F51BD35B0D34640755B22179C7B4540DC12B9E00CD246402783A3E4D5794540DC12B9E00CD24640
57634	Малый Барханчак	8	81	965	43.047699999999999	43.088250000000002	45.592230999999998	45.582852000000003	0103000020E6100000010000000500000075029A081B8645404034F3E49ACA464075029A081B864540B456B439CECB46409EEFA7C64B8B4540B456B439CECB46409EEFA7C64B8B45404034F3E49ACA464075029A081B8645404034F3E49ACA4640
9225	Лиман	8	81	965	42.994563999999997	43.034818000000001	45.752307000000002	45.729286000000002	0103000020E61000000100000005000000B4E386DF4D7F454020B75F3E59DD4640B4E386DF4D7F4540A4C684984BE04640F4A78DEA74844540A4C684984BE04640F4A78DEA7484454020B75F3E59DD4640B4E386DF4D7F454020B75F3E59DD4640
9148	Лесная Дача	8	81	965	42.219318000000001	42.233961000000001	45.804510000000001	45.796813	0103000020E610000001000000050000004AB6BA9C121C45408A03E8F7FDE546404AB6BA9C121C454009A7052FFAE646400DC51D6FF21D454009A7052FFAE646400DC51D6FF21D45408A03E8F7FDE546404AB6BA9C121C45408A03E8F7FDE54640
9488	Крестьянское	8	81	965	42.908290000000001	42.936101999999998	45.583098	45.562196999999998	0103000020E6100000010000000500000055A4C2D84274454064744012F6C7464055A4C2D842744540772E8CF4A2CA46402FDCB930D2774540772E8CF4A2CA46402FDCB930D277454064744012F6C7464055A4C2D84274454064744012F6C74640
9112	Красочный	8	81	965	42.499583999999999	42.545425000000002	45.836303999999998	45.815139000000002	0103000020E610000001000000050000006CCD565EF23F4540DA58897956E846406CCD565EF23F4540CAC16C020CEB4640DDB5847CD0454540CAC16C020CEB4640DDB5847CD0454540DA58897956E846406CCD565EF23F4540DA58897956E84640
9214	Красная Поляна	8	81	965	42.062013999999998	42.098045999999997	45.829270999999999	45.814323000000002	0103000020E6100000010000000500000073F22213F0074540B8B06EBC3BE8464073F22213F0074540B742588D25EA464076C075C58C0C4540B742588D25EA464076C075C58C0C4540B8B06EBC3BE8464073F22213F0074540B8B06EBC3BE84640
57640	Кочержинский	8	81	965	42.955514000000001	43.004283999999998	45.782170000000001	45.749111999999997	0103000020E61000000100000005000000616F62484E7A45404485EAE6E2DF4640616F62484E7A4540C7F484251EE44640B2F2CB608C804540C7F484251EE44640B2F2CB608C8045404485EAE6E2DF4640616F62484E7A45404485EAE6E2DF4640
9060	Кевсала	8	81	965	42.646197999999998	42.730477999999998	45.816307999999999	45.783628	0103000020E61000000100000005000000CC5EB69DB65245406D1D1CEC4DE44640CC5EB69DB652454049BBD1C77CE846404739984D805D454049BBD1C77CE846404739984D805D45406D1D1CEC4DE44640CC5EB69DB65245406D1D1CEC4DE44640
8050	Ипатово	8	81	965	42.850195999999997	42.943944000000002	45.734180000000002	45.685437	0103000020E610000001000000050000005298F738D36C4540F33B4D66BCD746405298F738D36C45404BB0389CF9DD4640B2A03028D37845404BB0389CF9DD4640B2A03028D3784540F33B4D66BCD746405298F738D36C4540F33B4D66BCD74640
8958	Золотаревка	8	81	965	42.516337	42.562502000000002	45.653103000000002	45.634912	0103000020E610000001000000050000007D5BB0541742454042EBE1CB44D146407D5BB05417424540B2F50CE198D34640A1F7C61000484540B2F50CE198D34640A1F7C6100048454042EBE1CB44D146407D5BB0541742454042EBE1CB44D14640
8817	Дружный	8	81	965	42.891680000000001	42.911479	45.870251000000003	45.859419000000003	0103000020E61000000100000005000000A73FFB9122724540D047197101EE4640A73FFB9122724540D927806264EF4640D2FE0758AB744540D927806264EF4640D2FE0758AB744540D047197101EE4640A73FFB9122724540D047197101EE4640
8819	Добровольное	8	81	965	42.386980000000001	42.416705	45.603740000000002	45.585059999999999	0103000020E61000000100000005000000611A868F883145405019FF3EE3CA4640611A868F88314540BEA4315A47CD4640338AE59656354540BEA4315A47CD4640338AE596563545405019FF3EE3CA4640611A868F883145405019FF3EE3CA4640
8769	Винодельненский	8	81	965	43.029356	43.055855999999999	45.825296000000002	45.811219000000001	0103000020E610000001000000050000007FF8F9EFC183454069723106D6E746407FF8F9EFC183454083C2A04CA3E9464087A4164A2687454083C2A04CA3E9464087A4164A2687454069723106D6E746407FF8F9EFC183454069723106D6E74640
9396	Верхний Барханчак	8	81	965	43.023256000000003	43.040190000000003	45.602473000000003	45.592199999999998	0103000020E61000000100000005000000C8B7770DFA8245407958A835CDCB4640C8B7770DFA8245408CDCD3D51DCD464029D027F2248545408CDCD3D51DCD464029D027F2248545407958A835CDCB4640C8B7770DFA8245407958A835CDCB4640
8695	Бурукшун	8	81	965	42.517055999999997	42.563426999999997	45.922324000000003	45.894989000000002	0103000020E61000000100000005000000AC1919E42E424540CFA3E2FF8EF24640AC1919E42E42454070287CB60EF6464079573D601E48454070287CB60EF6464079573D601E484540CFA3E2FF8EF24640AC1919E42E424540CFA3E2FF8EF24640
8596	Большевик	8	81	965	42.292064000000003	42.328130999999999	45.872290999999997	45.837170999999998	0103000020E61000000100000005000000632B685A622545406E14596B28EB4640632B685A622545402DCC423BA7EF4640E2E65432002A45402DCC423BA7EF4640E2E65432002A45406E14596B28EB4640632B685A622545406E14596B28EB4640
8599	Большая Джалга	8	81	965	42.650671000000003	42.721746000000003	45.994154999999999	45.948599000000002	0103000020E6100000010000000500000052BAF42F49534540580229B16BF9464052BAF42F49534540D313967840FF46406902452C625C4540D313967840FF46406902452C625C4540580229B16BF9464052BAF42F49534540580229B16BF94640
6880	Широбоков	8	81	744	41.762821000000002	41.779412999999998	45.349809	45.337057000000001	0103000020E61000000100000005000000DCD9571EA4E14440A6F10BAF24AB4640DCD9571EA4E14440596C938AC6AC4640E38920CEC3E34440596C938AC6AC4640E38920CEC3E34440A6F10BAF24AB4640DCD9571EA4E14440A6F10BAF24AB4640
7502	Филимоновская	8	81	744	41.642527999999999	41.672235000000001	45.163333999999999	45.13682	0103000020E61000000100000005000000D461855B3ED2444028B8585183914640D461855B3ED244409529E620E8944640001DE6CB0BD644409529E620E8944640001DE6CB0BD6444028B8585183914640D461855B3ED2444028B8585183914640
6952	Тищенское	8	81	744	41.639868999999997	41.687730999999999	45.477044999999997	45.443964000000001	0103000020E61000000100000005000000B35C363AE7D14440F94CF6CFD3B84640B35C363AE7D1444033DC80CF0FBD464002B9C49107D8444033DC80CF0FBD464002B9C49107D84440F94CF6CFD3B84640B35C363AE7D14440F94CF6CFD3B84640
57665	Сухой	8	81	744	41.644917	41.702382999999998	45.277901999999997	45.262317000000003	0103000020E6100000010000000500000035D1E7A38CD24440A9177C9A93A1464035D1E7A38CD244401ABFF04A92A346401822A7AFE7D944401ABFF04A92A346401822A7AFE7D94440A9177C9A93A1464035D1E7A38CD24440A9177C9A93A14640
7507	Староизобильная	8	81	744	41.64922	41.699086000000001	45.306562	45.279761000000001	0103000020E610000001000000050000005EF415A419D344401FD95C35CFA346405EF415A419D344402219726C3DA74640B58B69A67BD944402219726C3DA74640B58B69A67BD944401FD95C35CFA346405EF415A419D344401FD95C35CFA34640
57619	Спорный	8	81	744	41.754835	41.788989000000001	45.331583000000002	45.295676999999998	0103000020E610000001000000050000002670EB6E9EE04440F69672BED8A546402670EB6E9EE044406D74CE4F71AA4640AEF36F97FDE444406D74CE4F71AA4640AEF36F97FDE44440F69672BED8A546402670EB6E9EE04440F69672BED8A54640
6407	Солнечнодольск	8	81	744	41.483651999999999	41.549174999999998	45.322755999999998	45.290762999999998	0103000020E610000001000000050000008F52094FE8BD444084F1D3B837A546408F52094FE8BD44403C4B901150A94640F163CC5D4BC644403C4B901150A94640F163CC5D4BC6444084F1D3B837A546408F52094FE8BD444084F1D3B837A54640
7563	Смыков	8	81	744	41.535952000000002	41.558014	45.274363000000001	45.262856999999997	0103000020E61000000100000005000000E71C3C139AC444402843554CA5A14640E71C3C139AC44440C11DA8531EA34640E65AB4006DC74440C11DA8531EA34640E65AB4006DC744402843554CA5A14640E71C3C139AC444402843554CA5A14640
6700	Рыздвяный	8	81	744	41.828470000000003	41.856965000000002	45.288176	45.257241999999998	0103000020E61000000100000005000000CBDB114E0BEA44402D944C4EEDA04640CBDB114E0BEA4440FDBE7FF3E2A4464088687407B1ED4440FDBE7FF3E2A4464088687407B1ED44402D944C4EEDA04640CBDB114E0BEA44402D944C4EEDA04640
7681	Рождественская	8	81	744	41.773772000000001	41.855823999999998	45.252127999999999	45.194623999999997	0103000020E61000000100000005000000BF47FDF50AE3444023827170E9984640BF47FDF50AE34440F433F5BA45A04640E2900DA48BED4440F433F5BA45A04640E2900DA48BED444023827170E9984640BF47FDF50AE3444023827170E9984640
7027	Птичье	8	81	744	41.686599000000001	41.743983999999998	45.542057	45.504125000000002	0103000020E61000000100000005000000B03BDD79E2D744404A0C022B87C04640B03BDD79E2D74440B0C8AF1F62C54640A65F22DE3ADF4440B0C8AF1F62C54640A65F22DE3ADF44404A0C022B87C04640B03BDD79E2D744404A0C022B87C04640
7762	Подлужное	8	81	744	41.944074000000001	41.996895000000002	45.292855000000003	45.257894999999998	0103000020E610000001000000050000008080B56AD7F84440A5660FB402A146408080B56AD7F844402CBCCB457CA54640E1455F419AFF44402CBCCB457CA54640E1455F419AFF4440A5660FB402A146408080B56AD7F84440A5660FB402A14640
7128	Передовой	8	81	744	41.503135999999998	41.568291000000002	45.451242000000001	45.435053000000003	0103000020E610000001000000050000005AB8ACC266C044406B8313D1AFB746405AB8ACC266C04440734A404CC2B946403ACE6DC2BDC84440734A404CC2B946403ACE6DC2BDC844406B8313D1AFB746405AB8ACC266C044406B8313D1AFB74640
7234	Новотроицкая	8	81	744	41.498950000000001	41.564922000000003	45.419770999999997	45.307690000000001	0103000020E610000001000000050000006B2BF697DDBF444033A7CB6262A746406B2BF697DDBF444094675E0EBBB546403D65355D4FC8444094675E0EBBB546403D65355D4FC8444033A7CB6262A746406B2BF697DDBF444033A7CB6262A74640
6877	Новоизобильный	8	81	744	41.704889000000001	41.722028999999999	45.426760999999999	45.412919000000002	0103000020E61000000100000005000000B32781CD39DA4440D272A087DAB44640B32781CD39DA4440A81ABD1AA0B64640BDE13E726BDC4440A81ABD1AA0B64640BDE13E726BDC4440D272A087DAB44640B32781CD39DA4440D272A087DAB44640
57682	Найденовка	8	81	744	41.797811000000003	41.815561000000002	45.347591999999999	45.323700000000002	0103000020E61000000100000005000000CDB1BCAB1EE644408CDB68006FA94640CDB1BCAB1EE64440F52C08E57DAC46405072874D64E84440F52C08E57DAC46405072874D64E844408CDB68006FA94640CDB1BCAB1EE644408CDB68006FA94640
7820	Московское	8	81	744	41.889412	41.968885999999998	45.328592	45.246955999999997	0103000020E61000000100000005000000C1559E40D8F1444086C613419C9F4640C1559E40D8F1444016DD7A4D0FAA4640B0C6D97404FC444016DD7A4D0FAA4640B0C6D97404FC444086C613419C9F4640C1559E40D8F1444086C613419C9F4640
7091	Красная Балка	8	81	744	41.960656999999998	41.984076000000002	45.309483999999998	45.285246000000001	0103000020E6100000010000000500000034D6FECEF6FA44404CA8E0F082A4464034D6FECEF6FA44405051F52B9DA74640A663CE33F6FD44405051F52B9DA74640A663CE33F6FD44404CA8E0F082A4464034D6FECEF6FA44404CA8E0F082A44640
7415	Каменнобродская	8	81	744	41.491916000000003	41.540802999999997	45.203496999999999	45.163645000000002	0103000020E6100000010000000500000088307E1AF7BE4440B493C151F294464088307E1AF7BE4440C4EA8F300C9A4640124A5F0839C54440C4EA8F300C9A4640124A5F0839C54440B493C151F294464088307E1AF7BE4440B493C151F2944640
5219	Изобильный	8	81	744	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
7216	Гаевская	8	81	744	41.470905000000002	41.495742999999997	45.561672999999999	45.544770999999997	0103000020E61000000100000005000000EE42739D46BC444094675E0EBBC54640EE42739D46BC4440EA059FE6E4C74640471CB28174BF4440EA059FE6E4C74640471CB28174BF444094675E0EBBC54640EE42739D46BC444094675E0EBBC54640
57663	Беляев	8	81	744	41.841890999999997	41.877023999999999	45.373893000000002	45.333869999999997	0103000020E61000000100000005000000FBE59315C3EB4440C98E8D40BCAA4640FBE59315C3EB4440079ACFB9DBAF46404FE78A5242F04440079ACFB9DBAF46404FE78A5242F04440C98E8D40BCAA4640FBE59315C3EB4440C98E8D40BCAA4640
4767	Иноземцево	8	81	686	43.046495999999998	43.142310000000002	44.125076	44.069375999999998	0103000020E6100000010000000500000089B2B794F38545404B901150E108464089B2B794F3854540DBC1887D0210464067F2CD3637924540DBC1887D0210464067F2CD36379245404B901150E108464089B2B794F38545404B901150E1084640
1644	Тугулук	8	81	157	42.211520999999998	42.276046999999998	45.350411000000001	45.314535999999997	0103000020E6100000010000000500000067B5C01E131B454013B534B742A8464067B5C01E131B45404F948444DAAC464057941282552345404F948444DAAC4640579412825523454013B534B742A8464067B5C01E131B454013B534B742A84640
1401	Старомарьевка	8	81	157	42.187562999999997	42.292386999999998	45.107801000000002	45.069422000000003	0103000020E6100000010000000500000046787B1002184540BCCFF1D1E288464046787B1002184540F1BC546CCC8D46404563EDEF6C254540F1BC546CCC8D46404563EDEF6C254540BCCFF1D1E288464046787B1002184540BCCFF1D1E2884640
1254	Спицевка	8	81	157	42.481302999999997	42.532094000000001	45.135433999999997	45.109467000000002	0103000020E61000000100000005000000BC3B32569B3D4540E17EC003038E4640BC3B32569B3D45401B62BCE655914640EC32FCA71B4445401B62BCE655914640EC32FCA71B444540E17EC003038E4640BC3B32569B3D4540E17EC003038E4640
1127	Сергиевское	8	81	157	42.681061	42.718153000000001	44.977032000000001	44.933684	0103000020E6100000010000000500000060CAC0012D574540346612F58277464060CAC0012D5745409F9273620F7D46401C430070EC5B45409F9273620F7D46401C430070EC5B4540346612F58277464060CAC0012D574540346612F582774640
57671	Октябрь	8	81	157	42.791096000000003	42.816364999999998	45.020577000000003	45.001140999999997	0103000020E610000001000000050000008BFF3BA242654540A5D76663258046408BFF3BA24265454060066344A2824640AD4CF8A57E68454060066344A2824640AD4CF8A57E684540A5D76663258046408BFF3BA242654540A5D7666325804640
1358	Новоспицевский	8	81	157	42.644221000000002	42.654318000000004	45.115980999999998	45.106096000000001	0103000020E61000000100000005000000BE326FD575524540431EC18D948D4640BE326FD5755245408BFA2477D88E4640929735B1C05345408BFA2477D88E4640929735B1C0534540431EC18D948D4640BE326FD575524540431EC18D948D4640
891	Нагорный	8	81	157	42.400877000000001	42.413282000000002	45.080415000000002	45.069422000000003	0103000020E61000000100000005000000FB5B02F04F334540BCCFF1D1E2884640FB5B02F04F334540CE8DE9094B8A46404303B16CE6344540CE8DE9094B8A46404303B16CE6344540BCCFF1D1E2884640FB5B02F04F334540BCCFF1D1E2884640
941	Кугульта	8	81	157	42.352341000000003	42.421655000000001	45.382358000000004	45.345742999999999	0103000020E610000001000000050000001D058882192D454014E97E4E41AC46401D058882192D454097AE601BF1B04640F29881CAF835454097AE601BF1B04640F29881CAF835454014E97E4E41AC46401D058882192D454014E97E4E41AC4640
1585	Кизилов	8	81	157	42.191048000000002	42.234076999999999	45.162087999999997	45.151614000000002	0103000020E61000000100000005000000ADFBC74274184540D1CE691668934640ADFBC742741845407A89B14CBF94464076DF313CF61D45407A89B14CBF94464076DF313CF61D4540D1CE691668934640ADFBC74274184540D1CE691668934640
569	Грачевка	8	81	157	42.381993999999999	42.445092000000002	45.213935999999997	45.191263999999997	0103000020E6100000010000000500000055A2EC2DE53045407973B8567B98464055A2EC2DE5304540F1B73D41629B46400ADB4FC6F8384540F1B73D41629B46400ADB4FC6F83845407973B8567B98464055A2EC2DE53045407973B8567B984640
1055	Верхняя Кугульта	8	81	157	42.374799000000003	42.394686999999998	45.350873999999997	45.341327	0103000020E6100000010000000500000069C9E369F92F4540F31E679AB0AB464069C9E369F92F454023827170E9AC46400394861A8532454023827170E9AC46400394861A85324540F31E679AB0AB464069C9E369F92F4540F31E679AB0AB4640
451	Бешпагир	8	81	157	42.346133000000002	42.401513999999999	45.044590999999997	44.998368999999997	0103000020E610000001000000050000007F880D164E2C45408C2B2E8ECA7F46407F880D164E2C454014596B28B58546406D718DCF6433454014596B28B58546406D718DCF643345408C2B2E8ECA7F46407F880D164E2C45408C2B2E8ECA7F4640
57672	Базовый	8	81	157	42.450392000000001	42.486477000000001	45.055480000000003	45.042158000000001	0103000020E61000000100000005000000A530EF71A6394540E4A1EF6E65854640A530EF71A639454082CAF8F719874640CBA0DAE0443E454082CAF8F719874640CBA0DAE0443E4540E4A1EF6E65854640A530EF71A6394540E4A1EF6E65854640
315	Шаумянский	8	81	5	43.519790999999998	43.558292999999999	44.1723	44.150708000000002	0103000020E61000000100000005000000A8E0F08288C245406F9F55664A134640A8E0F08288C24540E78C28ED0D164640F94A202576C74540E78C28ED0D164640F94A202576C745406F9F55664A134640A8E0F08288C245406F9F55664A134640
186	Урухская	8	81	5	43.649050000000003	43.687516000000002	44.164462999999998	44.139995999999996	0103000020E6100000010000000500000002BC051214D3454010C99063EB11464002BC051214D345407633A31F0D15464006BD378600D845407633A31F0D15464006BD378600D8454010C99063EB11464002BC051214D3454010C99063EB114640
31219	Терский	8	81	5	43.308939000000002	43.317957999999997	44.200043000000001	44.191577000000002	0103000020E61000000100000005000000BFBA2A508BA7454039D55A9885184640BFBA2A508BA7454099654F029B19464033C005D9B2A8454099654F029B19464033C005D9B2A8454039D55A9885184640BFBA2A508BA7454039D55A9885184640
32202	Приэтокский	8	81	5	43.425567000000001	43.435277999999997	43.983987999999997	43.974089999999997	0103000020E61000000100000005000000E0A0BDFA78B6454029AE2AFBAEFC4540E0A0BDFA78B6454006D49B51F3FD45408A558330B7B7454006D49B51F3FD45408A558330B7B7454029AE2AFBAEFC4540E0A0BDFA78B6454029AE2AFBAEFC4540
8	Подгорная	8	81	5	43.394961000000002	43.448994999999996	44.210420999999997	44.189740999999998	0103000020E61000000100000005000000051901158EB24540ECDADE6E49184640051901158EB2454020B24813EF1A4640A4880CAB78B9454020B24813EF1A4640A4880CAB78B94540ECDADE6E49184640051901158EB24540ECDADE6E49184640
31674	Падинский	8	81	5	43.278413999999998	43.303018999999999	44.397632999999999	44.379049000000002	0103000020E61000000100000005000000D05FE811A3A345406F4A79AD84304640D05FE811A3A34540BA675DA3E532464087889B53C9A64540BA675DA3E532464087889B53C9A645406F4A79AD84304640D05FE811A3A345406F4A79AD84304640
32365	Обильное	8	81	5	43.512298999999999	43.589661999999997	44.267498000000003	44.223058000000002	0103000020E6100000010000000500000002637D0393C145403B8E1F2A8D1C464002637D0393C145406ADFDC5F3D224640D3D85E0B7ACB45406ADFDC5F3D224640D3D85E0B7ACB45403B8E1F2A8D1C464002637D0393C145403B8E1F2A8D1C4640
57628	Новый	8	81	5	43.421577999999997	43.461544000000004	44.180923999999997	44.132323	0103000020E61000000100000005000000465B9544F6B545401AC1C6F5EF104640465B9544F6B54540DF8783842817464020D5B0DF13BB4540DF8783842817464020D5B0DF13BB45401AC1C6F5EF104640465B9544F6B545401AC1C6F5EF104640
124	Новоульяновский	8	81	5	43.370311999999998	43.419710000000002	44.465927000000001	44.446503	0103000020E610000001000000050000007EA8346266AF45406F48A302273946407EA8346266AF454065A9F57EA33B4640EFE6A90EB9B5454065A9F57EA33B4640EFE6A90EB9B545406F48A302273946407EA8346266AF45406F48A30227394640
389	Новомихайловский	8	81	5	43.565317999999998	43.585825999999997	44.197529000000003	44.191007999999997	0103000020E6100000010000000500000089EB18575CC845401EA33CF37218464089EB18575CC845407C8159A148194640C092AB58FCCA45407C8159A148194640C092AB58FCCA45401EA33CF37218464089EB18575CC845401EA33CF372184640
32283	Новозаведенное	8	81	5	43.608212000000002	43.670313	44.270479999999999	44.246025000000003	0103000020E6100000010000000500000073840CE4D9CD4540CC7F48BF7D1F464073840CE4D9CD45406D1CB1169F224640B58AFED0CCD545406D1CB1169F224640B58AFED0CCD54540CC7F48BF7D1F464073840CE4D9CD4540CC7F48BF7D1F4640
270	Нижнезольский	8	81	5	43.622199000000002	43.653928000000001	44.124721000000001	44.112670999999999	0103000020E610000001000000050000004D4D8237A4CF4540931ADA006C0E46404D4D8237A4CF4540ED0F94DBF60F464027F8A6E9B3D34540ED0F94DBF60F464027F8A6E9B3D34540931ADA006C0E46404D4D8237A4CF4540931ADA006C0E4640
31885	Незлобная	8	81	5	43.350144	43.436104	44.129412000000002	44.095756999999999	0103000020E610000001000000050000000072C284D1AC454079AEEFC3410C46400072C284D1AC4540E0DA899290104640D0D38041D2B74540E0DA899290104640D0D38041D2B7454079AEEFC3410C46400072C284D1AC454079AEEFC3410C4640
31748	Лысогорская	8	81	5	43.232537000000001	43.325539999999997	44.120190999999998	44.083253999999997	0103000020E61000000100000005000000130EBDC5C39D45406EA12B11A80A4640130EBDC5C39D454003232F6B620F464019C5724BABA9454003232F6B620F464019C5724BABA945406EA12B11A80A4640130EBDC5C39D45406EA12B11A80A4640
31425	Краснокумское	8	81	5	43.453532000000003	43.509037999999997	44.191744999999997	44.155208999999999	0103000020E6100000010000000500000041D829560DBA4540BE8575E3DD13464041D829560DBA4540F415A4198B184640EB353D2828C14540F415A4198B184640EB353D2828C14540BE8575E3DD13464041D829560DBA4540BE8575E3DD134640
16014	Георгиевская	8	81	5	43.431863999999997	43.504044	44.122449000000003	44.100133	0103000020E61000000100000005000000ED28CE5147B745400C207C28D10C4640ED28CE5147B74540C636A968AC0F46405DDF878384C04540C636A968AC0F46405DDF878384C045400C207C28D10C4640ED28CE5147B745400C207C28D10C4640
31313	Балковский	8	81	5	43.494674000000003	43.512030000000003	44.528461	44.511178000000001	0103000020E610000001000000050000003C17467A51BF4540A437DC476E4146403C17467A51BF4540111B2C9CA44346401349F4328AC14540111B2C9CA44346401349F4328AC14540A437DC476E4146403C17467A51BF4540A437DC476E414640
31121	Александрийская	8	81	5	43.301068999999998	43.382151	44.238216999999999	44.206589000000001	0103000020E61000000100000005000000726BD26D89A645404F5B2382711A4640726BD26D89A64540F52C08E57D1E46401D91EF52EAB04540F52C08E57D1E46401D91EF52EAB045404F5B2382711A4640726BD26D89A645404F5B2382711A4640
29654	Херсонский	8	81	1382	43.897658999999997	43.937435999999998	44.689081000000002	44.673378999999997	0103000020E61000000100000005000000E3FA777DE6F245401668774831564640E3FA777DE6F24540C2A563CE33584640E90B21E7FDF74540C2A563CE33584640E90B21E7FDF745401668774831564640E3FA777DE6F245401668774831564640
29925	Толстово-Васюковское	8	81	1382	44.132962999999997	44.172372000000003	45.020819000000003	44.989617000000003	0103000020E61000000100000005000000FD497CEE04114640674815C5AB7E4640FD497CEE0411464056116E32AA824640815F23491016464056116E32AA824640815F234910164640674815C5AB7E4640FD497CEE04114640674815C5AB7E4640
15148	Терек	8	81	1382	44.023099000000002	44.047758000000002	44.598334000000001	44.573162000000004	0103000020E6100000010000000500000000C974E8F4024640ADA7565F5D49464000C974E8F4024640DD0A6135964C4640AA0F24EF1C064640DD0A6135964C4640AA0F24EF1C064640ADA7565F5D49464000C974E8F4024640ADA7565F5D494640
16978	Преображенское	8	81	1382	43.955204999999999	43.998404999999998	44.695872999999999	44.671647999999998	0103000020E61000000100000005000000E3FC4D2844FA45403F36C98FF8554640E3FC4D2844FA4540AF95D05D12594640D9942BBCCBFF4540AF95D05D12594640D9942BBCCBFF45403F36C98FF8554640E3FC4D2844FA45403F36C98FF8554640
15101	Прасковея	8	81	1382	44.181508000000001	44.235973000000001	44.765191999999999	44.717911000000001	0103000020E610000001000000050000002FFB75A73B1746402638F581E45B46402FFB75A73B1746409694BBCFF161464098DEFE5C341E46409694BBCFF161464098DEFE5C341E46402638F581E45B46402FFB75A73B1746402638F581E45B4640
29976	Правобережный	8	81	1382	43.844935999999997	43.867026000000003	44.687106999999997	44.681646999999998	0103000020E61000000100000005000000459BE3DC26EC454050357A3540574640459BE3DC26EC454024ED461FF35746400F643DB5FAEE454024ED461FF35746400F643DB5FAEE454050357A3540574640459BE3DC26EC454050357A3540574640
29836	Плаксейка	8	81	1382	44.023432	44.030707999999997	44.636465000000001	44.619889000000001	0103000020E6100000010000000500000006D7DCD1FF0246403813D385584F464006D7DCD1FF0246403A0664AF77514640DFDC5F3DEE0346403A0664AF77514640DFDC5F3DEE0346403813D385584F464006D7DCD1FF0246403813D385584F4640
57591	Буденновск	8	81	1382	44.105601	44.106544	44.754337	44.753498	0103000020E6100000010000000500000063B66455840D4640FBCC599F7260464063B66455840D4640D594641D8E604640E2CAD93BA30D4640D594641D8E604640E2CAD93BA30D4640FBCC599F7260464063B66455840D4640FBCC599F72604640
60666	Архиповское	8	81	1382	44.084778	44.093724999999999	44.575878000000003	44.548865999999997	0103000020E61000000100000005000000CCB56801DA0A464073F1B73D41464640CCB56801DA0A4640323ECC5EB6494640A7E8482EFF0B4640323ECC5EB6494640A7E8482EFF0B464073F1B73D41464640CCB56801DA0A464073F1B73D41464640
45588	Архангельское	8	81	1382	44.068815000000001	44.117404000000001	44.640531000000003	44.596491999999998	0103000020E61000000100000005000000B43C0FEECE084640AE2990D9594C4640B43C0FEECE0846407F8978EBFC514640B5352218070F46407F8978EBFC514640B5352218070F4640AE2990D9594C4640B43C0FEECE084640AE2990D9594C4640
57611	Буденновск	8	81	7439	44.145009999999999	44.145989	44.786408999999999	44.785597000000003	0103000020E61000000100000005000000E6CB0BB08F124640F96A47718E644640E6CB0BB08F124640D923D40CA9644640B2497EC4AF124640D923D40CA9644640B2497EC4AF124640F96A47718E644640E6CB0BB08F124640F96A47718E644640
57577	Буденновск	8	81	7439	44.145009999999999	44.145989	44.786408999999999	44.785597000000003	0103000020E61000000100000005000000E6CB0BB08F124640F96A47718E644640E6CB0BB08F124640D923D40CA9644640B2497EC4AF124640D923D40CA9644640B2497EC4AF124640F96A47718E644640E6CB0BB08F124640F96A47718E644640
57624	Эдельбай	8	81	1234	43.873080999999999	43.897047999999998	45.327539999999999	45.319239000000003	0103000020E6100000010000000500000026E1421EC1EF4540CB4DD4D2DCA8464026E1421EC1EF4540E010AAD4ECA946409A780778D2F24540E010AAD4ECA946409A780778D2F24540CB4DD4D2DCA8464026E1421EC1EF4540CB4DD4D2DCA84640
27850	Шишкино	8	81	1234	43.147115999999997	43.184027999999998	45.101425999999996	45.085054	0103000020E61000000100000005000000F25B74B2D49245406E32AA0CE38A4640F25B74B2D4924540677BF486FB8C46402EC6C03A8E974540677BF486FB8C46402EC6C03A8E9745406E32AA0CE38A4640F25B74B2D49245406E32AA0CE38A4640
27844	Ставропольский	8	81	1234	43.541539	43.570419999999999	44.951228999999998	44.937538000000004	0103000020E610000001000000050000001841632651C54540EE60C43E017846401841632651C54540DE0033DFC1794640FE7DC68503C94540DE0033DFC1794640FE7DC68503C94540EE60C43E017846401841632651C54540EE60C43E01784640
27771	Спасское	8	81	1234	43.658769999999997	43.723528999999999	45.081681000000003	45.064430999999999	0103000020E61000000100000005000000FFCA4A9352D445409EEC66463F884640FFCA4A9352D4454030DAE385748A4640925A28999CDC454030DAE385748A4640925A28999CDC45409EEC66463F884640FFCA4A9352D445409EEC66463F884640
15588	Сотниковское	8	81	1234	43.744971999999997	43.813864000000002	45.022399	44.984887000000001	0103000020E61000000100000005000000C537143E5BDF4540B6A0F7C6107E4640C537143E5BDF4540473B6EF8DD82464025B20FB22CE84540473B6EF8DD82464025B20FB22CE84540B6A0F7C6107E4640C537143E5BDF4540B6A0F7C6107E4640
27662	Мирное	8	81	1234	43.670771000000002	43.702849999999998	45.303012000000003	45.266485000000003	0103000020E61000000100000005000000780DFAD2DBD54540F2EF332E1CA24640780DFAD2DBD54540D525E318C9A646402EFF21FDF6D94540D525E318C9A646402EFF21FDF6D94540F2EF332E1CA24640780DFAD2DBD54540F2EF332E1CA24640
27571	Каменная Балка	8	81	1234	43.336751	43.360421000000002	45.259284999999998	45.243853000000001	0103000020E6100000010000000500000099F221A81AAB454008043A93369F464099F221A81AAB4540F3AB394030A1464054E57B4622AE4540F3AB394030A1464054E57B4622AE454008043A93369F464099F221A81AAB454008043A93369F4640
27486	Елизаветинское	8	81	1234	43.32103	43.394880000000001	45.018385000000002	44.996290999999999	0103000020E610000001000000050000007784D38217A945404A26A776867F46407784D38217A9454055DE8E705A82464018EC866D8BB2454055DE8E705A82464018EC866D8BB245404A26A776867F46407784D38217A945404A26A776867F4640
27431	Бурлацкое	8	81	1234	43.618929000000001	43.665605999999997	45.067863000000003	45.050640999999999	0103000020E61000000100000005000000E3C5C21039CF45401A6B7F677B864640E3C5C21039CF4540E2CD1ABCAF884640BC02D19332D54540E2CD1ABCAF884640BC02D19332D545401A6B7F677B864640E3C5C21039CF45401A6B7F677B864640
57638	Большевик	8	81	1234	43.198239000000001	43.220095000000001	45.019869	45.009661999999999	0103000020E6100000010000000500000058E542E55F994540C901BB9A3C81464058E542E55F994540249A40118B824640AE81AD122C9C4540249A40118B824640AE81AD122C9C4540C901BB9A3C81464058E542E55F994540C901BB9A3C814640
12647	Благодарный	8	81	1234	43.379555000000003	43.47916	45.129292	45.080905000000001	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
27578	Алтухов	8	81	1234	43.225413000000003	43.251348	45.179561999999997	45.168582999999998	0103000020E61000000100000005000000F08B4B55DA9C4540AED4B32094954640F08B4B55DA9C45405BCD3AE3FB9646401FF5D72B2CA045405BCD3AE3FB9646401FF5D72B2CA04540AED4B32094954640F08B4B55DA9C4540AED4B32094954640
27378	Алексеевское	8	81	1234	43.549840000000003	43.615901999999998	45.227383000000003	45.183171000000002	0103000020E610000001000000050000002E04392861C64540AE49B725729746402E04392861C645404C55DAE21A9D46403FC571E0D5CE45404C55DAE21A9D46403FC571E0D5CE4540AE49B725729746402E04392861C64540AE49B72572974640
15508	Александрия	8	81	1234	43.214750000000002	43.273212999999998	45.102915000000003	45.064928000000002	0103000020E61000000100000005000000736891ED7C9B45401F4C8A8F4F884640736891ED7C9B454049A297512C8D4640C8EBC1A4F8A2454049A297512C8D4640C8EBC1A4F8A245401F4C8A8F4F884640736891ED7C9B45401F4C8A8F4F884640
26751	Чограйский	8	81	1797	44.567585999999999	44.590555999999999	45.353425999999999	45.340648999999999	0103000020E610000001000000050000006FD575A8A64846402235ED629AAB46406FD575A8A64846402EC72B103DAD4640713AC956974B46402EC72B103DAD4640713AC956974B46402235ED629AAB46406FD575A8A64846402235ED629AAB4640
26661	Серафимовское	8	81	1797	43.893113	43.946455	45.234219000000003	45.194668999999998	0103000020E61000000100000005000000F450DB8651F24540C345EEE9EA984640F450DB8651F24540098D60E3FA9D46405E11FC6F25F94540098D60E3FA9D46405E11FC6F25F94540C345EEE9EA984640F450DB8651F24540C345EEE9EA984640
26652	Садовое	8	81	1797	44.642425000000003	44.664873999999998	45.295847999999999	45.270336	0103000020E6100000010000000500000000917EFB3A5246403A77BB5E9AA2464000917EFB3A524640234BE658DEA54640F8FA5A971A554640234BE658DEA54640F8FA5A971A5546403A77BB5E9AA2464000917EFB3A5246403A77BB5E9AA24640
26566	Родниковское	8	81	1797	44.077258999999998	44.110793000000001	45.445753000000003	45.431252000000001	0103000020E610000001000000050000002C29779FE3094640D42AFA4333B746402C29779FE3094640058C2E6F0EB9464018D00B772E0E4640058C2E6F0EB9464018D00B772E0E4640D42AFA4333B746402C29779FE3094640D42AFA4333B74640
32517	Петропавловское	8	81	1797	44.248271000000003	44.321734999999997	45.101286000000002	45.073101999999999	0103000020E61000000100000005000000CAC51858C71F4640D7A205685B894640CAC51858C71F464076C58CF0F68C4640417DCB9C2E29464076C58CF0F68C4640417DCB9C2E294640D7A205685B894640CAC51858C71F4640D7A205685B894640
26501	Новоромановское	8	81	1797	44.367801	44.442990000000002	45.052155999999997	44.993901000000001	0103000020E61000000100000005000000D237691A142F4640193BE125387F4640D237691A142F464024253D0CAD8646403F3A75E5B338464024253D0CAD8646403F3A75E5B3384640193BE125387F4640D237691A142F4640193BE125387F4640
26419	Каменная Балка	8	81	1797	43.968760000000003	43.994954999999997	45.551979000000003	45.542019000000003	0103000020E6100000010000000500000024D6E25300FC4540C367EBE060C5464024D6E25300FC4540168A743FA7C64640EFFE78AF5AFF4540168A743FA7C64640EFFE78AF5AFF4540C367EBE060C5464024D6E25300FC4540C367EBE060C54640
57648	Башанта	8	81	1797	44.089717999999998	44.102213999999996	45.271014000000001	45.259500000000003	0103000020E6100000010000000500000067EE21E17B0B4640F0A7C64B37A1464067EE21E17B0B46400B613596B0A24640BF982D59150D46400B613596B0A24640BF982D59150D4640F0A7C64B37A1464067EE21E17B0B4640F0A7C64B37A14640
26190	Арзгир	8	81	1797	44.177402999999998	44.259813999999999	45.395947	45.353540000000002	0103000020E610000001000000050000002C9B3924B5164640F7E978CC40AD46402C9B3924B516464083F92B64AEB246407F85CC954121464083F92B64AEB246407F85CC9541214640F7E978CC40AD46402C9B3924B5164640F7E978CC40AD4640
25368	Хлебный	8	81	1420	43.391278	43.399740000000001	45.658135999999999	45.648415999999997	0103000020E6100000010000000500000078D2C26515B24540001AA54BFFD2464078D2C26515B24540FE28EACC3DD44640977329AE2AB34540FE28EACC3DD44640977329AE2AB34540001AA54BFFD2464078D2C26515B24540001AA54BFFD24640
26150	Рагули	8	81	1420	43.684002999999997	43.750064999999999	45.664498000000002	45.625660000000003	0103000020E61000000100000005000000D5AE09698DD745402B357BA015D04640D5AE09698DD74540F3203D450ED54640E76F422102E04540F3203D450ED54640E76F422102E045402B357BA015D04640D5AE09698DD745402B357BA015D04640
26076	Манычское	8	81	1420	43.071396999999997	43.114507000000003	46.098267999999997	46.053598000000001	0103000020E610000001000000050000002904728923894540C5909C4CDC0647402904728923894540251FBB0B940C4740E014562AA88E4540251FBB0B940C4740E014562AA88E4540C5909C4CDC0647402904728923894540C5909C4CDC064740
17360	Малая Джалга	8	81	1420	42.747824000000001	42.795524999999998	46.031196000000001	45.976188999999998	0103000020E61000000100000005000000FB9463B2B85F454083DBDAC2F3FC4640FB9463B2B85F45400DE2033BFE034740401361C3D36545400DE2033BFE034740401361C3D365454083DBDAC2F3FC4640FB9463B2B85F454083DBDAC2F3FC4640
32516	Киевка	8	81	1420	42.908208999999999	42.945982999999998	46.100223999999997	46.061208999999998	0103000020E610000001000000050000006877483140744540459C4EB2D507474068774831407445401C23D923D40C474036C98FF8157945401C23D923D40C474036C98FF815794540459C4EB2D50747406877483140744540459C4EB2D5074740
15783	Дивное	8	81	1420	43.290218000000003	43.399588000000001	45.943235000000001	45.890892999999998	0103000020E61000000100000005000000F35A09DD25A545401F9E25C808F24640F35A09DD25A54540A6B8AAECBBF84640E1EF17B325B34540A6B8AAECBBF84640E1EF17B325B345401F9E25C808F24640F35A09DD25A545401F9E25C808F24640
25665	Дербетовка	8	81	1420	43.045183999999999	43.132060000000003	45.815623000000002	45.795462000000001	0103000020E61000000100000005000000B726DD96C8854540FA9AE5B2D1E54640B726DD96C8854540C66E9F5566E846400D8E9257E7904540C66E9F5566E846400D8E9257E7904540FA9AE5B2D1E54640B726DD96C8854540FA9AE5B2D1E54640
25560	Вознесеновское	8	81	1420	43.386580000000002	43.439580999999997	45.822777000000002	45.800224999999998	0103000020E61000000100000005000000D3A414747BB145408638D6C56DE64640D3A414747BB145405473B9C150E94640B378B13044B845405473B9C150E94640B378B13044B845408638D6C56DE64640D3A414747BB145408638D6C56DE64640
17172	Воздвиженское	8	81	1420	43.633463999999996	43.707925000000003	45.838406999999997	45.821829000000001	0103000020E61000000100000005000000BF982D5915D14540C3F352B131E94640BF982D5915D1454065DEAAEB50EB4640AA8251499DDA454065DEAAEB50EB4640AA8251499DDA4540C3F352B131E94640BF982D5915D14540C3F352B131E94640
25308	Водный	8	81	1420	43.365802000000002	43.386355000000002	45.683107999999997	45.668906999999997	0103000020E61000000100000005000000DC679599D2AE454061889CBE9ED54640DC679599D2AE454067D13B1570D74640B3D2A41474B1454067D13B1570D74640B3D2A41474B1454061889CBE9ED54640DC679599D2AE454061889CBE9ED54640
25455	Белые Копани	8	81	1420	43.013303000000001	43.027163999999999	45.971235	45.945678999999998	0103000020E6100000010000000500000027F8A6E9B3814540CAC16C020CF9464027F8A6E9B381454083DDB06D51FC464074D0251C7A83454083DDB06D51FC464074D0251C7A834540CAC16C020CF9464027F8A6E9B3814540CAC16C020CF94640
25450	Апанасенковское	8	81	1420	43.537587000000002	43.580705999999999	45.769723999999997	45.740313	0103000020E610000001000000050000009CE09BA6CFC44540DEE68D93C2DE46409CE09BA6CFC445402079E75086E24640A54BFF9254CA45402079E75086E24640A54BFF9254CA4540DEE68D93C2DE46409CE09BA6CFC44540DEE68D93C2DE4640
25263	Айгурский	8	81	1420	43.315100999999999	43.341188000000002	45.682327000000001	45.670293000000001	0103000020E61000000100000005000000ECF7C43A55A845406EDE3829CCD54640ECF7C43A55A84540C216BB7D56D74640D2E4620CACAB4540C216BB7D56D74640D2E4620CACAB45406EDE3829CCD54640ECF7C43A55A845406EDE3829CCD54640
24913	Янкуль	8	81	1374	42.503500000000003	42.582256000000001	44.674706	44.654696999999999	0103000020E610000001000000050000009CC420B07240454008E57D1CCD5346409CC420B0724045401E3526C45C5646402CF3565D874A45401E3526C45C5646402CF3565D874A454008E57D1CCD5346409CC420B07240454008E57D1CCD534640
24323	Суркуль	8	81	1374	42.451577999999998	42.478966999999997	44.485004000000004	44.471369000000003	0103000020E61000000100000005000000EACBD24ECD39454093ACC3D1553C4640EACBD24ECD394540F0366F9C143E46407E6E68CA4E3D4540F0366F9C143E46407E6E68CA4E3D454093ACC3D1553C4640EACBD24ECD39454093ACC3D1553C4640
25038	Султан	8	81	1374	42.628653	42.690097999999999	44.603372	44.576751000000002	0103000020E6100000010000000500000022C495B377504540B8770DFAD249464022C495B3775045403BA92F4B3B4D46407B849A21555845403BA92F4B3B4D46407B849A2155584540B8770DFAD249464022C495B377504540B8770DFAD2494640
25160	Солуно-Дмитриевское	8	81	1374	42.692101999999998	42.751759	44.421233000000001	44.383752000000001	0103000020E6100000010000000500000083BF5FCC9658454026E318C91E31464083BF5FCC965845407C7F83F6EA354640A1BC8FA3396045407C7F83F6EA354640A1BC8FA33960454026E318C91E31464083BF5FCC9658454026E318C91E314640
24727	Подгорное	8	81	1374	42.235317000000002	42.270792	44.518492999999999	44.504601999999998	0103000020E61000000100000005000000AF9811DE1E1E454083BF5FCC96404640AF9811DE1E1E45403B1A87FA5D4246405C02F04FA92245403B1A87FA5D4246405C02F04FA922454083BF5FCC96404640AF9811DE1E1E454083BF5FCC96404640
24999	Новая Янкуль	8	81	1374	42.503490999999997	42.522598000000002	44.782986999999999	44.771469000000003	0103000020E61000000100000005000000486AA164724045405D70067FBF624640486AA16472404540B91803EB386446403E7AC37DE4424540B91803EB386446403E7AC37DE44245405D70067FBF624640486AA164724045405D70067FBF624640
24995	Нижнеколонский	8	81	1374	42.372750000000003	42.423056000000003	44.696399	44.679358999999998	0103000020E61000000100000005000000C1CAA145B62F4540239F573CF5564640C1CAA145B62F4540CAFB389A235946403430F2B226364540CAFB389A235946403430F2B226364540239F573CF5564640C1CAA145B62F4540239F573CF5564640
25253	Куршава	8	81	1374	42.53698	42.610283000000003	44.442416000000001	44.421362000000002	0103000020E61000000100000005000000944DB9C2BB4445407AE3A430EF354640944DB9C2BB444540139D6516A13846400327DBC01D4E4540139D6516A13846400327DBC01D4E45407AE3A430EF354640944DB9C2BB4445407AE3A430EF354640
23003	Курсавка	8	81	1374	42.462268000000002	42.551811999999998	44.472810000000003	44.442056000000001	0103000020E6100000010000000500000061FE0A992B3B454013807F4A9538464061FE0A992B3B4540639CBF09853C46402AC58EC6A1464540639CBF09853C46402AC58EC6A146454013807F4A9538464061FE0A992B3B454013807F4A95384640
25093	Крымгиреевское	8	81	1374	42.685445000000001	42.762079999999997	44.555334999999999	44.517214000000003	0103000020E61000000100000005000000761A69A9BC57454045847F1134424640761A69A9BC5745407EA99F3715474640C47762D68B6145407EA99F3715474640C47762D68B61454045847F1134424640761A69A9BC57454045847F1134424640
24630	Красноярское	8	81	1374	42.341588000000002	42.382317	44.456147999999999	44.434558000000003	0103000020E61000000100000005000000605AD427B92B45408B1BB7989F374640605AD427B92B45406211C30E633A464038DA71C3EF3045406211C30E633A464038DA71C3EF3045408B1BB7989F374640605AD427B92B45408B1BB7989F374640
24914	Кианкиз	8	81	1374	42.415365999999999	42.468528999999997	44.630383999999999	44.620319000000002	0103000020E6100000010000000500000067EF8CB62A354540310BED9C664F464067EF8CB62A354540F9F5436CB0504640211D1EC2F83B4540F9F5436CB0504640211D1EC2F83B4540310BED9C664F464067EF8CB62A354540310BED9C664F4640
14930	Каскадный	8	81	1374	42.220495	42.240392999999997	44.613433999999998	44.599065000000003	0103000020E610000001000000050000003CF71E2E391C4540D1967329AE4C46403CF71E2E391C454092205C01854E4640FA97A432C51E454092205C01854E4640FA97A432C51E4540D1967329AE4C46403CF71E2E391C4540D1967329AE4C4640
17068	Казинка	8	81	1374	42.278221000000002	42.312429000000002	44.481395999999997	44.452809000000002	0103000020E61000000100000005000000BC07E8BE9C234540D02A33A5F5394640BC07E8BE9C2345406D3656629E3D464037A968ACFD2745406D3656629E3D464037A968ACFD274540D02A33A5F5394640BC07E8BE9C234540D02A33A5F5394640
17163	Дубовая Балка	8	81	1374	42.396797999999997	42.421914999999998	44.562578999999999	44.550651999999999	0103000020E61000000100000005000000218FE046CA3245400EBDC5C37B464640218FE046CA3245404C35B396024846408E588B4F013645404C35B396024846408E588B4F013645400EBDC5C37B464640218FE046CA3245400EBDC5C37B464640
24435	Воровсколесская	8	81	1374	42.374673000000001	42.441921000000001	44.407068000000002	44.355277000000001	0103000020E61000000100000005000000DCD8EC48F52F4540B0027CB7792D4640DCD8EC48F52F4540C39FE1CD1A344640333509DE90384540C39FE1CD1A344640333509DE90384540B0027CB7792D4640DCD8EC48F52F4540B0027CB7792D4640
24736	Водораздел	8	81	1374	42.349941999999999	42.373550000000002	44.530991999999998	44.502031000000002	0103000020E6100000010000000500000098BF42E6CA2C4540024A438D4240464098BF42E6CA2C45400438BD8BF7434640DDB5847CD02F45400438BD8BF7434640DDB5847CD02F4540024A438D4240464098BF42E6CA2C4540024A438D42404640
24545	Алексеевское	8	81	1374	42.366785999999998	42.408943999999998	44.427785999999998	44.409939999999999	0103000020E61000000100000005000000B950F9D7F22E45403FA9F6E978344640B950F9D7F22E4540E4D70FB1C13646409DF2E84658344540E4D70FB1C13646409DF2E846583445403FA9F6E978344640B950F9D7F22E45403FA9F6E978344640
57603	Средний	8	81	1714	42.931897999999997	42.981071999999998	44.566766000000001	44.541947	0103000020E61000000100000005000000999A046F487745402995F0845E454640999A046F487745400C3ECDC98B484640BA826DC4937D45400C3ECDC98B484640BA826DC4937D45402995F0845E454640999A046F487745402995F0845E454640
23744	Северное	8	81	1714	42.821629999999999	42.876399999999997	44.850149000000002	44.814039000000001	0103000020E61000000100000005000000CCB4FD2B2B6945409355116E32684640CCB4FD2B2B69454012DDB3AED16C4640711B0DE02D70454012DDB3AED16C4640711B0DE02D7045409355116E32684640CCB4FD2B2B6945409355116E32684640
48223	Садовое	8	81	1714	42.785947999999998	42.865000000000002	44.683852000000002	44.656998999999999	0103000020E61000000100000005000000A52DAEF1996445409A40118B18544640A52DAEF199644540F0A65B76885746401F85EB51B86E4540F0A65B76885746401F85EB51B86E45409A40118B18544640A52DAEF1996445409A40118B18544640
24032	Саблинское	8	81	1714	43.190666	43.253737000000001	44.537373000000002	44.500745000000002	0103000020E61000000100000005000000C53A55BE679845405951836918404640C53A55BE67984540706072A3C844464080643A747AA04540706072A3C844464080643A747AA045405951836918404640C53A55BE679845405951836918404640
24034	Новокавказский	8	81	1714	43.107607999999999	43.141438999999998	44.594135999999999	44.574978999999999	0103000020E61000000100000005000000DC645419C68D4540827170E998494640DC645419C68D454029B000A60C4C464081B053AC1A92454029B000A60C4C464081B053AC1A924540827170E998494640DC645419C68D4540827170E998494640
24130	Круглолесское	8	81	1714	42.776831000000001	42.856896999999996	44.678468000000002	44.647790999999998	0103000020E610000001000000050000006EC2BD326F63454052D2C3D0EA5246406EC2BD326F634540F7B0170AD85646402F8507CDAE6D4540F7B0170AD85646402F8507CDAE6D454052D2C3D0EA5246406EC2BD326F63454052D2C3D0EA524640
23823	Калиновское	8	81	1714	42.906771999999997	43.028503000000001	44.878999999999998	44.854506999999998	0103000020E61000000100000005000000D976DA1A11744540FE99417C606D4640D976DA1A117445408D976E1283704640406B7EFCA58345408D976E1283704640406B7EFCA5834540FE99417C606D4640D976DA1A11744540FE99417C606D4640
23735	Дубовая Роща	8	81	1714	42.844374999999999	42.8658	44.734599000000003	44.707771000000001	0103000020E61000000100000005000000AE47E17A146C45405307793D985A4640AE47E17A146C454050560C57075E46403B70CE88D26E454050560C57075E46403B70CE88D26E45405307793D985A4640AE47E17A146C45405307793D985A4640
23876	Грушевское	8	81	1714	43.008038999999997	43.063645000000001	44.954788000000001	44.928413999999997	0103000020E61000000100000005000000D80B056C0781454003931B45D6764640D80B056C078145407F4E417E367A4640E7C6F484258845407F4E417E367A4640E7C6F4842588454003931B45D6764640D80B056C0781454003931B45D6764640
23936	Всадник	8	81	1714	43.292230000000004	43.306961999999999	44.611944999999999	44.596626000000001	0103000020E610000001000000050000007E74EACA67A54540BEF8A23D5E4C46407E74EACA67A54540B1F9B836544E4640B08EE3874AA74540B1F9B836544E4640B08EE3874AA74540BEF8A23D5E4C46407E74EACA67A54540BEF8A23D5E4C4640
23101	Александровское	8	81	1714	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
19420	Ухта	3	25	\N	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
16244	Усинск	3	25	\N	57.372090999999998	57.573799000000001	66.008602999999994	65.978600999999998	0103000020E6100000010000000500000066118AADA0AF4C404EB51666A17E504066118AADA0AF4C4070E998F38C8050401FBDE13E72C94C4070E998F38C8050401FBDE13E72C94C404EB51666A17E504066118AADA0AF4C404EB51666A17E5040
669	Сыктывкар	3	25	\N	50.716276000000001	50.916933	61.723374	61.62189	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57211	Сосногорск	3	25	\N	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57207	Печора	3	25	\N	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57206	Инта	3	25	\N	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57225	Емва	3	25	\N	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
15656	Вуктыл	3	25	\N	57.290246000000003	57.336742999999998	63.882719000000002	63.838240999999996	0103000020E61000000100000005000000BDE5EAC726A54C404A95287B4BEB4F40BDE5EAC726A54C406747AAEFFCF04F40161406651AAB4C406747AAEFFCF04F40161406651AAB4C404A95287B4BEB4F40BDE5EAC726A54C404A95287B4BEB4F40
40318	Вуктыл	3	25	\N	57.290246000000003	57.336742999999998	63.882719000000002	63.838240999999996	0103000020E61000000100000005000000BDE5EAC726A54C404A95287B4BEB4F40BDE5EAC726A54C406747AAEFFCF04F40161406651AAB4C406747AAEFFCF04F40161406651AAB4C404A95287B4BEB4F40BDE5EAC726A54C404A95287B4BEB4F40
3457	Воркута	3	25	\N	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57218	Ярега	3	25	1830	53.548178999999998	53.617125000000001	63.442883000000002	63.423532000000002	0103000020E610000001000000050000004FADBEBA2AC64A409D67EC4B36B64F404FADBEBA2AC64A40297AE063B0B84F40A245B6F3FDCE4A40297AE063B0B84F40A245B6F3FDCE4A409D67EC4B36B64F404FADBEBA2AC64A409D67EC4B36B64F40
57217	Шудаяг	3	25	1830	53.586618000000001	53.622892	63.540010000000002	63.519080000000002	0103000020E610000001000000050000005A9F724C16CB4A40FC00A43671C24F405A9F724C16CB4A40A9C1340C1FC54F405378D0ECBACF4A40A9C1340C1FC54F405378D0ECBACF4A40FC00A43671C24F405A9F724C16CB4A40FC00A43671C24F40
57254	Седью	3	25	1830	53.941425000000002	53.979173000000003	63.407848000000001	63.389791000000002	0103000020E610000001000000050000008351499D80F84A4038A3E6ABE4B14F408351499D80F84A4098DEFE5C34B44F402810768A55FD4A4098DEFE5C34B44F402810768A55FD4A4038A3E6ABE4B14F408351499D80F84A4038A3E6ABE4B14F40
57247	Кэмдин	3	25	1830	54.426479999999998	54.462439000000003	63.187331	63.174712999999997	0103000020E61000000100000005000000F4328AE596364B40D097DEFE5C964F40F4328AE596364B4074435376FA974F408EB27E33313B4B4074435376FA974F408EB27E33313B4B40D097DEFE5C964F40F4328AE596364B40D097DEFE5C964F40
57307	Кедвавом	3	25	1830	53.548233000000003	53.591270999999999	64.231223999999997	64.219620000000006	0103000020E6100000010000000500000043CBBA7F2CC64A400B630B410E0E504043CBBA7F2CC64A403883BF5FCC0E50405F09A4C4AECB4A403883BF5FCC0E50405F09A4C4AECB4A400B630B410E0E504043CBBA7F2CC64A400B630B410E0E5040
57224	Водный	3	25	1830	53.387183	53.435808999999999	63.518040999999997	63.489432000000001	0103000020E61000000100000005000000994869368FB14A40D5CE30B5A5BE4F40994869368FB14A405A7EE02A4FC24F40B726DD96C8B74A405A7EE02A4FC24F40B726DD96C8B74A40D5CE30B5A5BE4F40994869368FB14A40D5CE30B5A5BE4F40
27900	Боровой	3	25	1830	52.876041000000001	52.911740000000002	63.242688999999999	63.221687000000003	0103000020E61000000100000005000000427A8A1C22704A406479573D609C4F40427A8A1C22704A40AA0CE36E109F4F403F3A75E5B3744A40AA0CE36E109F4F403F3A75E5B3744A406479573D609C4F40427A8A1C22704A406479573D609C4F40
57253	дер.Чукчино	3	25	778	48.999389000000001	53.786116	67.099691000000007	64.390798000000004	0103000020E61000000100000005000000B77D8FFAEB7F4840E7559DD502195040B77D8FFAEB7F4840282D5C5661C65040616EF7729FE44A40282D5C5661C65040616EF7729FE44A40E7559DD502195040B77D8FFAEB7F4840E7559DD502195040
57321	Харъяга	3	25	778	52.151352000000003	52.178068000000003	66.927717000000001	66.919669999999996	0103000020E61000000100000005000000941799805F134A4030478FDFDBBA5040941799805F134A405EBC1FB75FBB5040693BA6EECA164A405EBC1FB75FBB5040693BA6EECA164A4030478FDFDBBA5040941799805F134A4030478FDFDBBA5040
18282	Хабариха	3	25	778	52.306797000000003	52.322597999999999	65.828277	65.815034999999995	0103000020E6100000010000000500000066C1C41F45274A401A868F882974504066C1C41F45274A40DBC1887D02755040A4E029E44A294A40DBC1887D02755040A4E029E44A294A401A868F882974504066C1C41F45274A401A868F8829745040
18072	Филиппово	3	25	778	51.093685000000001	51.125422999999998	65.441738000000001	65.430420999999996	0103000020E610000001000000050000001990BDDEFD8B4940BEA085048C5B50401990BDDEFD8B4940A1D9756F455C5040469561DC0D904940A1D9756F455C5040469561DC0D904940BEA085048C5B50401990BDDEFD8B4940BEA085048C5B5040
5484	Усть-Цильма	3	25	778	52.134535999999997	52.192298000000001	65.456581	65.422713000000002	0103000020E610000001000000050000003C11C47938114A4005A6D3BA0D5B50403C11C47938114A4066BE839F385D5040098B8A389D184A4066BE839F385D5040098B8A389D184A4005A6D3BA0D5B50403C11C47938114A4005A6D3BA0D5B5040
18227	Уег	3	25	778	52.053714999999997	52.068258	65.740634999999997	65.730198000000001	0103000020E61000000100000005000000FE261422E0064A40B2666490BB6E5040FE261422E0064A4078D15790666F50405ED89AADBC084A4078D15790666F50405ED89AADBC084A40B2666490BB6E5040FE261422E0064A40B2666490BB6E5040
18155	Трусово	3	25	778	51.364984999999997	51.400998999999999	65.465034000000003	65.44829	0103000020E61000000100000005000000E94317D4B7AE4940ED478AC8B05C5040E94317D4B7AE4940CC61F71DC35D5040465D6BEF53B34940CC61F71DC35D5040465D6BEF53B34940ED478AC8B05C5040E94317D4B7AE4940ED478AC8B05C5040
17889	Степановская	3	25	778	51.877267000000003	51.894371	64.979005999999998	64.970772999999994	0103000020E61000000100000005000000166EF9484AF04940BFB51325213E5040166EF9484AF049409E25C808A83E5040D3BEB9BF7AF249409E25C808A83E5040D3BEB9BF7AF24940BFB51325213E5040166EF9484AF04940BFB51325213E5040
18308	Среднее Бугаево	3	25	778	52.510705999999999	52.534807000000001	66.004447999999996	65.980734999999996	0103000020E610000001000000050000007CEF6FD05E414A40B9C2BB5CC47E50407CEF6FD05E414A4016A243E0488050400056478E74444A4016A243E0488050400056478E74444A40B9C2BB5CC47E50407CEF6FD05E414A40B9C2BB5CC47E5040
57269	Синегорье	3	25	778	51.968743000000003	51.989331999999997	65.451294000000004	65.445976999999999	0103000020E610000001000000050000004E9D47C5FFFB49402A711DE38A5C50404E9D47C5FFFB494063B83A00E25C50407171546EA2FE494063B83A00E25C50407171546EA2FE49402A711DE38A5C50404E9D47C5FFFB49402A711DE38A5C5040
17772	Сергеево-Щелья	3	25	778	52.154190999999997	52.173513999999997	65.526358000000002	65.516109999999998	0103000020E61000000100000005000000342BDB87BC134A40DEC83CF207615040342BDB87BC134A403BFF76D9AF615040F6B2EDB435164A403BFF76D9AF615040F6B2EDB435164A40DEC83CF207615040342BDB87BC134A40DEC83CF207615040
18184	Рочево	3	25	778	51.545115000000003	51.569522999999997	65.476044999999999	65.469683000000003	0103000020E610000001000000050000008FC70C54C6C549402E1F49490F5E50408FC70C54C6C54940289B7285775E5040EFA83121E6C84940289B7285775E5040EFA83121E6C849402E1F49490F5E50408FC70C54C6C549402E1F49490F5E5040
18391	Окунев Нос	3	25	778	52.557966	52.581861000000004	66.261262000000002	66.250163000000001	0103000020E61000000100000005000000D5230D6E6B474A40D5EAABAB02905040D5230D6E6B474A40016C4084B8905040B0E8D66B7A4A4A40016C4084B8905040B0E8D66B7A4A4A40D5EAABAB02905040D5230D6E6B474A40D5EAABAB02905040
57234	Новый Бор	3	25	778	52.292765000000003	52.321106999999998	66.731556999999995	66.710808999999998	0103000020E61000000100000005000000EC34D25279254A40F52C08E57DAD5040EC34D25279254A403B8A73D4D1AE504022C2BF081A294A403B8A73D4D1AE504022C2BF081A294A40F52C08E57DAD5040EC34D25279254A40F52C08E57DAD5040
17554	Нерица	3	25	778	52.670155999999999	52.696935000000003	65.308313999999996	65.294891000000007	0103000020E61000000100000005000000ED9BFBABC7554A40A038807EDF525040ED9BFBABC7554A4088B9A46ABB5350400938842A35594A4088B9A46ABB5350400938842A35594A40A038807EDF525040ED9BFBABC7554A40A038807EDF525040
57294	Медвежка	3	25	778	52.341616000000002	52.367406000000003	66.465227999999996	66.452681999999996	0103000020E610000001000000050000002AE5B512BA2B4A40395FECBDF89C50402AE5B512BA2B4A40BE4BA94BC69D5040562DE928072F4A40BE4BA94BC69D5040562DE928072F4A40395FECBDF89C50402AE5B512BA2B4A40395FECBDF89C5040
57257	Коровий Ручей	3	25	778	52.211323999999998	52.240250000000003	65.427631000000005	65.419144000000003	0103000020E61000000100000005000000116E32AA0C1B4A4023145B41D35A5040116E32AA0C1B4A405FF0694E5E5B5040986E1283C01E4A405FF0694E5E5B5040986E1283C01E4A4023145B41D35A5040116E32AA0C1B4A4023145B41D35A5040
17923	Замежная	3	25	778	51.964008999999997	51.990212999999997	65.046119000000004	65.034713999999994	0103000020E610000001000000050000005B069CA564FB4940A7AD11C1384250405B069CA564FB49405A2E1B9DF34250407A89B14CBFFE49405A2E1B9DF34250407A89B14CBFFE4940A7AD11C1384250405B069CA564FB4940A7AD11C138425040
17985	Загривочная	3	25	778	51.928525	51.953912000000003	65.093487999999994	65.085562999999993	0103000020E610000001000000050000005B423EE8D9F64940D9AF3BDD794550405B423EE8D9F6494061A417B5FB45504088A1D5C919FA494061A417B5FB45504088A1D5C919FA4940D9AF3BDD794550405B423EE8D9F64940D9AF3BDD79455040
18602	Ермица	3	25	778	52.329766999999997	52.348289999999999	66.923128000000005	66.909649000000002	0103000020E61000000100000005000000672618CE352A4A40B47570B037BA5040672618CE352A4A406781768714BB50400DC347C4942C4A406781768714BB50400DC347C4942C4A40B47570B037BA5040672618CE352A4A40B47570B037BA5040
29908	Ярашъю	3	25	850	54.350499999999997	54.372680000000003	62.094515000000001	62.088042999999999	0103000020E61000000100000005000000BE9F1A2FDD2C4B4024D236FE440B4F40BE9F1A2FDD2C4B40A0FD4811190C4F40C8EF6DFAB32F4B40A0FD4811190C4F40C8EF6DFAB32F4B4024D236FE440B4F40BE9F1A2FDD2C4B4024D236FE440B4F40
30234	Ягкедж	3	25	850	54.202008999999997	54.223379999999999	62.295825999999998	62.284339000000003	0103000020E61000000100000005000000B33F506EDB194B401AFD683865244F40B33F506EDB194B403BA759A0DD254F404D4A41B7971C4B403BA759A0DD254F404D4A41B7971C4B401AFD683865244F40B33F506EDB194B401AFD683865244F40
29271	Югыдъяг	3	25	850	54.903036	54.965217000000003	61.642263	61.620533999999999	0103000020E610000001000000050000002A8E03AF96734B402D077AA86DCF4E402A8E03AF96734B4026378AAC35D24E4089450C3B8C7B4B4026378AAC35D24E4089450C3B8C7B4B402D077AA86DCF4E402A8E03AF96734B402D077AA86DCF4E40
29499	Шэръяг	3	25	850	54.320082999999997	54.339306999999998	61.601221000000002	61.595354	0103000020E61000000100000005000000B680D07AF8284B407AC5538F34CC4E40B680D07AF8284B408F554ACFF4CC4E40E5266A696E2B4B408F554ACFF4CC4E40E5266A696E2B4B407AC5538F34CC4E40B680D07AF8284B407AC5538F34CC4E40
29353	Усть-Нем	3	25	850	54.837862999999999	54.901096000000003	61.650602999999997	61.620936	0103000020E61000000100000005000000A4C343183F6B4B405C74B2D47ACF4E40A4C343183F6B4B40F9D687F546D34E4039471D1D57734B40F9D687F546D34E4039471D1D57734B405C74B2D47ACF4E40A4C343183F6B4B405C74B2D47ACF4E40
28967	Усть-Кулом	3	25	850	53.651215999999998	53.767043999999999	61.703927999999998	61.679400999999999	0103000020E61000000100000005000000E350BF0B5BD34A4052EFA99CF6D64E40E350BF0B5BD34A408D5E0D501ADA4E40E84B6F7F2EE24A408D5E0D501ADA4E40E84B6F7F2EE24A4052EFA99CF6D64E40E350BF0B5BD34A4052EFA99CF6D64E40
29695	Тимшер	3	25	850	55.099955999999999	55.131144999999997	61.906700000000001	61.890911000000003	0103000020E61000000100000005000000FD84B35BCB8C4B40C652245F09F24E40FD84B35BCB8C4B4040A4DFBE0EF44E405704FF5BC9904B4040A4DFBE0EF44E405704FF5BC9904B40C652245F09F24E40FD84B35BCB8C4B40C652245F09F24E40
29297	Смолянка	3	25	850	54.793557999999997	54.820723000000001	61.611215000000001	61.591839999999998	0103000020E6100000010000000500000055BDFC4E93654B40793BC269C1CB4E4055BDFC4E93654B408EE9094B3CCE4E409A0986730D694B408EE9094B3CCE4E409A0986730D694B40793BC269C1CB4E4055BDFC4E93654B40793BC269C1CB4E40
29926	Скородум	3	25	850	54.214683999999998	54.240240999999997	62.150702000000003	62.136633000000003	0103000020E61000000100000005000000BB7CEBC37A1B4B40F646AD307D114F40BB7CEBC37A1B4B408DB800344A134F4044149337C01E4B408DB800344A134F4044149337C01E4B40F646AD307D114F40BB7CEBC37A1B4B40F646AD307D114F40
28582	Руч	3	25	850	53.139302000000001	53.215676000000002	61.82714	61.789377000000002	0103000020E610000001000000050000003A22DFA5D4914A40789B374E0AE54E403A22DFA5D4914A40529B38B9DFE94E401C446B459B9B4A40529B38B9DFE94E401C446B459B9B4A40789B374E0AE54E403A22DFA5D4914A40789B374E0AE54E40
30403	Пузла	3	25	850	54.647042999999996	54.697744	62.435138999999999	62.423442999999999	0103000020E61000000100000005000000880D164ED2524B402D5C566133364F40880D164ED2524B40691B7FA2B2374F40787DE6AC4F594B40691B7FA2B2374F40787DE6AC4F594B402D5C566133364F40880D164ED2524B402D5C566133364F40
30035	Помоздино	3	25	850	54.169632999999997	54.195397	62.205571999999997	62.184393	0103000020E6100000010000000500000043A9BD88B6154B40404E98309A174F4043A9BD88B6154B40957CEC2E501A4F40465ED6C402194B40957CEC2E501A4F40465ED6C402194B40404E98309A174F4043A9BD88B6154B40404E98309A174F40
29842	Пожегдин	3	25	850	54.320954999999998	54.342388	62.010809999999999	62.001828000000003	0103000020E610000001000000050000006C3EAE0D15294B40CA1B60E63B004F406C3EAE0D15294B40213CDA3862014F407C45B75ED32B4B40213CDA3862014F407C45B75ED32B4B40CA1B60E63B004F406C3EAE0D15294B40CA1B60E63B004F40
29830	Пожег	3	25	850	54.318241999999998	54.357740999999997	61.982961000000003	61.965625000000003	0103000020E61000000100000005000000581B6327BC284B409A99999999FB4E40581B6327BC284B402A1F82AAD1FD4E401BB80375CA2D4B402A1F82AAD1FD4E401BB80375CA2D4B409A99999999FB4E40581B6327BC284B409A99999999FB4E40
28896	Паспом	3	25	850	53.599598	53.618741	61.684787	61.671325000000003	0103000020E610000001000000050000009E5F94A0BFCC4A405DFE43FAEDD54E409E5F94A0BFCC4A40ECDCB419A7D74E40E0D8B3E732CF4A40ECDCB419A7D74E40E0D8B3E732CF4A405DFE43FAEDD54E409E5F94A0BFCC4A405DFE43FAEDD54E40
29400	Парч	3	25	850	54.686731000000002	54.734377000000002	61.612288999999997	61.602606999999999	0103000020E610000001000000050000001F1329CDE6574B409BABE63922CD4E401F1329CDE6574B40AB59677C5FCE4E40A1F7C610005E4B40AB59677C5FCE4E40A1F7C610005E4B409BABE63922CD4E401F1329CDE6574B409BABE63922CD4E40
28775	Озъяг	3	25	850	53.429628000000001	53.457771999999999	61.830440000000003	61.815916000000001	0103000020E6100000010000000500000013B9E00CFEB64A403E247CEF6FE84E4013B9E00CFEB64A4027A5A0DB4BEA4E402383DC4598BA4A4027A5A0DB4BEA4E402383DC4598BA4A403E247CEF6FE84E4013B9E00CFEB64A403E247CEF6FE84E40
28861	Носим	3	25	850	53.615938999999997	53.646633999999999	61.713389999999997	61.701399000000002	0103000020E610000001000000050000005CAAD216D7CE4A403B394371C7D94E405CAAD216D7CE4A408FA50F5D50DB4E40A73D25E7C4D24A408FA50F5D50DB4E40A73D25E7C4D24A403B394371C7D94E405CAAD216D7CE4A403B394371C7D94E40
29188	Нижний Воч	3	25	850	54.159481999999997	54.188965000000003	61.215575000000001	61.196463000000001	0103000020E610000001000000050000007C26FBE769144B40E1EF17B325994E407C26FBE769144B40E86A2BF6979B4E40598B4F0130184B40E86A2BF6979B4E40598B4F0130184B40E1EF17B325994E407C26FBE769144B40E1EF17B325994E40
29561	Мыелдино	3	25	850	54.882491000000002	54.922699999999999	61.774760000000001	61.722700000000003	0103000020E61000000100000005000000D6011077F5704B40DC68006F81DC4E40D6011077F5704B40DE1FEF552BE34E4075029A081B764B40DE1FEF552BE34E4075029A081B764B40DC68006F81DC4E40D6011077F5704B40DC68006F81DC4E40
29670	Лопъювад	3	25	850	55.180849000000002	55.206243999999998	61.749591000000002	61.739373000000001	0103000020E61000000100000005000000D5415E0F26974B40D04543C6A3DE4E40D5415E0F26974B401F300F99F2DF4E40847F1134669A4B401F300F99F2DF4E40847F1134669A4B40D04543C6A3DE4E40D5415E0F26974B40D04543C6A3DE4E40
57341	Логинъяг	3	25	850	52.542864999999999	56.348632000000002	62.754502000000002	60.831910000000001	0103000020E610000001000000050000004F92AE997C454A40919BE1067C6A4E404F92AE997C454A402062838593604F40672B2FF99F2C4C402062838593604F40672B2FF99F2C4C40919BE1067C6A4E404F92AE997C454A40919BE1067C6A4E40
28715	Кужба	3	25	850	53.706291	53.724994000000002	61.762895	61.750115000000001	0103000020E61000000100000005000000C53A55BE67DA4A40999EB0C403E04E40C53A55BE67DA4A4016A4198BA6E14E40EBE5779ACCDC4A4016A4198BA6E14E40EBE5779ACCDC4A40999EB0C403E04E40C53A55BE67DA4A40999EB0C403E04E40
6314	Керчомъя	3	25	850	53.865554000000003	53.970764000000003	61.507224000000001	61.451838000000002	0103000020E6100000010000000500000004763579CAEE4A40878BDCD3D5B94E4004763579CAEE4A4087DF4DB7ECC04E402C11A8FE41FC4A4087DF4DB7ECC04E402C11A8FE41FC4A40878BDCD3D5B94E4004763579CAEE4A40878BDCD3D5B94E40
57220	Кебаньель	3	25	850	53.677850999999997	53.743122	61.740102	61.714669000000001	0103000020E61000000100000005000000CB4752D2C3D64A40863B17467ADB4E40CB4752D2C3D64A4023DA8EA9BBDE4E401478279F1EDF4A4023DA8EA9BBDE4E401478279F1EDF4A40863B17467ADB4E40CB4752D2C3D64A40863B17467ADB4E40
29117	Зимстан	3	25	850	53.839888999999999	53.881929999999997	61.266255999999998	61.251685000000002	0103000020E6100000010000000500000094A2957B81EB4A4067F2CD3637A04E4094A2957B81EB4A40902E36AD14A24E403EAE0D15E3F04A40902E36AD14A24E403EAE0D15E3F04A4067F2CD3637A04E4094A2957B81EB4A4067F2CD3637A04E40
57258	Дон	3	25	850	53.873899000000002	53.910829	61.640891000000003	61.629837999999999	0103000020E61000000100000005000000E98024ECDBEF4A4097E315889ED04E40E98024ECDBEF4A407FA65EB708D24E40CB9F6F0B96F44A407FA65EB708D24E40CB9F6F0B96F44A4097E315889ED04E40E98024ECDBEF4A4097E315889ED04E40
30114	Диасеръя	3	25	850	53.769666999999998	53.801549000000001	62.384144999999997	62.372011999999998	0103000020E61000000100000005000000BCE7C07284E24A401ADCD6169E2F4F40BCE7C07284E24A4001F6D1A92B314F401D925A2899E64A4001F6D1A92B314F401D925A2899E64A401ADCD6169E2F4F40BCE7C07284E24A401ADCD6169E2F4F40
29211	Дзель	3	25	850	53.650343999999997	53.673493999999998	60.896442	60.886392999999998	0103000020E610000001000000050000002D93E1783ED34A40A033695375714E402D93E1783ED34A406361889CBE724E40AF06280D35D64A406361889CBE724E40AF06280D35D64A40A033695375714E402D93E1783ED34A40A033695375714E40
28615	Деревянск	3	25	850	53.262137000000003	53.376978000000001	61.772399	61.749215999999997	0103000020E61000000100000005000000290989B48DA14A40E9D1544FE6DF4E40290989B48DA14A40473B6EF8DDE24E40DFA7AAD040B04A40473B6EF8DDE24E40DFA7AAD040B04A40E9D1544FE6DF4E40290989B48DA14A40E9D1544FE6DF4E40
30152	Вольдино	3	25	850	54.166220000000003	54.200049999999997	62.269143	62.249085000000001	0103000020E6100000010000000500000077F86BB246154B404B766C04E21F4F4077F86BB246154B4042791F4773224F404BC8073D9B194B4042791F4773224F404BC8073D9B194B404B766C04E21F4F4077F86BB246154B404B766C04E21F4F40
30013	Бадъельск	3	25	850	54.032532000000003	54.046762000000001	62.263508000000002	62.253818000000003	0103000020E61000000100000005000000680932022A044B406D91B41B7D204F40680932022A044B40001E51A1BA214F400859164CFC054B40001E51A1BA214F400859164CFC054B406D91B41B7D204F40680932022A044B406D91B41B7D204F40
28520	Аныб	3	25	850	52.986156999999999	53.025674000000002	61.879976999999997	61.863826000000003	0103000020E6100000010000000500000059DC7F643A7E4A409EB7B1D991EE4E4059DC7F643A7E4A40B81D1A16A3F04E40C32D1F4949834A40B81D1A16A3F04E40C32D1F4949834A409EB7B1D991EE4E4059DC7F643A7E4A409EB7B1D991EE4E40
57281	Яг	3	25	824	49.039102999999997	50.709583000000002	62.77102	61.618729999999999	0103000020E610000001000000050000007616BD5301854840EC866D8B32CF4E407616BD5301854840ED478AC8B0624F401766A19DD35A4940ED478AC8B0624F401766A19DD35A4940EC866D8B32CF4E407616BD5301854840EC866D8B32CF4E40
26894	Черный Яр	3	25	824	50.277718	50.309707000000003	62.223278000000001	62.216095000000003	0103000020E6100000010000000500000059C16F438C23494021EA3E00A91B4F4059C16F438C23494049F59D5F941C4F40D02B9E7AA427494049F59D5F941C4F40D02B9E7AA427494021EA3E00A91B4F4059C16F438C23494021EA3E00A91B4F40
26963	Усть-Вымь	3	25	824	50.374187999999997	50.423729999999999	62.235923999999997	62.219819000000001	0103000020E610000001000000050000001F477364E52F49400C056C07231C4F401F477364E52F4940B62BF4C1321E4F40C32ADEC83C364940B62BF4C1321E4F40C32ADEC83C3649400C056C07231C4F401F477364E52F49400C056C07231C4F40
27127	Туискерес	3	25	824	50.236790999999997	50.300705999999998	62.168928000000001	62.154218999999998	0103000020E610000001000000050000005A7EE02A4F1E4940FEB5BC72BD134F405A7EE02A4F1E494079B0C56E9F154F4001DBC1887D26494079B0C56E9F154F4001DBC1887D264940FEB5BC72BD134F405A7EE02A4F1E4940FEB5BC72BD134F40
26991	Студенец	3	25	824	50.487816000000002	50.521270000000001	62.172825000000003	62.160812	0103000020E61000000100000005000000973B33C1703E4940F566D47C95144F40973B33C1703E494032772D211F164F406631B1F9B842494032772D211F164F406631B1F9B8424940F566D47C95144F40973B33C1703E4940F566D47C95144F40
27220	Семуково	3	25	824	50.121214000000002	50.167701999999998	62.186402999999999	62.177112000000001	0103000020E610000001000000050000009FE8BAF0830F494055DD239BAB164F409FE8BAF0830F49402A70B20DDC174F40A5BC5642771549402A70B20DDC174F40A5BC56427715494055DD239BAB164F409FE8BAF0830F494055DD239BAB164F40
27248	Микунь	3	25	824	50.039144	50.114369000000003	62.389794999999999	62.340882999999998	0103000020E61000000100000005000000D5EAABAB020549409561DC0DA22B4F40D5EAABAB02054940799274CDE4314F408F56B5A4A30E4940799274CDE4314F408F56B5A4A30E49409561DC0DA22B4F40D5EAABAB020549409561DC0DA22B4F40
26322	Мадмас	3	25	824	49.290937	49.342607999999998	62.035836000000003	62.017716	0103000020E610000001000000050000002219726C3DA54840D74E948444024F402219726C3DA548407E02284696044F408AAC3594DAAB48407E02284696044F408AAC3594DAAB4840D74E948444024F402219726C3DA54840D74E948444024F40
27157	Лыаты	3	25	824	50.166955999999999	50.197301000000003	62.123393999999998	62.106057999999997	0103000020E610000001000000050000007CEF6FD05E15494055BDFC4E930D4F407CEF6FD05E154940E542E55FCB0F4F40EB3BBF2841194940E542E55FCB0F4F40EB3BBF284119494055BDFC4E930D4F407CEF6FD05E15494055BDFC4E930D4F40
27049	Коквицы	3	25	824	50.336638999999998	50.394660999999999	62.152605999999999	62.141106000000001	0103000020E6100000010000000500000071C79BFC162B49407BA2EBC20F124F4071C79BFC162B49403196E99788134F40DA006C40843249403196E99788134F40DA006C40843249407BA2EBC20F124F4071C79BFC162B49407BA2EBC20F124F40
27074	Кожмудор	3	25	824	50.231256999999999	50.289935	62.147575000000003	62.138806000000002	0103000020E610000001000000050000004CFC51D4991D49408A3E1F65C4114F404CFC51D4991D4940865AD3BCE3124F409E7B0F971C254940865AD3BCE3124F409E7B0F971C2549408A3E1F65C4114F404CFC51D4991D49408A3E1F65C4114F40
26428	Казлук	3	25	824	49.313673000000001	49.349955999999999	62.115341000000001	62.097867000000001	0103000020E61000000100000005000000B151D66F26A84840C72DE6E7860C4F40B151D66F26A84840A8716F7EC30E4F40FD84B35BCBAC4840A8716F7EC30E4F40FD84B35BCBAC4840C72DE6E7860C4F40B151D66F26A84840C72DE6E7860C4F40
26796	Илья-Шор	3	25	824	49.764429999999997	49.803128999999998	62.223827	62.207875000000001	0103000020E61000000100000005000000670A9DD7D8E14840F853E3A59B1A4F40670A9DD7D8E148401C7BF65CA61C4F400EBC5AEECCE648401C7BF65CA61C4F400EBC5AEECCE64840F853E3A59B1A4F40670A9DD7D8E14840F853E3A59B1A4F40
26498	Жешарт	3	25	824	49.532718000000003	49.624561999999997	62.106782000000003	62.038321000000003	0103000020E61000000100000005000000CAFE791A30C4484001E0D8B3E7044F40CAFE791A30C4484097E65608AB0D4F408429CAA5F1CF484097E65608AB0D4F408429CAA5F1CF484001E0D8B3E7044F40CAFE791A30C4484001E0D8B3E7044F40
57325	Донаелв	3	25	824	49.404358000000002	49.432268999999998	62.104331999999999	62.089604999999999	0103000020E6100000010000000500000020F0C000C2B348406F47382D780B4F4020F0C000C2B3484090F63FC05A0D4F408D09319754B7484090F63FC05A0D4F408D09319754B748406F47382D780B4F4020F0C000C2B348406F47382D780B4F40
26773	Вездино	3	25	824	49.862149000000002	49.901260999999998	62.173211000000002	62.157291000000001	0103000020E61000000100000005000000BAA3FFE55AEE4840427A8A1C22144F40BAA3FFE55AEE48405B272EC72B164F4083143C855CF348405B272EC72B164F4083143C855CF34840427A8A1C22144F40BAA3FFE55AEE4840427A8A1C22144F40
5910	Вежайка	3	25	824	49.728963999999998	49.751323999999997	62.574671000000002	62.552495	0103000020E610000001000000050000000DFB3DB14EDD48400D1AFA27B8464F400DFB3DB14EDD4840D57ABFD18E494F40965984622BE04840D57ABFD18E494F40965984622BE048400D1AFA27B8464F400DFB3DB14EDD48400D1AFA27B8464F40
26713	Арабач	3	25	824	49.813567999999997	49.842485000000003	62.131923	62.119177999999998	0103000020E610000001000000050000003B8908FF22E848408B338639410F4F403B8908FF22E848408C4B55DAE2104F406F2F698CD6EB48408C4B55DAE2104F406F2F698CD6EB48408B338639410F4F403B8908FF22E848408B338639410F4F40
26864	Айкино	3	25	824	49.957540999999999	50.040913000000003	62.234219000000003	62.203214000000003	0103000020E6100000010000000500000021CA17B490FA4840700B96EA021A4F4021CA17B490FA4840098D60E3FA1D4F409A7D1EA33C054940098D60E3FA1D4F409A7D1EA33C054940700B96EA021A4F4021CA17B490FA4840700B96EA021A4F40
57316	Щельябож	3	25	7429	56.443862000000003	56.468988000000003	66.296079000000006	66.283556000000004	0103000020E61000000100000005000000F5F75278D0384C406AA510C825925040F5F75278D0384C40138255F5F2925040B51B7DCC073C4C40138255F5F2925040B51B7DCC073C4C406AA510C825925040F5F75278D0384C406AA510C825925040
57250	Усть-Уса	3	25	7429	56.890602999999999	56.939050000000002	65.989485999999999	65.974723999999995	0103000020E61000000100000005000000185C7347FF714C4015A8C5E0617E5040185C7347FF714C40647616BD537F504087A757CA32784C40647616BD537F504087A757CA32784C4015A8C5E0617E5040185C7347FF714C4015A8C5E0617E5040
57278	Усть-Лыжа	3	25	7429	56.662638000000001	56.685195	65.690669999999997	65.675381999999999	0103000020E610000001000000050000001E8B6D52D1544C40A7936C75396B50401E8B6D52D1544C400395F1EF336C5040FD304278B4574C400395F1EF336C5040FD304278B4574C40A7936C75396B50401E8B6D52D1544C40A7936C75396B5040
57222	Парма	3	25	7429	57.416567000000001	57.498116000000003	65.973922000000002	65.940175999999994	0103000020E61000000100000005000000E2CB441152B54C40FB1EF5D72B7C5040E2CB441152B54C40B7B6F0BC547E5040A3CEDC43C2BF4C40B7B6F0BC547E5040A3CEDC43C2BF4C40FB1EF5D72B7C5040E2CB441152B54C40FB1EF5D72B7C5040
57268	Новикбож	3	25	7429	56.875934000000001	56.895302000000001	66.036129000000003	66.023386000000002	0103000020E610000001000000050000002CBAF59A1E704C40CB4BFE277F8150402CBAF59A1E704C40FB5B02F04F8250408E05854199724C40FB5B02F04F8250408E05854199724C40CB4BFE277F8150402CBAF59A1E704C40CB4BFE277F815040
57252	Мутный Материк	3	25	7429	55.097431	55.168757999999997	65.964729000000005	65.938034999999999	0103000020E61000000100000005000000EC4E779E788C4B4037E0F3C3087C5040EC4E779E788C4B402E20B41EBE7D50401C78B5DC99954B402E20B41EBE7D50401C78B5DC99954B4037E0F3C3087C5040EC4E779E788C4B4037E0F3C3087C5040
57318	Колва	3	25	7429	57.346893999999999	57.372827999999998	65.969753999999995	65.961579	0103000020E61000000100000005000000DD96C80567AC4C404E61A5828A7D5040DD96C80567AC4C4092CA1473107E50403C84F1D3B8AF4C4092CA1473107E50403C84F1D3B8AF4C404E61A5828A7D5040DD96C80567AC4C404E61A5828A7D5040
57261	Захарвань	3	25	7429	55.849778999999998	55.881912	66.334739999999996	66.327577000000005	0103000020E61000000100000005000000EEE9EA8EC5EC4B40FF7A8505F7945040EEE9EA8EC5EC4B406F2A52616C95504098F90E7EE2F04B406F2A52616C95504098F90E7EE2F04B40FF7A8505F7945040EEE9EA8EC5EC4B40FF7A8505F7945040
57310	Акись	3	25	7429	56.743765000000003	56.762090000000001	65.846903999999995	65.833203999999995	0103000020E61000000100000005000000697407B1335F4C405EB9DE3653755040697407B1335F4C4080B6D5AC33765040E84D452A8C614C4080B6D5AC33765040E84D452A8C614C405EB9DE3653755040697407B1335F4C405EB9DE3653755040
25291	Ыджыдъяг	3	25	756	48.887	48.901418	63.451922000000003	63.446899999999999	0103000020E61000000100000005000000A8C64B37897148408C4AEA0434B94F40A8C64B3789714840E52B8194D8B94F404B033FAA61734840E52B8194D8B94F404B033FAA617348408C4AEA0434B94F40A8C64B37897148408C4AEA0434B94F40
52918	Чупрово	3	25	756	46.556986000000002	46.573740000000001	64.230552000000003	64.215849000000006	0103000020E61000000100000005000000392A37514B474740F5F75278D00D5040392A37514B474740C1012D5DC10E50401A34F44F70494740C1012D5DC10E50401A34F44F70494740F5F75278D00D5040392A37514B474740F5F75278D00D5040
5333	Чим	3	25	756	48.221069999999997	48.249034999999999	63.435586000000001	63.421591999999997	0103000020E61000000100000005000000381092054C1C4840AB2006BAF6B54F40381092054C1C4840384C3448C1B74F409947FE60E01F4840384C3448C1B74F409947FE60E01F4840AB2006BAF6B54F40381092054C1C4840AB2006BAF6B54F40
25378	Чернутьево	3	25	756	48.627495000000003	48.654004	63.768675999999999	63.758651	0103000020E61000000100000005000000A7B393C151504840F209D9791BE14F40A7B393C1515048402C9CA4F963E24F4002BA2F67B65348402C9CA4F963E24F4002BA2F67B6534840F209D9791BE14F40A7B393C151504840F209D9791BE14F40
25875	Усогорск	3	25	756	48.648282000000002	48.729041000000002	63.448891000000003	63.423865999999997	0103000020E61000000100000005000000F14A92E7FA52484073F1B73D41B64F40F14A92E7FA524840003CA24275B94F40B9382A37515D4840003CA24275B94F40B9382A37515D484073F1B73D41B64F40F14A92E7FA52484073F1B73D41B64F40
26084	Солнечный	3	25	756	47.925137999999997	47.952986000000003	63.453028000000003	63.443007000000001	0103000020E61000000100000005000000B72407EC6AF6474015731074B4B84F40B72407EC6AF647400E164ED2FCB94F40DFC5FB71FBF947400E164ED2FCB94F40DFC5FB71FBF9474015731074B4B84F40B72407EC6AF6474015731074B4B84F40
5774	Селэгвож	3	25	756	48.530844999999999	48.539999000000002	63.308427999999999	63.302508000000003	0103000020E61000000100000005000000601F9DBAF2434840A2630795B8A64F40601F9DBAF2434840D99596917AA74F40B56FEEAF1E454840D99596917AA74F40B56FEEAF1E454840A2630795B8A64F40601F9DBAF2434840A2630795B8A64F40
25320	Сельыб	3	25	756	48.547725	48.604525000000002	63.702015000000003	63.684997000000003	0103000020E61000000100000005000000CE1951DA1B464840D76D50FBADD74F40CE1951DA1B4648409626A5A0DBD94F40A54E4013614D48409626A5A0DBD94F40A54E4013614D4840D76D50FBADD74F40CE1951DA1B464840D76D50FBADD74F40
25993	Разгорт	3	25	756	48.688302	48.711506	63.484307999999999	63.474057999999999	0103000020E61000000100000005000000BDE2A9471A5848401E34BBEEADBC4F40BDE2A9471A5848407898F6CDFDBD4F403274ECA0125B48407898F6CDFDBD4F403274ECA0125B48401E34BBEEADBC4F40BDE2A9471A5848401E34BBEEADBC4F40
25793	Муфтюга	3	25	756	46.736739	46.750743999999997	64.158497999999994	64.148283000000006	0103000020E610000001000000050000000858AB764D5E474061E3FA777D0950400858AB764D5E4740CF9ECBD4240A504088D51F6118604740CF9ECBD4240A504088D51F611860474061E3FA777D0950400858AB764D5E474061E3FA777D095040
26243	Мозындор	3	25	756	49.175736999999998	49.210231999999998	62.939551000000002	62.916727000000002	0103000020E610000001000000050000003CD9CD8C7E9648401B2E724F57754F403CD9CD8C7E96484049F6083543784F404D49D6E1E89A484049F6083543784F404D49D6E1E89A48401B2E724F57754F403CD9CD8C7E9648401B2E724F57754F40
7035	Междуреченск	3	25	756	48.550257999999999	48.575060000000001	63.229239999999997	63.214889999999997	0103000020E61000000100000005000000622EA9DA6E464840641EF983819B4F40622EA9DA6E464840AF777FBC579D4F406F9EEA909B494840AF777FBC579D4F406F9EEA909B494840641EF983819B4F40622EA9DA6E464840641EF983819B4F40
25482	Малая Пысса	3	25	756	48.843432	48.86439	64.172531000000006	64.162795000000003	0103000020E610000001000000050000002F336C94F56B4840F33CB83B6B0A50402F336C94F56B4840F5A276BF0A0B5040A67EDE54A46E4840F5A276BF0A0B5040A67EDE54A46E4840F33CB83B6B0A50402F336C94F56B4840F33CB83B6B0A5040
25615	Кривое	3	25	756	47.104050999999998	47.118631000000001	63.967094000000003	63.962798999999997	0103000020E61000000100000005000000DC0E0D8B518D47408DCF64FF3CFB4F40DC0E0D8B518D4740341477BCC9FB4F4059A5F44C2F8F4740341477BCC9FB4F4059A5F44C2F8F47408DCF64FF3CFB4F40DC0E0D8B518D47408DCF64FF3CFB4F40
25164	Кослан	3	25	756	48.859287000000002	48.927838000000001	63.465536	63.452264	0103000020E610000001000000050000006170CD1DFD6D48403E9468C9E3B94F406170CD1DFD6D48402A8E03AF96BB4F4037FE4465C37648402A8E03AF96BB4F4037FE4465C37648403E9468C9E3B94F406170CD1DFD6D48403E9468C9E3B94F40
25576	Ертом	3	25	756	47.813927	47.825758	63.550925999999997	63.543287999999997	0103000020E610000001000000050000006B2A8BC22EE84740952710768AC54F406B2A8BC22EE847400F4240BE84C64F4087342A70B2E947400F4240BE84C64F4087342A70B2E94740952710768AC54F406B2A8BC22EE84740952710768AC54F40
5499	Едва	3	25	756	48.866402000000001	48.890476999999997	63.070214	63.053004000000001	0103000020E610000001000000050000003198BF42E66E48405247C7D5C8864F403198BF42E66E484055DCB8C5FC884F408B6B7C26FB71484055DCB8C5FC884F408B6B7C26FB7148405247C7D5C8864F403198BF42E66E48405247C7D5C8864F40
52883	Глотово	3	25	756	49.473277000000003	49.488261000000001	63.487949999999998	63.471631000000002	0103000020E6100000010000000500000079793A5794BC4840D06394675EBC4F4079793A5794BC4840A60A462575BE4F40C57421567FBE4840A60A462575BE4F40C57421567FBE4840D06394675EBC4F4079793A5794BC4840D06394675EBC4F40
26302	Волжский	3	25	756	49.284486999999999	49.331307000000002	62.840600999999999	62.821131000000001	0103000020E610000001000000050000008E91EC116AA44840AB5D13D21A694F408E91EC116AA4484011FE45D0986B4F40CBF78C4468AA484011FE45D0986B4F40CBF78C4468AA4840AB5D13D21A694F408E91EC116AA44840AB5D13D21A694F40
25679	Важгорт	3	25	756	47.032859999999999	47.062316000000003	64.019868000000002	64.006597999999997	0103000020E610000001000000050000005CACA8C134844740048E041A6C0050405CACA8C1348447402A8F6E84450150403F027FF8F98747402A8F6E84450150403F027FF8F9874740048E041A6C0050405CACA8C134844740048E041A6C005040
52885	Буткан	3	25	756	49.077568999999997	49.110734999999998	63.370671000000002	63.357564000000004	0103000020E610000001000000050000007A17EFC7ED8948400D1D3BA8C4AD4F407A17EFC7ED894840AE49B72572AF4F40E3C281902C8E4840AE49B72572AF4F40E3C281902C8E48400D1D3BA8C4AD4F407A17EFC7ED8948400D1D3BA8C4AD4F40
25413	Большая Пысса	3	25	756	48.816338999999999	48.845103000000002	64.174627000000001	64.160094000000001	0103000020E6100000010000000500000084B9DDCB7D6848404B92E7FA3E0A504084B9DDCB7D684840E97FB9162D0B50403160C9552C6C4840E97FB9162D0B50403160C9552C6C48404B92E7FA3E0A504084B9DDCB7D6848404B92E7FA3E0A5040
52914	Большая Пучкома	3	25	756	46.88382	46.917803999999997	64.078327999999999	64.062354999999997	0103000020E610000001000000050000007EC68503217147407E6FD39FFD0350407EC68503217147401C97715303055040A911FA997A7547401C97715303055040A911FA997A7547407E6FD39FFD0350407EC68503217147407E6FD39FFD035040
26054	Благоево	3	25	756	47.935622000000002	47.967674000000002	63.432501000000002	63.415706999999998	0103000020E6100000010000000500000085B53176C2F74740F0DB10E335B54F4085B53176C2F74740603E59315CB74F404298DBBDDCFB4740603E59315CB74F404298DBBDDCFB4740F0DB10E335B54F4085B53176C2F74740F0DB10E335B54F40
32658	Якша	3	25	833	56.815136000000003	56.849685000000001	61.831246999999998	61.812885999999999	0103000020E6100000010000000500000069E55E6056684C4029B000A60CE84E4069E55E6056684C40F5F23B4D66EA4E406D73637AC26C4C40F5F23B4D66EA4E406D73637AC26C4C4029B000A60CE84E4069E55E6056684C4029B000A60CE84E40
57297	Усть-Илыч	3	25	833	56.719214000000001	56.768566999999997	62.520764999999997	62.513392000000003	0103000020E61000000100000005000000A56950340F5C4C4097033DD4B6414F40A56950340F5C4C4062F3716DA8424F4075E4486760624C4062F3716DA8424F4075E4486760624C4097033DD4B6414F40A56950340F5C4C4097033DD4B6414F40
6027	Троицко-Печорск	3	25	833	56.042270000000002	56.227916	62.751730000000002	62.678887000000003	0103000020E610000001000000050000000CCD751A69054C40FC56EBC4E5564F400CCD751A69054C4007B64AB038604F40191EFB592C1D4C4007B64AB038604F40191EFB592C1D4C40FC56EBC4E5564F400CCD751A69054C40FC56EBC4E5564F40
57339	Тимушбор	3	25	833	55.969802999999999	55.981158000000001	63.132016999999998	63.123190000000001	0103000020E610000001000000050000000648348122FC4B40DD989EB0C48F4F400648348122FC4B400DC2DCEEE5904F40B91AD99596FD4B400DC2DCEEE5904F40B91AD99596FD4B40DD989EB0C48F4F400648348122FC4B40DD989EB0C48F4F40
57331	Русаново	3	25	833	56.161351000000003	56.183539000000003	62.934995999999998	62.923566000000001	0103000020E61000000100000005000000A5164A26A7144C4049D9226937764F40A5164A26A7144C4006F2ECF2AD774F403145B9347E174C4006F2ECF2AD774F403145B9347E174C4049D9226937764F40A5164A26A7144C4049D9226937764F40
57335	Приуральский	3	25	833	57.446634000000003	57.481219000000003	62.632247	62.612811999999998	0103000020E610000001000000050000000EA48B4D2BB94C40554CA59F704E4F400EA48B4D2BB94C403FFF3D78ED504F405F9B8D9598BD4C403FFF3D78ED504F405F9B8D9598BD4C40554CA59F704E4F400EA48B4D2BB94C40554CA59F704E4F40
28346	Покча	3	25	833	56.110156000000003	56.126145999999999	62.951186999999997	62.938462000000001	0103000020E61000000100000005000000A6BA8097190E4C40F644D7851F784F40A6BA8097190E4C40AFB0E07EC0794F40B742588D25104C40AFB0E07EC0794F40B742588D25104C40F644D7851F784F40A6BA8097190E4C40F644D7851F784F40
57336	Палью	3	25	833	56.858668000000002	56.882330000000003	62.515920999999999	62.509464000000001	0103000020E61000000100000005000000950F41D5E86D4C40A33EC91D36414F40950F41D5E86D4C40E92807B309424F40CD237F30F0704C40E92807B309424F40CD237F30F0704C40A33EC91D36414F40950F41D5E86D4C40A33EC91D36414F40
32803	Нижняя Омра	3	25	833	55.809741000000002	55.861134	62.764564999999997	62.750127999999997	0103000020E610000001000000050000007C9DD497A5E74B402DE8BD3104604F407C9DD497A5E74B4047551344DD614F40A1BC8FA339EE4B4047551344DD614F40A1BC8FA339EE4B402DE8BD3104604F407C9DD497A5E74B402DE8BD3104604F40
57272	Митрофан-Дикост	3	25	833	56.107874000000002	56.143887999999997	63.195019000000002	63.179121000000002	0103000020E610000001000000050000005B0BB3D0CE0D4C406F83DA6FED964F405B0BB3D0CE0D4C40A08CF161F6984F40B72407EC6A124C40A08CF161F6984F40B72407EC6A124C406F83DA6FED964F405B0BB3D0CE0D4C406F83DA6FED964F40
27444	Курья	3	25	833	57.234146000000003	57.254223000000003	61.688375000000001	61.675477999999998	0103000020E610000001000000050000009F3E027FF89D4C407095271076D64E409F3E027FF89D4C40273108AC1CD84E400D7217618AA04C40273108AC1CD84E400D7217618AA04C407095271076D64E409F3E027FF89D4C407095271076D64E40
32664	Комсомольск-на-Печоре	3	25	833	56.593189000000002	56.624944999999997	62.150072000000002	62.129601999999998	0103000020E6100000010000000500000069ACFD9DED4B4C4083BF5FCC96104F4069ACFD9DED4B4C40CD052E8F35134F403C66A032FE4F4C40CD052E8F35134F403C66A032FE4F4C4083BF5FCC96104F4069ACFD9DED4B4C4083BF5FCC96104F40
57334	Знаменка	3	25	833	56.841340000000002	56.867201999999999	61.975856	61.965252999999997	0103000020E6100000010000000500000088687407B16B4C40D5AE09698DFB4E4088687407B16B4C407DCD72D9E8FC4E404D83A279006F4C407DCD72D9E8FC4E404D83A279006F4C40D5AE09698DFB4E4088687407B16B4C40D5AE09698DFB4E40
27629	Еремеево	3	25	833	57.537804000000001	57.552194999999998	62.628124	62.625281999999999	0103000020E6100000010000000500000039D4EFC2D6C44C408463963D09504F4039D4EFC2D6C44C4096EA025E66504F40E2016553AEC64C4096EA025E66504F40E2016553AEC64C408463963D09504F4039D4EFC2D6C44C408463963D09504F40
57338	Белый Бор	3	25	833	56.391534999999998	56.412547000000004	62.562972000000002	62.545718999999998	0103000020E61000000100000005000000A31EA2D11D324C4025E7C41EDA454F40A31EA2D11D324C4028486C770F484F400E881057CE344C4028486C770F484F400E881057CE344C4025E7C41EDA454F40A31EA2D11D324C4025E7C41EDA454F40
62096	Бадъель	3	25	833	55.629188999999997	55.650803000000003	62.775111000000003	62.764960000000002	0103000020E610000001000000050000006000E14389D04B40C45F9335EA614F406000E14389D04B408BE255D636634F40C19140834DD34B408BE255D636634F40C19140834DD34B40C45F9335EA614F406000E14389D04B40C45F9335EA614F40
57219	Троицко-Печорск	3	25	7428	56.042270000000002	56.227916	62.751730000000002	62.678887000000003	0103000020E610000001000000050000000CCD751A69054C40FC56EBC4E5564F400CCD751A69054C4007B64AB038604F40191EFB592C1D4C4007B64AB038604F40191EFB592C1D4C40FC56EBC4E5564F400CCD751A69054C40FC56EBC4E5564F40
1602	Шугрэм	3	25	199	49.435009000000001	49.459425000000003	60.957411	60.948141	0103000020E610000001000000050000009B3BFA5FAEB74840957F2DAF5C794E409B3BFA5FAEB7484053EA92718C7A4E407FFB3A70CEBA484053EA92718C7A4E407FFB3A70CEBA4840957F2DAF5C794E409B3BFA5FAEB74840957F2DAF5C794E40
32813	Шорсай	3	25	199	50.316462999999999	50.346223999999999	61.158552999999998	61.148947	0103000020E6100000010000000500000070B20DDC812849402DEBFEB110934E4070B20DDC8128494062D7F6764B944E408F8B6A11512C494062D7F6764B944E408F8B6A11512C49402DEBFEB110934E4070B20DDC812849402DEBFEB110934E40
756	Чухлэм	3	25	199	50.176056000000003	50.188426	61.225143000000003	61.219439000000001	0103000020E61000000100000005000000DE21C50089164940C53BC093169C4E40DE21C5008916494030F65E7CD19C4E40A9DBD9571E18494030F65E7CD19C4E40A9DBD9571E184940C53BC093169C4E40DE21C50089164940C53BC093169C4E40
1685	Пыелдино	3	25	199	50.226433	50.2376	60.946913000000002	60.935760999999999	0103000020E610000001000000050000001ADEACC1FB1C4940A6EF3504C7774E401ADEACC1FB1C49402194F77134794E40CAC342AD691E49402194F77134794E40CAC342AD691E4940A6EF3504C7774E401ADEACC1FB1C4940A6EF3504C7774E40
1032	Первомайский	3	25	199	50.256625999999997	50.303455	61.132688000000002	61.108018999999999	0103000020E61000000100000005000000D2A6EA1ED92049405E2C0C91D38D4E40D2A6EA1ED92049402C499EEBFB904E4062670A9DD72649402C499EEBFB904E4062670A9DD72649405E2C0C91D38D4E40D2A6EA1ED92049405E2C0C91D38D4E40
2037	Палауз	3	25	199	50.265438000000003	50.281509	60.714677000000002	60.708703999999997	0103000020E61000000100000005000000CE8E54DFF9214940AE450BD0B65A4E40CE8E54DFF9214940091A33897A5B4E40CC43A67C08244940091A33897A5B4E40CC43A67C08244940AE450BD0B65A4E40CE8E54DFF9214940AE450BD0B65A4E40
1431	Куратово	3	25	199	49.700200000000002	49.736420000000003	60.913890000000002	60.902034999999998	0103000020E6100000010000000500000061545227A0D94840766C04E275734E4061545227A0D948401B12F758FA744E40670FB40243DE48401B12F758FA744E40670FB40243DE4840766C04E275734E4061545227A0D94840766C04E275734E40
1074	Куниб	3	25	199	50.252844000000003	50.267172000000002	61.123961000000001	61.107489000000001	0103000020E61000000100000005000000B37E33315D20494002D71533C28D4E40B37E33315D2049405F7D3CF4DD8F4E4016342DB1322249405F7D3CF4DD8F4E4016342DB13222494002D71533C28D4E40B37E33315D20494002D71533C28D4E40
1804	Исанево	3	25	199	50.328688999999997	50.344113	61.002389999999998	60.994808999999997	0103000020E6100000010000000500000008C72C7B122A49401B62BCE6557F4E4008C72C7B122A494031EBC5504E804E40719010E50B2C494031EBC5504E804E40719010E50B2C49401B62BCE6557F4E4008C72C7B122A49401B62BCE6557F4E40
57301	Заречное	3	25	199	49.656722000000002	49.685181	60.899273999999998	60.887627000000002	0103000020E6100000010000000500000028486C770FD44840F705F4C29D714E4028486C770FD44840511212691B734E40986BD102B4D74840511212691B734E40986BD102B4D74840F705F4C29D714E4028486C770FD44840F705F4C29D714E40
1792	Заозерье	3	25	199	50.281339000000003	50.322212	60.923493999999998	60.895654999999998	0103000020E61000000100000005000000700B96EA02244940DBBFB2D2A4724E40700B96EA02244940AF06280D35764E407B30293E3E294940AF06280D35764E407B30293E3E294940DBBFB2D2A4724E40700B96EA02244940DBBFB2D2A4724E40
874	Ельбаза	3	25	199	50.130377000000003	50.145755999999999	61.315530000000003	61.304614999999998	0103000020E6100000010000000500000047938B31B01049407E6FD39FFDA64E4047938B31B010494015747B4963A84E400F99F221A812494015747B4963A84E400F99F221A81249407E6FD39FFDA64E4047938B31B01049407E6FD39FFDA64E40
57299	Денисовка	3	25	199	50.208961000000002	50.219759000000003	61.219988999999998	61.214413	0103000020E61000000100000005000000DA91EA3BBF1A49402B6B9BE2719B4E40DA91EA3BBF1A4940683D7C99289C4E4037001B10211C4940683D7C99289C4E4037001B10211C49402B6B9BE2719B4E40DA91EA3BBF1A49402B6B9BE2719B4E40
1930	Гагшор	3	25	199	50.181005999999996	50.200381999999998	60.799622999999997	60.785442000000003	0103000020E610000001000000050000009C3061342B174940D2730B5D89644E409C3061342B1749409010E50B5A664E40815A0C1EA61949409010E50B5A664E40815A0C1EA6194940D2730B5D89644E409C3061342B174940D2730B5D89644E40
981	Вотча	3	25	199	50.333468000000003	50.359779000000003	61.087907000000001	61.080686	0103000020E610000001000000050000009B215514AF2A49405E9F39EB538A4E409B215514AF2A4940740B5D89408B4E40D064FF3C0D2E4940740B5D89408B4E40D064FF3C0D2E49405E9F39EB538A4E409B215514AF2A49405E9F39EB538A4E40
1556	Визиндор	3	25	199	49.68121	49.704754999999999	60.972206	60.963456000000001	0103000020E61000000100000005000000A5DAA7E331D748404791B586527B4E40A5DAA7E331D74840CC7C073F717C4E40A3586E6935DA4840CC7C073F717C4E40A3586E6935DA48404791B586527B4E40A5DAA7E331D748404791B586527B4E40
1156	Визинга	3	25	199	50.06259	50.136288	61.087929000000003	61.057003999999999	0103000020E610000001000000050000004087F9F202084940DFDE35E84B874E404087F9F2020849405CAFE941418B4E402B6B9BE2711149405CAFE941418B4E402B6B9BE271114940DFDE35E84B874E404087F9F202084940DFDE35E84B874E40
1905	Бортом	3	25	199	50.194364	50.217567000000003	60.919659000000003	60.908268999999997	0103000020E6100000010000000500000087C267EBE01849403D7C992842744E4087C267EBE01849406D3CD862B7754E402CD8463CD91B49406D3CD862B7754E402CD8463CD91B49403D7C992842744E4087C267EBE01849403D7C992842744E40
32624	Яснэг	3	25	86	50.611775000000002	50.651201999999998	61.185459000000002	61.174222	0103000020E6100000010000000500000055C1A8A44E4E4940321F10E84C964E4055C1A8A44E4E4940DBDFD91EBD974E407E8B4E965A534940DBDFD91EBD974E407E8B4E965A534940321F10E84C964E4055C1A8A44E4E4940321F10E84C964E40
289	Язель	3	25	86	50.614021000000001	50.625115000000001	61.959180000000003	61.955069000000002	0103000020E610000001000000050000005307793D984E4940333674B33FFA4E405307793D984E4940187D0569C6FA4E40999EB0C403504940187D0569C6FA4E40999EB0C403504940333674B33FFA4E405307793D984E4940333674B33FFA4E40
57240	Ыб	3	25	86	49.361913000000001	51.577382999999998	62.219696999999996	60.925697	0103000020E61000000100000005000000A67F492A53AE4840AE80423D7D764E40A67F492A53AE4840C00303081F1C4F401822A7AFE7C94940C00303081F1C4F401822A7AFE7C94940AE80423D7D764E40A67F492A53AE4840AE80423D7D764E40
6237	Шошка	3	25	86	50.701929999999997	50.729391	61.516509999999997	61.486693000000002	0103000020E61000000100000005000000670A9DD7D85949409818CBF44BBE4E40670A9DD7D85949404A07EBFF1CC24E40957F2DAF5C5D49404A07EBFF1CC24E40957F2DAF5C5D49409818CBF44BBE4E40670A9DD7D85949409818CBF44BBE4E40
371	Часово	3	25	86	50.641626000000002	50.677495999999998	62.020775999999998	62.006169	0103000020E61000000100000005000000B421FFCC20524940E09F5225CA004F40B421FFCC205249405645B8C9A8024F40DD955D30B85649405645B8C9A8024F40DD955D30B8564940E09F5225CA004F40B421FFCC20524940E09F5225CA004F40
598	Слудка	3	25	86	50.169452999999997	50.189808999999997	61.958542000000001	61.945253999999998	0103000020E61000000100000005000000C39ACAA2B0154940E3344415FEF84E40C39ACAA2B0154940D5EB1681B1FA4E4044BE4BA94B184940D5EB1681B1FA4E4044BE4BA94B184940E3344415FEF84E40C39ACAA2B0154940E3344415FEF84E40
240	Парчег	3	25	86	50.761749000000002	50.789892999999999	61.944273000000003	61.920026	0103000020E610000001000000050000005F61C1FD806149401FBC7669C3F54E405F61C1FD8061494077BF0AF0DDF84E406F2BBD361B65494077BF0AF0DDF84E406F2BBD361B6549401FBC7669C3F54E405F61C1FD806149401FBC7669C3F54E40
551	Палевицы	3	25	86	50.328113999999999	50.386864000000003	61.999243	61.988796000000001	0103000020E610000001000000050000000CAEB9A3FF294940333509DE90FE4E400CAEB9A3FF294940E3E0D231E7FF4E40F8FF71C284314940E3E0D231E7FF4E40F8FF71C284314940333509DE90FE4E400CAEB9A3FF294940333509DE90FE4E40
6227	Пажга	3	25	86	50.562511000000001	50.596701000000003	61.397903999999997	61.381360000000001	0103000020E61000000100000005000000F451465C0048494054008C67D0B04E40F451465C004849404A79AD84EEB24E40C93EC8B2604C49404A79AD84EEB24E40C93EC8B2604C494054008C67D0B04E40F451465C0048494054008C67D0B04E40
31960	Озел	3	25	86	51.077057000000003	51.093801999999997	61.777214999999998	61.771070999999999	0103000020E61000000100000005000000C576F700DD8949406FF25B74B2E24E40C576F700DD894940F67AF7C77BE34E40522635B4018C4940F67AF7C77BE34E40522635B4018C49406FF25B74B2E24E40C576F700DD8949406FF25B74B2E24E40
57340	Нювчим	3	25	86	50.727621999999997	50.759134000000003	61.404893999999999	61.386251000000001	0103000020E61000000100000005000000D0ECBAB7225D49400E863AAC70B14E40D0ECBAB7225D49405E2C0C91D3B34E400EA48B4D2B6149405E2C0C91D3B34E400EA48B4D2B6149400E863AAC70B14E40D0ECBAB7225D49400E863AAC70B14E40
57323	Мандач	3	25	86	50.165025	50.192988999999997	61.696392000000003	61.688102000000001	0103000020E61000000100000005000000DE02098A1F154940F627F1B913D84E40DE02098A1F1549401899805F23D94E406EBE11DDB31849401899805F23D94E406EBE11DDB3184940F627F1B913D84E40DE02098A1F154940F627F1B913D84E40
375	Красная	3	25	86	50.797725999999997	50.821432999999999	62.024093999999998	62.017273000000003	0103000020E610000001000000050000009E95B4E21B6649404A0D6D0036024F409E95B4E21B664940D1031F8315034F40766D6FB724694940D1031F8315034F40766D6FB7246949404A0D6D0036024F409E95B4E21B6649404A0D6D0036024F40
506	Ивановка	3	25	86	50.437789000000002	50.464261999999998	62.002977000000001	61.994909	0103000020E6100000010000000500000037C64E78093849407FBF982D59FF4E4037C64E7809384940F2D1E28C61004F404563EDEF6C3B4940F2D1E28C61004F404563EDEF6C3B49407FBF982D59FF4E4037C64E78093849407FBF982D59FF4E40
110	Зеленец	3	25	86	50.714812000000002	50.768450000000001	61.901887000000002	61.877614999999999	0103000020E61000000100000005000000E964A9F57E5B494051BD35B055F04E40E964A9F57E5B494002D8800871F34E403C4ED1915C62494002D8800871F34E403C4ED1915C62494051BD35B055F04E40E964A9F57E5B494051BD35B055F04E40
32074	Захарово	3	25	86	50.545057	50.572671	61.245725999999998	61.202483999999998	0103000020E610000001000000050000005ABA826DC44549404CFBE6FEEA994E405ABA826DC445494071E316F3739F4E400E2F88484D49494071E316F3739F4E400E2F88484D4949404CFBE6FEEA994E405ABA826DC44549404CFBE6FEEA994E40
32639	Гарьинский	3	25	86	50.587898000000003	50.614856000000003	61.383406999999998	61.373511999999998	0103000020E6100000010000000500000021B1DD3D404B4940EF54C03DCFAF4E4021B1DD3D404B49405B07077B13B14E40ECDFF599B34E49405B07077B13B14E40ECDFF599B34E4940EF54C03DCFAF4E4021B1DD3D404B4940EF54C03DCFAF4E40
103	Выльгорт	3	25	86	50.703133000000001	50.812207000000001	61.641514999999998	61.595396999999998	0103000020E6100000010000000500000083DE1B43005A4940799109F835CC4E4083DE1B43005A49405C72DC291DD24E40884A2366F66749405C72DC291DD24E40884A2366F6674940799109F835CC4E4083DE1B43005A4940799109F835CC4E40
57245	Усть-Ухта	3	25	895	53.858646	53.894649999999999	63.627198	63.612022000000003	0103000020E61000000100000005000000AD6BB41CE8ED4A405D37A5BC56CE4F40AD6BB41CE8ED4A40ED0E290648D04F40E6AE25E483F24A40ED0E290648D04F40E6AE25E483F24A405D37A5BC56CE4F40AD6BB41CE8ED4A405D37A5BC56CE4F40
6907	Сосногорск	3	25	895	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57298	Порожок	3	25	895	53.737068000000001	53.753236999999999	63.921661999999998	63.911945000000003	0103000020E61000000100000005000000CD76853E58DE4A4018601F9DBAF44F40CD76853E58DE4A40A4FB3905F9F54F408E91EC116AE04A40A4FB3905F9F54F408E91EC116AE04A4018601F9DBAF44F40CD76853E58DE4A4018601F9DBAF44F40
57251	Поляна	3	25	895	54.060918999999998	54.086359999999999	63.549402999999998	63.538803000000001	0103000020E610000001000000050000003E5A9C31CC074B404CFE277FF7C44F403E5A9C31CC074B4082A966D652C64F405ED72FD80D0B4B4082A966D652C64F405ED72FD80D0B4B404CFE277FF7C44F403E5A9C31CC074B404CFE277FF7C44F40
57215	Нижний Одес	3	25	895	54.774028999999999	54.887746999999997	63.659548999999998	63.628656999999997	0103000020E61000000100000005000000EA93DC6113634B4063B323D577D04F40EA93DC6113634B40048E041A6CD44F40A10F96B1A1714B40048E041A6CD44F40A10F96B1A1714B4063B323D577D04F40EA93DC6113634B4063B323D577D04F40
57223	Малая Пера	3	25	895	54.813958999999997	54.853431	64.187072999999998	64.174364999999995	0103000020E6100000010000000500000076A4FACE2F684B404A24D1CB280B504076A4FACE2F684B40BC3D0801F90B504040321D3A3D6D4B40BC3D0801F90B504040321D3A3D6D4B404A24D1CB280B504076A4FACE2F684B404A24D1CB280B5040
57242	Керки	3	25	895	54.173577000000002	54.216849000000003	63.737445000000001	63.712744999999998	0103000020E610000001000000050000003D2B69C537164B409AB1683A3BDB4F403D2B69C537164B40A3CC069964DE4F40CD9541B5C11B4B40A3CC069964DE4F40CD9541B5C11B4B409AB1683A3BDB4F403D2B69C537164B409AB1683A3BDB4F40
57243	Ирасль	3	25	895	55.177416999999998	55.222171000000003	64.417846999999995	64.394604000000001	0103000020E610000001000000050000009160AA99B5964B40BBB72231411950409160AA99B5964B40D4EE5701BE1A5040508F6D19709C4B40D4EE5701BE1A5040508F6D19709C4B40BBB72231411950409160AA99B5964B40BBB7223141195040
57237	Войвож	3	25	895	54.938124000000002	55.020715000000003	62.907063999999998	62.883336999999997	0103000020E61000000100000005000000DECB7D7214784B40622CD32F11714F40DECB7D7214784B4081B053AC1A744F40B1C403CAA6824B4081B053AC1A744F40B1C403CAA6824B40622CD32F11714F40DECB7D7214784B40622CD32F11714F40
57236	Вис	3	25	895	54.426039000000003	54.473354	63.925438	63.903032000000003	0103000020E6100000010000000500000008E9297288364B40E99E758D96F34F4008E9297288364B40E23C9CC074F64F4024B726DD963C4B40E23C9CC074F64F4024B726DD963C4B40E99E758D96F34F4008E9297288364B40E99E758D96F34F40
57249	Верхнеижемский	3	25	895	54.675268000000003	54.731009	63.009712	62.985807000000001	0103000020E6100000010000000500000086048C2E6F564B407D957CEC2E7E4F4086048C2E6F564B407B30293E3E814F40740AF2B3915D4B407B30293E3E814F40740AF2B3915D4B407D957CEC2E7E4F4086048C2E6F564B407D957CEC2E7E4F40
57304	дер.Пожня	3	25	7426	53.826082	53.995288000000002	63.614445000000003	63.535873000000002	0103000020E610000001000000050000003AE8120EBDE94A409BE7887C97C44F403AE8120EBDE94A406A183E22A6CE4F40F60CE19865FF4A406A183E22A6CE4F40F60CE19865FF4A409BE7887C97C44F403AE8120EBDE94A409BE7887C97C44F40
57213	Сосногорск	3	25	7426	53.969389999999997	53.970064000000001	63.557091	63.556649999999998	0103000020E61000000100000005000000E388B5F814FC4A40C1A8A44E40C74F40E388B5F814FC4A40AEF204C24EC74F407383A10E2BFC4A40AEF204C24EC74F407383A10E2BFC4A40C1A8A44E40C74F40E388B5F814FC4A40C1A8A44E40C74F40
57327	Якуньель	3	25	420	49.764294999999997	49.789223	59.38776	59.368706000000003	0103000020E6100000010000000500000087BF266BD4E1484064EB19C231AF4D4087BF266BD4E148403659A31EA2B14D4021205F4205E548403659A31EA2B14D4021205F4205E5484064EB19C231AF4D4087BF266BD4E1484064EB19C231AF4D40
3520	Читаево	3	25	420	49.546075999999999	49.580714999999998	60.480629999999998	60.466971999999998	0103000020E61000000100000005000000B49080D1E5C54840E8120EBDC53B4E40B49080D1E5C54840FDBCA948853D4E40F8A57EDE54CA4840FDBCA948853D4E40F8A57EDE54CA4840E8120EBDC53B4E40B49080D1E5C54840E8120EBDC53B4E40
4062	Черныш	3	25	420	49.596158000000003	49.616988999999997	60.231600999999998	60.200282000000001	0103000020E61000000100000005000000D89FC4E74ECC48401EFD2FD7A2194E40D89FC4E74ECC4840465C001AA51D4E40F17EDC7EF9CE4840465C001AA51D4E40F17EDC7EF9CE48401EFD2FD7A2194E40D89FC4E74ECC48401EFD2FD7A2194E40
4804	Черемуховка	3	25	420	49.454044000000003	49.519441	59.554068000000001	59.504890000000003	0103000020E61000000100000005000000F778211D1EBA4840EA094B3CA0C04D40F778211D1EBA48404CE141B3EBC64D40CC99ED0A7DC248404CE141B3EBC64D40CC99ED0A7DC24840EA094B3CA0C04D40F778211D1EBA4840EA094B3CA0C04D40
57287	Чекша	3	25	420	49.514060000000001	49.532431000000003	60.162393000000002	60.153075000000001	0103000020E610000001000000050000004417D4B7CCC14840E86A2BF697134E404417D4B7CCC14840B70C384BC9144E403430F2B226C44840B70C384BC9144E403430F2B226C44840E86A2BF697134E404417D4B7CCC14840E86A2BF697134E40
57309	Усть-Лопью	3	25	420	49.624149000000003	49.645439000000003	60.230144000000003	60.222901999999998	0103000020E61000000100000005000000626A4B1DE4CF4840431B800D881C4E40626A4B1DE4CF484071AFCC5B751D4E400F48C2BE9DD2484071AFCC5B751D4E400F48C2BE9DD24840431B800D881C4E40626A4B1DE4CF4840431B800D881C4E40
3408	Спаспоруб	3	25	420	49.0242	49.062970999999997	60.657682999999999	60.632205999999996	0103000020E61000000100000005000000174850FC18834840E02A4F20EC504E40174850FC188348404D11E0F42E544E4057CC086F0F8848404D11E0F42E544E4057CC086F0F884840E02A4F20EC504E40174850FC18834840E02A4F20EC504E40
5178	Слудка	3	25	420	49.703183000000003	49.726619999999997	59.393433000000002	59.373845000000003	0103000020E61000000100000005000000350D8AE601DA4840F6622827DAAF4D40350D8AE601DA4840661536035CB24D404C4F58E201DD4840661536035CB24D404C4F58E201DD4840F6622827DAAF4D40350D8AE601DA4840F6622827DAAF4D40
5247	Прокопьевка	3	25	420	49.661726000000002	49.690382	59.288395000000001	59.273124000000003	0103000020E61000000100000005000000DA740470B3D4484059E02BBAF5A24D40DA740470B3D448403BAA9A20EAA44D40A0DFF76F5ED848403BAA9A20EAA44D40A0DFF76F5ED8484059E02BBAF5A24D40DA740470B3D4484059E02BBAF5A24D40
3325	Поруб-Кеповская	3	25	420	48.971342999999997	49.017947999999997	60.784616	60.754289999999997	0103000020E610000001000000050000006919A9F7547C484094D920938C604E406919A9F7547C48408CF50D4C6E644E40A983BC1E4C8248408CF50D4C6E644E40A983BC1E4C82484094D920938C604E406919A9F7547C484094D920938C604E40
57289	Пожемаяг	3	25	420	49.505310999999999	49.535359999999997	59.536841000000003	59.517277	0103000020E610000001000000050000008FA7E507AEC048408BFCFA2136C24D408FA7E507AEC048407313B534B7C44D4014CB2DAD86C448407313B534B7C44D4014CB2DAD86C448408BFCFA2136C24D408FA7E507AEC048408BFCFA2136C24D40
57282	Орысь	3	25	420	49.382905999999998	49.398079000000003	60.188394000000002	60.179540000000003	0103000020E6100000010000000500000099B8551003B148407429AE2AFB164E4099B8551003B148409E616A4B1D184E40B91CAF40F4B248409E616A4B1D184E40B91CAF40F4B248407429AE2AFB164E4099B8551003B148407429AE2AFB164E40
57313	Оньмесь	3	25	420	48.838087000000002	48.853079999999999	59.932842999999998	59.924438000000002	0103000020E61000000100000005000000F419506F466B4840FF9600FC53F64D40F419506F466B4840B9A6406667F74D40936FB6B9316D4840B9A6406667F74D40936FB6B9316D4840FF9600FC53F64D40F419506F466B4840FF9600FC53F64D40
2257	Объячево	3	25	420	49.572719999999997	49.644137000000001	60.353696999999997	60.321697999999998	0103000020E61000000100000005000000EFE192E34EC9484024986A662D294E40EFE192E34EC94840BED87BF1452D4E406092CA1473D24840BED87BF1452D4E406092CA1473D2484024986A662D294E40EFE192E34EC9484024986A662D294E40
4237	Ношуль	3	25	420	49.480328999999998	49.525396999999998	60.156514000000001	60.138271000000003	0103000020E610000001000000050000000229B16B7BBD48401C7E37DDB2114E400229B16B7BBD4840DEAE97A608144E4050357A3540C34840DEAE97A608144E4050357A3540C348401C7E37DDB2114E400229B16B7BBD48401C7E37DDB2114E40
4960	Мутница	3	25	420	49.503900999999999	49.542717000000003	59.489204999999998	59.471139999999998	0103000020E61000000100000005000000FAB5F5D37FC0484031EBC5504EBC4D40FAB5F5D37FC048401405FA449EBE4D40DBFD2AC077C548401405FA449EBE4D40DBFD2AC077C5484031EBC5504EBC4D40FAB5F5D37FC0484031EBC5504EBC4D40
3210	Лойма	3	25	420	48.802225999999997	48.821513000000003	60.556134999999998	60.546089000000002	0103000020E610000001000000050000001D007157AF66484049DA8D3EE6454E401D007157AF6648409A94826E2F474E40931E8656276948409A94826E2F474E40931E86562769484049DA8D3EE6454E401D007157AF66484049DA8D3EE6454E40
57330	Лихачевская	3	25	420	49.344988999999998	49.387596000000002	60.154606999999999	60.135502000000002	0103000020E61000000100000005000000683D7C9928AC48407445292158114E40683D7C9928AC4840C85D8429CA134E40BC07E8BE9CB14840C85D8429CA134E40BC07E8BE9CB148407445292158114E40683D7C9928AC48407445292158114E40
4683	Летка	3	25	420	49.398474	49.447971000000003	59.644877000000001	59.579000999999998	0103000020E6100000010000000500000035272F3201B34840F7AC6BB41CCA4D4035272F3201B34840A7785C548BD24D4039471D1D57B94840A7785C548BD24D4039471D1D57B94840F7AC6BB41CCA4D4035272F3201B34840F7AC6BB41CCA4D40
57312	Кыддзявидзь	3	25	420	49.577534999999997	49.609138000000002	60.497405999999998	60.487504999999999	0103000020E61000000100000005000000CEA5B8AAECC9484078D15790663E4E40CEA5B8AAECC94840C66AF3FFAA3F4E401C60E63BF8CD4840C66AF3FFAA3F4E401C60E63BF8CD484078D15790663E4E40CEA5B8AAECC9484078D15790663E4E40
57311	Коржинский	3	25	420	48.563194000000003	48.584592000000001	60.418337999999999	60.409514999999999	0103000020E61000000100000005000000D7A6B1BD16484840581CCEFC6A344E40D7A6B1BD1648484047567E198C354E406AC020E9D34A484047567E198C354E406AC020E9D34A4840581CCEFC6A344E40D7A6B1BD16484840581CCEFC6A344E40
3190	Козловская	3	25	420	48.769088000000004	48.788114	60.536717000000003	60.530591000000001	0103000020E610000001000000050000007FDFBF7971624840A646E867EA434E407FDFBF7971624840871A8524B3444E4087C267EBE0644840871A8524B3444E4087C267EBE0644840A646E867EA434E407FDFBF7971624840A646E867EA434E40
3728	Калининская	3	25	420	49.514456000000003	49.538629	60.365374000000003	60.347237999999997	0103000020E61000000100000005000000919DB7B1D9C14840D7F6764B722C4E40919DB7B1D9C1484084674293C42E4E40AED689CBF1C4484084674293C42E4E40AED689CBF1C44840D7F6764B722C4E40919DB7B1D9C14840D7F6764B722C4E40
3438	Занулье	3	25	420	49.383966000000001	49.398465000000002	60.647663999999999	60.637059000000001	0103000020E61000000100000005000000526342CC25B14840AD4F39268B514E40526342CC25B14840F56569A7E6524E40E2CCAFE600B34840F56569A7E6524E40E2CCAFE600B34840AD4F39268B514E40526342CC25B14840AD4F39268B514E40
57292	Гыркашор	3	25	420	49.707619999999999	49.721525999999997	60.215924999999999	60.209054999999999	0103000020E610000001000000050000006DFFCA4A93DA48405B087250C21A4E406DFFCA4A93DA4840C4B12E6EA31B4E405A9BC6F65ADC4840C4B12E6EA31B4E405A9BC6F65ADC48405B087250C21A4E406DFFCA4A93DA48405B087250C21A4E40
5065	Гурьевка	3	25	420	49.584586999999999	49.610019000000001	59.437365	59.420307000000001	0103000020E6100000010000000500000058552FBFD3CA4840D3A3A99ECCB54D4058552FBFD3CA484020B58993FBB74D402578431A15CE484020B58993FBB74D402578431A15CE4840D3A3A99ECCB54D4058552FBFD3CA4840D3A3A99ECCB54D40
4606	Гостиногорка	3	25	420	49.393138	49.415857000000003	59.693277999999999	59.678258	0103000020E610000001000000050000004D68925852B248400C207C28D1D64D404D68925852B24840A5846055BDD84D4006685BCD3AB54840A5846055BDD84D4006685BCD3AB548400C207C28D1D64D404D68925852B248400C207C28D1D64D40
3303	Галахтионовская	3	25	420	48.850906000000002	48.868063999999997	60.583126999999998	60.576301999999998	0103000020E610000001000000050000002FFCE07CEA6C4840484F9143C4494E402FFCE07CEA6C48401135D1E7A34A4E40DF6A9DB81C6F48401135D1E7A34A4E40DF6A9DB81C6F4840484F9143C4494E402FFCE07CEA6C4840484F9143C4494E40
57283	Вухтым	3	25	420	49.650038000000002	49.677545000000002	60.463295000000002	60.44256	0103000020E610000001000000050000002194F77134D3484046425BCEA5384E402194F77134D348403EB324404D3B4E40BF4868CBB9D648403EB324404D3B4E40BF4868CBB9D6484046425BCEA5384E402194F77134D3484046425BCEA5384E40
4577	Верхолузье	3	25	420	48.687997000000003	48.706905999999996	59.922404	59.896056999999999	0103000020E61000000100000005000000815F2349105848400A2DEBFEB1F24D40815F2349105848408CD9925511F64D404FAC53E57B5A48408CD9925511F64D404FAC53E57B5A48400A2DEBFEB1F24D40815F2349105848400A2DEBFEB1F24D40
57266	Велодоръя	3	25	420	49.088501999999998	49.097628	60.058385000000001	60.050668000000002	0103000020E61000000100000005000000B7D09508548B4840147AFD497C064E40B7D09508548B4840DAC9E02879074E40429605137F8C4840DAC9E02879074E40429605137F8C4840147AFD497C064E40B7D09508548B4840147AFD497C064E40
57326	Ваймес	3	25	420	49.217193999999999	49.235143000000001	60.137034999999997	60.125715	0103000020E6100000010000000500000097715303CD9B4840EECEDA6D17104E4097715303CD9B484024B4E55C8A114E401171732A199E484024B4E55C8A114E401171732A199E4840EECEDA6D17104E4097715303CD9B4840EECEDA6D17104E40
3918	Беляевская	3	25	420	49.630788000000003	49.647630999999997	60.319318000000003	60.301679	0103000020E61000000100000005000000C95A43A9BDD04840EB71DF6A9D264E40C95A43A9BDD0484017838769DF284E4019709692E5D2484017838769DF284E4019709692E5D24840EB71DF6A9D264E40C95A43A9BDD04840EB71DF6A9D264E40
5036	Архиповка	3	25	420	49.420904999999998	49.456595	59.509360000000001	59.489260000000002	0103000020E6100000010000000500000087DC0C37E0B54840D89E5912A0BE4D4087DC0C37E0B54840FEF15EB532C14D40314278B471BA4840FEF15EB532C14D40314278B471BA4840D89E5912A0BE4D4087DC0C37E0B54840D89E5912A0BE4D40
57337	пос.Новая Березовка	3	25	1277	54.521782000000002	60.221367999999998	65.829621000000003	64.203012999999999	0103000020E610000001000000050000001CD2A8C0C9424B406CEA3C2AFE0C50401CD2A8C0C9424B40CAC4AD8218755040C23060C9551C4E40CAC4AD8218755040C23060C9551C4E406CEA3C2AFE0C50401CD2A8C0C9424B406CEA3C2AFE0C5040
57239	Чикшино	3	25	1277	56.398927999999998	56.441527000000001	64.91583	64.885889000000006	0103000020E61000000100000005000000B6BA9C1210334C40B7B8C667B2385040B6BA9C1210334C4086AC6EF59C3A504087A6ECF483384C4086AC6EF59C3A504087A6ECF483384C40B7B8C667B2385040B6BA9C1210334C40B7B8C667B2385040
57273	Усть-Кожва	3	25	1277	56.983687000000003	57.014643	65.149255999999994	65.138542000000001	0103000020E610000001000000050000000C40A374E97D4C40D6C743DFDD4850400C40A374E97D4C40D5AE09698D495040C30E63D2DF814C40D5AE09698D495040C30E63D2DF814C40D6C743DFDD4850400C40A374E97D4C40D6C743DFDD485040
57291	Талый	3	25	1277	55.669308000000001	55.695449000000004	64.621091000000007	64.606966	0103000020E61000000100000005000000C07971E2ABD54B402CF2EB87D8265040C07971E2ABD54B40C23577F4BF27504099840B7904D94B40C23577F4BF27504099840B7904D94B402CF2EB87D8265040C07971E2ABD54B402CF2EB87D8265040
57320	Сыня	3	25	1277	58.018456	58.138210999999998	65.376740999999996	65.344811000000007	0103000020E610000001000000050000001E3526C45C024D4045132862115650401E3526C45C024D40FD8348861C5850404679E6E5B0114D40FD8348861C5850404679E6E5B0114D4045132862115650401E3526C45C024D404513286211565040
57286	Соколово	3	25	1277	57.004950000000001	57.022996999999997	65.351254999999995	65.339599000000007	0103000020E61000000100000005000000BF0E9C33A2804C4047B071FDBB555040BF0E9C33A2804C409D6340F67A565040FB73D190F1824C409D6340F67A565040FB73D190F1824C4047B071FDBB555040BF0E9C33A2804C4047B071FDBB555040
57277	Рыбница	3	25	1277	55.462955999999998	55.493912000000002	64.561623999999995	64.548455000000004	0103000020E6100000010000000500000055BE672442BB4B40F91400E31923504055BE672442BB4B408429CAA5F12350400D8D278238BF4B408429CAA5F12350400D8D278238BF4B40F91400E31923504055BE672442BB4B40F91400E319235040
57235	Путеец	3	25	1277	57.073267000000001	57.106755999999997	65.181348999999997	65.167702000000006	0103000020E61000000100000005000000227024D060894C40535E2BA1BB4A5040227024D060894C40630AD6389B4B50406D533C2EAA8D4C40630AD6389B4B50406D533C2EAA8D4C40535E2BA1BB4A5040227024D060894C40535E2BA1BB4A5040
57275	Причал	3	25	1277	56.293745000000001	56.344230000000003	64.573239000000001	64.562706000000006	0103000020E61000000100000005000000882EA86F99254C40D5D0066003245040882EA86F99254C40AC72A1F2AF245040AB2688BA0F2C4C40AC72A1F2AF245040AB2688BA0F2C4C40D5D0066003245040882EA86F99254C40D5D0066003245040
57314	Приуральское	3	25	1277	57.860137000000002	57.879541000000003	64.739007999999998	64.723059000000006	0103000020E610000001000000050000002F8A1EF818EE4C4006854199462E50402F8A1EF818EE4C40DFDE35E84B2F5040DE3EABCC94F04C40DFDE35E84B2F5040DE3EABCC94F04C4006854199462E50402F8A1EF818EE4C4006854199462E5040
13361	Печора	3	25	1277	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57244	Озерный	3	25	1277	57.150567000000002	57.176402000000003	65.096082999999993	65.086393000000001	0103000020E61000000100000005000000AD6D8AC745934C409D66817687455040AD6D8AC745934C40E6AC4F392646504079793A5794964C40E6AC4F392646504079793A5794964C409D66817687455040AD6D8AC745934C409D66817687455040
57276	Набережный	3	25	1277	57.024388999999999	57.053980000000003	65.137597	65.123424	0103000020E61000000100000005000000EAB0C22D1F834C40A8E2C62DE6475040EAB0C22D1F834C40C6C1A563CE485040AD510FD1E8864C40C6C1A563CE485040AD510FD1E8864C40A8E2C62DE6475040EAB0C22D1F834C40A8E2C62DE6475040
57319	Медвежская	3	25	1277	57.570160999999999	57.586222999999997	64.944626	64.940557999999996	0103000020E61000000100000005000000323A2009FBC84C406F7F2E1A323C5040323A2009FBC84C40E23C9CC0743C5040DD94F25A09CB4C40E23C9CC0743C5040DD94F25A09CB4C406F7F2E1A323C5040323A2009FBC84C406F7F2E1A323C5040
57290	Луговой	3	25	1277	57.096057000000002	57.124920000000003	65.169129999999996	65.143106000000003	0103000020E61000000100000005000000A4C684984B8C4C40217711A628495040A4C684984B8C4C4070B1A206D34A5040E44EE960FD8F4C4070B1A206D34A5040E44EE960FD8F4C40217711A628495040A4C684984B8C4C40217711A628495040
57260	Красный Яг	3	25	1277	57.278737999999997	57.301851999999997	65.091564000000005	65.068826999999999	0103000020E610000001000000050000008313D1AFADA34C403C855CA9674450408313D1AFADA34C406C5F402FDC455040B81D1A16A3A64C406C5F402FDC455040B81D1A16A3A64C403C855CA9674450408313D1AFADA34C403C855CA967445040
57280	Косью	3	25	1277	58.955148000000001	58.972503000000003	65.616722999999993	65.607393999999999	0103000020E610000001000000050000007F6B274A427A4D405872158BDF6650407F6B274A427A4D4039ECBE6378675040862172FA7A7C4D4039ECBE6378675040862172FA7A7C4D405872158BDF6650407F6B274A427A4D405872158BDF665040
57315	Конецбор	3	25	1277	57.723207000000002	57.739331999999997	64.848977000000005	64.840676999999999	0103000020E61000000100000005000000809E060C92DC4C40F65FE7A6CD355040809E060C92DC4C409983A0A3553650407171546EA2DE4C409983A0A3553650407171546EA2DE4C40F65FE7A6CD355040809E060C92DC4C40F65FE7A6CD355040
57227	Кожва	3	25	1277	57.017338000000002	57.101590999999999	65.123417000000003	65.095602	0103000020E61000000100000005000000317DAF2138824C40A9DBD9571E465040317DAF2138824C404FB16A10E6475040B24813EF008D4C404FB16A10E6475040B24813EF008D4C40A9DBD9571E465040317DAF2138824C40A9DBD9571E465040
57285	Кедровый Шор	3	25	1277	57.602392000000002	57.636834	64.890004000000005	64.882227999999998	0103000020E610000001000000050000009FAF592E1BCD4C4064E76D6C763850409FAF592E1BCD4C40CA5356D3F53850408D7DC9C683D14C40CA5356D3F53850408D7DC9C683D14C4064E76D6C763850409FAF592E1BCD4C4064E76D6C76385040
57209	Каджером	3	25	1277	55.866262999999996	55.936807999999999	64.700744	64.680926999999997	0103000020E610000001000000050000000F5EBBB4E1EE4B40A8FDD64E942B50400F5EBBB4E1EE4B4091B75CFDD82C5040CA501553E9F74B4091B75CFDD82C5040CA501553E9F74B40A8FDD64E942B50400F5EBBB4E1EE4B40A8FDD64E942B5040
57208	Изъяю	3	25	1277	56.961409000000003	57.008139	65.120018999999999	65.093288000000001	0103000020E61000000100000005000000408A3A730F7B4C40FE463B6EF8455040408A3A730F7B4C4083F92B64AE4750403C69E1B20A814C4083F92B64AE4750403C69E1B20A814C40FE463B6EF8455040408A3A730F7B4C40FE463B6EF8455040
57267	Зеленоборск	3	25	1277	55.285009000000002	55.319701000000002	64.486590000000007	64.473371999999998	0103000020E610000001000000050000006808C72C7BA44B40E5B512BA4B1E50406808C72C7BA44B40E223624A241F5040CFBF5DF6EBA84B40E223624A241F5040CFBF5DF6EBA84B40E5B512BA4B1E50406808C72C7BA44B40E5B512BA4B1E5040
57308	Даниловка	3	25	1277	57.853903000000003	57.872031	64.715354000000005	64.692625000000007	0103000020E61000000100000005000000687A89B14CED4C4017D9CEF7532C5040687A89B14CED4C4005C4245CC82D5040910C39B69EEF4C4005C4245CC82D5040910C39B69EEF4C4017D9CEF7532C5040687A89B14CED4C4017D9CEF7532C5040
57262	Бызовая	3	25	1277	57.367330000000003	57.389733999999997	65.023723000000004	65.014955999999998	0103000020E610000001000000050000007B6B60AB04AF4C4041B8020AF54050407B6B60AB04AF4C406F4A79AD84415040D311C0CDE2B14C406F4A79AD84415040D311C0CDE2B14C4041B8020AF54050407B6B60AB04AF4C4041B8020AF5405040
57264	Березовка	3	25	1277	56.508918000000001	56.595650999999997	65.030113	65.007679999999993	0103000020E61000000100000005000000412C9B3924414C40543541D47D405040412C9B3924414C40CE8B135FED415040336ABE4A3E4C4C40CE8B135FED415040336ABE4A3E4C4C40543541D47D405040412C9B3924414C40543541D47D405040
57263	Белый-Ю	3	25	1277	57.113835000000002	57.134613000000002	65.279617999999999	65.273114000000007	0103000020E61000000100000005000000F1113125928E4C401B8524B37A515040F1113125928E4C40DE57E542E5515040E84EB0FF3A914C40DE57E542E5515040E84EB0FF3A914C401B8524B37A515040F1113125928E4C401B8524B37A515040
57274	Аранец	3	25	1277	57.834921000000001	57.853067000000003	64.834719000000007	64.829042999999999	0103000020E610000001000000050000002FDFFAB0DEEA4C4093FE5E0A0F3550402FDFFAB0DEEA4C4064963D096C355040FF25A94C31ED4C4064963D096C355040FF25A94C31ED4C4093FE5E0A0F3550402FDFFAB0DEEA4C4093FE5E0A0F355040
57216	Печора	3	25	7427	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
30702	Усть-Лэкчим	3	25	795	51.682755	51.716622000000001	61.785961	61.775559999999999	0103000020E610000001000000050000001A170E8464D74940FA0AD28C45E34E401A170E8464D749403A77BB5E9AE44E400CCC0A45BADB49403A77BB5E9AE44E400CCC0A45BADB4940FA0AD28C45E34E401A170E8464D74940FA0AD28C45E34E40
31545	Уръель	3	25	795	52.484313	52.507795000000002	61.843013999999997	61.830902999999999	0103000020E610000001000000050000008A03E8F7FD3D4A40FB928D075BEA4E408A03E8F7FD3D4A40FA08FCE1E7EB4E404209336DFF404A40FA08FCE1E7EB4E404209336DFF404A40FB928D075BEA4E408A03E8F7FD3D4A40FB928D075BEA4E40
6559	Троицк	3	25	795	52.695579000000002	52.732185000000001	62.235827999999998	62.222771000000002	0103000020E61000000100000005000000676490BB08594A40A5BF97C2831C4F40676490BB08594A4094BDA59C2F1E4F4096CFF23CB85D4A4094BDA59C2F1E4F4096CFF23CB85D4A40A5BF97C2831C4F40676490BB08594A40A5BF97C2831C4F40
31869	Сюзяыб	3	25	795	52.465071000000002	52.482624000000001	62.229410999999999	62.217768999999997	0103000020E61000000100000005000000B5A84F72873B4A40938AC6DADF1B4F40B5A84F72873B4A40DC2BF3565D1D4F40E2218C9FC63D4A40DC2BF3565D1D4F40E2218C9FC63D4A40938AC6DADF1B4F40B5A84F72873B4A40938AC6DADF1B4F40
6539	Сторожевск	3	25	795	52.272714999999998	52.368242000000002	61.957095000000002	61.922795000000001	0103000020E6100000010000000500000077103B53E8224A40C7F484251EF64E4077103B53E8224A402315C61682FA4E40BF81C98D222F4A402315C61682FA4E40BF81C98D222F4A40C7F484251EF64E4077103B53E8224A40C7F484251EF64E40
31203	Приозерный	3	25	795	51.803085000000003	51.833123999999998	61.844712000000001	61.833201000000003	0103000020E610000001000000050000003F74417DCBE649404CFF9254A6EA4E403F74417DCBE64940F644D7851FEC4E40A0C1A6CEA3EA4940F644D7851FEC4E40A0C1A6CEA3EA49404CFF9254A6EA4E403F74417DCBE649404CFF9254A6EA4E40
30622	Позтыкерес	3	25	795	51.535736999999997	51.556452	61.570743999999998	61.561410000000002	0103000020E61000000100000005000000EA20AF0793C44940DDD26A48DCC74E40EA20AF0793C44940B131AF230EC94E409BE5B2D139C74940B131AF230EC94E409BE5B2D139C74940DDD26A48DCC74E40EA20AF0793C44940DDD26A48DCC74E40
31452	Подъельск	3	25	795	52.678673000000003	52.714011999999997	61.929332000000002	61.908881999999998	0103000020E61000000100000005000000D0D6C1C1DE564A4027F6D03E56F44E40D0D6C1C1DE564A402A90D959F4F64E40CC79C6BE645B4A402A90D959F4F64E40CC79C6BE645B4A4027F6D03E56F44E40D0D6C1C1DE564A4027F6D03E56F44E40
31628	Подтыбок	3	25	795	52.837772999999999	52.905129000000002	61.917425999999999	61.901290000000003	0103000020E61000000100000005000000643C4A253C6B4A401E1B81785DF34E40643C4A253C6B4A40034015376EF54E40A2D45E44DB734A40034015376EF54E40A2D45E44DB734A401E1B81785DF34E40643C4A253C6B4A401E1B81785DF34E40
31149	Пезмег	3	25	795	51.684049000000002	51.74597	61.829633000000001	61.821333000000003	0103000020E6100000010000000500000046EEE9EA8ED749401310937021E94E4046EEE9EA8ED749405857056A31EA4E4008E6E8F17BDF49405857056A31EA4E4008E6E8F17BDF49401310937021E94E4046EEE9EA8ED749401310937021E94E40
31890	Нившера	3	25	795	52.864775999999999	52.940351999999997	62.367643999999999	62.328853000000002	0103000020E61000000100000005000000CF2EDFFAB06E4A408318E8DA172A4F40CF2EDFFAB06E4A400A4966F50E2F4F40355D4F745D784A400A4966F50E2F4F40355D4F745D784A408318E8DA172A4F40CF2EDFFAB06E4A408318E8DA172A4F40
31293	Небдино	3	25	795	52.104514000000002	52.146878999999998	61.917709000000002	61.902988999999998	0103000020E61000000100000005000000B1FCF9B6600D4A40E9D2BF2495F34E40B1FCF9B6600D4A40581F0F7D77F54E400EBC5AEECC124A40581F0F7D77F54E400EBC5AEECC124A40E9D2BF2495F34E40B1FCF9B6600D4A40E9D2BF2495F34E40
30477	Намск	3	25	795	52.087339	52.120027999999998	61.191733999999997	61.173336999999997	0103000020E610000001000000050000002A55A2EC2D0B4A40E71725E82F964E402A55A2EC2D0B4A4000C45DBD8A984E40594DD7135D0F4A4000C45DBD8A984E40594DD7135D0F4A40E71725E82F964E402A55A2EC2D0B4A40E71725E82F964E40
30543	Мордино	3	25	795	51.889898000000002	51.911484000000002	61.361665000000002	61.353400999999998	0103000020E610000001000000050000004E637B2DE8F14940D5AF743E3CAD4E404E637B2DE8F14940CE8DE9094BAE4E40E469F981ABF44940CE8DE9094BAE4E40E469F981ABF44940D5AF743E3CAD4E404E637B2DE8F14940D5AF743E3CAD4E40
31053	Маджа	3	25	795	51.451421000000003	51.484361999999997	61.855682999999999	61.845497000000002	0103000020E6100000010000000500000023DDCF29C8B94940DDEEE53E39EC4E4023DDCF29C8B94940205F420587ED4E406BB6F292FFBD4940205F420587ED4E406BB6F292FFBD4940DDEEE53E39EC4E4023DDCF29C8B94940DDEEE53E39EC4E40
30754	Корткерос	3	25	795	51.542949999999998	51.603093000000001	61.820874000000003	61.794015999999999	0103000020E610000001000000050000007DAEB6627FC549401840F850A2E54E407DAEB6627FC549408011346612E94E4028B9C32632CD49408011346612E94E4028B9C32632CD49401840F850A2E54E407DAEB6627FC549401840F850A2E54E40
31486	Керес	3	25	795	52.644661999999997	52.696261999999997	61.873268000000003	61.858122999999999	0103000020E61000000100000005000000AA7CCF4884524A40037976F9D6ED4E40AA7CCF4884524A405952EE3EC7EF4E4049B9FB1C1F594A405952EE3EC7EF4E4049B9FB1C1F594A40037976F9D6ED4E40AA7CCF4884524A40037976F9D6ED4E40
30933	Додзь	3	25	795	51.339993999999997	51.371102999999998	61.780866000000003	61.775010999999999	0103000020E61000000100000005000000096B63EC84AB49402785798F33E34E40096B63EC84AB49407847C66AF3E34E404739984D80AF49407847C66AF3E34E404739984D80AF49402785798F33E34E40096B63EC84AB49402785798F33E34E40
31701	Выльыб	3	25	795	52.460445	52.478257999999997	62.155459	62.140045999999998	0103000020E61000000100000005000000A94D9CDCEF3A4A40C2F7FE06ED114F40A94D9CDCEF3A4A40376F9C14E6134F407286E28E373D4A40376F9C14E6134F407286E28E373D4A40C2F7FE06ED114F40A94D9CDCEF3A4A40C2F7FE06ED114F40
31388	Вомын	3	25	795	52.521394999999998	52.565638	61.947988000000002	61.936743999999997	0103000020E6100000010000000500000022A64412BD424A40B35C363AE7F74E4022A64412BD424A400F80B8AB57F94E40FBAF73D366484A400F80B8AB57F94E40FBAF73D366484A40B35C363AE7F74E4022A64412BD424A40B35C363AE7F74E40
31019	Визябож	3	25	795	51.203783000000001	51.262532	61.754513000000003	61.740169999999999	0103000020E610000001000000050000008A3DB48F159A49407BBDFBE3BDDE4E408A3DB48F159A494014B4C9E193E04E40A51309A69AA1494014B4C9E193E04E40A51309A69AA149407BBDFBE3BDDE4E408A3DB48F159A49407BBDFBE3BDDE4E40
30600	Веселовка	3	25	795	51.569693000000001	51.595267999999997	61.474051000000003	61.467300000000002	0103000020E610000001000000050000004CE141B3EBC84940DDB5847CD0BB4E404CE141B3EBC849406CD102B4ADBC4E407B2DE8BD31CC49406CD102B4ADBC4E407B2DE8BD31CC4940DDB5847CD0BB4E404CE141B3EBC84940DDB5847CD0BB4E40
57305	Важкуръя	3	25	795	51.873404999999998	51.950938000000001	61.866773999999999	61.847937999999999	0103000020E61000000100000005000000D9942BBCCBEF494090847D3B89EC4E40D9942BBCCBEF4940F5824F73F2EE4E4007431D56B8F94940F5824F73F2EE4E4007431D56B8F9494090847D3B89EC4E40D9942BBCCBEF494090847D3B89EC4E40
31597	Большелуг	3	25	795	52.483567000000001	52.528672	62.135136000000003	62.123600000000003	0103000020E6100000010000000500000061360186E53D4A408FE4F21FD20F4F4061360186E53D4A409241EE224C114F40CC272B86AB434A409241EE224C114F40CC272B86AB434A408FE4F21FD20F4F4061360186E53D4A408FE4F21FD20F4F40
5602	Богородск	3	25	795	52.477082000000003	52.499450000000003	62.264105999999998	62.251728	0103000020E6100000010000000500000051C1E105113D4A4066BE839F38204F4051C1E105113D4A40B456B439CE214F405DFE43FAED3F4A40B456B439CE214F405DFE43FAED3F4A4066BE839F38204F4051C1E105113D4A4066BE839F38204F40
31099	Аджером	3	25	795	51.643202000000002	51.718058999999997	61.864068000000003	61.841303000000003	0103000020E61000000100000005000000645C717154D249406B8313D1AFEB4E40645C717154D2494094C2BCC799EE4E409ACC785BE9DB494094C2BCC799EE4E409ACC785BE9DB49406B8313D1AFEB4E40645C717154D249406B8313D1AFEB4E40
2393	Ужга	3	25	394	51.012512999999998	51.089543999999997	60.525880999999998	60.501539999999999	0103000020E610000001000000050000002EE3A6069A81494063D1747632404E402EE3A6069A8149403C4B901150434E40C9C6832D768B49403C4B901150434E40C9C6832D768B494063D1747632404E402EE3A6069A81494063D1747632404E40
2495	Седтыдор	3	25	394	50.973148999999999	50.997574	60.566625000000002	60.549393999999999	0103000020E610000001000000050000004B917C25907C49402F4FE78A52464E404B917C25907C49404A0C022B87484E4082AB3C81B07F49404A0C022B87484E4082AB3C81B07F49402F4FE78A52464E404B917C25907C49402F4FE78A52464E40
2154	Подзь	3	25	394	50.341624000000003	50.365484000000002	60.677553000000003	60.667721	0103000020E61000000100000005000000ADC3D155BA2B49401CEDB8E177554E40ADC3D155BA2B49404227840EBA564E400B9B012EC82E49404227840EBA564E400B9B012EC82E49401CEDB8E177554E40ADC3D155BA2B49401CEDB8E177554E40
2608	Нючпас	3	25	394	51.464635000000001	51.495277000000002	60.686293999999997	60.675217000000004	0103000020E61000000100000005000000DAC9E02879BB4940045ABA826D564E40DAC9E02879BB494073B8567BD8574E4002BB9A3C65BF494073B8567BD8574E4002BB9A3C65BF4940045ABA826D564E40DAC9E02879BB4940045ABA826D564E40
3058	Нижний Турунъю	3	25	394	52.045341999999998	52.081473000000003	60.340826999999997	60.330927000000003	0103000020E610000001000000050000004F9143C4CD054A40842EE1D05B2A4E404F9143C4CD054A40014C1938A02B4E40E6400FB56D0A4A40014C1938A02B4E40E6400FB56D0A4A40842EE1D05B2A4E404F9143C4CD054A40842EE1D05B2A4E40
2837	Кузьель	3	25	394	50.767569999999999	50.798363999999999	60.352294999999998	60.341538999999997	0103000020E6100000010000000500000003B2D7BB3F6249407EA7C98CB72B4E4003B2D7BB3F624940ACC5A700182D4E40E126A3CA30664940ACC5A700182D4E40E126A3CA306649407EA7C98CB72B4E4003B2D7BB3F6249407EA7C98CB72B4E40
57270	Ком	3	25	394	49.940283999999998	52.371889000000003	60.984197000000002	59.748517999999997	0103000020E61000000100000005000000DD79E2395BF84840D13B1570CFDF4D40DD79E2395BF8484021E9D32AFA7D4E40FF5E0A0F9A2F4A4021E9D32AFA7D4E40FF5E0A0F9A2F4A40D13B1570CFDF4D40DD79E2395BF84840D13B1570CFDF4D40
2727	Койдин	3	25	394	50.973356000000003	50.993944999999997	60.436309999999999	60.401662999999999	0103000020E61000000100000005000000C5AEEDED967C4940B28174B169334E40C5AEEDED967C494079758E01D9374E40E882FA96397F494079758E01D9374E40E882FA96397F4940B28174B169334E40C5AEEDED967C4940B28174B169334E40
2631	Койгородок	3	25	394	50.970337000000001	51.029186000000003	60.463596000000003	60.435053000000003	0103000020E61000000100000005000000A48CB800347C49406B8313D1AF374E40A48CB800347C494039471D1D573B4E4023C0E95DBC83494039471D1D573B4E4023C0E95DBC8349406B8313D1AF374E40A48CB800347C49406B8313D1AF374E40
2954	Кажим	3	25	394	51.526538000000002	51.558069000000003	60.341174000000002	60.324255000000001	0103000020E61000000100000005000000F60CE19865C349404148163081294E40F60CE19865C349406D1FF296AB2B4E40AAF413CE6EC749406D1FF296AB2B4E40AAF413CE6EC749404148163081294E40F60CE19865C349404148163081294E40
2060	Иван-Чомья	3	25	394	50.430844999999998	50.448084000000001	60.678333000000002	60.671123000000001	0103000020E610000001000000050000009352D0ED25374940F54BC45BE7554E409352D0ED253749401766A19DD3564E4031EE06D15A3949401766A19DD3564E4031EE06D15A394940F54BC45BE7554E409352D0ED25374940F54BC45BE7554E40
2160	Зимовка	3	25	394	50.565798999999998	50.583207999999999	60.568083999999999	60.560938	0103000020E61000000100000005000000048E041A6C484940B58AFED0CC474E40048E041A6C484940C0B0FCF9B6484E40FE614B8FA64A4940C0B0FCF9B6484E40FE614B8FA64A4940B58AFED0CC474E40048E041A6C484940B58AFED0CC474E40
2272	Грива	3	25	394	50.873176000000001	50.900906999999997	60.587223000000002	60.571975000000002	0103000020E6100000010000000500000078D32D3BC46F494097900F7A36494E4078D32D3BC46F4940C13A8E1F2A4B4E4065DEAAEB50734940C13A8E1F2A4B4E4065DEAAEB5073494097900F7A36494E4078D32D3BC46F494097900F7A36494E40
57296	Вежъю	3	25	394	51.132114999999999	51.149299999999997	60.653075000000001	60.644275999999998	0103000020E61000000100000005000000D027F224E990494081CCCEA277524E40D027F224E9904940E86A2BF697534E407AA52C431C934940E86A2BF697534E407AA52C431C93494081CCCEA277524E40D027F224E990494081CCCEA277524E40
24147	Шошка	3	25	901	50.680478000000001	50.719168000000003	62.702800000000003	62.690824999999997	0103000020E61000000100000005000000E1D231E7195749402D211FF46C584F40E1D231E7195749407DD0B359F5594F40352A70B20D5C49407DD0B359F5594F40352A70B20D5C49402D211FF46C584F40E1D231E7195749402D211FF46C584F40
57228	Чиньяворык	3	25	901	52.650348999999999	52.691113999999999	63.228706000000003	63.199821999999998	0103000020E610000001000000050000003FFED2A23E534A40BA826DC493994F403FFED2A23E534A401233FB3C469D4F4064E76D6C76584A401233FB3C469D4F4064E76D6C76584A40BA826DC493994F403FFED2A23E534A40BA826DC493994F40
32953	Чернореченский	3	25	901	51.442985999999998	51.526763000000003	62.775370000000002	62.750799000000001	0103000020E61000000100000005000000FD4AE7C3B3B849404C6F7F2E1A604F40FD4AE7C3B3B849405726FC523F634F4016DF50F86CC349405726FC523F634F4016DF50F86CC349404C6F7F2E1A604F40FD4AE7C3B3B849404C6F7F2E1A604F40
57300	Туръя	3	25	901	50.633972	50.658146000000002	62.828237999999999	62.817897000000002	0103000020E61000000100000005000000344A97FE255149408E3F51D9B0684F40344A97FE25514940F8A6E9B3036A4F4022FFCC203E544940F8A6E9B3036A4F4022FFCC203E5449408E3F51D9B0684F40344A97FE255149408E3F51D9B0684F40
57255	Тракт	3	25	901	51.264482000000001	51.303145000000001	62.707977	62.691267000000003	0103000020E61000000100000005000000BA30D28BDAA14940EBE6E26F7B584F40BA30D28BDAA14940FCA886FD9E5A4F4014799274CDA64940FCA886FD9E5A4F4014799274CDA64940EBE6E26F7B584F40BA30D28BDAA14940EBE6E26F7B584F40
24343	Синдор	3	25	901	51.866326000000001	51.995908	62.873527000000003	62.807139999999997	0103000020E6100000010000000500000056D636C5E3EE49408FA50F5D50674F4056D636C5E3EE4940259694BBCF6F4F4092E9D0E979FF4940259694BBCF6F4F4092E9D0E979FF49408FA50F5D50674F4056D636C5E3EE49408FA50F5D50674F40
25003	Серегово	3	25	901	50.683092000000002	50.722034000000001	62.338034	62.315167000000002	0103000020E610000001000000050000006214048F6F574940A4E36A6457284F406214048F6F574940D177B7B2442B4F40CF4C309C6B5C4940D177B7B2442B4F40CF4C309C6B5C4940A4E36A6457284F406214048F6F574940A4E36A6457284F40
32927	Ропча	3	25	901	52.291786000000002	52.324593	63.043577999999997	63.023111999999998	0103000020E6100000010000000500000020B75F3E59254A4094128255F5824F4020B75F3E59254A409C69C2F693854F4059C16F438C294A409C69C2F693854F4059C16F438C294A4094128255F5824F4020B75F3E59254A4094128255F5824F40
32964	Ракпас	3	25	901	51.093558999999999	51.119458000000002	62.687188999999996	62.675707000000003	0103000020E610000001000000050000008C9FC6BDF98B4940D25625917D564F408C9FC6BDF98B4940E19524CFF5574F406F9F55664A8F4940E19524CFF5574F406F9F55664A8F4940D25625917D564F408C9FC6BDF98B4940D25625917D564F40
57332	Мещура	3	25	901	50.900807999999998	50.920813000000003	63.352034000000003	63.328870000000002	0103000020E61000000100000005000000D2FC31AD4D7349405951836918AA4F40D2FC31AD4D734940408A3A730FAD4F40A75D4C33DD754940408A3A730FAD4F40A75D4C33DD7549405951836918AA4F40D2FC31AD4D7349405951836918AA4F40
57322	Ляли	3	25	901	50.658577000000001	50.692523999999999	62.294479000000003	62.266832000000001	0103000020E61000000100000005000000EB724A404C5449405DC30C8D27224F40EB724A404C544940ED2DE57CB1254F40F9D85DA0A4584940ED2DE57CB1254F40F9D85DA0A45849405DC30C8D27224F40EB724A404C5449405DC30C8D27224F40
24179	Княжпогост	3	25	901	50.843271000000001	50.863061000000002	62.605553	62.598011	0103000020E610000001000000050000002655DB4DF06B4940FAD2DB9F8B4C4F402655DB4DF06B4940527FBDC2824D4F40FEB968C8786E4940527FBDC2824D4F40FEB968C8786E4940FAD2DB9F8B4C4F402655DB4DF06B4940FAD2DB9F8B4C4F40
57303	Иоссер	3	25	901	52.160524000000002	52.198397	63.000884999999997	62.975313	0103000020E610000001000000050000008F1CE90C8C144A408C2E6F0ED77C4F408F1CE90C8C144A404A07EBFF1C804F40F04FA91265194A404A07EBFF1C804F40F04FA91265194A408C2E6F0ED77C4F408F1CE90C8C144A408C2E6F0ED77C4F40
24632	Емва	3	25	901	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
57333	Ветью	3	25	901	50.773445000000002	50.808101999999998	62.949959999999997	62.937565999999997	0103000020E610000001000000050000009B20EA3E00634940B7EBA52902784F409B20EA3E006349400B410E4A98794F4085EAE6E26F6749400B410E4A98794F4085EAE6E26F674940B7EBA52902784F409B20EA3E00634940B7EBA52902784F40
57246	Юсьтыдор	3	25	1225	60.079532999999998	60.09581	66.057226	66.051439999999999	0103000020E61000000100000005000000F4F928232E0A4E40336DFFCA4A835040F4F928232E0A4E40C79E3D97A98350409C508880430C4E40C79E3D97A98350409C508880430C4E40336DFFCA4A835040F4F928232E0A4E40336DFFCA4A835040
57259	Петрунь	3	25	1225	60.718387999999997	60.748157999999997	66.478931000000003	66.466553000000005	0103000020E610000001000000050000005FEB5223F45B4E4072361D01DC9D50405FEB5223F45B4E40998235CEA69E5040D11E2FA4C35F4E40998235CEA69E5040D11E2FA4C35F4E4072361D01DC9D50405FEB5223F45B4E4072361D01DC9D5040
57256	Косьювом	3	25	1225	59.876226000000003	59.890321	66.292766999999998	66.276653999999994	0103000020E61000000100000005000000D4F36E2C28F04D40AF93FAB2B4915040D4F36E2C28F04D404696CCB1BC92504094F8DC09F6F14D404696CCB1BC92504094F8DC09F6F14D40AF93FAB2B4915040D4F36E2C28F04D40AF93FAB2B4915040
12419	Инта	3	25	1225	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57229	Верхняя Инта	3	25	1225	60.295136999999997	60.354705000000003	66.005578999999997	65.975335000000001	0103000020E61000000100000005000000766B990CC7254E403AE97DE36B7E5040766B990CC7254E40D7A205685B805040255D33F9662D4E40D7A205685B805040255D33F9662D4E403AE97DE36B7E5040766B990CC7254E403AE97DE36B7E5040
57306	Адзьвавом	3	25	1225	59.272756000000001	59.302553000000003	66.595507999999995	66.590242000000003	0103000020E61000000100000005000000D6E429ABE9A24D4071AE6186C6A55040D6E429ABE9A24D40682096CD1CA650404227840EBAA64D40682096CD1CA650404227840EBAA64D4071AE6186C6A55040D6E429ABE9A24D4071AE6186C6A55040
19292	Ыргеншар	3	25	1528	53.399984000000003	53.431766000000003	65.268945000000002	65.258999000000003	0103000020E610000001000000050000002E76FBAC32B34A4097AC8A70935050402E76FBAC32B34A400EDB1665365150402BC3B81B44B74A400EDB1665365150402BC3B81B44B74A4097AC8A70935050402E76FBAC32B34A4097AC8A7093505040
19710	Щельяюр	3	25	1528	53.365453000000002	53.456460999999997	65.331390999999996	65.313862999999998	0103000020E61000000100000005000000D09CF529C7AE4A402A1BD65416545040D09CF529C7AE4A4014CC988235555040217365506DBA4A4014CC988235555040217365506DBA4A402A1BD65416545040D09CF529C7AE4A402A1BD65416545040
19916	Чика	3	25	1528	54.309483	54.343592000000001	65.493088	65.481352999999999	0103000020E6100000010000000500000080D591239D274B403735D07CCE5E504080D591239D274B403483F8C08E5F5040689599D2FA2B4B403483F8C08E5F5040689599D2FA2B4B403735D07CCE5E504080D591239D274B403735D07CCE5E5040
19631	Усть-Ижма	3	25	1528	52.912351000000001	52.929912999999999	65.313614999999999	65.296936000000002	0103000020E6100000010000000500000088BCE5EAC7744A405340DAFF0053504088BCE5EAC7744A403E22A644125450400890A16307774A403E22A644125450400890A16307774A405340DAFF0053504088BCE5EAC7744A405340DAFF00535040
18807	Том	3	25	1528	53.345627	53.379286999999998	64.507234999999994	64.485044000000002	0103000020E61000000100000005000000ABCE6A813DAC4A40BF47FDF50A1F5040ABCE6A813DAC4A40BD18CA89762050402366F6798CB04A40BD18CA89762050402366F6798CB04A40BF47FDF50A1F5040ABCE6A813DAC4A40BF47FDF50A1F5040
19094	Сизябск	3	25	1528	53.837724000000001	53.878103000000003	65.073243000000005	65.058595999999994	0103000020E6100000010000000500000083893F8A3AEB4A404AEB6F09C043504083893F8A3AEB4A404D6A6803B04450407FC2D9AD65F04A404D6A6803B04450407FC2D9AD65F04A404AEB6F09C043504083893F8A3AEB4A404AEB6F09C0435040
19728	Пиль-Егор	3	25	1528	53.584606000000001	53.605742999999997	65.435955000000007	65.424657999999994	0103000020E61000000100000005000000CF85915ED4CA4A40067FBF982D5B5040CF85915ED4CA4A40C6E1CCAFE65B5040F56393FC88CD4A40C6E1CCAFE65B5040F56393FC88CD4A40067FBF982D5B5040CF85915ED4CA4A40067FBF982D5B5040
19810	Няшабож	3	25	1528	53.822254999999998	53.859768000000003	65.472009	65.458049000000003	0103000020E610000001000000050000007AFCDEA63FE94A40CBBDC0AC505D50407AFCDEA63FE94A40BB9A3C65355E5040DC12B9E00CEE4A40BB9A3C65355E5040DC12B9E00CEE4A40CBBDC0AC505D50407AFCDEA63FE94A40CBBDC0AC505D5040
18850	Мошъюга	3	25	1528	53.740445000000001	53.757648000000003	64.865099999999998	64.846095000000005	0103000020E610000001000000050000004DBED9E6C6DE4A40C993A46B263650404DBED9E6C6DE4A4041F163CC5D3750409EF0129CFAE04A4041F163CC5D3750409EF0129CFAE04A40C993A46B263650404DBED9E6C6DE4A40C993A46B26365040
18959	Мохча	3	25	1528	53.810612999999996	53.845503000000001	65.015119999999996	64.989144999999994	0103000020E61000000100000005000000315BB22AC2E74A401F80D4264E3F5040315BB22AC2E74A40FE60E0B9F7405040BFD53A7139EC4A40FE60E0B9F7405040BFD53A7139EC4A401F80D4264E3F5040315BB22AC2E74A401F80D4264E3F5040
19587	Малое Галово	3	25	1528	52.928251000000003	52.945822	65.289947999999995	65.282954000000004	0103000020E610000001000000050000005ABDC3EDD0764A406F1118EB1B5250405ABDC3EDD0764A4099620E828E5250402DEBFEB110794A4099620E828E5250402DEBFEB110794A406F1118EB1B5250405ABDC3EDD0764A406F1118EB1B525040
19103	Ласта	3	25	1528	53.801125999999996	53.816972999999997	64.931180999999995	64.923428999999999	0103000020E61000000100000005000000D6FCF84B8BE64A4064CBF275193B5040D6FCF84B8BE64A40056A3178983B5040855B3E9292E84A40056A3178983B5040855B3E9292E84A4064CBF275193B5040D6FCF84B8BE64A4064CBF275193B5040
19383	Краснобор	3	25	1528	53.264383000000002	53.309496000000003	65.299867000000006	65.285515000000004	0103000020E61000000100000005000000274F594DD7A14A401EE1B4E045525040274F594DD7A14A4094895B0531535040151F9F909DA74A4094895B0531535040151F9F909DA74A401EE1B4E045525040274F594DD7A14A401EE1B4E045525040
18700	Койю	3	25	1528	53.638055000000001	53.665300999999999	64.350313	64.341893999999996	0103000020E610000001000000050000004F0647C9ABD14A40B62C5F97E11550404F0647C9ABD14A40469737876B165040807F4A9528D54A40469737876B165040807F4A9528D54A40B62C5F97E11550404F0647C9ABD14A40B62C5F97E1155040
19931	Кипиево	3	25	1528	54.473300000000002	54.541536000000001	65.678715999999994	65.651302999999999	0103000020E6100000010000000500000031992A18953C4B405932C7F2AE69504031992A18953C4B4067D13B15706B5040A7CD380D51454B4067D13B15706B5040A7CD380D51454B405932C7F2AE69504031992A18953C4B405932C7F2AE695040
19532	Кельчиюр	3	25	1528	52.975386	53.016080000000002	65.282422999999994	65.270582000000005	0103000020E61000000100000005000000F67CCD72D97C4A40B9382A3751515040F67CCD72D97C4A40D828EB3713525040520FD1E80E824A40D828EB3713525040520FD1E80E824A40B9382A3751515040F67CCD72D97C4A40B9382A3751515040
18753	Картаель	3	25	1528	53.311176000000003	53.338664999999999	64.531008999999997	64.514852000000005	0103000020E610000001000000050000006AA67B9DD4A74A40EF91CD55F32050406AA67B9DD4A74A406D382C0DFC21504061A6ED5F59AB4A406D382C0DFC21504061A6ED5F59AB4A40EF91CD55F32050406AA67B9DD4A74A40EF91CD55F3205040
19188	Ижма	3	25	1528	53.888846999999998	53.939565999999999	65.030060000000006	64.994270999999998	0103000020E61000000100000005000000E8120EBDC5F14A401E17D522A23F5040E8120EBDC5F14A40BD3AC780EC4150407E37DDB243F84A40BD3AC780EC4150407E37DDB243F84A401E17D522A23F5040E8120EBDC5F14A401E17D522A23F5040
19318	Диюр	3	25	1528	53.346201999999998	53.380913	65.280133000000006	65.271353000000005	0103000020E61000000100000005000000A7E7DD5850AC4A40FA2AF9D85D515040A7E7DD5850AC4A40F261F6B2ED51504085CFD6C1C1B04A40F261F6B2ED51504085CFD6C1C1B04A40FA2AF9D85D515040A7E7DD5850AC4A40FA2AF9D85D515040
18908	Гам	3	25	1528	53.786195999999997	53.815750999999999	64.992384999999999	64.977309000000005	0103000020E610000001000000050000007D1F0E12A2E44A4089450C3B8C3E50407D1F0E12A2E44A409F02603C833F5040F3565D876AE84A409F02603C833F5040F3565D876AE84A4089450C3B8C3E50407D1F0E12A2E44A4089450C3B8C3E5040
18056	Вертеп	3	25	1528	53.188817	53.222152999999999	65.308257999999995	65.293447	0103000020E61000000100000005000000E4F6CB272B984A40FF06EDD5C7525040E4F6CB272B984A40BE2EC37FBA535040A9DA6E826F9C4A40BE2EC37FBA535040A9DA6E826F9C4A40FF06EDD5C7525040E4F6CB272B984A40FF06EDD5C7525040
19831	Брыкаланск	3	25	1528	54.249609999999997	54.294257000000002	65.482057999999995	65.467618000000002	0103000020E6100000010000000500000095607138F31F4B4057410C74ED5D504095607138F31F4B409C31CC09DA5E50403ECF9F36AA254B409C31CC09DA5E50403ECF9F36AA254B4057410C74ED5D504095607138F31F4B4057410C74ED5D5040
19487	Большое Галово	3	25	1528	53.093648999999999	53.117184999999999	65.290093999999996	65.278616999999997	0103000020E61000000100000005000000CC26C0B0FC8B4A4004C765DCD4515040CC26C0B0FC8B4A4003B16CE690525040774A07EBFF8E4A4003B16CE690525040774A07EBFF8E4A4004C765DCD4515040CC26C0B0FC8B4A4004C765DCD4515040
19034	Бакур	3	25	1528	53.838712000000001	53.865203000000001	65.049199999999999	65.041686999999996	0103000020E61000000100000005000000A26131EA5AEB4A40C66AF3FFAA425040A26131EA5AEB4A40A5BDC1172643504057B3CEF8BEEE4A40A5BDC1172643504057B3CEF8BEEE4A40C66AF3FFAA425040A26131EA5AEB4A40C66AF3FFAA425040
57279	Шердино	3	25	7430	56.447868999999997	56.468843999999997	63.482239999999997	63.468276000000003	0103000020E6100000010000000500000034F279C553394C4038C0CC77F0BB4F4034F279C553394C405969520ABABD4F4081768714033C4C405969520ABABD4F4081768714033C4C4038C0CC77F0BB4F4034F279C553394C4038C0CC77F0BB4F40
57271	Усть-Соплеск	3	25	7430	57.678021999999999	57.696131999999999	64.365337999999994	64.356947000000005	0103000020E61000000100000005000000F8FBC56CC9D64C40F1D93A38D8165040F8FBC56CC9D64C401B7FA2B2611750407BD976DA1AD94C401B7FA2B2611750407BD976DA1AD94C40F1D93A38D8165040F8FBC56CC9D64C40F1D93A38D8165040
57241	Подчерье	3	25	7430	57.550730000000001	57.575541999999999	63.949399	63.930914000000001	0103000020E610000001000000050000008A7615527EC64C40BCB1A03028F74F408A7615527EC64C4074ED0BE885F94F40BABC395CABC94C4074ED0BE885F94F40BABC395CABC94C40BCB1A03028F74F408A7615527EC64C40BCB1A03028F74F40
57293	Лемтыбож	3	25	7430	56.934989000000002	56.952478999999997	63.862751000000003	63.853779000000003	0103000020E61000000100000005000000548F34B8AD774C407C8159A148ED4F40548F34B8AD774C40B0CBF09F6EEE4F403A90F5D4EA794C40B0CBF09F6EEE4F403A90F5D4EA794C407C8159A148ED4F40548F34B8AD774C407C8159A148ED4F40
57317	Лемты	3	25	7430	56.828763000000002	56.843828000000002	63.875222000000001	63.865532999999999	0103000020E610000001000000050000004391EEE7146A4C40EC4D0CC9C9EE4F404391EEE7146A4C40AF5E454607F04F407CB94F8E026C4C40AF5E454607F04F407CB94F8E026C4C40EC4D0CC9C9EE4F404391EEE7146A4C40EC4D0CC9C9EE4F40
57232	Дутово	3	25	7430	56.684027	56.713482999999997	63.816871999999996	63.781509999999997	0103000020E610000001000000050000005E4A5D328E574C409CBF098508E44F405E4A5D328E574C405182FE428FE84F4040A03369535B4C405182FE428FE84F4040A03369535B4C409CBF098508E44F405E4A5D328E574C409CBF098508E44F40
40316	Вуктыл	3	25	6897	57.290246000000003	57.336742999999998	63.882719000000002	63.838240999999996	0103000020E61000000100000005000000BDE5EAC726A54C404A95287B4BEB4F40BDE5EAC726A54C406747AAEFFCF04F40161406651AAB4C406747AAEFFCF04F40161406651AAB4C404A95287B4BEB4F40BDE5EAC726A54C404A95287B4BEB4F40
57233	Сивомаскинский	3	25	7423	62.54486	62.585858999999999	66.680010999999993	66.66498	0103000020E610000001000000050000000473F4F8BD454F409F1F46088FAA50400473F4F8BD454F40E57ADB4C85AB50409C887E6DFD4A4F40E57ADB4C85AB50409C887E6DFD4A4F409F1F46088FAA50400473F4F8BD454F409F1F46088FAA5040
57214	Северный	3	25	7423	64.066677999999996	64.137573000000003	67.609491000000006	67.590271000000001	0103000020E610000001000000050000003657CD7344045040BE310400C7E550403657CD7344045040350D8AE601E7504002F4FBFECD085040350D8AE601E7504002F4FBFECD085040BE310400C7E550403657CD7344045040BE310400C7E55040
57231	Комсомольский	3	25	7423	63.757154999999997	63.827331000000001	67.573705000000004	67.537290999999996	0103000020E610000001000000050000005E807D74EAE04F40D95BCAF962E250405E807D74EAE04F404F232D95B7E45040C6FB71FBE5E94F404F232D95B7E45040C6FB71FBE5E94F40D95BCAF962E250405E807D74EAE04F40D95BCAF962E25040
57226	Заполярный	3	25	7423	63.710712000000001	63.755806999999997	67.499379000000005	67.487027999999995	0103000020E61000000100000005000000F86F5E9CF8DA4F401F0F7D772BDF5040F86F5E9CF8DA4F40CA5356D3F5DF50403F8BA548BEE04F40CA5356D3F5DF50403F8BA548BEE04F401F0F7D772BDF5040F86F5E9CF8DA4F401F0F7D772BDF5040
57284	Елецкий	3	25	7423	64.201695000000001	64.230710999999999	67.049049999999994	67.037592000000004	0103000020E6100000010000000500000012312592E80C5040D7A546E867C2504012312592E80C50409A779CA223C35040F5F411F8C30E50409A779CA223C35040F5F411F8C30E5040D7A546E867C2504012312592E80C5040D7A546E867C25040
57210	Воргашор	3	25	7423	63.77478	63.821860000000001	67.592201000000003	67.573451000000006	0103000020E6100000010000000500000025CCB4FD2BE34F40F2B6D26BB3E4504025CCB4FD2BE34F4025EA059FE6E55040FEF15EB532E94F4025EA059FE6E55040FEF15EB532E94F40F2B6D26BB3E4504025CCB4FD2BE34F40F2B6D26BB3E45040
57535	ст. Шуйская	3	24	\N	34.250911000000002	34.250928999999999	61.940556999999998	61.940019999999997	0103000020E61000000100000005000000749A05DA1D204140FFCA4A9352F84E40749A05DA1D2041400E83F92B64F84E401A4F04711E2041400E83F92B64F84E401A4F04711E204140FFCA4A9352F84E40749A05DA1D204140FFCA4A9352F84E40
26698	Ужесельга	3	24	\N	34.474448000000002	34.494444999999999	61.726647	61.716800999999997	0103000020E6100000010000000500000089D349B6BA3C4140BB5E9A22C0DB4E4089D349B6BA3C4140465ED6C402DD4E40DA5548F9493F4140465ED6C402DD4E40DA5548F9493F4140BB5E9A22C0DB4E4089D349B6BA3C4140BB5E9A22C0DB4E40
57532	Суоярви	3	24	\N	32.330357999999997	32.388506	62.103154000000004	62.073005000000002	0103000020E6100000010000000500000069FCC22B492A4040E5B8533A58094F4069FCC22B492A4040CE397826340D4F405F268A90BA314040CE397826340D4F405F268A90BA314040E5B8533A58094F4069FCC22B492A4040E5B8533A58094F40
57530	Сортавала городской округ	3	24	\N	30.030526999999999	31.0915	62.248289	61.538068000000003	0103000020E610000001000000050000001EA5129ED0073E4017838769DFC44E401EA5129ED0073E40707A17EFC71F4F408195438B6C173F40707A17EFC71F4F408195438B6C173F4017838769DFC44E401EA5129ED0073E4017838769DFC44E40
3053	Сортавала	3	24	\N	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
57538	Сегежа	3	24	\N	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
57537	Пудож	3	24	\N	36.489288000000002	36.557920000000003	61.822561	61.791379999999997	0103000020E61000000100000005000000A2293BFDA03E4240AF5A99F04BE54E40A2293BFDA03E424087FBC8AD49E94E4065E42CEC6947424087FBC8AD49E94E4065E42CEC69474240AF5A99F04BE54E40A2293BFDA03E4240AF5A99F04BE54E40
57527	Питкяранта	3	24	\N	31.425861999999999	31.506368999999999	61.596598999999998	61.541420000000002	0103000020E61000000100000005000000F19BC24A056D3F403EB324404DC54E40F19BC24A056D3F40C4E9245B5DCC4E404EB51666A1813F40C4E9245B5DCC4E404EB51666A1813F403EB324404DC54E40F19BC24A056D3F403EB324404DC54E40
1518	Петрозаводск	3	24	\N	34.186169999999997	34.604767000000002	61.861319000000002	61.711604000000001	0103000020E6100000010000000500000087BF266BD4174140F5D901D715DB4E4087BF266BD4174140333674B33FEE4E409B594B01694D4140333674B33FEE4E409B594B01694D4140F5D901D715DB4E4087BF266BD4174140F5D901D715DB4E40
26478	Новая Вилга	3	24	\N	34.169668000000001	34.182397000000002	61.819459000000002	61.811743	0103000020E61000000100000005000000C09657AEB7154140E3E0D231E7E74E40C09657AEB7154140D9B45208E4E84E40BBF1EEC858174140D9B45208E4E84E40BBF1EEC858174140E3E0D231E7E74E40C09657AEB7154140E3E0D231E7E74E40
3356	Мелиоративный	3	24	\N	34.235793000000001	34.250138999999997	61.867907000000002	61.86036	0103000020E6100000010000000500000018D00B772E1E4140AE64C74620EE4E4018D00B772E1E4140187C9A9317EF4E40213A048E04204140187C9A9317EF4E40213A048E04204140AE64C74620EE4E4018D00B772E1E4140AE64C74620EE4E40
57528	Медвежьегорск	3	24	\N	34.397587999999999	34.514341999999999	62.943748999999997	62.891162999999999	0103000020E610000001000000050000001AA4E029E4324140DF3312A111724F401AA4E029E4324140FC5069C4CC784F40C87A6AF5D5414140FC5069C4CC784F40C87A6AF5D5414140DF3312A111724F401AA4E029E4324140DF3312A111724F40
57536	Лахденпохья	3	24	\N	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
3252	Костомукша	3	24	\N	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
57533	Кондопога	3	24	\N	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
57539	Кемь	3	24	\N	34.527943	34.661935	64.965517000000006	64.941023000000001	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
57531	Кааламо	3	24	\N	30.484302	30.507532999999999	61.905624000000003	61.897717999999998	0103000020E610000001000000050000002C634337FB7B3E40E883656CE8F24E402C634337FB7B3E40823CBB7CEBF34E4009A4C4AEED813E40823CBB7CEBF34E4009A4C4AEED813E40E883656CE8F24E402C634337FB7B3E40E883656CE8F24E40
57566	Валаам	3	24	\N	30.941490999999999	30.957957	61.393901999999997	61.384627000000002	0103000020E61000000100000005000000747ADE8D05F13E404D1421753BB14E40747ADE8D05F13E401CEA77616BB24E406AF981AB3CF53E401CEA77616BB24E406AF981AB3CF53E404D1421753BB14E40747ADE8D05F13E404D1421753BB14E40
57541	Беломорск	3	24	\N	34.722248	34.815745	64.552330999999995	64.505497000000005	0103000020E61000000100000005000000FBCC599F725C414079CE16105A205040FBCC599F725C414049641F6459235040117008556A68414049641F6459235040117008556A68414079CE16105A205040FBCC599F725C414079CE16105A205040
30949	Тойвола	3	24	1897	32.594642	32.616723	62.330620000000003	62.317002000000002	0103000020E61000000100000005000000FD69A33A1D4C40402062838593284F40FD69A33A1D4C4040A7B393C1512A4F4073D87DC7F04E4040A7B393C1512A4F4073D87DC7F04E40402062838593284F40FD69A33A1D4C40402062838593284F40
30637	Суоярви	3	24	1897	32.330357999999997	32.388506	62.103154000000004	62.073005000000002	0103000020E6100000010000000500000069FCC22B492A4040E5B8533A58094F4069FCC22B492A4040CE397826340D4F405F268A90BA314040CE397826340D4F405F268A90BA314040E5B8533A58094F4069FCC22B492A4040E5B8533A58094F40
30886	Суоеки	3	24	1897	32.601703000000001	32.618214000000002	62.203395	62.197701000000002	0103000020E61000000100000005000000DA73999A044D404079B130444E194F40DA73999A044D4040C095ECD8081A4F40F5F6E7A2214F4040C095ECD8081A4F40F5F6E7A2214F404079B130444E194F40DA73999A044D404079B130444E194F40
31546	Суйстамо	3	24	1897	31.141715999999999	31.165306000000001	61.916196999999997	61.909377999999997	0103000020E61000000100000005000000E751F17F47243F40D7D9907F66F44E40E751F17F47243F40BED87BF145F54E4024D5777E512A3F40BED87BF145F54E4024D5777E512A3F40D7D9907F66F44E40E751F17F47243F40D7D9907F66F44E40
31424	Райконкоски	3	24	1897	31.552992	31.575728000000002	61.931097999999999	61.920178	0103000020E610000001000000050000001BF33AE2908D3F40D53F8864C8F54E401BF33AE2908D3F407DAF21382EF74E40396403E962933F407DAF21382EF74E40396403E962933F40D53F8864C8F54E401BF33AE2908D3F40D53F8864C8F54E40
31138	Поросозеро	3	24	1897	32.636719999999997	32.762987000000003	62.728746999999998	62.684187999999999	0103000020E61000000100000005000000C45A7C0A805140406728EE7893574F40C45A7C0A805140407007EA94475D4F40F722DA8EA96140407007EA94475D4F40F722DA8EA96140406728EE7893574F40C45A7C0A805140406728EE7893574F40
31578	Пийтсиеки	3	24	1897	32.087499000000001	32.113909	62.040577999999996	62.019595000000002	0103000020E6100000010000000500000063B7CF2A330B40402315C61682024F4063B7CF2A330B4040F277EFA831054F402BDCF291940E4040F277EFA831054F402BDCF291940E40402315C61682024F4063B7CF2A330B40402315C61682024F40
30980	Найстенъярви	3	24	1897	32.668664	32.695954	62.310518999999999	62.295102	0103000020E610000001000000050000009B012EC896554040FA7DFFE6C5254F409B012EC896554040B0E42A16BF274F409CC24A0515594040B0E42A16BF274F409CC24A0515594040FA7DFFE6C5254F409B012EC896554040FA7DFFE6C5254F40
31047	Найстенъярви	3	24	1897	32.625005999999999	32.648792999999998	62.438940000000002	62.421318999999997	0103000020E61000000100000005000000E2E65432005040407A17EFC7ED354F40E2E65432005040400074982F2F384F40D66F26A60B5340400074982F2F384F40D66F26A60B5340407A17EFC7ED354F40E2E65432005040407A17EFC7ED354F40
31405	Лоймола	3	24	1897	31.713090000000001	31.763601999999999	61.989834999999999	61.966647999999999	0103000020E61000000100000005000000CA1AF5108DB63F40355F251FBBFB4E40CA1AF5108DB63F40D4B7CCE9B2FE4E400229B16B7BC33F40D4B7CCE9B2FE4E400229B16B7BC33F40355F251FBBFB4E40CA1AF5108DB63F40355F251FBBFB4E40
31496	Леппясюрья	3	24	1897	31.339561	31.376213	61.86347	61.851956999999999	0103000020E610000001000000050000003FFF3D78ED563F40944C4EED0CED4E403FFF3D78ED563F40DF89592F86EE4E407E54C37E4F603F40DF89592F86EE4E407E54C37E4F603F40944C4EED0CED4E403FFF3D78ED563F40944C4EED0CED4E40
30846	Леппяниэми	3	24	1897	32.442261000000002	32.459795999999997	62.211678999999997	62.199241000000001	0103000020E61000000100000005000000ECA529029C384040DC82A5BA80194F40ECA529029C384040FF1F274C181B4F40726A6798DA3A4040FF1F274C181B4F40726A6798DA3A4040DC82A5BA80194F40ECA529029C384040DC82A5BA80194F40
31230	Гумарино	3	24	1897	33.100825	33.124504999999999	62.970627999999998	62.959670000000003	0103000020E6100000010000000500000042CF66D5E78C4040E6797077D67A4F4042CF66D5E78C40407B4ACE893D7C4F402098A3C7EF8F40407B4ACE893D7C4F402098A3C7EF8F4040E6797077D67A4F4042CF66D5E78C4040E6797077D67A4F40
31271	Вегарус	3	24	1897	32.088945000000002	32.110683999999999	62.302546	62.290263000000003	0103000020E610000001000000050000004512BD8C620B4040931E865627254F404512BD8C620B40408FC4CBD3B9264F406118B0E42A0E40408FC4CBD3B9264F406118B0E42A0E4040931E865627254F404512BD8C620B4040931E865627254F40
57554	Хюмпеля	3	24	7433	30.647113000000001	30.661826999999999	61.682195999999998	61.675179	0103000020E6100000010000000500000003D19332A9A53E4016F9F5436CD64E4003D19332A9A53E4023BBD23252D74E401B9C887E6DA93E4023BBD23252D74E401B9C887E6DA93E4016F9F5436CD64E4003D19332A9A53E4016F9F5436CD64E40
57553	Хелюля	3	24	7433	30.646744999999999	30.701218000000001	61.757570000000001	61.732858999999998	0103000020E61000000100000005000000FDD98F1491A53E4025CADE52CEDD4E40FDD98F1491A53E402237C30DF8E04E40D55DD90583B33E402237C30DF8E04E40D55DD90583B33E4025CADE52CEDD4E40FDD98F1491A53E4025CADE52CEDD4E40
57556	Туокслахти	3	24	7433	30.560057	30.573972000000001	61.696550000000002	61.690556000000001	0103000020E6100000010000000500000058E542E55F8F3E403E07962364D84E4058E542E55F8F3E40B003E78C28D94E40D9D138D4EF923E40B003E78C28D94E40D9D138D4EF923E403E07962364D84E4058E542E55F8F3E403E07962364D84E40
57565	Партала	3	24	7433	30.583925000000001	30.598441999999999	62.057760999999999	62.052920999999998	0103000020E610000001000000050000001A51DA1B7C953E40C422861DC6064F401A51DA1B7C953E40FCFD62B664074F40868DB27E33993E40FCFD62B664074F40868DB27E33993E40C422861DC6064F401A51DA1B7C953E40C422861DC6064F40
30051	Черный Порог	3	24	400	33.650855	33.676582000000003	63.999419000000003	63.990403000000001	0103000020E6100000010000000500000013B875374FD340401E6E8786C5FE4F4013B875374FD34040220038F6ECFF4F40F9872D3D9AD64040220038F6ECFF4F40F9872D3D9AD640401E6E8786C5FE4F4013B875374FD340401E6E8786C5FE4F40
29216	Сегежа	3	24	400	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
29886	Пристань Надвоицы	3	24	400	34.311368000000002	34.334660999999997	63.867846	63.856203999999998	0103000020E61000000100000005000000AE8218E8DA274140295AB91798ED4F40AE8218E8DA27414072FBE59315EF4F40921FF12BD62A414072FBE59315EF4F40921FF12BD62A4140295AB91798ED4F40AE8218E8DA274140295AB91798ED4F40
30373	Попов Порог	3	24	400	34.005994999999999	34.022047000000001	63.412334000000001	63.404989	0103000020E610000001000000050000004278B471C4004140B01EF7ADD6B34F404278B471C4004140B2834A5CC7B44F40CAFCA36FD2024140B2834A5CC7B44F40CAFCA36FD2024140B01EF7ADD6B34F404278B471C4004140B01EF7ADD6B34F40
2102	Полга	3	24	400	34.872878	34.925052000000001	63.700899	63.686388999999998	0103000020E61000000100000005000000EEB25F77BA6F4140C5AA4198DBD74F40EEB25F77BA6F41404966F50EB7D94F40B98C9B1A687641404966F50EB7D94F40B98C9B1A68764140C5AA4198DBD74F40EEB25F77BA6F4140C5AA4198DBD74F40
57571	Олений	3	24	400	32.947797000000001	36.256974999999997	64.231694000000005	63.142496000000001	0103000020E610000001000000050000009B1F7F6951794040C9E7154F3D924F409B1F7F69517940407C2B1213D40E5040DE718A8EE42042407C2B1213D40E5040DE718A8EE4204240C9E7154F3D924F409B1F7F6951794040C9E7154F3D924F40
48411	Надвоицы	3	24	400	34.237121999999999	34.276414000000003	63.910411000000003	63.885094000000002	0103000020E61000000100000005000000C09481035A1E414063F19BC24AF14F40C09481035A1E41409775FF5888F44F400A14B188612341409775FF5888F44F400A14B1886123414063F19BC24AF14F40C09481035A1E414063F19BC24AF14F40
29744	Надвоицы	3	24	400	34.319910999999998	34.329836999999998	63.878624000000002	63.870913000000002	0103000020E61000000100000005000000B950F9D7F2284140A454C2137AEF4F40B950F9D7F228414088BD50C076F04F4060014C19382A414088BD50C076F04F4060014C19382A4140A454C2137AEF4F40B950F9D7F2284140A454C2137AEF4F40
30335	Кочкома	3	24	400	34.205699000000003	34.255699	64.042767999999995	64.028858999999997	0103000020E61000000100000005000000F3E84658541A41407F4C6BD3D8015040F3E84658541A41402E54FEB5BC025040594FADBEBA2041402E54FEB5BC025040594FADBEBA2041407F4C6BD3D8015040F3E84658541A41407F4C6BD3D8015040
29946	Каменный Бор	3	24	400	34.168536000000003	34.196275999999997	63.933664999999998	63.920985999999999	0103000020E610000001000000050000006E19709692154140740987DEE2F54F406E19709692154140BD35B05582F74F40AE7E6C921F194140BD35B05582F74F40AE7E6C921F194140740987DEE2F54F406E19709692154140740987DEE2F54F40
30240	Идель	3	24	400	34.221905	34.277662999999997	64.143073999999999	64.121424000000005	0103000020E61000000100000005000000D1E80E62671C4140C53C2B69C5075040D1E80E62671C41401BBAD91F28095040952710768A2341401BBAD91F28095040952710768A234140C53C2B69C5075040D1E80E62671C4140C53C2B69C5075040
30435	Волдозеро	3	24	400	33.987876	34.004387000000001	63.725358	63.715302000000001	0103000020E610000001000000050000006C4084B872FE4040B76114048FDB4F406C4084B872FE40402CF2EB87D8DC4F4087C3D2C08F0041402CF2EB87D8DC4F4087C3D2C08F004140B76114048FDB4F406C4084B872FE4040B76114048FDB4F40
30578	Вожмогора	3	24	400	35.407178000000002	35.423572	63.462826999999997	63.454377999999998	0103000020E610000001000000050000004AD3A0681EB44140CD02ED0E29BA4F404AD3A0681EB44140575A46EA3DBB4F402BC0779B37B64140575A46EA3DBB4F402BC0779B37B64140CD02ED0E29BA4F404AD3A0681EB44140CD02ED0E29BA4F40
48474	Верхний	3	24	400	34.186008000000001	34.192503000000002	63.908974999999998	63.905568000000002	0103000020E61000000100000005000000AE65321CCF174140EE26F8A6E9F34F40AE65321CCF174140D8F0F44A59F44F40E2B034F0A3184140D8F0F44A59F44F40E2B034F0A3184140EE26F8A6E9F34F40AE65321CCF174140EE26F8A6E9F34F40
48510	Вача	3	24	400	33.454411	33.478772999999997	63.981724	63.969842	0103000020E61000000100000005000000A9F8BF232ABA4040C4245CC823FC4F40A9F8BF232ABA404062D9CC21A9FD4F40999A046F48BD404062D9CC21A9FD4F40999A046F48BD4040C4245CC823FC4F40A9F8BF232ABA4040C4245CC823FC4F40
30528	Валдай	3	24	400	35.498086999999998	35.524588000000001	63.441353999999997	63.421740999999997	0103000020E6100000010000000500000008C89750C1BF4140F030ED9BFBB54F4008C89750C1BF4140B9FAB1497EB84F40E1EF17B325C34140B9FAB1497EB84F40E1EF17B325C34140F030ED9BFBB54F4008C89750C1BF4140F030ED9BFBB54F40
28532	Шальский	3	24	1828	35.963918	36.042501999999999	61.806634000000003	61.792136999999997	0103000020E610000001000000050000004B033FAA61FB4140CC79C6BE64E54E404B033FAA61FB4140BCEB6CC83FE74E40DE019EB470054240BCEB6CC83FE74E40DE019EB470054240CC79C6BE64E54E404B033FAA61FB4140CC79C6BE64E54E40
28924	Тамбичозеро	3	24	1828	36.101522000000003	36.112526000000003	62.670347	62.662652000000001	0103000020E610000001000000050000008AE942ACFE0C42408350DEC7D1544F408AE942ACFE0C424061FC34EECD554F4090F98040670E424061FC34EECD554F4090F98040670E42408350DEC7D1544F408AE942ACFE0C42408350DEC7D1544F40
28851	Тамбицы	3	24	1828	36.143877000000003	36.169147000000002	62.496487999999999	62.487774999999999	0103000020E61000000100000005000000C4D2C08F6A124240386744696F3E4F40C4D2C08F6A124240A06D35EB8C3F4F40B79BE09BA6154240A06D35EB8C3F4F40B79BE09BA6154240386744696F3E4F40C4D2C08F6A124240386744696F3E4F40
47895	Семеново	3	24	1828	36.117322999999999	36.140796000000002	61.827475999999997	61.822293000000002	0103000020E61000000100000005000000C808A870040F4240685DA3E540E94E40C808A870040F4240C91CCBBBEAE94E402DB4739A05124240C91CCBBBEAE94E402DB4739A05124240685DA3E540E94E40C808A870040F4240685DA3E540E94E40
28160	Рагнукса	3	24	1828	36.423189999999998	36.434517999999997	62.010112999999997	62.001688999999999	0103000020E6100000010000000500000043FF04172B364240A8E15B5837004F4043FF04172B364240D921FE614B014F40FCC22B499E374240D921FE614B014F40FCC22B499E374240A8E15B5837004F4043FF04172B364240A8E15B5837004F40
47966	Пяльма	3	24	1828	35.838889999999999	35.928713000000002	62.463422000000001	62.429053000000003	0103000020E6100000010000000500000081785DBF60EB414017A06D35EB364F4081785DBF60EB41409B1F7F69513B4F405E2F4D11E0F641409B1F7F69513B4F405E2F4D11E0F6414017A06D35EB364F4081785DBF60EB414017A06D35EB364F40
28836	Пудожгорский	3	24	1828	35.915695999999997	35.943435999999998	62.324114999999999	62.313231999999999	0103000020E61000000100000005000000FC89CA8635F54140C40776FC17284F40FC89CA8635F541404F92AE997C294F403DEFC682C2F841404F92AE997C294F403DEFC682C2F84140C40776FC17284F40FC89CA8635F54140C40776FC17284F40
27864	Пудож	3	24	1828	36.489288000000002	36.557920000000003	61.822561	61.791379999999997	0103000020E61000000100000005000000A2293BFDA03E4240AF5A99F04BE54E40A2293BFDA03E424087FBC8AD49E94E4065E42CEC6947424087FBC8AD49E94E4065E42CEC69474240AF5A99F04BE54E40A2293BFDA03E4240AF5A99F04BE54E40
48145	Приречный	3	24	1828	37.592914	37.620995000000001	61.801827000000003	61.795121999999999	0103000020E6100000010000000500000097AB1F9BE4CB4240412AC58EC6E54E4097AB1F9BE4CB424060066344A2E64E4061FD9FC37CCF424060066344A2E64E4061FD9FC37CCF4240412AC58EC6E54E4097AB1F9BE4CB4240412AC58EC6E54E40
32531	Подпорожье	3	24	1828	36.357540999999998	36.382119000000003	61.830576000000001	61.817335	0103000020E6100000010000000500000054FD4AE7C32D42402670EB6E9EE84E4054FD4AE7C32D4240D76B7A5050EA4E4012178046E9304240D76B7A5050EA4E4012178046E93042402670EB6E9EE84E4054FD4AE7C32D42402670EB6E9EE84E40
48121	Погост	3	24	1828	37.727221	37.744270999999998	61.786862999999997	61.780942000000003	0103000020E6100000010000000500000072FBE59315DD424053094FE8F5E34E4072FBE59315DD42405AB741EDB7E44E403C2EAA4544DF42405AB741EDB7E44E403C2EAA4544DF424053094FE8F5E34E4072FBE59315DD424053094FE8F5E34E40
47942	Песчаное	3	24	1828	35.789752	35.801772	62.170279999999998	62.151971000000003	0103000020E61000000100000005000000ADF9F19716E54140607825C973134F40ADF9F19716E54140D9942BBCCB154F409C6C0377A0E64140D9942BBCCB154F409C6C0377A0E64140607825C973134F40ADF9F19716E54140607825C973134F40
28667	Онежский	3	24	1828	35.881075000000003	35.903424999999999	61.991132999999998	61.981152000000002	0103000020E610000001000000050000005F29CB10C7F04140D733846396FD4E405F29CB10C7F04140417E3672DDFE4E40C4B12E6EA3F34140417E3672DDFE4E40C4B12E6EA3F34140D733846396FD4E405F29CB10C7F04140D733846396FD4E40
28216	Куганаволок	3	24	1828	36.858747000000001	36.895398999999998	62.245024999999998	62.202655999999998	0103000020E61000000100000005000000E144F46BEB6D4240492BBEA1F0194F40E144F46BEB6D4240E8D9ACFA5C1F4F4080EF366F9C724240E8D9ACFA5C1F4F4080EF366F9C724240492BBEA1F0194F40E144F46BEB6D4240492BBEA1F0194F40
29054	Кубовская	3	24	1828	37.225448999999998	37.244466000000003	61.958177999999997	61.952720999999997	0103000020E610000001000000050000003CF54883DB9C4240309B00C3F2F94E403CF54883DB9C424093DFA293A5FA4E40F27D71A94A9F424093DFA293A5FA4E40F27D71A94A9F4240309B00C3F2F94E403CF54883DB9C4240309B00C3F2F94E40
32615	Кубово	3	24	1828	37.159117000000002	37.194232	61.954476999999997	61.945169999999997	0103000020E610000001000000050000006B9E23F25D94424085949F54FBF84E406B9E23F25D94424060E4654D2CFA4E4018EB1B98DC98424060E4654D2CFA4E4018EB1B98DC98424085949F54FBF84E406B9E23F25D94424085949F54FBF84E40
48029	Кривцы	3	24	1828	36.942622999999998	36.976768	61.815328999999998	61.795594000000001	0103000020E610000001000000050000008CBAD6DEA778424069723106D6E54E408CBAD6DEA77842407D3D5FB35CE84E40C1E3DBBB067D42407D3D5FB35CE84E40C1E3DBBB067D424069723106D6E54E408CBAD6DEA778424069723106D6E54E40
47821	Красноборский	3	24	1828	36.339188999999998	36.356158000000001	61.657485000000001	61.653708999999999	0103000020E61000000100000005000000DB148F8B6A2B4240E90C8CBCACD34E40DB148F8B6A2B4240274EEE7728D44E40B91AD995962D4240274EEE7728D44E40B91AD995962D4240E90C8CBCACD34E40DB148F8B6A2B4240E90C8CBCACD34E40
33132	Колово	3	24	1828	36.656671000000003	36.804175000000001	61.815448000000004	61.795641000000003	0103000020E61000000100000005000000A69D9ACB0D544240AA2D7590D7E54E40A69D9ACB0D54424058CB9D9960E84E4062A1D634EF66424058CB9D9960E84E4062A1D634EF664240AA2D7590D7E54E40A69D9ACB0D544240AA2D7590D7E54E40
28382	Каршево	3	24	1828	36.284922000000002	36.316336	61.690679000000003	61.668711999999999	0103000020E6100000010000000500000099F4F75278244240AC38D55A98D54E4099F4F752782442405A84622B68D84E401346B3B27D2842405A84622B68D84E401346B3B27D284240AC38D55A98D54E4099F4F75278244240AC38D55A98D54E40
46963	Заозерье	3	24	1828	37.739995	37.761923000000003	61.780439999999999	61.774267000000002	0103000020E610000001000000050000000D1AFA27B8DE42409FAF592E1BE34E400D1AFA27B8DE4240C03E3A75E5E34E40FD885FB186E14240C03E3A75E5E34E40FD885FB186E142409FAF592E1BE34E400D1AFA27B8DE42409FAF592E1BE34E40
29081	Водла	3	24	1828	37.437432999999999	37.464302000000004	62.088476999999997	62.052984000000002	0103000020E610000001000000050000007898F6CDFDB742400B9B012EC8064F407898F6CDFDB742405EB9DE36530B4F40D4BB783F6EBB42405EB9DE36530B4F40D4BB783F6EBB42400B9B012EC8064F407898F6CDFDB742400B9B012EC8064F40
28358	Бочилово	3	24	1828	36.204217	36.257899999999999	61.853723000000002	61.837006000000002	0103000020E61000000100000005000000C4245CC8231A424024473A0323EB4E40C4245CC8231A4240E86B96CB46ED4E40B7D100DE02214240E86B96CB46ED4E40B7D100DE0221424024473A0323EB4E40C4245CC8231A424024473A0323EB4E40
46554	Авдеево	3	24	1828	36.038837000000001	36.065212000000002	62.021329000000001	62.009394999999998	0103000020E61000000100000005000000F86F5E9CF80442407ADFF8DA33014F40F86F5E9CF80442406BBA9EE8BA024F4044A7E7DD580842406BBA9EE8BA024F4044A7E7DD580842407ADFF8DA33014F40F86F5E9CF80442407ADFF8DA33014F40
27355	Эссойла	3	24	550	33.136111	33.223050000000001	61.856188000000003	61.842180999999997	0103000020E610000001000000050000001CD0D2156C91404002284696CCEB4E401CD0D2156C914040249D819197ED4E40B8AF03E78C9C4040249D819197ED4E40B8AF03E78C9C404002284696CCEB4E401CD0D2156C91404002284696CCEB4E40
27001	Чална	3	24	550	34.040498999999997	34.094928000000003	61.89228	61.874786999999998	0103000020E61000000100000005000000A6423C122F054140A4FB3905F9EF4E40A6423C122F054140FC6F253B36F24E40C3BCC799260C4140FC6F253B36F24E40C3BCC799260C4140A4FB3905F9EF4E40A6423C122F054140A4FB3905F9EF4E40
27496	Сяпся	3	24	550	33.363366999999997	33.380856999999999	61.927016999999999	61.917662999999997	0103000020E610000001000000050000000AB952CF82AE4040E7DF2EFB75F54E400AB952CF82AE404003EB387EA8F64E40F1B913ECBFB0404003EB387EA8F64E40F1B913ECBFB04040E7DF2EFB75F54E400AB952CF82AE4040E7DF2EFB75F54E40
27408	Соддер	3	24	550	32.841571000000002	32.852558000000002	61.813828999999998	61.803778000000001	0103000020E610000001000000050000008A213999B86B4040459F8F32E2E64E408A213999B86B4040A8C4758C2BE84E40BAF8DB9E206D4040A8C4758C2BE84E40BAF8DB9E206D4040459F8F32E2E64E408A213999B86B4040459F8F32E2E64E40
27199	Святозеро	3	24	550	33.599085000000002	33.633104000000003	61.566974999999999	61.550521000000003	0103000020E61000000100000005000000184339D1AECC40407061DD7877C64E40184339D1AECC4040265305A392C84E40C07B478D09D14040265305A392C84E40C07B478D09D140407061DD7877C64E40184339D1AECC40407061DD7877C64E40
47514	Савиново	3	24	550	32.962727000000001	32.985005000000001	61.676617999999998	61.670513	0103000020E61000000100000005000000F4FC69A33A7B40407C45B75ED3D54E40F4FC69A33A7B404045F12A6B9BD64E40C0B2D2A4147E404045F12A6B9BD64E40C0B2D2A4147E40407C45B75ED3D54E40F4FC69A33A7B40407C45B75ED3D54E40
26908	Пряжа	3	24	550	33.605426999999999	33.641053999999997	61.717154999999998	61.675640000000001	0103000020E61000000100000005000000C58EC6A17ECD40404AEF1B5F7BD64E40C58EC6A17ECD4040D9942BBCCBDB4E40287CB60E0ED24040D9942BBCCBDB4E40287CB60E0ED240404AEF1B5F7BD64E40C58EC6A17ECD40404AEF1B5F7BD64E40
47433	Новые Пески	3	24	550	32.919473000000004	32.948866000000002	61.835242999999998	61.828257000000001	0103000020E610000001000000050000000B47904AB17540406FD74B5304EA4E400B47904AB1754040419B1C3EE9EA4E40A724EB7074794040419B1C3EE9EA4E40A724EB70747940406FD74B5304EA4E400B47904AB17540406FD74B5304EA4E40
27186	Матросы	3	24	550	33.788342	33.832422000000001	61.786723000000002	61.774450000000002	0103000020E6100000010000000500000018080264E8E440409031772D21E34E4018080264E8E440406901DA56B3E44E40473CD9CD8CEA40406901DA56B3E44E40473CD9CD8CEA40409031772D21E34E4018080264E8E440409031772D21E34E40
27122	Кутижма	3	24	550	33.545859999999998	33.584738999999999	61.877526000000003	61.868093999999999	0103000020E61000000100000005000000E71890BDDEC540404AED45B41DEF4E40E71890BDDEC54040E2B19FC552F04E400ED940BAD8CA4040E2B19FC552F04E400ED940BAD8CA40404AED45B41DEF4E40E71890BDDEC540404AED45B41DEF4E40
3398	Кудама	3	24	550	33.135356000000002	33.149469000000003	62.027473999999998	62.015090999999998	0103000020E61000000100000005000000A0A86C585391404062BB7B80EE014F40A0A86C5853914040C2BE9D4484034F400762D9CC21934040C2BE9D4484034F400762D9CC2193404062BB7B80EE014F40A0A86C585391404062BB7B80EE014F40
27291	Крошнозеро	3	24	550	33.158883000000003	33.186425999999997	61.651282000000002	61.625712	0103000020E61000000100000005000000F8713447569440407D5BB05417D04E40F8713447569440409B3C65355DD34E40E28FA2CEDC9740409B3C65355DD34E40E28FA2CEDC9740407D5BB05417D04E40F8713447569440407D5BB05417D04E40
27808	Колатсельга	3	24	550	32.224159	32.246814999999998	61.685673999999999	61.668357	0103000020E61000000100000005000000520DFB3DB11C4040BE86E0B88CD54E40520DFB3DB11C4040D7DB662AC4D74E40C49448A2971F4040D7DB662AC4D74E40C49448A2971F4040BE86E0B88CD54E40520DFB3DB11C4040BE86E0B88CD54E40
27780	Койвусельга	3	24	550	32.432541000000001	32.4709	61.528007000000002	61.515618000000003	0103000020E61000000100000005000000EE96E4805D3740404E9D47C5FFC14E40EE96E4805D3740409087BEBB95C34E40DCD78173463C40409087BEBB95C34E40DCD78173463C40404E9D47C5FFC14E40EE96E4805D3740404E9D47C5FFC14E40
27739	Кинелахта	3	24	550	32.582110999999998	32.634438000000003	61.394803000000003	61.384419999999999	0103000020E6100000010000000500000028D2FD9C824A4040D3F6AFAC34B14E4028D2FD9C824A40406DAE9AE788B24E407AABAE43355140406DAE9AE788B24E407AABAE4335514040D3F6AFAC34B14E4028D2FD9C824A4040D3F6AFAC34B14E40
27071	Виллагора	3	24	550	33.680176000000003	33.724893999999999	61.893030000000003	61.884149000000001	0103000020E6100000010000000500000016C3D50110D7404043E55FCB2BF14E4016C3D50110D74040672C9ACE4EF24E4087889B53C9DC4040672C9ACE4EF24E4087889B53C9DC404043E55FCB2BF14E4016C3D50110D7404043E55FCB2BF14E40
27056	Виданы	3	24	550	33.988190000000003	34.014932999999999	61.876092999999997	61.863095999999999	0103000020E61000000100000005000000FC1D8A027DFE40407AA702EE79EE4E40FC1D8A027DFE404094A0BFD023F04E40CA501553E901414094A0BFD023F04E40CA501553E90141407AA702EE79EE4E40FC1D8A027DFE40407AA702EE79EE4E40
31332	Вешкелица	3	24	550	32.802162000000003	32.838723999999999	61.923439000000002	61.913237000000002	0103000020E61000000100000005000000070C923EAD664040A33F34F3E4F44E40070C923EAD664040EC6CC83F33F64E40662FDB4E5B6B4040EC6CC83F33F64E40662FDB4E5B6B4040A33F34F3E4F44E40070C923EAD664040A33F34F3E4F44E40
27261	Верхние Важины	3	24	550	33.671686999999999	33.68703	61.386336999999997	61.378055000000003	0103000020E61000000100000005000000FD12F1D6F9D540406E8B321B64B04E40FD12F1D6F9D540400C1EA67D73B14E4079AF5A99F0D740400C1EA67D73B14E4079AF5A99F0D740406E8B321B64B04E40FD12F1D6F9D540406E8B321B64B04E40
57552	Велдозеро	3	24	550	32.805503999999999	32.861567999999998	61.579402999999999	61.562385999999996	0103000020E610000001000000050000000A664CC11A67404037DDB243FCC74E400A664CC11A674040261AA4E029CA4E40DBA337DC476E4040261AA4E029CA4E40DBA337DC476E404037DDB243FCC74E400A664CC11A67404037DDB243FCC74E40
57564	д. Верхручей	3	24	536	35.235258000000002	35.273805000000003	61.422086999999998	61.406818000000001	0103000020E61000000100000005000000AA0F24EF1C9E41404AB6BA9C12B44E40AA0F24EF1C9E41408B8862F206B64E409B3DD00A0CA341408B8862F206B64E409B3DD00A0CA341404AB6BA9C12B44E40AA0F24EF1C9E41404AB6BA9C12B44E40
26420	Ялгуба	3	24	536	34.539710999999997	34.582417	61.889778999999997	61.873196	0103000020E610000001000000050000004E25034015454140BF7FF3E2C4EF4E404E2503401545414073D53C47E4F14E4035D1E7A38C4A414073D53C47E4F14E4035D1E7A38C4A4140BF7FF3E2C4EF4E404E25034015454140BF7FF3E2C4EF4E40
49590	Шуя	3	24	536	34.146895000000001	34.276575999999999	61.959760000000003	61.855077000000001	0103000020E6100000010000000500000014799274CD124140E947C32973ED4E4014799274CD12414026016A6AD9FA4E40E36DA5D76623414026016A6AD9FA4E40E36DA5D766234140E947C32973ED4E4014799274CD124140E947C32973ED4E40
26824	Шелтозеро	3	24	536	35.332438000000003	35.373365	61.383251999999999	61.360931000000001	0103000020E610000001000000050000004DF910548DAA4140698EACFC32AE4E404DF910548DAA41403410CB660EB14E404B3CA06CCAAF41403410CB660EB14E404B3CA06CCAAF4140698EACFC32AE4E404DF910548DAA4140698EACFC32AE4E40
26838	Рыбрека	3	24	536	35.505462000000001	35.558076999999997	61.299706999999998	61.255440999999998	0103000020E6100000010000000500000075AF93FAB2C041405D876A4AB2A04E4075AF93FAB2C04140EEB089CC5CA64E402CD32F116FC74140EEB089CC5CA64E402CD32F116FC741405D876A4AB2A04E4075AF93FAB2C041405D876A4AB2A04E40
9317	Пухта	3	24	536	34.646394999999998	34.665537999999998	61.506790000000002	61.490608999999999	0103000020E6100000010000000500000022A64412BD524140C70F9546CCBE4E4022A64412BD5241404DF8A57EDEC04E40641F6459305541404DF8A57EDEC04E40641F645930554140C70F9546CCBE4E4022A64412BD524140C70F9546CCBE4E40
26632	Педасельга	3	24	536	34.676704000000001	34.697015	61.545270000000002	61.535941000000001	0103000020E610000001000000050000004489963C9E564140F3CAF5B699C44E404489963C9E564140B6BE4868CBC54E4025E99AC937594140B6BE4868CBC54E4025E99AC937594140F3CAF5B699C44E404489963C9E564140F3CAF5B699C44E40
26200	Пай	3	24	536	34.414755	34.461601999999999	61.213842	61.198808	0103000020E610000001000000050000001E6D1CB1163541407217618A72994E401E6D1CB1163541407041B62C5F9B4E4054E23AC6153B41407041B62C5F9B4E4054E23AC6153B41407217618A72994E401E6D1CB1163541407217618A72994E40
3262	Ладва-Ветка	3	24	536	34.421322000000004	34.475472000000003	61.367325999999998	61.342461	0103000020E61000000100000005000000EC8A19E1ED354140E69315C3D5AB4E40EC8A19E1ED354140397CD28904AF4E40F5143944DC3C4140397CD28904AF4E40F5143944DC3C4140E69315C3D5AB4E40EC8A19E1ED354140E69315C3D5AB4E40
26128	Ладва	3	24	536	34.590843	34.694302	61.371071999999998	61.346184999999998	0103000020E61000000100000005000000070951BEA04B4140D1AE42CA4FAC4E40070951BEA04B41400C3B8C497FAF4E4011C64FE3DE5841400C3B8C497FAF4E4011C64FE3DE584140D1AE42CA4FAC4E40070951BEA04B4140D1AE42CA4FAC4E40
47097	Кварцитный	3	24	536	35.041006000000003	35.054158000000001	61.502532000000002	61.493198999999997	0103000020E610000001000000050000004B7842AF3F854140BFB5132521BF4E404B7842AF3F854140C498F4F752C04E408C683BA6EE864140C498F4F752C04E408C683BA6EE864140BFB5132521BF4E404B7842AF3F854140BFB5132521BF4E40
26580	Деревянное	3	24	536	34.621071000000001	34.659644999999998	61.629461999999997	61.609037999999998	0103000020E610000001000000050000003CBF28417F4F4140B8020AF5F4CD4E403CBF28417F4F41409109F83592D04E4026FC523F6F5441409109F83592D04E4026FC523F6F544140B8020AF5F4CD4E403CBF28417F4F4140B8020AF5F4CD4E40
26271	Деревянка	3	24	536	34.430430999999999	34.495190000000001	61.579676999999997	61.553311000000001	0103000020E61000000100000005000000A017EE5C183741402FC214E5D2C64E40A017EE5C18374140279F1EDB32CA4E4033A7CB62623F4140279F1EDB32CA4E4033A7CB62623F41402FC214E5D2C64E40A017EE5C183741402FC214E5D2C64E40
26558	Вилга	3	24	536	34.058196000000002	34.103560999999999	61.833354	61.814331000000003	0103000020E6100000010000000500000007616EF7720741403B8F8AFF3BE84E4007616EF772074140D2FE0758ABEA4E400E12A27C410D4140D2FE0758ABEA4E400E12A27C410D41403B8F8AFF3BE84E4007616EF7720741403B8F8AFF3BE84E40
57558	д. Мансила	3	24	326	30.722697	32.320791	61.911898000000001	61.213087999999999	0103000020E61000000100000005000000D5EAABAB02B93E40C495B377469B4E40D5EAABAB02B93E40D7A4DB12B9F44E40F2ECF2AD0F294040D7A4DB12B9F44E40F2ECF2AD0F294040C495B377469B4E40D5EAABAB02B93E40C495B377469B4E40
18029	Янисъярви	3	24	326	30.940826000000001	30.951857	61.892601999999997	61.887549	0103000020E61000000100000005000000FC3905F9D9F03E407B4CA4349BF14E40FC3905F9D9F03E400E2C47C840F24E40FB777DE6ACF33E400E2C47C840F24E40FB777DE6ACF33E407B4CA4349BF14E40FC3905F9D9F03E407B4CA4349BF14E40
57570	Янис	3	24	326	30.722697	32.320791	61.911898000000001	61.213087999999999	0103000020E61000000100000005000000D5EAABAB02B93E40C495B377469B4E40D5EAABAB02B93E40D7A4DB12B9F44E40F2ECF2AD0F294040D7A4DB12B9F44E40F2ECF2AD0F294040C495B377469B4E40D5EAABAB02B93E40C495B377469B4E40
57549	Хийденсельга	3	24	326	30.722697	32.320791	61.911898000000001	61.213087999999999	0103000020E61000000100000005000000D5EAABAB02B93E40C495B377469B4E40D5EAABAB02B93E40D7A4DB12B9F44E40F2ECF2AD0F294040D7A4DB12B9F44E40F2ECF2AD0F294040C495B377469B4E40D5EAABAB02B93E40C495B377469B4E40
57555	Харлу	3	24	326	30.91826	30.961811000000001	61.820084000000001	61.800879000000002	0103000020E6100000010000000500000097395D1613EB3E40CF86FC3383E64E4097395D1613EB3E4087FC3383F8E84E40DDEEE53E39F63E4087FC3383F8E84E40DDEEE53E39F63E40CF86FC3383E64E4097395D1613EB3E40CF86FC3383E64E40
17675	Ууксу	3	24	326	31.599443999999998	31.608174999999999	61.499184	61.492722000000001	0103000020E610000001000000050000008EC8772975993F408602B68311BF4E408EC8772975993F40DE57E542E5BF4E40AB3E575BB19B3F40DE57E542E5BF4E40AB3E575BB19B3F408602B68311BF4E408EC8772975993F408602B68311BF4E40
1507	Салми	3	24	326	31.752884999999999	31.768588000000001	61.352522	61.346184999999998	0103000020E6100000010000000500000022A64412BDC03F40D1AE42CA4FAC4E4022A64412BDC03F406D8FDE701FAD4E401A19E42EC2C43F406D8FDE701FAD4E401A19E42EC2C43F40D1AE42CA4FAC4E4022A64412BDC03F40D1AE42CA4FAC4E40
18081	Рауталахти	3	24	326	30.881285999999999	30.906672	61.761907999999998	61.753290999999997	0103000020E61000000100000005000000336C94F59BE13E4081AFE8D66BE04E40336C94F59BE13E40C7478B3386E14E40EC32FCA71BE83E40C7478B3386E14E40EC32FCA71BE83E4081AFE8D66BE04E40336C94F59BE13E4081AFE8D66BE04E40
17448	Питкяранта	3	24	326	31.425861999999999	31.506368999999999	61.596598999999998	61.541420000000002	0103000020E61000000100000005000000F19BC24A056D3F403EB324404DC54E40F19BC24A056D3F40C4E9245B5DCC4E404EB51666A1813F40C4E9245B5DCC4E404EB51666A1813F403EB324404DC54E40F19BC24A056D3F403EB324404DC54E40
2906	Мийнала	3	24	326	31.864348	31.903721000000001	61.354129999999998	61.333652999999998	0103000020E61000000100000005000000EE5C18E945DD3F402C9B3924B5AA4E40EE5C18E945DD3F402844C02154AD4E405BB56B425AE73F402844C02154AD4E405BB56B425AE73F402C9B3924B5AA4E40EE5C18E945DD3F402C9B3924B5AA4E40
17864	Ляскеля	3	24	326	30.992236999999999	31.038805	61.774309000000002	61.752806	0103000020E6100000010000000500000093E1783E03FE3E40C51D6FF25BE04E4093E1783E03FE3E40CEFFAB8E1CE34E40D9EBDD1FEF093F40CEFFAB8E1CE34E40D9EBDD1FEF093F40C51D6FF25BE04E4093E1783E03FE3E40C51D6FF25BE04E40
17764	Импилахти	3	24	326	31.147241000000001	31.168593999999999	61.680050000000001	61.663181999999999	0103000020E610000001000000050000005EA10F96B1253F40DFA5D425E3D44E405EA10F96B1253F4089D2DEE00BD74E40444DF4F9282B3F4089D2DEE00BD74E40444DF4F9282B3F40DFA5D425E3D44E405EA10F96B1253F40DFA5D425E3D44E40
25747	Устье-Видлицы	3	24	1761	32.372264999999999	32.394255000000001	61.187615000000001	61.175150000000002	0103000020E6100000010000000500000004392861A62F40407CF2B0506B964E4004392861A62F4040999EB0C403984E406AA4A5F276324040999EB0C403984E406AA4A5F2763240407CF2B0506B964E4004392861A62F40407CF2B0506B964E40
25281	Устье Тулоксы	3	24	1761	32.559472999999997	32.574314000000001	61.121501000000002	61.115748000000004	0103000020E610000001000000050000005CFFAECF9C474040E94999D4D08E4E405CFFAECF9C47404035B742588D8F4E4046D1031F8349404035B742588D8F4E4046D1031F83494040E94999D4D08E4E405CFFAECF9C474040E94999D4D08E4E40
25533	Тукса	3	24	1761	32.823963999999997	32.856762000000003	61.032196999999996	60.987870999999998	0103000020E61000000100000005000000698A00A7776940405AD5928E727E4E40698A00A777694040C00303081F844E40503A9160AA6D4040C00303081F844E40503A9160AA6D40405AD5928E727E4E40698A00A7776940405AD5928E727E4E40
25444	Рыпушкалицы	3	24	1761	32.895344999999999	32.917864999999999	60.971947999999998	60.962975	0103000020E610000001000000050000008DD13AAA9A724040CCEEC9C3427B4E408DD13AAA9A724040D0B4C4CA687C4E404F92AE997C754040D0B4C4CA687C4E404F92AE997C754040CCEEC9C3427B4E408DD13AAA9A724040CCEEC9C3427B4E40
24984	Олонец	3	24	1761	32.942964000000003	33.010193999999998	60.988312000000001	60.965333000000001	0103000020E6100000010000000500000016A75A0BB3784040F25F2008907B4E4016A75A0BB3784040471FF301817E4E40C64E78094E814040471FF301817E4E40C64E78094E814040F25F2008907B4E4016A75A0BB3784040F25F2008907B4E40
25824	Нурмолицы	3	24	1761	32.921629000000003	32.936118999999998	61.077353000000002	61.071216999999997	0103000020E61000000100000005000000C90567F0F7754040A9F57EA31D894E40C90567F0F7754040AE9FFEB3E6894E40051555BFD2774040AE9FFEB3E6894E40051555BFD2774040A9F57EA31D894E40C90567F0F7754040A9F57EA31D894E40
46789	Михайловское	3	24	1761	33.723025	33.772280000000002	61.019013000000001	60.999471999999997	0103000020E610000001000000050000005F984C158CDC404044A2D0B2EE7F4E405F984C158CDC404074999A046F824E406DAD2F12DAE2404074999A046F824E406DAD2F12DAE2404044A2D0B2EE7F4E405F984C158CDC404044A2D0B2EE7F4E40
26102	Мегрега	3	24	1761	33.07658	33.122276999999997	60.940721000000003	60.923642000000001	0103000020E610000001000000050000008BC3995FCD894040249BABE639764E408BC3995FCD89404089D4B48B69784E40C806D2C5A68F404089D4B48B69784E40C806D2C5A68F4040249BABE639764E408BC3995FCD894040249BABE639764E40
26015	Куйтежа	3	24	1761	33.197555999999999	33.230415999999998	61.002516999999997	60.985374999999998	0103000020E610000001000000050000007590D78349994040E3A59BC4207E4E407590D783499940408E57207A52804E40D13C80457E9D40408E57207A52804E40D13C80457E9D4040E3A59BC4207E4E407590D78349994040E3A59BC4207E4E40
25894	Коткозеро	3	24	1761	33.172798	33.222116	61.294024999999998	61.254860999999998	0103000020E610000001000000050000003868AF3E1E9640404F0306499FA04E403868AF3E1E9640406B9A779CA2A54E408CF50D4C6E9C40406B9A779CA2A54E408CF50D4C6E9C40404F0306499FA04E403868AF3E1E9640404F0306499FA04E40
25874	Ковера	3	24	1761	33.013958000000002	33.031402999999997	61.145356	61.137461999999999	0103000020E6100000010000000500000040C23060C9814040AC38D55A98914E4040C23060C9814040812381069B924E4086FF740305844040812381069B924E4086FF740305844040AC38D55A98914E4040C23060C9814040AC38D55A98914E40
32716	Ильинский	3	24	1761	32.650446000000002	32.724080999999998	61.023052999999997	60.999690000000001	0103000020E6100000010000000500000032E884D041534040B21188D7F57F4E4032E884D0415340408F899466F3824E40D653ABAFAE5C40408F899466F3824E40D653ABAFAE5C4040B21188D7F57F4E4032E884D041534040B21188D7F57F4E40
57563	Гавриловка	3	24	1761	32.441685999999997	32.449457000000002	61.195929999999997	61.189275000000002	0103000020E61000000100000005000000EF8CB62A89384040A779C7293A984E40EF8CB62A893840401327F73B14994E40A9FA95CE873940401327F73B14994E40A9FA95CE87394040A779C7293A984E40EF8CB62A89384040A779C7293A984E40
25579	Видлица	3	24	1761	32.378686999999999	32.420028000000002	61.208151999999998	61.181156999999999	0103000020E61000000100000005000000CE35CCD07830404082380F2730974E40CE35CCD0783040406A4C88B9A49A4E40C0B33D7AC33540406A4C88B9A49A4E40C0B33D7AC335404082380F2730974E40CE35CCD07830404082380F2730974E40
32790	Верховье	3	24	1761	33.005388000000004	33.040880999999999	61.005896999999997	60.978797999999998	0103000020E610000001000000050000003BE5D18DB0804040F2B1BB40497D4E403BE5D18DB08040407F129F3BC1804E408E03AF963B8540407F129F3BC1804E408E03AF963B854040F2B1BB40497D4E403BE5D18DB0804040F2B1BB40497D4E40
25967	Верхнеолонецкий	3	24	1761	33.242030999999997	33.258901999999999	61.463006	61.455810999999997	0103000020E6100000010000000500000020CF2EDFFA9E40401A14CD0358BA4E4020CF2EDFFA9E404007EDD5C743BB4E403B6F63B323A1404007EDD5C743BB4E403B6F63B323A140401A14CD0358BA4E4020CF2EDFFA9E40401A14CD0358BA4E40
46670	Большие Горы	3	24	1761	32.453615999999997	32.479909999999997	61.318750999999999	61.301015999999997	0103000020E610000001000000050000009E78CE16103A40404FC939B187A64E409E78CE16103A40409D4830D5CCA84E40FD82DDB06D3D40409D4830D5CCA84E40FD82DDB06D3D40404FC939B187A64E409E78CE16103A40404FC939B187A64E40
25215	Алексала	3	24	1761	32.783396000000003	32.814793000000002	60.981896999999996	60.973612000000003	0103000020E610000001000000050000009BE8F35146644040207F69519F7C4E409BE8F351466440402F8507CDAE7D4E403F0114234B6840402F8507CDAE7D4E403F0114234B684040207F69519F7C4E409BE8F35146644040207F69519F7C4E40
24537	Тумба	3	24	1745	32.014491999999997	32.034956000000001	63.254196	63.248375000000003	0103000020E61000000100000005000000DD06B5DFDA0140406F1283C0CA9F4F40DD06B5DFDA0140401363997E89A04F4045662E70790440401363997E89A04F4045662E70790440406F1283C0CA9F4F40DD06B5DFDA0140406F1283C0CA9F4F40
24855	Тикша	3	24	1745	32.395172000000002	32.432702999999997	64.121804999999995	64.101417999999995	0103000020E61000000100000005000000C02500FF94324040724EECA17D065040C02500FF9432404050DF32A7CB075040C7F0D8CF6237404050DF32A7CB075040C7F0D8CF62374040724EECA17D065040C02500FF94324040724EECA17D065040
24386	Суккозеро	3	24	1745	32.299249000000003	32.363155999999996	63.176941999999997	63.162581000000003	0103000020E610000001000000050000002C2E8ECA4D264040BAF94674CF944F402C2E8ECA4D264040F8A41309A6964F404FAC53E57B2E4040F8A41309A6964F404FAC53E57B2E4040BAF94674CF944F402C2E8ECA4D264040BAF94674CF944F40
24924	Ругозеро	3	24	1745	32.767910000000001	32.793368000000001	64.090781000000007	64.073875999999998	0103000020E61000000100000005000000BC22F8DF4A62404065FD6662BA045040BC22F8DF4A62404049861C5BCF055040B2D826158D65404049861C5BCF055040B2D826158D65404065FD6662BA045040BC22F8DF4A62404065FD6662BA045040
24797	Реболы	3	24	1745	30.760956	30.835436000000001	63.845984999999999	63.820217999999997	0103000020E61000000100000005000000EAB12D03CEC23E4096CB46E7FCE84F40EAB12D03CEC23E400AF4893C49EC4F40ACE63922DFD53E400AF4893C49EC4F40ACE63922DFD53E4096CB46E7FCE84F40EAB12D03CEC23E4096CB46E7FCE84F40
24352	Пенинга	3	24	1745	32.030096	32.084812999999997	63.559766000000003	63.530079999999998	0103000020E61000000100000005000000C6DE8B2FDA034040C02154A9D9C34F40C6DE8B2FDA034040D5B48B69A6C74F4048A30227DB0A4040D5B48B69A6C74F4048A30227DB0A4040C02154A9D9C34F40C6DE8B2FDA034040C02154A9D9C34F40
24447	Ондозеро	3	24	1745	33.099532000000004	33.124333999999998	63.880873999999999	63.870271000000002	0103000020E61000000100000005000000E773EE76BD8C404020D4450A65EF4F40E773EE76BD8C4040C7F2AE7AC0F04F40F3E32F2DEA8F4040C7F2AE7AC0F04F40F3E32F2DEA8F404020D4450A65EF4F40E773EE76BD8C404020D4450A65EF4F40
24209	Муезерский	3	24	1745	31.971903000000001	32.014924000000001	63.971159999999998	63.953949000000001	0103000020E6100000010000000500000061E28FA2CEF83F40A58636001BFA4F4061E28FA2CEF83F4078978BF84EFC4F4077F69507E901404078978BF84EFC4F4077F69507E9014040A58636001BFA4F4061E28FA2CEF83F40A58636001BFA4F40
24621	Мотко	3	24	1745	31.707951000000001	31.737397999999999	63.295067000000003	63.288687000000003	0103000020E61000000100000005000000A62BD8463CB53F40E3E313B2F3A44F40A62BD8463CB53F407E9065C1C4A54F40C422861DC6BC3F407E9065C1C4A54F40C422861DC6BC3F40E3E313B2F3A44F40A62BD8463CB53F40E3E313B2F3A44F40
24637	Лендеры	3	24	1745	31.156610000000001	31.284026999999998	63.432537000000004	63.390968000000001	0103000020E61000000100000005000000003ACC9717283F402AE44A3D0BB24F40003ACC9717283F40ADA7565F5DB74F40552E54FEB5483F40ADA7565F5DB74F40552E54FEB5483F402AE44A3D0BB24F40003ACC9717283F402AE44A3D0BB24F40
24877	Ледмозеро	3	24	1745	32.014761999999997	32.043318999999997	64.260223999999994	64.243393999999995	0103000020E610000001000000050000009D9CA1B8E3014040BA826DC4930F50409D9CA1B8E301404098689082A7105040D0251C7A8B05404098689082A7105040D0251C7A8B054040BA826DC4930F50409D9CA1B8E3014040BA826DC4930F5040
24755	Кимоваара	3	24	1745	31.031061999999999	31.056080000000001	63.647959999999998	63.640600999999997	0103000020E61000000100000005000000FA25E2ADF3073F407764AC36FFD14F40FA25E2ADF3073F40DE8E705AF0D24F40AEF545425B0E3F40DE8E705AF0D24F40AEF545425B0E3F407764AC36FFD14F40FA25E2ADF3073F407764AC36FFD14F40
24521	Гимолы	3	24	1745	32.517136000000001	32.546565000000001	62.942297000000003	62.929333999999997	0103000020E61000000100000005000000C9CA2F8331424040CA87A06AF4764F40C9CA2F8331424040390F27309D784F40B21188D7F5454040390F27309D784F40B21188D7F5454040CA87A06AF4764F40C9CA2F8331424040CA87A06AF4764F40
24298	Волома	3	24	1745	31.907198000000001	31.951377000000001	63.749757000000002	63.738447999999998	0103000020E6100000010000000500000022FFCC203EE83F40F7E5CC7685DE4F4022FFCC203EE83F403A799109F8DF4F40A62A6D718DF33F403A799109F8DF4F40A62A6D718DF33F40F7E5CC7685DE4F4022FFCC203EE83F40F7E5CC7685DE4F40
32581	Шуньга	3	24	1704	34.920820999999997	34.953906000000003	62.601016000000001	62.584867000000003	0103000020E61000000100000005000000293C6876DD7541403CC1FEEBDC4A4F40293C6876DD754140B62FA017EE4C4F40A6BA8097197A4140B62FA017EE4C4F40A6BA8097197A41403CC1FEEBDC4A4F40293C6876DD7541403CC1FEEBDC4A4F40
57561	Шлюз 9	3	24	1704	34.897131999999999	34.908613000000003	62.918430000000001	62.911794999999998	0103000020E61000000100000005000000F818AC38D572414002D4D4B2B5744F40F818AC38D572414028D53E1D8F754F4038DC476E4D74414028D53E1D8F754F4038DC476E4D74414002D4D4B2B5744F40F818AC38D572414002D4D4B2B5744F40
23765	Шалговаара	3	24	1704	33.242885000000001	33.292993000000003	63.542960000000001	63.507505999999999	0103000020E6100000010000000500000030D80DDB169F40400B43E4F4F5C04F4030D80DDB169F4040A18499B67FC54F407D7A6CCB80A54040A18499B67FC54F407D7A6CCB80A540400B43E4F4F5C04F4030D80DDB169F40400B43E4F4F5C04F40
23542	Челмужи	3	24	1704	35.573258000000003	35.608302000000002	62.594175999999997	62.576619000000001	0103000020E61000000100000005000000CF15A58460C9414049A0C1A6CE494F40CF15A58460C94140B7088CF50D4C4F40B30B06D7DCCD4140B7088CF50D4C4F40B30B06D7DCCD414049A0C1A6CE494F40CF15A58460C9414049A0C1A6CE494F40
23630	Чебино	3	24	1704	34.144900999999997	34.163972000000001	62.917619000000002	62.909337000000001	0103000020E610000001000000050000002F14B01D8C1241407905A22765744F402F14B01D8C1241401898158A74754F40D8BAD408FD1441401898158A74754F40D8BAD408FD1441407905A22765744F402F14B01D8C1241407905A22765744F40
23981	Толвуя	3	24	1704	35.269888000000002	35.312828000000003	62.517829999999996	62.498026000000003	0103000020E610000001000000050000009BCAA2B08BA241406347E350BF3F4F409BCAA2B08BA241409F71E14048424F40F5A276BF0AA841409F71E14048424F40F5A276BF0AA841406347E350BF3F4F409BCAA2B08BA241406347E350BF3F4F40
57562	Сосновка	3	24	1704	35.482788999999997	35.697073000000003	62.980986000000001	62.910074999999999	0103000020E610000001000000050000002CEFAA07CCBD41401FF46C567D744F402CEFAA07CCBD4140BCEA01F3907D4F405AF624B039D94140BCEA01F3907D4F405AF624B039D941401FF46C567D744F402CEFAA07CCBD41401FF46C567D744F40
45696	Сергиево	3	24	1704	36.001035999999999	36.028281999999997	62.908738999999997	62.897049000000003	0103000020E61000000100000005000000300F99F2210042406BF46A80D2724F40300F99F221004240C4CC3E8F51744F4061889CBE9E034240C4CC3E8F51744F4061889CBE9E0342406BF46A80D2724F40300F99F2210042406BF46A80D2724F40
23185	Повенец	3	24	1704	34.807813000000003	34.857238000000002	62.885739000000001	62.834764999999997	0103000020E610000001000000050000004F24986A66674140376C5B94D96A4F404F24986A6667414058E542E55F714F40B9718BF9B96D414058E542E55F714F40B9718BF9B96D4140376C5B94D96A4F404F24986A66674140376C5B94D96A4F40
23058	Пиндуши	3	24	1704	34.560685999999997	34.590313000000002	62.9435	62.911212999999996	0103000020E610000001000000050000009BA9108FC44741405358A9A0A2744F409BA9108FC447414054E3A59BC4784F40ABB35A608F4B414054E3A59BC4784F40ABB35A608F4B41405358A9A0A2744F409BA9108FC44741405358A9A0A2744F40
23706	Паданы	3	24	1704	33.394933999999999	33.429167999999997	63.297176999999998	63.279029999999999	0103000020E610000001000000050000000B0A83328DB240402B4D4A41B7A34F400B0A83328DB24040CB0F5CE509A64F40AF3E1EFAEEB64040CB0F5CE509A64F40AF3E1EFAEEB640402B4D4A41B7A34F400B0A83328DB240402B4D4A41B7A34F40
45647	Огорелыши	3	24	1704	35.693866	35.717995000000002	63.018059999999998	63.006022000000002	0103000020E6100000010000000500000036E7E099D0D841403C873254C5804F4036E7E099D0D84140D1AE42CA4F824F4084D89942E7DB4140D1AE42CA4F824F4084D89942E7DB41403C873254C5804F4036E7E099D0D841403C873254C5804F40
23334	Новая Габсельга	3	24	1704	35.074002	35.095354999999998	62.814731999999999	62.794649	0103000020E6100000010000000500000057EBC4E5788941404966F50EB7654F4057EBC4E57889414099805F2349684F404A41B797348C414099805F2349684F404A41B797348C41404966F50EB7654F4057EBC4E5788941404966F50EB7654F40
22739	Медвежьегорск	3	24	1704	34.397587999999999	34.514341999999999	62.943748999999997	62.891162999999999	0103000020E610000001000000050000001AA4E029E4324140DF3312A111724F401AA4E029E4324140FC5069C4CC784F40C87A6AF5D5414140FC5069C4CC784F40C87A6AF5D5414140DF3312A111724F401AA4E029E4324140DF3312A111724F40
23816	Маслозеро	3	24	1704	32.845461	32.857534000000001	63.532586000000002	63.526302999999999	0103000020E610000001000000050000009085E810386C4040B2648EE55DC34F409085E810386C40405B272EC72BC44F40A29A92ACC36D40405B272EC72BC44F40A29A92ACC36D4040B2648EE55DC34F409085E810386C4040B2648EE55DC34F40
23161	Лумбуши	3	24	1704	34.515672000000002	34.589962	62.931126999999996	62.900213000000001	0103000020E6100000010000000500000041BB438A014241408F37F92D3A734F4041BB438A0142414017B6662B2F774F40FEF0F3DF834B414017B6662B2F774F40FEF0F3DF834B41408F37F92D3A734F4041BB438A014241408F37F92D3A734F40
24138	Ламбасручей	3	24	1704	34.865690999999998	34.885705999999999	62.294696999999999	62.280878000000001	0103000020E6100000010000000500000084B872F6CE6E41403C1570CFF3234F4084B872F6CE6E41405A9D9CA1B8254F407CEF6FD05E7141405A9D9CA1B8254F407CEF6FD05E7141403C1570CFF3234F4084B872F6CE6E41403C1570CFF3234F40
23688	Кумса 2	3	24	1704	33.794620999999999	33.814411	62.958917999999997	62.945647999999998	0103000020E610000001000000050000007FDB1324B6E540408FC360FE0A794F407FDB1324B6E54040DAC534D3BD7A4F405740A19E3EE84040DAC534D3BD7A4F405740A19E3EE840408FC360FE0A794F407FDB1324B6E540408FC360FE0A794F40
23943	Кажма	3	24	1704	34.833846000000001	34.842021000000003	62.553576999999997	62.546934	0103000020E6100000010000000500000041F33977BB6A41400589EDEE01464F4041F33977BB6A4140AD68739CDB464F40CAC51858C76B4140AD68739CDB464F40CAC51858C76B41400589EDEE01464F4041F33977BB6A41400589EDEE01464F40
23391	Верх. Волозеро	3	24	1704	35.406413999999998	35.425189000000003	62.777023999999997	62.768908000000003	0103000020E610000001000000050000007A51BB5F05B44140FFD0CC936B624F407A51BB5F05B44140821ABE8575634F403ACFD8976CB64140821ABE8575634F403ACFD8976CB64140FFD0CC936B624F407A51BB5F05B44140FFD0CC936B624F40
45864	Великая Нива	3	24	1704	35.209449999999997	35.220292000000001	62.361500999999997	62.354852999999999	0103000020E61000000100000005000000D712F241CF9A414099F1B6D26B2D4F40D712F241CF9A4140533C2EAA452E4F4004C93B87329C4140533C2EAA452E4F4004C93B87329C414099F1B6D26B2D4F40D712F241CF9A414099F1B6D26B2D4F40
24082	Великая Губа	3	24	1704	35.058630999999998	35.093414000000003	62.259923999999998	62.236761999999999	0103000020E6100000010000000500000011C4793881874140C0779B374E1E4F4011C479388187414006B98B3045214F40897E6DFDF48B414006B98B3045214F40897E6DFDF48B4140C0779B374E1E4F4011C4793881874140C0779B374E1E4F40
22105	Энгозеро	3	24	1619	33.918956999999999	33.951754000000001	65.797479999999993	65.780861999999999	0103000020E6100000010000000500000013B70A62A0F540401B2C9CA4F971504013B70A62A0F54040B3CD8DE90973504029EB3713D3F94040B3CD8DE90973504029EB3713D3F940401B2C9CA4F971504013B70A62A0F540401B2C9CA4F9715040
57543	Чупа	3	24	1619	32.956851999999998	33.095435000000002	66.279740000000004	66.259125999999995	0103000020E610000001000000050000005C8E57207A7A4040C5E23785959050405C8E57207A7A404084D89942E791504067F2CD36378C404084D89942E791504067F2CD36378C4040C5E23785959050405C8E57207A7A4040C5E2378595905040
49502	Чкаловский	3	24	1619	33.384208000000001	33.398069	66.298978000000005	66.295413999999994	0103000020E61000000100000005000000486E4DBA2DB14040F4311F10E8925040486E4DBA2DB140404E0E9F74229350409546CCECF3B240404E0E9F74229350409546CCECF3B24040F4311F10E8925040486E4DBA2DB14040F4311F10E8925040
22725	Хетоламбина	3	24	1619	33.272978000000002	33.303745999999997	66.361288999999999	66.348585999999997	0103000020E6100000010000000500000085436FF1F0A24040FB75A73B4F96504085436FF1F0A24040E4D9E55B1F97504039252026E1A64040E4D9E55B1F97504039252026E1A64040FB75A73B4F96504085436FF1F0A24040FB75A73B4F965040
22462	Тэдино	3	24	1619	32.733530999999999	32.758620999999998	66.471562000000006	66.462835999999996	0103000020E6100000010000000500000014CD0358E45D404055DAE21A9F9D504014CD0358E45D4040540262122E9E50408787307E1A614040540262122E9E50408787307E1A61404055DAE21A9F9D504014CD0358E45D404055DAE21A9F9D5040
22199	Тунгозеро	3	24	1619	31.290261999999998	31.312467999999999	65.756139000000005	65.749823000000006	0103000020E610000001000000050000008445459C4E4A3F4079B29B19FD6F50408445459C4E4A3F40BB0ED59464705040E90B21E7FD4F3F40BB0ED59464705040E90B21E7FD4F3F4079B29B19FD6F50408445459C4E4A3F4079B29B19FD6F5040
22276	Софпорог	3	24	1619	31.395220999999999	31.436696000000001	65.808505999999994	65.797421	0103000020E6100000010000000500000042B115342D653F40310917F20873504042B115342D653F40AA27F38FBE735040454B1E4FCB6F3F40AA27F38FBE735040454B1E4FCB6F3F40310917F20873504042B115342D653F40310917F208735040
57548	Сосновый	3	24	1619	32.307523000000003	32.330897	66.003647999999998	65.997073999999998	0103000020E6100000010000000500000048E2E5E95C274040486C770FD07F504048E2E5E95C274040882CD2C43B80504019AC38D55A2A4040882CD2C43B80504019AC38D55A2A4040486C770FD07F504048E2E5E95C274040486C770FD07F5040
22183	Пяозерский	3	24	1619	31.053843000000001	31.100735	65.770205000000004	65.758543000000003	0103000020E61000000100000005000000581EA4A7C80D3F400667F0F78B705040581EA4A7C80D3F40CE8DE9094B7150400490DAC4C9193F40CE8DE9094B7150400490DAC4C9193F400667F0F78B705040581EA4A7C80D3F400667F0F78B705040
49509	Плотина	3	24	1619	33.339274000000003	33.376491000000001	66.201678000000001	66.193612999999999	0103000020E610000001000000050000000A3197546DAB404026C5C727648C50400A3197546DAB4040A794D74AE88C5040821E6ADB30B04040A794D74AE88C5040821E6ADB30B0404026C5C727648C50400A3197546DAB404026C5C727648C5040
20276	Малиновая Варакка	3	24	1619	33.184556999999998	33.223292000000001	66.303999000000005	66.288781999999998	0103000020E61000000100000005000000BA9F53909F9740401A6B7F677B925040BA9F53909F97404012C138B874935040AEBA0ED5949C404012C138B874935040AEBA0ED5949C40401A6B7F677B925040BA9F53909F9740401A6B7F677B925040
21975	Лоухи	3	24	1619	32.932336999999997	33.078071000000001	66.082099999999997	66.063074999999998	0103000020E61000000100000005000000E5EC9DD1567740407E8CB96B09845040E5EC9DD1567740401AC05B20418550400DE2033BFE8940401AC05B20418550400DE2033BFE8940407E8CB96B09845040E5EC9DD1567740407E8CB96B09845040
22329	Кестеньга	3	24	1619	31.790694999999999	31.877832000000001	65.902685000000005	65.88167	0103000020E61000000100000005000000581CCEFC6ACA3F4051F701486D785040581CCEFC6ACA3F40BF654E97C5795040DD611399B9E03F40BF654E97C5795040DD611399B9E03F4051F701486D785040581CCEFC6ACA3F4051F701486D785040
22124	Амбарный	3	24	1619	33.696705000000001	33.737461000000003	65.902916000000005	65.891035000000002	0103000020E61000000100000005000000D7FA22A12DD94040D925AAB706795040D7FA22A12DD9404040C23060C9795040A9893E1F65DE404040C23060C9795040A9893E1F65DE4040D925AAB706795040D7FA22A12DD94040D925AAB706795040
21408	Эстерло	3	24	1642	29.731145999999999	29.750594	61.412329	61.400509999999997	0103000020E61000000100000005000000E9995E622CBB3D4048DC63E943B34E40E9995E622CBB3D40A0185932C7B44E40E692AAED26C03D40A0185932C7B44E40E692AAED26C03D4048DC63E943B34E40E9995E622CBB3D4048DC63E943B34E40
21372	Элисенваара	3	24	1642	29.7501	29.800532	61.419057000000002	61.400509999999997	0103000020E61000000100000005000000C7BAB88D06C03D4048DC63E943B34E40C7BAB88D06C03D407714E7A8A3B54E40C76647AAEFCC3D407714E7A8A3B54E40C76647AAEFCC3D4048DC63E943B34E40C7BAB88D06C03D4048DC63E943B34E40
21721	Хухтерву	3	24	1642	30.096122000000001	30.106263999999999	61.397590000000001	61.392003000000003	0103000020E61000000100000005000000166D8E739B183E408A7780272DB24E40166D8E739B183E40BB9BA73AE4B24E40FDBD141E341B3E40BB9BA73AE4B24E40FDBD141E341B3E408A7780272DB24E40166D8E739B183E408A7780272DB24E40
21801	Хийтола	3	24	1642	29.667822999999999	29.712226999999999	61.250118000000001	61.227879999999999	0103000020E610000001000000050000004084B872F6AA3D40CCB4FD2B2B9D4E404084B872F6AA3D400A12DBDD03A04E400454388254B63D400A12DBDD03A04E400454388254B63D40CCB4FD2B2B9D4E404084B872F6AA3D40CCB4FD2B2B9D4E40
21855	Тоунан	3	24	1642	29.530398999999999	29.555309000000001	61.321679000000003	61.308709999999998	0103000020E61000000100000005000000C3D4963AC8873D405DF92CCF83A74E40C3D4963AC8873D40AE6708C72CA94E40AA2C0ABB288E3D40AE6708C72CA94E40AA2C0ABB288E3D405DF92CCF83A74E40C3D4963AC8873D405DF92CCF83A74E40
21879	Тиурула	3	24	1642	29.855895	29.872945000000001	61.219954000000001	61.212186000000003	0103000020E6100000010000000500000057CF49EF1BDB3D40A4552DE9289B4E4057CF49EF1BDB3D40EC4FE273279C4E40EC34D25279DF3D40EC4FE273279C4E40EC34D25279DF3D40A4552DE9289B4E4057CF49EF1BDB3D40A4552DE9289B4E40
21713	Терву	3	24	1642	30.105905	30.121616	61.314419999999998	61.309880999999997	0103000020E610000001000000050000009E7B0F971C1B3E406D533C2EAAA74E409E7B0F971C1B3E40AA9A20EA3EA84E409BABE639221F3E40AA9A20EA3EA84E409BABE639221F3E406D533C2EAAA74E409E7B0F971C1B3E406D533C2EAAA74E40
21317	Раухала	3	24	1642	30.212706000000001	30.228166000000002	61.537827	61.529302000000001	0103000020E61000000100000005000000B9A981E673363E408CDAFD2AC0C34E40B9A981E673363E40F1F3DF83D7C44E40240F4416693A3E40F1F3DF83D7C44E40240F4416693A3E408CDAFD2AC0C34E40B9A981E673363E408CDAFD2AC0C34E40
21155	Мийнала	3	24	1642	30.305537000000001	30.330825000000001	61.557279000000001	61.547258999999997	0103000020E61000000100000005000000CCB73EAC374E3E4088B839950CC64E40CCB73EAC374E3E40B1DF13EB54C74E40FFB27BF2B0543E40B1DF13EB54C74E40FFB27BF2B0543E4088B839950CC64E40CCB73EAC374E3E4088B839950CC64E40
21242	Лумиваара	3	24	1642	30.139313000000001	30.151817999999999	61.446699000000002	61.431213999999997	0103000020E610000001000000050000005CE84A04AA233E40E6C9350532B74E405CE84A04AA233E40F513CE6E2DB94E40B2F1608BDD263E40F513CE6E2DB94E40B2F1608BDD263E40E6C9350532B74E405CE84A04AA233E40E6C9350532B74E40
20760	Лахденпохья	3	24	1642	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
21614	Ласанен	3	24	1642	29.841422999999999	29.863727999999998	61.273300999999996	61.268098000000002	0103000020E610000001000000050000002A1A6B7F67D73D40BF0F070951A24E402A1A6B7F67D73D40677BF486FBA24E40B5A338471DDD3D40677BF486FBA24E40B5A338471DDD3D40BF0F070951A24E402A1A6B7F67D73D40BF0F070951A24E40
21490	Ламминкюля	3	24	1642	29.580003999999999	29.592347	61.376344000000003	61.372670999999997	0103000020E61000000100000005000000978C63247B943D407495EEAEB3AF4E40978C63247B943D40DE054A0A2CB04E403BE2900DA4973D40DE054A0A2CB04E403BE2900DA4973D407495EEAEB3AF4E40978C63247B943D407495EEAEB3AF4E40
21553	Куркиеки	3	24	1642	29.864374999999999	29.903756999999999	61.311073	61.293753000000002	0103000020E61000000100000005000000E17A14AE47DD3D400B0DC4B299A54E40E17A14AE47DD3D4095D5743DD1A74E40F487669E5CE73D4095D5743DD1A74E40F487669E5CE73D400B0DC4B299A54E40E17A14AE47DD3D400B0DC4B299A54E40
21954	Куликово	3	24	1642	29.718658999999999	29.765165	61.207286000000003	61.183998000000003	0103000020E61000000100000005000000DFF94509FAB73D40C443183F8D974E40DFF94509FAB73D409775FF58889A4E40390B7BDAE1C33D409775FF58889A4E40390B7BDAE1C33D40C443183F8D974E40DFF94509FAB73D40C443183F8D974E40
21261	Ихала	3	24	1642	29.988925999999999	30.013180999999999	61.504215000000002	61.492907000000002	0103000020E61000000100000005000000022A1C412AFD3D40187C9A9317BF4E40022A1C412AFD3D408A93FB1D8AC04E40B7ED7BD45F033E408A93FB1D8AC04E40B7ED7BD45F033E40187C9A9317BF4E40022A1C412AFD3D40187C9A9317BF4E40
21458	Вялимяки	3	24	1642	29.817698	29.830400999999998	61.442343000000001	61.435172000000001	0103000020E610000001000000050000002E01F8A754D13D40451152B7B3B74E402E01F8A754D13D40A94E07B29EB84E40D190F12895D43D40A94E07B29EB84E40D190F12895D43D40451152B7B3B74E402E01F8A754D13D40451152B7B3B74E40
21627	Алхо	3	24	1642	29.710574000000001	29.737748	61.327942999999998	61.312657999999999	0103000020E610000001000000050000004E637B2DE8B53D40986A662D05A84E404E637B2DE8B53D40DFF94509FAA94E407DB08C0DDDBC3D40DFF94509FAA94E407DB08C0DDDBC3D40986A662D05A84E404E637B2DE8B53D40986A662D05A84E40
1389	Янишполе	3	24	19	34.263838	34.277304000000001	62.120348	62.108035999999998	0103000020E6100000010000000500000095B88E71C52141403465A71FD40D4F4095B88E71C5214140CB113290670F4F4066868DB27E234140CB113290670F4F4066868DB27E2341403465A71FD40D4F4095B88E71C52141403465A71FD40D4F40
943	Эльмус	3	24	19	33.623761000000002	33.649389999999997	62.715812999999997	62.704383999999997	0103000020E6100000010000000500000098C28366D7CF4040AFE94141295A4F4098C28366D7CF40409C86A8C29F5B4F40BA2C26361FD340409C86A8C29F5B4F40BA2C26361FD34040AFE94141295A4F4098C28366D7CF4040AFE94141295A4F40
1210	Уница	3	24	19	34.351782999999998	34.477888999999998	62.742902000000001	62.588408000000001	0103000020E61000000100000005000000F624B039072D4140365A0EF4504B4F40F624B039072D41400611A969175F4F401F0F7D772B3D41400611A969175F4F401F0F7D772B3D4140365A0EF4504B4F40F624B039072D4140365A0EF4504B4F40
52004	Улитина-Новинка	3	24	19	34.407451999999999	34.424816	62.155883000000003	62.147852999999998	0103000020E610000001000000050000004B581B6327344140C8CEDBD8EC124F404B581B63273441404E8061F9F3134F40A568E55E603641404E8061F9F3134F40A568E55E60364140C8CEDBD8EC124F404B581B6327344140C8CEDBD8EC124F40
51985	Тивдия	3	24	19	33.954799999999999	33.969800999999997	62.564247999999999	62.554485999999997	0103000020E61000000100000005000000431CEBE236FA4040800BB265F9464F40431CEBE236FA4040AD6A494739484F4065506D7022FC4040AD6A494739484F4065506D7022FC4040800BB265F9464F40431CEBE236FA4040800BB265F9464F40
796	Спасская Губа	3	24	19	33.803019999999997	33.833976	62.225637999999996	62.202446999999999	0103000020E610000001000000050000005704FF5BC9E640402F1686C8E9194F405704FF5BC9E640400F5EBBB4E11C4F400FD3BEB9BFEA40400F5EBBB4E11C4F400FD3BEB9BFEA40402F1686C8E9194F405704FF5BC9E640402F1686C8E9194F40
820	Нелгомозеро	3	24	19	33.436183999999997	33.455677999999999	62.199886999999997	62.187976999999997	0103000020E61000000100000005000000EC8497E0D4B7404039B35DA10F184F40EC8497E0D4B74040A1F2AFE595194F40DBC01DA853BA4040A1F2AFE595194F40DBC01DA853BA404039B35DA10F184F40EC8497E0D4B7404039B35DA10F184F40
1165	Кяппесельга	3	24	19	34.235729999999997	34.272336000000003	62.688752999999998	62.646808	0103000020E61000000100000005000000D15790662C1E41404565C39ACA524F40D15790662C1E4140CD02ED0E29584F4001C3F2E7DB224140CD02ED0E29584F4001C3F2E7DB2241404565C39ACA524F40D15790662C1E41404565C39ACA524F40
684	Кончезеро	3	24	19	34.000003	34.022533000000003	62.134596999999999	62.116376000000002	0103000020E6100000010000000500000071732A19000041400805A568E50E4F4071732A1900004140E29178793A114F40570A815CE2024140E29178793A114F40570A815CE20241400805A568E50E4F4071732A19000041400805A568E50E4F40
24	Кондопога	3	24	19	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
1050	Кедрозеро	3	24	19	34.435003000000002	34.505476000000002	62.387861000000001	62.355257999999999	0103000020E61000000100000005000000B954A52DAE37414039D21918792D4F40B954A52DAE3741406A32E36DA5314F40DA740470B34041406A32E36DA5314F40DA740470B340414039D21918792D4F40B954A52DAE37414039D21918792D4F40
921	Гирвас	3	24	19	33.665227999999999	33.691755000000001	62.484741999999997	62.457453000000001	0103000020E610000001000000050000001631EC3026D54040823AE5D18D3A4F401631EC3026D54040B27F9E060C3E4F4018EC866D8BD84040B27F9E060C3E4F4018EC866D8BD84040823AE5D18D3A4F401631EC3026D54040823AE5D18D3A4F40
574	Березовка	3	24	19	34.162453999999997	34.176270000000002	62.235610000000001	62.226799999999997	0103000020E610000001000000050000005C8DEC4ACB144140CC5D4BC8071D4F405C8DEC4ACB144140274EEE77281E4F400AA2EE0390164140274EEE77281E4F400AA2EE0390164140CC5D4BC8071D4F405C8DEC4ACB144140CC5D4BC8071D4F40
20488	Рабочеостровск	3	24	430	34.738686999999999	34.76455	64.989085000000003	64.978131000000005	0103000020E610000001000000050000007C7DAD4B8D5E41400B0DC4B2993E50407C7DAD4B8D5E4140B5FD2B2B4D3F504012143FC6DC614140B5FD2B2B4D3F504012143FC6DC6141400B0DC4B2993E50407C7DAD4B8D5E41400B0DC4B2993E5040
20600	Панозеро	3	24	430	32.853527999999997	32.909447999999998	64.977401	64.967975999999993	0103000020E61000000100000005000000321CCF67406D404006D49B51F33D5040321CCF67406D4040F984ECBC8D3E5040D0B4C4CA68744040F984ECBC8D3E5040D0B4C4CA6874404006D49B51F33D5040321CCF67406D404006D49B51F33D5040
3156	Кузема	3	24	430	34.220278999999998	34.271743000000001	65.367529000000005	65.352058	0103000020E610000001000000050000006F7F2E1A321C4140E412471E885650406F7F2E1A321C414039D55A98855750405EF58079C822414039D55A98855750405EF58079C8224140E412471E885650406F7F2E1A321C4140E412471E88565040
20554	Кривой Порог	3	24	430	33.650019	33.657663999999997	65.036647000000002	65.034649999999999	0103000020E61000000100000005000000AA6395D233D340409C33A2B437425040AA6395D233D34040C79FA86C58425040D6E07D552ED44040C79FA86C58425040D6E07D552ED440409C33A2B437425040AA6395D233D340409C33A2B437425040
3106	Кемь	3	24	430	34.527943	34.661935	64.965517000000006	64.941023000000001	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
57567	Гайжево	3	24	430	34.627808000000002	34.662061000000001	64.948328000000004	64.944157000000004	0103000020E61000000100000005000000661536035C50414087527B116D3C5040661536035C5041406478EC67B13C5040817A336ABE5441406478EC67B13C5040817A336ABE54414087527B116D3C5040661536035C50414087527B116D3C5040
57550	Бабгуба	3	24	430	34.685488999999997	34.726506000000001	64.975246999999996	64.962970999999996	0103000020E610000001000000050000004562821ABE574140C5FF1D51A13D50404562821ABE5741406AA164726A3E5040842C0B26FE5C41406AA164726A3E5040842C0B26FE5C4140C5FF1D51A13D50404562821ABE574140C5FF1D51A13D5040
32833	14-й километр	3	24	430	34.355896999999999	34.374501000000002	64.924910999999994	64.918678999999997	0103000020E610000001000000050000004CDF6B088E2D4140682101A3CB3A50404CDF6B088E2D41407B2DE8BD313B5040DFA815A6EF2F41407B2DE8BD313B5040DFA815A6EF2F4140682101A3CB3A50404CDF6B088E2D4140682101A3CB3A5040
1747	Юшкозеро	3	24	349	32.090463	32.229512999999997	64.781853999999996	64.738462999999996	0103000020E61000000100000005000000C03FA54A940B4040969350FA422F5040C03FA54A940B4040CB0F5CE509325040E08096AE601D4040CB0F5CE509325040E08096AE601D4040969350FA422F5040C03FA54A940B4040969350FA422F5040
57568	Луусалма	3	24	349	31.548760999999999	31.582636000000001	65.062642999999994	65.052887999999996	0103000020E61000000100000005000000FC51D4997B8C3F407496598462435040FC51D4997B8C3F40B114C95702445040E67805A227953F40B114C95702445040E67805A227953F407496598462435040FC51D4997B8C3F407496598462435040
1744	Куусиниэми	3	24	349	31.453405	31.482771	65.176777000000001	65.169666000000007	0103000020E61000000100000005000000C7D79E5912743F40904FC8CEDB4A5040C7D79E5912743F40D76B7A50504B50400C7558E1967B3F40D76B7A50504B50400C7558E1967B3F40904FC8CEDB4A5040C7D79E5912743F40904FC8CEDB4A5040
19734	Кепа	3	24	349	32.151916999999997	32.182997999999998	65.158147999999997	65.148391000000004	0103000020E610000001000000050000006C5A2904721340405401F73C7F4950406C5A29047213404061FBC9181F4A5040E09D7C7A6C17404061FBC9181F4A5040E09D7C7A6C1740405401F73C7F4950406C5A2904721340405401F73C7F495040
2777	Калевала	3	24	349	31.135949	31.226203000000002	65.216735999999997	65.182319000000007	0103000020E6100000010000000500000085ECBC8DCD223F40209C4F1DAB4B504085ECBC8DCD223F406AF7AB00DF4D5040D1419770E8393F406AF7AB00DF4D5040D1419770E8393F40209C4F1DAB4B504085ECBC8DCD223F40209C4F1DAB4B5040
2788	Боровой	3	24	349	32.214995999999999	32.253678000000001	64.626386999999994	64.599552000000003	0103000020E61000000100000005000000AA622AFD841B404017105A0F5F265040AA622AFD841B4040EEE87FB9162850407BDB4C8578204040EEE87FB9162850407BDB4C857820404017105A0F5F265040AA622AFD841B404017105A0F5F265040
19331	Шуерецкое	3	24	459	34.654353999999998	34.722940000000001	64.755341999999999	64.738420000000005	0103000020E61000000100000005000000DE0033DFC153414097ADF545422F5040DE0033DFC1534140E5D2F88557305040317C444C895C4140E5D2F88557305040317C444C895C414097ADF545422F5040DE0033DFC153414097ADF545422F5040
48471	Хвойный	3	24	459	35.177461000000001	35.198453999999998	64.046681000000007	64.032749999999993	0103000020E6100000010000000500000061A8C30AB79641406ABC74931802504061A8C30AB79641400E164ED2FC02504054E1CFF0669941400E164ED2FC02504054E1CFF0669941406ABC74931802504061A8C30AB79641406ABC749318025040
18870	Сумский Посад	3	24	459	35.381270000000001	35.429582000000003	64.261652999999995	64.223094000000003	0103000020E6100000010000000500000014799274CDB04140C47B0E2C470E504014799274CDB041409E7939ECBE105040A379008BFCB641409E7939ECBE105040A379008BFCB64140C47B0E2C470E504014799274CDB04140C47B0E2C470E5040
48524	Сосновец	3	24	459	34.446097000000002	34.506410000000002	64.437353000000002	64.413330000000002	0103000020E61000000100000005000000FFEBDCB4193941402A1DACFF731A5040FFEBDCB419394140AEF36F97FD1B5040062FFA0AD2404140AEF36F97FD1B5040062FFA0AD24041402A1DACFF731A5040FFEBDCB4193941402A1DACFF731A5040
48517	Пушной	3	24	459	34.130671999999997	34.154522	64.404779000000005	64.396721999999997	0103000020E610000001000000050000005F402FDCB9104140A3E6ABE4631950405F402FDCB9104140E3C62DE6E71950409A417C60C7134140E3C62DE6E71950409A417C60C7134140A3E6ABE4631950405F402FDCB9104140A3E6ABE463195040
48383	Нюхча	3	24	459	36.239584000000001	36.277501999999998	63.931356000000001	63.904685999999998	0103000020E610000001000000050000008B5242B0AA1E4240149337C0CCF34F408B5242B0AA1E4240797764AC36F74F408C497F2F85234240797764AC36F74F408C497F2F85234240149337C0CCF34F408B5242B0AA1E4240149337C0CCF34F40
19259	Новое Машезеро	3	24	459	33.405372	33.421478999999998	64.413803999999999	64.404612	0103000020E61000000100000005000000685BCD3AE3B340406DE4BA29E5195040685BCD3AE3B340400EBDC5C37B1A5040B3791C06F3B540400EBDC5C37B1A5040B3791C06F3B540406DE4BA29E5195040685BCD3AE3B340406DE4BA29E5195040
57569	Маленьга	3	24	459	36.432352999999999	36.509276	63.845655999999998	63.831581	0103000020E61000000100000005000000EBA9D55757374240CC7C073F71EA4F40EBA9D5575737424045D5AF743EEC4F40A051BAF42F41424045D5AF743EEC4F40A051BAF42F414240CC7C073F71EA4F40EBA9D55757374240CC7C073F71EA4F40
19119	Летнереченский	3	24	459	34.363883000000001	34.425400000000003	64.311510999999996	64.266582	0103000020E610000001000000050000000249D8B7932E4140F2ECF2AD0F1150400249D8B7932E41400856D5CBEF135040F5DBD781733641400856D5CBEF135040F5DBD78173364140F2ECF2AD0F1150400249D8B7932E4140F2ECF2AD0F115040
19013	Колежма	3	24	459	35.714491000000002	35.896436000000001	64.241499000000005	64.114187999999999	0103000020E61000000100000005000000A724EB7074DB41401F662FDB4E075040A724EB7074DB414012C138B8740F5040817A336ABEF2414012C138B8740F5040817A336ABEF241401F662FDB4E075040A724EB7074DB41401F662FDB4E075040
18659	Золотец	3	24	459	34.638876000000003	34.658341999999998	64.495073000000005	64.485866000000001	0103000020E61000000100000005000000831953B0C6514140410FB56D181F5040831953B0C65141407D08AA46AF1F5040A7CAF78C445441407D08AA46AF1F5040A7CAF78C44544140410FB56D181F5040831953B0C6514140410FB56D181F5040
18688	Вирандозеро	3	24	459	35.918795000000003	36.017043999999999	64.048711999999995	64.003936999999993	0103000020E610000001000000050000003A5D16139BF54140A38FF980400050403A5D16139BF541400EBBEF181E035040E84B6F7F2E0242400EBBEF181E035040E84B6F7F2E024240A38FF980400050403A5D16139BF54140A38FF98040005040
2679	Беломорск	3	24	459	34.722248	34.815745	64.552330999999995	64.505497000000005	0103000020E61000000100000005000000FBCC599F725C414079CE16105A205040FBCC599F725C414049641F6459235040117008556A68414049641F6459235040117008556A68414079CE16105A205040FBCC599F725C414079CE16105A205040
57387	Себеж	3	32	\N	28.458053	28.507344	56.305993000000001	56.266751999999997	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
51947	Родина	3	32	\N	28.249420000000001	28.270045	57.841479999999997	57.825629999999997	0103000020E61000000100000005000000E4F736FDD93F3C40594C6C3EAEE94C40E4F736FDD93F3C40791EDC9DB5EB4C40C5724BAB21453C40791EDC9DB5EB4C40C5724BAB21453C40594C6C3EAEE94C40E4F736FDD93F3C40594C6C3EAEE94C40
57373	Пыталово	3	32	\N	27.890173999999998	27.944181	57.078394000000003	57.053710000000002	0103000020E61000000100000005000000DFBF7971E2E33B40EDBB22F8DF864C40DFBF7971E2E33B40F01989D0088A4C402C8194D8B5F13B40F01989D0088A4C402C8194D8B5F13B40EDBB22F8DF864C40DFBF7971E2E33B40EDBB22F8DF864C40
4697	Псков	3	32	\N	28.255474	28.460272	57.859220000000001	57.743735000000001	0103000020E6100000010000000500000072FA7ABE66413C40FEF15EB532DF4C4072FA7ABE66413C40D908C4EBFAED4C40B743C362D4753C40D908C4EBFAED4C40B743C362D4753C40FEF15EB532DF4C4072FA7ABE66413C40FEF15EB532DF4C40
57388	Порхов	3	32	\N	29.514526	29.581863999999999	57.782330999999999	57.750681	0103000020E6100000010000000500000013F1D6F9B7833D40425DA45016E04C4013F1D6F9B7833D40D0D2156C23E44C4041B8020AF5943D40D0D2156C23E44C4041B8020AF5943D40425DA45016E04C4013F1D6F9B7833D40425DA45016E04C40
57376	Печоры	3	32	\N	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
57384	Остров	3	32	\N	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
57391	Опочка	3	32	\N	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
57378	Новоржев	3	32	\N	29.311606000000001	29.368307000000001	57.039374000000002	57.021731000000003	0103000020E61000000100000005000000C53C2B69C54F3D409A27D714C8824C40C53C2B69C54F3D4007280D350A854C404CE3175E495E3D4007280D350A854C404CE3175E495E3D409A27D714C8824C40C53C2B69C54F3D409A27D714C8824C40
59077	Нефедино	3	32	\N	27.325196999999999	31.517040999999999	59.021518999999998	55.589731999999998	0103000020E61000000100000005000000DFC14F1C40533B40CCB392567CCB4B40DFC14F1C40533B400E9F7422C1824D40EEB089CC5C843F400E9F7422C1824D40EEB089CC5C843F40CCB392567CCB4B40DFC14F1C40533B40CCB392567CCB4B40
57377	Невель	3	32	\N	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
57375	Дно	3	32	\N	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
4310	Голубово	3	32	\N	28.404171999999999	28.430107	57.855795999999998	57.834786999999999	0103000020E610000001000000050000007BF5F1D077673C401F10E84CDAEA4C407BF5F1D077673C4018062CB98AED4C40DAC70A7E1B6E3C4018062CB98AED4C40DAC70A7E1B6E3C401F10E84CDAEA4C407BF5F1D077673C401F10E84CDAEA4C40
57400	Гдов	3	32	\N	27.800864000000001	27.839464	58.753315000000001	58.728565000000003	0103000020E61000000100000005000000338B506C05CD3B405001309E415D4D40338B506C05CD3B400A4B3CA06C604D405A2BDA1CE7D63B400A4B3CA06C604D405A2BDA1CE7D63B405001309E415D4D40338B506C05CD3B405001309E415D4D40
9096	Великие Луки	3	32	\N	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
49092	Шершни	3	32	423	30.734438000000001	30.759671999999998	55.665979999999998	55.649017000000001	0103000020E610000001000000050000008DF0F62004BC3E4026C632FD12D34B408DF0F62004BC3E4021E527D53ED54B40D9AF3BDD79C23E4021E527D53ED54B40D9AF3BDD79C23E4026C632FD12D34B408DF0F62004BC3E4026C632FD12D34B40
48960	Чурилово	3	32	423	30.464421999999999	30.479927	55.833865000000003	55.821112999999997	0103000020E61000000100000005000000FC8A355CE4763E4004A9143B1AE94B40FC8A355CE4763E40B8239C16BCEA4B40A777F17EDC7A3E40B8239C16BCEA4B40A777F17EDC7A3E4004A9143B1AE94B40FC8A355CE4763E4004A9143B1AE94B40
49022	Церковище	3	32	423	30.837600999999999	30.872536	55.908791999999998	55.878292999999999	0103000020E61000000100000005000000CE18E6046DD63E4022A7AFE76BF04B40CE18E6046DD63E40E76ED74B53F44B402995F0845EDF3E40E76ED74B53F44B402995F0845EDF3E4022A7AFE76BF04B40CE18E6046DD63E4022A7AFE76BF04B40
2271	Усвяты	3	32	423	30.718951000000001	30.814181999999999	55.761178000000001	55.717638999999998	0103000020E610000001000000050000002F6D382C0DB83E40C5AA4198DBDB4B402F6D382C0DB83E40A437DC476EE14B40EBFD463B6ED03E40A437DC476EE14B40EBFD463B6ED03E40C5AA4198DBDB4B402F6D382C0DB83E40C5AA4198DBDB4B40
40409	Узкое	3	32	423	30.545432999999999	30.575391	55.784896000000003	55.763103000000001	0103000020E61000000100000005000000BF28417FA18B3E40603DEE5BADE14B40BF28417FA18B3E407061DD7877E44B40A96917D34C933E407061DD7877E44B40A96917D34C933E40603DEE5BADE14B40BF28417FA18B3E40603DEE5BADE14B40
2504	Удвяты	3	32	423	30.859933000000002	30.876192	55.751634000000003	55.741044000000002	0103000020E610000001000000050000004DC0AF9124DC3E40D272A087DADE4B404DC0AF9124DC3E40E547FC8A35E04B404F04711E4EE03E40E547FC8A35E04B404F04711E4EE03E40D272A087DADE4B404DC0AF9124DC3E40D272A087DADE4B40
2725	Стеревнево	3	32	423	30.626479	30.644867000000001	55.9191	55.908343000000002	0103000020E610000001000000050000007BA180ED60A03E4078465B9544F44B407BA180ED60A03E4076E09C11A5F54B400745F30016A53E4076E09C11A5F54B400745F30016A53E4078465B9544F44B407BA180ED60A03E4078465B9544F44B40
2800	Северики	3	32	423	30.594642	30.608719000000001	55.837302999999999	55.824491000000002	0103000020E61000000100000005000000FAD346753A983E40556CCCEB88E94B40FAD346753A983E40DDEBA4BE2CEB4B402E742502D59B3E40DDEBA4BE2CEB4B402E742502D59B3E40556CCCEB88E94B40FAD346753A983E40556CCCEB88E94B40
46455	Алексеевка	3	32	423	30.418447	30.429836999999999	55.86797	55.860691000000003	0103000020E61000000100000005000000FC1BB4571F6B3E40147B681F2BEE4B40FC1BB4571F6B3E405EF415A419EF4B405A9C31CC096E3E405EF415A419EF4B405A9C31CC096E3E40147B681F2BEE4B40FC1BB4571F6B3E40147B681F2BEE4B40
49008	Адамово	3	32	423	30.877503999999998	30.896529999999998	55.948799999999999	55.934759999999997	0103000020E61000000100000005000000F31B261AA4E03E40F2CD3637A6F74B40F31B261AA4E03E40EF38454772F94B4004E275FD82E53E40EF38454772F94B4004E275FD82E53E40F2CD3637A6F74B40F31B261AA4E03E40F2CD3637A6F74B40
28613	Цапелька	3	32	1837	28.930899	28.956268000000001	58.054797999999998	58.037483999999999	0103000020E610000001000000050000000DE198654FEE3C40C70F9546CC044D400DE198654FEE3C406FF1F09E03074D401A36CAFACDF43C406FF1F09E03074D401A36CAFACDF43C40C70F9546CC044D400DE198654FEE3C40C70F9546CC044D40
28831	Хредино	3	32	1837	29.404427999999999	29.423705999999999	58.124597999999999	58.103276000000001	0103000020E610000001000000050000003196E99788673D40193BE125380D4D403196E99788673D40D192C7D3F20F4D40751E15FF776C3D40D192C7D3F20F4D40751E15FF776C3D40193BE125380D4D403196E99788673D40193BE125380D4D40
57389	Струги-Красные	3	32	1837	29.058703000000001	29.128682000000001	58.313997999999998	58.247152	0103000020E61000000100000005000000562DE928070F3D400C923EADA21F4D40562DE928070F3D403481221631284D407995B54DF1203D403481221631284D407995B54DF1203D400C923EADA21F4D40562DE928070F3D400C923EADA21F4D40
28459	Сиковицы	3	32	1837	28.684842	28.701982000000001	58.438564	58.421672000000001	0103000020E610000001000000050000005FED28CE51AF3C40C8D11C59F9354D405FED28CE51AF3C40FA997ADD22384D407461A417B5B33C40FA997ADD22384D407461A417B5B33C40C8D11C59F9354D405FED28CE51AF3C40C8D11C59F9354D40
28679	Ротный Двор	3	32	1837	28.836926999999999	28.864388000000002	58.016323999999997	58.004528000000001	0103000020E61000000100000005000000AF230ED940D63C4049F59D5F94004D40AF230ED940D63C40E811A3E716024D400B0E2F8848DD3C40E811A3E716024D400B0E2F8848DD3C4049F59D5F94004D40AF230ED940D63C4049F59D5F94004D40
57438	Ровное	3	32	1837	28.786756	28.811845999999999	58.348390999999999	58.336153000000003	0103000020E6100000010000000500000089EE59D768C93C40E5B9BE0F072B4D4089EE59D768C93C40419C8713982C4D406F63B323D5CF3C40419C8713982C4D406F63B323D5CF3C40E5B9BE0F072B4D4089EE59D768C93C40E5B9BE0F072B4D40
46524	Пятчино	3	32	1837	29.214614000000001	29.237017999999999	58.380104000000003	58.370401999999999	0103000020E6100000010000000500000085436FF1F0363D40BE2F2E55692F4D4085436FF1F0363D40168A743FA7304D4036902E36AD3C3D40168A743FA7304D4036902E36AD3C3D40BE2F2E55692F4D4085436FF1F0363D40BE2F2E55692F4D40
46620	Погорелка	3	32	1837	28.743511000000002	28.752044999999999	58.480223000000002	58.476562000000001	0103000020E610000001000000050000005D37A5BC56BE3C401842CEFBFF3C4D405D37A5BC56BE3C40BDE47FF2773D4D40CD1E680586C03C40BDE47FF2773D4D40CD1E680586C03C401842CEFBFF3C4D405D37A5BC56BE3C401842CEFBFF3C4D40
46594	Новоселье	3	32	1837	28.848614000000001	28.89847	58.121536999999996	58.088383	0103000020E6100000010000000500000081ED60C43ED93C40DD425722500B4D4081ED60C43ED93C40812040868E0F4D40E76F422102E63C40812040868E0F4D40E76F422102E63C40DD425722500B4D4081ED60C43ED93C40DD425722500B4D40
49214	Молоди	3	32	1837	28.698136999999999	28.728967000000001	58.026466999999997	58.018560000000001	0103000020E61000000100000005000000A7203F1BB9B23C40C381902C60024D40A7203F1BB9B23C402CB6494563034D40FDDCD0949DBA3C402CB6494563034D40FDDCD0949DBA3C40C381902C60024D40A7203F1BB9B23C40C381902C60024D40
28779	Лудони	3	32	1837	29.325161000000001	29.375754000000001	58.232906999999997	58.211584000000002	0103000020E6100000010000000500000046EF54C03D533D40AE2D3C2F151B4D4046EF54C03D533D40360186E5CF1D4D405857056A31603D40360186E5CF1D4D405857056A31603D40AE2D3C2F151B4D4046EF54C03D533D40AE2D3C2F151B4D40
28714	Катежно	3	32	1837	29.043044999999999	29.066213000000001	58.096446	58.083530000000003	0103000020E610000001000000050000009E4143FF040B3D40111E6D1CB10A4D409E4143FF040B3D403EEAAF57580C4D40EF91CD55F3103D403EEAAF57580C4D40EF91CD55F3103D40111E6D1CB10A4D409E4143FF040B3D40111E6D1CB10A4D40
46615	Заполье	3	32	1837	28.942578000000001	28.957939	58.260263999999999	58.25356	0103000020E61000000100000005000000D9EDB3CA4CF13C4071C971A774204D40D9EDB3CA4CF13C40BF29AC5450214D401D90847D3BF53C40BF29AC5450214D401D90847D3BF53C4071C971A774204D40D9EDB3CA4CF13C4071C971A774204D40
59091	Заклинье	3	32	1837	28.863714000000002	28.867864999999998	58.149973000000003	58.147703	0103000020E61000000100000005000000EC18575C1CDD3C40B34291EEE7124D40EC18575C1CDD3C403A24B55032134D40D15790662CDE3C403A24B55032134D40D15790662CDE3C40B34291EEE7124D40EC18575C1CDD3C40B34291EEE7124D40
40389	Загорье	3	32	1837	28.709941000000001	28.713875999999999	58.470925000000001	58.466805999999998	0103000020E61000000100000005000000EC1681B1BEB53C40CDC98B4CC03B4D40EC1681B1BEB53C4035EF3845473C4D403866D993C0B63C4035EF3845473C4D403866D993C0B63C40CDC98B4CC03B4D40EC1681B1BEB53C40CDC98B4CC03B4D40
46556	Ждани	3	32	1837	28.942613999999999	28.965215000000001	58.406258000000001	58.393988	0103000020E6100000010000000500000072C0AE264FF13C401B82E3326E324D4072C0AE264FF13C4083DE1B4300344D40D09B8A5418F73C4083DE1B4300344D40D09B8A5418F73C401B82E3326E324D4072C0AE264FF13C401B82E3326E324D40
57413	Чернея	3	32	72	28.533556999999998	28.552645999999999	56.255772999999998	56.243665	0103000020E61000000100000005000000478D093197883C4005172B6A301F4C40478D093197883C4093196F2BBD204C40E54350357A8D3C4093196F2BBD204C40E54350357A8D3C4005172B6A301F4C40478D093197883C4005172B6A301F4C40
31866	Ульяновщина	3	32	72	28.515931999999999	28.520665999999999	56.296894000000002	56.293391999999997	0103000020E61000000100000005000000BAF59A1E14843C403A747ADE8D254C40BAF59A1E14843C407730629F00264C409E23F25D4A853C407730629F00264C409E23F25D4A853C403A747ADE8D254C40BAF59A1E14843C403A747ADE8D254C40
52753	Томсино	3	32	72	28.523171999999999	28.548037999999998	56.455747000000002	56.444563000000002	0103000020E61000000100000005000000D32EA699EE853C407E01BD70E7384C40D32EA699EE853C400420EEEA553A4C401AF7E6374C8C3C400420EEEA553A4C401AF7E6374C8C3C407E01BD70E7384C40D32EA699EE853C407E01BD70E7384C40
31886	Техомичи	3	32	72	28.446887	28.464746000000002	56.306252999999998	56.294401000000001	0103000020E61000000100000005000000EF01BA2F67723C40717495EEAE254C40EF01BA2F67723C40A4A65D4C33274C4063F20698F9763C40A4A65D4C33274C4063F20698F9763C40717495EEAE254C40EF01BA2F67723C40717495EEAE254C40
453	Сутоки	3	32	72	29.107589000000001	29.13841	56.242958999999999	56.228431	0103000020E61000000100000005000000CB68E4F38A1B3D4040321D3A3D1D4C40CB68E4F38A1B3D406AA2CF47191F4C407A7077D66E233D406AA2CF47191F4C407A7077D66E233D4040321D3A3D1D4C40CB68E4F38A1B3D4040321D3A3D1D4C40
31561	Себеж	3	32	72	28.458053	28.507344	56.305993000000001	56.266751999999997	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
52740	Осыно	3	32	72	28.670855	28.687142000000001	56.154485000000001	56.142434999999999	0103000020E61000000100000005000000AB5B3D27BDAB3C402367614F3B124C40AB5B3D27BDAB3C407D5C1B2AC6134C4042B5C189E8AF3C407D5C1B2AC6134C4042B5C189E8AF3C402367614F3B124C40AB5B3D27BDAB3C402367614F3B124C40
704	Мостище	3	32	72	28.761109000000001	28.769742000000001	56.292577999999999	56.288156000000001	0103000020E61000000100000005000000F7B0170AD8C23C40B612BA4BE2244C40F7B0170AD8C23C40B9C3263273254C408E5BCCCF0DC53C40B9C3263273254C408E5BCCCF0DC53C40B612BA4BE2244C40F7B0170AD8C23C40B612BA4BE2244C40
51966	Лопатово	3	32	72	29.171144999999999	29.180883000000001	56.146081000000002	56.142992	0103000020E61000000100000005000000B9DFA128D02B3D4079CBD58F4D124C40B9DFA128D02B3D4093C83EC8B2124C40026729594E2E3D4093C83EC8B2124C40026729594E2E3D4079CBD58F4D124C40B9DFA128D02B3D4079CBD58F4D124C40
31813	Кузнецовка	3	32	72	28.548459999999999	28.556076999999998	56.314256999999998	56.305694000000003	0103000020E61000000100000005000000062AE3DF678C3C40AE4A22FB20274C40062AE3DF678C3C4000C5C89239284C40CB0EF10F5B8E3C4000C5C89239284C40CB0EF10F5B8E3C40AE4A22FB20274C40062AE3DF678C3C40AE4A22FB20274C40
57461	Кортеньки	3	32	72	28.125623000000001	29.277892000000001	56.542499999999997	55.954531000000003	0103000020E610000001000000050000001BA034D428203C40540262122EFA4B401BA034D428203C403D0AD7A370454C40EED11BEE23473D403D0AD7A370454C40EED11BEE23473D40540262122EFA4B401BA034D428203C40540262122EFA4B40
632	Кицково	3	32	72	28.796026000000001	28.805880999999999	56.413488000000001	56.403801000000001	0103000020E6100000010000000500000005C4245CC8CB3C40CA8B4CC0AF334C4005C4245CC8CB3C40ECA4BE2CED344C40C0779B374ECE3C40ECA4BE2CED344C40C0779B374ECE3C40CA8B4CC0AF334C4005C4245CC8CB3C40CA8B4CC0AF334C40
522	Исаково	3	32	72	29.054247	29.067228	56.329931000000002	56.318561000000003	0103000020E61000000100000005000000F7E7A221E30D3D40FA635A9BC6284C40F7E7A221E30D3D40E277D32D3B2A4C402060ADDA35113D40E277D32D3B2A4C402060ADDA35113D40FA635A9BC6284C40F7E7A221E30D3D40FA635A9BC6284C40
191	Идрица	3	32	72	28.867370999999999	28.901399000000001	56.343563000000003	56.32208	0103000020E61000000100000005000000B27F9E060CDE3C400C59DDEA39294C40B27F9E060CDE3C40CE8E54DFF92B4C40A9A5B915C2E63C40CE8E54DFF92B4C40A9A5B915C2E63C400C59DDEA39294C40B27F9E060CDE3C400C59DDEA39294C40
52738	Заситино	3	32	72	28.234894000000001	28.249635000000001	56.363379000000002	56.359689000000003	0103000020E61000000100000005000000D1066003223C3C4090DD054A0A2E4C40D1066003223C3C40CF86FC33832E4C40DDEF5014E83F3C40CF86FC33832E4C40DDEF5014E83F3C4090DD054A0A2E4C40D1066003223C3C4090DD054A0A2E4C40
45659	Дубровка	3	32	72	28.623981000000001	28.653033000000001	56.397005999999998	56.381853	0103000020E610000001000000050000004C530438BD9F3C409370218FE0304C404C530438BD9F3C406B28B517D1324C407235B22B2DA73C406B28B517D1324C407235B22B2DA73C409370218FE0304C404C530438BD9F3C409370218FE0304C40
4217	Долосцы	3	32	72	28.706931999999998	28.726901000000002	56.059292999999997	56.051371000000003	0103000020E61000000100000005000000F17EDC7EF9B43C403E7B2E5393064C40F17EDC7EF9B43C40DCF0BBE996074C40016E162F16BA3C40DCF0BBE996074C40016E162F16BA3C403E7B2E5393064C40F17EDC7EF9B43C403E7B2E5393064C40
52735	Дедино	3	32	72	28.239493	28.266793	56.251466999999998	56.235745999999999	0103000020E61000000100000005000000F59ECA694F3D3C40D714C8EC2C1E4C40F59ECA694F3D3C40F982161230204C403ECDC98B4C443C40F982161230204C403ECDC98B4C443C40D714C8EC2C1E4C40F59ECA694F3D3C40D714C8EC2C1E4C40
52750	Глембочино	3	32	72	28.369938000000001	28.390608	56.189985999999998	56.181955000000002	0103000020E61000000100000005000000338CBB41B45E3C40FE2B2B4D4A174C40338CBB41B45E3C405359147651184C40548EC9E2FE633C405359147651184C40548EC9E2FE633C40FE2B2B4D4A174C40338CBB41B45E3C40FE2B2B4D4A174C40
763	Галузино	3	32	72	28.903959	28.923469999999998	56.253157000000002	56.243319	0103000020E61000000100000005000000C4EC65DB69E73C406ABFB513251F4C40C4EC65DB69E73C4072E0D57267204C404DD6A88768EC3C4072E0D57267204C404DD6A88768EC3C406ABFB513251F4C40C4EC65DB69E73C406ABFB513251F4C40
87	Бояриново	3	32	72	28.863606999999998	28.889531999999999	56.148643999999997	56.132252999999999	0103000020E61000000100000005000000BF982D5915DD3C4021E692AAED104C40BF982D5915DD3C40915F3FC406134C40D7BE805EB8E33C40915F3FC406134C40D7BE805EB8E33C4021E692AAED104C40BF982D5915DD3C4021E692AAED104C40
48631	Борки	3	32	72	28.776174000000001	28.787448000000001	56.272015000000003	56.267992	0103000020E610000001000000050000006901DA56B3C63C4079CBD58F4D224C406901DA56B3C63C40BF823463D1224C40F54C2F3196C93C40BF823463D1224C40F54C2F3196C93C4079CBD58F4D224C406901DA56B3C63C4079CBD58F4D224C40
52754	Борисенки	3	32	72	28.279657	28.293536	56.425333000000002	56.418695999999997	0103000020E61000000100000005000000F418E59997473C40A67B9DD497354C40F418E59997473C406D74CE4F71364C40DB32E02C254B3C406D74CE4F71364C40DB32E02C254B3C40A67B9DD497354C40F418E59997473C40A67B9DD497354C40
107	Александрово	3	32	72	29.055064999999999	29.071064	56.108432000000001	56.094726000000001	0103000020E610000001000000050000007C2766BD180E3D405B0A48FB1F0C4C407C2766BD180E3D4081EB8A19E10D4C4046EC134031123D4081EB8A19E10D4C4046EC134031123D405B0A48FB1F0C4C407C2766BD180E3D405B0A48FB1F0C4C40
57462	д.Скорды	3	32	735	27.660295000000001	28.319533	57.353296999999998	56.820295999999999	0103000020E610000001000000050000005BB6D61709A93B4012859675FF684C405BB6D61709A93B4030630AD638AD4C4026FE28EACC513C4030630AD638AD4C4026FE28EACC513C4012859675FF684C405BB6D61709A93B4012859675FF684C40
20448	Стехны	3	32	735	28.010656000000001	28.038036999999999	57.128208999999998	57.118496	0103000020E610000001000000050000009581035ABA023C40795A7EE02A8F4C409581035ABA023C40C4060B2769904C40B709F7CABC093C40C4060B2769904C40B709F7CABC093C40795A7EE02A8F4C409581035ABA023C40795A7EE02A8F4C40
20212	Скангали	3	32	735	27.735844	27.750171999999999	56.905076999999999	56.894705000000002	0103000020E6100000010000000500000034F5BA4560BC3B40AA4885B185724C4034F5BA4560BC3B404FAE2990D9734C40FA5FAE450BC03B404FAE2990D9734C40FA5FAE450BC03B40AA4885B185724C4034F5BA4560BC3B40AA4885B185724C40
19855	Пыталово	3	32	735	27.890173999999998	27.944181	57.078394000000003	57.053710000000002	0103000020E61000000100000005000000DFBF7971E2E33B40EDBB22F8DF864C40DFBF7971E2E33B40F01989D0088A4C402C8194D8B5F13B40F01989D0088A4C402C8194D8B5F13B40EDBB22F8DF864C40DFBF7971E2E33B40EDBB22F8DF864C40
47844	Мирный	3	32	735	27.961051000000001	27.976583000000002	57.322408000000003	57.310281000000003	0103000020E61000000100000005000000C1C9367007F63B40FCC8AD49B7A74C40C1C9367007F63B4001FC53AA44A94C405FD4EE5701FA3B4001FC53AA44A94C405FD4EE5701FA3B40FCC8AD49B7A74C40C1C9367007F63B40FCC8AD49B7A74C40
52307	Линово	3	32	735	27.962174000000001	27.996759000000001	57.257084999999996	57.248482000000003	0103000020E61000000100000005000000BF0F070951F63B4085D21742CE9F4C40BF0F070951F63B4065A54929E8A04C4061FE0A992BFF3B4065A54929E8A04C4061FE0A992BFF3B4085D21742CE9F4C40BF0F070951F63B4085D21742CE9F4C40
46431	Карпово	3	32	735	27.806298999999999	27.811554000000001	57.120660999999998	57.116149999999998	0103000020E6100000010000000500000029CC7B9C69CE3B4017B7D100DE8E4C4029CC7B9C69CE3B408A73D4D1718F4C4020F0C000C2CF3B408A73D4D1718F4C4020F0C000C2CF3B4017B7D100DE8E4C4029CC7B9C69CE3B4017B7D100DE8E4C40
20333	Емилово	3	32	735	27.976790000000001	27.990642000000001	57.008490000000002	56.998809000000001	0103000020E61000000100000005000000520FD1E80EFA3B40A9F92AF9D87F4C40520FD1E80EFA3B40E92B483316814C40460BD0B69AFD3B40E92B483316814C40460BD0B69AFD3B40A9F92AF9D87F4C40520FD1E80EFA3B40A9F92AF9D87F4C40
20103	Вышгородок	3	32	735	27.998835	28.016504000000001	57.044353999999998	57.028838999999998	0103000020E61000000100000005000000A4198BA6B3FF3B40B7EC10FFB0834C40A4198BA6B3FF3B4030B95164AD854C40D1402C9B39043C4030B95164AD854C40D1402C9B39043C40B7EC10FFB0834C40A4198BA6B3FF3B40B7EC10FFB0834C40
20413	Бороусы	3	32	735	28.097712000000001	28.116728999999999	57.012352	57.003255000000003	0103000020E61000000100000005000000406D54A703193C403546EBA86A804C40406D54A703193C40250516C094814C40AA7EA5F3E11D3C40250516C094814C40AA7EA5F3E11D3C403546EBA86A804C40406D54A703193C403546EBA86A804C40
20582	Белорусский	3	32	735	27.823132999999999	27.857233000000001	57.012734000000002	56.993955	0103000020E61000000100000005000000244223D8B8D23B400C59DDEA397F4C40244223D8B8D23B400DC68844A1814C404E0D349F73DB3B400DC68844A1814C404E0D349F73DB3B400C59DDEA397F4C40244223D8B8D23B400C59DDEA397F4C40
45615	Сорокино	3	32	1618	28.644984000000001	28.649826000000001	56.917087000000002	56.914414000000001	0103000020E610000001000000050000007A71E2AB1DA53C40958098840B754C407A71E2AB1DA53C401B4B581B63754C402B172AFF5AA63C401B4B581B63754C402B172AFF5AA63C40958098840B754C407A71E2AB1DA53C40958098840B754C40
20226	Пушкинские Горы	3	32	1618	28.876165	28.945964	57.030377000000001	57.011989	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
21337	Поляне	3	32	1618	28.87595	28.917542000000001	56.893289000000003	56.869377	0103000020E6100000010000000500000063EE5A423EE03C408272DBBE476F4C4063EE5A423EE03C403370404B57724C40D9B45208E4EA3C403370404B57724C40D9B45208E4EA3C408272DBBE476F4C4063EE5A423EE03C408272DBBE476F4C40
21210	Подкрестье	3	32	1618	28.857534000000001	28.876435000000001	56.991832000000002	56.985157000000001	0103000020E610000001000000050000004435255987DB3C407636E49F197E4C404435255987DB3C402A90D959F47E4C40DC114E0B5EE03C402A90D959F47E4C40DC114E0B5EE03C407636E49F197E4C404435255987DB3C407636E49F197E4C40
47780	Носово	3	32	1618	28.874072000000002	28.886424000000002	57.075830000000003	57.069068000000001	0103000020E610000001000000050000006D59BE2EC3DF3C409E996038D7884C406D59BE2EC3DF3C40210725CCB4894C40B763EAAEECE23C40210725CCB4894C40B763EAAEECE23C409E996038D7884C406D59BE2EC3DF3C409E996038D7884C40
21134	Козляки	3	32	1618	28.959285999999999	28.978959	57.05115	57.040050000000001	0103000020E61000000100000005000000BA826DC493F53C40371AC05B20854C40BA826DC493F53C405F984C158C864C40F71F990E9DFA3C405F984C158C864C40F71F990E9DFA3C40371AC05B20854C40BA826DC493F53C40371AC05B20854C40
48069	Исса	3	32	1618	28.655988000000001	28.688184	56.921228999999997	56.908881000000001	0103000020E6100000010000000500000086915ED4EEA73C40577A6D3656744C4086915ED4EEA73C403A90F5D4EA754C4066A19DD32CB03C403A90F5D4EA754C4066A19DD32CB03C40577A6D3656744C4086915ED4EEA73C40577A6D3656744C40
21291	Горелик	3	32	1618	28.883261999999998	28.913715	56.948298000000001	56.936960999999997	0103000020E61000000100000005000000AFCC5B751DE23C4050508A56EE774C40AFCC5B751DE23C405D6E30D461794C4059DDEA39E9E93C405D6E30D461794C4059DDEA39E9E93C4050508A56EE774C40AFCC5B751DE23C4050508A56EE774C40
49365	Богданово	3	32	1618	28.924745999999999	28.941374	56.886060999999998	56.879240000000003	0103000020E61000000100000005000000581B6327BCEC3C40E3AAB2EF8A704C40581B6327BCEC3C406AA164726A714C40014EEFE2FDF03C406AA164726A714C40014EEFE2FDF03C40E3AAB2EF8A704C40581B6327BCEC3C40E3AAB2EF8A704C40
21089	Блажи	3	32	1618	28.878627000000002	28.887869999999999	57.086244999999998	57.081735000000002	0103000020E61000000100000005000000F261F6B2EDE03C4023F8DF4A768A4C40F261F6B2EDE03C40C5387F130A8B4C407A19C5724BE33C40C5387F130A8B4C407A19C5724BE33C4023F8DF4A768A4C40F261F6B2EDE03C4023F8DF4A768A4C40
52895	Яссы	3	32	515	29.226230000000001	29.252289999999999	56.421334999999999	56.413991000000003	0103000020E61000000100000005000000C45F9335EA393D404FEB36A8FD344C40C45F9335EA393D4080D4264EEE354C409B1BD31396403D4080D4264EEE354C409B1BD31396403D404FEB36A8FD344C40C45F9335EA393D404FEB36A8FD344C40
23534	Щукино	3	32	515	29.276364999999998	29.299890999999999	56.592100000000002	56.578358999999999	0103000020E6100000010000000500000050C24CDBBF463D40732CEFAA074A4C4050C24CDBBF463D4016FBCBEEC94B4C405F5D15A8C54C3D4016FBCBEEC94B4C405F5D15A8C54C3D40732CEFAA074A4C4050C24CDBBF463D40732CEFAA074A4C40
3933	Шалахово	3	32	515	29.289624	29.307976	56.145389000000002	56.129919999999998	0103000020E61000000100000005000000FF2268CC244A3D40548CF337A1104C40FF2268CC244A3D405D19541B9C124C40F1F3DF83D74E3D405D19541B9C124C40F1F3DF83D74E3D40548CF337A1104C40FF2268CC244A3D40548CF337A1104C40
23310	Чурилово	3	32	515	29.658194000000002	29.672234	56.519297000000002	56.509940999999998	0103000020E61000000100000005000000666CE8667FA83D40DCF126BF45414C40666CE8667FA83D4099F4F75278424C405F42058717AC3D4099F4F75278424C405F42058717AC3D40DCF126BF45414C40666CE8667FA83D40DCF126BF45414C40
46303	Сопки	3	32	515	29.618254	29.623850999999998	56.546196999999999	56.542262000000001	0103000020E61000000100000005000000069FE6E4459E3D4089EE59D768454C40069FE6E4459E3D402F1686C8E9454C40AF93FAB2B49F3D402F1686C8E9454C40AF93FAB2B49F3D4089EE59D768454C40069FE6E4459E3D4089EE59D768454C40
23381	Соино	3	32	515	29.248149000000002	29.277604	56.350546999999999	56.341104000000001	0103000020E61000000100000005000000FD885FB1863F3D407444BE4BA92B4C40FD885FB1863F3D40FF5A5EB9DE2C4C40213D450E11473D40FF5A5EB9DE2C4C40213D450E11473D407444BE4BA92B4C40FD885FB1863F3D407444BE4BA92B4C40
3481	Сергейцево	3	32	515	29.270462999999999	29.296082999999999	56.256937999999998	56.244795000000003	0103000020E610000001000000050000002EC72B103D453D40B79C4B71551F4C402EC72B103D453D40C18C2958E3204C40CDE67118CC4B3D40C18C2958E3204C40CDE67118CC4B3D40B79C4B71551F4C402EC72B103D453D40B79C4B71551F4C40
23227	Ребле	3	32	515	29.624362999999999	29.639624999999999	56.326676999999997	56.311641000000002	0103000020E610000001000000050000001BD5E940D69F3D40DF8B2FDAE3274C401BD5E940D69F3D407DAD4B8DD0294C4039B4C876BEA33D407DAD4B8DD0294C4039B4C876BEA33D40DF8B2FDAE3274C401BD5E940D69F3D40DF8B2FDAE3274C40
5169	Пустошка	3	32	515	29.334071999999999	29.397772	56.351160999999998	56.318052000000002	0103000020E6100000010000000500000062821ABE85553D40B5368DEDB5284C4062821ABE85553D40B950F9D7F22C4C40B743C362D4653D40B950F9D7F22C4C40B743C362D4653D40B5368DEDB5284C4062821ABE85553D40B5368DEDB5284C40
23027	Поддубье	3	32	515	29.303494000000001	29.332545	56.451478999999999	56.438298000000003	0103000020E61000000100000005000000408864C8B14D3D407CF31B261A384C40408864C8B14D3D4057EA5910CA394C40C5724BAB21553D4057EA5910CA394C40C5724BAB21553D407CF31B261A384C40408864C8B14D3D407CF31B261A384C40
29680	Ореховно	3	32	515	29.507097000000002	29.517741999999998	56.210132000000002	56.203271999999998	0103000020E6100000010000000500000054E6E61BD1813D40A41820D1041A4C4054E6E61BD1813D40EAEBF99AE51A4C4000C45DBD8A843D40EAEBF99AE51A4C4000C45DBD8A843D40A41820D1041A4C4054E6E61BD1813D40A41820D1041A4C40
3154	Криуха	3	32	515	29.403161999999998	29.427900999999999	56.517485000000001	56.505519999999997	0103000020E610000001000000050000006DFDF49F35673D40A9BC1DE1B4404C406DFDF49F35673D40D595CFF23C424C40FAEC80EB8A6D3D40D595CFF23C424C40FAEC80EB8A6D3D40A9BC1DE1B4404C406DFDF49F35673D40A9BC1DE1B4404C40
23598	Красное	3	32	515	29.339561	29.356224999999998	56.590786000000001	56.582250999999999	0103000020E610000001000000050000003FFF3D78ED563D401A886533874A4C403FFF3D78ED563D40A3772AE09E4B4C408104C58F315B3D40A3772AE09E4B4C408104C58F315B3D401A886533874A4C403FFF3D78ED563D401A886533874A4C40
3423	Копылок	3	32	515	29.454006	29.478611000000001	56.414015999999997	56.394550000000002	0103000020E610000001000000050000001230BABC39743D408351499D80324C401230BABC39743D40A702EE79FE344C4080812040867A3D40A702EE79FE344C4080812040867A3D408351499D80324C401230BABC39743D408351499D80324C40
3990	Забелевица	3	32	515	29.595725000000002	29.615514999999998	56.360826000000003	56.345424000000001	0103000020E61000000100000005000000DC68006F81983D4073A087DA362C4C40DC68006F81983D40F4C5DE8B2F2E4C408B321B64929D3D40F4C5DE8B2F2E4C408B321B64929D3D4073A087DA362C4C40DC68006F81983D4073A087DA362C4C40
23352	Долосцы	3	32	515	29.327425000000002	29.337675000000001	56.329616999999999	56.324800000000003	0103000020E610000001000000050000008FE4F21FD2533D40D3DEE00B93294C408FE4F21FD2533D40529ACDE3302A4C4043AD69DE71563D40529ACDE3302A4C4043AD69DE71563D40D3DEE00B93294C408FE4F21FD2533D40D3DEE00B93294C40
23061	Гультяи	3	32	515	29.467355000000001	29.485752999999999	56.242058999999998	56.230072	0103000020E61000000100000005000000419FC893A4773D40D7DCD1FF721D4C40419FC893A4773D40EA5910CAFB1E4C4013EF004F5A7C3D40EA5910CAFB1E4C4013EF004F5A7C3D40D7DCD1FF721D4C40419FC893A4773D40D7DCD1FF721D4C40
4032	Алушково	3	32	515	29.61158	29.631657000000001	56.412885000000003	56.398775000000001	0103000020E610000001000000050000003FE3C281909C3D4030BB270F0B334C403FE3C281909C3D4026016A6AD9344C401B4AED45B4A13D4026016A6AD9344C401B4AED45B4A13D4030BB270F0B334C403FE3C281909C3D4030BB270F0B334C40
22915	Алоль	3	32	515	29.104255999999999	29.120920000000002	56.459383000000003	56.449204999999999	0103000020E610000001000000050000006A696E85B01A3D408F19A88C7F394C406A696E85B01A3D4050ABE80FCD3A4C40AD6EF59CF41E3D4050ABE80FCD3A4C40AD6EF59CF41E3D408F19A88C7F394C406A696E85B01A3D408F19A88C7F394C40
45724	Чернецово	3	32	1171	28.184201999999999	28.191109999999998	57.776020000000003	57.772463999999999	0103000020E6100000010000000500000098DBBDDC272F3C402EABB019E0E24C4098DBBDDC272F3C405E85949F54E34C4045F0BF95EC303C405E85949F54E34C4045F0BF95EC303C402EABB019E0E24C4098DBBDDC272F3C402EABB019E0E24C40
46965	Чернево	3	32	1171	28.200982	28.210387999999998	57.974724999999999	57.970323999999998	0103000020E61000000100000005000000AD156D8E73333C400F43AB9333FC4C40AD156D8E73333C40FBCBEEC9C3FC4C408978EBFCDB353C40FBCBEEC9C3FC4C408978EBFCDB353C400F43AB9333FC4C40AD156D8E73333C400F43AB9333FC4C40
57386	Череха	3	32	1171	27.525836000000002	29.252998999999999	58.290297000000002	57.495514999999997	0103000020E61000000100000005000000390F27309D863B40B6D617096DBF4C40390F27309D863B403F90BC7328254D40B3EBDE8AC4403D403F90BC7328254D40B3EBDE8AC4403D40B6D617096DBF4C40390F27309D863B40B6D617096DBF4C40
52044	Тямша	3	32	1171	28.137129999999999	28.159040000000001	57.750652000000002	57.736721000000003	0103000020E61000000100000005000000EC4CA1F31A233C4062A3ACDF4CDE4C40EC4CA1F31A233C40A8565F5D15E04C407FC16ED8B6283C40A8565F5D15E04C407FC16ED8B6283C4062A3ACDF4CDE4C40EC4CA1F31A233C4062A3ACDF4CDE4C40
52036	Торошино	3	32	1171	28.579765999999999	28.611772999999999	57.946888999999999	57.922792999999999	0103000020E610000001000000050000002E55698B6B943C4026FDBD141EF64C402E55698B6B943C4098F8A3A833F94C406893C3279D9C3C4098F8A3A833F94C406893C3279D9C3C4026FDBD141EF64C402E55698B6B943C4026FDBD141EF64C40
57430	Теребище	3	32	1171	28.259238	28.276458999999999	57.982604000000002	57.973899000000003	0103000020E6100000010000000500000065E1EB6B5D423C40B64DF1B8A8FC4C4065E1EB6B5D423C409B75C6F7C5FD4C4053AF5B04C6463C409B75C6F7C5FD4C4053AF5B04C6463C40B64DF1B8A8FC4C4065E1EB6B5D423C40B64DF1B8A8FC4C40
52066	Стремутка	3	32	1171	28.299652999999999	28.334409000000001	57.668841999999998	57.645420999999999	0103000020E61000000100000005000000F6251B0FB64C3C406893C3279DD24C40F6251B0FB64C3C407A185A9D9CD54C40F27C06D49B553C407A185A9D9CD54C40F27C06D49B553C406893C3279DD24C40F6251B0FB64C3C406893C3279DD24C40
52016	Спасовщина	3	32	1171	28.197937	28.213936	58.222268999999997	58.200127999999999	0103000020E6100000010000000500000019ABCDFFAB323C40C78157CB9D194D4019ABCDFFAB323C4012F5824F731C4D40E36F7B82C4363C4012F5824F731C4D40E36F7B82C4363C40C78157CB9D194D4019ABCDFFAB323C40C78157CB9D194D40
52063	Соловьи	3	32	1171	28.322541999999999	28.345556999999999	57.689895	57.679997999999998	0103000020E610000001000000050000002096CD1C92523C4036ACA92C0AD74C402096CD1C92523C404356B77A4ED84C4064E76D6C76583C404356B77A4ED84C4064E76D6C76583C4036ACA92C0AD74C402096CD1C92523C4036ACA92C0AD74C40
52026	Середка	3	32	1171	28.160639	28.208653999999999	58.175049999999999	58.145274999999998	0103000020E610000001000000050000004F7633A31F293C4094F6065F98124D404F7633A31F293C401895D40968164D40F92D3A596A353C401895D40968164D40F92D3A596A353C4094F6065F98124D404F7633A31F293C4094F6065F98124D40
57440	Селихново	3	32	1171	28.907551999999999	28.920397999999999	57.697837	57.684358000000003	0103000020E610000001000000050000005D6BEF5355E83C40C460FE0A99D74C405D6BEF5355E83C4029780AB952D94C40C64D0D349FEB3C4029780AB952D94C40C64D0D349FEB3C40C460FE0A99D74C405D6BEF5355E83C40C460FE0A99D74C40
48560	Родина	3	32	1171	28.238002000000002	28.282261999999999	57.839688000000002	57.820084000000001	0103000020E61000000100000005000000F261F6B2ED3C3C4087FC3383F8E84C40F261F6B2ED3C3C40FD6B79E57AEB4C404FE78A5242483C40FD6B79E57AEB4C404FE78A5242483C4087FC3383F8E84C40F261F6B2ED3C3C4087FC3383F8E84C40
52060	Похвальщина	3	32	1171	28.439036000000002	28.464691999999999	57.720146999999997	57.708489	0103000020E6100000010000000500000044C4CDA964703C40B2497EC4AFDA4C4044C4CDA964703C4000A8E2C62DDC4C407CB60E0EF6763C4000A8E2C62DDC4C407CB60E0EF6763C40B2497EC4AFDA4C4044C4CDA964703C40B2497EC4AFDA4C40
57432	Подборовье	3	32	1171	28.514800000000001	28.526154999999999	57.852730999999999	57.846716000000001	0103000020E6100000010000000500000016FBCBEEC9833C40FE7F9C3061EC4C4016FBCBEEC9833C4087A4164A26ED4C407BA01518B2863C4087A4164A26ED4C407BA01518B2863C40FE7F9C3061EC4C4016FBCBEEC9833C40FE7F9C3061EC4C40
51995	Писковичи	3	32	1171	28.196805000000001	28.224374999999998	57.864984	57.858055999999998	0103000020E6100000010000000500000075B0FECF61323C407B116DC7D4ED4C4075B0FECF61323C4019C8B3CBB7EE4C403D0AD7A370393C4019C8B3CBB7EE4C403D0AD7A370393C407B116DC7D4ED4C4075B0FECF61323C407B116DC7D4ED4C40
57456	Остров Залит	3	32	1171	28.058806000000001	28.080311999999999	58.014555000000001	58.009306000000002	0103000020E61000000100000005000000FFCEF6E80D0F3C400BD462F030014D40FFCEF6E80D0F3C40247F30F0DC014D40F279C5538F143C40247F30F0DC014D40F279C5538F143C400BD462F030014D40FFCEF6E80D0F3C400BD462F030014D40
51988	Неелово 1-е	3	32	1171	28.193904	28.209866999999999	57.805643000000003	57.789110000000001	0103000020E6100000010000000500000047904AB1A3313C402979758E01E54C4047904AB1A3313C402CA0504F1FE74C407782FDD7B9353C402CA0504F1FE74C407782FDD7B9353C402979758E01E54C4047904AB1A3313C402979758E01E54C40
52021	Мельницы	3	32	1171	28.266991000000001	28.287822999999999	58.165163	58.15419	0103000020E610000001000000050000008B53AD8559443C4064AF777FBC134D408B53AD8559443C402FC1A90F24154D405F09A4C4AE493C402FC1A90F24154D405F09A4C4AE493C4064AF777FBC134D408B53AD8559443C4064AF777FBC134D40
52039	Крипецкое 1	3	32	1171	28.574466000000001	28.586404999999999	57.963016000000003	57.959721000000002	0103000020E61000000100000005000000F8A92A3410933C4068244223D8FA4C40F8A92A3410933C402BC3B81B44FB4C40FC3559A31E963C402BC3B81B44FB4C40FC3559A31E963C4068244223D8FA4C40F8A92A3410933C4068244223D8FA4C40
51979	Кирово	3	32	1171	28.472335999999999	28.495377999999999	57.606591999999999	57.597791000000001	0103000020E6100000010000000500000034B91803EB783C40EC6B5D6A84CC4C4034B91803EB783C40F30181CEA4CD4C406B28B517D17E3C40F30181CEA4CD4C406B28B517D17E3C40EC6B5D6A84CC4C4034B91803EB783C40EC6B5D6A84CC4C40
48663	Карамышево	3	32	1171	28.744966000000002	28.777674000000001	57.770356999999997	57.752366000000002	0103000020E61000000100000005000000C7A17E17B6BE3C40A94F72874DE04C40C7A17E17B6BE3C40519FE40E9BE24C4013F3ACA415C73C40519FE40E9BE24C4013F3ACA415C73C40A94F72874DE04C40C7A17E17B6BE3C40A94F72874DE04C40
51980	Зайцево	3	32	1171	28.573954000000001	28.760937999999999	57.652906000000002	57.608154999999996	0103000020E610000001000000050000008C683BA6EE923C400EF3E505D8CD4C408C683BA6EE923C405CAE7E6C92D34C409D4830D5CCC23C405CAE7E6C92D34C409D4830D5CCC23C400EF3E505D8CD4C408C683BA6EE923C400EF3E505D8CD4C40
57385	Ершово	3	32	1171	28.202383999999999	28.251459000000001	57.950037000000002	57.936593999999999	0103000020E61000000100000005000000D13B1570CF333C409ED0EB4FE2F74C40D13B1570CF333C40B77EFACF9AF94C40ED48F59D5F403C40B77EFACF9AF94C40ED48F59D5F403C409ED0EB4FE2F74C40D13B1570CF333C409ED0EB4FE2F74C40
57374	Дуброво	3	32	1171	28.119783999999999	28.141387999999999	57.811666000000002	57.795039000000003	0103000020E6100000010000000500000085950A2AAA1E3C40B40584D6C3E54C4085950A2AAA1E3C4038A3E6ABE4E74C40FE0B040132243C4038A3E6ABE4E74C40FE0B040132243C40B40584D6C3E54C4085950A2AAA1E3C40B40584D6C3E54C40
57410	Горнево	3	32	1171	27.525836000000002	29.252998999999999	58.290297000000002	57.495514999999997	0103000020E61000000100000005000000390F27309D863B40B6D617096DBF4C40390F27309D863B403F90BC7328254D40B3EBDE8AC4403D403F90BC7328254D40B3EBDE8AC4403D40B6D617096DBF4C40390F27309D863B40B6D617096DBF4C40
49420	Гоголево	3	32	1171	28.967578	28.974342	57.711132999999997	57.708964999999999	0103000020E610000001000000050000003F541A31B3F73C401B81785DBFDA4C403F541A31B3F73C409D0DF96706DB4C40861E317A6EF93C409D0DF96706DB4C40861E317A6EF93C401B81785DBFDA4C403F541A31B3F73C401B81785DBFDA4C40
52015	Гверздонь	3	32	1171	28.371734	28.382073999999999	58.125030000000002	58.110004000000004	0103000020E61000000100000005000000AFCF9CF5295F3C40F0366F9C140E4D40AFCF9CF5295F3C406B82A8FB00104D40E3A6069ACF613C406B82A8FB00104D40E3A6069ACF613C40F0366F9C140E4D40AFCF9CF5295F3C40F0366F9C140E4D40
57417	Выставка	3	32	1171	28.952898999999999	28.973721999999999	57.757489999999997	57.752313999999998	0103000020E610000001000000050000001F645930F1F33C4056293DD34BE04C401F645930F1F33C400586AC6EF5E04C404D6551D845F93C400586AC6EF5E04C404D6551D845F93C4056293DD34BE04C401F645930F1F33C4056293DD34BE04C40
52011	Верхолино	3	32	1171	28.244523999999998	28.265913000000001	58.024813000000002	58.015861000000001	0103000020E610000001000000050000004C16F71F993E3C401424B6BB07024D404C16F71F993E3C4001C287122D034D40CD94D6DF12443C4001C287122D034D40CD94D6DF12443C401424B6BB07024D404C16F71F993E3C401424B6BB07024D40
52005	Ваулино	3	32	1171	28.308168999999999	28.330331000000001	57.877538999999999	57.867747000000001	0103000020E610000001000000050000001AA4E029E44E3C40DF196D5512EF4C401AA4E029E44E3C4076FBAC3253F04C40E0DA899290543C4076FBAC3253F04C40E0DA899290543C40DF196D5512EF4C401AA4E029E44E3C40DF196D5512EF4C40
51962	Быстрецово	3	32	1171	28.823757000000001	28.851327000000001	57.706598999999997	57.702438999999998	0103000020E61000000100000005000000E0D91EBDE1D23C40AC376A85E9D94C40E0D91EBDE1D23C40723106D671DA4C40A933F790F0D93C40723106D671DA4C40A933F790F0D93C40AC376A85E9D94C40E0D91EBDE1D23C40AC376A85E9D94C40
51955	Большое Загорье	3	32	1171	28.907219999999999	28.943943000000001	57.857582000000001	57.849502999999999	0103000020E61000000100000005000000F146E6913FE83C404C6DA983BCEC4C40F146E6913FE83C40B3D1393FC5ED4C40C3499A3FA6F13C40B3D1393FC5ED4C40C3499A3FA6F13C404C6DA983BCEC4C40F146E6913FE83C404C6DA983BCEC4C40
52049	Адворицы	3	32	1171	27.999661	28.008922999999999	57.721978	57.712637999999998	0103000020E610000001000000050000002F1686C8E9FF3B4084F1D3B837DB4C402F1686C8E9FF3B403B376DC669DC4C40A52E19C748023C403B376DC669DC4C40A52E19C748023C4084F1D3B837DB4C402F1686C8E9FF3B4084F1D3B837DB4C40
57434	Ясно	3	32	601	29.459477	29.480129000000002	57.619855000000001	57.607889	0103000020E61000000100000005000000A243E048A0753D40904C874ECFCD4C40A243E048A0753D408CA19C6857CF4C4077DCF0BBE97A3D408CA19C6857CF4C4077DCF0BBE97A3D40904C874ECFCD4C40A243E048A0753D40904C874ECFCD4C40
52639	Шмойлово	3	32	601	28.930755999999999	28.947769999999998	57.595258999999999	57.583869999999997	0103000020E61000000100000005000000478E740646EE3C40C98E8D40BCCA4C40478E740646EE3C4028D3687231CC4C404221020EA1F23C4028D3687231CC4C404221020EA1F23C40C98E8D40BCCA4C40478E740646EE3C40C98E8D40BCCA4C40
57406	Хилово	3	32	601	29.369205000000001	29.385573000000001	57.778069000000002	57.765830000000001	0103000020E610000001000000050000000A850838845E3D40D925AAB706E24C400A850838845E3D400684D6C397E34C407A3881E9B4623D400684D6C397E34C407A3881E9B4623D40D925AAB706E24C400A850838845E3D40D925AAB706E24C40
52699	Турово	3	32	601	29.673805999999999	29.68853	57.706546000000003	57.700785000000003	0103000020E610000001000000050000003CD9CD8C7EAC3D408143A852B3D94C403CD9CD8C7EAC3D40508F6D1970DA4C409C50888043B03D40508F6D1970DA4C409C50888043B03D408143A852B3D94C403CD9CD8C7EAC3D408143A852B3D94C40
52670	Тинеи	3	32	601	29.245004000000002	29.251920999999999	57.429450000000003	57.424706	0103000020E61000000100000005000000A2630795B83E3D401E3526C45CB64C40A2630795B83E3D4034A2B437F8B64C40F52C08E57D403D4034A2B437F8B64C40F52C08E57D403D401E3526C45CB64C40A2630795B83E3D401E3526C45CB64C40
52659	Терептино	3	32	601	29.273776999999999	29.286425999999999	57.564163999999998	57.556584000000001	0103000020E61000000100000005000000A165DD3F16463D400ABDFE243EC74C40A165DD3F16463D404FCAA48636C84C405EB9DE3653493D404FCAA48636C84C405EB9DE3653493D400ABDFE243EC74C40A165DD3F16463D400ABDFE243EC74C40
57383	Сосновый Бор	3	32	601	29.42915	29.434737999999999	57.760635000000001	57.756943	0103000020E6100000010000000500000012143FC6DC6D3D40D3F71A82E3E04C4012143FC6DC6D3D40B398D87C5CE14C40155454FD4A6F3D40B398D87C5CE14C40155454FD4A6F3D40D3F71A82E3E04C4012143FC6DC6D3D40D3F71A82E3E04C40
52693	Славковичи	3	32	601	29.039702999999999	29.080908999999998	57.652076999999998	57.637563999999998	0103000020E61000000100000005000000978DCEF9290A3D40B08D78B29BD14C40978DCEF9290A3D40A5BC564277D34C40BAF3C473B6143D40A5BC564277D34C40BAF3C473B6143D40B08D78B29BD14C40978DCEF9290A3D40B08D78B29BD14C40
57394	Пуково	3	32	601	29.112241999999998	29.125133000000002	57.691560000000003	57.686556000000003	0103000020E61000000100000005000000D53C47E4BB1C3D40B16F2711E1D74C40D53C47E4BB1C3D40639CBF0985D84C407FA65EB708203D40639CBF0985D84C407FA65EB708203D40B16F2711E1D74C40D53C47E4BB1C3D40B16F2711E1D74C40
57371	Порхов	3	32	601	29.514526	29.581863999999999	57.782330999999999	57.750681	0103000020E6100000010000000500000013F1D6F9B7833D40425DA45016E04C4013F1D6F9B7833D40D0D2156C23E44C4041B8020AF5943D40D0D2156C23E44C4041B8020AF5943D40425DA45016E04C4013F1D6F9B7833D40425DA45016E04C40
57404	Попадинка	3	32	601	29.548760999999999	29.569089999999999	57.754883	57.738700999999999	0103000020E61000000100000005000000FC51D4997B8C3D40E1421EC18DDE4C40FC51D4997B8C3D4037A79201A0E04C400B7BDAE1AF913D4037A79201A0E04C400B7BDAE1AF913D40E1421EC18DDE4C40FC51D4997B8C3D40E1421EC18DDE4C40
52679	Полоное	3	32	601	29.620581000000001	29.645607999999999	57.784182999999999	57.774858999999999	0103000020E61000000100000005000000DC847B65DE9E3D40710168942EE34C40DC847B65DE9E3D40228AC91B60E44C403509DE9046A53D40228AC91B60E44C403509DE9046A53D40710168942EE34C40DC847B65DE9E3D40710168942EE34C40
52672	Павы	3	32	601	29.481845	29.517112999999998	58.055469000000002	58.041319000000001	0103000020E61000000100000005000000BABDA4315A7B3D400ADAE4F049054D40BABDA4315A7B3D408E78B29B19074D4021567F8461843D408E78B29B19074D4021567F8461843D400ADAE4F049054D40BABDA4315A7B3D400ADAE4F049054D40
52674	Моньшино	3	32	601	29.164497000000001	29.182328999999999	57.551369000000001	57.543086000000002	0103000020E61000000100000005000000454AB3791C2A3D402E7590D783C54C40454AB3791C2A3D409D83674293C64C40C51C041DAD2E3D409D83674293C64C40C51C041DAD2E3D402E7590D783C54C40454AB3791C2A3D402E7590D783C54C40
52657	Молочище	3	32	601	29.273040999999999	29.287251999999999	57.674771999999997	57.670349000000002	0103000020E610000001000000050000009677D503E6453D4002F4FBFECDD54C409677D503E6453D40D520CCED5ED64C40E9B5D95889493D40D520CCED5ED64C40E9B5D95889493D4002F4FBFECDD54C409677D503E6453D4002F4FBFECDD54C40
52644	Махновка	3	32	601	29.340136000000001	29.352919	57.405990000000003	57.400157	0103000020E610000001000000050000003831242713573D40FB21365838B34C403831242713573D406440F67AF7B34C4014234BE6585A3D406440F67AF7B34C4014234BE6585A3D40FB21365838B34C403831242713573D40FB21365838B34C40
57447	Логовино	3	32	601	29.645562999999999	29.656065000000002	57.657822000000003	57.649259999999998	0103000020E61000000100000005000000F581E49D43A53D40EC4CA1F31AD34C40F581E49D43A53D406F4BE48233D44C40DD0C37E0F3A73D406F4BE48233D44C40DD0C37E0F3A73D40EC4CA1F31AD34C40F581E49D43A53D40EC4CA1F31AD34C40
49351	Иваньково	3	32	601	29.629491999999999	29.636697000000002	58.055855000000001	58.053697999999997	0103000020E61000000100000005000000F817416326A13D4028EE7893DF064D40F817416326A13D40B728B34126074D4019761893FEA23D40B728B34126074D4019761893FEA23D4028EE7893DF064D40F817416326A13D4028EE7893DF064D40
52652	Дубровно	3	32	601	29.356152999999999	29.375736	57.928533000000002	57.922243999999999	0103000020E610000001000000050000004E5FCFD72C5B3D40537765170CF64C404E5FCFD72C5B3D40DE205A2BDAF64C400BEE073C30603D40DE205A2BDAF64C400BEE073C30603D40537765170CF64C404E5FCFD72C5B3D40537765170CF64C40
47144	Должицы	3	32	601	29.843057999999999	29.852041	57.994191999999998	57.990467000000002	0103000020E6100000010000000500000094A12AA6D2D73D403562669FC7FE4C4094A12AA6D2D73D40F0F8F6AE41FF4C40E4D9E55B1FDA3D40F0F8F6AE41FF4C40E4D9E55B1FDA3D403562669FC7FE4C4094A12AA6D2D73D403562669FC7FE4C40
57455	Гора	3	32	601	28.761872	28.78866	57.527307	57.517186000000002	0103000020E61000000100000005000000F5BC1B0B0AC33C407BF99D2633C24C40F5BC1B0B0AC33C40D7F9B7CB7EC34C40D2A92B9FE5C93C40D7F9B7CB7EC34C40D2A92B9FE5C93C407BF99D2633C24C40F5BC1B0B0AC33C407BF99D2633C24C40
52668	Волышово	3	32	601	29.675899000000001	29.699380999999999	57.632004000000002	57.616567000000003	0103000020E610000001000000050000002C6684B707AD3D407C65DEAAEBCE4C402C6684B707AD3D407978CF81E5D04C409B711AA20AB33D407978CF81E5D04C409B711AA20AB33D407C65DEAAEBCE4C402C6684B707AD3D407C65DEAAEBCE4C40
52641	Верхний Мост	3	32	601	28.856303	28.893449	57.520696000000001	57.50318	0103000020E61000000100000005000000797764AC36DB3C402A00C63368C04C40797764AC36DB3C403A94A12AA6C24C40D7A4DB12B9E43C403A94A12AA6C24C40D7A4DB12B9E43C402A00C63368C04C40797764AC36DB3C402A00C63368C04C40
57393	Боровичи	3	32	601	29.633642999999999	29.656351999999998	57.959004999999998	57.953246	0103000020E61000000100000005000000DE567A6D36A23D407B8505F703FA4C40DE567A6D36A23D40A9D903ADC0FA4C4008AA46AF06A83D40A9D903ADC0FA4C4008AA46AF06A83D407B8505F703FA4C40DE567A6D36A23D407B8505F703FA4C40
57448	Береза	3	32	601	29.688987999999998	29.707187999999999	58.030226999999996	58.018231	0103000020E6100000010000000500000021567F8461B03D40FE62B66455024D4021567F8461B03D40643A747ADE034D40A71FD4450AB53D40643A747ADE034D40A71FD4450AB53D40FE62B66455024D4021567F8461B03D40FE62B66455024D40
52683	Арбузова-Щилинка	3	32	601	29.676402	29.693452000000001	57.859310999999998	57.851734999999998	0103000020E61000000100000005000000F1F274AE28AD3D40E5ED08A705ED4C40F1F274AE28AD3D40E90B21E7FDED4C408658FD1186B13D40E90B21E7FDED4C408658FD1186B13D40E5ED08A705ED4C40F1F274AE28AD3D40E5ED08A705ED4C40
29783	Плюсса	3	32	1870	29.349658000000002	29.410672000000002	58.442332	58.411881999999999	0103000020E61000000100000005000000E7C8CA2F83593D40D1E7A38CB8344D40E7C8CA2F83593D40B5FCC0559E384D400762D9CC21693D40B5FCC0559E384D400762D9CC21693D40D1E7A38CB8344D40E7C8CA2F83593D40D1E7A38CB8344D40
29858	Нежадово	3	32	1870	29.293234999999999	29.313859999999998	58.573	58.559877	0103000020E61000000100000005000000E50AEF72114B3D402C64AE0CAA474D40E50AEF72114B3D40D34D621058494D40C685032159503D40D34D621058494D40C685032159503D402C64AE0CAA474D40E50AEF72114B3D402C64AE0CAA474D40
29613	Ляды	3	32	1870	28.763300999999998	28.81119	58.638595000000002	58.617297000000001	0103000020E610000001000000050000000C01C0B167C33C409F758D96034F4D400C01C0B167C33C40CF31207BBD514D409DD7D825AACF3C40CF31207BBD514D409DD7D825AACF3C409F758D96034F4D400C01C0B167C33C409F758D96034F4D40
29947	Курея	3	32	1870	29.357914000000001	29.375350000000001	58.391247	58.383685	0103000020E61000000100000005000000D2C77C40A05B3D409E7B0F971C314D40D2C77C40A05B3D403DD4B66114324D40B98D06F016603D403DD4B66114324D40B98D06F016603D409E7B0F971C314D40D2C77C40A05B3D409E7B0F971C314D40
29907	Кошелевицы	3	32	1870	29.398624999999999	29.423967000000001	58.499701000000002	58.490257	0103000020E61000000100000005000000355EBA490C663D404AD1CABDC03E4D40355EBA490C663D40A663CE33F63F4D404F95EF19896C3D40A663CE33F63F4D404F95EF19896C3D404AD1CABDC03E4D40355EBA490C663D404AD1CABDC03E4D40
29519	Заянье	3	32	1870	28.610956000000002	28.641076000000002	58.784661999999997	58.770065000000002	0103000020E61000000100000005000000844BC79C679C3C40AA656B7D91624D40844BC79C679C3C40FC34EECD6F644D402140868E1DA43C40FC34EECD6F644D402140868E1DA43C40AA656B7D91624D40844BC79C679C3C40AA656B7D91624D40
30081	Заплюсье	3	32	1870	29.72015	29.748726000000001	58.441719999999997	58.433255000000003	0103000020E61000000100000005000000E3361AC05BB83D400CEA5BE674374D40E3361AC05BB83D409BFEEC478A384D4037AAD381ACBF3D409BFEEC478A384D4037AAD381ACBF3D400CEA5BE674374D40E3361AC05BB83D400CEA5BE674374D40
29988	Андромер	3	32	1870	29.544969999999999	29.576474000000001	58.367975999999999	58.353099	0103000020E61000000100000005000000164D6727838B3D400AA01859322D4D40164D6727838B3D4040DB6AD6192F4D408BFED0CC93933D4040DB6AD6192F4D408BFED0CC93933D400AA01859322D4D40164D6727838B3D400AA01859322D4D40
13203	Ротово	3	32	488	27.536301000000002	27.558247000000001	57.649607000000003	57.637025000000001	0103000020E61000000100000005000000E6CFB7054B893B4001DE02098AD14C40E6CFB7054B893B4058207A5226D34C4012178046E98E3B4058207A5226D34C4012178046E98E3B4001DE02098AD14C40E6CFB7054B893B4001DE02098AD14C40
40473	Подлесье	3	32	488	27.703306999999999	27.715783999999999	57.767899	57.761983999999998	0103000020E61000000100000005000000410C74ED0BB43B40A20914B188E14C40410C74ED0BB43B40C8D0B1834AE24C400400C79E3DB73B40C8D0B1834AE24C400400C79E3DB73B40A20914B188E14C40410C74ED0BB43B40A20914B188E14C40
2921	Печоры	3	32	488	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
11897	Паниковичи	3	32	488	27.553063999999999	27.582906000000001	57.695374000000001	57.685896999999997	0103000020E610000001000000050000004E98309A958D3B4056B60F79CBD74C404E98309A958D3B408E3EE60302D94C4066A4DE5339953B408E3EE60302D94C4066A4DE5339953B4056B60F79CBD74C404E98309A958D3B4056B60F79CBD74C40
57379	Новый Изборок	3	32	488	27.95806	27.987624	57.780189999999997	57.763933999999999	0103000020E61000000100000005000000139B8F6B43F53B40B726DD96C8E14C40139B8F6B43F53B4047551344DDE34C40A5BE2CEDD4FC3B4047551344DDE34C40A5BE2CEDD4FC3B40B726DD96C8E14C40139B8F6B43F53B40B726DD96C8E14C40
49287	Лавры	3	32	488	27.466978000000001	27.492381999999999	57.584558999999999	57.570014999999998	0103000020E6100000010000000500000095F3C5DE8B773B405E9D6340F6C84C4095F3C5DE8B773B408ECA4DD4D2CA4C409A232BBF0C7E3B408ECA4DD4D2CA4C409A232BBF0C7E3B405E9D6340F6C84C4095F3C5DE8B773B405E9D6340F6C84C40
40477	Крупп	3	32	488	27.827642999999998	27.844594000000001	57.912965	57.903219999999997	0103000020E6100000010000000500000069C36169E0D33B40EB8B84B69CF34C4069C36169E0D33B4042B28009DCF44C40D865F84F37D83B4042B28009DCF44C40D865F84F37D83B40EB8B84B69CF34C4069C36169E0D33B40EB8B84B69CF34C40
49309	Киршино	3	32	488	27.723447	27.730957	58.015709000000001	58.008667000000003	0103000020E61000000100000005000000AA6395D233B93B40F8C610001C014D40AA6395D233B93B405EA0A4C002024D4043C879FF1FBB3B405EA0A4C002024D4043C879FF1FBB3B40F8C610001C014D40AA6395D233B93B40F8C610001C014D40
57390	Изборск	3	32	488	27.846084999999999	27.881577	57.718108999999998	57.700650000000003	0103000020E61000000100000005000000DBA2CC0699D83B40A1F831E6AED94C40DBA2CC0699D83B404CFBE6FEEADB4C40E2E7BF07AFE13B404CFBE6FEEADB4C40E2E7BF07AFE13B40A1F831E6AED94C40DBA2CC0699D83B40A1F831E6AED94C40
48096	Велье	3	32	488	27.799012999999999	27.806891	57.640825999999997	57.638778000000002	0103000020E610000001000000050000002F14B01D8CCC3B40C0B33D7AC3D14C402F14B01D8CCC3B4097361C9606D24C40CE6F986890CE3B4097361C9606D24C40CE6F986890CE3B40C0B33D7AC3D14C402F14B01D8CCC3B40C0B33D7AC3D14C40
57397	д.Вернявино	3	32	1291	27.646794	28.392952000000001	57.704006999999997	57.319890000000001	0103000020E61000000100000005000000C03FA54A94A53B40A228D027F2A84C40C03FA54A94A53B40D993C0E61CDA4C40D6E5948098643C40D993C0E61CDA4C40D6E5948098643C40A228D027F2A84C40C03FA54A94A53B40A228D027F2A84C40
46301	Шейкино	3	32	1291	27.914186000000001	27.921094	57.591698999999998	57.588158999999997	0103000020E610000001000000050000000876FC1708EA3B408DEC4ACB48CB4C400876FC1708EA3B40B709F7CABCCB4C40B58AFED0CCEB3B40B709F7CABCCB4C40B58AFED0CCEB3B408DEC4ACB48CB4C400876FC1708EA3B408DEC4ACB48CB4C40
57429	Слопыгино	3	32	1291	28.091370000000001	28.104520999999998	57.584670000000003	57.573754999999998	0103000020E61000000100000005000000E5D5390664173C404F75C8CD70C94C40E5D5390664173C40E6797077D6CA4C40C6BE64E3C11A3C40E6797077D6CA4C40C6BE64E3C11A3C404F75C8CD70C94C40E5D5390664173C404F75C8CD70C94C40
57392	Палкино	3	32	1291	27.992788999999998	28.028047999999998	57.548848	57.533183000000001	0103000020E610000001000000050000001BD47E6B27FE3B403FE42D573FC44C401BD47E6B27FE3B40CD3CB9A640C64C40DCB75A272E073C40CD3CB9A640C64C40DCB75A272E073C403FE42D573FC44C401BD47E6B27FE3B403FE42D573FC44C40
57443	Новая Уситва	3	32	1291	28.105491000000001	28.138684000000001	57.463375999999997	57.452278999999997	0103000020E61000000100000005000000B8054B75011B3C4073D53C47E4B94C40B8054B75011B3C402AE09EE74FBB4C407D7A6CCB80233C402AE09EE74FBB4C407D7A6CCB80233C4073D53C47E4B94C40B8054B75011B3C4073D53C47E4B94C40
57407	Качаново	3	32	1291	27.757251	27.774211000000001	57.476816999999997	57.458302000000003	0103000020E6100000010000000500000001DD9733DBC13B4080D8D2A3A9BA4C4001DD9733DBC13B40A296E65608BD4C4016342DB132C63B40A296E65608BD4C4016342DB132C63B4080D8D2A3A9BA4C4001DD9733DBC13B4080D8D2A3A9BA4C40
57439	Васильево	3	32	1291	27.916423000000002	27.937048000000001	57.624116000000001	57.615642000000001	0103000020E610000001000000050000005E4D9EB29AEA3B40A305685BCDCE4C405E4D9EB29AEA3B4086747808E3CF4C403FC8B260E2EF3B4086747808E3CF4C403FC8B260E2EF3B40A305685BCDCE4C405E4D9EB29AEA3B40A305685BCDCE4C40
17596	Шики	3	32	1421	28.959250000000001	28.989747999999999	57.289439999999999	57.281028999999997	0103000020E6100000010000000500000021B0726891F53C40211D1EC2F8A34C4021B0726891F53C40BE13B35E0CA54C400A48FB1F60FD3C40BE13B35E0CA54C400A48FB1F60FD3C40211D1EC2F8A34C4021B0726891F53C40211D1EC2F8A34C40
16626	Черепягино	3	32	1421	28.409579999999998	28.440770000000001	57.273774000000003	57.257945999999997	0103000020E610000001000000050000007E18213CDA683C402711E15F04A14C407E18213CDA683C40603FC4060BA34C40D40E7F4DD6703C40603FC4060BA34C40D40E7F4DD6703C402711E15F04A14C407E18213CDA683C402711E15F04A14C40
17700	Спиры	3	32	1421	29.041903999999999	29.055288999999998	57.348945999999998	57.337114999999997	0103000020E6100000010000000500000053927538BA0A3D40DAFE959526AB4C4053927538BA0A3D40F6083543AAAC4C401BD47E6B270E3D40F6083543AAAC4C401BD47E6B270E3D40DAFE959526AB4C4053927538BA0A3D40DAFE959526AB4C40
40375	Рублево	3	32	1421	28.480772000000002	28.487770000000001	57.260472999999998	57.254271000000003	0103000020E6100000010000000500000020D5B0DF137B3C401EA9BEF38BA04C4020D5B0DF137B3C40D93EE42D57A14C404DF8A57EDE7C3C40D93EE42D57A14C404DF8A57EDE7C3C401EA9BEF38BA04C4020D5B0DF137B3C401EA9BEF38BA04C40
21454	Рубилово	3	32	1421	28.236681000000001	28.268985000000001	57.374374000000003	57.365685999999997	0103000020E61000000100000005000000A7954220973C3C40724D81CCCEAE4C40A7954220973C3C40823CBB7CEBAF4C40541D7233DC443C40823CBB7CEBAF4C40541D7233DC443C40724D81CCCEAE4C40A7954220973C3C40724D81CCCEAE4C40
16711	Покаты	3	32	1421	28.202266999999999	28.225245999999999	57.286307000000001	57.274777	0103000020E610000001000000050000005E0F26C5C7333C40B4588AE42BA34C405E0F26C5C7333C40D5CE30B5A5A44C40088ECBB8A9393C40D5CE30B5A5A44C40088ECBB8A9393C40B4588AE42BA34C405E0F26C5C7333C40B4588AE42BA34C40
17655	Подмогилье	3	32	1421	28.919616999999999	28.939001999999999	57.329211000000001	57.323748999999999	0103000020E610000001000000050000007BD80B056CEB3C406D8E739B70A94C407BD80B056CEB3C40E23D079623AA4C40EBE0606F62F03C40E23D079623AA4C40EBE0606F62F03C406D8E739B70A94C407BD80B056CEB3C406D8E739B70A94C40
49393	Подберезье	3	32	1421	28.570989000000001	28.575948	57.425181000000002	57.421351999999999	0103000020E610000001000000050000003160C9552C923C40560DC2DCEEB54C403160C9552C923C40B7F0BC546CB64C405532005471933C40B7F0BC546CB64C405532005471933C40560DC2DCEEB54C403160C9552C923C40560DC2DCEEB54C40
15838	Остров	3	32	1421	28.015992000000001	29.219294999999999	57.571299000000003	57.045495000000003	0103000020E6100000010000000500000065FF3C0D18043C40D690B8C7D2854C4065FF3C0D18043C40679E5C5320C94C40232D95B723383D40679E5C5320C94C40232D95B723383D40D690B8C7D2854C4065FF3C0D18043C40D690B8C7D2854C40
46259	Наумово	3	32	1421	28.829255	28.833729000000002	57.347391999999999	57.343327000000002	0103000020E61000000100000005000000630B410E4AD43C40BA6A9E23F2AB4C40630B410E4AD43C402E724F5777AC4C400FBA84436FD53C402E724F5777AC4C400FBA84436FD53C40BA6A9E23F2AB4C40630B410E4AD43C40BA6A9E23F2AB4C40
16491	Малая Губа	3	32	1421	28.205061000000001	28.216901	57.338349000000001	57.333666000000001	0103000020E6100000010000000500000060AFB0E07E343C40C1E44691B5AA4C4060AFB0E07E343C4031D120054FAB4C403E78EDD286373C4031D120054FAB4C403E78EDD286373C40C1E44691B5AA4C4060AFB0E07E343C40C1E44691B5AA4C40
57464	Лаврово	3	32	1421	28.809393	28.820226999999999	57.254646000000001	57.246709000000003	0103000020E61000000100000005000000809C306134CF3C407F501729949F4C40809C306134CF3C405307793D98A04C40D34B8C65FAD13C405307793D98A04C40D34B8C65FAD13C407F501729949F4C40809C306134CF3C407F501729949F4C40
46486	Крюки	3	32	1421	28.466569	28.490006000000001	57.193147000000003	57.172020000000003	0103000020E61000000100000005000000D253E41071773C40042159C004964C40D253E41071773C400729780AB9984C4002D88008717D3C400729780AB9984C4002D88008717D3C40042159C004964C40D253E41071773C40042159C004964C40
46370	Заборовье	3	32	1421	28.296581	28.318777999999998	57.232989000000003	57.224164999999999	0103000020E610000001000000050000006F9D7FBBEC4B3C4034F44F70B19C4C406F9D7FBBEC4B3C40F4A96395D29D4C402DAF5C6F9B513C40F4A96395D29D4C402DAF5C6F9B513C4034F44F70B19C4C406F9D7FBBEC4B3C4034F44F70B19C4C40
16806	Елины	3	32	1421	28.173072000000001	28.207018999999999	57.217387000000002	57.207281999999999	0103000020E6100000010000000500000073DA53724E2C3C4055867137889A4C4073DA53724E2C3C40ACC95356D39B4C408FA67A32FF343C40ACC95356D39B4C408FA67A32FF343C4055867137889A4C4073DA53724E2C3C4055867137889A4C40
16927	Дуловка	3	32	1421	28.328928999999999	28.347902000000001	57.512076999999998	57.504244	0103000020E61000000100000005000000BBB4E1B034543C40249A40118BC04C40BBB4E1B034543C40530438BD8BC14C408736001B10593C40530438BD8BC14C408736001B10593C40249A40118BC04C40BBB4E1B034543C40249A40118BC04C40
46319	Дубки	3	32	1421	28.118796	28.150397999999999	57.186636	57.168847999999997	0103000020E6100000010000000500000047E5266A691E3C405CFFAECF9C954C4047E5266A691E3C40CD203EB0E3974C404162BB7B80263C40CD203EB0E3974C404162BB7B80263C405CFFAECF9C954C4047E5266A691E3C405CFFAECF9C954C40
46522	Дарьино	3	32	1421	28.615573000000001	28.659869	57.16939	57.161898000000001	0103000020E61000000100000005000000F54C2F31969D3C40D7A4DB12B9944C40F54C2F31969D3C407D224F92AE954C40ECA4BE2CEDA83C407D224F92AE954C40ECA4BE2CEDA83C40D7A4DB12B9944C40F54C2F31969D3C40D7A4DB12B9944C40
17205	Гораи	3	32	1421	28.516335999999999	28.537267	57.135047999999998	57.125283000000003	0103000020E6100000010000000500000059BF99982E843C4055DFF94509904C4059BF99982E843C40F2B1BB4049914C40543882548A893C40F2B1BB4049914C40543882548A893C4055DFF94509904C4059BF99982E843C4055DFF94509904C40
57463	Воронцово	3	32	1421	28.713318999999998	28.764523000000001	57.286560000000001	57.277107999999998	0103000020E610000001000000050000008C9DF0129CB63C40E0BA624678A34C408C9DF0129CB63C40BF2B82FFADA44C40310A82C7B7C33C40BF2B82FFADA44C40310A82C7B7C33C40E0BA624678A34C408C9DF0129CB63C40E0BA624678A34C40
17333	Влазово	3	32	1421	28.566389999999998	28.591093999999998	57.351728999999999	57.339407999999999	0103000020E610000001000000050000000CC85EEFFE903C401900AAB871AB4C400CC85EEFFE903C400307B47405AD4C40A0DCB6EF51973C400307B47405AD4C40A0DCB6EF51973C401900AAB871AB4C400CC85EEFFE903C401900AAB871AB4C40
57431	Большое Приезживо	3	32	1421	28.492360000000001	28.503508	57.183149	57.175148	0103000020E61000000100000005000000CBDB114E0B7E3C40DBFAE93F6B964C40CBDB114E0B7E3C40C6A52A6D71974C403D4679E6E5803C40C6A52A6D71974C403D4679E6E5803C40DBFAE93F6B964C40CBDB114E0B7E3C40DBFAE93F6B964C40
22160	Разувайка	3	32	1432	28.633044999999999	28.653473000000002	56.694217000000002	56.683984000000002	0103000020E6100000010000000500000075E5B33C0FA23C405F7EA7C98C574C4075E5B33C0FA23C40E3A9471ADC584C40ABD1AB014AA73C40E3A9471ADC584C40ABD1AB014AA73C405F7EA7C98C574C4075E5B33C0FA23C405F7EA7C98C574C40
48472	Приозерный	3	32	1432	28.632192	28.643160000000002	56.794927999999999	56.788435999999997	0103000020E61000000100000005000000F7CABC55D7A13C40997E8978EB644C40F7CABC55D7A13C405C566133C0654C406A183E22A6A43C405C566133C0654C406A183E22A6A43C40997E8978EB644C40F7CABC55D7A13C40997E8978EB644C40
57372	Опочка	3	32	1432	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
41361	Норкино	3	32	1432	29.019805999999999	29.040313999999999	56.675207999999998	56.667532000000001	0103000020E61000000100000005000000BB438A0112053D40498446B071554C40BB438A0112053D40B0FF3A376D564C402992AF04520A3D40B0FF3A376D564C402992AF04520A3D40498446B071554C40BB438A0112053D40498446B071554C40
48456	Матюшкино	3	32	1432	28.613902	28.638669	56.867272	56.861116000000003	0103000020E61000000100000005000000F1F274AE289D3C40FB07910C396E4C40F1F274AE289D3C40465ED6C4026F4C4012F8C3CF7FA33C40465ED6C4026F4C4012F8C3CF7FA33C40FB07910C396E4C40F1F274AE289D3C40FB07910C396E4C40
48197	Макушино	3	32	1432	28.462150000000001	28.480412000000001	56.695892999999998	56.680616999999998	0103000020E61000000100000005000000AED85F764F763C40020D36751E574C40AED85F764F763C40F641960513594C40209BE447FC7A3C40F641960513594C40209BE447FC7A3C40020D36751E574C40AED85F764F763C40020D36751E574C40
22100	Ляпуны	3	32	1432	28.706966999999999	28.727674	56.742579999999997	56.731808000000001	0103000020E61000000100000005000000EA5910CAFBB43C40C07971E2AB5D4C40EA5910CAFBB43C40F35487DC0C5F4C404626E0D748BA3C40F35487DC0C5F4C404626E0D748BA3C40C07971E2AB5D4C40EA5910CAFBB43C40C07971E2AB5D4C40
48605	Лобово	3	32	1432	28.841068	28.853303	56.534495	56.525663000000002	0103000020E610000001000000050000004EB6813B50D73C40CFDBD8EC48434C404EB6813B50D73C40117008556A444C402594BE1072DA3C40117008556A444C402594BE1072DA3C40CFDBD8EC48434C404EB6813B50D73C40CFDBD8EC48434C40
57442	Лаптево	3	32	1432	28.829308999999999	28.845191	56.749406999999998	56.735669000000001	0103000020E61000000100000005000000494739984DD43C402CD7DB662A5E4C40494739984DD43C405D328E91EC5F4C40A0DFF76F5ED83C405D328E91EC5F4C40A0DFF76F5ED83C402CD7DB662A5E4C40494739984DD43C402CD7DB662A5E4C40
16012	Кахново	3	32	1432	28.648954	28.657927999999998	56.670059000000002	56.665103000000002	0103000020E61000000100000005000000BF9B6ED921A63C405ABC581822554C40BF9B6ED921A63C40FBB1497EC4554C40681F2BF86DA83C40FBB1497EC4554C40681F2BF86DA83C405ABC581822554C40BF9B6ED921A63C405ABC581822554C40
22692	Звоны	3	32	1432	28.807866000000001	28.821062000000001	56.627989999999997	56.622028	0103000020E61000000100000005000000E38C614ED0CE3C4020990E9D9E4F4C40E38C614ED0CE3C40861BF0F961504C4005FD851E31D23C40861BF0F961504C4005FD851E31D23C4020990E9D9E4F4C40E38C614ED0CE3C4020990E9D9E4F4C40
22530	Духново	3	32	1432	29.130504999999999	29.150690000000001	56.791946000000003	56.782223000000002	0103000020E61000000100000005000000E8F692C668213D40EA961DE21F644C40E8F692C668213D4059198D7C5E654C4091D5AD9E93263D4059198D7C5E654C4091D5AD9E93263D40EA961DE21F644C40E8F692C668213D40EA961DE21F644C40
48574	Глубокое	3	32	1432	29.008998999999999	29.035508	56.617308999999999	56.604151000000002	0103000020E610000001000000050000005BB22AC24D023D40406CE9D1544D4C405BB22AC24D023D40634337FB034F4C4012BF620D17093D40634337FB034F4C4012BF620D17093D40406CE9D1544D4C405BB22AC24D023D40406CE9D1544D4C40
48436	Варыгино	3	32	1432	28.531040999999998	28.539477000000002	56.764758	56.757292999999997	0103000020E61000000100000005000000CBD58F4DF2873C40AF3E1EFAEE604C40CBD58F4DF2873C405CAD1397E3614C40B7F1272A1B8A3C405CAD1397E3614C40B7F1272A1B8A3C40AF3E1EFAEE604C40CBD58F4DF2873C40AF3E1EFAEE604C40
22503	Болгатово	3	32	1432	28.925564000000001	28.958559000000001	56.805593999999999	56.793030000000002	0103000020E61000000100000005000000DE5A26C3F1EC3C409A5FCD0182654C40DE5A26C3F1EC3C404AED45B41D674C405649641F64F53C404AED45B41D674C405649641F64F53C409A5FCD0182654C40DE5A26C3F1EC3C409A5FCD0182654C40
57409	Белки	3	32	1432	28.693223	28.704084000000002	56.801706000000003	56.794148999999997	0103000020E61000000100000005000000C3D5011077B13C405793A7ACA6654C40C3D5011077B13C40E5805D4D9E664C400AA359D93EB43C40E5805D4D9E664C400AA359D93EB43C405793A7ACA6654C40C3D5011077B13C405793A7ACA6654C40
49403	Барсуки	3	32	1432	29.073013	29.081762999999999	56.781734999999998	56.77561	0103000020E61000000100000005000000CF2EDFFAB0123D40AC39403047634C40CF2EDFFAB0123D40BC9179E40F644C40D905836BEE143D40BC9179E40F644C40D905836BEE143D40AC39403047634C40CF2EDFFAB0123D40AC39403047634C40
22252	Барсаново	3	32	1432	28.554082999999999	28.571204999999999	56.721536	56.713183000000001	0103000020E6100000010000000500000002452C62D88D3C4016889E94495B4C4002452C62D88D3C407E71A94A5B5C4C40CA4FAA7D3A923C407E71A94A5B5C4C40CA4FAA7D3A923C4016889E94495B4C4002452C62D88D3C4016889E94495B4C40
52823	Барканы	3	32	1432	29.188941	29.193764999999999	56.623420000000003	56.619472999999999	0103000020E61000000100000005000000A0DFF76F5E303D40A4E029E44A4F4C40A0DFF76F5E303D400FD6FF39CC4F4C40041C42959A313D400FD6FF39CC4F4C40041C42959A313D40A4E029E44A4F4C40A0DFF76F5E303D40A4E029E44A4F4C40
22769	Балахи	3	32	1432	28.699933999999999	28.708396	56.577575000000003	56.570619000000001	0103000020E61000000100000005000000C45BE7DF2EB33C40F5BC1B0B0A494C40C45BE7DF2EB33C405DFE43FAED494C40029EB47059B53C405DFE43FAED494C40029EB47059B53C40F5BC1B0B0A494C40C45BE7DF2EB33C40F5BC1B0B0A494C40
24250	Шахниха	3	32	502	30.123412999999999	30.141559000000001	56.353180999999999	56.340848999999999	0103000020E61000000100000005000000B8E68EFE971F3E40E9EFA5F0A02B4C40B8E68EFE971F3E40C748F608352D4C405874EB353D243E40C748F608352D4C405874EB353D243E40E9EFA5F0A02B4C40B8E68EFE971F3E40E9EFA5F0A02B4C40
23892	Харино-Бор	3	32	502	29.527947000000001	29.534306999999998	56.577629999999999	56.569647000000003	0103000020E610000001000000050000007505DB8827873D40DCA16131EA484C407505DB8827873D402098A3C7EF494C401C06F357C8883D402098A3C7EF494C401C06F357C8883D40DCA16131EA484C407505DB8827873D40DCA16131EA484C40
24471	Старосокольники	3	32	502	29.995134	30.017088000000001	56.350422000000002	56.340744000000001	0103000020E610000001000000050000003E23111AC1FE3D407427D87F9D2B4C403E23111AC1FE3D4043E6CAA0DA2C4C40702711E15F043E4043E6CAA0DA2C4C40702711E15F043E407427D87F9D2B4C403E23111AC1FE3D407427D87F9D2B4C40
24674	Руново	3	32	502	29.794567000000001	29.821138999999999	56.466290000000001	56.452751999999997	0103000020E61000000100000005000000187B2FBE68CB3D406B990CC7F3394C40187B2FBE68CB3D40D6390664AF3B4C405B785E2A36D23D40D6390664AF3B4C405B785E2A36D23D406B990CC7F3394C40187B2FBE68CB3D406B990CC7F3394C40
57446	Ременье	3	32	502	29.989474000000001	30.022010999999999	56.454557999999999	56.440727000000003	0103000020E61000000100000005000000083E062B4EFD3D406BBB09BE69384C40083E062B4EFD3D404D11E0F42E3A4C40FA264D83A2053E404D11E0F42E3A4C40FA264D83A2053E406BBB09BE69384C40083E062B4EFD3D406BBB09BE69384C40
24581	Островки	3	32	502	29.775244000000001	29.797567000000001	56.546802999999997	56.532136999999999	0103000020E61000000100000005000000946B0A6476C63D40EBFEB1101D444C40946B0A6476C63D40662D05A4FD454C406C5ED5592DCC3D40662D05A4FD454C406C5ED5592DCC3D40EBFEB1101D444C40946B0A6476C63D40EBFEB1101D444C40
24296	Окни	3	32	502	30.067798	30.082270000000001	56.294545999999997	56.274265	0103000020E61000000100000005000000F5BBB0355B113E40FEB7921D1B234C40F5BBB0355B113E407495EEAEB3254C4022718FA50F153E407495EEAEB3254C4022718FA50F153E40FEB7921D1B234C40F5BBB0355B113E40FEB7921D1B234C40
57381	Новосокольники	3	32	502	30.135998000000001	30.173736999999999	56.356127999999998	56.317912	0103000020E610000001000000050000004852D2C3D0223E40C3802557B1284C404852D2C3D0223E404E98309A952D4C40EB1A2D077A2C3E404E98309A952D4C40EB1A2D077A2C3E40C3802557B1284C404852D2C3D0223E40C3802557B1284C40
24141	Насва	3	32	502	30.133851	30.170413	56.589759999999998	56.566338999999999	0103000020E610000001000000050000007289230F44223E4084B9DDCB7D484C407289230F44223E40963E74417D4B4C4031D0B52FA02B3E40963E74417D4B4C4031D0B52FA02B3E4084B9DDCB7D484C407289230F44223E4084B9DDCB7D484C40
24207	Назимово	3	32	502	30.143616000000002	30.161942	56.559131999999998	56.550569000000003	0103000020E61000000100000005000000AE2EA704C4243E408198840B79464C40AE2EA704C4243E40D3122BA391474C404DD9E90775293E40D3122BA391474C404DD9E90775293E408198840B79464C40AE2EA704C4243E408198840B79464C40
24119	Маево	3	32	502	29.779699999999998	29.807645999999998	56.365133999999998	56.354602	0103000020E61000000100000005000000F2B0506B9AC73D40508C2C99632D4C40F2B0506B9AC73D402E54FEB5BC2E4C40C6BE64E3C1CE3D402E54FEB5BC2E4C40C6BE64E3C1CE3D40508C2C99632D4C40F2B0506B9AC73D40508C2C99632D4C40
25332	Липшани	3	32	502	30.088352	30.100767000000001	56.606906000000002	56.597968000000002	0103000020E610000001000000050000004489963C9E163E40FB0626378A4C4C404489963C9E163E4083DF8618AF4D4C401B84B9DDCB193E4083DF8618AF4D4C401B84B9DDCB193E40FB0626378A4C4C404489963C9E163E40FB0626378A4C4C40
24510	Захарино	3	32	502	30.180994999999999	30.212292000000001	56.351405	56.337142	0103000020E6100000010000000500000051BD35B0552E3E40D40D1478272B4C4051BD35B0552E3E405053CBD6FA2C4C40D333BDC458363E405053CBD6FA2C4C40D333BDC458363E40D40D1478272B4C4051BD35B0552E3E40D40D1478272B4C40
24571	Демя	3	32	502	30.294129000000002	30.337032000000001	56.320152999999998	56.307496	0103000020E6100000010000000500000021CEC3094C4B3E404ED367075C274C4021CEC3094C4B3E40AF5B04C6FA284C409AB4A9BA47563E40AF5B04C6FA284C409AB4A9BA47563E404ED367075C274C4021CEC3094C4B3E404ED367075C274C40
23976	Горожане	3	32	502	30.004107999999999	30.053291000000002	56.572071999999999	56.558292999999999	0103000020E61000000100000005000000E7A6CD380D013E40F94A202576474C40E7A6CD380D013E40897AC1A739494C40D02B9E7AA40D3E40897AC1A739494C40D02B9E7AA40D3E40F94A202576474C40E7A6CD380D013E40F94A202576474C40
23968	Вяз	3	32	502	29.635276999999999	29.671102000000001	56.613920999999998	56.607922000000002	0103000020E61000000100000005000000A7E67283A1A23D406C425A63D04D4C40A7E67283A1A23D40EFA99CF6944E4C40BB473657CDAB3D40EFA99CF6944E4C40BB473657CDAB3D406C425A63D04D4C40A7E67283A1A23D406C425A63D04D4C40
19244	Стехново	3	32	685	29.205092	29.226113000000002	57.154302999999999	57.143760999999998	0103000020E61000000100000005000000D6ABC8E880343D405AB8ACC266924C40D6ABC8E880343D405C566133C0934C405133A48AE2393D405C566133C0934C405133A48AE2393D405AB8ACC266924C40D6ABC8E880343D405AB8ACC266924C40
19160	Орша	3	32	685	29.320993000000001	29.345921000000001	57.046930000000003	57.039662999999997	0103000020E61000000100000005000000B43EE5982C523D403DEE5BAD13854C40B43EE5982C523D40C4995FCD01864C40E7FF55478E583D40C4995FCD01864C40E7FF55478E583D403DEE5BAD13854C40B43EE5982C523D403DEE5BAD13854C40
18720	Новоржев	3	32	685	29.311606000000001	29.368307000000001	57.039374000000002	57.021731000000003	0103000020E61000000100000005000000C53C2B69C54F3D409A27D714C8824C40C53C2B69C54F3D4007280D350A854C404CE3175E495E3D4007280D350A854C404CE3175E495E3D409A27D714C8824C40C53C2B69C54F3D409A27D714C8824C40
19154	Макарово	3	32	685	29.381836	29.403808999999999	56.997759000000002	56.986539999999998	0103000020E610000001000000050000007A6F0C01C0613D40111956F1467E4C407A6F0C01C0613D4014252191B67F4C4099D4D00660673D4014252191B67F4C4099D4D00660673D40111956F1467E4C407A6F0C01C0613D40111956F1467E4C40
19089	Жадрицы	3	32	685	29.155137	29.17145	56.930605999999997	56.922879000000002	0103000020E610000001000000050000004966F50EB7273D40259529E620764C404966F50EB7273D400EBBEF181E774C4032E6AE25E42B3D400EBBEF181E774C4032E6AE25E42B3D40259529E620764C404966F50EB7273D40259529E620764C40
46592	Городище	3	32	685	29.434225999999999	29.44408	57.273181000000001	57.267004999999997	0103000020E61000000100000005000000A912656F296F3D402A6F47382DA24C40A912656F296F3D40BD715298F7A24C40C4CE143AAF713D40BD715298F7A24C40C4CE143AAF713D402A6F47382DA24C40A912656F296F3D402A6F47382DA24C40
4760	Выбор	3	32	685	29.148102999999999	29.167956	57.231186000000001	57.223624000000001	0103000020E6100000010000000500000082700514EA253D40E44C13B69F9C4C4082700514EA253D4083A5BA80979D4C40BF2A172AFF2A3D4083A5BA80979D4C40BF2A172AFF2A3D40E44C13B69F9C4C4082700514EA253D40E44C13B69F9C4C40
18986	Вехно	3	32	685	29.189928999999999	29.210464000000002	57.077660000000002	57.065477000000001	0103000020E61000000100000005000000DE8FDB2F9F303D40F2D1E28C61884C40DE8FDB2F9F303D408B1A4CC3F0894C4040FCFCF7E0353D408B1A4CC3F0894C4040FCFCF7E0353D40F2D1E28C61884C40DE8FDB2F9F303D40F2D1E28C61884C40
18915	Веска	3	32	685	29.372358999999999	29.400825999999999	57.257207000000001	57.248539999999998	0103000020E610000001000000050000000B5F5FEB525F3D40B9DFA128D09F4C400B5F5FEB525F3D40B1A6B228ECA04C40F16261889C663D40B1A6B228ECA04C40F16261889C663D40B9DFA128D09F4C400B5F5FEB525F3D40B9DFA128D09F4C40
18886	Барута	3	32	685	29.576096	29.596291000000001	57.064081999999999	57.051160000000003	0103000020E610000001000000050000003E5B07077B933D40836E2F698C864C403E5B07077B933D409221C7D633884C402EE6E786A6983D409221C7D633884C402EE6E786A6983D40836E2F698C864C403E5B07077B933D40836E2F698C864C40
57408	д.Урочище Дубровка	3	32	220	29.182769	30.442495000000001	56.291998	55.703341999999999	0103000020E61000000100000005000000FEB8FDF2C92E3D409DF3531C07DA4B40FEB8FDF2C92E3D40AB3FC23060254C40BEA4315A47713E40AB3FC23060254C40BEA4315A47713E409DF3531C07DA4B40FEB8FDF2C92E3D409DF3531C07DA4B40
57437	Щербино	3	32	220	29.951314	29.969954000000001	56.130487000000002	56.120717999999997	0103000020E61000000100000005000000193A765089F33D40EE04FBAF730F4C40193A765089F33D40CEC64ACCB3104C40D89FC4E74EF83D40CEC64ACCB3104C40D89FC4E74EF83D40EE04FBAF730F4C40193A765089F33D40EE04FBAF730F4C40
57414	Чернуха	3	32	220	30.131076	30.141836999999999	56.154741000000001	56.149214999999998	0103000020E610000001000000050000005E4A5D328E213E404C89247A19134C405E4A5D328E213E40D82C978DCE134C40DD5CFC6D4F243E40D82C978DCE134C40DD5CFC6D4F243E404C89247A19134C405E4A5D328E213E404C89247A19134C40
57423	Ушаково	3	32	220	29.769342000000002	29.785943	56.014015999999998	56.004266999999999	0103000020E610000001000000050000007270E998F3C43D40DCB930D28B004C407270E998F3C43D4074CFBA46CB014C402785798F33C93D4074CFBA46CB014C402785798F33C93D40DCB930D28B004C407270E998F3C43D40DCB930D28B004C40
2162	Усть-Долыссы	3	32	220	29.631316000000002	29.667840999999999	56.143749	56.126168	0103000020E610000001000000050000000971E5EC9DA13D409FE6E44526104C400971E5EC9DA13D4096EA025E66124C408DEDB5A0F7AA3D4096EA025E66124C408DEDB5A0F7AA3D409FE6E44526104C400971E5EC9DA13D409FE6E44526104C40
2110	Туричино	3	32	220	29.554447	29.586175999999998	55.862094999999997	55.851818000000002	0103000020E61000000100000005000000855D143DF08D3D4073124A5F08ED4B40855D143DF08D3D40C685032159EE4B4039B35DA10F963D40C685032159EE4B4039B35DA10F963D4073124A5F08ED4B40855D143DF08D3D4073124A5F08ED4B40
2006	Трехалево	3	32	220	29.817212999999999	29.830490000000001	56.209386000000002	56.188768000000003	0103000020E61000000100000005000000B5DD04DF34D13D400344C18C29184C40B5DD04DF34D13D40C11E1329CD1A4C40B1A71DFE9AD43D40C11E1329CD1A4C40B1A71DFE9AD43D400344C18C29184C40B5DD04DF34D13D400344C18C29184C40
57425	Рыколево	3	32	220	30.044720999999999	30.05162	56.025506999999998	56.017543000000003	0103000020E61000000100000005000000C571E0D5720B3E400AA359D93E024C40C571E0D5720B3E40D76839D043034C40CCD1E3F7360D3E40D76839D043034C40CCD1E3F7360D3E400AA359D93E024C40C571E0D5720B3E400AA359D93E024C40
52835	Рукавец	3	32	220	29.765201000000001	29.778369999999999	56.235235000000003	56.225999000000002	0103000020E61000000100000005000000D3DD7536E4C33D40E0F60489ED1C4C40D3DD7536E4C33D40F2EF332E1C1E4C4001309E4143C73D40F2EF332E1C1E4C4001309E4143C73D40E0F60489ED1C4C40D3DD7536E4C33D40E0F60489ED1C4C40
31975	Опухлики	3	32	220	30.145493999999999	30.171958	56.099525999999997	56.085264000000002	0103000020E61000000100000005000000A4C343183F253E4059C345EEE90A4C40A4C343183F253E40048D9944BD0C4C401B498270052C3E40048D9944BD0C4C401B498270052C3E4059C345EEE90A4C40A4C343183F253E4059C345EEE90A4C40
1694	Новохованск	3	32	220	29.690874000000001	29.725603	55.947364	55.925778000000001	0103000020E610000001000000050000001EA8531EDDB03D409BADBCE47FF64B401EA8531EDDB03D4031B43A3943F94B4026E1421EC1B93D4031B43A3943F94B4026E1421EC1B93D409BADBCE47FF64B401EA8531EDDB03D409BADBCE47FF64B40
833	Невель	3	32	220	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
52830	Ловец	3	32	220	29.613295999999998	29.627184	56.033968000000002	56.026966000000002	0103000020E6100000010000000500000082C476F7009D3D404E0D349F73034C4082C476F7009D3D40268E3C1059044C40109370218FA03D40268E3C1059044C40109370218FA03D404E0D349F73034C4082C476F7009D3D404E0D349F73034C40
1578	Лобок	3	32	220	29.948070999999999	29.971256	55.874949999999998	55.860624999999999	0103000020E610000001000000050000003849F3C7B4F23D405C8FC2F528EE4B403849F3C7B4F23D404ED1915CFEEF4B40350BB43BA4F83D404ED1915CFEEF4B40350BB43BA4F83D405C8FC2F528EE4B403849F3C7B4F23D405C8FC2F528EE4B40
57450	Лехово	3	32	220	30.354675	30.379487000000001	55.875591999999997	55.863155999999996	0103000020E6100000010000000500000074B515FBCB5A3E404FAC53E57BEE4B4074B515FBCB5A3E40D2510E6613F04B40D5415E0F26613E40D2510E6613F04B40D5415E0F26613E404FAC53E57BEE4B4074B515FBCB5A3E404FAC53E57BEE4B40
45407	Кресты	3	32	220	29.489032000000002	29.49868	55.795696999999997	55.784587000000002	0103000020E610000001000000050000008EB27E33317D3D40F2EEC8586DE44B408EB27E33317D3D403D433866D9E54B40562B137EA97F3D403D433866D9E54B40562B137EA97F3D40F2EEC8586DE44B408EB27E33317D3D40F2EEC8586DE44B40
48672	Юхово	3	32	1747	30.4148	30.43017	56.910452999999997	56.900702000000003	0103000020E610000001000000050000007C613255306A3E408DB800344A734C407C613255306A3E40C5C551B989744C4067B8019F1F6E3E40C5C551B989744C4067B8019F1F6E3E408DB800344A734C407C613255306A3E408DB800344A734C40
24894	Рысино	3	32	1747	30.137463	30.147030000000001	56.845165000000001	56.837642000000002	0103000020E61000000100000005000000F96871C630233E40C6E061DA376B4C40F96871C630233E40A75CE15D2E6C4C40E88711C2A3253E40A75CE15D2E6C4C40E88711C2A3253E40C6E061DA376B4C40F96871C630233E40C6E061DA376B4C40
25251	Прискуха	3	32	1747	30.151153000000001	30.175839	56.632209000000003	56.623866	0103000020E610000001000000050000003AB187F6B1263E400D8B51D7DA4F4C403AB187F6B1263E40529E7939EC504C40815CE2C8032D3E40529E7939EC504C40815CE2C8032D3E400D8B51D7DA4F4C403AB187F6B1263E400D8B51D7DA4F4C40
24371	Миритиницы	3	32	1747	29.803532000000001	29.85258	56.649939000000003	56.641356999999999	0103000020E610000001000000050000001B4AED45B4CD3D40C40776FC17524C401B4AED45B4CD3D408EB27E3331534C404339D1AE42DA3D408EB27E3331534C404339D1AE42DA3D40C40776FC17524C401B4AED45B4CD3D40C40776FC17524C40
24813	Локня	3	32	1747	30.127707000000001	30.170655	56.838754999999999	56.811748999999999	0103000020E610000001000000050000006478EC67B1203E40C5C72764E7674C406478EC67B1203E40A12DE7525C6B4C401DE6CB0BB02B3E40A12DE7525C6B4C401DE6CB0BB02B3E40C5C72764E7674C406478EC67B1203E40C5C72764E7674C40
24846	Крестилово	3	32	1747	30.157979999999998	30.204163000000001	56.751282000000003	56.730583000000003	0103000020E610000001000000050000000D6C956071283E40BD0166BE835D4C400D6C956071283E40680932022A604C40A20DC00644343E40680932022A604C40A20DC00644343E40BD0166BE835D4C400D6C956071283E40BD0166BE835D4C40
48147	Васильевское	3	32	1747	30.013100000000001	30.017861	56.594231000000001	56.591976000000003	0103000020E61000000100000005000000DE9387855A033E402A029CDEC54B4C40DE9387855A033E407BA2EBC20F4C4C40B5DFDA8992043E407BA2EBC20F4C4C40B5DFDA8992043E402A029CDEC54B4C40DE9387855A033E402A029CDEC54B4C40
25201	Башово	3	32	1747	30.135064	30.186178000000002	56.656267	56.629930999999999	0103000020E61000000100000005000000F0DDE68D93223E4048DE3994A1504C40F0DDE68D93223E40D6389B8E00544C40153C855CA92F3E40D6389B8E00544C40153C855CA92F3E4048DE3994A1504C40F0DDE68D93223E4048DE3994A1504C40
57401	Ушицы	3	32	1776	30.783280000000001	30.802629	56.285508	56.266646999999999	0103000020E61000000100000005000000639CBF0985C83E40CB49287D21224C40639CBF0985C83E40895FB1868B244C4039D2191879CD3E40895FB1868B244C4039D2191879CD3E40CB49287D21224C40639CBF0985C83E40CB49287D21224C40
27534	Усмынь	3	32	1776	31.136785	31.182644	55.865743000000002	55.850408000000002	0103000020E6100000010000000500000057957D5704233F40DE205A2BDAEC4B4057957D5704233F40D7DEA7AAD0EE4B4085CFD6C1C12E3F40D7DEA7AAD0EE4B4085CFD6C1C12E3F40DE205A2BDAEC4B4057957D5704233F40DE205A2BDAEC4B40
26341	Слепнево	3	32	1776	31.012771999999998	31.024774000000001	56.093310000000002	56.079503000000003	0103000020E61000000100000005000000F44D9A0645033F408A7780272D0A4C40F44D9A0645033F40E4310395F10B4C4086CABF9657063F40E4310395F10B4C4086CABF9657063F408A7780272D0A4C40F44D9A0645033F408A7780272D0A4C40
27435	Пухново	3	32	1776	31.080424000000001	31.104796	55.974977000000003	55.960442	0103000020E6100000010000000500000042D0D1AA96143F4038DA71C3EFFA4B4042D0D1AA96143F4015ADDC0BCCFC4B406AC020E9D31A3F4015ADDC0BCCFC4B406AC020E9D31A3F4038DA71C3EFFA4B4042D0D1AA96143F4038DA71C3EFFA4B40
46093	Прихабы	3	32	1776	31.257760999999999	31.289759	55.945650000000001	55.931623000000002	0103000020E610000001000000050000002B2FF99FFC413F40C899266C3FF74B402B2FF99FFC413F4030BB270F0BF94B40BFB854A52D4A3F4030BB270F0BF94B40BFB854A52D4A3F40C899266C3FF74B402B2FF99FFC413F40C899266C3FF74B40
57426	Лукино	3	32	1776	30.832211000000001	30.850303	56.227960000000003	56.212254000000001	0103000020E61000000100000005000000185FB4C70BD53E40FC389A232B1B4C40185FB4C70BD53E40E96514CB2D1D4C40D1B01875ADD93E40E96514CB2D1D4C40D1B01875ADD93E40FC389A232B1B4C40185FB4C70BD53E40FC389A232B1B4C40
27045	Кунья	3	32	1776	30.945119999999999	30.997456	56.303261999999997	56.265447000000002	0103000020E61000000100000005000000A7CB6262F3F13E4021E9D32AFA214C40A7CB6262F3F13E404D0F0A4AD1264C40F032C34659FF3E404D0F0A4AD1264C40F032C34659FF3E4021E9D32AFA214C40A7CB6262F3F13E4021E9D32AFA214C40
49286	Каськово	3	32	1776	31.184412999999999	31.192793999999999	56.211863999999998	56.192990999999999	0103000020E610000001000000050000000EF5BBB0352F3F400FB6D8EDB3184C400EF5BBB0352F3F4091990B5C1E1B4C4072DD94F25A313F4091990B5C1E1B4C4072DD94F25A313F400FB6D8EDB3184C400EF5BBB0352F3F400FB6D8EDB3184C40
27774	Жижица	3	32	1776	31.339310000000001	31.371262999999999	56.293792000000003	56.272444999999998	0103000020E61000000100000005000000AD342905DD563F40B77A4E7ADF224C40AD342905DD563F40C9E9EBF99A254C4000378B170B5F3F40C9E9EBF99A254C4000378B170B5F3F40B77A4E7ADF224C40AD342905DD563F40B77A4E7ADF224C40
27605	Долговица	3	32	1776	31.291474000000001	31.318235000000001	55.817996999999998	55.802892	0103000020E6100000010000000500000062A2410A9E4A3F402A1C412AC5E64B4062A2410A9E4A3F40F19C2D20B4E84B404C7155D977513F40F19C2D20B4E84B404C7155D977513F402A1C412AC5E64B4062A2410A9E4A3F402A1C412AC5E64B40
25538	Встеселово	3	32	1776	30.951543000000001	30.987314000000001	56.172083999999998	56.160981999999997	0103000020E61000000100000005000000DCBC715298F33E40519FE40E9B144C40DCBC715298F33E401A1538D906164C4009E23C9CC0FC3E401A1538D906164C4009E23C9CC0FC3E40519FE40E9B144C40DCBC715298F33E40519FE40E9B144C40
57436	Боталово	3	32	1776	30.885580000000001	30.908514	56.293191999999998	56.281891000000002	0103000020E61000000100000005000000DFFDF15EB5E23E40B404190115244C40DFFDF15EB5E23E4073B9C15087254C4049F59D5F94E83E4073B9C15087254C4049F59D5F94E83E40B404190115244C40DFFDF15EB5E23E40B404190115244C40
49686	Борок	3	32	1776	30.920767000000001	30.940484999999999	56.358597000000003	56.346381999999998	0103000020E610000001000000050000006D3CD862B7EB3E4027F6D03E562C4C406D3CD862B7EB3E40CCB8A981E62D4C40E960FD9FC3F03E40CCB8A981E62D4C40E960FD9FC3F03E4027F6D03E562C4C406D3CD862B7EB3E4027F6D03E562C4C40
57415	Усово	3	32	696	28.390069	28.403085000000001	56.790934999999998	56.783431	0103000020E61000000100000005000000F52EDE8FDB633C4017D68D7747644C40F52EDE8FDB633C408121AB5B3D654C4017821C9430673C408121AB5B3D654C4017821C9430673C4017D68D7747644C40F52EDE8FDB633C4017D68D7747644C40
5054	Треньки	3	32	696	28.016719999999999	28.026557	56.807068000000001	56.801670999999999	0103000020E610000001000000050000006A300DC347043C406893C3279D664C406A300DC347043C40F6D214014E674C40D97A8670CC063C40F6D214014E674C40D97A8670CC063C406893C3279D664C406A300DC347043C406893C3279D664C40
47415	Саурово	3	32	696	28.343150000000001	28.351899	56.833457000000003	56.82734	0103000020E61000000100000005000000569FABADD8573C401956F146E6694C40569FABADD8573C40A7CF0EB8AE6A4C40BF7E880D165A3C40A7CF0EB8AE6A4C40BF7E880D165A3C401956F146E6694C40569FABADD8573C401956F146E6694C40
19769	Покровское	3	32	696	28.251234	28.273872000000001	56.695323999999999	56.684330000000003	0103000020E61000000100000005000000ADA415DF50403C40FAD51C2098574C40ADA415DF50403C40DC0F786000594C40454AB3791C463C40DC0F786000594C40454AB3791C463C40FAD51C2098574C40ADA415DF50403C40FAD51C2098574C40
46897	Мыза	3	32	696	28.299634999999999	28.332388000000002	56.82405	56.709116999999999	0103000020E61000000100000005000000A9BC1DE1B44C3C40D1048A58C45A4C40A9BC1DE1B44C3C4068226C787A694C403695456117553C4068226C787A694C403695456117553C40D1048A58C45A4C40A9BC1DE1B44C3C40D1048A58C45A4C40
19672	Кресты	3	32	696	28.072648999999998	28.093508	56.786251	56.774445999999998	0103000020E610000001000000050000004C16F71F99123C404E42E90B21634C404C16F71F99123C4041B96DDFA3644C4014EAE923F0173C4041B96DDFA3644C4014EAE923F0173C404E42E90B21634C404C16F71F99123C404E42E90B21634C40
19302	Красногородск	3	32	696	28.265329000000001	28.308529	56.847326000000002	56.821686	0103000020E610000001000000050000002EAEF199EC433C4060CAC0012D694C402EAEF199EC433C407786A92D756C4C401ADEACC1FB4E3C407786A92D756C4C401ADEACC1FB4E3C4060CAC0012D694C402EAEF199EC433C4060CAC0012D694C40
45378	Ильинское	3	32	696	28.508467	28.545423	56.929181	56.915033000000001	0103000020E610000001000000050000006118B0E42A823C4061E124CD1F754C406118B0E42A823C4044882B67EF764C40787C7BD7A08B3C4044882B67EF764C40787C7BD7A08B3C4061E124CD1F754C406118B0E42A823C4061E124CD1F754C40
47542	Золотово	3	32	696	28.314907000000002	28.332180999999999	56.742279000000003	56.732982999999997	0103000020E610000001000000050000000F48C2BE9D503C4011C30E63D25D4C400F48C2BE9D503C40F9C08EFF025F4C40425A63D009553C40F9C08EFF025F4C40425A63D009553C4011C30E63D25D4C400F48C2BE9D503C4011C30E63D25D4C40
20118	Гавры	3	32	696	28.160657	28.177447000000001	56.878138	56.864192000000003	0103000020E610000001000000050000009CDF30D120293C4080BBECD79D6E4C409CDF30D120293C40FBAF73D366704C40F8C5A52A6D2D3C40FBAF73D366704C40F8C5A52A6D2D3C4080BBECD79D6E4C409CDF30D120293C4080BBECD79D6E4C40
4912	Блясино	3	32	696	28.292862	28.315598000000001	56.948489000000002	56.940432999999999	0103000020E61000000100000005000000BC3D0801F94A3C40228AC91B60784C40BC3D0801F94A3C40D1CE691668794C40DAAED007CB503C40D1CE691668794C40DAAED007CB503C40228AC91B60784C40BC3D0801F94A3C40228AC91B60784C40
14382	Скугры	3	32	880	29.883849999999999	29.923573999999999	57.853113999999998	57.843620999999999	0103000020E61000000100000005000000D1915CFE43E23D40029CDEC5FBEB4C40D1915CFE43E23D403FE1ECD632ED4C40976F7D586FEC3D403FE1ECD632ED4C40976F7D586FEC3D40029CDEC5FBEB4C40D1915CFE43E23D40029CDEC5FBEB4C40
57441	Панкратово	3	32	880	30.232099999999999	30.245835	57.826611999999997	57.815472	0103000020E61000000100000005000000CF66D5E76A3B3E40E066F16261E84C40CF66D5E76A3B3E40963D096CCEE94C405036E50AEF3E3E40963D096CCEE94C405036E50AEF3E3E40E066F16261E84C40CF66D5E76A3B3E40E066F16261E84C40
57399	Морино	3	32	880	30.316120000000002	30.377475	57.900207000000002	57.884808	0103000020E610000001000000050000008D9C853DED503E409D9E776341F14C408D9C853DED503E40AD50A4FB39F34C40BF0E9C33A2603E40AD50A4FB39F34C40BF0E9C33A2603E409D9E776341F14C408D9C853DED503E409D9E776341F14C40
49373	Михайлов Погост	3	32	880	30.24447	30.267628999999999	57.837609	57.825192999999999	0103000020E6100000010000000500000066DAFE95953E3E40AEF199EC9FE94C4066DAFE95953E3E40EAEA8EC536EB4C4010768A5583443E40EAEA8EC536EB4C4010768A5583443E40AEF199EC9FE94C4066DAFE95953E3E40AEF199EC9FE94C40
55035	Лукомо	3	32	880	30.025801999999999	30.050452	57.926335000000002	57.91395	0103000020E61000000100000005000000E02BBAF59A063E40F0164850FCF44C40E02BBAF59A063E40F111312592F64C408E041A6CEA0C3E40F111312592F64C408E041A6CEA0C3E40F0164850FCF44C40E02BBAF59A063E40F0164850FCF44C40
57449	Искра	3	32	880	29.869001000000001	29.884174000000002	57.774872999999999	57.767893999999998	0103000020E61000000100000005000000F9307BD976DE3D40B665C0594AE24C40F9307BD976DE3D40D6C6D8092FE34C4038F92D3A59E23D40D6C6D8092FE34C4038F92D3A59E23D40B665C0594AE24C40F9307BD976DE3D40B665C0594AE24C40
6658	Дно	3	32	880	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
45435	Дачное	3	32	880	29.99879	30.031929000000002	57.826841999999999	57.811225	0103000020E61000000100000005000000649291B3B0FF3D404B598638D6E74C40649291B3B0FF3D40C87A6AF5D5E94C4043CBBA7F2C083E40C87A6AF5D5E94C4043CBBA7F2C083E404B598638D6E74C40649291B3B0FF3D404B598638D6E74C40
57460	Гаврово	3	32	880	30.136430000000001	30.156587999999999	57.73516	57.726202999999998	0103000020E610000001000000050000007B319413ED223E40E8A04B38F4DC4C407B319413ED223E40E7A90EB919DE4C4030F2B22616283E40E7A90EB919DE4C4030F2B22616283E40E8A04B38F4DC4C407B319413ED223E40E8A04B38F4DC4C40
52123	Выскодь	3	32	880	30.059085	30.091640000000002	57.777906000000002	57.769185	0103000020E6100000010000000500000025AFCE31200F3E4071C971A774E24C4025AFCE31200F3E405CAE7E6C92E34C40650113B875173E405CAE7E6C92E34C40650113B875173E4071C971A774E24C4025AFCE31200F3E4071C971A774E24C40
57419	Большое Юрково	3	32	880	29.833302	29.851044000000002	57.938868999999997	57.929383999999999	0103000020E61000000100000005000000FFB0A54753D53D407CB60E0EF6F64C40FFB0A54753D53D40361D01DC2CF84C4000750305DED93D40361D01DC2CF84C4000750305DED93D407CB60E0EF6F64C40FFB0A54753D53D407CB60E0EF6F64C40
57451	Белая	3	32	880	30.000064999999999	30.023807999999999	57.675291999999999	57.663831000000002	0103000020E61000000100000005000000CEDF844204003E401689096AF8D44C40CEDF844204003E400EA0DFF76FD64C401762F54718063E400EA0DFF76FD64C401762F54718063E401689096AF8D44C40CEDF844204003E401689096AF8D44C40
15523	Ясски	3	32	683	30.104216000000001	30.133662999999999	57.556628000000003	57.543593000000001	0103000020E610000001000000050000004EB857E6AD1A3E40D2AA967494C54C404EB857E6AD1A3E40DA0418963FC74C406CAF05BD37223E40DA0418963FC74C406CAF05BD37223E40D2AA967494C54C404EB857E6AD1A3E40D2AA967494C54C40
45749	Станки	3	32	683	30.338964000000001	30.362670000000001	57.558236000000001	57.549079999999996	0103000020E6100000010000000500000077853E58C6563E409F71E14048C64C4077853E58C6563E4095B9F94674C74C40863DEDF0D75C3E4095B9F94674C74C40863DEDF0D75C3E409F71E14048C64C4077853E58C6563E409F71E14048C64C40
15272	Пожеревицы	3	32	683	29.783455	29.803936	57.472113	57.451605999999998	0103000020E610000001000000050000003FE3C28190C83D40B456B439CEB94C403FE3C28190C83D401B82E3326EBC4C40BA13ECBFCECD3D401B82E3326EBC4C40BA13ECBFCECD3D40B456B439CEB94C403FE3C28190C83D40B456B439CEB94C40
45844	Погостище	3	32	683	29.859829000000001	29.874562000000001	57.565950000000001	57.559804999999997	0103000020E610000001000000050000000327DBC01DDC3D409291B3B0A7C74C400327DBC01DDC3D40EA95B20C71C84C400953944BE3DF3D40EA95B20C71C84C400953944BE3DF3D409291B3B0A7C74C400327DBC01DDC3D409291B3B0A7C74C40
15052	Навережье	3	32	683	29.483533999999999	29.498635	57.393115000000002	57.379401000000001	0103000020E610000001000000050000000A815CE2C87B3D40EC88433690B04C400A815CE2C87B3D409548A29751B24C4016A4198BA67F3D409548A29751B24C4016A4198BA67F3D40EC88433690B04C400A815CE2C87B3D40EC88433690B04C40
45788	Крутец	3	32	683	30.054548	30.097639999999998	57.633232999999997	57.621141999999999	0103000020E61000000100000005000000ED0F94DBF60D3E400516C09481CF4C40ED0F94DBF60D3E40BDDF68C70DD14C400CC85EEFFE183E40BDDF68C70DD14C400CC85EEFFE183E400516C09481CF4C40ED0F94DBF60D3E400516C09481CF4C40
45873	Красные Горки	3	32	683	29.904026000000002	29.920905999999999	57.532637000000001	57.522629000000002	0103000020E61000000100000005000000D4BB783F6EE73D407978CF81E5C24C40D4BB783F6EE73D40DDD1FF722DC44C40AFB0E07EC0EB3D40DDD1FF722DC44C40AFB0E07EC0EB3D407978CF81E5C24C40D4BB783F6EE73D407978CF81E5C24C40
57457	Дубишино	3	32	683	29.946095	29.966602999999999	57.597275000000003	57.587989999999998	0103000020E61000000100000005000000BCE82B4833F23D4001309E4143CB4C40BCE82B4833F23D40F5DBD78173CC4C402A37514B73F73D40F5DBD78173CC4C402A37514B73F73D4001309E4143CB4C40BCE82B4833F23D4001309E4143CB4C40
14954	Дедовичи	3	32	683	29.923466000000001	29.968283	57.561374000000001	57.534520999999998	0103000020E61000000100000005000000CBF78C4468EC3D403A03232F6BC44C40CBF78C4468EC3D4090696D1ADBC74C40D4450A65E1F73D4090696D1ADBC74C40D4450A65E1F73D403A03232F6BC44C40CBF78C4468EC3D403A03232F6BC44C40
57453	Горушка	3	32	683	29.561758999999999	29.576411	57.523881000000003	57.518718999999997	0103000020E61000000100000005000000D13B1570CF8F3D402B685A6265C24C40D13B1570CF8F3D4076FF58880EC34C40FE0DDAAB8F933D4076FF58880EC34C40FE0DDAAB8F933D402B685A6265C24C40D13B1570CF8F3D402B685A6265C24C40
15354	Городовик	3	32	683	30.122226999999999	30.141784000000001	57.403740999999997	57.388317999999998	0103000020E610000001000000050000002DB0C7444A1F3E405C397B67B4B14C402DB0C7444A1F3E40F486FBC8ADB34C409818CBF44B243E40F486FBC8ADB34C409818CBF44B243E405C397B67B4B14C402DB0C7444A1F3E405C397B67B4B14C40
57411	Вязье	3	32	683	29.816161999999998	29.833822999999999	57.637878000000001	57.629783000000003	0103000020E61000000100000005000000EA3C2AFEEFD03D40D449B6BA9CD04C40EA3C2AFEEFD03D40406B7EFCA5D14C4011A7936C75D53D40406B7EFCA5D14C4011A7936C75D53D40D449B6BA9CD04C40EA3C2AFEEFD03D40D449B6BA9CD04C40
11244	Ямм	3	32	596	28.046975	28.088244	58.428764000000001	58.412655000000001	0103000020E61000000100000005000000C7BAB88D060C3C40F4C308E1D1344D40C7BAB88D060C3C40E0D91EBDE1364D407711A62897163C40E0D91EBDE1364D407711A62897163C40F4C308E1D1344D40C7BAB88D060C3C40F4C308E1D1344D40
46970	Трутнево	3	32	596	27.931927999999999	27.951017	58.622030000000002	58.613529	0103000020E61000000100000005000000083A5AD592EE3B40E412471E884E4D40083A5AD592EE3B40C190D5AD9E4F4D40A6F0A0D975F33B40C190D5AD9E4F4D40A6F0A0D975F33B40E412471E884E4D40083A5AD592EE3B40E412471E884E4D40
59082	Смуравьево-2	3	32	596	27.358281999999999	28.595593999999998	59.021847999999999	58.166397000000003	0103000020E61000000100000005000000D7BE805EB85B3B408693347F4C154D40D7BE805EB85B3B40D3BD4EEACB824D409EB12FD978983C40D3BD4EEACB824D409EB12FD978983C408693347F4C154D40D7BE805EB85B3B408693347F4C154D40
12348	Самолва	3	32	596	27.613844	27.628989000000001	58.294818999999997	58.287703999999998	0103000020E6100000010000000500000088D860E1249D3B40D576137CD3244D4088D860E1249D3B40A59E05A1BC254D40338B506C05A13B40A59E05A1BC254D40338B506C05A13B40D576137CD3244D4088D860E1249D3B40D576137CD3244D40
19484	Ремда	3	32	596	27.783607	27.792051000000001	58.316578999999997	58.311591999999997	0103000020E61000000100000005000000ABEAE5779AC83B40FDD8243FE2274D40ABEAE5779AC83B40D9CC21A985284D409CC3B5DAC3CA3B40D9CC21A985284D409CC3B5DAC3CA3B40FDD8243FE2274D40ABEAE5779AC83B40FDD8243FE2274D40
29454	Полна	3	32	596	28.132127000000001	28.177302999999998	58.457090000000001	58.447225000000003	0103000020E6100000010000000500000029EB3713D3213C40107A36AB3E394D4029EB3713D3213C4011AAD4EC813A4D40917BBABA632D3C4011AAD4EC813A4D40917BBABA632D3C40107A36AB3E394D4029EB3713D3213C40107A36AB3E394D40
29065	Полично	3	32	596	27.806487000000001	27.823554999999999	58.807088	58.796660000000003	0103000020E610000001000000050000002FA699EE75CE3B40040473F4F8654D402FA699EE75CE3B403D7FDAA84E674D4010751F80D4D23B403D7FDAA84E674D4010751F80D4D23B40040473F4F8654D402FA699EE75CE3B40040473F4F8654D40
46948	Плесна	3	32	596	28.291497	28.305043000000001	58.776107000000003	58.765501999999998	0103000020E61000000100000005000000D2E1218C9F4A3C40E48233F8FB614D40D2E1218C9F4A3C402D99637957634D40ADDF4C4C174E3C402D99637957634D40ADDF4C4C174E3C40E48233F8FB614D40D2E1218C9F4A3C40E48233F8FB614D40
57454	Первомайское	3	32	596	28.36214	28.373073000000002	58.438930999999997	58.433500000000002	0103000020E61000000100000005000000CD920035B55C3C40736891ED7C374D40CD920035B55C3C40AC1919E42E384D4047054EB6815F3C40AC1919E42E384D4047054EB6815F3C40736891ED7C374D40CD920035B55C3C40736891ED7C374D40
57452	Партизанская	3	32	596	28.043265000000002	28.076816999999998	58.459834999999998	58.445323000000002	0103000020E61000000100000005000000BB0F406A130B3C400C94145800394D40BB0F406A130B3C4030478FDFDB3A4D40DEC66647AA133C4030478FDFDB3A4D40DEC66647AA133C400C94145800394D40BB0F406A130B3C400C94145800394D40
46627	Островцы	3	32	596	27.697171000000001	27.712910000000001	58.409733000000003	58.404828999999999	0103000020E6100000010000000500000039B874CC79B23B4077BCC96FD1334D4039B874CC79B23B40C68B852172344D40CAFD0E4581B63B40C68B852172344D40CAFD0E4581B63B4077BCC96FD1334D4039B874CC79B23B4077BCC96FD1334D40
29084	Кануновщина	3	32	596	27.863306000000001	27.878882000000001	58.847749999999998	58.840077000000001	0103000020E61000000100000005000000CA703C9F01DD3B40978FA4A4876B4D40CA703C9F01DD3B408D976E12836C4D40070B2769FEE03B408D976E12836C4D40070B2769FEE03B40978FA4A4876B4D40CA703C9F01DD3B40978FA4A4876B4D40
49112	Залесье	3	32	596	28.059488999999999	28.066316	58.936444000000002	58.933477000000003	0103000020E61000000100000005000000C478CDAB3A0F3C40BB48A12C7C774D40C478CDAB3A0F3C408944A165DD774D409833DB15FA103C408944A165DD774D409833DB15FA103C40BB48A12C7C774D40C478CDAB3A0F3C40BB48A12C7C774D40
28860	Гдов	3	32	596	27.800864000000001	27.839464	58.753315000000001	58.728565000000003	0103000020E61000000100000005000000338B506C05CD3B405001309E415D4D40338B506C05CD3B400A4B3CA06C604D405A2BDA1CE7D63B400A4B3CA06C604D405A2BDA1CE7D63B405001309E415D4D40338B506C05CD3B405001309E415D4D40
46885	Вейно	3	32	596	28.090848999999999	28.120978000000001	58.965584	58.950640999999997	0103000020E61000000100000005000000D2DF4BE141173C404D9EB29AAE794D40D2DF4BE141173C403BC5AA41987B4D401689096AF81E3C403BC5AA41987B4D401689096AF81E3C404D9EB29AAE794D40D2DF4BE141173C404D9EB29AAE794D40
57418	пос. Нагорный	3	32	537	30.171994000000002	31.064945999999999	56.779195000000001	55.911396000000003	0103000020E61000000100000005000000B51B7DCC072C3E4045DAC69FA8F44B40B51B7DCC072C3E40761A69A9BC634C408A01124DA0103F40761A69A9BC634C408A01124DA0103F4045DAC69FA8F44B40B51B7DCC072C3E4045DAC69FA8F44B40
57428	д. Колюбаки	3	32	537	30.171994000000002	31.064945999999999	56.779195000000001	55.911396000000003	0103000020E61000000100000005000000B51B7DCC072C3E4045DAC69FA8F44B40B51B7DCC072C3E40761A69A9BC634C408A01124DA0103F40761A69A9BC634C408A01124DA0103F4045DAC69FA8F44B40B51B7DCC072C3E4045DAC69FA8F44B40
52499	Шелково	3	32	537	30.602916	30.640753	56.358207999999998	56.337356999999997	0103000020E61000000100000005000000323CF6B3589A3E40D009A1832E2B4C40323CF6B3589A3E4031957EC2D92D4C405BD07B6308A43E4031957EC2D92D4C405BD07B6308A43E40D009A1832E2B4C40323CF6B3589A3E40D009A1832E2B4C40
52489	Черпесса	3	32	537	30.633872	30.653131999999999	56.694316000000001	56.680132999999998	0103000020E61000000100000005000000A1D9756F45A23E4016F71F990E574C40A1D9756F45A23E40768BC058DF584C4098F8A3A833A73E40768BC058DF584C4098F8A3A833A73E4016F71F990E574C40A1D9756F45A23E4016F71F990E574C40
57433	Федорково	3	32	537	30.677063	30.693276999999998	56.175756999999997	56.170205000000003	0103000020E61000000100000005000000E754320054AD3E40CF4E0647C9154C40E754320054AD3E40838593347F164C40A911FA997AB13E40838593347F164C40A911FA997AB13E40CF4E0647C9154C40E754320054AD3E40CF4E0647C9154C40
52485	Успенское	3	32	537	30.750966999999999	30.774144	56.097456999999999	56.084555999999999	0103000020E610000001000000050000000F60915F3FC03E401D5723BBD20A4C400F60915F3FC03E4015E29178790C4C4006651A4D2EC63E4015E29178790C4C4006651A4D2EC63E401D5723BBD20A4C400F60915F3FC03E401D5723BBD20A4C40
52484	Урицкое	3	32	537	30.561854	30.587761	56.024948999999999	56.013573000000001	0103000020E610000001000000050000007520EBA9D58F3E40E78D93C2BC014C407520EBA9D58F3E40B188618731034C4040DD408177963E40B188618731034C4040DD408177963E40E78D93C2BC014C407520EBA9D58F3E40E78D93C2BC014C40
57445	Троица	3	32	537	30.662527999999998	30.683719	56.041868000000001	56.029848000000001	0103000020E610000001000000050000002DAF5C6F9BA93E40EEEC2B0FD2034C402DAF5C6F9BA93E40DD5F3DEE5B054C4061A7583508AF3E40DD5F3DEE5B054C4061A7583508AF3E40EEEC2B0FD2034C402DAF5C6F9BA93E40EEEC2B0FD2034C40
25604	Тарасы	3	32	537	30.917245000000001	30.962897999999999	56.527793000000003	56.506881	0103000020E61000000100000005000000666B7D91D0EA3E405DFB027AE1404C40666B7D91D0EA3E40640795B88E434C404162BB7B80F63E40640795B88E434C404162BB7B80F63E405DFB027AE1404C40666B7D91D0EA3E405DFB027AE1404C40
52494	Суханово	3	32	537	30.662904999999999	30.685210000000001	56.331941999999998	56.321496000000003	0103000020E61000000100000005000000D95A5F24B4A93E40BDE5EAC726294C40D95A5F24B4A93E409C1551137D2A4C4065E42CEC69AF3E409C1551137D2A4C4065E42CEC69AF3E40BDE5EAC726294C40D95A5F24B4A93E40BDE5EAC726294C40
58954	Рыжково	3	32	537	30.620235000000001	30.688003999999999	56.361767999999998	56.322933999999997	0103000020E61000000100000005000000A6D590B8C79E3E401B62BCE655294C40A6D590B8C79E3E40A25EF0694E2E4C406684B70721B03E40A25EF0694E2E4C406684B70721B03E401B62BCE655294C40A6D590B8C79E3E401B62BCE655294C40
57405	Русаново	3	32	537	30.352142000000001	30.376459000000001	56.398685	56.386369000000002	0103000020E610000001000000050000004C8C65FA255A3E401898158A74314C404C8C65FA255A3E40F0332E1C08334C40ED48F59D5F603E40F0332E1C08334C40ED48F59D5F603E401898158A74314C404C8C65FA255A3E401898158A74314C40
57403	Поречье	3	32	537	30.460066000000001	30.497129999999999	56.106419000000002	56.083677000000002	0103000020E610000001000000050000006500A8E2C6753E40B5368DEDB50A4C406500A8E2C6753E40265646239F0D4C4048DC63E9437F3E40265646239F0D4C4048DC63E9437F3E40B5368DEDB50A4C406500A8E2C6753E40B5368DEDB50A4C40
52436	Полибино	3	32	537	30.383133999999998	30.416803000000002	56.139029999999998	56.127842999999999	0103000020E6100000010000000500000054FCDF1115623E40E202D0285D104C4054FCDF1115623E40D9942BBCCB114C40ECDFF599B36A3E40D9942BBCCB114C40ECDFF599B36A3E40E202D0285D104C4054FCDF1115623E40E202D0285D104C40
57422	Першино	3	32	537	30.596672000000002	30.731375	56.336497999999999	56.286298000000002	0103000020E610000001000000050000005D70067FBF983E408274B169A5244C405D70067FBF983E40AF95D05D122B4C40AC1C5A643BBB3E40AF95D05D122B4C40AC1C5A643BBB3E408274B169A5244C405D70067FBF983E408274B169A5244C40
52467	Переслегино	3	32	537	30.431426999999999	30.448153999999999	56.388720999999997	56.379975000000002	0103000020E61000000100000005000000849CF7FF716E3E4018265305A3304C40849CF7FF716E3E405B22179CC1314C4053927538BA723E405B22179CC1314C4053927538BA723E4018265305A3304C40849CF7FF716E3E4018265305A3304C40
46456	Марьино	3	32	537	30.603283999999999	30.608754999999999	56.496026000000001	56.490813000000003	0103000020E610000001000000050000003733FAD1709A3E40D0B9DBF5D23E4C403733FAD1709A3E409CFBABC77D3F4C40C746205ED79B3E409CFBABC77D3F4C40C746205ED79B3E40D0B9DBF5D23E4C403733FAD1709A3E40D0B9DBF5D23E4C40
52473	Майкино	3	32	537	30.489709999999999	30.500059	56.381101000000001	56.374003000000002	0103000020E610000001000000050000002F8672A25D7D3E408ECD8E54DF2F4C402F8672A25D7D3E4088BCE5EAC7304C400A12DBDD03803E4088BCE5EAC7304C400A12DBDD03803E408ECD8E54DF2F4C402F8672A25D7D3E408ECD8E54DF2F4C40
52464	Лычево	3	32	537	30.608170999999999	30.614764999999998	56.336407999999999	56.327979999999997	0103000020E6100000010000000500000028603B18B19B3E40FCDEA63FFB294C4028603B18B19B3E406F0ED76A0F2B4C40B6B9313D619D3E406F0ED76A0F2B4C40B6B9313D619D3E40FCDEA63FFB294C4028603B18B19B3E40FCDEA63FFB294C40
57396	Липец	3	32	537	30.665842999999999	30.692855000000002	56.261713	56.253762000000002	0103000020E610000001000000050000004145D5AF74AA3E40D97BF1457B204C404145D5AF74AA3E4012F8C3CF7F214C40BEDEFDF15EB13E4012F8C3CF7F214C40BEDEFDF15EB13E40D97BF1457B204C404145D5AF74AA3E40D97BF1457B204C40
52451	Купуй	3	32	537	30.502044000000001	30.536359999999998	56.235965999999998	56.218642000000003	0103000020E610000001000000050000002D27A1F485803E401AC40776FC1B4C402D27A1F485803E40E57B4622341E4C40EFE192E34E893E40E57B4622341E4C40EFE192E34E893E401AC40776FC1B4C402D27A1F485803E401AC40776FC1B4C40
28254	Костелево	3	32	537	30.486404	30.491201	55.96407	55.961022	0103000020E61000000100000005000000C2A4F8F8847C3E40465ED6C402FB4B40C2A4F8F8847C3E40018750A566FB4B4033C34659BF7D3E40018750A566FB4B4033C34659BF7D3E40465ED6C402FB4B40C2A4F8F8847C3E40465ED6C402FB4B40
52468	Карцево	3	32	537	30.610074999999998	30.621556000000002	56.494306000000002	56.481360000000002	0103000020E61000000100000005000000711B0DE02D9C3E4021CD58349D3D4C40711B0DE02D9C3E40B91B446B453F4C40F1A1444B1E9F3E40B91B446B453F4C40F1A1444B1E9F3E4021CD58349D3D4C40711B0DE02D9C3E4021CD58349D3D4C40
48419	Иваново	3	32	537	30.247713000000001	30.267790000000002	56.470073999999997	56.458098999999997	0103000020E6100000010000000500000047CB811E6A3F3E4047AAEFFCA23A4C4047CB811E6A3F3E40965984622B3C4C402332ACE28D443E40965984622B3C4C402332ACE28D443E4047AAEFFCA23A4C4047CB811E6A3F3E4047AAEFFCA23A4C40
25903	Дубрава 1-я	3	32	537	30.572894000000002	30.613318	56.332915	56.310822000000002	0103000020E610000001000000050000001B13622EA9923E404C70EA03C9274C401B13622EA9923E4086AC6EF59C2A4C40520C9068029D3E4086AC6EF59C2A4C40520C9068029D3E404C70EA03C9274C401B13622EA9923E404C70EA03C9274C40
25849	Дорожный	3	32	537	30.499610000000001	30.514655999999999	56.305953000000002	56.286997	0103000020E610000001000000050000002BC1E270E67F3E406A865451BC244C402BC1E270E67F3E407A8EC87729274C40AFB0E07EC0833E407A8EC87729274C40AFB0E07EC0833E406A865451BC244C402BC1E270E67F3E406A865451BC244C40
57444	Демидово	3	32	537	30.617702000000001	30.638794000000001	56.399237999999997	56.385935000000003	0103000020E610000001000000050000007EACE0B7219E3E40DEB06D5166314C407EACE0B7219E3E4004A9143B1A334C408BE1EA0088A33E4004A9143B1A334C408BE1EA0088A33E40DEB06D5166314C407EACE0B7219E3E40DEB06D5166314C40
49048	Глазуново	3	32	537	30.438416	30.450202000000001	56.131515999999998	56.124907999999998	0103000020E610000001000000050000000B0BEE073C703E401F813FFCFC0F4C400B0BEE073C703E404B732B84D5104C400398327040733E404B732B84D5104C400398327040733E401F813FFCFC0F4C400B0BEE073C703E401F813FFCFC0F4C40
57424	Великополье	3	32	537	30.812114999999999	30.832246999999999	56.374929999999999	56.353653999999999	0103000020E610000001000000050000004E97C5C4E6CF3E40BF0CC688442D4C404E97C5C4E6CF3E400725CCB4FD2F4C40B131AF230ED53E400725CCB4FD2F4C40B131AF230ED53E40BF0CC688442D4C404E97C5C4E6CF3E40BF0CC688442D4C40
52453	Булынино	3	32	537	30.515384000000001	30.534984999999999	56.288746000000003	56.277343000000002	0103000020E61000000100000005000000B5E1B034F0833E402463B5F97F234C40B5E1B034F0833E40E86C01A1F5244C40BED9E6C6F4883E40E86C01A1F5244C40BED9E6C6F4883E402463B5F97F234C40B5E1B034F0833E402463B5F97F234C40
52439	Букрово 2-е	3	32	537	30.772302	30.780728	56.547080999999999	56.542713999999997	0103000020E61000000100000005000000A9A27895B5C53E40698A00A777454C40A9A27895B5C53E40A9A10DC006464C404D124BCADDC73E40A9A10DC006464C404D124BCADDC73E40698A00A777454C40A9A27895B5C53E40698A00A777454C40
57395	Борки	3	32	537	30.235855000000001	30.259104000000001	56.085329000000002	56.075091999999998	0103000020E610000001000000050000001C9947FE603C3E407A185A9D9C094C401C9947FE603C3E404033880FEC0A4C404643C6A354423E404033880FEC0A4C404643C6A354423E407A185A9D9C094C401C9947FE603C3E407A185A9D9C094C40
57402	Баландино	3	32	537	30.592549000000002	30.618528000000001	56.379550999999999	56.355454999999999	0103000020E610000001000000050000000B47904AB1973E408F19A88C7F2D4C400B47904AB1973E4001158E2095304C4009A9DBD9579E3E4001158E2095304C4009A9DBD9579E3E408F19A88C7F2D4C400B47904AB1973E408F19A88C7F2D4C40
18637	Шилово	3	32	543	29.888646999999999	29.906838	57.143742000000003	57.133861000000003	0103000020E6100000010000000500000042B0AA5E7EE33D40DD9A745B22914C4042B0AA5E7EE33D40E4874A2366924C4022C5008926E83D40E4874A2366924C4022C5008926E83D40DD9A745B22914C4042B0AA5E7EE33D40DD9A745B22914C40
18628	Чихачево	3	32	543	29.886581	29.924893999999998	57.292845	57.272829999999999	0103000020E610000001000000050000004641F0F8F6E23D4010AFEB17ECA24C404641F0F8F6E23D4008E6E8F17BA54C4041446ADAC5EC3D4008E6E8F17BA54C4041446ADAC5EC3D4010AFEB17ECA24C404641F0F8F6E23D4010AFEB17ECA24C40
18558	Цевло	3	32	543	30.271841999999999	30.289439999999999	57.052574999999997	57.040098999999998	0103000020E61000000100000005000000E2ADF36F97453E4018CDCAF621854C40E2ADF36F97453E4029CB10C7BA864C407C2766BD184A3E4029CB10C7BA864C407C2766BD184A3E4018CDCAF621854C40E2ADF36F97453E4018CDCAF621854C40
18448	Ублиска	3	32	543	29.758185000000001	29.769459000000001	57.222689000000003	57.211435999999999	0103000020E610000001000000050000005951836918C23D403999B855109B4C405951836918C23D40E816BA12819C4C40E59CD843FBC43D40E816BA12819C4C40E59CD843FBC43D403999B855109B4C405951836918C23D403999B855109B4C40
45791	Спицино	3	32	543	30.065193000000001	30.076951999999999	56.927089000000002	56.922786000000002	0103000020E610000001000000050000009AED0A7DB0103E40749A05DA1D764C409AED0A7DB0103E409DBD33DAAA764C409E5C5320B3133E409DBD33DAAA764C409E5C5320B3133E40749A05DA1D764C409AED0A7DB0103E40749A05DA1D764C40
15333	Сосонка	3	32	543	29.974993000000001	30.002777999999999	57.431125999999999	57.415743999999997	0103000020E6100000010000000500000035D4282499F93D400DC1711937B54C4035D4282499F93D40473A03232FB74C40F6251B0FB6003E40473A03232FB74C40F6251B0FB6003E400DC1711937B54C4035D4282499F93D400DC1711937B54C40
18492	Сапрыгино	3	32	543	29.741745999999999	29.759073999999998	57.070982000000001	57.061278000000001	0103000020E6100000010000000500000056F0DB10E3BD3D406EFB1EF5D7874C4056F0DB10E3BD3D40664D2CF015894C40703E75AC52C23D40664D2CF015894C40703E75AC52C23D406EFB1EF5D7874C4056F0DB10E3BD3D406EFB1EF5D7874C40
18372	Махново	3	32	543	29.808446	29.835978999999998	56.963484000000001	56.956181000000001	0103000020E61000000100000005000000FF942A51F6CE3D403E079623647A4C40FF942A51F6CE3D40111C9771537B4C408D2441B802D63D40111C9771537B4C408D2441B802D63D403E079623647A4C40FF942A51F6CE3D403E079623647A4C40
18333	Лющик	3	32	543	29.898682000000001	29.908041999999998	57.014684000000003	57.010312999999996	0103000020E61000000100000005000000FE80070610E63D40A0DCB6EF51814C40FE80070610E63D4022E3512AE1814C40F964C57075E83D4022E3512AE1814C40F964C57075E83D40A0DCB6EF51814C40FE80070610E63D40A0DCB6EF51814C40
18278	Кудеверь	3	32	543	29.398606999999998	29.422250999999999	56.782159	56.763449999999999	0103000020E61000000100000005000000E8F4BC1B0B663D40CB10C7BAB8614C40E8F4BC1B0B663D40D3A23EC91D644C400BB43BA4186C3D40D3A23EC91D644C400BB43BA4186C3D40CB10C7BAB8614C40E8F4BC1B0B663D40CB10C7BAB8614C40
18248	Красный Луч	3	32	543	30.059920000000002	30.108546	57.078951000000004	57.057513999999998	0103000020E610000001000000050000005760C8EA560F3E40F487669E5C874C405760C8EA560F3E40467EFD101B8A4C40931CB0ABC91B3E40467EFD101B8A4C40931CB0ABC91B3E40F487669E5C874C405760C8EA560F3E40F487669E5C874C40
59089	Кошелево	3	32	543	29.819181	29.825019999999999	56.901789000000001	56.895560000000003	0103000020E610000001000000050000002C8194D8B5D13D408ACDC7B5A1724C402C8194D8B5D13D403F726BD26D734C40C18BBE8234D33D403F726BD26D734C40C18BBE8234D33D408ACDC7B5A1724C402C8194D8B5D13D408ACDC7B5A1724C40
57459	Заполье	3	32	543	29.918894000000002	29.942537000000002	57.028740999999997	57.015884999999997	0103000020E610000001000000050000009A7D1EA33CEB3D409CBF098508824C409A7D1EA33CEB3D40F486FBC8AD834C401C45D61A4AF13D40F486FBC8AD834C401C45D61A4AF13D409CBF098508824C409A7D1EA33CEB3D409CBF098508824C40
18196	Добрывичи	3	32	543	29.862093000000002	29.879619000000002	57.222050000000003	57.212240000000001	0103000020E610000001000000050000004C1C7920B2DC3D40977329AE2A9B4C404C1C7920B2DC3D40D50968226C9C4C40B3F0F5B52EE13D40D50968226C9C4C40B3F0F5B52EE13D40977329AE2A9B4C404C1C7920B2DC3D40977329AE2A9B4C40
18092	Дворцы	3	32	543	29.789985000000001	29.807556000000002	56.924047999999999	56.909176000000002	0103000020E61000000100000005000000A054FB743CCA3D40702711E15F744C40A054FB743CCA3D4094F7713447764C4047B071FDBBCE3D4094F7713447764C4047B071FDBBCE3D40702711E15F744C40A054FB743CCA3D40702711E15F744C40
16908	Гривы	3	32	543	30.000496999999999	30.011465000000001	57.347999000000002	57.345517999999998	0103000020E6100000010000000500000001BF469220003E40F4160FEF39AC4C4001BF469220003E403605323B8BAC4C40740CC85EEF023E403605323B8BAC4C40740CC85EEF023E40F4160FEF39AC4C4001BF469220003E40F4160FEF39AC4C40
18059	Гора	3	32	543	29.812775999999999	29.845213999999999	57.096729000000003	57.083818999999998	0103000020E6100000010000000500000044F9821612D03D4047E4BB94BA8A4C4044F9821612D03D4093C9A99D618C4C40101FD8F15FD83D4093C9A99D618C4C40101FD8F15FD83D4047E4BB94BA8A4C4044F9821612D03D4047E4BB94BA8A4C40
45773	Быково	3	32	543	29.763584000000002	29.768183000000001	56.990561999999997	56.987045999999999	0103000020E61000000100000005000000B6BFB33D7AC33D40E5D2F885577E4C40B6BFB33D7AC33D40865451BCCA7E4C40DA571EA4A7C43D40865451BCCA7E4C40DA571EA4A7C43D40E5D2F885577E4C40B6BFB33D7AC33D40E5D2F885577E4C40
17910	Бежаницы	3	32	543	29.863216000000001	29.923124999999999	57.021220999999997	56.967066000000003	0103000020E610000001000000050000004A6249B9FBDC3D406A8995D1C87B4C404A6249B9FBDC3D40847EA65EB7824C40B81E85EB51EC3D40847EA65EB7824C40B81E85EB51EC3D406A8995D1C87B4C404A6249B9FBDC3D406A8995D1C87B4C40
17847	Бардово	3	32	543	29.354536	29.376248	56.682946000000001	56.671008999999998	0103000020E6100000010000000500000031410DDFC25A3D402C29779FE3554C4031410DDFC25A3D408E7747C66A574C40772FF7C951603D408E7747C66A574C40772FF7C951603D402C29779FE3554C4031410DDFC25A3D402C29779FE3554C40
17788	Ашево	3	32	543	29.708760000000002	29.761175999999999	57.119687999999996	57.106791000000001	0103000020E6100000010000000500000085B69C4B71B53D40EA40D653AB8D4C4085B69C4B71B53D40A0DCB6EF518F4C4006802A6EDCC23D40A0DCB6EF518F4C4006802A6EDCC23D40EA40D653AB8D4C4085B69C4B71B53D40EA40D653AB8D4C40
17757	Аполье	3	32	543	29.887488000000001	29.910881	56.882717	56.876722000000001	0103000020E61000000100000005000000AB97DF6932E33D4084D72E6D38704C40AB97DF6932E33D40C64FE3DEFC704C403B8C497F2FE93D40C64FE3DEFC704C403B8C497F2FE93D4084D72E6D38704C40AB97DF6932E33D4084D72E6D38704C40
146	Шолохово	3	31	\N	31.359468	31.36758	58.5182	58.513716000000002	0103000020E6100000010000000500000062F54718065C3F404AB72572C1414D4062F54718065C3F40C364AA6054424D40E7A90EB9195E3F40C364AA6054424D40E7A90EB9195E3F404AB72572C1414D4062F54718065C3F404AB72572C1414D40
15086	Сырково	3	31	\N	31.225124999999998	31.240072999999999	58.585211999999999	58.573577	0103000020E610000001000000050000001283C0CAA1393F40705E9CF86A494D401283C0CAA1393F40069D103AE84A4D4011A7936C753D3F40069D103AE84A4D4011A7936C753D3F40705E9CF86A494D401283C0CAA1393F40705E9CF86A494D40
57344	Старая Русса	3	31	\N	31.313717	31.39134	58.015914000000002	57.968438999999996	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
57350	Сольцы	3	31	\N	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
1338	Слутка	3	31	\N	31.414068	31.438825000000001	58.639443	58.615651999999997	0103000020E61000000100000005000000F451465C006A3F40C6DB4AAFCD4E4D40F451465C006A3F40FC53AA44D9514D40CEAACFD556703F40FC53AA44D9514D40CEAACFD556703F40C6DB4AAFCD4E4D40F451465C006A3F40C6DB4AAFCD4E4D40
57345	Пестово	3	31	\N	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
57347	Окуловка	3	31	\N	33.25273	33.341628	58.427219000000001	58.365101000000003	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
57343	Малая Вишера	3	31	\N	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
14948	Григорово	3	31	\N	31.198354999999999	31.220327999999999	58.554054999999998	58.542197999999999	0103000020E6100000010000000500000082FFAD64C7323F4072FA7ABE66454D4082FFAD64C7323F40B7973446EB464D40A164726A67383F40B7973446EB464D40A164726A67383F4072FA7ABE66454D4082FFAD64C7323F4072FA7ABE66454D40
1808	Великий Новгород	3	31	\N	31.197565000000001	31.425754999999999	58.650545999999999	58.470453999999997	0103000020E6100000010000000500000091D5AD9E93323F40DD2230D6373C4D4091D5AD9E93323F409545611745534D40C51B9947FE6C3F409545611745534D40C51B9947FE6C3F40DD2230D6373C4D4091D5AD9E93323F40DD2230D6373C4D40
57346	Валдай	3	31	\N	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
57342	Боровичи	3	31	\N	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
25098	Шимск	3	31	371	30.695038	30.731555	58.222036000000003	58.202319000000003	0103000020E610000001000000050000002D7AA702EEB13E40022EC896E5194D402D7AA702EEB13E407044F7AC6B1C4D40AC39403047BB3E407044F7AC6B1C4D40AC39403047BB3E40022EC896E5194D402D7AA702EEB13E40022EC896E5194D40
57367	Уторгош	3	31	371	30.223890000000001	30.261565000000001	58.288933999999998	58.270702999999997	0103000020E61000000100000005000000C5E6E3DA50393E40ECF65965A6224D40C5E6E3DA50393E40EA5910CAFB244D403BC780ECF5423E40EA5910CAFB244D403BC780ECF5423E40ECF65965A6224D40C5E6E3DA50393E40ECF65965A6224D40
2159	Турская Горка	3	31	371	30.225614	30.244236000000001	58.374237999999998	58.366588	0103000020E610000001000000050000000E85CFD6C1393E40938D075BEC2E4D400E85CFD6C1393E40D175E107E72F4D4080812040863E3E40D175E107E72F4D4080812040863E3E40938D075BEC2E4D400E85CFD6C1393E40938D075BEC2E4D40
2062	Старый Медведь	3	31	371	30.480934000000001	30.507954999999999	58.305610999999999	58.285196999999997	0103000020E61000000100000005000000D388997D1E7B3E406AF5D55581244D40D388997D1E7B3E402026E1421E274D40F5D6C05609823E402026E1421E274D40F5D6C05609823E406AF5D55581244D40D388997D1E7B3E406AF5D55581244D40
6948	Подгощи	3	31	371	30.723963999999999	30.753276	58.169178000000002	58.154877999999997	0103000020E61000000100000005000000397B67B455B93E40586FD40AD3134D40397B67B455B93E40F299EC9FA7154D4098DC28B2D6C03E40F299EC9FA7154D4098DC28B2D6C03E40586FD40AD3134D40397B67B455B93E40586FD40AD3134D40
1904	Мшага-Ямская	3	31	371	30.579515000000001	30.603014999999999	58.207687	58.197951000000003	0103000020E610000001000000050000009C8A54185B943E40F29A577556194D409C8A54185B943E40F566D47C951A4D4058FFE7305F9A3E40F566D47C951A4D4058FFE7305F9A3E40F29A577556194D409C8A54185B943E40F29A577556194D40
2016	Менюша	3	31	371	30.698281000000001	30.715078999999999	58.391506999999997	58.360928000000001	0103000020E610000001000000050000000E6B2A8BC2B23E40F81A82E3322E4D400E6B2A8BC2B23E40D993C0E61C324D406F0ED76A0FB73E40D993C0E61C324D406F0ED76A0FB73E40F81A82E3322E4D400E6B2A8BC2B23E40F81A82E3322E4D40
1958	Медведь	3	31	371	30.498864000000001	30.525660999999999	58.311407000000003	58.292893999999997	0103000020E61000000100000005000000D926158DB57F3E40E998F38C7D254D40D926158DB57F3E406C5F402FDC274D405CC823B891863E406C5F402FDC274D405CC823B891863E40E998F38C7D254D40D926158DB57F3E40E998F38C7D254D40
7016	Любыни	3	31	371	30.610389999999999	30.628491	58.105671999999998	58.092308000000003	0103000020E6100000010000000500000031CEDF84429C3E406094A0BFD00B4D4031CEDF84429C3E402C0DFCA8860D4D4091D442C9E4A03E402C0DFCA8860D4D4091D442C9E4A03E406094A0BFD00B4D4031CEDF84429C3E406094A0BFD00B4D40
25077	Красный Двор	3	31	371	30.647490000000001	30.667514000000001	58.192397	58.184013999999998	0103000020E61000000100000005000000AF7C96E7C1A53E40C90050C58D174D40AF7C96E7C1A53E409C6C0377A0184D40459F8F32E2AA3E409C6C0377A0184D40459F8F32E2AA3E40C90050C58D174D40AF7C96E7C1A53E40C90050C58D174D40
6860	Коростынь	3	31	371	30.969725	30.996441000000001	58.191192000000001	58.183225999999998	0103000020E61000000100000005000000151DC9E53FF83E4071E316F373174D40151DC9E53FF83E40E0A0BDFA78184D40BF64E3C116FF3E40E0A0BDFA78184D40BF64E3C116FF3E4071E316F373174D40151DC9E53FF83E4071E316F373174D40
2153	Закибье	3	31	371	30.388829000000001	30.411259999999999	58.349845999999999	58.336945999999998	0103000020E6100000010000000500000084BC1E4C8A633E404E42E90B212B4D4084BC1E4C8A633E407651F4C0C72C4D402827DA5548693E407651F4C0C72C4D402827DA5548693E404E42E90B212B4D4084BC1E4C8A633E404E42E90B212B4D40
24942	Горцы	3	31	371	30.852153000000001	30.882345999999998	58.177478999999998	58.173754000000002	0103000020E610000001000000050000003430F2B226DA3E404CC631923D164D403430F2B226DA3E40075DC2A1B7164D40A4C16D6DE1E13E40075DC2A1B7164D40A4C16D6DE1E13E404CC631923D164D403430F2B226DA3E404CC631923D164D40
25595	Городище	3	31	371	29.890031	29.904430999999999	58.250771	58.246366000000002	0103000020E610000001000000050000001A6D5512D9E33D40556CCCEB881F4D401A6D5512D9E33D4082E49D4319204D40137D3ECA88E73D4082E49D4319204D40137D3ECA88E73D40556CCCEB881F4D401A6D5512D9E33D40556CCCEB881F4D40
6922	Веряжа	3	31	371	30.995398999999999	31.009951000000001	58.164099	58.154817000000001	0103000020E610000001000000050000009A780778D2FE3E40B3EE1F0BD1134D409A780778D2FE3E4035272F3201154D40009013268C023F4035272F3201154D40009013268C023F40B3EE1F0BD1134D409A780778D2FE3E40B3EE1F0BD1134D40
57370	Бор	3	31	371	30.658315000000002	30.679514999999999	58.203010999999996	58.199652999999998	0103000020E610000001000000050000005C77F35487A83E402EC6C03A8E194D405C77F35487A83E4037DDB243FC194D403524EEB1F4AD3E4037DDB243FC194D403524EEB1F4AD3E402EC6C03A8E194D405C77F35487A83E402EC6C03A8E194D40
2263	Большой Уторгош	3	31	371	30.110423000000001	30.127869	58.276836000000003	58.263176000000001	0103000020E61000000100000005000000E9B985AE441C3E40CA8B4CC0AF214D40E9B985AE441C3E40802DAF5C6F234D40172CD505BC203E40802DAF5C6F234D40172CD505BC203E40CA8B4CC0AF214D40E9B985AE441C3E40CA8B4CC0AF214D40
24483	Чудово	3	31	477	31.648167999999998	31.73208	59.140804000000003	59.111291000000001	0103000020E6100000010000000500000050508A56EEA53F4069AB92C83E8E4D4050508A56EEA53F40B0928FDD05924D40410E4A9869BB3F40B0928FDD05924D40410E4A9869BB3F4069AB92C83E8E4D4050508A56EEA53F4069AB92C83E8E4D40
24470	Успенское	3	31	477	31.637712000000001	31.659756999999999	59.127876999999998	59.105722999999998	0103000020E610000001000000050000004A44F81741A33F40AEB7CD54888D4D404A44F81741A33F408E7406465E904D409C4EB2D5E5A83F408E7406465E904D409C4EB2D5E5A83F40AEB7CD54888D4D404A44F81741A33F40AEB7CD54888D4D40
4981	Трегубово	3	31	477	31.541115999999999	31.557366999999999	58.995083999999999	58.983085000000003	0103000020E61000000100000005000000A3570394868A3F401618B2BAD57D4D40A3570394868A3F40ED629AE95E7F4D40A0DE8C9AAF8E3F40ED629AE95E7F4D40A0DE8C9AAF8E3F401618B2BAD57D4D40A3570394868A3F401618B2BAD57D4D40
24063	Суворовка	3	31	477	31.851618999999999	31.863899	59.026707000000002	59.020370999999997	0103000020E61000000100000005000000F8A6E9B303DA3F40B66455849B824D40F8A6E9B303DA3F4082C98D226B834D400F0C207C28DD3F4082C98D226B834D400F0C207C28DD3F40B66455849B824D40F8A6E9B303DA3F40B66455849B824D40
3195	Спасская-Полисть	3	31	477	31.506333000000001	31.519439999999999	58.930290999999997	58.917307999999998	0103000020E61000000100000005000000B5E21B0A9F813F40F92D3A596A754D40B5E21B0A9F813F40AE6186C613774D40F73B1405FA843F40AE6186C613774D40F73B1405FA843F40F92D3A596A754D40B5E21B0A9F813F40F92D3A596A754D40
24214	Селищи	3	31	477	31.661733000000002	31.674965	58.899614999999997	58.882615999999999	0103000020E6100000010000000500000019AF795567A93F409276A38FF9704D4019AF795567A93F40DAFE959526734D40D4F19881CAAC3F40DAFE959526734D40D4F19881CAAC3F409276A38FF9704D4019AF795567A93F409276A38FF9704D40
2947	Переход	3	31	477	31.902723999999999	31.914375	59.120035000000001	59.111156999999999	0103000020E61000000100000005000000765089EB18E73F4059DC7F643A8E4D40765089EB18E73F400CB08F4E5D8F4D40AE47E17A14EA3F400CB08F4E5D8F4D40AE47E17A14EA3F4059DC7F643A8E4D40765089EB18E73F4059DC7F643A8E4D40
3045	Оскуй	3	31	477	32.072280999999997	32.098861999999997	59.282916999999998	59.270834000000001	0103000020E61000000100000005000000A38FF980400940408B5242B0AAA24D40A38FF98040094040C03DCF9F36A44D4098689082A70C4040C03DCF9F36A44D4098689082A70C40408B5242B0AAA24D40A38FF980400940408B5242B0AAA24D40
3090	Краснофарфорный	3	31	477	31.840498	31.875775000000001	59.148626999999998	59.121957000000002	0103000020E61000000100000005000000795A7EE02AD73F40574277499C8F4D40795A7EE02AD73F40BB26A43506934D4087A757CA32E03F40BB26A43506934D4087A757CA32E03F40574277499C8F4D40795A7EE02AD73F40574277499C8F4D40
24369	Карловка	3	31	477	31.612622000000002	31.631307	59.262846000000003	59.248184999999999	0103000020E6100000010000000500000064CF9ECBD49C3F40CB2DAD86C49F4D4064CF9ECBD49C3F4035F10EF0A4A14D4062BCE6559DA13F4035F10EF0A4A14D4062BCE6559DA13F40CB2DAD86C49F4D4064CF9ECBD49C3F40CB2DAD86C49F4D40
24381	Зуево	3	31	477	31.523437000000001	31.551779	59.193596999999997	59.181320999999997	0103000020E6100000010000000500000030849CF7FF853F40FC89CA8635974D4030849CF7FF853F4046CD57C9C7984D409D9E7763418D3F4046CD57C9C7984D409D9E7763418D3F40FC89CA8635974D4030849CF7FF853F40FC89CA8635974D40
2850	Грузино	3	31	477	31.876968999999999	31.888943999999999	59.153154000000001	59.145280999999997	0103000020E61000000100000005000000179B560A81E03F4076DD5B9198924D40179B560A81E03F4034A0DE8C9A934D40B5F97FD591E33F4034A0DE8C9A934D40B5F97FD591E33F4076DD5B9198924D40179B560A81E03F4076DD5B9198924D40
2512	Чекуново	3	31	445	31.128816	31.140944000000001	57.199150000000003	57.190553000000001	0103000020E610000001000000050000009833DB15FA203F40CD936B0A64984C409833DB15FA203F40CC7F48BF7D994C404391EEE714243F40CC7F48BF7D994C404391EEE714243F40CD936B0A64984C409833DB15FA203F40CD936B0A64984C40
8724	Холм	3	31	445	31.155092	31.198803999999999	57.160916999999998	57.123373000000001	0103000020E6100000010000000500000009DFFB1BB4273F40CE1ABCAFCA8F4C4009DFFB1BB4273F406A2FA2ED98944C406150A6D1E4323F406A2FA2ED98944C406150A6D1E4323F40CE1ABCAFCA8F4C4009DFFB1BB4273F40CE1ABCAFCA8F4C40
2700	Тухомичи	3	31	445	31.533912000000001	31.565522999999999	57.044873000000003	57.034745999999998	0103000020E6100000010000000500000024F1F274AE883F405AD5928E72844C4024F1F274AE883F4099BC0166BE854C40C422861DC6903F4099BC0166BE854C40C422861DC6903F405AD5928E72844C4024F1F274AE883F405AD5928E72844C40
23880	Тогодь	3	31	445	31.707968999999999	31.714787999999999	57.101692	57.097174000000003	0103000020E61000000100000005000000F294D5743DB53F40C1029832708C4C40F294D5743DB53F40E621533E048D4C40C092AB58FCB63F40E621533E048D4C40C092AB58FCB63F40C1029832708C4C40F294D5743DB53F40C1029832708C4C40
23577	Сопки	3	31	445	30.906043	30.979489999999998	57.136386999999999	57.098816999999997	0103000020E610000001000000050000000DC51D6FF2E73E40F8A41309A68C4C400DC51D6FF2E73E40BE4C142175914C4050C24CDBBFFA3E40BE4C142175914C4050C24CDBBFFA3E40F8A41309A68C4C400DC51D6FF2E73E40F8A41309A68C4C40
23788	Наход	3	31	445	31.396317	31.412963000000001	57.167413000000003	57.158306000000003	0103000020E610000001000000050000004DD9E90775653F405B61FA5E43944C404DD9E90775653F406FF607CA6D954C40437573F1B7693F406FF607CA6D954C40437573F1B7693F405B61FA5E43944C404DD9E90775653F405B61FA5E43944C40
2647	Морхово	3	31	445	31.285509999999999	31.302955000000001	57.010097000000002	56.999141999999999	0103000020E6100000010000000500000053AEF02E17493F40AF0793E2E37F4C4053AEF02E17493F40D464C6DB4A814C40E12879758E4D3F40D464C6DB4A814C40E12879758E4D3F40AF0793E2E37F4C4053AEF02E17493F40AF0793E2E37F4C40
23859	Мамоново	3	31	445	31.486481000000001	31.500862999999999	57.126558000000003	57.115138999999999	0103000020E610000001000000050000001920D1048A7C3F4040BFEFDFBC8E4C401920D1048A7C3F400A86730D33904C40C5C6BC8E38803F400A86730D33904C40C5C6BC8E38803F4040BFEFDFBC8E4C401920D1048A7C3F4040BFEFDFBC8E4C40
23547	Красный Бор	3	31	445	30.796637	30.822859000000001	56.997602999999998	56.985436999999997	0103000020E6100000010000000500000097C80567F0CB3E4059A2B3CC227E4C4097C80567F0CB3E401CB28174B17F4C4022382EE3A6D23E401CB28174B17F4C4022382EE3A6D23E4059A2B3CC227E4C4097C80567F0CB3E4059A2B3CC227E4C40
23779	Залесье	3	31	445	31.215684	31.234566000000001	57.124569999999999	57.115872000000003	0103000020E610000001000000050000003D450E1137373F40D542C9E4D48E4C403D450E1137373F400708E6E8F18F4C40E8C072840C3C3F400708E6E8F18F4C40E8C072840C3C3F40D542C9E4D48E4C403D450E1137373F40D542C9E4D48E4C40
23345	Юбилейный	3	31	938	34.987566000000001	35.007157999999997	58.843829999999997	58.828713	0103000020E610000001000000050000001E520C90687E414091628044136A4D401E520C90687E41401CB1169F026C4D40CFF3A78DEA8041401CB1169F026C4D40CFF3A78DEA80414091628044136A4D401E520C90687E414091628044136A4D40
7571	Хвойная	3	31	938	34.479909999999997	34.551541	58.910820999999999	58.881853	0103000020E61000000100000005000000FD82DDB06D3D41409370218FE0704D40FD82DDB06D3D414048C153C895744D409AB33EE59846414048C153C895744D409AB33EE5984641409370218FE0704D40FD82DDB06D3D41409370218FE0704D40
9392	Песь	3	31	938	34.167521000000001	34.172713000000002	58.920588000000002	58.916559999999997	0103000020E6100000010000000500000055320054711541402F698CD651754D405532005471154140878BDCD3D5754D400A4CA7751B164140878BDCD3D5754D400A4CA7751B1641402F698CD651754D4055320054711541402F698CD651754D40
9383	Остахново	3	31	938	34.504784000000001	34.519328000000002	58.930926999999997	58.925970999999997	0103000020E61000000100000005000000A4C519C39C404140AF05BD3786764D40A4C519C39C40414050FBAD9D28774D40D4F203577942414050FBAD9D28774D40D4F2035779424140AF05BD3786764D40A4C519C39C404140AF05BD3786764D40
9329	Минцы	3	31	938	34.738661	34.769508999999999	58.950696999999998	58.919806999999999	0103000020E6100000010000000500000053EA92718C5E4140E1D05B3CBC754D4053EA92718C5E4140E1B37570B0794D40247D5A457F624140E1B37570B0794D40247D5A457F624140E1D05B3CBC754D4053EA92718C5E4140E1D05B3CBC754D40
9278	Миголощи	3	31	938	34.238199999999999	34.259284000000001	58.835458000000003	58.827641999999997	0103000020E610000001000000050000001FF46C567D1E4140E4654D2CF0694D401FF46C567D1E41403E97A949F06A4D402330D637302141403E97A949F06A4D402330D63730214140E4654D2CF0694D401FF46C567D1E4140E4654D2CF0694D40
23297	Лесной	3	31	938	34.173333	34.191110000000002	58.943157999999997	58.934322000000002	0103000020E61000000100000005000000A62897C62F16414077F700DD97774D40A62897C62F164140FA7ABE66B9784D4023F8DF4A76184140FA7ABE66B9784D4023F8DF4A7618414077F700DD97774D40A62897C62F16414077F700DD97774D40
9263	Левоча	3	31	938	35.015027000000003	35.045354000000003	58.832402000000002	58.806758000000002	0103000020E610000001000000050000004CC79C67EC814140A8E49CD843674D404CC79C67EC814140009013268C6A4D40145FED28CE854140009013268C6A4D40145FED28CE854140A8E49CD843674D404CC79C67EC814140A8E49CD843674D40
57366	Кушавера	3	31	938	34.652870999999998	34.691417999999999	58.871141000000001	58.796557999999997	0103000020E61000000100000005000000DFC0E44691534140FFAECF9CF5654D40DFC0E44691534140359A5C8C816F4D40D0EE906280584140359A5C8C816F4D40D0EE906280584140FFAECF9CF5654D40DFC0E44691534140FFAECF9CF5654D40
57349	Крестцы	3	31	938	35.092902000000002	35.107778000000003	58.838908000000004	58.834344000000002	0103000020E61000000100000005000000D3DD7536E48B414092CEC0C8CB6A4D40D3DD7536E48B4140282D5C56616B4D40399D64ABCB8D4140282D5C56616B4D40399D64ABCB8D414092CEC0C8CB6A4D40D3DD7536E48B414092CEC0C8CB6A4D40
45399	Кабожа	3	31	938	35.013562999999998	35.048723000000003	58.808658999999999	58.790753000000002	0103000020E61000000100000005000000C3B7B06EBC814140611BF16437654D40C3B7B06EBC814140DB4E5B2382674D4011C8258E3C864140DB4E5B2382674D4011C8258E3C864140611BF16437654D40C3B7B06EBC814140611BF16437654D40
22987	Звягино	3	31	938	35.148535000000003	35.155693999999997	58.776415	58.769697000000001	0103000020E61000000100000005000000DBA7E33103934140276A696E85624D40DBA7E33103934140DA8F149161634D407A17EFC7ED934140DA8F149161634D407A17EFC7ED934140276A696E85624D40DBA7E33103934140276A696E85624D40
22856	Дворищи	3	31	938	34.672347000000002	34.685166000000002	58.815724000000003	58.805928000000002	0103000020E6100000010000000500000028486C770F564140217711A628674D4028486C770F564140FA47DFA469684D40632AFD84B3574140FA47DFA469684D40632AFD84B3574140217711A628674D4028486C770F564140217711A628674D40
22753	Горный	3	31	938	33.824975000000002	33.835107999999998	58.963807000000003	58.955668000000003	0103000020E610000001000000050000004182E2C798E94040B8EA3A54537A4D404182E2C798E94040F4531C075E7B4D406150A6D1E4EA4040F4531C075E7B4D406150A6D1E4EA4040B8EA3A54537A4D404182E2C798E94040B8EA3A54537A4D40
57361	Бугры	3	31	938	35.235095999999999	35.259117000000003	58.763705000000002	58.753525000000003	0103000020E61000000100000005000000D0B52FA0179E4140F5DBD78173604D40D0B52FA0179E41405665DF15C1614D40386BF0BE2AA141405665DF15C1614D40386BF0BE2AA14140F5DBD78173604D40D0B52FA0179E4140F5DBD78173604D40
22797	Боровское	3	31	938	34.349268000000002	34.367970999999997	58.816656000000002	58.811259999999997	0103000020E6100000010000000500000009C556D0B42C4140C746205ED7674D4009C556D0B42C4140850A0E2F88684D402E7079AC192F4140850A0E2F88684D402E7079AC192F4140C746205ED7674D4009C556D0B42C4140C746205ED7674D40
7648	Анциферово	3	31	938	33.976638000000001	33.984865999999997	58.940275	58.937136000000002	0103000020E61000000100000005000000F303577902FD4040BFF38B12F4774D40F303577902FD40408A1F63EE5A784D409E78CE1610FE40408A1F63EE5A784D409E78CE1610FE4040BFF38B12F4774D40F303577902FD4040BFF38B12F4774D40
57365	Тулебля	3	31	667	31.048919999999999	31.077199	57.966299999999997	57.947696000000001	0103000020E61000000100000005000000CD1E6805860C3F4067463F1A4EF94C40CD1E6805860C3F40F90FE9B7AFFB4C40AE484C50C3133F40F90FE9B7AFFB4C40AE484C50C3133F4067463F1A4EF94C40CD1E6805860C3F4067463F1A4EF94C40
51918	Сусолово	3	31	667	31.238636	31.256207	57.959381999999998	57.951560000000001	0103000020E61000000100000005000000F4A5B73F173D3F404417D4B7CCF94C40F4A5B73F173D3F407F2F8507CDFA4C409B012EC896413F407F2F8507CDFA4C409B012EC896413F404417D4B7CCF94C40F4A5B73F173D3F404417D4B7CCF94C40
4716	Старая Русса	3	31	667	31.313717	31.39134	58.015914000000002	57.968438999999996	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
21472	Святогорша	3	31	667	31.198696000000002	31.210024000000001	57.791964999999998	57.781117000000002	0103000020E6100000010000000500000095D8B5BDDD323F40C1AC50A4FBE34C4095D8B5BDDD323F40CF49EF1B5FE54C4007600322C4353F40CF49EF1B5FE54C4007600322C4353F40C1AC50A4FBE34C4095D8B5BDDD323F40C1AC50A4FBE34C40
51915	Пробуждение	3	31	667	31.381117	31.397925000000001	57.765292000000002	57.760693000000003	0103000020E610000001000000050000001BF33AE290613F40E8A562635EE14C401BF33AE290613F40FAF19716F5E14C40C442AD69DE653F40FAF19716F5E14C40C442AD69DE653F40E8A562635EE14C401BF33AE290613F40E8A562635EE14C40
4548	Пинаевы Горки	3	31	667	31.593353	31.612838	57.664831999999997	57.647435000000002	0103000020E61000000100000005000000C6FB71FBE5973F4094A46B26DFD24C40C6FB71FBE5973F40C9AA083719D54C40FDBE7FF3E29C3F40C9AA083719D54C40FDBE7FF3E29C3F4094A46B26DFD24C40C6FB71FBE5973F4094A46B26DFD24C40
21297	Новосельский	3	31	667	31.359279000000001	31.374711999999999	57.865516	57.850633999999999	0103000020E61000000100000005000000BC2363B5F95B3F40CE6E2D93E1EC4C40BC2363B5F95B3F401615713AC9EE4C40336B2920ED5F3F401615713AC9EE4C40336B2920ED5F3F40CE6E2D93E1EC4C40BC2363B5F95B3F40CE6E2D93E1EC4C40
10982	Нагово	3	31	667	31.169007000000001	31.190064	58.056212000000002	58.035659000000003	0103000020E610000001000000050000008ACBF10A442B3F406F675F7990044D408ACBF10A442B3F4046D26EF431074D409E25C808A8303F4046D26EF431074D409E25C808A8303F406F675F7990044D408ACBF10A442B3F406F675F7990044D40
21216	Медниково	3	31	667	31.397772	31.423203000000001	57.987943000000001	57.976734	0103000020E61000000100000005000000B743C362D4653F401572A59E05FD4C40B743C362D4653F40F4A78DEA74FE4C40B0912408576C3F40F4A78DEA74FE4C40B0912408576C3F401572A59E05FD4C40B743C362D4653F401572A59E05FD4C40
52721	Луньшино	3	31	667	31.047546000000001	31.067632	58.100650000000002	58.084591000000003	0103000020E610000001000000050000003D0E83F92B0C3F409A44BDE0D30A4D403D0E83F92B0C3F40D42B6519E20C4D40BF29AC5450113F40D42B6519E20C4D40BF29AC5450113F409A44BDE0D30A4D403D0E83F92B0C3F409A44BDE0D30A4D40
10860	Коровитчино	3	31	667	31.652740999999999	31.668704000000002	57.786793000000003	57.774211000000001	0103000020E6100000010000000500000022C2BF081AA73F400B9A965819E34C4022C2BF081AA73F4062DC0DA2B5E44C4053B4722F30AB3F4062DC0DA2B5E44C4053B4722F30AB3F400B9A965819E34C4022C2BF081AA73F400B9A965819E34C40
21595	Ивановское	3	31	667	31.250188000000001	31.264372000000002	57.882612000000002	57.874040999999998	0103000020E6100000010000000500000006DA1D520C403F407B2E5393E0EF4C4006DA1D520C403F405187156EF9F04C4066FA25E2AD433F405187156EF9F04C4066FA25E2AD433F407B2E5393E0EF4C4006DA1D520C403F407B2E5393E0EF4C40
10791	Залучье	3	31	667	31.748958999999999	31.779807999999999	57.676051999999999	57.661740999999999	0103000020E610000001000000050000007C0BEBC6BBBF3F400FB6D8EDB3D44C407C0BEBC6BBBF3F409C3237DF88D64C40BF28417FA1C73F409C3237DF88D64C40BF28417FA1C73F400FB6D8EDB3D44C407C0BEBC6BBBF3F400FB6D8EDB3D44C40
22340	Дубовицы	3	31	667	31.294150999999999	31.335079	58.013277000000002	57.993772999999997	0103000020E61000000100000005000000F015DD7A4D4B3F40EB5223F433FF4C40F015DD7A4D4B3F40FE648C0FB3014D408E93C2BCC7553F40FE648C0FB3014D408E93C2BCC7553F40EB5223F433FF4C40F015DD7A4D4B3F40EB5223F433FF4C40
52949	Давыдово	3	31	667	31.500557000000001	31.520401	57.917425000000001	57.907972999999998	0103000020E61000000100000005000000ACC8E88024803F405453927538F44C40ACC8E88024803F4033C4B12E6EF54C4042CEFBFF38853F4033C4B12E6EF54C4042CEFBFF38853F405453927538F44C40ACC8E88024803F405453927538F44C40
10721	Взвад	3	31	667	31.462837	31.482932000000002	58.164625999999998	58.155352999999998	0103000020E61000000100000005000000F660527C7C763F40F12A6B9BE2134D40F660527C7C763F402009FB7612154D401F317A6EA17B3F402009FB7612154D401F317A6EA17B3F40F12A6B9BE2134D40F660527C7C763F40F12A6B9BE2134D40
20964	Великое	3	31	667	31.102243999999999	31.123902999999999	57.923816000000002	57.91863	0103000020E610000001000000050000005436ACA92C1A3F40EF8FF7AA95F54C405436ACA92C1A3F40C2C2499A3FF64C4054E0641BB81F3F40C2C2499A3FF64C4054E0641BB81F3F40EF8FF7AA95F54C405436ACA92C1A3F40EF8FF7AA95F54C40
20892	Буреги	3	31	667	31.040575	31.061730000000001	58.152684999999998	58.143698000000001	0103000020E6100000010000000500000003098A1F630A3F40144031B264124D4003098A1F630A3F407DCB9C2E8B134D409D2E8B89CD0F3F407DCB9C2E8B134D409D2E8B89CD0F3F40144031B264124D4003098A1F630A3F40144031B264124D40
20812	Борисово	3	31	667	31.145723	31.171028	58.136321000000002	58.123784999999998	0103000020E6100000010000000500000067463F1A4E253F40205ED72FD80F4D4067463F1A4E253F4007616EF772114D4046B3B27DC82B3F4007616EF772114D4046B3B27DC82B3F40205ED72FD80F4D4067463F1A4E253F40205ED72FD80F4D40
20670	Большое Вороново	3	31	667	31.253250999999999	31.269366999999999	58.074278999999997	58.062534999999997	0103000020E61000000100000005000000E6ADBA0ED5403F407CED992501084D40E6ADBA0ED5403F40C9E369F981094D40239F573CF5443F40C9E369F981094D40239F573CF5443F407CED992501084D40E6ADBA0ED5403F407CED992501084D40
52937	Большие Боры	3	31	667	31.086147	31.108497	57.855164000000002	57.846255999999997	0103000020E6100000010000000500000005A6D3BA0D163F409A05DA1D52EC4C4005A6D3BA0D163F40B85B920376ED4C40D0B69A75C61B3F40B85B920376ED4C40D0B69A75C61B3F409A05DA1D52EC4C4005A6D3BA0D163F409A05DA1D52EC4C40
52215	Большая Козона	3	31	667	31.348455000000001	31.368010999999999	57.962352000000003	57.947800999999998	0103000020E61000000100000005000000B020CD5834593F40DC0E0D8B51F94C40B020CD5834593F40BF9EAF592EFB4C40799109F8355E3F40BF9EAF592EFB4C40799109F8355E3F40DC0E0D8B51F94C40B020CD5834593F40DC0E0D8B51F94C40
52924	Астрилово	3	31	667	31.068369000000001	31.081619	57.777752999999997	57.768738999999997	0103000020E610000001000000050000006B0F7BA180113F407214200A66E24C406B0F7BA180113F40D5AE09698DE34C4073BB97FBE4143F40D5AE09698DE34C4073BB97FBE4143F407214200A66E24C406B0F7BA180113F407214200A66E24C40
20509	Анишино 1-е	3	31	667	31.452065999999999	31.457124	58.001137	57.998289999999997	0103000020E610000001000000050000002FA2ED98BA733F4040F67AF7C7FF4C402FA2ED98BA733F4064E8D84125004D407A37161406753F4064E8D84125004D407A37161406753F4040F67AF7C7FF4C402FA2ED98BA733F4040F67AF7C7FF4C40
11289	Толчино	3	31	908	30.065750000000001	30.082979999999999	58.177849999999999	58.168970000000002	0103000020E6100000010000000500000046B6F3FDD4103E40A80018CFA0154D4046B6F3FDD4103E40FBCBEEC9C3164D40DA38622D3E153E40FBCBEEC9C3164D40DA38622D3E153E40A80018CFA0154D4046B6F3FDD4103E40A80018CFA0154D40
7236	Сольцы	3	31	908	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
19586	Светлицы	3	31	908	30.354181000000001	30.363631999999999	58.011040999999999	58.002558000000001	0103000020E6100000010000000500000055DD239BAB5A3E40ED2B0FD253004D4055DD239BAB5A3E4023F59ECA69014D4071C79BFC165D3E4023F59ECA69014D4071C79BFC165D3E40ED2B0FD253004D4055DD239BAB5A3E40ED2B0FD253004D40
19878	Ретно	3	31	908	30.199258	30.211098	57.994726999999997	57.987557000000002	0103000020E610000001000000050000006477819202333E40CBF78C4468FE4C406477819202333E405EB9DE3653FF4C404240BE840A363E405EB9DE3653FF4C404240BE840A363E40CBF78C4468FE4C406477819202333E40CBF78C4468FE4C40
19953	Песочки	3	31	908	30.508754	30.523216999999999	58.174441999999999	58.165546999999997	0103000020E610000001000000050000008DB5BFB33D823E40B779E3A430154D408DB5BFB33D823E4040868E1D54164D4013B69F8CF1853E4040868E1D54164D4013B69F8CF1853E40B779E3A430154D408DB5BFB33D823E40B779E3A430154D40
7202	Невское	3	31	908	30.426477999999999	30.456220999999999	58.131256	58.117714999999997	0103000020E61000000100000005000000A77686A92D6D3E40D39FFD48110F4D40A77686A92D6D3E40AFB321FFCC104D4098BF42E6CA743E40AFB321FFCC104D4098BF42E6CA743E40D39FFD48110F4D40A77686A92D6D3E40D39FFD48110F4D40
19785	Куклино	3	31	908	30.231587999999999	30.24756	58.066443999999997	58.058883999999999	0103000020E610000001000000050000006325E659493B3E40FB20CB8289074D406325E659493B3E40F981AB3C81084D403ACC9717603F3E40F981AB3C81084D403ACC9717603F3E40FB20CB8289074D406325E659493B3E40FB20CB8289074D40
19778	Жильско	3	31	908	29.979897999999999	29.996462999999999	58.064787000000003	58.060326000000003	0103000020E61000000100000005000000726A6798DAFA3D409C8C2AC3B8074D40726A6798DAFA3D405D1ABFF04A084D408EACFC3218FF3D405D1ABFF04A084D408EACFC3218FF3D409C8C2AC3B8074D40726A6798DAFA3D409C8C2AC3B8074D40
7127	Дуброво	3	31	908	30.093561999999999	30.113468999999998	58.084453000000003	58.078181000000001	0103000020E61000000100000005000000FA25E2ADF3173E409415C3D5010A4D40FA25E2ADF3173E4049861C5BCF0A4D401D1CEC4D0C1D3E4049861C5BCF0A4D401D1CEC4D0C1D3E409415C3D5010A4D40FA25E2ADF3173E409415C3D5010A4D40
7118	Горки	3	31	908	30.032036000000002	30.054978999999999	57.993329000000003	57.981878999999999	0103000020E610000001000000050000006F4BE48233083E4089D00836AEFD4C406F4BE48233083E408E95986725FF4C407FF78E1A130E3E408E95986725FF4C407FF78E1A130E3E4089D00836AEFD4C406F4BE48233083E4089D00836AEFD4C40
11357	Выбити	3	31	908	30.419857	30.438828999999998	58.076563	58.060383000000002	0103000020E6100000010000000500000026FF93BF7B6B3E40001E51A1BA074D4026FF93BF7B6B3E40B58AFED0CC094D405089EB1857703E40B58AFED0CC094D405089EB1857703E40001E51A1BA074D4026FF93BF7B6B3E40001E51A1BA074D40
19444	Вшели	3	31	908	29.862784999999999	29.878685000000001	58.147593000000001	58.135688999999999	0103000020E61000000100000005000000B77A4E7ADFDC3D40A6B6D4415E114D40B77A4E7ADFDC3D402C0FD253E4124D405B7C0A80F1E03D402C0FD253E4124D405B7C0A80F1E03D40A6B6D4415E114D40B77A4E7ADFDC3D40A6B6D4415E114D40
20004	Большое Заборовье	3	31	908	30.242322999999999	30.259139000000001	58.122587000000003	58.118299999999998	0103000020E61000000100000005000000901150E1083E3E40F38E5374240F4D40901150E1083E3E4017F549EEB00F4D403F1EFAEE56423E4017F549EEB00F4D403F1EFAEE56423E40F38E5374240F4D40901150E1083E3E40F38E5374240F4D40
19382	Селеево	3	31	1107	31.391717	31.410250000000001	57.397799999999997	57.387386999999997	0103000020E610000001000000050000008849B89047643F40A1F2AFE595B14C408849B89047643F40A52C431CEBB24C401B2FDD2406693F40A52C431CEBB24C401B2FDD2406693F40A1F2AFE595B14C408849B89047643F40A1F2AFE595B14C40
11171	Поддорье	3	31	1107	31.095524999999999	31.124891000000002	57.479647	57.460979999999999	0103000020E610000001000000050000004DF38E5374183F40170E846401BB4C404DF38E5374183F40F04FA91265BD4C40939048DBF81F3F40F04FA91265BD4C40939048DBF81F3F40170E846401BB4C404DF38E5374183F40170E846401BB4C40
19081	Переезд	3	31	1107	30.722742	30.741417999999999	57.507131000000001	57.498519000000002	0103000020E610000001000000050000001572A59E05B93E40A2B77878CFBF4C401572A59E05B93E40D6E429ABE9C04C406DAAEE91CDBD3E40D6E429ABE9C04C406DAAEE91CDBD3E40A2B77878CFBF4C401572A59E05B93E40A2B77878CFBF4C40
11188	Перегино	3	31	1107	31.379213	31.397196999999998	57.453257000000001	57.442791	0103000020E61000000100000005000000D237691A14613F4048FB1F60ADB84C40D237691A14613F406FD74B5304BA4C40BE11DDB3AE653F406FD74B5304BA4C40BE11DDB3AE653F4048FB1F60ADB84C40D237691A14613F4048FB1F60ADB84C40
19238	Нивки	3	31	1107	30.917973	30.946574999999999	57.421652999999999	57.415221000000003	0103000020E610000001000000050000006B9C4D4700EB3E4064CE33F625B54C406B9C4D4700EB3E4051A1BAB9F8B54C4011363CBD52F23E4051A1BAB9F8B54C4011363CBD52F23E4064CE33F625B54C406B9C4D4700EB3E4064CE33F625B54C40
19176	Масловское	3	31	1107	31.111425000000001	31.134943	57.470235000000002	57.459774000000003	0103000020E61000000100000005000000F1F44A59861C3F408BC6DADFD9BA4C40F1F44A59861C3F40A03715A930BC4C40FAD2DB9F8B223F40A03715A930BC4C40FAD2DB9F8B223F408BC6DADFD9BA4C40F1F44A59861C3F408BC6DADFD9BA4C40
19023	Заозерье	3	31	1107	31.008576999999999	31.026992	57.675792000000001	57.668725999999999	0103000020E610000001000000050000006F7F2E1A32023F4011FE45D098D54C406F7F2E1A32023F4000732D5A80D64C40EE409DF2E8063F4000732D5A80D64C40EE409DF2E8063F4011FE45D098D54C406F7F2E1A32023F4011FE45D098D54C40
19122	Бураково	3	31	1107	31.14142	31.162557	57.590874999999997	57.582079	0103000020E610000001000000050000001500E31934243F401D588E9081CA4C401500E31934243F401283C0CAA1CB4C4062BCE6559D293F401283C0CAA1CB4C4062BCE6559D293F401D588E9081CA4C401500E31934243F401D588E9081CA4C40
9920	Белебелка	3	31	1107	30.906295	30.962278000000001	57.588096	57.563077999999997	0103000020E610000001000000050000004087F9F202E83E406D8C9DF012C84C404087F9F202E83E404774CFBA46CB4C4009A9DBD957F63E404774CFBA46CB4C4009A9DBD957F63E406D8C9DF012C84C404087F9F202E83E406D8C9DF012C84C40
28969	Устюцкое	3	31	1083	35.316896999999997	35.343155000000003	58.508836000000002	58.499856000000001	0103000020E61000000100000005000000AA99B51490A84140CD5A0A48FB3F4D40AA99B51490A841408483BD8921414D40BD3AC780ECAB41408483BD8921414D40BD3AC780ECAB4140CD5A0A48FB3F4D40AA99B51490A84140CD5A0A48FB3F4D40
18339	Семытино	3	31	1083	35.805311000000003	35.812632000000001	58.495477999999999	58.491371999999998	0103000020E61000000100000005000000F60D4C6E14E74140C6151747E53E4D40F60D4C6E14E7414099F1B6D26B3F4D406FD74B5304E8414099F1B6D26B3F4D406FD74B5304E84140C6151747E53E4D40F60D4C6E14E74140C6151747E53E4D40
18222	Русское-Пестово	3	31	1083	35.737704000000001	35.776412000000001	58.584963000000002	58.574143999999997	0103000020E610000001000000050000006F10AD156DDE4140E998F38C7D494D406F10AD156DDE41405E2F4D11E04A4D40691CEA7761E341405E2F4D11E04A4D40691CEA7761E34140E998F38C7D494D406F10AD156DDE4140E998F38C7D494D40
17950	Погорелово	3	31	1083	35.193100000000001	35.212755000000001	58.463766	58.454858999999999	0103000020E61000000100000005000000C66D3480B798414048A5D8D1383A4D40C66D3480B7984140957F2DAF5C3B4D40BE874B8E3B9B4140957F2DAF5C3B4D40BE874B8E3B9B414048A5D8D1383A4D40C66D3480B798414048A5D8D1383A4D40
9620	Пестово	3	31	1083	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
18192	Охона	3	31	1083	35.620123	35.648159999999997	58.571550000000002	58.563856999999999	0103000020E61000000100000005000000AB3FC23060CF4140724F57772C484D40AB3FC23060CF4140B003E78C28494D40A54929E8F6D24140B003E78C28494D40A54929E8F6D24140724F57772C484D40AB3FC23060CF4140724F57772C484D40
18114	Лаптево	3	31	1083	35.268450999999999	35.288716999999998	58.629385999999997	58.622194	0103000020E610000001000000050000000CCA349A5CA241403BE2900DA44F4D400CCA349A5CA24140B6476FB88F504D404D66BCADF4A44140B6476FB88F504D404D66BCADF4A441403BE2900DA44F4D400CCA349A5CA241403BE2900DA44F4D40
17883	Карпелово	3	31	1083	35.957225000000001	35.981417	58.604871000000003	58.595267999999997	0103000020E61000000100000005000000F1F44A5986FA41407B2DE8BD314C4D40F1F44A5986FA414040A6B5696C4D4D40855E7F129FFD414040A6B5696C4D4D40855E7F129FFD41407B2DE8BD314C4D40F1F44A5986FA41407B2DE8BD314C4D40
18003	Вятка	3	31	1083	35.661203	35.688080999999997	58.475254	58.461751	0103000020E610000001000000050000003082C64CA2D4414099F221A81A3B4D403082C64CA2D4414087A5811FD53C4D40DEFFC70913D8414087A5811FD53C4D40DEFFC70913D8414099F221A81A3B4D403082C64CA2D4414099F221A81A3B4D40
18292	Вотроса	3	31	1083	35.812137999999997	35.827759999999998	58.726654000000003	58.717331999999999	0103000020E610000001000000050000005FEB5223F4E74140E82FF488D15B4D405FEB5223F4E74140F9C08EFF025D4D40EE77280AF4E94140F9C08EFF025D4D40EE77280AF4E94140E82FF488D15B4D405FEB5223F4E74140E82FF488D15B4D40
29438	Быково	3	31	1083	36.095987999999998	36.121608000000002	58.561337000000002	58.552210000000002	0103000020E610000001000000050000007B67B455490C4240184339D1AE464D407B67B455490C424073840CE4D9474D404B77D7D9900F424073840CE4D9474D404B77D7D9900F4240184339D1AE464D407B67B455490C4240184339D1AE464D40
29396	Богослово	3	31	1083	35.397933999999999	35.431378000000002	58.773223999999999	58.761296999999999	0103000020E61000000100000005000000B5FB5580EFB241407EC51A2E72614D40B5FB5580EFB24140BC3D0801F9624D40611BF16437B74140BC3D0801F9624D40611BF16437B741407EC51A2E72614D40B5FB5580EFB241407EC51A2E72614D40
18117	Беззубцево	3	31	1083	35.467993999999997	35.480606000000002	58.633668	58.622521999999996	0103000020E61000000100000005000000B35C363AE7BB41402F8507CDAE4F4D40B35C363AE7BB4140C84274081C514D407521567F84BD4140C84274081C514D407521567F84BD41402F8507CDAE4F4D40B35C363AE7BB41402F8507CDAE4F4D40
18402	Барсаниха	3	31	1083	35.463844000000002	35.486516999999999	58.521225999999999	58.511096999999999	0103000020E6100000010000000500000011397D3D5FBB4140B70A62A06B414D4011397D3D5FBB414096E99788B7424D4059F9653046BE414096E99788B7424D4059F9653046BE4140B70A62A06B414D4011397D3D5FBB4140B70A62A06B414D40
57352	Абросово	3	31	1083	35.376643999999999	35.451213000000003	58.725718999999998	58.707689999999999	0103000020E61000000100000005000000081EDFDE35B0414066DAFE95955A4D40081EDFDE35B04140FC8A355CE45C4D40D943FB58C1B94140FC8A355CE45C4D40D943FB58C1B9414066DAFE95955A4D40081EDFDE35B0414066DAFE95955A4D40
17225	Федорково	3	31	1475	31.609119	31.632349000000001	57.995508999999998	57.975627000000003	0103000020E610000001000000050000004A5F0839EF9B3F401C0C7558E1FC4C404A5F0839EF9B3F40D4EFC2D66CFF4C4087A8C29FE1A13F40D4EFC2D66CFF4C4087A8C29FE1A13F401C0C7558E1FC4C404A5F0839EF9B3F401C0C7558E1FC4C40
17195	Сергеево	3	31	1475	31.602031	31.615127999999999	57.953719	57.945337000000002	0103000020E610000001000000050000009D2D20B41E9A3F40715985CD00F94C409D2D20B41E9A3F407349D57613FA4C4098DA5207799D3F407349D57613FA4C4098DA5207799D3F40715985CD00F94C409D2D20B41E9A3F40715985CD00F94C40
17501	Пола	3	31	1475	31.812021000000001	31.847325000000001	57.947949999999999	57.922096000000003	0103000020E610000001000000050000004CAAB69BE0CF3F40DFE2E13D07F64C404CAAB69BE0CF3F40211FF46C56F94C404D158C4AEAD83F40211FF46C56F94C404D158C4AEAD83F40DFE2E13D07F64C404CAAB69BE0CF3F40DFE2E13D07F64C40
16903	Парфино	3	31	1475	31.627516	31.665649999999999	57.984135999999999	57.954129999999999	0103000020E610000001000000050000007CB779E3A4A03F40F5108DEE20FA4C407CB779E3A4A03F407B681F2BF8FD4C401895D40968AA3F407B681F2BF8FD4C401895D40968AA3F40F5108DEE20FA4C407CB779E3A4A03F40F5108DEE20FA4C40
17606	Новая Деревня	3	31	1475	31.877849999999999	31.900307999999999	57.841341	57.832017999999998	0103000020E6100000010000000500000029CB10C7BAE03F4077D7D9907FEA4C4029CB10C7BAE03F4058E4D70FB1EB4C40C153C8957AE63F4058E4D70FB1EB4C40C153C8957AE63F4077D7D9907FEA4C4029CB10C7BAE03F4077D7D9907FEA4C40
17441	Лажины	3	31	1475	31.812425000000001	31.837713000000001	58.160775999999998	58.150182000000001	0103000020E61000000100000005000000EB73B515FBCF3F405439ED2939134D40EB73B515FBCF3F40A8FDD64E94144D401E6FF25B74D63F40A8FDD64E94144D401E6FF25B74D63F405439ED2939134D40EB73B515FBCF3F405439ED2939134D40
17628	Кузьминское	3	31	1475	32.013468000000003	32.029153000000001	57.855412999999999	57.844627000000003	0103000020E6100000010000000500000072C5C551B9014040C828CFBC1CEC4C4072C5C551B901404060C9552C7EED4C4047CA1649BB03404060C9552C7EED4C4047CA1649BB034040C828CFBC1CEC4C4072C5C551B9014040C828CFBC1CEC4C40
17392	Городок	3	31	1475	31.607285999999998	31.621237000000001	58.049506999999998	58.041004000000001	0103000020E6100000010000000500000093516518779B3F40AA807B9E3F054D4093516518779B3F4027F6D03E56064D40AE105663099F3F4027F6D03E56064D40AE105663099F3F40AA807B9E3F054D4093516518779B3F40AA807B9E3F054D40
17354	Березицко	3	31	1475	31.582716999999999	31.591718	58.041519000000001	58.033081000000003	0103000020E61000000100000005000000BFD2F9F02C953F403B8F8AFF3B044D40BFD2F9F02C953F40D1949D7E50054D405C74B2D47A973F40D1949D7E50054D405C74B2D47A973F403B8F8AFF3B044D40BFD2F9F02C953F403B8F8AFF3B044D40
57362	дер.Шуркино	3	31	1409	32.544193	33.732295999999998	58.748497	58.067028999999998	0103000020E6100000010000000500000027DBC01DA84540401971016894084D4027DBC01DA8454040BA13ECBFCE5F4D40ED7E15E0BBDD4040BA13ECBFCE5F4D40ED7E15E0BBDD40401971016894084D4027DBC01DA84540401971016894084D40
57351	дер.Козловка	3	31	1409	32.544193	33.732295999999998	58.748497	58.067028999999998	0103000020E6100000010000000500000027DBC01DA84540401971016894084D4027DBC01DA8454040BA13ECBFCE5F4D40ED7E15E0BBDD4040BA13ECBFCE5F4D40ED7E15E0BBDD40401971016894084D4027DBC01DA84540401971016894084D40
16083	Угловка	3	31	1409	33.488833999999997	33.526823999999998	58.245277000000002	58.226770999999999	0103000020E610000001000000050000002096CD1C92BE4040325706D5061D4D402096CD1C92BE404002BB9A3C651F4D40BB5F05F86EC3404002BB9A3C651F4D40BB5F05F86EC34040325706D5061D4D402096CD1C92BE4040325706D5061D4D40
57355	Торбино	3	31	1409	32.931592000000002	32.939712	58.646242999999998	58.642130999999999	0103000020E610000001000000050000008D9B1A683E774040B75F3E5931524D408D9B1A683E7740406C223317B8524D4052D4997B487840406C223317B8524D4052D4997B48784040B75F3E5931524D408D9B1A683E774040B75F3E5931524D40
16758	Топорок	3	31	1409	33.465164000000001	33.495274999999999	58.557383999999999	58.541761999999999	0103000020E6100000010000000500000066A3737E8ABB4040971B0C7558454D4066A3737E8ABB404026A8E15B58474D4061C3D32B65BF404026A8E15B58474D4061C3D32B65BF4040971B0C7558454D4066A3737E8ABB4040971B0C7558454D40
16199	Селище	3	31	1409	33.575504000000002	33.593694999999997	58.177588999999998	58.168945999999998	0103000020E61000000100000005000000CD5B751DAAC940401F65C405A0154D40CD5B751DAAC940408E90813CBB164D403C66A032FECB40408E90813CBB164D403C66A032FECB40401F65C405A0154D40CD5B751DAAC940401F65C405A0154D40
16823	Пузырево	3	31	1409	33.332222000000002	33.346738999999999	58.289468999999997	58.277597999999998	0103000020E610000001000000050000008081204086AA4040AEB7CD5488234D408081204086AA4040581AF8510D254D40B69F8CF161AC4040581AF8510D254D40B69F8CF161AC4040AEB7CD5488234D408081204086AA4040AEB7CD5488234D40
16047	Полищи	3	31	1409	33.331764	33.347898000000001	58.449024000000001	58.444488999999997	0103000020E61000000100000005000000BDFE243E77AA40404337FB03E5384D40BDFE243E77AA40403F8F519E79394D40022CF2EB87AC40403F8F519E79394D40022CF2EB87AC40404337FB03E5384D40BDFE243E77AA40404337FB03E5384D40
15569	Окуловка	3	31	1409	33.25273	33.341628	58.427219000000001	58.365101000000003	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
16297	Озерки	3	31	1409	33.419151999999997	33.430093999999997	58.358576999999997	58.352547000000001	0103000020E61000000100000005000000C806D2C5A6B54040C6A69542202D4D40C806D2C5A6B54040840CE4D9E52D4D40581AF8510DB74040840CE4D9E52D4D40581AF8510DB74040C6A69542202D4D40C806D2C5A6B54040C6A69542202D4D40
16821	Мельница	3	31	1409	33.276454999999999	33.284342000000002	58.256832000000003	58.252025000000003	0103000020E6100000010000000500000068E89FE062A340402063EE5A42204D4068E89FE062A340407C48F8DEDF204D408B70935165A440407C48F8DEDF204D408B70935165A440402063EE5A42204D4068E89FE062A340402063EE5A42204D40
15922	Кулотино	3	31	1409	33.336615000000002	33.392302000000001	58.464345000000002	58.441690999999999	0103000020E61000000100000005000000E92B483316AB404001F8A75489384D40E92B483316AB4040D3872EA86F3B4D40E413B2F336B24040D3872EA86F3B4D40E413B2F336B2404001F8A75489384D40E92B483316AB404001F8A75489384D40
16694	Котово	3	31	1409	33.464615999999999	33.524425999999998	58.491297000000003	58.475932	0103000020E6100000010000000500000063997E8978BB4040588FFB56EB3C4D4063997E8978BB4040BCCFF1D1E23E4D400796236420C34040BCCFF1D1E23E4D400796236420C34040588FFB56EB3C4D4063997E8978BB4040588FFB56EB3C4D40
16385	Завод	3	31	1409	33.107284	33.116985999999997	58.347116	58.341340000000002	0103000020E6100000010000000500000029B16B7BBB8D404088687407B12B4D4029B16B7BBB8D40408CF50D4C6E2C4D40800BB265F98E40408CF50D4C6E2C4D40800BB265F98E404088687407B12B4D4029B16B7BBB8D404088687407B12B4D40
16508	Дерняки	3	31	1409	33.219034000000001	33.239497999999998	58.531916000000002	58.522472	0103000020E61000000100000005000000255B5D4E099C4040B189CC5CE0424D40255B5D4E099C40400D1CD0D215444D408CBAD6DEA79E40400D1CD0D215444D408CBAD6DEA79E4040B189CC5CE0424D40255B5D4E099C4040B189CC5CE0424D40
16511	Висленев Остров	3	31	1409	33.076183999999998	33.093907999999999	58.705193999999999	58.698143999999999	0103000020E610000001000000050000003E3DB665C089404006F357C85C594D403E3DB665C0894040EFAA07CC435A4D40986A662D058C4040EFAA07CC435A4D40986A662D058C404006F357C85C594D403E3DB665C089404006F357C85C594D40
16452	Боровенка	3	31	1409	33.062322999999999	33.093603000000002	58.496442000000002	58.478374000000002	0103000020E61000000100000005000000F1643733FA874040DCA0F65B3B3D4D40F1643733FA874040302E55698B3F4D405CE7DF2EFB8B4040302E55698B3F4D405CE7DF2EFB8B4040DCA0F65B3B3D4D40F1643733FA874040DCA0F65B3B3D4D40
16209	Березовка	3	31	1409	33.463636999999999	33.47907	58.222875000000002	58.217016999999998	0103000020E61000000100000005000000971B0C7558BB404088D68A36C71B4D40971B0C7558BB40404A0C022B871C4D40533F6F2A52BD40404A0C022B871C4D40533F6F2A52BD404088D68A36C71B4D40971B0C7558BB404088D68A36C71B4D40
16345	Березовик	3	31	1409	33.196882000000002	33.210959000000003	58.383119000000001	58.37471	0103000020E61000000100000005000000E695EB6D33994040F9BD4D7FF62F4D40E695EB6D33994040F5BC1B0B0A314D4000E65AB4009B4040F5BC1B0B0A314D4000E65AB4009B4040F9BD4D7FF62F4D40E695EB6D33994040F9BD4D7FF62F4D40
15155	Чечулино	3	31	51	31.354005999999998	31.389526	58.678139999999999	58.650162000000002	0103000020E6100000010000000500000078962023A05A3F400D8D278238534D4078962023A05A3F40020EA14ACD564D4013F1D6F9B7633F40020EA14ACD564D4013F1D6F9B7633F400D8D278238534D4078962023A05A3F400D8D278238534D40
60	Частова	3	31	51	32.054791000000002	32.079261000000002	58.613968999999997	58.609844000000002	0103000020E61000000100000005000000BD8E386403074040B7D4415E0F4E4D40BD8E38640307404000E14389964E4D40946C7539250A404000E14389964E4D40946C7539250A4040B7D4415E0F4E4D40BD8E386403074040B7D4415E0F4E4D40
14275	Холынья	3	31	51	31.522907	31.565586	58.483921000000002	58.475197999999999	0103000020E6100000010000000500000077D9AF3BDD853F40F38FBE49D33C4D4077D9AF3BDD853F407F6C921FF13D4D4051137D3ECA903F407F6C921FF13D4D4051137D3ECA903F40F38FBE49D33C4D4077D9AF3BDD853F40F38FBE49D33C4D40
57359	Трубичино	3	31	51	30.707695000000001	32.12229	59.092039	58.213295000000002	0103000020E61000000100000005000000F08AE07F2BB53E403EB324404D1B4D40F08AE07F2BB53E40707A17EFC78B4D405D50DF32A70F4040707A17EFC78B4D405D50DF32A70F40403EB324404D1B4D40F08AE07F2BB53E403EB324404D1B4D40
13707	Толстиково	3	31	51	31.111722	31.126113	58.421247999999999	58.416606000000002	0103000020E61000000100000005000000643E20D0991C3F40A0A86C5853354D40643E20D0991C3F40B1C05774EB354D40B7990AF148203F40B1C05774EB354D40B7990AF148203F40A0A86C5853354D40643E20D0991C3F40A0A86C5853354D40
15476	Тесовский	3	31	51	30.867028999999999	30.886927	58.796599999999998	58.786200999999998	0103000020E61000000100000005000000FFAECF9CF5DD3E408F8AFF3BA2644D40FFAECF9CF5DD3E402EFF21FDF6654D407CF0DAA50DE33E402EFF21FDF6654D407CF0DAA50DE33E408F8AFF3BA2644D40FFAECF9CF5DD3E408F8AFF3BA2644D40
15229	Тесово-Нетыльский	3	31	51	31.019805999999999	31.085086	58.953871999999997	58.876393	0103000020E61000000100000005000000BB438A0112053F40BFB854A52D704D40BB438A0112053F40F9484A7A187A4D40F3583332C8153F40F9484A7A187A4D40F3583332C8153F40BFB854A52D704D40BB438A0112053F40BFB854A52D704D40
13947	Старое Ракомо	3	31	51	31.221243999999999	31.240091	58.453305	58.4435	0103000020E61000000100000005000000AC6F6072A3383F4054E3A59BC4384D40AC6F6072A3383F40800EF3E5053A4D405E10919A763D3F40800EF3E5053A4D405E10919A763D3F4054E3A59BC4384D40AC6F6072A3383F4054E3A59BC4384D40
13725	Сергово	3	31	51	31.080549999999999	31.094645	58.346482999999999	58.329532999999998	0103000020E610000001000000050000005BB1BFEC9E143F40F4F928232E2A4D405BB1BFEC9E143F405BCF108E592C4D40DCBA9BA73A183F405BCF108E592C4D40DCBA9BA73A183F40F4F928232E2A4D405BB1BFEC9E143F40F4F928232E2A4D40
14577	Савино	3	31	51	31.441313000000001	31.453251999999999	58.547651000000002	58.542748000000003	0103000020E61000000100000005000000B64C86E3F9703F4016FC36C478454D40B64C86E3F9703F40944F8F6D19464D40BAD8B45208743F40944F8F6D19464D40BAD8B45208743F4016FC36C478454D40B64C86E3F9703F4016FC36C478454D40
14755	Пролетарий	3	31	51	31.676303999999998	31.739526999999999	58.446331000000001	58.419057000000002	0103000020E610000001000000050000006B274A4222AD3F407714E7A8A3354D406B274A4222AD3F407218CC5F21394D404D8237A451BD3F407218CC5F21394D404D8237A451BD3F407714E7A8A3354D406B274A4222AD3F407714E7A8A3354D40
15000	Подберезье	3	31	51	31.362656999999999	31.416744000000001	58.707326000000002	58.682912000000002	0103000020E610000001000000050000005CAAD216D75C3F40E20511A969574D405CAAD216D75C3F4025CE8AA8895A4D40E2CD1ABCAF6A3F4025CE8AA8895A4D40E2CD1ABCAF6A3F40E20511A969574D405CAAD216D75C3F40E20511A969574D40
57360	Панковка	3	31	51	31.101355000000002	31.233892000000001	58.511107000000003	58.467323999999998	0103000020E610000001000000050000003D49BA66F2193F406551D845D13B4D403D49BA66F2193F40DBE044F46B414D40C9CB9A58E03B3F40DBE044F46B414D40C9CB9A58E03B3F406551D845D13B4D403D49BA66F2193F406551D845D13B4D40
14049	Панковка	3	31	51	31.101355000000002	31.233892000000001	58.511107000000003	58.467323999999998	0103000020E610000001000000050000003D49BA66F2193F406551D845D13B4D403D49BA66F2193F40DBE044F46B414D40C9CB9A58E03B3F40DBE044F46B414D40C9CB9A58E03B3F406551D845D13B4D403D49BA66F2193F406551D845D13B4D40
15430	Осия	3	31	51	31.235330000000001	31.249127999999999	58.760438000000001	58.750621000000002	0103000020E6100000010000000500000087C43D963E3C3F406D58535914604D4087C43D963E3C3F405D514A0856614D40948444DAC63F3F405D514A0856614D40948444DAC63F3F406D58535914604D4087C43D963E3C3F406D58535914604D40
14473	Новоселицы	3	31	51	31.682233	31.707888000000001	58.538120999999997	58.512065999999997	0103000020E61000000100000005000000814067D2A6AE3F405FB2F1608B414D40814067D2A6AE3F4039252026E1444D40193BE12538B53F4039252026E1444D40193BE12538B53F405FB2F1608B414D40814067D2A6AE3F405FB2F1608B414D40
13845	Новая Мельница	3	31	51	31.127433	31.196180999999999	58.534053	58.505065999999999	0103000020E61000000100000005000000616EF7729F203F402829B000A6404D40616EF7729F203F4054AA44D95B444D40B91803EB38323F4054AA44D95B444D40B91803EB38323F402829B000A6404D40616EF7729F203F402829B000A6404D40
14192	Наволок	3	31	51	31.62068	31.631747000000001	58.370207999999998	58.361300999999997	0103000020E6100000010000000500000002486DE2E49E3F408C81751C3F2E4D4002486DE2E49E3F40D95BCAF9622F4D409B58E02BBAA13F40D95BCAF9622F4D409B58E02BBAA13F408C81751C3F2E4D4002486DE2E49E3F408C81751C3F2E4D40
263	Мытно	3	31	51	31.742122999999999	31.753442	58.682200999999999	58.670017999999999	0103000020E61000000100000005000000029CDEC5FBBD3F409CDD5A26C3554D40029CDEC5FBBD3F403526C45C52574D40CE6E2D93E1C03F403526C45C52574D40CE6E2D93E1C03F409CDD5A26C3554D40029CDEC5FBBD3F409CDD5A26C3554D40
13882	Лесная	3	31	51	30.874718999999999	30.895488	58.311019999999999	58.292642999999998	0103000020E6100000010000000500000098309A95EDDF3E40A033695375254D4098309A95EDDF3E407233DC80CF274D40E0F599B33EE53E407233DC80CF274D40E0F599B33EE53E40A033695375254D4098309A95EDDF3E40A033695375254D40
14871	Красные Станки	3	31	51	31.802005000000001	31.857503000000001	58.409874000000002	58.396326999999999	0103000020E610000001000000050000007E3A1E3350CD3F40CAC2D7D7BA324D407E3A1E3350CD3F4088BD50C076344D40CE380D5185DB3F4088BD50C076344D40CE380D5185DB3F40CAC2D7D7BA324D407E3A1E3350CD3F40CAC2D7D7BA324D40
15307	Кересть	3	31	51	31.087358999999999	31.106386000000001	58.913083999999998	58.903534000000001	0103000020E61000000100000005000000E202D0285D163F407B698A00A7734D40E202D0285D163F401C40BFEFDF744D4094C0E61C3C1B3F401C40BFEFDF744D4094C0E61C3C1B3F407B698A00A7734D40E202D0285D163F407B698A00A7734D40
14004	Ильмень	3	31	51	31.187180000000001	31.211874999999999	58.400830999999997	58.391077000000003	0103000020E610000001000000050000001D774A07EB2F3F40E19BA6CF0E324D401D774A07EB2F3F408A1C226E4E334D400AD7A3703D363F408A1C226E4E334D400AD7A3703D363F40E19BA6CF0E324D401D774A07EB2F3F40E19BA6CF0E324D40
15028	Захарьино	3	31	51	31.552973999999999	31.576169	58.802418000000003	58.789180999999999	0103000020E61000000100000005000000CE893DB48F8D3F40F2CF0CE203654D40CE893DB48F8D3F4062DC0DA2B5664D4012F8C3CF7F933F4062DC0DA2B5664D4012F8C3CF7F933F40F2CF0CE203654D40CE893DB48F8D3F40F2CF0CE203654D40
13799	Ермолино	3	31	51	31.058999	31.108829	58.539037	58.525207000000002	0103000020E61000000100000005000000287FF78E1A0F3F40AD50A4FB39434D40287FF78E1A0F3F40BF2A172AFF444D403CDBA337DC1B3F40BF2A172AFF444D403CDBA337DC1B3F40AD50A4FB39434D40287FF78E1A0F3F40AD50A4FB39434D40
14708	Дубровка	3	31	51	31.499569000000001	31.51211	58.71358	58.695058000000003	0103000020E610000001000000050000006E1805C1E37F3F405E6919A9F7584D406E1805C1E37F3F40338AE596565B4D405EF415A419833F40338AE596565B4D405EF415A419833F405E6919A9F7584D406E1805C1E37F3F405E6919A9F7584D40
14859	Гостцы	3	31	51	31.698931999999999	31.714113999999999	58.324911999999998	58.316006999999999	0103000020E61000000100000005000000BC202235EDB23F404E27D9EA72284D40BC202235EDB23F40FA0967B796294D40A19DD32CD0B63F40FA0967B796294D40A19DD32CD0B63F404E27D9EA72284D40BC202235EDB23F404E27D9EA72284D40
15383	Гора	3	31	51	31.050286	31.067820999999999	58.811796000000001	58.799382999999999	0103000020E610000001000000050000005872158BDF0C3F403BFDA02E52664D405872158BDF0C3F4006836BEEE8674D4065FB90B75C113F4006836BEEE8674D4065FB90B75C113F403BFDA02E52664D405872158BDF0C3F403BFDA02E52664D40
57363	Волховец	3	31	51	30.707695000000001	32.12229	59.092039	58.213295000000002	0103000020E61000000100000005000000F08AE07F2BB53E403EB324404D1B4D40F08AE07F2BB53E40707A17EFC78B4D405D50DF32A70F4040707A17EFC78B4D405D50DF32A70F40403EB324404D1B4D40F08AE07F2BB53E403EB324404D1B4D40
14140	Бронница	3	31	51	31.633661	31.687137	58.466099999999997	58.439723000000001	0103000020E610000001000000050000002BC0779B37A23F404626E0D748384D402BC0779B37A23F403255302AA93B4D401EDFDE35E8AF3F403255302AA93B4D401EDFDE35E8AF3F404626E0D748384D402BC0779B37A23F404626E0D748384D40
13655	Борки	3	31	51	30.999790999999998	31.018180000000001	58.386463999999997	58.373832999999998	0103000020E61000000100000005000000CBD58F4DF2FF3E4031957EC2D92F4D40CBD58F4DF2FF3E40698A00A777314D40F870C971A7043F40698A00A777314D40F870C971A7043F4031957EC2D92F4D40CBD58F4DF2FF3E4031957EC2D92F4D40
15131	Болотная	3	31	51	31.160204	31.175619000000001	58.640585999999999	58.631227000000003	0103000020E610000001000000050000003AB01C2103293F4015ADDC0BCC504D403AB01C2103293F404223D8B8FE514D40658EE55DF52C3F404223D8B8FE514D40658EE55DF52C3F4015ADDC0BCC504D403AB01C2103293F4015ADDC0BCC504D40
14555	Божонка	3	31	51	31.638431000000001	31.669971	58.511938999999998	58.494283000000003	0103000020E61000000100000005000000A9C0C93670A33F4001FC53AA443F4D40A9C0C93670A33F400246973787414D40B7442E3883AB3F400246973787414D40B7442E3883AB3F4001FC53AA443F4D40A9C0C93670A33F4001FC53AA443F4D40
14208	Белая Гора	3	31	51	31.687362	31.733787	58.509982999999998	58.481591999999999	0103000020E610000001000000050000005E83BEF4F6AF3F40F30181CEA43D4D405E83BEF4F6AF3F400B42791F47414D40DE3AFF76D9BB3F400B42791F47414D40DE3AFF76D9BB3F40F30181CEA43D4D405E83BEF4F6AF3F40F30181CEA43D4D40
1796	Чувашева Гора	3	31	257	34.940772000000003	34.956870000000002	58.345146999999997	58.342691000000002	0103000020E610000001000000050000000B7F86376B78414018D1764CDD2B4D400B7F86376B78414000A8E2C62D2C4D40034356B77A7A414000A8E2C62D2C4D40034356B77A7A414018D1764CDD2B4D400B7F86376B78414018D1764CDD2B4D40
1567	Устрека	3	31	257	34.538955999999999	34.559285000000003	58.634079999999997	58.622883000000002	0103000020E61000000100000005000000D2FD9C82FC444140001E51A1BA4F4D40D2FD9C82FC4441401A868F8829514D405A12A0A6964741401A868F8829514D405A12A0A696474140001E51A1BA4F4D40D2FD9C82FC444140001E51A1BA4F4D40
1470	Слоптово	3	31	257	34.555439999999997	34.576855999999999	58.505541000000001	58.497146999999998	0103000020E61000000100000005000000F3716DA818474140FA264D83A23F4D40F3716DA818474140C1E44691B5404D402D40DB6AD6494140C1E44691B5404D402D40DB6AD6494140FA264D83A23F4D40F3716DA818474140FA264D83A23F4D40
10322	Петрово	3	31	257	35.136057000000001	35.148345999999997	58.379302000000003	58.367626000000001	0103000020E6100000010000000500000029B2D6506A9141406494675E0E2F4D4029B2D6506A91414059A7CAF78C304D40073F7100FD92414059A7CAF78C304D40073F7100FD9241406494675E0E2F4D4029B2D6506A9141406494675E0E2F4D40
10023	Осташево	3	31	257	34.411251999999998	34.420180999999999	58.555149	58.545678000000002	0103000020E610000001000000050000001135D1E7A3344140C712D6C6D8454D401135D1E7A33441401CB4571F0F474D4046B3B27DC83541401CB4571F0F474D4046B3B27DC8354140C712D6C6D8454D401135D1E7A3344140C712D6C6D8454D40
10244	Ореховно	3	31	257	35.024630000000002	35.046548999999999	58.317624000000002	58.301212999999997	0103000020E6100000010000000500000010406A1327834140A510C8258E264D4010406A13278341405D363AE7A7284D40AC545051F58541405D363AE7A7284D40AC545051F5854140A510C8258E264D4010406A1327834140A510C8258E264D40
9851	Новый Поселок	3	31	257	34.590941999999998	34.605665000000002	58.530538999999997	58.513390999999999	0103000020E610000001000000050000009AEAC9FCA34B4140C687D9CBB6414D409AEAC9FCA34B41405320B3B3E8434D407AAA436E864D41405320B3B3E8434D407AAA436E864D4140C687D9CBB6414D409AEAC9FCA34B4140C687D9CBB6414D40
10137	Мошенское	3	31	257	34.573092000000003	34.601343999999997	58.518861999999999	58.500439	0103000020E61000000100000005000000B4CC22145B4941404C5299620E404D40B4CC22145B4941408E91EC116A424D40AAD216D7F84C41408E91EC116A424D40AAD216D7F84C41404C5299620E404D40B4CC22145B4941404C5299620E404D40
1430	Меглецы	3	31	257	34.546691000000003	34.566696	58.430154000000002	58.421432000000003	0103000020E610000001000000050000003F027FF8F945414073BED87BF1354D403F027FF8F94541402E1F49490F374D401363997E894841402E1F49490F374D401363997E8948414073BED87BF1354D403F027FF8F945414073BED87BF1354D40
9751	Красная Гора	3	31	257	34.768214999999998	34.783746999999998	58.403646000000002	58.398553	0103000020E61000000100000005000000F8A57EDE54624140815CE2C803334D40F8A57EDE54624140A39410ACAA334D4047AB5AD251644140A39410ACAA334D4047AB5AD251644140815CE2C803334D40F8A57EDE54624140815CE2C803334D40
1266	Кабожа	3	31	257	34.963554000000002	34.976399999999998	58.582163000000001	58.572727	0103000020E610000001000000050000000AF7CABC557B4140A2444B1E4F494D400AF7CABC557B41407BF83251844A4D403EE8D9ACFA7C41407BF83251844A4D403EE8D9ACFA7C4140A2444B1E4F494D400AF7CABC557B4140A2444B1E4F494D40
1620	Дубишки	3	31	257	35.070525000000004	35.085023999999997	58.256998000000003	58.248908999999998	0103000020E61000000100000005000000744694F6068941400C570740DC1F4D40744694F60689414097917A4FE5204D4003B00111E28A414097917A4FE5204D4003B00111E28A41400C570740DC1F4D40744694F6068941400C570740DC1F4D40
9710	Долгое	3	31	257	34.889200000000002	34.905810000000002	58.467126	58.459533999999998	0103000020E6100000010000000500000036CD3B4ED171414035B39602D23A4D4036CD3B4ED17141403F8EE6C8CA3B4D40E4310395F17341403F8EE6C8CA3B4D40E4310395F173414035B39602D23A4D4036CD3B4ED171414035B39602D23A4D40
1082	Броди	3	31	257	35.114587999999998	35.129167000000002	58.466740999999999	58.459147999999999	0103000020E61000000100000005000000CC41D0D1AA8E41400C03965CC53A4D40CC41D0D1AA8E4140E659492BBE3B4D40795C548B88904140E659492BBE3B4D40795C548B889041400C03965CC53A4D40CC41D0D1AA8E41400C03965CC53A4D40
9915	Барышево	3	31	257	34.669311	34.683512999999998	58.308844999999998	58.303516000000002	0103000020E6100000010000000500000031ED9BFBAB55414008E8BE9CD9264D4031ED9BFBAB5541403D44A33B88274D4007B29E5A7D5741403D44A33B88274D4007B29E5A7D57414008E8BE9CD9264D4031ED9BFBAB55414008E8BE9CD9264D40
9622	Первомайский	3	31	163	32.321671000000002	32.333745	57.403075999999999	57.395660999999997	0103000020E610000001000000050000002B89EC832C294040BDA60705A5B24C402B89EC832C294040B8E68EFE97B34C400D1AFA27B82A4040B8E68EFE97B34C400D1AFA27B82A4040BDA60705A5B24C402B89EC832C294040BDA60705A5B24C40
1024	Новая Русса	3	31	163	32.180537000000001	32.198484999999998	57.422790999999997	57.414988000000001	0103000020E61000000100000005000000E65B1FD61B174040C11DA8531EB54C40E65B1FD61B1740408505F7031EB64C408FDFDBF4671940408505F7031EB64C408FDFDBF467194040C11DA8531EB54C40E65B1FD61B174040C11DA8531EB54C40
57369	Новая Деревня	3	31	163	31.938638999999998	31.956002999999999	57.408332000000001	57.405084000000002	0103000020E6100000010000000500000009C03FA54AF03F400211E2CAD9B34C4009C03FA54AF03F4084F4143944B44C40BDE0D39CBCF43F4084F4143944B44C40BDE0D39CBCF43F400211E2CAD9B34C4009C03FA54AF03F400211E2CAD9B34C40
870	Молвотицы	3	31	163	32.317287999999998	32.338729999999998	57.422485999999999	57.406165000000001	0103000020E61000000100000005000000E5B4A7E49C284040D2E3F736FDB34C40E5B4A7E49C2840404982700514B64C40481630815B2B40404982700514B64C40481630815B2B4040D2E3F736FDB34C40E5B4A7E49C284040D2E3F736FDB34C40
9334	Моисеево	3	31	163	32.077356999999999	32.096212000000001	57.332324999999997	57.324069999999999	0103000020E61000000100000005000000EF8E8CD5E6094040AFCE31207BA94C40EF8E8CD5E6094040545227A089AA4C40CBBDC0AC500C4040545227A089AA4C40CBBDC0AC500C4040AFCE31207BA94C40EF8E8CD5E6094040AFCE31207BA94C40
518	Марево	3	31	163	32.066253000000003	32.091926999999998	57.321323999999997	57.303075999999997	0103000020E61000000100000005000000862172FA7A084040EB19C231CBA64C40862172FA7A084040BFB5132521A94C40484F9143C40B4040BFB5132521A94C40484F9143C40B4040EB19C231CBA64C40862172FA7A084040EB19C231CBA64C40
966	Мамоновщина	3	31	163	32.556140999999997	32.570270999999998	57.351646000000002	57.346294999999998	0103000020E610000001000000050000007C7BD7A02F47404058E2016553AC4C407C7BD7A02F47404076E272BC02AD4C40B96DDFA3FE48404076E272BC02AD4C40B96DDFA3FE48404058E2016553AC4C407C7BD7A02F47404058E2016553AC4C40
640	Липье	3	31	163	32.195404000000003	32.214897999999998	57.343454000000001	57.337133999999999	0103000020E61000000100000005000000F9C08EFF02194040512FF83427AB4C40F9C08EFF0219404017D7F84CF6AB4C40E7FC14C7811B404017D7F84CF6AB4C40E7FC14C7811B4040512FF83427AB4C40F9C08EFF02194040512FF83427AB4C40
9454	Горное	3	31	163	32.379747000000002	32.394067	57.381287999999998	57.369632000000003	0103000020E6100000010000000500000087E0B88C9B3040400DC7F31950AF4C4087E0B88C9B304040BA2D910BCEB04C4067B796C970324040BA2D910BCEB04C4067B796C9703240400DC7F31950AF4C4087E0B88C9B3040400DC7F31950AF4C40
501	Велилы	3	31	163	31.900127999999999	31.903639999999999	57.215387999999997	57.212600999999999	0103000020E61000000100000005000000C136E2C96EE63F40670C7382369B4C40C136E2C96EE63F40B5F97FD5919B4C40815B77F354E73F40B5F97FD5919B4C40815B77F354E73F40670C7382369B4C40C136E2C96EE63F40670C7382369B4C40
737	Афаносово	3	31	163	32.349780000000003	32.359014000000002	57.316288999999998	57.310174000000004	0103000020E61000000100000005000000BF654E97C52C4040E60819C8B3A74C40BF654E97C52C4040D28A6F287CA84C403067B62BF42D4040D28A6F287CA84C403067B62BF42D4040E60819C8B3A74C40BF654E97C52C4040E60819C8B3A74C40
52415	Подгорное	3	31	149	32.792721	32.812474999999999	58.775575000000003	58.765413000000002	0103000020E610000001000000050000001CEDB8E17765404075779D0DF9614D401CEDB8E177654040304CA60A46634D40A7E8482EFF674040304CA60A46634D40A7E8482EFF67404075779D0DF9614D401CEDB8E17765404075779D0DF9614D40
384	Оксочи	3	31	149	32.785265000000003	32.798183000000002	58.665300999999999	58.650517999999998	0103000020E61000000100000005000000C3D8429083644040CBBA7F2C44534D40C3D8429083644040807F4A9528554D40919C4CDC2A664040807F4A9528554D40919C4CDC2A664040CBBA7F2C44534D40C3D8429083644040CBBA7F2C44534D40
8904	Мстинский Мост	3	31	149	32.566938	32.597535000000001	58.696232000000002	58.680573000000003	0103000020E61000000100000005000000096EA46C9148404033C51C041D574D40096EA46C91484040DF3653211E594D40919BE1067C4C4040DF3653211E594D40919BE1067C4C404033C51C041D574D40096EA46C9148404033C51C041D574D40
8130	Малая Вишера	3	31	149	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
4158	Красненка	3	31	149	32.358708999999998	32.375399999999999	58.780161	58.763472	0103000020E61000000100000005000000F3E32F2DEA2D4040B3B45373B9614D40F3E32F2DEA2D4040AD4ECE50DC634D408E75711B0D304040AD4ECE50DC634D408E75711B0D304040B3B45373B9614D40F3E32F2DEA2D4040B3B45373B9614D40
4300	Карпина Гора	3	31	149	32.480961000000001	32.489513000000002	58.639063999999998	58.632328000000001	0103000020E6100000010000000500000063D34A21903D40402C2CB81FF0504D4063D34A21903D4040850662D9CC514D40C2FBAA5CA83E4040850662D9CC514D40C2FBAA5CA83E40402C2CB81FF0504D4063D34A21903D40402C2CB81FF0504D40
4240	Дворищи	3	31	149	32.331104000000003	32.356580000000001	58.653312999999997	58.646079	0103000020E6100000010000000500000093C9A99D612A4040F2D077B7B2524D4093C9A99D612A40409C86A8C29F534D402F34D769A42D40409C86A8C29F534D402F34D769A42D4040F2D077B7B2524D4093C9A99D612A4040F2D077B7B2524D40
57353	Гряды	3	31	149	31.945556	31.989591000000001	58.980386000000003	58.956432999999997	0103000020E610000001000000050000005D8940F50FF23F4057E883656C7A4D405D8940F50FF23F4067BAD7497D7D4D407B6AF5D555FD3F4067BAD7497D7D4D407B6AF5D555FD3F4057E883656C7A4D405D8940F50FF23F4057E883656C7A4D40
8548	Глутно	3	31	149	32.195008999999999	32.211134000000001	58.812685999999999	58.805689999999998	0103000020E610000001000000050000007CB60E0EF61840406C5B94D920674D407CB60E0EF618404062F5471806684D406E895C70061B404062F5471806684D406E895C70061B40406C5B94D920674D407CB60E0EF61840406C5B94D920674D40
8995	Гарь	3	31	149	32.843502999999998	32.855773999999997	58.817625	58.810281000000003	0103000020E61000000100000005000000F88903E8F76B4040FCC8AD49B7674D40F88903E8F76B40402DB29DEFA7684D4030629F008A6D40402DB29DEFA7684D4030629F008A6D4040FCC8AD49B7674D40F88903E8F76B4040FCC8AD49B7674D40
4396	Веребье	3	31	149	32.678832999999997	32.715609999999998	58.688048000000002	58.669961999999998	0103000020E610000001000000050000000839EFFFE356404008C89750C1554D400839EFFFE3564040030AF5F411584D406458C51B995B4040030AF5F411584D406458C51B995B404008C89750C1554D400839EFFFE356404008C89750C1554D40
8685	Бурга	3	31	149	32.446348999999998	32.478831999999997	58.732160999999998	58.712139999999998	0103000020E6100000010000000500000018CDCAF62139404033164D67275B4D4018CDCAF6213940400D349F73B75D4D409E23F25D4A3D40400D349F73B75D4D409E23F25D4A3D404033164D67275B4D4018CDCAF62139404033164D67275B4D40
8560	Большая Вишера	3	31	149	32.067646000000003	32.103596000000003	58.918965999999998	58.896737999999999	0103000020E6100000010000000500000045DAC69FA80840404C8A8F4FC8724D4045DAC69FA808404066118AADA0754D408BFF3BA2420D404066118AADA0754D408BFF3BA2420D40404C8A8F4FC8724D4045DAC69FA80840404C8A8F4FC8724D40
7641	Ярцево	3	31	549	33.176372999999998	33.187054000000003	58.743724999999998	58.737172999999999	0103000020E61000000100000005000000DE72F56393964040423F53AF5B5E4D40DE72F56393964040DA1B7C61325F4D40024BAE62F1974040DA1B7C61325F4D40024BAE62F1974040423F53AF5B5E4D40DE72F56393964040423F53AF5B5E4D40
7213	Шереховичи	3	31	549	33.54665	33.562801999999998	58.800586000000003	58.790579999999999	0103000020E61000000100000005000000E02D90A0F8C54040936FB6B931654D40E02D90A0F8C5404057D11F9A79664D40CB0F5CE509C8404057D11F9A79664D40CB0F5CE509C84040936FB6B931654D40E02D90A0F8C54040936FB6B931654D40
7129	Слобода	3	31	549	33.639778	33.663314	58.781495	58.771106000000003	0103000020E61000000100000005000000A359D93EE4D14040ECDFF599B3624D40A359D93EE4D14040677E350708644D404E7D2079E7D44040677E350708644D404E7D2079E7D44040ECDFF599B3624D40A359D93EE4D14040ECDFF599B3624D40
52379	Никольское	3	31	549	33.425539000000001	33.439939000000003	58.777982000000002	58.768549	0103000020E610000001000000050000001616DC0F78B64040CF2F4AD05F624D401616DC0F78B64040377007EA94634D40139ED0EB4FB84040377007EA94634D40139ED0EB4FB84040CF2F4AD05F624D401616DC0F78B64040CF2F4AD05F624D40
8037	Неболчи	3	31	549	33.318702999999999	33.368423999999997	59.131261000000002	59.112917000000003	0103000020E610000001000000050000008C118942CBA84040CB147310748E4D408C118942CBA84040C11E1329CD904D40DF87838428AF4040C11E1329CD904D40DF87838428AF4040CB147310748E4D408C118942CBA84040CB147310748E4D40
3669	Любытино	3	31	549	33.374569000000001	33.418486999999999	58.823869000000002	58.806472999999997	0103000020E61000000100000005000000378C82E0F1AF4040B20DDC813A674D40378C82E0F1AF40401898158A74694D408C6665FB90B540401898158A74694D408C6665FB90B54040B20DDC813A674D40378C82E0F1AF4040B20DDC813A674D40
7408	Комарово	3	31	549	33.401392000000001	33.448635000000003	58.655022000000002	58.640979000000002	0103000020E61000000100000005000000227024D060B340401E3691990B524D40227024D060B340408C14CAC2D7534D40A56B26DF6CB940408C14CAC2D7534D40A56B26DF6CB940401E3691990B524D40227024D060B340401E3691990B524D40
57348	Зарубино	3	31	549	33.458741000000003	33.492804999999997	58.744200999999997	58.727929000000003	0103000020E61000000100000005000000CC2A6C06B8BA4040AE6708C72C5D4D40CC2A6C06B8BA4040435376FA415F4D401327F73B14BF4040435376FA415F4D401327F73B14BF4040AE6708C72C5D4D40CC2A6C06B8BA4040AE6708C72C5D4D40
7838	Заполье	3	31	549	32.941319999999997	32.958424000000001	59.293041000000002	59.285229000000001	0103000020E610000001000000050000000D897B2C7D784040766F456282A44D400D897B2C7D7840408EB1135E82A54D40CBD93BA3AD7A40408EB1135E82A54D40CBD93BA3AD7A4040766F456282A44D400D897B2C7D784040766F456282A44D40
3826	Дрегли	3	31	549	33.515828999999997	33.538556	59.247739000000003	59.235598000000003	0103000020E6100000010000000500000008AA46AF06C2404063804413289E4D4008AA46AF06C24040CD785BE9B59F4D4044882B67EFC44040CD785BE9B59F4D4044882B67EFC4404063804413289E4D4008AA46AF06C2404063804413289E4D40
3627	Вычерема	3	31	549	33.107455000000002	33.127541000000001	58.851083000000003	58.843183000000003	0103000020E610000001000000050000005665DF15C18D404087C5A86BED6B4D405665DF15C18D40403E97A949F06C4D4017F37343539040403E97A949F06C4D4017F373435390404087C5A86BED6B4D405665DF15C18D404087C5A86BED6B4D40
7494	Высочка	3	31	549	33.423338000000001	33.433506999999999	58.914180999999999	58.907246999999998	0103000020E61000000100000005000000B89388F02FB64040723271AB20744D40B89388F02FB64040F2CF0CE203754D4025CB49287DB74040F2CF0CE203754D4025CB49287DB74040723271AB20744D40B89388F02FB64040723271AB20744D40
3919	Водогон	3	31	549	32.995362999999998	33.014246	59.175815999999998	59.163608000000004	0103000020E610000001000000050000000053060E687F404097AE601BF1944D400053060E687F4040880E812381964D40A60C1CD0D2814040880E812381964D40A60C1CD0D281404097AE601BF1944D400053060E687F404097AE601BF1944D40
52377	Васильково	3	31	549	33.516385999999997	33.526743000000003	58.706961	58.698827000000001	0103000020E610000001000000050000005E0EBBEF18C24040E947C32973594D405E0EBBEF18C240401346B3B27D5A4D40CF328B506CC340401346B3B27D5A4D40CF328B506CC34040E947C32973594D405E0EBBEF18C24040E947C32973594D40
52399	Ваган	3	31	549	33.389552999999999	33.406117999999999	59.046138999999997	59.038612000000001	0103000020E61000000100000005000000838769DFDCB14040D89DEE3CF1844D40838769DFDCB14040FA08FCE1E7854D409128B4ACFBB34040FA08FCE1E7854D409128B4ACFBB34040D89DEE3CF1844D40838769DFDCB14040D89DEE3CF1844D40
3395	Артем	3	31	549	33.495229999999999	33.509872999999999	58.747408999999998	58.734454999999997	0103000020E61000000100000005000000C1FF56B263BF40401CB1169F025E4D40C1FF56B263BF404037DE1D19AB5F4D40840EBA8443C1404037DE1D19AB5F4D40840EBA8443C140401CB1169F025E4D40C1FF56B263BF40401CB1169F025E4D40
6662	Ямская Слобода	3	31	528	32.520072999999996	32.532533000000001	58.266967999999999	58.258569999999999	0103000020E610000001000000050000002C4487C09142404005DD5ED218214D402C4487C0914240400D8AE6012C224D403885950A2A4440400D8AE6012C224D403885950A2A44404005DD5ED218214D402C4487C09142404005DD5ED218214D40
6816	Усть-Волма	3	31	528	32.430143000000001	32.445998000000003	58.471592999999999	58.460648999999997	0103000020E610000001000000050000003ACD02ED0E374040B1F7E28BF63A4D403ACD02ED0E374040E202D0285D3C4D406C0A647616394040E202D0285D3C4D406C0A647616394040B1F7E28BF63A4D403ACD02ED0E374040B1F7E28BF63A4D40
3309	Соменка	3	31	528	32.771566	32.795703000000003	58.066392	58.057583999999999	0103000020E610000001000000050000004F5AB8ACC2624040ED629AE95E074D404F5AB8ACC2624040A75B76887F084D40202A8D98D9654040A75B76887F084D40202A8D98D9654040ED629AE95E074D404F5AB8ACC2624040ED629AE95E074D40
6925	Ручьи	3	31	528	32.685865999999997	32.705908000000001	58.357840000000003	58.349936	0103000020E610000001000000050000001BB80375CA574040B6D8EDB3CA2C4D401BB80375CA574040AF997CB3CD2D4D400DFE7E315B5A4040AF997CB3CD2D4D400DFE7E315B5A4040B6D8EDB3CA2C4D401BB80375CA574040B6D8EDB3CA2C4D40
6821	Ольховка	3	31	528	32.277608999999998	32.290877000000002	58.442816999999998	58.437432999999999	0103000020E61000000100000005000000A20914B1882340407898F6CDFD374D40A20914B188234040718E3A3AAE384D404D1421753B254040718E3A3AAE384D404D1421753B2540407898F6CDFD374D40A20914B1882340407898F6CDFD374D40
3207	Новое Рахино	3	31	528	32.750436999999998	32.765726999999998	58.150205999999997	58.140858000000001	0103000020E61000000100000005000000AB5AD2510E604040A3B08BA207124D40AB5AD2510E604040DCD440F339134D400455A35703624040DCD440F339134D400455A35703624040A3B08BA207124D40AB5AD2510E604040A3B08BA207124D40
6936	Лякова	3	31	528	32.609968000000002	32.623756999999998	58.297637999999999	58.285386000000003	0103000020E61000000100000005000000A3CD716E134E40403E5E488787244D40A3CD716E134E4040FF05820019264D4056D3F544D74F4040FF05820019264D4056D3F544D74F40403E5E488787244D40A3CD716E134E40403E5E488787244D40
7119	Локотско	3	31	528	32.929912000000002	32.953375999999999	58.227936999999997	58.219098000000002	0103000020E6100000010000000500000038143E5B077740403C4F3C670B1C4D4038143E5B077740403046240A2D1D4D4049658A39087A40403046240A2D1D4D4049658A39087A40403C4F3C670B1C4D4038143E5B077740403C4F3C670B1C4D40
47070	Крестцы	3	31	528	32.483853000000003	32.551307999999999	58.268241000000003	58.228406	0103000020E61000000100000005000000278925E5EE3D4040E71A66683C1D4D40278925E5EE3D4040223999B855224D40F702B34291464040223999B855224D40F702B34291464040E71A66683C1D4D40278925E5EE3D4040E71A66683C1D4D40
6738	Зайцево	3	31	528	32.047981999999998	32.085934999999999	58.371783999999998	58.365290000000002	0103000020E61000000100000005000000F96530462406404026C79DD2C12E4D40F96530462406404089963C9E962F4D40774A07EBFF0A404089963C9E962F4D40774A07EBFF0A404026C79DD2C12E4D40F96530462406404026C79DD2C12E4D40
6781	Вины	3	31	528	32.202914	32.237363999999999	58.364634000000002	58.354596000000001	0103000020E6100000010000000500000045F30016F91940406EA5D766632D4D4045F30016F91940403D81B053AC2E4D40B69F8CF1611E40403D81B053AC2E4D40B69F8CF1611E40406EA5D766632D4D4045F30016F91940406EA5D766632D4D40
6424	Ямник	3	31	773	32.480134	32.502439000000003	57.847203999999998	57.836123999999998	0103000020E610000001000000050000004DD9E907753D40404AB3791C06EB4C404DD9E907753D40402B85402E71EC4C40139ED0EB4F4040402B85402E71EC4C40139ED0EB4F4040404AB3791C06EB4C404DD9E907753D40404AB3791C06EB4C40
6352	Шишково	3	31	773	32.550131	32.572642999999999	57.597332999999999	57.587662000000002	0103000020E6100000010000000500000005C24EB16A4640400D8D278238CB4C4005C24EB16A46404029E9616875CC4C4044A4A65D4C49404029E9616875CC4C4044A4A65D4C4940400D8D278238CB4C4005C24EB16A4640400D8D278238CB4C40
6325	Черный Ручей	3	31	773	32.572158000000002	32.586638000000001	57.747078000000002	57.740530999999997	0103000020E6100000010000000500000088122D793C4940404B5645B8C9DE4C4088122D793C494040D2C77C40A0DF4C40A14B38F4164B4040D2C77C40A0DF4C40A14B38F4164B40404B5645B8C9DE4C4088122D793C4940404B5645B8C9DE4C40
6254	Филиппова Гора	3	31	773	32.758809999999997	32.769167000000003	57.641409000000003	57.635623000000002	0103000020E610000001000000050000005AF0A2AF20614040EFCA2E185CD14C405AF0A2AF20614040172EABB019D24C40CB14731074624040172EABB019D24C40CB14731074624040EFCA2E185CD14C405AF0A2AF20614040EFCA2E185CD14C40
6199	Старое Тарасово	3	31	773	32.442188999999999	32.455843999999999	57.539057	57.531289000000001	0103000020E6100000010000000500000052D32EA699384040BEDC274701C44C4052D32EA69938404006D7DCD1FFC44C40F609A018593A404006D7DCD1FFC44C40F609A018593A4040BEDC274701C44C4052D32EA699384040BEDC274701C44C40
6165	Полново	3	31	773	32.937538000000004	32.956969000000001	57.539864000000001	57.528799999999997	0103000020E61000000100000005000000EE60C43E01784040F90FE9B7AFC34C40EE60C43E01784040D52478431AC54C409624CFF57D7A4040D52478431AC54C409624CFF57D7A4040F90FE9B7AFC34C40EE60C43E01784040F90FE9B7AFC34C40
6123	Пески	3	31	773	32.601954999999997	32.616543	57.648504000000003	57.642265999999999	0103000020E61000000100000005000000F35487DC0C4D404097AAB4C535D24C40F35487DC0C4D4040A0A9D72D02D34C40F3C98AE1EA4E4040A0A9D72D02D34C40F3C98AE1EA4E404097AAB4C535D24C40F35487DC0C4D404097AAB4C535D24C40
6037	Новая Скребель	3	31	773	33.054634	33.068306	57.513410999999998	57.503982999999998	0103000020E61000000100000005000000F59F353FFE864040B75ED38382C04C40F59F353FFE8640400D349F73B7C14C406F0F4240BE8840400D349F73B7C14C406F0F4240BE884040B75ED38382C04C40F59F353FFE864040B75ED38382C04C40
5968	Никольское	3	31	773	32.992514999999997	33.01182	57.733896000000001	57.723896000000003	0103000020E610000001000000050000000CE544BB0A7F404045DAC69FA8DC4C400CE544BB0A7F40402655DB4DF0DD4C4028B85851838140402655DB4DF0DD4C4028B858518381404045DAC69FA8DC4C400CE544BB0A7F404045DAC69FA8DC4C40
52330	Малые Луки	3	31	773	32.517028000000003	32.527053000000002	57.643783999999997	57.637819999999998	0103000020E61000000100000005000000E38E37F92D4240400B5EF415A4D14C40E38E37F92D42404012D89C8367D24C401D2103797643404012D89C8367D24C401D210379764340400B5EF415A4D14C40E38E37F92D4240400B5EF415A4D14C40
5963	Лычково	3	31	773	32.382263000000002	32.421329999999998	57.927401000000003	57.898417999999999	0103000020E6100000010000000500000045BC75FEED304040A1116C5CFFF24C4045BC75FEED3040408CA37213B5F64C406E693524EE3540408CA37213B5F64C406E693524EE354040A1116C5CFFF24C4045BC75FEED304040A1116C5CFFF24C40
5898	Кневицы	3	31	773	32.211888000000002	32.237076999999999	57.935752999999998	57.919142000000001	0103000020E610000001000000050000001A355F251F1B4040A530EF71A6F54C401A355F251F1B404023111AC1C6F74C4020D1048A581E404023111AC1C6F74C4020D1048A581E4040A530EF71A6F54C401A355F251F1B4040A530EF71A6F54C40
5818	Ильина Гора	3	31	773	32.645766000000002	32.658881000000001	57.584183000000003	57.577765999999997	0103000020E61000000100000005000000336FD575A8524040D05E7D3CF4C94C40336FD575A852404089F02F82C6CA4C40577A6D365654404089F02F82C6CA4C40577A6D3656544040D05E7D3CF4C94C40336FD575A8524040D05E7D3CF4C94C40
5792	Жирково	3	31	773	32.402430000000003	32.413623000000001	57.669255999999997	57.661929000000001	0103000020E61000000100000005000000F37684D38233404012A3E716BAD44C40F37684D3823340406D533C2EAAD54C40CCEF3499F13440406D533C2EAAD54C40CCEF3499F134404012A3E716BAD44C40F37684D38233404012A3E716BAD44C40
5626	Демянск	3	31	773	32.439135	32.485497000000002	57.667532999999999	57.632944000000002	0103000020E61000000100000005000000B5C35F933538404087191A4F04D14C40B5C35F93353840401900AAB871D54C402FA704C4243E40401900AAB871D54C402FA704C4243E404087191A4F04D14C40B5C35F933538404087191A4F04D14C40
5553	Вотолино	3	31	773	32.70872	32.721178999999999	57.510815000000001	57.501483	0103000020E61000000100000005000000B4024356B75A4040FF3F4E9830C04C40B4024356B75A404033A7CB6262C14C40EFC7ED974F5C404033A7CB6262C14C40EFC7ED974F5C4040FF3F4E9830C04C40B4024356B75A4040FF3F4E9830C04C40
57357	Великий Завод	3	31	773	32.117116000000003	32.129890000000003	57.617227999999997	57.604683000000001	0103000020E610000001000000050000004FEB36A8FD0E40403DB9A64066CD4C404FEB36A8FD0E40407616BD5301CF4C40EA094B3CA01040407616BD5301CF4C40EA094B3CA01040403DB9A64066CD4C404FEB36A8FD0E40403DB9A64066CD4C40
5416	Соловьево	3	31	702	30.591597	30.612447	57.772291000000003	57.759371999999999	0103000020E610000001000000050000006669A7E672973E40C2BF081A33E14C406669A7E672973E4061FF756EDAE24C4087889B53C99C3E4061FF756EDAE24C4087889B53C99C3E40C2BF081A33E14C406669A7E672973E40C2BF081A33E14C40
5307	Славитино	3	31	702	30.686593999999999	30.706105000000001	57.821914999999997	57.811340000000001	0103000020E610000001000000050000003CA1D79FC4AF3E40E4F736FDD9E74C403CA1D79FC4AF3E40C18BBE8234E94C40C68A1A4CC3B43E40C18BBE8234E94C40C68A1A4CC3B43E40E4F736FDD9E74C403CA1D79FC4AF3E40E4F736FDD9E74C40
5050	Раглицы	3	31	702	30.731131999999999	30.752126000000001	57.963149000000001	57.949854999999999	0103000020E610000001000000050000001F0F7D772BBB3E40967840D994F94C401F0F7D772BBB3E406A16687748FB4C40A7785C548BC03E406A16687748FB4C40A7785C548BC03E40967840D994F94C401F0F7D772BBB3E40967840D994F94C40
4923	Порожки	3	31	702	30.851317999999999	30.863489999999999	57.918543999999997	57.910463999999997	0103000020E61000000100000005000000027FF8F9EFD93E40B91798158AF44C40027FF8F9EFD93E40F0F78BD992F54C404C6C3EAE0DDD3E40F0F78BD992F54C404C6C3EAE0DDD3E40B91798158AF44C40027FF8F9EFD93E40B91798158AF44C40
5071	Дерглец	3	31	702	30.616786000000001	30.639720000000001	57.888247999999997	57.875697000000002	0103000020E6100000010000000500000073A1F2AFE59D3E40481ADCD616F04C4073A1F2AFE59D3E40635E471CB2F14C40DD989EB0C4A33E40635E471CB2F14C40DD989EB0C4A33E40481ADCD616F04C4073A1F2AFE59D3E40481ADCD616F04C40
5231	Горки Ратицкие	3	31	702	30.538677	30.582927999999999	57.987217999999999	57.972481999999999	0103000020E610000001000000050000007E1B62BCE6893E406EF9484A7AFC4C407E1B62BCE6893E40E202D0285DFE4C4035ECF7C43A953E40E202D0285DFE4C4035ECF7C43A953E406EF9484A7AFC4C407E1B62BCE6893E406EF9484A7AFC4C40
5198	Горицы	3	31	702	30.819759999999999	30.835445	58.030994	58.020204	0103000020E61000000100000005000000A79196CADBD13E40CB9F6F0B96024D40A79196CADBD13E40A52F849CF7034D40529B38B9DFD53E40A52F849CF7034D40529B38B9DFD53E40CB9F6F0B96024D40A79196CADBD13E40CB9F6F0B96024D40
57358	Геородцы	3	31	702	30.754021000000002	30.779408	57.997908000000002	57.980685999999999	0103000020E610000001000000050000004A7F2F8507C13E4091D26C1E87FD4C404A7F2F8507C13E4059350873BBFF4C40A33D5E4887C73E4059350873BBFF4C40A33D5E4887C73E4091D26C1E87FD4C404A7F2F8507C13E4091D26C1E87FD4C40
4899	Волот	3	31	702	30.690493	30.72391	57.937168	57.917239000000002	0103000020E61000000100000005000000EF1D3526C4B03E40D1CE691668F54C40EF1D3526C4B03E40CA6DFB1EF5F74C40533F6F2A52B93E40CA6DFB1EF5F74C40533F6F2A52B93E40D1CE691668F54C40EF1D3526C4B03E40D1CE691668F54C40
5328	Верехново	3	31	702	30.822823	30.839055999999999	57.787916000000003	57.769247999999997	0103000020E6100000010000000500000088653387A4D23E40B741EDB776E24C4088653387A4D23E4061FF756EDAE44C403883BF5FCCD63E4061FF756EDAE44C403883BF5FCCD63E40B741EDB776E24C4088653387A4D23E40B741EDB776E24C40
4630	Яжелбицы	3	31	526	32.935212	32.979650999999997	58.041823999999998	58.028778000000003	0103000020E61000000100000005000000D369DD06B5774040126C5CFFAE034D40D369DD06B57740400D18247D5A054D40313F3734657D40400D18247D5A054D40313F3734657D4040126C5CFFAE034D40D369DD06B5774040126C5CFFAE034D40
4445	Шуя	3	31	526	33.383929000000002	33.397817000000003	58.018884	58.009177000000001	0103000020E61000000100000005000000357EE19524B140400D7041B62C014D40357EE19524B14040763579CA6A024D407C65DEAAEBB24040763579CA6A024D407C65DEAAEBB240400D7041B62C014D40357EE19524B140400D7041B62C014D40
4520	Семеновщина	3	31	526	32.695739000000003	32.712735000000002	57.929034999999999	57.919127000000003	0103000020E61000000100000005000000A0C6BDF90D59404070EF1AF4A5F54C40A0C6BDF90D59404070EB6E9EEAF64C4077DB85E63A5B404070EB6E9EEAF64C4077DB85E63A5B404070EF1AF4A5F54C40A0C6BDF90D59404070EF1AF4A5F54C40
4398	Рощино	3	31	526	33.317974999999997	33.328727999999998	58.026400000000002	58.022730000000003	0103000020E6100000010000000500000009F9A067B3A84040AD510FD1E8024D4009F9A067B3A84040A54E401361034D40C6A354C213AA4040A54E401361034D40C6A354C213AA4040AD510FD1E8024D4009F9A067B3A84040AD510FD1E8024D40
4162	Приозерный	3	31	526	33.119995000000003	33.127155000000002	58.136535000000002	58.127676999999998	0103000020E610000001000000050000007E5704FF5B8F4040C7B94DB857104D407E5704FF5B8F404033E197FA79114D40EE42739D4690404033E197FA79114D40EE42739D46904040C7B94DB857104D407E5704FF5B8F4040C7B94DB857104D40
3917	Наволок	3	31	526	33.406512999999997	33.417462999999998	57.845891999999999	57.84113	0103000020E610000001000000050000000D33349E08B440409DD7D825AAEB4C400D33349E08B4404059F9653046EC4C402025766D6FB5404059F9653046EC4C402025766D6FB540409DD7D825AAEB4C400D33349E08B440409DD7D825AAEB4C40
4245	Любница	3	31	526	32.688893999999998	32.711055000000002	57.977907999999999	57.960461000000002	0103000020E610000001000000050000008F34B8AD2D584040AF0AD462F0FA4C408F34B8AD2D584040963FDF162CFD4C402254A9D9035B4040963FDF162CFD4C402254A9D9035B4040AF0AD462F0FA4C408F34B8AD2D584040AF0AD462F0FA4C40
4297	Лутовенка	3	31	526	32.775401000000002	32.799574999999997	58.017395999999998	58.004255999999998	0103000020E610000001000000050000009224085740634040E867EA758B004D409224085740634040658A39083A024D407FD93D7958664040658A39083A024D407FD93D7958664040E867EA758B004D409224085740634040E867EA758B004D40
3831	Красилово	3	31	526	33.319797999999999	33.342956999999998	57.692309999999999	57.685684999999999	0103000020E61000000100000005000000C1A90F24EFA84040CB2DAD86C4D74C40C1A90F24EFA84040CD58349D9DD84C409677D503E6AB4040CD58349D9DD84C409677D503E6AB4040CB2DAD86C4D74C40C1A90F24EFA84040CB2DAD86C4D74C40
4137	Костково	3	31	526	33.030459999999998	33.054803999999997	58.125387000000003	58.118462000000001	0103000020E6100000010000000500000007EBFF1CE6834040CDE847C3290F4D4007EBFF1CE6834040FA2B64AE0C104D4051D845D103874040FA2B64AE0C104D4051D845D103874040CDE847C3290F4D4007EBFF1CE6834040CDE847C3290F4D40
4036	Короцко	3	31	526	33.237665999999997	33.252181999999998	57.942723999999998	57.934458999999997	0103000020E6100000010000000500000081AFE8D66B9E4040F7393E5A9CF74C4081AFE8D66B9E4040C093162EABF84C40E751F17F47A04040C093162EABF84C40E751F17F47A04040F7393E5A9CF74C4081AFE8D66B9E4040F7393E5A9CF74C40
4025	Ивантеево	3	31	526	33.138150000000003	33.153134000000001	57.798842999999998	57.790948	0103000020E61000000100000005000000A1F831E6AE914040166BB8C83DE54C40A1F831E6AE914040BBD1C77C40E64C40EDF318E599934040BBD1C77C40E64C40EDF318E599934040166BB8C83DE54C40A1F831E6AE914040166BB8C83DE54C40
3707	Зимогорье	3	31	526	33.259225000000001	33.290792000000003	57.960881000000001	57.952151999999998	0103000020E610000001000000050000001EA7E8482EA140401669E21DE0F94C401EA7E8482EA14040842C0B26FEFA4C401FF818AC38A54040842C0B26FEFA4C401FF818AC38A540401669E21DE0F94C401EA7E8482EA140401669E21DE0F94C40
3751	Едрово	3	31	526	33.590325999999997	33.638314000000001	57.925407999999997	57.901254000000002	0103000020E610000001000000050000003FFD67CD8FCB4040D1B1834A5CF34C403FFD67CD8FCB404077BAF3C473F64C401B4AED45B4D1404077BAF3C473F64C401B4AED45B4D14040D1B1834A5CF34C403FFD67CD8FCB4040D1B1834A5CF34C40
3825	Добывалово	3	31	526	33.427632000000003	33.446919000000001	57.943942	57.936914999999999	0103000020E610000001000000050000008E5C37A5BCB64040E010AAD4ECF74C408E5C37A5BCB6404011A96917D3F84C40037B4CA434B9404011A96917D3F84C40037B4CA434B94040E010AAD4ECF74C408E5C37A5BCB64040E010AAD4ECF74C40
4708	Дворец	3	31	526	32.982633999999997	33.004130000000004	57.946927000000002	57.939466000000003	0103000020E6100000010000000500000005F86EF3C67D40401BDA006C40F84C4005F86EF3C67D4040865968E734F94C405C77F35487804040865968E734F94C405C77F354878040401BDA006C40F84C4005F86EF3C67D40401BDA006C40F84C40
3192	Валдай	3	31	526	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
4540	Большое Замошье	3	31	526	32.807380999999999	32.824224999999998	57.794128000000001	57.786140000000003	0103000020E61000000100000005000000B534B74258674040EA094B3CA0E44C40B534B74258674040406B7EFCA5E54C40D6C56D3480694040406B7EFCA5E54C40D6C56D3480694040EA094B3CA0E44C40B534B74258674040EA094B3CA0E44C40
3093	Удино	3	31	44	34.306911999999997	34.325606000000001	58.662633	58.657096000000003	0103000020E61000000100000005000000FE5F75E4482741408D2AC3B81B544D40FE5F75E4482741400C207C28D1544D40D1B01875AD2941400C207C28D1544D40D1B01875AD2941408D2AC3B81B544D40FE5F75E4482741408D2AC3B81B544D40
46389	Тухун	3	31	44	34.081228000000003	34.096428000000003	58.469414	58.462499000000001	0103000020E610000001000000050000007FC2D9AD650A414063B7CF2A333B4D407FC2D9AD650A41406C2409C2153C4D409835B1C0570C41406C2409C2153C4D409835B1C0570C414063B7CF2A333B4D407FC2D9AD650A414063B7CF2A333B4D40
2953	Травково	3	31	44	33.677166	33.711733000000002	58.319547	58.295811999999998	0103000020E6100000010000000500000048FB1F60ADD64040D6E1E82ADD254D4048FB1F60ADD64040784485EAE6284D40F33D23111ADB4040784485EAE6284D40F33D23111ADB4040D6E1E82ADD254D4048FB1F60ADD64040D6E1E82ADD254D40
2847	Сушилово	3	31	44	33.610959999999999	33.626277000000002	58.422789000000002	58.414912999999999	0103000020E610000001000000050000000395F1EF33CE4040B6D782DE1B354D400395F1EF33CE4040E50D30F31D364D40569E40D829D04040E50D30F31D364D40569E40D829D04040B6D782DE1B354D400395F1EF33CE4040B6D782DE1B354D40
3042	Сутоки-Рядок	3	31	44	33.698833999999998	33.711680000000001	58.271394000000001	58.265372999999997	0103000020E610000001000000050000009BAA7B6473D94040E61E12BEF7214D409BAA7B6473D94040522AE109BD224D40D09B8A5418DB4040522AE109BD224D40D09B8A5418DB4040E61E12BEF7214D409BAA7B6473D94040E61E12BEF7214D40
57364	Речка	3	31	44	33.844180999999999	33.860953000000002	58.182774999999999	58.173473999999999	0103000020E61000000100000005000000C9737D1F0EEC4040685A626534164D40C9737D1F0EEC404061C3D32B65174D40513239B533EE404061C3D32B65174D40513239B533EE4040685A626534164D40C9737D1F0EEC4040685A626534164D40
2498	Прошково	3	31	44	33.872675999999998	33.878973000000002	58.310391000000003	58.307568000000003	0103000020E610000001000000050000008600E0D8B3EF4040E8A562635E274D408600E0D8B3EF404083FC6CE4BA274D409488F02F82F0404083FC6CE4BA274D409488F02F82F04040E8A562635E274D408600E0D8B3EF4040E8A562635E274D40
2605	Прогресс	3	31	44	33.930644000000001	33.943328000000001	58.405065	58.397835999999998	0103000020E61000000100000005000000FC1BB4571FF74040F295404AEC324D40FC1BB4571FF740408BE07F2BD9334D4057B3CEF8BEF840408BE07F2BD9334D4057B3CEF8BEF84040F295404AEC324D40FC1BB4571FF74040F295404AEC324D40
2508	Починная Сопка	3	31	44	34.352026000000002	34.409346999999997	58.423383000000001	58.414347999999997	0103000020E61000000100000005000000BDAB1E300F2D4140DD94F25A09354D40BDAB1E300F2D41405857056A31364D409CDB847B653441405857056A31364D409CDB847B65344140DD94F25A09354D40BDAB1E300F2D4140DD94F25A09354D40
2358	Перелучи	3	31	44	34.486620000000002	34.501154999999997	58.220776000000001	58.209274999999998	0103000020E610000001000000050000002ECA6C90493E4140696FF085C91A4D402ECA6C90493E4140F0DE5163421C4D400A9DD7D825404140F0DE5163421C4D400A9DD7D825404140696FF085C91A4D402ECA6C90493E4140696FF085C91A4D40
2262	Передки	3	31	44	34.035207999999997	34.059328000000001	58.415709999999997	58.406734	0103000020E610000001000000050000005E471CB281044140EC1516DC0F344D405E471CB281044140614F3BFC35354D4059DE550F98074140614F3BFC35354D4059DE550F98074140EC1516DC0F344D405E471CB281044140EC1516DC0F344D40
2171	Опеченский Посад	3	31	44	34.096041999999997	34.141955000000003	58.280754000000002	58.270744999999998	0103000020E610000001000000050000006E85B01A4B0C41401B47ACC5A7224D406E85B01A4B0C4140501C40BFEF234D407940D9942B124140501C40BFEF234D407940D9942B1241401B47ACC5A7224D406E85B01A4B0C41401B47ACC5A7224D40
41058	Круппа	3	31	44	33.881757999999998	33.891998000000001	58.343313999999999	58.334952999999999	0103000020E61000000100000005000000417E3672DDF040403A596ABDDF2A4D40417E3672DDF04040252191B6F12B4D40780C8FFD2CF24040252191B6F12B4D40780C8FFD2CF240403A596ABDDF2A4D40417E3672DDF040403A596ABDDF2A4D40
57368	Кончанско-Суворовское	3	31	44	34.062696000000003	34.080697999999998	58.660212999999999	58.649867	0103000020E6100000010000000500000086CB2A6C06084140F4DF83D72E534D4086CB2A6C0608414070B20DDC81544D40226DE34F540A414070B20DDC81544D40226DE34F540A4140F4DF83D72E534D4086CB2A6C06084140F4DF83D72E534D40
2742	Коегоща	3	31	44	33.865147999999998	33.902329000000002	58.429433000000003	58.417482	0103000020E6100000010000000500000093196F2BBDEE40409755D80C70354D4093196F2BBDEE40405E6919A9F7364D40BF9D44847FF340405E6919A9F7364D40BF9D44847FF340409755D80C70354D4093196F2BBDEE40409755D80C70354D40
2063	Кировский	3	31	44	33.727390999999997	33.747819	58.594043999999997	58.581684000000003	0103000020E61000000100000005000000CE33F6251BDD4040A14D0E9F744A4D40CE33F6251BDD4040483140A2094C4D40E9297288B8DF4040483140A2094C4D40E9297288B8DF4040A14D0E9F744A4D40CE33F6251BDD4040A14D0E9F744A4D40
2994	Желомля	3	31	44	33.808239	33.821956999999998	58.383406999999998	58.377659999999999	0103000020E61000000100000005000000062D246074E74040F180B22957304D40062D246074E740405B07077B13314D40F0DB10E335E940405B07077B13314D40F0DB10E335E94040F180B22957304D40062D246074E74040F180B22957304D40
1956	Железково	3	31	44	33.929422000000002	33.939340000000001	58.288722	58.283560000000001	0103000020E610000001000000050000006A17D34CF7F64040153AAFB14B244D406A17D34CF7F640405FD1ADD7F4244D408EE9094B3CF840405FD1ADD7F4244D408EE9094B3CF84040153AAFB14B244D406A17D34CF7F64040153AAFB14B244D40
1802	Елигово	3	31	44	33.612766000000001	33.624290999999999	58.628847	58.622244999999999	0103000020E61000000100000005000000E50CC51D6FCE4040BD8C62B9A54F4D40E50CC51D6FCE40400798F90E7E504D40F4177AC4E8CF40400798F90E7E504D40F4177AC4E8CF4040BD8C62B9A54F4D40E50CC51D6FCE4040BD8C62B9A54F4D40
1903	Егла	3	31	44	33.967860999999999	34.025748999999998	58.328262000000002	58.309181000000002	0103000020E61000000100000005000000740987DEE2FB4040B5C5353E93274D40740987DEE2FB404081423D7D042A4D40CD7344BE4B03414081423D7D042A4D40CD7344BE4B034140B5C5353E93274D40740987DEE2FB4040B5C5353E93274D40
1798	Волок	3	31	44	33.750954	33.771112000000002	58.521315999999999	58.50855	0103000020E610000001000000050000007366BB421FE04040BE30992A18414D407366BB421FE04040D670917BBA424D40CEC64ACCB3E24040D670917BBA424D40CEC64ACCB3E24040BE30992A18414D407366BB421FE04040BE30992A18414D40
2838	Волгино	3	31	44	33.863782	33.878397999999997	58.450978999999997	58.440721000000003	0103000020E61000000100000005000000CE6F986890EE404089D4B48B69384D40CE6F986890EE404065170CAEB9394D40976F7D586FF0404065170CAEB9394D40976F7D586FF0404089D4B48B69384D40CE6F986890EE404089D4B48B69384D40
52	Боровичи	3	31	44	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
2655	Березник	3	31	44	33.86495	33.873286	58.494329999999998	58.488610999999999	0103000020E610000001000000050000006D567DAEB6EE4040A1BB24CE8A3E4D406D567DAEB6EE404041B79734463F4D40FF06EDD5C7EF404041B79734463F4D40FF06EDD5C7EF4040A1BB24CE8A3E4D406D567DAEB6EE4040A1BB24CE8A3E4D40
2014	Ануфриево	3	31	44	33.974058999999997	33.987678000000002	58.310518999999999	58.294955999999999	0103000020E61000000100000005000000EEAF1EF7ADFC404026E1421EC1254D40EEAF1EF7ADFC4040B0E42A16BF274D40467D923B6CFE4040B0E42A16BF274D40467D923B6CFE404026E1421EC1254D40EEAF1EF7ADFC404026E1421EC1254D40
32006	Черное	3	31	952	30.670549999999999	30.686540000000001	58.6496	58.639462000000002	0103000020E610000001000000050000003255302AA9AB3E4073840CE4D9514D403255302AA9AB3E40A5BDC11726534D405665DF15C1AF3E40A5BDC11726534D405665DF15C1AF3E4073840CE4D9514D403255302AA9AB3E4073840CE4D9514D40
9502	Новое Овсино	3	31	952	30.286753999999998	30.297595999999999	58.494146999999998	58.489373000000001	0103000020E6100000010000000500000047FFCBB568493E40D04543C6A33E4D4047FFCBB568493E4050357A35403F4D40A06B5F402F4C3E4050357A35403F4D40A06B5F402F4C3E40D04543C6A33E4D4047FFCBB568493E40D04543C6A33E4D40
32042	Мойка	3	31	952	30.617343000000002	30.643663	58.628725000000003	58.619776000000002	0103000020E610000001000000050000001F6ADB300A9E3E40406CE9D1544F4D401F6ADB300A9E3E40BC96900F7A504D402FA52E19C7A43E40BC96900F7A504D402FA52E19C7A43E40406CE9D1544F4D401F6ADB300A9E3E40406CE9D1544F4D40
7778	Мелковичи	3	31	952	30.176898999999999	30.201764000000001	58.437748999999997	58.432580999999999	0103000020E61000000100000005000000F2B1BB40492D3E407CEF6FD05E374D40F2B1BB40492D3E40A86DC32808384D40998235CEA6333E40A86DC32808384D40998235CEA6333E407CEF6FD05E374D40F2B1BB40492D3E407CEF6FD05E374D40
11611	Косицкое	3	31	952	30.447633	30.46471	58.478166999999999	58.470740999999997	0103000020E61000000100000005000000419C871398723E4073F1B73D413C4D40419C871398723E4062838593343D4D40C91F0C3CF7763E4062838593343D4D40C91F0C3CF7763E4073F1B73D413C4D40419C871398723E4073F1B73D413C4D40
31968	Городня	3	31	952	30.223790999999999	30.237292	58.685119999999998	58.677171999999999	0103000020E610000001000000050000009E23F25D4A393E402AE27492AD564D409E23F25D4A393E40F2EA1C03B2574D40399A232BBF3C3E40F2EA1C03B2574D40399A232BBF3C3E402AE27492AD564D409E23F25D4A393E402AE27492AD564D40
32151	Воронино	3	31	952	30.593285999999999	30.600445000000001	58.569574000000003	58.560322999999997	0103000020E61000000100000005000000B62C5F97E1973E402A1900AAB8474D40B62C5F97E1973E40725303CDE7484D40F60B76C3B6993E40725303CDE7484D40F60B76C3B6993E402A1900AAB8474D40B62C5F97E1973E402A1900AAB8474D40
11516	Вольная Горка	3	31	952	30.837313000000002	30.852170999999998	58.725093000000001	58.713234	0103000020E6100000010000000500000002840F255AD63E40983270404B5B4D4002840F255AD63E407EC7F0D8CF5C4D408099EFE027DA3E407EC7F0D8CF5C4D408099EFE027DA3E40983270404B5B4D4002840F255AD63E40983270404B5B4D40
31839	Батецкий	3	31	952	30.284939000000001	30.323674	58.653477000000002	58.637438000000003	0103000020E61000000100000005000000DE5A26C3F1483E40249D819197514D40DE5A26C3F1483E4017D86322A5534D40C5909C4CDC523E4017D86322A5534D40C5909C4CDC523E40249D819197514D40DE5A26C3F1483E40249D819197514D40
4831	Щелино	3	60	\N	52.020980000000002	52.048630000000003	67.126001000000002	67.116680000000002	0103000020E610000001000000050000005FEFFE78AF024A403A0664AF77C750405FEFFE78AF024A40DA907F6610C8504060CD018239064A40DA907F6610C8504060CD018239064A403A0664AF77C750405FEFFE78AF024A403A0664AF77C75040
3864	Шойна	3	60	\N	44.139727999999998	44.169362999999997	67.882002	67.873462000000004	0103000020E61000000100000005000000F12A6B9BE21146401F1329CDE6F75040F12A6B9BE21146406C4084B872F850408313D1AFAD1546406C4084B872F850408313D1AFAD1546401F1329CDE6F75040F12A6B9BE21146401F1329CDE6F75040
3931	Чижа	3	60	\N	44.299295000000001	44.392575999999998	67.092044000000001	67.064446000000004	0103000020E610000001000000050000009C6D6E4C4F264640EA961DE21FC450409C6D6E4C4F264640C172840CE4C55040E5982CEE3F324640C172840CE4C55040E5982CEE3F324640EA961DE21FC450409C6D6E4C4F264640EA961DE21FC45040
5588	Хорей-Вер	3	60	\N	58.041013	58.05491	67.427234999999996	67.415002000000001	0103000020E61000000100000005000000FDDAFAE93F054D4093718C648FDA5040FDDAFAE93F054D40382D78D157DB5040971C774A07074D40382D78D157DB5040971C774A07074D4093718C648FDA5040FDDAFAE93F054D4093718C648FDA5040
5009	Хонгурей	3	60	\N	51.944291	51.960937000000001	67.56071	67.554586	0103000020E610000001000000050000001D740987DEF84940723447567EE350401D740987DEF84940922232ACE2E350401842CEFBFFFA4940922232ACE2E350401842CEFBFFFA4940723447567EE350401D740987DEF84940723447567EE35040
5700	Усть-Кара	3	60	\N	64.907545999999996	64.946425000000005	69.255934999999994	69.232437000000004	0103000020E610000001000000050000006667D13B153A50405858703FE04E51406667D13B153A5040B6B9313D615051407AC7293A923C5040B6B9313D615051407AC7293A923C50405858703FE04E51406667D13B153A50405858703FE04E5140
4774	Тошвиска	3	60	\N	52.292091999999997	52.305979000000001	67.125487000000007	67.117256999999995	0103000020E610000001000000050000002CB6494563254A40880E812381C750402CB6494563254A40AF44A0FA07C85040A321E3512A274A40AF44A0FA07C85040A321E3512A274A40880E812381C750402CB6494563254A40880E812381C75040
5135	Тельвиска	3	60	\N	52.874504999999999	52.906520999999998	67.637540000000001	67.629828000000003	0103000020E610000001000000050000002098A3C7EF6F4A40BA86191A4FE850402098A3C7EF6F4A4014799274CDE85040901150E108744A4014799274CDE85040901150E108744A40BA86191A4FE850402098A3C7EF6F4A40BA86191A4FE85040
4252	Снопа	3	60	\N	47.010069999999999	47.024585999999999	66.747114999999994	66.737967999999995	0103000020E61000000100000005000000DA5548F949814740A65F22DE3AAF5040DA5548F94981474077D66EBBD0AF504040F850A22583474077D66EBBD0AF504040F850A225834740A65F22DE3AAF5040DA5548F949814740A65F22DE3AAF5040
4941	Пылемец	3	60	\N	52.250796000000001	52.266506999999997	67.413521000000003	67.407990999999996	0103000020E61000000100000005000000DBFB54151A204A40FD8348861CDA5040DBFB54151A204A4064CDC82077DA5040D993C0E61C224A4064CDC82077DA5040D993C0E61C224A40FD8348861CDA5040DBFB54151A204A40FD8348861CDA5040
4177	Ома	3	60	\N	46.479047999999999	46.511927	66.651437000000001	66.635981999999998	0103000020E610000001000000050000006B9BE271513D47400FB6D8EDB3A850406B9BE271513D4740E199D024B1A950403E78EDD286414740E199D024B1A950403E78EDD2864147400FB6D8EDB3A850406B9BE271513D47400FB6D8EDB3A85040
5081	Оксино	3	60	\N	52.173378999999997	52.197589000000001	67.592205000000007	67.579398999999995	0103000020E610000001000000050000001668774831164A4072158BDF14E550401668774831164A40C6E1CCAFE6E550405186AA984A194A40C6E1CCAFE6E550405186AA984A194A4072158BDF14E550401668774831164A4072158BDF14E55040
4259	Нижняя Пеша	3	60	\N	47.749122	47.789178	66.758888999999996	66.746252999999996	0103000020E61000000100000005000000685BCD3AE3DF4740AE62F19BC2AF5040685BCD3AE3DF4740D3122BA391B05040815CE2C803E54740D3122BA391B05040815CE2C803E54740AE62F19BC2AF5040685BCD3AE3DF4740AE62F19BC2AF5040
4021	Несь	3	60	\N	44.661011000000002	44.695397999999997	66.609617	66.595421999999999	0103000020E61000000100000005000000ECA529029C5446406954E0641BA65040ECA529029C5446407B8505F703A7504016DA39CD025946407B8505F703A7504016DA39CD025946406954E0641BA65040ECA529029C5446406954E0641BA65040
5344	Нельмин Нос	3	60	\N	52.949182	52.971640000000001	67.986136999999999	67.978245000000001	0103000020E61000000100000005000000D7F9B7CB7E794A406F9EEA909BFE5040D7F9B7CB7E794A4009185DDE1CFF504023BE13B35E7C4A4009185DDE1CFF504023BE13B35E7C4A406F9EEA909BFE5040D7F9B7CB7E794A406F9EEA909BFE5040
5949	Нарьян-Мар	3	60	\N	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
49588	Макарово	3	60	\N	52.866708000000003	52.892184	67.687916999999999	67.681647999999996	0103000020E610000001000000050000003E97A949F06E4A4090D8EE1EA0EB50403E97A949F06E4A40325706D506EC5040DA01D71533724A40325706D506EC5040DA01D71533724A4090D8EE1EA0EB50403E97A949F06E4A4090D8EE1EA0EB5040
4865	Лабожское	3	60	\N	52.085461000000002	52.099062000000004	67.333800999999994	67.328190000000006	0103000020E61000000100000005000000AF0AD462F00A4A40F437A11001D55040AF0AD462F00A4A40D097DEFE5CD5504060234910AE0C4A40D097DEFE5CD5504060234910AE0C4A40F437A11001D55040AF0AD462F00A4A40F437A11001D55040
5264	Куя	3	60	\N	53.259307999999997	53.275359999999999	67.773987000000005	67.76867	0103000020E61000000100000005000000ABCB290131A14A40A5DAA7E331F15040ABCB290131A14A40DE21C50089F15040335019FF3EA34A40DE21C50089F15040335019FF3EA34A40A5DAA7E331F15040ABCB290131A14A40A5DAA7E331F15040
45357	Красное	3	60	\N	53.587130000000002	53.616576999999999	67.839251000000004	67.830627000000007	0103000020E6100000010000000500000010406A1327CB4A402D0B26FE28F5504010406A1327CB4A40A988D349B6F550409F3BC1FEEBCE4A40A988D349B6F550409F3BC1FEEBCE4A402D0B26FE28F5504010406A1327CB4A402D0B26FE28F55040
4660	Коткино	3	60	\N	51.126986000000002	51.145823	67.035668999999999	67.027784999999994	0103000020E610000001000000050000006286C613419049407094BC3AC7C150406286C61341904940C91EA16648C250409700FC53AA924940C91EA16648C250409700FC53AA9249407094BC3AC7C150406286C613419049407094BC3AC7C15040
49257	Кия	3	60	\N	44.08343	44.108286999999997	67.659439000000006	67.651446000000007	0103000020E61000000100000005000000ADC090D5AD0A46400B47904AB1E95040ADC090D5AD0A46403FADA23F34EA50407DCA3159DC0D46403FADA23F34EA50407DCA3159DC0D46400B47904AB1E95040ADC090D5AD0A46400B47904AB1E95040
5508	Каратайка	3	60	\N	61.393740999999999	61.429485	68.766863999999998	68.756793000000002	0103000020E61000000100000005000000130CE71A66B24E40DF35E84B6F305140130CE71A66B24E40B41EBE4C14315140B08F4E5DF9B64E40B41EBE4C14315140B08F4E5DF9B64E40DF35E84B6F305140130CE71A66B24E40DF35E84B6F305140
49533	Каменка	3	60	\N	51.875039999999998	51.888388999999997	67.491349	67.482607000000002	0103000020E610000001000000050000008E588B4F01F0494086747808E3DE50408E588B4F01F04940077B134372DF5040259012BBB6F14940077B134372DF5040259012BBB6F1494086747808E3DE50408E588B4F01F0494086747808E3DE5040
3080	Искателей	3	60	\N	53.082250000000002	53.170383000000001	67.684666000000007	67.664203000000001	0103000020E610000001000000050000004A0C022B878A4A40EDB94C4D82EA50404A0C022B878A4A40B9AB5791D1EB5040AE65321CCF954A40B9AB5791D1EB5040AE65321CCF954A40EDB94C4D82EA50404A0C022B878A4A40EDB94C4D82EA5040
4560	Индига	3	60	\N	48.678078999999997	48.688023999999999	67.691890000000001	67.68777	0103000020E610000001000000050000005C8DEC4ACB564840E04A766C04EC50405C8DEC4ACB5648407C9BFEEC47EC50407A6EA12B115848407C9BFEEC47EC50407A6EA12B11584840E04A766C04EC50405C8DEC4ACB564840E04A766C04EC5040
4641	Выучейский	3	60	\N	49.046874000000003	49.067067999999999	67.572062000000003	67.566146000000003	0103000020E6100000010000000500000030849CF7FF854840B8B06EBC3BE4504030849CF7FF8548403352EFA99CE45040D74D29AF958848403352EFA99CE45040D74D29AF95884840B8B06EBC3BE4504030849CF7FF854840B8B06EBC3BE45040
49385	Волонга	3	60	\N	47.766280000000002	47.788307000000003	67.133280999999997	67.126581000000002	0103000020E6100000010000000500000019CA897615E24740E1D231E719C8504019CA897615E24740670B08AD87C850409C1A683EE7E44740670B08AD87C850409C1A683EE7E44740E1D231E719C8504019CA897615E24740E1D231E719C85040
49357	Волоковая	3	60	\N	48.230744999999999	48.252690999999999	66.488985	66.478931000000003	0103000020E61000000100000005000000965B5A0D891D4840998235CEA69E5040965B5A0D891D484003CFBD874B9F50402C7FBE2D5820484003CFBD874B9F50402C7FBE2D58204840998235CEA69E5040965B5A0D891D4840998235CEA69E5040
4121	Вижас	3	60	\N	45.879306	45.909911999999998	66.645306000000005	66.639201999999997	0103000020E610000001000000050000009A9658198DF046406B6281AFE8A850409A9658198DF04640687A89B14CA95040751E15FF77F44640687A89B14CA95040751E15FF77F446406B6281AFE8A850409A9658198DF046406B6281AFE8A85040
4333	Верхняя Пеша	3	60	\N	47.944451999999998	47.973737	66.612059000000002	66.605557000000005	0103000020E6100000010000000500000026529ACDE3F847404AB72572C1A6504026529ACDE3F847403D0E83F92BA75040DCF3FC69A3FC47403D0E83F92BA75040DCF3FC69A3FC47404AB72572C1A6504026529ACDE3F847404AB72572C1A65040
4737	Великовисочное	3	60	\N	52.015321	52.050499000000002	67.261358000000001	67.251444000000006	0103000020E6100000010000000500000094F8DC09F6014A40A13193A817D0504094F8DC09F6014A4012A3E716BAD0504088BD50C076064A4012A3E716BAD0504088BD50C076064A40A13193A817D0504094F8DC09F6014A40A13193A817D05040
54901	Бугрино	3	60	\N	43.266871000000002	65.672865999999999	69.865477999999996	65.820004999999995	0103000020E610000001000000050000001BA034D428A245409D6340F67A7450401BA034D428A24540145AD6FD63775140C8258E3C106B5040145AD6FD63775140C8258E3C106B50409D6340F67A7450401BA034D428A245409D6340F67A745040
4442	Белушье	3	60	\N	47.593094000000001	47.621732000000002	66.900527999999994	66.886319999999998	0103000020E6100000010000000500000017BA1281EACB47409B728577B9B8504017BA1281EACB474077483140A2B95040377007EA94CF474077483140A2B95040377007EA94CF47409B728577B9B8504017BA1281EACB47409B728577B9B85040
5423	Андег	3	60	\N	53.207276999999998	53.228262000000001	67.895258999999996	67.883792999999997	0103000020E61000000100000005000000431B800D889A4A40C2DB831090F85040431B800D889A4A40C79C67EC4BF95040B47570B0379D4A40C79C67EC4BF95040B47570B0379D4A40C2DB831090F85040431B800D889A4A40C2DB831090F85040
54900	Амдерма	3	60	\N	61.647433999999997	61.700327000000001	69.765541999999996	69.752060999999998	0103000020E61000000100000005000000C328081EDFD24E4036E675C421705140C328081EDFD24E40B96DDFA3FE705140BEC0AC50A4D94E40B96DDFA3FE705140BEC0AC50A4D94E4036E675C421705140C328081EDFD24E4036E675C421705140
35594	Харута	3	60	3735	59.511088000000001	59.546166999999997	66.843356999999997	66.837461000000005	0103000020E6100000010000000500000064B0E2546BC14D403BAB05F698B5504064B0E2546BC14D409276A38FF9B55040C493DDCCE8C54D409276A38FF9B55040C493DDCCE8C54D403BAB05F698B5504064B0E2546BC14D403BAB05F698B55040
53309	ж-д ст. Лопарская	3	30	\N	28.417090000000002	41.406135999999996	69.953256999999994	66.054203999999999	0103000020E61000000100000005000000187D0569C66A3C40FED30D1478835040187D0569C66A3C40B7EBA529027D514037DDB243FCB34440B7EBA529027D514037DDB243FCB34440FED30D1478835040187D0569C66A3C40FED30D1478835040
1028	Снежногорск	3	30	\N	33.220148000000002	33.263106000000001	69.202822999999995	69.185440999999997	0103000020E61000000100000005000000D12346CF2D9C40409A95ED43DE4B5140D12346CF2D9C40401AF8510DFB4C5140D1B01875ADA140401AF8510DFB4C5140D1B01875ADA140409A95ED43DE4B5140D12346CF2D9C40409A95ED43DE4B5140
358	Североморск	3	30	\N	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
53417	Поселок Африканда-1	3	30	\N	28.417090000000002	41.406135999999996	69.953256999999994	66.054203999999999	0103000020E61000000100000005000000187D0569C66A3C40FED30D1478835040187D0569C66A3C40B7EBA529027D514037DDB243FCB34440B7EBA529027D514037DDB243FCB34440FED30D1478835040187D0569C66A3C40FED30D1478835040
30878	Полярный	3	30	\N	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
53412	Оленья Губа	3	30	\N	33.269376000000001	33.319367	69.220313000000004	69.210448	0103000020E61000000100000005000000E529ABE97AA240408D60E3FA774D5140E529ABE97AA240408E78B29B194E5140F8359204E1A840408E78B29B194E5140F8359204E1A840408D60E3FA774D5140E529ABE97AA240408D60E3FA774D5140
3431	Оленегорск	3	30	\N	33.221729000000003	33.326751000000002	68.152384999999995	68.123631000000003	0103000020E6100000010000000500000093C9A99D619C40406571FF91E907514093C9A99D619C4040A9D903ADC0095140B8770DFAD2A94040A9D903ADC0095140B8770DFAD2A940406571FF91E907514093C9A99D619C40406571FF91E9075140
2533	Мурманск	3	30	\N	32.933019999999999	33.222610000000003	69.043582999999998	68.882762999999997	0103000020E61000000100000005000000C84109336D7740409BC761307F385140C84109336D77404057EA5910CA4251409CE1067C7E9C404057EA5910CA4251409CE1067C7E9C40409BC761307F385140C84109336D7740409BC761307F385140
3240	Мончегорск	3	30	\N	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
1613	Кола	3	30	\N	32.991123000000002	33.068503999999997	68.896376000000004	68.874173999999996	0103000020E610000001000000050000001EA8531EDD7E4040DD408177F23751401EA8531EDD7E4040D63A71395E39514095D233BDC4884040D63A71395E39514095D233BDC4884040DD408177F23751401EA8531EDD7E4040DD408177F2375140
53399	Коашва	3	30	\N	34.032980000000002	34.043832000000002	67.64922	67.643810000000002	0103000020E6100000010000000500000007B64AB0380441409EB5DB2E34E9504007B64AB0380441402FFA0AD28CE95040574277499C0541402FFA0AD28CE95040574277499C0541409EB5DB2E34E9504007B64AB0380441409EB5DB2E34E95040
45752	Кировск	3	30	\N	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
2080	Кандалакша	3	30	\N	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
40322	Город Мончегорск	3	30	\N	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
621	Гаджиево	3	30	\N	33.291528	33.370669999999997	69.267718000000002	69.244327999999996	0103000020E6100000010000000500000024EF1CCA50A54040D05FE811A34F514024EF1CCA50A540403CA3AD4A22515140DDCD531D72AF40403CA3AD4A22515140DDCD531D72AF4040D05FE811A34F514024EF1CCA50A54040D05FE811A34F5140
47582	Белокаменка	3	30	\N	33.156305000000003	33.186425999999997	69.086912999999996	69.075626	0103000020E61000000100000005000000C4995FCD019440408C2E6F0ED7445140C4995FCD0194404039268BFB8F455140E28FA2CEDC97404039268BFB8F455140E28FA2CEDC9740408C2E6F0ED7445140C4995FCD019440408C2E6F0ED7445140
2005	Апатиты	3	30	\N	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
53395	Умба	3	30	314	34.313039000000003	34.359302	66.705099000000004	66.668127999999996	0103000020E61000000100000005000000B0AF75A911284140AE62F19BC2AA5040B0AF75A9112841404F5C8E5720AD504096B1A19BFD2D41404F5C8E5720AD504096B1A19BFD2D4140AE62F19BC2AA5040B0AF75A911284140AE62F19BC2AA5040
53301	Умба	3	30	314	34.313039000000003	34.359302	66.705099000000004	66.668127999999996	0103000020E61000000100000005000000B0AF75A911284140AE62F19BC2AA5040B0AF75A9112841404F5C8E5720AD504096B1A19BFD2D41404F5C8E5720AD504096B1A19BFD2D4140AE62F19BC2AA5040B0AF75A911284140AE62F19BC2AA5040
1480	Варзуга	3	30	314	36.580333000000003	36.60492	66.404568999999995	66.393288999999996	0103000020E6100000010000000500000011E50B5A484A42401938A0A52B99504011E50B5A484A42406DFE5F75E49950402159C0046E4D42406DFE5F75E49950402159C0046E4D42401938A0A52B99504011E50B5A484A42401938A0A52B995040
247	Щукозеро	3	30	53	33.615704000000001	33.642797000000002	69.043566999999996	69.027405999999999	0103000020E6100000010000000500000019028063CFCE4040B56D1805C141514019028063CFCE4040D40B3ECDC9425140C47B0E2C47D24040D40B3ECDC9425140C47B0E2C47D24040B56D1805C141514019028063CFCE4040B56D1805C1415140
32341	Сафоново	3	30	53	33.271658000000002	33.308534000000002	69.071696000000003	69.024180999999999	0103000020E6100000010000000500000030D978B0C5A24040D00B772E8C41514030D978B0C5A2404042D0D1AA964451401FDAC70A7EA7404042D0D1AA964451401FDAC70A7EA74040D00B772E8C41514030D978B0C5A24040D00B772E8C415140
63	Росляково	3	30	53	33.186613999999999	33.244788999999997	69.060507000000001	69.037231000000006	0103000020E61000000100000005000000E57CB1F7E29740406FD921FE61425140E57CB1F7E2974040768BC058DF435140D4B5F63E559F4040768BC058DF435140D4B5F63E559F40406FD921FE61425140E57CB1F7E29740406FD921FE61425140
26381	Никель	3	30	435	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
30795	Корзуново	3	30	435	30.989218000000001	31.029444999999999	69.410392000000002	69.389201	0103000020E61000000100000005000000529D0E643DFD3E4083A44FABE8585140529D0E643DFD3E4090A2CEDC435A5140DD0720B589073F4090A2CEDC435A5140DD0720B589073F4083A44FABE8585140529D0E643DFD3E4083A44FABE8585140
2388	Заполярный	3	30	435	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
3611	Высокий	3	30	573	33.389381999999998	33.440882000000002	68.149480999999994	68.127476999999999	0103000020E6100000010000000500000056D3F544D7B14040807F4A952808514056D3F544D7B14040E597C1189109514092B245D26EB84040E597C1189109514092B245D26EB84040807F4A952808514056D3F544D7B14040807F4A9528085140
53382	27 километр	3	30	573	32.931789000000002	32.97383	67.978720999999993	67.963845000000006	0103000020E61000000100000005000000E3E2A8DC44774040715AF0A2AFFD5040E3E2A8DC4477404023BA675DA3FE50408DEE2076A67C404023BA675DA3FE50408DEE2076A67C4040715AF0A2AFFD5040E3E2A8DC44774040715AF0A2AFFD5040
53387	25 километр	3	30	573	32.975743999999999	33.006321999999997	67.988954000000007	67.972098000000003	0103000020E6100000010000000500000055A2EC2DE57C404073A087DA36FE504055A2EC2DE57C4040E6CFB7054BFF5040669FC728CF804040E6CFB7054BFF5040669FC728CF80404073A087DA36FE504055A2EC2DE57C404073A087DA36FE5040
45970	Ревда	3	30	524	34.529488000000001	34.573397	67.956282999999999	67.935768999999993	0103000020E61000000100000005000000EECF4543C643414014E7A8A3E3FB5040EECF4543C643414021AE9CBD33FD5040F04FA9126549414021AE9CBD33FD5040F04FA9126549414014E7A8A3E3FB5040EECF4543C643414014E7A8A3E3FB5040
27552	Ловозеро	3	30	524	35.002513999999998	35.032167000000001	68.012366999999998	67.996994000000001	0103000020E610000001000000050000001DE4F56052804140BA13ECBFCEFF50401DE4F560528041402D23F59ECA00514056815A0C1E8441402D23F59ECA00514056815A0C1E844140BA13ECBFCEFF50401DE4F56052804140BA13ECBFCEFF5040
53300	п.г.т. Туманный	3	30	408	28.433969000000001	36.187094999999999	69.588654000000005	67.669399999999996	0103000020E61000000100000005000000537AA697186F3C4050FC1873D7EA5040537AA697186F3C4037AAD381AC655140601F9DBAF217424037AAD381AC655140601F9DBAF217424050FC1873D7EA5040537AA697186F3C4050FC1873D7EA5040
53407	Шонгуй	3	30	408	33.120452999999998	33.173741	68.768891999999994	68.738750999999993	0103000020E6100000010000000500000040DAFF006B8F4040C93846B2472F514040DAFF006B8F4040FC89CA8635315140B77C24253D964040FC89CA8635315140B77C24253D964040C93846B2472F514040DAFF006B8F4040C93846B2472F5140
27144	Ура-Губа	3	30	408	32.779471000000001	32.820407000000003	69.295962000000003	69.279971000000003	0103000020E610000001000000050000001897AAB4C563404005357C0BEB5151401897AAB4C5634040F6B6990AF15251406A34B91803694040F6B6990AF15251406A34B9180369404005357C0BEB5151401897AAB4C563404005357C0BEB515140
2175	Тулома	3	30	408	32.673074	32.700814000000001	68.821550000000002	68.814549	0103000020E61000000100000005000000DAE4F0492756404054FF209221345140DAE4F04927564040D8817346943451401B4AED45B4594040D8817346943451401B4AED45B459404054FF209221345140DAE4F0492756404054FF209221345140
53393	Североморск 2I	3	30	408	33.719127	33.740237	68.894356000000002	68.861344000000003	0103000020E61000000100000005000000D655815A0CDC4040C6A6954220375140D655815A0CDC4040CFBEF2203D39514003250516C0DE4040CFBEF2203D39514003250516C0DE4040C6A6954220375140D655815A0CDC4040C6A6954220375140
53302	Пушной	3	30	408	33.306279000000004	33.346389000000002	68.483957000000004	68.454153000000005	0103000020E61000000100000005000000CE39782634A740405798BED7101D5140CE39782634A74040E6EAC726F91E5140DA58897956AC4040E6EAC726F91E5140DA58897956AC40405798BED7101D5140CE39782634A740405798BED7101D5140
53371	Песчаный	3	30	408	33.187314999999998	33.280802999999999	68.499566000000002	68.466648000000006	0103000020E610000001000000050000006E861BF0F99740409BAF928FDD1D51406E861BF0F9974040630CACE3F81F514031CF4A5AF1A34040630CACE3F81F514031CF4A5AF1A340409BAF928FDD1D51406E861BF0F99740409BAF928FDD1D5140
25966	Мурмаши	3	30	408	32.747787000000002	32.840035	68.832254000000006	68.802324999999996	0103000020E61000000100000005000000DEAF027CB75F4040D8F0F44A59335140DEAF027CB75F4040C6FD47A643355140683F5244866B4040C6FD47A643355140683F5244866B4040D8F0F44A59335140DEAF027CB75F4040D8F0F44A59335140
26225	Молочный	3	30	408	33.009709000000001	33.024611999999998	68.858406000000002	68.851056999999997	0103000020E610000001000000050000000ABDFE243E8140400A82C7B7773651400ABDFE243E8140402C2CB81FF0365140698B6B7C268340402C2CB81FF0365140698B6B7C268340400A82C7B7773651400ABDFE243E8140400A82C7B777365140
53380	Мишуково	3	30	408	33.016303000000001	33.042354000000003	69.046664000000007	69.040032999999994	0103000020E61000000100000005000000D1E9793716824040B07092E68F425140D1E9793716824040A379008BFC4251406A6D1ADB6B854040A379008BFC4251406A6D1ADB6B854040B07092E68F425140D1E9793716824040B07092E68F425140
26902	Минькино	3	30	408	33.012763	33.028241000000001	68.993955	68.979792000000003	0103000020E61000000100000005000000A7CCCD37A28140407A3881E9B43E5140A7CCCD37A281404086AC6EF59C3F514003B4AD669D83404086AC6EF59C3F514003B4AD669D8340407A3881E9B43E5140A7CCCD37A28140407A3881E9B43E5140
26955	Междуречье	3	30	408	32.906115	32.959215	69.044313000000002	69.028191000000007	0103000020E6100000010000000500000020B58993FB734040A9C29FE1CD41514020B58993FB73404069723106D6425140946A9F8EC77A404069723106D6425140946A9F8EC77A4040A9C29FE1CD41514020B58993FB734040A9C29FE1CD415140
53406	Магнетиты	3	30	408	33.117578999999999	33.134780999999997	68.688569999999999	68.678168999999997	0103000020E6100000010000000500000023D923D40C8F40404E0AF31E672B514023D923D40C8F40406EC0E787112C5140A38FF980409140406EC0E787112C5140A38FF980409140404E0AF31E672B514023D923D40C8F40404E0AF31E672B5140
53414	Кола	3	30	408	33.024602999999999	33.288366000000003	68.88297	68.332234999999997	0103000020E610000001000000050000001631EC30268340408AE59656431551401631EC302683404058569A9482385140A1A3552DE9A4404058569A9482385140A1A3552DE9A440408AE59656431551401631EC30268340408AE5965643155140
53409	Кильдинстрой	3	30	408	33.090935000000002	33.133676999999999	68.825912000000002	68.799567999999994	0103000020E61000000100000005000000E88711C2A38B404066BB421F2C335140E88711C2A38B4040EF5701BEDB3451401B9DF3531C914040EF5701BEDB3451401B9DF3531C91404066BB421F2C335140E88711C2A38B404066BB421F2C335140
53310	Килпъявр	3	30	408	32.406320000000001	32.435084000000003	69.100712000000001	69.084978000000007	0103000020E61000000100000005000000F9DA334B023440404AB8904770455140F9DA334B023440402594BE1072465140A6811FD5B03740402594BE1072465140A6811FD5B03740404AB8904770455140F9DA334B023440404AB8904770455140
53411	Зверосовхоз	3	30	408	33.075232	33.195481000000001	68.862249000000006	68.833817999999994	0103000020E610000001000000050000006CCEC133A18940403B342C465D3551406CCEC133A18940408F006E162F375140A4FE7A85059940408F006E162F375140A4FE7A85059940403B342C465D3551406CCEC133A18940403B342C465D355140
22939	Заозерск	3	30	408	32.422265000000003	32.468626999999998	69.435854000000006	69.383370999999997	0103000020E610000001000000050000006B9F8EC70C36404007CF8426895851406B9F8EC70C3640402CF52C08E55B5140E48233F8FB3B40402CF52C08E55B5140E48233F8FB3B404007CF8426895851406B9F8EC70C36404007CF842689585140
53416	Видяево	3	30	408	32.789738999999997	32.835318999999998	69.333262000000005	69.316753000000006	0103000020E6100000010000000500000018B0E42A166540403CFA5FAE4554514018B0E42A16654040F9BF232A545551401C5DA5BBEB6A4040F9BF232A545551401C5DA5BBEB6A40403CFA5FAE4554514018B0E42A166540403CFA5FAE45545140
53386	Верхнетуломский	3	30	408	31.781172999999999	31.852409000000002	68.613217000000006	68.601177000000007	0103000020E61000000100000005000000A98427F4FAC73F40E08618AF79265140A98427F4FAC73F407B1684F23E275140EAD0E97937DA3F407B1684F23E275140EAD0E97937DA3F40E08618AF79265140A98427F4FAC73F40E08618AF79265140
3071	Риколатва	3	30	491	31.296631000000001	31.337323999999999	67.500647999999998	67.490787999999995	0103000020E61000000100000005000000D3FA5B02F04B3F403B51121269DF5040D3FA5B02F04B3F40B3B3E89D0AE05040E9279CDD5A563F40B3B3E89D0AE05040E9279CDD5A563F403B51121269DF5040D3FA5B02F04B3F403B51121269DF5040
25522	Куропта	3	30	491	30.828150000000001	30.845452000000002	67.491748000000001	67.478836000000001	0103000020E61000000100000005000000B22E6EA301D43E407009C03FA5DE5040B22E6EA301D43E40E6779ACC78DF50407A56D28A6FD83E40E6779ACC78DF50407A56D28A6FD83E407009C03FA5DE5040B22E6EA301D43E407009C03FA5DE5040
2984	Ковдор	3	30	491	30.426029	30.534482000000001	67.583547999999993	67.541403000000003	0103000020E61000000100000005000000C8258E3C106D3E4034BDC458A6E25040C8258E3C106D3E405BE9B5D958E55040F94CF6CFD3883E405BE9B5D958E55040F94CF6CFD3883E4034BDC458A6E25040C8258E3C106D3E4034BDC458A6E25040
25625	Енский	3	30	491	31.126517	31.171828000000001	67.591457000000005	67.575491999999997	0103000020E610000001000000050000005663096B63203F4004C765DCD4E450405663096B63203F4061FF756EDAE550407F8978EBFC2B3F4061FF756EDAE550407F8978EBFC2B3F4004C765DCD4E450405663096B63203F4004C765DCD4E45040
25596	Ена	3	30	491	31.148489999999999	31.162134999999999	67.608853999999994	67.605441999999996	0103000020E6100000010000000500000075C8CD7003263F40FD67CD8FBFE6504075C8CD7003263F407B82C476F7E650407689EAAD81293F407B82C476F7E650407689EAAD81293F40FD67CD8FBFE6504075C8CD7003263F40FD67CD8FBFE65040
1902	Титан	3	30	370	33.622432000000003	33.647917	67.569794000000002	67.554686000000004	0103000020E61000000100000005000000F0FD0DDAABCF40402463B5F97FE35040F0FD0DDAABCF404040DD408177E45040DFC2BAF1EED2404040DD408177E45040DFC2BAF1EED240402463B5F97FE35040F0FD0DDAABCF40402463B5F97FE35040
53398	Кандалакша	3	30	7286	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
53383	Кандалакша	3	30	7279	29.033891000000001	33.324928	67.673147	66.344375999999997	0103000020E61000000100000005000000F5A0A014AD083D40BF61A2410A965040F5A0A014AD083D40A29927D714EB504000C79E3D97A94040A29927D714EB504000C79E3D97A94040BF61A2410A965040F5A0A014AD083D40BF61A2410A965040
53372	Зеленоборский	3	30	7279	32.350183999999999	32.406112999999998	66.867857999999998	66.840834999999998	0103000020E610000001000000050000008ECA4DD4D22C404042959A3DD0B550408ECA4DD4D22C40409BE447FC8AB750407FBDC282FB3340409BE447FC8AB750407FBDC282FB33404042959A3DD0B550408ECA4DD4D22C404042959A3DD0B55040
53374	Зареченск	3	30	7279	31.416349	31.448077999999999	66.685592	66.676714000000004	0103000020E61000000100000005000000E9B81AD9956A3F40B4AF3C484FAB5040E9B81AD9956A3F408D9944BDE0AB50409D0E643DB5723F408D9944BDE0AB50409D0E643DB5723F40B4AF3C484FAB5040E9B81AD9956A3F40B4AF3C484FAB5040
53377	Нивский	3	30	1741	32.466453000000001	32.496996000000003	67.302785	67.294272000000007	0103000020E61000000100000005000000800F5EBBB43B40403A083A5AD5D25040800F5EBBB43B40400A2E56D460D35040151F9F909D3F40400A2E56D460D35040151F9F909D3F40403A083A5AD5D25040800F5EBBB43B40403A083A5AD5D25040
24107	Лувеньга	3	30	1741	32.697687999999999	32.718088999999999	67.107153999999994	67.099936	0103000020E61000000100000005000000E46723D74D5940405BECF65965C65040E46723D74D594040AD68739CDBC65040054F2157EA5B4040AD68739CDBC65040054F2157EA5B40405BECF65965C65040E46723D74D5940405BECF65965C65040
24378	Ковдозеро	3	30	1741	31.552227999999999	31.574003999999999	66.765928000000002	66.756788	0103000020E610000001000000050000007CEF6FD05E8D3F405680EF366FB050407CEF6FD05E8D3F40CEC5DFF604B15040EFC517EDF1923F40CEC5DFF604B15040EFC517EDF1923F405680EF366FB050407CEF6FD05E8D3F405680EF366FB05040
53394	Зеленоборский	3	30	1741	32.350183999999999	32.406112999999998	66.867857999999998	66.840834999999998	0103000020E610000001000000050000008ECA4DD4D22C404042959A3DD0B550408ECA4DD4D22C40409BE447FC8AB750407FBDC282FB3340409BE447FC8AB750407FBDC282FB33404042959A3DD0B550408ECA4DD4D22C404042959A3DD0B55040
53384	Алакуртти	3	30	1741	30.315930999999999	30.397390000000001	66.973568	66.956495000000004	0103000020E61000000100000005000000E6CAA0DAE0503E4067F2CD3637BD5040E6CAA0DAE0503E40A81B28F04EBE5040E8C1DD59BB653E40A81B28F04EBE5040E8C1DD59BB653E4067F2CD3637BD5040E6CAA0DAE0503E4067F2CD3637BD5040
31224	Полярные Зори	3	30	1913	32.452188	32.514468000000001	67.469830999999999	67.362525000000005	0103000020E6100000010000000500000063D2DF4BE1394040E0BE0E9C33D7504063D2DF4BE139404068E90AB611DE5040556B6116DA41404068E90AB611DE5040556B6116DA414040E0BE0E9C33D7504063D2DF4BE1394040E0BE0E9C33D75040
40412	Зашеек	3	30	1913	32.526136999999999	32.567819	67.421463000000003	67.394047999999998	0103000020E61000000100000005000000971B0C755843404078431A1538D95040971B0C7558434040575EF23FF9DA50401286014BAE484040575EF23FF9DA50401286014BAE48404078431A1538D95040971B0C755843404078431A1538D95040
31630	Африканда 2-я	3	30	1913	32.698065	32.717694000000002	67.432905000000005	67.428663	0103000020E61000000100000005000000BABDA4315A5940405680EF366FDB5040BABDA4315A59404098512CB7B4DB50408944A165DD5B404098512CB7B4DB50408944A165DD5B40405680EF366FDB5040BABDA4315A5940405680EF366FDB5040
59022	посекло Выра	3	29	\N	26.580233	35.967061999999999	61.330865000000003	58.417071999999997	0103000020E610000001000000050000005A0F5F268A943A40E509849D62354D405A0F5F268A943A400E32C9C859AA4E40289A07B0C8FB41400E32C9C859AA4E40289A07B0C8FB4140E509849D62354D405A0F5F268A943A40E509849D62354D40
59066	Тосно	3	29	\N	30.808567	30.921341999999999	59.573673999999997	59.518796999999999	0103000020E61000000100000005000000F59F353FFECE3E40A721AAF067C24D40F59F353FFECE3E4062484E266EC94D40656EBE11DDEB3E4062484E266EC94D40656EBE11DDEB3E40A721AAF067C24D40F59F353FFECE3E40A721AAF067C24D40
59047	Тихвин	3	29	\N	33.449731	33.602012999999999	59.681887000000003	59.598306000000001	0103000020E61000000100000005000000AA7F10C990B9404013807F4A95CC4D40AA7F10C990B94040A648BE1248D74D40286211C30ECD4040A648BE1248D74D40286211C30ECD404013807F4A95CC4D40AA7F10C990B9404013807F4A95CC4D40
58989	Сясьстрой	3	29	\N	32.489269999999998	32.601056	60.160046999999999	60.133983000000001	0103000020E61000000100000005000000FB743C66A03E4040289CDD5A26114E40FB743C66A03E404055698B6B7C144E4044882B67EF4C404055698B6B7C144E4044882B67EF4C4040289CDD5A26114E40FB743C66A03E4040289CDD5A26114E40
4047	Сосновый Бор	3	29	\N	28.997841999999999	29.155999000000001	59.936070000000001	59.816034000000002	0103000020E610000001000000050000004293C49272FF3C40483657CD73E84D404293C49272FF3C4024624A24D1F74D406E35EB8CEF273D4024624A24D1F74D406E35EB8CEF273D40483657CD73E84D404293C49272FF3C40483657CD73E84D40
59004	Сланцы	3	29	\N	28.051988000000001	28.221679999999999	59.131672000000002	59.076717000000002	0103000020E61000000100000005000000D2C8E7154F0D3C400C06D7DCD1894D40D2C8E7154F0D3C4043E6CAA0DA904D40622D3E05C0383C4043E6CAA0DA904D40622D3E05C0383C400C06D7DCD1894D40D2C8E7154F0D3C400C06D7DCD1894D40
59068	Сертолово	3	29	\N	30.142296000000002	30.235171999999999	60.167107000000001	60.123241	0103000020E61000000100000005000000045ABA826D243E405F43705CC60F4E40045ABA826D243E4062F71DC363154E4056EF703B343C3E4062F71DC363154E4056EF703B343C3E405F43705CC60F4E40045ABA826D243E405F43705CC60F4E40
58979	Селезнёво	3	29	\N	28.614989000000001	28.627044000000001	60.761164999999998	60.754862000000003	0103000020E6100000010000000500000056664AEB6F9D3C40207F69519F604E4056664AEB6F9D3C400FEECEDA6D614E402D27A1F485A03C400FEECEDA6D614E402D27A1F485A03C40207F69519F604E4056664AEB6F9D3C40207F69519F604E40
59015	Приозерск	3	29	\N	30.087031	30.18289	61.052970999999999	61.006320000000002	0103000020E61000000100000005000000F9BCE2A947163E40C6A70018CF804E40F9BCE2A947163E407651F4C0C7864E40F4C308E1D12E3E407651F4C0C7864E40F4C308E1D12E3E40C6A70018CF804E40F9BCE2A947163E40C6A70018CF804E40
59057	Подпорожье	3	29	\N	34.102375000000002	34.253228999999997	60.939051999999997	60.895935000000001	0103000020E61000000100000005000000C976BE9F1A0D4140BF2B82FFAD724E40C976BE9F1A0D4140279F1EDB32784E400BB3D0CE69204140279F1EDB32784E400BB3D0CE69204140BF2B82FFAD724E40C976BE9F1A0D4140BF2B82FFAD724E40
59051	Отрадное	3	29	\N	30.744553	30.850059999999999	59.798679	59.745992999999999	0103000020E61000000100000005000000812381069BBE3E40C005D9B27CDF4D40812381069BBE3E4041800C1D3BE64D4044A33B889DD93E4041800C1D3BE64D4044A33B889DD93E40C005D9B27CDF4D40812381069BBE3E40C005D9B27CDF4D40
59048	Никольское	3	29	\N	30.755134999999999	30.831133000000001	59.734560999999999	59.672724000000002	0103000020E61000000100000005000000A110018750C13E40FE9DEDD11BD64D40A110018750C13E4062F5471806DE4D405AA0DD21C5D43E4062F5471806DE4D405AA0DD21C5D43E40FE9DEDD11BD64D40A110018750C13E40FE9DEDD11BD64D40
58933	Луга	3	29	\N	29.711365000000001	29.918759000000001	58.804791000000002	58.675502000000002	0103000020E61000000100000005000000E08442041CB63D40F9307BD976564D40E08442041CB63D40BD8E386403674D40DAE731CA33EB3D40BD8E386403674D40DAE731CA33EB3D40F9307BD976564D40E08442041CB63D40F9307BD976564D40
359	Лодейное Поле	3	29	\N	33.470391999999997	33.610233000000001	60.745753000000001	60.708677999999999	0103000020E61000000100000005000000672618CE35BC404085B2F0F5B55A4E40672618CE35BC40406BF294D5745F4E4051F86C1D1CCE40406BF294D5745F4E4051F86C1D1CCE404085B2F0F5B55A4E40672618CE35BC404085B2F0F5B55A4E40
59067	Кировск	3	29	\N	30.944644	31.020883999999999	59.907626999999998	59.845179999999999	0103000020E61000000100000005000000D55C6E30D4F13E40DC9DB5DB2EEC4D40D55C6E30D4F13E40B9FB1C1F2DF44D40790261A758053F40B9FB1C1F2DF44D40790261A758053F40DC9DB5DB2EEC4D40D55C6E30D4F13E40DC9DB5DB2EEC4D40
59052	Кириши	3	29	\N	31.984031000000002	32.104422999999997	59.514085999999999	59.430062	0103000020E610000001000000050000000C40A374E9FB3F404DA088450CB74D400C40A374E9FB3F406DAAEE91CDC14D40A0F99CBB5D0D40406DAAEE91CDC14D40A0F99CBB5D0D40404DA088450CB74D400C40A374E9FB3F404DA088450CB74D40
59024	Каменногорск	3	29	\N	29.063590000000001	29.170552000000001	60.973126999999998	60.915000999999997	0103000020E61000000100000005000000475A2A6F47103D405567B5C01E754E40475A2A6F47103D4063EDEF6C8F7C4E407444BE4BA92B3D4063EDEF6C8F7C4E407444BE4BA92B3D405567B5C01E754E40475A2A6F47103D405567B5C01E754E40
59071	Ивангород	3	29	\N	28.191685	28.238218	59.387334000000003	59.341776000000003	0103000020E610000001000000050000003E22A64412313C406347E350BFAB4D403E22A64412313C407F50172994B14D408B51D7DAFB3C3C407F50172994B14D408B51D7DAFB3C3C406347E350BFAB4D403E22A64412313C406347E350BFAB4D40
59064	Гатчина	3	29	\N	30.043409	30.172084000000002	59.604889999999997	59.531725999999999	0103000020E61000000100000005000000215A2BDA1C0B3E406937FA980FC44D40215A2BDA1C0B3E40B6D617096DCD4D40352A70B20D2C3E40B6D617096DCD4D40352A70B20D2C3E406937FA980FC44D40215A2BDA1C0B3E406937FA980FC44D40
58966	Выборг	3	29	\N	28.579470000000001	28.913733000000001	60.811289000000002	60.653542000000002	0103000020E610000001000000050000005C035B2558943C40FE47A643A7534E405C035B2558943C40624D6551D8674E40A646E867EAE93C40624D6551D8674E40A646E867EAE93C40FE47A643A7534E405C035B2558943C40FE47A643A7534E40
59050	Всеволожск	3	29	\N	30.571421000000001	30.716660000000001	60.056686999999997	59.979154999999999	0103000020E61000000100000005000000643F8BA548923E40815B77F354FD4D40643F8BA548923E40DE8D058541074E40F3599E0777B73E40DE8D058541074E40F3599E0777B73E40815B77F354FD4D40643F8BA548923E40815B77F354FD4D40
59075	Волхов	3	29	\N	32.234625000000001	32.389772999999998	59.965218999999998	59.870094999999999	0103000020E6100000010000000500000079E92631081E4040E1B4E0455FEF4D4079E92631081E4040293DD34B8CFB4D4091EEE714E4314040293DD34B8CFB4D4091EEE714E4314040E1B4E0455FEF4D4079E92631081E4040E1B4E0455FEF4D40
59062	Бокситогорск	3	29	\N	33.800953999999997	33.885486	59.496482	59.450297999999997	0103000020E61000000100000005000000D9CC21A985E6404023BA675DA3B94D40D9CC21A985E64040BE86E0B88CBF4D406E88F19A57F14040BE86E0B88CBF4D406E88F19A57F1404023BA675DA3B94D40D9CC21A985E6404023BA675DA3B94D40
3512	ской посёлок Ульяновка	3	29	564	30.727961000000001	30.808720000000001	59.667935	59.613388999999998	0103000020E6100000010000000500000072C3EFA65BBA3E40F25CDF8783CE4D4072C3EFA65BBA3E40486DE2E47ED54D40029F1F4608CF3E40486DE2E47ED54D40029F1F4608CF3E40F25CDF8783CE4D4072C3EFA65BBA3E40F25CDF8783CE4D40
14227	ской посёлок Рябово	3	29	564	31.111927999999999	31.140080999999999	59.424577999999997	59.407578000000001	0103000020E61000000100000005000000B6813B50A71C3F40D84812842BB44D40B6813B50A71C3F40F04C689258B64D407DCA3159DC233F40F04C689258B64D407DCA3159DC233F40D84812842BB44D40B6813B50A71C3F40D84812842BB44D40
14945	Шапки	3	29	564	31.160805	31.217093999999999	59.610526	59.585976000000002	0103000020E61000000100000005000000850838842A293F40D61EF64201CB4D40850838842A293F40C9AD49B725CE4D406728EE7893373F40C9AD49B725CE4D406728EE7893373F40D61EF64201CB4D40850838842A293F40D61EF64201CB4D40
10993	Чудской Бор	3	29	564	31.409306000000001	31.426078	59.353732000000001	59.349319000000001	0103000020E610000001000000050000007C0E2C47C8683F408B6F287CB6AC4D407C0E2C47C8683F403BC6151747AD4D408B8BA372136D3F403BC6151747AD4D408B8BA372136D3F408B6F287CB6AC4D407C0E2C47C8683F408B6F287CB6AC4D40
11076	Фёдоровское	3	29	564	30.517136000000001	30.546168999999999	59.669407	59.653903	0103000020E6100000010000000500000092955F0663843E40CEE0EF17B3D34D4092955F0663843E40535BEA20AFD54D40CA1649BBD18B3E40535BEA20AFD54D40CA1649BBD18B3E40CEE0EF17B3D34D4092955F0663843E40CEE0EF17B3D34D40
50500	Форносово	3	29	564	30.535488000000001	30.560821000000001	59.582290999999998	59.556410999999997	0103000020E610000001000000050000008466D7BD15893E403C11C47938C74D408466D7BD15893E40A8E0F08288CA4D40F7E80DF7918F3E40A8E0F08288CA4D40F7E80DF7918F3E403C11C47938C74D408466D7BD15893E403C11C47938C74D40
13892	Ушаки	3	29	564	30.880962	30.924323999999999	59.522485000000003	59.509611999999997	0103000020E61000000100000005000000CD04C3B986E13E4017D34CF73AC14D40CD04C3B986E13E4046D3D9C9E0C24D406CE8667FA0EC3E4046D3D9C9E0C24D406CE8667FA0EC3E4017D34CF73AC14D40CD04C3B986E13E4017D34CF73AC14D40
59038	Ульяновка	3	29	564	30.727961000000001	30.808720000000001	59.667935	59.613388999999998	0103000020E6100000010000000500000072C3EFA65BBA3E40F25CDF8783CE4D4072C3EFA65BBA3E40486DE2E47ED54D40029F1F4608CF3E40486DE2E47ED54D40029F1F4608CF3E40F25CDF8783CE4D4072C3EFA65BBA3E40F25CDF8783CE4D40
58965	Ульяновка	3	29	564	30.727961000000001	30.808720000000001	59.667935	59.613388999999998	0103000020E6100000010000000500000072C3EFA65BBA3E40F25CDF8783CE4D4072C3EFA65BBA3E40486DE2E47ED54D40029F1F4608CF3E40486DE2E47ED54D40029F1F4608CF3E40F25CDF8783CE4D4072C3EFA65BBA3E40F25CDF8783CE4D40
10898	Трубников Бор	3	29	564	31.387073000000001	31.400431000000001	59.270769999999999	59.258932000000001	0103000020E61000000100000005000000242A543717633F40A6F10BAF24A14D40242A543717633F40745E6397A8A24D40F94D61A582663F40745E6397A8A24D40F94D61A582663F40A6F10BAF24A14D40242A543717633F40A6F10BAF24A14D40
13080	Тосно	3	29	564	30.808567	30.921341999999999	59.573673999999997	59.518796999999999	0103000020E61000000100000005000000F59F353FFECE3E40A721AAF067C24D40F59F353FFECE3E4062484E266EC94D40656EBE11DDEB3E4062484E266EC94D40656EBE11DDEB3E40A721AAF067C24D40F59F353FFECE3E40A721AAF067C24D40
11123	Тельмана	3	29	564	30.599287	30.640411	59.730978	59.706785000000004	0103000020E61000000100000005000000FFEA71DF6A993E40D5264EEE77DA4D40FFEA71DF6A993E40390CE6AF90DD4D40A8FFACF9F1A33E40390CE6AF90DD4D40A8FFACF9F1A33E40D5264EEE77DA4D40FFEA71DF6A993E40D5264EEE77DA4D40
14025	Тарасово	3	29	564	30.909610000000001	30.921333000000001	59.426839999999999	59.414282	0103000020E61000000100000005000000541D7233DCE83E4026A94C3107B54D40541D7233DCE83E40F44F70B1A2B64D40BFB9BF7ADCEB3E40F44F70B1A2B64D40BFB9BF7ADCEB3E4026A94C3107B54D40541D7233DCE83E4026A94C3107B54D40
58967	Сельцо	3	29	564	31.186299999999999	31.215952999999999	59.341349000000001	59.328282999999999	0103000020E61000000100000005000000AB3E575BB12F3F40986A662D05AA4D40AB3E575BB12F3F40DBC2F352B1AB4D401C7920B248373F40DBC2F352B1AB4D401C7920B248373F40986A662D05AA4D40AB3E575BB12F3F40986A662D05AA4D40
10802	Сельцо	3	29	564	31.186299999999999	31.215952999999999	59.341349000000001	59.328282999999999	0103000020E61000000100000005000000AB3E575BB12F3F40986A662D05AA4D40AB3E575BB12F3F40DBC2F352B1AB4D401C7920B248373F40DBC2F352B1AB4D401C7920B248373F40986A662D05AA4D40AB3E575BB12F3F40986A662D05AA4D40
58970	Рябово	3	29	564	31.111927999999999	31.140080999999999	59.424577999999997	59.407578000000001	0103000020E61000000100000005000000B6813B50A71C3F40D84812842BB44D40B6813B50A71C3F40F04C689258B64D407DCA3159DC233F40F04C689258B64D407DCA3159DC233F40D84812842BB44D40B6813B50A71C3F40D84812842BB44D40
14182	Радофинниково	3	29	564	30.867038000000001	30.888445000000001	59.153799999999997	59.144506	0103000020E61000000100000005000000A663CE33F6DD3E40B309302C7F924D40A663CE33F6DD3E40F90FE9B7AF934D40734BAB2171E33E40F90FE9B7AF934D40734BAB2171E33E40B309302C7F924D40A663CE33F6DD3E40B309302C7F924D40
14797	Померанье	3	29	564	31.304078000000001	31.325206000000001	59.311678999999998	59.301274999999997	0103000020E61000000100000005000000DF6E490ED84D3F401B0DE02D90A64D40DF6E490ED84D3F40CCECF318E5A74D4086764EB340533F40CCECF318E5A74D4086764EB340533F401B0DE02D90A64D40DF6E490ED84D3F401B0DE02D90A64D40
11029	Нурма	3	29	564	31.007633999999999	31.024989000000001	59.562520999999997	59.549827000000001	0103000020E610000001000000050000007156444DF4013F4099BA2BBB60C64D407156444DF4013F40172829B000C84D407FC2D9AD65063F40172829B000C84D407FC2D9AD65063F4099BA2BBB60C64D407156444DF4013F4099BA2BBB60C64D40
13272	Новолисино	3	29	564	30.750042000000001	30.780638	59.573518999999997	59.554518999999999	0103000020E610000001000000050000005EA0A4C002C03E405C01857AFAC64D405EA0A4C002C03E403B51121269C94D40CD0358E4D7C73E403B51121269C94D40CD0358E4D7C73E405C01857AFAC64D405EA0A4C002C03E405C01857AFAC64D40
9079	Никольское	3	29	564	30.755134999999999	30.831133000000001	59.734560999999999	59.672724000000002	0103000020E61000000100000005000000A110018750C13E40FE9DEDD11BD64D40A110018750C13E4062F5471806DE4D405AA0DD21C5D43E4062F5471806DE4D405AA0DD21C5D43E40FE9DEDD11BD64D40A110018750C13E40FE9DEDD11BD64D40
14369	Любань	3	29	564	31.243648	31.270579999999999	59.374932000000001	59.362878000000002	0103000020E610000001000000050000005EBC1FB75F3E3F400D384BC972AE4D405EBC1FB75F3E3F40A81C93C5FDAF4D40A1F31ABB44453F40A81C93C5FDAF4D40A1F31ABB44453F400D384BC972AE4D405EBC1FB75F3E3F400D384BC972AE4D40
14092	Лисино-Корпус	3	29	564	30.646160999999999	30.690366999999998	59.435160000000003	59.419409999999999	0103000020E610000001000000050000005EF3AACE6AA53E40C4CE143AAFB54D405EF3AACE6AA53E408143A852B3B74D40D53C47E4BBB03E408143A852B3B74D40D53C47E4BBB03E40C4CE143AAFB54D405EF3AACE6AA53E40C4CE143AAFB54D40
11202	Красный Бор	3	29	564	30.636037000000002	30.712717000000001	59.692473999999997	59.647928999999998	0103000020E61000000100000005000000C40B2252D3A23E40A3906456EFD24D40C40B2252D3A23E4047AAEFFCA2D84D40A14D0E9F74B63E4047AAEFFCA2D84D40A14D0E9F74B63E40A3906456EFD24D40C40B2252D3A23E40A3906456EFD24D40
58925	Гладкое	3	29	564	30.848129	30.862924	59.647770000000001	59.640183999999998	0103000020E6100000010000000500000008CA6DFB1ED93E4013B69F8CF1D14D4008CA6DFB1ED93E403BAA9A20EAD24D40FAEE5696E8DC3E403BAA9A20EAD24D40FAEE5696E8DC3E4013B69F8CF1D14D4008CA6DFB1ED93E4013B69F8CF1D14D40
15227	Войскорово	3	29	564	30.553678999999999	30.577251	59.697305999999998	59.684480999999998	0103000020E61000000100000005000000637B2DE8BD8D3E40DFDDCA129DD74D40637B2DE8BD8D3E40FCA6B05241D94D405395B6B8C6933E40FCA6B05241D94D405395B6B8C6933E40DFDDCA129DD74D40637B2DE8BD8D3E40DFDDCA129DD74D40
10937	Бабино-2	3	29	564	31.474191999999999	31.482285999999998	59.222495000000002	59.217581000000003	0103000020E610000001000000050000005B069CA564793F40919DB7B1D99B4D405B069CA564793F40034356B77A9C4D4093516518777B3F40034356B77A9C4D4093516518777B3F40919DB7B1D99B4D405B069CA564793F40919DB7B1D99B4D40
12998	Шугозеро	3	29	1194	34.187823000000002	34.240724	59.936948999999998	59.918768999999998	0103000020E61000000100000005000000E33785950A18414010CAFB389AF54D40E33785950A1841408C82E0F1EDF74D4060AE450BD01E41408C82E0F1EDF74D4060AE450BD01E414010CAFB389AF54D40E33785950A18414010CAFB389AF54D40
12699	Цвылёво	3	29	1194	33.202388999999997	33.214444	59.657581	59.65108	0103000020E61000000100000005000000FA08FCE1E7994040338AE59656D34D40FA08FCE1E799404049BC3C9D2BD44D406669A7E6729B404049BC3C9D2BD44D406669A7E6729B4040338AE59656D34D40FA08FCE1E7994040338AE59656D34D40
11445	Тихвин	3	29	1194	33.449731	33.602012999999999	59.681887000000003	59.598306000000001	0103000020E61000000100000005000000AA7F10C990B9404013807F4A95CC4D40AA7F10C990B94040A648BE1248D74D40286211C30ECD4040A648BE1248D74D40286211C30ECD404013807F4A95CC4D40AA7F10C990B9404013807F4A95CC4D40
12609	Сарка	3	29	1194	33.651178000000002	33.664167999999997	59.679203000000001	59.674236999999998	0103000020E61000000100000005000000F6EFFACC59D340406760E4654DD64D40F6EFFACC59D340402C2CB81FF0D64D405D86FF7403D540402C2CB81FF0D64D405D86FF7403D540406760E4654DD64D40F6EFFACC59D340406760E4654DD64D40
13050	Пашозеро	3	29	1194	34.592737999999997	34.635983000000003	60.034635999999999	60.026572000000002	0103000020E61000000100000005000000588CBAD6DE4B4140A27E17B666034E40588CBAD6DE4B4140D3A1D3F36E044E40EFE714E467514140D3A1D3F36E044E40EFE714E467514140A27E17B666034E40588CBAD6DE4B4140A27E17B666034E40
12673	Мелегежская Горка	3	29	1194	33.407420000000002	33.424767000000003	59.577607	59.565624999999997	0103000020E6100000010000000500000040DEAB5626B440406666666666C84D4040DEAB5626B440406878B306EFC94D40C4B5DAC35EB640406878B306EFC94D40C4B5DAC35EB640406666666666C84D4040DEAB5626B440406666666666C84D40
12513	Красава	3	29	1194	33.581639000000003	33.599947	59.560560000000002	59.552790999999999	0103000020E61000000100000005000000018A912573CA4040F64201DBC1C64D40018A912573CA40400FB9196EC0C74D40AA2A3410CBCC40400FB9196EC0C74D40AA2A3410CBCC4040F64201DBC1C64D40018A912573CA4040F64201DBC1C64D40
12870	Коськово	3	29	1194	33.270857999999997	33.294708999999997	60.033121999999999	60.023668000000001	0103000020E6100000010000000500000013EE9579ABA240401AFB928D07034E4013EE9579ABA24040996379573D044E401E6B4606B9A54040996379573D044E401E6B4606B9A540401AFB928D07034E4013EE9579ABA240401AFB928D07034E40
58987	Ерёмина Гора	3	29	1194	33.891719999999999	33.899023	59.991813	59.987893	0103000020E61000000100000005000000359886E123F2404042791F4773FE4D40359886E123F24040B35F77BAF3FE4D4008AD872F13F34040B35F77BAF3FE4D4008AD872F13F3404042791F4773FE4D40359886E123F2404042791F4773FE4D40
12837	Горка	3	29	1194	33.317427000000002	33.347368000000003	59.822127000000002	59.804658000000003	0103000020E6100000010000000500000007EFAB72A1A840407E3B8908FFE64D4007EFAB72A1A840404D1421753BE94D40A6D6FB8D76AC40404D1421753BE94D40A6D6FB8D76AC40407E3B8908FFE64D4007EFAB72A1A840407E3B8908FFE64D40
12913	Ганьково	3	29	1194	33.784694999999999	33.811940999999997	59.899293	59.888519000000002	0103000020E61000000100000005000000D82AC1E270E44040F46F97FDBAF14D40D82AC1E270E44040C84274081CF34D4009A4C4AEEDE74040C84274081CF34D4009A4C4AEEDE74040F46F97FDBAF14D40D82AC1E270E44040F46F97FDBAF14D40
58990	Бор	3	29	1194	33.456198999999998	33.481521999999998	59.775105000000003	59.764141000000002	0103000020E61000000100000005000000E4BB94BA64BA404031444E5FCFE14D40E4BB94BA64BA4040A9FB00A436E34D40FA264D83A2BD4040A9FB00A436E34D40FA264D83A2BD404031444E5FCFE14D40E4BB94BA64BA404031444E5FCFE14D40
12558	Березовик	3	29	1194	33.470283999999999	33.481828	59.691656999999999	59.688699999999997	0103000020E6100000010000000500000081EA1F4432BC4040AA60545227D84D4081EA1F4432BC40405586713788D84D400726378AACBD40405586713788D84D400726378AACBD4040AA60545227D84D4081EA1F4432BC4040AA60545227D84D40
11688	Черновское	3	29	1125	28.423853999999999	28.438828999999998	59.223457000000003	59.212980000000002	0103000020E610000001000000050000005E471CB2816C3C40DE59BBED429B4D405E471CB2816C3C40F9872D3D9A9C4D405089EB1857703C40F9872D3D9A9C4D405089EB1857703C40DE59BBED429B4D405E471CB2816C3C40DE59BBED429B4D40
58949	Старополье	3	29	1125	28.586207000000002	28.600615999999999	59.047744999999999	59.041857	0103000020E61000000100000005000000B0AF75A911963C40E90DF7915B854D40B0AF75A911963C4015C616821C864D404F745DF8C1993C4015C616821C864D404F745DF8C1993C40E90DF7915B854D40B0AF75A911963C40E90DF7915B854D40
10320	Сланцы	3	29	1125	28.065947999999999	28.066279999999999	59.096786000000002	59.095269999999999	0103000020E61000000100000005000000923CD7F7E1103C401C25AFCE318C4D40923CD7F7E1103C40F75AD07B638C4D40FE60E0B9F7103C40F75AD07B638C4D40FE60E0B9F7103C401C25AFCE318C4D40923CD7F7E1103C401C25AFCE318C4D40
10246	Сельхозтехника	3	29	1125	28.060827	28.067250000000001	59.076065	59.06729	0103000020E61000000100000005000000BBB6B75B920F3C4086AC6EF59C884D40BBB6B75B920F3C4064AF777FBC894D40F0A7C64B37113C4064AF777FBC894D40F0A7C64B37113C4086AC6EF59C884D40BBB6B75B920F3C4086AC6EF59C884D40
59012	Овсище	3	29	1125	28.717738000000001	28.730547999999999	59.060442999999999	59.051582000000003	0103000020E61000000100000005000000B11875ADBDB73C40F9872D3D9A864D40B11875ADBDB73C40D522A298BC874D408028983105BB3C40D522A298BC874D408028983105BB3C40F9872D3D9A864D40B11875ADBDB73C40F9872D3D9A864D40
11503	Новоселье	3	29	1125	28.337175999999999	28.350193000000001	58.910524000000002	58.905728000000003	0103000020E6100000010000000500000000FF942A51563C40278925E5EE734D4000FF942A51563C408F1CE90C8C744D40C3499A3FA6593C408F1CE90C8C744D40C3499A3FA6593C40278925E5EE734D4000FF942A51563C40278925E5EE734D40
11631	Ложголово	3	29	1125	28.704183	28.728383000000001	59.159396000000001	59.146138999999998	0103000020E6100000010000000500000030664B5645B43C40C7D5C8AEB4924D4030664B5645B43C407E8E8F1667944D405EF6EB4E77BA3C407E8E8F1667944D405EF6EB4E77BA3C40C7D5C8AEB4924D4030664B5645B43C40C7D5C8AEB4924D40
10243	Загривье	3	29	1125	27.843713000000001	27.865667999999999	59.113134000000002	59.101463000000003	0103000020E61000000100000005000000C6353E93FDD73B40856055BDFC8C4D40C6353E93FDD73B406808C72C7B8E4D409831056B9CDD3B406808C72C7B8E4D409831056B9CDD3B40856055BDFC8C4D40C6353E93FDD73B40856055BDFC8C4D40
11400	Гусева Гора	3	29	1125	28.267637000000001	28.28511	58.954149999999998	58.947099000000001	0103000020E610000001000000050000001633C2DB83443C4083893F8A3A794D401633C2DB83443C403CBD5296217A4D4037C30DF8FC483C403CBD5296217A4D4037C30DF8FC483C4083893F8A3A794D401633C2DB83443C4083893F8A3A794D40
11356	Выскатка	3	29	1125	28.173539000000002	28.190715000000001	59.023918999999999	59.017632999999996	0103000020E610000001000000050000009F94490D6D2C3C40492A53CC41824D409F94490D6D2C3C4063601DC70F834D404DDBBFB2D2303C4063601DC70F834D404DDBBFB2D2303C40492A53CC41824D409F94490D6D2C3C40492A53CC41824D40
59011	Большие Поля	3	29	1125	28.060296999999998	28.080455000000001	59.144815000000001	59.121969999999997	0103000020E61000000100000005000000020CCB9F6F0F3C40EB8B84B69C8F4D40020CCB9F6F0F3C40317C444C89924D40B8CCE9B298143C40317C444C89924D40B8CCE9B298143C40EB8B84B69C8F4D40020CCB9F6F0F3C40EB8B84B69C8F4D40
59032	остановочный пункт 69 км	3	29	97	30.172281000000002	30.304082000000001	60.540553000000003	60.475561999999996	0103000020E61000000100000005000000E1B88C9B1A2C3E40349C3237DF3C4E40E1B88C9B1A2C3E409A6038D730454E40624D6551D84D3E409A6038D730454E40624D6551D84D3E40349C3237DF3C4E40E1B88C9B1A2C3E40349C3237DF3C4E40
6676	Суходолье	3	29	97	30.018274000000002	30.048556000000001	60.717692	60.711851000000003	0103000020E61000000100000005000000FB5DD89AAD043E40FD4FFEEE1D5B4E40FB5DD89AAD043E40E84CDA54DD5B4E404B06802A6E0C3E40E84CDA54DD5B4E404B06802A6E0C3E40FD4FFEEE1D5B4E40FB5DD89AAD043E40FD4FFEEE1D5B4E40
9709	Сосново	3	29	97	30.194963999999999	30.268616999999999	60.58287	60.539203999999998	0103000020E61000000100000005000000B8E52329E9313E40AAEFFCA204454E40B8E52329E9313E40E6E8F17B9B4A4E404E266E15C4443E40E6E8F17B9B4A4E404E266E15C4443E40AAEFFCA204454E40B8E52329E9313E40AAEFFCA204454E40
9639	Снегирёвка	3	29	97	30.284552999999999	30.311826	60.558784000000003	60.54804	0103000020E610000001000000050000008BFA2477D8483E402E73BA2C26464E408BFA2477D8483E4098C3EE3B86474E40E10A28D4D34F3E4098C3EE3B86474E40E10A28D4D34F3E402E73BA2C26464E408BFA2477D8483E402E73BA2C26464E40
10020	Севастьяново	3	29	97	29.785359	29.808778	61.061070000000001	61.052095999999999	0103000020E61000000100000005000000889E94490DC93D404F20EC14AB864E40889E94490DC93D4024624A24D1874E406BB933130CCF3D4024624A24D1874E406BB933130CCF3D404F20EC14AB864E40889E94490DC93D404F20EC14AB864E40
9374	Сапёрное	3	29	97	29.938404999999999	29.973143	60.733271000000002	60.708888999999999	0103000020E610000001000000050000002367614F3BF03D4040BFEFDFBC5A4E402367614F3BF03D40780DFAD2DB5D4E40D2544FE61FF93D40780DFAD2DB5D4E40D2544FE61FF93D4040BFEFDFBC5A4E402367614F3BF03D4040BFEFDFBC5A4E40
6612	Ромашки	3	29	97	29.793641000000001	29.819603000000001	60.722216000000003	60.707476	0103000020E61000000100000005000000C6C37B0E2CCB3D403A5AD5928E5A4E40C6C37B0E2CCB3D40F052EA92715C4E4018B49080D1D13D40F052EA92715C4E4018B49080D1D13D403A5AD5928E5A4E40C6C37B0E2CCB3D403A5AD5928E5A4E40
59023	Раздолье	3	29	97	30.129926000000001	30.162050000000001	60.581088999999999	60.570042999999998	0103000020E610000001000000050000006DE690D442213E402828452BF7484E406DE690D442213E405D88D51F614A4E401A51DA1B7C293E405D88D51F614A4E401A51DA1B7C293E402828452BF7484E406DE690D442213E402828452BF7484E40
125	Приозерск	3	29	97	30.087031	30.18289	61.052970999999999	61.006320000000002	0103000020E61000000100000005000000F9BCE2A947163E40C6A70018CF804E40F9BCE2A947163E407651F4C0C7864E40F4C308E1D12E3E407651F4C0C7864E40F4C308E1D12E3E40C6A70018CF804E40F9BCE2A947163E40C6A70018CF804E40
6409	Починок	3	29	97	30.180392999999999	30.219532999999998	60.974108999999999	60.964613	0103000020E61000000100000005000000656D533C2E2E3E40F2255470787B4E40656D533C2E2E3E40A0DE8C9AAF7C4E408C648F5033383E40A0DE8C9AAF7C4E408C648F5033383E40F2255470787B4E40656D533C2E2E3E40F2255470787B4E40
9167	Плодовое	3	29	97	30.143338	30.227573	60.843716999999998	60.816374000000003	0103000020E61000000100000005000000284696CCB1243E4001A777F17E684E40284696CCB1243E40240A2DEBFE6B4E40DE736039423A3E40240A2DEBFE6B4E40DE736039423A3E4001A777F17E684E40284696CCB1243E4001A777F17E684E40
6724	Петровское	3	29	97	30.127330000000001	30.172605000000001	60.648902999999997	60.632019999999997	0103000020E61000000100000005000000B8CCE9B298203E407E350708E6504E40B8CCE9B298203E405DA3E5400F534E4047205ED72F2C3E405DA3E5400F534E4047205ED72F2C3E407E350708E6504E40B8CCE9B298203E407E350708E6504E40
9135	Моторное	3	29	97	30.287103999999999	30.304316	60.966603999999997	60.953859999999999	0103000020E61000000100000005000000008DD2A57F493E40357BA015187A4E40008DD2A57F493E4065170CAEB97B4E4048A643A7E74D3E4065170CAEB97B4E4048A643A7E74D3E40357BA015187A4E40008DD2A57F493E40357BA015187A4E40
9936	Мичуринское	3	29	97	29.789176999999999	29.892500999999999	60.590431000000002	60.556666	0103000020E6100000010000000500000061C1FD8007CA3D40C765DCD440474E4061C1FD8007CA3D40B5C5353E934B4E40B5A50EF27AE43D40B5C5353E934B4E40B5A50EF27AE43D40C765DCD440474E4061C1FD8007CA3D40C765DCD440474E40
6525	Мельниково	3	29	97	29.736194000000001	29.80911	60.933247000000001	60.900556000000002	0103000020E61000000100000005000000ED82C13577BC3D40B91B446B45734E40ED82C13577BC3D40890B40A374774E40D7DD3CD521CF3D40890B40A374774E40D7DD3CD521CF3D40B91B446B45734E40ED82C13577BC3D40B91B446B45734E40
6462	Ларионово	3	29	97	30.158169000000001	30.237580000000001	61.011073000000003	60.992753999999998	0103000020E61000000100000005000000B43D7AC37D283E40917C2590127F4E40B43D7AC37D283E402F6F0ED76A814E40062FFA0AD23C3E402F6F0ED76A814E40062FFA0AD23C3E40917C2590127F4E40B43D7AC37D283E40917C2590127F4E40
10082	Кузнечное	3	29	97	29.853370000000002	29.887056999999999	61.128740000000001	61.110514000000002	0103000020E610000001000000050000003563D17476DA3D4005E09F52258E4E403563D17476DA3D40F1D7648D7A904E4018B0E42A16E33D40F1D7648D7A904E4018B0E42A16E33D4005E09F52258E4E403563D17476DA3D4005E09F52258E4E40
59035	Кузнечное	3	29	97	29.853370000000002	29.887056999999999	61.128740000000001	61.110514000000002	0103000020E610000001000000050000003563D17476DA3D4005E09F52258E4E403563D17476DA3D40F1D7648D7A904E4018B0E42A16E33D40F1D7648D7A904E4018B0E42A16E33D4005E09F52258E4E403563D17476DA3D4005E09F52258E4E40
59019	Кривко	3	29	97	30.235271000000001	30.270368000000001	60.599969000000002	60.579205999999999	0103000020E610000001000000050000007DB262B83A3C3E40D0D2156C234A4E407DB262B83A3C3E4092CEC0C8CB4C4E408BE255D636453E4092CEC0C8CB4C4E408BE255D636453E40D0D2156C234A4E407DB262B83A3C3E40D0D2156C234A4E40
9963	Красноозёрное	3	29	97	29.647566000000001	29.668479000000001	60.585774000000001	60.578446	0103000020E610000001000000050000006500A8E2C6A53D404240BE840A4A4E406500A8E2C6A53D406E6C76A4FA4A4E401310937021AB3D406E6C76A4FA4A4E401310937021AB3D404240BE840A4A4E406500A8E2C6A53D404240BE840A4A4E40
6369	Коммунары	3	29	97	30.053038999999998	30.081426	60.912219	60.901544999999999	0103000020E610000001000000050000009C69C2F6930D3E40A86F99D365734E409C69C2F6930D3E4019E59997C3744E404A0B9755D8143E4019E59997C3744E404A0B9755D8143E40A86F99D365734E409C69C2F6930D3E40A86F99D365734E40
1005	Запорожское	3	29	97	30.499842999999998	30.540061000000001	60.591963999999997	60.557679	0103000020E610000001000000050000007022FAB5F57F3E403F55850662474E407022FAB5F57F3E406534F279C54B4E4056D80C70418A3E406534F279C54B4E4056D80C70418A3E403F55850662474E407022FAB5F57F3E403F55850662474E40
58916	Громово	3	29	97	30.140526000000001	30.223206999999999	60.702378000000003	60.690345999999998	0103000020E61000000100000005000000DA3C0E83F9233E405376FA415D584E40DA3C0E83F9233E4007B7B585E7594E40FF3C0D1824393E4007B7B585E7594E40FF3C0D1824393E405376FA415D584E40DA3C0E83F9233E405376FA415D584E40
6595	Громово	3	29	97	30.140526000000001	30.223206999999999	60.702378000000003	60.690345999999998	0103000020E61000000100000005000000DA3C0E83F9233E405376FA415D584E40DA3C0E83F9233E4007B7B585E7594E40FF3C0D1824393E4007B7B585E7594E40FF3C0D1824393E405376FA415D584E40DA3C0E83F9233E405376FA415D584E40
7607	ской посёлок Никольский	3	29	438	34.056651000000002	34.077697999999998	60.920223	60.910595999999998	0103000020E61000000100000005000000922408574007414028EFE3688E744E409224085740074140750305DEC9754E40787B1002F2094140750305DEC9754E40787B1002F209414028EFE3688E744E40922408574007414028EFE3688E744E40
8434	Ярославичи	3	29	438	34.495674999999999	34.516461999999997	60.501725999999998	60.488551000000001	0103000020E61000000100000005000000EF384547723F4140CCB6D3D6883E4E40EF384547723F4140C5C6BC8E38404E4039D0436D1B424140C5C6BC8E38404E4039D0436D1B424140CCB6D3D6883E4E40EF384547723F4140CCB6D3D6883E4E40
2830	Шеменичи	3	29	438	34.409427999999998	34.437508999999999	60.882654000000002	60.871602000000003	0103000020E610000001000000050000008908FF2268344140699082A7906F4E408908FF226834414080D767CEFA704E40535A7F4B0038414080D767CEFA704E40535A7F4B00384140699082A7906F4E408908FF2268344140699082A7906F4E40
2738	Токари	3	29	438	34.378309999999999	34.411287000000002	61.108206000000003	61.091856999999997	0103000020E61000000100000005000000F8DF4A766C3041404F745DF8C18B4E40F8DF4A766C304140919DB7B1D98D4E408E226B0DA5344140919DB7B1D98D4E408E226B0DA53441404F745DF8C18B4E40F8DF4A766C3041404F745DF8C18B4E40
7782	Родионово	3	29	438	34.992327000000003	35.010930999999999	60.935896	60.922553999999998	0103000020E610000001000000050000000AF83592047F4140A165DD3F16764E400AF83592047F4140863AAC70CB774E409CC1DF2F66814140863AAC70CB774E409CC1DF2F66814140A165DD3F16764E400AF83592047F4140A165DD3F16764E40
2412	Подпорожье	3	29	438	34.102375000000002	34.253228999999997	60.939051999999997	60.895935000000001	0103000020E61000000100000005000000C976BE9F1A0D4140BF2B82FFAD724E40C976BE9F1A0D4140279F1EDB32784E400BB3D0CE69204140279F1EDB32784E400BB3D0CE69204140BF2B82FFAD724E40C976BE9F1A0D4140BF2B82FFAD724E40
58959	Никольский	3	29	438	34.056651000000002	34.077697999999998	60.920223	60.910595999999998	0103000020E61000000100000005000000922408574007414028EFE3688E744E409224085740074140750305DEC9754E40787B1002F2094140750305DEC9754E40787B1002F209414028EFE3688E744E40922408574007414028EFE3688E744E40
8237	Лукинская	3	29	438	34.822212999999998	34.841400999999998	60.462251999999999	60.456316000000001	0103000020E610000001000000050000004BAC8C463E6941401E520C90683A4E404BAC8C463E6941405B41D3122B3B4E402DE92807B36B41405B41D3122B3B4E402DE92807B36B41401E520C90683A4E404BAC8C463E6941401E520C90683A4E40
7734	Курпово	3	29	438	34.038989999999998	34.055940999999997	60.977431000000003	60.971643	0103000020E610000001000000050000007E6FD39FFD04414094313ECC5E7C4E407E6FD39FFD0441405D8C81751C7D4E40B5C01E13290741405D8C81751C7D4E40B5C01E132907414094313ECC5E7C4E407E6FD39FFD04414094313ECC5E7C4E40
8331	Курба	3	29	438	34.917918999999998	34.940466999999998	60.405298000000002	60.395783000000002	0103000020E6100000010000000500000042B0AA5E7E75414009A87004A9324E4042B0AA5E7E7541402E910BCEE0334E40CEFBFF38617841402E910BCEE0334E40CEFBFF386178414009A87004A9324E4042B0AA5E7E75414009A87004A9324E40
8477	Кузра	3	29	438	34.589207999999999	34.602556999999997	60.549751999999998	60.542478000000003	0103000020E610000001000000050000005245F12A6B4B414056664AEB6F454E405245F12A6B4B41408E7406465E464E40E97C7896204D41408E7406465E464E40E97C7896204D414056664AEB6F454E405245F12A6B4B414056664AEB6F454E40
59001	Красный Бор	3	29	438	35.392499000000001	35.450125999999997	61.059072	61.045067000000003	0103000020E610000001000000050000003A5B40683DB241407E9065C1C4854E403A5B40683DB24140FE0DDAAB8F874E40268A90BA9DB94140FE0DDAAB8F874E40268A90BA9DB941407E9065C1C4854E403A5B40683DB241407E9065C1C4854E40
7829	Кипрушино	3	29	438	35.419744999999999	35.439247999999999	60.946126999999997	60.939816999999998	0103000020E610000001000000050000006BD44334BAB54140C79C67EC4B784E406BD44334BAB54140696E85B01A794E40AD6A494739B84140696E85B01A794E40AD6A494739B84140C79C67EC4B784E406BD44334BAB54140C79C67EC4B784E40
58996	Кармановская	3	29	438	34.859098000000003	34.872805999999997	60.563304000000002	60.554264000000003	0103000020E610000001000000050000008E075BECF66D4140D2AC6C1FF2464E408E075BECF66D41405EDA70581A484E4054E0641BB86F41405EDA70581A484E4054E0641BB86F4140D2AC6C1FF2464E408E075BECF66D4140D2AC6C1FF2464E40
8400	Казыченская	3	29	438	35.054336999999997	35.064048	60.398699000000001	60.394275999999998	0103000020E610000001000000050000003BFBCA83F486414081CCCEA277324E403BFBCA83F486414055F99E9108334E40E6AF90B93288414055F99E9108334E40E6AF90B93288414081CCCEA277324E403BFBCA83F486414081CCCEA277324E40
7873	Гимрека	3	29	438	35.611939999999997	35.627166000000003	61.155810000000002	61.148001000000001	0103000020E610000001000000050000009F8EC70C54CE41403D635FB2F1924E409F8EC70C54CE4140E4310395F1934E40E294B9F946D04140E4310395F1934E40E294B9F946D041403D635FB2F1924E409F8EC70C54CE41403D635FB2F1924E40
58948	Вознесенье	3	29	438	35.401491	35.507402999999996	61.051555999999998	60.992809999999999	0103000020E61000000100000005000000B5519D0E64B341402592E865147F4E40B5519D0E64B34140CFF4126399864E403672DD94F2C04140CFF4126399864E403672DD94F2C041402592E865147F4E40B5519D0E64B341402592E865147F4E40
8071	Винницы	3	29	438	34.732883999999999	34.801596000000004	60.639949000000001	60.618929999999999	0103000020E610000001000000050000007EE19524CF5D4140B3412619394F4E407EE19524CF5D4140D00D4DD9E9514E405E4D9EB29A664140D00D4DD9E9514E405E4D9EB29A664140B3412619394F4E407EE19524CF5D4140B3412619394F4E40
7691	Важины	3	29	438	33.987749999999998	34.050362	60.970537999999998	60.953479999999999	0103000020E61000000100000005000000DF4F8D976EFE4040EEB1F4A10B7A4E40DF4F8D976EFE40403BC3D4963A7C4E40077B1343720641403BC3D4963A7C4E40077B134372064140EEB1F4A10B7A4E40DF4F8D976EFE4040EEB1F4A10B7A4E40
6168	ской посёлок Толмачёво	3	29	261	29.864186	29.925784	58.870243000000002	58.838908000000004	0103000020E610000001000000050000003BA92F4B3BDD3D40282D5C56616B4D403BA92F4B3BDD3D405649641F646F4D40FA28232E00ED3D405649641F646F4D40FA28232E00ED3D40282D5C56616B4D403BA92F4B3BDD3D40282D5C56616B4D40
6470	при ж/д станции Низовская	3	29	261	29.965192999999999	29.988368999999999	59.109299999999998	59.089343999999997	0103000020E61000000100000005000000005471E316F73D40020CCB9F6F8B4D40005471E316F73D40F5B9DA8AFD8D4D40566133C005FD3D40F5B9DA8AFD8D4D40566133C005FD3D40020CCB9F6F8B4D40005471E316F73D40020CCB9F6F8B4D40
3753	детский лагерь Зелёный Бор	3	29	261	29.932431000000001	29.939339	58.821409000000003	58.816698000000002	0103000020E61000000100000005000000CEC64ACCB3EE3D40B45A608F89684D40CEC64ACCB3EE3D40EED11BEE23694D407BDB4C8578F03D40EED11BEE23694D407BDB4C8578F03D40B45A608F89684D40CEC64ACCB3EE3D40B45A608F89684D40
6034	Ям-Тёсово	3	29	261	30.572202000000001	30.590205000000001	58.898434999999999	58.889800999999999	0103000020E61000000100000005000000AFB48CD47B923E405B79C9FFE4714D40AFB48CD47B923E40774A07EBFF724D4089EFC4AC17973E40774A07EBFF724D4089EFC4AC17973E405B79C9FFE4714D40AFB48CD47B923E405B79C9FFE4714D40
1889	Тёсово-4	3	29	261	30.554299	30.580126	58.804212999999997	58.794790999999996	0103000020E610000001000000050000009C340D8AE68D3E40DB1324B6BB654D409C340D8AE68D3E404F029B73F0664D402E8F352383943E404F029B73F0664D402E8F352383943E40DB1324B6BB654D409C340D8AE68D3E40DB1324B6BB654D40
5567	Турово	3	29	261	29.923528999999998	29.944800999999998	58.744771	58.736389000000003	0103000020E6100000010000000500000057E883656CEC3D402C11A8FE415E4D4057E883656CEC3D402E01F8A7545F4D40643A747ADEF13D402E01F8A7545F4D40643A747ADEF13D402C11A8FE415E4D4057E883656CEC3D402C11A8FE415E4D40
1562	Торошковичи	3	29	261	30.104673999999999	30.118974999999999	58.573036999999999	58.560308999999997	0103000020E61000000100000005000000D3BD4EEACB1A3E40C5538F34B8474D40D3BD4EEACB1A3E40F032C34659494D40A60A4625751E3E40F032C34659494D40A60A4625751E3E40C5538F34B8474D40D3BD4EEACB1A3E40C5538F34B8474D40
59026	Торковичи	3	29	261	30.322282000000001	30.363406999999999	58.864128999999998	58.846930999999998	0103000020E61000000100000005000000E816BA1281523E40FA7B293C686C4D40E816BA1281523E40394371C79B6E4D403123BC3D085D3E40394371C79B6E4D403123BC3D085D3E40FA7B293C686C4D40E816BA1281523E40FA7B293C686C4D40
1814	Скреблово	3	29	261	29.876709000000002	29.890552	58.608691	58.596420999999999	0103000020E61000000100000005000000DF1B430070E03D40E5D2F885574C4D40DF1B430070E03D404D2F3196E94D4D402C634337FBE33D404D2F3196E94D4D402C634337FBE33D40E5D2F885574C4D40DF1B430070E03D40E5D2F885574C4D40
6773	Серебрянский	3	29	261	29.592230000000001	29.621372000000001	58.587491999999997	58.570535999999997	0103000020E61000000100000005000000C8B5A1629C973D406798DA5207494D40C8B5A1629C973D40B05417F0324B4D406EA6423C129F3D40B05417F0324B4D406EA6423C129F3D406798DA5207494D40C8B5A1629C973D406798DA5207494D40
6730	Ретюнь	3	29	261	29.780049999999999	29.812757999999999	58.566020999999999	58.558694000000003	0103000020E61000000100000005000000AB3E575BB1C73D40583CF54883474D40AB3E575BB1C73D40B3EC496073484D40F78F85E810D03D40B3EC496073484D40F78F85E810D03D40583CF54883474D40AB3E575BB1C73D40583CF54883474D40
2246	Рель	3	29	261	28.921565999999999	28.934546999999998	58.964767000000002	58.957686000000002	0103000020E61000000100000005000000041BD7BFEBEB3C4025EB7074957A4D40041BD7BFEBEB3C4049A12C7C7D7B4D402D93E1783EEF3C4049A12C7C7D7B4D402D93E1783EEF3C4025EB7074957A4D40041BD7BFEBEB3C4025EB7074957A4D40
1674	Раковно	3	29	261	30.018274000000002	30.032225	58.666545999999997	58.658008000000002	0103000020E61000000100000005000000FB5DD89AAD043E40D1402C9B39544D40FB5DD89AAD043E40CAA31B6151554D40151DC9E53F083E40CAA31B6151554D40151DC9E53F083E40D1402C9B39544D40FB5DD89AAD043E40D1402C9B39544D40
6096	Приозерный	3	29	261	30.652906999999999	30.660309000000002	58.927090999999997	58.921145000000003	0103000020E610000001000000050000005854C4E924A73E40DDEF5014E8754D405854C4E924A73E403DB5FAEAAA764D402541B8020AA93E403DB5FAEAAA764D402541B8020AA93E40DDEF5014E8754D405854C4E924A73E40DDEF5014E8754D40
6308	Плоское	3	29	261	29.940714	29.988054999999999	58.830018000000003	58.813780999999999	0103000020E61000000100000005000000ACE3F8A1D2F03D40978DCEF929684D40ACE3F8A1D2F03D40B18BA2073E6A4D4037A6272CF1FC3D40B18BA2073E6A4D4037A6272CF1FC3D40978DCEF929684D40ACE3F8A1D2F03D40978DCEF929684D40
6586	Пехенец	3	29	261	30.037686999999998	30.056363000000001	58.985505000000003	58.976818999999999	0103000020E61000000100000005000000FE7BF0DAA5093E40438EAD67087D4D40FE7BF0DAA5093E40B2852007257E4D4057B439CE6D0E3E40B2852007257E4D4057B439CE6D0E3E40438EAD67087D4D40FE7BF0DAA5093E40438EAD67087D4D40
2180	Осьмино	3	29	261	29.077289	29.108208999999999	59.020667000000003	59.004182	0103000020E610000001000000050000002E573F36C9133D40AE9D280989804D402E573F36C9133D40A08D5C37A5824D400322C495B31B3D40A08D5C37A5824D400322C495B31B3D40AE9D280989804D402E573F36C9133D40AE9D280989804D40
1789	Оредеж	3	29	261	30.325192999999999	30.359373999999999	58.829192999999997	58.806725	0103000020E610000001000000050000005CE333D93F533E40CCEEC9C342674D405CE333D93F533E403B8908FF226A4D405F0839EFFF5B3E403B8908FF226A4D405F0839EFFF5B3E40CCEEC9C342674D405CE333D93F533E40CCEEC9C342674D40
6416	Мшинская	3	29	261	29.976161000000001	30.103767000000001	59.067762000000002	59.023659000000002	0103000020E6100000010000000500000073A1F2AFE5F93D40C7A0134207834D4073A1F2AFE5F93D40AEF4DA6CAC884D406F675F79901A3E40AEF4DA6CAC884D406F675F79901A3E40C7A0134207834D4073A1F2AFE5F93D40C7A0134207834D40
5725	Мерёво	3	29	261	30.052562999999999	30.076322999999999	58.765642	58.760821	0103000020E61000000100000005000000CAFACDC4740D3E40158E209562614D40CAFACDC4740D3E40D6389B8E00624D40BFEE74E789133E40D6389B8E00624D40BFEE74E789133E40158E209562614D40CAFACDC4740D3E40158E209562614D40
5877	Межозёрный	3	29	261	29.825783000000001	29.831002000000002	58.631385999999999	58.628064999999999	0103000020E61000000100000005000000C097C28366D33D409161156F64504D40C097C28366D33D407D93A641D1504D401DE90C8CBCD43D407D93A641D1504D401DE90C8CBCD43D409161156F64504D40C097C28366D33D409161156F64504D40
58994	Луга-3	3	29	261	29.805688	29.827652	58.749706000000003	58.742314999999998	0103000020E6100000010000000500000097C79A9141CE3D40452A8C2D045F4D4097C79A9141CE3D40B8CEBF5DF65F4D4010786000E1D33D40B8CEBF5DF65F4D4010786000E1D33D40452A8C2D045F4D4097C79A9141CE3D40452A8C2D045F4D40
1097	Луга	3	29	261	29.711365000000001	29.918759000000001	58.804791000000002	58.675502000000002	0103000020E61000000100000005000000E08442041CB63D40F9307BD976564D40E08442041CB63D40BD8E386403674D40DAE731CA33EB3D40BD8E386403674D40DAE731CA33EB3D40F9307BD976564D40E08442041CB63D40F9307BD976564D40
2139	Красный Маяк	3	29	261	29.934488000000002	29.953918999999999	59.171204000000003	59.162647999999997	0103000020E610000001000000050000002481069B3AEF3D40416150A6D1944D402481069B3AEF3D40E2783E03EA954D4074081C0934F43D40E2783E03EA954D4074081C0934F43D40416150A6D1944D402481069B3AEF3D40416150A6D1944D40
58988	Каменка	3	29	261	30.089932999999998	30.115670000000001	58.821958000000002	58.816879999999998	0103000020E61000000100000005000000C7D45DD905173E40D4601A868F684D40C7D45DD905173E40C15774EB35694D40DA20938C9C1D3E40C15774EB35694D40DA20938C9C1D3E40D4601A868F684D40C7D45DD905173E40D4601A868F684D40
1586	Заклинье	3	29	261	29.884353000000001	29.913055	58.731642999999998	58.720052000000003	0103000020E61000000100000005000000971E4DF564E23D40AFB5F7A92A5C4D40971E4DF564E23D4075AC527AA65D4D400473F4F8BDE93D4075AC527AA65D4D400473F4F8BDE93D40AFB5F7A92A5C4D40971E4DF564E23D40AFB5F7A92A5C4D40
58898	Жельцы	3	29	261	29.916350999999999	29.928101000000002	58.848742000000001	58.838558999999997	0103000020E610000001000000050000002AA8A8FA95EA3D401B62BCE6556B4D402AA8A8FA95EA3D40EE5EEE93A36C4D408962F20698ED3D40EE5EEE93A36C4D408962F20698ED3D401B62BCE6556B4D402AA8A8FA95EA3D401B62BCE6556B4D40
1464	Дзержинского	3	29	261	29.877911999999998	29.901592000000001	58.681874000000001	58.663198999999999	0103000020E6100000010000000500000015C440D7BEE03D40B5DE6FB4E3544D4015C440D7BEE03D4011FFB0A547574D40D255BABBCEE63D4011FFB0A547574D40D255BABBCEE63D40B5DE6FB4E3544D4015C440D7BEE03D40B5DE6FB4E3544D40
2061	Волошово	3	29	261	29.291861000000001	29.31439	58.738686000000001	58.727148999999997	0103000020E6100000010000000500000055FA0967B74A3D40D828EB37135D4D4055FA0967B74A3D40AC014A438D5E4D407F30F0DC7B503D40AC014A438D5E4D407F30F0DC7B503D40D828EB37135D4D4055FA0967B74A3D40D828EB37135D4D40
5303	Володарское	3	29	261	29.861419000000001	29.893435	58.525807999999998	58.519741000000003	0103000020E610000001000000050000002D27A1F485DC3D40F7B182DF86424D402D27A1F485DC3D40D2FC31AD4D434D400D1AFA27B8E43D40D2FC31AD4D434D400D1AFA27B8E43D40F7B182DF86424D402D27A1F485DC3D40F7B182DF86424D40
58919	Бор	3	29	261	29.957035999999999	29.966674999999999	58.658138999999998	58.651496000000002	0103000020E610000001000000050000003B18B14F00F53D40C7BC8E3864534D403B18B14F00F53D406F9C14E63D544D405DDC460378F73D406F9C14E63D544D405DDC460378F73D40C7BC8E3864534D403B18B14F00F53D40C7BC8E3864534D40
3622	Яльгелево	3	29	356	29.933491	29.951457999999999	59.733359999999998	59.726514999999999	0103000020E610000001000000050000003F1C2444F9EE3D40D7868A71FEDC4D403F1C2444F9EE3D40E71890BDDEDD4D407F8461C092F33D40E71890BDDEDD4D407F8461C092F33D40D7868A71FEDC4D403F1C2444F9EE3D40D7868A71FEDC4D40
2377	Шепелево	3	29	356	29.142479999999999	29.176749999999998	59.979303999999999	59.973289000000001	0103000020E610000001000000050000008655BC9179243D403D47E4BB94FC4D408655BC9179243D40C66B5ED559FD4D406891ED7C3F2D3D40C66B5ED559FD4D406891ED7C3F2D3D403D47E4BB94FC4D408655BC9179243D403D47E4BB94FC4D40
3656	Русско-Высоцкое	3	29	356	29.913791	29.962444000000001	59.709699000000001	59.688982000000003	0103000020E610000001000000050000000F61FC34EEE93D402FC4EA8F30D84D400F61FC34EEE93D408080B56AD7DA4D403F3BE0BA62F63D408080B56AD7DA4D403F3BE0BA62F63D402FC4EA8F30D84D400F61FC34EEE93D402FC4EA8F30D84D40
3552	Ропша	3	29	356	29.858176	29.885368	59.744261000000002	59.715080999999998	0103000020E610000001000000050000004C361E6CB1DB3D40D87E32C687DB4D404C361E6CB1DB3D401958C7F143DF4D40C8EC2C7AA7E23D401958C7F143DF4D40C8EC2C7AA7E23D40D87E32C687DB4D404C361E6CB1DB3D40D87E32C687DB4D40
2736	Разбегаево	3	29	356	29.906973000000001	29.949921	59.799838000000001	59.782465000000002	0103000020E61000000100000005000000E25AED612FE83D40E0A128D027E44D40E25AED612FE83D408D0C721761E64D409BC8CC052EF33D408D0C721761E64D409BC8CC052EF33D40E0A128D027E44D40E25AED612FE83D40E0A128D027E44D40
59039	Пеники	3	29	356	29.624866000000001	29.657556	59.920203000000001	59.905203999999998	0103000020E61000000100000005000000E161DA37F79F3D40AC1A84B9DDF34D40E161DA37F79F3D402E573F36C9F54D40E0490B9755A83D402E573F36C9F54D40E0490B9755A83D40AC1A84B9DDF34D40E161DA37F79F3D40AC1A84B9DDF34D40
3400	Оржицы	3	29	356	29.702966	29.728235000000002	59.755679999999998	59.748477000000001	0103000020E610000001000000050000002F336C94F5B33D4073672618CEDF4D402F336C94F5B33D40E21E4B1FBAE04D4075CDE49B6DBA3D40E21E4B1FBAE04D4075CDE49B6DBA3D4073672618CEDF4D402F336C94F5B33D4073672618CEDF4D40
2482	Новоселье	3	29	356	30.052697999999999	30.077760999999999	59.814802999999998	59.804599000000003	0103000020E610000001000000050000008A90BA9D7D0D3E4079B29B19FDE64D408A90BA9D7D0D3E4062D7F6764BE84D407DE71725E8133E4062D7F6764BE84D407DE71725E8133E4079B29B19FDE64D408A90BA9D7D0D3E4079B29B19FDE64D40
59013	Низино	3	29	356	29.862012	29.881353000000001	59.842689	59.827165999999998	0103000020E6100000010000000500000072C284D1ACDC3D407B2E5393E0E94D4072C284D1ACDC3D4077D9AF3BDDEB4D40433BA759A0E13D4077D9AF3BDDEB4D40433BA759A0E13D407B2E5393E0E94D4072C284D1ACDC3D407B2E5393E0E94D40
3294	Низино	3	29	356	29.862012	29.881353000000001	59.842689	59.827165999999998	0103000020E6100000010000000500000072C284D1ACDC3D407B2E5393E0E94D4072C284D1ACDC3D4077D9AF3BDDEB4D40433BA759A0E13D4077D9AF3BDDEB4D40433BA759A0E13D407B2E5393E0E94D4072C284D1ACDC3D407B2E5393E0E94D40
1813	Малое Карлино	3	29	356	30.238236000000001	30.280591000000001	59.731382000000004	59.707402000000002	0103000020E61000000100000005000000D8BAD408FD3C3E40009013268CDA4D40D8BAD408FD3C3E400971E5EC9DDD4D404C8DD0CFD4473E400971E5EC9DDD4D404C8DD0CFD4473E40009013268CDA4D40D8BAD408FD3C3E40009013268CDA4D40
58950	Лопухинка	3	29	356	29.388546000000002	29.406863000000001	59.734783999999998	59.725529999999999	0103000020E61000000100000005000000DBFD2AC077633D402922C32ADEDC4D40DBFD2AC077633D40E1CFF0660DDE4D40D4F36E2C28683D40E1CFF0660DDE4D40D4F36E2C28683D402922C32ADEDC4D40DBFD2AC077633D402922C32ADEDC4D40
59044	Лебяжье	3	29	356	29.389714000000001	29.406863000000001	59.969271999999997	59.947071999999999	0103000020E6100000010000000500000019CBF44BC4633D40897AC1A739F94D4019CBF44BC4633D40D976DA1A11FC4D40D4F36E2C28683D40D976DA1A11FC4D40D4F36E2C28683D40897AC1A739F94D4019CBF44BC4633D40897AC1A739F94D40
58921	Лаголово	3	29	356	30.006578000000001	30.046122	59.708505000000002	59.698450000000001	0103000020E6100000010000000500000083DF8618AF013E4013F241CF66D94D4083DF8618AF013E40B806B64AB0DA4D4049A0C1A6CE0B3E40B806B64AB0DA4D4049A0C1A6CE0B3E4013F241CF66D94D4083DF8618AF013E4013F241CF66D94D40
3056	Копорье	3	29	356	29.026588	29.054839999999999	59.714210000000001	59.701723000000001	0103000020E610000001000000050000004F779E78CE063D40EEEC2B0FD2D94D404F779E78CE063D40F33CB83B6BDB4D403C8386FE090E3D40F33CB83B6BDB4D403C8386FE090E3D40EEEC2B0FD2D94D404F779E78CE063D40EEEC2B0FD2D94D40
2942	Кипень	3	29	356	29.839303000000001	29.858644000000002	59.680520000000001	59.669502000000001	0103000020E61000000100000005000000486FB88FDCD63D40A54DD53DB2D54D40486FB88FDCD63D40102384471BD74D4019E8DA17D0DB3D40102384471BD74D4019E8DA17D0DB3D40A54DD53DB2D54D40486FB88FDCD63D40A54DD53DB2D54D40
2980	Келози	3	29	356	29.808247999999999	29.836707000000001	59.669784	59.655557999999999	0103000020E61000000100000005000000B20E4757E9CE3D40CA501553E9D34D40B20E4757E9CE3D4029B16B7BBBD54D409355116E32D63D4029B16B7BBBD54D409355116E32D63D40CA501553E9D34D40B20E4757E9CE3D40CA501553E9D34D40
2833	Гостилицы	3	29	356	29.550108000000002	29.648752000000002	59.759532999999998	59.724814000000002	0103000020E610000001000000050000009A44BDE0D38C3D406BD784B4C6DC4D409A44BDE0D38C3D40CB9D996038E14D40F0366F9C14A63D40CB9D996038E14D40F0366F9C14A63D406BD784B4C6DC4D409A44BDE0D38C3D406BD784B4C6DC4D40
32515	Горбунки	3	29	356	29.968471999999998	29.989384000000001	59.819698000000002	59.811165000000003	0103000020E610000001000000050000007A17EFC7EDF73D4076543541D4E74D407A17EFC7EDF73D405E4C33DDEBE84D40882F134548FD3D405E4C33DDEBE84D40882F134548FD3D4076543541D4E74D407A17EFC7EDF73D4076543541D4E74D40
2286	Гора-Валдай	3	29	356	29.194699	29.206071000000001	59.973292999999998	59.964210000000001	0103000020E610000001000000050000005C902DCBD7313D40F33CB83B6BFB4D405C902DCBD7313D407E3672DD94FC4D406EA7AD11C1343D407E3672DD94FC4D406EA7AD11C1343D40F33CB83B6BFB4D405C902DCBD7313D40F33CB83B6BFB4D40
3218	Глобицы	3	29	356	29.203206000000002	29.237818000000001	59.747366999999997	59.739341000000003	0103000020E61000000100000005000000DA59F44E05343D40C5CBD3B9A2DE4D40DA59F44E05343D40088ECBB8A9DF4D406F66F4A3E13C3D40088ECBB8A9DF4D406F66F4A3E13C3D40C5CBD3B9A2DE4D40DA59F44E05343D40C5CBD3B9A2DE4D40
2869	Виллози	3	29	356	30.087174999999998	30.121175999999998	59.704310999999997	59.690607999999997	0103000020E610000001000000050000005F07CE1951163E40902DCBD765D84D405F07CE1951163E40459BE3DC26DA4D40620FED63051F3E40459BE3DC26DA4D40620FED63051F3E40902DCBD765D84D405F07CE1951163E40902DCBD765D84D40
2178	Большая Ижора	3	29	356	29.451338	29.589410000000001	59.954839999999997	59.926436000000002	0103000020E610000001000000050000002A711DE38A733D4025EB707495F64D402A711DE38A733D40D174763238FA4D4074EFE192E3963D40D174763238FA4D4074EFE192E3963D4025EB707495F64D402A711DE38A733D4025EB707495F64D40
2410	Аннино	3	29	356	30.024885999999999	30.082100000000001	59.784928999999998	59.764273000000003	0103000020E61000000100000005000000D520CCED5E063E40A01B9AB2D3E14D40D520CCED5E063E404B57B08D78E44D4069006F8104153E404B57B08D78E44D4069006F8104153E40A01B9AB2D3E14D40D520CCED5E063E40A01B9AB2D3E14D40
1933	Яровщина	3	29	225	33.532960000000003	33.548321000000001	60.477179999999997	60.470041000000002	0103000020E61000000100000005000000C009850838C44040BB63B14D2A3C4E40C009850838C440401327F73B143D4E40E25AED612FC640401327F73B143D4E40E25AED612FC64040BB63B14D2A3C4E40C009850838C44040BB63B14D2A3C4E40
1354	Янега	3	29	225	33.696049000000002	33.715407999999996	60.751309999999997	60.739913000000001	0103000020E61000000100000005000000EEB4352218D9404050711C78B55E4E40EEB4352218D94040319413ED2A604E40FCA5457D92DB4040319413ED2A604E40FCA5457D92DB404050711C78B55E4E40EEB4352218D9404050711C78B55E4E40
1888	Шархиничи	3	29	225	33.745842000000003	33.766404999999999	60.395386999999999	60.386806999999997	0103000020E61000000100000005000000DBFD2AC077DF4040936E4BE482314E40DBFD2AC077DF4040BC218D0A9C324E40D53E1D8F19E24040BC218D0A9C324E40D53E1D8F19E24040936E4BE482314E40DBFD2AC077DF4040936E4BE482314E40
8074	Шамокша	3	29	225	33.348230000000001	33.355362999999997	60.661628999999998	60.658701000000001	0103000020E6100000010000000500000038BEF6CC92AC4040D76B7A5050544E4038BEF6CC92AC4040E78A5242B0544E40AE9AE7887CAD4040E78A5242B0544E40AE9AE7887CAD4040D76B7A5050544E4038BEF6CC92AC4040D76B7A5050544E40
1329	Харевщина	3	29	225	33.675396999999997	33.682772	60.756580999999997	60.753095000000002	0103000020E610000001000000050000008368AD6873D64040FCE3BD6A65604E408368AD6873D6404032E36DA5D7604E40F04FA91265D7404032E36DA5D7604E40F04FA91265D74040FCE3BD6A65604E408368AD6873D64040FCE3BD6A65604E40
1444	Тервеничи	3	29	225	34.090975	34.111635999999997	60.329382000000003	60.318778999999999	0103000020E6100000010000000500000076E09C11A50B414067D311C0CD284E4076E09C11A50B41400FF27A30292A4E403387A4164A0E41400FF27A30292A4E403387A4164A0E414067D311C0CD284E4076E09C11A50B414067D311C0CD284E40
1209	Старая Слобода	3	29	225	33.308965000000001	33.322035	60.784230000000001	60.772286000000001	0103000020E61000000100000005000000E84D452A8CA740404F948444DA624E40E84D452A8CA7404063450DA661644E406C95607138A9404063450DA661644E406C95607138A940404F948444DA624E40E84D452A8CA740404F948444DA624E40
59060	Свирьстрой	3	29	225	33.703577000000003	33.739607999999997	60.818821999999997	60.784923999999997	0103000020E61000000100000005000000E19BA6CF0EDA404039ECBE6378644E40E19BA6CF0EDA4040669FC728CF684E4013EE9579ABDE4040669FC728CF684E4013EE9579ABDE404039ECBE6378644E40E19BA6CF0EDA404039ECBE6378644E40
1597	Ребовичи	3	29	225	34.334823	34.359769	60.219630000000002	60.213524999999997	0103000020E610000001000000050000006C79E57ADB2A41406FF085C9541B4E406C79E57ADB2A4140399CF9D51C1C4E40AC8E1CE90C2E4140399CF9D51C1C4E40AC8E1CE90C2E41406FF085C9541B4E406C79E57ADB2A41406FF085C9541B4E40
2064	Рассвет	3	29	225	33.14875	33.176229999999997	60.464568	60.452233999999997	0103000020E61000000100000005000000D7A3703D0A934040D311C0CDE2394E40D7A3703D0A9340405262D7F6763B4E407B4963B48E9640405262D7F6763B4E407B4963B48E964040D311C0CDE2394E40D7A3703D0A934040D311C0CDE2394E40
59009	Пирозерово	3	29	225	32.825087000000003	34.647077000000003	61.006005999999999	60.138966000000003	0103000020E6100000010000000500000069AD68739C694040C3A04CA3C9114E4069AD68739C69404036CAFACDC4804E40357F4C6BD352414036CAFACDC4804E40357F4C6BD3524140C3A04CA3C9114E4069AD68739C694040C3A04CA3C9114E40
58978	Надпорожье	3	29	225	34.273935000000002	34.291559999999997	60.475561999999996	60.468798999999997	0103000020E61000000100000005000000691D554D10234140E1B20A9B013C4E40691D554D10234140349C3237DF3C4E402F698CD651254140349C3237DF3C4E402F698CD651254140E1B20A9B013C4E40691D554D10234140E1B20A9B013C4E40
59074	Лодейное Поле	3	29	225	32.825087000000003	34.647077000000003	61.006005999999999	60.138966000000003	0103000020E6100000010000000500000069AD68739C694040C3A04CA3C9114E4069AD68739C69404036CAFACDC4804E40357F4C6BD352414036CAFACDC4804E40357F4C6BD3524140C3A04CA3C9114E4069AD68739C694040C3A04CA3C9114E40
2031	Имоченицы	3	29	225	33.508490000000002	33.535294999999998	60.487119	60.479987000000001	0103000020E61000000100000005000000E92B483316C14040A9C0C936703D4E40E92B483316C140404F2157EA593E4E402D5BEB8B84C440404F2157EA593E4E402D5BEB8B84C44040A9C0C936703D4E40E92B483316C14040A9C0C936703D4E40
2145	Доможирово	3	29	225	33.086210000000001	33.093440999999999	60.473641999999998	60.465291000000001	0103000020E61000000100000005000000494BE5ED088B4040C30FCEA78E3B4E40494BE5ED088B40408A01124DA03C4E40828DEBDFF58B40408A01124DA03C4E40828DEBDFF58B4040C30FCEA78E3B4E40494BE5ED088B4040C30FCEA78E3B4E40
1473	Вонозеро	3	29	225	34.410406999999999	34.427475000000001	60.370404999999998	60.364941999999999	0103000020E610000001000000050000005586713788344140EA77616BB62E4E4055867137883441402FA3586E692F4E40C66D3480B73641402FA3586E692F4E40C66D3480B7364140EA77616BB62E4E405586713788344140EA77616BB62E4E40
58451	Анисимово	3	29	225	34.348000999999996	34.349375999999999	60.339669000000001	60.339055000000002	0103000020E61000000100000005000000D6FCF84B8B2C4140CC457C27662B4E40D6FCF84B8B2C4140863B17467A2B4E40EF004F5AB82C4140863B17467A2B4E40EF004F5AB82C4140CC457C27662B4E40D6FCF84B8B2C4140CC457C27662B4E40
1256	Андреевщина	3	29	225	33.402470000000001	33.434199	60.845211999999997	60.821247999999997	0103000020E6100000010000000500000081CF0F2384B34040E4F38AA71E694E4081CF0F2384B34040E71725E82F6C4E405B7A34D593B74040E71725E82F6C4E405B7A34D593B74040E4F38AA71E694E4081CF0F2384B34040E4F38AA71E694E40
1700	Алёховщина	3	29	225	33.813305999999997	33.886733999999997	60.415939000000002	60.397392000000004	0103000020E61000000100000005000000FED137691AE8404095D8B5BDDD324E40FED137691AE84040C310397D3D354E402920ED7F80F14040C310397D3D354E402920ED7F80F1404095D8B5BDDD324E40FED137691AE8404095D8B5BDDD324E40
58946	ст.Новый Быт	3	29	69	31.858608	31.990409	59.924695	59.858466999999997	0103000020E610000001000000050000007F15E0BBCDDB3F40FDD8243FE2ED4D407F15E0BBCDDB3F402AE3DF675CF64D4000AAB8718BFD3F402AE3DF675CF64D4000AAB8718BFD3F40FDD8243FE2ED4D407F15E0BBCDDB3F40FDD8243FE2ED4D40
9443	ской посёлок Назия	3	29	69	31.563780999999999	31.630597000000002	59.860512999999997	59.831707000000002	0103000020E610000001000000050000002E1B9DF353903F40596DFE5F75EA4D402E1B9DF353903F4034643C4A25EE4D40AAF413CE6EA13F4034643C4A25EE4D40AAF413CE6EA13F40596DFE5F75EA4D402E1B9DF353903F40596DFE5F75EA4D40
12357	ской посёлок Мга	3	29	69	31.029606999999999	31.082329000000001	59.762664000000001	59.733750000000001	0103000020E6100000010000000500000090BB085394073F4052B81E85EBDD4D4090BB085394073F4014EB54F99EE14D402C836A8313153F4014EB54F99EE14D402C836A8313153F4052B81E85EBDD4D4090BB085394073F4052B81E85EBDD4D40
11450	имени Морозова	3	29	69	30.960688000000001	31.060894999999999	60.007843000000001	59.961215000000003	0103000020E61000000100000005000000DFA815A6EFF53E405BB6D61709FB4D40DFA815A6EFF53E405340DAFF00014E406B7D91D0960F3F405340DAFF00014E406B7D91D0960F3F405BB6D61709FB4D40DFA815A6EFF53E405BB6D61709FB4D40
9510	Шум	3	29	69	31.766504000000001	31.795940999999999	59.879593	59.867981	0103000020E61000000100000005000000D1402C9B39C43F4052465C001AEF4D40D1402C9B39C43F403065E08096F04D40A88B14CAC2CB3F403065E08096F04D40A88B14CAC2CB3F4052465C001AEF4D40D1402C9B39C43F4052465C001AEF4D40
12703	Шлиссельбург	3	29	69	30.991392000000001	31.064596000000002	59.950105000000001	59.924055000000003	0103000020E610000001000000050000001B84B9DDCBFD3E40475A2A6F47F64D401B84B9DDCBFD3E400F62670A9DF94D40D2730B5D89103F400F62670A9DF94D40D2730B5D89103F40475A2A6F47F64D401B84B9DDCBFD3E40475A2A6F47F64D40
223	Сухое	3	29	69	31.726996	31.735223999999999	60.021509999999999	60.006165000000003	0103000020E61000000100000005000000A452EC681CBA3F409FB0C403CA004E40A452EC681CBA3F40BB44F5D6C0024E40FB3BDBA337BC3F40BB44F5D6C0024E40FB3BDBA337BC3F409FB0C403CA004E40A452EC681CBA3F409FB0C403CA004E40
12430	Старая Малукса	3	29	69	31.364578999999999	31.388276999999999	59.644213000000001	59.633043000000001	0103000020E61000000100000005000000F2CEA10C555D3F401AFB928D07D14D40F2CEA10C555D3F403B54539275D24D40FBC9181F66633F403B54539275D24D40FBC9181F66633F401AFB928D07D14D40F2CEA10C555D3F401AFB928D07D14D40
59005	Сологубовка	3	29	69	31.154257000000001	31.171792	59.732506999999998	59.724741000000002	0103000020E61000000100000005000000D82D02637D273F4001892650C4DC4D40D82D02637D273F40A88B14CAC2DD4D40E5B67D8FFA2B3F40A88B14CAC2DD4D40E5B67D8FFA2B3F4001892650C4DC4D40D82D02637D273F4001892650C4DC4D40
12877	Синявино-2	3	29	69	31.201741999999999	31.221568000000001	59.877457	59.868296999999998	0103000020E61000000100000005000000C93A1C5DA5333F40821B295B24EF4D40C93A1C5DA5333F40B952CF8250F04D4013D731AEB8383F40B952CF8250F04D4013D731AEB8383F40821B295B24EF4D40C93A1C5DA5333F40821B295B24EF4D40
59041	Синявино	3	29	69	31.04654	31.086739000000001	59.914848999999997	59.903782999999997	0103000020E61000000100000005000000B2F4A10BEA0B3F4023D74D29AFF34D40B2F4A10BEA0B3F409FE3A3C519F54D40AA49F08634163F409FE3A3C519F54D40AA49F08634163F4023D74D29AFF34D40B2F4A10BEA0B3F4023D74D29AFF34D40
12960	Путилово	3	29	69	31.421289999999999	31.461112	59.872819	59.863422999999997	0103000020E61000000100000005000000C02154A9D96B3F409ECE15A584EE4D40C02154A9D96B3F40E9297288B8EF4D400CCB9F6F0B763F40E9297288B8EF4D400CCB9F6F0B763F409ECE15A584EE4D40C02154A9D96B3F409ECE15A584EE4D40
58947	Приладожский	3	29	69	31.319717000000001	31.332194999999999	59.879407999999998	59.874972999999997	0103000020E61000000100000005000000A9F92AF9D8513F4006F1811DFFEF4D40A9F92AF9D8513F409EEBFB7090F04D400CE544BB0A553F409EEBFB7090F04D400CE544BB0A553F4006F1811DFFEF4D40A9F92AF9D8513F4006F1811DFFEF4D40
58963	Павлово	3	29	69	30.855063999999999	30.933316000000001	59.815767000000001	59.801774999999999	0103000020E61000000100000005000000A8FC6B79E5DA3E400DE02D90A0E64D40A8FC6B79E5DA3E40F913950D6BE84D4063D520CCEDEE3E40F913950D6BE84D4063D520CCEDEE3E400DE02D90A0E64D40A8FC6B79E5DA3E400DE02D90A0E64D40
14697	Отрадное	3	29	69	30.744553	30.850059999999999	59.798679	59.745992999999999	0103000020E61000000100000005000000812381069BBE3E40C005D9B27CDF4D40812381069BBE3E4041800C1D3BE64D4044A33B889DD93E4041800C1D3BE64D4044A33B889DD93E40C005D9B27CDF4D40812381069BBE3E40C005D9B27CDF4D40
28422	Назия	3	29	69	31.328565999999999	31.356242999999999	59.902884999999998	59.893433999999999	0103000020E61000000100000005000000D993C0E61C543F403691990B5CF24D40D993C0E61C543F40448655BC91F34D40CE6DC2BD325B3F40448655BC91F34D40CE6DC2BD325B3F403691990B5CF24D40D993C0E61C543F403691990B5CF24D40
58956	Назия	3	29	69	31.328565999999999	31.356242999999999	59.902884999999998	59.893433999999999	0103000020E61000000100000005000000D993C0E61C543F403691990B5CF24D40D993C0E61C543F40448655BC91F34D40CE6DC2BD325B3F40448655BC91F34D40CE6DC2BD325B3F403691990B5CF24D40D993C0E61C543F403691990B5CF24D40
12456	Молодцово	3	29	69	31.094833000000001	31.109439999999999	59.829360000000001	59.823397999999997	0103000020E61000000100000005000000E294B9F946183F40C0CB0C1B65E94D40E294B9F946183F40274EEE7728EA4D40CEDF8442041C3F40274EEE7728EA4D40CEDF8442041C3F40C0CB0C1B65E94D40E294B9F946183F40C0CB0C1B65E94D40
59014	Мга	3	29	69	31.029606999999999	31.082329000000001	59.762664000000001	59.733750000000001	0103000020E6100000010000000500000090BB085394073F4052B81E85EBDD4D4090BB085394073F4014EB54F99EE14D402C836A8313153F4014EB54F99EE14D402C836A8313153F4052B81E85EBDD4D4090BB085394073F4052B81E85EBDD4D40
277	Лаврово	3	29	69	31.570499999999999	31.597351	59.957389999999997	59.938743000000002	0103000020E61000000100000005000000355EBA490C923F40AA2C0ABB28F84D40355EBA490C923F403BC269C18BFA4D409F3BC1FEEB983F403BC269C18BFA4D409F3BC1FEEB983F40AA2C0ABB28F84D40355EBA490C923F40AA2C0ABB28F84D40
84	Концы	3	29	69	31.731342999999999	31.746569999999998	59.882522999999999	59.876801999999998	0103000020E6100000010000000500000095287B4B39BB3F40A088450C3BF04D4095287B4B39BB3F40E17B7F83F6F04D40BA2C26361FBF3F40E17B7F83F6F04D40BA2C26361FBF3F40A088450C3BF04D4095287B4B39BB3F40A088450C3BF04D40
12502	Кировск	3	29	69	30.944644	31.020883999999999	59.907626999999998	59.845179999999999	0103000020E61000000100000005000000D55C6E30D4F13E40DC9DB5DB2EEC4D40D55C6E30D4F13E40B9FB1C1F2DF44D40790261A758053F40B9FB1C1F2DF44D40790261A758053F40DC9DB5DB2EEC4D40D55C6E30D4F13E40DC9DB5DB2EEC4D40
14845	Горы	3	29	69	30.963329000000002	30.976094	59.759664000000001	59.755445000000002	0103000020E61000000100000005000000D449B6BA9CF63E409F76F86BB2E04D40D449B6BA9CF63E406AF981AB3CE14D4063D2DF4BE1F93E406AF981AB3CE14D4063D2DF4BE1F93E409F76F86BB2E04D40D449B6BA9CF63E409F76F86BB2E04D40
128	Горка	3	29	69	31.780787	31.791917000000002	59.911926000000001	59.903629000000002	0103000020E61000000100000005000000572426A8E1C73F40CD5B751DAAF34D40572426A8E1C73F40A12FBDFDB9F44D407D259012BBCA3F40A12FBDFDB9F44D407D259012BBCA3F40CD5B751DAAF34D40572426A8E1C73F40CD5B751DAAF34D40
14403	Тихорицы	3	29	1304	32.072101000000004	32.092843999999999	59.625317000000003	59.602649999999997	0103000020E610000001000000050000002481069B3A0940409A779CA223CD4D402481069B3A094040015130630AD04D409ED0EB4FE20B4040015130630AD04D409ED0EB4FE20B40409A779CA223CD4D402481069B3A0940409A779CA223CD4D40
30155	Среднее Село	3	29	1304	32.674557	32.687043000000003	59.249473000000002	59.243476999999999	0103000020E61000000100000005000000D9243FE257564040022A1C412A9F4D40D9243FE257564040151E34BBEE9F4D400EF96706F1574040151E34BBEE9F4D400EF96706F1574040022A1C412A9F4D40D9243FE257564040022A1C412A9F4D40
14375	Пчевжа	3	29	1304	32.319344999999998	32.369767000000003	59.364702999999999	59.35087	0103000020E610000001000000050000001092054CE0284040E292E34EE9AC4D401092054CE028404065E08096AEAE4D40ED116A86542F404065E08096AEAE4D40ED116A86542F4040E292E34EE9AC4D401092054CE0284040E292E34EE9AC4D40
59025	Пчева	3	29	1304	32.101737	32.109336999999996	59.565142000000002	59.556749000000003	0103000020E6100000010000000500000086E5CFB7050D4040558A1D8D43C74D4086E5CFB7050D40404BCCB39256C84D40129F3BC1FE0D40404BCCB39256C84D40129F3BC1FE0D4040558A1D8D43C74D4086E5CFB7050D4040558A1D8D43C74D40
30484	Мотохово	3	29	1304	32.373126999999997	32.387976000000002	59.529038	59.520403999999999	0103000020E61000000100000005000000962023A0C22F4040925A28999CC24D40962023A0C22F4040AE2B6684B7C34D4003D19332A9314040AE2B6684B7C34D4003D19332A9314040925A28999CC24D40962023A0C22F4040925A28999CC24D40
30228	Могилёво	3	29	1304	32.471150999999999	32.480718000000003	59.317878999999998	59.313488999999997	0103000020E61000000100000005000000253D0CAD4E3C4040EF53556820A84D40253D0CAD4E3C4040E78A5242B0A84D409D4CDC2A883D4040E78A5242B0A84D409D4CDC2A883D4040EF53556820A84D40253D0CAD4E3C4040EF53556820A84D40
14502	Кусино	3	29	1304	31.796866999999999	31.821650999999999	59.383851	59.371758999999997	0103000020E61000000100000005000000FA42C879FFCB3F40307F85CC95AF4D40FA42C879FFCB3F40B9C4910722B14D40C7B94DB857D23F40B9C4910722B14D40C7B94DB857D23F40307F85CC95AF4D40FA42C879FFCB3F40307F85CC95AF4D40
30206	Кукуй	3	29	1304	32.519677999999999	32.545675000000003	59.355699999999999	59.348300999999999	0103000020E61000000100000005000000B03907CF8442404001158E2095AC4D40B03907CF84424040F697DD9387AD4D40569FABADD8454040F697DD9387AD4D40569FABADD845404001158E2095AC4D40B03907CF8442404001158E2095AC4D40
13736	Кириши	3	29	1304	31.984031000000002	32.104422999999997	59.514085999999999	59.430062	0103000020E610000001000000050000000C40A374E9FB3F404DA088450CB74D400C40A374E9FB3F406DAAEE91CDC14D40A0F99CBB5D0D40406DAAEE91CDC14D40A0F99CBB5D0D40404DA088450CB74D400C40A374E9FB3F404DA088450CB74D40
58991	Гремячево	3	29	1304	32.397677999999999	32.407091999999999	59.222104000000002	59.210718	0103000020E610000001000000050000005A2BDA1CE7324040DA56B3CEF89A4D405A2BDA1CE7324040C82764E76D9C4D404B3B35971B344040C82764E76D9C4D404B3B35971B344040DA56B3CEF89A4D405A2BDA1CE7324040DA56B3CEF89A4D40
58971	Городище	3	29	1304	32.114978000000001	32.134219999999999	59.635854000000002	59.623311000000001	0103000020E6100000010000000500000037E15E99B70E4040581EA4A7C8CF4D4037E15E99B70E4040F183F3A963D14D400C3CF71E2E114040F183F3A963D14D400C3CF71E2E114040581EA4A7C8CF4D4037E15E99B70E4040581EA4A7C8CF4D40
21471	Глажево	3	29	1304	32.112597000000001	32.121822999999999	59.655371000000002	59.648679000000001	0103000020E6100000010000000500000059501894690E40400E4DD9E907D34D4059501894690E404098DF6932E3D34D40477364E5970F404098DF6932E3D34D40477364E5970F40400E4DD9E907D34D4059501894690E40400E4DD9E907D34D40
59033	Будогощь	3	29	1304	32.405520000000003	32.494759000000002	59.293869000000001	59.276145	0103000020E61000000100000005000000DDEF5014E83340401AFA27B858A34D40DDEF5014E83340407427D87F9DA54D406A334E43543F40407427D87F9DA54D406A334E43543F40401AFA27B858A34D40DDEF5014E83340401AFA27B858A34D40
28993	Фалилеево	3	29	1405	28.922698	28.936513999999999	59.541260999999999	59.529339999999998	0103000020E61000000100000005000000A915A6EF35EC3C40793BC269C1C34D40A915A6EF35EC3C40D5CC5A0A48C54D40033FAA61BFEF3C40D5CC5A0A48C54D40033FAA61BFEF3C40793BC269C1C34D40A915A6EF35EC3C40793BC269C1C34D40
15830	Усть-Луга	3	29	1405	28.245072	28.295449000000001	59.670769999999997	59.644218000000002	0103000020E61000000100000005000000522AE109BD3E3C404DBF44BC75D24D40522AE109BD3E3C40A79196CADBD54D40CBA2B08BA24B3C40A79196CADBD54D40CBA2B08BA24B3C404DBF44BC75D24D40522AE109BD3E3C404DBF44BC75D24D40
15625	Ополье	3	29	1405	28.820343999999999	28.844149000000002	59.444049999999997	59.433554000000001	0103000020E6100000010000000500000046787B1002D23C4066868DB27EB74D4046787B1002D23C40F7E461A1D6B84D407CF31B261AD83C40F7E461A1D6B84D407CF31B261AD83C4066868DB27EB74D4046787B1002D23C4066868DB27EB74D40
15933	Нежново	3	29	1405	28.761855000000001	28.790178000000001	59.690876000000003	59.687420000000003	0103000020E61000000100000005000000494BE5ED08C33C40E44EE960FDD74D40494BE5ED08C33C40B0CBF09F6ED84D40C904FC1A49CA3C40B0CBF09F6ED84D40C904FC1A49CA3C40E44EE960FDD74D40494BE5ED08C33C40E44EE960FDD74D40
59049	Кошкино	3	29	1405	28.370512000000002	28.398675000000001	59.435676999999998	59.423718000000001	0103000020E610000001000000050000008BC6DADFD95E3C40FF5C34643CB64D408BC6DADFD95E3C40484F9143C4B74D4099BB96900F663C40484F9143C4B74D4099BB96900F663C40FF5C34643CB64D408BC6DADFD95E3C40FF5C34643CB64D40
15995	Котлы	3	29	1405	28.740834	28.769203000000001	59.610795000000003	59.595336000000003	0103000020E61000000100000005000000CEC3094CA7BD3C40D41055F833CC4D40CEC3094CA7BD3C40B9C7D2872ECE4D402FFCE07CEAC43C40B9C7D2872ECE4D402FFCE07CEAC43C40D41055F833CC4D40CEC3094CA7BD3C40D41055F833CC4D40
24397	Котельский	3	29	1405	28.740905999999999	28.765115000000002	59.587510999999999	59.576900000000002	0103000020E610000001000000050000000169FF03ACBD3C40FD87F4DBD7C94D400169FF03ACBD3C402785798F33CB4D40D6AD9E93DEC33C402785798F33CB4D40D6AD9E93DEC33C40FD87F4DBD7C94D400169FF03ACBD3C40FD87F4DBD7C94D40
16084	Кингисеппский	3	29	1405	28.562518000000001	28.573181000000002	59.402137000000003	59.399503000000003	0103000020E610000001000000050000004D69FD2D01903C40B3D30FEA22B34D404D69FD2D01903C407BC1A73979B34D4047B071FDBB923C407BC1A73979B34D4047B071FDBB923C40B3D30FEA22B34D404D69FD2D01903C40B3D30FEA22B34D40
15461	Кингисепп	3	29	1405	28.559616999999999	28.664369000000001	59.398297999999997	59.327373999999999	0103000020E610000001000000050000001F49490F438F3C40C5C72764E7A94D401F49490F438F3C40F607CA6DFBB24D40EA79371614AA3C40F607CA6DFBB24D40EA79371614AA3C40C5C72764E7A94D401F49490F438F3C40C5C72764E7A94D40
59070	Кингисеп	3	29	1405	28.559616999999999	28.664369000000001	59.398297999999997	59.327373999999999	0103000020E610000001000000050000001F49490F438F3C40C5C72764E7A94D401F49490F438F3C40F607CA6DFBB24D40EA79371614AA3C40F607CA6DFBB24D40EA79371614AA3C40C5C72764E7A94D401F49490F438F3C40C5C72764E7A94D40
15739	Ивановское	3	29	1405	28.865034999999999	28.885579	59.294373999999998	59.277597999999998	0103000020E6100000010000000500000036E50AEF72DD3C40AEB7CD5488A34D4036E50AEF72DD3C407765170CAEA54D403E062B4EB5E23C407765170CAEA54D403E062B4EB5E23C40AEB7CD5488A34D4036E50AEF72DD3C40AEB7CD5488A34D40
16226	Ивангород	3	29	1405	28.191685	28.238218	59.387334000000003	59.341776000000003	0103000020E610000001000000050000003E22A64412313C406347E350BFAB4D403E22A64412313C407F50172994B14D408B51D7DAFB3C3C407F50172994B14D408B51D7DAFB3C3C406347E350BFAB4D403E22A64412313C406347E350BFAB4D40
19171	Захонье-2	3	29	1405	28.253775999999998	28.262848999999999	59.387036000000002	59.383274	0103000020E610000001000000050000007B82C476F7403C401CB4571F0FB14D407B82C476F7403C40F52F49658AB14D404BC972124A433C40F52F49658AB14D404BC972124A433C401CB4571F0FB14D407B82C476F7403C401CB4571F0FB14D40
15907	Вистино	3	29	1405	28.471841999999999	28.486098999999999	59.786490999999998	59.772917	0103000020E6100000010000000500000015E126A3CA783C40DFC2BAF1EEE24D4015E126A3CA783C4096CCB1BCABE44D40499EEBFB707C3C4096CCB1BCABE44D40499EEBFB707C3C40DFC2BAF1EEE24D4015E126A3CA783C40DFC2BAF1EEE24D40
24353	Большое Кузёмкино	3	29	1405	28.175362	28.198135000000001	59.595140999999998	59.570990000000002	0103000020E610000001000000050000000EF62686E42C3C40E92B483316C94D400EF62686E42C3C401EC18D942DCC4D406631B1F9B8323C401EC18D942DCC4D406631B1F9B8323C40E92B483316C94D400EF62686E42C3C40E92B483316C94D40
24284	Большая Пустомержа	3	29	1405	28.862448000000001	28.893547999999999	59.391815000000001	59.380533	0103000020E6100000010000000500000028806264C9DC3C403E062B4EB5B04D4028806264C9DC3C40878A71FE26B24D40FD67CD8FBFE43C40878A71FE26B24D40FD67CD8FBFE43C403E062B4EB5B04D4028806264C9DC3C403E062B4EB5B04D40
24264	Алексеевка	3	29	1405	28.753204	28.786396	59.438043	59.428125999999999	0103000020E61000000100000005000000653733FAD1C03C409D4830D5CCB64D40653733FAD1C03C40F19E03CB11B84D4089B48D3F51C93C40F19E03CB11B84D4089B48D3F51C93C409D4830D5CCB64D40653733FAD1C03C409D4830D5CCB64D40
59016	п. Др.Горка	3	29	120	29.576591000000001	30.686091000000001	59.622655000000002	59.013782999999997	0103000020E61000000100000005000000FE2AC0779B933D40D11E2FA4C3814D40FE2AC0779B933D406FD8B628B3CF4D407714E7A8A3AF3E406FD8B628B3CF4D407714E7A8A3AF3E40D11E2FA4C3814D40FE2AC0779B933D40D11E2FA4C3814D40
19042	Шпаньково	3	29	120	29.830562	29.856703	59.501666	59.491886999999998	0103000020E61000000100000005000000E44C13B69FD43D40ED293927F6BE4D40E44C13B69FD43D40F0C16B9736C04D40956247E350DB3D40F0C16B9736C04D40956247E350DB3D40ED293927F6BE4D40E44C13B69FD43D40ED293927F6BE4D40
19037	Черново	3	29	120	29.975055999999999	29.993202	59.561267000000001	59.553229000000002	0103000020E61000000100000005000000C1C41F459DF93D4072193735D0C64D40C1C41F459DF93D407AA9D898D7C74D4061527C7C42FE3D407AA9D898D7C74D4061527C7C42FE3D4072193735D0C64D40C1C41F459DF93D4072193735D0C64D40
47677	Чаща	3	29	120	30.265895	30.273098999999998	59.158695000000002	59.156204000000002	0103000020E61000000100000005000000802BD9B111443E4090C01F7EFE934D40802BD9B111443E40F584251E50944D40FF91E9D0E9453E40F584251E50944D40FF91E9D0E9453E4090C01F7EFE934D40802BD9B111443E4090C01F7EFE934D40
3851	Торфяное	3	29	120	30.164484000000002	30.177420000000001	59.553638999999997	59.540590999999999	0103000020E610000001000000050000001CB7989F1B2A3E4087C1FC1532C54D401CB7989F1B2A3E4023658BA4DDC64D4005A8A9656B2D3E4023658BA4DDC64D4005A8A9656B2D3E4087C1FC1532C54D401CB7989F1B2A3E4087C1FC1532C54D40
18800	Тихковицы	3	29	120	29.945609000000001	29.961312	59.423141000000001	59.409511000000002	0103000020E61000000100000005000000A3CD716E13F23D40172D40DB6AB44D40A3CD716E13F23D40624CFA7B29B64D409A40118B18F63D40624CFA7B29B64D409A40118B18F63D40172D40DB6AB44D40A3CD716E13F23D40172D40DB6AB44D40
27090	Терволово	3	29	120	29.873474999999999	29.918237999999999	59.675049999999999	59.662613	0103000020E61000000100000005000000A4DFBE0E9CDF3D40C573B680D0D44D40A4DFBE0E9CDF3D401895D40968D64D40C7F143A511EB3D401895D40968D64D40C7F143A511EB3D40C573B680D0D44D40A4DFBE0E9CDF3D40C573B680D0D44D40
25821	Тайцы	3	29	120	30.121642999999999	30.150551	59.655217	59.623606000000002	0103000020E610000001000000050000008EC9E2FE231F3E4071CB4752D2CF4D408EC9E2FE231F3E4041649126DED34D404E61A5828A263E4041649126DED34D404E61A5828A263E4071CB4752D2CF4D408EC9E2FE231F3E4071CB4752D2CF4D40
59055	Тайцы	3	29	120	30.121642999999999	30.150551	59.655217	59.623606000000002	0103000020E610000001000000050000008EC9E2FE231F3E4071CB4752D2CF4D408EC9E2FE231F3E4041649126DED34D404E61A5828A263E4041649126DED34D404E61A5828A263E4071CB4752D2CF4D408EC9E2FE231F3E4071CB4752D2CF4D40
27167	Сяськелево	3	29	120	29.815327	29.857637	59.556443000000002	59.541443999999998	0103000020E61000000100000005000000B98B3045B9D03D40C64E78094EC54D40B98B3045B9D03D40488B338639C74D40EDD632198EDB3D40488B338639C74D40EDD632198EDB3D40C64E78094EC54D40B98B3045B9D03D40C64E78094EC54D40
18770	Сусанино	3	29	120	30.333987	30.391255000000001	59.497368000000002	59.485444999999999	0103000020E61000000100000005000000064A0A2C80553E40DC80CF0F23BE4D40064A0A2C80553E40D9092FC1A9BF4D408065A54929643E40D9092FC1A9BF4D408065A54929643E40DC80CF0F23BE4D40064A0A2C80553E40DC80CF0F23BE4D40
3726	Суйда	3	29	120	30.118058999999999	30.125093	59.468826999999997	59.460180999999999	0103000020E610000001000000050000009BFF571D391E3E40CB9E0436E7BA4D409BFF571D391E3E40AB3DEC8502BC4D4062F5471806203E40AB3DEC8502BC4D4062F5471806203E40CB9E0436E7BA4D409BFF571D391E3E40CB9E0436E7BA4D40
19375	Старые Низковицы	3	29	120	29.699884000000001	29.729914999999998	59.608414000000003	59.600692000000002	0103000020E6100000010000000500000061FE0A992BB33D40037CB779E3CC4D4061FE0A992BB33D40DB368C82E0CD4D401EDC9DB5DBBA3D40DB368C82E0CD4D401EDC9DB5DBBA3D40037CB779E3CC4D4061FE0A992BB33D40037CB779E3CC4D40
59010	Сиверский-2	3	29	120	29.576591000000001	30.686091000000001	59.622655000000002	59.013782999999997	0103000020E61000000100000005000000FE2AC0779B933D40D11E2FA4C3814D40FE2AC0779B933D406FD8B628B3CF4D407714E7A8A3AF3E406FD8B628B3CF4D407714E7A8A3AF3E40D11E2FA4C3814D40FE2AC0779B933D40D11E2FA4C3814D40
357	Сиверский	3	29	120	30.020745000000002	30.127806	59.376559	59.333773000000001	0103000020E61000000100000005000000378E588B4F053E40D7A4DB12B9AA4D40378E588B4F053E40DA01D71533B04D408A3BDEE4B7203E40DA01D71533B04D408A3BDEE4B7203E40D7A4DB12B9AA4D40378E588B4F053E40D7A4DB12B9AA4D40
22048	Семрино	3	29	120	30.368203999999999	30.395655999999999	59.550328	59.526811000000002	0103000020E61000000100000005000000A2410A9E425E3E402716F88A6EC34D40A2410A9E425E3E405B09DD2571C64D4057772CB649653E405B09DD2571C64D4057772CB649653E402716F88A6EC34D40A2410A9E425E3E402716F88A6EC34D40
19124	Рождествено	3	29	120	29.923870000000001	29.957727999999999	59.334162999999997	59.306443000000002	0103000020E610000001000000050000006AC18BBE82EC3D40488B338639A74D406AC18BBE82EC3D4041446ADAC5AA4D40A77686A92DF53D4041446ADAC5AA4D40A77686A92DF53D40488B338639A74D406AC18BBE82EC3D40488B338639A74D40
27032	Пудость	3	29	120	30.035081999999999	30.06222	59.619965999999998	59.611795999999998	0103000020E61000000100000005000000A3AD4A22FB083E406CE9D1544FCE4D40A3AD4A22FB083E40E350BF0B5BCF4D40392861A6ED0F3E40E350BF0B5BCF4D40392861A6ED0F3E406CE9D1544FCE4D40A3AD4A22FB083E406CE9D1544FCE4D40
58951	Пудомяги	3	29	120	30.321059999999999	30.330627	59.607922000000002	59.600062999999999	0103000020E61000000100000005000000C30DF8FC30523E40134548DDCECC4D40C30DF8FC30523E406C425A63D0CD4D40B22C98F8A3543E406C425A63D0CD4D40B22C98F8A3543E40134548DDCECC4D40C30DF8FC30523E40134548DDCECC4D40
3913	Пригородный	3	29	120	30.129799999999999	30.154540000000001	59.543081000000001	59.533454999999996	0103000020E610000001000000050000005305A3923A213E409F71E14048C44D405305A3923A213E401C0A9FAD83C54D4081ECF5EE8F273E401C0A9FAD83C54D4081ECF5EE8F273E409F71E14048C44D405305A3923A213E409F71E14048C44D40
3822	Прибытково	3	29	120	30.082557999999999	30.091100999999998	59.438581999999997	59.427453	0103000020E61000000100000005000000EE05668522153E40DEC9A7C7B6B64D40EE05668522153E40A04E797423B84D4005A2276552173E40A04E797423B84D4005A2276552173E40DEC9A7C7B6B64D40EE05668522153E40DEC9A7C7B6B64D40
23030	Покровская	3	29	120	30.383996	30.412517999999999	59.649583999999997	59.633771000000003	0103000020E6100000010000000500000079CBD58F4D623E409D137B681FD14D4079CBD58F4D623E409F008A9125D34D40E60297C79A693E409F008A9125D34D40E60297C79A693E409D137B681FD14D4079CBD58F4D623E409D137B681FD14D40
26349	Новый Учхоз	3	29	120	29.928720999999999	29.942349	59.546306000000001	59.539983999999997	0103000020E61000000100000005000000C11BD2A8C0ED3D407F2E1A321EC54D40C11BD2A8C0ED3D40E6CDE15AEDC54D40166BB8C83DF13D40E6CDE15AEDC54D40166BB8C83DF13D407F2E1A321EC54D40C11BD2A8C0ED3D407F2E1A321EC54D40
17042	Новый Свет	3	29	120	30.187812999999998	30.202922999999998	59.564526000000001	59.554569000000001	0103000020E610000001000000050000007EC3448314303E400E30F31DFCC64D407EC3448314303E40F0DE516342C84D40309B00C3F2333E40F0DE516342C84D40309B00C3F2333E400E30F31DFCC64D407EC3448314303E400E30F31DFCC64D40
23316	Новинка	3	29	120	30.338757000000001	30.407478000000001	59.247715999999997	59.217511999999999	0103000020E61000000100000005000000844A5CC7B8563E40683EE76ED79B4D40844A5CC7B8563E4014596B28B59F4D40E9D66B7A50683E4014596B28B59F4D40E9D66B7A50683E40683EE76ED79B4D40844A5CC7B8563E40683EE76ED79B4D40
18701	Никольское	3	29	120	29.984956	30.013908000000001	59.470120999999999	59.445601000000003	0103000020E61000000100000005000000BDFF8F1326FC3D404F081D7409B94D40BDFF8F1326FC3D40D714C8EC2CBC4D401C2785798F033E40D714C8EC2CBC4D401C2785798F033E404F081D7409B94D40BDFF8F1326FC3D404F081D7409B94D40
27019	Мыза-Ивановка	3	29	120	30.061150999999999	30.096876999999999	59.613411999999997	59.599097999999998	0103000020E61000000100000005000000211E8997A70F3E40AC8C463EAFCC4D40211E8997A70F3E40AA7CCF4884CE4D400EBC5AEECC183E40AA7CCF4884CE4D400EBC5AEECC183E40AC8C463EAFCC4D40211E8997A70F3E40AC8C463EAFCC4D40
59056	Мины	3	29	120	30.387329000000001	30.428201999999999	59.424771	59.410367000000001	0103000020E61000000100000005000000DACA4BFE27633E40C72DE6E786B44D40DACA4BFE27633E4005A568E55EB64D40F01472A59E6D3E4005A568E55EB64D40F01472A59E6D3E40C72DE6E786B44D40DACA4BFE27633E40C72DE6E786B44D40
58509	Меньково	3	29	120	30.027248	30.036887	59.432364	59.419904000000002	0103000020E61000000100000005000000A4E194B9F9063E40D4BA0D6ABFB54D40A4E194B9F9063E40DFFB1BB457B74D40C6A52A6D71093E40DFFB1BB457B74D40C6A52A6D71093E40D4BA0D6ABFB54D40A4E194B9F9063E40D4BA0D6ABFB54D40
26116	Малые Колпаны	3	29	120	30.054718999999999	30.093373	59.547418999999998	59.534719000000003	0103000020E6100000010000000500000046787B10020E3E4061C614AC71C44D4046787B10020E3E40C11A67D311C64D405454FD4AE7173E40C11A67D311C64D405454FD4AE7173E4061C614AC71C44D4046787B10020E3E4061C614AC71C44D40
22850	Малое Верево	3	29	120	30.151745999999999	30.178345	59.618049999999997	59.609287999999999	0103000020E610000001000000050000007F4C6BD3D8263E4031EC3026FDCD4D407F4C6BD3D8263E407AA52C431CCF4D40B6679604A82D3E407AA52C431CCF4D40B6679604A82D3E4031EC3026FDCD4D407F4C6BD3D8263E4031EC3026FDCD4D40
22953	Лукаши	3	29	120	30.291964	30.299033999999999	59.59892	59.595232000000003	0103000020E61000000100000005000000FE9B1727BE4A3E402FC4EA8F30CC4D40FE9B1727BE4A3E40CD751A69A9CC4D405E64027E8D4C3E40CD751A69A9CC4D405E64027E8D4C3E402FC4EA8F30CC4D40FE9B1727BE4A3E402FC4EA8F30CC4D40
3654	Лампово	3	29	120	30.054755	30.077842	59.301375999999998	59.282097999999998	0103000020E61000000100000005000000E04A766C040E3E402D228AC91BA44D40E04A766C040E3E404FE61F7D93A64D4057410C74ED133E404FE61F7D93A64D4057410C74ED133E402D228AC91BA44D40E04A766C040E3E402D228AC91BA44D40
236	Коммунар	3	29	120	30.368402	30.435873999999998	59.660913000000001	59.609997999999997	0103000020E61000000100000005000000EFC7ED974F5E3E400D501A6A14CE4D40EFC7ED974F5E3E40294014CC98D44D403C2D3F70956F3E40294014CC98D44D403C2D3F70956F3E400D501A6A14CE4D40EFC7ED974F5E3E400D501A6A14CE4D40
16946	Кобринское	3	29	120	30.113935999999999	30.13775	59.431731999999997	59.415230000000001	0103000020E6100000010000000500000049D6E1E82A1D3E40B728B34126B54D4049D6E1E82A1D3E407E5182FE42B74D402506819543233E407E5182FE42B74D402506819543233E40B728B34126B54D4049D6E1E82A1D3E40B728B34126B54D40
727	Кобралово	3	29	120	30.374528000000002	30.409040999999998	59.595191	59.579543000000001	0103000020E61000000100000005000000B16F2711E15F3E4018D00B772ECA4D40B16F2711E15F3E40D0EFFB372FCC4D401FB935E9B6683E40D0EFFB372FCC4D401FB935E9B6683E4018D00B772ECA4D40B16F2711E15F3E4018D00B772ECA4D40
3749	Карташевская	3	29	120	30.051988000000001	30.090337000000002	59.415436	59.401262000000003	0103000020E61000000100000005000000D2C8E7154F0D3E4054909F8D5CB34D40D2C8E7154F0D3E4060CAC0012DB54D40679E5C5320173E4060CAC0012DB54D40679E5C5320173E4054909F8D5CB34D40D2C8E7154F0D3E4054909F8D5CB34D40
59036	Ивановка	3	29	120	29.981936999999999	30.004773	59.636440999999998	59.624357000000003	0103000020E610000001000000050000007BBB253960FB3D40AC0320EEEACF4D407BBB253960FB3D40B16A10E676D14D4060E7A6CD38013E40B16A10E676D14D4060E7A6CD38013E40AC0320EEEACF4D407BBB253960FB3D40AC0320EEEACF4D40
58984	Жабино	3	29	120	29.658283000000001	29.682456999999999	59.606479	59.597932	0103000020E610000001000000050000004583143C85A83D40AE9D280989CC4D404583143C85A83D40FB5A971AA1CD4D4020ED7F80B5AE3D40FB5A971AA1CD4D4020ED7F80B5AE3D40AE9D280989CC4D404583143C85A83D40AE9D280989CC4D40
18936	Елизаветино	3	29	120	29.762945999999999	29.804798999999999	59.498441	59.487606	0103000020E61000000100000005000000309DD66D50C33D40ACAA97DF69BE4D40309DD66D50C33D4026FE28EACCBF4D407FDAA84E07CE3D4026FE28EACCBF4D407FDAA84E07CE3D40ACAA97DF69BE4D40309DD66D50C33D40ACAA97DF69BE4D40
51010	Дружная Горка	3	29	120	30.114968999999999	30.150641	59.285817000000002	59.269731	0103000020E61000000100000005000000C70DBF9B6E1D3E40D3DB9F8B86A24D40C70DBF9B6E1D3E4007D2C5A695A44D40CE6F986890263E4007D2C5A695A44D40CE6F986890263E40D3DB9F8B86A24D40C70DBF9B6E1D3E40D3DB9F8B86A24D40
27150	Дивенский	3	29	120	30.000892	30.023215	59.222757000000001	59.198753000000004	0103000020E61000000100000005000000FAD346753A003E40AF7D01BD70994D40FAD346753A003E4040FA264D839C4D40D2C6116BF1053E4040FA264D839C4D40D2C6116BF1053E40AF7D01BD70994D40FAD346753A003E40AF7D01BD70994D40
867	Гатчина	3	29	120	30.043409	30.172084000000002	59.604889999999997	59.531725999999999	0103000020E61000000100000005000000215A2BDA1C0B3E406937FA980FC44D40215A2BDA1C0B3E40B6D617096DCD4D40352A70B20D2C3E40B6D617096DCD4D40352A70B20D2C3E406937FA980FC44D40215A2BDA1C0B3E406937FA980FC44D40
18704	Высокоключевой	3	29	120	30.085172	30.110792	59.490684999999999	59.464987000000001	0103000020E61000000100000005000000F0880AD5CD153E405708ABB184BB4D40F0880AD5CD153E40A2D11DC4CEBE4D408FA850DD5C1C3E40A2D11DC4CEBE4D408FA850DD5C1C3E405708ABB184BB4D40F0880AD5CD153E405708ABB184BB4D40
8475	Вырица	3	29	120	30.276827000000001	30.389341000000002	59.438724000000001	59.355804999999997	0103000020E6100000010000000500000059A65F22DE463E406B60AB048BAD4D4059A65F22DE463E4033FCA71B28B84D40F0FD0DDAAB633E4033FCA71B28B84D40F0FD0DDAAB633E406B60AB048BAD4D4059A65F22DE463E406B60AB048BAD4D40
26290	Войсковицы	3	29	120	29.915272999999999	29.982925999999999	59.541224999999997	59.516596999999997	0103000020E610000001000000050000006CE9D1544FEA3D40191BBAD91FC24D406CE9D1544FEA3D4088635DDC46C54D405A63D009A1FB3D4088635DDC46C54D405A63D009A1FB3D40191BBAD91FC24D406CE9D1544FEA3D40191BBAD91FC24D40
18947	Большое Рейзино	3	29	120	30.047972999999999	30.065373000000001	59.601579999999998	59.591892999999999	0103000020E610000001000000050000004C1762F5470C3E409CDD5A26C3CB4D404C1762F5470C3E40BEF6CC9200CD4D409A0AF148BC103E40BEF6CC9200CD4D409A0AF148BC103E409CDD5A26C3CB4D404C1762F5470C3E409CDD5A26C3CB4D40
59065	Большие Тайцы	3	29	120	30.096643	30.119209000000001	59.665984999999999	59.653807999999998	0103000020E6100000010000000500000028637C98BD183E407CEE04FBAFD34D4028637C98BD183E40335019FF3ED54D408D63247B841E3E40335019FF3ED54D408D63247B841E3E407CEE04FBAFD34D4028637C98BD183E407CEE04FBAFD34D40
18668	Большие Колпаны	3	29	120	30.057736999999999	30.089834	59.535080000000001	59.520243999999998	0103000020E61000000100000005000000E7C41EDAC70E3E4059F8FA5A97C24D40E7C41EDAC70E3E40315F5E807DC44D40A1116C5CFF163E40315F5E807DC44D40A1116C5CFF163E4059F8FA5A97C24D40E7C41EDAC70E3E4059F8FA5A97C24D40
59063	Белогорка	3	29	120	30.124051000000001	30.141217999999999	59.350589999999997	59.342624999999998	0103000020E610000001000000050000003E096CCEC11F3E4060E5D022DBAB4D403E096CCEC11F3E40FE261422E0AC4D40459BE3DC26243E40FE261422E0AC4D40459BE3DC26243E4060E5D022DBAB4D403E096CCEC11F3E4060E5D022DBAB4D40
59006	Батово	3	29	120	29.879124999999998	29.889105000000001	59.321193999999998	59.315427	0103000020E61000000100000005000000931804560EE13D4040A374E95FA84D40931804560EE13D40F1D58EE21CA94D40C8B5A1629CE33D40F1D58EE21CA94D40C8B5A1629CE33D4040A374E95FA84D40931804560EE13D4040A374E95FA84D40
22775	при ж/д станции Приветнинское	3	29	644	28.712447000000001	28.714728999999998	60.586092000000001	60.584598	0103000020E61000000100000005000000212235ED62B63C404CA7751BD44A4E40212235ED62B63C403F390A10054B4E40B680D07AF8B63C403F390A10054B4E40B680D07AF8B63C404CA7751BD44A4E40212235ED62B63C404CA7751BD44A4E40
5400	Черкасово	3	29	644	28.812546000000001	28.926812000000002	60.684426000000002	60.643121000000001	0103000020E61000000100000005000000E17EC00303D03C40772FF7C951524E40E17EC00303D03C401C446B459B574E40558A1D8D43ED3C401C446B459B574E40558A1D8D43ED3C40772FF7C951524E40E17EC00303D03C40772FF7C951524E40
4795	Цвелодубово	3	29	644	29.550153000000002	29.576447000000002	60.402205000000002	60.386558000000001	0103000020E61000000100000005000000DACBB6D3D68C3D40EB0088BB7A314E40DACBB6D3D68C3D40D3A414747B334E4098E0D40792933D40D3A414747B334E4098E0D40792933D40EB0088BB7A314E40DACBB6D3D68C3D40EB0088BB7A314E40
11595	Торфяновка	3	29	644	27.924661	27.938476999999999	60.596266999999997	60.588341	0103000020E61000000100000005000000FCE25295B6EC3B40AEF204C24E4B4E40FCE25295B6EC3B408E57207A524C4E40560C570740F03B408E57207A524C4E40560C570740F03B40AEF204C24E4B4E40FCE25295B6EC3B40AEF204C24E4B4E40
21229	Токарево	3	29	644	28.772275	28.801102	60.533777999999998	60.514983000000001	0103000020E61000000100000005000000B6847CD0B3C53C407C7F83F6EA414E40B6847CD0B3C53C4082A966D652444E409CC24A0515CD3C4082A966D652444E409CC24A0515CD3C407C7F83F6EA414E40B6847CD0B3C53C407C7F83F6EA414E40
22954	Тарасово	3	29	644	29.287655999999998	29.32535	60.270328999999997	60.254452999999998	0103000020E61000000100000005000000887FD8D2A3493D403EAF78EA91204E40887FD8D2A3493D40871403249A224E40ECC039234A533D40871403249A224E40ECC039234A533D403EAF78EA91204E40887FD8D2A3493D403EAF78EA91204E40
11753	Соколинское	3	29	644	28.732209999999998	28.773002999999999	60.663119000000002	60.646155	0103000020E61000000100000005000000DDCD531D72BB3C40CD920035B5524E40DDCD531D72BB3C40992D5915E1544E40BBB54C86E3C53C40992D5915E1544E40BBB54C86E3C53C40CD920035B5524E40DDCD531D72BB3C40CD920035B5524E40
21154	Советский	3	29	644	28.651720999999998	28.724996999999998	60.557307000000002	60.519137000000001	0103000020E61000000100000005000000CD1DFD2FD7A63C406092CA1473424E40CD1DFD2FD7A63C407B6AF5D555474E40B7B2446799B93C407B6AF5D555474E40B7B2446799B93C406092CA1473424E40CD1DFD2FD7A63C406092CA1473424E40
22502	Семиозерье	3	29	644	29.291259	29.303726999999999	60.323020999999997	60.316119	0103000020E6100000010000000500000069AA27F38F4A3D4076525F9676284E4069AA27F38F4A3D40EA758BC058294E4085E97B0DC14D3D40EA758BC058294E4085E97B0DC14D3D4076525F9676284E4069AA27F38F4A3D4076525F9676284E40
5980	Светогорск	3	29	644	28.818277999999999	28.904696000000001	61.127037000000001	61.073422999999998	0103000020E610000001000000050000004A09C1AA7AD13C4019E3C3EC65894E404A09C1AA7AD13C40E43098BF42904E4070D234289AE73C40E43098BF42904E4070D234289AE73C4019E3C3EC65894E404A09C1AA7AD13C4019E3C3EC65894E40
4276	Рябово	3	29	644	28.964344000000001	28.999082000000001	60.353577000000001	60.335433999999999	0103000020E610000001000000050000000518963FDFF63C40B5FB5580EF2A4E400518963FDFF63C4014CFD902422D4E40B40584D6C3FF3C4014CFD902422D4E40B40584D6C3FF3C40B5FB5580EF2A4E400518963FDFF63C40B5FB5580EF2A4E40
4979	Рощино	3	29	644	29.559432999999999	29.667195	60.279114	60.225408000000002	0103000020E610000001000000050000009C4D4700378F3D40DE205A2BDA1C4E409C4D4700378F3D4089EDEE01BA234E40020EA14ACDAA3D4089EDEE01BA234E40020EA14ACDAA3D40DE205A2BDA1C4E409C4D4700378F3D40DE205A2BDA1C4E40
21983	Решетниково	3	29	644	29.688368000000001	29.72015	60.247791999999997	60.227263000000001	0103000020E61000000100000005000000E99C9FE238B03D40A14B38F4161D4E40E99C9FE238B03D40EF1AF4A5B71F4E40E3361AC05BB83D40EF1AF4A5B71F4E40E3361AC05BB83D40A14B38F4161D4E40E99C9FE238B03D40A14B38F4161D4E40
4833	Пушное	3	29	644	29.449352999999999	29.481010000000001	60.411411999999999	60.389189999999999	0103000020E61000000100000005000000075C57CC08733D4012F758FAD0314E40075C57CC08733D404A97FE25A9344E40890CAB78237B3D404A97FE25A9344E40890CAB78237B3D4012F758FAD0314E40075C57CC08733D4012F758FAD0314E40
5684	Пруды	3	29	644	29.030666	29.051417000000001	61.023380000000003	61.010601999999999	0103000020E6100000010000000500000061191BBAD9073D40D7A205685B814E4061191BBAD9073D40B4B0A71DFE824E405C751DAA290D3D40B4B0A71DFE824E405C751DAA290D3D40D7A205685B814E4061191BBAD9073D40D7A205685B814E40
4242	Приморск	3	29	644	28.571843000000001	28.745757000000001	60.411971999999999	60.330469000000001	0103000020E610000001000000050000005072874D64923C40C1ABE5CE4C2A4E405072874D64923C40116F9D7FBB344E4059C345EEE9BE3C40116F9D7FBB344E4059C345EEE9BE3C40C1ABE5CE4C2A4E405072874D64923C40C1ABE5CE4C2A4E40
58974	Приветнинское	3	29	644	29.418137000000002	29.435205	60.179364999999997	60.170817999999997	0103000020E61000000100000005000000603FC4060B6B3D40B8C83D5DDD154E40603FC4060B6B3D400586AC6EF5164E40410E4A98696F3D400586AC6EF5164E40410E4A98696F3D40B8C83D5DDD154E40603FC4060B6B3D40B8C83D5DDD154E40
4938	Поляны	3	29	644	29.245660000000001	29.291034	60.328197000000003	60.300939	0103000020E6100000010000000500000074EFE192E33E3D40A48B4D2B85264E4074EFE192E33E3D409AD2FA5B022A4E4029064834814A3D409AD2FA5B022A4E4029064834814A3D40A48B4D2B85264E4074EFE192E33E3D40A48B4D2B85264E40
58443	Подборовье	3	29	644	28.512132000000001	28.533134	60.682214000000002	60.670295000000003	0103000020E610000001000000050000002E3C2F151B833C400FD6FF39CC554E402E3C2F151B833C40CA6FD1C952574E40BB6246787B883C40CA6FD1C952574E40BB6246787B883C400FD6FF39CC554E402E3C2F151B833C400FD6FF39CC554E40
4875	Победа	3	29	644	29.546192000000001	29.551465	60.380119000000001	60.377032999999997	0103000020E610000001000000050000003B56293DD38B3D40A2410A9E42304E403B56293DD38B3D404BCB48BDA7304E407EE36BCF2C8D3D404BCB48BDA7304E407EE36BCF2C8D3D40A2410A9E42304E403B56293DD38B3D40A2410A9E42304E40
5025	Песочное	3	29	644	29.358048	29.374756999999999	60.170020999999998	60.163696000000002	0103000020E61000000100000005000000F165A208A95B3D40363E93FDF3144E40F165A208A95B3D400D51853FC3154E4073F22213F05F3D400D51853FC3154E4073F22213F05F3D40363E93FDF3144E40F165A208A95B3D40363E93FDF3144E40
5348	Перово	3	29	644	28.943062999999999	28.958262000000001	60.683971999999997	60.67754	0103000020E610000001000000050000005111A7936CF13C40ADDD76A1B9564E405111A7936CF13C409AB0FD648C574E40E3FF8EA850F53C409AB0FD648C574E40E3FF8EA850F53C40ADDD76A1B9564E405111A7936CF13C40ADDD76A1B9564E40
58943	Первомайское	3	29	644	29.725325000000002	29.757034999999998	60.367393	60.351599999999998	0103000020E61000000100000005000000A1F831E6AEB93D4005A3923A012D4E40A1F831E6AEB93D40C1E3DBBB062F4E4067EDB60BCDC13D40C1E3DBBB062F4E4067EDB60BCDC13D4005A3923A012D4E40A1F831E6AEB93D4005A3923A012D4E40
4628	Первомайское	3	29	644	29.725325000000002	29.757034999999998	60.367393	60.351599999999998	0103000020E61000000100000005000000A1F831E6AEB93D4005A3923A012D4E40A1F831E6AEB93D40C1E3DBBB062F4E4067EDB60BCDC13D40C1E3DBBB062F4E4067EDB60BCDC13D4005A3923A012D4E40A1F831E6AEB93D4005A3923A012D4E40
20150	Михалёво	3	29	644	29.386641999999998	29.419044	61.012652000000003	61.001416999999996	0103000020E61000000100000005000000914259F8FA623D404754A86E2E804E40914259F8FA623D40501DAB949E814E40C495B377466B3D40501DAB949E814E40C495B377466B3D404754A86E2E804E40914259F8FA623D404754A86E2E804E40
58997	Лужайка	3	29	644	28.470351000000001	28.496168999999998	60.810442000000002	60.802007000000003	0103000020E6100000010000000500000012A452EC68783C40E014562AA8664E4012A452EC68783C4005A73E90BC674E40FD497CEE047F3C4005A73E90BC674E40FD497CEE047F3C40E014562AA8664E4012A452EC68783C40E014562AA8664E40
59045	Лосево	3	29	644	28.956430000000001	28.994796999999998	61.084989	61.074793999999997	0103000020E61000000100000005000000CDE9B298D8F43C40F0F78BD992894E40CDE9B298D8F43C4087C267EBE08A4E40AE282504ABFE3C4087C267EBE08A4E40AE282504ABFE3C40F0F78BD992894E40CDE9B298D8F43C40F0F78BD992894E40
5882	Лесогорский	3	29	644	28.862493000000001	28.955603	61.074545999999998	61.022573999999999	0103000020E6100000010000000500000068075C57CCDC3C40B5DE6FB4E3824E4068075C57CCDC3C4018062CB98A894E40A1F5F065A2F43C4018062CB98A894E40A1F5F065A2F43C40B5DE6FB4E3824E4068075C57CCDC3C40B5DE6FB4E3824E40
4666	Ленинское	3	29	644	29.838180000000001	29.863980000000002	60.238846000000002	60.196238999999998	0103000020E610000001000000050000004A29E8F692D63D4091990B5C1E194E404A29E8F692D63D40E5637781921E4E40E96514CB2DDD3D40E5637781921E4E40E96514CB2DDD3D4091990B5C1E194E404A29E8F692D63D4091990B5C1E194E40
20088	Красный Сокол	3	29	644	29.248695999999999	29.325807999999999	60.982799999999997	60.892845000000001	0103000020E6100000010000000500000061A5828AAA3F3D40D5B2B5BE48724E4061A5828AAA3F3D402041F163CC7D4E4071C6302768533D402041F163CC7D4E4071C6302768533D40D5B2B5BE48724E4061A5828AAA3F3D40D5B2B5BE48724E40
21756	Красносельское	3	29	644	29.470616	29.499991000000001	60.555985	60.536158999999998	0103000020E610000001000000050000006EF9484A7A783D40603AADDBA0444E406EF9484A7A783D40850838842A474E405A4B0169FF7F3D40850838842A474E405A4B0169FF7F3D40603AADDBA0444E406EF9484A7A783D40603AADDBA0444E40
4393	Красная Долина	3	29	644	28.982417999999999	28.994734000000001	60.366179000000002	60.356171000000003	0103000020E610000001000000050000007100FDBE7FFB3C404E64E602972D4E407100FDBE7FFB3C40B2BD16F4DE2E4E4022382EE3A6FE3C40B2BD16F4DE2E4E4022382EE3A6FE3C404E64E602972D4E407100FDBE7FFB3C404E64E602972D4E40
4497	Коробицыно	3	29	644	29.716412999999999	29.733346999999998	60.521797999999997	60.509858999999999	0103000020E61000000100000005000000E36DA5D766B73D401F49490F43414E40E36DA5D766B73D40218FE046CA424E40A59E05A1BCBB3D40218FE046CA424E40A59E05A1BCBB3D401F49490F43414E40E36DA5D766B73D401F49490F43414E40
11640	Кондратьево	3	29	644	28.145871	28.176476000000001	60.646182000000003	60.617733000000001	0103000020E61000000100000005000000506F46CD57253C407A54FCDF114F4E40506F46CD57253C40C7A17E17B6524E406687F8872D2D3C40C7A17E17B6524E406687F8872D2D3C407A54FCDF114F4E40506F46CD57253C407A54FCDF114F4E40
22766	Клеверное	3	29	644	29.160266	29.172394000000001	60.316265999999999	60.309050999999997	0103000020E6100000010000000500000026A94C3107293D40E6E5B0FB8E274E4026A94C3107293D401A6B7F677B284E40D1066003222C3D401A6B7F677B284E40D1066003222C3D40E6E5B0FB8E274E4026A94C3107293D40E6E5B0FB8E274E40
4564	Кирпичное	3	29	644	29.357185999999999	29.374029	60.471978999999997	60.467007000000002	0103000020E61000000100000005000000CC96AC8A705B3D406500A8E2C63B4E40CC96AC8A705B3D400BB3D0CE693C4E406EC1525DC05F3D400BB3D0CE693C4E406EC1525DC05F3D406500A8E2C63B4E40CC96AC8A705B3D406500A8E2C63B4E40
21890	Кирилловское	3	29	644	29.245902999999998	29.299586000000001	60.477339999999998	60.463245999999998	0103000020E6100000010000000500000000FDBE7FF33E3D405C001AA54B3B4E4000FDBE7FF33E3D404C89247A193D4E40E75608ABB14C3D404C89247A193D4E40E75608ABB14C3D405C001AA54B3B4E4000FDBE7FF33E3D405C001AA54B3B4E40
5615	Каменногорск	3	29	644	29.063590000000001	29.170552000000001	60.973126999999998	60.915000999999997	0103000020E61000000100000005000000475A2A6F47103D405567B5C01E754E40475A2A6F47103D4063EDEF6C8F7C4E407444BE4BA92B3D4063EDEF6C8F7C4E407444BE4BA92B3D405567B5C01E754E40475A2A6F47103D405567B5C01E754E40
4736	Ильичёво	3	29	644	29.742895999999998	29.793246	60.273094999999998	60.257694000000001	0103000020E610000001000000050000004754A86E2EBE3D400E30F31DFC204E404754A86E2EBE3D40BED9E6C6F4224E40CDAE7B2B12CB3D40BED9E6C6F4224E40CDAE7B2B12CB3D400E30F31DFC204E404754A86E2EBE3D400E30F31DFC204E40
5836	Зайцево	3	29	644	29.426392	29.462271000000001	61.066046	61.054400000000001	0103000020E61000000100000005000000AA46AF06286D3D4082734694F6864E40AA46AF06286D3D400C04013274884E40A4E36A6457763D400C04013274884E40A4E36A6457763D4082734694F6864E40AA46AF06286D3D4082734694F6864E40
5503	Житково	3	29	644	29.277631	29.367481000000002	60.705561000000003	60.687510000000003	0103000020E61000000100000005000000145B41D312473D4024D6E25300584E40145B41D312473D40A22AA6D24F5A4E40C1E61C3C135E3D40A22AA6D24F5A4E40C1E61C3C135E3D4024D6E25300584E40145B41D312473D4024D6E25300584E40
20351	Ермилово	3	29	644	28.750554000000001	28.789117999999998	60.368955	60.349378999999999	0103000020E61000000100000005000000CAE1934E24C03C4060747973B82C4E40CAE1934E24C03C400C59DDEA392F4E4057AF22A303CA3C400C59DDEA392F4E4057AF22A303CA3C4060747973B82C4E40CAE1934E24C03C4060747973B82C4E40
5083	Горьковское	3	29	644	29.422494	29.445302000000002	60.271636000000001	60.265318000000001	0103000020E6100000010000000500000098C11891286C3D402385B2F0F5214E4098C11891286C3D404835ECF7C4224E40E9D7D64FFF713D404835ECF7C4224E40E9D7D64FFF713D402385B2F0F5214E4098C11891286C3D402385B2F0F5214E40
19475	Гончарово	3	29	644	28.923487999999999	28.947105000000001	60.726176000000002	60.698124	0103000020E610000001000000050000009A3FA6B569EC3C40BF4692205C594E409A3FA6B569EC3C40EF91CD55F35C4E40CAE0287975F23C40EF91CD55F35C4E40CAE0287975F23C40BF4692205C594E409A3FA6B569EC3C40BF4692205C594E40
6763	Глебычево	3	29	644	28.717648000000001	28.731617	60.457957999999998	60.446421000000001	0103000020E61000000100000005000000310A82C7B7B73C40B29FC55224394E40310A82C7B7B73C408578245E9E3A4E40983270404BBB3C408578245E9E3A4E40983270404BBB3C40B29FC55224394E40310A82C7B7B73C40B29FC55224394E40
5453	Гвардейское	3	29	644	28.944841	28.967856000000001	60.812964999999998	60.794227999999997	0103000020E6100000010000000500000081EB8A19E1F13C40A3C85A43A9654E4081EB8A19E1F13C4075E5B33C0F684E40C53C2B69C5F73C4075E5B33C0F684E40C53C2B69C5F73C40A3C85A43A9654E4081EB8A19E1F13C40A3C85A43A9654E40
18461	Гаврилово	3	29	644	29.023748999999999	29.055038	60.597476999999998	60.586454000000003	0103000020E610000001000000050000000D501A6A14063D40E04DB7EC104B4E400D501A6A14063D405C8E57207A4C4E4089096AF8160E3D405C8E57207A4C4E4089096AF8160E3D40E04DB7EC104B4E400D501A6A14063D40E04DB7EC104B4E40
11681	Высоцк	3	29	644	28.555358999999999	28.585919000000001	60.637425	60.613301	0103000020E610000001000000050000000D8AE6012C8E3C4053CDACA5804E4E400D8AE6012C8E3C408F53742497514E40E31A9FC9FE953C408F53742497514E40E31A9FC9FE953C4053CDACA5804E4E400D8AE6012C8E3C4053CDACA5804E4E40
5146	Выборг	3	29	644	28.579470000000001	28.913733000000001	60.811289000000002	60.653542000000002	0103000020E610000001000000050000005C035B2558943C40FE47A643A7534E405C035B2558943C40624D6551D8674E40A646E867EAE93C40624D6551D8674E40A646E867EAE93C40FE47A643A7534E405C035B2558943C40FE47A643A7534E40
19969	Возрождение	3	29	644	28.932903	28.975645	60.867072999999998	60.831077000000001	0103000020E610000001000000050000001D5723BBD2EE3C4099BA2BBB606A4E401D5723BBD2EE3C404F1F813FFC6E4E408481E7DEC3F93C404F1F813FFC6E4E408481E7DEC3F93C4099BA2BBB606A4E401D5723BBD2EE3C4099BA2BBB606A4E40
58969	Вещево	3	29	644	29.152442000000001	29.198938999999999	60.733165999999997	60.719549000000001	0103000020E610000001000000050000006E895C7006273D404C6F7F2E1A5C4E406E895C7006273D4002452C62D85D4E4021E692AAED323D4002452C62D85D4E4021E692AAED323D404C6F7F2E1A5C4E406E895C7006273D404C6F7F2E1A5C4E40
20899	Большое Поле	3	29	644	28.486951999999999	28.515976999999999	60.703544000000001	60.685589	0103000020E61000000100000005000000C7B8E2E2A87C3C40A9BF5E61C1574E40C7B8E2E2A87C3C4005A6D3BA0D5A4E40FA7C941117843C4005A6D3BA0D5A4E40FA7C941117843C40A9BF5E61C1574E40C7B8E2E2A87C3C40A9BF5E61C1574E40
5560	Барышево	3	29	644	29.571981999999998	29.597511999999998	60.705468000000003	60.687685999999999	0103000020E6100000010000000500000092E68F696D923D4062F5471806584E4092E68F696D923D40F12F82C64C5A4E40B1F7E28BF6983D40F12F82C64C5A4E40B1F7E28BF6983D4062F5471806584E4092E68F696D923D4062F5471806584E40
59061	п.Дубровка	3	29	623	30.875267000000001	30.939990999999999	59.898114999999997	59.849550999999998	0103000020E610000001000000050000009E44847F11E03E405DA45016BEEC4D409E44847F11E03E400586AC6EF5F24D40CA880B40A3F03E400586AC6EF5F24D40CA880B40A3F03E405DA45016BEEC4D409E44847F11E03E405DA45016BEEC4D40
11783	имени Свердлова	3	29	623	30.590205000000001	30.755216000000001	59.821131999999999	59.777402000000002	0103000020E6100000010000000500000089EFC4AC17973E4029ECA2E881E34D4089EFC4AC17973E407BD976DA1AE94D407B6AF5D555C13E407BD976DA1AE94D407B6AF5D555C13E4029ECA2E881E34D4089EFC4AC17973E4029ECA2E881E34D40
59076	имени Морозова	3	29	623	29.937013	31.899014000000001	60.846325	59.801499	0103000020E6100000010000000500000046ED7E15E0EF3D406B63EC8497E64D4046ED7E15E0EF3D40C364AA60546C4E406AA510C825E63F40C364AA60546C4E406AA510C825E63F406B63EC8497E64D4046ED7E15E0EF3D406B63EC8497E64D40
11916	Янино-1	3	29	623	30.541308999999998	30.583386000000001	59.966510999999997	59.933247999999999	0103000020E61000000100000005000000CC07043A938A3E405987A3AB74F74D40CC07043A938A3E40B41CE8A1B6FB4D40BBF1EEC858953E40B41CE8A1B6FB4D40BBF1EEC858953E405987A3AB74F74D40CC07043A938A3E405987A3AB74F74D40
17334	Юкки	3	29	623	30.24456	30.316928000000001	60.122076	60.102727999999999	0103000020E61000000100000005000000E6E8F17B9B3E3E401631EC30260D4E40E6E8F17B9B3E3E4031D0B52FA00F4E40CB2F833122513E4031D0B52FA00F4E40CB2F833122513E401631EC30260D4E40E6E8F17B9B3E3E401631EC30260D4E40
58926	Энтолово	3	29	623	29.937013	31.899014000000001	60.846325	59.801499	0103000020E6100000010000000500000046ED7E15E0EF3D406B63EC8497E64D4046ED7E15E0EF3D40C364AA60546C4E406AA510C825E63F40C364AA60546C4E406AA510C825E63F406B63EC8497E64D4046ED7E15E0EF3D406B63EC8497E64D40
13698	Щеглово	3	29	623	30.746251000000001	30.782299999999999	60.034199999999998	60.020668999999998	0103000020E61000000100000005000000789B374E0ABF3E4040852348A5024E40789B374E0ABF3E40F8C264AA60044E402AA913D044C83E40F8C264AA60044E402AA913D044C83E4040852348A5024E40789B374E0ABF3E4040852348A5024E40
58939	Хапо-Ое	3	29	623	30.737043	30.765896999999999	59.889750999999997	59.876834000000002	0103000020E61000000100000005000000E8BE9CD9AEBC3E40AC02B5183CF04D40E8BE9CD9AEBC3E40A94A5B5CE3F14D40C11A67D311C43E40A94A5B5CE3F14D40C11A67D311C43E40AC02B5183CF04D40E8BE9CD9AEBC3E40AC02B5183CF04D40
14758	Углово	3	29	623	30.721609999999998	30.743763000000001	60.079366	60.064349	0103000020E610000001000000050000007077D66EBBB83E40E14389963C084E407077D66EBBB83E40093543AA280A4E4090F9804067BE3E40093543AA280A4E4090F9804067BE3E40E14389963C084E407077D66EBBB83E40E14389963C084E40
13366	Токсово	3	29	623	30.444516	30.571204999999999	60.181883999999997	60.131357999999999	0103000020E610000001000000050000007A8CF2CCCB713E40B308C556D0104E407A8CF2CCCB713E4034D593F947174E40CA4FAA7D3A923E4034D593F947174E40CA4FAA7D3A923E40B308C556D0104E407A8CF2CCCB713E40B308C556D0104E40
11864	Суоранда	3	29	623	30.581329	30.630206999999999	59.950068999999999	59.934786000000003	0103000020E61000000100000005000000653733FAD1943E401C615111A7F74D40653733FAD1943E40C2F869DC9BF94D40D4B5F63E55A13E40C2F869DC9BF94D40D4B5F63E55A13E401C615111A7F74D40653733FAD1943E401C615111A7F74D40
13172	Стеклянный	3	29	623	30.212463	30.247748999999999	60.388131999999999	60.379995000000001	0103000020E610000001000000050000002C9CA4F963363E405FD218ADA3304E402C9CA4F963363E40FA43334FAE314E40E09D7C7A6C3F3E40FA43334FAE314E40E09D7C7A6C3F3E405FD218ADA3304E402C9CA4F963363E405FD218ADA3304E40
52211	Старая	3	29	623	30.613399000000001	30.633872	59.934036999999996	59.923532000000002	0103000020E610000001000000050000002C6684B7079D3E409D67EC4B36F64D402C6684B7079D3E40812040868EF74D40A1D9756F45A23E40812040868EF74D40A1D9756F45A23E409D67EC4B36F64D402C6684B7079D3E409D67EC4B36F64D40
12757	Сертолово	3	29	623	30.142296000000002	30.235171999999999	60.167107000000001	60.123241	0103000020E61000000100000005000000045ABA826D243E405F43705CC60F4E40045ABA826D243E4062F71DC363154E4056EF703B343C3E4062F71DC363154E4056EF703B343C3E405F43705CC60F4E40045ABA826D243E405F43705CC60F4E40
13427	Романовка	3	29	623	30.680413000000001	30.736934999999999	60.054724999999998	60.038474000000001	0103000020E61000000100000005000000F4C5DE8B2FAE3E4087DF4DB7EC044E40F4C5DE8B2FAE3E4005A3923A01074E401B47ACC5A7BC3E4005A3923A01074E401B47ACC5A7BC3E4087DF4DB7EC044E40F4C5DE8B2FAE3E4087DF4DB7EC044E40
58952	Рахья	3	29	623	30.813229	30.853176999999999	60.097655000000003	60.083804000000001	0103000020E61000000100000005000000A62897C62FD03E4012A3E716BA0A4E40A62897C62FD03E403CA583F57F0C4E400BB3D0CE69DA3E403CA583F57F0C4E400BB3D0CE69DA3E4012A3E716BA0A4E40A62897C62FD03E4012A3E716BA0A4E40
58924	Рахья	3	29	623	30.813229	30.853176999999999	60.097655000000003	60.083804000000001	0103000020E61000000100000005000000A62897C62FD03E4012A3E716BA0A4E40A62897C62FD03E403CA583F57F0C4E400BB3D0CE69DA3E403CA583F57F0C4E400BB3D0CE69DA3E4012A3E716BA0A4E40A62897C62FD03E4012A3E716BA0A4E40
14557	Рапполово	3	29	623	30.425445	30.459472999999999	60.168405	60.152892000000001	0103000020E61000000100000005000000293FA9F6E96C3E40F7E80DF791134E40293FA9F6E96C3E40CFBD874B8E154E401F65C405A0753E40CFBD874B8E154E401F65C405A0753E40F7E80DF791134E40293FA9F6E96C3E40F7E80DF791134E40
15692	Разметелево	3	29	623	30.660236999999999	30.691597000000002	59.916694	59.894562999999998	0103000020E61000000100000005000000F19BC24A05A93E40179B560A81F24D40F19BC24A05A93E403F389F3A56F54D40000341800CB13E403F389F3A56F54D40000341800CB13E40179B560A81F24D40F19BC24A05A93E40179B560A81F24D40
13455	Порошкино	3	29	623	30.321788000000002	30.376873	60.122397999999997	60.101880000000001	0103000020E61000000100000005000000C93EC8B260523E40E90E62670A0D4E40C93EC8B260523E40438CD7BCAA0F4E40D3BEB9BF7A603E40438CD7BCAA0F4E40D3BEB9BF7A603E40E90E62670A0D4E40C93EC8B260523E40E90E62670A0D4E40
10098	Павлово	3	29	623	30.656625999999999	30.668762000000001	59.940140999999997	59.931255999999998	0103000020E610000001000000050000000BB43BA418A83E40151A886533F74D400BB43BA418A83E407A50508A56F84D40BCCE86FC33AB3E407A50508A56F84D40BCCE86FC33AB3E40151A886533F74D400BB43BA418A83E40151A886533F74D40
13278	Осельки	3	29	623	30.407838000000002	30.452089000000001	60.267482000000001	60.250846000000003	0103000020E61000000100000005000000E910381268683E408D2AC3B81B204E40E910381268683E406422A5D93C224E40A0E1CD1ABC733E406422A5D93C224E40A0E1CD1ABC733E408D2AC3B81B204E40E910381268683E408D2AC3B81B204E40
13737	Новое Девяткино	3	29	623	30.461296000000001	30.49051	60.064743999999997	60.047865000000002	0103000020E610000001000000050000008FC6A17E17763E40C0CFB87020064E408FC6A17E17763E405D4E098849084E40685C3810927D3E405D4E098849084E40685C3810927D3E40C0CFB87020064E408FC6A17E17763E40C0CFB87020064E40
58982	Новое Девяткино	3	29	623	30.461296000000001	30.49051	60.064743999999997	60.047865000000002	0103000020E610000001000000050000008FC6A17E17763E40C0CFB87020064E408FC6A17E17763E405D4E098849084E40685C3810927D3E405D4E098849084E40685C3810927D3E40C0CFB87020064E408FC6A17E17763E40C0CFB87020064E40
14088	Ненимяки	3	29	623	30.379783	30.390868000000001	60.355089999999997	60.349049999999998	0103000020E61000000100000005000000A7936C7539613E409B559FABAD2C4E40A7936C7539613E407D91D096732D4E408D0DDDEC0F643E407D91D096732D4E408D0DDDEC0F643E409B559FABAD2C4E40A7936C7539613E409B559FABAD2C4E40
15979	Мурино	3	29	623	30.435101	30.499385	60.060769999999998	60.031593000000001	0103000020E61000000100000005000000F77475C7626F3E402AE44A3D0B044E40F77475C7626F3E40F949B54FC7074E40EB1C03B2D77F3E40F949B54FC7074E40EB1C03B2D77F3E402AE44A3D0B044E40F77475C7626F3E402AE44A3D0B044E40
59020	Лупполово	3	29	623	30.249438000000001	30.262094999999999	60.156495999999997	60.150481999999997	0103000020E610000001000000050000003161342BDB3F3E407E5182FE42134E403161342BDB3F3E4037FA980F08144E40F3716DA818433E4037FA980F08144E40F3716DA818433E407E5182FE42134E403161342BDB3F3E407E5182FE42134E40
14222	Лесное	3	29	623	30.194614000000001	30.207594	60.383800999999998	60.374021999999997	0103000020E6100000010000000500000000581D39D2313E4004FEF0F3DF2F4E4000581D39D2313E400796236420314E4088D860E124353E400796236420314E4088D860E124353E4004FEF0F3DF2F4E4000581D39D2313E4004FEF0F3DF2F4E40
13333	Лесколово	3	29	623	30.452286000000001	30.471941000000001	60.275612000000002	60.257854999999999	0103000020E610000001000000050000004C70EA03C9733E40170E846401214E404C70EA03C9733E404D31074147234E403CA41820D1783E404D31074147234E403CA41820D1783E40170E846401214E404C70EA03C9733E40170E846401214E40
59002	Лаврики	3	29	623	30.426791999999999	30.459679000000001	60.079841000000002	60.068857000000001	0103000020E61000000100000005000000C631923D426D3E40E38C614ED0084E40C631923D426D3E40A2F0D93A380A4E4072A8DF85AD753E40A2F0D93A380A4E4072A8DF85AD753E40E38C614ED0084E40C631923D426D3E40E38C614ED0084E40
29981	Куйвози	3	29	623	30.439610999999999	30.455358	60.320489999999999	60.307937000000003	0103000020E610000001000000050000003CF6B3588A703E403B1DC87A6A274E403CF6B3588A703E40F758FAD005294E40D3F8855792743E40F758FAD005294E40D3F8855792743E403B1DC87A6A274E403CF6B3588A703E403B1DC87A6A274E40
13521	Кузьмоловский	3	29	623	30.465878	30.504317	60.119807000000002	60.102167000000001	0103000020E6100000010000000500000007EDD5C743773E407FDDE9CE130D4E4007EDD5C743773E407B6AF5D5550F4E401CD13DEB1A813E407B6AF5D5550F4E401CD13DEB1A813E407FDDE9CE130D4E4007EDD5C743773E407FDDE9CE130D4E40
58995	Кузьмолово	3	29	623	30.494299999999999	30.515070000000001	60.125070000000001	60.116776999999999	0103000020E61000000100000005000000AD69DE718A7E3E4066F6798CF20E4E40AD69DE718A7E3E40F9DA334B02104E409626A5A0DB833E40F9DA334B02104E409626A5A0DB833E4066F6798CF20E4E40AD69DE718A7E3E4066F6798CF20E4E40
10026	Колтуши	3	29	623	30.633593000000001	30.663416999999999	59.940942999999997	59.921601000000003	0103000020E610000001000000050000007BF99D2633A23E40FF7A8505F7F54D407BF99D2633A23E403733FAD170F84D40459C4EB2D5A93E403733FAD170F84D40459C4EB2D5A93E40FF7A8505F7F54D407BF99D2633A23E40FF7A8505F7F54D40
59003	Ириновка	3	29	623	30.90766	30.939236000000001	60.083193999999999	60.073507999999997	0103000020E610000001000000050000002AE3DF675CE83E4047FFCBB568094E402AE3DF675CE83E40999CDA19A60A4E40D2393FC571F03E40999CDA19A60A4E40D2393FC571F03E4047FFCBB568094E402AE3DF675CE83E4047FFCBB568094E40
11968	Заневка	3	29	623	30.502412	30.528607000000001	59.948265999999997	59.925083000000001	0103000020E61000000100000005000000321EA5129E803E40F48AA71E69F64D40321EA5129E803E4051F4C0C760F94D40CA6FD1C952873E4051F4C0C760F94D40CA6FD1C952873E40F48AA71E69F64D40321EA5129E803E40F48AA71E69F64D40
13078	Заводской	3	29	623	30.489279	30.496627	60.317162000000003	60.308762000000002	0103000020E610000001000000050000009D9E7763417D3E40B01F628385274E409D9E7763417D3E4059C4B0C398284E40834F73F2227F3E4059C4B0C398284E40834F73F2227F3E40B01F628385274E409D9E7763417D3E40B01F628385274E40
13051	Гарболово	3	29	623	30.477088999999999	30.504864999999999	60.345559999999999	60.335323000000002	0103000020E6100000010000000500000006483481227A3E405E4C33DDEB2A4E4006483481227A3E402367614F3B2C4E4021E527D53E813E402367614F3B2C4E4021E527D53E813E405E4C33DDEB2A4E4006483481227A3E405E4C33DDEB2A4E40
9960	Всеволожск	3	29	623	30.571421000000001	30.716660000000001	60.056686999999997	59.979154999999999	0103000020E61000000100000005000000643F8BA548923E40815B77F354FD4D40643F8BA548923E40DE8D058541074E40F3599E0777B73E40DE8D058541074E40F3599E0777B73E40815B77F354FD4D40643F8BA548923E40815B77F354FD4D40
17304	Воейково	3	29	623	30.691678	30.724871	59.963624000000003	59.942236000000001	0103000020E61000000100000005000000D95C35CF11B13E40938E72309BF84D40D95C35CF11B13E4003D2FE0758FB4D409ED1562591B93E4003D2FE0758FB4D409ED1562591B93E40938E72309BF84D40D95C35CF11B13E40938E72309BF84D40
13228	Верхние Осельки	3	29	623	30.444254999999998	30.458915999999999	60.256123000000002	60.250846000000003	0103000020E61000000100000005000000A01518B2BA713E408D2AC3B81B204E40A01518B2BA713E40706072A3C8204E40739CDB847B753E40706072A3C8204E40739CDB847B753E408D2AC3B81B204E40A01518B2BA713E408D2AC3B81B204E40
13139	Васкелово	3	29	623	30.309273999999998	30.376100000000001	60.387869999999999	60.363278000000001	0103000020E61000000100000005000000CB80B3942C4F3E409BADBCE47F2E4E40CB80B3942C4F3E40BD8C62B9A5314E408E06F01648603E40BD8C62B9A5314E408E06F01648603E409BADBCE47F2E4E40CB80B3942C4F3E409BADBCE47F2E4E40
58942	Вартемяги	3	29	623	30.283798000000001	30.339368	60.188783000000001	60.159264	0103000020E6100000010000000500000093AB58FCA6483E400FB743C362144E4093AB58FCA6483E403885950A2A184E40164F3DD2E0563E403885950A2A184E40164F3DD2E0563E400FB743C362144E4093AB58FCA6483E400FB743C362144E40
13641	Ваганово	3	29	623	31.012232999999998	31.035257000000001	60.092101	60.078490000000002	0103000020E6100000010000000500000095EEAEB321033F401288D7F50B0A4E4095EEAEB321033F40E6762FF7C90B4E4080F44D9A06093F40E6762FF7C90B4E4080F44D9A06093F401288D7F50B0A4E4095EEAEB321033F401288D7F50B0A4E40
13368	Бугры	3	29	623	30.382218000000002	30.411099	60.082050000000002	60.059679000000003	0103000020E610000001000000050000004AF1F109D9613E4006A1BC8FA3074E404AF1F109D9613E408351499D800A4E40166BB8C83D693E408351499D800A4E40166BB8C83D693E4006A1BC8FA3074E404AF1F109D9613E4006A1BC8FA3074E40
13553	Борисова Грива	3	29	623	30.929255999999999	30.982382000000001	60.105862999999999	60.086955000000003	0103000020E610000001000000050000009D9CA1B8E3ED3E40A29C6857210B4E409D9CA1B8E3ED3E40A06D35EB8C0D4E40D82D02637DFB3E40A06D35EB8C0D4E40D82D02637DFB3E40A29C6857210B4E409D9CA1B8E3ED3E40A29C6857210B4E40
13265	Агалатово	3	29	623	30.230689999999999	30.315131000000001	60.242026000000003	60.207351000000003	0103000020E61000000100000005000000A583F57F0E3B3E407EE5417A8A1A4E40A583F57F0E3B3E400F643DB5FA1E4E40AEF4DA6CAC503E400F643DB5FA1E4E40AEF4DA6CAC503E407EE5417A8A1A4E40A583F57F0E3B3E407EE5417A8A1A4E40
17032	Хвалово	3	29	953	32.729075000000002	32.743178999999998	59.956556999999997	59.947215999999997	0103000020E6100000010000000500000065AA6054525D4040BC1FB75F3EF94D4065AA6054525D404043E1B37570FA4D4078094E7D205F404043E1B37570FA4D4078094E7D205F4040BC1FB75F3EF94D4065AA6054525D4040BC1FB75F3EF94D40
12078	Усадище	3	29	953	32.811298000000001	32.834600000000002	60.109966	60.093522999999998	0103000020E61000000100000005000000B5A7E49CD86740403F36C98FF80B4E40B5A7E49CD867404002D6AA5D130E4E40ED9E3C2CD46A404002D6AA5D130E4E40ED9E3C2CD46A40403F36C98FF80B4E40B5A7E49CD86740403F36C98FF80B4E40
7783	Сясьстрой	3	29	953	32.489269999999998	32.601056	60.160046999999999	60.133983000000001	0103000020E61000000100000005000000FB743C66A03E4040289CDD5A26114E40FB743C66A03E404055698B6B7C144E4044882B67EF4C404055698B6B7C144E4044882B67EF4C4040289CDD5A26114E40FB743C66A03E4040289CDD5A26114E40
10324	Старая Ладога	3	29	953	32.285702999999998	32.298459000000001	60.009408000000001	59.991498	0103000020E610000001000000050000003EAF78EA9124404053060E68E9FE4D403EAF78EA912440400F29064834014E4033198EE7332640400F29064834014E4033198EE73326404053060E68E9FE4D403EAF78EA9124404053060E68E9FE4D40
11752	Сорзуй	3	29	953	33.472017999999998	33.489454000000002	60.235151999999999	60.228259000000001	0103000020E61000000100000005000000C98FF8156BBC404043024697371D4E40C98FF8156BBC404064CBF275191E4E40BD72BD6DA6BE404064CBF275191E4E40BD72BD6DA6BE404043024697371D4E40C98FF8156BBC404043024697371D4E40
12190	Селиваново	3	29	953	32.667217000000001	32.692559000000003	60.209457	60.198444000000002	0103000020E61000000100000005000000E92ADD5D67554040310BED9C66194E40E92ADD5D675540408A75AA7CCF1A4E4076C6F7C5A55840408A75AA7CCF1A4E4076C6F7C5A5584040310BED9C66194E40E92ADD5D67554040310BED9C66194E40
12708	Свирица	3	29	953	32.891347000000003	32.935149000000003	60.470702000000003	60.454808	0103000020E61000000100000005000000A13193A817724040C6FA0626373A4E40A13193A817724040B61490F63F3C4E408DF161F6B2774040B61490F63F3C4E408DF161F6B2774040C6FA0626373A4E40A13193A817724040C6FA0626373A4E40
11638	Рыбежно	3	29	953	33.088895999999998	33.105676000000003	60.350603	60.342007000000002	0103000020E61000000100000005000000635FB2F1608B40406500A8E2C62B4E40635FB2F1608B40409370218FE02C4E406EFC89CA868D40409370218FE02C4E406EFC89CA868D40406500A8E2C62B4E40635FB2F1608B40406500A8E2C62B4E40
12227	Потанино	3	29	953	32.762788999999998	32.793008	60.275857000000002	60.268267000000002	0103000020E61000000100000005000000D05FE811A36140404BCCB39256224E40D05FE811A3614040B4AF3C484F234E40B2BB404981654040B4AF3C484F234E40B2BB4049816540404BCCB39256224E40D05FE811A36140404BCCB39256224E40
11403	Паша	3	29	953	32.993099000000001	33.049855000000001	60.416739	60.377023999999999	0103000020E610000001000000050000005C5837DE1D7F40404FE78A5242304E405C5837DE1D7F4040DFFB1BB457354E4063450DA661864040DFFB1BB457354E4063450DA6618640404FE78A5242304E405C5837DE1D7F40404FE78A5242304E40
11257	Новая Ладога	3	29	953	32.283887999999997	32.324267999999996	60.115338000000001	60.088147999999997	0103000020E6100000010000000500000009DD257156244040999A046F480B4E4009DD25715624404037FE4465C30E4E40D591239D8129404037FE4465C30E4E40D591239D81294040999A046F480B4E4009DD257156244040999A046F480B4E40
58999	Николаевщина	3	29	953	33.194448000000001	33.231611000000001	60.314625999999997	60.303978999999998	0103000020E61000000100000005000000E5620CACE3984040DCD5ABC8E8264E40E5620CACE3984040533C2EAA45284E406A32E36DA59D4040533C2EAA45284E406A32E36DA59D4040DCD5ABC8E8264E40E5620CACE3984040DCD5ABC8E8264E40
11940	Немятово-2	3	29	953	32.328633000000004	32.361187999999999	60.112983999999997	60.102777000000003	0103000020E6100000010000000500000075B169A5102A4040F8E3F6CB270D4E4075B169A5102A4040527C7C42760E4E4094DA8B683B2E4040527C7C42760E4E4094DA8B683B2E4040F8E3F6CB270D4E4075B169A5102A4040F8E3F6CB270D4E40
11500	Надкопанье	3	29	953	32.984071	33.000554999999999	60.424075999999999	60.418315999999997	0103000020E6100000010000000500000094F8DC09F67D40405FB2F1608B354E4094F8DC09F67D40405E82531F48364E40B56CAD2F128040405E82531F48364E40B56CAD2F128040405FB2F1608B354E4094F8DC09F67D40405FB2F1608B354E40
58985	Лесозавод	3	29	953	33.031959999999998	33.083775000000003	60.391737999999997	60.373128000000001	0103000020E61000000100000005000000DC63E94317844040679C86A8C22F4E40DC63E94317844040DB4C857824324E40789CA223B98A4040DB4C857824324E40789CA223B98A4040679C86A8C22F4E40DC63E94317844040679C86A8C22F4E40
8521	Колчаново	3	29	953	32.573577	32.599035000000001	60.048166000000002	60.003672999999999	0103000020E61000000100000005000000705E9CF86A49404069705B5B78004E40705E9CF86A494040BB63B14D2A064E406614CB2DAD4C4040BB63B14D2A064E406614CB2DAD4C404069705B5B78004E40705E9CF86A49404069705B5B78004E40
18948	Кисельня	3	29	953	32.134247000000002	32.163666999999997	60.008724999999998	59.998210999999998	0103000020E61000000100000005000000064B75012F114040F4C0C760C5FF4D40064B75012F1140402CD49AE61D014E409B374E0AF31440402CD49AE61D014E409B374E0AF3144040F4C0C760C5FF4D40064B75012F114040F4C0C760C5FF4D40
11830	Иссад	3	29	953	32.336440000000003	32.356974999999998	60.074275999999998	60.055681	0103000020E610000001000000050000007B884677102B40401901158E20074E407B884677102B404058703FE081094E40AB3E575BB12D404058703FE081094E40AB3E575BB12D40401901158E20074E407B884677102B40401901158E20074E40
10371	Вындин Остров	3	29	953	32.348979999999997	32.359499	59.812288000000002	59.798651999999997	0103000020E61000000100000005000000A27A6B60AB2C404047718E3A3AE64D40A27A6B60AB2C404075779D0DF9E74D40ECF82F10042E404075779D0DF9E74D40ECF82F10042E404047718E3A3AE64D40A27A6B60AB2C404047718E3A3AE64D40
10401	Волхов	3	29	953	32.234625000000001	32.389772999999998	59.965218999999998	59.870094999999999	0103000020E6100000010000000500000079E92631081E4040E1B4E0455FEF4D4079E92631081E4040293DD34B8CFB4D4091EEE714E4314040293DD34B8CFB4D4091EEE714E4314040E1B4E0455FEF4D4079E92631081E4040E1B4E0455FEF4D40
12019	Бережки	3	29	953	32.323540000000001	32.339215000000003	59.758381	59.747430000000001	0103000020E6100000010000000500000053793BC2692940404F0647C9ABDF4D4053793BC2692940403274ECA012E14D4005A8A9656B2B40403274ECA012E14D4005A8A9656B2B40404F0647C9ABDF4D4053793BC2692940404F0647C9ABDF4D40
12681	Аврово	3	29	953	32.568600000000004	32.584411000000003	60.101202999999998	60.095390000000002	0103000020E61000000100000005000000B84082E2C7484040C72E51BD350C4E40B84082E2C7484040E8A04B38F40C4E401A36CAFACD4A4040E8A04B38F40C4E401A36CAFACD4A4040C72E51BD350C4E40B84082E2C7484040C72E51BD350C4E40
9641	Ущевицы	3	29	1020	28.995875000000002	29.016293000000001	59.471977000000003	59.455851000000003	0103000020E610000001000000050000006DE7FBA9F1FE3C40A96C585359BA4D406DE7FBA9F1FE3C406BBB09BE69BC4D405B272EC72B043D406BBB09BE69BC4D405B272EC72B043D40A96C585359BA4D406DE7FBA9F1FE3C40A96C585359BA4D40
9421	Торосово	3	29	1020	29.55592	29.568325999999999	59.52149	59.505204999999997	0103000020E610000001000000050000003C31EBC5508E3D404963B48EAAC04D403C31EBC5508E3D4074982F2FC0C24D406C770FD07D913D4074982F2FC0C24D406C770FD07D913D404963B48EAAC04D403C31EBC5508E3D404963B48EAAC04D40
10156	Терпилицы	3	29	1020	29.352892000000001	29.372233000000001	59.494005999999999	59.481482999999997	0103000020E6100000010000000500000021054F21575A3D403C4A253CA1BD4D4021054F21575A3D408E03AF963BBF4D40F27D71A94A5F3D408E03AF963BBF4D40F27D71A94A5F3D403C4A253CA1BD4D4021054F21575A3D403C4A253CA1BD4D40
9378	Сумино	3	29	1020	29.463394000000001	29.493352999999999	59.478923999999999	59.466563999999998	0103000020E61000000100000005000000A2293BFDA0763D40D7BE805EB8BB4D40A2293BFDA0763D407FA2B2614DBD4D402C62D8614C7E3D407FA2B2614DBD4D402C62D8614C7E3D40D7BE805EB8BB4D40A2293BFDA0763D40D7BE805EB8BB4D40
17662	Сельцо	3	29	1020	29.520804999999999	29.526608	59.594898999999998	59.589725000000001	0103000020E61000000100000005000000E197FA7953853D401A51DA1B7CCB4D40E197FA7953853D4028B682A625CC4D40DDCF29C8CF863D4028B682A625CC4D40DDCF29C8CF863D401A51DA1B7CCB4D40E197FA7953853D401A51DA1B7CCB4D40
9544	Реполка	3	29	1020	29.583103000000001	29.609801000000001	59.268089000000003	59.257989000000002	0103000020E610000001000000050000001233FB3C46953D4027DD96C805A14D401233FB3C46953D406CB587BD50A24D406F1118EB1B9C3D406CB587BD50A24D406F1118EB1B9C3D4027DD96C805A14D401233FB3C46953D4027DD96C805A14D40
58469	Рабитицы	3	29	1020	29.375313999999999	29.400808000000001	59.413147000000002	59.399920000000002	0103000020E610000001000000050000001FBB0B9414603D4017821C9430B34D401FBB0B9414603D4063B83A00E2B44D40A5F9635A9B663D4063B83A00E2B44D40A5F9635A9B663D4017821C9430B34D401FBB0B9414603D4017821C9430B34D40
58914	Остроговицы	3	29	1020	29.079094999999999	29.092102000000001	59.392685999999998	59.378562000000002	0103000020E61000000100000005000000F146E6913F143D4012C138B874B04D40F146E6913F143D406CCCEB8843B24D406DE525FF93173D406CCCEB8843B24D406DE525FF93173D4012C138B874B04D40F146E6913F143D4012C138B874B04D40
9933	Курск	3	29	1020	29.114909999999998	29.147627	59.325524000000001	59.302925000000002	0103000020E61000000100000005000000BDFBE3BD6A1D3D400612143FC6A64D40BDFBE3BD6A1D3D4014083BC5AAA94D40B00111E2CA253D4014083BC5AAA94D40B00111E2CA253D400612143FC6A64D40BDFBE3BD6A1D3D400612143FC6A64D40
9787	Курковицы	3	29	1020	29.663889000000001	29.680821999999999	59.431220000000003	59.42174	0103000020E61000000100000005000000952C27A1F4A93D4020B58993FBB54D40952C27A1F4A93D40C9B08A3732B74D40B665C0594AAE3D40C9B08A3732B74D40B665C0594AAE3D4020B58993FBB54D40952C27A1F4A93D4020B58993FBB54D40
52928	Клопицы	3	29	1020	29.459962000000001	29.485527999999999	59.540101999999997	59.52411	0103000020E610000001000000050000001B67D311C0753D40D7C0560916C34D401B67D311C0753D408940F50F22C54D40D34A21904B7C3D408940F50F22C54D40D34A21904B7C3D40D7C0560916C34D401B67D311C0753D40D7C0560916C34D40
9800	Кикерино	3	29	1020	29.613061999999999	29.642634999999999	59.471528999999997	59.456834000000001	0103000020E610000001000000050000009C6B98A1F19C3D40B6D9588979BA4D409C6B98A1F19C3D40CB0EF10F5BBC4D40D44334BA83A43D40CB0EF10F5BBC4D40D44334BA83A43D40B6D9588979BA4D409C6B98A1F19C3D40B6D9588979BA4D40
9621	Каложицы	3	29	1020	28.999898999999999	29.017847	59.417679	59.407133999999999	0103000020E61000000100000005000000984D8061F9FF3C407A8B87F71CB44D40984D8061F9FF3C40ED9C668176B54D40EB54F99E91043D40ED9C668176B54D40EB54F99E91043D407A8B87F71CB44D40984D8061F9FF3C407A8B87F71CB44D40
9717	Калитино	3	29	1020	29.638376999999998	29.65363	59.413682000000001	59.402617999999997	0103000020E61000000100000005000000C284D1AC6CA33D40F56393FC88B34D40C284D1AC6CA33D40D1782288F3B44D403AAFB14B54A73D40D1782288F3B44D403AAFB14B54A73D40F56393FC88B34D40C284D1AC6CA33D40F56393FC88B34D40
52911	Извара	3	29	1020	29.506522	29.526033000000002	59.355828000000002	59.334313999999999	0103000020E610000001000000050000005BB4006DAB813D40274C18CDCAAA4D405BB4006DAB813D4024809BC58BAD4D40E59D4319AA863D4024809BC58BAD4D40E59D4319AA863D40274C18CDCAAA4D405BB4006DAB813D40274C18CDCAAA4D40
9446	Зимитицы	3	29	1020	29.102046999999999	29.140440999999999	59.552982	59.540134000000002	0103000020E61000000100000005000000A8A78FC01F1A3D4095BA641C23C54D40A8A78FC01F1A3D406AA33A1DC8C64D407D04FEF0F3233D406AA33A1DC8C64D407D04FEF0F3233D4095BA641C23C54D40A8A78FC01F1A3D4095BA641C23C54D40
8888	Волосово	3	29	1020	29.458696	29.521632	59.456569000000002	59.431246999999999	0103000020E6100000010000000500000057CEDE196D753D40C2BF081A33B74D4057CEDE196D753D4008AF5DDA70BA4D400D8CBCAC89853D4008AF5DDA70BA4D400D8CBCAC89853D40C2BF081A33B74D4057CEDE196D753D40C2BF081A33B74D40
10092	Большой Сабск	3	29	1020	29.002136	29.019760999999999	59.138463000000002	59.133555999999999	0103000020E61000000100000005000000EE2422FC8B003D40A017EE5C18914D40EE2422FC8B003D40605AD427B9914D407BBC900E0F053D40605AD427B9914D407BBC900E0F053D40A017EE5C18914D40EE2422FC8B003D40A017EE5C18914D40
52900	Большая Вруда	3	29	1020	29.233074999999999	29.249711999999999	59.408714000000003	59.401775000000001	0103000020E61000000100000005000000E4839ECDAA3B3D40DAACFA5C6DB34D40E4839ECDAA3B3D406CB587BD50B44D40336B2920ED3F3D406CB587BD50B44D40336B2920ED3F3D40DAACFA5C6DB34D40E4839ECDAA3B3D40DAACFA5C6DB34D40
9254	Беседа	3	29	1020	28.952441	28.977145	59.364313000000003	59.353695000000002	0103000020E610000001000000050000009A5E622CD3F33C401EE1B4E045AD4D409A5E622CD3F33C40FB40F2CEA1AE4D402E73BA2C26FA3C40FB40F2CEA1AE4D402E73BA2C26FA3C401EE1B4E045AD4D409A5E622CD3F33C401EE1B4E045AD4D40
9170	Бегуницы	3	29	1020	29.295103000000001	29.334423000000001	59.592115999999997	59.580719000000002	0103000020E6100000010000000500000095F3C5DE8B4B3D403A950C0055CA4D4095F3C5DE8B4B3D401BB80375CACB4D40BC07E8BE9C553D401BB80375CACB4D40BC07E8BE9C553D403A950C0055CA4D4095F3C5DE8B4B3D403A950C0055CA4D40
8118	при ж/д станции Большой Двор	3	29	906	34.340285000000002	34.381562000000002	59.509306000000002	59.501935000000003	0103000020E61000000100000005000000E12879758E2B4140E0DBF4673FC04D40E12879758E2B41400BD462F030C14D40BCB20B06D73041400BD462F030C14D40BCB20B06D7304140E0DBF4673FC04D40E12879758E2B4140E0DBF4673FC04D40
8399	Утишье	3	29	906	35.449444	35.466161	59.519691999999999	59.514660999999997	0103000020E6100000010000000500000014B1886187B9414069C36169E0C14D4014B1886187B9414015FF774485C24D40D8D5E429ABBB414015FF774485C24D40D8D5E429ABBB414069C36169E0C14D4014B1886187B9414069C36169E0C14D40
58957	Сёгла	3	29	906	33.902786999999996	33.914186999999998	59.519978999999999	59.513053999999997	0103000020E61000000100000005000000812040868EF340407E8AE3C0ABC14D40812040868EF34040ABCDFFAB8EC24D40D4B6611404F54040ABCDFFAB8EC24D40D4B6611404F540407E8AE3C0ABC14D40812040868EF340407E8AE3C0ABC14D40
7967	Сомино	3	29	906	34.836613	34.884053000000002	59.349612999999998	59.338650999999999	0103000020E6100000010000000500000048348122166B4140FCE07CEA58AB4D4048348122166B4140D3A0681EC0AC4D40217711A628714140D3A0681EC0AC4D40217711A628714140FCE07CEA58AB4D4048348122166B4140FCE07CEA58AB4D40
32501	Совхозный	3	29	906	34.271608000000001	34.291353000000001	59.509543000000001	59.502324000000002	0103000020E610000001000000050000007EAA0A0DC42241407AFF1F274CC04D407EAA0A0DC4224140EF737CB438C14D40B64B1B0E4B254140EF737CB438C14D40B64B1B0E4B2541407AFF1F274CC04D407EAA0A0DC42241407AFF1F274CC04D40
58983	Сидорово	3	29	906	35.074271000000003	35.101624999999999	59.915318999999997	59.903986000000003	0103000020E6100000010000000500000047054EB6818941405C0531D0B5F34D4047054EB6818941402634492C29F54D405EBA490C028D41402634492C29F54D405EBA490C028D41405C0531D0B5F34D4047054EB6818941405C0531D0B5F34D40
58977	Сельхозтехника	3	29	906	33.799228999999997	33.814383999999997	59.492137999999997	59.480226000000002	0103000020E61000000100000005000000E481C8224DE640402E58AA0B78BD4D40E481C8224DE64040368FC360FEBE4D405D3123BC3DE84040368FC360FEBE4D405D3123BC3DE840402E58AA0B78BD4D40E481C8224DE640402E58AA0B78BD4D40
46215	Радогощь	3	29	906	34.844346999999999	34.872869000000001	59.785910999999999	59.776156	0103000020E61000000100000005000000E4BCFF8F136C41400E4C6E1459E34D40E4BCFF8F136C414088484DBB98E44D409B58E02BBA6F414088484DBB98E44D409B58E02BBA6F41400E4C6E1459E34D40E4BCFF8F136C41400E4C6E1459E34D40
7425	Пикалёво	3	29	906	34.110962999999998	34.227500999999997	59.537224000000002	59.502949000000001	0103000020E6100000010000000500000074081C09340E4140284701A260C04D4074081C09340E41402B508BC1C3C44D405567B5C01E1D41402B508BC1C3C44D405567B5C01E1D4140284701A260C04D4074081C09340E4140284701A260C04D40
8436	Ольеши	3	29	906	35.403593000000001	35.414248000000001	59.698208999999999	59.692718999999997	0103000020E6100000010000000500000080F277EFA8B34140AE282504ABD84D4080F277EFA8B34140ED629AE95ED94D407A37161406B54140ED629AE95ED94D407A37161406B54140AE282504ABD84D4080F277EFA8B34140AE282504ABD84D40
59000	Озеро-Село	3	29	906	35.069600000000001	35.072915000000002	59.467826000000002	59.463011999999999	0103000020E610000001000000050000009BE61DA7E8884140E9D32AFA43BB4D409BE61DA7E8884140F81BEDB8E1BB4D40A5315A4755894140F81BEDB8E1BB4D40A5315A4755894140E9D32AFA43BB4D409BE61DA7E8884140E9D32AFA43BB4D40
8837	Коли	3	29	906	34.482353000000003	34.508870999999999	59.505378999999998	59.494883000000002	0103000020E6100000010000000500000052103CBEBD3D4140562C7E5358BF4D4052103CBEBD3D4140E78A5242B0C04D40007157AF22414140E78A5242B0C04D40007157AF22414140562C7E5358BF4D4052103CBEBD3D4140562C7E5358BF4D40
8529	Климово	3	29	906	34.685479999999998	34.699117000000001	59.197600999999999	59.192208999999998	0103000020E61000000100000005000000F20703CFBD574140997FF44D9A984D40F20703CFBD574140155454FD4A994D40F08975AA7C594140155454FD4A994D40F08975AA7C594140997FF44D9A984D40F20703CFBD574140997FF44D9A984D40
8329	Заборье	3	29	906	35.199263000000002	35.253583999999996	59.533245000000001	59.503135999999998	0103000020E61000000100000005000000C4263273819941405AB8ACC266C04D40C426327381994140B5E0455F41C44D40F964C57075A04140B5E0455F41C44D40F964C57075A041405AB8ACC266C04D40C4263273819941405AB8ACC266C04D40
8572	Журавлёво	3	29	906	34.701326999999999	34.732390000000002	59.354506999999998	59.348246000000003	0103000020E61000000100000005000000A1664815C55941403E7B2E5393AC4D40A1664815C5594140FE99417C60AD4D406FF59CF4BE5D4140FE99417C60AD4D406FF59CF4BE5D41403E7B2E5393AC4D40A1664815C55941403E7B2E5393AC4D40
59007	Ефимовский	3	29	906	34.64873	34.690770999999998	59.509793999999999	59.483781	0103000020E6100000010000000500000090F7AA95095341408DB62A89ECBD4D4090F7AA950953414038D906EE40C14D403A03232F6B58414038D906EE40C14D403A03232F6B5841408DB62A89ECBD4D4090F7AA95095341408DB62A89ECBD4D40
51017	Ефимовский	3	29	906	34.64873	34.690770999999998	59.509793999999999	59.483781	0103000020E6100000010000000500000090F7AA95095341408DB62A89ECBD4D4090F7AA950953414038D906EE40C14D403A03232F6B58414038D906EE40C14D403A03232F6B5841408DB62A89ECBD4D4090F7AA95095341408DB62A89ECBD4D40
8082	Дыми	3	29	906	33.779268999999999	33.799031999999997	59.571669	59.566099000000001	0103000020E61000000100000005000000B0E42A16BFE340402FA699EE75C84D40B0E42A16BFE340408A9125732CC94D408E3A3AAE46E640408A9125732CC94D408E3A3AAE46E640402FA699EE75C84D40B0E42A16BFE340402FA699EE75C84D40
7109	Бокситогорск	3	29	906	33.800953999999997	33.885486	59.496482	59.450297999999997	0103000020E61000000100000005000000D9CC21A985E6404023BA675DA3B94D40D9CC21A985E64040BE86E0B88CBF4D406E88F19A57F14040BE86E0B88CBF4D406E88F19A57F1404023BA675DA3B94D40D9CC21A985E6404023BA675DA3B94D40
7525	Советск	3	28	\N	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
5894	Светлый	3	28	\N	20.117393	20.149086	54.692734000000002	54.667681000000002	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
50985	Светлогорск	3	28	\N	20.124517000000001	20.178308000000001	54.951715	54.936630999999998	0103000020E61000000100000005000000C9CB9A58E01F3440BBB54C86E3774B40C9CB9A58E01F34406B0E10CCD1794B407C9DD497A52D34406B0E10CCD1794B407C9DD497A52D3440BBB54C86E3774B40C9CB9A58E01F3440BBB54C86E3774B40
47440	Приморск	3	28	\N	19.998069999999998	20.012550999999998	54.742601000000001	54.728409999999997	0103000020E61000000100000005000000641EF98381FF3340280AF4893C5D4B40641EF98381FF33400B7DB08C0D5F4B403788D68A360334400B7DB08C0D5F4B403788D68A36033440280AF4893C5D4B40641EF98381FF3340280AF4893C5D4B40
3708	Пионерский	3	28	\N	20.212786000000001	20.249365000000001	54.9572	54.942686999999999	0103000020E61000000100000005000000F20BAF2479363440A3AEB5F7A9784B40F20BAF247936344098DD9387857A4B405DC47762D63F344098DD9387857A4B405DC47762D63F3440A3AEB5F7A9784B40F20BAF2479363440A3AEB5F7A9784B40
50968	Неман	3	28	\N	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
6464	Люблино	3	28	\N	20.279952999999999	20.290794999999999	54.759721999999996	54.747683000000002	0103000020E61000000100000005000000C66AF3FFAA47344039639813B45F4B40C66AF3FFAA4734409E060C923E614B401FD7868A714A34409E060C923E614B401FD7868A714A344039639813B45F4B40C66AF3FFAA47344039639813B45F4B40
56665	Коса	3	28	\N	19.868397999999999	19.88552	54.639721000000002	54.618769999999998	0103000020E610000001000000050000006CE9D1544FDE33407ADFF8DA334F4B406CE9D1544FDE33403FC8B260E2514B4034F44F70B1E233403FC8B260E2514B4034F44F70B1E233407ADFF8DA334F4B406CE9D1544FDE33407ADFF8DA334F4B40
1269	Калининград	3	28	\N	20.283932	20.648828000000002	54.778762	54.630732000000002	0103000020E61000000100000005000000B2497EC4AF483440354580D3BB504B40B2497EC4AF4834400CAF2479AE634B40A6BA809719A634400CAF2479AE634B40A6BA809719A63440354580D3BB504B40B2497EC4AF483440354580D3BB504B40
50975	Гусев	3	28	\N	22.167556000000001	22.235989	54.616970999999999	54.5747	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
7926	Балтийск	3	28	\N	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
45690	Щеглы	3	28	962	22.048852	22.061105000000001	54.774197000000001	54.766443000000002	0103000020E610000001000000050000001D588E90810C3640C39FE1CD1A624B401D588E90810C3640A6D425E318634B40419FC893A40F3640A6D425E318634B40419FC893A40F3640C39FE1CD1A624B401D588E90810C3640C39FE1CD1A624B40
25139	Шоссейное	3	28	962	21.892806	21.905787	54.621975999999997	54.617826000000001	0103000020E610000001000000050000002EAC1BEF8EE435402B4F20EC144F4B402EAC1BEF8EE43540CD72D9E89C4F4B40572426A8E1E73540CD72D9E89C4F4B40572426A8E1E735402B4F20EC144F4B402EAC1BEF8EE435402B4F20EC144F4B40
8015	Черняховск	3	28	962	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
45725	Тимофеевка	3	28	962	21.883068000000002	21.896992000000001	54.650651000000003	54.641373000000002	0103000020E61000000100000005000000E62494BE10E23540CAC4AD8218524B40E62494BE10E235400B0E2F8848534B400DC68844A1E535400B0E2F8848534B400DC68844A1E53540CAC4AD8218524B40E62494BE10E23540CAC4AD8218524B40
46718	Совхозное	3	28	962	21.675988	21.682967999999999	54.650208999999997	54.647083000000002	0103000020E610000001000000050000000B7DB08C0DAD35401766A19DD3524B400B7DB08C0DAD35404D486B0C3A534B40EB36A8FDD6AE35404D486B0C3A534B40EB36A8FDD6AE35401766A19DD3524B400B7DB08C0DAD35401766A19DD3524B40
45759	Свобода	3	28	962	21.709378999999998	21.741152	54.550367999999999	54.527144999999997	0103000020E610000001000000050000001C78B5DC99B53540FD9FC37C79434B401C78B5DC99B53540E961687572464B40705D3123BCBD3540E961687572464B40705D3123BCBD3540FD9FC37C79434B401C78B5DC99B53540FD9FC37C79434B40
45813	Пеньки	3	28	962	21.611642	21.627084	54.572502999999998	54.566020999999999	0103000020E610000001000000050000002BDCF291949C3540B3EC496073484B402BDCF291949C354052EE3EC747494B4049D8B79388A0354052EE3EC747494B4049D8B79388A03540B3EC496073484B402BDCF291949C3540B3EC496073484B40
47098	Партизанское	3	28	962	21.519879	21.526239	54.712575999999999	54.710349999999998	0103000020E610000001000000050000008FE046CA16853540575BB1BFEC5A4B408FE046CA168535400EF5BBB0355B4B4037E15E99B78635400EF5BBB0355B4B4037E15E99B7863540575BB1BFEC5A4B408FE046CA16853540575BB1BFEC5A4B40
45843	Междуречье	3	28	962	21.514534000000001	21.525466999999999	54.626724000000003	54.616830999999998	0103000020E6100000010000000500000019AE0E80B883354059147651F44E4B4019AE0E80B883354025CFF57D38504B4092205C018586354025CFF57D38504B4092205C018586354059147651F44E4B4019AE0E80B883354059147651F44E4B40
9449	Краснополянское	3	28	962	21.957295999999999	21.980651999999999	54.606000999999999	54.594755999999997	0103000020E610000001000000050000007497C45911F53540C58CF0F6204C4B407497C45911F53540F12BD670914D4B40CAC16C020CFB3540F12BD670914D4B40CAC16C020CFB3540C58CF0F6204C4B407497C45911F53540C58CF0F6204C4B40
45560	Каменское	3	28	962	21.526437000000001	21.558479999999999	54.671159000000003	54.651516000000001	0103000020E6100000010000000500000084674293C48635400E6954E064534B4084674293C486354042B5C189E8554B405778978BF88E354042B5C189E8554B405778978BF88E35400E6954E064534B4084674293C48635400E6954E064534B40
9239	Калужское	3	28	962	21.891351	21.957709000000001	54.831913999999998	54.778740999999997	0103000020E61000000100000005000000C44142942FE43540F486FBC8AD634B40C44142942FE43540D28A6F287C6A4B40BA15C26A2CF53540D28A6F287C6A4B40BA15C26A2CF53540F486FBC8AD634B40C44142942FE43540F486FBC8AD634B40
45641	Калиновка	3	28	962	21.771156000000001	21.786256999999999	54.811264000000001	54.798015999999997	0103000020E610000001000000050000003B1DC87A6AC53540A5D7666325664B403B1DC87A6AC535400936AE7FD7674B404640852348C935400936AE7FD7674B404640852348C93540A5D7666325664B403B1DC87A6AC53540A5D7666325664B40
9603	Заовражное	3	28	962	21.607213000000002	21.625610999999999	54.628179000000003	54.619323000000001	0103000020E61000000100000005000000C0B4A84F729B35408F54DFF9454F4B40C0B4A84F729B35405A84622B68504B409204E10A28A035405A84622B68504B409204E10A28A035408F54DFF9454F4B40C0B4A84F729B35408F54DFF9454F4B40
45712	Загорское	3	28	962	21.95196	21.990227999999998	54.751139000000002	54.739908	0103000020E61000000100000005000000A4198BA6B3F335403E062B4EB55E4B40A4198BA6B3F3354005E09F5225604B405F950B957FFD354005E09F5225604B405F950B957FFD35403E062B4EB55E4B40A4198BA6B3F335403E062B4EB55E4B40
48496	Железнодорожный	3	28	962	21.845383999999999	21.863924999999998	54.629575000000003	54.613478000000001	0103000020E61000000100000005000000C98FF8156BD8354062687572864E4B40C98FF8156BD835408AB0E1E995504B40613255302ADD35408AB0E1E995504B40613255302ADD354062687572864E4B40C98FF8156BD8354062687572864E4B40
9041	Доваторовка	3	28	962	21.702013000000001	21.756792000000001	54.674424000000002	54.648453000000003	0103000020E61000000100000005000000EA5DBC1FB7B335401EFF058200534B40EA5DBC1FB7B335409AD18F8653564B40DBDFD91EBDC135409AD18F8653564B40DBDFD91EBDC135401EFF058200534B40EA5DBC1FB7B335401EFF058200534B40
45602	Глушково	3	28	962	21.414794000000001	21.433084000000001	54.663313000000002	54.656526999999997	0103000020E61000000100000005000000B89388F02F6A354072F8A41309544B40B89388F02F6A35407E01BD70E7544B40BE6BD097DE6E35407E01BD70E7544B40BE6BD097DE6E354072F8A41309544B40B89388F02F6A354072F8A41309544B40
45778	Володаровка	3	28	962	21.670328999999999	21.695212000000001	54.504463000000001	54.490454999999997	0103000020E61000000100000005000000758F6CAE9AAB35407094BC3AC73E4B40758F6CAE9AAB354062855B3E92404B4069C9E369F9B1354062855B3E92404B4069C9E369F9B135407094BC3AC73E4B40758F6CAE9AAB35407094BC3AC73E4B40
59079	Калининград	3	28	7463	20.35887	20.509571000000001	54.778762	54.717047999999998	0103000020E61000000100000005000000F98381E7DE5B3440C3D4963AC85B4B40F98381E7DE5B34400CAF2479AE634B4072FDBB3E738234400CAF2479AE634B4072FDBB3E73823440C3D4963AC85B4B40F98381E7DE5B3440C3D4963AC85B4B40
7766	Яснополянка	3	28	879	21.390369	21.419312999999999	55.194799000000003	55.179827000000003	0103000020E610000001000000050000004A5F0839EF6335400AF8359204974B404A5F0839EF6335409225732CEF984B40A3C9C518586B35409225732CEF984B40A3C9C518586B35400AF8359204974B404A5F0839EF6335400AF8359204974B40
7303	Ясное	3	28	879	21.524388999999999	21.622781	55.184685000000002	55.162509999999997	0103000020E61000000100000005000000D461855B3E863540F0A2AF20CD944B40D461855B3E863540E88711C2A3974B40F7915B936E9F3540E88711C2A3974B40F7915B936E9F3540F0A2AF20CD944B40D461855B3E863540F0A2AF20CD944B40
7193	Тимирязево	3	28	879	21.591538	21.621865	55.091124000000001	55.073773000000003	0103000020E610000001000000050000005C57CC086F973540F629C76471894B405C57CC086F973540BBF083F3A98B4B40EC866D8B329F3540BBF083F3A98B4B40EC866D8B329F3540F629C76471894B405C57CC086F973540F629C76471894B40
50608	Советское	3	28	879	21.608723000000001	21.643927999999999	54.864103999999998	54.836984999999999	0103000020E61000000100000005000000B1524145D59B35400C1F1153226B4B40B1524145D59B3540E02BBAF59A6E4B408BFA2477D8A43540E02BBAF59A6E4B408BFA2477D8A435400C1F1153226B4B40B1524145D59B35400C1F1153226B4B40
6643	Славск	3	28	879	21.651122999999998	21.695571999999999	55.052902000000003	55.033800999999997	0103000020E6100000010000000500000064AC36FFAFA635403AC9569753844B4064AC36FFAFA635404EF2237EC5864B406803B00111B235404EF2237EC5864B406803B00111B235403AC9569753844B4064AC36FFAFA635403AC9569753844B40
7253	Ржевское	3	28	879	21.734262000000001	21.763286999999998	55.100057	55.068092	0103000020E6100000010000000500000010B22C98F8BB3540438F183DB7884B4010B22C98F8BB3540315EF3AACE8C4B404276DEC666C33540315EF3AACE8C4B404276DEC666C33540438F183DB7884B4010B22C98F8BB3540438F183DB7884B40
7162	Прохладное	3	28	879	21.310697999999999	21.334036000000001	55.161645999999998	55.151760000000003	0103000020E61000000100000005000000BFEE74E7894F3540A56B26DF6C934B40BFEE74E7894F3540BDC3EDD0B0944B40C9AF1F6283553540BDC3EDD0B0944B40C9AF1F6283553540A56B26DF6C934B40BFEE74E7894F3540A56B26DF6C934B40
7041	Приозерье	3	28	879	21.727525	21.756325	55.01023	54.998596999999997	0103000020E61000000100000005000000BC0512143FBA35401D71C806D27F4B40BC0512143FBA354013B875374F814B40AF25E4839EC1354013B875374F814B40AF25E4839EC135401D71C806D27F4B40BC0512143FBA35401D71C806D27F4B40
6776	Придорожное	3	28	879	21.701958999999999	21.733463	54.870767000000001	54.827314000000001	0103000020E610000001000000050000000322C495B3B33540F0C2D66CE5694B400322C495B3B33540D0B7054B756F4B4078D32D3BC4BB3540D0B7054B756F4B4078D32D3BC4BB3540F0C2D66CE5694B400322C495B3B33540F0C2D66CE5694B40
7002	Охотное	3	28	879	21.609027999999999	21.629168	54.931412000000002	54.918773000000002	0103000020E6100000010000000500000029594E42E99B354052B9895A9A754B4029594E42E99B35400D8D278238774B4092B06F2711A135400D8D278238774B4092B06F2711A1354052B9895A9A754B4029594E42E99B354052B9895A9A754B40
7383	Мысовка	3	28	879	21.262592999999999	21.279724000000002	55.197172999999999	55.192677000000003	0103000020E6100000010000000500000095287B4B3943354080D8D2A3A9984B4095287B4B39433540BD5301F73C994B4004E8F7FD9B473540BD5301F73C994B4004E8F7FD9B47354080D8D2A3A9984B4095287B4B3943354080D8D2A3A9984B40
48565	Майское	3	28	879	21.623563000000001	21.639399999999998	55.033099	55.026685000000001	0103000020E61000000100000005000000E3FE23D3A19F35409A25016A6A834B40E3FE23D3A19F3540E14389963C844B40F90FE9B7AFA33540E14389963C844B40F90FE9B7AFA335409A25016A6A834B40E3FE23D3A19F35409A25016A6A834B40
47914	Лужки	3	28	879	21.756298000000001	21.764472999999999	55.071339999999999	55.067405999999998	0103000020E61000000100000005000000BC07E8BE9CC13540EFC682C2A0884B40BC07E8BE9CC13540C5724BAB21894B40CDACA580B4C33540C5724BAB21894B40CDACA580B4C33540EFC682C2A0884B40BC07E8BE9CC13540EFC682C2A0884B40
6896	Красное	3	28	879	21.658417	21.704841999999999	54.786586	54.768079	0103000020E6100000010000000500000064213A048EA8354048DFA46950624B4064213A048EA83540E8BE9CD9AE644B40E4D87A8670B43540E8BE9CD9AE644B40E4D87A8670B4354048DFA46950624B4064213A048EA8354048DFA46950624B40
7093	Заповедное	3	28	879	21.305918999999999	21.491572999999999	55.071345000000001	55.022804000000001	0103000020E610000001000000050000009B3924B5504E3540E71BD13DEB824B409B3924B5504E3540D7DD3CD521894B40BB9866BAD77D3540D7DD3CD521894B40BB9866BAD77D3540E71BD13DEB824B409B3924B5504E3540E71BD13DEB824B40
6815	Громово	3	28	879	21.405632000000001	21.470237999999998	54.974215000000001	54.951653	0103000020E610000001000000050000000936AE7FD7673540F511F8C3CF794B400936AE7FD7673540E622BE13B37C4B4021567F8461783540E622BE13B37C4B4021567F8461783540F511F8C3CF794B400936AE7FD7673540F511F8C3CF794B40
6973	Гастеллово	3	28	879	21.539048999999999	21.596298999999998	55.044798999999998	55.006224000000003	0103000020E6100000010000000500000006F1811DFF893540A439B2F2CB804B4006F1811DFF8935405EF23FF9BB854B4033A31F0DA79835405EF23FF9BB854B4033A31F0DA7983540A439B2F2CB804B4006F1811DFF893540A439B2F2CB804B40
6856	Высокое	3	28	879	21.657708	21.665011	54.792011000000002	54.788226999999999	0103000020E610000001000000050000004C512E8D5FA835407F69519FE4644B404C512E8D5FA835404089CF9D60654B40F27A30293EAA35404089CF9D60654B40F27A30293EAA35407F69519FE4644B404C512E8D5FA835407F69519FE4644B40
7345	Вишневка	3	28	879	21.409269999999999	21.462755000000001	55.147598000000002	55.112983	0103000020E61000000100000005000000E23B31EBC56835408200193A768E4B40E23B31EBC56835403E7AC37DE4924B407C0F971C777635403E7AC37DE4924B407C0F971C777635408200193A768E4B40E23B31EBC56835408200193A768E4B40
6729	Большаково	3	28	879	21.633462000000002	21.669287000000001	54.893943	54.867902000000001	0103000020E610000001000000050000003E42CD902AA235400611A969176F4B403E42CD902AA235407BBE66B96C724B4051A3906456AB35407BBE66B96C724B4051A3906456AB35400611A969176F4B403E42CD902AA235400611A969176F4B40
6524	Взморье	3	28	865	20.230599000000002	20.261455999999999	54.704138999999998	54.692270999999998	0103000020E61000000100000005000000857D3B89083B34400F7C0C569C584B40857D3B89083B3440486B0C3A215A4B40CD57C9C7EE423440486B0C3A215A4B40CD57C9C7EE4234400F7C0C569C584B40857D3B89083B34400F7C0C569C584B40
50987	Светлогорск	3	28	7096	20.124517000000001	20.178308000000001	54.951715	54.936630999999998	0103000020E61000000100000005000000C9CB9A58E01F3440BBB54C86E3774B40C9CB9A58E01F34406B0E10CCD1794B407C9DD497A52D34406B0E10CCD1794B407C9DD497A52D3440BBB54C86E3774B40C9CB9A58E01F3440BBB54C86E3774B40
47873	Отрадное	3	28	6960	20.093247000000002	20.123304000000001	54.946224000000001	54.937055000000001	0103000020E610000001000000050000003B730F09DF173440D2C6116BF1774B403B730F09DF1734405C5837DE1D794B404B77D7D9901F34405C5837DE1D794B404B77D7D9901F3440D2C6116BF1774B403B730F09DF173440D2C6116BF1774B40
47807	Чистополье	3	28	680	20.943681999999999	20.949081	54.432578999999997	54.429609999999997	0103000020E61000000100000005000000E9D2BF2495F134406C04E275FD364B40E9D2BF2495F13440DBF7A8BF5E374B404641F0F8F6F23440DBF7A8BF5E374B404641F0F8F6F234406C04E275FD364B40E9D2BF2495F134406C04E275FD364B40
4873	Севское	3	28	680	21.101254999999998	21.120353999999999	54.402543999999999	54.390949999999997	0103000020E61000000100000005000000758E01D9EB193540832F4CA60A324B40758E01D9EB193540BB99D18F86334B405AF10D85CF1E3540BB99D18F86334B405AF10D85CF1E3540832F4CA60A324B40758E01D9EB193540832F4CA60A324B40
4713	Правдинск	3	28	680	20.986827999999999	21.037860999999999	54.450192999999999	54.434474999999999	0103000020E61000000100000005000000EFC682C2A0FC3440FDF675E09C374B40EFC682C2A0FC3440AEF199EC9F394B403ACB2C42B1093540AEF199EC9F394B403ACB2C42B1093540FDF675E09C374B40EFC682C2A0FC3440FDF675E09C374B40
50981	Новобобруйск	3	28	680	21.297132999999999	21.342524999999998	54.512695999999998	54.501021999999999	0103000020E61000000100000005000000F78F85E8104C3540CB49287D21404B40F78F85E8104C35401F65C405A0414B40F90FE9B7AF5735401F65C405A0414B40F90FE9B7AF573540CB49287D21404B40F78F85E8104C3540CB49287D21404B40
5292	Мозырь	3	28	680	21.4681	21.492668999999999	54.451166999999998	54.435825999999999	0103000020E61000000100000005000000F241CF66D57735408D5F7825C9374B40F241CF66D577354068041BD7BF394B40C6C03A8E1F7E354068041BD7BF394B40C6C03A8E1F7E35408D5F7825C9374B40F241CF66D57735408D5F7825C9374B40
5034	Липняки	3	28	680	21.276229000000001	21.293745999999999	54.407266	54.398372000000002	0103000020E61000000100000005000000F03499F1B646354031D28BDAFD324B40F03499F1B6463540E962D34A21344B40B05417F0324B3540E962D34A21344B40B05417F0324B354031D28BDAFD324B40F03499F1B646354031D28BDAFD324B40
48552	Крылово	3	28	680	21.538259	21.559576	54.343420999999999	54.326107	0103000020E6100000010000000500000015C78157CB89354093FFC9DFBD294B4015C78157CB8935403BE12538F52B4B4062A06B5F408F35403BE12538F52B4B4062A06B5F408F354093FFC9DFBD294B4015C78157CB89354093FFC9DFBD294B40
48545	Знаменка	3	28	680	21.353323	21.378422	54.368653000000002	54.360526999999998	0103000020E61000000100000005000000B3EC4960735A35409929ADBF252E4B40B3EC4960735A354041498105302F4B404016A243E060354041498105302F4B404016A243E06035409929ADBF252E4B40B3EC4960735A35409929ADBF252E4B40
48585	Ермаково	3	28	680	20.922922	20.944005000000001	54.418112000000001	54.396369999999997	0103000020E6100000010000000500000048C2BE9D44EC3440C98E8D40BC324B4048C2BE9D44EC34405708ABB184354B40AF42CA4FAAF134405708ABB184354B40AF42CA4FAAF13440C98E8D40BC324B4048C2BE9D44EC3440C98E8D40BC324B40
5182	Домново	3	28	680	20.819040999999999	20.840430000000001	54.434271000000003	54.420689000000003	0103000020E610000001000000050000004815C5ABACD13440BB641C23D9354B404815C5ABACD13440F54C2F3196374B40C993A46B26D73440F54C2F3196374B40C993A46B26D73440BB641C23D9354B404815C5ABACD13440BB641C23D9354B40
61710	Февральское	3	28	451	21.278977999999999	21.287089999999999	54.814853999999997	54.812410999999997	0103000020E61000000100000005000000B14D2A1A6B47354090F46915FD674B40B14D2A1A6B473540E481C8224D684B403602F1BA7E493540E481C8224D684B403602F1BA7E49354090F46915FD674B40B14D2A1A6B47354090F46915FD674B40
48275	Тургенево	3	28	451	21.003357000000001	21.015187999999998	54.871414000000001	54.836466000000001	0103000020E6100000010000000500000072361D01DC003540A41B6151116B4B4072361D01DC00354066A3737E8A6F4B40A94A5B5CE303354066A3737E8A6F4B40A94A5B5CE3033540A41B6151116B4B4072361D01DC003540A41B6151116B4B40
51015	Саранск	3	28	451	21.225563999999999	21.240494000000002	54.835061000000003	54.823475999999999	0103000020E61000000100000005000000AA27F38FBE3935403C855CA967694B40AA27F38FBE39354021956247E36A4B405DE2C803913D354021956247E36A4B405DE2C803913D35403C855CA967694B40AA27F38FBE3935403C855CA967694B40
3974	Полесск	3	28	451	21.087152	21.112206	54.873631000000003	54.855476000000003	0103000020E61000000100000005000000EFC7ED974F163540A741D13C806D4B40EFC7ED974F163540CAE2FE23D36F4B403C6A4C88B91C3540CAE2FE23D36F4B403C6A4C88B91C3540A741D13C806D4B40EFC7ED974F163540A741D13C806D4B40
60709	Новая-Деревня	3	28	451	21.270696000000001	21.284844	54.763109	54.755664000000003	0103000020E61000000100000005000000742843554C453540DD611399B9604B40742843554C4535404224438EAD614B403A765089EB4835404224438EAD614B403A765089EB483540DD611399B9604B40742843554C453540DD611399B9604B40
4231	Нахимово	3	28	451	21.040053	21.064910000000001	54.813105999999998	54.788849999999996	0103000020E61000000100000005000000501BD5E9400A35408CB96B09F9644B40501BD5E9400A354037177FDB13684B40F12E17F19D10354037177FDB13684B40F12E17F19D1035408CB96B09F9644B40501BD5E9400A35408CB96B09F9644B40
48290	Зеленое	3	28	451	21.092057	21.109923999999999	54.837601999999997	54.821339000000002	0103000020E610000001000000050000002D5E2C0C91173540F5F6E7A221694B402D5E2C0C911735403788D68A366B4B40A60BB1FA231C35403788D68A366B4B40A60BB1FA231C3540F5F6E7A221694B402D5E2C0C91173540F5F6E7A221694B40
48375	Заливино	3	28	451	21.046844	21.072087	54.901403999999999	54.890438000000003	0103000020E610000001000000050000008A03E8F7FD0B3540CE8E54DFF9714B408A03E8F7FD0B3540E63DCE3461734B407D772B4B74123540E63DCE3461734B407D772B4B74123540CE8E54DFF9714B408A03E8F7FD0B3540CE8E54DFF9714B40
48398	Залесье	3	28	451	21.507024000000001	21.54222	54.854185000000001	54.834516999999998	0103000020E6100000010000000500000080492A53CC8135405F7AFB73D16A4B4080492A53CC813540ECDD1FEF556D4B40B43C0FEECE8A3540ECDD1FEF556D4B40B43C0FEECE8A35405F7AFB73D16A4B4080492A53CC8135405F7AFB73D16A4B40
7248	Дальнее	3	28	451	21.527183000000001	21.534054999999999	54.764293000000002	54.758636000000003	0103000020E61000000100000005000000D6011077F5863540BDC804FC1A614B40D6011077F5863540E7C75F5AD4614B40E94317D4B7883540E7C75F5AD4614B40E94317D4B7883540BDC804FC1A614B40D6011077F5863540BDC804FC1A614B40
48387	Головкино	3	28	451	21.247492000000001	21.28903	54.987290999999999	54.971356999999998	0103000020E610000001000000050000008A05BEA25B3F3540CEDE196D557C4B408A05BEA25B3F35404C512E8D5F7E4B401990BDDEFD4935404C512E8D5F7E4B401990BDDEFD493540CEDE196D557C4B408A05BEA25B3F3540CEDE196D557C4B40
47771	Суворовка	3	28	472	22.041575999999999	22.065085	54.426090000000002	54.418573000000002	0103000020E610000001000000050000006A4C88B9A40A36408BFED0CC93354B406A4C88B9A40A36408A93FB1D8A364B40CD751A69A91036408A93FB1D8A364B40CD751A69A91036408BFED0CC93354B406A4C88B9A40A36408BFED0CC93354B40
48637	Первомайское	3	28	472	21.774632	21.783156999999999	54.493498000000002	54.488447000000001	0103000020E61000000100000005000000616F62484EC63540276A696E853E4B40616F62484EC635401A5245F12A3F4B402BA226FA7CC835401A5245F12A3F4B402BA226FA7CC83540276A696E853E4B40616F62484EC63540276A696E853E4B40
47861	Олехово	3	28	472	21.815128999999999	21.832861000000001	54.395589000000001	54.38599	0103000020E610000001000000050000006C054D4BACD03540A14ACD1E68314B406C054D4BACD0354024D40CA9A2324B40261DE56036D5354024D40CA9A2324B40261DE56036D53540A14ACD1E68314B406C054D4BACD03540A14ACD1E68314B40
3590	Озерск	3	28	472	22.000747	22.036149999999999	54.422742999999997	54.394996999999996	0103000020E61000000100000005000000F39194F4300036405182FE428F324B40F39194F43000364074CE4F711C364B401AC05B204109364074CE4F711C364B401AC05B20410936405182FE428F324B40F39194F4300036405182FE428F324B40
3111	Новостроево	3	28	472	21.818892000000002	21.857385000000001	54.447187999999997	54.425052999999998	0103000020E61000000100000005000000BFF4F6E7A2D135408908FF2268364B40BFF4F6E7A2D13540F294D5743D394B40BA1457957DDB3540F294D5743D394B40BA1457957DDB35408908FF2268364B40BFF4F6E7A2D135408908FF2268364B40
60686	Новогурьевское	3	28	472	21.982762999999998	21.993497999999999	54.470247999999998	54.462707000000002	0103000020E6100000010000000500000006B8205B96FB3540AD50A4FB393B4B4006B8205B96FB354034812216313C4B4033A48AE255FE354034812216313C4B4033A48AE255FE3540AD50A4FB393B4B4006B8205B96FB3540AD50A4FB393B4B40
3376	Нилово	3	28	472	21.658256000000002	21.672485000000002	54.389980000000001	54.380929999999999	0103000020E610000001000000050000005265187783A835405B087250C2304B405265187783A835400B0C59DDEA314B40F20C1AFA27AC35400B0C59DDEA314B40F20C1AFA27AC35405B087250C2304B405265187783A835405B087250C2304B40
47924	Мальцево	3	28	472	21.70955	21.733508	54.378151000000003	54.369686000000002	0103000020E6100000010000000500000076E09C11A5B5354000E5EFDE512F4B4076E09C11A5B5354090F9804067304B40B85A272EC7BB354090F9804067304B40B85A272EC7BB354000E5EFDE512F4B4076E09C11A5B5354000E5EFDE512F4B40
47796	Львовское	3	28	472	21.939087000000001	21.960647000000002	54.412564000000003	54.397512999999996	0103000020E610000001000000050000004819710168F035400F5EBBB4E1324B404819710168F03540E4C0ABE5CE344B40220038F6ECF53540E4C0ABE5CE344B40220038F6ECF535400F5EBBB4E1324B404819710168F035400F5EBBB4E1324B40
47972	Красноярское	3	28	472	21.935907	21.955814	54.526403000000002	54.519860999999999	0103000020E61000000100000005000000F418E59997EF3540A1BB24CE8A424B40F418E59997EF354016C26A2C61434B40170FEF39B0F4354016C26A2C61434B40170FEF39B0F43540A1BB24CE8A424B40F418E59997EF3540A1BB24CE8A424B40
47747	Карамышево	3	28	472	22.221032000000001	22.246525999999999	54.434354999999996	54.415827999999998	0103000020E61000000100000005000000965E9B8D953836406B6116DA39354B40965E9B8D9538364052EDD3F198374B401B9DF3531C3F364052EDD3F198374B401B9DF3531C3F36406B6116DA39354B40965E9B8D953836406B6116DA39354B40
47715	Гаврилово	3	28	472	22.228228000000001	22.248277999999999	54.402329000000002	54.390604000000003	0103000020E61000000100000005000000100874266D3A3640E9D7D64FFF314B40100874266D3A3640BF9D44847F334B40F850A2258F3F3640BF9D44847F334B40F850A2258F3F3640E9D7D64FFF314B40100874266D3A3640E9D7D64FFF314B40
2794	Багратионово	3	28	472	22.103729999999999	22.12838	54.378570000000003	54.368814999999998	0103000020E61000000100000005000000349D9D0C8E1A36401AA37554352F4B40349D9D0C8E1A3640959F54FB74304B40E275FD82DD203640959F54FB74304B40E275FD82DD2036401AA37554352F4B40349D9D0C8E1A36401AA37554352F4B40
47658	Ясная-Поляна	3	28	361	22.432818999999999	22.465464000000001	54.575727999999998	54.555349999999997	0103000020E610000001000000050000006116DA39CD6E3640B3EA73B515474B406116DA39CD6E36401CB28174B1494B40217711A6287736401CB28174B1494B40217711A628773640B3EA73B515474B406116DA39CD6E3640B3EA73B515474B40
50991	Чистые-Пруды	3	28	361	22.418185999999999	22.448055	54.466448999999997	54.452449000000001	0103000020E6100000010000000500000022A5D93C0E6B3640D00D4DD9E9394B4022A5D93C0E6B36403E20D099B43B4B402DCF83BBB37236403E20D099B43B4B402DCF83BBB3723640D00D4DD9E9394B4022A5D93C0E6B3640D00D4DD9E9394B40
1971	Чернышевское	3	28	361	22.717898999999999	22.746797999999998	54.643822	54.633848999999998	0103000020E61000000100000005000000C3D4963AC8B7364018CDCAF621514B40C3D4963AC8B73640003961C268524B40DCB75A272EBF3640003961C268524B40DCB75A272EBF364018CDCAF621514B40C3D4963AC8B7364018CDCAF621514B40
47675	Фурмановка	3	28	361	22.410226000000002	22.437004999999999	54.672721000000003	54.658234999999998	0103000020E610000001000000050000000AF8359204693640910A630B41544B400AF83592046936408D2AC3B81B564B404030478FDF6F36408D2AC3B81B564B404030478FDF6F3640910A630B41544B400AF8359204693640910A630B41544B40
47961	Садовое	3	28	361	22.435818999999999	22.464079999999999	54.723528000000002	54.711607999999998	0103000020E61000000100000005000000B5F97FD5916F364036C98FF8155B4B40B5F97FD5916F3640C2DEC4909C5C4B4049BA66F2CD763640C2DEC4909C5C4B4049BA66F2CD76364036C98FF8155B4B40B5F97FD5916F364036C98FF8155B4B40
1858	Нестеров	3	28	361	22.558143000000001	22.593851000000001	54.639350999999998	54.620849999999997	0103000020E61000000100000005000000C87DAB75E28E36405DDC4603784F4B40C87DAB75E28E36401BD5E940D6514B4068B27F9E069836401BD5E940D6514B4068B27F9E069836405DDC4603784F4B40C87DAB75E28E36405DDC4603784F4B40
47579	Невское	3	28	361	22.642163	22.664045000000002	54.519762	54.501263000000002	0103000020E6100000010000000500000085B35BCB64A43640F1D8CF6229404B4085B35BCB64A436400EDAAB8F87424B40841266DAFEA936400EDAAB8F87424B40841266DAFEA93640F1D8CF6229404B4085B35BCB64A43640F1D8CF6229404B40
47518	Луговое	3	28	361	22.676981000000001	22.692405000000001	54.676417000000001	54.667363999999999	0103000020E610000001000000050000006D0377A04EAD36408D43FD2E6C554B406D0377A04EAD3640AEBA0ED594564B403E963E7441B13640AEBA0ED594564B403E963E7441B136408D43FD2E6C554B406D0377A04EAD36408D43FD2E6C554B40
2443	Краснолесье	3	28	361	22.362947999999999	22.383223000000001	54.399304999999998	54.388879000000003	0103000020E610000001000000050000000B26FE28EA5C3640F48C7DC9C6314B400B26FE28EA5C36408C101E6D1C334B4034130CE71A6236408C101E6D1C334B4034130CE71A623640F48C7DC9C6314B400B26FE28EA5C3640F48C7DC9C6314B40
47597	Илюшино	3	28	361	22.499115	22.527987	54.582836	54.545282	0103000020E610000001000000050000006BF12900C67F36407A8CF2CCCB454B406BF12900C67F36403A77BB5E9A4A4B4091B6F1272A8736403A77BB5E9A4A4B4091B6F1272A8736407A8CF2CCCB454B406BF12900C67F36407A8CF2CCCB454B40
48048	Ильинское	3	28	361	22.509733000000001	22.522542999999999	54.508958	54.499327999999998	0103000020E6100000010000000500000025B1A4DC7D82364011FDDAFAE93F4B4025B1A4DC7D823640CF84268925414B40F4C0C760C5853640CF84268925414B40F4C0C760C585364011FDDAFAE93F4B4025B1A4DC7D82364011FDDAFAE93F4B40
47539	Бабушкино	3	28	361	22.622858000000001	22.638884000000001	54.688544999999998	54.677146	0103000020E610000001000000050000004E0D349F739F3640014F5AB8AC564B404E0D349F739F36408369183E22584B400BF0DDE68DA336408369183E22584B400BF0DDE68DA33640014F5AB8AC564B404E0D349F739F3640014F5AB8AC564B40
50969	Калинино	3	28	7094	22.566811999999999	22.587554000000001	54.461011999999997	54.441094	0103000020E61000000100000005000000F8FA5A971A9136401D3BA8C475384B40F8FA5A971A9136402288F370023B4B404DA25EF0699636402288F370023B4B404DA25EF0699636401D3BA8C475384B40F8FA5A971A9136401D3BA8C475384B40
1409	Ульяново	3	28	189	22.070636	22.108032999999999	54.832239999999999	54.819491999999997	0103000020E6100000010000000500000096EB6D3315123640B4AA251DE5684B4096EB6D331512364026361FD7866A4B4086E3F90CA81B364026361FD7866A4B4086E3F90CA81B3640B4AA251DE5684B4096EB6D3315123640B4AA251DE5684B40
1629	Ракитино	3	28	189	21.983167000000002	21.994800999999999	55.010916999999999	55.003590000000003	0103000020E61000000100000005000000A6811FD5B0FB3540DC4B1AA375804B40A6811FD5B0FB354037FC6EBA65814B4031074147ABFE354037FC6EBA65814B4031074147ABFE3540DC4B1AA375804B40A6811FD5B0FB3540DC4B1AA375804B40
1751	Новоколхозное	3	28	189	21.749534000000001	21.813089000000002	55.005057000000001	54.975656000000001	0103000020E61000000100000005000000753DD175E1BF3540B612BA4BE27C4B40753DD175E1BF3540D5CE30B5A5804B40C3BCC79926D03540D5CE30B5A5804B40C3BCC79926D03540B612BA4BE27C4B40753DD175E1BF3540B612BA4BE27C4B40
695	Неман	3	28	189	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
1395	Маломожайское	3	28	189	22.270233000000001	22.274885999999999	54.932229	54.927976999999998	0103000020E61000000100000005000000CB4C69FD2D453640583849F3C7764B40CB4C69FD2D453640FFB0A54753774B40D520CCED5E463640FFB0A54753774B40D520CCED5E463640583849F3C7764B40CB4C69FD2D453640583849F3C7764B40
1498	Лунино	3	28	189	22.068605999999999	22.097118999999999	54.922493000000003	54.899442000000001	0103000020E61000000100000005000000334FAE29901136400D535BEA20734B40334FAE2990113640FCE4284014764B40FAD170CADC183640FCE4284014764B40FAD170CADC1836400D535BEA20734B40334FAE29901136400D535BEA20734B40
7058	Лесное	3	28	189	22.194261999999998	22.210287999999998	55.020657	55.012025999999999	0103000020E6100000010000000500000005DB8827BB313640D15966118A814B4005DB8827BB3136407CB779E3A4824B40C2BD326FD53536407CB779E3A4824B40C2BD326FD5353640D15966118A814B4005DB8827BB313640D15966118A814B40
1843	Канаш	3	28	189	21.815829000000001	21.841799999999999	54.959428000000003	54.938726000000003	0103000020E61000000100000005000000DE205A2BDAD03540D4F36E2C28784B40DE205A2BDAD03540F06E6589CE7A4B40D6C56D3480D73540F06E6589CE7A4B40D6C56D3480D73540D4F36E2C28784B40DE205A2BDAD03540D4F36E2C28784B40
1515	Жилино	3	28	189	21.911051	21.940937999999999	54.924480000000003	54.900151000000001	0103000020E61000000100000005000000F4FC69A33AE93540193BE12538734B40F4FC69A33AE935402EE7525C55764B404B901150E1F035402EE7525C55764B404B901150E1F03540193BE12538734B40F4FC69A33AE93540193BE12538734B40
1637	Ветрово	3	28	189	21.945905	21.962695	55.015861999999998	55.007834000000003	0103000020E61000000100000005000000751F80D426F2354000E65AB400814B40751F80D426F23540E49F19C407824B40D105F52D73F63540E49F19C407824B40D105F52D73F6354000E65AB400814B40751F80D426F2354000E65AB400814B40
50998	Большое	3	28	189	22.131730999999998	22.150307999999999	55.024208000000002	55.016382999999998	0103000020E610000001000000050000008FDE701FB9213640ED9A90D618824B408FDE701FB92136409A266C3F19834B40C153C8957A2636409A266C3F19834B40C153C8957A263640ED9A90D618824B408FDE701FB9213640ED9A90D618824B40
1732	Акулово	3	28	189	21.978010999999999	21.987614000000001	55.048498000000002	55.039366999999999	0103000020E61000000100000005000000D520CCED5EFA354054C554FA09854B40D520CCED5EFA3540F1F5B52E35864B405E126745D4FC3540F1F5B52E35864B405E126745D4FC354054C554FA09854B40D520CCED5EFA354054C554FA09854B40
46944	Хлебниково	3	28	23	22.453723	22.463757000000001	54.941048000000002	54.930424000000002	0103000020E610000001000000050000006971C63027743640EEB4352218774B406971C63027743640ADFBC74274784B40844A5CC7B8763640ADFBC74274784B40844A5CC7B8763640EEB4352218774B406971C63027743640EEB4352218774B40
7517	Узловое	3	28	23	22.280258	22.396401000000001	54.876334999999997	54.853760000000001	0103000020E610000001000000050000003F7100FDBE4736400551F701486D4B403F7100FDBE4736408AABCABE2B704B40091A33897A6536408AABCABE2B704B40091A33897A6536400551F701486D4B403F7100FDBE4736400551F701486D4B40
47007	Тимофеево	3	28	23	22.288433000000001	22.304736999999999	54.985472999999999	54.975858000000002	0103000020E610000001000000050000005116BEBED64936401EC539EAE87C4B405116BEBED6493640A60BB1FA237E4B4093E1783E034E3640A60BB1FA237E4B4093E1783E034E36401EC539EAE87C4B405116BEBED64936401EC539EAE87C4B40
46870	Правдино	3	28	23	22.594839	22.609463999999999	54.846825000000003	54.836809000000002	0103000020E61000000100000005000000A662635E47983640CEFFAB8E1C6B4B40A662635E47983640B537F8C2646C4B40DF162CD5059C3640B537F8C2646C4B40DF162CD5059C3640CEFFAB8E1C6B4B40A662635E47983640CEFFAB8E1C6B4B40
61724	Победино	3	28	23	22.715788	22.733727999999999	54.904251000000002	54.884177000000001	0103000020E6100000010000000500000087DEE2E13DB736400D7041B62C714B4087DEE2E13DB736400A302C7FBE734B40D4282499D5BB36400A302C7FBE734B40D4282499D5BB36400D7041B62C714B4087DEE2E13DB736400D7041B62C714B40
50999	Острогожское	3	28	23	22.187328000000001	22.881195000000002	55.070045999999998	54.711399999999998	0103000020E6100000010000000500000006A051BAF42F3640EC2FBB270F5B4B4006A051BAF42F3640999B6F44F7884B401366DAFE95E13640999B6F44F7884B401366DAFE95E13640EC2FBB270F5B4B4006A051BAF42F3640EC2FBB270F5B4B40
10710	Ново-Уральское	3	28	23	22.505457	22.518581000000001	54.820228999999998	54.809666	0103000020E61000000100000005000000C68844A1658136407157AF22A3674B40C68844A1658136408A1D8D43FD684B40B55373B9C18436408A1D8D43FD684B40B55373B9C18436407157AF22A3674B40C68844A1658136407157AF22A3674B40
582	Неманское	3	28	23	22.37265	22.404261999999999	55.052875999999998	55.046512	0103000020E61000000100000005000000BADA8AFD655F36408F6FEF1AF4854B40BADA8AFD655F3640245F09A4C4864B40FB03E5B67D673640245F09A4C4864B40FB03E5B67D6736408F6FEF1AF4854B40BADA8AFD655F36408F6FEF1AF4854B40
28	Краснознаменск	3	28	23	22.471302999999999	22.513272000000001	54.954563999999998	54.935312000000003	0103000020E61000000100000005000000B6813B50A778364037C7B94DB8774B40B6813B50A77836402FF834272F7A4B40D8F335CB658336402FF834272F7A4B40D8F335CB6583364037C7B94DB8774B40B6813B50A778364037C7B94DB8774B40
690	Добровольск	3	28	23	22.494658999999999	22.501307000000001	54.762402000000002	54.756953000000003	0103000020E610000001000000050000000CACE3F8A17E3640F7CDFDD5E3604B400CACE3F8A17E3640D733846396614B408141D2A755803640D733846396614B408141D2A755803640F7CDFDD5E3604B400CACE3F8A17E3640F7CDFDD5E3604B40
7487	Весново	3	28	23	22.336231999999999	22.356795000000002	54.763638	54.752702999999997	0103000020E6100000010000000500000061DEE34C13563640F04C689258604B4061DEE34C13563640CEFDD5E3BE614B405760C8EA565B3640CEFDD5E3BE614B405760C8EA565B3640F04C689258604B4061DEE34C13563640F04C689258604B40
8381	Большое Исаково	3	28	991	20.587724000000001	20.621115	54.730240000000002	54.710932	0103000020E6100000010000000500000006137F147596344006D7DCD1FF5A4B4006137F1475963440931D1B81785D4B40170E8464019F3440931D1B81785D4B40170E8464019F344006D7DCD1FF5A4B4006137F147596344006D7DCD1FF5A4B40
5829	Янтарный	3	28	816	19.930149	19.951070000000001	54.880712000000003	54.865104000000002	0103000020E610000001000000050000003868AF3E1EEE3340C4D155BABB6E4B403868AF3E1EEE3340EE98BA2BBB704B40EC34D25279F33340EE98BA2BBB704B40EC34D25279F33340C4D155BABB6E4B403868AF3E1EEE3340C4D155BABB6E4B40
26696	Рыбачий	3	28	816	20.839925999999998	20.860821000000001	55.165672999999998	55.148256000000003	0103000020E61000000100000005000000620FED6305D73440C8B7770DFA924B40620FED6305D73440446ADAC534954B40C4B5DAC35EDC3440446ADAC534954B40C4B5DAC35EDC3440C8B7770DFA924B40620FED6305D73440C8B7770DFA924B40
27181	Романово	3	28	816	20.269703	20.287391	54.900191999999997	54.890918999999997	0103000020E6100000010000000500000012A27C410B453440483140A209724B4012A27C410B453440770FD07D39734B402C2AE27492493440770FD07D39734B402C2AE27492493440483140A209724B4012A27C410B453440483140A209724B40
50992	Приморье	3	28	816	20.026619	20.051772	54.946105000000003	54.936072000000003	0103000020E61000000100000005000000C573B680D0063440C5591135D1774B40C573B680D006344082CAF8F719794B4038D906EE400D344082CAF8F719794B4038D906EE400D3440C5591135D1774B40C573B680D0063440C5591135D1774B40
45669	Привольное	3	28	816	20.617979999999999	20.628741999999999	54.909095000000001	54.902900000000002	0103000020E610000001000000050000000395F1EF339E34407AC7293A92734B400395F1EF339E344083FA96395D744B40239F573CF5A0344083FA96395D744B40239F573CF5A034407AC7293A92734B400395F1EF339E34407AC7293A92734B40
27352	Поваровка	3	28	816	20.002390999999999	20.015785000000001	54.839846999999999	54.828480999999996	0103000020E6100000010000000500000003CE52B29C003440BE2D58AA0B6A4B4003CE52B29C0034406552431B806B4B4072C45A7C0A0434406552431B806B4B4072C45A7C0A043440BE2D58AA0B6A4B4003CE52B29C003440BE2D58AA0B6A4B40
27053	Переславское	3	28	816	20.252213000000001	20.302634999999999	54.823475999999999	54.809857999999998	0103000020E6100000010000000500000045A0FA0791403440B5334C6DA9674B4045A0FA07914034403C855CA967694B40FD9FC37C794D34403C855CA967694B40FD9FC37C794D3440B5334C6DA9674B4045A0FA0791403440B5334C6DA9674B40
8061	Откосово	3	28	816	20.336186999999999	20.346212000000001	54.813651	54.804602000000003	0103000020E610000001000000050000002157EA5910563440EA25C632FD664B402157EA5910563440C9AD49B725684B40967B8159A1583440C9AD49B725684B40967B8159A1583440EA25C632FD664B402157EA5910563440EA25C632FD664B40
46940	Надеждино	3	28	816	20.586431000000001	20.593195000000001	54.910974000000003	54.903697000000001	0103000020E610000001000000050000004F5C8E5720963440253FE257AC734B404F5C8E5720963440CFC0C8CB9A744B409626A5A0DB973440CFC0C8CB9A744B409626A5A0DB973440253FE257AC734B404F5C8E5720963440253FE257AC734B40
26836	Муромское	3	28	816	20.485433	20.500641999999999	54.900486999999998	54.891955000000003	0103000020E6100000010000000500000030664B56457C34407940D9942B724B4030664B56457C344090BC732843734B400801F9122A80344090BC732843734B400801F9122A8034407940D9942B724B4030664B56457C34407940D9942B724B40
26820	Моховое	3	28	816	20.472057	20.483825	54.931246000000002	54.918649000000002	0103000020E610000001000000050000000ED940BAD878344066C0594A96754B400ED940BAD8783440F243A51133774B40B9FC87F4DB7B3440F243A51133774B40B9FC87F4DB7B344066C0594A96754B400ED940BAD878344066C0594A96754B40
26721	Морское	3	28	816	20.909106000000001	20.926542000000001	55.233285000000002	55.224659000000003	0103000020E61000000100000005000000EE98BA2BBBE8344044E048A0C19C4B40EE98BA2BBBE83440DDD26A48DC9D4B40D55E44DB31ED3440DDD26A48DC9D4B40D55E44DB31ED344044E048A0C19C4B40EE98BA2BBBE8344044E048A0C19C4B40
26936	Мельниково	3	28	816	20.439709000000001	20.476818000000002	54.879412000000002	54.871310000000001	0103000020E61000000100000005000000C2C1DEC490703440C1560916876F4B40C2C1DEC490703440E0DA899290704B40E62494BE107A3440E0DA899290704B40E62494BE107A3440C1560916876F4B40C2C1DEC490703440C1560916876F4B40
26914	Луговское	3	28	816	20.58953	20.597660000000001	54.913758000000001	54.904333000000001	0103000020E61000000100000005000000C9022670EB963440C7D8092FC1734B40C9022670EB963440AC3AAB05F6744B409B20EA3E00993440AC3AAB05F6744B409B20EA3E00993440C7D8092FC1734B40C9022670EB963440C7D8092FC1734B40
8018	Логвино	3	28	816	20.198601	20.211447	54.770218999999997	54.762802000000001	0103000020E61000000100000005000000F1F3DF83D732344065A9F57EA3614B40F1F3DF83D732344000E1438996624B405AD6FD632136344000E1438996624B405AD6FD632136344065A9F57EA3614B40F1F3DF83D732344065A9F57EA3614B40
26622	Лесной	3	28	816	20.599015999999999	20.621949999999998	55.016584999999999	55.006574999999998	0103000020E61000000100000005000000DEC7D11C5999344050FC1873D7804B40DEC7D11C59993440554D10751F824B4048BF7D1D389F3440554D10751F824B4048BF7D1D389F344050FC1873D7804B40DEC7D11C5999344050FC1873D7804B40
27283	Красноторовка	3	28	816	20.014158999999999	20.023123999999999	54.900756000000001	54.890748000000002	0103000020E61000000100000005000000AEF199EC9F0334401C7DCC0704724B40AEF199EC9F03344080D6FCF84B734B40B1C05774EB05344080D6FCF84B734B40B1C05774EB0534401C7DCC0704724B40AEF199EC9F0334401C7DCC0704724B40
27407	Кострово	3	28	816	20.084219000000001	20.098295	54.741998000000002	54.732261999999999	0103000020E61000000100000005000000ABB35A608F153440410DDFC2BA5D4B40ABB35A608F15344045D95BCAF95E4B403E5C72DC2919344045D95BCAF95E4B403E5C72DC29193440410DDFC2BA5D4B40ABB35A608F153440410DDFC2BA5D4B40
27119	Колосовка	3	28	816	20.291460000000001	20.317834999999999	54.804907999999998	54.794221999999998	0103000020E610000001000000050000009817601F9D4A3440C1E10511A9654B409817601F9D4A3440F624B03907674B402F8672A25D513440F624B03907674B402F8672A25D513440C1E10511A9654B409817601F9D4A3440C1E10511A9654B40
26765	Коврово	3	28	816	20.393993999999999	20.409597000000002	54.922865000000002	54.906087999999997	0103000020E61000000100000005000000FAD170CADC64344026A60BB1FA734B40FAD170CADC643440C0CFB87020764B402B8A5759DB683440C0CFB87020764B402B8A5759DB68344026A60BB1FA734B40FAD170CADC64344026A60BB1FA734B40
10052	Зеленоградск	3	28	816	20.450067000000001	20.495324	54.965299999999999	54.950871999999997	0103000020E6100000010000000500000043024697377334404F57772CB6794B404302469737733440166A4DF38E7B4B4085ECBC8DCD7E3440166A4DF38E7B4B4085ECBC8DCD7E34404F57772CB6794B4043024697377334404F57772CB6794B40
27202	Заостровье	3	28	816	20.247900999999999	20.284309	54.958756000000001	54.945309000000002	0103000020E610000001000000050000004CA59F70763F3440A7CEA3E2FF784B404CA59F70763F3440016C4084B87A4B405EF58079C8483440016C4084B87A4B405EF58079C8483440A7CEA3E2FF784B404CA59F70763F3440A7CEA3E2FF784B40
48460	Дружба	3	28	816	20.113091000000001	20.121319	54.860636999999997	54.856357000000003	0103000020E61000000100000005000000D1782288F31C3440B0592E1B9D6D4B40D1782288F31C3440205D6C5A296E4B40286211C30E1F3440205D6C5A296E4B40286211C30E1F3440B0592E1B9D6D4B40D1782288F31C3440B0592E1B9D6D4B40
61677	Донское	3	28	816	19.962586999999999	19.974606000000001	54.943716000000002	54.933346	0103000020E61000000100000005000000048E041A6CF633401CEDB8E177774B40048E041A6CF63340215B96AFCB784B40427C60C77FF93340215B96AFCB784B40427C60C77FF933401CEDB8E177774B40048E041A6CF633401CEDB8E177774B40
27265	Грачевка	3	28	816	20.116378000000001	20.133195000000001	54.904023000000002	54.896158999999997	0103000020E6100000010000000500000051F9D7F2CA1D34400E828E56B5724B4051F9D7F2CA1D344079EA9106B7734B40A0FD48111922344079EA9106B7734B40A0FD4811192234400E828E56B5724B4051F9D7F2CA1D34400E828E56B5724B40
50983	Васильково	3	28	816	20.396903999999999	20.400110999999999	54.894936999999999	54.888480000000001	0103000020E61000000100000005000000CEA623809B65344036936FB6B9714B40CEA623809B6534407C7DAD4B8D724B4015C5ABAC6D6634407C7DAD4B8D724B4015C5ABAC6D66344036936FB6B9714B40CEA623809B65344036936FB6B9714B40
46988	Алексеевка	3	28	816	20.338792000000002	20.350335999999999	54.838120000000004	54.831420999999999	0103000020E610000001000000050000007D259012BB563440931ADA006C6A4B407D259012BB563440D00F2384476B4B40889CBE9EAF593440D00F2384476B4B40889CBE9EAF593440931ADA006C6A4B407D259012BB563440931ADA006C6A4B40
47820	Юдино	3	28	1115	22.235880999999999	22.244423999999999	54.644607999999998	54.635730000000002	0103000020E610000001000000050000006EBF7CB2623C3640058BC3995F514B406EBF7CB2623C3640B75ED38382524B40855B3E92923E3640B75ED38382524B40855B3E92923E3640058BC3995F514B406EBF7CB2623C3640058BC3995F514B40
48527	Фурманово	3	28	1115	22.139519	22.171688	54.611789000000002	54.596034000000003	0103000020E61000000100000005000000AE2B6684B7233640ECA694D74A4C4B40AE2B6684B7233640BA86191A4F4E4B409B1DA9BEF32B3640BA86191A4F4E4B409B1DA9BEF32B3640ECA694D74A4C4B40AE2B6684B7233640ECA694D74A4C4B40
47066	Северное	3	28	1115	22.204872000000002	22.217744	54.639809999999997	54.629502000000002	0103000020E61000000100000005000000BADDCB7D723436402062838593504B40BADDCB7D72343640AED3484BE5514B4075E61E12BE373640AED3484BE5514B4075E61E12BE3736402062838593504B40BADDCB7D723436402062838593504B40
48526	Покровское	3	28	1115	22.147209	22.165382000000001	54.648667000000003	54.641863000000001	0103000020E6100000010000000500000047AD307DAF25364098C1189128524B4047AD307DAF2536404A7F2F8507534B40DA588979562A36404A7F2F8507534B40DA588979562A364098C1189128524B4047AD307DAF25364098C1189128524B40
25964	Поддубы	3	28	1115	22.064124	22.077086000000001	54.609499999999997	54.598820000000003	0103000020E6100000010000000500000082E3326E6A1036406A183E22A64C4B4082E3326E6A103640BC749318044E4B40BEFA78E8BB133640BC749318044E4B40BEFA78E8BB1336406A183E22A64C4B4082E3326E6A1036406A183E22A64C4B40
50990	Ольховатка	3	28	1115	21.995581999999999	22.391254	54.823594999999997	54.476097000000003	0103000020E610000001000000050000007C7C4276DEFE3540A35C1ABFF03C4B407C7C4276DEFE354016139B8F6B694B40DF6DDE382964364016139B8F6B694B40DF6DDE3829643640A35C1ABFF03C4B407C7C4276DEFE3540A35C1ABFF03C4B40
50988	Михайловка	3	28	1115	22.114932	22.143121000000001	54.655901999999998	54.646571999999999	0103000020E610000001000000050000008D43FD2E6C1D364031410DDFC2524B408D43FD2E6C1D3640C4B0C398F4534B40EE5EEE93A3243640C4B0C398F4534B40EE5EEE93A324364031410DDFC2524B408D43FD2E6C1D364031410DDFC2524B40
26268	Маяковское	3	28	1115	22.053757000000001	22.078299000000001	54.529291999999998	54.515680000000003	0103000020E610000001000000050000005BEECC04C30D3640C4995FCD01424B405BEECC04C30D364068041BD7BF434B403C4F3C670B14364068041BD7BF434B403C4F3C670B143640C4995FCD01424B405BEECC04C30D3640C4995FCD01424B40
48620	Кубановка	3	28	1115	22.291352	22.312543999999999	54.683892	54.673231000000001	0103000020E61000000100000005000000CB9F6F0B964A3640A2D3F36E2C564B40CB9F6F0B964A36407EFFE6C589574B409F8F32E2025036407EFFE6C589574B409F8F32E202503640A2D3F36E2C564B40CB9F6F0B964A3640A2D3F36E2C564B40
48596	Красногорское	3	28	1115	22.246095	22.258645000000001	54.665885000000003	54.659208999999997	0103000020E6100000010000000500000089B5F814003F36404B1DE4F560544B4089B5F814003F3640D0F23CB83B554B402046088F36423640D0F23CB83B554B402046088F364236404B1DE4F560544B4089B5F814003F36404B1DE4F560544B40
48653	Калининское	3	28	1115	22.262129999999999	22.275326	54.562950999999998	54.552697000000002	0103000020E61000000100000005000000EC4CA1F31A43364075CC79C6BE464B40EC4CA1F31A433640102043C70E484B400EBDC5C37B463640102043C70E484B400EBDC5C37B46364075CC79C6BE464B40EC4CA1F31A43364075CC79C6BE464B40
10024	Гусев	3	28	1115	22.167556000000001	22.235989	54.616970999999999	54.5747	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
25074	Яблоневка	3	28	641	20.428111999999999	20.441514999999999	54.606642000000001	54.596066	0103000020E6100000010000000500000070067FBF986D3440F72004E44B4C4B4070067FBF986D3440A530EF71A64D4B4085B1852007713440A530EF71A64D4B4085B1852007713440F72004E44B4C4B4070067FBF986D3440F72004E44B4C4B40
7965	Храброво	3	28	641	20.556894	20.588909999999998	54.906927000000003	54.889516	0103000020E61000000100000005000000B056ED9A908E344066A208A9DB714B40B056ED9A908E3440016E162F16744B40904946CEC2963440016E162F16744B40904946CEC296344066A208A9DB714B40B056ED9A908E344066A208A9DB714B40
25187	Ушаково	3	28	641	20.227616999999999	20.260486	54.617597000000004	54.603805999999999	0103000020E610000001000000050000007D03931B453A34407590D783494D4B407D03931B453A3440CA8D226B0D4F4B40DC10E335AF423440CA8D226B0D4F4B40DC10E335AF4234407590D783494D4B407D03931B453A34407590D783494D4B40
48340	Сосновка	3	28	641	20.676586	20.685713	54.639491999999997	54.634551999999999	0103000020E6100000010000000500000074EE76BD34AD344042CEFBFF38514B4074EE76BD34AD3440DD06B5DFDA514B402A711DE38AAF3440DD06B5DFDA514B402A711DE38AAF344042CEFBFF38514B4074EE76BD34AD344042CEFBFF38514B40
4201	Славянское	3	28	641	20.713263999999999	20.725688000000002	54.678578000000002	54.675063999999999	0103000020E61000000100000005000000056A317898B634407D5A457F68564B40056A317898B634407EE4D6A4DB564B40831953B0C6B934407EE4D6A4DB564B40831953B0C6B934407D5A457F68564B40056A317898B634407D5A457F68564B40
25461	Рябиновка	3	28	641	20.501961999999999	20.510522999999999	54.831026999999999	54.828226000000001	0103000020E61000000100000005000000B2D5E5948080344034D93F4F036A4B40B2D5E59480803440E78BBD175F6A4B4016DBA4A2B1823440E78BBD175F6A4B4016DBA4A2B182344034D93F4F036A4B40B2D5E5948080344034D93F4F036A4B40
8193	Рыбное	3	28	641	20.671797999999999	20.682739000000002	54.664926999999999	54.650719000000002	0103000020E61000000100000005000000A98427F4FAAB344063F19BC24A534B40A98427F4FAAB34401B9DF3531C554B4029B4ACFBC7AE34401B9DF3531C554B4029B4ACFBC7AE344063F19BC24A534B40A98427F4FAAB344063F19BC24A534B40
24930	Родники	3	28	641	20.660335	20.681131000000001	54.711790000000001	54.700319999999998	0103000020E610000001000000050000007767EDB60BA934400B5EF415A4594B407767EDB60BA9344057CF49EF1B5B4B40B24AE9995EAE344057CF49EF1B5B4B40B24AE9995EAE34400B5EF415A4594B407767EDB60BA934400B5EF415A4594B40
24711	Рассвет	3	28	641	20.629352000000001	20.646259000000001	54.811248999999997	54.802588	0103000020E6100000010000000500000015AC71361DA13440BE141E34BB664B4015AC71361DA13440D3F4D901D7674B40E4BED53A71A53440D3F4D901D7674B40E4BED53A71A53440BE141E34BB664B4015AC71361DA13440BE141E34BB664B40
25366	Петрово	3	28	641	20.400623	20.432711000000001	54.812176999999998	54.798752999999998	0103000020E6100000010000000500000081069B3A8F6634407B4ACE893D664B4081069B3A8F6634401DC87A6AF5674B40959EE925C66E34401DC87A6AF5674B40959EE925C66E34407B4ACE893D664B4081069B3A8F6634407B4ACE893D664B40
25323	Орловка	3	28	641	20.521501000000001	20.548459000000001	54.798681000000002	54.788781999999998	0103000020E61000000100000005000000D0D4EB168185344034D6FECEF6644B40D0D4EB1681853440E277D32D3B664B4066321CCF678C3440E277D32D3B664B4066321CCF678C344034D6FECEF6644B40D0D4EB168185344034D6FECEF6644B40
24872	Низовье	3	28	641	20.728311000000001	20.748173000000001	54.707535999999998	54.694440999999998	0103000020E610000001000000050000002B51F69672BA344032005471E3584B402B51F69672BA34400F5F268A905A4B400EC0064488BF34400F5F268A905A4B400EC0064488BF344032005471E3584B402B51F69672BA344032005471E3584B40
8364	Некрасово	3	28	641	20.666785000000001	20.683332	54.907341000000002	54.897303000000001	0103000020E610000001000000050000009F76F86BB2AA344025CD1FD3DA724B409F76F86BB2AA3440F4A8F8BF23744B406E4F90D8EEAE3440F4A8F8BF23744B406E4F90D8EEAE344025CD1FD3DA724B409F76F86BB2AA344025CD1FD3DA724B40
24395	Моргуново	3	28	641	20.789145000000001	20.797256000000001	54.81832	54.813375999999998	0103000020E610000001000000050000004BCD1E6805CA3440F7AC6BB41C684B404BCD1E6805CA3440D4D4B2B5BE684B402F8A1EF818CC3440D4D4B2B5BE684B402F8A1EF818CC3440F7AC6BB41C684B404BCD1E6805CA3440F7AC6BB41C684B40
25449	Матросово	3	28	641	20.587114	20.604209000000001	54.864652999999997	54.856186000000001	0103000020E610000001000000050000001406651A4D96344083A5BA80976D4B401406651A4D963440B3B112F3AC6E4B40E9F2E670AD9A3440B3B112F3AC6E4B40E9F2E670AD9A344083A5BA80976D4B401406651A4D96344083A5BA80976D4B40
24535	Маршальское	3	28	641	20.729648999999998	20.754254	54.879644999999996	54.874527	0103000020E61000000100000005000000218FE046CABA3440083C3080F06F4B40218FE046CABA3440828B153598704B408FE046CA16C13440828B153598704B408FE046CA16C13440083C3080F06F4B40218FE046CABA3440083C3080F06F4B40
24998	Малое Васильково	3	28	641	20.602744000000001	20.618528000000001	54.749523000000003	54.740459000000001	0103000020E6100000010000000500000038DC476E4D9A3440B2834A5CC75E4B4038DC476E4D9A3440C74CA25EF05F4B4009A9DBD9579E3440C74CA25EF05F4B4009A9DBD9579E3440B2834A5CC75E4B4038DC476E4D9A3440B2834A5CC75E4B40
24763	Малинники	3	28	641	20.740465	20.752528999999999	54.724994000000002	54.715820999999998	0103000020E6100000010000000500000028D53E1D8FBD34401F65C405A05B4B4028D53E1D8FBD3440EBE5779ACC5C4B40A54A94BDA5C03440EBE5779ACC5C4B40A54A94BDA5C034401F65C405A05B4B4028D53E1D8FBD34401F65C405A05B4B40
25222	Луговое	3	28	641	20.633088999999998	20.645817999999998	54.649890999999997	54.642893999999998	0103000020E610000001000000050000001475E61E12A23440B665C0594A524B401475E61E12A234407C7BD7A02F534B400A2B155454A534407C7BD7A02F534B400A2B155454A53440B665C0594A524B401475E61E12A23440B665C0594A524B40
25084	Лесной	3	28	641	20.545027999999999	20.552662999999999	54.639310000000002	54.630763999999999	0103000020E610000001000000050000007F677BF4868B344040BFEFDFBC504B407F677BF4868B3440BD00FBE8D4514B4091B586527B8D3440BD00FBE8D4514B4091B586527B8D344040BFEFDFBC504B407F677BF4868B344040BFEFDFBC504B40
24643	Константиновка	3	28	641	20.682703	20.695298000000001	54.804181999999997	54.795462999999998	0103000020E610000001000000050000008FE1B19FC5AE3440CA1649BBD1654B408FE1B19FC5AE344014048F6FEF664B4066F9BA0CFFB1344014048F6FEF664B4066F9BA0CFFB13440CA1649BBD1654B408FE1B19FC5AE3440CA1649BBD1654B40
24516	Заречье	3	28	641	20.876819999999999	20.891749999999998	54.790453999999997	54.783783	0103000020E610000001000000050000008D7A884677E034409414580053644B408D7A884677E03440067FBF982D654B403F355EBA49E43440067FBF982D654B403F355EBA49E434409414580053644B408D7A884677E034409414580053644B40
24987	Заозерье	3	28	641	20.625489999999999	20.661054	54.730894999999997	54.712581	0103000020E610000001000000050000009CF9D51C20A034402060ADDA355B4B409CF9D51C20A03440ABE7A4F78D5D4B40D6E3BED53AA93440ABE7A4F78D5D4B40D6E3BED53AA934402060ADDA355B4B409CF9D51C20A034402060ADDA355B4B40
24627	Заливное	3	28	641	20.798908999999998	20.837142	54.925773	54.904603000000002	0103000020E61000000100000005000000E57ADB4C85CC3440876EF607CA734B40E57ADB4C85CC34408942CBBA7F764B40A81B28F04ED634408942CBBA7F764B40A81B28F04ED63440876EF607CA734B40E57ADB4C85CC3440876EF607CA734B40
24443	Добрино	3	28	641	20.863524999999999	20.869589000000001	54.812603000000003	54.809542	0103000020E61000000100000005000000454772F90FDD3440855E7F129F674B40454772F90FDD3440D5D0066003684B401BF67B629DDE3440D5D0066003684B401BF67B629DDE3440855E7F129F674B40454772F90FDD3440855E7F129F674B40
24148	Гурьевск	3	28	641	20.581948000000001	20.630709	54.792603	54.764589000000001	0103000020E61000000100000005000000FDF84B8BFA943440D0F0660DDE614B40FDF84B8BFA94344012DBDD0374654B40F94A202576A1344012DBDD0374654B40F94A202576A13440D0F0660DDE614B40FDF84B8BFA943440D0F0660DDE614B40
24852	Высокое	3	28	641	20.798881999999999	20.808817999999999	54.705776999999998	54.700924000000001	0103000020E61000000100000005000000F25CDF8783CC3440A27DACE0B7594B40F25CDF8783CC34406EA296E6565A4B40876A4AB20ECF34406EA296E6565A4B40876A4AB20ECF3440A27DACE0B7594B40F25CDF8783CC3440A27DACE0B7594B40
47742	Яблоновка	3	28	386	20.909662999999998	20.921305	54.706532000000003	54.702052999999999	0103000020E610000001000000050000009961A3ACDFE83440838769DFDC594B409961A3ACDFE83440EBC9FCA36F5A4B402BA4FCA4DAEB3440EBC9FCA36F5A4B402BA4FCA4DAEB3440838769DFDC594B409961A3ACDFE83440838769DFDC594B40
51011	Толпаки	3	28	386	21.329598000000001	21.348993	54.654541999999999	54.646014999999998	0103000020E61000000100000005000000B7D3D68860543540DBDC989EB0524B40B7D3D68860543540E1ED4108C8534B406E88F19A57593540E1ED4108C8534B406E88F19A57593540DBDC989EB0524B40B7D3D68860543540DBDC989EB0524B40
23948	Славинск	3	28	386	21.079283	21.091868000000002	54.754246000000002	54.746794000000001	0103000020E61000000100000005000000F72004E44B143540AD6C1FF2965F4B40F72004E44B143540C59107228B604B40878C47A984173540C59107228B604B40878C47A984173540AD6C1FF2965F4B40F72004E44B143540AD6C1FF2965F4B40
1991	Пригородное	3	28	386	21.034807000000001	21.047518	54.665785999999997	54.660843999999997	0103000020E6100000010000000500000000AC8E1CE908354000E1438996544B4000AC8E1CE90835403C11C47938554B40A9F8BF232A0C35403C11C47938554B40A9F8BF232A0C354000E1438996544B4000AC8E1CE908354000E1438996544B40
23686	Озерки	3	28	386	20.857695	20.9194	54.633515000000003	54.609662	0103000020E6100000010000000500000056F146E691DB344096CE8767094E4B4056F146E691DB34404243FF0417514B4041F163CC5DEB34404243FF0417514B4041F163CC5DEB344096CE8767094E4B4056F146E691DB344096CE8767094E4B40
24044	Малиновка	3	28	386	20.895703000000001	20.908109	54.709954000000003	54.694856999999999	0103000020E61000000100000005000000D9EDB3CA4CE53440C632FD12F1584B40D9EDB3CA4CE534400BD5CDC5DF5A4B400934D8D479E834400BD5CDC5DF5A4B400934D8D479E83440C632FD12F1584B40D9EDB3CA4CE53440C632FD12F1584B40
23854	Красный Яр	3	28	386	21.347286	21.355937000000001	54.689638000000002	54.680743	0103000020E61000000100000005000000D15B3CBCE75835408FFD2C9622574B40D15B3CBCE7583540180AD80E46584B40B56FEEAF1E5B3540180AD80E46584B40B56FEEAF1E5B35408FFD2C9622574B40D15B3CBCE75835408FFD2C9622574B40
23703	Комсомольск	3	28	386	20.735586999999999	20.787195000000001	54.635323999999997	54.619410999999999	0103000020E61000000100000005000000DD5CFC6D4FBC34402EE411DC484F4B40DD5CFC6D4FBC3440942EFD4B52514B4021938C9C85C93440942EFD4B52514B4021938C9C85C934402EE411DC484F4B40DD5CFC6D4FBC34402EE411DC484F4B40
23889	Зорино	3	28	386	21.205414999999999	21.226057999999998	54.665323000000001	54.651308	0103000020E610000001000000050000009B1BD31396343540C4CF7F0F5E534B409B1BD313963435406823D74D29554B40C9FFE4EFDE3935406823D74D29554B40C9FFE4EFDE393540C4CF7F0F5E534B409B1BD31396343540C4CF7F0F5E534B40
23543	Знаменск	3	28	386	21.202082000000001	21.248453000000001	54.627105	54.598740999999997	0103000020E610000001000000050000003B1C5DA5BB3335401DE38A8BA34C4B403B1C5DA5BB3335403C1405FA44504B40D597A59D9A3F35403C1405FA44504B40D597A59D9A3F35401DE38A8BA34C4B403B1C5DA5BB3335401DE38A8BA34C4B40
23756	Заречье	3	28	386	21.013715000000001	21.034457	54.621955	54.606413000000003	0103000020E61000000100000005000000F37684D382033540446FF1F09E4D4B40F37684D382033540B64AB0389C4F4B40471E882CD2083540B64AB0389C4F4B40471E882CD2083540446FF1F09E4D4B40F37684D382033540446FF1F09E4D4B40
60861	Дивное	3	28	386	21.363060000000001	21.375834000000001	54.673054	54.663099000000003	0103000020E610000001000000050000005B7C0A80F15C35405281936DE0544B405B7C0A80F15C354093382BA226564B4091B932A83660354093382BA226564B4091B932A8366035405281936DE0544B405B7C0A80F15C35405281936DE0544B40
9954	Гвардейск	3	28	386	21.052772999999998	21.091518000000001	54.665047000000001	54.644848000000003	0103000020E610000001000000050000009F1C0588820D35400D7217618A524B409F1C0588820D3540C6A6954220554B40CEFE40B96D173540C6A6954220554B40CEFE40B96D1735400D7217618A524B409F1C0588820D35400D7217618A524B40
23985	Борское	3	28	386	20.957004000000001	20.969248	54.670639000000001	54.663812	0103000020E610000001000000050000002524D236FEF434409F58A7CAF7544B402524D236FEF434400936AE7FD7554B40A2B60DA320F834400936AE7FD7554B40A2B60DA320F834409F58A7CAF7544B402524D236FEF434409F58A7CAF7544B40
50982	Южный	3	28	1103	20.585227	20.609508999999999	54.557991999999999	54.543658000000001	0103000020E6100000010000000500000077BCC96FD1953440B91AD99596454B4077BCC96FD1953440FEB627486C474B401F9E25C8089C3440FEB627486C474B401F9E25C8089C3440B91AD99596454B4077BCC96FD1953440B91AD99596454B40
47000	Чехово	3	28	1103	20.703392000000001	20.735406999999999	54.548948000000003	54.528483000000001	0103000020E610000001000000050000009E44847F11B43440F9BEB854A5434B409E44847F11B43440319A95ED43464B40DD3F16A243BC3440319A95ED43464B40DD3F16A243BC3440F9BEB854A5434B409E44847F11B43440F9BEB854A5434B40
50996	Тишоно	3	28	1103	20.752790000000001	20.772722999999999	54.501885000000001	54.491804000000002	0103000020E610000001000000050000007FC16ED8B6C034406005F86EF33E4B407FC16ED8B6C034402EAD86C43D404B40F4DDAD2CD1C534402EAD86C43D404B40F4DDAD2CD1C534406005F86EF33E4B407FC16ED8B6C034406005F86EF33E4B40
21806	Славское	3	28	1103	20.438002000000001	20.448557000000001	54.501722999999998	54.488388999999998	0103000020E61000000100000005000000259529E620703440F25CDF87833E4B40259529E6207034405453927538404B405264ADA1D47234405453927538404B405264ADA1D4723440F25CDF87833E4B40259529E620703440F25CDF87833E4B40
21493	Пятидорожное	3	28	1103	20.087731000000002	20.110970999999999	54.508325999999997	54.493467000000003	0103000020E610000001000000050000006BD8EF8975163440DF5339ED293F4B406BD8EF89751634406EDA8CD310414B40EECD6F98681C34406EDA8CD310414B40EECD6F98681C3440DF5339ED293F4B406BD8EF8975163440DF5339ED293F4B40
47572	Пушкино	3	28	1103	20.544839	20.555367	54.465538000000002	54.457641000000002	0103000020E61000000100000005000000D99596917A8B34408527F4FA933A4B40D99596917A8B3440CB85CABF963B4B4013471E882C8E3440CB85CABF963B4B4013471E882C8E34408527F4FA933A4B40D99596917A8B34408527F4FA933A4B40
61670	Пограничное	3	28	1103	20.155186	20.451414	54.438282000000001	54.411929999999998	0103000020E610000001000000050000000CCC0A45BA273440E21E4B1FBA344B400CCC0A45BA2734407636E49F19384B40E0F42EDE8F7334407636E49F19384B40E0F42EDE8F733440E21E4B1FBA344B400CCC0A45BA273440E21E4B1FBA344B40
51001	Новомосковский	3	28	1103	20.214672	20.255096000000002	54.598632000000002	54.566417000000001	0103000020E61000000100000005000000EE5D83BEF436344000732D5A80484B40EE5D83BEF4363440672B2FF99F4C4B402657B1F84D413440672B2FF99F4C4B402657B1F84D41344000732D5A80484B40EE5D83BEF436344000732D5A80484B40
22202	Нивенское	3	28	1103	20.544326999999999	20.585964000000001	54.590702999999998	54.570306000000002	0103000020E610000001000000050000006D54A703598B3440365B79C9FF484B406D54A703598B34401553E9279C4B4B4023A298BC019634401553E9279C4B4B4023A298BC01963440365B79C9FF484B406D54A703598B3440365B79C9FF484B40
21725	Медовое	3	28	1103	20.345825999999999	20.383519	54.539980999999997	54.523806	0103000020E61000000100000005000000431B800D885834406BB933130C434B40431B800D885834400EBBEF181E454B4006651A4D2E6234400EBBEF181E454B4006651A4D2E6234406BB933130C434B40431B800D885834406BB933130C434B40
9827	Мамоново	3	28	1103	19.917303	19.970922999999999	54.480705999999998	54.450476000000002	0103000020E61000000100000005000000CF85915ED4EA334003D19332A9394B40CF85915ED4EA3340D87E32C6873D4B4028EFE3688EF83340D87E32C6873D4B4028EFE3688EF8334003D19332A9394B40CF85915ED4EA334003D19332A9394B40
45609	Липовка	3	28	1103	20.054501999999999	20.062218999999999	54.448937000000001	54.445455000000003	0103000020E610000001000000050000000C91D3D7F30D34407B6B60AB04394B400C91D3D7F30D3440707B82C476394B4098309A95ED0F3440707B82C476394B4098309A95ED0F34407B6B60AB04394B400C91D3D7F30D34407B6B60AB04394B40
22444	Ладушкин	3	28	1103	20.138494999999999	20.188136	54.589326	54.563197000000002	0103000020E61000000100000005000000D6A8876874233440481ADCD616484B40D6A88768742334405C57CC086F4B4B4044334FAE293034405C57CC086F4B4B4044334FAE29303440481ADCD616484B40D6A8876874233440481ADCD616484B40
48092	Краснознаменское	3	28	1103	20.531966000000001	20.545377999999999	54.484915999999998	54.477043999999999	0103000020E610000001000000050000007D957CEC2E88344063601DC70F3D4B407D957CEC2E88344050A73CBA113E4B4038F581E49D8B344050A73CBA113E4B4038F581E49D8B344063601DC70F3D4B407D957CEC2E88344063601DC70F3D4B40
46784	Корнево	3	28	1103	20.27627	20.305185999999999	54.449413	54.436647999999998	0103000020E61000000100000005000000ADDD76A1B946344091EEE714E4374B40ADDD76A1B9463440D9B27C5D86394B40723271AB204E3440D9B27C5D86394B40723271AB204E344091EEE714E4374B40ADDD76A1B946344091EEE714E4374B40
46956	Заречное	3	28	1103	20.425426000000002	20.433043999999999	54.575201	54.572116999999999	0103000020E610000001000000050000003CDEE4B7E86C3440293E3E213B494B403CDEE4B7E86C344031D0B52FA0494B40A1BAB9F8DB6E344031D0B52FA0494B40A1BAB9F8DB6E3440293E3E213B494B403CDEE4B7E86C3440293E3E213B494B40
47554	Долгоруково	3	28	1103	20.516542000000001	20.521896000000002	54.444890000000001	54.442402999999999	0103000020E61000000100000005000000AC02B5183C8434407E5358A9A0384B40AC02B5183C843440A228D027F2384B40C9E9EBF99A853440A228D027F2384B40C9E9EBF99A8534407E5358A9A0384B40AC02B5183C8434407E5358A9A0384B40
46951	Гвардейское	3	28	1103	20.627680999999999	20.644552000000001	54.494444999999999	54.480271000000002	0103000020E610000001000000050000001152B7B3AFA03440CE1B2785793D4B401152B7B3AFA03440DA5548F9493F4B404792205C01A53440DA5548F9493F4B404792205C01A53440CE1B2785793D4B401152B7B3AFA03440CE1B2785793D4B40
47082	Владимирово	3	28	1103	20.521312000000002	20.546787999999999	54.568922999999998	54.559432999999999	0103000020E610000001000000050000002A0307B474853440CEA623809B474B402A0307B4748534409A780778D2484B4062D8614CFA8B34409A780778D2484B4062D8614CFA8B3440CEA623809B474B402A0307B474853440CEA623809B474B40
21847	Багратионовск	3	28	1103	20.61515	20.664162000000001	54.399410000000003	54.373598999999999	0103000020E6100000010000000500000068226C787A9D3440BE688F17D22F4B4068226C787A9D344002D9EBDD1F334B40F73E558506AA344002D9EBDD1F334B40F73E558506AA3440BE688F17D22F4B4068226C787A9D3440BE688F17D22F4B40
26113	Ясная Поляна	3	27	\N	37.899140000000003	37.924939999999999	59.161062000000001	59.147689999999997	0103000020E610000001000000050000004243FF0417F342401EF98381E7924D404243FF0417F342406E50FBAD9D944D409161156F64F642406E50FBAD9D944D409161156F64F642401EF98381E7924D404243FF0417F342401EF98381E7924D40
164	Череповец	3	27	\N	37.671425999999997	38.052419999999998	59.186936000000003	59.063229	0103000020E6100000010000000500000090D78349F1D5424053944BE317884D4090D78349F1D54240F838D384ED974D4002D4D4B2B5064340F838D384ED974D4002D4D4B2B506434053944BE317884D4090D78349F1D5424053944BE317884D40
53270	Устюжна	3	27	\N	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
53263	Сокол	3	27	\N	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
53266	Никольск	3	27	\N	45.429645000000001	45.492213	59.557451	59.498026000000003	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
29401	Кувшиново	3	27	\N	39.808194999999998	39.825370999999997	59.268549	59.248672999999997	0103000020E6100000010000000500000036E50AEF72E74340F8325184D49F4D4036E50AEF72E74340CF2F4AD05FA24D408D08C6C1A5E94340CF2F4AD05FA24D408D08C6C1A5E94340F8325184D49F4D4036E50AEF72E74340F8325184D49F4D40
53249	Грязовец	3	27	\N	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
17	Вологда	3	27	\N	39.732394999999997	40.028049000000003	59.28396	59.167062999999999	0103000020E6100000010000000500000080608E1EBFDD434092AF045262954D4080608E1EBFDD4340A3AF20CD58A44D40BFD7101C97034440A3AF20CD58A44D40BFD7101C9703444092AF045262954D4080608E1EBFDD434092AF045262954D40
53250	Бабаево	3	27	\N	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
32194	Юрочкино	3	27	1561	38.532273000000004	38.545523000000003	59.061951999999998	59.054053000000003	0103000020E610000001000000050000009CC58B852144434017A06D35EB864D409CC58B8521444340FDF50A0BEE874D40A01B9AB2D3454340FDF50A0BEE874D40A01B9AB2D345434017A06D35EB864D409CC58B852144434017A06D35EB864D40
31775	Шигоево	3	27	1561	38.503445999999997	38.518825	59.379832	59.373702999999999	0103000020E61000000100000005000000A8A624EB7040434063B5F97FD5AF4D40A8A624EB70404340B5FCC0559EB04D4071AC8BDB68424340B5FCC0559EB04D4071AC8BDB6842434063B5F97FD5AF4D40A8A624EB7040434063B5F97FD5AF4D40
53276	Шексна 2-я	3	27	1561	38.503337999999999	38.523676000000002	59.240242000000002	59.231445999999998	0103000020E61000000100000005000000C26A2C616D4043401F65C405A09D4D40C26A2C616D4043401590F63FC09E4D409DD9AED0074343401590F63FC09E4D409DD9AED0074343401F65C405A09D4D40C26A2C616D4043401F65C405A09D4D40
30890	Шексна	3	27	1561	38.488290999999997	38.551102	59.233826000000001	59.200564	0103000020E610000001000000050000002FF7C951803E4340A260C614AC994D402FF7C951803E43402D7AA702EE9D4D404E61A5828A4643402D7AA702EE9D4D404E61A5828A464340A260C614AC994D402FF7C951803E4340A260C614AC994D40
31937	Чуровское	3	27	1561	38.590690000000002	38.605432	59.261135000000003	59.254769000000003	0103000020E610000001000000050000008109DCBA9B4B43406F8445459CA04D408109DCBA9B4B4340A56B26DF6CA14D40D7F9B7CB7E4D4340A56B26DF6CA14D40D7F9B7CB7E4D43406F8445459CA04D408109DCBA9B4B43406F8445459CA04D40
18687	Чернеево	3	27	1561	38.919725	38.93479	59.137776000000002	59.127023000000001	0103000020E6100000010000000500000024287E8CB97543407F6B274A42904D4024287E8CB97543403C16DBA4A2914D405D50DF32A77743403C16DBA4A2914D405D50DF32A77743407F6B274A42904D4024287E8CB97543407F6B274A42904D40
31236	Чебсара	3	27	1561	38.753006999999997	38.760328000000001	59.147584000000002	59.144523999999997	0103000020E610000001000000050000005C548B886260434059BE2EC37F924D405C548B8862604340D9B45208E4924D40D61D8B6D52614340D9B45208E4924D40D61D8B6D5261434059BE2EC37F924D405C548B886260434059BE2EC37F924D40
31822	Чаромское	3	27	1561	38.601021000000003	38.631464999999999	59.345644	59.333708000000001	0103000020E61000000100000005000000C89A9141EE4C4340F03499F1B6AA4D40C89A9141EE4C4340810706103EAC4D40C9C859D8D3504340810706103EAC4D40C9C859D8D3504340F03499F1B6AA4D40C89A9141EE4C4340F03499F1B6AA4D40
32284	Фоминское	3	27	1561	39.054059000000002	39.061011999999998	58.984777000000001	58.981053000000003	0103000020E61000000100000005000000F986C267EB86434044520B25937D4D40F986C267EB8643402F6D382C0D7E4D40EF54C03DCF8743402F6D382C0D7E4D40EF54C03DCF87434044520B25937D4D40F986C267EB86434044520B25937D4D40
31698	Сыромяткино	3	27	1561	38.788823000000001	38.799351000000001	59.419662000000002	59.417001999999997	0103000020E6100000010000000500000093AAED26F8644340EC2E505260B54D4093AAED26F8644340DEAF027CB7B54D403083312251664340DEAF027CB7B54D403083312251664340EC2E505260B54D4093AAED26F8644340EC2E505260B54D40
32025	Слизово	3	27	1561	38.618268999999998	38.634734999999999	59.217765	59.211663000000001	0103000020E61000000100000005000000B8904770234F4340FA62EFC5179B4D40B8904770234F4340529B38B9DF9B4D40335019FF3E514340529B38B9DF9B4D40335019FF3E514340FA62EFC5179B4D40B8904770234F4340FA62EFC5179B4D40
31647	Сизьма	3	27	1561	38.701847999999998	38.720488000000003	59.419502000000001	59.409436999999997	0103000020E61000000100000005000000AA61BF27D6594340DC627E6E68B44D40AA61BF27D6594340A54DD53DB2B54D408A9466F3385C4340A54DD53DB2B54D408A9466F3385C4340DC627E6E68B44D40AA61BF27D6594340DC627E6E68B44D40
31574	Раменье	3	27	1561	38.479353000000003	38.493115000000003	59.487701999999999	59.481597000000001	0103000020E61000000100000005000000A81E69705B3D4340056D72F8A4BD4D40A81E69705B3D4340CE18E6046DBE4D4062156F641E3F4340CE18E6046DBE4D4062156F641E3F4340056D72F8A4BD4D40A81E69705B3D4340056D72F8A4BD4D40
31305	Прогресс	3	27	1561	38.500534999999999	38.514890999999999	59.195895999999998	59.191789999999997	0103000020E610000001000000050000006EC0E7871140434094D920938C984D406EC0E7871140434067B5C01E13994D409B00C3F2E741434067B5C01E13994D409B00C3F2E741434094D920938C984D406EC0E7871140434094D920938C984D40
31393	Пача	3	27	1561	38.303390999999998	38.324016	59.182533999999997	59.176231000000001	0103000020E610000001000000050000004B732B84D52643404CC5C6BC8E964D404B732B84D52643403B342C465D974D40BCB0355B792943403B342C465D974D40BCB0355B792943404CC5C6BC8E964D404B732B84D52643404CC5C6BC8E964D40
31318	Нифантово	3	27	1561	38.439521999999997	38.477161000000002	59.217055999999999	59.204172	0103000020E61000000100000005000000AEEFC341423843402461DF4E229A4D40AEEFC3414238434046B3B27DC89B4D409DF6949C133D434046B3B27DC89B4D409DF6949C133D43402461DF4E229A4D40AEEFC341423843402461DF4E229A4D40
30397	Нестерово	3	27	1561	39.001660999999999	39.016303000000001	59.124755	59.119061000000002	0103000020E61000000100000005000000DE567A6D36804340529D0E643D8F4D40DE567A6D368043409981CAF8F78F4D40D1E97937168243409981CAF8F78F4D40D1E9793716824340529D0E643D8F4D40DE567A6D36804340529D0E643D8F4D40
31843	Медвежье	3	27	1561	38.650958000000003	38.659376000000002	59.313420000000001	59.310383999999999	0103000020E61000000100000005000000E8887C9752534340D099B4A9BAA74D40E8887C9752534340C7F484251EA84D4037E2C96E66544340C7F484251EA84D4037E2C96E66544340D099B4A9BAA74D40E8887C9752534340D099B4A9BAA74D40
32015	Малинуха	3	27	1561	38.518089000000003	38.532471000000001	59.280825	59.273823	0103000020E610000001000000050000006CB587BD5042434041F2CEA10CA34D406CB587BD504243401973D712F2A34D40C2887D02284443401973D712F2A34D40C2887D022844434041F2CEA10CA34D406CB587BD5042434041F2CEA10CA34D40
32115	Любомирово	3	27	1561	38.754741000000003	38.768394999999998	59.108606999999999	59.098390000000002	0103000020E61000000100000005000000A5F9635A9B6043407120240B988C4D40A5F9635A9B604340EF8E8CD5E68D4D4078B471C45A624340EF8E8CD5E68D4D4078B471C45A6243407120240B988C4D40A5F9635A9B6043407120240B988C4D40
31713	Княже	3	27	1561	38.619759999999999	38.636719999999997	59.386916999999997	59.379167000000002	0103000020E610000001000000050000003AAFB14B544F4340795C548B88B04D403AAFB14B544F43401AA20A7F86B14D40C45A7C0A805143401AA20A7F86B14D40C45A7C0A80514340795C548B88B04D403AAFB14B544F4340795C548B88B04D40
31921	Квасюнино	3	27	1561	38.518106000000003	38.530960999999998	59.329371000000002	59.319426999999997	0103000020E6100000010000000500000042EE224C51424340CD3AE3FBE2A84D4042EE224C514243401BA034D428AA4D40C939B187F64343401BA034D428AA4D40C939B187F6434340CD3AE3FBE2A84D4042EE224C51424340CD3AE3FBE2A84D40
31538	Камешник	3	27	1561	38.356876999999997	38.378463000000004	59.567334000000002	59.554054000000001	0103000020E61000000100000005000000E8D84125AE2D4340E71BD13DEBC64D40E8D84125AE2D434056F487669EC84D407FDFBF797130434056F487669EC84D407FDFBF7971304340E71BD13DEBC64D40E8D84125AE2D4340E71BD13DEBC64D40
31482	Игнатовское	3	27	1561	38.330314000000001	38.341569999999997	59.364261999999997	59.358694999999997	0103000020E610000001000000050000009AB4A9BA472A43408E1EBFB7E9AD4D409AB4A9BA472A434078962023A0AE4D40B9A5D590B82B434078962023A0AE4D40B9A5D590B82B43408E1EBFB7E9AD4D409AB4A9BA472A43408E1EBFB7E9AD4D40
29989	Ершово	3	27	1561	38.401899999999998	38.414171000000003	59.363075000000002	59.356746000000001	0103000020E6100000010000000500000096218E75713343404A7D59DAA9AD4D4096218E7571334340637FD93D79AE4D40CFF9298E03354340637FD93D79AE4D40CFF9298E033543404A7D59DAA9AD4D4096218E75713343404A7D59DAA9AD4D40
28721	Добрец	3	27	1561	38.34422	38.356454999999997	59.163525	59.156596	0103000020E610000001000000050000008750A5660F2C43409B5775560B944D408750A5660F2C4340098A1F63EE944D4072BF4351A02D4340098A1F63EE944D4072BF4351A02D43409B5775560B944D408750A5660F2C43409B5775560B944D40
29185	Демидово	3	27	1561	38.274096999999998	38.290940999999997	59.276384	59.269376999999999	0103000020E610000001000000050000004277499C15234340B5A50EF27AA24D404277499C152343409F91088D60A34D406308008E3D2543409F91088D60A34D406308008E3D254340B5A50EF27AA24D404277499C15234340B5A50EF27AA24D40
32167	Братково	3	27	1561	38.799709999999997	38.811594999999997	59.138851000000003	59.133653000000002	0103000020E610000001000000050000005F24B4E55C6643409301A08A1B914D405F24B4E55C6643402A029CDEC5914D406E4C4F58E26743402A029CDEC5914D406E4C4F58E26743409301A08A1B914D405F24B4E55C6643409301A08A1B914D40
32277	Большое Ивановское	3	27	1561	38.691319999999997	38.700823999999997	59.134193000000003	59.128999	0103000020E610000001000000050000000D897B2C7D584340BD1B0B0A83904D400D897B2C7D584340132D793C2D914D403E20D099B4594340132D793C2D914D403E20D099B4594340BD1B0B0A83904D400D897B2C7D584340BD1B0B0A83904D40
26354	Ягница	3	27	296	37.535052999999998	37.559837999999999	58.747587000000003	58.731788000000002	0103000020E610000001000000050000003750E09D7CC4424079CDAB3AAB5D4D403750E09D7CC4424017F549EEB05F4D406E8786C5A8C7424017F549EEB05F4D406E8786C5A8C7424079CDAB3AAB5D4D403750E09D7CC4424079CDAB3AAB5D4D40
26281	Яганово	3	27	296	38.121032999999997	38.147748999999997	59.338724999999997	59.329025999999999	0103000020E610000001000000050000004E5E64027E0F434050C422861DAA4D404E5E64027E0F434036AB3E575BAB4D4023827170E912434036AB3E575BAB4D4023827170E912434050C422861DAA4D404E5E64027E0F434050C422861DAA4D40
26210	Щетинское	3	27	296	38.304406	38.326667	58.823948000000001	58.811236999999998	0103000020E61000000100000005000000645A9BC6F62643400F27309DD6674D40645A9BC6F626434064CDC82077694D405AD76839D029434064CDC82077694D405AD76839D02943400F27309DD6674D40645A9BC6F62643400F27309DD6674D40
24591	Шухободь	3	27	296	37.702579999999998	37.724643	59.236643000000001	59.223531000000001	0103000020E610000001000000050000006E693524EED942403352EFA99C9C4D406E693524EED94240E6E95C514A9E4D403E23111AC1DC4240E6E95C514A9E4D403E23111AC1DC42403352EFA99C9C4D406E693524EED942403352EFA99C9C4D40
25389	Шулма	3	27	296	37.534064999999998	37.557727	59.210943999999998	59.198937999999998	0103000020E610000001000000050000001878EE3D5CC4424040F7E5CC76994D401878EE3D5CC44240CAA48636009B4D40508C2C9963C74240CAA48636009B4D40508C2C9963C7424040F7E5CC76994D401878EE3D5CC4424040F7E5CC76994D40
25244	Шишовка	3	27	296	38.864111000000001	38.878321999999997	58.859656999999999	58.848165000000002	0103000020E61000000100000005000000938E72309B6E4340514EB4AB906C4D40938E72309B6E43408463963D096E4D40BCADF4DA6C7043408463963D096E4D40BCADF4DA6C704340514EB4AB906C4D40938E72309B6E4340514EB4AB906C4D40
26173	Шалимово	3	27	296	38.60801	38.625059999999998	58.9664	58.961008999999997	0103000020E610000001000000050000000BD28C45D34D4340B114C957027B4D400BD28C45D34D43405D6DC5FEB27B4D40D50451F7015043405D6DC5FEB27B4D40D50451F701504340B114C957027B4D400BD28C45D34D4340B114C957027B4D40
24898	Шайма	3	27	296	38.107469000000002	38.138936999999999	59.089861999999997	59.080148000000001	0103000020E61000000100000005000000BB2A508BC10D43407F6B274A428A4D40BB2A508BC10D43409A931799808B4D40289A07B0C81143409A931799808B4D40289A07B0C81143407F6B274A428A4D40BB2A508BC10D43407F6B274A428A4D40
25047	Чаево	3	27	296	37.203665000000001	37.238331000000002	58.932952	58.923231000000001	0103000020E61000000100000005000000802BD9B1119A4240A2D3F36E2C764D40802BD9B1119A4240705E9CF86A774D40BE4F55A1819E4240705E9CF86A774D40BE4F55A1819E4240A2D3F36E2C764D40802BD9B1119A4240A2D3F36E2C764D40
25557	Харламовская	3	27	296	37.205120000000001	37.222636999999999	58.814954999999998	58.791241999999997	0103000020E61000000100000005000000B5E0455F419A42405E9CF86A47654D40B5E0455F419A4240185B087250684D4095F0845E7F9C4240185B087250684D4095F0845E7F9C42405E9CF86A47654D40B5E0455F419A42405E9CF86A47654D40
21630	Улазорский	3	27	296	37.379832999999998	37.395311	59.562981000000001	59.557237000000001	0103000020E610000001000000050000008578245E9EB04240828FC18A53C74D408578245E9EB042407BA2EBC20FC84D40E15F048D99B242407BA2EBC20FC84D40E15F048D99B24240828FC18A53C74D408578245E9EB04240828FC18A53C74D40
26045	Тоншалово	3	27	296	37.943489999999997	37.957144999999997	59.202849999999998	59.188301000000003	0103000020E61000000100000005000000300DC347C4F84240ED66463F1A984D40300DC347C4F842402EFF21FDF6994D40D44334BA83FA42402EFF21FDF6994D40D44334BA83FA4240ED66463F1A984D40300DC347C4F84240ED66463F1A984D40
25918	Сурково	3	27	296	38.322552000000002	38.339216	58.996524999999998	58.989153999999999	0103000020E6100000010000000500000034A1496249294340925A28999C7E4D4034A1496249294340BD5296218E7F4D40D5230D6E6B2B4340BD5296218E7F4D40D5230D6E6B2B4340925A28999C7E4D4034A1496249294340925A28999C7E4D40
25635	Суда	3	27	296	37.535781	37.614716000000001	59.171337999999999	59.131926	0103000020E61000000100000005000000BA68C87894C44240FDBE7FF3E2904D40BA68C87894C44240F1475167EE954D40FA298E03AFCE4240F1475167EE954D40FA298E03AFCE4240FDBE7FF3E2904D40BA68C87894C44240FDBE7FF3E2904D40
24694	Романово	3	27	296	37.949185	37.973314000000002	59.389212999999998	59.371406	0103000020E61000000100000005000000486DE2E47EF94240E3C4573B8AAF4D40486DE2E47EF94240CA1649BBD1B14D40965E9B8D95FC4240CA1649BBD1B14D40965E9B8D95FC4240E3C4573B8AAF4D40486DE2E47EF94240E3C4573B8AAF4D40
24156	Починок	3	27	296	38.039942000000003	38.068517999999997	59.028396999999998	59.014589000000001	0103000020E6100000010000000500000051DEC7D11C054340D0F0660DDE814D4051DEC7D11C054340FA264D83A2834D40FA97A432C5084340FA264D83A2834D40FA97A432C5084340D0F0660DDE814D4051DEC7D11C054340D0F0660DDE814D40
21167	Поповка	3	27	296	37.499471	37.526285999999999	59.505204999999997	59.492462000000003	0103000020E6100000010000000500000074266DAAEEBF4240EA42ACFE08BF4D4074266DAAEEBF42404963B48EAAC04D40DC2BF3565DC342404963B48EAAC04D40DC2BF3565DC34240EA42ACFE08BF4D4074266DAAEEBF4240EA42ACFE08BF4D40
25020	Песье	3	27	296	37.385429999999999	37.401941000000001	59.031920999999997	59.020069999999997	0103000020E61000000100000005000000DA722EC555B14240BBD05CA791824D40DA722EC555B142401E87C1FC15844D40F5F57CCD72B342401E87C1FC15844D40F5F57CCD72B34240BBD05CA791824D40DA722EC555B14240BBD05CA791824D40
22176	Новое Домозерово	3	27	296	38.132738000000003	38.149284999999999	59.045879999999997	59.039648999999997	0103000020E61000000100000005000000DE770C8FFD104340D828EB3713854D40DE770C8FFD1043402EC55565DF854D40456458C51B1343402EC55565DF854D40456458C51B134340D828EB3713854D40DE770C8FFD104340D828EB3713854D40
25536	Николо-Раменье	3	27	296	37.362378999999997	37.403278999999998	58.815565999999997	58.805535999999996	0103000020E61000000100000005000000EBE0606F62AE424015E0BBCD1B674D40EBE0606F62AE424061DD787764684D40F01472A59EB3424061DD787764684D40F01472A59EB3424015E0BBCD1B674D40EBE0606F62AE424015E0BBCD1B674D40
25409	Нелазское	3	27	296	37.616278999999999	37.647413999999998	59.19473	59.186290999999997	0103000020E61000000100000005000000151BF33AE2CE424002452C62D8974D40151BF33AE2CE424069C6A2E9EC984D407C7C4276DED2424069C6A2E9EC984D407C7C4276DED2424002452C62D8974D40151BF33AE2CE424002452C62D8974D40
25259	Мякса	3	27	296	38.180627000000001	38.213631999999997	58.895180000000003	58.883178999999998	0103000020E6100000010000000500000026E318C91E174340CAC16C020C714D4026E318C91E17434043041C4295724D4085B01A4B581B434043041C4295724D4085B01A4B581B4340CAC16C020C714D4026E318C91E174340CAC16C020C714D40
26233	Музга	3	27	296	38.394157	38.404522999999998	58.768362000000003	58.762673999999997	0103000020E61000000100000005000000A73E90BC7332434037C1374D9F614D40A73E90BC733243409DBE9EAF59624D406ABDDF68C73343409DBE9EAF59624D406ABDDF68C733434037C1374D9F614D40A73E90BC7332434037C1374D9F614D40
25106	Малечкино	3	27	296	37.849544000000002	37.877912999999999	59.220694000000002	59.206806999999998	0103000020E61000000100000005000000AB4198DBBDEC4240BCCADAA6789A4D40AB4198DBBDEC4240333674B33F9C4D40DBDD03745FF04240333674B33F9C4D40DBDD03745FF04240BCCADAA6789A4D40AB4198DBBDEC4240BCCADAA6789A4D40
24974	Коротово	3	27	296	37.452210000000001	37.478639000000001	58.960155	58.947048000000002	0103000020E610000001000000050000004B766C04E2B9424001DF6DDE38794D404B766C04E2B94240A20BEA5BE67A4D408ACBF10A44BD4240A20BEA5BE67A4D408ACBF10A44BD424001DF6DDE38794D404B766C04E2B9424001DF6DDE38794D40
24918	Климовское	3	27	296	38.008707999999999	38.028444	59.350704999999998	59.340491	0103000020E61000000100000005000000569BFF571D0143408ACA863595AB4D40569BFF571D01434097C5C4E6E3AC4D403BE2900DA403434097C5C4E6E3AC4D403BE2900DA40343408ACA863595AB4D40569BFF571D0143408ACA863595AB4D40
24830	Ирдоматка	3	27	296	38.079953000000003	38.135460000000002	59.119790000000002	59.109678000000002	0103000020E61000000100000005000000CA1B60E63B0A43409C8BBFED098E4D40CA1B60E63B0A4340A5315A47558F4D4045F5D6C056114340A5315A47558F4D4045F5D6C0561143409C8BBFED098E4D40CA1B60E63B0A43409C8BBFED098E4D40
24811	Ивановское	3	27	296	37.948853	37.963298000000002	59.501269000000001	59.491909	0103000020E6100000010000000500000012DBDD0374F94240D5CDC5DFF6BE4D4012DBDD0374F94240D3BF249529C04D40AF264F594DFB4240D3BF249529C04D40AF264F594DFB4240D5CDC5DFF6BE4D4012DBDD0374F94240D5CDC5DFF6BE4D40
23135	Городище	3	27	296	37.849696999999999	37.868364	59.063778999999997	59.056955000000002	0103000020E6100000010000000500000031410DDFC2EC4240FE2B2B4D4A874D4031410DDFC2EC4240F69507E929884D400A83328D26EF4240F69507E929884D400A83328D26EF4240FE2B2B4D4A874D4031410DDFC2EC4240FE2B2B4D4A874D40
25971	Горка-Заречье	3	27	296	37.992007999999998	38.003703999999999	59.404325999999998	59.393459999999997	0103000020E6100000010000000500000068AF3E1EFAFE42405F24B4E55CB24D4068AF3E1EFAFE4240147651F4C0B34D40A46E675F79004340147651F4C0B34D40A46E675F790043405F24B4E55CB24D4068AF3E1EFAFE42405F24B4E55CB24D40
3019	Воскресенское	3	27	296	37.890282999999997	37.944468999999998	59.440271000000003	59.423402000000003	0103000020E61000000100000005000000A69718CBF4F14240CF87670932B64D40A69718CBF4F142404930D5CC5AB84D40FC8A355CE4F842404930D5CC5AB84D40FC8A355CE4F84240CF87670932B64D40A69718CBF4F14240CF87670932B64D40
26492	Ботово	3	27	296	37.953398999999997	37.978389999999997	59.265034999999997	59.251088000000003	0103000020E6100000010000000500000001857AFA08FA42408335CEA623A04D4001857AFA08FA4240CEA5B8AAECA14D40E15D2EE23BFD4240CEA5B8AAECA14D40E15D2EE23BFD42408335CEA623A04D4001857AFA08FA42408335CEA623A04D40
26380	Борок	3	27	296	37.536983999999997	37.552112000000001	58.549543	58.535181000000001	0103000020E61000000100000005000000D53C47E4BBC4424065389ECF80444D40D53C47E4BBC44240745FCE6C57464D4055DD239BABC64240745FCE6C57464D4055DD239BABC6424065389ECF80444D40D53C47E4BBC4424065389ECF80444D40
26455	Большой Двор	3	27	296	37.714123000000001	37.735117000000002	58.716169000000001	58.707315999999999	0103000020E610000001000000050000002429E96168DB424001F8A754895A4D402429E96168DB42405BB4006DAB5B4D40E8DD585018DE42405BB4006DAB5B4D40E8DD585018DE424001F8A754895A4D402429E96168DB424001F8A754895A4D40
25834	Большое Ново	3	27	296	37.566135000000003	37.578909000000003	59.128177000000001	59.123328000000001	0103000020E610000001000000050000007C0F971C77C842402E573F36C98F4D407C0F971C77C84240B98C9B1A68904D40172EABB019CA4240B98C9B1A68904D40172EABB019CA42402E573F36C98F4D407C0F971C77C842402E573F36C98F4D40
25990	Батран	3	27	296	38.410569000000002	38.417521999999998	58.963903999999999	58.960312999999999	0103000020E610000001000000050000002FE065868D3443403A765089EB7A4D402FE065868D344340E63DCE34617B4D4025AE635C71354340E63DCE34617B4D4025AE635C713543403A765089EB7A4D402FE065868D3443403A765089EB7A4D40
25478	Андогский	3	27	296	37.382886999999997	37.413339999999998	59.204613999999999	59.188107000000002	0103000020E610000001000000050000002288F37002B142400893E2E313984D402288F37002B14240E126A3CA309A4D4077103B53E8B44240E126A3CA309A4D4077103B53E8B442400893E2E313984D402288F37002B142400893E2E313984D40
25174	Аксеново	3	27	296	38.499493000000001	38.51755	58.912745000000001	58.904798	0103000020E610000001000000050000005CCAF962EF3F43403CBEBD6BD0734D405CCAF962EF3F4340344B02D4D4744D40BC0512143F424340344B02D4D4744D40BC0512143F4243403CBEBD6BD0734D405CCAF962EF3F43403CBEBD6BD0734D40
24559	Абаканово	3	27	296	37.648887999999999	37.670411000000001	59.292554000000003	59.282319000000001	0103000020E61000000100000005000000286211C30ED342400C056C0723A44D40286211C30ED342403128D36872A54D4078F01307D0D542403128D36872A54D4078F01307D0D542400C056C0723A44D40286211C30ED342400C056C0723A44D40
23641	Чагода	3	27	1734	35.286211000000002	35.296028999999997	59.139654	59.134788999999998	0103000020E61000000100000005000000B360E28FA2A44140266E15C440914D40B360E28FA2A44140B760A92EE0914D4073D53C47E4A54140B760A92EE0914D4073D53C47E4A54140266E15C440914D40B360E28FA2A44140266E15C440914D40
23926	Чагода	3	27	1734	35.281063000000003	35.371172999999999	59.180030000000002	59.149194000000001	0103000020E61000000100000005000000CE8E54DFF9A341403561FBC918934D40CE8E54DFF9A34140422619390B974D404014CC9882AF4140422619390B974D404014CC9882AF41403561FBC918934D40CE8E54DFF9A341403561FBC918934D40
24500	Смердомский	3	27	1734	35.047258999999997	35.076005000000002	59.183765000000001	59.170369999999998	0103000020E6100000010000000500000088B839950C864140191C25AFCE954D4088B839950C86414021938C9C85974D408FAA2688BA89414021938C9C85974D408FAA2688BA894140191C25AFCE954D4088B839950C864140191C25AFCE954D40
24000	Сазоново	3	27	1734	35.209260999999998	35.250044000000003	59.112478000000003	59.070205000000001	0103000020E6100000010000000500000004AA7F10C99A41400282397AFC884D4004AA7F10C99A41407FC2D9AD658E4D40D047197101A041407FC2D9AD658E4D40D047197101A041400282397AFC884D4004AA7F10C99A41400282397AFC884D40
32351	Покровское	3	27	1734	35.554501000000002	35.589778000000003	58.961323999999998	58.947926000000002	0103000020E61000000100000005000000B64C86E3F9C641409983A0A355794D40B64C86E3F9C64140116E32AA0C7B4D403DF372D87DCB4140116E32AA0C7B4D403DF372D87DCB41409983A0A355794D40B64C86E3F9C641409983A0A355794D40
24432	Первомайский	3	27	1734	35.114632	35.124622000000002	59.175811000000003	59.171739000000002	0103000020E610000001000000050000009C89E942AC8E41405039268BFB954D409C89E942AC8E414077A38FF980964D405A2E1B9DF38F414077A38FF980964D405A2E1B9DF38F41405039268BFB954D409C89E942AC8E41405039268BFB954D40
24402	Мегрино	3	27	1734	35.578693000000001	35.593389999999999	59.149318999999998	59.144976	0103000020E610000001000000050000004AB6BA9C12CA41403A5AD5928E924D404AB6BA9C12CA4140F1D58EE21C934D4000E31934F4CB4140F1D58EE21C934D4000E31934F4CB41403A5AD5928E924D404AB6BA9C12CA41403A5AD5928E924D40
24312	Избоищи	3	27	1734	35.270634000000001	35.300566000000003	58.992302000000002	58.982857000000003	0103000020E61000000100000005000000C4978922A4A2414085D21742CE7D4D40C4978922A4A24140B1E07EC0037F4D4010255AF278A64140B1E07EC0037F4D4010255AF278A6414085D21742CE7D4D40C4978922A4A2414085D21742CE7D4D40
24244	Борисово	3	27	1734	35.366754	35.392426999999998	59.110990999999999	59.100524999999998	0103000020E61000000100000005000000AED689CBF1AE414017B7D100DE8C4D40AED689CBF1AE41403E93FDF3348E4D40A088450C3BB241403E93FDF3348E4D40A088450C3BB2414017B7D100DE8C4D40AED689CBF1AE414017B7D100DE8C4D40
24184	Белые Кресты	3	27	1734	35.212477	35.225529000000002	59.077840000000002	59.071629000000001	0103000020E610000001000000050000007B134372329B4140FC389A232B894D407B134372329B41400B293FA9F6894D4059A65F22DE9C41400B293FA9F6894D4059A65F22DE9C4140FC389A232B894D407B134372329B4140FC389A232B894D40
24328	Анишино	3	27	1734	35.312235000000001	35.334359999999997	58.891455999999998	58.881923	0103000020E6100000010000000500000052D50451F7A741408C4B55DAE2704D4052D50451F7A7414057E9EE3A1B724D40978BF84ECCAA414057E9EE3A1B724D40978BF84ECCAA41408C4B55DAE2704D4052D50451F7A741408C4B55DAE2704D40
23587	Шапша	3	27	499	39.852122999999999	39.878183	60.165782	60.148780000000002	0103000020E61000000100000005000000AF95D05D12ED4340422619390B134E40AF95D05D12ED4340FB21365838154E409B73F04C68F04340FB21365838154E409B73F04C68F04340422619390B134E40AF95D05D12ED4340422619390B134E40
51299	Харовск	3	27	499	40.169829999999997	40.236897999999997	59.979177999999997	59.932743000000002	0103000020E6100000010000000500000099F04BFDBC1544405649641F64F74D4099F04BFDBC154440397B67B455FD4D40703E75AC521E4440397B67B455FD4D40703E75AC521E44405649641F64F74D4099F04BFDBC1544405649641F64F74D40
23005	Сорожино	3	27	499	40.048521000000001	40.068123	60.063963000000001	60.056741000000002	0103000020E61000000100000005000000A915A6EF35064440D2AB014A43074E40A915A6EF35064440B89388F02F084E407E8D2441B8084440B89388F02F084E407E8D2441B8084440D2AB014A43074E40A915A6EF35064440D2AB014A43074E40
23496	Ситинский	3	27	499	40.150049000000003	40.165626000000003	59.997810999999999	59.990462000000001	0103000020E6100000010000000500000015E63DCE3413444023F77475C7FE4D4015E63DCE34134440664B5645B8FF4D4004AF963B33154440664B5645B8FF4D4004AF963B3315444023F77475C7FE4D4015E63DCE3413444023F77475C7FE4D40
23268	Семигородняя	3	27	499	40.157065000000003	40.191218999999997	59.821947000000002	59.801639000000002	0103000020E61000000100000005000000522CB7B41A1444405D19541B9CE64D40522CB7B41A144440CD052E8F35E94D40D9AF3BDD79184440CD052E8F35E94D40D9AF3BDD791844405D19541B9CE64D40522CB7B41A1444405D19541B9CE64D40
22870	Семениха	3	27	499	40.449556000000001	40.463022000000002	60.003120000000003	59.998049000000002	0103000020E610000001000000050000003CDC0E0D8B3944401B67D311C0FF4D403CDC0E0D8B39444055FB743C66004E400DAA0D4E443B444055FB743C66004E400DAA0D4E443B44401B67D311C0FF4D403CDC0E0D8B3944401B67D311C0FF4D40
22844	Поповка	3	27	499	39.663629	39.675863999999997	60.268410000000003	60.262649000000003	0103000020E61000000100000005000000AED689CBF1D44340DFA9807B9E214E40AED689CBF1D44340AEF545425B224E40994528B682D64340AEF545425B224E40994528B682D64340DFA9807B9E214E40AED689CBF1D44340DFA9807B9E214E40
53296	Погост Никольский	3	27	499	39.384692999999999	41.008290000000002	60.403396000000001	59.721995999999997	0103000020E610000001000000050000000400C79E3DB14340E1EB6B5D6ADC4D400400C79E3DB143402AABE97AA2334E4022718FA50F8144402AABE97AA2334E4022718FA50F814440E1EB6B5D6ADC4D400400C79E3DB14340E1EB6B5D6ADC4D40
23259	Никулинское	3	27	499	40.095252000000002	40.107190000000003	60.249935000000001	60.245353000000001	0103000020E610000001000000050000007670B037310C4440DD7C23BA671F4E407670B037310C44401990BDDEFD1F4E40A83AE466B80D44401990BDDEFD1F4E40A83AE466B80D4440DD7C23BA671F4E407670B037310C4440DD7C23BA671F4E40
53295	Нижнекубенский	3	27	499	39.942160999999999	39.959355000000002	59.978296	59.967975000000003	0103000020E6100000010000000500000088484DBB98F843403D2CD49AE6FB4D4088484DBB98F8434060E7A6CD38FD4D4086200725CCFA434060E7A6CD38FD4D4086200725CCFA43403D2CD49AE6FB4D4088484DBB98F843403D2CD49AE6FB4D40
3010	Михайловское	3	27	499	40.467001000000003	40.490268	59.972203999999998	59.961781999999999	0103000020E61000000100000005000000831953B0C63B4440D4F02DAC1BFB4D40831953B0C63B44402B85402E71FC4D403E23111AC13E44402B85402E71FC4D403E23111AC13E4440D4F02DAC1BFB4D40831953B0C63B4440D4F02DAC1BFB4D40
23072	Кумзеро	3	27	499	39.644171999999998	39.650244000000001	60.141627	60.138728	0103000020E61000000100000005000000DC7F643A74D243400E85CFD6C1114E40DC7F643A74D24340849D62D520124E40CA3505323BD34340849D62D520124E40CA3505323BD343400E85CFD6C1114E40DC7F643A74D243400E85CFD6C1114E40
22917	Золотава	3	27	499	40.586692999999997	40.604604999999999	60.025416999999997	60.019441999999998	0103000020E6100000010000000500000064E597C1184B44409C1551137D024E4064E597C1184B444097E13FDD40034E40C1FF56B2634D444097E13FDD40034E40C1FF56B2634D44409C1551137D024E4064E597C1184B44409C1551137D024E40
23207	Гора	3	27	499	39.983725999999997	39.990777999999999	60.014225000000003	60.011136	0103000020E61000000100000005000000C91CCBBBEAFD434075E789E76C014E40C91CCBBBEAFD43408FE4F21FD2014E4053CC41D0D1FE43408FE4F21FD2014E4053CC41D0D1FE434075E789E76C014E40C91CCBBBEAFD434075E789E76C014E40
23429	Бараниха	3	27	499	40.246923000000002	40.257945999999997	59.960661000000002	59.953046999999998	0103000020E61000000100000005000000ABD0402C9B1F44408446B071FDF94D40ABD0402C9B1F444076C58CF0F6FA4D402711E15F0421444076C58CF0F6FA4D402711E15F042144408446B071FDF94D40ABD0402C9B1F44408446B071FDF94D40
23364	Арзубиха	3	27	499	40.566893999999998	40.583396	60.166215999999999	60.154153999999998	0103000020E6100000010000000500000039268BFB8F48444017467A51BB134E4039268BFB8F4844403509DE9046154E40014F5AB8AC4A44403509DE9046154E40014F5AB8AC4A444017467A51BB134E4039268BFB8F48444017467A51BB134E40
21446	Ярцево	3	27	489	36.040337000000001	36.057009999999998	58.754337	58.744981000000003	0103000020E61000000100000005000000CDE847C329054240199293895B5F4D40CDE847C329054240D594641D8E604D40C1C58A1A4C074240D594641D8E604D40C1C58A1A4C074240199293895B5F4D40CDE847C329054240199293895B5F4D40
22551	Яковлевское	3	27	489	36.142054000000002	36.167090000000002	58.821762999999997	58.815491000000002	0103000020E610000001000000050000000C2252D32E1242405797530262684D400C2252D32E1242400B08AD872F694D408CBE8234631542400B08AD872F694D408CBE8234631542405797530262684D400C2252D32E1242405797530262684D40
2932	Устюжна	3	27	489	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
21512	Степачево	3	27	489	36.277707999999997	36.290607999999999	58.781849000000001	58.770536	0103000020E6100000010000000500000035EB8CEF8B234240013274ECA0624D4035EB8CEF8B23424085B4C6A013644D405DFA97A43225424085B4C6A013644D405DFA97A432254240013274ECA0624D4035EB8CEF8B234240013274ECA0624D40
22002	Спасское	3	27	489	36.335515000000001	36.352106999999997	58.690452000000001	58.681663	0103000020E61000000100000005000000A228D027F22A424056F2B1BB40574D40A228D027F22A424099BA2BBB60584D40A9D898D7112D424099BA2BBB60584D40A9D898D7112D424056F2B1BB40574D40A228D027F22A424056F2B1BB40574D40
22238	Соболево	3	27	489	36.535336000000001	36.564486000000002	58.832104000000001	58.824134000000001	0103000020E610000001000000050000008C2FDAE385444240C6C210397D694D408C2FDAE385444240766F4562826A4D406286C61341484240766F4562826A4D406286C61341484240C6C210397D694D408C2FDAE385444240C6C210397D694D40
21849	Слуды	3	27	489	36.866472999999999	36.888958000000002	58.879573999999998	58.873443999999999	0103000020E61000000100000005000000FAEE5696E86E424097715303CD6F4D40FAEE5696E86E4240B9347EE195704D4040C23060C9714240B9347EE195704D4040C23060C971424097715303CD6F4D40FAEE5696E86E424097715303CD6F4D40
22263	Славынево	3	27	489	36.793250999999998	36.819716	58.749822999999999	58.737000000000002	0103000020E610000001000000050000007842AF3F8965424075931804565E4D407842AF3F89654240F1643733FA5F4D4004013274EC684240F1643733FA5F4D4004013274EC68424075931804565E4D407842AF3F8965424075931804565E4D40
22128	Расторопово	3	27	489	36.294758000000002	36.314062999999997	58.557886000000003	58.549087999999998	0103000020E61000000100000005000000001E51A1BA2542402250FD8348464D40001E51A1BA254240B972F6CE68474D401BF1643733284240B972F6CE68474D401BF16437332842402250FD8348464D40001E51A1BA2542402250FD8348464D40
22346	Оснополье	3	27	489	36.583314999999999	36.600203	58.922701000000004	58.913642000000003	0103000020E610000001000000050000001422E010AA4A424043209738F2744D401422E010AA4A4240467EFD101B764D4005FBAF73D34C4240467EFD101B764D4005FBAF73D34C424043209738F2744D401422E010AA4A424043209738F2744D40
22099	Никола	3	27	489	36.381265999999997	36.400812999999999	58.555548000000002	58.533875000000002	0103000020E61000000100000005000000D2890453CD3042407593180456444D40D2890453CD304240DAAD65321C474D40E46723D74D334240DAAD65321C474D40E46723D74D3342407593180456444D40D2890453CD3042407593180456444D40
21785	Модно	3	27	489	36.902099999999997	36.906987000000001	58.932056000000003	58.925590999999997	0103000020E610000001000000050000005DDC460378734240683C11C479764D405DDC46037873424032056B9C4D774D40D67267261874424032056B9C4D774D40D672672618744240683C11C479764D405DDC460378734240683C11C479764D40
21690	Мережа	3	27	489	36.388902000000002	36.405844000000002	59.033856999999998	59.020750999999997	0103000020E61000000100000005000000ACAC6D8AC7314240FD2D01F8A7824D40ACAC6D8AC7314240CEDE196D55844D4090A339B2F2334240CEDE196D55844D4090A339B2F2334240FD2D01F8A7824D40ACAC6D8AC7314240FD2D01F8A7824D40
22017	Мелечино	3	27	489	36.341444000000003	36.362302999999997	58.669367000000001	58.657933	0103000020E610000001000000050000002DB5DE6FB42B4240C6FA062637544D402DB5DE6FB42B4240C5025FD1AD554D40101FD8F15F2E4240C5025FD1AD554D40101FD8F15F2E4240C6FA062637544D402DB5DE6FB42B4240C6FA062637544D40
21406	Малое Восное	3	27	489	36.192780999999997	36.206893999999998	58.690882000000002	58.682223999999998	0103000020E6100000010000000500000024253D0CAD184240ED45B41D53574D4024253D0CAD18424092B245D26E584D408BDEA9807B1A424092B245D26E584D408BDEA9807B1A4240ED45B41D53574D4024253D0CAD184240ED45B41D53574D40
21535	Лентьево	3	27	489	36.591785999999999	36.624457999999997	58.973005999999998	58.960656	0103000020E61000000100000005000000861DC6A4BF4B4240645A9BC6F67A4D40861DC6A4BF4B4240E867EA758B7C4D40DFDC5F3DEE4F4240E867EA758B7C4D40DFDC5F3DEE4F4240645A9BC6F67A4D40861DC6A4BF4B4240645A9BC6F67A4D40
22332	Имени Желябова	3	27	489	36.571969000000003	36.630682999999998	58.959566000000002	58.950051999999999	0103000020E61000000100000005000000B5A9BA4736494240ECBFCE4D9B794D40B5A9BA4736494240412D060FD37A4D4053927538BA504240412D060FD37A4D4053927538BA504240ECBFCE4D9B794D40B5A9BA4736494240ECBFCE4D9B794D40
21752	Долоцкое	3	27	489	35.936805999999997	35.992806999999999	58.978043999999997	58.959088000000001	0103000020E6100000010000000500000029594E42E9F7414037FE4465C37A4D4029594E42E9F741404606B98B307D4D40B41EBE4C14FF41404606B98B307D4D40B41EBE4C14FF414037FE4465C37A4D4029594E42E9F7414037FE4465C37A4D40
21941	Даниловское	3	27	489	36.438021999999997	36.463749	58.719842	58.714658999999997	0103000020E61000000100000005000000D976DA1A11384240626534F2795B4D40D976DA1A11384240C4245CC8235C4D40BF4692205C3B4240C4245CC8235C4D40BF4692205C3B4240626534F2795B4D40D976DA1A11384240626534F2795B4D40
21885	Веницы	3	27	489	36.481177000000002	36.493707999999998	58.673186000000001	58.661987000000003	0103000020E61000000100000005000000304B3B35973D424047B071FDBB544D40304B3B35973D4240021077F52A564D4004E3E0D2313F4240021077F52A564D4004E3E0D2313F424047B071FDBB544D40304B3B35973D424047B071FDBB544D40
21600	Ванское	3	27	489	36.857059	36.892892000000003	58.944856999999999	58.932873000000001	0103000020E6100000010000000500000009DFFB1BB46D42402429E96168774D4009DFFB1BB46D4240C632FD12F1784D40166EF9484A724240C632FD12F1784D40166EF9484A7242402429E96168774D4009DFFB1BB46D42402429E96168774D40
22464	Брилино	3	27	489	36.413964999999997	36.437033	58.757922000000001	58.749487000000002	0103000020E6100000010000000500000025581CCEFC3442407AE3A430EF5F4D4025581CCEFC3442409F758D9603614D40EA2285B2F03742409F758D9603614D40EA2285B2F03742407AE3A430EF5F4D4025581CCEFC3442407AE3A430EF5F4D40
20170	Устье	3	27	1616	39.694468000000001	39.764257999999998	59.638997000000003	59.624257	0103000020E610000001000000050000002C0FD253E4D8434048A643A7E7CF4D402C0FD253E4D84340FE9E58A7CAD14D406ADAC534D3E14340FE9E58A7CAD14D406ADAC534D3E1434048A643A7E7CF4D402C0FD253E4D8434048A643A7E7CF4D40
20935	Порохово	3	27	1616	39.834749000000002	39.846471999999999	59.660699000000001	59.655648999999997	0103000020E6100000010000000500000032AF230ED9EA4340DA53724EECD34D4032AF230ED9EA4340FDBFEAC891D44D40677DCA3159EC4340FDBFEAC891D44D40677DCA3159EC4340DA53724EECD34D4032AF230ED9EA4340DA53724EECD34D40
20651	Никольское	3	27	1616	39.347197999999999	39.377479999999998	59.854241999999999	59.840397000000003	0103000020E61000000100000005000000499EEBFB70AC43400954FF2092EB4D40499EEBFB70AC4340506F46CD57ED4D407172BF4351B04340506F46CD57ED4D407172BF4351B043400954FF2092EB4D40499EEBFB70AC43400954FF2092EB4D40
20898	Никола-Корень	3	27	1616	39.621319	39.634461000000002	59.697513999999998	59.691415999999997	0103000020E6100000010000000500000014B1886187CF43402FF7C95180D84D4014B1886187CF43404640852348D94D4032CB9E0436D143404640852348D94D4032CB9E0436D143402FF7C95180D84D4014B1886187CF43402FF7C95180D84D40
20499	Никифоровская	3	27	1616	39.338484000000001	39.345329	60.134793999999999	60.131746999999997	0103000020E61000000100000005000000111C977153AB43404D2CF015DD104E40111C977153AB434038D906EE40114E4021AE9CBD33AC434038D906EE40114E4021AE9CBD33AC43404D2CF015DD104E40111C977153AB43404D2CF015DD104E40
20631	Митенское	3	27	1616	39.746912000000002	39.767446999999997	59.583862000000003	59.576690999999997	0103000020E61000000100000005000000B77EFACF9ADF4340E272BC02D1C94D40B77EFACF9ADF434047B071FDBBCA4D40E7340BB43BE2434047B071FDBBCA4D40E7340BB43BE24340E272BC02D1C94D40B77EFACF9ADF4340E272BC02D1C94D40
20379	Марковская	3	27	1616	39.064498	39.268047000000003	60.071820000000002	59.989265000000003	0103000020E610000001000000050000002654707841884340EA094B3CA0FE4D4026547078418843407099D36531094E403D65355D4FA243407099D36531094E403D65355D4FA24340EA094B3CA0FE4D402654707841884340EA094B3CA0FE4D40
20728	Королиха	3	27	1616	39.659488000000003	39.670563999999999	59.878604000000003	59.874651999999998	0103000020E610000001000000050000005F0D501A6AD44340C4B0C398F4EF4D405F0D501A6AD4434041118B1876F04D40FEEF880AD5D5434041118B1876F04D40FEEF880AD5D54340C4B0C398F4EF4D405F0D501A6AD44340C4B0C398F4EF4D40
20575	Заднее	3	27	1616	39.683185000000002	39.714500999999998	59.776065000000003	59.766905000000001	0103000020E61000000100000005000000130F289B72D74340C7116BF129E24D40130F289B72D74340FE48111956E34D40CAFACDC474DB4340FE48111956E34D40CAFACDC474DB4340C7116BF129E24D40130F289B72D74340C7116BF129E24D40
20820	Высокое	3	27	1616	39.826422000000001	39.860055000000003	59.636614000000002	59.623505999999999	0103000020E61000000100000005000000F3583332C8E943400D6E6B0BCFCF4D40F3583332C8E943407F164B917CD14D4072E1404816EE43407F164B917CD14D4072E1404816EE43400D6E6B0BCFCF4D40F3583332C8E943400D6E6B0BCFCF4D40
20461	Богородское	3	27	1616	39.265208000000001	39.287396999999999	59.991813	59.982883000000001	0103000020E610000001000000050000009C51F355F2A14340AE65321CCFFD4D409C51F355F2A14340B35F77BAF3FE4D40F8FBC56CC9A44340B35F77BAF3FE4D40F8FBC56CC9A44340AE65321CCFFD4D409C51F355F2A14340AE65321CCFFD4D40
20783	Бережное	3	27	1616	39.272565999999998	39.281818000000001	59.911740999999999	59.904192999999999	0103000020E6100000010000000500000032005471E3A24340D522A298BCF34D4032005471E3A243400FB6D8EDB3F44D404AB6BA9C12A443400FB6D8EDB3F44D404AB6BA9C12A44340D522A298BCF34D4032005471E3A24340D522A298BCF34D40
19476	Юбилейный	3	27	1544	42.044156000000001	42.066515000000003	59.672356000000001	59.665894000000002	0103000020E610000001000000050000000AF65FE7A6054540234DBC033CD54D400AF65FE7A60545407BA2EBC20FD64D40C3D84290830845407BA2EBC20FD64D40C3D8429083084540234DBC033CD54D400AF65FE7A6054540234DBC033CD54D40
18856	Чуриловка	3	27	1544	42.667217999999998	42.679732000000001	59.842458000000001	59.827370000000002	0103000020E61000000100000005000000B9A640666755454084D89942E7E94D40B9A64066675545407520EBA9D5EB4D40B8054B75015745407520EBA9D5EB4D40B8054B750157454084D89942E7E94D40B9A640666755454084D89942E7E94D40
19139	Устье	3	27	1544	42.620379999999997	42.633890999999998	59.790633999999997	59.778063000000003	0103000020E61000000100000005000000D68BA19C684F4540249D819197E34D40D68BA19C684F4540868DB27E33E54D40471D1D5723514540868DB27E33E54D40471D1D5723514540249D819197E34D40D68BA19C684F4540249D819197E34D40
19004	Усть-Царева	3	27	1544	42.670721999999998	42.683936000000003	59.892161999999999	59.887900000000002	0103000020E61000000100000005000000965AEF37DA554540280F0BB5A6F14D40965AEF37DA554540F25D4A5D32F24D404E4700378B574540F25D4A5D32F24D404E4700378B574540280F0BB5A6F14D40965AEF37DA554540280F0BB5A6F14D40
19996	Успенье	3	27	1544	42.775393000000001	42.787745000000001	59.407912000000003	59.400153000000003	0103000020E610000001000000050000000F46EC1340634540BA32A83638B34D400F46EC1340634540AFD2DD7536B44D40344B02D4D4644540AFD2DD7536B44D40344B02D4D4644540BA32A83638B34D400F46EC1340634540BA32A83638B34D40
18374	Тотьма	3	27	1544	42.737386000000001	42.788913000000001	59.985560999999997	59.955236999999997	0103000020E610000001000000050000009E4319AA625E4540EE76BD3445FA4D409E4319AA625E4540459BE3DC26FE4D40D331E719FB644540459BE3DC26FE4D40D331E719FB644540EE76BD3445FA4D409E4319AA625E4540EE76BD3445FA4D40
19857	Текстильщики	3	27	1544	42.820650000000001	42.834997000000001	59.964210000000001	59.957034	0103000020E6100000010000000500000030BB270F0B6945407D94111780FA4D4030BB270F0B694540F33CB83B6BFB4D400AA1832EE16A4540F33CB83B6BFB4D400AA1832EE16A45407D94111780FA4D4030BB270F0B6945407D94111780FA4D40
52410	Советский	3	27	1544	42.703420000000001	42.731358	59.932837999999997	59.919513000000002	0103000020E6100000010000000500000019ADA3AA095A4540999F1B9AB2F54D4019ADA3AA095A4540A73B4F3C67F74D4080D591239D5D4540A73B4F3C67F74D4080D591239D5D4540999F1B9AB2F54D4019ADA3AA095A4540999F1B9AB2F54D40
19451	Середская	3	27	1544	42.066614000000001	42.082954000000001	60.327471000000003	60.320093999999997	0103000020E6100000010000000500000056BABBCE86084540AAD216D7F8284E4056BABBCE86084540B8B1D991EA294E404489963C9E0A4540B8B1D991EA294E404489963C9E0A4540AAD216D7F8284E4056BABBCE86084540AAD216D7F8284E40
19556	Погорелово	3	27	1544	42.031103000000002	42.054971000000002	59.713451999999997	59.702241000000001	0103000020E610000001000000050000005CE7DF2EFB03454086747808E3D94D405CE7DF2EFB03454005A2276552DB4D403D9D2B4A0907454005A2276552DB4D403D9D2B4A0907454086747808E3D94D405CE7DF2EFB03454086747808E3D94D40
19804	Октябрьский	3	27	1544	42.674512	42.692523999999999	60.129573999999998	60.121685999999997	0103000020E610000001000000050000003961C26856564540C6302768930F4E403961C26856564540B9347EE195104E40F9D85DA0A4584540B9347EE195104E40F9D85DA0A4584540C6302768930F4E403961C26856564540C6302768930F4E40
20077	Никольское	3	27	1544	42.514774000000003	42.53584	59.496870000000001	59.486820000000002	0103000020E61000000100000005000000626A4B1DE4414540F584251E50BE4D40626A4B1DE4414540882EA86F99BF4D40BFF1B56796444540882EA86F99BF4D40BFF1B56796444540F584251E50BE4D40626A4B1DE4414540F584251E50BE4D40
19313	Мосеево	3	27	1544	42.444291999999997	42.452503	60.156089000000001	60.151432	0103000020E61000000100000005000000EDEF6C8FDE384540B0C8AF1F62134E40EDEF6C8FDE384540F7216FB9FA134E40C32B499EEB394540F7216FB9FA134E40C32B499EEB394540B0C8AF1F62134E40EDEF6C8FDE384540B0C8AF1F62134E40
19297	Михайловка	3	27	1544	43.460188000000002	43.493695000000002	60.088337000000003	60.074572000000003	0103000020E610000001000000050000007E01BD70E7BA4540429946938B094E407E01BD70E7BA45406D0377A04E0B4E407099D36531BF45406D0377A04E0B4E407099D36531BF4540429946938B094E407E01BD70E7BA4540429946938B094E40
19246	Медведево	3	27	1544	43.011057000000001	43.029724000000002	60.029421999999997	60.024400999999997	0103000020E6100000010000000500000029B2D6506A814540AE7E6C921F034E4029B2D6506A81454036E49F19C4034E4002F4FBFECD83454036E49F19C4034E4002F4FBFECD834540AE7E6C921F034E4029B2D6506A814540AE7E6C921F034E40
19732	Матвеево	3	27	1544	42.798085	42.806348999999997	60.093223000000002	60.086936999999999	0103000020E61000000100000005000000CE3637A627664540FBE769C0200B4E40CE3637A627664540151E34BBEE0B4E40C614AC7136674540151E34BBEE0B4E40C614AC7136674540FBE769C0200B4E40CE3637A627664540FBE769C0200B4E40
18920	Кудринская	3	27	1544	42.283996999999999	42.305269000000003	59.988649000000002	59.981473999999999	0103000020E61000000100000005000000C09481035A244540E9EFA5F0A0FD4D40C09481035A2445408F1CE90C8CFE4D40C7BDF90D132745408F1CE90C8CFE4D40C7BDF90D13274540E9EFA5F0A0FD4D40C09481035A244540E9EFA5F0A0FD4D40
18990	Крутая Осыпь	3	27	1544	42.150722999999999	42.175094000000001	60.074652999999998	60.064945999999999	0103000020E61000000100000005000000A4E029E44A134540C500892650084E40A4E029E44A1345402EC6C03A8E094E40E8DCED7A691645402EC6C03A8E094E40E8DCED7A69164540C500892650084E40A4E029E44A134540C500892650084E40
51296	Красный Бор	3	27	1544	42.225929999999998	42.239449	59.871324000000001	59.864674000000001	0103000020E61000000100000005000000B7973446EB1C4540CBD93BA3ADEE4D40B7973446EB1C4540261C7A8B87EF4D40AB07CC43A61E4540261C7A8B87EF4D40AB07CC43A61E4540CBD93BA3ADEE4D40B7973446EB1C4540CBD93BA3ADEE4D40
19963	Карица	3	27	1544	42.813527000000001	42.852468999999999	59.314320000000002	59.304918000000001	0103000020E61000000100000005000000DDB419A7216845401AFB928D07A74D40DDB419A721684540473D44A33BA84D404AED45B41D6D4540473D44A33BA84D404AED45B41D6D45401AFB928D07A74D40DDB419A7216845401AFB928D07A74D40
19170	Камчуга	3	27	1544	43.148274999999998	43.184584999999998	60.053409000000002	60.041412999999999	0103000020E610000001000000050000003EE8D9ACFA9245408B506C054D054E403EE8D9ACFA924540F2272A1BD6064E40842A357BA0974540F2272A1BD6064E40842A357BA09745408B506C054D054E403EE8D9ACFA9245408B506C054D054E40
19658	Задняя	3	27	1544	42.722123000000003	42.736784	59.947445999999999	59.937309999999997	0103000020E610000001000000050000003F58C6866E5C45405C1B2AC6F9F74D403F58C6866E5C4540EE5C18E945F94D40A81B28F04E5E4540EE5C18E945F94D40A81B28F04E5E45405C1B2AC6F9F74D403F58C6866E5C45405C1B2AC6F9F74D40
19378	Данилов Починок	3	27	1544	42.244506999999999	42.268303000000003	60.277825	60.268856	0103000020E61000000100000005000000505260014C1F4540ACAA97DF69224E40505260014C1F45406F8104C58F234E409835B1C0572245406F8104C58F234E409835B1C057224540ACAA97DF69224E40505260014C1F4540ACAA97DF69224E40
18810	Великий Двор	3	27	1544	42.746980000000001	42.761290000000002	59.680242999999997	59.675131999999998	0103000020E610000001000000050000000F62670A9D5F4540D53DB2B96AD64D400F62670A9D5F45409D2ADF3312D74D40CC6262F3716145409D2ADF3312D74D40CC6262F371614540D53DB2B96AD64D400F62670A9D5F4540D53DB2B96AD64D40
53287	Бор	3	27	1544	42.304307999999999	42.318573000000001	59.601188	59.590243999999998	0103000020E61000000100000005000000A1F48590F326454082548A1D8DCB4D40A1F48590F3264540B35F77BAF3CC4D40BE310400C7284540B35F77BAF3CC4D40BE310400C728454082548A1D8DCB4D40A1F48590F326454082548A1D8DCB4D40
53291	Шебенгский Погост	3	27	274	43.591028000000001	43.612344999999998	60.423032999999997	60.413811000000003	0103000020E61000000100000005000000998235CEA6CB4540CFDC43C2F7344E40998235CEA6CB45407B1002F225364E403F6F2A5261CE45407B1002F225364E403F6F2A5261CE4540CFDC43C2F7344E40998235CEA6CB4540CFDC43C2F7344E40
18076	Тюприха	3	27	274	43.286318999999999	43.293945999999998	60.443362999999998	60.435110999999999	0103000020E61000000100000005000000999CDA19A6A445409F909DB7B1374E40999CDA19A6A44540D3A0681EC0384E401F65C405A0A54540D3A0681EC0384E401F65C405A0A545409F909DB7B1374E40999CDA19A6A445409F909DB7B1374E40
53283	Тарногский Городок	3	27	274	43.556837999999999	43.599885	60.506819999999998	60.486060000000002	0103000020E61000000100000005000000C495B37746C7454067F2CD36373E4E40C495B37746C74540B77A4E7ADF404E40342E1C08C9CC4540B77A4E7ADF404E40342E1C08C9CC454067F2CD36373E4E40C495B37746C7454067F2CD36373E4E40
17339	Слуда	3	27	274	43.614958999999999	43.622306999999999	60.539588999999999	60.534021000000003	0103000020E61000000100000005000000C0B0FCF9B6CE45404930D5CC5A444E40C0B0FCF9B6CE454003249A4011454E4033897AC1A7CF454003249A4011454E4033897AC1A7CF45404930D5CC5A444E40C0B0FCF9B6CE45404930D5CC5A444E40
18231	Сергиевская	3	27	274	43.932395999999997	43.949725000000001	60.251894999999998	60.239891999999998	0103000020E61000000100000005000000EA758BC058F745403849F3C7B41E4E40EA758BC058F74540518369183E204E40C898BB9690F94540518369183E204E40C898BB9690F945403849F3C7B41E4E40EA758BC058F745403849F3C7B41E4E40
17980	Ромашевский Погост	3	27	274	43.336652000000001	43.345024000000002	60.500334000000002	60.496205000000003	0103000020E610000001000000050000000611A96917AB45404C8E3BA5833F4E400611A96917AB4540D789CBF10A404E40E52A16BF29AC4540D789CBF10A404E40E52A16BF29AC45404C8E3BA5833F4E400611A96917AB45404C8E3BA5833F4E40
2098	Раменье	3	27	274	43.756399000000002	43.784686000000001	60.276128999999997	60.265433999999999	0103000020E6100000010000000500000012DDB3AED1E045408C9FC6BDF9214E4012DDB3AED1E04540143DF03158234E4085D0419770E44540143DF03158234E4085D0419770E445408C9FC6BDF9214E4012DDB3AED1E045408C9FC6BDF9214E40
19717	Пятовская	3	27	274	43.642941	43.658634999999997	60.494746999999997	60.421998000000002	0103000020E61000000100000005000000F72004E44BD245401C7DCC0704364E40F72004E44BD24540A565A4DE533F4E401F80D4264ED44540A565A4DE533F4E401F80D4264ED445401C7DCC0704364E40F72004E44BD245401C7DCC0704364E40
17735	Никифоровская	3	27	274	43.193873000000004	43.204833000000001	60.660477999999998	60.652757000000001	0103000020E61000000100000005000000E94999D4D0984540179E978A8D534E40E94999D4D09845401EDD088B8A544E401F12BEF7379A45401EDD088B8A544E401F12BEF7379A4540179E978A8D534E40E94999D4D0984540179E978A8D534E40
17663	Нижнепаунинская	3	27	274	43.328305999999998	43.337065000000003	60.611614000000003	60.607489999999999	0103000020E61000000100000005000000508A56EE05AA4540D252793BC24D4E40508A56EE05AA45404CE3175E494E4E4029D027F224AB45404CE3175E494E4E4029D027F224AB4540D252793BC24D4E40508A56EE05AA4540D252793BC24D4E40
17956	Красное	3	27	274	43.212674999999997	43.236013	60.515444000000002	60.507024000000001	0103000020E61000000100000005000000A1D634EF389B4540C0249529E6404E40A1D634EF389B4540B075A911FA414E4026378AAC359E4540B075A911FA414E4026378AAC359E4540C0249529E6404E40A1D634EF389B4540C0249529E6404E40
18313	Конторка	3	27	274	44.120260999999999	44.140113999999997	60.832729999999998	60.823928000000002	0103000020E61000000100000005000000FCFD62B6640F46401D21037976694E40FCFD62B6640F4640F4328AE5966A4E401ADB6B41EF114640F4328AE5966A4E401ADB6B41EF1146401D21037976694E40FCFD62B6640F46401D21037976694E40
17869	Каплинская	3	27	274	43.049460000000003	43.065477000000001	60.487318999999999	60.482483000000002	0103000020E61000000100000005000000E73A8DB45486454020F0C000C23D4E40E73A8DB45486454016DC0F78603E4E40F2D1E28C6188454016DC0F78603E4E40F2D1E28C6188454020F0C000C23D4E40E73A8DB45486454020F0C000C23D4E40
17794	Ильинская	3	27	274	43.109099000000001	43.117534999999997	60.747374999999998	60.741272000000002	0103000020E610000001000000050000005E83BEF4F68D454063B83A00E25E4E405E83BEF4F68D45408B6CE7FBA95F4E4053910A630B8F45408B6CE7FBA95F4E4053910A630B8F454063B83A00E25E4E405E83BEF4F68D454063B83A00E25E4E40
18287	Илезский Погост	3	27	274	43.912607000000001	43.937660999999999	60.690663999999998	60.677236000000001	0103000020E61000000100000005000000E38C614ED0F4454041D653ABAF564E40E38C614ED0F4454024438EAD67584E4009DE904605F8454024438EAD67584E4009DE904605F8454041D653ABAF564E40E38C614ED0F4454041D653ABAF564E40
17570	Игумновская	3	27	274	43.509163999999998	43.521892999999999	60.512211000000001	60.504852999999997	0103000020E61000000100000005000000782634492CC14540CC24EA059F404E40782634492CC1454063D34A2190414E407381CB63CDC2454063D34A2190414E407381CB63CDC24540CC24EA059F404E40782634492CC14540CC24EA059F404E40
18148	Заречье	3	27	274	43.856721999999998	43.872362000000003	60.426189999999998	60.417608999999999	0103000020E61000000100000005000000C1E10511A9ED4540F4C1323674354E40C1E10511A9ED4540EDF0D7648D364E40F722DA8EA9EF4540EDF0D7648D364E40F722DA8EA9EF4540F4C1323674354E40C1E10511A9ED4540F4C1323674354E40
17421	Евсеевская	3	27	274	43.675567999999998	43.682870999999999	60.611769000000002	60.609459000000001	0103000020E61000000100000005000000B01C210379D645405EA0A4C0024E4E40B01C210379D6454073DA53724E4E4E408331225168D7454073DA53724E4E4E408331225168D745405EA0A4C0024E4E40B01C210379D645405EA0A4C0024E4E40
2787	Вощар	3	27	274	43.363959999999999	43.385348999999998	60.697040999999999	60.683615000000003	0103000020E61000000100000005000000AD86C43D96AE45400C0742B280574E40AD86C43D96AE45404E7CB5A338594E40ED45B41D53B145404E7CB5A338594E40ED45B41D53B145400C0742B280574E40AD86C43D96AE45400C0742B280574E40
53262	Верховский Погост	3	27	274	42.605693000000002	44.487870000000001	61.062302000000003	60.164693999999997	0103000020E6100000010000000500000044352559874D454078EC67B114154E4044352559874D4540DA3C0E83F9874E408A592F86723E4640DA3C0E83F9874E408A592F86723E464078EC67B114154E4044352559874D454078EC67B114154E40
53254	Верхнекокшенгский Погост	3	27	274	43.805267000000001	43.817753000000003	60.686739000000003	60.682125999999997	0103000020E6100000010000000500000026C632FD12E745402AE09EE74F574E4026C632FD12E74540A2F14410E7574E405B9A5B21ACE84540A2F14410E7574E405B9A5B21ACE845402AE09EE74F574E4026C632FD12E745402AE09EE74F574E40
17386	Афанасьевская	3	27	274	43.479591999999997	43.683706999999998	60.618616000000003	60.574074000000003	0103000020E610000001000000050000002CB6494563BD4540F1BDBF417B494E402CB6494563BD4540246420CF2E4F4E40EC8502B683D74540246420CF2E4F4E40EC8502B683D74540F1BDBF417B494E402CB6494563BD4540F1BDBF417B494E40
17080	Шокша	3	27	259	40.884717999999999	40.898300999999996	60.032259000000003	60.026491	0103000020E610000001000000050000005D177E703E714440B5519D0E64034E405D177E703E71444037001B1021044E40677BF486FB72444037001B1021044E40677BF486FB724440B5519D0E64034E405D177E703E714440B5519D0E64034E40
16853	Ширега	3	27	259	41.260618000000001	41.269511000000001	60.176501000000002	60.164653999999999	0103000020E61000000100000005000000DD5F3DEE5BA14440EA93DC6113154E40DD5F3DEE5BA144400C5BB39597164E40C57421567FA244400C5BB39597164E40C57421567FA24440EA93DC6113154E40DD5F3DEE5BA14440EA93DC6113154E40
16369	Филинская	3	27	259	40.940610999999997	40.966213000000003	59.889367	59.881104999999998	0103000020E6100000010000000500000001A1F5F065784440C9AB730CC8F04D4001A1F5F065784440219221C7D6F14D402BFC19DEAC7B4440219221C7D6F14D402BFC19DEAC7B4440C9AB730CC8F04D4001A1F5F065784440C9AB730CC8F04D40
17145	Усть-Река	3	27	259	40.758343000000004	40.780765000000002	60.037165999999999	60.032263	0103000020E61000000100000005000000451328621161444078EFA83121044E404513286211614440F64201DBC1044E40446E861BF0634440F64201DBC1044E40446E861BF063444078EFA83121044E40451328621161444078EFA83121044E40
2701	Сямжа	3	27	259	41.046773999999999	41.108829999999998	60.024912999999998	60.004567999999999	0103000020E61000000100000005000000CC26C0B0FC854440D74D29AF95004E40CC26C0B0FC854440641F645930034E406E693524EE8D4440641F645930034E406E693524EE8D4440D74D29AF95004E40CC26C0B0FC854440D74D29AF95004E40
16442	Согорки	3	27	259	41.289651999999997	41.315586000000003	59.802208999999998	59.791978999999998	0103000020E61000000100000005000000499C155113A54440340F60915FE54D40499C155113A5444047C7D5C8AEE64D40A9893E1F65A8444047C7D5C8AEE64D40A9893E1F65A84440340F60915FE54D40499C155113A54440340F60915FE54D40
2583	Самсоновская	3	27	259	41.640731000000002	41.651915000000002	60.250725000000003	60.244866999999999	0103000020E610000001000000050000004644317903D24440506F46CD571F4E404644317903D2444012A5BDC117204E40CC6262F371D3444012A5BDC117204E40CC6262F371D34440506F46CD571F4E404644317903D24440506F46CD571F4E40
16787	Раменье	3	27	259	41.088284999999999	41.100323000000003	60.248435000000001	60.240758	0103000020E610000001000000050000001ADD41EC4C8B44400C207C28D11E4E401ADD41EC4C8B44404417D4B7CC1F4E40B0045262D78C44404417D4B7CC1F4E40B0045262D78C44400C207C28D11E4E401ADD41EC4C8B44400C207C28D11E4E40
16698	Пигилинская	3	27	259	41.086156000000003	41.103484999999999	60.148355000000002	60.142921000000001	0103000020E61000000100000005000000562DE928078B4440B0743E3C4B124E40562DE928078B44405B99F04BFD124E40335019FF3E8D44405B99F04BFD124E40335019FF3E8D4440B0743E3C4B124E40562DE928078B4440B0743E3C4B124E40
16622	Ногинская	3	27	259	41.052703000000001	41.078709000000003	60.008395999999998	60.000478999999999	0103000020E6100000010000000500000057B3CEF8BE864440DAAA24B20F004E4057B3CEF8BE86444067B5C01E13014E405073F222138A444067B5C01E13014E405073F222138A4440DAAA24B20F004E4057B3CEF8BE864440DAAA24B20F004E40
16280	Мирный	3	27	259	41.711995000000002	41.729979	60.183217999999997	60.176873000000001	0103000020E6100000010000000500000030F5F3A622DB4440D04543C6A3164E4030F5F3A622DB4440EE04FBAF73174E4026E2ADF36FDD4440EE04FBAF73174E4026E2ADF36FDD4440D04543C6A3164E4030F5F3A622DB4440D04543C6A3164E40
16580	Коростелево	3	27	259	41.460619000000001	41.474030999999997	60.035153000000001	60.031126	0103000020E6100000010000000500000047753A90F5BA44401407D0EFFB034E4047753A90F5BA44409BADBCE47F044E4024253D0CADBC44409BADBCE47F044E4024253D0CADBC44401407D0EFFB034E4047753A90F5BA44401407D0EFFB034E40
16902	Копылово	3	27	259	41.616332999999997	41.626852	60.149442999999998	60.144461999999997	0103000020E610000001000000050000000839EFFFE3CE4440E3C116BB7D124E400839EFFFE3CE4440DDCEBEF220134E4052B7B3AF3CD04440DDCEBEF220134E4052B7B3AF3CD04440E3C116BB7D124E400839EFFFE3CE4440E3C116BB7D124E40
17170	Истоминская	3	27	259	40.794697999999997	40.804417999999998	60.095483999999999	60.085800999999996	0103000020E610000001000000050000002A1900AAB8654440677BF486FB0A4E402A1900AAB865444048A5D8D1380C4E402828452BF766444048A5D8D1380C4E402828452BF7664440677BF486FB0A4E402A1900AAB8654440677BF486FB0A4E40
16355	Житьево	3	27	259	41.091527999999997	41.116160000000001	59.912129	59.899762000000003	0103000020E610000001000000050000008A558330B78B44407F17B6662BF34D408A558330B78B4440D95DA0A4C0F44D403B8DB454DE8E4440D95DA0A4C0F44D403B8DB454DE8E44407F17B6662BF34D408A558330B78B44407F17B6662BF34D40
16764	Гремячий	3	27	259	41.113393000000002	41.135581999999999	60.219214999999998	60.207579000000003	0103000020E61000000100000005000000344C6DA9838E44400F2BDCF2911A4E40344C6DA9838E444075E5B33C0F1C4E4090F63FC05A91444075E5B33C0F1C4E4090F63FC05A9144400F2BDCF2911A4E40344C6DA9838E44400F2BDCF2911A4E40
16501	Голузино	3	27	259	41.544207	41.565038999999999	59.899054	59.893687	0103000020E610000001000000050000008CA03193A8C5444020EEEA5564F24D408CA03193A8C5444043AB933314F34D4076FBAC3253C8444043AB933314F34D4076FBAC3253C8444020EEEA5564F24D408CA03193A8C5444020EEEA5564F24D40
16527	Георгиевская	3	27	259	41.577722999999999	41.590668000000001	60.016285000000003	60.011158000000002	0103000020E61000000100000005000000D192C7D3F2C944405D8B16A06D014E40D192C7D3F2C944402B357BA015024E4099654F029BCB44402B357BA015024E4099654F029BCB44405D8B16A06D014E40D192C7D3F2C944405D8B16A06D014E40
53258	Щера	3	27	450	39.859434999999998	39.873961000000001	59.516267999999997	59.509830999999998	0103000020E61000000100000005000000D50451F701EE434055BE672442C14D40D50451F701EE434054FCDF1115C24D405F7D3CF4DDEF434054FCDF1115C24D405F7D3CF4DDEF434055BE672442C14D40D50451F701EE434055BE672442C14D40
2554	Чучково	3	27	450	41.234513	41.252398999999997	59.604125000000003	59.594602999999999	0103000020E6100000010000000500000051BEA085049E44403F8D7BF31BCC4D4051BEA085049E444017D9CEF753CD4D408445459C4EA0444017D9CEF753CD4D408445459C4EA044403F8D7BF31BCC4D4051BEA085049E44403F8D7BF31BCC4D40
15953	Чекшино	3	27	450	40.548838000000003	40.572248000000002	59.665053	59.652903000000002	0103000020E61000000100000005000000AA66D65240464440EB3A545392D34D40AA66D65240464440A88DEA7420D54D40C899266C3F494440A88DEA7420D54D40C899266C3F494440EB3A545392D34D40AA66D65240464440EB3A545392D34D40
14256	Сокол	3	27	450	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
15792	Оларево	3	27	450	40.052239999999998	40.081651000000001	59.371721999999998	59.356983999999997	0103000020E6100000010000000500000082C5E1CCAF064440FE98D6A6B1AD4D4082C5E1CCAF064440139A249694AF4D40C5573B8A730A4440139A249694AF4D40C5573B8A730A4440FE98D6A6B1AD4D4082C5E1CCAF064440FE98D6A6B1AD4D40
16040	Огарово	3	27	450	41.143729	41.169860999999997	59.620429999999999	59.611682000000002	0103000020E610000001000000050000004F3E3DB665924440A4C684984BCE4D404F3E3DB66592444088BA0F406ACF4D40D4EE5701BE95444088BA0F406ACF4D40D4EE5701BE954440A4C684984BCE4D404F3E3DB665924440A4C684984BCE4D40
15659	Обросово	3	27	450	39.975821000000003	40.003129000000001	59.478563000000001	59.469901	0103000020E6100000010000000500000001E0D8B3E7FC4340C9AD49B725BC4D4001E0D8B3E7FC4340AF09698D41BD4D40A855F48766004440AF09698D41BD4D40A855F48766004440C9AD49B725BC4D4001E0D8B3E7FC4340C9AD49B725BC4D40
15526	Нестерово	3	27	450	39.989789000000002	40.003875000000001	59.684804	59.676718000000001	0103000020E610000001000000050000006478EC67B1FE4340A94E07B29ED64D406478EC67B1FE4340C21550A8A7D74D40D122DBF97E004440C21550A8A7D74D40D122DBF97E004440A94E07B29ED64D406478EC67B1FE4340A94E07B29ED64D40
15612	Морженга	3	27	450	40.178463000000001	40.200094	59.627564999999997	59.611054000000003	0103000020E61000000100000005000000E54526E0D7164440850B790437CE4D40E54526E0D71644409F8EC70C54D04D401B1021AE9C1944409F8EC70C54D04D401B1021AE9C194440850B790437CE4D40E54526E0D7164440850B790437CE4D40
15824	Марковское	3	27	450	40.446995999999999	40.472363999999999	59.436605999999998	59.427036000000001	0103000020E61000000100000005000000AEB8382A373944407A1B9B1DA9B64D40AEB8382A37394440629E95B4E2B74D4064E76D6C763C4440629E95B4E2B74D4064E76D6C763C44407A1B9B1DA9B64D40AEB8382A373944407A1B9B1DA9B64D40
15754	Литега	3	27	450	40.209428000000003	40.226486999999999	59.428716000000001	59.417231000000001	0103000020E61000000100000005000000F06E6589CE1A44404EF04DD367B54D40F06E6589CE1A4440CFA2772AE0B64D400DFCA886FD1C4440CFA2772AE0B64D400DFCA886FD1C44404EF04DD367B54D40F06E6589CE1A44404EF04DD367B54D40
15253	Кадников	3	27	450	40.324044000000001	40.363182999999999	59.515276999999998	59.491928000000001	0103000020E61000000100000005000000863B17467A2944404CFE277FF7BE4D40863B17467A294440C4B0C398F4C14D4049BBD1C77C2E4440C4B0C398F4C14D4049BBD1C77C2E44404CFE277FF7BE4D40863B17467A2944404CFE277FF7BE4D40
15887	Замошье	3	27	450	40.545119	40.561073	59.496678000000003	59.491809000000003	0103000020E61000000100000005000000D0B69A75C64544407270E998F3BE4D40D0B69A75C645444044520B2593BF4D4095D5743DD147444044520B2593BF4D4095D5743DD14744407270E998F3BE4D40D0B69A75C64544407270E998F3BE4D40
15960	Воробьево	3	27	450	40.878062	40.904651999999999	59.631382000000002	59.623387999999998	0103000020E6100000010000000500000020EEEA5564704440035C902DCBCF4D4020EEEA55647044403CA41820D1D04D40682101A3CB7344403CA41820D1D04D40682101A3CB734440035C902DCBCF4D4020EEEA5564704440035C902DCBCF4D40
15554	Великий Двор	3	27	450	40.055591	40.068292999999997	59.641343999999997	59.632688000000002	0103000020E61000000100000005000000D9791B9B1D0744402C499EEBFBD04D40D9791B9B1D0744402FBE688F17D24D40DAC534D3BD0844402FBE688F17D24D40DAC534D3BD0844402C499EEBFBD04D40D9791B9B1D0744402C499EEBFBD04D40
15472	Василево	3	27	450	39.945079999999997	39.957495000000002	59.606319999999997	59.600205000000003	0103000020E61000000100000005000000450DA661F8F84340A6F27684D3CC4D40450DA661F8F843409274CDE49BCD4D40B18A37328FFA43409274CDE49BCD4D40B18A37328FFA4340A6F27684D3CC4D40450DA661F8F84340A6F27684D3CC4D40
16117	Биряково	3	27	450	41.462657999999998	41.515039000000002	59.594161	59.577984999999998	0103000020E61000000100000005000000CB9D996038BB44400E4A9869FBC94D40CB9D996038BB444082C7B7770DCC4D40109546CCECC1444082C7B7770DCC4D40109546CCECC144400E4A9869FBC94D40CB9D996038BB44400E4A9869FBC94D40
15399	Архангельское	3	27	450	39.950344000000001	39.963109000000003	59.552785999999998	59.533419000000002	0103000020E6100000010000000500000094F947DFA4F943405308E41247C44D4094F947DFA4F94340E4D70FB1C1C64D40DCBDDC2747FB4340E4D70FB1C1C64D40DCBDDC2747FB43405308E41247C44D4094F947DFA4F943405308E41247C44D40
13496	Юшково	3	27	298	44.350921999999997	44.370711	60.210749	60.200384999999997	0103000020E6100000010000000500000034B91803EB2C4640F2CD3637A6194E4034B91803EB2C46401555BFD2F91A4E403CA24275732F46401555BFD2F91A4E403CA24275732F4640F2CD3637A6194E4034B91803EB2C4640F2CD3637A6194E40
53279	Пустыня	3	27	298	43.941757000000003	43.952671000000002	60.24145	60.231391000000002	0103000020E61000000100000005000000B9E34D7E8BF845405CCB64389E1D4E40B9E34D7E8BF8454042CF66D5E71E4E407F6C921FF1F9454042CF66D5E71E4E407F6C921FF1F945405CCB64389E1D4E40B9E34D7E8BF845405CCB64389E1D4E40
13585	Пески	3	27	298	43.754978999999999	43.771220999999997	60.178725	60.172643999999998	0103000020E610000001000000050000005915E126A3E04540E1ECD63219164E405915E126A3E0454022FDF675E0164E40847EA65EB7E2454022FDF675E0164E40847EA65EB7E24540E1ECD63219164E405915E126A3E04540E1ECD63219164E40
13840	Озерки	3	27	298	44.567307999999997	44.592748	60.475881000000001	60.467398000000003	0103000020E610000001000000050000002C616D8C9D484640A01B9AB2D33B4E402C616D8C9D484640D6E429ABE93C4E407C629D2ADF4B4640D6E429ABE93C4E407C629D2ADF4B4640A01B9AB2D33B4E402C616D8C9D484640A01B9AB2D33B4E40
2447	Нюксеница	3	27	298	44.203660999999997	44.267296999999999	60.428913000000001	60.406075999999999	0103000020E610000001000000050000003E3C4B90111A464062D8614CFA334E403E3C4B90111A464025EA059FE6364E40D2A8C0C93622464025EA059FE6364E40D2A8C0C93622464062D8614CFA334E403E3C4B90111A464062D8614CFA334E40
13568	Матвеевская	3	27	298	44.408377999999999	44.428617000000003	60.233111000000001	60.228513999999997	0103000020E61000000100000005000000F433F5BA45344640CD565EF23F1D4E40F433F5BA453446403FABCC94D61D4E403CC1FEEBDC3646403FABCC94D61D4E403CC1FEEBDC364640CD565EF23F1D4E40F433F5BA45344640CD565EF23F1D4E40
13751	Матвеево	3	27	298	44.611944999999999	44.636324999999999	60.476196000000002	60.470781000000002	0103000020E61000000100000005000000B1F9B836544E4640024A438D423C4E40B1F9B836544E4640363E93FDF33C4E404850FC1873514640363E93FDF33C4E404850FC1873514640024A438D423C4E40B1F9B836544E4640024A438D423C4E40
14242	Лесютино	3	27	298	44.116883000000001	44.139530000000001	60.496169000000002	60.485647999999998	0103000020E61000000100000005000000AC3AAB05F60E464014AFB2B6293E4E40AC3AAB05F60E4640FF243E77823F4E40CB67791EDC114640FF243E77823F4E40CB67791EDC11464014AFB2B6293E4E40AC3AAB05F60E464014AFB2B6293E4E40
13287	Леваш	3	27	298	44.875376000000003	44.893621000000003	60.525888999999999	60.516556000000001	0103000020E6100000010000000500000006DA1D520C704640BB46CB811E424E4006DA1D520C704640BF29AC5450434E406902452C62724640BF29AC5450434E406902452C62724640BB46CB811E424E4006DA1D520C704640BB46CB811E424E40
13775	Красавино	3	27	298	44.472831999999997	44.485570000000003	60.468803000000001	60.465366000000003	0103000020E610000001000000050000004A404CC2853C4640CE55F31C913B4E404A404CC2853C464023A298BC013C4E4099F56228273E464023A298BC013C4E4099F56228273E4640CE55F31C913B4E404A404CC2853C4640CE55F31C913B4E40
13209	Копылово	3	27	298	45.067517000000002	45.093074000000001	60.585189999999997	60.578552000000002	0103000020E610000001000000050000004776A565A48846408884EFFD0D4A4E404776A565A48846401EF98381E74A4E40D00D4DD9E98B46401EF98381E74A4E40D00D4DD9E98B46408884EFFD0D4A4E404776A565A48846408884EFFD0D4A4E40
13659	Игмас	3	27	298	43.760288000000003	43.792304000000001	60.176093999999999	60.161990000000003	0103000020E6100000010000000500000048C5FF1D51E14540B8239C16BC144E4048C5FF1D51E14540CB82893F8A164E40B83EAC376AE54540CB82893F8A164E40B83EAC376AE54540B8239C16BC144E4048C5FF1D51E14540B8239C16BC144E40
2359	Городищна	3	27	298	44.351038000000003	44.375534999999999	60.238100000000003	60.225855000000003	0103000020E610000001000000050000009ED32CD0EE2C4640AD510FD1E81C4E409ED32CD0EE2C4640BC96900F7A1E4E406EC0E78711304640BC96900F7A1E4E406EC0E78711304640AD510FD1E81C4E409ED32CD0EE2C4640AD510FD1E81C4E40
13197	Вострое	3	27	298	44.920183999999999	44.935122999999997	60.541739	60.534557	0103000020E61000000100000005000000B726DD96C8754640876C205D6C444E40B726DD96C8754640DFFB1BB457454E40635E471CB2774640DFFB1BB457454E40635E471CB2774640876C205D6C444E40B726DD96C8754640876C205D6C444E40
2293	Брусноволовский Погост	3	27	298	44.084139999999998	44.095773000000001	60.223987000000001	60.217883	0103000020E6100000010000000500000089247A19C50A46405CAD1397E31B4E4089247A19C50A464055DD239BAB1C4E407F6B274A420C464055DD239BAB1C4E407F6B274A420C46405CAD1397E31B4E4089247A19C50A46405CAD1397E31B4E40
13680	Бобровское	3	27	298	44.764918999999999	44.780603999999997	60.483626000000001	60.476993999999998	0103000020E61000000100000005000000658BA4DDE8614640B131AF230E3D4E40658BA4DDE861464066BFEE74E73D4E403A90F5D4EA63464066BFEE74E73D4E403A90F5D4EA634640B131AF230E3D4E40658BA4DDE8614640B131AF230E3D4E40
14131	Березово	3	27	298	44.271340000000002	44.289485999999997	60.424165000000002	60.415393000000002	0103000020E610000001000000050000005F0CE544BB22464061FE0A992B354E405F0CE544BB224640CE8DE9094B364E402E5393E00D254640CE8DE9094B364E402E5393E00D25464061FE0A992B354E405F0CE544BB22464061FE0A992B354E40
14160	Березовая Слободка	3	27	298	44.154944999999998	44.170287999999999	60.397730000000003	60.387101000000001	0103000020E61000000100000005000000E0D6DD3CD5134640DC9F8B868C314E40E0D6DD3CD5134640AD510FD1E8324E405C7347FFCB154640AD510FD1E8324E405C7347FFCB154640DC9F8B868C314E40E0D6DD3CD5134640DC9F8B868C314E40
12537	Шарженга	3	27	413	44.892049	44.911740000000002	59.945982000000001	59.939405999999998	0103000020E61000000100000005000000FAB660A92E72464045D5AF743EF84D40FAB660A92E724640664D2CF015F94D403F3A75E5B3744640664D2CF015F94D403F3A75E5B374464045D5AF743EF84D40FAB660A92E72464045D5AF743EF84D40
53256	Филинский починок	3	27	413	44.191938	46.407677	60.040199999999999	59.122686000000002	0103000020E61000000100000005000000096EA46C91184640AAD6C22CB48F4D40096EA46C911846404CA60A4625054E406B2A8BC22E3447404CA60A4625054E406B2A8BC22E344740AAD6C22CB48F4D40096EA46C91184640AAD6C22CB48F4D40
12083	Старина	3	27	413	44.682678000000003	44.698453000000001	59.600969999999997	59.595013000000002	0103000020E610000001000000050000006FD921FE61574640F1D8CF6229CC4D406FD921FE6157464045F0BF95ECCC4D4084656CE86659464045F0BF95ECCC4D4084656CE866594640F1D8CF6229CC4D406FD921FE61574640F1D8CF6229CC4D40
12850	Скочково	3	27	413	45.425395999999999	45.451087999999999	59.385097999999999	59.373066000000001	0103000020E61000000100000005000000B3EC496073B64640F19F6EA0C0AF4D40B3EC496073B64640A4E029E44AB14D401CCF6740BDB94640A4E029E44AB14D401CCF6740BDB94640F19F6EA0C0AF4D40B3EC496073B64640F19F6EA0C0AF4D40
12308	Рокуново	3	27	413	44.889128999999997	44.907741999999999	59.853296999999998	59.842671000000003	0103000020E610000001000000050000006C76A4FACE714640D124B1A4DCEB4D406C76A4FACE71464030630AD638ED4D40529ACDE33074464030630AD638ED4D40529ACDE330744640D124B1A4DCEB4D406C76A4FACE714640D124B1A4DCEB4D40
12739	Путилово	3	27	413	44.684556000000001	44.699736999999999	59.427864999999997	59.421661999999998	0103000020E61000000100000005000000EA23F0879F574640A4FB3905F9B54D40EA23F0879F574640300DC347C4B64D408C6665FB90594640300DC347C4B64D408C6665FB90594640A4FB3905F9B54D40EA23F0879F574640A4FB3905F9B54D40
11979	Половина	3	27	413	44.919043000000002	44.937215999999999	59.786527	59.777397000000001	0103000020E61000000100000005000000124F7633A37546401781B1BE81E34D40124F7633A3754640E335AFEAACE44D40DBA4A2B1F6774640E335AFEAACE44D40DBA4A2B1F67746401781B1BE81E34D40124F7633A37546401781B1BE81E34D40
13006	Полежаево	3	27	413	44.935105	44.953332000000003	59.516295	59.507382999999997	0103000020E61000000100000005000000BDA94885B1774640EFC517EDF1C04D40BDA94885B17746404E0B5EF415C24D407A1D71C8067A46404E0B5EF415C24D407A1D71C8067A4640EFC517EDF1C04D40BDA94885B1774640EFC517EDF1C04D40
12863	Пермас	3	27	413	45.587910999999998	45.610323999999999	59.340541999999999	59.323435000000003	0103000020E61000000100000005000000B5FAEAAA40CB4640DEB06D5166A94D40B5FAEAAA40CB46400C7558E196AB4D4061FBC9181FCE46400C7558E196AB4D4061FBC9181FCE4640DEB06D5166A94D40B5FAEAAA40CB4640DEB06D5166A94D40
12786	Осиново	3	27	413	45.411428000000001	45.429780000000001	59.474668999999999	59.466408999999999	0103000020E61000000100000005000000505436ACA9B44640B0C7444AB3BB4D40505436ACA9B4464067B62BF4C1BC4D40C93CF20703B7464067B62BF4C1BC4D40C93CF20703B74640B0C7444AB3BB4D40505436ACA9B44640B0C7444AB3BB4D40
12718	Никольское	3	27	413	44.575958	44.596260000000001	59.387407000000003	59.37914	0103000020E610000001000000050000004EEFE2FDB84946407F4DD6A887B04D404EEFE2FDB8494640E99E758D96B14D40DCF4673F524C4640E99E758D96B14D40DCF4673F524C46407F4DD6A887B04D404EEFE2FDB84946407F4DD6A887B04D40
53252	Никольск	3	27	413	45.429645000000001	45.492213	59.557451	59.498026000000003	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
12623	Нигино	3	27	413	45.261265000000002	45.290334999999999	59.659253999999997	59.645232	0103000020E61000000100000005000000734BAB2171A14640952A51F696D24D40734BAB2171A14640EBE0606F62D44D402CF180B229A54640EBE0606F62D44D402CF180B229A54640952A51F696D24D40734BAB2171A14640952A51F696D24D40
13024	Молодежный	3	27	413	45.113250000000001	45.137521999999997	59.551153999999997	59.534993	0103000020E61000000100000005000000D122DBF97E8E4640624B8FA67AC44D40D122DBF97E8E4640A087DA368CC64D40813D26529A914640A087DA368CC64D40813D26529A914640624B8FA67AC44D40D122DBF97E8E4640624B8FA67AC44D40
2253	Милофаново	3	27	413	44.911479	44.931762999999997	59.904266	59.895347999999998	0103000020E61000000100000005000000D2FE0758AB744640FE4465C39AF24D40D2FE0758AB7446403F7100FDBEF34D40B94F8E02447746403F7100FDBEF34D40B94F8E0244774640FE4465C39AF24D40D2FE0758AB744640FE4465C39AF24D40
53272	Куданский	3	27	413	45.376196	45.402723000000002	59.298909000000002	59.292383999999998	0103000020E610000001000000050000006971C63027B04640D4EFC2D66CA54D406971C63027B0464073BD6DA642A64D406B2C616D8CB3464073BD6DA642A64D406B2C616D8CB34640D4EFC2D66CA54D406971C63027B04640D4EFC2D66CA54D40
11820	Кривяцкое	3	27	413	45.642313000000001	45.658203999999998	59.596679999999999	59.578718000000002	0103000020E61000000100000005000000D865F84F37D24640A3CD716E13CA4D40D865F84F37D24640B1169F0260CC4D40560C570740D44640B1169F0260CC4D40560C570740D44640A3CD716E13CA4D40D865F84F37D24640A3CD716E13CA4D40
11920	Котельное	3	27	413	45.045211000000002	45.061588	59.765134000000003	59.755164000000001	0103000020E61000000100000005000000B1355B79C9854640EB8EC536A9E04D40B1355B79C9854640628731E9EFE14D40BCE9961DE2874640628731E9EFE14D40BCE9961DE2874640EB8EC536A9E04D40B1355B79C9854640EB8EC536A9E04D40
12359	Кожаево	3	27	413	45.497163	45.521839999999997	59.481876	59.471820999999998	0103000020E6100000010000000500000000E48409A3BF464073486AA164BC4D4000E48409A3BF4640185DDE1CAEBD4D4050DF32A7CBC24640185DDE1CAEBD4D4050DF32A7CBC2464073486AA164BC4D4000E48409A3BF464073486AA164BC4D40
53271	Кипшеньга	3	27	413	45.117966000000003	45.456612999999997	59.740017000000002	59.399517000000003	0103000020E610000001000000050000001D058882198F46401899805F23B34D401D058882198F4640F5BD86E0B8DE4D40D7F6764B72BA4640F5BD86E0B8DE4D40D7F6764B72BA46401899805F23B34D401D058882198F46401899805F23B34D40
13121	Калинино	3	27	413	45.327759	45.356585000000003	59.763271000000003	59.756990000000002	0103000020E610000001000000050000001EFCC401F4A9464014B35E0CE5E04D401EFCC401F4A946401C7E37DDB2E14D40419FC893A4AD46401C7E37DDB2E14D40419FC893A4AD464014B35E0CE5E04D401EFCC401F4A9464014B35E0CE5E04D40
11689	Ильинское	3	27	413	45.082779000000002	45.103431	59.838168000000003	59.830047	0103000020E61000000100000005000000D6E59480988A46404B92E7FA3EEA4D40D6E59480988A4640E146CA1649EB4D4040321D3A3D8D4640E146CA1649EB4D4040321D3A3D8D46404B92E7FA3EEA4D40D6E59480988A46404B92E7FA3EEA4D40
12271	Зеленцово	3	27	413	44.957329000000001	44.990181	59.880288	59.870890000000003	0103000020E610000001000000050000009641B5C1897A4640EC34D25279EF4D409641B5C1897A4640D787F546ADF04D406F0F4240BE7E4640D787F546ADF04D406F0F4240BE7E4640EC34D25279EF4D409641B5C1897A4640EC34D25279EF4D40
11787	Займище	3	27	413	45.677931000000001	45.709192000000002	59.642744999999998	59.628847999999998	0103000020E61000000100000005000000E8F86871C6D64640D7135D177ED04D40E8F86871C6D646407155D97745D24D40DC4AAFCDC6DA46407155D97745D24D40DC4AAFCDC6DA4640D7135D177ED04D40E8F86871C6D64640D7135D177ED04D40
12123	Завражье	3	27	413	45.856723000000002	45.875048	59.446185999999997	59.438093000000002	0103000020E61000000100000005000000925D6919A9ED4640A3CD716E13B84D40925D6919A9ED46406EF7729F1CB94D401137A79201F046406EF7729F1CB94D401137A79201F04640A3CD716E13B84D40925D6919A9ED4640A3CD716E13B84D40
12242	Дуниловский	3	27	413	45.849311	45.869262999999997	59.338797999999997	59.322797000000001	0103000020E6100000010000000500000008910C39B6EC46409B1F7F6951A94D4008910C39B6EC4640A0F99CBB5DAB4D40B94F8E0244EF4640A0F99CBB5DAB4D40B94F8E0244EF46409B1F7F6951A94D4008910C39B6EC46409B1F7F6951A94D40
12181	Высокинский	3	27	413	46.049672000000001	46.069730999999997	59.484895999999999	59.472900000000003	0103000020E6100000010000000500000072C3EFA65B064740A323B9FC87BC4D4072C3EFA65B06474009FB761211BE4D40394206F2EC08474009FB761211BE4D40394206F2EC084740A323B9FC87BC4D4072C3EFA65B064740A323B9FC87BC4D40
11858	Вахнево	3	27	413	45.169161000000003	45.194808000000002	59.787216000000001	59.781658999999998	0103000020E610000001000000050000001C615111A7954640E1CFF0660DE44D401C615111A7954640A8716F7EC3E44D40E57FF277EF984640A8716F7EC3E44D40E57FF277EF984640E1CFF0660DE44D401C615111A7954640E1CFF0660DE44D40
12449	Бутова Курья	3	27	413	45.193334999999998	45.222341	59.606150999999997	59.587999000000003	0103000020E6100000010000000500000009168733BF984640558A1D8D43CB4D4009168733BF98464006B8205B96CD4D40ACC77DAB759C464006B8205B96CD4D40ACC77DAB759C4640558A1D8D43CB4D4009168733BF984640558A1D8D43CB4D40
12023	Борок	3	27	413	44.748902000000001	44.783172999999998	59.506548000000002	59.496423	0103000020E610000001000000050000005AF44E05DC5F4640B9FDF2C98ABF4D405AF44E05DC5F464057ED9A90D6C04D401B0E4B033F64464057ED9A90D6C04D401B0E4B033F644640B9FDF2C98ABF4D405AF44E05DC5F4640B9FDF2C98ABF4D40
12942	Большое Сверчково	3	27	413	45.814942000000002	45.830706999999997	59.263665000000003	59.253098999999999	0103000020E610000001000000050000008411FB0450E846403DD34B8C65A04D408411FB0450E84640C80C54C6BFA14D4075C7629B54EA4640C80C54C6BFA14D4075C7629B54EA46403DD34B8C65A04D408411FB0450E846403DD34B8C65A04D40
11739	Байдарово	3	27	413	45.539707	45.559927999999999	59.655284999999999	59.643076999999998	0103000020E610000001000000050000000D36751E15C54640A7E7DD5850D24D400D36751E15C546409947FE60E0D34D40AE0E80B8ABC746409947FE60E0D34D40AE0E80B8ABC74640A7E7DD5850D24D400D36751E15C54640A7E7DD5850D24D40
11651	Аргуново	3	27	413	45.098832000000002	45.117068000000003	59.862045000000002	59.853808000000001	0103000020E610000001000000050000002EE6E786A68C464016889E9449ED4D402EE6E786A68C46401557957D57EE4D403EB48F15FC8E46401557957D57EE4D403EB48F15FC8E464016889E9449ED4D402EE6E786A68C464016889E9449ED4D40
12416	Абатурово	3	27	413	45.488314000000003	45.503523000000001	59.547939	59.540498999999997	0103000020E61000000100000005000000E816BA1281BE4640A6423C122FC54D40E816BA1281BE4640FA997ADD22C64D4054E4107173C04640FA997ADD22C64D4054E4107173C04640A6423C122FC54D40E816BA1281BE4640A6423C122FC54D40
9335	Шуйское	3	27	213	40.993226	41.045346000000002	59.384520000000002	59.36374	0103000020E61000000100000005000000B9C49107227F44409F1F46088FAE4D40B9C49107227F444037548CF337B14D409180D1E5CD85444037548CF337B14D409180D1E5CD8544409F1F46088FAE4D40B9C49107227F44409F1F46088FAE4D40
2012	Шиченга	3	27	213	41.133462000000002	41.188249999999996	59.40025	59.388668000000003	0103000020E610000001000000050000001FA166481591444039807EDFBFB14D401FA1664815914440AC1C5A643BB34D406ABC749318984440AC1C5A643BB34D406ABC74931898444039807EDFBFB14D401FA166481591444039807EDFBFB14D40
11264	Шейбухта	3	27	213	40.912692	40.926974999999999	59.262340000000002	59.247449000000003	0103000020E6100000010000000500000011A96917D3744440C636A968AC9F4D4011A96917D374444061376C5B94A14D40D49AE61DA776444061376C5B94A14D40D49AE61DA7764440C636A968AC9F4D4011A96917D3744440C636A968AC9F4D40
11190	Туровец	3	27	213	41.918185000000001	41.949249000000002	59.586942000000001	59.564002000000002	0103000020E61000000100000005000000C156091687F544407670B03731C84D40C156091687F544400D535BEA20CB4D405F61C1FD80F944400D535BEA20CB4D405F61C1FD80F944407670B03731C84D40C156091687F544407670B03731C84D40
11089	Старое	3	27	213	40.641534999999998	40.680621000000002	59.276186000000003	59.263903999999997	0103000020E61000000100000005000000A31EA2D11D5244404CA4349BC7A14D40A31EA2D11D52444079CE16105AA34D4044FCC3961E57444079CE16105AA34D4044FCC3961E5744404CA4349BC7A14D40A31EA2D11D5244404CA4349BC7A14D40
11027	Спас-Ямщики	3	27	213	40.704157000000002	40.720999999999997	59.28396	59.276516999999998	0103000020E61000000100000005000000EF1F0BD1215A4440DEE4B7E864A34D40EF1F0BD1215A4440A3AF20CD58A44D403F355EBA495C4440A3AF20CD58A44D403F355EBA495C4440DEE4B7E864A34D40EF1F0BD1215A4440DEE4B7E864A34D40
809	Пионерский	3	27	213	40.898632999999997	40.908335000000001	59.310540000000003	59.304040999999998	0103000020E610000001000000050000009D0DF9670673444052D2C3D0EAA64D409D0DF96706734440C80C54C6BFA74D40F5673F5244744440C80C54C6BFA74D40F5673F524474444052D2C3D0EAA64D409D0DF9670673444052D2C3D0EAA64D40
10958	Игумницево	3	27	213	40.659914999999998	40.677387000000003	59.198855000000002	59.183230000000002	0103000020E61000000100000005000000E6913F1878544440B3D2A41474974D40E6913F1878544440B3D2A41474994D4027DE019EB4564440B3D2A41474994D4027DE019EB4564440B3D2A41474974D40E6913F1878544440B3D2A41474974D40
27207	Иваньково	3	27	213	41.005271999999998	41.010176999999999	59.148622000000003	59.145558000000001	0103000020E61000000100000005000000D1CABDC0AC804440E9D500A5A1924D40D1CABDC0AC804440AABBB20B06934D40F015DD7A4D814440AABBB20B06934D40F015DD7A4D814440E9D500A5A1924D40D1CABDC0AC804440E9D500A5A1924D40
2109	Гаврилково	3	27	213	40.889291	40.910482000000002	59.146813000000002	59.138182	0103000020E6100000010000000500000046D09849D4714440AC72A1F2AF914D4046D09849D471444057D0B4C4CA924D4060CC96AC8A74444057D0B4C4CA924D4060CC96AC8A744440AC72A1F2AF914D4046D09849D4714440AC72A1F2AF914D40
10971	Врагово	3	27	213	41.073957	41.094366999999998	59.306452	59.298237999999998	0103000020E61000000100000005000000B727486C778944405436ACA92CA64D40B727486C778944409BE5B2D139A74D402B69C537148C44409BE5B2D139A74D402B69C537148C44405436ACA92CA64D40B727486C778944405436ACA92CA64D40
10915	Югский	3	27	233	45.937112999999997	45.964376999999999	59.972982999999999	59.955561000000003	0103000020E6100000010000000500000006D49B51F3F74640A22AA6D24FFA4D4006D49B51F3F746403048FAB48AFC4D40DE019EB470FB46403048FAB48AFC4D40DE019EB470FB4640A22AA6D24FFA4D4006D49B51F3F74640A22AA6D24FFA4D40
10835	Шонга	3	27	233	45.666792000000001	45.682845	59.946527000000003	59.933433000000001	0103000020E61000000100000005000000029EB47059D54640EB0088BB7AF74D40029EB47059D54640F8E3F6CB27F94D405A9E077767D74640F8E3F6CB27F94D405A9E077767D74640EB0088BB7AF74D40029EB47059D54640EB0088BB7AF74D40
10830	Шатенево	3	27	233	45.455688000000002	45.474992	59.910387999999998	59.901665999999999	0103000020E61000000100000005000000FF9600FC53BA464023F59ECA69F34D40FF9600FC53BA4640DE550F9887F44D404AEEB089CCBC4640DE550F9887F44D404AEEB089CCBC464023F59ECA69F34D40FF9600FC53BA464023F59ECA69F34D40
9611	Торопово	3	27	233	45.773296000000002	45.780284999999999	60.000025000000001	59.995182999999997	0103000020E610000001000000050000005610035DFBE246408044132862FF4D405610035DFBE246405917B7D100004E409947FE60E0E346405917B7D100004E409947FE60E0E346408044132862FF4D405610035DFBE246408044132862FF4D40
53269	Слободка	3	27	233	46.213946999999997	46.223621000000001	59.974702999999998	59.970464999999997	0103000020E61000000100000005000000E509849D621B4740D174763238FC4D40E509849D621B474013286211C3FC4D4073D9E89C9F1C474013286211C3FC4D4073D9E89C9F1C4740D174763238FC4D40E509849D621B4740D174763238FC4D40
51281	Слобода	3	27	233	45.846428000000003	45.871194000000003	60.036572999999997	60.028263000000003	0103000020E610000001000000050000009835B1C057EC4640EB573A1F9E034E409835B1C057EC464053758F6CAE044E40583CF54883EF464053758F6CAE044E40583CF54883EF4640EB573A1F9E034E409835B1C057EC4640EB573A1F9E034E40
10637	Светица	3	27	233	45.059170999999999	45.067481000000001	60.217941000000003	60.211478	0103000020E6100000010000000500000091EF52EA9287464068E90AB6111B4E4091EF52EA9287464091BA9D7DE51B4E40FA0CA837A388464091BA9D7DE51B4E40FA0CA837A388464068E90AB6111B4E4091EF52EA9287464068E90AB6111B4E40
10563	Сараево	3	27	233	45.280166000000001	45.300288000000002	60.141663000000001	60.136541999999999	0103000020E61000000100000005000000BFB9BF7ADCA34640E54350357A114E40BFB9BF7ADCA34640D106600322124E40CDB051D66FA64640D106600322124E40CDB051D66FA64640E54350357A114E40BFB9BF7ADCA34640E54350357A114E40
9655	Подол	3	27	233	45.699022999999997	45.859256000000002	60.002795999999996	59.894593999999998	0103000020E610000001000000050000006E13EE9579D946405299620E82F24D406E13EE9579D94640A1478C9E5B004E402672C119FCED4640A1478C9E5B004E402672C119FCED46405299620E82F24D406E13EE9579D946405299620E82F24D40
10641	Подволочье	3	27	233	45.875155999999997	45.886906000000003	60.067070000000001	60.057357000000003	0103000020E61000000100000005000000F7729F1C05F046402D99637957074E40F7729F1C05F046407845F0BF95084E402750C42286F146407845F0BF95084E402750C42286F146402D99637957074E40F7729F1C05F046402D99637957074E40
9821	Олятово	3	27	233	46.466059000000001	46.480080999999998	60.086810999999997	60.078552999999999	0103000020E61000000100000005000000D48041D2A73B4740580053060E0A4E40D48041D2A73B47406EF7729F1C0B4E402A37514B733D47406EF7729F1C0B4E402A37514B733D4740580053060E0A4E40D48041D2A73B4740580053060E0A4E40
9973	Нижняя Ентала	3	27	233	46.631295000000001	46.641275	59.973815999999999	59.967357999999997	0103000020E610000001000000050000006D904946CE50474011C30E63D2FB4D406D904946CE5047402829B000A6FC4D40075F984C155247402829B000A6FC4D40075F984C1552474011C30E63D2FB4D406D904946CE50474011C30E63D2FB4D40
9907	Нижний Енангск	3	27	233	46.386215999999997	46.414442000000001	60.000267000000001	59.983913999999999	0103000020E610000001000000050000009198A0866F314740CC09DAE4F0FD4D409198A0866F3147404F22C2BF08004E405F0B7A6F0C3547404F22C2BF08004E405F0B7A6F0C354740CC09DAE4F0FD4D409198A0866F314740CC09DAE4F0FD4D40
10129	Лаптюг	3	27	233	45.962193999999997	45.981292000000003	60.174036000000001	60.164323000000003	0103000020E610000001000000050000002634492C29FB4640857D3B8908154E402634492C29FB4640D029C8CF46164E40C9E9EBF99AFD4640D029C8CF46164E40C9E9EBF99AFD4640857D3B8908154E402634492C29FB4640857D3B8908154E40
10287	Курилово	3	27	233	45.489671000000001	45.508552999999999	59.802543999999997	59.795678000000002	0103000020E610000001000000050000005A66118AADBE4640C712D6C6D8E54D405A66118AADBE4640EECC04C3B9E64D402FA4C34318C14640EECC04C3B9E64D402FA4C34318C14640C712D6C6D8E54D405A66118AADBE4640C712D6C6D8E54D40
1019	Косково	3	27	233	45.975507	46.017090000000003	59.896075000000003	59.886830000000003	0103000020E610000001000000050000007102D369DDFC46404C8E3BA583F14D407102D369DDFC4640B1E1E995B2F24D40598B4F0130024740B1E1E995B2F24D40598B4F01300247404C8E3BA583F14D407102D369DDFC46404C8E3BA583F14D40
27772	Коряковская	3	27	233	45.908304000000001	45.918266000000003	59.932712000000002	59.929118000000003	0103000020E61000000100000005000000BA69334E43F44640FE0FB056EDF64D40BA69334E43F446401B4B581B63F74D40AE8383BD89F546401B4B581B63F74D40AE8383BD89F54640FE0FB056EDF64D40BA69334E43F44640FE0FB056EDF64D40
10434	Кобыльск	3	27	233	46.112886000000003	46.125821999999999	60.005212	60.000267000000001	0103000020E610000001000000050000009016670C730E47404F22C2BF08004E409016670C730E4740FCC56CC9AA004E40048F6FEF1A104740FCC56CC9AA004E40048F6FEF1A1047404F22C2BF08004E409016670C730E47404F22C2BF08004E40
51315	Кичменьга	3	27	233	45.598492999999998	45.604528999999999	60.056840000000001	60.047317	0103000020E6100000010000000500000045F12A6B9BCC4640BDC5C37B0E064E4045F12A6B9BCC4640658D7A8846074E40E63DCE3461CD4640658D7A8846074E40E63DCE3461CD4640BDC5C37B0E064E4045F12A6B9BCC4640BDC5C37B0E064E40
53285	Кичменский Городок	3	27	233	45.751376999999998	45.816459999999999	60.010613999999997	59.962871999999997	0103000020E61000000100000005000000B9FB1C1F2DE04640F71DC3633FFB4D40B9FB1C1F2DE046409B70AFCC5B014E40FF3EE3C281E846409B70AFCC5B014E40FF3EE3C281E84640F71DC3633FFB4D40B9FB1C1F2DE04640F71DC3633FFB4D40
1954	Кильченга	3	27	233	46.322679000000001	46.343493000000002	60.073898	60.059202999999997	0103000020E61000000100000005000000910DA48B4D2947409C69C2F693074E40910DA48B4D294740B29E5A7D75094E40D5B32094F72B4740B29E5A7D75094E40D5B32094F72B47409C69C2F693074E40910DA48B4D2947409C69C2F693074E40
1880	Исады	3	27	233	45.346524000000002	45.354438999999999	60.090969999999999	60.089001000000003	0103000020E61000000100000005000000BAA3FFE55AAC4640D9278062640B4E40BAA3FFE55AAC46406475ABE7A40B4E40A6B6D4415EAD46406475ABE7A40B4E40A6B6D4415EAD4640D9278062640B4E40BAA3FFE55AAC4640D9278062640B4E40
10318	Еловино	3	27	233	45.815677999999998	45.841324999999998	59.807296000000001	59.796325000000003	0103000020E610000001000000050000008908FF2268E846405DFE43FAEDE54D408908FF2268E846408718AF7955E74D405227A089B0EB46408718AF7955E74D405227A089B0EB46405DFE43FAEDE54D408908FF2268E846405DFE43FAEDE54D40
10053	Дорожково	3	27	233	45.963290000000001	45.976055000000002	60.033638000000003	60.026235	0103000020E610000001000000050000002C4833164DFB46405A8121AB5B034E402C4833164DFB464091F3FE3F4E044E40740CC85EEFFC464091F3FE3F4E044E40740CC85EEFFC46405A8121AB5B034E402C4833164DFB46405A8121AB5B034E40
9777	Гаражи	3	27	233	45.484999999999999	45.512011999999999	60.112037999999998	60.100377999999999	0103000020E61000000100000005000000AE47E17A14BE4640739EB12FD90C4E40AE47E17A14BE464062F4DC42570E4E406C94F59B89C1464062F4DC42570E4E406C94F59B89C14640739EB12FD90C4E40AE47E17A14BE4640739EB12FD90C4E40
53286	Верняя Ентала	3	27	233	46.636792999999997	46.652441000000003	59.880468999999998	59.871856999999999	0103000020E610000001000000050000002EA9DA6E82514740F3E49A0299EF4D402EA9DA6E8251474027124C35B3F04D40E7C8CA2F8353474027124C35B3F04D40E7C8CA2F83534740F3E49A0299EF4D402EA9DA6E82514740F3E49A0299EF4D40
10198	Ваганово	3	27	233	45.641019	45.652526000000002	60.061259	60.057653000000002	0103000020E61000000100000005000000AC8E1CE90CD2464016C26A2C61074E40AC8E1CE90CD24640F7CABC55D7074E4015E5D2F885D34640F7CABC55D7074E4015E5D2F885D3464016C26A2C61074E40AC8E1CE90CD2464016C26A2C61074E40
10034	Березовая Гора	3	27	233	45.719369999999998	45.745457000000002	59.898525999999997	59.889521000000002	0103000020E610000001000000050000009CDCEF5014DC4640780DFAD2DBF14D409CDCEF5014DC4640874D64E602F34D4082C98D226BDF4640874D64E602F34D4082C98D226BDF4640780DFAD2DBF14D409CDCEF5014DC4640780DFAD2DBF14D40
9549	Ананино	3	27	233	45.802725000000002	45.816316	59.986308000000001	59.980370999999998	0103000020E610000001000000050000003F575BB1BFE64640317903CC7CFD4D403F575BB1BFE646403FE42D573FFE4D40CC99ED0A7DE846403FE42D573FFE4D40CC99ED0A7DE84640317903CC7CFD4D403F575BB1BFE64640317903CC7CFD4D40
10490	Алферово	3	27	233	46.148997999999999	46.171258999999999	60.039192999999997	60.033859	0103000020E61000000100000005000000AF95D05D121347406FD6E07D55044E40AF95D05D12134740B69DB64604054E40A5129ED0EB154740B69DB64604054E40A5129ED0EB1547406FD6E07D55044E40AF95D05D121347406FD6E07D55044E40
8579	Шиндалово	3	27	949	38.260936999999998	38.268411	59.775444999999998	59.772024999999999	0103000020E610000001000000050000007EA8346266214340E25817B7D1E24D407EA8346266214340616C21C841E34D407E71A94A5B224340616C21C841E34D407E71A94A5B224340E25817B7D1E24D407EA8346266214340E25817B7D1E24D40
9191	Чарозеро	3	27	949	38.624844000000003	38.653294000000002	60.463445999999998	60.452004000000002	0103000020E61000000100000005000000098D60E3FA4F4340A2D45E44DB394E40098D60E3FA4F434023BBD232523B4E40265646239F53434023BBD232523B4E40265646239F534340A2D45E44DB394E40098D60E3FA4F4340A2D45E44DB394E40
9109	Ферапонтово	3	27	949	38.553472999999997	38.585687	59.961440000000003	59.946004000000002	0103000020E61000000100000005000000081C0934D84643404EF1B8A816F94D40081C0934D84643407B88467710FB4D409F58A7CAF74A43407B88467710FB4D409F58A7CAF74A43404EF1B8A816F94D40081C0934D84643404EF1B8A816F94D40
8629	Топорня	3	27	949	38.364935000000003	38.393383999999998	59.769506	59.756745000000002	0103000020E610000001000000050000003815A930B62E4340AD342905DDE04D403815A930B62E4340B309302C7FE24D4084622B685A324340B309302C7FE24D4084622B685A324340AD342905DDE04D403815A930B62E4340AD342905DDE04D40
8990	Талицы	3	27	949	38.783558999999997	38.816490999999999	59.654148999999997	59.636713999999998	0103000020E6100000010000000500000044BE4BA94B644340E27327D87FD14D4044BE4BA94B64434005DB8827BBD34D403A3DEFC68268434005DB8827BBD34D403A3DEFC682684340E27327D87FD14D4044BE4BA94B644340E27327D87FD14D40
9095	Суховерхово	3	27	949	38.479793000000001	38.498936	59.855172000000003	59.849857999999998	0103000020E61000000100000005000000C4EC65DB693D43403A1F9E25C8EC4D40C4EC65DB693D43403B3AAE4676ED4D4006668522DD3F43403B3AAE4676ED4D4006668522DD3F43403A1F9E25C8EC4D40C4EC65DB693D43403A1F9E25C8EC4D40
8880	Рукино	3	27	949	38.953204999999997	38.964821000000001	59.863066000000003	59.856175999999998	0103000020E610000001000000050000001CB1169F027A43405FCFD72C97ED4D401CB1169F027A434010255AF278EE4D403CBF28417F7B434010255AF278EE4D403CBF28417F7B43405FCFD72C97ED4D401CB1169F027A43405FCFD72C97ED4D40
53251	Пустынь	3	27	949	38.286673999999998	38.301675000000003	59.984625000000001	59.981568000000003	0103000020E61000000100000005000000874ECFBBB12443406B662D05A4FD4D40874ECFBBB124434079E9263108FE4D40AA8251499D26434079E9263108FE4D40AA8251499D2643406B662D05A4FD4D40874ECFBBB12443406B662D05A4FD4D40
8732	Новостройка	3	27	949	38.454631999999997	38.462878000000003	59.995731999999997	59.992140999999997	0103000020E6100000010000000500000087DBA161313A4340A702EE79FEFE4D4087DBA161313A434053CA6B2574FF4D40DA0418963F3B434053CA6B2574FF4D40DA0418963F3B4340A702EE79FEFE4D4087DBA161313A4340A702EE79FEFE4D40
8835	Никольский Торжок	3	27	949	38.759098000000002	38.793674000000003	59.884929999999997	59.862628000000001	0103000020E61000000100000005000000C13A8E1F2A614340944E24986AEE4D40C13A8E1F2A614340E89FE06245F14D40BFD7101C97654340E89FE06245F14D40BFD7101C97654340944E24986AEE4D40C13A8E1F2A614340944E24986AEE4D40
27476	Лукьяновская	3	27	949	38.830522999999999	38.842461	59.958168999999998	59.953668999999998	0103000020E61000000100000005000000B4C9E1934E6A4340C11A67D311FA4D40B4C9E1934E6A434040852348A5FA4D40E69315C3D56B434040852348A5FA4D40E69315C3D56B4340C11A67D311FA4D40B4C9E1934E6A4340C11A67D311FA4D40
9249	Коротецкая	3	27	949	38.668861999999997	38.675384000000001	60.302681999999997	60.299815000000002	0103000020E61000000100000005000000C1C41F459D554340D5EC815660264E40C1C41F459D5543403F8BA548BE264E40EF1EA0FB725643403F8BA548BE264E40EF1EA0FB72564340D5EC815660264E40C1C41F459D554340D5EC815660264E40
9284	Королево	3	27	949	38.777172	38.783999000000001	60.646191000000002	60.643031999999998	0103000020E61000000100000005000000F7AE415F7A634340072461DF4E524E40F7AE415F7A6343401AFCFD62B6524E40618C48145A6443401AFCFD62B6524E40618C48145A644340072461DF4E524E40F7AE415F7A634340072461DF4E524E40
9032	Колкач	3	27	949	38.876175000000003	38.898049	59.704179000000003	59.685352999999999	0103000020E6100000010000000500000052499D8026704340959BA8A5B9D74D4052499D8026704340D7C3978922DA4D404E9A0645F3724340D7C3978922DA4D404E9A0645F3724340959BA8A5B9D74D4052499D8026704340959BA8A5B9D74D40
8124	Коварзино	3	27	949	38.554775999999997	38.581249	60.157755000000002	60.142679999999999	0103000020E61000000100000005000000874D64E6024743408AE5965643124E40874D64E602474340E7E3DA5031144E4096EA025E664A4340E7E3DA5031144E4096EA025E664A43408AE5965643124E40874D64E6024743408AE5965643124E40
8398	Кириллов	3	27	949	38.327080000000002	38.39987	59.876489999999997	59.829811999999997	0103000020E610000001000000050000007D96E7C1DD29434007EA944737EA4D407D96E7C1DD294340B1A206D330F04D406553AEF02E334340B1A206D330F04D406553AEF02E33434007EA944737EA4D407D96E7C1DD29434007EA944737EA4D40
8643	Иванов Бор	3	27	949	38.241362000000002	38.257801999999998	59.774684000000001	59.761938999999998	0103000020E61000000100000005000000A33F34F3E41E43400246973787E14D40A33F34F3E41E4340035E66D828E34D40F46BEBA7FF204340035E66D828E34D40F46BEBA7FF2043400246973787E14D40A33F34F3E41E43400246973787E14D40
9174	Запань-Нова	3	27	949	38.670721	38.684635999999998	59.929203999999999	59.925064999999996	0103000020E61000000100000005000000C6DE8B2FDA5543404DD6A88768F64D40C6DE8B2FDA554340FCA71B28F0F64D4006D50627A2574340FCA71B28F0F64D4006D50627A25743404DD6A88768F64D40C6DE8B2FDA5543404DD6A88768F64D40
7713	Горицы	3	27	949	38.246645000000001	38.267054000000002	59.879714999999997	59.861426000000002	0103000020E61000000100000005000000685C3810921F434049F6083543EE4D40685C3810921F43407B6649809AF04D400C2252D32E2243407B6649809AF04D400C2252D32E22434049F6083543EE4D40685C3810921F434049F6083543EE4D40
8933	Волокославинское	3	27	949	38.753959000000002	38.804479999999998	59.926656999999999	59.908749999999998	0103000020E610000001000000050000002FC37FBA81604340B81E85EB51F44D402FC37FBA8160434003CE52B29CF64D409E245D33F966434003CE52B29CF64D409E245D33F9664340B81E85EB51F44D402FC37FBA81604340B81E85EB51F44D40
8766	Вогнема	3	27	949	38.152006999999998	38.164566000000001	59.981357000000003	59.973748000000001	0103000020E61000000100000005000000ACE122F774134340D04543C6A3FC4D40ACE122F774134340B0592E1B9DFD4D404B04AA7F10154340B0592E1B9DFD4D404B04AA7F10154340D04543C6A3FC4D40ACE122F774134340D04543C6A3FC4D40
7857	Хохлово	3	27	191	37.378881	37.418874000000002	59.155797999999997	59.140540999999999	0103000020E61000000100000005000000B309302C7FB04240A25F5B3FFD914D40B309302C7FB042401F645930F1934D408692C9A99DB542401F645930F1934D408692C9A99DB54240A25F5B3FFD914D40B309302C7FB04240A25F5B3FFD914D40
8080	Фанерный Завод	3	27	191	37.267158000000002	37.288933	59.283804000000003	59.272866999999998	0103000020E61000000100000005000000B16EBC3B32A242402D944C4EEDA24D40B16EBC3B32A24240AC3C81B053A44D401ADEACC1FBA44240AC3C81B053A44D401ADEACC1FBA442402D944C4EEDA24D40B16EBC3B32A242402D944C4EEDA24D40
53289	Сосновка	3	27	191	36.484752	36.506698	59.587429	59.578094	0103000020E61000000100000005000000D655815A0C3E4240C501F4FBFEC94D40D655815A0C3E42406ADC9BDF30CB4D406C79E57ADB4042406ADC9BDF30CB4D406C79E57ADB404240C501F4FBFEC94D40D655815A0C3E4240C501F4FBFEC94D40
8267	Никольское	3	27	191	37.162531000000001	37.180084000000001	59.356226999999997	59.349397000000003	0103000020E6100000010000000500000008CBD8D0CD9442400729780AB9AC4D4008CBD8D0CD944240E179A9D898AD4D40354415FE0C974240E179A9D898AD4D40354415FE0C9742400729780AB9AC4D4008CBD8D0CD9442400729780AB9AC4D40
8361	Малая Рукавицкая	3	27	191	37.182366000000002	37.200592	59.199089999999998	59.192993000000001	0103000020E6100000010000000500000080F3E2C457974240B0AD9FFEB3984D4080F3E2C457974240F67AF7C77B994D406CEBA7FFAC994240F67AF7C77B994D406CEBA7FFAC994240B0AD9FFEB3984D4080F3E2C457974240B0AD9FFEB3984D40
8252	Маза	3	27	191	36.701146999999999	36.734636000000002	59.334429	59.321300000000001	0103000020E610000001000000050000002158552FBF594240371AC05B20A94D402158552FBF594240C0EAC891CEAA4D406D3B6D8D085E4240C0EAC891CEAA4D406D3B6D8D085E4240371AC05B20A94D402158552FBF594240371AC05B20A94D40
53267	Крюково	3	27	191	37.092291000000003	37.103808000000001	59.215034000000003	59.207788999999998	0103000020E610000001000000050000008A5B0531D08B4240F9BB77D4989A4D408A5B0531D08B424098C3EE3B869B4D4016889E94498D424098C3EE3B869B4D4016889E94498D4240F9BB77D4989A4D408A5B0531D08B4240F9BB77D4989A4D40
52618	Кривец	3	27	191	37.409962999999998	37.442419000000001	59.182017000000002	59.170720000000003	0103000020E61000000100000005000000F7C8E6AA79B44240F6622827DA954D40F7C8E6AA79B44240742843554C974D408410902FA1B84240742843554C974D408410902FA1B84240F6622827DA954D40F7C8E6AA79B44240F6622827DA954D40
702	Кадуй	3	27	191	37.101759999999999	37.209243000000001	59.219330999999997	59.193204999999999	0103000020E610000001000000050000003E05C078068D42403B3602F1BA984D403E05C078068D4240DEFFC709139C4D405EF58079C89A4240DEFFC709139C4D405EF58079C89A42403B3602F1BA984D403E05C078068D42403B3602F1BA984D40
20412	Верхний Двор	3	27	191	36.562950000000001	36.579785000000001	59.274687999999998	59.267510000000001	0103000020E6100000010000000500000040A4DFBE0E4842402EAD86C43DA24D4040A4DFBE0E484240444DF4F928A34D400EDB1665364A4240444DF4F928A34D400EDB1665364A42402EAD86C43DA24D4040A4DFBE0E4842402EAD86C43DA24D40
8190	Великое	3	27	191	37.004733000000002	37.022474000000003	59.527692000000002	59.518906000000001	0103000020E61000000100000005000000221B48179B8042405ED905836BC24D40221B48179B804240302E55698BC34D405281936DE0824240302E55698BC34D405281936DE08242405ED905836BC24D40221B48179B8042405ED905836BC24D40
7999	Бойлово	3	27	191	37.339390999999999	37.358687000000003	59.288753999999997	59.280332999999999	0103000020E6100000010000000500000043C70E2A71AB4240AA7EA5F3E1A34D4043C70E2A71AB42406A4B1DE4F5A44D400C40A374E9AD42406A4B1DE4F5A44D400C40A374E9AD4240AA7EA5F3E1A34D4043C70E2A71AB4240AA7EA5F3E1A34D40
7940	Барановская	3	27	191	36.500337999999999	36.527538999999997	59.548842	59.519043000000003	0103000020E61000000100000005000000187959130B404240DF1B430070C24D40187959130B404240EB55647440C64D40A92EE06586434240EB55647440C64D40A92EE06586434240DF1B430070C24D40187959130B404240DF1B430070C24D40
7865	Андроново	3	27	191	37.252451999999998	37.272205999999997	59.406849999999999	59.398958	0103000020E61000000100000005000000A7E7DD5850A04240213D450E11B34D40A7E7DD5850A0424055302AA913B44D4032E36DA5D7A2424055302AA913B44D4032E36DA5D7A24240213D450E11B34D40A7E7DD5850A04240213D450E11B34D40
596	Юрово	3	27	27	39.974859000000002	39.993831999999998	58.972045999999999	58.965235999999997	0103000020E610000001000000050000000B9B012EC8FC4340FF756EDA8C7B4D400B9B012EC8FC4340931ADA006C7C4D40F0DB10E335FF4340931ADA006C7C4D40F0DB10E335FF4340FF756EDA8C7B4D400B9B012EC8FC4340FF756EDA8C7B4D40
1551	Хорошево	3	27	27	40.263083999999999	40.277267999999999	59.023567	59.018796000000002	0103000020E61000000100000005000000E90C8CBCAC214440D7A546E867824D40E90C8CBCAC214440E621533E04834D40191D90847D234440E621533E04834D40191D90847D234440D7A546E867824D40E90C8CBCAC214440D7A546E867824D40
6656	Фрол	3	27	27	40.476675999999998	40.497534999999999	58.922682999999999	58.915677000000002	0103000020E61000000100000005000000E0641BB8033D4440865968E734754D40E0641BB8033D44409FC9FE791A764D40C4CE143AAF3F44409FC9FE791A764D40C4CE143AAF3F4440865968E734754D40E0641BB8033D4440865968E734754D40
692	Степурино	3	27	27	40.039079999999998	40.050884000000003	58.936610999999999	58.930141999999996	0103000020E61000000100000005000000BEF6CC920005444069519FE40E774D40BEF6CC9200054440740987DEE2774D40E1F1ED5D83064440740987DEE2774D40E1F1ED5D8306444069519FE40E774D40BEF6CC920005444069519FE40E774D40
483	Спасское	3	27	27	40.733981	40.755783000000001	58.934308000000001	58.914890999999997	0103000020E610000001000000050000005471E316F35D4440CE33F6251B754D405471E316F35D44401232906797774D40B7EF517FBD6044401232906797774D40B7EF517FBD604440CE33F6251B754D405471E316F35D4440CE33F6251B754D40
53288	Слобода	3	27	27	40.216676999999997	40.237220999999998	58.969248999999998	58.950037999999999	0103000020E61000000100000005000000CF656A12BC1B444087FA5DD89A794D40CF656A12BC1B44402157EA59107C4D405376FA415D1E44402157EA59107C4D405376FA415D1E444087FA5DD89A794D40CF656A12BC1B444087FA5DD89A794D40
7354	Скородумка	3	27	27	40.009166	40.023359999999997	58.867199999999997	58.860574	0103000020E61000000100000005000000191EFB592C014440DAE4F049276E4D40191EFB592C014440AC8BDB68006F4D406C04E275FD024440AC8BDB68006F4D406C04E275FD024440DAE4F049276E4D40191EFB592C014440DAE4F049276E4D40
187	Сидоровское	3	27	27	40.391461999999997	40.404415999999998	58.722827000000002	58.714748	0103000020E6100000010000000500000039D0436D1B324440D270CADC7C5B4D4039D0436D1B32444039D55A98855C4D4054FD4AE7C333444039D55A98855C4D4054FD4AE7C3334440D270CADC7C5B4D4039D0436D1B324440D270CADC7C5B4D40
410	Сидорово	3	27	27	40.96978	40.997070000000001	58.763976	58.751461999999997	0103000020E610000001000000050000004E2844C0217C4440E71725E82F604D404E2844C0217C4440E6762FF7C9614D404FE960FD9F7F4440E6762FF7C9614D404FE960FD9F7F4440E71725E82F604D404E2844C0217C4440E71725E82F604D40
33	Ростилово	3	27	27	40.261161999999999	40.283377000000002	58.802376000000002	58.795164	0103000020E610000001000000050000009E7AA4C16D214440707A17EFC7654D409E7AA4C16D214440338CBB41B4664D4024B891B245244440338CBB41B4664D4024B891B245244440707A17EFC7654D409E7AA4C16D214440707A17EFC7654D40
307	Плоское	3	27	27	40.269705000000002	40.295620999999997	58.644379000000001	58.629835999999997	0103000020E61000000100000005000000AA4885B185224440F6EB4E779E504D40AA4885B185224440569DD5027B524D406281AFE8D6254440569DD5027B524D406281AFE8D6254440F6EB4E779E504D40AA4885B185224440F6EB4E779E504D40
7151	Панфилово	3	27	27	39.867178000000003	39.877186000000002	58.983882000000001	58.976156000000003	0103000020E61000000100000005000000C5E74EB0FFEE4340A8E507AEF27C4D40C5E74EB0FFEE4340C18F6AD8EF7D4D4029417FA147F04340C18F6AD8EF7D4D4029417FA147F04340A8E507AEF27C4D40C5E74EB0FFEE4340A8E507AEF27C4D40
1844	Палкино	3	27	27	40.134517000000002	40.145809	59.010378000000003	59.005234000000002	0103000020E61000000100000005000000C6E061DA37114440E469F981AB804D40C6E061DA37114440884CF91054814D40323B8BDEA9124440884CF91054814D40323B8BDEA9124440E469F981AB804D40C6E061DA37114440E469F981AB804D40
548	Минькино	3	27	27	39.755096000000002	39.767994999999999	58.967941000000003	58.962451999999999	0103000020E6100000010000000500000093AB58FCA6E0434022FC8BA0317B4D4093AB58FCA6E0434091BA9D7DE57B4D40EA3E00A94DE2434091BA9D7DE57B4D40EA3E00A94DE2434022FC8BA0317B4D4093AB58FCA6E0434022FC8BA0317B4D40
53278	Льнозавода	3	27	27	40.247238000000003	40.256166999999998	58.835076000000001	58.829445	0103000020E610000001000000050000000B2AAA7EA51F4440556AF6402B6A4D400B2AAA7EA51F444056D636C5E36A4D403FA88B14CA20444056D636C5E36A4D403FA88B14CA204440556AF6402B6A4D400B2AAA7EA51F4440556AF6402B6A4D40
6823	Заемье	3	27	27	40.290671000000003	40.298954000000002	58.741366999999997	58.734408000000002	0103000020E61000000100000005000000A47213B534254440DCF5D214015E4D40A47213B534254440B4AA251DE55E4D401381EA1F44264440B4AA251DE55E4D401381EA1F44264440DCF5D214015E4D40A47213B534254440DCF5D214015E4D40
5379	Жерноково	3	27	27	40.603177000000002	40.638866999999998	58.855473000000003	58.850478000000003	0103000020E61000000100000005000000865968E7344D4440D7FB8D76DC6C4D40865968E7344D444036CEA623806D4D402FBFD364C651444036CEA623806D4D402FBFD364C6514440D7FB8D76DC6C4D40865968E7344D4440D7FB8D76DC6C4D40
29210	Дорожный	3	27	27	40.192126000000002	40.198576000000003	59.008282999999999	59.004381000000002	0103000020E610000001000000050000000C5BB39597184440A5DC7D8E8F804D400C5BB395971844406F0ED76A0F814D40A0E238F06A1944406F0ED76A0F814D40A0E238F06A194440A5DC7D8E8F804D400C5BB39597184440A5DC7D8E8F804D40
4652	Демьяново	3	27	27	41.142265000000002	41.162377999999997	58.894711000000001	58.886471	0103000020E61000000100000005000000C72E51BD359244401CEDB8E177714D40C72E51BD359244408C2FDAE385724D4081CB63CDC89444408C2FDAE385724D4081CB63CDC89444401CEDB8E177714D40C72E51BD359244401CEDB8E177714D40
4103	Грязовец	3	27	27	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
4566	Вохтога	3	27	27	41.062691999999998	41.087206999999999	58.775846000000001	58.76146	0103000020E6100000010000000500000044DC9C4A06884440289B728577614D4044DC9C4A06884440C05DF6EB4E634D40BB7D5699298B4440C05DF6EB4E634D40BB7D5699298B4440289B728577614D4044DC9C4A06884440289B728577614D40
4384	Вохтога	3	27	27	41.025188	41.074685000000002	58.835476	58.801130999999998	0103000020E610000001000000050000003620425C39834440E867EA758B664D403620425C39834440E44BA8E0F06A4D403A4030478F894440E44BA8E0F06A4D403A4030478F894440E867EA758B664D403620425C39834440E867EA758B664D40
1508	Вострогский	3	27	27	41.412838000000001	41.423302999999997	59.156503000000001	59.148068000000002	0103000020E61000000100000005000000E54526E0D7B44440C5CA68E4F3924D40E54526E0D7B44440EA5C514A08944D403BA6EECA2EB64440EA5C514A08944D403BA6EECA2EB64440C5CA68E4F3924D40E54526E0D7B44440C5CA68E4F3924D40
53260	Вараксино	3	27	27	40.427889	40.444111999999997	58.610720999999998	58.600285	0103000020E61000000100000005000000B9A81611C5364440C2A38D23D64C4D40B9A81611C53644407EFD101B2C4E4D406DE179A9D83844407EFD101B2C4E4D406DE179A9D8384440C2A38D23D64C4D40B9A81611C5364440C2A38D23D64C4D40
1669	Бушуиха	3	27	27	40.447032	40.467567000000003	59.022492	59.017285999999999	0103000020E61000000100000005000000FB21365838394440DE567A6D36824D40FB21365838394440F8359204E1824D402CD8463CD93B4440F8359204E1824D402CD8463CD93B4440DE567A6D36824D40FB21365838394440DE567A6D36824D40
6985	Анохино	3	27	27	40.786658000000003	40.810929999999999	58.803097999999999	58.794165999999997	0103000020E6100000010000000500000082919735B16444402DCC423BA7654D4082919735B1644440D3BD4EEACB664D4032ACE28DCC674440D3BD4EEACB664D4032ACE28DCC6744402DCC423BA7654D4082919735B16444402DCC423BA7654D40
4615	Аксеново	3	27	27	40.971243999999999	40.983317	58.839205999999997	58.833981000000001	0103000020E61000000100000005000000D63730B9517C4440213EB0E3BF6A4D40D63730B9517C4440B14D2A1A6B6B4D40E84CDA54DD7D4440B14D2A1A6B6B4D40E84CDA54DD7D4440213EB0E3BF6A4D40D63730B9517C4440213EB0E3BF6A4D40
3963	Янишево	3	27	547	37.535950999999997	37.562362	61.226472999999999	61.219313	0103000020E6100000010000000500000016A1D80A9AC44240384BC972129C4E4016A1D80A9AC44240A8363811FD9C4E40AF415F7AFBC74240A8363811FD9C4E40AF415F7AFBC74240384BC972129C4E4016A1D80A9AC44240384BC972129C4E40
3554	Шестово	3	27	547	36.456895000000003	36.464441000000001	60.993468999999997	60.988168000000002	0103000020E610000001000000050000005C5A0D897B3A4240147AFD497C7E4E405C5A0D897B3A42407F4B00FE297F4E40F5F57CCD723B42407F4B00FE297F4E40F5F57CCD723B4240147AFD497C7E4E405C5A0D897B3A4240147AFD497C7E4E40
4293	Тудозерский Погост	3	27	547	36.533566	36.546348999999999	61.116186999999996	61.107711000000002	0103000020E61000000100000005000000F72004E44B444240B1355B79C98D4E40F72004E44B444240349C3237DF8E4E40E59997C3EE454240349C3237DF8E4E40E59997C3EE454240B1355B79C98D4E40F72004E44B444240B1355B79C98D4E40
4320	Сорокополье	3	27	547	36.543546999999997	36.575139999999998	61.264006999999999	61.256622	0103000020E61000000100000005000000616BB6F29245424091B75CFDD8A04E40616BB6F29245424021753BFBCAA14E408B4F01309E49424021753BFBCAA14E408B4F01309E49424091B75CFDD8A04E40616BB6F29245424091B75CFDD8A04E40
4483	Саминский Погост	3	27	547	36.591157000000003	36.602009000000002	61.349769000000002	61.341987000000003	0103000020E6100000010000000500000097E65608AB4B42401E54E23AC6AB4E4097E65608AB4B4240CB13083BC5AC4E40E77283A10E4D4240CB13083BC5AC4E40E77283A10E4D42401E54E23AC6AB4E4097E65608AB4B42401E54E23AC6AB4E40
5511	Прокшино	3	27	547	37.789563999999999	37.805391999999998	60.786020999999998	60.779257999999999	0103000020E61000000100000005000000AA0CE36E10E54240BC92E4B9BE634E40AA0CE36E10E542400F7C0C569C644E40E23AC61517E742400F7C0C569C644E40E23AC61517E74240BC92E4B9BE634E40AA0CE36E10E54240BC92E4B9BE634E40
4111	Палтога	3	27	547	36.144137999999998	36.155698999999998	61.013210000000001	61.007719999999999	0103000020E61000000100000005000000300E2E1D7312424037C30DF8FC804E40300E2E1D7312424076FD82DDB0814E408C82E0F1ED13424076FD82DDB0814E408C82E0F1ED13424037C30DF8FC804E40300E2E1D7312424037C30DF8FC804E40
4210	Палозеро	3	27	547	36.336888999999999	36.355950999999997	60.995956	60.989336999999999	0103000020E61000000100000005000000EAB0C22D1F2B424083DC4598A27E4E40EAB0C22D1F2B4240A320787C7B7F4E403FFD67CD8F2D4240A320787C7B7F4E403FFD67CD8F2D424083DC4598A27E4E40EAB0C22D1F2B424083DC4598A27E4E40
5391	Павшозеро	3	27	547	37.059466999999998	37.089058000000001	60.846259000000003	60.834949000000002	0103000020E610000001000000050000007A185A9D9C874240F969DC9BDF6A4E407A185A9D9C8742400C790437526C4E403DB9A640668B42400C790437526C4E403DB9A640668B4240F969DC9BDF6A4E407A185A9D9C874240F969DC9BDF6A4E40
3694	Ошта	3	27	547	35.550944000000001	35.572584999999997	60.859335999999999	60.845655000000001	0103000020E61000000100000005000000B6F63E5585C6414075594C6C3E6C4E40B6F63E5585C641404223D8B8FE6D4E400F971C774AC941404223D8B8FE6D4E400F971C774AC9414075594C6C3E6C4E40B6F63E5585C6414075594C6C3E6C4E40
4574	Октябрьский	3	27	547	36.605502999999999	36.655081000000003	61.386522999999997	61.377473000000002	0103000020E61000000100000005000000A0504F1F814D4240BF0F070951B04E40A0504F1F814D42406E13EE9579B14E40919DB7B1D95342406E13EE9579B14E40919DB7B1D9534240BF0F070951B04E40A0504F1F814D4240BF0F070951B04E40
5075	Новостройка	3	27	547	36.76296	36.775635000000001	60.756154000000002	60.749001999999997	0103000020E61000000100000005000000FD135CACA8614240BD512B4CDF5F4E40FD135CACA8614240AB5E7EA7C9604E400551F70148634240AB5E7EA7C9604E400551F70148634240BD512B4CDF5F4E40FD135CACA8614240BD512B4CDF5F4E40
3777	Ниж. Водлица	3	27	547	35.741081999999999	35.750864	60.834378999999998	60.827029000000003	0103000020E61000000100000005000000BFD364C6DBDE4140FBEB1516DC694E40BFD364C6DBDE41400EBC5AEECC6A4E4033DFC14F1CE041400EBC5AEECC6A4E4033DFC14F1CE04140FBEB1516DC694E40BFD364C6DBDE4140FBEB1516DC694E40
5143	Митино	3	27	547	36.819958	36.824413999999997	60.597057999999997	60.593294	0103000020E61000000100000005000000FA0B3D62F4684240DE74CB0EF14B4E40FA0B3D62F468424057E883656C4C4E40A92EE0658669424057E883656C4C4E40A92EE06586694240DE74CB0EF14B4E40FA0B3D62F4684240DE74CB0EF14B4E40
5478	Мирный	3	27	547	37.658886000000003	37.695428999999997	60.851931	60.829493999999997	0103000020E6100000010000000500000069E55E6056D44240361D01DC2C6A4E4069E55E6056D442406BB933130C6D4E4051D845D103D942406BB933130C6D4E4051D845D103D94240361D01DC2C6A4E4069E55E6056D44240361D01DC2C6A4E40
4005	Межозерье	3	27	547	36.010271000000003	36.023997000000001	60.564078000000002	60.556316000000002	0103000020E61000000100000005000000728C648F50014240EB1ED95C35474E40728C648F50014240513239B533484E40DF196D5512034240513239B533484E40DF196D5512034240EB1ED95C35474E40728C648F50014240EB1ED95C35474E40
3870	Мегра	3	27	547	35.984417000000001	36.018040999999997	60.877422000000003	60.85718	0103000020E610000001000000050000002F50526001FE414084640113B86D4E402F50526001FE41403D65355D4F704E405A7EE02A4F0242403D65355D4F704E405A7EE02A4F02424084640113B86D4E402F50526001FE414084640113B86D4E40
4471	Макачево	3	27	547	36.716633999999999	36.732731999999999	61.168326	61.160662000000002	0103000020E61000000100000005000000D099B4A9BA5B4240E0DA899290944E40D099B4A9BA5B42408388D4B48B954E40C85D8429CA5D42408388D4B48B954E40C85D8429CA5D4240E0DA899290944E40D099B4A9BA5B4240E0DA899290944E40
3957	Коштуги	3	27	547	35.983159999999998	36.003956000000002	60.700000000000003	60.694234999999999	0103000020E61000000100000005000000205ED72FD8FD4140895E46B1DC584E40205ED72FD8FD41409A99999999594E40BE4F55A1810042409A99999999594E40BE4F55A181004240895E46B1DC584E40205ED72FD8FD4140895E46B1DC584E40
4056	Кондушский Погост	3	27	547	36.077851000000003	36.091056000000002	60.934671999999999	60.924985	0103000020E61000000100000005000000FF7A8505F7094240312592E865764E40FF7A8505F7094240533E0455A3774E40630D17B9A70B4240533E0455A3774E40630D17B9A70B4240312592E865764E40FF7A8505F7094240312592E865764E40
4895	Депо	3	27	547	36.827916999999999	36.862341000000001	60.921998000000002	60.908155999999998	0103000020E61000000100000005000000B6662B2FF969424045D5AF743E744E40B6662B2FF96942401C7DCC0704764E40FE7F9C30616E42401C7DCC0704764E40FE7F9C30616E424045D5AF743E744E40B6662B2FF969424045D5AF743E744E40
4837	Девятины	3	27	547	36.742317	36.794707000000002	60.927027000000002	60.914459000000001	0103000020E61000000100000005000000E621533E045F4240354415FE0C754E40E621533E045F424027C11BD2A8764E407E737FF5B865424027C11BD2A8764E407E737FF5B8654240354415FE0C754E40E621533E045F4240354415FE0C754E40
53293	Горный Ручей	3	27	547	35.177739000000003	38.413722	61.604447	60.411296999999998	0103000020E61000000100000005000000A41CCC26C0964140B1F84D61A5344E40A41CCC26C09641402995F0845ECD4E405FD1ADD7F43443402995F0845ECD4E405FD1ADD7F4344340B1F84D61A5344E40A41CCC26C0964140B1F84D61A5344E40
51294	Вытегра	3	27	547	36.396617999999997	36.470460000000003	61.033639000000001	60.993940000000002	0103000020E61000000100000005000000A180ED60C4324240D717096D397F4E40A180ED60C4324240616F62484E844E40C0098508383C4240616F62484E844E40C0098508383C4240D717096D397F4E40A180ED60C4324240D717096D397F4E40
51278	Волоков Мост	3	27	547	36.875061000000002	36.904535000000003	60.859265999999998	60.844952999999997	0103000020E61000000100000005000000A680B4FF017042401BD47E6B276C4E40A680B4FF017042404948A46DFC6D4E402F8B89CDC77342404948A46DFC6D4E402F8B89CDC77342401BD47E6B276C4E40A680B4FF017042401BD47E6B276C4E40
3883	Верхнее Понизовье	3	27	547	36.038908999999997	36.050460999999999	60.900520999999998	60.888922999999998	0103000020E61000000100000005000000914259F8FA044240C3D4963AC8714E40914259F8FA0442403C2EAA4544734E409A5C8C81750642403C2EAA4544734E409A5C8C8175064240C3D4963AC8714E40914259F8FA044240C3D4963AC8714E40
53257	Боярская	3	27	547	35.177739000000003	38.413722	61.604447	60.411296999999998	0103000020E61000000100000005000000A41CCC26C0964140B1F84D61A5344E40A41CCC26C09641402995F0845ECD4E405FD1ADD7F43443402995F0845ECD4E405FD1ADD7F4344340B1F84D61A5344E40A41CCC26C0964140B1F84D61A5344E40
4655	Белоусово	3	27	547	36.538238	36.557631999999998	60.959477	60.952894000000001	0103000020E6100000010000000500000073BB97FBE4444240FE463B6EF8794E4073BB97FBE4444240D1217024D07A4E40FE99417C60474240D1217024D07A4E40FE99417C60474240FE463B6EF8794E4073BB97FBE4444240FE463B6EF8794E40
4617	Анхимово	3	27	547	36.500984000000003	36.532910999999999	60.955271000000003	60.948512000000001	0103000020E61000000100000005000000DEE8633E2040424089EE59D768794E40DEE8633E204042409BE8F351467A4E40DE567A6D364442409BE8F351467A4E40DE567A6D3644424089EE59D768794E40DEE8633E2040424089EE59D768794E40
53281	Анненский Мост	3	27	547	37.093395999999998	37.150817000000004	60.752616000000003	60.722185000000003	0103000020E61000000100000005000000E2C96E66F48B4240B554DE8E705C4E40E2C96E66F48B4240223999B855604E402657B1F84D934240223999B855604E402657B1F84D934240B554DE8E705C4E40E2C96E66F48B4240B554DE8E705C4E40
4403	Андомский Погост	3	27	547	36.625320000000002	36.641831000000003	61.25609	61.243206999999998	0103000020E6100000010000000500000072C45A7C0A50424042942F68219F4E4072C45A7C0A504240946A9F8EC7A04E408D47A98427524240946A9F8EC7A04E408D47A9842752424042942F68219F4E4072C45A7C0A50424042942F68219F4E40
5284	Александровское	3	27	547	37.112450000000003	37.132840999999999	60.800382999999997	60.795535999999998	0103000020E61000000100000005000000B537F8C2648E42403465A71FD4654E40B537F8C2648E42401EA33CF372664E40B24813EF009142401EA33CF372664E40B24813EF009142403465A71FD4654E40B537F8C2648E42403465A71FD4654E40
28957	Шолохово	3	27	587	39.436543999999998	39.448923000000001	59.559334	59.551974999999999	0103000020E61000000100000005000000ECA17DACE0B74340D49AE61DA7C64D40ECA17DACE0B743403BC5AA4198C74D400BB6114F76B943403BC5AA4198C74D400BB6114F76B94340D49AE61DA7C64D40ECA17DACE0B74340D49AE61DA7C64D40
29082	Харачево	3	27	587	39.968373999999997	39.983358000000003	59.160240000000002	59.154653000000003	0103000020E61000000100000005000000FA25E2ADF3FB4340399D64ABCB934D40FA25E2ADF3FB43406AC18BBE82944D404721C9ACDEFD43406AC18BBE82944D404721C9ACDEFD4340399D64ABCB934D40FA25E2ADF3FB4340399D64ABCB934D40
29141	Фофанцево	3	27	587	39.985118	39.998099000000003	59.329856999999997	59.322057000000001	0103000020E61000000100000005000000B859BC5818FE43405439ED2939A94D40B859BC5818FE4340A7AD11C138AA4D40CD9541B5C1FF4340A7AD11C138AA4D40CD9541B5C1FF43405439ED2939A94D40B859BC5818FE43405439ED2939A94D40
29336	Фетинино	3	27	587	39.762579000000002	39.774507999999997	59.366985999999997	59.360149	0103000020E61000000100000005000000E6CE4C309CE14340F357C85C19AE4D40E6CE4C309CE14340800BB265F9AE4D40C43E011423E34340800BB265F9AE4D40C43E011423E34340F357C85C19AE4D40E6CE4C309CE14340F357C85C19AE4D40
29897	Федотово	3	27	587	39.154536	39.168900000000001	59.202157999999997	59.19444	0103000020E61000000100000005000000FF06EDD5C79343406284F068E3984D40FF06EDD5C7934340F84F3750E0994D40AF25E4839E954340F84F3750E0994D40AF25E4839E9543406284F068E3984D40FF06EDD5C79343406284F068E3984D40
29839	Уткино	3	27	587	39.405273999999999	39.419924999999999	59.146366	59.135610999999997	0103000020E61000000100000005000000A5F5B704E0B343402AFD84B35B914D40A5F5B704E0B34340889FFF1EBC924D40EBE2361AC0B54340889FFF1EBC924D40EBE2361AC0B543402AFD84B35B914D40A5F5B704E0B343402AFD84B35B914D40
29723	Стризнево	3	27	587	39.287747000000003	39.30292	59.198666000000003	59.190845000000003	0103000020E61000000100000005000000D542C9E4D4A4434075CDE49B6D984D40D542C9E4D4A44340E06932E36D994D40F4A62215C6A64340E06932E36D994D40F4A62215C6A6434075CDE49B6D984D40D542C9E4D4A4434075CDE49B6D984D40
61538	Сосновка	3	27	587	39.567850999999997	39.588825999999997	59.200761999999997	59.189287	0103000020E610000001000000050000001D007157AFC843406B47718E3A984D401D007157AFC84340C823B891B2994D406A847EA65ECB4340C823B891B2994D406A847EA65ECB43406B47718E3A984D401D007157AFC843406B47718E3A984D40
29193	Семенково 2-е	3	27	587	39.33887	39.344161	59.419758000000002	59.416887000000003	0103000020E610000001000000050000003ACC971760AB434054909F8D5CB54D403ACC971760AB4340001E51A1BAB54D4082C7B7770DAC4340001E51A1BAB54D4082C7B7770DAC434054909F8D5CB54D403ACC971760AB434054909F8D5CB54D40
29269	Семенково	3	27	587	39.33887	39.344161	59.419758000000002	59.416887000000003	0103000020E610000001000000050000003ACC971760AB434054909F8D5CB54D403ACC971760AB4340001E51A1BAB54D4082C7B7770DAC4340001E51A1BAB54D4082C7B7770DAC434054909F8D5CB54D403ACC971760AB434054909F8D5CB54D40
27721	Северная Ферма	3	27	587	39.059288000000002	39.088123000000003	59.418087	59.408704999999998	0103000020E61000000100000005000000CB85CABF96874340185B087250B44D40CB85CABF96874340FEF0F3DF83B54D4041834D9D478B4340FEF0F3DF83B54D4041834D9D478B4340185B087250B44D40CB85CABF96874340185B087250B44D40
28895	Севастьяново	3	27	587	39.157787999999996	39.177605	59.562156000000002	59.557478000000003	0103000020E61000000100000005000000C2D9AD6532944340A81E69705BC74D40C2D9AD653294434006A051BAF4C74D40944DB9C2BB96434006A051BAF4C74D40944DB9C2BB964340A81E69705BC74D40C2D9AD6532944340A81E69705BC74D40
62099	Помыгалово	3	27	587	39.549112000000001	39.556145999999998	59.381242999999998	59.378191000000001	0103000020E61000000100000005000000ABEB504D49C643401E520C9068B04D40ABEB504D49C643401A6A1492CCB04D408EE6C8CA2FC743401A6A1492CCB04D408EE6C8CA2FC743401E520C9068B04D40ABEB504D49C643401E520C9068B04D40
29549	Погорелово	3	27	587	39.583022999999997	39.601295	59.151811000000002	59.144021000000002	0103000020E610000001000000050000006CE8667FA0CA4340F777B6476F924D406CE8667FA0CA43402716F88A6E934D40C91F0C3CF7CC43402716F88A6E934D40C91F0C3CF7CC4340F777B6476F924D406CE8667FA0CA4340F777B6476F924D40
29665	Перьево	3	27	587	39.772252999999999	39.782252	59.050930000000001	59.043579000000001	0103000020E61000000100000005000000739EB12FD9E243406DE525FF93854D40739EB12FD9E243405131CEDF84864D40849D62D520E443405131CEDF84864D40849D62D520E443406DE525FF93854D40739EB12FD9E243406DE525FF93854D40
28367	Остахово	3	27	587	39.500208000000001	39.525190000000002	59.382334	59.372937	0103000020E610000001000000050000004A99D4D006C04340F33B4D66BCAF4D404A99D4D006C043400E130D52F0B04D40D717096D39C343400E130D52F0B04D40D717096D39C34340F33B4D66BCAF4D404A99D4D006C04340F33B4D66BCAF4D40
22491	Огарково	3	27	587	40.037292000000001	40.065238999999998	59.149965000000002	59.137872999999999	0103000020E610000001000000050000008333F8FBC50444402E008DD2A5914D408333F8FBC5044440B745990D32934D403DB665C059084440B745990D32934D403DB665C0590844402E008DD2A5914D408333F8FBC50444402E008DD2A5914D40
53259	Новое	3	27	587	38.783999000000001	40.326694000000003	59.872801000000003	58.875281000000001	0103000020E61000000100000005000000618C48145A644340B4E7323509704D40618C48145A644340437573F1B7EF4D4054E6E61BD1294440437573F1B7EF4D4054E6E61BD1294440B4E7323509704D40618C48145A644340B4E7323509704D40
28758	Новленское	3	27	587	39.321235999999999	39.350332999999999	59.624229999999997	59.611472999999997	0103000020E610000001000000050000002026E1421EA9434089B14CBF44CE4D402026E1421EA943404E97C5C4E6CF4D40D3DA34B6D7AC43404E97C5C4E6CF4D40D3DA34B6D7AC434089B14CBF44CE4D402026E1421EA9434089B14CBF44CE4D40
28874	Нефедово	3	27	587	39.064928999999999	39.072088999999998	59.768504999999998	59.762405999999999	0103000020E61000000100000005000000EFC7ED974F8843401823128596E14D40EFC7ED974F884340FFE7305F5EE24D405FB35C363A894340FFE7305F5EE24D405FB35C363A8943401823128596E14D40EFC7ED974F8843401823128596E14D40
29587	Непотягово	3	27	587	39.808526999999998	39.821435999999999	59.151575999999999	59.142766000000002	0103000020E610000001000000050000006C770FD07DE74340897D022846924D406C770FD07DE74340E36DA5D766934D40E7E099D024E94340E36DA5D766934D40E7E099D024E94340897D022846924D406C770FD07DE74340897D022846924D40
29052	Надеево	3	27	587	39.944477999999997	39.956740000000003	59.102142000000001	59.095163999999997	0103000020E610000001000000050000004FE5B4A7E4F84340D6E07D552E8C4D404FE5B4A7E4F8434026C632FD128D4D403563D17476FA434026C632FD128D4D403563D17476FA4340D6E07D552E8C4D404FE5B4A7E4F84340D6E07D552E8C4D40
18774	Мынчаково	3	27	587	39.147438999999999	39.163680999999997	59.469321000000001	59.457098999999999	0103000020E61000000100000005000000D593F947DF9243406404543882BA4D40D593F947DF924340BB29E5B512BC4D4000FDBE7FF3944340BB29E5B512BC4D4000FDBE7FF39443406404543882BA4D40D593F947DF9243406404543882BA4D40
53246	Молочное	3	27	587	39.660691999999997	39.694693000000001	59.301951000000003	59.281343999999997	0103000020E610000001000000050000004A5D328E91D443408176871403A44D404A5D328E91D443404CFF9254A6A64D404CE141B3EBD843404CFF9254A6A64D404CE141B3EBD843408176871403A44D404A5D328E91D443408176871403A44D40
29610	Можайское	3	27	587	39.788395999999999	39.796975000000003	59.127738000000001	59.122025999999998	0103000020E610000001000000050000000B26FE28EAE443407FA1478C9E8F4D400B26FE28EAE443406D3A02B859904D40645DDC4603E643406D3A02B859904D40645DDC4603E643407FA1478C9E8F4D400B26FE28EAE443407FA1478C9E8F4D40
28298	Макарово	3	27	587	39.248157999999997	39.269871000000002	59.400061999999998	59.388209000000003	0103000020E61000000100000005000000D11E2FA4C39F4340A6811FD5B0B14D40D11E2FA4C39F4340A92F4B3B35B34D40C59107228BA24340A92F4B3B35B34D40C59107228BA24340A6811FD5B0B14D40D11E2FA4C39F4340A6811FD5B0B14D40
3688	Майский	3	27	587	39.736240000000002	39.754494000000001	59.262675999999999	59.251949000000003	0103000020E61000000100000005000000E700C11C3DDE434045A165DD3FA04D40E700C11C3DDE4340D8B8FE5D9FA14D409D83674293E04340D8B8FE5D9FA14D409D83674293E0434045A165DD3FA04D40E700C11C3DDE434045A165DD3FA04D40
28376	Лесково	3	27	587	39.634343999999999	39.646956000000003	59.204203999999997	59.197845999999998	0103000020E61000000100000005000000F834272F32D143407CD2890453994D40F834272F32D143402FDB4E5B239A4D40BAF94674CFD243402FDB4E5B239A4D40BAF94674CFD243407CD2890453994D40F834272F32D143407CD2890453994D40
28527	Куркино	3	27	587	39.617294000000001	39.660575000000001	59.374808000000002	59.355525999999998	0103000020E610000001000000050000002E02637D03CF434058703FE081AD4D402E02637D03CF4340BC2363B5F9AF4D4011C7BAB88DD44340BC2363B5F9AF4D4011C7BAB88DD4434058703FE081AD4D402E02637D03CF434058703FE081AD4D40
28181	Кубенское	3	27	587	39.656002000000001	39.688009000000001	59.444695000000003	59.423859999999998	0103000020E61000000100000005000000280EA0DFF7D34340910A630B41B64D40280EA0DFF7D34340EDD808C4EBB84D40452DCDAD10D84340EDD808C4EBB84D40452DCDAD10D84340910A630B41B64D40280EA0DFF7D34340910A630B41B64D40
29742	Кипелово	3	27	587	39.127612999999997	39.155785000000002	59.246814000000001	59.224378000000002	0103000020E61000000100000005000000B0C56E9F5590434090F8156BB89C4D40B0C56E9F55904340F418E599979F4D408B1A4CC3F0934340F418E599979F4D408B1A4CC3F093434090F8156BB89C4D40B0C56E9F5590434090F8156BB89C4D40
28572	Ильинское	3	27	587	39.649894000000003	39.661734000000003	59.290095999999998	59.286335999999999	0103000020E61000000100000005000000EEEE01BA2FD343406FD575A8A6A44D40EEEE01BA2FD34340A759A0DD21A54D405D5320B3B3D44340A759A0DD21A54D405D5320B3B3D443406FD575A8A6A44D40EEEE01BA2FD343406FD575A8A6A44D40
28624	Заря	3	27	587	39.480390999999997	39.494700999999999	59.305097000000004	59.299309000000001	0103000020E610000001000000050000007825C9737DBD43400133DFC14FA64D407825C9737DBD4340CA8D226B0DA74D403526C45C52BF4340CA8D226B0DA74D403526C45C52BF43400133DFC14FA64D407825C9737DBD43400133DFC14FA64D40
28449	Ермаково	3	27	587	39.692402000000001	39.719684000000001	59.196620000000003	59.184516000000002	0103000020E61000000100000005000000AED7F4A0A0D843405CCB64389E974D40AED7F4A0A0D84340A9DE1AD82A994D402CBAF59A1EDC4340A9DE1AD82A994D402CBAF59A1EDC43405CCB64389E974D40AED7F4A0A0D843405CCB64389E974D40
29315	Дубровское	3	27	587	39.791620999999999	39.832000000000001	59.350020999999998	59.340311999999997	0103000020E61000000100000005000000D5E940D653E54340DA37F7578FAB4D40D5E940D653E54340E4F4F57CCDAC4D40D122DBF97EEA4340E4F4F57CCDAC4D40D122DBF97EEA4340DA37F7578FAB4D40D5E940D653E54340DA37F7578FAB4D40
53248	Дикая	3	27	587	39.475772999999997	39.498555000000003	59.249625000000002	59.239032000000002	0103000020E61000000100000005000000EFA83121E6BC43404759BF99989E4D40EFA83121E6BC4340CBA145B6F39F4D40EF2076A6D0BF4340CBA145B6F39F4D40EF2076A6D0BF43404759BF99989E4D40EFA83121E6BC43404759BF99989E4D40
28991	Грибково	3	27	587	40.044659000000003	40.061421000000003	59.121563999999999	59.113290999999997	0103000020E610000001000000050000006D3CD862B70544402FF7C951808E4D406D3CD862B70544407B2FBE688F8F4D40D124B1A4DC0744407B2FBE688F8F4D40D124B1A4DC0744402FF7C951808E4D406D3CD862B70544402FF7C951808E4D40
29824	Горка	3	27	587	39.171908999999999	39.183101999999998	59.287950000000002	59.279938000000001	0103000020E61000000100000005000000AC71361D019643402E742502D5A34D40AC71361D019643400D71AC8BDBA44D4085EAE6E26F9743400D71AC8BDBA44D4085EAE6E26F9743402E742502D5A34D40AC71361D019643402E742502D5A34D40
28711	Васильевское	3	27	587	40.13749	40.187112999999997	59.101745000000001	59.073909	0103000020E6100000010000000500000076C3B64599114440A6F0A0D975894D4076C3B6459911444009C4EBFA058D4D4006D49B51F317444009C4EBFA058D4D4006D49B51F3174440A6F0A0D975894D4076C3B64599114440A6F0A0D975894D40
28817	Березник	3	27	587	39.191510999999998	39.207895999999998	59.708191999999997	59.696711000000001	0103000020E6100000010000000500000081E9B46E83984340B9E177D32DD94D4081E9B46E83984340F8A41309A6DA4D400F7C0C569C9A4340F8A41309A6DA4D400F7C0C569C9A4340B9E177D32DD94D4081E9B46E83984340B9E177D32DD94D40
53292	Яхреньга	3	27	309	39.998457999999999	40.013792000000002	60.334102999999999	60.320481000000001	0103000020E61000000100000005000000FC36C478CDFF4340A4FE7A8505294E40FC36C478CDFF43406C3F19E3C32A4E402579AEEFC30144406C3F19E3C32A4E402579AEEFC3014440A4FE7A8505294E40FC36C478CDFF4340A4FE7A8505294E40
27853	Ючка	3	27	309	40.732830999999997	40.773803000000001	60.469996000000002	60.461024000000002	0103000020E610000001000000050000005B3FFD67CD5D4440E7559DD5023B4E405B3FFD67CD5D44401BA034D4283C4E40FA4509FA0B6344401BA034D4283C4E40FA4509FA0B634440E7559DD5023B4E405B3FFD67CD5D4440E7559DD5023B4E40
27466	Сосновица	3	27	309	40.829219999999999	40.846736999999997	60.357590999999999	60.346806000000001	0103000020E61000000100000005000000359886E1236A44403E079623642C4E40359886E1236A4440062CB98AC52D4E4015A8C5E0616C4440062CB98AC52D4E4015A8C5E0616C44403E079623642C4E40359886E1236A44403E079623642C4E40
27108	Савинская	3	27	309	39.823079999999997	39.843812999999997	60.481796000000003	60.470041000000002	0103000020E61000000100000005000000EFFE78AF5AE94340BB63B14D2A3C4E40EFFE78AF5AE94340FCABC77DAB3D4E4046787B1002EC4340FCABC77DAB3D4E4046787B1002EC4340BB63B14D2A3C4E40EFFE78AF5AE94340BB63B14D2A3C4E40
28115	Покровское	3	27	309	40.154243999999998	40.174636	60.607630999999998	60.595939999999999	0103000020E6100000010000000500000057CD7344BE1344406A300DC3474C4E4057CD7344BE134440948444DAC64D4E40255AF2785A164440948444DAC64D4E40255AF2785A1644406A300DC3474C4E4057CD7344BE1344406A300DC3474C4E40
28000	Олеховская	3	27	309	40.563139	40.576200999999998	60.599685999999998	60.594279	0103000020E61000000100000005000000130D52F0144844408CD99255114C4E40130D52F0144844403DEFC682C24C4E40147651F4C04944403DEFC682C24C4E40147651F4C04944408CD99255114C4E40130D52F0144844408CD99255114C4E40
27582	Озерный	3	27	309	41.310502	41.326141	60.525981999999999	60.516285000000003	0103000020E61000000100000005000000DAAB8F87BEA744402B357BA015424E40DAAB8F87BEA744407024D06053434E403F7100FDBEA944407024D06053434E403F7100FDBEA944402B357BA015424E40DAAB8F87BEA744402B357BA015424E40
27839	Огибалово	3	27	309	39.675243999999999	39.687542000000001	60.568308999999999	60.560819000000002	0103000020E61000000100000005000000FD6838656ED64340DBFCBFEAC8474E40FD6838656ED64340E0826C59BE484E402F50526001D84340E0826C59BE484E402F50526001D84340DBFCBFEAC8474E40FD6838656ED64340DBFCBFEAC8474E40
27557	Мишутинская	3	27	309	41.212584999999997	41.227156000000001	60.458458999999998	60.453738999999999	0103000020E61000000100000005000000614F3BFC359B4440BAF59A1E143A4E40614F3BFC359B444047C7D5C8AE3A4E408B8BA372139D444047C7D5C8AE3A4E408B8BA372139D4440BAF59A1E143A4E40614F3BFC359B4440BAF59A1E143A4E40
28045	Михайловская	3	27	309	40.293653999999997	40.301217000000001	60.601947000000003	60.595365999999999	0103000020E61000000100000005000000772B4B74962544403E93FDF3344C4E40772B4B749625444071766B990C4D4E40E7FF55478E26444071766B990C4D4E40E7FF55478E2644403E93FDF3344C4E40772B4B74962544403E93FDF3344C4E40
27911	Марьинская	3	27	309	40.388516000000003	40.400543999999996	60.541828000000002	60.535668000000001	0103000020E6100000010000000500000083FC6CE4BA314440C2C1DEC490444E4083FC6CE4BA3144404F07B29E5A454E40F44D9A06453344404F07B29E5A454E40F44D9A0645334440C2C1DEC490444E4083FC6CE4BA314440C2C1DEC490444E40
27334	Кадниковский	3	27	309	40.239727999999999	40.288003000000003	60.326433000000002	60.309145000000001	0103000020E61000000100000005000000BEF73768AF1E4440685C381092274E40BEF73768AF1E4440E7AA798EC8294E4030134548DD244440E7AA798EC8294E4030134548DD244440685C381092274E40BEF73768AF1E4440685C381092274E40
27648	Деревенька	3	27	309	40.957203	40.962772999999999	60.491095000000001	60.488045999999997	0103000020E610000001000000050000000951BEA0857A4440C878944A783E4E400951BEA0857A4440541D7233DC3E4E40643C4A253C7B4440541D7233DC3E4E40643C4A253C7B4440C878944A783E4E400951BEA0857A4440C878944A783E4E40
27706	Гридино	3	27	309	39.867618999999998	39.878767000000003	60.479765	60.470258000000001	0103000020E61000000100000005000000B131AF230EEF43405857056A313C4E40B131AF230EEF4340FA6184F0683D4E40EBE6E26F7BF04340FA6184F0683D4E40EBE6E26F7BF043405857056A313C4E40B131AF230EEF43405857056A313C4E40
27269	Воскресенское	3	27	309	39.19408	39.198185000000002	60.362761999999996	60.359540000000003	0103000020E6100000010000000500000062670A9DD79843404BCD1E68052E4E4062670A9DD7984340A31D37FC6E2E4E4065C746205E994340A31D37FC6E2E4E4065C746205E9943404BCD1E68052E4E4062670A9DD79843404BCD1E68052E4E40
26984	Вожега	3	27	309	40.180610000000001	40.247425999999997	60.489801	60.459457999999998	0103000020E6100000010000000500000050AA7D3A1E1744405AF10D85CF3A4E4050AA7D3A1E174440284696CCB13E4E400D17B9A7AB1F4440284696CCB13E4E400D17B9A7AB1F44405AF10D85CF3A4E4050AA7D3A1E1744405AF10D85CF3A4E40
27191	Бекетовская	3	27	309	39.380974000000002	39.413978	60.510395000000003	60.495474000000002	0103000020E610000001000000050000002B508BC1C3B04340580229B16B3F4E402B508BC1C3B043405E85949F54414E40BAA1293BFDB443405E85949F54414E40BAA1293BFDB44340580229B16B3F4E402B508BC1C3B04340580229B16B3F4E40
27314	Бекетово	3	27	309	39.642769999999999	39.661850000000001	60.439447999999999	60.432194000000003	0103000020E61000000100000005000000CA6C904946D2434083C30B2252374E40CA6C904946D24340742502D53F384E40C66D3480B7D44340742502D53F384E40C66D3480B7D4434083C30B2252374E40CA6C904946D2434083C30B2252374E40
28076	База	3	27	309	40.139242000000003	40.158330999999997	60.612630000000003	60.599817999999999	0103000020E61000000100000005000000651D8EAED2114440ACC612D6C64C4E40651D8EAED21144403546EBA86A4E4E40B378B130441444403546EBA86A4E4E40B378B13044144440ACC612D6C64C4E40651D8EAED2114440ACC612D6C64C4E40
26956	Шелота	3	27	563	41.660539	41.677346999999997	60.376348	60.364786000000002	0103000020E61000000100000005000000C45DBD8A8CD44440F304C24EB12E4E40C45DBD8A8CD444401FF5D72B2C304E409885764EB3D644401FF5D72B2C304E409885764EB3D64440F304C24EB12E4E40C45DBD8A8CD44440F304C24EB12E4E40
3602	Чушевицы	3	27	563	41.749319999999997	41.771059000000001	60.507928	60.496493000000001	0103000020E610000001000000050000008E1EBFB7E9DF4440B2D826158D3F4E408E1EBFB7E9DF4440815CE2C803414E40AB24B20FB2E24440815CE2C803414E40AB24B20FB2E24440B2D826158D3F4E408E1EBFB7E9DF4440B2D826158D3F4E40
26109	Феклуха	3	27	563	42.915565999999998	42.935293000000001	60.63503	60.623908999999998	0103000020E610000001000000050000002EAA4544317545400C570740DC4F4E402EAA4544317545404CFDBCA948514E40C09657AEB77745404CFDBCA948514E40C09657AEB77745400C570740DC4F4E402EAA4544317545400C570740DC4F4E40
3563	Урусовская	3	27	563	42.586001000000003	42.605369000000003	60.716675000000002	60.703051000000002	0103000020E610000001000000050000002F36AD14024B4540C6353E93FD594E402F36AD14024B45402F6EA301BC5B4E4091813CBB7C4D45402F6EA301BC5B4E4091813CBB7C4D4540C6353E93FD594E402F36AD14024B4540C6353E93FD594E40
53264	Теплый Ручей	3	27	563	42.067799000000001	42.085405999999999	60.747968999999998	60.742164000000002	0103000020E61000000100000005000000CBD93BA3AD0845406022DE3AFF5E4E40CBD93BA3AD084540FEB5BC72BD5F4E40EB707495EE0A4540FEB5BC72BD5F4E40EB707495EE0A45406022DE3AFF5E4E40CBD93BA3AD0845406022DE3AFF5E4E40
26518	Средняя	3	27	563	41.528773999999999	41.537084	60.670202000000003	60.667126000000003	0103000020E61000000100000005000000D07CCEDDAEC34440D927806264554E40D07CCEDDAEC344405EDBDB2DC9554E40399A232BBFC444405EDBDB2DC9554E40399A232BBFC44440D927806264554E40D07CCEDDAEC34440D927806264554E40
25920	Сметанино	3	27	563	41.821579999999997	41.845260000000003	60.644201000000002	60.628486000000002	0103000020E610000001000000050000001A868F8829E9444037FFAF3A72504E401A868F8829E944407786A92D75524E40F94ECC7A31EC44407786A92D75524E40F94ECC7A31EC444037FFAF3A72504E401A868F8829E9444037FFAF3A72504E40
26669	Рогна	3	27	563	42.573667999999998	42.593637000000001	60.498964999999998	60.488892	0103000020E610000001000000050000008061F9F36D49454055A35703943E4E408061F9F36D494540A06CCA15DE3F4E400859164CFC4B4540A06CCA15DE3F4E400859164CFC4B454055A35703943E4E408061F9F36D49454055A35703943E4E40
26917	Плосково	3	27	563	41.778668000000003	41.790768	60.492224999999998	60.485045	0103000020E610000001000000050000008B389D64ABE344404E0B5EF4153E4E408B389D64ABE3444005A3923A013F4E40965CC5E237E5444005A3923A013F4E40965CC5E237E544404E0B5EF4153E4E408B389D64ABE344404E0B5EF4153E4E40
26240	Пежма	3	27	563	41.719656999999998	41.742322000000001	60.859253000000002	60.846448000000002	0103000020E6100000010000000500000032AB77B81DDC4440DFE17668586C4E4032AB77B81DDC4440B5FE9600FC6D4E40F88C446804DF4440B5FE9600FC6D4E40F88C446804DF4440DFE17668586C4E4032AB77B81DDC4440DFE17668586C4E40
26633	Осташевская	3	27	563	42.67277	42.688831999999998	60.633485	60.628807999999999	0103000020E610000001000000050000006EDDCD531D56454049BBD1C77C504E406EDDCD531D564540D7C0560916514E401938A0A52B584540D7C0560916514E401938A0A52B58454049BBD1C77C504E406EDDCD531D56454049BBD1C77C504E40
26098	Ногинская	3	27	563	42.701290999999998	42.721854	60.789306000000003	60.781602999999997	0103000020E6100000010000000500000054FD4AE7C35945404DBA2D910B644E4054FD4AE7C3594540AF44A0FA07654E404F3E3DB6655C4540AF44A0FA07654E404F3E3DB6655C45404DBA2D910B644E4054FD4AE7C35945404DBA2D910B644E40
26357	Наумиха	3	27	563	42.039735999999998	42.048107999999999	60.757446999999999	60.753639999999997	0103000020E61000000100000005000000A73CBA11160545408D7A884677604E40A73CBA111605454006BAF605F4604E40865627672806454006BAF605F4604E4086562767280645408D7A884677604E40A73CBA11160545408D7A884677604E40
26217	Морозово	3	27	563	41.677751000000001	41.686374999999998	60.796120000000002	60.791769000000002	0103000020E6100000010000000500000068EA758BC0D644404A7EC4AF58654E4068EA758BC0D6444084D89942E7654E4060E5D022DBD7444084D89942E7654E4060E5D022DBD744404A7EC4AF58654E4068EA758BC0D644404A7EC4AF58654E40
25977	Макарцево	3	27	563	41.900506	41.916882000000001	60.583303000000001	60.575378000000001	0103000020E6100000010000000500000007EDD5C743F34440406B7EFCA5494E4007EDD5C743F34440505436ACA94A4E404225AE635CF54440505436ACA94A4E404225AE635CF54440406B7EFCA5494E4007EDD5C743F34440406B7EFCA5494E40
26179	Леушинская	3	27	563	41.695833999999998	41.708258000000001	60.434876000000003	60.423841000000003	0103000020E61000000100000005000000F1B8A81611D944401BDA006C40364E40F1B8A81611D944405CE84A04AA374E40B090B932A8DA44405CE84A04AA374E40B090B932A8DA44401BDA006C40364E40F1B8A81611D944401BDA006C40364E40
26743	Куколовская	3	27	563	42.053947000000001	42.070233999999999	60.678623999999999	60.663497999999997	0103000020E61000000100000005000000D15B3CBCE70645400F7BA180ED544E40D15B3CBCE7064540EE23B726DD564E409C887E6DFD084540EE23B726DD564E409C887E6DFD0845400F7BA180ED544E40D15B3CBCE70645400F7BA180ED544E40
26040	Климушино	3	27	563	42.090383000000003	42.110917999999998	60.819656000000002	60.810389000000001	0103000020E61000000100000005000000A48E8EAB910B4540E204A6D3BA674E40A48E8EAB910B45402FFCE07CEA684E40D4449F8F320E45402FFCE07CEA684E40D4449F8F320E4540E204A6D3BA674E40A48E8EAB910B4540E204A6D3BA674E40
26847	Каменка	3	27	563	41.765740999999998	41.783437999999997	60.467725999999999	60.458703	0103000020E61000000100000005000000691A14CD03E24440DEC9A7C7B63A4E40691A14CD03E2444094BE1072DE3B4E40C93846B247E4444094BE1072DE3B4E40C93846B247E44440DEC9A7C7B63A4E40691A14CD03E24440DEC9A7C7B63A4E40
26583	Елисеевская	3	27	563	42.616086000000003	42.627071999999998	60.569423999999998	60.563321999999999	0103000020E6100000010000000500000001C3F2E7DB4E4540048F6FEF1A484E4001C3F2E7DB4E45405CC7B8E2E2484E40601E32E5435045405CC7B8E2E2484E40601E32E543504540048F6FEF1A484E4001C3F2E7DB4E4540048F6FEF1A484E40
26827	Владыкина Гора	3	27	563	41.888558000000003	41.900542000000002	60.505195000000001	60.501393	0103000020E61000000100000005000000B24CBF44BCF14440BFB854A52D404E40B24CBF44BCF14440268DD13AAA404E405456D3F544F34440268DD13AAA404E405456D3F544F34440BFB854A52D404E40B24CBF44BCF14440BFB854A52D404E40
25718	Верховажье	3	27	563	42.000056999999998	42.066541999999998	60.754260000000002	60.728907999999997	0103000020E61000000100000005000000649126DE0100454079E57ADB4C5D4E40649126DE010045402A5778978B604E40BCE7C072840845402A5778978B604E40BCE7C0728408454079E57ADB4C5D4E40649126DE0100454079E57ADB4C5D4E40
25995	Великодворская	3	27	563	42.171159000000003	42.181238999999998	60.433464000000001	60.426999000000002	0103000020E6100000010000000500000042B5C189E81545405D363AE7A7364E4042B5C189E815454026FF93BF7B374E403FE1ECD63217454026FF93BF7B374E403FE1ECD6321745405D363AE7A7364E4042B5C189E81545405D363AE7A7364E40
3507	Большое Ефимово	3	27	563	41.936124	41.953561000000001	60.713642999999998	60.710068999999997	0103000020E61000000100000005000000178046E9D2F74440A3737E8AE35A4E40178046E9D2F74440790261A7585B4E40DBDE6E490EFA4440790261A7585B4E40DBDE6E490EFA4440A3737E8AE35A4E40178046E9D2F74440A3737E8AE35A4E40
26387	Безымянная	3	27	563	42.304217999999999	42.313730999999997	60.729097000000003	60.725180999999999	0103000020E61000000100000005000000616D8C9DF02645401D5723BBD25C4E40616D8C9DF02645404D4EED0C535D4E40E55E6056282845404D4EED0C535D4E40E55E6056282845401D5723BBD25C4E40616D8C9DF02645401D5723BBD25C4E40
26286	Артемьевская	3	27	563	41.607987999999999	41.620465000000003	60.750425999999997	60.735664	0103000020E61000000100000005000000232E008DD2CD44401A6CEA3C2A5E4E40232E008DD2CD4440B7088CF50D604E4005A8A9656BCF4440B7088CF50D604E4005A8A9656BCF44401A6CEA3C2A5E4E40232E008DD2CD44401A6CEA3C2A5E4E40
53273	дер.Бухинино	3	27	1717	46.472185000000003	46.507049000000002	60.985899000000003	60.973624999999998	0103000020E61000000100000005000000B554DE8E703C4740B4C876BE9F7C4E40B554DE8E703C47405E143DF0317E4E40193C4CFBE64047405E143DF0317E4E40193C4CFBE6404740B4C876BE9F7C4E40B554DE8E703C4740B4C876BE9F7C4E40
25644	Юдино	3	27	1717	46.322526000000003	46.355952000000002	60.791629	60.775243000000003	0103000020E610000001000000050000000B0E2F8848294740FAB9A1293B634E400B0E2F884829474058C85C1954654E401079CBD58F2D474058C85C1954654E401079CBD58F2D4740FAB9A1293B634E400B0E2F8848294740FAB9A1293B634E40
25383	Щекино	3	27	1717	46.195512999999998	46.212356999999997	60.650494999999999	60.646186	0103000020E61000000100000005000000AF78EA910619474008910C39B6524E40AF78EA9106194740139B8F6B43534E40D009A1832E1B4740139B8F6B43534E40D009A1832E1B474008910C39B6524E40AF78EA910619474008910C39B6524E40
24893	Чучеры	3	27	1717	46.615997	46.625132000000001	60.641899000000002	60.638311999999999	0103000020E6100000010000000500000091B75CFDD84E47407A522635B4514E4091B75CFDD84E4740E52A16BF29524E406FD74B5304504740E52A16BF29524E406FD74B53045047407A522635B4514E4091B75CFDD84E47407A522635B4514E40
24816	Чернево	3	27	1717	46.628186999999997	46.642299000000001	60.507475999999997	60.494539000000003	0103000020E61000000100000005000000DC627E6E685047405CCCCF0D4D3F4E40DC627E6E68504740A0C03BF9F4404E4073A087DA36524740A0C03BF9F4404E4073A087DA365247405CCCCF0D4D3F4E40DC627E6E685047405CCCCF0D4D3F4E40
25407	Усть-Алексеево	3	27	1717	46.472544999999997	46.508234999999999	60.479787000000002	60.450387999999997	0103000020E61000000100000005000000B471C45A7C3C474063416150A6394E40B471C45A7C3C4740E20511A9693D4E405ED72FD80D414740E20511A9693D4E405ED72FD80D41474063416150A6394E40B471C45A7C3C474063416150A6394E40
25265	Теплогорье	3	27	1717	46.670074999999997	46.694752000000001	60.461812999999999	60.455167000000003	0103000020E61000000100000005000000006F8104C5554740F69B89E9423A4E40006F8104C55547400FEF39B01C3B4E40516A2FA2ED5847400FEF39B01C3B4E40516A2FA2ED584740F69B89E9423A4E40006F8104C5554740F69B89E9423A4E40
25184	Сусоловка	3	27	1717	47.032787999999996	47.067318999999998	60.826445999999997	60.808858000000001	0103000020E61000000100000005000000C2D9AD6532844740D28DB0A888674E40C2D9AD65328447407BF486FBC8694E4020B3B3E89D8847407BF486FBC8694E4020B3B3E89D884740D28DB0A888674E40C2D9AD6532844740D28DB0A888674E40
25561	Стрига	3	27	1717	46.328895000000003	46.343538000000002	60.799452000000002	60.792292000000003	0103000020E61000000100000005000000B2683A3B192A4740F47002D369654E40B2683A3B192A4740645C717154664E4075779D0DF92B4740645C717154664E4075779D0DF92B4740F47002D369654E40B2683A3B192A4740F47002D369654E40
25254	Северный	3	27	1717	46.945372999999996	46.963715999999998	60.782643999999998	60.772061999999998	0103000020E61000000100000005000000BDC282FB01794740FF3D78EDD2624E40BDC282FB017947408F34B8AD2D644E40E350BF0B5B7B47408F34B8AD2D644E40E350BF0B5B7B4740FF3D78EDD2624E40BDC282FB01794740FF3D78EDD2624E40
24751	Полдарса	3	27	1717	45.379187000000002	45.404052	60.597937000000002	60.588478000000002	0103000020E61000000100000005000000C0081A3389B046402F35423F534B4E40C0081A3389B04640C0081A33894C4E4013F1D6F9B7B34640C0081A33894C4E4013F1D6F9B7B346402F35423F534B4E40C0081A3389B046402F35423F534B4E40
25109	Подсосенье	3	27	1717	46.173665999999997	46.182738999999998	60.724120999999997	60.719090999999999	0103000020E61000000100000005000000AC36FFAF3A16474089EC832C0B5C4E40AC36FFAF3A16474064AC36FFAF5C4E40145AD6FD6317474064AC36FFAF5C4E40145AD6FD6317474089EC832C0B5C4E40AC36FFAF3A16474089EC832C0B5C4E40
61559	Плутово	3	27	1717	46.421790000000001	46.440511000000001	60.872433999999998	60.861688999999998	0103000020E61000000100000005000000D2E3F736FD35474056293DD34B6E4E40D2E3F736FD35474090F5D4EAAB6F4E409E4319AA6238474090F5D4EAAB6F4E409E4319AA6238474056293DD34B6E4E40D2E3F736FD35474056293DD34B6E4E40
24248	Первомайское	3	27	1717	46.854796	46.873004999999999	60.613672000000001	60.605949000000003	0103000020E61000000100000005000000356090F4696D47409F05A1BC8F4D4E40356090F4696D4740473CD9CD8C4E4E404B1FBAA0BE6F4740473CD9CD8C4E4E404B1FBAA0BE6F47409F05A1BC8F4D4E40356090F4696D47409F05A1BC8F4D4E40
24688	Пеганово	3	27	1717	46.202215000000002	46.218330000000002	60.565064	60.55142	0103000020E610000001000000050000005DE15D2EE21947401F2E39EE94464E405DE15D2EE2194740CF12640454484E402BDEC83CF21B4740CF12640454484E402BDEC83CF21B47401F2E39EE94464E405DE15D2EE21947401F2E39EE94464E40
25023	Новатор	3	27	1717	46.195414	46.24183	60.755854999999997	60.738104999999997	0103000020E610000001000000050000001C97715303194740CD0182397A5E4E401C9771530319474050C24CDBBF604E4089981249F41E474050C24CDBBF604E4089981249F41E4740CD0182397A5E4E401C97715303194740CD0182397A5E4E40
24187	Мякинницыно	3	27	1717	46.633918000000001	46.650573000000001	60.338048000000001	60.331591000000003	0103000020E61000000100000005000000412C9B3924514740F052EA92712A4E40412C9B3924514740363D2828452B4E408F54DFF945534740363D2828452B4E408F54DFF945534740F052EA92712A4E40412C9B3924514740F052EA92712A4E40
25346	Морозовица	3	27	1717	46.272714000000001	46.315779999999997	60.721943000000003	60.705710000000003	0103000020E61000000100000005000000A794D74AE8224740E73A8DB4545A4E40A794D74AE8224740BF49D3A0685C4E408D5DA27A6B284740BF49D3A0685C4E408D5DA27A6B284740E73A8DB4545A4E40A794D74AE8224740E73A8DB4545A4E40
24505	Ломоватка	3	27	1717	45.507475999999997	45.547764999999998	61.140214999999998	61.120018999999999	0103000020E61000000100000005000000A0C03BF9F4C0464006F357C85C8F4E40A0C03BF9F4C046404EB4AB90F2914E405C72DC291DC646404EB4AB90F2914E405C72DC291DC6464006F357C85C8F4E40A0C03BF9F4C0464006F357C85C8F4E40
24660	Лодейка	3	27	1717	45.743391000000003	45.763145000000002	60.700955	60.691980000000001	0103000020E610000001000000050000000492B06F27DF464038BEF6CC92584E400492B06F27DF4640DD7BB8E4B8594E408F8D40BCAEE14640DD7BB8E4B8594E408F8D40BCAEE1464038BEF6CC92584E400492B06F27DF464038BEF6CC92584E40
23929	Кузино	3	27	1717	46.364387000000001	46.393340000000002	60.748742	60.719926999999998	0103000020E61000000100000005000000350BB43BA42E4740F2406491265C4E40350BB43BA42E4740219221C7D65F4E40B51A12F758324740219221C7D65F4E40B51A12F758324740F2406491265C4E40350BB43BA42E4740F2406491265C4E40
23999	Красавино	3	27	1717	46.447840999999997	46.506923	60.974926000000004	60.934327000000003	0103000020E610000001000000050000006A6798DA523947408962F20698774E406A6798DA5239474093020B60CA7C4E408C4B55DAE240474093020B60CA7C4E408C4B55DAE24047408962F20698774E406A6798DA523947408962F20698774E40
24829	Карасово	3	27	1717	46.319831000000001	46.339585	60.674154999999999	60.66534	0103000020E610000001000000050000009D9FE238F02847403E5C72DC29554E409D9FE238F0284740AAB706B64A564E40289B7285772B4740AAB706B64A564E40289B7285772B47403E5C72DC29554E409D9FE238F02847403E5C72DC29554E40
24593	Ишутино	3	27	1717	46.209051000000002	46.242558000000002	60.779964999999997	60.765985999999998	0103000020E610000001000000050000001A19E42EC21A4740D09849D40B624E401A19E42EC21A47402783A3E4D5634E400CB1FA230C1F47402783A3E4D5634E400CB1FA230C1F4740D09849D40B624E401A19E42EC21A4740D09849D40B624E40
24916	Ильинское	3	27	1717	46.748624	46.756655000000002	60.605361000000002	60.597990000000003	0103000020E61000000100000005000000178046E9D25F4740E3AAB2EF8A4C4E40178046E9D25F47400EA320787C4D4E406DAD2F12DA6047400EA320787C4D4E406DAD2F12DA604740E3AAB2EF8A4C4E40178046E9D25F4740E3AAB2EF8A4C4E40
53275	Измарухово	3	27	1717	45.148392000000001	47.075090000000003	61.195188999999999	60.235371000000001	0103000020E61000000100000005000000787E5182FE924640A2B60DA3201E4E40787E5182FE924640FCC401F4FB984E40DA20938C9C894740FCC401F4FB984E40DA20938C9C894740A2B60DA3201E4E40787E5182FE924640A2B60DA3201E4E40
25541	Золотавцево	3	27	1717	46.246555000000001	46.254631000000003	60.799022000000001	60.794707000000002	0103000020E6100000010000000500000028D53E1D8F1F47407E737FF5B8654E4028D53E1D8F1F47406B64575A46664E401EC6A4BF972047406B64575A46664E401EC6A4BF972047407E737FF5B8654E4028D53E1D8F1F47407E737FF5B8654E40
24301	Верхняя Шарденьга	3	27	1717	46.309851000000002	46.318159999999999	60.398933999999997	60.393725000000003	0103000020E6100000010000000500000003D19332A92747400E4FAF9465324E4003D19332A927474098A1F14410334E409B728577B928474098A1F14410334E409B728577B92847400E4FAF9465324E4003D19332A92747400E4FAF9465324E40
25134	Верхнее Анисимово	3	27	1717	45.583590000000001	45.598205	60.595188999999998	60.591262	0103000020E61000000100000005000000E622BE13B3CA46400CAF2479AE4B4E40E622BE13B3CA46402FF834272F4C4E40DFA63FFB91CC46402FF834272F4C4E40DFA63FFB91CC46400CAF2479AE4B4E40E622BE13B3CA46400CAF2479AE4B4E40
23172	Великий Устюг	3	27	1717	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
24404	Васильевское	3	27	1717	46.455745999999998	46.477063000000001	60.934387999999998	60.919618999999997	0103000020E6100000010000000500000033A48AE2553A4740DEE34C13B6754E4033A48AE2553A47402EE3A6069A774E40DA907F66103D47402EE3A6069A774E40DA907F66103D4740DEE34C13B6754E4033A48AE2553A4740DEE34C13B6754E40
25682	Бобровниково	3	27	1717	46.415689999999998	46.434752000000003	60.82649	60.816585000000003	0103000020E610000001000000050000001AA3755435354740BCB376DB85684E401AA37554353547404B3CA06CCA694E4070EF1AF4A53747404B3CA06CCA694E4070EF1AF4A5374740BCB376DB85684E401AA3755435354740BCB376DB85684E40
24555	Благовещенье	3	27	1717	46.096302999999999	46.109535000000001	60.731222000000002	60.726506000000001	0103000020E61000000100000005000000DBC01DA8530C4740842C0B26FE5C4E40DBC01DA8530C4740D00EB8AE985D4E4039622D3E050E4740D00EB8AE985D4E4039622D3E050E4740842C0B26FE5C4E40DBC01DA8530C4740842C0B26FE5C4E40
25477	Аристово	3	27	1717	46.386333	46.413373	60.770176999999997	60.759459999999997	0103000020E61000000100000005000000CB2E185C73314740614F3BFC35614E40CB2E185C73314740D190F12895624E4053060E68E9344740D190F12895624E4053060E68E9344740614F3BFC35614E40CB2E185C73314740614F3BFC35614E40
22721	Троицкое	3	27	1690	37.701555999999997	37.715623000000001	60.334695000000004	60.327052000000002	0103000020E6100000010000000500000002284696CCD94240B30B06D7DC294E4002284696CCD942403F912749D72A4E40F9A1D28899DB42403F912749D72A4E40F9A1D28899DB4240B30B06D7DC294E4002284696CCD94240B30B06D7DC294E40
23028	Покровское	3	27	1690	37.284261000000001	37.314785999999998	60.443350000000002	60.433960999999996	0103000020E610000001000000050000009E4319AA62A44240A65EB7088C374E409E4319AA62A442403F575BB1BF384E408C9E5BE84AA842403F575BB1BF384E408C9E5BE84AA84240A65EB7088C374E409E4319AA62A44240A65EB7088C374E40
22575	Пиньшино	3	27	1690	38.278229000000003	38.289081000000003	60.285519000000001	60.281036999999998	0103000020E610000001000000050000003FE603029D234340A4FB3905F9234E403FE603029D2343407DB1F7E28B244E408F72309B002543407DB1F7E28B244E408F72309B00254340A4FB3905F9234E403FE603029D234340A4FB3905F9234E40
22986	Пиксимово	3	27	1690	37.645150999999998	37.666513000000002	60.464314999999999	60.454377999999998	0103000020E61000000100000005000000A8FDD64E94D24240CD02ED0E293A4E40A8FDD64E94D24240680586AC6E3B4E40EFAD484C50D54240680586AC6E3B4E40EFAD484C50D54240CD02ED0E293A4E40A8FDD64E94D24240CD02ED0E293A4E40
22440	Первомайский	3	27	1690	37.950828999999999	37.971688	60.464115	60.454165000000003	0103000020E61000000100000005000000508BC1C3B4F9424072FE2614223A4E40508BC1C3B4F94240A14ACD1E683B4E4034F5BA4560FC4240A14ACD1E683B4E4034F5BA4560FC424072FE2614223A4E40508BC1C3B4F9424072FE2614223A4E40
23110	Парфеново	3	27	1690	38.185352999999999	38.194218999999997	60.415410999999999	60.411048000000001	0103000020E61000000100000005000000959BA8A5B9174340098B8A389D344E40959BA8A5B917434007B309302C354E4083A10E2BDC18434007B309302C354E4083A10E2BDC184340098B8A389D344E40959BA8A5B9174340098B8A389D344E40
53294	Остров	3	27	1690	37.873933999999998	37.888468000000003	60.558447999999999	60.549667999999997	0103000020E61000000100000005000000656EBE11DDEF424030D461855B464E40656EBE11DDEF424020425C397B474E4072C5C551B9F1424020425C397B474E4072C5C551B9F1424030D461855B464E40656EBE11DDEF424030D461855B464E40
22664	Октябрьский	3	27	1690	38.132334	38.146706999999999	60.645569000000002	60.639578	0103000020E610000001000000050000000E130D52F0104340DC9E20B1DD514E400E130D52F0104340DD274701A2524E40118C834BC7124340DD274701A2524E40118C834BC7124340DC9E20B1DD514E400E130D52F0104340DC9E20B1DD514E40
22762	Новокемский	3	27	1690	37.235715999999996	37.259647999999999	60.360061000000002	60.346294	0103000020E610000001000000050000006C921FF12B9E424088669E5C532C4E406C921FF12B9E424054C8957A162E4E40643C4A253CA1424054C8957A162E4E40643C4A253CA1424088669E5C532C4E406C921FF12B9E424088669E5C532C4E40
53280	Липин Бор	3	27	1690	37.950792999999997	37.996094999999997	60.270587999999996	60.249885999999996	0103000020E610000001000000050000000322C495B3F9424037DDB243FC1F4E400322C495B3F942405358A9A0A2224E40C45A7C0A80FF42405358A9A0A2224E40C45A7C0A80FF424037DDB243FC1F4E400322C495B3F9424037DDB243FC1F4E40
22648	Ивановская	3	27	1690	37.976089999999999	37.999006000000001	60.658228999999999	60.650804000000001	0103000020E61000000100000005000000F0F96184F0FC4240910DA48B4D534E40F0F96184F0FC4240AF230ED940544E40FF40B96DDFFF4240AF230ED940544E40FF40B96DDFFF4240910DA48B4D534E40F0F96184F0FC4240910DA48B4D534E40
22890	Заречный	3	27	1690	37.988280000000003	38.002994999999999	60.276401999999997	60.269753000000001	0103000020E610000001000000050000003CA583F57FFE4240BB7F2C4487224E403CA583F57FFE42404546072461234E409886E123620043404546072461234E409886E12362004340BB7F2C4487224E403CA583F57FFE4240BB7F2C4487224E40
22525	Васильевская	3	27	1690	38.010207999999999	38.021436999999999	60.280760000000001	60.272185	0103000020E610000001000000050000002B14E97E4E0143401BBB44F5D6224E402B14E97E4E014340320395F1EF234E4051F69672BE024340320395F1EF234E4051F69672BE0243401BBB44F5D6224E402B14E97E4E0143401BBB44F5D6224E40
23056	Бонга	3	27	1690	37.547378000000002	37.566952000000001	60.512844000000001	60.505052999999997	0103000020E610000001000000050000006346787B10C6424093DFA293A5404E406346787B10C6424094F947DFA4414E406E3315E291C8424094F947DFA4414E406E3315E291C8424093DFA293A5404E406346787B10C6424093DFA293A5404E40
22385	Андреевская	3	27	1690	37.912579000000001	37.924688000000003	60.496035999999997	60.479179999999999	0103000020E6100000010000000500000019028063CFF44240DA722EC5553D4E4019028063CFF44240BFD18E1B7E3F4E407880272D5CF64240BFD18E1B7E3F4E407880272D5CF64240DA722EC5553D4E4019028063CFF44240DA722EC5553D4E40
21817	Панинская	3	27	540	36.887853	36.901533999999998	60.061439	60.058416999999999	0103000020E61000000100000005000000E753C72AA5714240E54350357A074E40E753C72AA571424077D9AF3BDD074E40B41D53776573424077D9AF3BDD074E40B41D537765734240E54350357A074E40E753C72AA5714240E54350357A074E40
22139	Никоновская	3	27	540	37.684677000000001	37.814366	59.880094	59.809953	0103000020E6100000010000000500000065A9F57EA3D742400726378AACE74D4065A9F57EA3D74240F2B391EBA6F04D40B77C24253DE84240F2B391EBA6F04D40B77C24253DE842400726378AACE74D4065A9F57EA3D742400726378AACE74D40
22359	Нижняя Мондома	3	27	540	37.503216999999999	37.515084000000002	60.041592999999999	60.026041999999997	0103000020E6100000010000000500000047E5266A69C042404529215855034E4047E5266A69C042400B5F5FEB52054E40B058C345EEC142400B5F5FEB52054E40B058C345EEC142404529215855034E4047E5266A69C042404529215855034E40
22081	Мегринский	3	27	540	37.111983000000002	37.145156999999998	60.187772000000002	60.177571	0103000020E610000001000000050000009F5A7D75558E4240E8DB82A5BA164E409F5A7D75558E4240618DB3E908184E408AE42B8194924240618DB3E908184E408AE42B8194924240E8DB82A5BA164E409F5A7D75558E4240E8DB82A5BA164E40
21417	Маэкса	3	27	540	37.692850999999997	37.741925999999999	60.036015999999996	60.023761999999998	0103000020E610000001000000050000001D007157AFD842409B711AA20A034E401D007157AFD84240FD101B2C9C044E40AB06616EF7DE4240FD101B2C9C044E40AB06616EF7DE42409B711AA20A034E401D007157AFD842409B711AA20A034E40
22217	Лаврово	3	27	540	37.361930000000001	37.380865999999997	59.868302	59.855913999999999	0103000020E610000001000000050000007CB8E4B853AE4240221807978EED4D407CB8E4B853AE424094861A8524EF4D4044149337C0B0424094861A8524EF4D4044149337C0B04240221807978EED4D407CB8E4B853AE4240221807978EED4D40
22308	Куность	3	27	540	37.621507000000001	37.646031000000001	60.026657999999998	60.005625000000002	0103000020E61000000100000005000000179E978A8DCF42401F85EB51B8004E40179E978A8DCF4240A016838769034E40E199D024B1D24240A016838769034E40E199D024B1D242401F85EB51B8004E40179E978A8DCF42401F85EB51B8004E40
22186	Кукшево	3	27	540	37.934803000000002	37.957692000000002	59.909115999999997	59.899960999999998	0103000020E61000000100000005000000F299EC9FA7F7424075560BEC31F34D40F299EC9FA7F742409A22C0E95DF44D4007D2C5A695FA42409A22C0E95DF44D4007D2C5A695FA424075560BEC31F34D40F299EC9FA7F7424075560BEC31F34D40
21956	Климшин Бор	3	27	540	36.983389000000003	36.997411	59.907558999999999	59.898750999999997	0103000020E61000000100000005000000821FD5B0DF7D4240A71FD4450AF34D40821FD5B0DF7D42406118B0E42AF44D40D8D5E429AB7F42406118B0E42AF44D40D8D5E429AB7F4240A71FD4450AF34D40821FD5B0DF7D4240A71FD4450AF34D40
21726	Карл Либкнехт	3	27	540	37.194330999999998	37.211157	59.958359000000002	59.950631999999999	0103000020E61000000100000005000000ABCC94D6DF984240FA43334FAEF94D40ABCC94D6DF984240E469F981ABFA4D4026A94C31079B4240E469F981ABFA4D4026A94C31079B4240FA43334FAEF94D40ABCC94D6DF984240FA43334FAEF94D40
21259	Зубово	3	27	540	36.946745999999997	37.022699000000003	60.325854	60.308988999999997	0103000020E6100000010000000500000035CF11F92E79424070E998F38C274E4035CF11F92E794240A9A27895B5294E40725303CDE7824240A9A27895B5294E40725303CDE782424070E998F38C274E4035CF11F92E79424070E998F38C274E40
22043	Глушково	3	27	540	37.917088999999997	37.929602000000003	60.032097	60.024963	0103000020E61000000100000005000000BB421F2C63F54240164ED2FC31034E40BB421F2C63F542405DA626C11B044E40EA25C632FDF642405DA626C11B044E40EA25C632FDF64240164ED2FC31034E40BB421F2C63F54240164ED2FC31034E40
3362	Георгиевское	3	27	540	36.871682999999997	36.884402999999999	59.726346999999997	59.714672999999998	0103000020E6100000010000000500000055BDFC4E936F4240C72AA5677ADB4D4055BDFC4E936F42401B4641F0F8DC4D40FDBD141E347142401B4641F0F8DC4D40FDBD141E34714240C72AA5677ADB4D4055BDFC4E936F4240C72AA5677ADB4D40
3273	Визьма	3	27	540	37.059198000000002	37.094906000000002	59.900740999999996	59.894658	0103000020E610000001000000050000008BFED0CC93874240698D412784F24D408BFED0CC938742404A95287B4BF34D40DB183BE1258C42404A95287B4BF34D40DB183BE1258C4240698D412784F24D408BFED0CC93874240698D412784F24D40
21828	Бечевинка	3	27	540	37.662568999999998	37.684254000000003	59.739145999999998	59.730415999999998	0103000020E61000000100000005000000F52B9D0FCFD44240D13C80457EDD4D40F52B9D0FCFD442400F7C0C569CDE4D401F1494A295D742400F7C0C569CDE4D401F1494A295D74240D13C80457EDD4D40F52B9D0FCFD44240D13C80457EDD4D40
22286	Белый Ручей	3	27	540	37.423653000000002	37.443578000000002	59.753999	59.747892999999998	0103000020E6100000010000000500000018EDF1423AB6424023F433F5BADF4D4018EDF1423AB64240BD1B0B0A83E04D40D09CF529C7B84240BD1B0B0A83E04D40D09CF529C7B8424023F433F5BADF4D4018EDF1423AB6424023F433F5BADF4D40
21350	Белозерск	3	27	540	37.755994000000001	37.821525999999999	60.038542	60.018844000000001	0103000020E6100000010000000500000072FC5069C4E04240E8DCED7A69024E4072FC5069C4E04240DFC2BAF1EE044E40276893C327E94240DFC2BAF1EE044E40276893C327E94240E8DCED7A69024E4072FC5069C4E04240E8DCED7A69024E40
21706	Артюшино	3	27	540	37.324865000000003	37.350602000000002	60.005530999999998	59.997154000000002	0103000020E61000000100000005000000BA4E232D95A94240AD8905BEA2FF4D40BA4E232D95A942409D0E643DB5004E40C3F4BD86E0AC42409D0E643DB5004E40C3F4BD86E0AC4240AD8905BEA2FF4D40BA4E232D95A94240AD8905BEA2FF4D40
21643	Антушево	3	27	540	37.659092000000001	37.683391999999998	59.908470999999999	59.897334000000001	0103000020E6100000010000000500000012876C205DD4424060CB2BD7DBF24D4012876C205DD44240A52E19C748F44D408C2C996379D74240A52E19C748F44D408C2C996379D7424060CB2BD7DBF24D4012876C205DD4424060CB2BD7DBF24D40
19940	Юрманга	3	27	519	43.105111000000001	43.135654000000002	59.792513	59.771875000000001	0103000020E6100000010000000500000095B9F946748D4540CDCCCCCCCCE24D4095B9F946748D4540D253E41071E54D402AC93A1C5D914540D253E41071E54D402AC93A1C5D914540CDCCCCCCCCE24D4095B9F946748D4540CDCCCCCCCCE24D40
21249	Юркино	3	27	519	43.576852000000002	43.593426000000001	59.493338999999999	59.478974000000001	0103000020E61000000100000005000000EC504D49D6C9454031D120054FBD4D40EC504D49D6C94540B16B7BBB25BF4D404D4C1762F5CB4540B16B7BBB25BF4D404D4C1762F5CB454031D120054FBD4D40EC504D49D6C9454031D120054FBD4D40
20639	Тиноватка	3	27	519	43.389930999999997	43.400790999999998	59.677295000000001	59.669943000000004	0103000020E6100000010000000500000029594E42E9B14540929735B1C0D54D4029594E42E9B14540465F419AB1D64D40FCC3961E4DB34540465F419AB1D64D40FCC3961E4DB34540929735B1C0D54D4029594E42E9B14540929735B1C0D54D40
21100	Тиманова Гора	3	27	519	43.685952999999998	43.708150000000003	59.942345000000003	59.934637000000002	0103000020E61000000100000005000000EACBD24ECDD74540D7506A2FA2F74D40EACBD24ECDD745404A46CEC29EF84D40CA54C1A8A4DA45404A46CEC29EF84D40CA54C1A8A4DA4540D7506A2FA2F74D40EACBD24ECDD74540D7506A2FA2F74D40
20840	Скоково	3	27	519	44.515276999999998	44.529192000000002	59.860467999999997	59.855483999999997	0103000020E61000000100000005000000C4B0C398F44146402920ED7F80ED4D40C4B0C398F441464094A0BFD023EE4D4005A73E90BC43464094A0BFD023EE4D4005A73E90BC4346402920ED7F80ED4D40C4B0C398F44146402920ED7F80ED4D40
21031	Рослятино	3	27	519	44.208466999999999	44.254855999999997	59.774583999999997	59.756413999999999	0103000020E61000000100000005000000CAA5F10BAF1A4640471E882CD2E04D40CAA5F10BAF1A46409F008A9125E34D403D98141F9F2046409F008A9125E34D403D98141F9F204640471E882CD2E04D40CAA5F10BAF1A4640471E882CD2E04D40
20761	Подболотье	3	27	519	44.560256000000003	44.582399000000002	59.878224000000003	59.864119000000002	0103000020E61000000100000005000000A3B1F677B6474640166D8E739BEE4D40A3B1F677B6474640FA47DFA469F04D408F1CE90C8C4A4640FA47DFA469F04D408F1CE90C8C4A4640166D8E739BEE4D40A3B1F677B6474640166D8E739BEE4D40
61542	Миньково	3	27	519	43.462280999999997	43.499220000000001	59.709476000000002	59.691884000000002	0103000020E61000000100000005000000F54718062CBB45401650A8A78FD84D40F54718062CBB454001A60C1CD0DA4D402BC1E270E6BF454001A60C1CD0DA4D402BC1E270E6BF45401650A8A78FD84D40F54718062CBB45401650A8A78FD84D40
20326	Логдуз	3	27	519	44.709206000000002	44.738221000000003	59.997729999999997	59.989728999999997	0103000020E6100000010000000500000041102043C75A46408E739B70AFFE4D4041102043C75A4640791EDC9DB5FF4D40371C96067E5E4640791EDC9DB5FF4D40371C96067E5E46408E739B70AFFE4D4041102043C75A46408E739B70AFFE4D40
3225	Кунож	3	27	519	43.729215000000003	43.757198000000002	59.276696999999999	59.262897000000002	0103000020E610000001000000050000005760C8EA56DD4540B79BE09BA6A14D405760C8EA56DD45405EF3AACE6AA34D405E4C33DDEBE045405EF3AACE6AA34D405E4C33DDEBE04540B79BE09BA6A14D405760C8EA56DD4540B79BE09BA6A14D40
20512	Кулибарово	3	27	519	43.607996999999997	43.629215000000002	59.733668000000002	59.724519000000001	0103000020E6100000010000000500000076887FD8D2CD4540522AE109BDDC4D4076887FD8D2CD4540950F41D5E8DD4D408A93FB1D8AD04540950F41D5E8DD4D408A93FB1D8AD04540522AE109BDDC4D4076887FD8D2CD4540522AE109BDDC4D40
21000	Красота	3	27	519	44.172417000000003	44.182837999999997	59.758471999999998	59.751637000000002	0103000020E610000001000000050000002123A0C21116464056BB26A435E04D402123A0C2111646404277499C15E14D40A73B4F3C671746404277499C15E14D40A73B4F3C6717464056BB26A435E04D402123A0C21116464056BB26A435E04D40
20130	Косиково	3	27	519	43.405597	43.422468000000002	59.872100000000003	59.864254000000003	0103000020E61000000100000005000000882D3D9AEAB34540F6B704E09FEE4D40882D3D9AEAB34540BA6B09F9A0EF4D40A3CD716E13B64540BA6B09F9A0EF4D40A3CD716E13B64540F6B704E09FEE4D40882D3D9AEAB34540F6B704E09FEE4D40
20435	Комсомольский	3	27	519	43.481046999999997	43.495249000000001	59.817898	59.806770999999998	0103000020E61000000100000005000000616BB6F292BD45403C2EAA4544E74D40616BB6F292BD45405EBBB4E1B0E84D403830B95164BF45405EBBB4E1B0E84D403830B95164BF45403C2EAA4544E74D40616BB6F292BD45403C2EAA4544E74D40
20741	Кокшарка	3	27	519	44.527763999999998	44.551200999999999	59.859985000000002	59.850414000000001	0103000020E61000000100000005000000C90050C58D434640C007AF5DDAEC4D40C90050C58D43464079060DFD13EE4D40E1421EC18D46464079060DFD13EE4D40E1421EC18D464640C007AF5DDAEC4D40C90050C58D434640C007AF5DDAEC4D40
20245	Козлец	3	27	519	44.719087000000002	44.737053000000003	59.880378	59.869796999999998	0103000020E6100000010000000500000048FDF50A0B5C46405794128255EF4D4048FDF50A0B5C4640170FEF39B0F04D409835B1C0575E4640170FEF39B0F04D409835B1C0575E46405794128255EF4D4048FDF50A0B5C46405794128255EF4D40
19858	Имени Бабушкина	3	27	519	43.107455999999999	43.159486000000001	59.770294	59.744284	0103000020E6100000010000000500000026E1421EC18D4540D177B7B244DF4D4026E1421EC18D45400B2769FE98E24D40BE1589096A9445400B2769FE98E24D40BE1589096A944540D177B7B244DF4D4026E1421EC18D4540D177B7B244DF4D40
20211	Ида	3	27	519	43.143191000000002	43.165396999999999	59.342968999999997	59.329196000000003	0103000020E61000000100000005000000700A2B1554924540ADFC321823AA4D40700A2B15549245405A457F68E6AB4D40A2ED98BA2B9545405A457F68E6AB4D40A2ED98BA2B954540ADFC321823AA4D40700A2B1554924540ADFC321823AA4D40
20939	Зайчики	3	27	519	44.111449	44.135820000000002	59.607230000000001	59.588445	0103000020E610000001000000050000000116F9F5430E4640533F6F2A52CB4D400116F9F5430E464036936FB6B9CD4D404512BD8C6211464036936FB6B9CD4D404512BD8C62114640533F6F2A52CB4D400116F9F5430E4640533F6F2A52CB4D40
20862	Жубрино	3	27	519	44.295935999999998	44.334221999999997	59.785862000000002	59.773147999999999	0103000020E61000000100000005000000C2DA183BE1254640E17B7F83F6E24D40C2DA183BE1254640A795422097E44D4046CD57C9C72A4640A795422097E44D4046CD57C9C72A4640E17B7F83F6E24D40C2DA183BE1254640E17B7F83F6E24D40
3168	Демьяновский Погост	3	27	519	43.424515999999997	43.441673999999999	59.918394999999997	59.905506000000003	0103000020E610000001000000050000007A50508A56B64540782AE09EE7F34D407A50508A56B64540ABE7A4F78DF54D402BBF0CC688B84540ABE7A4F78DF54D402BBF0CC688B84540782AE09EE7F34D407A50508A56B64540782AE09EE7F34D40
20017	Воскресенское	3	27	519	43.965983999999999	43.981202000000003	59.474576999999996	59.467222	0103000020E61000000100000005000000C93A1C5DA5FB454061FC34EECDBB4D40C93A1C5DA5FB454086376BF0BEBC4D408962F20698FD454086376BF0BEBC4D408962F20698FD454061FC34EECDBB4D40C93A1C5DA5FB454061FC34EECDBB4D40
20653	Безгачиха	3	27	519	44.522427999999998	44.53884	59.885241000000001	59.867646999999998	0103000020E61000000100000005000000E141B3EBDE4246407BBC900E0FEF4D40E141B3EBDE424640070ABC934FF14D4069E388B5F8444640070ABC934FF14D4069E388B5F84446407BBC900E0FEF4D40E141B3EBDE4246407BBC900E0FEF4D40
21179	Аниково	3	27	519	43.737085	43.759929	59.391921000000004	59.383287000000003	0103000020E61000000100000005000000A3AF20CD58DE4540B1FD648C0FB14D40A3AF20CD58DE4540CDCEA2772AB24D4018247D5A45E14540CDCEA2772AB24D4018247D5A45E14540B1FD648C0FB14D40A3AF20CD58DE4540B1FD648C0FB14D40
19760	Торопово	3	27	311	35.649183999999998	35.675944999999999	59.503027000000003	59.493431000000001	0103000020E61000000100000005000000118B187618D3414092EA3BBF28BF4D40118B187618D34140A400513063C04D408672A25D85D64140A400513063C04D408672A25D85D6414092EA3BBF28BF4D40118B187618D3414092EA3BBF28BF4D40
18901	Тимошкино	3	27	311	36.142611000000002	36.164043999999997	59.385959	59.378250000000001	0103000020E610000001000000050000006286C6134112424023DBF97E6AB04D406286C61341124240664CC11A67B14D40718DCF64FF144240664CC11A67B14D40718DCF64FF14424023DBF97E6AB04D406286C6134112424023DBF97E6AB04D40
19612	Тимошино	3	27	311	36.172992000000001	36.201908000000003	60.118445000000001	60.09901	0103000020E610000001000000050000001D3C139A241642400DFD135CAC0C4E401D3C139A24164240F7AFAC34290F4E408066101FD8194240F7AFAC34290F4E408066101FD81942400DFD135CAC0C4E401D3C139A241642400DFD135CAC0C4E40
19683	Смородинка	3	27	311	35.648491999999997	35.675127000000003	59.494937999999998	59.485261999999999	0103000020E61000000100000005000000DBDB2DC901D34140EBFEB1101DBE4D40DBDB2DC901D3414019C6DD205ABF4D40C4D2C08F6AD6414019C6DD205ABF4D40C4D2C08F6AD64140EBFEB1101DBE4D40DBDB2DC901D34140EBFEB1101DBE4D40
19501	Санинская	3	27	311	36.038460000000001	36.071140999999997	59.609983999999997	59.602677	0103000020E61000000100000005000000221ADD41EC04424094861A8524CD4D40221ADD41EC044240A88AA9F413CE4D40CE33F6251B094240A88AA9F413CE4D40CE33F6251B09424094861A8524CD4D40221ADD41EC04424094861A8524CD4D40
19441	Пяжелка	3	27	311	35.744971	35.772190000000002	60.152605000000001	60.143168000000003	0103000020E61000000100000005000000F5BBB0355BDF4140B8EA3A5453124E40F5BBB0355BDF4140611A868F88134E402D26361FD7E24140611A868F88134E402D26361FD7E24140B8EA3A5453124E40F5BBB0355BDF4140B8EA3A5453124E40
19267	Пожара	3	27	311	36.088011000000002	36.114035000000001	59.962952999999999	59.948130999999997	0103000020E610000001000000050000001958C7F1430B424071A94A5B5CF94D401958C7F1430B4240E44A3D0B42FB4D40B8CCE9B2980E4240E44A3D0B42FB4D40B8CCE9B2980E424071A94A5B5CF94D401958C7F1430B424071A94A5B5CF94D40
19252	Плесо	3	27	311	35.714221999999999	35.733274999999999	59.792752999999998	59.778471000000003	0103000020E61000000100000005000000B70A62A06BDB414035F10EF0A4E34D40B70A62A06BDB4140276728EE78E54D40B9FC87F4DBDD4140276728EE78E54D40B9FC87F4DBDD414035F10EF0A4E34D40B70A62A06BDB414035F10EF0A4E34D40
19108	Новое Лукино	3	27	311	36.118167	36.149689000000002	59.888772000000003	59.881196000000003	0103000020E61000000100000005000000B43BA418200F4240DAAED007CBF04D40B43BA418200F4240DECCE847C3F14D4015C9570229134240DECCE847C3F14D4015C9570229134240DAAED007CBF04D40B43BA418200F4240DAAED007CBF04D40
19178	Новая Старина	3	27	311	35.963647999999999	35.995933999999998	59.998534999999997	59.986199999999997	0103000020E610000001000000050000008B6D52D158FB414058A835CD3BFE4D408B6D52D158FB4140A774B0FECFFF4D40BB7CEBC37AFF4140A774B0FECFFF4D40BB7CEBC37AFF414058A835CD3BFE4D408B6D52D158FB414058A835CD3BFE4D40
18609	Малое Борисово	3	27	311	36.057783000000001	36.068840999999999	59.807962000000003	59.794328999999998	0103000020E61000000100000005000000E4A1EF6E65074240D7A19A92ACE54D40E4A1EF6E6507424094347F4C6BE74D40DDCF29C8CF08424094347F4C6BE74D40DDCF29C8CF084240D7A19A92ACE54D40E4A1EF6E65074240D7A19A92ACE54D40
19346	Колошма	3	27	311	35.399200999999998	35.430911000000002	60.175521000000003	60.161681000000002	0103000020E61000000100000005000000E7C3B30419B341403AB187F6B1144E40E7C3B30419B341407061DD7877164E404B3E761728B741407061DD7877164E404B3E761728B741403AB187F6B1144E40E7C3B30419B341403AB187F6B1144E40
19091	Кийно	3	27	311	35.742178000000003	35.769792000000002	60.046925999999999	60.041611000000003	0103000020E61000000100000005000000C5E74EB0FFDE4140B2135E8253054E40C5E74EB0FFDE414082AAD1AB01064E40795C548B88E2414082AAD1AB01064E40795C548B88E24140B2135E8253054E40C5E74EB0FFDE4140B2135E8253054E40
19529	Заполье	3	27	311	36.432406999999998	36.443689999999997	59.285114	59.281165000000001	0103000020E61000000100000005000000DEC7D11C59374240D2E3F736FDA34D40DEC7D11C59374240DDD0949D7EA44D40F7C77BD5CA384240DDD0949D7EA44D40F7C77BD5CA384240D2E3F736FDA34D40DEC7D11C59374240D2E3F736FDA34D40
18982	Дубровка	3	27	311	36.215750999999997	36.224823999999998	59.212353999999998	59.206429	0103000020E61000000100000005000000268A90BA9D1B424016F9F5436C9A4D40268A90BA9D1B42405F96766A2E9B4D408EAD6708C71C42405F96766A2E9B4D408EAD6708C71C424016F9F5436C9A4D40268A90BA9D1B424016F9F5436C9A4D40
19370	Григорьевская	3	27	311	35.663808000000003	35.681514	60.250649000000003	60.246094999999997	0103000020E610000001000000050000005E6919A9F7D44140C45A7C0A801F4E405E6919A9F7D4414037E3344415204E4011E2CAD93BD7414037E3344415204E4011E2CAD93BD74140C45A7C0A801F4E405E6919A9F7D44140C45A7C0A801F4E40
19005	Горка	3	27	311	36.308098000000001	36.326090999999998	60.099345999999997	60.093491999999998	0103000020E6100000010000000500000044FB58C16F2742400438BD8BF70B4E4044FB58C16F274240847EA65EB70C4E408D429259BD294240847EA65EB70C4E408D429259BD2942400438BD8BF70B4E4044FB58C16F2742400438BD8BF70B4E40
18887	Володино	3	27	311	35.817106000000003	35.832943	59.413884000000003	59.398491	0103000020E61000000100000005000000C5AEEDED96E841400B60CAC001B34D40C5AEEDED96E84140392BA226FAB44D40503750E09DEA4140392BA226FAB44D40503750E09DEA41400B60CAC001B34D40C5AEEDED96E841400B60CAC001B34D40
18649	Борисово-Судское	3	27	311	35.985377999999997	36.026817999999999	59.921484	59.872796000000001	0103000020E610000001000000050000005419C6DD20FE4140310A82C7B7EF4D405419C6DD20FE4140C5E40D30F3F54D40D978B0C56E034240C5E40D30F3F54D40D978B0C56E034240310A82C7B7EF4D405419C6DD20FE4140310A82C7B7EF4D40
18166	Бабаево	3	27	311	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
18792	Александровская	3	27	311	36.004009000000003	36.018642999999997	59.929271999999997	59.919924000000002	0103000020E61000000100000005000000E1F1ED5D830042401B67D311C0F54D40E1F1ED5D83004240548B8862F2F64D4050A6D1E462024240548B8862F2F64D4050A6D1E4620242401B67D311C0F54D40E1F1ED5D830042401B67D311C0F54D40
18707	Аксентьевская	3	27	311	35.502758999999998	35.525261	60.082040999999997	60.078252999999997	0103000020E6100000010000000500000084622B685AC041402DE8BD31040A4E4084622B685AC041402FF7C951800A4E40A06EA0C03BC341402FF7C951800A4E40A06EA0C03BC341402DE8BD31040A4E4084622B685AC041402DE8BD31040A4E40
53297	Верхневольский	3	27	7278	35.142417000000002	36.720092999999999	60.483696999999999	59.043393999999999	0103000020E610000001000000050000007DB262B83A924140DB6B41EF8D854D407DB262B83A9241402F1686C8E93D4E400D8AE6012C5C42402F1686C8E93D4E400D8AE6012C5C4240DB6B41EF8D854D407DB262B83A924140DB6B41EF8D854D40
57526	Шенкурск	3	26	\N	42.881898	42.938231000000002	62.116292000000001	62.095112999999998	0103000020E6100000010000000500000033349E08E27045405436ACA92C0C4F4033349E08E2704540AA6400A8E20E4F40F48B12F417784540AA6400A8E20E4F40F48B12F4177845405436ACA92C0C4F4033349E08E27045405436ACA92C0C4F40
9494	Северодвинск	3	26	\N	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
51983	Повракульская	3	26	\N	40.611297999999998	40.618519999999997	64.639934999999994	64.631670999999997	0103000020E610000001000000050000001B0E4B033F4E444039B5334C6D2850401B0E4B033F4E44403524EEB1F428504001F6D1A92B4F44403524EEB1F428504001F6D1A92B4F444039B5334C6D2850401B0E4B033F4E444039B5334C6D285040
57458	Онега	3	26	\N	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
57467	Няндома	3	26	\N	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
2333	Новодвинск	3	26	\N	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
57473	Мирный	3	26	\N	40.311638000000002	40.377844000000003	62.778320999999998	62.747137000000002	0103000020E610000001000000050000006E1805C1E3274440D7506A2FA25F4F406E1805C1E32744401F65C405A0634F40B37E33315D3044401F65C405A0634F40B37E33315D304440D7506A2FA25F4F406E1805C1E3274440D7506A2FA25F4F40
57475	Лесная Речка	3	26	\N	40.621628999999999	40.660246999999998	64.423455000000004	64.407891000000006	0103000020E61000000100000005000000629F008A914F44404C55DAE21A1A5040629F008A914F4440F91400E3191B50401C2444F982544440F91400E3191B50401C2444F9825444404C55DAE21A1A5040629F008A914F44404C55DAE21A1A5040
22794	Котлас	3	26	\N	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
15561	Коряжма	3	26	\N	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
12131	Катунино	3	26	\N	40.608414000000003	40.652709999999999	64.401506999999995	64.381197999999998	0103000020E61000000100000005000000DB368C82E04D44403DD34B8C65185040DB368C82E04D44405D876A4AB2195040D6E253008C5344405D876A4AB2195040D6E253008C5344403DD34B8C65185040DB368C82E04D44403DD34B8C65185040
57469	Каргополь	3	26	\N	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
57465	Вельск	3	26	\N	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
11790	Васьково	3	26	\N	40.446601000000001	40.468214000000003	64.421038999999993	64.399867	0103000020E6100000010000000500000032AEB8382A394440FAEFC16B9719504032AEB8382A394440CBD58F4DF21A5040C2C3B46FEE3B4440CBD58F4DF21A5040C2C3B46FEE3B4440FAEFC16B9719504032AEB8382A394440FAEFC16B97195040
11301	Большое Анисимово	3	26	\N	40.494795000000003	40.517890999999999	64.488805999999997	64.477817999999999	0103000020E61000000100000005000000B79C4B71553F44402BDCF291941E5040B79C4B71553F4440AB05F698481F504045F295404A424440AB05F698481F504045F295404A4244402BDCF291941E5040B79C4B71553F44402BDCF291941E5040
1382	Архангельск	3	26	\N	40.311906999999998	40.802190000000003	64.739548999999997	64.396142999999995	0103000020E610000001000000050000005D328E91EC27444084622B685A1950405D328E91EC274440873254C5542F5040D1967329AE664440873254C5542F5040D1967329AE66444084622B685A1950405D328E91EC27444084622B685A195040
57498	Антоново	3	26	\N	46.550393	46.566507999999999	65.737587000000005	65.731496000000007	0103000020E6100000010000000500000042791F4773464740E94999D4D06E504042791F47734647401BBD1AA0346F504010768A55834847401BBD1AA0346F504010768A5583484740E94999D4D06E504042791F4773464740E94999D4D06E5040
19758	Шипуновская	3	26	1595	42.775320999999998	42.826391000000001	62.121547	62.095947000000002	0103000020E610000001000000050000007573F1B73D6345401D93C5FD470C4F407573F1B73D634540A5F622DA8E0F4F40B85A272EC7694540A5F622DA8E0F4F40B85A272EC76945401D93C5FD470C4F407573F1B73D6345401D93C5FD470C4F40
21176	Шенкурск	3	26	1595	42.881898	42.938231000000002	62.116292000000001	62.095112999999998	0103000020E6100000010000000500000033349E08E27045405436ACA92C0C4F4033349E08E2704540AA6400A8E20E4F40F48B12F417784540AA6400A8E20E4F40F48B12F4177845405436ACA92C0C4F4033349E08E27045405436ACA92C0C4F40
57483	Шелаша	3	26	1595	42.714478999999997	42.738472999999999	61.967683999999998	61.950614999999999	0103000020E61000000100000005000000E256410C745B4540240B98C0ADF94E40E256410C745B4540656EBE11DDFB4E4050FD8348865E4540656EBE11DDFB4E4050FD8348865E4540240B98C0ADF94E40E256410C745B4540240B98C0ADF94E40
20986	Шеговары	3	26	1595	42.936767000000003	42.968819000000003	62.382623000000002	62.366655000000002	0103000020E610000001000000050000006C7C26FBE77745401BF5108DEE2E4F406C7C26FBE777454045D95BCAF9304F40295FD042027C454045D95BCAF9304F40295FD042027C45401BF5108DEE2E4F406C7C26FBE77745401BF5108DEE2E4F40
21043	Чушевская	3	26	1595	42.936568999999999	42.953907000000001	62.307605000000002	62.300606000000002	0103000020E6100000010000000500000045B9347EE17745409E7DE5417A264F4045B9347EE1774540058BC3995F274F407636E49F197A4540058BC3995F274F407636E49F197A45409E7DE5417A264F4045B9347EE17745409E7DE5417A264F40
20376	Усть-Паденьга	3	26	1595	42.625535999999997	42.666176	61.916528	61.899068999999997	0103000020E610000001000000050000003E3C4B901150454078EC67B114F34E403E3C4B901150454024EF1CCA50F54E40A7B052414555454024EF1CCA50F54E40A7B052414555454078EC67B114F34E403E3C4B901150454078EC67B114F34E40
19363	Уколок	3	26	1595	41.861033999999997	41.888351999999998	62.341692999999999	62.334242000000003	0103000020E610000001000000050000003D5FB35C36EE44408E791D71C82A4F403D5FB35C36EE4440D522A298BC2B4F4008ABB184B5F14440D522A298BC2B4F4008ABB184B5F144408E791D71C82A4F403D5FB35C36EE44408E791D71C82A4F40
20501	Тронинская	3	26	1595	42.659295	42.670659000000001	61.820929	61.815188999999997	0103000020E610000001000000050000004AB54FC7635445408B87F71C58E84E404AB54FC76354454043AB933314E94E4050E27327D855454043AB933314E94E4050E27327D85545408B87F71C58E84E404AB54FC7635445408B87F71C58E84E40
21599	Сельменьга	3	26	1595	42.696511999999998	42.699953000000001	61.887045000000001	61.883628000000002	0103000020E61000000100000005000000C2A2224E275945403AEAE8B81AF14E40C2A2224E27594540488AC8B08AF14E4059DE550F98594540488AC8B08AF14E4059DE550F985945403AEAE8B81AF14E40C2A2224E275945403AEAE8B81AF14E40
20321	Рыбогорская	3	26	1595	42.362904999999998	42.373989999999999	62.091327999999997	62.087020000000003	0103000020E610000001000000050000000647C9AB732E4540890CAB78230B4F400647C9AB732E4540C39ACAA2B00B4F40F98381E7DE2F4540C39ACAA2B00B4F40F98381E7DE2F4540890CAB78230B4F400647C9AB732E4540890CAB78230B4F40
19896	Ровдино	3	26	1595	42.513139000000002	42.561450999999998	61.694225000000003	61.677194	0103000020E61000000100000005000000ADA6EB89AE4145401286014BAED64E40ADA6EB89AE4145406688635DDCD84E403BA759A0DD4745406688635DDCD84E403BA759A0DD4745401286014BAED64E40ADA6EB89AE4145401286014BAED64E40
20143	Плесо-Лесоучасток	3	26	1595	42.278733000000003	42.296978000000003	61.711485000000003	61.704853999999997	0103000020E6100000010000000500000072A8DF85AD234540363AE7A738DA4E4072A8DF85AD2345401B4CC3F011DB4E40D5D00660032645401B4CC3F011DB4E40D5D0066003264540363AE7A738DA4E4072A8DF85AD234540363AE7A738DA4E40
19624	Петровская	3	26	1595	42.769230999999998	42.789766	62.031115	62.016221999999999	0103000020E61000000100000005000000E108522976624540E4BCFF8F13024F40E10852297662454020B58993FB034F4012BF620D1765454020B58993FB034F4012BF620D17654540E4BCFF8F13024F40E108522976624540E4BCFF8F13024F40
21137	Одинцовская	3	26	1595	42.818143999999997	42.847743999999999	62.265371000000002	62.255279000000002	0103000020E6100000010000000500000095B54DF1B8684540842D76FBAC204F4095B54DF1B868454046274BADF7214F40ABB019E0826C454046274BADF7214F40ABB019E0826C4540842D76FBAC204F4095B54DF1B8684540842D76FBAC204F40
20940	Носовская	3	26	1595	42.497796000000001	42.506815000000003	61.675589000000002	61.671098000000001	0103000020E61000000100000005000000310A82C7B73F45409C340D8AE6D54E40310A82C7B73F4540C8444AB379D64E40A60F5D50DF404540C8444AB379D64E40A60F5D50DF4045409C340D8AE6D54E40310A82C7B73F45409C340D8AE6D54E40
57504	Никольский Погост	3	26	1595	41.218899999999998	44.083995999999999	62.704698	61.593997000000002	0103000020E61000000100000005000000158C4AEA049C44400876FC1708CC4E40158C4AEA049C44403FC7478B335A4F40567F8461C00A46403FC7478B335A4F40567F8461C00A46400876FC1708CC4E40158C4AEA049C44400876FC1708CC4E40
20051	Никольская	3	26	1595	42.381005999999999	42.396430000000002	61.684778000000001	61.678859000000003	0103000020E6100000010000000500000036CAFACDC430454032CC09DAE4D64E4036CAFACDC4304540998235CEA6D74E409F93DE37BE324540998235CEA6D74E409F93DE37BE32454032CC09DAE4D64E4036CAFACDC430454032CC09DAE4D64E40
20660	Никифоровская	3	26	1595	42.968854	42.994509999999998	62.11721	62.106802999999999	0103000020E61000000100000005000000A54C6A68037C4540AE0E80B8AB0D4F40A54C6A68037C4540D061BEBC000F4F40C1C58A1A4C7F4540D061BEBC000F4F40C1C58A1A4C7F4540AE0E80B8AB0D4F40A54C6A68037C4540AE0E80B8AB0D4F40
20234	Куликовская	3	26	1595	42.777729000000001	42.795237	62.508006000000002	62.498325000000001	0103000020E610000001000000050000004D13B69F8C634540BDE3141DC93F4F404D13B69F8C634540FD15325706414F40DAC87553CA654540FD15325706414F40DAC87553CA654540BDE3141DC93F4F404D13B69F8C634540BDE3141DC93F4F40
19851	Красковская	3	26	1595	42.973553000000003	42.989362999999997	62.317127999999997	62.312638999999997	0103000020E610000001000000050000001BF67B629D7C4540213A048E04284F401BF67B629D7C4540AC527AA697284F40AC6F6072A37E4540AC527AA697284F40AC6F6072A37E4540213A048E04284F401BF67B629D7C4540213A048E04284F40
20723	Копалинская	3	26	1595	42.93488	42.945974	62.069102999999998	62.064438000000003	0103000020E610000001000000050000009DD7D825AA774540514F1F813F084F409DD7D825AA7745401A87FA5DD8084F40E36E10AD157945401A87FA5DD8084F40E36E10AD15794540514F1F813F084F409DD7D825AA774540514F1F813F084F40
19542	Ивановское	3	26	1595	42.035586000000002	42.054468	61.924768	61.910251000000002	0103000020E61000000100000005000000051901158E0445405E13D21A83F44E40051901158E04454094313ECC5EF64E40DA56B3CEF806454094313ECC5EF64E40DA56B3CEF80645405E13D21A83F44E40051901158E0445405E13D21A83F44E40
19434	Дывлевская	3	26	1595	42.26153	42.285335000000003	62.276814999999999	62.271360999999999	0103000020E610000001000000050000002176A6D07921454076340EF5BB224F402176A6D079214540680586AC6E234F40BCB376DB85244540680586AC6E234F40BCB376DB8524454076340EF5BB224F402176A6D07921454076340EF5BB224F40
20028	Демидовское	3	26	1595	42.440770999999998	42.452494000000002	61.655439000000001	61.647013999999999	0103000020E610000001000000050000003A03232F6B384540EE06D15AD1D24E403A03232F6B384540F0C2D66CE5D34E4070D1C952EB394540F0C2D66CE5D34E4070D1C952EB394540EE06D15AD1D24E403A03232F6B384540EE06D15AD1D24E40
21085	Данковская	3	26	1595	42.668458000000001	42.683081999999999	62.261811999999999	62.254446000000002	0103000020E61000000100000005000000F25F2008905545408C4CC0AF91204F40F25F200890554540A5D93C0E83214F403E3E213B6F574540A5D93C0E83214F403E3E213B6F5745408C4CC0AF91204F40F25F2008905545408C4CC0AF91204F40
52251	Гребневская	3	26	1595	42.855666999999997	42.874433000000003	62.069073000000003	62.062975000000002	0103000020E610000001000000050000001AA20A7F866D454099BB96900F084F401AA20A7F866D4540B0045262D7084F4087C5A86BED6F4540B0045262D7084F4087C5A86BED6F454099BB96900F084F401AA20A7F866D454099BB96900F084F40
57493	Бобыкинская	3	26	1595	41.218899999999998	44.083995999999999	62.704698	61.593997000000002	0103000020E61000000100000005000000158C4AEA049C44400876FC1708CC4E40158C4AEA049C44403FC7478B335A4F40567F8461C00A46403FC7478B335A4F40567F8461C00A46400876FC1708CC4E40158C4AEA049C44400876FC1708CC4E40
19946	Барановская	3	26	1595	42.516956999999998	42.544148999999997	61.732028999999997	61.724648000000002	0103000020E610000001000000050000001938A0A52B424540508E0244C1DC4E401938A0A52B4245409E5C5320B3DD4E405793A7ACA64545409E5C5320B3DD4E405793A7ACA6454540508E0244C1DC4E401938A0A52B424540508E0244C1DC4E40
19474	Артемьевская	3	26	1595	41.923592999999997	41.942565000000002	61.957861000000001	61.947844000000003	0103000020E6100000010000000500000042E8A04B38F64440DCDAC2F352F94E4042E8A04B38F64440938E72309BFA4E4058AD4CF8A5F84440938E72309BFA4E4058AD4CF8A5F84440DCDAC2F352F94E4042E8A04B38F64440DCDAC2F352F94E40
20445	Алешковская	3	26	1595	42.388713000000003	42.405853	61.863754	61.854767000000002	0103000020E61000000100000005000000D943FB58C13145409B594B0169ED4E40D943FB58C131454004E5B67D8FEE4E40E3FDB8FDF233454004E5B67D8FEE4E40E3FDB8FDF23345409B594B0169ED4E40D943FB58C13145409B594B0169ED4E40
18892	Часовня	3	26	1487	41.869459999999997	41.883043000000001	63.446434000000004	63.438865	0103000020E610000001000000050000000F971C774AEF4440F52D73BA2CB84F400F971C774AEF444047E9D2BF24B94F401AFB928D07F1444047E9D2BF24B94F401AFB928D07F14440F52D73BA2CB84F400F971C774AEF4440F52D73BA2CB84F40
18394	Часовенская	3	26	1487	41.512425	41.525396999999998	63.815955000000002	63.811096999999997	0103000020E610000001000000050000008F53742497C144401D71C806D2E74F408F53742497C14440FC00A43671E84F4050357A3540C34440FC00A43671E84F4050357A3540C344401D71C806D2E74F408F53742497C144401D71C806D2E74F40
17243	Хомяковская	3	26	1487	41.208300000000001	41.230595999999998	64.309978999999998	64.303931000000006	0103000020E61000000100000005000000DFE00B93A99A4440664F029B73135040DFE00B93A99A444098DC28B2D6135040514B732B849D444098DC28B2D6135040514B732B849D4440664F029B73135040DFE00B93A99A4440664F029B73135040
17430	Холмогоры	3	26	1487	41.630175999999999	41.666046000000001	64.236710000000002	64.216200999999998	0103000020E61000000100000005000000AF5C6F9BA9D044403317B83CD60D5040AF5C6F9BA9D04440B728B341260F5040D9D0CDFE40D54440B728B341260F5040D9D0CDFE40D544403317B83CD60D5040AF5C6F9BA9D044403317B83CD60D5040
17835	Харлово	3	26	1487	41.643507	41.657879999999999	64.189657999999994	64.185948999999994	0103000020E61000000100000005000000A0DFF76F5ED24440546EA296E60B5040A0DFF76F5ED244402FDB4E5B230C5040A3586E6935D444402FDB4E5B230C5040A3586E6935D44440546EA296E60B5040A0DFF76F5ED24440546EA296E60B5040
18038	Усть-Пинега	3	26	1487	41.903973999999998	41.929872000000003	64.157568999999995	64.136111	0103000020E610000001000000050000009737876BB5F344400E68E90AB60850409737876BB5F344404277499C150A5040AABBB20B06F744404277499C150A5040AABBB20B06F744400E68E90AB60850409737876BB5F344400E68E90AB6085040
17636	Среднепогостская	3	26	1487	41.832251999999997	41.838073000000001	64.268859000000006	64.264391000000003	0103000020E61000000100000005000000EA03C93B87EA4440D5963AC8EB105040EA03C93B87EA44400F0F61FC341150408F54DFF945EB44400F0F61FC341150408F54DFF945EB4440D5963AC8EB105040EA03C93B87EA4440D5963AC8EB105040
18133	Светлый	3	26	1487	42.683171999999999	42.720838999999998	64.051620999999997	64.037306000000001	0103000020E610000001000000050000007EC51A2E72574540747CB438630250407EC51A2E725745405BB22AC24D0350403657CD73445C45405BB22AC24D0350403657CD73445C4540747CB438630250407EC51A2E72574540747CB43863025040
20877	Россохи	3	26	1487	41.997900999999999	42.004702000000002	63.322983000000001	63.319037000000002	0103000020E61000000100000005000000A6D24F38BBFF4440639B5434D6A84F40A6D24F38BBFF4440FD14C78157A94F40E71C3C139A004540FD14C78157A94F40E71C3C139A004540639B5434D6A84F40A6D24F38BBFF4440639B5434D6A84F40
17587	Рембуево	3	26	1487	41.588368000000003	41.597459000000001	64.324428999999995	64.320831999999996	0103000020E61000000100000005000000A80183A44FCB4440A8E0F08288145040A80183A44FCB4440EF37DA71C3145040B6D9588979CC4440EF37DA71C3145040B6D9588979CC4440A8E0F08288145040A80183A44FCB4440A8E0F08288145040
18884	Погост	3	26	1487	41.787317999999999	41.923394999999999	63.626866999999997	63.519241000000001	0103000020E61000000100000005000000ACC612D6C6E4444005DF347D76C24F40ACC612D6C6E4444087F8872D3DD04F401C25AFCE31F6444087F8872D3DD04F401C25AFCE31F6444005DF347D76C24F40ACC612D6C6E4444005DF347D76C24F40
18499	Палово	3	26	1487	41.471066	41.493470000000002	63.882460999999999	63.867454000000002	0103000020E61000000100000005000000F72004E44BBC4440676490BB08EF4F40F72004E44BBC44406B7F677BF4F04F4050C763062ABF44406B7F677BF4F04F4050C763062ABF4440676490BB08EF4F40F72004E44BBC4440676490BB08EF4F40
18752	Осередок	3	26	1487	41.534865000000003	41.844513999999997	63.522461	63.469135999999999	0103000020E610000001000000050000003563D17476C4444029B000A60CBC4F403563D17476C44440BD378600E0C24F40CF81E50819EC4440BD378600E0C24F40CF81E50819EC444029B000A60CBC4F403563D17476C4444029B000A60CBC4F40
18249	Орлецы	3	26	1487	41.791117999999997	41.812632999999998	64.008274	63.992829	0103000020E6100000010000000500000072A3C85A43E544409CC24A0515FF4F4072A3C85A43E544400EDAAB8F870050403F53AF5B04E844400EDAAB8F870050403F53AF5B04E844409CC24A0515FF4F4072A3C85A43E544409CC24A0515FF4F40
17959	Малая Товра	3	26	1487	41.702724000000003	41.713405000000002	64.117245999999994	64.104522000000003	0103000020E61000000100000005000000A20E2BDCF2D944409AED0A7DB0065040A20E2BDCF2D944408EE55DF580075040C5E6E3DA50DB44408EE55DF580075040C5E6E3DA50DB44409AED0A7DB0065040A20E2BDCF2D944409AED0A7DB0065040
17696	Луковецкий	3	26	1487	41.910262000000003	41.932603	64.305479000000005	64.288482000000002	0103000020E610000001000000050000005265187783F4444005DF347D761250405265187783F4444059A7CAF78C1350406493FC885FF7444059A7CAF78C1350406493FC885FF7444005DF347D761250405265187783F4444005DF347D76125040
17793	Ломоносово	3	26	1487	41.725622000000001	41.738835999999999	64.231936000000005	64.228542000000004	0103000020E610000001000000050000000AA1832EE1DC4440CCF09F6EA00E50400AA1832EE1DC4440F7B0170AD80E5040C18D942D92DE4440F7B0170AD80E5040C18D942D92DE4440CCF09F6EA00E50400AA1832EE1DC4440CCF09F6EA00E5040
18183	Кузомень	3	26	1487	42.925618999999998	42.954498999999998	64.280462	64.269330999999994	0103000020E6100000010000000500000032C7F2AE7A764540223317B83C11504032C7F2AE7A7645405471E316F31150404888F2052D7A45405471E316F31150404888F2052D7A4540223317B83C11504032C7F2AE7A764540223317B83C115040
18346	Копачево	3	26	1487	41.696911999999998	41.707332000000001	63.959715000000003	63.952427999999998	0103000020E610000001000000050000005018946934D94440B8E52329E9F94F405018946934D94440863DEDF0D7FA4F4007B5DFDA89DA4440863DEDF0D7FA4F4007B5DFDA89DA4440B8E52329E9F94F405018946934D94440B8E52329E9F94F40
17280	Калитинская	3	26	1487	41.308543	41.330030999999998	64.296425999999997	64.292648999999997	0103000020E61000000100000005000000723447567EA74440410DDFC2BA125040723447567EA74440C8EBC1A4F812504045D5AF743EAA4440C8EBC1A4F812504045D5AF743EAA4440410DDFC2BA125040723447567EA74440410DDFC2BA125040
18565	Казенщина	3	26	1487	41.644494999999999	41.677230000000002	63.853850000000001	63.845156000000003	0103000020E61000000100000005000000BFB7E9CF7ED24440540262122EEC4F40BFB7E9CF7ED2444045D8F0F44AED4F405FEFFE78AFD6444045D8F0F44AED4F405FEFFE78AFD64440540262122EEC4F40BFB7E9CF7ED24440540262122EEC4F40
18262	Ичково	3	26	1487	41.730536000000001	41.747028999999998	63.941445999999999	63.927987999999999	0103000020E610000001000000050000007C46223482DD44404C8A8F4FC8F64F407C46223482DD44409A79724D81F84F40F01472A59EDF44409A79724D81F84F40F01472A59EDF44404C8A8F4FC8F64F407C46223482DD44404C8A8F4FC8F64F40
19194	Заболотье	3	26	1487	41.810639000000002	41.841586	63.41142	63.396220999999997	0103000020E610000001000000050000005BEECC04C3E74440847EA65EB7B24F405BEECC04C3E74440CD751A69A9B44F40BF620D17B9EB4440CD751A69A9B44F40BF620D17B9EB4440847EA65EB7B24F405BEECC04C3E74440847EA65EB7B24F40
18711	Емецк	3	26	1487	41.777545000000003	41.796301	63.479500999999999	63.469352999999998	0103000020E610000001000000050000008C15359886E34440C6A354C213BC4F408C15359886E344401CB3EC4960BD4F40D462F030EDE544401CB3EC4960BD4F40D462F030EDE54440C6A354C213BC4F408C15359886E34440C6A354C213BC4F40
17477	Демидово	3	26	1487	41.591062999999998	41.602598	64.201181000000005	64.196862999999993	0103000020E610000001000000050000001570CFF3A7CB4440B7B24467990C50401570CFF3A7CB4440E7E44526E00C5040485167EE21CD4440E7E44526E00C5040485167EE21CD4440B7B24467990C50401570CFF3A7CB4440B7B24467990C5040
19287	Двинской	3	26	1487	42.010083000000002	42.032755999999999	63.354317000000002	63.340355000000002	0103000020E610000001000000050000006F9F55664A014540DA03ADC090AB4F406F9F55664A0145405BB56B425AAD4F40B75F3E59310445405BB56B425AAD4F40B75F3E5931044540DA03ADC090AB4F406F9F55664A014540DA03ADC090AB4F40
19068	Горка-Рудаковская	3	26	1487	41.698807000000002	41.715282000000002	63.458672	63.454667999999998	0103000020E61000000100000005000000A29BFD8172D94440D4449F8F32BA4F40A29BFD8172D94440A3CB9BC3B5BA4F4070B54E5C8EDB4440A3CB9BC3B5BA4F4070B54E5C8EDB4440D4449F8F32BA4F40A29BFD8172D94440D4449F8F32BA4F40
57510	Горка-Кузнечевская	3	26	1487	40.638095	43.679296000000001	64.733295999999996	62.888195000000003	0103000020E61000000100000005000000DD5ED218AD51444041BCAE5FB0714F40DD5ED218AD51444068925852EE2E5040DD26DC2BF3D6454068925852EE2E5040DD26DC2BF3D6454041BCAE5FB0714F40DD5ED218AD51444041BCAE5FB0714F40
17979	Горка	3	26	1487	41.683653	41.706631999999999	64.181596999999996	64.176355000000001	0103000020E61000000100000005000000F96706F181D744401C5F7B66490B5040F96706F181D744404F0306499F0B50404E27D9EA72DA44404F0306499F0B50404E27D9EA72DA44401C5F7B66490B5040F96706F181D744401C5F7B66490B5040
19126	Верхняя Горка	3	26	1487	41.768282999999997	41.778506	63.445843000000004	63.440919999999998	0103000020E610000001000000050000005089EB1857E244407F130A1170B84F405089EB1857E244404513286211B94F40B1DEA815A6E344404513286211B94F40B1DEA815A6E344407F130A1170B84F405089EB1857E244407F130A1170B84F40
17181	Васильевская	3	26	1487	41.067425999999998	41.071559000000001	64.324732999999995	64.323115999999999	0103000020E610000001000000050000003673486AA18844401E34BBEEAD1450403673486AA1884440A5BBEB6CC8145040035E66D828894440A5BBEB6CC8145040035E66D8288944401E34BBEEAD1450403673486AA18844401E34BBEEAD145040
57501	Ваймужский	3	26	1487	40.638095	43.679296000000001	64.733295999999996	62.888195000000003	0103000020E61000000100000005000000DD5ED218AD51444041BCAE5FB0714F40DD5ED218AD51444068925852EE2E5040DD26DC2BF3D6454068925852EE2E5040DD26DC2BF3D6454041BCAE5FB0714F40DD5ED218AD51444041BCAE5FB0714F40
57503	Бушковы	3	26	1487	40.638095	43.679296000000001	64.733295999999996	62.888195000000003	0103000020E61000000100000005000000DD5ED218AD51444041BCAE5FB0714F40DD5ED218AD51444068925852EE2E5040DD26DC2BF3D6454068925852EE2E5040DD26DC2BF3D6454041BCAE5FB0714F40DD5ED218AD51444041BCAE5FB0714F40
18586	Брин-Наволок	3	26	1487	41.409728999999999	41.435510999999998	63.743307000000001	63.723343	0103000020E61000000100000005000000849CF7FF71B444403065E08096DC4F40849CF7FF71B44440A6F10BAF24DF4F402D060FD3BEB74440A6F10BAF24DF4F402D060FD3BEB744403065E08096DC4F40849CF7FF71B444403065E08096DC4F40
17743	Боярская	3	26	1487	41.839708000000002	41.859856999999998	64.228092000000004	64.223761999999994	0103000020E6100000010000000500000044183F8D7BEB44409A05DA1D520E504044183F8D7BEB4440AC1E300F990E50404B1E4FCB0FEE4440AC1E300F990E50404B1E4FCB0FEE44409A05DA1D520E504044183F8D7BEB44409A05DA1D520E5040
18673	Большая Гора	3	26	1487	41.60284	41.623699000000002	63.630521999999999	63.620145000000001	0103000020E610000001000000050000003E5C72DC29CD444093E34EE960CF4F403E5C72DC29CD44404AB4E4F1B4D04F4022C66B5ED5CF44404AB4E4F1B4D04F4022C66B5ED5CF444093E34EE960CF4F403E5C72DC29CD444093E34EE960CF4F40
18095	Белогорский	3	26	1487	42.319543000000003	42.357084	64.196854999999999	64.179716999999997	0103000020E610000001000000050000003755F7C8E62845404162BB7B800B50403755F7C8E628454076C3B645990C504062F6B2EDB42D454076C3B645990C504062F6B2EDB42D45404162BB7B800B50403755F7C8E62845404162BB7B800B5040
17338	Анашкино	3	26	1487	41.516584000000002	41.523204999999997	64.270900999999995	64.264617999999999	0103000020E6100000010000000500000085D1AC6C1FC24440B5FB5580EF10504085D1AC6C1FC2444009DD257156115040450DA661F8C2444009DD257156115040450DA661F8C24440B5FB5580EF10504085D1AC6C1FC24440B5FB5580EF105040
57515	д.Левоплосская	3	26	1387	42.785293000000003	45.362046999999997	61.864997000000002	60.729216000000001	0103000020E610000001000000050000008D63247B8464454027DC2BF3565D4E408D63247B84644540AE11C138B8EE4E40B54E5C8E57AE4640AE11C138B8EE4E40B54E5C8E57AE464027DC2BF3565D4E408D63247B8464454027DC2BF3565D4E40
15871	Юрятинская	3	26	1387	43.369467	43.392859000000001	61.138117000000001	61.132376000000001	0103000020E61000000100000005000000C2F9D4B14AAF45403D635FB2F1904E40C2F9D4B14AAF4540C5025FD1AD914E403A78263449B24540C5025FD1AD914E403A78263449B245403D635FB2F1904E40C2F9D4B14AAF45403D635FB2F1904E40
16718	Шурай	3	26	1387	43.645367	43.677194	61.043044999999999	61.032471999999999	0103000020E610000001000000050000007575C7629BD245409204E10A28844E407575C7629BD24540CFA0A17F82854E401286014BAED64540CFA0A17F82854E401286014BAED645409204E10A28844E407575C7629BD245409204E10A28844E40
15947	Шангалы	3	26	1387	43.324452999999998	43.344583999999998	61.136476000000002	61.12247	0103000020E61000000100000005000000670B08AD87A94540DD5ED218AD8F4E40670B08AD87A945402E58AA0B78914E40C85C19541BAC45402E58AA0B78914E40C85C19541BAC4540DD5ED218AD8F4E40670B08AD87A94540DD5ED218AD8F4E40
16262	Чадрома	3	26	1387	42.894429000000002	42.906314000000002	61.205556999999999	61.195335999999998	0103000020E6100000010000000500000008CC43A67C724540A0DD21C500994E4008CC43A67C724540603B18B14F9A4E4017F4DE1802744540603B18B14F9A4E4017F4DE1802744540A0DD21C500994E4008CC43A67C724540A0DD21C500994E40
16650	Филинская	3	26	1387	43.007949000000004	43.024845999999997	60.811131000000003	60.805925999999999	0103000020E6100000010000000500000099840B7904814540807F4A9528674E4099840B7904814540CAE2FE23D3674E40DCB75A272E834540CAE2FE23D3674E40DCB75A272E834540807F4A9528674E4099840B7904814540807F4A9528674E40
16567	Ульяновская	3	26	1387	43.105874999999997	43.115442000000002	60.891995999999999	60.885525999999999	0103000020E61000000100000005000000643BDF4F8D8D4540FCE07CEA58714E40643BDF4F8D8D4540D714C8EC2C724E40DC4AAFCDC68E4540D714C8EC2C724E40DC4AAFCDC68E4540FCE07CEA58714E40643BDF4F8D8D4540FCE07CEA58714E40
15511	Студенец	3	26	1387	43.713872000000002	43.745789000000002	61.478033000000003	61.471885	0103000020E61000000100000005000000DBC35E2860DB45408A3C49BA66BC4E40DBC35E2860DB454053B4722F30BD4E40B85B920376DF454053B4722F30BD4E40B85B920376DF45408A3C49BA66BC4E40DBC35E2860DB45408A3C49BA66BC4E40
15610	Строевское	3	26	1387	43.695556000000003	43.722324999999998	61.410606999999999	61.397404000000002	0103000020E61000000100000005000000AF44A0FA07D9454059A65F22DEB24E40AF44A0FA07D945401C412AC58EB44E40A60A462575DC45401C412AC58EB44E40A60A462575DC454059A65F22DEB24E40AF44A0FA07D9454059A65F22DEB24E40
16025	Советский	3	26	1387	43.272728000000001	43.294575000000002	61.115969	61.105536999999998	0103000020E610000001000000050000000C5A48C0E8A245404CC2853C828D4E400C5A48C0E8A24540C72C7B12D88E4E400F9C33A2B4A54540C72C7B12D88E4E400F9C33A2B4A545404CC2853C828D4E400C5A48C0E8A245404CC2853C828D4E40
16126	Октябрьский	3	26	1387	43.135734999999997	43.199137999999998	61.101381000000003	61.079858999999999	0103000020E6100000010000000500000016F6B4C35F91454048A5D8D1388A4E4016F6B4C35F914540C8B7770DFA8C4E4007B29E5A7D994540C8B7770DFA8C4E4007B29E5A7D99454048A5D8D1388A4E4016F6B4C35F91454048A5D8D1388A4E40
15852	Нижнеборская	3	26	1387	43.367949000000003	43.386040999999999	61.100136999999997	61.090060999999999	0103000020E6100000010000000500000047CCECF318AF454091D26C1E878B4E4047CCECF318AF45404D0F0A4AD18C4E4023F59ECA69B145404D0F0A4AD18C4E4023F59ECA69B1454091D26C1E878B4E4047CCECF318AF454091D26C1E878B4E40
16557	Нагорская	3	26	1387	43.178556999999998	43.199928	60.925164000000002	60.916728999999997	0103000020E6100000010000000500000066BCADF4DA964540BB25396057754E4066BCADF4DA964540E1B721C66B764E4000C79E3D97994540E1B721C66B764E4000C79E3D97994540BB25396057754E4066BCADF4DA964540BB25396057754E40
17083	Мирный	3	26	1387	44.526910000000001	44.552152999999997	61.338766999999997	61.328111	0103000020E61000000100000005000000BAF770C9714346409B3A8F8AFFA94E40BAF770C97143464065FB90B75CAB4E40B3B112F3AC46464065FB90B75CAB4E40B3B112F3AC4646409B3A8F8AFFA94E40BAF770C9714346409B3A8F8AFFA94E40
16394	Маренинская	3	26	1387	43.417779000000003	43.430660000000003	60.938640999999997	60.932181	0103000020E6100000010000000500000051FA42C879B54540EE79FEB451774E4051FA42C879B54540A5D7666325784E4002D9EBDD1FB74540A5D7666325784E4002D9EBDD1FB74540EE79FEB451774E4051FA42C879B54540EE79FEB451774E40
57525	Малый Дор	3	26	1387	43.286462999999998	43.299812000000003	61.033208000000002	61.025682000000003	0103000020E61000000100000005000000CC41D0D1AAA44540460C3B8C49834E40CC41D0D1AAA4454098FBE42840844E406479573D60A6454098FBE42840844E406479573D60A64540460C3B8C49834E40CC41D0D1AAA44540460C3B8C49834E40
16430	Малодоры	3	26	1387	43.326104999999998	43.348284999999997	60.966180999999999	60.958455000000001	0103000020E61000000100000005000000F20703CFBDA9454006D847A7AE7A4E40F20703CFBDA945401F82AAD1AB7B4E40FB57569A94AC45401F82AAD1AB7B4E40FB57569A94AC454006D847A7AE7A4E40F20703CFBDA9454006D847A7AE7A4E40
16842	Лойга	3	26	1387	44.589253999999997	44.628473999999997	61.086311000000002	61.071359999999999	0103000020E61000000100000005000000C284D1AC6C4B46400C1F115322894E40C284D1AC6C4B46407D24253D0C8B4E40723106D6715046407D24253D0C8B4E40723106D6715046400C1F115322894E40C284D1AC6C4B46400C1F115322894E40
16078	Костылево	3	26	1387	43.201599000000002	43.256036999999999	61.074437000000003	61.064723000000001	0103000020E6100000010000000500000002F4FBFECD9945404626E0D748884E4002F4FBFECD994540624ED02687894E4071C806D2C5A04540624ED02687894E4071C806D2C5A045404626E0D748884E4002F4FBFECD9945404626E0D748884E40
16894	Кизема	3	26	1387	44.782805000000003	44.842784999999999	61.133014000000003	61.092804999999998	0103000020E61000000100000005000000991249F432644640E0F3C308E18B4E40991249F43264464080F44D9A06914E409947FE60E06B464080F44D9A06914E409947FE60E06B4640E0F3C308E18B4E40991249F432644640E0F3C308E18B4E40
17137	Кидюга	3	26	1387	44.938077999999997	44.954211999999998	61.461188	61.451132999999999	0103000020E610000001000000050000006D8C9DF012784640BC92E4B9BEB94E406D8C9DF01278464061A7583508BB4E40B2B96A9E237A464061A7583508BB4E40B2B96A9E237A4640BC92E4B9BEB94E406D8C9DF012784640BC92E4B9BEB94E40
15217	Квазеньга	3	26	1387	44.262455000000003	44.293340000000001	61.489522999999998	61.47625	0103000020E61000000100000005000000FAD51C2098214640295C8FC2F5BC4E40FAD51C2098214640E5D18DB0A8BE4E40E84D452A8C254640E5D18DB0A8BE4E40E84D452A8C254640295C8FC2F5BC4E40FAD51C2098214640295C8FC2F5BC4E40
15304	Кадыевская	3	26	1387	44.168393000000002	44.181058999999998	61.548282999999998	61.537222999999997	0103000020E610000001000000050000000BF0DDE68D1546405AD427B9C3C44E400BF0DDE68D154640F4F928232EC64E40BFD2F9F02C174640F4F928232EC64E40BFD2F9F02C1746405AD427B9C3C44E400BF0DDE68D1546405AD427B9C3C44E40
16739	Илеза	3	26	1387	43.865723000000003	43.918751	61.063882	61.038775999999999	0103000020E610000001000000050000009032E202D0EE454052EFA99CF6844E409032E202D0EE4540CB660E492D884E406A15FDA199F54540CB660E492D884E406A15FDA199F5454052EFA99CF6844E409032E202D0EE454052EFA99CF6844E40
15644	Едьма	3	26	1387	43.701979000000001	43.718426999999998	61.314138999999997	61.304307999999999	0103000020E6100000010000000500000049BDA772DAD94540A1F48590F3A64E4049BDA772DAD94540F6B2EDB435A84E401DC87A6AF5DB4540F6B2EDB435A84E401DC87A6AF5DB4540A1F48590F3A64E4049BDA772DAD94540A1F48590F3A64E40
15731	Дубровская	3	26	1387	43.623618999999998	43.637281999999999	61.172066000000001	61.163054000000002	0103000020E61000000100000005000000051555BFD2CF4540B2BD16F4DE944E40051555BFD2CF45407460394206964E402C2AE27492D145407460394206964E402C2AE27492D14540B2BD16F4DE944E40051555BFD2CF4540B2BD16F4DE944E40
15551	Грунцовская	3	26	1387	43.603819999999999	43.615102	61.434153000000002	61.428246000000001	0103000020E61000000100000005000000DA5548F949CD45404852D2C3D0B64E40DA5548F949CD4540EB3A545392B74E4023DA8EA9BBCE4540EB3A545392B74E4023DA8EA9BBCE45404852D2C3D0B64E40DA5548F949CD45404852D2C3D0B64E40
15355	Глубокий	3	26	1387	43.996617000000001	44.054262000000001	61.583458	61.56467	0103000020E610000001000000050000009ED1562591FF45402384471B47C84E409ED1562591FF4540774B72C0AECA4E4031B5A50EF2064640774B72C0AECA4E4031B5A50EF20646402384471B47C84E409ED1562591FF45402384471B47C84E40
15411	Веригинская	3	26	1387	43.199765999999997	43.207501000000001	60.895178000000001	60.890870999999997	0103000020E61000000100000005000000266DAAEE9199454037FA980F08724E40266DAAEE91994540A20C553195724E4093718C648F9A4540A20C553195724E4093718C648F9A454037FA980F08724E40266DAAEE9199454037FA980F08724E40
15706	Березник	3	26	1387	43.611427999999997	43.630885999999997	61.240262999999999	61.227373	0103000020E61000000100000005000000E9EDCF4543CE4540287FF78E1A9D4E40E9EDCF4543CE45402CB81FF0C09E4E408BC058DFC0D045402CB81FF0C09E4E408BC058DFC0D04540287FF78E1A9D4E40E9EDCF4543CE4540287FF78E1A9D4E40
17045	Алферовская	3	26	1387	44.688930999999997	44.705271000000003	61.238323999999999	61.230600000000003	0103000020E61000000100000005000000AC1919E42E584640933A014D849D4E40AC1919E42E5846400BED9C66819E4E409BE8F351465A46400BED9C66819E4E409BE8F351465A4640933A014D849D4E40AC1919E42E584640933A014D849D4E40
57545	Соловецкий	3	26	7432	35.502201999999997	35.880589999999998	65.172982000000005	64.954785999999999	0103000020E610000001000000050000002EFEB62748C041406F2BBD361B3D50402EFEB62748C04140FD321823124B5040A297512CB7F04140FD321823124B5040A297512CB7F041406F2BBD361B3D50402EFEB62748C041406F2BBD361B3D5040
11974	Яреньга	3	26	1176	37.932952999999998	37.948160999999999	64.881808000000007	64.873354000000006	0103000020E6100000010000000500000040DAFF006BF742402CF52C08E537504040DAFF006BF742407A56D28A6F385040DC2BF3565DF942407A56D28A6F385040DC2BF3565DF942402CF52C08E537504040DAFF006BF742402CF52C08E5375040
57491	Ширшинский	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
11691	Хорьково	3	26	1176	41.020346000000004	41.031934	64.384479999999996	64.377841000000004	0103000020E610000001000000050000005E4D9EB29A824440A185048C2E1850405E4D9EB29A824440D47D00529B185040B3D0CE6916844440D47D00529B185040B3D0CE6916844440A185048C2E1850405E4D9EB29A824440A185048C2E185040
11490	Уемский	3	26	1176	40.783791999999998	40.897824999999997	64.489351999999997	64.462114	0103000020E61000000100000005000000E76ED74B5364444085419946931D5040E76ED74B53644440DC0E0D8B511F5040FE43FAEDEB724440DC0E0D8B511F5040FE43FAEDEB72444085419946931D5040E76ED74B5364444085419946931D5040
57476	Талаги	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
57472	Талаги	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
11199	Рикасиха	3	26	1176	40.156165999999999	40.193527000000003	64.544839999999994	64.535889999999995	0103000020E61000000100000005000000A25F5B3FFD134440381092054C225040A25F5B3FFD1344405E6397A8DE2250404EF2237EC51844405E6397A8DE2250404EF2237EC5184440381092054C225040A25F5B3FFD134440381092054C225040
12058	Пушлахта	3	26	1176	36.564289000000002	36.588749999999997	64.814147000000006	64.805364999999995	0103000020E610000001000000050000000C3F389F3A484240F415A4198B3350400C3F389F3A484240BDC804FC1A3450408FC2F5285C4B4240BDC804FC1A3450408FC2F5285C4B4240F415A4198B3350400C3F389F3A484240F415A4198B335040
57478	Пустошь	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
28114	Пертоминск	3	26	1176	38.396762000000003	38.425579999999997	64.800704999999994	64.788030000000006	0103000020E61000000100000005000000D525E318C9324340159161156F325040D525E318C9324340982F2FC03E33504074EACA6779364340982F2FC03E33504074EACA6779364340159161156F325040D525E318C9324340159161156F325040
12401	Патракеевка	3	26	1176	40.371924	40.39987	64.967354999999998	64.961360999999997	0103000020E610000001000000050000007B4CA4349B2F444097A949F0863D50407B4CA4349B2F4440D027F224E93D50406553AEF02E334440D027F224E93D50406553AEF02E33444097A949F0863D50407B4CA4349B2F444097A949F0863D5040
57485	Окулово	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
11634	Новинки	3	26	1176	41.022421000000001	41.035257999999999	64.387707000000006	64.382504999999995	0103000020E610000001000000050000002FDFFAB0DE8244409D6340F67A1850402FDFFAB0DE8244408A5B0531D018504010768A55838444408A5B0531D018504010768A55838444409D6340F67A1850402FDFFAB0DE8244409D6340F67A185040
12291	Нижняя Золотица	3	26	1176	40.168427999999999	40.188927999999997	65.696826000000001	65.685342000000006	0103000020E6100000010000000500000087DD770C8F154440D124B1A4DC6B504087DD770C8F154440294014CC986C50403BA6EECA2E184440294014CC986C50403BA6EECA2E184440D124B1A4DC6B504087DD770C8F154440D124B1A4DC6B5040
57481	Ненокса	3	26	1176	39.170993000000003	39.235052000000003	64.637088000000006	64.613465000000005	0103000020E61000000100000005000000276C3F19E3954340670FB40243275040276C3F19E3954340242BBF0CC6285040016E162F169E4340242BBF0CC6285040016E162F169E4340670FB40243275040276C3F19E3954340670FB40243275040
11888	Луда	3	26	1176	38.145575000000001	38.172272999999997	64.650496000000004	64.639126000000005	0103000020E61000000100000005000000BF0E9C33A21243407E01BD70E7285040BF0E9C33A2124340728BF9B9A1295040ED7DAA0A0D164340728BF9B9A1295040ED7DAA0A0D1643407E01BD70E7285040BF0E9C33A21243407E01BD70E7285040
57495	Луговой	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
11906	Лопшеньга	3	26	1176	37.684190999999998	37.696328000000001	64.978567999999996	64.966001000000006	0103000020E61000000100000005000000D89B189293D74240D0B9DBF5D23D5040D89B189293D74240603AADDBA03E504001A5A14621D94240603AADDBA03E504001A5A14621D94240D0B9DBF5D23D5040D89B189293D74240D0B9DBF5D23D5040
12055	Летняя Золотица	3	26	1176	36.819284000000003	36.846395999999999	64.955472	64.945802999999998	0103000020E610000001000000050000006B11514CDE6842405B5D4E09883C50406B11514CDE684240990F0874263D50408CBB41B4566C4240990F0874263D50408CBB41B4566C42405B5D4E09883C50406B11514CDE6842405B5D4E09883C5040
57479	Лахта	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
12696	Ластола	3	26	1176	40.273009999999999	40.295862999999997	64.602514999999997	64.594436000000002	0103000020E6100000010000000500000090BDDEFDF12244402AE44A3D0B26504090BDDEFDF12244405D16139B8F265040588CBAD6DE2544405D16139B8F265040588CBAD6DE2544402AE44A3D0B26504090BDDEFDF12244402AE44A3D0B265040
11164	Лайский Док	3	26	1176	40.245531	40.259059000000001	64.541593000000006	64.531129000000007	0103000020E61000000100000005000000BC934F8F6D1F4440433D7D04FE215040BC934F8F6D1F444086AFAF75A9225040035E66D82821444086AFAF75A9225040035E66D828214440433D7D04FE215040BC934F8F6D1F4440433D7D04FE215040
11540	Кузьмино	3	26	1176	40.946998000000001	40.966887	64.385553000000002	64.380891000000005	0103000020E610000001000000050000004FB0FF3A37794440CF15A584601850404FB0FF3A37794440FB777DE6AC185040BAF605F4C27B4440FB777DE6AC185040BAF605F4C27B4440CF15A584601850404FB0FF3A37794440CF15A58460185040
12747	Конецдворье	3	26	1176	40.223531000000001	40.237796000000003	64.573370999999995	64.567824000000002	0103000020E610000001000000050000003352EFA99C1C44409278793A572450403352EFA99C1C4440635E471CB2245040508F6D19701E4440635E471CB2245040508F6D19701E44409278793A572450403352EFA99C1C44409278793A57245040
57482	Вознесенье	3	26	1176	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
12210	Верхняя Золотица	3	26	1176	40.348253	40.385713000000003	65.692717000000002	65.685879	0103000020E61000000100000005000000F0DDE68D932C4440D8800871E56B5040F0DDE68D932C44408718AF79556C50402F52280B5F3144408718AF79556C50402F52280B5F314440D8800871E56B5040F0DDE68D932C4440D8800871E56B5040
11744	Боброво	3	26	1176	41.135410999999998	41.206575000000001	64.359110999999999	64.350791999999998	0103000020E610000001000000050000006342CC2555914440B3EC4960731650406342CC25559144409128B4ACFB165040EA95B20C719A44409128B4ACFB165040EA95B20C719A4440B3EC4960731650406342CC2555914440B3EC496073165040
12667	Беломорье	3	26	1176	40.884780999999997	40.896756000000003	64.295833000000002	64.290987000000001	0103000020E61000000100000005000000A38FF98040714440EA23F0879F125040A38FF98040714440F70489EDEE125040F33E8EE6C8724440F70489EDEE125040F33E8EE6C8724440EA23F0879F125040A38FF98040714440EA23F0879F125040
57505	Белое Озеро	3	26	1176	39.828156	39.853569	64.273625999999993	64.262281999999999	0103000020E610000001000000050000003BFE0B0401EA43401615713AC91050403BFE0B0401EA43407555A0168311504091F0BDBF41ED43407555A0168311504091F0BDBF41ED43401615713AC91050403BFE0B0401EA43401615713AC9105040
9833	Шелекса	3	26	1059	40.293320999999999	40.319893	62.901314999999997	62.889687000000002	0103000020E61000000100000005000000711DE38A8B25444093567C43E1714F40711DE38A8B2544407632384A5E734F40139CFA40F22844407632384A5E734F40139CFA40F228444093567C43E1714F40711DE38A8B25444093567C43E1714F40
10581	Федово	3	26	1059	39.820411999999997	39.836528000000001	62.399057999999997	62.390596000000002	0103000020E610000001000000050000007B9FAA4203E9434066F9BA0CFF314F407B9FAA4203E94340849A215514334F401A18795913EB4340849A215514334F401A18795913EB434066F9BA0CFF314F407B9FAA4203E9434066F9BA0CFF314F40
37053	Усть-Поча	3	26	1059	38.152051999999998	38.177653999999997	62.163496000000002	62.150323999999998	0103000020E610000001000000050000004CA59F7076134340E6E61BD13D134F404CA59F70761343406F83DA6FED144F407500C45DBD1643406F83DA6FED144F407500C45DBD164340E6E61BD13D134F404CA59F7076134340E6E61BD13D134F40
11019	Ундозеро	3	26	1059	38.810409	38.841661999999999	62.695112999999999	62.685665999999998	0103000020E6100000010000000500000029B16B7BBB67434054FD4AE7C3574F4029B16B7BBB67434021037976F9584F409A249694BB6B434021037976F9584F409A249694BB6B434054FD4AE7C3574F4029B16B7BBB67434054FD4AE7C3574F40
11079	Улитино	3	26	1059	39.314517000000002	39.332797999999997	62.985284	62.963453000000001	0103000020E610000001000000050000009D84D21742A84340D61D8B6D527B4F409D84D21742A84340D3A23EC91D7E4F404C16F71F99AA4340D3A23EC91D7E4F404C16F71F99AA4340D61D8B6D527B4F409D84D21742A84340D61D8B6D527B4F40
10460	Североонежск	3	26	1059	39.838917000000002	39.856766999999998	62.594847000000001	62.587463	0103000020E610000001000000050000007B87DBA161EB4340164ED2FC314B4F407B87DBA161EB4340D68F4DF2234C4F4061A5828AAAED4340D68F4DF2234C4F4061A5828AAAED4340164ED2FC314B4F407B87DBA161EB4340164ED2FC314B4F40
57470	Самодед	3	26	1059	40.456958	40.544966000000002	63.619430000000001	63.594582000000003	0103000020E61000000100000005000000A2D288997D3A4440286552431BCC4F40A2D288997D3A4440A514747B49CF4F404AB72572C1454440A514747B49CF4F404AB72572C1454440286552431BCC4F40A2D288997D3A4440286552431BCC4F40
10864	Самково	3	26	1059	38.682220000000001	38.704946999999997	62.150820000000003	62.139487000000003	0103000020E61000000100000005000000AC5626FC52574340CC9BC3B5DA114F40AC5626FC5257434097CADB114E134F40E7340BB43B5A434097CADB114E134F40E7340BB43B5A4340CC9BC3B5DA114F40AC5626FC52574340CC9BC3B5DA114F40
9595	Савинский	3	26	1059	40.109453999999999	40.159706	62.941800999999998	62.924940999999997	0103000020E610000001000000050000004C35B396020E444061DD787764764F404C35B396020E4440882B67EF8C784F40CC7C073F71144440882B67EF8C784F40CC7C073F7114444061DD787764764F404C35B396020E444061DD787764764F40
9748	Река-Емца	3	26	1059	40.292315000000002	40.313820999999997	62.967260000000003	62.960791	0103000020E61000000100000005000000AC90F2936A25444044A51133FB7A4F40AC90F2936A2544404F5DF92CCF7B4F4025E659492B2844404F5DF92CCF7B4F4025E659492B28444044A51133FB7A4F40AC90F2936A25444044A51133FB7A4F40
10295	Пуксоозеро	3	26	1059	40.582031000000001	40.634034	62.610411999999997	62.574742000000001	0103000020E610000001000000050000000C21E7FD7F4A44409ED1562591494F400C21E7FD7F4A4440008BFCFA214E4F40AA46AF0628514440008BFCFA214E4F40AA46AF06285144409ED1562591494F400C21E7FD7F4A44409ED1562591494F40
10155	Пукса	3	26	1059	40.296348999999999	40.332928000000003	62.610002000000001	62.594487000000001	0103000020E61000000100000005000000E59997C3EE254440D6726726184C4F40E59997C3EE2544404F3FA88B144E4F401BF67B629D2A44404F3FA88B144E4F401BF67B629D2A4440D6726726184C4F40E59997C3EE254440D6726726184C4F40
10944	Поча	3	26	1059	38.164969999999997	38.189304999999997	62.200890000000001	62.187176000000001	0103000020E610000001000000050000001A69A9BC1D1543404D4C1762F5174F401A69A9BC1D154340F60B76C3B6194F4011FC6F253B184340F60B76C3B6194F4011FC6F253B1843404D4C1762F5174F401A69A9BC1D1543404D4C1762F5174F40
10208	Подволочье	3	26	1059	41.153638000000001	41.174137000000002	62.817571999999998	62.810980000000001	0103000020E6100000010000000500000020B6F468AA934440E4DA5031CE674F4020B6F468AA9344400A100533A6684F400403081F4A9644400A100533A6684F400403081F4A964440E4DA5031CE674F4020B6F468AA934440E4DA5031CE674F40
9872	Плесецк	3	26	1059	40.254882000000002	40.325794999999999	62.728395999999996	62.693742999999998	0103000020E61000000100000005000000672B2FF99F2044401A6A1492CC584F40672B2FF99F204440C34483143C5D4F40A4198BA6B3294440C34483143C5D4F40A4198BA6B32944401A6A1492CC584F40672B2FF99F2044401A6A1492CC584F40
57492	Первомайский	3	26	1059	40.023764	40.035397000000003	63.587093000000003	63.581578	0103000020E610000001000000050000003C69E1B20A0344405B09DD2571CA4F403C69E1B20A034440F35A09DD25CB4F4032B08EE387044440F35A09DD25CB4F4032B08EE3870444405B09DD2571CA4F403C69E1B20A0344405B09DD2571CA4F40
10373	Оксовский	3	26	1059	39.902858999999999	39.922317	62.605719000000001	62.596784999999997	0103000020E610000001000000050000001BF33AE290F3434026DF6C73634C4F401BF33AE290F343406DC83F33884D4F40BDC5C37B0EF643406DC83F33884D4F40BDC5C37B0EF6434026DF6C73634C4F401BF33AE290F3434026DF6C73634C4F40
9343	Обозерский	3	26	1059	40.276297999999997	40.323045999999998	63.465926000000003	63.429065000000001	0103000020E61000000100000005000000A0F99CBB5D234440DB6D179AEBB64F40A0F99CBB5D234440952D9276A3BB4F40438D429259294440952D9276A3BB4F40438D429259294440DB6D179AEBB64F40A0F99CBB5D234440DB6D179AEBB64F40
10998	Нижнее Устье	3	26	1059	38.217646999999999	38.234616000000003	62.335828999999997	62.327232000000002	0103000020E6100000010000000500000048895DDBDB1B4340331AF9BCE2294F4048895DDBDB1B43403106D671FC2A4F40268FA7E5071E43403106D671FC2A4F40268FA7E5071E4340331AF9BCE2294F4048895DDBDB1B4340331AF9BCE2294F40
57517	Ломовое	3	26	1059	40.630395999999998	40.666804999999997	64.017965000000004	64.004492999999997	0103000020E61000000100000005000000BDC3EDD0B0504440E603029D49005040BDC3EDD0B050444040DEAB562601504096E7C1DD5955444040DEAB562601504096E7C1DD59554440E603029D49005040BDC3EDD0B0504440E603029D49005040
10652	Липаково	3	26	1059	39.681964000000001	39.704179000000003	62.409754999999997	62.402892000000001	0103000020E610000001000000050000005186AA984AD74340F7E80DF791334F405186AA984AD74340AD2F12DA72344F40D7C3978922DA4340AD2F12DA72344F40D7C3978922DA4340F7E80DF791334F405186AA984AD74340F7E80DF791334F40
9430	Летнеозерский	3	26	1059	40.333314000000001	40.374420999999998	63.407223999999999	63.367488999999999	0103000020E6100000010000000500000044A67C08AA2A4440E3512AE109AF4F4044A67C08AA2A4440BA1281EA1FB44F40C2F7FE06ED2F4440BA1281EA1FB44F40C2F7FE06ED2F4440E3512AE109AF4F4044A67C08AA2A4440E3512AE109AF4F40
10826	Корякино	3	26	1059	38.868656000000001	38.894635000000001	62.105187000000001	62.100797	0103000020E61000000100000005000000B2BCAB1E306F4340784485EAE60C4F40B2BCAB1E306F4340707B82C4760D4F40B16D516683724340707B82C4760D4F40B16D516683724340784485EAE60C4F40B2BCAB1E306F4340784485EAE60C4F40
10729	Конево	3	26	1059	39.306548999999997	39.345185000000001	62.135821	62.113553000000003	0103000020E610000001000000050000008DCF64FF3CA743406DAE9AE7880E4F408DCF64FF3CA74340158E209562114F40EE08A7052FAC4340158E209562114F40EE08A7052FAC43406DAE9AE7880E4F408DCF64FF3CA743406DAE9AE7880E4F40
10745	Коковка	3	26	1059	39.461212000000003	39.476258999999999	62.249256000000003	62.241304999999997	0103000020E61000000100000005000000EA42ACFE08BB43403EAE0D15E31E4F40EA42ACFE08BB4340782AE09EE71F4F407CB60E0EF6BC4340782AE09EE71F4F407CB60E0EF6BC43403EAE0D15E31E4F40EA42ACFE08BB43403EAE0D15E31E4F40
9556	Емца	3	26	1059	40.313982000000003	40.355618999999997	63.087878000000003	63.062154999999997	0103000020E610000001000000050000002FC4EA8F302844403524EEB1F4874F402FC4EA8F30284440DA0418963F8B4F40096B63EC842D4440DA0418963F8B4F40096B63EC842D44403524EEB1F4874F402FC4EA8F302844403524EEB1F4874F40
10891	Вершинино	3	26	1059	38.189574999999998	38.209238999999997	62.083351	62.075743000000003	0103000020E61000000100000005000000D1915CFE4318434052F355F2B1094F40D1915CFE43184340618BDD3EAB0A4F401C06F357C81A4340618BDD3EAB0A4F401C06F357C81A434052F355F2B1094F40D1915CFE4318434052F355F2B1094F40
37018	Верховский	3	26	1059	40.110827999999998	40.130249999999997	63.196488000000002	63.185513	0103000020E6100000010000000500000094BDA59C2F0E4440CEFDD5E3BE974F4094BDA59C2F0E44403A07CF8426994F40E9263108AC1044403A07CF8426994F40E9263108AC104440CEFDD5E3BE974F4094BDA59C2F0E4440CEFDD5E3BE974F40
10448	Булатово	3	26	1059	39.976261000000001	39.993724	62.618597000000001	62.611699000000002	0103000020E610000001000000050000001DAED51EF6FC43407AFF1F274C4E4F401DAED51EF6FC4340AD33BE2F2E4F4F400AA0185932FF4340AD33BE2F2E4F4F400AA0185932FF43407AFF1F274C4E4F401DAED51EF6FC43407AFF1F274C4E4F40
57514	Бархатиха	3	26	1059	37.252749000000001	42.003892999999998	64.135502000000002	61.751499000000003	0103000020E61000000100000005000000618C48145AA0424005FD851E31E04E40618C48145AA04240BAA29410AC08504077D7D9907F004540BAA29410AC08504077D7D9907F00454005FD851E31E04E40618C48145AA0424005FD851E31E04E40
57486	дер.Кушкопала	3	26	904	41.756793999999999	47.233984	65.274698000000001	63.067297000000003	0103000020E610000001000000050000008EE733A0DEE04440390F27309D884F408EE733A0DEE04440B491EBA694515040C5E40D30F39D4740B491EBA694515040C5E40D30F39D4740390F27309D884F408EE733A0DEE04440390F27309D884F40
8449	Ясный	3	26	904	44.060847000000003	44.095278999999998	64.041231999999994	64.030631	0103000020E61000000100000005000000A587A1D5C90746409ACFB9DBF5015040A587A1D5C90746401DE38A8BA30250406F7F2E1A320C46401DE38A8BA30250406F7F2E1A320C46409ACFB9DBF5015040A587A1D5C90746409ACFB9DBF5015040
7584	Явзора	3	26	904	45.411940000000001	45.424973999999999	63.717975000000003	63.700943000000002	0103000020E6100000010000000500000006F52D73BAB4464019AE0E80B8D94F4006F52D73BAB446403D2CD49AE6DB4F403DD34B8C65B646403D2CD49AE6DB4F403DD34B8C65B6464019AE0E80B8D94F4006F52D73BAB4464019AE0E80B8D94F40
7299	Шуйга	3	26	904	45.681353000000001	45.706541999999999	63.526772000000001	63.514203000000002	0103000020E6100000010000000500000008043A9336D74640A7406667D1C14F4008043A9336D746406939D0436DC34F400EA0DFF76FDA46406939D0436DC34F400EA0DFF76FDA4640A7406667D1C14F4008043A9336D74640A7406667D1C14F40
8581	Шотогорка	3	26	904	44.161259999999999	44.201729	64.183927999999995	64.164786000000007	0103000020E610000001000000050000009413ED2AA4144640AD3594DA8B0A50409413ED2AA41446406534F279C50B5040D0D38041D21946406534F279C50B5040D0D38041D2194640AD3594DA8B0A50409413ED2AA4144640AD3594DA8B0A5040
8139	Шотова	3	26	904	44.278787000000001	44.370451000000003	64.021002999999993	64.008005999999995	0103000020E6100000010000000500000065C6DB4AAF234640FE0A992B8300504065C6DB4AAF2346408B87F71C58015040A0E238F06A2F46408B87F71C58015040A0E238F06A2F4640FE0A992B8300504065C6DB4AAF234640FE0A992B83005040
8667	Широкое	3	26	904	44.610219999999998	44.627504000000002	64.299773000000002	64.289910000000006	0103000020E61000000100000005000000BCAE5FB01B4E46402332ACE28D125040BCAE5FB01B4E464053CE177B2F135040FA0D130D5250464053CE177B2F135040FA0D130D525046402332ACE28D125040BCAE5FB01B4E46402332ACE28D125040
7859	Шардонемь	3	26	904	44.569949000000001	44.625411	63.914766	63.900452000000001	0103000020E61000000100000005000000A7B1BD16F448464014CFD90242F34F40A7B1BD16F448464012BF620D17F54F4082C7B7770D50464012BF620D17F54F4082C7B7770D50464014CFD90242F34F40A7B1BD16F448464014CFD90242F34F40
8748	Чакола	3	26	904	44.311610999999999	44.329586999999997	64.327399	64.311238000000003	0103000020E61000000100000005000000740987DEE227464070D1C952EB135040740987DEE22746408F6FEF1AF4145040E71725E82F2A46408F6FEF1AF4145040E71725E82F2A464070D1C952EB135040740987DEE227464070D1C952EB135040
8798	Труфанова	3	26	904	44.073467999999998	44.098377999999997	64.486749000000003	64.474686000000005	0103000020E61000000100000005000000B9A64066670946409F776341611E5040B9A6406667094640161747E5261F5040AC527AA6970C4640161747E5261F5040AC527AA6970C46409F776341611E5040B9A64066670946409F776341611E5040
8839	Тайга	3	26	904	43.479053	43.493524000000001	64.774269000000004	64.764201	0103000020E610000001000000050000007D06D49B51BD454083A44FABE83050407D06D49B51BD4540A053909F8D31504043E55FCB2BBF4540A053909F8D31504043E55FCB2BBF454083A44FABE83050407D06D49B51BD454083A44FABE8305040
8464	Таежный	3	26	904	44.020817999999998	44.041379999999997	64.048368999999994	64.042046999999997	0103000020E6100000010000000500000085950A2AAA0246404679E6E5B002504085950A2AAA024640F9484A7A18035040AF5A99F04B054640F9484A7A18035040AF5A99F04B0546404679E6E5B002504085950A2AAA0246404679E6E5B0025040
8288	Сылога	3	26	904	43.642510000000001	43.684902000000001	63.830509999999997	63.818694000000001	0103000020E610000001000000050000002EAD86C43DD2454039B709F7CAE84F402EAD86C43DD245401F80D4264EEA4F40857B65DEAAD745401F80D4264EEA4F40857B65DEAAD7454039B709F7CAE84F402EAD86C43DD2454039B709F7CAE84F40
7372	Сура	3	26	904	45.621066999999996	45.655895000000001	63.582723000000001	63.566285999999998	0103000020E61000000100000005000000FACF9A1F7FCF46406117450F7CC84F40FACF9A1F7FCF464042D0D1AA96CA4F40124E0B5EF4D3464042D0D1AA96CA4F40124E0B5EF4D346406117450F7CC84F40FACF9A1F7FCF46406117450F7CC84F40
7212	Сульца	3	26	904	45.980455999999997	46.009498999999998	63.447060999999998	63.438783999999998	0103000020E610000001000000050000005F950B957FFD46400801F9122AB84F405F950B957FFD464095287B4B39B94F401F2C63433701474095287B4B39B94F401F2C6343370147400801F9122AB84F405F950B957FFD46400801F9122AB84F40
7076	Сосновка	3	26	904	46.133161000000001	46.157200000000003	63.422682999999999	63.413521000000003	0103000020E61000000100000005000000240D6E6B0B114740C89A9141EEB44F40240D6E6B0B1147409FC9FE791AB64F4032772D211F1447409FC9FE791AB64F4032772D211F144740C89A9141EEB44F40240D6E6B0B114740C89A9141EEB44F40
8363	Сия	3	26	904	43.151733	43.198365000000003	64.037862000000004	64.020069000000007	0103000020E61000000100000005000000AB5CA8FC6B93454076AA7CCF48015040AB5CA8FC6B934540B7F0BC546C025040E5D5390664994540B7F0BC546C025040E5D539066499454076AA7CCF48015040AB5CA8FC6B93454076AA7CCF48015040
8372	Русковера	3	26	904	44.115535999999999	44.136358999999999	63.899011999999999	63.893594	0103000020E610000001000000050000005DC136E2C90E46406FF3C64961F24F405DC136E2C90E4640145B41D312F34F40F4C1323674114640145B41D312F34F40F4C13236741146406FF3C64961F24F405DC136E2C90E46406FF3C64961F24F40
57511	Пиринем	3	26	904	44.210828999999997	44.240222000000003	64.234692999999993	64.222549999999998	0103000020E610000001000000050000003106D671FC1A464063EE5A423E0E50403106D671FC1A464068E6C935050F5040CEE33098BF1E464068E6C935050F5040CEE33098BF1E464063EE5A423E0E50403106D671FC1A464063EE5A423E0E5040
8967	Пинега	3	26	904	43.374318000000002	43.401456000000003	64.713528999999994	64.681262000000004	0103000020E61000000100000005000000EE26F8A6E9AF45407C80EECB992B5040EE26F8A6E9AF4540D8EF8975AA2D5040396403E962B34540D8EF8975AA2D5040396403E962B345407C80EECB992B5040EE26F8A6E9AF45407C80EECB992B5040
9172	Петрово	3	26	904	43.350000999999999	43.376797000000003	64.590001999999998	64.578359000000006	0103000020E610000001000000050000009D4830D5CCAC45403A9677D5032550409D4830D5CCAC4540C6A4BF97C22550408F1D54E23AB04540C6A4BF97C22550408F1D54E23AB045403A9677D5032550409D4830D5CCAC45403A9677D503255040
57490	Пачиха	3	26	904	44.379524000000004	44.410902	63.629488000000002	63.613824999999999	0103000020E610000001000000050000000806103E94304640CD3B4ED191CE4F400806103E94304640BB9C121093D04F4035EECD6F98344640BB9C121093D04F4035EECD6F98344640CD3B4ED191CE4F400806103E94304640CD3B4ED191CE4F40
7442	Новолавела	3	26	904	45.502704999999999	45.553128000000001	63.623786000000003	63.603465999999997	0103000020E6100000010000000500000091442FA358C04640BC1FB75F3ECD4F4091442FA358C04640F1D93A38D8CF4F403E40F7E5CCC64640F1D93A38D8CF4F403E40F7E5CCC64640BC1FB75F3ECD4F4091442FA358C04640BC1FB75F3ECD4F40
7848	Немнюга	3	26	904	44.398586000000002	44.425724000000002	63.989145000000001	63.967666999999999	0103000020E610000001000000050000005D52B5DD043346408F352383DCFB4F405D52B5DD043346403F00A94D9CFE4F40A88FC01F7E3646403F00A94D9CFE4F40A88FC01F7E3646408F352383DCFB4F405D52B5DD043346408F352383DCFB4F40
8198	Междуреченский	3	26	904	44.397902999999999	44.455027000000001	64.055210000000002	64.044409000000002	0103000020E610000001000000050000007AFD497CEE3246407AA9D898D70250407AFD497CEE324640611A868F8803504004E621533E3A4640611A868F8803504004E621533E3A46407AA9D898D70250407AFD497CEE3246407AA9D898D7025040
7160	Мамониха	3	26	904	46.108718000000003	46.134149000000001	63.421245999999996	63.406689	0103000020E61000000100000005000000473EAF78EA0D47404C5299620EB44F40473EAF78EA0D474010C99063EBB54F4043E55FCB2B11474010C99063EBB54F4043E55FCB2B1147404C5299620EB44F40473EAF78EA0D47404C5299620EB44F40
7251	Кулосега	3	26	904	45.884777	45.909067	63.445714000000002	63.438462999999999	0103000020E6100000010000000500000062A06B5F40F14640C6C03A8E1FB84F4062A06B5F40F1464047AF06280DB94F40B96FB54E5CF4464047AF06280DB94F40B96FB54E5CF44640C6C03A8E1FB84F4062A06B5F40F14640C6C03A8E1FB84F40
8882	Кривые Озера	3	26	904	43.232689999999998	43.246586999999998	64.886431000000002	64.880139999999997	0103000020E61000000100000005000000990D32C9C89D4540B1F9B83654385040990D32C9C89D454047CA1649BB385040334FAE29909F454047CA1649BB385040334FAE29909F4540B1F9B83654385040990D32C9C89D4540B1F9B83654385040
9106	Красная Горка	3	26	904	43.284585	43.295886000000003	64.595913999999993	64.590878000000004	0103000020E6100000010000000500000051F701486DA44540427BF5F1D025504051F701486DA44540A04E79742326504011ACAA97DFA54540A04E79742326504011ACAA97DFA54540427BF5F1D025504051F701486DA44540427BF5F1D0255040
8233	Кобелево	3	26	904	44.253768999999998	44.272606000000003	63.997490999999997	63.985978000000003	0103000020E610000001000000050000008BDEA9807B204640AA49F08634FE4F408BDEA9807B204640F486FBC8ADFF4F40C158DFC0E4224640F486FBC8ADFF4F40C158DFC0E4224640AA49F08634FE4F408BDEA9807B204640AA49F08634FE4F40
7769	Кеврола	3	26	904	44.471699999999998	44.553519000000001	63.961271000000004	63.945717000000002	0103000020E61000000100000005000000F8C264AA603C4640B82231410DF94F40F8C264AA603C4640EFCB99ED0AFB4F40795BE9B5D9464640EFCB99ED0AFB4F40795BE9B5D9464640B82231410DF94F40F8C264AA603C4640B82231410DF94F40
8024	Карпогоры	3	26	904	44.408495000000002	44.486629999999998	64.021782999999999	63.988723	0103000020E610000001000000050000002ECA6C9049344640C9E6AA798EFE4F402ECA6C9049344640F62686E46401504051A04FE4493E4640F62686E46401504051A04FE4493E4640C9E6AA798EFE4F402ECA6C9049344640C9E6AA798EFE4F40
9206	Заозерье	3	26	904	43.264615999999997	43.274650000000001	64.517909000000003	64.509484	0103000020E61000000100000005000000C9FFE4EFDEA145407575C7629B205040C9FFE4EFDEA145407653CA6B2521504057EC2FBB27A345407653CA6B2521504057EC2FBB27A345407575C7629B205040C9FFE4EFDEA145407575C7629B205040
7057	Занюхча	3	26	904	46.532175000000002	46.550635	63.439014	63.430228	0103000020E61000000100000005000000D95F764F1E44474068E90AB611B74F40D95F764F1E4447403A3E5A9C31B84F4038842A357B4647403A3E5A9C31B84F4038842A357B46474068E90AB611B74F40D95F764F1E44474068E90AB611B74F40
7519	Заедовье	3	26	904	45.519333000000003	45.542518999999999	63.636522999999997	63.619453999999998	0103000020E61000000100000005000000E65DF58079C246402DB0C7444ACF4F40E65DF58079C246406E13EE9579D14F40B43A394371C546406E13EE9579D14F40B43A394371C546402DB0C7444ACF4F40E65DF58079C246402DB0C7444ACF4F40
7743	Еркино	3	26	904	44.659680999999999	44.710706000000002	63.900329999999997	63.884259	0103000020E610000001000000050000007365506D70544640CA181F662FF14F407365506D70544640C8CD70033EF34F401689096AF85A4640C8CD70033EF34F401689096AF85A4640CA181F662FF14F407365506D70544640CA181F662FF14F40
7357	Городецк	3	26	904	45.684480000000001	45.704180000000001	63.577503999999998	63.563899999999997	0103000020E610000001000000050000000F62670A9DD74640711B0DE02DC84F400F62670A9DD7464093A7ACA6EBC94F40A73FFB9122DA464093A7ACA6EBC94F40A73FFB9122DA4640711B0DE02DC84F400F62670A9DD74640711B0DE02DC84F40
8925	Воепала	3	26	904	43.395428000000003	43.407564999999998	64.728219999999993	64.713525000000004	0103000020E610000001000000050000001BF67B629DB2454038F8C264AA2D50401BF67B629DB24540C2120F289B2E504043FF04172BB44540C2120F289B2E504043FF04172BB4454038F8C264AA2D50401BF67B629DB2454038F8C264AA2D5040
7599	Веркола	3	26	904	45.111229000000002	45.15645	63.817704999999997	63.794212000000002	0103000020E61000000100000005000000F3AE7AC03C8E46409E0B23BDA8E54F40F3AE7AC03C8E46404963B48EAAE84F40C7BAB88D069446404963B48EAAE84F40C7BAB88D069446409E0B23BDA8E54F40F3AE7AC03C8E46409E0B23BDA8E54F40
8733	Веегора	3	26	904	44.312105000000003	44.340187	64.291584	64.283624000000003	0103000020E6100000010000000500000084F57F0EF3274640161747E52612504084F57F0EF32746405C02F04FA91250401EC3633F8B2B46405C02F04FA91250401EC3633F8B2B4640161747E52612504084F57F0EF3274640161747E526125040
7931	Ваймуша	3	26	904	44.495415999999999	44.530817999999996	63.981977000000001	63.962684000000003	0103000020E6100000010000000500000023F59ECA693F4640F530B43A39FB4F4023F59ECA693F46404C361E6CB1FD4F4066101FD8F14346404C361E6CB1FD4F4066101FD8F1434640F530B43A39FB4F4023F59ECA693F4640F530B43A39FB4F40
6115	Шомокша	3	26	715	39.141455999999998	39.170292000000003	63.182575	63.177534000000001	0103000020E6100000010000000500000057E9EE3A1B924340CBF6216FB9964F4057E9EE3A1B9243409A081B9E5E974F409E62D520CC9543409A081B9E5E974F409E62D520CC954340CBF6216FB9964F4057E9EE3A1B924340CBF6216FB9964F40
6321	Шаста	3	26	715	37.824328999999999	37.853307999999998	63.713928000000003	63.700935000000001	0103000020E610000001000000050000007B12D89C83E9424096CFF23CB8D94F407B12D89C83E942406FD921FE61DB4F4024B5503239ED42406FD921FE61DB4F4024B5503239ED424096CFF23CB8D94F407B12D89C83E9424096CFF23CB8D94F40
5885	Хачела	3	26	715	39.070013000000003	39.086039	63.420079000000001	63.406604000000002	0103000020E61000000100000005000000BEA59C2FF68843401E3691990BB44F40BEA59C2FF6884340425E0F26C5B54F401C977153038B4340425E0F26C5B54F401C977153038B43401E3691990BB44F40BEA59C2FF68843401E3691990BB44F40
5686	Усть-Кожа	3	26	715	38.710327999999997	38.744957999999997	63.638544000000003	63.625804000000002	0103000020E610000001000000050000006FB72407EC5A43405EDA70581AD04F406FB72407EC5A43404D874ECFBBD14F406072A3C85A5F43404D874ECFBBD14F406072A3C85A5F43405EDA70581AD04F406FB72407EC5A43405EDA70581AD04F40
6670	Унежма	3	26	715	36.608333000000002	36.807732000000001	63.915252000000002	63.769207999999999	0103000020E61000000100000005000000EE0912DBDD4D424029E9616875E24F40EE0912DBDD4D42409FCC3FFA26F54F4062F71DC3636742409FCC3FFA26F54F4062F71DC36367424029E9616875E24F40EE0912DBDD4D424029E9616875E24F40
6791	Тамица	3	26	715	38.019900999999997	38.039628	64.167393000000004	64.160011999999995	0103000020E610000001000000050000002F14B01D8C024340ECBDF8A23D0A50402F14B01D8C02434014252191B60A5040C100C2871205434014252191B60A5040C100C28712054340ECBDF8A23D0A50402F14B01D8C024340ECBDF8A23D0A5040
6852	Пурнема	3	26	715	37.418640000000003	37.444978999999996	64.385227	64.377195999999998	0103000020E610000001000000050000001366DAFE95B54240A60BB1FA231850401366DAFE95B5424051A2258FA718504011346612F5B8424051A2258FA718504011346612F5B84240A60BB1FA231850401366DAFE95B54240A60BB1FA23185040
6219	Прошково	3	26	715	39.296469999999999	39.318325999999999	63.045009	63.037517999999999	0103000020E61000000100000005000000601F9DBAF2A543407381CB63CD844F40601F9DBAF2A543404983DBDAC2854F40B6BB07E8BEA843404983DBDAC2854F40B6BB07E8BEA843407381CB63CD844F40601F9DBAF2A543407381CB63CD844F40
6036	Прилуки	3	26	715	39.120210999999998	39.136524999999999	63.235253	63.227525999999997	0103000020E610000001000000050000004ACFF412638F4340AE7E6C921F9D4F404ACFF412638F434098A432C51C9E4F400F0BB5A67991434098A432C51C9E4F400F0BB5A679914340AE7E6C921F9D4F404ACFF412638F4340AE7E6C921F9D4F40
6136	Посад	3	26	715	39.194474999999997	39.247762999999999	63.136156	63.104677000000002	0103000020E61000000100000005000000DE718A8EE49843405BD2510E668D4F40DE718A8EE4984340BC934F8F6D914F405514AFB2B69F4340BC934F8F6D914F405514AFB2B69F43405BD2510E668D4F40DE718A8EE49843405BD2510E668D4F40
52676	Порог	3	26	715	38.462060999999999	38.490940999999999	63.841346000000001	63.824649999999998	0103000020E61000000100000005000000E7E099D0243B4340BD5296218EE94F40E7E099D0243B43406A4FC939B1EB4F40FDA19927D73E43406A4FC939B1EB4F40FDA19927D73E4340BD5296218EE94F40E7E099D0243B4340BD5296218EE94F40
6731	Покровское	3	26	715	38.081848999999998	38.138370999999999	64.020014000000003	64.011781999999997	0103000020E61000000100000005000000EB1A2D077A0A43409D2B4A09C1005040EB1A2D077A0A434094DDCCE8470150407FDB1324B611434094DDCCE8470150407FDB1324B61143409D2B4A09C1005040EB1A2D077A0A43409D2B4A09C1005040
4987	Онега	3	26	715	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
6258	Нименьга	3	26	715	37.602426999999999	37.676546999999999	63.783751000000002	63.686416999999999	0103000020E610000001000000050000001B9DF3531CCD42408F352383DCD74F401B9DF3531CCD4240899AE8F351E44F407C9A931799D64240899AE8F351E44F407C9A931799D642408F352383DCD74F401B9DF3531CCD42408F352383DCD74F40
5454	Мудьюга	3	26	715	39.224091999999999	39.268909000000001	63.788158000000003	63.772388999999997	0103000020E61000000100000005000000CAA5F10BAF9C434023658BA4DDE24F40CAA5F10BAF9C4340570A815CE2E44F40CF4C309C6BA24340570A815CE2E44F40CF4C309C6BA2434023658BA4DDE24F40CAA5F10BAF9C434023658BA4DDE24F40
6434	Малошуйка	3	26	715	37.433067000000001	37.485035000000003	63.729567000000003	63.684100000000001	0103000020E6100000010000000500000009FD4CBD6EB74240C898BB9690D74F4009FD4CBD6EB74240D49E927362DD4F402B357BA015BE4240D49E927362DD4F402B357BA015BE4240C898BB9690D74F4009FD4CBD6EB74240C898BB9690D74F40
6914	Маложма	3	26	715	38.286107999999999	38.298440999999997	64.156711000000001	64.153059999999996	0103000020E61000000100000005000000DE8FDB2F9F244340D9942BBCCB095040DE8FDB2F9F2443401AFB928D070A50408C648F50332643401AFB928D070A50408C648F5033264340D9942BBCCB095040DE8FDB2F9F244340D9942BBCCB095040
6800	Кянда	3	26	715	38.086879000000003	38.116919000000003	64.305693000000005	64.294529999999995	0103000020E61000000100000005000000C7DADFD91E0B4340376C5B94D9125040C7DADFD91E0B43406F675F7990135040F9A3A833F70E43406F675F7990135040F9A3A833F70E4340376C5B94D9125040C7DADFD91E0B4340376C5B94D9125040
6513	Куша	3	26	715	37.045974000000001	37.062818	63.726962999999998	63.716341999999997	0103000020E61000000100000005000000B03BDD79E285424028603B18B1DB4F40B03BDD79E28542407633A31F0DDD4F40D1CC936B0A8842407633A31F0DDD4F40D1CC936B0A88424028603B18B1DB4F40B03BDD79E285424028603B18B1DB4F40
5385	Кодино	3	26	715	39.606389	39.679071	63.736930999999998	63.704545000000003	0103000020E61000000100000005000000BBD39D279ECD4340B9C7D2872EDA4F40BBD39D279ECD43404C3448C153DE4F40BD546CCCEBD643404C3448C153DE4F40BD546CCCEBD64340B9C7D2872EDA4F40BBD39D279ECD4340B9C7D2872EDA4F40
5938	Ковкула	3	26	715	39.110357	39.131008999999999	63.400072000000002	63.385914999999997	0103000020E610000001000000050000003DF19C2D208E43409604A8A965B14F403DF19C2D208E4340CD052E8F35B34F40A73D25E7C4904340CD052E8F35B34F40A73D25E7C49043409604A8A965B14F403DF19C2D208E43409604A8A965B14F40
5994	Клещево	3	26	715	39.116205000000001	39.135285000000003	63.276820999999998	63.269171	0103000020E61000000100000005000000DB5031CEDF8E43400C04013274A24F40DB5031CEDF8E43404AECDADE6EA34F40D751D504519143404AECDADE6EA34F40D751D504519143400C04013274A24F40DB5031CEDF8E43400C04013274A24F40
5852	Каска	3	26	715	39.027648999999997	39.037323999999998	63.485931000000001	63.480894999999997	0103000020E6100000010000000500000030629F008A834340ABE7A4F78DBD4F4030629F008A834340698EACFC32BE4F408EAD6708C7844340698EACFC32BE4F408EAD6708C7844340ABE7A4F78DBD4F4030629F008A834340ABE7A4F78DBD4F40
6653	Золотуха	3	26	715	36.889702999999997	36.935229999999997	63.704887999999997	63.688015999999998	0103000020E610000001000000050000009813B4C9E1714240F78F85E810D84F409813B4C9E1714240E2AB1DC539DA4F40791EDC9DB5774240E2AB1DC539DA4F40791EDC9DB5774240F78F85E810D84F409813B4C9E1714240F78F85E810D84F40
5538	Глазаниха	3	26	715	38.969537000000003	39.012557000000001	63.79542	63.779197000000003	0103000020E6100000010000000500000088A1D5C9197C4340171230BABCE34F4088A1D5C9197C4340CB4A9352D0E54F40FE2AC0779B814340CB4A9352D0E54F40FE2AC0779B814340171230BABCE34F4088A1D5C9197C4340171230BABCE34F40
6331	Ворзогоры	3	26	715	37.659720999999998	37.698340000000002	63.897069000000002	63.886037000000002	0103000020E6100000010000000500000001BEDBBC71D44240E20511A969F14F4001BEDBBC71D44240B2A03028D3F24F408CBE823463D94240B2A03028D3F24F408CBE823463D94240E20511A969F14F4001BEDBBC71D44240E20511A969F14F40
5550	Вонгуда	3	26	715	38.512366	38.553347000000002	63.870840999999999	63.842582999999998	0103000020E610000001000000050000008ACA86359541434031957EC2D9EB4F408ACA8635954143400A82C7B777EF4F407C2B1213D44643400A82C7B777EF4F407C2B1213D446434031957EC2D9EB4F408ACA86359541434031957EC2D9EB4F40
5735	Большой Бор	3	26	715	39.108812	39.128557000000001	63.617131000000001	63.609160000000003	0103000020E61000000100000005000000C8B4368DED8D4340040473F4F8CD4F40C8B4368DED8D4340842C0B26FECE4F400056478E74904340842C0B26FECE4F400056478E74904340040473F4F8CD4F40C8B4368DED8D4340040473F4F8CD4F40
5782	Анциферовский Бор	3	26	715	39.003169999999997	39.037405	63.582270999999999	63.562717999999997	0103000020E61000000100000005000000062AE3DF678043406D6FB72407C84F40062AE3DF6780434061342BDB87CA4F407BDAE1AFC984434061342BDB87CA4F407BDAE1AFC98443406D6FB72407C84F40062AE3DF678043406D6FB72407C84F40
6483	Абрамовская	3	26	715	37.388151999999998	37.416826	63.753225	63.737707	0103000020E6100000010000000500000041F0F8F6AEB14240E083D72E6DDE4F4041F0F8F6AEB14240CAC342AD69E04F40AE0FEB8D5AB54240CAC342AD69E04F40AE0FEB8D5AB54240E083D72E6DDE4F4041F0F8F6AEB14240E083D72E6DDE4F40
57507	Шожма	3	26	511	40.244076	40.267189000000002	61.937264999999996	61.927346999999997	0103000020E6100000010000000500000087DEE2E13D1F44409885764EB3F64E4087DEE2E13D1F4440BC57AD4CF8F74E40EC6CC83F33224440BC57AD4CF8F74E40EC6CC83F332244409885764EB3F64E4087DEE2E13D1F44409885764EB3F64E40
3872	Шестиозерский	3	26	511	40.188281000000003	40.218572000000002	61.817259	61.802911000000002	0103000020E61000000100000005000000A6BA809719184440A14CA3C9C5E64E40A6BA8097191844404BAE62F19BE84E4021E9D32AFA1B44404BAE62F19BE84E4021E9D32AFA1B4440A14CA3C9C5E64E40A6BA809719184440A14CA3C9C5E64E40
4373	Шалакуша	3	26	511	40.238954999999997	40.275049000000003	62.236849999999997	62.213918999999997	0103000020E610000001000000050000009B1BD313961E44401B7FA2B2611B4F409B1BD313961E44405F07CE19511E4F4015E63DCE342344405F07CE19511E4F4015E63DCE342344401B7FA2B2611B4F409B1BD313961E44401B7FA2B2611B4F40
4352	Федосеевская	3	26	511	40.662258999999999	40.675643999999998	62.125689999999999	62.120769000000003	0103000020E61000000100000005000000A73D25E7C454444071AFCC5B750F4F40A73D25E7C454444095B7239C16104F408BDEA9807B56444095B7239C16104F408BDEA9807B56444071AFCC5B750F4F40A73D25E7C454444071AFCC5B750F4F40
57488	Тарза	3	26	511	40.425651999999999	40.442171999999999	62.500892	62.491273999999997	0103000020E610000001000000050000000EBDC5C37B36444003B00111E23E4F400EBDC5C37B364440FD69A33A1D404F407C9A931799384440FD69A33A1D404F407C9A93179938444003B00111E23E4F400EBDC5C37B36444003B00111E23E4F40
4653	Ступинская	3	26	511	40.809348999999997	40.828493000000002	62.258294999999997	62.251944999999999	0103000020E6100000010000000500000070067FBF9867444003B2D7BB3F204F4070067FBF9867444033DC80CF0F214F4083FB010F0C6A444033DC80CF0F214F4083FB010F0C6A444003B2D7BB3F204F4070067FBF9867444003B2D7BB3F204F40
3999	Петариха	3	26	511	40.840682999999999	40.854705000000003	61.795228000000002	61.787089000000002	0103000020E61000000100000005000000CEA623809B6B44404B051555BFE44E40CEA623809B6B4440876EF607CAE54E40255D33F9666D4440876EF607CAE54E40255D33F9666D44404B051555BFE44E40CEA623809B6B44404B051555BFE44E40
3132	Няндома	3	26	511	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
4181	Наволок	3	26	511	40.879409000000003	40.892327000000002	61.882469999999998	61.876373000000001	0103000020E610000001000000050000006F675F7990704440780C8FFD2CF04E406F675F7990704440BED9E6C6F4F04E403D2B69C537724440BED9E6C6F4F04E403D2B69C537724440780C8FFD2CF04E406F675F7990704440780C8FFD2CF04E40
57484	Лепша-Новый	3	26	511	40.302250000000001	40.341695000000001	62.307768000000003	62.291998999999997	0103000020E61000000100000005000000A69BC420B02644407BBB253960254F40A69BC420B0264440AF601BF164274F40761A69A9BC2B4440AF601BF164274F40761A69A9BC2B44407BBB253960254F40A69BC420B02644407BBB253960254F40
57489	Лельма	3	26	511	40.229621999999999	40.251972000000002	62.050105000000002	62.038279000000003	0103000020E610000001000000050000009738F240641D4440D28F8653E6044F409738F240641D4440DC2E34D769064F40FDC0559E40204440DC2E34D769064F40FDC0559E40204440D28F8653E6044F409738F240641D4440D28F8653E6044F40
4546	Ивакша	3	26	511	40.357999999999997	40.394463000000002	62.418908000000002	62.405862999999997	0103000020E61000000100000005000000E7FBA9F1D22D444006D49B51F3334F40E7FBA9F1D22D4440320400C79E354F40B43D7AC37D324440320400C79E354F40B43D7AC37D32444006D49B51F3334F40E7FBA9F1D22D444006D49B51F3334F40
40301	Заозерный	3	26	511	40.838051	40.845560999999996	61.838458000000003	61.833311000000002	0103000020E61000000100000005000000A7B05241456B4440D33252EFA9EA4E40A7B05241456B4440E8887C9752EB4E40F3E2C4573B6C4440E8887C9752EB4E40F3E2C4573B6C4440D33252EFA9EA4E40A7B05241456B4440D33252EFA9EA4E40
3908	Волковская	3	26	511	40.977460000000001	40.984808000000001	61.692616000000001	61.687598999999999	0103000020E61000000100000005000000F792C6681D7D444093E1783E03D84E40F792C6681D7D4440DA571EA4A7D84E406A6B44300E7E4440DA571EA4A7D84E406A6B44300E7E444093E1783E03D84E40F792C6681D7D444093E1783E03D84E40
57477	Бурачиха	3	26	511	40.204324999999997	40.235658000000001	61.516120000000001	61.50273	0103000020E61000000100000005000000AA605452271A4440EA5BE67459C04E40AA605452271A4440E0675C3810C24E403885950A2A1E4440E0675C3810C24E403885950A2A1E4440EA5BE67459C04E40AA605452271A4440EA5BE67459C04E40
3950	Большой Двор	3	26	511	40.939532999999997	40.955829000000001	61.758507000000002	61.753129000000001	0103000020E61000000100000005000000A2410A9E42784440A855F48766E04E40A2410A9E42784440BF64E3C116E14E40C1C8CB9A587A4440BF64E3C116E14E40C1C8CB9A587A4440A855F48766E04E40A2410A9E42784440A855F48766E04E40
3782	Андреевская	3	26	511	40.050640999999999	40.066488	61.617562	61.609414000000001	0103000020E610000001000000050000001A6B7F677B064440BEDC274701CE4E401A6B7F677B0644404DA088450CCF4E40C9C9C4AD820844404DA088450CCF4E40C9C9C4AD82084440BEDC274701CE4E401A6B7F677B064440BEDC274701CE4E40
954	Чижгора	3	26	41	43.934201999999999	43.950515000000003	65.291233000000005	65.284074000000004	0103000020E61000000100000005000000CCED5EEE93F7454036E9B6442E525040CCED5EEE93F7454006A1BC8FA3525040C1ADBB79AAF9454006A1BC8FA3525040C1ADBB79AAF9454036E9B6442E525040CCED5EEE93F7454036E9B6442E525040
676	Целегора	3	26	41	45.131836	45.144080000000002	65.331244999999996	65.326755000000006	0103000020E61000000100000005000000BD378600E09046407DB3CD8DE9545040BD378600E0904640AA7D3A1E33555040FC00A43671924640AA7D3A1E33555040FC00A436719246407DB3CD8DE9545040BD378600E09046407DB3CD8DE9545040
1061	Сояна	3	26	41	43.372512	43.483643000000001	65.785193000000007	65.765210999999994	0103000020E610000001000000050000000CAF2479AEAF454086E28E37F97050400CAF2479AEAF45401503249A407250403CF88903E8BD45401503249A407250403CF88903E8BD454086E28E37F97050400CAF2479AEAF454086E28E37F9705040
905	Сафоново	3	26	41	47.680805999999997	47.696885000000002	65.673826000000005	65.666663999999997	0103000020E61000000100000005000000D575A8A624D74740EA5A7B9FAA6A5040D575A8A624D74740734C16F71F6B50405709168733D94740734C16F71F6B50405709168733D94740EA5A7B9FAA6A5040D575A8A624D74740EA5A7B9FAA6A5040
1294	Ручьи	3	26	41	41.214120999999999	41.237963000000001	66.044025000000005	66.036322999999996	0103000020E6100000010000000500000083312251689B4440ED45B41D5382504083312251689B444036CD3B4ED18250403B545392759E444036CD3B4ED18250403B545392759E4440ED45B41D5382504083312251689B4440ED45B41D53825040
837	Мосеево	3	26	41	46.172165999999997	46.185640999999997	65.776049999999998	65.771161000000006	0103000020E61000000100000005000000D7BD158909164740D8BCAAB35A715040D7BD158909164740E4839ECDAA715040FBE59315C3174740E4839ECDAA715040FBE59315C3174740D8BCAAB35A715040D7BD158909164740D8BCAAB35A715040
32308	Мезень	3	26	41	44.192853999999997	44.274330999999997	65.877829000000006	65.826823000000005	0103000020E610000001000000050000008E739B70AF184640292504ABEA7450408E739B70AF184640BF9EAF592E785040B5A338471D234640BF9EAF592E785040B5A338471D234640292504ABEA7450408E739B70AF184640292504ABEA745040
32448	Лампожня	3	26	41	44.304703000000003	44.339602999999997	65.697158999999999	65.689159000000004	0103000020E610000001000000050000001EFF0582002746409FAF592E1B6C50401EFF0582002746402C47C8409E6C5040CE4F711C782B46402C47C8409E6C5040CE4F711C782B46409FAF592E1B6C50401EFF0582002746409FAF592E1B6C5040
1167	Койда	3	26	41	42.528869	42.577053999999997	66.386697999999996	66.375823999999994	0103000020E61000000100000005000000226FB9FAB143454052431B800D985040226FB9FAB14345406EDBF7A8BF9850405303CDE7DC4945406EDBF7A8BF9850405303CDE7DC49454052431B800D985040226FB9FAB143454052431B800D985040
468	Козьмогородское	3	26	41	44.880532000000002	44.903025999999997	65.515186	65.509996999999998	0103000020E610000001000000050000006E8AC745B5704640B80375CAA36050406E8AC745B5704640DA56B3CEF860504006B8205B96734640DA56B3CEF860504006B8205B96734640B80375CAA36050406E8AC745B5704640B80375CAA3605040
332	Кимжа	3	26	41	44.596476000000003	44.62471	65.575697000000005	65.565478999999996	0103000020E61000000100000005000000A96C5853594C4640C9E4D4CE30645040A96C5853594C4640F1D93A38D8645040F9BD4D7FF64F4640F1D93A38D8645040F9BD4D7FF64F4640C9E4D4CE30645040A96C5853594C4640C9E4D4CE30645040
178	Каменка	3	26	41	44.098188999999998	44.141578000000003	65.901245000000003	65.872032000000004	0103000020E61000000100000005000000D9E90775910C464031444E5FCF775040D9E90775910C4640BF2B82FFAD795040A3EA573A1F124640BF2B82FFAD795040A3EA573A1F12464031444E5FCF775040D9E90775910C464031444E5FCF775040
49	Заозерье	3	26	41	44.404271999999999	44.424160999999998	65.661897999999994	65.652215999999996	0103000020E610000001000000050000002158552FBF334640637B2DE8BD6950402158552FBF3346406BD26D895C6A50408C9E5BE84A3646406BD26D895C6A50408C9E5BE84A364640637B2DE8BD6950402158552FBF334640637B2DE8BD695040
32459	Заакакурье	3	26	41	44.361845000000002	44.378509000000001	65.726855999999998	65.717885999999993	0103000020E610000001000000050000004E9CDCEF502E464066101FD8F16D50404E9CDCEF502E4640B03907CF846E5040EF1EA0FB72304640B03907CF846E5040EF1EA0FB7230464066101FD8F16D50404E9CDCEF502E464066101FD8F16D5040
422	Жердь	3	26	41	44.687519999999999	44.703043000000001	65.575205999999994	65.566047999999995	0103000020E6100000010000000500000047ACC5A700584640D6FD63213A64504047ACC5A700584640A19DD32CD064504043572250FD594640A19DD32CD064504043572250FD594640D6FD63213A64504047ACC5A700584640D6FD63213A645040
285	Дорогорское	3	26	41	44.478357000000003	44.519257000000003	65.610669999999999	65.600177000000002	0103000020E6100000010000000500000006685BCD3A3D4640EEB3CA4C6966504006685BCD3A3D46407EA99F37156750400B9C6C03774246407EA99F37156750400B9C6C0377424640EEB3CA4C6966504006685BCD3A3D4640EEB3CA4C69665040
1048	Долгощелье	3	26	41	43.429538000000001	43.471183000000003	66.052589999999995	66.034029000000004	0103000020E61000000100000005000000D331E719FBB645406687F8872D825040D331E719FBB645402F8672A25D83504031B77BB94FBC45402F8672A25D83504031B77BB94FBC45406687F8872D825040D331E719FBB645406687F8872D825040
794	Бычье	3	26	41	45.036093999999999	45.064937999999998	65.796115999999998	65.783023999999997	0103000020E6100000010000000500000079CA6ABA9E844640EBFEB1101D72504079CA6ABA9E844640A1F48590F372504042226DE34F884640A1F48590F372504042226DE34F884640EBFEB1101D72504079CA6ABA9E844640EBFEB1101D725040
564	Березник	3	26	41	44.984296999999998	45.002865	65.486352999999994	65.473259999999996	0103000020E610000001000000050000008446B071FD7D464051A04FE4495E50408446B071FD7D4640EF535568205F5040CAA65CE15D804640EF535568205F5040CAA65CE15D80464051A04FE4495E50408446B071FD7D464051A04FE4495E5040
733	Азаполье	3	26	41	45.165514000000002	45.184010000000001	65.297488000000001	65.285472999999996	0103000020E61000000100000005000000DC8310902F95464006B98B3045525040DC8310902F954640F5BC1B0B0A5350408811C2A38D974640F5BC1B0B0A5350408811C2A38D97464006B98B3045525040DC8310902F95464006B98B3045525040
31800	Юрома	3	26	1566	45.563099000000001	45.590299999999999	65.152163000000002	65.141876999999994	0103000020E6100000010000000500000085B4C6A013C846407EC344831449504085B4C6A013C84640522AE109BD495040166A4DF38ECB4640522AE109BD495040166A4DF38ECB46407EC344831449504085B4C6A013C846407EC3448314495040
32131	Чуласа	3	26	1566	46.014125	46.031408999999996	64.637928000000002	64.628964999999994	0103000020E610000001000000050000002B8716D9CE01474008556AF6402850402B8716D9CE014740F94CF6CFD328504068E6C93505044740F94CF6CFD328504068E6C9350504474008556AF6402850402B8716D9CE01474008556AF640285040
31532	Ценогора	3	26	1566	46.686784000000003	46.731098000000003	64.887739999999994	64.876936000000001	0103000020E6100000010000000500000042B5C189E8574740D82B2CB81F38504042B5C189E857474077D66EBBD0385040E415889E945D474077D66EBBD0385040E415889E945D4740D82B2CB81F38504042B5C189E8574740D82B2CB81F385040
32184	Усть-Чуласа	3	26	1566	46.055914999999999	46.071841999999997	64.611421000000007	64.604643999999993	0103000020E610000001000000050000008C2D0439280747403F6EBF7CB22650408C2D0439280747409CC58B8521275040573D601E320947409CC58B8521275040573D601E320947403F6EBF7CB22650408C2D0439280747403F6EBF7CB2265040
31432	Усть-Кыма	3	26	1566	47.473564000000003	47.499301000000003	64.838310000000007	64.830650000000006	0103000020E610000001000000050000000F48C2BE9DBC4740091B9E5E293550400F48C2BE9DBC47403A7AFCDEA635504018EE5C18E9BF47403A7AFCDEA635504018EE5C18E9BF4740091B9E5E293550400F48C2BE9DBC4740091B9E5E29355040
31670	Смоленец	3	26	1566	45.729233999999998	45.756020999999997	64.931070000000005	64.921923000000007	0103000020E61000000100000005000000CD902A8A57DD4640899B53C9003B5040CD902A8A57DD46405A12A0A6963B50406B0BCF4BC5E046405A12A0A6963B50406B0BCF4BC5E04640899B53C9003B5040CD902A8A57DD4640899B53C9003B5040
52445	Селище	3	26	1566	46.345621999999999	46.357577999999997	64.956850000000003	64.952319000000003	0103000020E61000000100000005000000996379573D2C4740011764CBF23C5040996379573D2C47405E4BC8073D3D504071E2AB1DC52D47405E4BC8073D3D504071E2AB1DC52D4740011764CBF23C5040996379573D2C4740011764CBF23C5040
57506	Северный	3	26	1566	48.590853000000003	48.722653999999999	64.844764999999995	64.788612999999998	0103000020E610000001000000050000002BDF3312A14B4840D40CA9A2783250402BDF3312A14B48408CF337A1103650406B2920ED7F5C48408CF337A1103650406B2920ED7F5C4840D40CA9A2783250402BDF3312A14B4840D40CA9A278325040
31120	Родома	3	26	1566	48.540241999999999	48.579371999999999	64.513930999999999	64.503784999999993	0103000020E610000001000000050000007BF65CA626454840C8CD70033E2050407BF65CA626454840A359D93EE4205040EB1B98DC284A4840A359D93EE4205040EB1B98DC284A4840C8CD70033E2050407BF65CA626454840C8CD70033E205040
31653	Пылема	3	26	1566	45.971905	45.988019999999999	64.987680999999995	64.976206000000005	0103000020E61000000100000005000000D1E80E6267FC46402D0ABB287A3E5040D1E80E6267FC46405B785E2A363F50409FE5797077FE46405B785E2A363F50409FE5797077FE46402D0ABB287A3E5040D1E80E6267FC46402D0ABB287A3E5040
21940	Палуга	3	26	1566	45.263942	45.275477000000002	65.231894999999994	65.227592000000001	0103000020E610000001000000050000003A05F9D9C8A14640333509DE904E50403A05F9D9C8A14640C746205ED74E50406DE690D442A34640C746205ED74E50406DE690D442A34640333509DE904E50403A05F9D9C8A14640333509DE904E5040
32196	Олема	3	26	1566	46.14819	46.171025	64.496184	64.480688999999998	0103000020E6100000010000000500000010CCD1E3F712474001A3CB9BC31E504010CCD1E3F71247401A33897AC11F504032E6AE25E41547401A33897AC11F504032E6AE25E415474001A3CB9BC31E504010CCD1E3F712474001A3CB9BC31E5040
29223	Лешуконское	3	26	1566	45.708429000000002	45.784973999999998	64.911028999999999	64.886542000000006	0103000020E61000000100000005000000DD442DCDADDA4640F321A81ABD385040DD442DCDADDA4640492D944C4E3A5040EB1A2D077AE44640492D944C4E3A5040EB1A2D077AE44640F321A81ABD385040DD442DCDADDA4640F321A81ABD385040
31241	Кысса	3	26	1566	47.861511	47.901179999999997	64.642060999999998	64.633015	0103000020E61000000100000005000000771211FE45EE474028B8585183285040771211FE45EE47405F4205871729504096E7C1DD59F347405F4205871729504096E7C1DD59F3474028B8585183285040771211FE45EE474028B8585183285040
31345	Койнас	3	26	1566	47.625757	47.667582000000003	64.762908999999993	64.733196000000007	0103000020E610000001000000050000001D1F2DCE18D04740B763EAAEEC2E50401D1F2DCE18D04740BD344580D3305040FBB2B45373D54740BD344580D3305040FBB2B45373D54740B763EAAEEC2E50401D1F2DCE18D04740B763EAAEEC2E5040
31857	Кеслома	3	26	1566	45.364086	45.380723000000003	65.213626000000005	65.208798999999999	0103000020E610000001000000050000003A77BB5E9AAE4640001C7BF65C4D50403A77BB5E9AAE4640D2E4620CAC4D5040E2EA0088BBB04640D2E4620CAC4D5040E2EA0088BBB04640001C7BF65C4D50403A77BB5E9AAE4640001C7BF65C4D5040
32262	Кеба	3	26	1566	46.194533999999997	46.219344999999997	64.361664000000005	64.342310999999995	0103000020E61000000100000005000000E3FA777DE6184740E883656CE8155040E3FA777DE6184740FF08C3802517504043C5387F131C4740FF08C3802517504043C5387F131C4740E883656CE8155040E3FA777DE6184740E883656CE8155040
31126	Зубово	3	26	1566	48.474556999999997	48.497877000000003	64.505779000000004	64.495890000000003	0103000020E610000001000000050000003F8BA548BE3C4840761A69A9BC1F50403F8BA548BE3C48403B00E2AE5E2050401E37FC6EBA3F48403B00E2AE5E2050401E37FC6EBA3F4840761A69A9BC1F50403F8BA548BE3C4840761A69A9BC1F5040
31273	Засулье	3	26	1566	47.800334999999997	47.823036000000002	64.675810999999996	64.668277000000003	0103000020E610000001000000050000000D6C956071E64740D1EAE40CC52A50400D6C956071E64740BBD1C77C402B504020B75F3E59E94740BBD1C77C402B504020B75F3E59E94740D1EAE40CC52A50400D6C956071E64740D1EAE40CC52A5040
31199	Вожгора	3	26	1566	48.416193	48.483828000000003	64.551276000000001	64.529330000000002	0103000020E610000001000000050000007DE9EDCF45354840ABB2EF8AE02150407DE9EDCF4535484076C4211B48235040CE716E13EE3D484076C4211B48235040CE716E13EE3D4840ABB2EF8AE02150407DE9EDCF45354840ABB2EF8AE0215040
31789	Большая Нисогора	3	26	1566	45.554287000000002	45.579681999999998	64.992146000000005	64.986073000000005	0103000020E610000001000000050000008ACC5CE0F2C64640FE9DEDD11B3F50408ACC5CE0F2C64640DDB6EF517F3F5040390A100533CA4640DDB6EF517F3F5040390A100533CA4640FE9DEDD11B3F50408ACC5CE0F2C64640FE9DEDD11B3F5040
31723	Березник	3	26	1566	45.569684000000002	45.595464999999997	64.959979000000004	64.951701999999997	0103000020E61000000100000005000000F986C267EBC846406B6281AFE83C5040F986C267EBC846403276C24B703D5040D174763238CC46403276C24B703D5040D174763238CC46406B6281AFE83C5040F986C267EBC846406B6281AFE83C5040
31509	Белощелье	3	26	1566	46.964471000000003	46.995767999999998	64.924180000000007	64.917180000000002	0103000020E61000000100000005000000607825C9737B4740E622BE13B33A5040607825C9737B474082E7DEC3253B5040A0336953757F474082E7DEC3253B5040A0336953757F4740E622BE13B33A5040607825C9737B4740E622BE13B33A5040
30037	Яренск	3	26	1854	49.065361000000003	49.108148	62.193908	62.164290000000001	0103000020E6100000010000000500000089B7CEBF5D884840A987687407154F4089B7CEBF5D884840653733FAD1184F405C902DCBD78D4840653733FAD1184F405C902DCBD78D4840A987687407154F4089B7CEBF5D884840A987687407154F40
30216	Усть-Очея	3	26	1854	48.603681000000002	48.629776999999997	62.418187000000003	62.394719000000002	0103000020E61000000100000005000000B91B446B454D48400F0EF62686324F40B91B446B454D4840624ED02687354F40F16261889C504840624ED02687354F40F16261889C5048400F0EF62686324F40B91B446B454D48400F0EF62686324F40
57468	Урдома	3	26	1854	48.369607000000002	48.375608	61.788730000000001	61.784064000000001	0103000020E61000000100000005000000B4AF3C484F2F484048FC8A355CE44E40B4AF3C484F2F4840E2AFC91AF5E44E40D80E46EC13304840E2AFC91AF5E44E40D80E46EC1330484048FC8A355CE44E40B4AF3C484F2F484048FC8A355CE44E40
30838	Урдома	3	26	1854	48.491813999999998	48.581249999999997	61.773815999999997	61.734892000000002	0103000020E6100000010000000500000083DBDAC2F33E4840C80BE9F010DE4E4083DBDAC2F33E48408E8F16670CE34E4066666666664A48408E8F16670CE34E4066666666664A4840C80BE9F010DE4E4083DBDAC2F33E4840C80BE9F010DE4E40
30821	Тыва	3	26	1854	48.668098999999998	48.703249999999997	61.813369999999999	61.796436	0103000020E61000000100000005000000C2BE9D4484554840B4AD669DF1E54E40C2BE9D448455484015C616821CE84E40BC749318045A484015C616821CE84E40BC749318045A4840B4AD669DF1E54E40C2BE9D4484554840B4AD669DF1E54E40
30525	Сойга	3	26	1854	48.101424000000002	48.137374000000001	61.662357999999998	61.649282999999997	0103000020E61000000100000005000000C7832D76FB0C4840A46C91B41BD34E40C7832D76FB0C48403A1F9E25C8D44E400DA9A278951148403A1F9E25C8D44E400DA9A27895114840A46C91B41BD34E40C7832D76FB0C4840A46C91B41BD34E40
30675	Селивановская	3	26	1854	47.797910000000002	47.817143000000002	61.516961000000002	61.511121000000003	0103000020E61000000100000005000000609335EA21E6474040A6B5696CC14E40609335EA21E647405B272EC72BC24E40E2934E2498E847405B272EC72BC24E40E2934E2498E8474040A6B5696CC14E40609335EA21E6474040A6B5696CC14E40
28871	Лысимо	3	26	1854	48.914121000000002	48.942615000000004	62.236075	62.222439999999999	0103000020E610000001000000050000001DCBBBEA017548403FA9F6E9781C4F401DCBBBEA017548409C33A2B4371E4F400ADCBA9BA77848409C33A2B4371E4F400ADCBA9BA77848403FA9F6E9781C4F401DCBBBEA017548403FA9F6E9781C4F40
31065	Лупья	3	26	1854	48.313794000000001	48.328096000000002	61.555748999999999	61.548591999999999	0103000020E610000001000000050000002CD7DB662A284840726C3D4338C64E402CD7DB662A28484071E481C822C74E4066F9BA0CFF29484071E481C822C74E4066F9BA0CFF294840726C3D4338C64E402CD7DB662A284840726C3D4338C64E40
30598	Литвино	3	26	1854	48.004081999999997	48.033529000000001	61.580314999999999	61.557231999999999	0103000020E610000001000000050000004A404CC2850048407024D06053C74E404A404CC2850048406A300DC347CA4E40DA3BA3AD4A0448406A300DC347CA4E40DA3BA3AD4A0448407024D06053C74E404A404CC2850048407024D06053C74E40
30353	Лена	3	26	1854	48.606717000000003	48.658101000000002	62.085431999999997	62.068373999999999	0103000020E61000000100000005000000B07614E7A84D4840C7F2AE7AC0084F40B07614E7A84D484014048F6FEF0A4F40823B50A73C54484014048F6FEF0A4F40823B50A73C544840C7F2AE7AC0084F40B07614E7A84D4840C7F2AE7AC0084F40
30372	Козьмино	3	26	1854	48.366885000000003	48.385606000000003	61.921363999999997	61.911521	0103000020E610000001000000050000004D327216F62E4840014F5AB8ACF44E404D327216F62E48401ADB6B41EFF54E40199293895B3148401ADB6B41EFF54E40199293895B314840014F5AB8ACF44E404D327216F62E4840014F5AB8ACF44E40
30290	Ирта	3	26	1854	48.845632999999999	48.882598999999999	62.100085	62.081350999999998	0103000020E610000001000000050000008DB5BFB33D6C48409A3FA6B5690A4F408DB5BFB33D6C4840FBE8D495CF0C4F40BC3D0801F9704840FBE8D495CF0C4F40BC3D0801F97048409A3FA6B5690A4F408DB5BFB33D6C48409A3FA6B5690A4F40
30131	Запань Яреньга	3	26	1854	48.985751999999998	49.020606999999998	62.11251	62.099364999999999	0103000020E61000000100000005000000B9FB1C1F2D7E4840FBAE08FEB70C4F40B9FB1C1F2D7E48408A3C49BA660E4F40CA880B40A38248408A3C49BA660E4F40CA880B40A3824840FBAE08FEB70C4F40B9FB1C1F2D7E4840FBAE08FEB70C4F40
30669	Запань Лупья	3	26	1854	48.046033999999999	48.058089000000002	61.585940999999998	61.575142999999997	0103000020E6100000010000000500000085402E71E4054840FCC22B499EC94E4085402E71E405484059315C1D00CB4E40F1A0D9756F07484059315C1D00CB4E40F1A0D9756F074840FCC22B499EC94E4085402E71E4054840FCC22B499EC94E40
30449	Гыжег	3	26	1854	48.396079999999998	48.421214999999997	61.962944	61.950898000000002	0103000020E61000000100000005000000C24CDBBFB232484079EA9106B7F94E40C24CDBBFB232484091F0BDBF41FB4E40D5CA845FEA35484091F0BDBF41FB4E40D5CA845FEA35484079EA9106B7F94E40C24CDBBFB232484079EA9106B7F94E40
30981	Витюнино	3	26	1854	48.782238999999997	48.806269	61.482466000000002	61.470488000000003	0103000020E61000000100000005000000EF535568206448408A9466F338BC4E40EF535568206448404AB72572C1BD4E40AA6395D2336748404AB72572C1BD4E40AA6395D2336748408A9466F338BC4E40EF535568206448408A9466F338BC4E40
57496	Бор	3	26	1854	48.763033	48.769914	62.084601999999997	62.082664999999999	0103000020E610000001000000050000006762BA10AB6148400DC347C4940A4F406762BA10AB6148408D96033DD40A4F40C45DBD8A8C6248408D96033DD40A4F40C45DBD8A8C6248400DC347C4940A4F406762BA10AB6148400DC347C4940A4F40
30507	Белопашино	3	26	1854	48.104981000000002	48.127906000000003	61.650035000000003	61.641185999999998	0103000020E61000000100000005000000C7D97404700D48409753026212D24E40C7D97404700D4840B020CD5834D34E40297B4B395F104840B020CD5834D34E40297B4B395F1048409753026212D24E40C7D97404700D48409753026212D24E40
29763	Черевково	3	26	1643	45.230049000000001	45.292490999999998	61.795771999999999	61.766454000000003	0103000020E610000001000000050000001FBDE13E729D4640B7F1272A1BE24E401FBDE13E729D464048895DDBDBE54E40EAAF575870A5464048895DDBDBE54E40EAAF575870A54640B7F1272A1BE24E401FBDE13E729D4640B7F1272A1BE24E40
29126	Фроловская	3	26	1643	45.870942999999997	45.890507999999997	61.573695000000001	61.564647999999998	0103000020E610000001000000050000000ED76A0F7BEF46403BE0BA6246C84E400ED76A0F7BEF46407A7077D66EC94E40C669882AFCF146407A7077D66EC94E40C669882AFCF146403BE0BA6246C84E400ED76A0F7BEF46403BE0BA6246C84E40
29697	Сакулинская	3	26	1643	45.332897000000003	45.345427999999998	61.730784	61.720927000000003	0103000020E61000000100000005000000E0F76F5E9CAA4640D6E6FF5547DC4E40E0F76F5E9CAA4640543882548ADD4E40B48F15FC36AC4640543882548ADD4E40B48F15FC36AC4640D6E6FF5547DC4E40E0F76F5E9CAA4640D6E6FF5547DC4E40
29800	Савинская	3	26	1643	45.335267999999999	45.342877000000001	61.841009999999997	61.837549000000003	0103000020E610000001000000050000009AB2D30FEAAA464015E63DCE34EB4E409AB2D30FEAAA4640F2CD3637A6EB4E407AC6BE64E3AB4640F2CD3637A6EB4E407AC6BE64E3AB464015E63DCE34EB4E409AB2D30FEAAA464015E63DCE34EB4E40
29491	Монастырская Пашня	3	26	1643	46.137230000000002	46.163632	61.510824	61.501050999999997	0103000020E61000000100000005000000DA03ADC09011474065506D7022C04E40DA03ADC09011474086014BAE62C14E401F4AB4E4F114474086014BAE62C14E401F4AB4E4F114474065506D7022C04E40DA03ADC09011474065506D7022C04E40
29342	Куликово	3	26	1643	46.668764000000003	46.706232	61.718344000000002	61.705134999999999	0103000020E61000000100000005000000FF5E0A0F9A554740EA211ADD41DA4E40FF5E0A0F9A55474090A339B2F2DB4E40C0B167CF655A474090A339B2F2DB4E40C0B167CF655A4740EA211ADD41DA4E40FF5E0A0F9A554740EA211ADD41DA4E40
29043	Красноборск	3	26	1643	45.914690999999998	45.980770999999997	61.563367999999997	61.548498000000002	0103000020E6100000010000000500000007793D9814F54640F1F5B52E35C64E4007793D9814F5464074CE4F711CC84E40BFEE74E789FD464074CE4F711CC84E40BFEE74E789FD4640F1F5B52E35C64E4007793D9814F54640F1F5B52E35C64E40
29426	Комсомольский	3	26	1643	45.428828000000003	45.444090000000003	61.405061000000003	61.395358000000002	0103000020E61000000100000005000000F7CDFDD5E3B64640221B48179BB24E40F7CDFDD5E3B646404AF1F109D9B34E40863DEDF0D7B846404AF1F109D9B34E40863DEDF0D7B84640221B48179BB24E40F7CDFDD5E3B64640221B48179BB24E40
29385	Комарово	3	26	1643	46.860545000000002	46.880235999999996	61.780622999999999	61.772731	0103000020E6100000010000000500000040DEAB56266E47407DCD72D9E8E24E4040DEAB56266E4740B1C05774EBE34E408461C092AB704740B1C05774EBE34E408461C092AB7047407DCD72D9E8E24E4040DEAB56266E47407DCD72D9E8E24E40
29525	Ершевская	3	26	1643	46.000703999999999	46.023854	61.546162000000002	61.527920999999999	0103000020E61000000100000005000000FA7C94111700474091EF52EA92C34E40FA7C941117004740B328ECA2E8C54E407CF0DAA50D034740B328ECA2E8C54E407CF0DAA50D03474091EF52EA92C34E40FA7C94111700474091EF52EA92C34E40
23538	Емельяновская	3	26	1643	46.114476000000003	46.133699999999997	61.580396999999998	61.575682	0103000020E61000000100000005000000A5164A26A70E4740AC72A1F2AFC94E40A5164A26A70E474027D9EA724ACA4E40D3BCE3141D11474027D9EA724ACA4E40D3BCE3141D114740AC72A1F2AFC94E40A5164A26A70E4740AC72A1F2AFC94E40
29179	Дябрино	3	26	1643	45.946930999999999	45.979846000000002	61.588433000000002	61.578020000000002	0103000020E61000000100000005000000C748F60835F946408B37328FFCC94E40C748F60835F946408F71C5C551CB4E40E78EFE976BFD46408F71C5C551CB4E40E78EFE976BFD46408B37328FFCC94E40C748F60835F946408B37328FFCC94E40
20766	Демьяновская	3	26	1643	45.167929999999998	45.179734000000003	61.940384000000002	61.933028	0103000020E610000001000000050000003602F1BA7E9546404B2025766DF74E403602F1BA7E95464041D7BE805EF84E4059FD11860197464041D7BE805EF84E4059FD1186019746404B2025766DF74E403602F1BA7E9546404B2025766DF74E40
29314	Верхняя Уфтюга	3	26	1643	46.605792000000001	46.637799000000001	61.647283999999999	61.638129999999997	0103000020E61000000100000005000000D7169E978A4D4740594C6C3EAED14E40D7169E978A4D4740AE9CBD33DAD24E40F435CB65A3514740AE9CBD33DAD24E40F435CB65A3514740594C6C3EAED14E40D7169E978A4D4740594C6C3EAED14E40
29668	Верхняя Сергиевская	3	26	1643	45.402183999999998	45.434308000000001	61.702235000000002	61.689630000000001	0103000020E61000000100000005000000BB7CEBC37AB34640952BBCCB45D84E40BB7CEBC37AB34640A48D23D6E2D94E401232906797B74640A48D23D6E2D94E401232906797B74640952BBCCB45D84E40BB7CEBC37AB34640952BBCCB45D84E40
29621	Верхнее Шилово	3	26	1643	45.529483999999997	45.549193000000002	61.681286999999998	61.670355000000001	0103000020E61000000100000005000000ACE0B721C6C34640E4DA5031CED54E40ACE0B721C6C346405018946934D74E409818CBF44BC646405018946934D74E409818CBF44BC64640E4DA5031CED54E40ACE0B721C6C34640E4DA5031CED54E40
29231	Большая Слудка	3	26	1643	46.085298999999999	46.11992	61.631587000000003	61.620337999999997	0103000020E61000000100000005000000D5B0DF13EB0A4740A73B4F3C67CF4E40D5B0DF13EB0A474015CAC2D7D7D04E407311DF89590F474015CAC2D7D7D04E407311DF89590F4740A73B4F3C67CF4E40D5B0DF13EB0A4740A73B4F3C67CF4E40
57524	Большая	3	26	1643	45.616387000000003	45.641503999999998	61.640296999999997	61.628397	0103000020E61000000100000005000000FC56EBC4E5CE4640C7F319506FD04E40FC56EBC4E5CE46400B5D8940F5D14E40682096CD1CD246400B5D8940F5D14E40682096CD1CD24640C7F319506FD04E40FC56EBC4E5CE4640C7F319506FD04E40
29254	Березонаволок	3	26	1643	46.375562000000002	46.393331000000003	61.612588000000002	61.601063000000003	0103000020E6100000010000000500000068CF656A12304740F7EAE3A1EFCC4E4068CF656A1230474006F6984869CE4E4062C092AB5832474006F6984869CE4E4062C092AB58324740F7EAE3A1EFCC4E4068CF656A12304740F7EAE3A1EFCC4E40
24650	Шипицыно	3	26	1457	46.486207999999998	46.538876000000002	61.294362	61.255111999999997	0103000020E61000000100000005000000DB8651103C3E474098689082A7A04E40DB8651103C3E4740B3976DA7ADA54E40B64C86E3F9444740B3976DA7ADA54E40B64C86E3F944474098689082A7A04E40DB8651103C3E474098689082A7A04E40
22930	Черемушский	3	26	1457	47.231648	47.279680999999997	61.285670000000003	61.254260000000002	0103000020E61000000100000005000000871744A4A69D47402A5778978BA04E40871744A4A69D474063B9A5D590A44E4002284696CCA3474063B9A5D590A44E4002284696CCA347402A5778978BA04E40871744A4A69D47402A5778978BA04E40
28097	Харитоново	3	26	1457	47.477013999999997	47.523726000000003	61.413018000000001	61.389991000000002	0103000020E61000000100000005000000F8DD74CB0EBD4740FF5D9F39EBB14E40F8DD74CB0EBD4740655419C6DDB44E404F081D7409C34740655419C6DDB44E404F081D7409C34740FF5D9F39EBB14E40F8DD74CB0EBD4740FF5D9F39EBB14E40
28736	Федотовская	3	26	1457	46.251621999999998	46.282003000000003	61.411726999999999	61.401724000000002	0103000020E61000000100000005000000207A522635204740580229B16BB34E40207A522635204740AAF06778B3B44E40DC2F9FAC18244740AAF06778B3B44E40DC2F9FAC18244740580229B16BB34E40207A522635204740580229B16BB34E40
28471	Удимский	3	26	1457	45.888387999999999	45.934696000000002	61.153601000000002	61.126693000000003	0103000020E610000001000000050000005514AFB2B6F14640EAD0E97937904E405514AFB2B6F1464003D19332A9934E40DCD9571EA4F7464003D19332A9934E40DCD9571EA4F74640EAD0E97937904E405514AFB2B6F14640EAD0E97937904E40
22825	Сольвычегодск	3	26	1457	46.894680999999999	46.943603000000003	61.342132999999997	61.326751000000002	0103000020E6100000010000000500000021AD31E884724740B8770DFAD2A94E4021AD31E884724740F1F09E03CBAB4E4029B4ACFBC7784740F1F09E03CBAB4E4029B4ACFBC7784740B8770DFAD2A94E4021AD31E884724740B8770DFAD2A94E40
28468	Реваж	3	26	1457	46.342010000000002	46.374915999999999	61.161799999999999	61.149133999999997	0103000020E61000000100000005000000D673D2FBC62B47405F5CAAD216934E40D673D2FBC62B4740143FC6DCB5944E40A25F5B3FFD2F4740143FC6DCB5944E40A25F5B3FFD2F47405F5CAAD216934E40D673D2FBC62B47405F5CAAD216934E40
28299	Приводино	3	26	1457	46.479039	46.519032000000003	61.091357000000002	61.067991999999997	0103000020E6100000010000000500000018416326513D4740DF313CF6B3884E4018416326513D47405EA10F96B18B4E40EBC9FCA36F4247405EA10F96B18B4E40EBC9FCA36F424740DF313CF6B3884E4018416326513D4740DF313CF6B3884E40
28663	Печерино	3	26	1457	46.331626	46.341391000000002	61.395923000000003	61.392144999999999	0103000020E610000001000000050000006C4084B8722A47401C25AFCE31B24E406C4084B8722A4740FB5DD89AADB24E400A1346B3B22B4740FB5DD89AADB24E400A1346B3B22B47401C25AFCE31B24E406C4084B8722A47401C25AFCE31B24E40
28396	Медведка	3	26	1457	46.378149999999998	46.395567999999997	61.169063000000001	61.161690999999998	0103000020E61000000100000005000000BF7D1D38673047405D876A4AB2944E40BF7D1D386730474059FB3BDBA3954E400CACE3F8A132474059FB3BDBA3954E400CACE3F8A13247405D876A4AB2944E40BF7D1D38673047405D876A4AB2944E40
28345	Курцево	3	26	1457	46.53098	46.558180999999998	61.163631000000002	61.149636999999998	0103000020E61000000100000005000000406A1327F7434740C2A2224E27934E40406A1327F74347404FCE50DCF1944E40D11F9A79724747404FCE50DCF1944E40D11F9A7972474740C2A2224E27934E40406A1327F7434740C2A2224E27934E40
16644	Куимиха	3	26	1457	46.535857999999998	46.565187999999999	61.187376	61.174035000000003	0103000020E6100000010000000500000065A6B4FE9644474000AE64C746964E4065A6B4FE964447401407D0EFFB974E40BB0B9414584847401407D0EFFB974E40BB0B94145848474000AE64C746964E4065A6B4FE9644474000AE64C746964E40
28205	Григорово	3	26	1457	46.503329999999998	46.544949000000003	61.384234999999997	61.366545000000002	0103000020E610000001000000050000003F8C101E6D40474094C151F2EAAE4E403F8C101E6D404740417DCB9C2EB14E40747E8AE3C0454740417DCB9C2EB14E40747E8AE3C045474094C151F2EAAE4E403F8C101E6D40474094C151F2EAAE4E40
57474	Вычегодский	3	26	1457	46.825105999999998	46.960483000000004	61.263162999999999	61.234873	0103000020E61000000100000005000000DFDDCA129D69474051DB8651109E4E40DFDDCA129D69474035423F53AFA14E4097AE601BF17A474035423F53AFA14E4097AE601BF17A474051DB8651109E4E40DFDDCA129D69474051DB8651109E4E40
24485	Выставка	3	26	1457	46.526128999999997	46.675401999999998	61.322443	61.089590999999999	0103000020E61000000100000005000000143DF031584347400A82C7B7778B4E40143DF031584347407DE9EDCF45A94E4095D39E92735647407DE9EDCF45A94E4095D39E92735647400A82C7B7778B4E40143DF031584347400A82C7B7778B4E40
29014	Борки	3	26	1457	47.344512000000002	47.363979	61.339820000000003	61.329445	0103000020E610000001000000050000002F8A1EF818AC4740556AF6402BAA4E402F8A1EF818AC47406C43C5387FAB4E4024B726DD96AE47406C43C5387FAB4E4024B726DD96AE4740556AF6402BAA4E402F8A1EF818AC4740556AF6402BAA4E40
28177	Андреевская	3	26	1457	46.674827000000001	46.700268000000001	61.347047000000003	61.336657000000002	0103000020E6100000010000000500000099BA2BBB60564740187C9A9317AB4E4099BA2BBB6056474064963D096CAC4E40B937BF61A259474064963D096CAC4E40B937BF61A2594740187C9A9317AB4E4099BA2BBB60564740187C9A9317AB4E40
24219	Фоминский	3	26	1743	40.274942000000003	40.292225000000002	61.193823000000002	61.185046999999997	0103000020E61000000100000005000000FF25A94C31234440889CBE9EAF974E40FF25A94C31234440371B2B31CF984E406C09F9A067254440371B2B31CF984E406C09F9A067254440889CBE9EAF974E40FF25A94C31234440889CBE9EAF974E40
25169	Топоровская	3	26	1743	39.774787000000003	39.783490999999998	61.069754000000003	61.064295999999999	0103000020E61000000100000005000000D82E6D382CE34340BEA1F0D93A884E40D82E6D382CE34340F261F6B2ED884E40ECDADE6E49E44340F261F6B2ED884E40ECDADE6E49E44340BEA1F0D93A884E40D82E6D382CE34340BEA1F0D93A884E40
25156	Сосновка	3	26	1743	40.084508	40.099375000000002	60.946475999999997	60.941049	0103000020E610000001000000050000000C207C28D10A44407D772B4B74784E400C207C28D10A44407539252026794E401F85EB51B80C44407539252026794E401F85EB51B80C44407D772B4B74784E400C207C28D10A44407D772B4B74784E40
25909	Пономаревская	3	26	1743	40.959161000000002	40.982877000000002	60.836409000000003	60.827375000000004	0103000020E61000000100000005000000A14CA3C9C57A444096438B6CE7694E40A14CA3C9C57A4440408A3A730F6B4E40CC7EDDE9CE7D4440408A3A730F6B4E40CC7EDDE9CE7D444096438B6CE7694E40A14CA3C9C57A444096438B6CE7694E40
25462	Подюга	3	26	1743	40.827154	40.904938999999999	61.105615	61.079633000000001	0103000020E61000000100000005000000B760A92EE06944405857056A318A4E40B760A92EE0694440C87BD5CA848D4E40FEEF880AD5734440C87BD5CA848D4E40FEEF880AD57344405857056A318A4E40B760A92EE06944405857056A318A4E40
25728	Першинская	3	26	1743	40.846063999999998	40.855136999999999	60.905197999999999	60.900095999999998	0103000020E6100000010000000500000056293DD34B6C444055A1815836734E4056293DD34B6C4440CA332F87DD734E40BE4C1421756D4440CA332F87DD734E40BE4C1421756D444055A1815836734E4056293DD34B6C444055A1815836734E40
25814	Папинская	3	26	1743	41.124712000000002	41.137729	60.990113999999998	60.984616000000003	0103000020E610000001000000050000009AB51490F68F4440268FA7E5077E4E409AB51490F68F4440E7A7380EBC7E4E40FB5A971AA1914440E7A7380EBC7E4E40FB5A971AA1914440268FA7E5077E4E409AB51490F68F4440268FA7E5077E4E40
57516	Норминга	3	26	1743	40.725625999999998	40.753447000000001	61.059210999999998	61.047866999999997	0103000020E610000001000000050000004B901150E15C444060C77F8120864E404B901150E15C44401F48DE3994874E40792288F3706044401F48DE3994874E40792288F37060444060C77F8120864E404B901150E15C444060C77F8120864E40
57520	Новый	3	26	1743	40.879579999999997	40.904831000000001	61.055287999999997	61.045428000000001	0103000020E610000001000000050000009B1BD313967044404E29AF95D0854E409B1BD313967044403DEE5BAD13874E4018B49080D17344403DEE5BAD13874E4018B49080D17344404E29AF95D0854E409B1BD313967044404E29AF95D0854E40
25563	Николаевка	3	26	1743	40.913446	40.938302999999998	61.095506	61.086742000000001	0103000020E61000000100000005000000BD546CCCEB7444404698A25C1A8B4E40BD546CCCEB7444403049658A398C4E408D5E0D501A7844403049658A398C4E408D5E0D501A7844404698A25C1A8B4E40BD546CCCEB7444404698A25C1A8B4E40
25090	Мирный	3	26	1743	40.057288999999997	40.081192999999999	61.073306000000002	61.064213000000002	0103000020E61000000100000005000000D4B5F63E55074440317DAF2138884E40D4B5F63E55074440E04C4C1762894E4002D53F88640A4440E04C4C1762894E4002D53F88640A4440317DAF2138884E40D4B5F63E55074440317DAF2138884E40
24237	Мелентьевский	3	26	1743	40.268904999999997	40.291659000000003	61.093096000000003	61.075704000000002	0103000020E610000001000000050000008D5DA27A6B22444094162EABB0894E408D5DA27A6B224440B8B1D991EA8B4E40C34A051555254440B8B1D991EA8B4E40C34A05155525444094162EABB0894E408D5DA27A6B22444094162EABB0894E40
25045	Кремлево	3	26	1743	40.321770999999998	40.338631999999997	60.882299000000003	60.876572000000003	0103000020E610000001000000050000008EE6C8CA2F2944406F4BE48233704E408EE6C8CA2F2944409225732CEF704E4085B01A4B582B44409225732CEF704E4085B01A4B582B44406F4BE48233704E408EE6C8CA2F2944406F4BE48233704E40
25947	Красивое	3	26	1743	40.899189999999997	40.915107999999996	60.821634000000003	60.816071000000001	0103000020E61000000100000005000000F3716DA818734440651BB80375684E40F3716DA8187344400EA48B4D2B694E406B274A42227544400EA48B4D2B694E406B274A4222754440651BB80375684E40F3716DA818734440651BB80375684E40
25844	Кощеевская	3	26	1743	41.002101000000003	41.009628999999997	60.816009999999999	60.808501999999997	0103000020E61000000100000005000000FB2477D844804440136058FE7C674E40FB2477D844804440BF9A030473684E40ED0BE8853B814440BF9A030473684E40ED0BE8853B814440136058FE7C674E40FB2477D844804440136058FE7C674E40
24562	Коноша	3	26	1743	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
24456	Климовская	3	26	1743	39.505687000000002	39.524354000000002	60.869114000000003	60.859059999999999	0103000020E610000001000000050000009581035ABAC04340A0A696ADF56D4E409581035ABAC04340753FA7203F6F4E406EC328081EC34340753FA7203F6F4E406EC328081EC34340A0A696ADF56D4E409581035ABAC04340A0A696ADF56D4E40
25654	Кварзонгский	3	26	1743	40.930909	40.939345000000003	61.167115000000003	61.158141000000001	0103000020E61000000100000005000000AA46AF06287744401094DBF63D944E40AA46AF0628774440E5D5390664954E40A054FB743C784440E5D5390664954E40A054FB743C7844401094DBF63D944E40AA46AF06287744401094DBF63D944E40
24307	Ивакинская	3	26	1743	40.508521999999999	40.524906999999999	61.063437999999998	61.0578	0103000020E61000000100000005000000F4A5B73F17414440BADA8AFD65874E40F4A5B73F174144406DA983BC1E884E4082380F27304344406DA983BC1E884E4082380F2730434440BADA8AFD65874E40F4A5B73F17414440BADA8AFD65874E40
24326	Ерцево	3	26	1743	40.055393000000002	40.129828000000003	60.809182	60.786298000000002	0103000020E61000000100000005000000B3B6291E170744408274B169A5644E40B3B6291E170744408541994693674E40740D33349E1044408541994693674E40740D33349E1044408274B169A5644E40B3B6291E170744408274B169A5644E40
57480	Волошка	3	26	1743	40.058141999999997	40.106175	61.352530000000002	61.312485000000002	0103000020E610000001000000050000001343723271074440CBBE2B82FFA74E401343723271074440F06DFAB31FAD4E408F537424970D4440F06DFAB31FAD4E408F537424970D4440CBBE2B82FFA74E401343723271074440CBBE2B82FFA74E40
57494	Вересово	3	26	1743	40.410884000000003	40.433278999999999	61.004004000000002	60.990830000000003	0103000020E610000001000000050000008F39CFD897344440A6F27684D37E4E408F39CFD897344440CF86FC3383804E409485AFAF75374440CF86FC3383804E409485AFAF75374440A6F27684D37E4E408F39CFD897344440A6F27684D37E4E40
25427	Вельцы	3	26	1743	40.735849000000002	40.748353999999999	61.153300999999999	61.146998000000004	0103000020E61000000100000005000000ACE5CE4C305E4440E94999D4D0924E40ACE5CE4C305E4440D8B8FE5D9F934E4057EA5910CA5F4440D8B8FE5D9F934E4057EA5910CA5F4440E94999D4D0924E40ACE5CE4C305E4440E94999D4D0924E40
57521	Вандыш	3	26	1743	40.230367000000001	40.280323000000003	61.336174	61.321773999999998	0103000020E61000000100000005000000F08975AA7C1D4440FF59F3E32FA94E40F08975AA7C1D4440FCE1E7BF07AB4E4087A8C29FE1234440FCE1E7BF07AB4E4087A8C29FE1234440FF59F3E32FA94E40F08975AA7C1D4440FF59F3E32FA94E40
25764	Бор	3	26	1743	41.108407999999997	41.119861	60.761130000000001	60.751319000000002	0103000020E61000000100000005000000F84F3750E08D444085EE92382B604E40F84F3750E08D4440930035B56C614E406E88F19A578F4440930035B56C614E406E88F19A578F444085EE92382B604E40F84F3750E08D444085EE92382B604E40
24497	Ануфриево	3	26	1743	39.642204	39.658957999999998	60.901007	60.895046000000001	0103000020E6100000010000000500000021AE9CBD33D24340333509DE90724E4021AE9CBD33D24340C93B873254734E4002B859BC58D44340C93B873254734E4002B859BC58D44340333509DE90724E4021AE9CBD33D24340333509DE90724E40
57512	пос.Зелёный Бор	3	26	1570	37.759093	39.912894000000001	62.084598	60.709139999999998	0103000020E61000000100000005000000AFCF9CF529E1424089247A19C55A4E40AFCF9CF529E142404CA7751BD40A4F40795BE9B5D9F443404CA7751BD40A4F40795BE9B5D9F4434089247A19C55A4E40AFCF9CF529E1424089247A19C55A4E40
23751	Ширяиха	3	26	1570	38.762718	38.780189999999997	61.877313999999998	61.864963000000003	0103000020E61000000100000005000000070951BEA061434002A08A1BB7EE4E40070951BEA061434056293DD34BF04E4047551344DD63434056293DD34BF04E4047551344DD63434002A08A1BB7EE4E40070951BEA061434002A08A1BB7EE4E40
23594	Шелоховская	3	26	1570	39.09637	39.114426000000002	61.915706	61.905807000000003	0103000020E61000000100000005000000632827DA558C434073BED87BF1F34E40632827DA558C43402060ADDA35F54E40F3E7DB82A58E43402060ADDA35F54E40F3E7DB82A58E434073BED87BF1F34E40632827DA558C434073BED87BF1F34E40
23670	Усачевская	3	26	1570	39.231116999999998	39.243423999999997	61.724162	61.716813999999999	0103000020E610000001000000050000005A46EA3D959D434050A8A78FC0DB4E405A46EA3D959D4340C3802557B1DC4E40DF878384289F4340C3802557B1DC4E40DF878384289F434050A8A78FC0DB4E405A46EA3D959D434050A8A78FC0DB4E40
23723	Трофимовская	3	26	1570	39.160967999999997	39.173841000000003	61.792183000000001	61.785361999999999	0103000020E61000000100000005000000ECD973999A944340B5C2F4BD86E44E40ECD973999A9443403DB9A64066E54E401BDA006C409643403DB9A64066E54E401BDA006C40964340B5C2F4BD86E44E40ECD973999A944340B5C2F4BD86E44E40
23369	Тимошинская	3	26	1570	38.876939	38.881798000000003	61.218953999999997	61.216523000000002	0103000020E6100000010000000500000021CB82893F70434079EA9106B79B4E4021CB82893F70434008AA46AF069C4E40D0D6C1C1DE70434008AA46AF069C4E40D0D6C1C1DE70434079EA9106B79B4E4021CB82893F70434079EA9106B79B4E40
23612	Семеновская	3	26	1570	38.986891999999997	39.006152	61.951020999999997	61.940375000000003	0103000020E610000001000000050000008E57207A527E4340EE7C3F355EF84E408E57207A527E434094675E0EBBF94E400A67B796C980434094675E0EBBF94E400A67B796C9804340EE7C3F355EF84E408E57207A527E4340EE7C3F355EF84E40
57546	Пригородный	3	26	1570	37.759093	39.912894000000001	62.084598	60.709139999999998	0103000020E61000000100000005000000AFCF9CF529E1424089247A19C55A4E40AFCF9CF529E142404CA7751BD40A4F40795BE9B5D9F443404CA7751BD40A4F40795BE9B5D9F4434089247A19C55A4E40AFCF9CF529E1424089247A19C55A4E40
23801	Погост-Наволочный	3	26	1570	38.715789999999998	38.728347999999997	61.757553000000001	61.753197999999998	0103000020E61000000100000005000000E466B8019F5B4340D0B4C4CA68E04E40E466B8019F5B43404CFE277FF7E04E40B20DDC813A5D43404CFE277FF7E04E40B20DDC813A5D4340D0B4C4CA68E04E40E466B8019F5B4340D0B4C4CA68E04E40
23221	Петровская	3	26	1570	38.811137000000002	38.824953000000001	61.614769000000003	61.608592999999999	0103000020E61000000100000005000000ACC95356D36743408AC91B60E6CD4E40ACC95356D36743401DCC26C0B0CE4E4059DE550F986943401DCC26C0B0CE4E4059DE550F986943408AC91B60E6CD4E40ACC95356D36743408AC91B60E6CD4E40
23831	Песок	3	26	1570	38.568987	38.576999999999998	61.191647000000003	61.185693999999998	0103000020E61000000100000005000000B16CE690D44843401E882CD2C4974E40B16CE690D448434032B08EE387984E4060E5D022DB49434032B08EE387984E4060E5D022DB4943401E882CD2C4974E40B16CE690D44843401E882CD2C4974E40
23984	Патровская	3	26	1570	38.555287999999997	38.603608000000001	61.278213000000001	61.262492999999999	0103000020E610000001000000050000003DEE5BAD13474340E736E15E99A14E403DEE5BAD134743403929CC7B9CA34E404FCDE506434D43403929CC7B9CA34E404FCDE506434D4340E736E15E99A14E403DEE5BAD13474340E736E15E99A14E40
24056	Осташевская	3	26	1570	38.575087000000003	38.588481000000002	61.426791000000001	61.417400000000001	0103000020E6100000010000000500000069AD68739C494340DAACFA5C6DB54E4069AD68739C494340139D6516A1B64E40A0A86C58534B4340139D6516A1B64E40A0A86C58534B4340DAACFA5C6DB54E4069AD68739C494340DAACFA5C6DB54E40
23531	Морщихинская	3	26	1570	38.876876000000003	38.886003000000002	61.222523000000002	61.218896999999998	0103000020E61000000100000005000000DB5207793D704340A41820D1049C4E40DB5207793D704340CDCD37A27B9C4E403694DA8B68714340CDCD37A27B9C4E403694DA8B68714340A41820D1049C4E40DB5207793D704340A41820D1049C4E40
22964	Лукино	3	26	1570	38.724530000000001	38.734205000000003	61.135128999999999	61.131003	0103000020E61000000100000005000000467C2766BD5C4340C556D0B4C4904E40467C2766BD5C4340DFDE35E84B914E40A4C7EF6DFA5D4340DFDE35E84B914E40A4C7EF6DFA5D4340C556D0B4C4904E40467C2766BD5C4340C556D0B4C4904E40
23287	Лазаревская	3	26	1570	39.475082	39.482951	61.488053999999998	61.479498	0103000020E610000001000000050000008A75AA7CCFBC4340AB3FC23060BD4E408A75AA7CCFBC43404B57B08D78BE4E4006499F56D1BD43404B57B08D78BE4E4006499F56D1BD4340AB3FC23060BD4E408A75AA7CCFBC4340AB3FC23060BD4E40
23964	Кречетово	3	26	1570	38.498856000000004	38.518681000000001	60.952880999999998	60.943702000000002	0103000020E61000000100000005000000EAB46E83DA3F4340BC95253ACB784E40EAB46E83DA3F434069FD2D01F8794E403E0796236442434069FD2D01F8794E403E07962364424340BC95253ACB784E40EAB46E83DA3F4340BC95253ACB784E40
23079	Кипрово	3	26	1570	38.926121000000002	38.937440000000002	61.553550999999999	61.547502999999999	0103000020E61000000100000005000000C59107228B7643401FBB0B9414C64E40C59107228B76434084D558C2DAC64E402BFBAE08FE77434084D558C2DAC64E402BFBAE08FE7743401FBB0B9414C64E40C59107228B7643401FBB0B9414C64E40
22640	Каргополь	3	26	1570	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
23353	Калитинка	3	26	1570	38.951732	38.958514999999998	61.400039999999997	61.392738999999999	0103000020E610000001000000050000004147AB5AD27943408F6E844545B24E404147AB5AD2794340C18BBE8234B34E40DBDC989EB07A4340C18BBE8234B34E40DBDC989EB07A43408F6E844545B24E404147AB5AD27943408F6E844545B24E40
23234	Казаково	3	26	1570	39.125934000000001	39.140289000000003	61.519634000000003	61.509867	0103000020E610000001000000050000002CBAF59A1E904340A227655243C14E402CBAF59A1E904340E1F1ED5D83C24E40897E6DFDF4914340E1F1ED5D83C24E40897E6DFDF4914340A227655243C14E402CBAF59A1E904340A227655243C14E40
23897	Ишуково	3	26	1570	38.769948999999997	38.778789000000003	61.119042	61.114125999999999	0103000020E61000000100000005000000404B57B08D624340C8CF46AE9B8E4E40404B57B08D624340DB6CACC43C8F4E4006BEA25BAF634340DB6CACC43C8F4E4006BEA25BAF634340C8CF46AE9B8E4E40404B57B08D624340C8CF46AE9B8E4E40
24956	Заречный	3	26	1570	38.947285999999998	38.978259999999999	61.512597	61.489514	0103000020E61000000100000005000000B5FAEAAA4079434092770E65A8BE4E40B5FAEAAA407943408C834BC79CC14E40137EA99F377D43408C834BC79CC14E40137EA99F377D434092770E65A8BE4E40B5FAEAAA4079434092770E65A8BE4E40
23013	Жуковская	3	26	1570	38.687223000000003	38.703079000000002	61.490141000000001	61.481461000000003	0103000020E610000001000000050000008E075BECF657434055A69883A0BD4E408E075BECF6574340E1B6B6F0BCBE4E4090C01F7EFE594340E1B6B6F0BCBE4E4090C01F7EFE59434055A69883A0BD4E408E075BECF657434055A69883A0BD4E40
23475	Дудкинская	3	26	1570	38.316363000000003	38.327950999999999	61.563209000000001	61.559618999999998	0103000020E610000001000000050000000D5531957E284340309C6B98A1C74E400D5531957E2843400CE8853B17C84E4062D8614CFA2943400CE8853B17C84E4062D8614CFA294340309C6B98A1C74E400D5531957E284340309C6B98A1C74E40
22395	Григорьево	3	26	1570	38.441713999999997	38.453149000000003	61.006974	61.000253000000001	0103000020E61000000100000005000000B91798158A384340EA5C514A08804E40B91798158A3843400EF62686E4804E40899B53C9003A43400EF62686E4804E40899B53C9003A4340EA5C514A08804E40B91798158A384340EA5C514A08804E40
23426	Ватамановская	3	26	1570	38.576227000000003	38.598047999999999	61.561053999999999	61.552947000000003	0103000020E610000001000000050000003E096CCEC1494340EEB5A0F7C6C64E403E096CCEC14943401EA5129ED0C74E4017B83CD68C4C43401EA5129ED0C74E4017B83CD68C4C4340EEB5A0F7C6C64E403E096CCEC1494340EEB5A0F7C6C64E40
23174	Абакумово	3	26	1570	39.051561999999997	39.063589999999998	61.590153999999998	61.583748999999997	0103000020E61000000100000005000000B1DB6795998643404E098849B8CA4E40B1DB67959986434042CD902A8ACB4E40232D95B72388434042CD902A8ACB4E40232D95B7238843404E098849B8CA4E40B1DB6795998643404E098849B8CA4E40
22556	Яковлевская	3	26	1587	43.644136000000003	43.672837000000001	62.530065999999998	62.515908000000003	0103000020E610000001000000050000009016670C73D2454055DFF94509424F409016670C73D245405B5CE333D9434F40F644D7851FD645405B5CE333D9434F40F644D7851FD6454055DFF94509424F409016670C73D2454055DFF94509424F40
22544	Шидрово	3	26	1587	42.861353000000001	42.885176000000001	62.792946000000001	62.774464999999999	0103000020E61000000100000005000000DFA7AAD0406E4540C5724BAB21634F40DFA7AAD0406E45403CBF28417F654F40209A79724D7145403CBF28417F654F40209A79724D714540C5724BAB21634F40DFA7AAD0406E4540C5724BAB21634F40
22086	Хетово	3	26	1587	42.338982999999999	42.358395000000002	63.036824000000003	63.030647999999999	0103000020E61000000100000005000000327381CB632B45400AD80E46EC834F40327381CB632B45409DDA19A6B6844F4064062AE3DF2D45409DDA19A6B6844F4064062AE3DF2D45400AD80E46EC834F40327381CB632B45400AD80E46EC834F40
21943	Усть-Ваеньга	3	26	1587	42.603959000000003	42.657057999999999	63.015864000000001	62.995240000000003	0103000020E61000000100000005000000FC8F4C874E4D4540E5D53906647F4F40FC8F4C874E4D45408597E0D407824F409FC9FE791A5445408597E0D407824F409FC9FE791A544540E5D53906647F4F40FC8F4C874E4D4540E5D53906647F4F40
22429	Усть-Вага	3	26	1587	42.802424000000002	42.840063000000001	62.750745000000002	62.733536000000001	0103000020E6100000010000000500000044C362D4B56645402638F581E45D4F4044C362D4B56645405951836918604F4032CA332F876B45405951836918604F4032CA332F876B45402638F581E45D4F4044C362D4B56645402638F581E45D4F40
22177	Уйта	3	26	1587	42.501325999999999	42.528185999999998	63.013876000000003	63.005842000000001	0103000020E6100000010000000500000037514B732B404540BC783F6EBF804F4037514B732B404540831953B0C6814F403F1A4E999B434540831953B0C6814F403F1A4E999B434540BC783F6EBF804F4037514B732B404540BC783F6EBF804F40
21634	Топса	3	26	1587	43.611643999999998	43.645142	62.606231999999999	62.590876000000002	0103000020E61000000100000005000000B665C0594ACE4540E3FE23D3A14B4F40B665C0594ACE4540F3E49A02994D4F4055A3570394D24540F3E49A02994D4F4055A3570394D24540E3FE23D3A14B4F40B665C0594ACE4540E3FE23D3A14B4F40
22135	Рязаново	3	26	1587	42.358341000000003	42.380952000000001	63.034238000000002	63.025723999999997	0103000020E6100000010000000500000071E82D1EDE2D4540745C8DEC4A834F4071E82D1EDE2D4540E62329E961844F4043ACFE08C3304540E62329E961844F4043ACFE08C3304540745C8DEC4A834F4071E82D1EDE2D4540745C8DEC4A834F40
21684	Рочегда	3	26	1587	43.337200000000003	43.430219999999998	62.686754999999998	62.661535999999998	0103000020E61000000100000005000000091B9E5E29AB454036902E36AD544F40091B9E5E29AB4540A7AE7C96E7574F40E50AEF7211B74540A7AE7C96E7574F40E50AEF7211B7454036902E36AD544F40091B9E5E29AB454036902E36AD544F40
22219	Пянда	3	26	1587	42.587420999999999	42.613624999999999	62.974144000000003	62.952430999999997	0103000020E61000000100000005000000E7FD7F9C304B454029594E42E9794F40E7FD7F9C304B45401DCC26C0B07C4F40068195438B4E45401DCC26C0B07C4F40068195438B4E454029594E42E9794F40E7FD7F9C304B454029594E42E9794F40
19222	Почтовое	3	26	1587	42.009453999999998	42.022291000000003	63.161622999999999	63.153193999999999	0103000020E610000001000000050000007F68E6C935014540C2F869DC9B934F407F68E6C93501454005A4FD0FB0944F4061FF756EDA02454005A4FD0FB0944F4061FF756EDA024540C2F869DC9B934F407F68E6C935014540C2F869DC9B934F40
21804	Осиново	3	26	1587	42.757975000000002	42.827593999999998	62.872320999999999	62.854263000000003	0103000020E61000000100000005000000C21726530561454068976F7D586D4F40C217265305614540984EEB36A86F4F40D32EA699EE694540984EEB36A86F4F40D32EA699EE69454068976F7D586D4F40C21726530561454068976F7D586D4F40
22028	Моржегоры	3	26	1587	42.142071999999999	42.184859000000003	63.054986	63.046835999999999	0103000020E61000000100000005000000B2D6506A2F1245404223D8B8FE854F40B2D6506A2F12454072DEFFC709874F4086AFAF75A917454072DEFFC709874F4086AFAF75A91745404223D8B8FE854F40B2D6506A2F1245404223D8B8FE854F40
21743	Конецгорье	3	26	1587	43.200665000000001	43.235411999999997	62.764018	62.752315000000003	0103000020E61000000100000005000000D6390664AF99454027A5A0DB4B604F40D6390664AF99454015C78157CB614F40008BFCFA219E454015C78157CB614F40008BFCFA219E454027A5A0DB4B604F40D6390664AF99454027A5A0DB4B604F40
21836	Квахтюга	3	26	1587	43.108471000000002	43.134422999999998	62.919142999999998	62.911954999999999	0103000020E610000001000000050000003FC8B260E28D45403B3602F1BA744F403FC8B260E28D454075AC527AA6754F40446ADAC53491454075AC527AA6754F40446ADAC5349145403B3602F1BA744F403FC8B260E28D45403B3602F1BA744F40
21548	Гридинская	3	26	1587	43.917816999999999	43.944406999999998	62.484603999999997	62.467402	0103000020E610000001000000050000003E5B07077BF54540E10A28D4D33B4F403E5B07077BF5454061C1FD80073E4F40868E1D54E2F8454061C1FD80073E4F40868E1D54E2F84540E10A28D4D33B4F403E5B07077BF54540E10A28D4D33B4F40
21541	Воронцы	3	26	1587	43.052307999999996	43.073543999999998	62.953052999999997	62.941032	0103000020E61000000100000005000000DAA84E07B2864540A73E90BC73784F40DAA84E07B2864540662D05A4FD794F409468C9E369894540662D05A4FD794F409468C9E369894540A73E90BC73784F40DAA84E07B2864540A73E90BC73784F40
22483	Важский	3	26	1587	42.937942999999997	42.957087000000001	62.64873	62.639933999999997	0103000020E610000001000000050000008D4127840E7845409ACC785BE9514F408D4127840E78454090F7AA9509534F40A036AAD3817A454090F7AA9509534F40A036AAD3817A45409ACC785BE9514F408D4127840E7845409ACC785BE9514F40
22267	Березник	3	26	1587	42.663345999999997	42.825797999999999	62.872698	62.829331000000003	0103000020E6100000010000000500000059F78F85E85445408D47A984276A4F4059F78F85E85445406EA46C91B46F4F40158DB5BFB36945406EA46C91B46F4F40158DB5BFB36945408D47A984276A4F4059F78F85E85445408D47A984276A4F40
20725	Широкий Прилук	3	26	1635	48.832966999999996	48.861038999999998	61.128005000000002	61.116539000000003	0103000020E61000000100000005000000D8D2A3A99E6A4840B2DAFCBFEA8E4E40D8D2A3A99E6A4840BC5CC47762904E404FCAA486366E4840BC5CC47762904E404FCAA486366E4840B2DAFCBFEA8E4E40D8D2A3A99E6A4840B2DAFCBFEA8E4E40
21502	Шалимово	3	26	1635	47.452472	47.472602999999999	61.209695000000004	61.198925000000003	0103000020E61000000100000005000000882D3D9AEAB94740ACADD85F76994E40882D3D9AEAB947403F912749D79A4E40E97E4E417EBC47403F912749D79A4E40E97E4E417EBC4740ACADD85F76994E40882D3D9AEAB94740ACADD85F76994E40
20559	Фоминский	3	26	1635	48.658073999999999	48.687187999999999	61.273915000000002	61.259953000000003	0103000020E61000000100000005000000882CD2C43B544840A1BFD02346A14E40882CD2C43B54484022718FA50FA34E40111AC1C6F557484022718FA50FA34E40111AC1C6F5574840A1BFD02346A14E40882CD2C43B544840A1BFD02346A14E40
20771	Теринская	3	26	1635	48.329954999999998	48.355566000000003	61.211385	61.202548999999998	0103000020E610000001000000050000006A1327F73B2A4840336B2920ED994E406A1327F73B2A4840B7EEE6A90E9B4E40E7C8CA2F832D4840B7EEE6A90E9B4E40E7C8CA2F832D4840336B2920ED994E406A1327F73B2A4840336B2920ED994E40
20624	Стафоровская	3	26	1635	48.634062	48.663473000000003	61.290416	61.2821	0103000020E6100000010000000500000074D190F128514840CE1951DA1BA44E4074D190F128514840191EFB592CA54E40B763EAAEEC544840191EFB592CA54E40B763EAAEEC544840CE1951DA1BA44E4074D190F128514840CE1951DA1BA44E40
20662	Сорово	3	26	1635	48.363390000000003	48.497159000000003	61.294181000000002	61.258339999999997	0103000020E61000000100000005000000C3D84290832E4840D39FFD4811A14E40C3D84290832E4840630D17B9A7A54E40BFF4F6E7A23F4840630D17B9A7A54E40BFF4F6E7A23F4840D39FFD4811A14E40C3D84290832E4840D39FFD4811A14E40
57487	Слобода	3	26	1635	48.319481000000003	48.342171999999998	61.010523999999997	61.003084000000001	0103000020E61000000100000005000000C158DFC0E42848400892770E65804E40C158DFC0E42848405BE9B5D958814E40AFCDC64ACC2B48405BE9B5D958814E40AFCDC64ACC2B48400892770E65804E40C158DFC0E42848400892770E65804E40
21142	Сидоровская	3	26	1635	47.952995000000001	47.975085	61.105066999999998	61.096380000000003	0103000020E6100000010000000500000032207BBDFBF9474087FE092E568C4E4032207BBDFBF94740C571E0D5728D4E40FBE8D495CFFC4740C571E0D5728D4E40FBE8D495CFFC474087FE092E568C4E4032207BBDFBF9474087FE092E568C4E40
21074	Подомо	3	26	1635	48.010496000000003	48.034320000000001	61.10848	61.099285000000002	0103000020E61000000100000005000000925ED4EE57014840DFFDF15EB58C4E40925ED4EE57014840922232ACE28D4E40A3CC069964044840922232ACE28D4E40A3CC069964044840DFFDF15EB58C4E40925ED4EE57014840DFFDF15EB58C4E40
20872	Павловск	3	26	1635	48.174546999999997	48.202125000000002	61.071751999999996	61.061143999999999	0103000020E61000000100000005000000B54E5C8E571648405E2C0C91D3874E40B54E5C8E5716484017B6662B2F894E401D5A643BDF19484017B6662B2F894E401D5A643BDF1948405E2C0C91D3874E40B54E5C8E571648405E2C0C91D3874E40
21316	Никольск	3	26	1635	47.702455	47.740157000000004	61.260264999999997	61.247163	0103000020E61000000100000005000000B2F4A10BEAD9474000E48409A39F4E40B2F4A10BEAD947408FA50F5D50A14E40E773EE76BDDE47408FA50F5D50A14E40E773EE76BDDE474000E48409A39F4E40B2F4A10BEAD9474000E48409A39F4E40
21232	Мухонская	3	26	1635	47.936466000000003	47.997767000000003	61.128256999999998	61.113005000000001	0103000020E6100000010000000500000071E82D1EDEF747406AA4A5F2768E4E4071E82D1EDEF74740D53DB2B96A904E4097033DD4B6FF4740D53DB2B96A904E4097033DD4B6FF47406AA4A5F2768E4E4071E82D1EDEF747406AA4A5F2768E4E40
21268	Кошкино	3	26	1635	47.819325999999997	47.839196999999999	61.159951	61.147536000000002	0103000020E610000001000000050000009961A3ACDFE84740C87DAB75E2924E409961A3ACDFE8474033FB3C4679944E405EF3AACE6AEB474033FB3C4679944E405EF3AACE6AEB4740C87DAB75E2924E409961A3ACDFE84740C87DAB75E2924E40
21419	Кивер	3	26	1635	47.699615999999999	47.722594999999998	61.392795	61.381734999999999	0103000020E6100000010000000500000011E15F048DD94740895E46B1DCB04E4011E15F048DD947402384471B47B24E4066A032FE7DDC47402384471B47B24E4066A032FE7DDC4740895E46B1DCB04E4011E15F048DD94740895E46B1DCB04E40
21183	Ильинско-Подомское	3	26	1635	47.962122000000001	47.991973000000002	61.117263999999999	61.108750000000001	0103000020E610000001000000050000008D614ED026FB474052B81E85EB8D4E408D614ED026FB4740C37FBA81028F4E40ECC1A4F8F8FE4740C37FBA81028F4E40ECC1A4F8F8FE474052B81E85EB8D4E408D614ED026FB474052B81E85EB8D4E40
21356	Виледь	3	26	1635	47.499526000000003	47.535099000000002	61.314433000000001	61.299435000000003	0103000020E6100000010000000500000038C0CC77F0BF47408E23D6E253A64E4038C0CC77F0BF47403FE42D573FA84E40A88FC01F7EC447403FE42D573FA84E40A88FC01F7EC447408E23D6E253A64E4038C0CC77F0BF47408E23D6E253A64E40
20831	Вилегодск	3	26	1635	48.276828999999999	48.297535000000003	61.161937999999999	61.151390999999997	0103000020E61000000100000005000000CDCAF6216F23484051F4C0C760934E40CDCAF6216F23484065FD6662BA944E402B357BA01526484065FD6662BA944E402B357BA01526484051F4C0C760934E40CDCAF6216F23484051F4C0C760934E40
21038	Быково	3	26	1635	48.073872000000001	48.105043999999999	61.066929999999999	61.053198000000002	0103000020E61000000100000005000000890B40A374094840371B2B31CF864E40890B40A374094840868F882991884E400D52F014720D4840868F882991884E400D52F014720D4840371B2B31CF864E40890B40A374094840371B2B31CF864E40
59094	д.Скрипчинская	3	26	1579	43.549596999999999	47.567293999999997	63.219352000000001	61.641195000000003	0103000020E61000000100000005000000677DCA3159C64540EBAD81AD12D24E40677DCA3159C64540F627F1B9139C4F40C79BFC169DC84740F627F1B9139C4F40C79BFC169DC84740EBAD81AD12D24E40677DCA3159C64540EBAD81AD12D24E40
19371	Черный Ручей	3	26	1579	45.187145000000001	45.195633999999998	62.408946999999998	62.403025999999997	0103000020E61000000100000005000000124E0B5EF497464006B8205B96334F40124E0B5EF49746400E66136058344F402AFEEF880A9946400E66136058344F402AFEEF880A99464006B8205B96334F40124E0B5EF497464006B8205B96334F40
19610	Ухменьга	3	26	1579	45.305570000000003	45.324147000000004	62.451403999999997	62.442790000000002	0103000020E61000000100000005000000C251F2EA1CA74640787FBC57AD384F40C251F2EA1CA746404CA4349BC7394F405B0C1EA67DA946404CA4349BC7394F405B0C1EA67DA94640787FBC57AD384F40C251F2EA1CA74640787FBC57AD384F40
19845	Усть-Ерга	3	26	1579	45.139741000000001	45.153520999999998	62.102127000000003	62.095306999999998	0103000020E6100000010000000500000086747808E3914640390A1005330C4F4086747808E3914640F1845E7F120D4F40E61F7D93A6934640F1845E7F120D4F40E61F7D93A6934640390A1005330C4F4086747808E3914640390A1005330C4F40
19460	Сосновый	3	26	1579	44.765979000000002	44.780667000000001	62.309299000000003	62.297640999999999	0103000020E610000001000000050000001E3691990B6246407079AC1919264F401E3691990B624640BFD7101C97274F40810871E5EC634640BFD7101C97274F40810871E5EC6346407079AC1919264F401E3691990B6246407079AC1919264F40
19445	Сойга	3	26	1579	44.866841999999998	44.878079999999997	62.231363999999999	62.227893999999999	0103000020E610000001000000050000004D66BCADF46E4640317A6EA12B1D4F404D66BCADF46E464062BCE6559D1D4F40C6A2E9EC6470464062BCE6559D1D4F40C6A2E9EC64704640317A6EA12B1D4F404D66BCADF46E4640317A6EA12B1D4F40
19202	Согра	3	26	1579	46.174942000000001	46.204272000000003	62.679188000000003	62.670186000000001	0103000020E610000001000000050000003259DC7F64164740581EA4A7C8554F403259DC7F64164740F7EAE3A1EF564F4088BEBB95251A4740F7EAE3A1EF564F4088BEBB95251A4740581EA4A7C8554F403259DC7F64164740581EA4A7C8554F40
19751	Семеновская 1-я	3	26	1579	45.191313000000001	45.205067	62.019502000000003	62.014477999999997	0103000020E610000001000000050000005B26C3F17C9846407841446ADA014F405B26C3F17C984640721AA20A7F024F40923EADA23F9A4640721AA20A7F024F40923EADA23F9A46407841446ADA014F405B26C3F17C9846407841446ADA014F40
20311	Поперечка	3	26	1579	44.600456000000001	44.624862999999998	62.026432	62.016770999999999	0103000020E61000000100000005000000EF5701BEDB4C4640B742588D25024F40EF5701BEDB4C4640B0C8AF1F62034F407FBDC282FB4F4640B0C8AF1F62034F407FBDC282FB4F4640B742588D25024F40EF5701BEDB4C4640B742588D25024F40
19132	Палова	3	26	1579	46.142691999999997	46.157128	62.489820000000002	62.482754999999997	0103000020E610000001000000050000004EB340BB43124740807D74EACA3D4F404EB340BB431247409F76F86BB23E4F4098A432C51C1447409F76F86BB23E4F4098A432C51C144740807D74EACA3D4F404EB340BB43124740807D74EACA3D4F40
18974	Осяткино	3	26	1579	46.845641999999998	46.874567999999996	62.746639000000002	62.732798000000003	0103000020E61000000100000005000000E00F3FFF3D6C474080492A53CC5D4F40E00F3FFF3D6C47408675E3DD915F4F4066101FD8F16F47408675E3DD915F4F4066101FD8F16F474080492A53CC5D4F40E00F3FFF3D6C474080492A53CC5D4F40
57509	Окулово	3	26	1579	45.200637999999998	45.206063999999998	62.403554999999997	62.401395999999998	0103000020E61000000100000005000000DC2A8881AE994640635FB2F160334F40DC2A8881AE9946409291B3B0A7334F4004711E4E609A46409291B3B0A7334F4004711E4E609A4640635FB2F160334F40DC2A8881AE994640635FB2F160334F40
19625	Лахома	3	26	1579	45.906892999999997	45.92521	61.964897999999998	61.960166000000001	0103000020E6100000010000000500000054FCDF1115F44640965D30B8E6FA4E4054FCDF1115F44640E7FC14C781FB4E4051F701486DF64640E7FC14C781FB4E4051F701486DF64640965D30B8E6FA4E4054FCDF1115F44640965D30B8E6FA4E40
19229	Ламбас	3	26	1579	45.921545000000002	45.950119999999998	62.587890000000002	62.579062999999998	0103000020E610000001000000050000006B65C22FF5F546406DA983BC1E4A4F406B65C22FF5F546409ED2C1FA3F4B4F4044A33B889DF946409ED2C1FA3F4B4F4044A33B889DF946406DA983BC1E4A4F406B65C22FF5F546406DA983BC1E4A4F40
19028	Красная	3	26	1579	46.753177999999998	46.775689999999997	62.467826000000002	62.456707999999999	0103000020E610000001000000050000008908FF226860474029E96168753A4F408908FF2268604740F81BEDB8E13B4F40C8EA56CF49634740F81BEDB8E13B4F40C8EA56CF4963474029E96168753A4F408908FF226860474029E96168753A4F40
20136	Кондратовская	3	26	1579	43.946823000000002	43.969883000000003	62.384608	62.375182000000002	0103000020E61000000100000005000000E10CFE7E31F945402106BAF605304F40E10CFE7E31F94540D6E3BED53A314F4023F94A2025FC4540D6E3BED53A314F4023F94A2025FC45402106BAF605304F40E10CFE7E31F945402106BAF605304F40
20248	Кодимский	3	26	1579	43.872461000000001	43.899248999999998	62.289062000000001	62.277684999999998	0103000020E610000001000000050000008A0453CDACEF45407DCB9C2E8B234F408A0453CDACEF45401842CEFBFF244F40F8FA5A971AF345401842CEFBFF244F40F8FA5A971AF345407DCB9C2E8B234F408A0453CDACEF45407DCB9C2E8B234F40
20381	Каменное	3	26	1579	44.803645000000003	44.821826999999999	61.784208999999997	61.777560000000001	0103000020E61000000100000005000000064CE0D6DD664640C156091687E34E40064CE0D6DD6646404B1DE4F560E44E4022FC8BA0316946404B1DE4F560E44E4022FC8BA031694640C156091687E34E40064CE0D6DD664640C156091687E34E40
19794	Исаковская	3	26	1579	44.767496999999999	44.773668999999998	62.260125000000002	62.256351000000002	0103000020E61000000100000005000000996379573D62464001A60C1CD0204F40996379573D6246409EEFA7C64B214F40EA76F695076346409EEFA7C64B214F40EA76F6950763464001A60C1CD0204F40996379573D62464001A60C1CD0204F40
19947	Зеленник	3	26	1579	44.650582	44.692722000000003	62.352887000000003	62.339421000000002	0103000020E61000000100000005000000E2AE5E4546534640AE49B725722B4F40E2AE5E45465346407F17B6662B2D4F40209C4F1DAB5846407F17B6662B2D4F40209C4F1DAB584640AE49B725722B4F40E2AE5E4546534640AE49B725722B4F40
57508	Заруба	3	26	1579	45.781264	45.801170999999997	62.090809999999998	62.082887999999997	0103000020E6100000010000000500000065C5707500E446408C9DF0129C0A4F4065C5707500E446402B137EA99F0B4F4076C075C58CE646402B137EA99F0B4F4076C075C58CE646408C9DF0129C0A4F4065C5707500E446408C9DF0129C0A4F40
20196	Евдокимовская	3	26	1579	43.879413999999997	43.889960000000002	62.410001000000001	62.402000000000001	0103000020E6100000010000000500000080D250A390F04540FA7E6ABC74334F4080D250A390F04540E529ABE97A344F40C45F9335EAF14540E529ABE97A344F40C45F9335EAF14540FA7E6ABC74334F4080D250A390F04540FA7E6ABC74334F40
19543	Двинской	3	26	1579	45.100448999999998	45.138843000000001	62.161921	62.147747000000003	0103000020E610000001000000050000003CF54883DB8C4640838AAA5FE9124F403CF54883DB8C46408FC4CBD3B9144F40A723809BC59146408FC4CBD3B9144F40A723809BC5914640838AAA5FE9124F403CF54883DB8C4640838AAA5FE9124F40
20030	Вознесенское	3	26	1579	44.214575000000004	44.228526000000002	62.337600000000002	62.334083	0103000020E6100000010000000500000005C58F31771B46402593533BC32A4F4005C58F31771B464097900F7A362B4F4092240857401D464097900F7A362B4F4092240857401D46402593533BC32A4F4005C58F31771B46402593533BC32A4F40
19281	Верхняя Тойма	3	26	1579	44.979976000000001	45.017659999999999	62.25076	62.231377000000002	0103000020E61000000100000005000000B56E83DA6F7D4640F705F4C29D1D4F40B56E83DA6F7D46408E9257E718204F404339D1AE428246408E9257E718204F404339D1AE42824640F705F4C29D1D4F40B56E83DA6F7D4640F705F4C29D1D4F40
20059	Бурцевская	3	26	1579	44.264189000000002	44.282254000000002	62.363599999999998	62.355336999999999	0103000020E61000000100000005000000427BF5F1D02146408507CDAE7B2D4F40427BF5F1D0214640AD69DE718A2E4F40259529E620244640AD69DE718A2E4F40259529E6202446408507CDAE7B2D4F40427BF5F1D02146408507CDAE7B2D4F40
19058	Белореченский	3	26	1579	46.230449	46.242477000000001	62.397306999999998	62.39085	0103000020E61000000100000005000000AD32535A7F1D474020D26F5F07324F40AD32535A7F1D474066BCADF4DA324F401F84807C091F474066BCADF4DA324F401F84807C091F474020D26F5F07324F40AD32535A7F1D474020D26F5F07324F40
20440	Авнюгский	3	26	1579	45.077461	45.099576999999996	62.001291999999999	61.989806000000002	0103000020E6100000010000000500000094DBF63DEA8946403AB187F6B1FE4E4094DBF63DEA8946408BDF14562A004F4086376BF0BE8C46408BDF14562A004F4086376BF0BE8C46403AB187F6B1FE4E4094DBF63DEA8946403AB187F6B1FE4E40
57499	дер.Выселок	3	26	1404	40.908693999999997	43.621696	61.912897999999998	60.767884000000002	0103000020E610000001000000050000002409C21550744440938FDD054A624E402409C21550744440BA4A77D7D9F44E40EA060ABC93CF4540BA4A77D7D9F44E40EA060ABC93CF4540938FDD054A624E402409C21550744440938FDD054A624E40
18812	Шунема	3	26	1404	41.825127999999999	41.857368999999998	61.213894000000003	61.201504	0103000020E61000000100000005000000C78157CB9DE94440B00111E2CA994E40C78157CB9DE94440C367EBE0609B4E4057CD7344BEED4440C367EBE0609B4E4057CD7344BEED4440B00111E2CA994E40C78157CB9DE94440B00111E2CA994E40
17594	Шокша	3	26	1404	42.058619	42.067583999999997	61.420499	61.408088999999997	0103000020E610000001000000050000004DF6CFD380074540BD6DA6423CB44E404DF6CFD380074540178046E9D2B54E40CEDDAE97A6084540178046E9D2B54E40CEDDAE97A6084540BD6DA6423CB44E404DF6CFD380074540BD6DA6423CB44E40
18559	Шиловская	3	26	1404	42.034939000000001	42.051772999999997	61.019736000000002	61.008277999999997	0103000020E610000001000000050000006F2D93E1780445405DA3E5400F814E406F2D93E178044540E54691B586824E406CE8667FA0064540E54691B586824E406CE8667FA00645405DA3E5400F814E406F2D93E1780445405DA3E5400F814E40
18491	Хорошевская	3	26	1404	42.065482000000003	42.077204999999999	61.081555999999999	61.075024999999997	0103000020E61000000100000005000000043DD4B661084540F2B0506B9A894E40043DD4B6610845407365506D708A4E40390B7BDAE10945407365506D708A4E40390B7BDAE1094540F2B0506B9A894E40043DD4B661084540F2B0506B9A894E40
18713	Хозьмино	3	26	1404	41.601258999999999	41.618462000000001	61.200364999999998	61.194881000000002	0103000020E610000001000000050000007CB60E0EF6CC44404FCE50DCF1984E407CB60E0EF6CC4440AB21718FA5994E40CDE847C329CF4440AB21718FA5994E40CDE847C329CF44404FCE50DCF1984E407CB60E0EF6CC44404FCE50DCF1984E40
17470	Усть-Шоноша	3	26	1404	41.307699	41.397638000000001	61.153944000000003	61.136744999999998	0103000020E6100000010000000500000086014BAE62A744401D7233DC80914E4086014BAE62A744402DB5DE6FB4934E40CCD24ECDE5B244402DB5DE6FB4934E40CCD24ECDE5B244401D7233DC80914E4086014BAE62A744401D7233DC80914E40
17286	Тимонино	3	26	1404	41.958519000000003	41.973036	61.5199	61.512442	0103000020E610000001000000050000001DCC26C0B0FA4440658C0FB397C14E401DCC26C0B0FA44405F984C158CC24E4053EA92718CFC44405F984C158CC24E4053EA92718CFC4440658C0FB397C14E401DCC26C0B0FA4440658C0FB397C14E40
17434	Теребино	3	26	1404	42.096977000000003	42.116442999999997	60.871071999999998	60.860331000000002	0103000020E610000001000000050000006BBB09BE690C4540145E82531F6E4E406BBB09BE690C45400C3B8C497F6F4E408F6CAE9AE70E45400C3B8C497F6F4E408F6CAE9AE70E4540145E82531F6E4E406BBB09BE690C4540145E82531F6E4E40
18259	Тегрозеро	3	26	1404	41.511040999999999	41.530462999999997	61.669052999999998	61.657946000000003	0103000020E6100000010000000500000023F59ECA69C144405B44149337D44E4023F59ECA69C1444035255987A3D54E40785E2A36E6C3444035255987A3D54E40785E2A36E6C344405B44149337D44E4023F59ECA69C144405B44149337D44E40
16831	Средний	3	26	1404	41.138294999999999	41.153485000000003	61.191412999999997	61.183824000000001	0103000020E61000000100000005000000A4198BA6B3914440261C7A8B87974E40A4198BA6B3914440BE839F3880984E409AB67F65A5934440BE839F3880984E409AB67F65A5934440261C7A8B87974E40A4198BA6B3914440261C7A8B87974E40
18122	Солгинский	3	26	1404	41.321632000000001	41.361077000000002	61.059198000000002	61.040165999999999	0103000020E610000001000000050000006DACC43C2BA94440A034D42824854E406DACC43C2BA944408BFED0CC93874E403D2B69C537AE44408BFED0CC93874E403D2B69C537AE4440A034D42824854E406DACC43C2BA94440A034D42824854E40
18689	Смольянская	3	26	1404	41.557619000000003	41.575001999999998	61.297806000000001	61.286444000000003	0103000020E610000001000000050000006A50340F60C7444056116E32AAA44E406A50340F60C74440BB46CB811EA64E403A9160AA99C94440BB46CB811EA64E403A9160AA99C9444056116E32AAA44E406A50340F60C7444056116E32AAA44E40
18420	Синега	3	26	1404	41.750523000000001	41.778156000000003	61.082900000000002	61.073737000000001	0103000020E61000000100000005000000AAF23D2311E04440A9C0C93670894E40AAF23D2311E04440516B9A779C8A4E40D597A59D9AE34440516B9A779C8A4E40D597A59D9AE34440A9C0C93670894E40AAF23D2311E04440A9C0C93670894E40
17833	Саргино	3	26	1404	42.882257000000003	42.897663000000001	61.664946	61.655439000000001	0103000020E6100000010000000500000063D520CCED704540F0C2D66CE5D34E4063D520CCED70454092CD55F31CD54E4025EA059FE672454092CD55F31CD54E4025EA059FE6724540F0C2D66CE5D34E4063D520CCED704540F0C2D66CE5D34E40
17650	Притыкинская	3	26	1404	41.767484000000003	41.779207	60.949320999999998	60.942321	0103000020E61000000100000005000000051A6CEA3CE24440C1AA7AF99D784E40051A6CEA3CE24440F833BC5983794E403AE8120EBDE34440F833BC5983794E403AE8120EBDE34440C1AA7AF99D784E40051A6CEA3CE24440C1AA7AF99D784E40
18380	Прилуцкая	3	26	1404	41.966047000000003	41.976405	61.080629000000002	61.071896000000002	0103000020E6100000010000000500000010B3976DA7FB44404B5B5CE333894E4010B3976DA7FB4440FA0D130D528A4E405053CBD6FAFC4440FA0D130D528A4E405053CBD6FAFC44404B5B5CE333894E4010B3976DA7FB44404B5B5CE333894E40
18170	Погост	3	26	1404	42.378678999999998	42.385649999999998	61.284208999999997	61.274684999999998	0103000020E610000001000000050000004B57B08D78304540D3D9C9E028A34E404B57B08D783045404B1DE4F560A44E40E8D9ACFA5C3145404B1DE4F560A44E40E8D9ACFA5C314540D3D9C9E028A34E404B57B08D78304540D3D9C9E028A34E40
17690	Пежма	3	26	1404	41.741370000000003	41.812004000000002	61.021127	60.964146	0103000020E61000000100000005000000261E5036E5DE4440DC48D922697B4E40261E5036E5DE444003081F4AB4824E40501C40BFEFE7444003081F4AB4824E40501C40BFEFE74440DC48D922697B4E40261E5036E5DE4440DC48D922697B4E40
17750	Пасьва	3	26	1404	42.702638999999998	42.738787000000002	61.590462000000002	61.57611	0103000020E6100000010000000500000073F22213F05945400473F4F8BDC94E4073F22213F0594540F0C3414294CB4E40E0DA8992905E4540F0C3414294CB4E40E0DA8992905E45400473F4F8BDC94E4073F22213F05945400473F4F8BDC94E40
17790	Павловское	3	26	1404	42.552216000000001	42.568871000000001	61.593423999999999	61.584814999999999	0103000020E61000000100000005000000FA298E03AF464540E99AC937DBCA4E40FA298E03AF464540AC545051F5CB4E404852D2C3D0484540AC545051F5CB4E404852D2C3D0484540E99AC937DBCA4E40FA298E03AF464540E99AC937DBCA4E40
16241	Новый Куваш	3	26	1404	41.635385999999997	41.647486999999998	61.039282	61.032406000000002	0103000020E610000001000000050000000A2B155454D14440DB183BE125844E400A2B155454D1444026A94C3107854E40E6CAA0DAE0D2444026A94C3107854E40E6CAA0DAE0D24440DB183BE125844E400A2B155454D14440DB183BE125844E40
40349	Никифорово	3	26	1404	41.898296000000002	41.916477999999998	61.026166000000003	61.013899000000002	0103000020E610000001000000050000005610035DFBF244403B394371C7814E405610035DFBF244403222516859834E4072C0AE264FF544403222516859834E4072C0AE264FF544403B394371C7814E405610035DFBF244403B394371C7814E40
16702	Нестюковская	3	26	1404	42.220081999999998	42.239297000000001	61.001739999999998	60.993704999999999	0103000020E610000001000000050000001938A0A52B1C4540936FB6B9317F4E401938A0A52B1C45402A8C2D0439804E40F583BA48A11E45402A8C2D0439804E40F583BA48A11E4540936FB6B9317F4E401938A0A52B1C4540936FB6B9317F4E40
16546	Мелединская	3	26	1404	42.430709999999998	42.446457000000002	60.987321000000001	60.977074000000002	0103000020E61000000100000005000000B3075A8121374540CEE2C5C2107D4E40B3075A8121374540B7D3D688607E4E40FF08C38025394540B7D3D688607E4E40FF08C38025394540CEE2C5C2107D4E40B3075A8121374540CEE2C5C2107D4E40
17233	Малая Липовка	3	26	1404	41.849651999999999	41.882710000000003	61.509566999999997	61.502682	0103000020E61000000100000005000000917D9065C1EC4440D9243FE257C04E40917D9065C1EC4440770FD07D39C14E4014ED2AA4FCF04440770FD07D39C14E4014ED2AA4FCF04440D9243FE257C04E40917D9065C1EC4440D9243FE257C04E40
16740	Лодейное	3	26	1404	41.371397999999999	41.378881	61.257029000000003	61.250551000000002	0103000020E6100000010000000500000060E63BF889AF4440747D1F0E12A04E4060E63BF889AF4440D28F8653E6A04E40B309302C7FB04440D28F8653E6A04E40B309302C7FB04440747D1F0E12A04E4060E63BF889AF4440747D1F0E12A04E40
16575	Лиходиевский Погост	3	26	1404	42.463175	42.480835999999996	60.835057999999997	60.825187	0103000020E6100000010000000500000093A98251493B4540CC0A45BA9F694E4093A98251493B4540AF21382EE36A4E40A65EB7088C3D4540AF21382EE36A4E40A65EB7088C3D4540CC0A45BA9F694E4093A98251493B4540CC0A45BA9F694E40
18744	Леушинская	3	26	1404	41.917079999999999	41.943904000000003	61.165166999999997	61.158931000000003	0103000020E6100000010000000500000068E89FE062F5444009A9DBD957944E4068E89FE062F5444070B0373124954E402448A5D8D1F8444070B0373124954E402448A5D8D1F8444009A9DBD957944E4068E89FE062F5444009A9DBD957944E40
16889	Кулой	3	26	1404	42.436844999999998	42.532884000000003	61.041258999999997	61.022094000000003	0103000020E61000000100000005000000E7357689EA3745400BB8E7F9D3824E40E7357689EA37454034D593F947854E40E547FC8A3544454034D593F947854E40E547FC8A354445400BB8E7F9D3824E40E7357689EA3745400BB8E7F9D3824E40
16801	Комсомольский	3	26	1404	41.128117000000003	41.151831999999999	61.329746999999998	61.316747999999997	0103000020E61000000100000005000000E4874A23669044406589CE328BA84E40E4874A2366904440207A522635AA4E403E3E213B6F934440207A522635AA4E403E3E213B6F9344406589CE328BA84E40E4874A23669044406589CE328BA84E40
18047	Козловская	3	26	1404	42.833703	42.848103000000002	61.107519000000003	61.098367000000003	0103000020E61000000100000005000000DEC9A7C7B66A4540B900344A978C4E40DEC9A7C7B66A45406D59BE2EC38D4E40DB519CA38E6C45406D59BE2EC38D4E40DB519CA38E6C4540B900344A978C4E40DEC9A7C7B66A4540B900344A978C4E40
17958	Игнатовка	3	26	1404	42.418475000000001	42.437536999999999	61.482939000000002	61.474277999999998	0103000020E61000000100000005000000C898BB96903545402C9B3924B5BC4E40C898BB9690354540427BF5F1D0BD4E401DE5603601384540427BF5F1D0BD4E401DE56036013845402C9B3924B5BC4E40C898BB96903545402C9B3924B5BC4E40
17533	Ефремковская	3	26	1404	42.074761000000002	42.104962999999998	61.347323000000003	61.334826999999997	0103000020E610000001000000050000001502B9C491094540AD68739CDBAA4E401502B9C49109454006137F1475AC4E402025766D6F0D454006137F1475AC4E402025766D6F0D4540AD68739CDBAA4E401502B9C491094540AD68739CDBAA4E40
15854	Дюковская	3	26	1404	42.086008	42.118859999999998	61.094684000000001	61.083601000000002	0103000020E61000000100000005000000E198654F020B4540DA740470B38A4E40E198654F020B45402CBAF59A1E8C4E40BA66F2CD360F45402CBAF59A1E8C4E40BA66F2CD360F4540DA740470B38A4E40E198654F020B4540DA740470B38A4E40
17886	Долматово	3	26	1404	42.324995999999999	42.362222000000003	61.551129000000003	61.533800999999997	0103000020E6100000010000000500000058AA0B78992945403AC9569753C44E4058AA0B7899294540487023658BC64E4024F25D4A5D2E4540487023658BC64E4024F25D4A5D2E45403AC9569753C44E4058AA0B78992945403AC9569753C44E40
17373	Горка-Муравьевская	3	26	1404	42.124510000000001	42.144435000000001	61.108832	61.098554	0103000020E61000000100000005000000320395F1EF0F4540EB71DF6A9D8C4E40320395F1EF0F45400F61FC34EE8D4E40EAB298D87C1245400F61FC34EE8D4E40EAB298D87C124540EB71DF6A9D8C4E40320395F1EF0F4540EB71DF6A9D8C4E40
17142	Георгиевское	3	26	1404	41.548357000000003	41.575944999999997	61.539327999999998	61.531751	0103000020E610000001000000050000002FC4EA8F30C64440C24EB16A10C44E402FC4EA8F30C6444096E82CB308C54E40B9A5D590B8C9444096E82CB308C54E40B9A5D590B8C94440C24EB16A10C44E402FC4EA8F30C64440C24EB16A10C44E40
16486	Воскресенское	3	26	1404	42.484248999999998	42.496116000000001	61.475993000000003	61.467523	0103000020E61000000100000005000000730F09DFFB3D45405C902DCBD7BB4E40730F09DFFB3D4540FE0FB056EDBC4E40DC82A5BA803F4540FE0FB056EDBC4E40DC82A5BA803F45405C902DCBD7BB4E40730F09DFFB3D45405C902DCBD7BB4E40
17327	Вороновская	3	26	1404	42.113163999999998	42.124977000000001	61.098680000000002	61.091656999999998	0103000020E61000000100000005000000D28A6F287C0E454088B9A46ABB8B4E40D28A6F287C0E45407862D68BA18C4E4048E00F3FFF0F45407862D68BA18C4E4048E00F3FFF0F454088B9A46ABB8B4E40D28A6F287C0E454088B9A46ABB8B4E40
18251	Верхопуйский	3	26	1404	41.394413	41.418596000000001	61.610897999999999	61.601418000000002	0103000020E61000000100000005000000020F0C207CB24440E59CD843FBCC4E40020F0C207CB244408D98D9E731CE4E40431EC18D94B544408D98D9E731CE4E40431EC18D94B54440E59CD843FBCC4E40020F0C207CB24440E59CD843FBCC4E40
15459	Вельск	3	26	1404	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
17973	Великое	3	26	1404	42.216020999999998	42.229971999999997	61.535271999999999	61.528444999999998	0103000020E61000000100000005000000E61F7D93A61B45400B5EF415A4C34E40E61F7D93A61B4540753BFBCA83C44E40737FF5B86F1D4540753BFBCA83C44E40737FF5B86F1D45400B5EF415A4C34E40E61F7D93A61B45400B5EF415A4C34E40
16422	Боровое	3	26	1404	42.754939	42.779975	61.362273000000002	61.356188000000003	0103000020E61000000100000005000000CBBC55D7A1604540249D819197AD4E40CBBC55D7A1604540A69C2FF65EAE4E404B598638D6634540A69C2FF65EAE4E404B598638D6634540249D819197AD4E40CBBC55D7A1604540249D819197AD4E40
16403	Благовещенское	3	26	1404	42.530853999999998	42.566203000000002	61.465409000000001	61.454706000000002	0103000020E61000000100000005000000B3791C06F3434540C2A563CE33BA4E40B3791C06F3434540CD21A98592BB4E40D4F2035779484540CD21A98592BB4E40D4F2035779484540C2A563CE33BA4E40B3791C06F3434540C2A563CE33BA4E40
16332	Аргуновский	3	26	1404	42.165832000000002	42.172803000000002	61.083579	61.078035999999997	0103000020E61000000100000005000000AD50A4FB3915454090F46915FD894E40AD50A4FB39154540F2D077B7B28A4E404AD3A0681E164540F2D077B7B28A4E404AD3A0681E16454090F46915FD894E40AD50A4FB3915454090F46915FD894E40
2	Санкт-Петербург	3	\N	\N	29.425108000000002	30.759285999999999	60.245415999999999	59.633710999999998	0103000020E610000001000000050000009A44BDE0D36C3D40C70E2A711DD14D409A44BDE0D36C3D4023F59ECA691F4E40874F3A9160C23E4023F59ECA691F4E40874F3A9160C23E40C70E2A711DD14D409A44BDE0D36C3D40C70E2A711DD14D40
58046	п.имени Кирова	7	66	\N	47.155731000000003	47.166969000000002	56.112613000000003	56.111167999999999	0103000020E6100000010000000500000098FC4FFEEE9347404D2EC6C03A0E4C4098FC4FFEEE9347405F0D501A6A0E4C4011397D3D5F9547405F0D501A6A0E4C4011397D3D5F9547404D2EC6C03A0E4C4098FC4FFEEE9347404D2EC6C03A0E4C40
57863	Ядрин	7	66	\N	46.180134000000002	46.217576000000001	55.959228000000003	55.928919999999998	0103000020E61000000100000005000000E77283A10E174740D74CBED9E6F64B40E77283A10E17474029B4ACFBC7FA4B407F32C687D91B474029B4ACFBC7FA4B407F32C687D91B4740D74CBED9E6F64B40E77283A10E174740D74CBED9E6F64B40
2126	Шумерля	7	66	\N	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61	Чебоксары	7	66	\N	47.134684	47.380229	56.199477000000002	56.059840999999999	0103000020E61000000100000005000000B1A547533D914740DFFAB0DEA8074C40B1A547533D914740F0A65B7688194C40D2FE0758ABB04740F0A65B7688194C40D2FE0758ABB04740DFFAB0DEA8074C40B1A547533D914740DFFAB0DEA8074C40
57859	Цивильск	7	66	\N	47.450442000000002	47.499282999999998	55.882908999999998	55.851838999999998	0103000020E61000000100000005000000575F5D15A8B947408A3A730F09ED4B40575F5D15A8B947400A2C802903F14B4071395E81E8BF47400A2C802903F14B4071395E81E8BF47408A3A730F09ED4B40575F5D15A8B947408A3A730F09ED4B40
21149	Новочебоксарск	7	66	\N	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
52521	Новое Байдеряково	7	66	\N	48.094129000000002	48.119722000000003	55.020301000000003	55.010503999999997	0103000020E61000000100000005000000774D486B0C0C4840143DF03158814B40774D486B0C0C4840BE89213999824B404D4EED0C530F4840BE89213999824B404D4EED0C530F4840143DF03158814B40774D486B0C0C4840143DF03158814B40
57858	Мариинский Посад	7	66	\N	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
57865	Козловка	7	66	\N	48.205305000000003	48.297956999999997	55.853985999999999	55.804197000000002	0103000020E61000000100000005000000475A2A6F471A48404A4563EDEFE64B40475A2A6F471A4840F59ECA694FED4B40A04E797423264840F59ECA694FED4B40A04E7974232648404A4563EDEFE64B40475A2A6F471A48404A4563EDEFE64B40
4268	Канаш	7	66	\N	47.443767000000001	47.548456999999999	55.526499999999999	55.491100000000003	0103000020E61000000100000005000000A305685BCDB847406688635DDCBE4B40A305685BCDB8474008AC1C5A64C34B409221C7D633C6474008AC1C5A64C34B409221C7D633C647406688635DDCBE4B40A305685BCDB847406688635DDCBE4B40
12030	Канаш	7	66	\N	47.839151999999999	47.846634999999999	54.771459999999998	54.766250999999997	0103000020E61000000100000005000000BE2F2E5569EB47407EC3448314624B40BE2F2E5569EB474009168733BF624B40115322895EEC474009168733BF624B40115322895EEC47407EC3448314624B40BE2F2E5569EB47407EC3448314624B40
57914	Ибреси	7	66	\N	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
314	Алатырь	7	66	\N	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
20441	Яншихово-Норваши	7	66	1567	47.620412000000002	47.660620000000002	55.569713	55.553865000000002	0103000020E61000000100000005000000E20511A969CF474014B35E0CE5C64B40E20511A969CF4740938D075BECC84B40B18A37328FD44740938D075BECC84B40B18A37328FD4474014B35E0CE5C64B40E20511A969CF474014B35E0CE5C64B40
20068	Янтиково	7	66	1567	47.763657000000002	47.787804000000001	55.532955999999999	55.505673999999999	0103000020E61000000100000005000000452E3883BFE147400038F6ECB9C04B40452E3883BFE147407E1AF7E637C44B4039D4EFC2D6E447407E1AF7E637C44B4039D4EFC2D6E447400038F6ECB9C04B40452E3883BFE147400038F6ECB9C04B40
19960	Шимкусы	7	66	1567	47.928570000000001	47.961852999999998	55.552199999999999	55.541311	0103000020E61000000100000005000000FB05BB61DBF6474087FBC8AD49C54B40FB05BB61DBF64740F46C567DAEC64B409D47C5FF1DFB4740F46C567DAEC64B409D47C5FF1DFB474087FBC8AD49C54B40FB05BB61DBF6474087FBC8AD49C54B40
19847	Чутеево	7	66	1567	47.814816	47.839393999999999	55.399228999999998	55.383592	0103000020E61000000100000005000000F72004E44BE84740ED80EB8A19B14B40F72004E44BE84740B14E95EF19B34B40B43A394371EB4740B14E95EF19B34B40B43A394371EB4740ED80EB8A19B14B40F72004E44BE84740ED80EB8A19B14B40
19179	Уразлино	7	66	1567	47.820915999999997	47.844037999999998	55.527982999999999	55.517200000000003	0103000020E61000000100000005000000AE6186C613E94740E0BE0E9C33C24B40AE6186C613E9474007EC6AF294C34B40664AEB6F09EC474007EC6AF294C34B40664AEB6F09EC4740E0BE0E9C33C24B40AE6186C613E94740E0BE0E9C33C24B40
19020	Уразкасы	7	66	1567	47.718947999999997	47.744900000000001	55.576349999999998	55.565544000000003	0103000020E6100000010000000500000026C3F17C06DC47407A39ECBE63C84B4026C3F17C06DC4740598638D6C5C94B402C6519E258DF4740598638D6C5C94B402C6519E258DF47407A39ECBE63C84B4026C3F17C06DC47407A39ECBE63C84B40
19592	Тюмерево	7	66	1567	47.75665	47.790273999999997	55.449525999999999	55.429180000000002	0103000020E610000001000000050000005B423EE8D9E04740740CC85EEFB64B405B423EE8D9E04740D15966118AB94B408670CCB227E54740D15966118AB94B408670CCB227E54740740CC85EEFB64B405B423EE8D9E04740740CC85EEFB64B40
19488	Турмыши	7	66	1567	47.645240999999999	47.683204000000003	55.521669000000003	55.504792000000002	0103000020E61000000100000005000000E884D04197D2474027A435069DC04B40E884D04197D24740242BBF0CC6C24B408A3F8A3A73D74740242BBF0CC6C24B408A3F8A3A73D7474027A435069DC04B40E884D04197D2474027A435069DC04B40
19121	Тенеево	7	66	1567	47.911996000000002	47.941721000000001	55.511012000000001	55.501849999999997	0103000020E610000001000000050000009A0AF148BCF44740B1BFEC9E3CC04B409A0AF148BCF4474089EE59D768C14B406C7A50508AF8474089EE59D768C14B406C7A50508AF84740B1BFEC9E3CC04B409A0AF148BCF44740B1BFEC9E3CC04B40
19442	Старое Буяново	7	66	1567	47.782836000000003	47.803066000000001	55.556089999999998	55.546379000000002	0103000020E61000000100000005000000D41055F833E44740501C40BFEFC54B40D41055F833E44740FAD005F52DC74B40C843DFDDCAE64740FAD005F52DC74B40C843DFDDCAE64740501C40BFEFC54B40D41055F833E44740501C40BFEFC54B40
20313	Салагаево	7	66	1567	47.809049000000002	47.833483000000001	55.511088000000001	55.496766000000001	0103000020E6100000010000000500000046EEE9EA8EE74740E3E13D0796BF4B4046EEE9EA8EE7474064B0E2546BC14B40D0622992AFEA474064B0E2546BC14B40D0622992AFEA4740E3E13D0796BF4B4046EEE9EA8EE74740E3E13D0796BF4B40
20263	Русские Норваши	7	66	1567	47.723449000000002	47.743589	55.531993	55.525191	0103000020E6100000010000000500000076A911FA99DC4740A7936C7539C34B4076A911FA99DC4740B859BC5818C44B402A55A2EC2DDF4740B859BC5818C44B402A55A2EC2DDF4740A7936C7539C34B4076A911FA99DC4740A7936C7539C34B40
18971	Нюшкасы	7	66	1567	47.755312000000004	47.774670999999998	55.612029	55.601593999999999	0103000020E6100000010000000500000060234910AEE0474023BC3D0801CD4B4060234910AEE047400F9A5DF756CE4B406E14596B28E347400F9A5DF756CE4B406E14596B28E3474023BC3D0801CD4B4060234910AEE0474023BC3D0801CD4B40
20528	Норваш-Кошки	7	66	1567	47.688073000000003	47.706093000000003	55.547865999999999	55.537785999999997	0103000020E610000001000000050000005C21ACC612D84740921FF12BD6C44B405C21ACC612D84740904B1C7920C64B409F77634161DA4740904B1C7920C64B409F77634161DA4740921FF12BD6C44B405C21ACC612D84740921FF12BD6C44B40
19908	Новое Ишино	7	66	1567	47.775793	47.797550999999999	55.378129999999999	55.365524999999998	0103000020E610000001000000050000009DBB5D2F4DE34740696FF085C9AE4B409DBB5D2F4DE3474078D1579066B04B4030F2B22616E6474078D1579066B04B4030F2B22616E64740696FF085C9AE4B409DBB5D2F4DE34740696FF085C9AE4B40
19384	Новое Буяново	7	66	1567	47.790193000000002	47.810800999999998	55.57009	55.557872000000003	0103000020E610000001000000050000009A43520B25E5474054AD855968C74B409A43520B25E5474069E388B5F8C84B403448C153C8E7474069E388B5F8C84B403448C153C8E7474054AD855968C74B409A43520B25E5474054AD855968C74B40
20021	Нижарово	7	66	1567	47.875523999999999	47.902070000000002	55.574894999999998	55.556705999999998	0103000020E610000001000000050000007A6EA12B11F0474055BE672442C74B407A6EA12B11F0474024D1CB2896C94B40F3599E0777F3474024D1CB2896C94B40F3599E0777F3474055BE672442C74B407A6EA12B11F0474055BE672442C74B40
19239	Можарки	7	66	1567	47.803694999999998	47.833447	55.479168999999999	55.463549	0103000020E61000000100000005000000B77A4E7ADFE64740F88BD99255BB4B40B77A4E7ADFE64740E620E86855BD4B4083F92B64AEEA4740E620E86855BD4B4083F92B64AEEA4740F88BD99255BB4B40B77A4E7ADFE64740F88BD99255BB4B40
19551	Латышево	7	66	1567	47.690966000000003	47.718570999999997	55.51173	55.500106000000002	0103000020E61000000100000005000000F052EA9271D847404644317903C04B40F052EA9271D84740E8305F5E80C14B40506D7022FADB4740E8305F5E80C14B40506D7022FADB47404644317903C04B40F052EA9271D847404644317903C04B40
19329	Кичкеево	7	66	1567	47.895332000000003	47.913145999999998	55.469386999999998	55.454324999999997	0103000020E61000000100000005000000F9872D3D9AF24740AA60545227BA4B40F9872D3D9AF2474072158BDF14BC4B40923CD7F7E1F4474072158BDF14BC4B40923CD7F7E1F44740AA60545227BA4B40F9872D3D9AF24740AA60545227BA4B40
19805	Кармалы	7	66	1567	47.688836999999999	47.715777000000003	55.449409000000003	55.429496999999998	0103000020E610000001000000050000002BA391CF2BD84740745DF8C1F9B64B402BA391CF2BD8474098C3EE3B86B94B40501DAB949EDB474098C3EE3B86B94B40501DAB949EDB4740745DF8C1F9B64B402BA391CF2BD84740745DF8C1F9B64B40
19086	Индырчи	7	66	1567	47.856048999999999	47.882638999999998	55.525033000000001	55.510109	0103000020E6100000010000000500000002637D0393ED4740983270404BC14B4002637D0393ED47400F29064834C34B404A969350FAF047400F29064834C34B404A969350FAF04740983270404BC14B4002637D0393ED4740983270404BC14B40
20184	Иваново	7	66	1567	47.735306000000001	47.752077999999997	55.508966999999998	55.500329999999998	0103000020E61000000100000005000000BB46CB811EDE4740959A3DD00AC04B40BB46CB811EDE474022DFA5D425C14B404205871744E0474022DFA5D425C14B404205871744E04740959A3DD00AC04B40BB46CB811EDE4740959A3DD00AC04B40
19283	Гришино	7	66	1567	47.872478999999998	47.897488000000003	55.484357000000003	55.473255000000002	0103000020E6100000010000000500000030B95164ADEF474091D5AD9E93BC4B4030B95164ADEF47405A4B0169FFBD4B40B74604E3E0F247405A4B0169FFBD4B40B74604E3E0F2474091D5AD9E93BC4B4030B95164ADEF474091D5AD9E93BC4B40
18910	Беляево	7	66	1567	47.716154000000003	47.744388000000001	55.591813000000002	55.578319999999998	0103000020E6100000010000000500000026732CEFAADB4740B54FC76306CA4B4026732CEFAADB4740802C4487C0CB4B4076C4211B48DF4740802C4487C0CB4B4076C4211B48DF4740B54FC76306CA4B4026732CEFAADB4740B54FC76306CA4B40
19704	Бахтиарово	7	66	1567	47.713217	47.740093999999999	55.463028000000001	55.450465999999999	0103000020E61000000100000005000000C2F9D4B14ADB4740DFFAB0DEA8B94B40C2F9D4B14ADB4740EF90628044BB4B40A0FB7266BBDE4740EF90628044BB4B40A0FB7266BBDE4740DFFAB0DEA8B94B40C2F9D4B14ADB4740DFFAB0DEA8B94B40
19640	Амалыково	7	66	1567	47.844470000000001	47.866855999999999	55.428981	55.415835000000001	0103000020E61000000100000005000000003ACC9717EC47401EC4CE143AB54B40003ACC9717EC47407DCD72D9E8B64B40B22B2D23F5EE47407DCD72D9E8B64B40B22B2D23F5EE47401EC4CE143AB54B40003ACC9717EC47401EC4CE143AB54B40
18876	Алдиарово	7	66	1567	47.746597999999999	47.773879999999998	55.593353999999998	55.580207000000001	0103000020E6100000010000000500000027A1F48590DF474084F4143944CA4B4027A1F48590DF4740B3791C06F3CB4B40A583F57F0EE34740B3791C06F3CB4B40A583F57F0EE3474084F4143944CA4B4027A1F48590DF474084F4143944CA4B40
61568	Яльчики	7	66	708	47.987841000000003	48.029207999999997	55.167574999999999	55.155546000000001	0103000020E61000000100000005000000F052EA9271FE474006836BEEE8934B40F052EA9271FE47404850FC1873954B400A647616BD0348404850FC1873954B400A647616BD03484006836BEEE8934B40F052EA9271FE474006836BEEE8934B40
16627	Яльчики	7	66	708	47.987841000000003	48.029207999999997	55.167574999999999	55.155546000000001	0103000020E61000000100000005000000F052EA9271FE474006836BEEE8934B40F052EA9271FE47404850FC1873954B400A647616BD0348404850FC1873954B400A647616BD03484006836BEEE8934B40F052EA9271FE474006836BEEE8934B40
52532	Эшмикеево	7	66	708	47.876665000000003	47.893211999999998	55.035524000000002	55.025435999999999	0103000020E610000001000000050000002046088F36F047400E12A27C41834B402046088F36F047408F1CE90C8C844B40873254C554F247408F1CE90C8C844B40873254C554F247400E12A27C41834B402046088F36F047400E12A27C41834B40
52504	Эмметево	7	66	708	47.741469000000002	47.756255000000003	55.229146999999998	55.222856999999998	0103000020E61000000100000005000000B9FFC874E8DE4740A3570394869C4B40B9FFC874E8DE4740FE7C5BB0549D4B40DF37BEF6CCE04740FE7C5BB0549D4B40DF37BEF6CCE04740A3570394869C4B40B9FFC874E8DE4740A3570394869C4B40
52514	Шемалаково	7	66	708	47.888891000000001	47.927312000000001	54.979185000000001	54.965206999999999	0103000020E61000000100000005000000B85A272EC7F14740656F29E78B7B4B40B85A272EC7F14740ECDD1FEF557D4B401C98DC28B2F64740ECDD1FEF557D4B401C98DC28B2F64740656F29E78B7B4B40B85A272EC7F14740656F29E78B7B4B40
21314	Старое Янашево	7	66	708	47.965634000000001	47.989071000000003	55.201587000000004	55.183599999999998	0103000020E61000000100000005000000EDF318E599FB4740D6C56D3480974B40EDF318E599FB47403E26529ACD994B400536E7E099FE47403E26529ACD994B400536E7E099FE4740D6C56D3480974B40EDF318E599FB4740D6C56D3480974B40
52534	Старое Арланово	7	66	708	47.837310000000002	47.852995	55.043174999999998	55.030602000000002	0103000020E61000000100000005000000904E5DF92CEB47409A982EC4EA834B40904E5DF92CEB47409D8026C286854B406553AEF02EED47409D8026C286854B406553AEF02EED47409A982EC4EA834B40904E5DF92CEB47409A982EC4EA834B40
52551	Сабанчино	7	66	708	47.886609999999997	47.922111000000001	55.160308999999998	55.147196000000001	0103000020E610000001000000050000003D27BD6F7CF147400F0D8B51D7924B403D27BD6F7CF1474092205C0185944B401424B6BB07F6474092205C0185944B401424B6BB07F647400F0D8B51D7924B403D27BD6F7CF147400F0D8B51D7924B40
52502	Полевые Пинеры	7	66	708	47.798870999999998	47.811115000000001	55.255220999999999	55.243910999999997	0103000020E61000000100000005000000855CA96741E647403C11C479389F4B40855CA96741E647404F20EC14ABA04B40C425C79DD2E747404F20EC14ABA04B40C425C79DD2E747403C11C479389F4B40855CA96741E647403C11C479389F4B40
52167	Полевые Козыльяры	7	66	708	47.853569999999998	47.876134999999998	55.178742999999997	55.169888999999998	0103000020E61000000100000005000000616C21C841ED47409E7939ECBE954B40616C21C841ED4740C8B1F50CE1964B40C3F0113125F04740C8B1F50CE1964B40C3F0113125F047409E7939ECBE954B40616C21C841ED47409E7939ECBE954B40
58055	Полевые Буртасы	7	66	708	47.741819	47.759982999999998	55.181533999999999	55.168289999999999	0103000020E610000001000000050000009546CCECF3DE4740361FD7868A954B409546CCECF3DE4740588E90813C974B400B42791F47E14740588E90813C974B400B42791F47E14740361FD7868A954B409546CCECF3DE4740361FD7868A954B40
32765	Новые Шимкусы	7	66	708	47.747326000000001	47.784354	55.160324000000003	55.152773000000003	0103000020E61000000100000005000000AAB9DC60A8DF47401D5BCF108E934B40AAB9DC60A8DF4740C861307F85944B404F3E3DB665E44740C861307F85944B404F3E3DB665E447401D5BCF108E934B40AAB9DC60A8DF47401D5BCF108E934B40
58031	Новопоселенная Таяба	7	66	708	47.992089999999997	48.003453999999998	55.285687000000003	55.279262000000003	0103000020E6100000010000000500000025581CCEFCFE4740FE8172DBBEA34B4025581CCEFCFE474039F2406491A44B402B85402E7100484039F2406491A44B402B85402E71004840FE8172DBBEA34B4025581CCEFCFE4740FE8172DBBEA34B40
21749	Новое Янашево	7	66	708	48.001261999999997	48.012607000000003	55.115006999999999	55.106695999999999	0103000020E61000000100000005000000205D6C5A29004840984EEB36A88D4B40205D6C5A29004840D1E7A38CB88E4B40B0592E1B9D014840D1E7A38CB88E4B40B0592E1B9D014840984EEB36A88D4B40205D6C5A29004840984EEB36A88D4B40
52508	Новое Чурино	7	66	708	47.806973999999997	47.827995000000001	55.168284999999997	55.158940000000001	0103000020E61000000100000005000000745C8DEC4AE747405C035B2558944B40745C8DEC4AE7474024B4E55C8A954B4032207BBDFBE9474024B4E55C8A954B4032207BBDFBE947405C035B2558944B40745C8DEC4AE747405C035B2558944B40
52491	Новое Тойдеряково	7	66	708	47.949420000000003	47.973252000000002	55.159557999999997	55.152948000000002	0103000020E610000001000000050000008C15359886F947408BFED0CC93934B408C15359886F9474057E883656C944B402062838593FC474057E883656C944B402062838593FC47408BFED0CC93934B408C15359886F947408BFED0CC93934B40
32750	Новое Тинчурино	7	66	708	47.815122000000002	47.843994000000002	55.205784000000001	55.192466000000003	0103000020E610000001000000050000000420EEEA55E84740C5CBD3B9A2984B400420EEEA55E8474021054F21579A4B409702D2FE07EC474021054F21579A4B409702D2FE07EC4740C5CBD3B9A2984B400420EEEA55E84740C5CBD3B9A2984B40
4927	Новое Изамбаево	7	66	708	47.890715	47.909219999999998	55.095455999999999	55.089556999999999	0103000020E610000001000000050000004087F9F202F247405E10919A768B4B404087F9F202F247407E1AF7E6378C4B403F6F2A5261F447407E1AF7E6378C4B403F6F2A5261F447405E10919A768B4B404087F9F202F247405E10919A768B4B40
52493	Новое Булаево	7	66	708	48.011817000000001	48.025606000000003	55.150123999999998	55.143321999999998	0103000020E61000000100000005000000B7442E38830148400E66136058924B40B7442E38830148401F2C634337934B406B4AB20E470348401F2C634337934B406B4AB20E470348400E66136058924B40B7442E38830148400E66136058924B40
52509	Новое Байбатырево	7	66	708	47.811942000000002	47.841118999999999	55.160730000000001	55.148215	0103000020E61000000100000005000000DA1F28B7EDE7474069E388B5F8924B40DA1F28B7EDE7474038BEF6CC92944B40A98592C9A9EB474038BEF6CC92944B40A98592C9A9EB474069E388B5F8924B40DA1F28B7EDE7474069E388B5F8924B40
52518	Новое Андиберево	7	66	708	47.951431999999997	47.969551000000003	55.061157999999999	55.044165	0103000020E61000000100000005000000162F1686C8F947405D50DF32A7854B40162F1686C8F94740C3F17C06D4874B40ED66463F1AFC4740C3F17C06D4874B40ED66463F1AFC47405D50DF32A7854B40162F1686C8F947405D50DF32A7854B40
32529	Малая Таяба	7	66	708	47.947426	47.979028	55.229120999999999	55.212175000000002	0103000020E61000000100000005000000A7B0524145F94740B003E78C289B4B40A7B0524145F94740D5E940D6539D4B4024EF1CCA50FD4740D5E940D6539D4B4024EF1CCA50FD4740B003E78C289B4B40A7B0524145F94740B003E78C289B4B40
52541	Малая Ерыкла	7	66	708	47.892924999999998	47.916136999999999	55.193339999999999	55.179817	0103000020E61000000100000005000000F163CC5D4BF24740E621533E04974B40F163CC5D4BF247401B81785DBF984B40E9D32AFA43F547401B81785DBF984B40E9D32AFA43F54740E621533E04974B40F163CC5D4BF24740E621533E04974B40
32814	Лащ-Таяба	7	66	708	47.982640000000004	48.008457	55.039048000000001	55.014071000000001	0103000020E61000000100000005000000E8DEC325C7FD474038691A14CD814B40E8DEC325C7FD4740B37C5D86FF844B400D36751E15014840B37C5D86FF844B400D36751E1501484038691A14CD814B40E8DEC325C7FD474038691A14CD814B40
52501	Кушелга	7	66	708	47.810594000000002	47.838594999999998	55.272241000000001	55.257319000000003	0103000020E61000000100000005000000BB2A508BC1E74740D9D138D4EFA04B40BB2A508BC1E74740AFD007CBD8A24B4068CBB91457EB4740AFD007CBD8A24B4068CBB91457EB4740D9D138D4EFA04B40BB2A508BC1E74740D9D138D4EFA04B40
32873	Кошки-Куликеево	7	66	708	47.843876999999999	47.870888999999998	55.076731000000002	55.064483000000003	0103000020E610000001000000050000005D6C5A2904EC4740F1129CFA40884B405D6C5A2904EC474071CB4752D2894B401BB96E4A79EF474071CB4752D2894B401BB96E4A79EF4740F1129CFA40884B405D6C5A2904EC4740F1129CFA40884B40
32584	Кильдюшево	7	66	708	47.791711999999997	47.810935999999998	55.229717000000001	55.209266999999997	0103000020E61000000100000005000000E5EC9DD156E54740E690D442C99A4B40E5EC9DD156E54740E92ADD5D679D4B40149337C0CCE74740E92ADD5D679D4B40149337C0CCE74740E690D442C99A4B40E5EC9DD156E54740E690D442C99A4B40
52525	Избахтино	7	66	708	47.929675000000003	47.955312999999997	55.102739999999997	55.092489	0103000020E6100000010000000500000054742497FFF64740B01EF7ADD68B4B4054742497FFF64740DAFE9595268D4B40C93846B247FA4740DAFE9595268D4B40C93846B247FA4740B01EF7ADD68B4B4054742497FFF64740B01EF7ADD68B4B40
32653	Большие Яльчики	7	66	708	48.041316999999999	48.075507000000002	55.182994000000001	55.161949	0103000020E6100000010000000500000069E21DE049054840594FADBEBA944B4069E21DE0490548409FAEEE586C974B403ECF9F36AA0948409FAEEE586C974B403ECF9F36AA094840594FADBEBA944B4069E21DE049054840594FADBEBA944B40
32692	Большая Таяба	7	66	708	47.913648999999999	47.938127999999999	55.252014000000003	55.236119000000002	0103000020E61000000100000005000000F5824F73F2F447406C7BBB25399E4B40F5824F73F2F447402C11A8FE41A04B401FBB0B9414F847402C11A8FE41A04B401FBB0B9414F847406C7BBB25399E4B40F5824F73F2F447406C7BBB25399E4B40
61200	Белая Воложка	7	66	708	47.883546000000003	47.898978999999997	55.290925999999999	55.280676999999997	0103000020E610000001000000050000007D410B0918F14740A4DE5339EDA34B407D410B0918F147402EC72B103DA54B4038656EBE11F347402EC72B103DA54B4038656EBE11F34740A4DE5339EDA34B407D410B0918F14740A4DE5339EDA34B40
32641	Байдеряково	7	66	708	48.025651000000003	48.059849999999997	55.147787999999998	55.141438999999998	0103000020E610000001000000050000000B0E2F884803484081B053AC1A924B400B0E2F8848034840E15E99B7EA924B403255302AA9074840E15E99B7EA924B403255302AA907484081B053AC1A924B400B0E2F884803484081B053AC1A924B40
52524	Байглычево	7	66	708	47.963514000000004	47.985092000000002	55.102452	55.097192	0103000020E610000001000000050000007C9E3F6D54FB474067B796C9708C4B407C9E3F6D54FB474074B4AA251D8D4B408FC6A17E17FE474074B4AA251D8D4B408FC6A17E17FE474067B796C9708C4B407C9E3F6D54FB474067B796C9708C4B40
58073	Аранчеево	7	66	708	47.892609999999998	47.915346999999997	55.315499000000003	55.300567000000001	0103000020E61000000100000005000000910A630B41F24740E0A0BDFA78A64B40910A630B41F24740DA756F4562A84B40F0BE2A172AF54740DA756F4562A84B40F0BE2A172AF54740E0A0BDFA78A64B40910A630B41F24740E0A0BDFA78A64B40
25813	Ядрино	7	66	939	46.418322000000003	46.435929000000002	55.995463000000001	55.987734000000003	0103000020E61000000100000005000000429946938B354740DA9255116EFE4B40429946938B35474064B0E2546BFF4B4062307F85CC37474064B0E2546BFF4B4062307F85CC374740DA9255116EFE4B40429946938B354740DA9255116EFE4B40
9071	Юваново	7	66	939	46.524593000000003	46.567442999999997	56.071725000000001	56.053995	0103000020E61000000100000005000000F35A09DD25434740E292E34EE9064C40F35A09DD254347401EA7E8482E094C400CACE3F8A14847401EA7E8482E094C400CACE3F8A1484740E292E34EE9064C40F35A09DD25434740E292E34EE9064C40
28913	Чебаково	7	66	939	46.341749999999998	46.390771000000001	55.989693000000003	55.963459999999998	0103000020E6100000010000000500000039B4C876BE2B4740888043A852FB4B4039B4C876BE2B4740420A9E42AEFE4B40D49CBCC804324740420A9E42AEFE4B40D49CBCC804324740888043A852FB4B4039B4C876BE2B4740888043A852FB4B40
15773	Хочашево	7	66	939	46.412196000000002	46.435479999999998	55.826256000000001	55.817819999999998	0103000020E6100000010000000500000061C5A9D6C2344740E2016553AEE84B4061C5A9D6C2344740D80FB1C1C2E94B40F20703CFBD374740D80FB1C1C2E94B40F20703CFBD374740E2016553AEE84B4061C5A9D6C2344740E2016553AEE84B40
15902	Хорамалы	7	66	939	46.381833	46.405144	55.845986000000003	55.831260999999998	0103000020E610000001000000050000004CC45BE7DF3047405AB8ACC266EA4B404CC45BE7DF304740DB6FED4449EC4B40D71533C2DB334740DB6FED4449EC4B40D71533C2DB3347405AB8ACC266EA4B404CC45BE7DF3047405AB8ACC266EA4B40
15761	Хирле-Сиры	7	66	939	46.406796999999997	46.421143000000001	55.810622000000002	55.797331	0103000020E61000000100000005000000328E91EC11344740228B34F10EE64B40328E91EC1134474085B53176C2E74B403CF88903E835474085B53176C2E74B403CF88903E8354740228B34F10EE64B40328E91EC11344740228B34F10EE64B40
12950	Тяптяево	7	66	939	46.553662000000003	46.572626	56.097220999999998	56.086810999999997	0103000020E61000000100000005000000DC847B65DE4647406EF7729F1C0B4C40DC847B65DE46474001BEDBBC710C4C406E6B0BCF4B49474001BEDBBC710C4C406E6B0BCF4B4947406EF7729F1C0B4C40DC847B65DE4647406EF7729F1C0B4C40
16457	Талой	7	66	939	46.193931999999997	46.220458999999998	55.832828999999997	55.817915999999997	0103000020E61000000100000005000000EDD286C3D21847400470B378B1E84B40EDD286C3D2184740871403249AEA4B40EF8D2100381C4740871403249AEA4B40EF8D2100381C47400470B378B1E84B40EDD286C3D21847400470B378B1E84B40
14917	Стрелецкая	7	66	939	46.164026999999997	46.184904000000003	55.974111000000001	55.956707999999999	0103000020E610000001000000050000009B5434D6FE14474029E9616875FA4B409B5434D6FE14474041D653ABAFFC4B4026732CEFAA17474041D653ABAFFC4B4026732CEFAA17474029E9616875FA4B409B5434D6FE14474029E9616875FA4B40
15567	Старые Тиньгеши	7	66	939	46.483305999999999	46.500535999999997	55.840122999999998	55.834735000000002	0103000020E61000000100000005000000F4FA93F8DC3D4740CDE9B298D8EA4B40F4FA93F8DC3D474007CF842689EB4B403E3C4B901140474007CF842689EB4B403E3C4B9011404740CDE9B298D8EA4B40F4FA93F8DC3D4740CDE9B298D8EA4B40
57903	Совхозный	7	66	939	46.264161999999999	46.283107999999999	56.0458	56.040244000000001	0103000020E61000000100000005000000486C770FD02147401CEE23B726054C40486C770FD021474012143FC6DC054C40349E08E23C24474012143FC6DC054C40349E08E23C2447401CEE23B726054C40486C770FD02147401CEE23B726054C40
57906	Советское	7	66	939	46.534097000000003	46.561261999999999	55.866489999999999	55.851050000000001	0103000020E6100000010000000500000024F25D4A5D44474062A1D634EFEC4B4024F25D4A5D444740D027F224E9EE4B40683EE76ED7474740D027F224E9EE4B40683EE76ED747474062A1D634EFEC4B4024F25D4A5D44474062A1D634EFEC4B40
15616	Сехры	7	66	939	46.480755000000002	46.490969	55.859336999999996	55.848382000000001	0103000020E61000000100000005000000BA313D61893D4740EE4108C897EC4B40BA313D61893D4740129F3BC1FEED4B40C72C7B12D83E4740129F3BC1FEED4B40C72C7B12D83E4740EE4108C897EC4B40BA313D61893D4740EE4108C897EC4B40
16267	Сареево	7	66	939	46.270316000000001	46.298101000000003	55.926923000000002	55.913974000000003	0103000020E61000000100000005000000F3CAF5B69922474079B29B19FDF44B40F3CAF5B6992247408274B169A5F64B40D4F36E2C282647408274B169A5F64B40D4F36E2C2826474079B29B19FDF44B40F3CAF5B69922474079B29B19FDF44B40
15693	Салугино	7	66	939	46.425006000000003	46.444760000000002	55.786931000000003	55.777777999999998	0103000020E61000000100000005000000494DBB98663647402EC6C03A8EE34B40494DBB9866364740B39AAE27BAE44B40D4484BE5ED384740B39AAE27BAE44B40D4484BE5ED3847402EC6C03A8EE34B40494DBB98663647402EC6C03A8EE34B40
26909	Саваткино	7	66	939	46.493583000000001	46.509608999999998	55.997447000000001	55.992598000000001	0103000020E61000000100000005000000486E4DBA2D3F47409A0986730DFF4B40486E4DBA2D3F4740253FE257ACFF4B40A65F22DE3A414740253FE257ACFF4B40A65F22DE3A4147409A0986730DFF4B40486E4DBA2D3F47409A0986730DFF4B40
26342	Пошнары	7	66	939	46.404586999999999	46.435552000000001	56.032528999999997	56.016475999999997	0103000020E6100000010000000500000081B1BE81C93347409E95B4E21B024C4081B1BE81C9334740F69507E929044C408CDAFD2AC0374740F69507E929044C408CDAFD2AC03747409E95B4E21B024C4081B1BE81C93347409E95B4E21B024C40
16175	Персирланы	7	66	939	46.237670999999999	46.255197000000003	55.880853999999999	55.867373999999998	0103000020E61000000100000005000000931ADA006C1E47404AB3791C06EF4B40931ADA006C1E47408046E9D2BFF04B40C784984BAA2047408046E9D2BFF04B40C784984BAA2047404AB3791C06EF4B40931ADA006C1E47404AB3791C06EF4B40
15469	Ойкас-Асламасы	7	66	939	46.488444999999999	46.509250000000002	55.957040999999997	55.941954000000003	0103000020E610000001000000050000008672A25D853E47400F2BDCF291F84B408672A25D853E47402FF7C95180FA4B4077BE9F1A2F4147402FF7C95180FA4B4077BE9F1A2F4147400F2BDCF291F84B408672A25D853E47400F2BDCF291F84B40
48061	Никольское	7	66	939	46.182702999999997	46.209274999999998	56.006180000000001	55.992471999999999	0103000020E61000000100000005000000C7F0D8CF621747400D198F5209FF4B40C7F0D8CF62174740D4F19881CA004C40696FF085C91A4740D4F19881CA004C40696FF085C91A47400D198F5209FF4B40C7F0D8CF621747400D198F5209FF4B40
33121	Николаевское	7	66	939	46.385471000000003	46.422769000000002	55.790666000000002	55.778623000000003	0103000020E6100000010000000500000039471D1D57314740EB7420EBA9E34B4039471D1D573147409207228B34E54B409E616A4B1D3647409207228B34E54B409E616A4B1D364740EB7420EBA9E34B4039471D1D57314740EB7420EBA9E34B40
48216	Никиткино	7	66	939	46.464782999999997	46.4846	55.899926000000001	55.889688999999997	0103000020E610000001000000050000004E5E64027E3B4740334E4354E1F14B404E5E64027E3B4740F96871C630F34B4020D26F5F073E4740F96871C630F34B4020D26F5F073E4740334E4354E1F14B404E5E64027E3B4740334E4354E1F14B40
15193	Нижние Мочары	7	66	939	46.400148999999999	46.420011000000002	55.942281999999999	55.931148999999998	0103000020E6100000010000000500000078431A1538334740FF59F3E32FF74B4078431A153833474003CE52B29CF84B40EA7AA2EBC235474003CE52B29CF84B40EA7AA2EBC2354740FF59F3E32FF74B4078431A1538334740FF59F3E32FF74B40
15102	Малые Тюмерли	7	66	939	46.462536999999998	46.479793999999998	56.061051999999997	56.054040000000001	0103000020E6100000010000000500000050189469343B4740825660C8EA064C4050189469343B47407DAD4B8DD0074C409468C9E3693D47407DAD4B8DD0074C409468C9E3693D4740825660C8EA064C4050189469343B4740825660C8EA064C40
16378	Малое Кумаркино	7	66	939	46.279756999999996	46.292253000000002	55.827382999999998	55.814093	0103000020E61000000100000005000000DDE9CE13CF23474086730D3334E84B40DDE9CE13CF2347401822A7AFE7E94B403694DA8B682547401822A7AFE7E94B403694DA8B6825474086730D3334E84B40DDE9CE13CF23474086730D3334E84B40
15081	Малое Карачкино	7	66	939	46.446044000000001	46.468969000000001	56.097422000000002	56.082867999999998	0103000020E61000000100000005000000DC4944F81739474045F12A6B9B0A4C40DC4944F81739474099F4F752780C4C403EEB1A2D073C474099F4F752780C4C403EEB1A2D073C474045F12A6B9B0A4C40DC4944F81739474045F12A6B9B0A4C40
15839	Лапракасы	7	66	939	46.432561	46.453949000000001	55.861832999999997	55.844233000000003	0103000020E610000001000000050000003543AA285E3747401C9AB2D30FEC4B403543AA285E37474089CE328B50EE4B40A58636001B3A474089CE328B50EE4B40A58636001B3A47401C9AB2D30FEC4B403543AA285E3747401C9AB2D30FEC4B40
7574	Кукшумы	7	66	939	46.315286	46.363506999999998	55.885962999999997	55.868991000000001	0103000020E610000001000000050000007E71A94A5B28474059C2DA183BEF4B407E71A94A5B284740A73B4F3C67F14B40FC6EBA65872E4740A73B4F3C67F14B40FC6EBA65872E474059C2DA183BEF4B407E71A94A5B28474059C2DA183BEF4B40
15171	Кудаши	7	66	939	46.360570000000003	46.401271999999999	56.011847000000003	56.001091000000002	0103000020E6100000010000000500000099F56228272E4740F4A8F8BF23004C4099F56228272E474022C7D63384014C40776682E15C33474022C7D63384014C40776682E15C334740F4A8F8BF23004C4099F56228272E4740F4A8F8BF23004C40
16531	Кильдишево	7	66	939	46.570138	46.596018000000001	55.848872	55.831265999999999	0103000020E610000001000000050000007A1A3048FA4847406C239EEC66EA4B407A1A3048FA484740BC3E73D6A7EC4B40E6E95C514A4C4740BC3E73D6A7EC4B40E6E95C514A4C47406C239EEC66EA4B407A1A3048FA4847406C239EEC66EA4B40
16475	Ильина Гора	7	66	939	46.118589999999998	46.139736999999997	55.833531000000001	55.817900999999999	0103000020E61000000100000005000000FAD005F52D0F4740CF2EDFFAB0E84B40FAD005F52D0F4740E199D024B1EA4B404485EAE6E2114740E199D024B1EA4B404485EAE6E2114740CF2EDFFAB0E84B40FAD005F52D0F4740CF2EDFFAB0E84B40
15293	Верхние Мочары	7	66	939	46.422203000000003	46.449727000000003	55.971753	55.960251	0103000020E61000000100000005000000F5A276BF0A364740C4793881E9FA4B40F5A276BF0A3647401B65FD6662FC4B40699082A7903947401B65FD6662FC4B40699082A790394740C4793881E9FA4B40F5A276BF0A364740C4793881E9FA4B40
11292	Верхние Ирзеи	7	66	939	46.499367999999997	46.517235999999997	56.082160000000002	56.072277999999997	0103000020E610000001000000050000009F55664AEB3F4740321CCF6740094C409F55664AEB3F47400A850838840A4C402C280CCA344247400A850838840A4C402C280CCA34424740321CCF6740094C409F55664AEB3F4740321CCF6740094C40
15978	Верхние Ачаки	7	66	939	46.339145000000002	46.368519999999997	55.817036000000002	55.801591999999999	0103000020E610000001000000050000000CCD751A692B47401C5E10919AE64B400CCD751A692B4740CCD3B9A294E84B4001F6D1A92B2F4740CCD3B9A294E84B4001F6D1A92B2F47401C5E10919AE64B400CCD751A692B47401C5E10919AE64B40
15370	Большое Чурашево	7	66	939	46.465420999999999	46.499943000000002	55.929918999999998	55.915371999999998	0103000020E6100000010000000500000091EF52EA923B474049D6E1E82AF54B4091EF52EA923B4740EA76F69507F74B409C6ED921FE3F4740EA76F69507F74B409C6ED921FE3F474049D6E1E82AF54B4091EF52EA923B474049D6E1E82AF54B40
16043	Большие Шемердяны	7	66	939	46.328167000000001	46.344462999999998	55.847568000000003	55.835169	0103000020E610000001000000050000002F505260012A474007D15AD1E6EA4B402F505260012A47406D91B41B7DEC4B404DD7135D172C47406D91B41B7DEC4B404DD7135D172C474007D15AD1E6EA4B402F505260012A474007D15AD1E6EA4B40
16220	Балдаево	7	66	939	46.278491000000002	46.304703000000003	55.884883000000002	55.875728000000002	0103000020E610000001000000050000007C9DD497A52347408318E8DA17F04B407C9DD497A5234740A8E49CD843F14B401EFF058200274740A8E49CD843F14B401EFF0582002747408318E8DA17F04B407C9DD497A52347408318E8DA17F04B40
16004	Атликасы	7	66	939	46.282749000000003	46.298684999999999	55.873390000000001	55.861656000000004	0103000020E6100000010000000500000005FD851E312447407B336ABE4AEE4B4005FD851E31244740A453573ECBEF4B402367614F3B264740A453573ECBEF4B402367614F3B2647407B336ABE4AEE4B4005FD851E312447407B336ABE4AEE4B40
13702	Яндаши	7	66	115	46.664451999999997	46.688552999999999	55.597285999999997	55.582929999999998	0103000020E6100000010000000500000082E15CC30C554740BBED42739DCA4B4082E15CC30C554740E82D1EDE73CC4B400648348122584740E82D1EDE73CC4B400648348122584740BBED42739DCA4B4082E15CC30C554740BBED42739DCA4B40
13869	Юманай	7	66	115	46.690277999999999	46.720784999999999	55.627401999999996	55.616650999999997	0103000020E61000000100000005000000FB928D075B584740D905836BEECE4B40FB928D075B584740F5B86FB54ED04B404339D1AE425C4740F5B86FB54ED04B404339D1AE425C4740D905836BEECE4B40FB928D075B584740D905836BEECE4B40
57910	Шумерля	7	66	115	46.207362000000003	46.738194	55.676098000000003	55.268497000000004	0103000020E61000000100000005000000723788D68A1A47407D09151C5EA24B40723788D68A1A47400D7217618AD64B403D0D18247D5E47400D7217618AD64B403D0D18247D5E47407D09151C5EA24B40723788D68A1A47407D09151C5EA24B40
5794	Чувашские Алгаши	7	66	115	46.523927999999998	46.551865999999997	55.325553999999997	55.310468	0103000020E61000000100000005000000B6BA9C12104347402E3A596ABDA74B40B6BA9C12104347407E8AE3C0ABA94B401DE38A8BA34647407E8AE3C0ABA94B401DE38A8BA34647402E3A596ABDA74B40B6BA9C12104347402E3A596ABDA74B40
13584	Ходары	7	66	115	46.599701000000003	46.633954000000003	55.595261999999998	55.579256000000001	0103000020E6100000010000000500000073309B00C34C47408201840F25CA4B4073309B00C34C47409946938B31CC4B408E959867255147409946938B31CC4B408E959867255147408201840F25CA4B4073309B00C34C47408201840F25CA4B40
13658	Тугасы	7	66	115	46.625886999999999	46.646996999999999	55.606344	55.590713999999998	0103000020E61000000100000005000000EBFEB1101D50474009A52F849CCB4B40EBFEB1101D5047401B1021AE9CCD4B4018CE35CCD05247401B1021AE9CCD4B4018CE35CCD052474009A52F849CCB4B40EBFEB1101D50474009A52F849CCB4B40
13446	Туваны	7	66	115	46.537222999999997	46.549602	55.604650999999997	55.597821000000003	0103000020E610000001000000050000005AD427B9C344474057EE056685CC4B405AD427B9C3444740313F373465CD4B4079E8BB5B59464740313F373465CD4B4079E8BB5B5946474057EE056685CC4B405AD427B9C344474057EE056685CC4B40
13300	Торханы	7	66	115	46.555235000000003	46.590439000000003	55.573901999999997	55.543729999999996	0103000020E610000001000000050000001B4CC3F01147474052EDD3F198C54B401B4CC3F011474740F38DE89E75C94B4038A45181934B4740F38DE89E75C94B4038A45181934B474052EDD3F198C54B401B4CC3F01147474052EDD3F198C54B40
13239	Саланчик	7	66	115	46.268940999999998	46.291795	55.603704999999998	55.590795999999997	0103000020E61000000100000005000000DAC69FA86C224740C64D0D349FCB4B40DAC69FA86C22474041B7973446CD4B407311DF895925474041B7973446CD4B407311DF8959254740C64D0D349FCB4B40DAC69FA86C224740C64D0D349FCB4B40
13783	Савадеркино	7	66	115	46.564208999999998	46.585785999999999	55.607326	55.599952000000002	0103000020E61000000100000005000000EF8D210038484740BC95253ACBCC4B40EF8D2100384847405801BEDBBCCD4B40323A2009FB4A47405801BEDBBCCD4B40323A2009FB4A4740BC95253ACBCC4B40EF8D210038484740BC95253ACBCC4B40
4578	Русские Алгаши	7	66	115	46.478887	46.517944999999997	55.345852000000001	55.329512999999999	0103000020E6100000010000000500000062BD512B4C3D4740AD4D637B2DAA4B4062BD512B4C3D4740CBA0DAE044AC4B40381092054C424740CBA0DAE044AC4B40381092054C424740AD4D637B2DAA4B4062BD512B4C3D4740AD4D637B2DAA4B40
6444	Речной	7	66	115	46.571952000000003	46.588588999999999	55.345263000000003	55.335017999999998	0103000020E61000000100000005000000DF701FB93549474021C9ACDEE1AA4B40DF701FB9354947406AC2F69331AC4B4086E464E2564B47406AC2F69331AC4B4086E464E2564B474021C9ACDEE1AA4B40DF701FB93549474021C9ACDEE1AA4B40
13843	Пояндайкино	7	66	115	46.57188	46.594113999999998	55.636234000000002	55.615394999999999	0103000020E61000000100000005000000459E245D334947409B8F6B43C5CE4B40459E245D33494740384D9F1D70D14B40410C74ED0B4C4740384D9F1D70D14B40410C74ED0B4C47409B8F6B43C5CE4B40459E245D334947409B8F6B43C5CE4B40
28435	Пинеры	7	66	115	46.657068000000002	46.683028999999998	55.505704999999999	55.492258	0103000020E61000000100000005000000C39FE1CD1A544740E198654F02BF4B40C39FE1CD1A5447403B3602F1BAC04B401B9C887E6D5747403B3602F1BAC04B401B9C887E6D574740E198654F02BF4B40C39FE1CD1A544740E198654F02BF4B40
13023	Нижняя Кумашка	7	66	115	46.319184	46.349260000000001	55.583295999999997	55.568033	0103000020E6100000010000000500000007B47405DB2847403E062B4EB5C84B4007B47405DB2847409DF17D71A9CA4B4086E63A8DB42C47409DF17D71A9CA4B4086E63A8DB42C47403E062B4EB5C84B4007B47405DB2847403E062B4EB5C84B40
10749	Мыслец	7	66	115	46.530099999999997	46.556663	55.484851999999997	55.471918000000002	0103000020E6100000010000000500000007CE1951DA43474066321CCF67BC4B4007CE1951DA43474039B35DA10FBE4B4056F2B1BB4047474039B35DA10FBE4B4056F2B1BB4047474066321CCF67BC4B4007CE1951DA43474066321CCF67BC4B40
13374	Молгачкино	7	66	115	46.527377999999999	46.558154000000002	55.597464000000002	55.587947	0103000020E61000000100000005000000A0504F1F814347400264E8D841CB4B40A0504F1F81434740C8444AB379CC4B40D8101C9771474740C8444AB379CC4B40D8101C97714747400264E8D841CB4B40A0504F1F814347400264E8D841CB4B40
13574	Малые Туваны	7	66	115	46.498505999999999	46.537222999999997	55.603583	55.59281	0103000020E610000001000000050000000D6E6B0BCF3F4740F25EB532E1CB4B400D6E6B0BCF3F4740F6B52E3542CD4B405AD427B9C3444740F6B52E3542CD4B405AD427B9C3444740F25EB532E1CB4B400D6E6B0BCF3F4740F25EB532E1CB4B40
13504	Лесные Туваны	7	66	115	46.507381000000002	46.553043000000002	55.580762	55.567112000000002	0103000020E610000001000000050000004FCE50DCF1404740A795422097C84B404FCE50DCF14047403961C26856CA4B401024EF1CCA4647403961C26856CA4B401024EF1CCA464740A795422097C84B404FCE50DCF1404740A795422097C84B40
201	Красный Октябрь	7	66	115	46.640889000000001	46.663041	55.418466000000002	55.406768	0103000020E61000000100000005000000DEAE97A60852474098874CF910B44B40DEAE97A608524740753E3C4B90B54B401D740987DE544740753E3C4B90B54B401D740987DE54474098874CF910B44B40DEAE97A60852474098874CF910B44B40
13941	Кадеркино	7	66	115	46.63355	46.649126000000003	55.649627000000002	55.639221999999997	0103000020E61000000100000005000000BE30992A185147401D71C806D2D14B40BE30992A185147409FCC3FFA26D34B40DD7D8E8F165347409FCC3FFA26D34B40DD7D8E8F165347401D71C806D2D14B40BE30992A185147401D71C806D2D14B40
12909	Кабаново	7	66	115	46.502862999999998	46.515492999999999	55.416615999999998	55.410867000000003	0103000020E6100000010000000500000029AF95D05D404740B900344A97B44B4029AF95D05D404740C37E4FAC53B54B409128B4ACFB414740C37E4FAC53B54B409128B4ACFB414740B900344A97B44B4029AF95D05D404740B900344A97B44B40
13726	Егоркино	7	66	115	46.350931000000003	46.572490999999999	55.641528999999998	55.61056	0103000020E610000001000000050000008813984EEB2C4740751F80D426CE4B408813984EEB2C4740C1374D9F1DD24B408E20956247494740C1374D9F1DD24B408E20956247494740751F80D426CE4B408813984EEB2C4740751F80D426CE4B40
58026	Волга	7	66	115	46.273622000000003	46.288156000000001	55.564923	55.555387000000003	0103000020E61000000100000005000000AABBB20B06234740D1CFD4EB16C74B40AABBB20B062347400DE198654FC84B40B612BA4BE22447400DE198654FC84B40B612BA4BE2244740D1CFD4EB16C74B40AABBB20B06234740D1CFD4EB16C74B40
13087	Верхняя Кумашка	7	66	115	46.369174999999998	46.394849000000001	55.596111000000001	55.578518000000003	0103000020E610000001000000050000001AC05B20412F4740DC12B9E00CCA4B401AC05B20412F474097E4805D4DCC4B40DDED7A698A32474097E4805D4DCC4B40DDED7A698A324740DC12B9E00CCA4B401AC05B20412F4740DC12B9E00CCA4B40
13171	Верхний Магарин	7	66	115	46.328130999999999	46.343024999999997	55.633074000000001	55.625526000000001	0103000020E61000000100000005000000E2E65432002A47401B66683C11D04B40E2E65432002A474055F99E9108D14B40EE5A423EE82B474055F99E9108D14B40EE5A423EE82B47401B66683C11D04B40E2E65432002A47401B66683C11D04B40
13308	Бреняши	7	66	115	46.650663000000002	46.676696	55.569118000000003	55.556538000000003	0103000020E61000000100000005000000CFDBD8EC485347409A7D1EA33CC74B40CFDBD8EC4853474050C8CEDBD8C84B40C1AA7AF99D56474050C8CEDBD8C84B40C1AA7AF99D5647409A7D1EA33CC74B40CFDBD8EC485347409A7D1EA33CC74B40
12889	Большие Алгаши	7	66	115	46.429372000000001	46.476990999999998	55.379050999999997	55.344771000000001	0103000020E61000000100000005000000B8E864A9F5364740FBCDC47421AC4B40B8E864A9F53647400F4240BE84B04B4040BE840A0E3D47400F4240BE84B04B4040BE840A0E3D4740FBCDC47421AC4B40B8E864A9F5364740FBCDC47421AC4B40
57923	Яблоновка	7	66	1210	47.034889999999997	47.845044999999999	54.992899999999999	54.653542000000002	0103000020E610000001000000050000008D7A884677844740FE47A643A7534B408D7A8846778447406519E258177F4B40FC523F6F2AEC47406519E258177F4B40FC523F6F2AEC4740FE47A643A7534B408D7A884677844740FE47A643A7534B40
11874	Шемурша	7	66	1210	47.488872000000001	47.539338999999998	54.895553	54.879447999999996	0103000020E610000001000000050000000EF7915B93BE47402C4487C091704B400EF7915B93BE4740D76A0F7BA1724B408A3A730F09C54740D76A0F7BA1724B408A3A730F09C547402C4487C091704B400EF7915B93BE47402C4487C091704B40
12761	Чепкас-Никольское	7	66	1210	47.746077	47.768849000000003	54.905824000000003	54.889319	0103000020E610000001000000050000001EA67D737FDF4740105B7A34D5714B401EA67D737FDF474049F7730AF2734B40FA47DFA469E2474049F7730AF2734B40FA47DFA469E24740105B7A34D5714B401EA67D737FDF4740105B7A34D5714B40
12707	Трехизб-Шемурша	7	66	1210	47.575406000000001	47.607197999999997	54.861289999999997	54.843673000000003	0103000020E610000001000000050000000AF65FE7A6C9474055C2137AFD6B4B400AF65FE7A6C94740982F2FC03E6E4B402A1900AAB8CD4740982F2FC03E6E4B402A1900AAB8CD474055C2137AFD6B4B400AF65FE7A6C9474055C2137AFD6B4B40
12659	Трехбалтаево	7	66	1210	47.652625	47.691719999999997	54.939774999999997	54.910958999999998	0103000020E61000000100000005000000A8C64B3789D34740997FF44D9A744B40A8C64B3789D34740984C158C4A784B409BFEEC478AD84740984C158C4A784B409BFEEC478AD84740997FF44D9A744B40A8C64B3789D34740997FF44D9A744B40
12553	Старые Чукалы	7	66	1210	47.184882000000002	47.215280999999997	54.724162	54.702202999999997	0103000020E610000001000000050000003ECF9F36AA9747409813B4C9E1594B403ECF9F36AA974740C3802557B15C4B409F39EB538E9B4740C3802557B15C4B409F39EB538E9B47409813B4C9E1594B403ECF9F36AA9747409813B4C9E1594B40
12626	Старая Шемурша	7	66	1210	47.558957999999997	47.587327000000002	54.886615999999997	54.875481000000001	0103000020E6100000010000000500000035EB8CEF8BC747407BA2EBC20F704B4035EB8CEF8BC747401F0E12A27C714B406687F8872DCB47401F0E12A27C714B406687F8872DCB47407BA2EBC20F704B4035EB8CEF8BC747407BA2EBC20F704B40
12771	Русские Чукалы	7	66	1210	47.149667999999998	47.169187999999998	54.705007000000002	54.69314	0103000020E61000000100000005000000FDA02E522893474054C6BFCFB8584B40FDA02E5228934740BD395CAB3D5A4B401570CFF3A7954740BD395CAB3D5A4B401570CFF3A795474054C6BFCFB8584B40FDA02E522893474054C6BFCFB8584B40
12138	Новая Шемурша	7	66	1210	47.525621999999998	47.551789999999997	54.882855999999997	54.871901000000001	0103000020E610000001000000050000007007EA9447C34740C32CB4739A6F4B407007EA9447C34740E789E76C01714B404221020EA1C64740E789E76C01714B404221020EA1C64740C32CB4739A6F4B407007EA9447C34740C32CB4739A6F4B40
12525	Нижнее Буяново	7	66	1210	47.627795999999996	47.656703999999998	54.924221000000003	54.910269999999997	0103000020E61000000100000005000000A1478C9E5BD04740D44334BA83744B40A1478C9E5BD0474062A3ACDF4C764B4081936DE00ED4474062A3ACDF4C764B4081936DE00ED44740D44334BA83744B40A1478C9E5BD04740D44334BA83744B40
58065	Мордовские Тюки	7	66	1210	47.034889999999997	47.845044999999999	54.992899999999999	54.653542000000002	0103000020E610000001000000050000008D7A884677844740FE47A643A7534B408D7A8846778447406519E258177F4B40FC523F6F2AEC47406519E258177F4B40FC523F6F2AEC4740FE47A643A7534B408D7A884677844740FE47A643A7534B40
12463	Малое Буяново	7	66	1210	47.628748000000002	47.650630999999997	54.880681000000003	54.863041000000003	0103000020E6100000010000000500000074B680D07AD04740B70DA320786E4B4074B680D07AD04740B39AAE27BA704B40C36169E047D34740B39AAE27BA704B40C36169E047D34740B70DA320786E4B4074B680D07AD04740B70DA320786E4B40
12412	Карабай-Шемурша	7	66	1210	47.501987	47.531964000000002	54.972302999999997	54.958834000000003	0103000020E6100000010000000500000032022A1C41C047407D259012BB7A4B4032022A1C41C04740BE66B96C747C4B401E53776517C44740BE66B96C747C4B401E53776517C447407D259012BB7A4B4032022A1C41C047407D259012BB7A4B40
12367	Верхнее Буяново	7	66	1210	47.574902999999999	47.605401000000001	54.914281000000003	54.902962000000002	0103000020E61000000100000005000000A7AFE76B96C94740F0C3414294734B40A7AFE76B96C94740562DE92807754B409CFBABC77DCD4740562DE92807754B409CFBABC77DCD4740F0C3414294734B40A7AFE76B96C94740F0C3414294734B40
12313	Большое Буяново	7	66	1210	47.598267999999997	47.624805000000002	54.903489999999998	54.890929999999997	0103000020E61000000100000005000000251FBB0B94CC47403C8386FE09724B40251FBB0B94CC4740AB21718FA5734B404BB0389CF9CF4740AB21718FA5734B404BB0389CF9CF47403C8386FE09724B40251FBB0B94CC47403C8386FE09724B40
12286	Бичурга-Баишево	7	66	1210	47.288305000000001	47.325189999999999	54.769871000000002	54.751539000000001	0103000020E61000000100000005000000FB22A12DE7A447409355116E32604B40FB22A12DE7A44740C59107228B624B403D7E6FD39FA94740C59107228B624B403D7E6FD39FA947409355116E32604B40FB22A12DE7A447409355116E32604B40
12215	Байдеряково	7	66	1210	47.703901000000002	47.746355999999999	54.952629999999999	54.935358999999998	0103000020E61000000100000005000000944F8F6D19DA47407782FDD7B9774B40944F8F6D19DA47402098A3C7EF794B403196E99788DF47402098A3C7EF794B403196E99788DF47407782FDD7B9774B40944F8F6D19DA47407782FDD7B9774B40
12167	Асаново	7	66	1210	47.323329999999999	47.363098000000001	54.768453000000001	54.757908	0103000020E6100000010000000500000068E89FE062A947403AB01C2103614B4068E89FE062A94740ADC1FBAA5C624B401B9FC9FE79AE4740ADC1FBAA5C624B401B9FC9FE79AE47403AB01C2103614B4068E89FE062A947403AB01C2103614B40
11961	Андреевка	7	66	1210	47.470196000000001	47.496031000000002	54.881064000000002	54.862206999999998	0103000020E61000000100000005000000E25AED612FBC4740EEB089CC5C6E4B40E25AED612FBC47406BD784B4C6704B40AE669DF17DBF47406BD784B4C6704B40AE669DF17DBF4740EEB089CC5C6E4B40E25AED612FBC4740EEB089CC5C6E4B40
57911	д.Толиково	7	66	1036	47.443776	47.462721999999999	56.074066999999999	56.059880999999997	0103000020E61000000100000005000000F65FE7A6CDB847406D533C2EAA074C40F65FE7A6CDB847403E5B07077B094C40E29178793ABB47403E5B07077B094C40E29178793ABB47406D533C2EAA074C40F65FE7A6CDB847406D533C2EAA074C40
33097	Яуши	7	66	1036	47.093631000000002	47.114508000000001	56.094991999999998	56.085766	0103000020E610000001000000050000002672C119FC8B4740EB8D5A61FA0A4C402672C119FC8B4740D9B0A6B2280C4C40B090B932A88E4740D9B0A6B2280C4C40B090B932A88E4740EB8D5A61FA0A4C402672C119FC8B4740EB8D5A61FA0A4C40
33010	Яныши	7	66	1036	46.946936000000001	46.96669	55.934744000000002	55.920931000000003	0103000020E61000000100000005000000D9B3E73235794740B16F2711E1F54B40D9B3E73235794740ED10FFB0A5F74B4064AF777FBC7B4740ED10FFB0A5F74B4064AF777FBC7B4740B16F2711E1F54B40D9B3E73235794740B16F2711E1F54B40
52349	Яндово	7	66	1036	47.419333000000002	47.435071000000001	56.096378000000001	56.085369999999998	0103000020E61000000100000005000000199128B4ACB547409E077767ED0A4C40199128B4ACB54740E606431D560C4C4011381268B0B74740E606431D560C4C4011381268B0B747409E077767ED0A4C40199128B4ACB547409E077767ED0A4C40
10433	Янгильдино	7	66	1036	47.114004999999999	47.145724000000001	56.018746	56.008470000000003	0103000020E610000001000000050000004D4A41B7978E4740A27F828B15014C404D4A41B7978E47402577D84466024C40041F8315A79247402577D84466024C40041F8315A7924740A27F828B15014C404D4A41B7978E4740A27F828B15014C40
52280	Ядринкасы	7	66	1036	47.005828999999999	47.029131999999997	56.064875999999998	56.053407	0103000020E61000000100000005000000272F3201BF8047405130630AD6064C40272F3201BF804740CC2555DB4D084C402FA2ED98BA834740CC2555DB4D084C402FA2ED98BA8347405130630AD6064C40272F3201BF8047405130630AD6064C40
52266	Эндимиркасы	7	66	1036	46.989282000000003	47.011308999999997	55.897801000000001	55.882711999999998	0103000020E61000000100000005000000C042E6CAA07E4740B4E4F1B4FCF04B40C042E6CAA07E474076A8A624EBF24B404293C4927281474076A8A624EBF24B404293C49272814740B4E4F1B4FCF04B40C042E6CAA07E4740B4E4F1B4FCF04B40
32540	Шорчекасы	7	66	1036	47.455823000000002	47.49136	55.982199999999999	55.968730999999998	0103000020E61000000100000005000000DFE1766858BA474089CF9D60FFFB4B40DFE1766858BA4740CB10C7BAB8FD4B4002486DE2E4BE4740CB10C7BAB8FD4B4002486DE2E4BE474089CF9D60FFFB4B40DFE1766858BA474089CF9D60FFFB4B40
33081	Шоркино	7	66	1036	47.183129999999998	47.201904999999996	55.994446000000003	55.981535000000001	0103000020E610000001000000050000004F75C8CD709747408F705AF0A2FD4B404F75C8CD70974740ABD1AB014AFF4B400EF3E505D8994740ABD1AB014AFF4B400EF3E505D89947408F705AF0A2FD4B404F75C8CD709747408F705AF0A2FD4B40
52270	Шоркасы	7	66	1036	47.030192	47.039777000000001	55.944904000000001	55.941001999999997	0103000020E61000000100000005000000E84CDA54DD8347403CBCE7C072F84B40E84CDA54DD83474007EE409DF2F84B400611A9691785474007EE409DF2F84B400611A969178547403CBCE7C072F84B40E84CDA54DD8347403CBCE7C072F84B40
33146	Шинерпоси	7	66	1036	47.339292999999998	47.362389	56.029612	56.019570999999999	0103000020E610000001000000050000008061F9F36DAB47409A79724D81024C408061F9F36DAB4740DAC87553CA034C400FB743C362AE4740DAC87553CA034C400FB743C362AE47409A79724D81024C408061F9F36DAB47409A79724D81024C40
9681	Чиршкасы	7	66	1036	47.015962000000002	47.392724999999999	56.072951000000003	55.922656000000003	0103000020E6100000010000000500000048FDF50A0B824740A6BA809719F64B4048FDF50A0B824740F29A577556094C402AA913D044B24740F29A577556094C402AA913D044B24740A6BA809719F64B4048FDF50A0B824740A6BA809719F64B40
11799	Чемурша	7	66	1036	47.403216999999998	47.418326999999998	56.113726999999997	56.103597999999998	0103000020E610000001000000050000007A185A9D9CB347402BF702B3420D4C407A185A9D9CB347400AD6389B8E0E4C40530438BD8BB547400AD6389B8E0E4C40530438BD8BB547402BF702B3420D4C407A185A9D9CB347402BF702B3420D4C40
9243	Хыркасы	7	66	1036	47.438198	47.456451000000001	55.998170999999999	55.986863	0103000020E6100000010000000500000018963FDF16B84740F450DB8651FE4B4018963FDF16B8474066683C11C4FF4B40FE9C82FC6CBA474066683C11C4FF4B40FE9C82FC6CBA4740F450DB8651FE4B4018963FDF16B84740F450DB8651FE4B40
58003	Тренькасы	7	66	1036	47.414814	47.431370000000001	56.008142999999997	55.997084000000001	0103000020E6100000010000000500000023F609A018B54740B4AED172A0FF4B4023F609A018B547407D586FD40A014C40DE3CD52137B747407D586FD40A014C40DE3CD52137B74740B4AED172A0FF4B4023F609A018B54740B4AED172A0FF4B40
33075	Сятракасы	7	66	1036	47.171461000000001	47.249282000000001	56.062313000000003	55.993701000000001	0103000020E610000001000000050000000DC51D6FF29547405280289831FF4B400DC51D6FF2954740CE8E54DFF9074C40A1BDFA78E89F4740CE8E54DFF9074C40A1BDFA78E89F47405280289831FF4B400DC51D6FF29547405280289831FF4B40
9193	Сюктерка	7	66	1036	47.031089999999999	47.048597999999998	56.128565999999999	56.118862	0103000020E61000000100000005000000C79DD2C1FA8347405B5EB9DE360F4C40C79DD2C1FA83474053B0C6D974104C40545392753886474053B0C6D974104C4054539275388647405B5EB9DE360F4C40C79DD2C1FA8347405B5EB9DE360F4C40
11734	Синьялы	7	66	1036	47.265182000000003	47.381450999999998	56.087293000000003	56.028249000000002	0103000020E6100000010000000500000073BED87BF1A147408692C9A99D034C4073BED87BF1A14740BA15C26A2C0B4C406403E962D3B04740BA15C26A2C0B4C406403E962D3B047408692C9A99D034C4073BED87BF1A147408692C9A99D034C40
52256	Селиванкино	7	66	1036	47.088608999999998	47.104472999999999	56.072237999999999	56.060861000000003	0103000020E61000000100000005000000CD902A8A578B47400A4D124BCA074C40CD902A8A578B4740A4C343183F094C4052280B5F5F8D4740A4C343183F094C4052280B5F5F8D47400A4D124BCA074C40CD902A8A578B47400A4D124BCA074C40
57919	Салабаикасы	7	66	1036	47.019151000000001	47.043585999999998	56.085434999999997	56.080531999999998	0103000020E61000000100000005000000C5573B8A73824740072461DF4E0A4C40C5573B8A738247408577B988EF0A4C401F48DE39948547408577B988EF0A4C401F48DE3994854740072461DF4E0A4C40C5573B8A73824740072461DF4E0A4C40
57901	Пархикасы	7	66	1036	47.059764000000001	47.083739999999999	56.049601000000003	56.036724	0103000020E6100000010000000500000034BDC458A6874740397D3D5FB3044C4034BDC458A6874740A96C585359064C40FBAE08FEB78A4740A96C585359064C40FBAE08FEB78A4740397D3D5FB3044C4034BDC458A6874740397D3D5FB3044C40
52278	Олгаши	7	66	1036	46.965117999999997	46.989426000000002	56.032589999999999	56.015127999999997	0103000020E61000000100000005000000F56393FC887B47407FA0DCB6EF014C40F56393FC887B47409C16BCE82B044C40F3E7DB82A57E47409C16BCE82B044C40F3E7DB82A57E47407FA0DCB6EF014C40F56393FC887B47407FA0DCB6EF014C40
52333	Ойкасы	7	66	1036	47.027982000000002	47.276662999999999	56.073563999999998	56.040410000000001	0103000020E61000000100000005000000377007EA948347403737A6272C054C40377007EA94834740DB148F8B6A094C40B28174B169A34740DB148F8B6A094C40B28174B169A347403737A6272C054C40377007EA948347403737A6272C054C40
52277	Мускаринкасы	7	66	1036	47.015450000000001	47.030496999999997	56.022725000000001	56.007252000000001	0103000020E61000000100000005000000925CFE43FA814740516A2FA2ED004C40925CFE43FA8147409BE61DA7E8024C4024D06053E78347409BE61DA7E8024C4024D06053E7834740516A2FA2ED004C40925CFE43FA814740516A2FA2ED004C40
52296	Малые Карачуры	7	66	1036	47.165218000000003	47.183202000000001	56.058011	56.048751000000003	0103000020E61000000100000005000000F35A09DD25954740DB5207793D064C40F35A09DD2595474075E789E76C074C40E947C3297397474075E789E76C074C40E947C32973974740DB5207793D064C40F35A09DD25954740DB5207793D064C40
32958	Малая Сундырь	7	66	1036	46.953367999999998	46.978645999999998	56.064946999999997	56.053980000000003	0103000020E61000000100000005000000C6866EF6077A4740AD510FD1E8064C40C6866EF6077A4740957CEC2E50084C403C2EAA45447D4740957CEC2E50084C403C2EAA45447D4740AD510FD1E8064C40C6866EF6077A4740AD510FD1E8064C40
52291	Курмыши	7	66	1036	47.055596000000001	47.064615000000003	55.990841000000003	55.984582000000003	0103000020E61000000100000005000000EBE40CC51D8747407A1D71C806FE4B40EBE40CC51D8747409A44BDE0D3FE4B4060EAE74D458847409A44BDE0D3FE4B4060EAE74D458847407A1D71C806FE4B40EBE40CC51D8747407A1D71C806FE4B40
10047	Кугеси	7	66	1036	47.283839999999998	47.31935	56.046619999999997	56.019123	0103000020E61000000100000005000000F8A57EDE54A44740FBCC599F72024C40F8A57EDE54A4474075ABE7A4F7054C4022FDF675E0A8474075ABE7A4F7054C4022FDF675E0A84740FBCC599F72024C40F8A57EDE54A44740FBCC599F72024C40
52279	Корак-Чурачики	7	66	1036	46.937531	46.963779000000002	56.002786999999998	55.994757999999997	0103000020E610000001000000050000003BFE0B040178474099B7EA3A54FF4B403BFE0B04017847404EED0C535B004C402AC93A1C5D7B47404EED0C535B004C402AC93A1C5D7B474099B7EA3A54FF4B403BFE0B040178474099B7EA3A54FF4B40
33116	Клычево	7	66	1036	47.328997999999999	47.355885000000001	55.966887	55.952151999999998	0103000020E610000001000000050000008639419B1CAA47401669E21DE0F94B408639419B1CAA4740BAF605F4C2FB4B408811C2A38DAD4740BAF605F4C2FB4B408811C2A38DAD47401669E21DE0F94B408639419B1CAA47401669E21DE0F94B40
9764	Ишлей	7	66	1036	47.033344999999997	47.069358000000001	56.029435999999997	56.017201	0103000020E61000000100000005000000183E22A644844740B03A72A433024C40183E22A6448447409BA9108FC4034C40A5DB12B9E08847409BA9108FC4034C40A5DB12B9E0884740B03A72A433024C40183E22A644844740B03A72A433024C40
9415	Ишаки	7	66	1036	47.057375	47.088861000000001	55.943800000000003	55.927169999999997	0103000020E61000000100000005000000D34D62105887474089EAAD81ADF64B40D34D6210588747407FFB3A70CEF84B40E77118CC5F8B47407FFB3A70CEF84B40E77118CC5F8B474089EAAD81ADF64B40D34D62105887474089EAAD81ADF64B40
52340	Ильбеши	7	66	1036	47.342059999999996	47.357151999999999	56.065007000000001	56.049928000000001	0103000020E6100000010000000500000087A2409FC8AB4740CD936B0A64064C4087A2409FC8AB47406B813D2652084C40BAD91F28B7AD47406B813D2652084C40BAD91F28B7AD4740CD936B0A64064C4087A2409FC8AB4740CD936B0A64064C40
10824	Икково	7	66	1036	47.225197999999999	47.254995000000001	55.982531999999999	55.967430999999998	0103000020E61000000100000005000000F38FBE49D39C47407B116DC7D4FB4B40F38FBE49D39C474001A3CB9BC3FD4B405FD218ADA3A0474001A3CB9BC3FD4B405FD218ADA3A047407B116DC7D4FB4B40F38FBE49D39C47407B116DC7D4FB4B40
52252	Вурманкасы	7	66	1036	47.009422999999998	47.023660999999997	56.117843000000001	56.104199999999999	0103000020E61000000100000005000000446ADAC534814740211FF46C560D4C40446ADAC5348147400188BB7A150F4C406798DA52078347400188BB7A150F4C406798DA5207834740211FF46C560D4C40446ADAC534814740211FF46C560D4C40
52265	Вурманкас-Туруново	7	66	1036	47.042768000000002	47.060169000000002	55.895811999999999	55.888446999999999	0103000020E610000001000000050000005DA8FC6B798547405A9D9CA1B8F14B405DA8FC6B79854740A3AEB5F7A9F24B40D49D279EB3874740A3AEB5F7A9F24B40D49D279EB38747405A9D9CA1B8F14B405DA8FC6B798547405A9D9CA1B8F14B40
58048	Большое Князьтеняково	7	66	1036	47.397899000000002	47.416502999999999	56.061655000000002	56.051411000000002	0103000020E61000000100000005000000390EBC5AEEB24740CCD3B9A294064C40390EBC5AEEB247404451A04FE4074C40CBD765F84FB547404451A04FE4074C40CBD765F84FB54740CCD3B9A294064C40390EBC5AEEB24740CCD3B9A294064C40
52261	Большие Мамыши	7	66	1036	46.954661000000002	46.969465999999997	55.970660000000002	55.956994999999999	0103000020E6100000010000000500000022E2E654327A4740BFB7E9CF7EFA4B4022E2E654327A474087C43D963EFC4B40BE4A3E76177C474087C43D963EFC4B40BE4A3E76177C4740BFB7E9CF7EFA4B4022E2E654327A4740BFB7E9CF7EFA4B40
57862	Большие Катраси	7	66	1036	46.920768000000002	47.597459999999998	56.300085000000003	55.871682999999997	0103000020E61000000100000005000000079ACFB9DB75474055BDFC4E93EF4B40079ACFB9DB75474095826E2F69264C408655BC9179CC474095826E2F69264C408655BC9179CC474055BDFC4E93EF4B40079ACFB9DB75474055BDFC4E93EF4B40
32585	Большие Карачуры	7	66	1036	47.120534999999997	47.142167000000001	56.069957000000002	56.058427999999999	0103000020E61000000100000005000000FD82DDB06D8F4740D99596917A074C40FD82DDB06D8F47402A90D959F4084C4004C93B87329247402A90D959F4084C4004C93B8732924740D99596917A074C40FD82DDB06D8F4740D99596917A074C40
52312	Большая Чигирь	7	66	1036	47.427472000000002	47.456972	56.039585000000002	56.027805999999998	0103000020E6100000010000000500000055FA0967B7B64740F850A2258F034C4055FA0967B7B64740C2340C1F11054C400798F90E7EBA4740C2340C1F11054C400798F90E7EBA4740F850A2258F034C4055FA0967B7B64740F850A2258F034C40
52301	Байсубаково	7	66	1036	47.378000999999998	47.395294	55.970680000000002	55.958103999999999	0103000020E610000001000000050000007A6D365662B047405915E126A3FA4B407A6D365662B04740CE70033E3FFC4B400B2769FE98B24740CE70033E3FFC4B400B2769FE98B247405915E126A3FA4B407A6D365662B047405915E126A3FA4B40
58006	Атлашево	7	66	1036	47.539059999999999	47.567914000000002	56.021835000000003	56.000974999999997	0103000020E61000000100000005000000774A07EBFFC447408A8EE4F21F004C40774A07EBFFC447403F74417DCB024C406478EC67B1C847403F74417DCB024C406478EC67B1C847408A8EE4F21F004C40774A07EBFFC447408A8EE4F21F004C40
52258	Анаткас-Марги	7	66	1036	47.105623000000001	47.127704000000001	55.926392999999997	55.910054000000002	0103000020E610000001000000050000004B5AF10D858D474008CC43A67CF44B404B5AF10D858D4740251FBB0B94F64B40C1C8CB9A58904740251FBB0B94F64B40C1C8CB9A5890474008CC43A67CF44B404B5AF10D858D474008CC43A67CF44B40
58108	Альгешево	7	66	1036	46.920768000000002	47.597459999999998	56.300085000000003	55.871682999999997	0103000020E61000000100000005000000079ACFB9DB75474055BDFC4E93EF4B40079ACFB9DB75474095826E2F69264C408655BC9179CC474095826E2F69264C408655BC9179CC474055BDFC4E93EF4B40079ACFB9DB75474055BDFC4E93EF4B40
11116	Акулево	7	66	1036	47.504807999999997	47.533617	55.991712	55.984712999999999	0103000020E610000001000000050000002C616D8C9DC04740187959130BFE4B402C616D8C9DC047407F86376BF0FE4B4079CBD58F4DC447407F86376BF0FE4B4079CBD58F4DC44740187959130BFE4B402C616D8C9DC04740187959130BFE4B40
10632	Абашево	7	66	1036	47.343434000000002	47.369252000000003	55.994903999999998	55.982335999999997	0103000020E61000000100000005000000D02A33A5F5AB47407BD7A02FBDFD4B40D02A33A5F5AB47406D54A70359FF4B40C6FD47A643AF47406D54A70359FF4B40C6FD47A643AF47407BD7A02FBDFD4B40D02A33A5F5AB47407BD7A02FBDFD4B40
8789	Чурачики	7	66	889	47.421902000000003	47.448312999999999	55.737805999999999	55.718044999999996	0103000020E61000000100000005000000FA0E7EE200B64740350708E6E8DB4B40FA0E7EE200B647407365506D70DE4B4092AF045262B947407365506D70DE4B4092AF045262B94740350708E6E8DB4B40FA0E7EE200B64740350708E6E8DB4B40
8562	Чиричкасы	7	66	889	47.623161000000003	47.64958	55.807648	55.799370000000003	0103000020E61000000100000005000000439259BDC3CF4740A7B393C151E64B40439259BDC3CF47400457790261E74B405E11FC6F25D347400457790261E74B405E11FC6F25D34740A7B393C151E64B40439259BDC3CF4740A7B393C151E64B40
7835	Чемерчеево 1-е	7	66	889	47.439337999999999	47.456226999999998	55.793838999999998	55.783782000000002	0103000020E61000000100000005000000EDF1423A3CB84740C498F4F752E44B40EDF1423A3CB8474009A52F849CE54B40AE4676A565BA474009A52F849CE54B40AE4676A565BA4740C498F4F752E44B40EDF1423A3CB84740C498F4F752E44B40
8232	Хорамалы	7	66	889	47.749482	47.764726000000003	55.830958000000003	55.817839999999997	0103000020E610000001000000050000006878B306EFDF474029AE2AFBAEE84B406878B306EFDF4740BF2CEDD45CEA4B405133A48AE2E14740BF2CEDD45CEA4B405133A48AE2E1474029AE2AFBAEE84B406878B306EFDF474029AE2AFBAEE84B40
6972	Унгасемы	7	66	889	47.208992000000002	47.235807000000001	55.866489999999999	55.858584	0103000020E610000001000000050000001590F63FC09A4740376F9C14E6ED4B401590F63FC09A4740D027F224E9EE4B407D957CEC2E9E4740D027F224E9EE4B407D957CEC2E9E4740376F9C14E6ED4B401590F63FC09A4740376F9C14E6ED4B40
7971	Тюрары	7	66	889	47.356028999999999	47.369081000000001	55.727663	55.723176000000002	0103000020E61000000100000005000000BBB6B75B92AD474045A0FA0791DC4B40BBB6B75B92AD47402FC1A90F24DD4B409949D40B3EAF47402FC1A90F24DD4B409949D40B3EAF474045A0FA0791DC4B40BBB6B75B92AD474045A0FA0791DC4B40
8462	Тюнзыры	7	66	889	47.524202000000002	47.549723	55.888831000000003	55.874647000000003	0103000020E61000000100000005000000B83F170D19C34740B345D26EF4EF4B40B83F170D19C34740E355D636C5F14B40F46DC1525DC64740E355D636C5F14B40F46DC1525DC64740B345D26EF4EF4B40B83F170D19C34740B345D26EF4EF4B40
8282	Тувси	7	66	889	47.462560000000003	47.504736000000001	55.917743000000002	55.903196000000001	0103000020E610000001000000050000000938842A35BB474063F030ED9BF34B400938842A35BB47400491459A78F54B40938E72309BC047400491459A78F54B40938E72309BC0474063F030ED9BF34B400938842A35BB474063F030ED9BF34B40
8537	Таушкасы	7	66	889	47.565308999999999	47.586060000000003	55.870142000000001	55.849857999999998	0103000020E610000001000000050000003691990B5CC847403A1F9E25C8EC4B403691990B5CC84740227024D060EF4B4034BF9A0304CB4740227024D060EF4B4034BF9A0304CB47403A1F9E25C8EC4B403691990B5CC847403A1F9E25C8EC4B40
8711	Таганы	7	66	889	47.457546999999998	47.472172	55.705320999999998	55.696707000000004	0103000020E6100000010000000500000003B16CE690BA474078F2E9B12DD94B4003B16CE690BA47404C1762F547DA4B40200BD12170BC47404C1762F547DA4B40200BD12170BC474078F2E9B12DD94B4003B16CE690BA474078F2E9B12DD94B40
6891	Сюлескеры	7	66	889	47.337991000000002	47.351078999999999	55.872228	55.861449	0103000020E61000000100000005000000D2AB014A43AB47400116F9F543EE4B40D2AB014A43AB4740E753C72AA5EF4B40FCA71B28F0AC4740E753C72AA5EF4B40FCA71B28F0AC47400116F9F543EE4B40D2AB014A43AB47400116F9F543EE4B40
8094	Степное Тугаево	7	66	889	47.463880000000003	47.483949000000003	55.774993000000002	55.765659999999997	0103000020E610000001000000050000005EA27A6B60BB47407CED992501E24B405EA27A6B60BB474081D07AF832E34B4049F7730AF2BD474081D07AF832E34B4049F7730AF2BD47407CED992501E24B405EA27A6B60BB47407CED992501E24B40
8026	Степаново 1-е	7	66	889	47.522818999999998	47.547567000000001	55.752915999999999	55.744835000000002	0103000020E610000001000000050000001C5DA5BBEBC2474045F5D6C056DF4B401C5DA5BBEBC247404C512E8D5FE04B4036AFEAAC16C647404C512E8D5FE04B4036AFEAAC16C6474045F5D6C056DF4B401C5DA5BBEBC2474045F5D6C056DF4B40
8129	Старое Акташево	7	66	889	47.690193000000001	47.716692999999999	55.899839999999998	55.886215999999997	0103000020E61000000100000005000000CD76853E58D847409198A0866FF14B40CD76853E58D84740FAD005F52DF34B40D522A298BCDB4740FAD005F52DF34B40D522A298BCDB47409198A0866FF14B40CD76853E58D847409198A0866FF14B40
8328	Синьялы	7	66	889	47.193452000000001	47.211660000000002	55.893752999999997	55.886918000000001	0103000020E6100000010000000500000043ACFE08C3984740EB1D6E8786F14B4043ACFE08C3984740D7D9907F66F24B4089EFC4AC179B4740D7D9907F66F24B4089EFC4AC179B4740EB1D6E8786F14B4043ACFE08C3984740EB1D6E8786F14B40
7453	Рындино	7	66	889	47.425235000000001	47.449174999999997	55.860267	55.846617999999999	0103000020E61000000100000005000000AA0EB9196EB647403B1A87FA5DEC4B40AA0EB9196EB64740FD69A33A1DEE4B402497FF907EB94740FD69A33A1DEE4B402497FF907EB947403B1A87FA5DEC4B40AA0EB9196EB647403B1A87FA5DEC4B40
8680	Поваркасы	7	66	889	47.495078999999997	47.530652000000003	55.719703000000003	55.705157999999997	0103000020E61000000100000005000000DBF7A8BF5EBF4740A2410A9E42DA4B40DBF7A8BF5EBF4740A3EA573A1FDC4B404CC79C67ECC34740A3EA573A1FDC4B404CC79C67ECC34740A2410A9E42DA4B40DBF7A8BF5EBF4740A2410A9E42DA4B40
7340	Первомайское	7	66	889	47.342644	47.352885000000001	55.905093999999998	55.899532000000001	0103000020E61000000100000005000000D71533C2DBAB47404DDA54DD23F34B40D71533C2DBAB474025E7C41EDAF34B40DE1FEF552BAD474025E7C41EDAF34B40DE1FEF552BAD47404DDA54DD23F34B40D71533C2DBAB47404DDA54DD23F34B40
7527	Первое Семеново	7	66	889	47.370896000000002	47.392958	55.872788999999997	55.859504000000001	0103000020E61000000100000005000000CE1B278579AF4740FE63213A04EE4B40CE1B278579AF47407EA7C98CB7EF4B40CD599F724CB247407EA7C98CB7EF4B40CD599F724CB24740FE63213A04EE4B40CE1B278579AF4740FE63213A04EE4B40
7741	Опытный	7	66	889	47.494486000000002	47.499912000000002	55.855258999999997	55.852030999999997	0103000020E61000000100000005000000392A37514BBF4740CE16105A0FED4B40392A37514BBF4740094E7D2079ED4B406170CD1DFDBF4740094E7D2079ED4B406170CD1DFDBF4740CE16105A0FED4B40392A37514BBF4740CE16105A0FED4B40
8625	Нюрши	7	66	889	47.578595	47.599310000000003	55.818078	55.809995000000001	0103000020E610000001000000050000008750A5660FCA4740367689EAADE74B408750A5660FCA4740DEC9A7C7B6E84B403815A930B6CC4740DEC9A7C7B6E84B403815A930B6CC4740367689EAADE74B408750A5660FCA4740367689EAADE74B40
7038	Нижние Кунаши	7	66	889	47.339491000000002	47.353530999999997	55.811528000000003	55.803443999999999	0103000020E61000000100000005000000A724EB7074AB47406E15C440D7E64B40A724EB7074AB4740E7E44526E0E74B40A38FF98040AD4740E7E44526E0E74B40A38FF98040AD47406E15C440D7E64B40A724EB7074AB47406E15C440D7E64B40
7471	Нижние Кибекси	7	66	889	47.341583999999997	47.362011000000003	55.850676	55.843313000000002	0103000020E610000001000000050000001E6B4606B9AB474055A52DAEF1EB4B401E6B4606B9AB4740FDBE7FF3E2EC4B4069E55E6056AE4740FDBE7FF3E2EC4B4069E55E6056AE474055A52DAEF1EB4B401E6B4606B9AB474055A52DAEF1EB4B40
7692	Мунсют	7	66	889	47.603326000000003	47.622703000000001	55.785037000000003	55.763665000000003	0103000020E61000000100000005000000CB694FC939CD4740C80C54C6BFE14B40CB694FC939CD47403293A8177CE44B40800F5EBBB4CF47403293A8177CE44B40800F5EBBB4CF4740C80C54C6BFE14B40CB694FC939CD4740C80C54C6BFE14B40
7003	Михайловка	7	66	889	47.373887000000003	47.388250999999997	55.829870999999997	55.820703000000002	0103000020E6100000010000000500000025B37A87DBAF4740535DC0CB0CE94B4025B37A87DBAF47400C73823639EA4B40D4D17135B2B147400C73823639EA4B40D4D17135B2B14740535DC0CB0CE94B4025B37A87DBAF4740535DC0CB0CE94B40
7885	Медикасы	7	66	889	47.339894999999999	47.351985999999997	55.705021000000002	55.697122999999998	0103000020E610000001000000050000007689EAAD81AB47400B2593533BD94B407689EAAD81AB474022FFCC203EDA4B402E5393E00DAD474022FFCC203EDA4B402E5393E00DAD47400B2593533BD94B407689EAAD81AB47400B2593533BD94B40
7096	Малое Янгорчино	7	66	889	47.296300000000002	47.311939000000002	55.90793	55.900027000000001	0103000020E6100000010000000500000004E78C28EDA547402D42B11534F34B4004E78C28EDA547405587DC0C37F44B4069ACFD9DEDA747405587DC0C37F44B4069ACFD9DEDA747402D42B11534F34B4004E78C28EDA547402D42B11534F34B40
8186	Конар	7	66	889	47.704081000000002	47.720672999999998	55.867697999999997	55.861767	0103000020E61000000100000005000000145E82531FDA4740D2E28C614EEE4B40145E82531FDA4740FD6662BA10EF4B401B0E4B033FDC4740FD6662BA10EF4B401B0E4B033FDC4740D2E28C614EEE4B40145E82531FDA4740D2E28C614EEE4B40
8759	Камайкасы	7	66	889	47.400226000000004	47.417734000000003	55.752327999999999	55.744048999999997	0103000020E610000001000000050000002481069B3AB347408DCF64FF3CDF4B402481069B3AB34740BBEEAD484CE04B40B136C64E78B54740BBEEAD484CE04B40B136C64E78B547408DCF64FF3CDF4B402481069B3AB347408DCF64FF3CDF4B40
7799	Искеево-Яндуши	7	66	889	47.524723000000002	47.54383	55.800317	55.787568	0103000020E61000000100000005000000C13A8E1F2AC3474025B03907CFE44B40C13A8E1F2AC3474067B796C970E64B40B64AB0389CC5474067B796C970E64B40B64AB0389CC5474025B03907CFE44B40C13A8E1F2AC3474025B03907CFE44B40
8467	Имбюрти	7	66	889	47.653578000000003	47.671149	55.853409999999997	55.840108000000001	0103000020E610000001000000050000004BB1A371A8D34740D28DB0A888EB4B404BB1A371A8D34740280AF4893CED4B401EDFDE35E8D54740280AF4893CED4B401EDFDE35E8D54740D28DB0A888EB4B404BB1A371A8D34740D28DB0A888EB4B40
7668	Игорвары	7	66	889	47.638961999999999	47.669550000000001	55.783726000000001	55.771687	0103000020E6100000010000000500000081B1BE81C9D14740CADFBDA3C6E24B4081B1BE81C9D147403083312251E44B40B6847CD0B3D547403083312251E44B40B6847CD0B3D54740CADFBDA3C6E24B4081B1BE81C9D14740CADFBDA3C6E24B40
7261	Елаши	7	66	889	47.230947	47.257483999999998	55.932450000000003	55.921908999999999	0103000020E61000000100000005000000FE0DDAAB8F9D4740AC71361D01F64B40FE0DDAAB8F9D4740DE9387855AF74B40239F573CF5A04740DE9387855AF74B40239F573CF5A04740AC71361D01F64B40FE0DDAAB8F9D4740AC71361D01F64B40
7580	Вурумсют	7	66	889	47.590417000000002	47.605750999999998	55.938187999999997	55.924905000000003	0103000020E610000001000000050000005000C5C892CB474015747B4963F64B405000C5C892CB4740F4BF5C8B16F84B407842AF3F89CD4740F4BF5C8B16F84B407842AF3F89CD474015747B4963F64B405000C5C892CB474015747B4963F64B40
57908	Вурманкасы 2-е	7	66	889	47.273833000000003	47.287864999999996	55.929091	55.919927000000001	0103000020E6100000010000000500000065C8B1F50CA347408CDAFD2AC0F54B4065C8B1F50CA3474004013274ECF64B40DE54A4C2D8A4474004013274ECF64B40DE54A4C2D8A447408CDAFD2AC0F54B4065C8B1F50CA347408CDAFD2AC0F54B40
45611	Вотланы	7	66	889	47.413331999999997	47.426726000000002	55.695768000000001	55.688699999999997	0103000020E61000000100000005000000F4311F10E8B44740AA60545227D84B40F4311F10E8B447403ACD02ED0ED94B402C2D23F59EB647403ACD02ED0ED94B402C2D23F59EB64740AA60545227D84B40F4311F10E8B44740AA60545227D84B40
7186	Визикасы	7	66	889	47.226995000000002	47.249093000000002	55.897765999999997	55.885378000000003	0103000020E6100000010000000500000082AD122C0E9D4740884CF91054F14B4082AD122C0E9D4740F9BA0CFFE9F24B40CE548847E29F4740F9BA0CFFE9F24B40CE548847E29F4740884CF91054F14B4082AD122C0E9D4740884CF91054F14B40
7617	Булдеево	7	66	889	47.598959999999998	47.622891000000003	55.910719999999998	55.902278000000003	0103000020E610000001000000050000005BCEA5B8AACC47403DF372D87DF34B405BCEA5B8AACC474014E8137992F44B4083FC6CE4BACF474014E8137992F44B4083FC6CE4BACF47403DF372D87DF34B405BCEA5B8AACC47403DF372D87DF34B40
7950	Борзайкасы	7	66	889	47.388556999999999	47.401591000000003	55.704894000000003	55.698604000000003	0103000020E61000000100000005000000E1D05B3CBCB147406A6D1ADB6BD94B40E1D05B3CBCB14740C59272F739DA4B4019AF795567B34740C59272F739DA4B4019AF795567B347406A6D1ADB6BD94B40E1D05B3CBCB147406A6D1ADB6BD94B40
6868	Большие Тиуши	7	66	889	47.309477999999999	47.327337	55.818897	55.810778999999997	0103000020E610000001000000050000006E6AA0F99CA747404CA4349BC7E74B406E6AA0F99CA7474071E5EC9DD1E84B40A8E2C62DE6A9474071E5EC9DD1E84B40A8E2C62DE6A947404CA4349BC7E74B406E6AA0F99CA747404CA4349BC7E74B40
6822	Богатырево	7	66	889	47.283472000000003	47.294933999999998	55.856012	55.847745000000003	0103000020E6100000010000000500000076AA7CCF48A447407C2C7DE882EC4B4076AA7CCF48A44740E57D1CCD91ED4B403E3DB665C0A54740E57D1CCD91ED4B403E3DB665C0A547407C2C7DE882EC4B4076AA7CCF48A447407C2C7DE882EC4B40
7172	Байдуши	7	66	889	47.307411999999999	47.327525000000001	55.926993000000003	55.913882999999998	0103000020E61000000100000005000000F032C34659A7474068AF3E1EFAF44B40F032C34659A747407B4FE5B4A7F64B40ABCFD556ECA947407B4FE5B4A7F64B40ABCFD556ECA9474068AF3E1EFAF44B40F032C34659A7474068AF3E1EFAF44B40
8383	Байгеево	7	66	889	47.526789000000001	47.543094000000004	55.924562000000002	55.913252999999997	0103000020E610000001000000050000003F726BD26DC34740A8FC6B79E5F44B403F726BD26DC34740EB8F300C58F64B40B153AC1A84C54740EB8F300C58F64B40B153AC1A84C54740A8FC6B79E5F44B403F726BD26DC34740A8FC6B79E5F44B40
6202	Ямбай	7	66	546	47.939970000000002	47.952339000000002	55.717770999999999	55.708080000000002	0103000020E610000001000000050000004E9CDCEF50F84740D1798D5DA2DA4B404E9CDCEF50F8474034828DEBDFDB4B4049DA8D3EE6F9474034828DEBDFDB4B4049DA8D3EE6F94740D1798D5DA2DA4B404E9CDCEF50F84740D1798D5DA2DA4B40
6626	Шоркистры	7	66	546	47.733707000000003	47.772119000000004	55.657657	55.628219999999999	0103000020E6100000010000000500000053EC681CEADD4740B858518369D04B4053EC681CEADD4740247EC51A2ED44B4064CF9ECBD4E24740247EC51A2ED44B4064CF9ECBD4E24740B858518369D04B4053EC681CEADD4740B858518369D04B40
6458	Шихабылово	7	66	546	47.831004	47.875380999999997	55.756872999999999	55.735048999999997	0103000020E610000001000000050000002F6CCD565EEA47408FFAEB1516DE4B402F6CCD565EEA4740DA1CE736E1E04B4017450F7C0CF04740DA1CE736E1E04B4017450F7C0CF047408FFAEB1516DE4B402F6CCD565EEA47408FFAEB1516DE4B40
6350	Шигали	7	66	546	48.005960000000002	48.058394	55.56588	55.542817999999997	0103000020E61000000100000005000000C68A1A4CC30048400ED76A0F7BC54B40C68A1A4CC3004840F1BA7EC16EC84B402D24607479074840F1BA7EC16EC84B402D246074790748400ED76A0F7BC54B40C68A1A4CC30048400ED76A0F7BC54B40
4769	Шибулаты	7	66	546	47.688189999999999	47.718715000000003	55.758519	55.745199	0103000020E6100000010000000500000095B7239C16D8474086014BAE62DF4B4095B7239C16D8474083328D2617E14B40841266DAFEDB474083328D2617E14B40841266DAFEDB474086014BAE62DF4B4095B7239C16D8474086014BAE62DF4B40
6246	Чубаево	7	66	546	47.860261999999999	47.881596999999999	55.678198999999999	55.665101	0103000020E61000000100000005000000EBFEB1101DEE4740B9C4910722D54B40EBFEB1101DEE474007978E39CFD64B4038A0A52BD8F0474007978E39CFD64B4038A0A52BD8F04740B9C4910722D54B40EBFEB1101DEE4740B9C4910722D54B40
5349	Чирш-Сирма	7	66	546	48.119947000000003	48.144236999999997	55.732214999999997	55.717908000000001	0103000020E610000001000000050000006D205D6C5A0F4840B5C4CA68E4DB4B406D205D6C5A0F484000529B38B9DD4B40C3EFA65B7612484000529B38B9DD4B40C3EFA65B76124840B5C4CA68E4DB4B406D205D6C5A0F4840B5C4CA68E4DB4B40
6024	Челкасы	7	66	546	47.894973	47.927106000000002	55.708384000000002	55.696711999999998	0103000020E61000000100000005000000C9E6AA798EF24740895DDBDB2DD94B40C9E6AA798EF247403D81B053ACDA4B4073F6CE68ABF647403D81B053ACDA4B4073F6CE68ABF64740895DDBDB2DD94B40C9E6AA798EF24740895DDBDB2DD94B40
6759	Хоруй	7	66	546	47.637956000000003	47.661788000000001	55.68497	55.675280000000001	0103000020E61000000100000005000000BC24CE8AA8D147404AD235936FD64B40BC24CE8AA8D14740DD5ED218ADD74B4050711C78B5D44740DD5ED218ADD74B4050711C78B5D447404AD235936FD64B40BC24CE8AA8D147404AD235936FD64B40
4449	Урмары	7	66	546	47.925246000000001	47.960622000000001	55.695884999999997	55.670574000000002	0103000020E610000001000000050000009E60FF756EF6474022C66B5ED5D54B409E60FF756EF6474073637AC212D94B40B8E864A9F5FA474073637AC212D94B40B8E864A9F5FA474022C66B5ED5D54B409E60FF756EF6474022C66B5ED5D54B40
5897	Тегешево	7	66	546	48.078256000000003	48.104002000000001	55.56024	55.54072	0103000020E610000001000000050000009F5BE84A040A484085251E5036C54B409F5BE84A040A48409DF4BEF1B5C74B40FB5B02F04F0D48409DF4BEF1B5C74B40FB5B02F04F0D484085251E5036C54B409F5BE84A040A484085251E5036C54B40
5662	Тансарино	7	66	546	47.979298	47.99624	55.762855000000002	55.748463000000001	0103000020E61000000100000005000000E48409A359FD47400EA2B5A2CDDF4B40E48409A359FD4740884B8E3BA5E14B40C87BD5CA84FF4740884B8E3BA5E14B40C87BD5CA84FF47400EA2B5A2CDDF4B40E48409A359FD47400EA2B5A2CDDF4B40
58027	Старые Шелканы	7	66	546	47.992942999999997	48.018841999999999	55.653115999999997	55.641122000000003	0103000020E6100000010000000500000064E597C118FF4740815F234910D24B4064E597C118FF4740463F1A4E99D34B4047E5266A69024840463F1A4E99D34B4047E5266A69024840815F234910D24B4064E597C118FF4740815F234910D24B40
5825	Старые Урмары	7	66	546	47.970449000000002	48.010675999999997	55.693905999999998	55.67756	0103000020E61000000100000005000000CCB73EAC37FC4740F4893C49BAD64B40CCB73EAC37FC4740C43F6CE9D1D84B40116DC7D45D014840C43F6CE9D1D84B40116DC7D45D014840F4893C49BAD64B40CCB73EAC37FC4740F4893C49BAD64B40
6169	Старое Шептахово	7	66	546	47.842959999999998	47.863990000000001	55.725118000000002	55.714871000000002	0103000020E6100000010000000500000007EBFF1CE6EB4740EEED96E480DB4B4007EBFF1CE6EB4740D7DEA7AAD0DC4B4018096D3997EE4740D7DEA7AAD0DC4B4018096D3997EE4740EEED96E480DB4B4007EBFF1CE6EB4740EEED96E480DB4B40
5313	Старое Муратово	7	66	546	48.113407000000002	48.128059	55.675401999999998	55.664411000000001	0103000020E610000001000000050000009911DE1E840E4840240D6E6B0BD54B409911DE1E840E484095D39E9273D64B40AF7AC03C6410484095D39E9273D64B40AF7AC03C64104840240D6E6B0BD54B409911DE1E840E4840240D6E6B0BD54B40
5634	Ситмиши	7	66	546	47.923333	47.944065999999999	55.742955000000002	55.730218000000001	0103000020E61000000100000005000000A62897C62FF64740AB798EC877DD4B40A62897C62FF6474029B3412619DF4B40FDA19927D7F8474029B3412619DF4B40FDA19927D7F84740AB798EC877DD4B40A62897C62FF64740AB798EC877DD4B40
5257	Систеби	7	66	546	48.078651000000001	48.098998000000002	55.732295999999998	55.724378000000002	0103000020E610000001000000050000001B66683C110A484090F8156BB8DC4B401B66683C110A4840ED7E15E0BBDD4B40492F6AF7AB0C4840ED7E15E0BBDD4B40492F6AF7AB0C484090F8156BB8DC4B401B66683C110A484090F8156BB8DC4B40
6584	Сине-Кинчеры	7	66	546	47.933214	47.947910999999998	55.798302999999997	55.789082000000001	0103000020E61000000100000005000000AD156D8E73F747405FEE93A300E54B40AD156D8E73F747403BA6EECA2EE64B406342CC2555F947403BA6EECA2EE64B406342CC2555F947405FEE93A300E54B40AD156D8E73F747405FEE93A300E54B40
5158	Саруй	7	66	546	47.663226000000002	47.692824999999999	55.732149	55.717072000000002	0103000020E61000000100000005000000AFEDED96E4D447404C70EA03C9DB4B40AFEDED96E4D447404966F50EB7DD4B40F46C567DAED847404966F50EB7DD4B40F46C567DAED847404C70EA03C9DB4B40AFEDED96E4D447404C70EA03C9DB4B40
5090	Орнары	7	66	546	47.694361000000001	47.715066999999998	55.727429999999998	55.707507	0103000020E61000000100000005000000164F3DD2E0D847407558E1968FDA4B40164F3DD2E0D847408C101E6D1CDD4B4073B9C15087DB47408C101E6D1CDD4B4073B9C15087DB47407558E1968FDA4B40164F3DD2E0D847407558E1968FDA4B40
4935	Новое Шептахово	7	66	546	47.846563000000003	47.863424000000002	55.703372999999999	55.691358999999999	0103000020E610000001000000050000007880272D5CEC4740CB65A3737ED84B407880272D5CEC4740D8F15F2008DA4B406F4A79AD84EE4740D8F15F2008DA4B406F4A79AD84EE4740CB65A3737ED84B407880272D5CEC4740CB65A3737ED84B40
5948	Новое Муратово	7	66	546	48.054549999999999	48.072282000000001	55.613346	55.600735	0103000020E6100000010000000500000097FF907EFB06484002486DE2E4CC4B4097FF907EFB064840F390291F82CE4B40740B5D8940094840F390291F82CE4B40740B5D894009484002486DE2E4CC4B4097FF907EFB06484002486DE2E4CC4B40
4670	Новое Исаково	7	66	546	47.916874	47.942314000000003	55.67492	55.666156999999998	0103000020E61000000100000005000000BF4692205CF547403080F0A144D54B40BF4692205CF547404AB54FC763D64B400F48C2BE9DF847404AB54FC763D64B400F48C2BE9DF847403080F0A144D54B40BF4692205CF547403080F0A144D54B40
5752	Мусирмы	7	66	546	47.970063000000003	47.997605	55.631507999999997	55.613672000000001	0103000020E61000000100000005000000A3073E062BFC4740473CD9CD8CCE4B40A3073E062BFC4740C8940F41D5D04B40BDA94885B1FF4740C8940F41D5D04B40BDA94885B1FF4740473CD9CD8CCE4B40A3073E062BFC4740473CD9CD8CCE4B40
4872	Малое Яниково	7	66	546	47.755868999999997	47.776888999999997	55.69661	55.692180999999998	0103000020E61000000100000005000000B587BD50C0E04740CFF4126399D84B40B587BD50C0E04740850838842AD94B40A2CF471971E34740850838842AD94B40A2CF471971E34740CFF4126399D84B40B587BD50C0E04740CFF4126399D84B40
5551	Кульгеши	7	66	546	47.947893000000001	47.966596000000003	55.76999	55.749688999999996	0103000020E61000000100000005000000BD8DCD8E54F94740E19524CFF5DF4B40BD8DCD8E54F947409F1F46088FE24B40E338F06AB9FB47409F1F46088FE24B40E338F06AB9FB4740E19524CFF5DF4B40BD8DCD8E54F94740E19524CFF5DF4B40
5407	Кудеснеры	7	66	546	47.900784999999999	47.942169999999997	55.635071000000003	55.617204999999998	0103000020E610000001000000050000001ADD41EC4CF34740BEF6CC9200CF4B401ADD41EC4CF34740ABD1AB014AD14B40DBA2CC0699F84740ABD1AB014AD14B40DBA2CC0699F84740BEF6CC9200CF4B401ADD41EC4CF34740BEF6CC9200CF4B40
3354	Ковали	7	66	546	48.036825999999998	48.067737000000001	55.686878	55.668045999999997	0103000020E610000001000000050000003DD2E0B6B60448409F1C058882D54B403DD2E0B6B6044840C32B499EEBD74B4055DD239BAB084840C32B499EEBD74B4055DD239BAB0848409F1C058882D54B403DD2E0B6B60448409F1C058882D54B40
5019	Карак-Сирмы	7	66	546	47.744325000000003	47.759560999999998	55.731484999999999	55.717827	0103000020E61000000100000005000000304CA60A46DF4740C89750C1E1DB4B40304CA60A46DF4740DD41EC4CA1DD4B4095287B4B39E14740DD41EC4CA1DD4B4095287B4B39E14740C89750C1E1DB4B40304CA60A46DF4740C89750C1E1DB4B40
6736	Ичеснер-Атаево	7	66	546	47.707827000000002	47.720179000000002	55.681086999999998	55.672823000000001	0103000020E61000000100000005000000E71C3C139ADA4740917F66101FD64B40E71C3C139ADA4740895DDBDB2DD74B400C2252D32EDC4740895DDBDB2DD74B400C2252D32EDC4740917F66101FD64B40E71C3C139ADA4740917F66101FD64B40
5444	Избеби	7	66	546	47.977680999999997	47.992907000000002	55.658372999999997	55.647198000000003	0103000020E61000000100000005000000D575A8A624FD4740B0045262D7D24B40D575A8A624FD4740E2C8039145D44B40187C9A9317FF4740E2C8039145D44B40187C9A9317FF4740B0045262D7D24B40D575A8A624FD4740B0045262D7D24B40
6528	Вознесенское	7	66	546	47.876593	47.904961999999998	55.778106999999999	55.768647999999999	0103000020E6100000010000000500000086730D3334F047406211C30E63E24B4086730D3334F04740F3E49A0299E34B40B60F79CBD5F34740F3E49A0299E34B40B60F79CBD5F347406211C30E63E24B4086730D3334F047406211C30E63E24B40
5180	Буинск	7	66	546	48.074708000000001	48.101154000000001	55.707698999999998	55.698751000000001	0103000020E61000000100000005000000F25F2008900948400E863AAC70D94B40F25F200890094840B9347EE195DA4B4007EE409DF20C4840B9347EE195DA4B4007EE409DF20C48400E863AAC70D94B40F25F2008900948400E863AAC70D94B40
5014	Большое Яниково	7	66	546	47.783518999999998	47.810864000000002	55.738742999999999	55.720945	0103000020E61000000100000005000000B665C0594AE447407C9BFEEC47DC4B40B665C0594AE44740109370218FDE4B407BC03C64CAE74740109370218FDE4B407BC03C64CAE747407C9BFEEC47DC4B40B665C0594AE447407C9BFEEC47DC4B40
4836	Большие Чаки	7	66	546	47.802365999999999	47.820799000000001	55.704408000000001	55.693972000000002	0103000020E610000001000000050000000FB6D8EDB3E647407C2B1213D4D84B400FB6D8EDB3E647403885950A2ADA4B4075CB0EF10FE947403885950A2ADA4B4075CB0EF10FE947407C2B1213D4D84B400FB6D8EDB3E647407C2B1213D4D84B40
4747	Бишево	7	66	546	47.774903999999999	47.802329999999998	55.772669	55.760322000000002	0103000020E6100000010000000500000011C5E40D30E34740F436363B52E14B4011C5E40D30E3474007D15AD1E6E24B40C24CDBBFB2E6474007D15AD1E6E24B40C24CDBBFB2E64740F436363B52E14B4011C5E40D30E34740F436363B52E14B40
6301	Батеево	7	66	546	47.812966000000003	47.824382999999997	55.674382000000001	55.665756000000002	0103000020E61000000100000005000000466117450FE84740D28E1B7E37D54B40466117450FE847406B813D2652D64B406E30D46185E947406B813D2652D64B406E30D46185E94740D28E1B7E37D54B40466117450FE84740D28E1B7E37D54B40
4591	Арабоси	7	66	546	47.886726000000003	47.922704000000003	55.653472000000001	55.636975999999997	0103000020E61000000100000005000000A741D13C80F147401F2BF86D88D14B40A741D13C80F14740056D72F8A4D34B40B7F1272A1BF64740056D72F8A4D34B40B7F1272A1BF647401F2BF86D88D14B40A741D13C80F147401F2BF86D88D14B40
6098	Анаткасы	7	66	546	47.915534999999998	47.937157999999997	55.724843999999997	55.715327000000002	0103000020E61000000100000005000000F3AB394030F547401079CBD58FDB4B40F3AB394030F54740D5592DB0C7DC4B40A69718CBF4F74740D5592DB0C7DC4B40A69718CBF4F747401079CBD58FDB4B40F3AB394030F547401079CBD58FDB4B40
4215	Сыреси	7	66	501	46.388452999999998	46.426065999999999	55.081631999999999	55.062612000000001	0103000020E610000001000000050000003C84F1D3B8314740282B86AB03884B403C84F1D3B83147404E27D9EA728A4B4001F8A754893647404E27D9EA728A4B4001F8A75489364740282B86AB03884B403C84F1D3B8314740282B86AB03884B40
3890	Сиява	7	66	501	46.477072	46.547015000000002	55.148477	55.135371999999997	0103000020E610000001000000050000002DEBFEB1103D4740A565A4DE53914B402DEBFEB1103D4740A69A594B01934B40F2B5679604464740A69A594B01934B40F2B5679604464740A565A4DE53914B402DEBFEB1103D4740A565A4DE53914B40
4099	Семеновское	7	66	501	46.194965000000003	46.228786999999997	55.114944999999999	55.097676999999997	0103000020E61000000100000005000000AD6EF59CF4184740234910AE808C4B40AD6EF59CF41847405BEB8B84B68E4B40FE5F75E4481D47405BEB8B84B68E4B40FE5F75E4481D4740234910AE808C4B40AD6EF59CF4184740234910AE808C4B40
3248	Ряпино	7	66	501	46.264809	46.300589000000002	55.254482000000003	55.214244999999998	0103000020E61000000100000005000000DE57E542E52147406F2A52616C9B4B40DE57E542E5214740D9B5BDDD92A04B40C8444AB379264740D9B5BDDD92A04B40C8444AB3792647406F2A52616C9B4B40DE57E542E52147406F2A52616C9B4B40
4390	Рындино	7	66	501	46.295378999999997	46.320450999999998	55.088867	55.073458000000002	0103000020E610000001000000050000006C76A4FACE25474096D05D1267894B406C76A4FACE254740C9586DFE5F8B4B40397CD28904294740C9586DFE5F8B4B40397CD2890429474096D05D1267894B406C76A4FACE25474096D05D1267894B40
4323	Раздольное	7	66	501	46.329407000000003	46.3626	55.048012999999997	55.027541999999997	0103000020E61000000100000005000000680932022A2A47401AA20A7F86834B40680932022A2A474034643C4A25864B40CAC342AD692E474034643C4A25864B40CAC342AD692E47401AA20A7F86834B40680932022A2A47401AA20A7F86834B40
3692	Порецкое	7	66	501	46.303579999999997	46.346088999999999	55.207500000000003	55.179842999999998	0103000020E610000001000000050000001EDC9DB5DB2647400FB56D1805974B401EDC9DB5DB264740C3F5285C8F9A4B40AF40F4A44C2C4740C3F5285C8F9A4B40AF40F4A44C2C47400FB56D1805974B401EDC9DB5DB2647400FB56D1805974B40
4193	Полибино	7	66	501	46.174878999999997	46.202025999999996	55.090283999999997	55.072896	0103000020E61000000100000005000000EBE0606F621647402E01F8A754894B40EBE0606F6216474010AD156D8E8B4B408978EBFCDB19474010AD156D8E8B4B408978EBFCDB1947402E01F8A754894B40EBE0606F621647402E01F8A754894B40
3584	Никулино	7	66	501	46.050750000000001	46.076225999999998	55.165004000000003	55.145986999999998	0103000020E61000000100000005000000D122DBF97E0647401152B7B3AF924B40D122DBF97E064740C7DADFD91E954B406D8D08C6C1094740C7DADFD91E954B406D8D08C6C10947401152B7B3AF924B40D122DBF97E0647401152B7B3AF924B40
3989	Никольское	7	66	501	46.578986	46.603257999999997	55.188246999999997	55.176254	0103000020E61000000100000005000000C26B97361C4A474004E5B67D8F964B40C26B97361C4A4740F9484A7A18984B407286E28E374D4740F9484A7A18984B407286E28E374D474004E5B67D8F964B40C26B97361C4A474004E5B67D8F964B40
3571	Напольное	7	66	501	46.339872	46.378599000000001	55.141413	55.109949999999998	0103000020E61000000100000005000000BE69FAEC802B4740FC1873D7128E4B40BE69FAEC802B4740581D39D219924B402FA699EE75304740581D39D219924B402FA699EE75304740FC1873D7128E4B40BE69FAEC802B4740FC1873D7128E4B40
3471	Мишуково	7	66	501	46.135488000000002	46.159554	55.046187000000003	55.023052	0103000020E610000001000000050000000F80B8AB57114740BF0D315EF3824B400F80B8AB571147400C40A374E9854B4016F9F5436C1447400C40A374E9854B4016F9F5436C144740BF0D315EF3824B400F80B8AB57114740BF0D315EF3824B40
4279	Любимовка	7	66	501	46.404183000000003	46.427377	55.057409	55.043571999999998	0103000020E61000000100000005000000B24CBF44BC334740BA826DC493854B40B24CBF44BC3347407FBF982D59874B4003081F4AB43647407FBF982D59874B4003081F4AB4364740BA826DC493854B40B24CBF44BC334740BA826DC493854B40
3367	Кудеиха	7	66	501	46.399107000000001	46.436135999999998	55.23809	55.216349999999998	0103000020E61000000100000005000000664D2CF015334740AB3E575BB19B4B40664D2CF01533474098C0ADBB799E4B40DB4DF04DD337474098C0ADBB799E4B40DB4DF04DD3374740AB3E575BB19B4B40664D2CF015334740AB3E575BB19B4B40
3136	Козловка	7	66	501	46.260147000000003	46.281931	55.271343999999999	55.254092	0103000020E610000001000000050000008693347F4C2147406E162F1686A04B408693347F4C214740A0FB7266BBA24B40425DA45016244740A0FB7266BBA24B40425DA450162447406E162F1686A04B408693347F4C2147406E162F1686A04B40
3264	Кожевенное	7	66	501	46.491840000000003	46.537222999999997	55.227684000000004	55.211146999999997	0103000020E61000000100000005000000AD6EF59CF43E474002D369DD069B4B40AD6EF59CF43E474047E9D2BF249D4B405AD427B9C344474047E9D2BF249D4B405AD427B9C344474002D369DD069B4B40AD6EF59CF43E474002D369DD069B4B40
3475	Ивановка	7	66	501	46.148783000000002	46.171554999999998	55.027196000000004	55.015495000000001	0103000020E61000000100000005000000B39943520B13474032207BBDFB814B40B39943520B134740804A95287B834B408E3BA583F5154740804A95287B834B408E3BA583F515474032207BBDFB814B40B39943520B13474032207BBDFB814B40
3956	Долгая Поляна	7	66	501	46.569814000000001	46.591121999999999	55.112335000000002	55.093051000000003	0103000020E61000000100000005000000C76647AAEF48474018EE5C18E98B4B40C76647AAEF4847401C9947FE608E4B401AF9BCE2A94B47401C9947FE608E4B401AF9BCE2A94B474018EE5C18E98B4B40C76647AAEF48474018EE5C18E98B4B40
4078	Гарт	7	66	501	46.647365999999998	46.691229999999997	55.133642000000002	55.119692000000001	0103000020E610000001000000050000006B459BE3DC524740E2CB4411528F4B406B459BE3DC5247409FAF592E1B914B40CD0182397A5847409FAF592E1B914B40CD0182397A584740E2CB4411528F4B406B459BE3DC524740E2CB4411528F4B40
3022	Бахмутово	7	66	501	46.230744999999999	46.265248999999997	55.204279	55.185955	0103000020E61000000100000005000000965B5A0D891D47408BC3995FCD974B40965B5A0D891D47403A2174D0259A4B40FA25E2ADF32147403A2174D0259A4B40FA25E2ADF32147408BC3995FCD974B40965B5A0D891D47408BC3995FCD974B40
3680	Антипинка	7	66	501	46.229874000000002	46.258268999999999	55.146455000000003	55.124701999999999	0103000020E61000000100000005000000B119E0826C1D474076DF313CF68F4B40B119E0826C1D4740F8AA9509BF924B400A4966F50E214740F8AA9509BF924B400A4966F50E21474076DF313CF68F4B40B119E0826C1D474076DF313CF68F4B40
3125	Анастасово	7	66	501	46.231499999999997	46.257173999999999	55.188822000000002	55.172131	0103000020E610000001000000050000001283C0CAA11D47405BD07B6308964B401283C0CAA11D4740F661BD512B984B40D5B0DF13EB204740F661BD512B984B40D5B0DF13EB2047405BD07B6308964B401283C0CAA11D47405BD07B6308964B40
40483	Новочебоксарск	7	66	6914	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
26253	Ятманкино	7	66	1445	46.821126999999997	46.848345999999999	55.937981999999998	55.922015000000002	0103000020E61000000100000005000000696E85B01A694740F2B5679604F64B40696E85B01A6947404B1E4FCB0FF84B40A1D80A9A966C47404B1E4FCB0FF84B40A1D80A9A966C4740F2B5679604F64B40696E85B01A694740F2B5679604F64B40
27391	Ярославка	7	66	1445	46.593907000000002	46.625267000000001	55.997889999999998	55.983156999999999	0103000020E61000000100000005000000C8EE0225054C4740AFEAAC16D8FD4B40C8EE0225054C4740B28009DCBAFF4B404F22C2BF08504740B28009DCBAFF4B404F22C2BF08504740AFEAAC16D8FD4B40C8EE0225054C4740AFEAAC16D8FD4B40
57918	Ярабаикасы	7	66	1445	46.880451999999998	46.893621000000003	56.007066000000002	56.000335999999997	0103000020E6100000010000000500000051D9B0A6B2704740778192020B004C4051D9B0A6B2704740EF74E789E7004C406902452C62724740EF74E789E7004C406902452C62724740778192020B004C4051D9B0A6B2704740778192020B004C40
27087	Юськасы	7	66	1445	46.760804999999998	46.771009999999997	55.854284	55.847816000000002	0103000020E610000001000000050000000FD1E80E626147404583143C85EC4B400FD1E80E626147407FBF982D59ED4B40C971A774B06247407FBF982D59ED4B40C971A774B06247404583143C85EC4B400FD1E80E626147404583143C85EC4B40
27039	Юнгапоси	7	66	1445	46.653033999999998	46.678069999999998	56.045237	56.035356	0103000020E6100000010000000500000089963C9E96534740D3DB9F8B86044C4089963C9E96534740DAC87553CA054C4009336DFFCA564740DAC87553CA054C4009336DFFCA564740D3DB9F8B86044C4089963C9E96534740D3DB9F8B86044C40
26857	Юнга	7	66	1445	46.623542	46.663086	56.058960999999996	56.035581999999998	0103000020E610000001000000050000005AD76839D04F4740C32973F38D044C405AD76839D04F4740A65EB7088C074C40BD378600E0544740A65EB7088C074C40BD378600E0544740C32973F38D044C405AD76839D04F4740C32973F38D044C40
25269	Шупоси	7	66	1445	46.676048999999999	46.859692000000003	56.090466999999997	55.902732	0103000020E610000001000000050000002BBF0CC688564740BE86E0B88CF34B402BBF0CC688564740012F336C940B4C40015130630A6E4740012F336C940B4C40015130630A6E4740BE86E0B88CF34B402BBF0CC688564740BE86E0B88CF34B40
25730	Шомиково	7	66	1445	46.913913999999998	46.943683999999998	56.103186000000001	56.085706000000002	0103000020E61000000100000005000000A3AD4A22FB7447401689096AF80A4C40A3AD4A22FB744740D9B3E732350D4C4015E126A3CA784740D9B3E732350D4C4015E126A3CA7847401689096AF80A4C40A3AD4A22FB7447401689096AF80A4C40
26771	Шатьмапоси	7	66	1445	46.876013999999998	46.904103999999997	55.884312000000001	55.875647000000001	0103000020E61000000100000005000000486B0C3A2170474096EB6D3315F04B40486B0C3A21704740EDBAB72231F14B4065170CAEB9734740EDBAB72231F14B4065170CAEB973474096EB6D3315F04B40486B0C3A2170474096EB6D3315F04B40
25668	Шатракасы	7	66	1445	46.843314999999997	46.870274000000002	56.114519999999999	56.100304000000001	0103000020E61000000100000005000000F59CF4BEF16B474039D4EFC2D60C4C40F59CF4BEF16B4740745E6397A80E4C4091477023656F4740745E6397A80E4C4091477023656F474039D4EFC2D60C4C40F59CF4BEF16B474039D4EFC2D60C4C40
25532	Чураккасы	7	66	1445	46.831924999999998	46.857329	56.133909000000003	56.117440999999999	0103000020E61000000100000005000000C6DCB5847C6A4740D21A834E080F4C40C6DCB5847C6A4740EED11BEE23114C40C974E8F4BC6D4740EED11BEE23114C40C974E8F4BC6D4740D21A834E080F4C40C6DCB5847C6A4740D21A834E080F4C40
27478	Чемеево	7	66	1445	46.563104000000003	46.574629000000002	55.976205999999998	55.970453999999997	0103000020E61000000100000005000000971FB8CA13484740DD2230D637FC4B40971FB8CA1348474059147651F4FC4B40A62A6D718D49474059147651F4FC4B40A62A6D718D494740DD2230D637FC4B40971FB8CA13484740DD2230D637FC4B40
26616	Хорной	7	66	1445	46.712097999999997	46.752198999999997	55.999640999999997	55.985478000000001	0103000020E6100000010000000500000004C6FA06265B4740B876A22424FE4B4004C6FA06265B4740D05E7D3CF4FF4B40BD8A8C0E48604740D05E7D3CF4FF4B40BD8A8C0E48604740B876A22424FE4B4004C6FA06265B4740B876A22424FE4B40
25370	Тренькино	7	66	1445	46.793233999999998	46.814183	56.169407999999997	56.157573999999997	0103000020E61000000100000005000000A20914B188654740965984622B144C40A20914B18865474023D74D29AF154C40C6FA06263768474023D74D29AF154C40C6FA062637684740965984622B144C40A20914B188654740965984622B144C40
26275	Тораево	7	66	1445	46.596322999999998	46.609430000000003	55.947263	55.941147999999998	0103000020E61000000100000005000000226DE34F544C47401059A48977F84B40226DE34F544C4740FDDAFAE93FF94B40C4995FCD014E4740FDDAFAE93FF94B40C4995FCD014E47401059A48977F84B40226DE34F544C47401059A48977F84B40
26538	Тойшево	7	66	1445	46.498990999999997	46.524915999999997	55.933509000000001	55.922192000000003	0103000020E61000000100000005000000C9FFE4EFDE3F4740015130630AF64B40C9FFE4EFDE3F4740C6C210397DF74B40D5928E7230434740C6C210397DF74B40D5928E7230434740015130630AF64B40C9FFE4EFDE3F4740015130630AF64B40
26589	Тойгильдино	7	66	1445	46.645254999999999	46.656798000000002	55.948265999999997	55.941974999999999	0103000020E610000001000000050000004D4A41B797524740265305A392F84B404D4A41B79752474051F4C0C760F94B40030AF5F41154474051F4C0C760F94B40030AF5F411544740265305A392F84B404D4A41B797524740265305A392F84B40
26813	Тиуши	7	66	1445	46.928106999999997	46.956978999999997	55.864384000000001	55.851500000000001	0103000020E610000001000000050000002618CE35CC764740A245B6F3FDEC4B402618CE35CC764740C4978922A4EE4B40B9FAB1497E7A4740C4978922A4EE4B40B9FAB1497E7A4740A245B6F3FDEC4B402618CE35CC764740A245B6F3FDEC4B40
26120	Сятракасы	7	66	1445	46.523316999999999	46.811281000000001	55.951219999999999	55.922609999999999	0103000020E610000001000000050000006D382C0DFC424740357BA01518F64B406D382C0DFC4247408BA6B393C1F94B40DF6E490ED86747408BA6B393C1F94B40DF6E490ED8674740357BA01518F64B406D382C0DFC424740357BA01518F64B40
58013	Сярмыськасы	7	66	1445	46.588571000000002	46.604300000000002	56.049208999999998	56.038654999999999	0103000020E61000000100000005000000E02F664B564B4740D769A4A5F2044C40E02F664B564B47409DD5027B4C064C40857CD0B3594D47409DD5027B4C064C40857CD0B3594D4740D769A4A5F2044C40E02F664B564B4740D769A4A5F2044C40
26439	Сюткюль	7	66	1445	46.600357000000002	46.622725000000003	55.907035999999998	55.898052999999997	0103000020E610000001000000050000005C76887FD84C47408F899466F3F24B405C76887FD84C4740B72572C119F44B4068B3EA73B54F4740B72572C119F44B4068B3EA73B54F47408F899466F3F24B405C76887FD84C47408F899466F3F24B40
27298	Сыбайкасы	7	66	1445	46.891285000000003	46.907383000000003	56.032640000000001	56.023328999999997	0103000020E610000001000000050000002B357BA0157247403106D671FC024C402B357BA0157247404E452A8C2D044C4023F94A20257447404E452A8C2D044C4023F94A20257447403106D671FC024C402B357BA0157247403106D671FC024C40
27174	Старые Мадики	7	66	1445	46.712521000000002	46.729993	55.847375999999997	55.835715	0103000020E610000001000000050000004B5B5CE3335B474069E388B5F8EA4B404B5B5CE3335B474028B517D176EC4B408BA71E69705D474028B517D176EC4B408BA71E69705D474069E388B5F8EA4B404B5B5CE3335B474069E388B5F8EA4B40
25862	Рыкакасы	7	66	1445	46.846719999999998	46.862017999999999	56.055779000000001	56.045729999999999	0103000020E610000001000000050000003F6F2A52616C474019390B7BDA054C403F6F2A52616C4740DC662AC423074C401B48179B566E4740DC662AC423074C401B48179B566E474019390B7BDA054C403F6F2A52616C474019390B7BDA054C40
25910	Полевые Хачики	7	66	1445	46.751939	46.769384000000002	56.069293000000002	56.048836999999999	0103000020E6100000010000000500000021CB82893F604740D9EA724A40064C4021CB82893F604740BE6BD097DE084C406808C72C7B624740BE6BD097DE084C406808C72C7B624740D9EA724A40064C4021CB82893F604740D9EA724A40064C40
26196	Оточево	7	66	1445	46.873786000000003	46.887557000000001	55.919356999999998	55.905174000000002	0103000020E61000000100000005000000F1D93A38D86F47404298DBBDDCF34B40F1D93A38D86F4740A12C7C7DADF54B40FE2AC0779B714740A12C7C7DADF54B40FE2AC0779B7147404298DBBDDCF34B40F1D93A38D86F47404298DBBDDCF34B40
25962	Оринино	7	66	1445	46.802540999999998	46.817453	56.018363000000001	56.007755000000003	0103000020E610000001000000050000007D59DAA9B9664740B4B0A71DFE004C407D59DAA9B96647406D3A02B859024C403082C64CA26847406D3A02B859024C403082C64CA2684740B4B0A71DFE004C407D59DAA9B9664740B4B0A71DFE004C40
58017	Ойкасы	7	66	1445	46.630558000000001	46.642676999999999	56.105074000000002	56.099325	0103000020E61000000100000005000000971DE21FB65047406D567DAEB60C4C40971DE21FB650474078D49810730D4C4019726C3D4352474078D49810730D4C4019726C3D435247406D567DAEB60C4C40971DE21FB65047406D567DAEB60C4C40
26686	Одаркино	7	66	1445	46.695605	46.720255000000002	55.917994999999998	55.902529999999999	0103000020E6100000010000000500000090F7AA950959474056D4601A86F34B4090F7AA95095947401D7233DC80F54B40E7E3DA50315C47401D7233DC80F54B40E7E3DA50315C474056D4601A86F34B4090F7AA950959474056D4601A86F34B40
27212	Нижний Панклей	7	66	1445	46.822842999999999	46.835966999999997	55.874597000000001	55.866146999999998	0103000020E610000001000000050000000B5F5FEB52694740A643A7E7DDEE4B400B5F5FEB52694740011764CBF2EF4B4082C476F7006B4740011764CBF2EF4B4082C476F7006B4740A643A7E7DDEE4B400B5F5FEB52694740A643A7E7DDEE4B40
25796	Москакасы	7	66	1445	46.756798000000003	46.773453000000003	56.055276999999997	56.043084999999998	0103000020E61000000100000005000000D0D6C1C1DE6047405DF92CCF83054C40D0D6C1C1DE604740499C155113074C401EFF058200634740499C155113074C401EFF0582006347405DF92CCF83054C40D0D6C1C1DE6047405DF92CCF83054C40
25012	Моргауши	7	66	1445	46.762844000000001	46.792614	55.972056000000002	55.954486000000003	0103000020E6100000010000000500000094F947DFA4614740B43EE5982CFA4B4094F947DFA4614740B7F0BC546CFC4B40062D246074654740B7F0BC546CFC4B40062D246074654740B43EE5982CFA4B4094F947DFA4614740B43EE5982CFA4B40
26097	Молгачкасы	7	66	1445	46.828268000000001	46.849496000000002	56.020079000000003	56.009309999999999	0103000020E61000000100000005000000632992AF046A47404CC3F01131014C40632992AF046A47400F2BDCF291024C409A0AF148BC6C47400F2BDCF291024C409A0AF148BC6C47404CC3F01131014C40632992AF046A47404CC3F01131014C40
26947	Кубасы	7	66	1445	46.604058000000002	46.630082000000002	56.081220999999999	56.061991999999996	0103000020E610000001000000050000008F71C5C5514D47408B4E965AEF074C408F71C5C5514D4740CC5F2173650A4C402EE6E786A6504740CC5F2173650A4C402EE6E786A65047408B4E965AEF074C408F71C5C5514D47408B4E965AEF074C40
26160	Кашмаши	7	66	1445	46.795479999999998	46.838706999999999	55.965651999999999	55.947620999999998	0103000020E61000000100000005000000A04FE449D26547405C001AA54BF94B40A04FE449D265474093A8177C9AFB4B4090F63FC05A6B474093A8177C9AFB4B4090F63FC05A6B47405C001AA54BF94B40A04FE449D26547405C001AA54BF94B40
25627	Калайкасы	7	66	1445	46.872996000000001	46.886496999999999	56.063825999999999	56.054492000000003	0103000020E61000000100000005000000F8C43A55BE6F474063F20698F9064C40F8C43A55BE6F474037514B732B084C404580D3BB7871474037514B732B084C404580D3BB7871474063F20698F9064C40F8C43A55BE6F474063F20698F9064C40
25575	Кадикасы	7	66	1445	46.874217000000002	46.909520999999998	56.087991000000002	56.072544000000001	0103000020E61000000100000005000000BA4DB857E66F4740B1C22D1F49094C40BA4DB857E66F4740D2AB014A430B4C403A03232F6B744740D2AB014A430B4C403A03232F6B744740B1C22D1F49094C40BA4DB857E66F4740B1C22D1F49094C40
26737	Изедеркино	7	66	1445	46.67436	46.693520999999997	55.876375000000003	55.862181	0103000020E6100000010000000500000083DDB06D51564740C51D6FF25BEE4B4083DDB06D515647401904560E2DF04B406B0BCF4BC55847401904560E2DF04B406B0BCF4BC5584740C51D6FF25BEE4B4083DDB06D51564740C51D6FF25BEE4B40
25480	Вурманкасы	7	66	1445	46.745919999999998	46.849333999999999	56.145634999999999	55.869607000000002	0103000020E6100000010000000500000056B77A4E7A5F4740B4AF3C484FEF4B4056B77A4E7A5F47409413ED2AA4124C40C0B0FCF9B66C47409413ED2AA4124C40C0B0FCF9B66C4740B4AF3C484FEF4B4056B77A4E7A5F4740B4AF3C484FEF4B40
24740	Вомбакасы	7	66	1445	46.677064000000001	46.705074000000003	56.111991000000003	56.099431000000003	0103000020E6100000010000000500000044A67C08AA564740B39AAE27BA0C4C4044A67C08AA564740223999B8550E4C4045A165DD3F5A4740223999B8550E4C4045A165DD3F5A4740B39AAE27BA0C4C4044A67C08AA564740B39AAE27BA0C4C40
25141	Васькино	7	66	1445	46.658011000000002	46.674934999999998	55.865813000000003	55.856648999999997	0103000020E6100000010000000500000042B456B4395447405793A7ACA6ED4B4042B456B439544740D0B9DBF5D2EE4B407FF6234564564740D0B9DBF5D2EE4B407FF62345645647405793A7ACA6ED4B4042B456B4395447405793A7ACA6ED4B40
25331	Большое Карачкино	7	66	1445	46.604498	46.617702999999999	56.125390000000003	56.113425999999997	0103000020E61000000100000005000000AB3FC230604D47400F4240BE840E4C40AB3FC230604D47406B9F8EC70C104C400FD253E4104F47406B9F8EC70C104C400FD253E4104F47400F4240BE840E4C40AB3FC230604D47400F4240BE840E4C40
26401	Большие Токшики	7	66	1445	46.636541000000001	46.664676	55.934432000000001	55.919549000000004	0103000020E6100000010000000500000015C8EC2C7A514740E60819C8B3F54B4015C8EC2C7A514740FE2AC0779BF74B40D237691A14554740FE2AC0779BF74B40D237691A14554740E60819C8B3F54B4015C8EC2C7A514740E60819C8B3F54B40
25235	Большие Татаркасы	7	66	1445	46.746206999999998	46.759943	56.096618999999997	56.084761999999998	0103000020E61000000100000005000000EC8502B6835F4740C6F8307BD90A4C40EC8502B6835F47400B96EA025E0C4C407DE9EDCF456147400B96EA025E0C4C407DE9EDCF45614740C6F8307BD90A4C40EC8502B6835F4740C6F8307BD90A4C40
16323	Большая Сундырь	7	66	1445	46.724055	46.76182	56.120176000000001	56.101866000000001	0103000020E61000000100000005000000ADC090D5AD5C47408449F1F1090D4C40ADC090D5AD5C4740CEE15AED610F4C4028B8585183614740CEE15AED610F4C4028B85851836147408449F1F1090D4C40ADC090D5AD5C47408449F1F1090D4C40
26049	Басурманы	7	66	1445	46.782733	46.791707000000002	56.005667000000003	56.000563	0103000020E61000000100000005000000FF3F4E9830644740384BC97212004C40FF3F4E98306447404ED53DB2B9004C40D481ACA7566547404ED53DB2B9004C40D481ACA756654740384BC97212004C40FF3F4E9830644740384BC97212004C40
25421	Апчары	7	66	1445	46.763086999999999	46.783864999999999	56.140946	56.128901999999997	0103000020E610000001000000050000005A80B6D5AC614740CA3159DC7F104C405A80B6D5AC6147404240BE840A124C4051BD35B0556447404240BE840A124C4051BD35B055644740CA3159DC7F104C405A80B6D5AC614740CA3159DC7F104C40
26481	Анаткасы	7	66	1445	46.544759999999997	46.925628000000003	56.090035	55.926827000000003	0103000020E61000000100000005000000A01518B2BA45474060066344A2F64B40A01518B2BA454740683F5244860B4C40862172FA7A764740683F5244860B4C40862172FA7A76474060066344A2F64B40A01518B2BA45474060066344A2F64B40
27343	Акрамово	7	66	1445	46.867542999999998	46.885472999999998	55.972881999999998	55.957273000000001	0103000020E61000000100000005000000D66F26A60B6F4740022CF2EB87FA4B40D66F26A60B6F4740FC6EBA6587FC4B40D93EE42D57714740FC6EBA6587FC4B40D93EE42D57714740022CF2EB87FA4B40D66F26A60B6F4740022CF2EB87FA4B40
26010	Адабай	7	66	1445	46.822572999999998	46.831843999999997	55.989964999999998	55.980936	0103000020E610000001000000050000004BC972124A6947400ABC934F8FFD4B404BC972124A694740A297512CB7FE4B40D9AF3BDD796A4740A297512CB7FE4B40D9AF3BDD796A47400ABC934F8FFD4B404BC972124A6947400ABC934F8FFD4B40
52569	Ящерино	7	66	1654	47.679692000000003	47.712443999999998	56.070695000000001	56.056914999999996	0103000020E610000001000000050000002AADBF2500D747406FD39FFD48074C402AADBF2500D74740D07EA4880C094C409F1D705D31DB4740D07EA4880C094C409F1D705D31DB47406FD39FFD48074C402AADBF2500D747406FD39FFD48074C40
32766	Эльбарусово	7	66	1654	47.774141	47.806173999999999	55.972574000000002	55.960552999999997	0103000020E6100000010000000500000012BF620D17E347408F899466F3FA4B4012BF620D17E347404F78094E7DFC4B405871AAB530E747404F78094E7DFC4B405871AAB530E747408F899466F3FA4B4012BF620D17E347408F899466F3FA4B40
52506	Щамалы	7	66	1654	48.042701000000001	48.057423999999997	55.910981999999997	55.903816999999997	0103000020E61000000100000005000000D540F33977054840CF488446B0F34B40D540F33977054840519FE40E9BF44B40B4006DAB59074840519FE40E9BF44B40B4006DAB59074840CF488446B0F34B40D540F33977054840CF488446B0F34B40
52552	Шульгино	7	66	1654	47.875255000000003	47.889727000000001	56.082777999999998	56.073810000000002	0103000020E610000001000000050000008B54185B08F04740130F289B72094C408B54185B08F04740056A3178980A4C4021AF0793E2F14740056A3178980A4C4021AF0793E2F14740130F289B72094C408B54185B08F04740130F289B72094C40
24612	Шоршелы	7	66	1654	47.576555999999997	47.605714999999996	56.013159999999999	56.000774	0103000020E6100000010000000500000002284696CCC94740F357C85C19004C4002284696CCC94740C4CE143AAF014C402BD9B11188CD4740C4CE143AAF014C402BD9B11188CD4740F357C85C19004C4002284696CCC94740F357C85C19004C40
23672	Шанары	7	66	1654	47.971122999999999	47.987374000000003	55.899698999999998	55.884782000000001	0103000020E610000001000000050000005BB22AC24DFC4740740B5D8940F14B405BB22AC24DFC4740389F3A5629F34B40DA756F4562FE4740389F3A5629F34B40DA756F4562FE4740740B5D8940F14B405BB22AC24DFC4740740B5D8940F14B40
23895	Чурашево 1-е	7	66	1654	47.661060999999997	47.687893000000003	55.950186000000002	55.939565000000002	0103000020E610000001000000050000009DD497A59DD44740AEBB79AA43F84B409DD497A59DD44740FC8EE1B19FF94B40DC12B9E00CD84740FC8EE1B19FF94B40DC12B9E00CD84740AEBB79AA43F84B409DD497A59DD44740AEBB79AA43F84B40
58043	Чекуры 2-е	7	66	1654	47.866450999999998	47.876314999999998	55.886493999999999	55.872656999999997	0103000020E61000000100000005000000124BCADDE7EE47400FD07D39B3EF4B40124BCADDE7EE4740D40CA9A278F14B4043FF04172BF04740D40CA9A278F14B4043FF04172BF047400FD07D39B3EF4B40124BCADDE7EE47400FD07D39B3EF4B40
52560	Ураково	7	66	1654	47.871634999999998	47.887894000000003	56.105074000000002	56.089813999999997	0103000020E61000000100000005000000448655BC91EF4740895C70067F0B4C40448655BC91EF474078D49810730D4C404628B682A6F1474078D49810730D4C404628B682A6F14740895C70067F0B4C40448655BC91EF4740895C70067F0B4C40
24975	Тогаево	7	66	1654	47.830832999999998	47.856794999999998	55.974176	55.960906000000001	0103000020E6100000010000000500000002B859BC58EA4740DD43C2F7FEFA4B4002B859BC58EA4740284696CCB1FC4B402B306475ABED4740284696CCB1FC4B402B306475ABED4740DD43C2F7FEFA4B4002B859BC58EA4740DD43C2F7FEFA4B40
52547	Тинсарино	7	66	1654	47.777303000000003	47.793031999999997	56.073821000000002	56.062947000000001	0103000020E61000000100000005000000960A2AAA7EE34740CF30B5A50E084C40960A2AAA7EE3474007616EF772094C403A57941282E5474007616EF772094C403A57941282E54740CF30B5A50E084C40960A2AAA7EE34740CF30B5A50E084C40
52505	Сятракасы	7	66	1654	47.935909000000002	47.982056	55.926488999999997	55.912602	0103000020E610000001000000050000001B84B9DDCBF74740D1217024D0F44B401B84B9DDCBF74740478D093197F64B40986BD102B4FD4740478D093197F64B40986BD102B4FD4740D1217024D0F44B401B84B9DDCBF74740D1217024D0F44B40
52507	Сюндюково	7	66	1654	47.735844999999998	47.762768000000001	55.900637000000003	55.885933000000001	0103000020E610000001000000050000006AF6402B30DE47403DB9A64066F14B406AF6402B30DE4740A648BE1248F34B40B937BF61A2E14740A648BE1248F34B40B937BF61A2E147403DB9A64066F14B406AF6402B30DE47403DB9A64066F14B40
52565	Сутчево	7	66	1654	47.685549000000002	47.706434999999999	56.086770999999999	56.077508000000002	0103000020E610000001000000050000001B67D311C0D74740D5963AC8EB094C401B67D311C0D74740E09EE74F1B0B4C40F8DF4A766CDA4740E09EE74F1B0B4C40F8DF4A766CDA4740D5963AC8EB094C401B67D311C0D74740D5963AC8EB094C40
52581	Средние Бокаши	7	66	1654	47.771014000000001	47.781866000000001	55.939207000000003	55.927709999999998	0103000020E610000001000000050000000B613596B0E2474009168733BFF64B400B613596B0E247404F965AEF37F84B405BED612F14E447404F965AEF37F84B405BED612F14E4474009168733BFF64B400B613596B0E2474009168733BFF64B40
23375	Сотниково	7	66	1654	47.766396999999998	47.791685000000001	56.030296	56.011750999999997	0103000020E610000001000000050000005260014C19E24740FF58880E81014C405260014C19E247408D9944BDE0034C40ECDD1FEF55E547408D9944BDE0034C40ECDD1FEF55E54740FF58880E81014C405260014C19E24740FF58880E81014C40
58047	Синьялы 1-е	7	66	1654	47.746437	47.759300000000003	55.953628999999999	55.942680000000003	0103000020E610000001000000050000001EC3633F8BDF4740F14BFDBCA9F84B401EC3633F8BDF474033C2DB8310FA4B4029ED0DBE30E1474033C2DB8310FA4B4029ED0DBE30E14740F14BFDBCA9F84B401EC3633F8BDF4740F14BFDBCA9F84B40
23526	Покровское	7	66	1654	47.911475000000003	47.954810000000002	55.948129999999999	55.930608999999997	0103000020E61000000100000005000000910F7A36ABF447407F2E1A321EF74B40910F7A36ABF44740A12DE7525CF94B4067F2CD3637FA4740A12DE7525CF94B4067F2CD3637FA47407F2E1A321EF74B40910F7A36ABF447407F2E1A321EF74B40
52529	Передние Бокаши	7	66	1654	47.793031999999997	47.80621	55.939332999999998	55.924244999999999	0103000020E610000001000000050000003A57941282E54740EA3E00A94DF64B403A57941282E54740DB8651103CF84B40A5DAA7E331E74740DB8651103CF84B40A5DAA7E331E74740EA3E00A94DF64B403A57941282E54740EA3E00A94DF64B40
23759	Октябрьское	7	66	1654	47.806623999999999	47.824195000000003	55.910012999999999	55.897618999999999	0103000020E6100000010000000500000098158A743FE7474055A2EC2DE5F24B4098158A743FE74740A9F7544E7BF44B406C43C5387FE94740A9F7544E7BF44B406C43C5387FE9474055A2EC2DE5F24B4098158A743FE7474055A2EC2DE5F24B40
52553	Нерядово	7	66	1654	47.766728999999998	47.800704000000003	56.119202999999999	56.104596999999998	0103000020E6100000010000000500000088F2052D24E247403E213B6F630D4C4088F2052D24E24740E44A3D0B420F4C4061E3FA777DE64740E44A3D0B420F4C4061E3FA777DE647403E213B6F630D4C4088F2052D24E247403E213B6F630D4C40
57922	Мижули	7	66	1654	47.713459	47.735180999999997	55.939841999999999	55.933045	0103000020E61000000100000005000000B804E09F52DB47402159C0046EF74B40B804E09F52DB474020B41EBE4CF84B40FED137691ADE474020B41EBE4CF84B40FED137691ADE47402159C0046EF74B40B804E09F52DB47402159C0046EF74B40
22673	Мариинский Посад	7	66	1654	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
52511	Малое Шигаево	7	66	1654	47.681739999999998	47.708706999999997	56.028117999999999	56.016446000000002	0103000020E6100000010000000500000001309E4143D7474034130CE71A024C4001309E4143D74740E736E15E99034C401FB935E9B6DA4740E736E15E99034C401FB935E9B6DA474034130CE71A024C4001309E4143D7474034130CE71A024C40
52578	Малое Камаево	7	66	1654	47.620770999999998	47.648663999999997	56.009366	56.001458999999997	0103000020E6100000010000000500000011A7936C75CF474076A4FACE2F004C4011A7936C75CF4740E0D8B3E732014C40D80B056C07D34740E0D8B3E732014C40D80B056C07D3474076A4FACE2F004C4011A7936C75CF474076A4FACE2F004C40
24339	Кушниково	7	66	1654	47.875290999999997	47.896177000000002	56.065539999999999	56.046709999999997	0103000020E61000000100000005000000D7BD158909F04740B532E197FA054C40D7BD158909F04740384A5E9D63084C40B5368DEDB5F24740384A5E9D63084C40B5368DEDB5F24740B532E197FA054C40D7BD158909F04740B532E197FA054C40
52520	Кугеево	7	66	1654	47.903317999999999	47.925632	55.868698000000002	55.851652000000001	0103000020E61000000100000005000000AEF199EC9FF3474058C9C7EE02ED4B40AEF199EC9FF34740E10CFE7E31EF4B40C710001C7BF64740E10CFE7E31EF4B40C710001C7BF6474058C9C7EE02ED4B40AEF199EC9FF3474058C9C7EE02ED4B40
52537	Караньялы	7	66	1654	47.708393000000001	47.738424000000002	55.959591000000003	55.940199999999997	0103000020E6100000010000000500000090DB2F9FACDA47407FD93D7958F84B4090DB2F9FACDA47409A44BDE0D3FA4B406F4A79AD84DE47409A44BDE0D3FA4B406F4A79AD84DE47407FD93D7958F84B4090DB2F9FACDA47407FD93D7958F84B40
52543	Карабаши	7	66	1654	47.893858999999999	47.935765000000004	55.964252000000002	55.955598999999999	0103000020E610000001000000050000001D1EC2F869F247408F8B6A1151FA4B401D1EC2F869F24740228D0A9C6CFB4B40E8DEC325C7F74740228D0A9C6CFB4B40E8DEC325C7F747408F8B6A1151FA4B401D1EC2F869F247408F8B6A1151FA4B40
52533	Ибраялы	7	66	1654	47.670546999999999	47.682673999999999	55.924501999999997	55.918398000000003	0103000020E6100000010000000500000028B7ED7BD4D547401D5BCF108EF54B4028B7ED7BD4D54740158BDF1456F64B402DEA93DC61D74740158BDF1456F64B402DEA93DC61D747401D5BCF108EF54B4028B7ED7BD4D547401D5BCF108EF54B40
52579	Ельниково	7	66	1654	47.587488999999998	47.594234999999998	56.030397000000001	56.024656999999998	0103000020E610000001000000050000003FE1ECD632CB4740094FE8F527034C403FE1ECD632CB4740C172840CE4034C40BC9179E40FCC4740C172840CE4034C40BC9179E40FCC4740094FE8F527034C403FE1ECD632CB4740094FE8F527034C40
52545	Дубовка	7	66	1654	47.810054999999998	47.828974000000002	56.068967000000001	56.052286000000002	0103000020E610000001000000050000000B7BDAE1AFE74740F304C24EB1064C400B7BDAE1AFE747406AC020E9D3084C40FE9DEDD11BEA47406AC020E9D3084C40FE9DEDD11BEA4740F304C24EB1064C400B7BDAE1AFE74740F304C24EB1064C40
52517	Большое Яндуганово	7	66	1654	47.764420999999999	47.777779000000002	56.007452999999998	55.994183999999997	0103000020E6100000010000000500000014B01D8CD8E147406D1ADB6B41FF4B4014B01D8CD8E14740E8A04B38F4004C40FF4124438EE34740E8A04B38F4004C40FF4124438EE347406D1ADB6B41FF4B4014B01D8CD8E147406D1ADB6B41FF4B40
52510	Большое Шигаево	7	66	1654	47.690767999999998	47.709012999999999	56.000014	55.991610999999999	0103000020E61000000100000005000000C98FF8156BD847404BADF71BEDFE4B40C98FF8156BD8474065C5707500004C402CB81FF0C0DA474065C5707500004C402CB81FF0C0DA47404BADF71BEDFE4B40C98FF8156BD847404BADF71BEDFE4B40
58025	Большое Малашкино	7	66	1654	47.651242000000003	47.671239	56.093721000000002	56.084375000000001	0103000020E610000001000000050000000DE4D9E55BD34740CDCCCCCCCC0A4C400DE4D9E55BD3474066F9BA0CFF0B4C405E66D828EBD5474066F9BA0CFF0B4C405E66D828EBD54740CDCCCCCCCC0A4C400DE4D9E55BD34740CDCCCCCCCC0A4C40
52576	Большое Камаево	7	66	1654	47.614249000000001	47.635027000000001	55.992769000000003	55.982531999999999	0103000020E61000000100000005000000E44C13B69FCE474001A3CB9BC3FD4B40E44C13B69FCE4740C7BDF90D13FF4B40DB89929048D14740C7BDF90D13FF4B40DB89929048D1474001A3CB9BC3FD4B40E44C13B69FCE474001A3CB9BC3FD4B40
23165	Бичурино	7	66	1654	47.769208999999996	47.805995000000003	55.870890000000003	55.858018000000001	0103000020E61000000100000005000000F964C57075E247408EB0A888D3ED4B40F964C57075E24740EC34D25279EF4B40A9DE1AD82AE74740EC34D25279EF4B40A9DE1AD82AE747408EB0A888D3ED4B40F964C57075E247408EB0A888D3ED4B40
52539	Астакасы	7	66	1654	47.800192000000003	47.827832999999998	56.049565999999999	56.035240000000002	0103000020E61000000100000005000000AB4203B16CE647406AC18BBE82044C40AB4203B16CE647402C7FBE2D58064C4058C6866EF6E947402C7FBE2D58064C4058C6866EF6E947406AC18BBE82044C40AB4203B16CE647406AC18BBE82044C40
52513	Арзаматово	7	66	1654	47.698160999999999	47.722002000000003	56.040671000000003	56.030813999999999	0103000020E61000000100000005000000DC2BF3565DD94740252191B6F1034C40DC2BF3565DD94740A47213B534054C40C4D2C08F6ADC4740A47213B534054C40C4D2C08F6ADC4740252191B6F1034C40DC2BF3565DD94740252191B6F1034C40
52535	Алмандаево	7	66	1654	47.608122999999999	47.624417999999999	55.974992	55.969068	0103000020E61000000100000005000000037976F9D6CD4740D1CC936B0AFC4B40037976F9D6CD47404AEEB089CCFC4B405184D4EDECCF47404AEEB089CCFC4B405184D4EDECCF4740D1CC936B0AFC4B40037976F9D6CD4740D1CC936B0AFC4B40
52528	Акшики	7	66	1654	47.836492999999997	47.864969000000002	55.926609999999997	55.915841	0103000020E610000001000000050000009D2ADF3312EB474000AB23473AF54B409D2ADF3312EB4740C2120F289BF64B40E486DF4DB7EE4740C2120F289BF64B40E486DF4DB7EE474000AB23473AF54B409D2ADF3312EB474000AB23473AF54B40
52503	Аксарино	7	66	1654	47.897533000000003	47.932037000000001	55.919922	55.904079000000003	0103000020E61000000100000005000000570A815CE2F247400D0055DCB8F34B40570A815CE2F247407A6F0C01C0F54B40BBD408FD4CF747407A6F0C01C0F54B40BBD408FD4CF747400D0055DCB8F34B40570A815CE2F247400D0055DCB8F34B40
52465	Янгильдино	7	66	1454	46.170468	46.186574999999998	55.707901999999997	55.688491999999997	0103000020E61000000100000005000000DC813AE5D115474060C77F8120D84B40DC813AE5D1154740F16261889CDA4B4027A089B0E1174740F16261889CDA4B4027A089B0E117474060C77F8120D84B40DC813AE5D115474060C77F8120D84B40
52420	Ямаши	7	66	1454	46.108322999999999	46.131571000000001	55.742457999999999	55.731090000000002	0103000020E61000000100000005000000CA332F87DD0D474061376C5B94DD4B40CA332F87DD0D4740A8531EDD08DF4B400F0D8B51D7104740A8531EDD08DF4B400F0D8B51D710474061376C5B94DD4B40CA332F87DD0D474061376C5B94DD4B40
52482	Яманы	7	66	1454	46.460991999999997	46.476613999999998	55.737561999999997	55.727865999999999	0103000020E61000000100000005000000DBDB2DC9013B474067EF8CB62ADD4B40DBDB2DC9013B4740DC627E6E68DE4B406A6803B0013D4740DC627E6E68DE4B406A6803B0013D474067EF8CB62ADD4B40DBDB2DC9013B474067EF8CB62ADD4B40
52496	Ягункино	7	66	1454	46.322679000000001	46.351281	55.720925000000001	55.708875999999997	0103000020E61000000100000005000000910DA48B4D294740AB75E272BCDA4B40910DA48B4D29474035EF384547DC4B40645A9BC6F62C474035EF384547DC4B40645A9BC6F62C4740AB75E272BCDA4B40910DA48B4D294740AB75E272BCDA4B40
22566	Штанаши	7	66	1454	46.446421999999998	46.464863999999999	55.693728	55.680624999999999	0103000020E61000000100000005000000821B295B2439474085EB51B81ED74B40821B295B24394740E5284014CCD84B403B8BDEA9803B4740E5284014CCD84B403B8BDEA9803B474085EB51B81ED74B40821B295B2439474085EB51B81ED74B40
33148	Шоля	7	66	1454	46.052132999999998	46.082011000000001	55.736477999999998	55.712791000000003	0103000020E610000001000000050000006C054D4BAC0647400BF148BC3CDB4B406C054D4BAC0647409B1C3EE944DE4B40C57421567F0A47409B1C3EE944DE4B40C57421567F0A47400BF148BC3CDB4B406C054D4BAC0647400BF148BC3CDB4B40
57913	Черепаново	7	66	1454	46.114620000000002	46.147714000000001	55.718197000000004	55.703839000000002	0103000020E61000000100000005000000D8BB3FDEAB0E47401E53776517DA4B40D8BB3FDEAB0E4740EC8A19E1EDDB4B40A794D74AE8124740EC8A19E1EDDB4B40A794D74AE81247401E53776517DA4B40D8BB3FDEAB0E47401E53776517DA4B40
22472	Хоршеваши	7	66	1454	46.360489000000001	46.379900999999997	55.730994000000003	55.720038000000002	0103000020E61000000100000005000000ACC8E880242E47404AF086342ADC4B40ACC8E880242E47403FC91D3691DD4B40DD5B9198A03047403FC91D3691DD4B40DD5B9198A03047404AF086342ADC4B40ACC8E880242E47404AF086342ADC4B40
52472	Хирлукасы	7	66	1454	46.133178999999998	46.157181999999999	55.770142	55.743749999999999	0103000020E61000000100000005000000CAC16C020C1147403333333333DF4B40CAC16C020C11474055A3570394E24B408BC22E8A1E14474055A3570394E24B408BC22E8A1E1447403333333333DF4B40CAC16C020C1147403333333333DF4B40
52470	Хвадукасы	7	66	1454	46.075147999999999	46.101343	55.774816000000001	55.760660999999999	0103000020E610000001000000050000000E2E1D739E094740DC2BF3565DE14B400E2E1D739E0947407235B22B2DE34B40DA56B3CEF80C47407235B22B2DE34B40DA56B3CEF80C4740DC2BF3565DE14B400E2E1D739E094740DC2BF3565DE14B40
52450	Торханы	7	66	1454	46.217477000000002	46.236412999999999	55.772325000000002	55.760635999999998	0103000020E61000000100000005000000EC504D49D61B474083143C855CE14B40EC504D49D61B47400D71AC8BDBE24B40B4ACFBC7421E47400D71AC8BDBE24B40B4ACFBC7421E474083143C855CE14B40EC504D49D61B474083143C855CE14B40
52431	Тоганаши	7	66	1454	46.228265999999998	46.260568999999997	55.686112000000001	55.655366000000001	0103000020E61000000100000005000000F564FED1371D474086747808E3D34B40F564FED1371D474053B29C84D2D74B40FBAC32535A21474053B29C84D2D74B40FBAC32535A21474086747808E3D34B40F564FED1371D474086747808E3D34B40
52492	Тиханкино	7	66	1454	46.338273000000001	46.368501999999999	55.713202000000003	55.700273000000003	0103000020E61000000100000005000000560F98874C2B4740CBA2B08BA2D94B40560F98874C2B47408DB800344ADB4B405B41D3122B2F47408DB800344ADB4B405B41D3122B2F4740CBA2B08BA2D94B40560F98874C2B4740CBA2B08BA2D94B40
52430	Тарабай	7	66	1454	46.173163000000002	46.193311999999999	55.676107999999999	55.650775000000003	0103000020E610000001000000050000004AF086342A164740F7065F984CD34B404AF086342A1647403048FAB48AD64B4051F69672BE1847403048FAB48AD64B4051F69672BE184740F7065F984CD34B404AF086342A164740F7065F984CD34B40
52476	Старые Атаи	7	66	1454	46.375805	46.411422999999999	55.721680999999997	55.708013999999999	0103000020E610000001000000050000002E56D4601A304740198EE733A0DA4B402E56D4601A3047408192020B60DC4B403EE94482A93447408192020B60DC4B403EE94482A9344740198EE733A0DA4B402E56D4601A304740198EE733A0DA4B40
52425	Сосново	7	66	1454	46.193168999999997	46.210631999999997	55.681365999999997	55.673087000000002	0103000020E61000000100000005000000EECC04C3B91847406F2EFEB627D64B40EECC04C3B91847409C4D470037D74B40DBBE47FDF51A47409C4D470037D74B40DBBE47FDF51A47406F2EFEB627D64B40EECC04C3B91847406F2EFEB627D64B40
52428	Сормово	7	66	1454	46.185586999999998	46.201791999999998	55.630313999999998	55.617927000000002	0103000020E6100000010000000500000008C89750C11747405F28603B18CF4B4008C89750C1174740001B1021AED04B40164CFC51D4194740001B1021AED04B40164CFC51D41947405F28603B18CF4B4008C89750C11747405F28603B18CF4B40
52486	Санкино	7	66	1454	46.301613000000003	46.334384	55.742812999999998	55.725737000000002	0103000020E61000000100000005000000348639419B264740A33F34F3E4DC4B40348639419B2647409605137F14DF4B4020274C18CD2A47409605137F14DF4B4020274C18CD2A4740A33F34F3E4DC4B40348639419B264740A33F34F3E4DC4B40
33039	Питеркино	7	66	1454	46.111789999999999	46.161943000000001	55.687882999999999	55.668219000000001	0103000020E610000001000000050000008A027D224F0E47406DC83F3388D54B408A027D224F0E4740B83CD68C0CD84B407768588CBA144740B83CD68C0CD84B407768588CBA1447406DC83F3388D54B408A027D224F0E47406DC83F3388D54B40
21795	Пандиково	7	66	1454	46.107486999999999	46.123136000000002	55.759850999999998	55.751229000000002	0103000020E6100000010000000500000061DF4E22C20D47404567994528E04B4061DF4E22C20D47409C6A2DCC42E14B40EA7AA2EBC20F47409C6A2DCC42E14B40EA7AA2EBC20F47404567994528E04B4061DF4E22C20D47404567994528E04B40
52481	Новые Атаи	7	66	1454	46.403427999999998	46.437806999999999	55.733562999999997	55.722968000000002	0103000020E6100000010000000500000035255987A3334740FB0626378ADC4B4035255987A33347401F477364E5DD4B40DD7A4D0F0A3847401F477364E5DD4B40DD7A4D0F0A384740FB0626378ADC4B4035255987A3334740FB0626378ADC4B40
52441	Мочковаши	7	66	1454	46.239432000000001	46.271942000000003	55.751528	55.737720000000003	0103000020E61000000100000005000000D5CE30B5A51E474075CDE49B6DDE4B40D5CE30B5A51E47409F03CB1132E04B405534D6FECE2247409F03CB1132E04B405534D6FECE22474075CDE49B6DDE4B40D5CE30B5A51E474075CDE49B6DDE4B40
33027	Мижеркасы	7	66	1454	46.063119	46.078094	55.735402999999998	55.730918000000003	0103000020E61000000100000005000000CC608C4814084740640795B88EDD4B40CC608C4814084740AD307DAF21DE4B40C501F4FBFE094740AD307DAF21DE4B40C501F4FBFE094740640795B88EDD4B40CC608C4814084740640795B88EDD4B40
52447	Кумаркино	7	66	1454	46.265663000000004	46.287365999999999	55.791268000000002	55.771858999999999	0103000020E61000000100000005000000EE60C43E01224740C70F9546CCE24B40EE60C43E01224740882F134548E54B40BDFDB968C8244740882F134548E54B40BDFDB968C8244740C70F9546CCE24B40EE60C43E01224740C70F9546CCE24B40
52478	Кузнечная	7	66	1454	46.399538999999997	46.419938999999999	55.770558000000001	55.755834	0103000020E61000000100000005000000FF3C0D1824334740399A232BBFE04B40FF3C0D1824334740E9D500A5A1E24B4050A8A78FC0354740E9D500A5A1E24B4050A8A78FC0354740399A232BBFE04B40FF3C0D1824334740399A232BBFE04B40
21521	Красные Четаи	7	66	1454	46.116757999999997	46.17407	55.710397999999998	55.685319999999997	0103000020E61000000100000005000000EFC517EDF10E4740B9A5D590B8D74B40EFC517EDF10E474068925852EEDA4B407C9BFEEC4716474068925852EEDA4B407C9BFEEC47164740B9A5D590B8D74B40EFC517EDF10E4740B9A5D590B8D74B40
52448	Карк-Сирмы	7	66	1454	46.157730000000001	46.180340999999999	55.775413	55.763756000000001	0103000020E610000001000000050000008ECC237F30144740D80FB1C1C2E14B408ECC237F3014474056F2B1BB40E34B406090F4691517474056F2B1BB40E34B406090F46915174740D80FB1C1C2E14B408ECC237F30144740D80FB1C1C2E14B40
16588	Испуханы	7	66	1454	46.214441000000001	46.227808000000003	55.772309999999997	55.766364000000003	0103000020E61000000100000005000000F5F57CCD721B4740776A2E3718E24B40F5F57CCD721B4740D72FD80DDBE24B4033E202D0281D4740D72FD80DDBE24B4033E202D0281D4740776A2E3718E24B40F5F57CCD721B4740776A2E3718E24B40
52457	Ижекей	7	66	1454	46.209750999999997	46.224716999999998	55.721463	55.706710000000001	0103000020E61000000100000005000000D2A6EA1ED91A4740CAE0287975DA4B40D2A6EA1ED91A474014234BE658DC4B4078EDD286C31C474014234BE658DC4B4078EDD286C31C4740CAE0287975DA4B40D2A6EA1ED91A4740CAE0287975DA4B40
58032	Выла	7	66	1454	46.484887000000001	46.505881000000002	55.712249	55.703986999999998	0103000020E61000000100000005000000B6A0F7C6103E474092E7FA3E1CDA4B40B6A0F7C6103E4740EACDA8F92ADB4B407A5567B5C0404740EACDA8F92ADB4B407A5567B5C040474092E7FA3E1CDA4B40B6A0F7C6103E474092E7FA3E1CDA4B40
52488	Вторые Хоршеваши	7	66	1454	46.340716999999998	46.367117999999998	55.745173999999999	55.732782999999998	0103000020E610000001000000050000007A185A9D9C2B47404A0856D5CBDD4B407A185A9D9C2B47402DEA93DC61DF4B40EFE2FDB8FD2E47402DEA93DC61DF4B40EFE2FDB8FD2E47404A0856D5CBDD4B407A185A9D9C2B47404A0856D5CBDD4B40
52487	Верхнее Аккозино	7	66	1454	46.352431000000003	46.375041000000003	55.764403999999999	55.750393000000003	0103000020E610000001000000050000005D8C81751C2D4740DC12B9E00CE04B405D8C81751C2D47403E7782FDD7E14B405FD4EE57013047403E7782FDD7E14B405FD4EE5701304740DC12B9E00CE04B405D8C81751C2D4740DC12B9E00CE04B40
32960	Большие Атмени	7	66	1454	46.167476999999998	46.179558999999998	55.748133000000003	55.740085999999998	0103000020E6100000010000000500000085EAE6E26F1547401D1D5723BBDE4B4085EAE6E26F154740790778D2C2DF4B40EA5910CAFB164740790778D2C2DF4B40EA5910CAFB1647401D1D5723BBDE4B4085EAE6E26F1547401D1D5723BBDE4B40
52424	Березовка	7	66	1454	46.191237000000001	46.208942999999998	55.606786999999997	55.595281999999997	0103000020E6100000010000000500000080643A747A184740E0F2583332CC4B4080643A747A184740A8514832ABCD4B4033DDEBA4BE1A4740A8514832ABCD4B4033DDEBA4BE1A4740E0F2583332CC4B4080643A747A184740E0F2583332CC4B40
20681	Баймашкино	7	66	1454	46.148262000000003	46.181337999999997	55.728681999999999	55.716118000000002	0103000020E61000000100000005000000AA9ECC3FFA124740D9092FC1A9DB4B40AA9ECC3FFA1247408997A77345DD4B40D2C26515361747408997A77345DD4B40D2C2651536174740D9092FC1A9DB4B40AA9ECC3FFA124740D9092FC1A9DB4B40
20811	Атнары	7	66	1454	46.197436000000003	46.225498999999999	55.661256999999999	55.640411	0103000020E61000000100000005000000CB86359545194740D47FD6FCF8D14B40CB8635954519474023A0C211A4D44B40EE23B726DD1C474023A0C211A4D44B40EE23B726DD1C4740D47FD6FCF8D14B40CB86359545194740D47FD6FCF8D14B40
22632	Арайкасы	7	66	1454	46.494742000000002	46.527836000000001	55.714576999999998	55.701830999999999	0103000020E6100000010000000500000094FAB2B4533F4740D4282499D5D94B4094FAB2B4533F4740A5BC564277DB4B4063D34A2190434740A5BC564277DB4B4063D34A2190434740D4282499D5D94B4094FAB2B4533F4740D4282499D5D94B40
52440	Аликово	7	66	1454	46.206615999999997	46.231158000000001	55.751638999999997	55.739767000000001	0103000020E61000000100000005000000486AA164721A47407CD45FAFB0DE4B40486AA164721A4740F6B2EDB435E04B40B91AD995961D4740F6B2EDB435E04B40B91AD995961D47407CD45FAFB0DE4B40486AA164721A47407CD45FAFB0DE4B40
52416	Акчикасы	7	66	1454	46.109769	46.142817999999998	55.729000999999997	55.717968999999997	0103000020E61000000100000005000000AC8E1CE90C0E47405A457F68E6DB4B40AC8E1CE90C0E47402AE09EE74FDD4B40DBA337DC471247402AE09EE74FDD4B40DBA337DC471247405A457F68E6DB4B40AC8E1CE90C0E47405A457F68E6DB4B40
57912	д. Чадукасы	7	66	1590	47.164005000000003	47.182482999999998	55.863869000000001	55.852899999999998	0103000020E61000000100000005000000B4B0A71DFE9447401361C3D32BED4B40B4B0A71DFE9447409D83674293EE4B40B9895A9A5B9747409D83674293EE4B40B9895A9A5B9747401361C3D32BED4B40B4B0A71DFE9447401361C3D32BED4B40
19545	Яншихово-Челлы	7	66	1590	47.277695999999999	47.311706000000001	55.753995000000003	55.736939	0103000020E61000000100000005000000711DE38A8BA34740CF12640454DE4B40711DE38A8BA347407C2C7DE882E04B40C6FB71FBE5A747407C2C7DE882E04B40C6FB71FBE5A74740CF12640454DE4B40711DE38A8BA34740CF12640454DE4B40
19440	Янгасы	7	66	1590	47.167859	47.183121	55.745508999999998	55.736012000000002	0103000020E610000001000000050000006DAB59677C95474056BB26A435DE4B406DAB59677C954740D4EFC2D66CDF4B40FC1A498270974740D4EFC2D66CDF4B40FC1A49827097474056BB26A435DE4B406DAB59677C95474056BB26A435DE4B40
19912	Яманаки	7	66	1590	47.086157	47.120283999999998	55.792740999999999	55.781275999999998	0103000020E6100000010000000500000026A94C31078B474029931ADA00E44B4026A94C31078B474063997E8978E54B40B41D5377658F474063997E8978E54B40B41D5377658F474029931ADA00E44B4026A94C31078B474029931ADA00E44B40
57921	Ямаикасы	7	66	1590	47.016348999999998	47.029150000000001	55.867541000000003	55.863191999999998	0103000020E6100000010000000500000041295AB9178247409C1551137DEE4B4041295AB91782474036785F950BEF4B40D656EC2FBB83474036785F950BEF4B40D656EC2FBB8347409C1551137DEE4B4041295AB9178247409C1551137DEE4B40
20078	Шупоси	7	66	1590	47.084369000000002	47.103216000000003	55.841554000000002	55.833844999999997	0103000020E61000000100000005000000EBE5779ACC8A47407077D66EBBEA4B40EBE5779ACC8A4740B4E89D0AB8EB4B404436902E368D4740B4E89D0AB8EB4B404436902E368D47407077D66EBBEA4B40EBE5779ACC8A47407077D66EBBEA4B40
20404	Шивбоси	7	66	1590	47.256801000000003	47.277740999999999	55.674747000000004	55.665222999999997	0103000020E61000000100000005000000414AECDADEA0474004C6FA0626D54B40414AECDADEA047407D09151C5ED64B4011E15F048DA347407D09151C5ED64B4011E15F048DA3474004C6FA0626D54B40414AECDADEA0474004C6FA0626D54B40
48165	Чиганары	7	66	1590	47.188249999999996	47.200000000000003	55.737841000000003	55.731935999999997	0103000020E610000001000000050000006ABC749318984740ED612F14B0DD4B406ABC749318984740F052EA9271DE4B409A99999999994740F052EA9271DE4B409A99999999994740ED612F14B0DD4B406ABC749318984740ED612F14B0DD4B40
20534	Убеево	7	66	1590	47.137557999999999	47.155327	55.714576999999998	55.705204000000002	0103000020E61000000100000005000000CEA623809B9147401381EA1F44DA4B40CEA623809B914740A5BC564277DB4B40C89750C1E1934740A5BC564277DB4B40C89750C1E19347401381EA1F44DA4B40CEA623809B9147401381EA1F44DA4B40
19594	Санькасы	7	66	1590	47.348635999999999	47.369953000000002	55.757116000000003	55.745620000000002	0103000020E61000000100000005000000A81ABD1AA0AC47402C9FE57970DF4B40A81ABD1AA0AC4740A1A3552DE9E04B404F07B29E5AAF4740A1A3552DE9E04B404F07B29E5AAF47402C9FE57970DF4B40A81ABD1AA0AC47402C9FE57970DF4B40
19853	Пшонги	7	66	1590	47.214517000000001	47.222772999999997	55.811163999999998	55.803621	0103000020E61000000100000005000000D0B7054B759B47407DB08C0DDDE64B40D0B7054B759B4740A5D8D138D4E74B4045B75ED3839C4740A5D8D138D4E74B4045B75ED3839C47407DB08C0DDDE64B40D0B7054B759B47407DB08C0DDDE64B40
19956	Пикшики	7	66	1590	47.027676	47.040927000000003	55.854273999999997	55.850312000000002	0103000020E610000001000000050000002A711DE38A834740BCB20B06D7EC4B402A711DE38A8347405BE9B5D958ED4B40FF428F183D8547405BE9B5D958ED4B40FF428F183D854740BCB20B06D7EC4B402A711DE38A834740BCB20B06D7EC4B40
19381	Крендейкасы	7	66	1590	47.253881	47.264400999999999	55.784298	55.777292000000003	0103000020E61000000100000005000000B309302C7FA04740A2B8E34D7EE34B40B309302C7FA04740BB287AE063E44B40CD0358E4D7A14740BB287AE063E44B40CD0358E4D7A14740A2B8E34D7EE34B40B309302C7FA04740A2B8E34D7EE34B40
19282	Красноармейское	7	66	1590	47.132151	47.184773999999997	55.783686000000003	55.760601000000001	0103000020E610000001000000050000001D91EF52EA9047400727A25F5BE14B401D91EF52EA904740A22AA6D24FE44B405793A7ACA6974740A22AA6D24FE44B405793A7ACA69747400727A25F5BE14B401D91EF52EA9047400727A25F5BE14B40
19736	Кошки	7	66	1590	47.037000999999997	47.058058000000003	55.795741999999997	55.785153999999999	0103000020E61000000100000005000000AB75E272BC8447406B2920ED7FE44B40AB75E272BC844740DD06B5DFDAE54B40B6A2CD716E874740DD06B5DFDAE54B40B6A2CD716E8747406B2920ED7FE44B40AB75E272BC8447406B2920ED7FE44B40
19703	Кожары	7	66	1590	47.010401999999999	47.023122000000001	55.809660999999998	55.801577000000002	0103000020E6100000010000000500000010E84CDA54814740E71C3C139AE64B4010E84CDA548147405FECBDF8A2E74B40B8E864A9F58247405FECBDF8A2E74B40B8E864A9F5824740E71C3C139AE64B4010E84CDA54814740E71C3C139AE64B40
20449	Караево	7	66	1590	47.023113000000002	47.039237999999997	55.757444999999997	55.747591	0103000020E61000000100000005000000658EE55DF582474058E4D70FB1DF4B40658EE55DF582474065C22FF5F3E04B40566133C00585474065C22FF5F3E04B40566133C00585474058E4D70FB1DF4B40658EE55DF582474058E4D70FB1DF4B40
19802	Исаково	7	66	1590	47.155138000000001	47.172969999999999	55.818052999999999	55.808877000000003	0103000020E61000000100000005000000F52EDE8FDB93474049BE124889E74B40F52EDE8FDB93474085B2F0F5B5E84B40359886E12396474085B2F0F5B5E84B40359886E12396474049BE124889E74B40F52EDE8FDB93474049BE124889E74B40
19481	Именево	7	66	1590	47.296883999999999	47.316287000000003	55.794431000000003	55.780774999999998	0103000020E61000000100000005000000535A7F4B00A647406744696FF0E34B40535A7F4B00A64740DCF63DEAAFE54B403293A8177CA84740DCF63DEAAFE54B403293A8177CA847406744696FF0E34B40535A7F4B00A647406744696FF0E34B40
20192	Енешкасы	7	66	1590	47.148105000000001	47.167265999999998	55.888271000000003	55.880707000000001	0103000020E61000000100000005000000E2AFC91AF5924740DC2DC901BBF04B40E2AFC91AF59247401C7E37DDB2F14B40CADDE7F8689547401C7E37DDB2F14B40CADDE7F868954740DC2DC901BBF04B40E2AFC91AF5924740DC2DC901BBF04B40
20542	Досаево	7	66	1590	47.083983000000003	47.107294000000003	55.724671999999998	55.708486000000001	0103000020E61000000100000005000000C23577F4BF8A474041D653ABAFDA4B40C23577F4BF8A4740D829560DC2DC4B404D874ECFBB8D4740D829560DC2DC4B404D874ECFBB8D474041D653ABAFDA4B40C23577F4BF8A474041D653ABAFDA4B40
19643	Большая Шатьма	7	66	1590	47.003745000000002	47.015962000000002	55.826352	55.818629000000001	0103000020E61000000100000005000000034356B77A8047405247C7D5C8E84B40034356B77A804740FA7DFFE6C5E94B4048FDF50A0B824740FA7DFFE6C5E94B4048FDF50A0B8247405247C7D5C8E84B40034356B77A8047405247C7D5C8E84B40
20269	Алманчино	7	66	1590	47.208885000000002	47.227093000000004	55.703747999999997	55.688324000000001	0103000020E61000000100000005000000FFCF61BEBC9A4740A58636001BD84B40FFCF61BEBC9A47400D501A6A14DA4B4045132862119D47400D501A6A14DA4B4045132862119D4740A58636001BD84B40FFCF61BEBC9A4740A58636001BD84B40
20320	Албахтино	7	66	1590	47.254832999999998	47.287945000000001	55.731332999999999	55.721091999999999	0103000020E610000001000000050000008578245E9EA0474020B41EBE4CDC4B408578245E9EA0474027BEDA519CDD4B40FB05BB61DBA4474027BEDA519CDD4B40FB05BB61DBA4474020B41EBE4CDC4B408578245E9EA0474020B41EBE4CDC4B40
18661	Шурут-Нурусово	7	66	215	47.328198999999998	47.358893999999999	55.140343000000001	55.125988999999997	0103000020E610000001000000050000003ACAC16C02AA4740EF53556820904B403ACAC16C02AA47407C9C69C2F6914B40855D143DF0AD47407C9C69C2F6914B40855D143DF0AD4740EF53556820904B403ACAC16C02AA4740EF53556820904B40
18593	Шерауты	7	66	215	47.358580000000003	47.379888000000001	55.136240999999998	55.125458000000002	0103000020E61000000100000005000000F67F0EF3E5AD4740C382FB010F904B40F67F0EF3E5AD4740EAAF575870914B404912842BA0B04740EAAF575870914B404912842BA0B04740C382FB010F904B40F67F0EF3E5AD4740C382FB010F904B40
18485	Чичканы	7	66	215	47.422082000000003	47.450009999999999	55.216909999999999	55.196793	0103000020E610000001000000050000007A1D71C806B64740768A558330994B407A1D71C806B647407216F6B4C39B4B40BD6F7CED99B947407216F6B4C39B4B40BD6F7CED99B94740768A558330994B407A1D71C806B64740768A558330994B40
12948	Урмаево	7	66	215	47.488242999999997	47.518399000000002	55.246918000000001	55.218722999999997	0103000020E610000001000000050000001EC022BF7EBE474006F1811DFF9B4B401EC022BF7EBE474099654F029B9F4B40BAA3FFE55AC2474099654F029B9F4B40BAA3FFE55AC2474006F1811DFF9B4B401EC022BF7EBE474006F1811DFF9B4B40
58039	Тябердино-Эткерово	7	66	215	47.445276	47.461616999999997	55.260376999999998	55.249960999999999	0103000020E61000000100000005000000CBD8D0CDFEB847404223D8B8FE9F4B40CBD8D0CDFEB84740B7D0950854A14B4089230F4416BB4740B7D0950854A14B4089230F4416BB47404223D8B8FE9F4B40CBD8D0CDFEB847404223D8B8FE9F4B40
18966	Тугаево	7	66	215	47.333615999999999	47.360591999999997	55.206817000000001	55.191175999999999	0103000020E610000001000000050000000FB6D8EDB3AA4740DAE3857478984B400FB6D8EDB3AA4740E0A0BDFA789A4B408099EFE027AE4740E0A0BDFA789A4B408099EFE027AE4740DAE3857478984B400FB6D8EDB3AA4740DAE3857478984B40
18373	Токаево	7	66	215	47.439005999999999	47.461967000000001	55.238104999999997	55.223734999999998	0103000020E61000000100000005000000B75F3E5931B847403BFC3559A39C4B40B75F3E5931B84740CD0182397A9E4B40666A12BC21BB4740CD0182397A9E4B40666A12BC21BB47403BFC3559A39C4B40B75F3E5931B847403BFC3559A39C4B40
18794	Татарские Шуруты	7	66	215	47.391179999999999	47.417195	55.133204999999997	55.122971999999997	0103000020E61000000100000005000000B56CAD2F12B247406F29E78BBD8F4B40B56CAD2F12B24740F35487DC0C914B40018750A566B54740F35487DC0C914B40018750A566B547406F29E78BBD8F4B40B56CAD2F12B247406F29E78BBD8F4B40
19125	Сюрбей-Токаево	7	66	215	47.398114999999997	47.417096000000001	55.267004999999997	55.26108	0103000020E610000001000000050000000586AC6EF5B24740E1D1C6116BA14B400586AC6EF5B247402A6F47382DA24B406EA5D76663B547402A6F47382DA24B406EA5D76663B54740E1D1C6116BA14B400586AC6EF5B24740E1D1C6116BA14B40
17368	Степные Шихазаны	7	66	215	47.578586000000001	47.599345999999997	55.169370000000001	55.153858	0103000020E6100000010000000500000034F6251B0FCA47402E1D739EB1934B4034F6251B0FCA4740367689EAAD954B40847EA65EB7CC4740367689EAAD954B40847EA65EB7CC47402E1D739EB1934B4034F6251B0FCA47402E1D739EB1934B40
6205	Старые Мураты	7	66	215	47.439689000000001	47.453487000000003	55.178120999999997	55.167704000000001	0103000020E610000001000000050000009AB4A9BA47B8474046B41D5377954B409AB4A9BA47B847408BDD3EABCC964B40A114ADDC0BBA47408BDD3EABCC964B40A114ADDC0BBA474046B41D5377954B409AB4A9BA47B8474046B41D5377954B40
19018	Старые Высли	7	66	215	47.312334999999997	47.329231999999998	55.230446000000001	55.211969000000003	0103000020E61000000100000005000000B532E197FAA747400762D9CC219B4B40B532E197FAA747403CBF28417F9D4B40F965304624AA47403CBF28417F9D4B40F965304624AA47400762D9CC219B4B40B532E197FAA747400762D9CC219B4B40
11366	Старочелны Сюрбеево	7	66	215	47.554825999999998	47.571139000000002	55.166794000000003	55.158349000000001	0103000020E61000000100000005000000397CD28904C747405A2DB0C744944B40397CD28904C74740A3957B8159954B402E3C2F151BC94740A3957B8159954B402E3C2F151BC947405A2DB0C744944B40397CD28904C747405A2DB0C744944B40
49516	Старая Сундырь	7	66	215	47.639437999999998	47.666451000000002	55.253604000000003	55.235821000000001	0103000020E61000000100000005000000EAE8B81AD9D14740E25AED612F9E4B40EAE8B81AD9D1474041118B1876A04B4079B130444ED5474041118B1876A04B4079B130444ED54740E25AED612F9E4B40EAE8B81AD9D14740E25AED612F9E4B40
17946	Починок-Инели	7	66	215	47.656416	47.693004999999999	55.277256999999999	55.263582999999997	0103000020E610000001000000050000001B49827005D447400A647616BDA14B401B49827005D4474025CB49287DA34B40747B4963B4D8474025CB49287DA34B40747B4963B4D847400A647616BDA14B401B49827005D447400A647616BDA14B40
18082	Починок-Быбыть	7	66	215	47.621454	47.634030000000003	55.226723999999997	55.210382000000003	0103000020E61000000100000005000000F4FBFECD8BCF474063D520CCED9A4B40F4FBFECD8BCF4740F19BC24A059D4B40695721E527D14740F19BC24A059D4B40695721E527D1474063D520CCED9A4B40F4FBFECD8BCF474063D520CCED9A4B40
817	Полевые Яуши	7	66	215	47.480148999999997	47.497396999999999	55.184592000000002	55.171663000000002	0103000020E61000000100000005000000821ABE8575BD474075779D0DF9954B40821ABE8575BD4740378DEDB5A0974B40731074B4AABF4740378DEDB5A0974B40731074B4AABF474075779D0DF9954B40821ABE8575BD474075779D0DF9954B40
18226	Полевой Сундырь	7	66	215	47.659246000000003	47.674922000000002	55.175657999999999	55.170059000000002	0103000020E610000001000000050000006902452C62D44740FBB1497EC4954B406902452C62D44740F0A31AF67B964B40EBAC16D863D64740F0A31AF67B964B40EBAC16D863D64740FBB1497EC4954B406902452C62D44740FBB1497EC4954B40
18174	Полевое Шептахово	7	66	215	47.611348	47.633806	55.198900000000002	55.188499	0103000020E61000000100000005000000CD3CB9A640CE4740132A38BC20984B40CD3CB9A640CE47405396218E75994B401901158E20D147405396218E75994B401901158E20D14740132A38BC20984B40CD3CB9A640CE4740132A38BC20984B40
19175	Подлесные Чурачики	7	66	215	47.375881	47.400064	55.238449000000003	55.228746999999998	0103000020E6100000010000000500000009185DDE1CB047407007EA94479D4B4009185DDE1CB04740C861307F859E4B404A27124C35B34740C861307F859E4B404A27124C35B347407007EA94479D4B4009185DDE1CB047407007EA94479D4B40
18276	Нюргечи	7	66	215	47.691459999999999	47.719693999999997	55.161012999999997	55.147900999999997	0103000020E61000000100000005000000FF3EE3C281D84740D905836BEE924B40FF3EE3C281D847408C9DF0129C944B404F90D8EE1EDC47408C9DF0129C944B404F90D8EE1EDC4740D905836BEE924B40FF3EE3C281D84740D905836BEE924B40
18872	Новые Мураты	7	66	215	47.288763000000003	47.324084999999997	55.196525999999999	55.179456999999999	0103000020E61000000100000005000000BEA59C2FF6A44740E6046D72F8964B40BEA59C2FF6A44740276893C327994B40E40F069E7BA94740276893C327994B40E40F069E7BA94740E6046D72F8964B40BEA59C2FF6A44740E6046D72F8964B40
49169	Новые Высли	7	66	215	47.452247	47.468237000000002	55.159624000000001	55.149568000000002	0103000020E61000000100000005000000685BCD3AE3B947409A43520B25934B40685BCD3AE3B947400FD4298F6E944B407AE3A430EFBB47400FD4298F6E944B407AE3A430EFBB47409A43520B25934B40685BCD3AE3B947409A43520B25934B40
6820	Новочелны-Сюрбеево	7	66	215	47.565471000000002	47.591163000000002	55.157268999999999	55.143794999999997	0103000020E6100000010000000500000010EB8D5A61C84740062AE3DF67924B4010EB8D5A61C847405AD6FD6321944B4079CDAB3AABCB47405AD6FD6321944B4079CDAB3AABCB4740062AE3DF67924B4010EB8D5A61C84740062AE3DF67924B40
17740	Новое Бикмурзино	7	66	215	47.574444999999997	47.585773000000003	55.235734000000001	55.227294000000001	0103000020E61000000100000005000000E42CEC6987C94740DC4944F8179D4B40E42CEC6987C9474013471E882C9E4B409EF0129CFACA474013471E882C9E4B409EF0129CFACA4740DC4944F8179D4B40E42CEC6987C94740DC4944F8179D4B40
17986	Новая Сундырь	7	66	215	47.651564999999998	47.666612000000001	55.298476000000001	55.285896999999999	0103000020E61000000100000005000000EF1B5F7B66D347402383DC4598A44B40EF1B5F7B66D347400952297634A64B40828FC18A53D547400952297634A64B40828FC18A53D547402383DC4598A44B40EF1B5F7B66D347402383DC4598A44B40
18694	Нижние Бюртли Шигали	7	66	215	47.361490000000003	47.388727000000003	55.113081000000001	55.101025	0103000020E6100000010000000500000060EAE74D45AE4740098A1F63EE8C4B4060EAE74D45AE474045662E70798E4B403E096CCEC1B1474045662E70798E4B403E096CCEC1B14740098A1F63EE8C4B4060EAE74D45AE4740098A1F63EE8C4B40
18548	Нижнее Тимерчеево	7	66	215	47.372557999999998	47.401412000000001	55.191032	55.176665999999997	0103000020E610000001000000050000007CEE04FBAFAF47405628D2FD9C964B407CEE04FBAFAF4740A73E90BC73984B40691CEA7761B34740A73E90BC73984B40691CEA7761B347405628D2FD9C964B407CEE04FBAFAF47405628D2FD9C964B40
32522	Малые Кошелеи	7	66	215	47.487704000000001	47.516333000000003	55.271512999999999	55.263069999999999	0103000020E610000001000000050000006F10AD156DBE474084471B47ACA14B406F10AD156DBE47402CB81FF0C0A24B403C6C223317C247402CB81FF0C0A24B403C6C223317C2474084471B47ACA14B406F10AD156DBE474084471B47ACA14B40
49401	Комсомольское	7	66	215	47.515380999999998	47.560692000000003	55.270071999999999	55.253348000000003	0103000020E6100000010000000500000069FD2D01F8C14740E6400FB56DA04B4069FD2D01F8C147405CC823B891A24B407E9065C1C4C747405CC823B891A24B407E9065C1C4C74740E6400FB56DA04B4069FD2D01F8C14740E6400FB56DA04B40
18143	Кайнлык	7	66	215	47.622146000000001	47.632207000000001	55.237679	55.229958000000003	0103000020E610000001000000050000002AABE97AA2CF47400FBA84436F9D4B402AABE97AA2CF474016F9F5436C9E4B40B1A6B228ECD0474016F9F5436C9E4B40B1A6B228ECD047400FBA84436F9D4B402AABE97AA2CF47400FBA84436F9D4B40
18751	Ендоба	7	66	215	47.398411000000003	47.413440000000001	55.118658000000003	55.110197999999997	0103000020E61000000100000005000000EFAEB321FFB24740D40AD3F71A8E4B40EFAEB321FFB2474053B4722F308F4B40DB6D179AEBB4474053B4722F308F4B40DB6D179AEBB44740D40AD3F71A8E4B40EFAEB321FFB24740D40AD3F71A8E4B40
49447	Дубовка	7	66	215	47.527723999999999	47.547882000000001	55.313699999999997	55.307414000000001	0103000020E610000001000000050000003BA8C4758CC34740912A8A5759A74B403BA8C4758CC34740AA60545227A84B40960854FF20C64740AA60545227A84B40960854FF20C64740912A8A5759A74B403BA8C4758CC34740912A8A5759A74B40
17784	Байбахтино	7	66	215	47.535134999999997	47.548008000000003	55.217264999999998	55.209899	0103000020E61000000100000005000000F4F8BD4D7FC44740473B6EF8DD9A4B40F4F8BD4D7FC4474060C8EA56CF9B4B4023F94A2025C6474060C8EA56CF9B4B4023F94A2025C64740473B6EF8DD9A4B40F4F8BD4D7FC44740473B6EF8DD9A4B40
33147	Асаново	7	66	215	47.381028999999998	47.421624000000001	55.322316999999998	55.304180000000002	0103000020E61000000100000005000000EEE9EA8EC5B04740740CC85EEFA64B40EEE9EA8EC5B04740F0F8F6AE41A94B40B79A75C6F7B54740F0F8F6AE41A94B40B79A75C6F7B54740740CC85EEFA64B40EEE9EA8EC5B04740740CC85EEFA64B40
57907	Александровка	7	66	215	47.571705000000001	47.613790999999999	55.272534	55.263931999999997	0103000020E61000000100000005000000D7FA22A12DC94740162F1686C8A14B40D7FA22A12DC947402786E464E2A24B4021CA17B490CE47402786E464E2A24B4021CA17B490CE4740162F1686C8A14B40D7FA22A12DC94740162F1686C8A14B40
57902	с.Карамышево	7	66	1418	48.032890999999999	48.065671000000002	55.889471999999998	55.874338999999999	0103000020E6100000010000000500000097AAB4C535044840054F2157EAEF4B4097AAB4C535044840965AEF37DAF14B40D7A546E867084840965AEF37DAF14B40D7A546E867084840054F2157EAEF4B4097AAB4C535044840054F2157EAEF4B40
52311	Янтиково	7	66	1418	47.897488000000003	47.919280999999998	55.831038999999997	55.813966000000001	0103000020E61000000100000005000000B74604E3E0F247402907B30930E84B40B74604E3E0F24740AB59677C5FEA4B40C66AF3FFAAF54740AB59677C5FEA4B40C66AF3FFAAF547402907B30930E84B40B74604E3E0F247402907B30930E84B40
17290	Янгильдино	7	66	1418	48.174411999999997	48.193896000000002	55.735793999999999	55.715525	0103000020E61000000100000005000000D503E62153164840363CBD5296DB4B40D503E62153164840E84B6F7F2EDE4B40A1698995D1184840E84B6F7F2EDE4B40A1698995D1184840363CBD5296DB4B40D503E62153164840363CBD5296DB4B40
52313	Чешлама	7	66	1418	48.084670000000003	48.107289999999999	55.761927999999997	55.749172000000002	0103000020E61000000100000005000000E6797077D60A48401A8A3BDEE4DF4B40E6797077D60A48400EF450DB86E14B400B98C0ADBB0D48400EF450DB86E14B400B98C0ADBB0D48401A8A3BDEE4DF4B40E6797077D60A48401A8A3BDEE4DF4B40
52351	Уразметьево	7	66	1418	48.167395999999997	48.190266999999999	55.780141999999998	55.762889999999999	0103000020E6100000010000000500000098BD6C3B6D15484004392861A6E14B4098BD6C3B6D154840361E6CB1DBE34B40074147AB5A184840361E6CB1DBE34B40074147AB5A18484004392861A6E14B4098BD6C3B6D15484004392861A6E14B40
16382	Тогонашево	7	66	1418	48.141568999999997	48.161593000000003	55.808633999999998	55.797472999999997	0103000020E610000001000000050000004F90D8EE1E124840B438639813E64B404F90D8EE1E1248408237A45181E74B409B215514AF1448408237A45181E74B409B215514AF144840B438639813E64B404F90D8EE1E124840B438639813E64B40
17122	Старая Тюрлема	7	66	1418	48.197561	48.249339999999997	55.777687	55.758696	0103000020E6100000010000000500000087FBC8AD4919484092CD55F31CE14B4087FBC8AD491948401EC3633F8BE34B40D5CA845FEA1F48401EC3633F8BE34B40D5CA845FEA1F484092CD55F31CE14B4087FBC8AD4919484092CD55F31CE14B40
52344	Солдыбаево	7	66	1418	48.124806999999997	48.151693000000002	55.880080999999997	55.857205	0103000020E61000000100000005000000EBA7FFACF90F4840DD7BB8E4B8ED4B40EBA7FFACF90F48405D6A847EA6F04B401D041DAD6A1348405D6A847EA6F04B401D041DAD6A134840DD7BB8E4B8ED4B40EBA7FFACF90F4840DD7BB8E4B8ED4B40
52360	Семенчино	7	66	1418	48.167772999999997	48.181158000000003	55.723922000000002	55.715133999999999	0103000020E610000001000000050000006E13EE9579154840FB20CB8289DB4B406E13EE95791548406E6DE179A9DC4B4053B4722F301748406E6DE179A9DC4B4053B4722F30174840FB20CB8289DB4B406E13EE9579154840FB20CB8289DB4B40
52346	Пиндиково	7	66	1418	48.148620999999999	48.161341	55.873471000000002	55.863919000000003	0103000020E61000000100000005000000D93F4F03061348404FB2D5E594EE4B40D93F4F03061348409180D1E5CDEF4B40814067D2A61448409180D1E5CDEF4B40814067D2A61448404FB2D5E594EE4B40D93F4F03061348404FB2D5E594EE4B40
52337	Осинкино	7	66	1418	48.093420000000002	48.123334	55.834507000000002	55.824793999999997	0103000020E610000001000000050000006B65C22FF50B4840F0F78BD992E94B406B65C22FF50B48403CA41820D1EA4B40103E9468C90F48403CA41820D1EA4B40103E9468C90F4840F0F78BD992E94B406B65C22FF50B4840F0F78BD992E94B40
52329	Можары	7	66	1418	48.056202999999996	48.084651999999998	55.907158000000003	55.900072000000002	0103000020E61000000100000005000000F277EFA831074840CD052E8F35F34B40F277EFA8310748400327DBC01DF44B403FC571E0D50A48400327DBC01DF44B403FC571E0D50A4840CD052E8F35F34B40F277EFA831074840CD052E8F35F34B40
52336	Малое Бишево	7	66	1418	48.008142999999997	48.021661999999999	55.838996000000002	55.828617000000001	0103000020E610000001000000050000007D586FD40A0148406FF4311F10EA4B407D586FD40A014840C7BC8E3864EB4B4071C806D2C5024840C7BC8E3864EB4B4071C806D2C50248406FF4311F10EA4B407D586FD40A0148406FF4311F10EA4B40
52323	Липово	7	66	1418	48.053534999999997	48.072040000000001	55.805503000000002	55.796323999999998	0103000020E610000001000000050000007E18213CDA0648408C82E0F1EDE54B407E18213CDA0648403AEAE8B81AE74B407E00529B380948403AEAE8B81AE74B407E00529B380948408C82E0F1EDE54B407E18213CDA0648408C82E0F1EDE54B40
52352	Курочкино	7	66	1418	48.360210000000002	48.382821	55.824162000000001	55.811993000000001	0103000020E6100000010000000500000099D87C5C1B2E48405CCAF962EFE74B4099D87C5C1B2E4840904DF2237EE94B406B9C4D4700314840904DF2237EE94B406B9C4D47003148405CCAF962EFE74B4099D87C5C1B2E48405CCAF962EFE74B40
52310	Кудемеры	7	66	1418	47.818823000000002	47.834471000000001	55.843606000000001	55.833840000000002	0103000020E61000000100000005000000371B2B31CFE847405F0CE544BBEA4B40371B2B31CFE84740CD5A0A48FBEB4B40EF3A1BF2CFEA4740CD5A0A48FBEB4B40EF3A1BF2CFEA47405F0CE544BBEA4B40371B2B31CFE847405F0CE544BBEA4B40
15774	Козловка	7	66	1418	48.205305000000003	48.297956999999997	55.853985999999999	55.804197000000002	0103000020E61000000100000005000000475A2A6F471A48404A4563EDEFE64B40475A2A6F471A4840F59ECA694FED4B40A04E797423264840F59ECA694FED4B40A04E7974232648404A4563EDEFE64B40475A2A6F471A48404A4563EDEFE64B40
52327	Картлуево	7	66	1418	48.084940000000003	48.106490000000001	55.877374000000003	55.856048000000001	0103000020E61000000100000005000000A60F5D50DF0A484032E719FB92ED4B40A60F5D50DF0A48402C2E8ECA4DF04B40EFACDD76A10D48402C2E8ECA4DF04B40EFACDD76A10D484032E719FB92ED4B40A60F5D50DF0A484032E719FB92ED4B40
52332	Илебары	7	66	1418	48.033771999999999	48.055779999999999	55.835538	55.825664000000003	0103000020E61000000100000005000000A0C211A45204484006BEA25BAFE94B40A0C211A4520448405A48C0E8F2EA4B40ACE28DCC230748405A48C0E8F2EA4B40ACE28DCC2307484006BEA25BAFE94B40A0C211A45204484006BEA25BAFE94B40
52316	Еметкино	7	66	1418	48.030672000000003	48.054234999999998	55.805371000000001	55.793849000000002	0103000020E610000001000000050000009373620FED0348402D7B12D89CE54B409373620FED034840CB129D6516E74B4037A6272CF1064840CB129D6516E74B4037A6272CF10648402D7B12D89CE54B409373620FED0348402D7B12D89CE54B40
52345	Дятлино	7	66	1418	48.099590999999997	48.123621	55.884984000000003	55.863131000000003	0103000020E61000000100000005000000EBFCDB65BF0C4840F7949C137BEE4B40EBFCDB65BF0C4840DCBDDC2747F14B40A60C1CD0D20F4840DCBDDC2747F14B40A60C1CD0D20F4840F7949C137BEE4B40EBFCDB65BF0C4840F7949C137BEE4B40
52318	Бишево	7	66	1418	48.007271000000003	48.023468000000001	55.784779	55.774765000000002	0103000020E61000000100000005000000C89A9141EE004840F08AE07F2BE34B40C89A9141EE00484036CB65A373E44B405340DAFF0003484036CB65A373E44B405340DAFF00034840F08AE07F2BE34B40C89A9141EE004840F08AE07F2BE34B40
16458	Байгулово	7	66	1418	47.941667000000002	47.982289000000002	55.851480000000002	55.825234000000002	0103000020E61000000100000005000000795C548B88F847400DC68844A1E94B40795C548B88F847405B99F04BFDEC4B403B1C5DA5BBFD47405B99F04BFDEC4B403B1C5DA5BBFD47400DC68844A1E94B40795C548B88F847400DC68844A1E94B40
16273	Аттиково	7	66	1418	48.114745999999997	48.13503	55.781427999999998	55.772629000000002	0103000020E6100000010000000500000064AC36FFAF0E48407978CF81E5E24B4064AC36FFAF0E4840DF162CD505E44B404CFDBCA948114840DF162CD505E44B404CFDBCA9481148407978CF81E5E24B4064AC36FFAF0E48407978CF81E5E24B40
52309	Андреево-Базары	7	66	1418	47.797676000000003	47.823197999999998	55.793647	55.787184000000003	0103000020E61000000100000005000000ED66463F1AE647409DF7FF71C2E44B40ED66463F1AE64740C5C8923996E54B40F910548D5EE94740C5C8923996E54B40F910548D5EE947409DF7FF71C2E44B40ED66463F1AE647409DF7FF71C2E44B40
52359	Альменево	7	66	1418	48.221780000000003	48.232353000000003	55.728372999999998	55.717588999999997	0103000020E6100000010000000500000015747B49631C4840137CD3F4D9DB4B4015747B49631C48400B2593533BDD4B4052103CBEBD1D48400B2593533BDD4B4052103CBEBD1D4840137CD3F4D9DB4B4015747B49631C4840137CD3F4D9DB4B40
14593	Янгличи	7	66	1185	47.283714000000003	47.305463000000003	55.450476000000002	55.427678	0103000020E610000001000000050000006CB587BD50A44740FE9B1727BEB64B406CB587BD50A4474003D19332A9B94B40AC915D6919A7474003D19332A9B94B40AC915D6919A74740FE9B1727BEB64B406CB587BD50A44740FE9B1727BEB64B40
12628	Ямашево	7	66	1185	47.209657	47.238816999999997	55.601939999999999	55.592047000000001	0103000020E610000001000000050000005130630AD69A4740F3583332C8CB4B405130630AD69A4740BE13B35E0CCD4B404A5D328E919E4740BE13B35E0CCD4B404A5D328E919E4740F3583332C8CB4B405130630AD69A4740F3583332C8CB4B40
14030	Яманово	7	66	1185	47.633904999999999	47.655644000000002	55.362608000000002	55.349291000000001	0103000020E61000000100000005000000ACE28DCC23D14740C1E44691B5AC4B40ACE28DCC23D147404DA25EF069AE4B40C9E88024ECD347404DA25EF069AE4B40C9E88024ECD34740C1E44691B5AC4B40ACE28DCC23D14740C1E44691B5AC4B40
13944	Юманзары	7	66	1185	47.571831000000003	47.600091999999997	55.440994000000003	55.425021000000001	0103000020E6100000010000000500000064EB19C231C947407E8E8F1667B64B4064EB19C231C94740BADDCB7D72B84B40AD4B8DD0CFCC4740BADDCB7D72B84B40AD4B8DD0CFCC47407E8E8F1667B64B4064EB19C231C947407E8E8F1667B64B40
12833	Шоркасы	7	66	1185	47.358778000000001	47.375298000000001	55.670203999999998	55.661399000000003	0103000020E610000001000000050000001C430070ECAD4740B64DF1B8A8D44B401C430070ECAD4740FED2A23EC9D54B408A20CEC309B04740FED2A23EC9D54B408A20CEC309B04740B64DF1B8A8D44B401C430070ECAD4740B64DF1B8A8D44B40
12128	Шихазаны	7	66	1185	47.287343999999997	47.40408	55.570945000000002	55.536864000000001	0103000020E61000000100000005000000D5592DB0C7A447402B33A5F5B7C44B40D5592DB0C7A447404968CBB914C94B40DD7BB8E4B8B347404968CBB914C94B40DD7BB8E4B8B347402B33A5F5B7C44B40D5592DB0C7A447402B33A5F5B7C44B40
13029	Шигали	7	66	1185	47.459145999999997	47.478217999999998	55.688628999999999	55.672646	0103000020E610000001000000050000006B0BCF4BC5BA474082E49D4319D64B406B0BCF4BC5BA4740E109BDFE24D84B40E42D573F36BD4740E109BDFE24D84B40E42D573F36BD474082E49D4319D64B406B0BCF4BC5BA474082E49D4319D64B40
12315	Шибылги	7	66	1185	47.429690999999998	47.461410000000001	55.622003999999997	55.609603999999997	0103000020E6100000010000000500000059315C1D00B7474061C1FD8007CE4B4059315C1D00B7474097FDBAD39DCF4B4010069E7B0FBB474097FDBAD39DCF4B4010069E7B0FBB474061C1FD8007CE4B4059315C1D00B7474061C1FD8007CE4B40
13729	Шакулово	7	66	1185	47.602967	47.628892	55.458925000000001	55.444813000000003	0103000020E610000001000000050000009BC8CC052ECD4740F7EAE3A1EFB84B409BC8CC052ECD47408D28ED0DBEBA4B40A75B76887FD047408D28ED0DBEBA4B40A75B76887FD04740F7EAE3A1EFB84B409BC8CC052ECD4740F7EAE3A1EFB84B40
13451	Чиршкасы	7	66	1185	47.460476	47.477274000000001	55.579098000000002	55.569218999999997	0103000020E61000000100000005000000E44BA8E0F0BA474083A10E2BDCC84B40E44BA8E0F0BA4740EA961DE21FCA4B40959D7E5017BD4740EA961DE21FCA4B40959D7E5017BD474083A10E2BDCC84B40E44BA8E0F0BA474083A10E2BDCC84B40
13227	Челкумаги	7	66	1185	47.579358999999997	47.599983999999999	55.626669999999997	55.612848	0103000020E6100000010000000500000056D28A6F28CA4740A2B5A2CD71CE4B4056D28A6F28CA474031B1F9B836D04B40C70F9546CCCC474031B1F9B836D04B40C70F9546CCCC4740A2B5A2CD71CE4B4056D28A6F28CA4740A2B5A2CD71CE4B40
14425	Чагаси	7	66	1185	47.331020000000002	47.366385999999999	55.476230000000001	55.466028999999999	0103000020E61000000100000005000000352905DD5EAA474069FE98D6A6BB4B40352905DD5EAA4740E2AFC91AF5BC4B402BDB87BCE5AE4740E2AFC91AF5BC4B402BDB87BCE5AE474069FE98D6A6BB4B40352905DD5EAA474069FE98D6A6BB4B40
13583	Хучель	7	66	1185	47.591459	47.609820999999997	55.524661000000002	55.51408	0103000020E6100000010000000500000062F6B2EDB4CB47408BC3995FCDC14B4062F6B2EDB4CB47404B3E761728C34B40FEB4519D0ECE47404B3E761728C34B40FEB4519D0ECE47408BC3995FCDC14B4062F6B2EDB4CB47408BC3995FCDC14B40
13429	Ухманы	7	66	1185	47.494387000000003	47.522891000000001	55.579292000000002	55.558641000000001	0103000020E61000000100000005000000A648BE1248BF4740359A5C8C81C74B40A648BE1248BF4740CF6A813D26CA4B40B62FA017EEC24740CF6A813D26CA4B40B62FA017EEC24740359A5C8C81C74B40A648BE1248BF4740359A5C8C81C74B40
11619	Туруново	7	66	1185	47.300072999999998	47.322566000000002	55.529893999999999	55.517505	0103000020E61000000100000005000000D0B4C4CA68A647401C42959A3DC24B40D0B4C4CA68A647405E2C0C91D3C34B409966BAD749A947405E2C0C91D3C34B409966BAD749A947401C42959A3DC24B40D0B4C4CA68A647401C42959A3DC24B40
14001	Тобурданово	7	66	1185	47.567042999999998	47.616898999999997	55.368456000000002	55.352249999999998	0103000020E610000001000000050000007E3672DD94C847400C022B8716AD4B407E3672DD94C84740EB01F39029AF4B40B1F7E28BF6CE4740EB01F39029AF4B40B1F7E28BF6CE47400C022B8716AD4B407E3672DD94C847400C022B8716AD4B40
14357	Сядорга-Сирмы	7	66	1185	47.483302000000002	47.498466000000001	55.434925999999997	55.423789999999997	0103000020E61000000100000005000000B30B06D7DCBD4740982F2FC03EB64B40B30B06D7DCBD47400D17B9A7ABB74B407F15E0BBCDBF47400D17B9A7ABB74B407F15E0BBCDBF4740982F2FC03EB64B40B30B06D7DCBD4740982F2FC03EB64B40
13507	Сугайкасы	7	66	1185	47.482025999999998	47.524112000000002	55.54374	55.524701999999998	0103000020E610000001000000050000002DE92807B3BD4740A912656F29C34B402DE92807B3BD474076C3B64599C54B4078B81D1A16C3474076C3B64599C54B4078B81D1A16C34740A912656F29C34B402DE92807B3BD4740A912656F29C34B40
14083	Старые Шальтямы	7	66	1185	47.478586	47.505383000000002	55.384645999999996	55.372799999999998	0103000020E610000001000000050000006729594E42BD474072F90FE9B7AF4B406729594E42BD4740C34483143CB14B40297AE063B0C04740C34483143CB14B40297AE063B0C0474072F90FE9B7AF4B406729594E42BD474072F90FE9B7AF4B40
13857	Старое-Ахпердино	7	66	1185	47.606434	47.633366000000002	55.478327	55.467331000000001	0103000020E610000001000000050000005B971AA19FCD474018B49080D1BB4B405B971AA19FCD47409BE5B2D139BD4B40FD32182312D147409BE5B2D139BD4B40FD32182312D1474018B49080D1BB4B405B971AA19FCD474018B49080D1BB4B40
14718	Средние Татмыши	7	66	1185	47.21387	47.233713999999999	55.455744000000003	55.441913	0103000020E610000001000000050000003ACC9717609B4740B056ED9A90B84B403ACC9717609B474093ACC3D155BA4B40054F2157EA9D474093ACC3D155BA4B40054F2157EA9D4740B056ED9A90B84B403ACC9717609B4740B056ED9A90B84B40
12165	Сиделево	7	66	1185	47.341377000000001	47.363844	55.575378000000001	55.564954	0103000020E61000000100000005000000A54DD53DB2AB474048DFA46950C84B40A54DD53DB2AB4740406B7EFCA5C94B40446CB07092AE4740406B7EFCA5C94B40446CB07092AE474048DFA46950C84B40A54DD53DB2AB474048DFA46950C84B40
12459	Сеспель	7	66	1185	47.287936000000002	47.307608999999999	55.612126000000004	55.592728999999999	0103000020E61000000100000005000000A8AB3B16DBA4474005323B8BDECB4B40A8AB3B16DBA4474002840F255ACE4B40467A51BB5FA7474002840F255ACE4B40467A51BB5FA7474005323B8BDECB4B40A8AB3B16DBA4474005323B8BDECB4B40
11508	Семеновка	7	66	1185	47.352381999999999	47.362506000000003	55.504986000000002	55.496547	0103000020E610000001000000050000007BD976DA1AAD4740A5F622DA8EBF4B407BD976DA1AAD47400C789961A3C04B40494DBB9866AE47400C789961A3C04B40494DBB9866AE4740A5F622DA8EBF4B407BD976DA1AAD4740A5F622DA8EBF4B40
13310	Передние Яндоуши	7	66	1185	47.610152999999997	47.631264000000002	55.679448000000001	55.666868000000001	0103000020E610000001000000050000003447567E19CE4740DD5F3DEE5BD54B403447567E19CE474093AAED26F8D64B4032923D42CDD0474093AAED26F8D64B4032923D42CDD04740DD5F3DEE5BD54B403447567E19CE4740DD5F3DEE5BD54B40
11825	Оженары	7	66	1185	47.289732999999998	47.313519999999997	55.569921999999998	55.557367999999997	0103000020E6100000010000000500000036C98FF815A5474020EBA9D557C74B4036C98FF815A54740ADA23F34F3C84B402A52616C21A84740ADA23F34F3C84B402A52616C21A8474020EBA9D557C74B4036C98FF815A5474020EBA9D557C74B40
14139	Новые Шальтямы	7	66	1185	47.470708000000002	47.499704999999999	55.36795	55.355018999999999	0103000020E6100000010000000500000098FBE42840BC4740B43A394371AD4B4098FBE42840BC4740174850FC18AF4B40E7525C55F6BF4740174850FC18AF4B40E7525C55F6BF4740B43A394371AD4B4098FBE42840BC4740B43A394371AD4B40
11697	Новые Челкасы	7	66	1185	47.261122	47.279159999999997	55.535947	55.525685000000003	0103000020E61000000100000005000000102219726CA14740B77F65A549C34B40102219726CA14740D5B14AE999C44B40F92CCF83BBA34740D5B14AE999C44B40F92CCF83BBA34740B77F65A549C34B40102219726CA14740B77F65A549C34B40
12411	Новые Пинеры	7	66	1185	47.481712000000002	47.498204999999999	55.619329999999998	55.610529	0103000020E610000001000000050000009E0B23BDA8BD47403A2174D025CE4B409E0B23BDA8BD474041B7973446CF4B4012DA722EC5BF474041B7973446CF4B4012DA722EC5BF47403A2174D025CE4B409E0B23BDA8BD47403A2174D025CE4B40
11533	Новые Мамеи	7	66	1185	47.358947999999998	47.379492999999997	55.530684000000001	55.426170999999997	0103000020E61000000100000005000000787B1002F2AD474076C075C58CB64B40787B1002F2AD474057410C74EDC34B40CC07043A93B0474057410C74EDC34B40CC07043A93B0474076C075C58CB64B40787B1002F2AD474076C075C58CB64B40
14283	Новые Бюрженеры	7	66	1185	47.417212999999997	47.436967000000003	55.377245000000002	55.365571000000003	0103000020E61000000100000005000000A73B4F3C67B54740DAAED007CBAE4B40A73B4F3C67B547402ECA6C9049B04B403337DF88EEB747402ECA6C9049B04B403337DF88EEB74740DAAED007CBAE4B40A73B4F3C67B54740DAAED007CBAE4B40
12038	Новые Ачакасы	7	66	1185	47.196227	47.222161999999997	55.490181999999997	55.473286000000002	0103000020E61000000100000005000000CDCB61F71D994740CCD3B9A294BC4B40CDCB61F71D9947403F8BA548BEBE4B40FC34EECD6F9C47403F8BA548BEBE4B40FC34EECD6F9C4740CCD3B9A294BC4B40CDCB61F71D994740CCD3B9A294BC4B40
14226	Новое Урюмово	7	66	1185	47.396417	47.425908999999997	55.391058000000001	55.378667	0103000020E610000001000000050000000A4AD1CABDB247408789062978B04B400A4AD1CABDB247406A6B44300EB24B403909A52F84B647406A6B44300EB24B403909A52F84B647408789062978B04B400A4AD1CABDB247408789062978B04B40
14657	Новая Яндоба	7	66	1185	47.330651000000003	47.349246000000001	55.415359000000002	55.403511999999999	0103000020E61000000100000005000000E2B19FC552AA474093C5FD47A6B34B40E2B19FC552AA4740B58CD47B2AB54B402121CA17B4AC4740B58CD47B2AB54B402121CA17B4AC474093C5FD47A6B34B40E2B19FC552AA474093C5FD47A6B34B40
13164	Нижние Кибечи	7	66	1185	47.544828000000003	47.563845000000001	55.629201000000002	55.617525000000001	0103000020E61000000100000005000000F9F884ECBCC5474030BB270F0BCF4B40F9F884ECBCC5474025CE8AA889D04B40AE81AD122CC8474025CE8AA889D04B40AE81AD122CC8474030BB270F0BCF4B40F9F884ECBCC5474030BB270F0BCF4B40
11956	Напольные Котяки	7	66	1185	47.248069000000001	47.270176999999997	55.498184000000002	55.485264999999998	0103000020E61000000100000005000000621399B9C09F47405C72DC291DBE4B40621399B9C09F4740FBB1497EC4BF4B40D190F12895A24740FBB1497EC4BF4B40D190F12895A247405C72DC291DBE4B40621399B9C09F47405C72DC291DBE4B40
14510	Мокры	7	66	1185	47.324281999999997	47.343550999999998	55.499203999999999	55.480893000000002	0103000020E610000001000000050000003A57941282A947400BF0DDE68DBD4B403A57941282A947402504ABEAE5BF4B4009C1AA7AF9AB47402504ABEAE5BF4B4009C1AA7AF9AB47400BF0DDE68DBD4B403A57941282A947400BF0DDE68DBD4B40
14155	Маяк	7	66	1185	47.539715999999999	47.556882999999999	55.379429000000002	55.369551000000001	0103000020E610000001000000050000006090F46915C54740209A79724DAF4B406090F46915C54740B613252191B04B40645930F147C74740B613252191B04B40645930F147C74740209A79724DAF4B406090F46915C54740209A79724DAF4B40
13376	Малые Кибечи	7	66	1185	47.618067000000003	47.645950999999997	55.636687000000002	55.612257999999997	0103000020E6100000010000000500000051DEC7D11CCF4740705B5B785ECE4B4051DEC7D11CCF4740E964A9F57ED14B40C4E8B985AED24740E964A9F57ED14B40C4E8B985AED24740705B5B785ECE4B4051DEC7D11CCF4740705B5B785ECE4B40
13649	Малые Бикшихи	7	66	1185	47.488045	47.520277	55.492207000000001	55.468862000000001	0103000020E61000000100000005000000F8FC304278BE4740282B86AB03BC4B40F8FC304278BE47405FEE93A300BF4B4035EECD6F98C247405FEE93A300BF4B4035EECD6F98C24740282B86AB03BC4B40F8FC304278BE4740282B86AB03BC4B40
11740	Малое Тугаево	7	66	1185	47.255004	47.266413	55.545976000000003	55.540948999999998	0103000020E61000000100000005000000B22C98F8A3A04740E6E61BD13DC54B40B22C98F8A3A047405133A48AE2C54B40581D39D219A247405133A48AE2C54B40581D39D219A24740E6E61BD13DC54B40B22C98F8A3A04740E6E61BD13DC54B40
58022	Малды-Питикасы	7	66	1185	47.250664999999998	47.268765999999999	55.637560999999998	55.627687000000002	0103000020E610000001000000050000003CA06CCA15A04740EB8F300C58D04B403CA06CCA15A047403F1A4E999BD14B406C239EEC66A247403F1A4E999BD14B406C239EEC66A24740EB8F300C58D04B403CA06CCA15A04740EB8F300C58D04B40
12376	Малая Андреевка	7	66	1185	47.428702000000001	47.438538999999999	55.638860999999999	55.631498000000001	0103000020E610000001000000050000006ADD06B5DFB64740A5BE2CEDD4D04B406ADD06B5DFB647404DD87E32C6D14B40A182C30B22B847404DD87E32C6D14B40A182C30B22B84740A5BE2CEDD4D04B406ADD06B5DFB64740A5BE2CEDD4D04B40
13015	Кошноруй	7	66	1185	47.411490999999998	47.430875999999998	55.679797999999998	55.671711999999999	0103000020E6100000010000000500000096CCB1BCABB44740562AA8A8FAD54B4096CCB1BCABB447406FF1F09E03D74B40CE50DCF126B747406FF1F09E03D74B40CE50DCF126B74740562AA8A8FAD54B4096CCB1BCABB44740562AA8A8FAD54B40
11460	Кармамеи	7	66	1185	47.364913000000001	47.40549	55.506825999999997	55.435533999999997	0103000020E6100000010000000500000050711C78B5AE4740E525FF93BFB74B4050711C78B5AE47409961A3ACDFC04B40726DA818E7B347409961A3ACDFC04B40726DA818E7B34740E525FF93BFB74B4050711C78B5AE4740E525FF93BFB74B40
13872	Караклы	7	66	1185	47.535063000000001	47.558743	55.440840000000001	55.430788999999997	0103000020E610000001000000050000005B26C3F17CC44740FF3C0D1824B74B405B26C3F17CC447406362F3716DB84B4039EFFFE384C747406362F3716DB84B4039EFFFE384C74740FF3C0D1824B74B405B26C3F17CC44740FF3C0D1824B74B40
12211	Калиновка	7	66	1185	47.368164999999998	47.383705999999997	55.613112000000001	55.607356000000003	0103000020E610000001000000050000001344DD0720AF4740C38366D7BDCD4B401344DD0720AF474080643A747ACE4B40B5A338471DB1474080643A747ACE4B40B5A338471DB14740C38366D7BDCD4B401344DD0720AF4740C38366D7BDCD4B40
11919	Ирдеменево-Кошки	7	66	1185	47.215612999999998	47.232385000000001	55.51932	55.512836	0103000020E61000000100000005000000D5CBEF34999B4740111B2C9CA4C14B40D5CBEF34999B47405114E81379C24B405D8AABCABE9D47405114E81379C24B405D8AABCABE9D4740111B2C9CA4C14B40D5CBEF34999B4740111B2C9CA4C14B40
12715	Имелево	7	66	1185	47.227794000000003	47.243982000000003	55.589030000000001	55.580055000000002	0103000020E61000000100000005000000CE1C925A289D4740CE70033E3FCA4B40CE1C925A289D4740732EC55565CB4B4006685BCD3A9F4740732EC55565CB4B4006685BCD3A9F4740CE70033E3FCA4B40CE1C925A289D4740CE70033E3FCA4B40
13705	Зеленый	7	66	1185	47.531443000000003	47.539231000000001	55.483938999999999	55.479030999999999	0103000020E610000001000000050000001558005306C44740956247E350BD4B401558005306C44740252191B6F1BD4B40A4FE7A8505C54740252191B6F1BD4B40A4FE7A8505C54740956247E350BD4B401558005306C44740956247E350BD4B40
13298	Задние Яндоуши	7	66	1185	47.552202999999999	47.579521	55.685395999999997	55.674621000000002	0103000020E6100000010000000500000065E08096AEC64740F0181EFB59D64B4065E08096AEC6474094675E0EBBD74B40302C7FBE2DCA474094675E0EBBD74B40302C7FBE2DCA4740F0181EFB59D64B4065E08096AEC64740F0181EFB59D64B40
12079	Елмачи	7	66	1185	47.191375999999998	47.218567999999998	55.463231999999998	55.449964999999999	0103000020E61000000100000005000000A19E3E027F9847401DACFF7398B94B40A19E3E027F984740F73AA92F4BBB4B40DFF94509FA9B4740F73AA92F4BBB4B40DFF94509FA9B47401DACFF7398B94B40A19E3E027F9847401DACFF7398B94B40
13088	Дальние Сормы	7	66	1185	47.422324000000003	47.443282000000004	55.661485999999996	55.652155999999998	0103000020E6100000010000000500000070287CB60EB64740F1F109D979D34B4070287CB60EB647408461C092ABD44B40E773EE76BDB847408461C092ABD44B40E773EE76BDB84740F1F109D979D34B4070287CB60EB64740F1F109D979D34B40
14311	Вутабоси	7	66	1185	47.426780000000001	47.454402999999999	55.440283999999998	55.420817	0103000020E610000001000000050000001F4B1FBAA0B64740E84CDA54DDB54B401F4B1FBAA0B64740DD79E2395BB84B40261AA4E029BA4740DD79E2395BB84B40261AA4E029BA4740E84CDA54DDB54B401F4B1FBAA0B64740E84CDA54DDB54B40
12664	Вурман-Янишево	7	66	1185	47.206288999999998	47.231648	55.628698	55.614327000000003	0103000020E6100000010000000500000024438EAD679A474060066344A2CE4B4024438EAD679A4740C287122D79D04B40871744A4A69D4740C287122D79D04B40871744A4A69D474060066344A2CE4B4024438EAD679A474060066344A2CE4B40
11802	Вторые Хормалы	7	66	1185	47.222512000000002	47.240459999999999	55.552917999999998	55.540698999999996	0103000020E61000000100000005000000D97BF1457B9C47406DFDF49F35C54B40D97BF1457B9C474053AF5B04C6C64B4082FFAD64C79E474053AF5B04C6C64B4082FFAD64C79E47406DFDF49F35C54B40D97BF1457B9C47406DFDF49F35C54B40
14560	Верхняя Яндоба	7	66	1185	47.285806999999998	47.305723	55.484423	55.466636999999999	0103000020E61000000100000005000000E3FBE25295A44740410DDFC2BABB4B40E3FBE25295A447401137A79201BE4B40485167EE21A747401137A79201BE4B40485167EE21A74740410DDFC2BABB4B40E3FBE25295A44740410DDFC2BABB4B40
13233	Верхнее Девлизерово	7	66	1185	47.527040999999997	47.546993000000001	55.604066000000003	55.592931999999998	0103000020E610000001000000050000005853591476C347403D601E32E5CB4B405853591476C347401250E10852CD4B400A12DBDD03C647401250E10852CD4B400A12DBDD03C647403D601E32E5CB4B405853591476C347403D601E32E5CB4B40
12766	Братьякасы	7	66	1185	47.195832000000003	47.209153999999998	55.628290999999997	55.617880999999997	0103000020E6100000010000000500000051C1E10511994740EEE87FB916CF4B4051C1E1051199474081AFE8D66BD04B40EEE9EA8EC59A474081AFE8D66BD04B40EEE9EA8EC59A4740EEE87FB916CF4B4051C1E10511994740EEE87FB916CF4B40
32994	Большие Бикшихи	7	66	1185	47.444046	47.467779	55.539043999999997	55.525399999999998	0103000020E61000000100000005000000B6F5D37FD6B84740C1A8A44E40C34B40B6F5D37FD6B84740718DCF64FFC44B40B760A92EE0BB4740718DCF64FFC44B40B760A92EE0BB4740C1A8A44E40C34B40B6F5D37FD6B84740C1A8A44E40C34B40
12898	Ближние Сормы	7	66	1185	47.369027000000003	47.395052	55.645074999999999	55.629994000000003	0103000020E61000000100000005000000A62BD8463CAF47408F56B5A4A3D04B40A62BD8463CAF4740CD3B4ED191D24B40151C5E1091B24740CD3B4ED191D24B40151C5E1091B247408F56B5A4A3D04B40A62BD8463CAF47408F56B5A4A3D04B40
11594	Байгильдино	7	66	1185	47.336454000000003	47.354869999999998	55.534418000000002	55.527411999999998	0103000020E61000000100000005000000E04DB7EC10AB47404CC2853C82C34B40E04DB7EC10AB474066321CCF67C44B406F2A52616CAD474066321CCF67C44B406F2A52616CAD47404CC2853C82C34B40E04DB7EC10AB47404CC2853C82C34B40
11876	Ачакасы	7	66	1185	47.153098999999997	47.179312000000003	55.503951000000001	55.490799000000003	0103000020E6100000010000000500000070067FBF989347406BF46A80D2BE4B4070067FBF98934740ACE4637781C04B40E3E313B2F3964740ACE4637781C04B40E3E313B2F39647406BF46A80D2BE4B4070067FBF989347406BF46A80D2BE4B40
12514	Атыково	7	66	1185	47.276401999999997	47.295409999999997	55.637605999999998	55.623238999999998	0103000020E610000001000000050000004546072461A34740BE4BA94BC6CF4B404546072461A34740DFDDCA129DD14B40A774B0FECFA54740DFDDCA129DD14B40A774B0FECFA54740BE4BA94BC6CF4B404546072461A34740BE4BA94BC6CF4B40
12287	Атнашево	7	66	1185	47.428773999999997	47.468398999999998	55.588771000000001	55.577103000000001	0103000020E6100000010000000500000003B00111E2B6474035B6D782DEC94B4003B00111E2B64740A7EA1ED95CCB4B40533D997FF4BB4740A7EA1ED95CCB4B40533D997FF4BB474035B6D782DEC94B4003B00111E2B6474035B6D782DEC94B40
11294	Асхва	7	66	1185	47.423465	47.447217000000002	55.530949	55.514605000000003	0103000020E610000001000000050000001500E31934B64740D6AD9E93DEC14B401500E31934B64740056C0723F6C34B408D9B1A683EB94740056C0723F6C34B408D9B1A683EB94740D6AD9E93DEC14B401500E31934B64740D6AD9E93DEC14B40
13788	Аниш-Ахпердино	7	66	1185	47.641199	47.672460000000001	55.462961999999997	55.444628999999999	0103000020E610000001000000050000002C9D0FCF12D2474035ED629AE9B84B402C9D0FCF12D2474037A5BC5642BB4B4020EF552B13D6474037A5BC5642BB4B4020EF552B13D6474035ED629AE9B84B402C9D0FCF12D2474035ED629AE9B84B40
12549	Анаткасы	7	66	1185	47.262881999999998	47.280318999999999	55.611902000000001	55.601137000000001	0103000020E61000000100000005000000815A0C1EA6A1474031B5A50EF2CC4B40815A0C1EA6A14740B22D03CE52CE4B4045B9347EE1A34740B22D03CE52CE4B4045B9347EE1A3474031B5A50EF2CC4B40815A0C1EA6A1474031B5A50EF2CC4B40
13593	Алешево	7	66	1185	47.571587999999998	47.576645999999997	55.543357999999998	55.539951000000002	0103000020E610000001000000050000009D64ABCB29C94740A438471D1DC54B409D64ABCB29C947408E0244C18CC54B4042AF3F89CFC947408E0244C18CC54B4042AF3F89CFC94740A438471D1DC54B409D64ABCB29C94740A438471D1DC54B40
12884	Алаксары	7	66	1185	47.353316	47.370787999999997	55.688339999999997	55.678631000000003	0103000020E61000000100000005000000A7936C7539AD4740A1866F61DDD64B40A7936C7539AD4740AA436E861BD84B40E7DF2EFB75AF4740AA436E861BD84B40E7DF2EFB75AF4740A1866F61DDD64B40A7936C7539AD4740A1866F61DDD64B40
61570	Ширтаны	7	66	1106	47.046343	47.067059	55.286476	55.269948999999997	0103000020E6100000010000000500000003B34291EE854740404B57B08DA24B4003B34291EE854740618BDD3EABA44B4084F3A96395884740618BDD3EABA44B4084F3A96395884740404B57B08DA24B4003B34291EE854740404B57B08DA24B40
58049	Хормалы	7	66	1106	47.242356000000001	47.274974	55.305123000000002	55.285507000000003	0103000020E61000000100000005000000A4FE7A85059F4740B9E34D7E8BA44B40A4FE7A85059F4740F3203D450EA74B400AA0185932A34740F3203D450EA74B400AA0185932A34740B9E34D7E8BA44B40A4FE7A85059F4740B9E34D7E8BA44B40
61569	Малые Кармалы	7	66	1106	46.703600000000002	47.404394000000003	55.430998000000002	55.083091000000003	0103000020E6100000010000000500000099BB96900F5A4740C5CBD3B9A28A4B4099BB96900F5A47401A5245F12AB74B406D59BE2EC3B347401A5245F12AB74B406D59BE2EC3B34740C5CBD3B9A28A4B4099BB96900F5A4740C5CBD3B9A28A4B40
61590	Малые Кармалы	7	66	1106	46.703600000000002	47.404394000000003	55.430998000000002	55.083091000000003	0103000020E6100000010000000500000099BB96900F5A4740C5CBD3B9A28A4B4099BB96900F5A47401A5245F12AB74B406D59BE2EC3B347401A5245F12AB74B406D59BE2EC3B34740C5CBD3B9A28A4B4099BB96900F5A4740C5CBD3B9A28A4B40
32799	Ибреси	7	66	1106	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
58051	Бугуян	7	66	1106	46.788662000000002	46.80847	55.330675999999997	55.314787000000003	0103000020E610000001000000050000008ACC5CE0F26447405D1ABFF04AA84B408ACC5CE0F26447403AC9569753AA4B4008E6E8F17B6747403AC9569753AA4B4008E6E8F17B6747405D1ABFF04AA84B408ACC5CE0F26447405D1ABFF04AA84B40
32854	Большие Абакасы	7	66	1106	47.016483000000001	47.046073999999997	55.394846999999999	55.371991000000001	0103000020E6100000010000000500000051F86C1D1C82474003B4AD669DAF4B4051F86C1D1C8247403CF6B3588AB24B401399B9C0E58547403CF6B3588AB24B401399B9C0E585474003B4AD669DAF4B4051F86C1D1C82474003B4AD669DAF4B40
58101	Андреевка	7	66	1106	47.115198999999997	47.145463999999997	55.322927	55.314546	0103000020E6100000010000000500000015C440D7BE8E4740378B170B43A84B4015C440D7BE8E474069FF03AC55A94B40675F79909E92474069FF03AC55A94B40675F79909E924740378B170B43A84B4015C440D7BE8E4740378B170B43A84B40
58023	Айбечи	7	66	1106	47.332501999999998	47.360332	55.351430999999998	55.331290000000003	0103000020E6100000010000000500000063EDEF6C8FAA4740F5BEF1B567AA4B4063EDEF6C8FAA474079E6E5B0FBAC4B40E4D9E55B1FAE474079E6E5B0FBAC4B40E4D9E55B1FAE4740F5BEF1B567AA4B4063EDEF6C8FAA4740F5BEF1B567AA4B40
9189	Янишево	7	66	902	47.171900999999998	47.193479000000004	55.638855999999997	55.627529000000003	0103000020E6100000010000000500000029931ADA009647405325CADE52D04B4029931ADA009647403B6D8D08C6D14B403DBB7CEBC39847403B6D8D08C6D14B403DBB7CEBC39847405325CADE52D04B4029931ADA009647405325CADE52D04B40
32768	Янгорчино	7	66	902	47.096308000000001	47.130830000000003	55.544559999999997	55.533776000000003	0103000020E61000000100000005000000ED2B0FD2538C4740E2B19FC552C44B40ED2B0FD2538C4740D95A5F24B4C54B40F8AA9509BF904740D95A5F24B4C54B40F8AA9509BF904740E2B19FC552C44B40ED2B0FD2538C4740E2B19FC552C44B40
52070	Ямбахтино	7	66	902	46.788338000000003	46.808028999999998	55.625211	55.608694	0103000020E61000000100000005000000D7187442E8644740BEA25BAFE9CD4B40D7187442E8644740BB0CFFE906D04B401B9C887E6D674740BB0CFFE906D04B401B9C887E6D674740BEA25BAFE9CD4B40D7187442E8644740BEA25BAFE9CD4B40
51990	Эпшики	7	66	902	46.738050999999999	46.757122000000003	55.648311	55.636285000000001	0103000020E61000000100000005000000DAE38574785E4740BAF770C971D14B40DAE38574785E47408B51D7DAFBD24B40838AAA5FE96047408B51D7DAFBD24B40838AAA5FE9604740BAF770C971D14B40DAE38574785E4740BAF770C971D14B40
52102	Шинеры	7	66	902	46.734456999999999	46.760491000000002	55.582039000000002	55.567652000000002	0103000020E61000000100000005000000BDA8DDAF025E474027C11BD2A8C84B40BDA8DDAF025E47408FFF024180CA4B4080F3E2C4576147408FFF024180CA4B4080F3E2C45761474027C11BD2A8C84B40BDA8DDAF025E474027C11BD2A8C84B40
58020	Чиршкас-Мураты	7	66	902	47.022250999999997	47.038780000000003	55.586475999999998	55.57949	0103000020E61000000100000005000000D2A6EA1ED9824740F52D73BA2CCA4B40D2A6EA1ED9824740C7F143A511CB4B4094DE37BEF6844740C7F143A511CB4B4094DE37BEF6844740F52D73BA2CCA4B40D2A6EA1ED9824740F52D73BA2CCA4B40
57920	Чириш-Шинеры	7	66	902	46.765880000000003	46.790880999999999	55.583668000000003	55.568145000000001	0103000020E610000001000000050000008B54185B086247406631B1F9B8C84B408B54185B0862474062DC0DA2B5CA4B408E03AF963B65474062DC0DA2B5CA4B408E03AF963B6547406631B1F9B8C84B408B54185B086247406631B1F9B8C84B40
8127	Чаркли	7	66	902	46.817677000000003	46.839739999999999	55.483443999999999	55.468871999999998	0103000020E6100000010000000500000080D8D2A3A96847404B0169FF03BC4B4080D8D2A3A968474045B9347EE1BD4B404F92AE997C6B474045B9347EE1BD4B404F92AE997C6B47404B0169FF03BC4B4080D8D2A3A96847404B0169FF03BC4B40
57924	Хорнзор	7	66	902	47.077883	47.095894999999999	55.548603999999997	55.537989000000003	0103000020E610000001000000050000000AF5F411F8894740CB4DD4D2DCC44B400AF5F411F8894740363AE7A738C64B40CA6C9049468C4740363AE7A738C64B40CA6C9049468C4740CB4DD4D2DCC44B400AF5F411F8894740CB4DD4D2DCC44B40
52062	Хора-Сирма	7	66	902	47.045796000000003	47.067202000000002	55.418109000000001	55.407131	0103000020E61000000100000005000000D124B1A4DC85474009185DDE1CB44B40D124B1A4DC854740E694809884B54B40E71C3C139A884740E694809884B54B40E71C3C139A88474009185DDE1CB44B40D124B1A4DC85474009185DDE1CB44B40
52100	Хирпоси	7	66	902	47.116833999999997	47.150664999999996	55.520054000000002	55.508524000000001	0103000020E61000000100000005000000CA87A06AF48E4740959D7E5017C14B40CA87A06AF48E4740B613252191C24B406FD39FFD48934740B613252191C24B406FD39FFD48934740959D7E5017C14B40CA87A06AF48E4740959D7E5017C14B40
58037	Тузи-Сярмус	7	66	902	47.125340999999999	47.147880000000001	55.585199000000003	55.574263000000002	0103000020E6100000010000000500000089EC832C0B904740C426327381C94B4089EC832C0B904740725303CDE7CA4B40C2DD59BBED924740725303CDE7CA4B40C2DD59BBED924740C426327381C94B4089EC832C0B904740C426327381C94B40
52088	Троицкое	7	66	902	47.160438999999997	47.172772000000002	55.566608000000002	55.557988999999999	0103000020E610000001000000050000006000E143899447408D43FD2E6CC74B406000E1438994474074D3669C86C84B400FD594641D96474074D3669C86C84B400FD594641D9647408D43FD2E6CC74B406000E143899447408D43FD2E6CC74B40
52089	Сявалкасы	7	66	902	46.999226999999998	47.011614999999999	55.631635000000003	55.619436999999998	0103000020E61000000100000005000000DD239BABE67F474057772CB649CF4B40DD239BABE67F474026016A6AD9D04B404F92AE997C81474026016A6AD9D04B404F92AE997C81474057772CB649CF4B40DD239BABE67F474057772CB649CF4B40
52082	Сявалкас-Хирпоси	7	66	902	47.085923000000001	47.105865999999999	55.470362000000002	55.466346000000001	0103000020E61000000100000005000000B37C5D86FF8A47406A4FC939B1BB4B40B37C5D86FF8A4740FDA36FD234BC4B4011E15F048D8D4740FDA36FD234BC4B4011E15F048D8D47406A4FC939B1BB4B40B37C5D86FF8A47406A4FC939B1BB4B40
52090	Сугут-Торбиково	7	66	902	46.995615999999998	47.009287999999998	55.664700000000003	55.649931000000002	0103000020E61000000100000005000000EAAF5758707F47400BD462F030D34B40EAAF5758707F47405BD3BCE314D54B40641F6459308147405BD3BCE314D54B40641F6459308147400BD462F030D34B40EAAF5758707F47400BD462F030D34B40
52007	Старые Яхакасы	7	66	902	46.952531999999998	46.969923999999999	55.527219000000002	55.509619999999998	0103000020E610000001000000050000005D328E91EC7947409AB1683A3BC14B405D328E91EC794740386A85E97BC34B4081CD3978267C4740386A85E97BC34B4081CD3978267C47409AB1683A3BC14B405D328E91EC7947409AB1683A3BC14B40
52034	Синьял-Яуши	7	66	902	47.047995999999998	47.065109	55.677467999999998	55.662019000000001	0103000020E610000001000000050000005E2BA1BB24864740522AE109BDD44B405E2BA1BB24864740130B7C45B7D64B406FD6E07D55884740130B7C45B7D64B406FD6E07D55884740522AE109BDD44B405E2BA1BB24864740522AE109BDD44B40
52050	Сендимиркино	7	66	902	46.879257000000003	46.907949000000002	55.543413999999999	55.525236999999997	0103000020E61000000100000005000000B9E34D7E8B70474017D34CF73AC34B40B9E34D7E8B704740221807978EC54B40CCB73EAC37744740221807978EC54B40CCB73EAC3774474017D34CF73AC34B40B9E34D7E8B70474017D34CF73AC34B40
52101	Рунги	7	66	902	47.134217	47.156953000000001	55.492747000000001	55.480148	0103000020E610000001000000050000009BC8CC052E914740B29E5A7D75BD4B409BC8CC052E914740DF196D5512BF4B402A01310917944740DF196D5512BF4B402A01310917944740B29E5A7D75BD4B409BC8CC052E914740B29E5A7D75BD4B40
52075	Ослаба	7	66	902	46.867730999999999	46.881681999999998	55.658759000000003	55.645811999999999	0103000020E61000000100000005000000D95C35CF116F4740A3AEB5F7A9D24B40D95C35CF116F47400C79043752D44B4066BCADF4DA7047400C79043752D44B4066BCADF4DA704740A3AEB5F7A9D24B40D95C35CF116F4740A3AEB5F7A9D24B40
33103	Орауши	7	66	902	47.063411000000002	47.092571	55.509211999999998	55.493246999999997	0103000020E61000000100000005000000749A05DA1D884740D0ECBAB722BF4B40749A05DA1D884740895DDBDB2DC14B406DC7D45DD98B4740895DDBDB2DC14B406DC7D45DD98B4740D0ECBAB722BF4B40749A05DA1D884740D0ECBAB722BF4B40
52033	Ойкас-Яуши	7	66	902	47.071362000000001	47.087513000000001	55.658312000000002	55.646822999999998	0103000020E61000000100000005000000AD16D863228947407AA69718CBD24B40AD16D863228947403D484F9143D44B40C87C40A0338B47403D484F9143D44B40C87C40A0338B47407AA69718CBD24B40AD16D863228947407AA69718CBD24B40
33119	Новые Яхакасы	7	66	902	46.974218	46.995148	55.521593000000003	55.506678000000001	0103000020E610000001000000050000005796E82CB37C474025CD1FD3DAC04B405796E82CB37C47404969368FC3C24B4004577902617F47404969368FC3C24B4004577902617F474025CD1FD3DAC04B405796E82CB37C474025CD1FD3DAC04B40
52109	Напольное Тугаево	7	66	902	47.162514000000002	47.176437999999997	55.545777999999999	55.538961999999998	0103000020E6100000010000000500000032923D42CD944740B4E4F1B4FCC44B4032923D42CD9447402A70B20DDCC54B40C5E23785959647402A70B20DDCC54B40C5E2378595964740B4E4F1B4FCC44B4032923D42CD944740B4E4F1B4FCC44B40
52080	Мамалаево	7	66	902	47.036802999999999	47.057913999999997	55.457239999999999	55.444476000000002	0103000020E6100000010000000500000085B2F0F5B5844740AFEDED96E4B84B4085B2F0F5B584474026361FD786BA4B4082FDD7B96987474026361FD786BA4B4082FDD7B969874740AFEDED96E4B84B4085B2F0F5B5844740AFEDED96E4B84B40
52083	Малые Яуши	7	66	902	47.088994999999997	47.110222999999998	55.610442999999997	55.594977	0103000020E61000000100000005000000F6402B30648B4740A46FD23428CC4B40F6402B30648B47403B8908FF22CE4B402D228AC91B8E47403B8908FF22CE4B402D228AC91B8E4740A46FD23428CC4B40F6402B30648B4740A46FD23428CC4B40
51986	Малдыкасы	7	66	902	46.781826000000002	46.807949000000001	55.646025000000002	55.631148000000003	0103000020E61000000100000005000000CD94D6DF12644740C9772975C9D04B40CD94D6DF12644740FFB27BF2B0D24B40FFEA71DF6A674740FFB27BF2B0D24B40FFEA71DF6A674740C9772975C9D04B40CD94D6DF12644740C9772975C9D04B40
32574	Кюстюмеры	7	66	902	46.976849999999999	47.001094999999999	55.438231000000002	55.418246000000003	0103000020E610000001000000050000007E8CB96B097D474067D7BD1589B54B407E8CB96B097D4740F48B12F417B84B40359886E123804740F48B12F417B84B40359886E12380474067D7BD1589B54B407E8CB96B097D474067D7BD1589B54B40
52085	Кюмель-Ямаши	7	66	902	47.054122999999997	47.088636000000001	55.577815999999999	55.567036000000002	0103000020E610000001000000050000000F7BA180ED864740CCD3B9A294C84B400F7BA180ED864740828DEBDFF5C94B40C79FA86C588B4740828DEBDFF5C94B40C79FA86C588B4740CCD3B9A294C84B400F7BA180ED864740CCD3B9A294C84B40
52069	Кюльхири	7	66	902	46.865701000000001	46.894554999999997	55.589965999999997	55.574354999999997	0103000020E61000000100000005000000A88E554ACF6E4740A4A5F27684C94B40A88E554ACF6E47403FE0810184CB4B4094BC3AC7807247403FE0810184CB4B4094BC3AC780724740A4A5F27684C94B40A88E554ACF6E4740A4A5F27684C94B40
52078	Кольцовка	7	66	902	47.085051999999997	47.113563999999997	55.432943999999999	55.419519000000001	0103000020E61000000100000005000000CD3AE3FBE28A47407B8670CCB2B54B40CD3AE3FBE28A4740ED7F80B56AB74B406000E143898E4740ED7F80B56AB74B406000E143898E47407B8670CCB2B54B40CD3AE3FBE28A47407B8670CCB2B54B40
52094	Кожар-Яндоба	7	66	902	47.018360999999999	47.037467999999997	55.698872999999999	55.688308999999997	0103000020E61000000100000005000000CC423BA7598247406F4562821AD84B40CC423BA7598247405987A3AB74D94B40C1525DC0CB8447405987A3AB74D94B40C1525DC0CB8447406F4562821AD84B40CC423BA7598247406F4562821AD84B40
52041	Киберли	7	66	902	46.748282000000003	46.757472	55.510368999999997	55.504261999999997	0103000020E61000000100000005000000BE175FB4C75F4740CA4E3FA88BC04B40BE175FB4C75F474034F279C553C14B405FD1ADD7F460474034F279C553C14B405FD1ADD7F4604740CA4E3FA88BC04B40BE175FB4C75F4740CA4E3FA88BC04B40
8614	Калинино	7	66	902	46.836191999999997	46.866815000000003	55.622033999999999	55.595384000000003	0103000020E61000000100000005000000A296E656086B4740E547FC8A35CC4B40A296E656086B4740028063CF9ECF4B4054573ECBF36E4740028063CF9ECF4B4054573ECBF36E4740E547FC8A35CC4B40A296E656086B4740E547FC8A35CC4B40
8457	Ершипоси	7	66	902	46.988303000000002	47.017687000000002	55.412568999999998	55.398328999999997	0103000020E61000000100000005000000F4C473B6807E47403106D671FCB24B40F4C473B6807E4740F52B9D0FCFB44B403D484F9143824740F52B9D0FCFB44B403D484F91438247403106D671FCB24B40F4C473B6807E47403106D671FCB24B40
32697	Ермошкино	7	66	902	46.914155999999998	46.926561999999997	55.667786999999997	55.658459000000001	0103000020E6100000010000000500000099B8551003754740E1606F6248D44B4099B8551003754740D3D85E0B7AD54B40B1DB679599764740D3D85E0B7AD54B40B1DB679599764740E1606F6248D44B4099B8551003754740E1606F6248D44B40
7034	Вурнары	7	66	902	46.925538000000003	47.006512000000001	55.504781999999999	55.467993999999997	0103000020E61000000100000005000000469A780778764740B35C363AE7BB4B40469A78077876474003CE52B29CC04B400A849D62D580474003CE52B29CC04B400A849D62D5804740B35C363AE7BB4B40469A780778764740B35C363AE7BB4B40
52047	Вурманкасы	7	66	902	46.831493000000002	46.862637999999997	55.558585000000001	55.536175999999998	0103000020E610000001000000050000002DEDD45C6E6A47403673486AA1C44B402DEDD45C6E6A4740A18499B67FC74B40B72407EC6A6E4740A18499B67FC74B40B72407EC6A6E47403673486AA1C44B402DEDD45C6E6A47403673486AA1C44B40
58008	Вурман-Кибеки	7	66	902	47.152569	47.168416000000001	55.632510000000003	55.619034999999997	0103000020E6100000010000000500000014B1886187934740280AF4893CCF4B4014B18861879347404D327216F6D04B40C30FCEA78E9547404D327216F6D04B40C30FCEA78E954740280AF4893CCF4B4014B1886187934740280AF4893CCF4B40
57926	Волонтер	7	66	902	46.779139999999998	46.794015999999999	55.490009000000001	55.481560999999999	0103000020E61000000100000005000000B28009DCBA634740B80375CAA3BD4B40B28009DCBA63474072DF6A9DB8BE4B401840F850A265474072DF6A9DB8BE4B401840F850A2654740B80375CAA3BD4B40B28009DCBA634740B80375CAA3BD4B40
8234	Буртасы	7	66	902	46.841419999999999	46.877146000000003	55.508803999999998	55.483383000000003	0103000020E61000000100000005000000A4198BA6B36B4740A038807EDFBD4B40A4198BA6B36B474078094E7D20C14B409BE8F3514670474078094E7D20C14B409BE8F35146704740A038807EDFBD4B40A4198BA6B36B4740A038807EDFBD4B40
52028	Большие Яуши	7	66	902	47.050179	47.077255000000001	55.646213000000003	55.629719000000001	0103000020E6100000010000000500000016F9F5436C864740BD55D7A19AD04B4016F9F5436C86474002A08A1BB7D24B40EB39E97DE389474002A08A1BB7D24B40EB39E97DE3894740BD55D7A19AD04B4016F9F5436C864740BD55D7A19AD04B40
58029	Большие Хирлепы	7	66	902	46.81147	46.827640000000002	55.655706000000002	55.648499000000001	0103000020E61000000100000005000000B2D7BB3FDE6747408E3EE60302D34B40B2D7BB3FDE6747403FE5982CEED34B40446E861BF06947403FE5982CEED34B40446E861BF06947408E3EE60302D34B40B2D7BB3FDE6747408E3EE60302D34B40
52012	Большие Торханы	7	66	902	46.981054	47.001589000000003	55.563386000000001	55.554450000000003	0103000020E6100000010000000500000014CE6E2D937D474034A2B437F8C64B4014CE6E2D937D47401B834E081DC84B4045847F11348047401B834E081DC84B4045847F113480474034A2B437F8C64B4014CE6E2D937D474034A2B437F8C64B40
52001	Апнеры	7	66	902	46.923237999999998	46.947510999999999	55.513846000000001	55.499805000000002	0103000020E610000001000000050000005436ACA92C7647404BB0389CF9BF4B405436ACA92C7647401897AAB4C5C14B40D5CC5A0A487947401897AAB4C5C14B40D5CC5A0A487947404BB0389CF9BF4B405436ACA92C7647404BB0389CF9BF4B40
52020	Альмень-Сунары	7	66	902	47.015692999999999	47.031925999999999	55.550722999999998	55.540322000000003	0103000020E6100000010000000500000058E36C3A0282474098A7734529C54B4058E36C3A02824740D7135D177EC64B4030F2B22616844740D7135D177EC64B4030F2B2261684474098A7734529C54B4058E36C3A0282474098A7734529C54B40
52091	Альменево	7	66	902	46.917723000000002	46.936542000000003	55.655371000000002	55.638333000000003	0103000020E61000000100000005000000BDE47FF277754740927A4FE5B4D14B40BDE47FF27775474098DF6932E3D34B404CAAB69BE077474098DF6932E3D34B404CAAB69BE0774740927A4FE5B4D14B40BDE47FF277754740927A4FE5B4D14B40
51997	Алгазино	7	66	902	46.931144000000003	46.955632000000001	55.605759999999997	55.588867	0103000020E61000000100000005000000EEEE01BA2F774740C9586DFE5FCB4B40EEEE01BA2F774740CB9C2E8B89CD4B406B813D26527A4740CB9C2E8B89CD4B406B813D26527A4740C9586DFE5FCB4B40EEEE01BA2F774740C9586DFE5FCB4B40
51973	Азим-Сирма	7	66	902	46.735022999999998	46.756304	55.621211000000002	55.608989000000001	0103000020E610000001000000050000006667D13B155E4740D74FFF59F3CD4B406667D13B155E47402E7590D783CF4B40C0EAC891CE6047402E7590D783CF4B40C0EAC891CE604740D74FFF59F3CD4B406667D13B155E4740D74FFF59F3CD4B40
33102	Абызово	7	66	902	46.909198000000004	46.935177000000003	55.541158000000003	55.529252	0103000020E6100000010000000500000058CB9D9960744740DAAB8F87BEC34B4058CB9D996074474001FC53AA44C54B40577C43E1B377474001FC53AA44C54B40577C43E1B3774740DAAB8F87BEC34B4058CB9D9960744740DAAB8F87BEC34B40
51938	Яншихово	7	66	619	47.490155999999999	47.516764000000002	55.080246000000002	55.068210999999998	0103000020E6100000010000000500000016F88A6EBDBE47401D1D5723BB884B4016F88A6EBDBE474042D13C80458A4B4005E09F5225C2474042D13C80458A4B4005E09F5225C247401D1D5723BB884B4016F88A6EBDBE47401D1D5723BB884B40
4208	Шыгырдан	7	66	619	47.526116000000002	47.575127999999999	55.065503999999997	55.038026000000002	0103000020E6100000010000000500000080F3E2C457C34740E8323509DE844B4080F3E2C457C34740EBE0606F62884B40C78157CB9DC94740EBE0606F62884B40C78157CB9DC94740E8323509DE844B4080F3E2C457C34740E8323509DE844B40
32855	Шаймурзино	7	66	619	47.363259999999997	47.388601999999999	55.034399000000001	55.016444999999997	0103000020E61000000100000005000000F4F8BD4D7FAE47406397A8DE1A824B40F4F8BD4D7FAE4740EF01BA2F67844B408194D8B5BDB14740EF01BA2F67844B408194D8B5BDB147406397A8DE1A824B40F4F8BD4D7FAE47406397A8DE1A824B40
52912	Чувашские Ишаки	7	66	619	47.483904000000003	47.506461000000002	55.133946000000002	55.120474999999999	0103000020E61000000100000005000000A933F790F0BD4740287E8CB96B8F4B40A933F790F0BD47400BB77C2425914B4088D9CBB6D3C047400BB77C2425914B4088D9CBB6D3C04740287E8CB96B8F4B40A933F790F0BD4740287E8CB96B8F4B40
58044	Хумара-Твар	7	66	619	47.333866999999998	47.354483999999999	54.957821000000003	54.937241	0103000020E61000000100000005000000581B6327BCAA474034BC5983F7774B40581B6327BCAA47400536E7E0997A4B40467A51BB5FAD47400536E7E0997A4B40467A51BB5FAD474034BC5983F7774B40581B6327BCAA474034BC5983F7774B40
6017	Ульяновка	7	66	619	47.092813	47.118333999999997	55.080112	55.073247000000002	0103000020E6100000010000000500000063D2DF4BE18B4740DBC35E2860894B4063D2DF4BE18B474032022A1C418A4B409F008A91258F474032022A1C418A4B409F008A91258F4740DBC35E2860894B4063D2DF4BE18B4740DBC35E2860894B40
4441	Туруново	7	66	619	47.553074000000002	47.58032	55.076999000000001	55.068381000000002	0103000020E610000001000000050000004B22FB20CBC647407A5567B5C0884B404B22FB20CBC6474090696D1ADB894B407C9BFEEC47CA474090696D1ADB894B407C9BFEEC47CA47407A5567B5C0884B404B22FB20CBC647407A5567B5C0884B40
4871	Тойси	7	66	619	47.752788000000002	47.782854	55.081271999999998	55.069612999999997	0103000020E610000001000000050000001F69705B5BE047402F302B14E9884B401F69705B5BE047404E0AF31E678A4B407AC5538F34E447404E0AF31E678A4B407AC5538F34E447402F302B14E9884B401F69705B5BE047402F302B14E9884B40
51944	Тигашево	7	66	619	47.487335000000002	47.515811999999997	55.065519000000002	55.058332	0103000020E610000001000000050000001C9947FE60BE4740B727486C77874B401C9947FE60BE4740212235ED62884B403271AB2006C24740212235ED62884B403271AB2006C24740B727486C77874B401C9947FE60BE4740B727486C77874B40
52915	Татмыш-Югелево	7	66	619	47.626483999999998	47.661222000000002	55.126528999999998	55.118234999999999	0103000020E61000000100000005000000CFBBB1A030D047400C1F1153228F4B40CFBBB1A030D047406F7F2E1A32904B40A7B228ECA2D447406F7F2E1A32904B40A7B228ECA2D447400C1F1153228F4B40CFBBB1A030D047400C1F1153228F4B40
52931	Татарские Тимяши	7	66	619	47.816909000000003	47.827661999999997	55.090494999999997	55.079700000000003	0103000020E610000001000000050000006F675F7990E84740E0BE0E9C338A4B406F675F7990E84740CBB91457958B4B402B1213D4F0E94740CBB91457958B4B402B1213D4F0E94740E0BE0E9C338A4B406F675F7990E84740E0BE0E9C338A4B40
33035	Татарские Сугуты	7	66	619	47.684165	47.725084000000003	54.998519000000002	54.983204999999998	0103000020E61000000100000005000000AF08FEB792D74740C02154A9D97D4B40AF08FEB792D74740A2B77878CF7F4B402B6D718DCFDC4740A2B77878CF7F4B402B6D718DCFDC4740C02154A9D97D4B40AF08FEB792D74740C02154A9D97D4B40
5446	Тарханы	7	66	619	47.319960999999999	47.346156000000001	55.016919999999999	55.000038000000004	0103000020E610000001000000050000006B7F677BF4A84740EE60C43E01804B406B7F677BF4A84740FC523F6F2A824B4037A8FDD64EAC4740FC523F6F2A824B4037A8FDD64EAC4740EE60C43E01804B406B7F677BF4A84740EE60C43E01804B40
6762	Сугуты	7	66	619	47.615102999999998	47.662317999999999	55.006749999999997	54.99024	0103000020E61000000100000005000000F355F2B1BBCE474074982F2FC07E4B40F355F2B1BBCE4740BE9F1A2FDD804B40ACC612D6C6D44740BE9F1A2FDD804B40ACC612D6C6D4474074982F2FC07E4B40F355F2B1BBCE474074982F2FC07E4B40
32822	Старые Тойси	7	66	619	47.807862999999998	47.838540999999999	55.079529999999998	55.069077	0103000020E610000001000000050000000053060E68E74740F1F3DF83D7884B400053060E68E747408386FE092E8A4B4075ADBD4F55EB47408386FE092E8A4B4075ADBD4F55EB4740F1F3DF83D7884B400053060E68E74740F1F3DF83D7884B40
4834	Старое Котяково	7	66	619	47.625729999999997	47.646040999999997	55.089891999999999	55.074443000000002	0103000020E610000001000000050000002310AFEB17D047404435255987894B402310AFEB17D047400516C094818B4B400470B378B1D247400516C094818B4B400470B378B1D247404435255987894B402310AFEB17D047404435255987894B40
52923	Старое Ахпердино	7	66	619	47.709569999999999	47.741810000000001	55.078302999999998	55.068674999999999	0103000020E61000000100000005000000821C9430D3DA4740C286A757CA884B40821C9430D3DA4740DF162CD5058A4B4042EC4CA1F3DE4740DF162CD5058A4B4042EC4CA1F3DE4740C286A757CA884B40821C9430D3DA4740C286A757CA884B40
51922	Сидели	7	66	619	47.281126999999998	47.305228999999997	55.089063000000003	55.077396	0103000020E61000000100000005000000E48233F8FBA34740AD6BB41CE8894B40E48233F8FBA347404F24986A668B4B4038656EBE11A747404F24986A668B4B4038656EBE11A74740AD6BB41CE8894B40E48233F8FBA34740AD6BB41CE8894B40
52958	Сигачи	7	66	619	47.264561999999998	47.291431000000003	55.022376000000001	55.003878999999998	0103000020E61000000100000005000000D6E1E82ADDA147401212691B7F804B40D6E1E82ADDA147408F1B7E37DD824B4032056B9C4DA547408F1B7E37DD824B4032056B9C4DA547401212691B7F804B40D6E1E82ADDA147401212691B7F804B40
32995	Полевые-Бикшики	7	66	619	47.456747999999997	47.490155999999999	55.105207	55.083657000000002	0103000020E61000000100000005000000B741EDB776BA47406E8AC745B58A4B40B741EDB776BA4740B727486C778D4B4016F88A6EBDBE4740B727486C778D4B4016F88A6EBDBE47406E8AC745B58A4B40B741EDB776BA47406E8AC745B58A4B40
51924	Полевое Чекурово	7	66	619	47.331235	47.355310000000003	55.074432000000002	55.067039999999999	0103000020E61000000100000005000000312592E865AA47400DC347C494884B40312592E865AA474050E3DEFC86894B408CF84ECC7AAD474050E3DEFC86894B408CF84ECC7AAD47400DC347C494884B40312592E865AA47400DC347C494884B40
32852	Подлесные Шигали	7	66	619	47.423250000000003	47.449210999999998	55.024559000000004	55.007488000000002	0103000020E610000001000000050000001904560E2DB64740658EE55DF5804B401904560E2DB6474047E9D2BF24834B407100FDBE7FB9474047E9D2BF24834B407100FDBE7FB94740658EE55DF5804B401904560E2DB64740658EE55DF5804B40
6440	Первомайское	7	66	619	47.330274000000003	47.394089999999998	55.083596	55.071046000000003	0103000020E610000001000000050000000C5C1E6B46AA47407D410B0918894B400C5C1E6B46AA4740C8091346B38A4B401FD7868A71B24740C8091346B38A4B401FD7868A71B247407D410B0918894B400C5C1E6B46AA47407D410B0918894B40
57917	НорвашШигали	7	66	619	47.444826999999997	47.471705	55.041266	55.023124000000003	0103000020E610000001000000050000005BB05417F0B8474059E02BBAF5824B405BB05417F0B84740E7374C3448854B400A2E56D460BC4740E7374C3448854B400A2E56D460BC474059E02BBAF5824B405BB05417F0B8474059E02BBAF5824B40
52908	Новое Котяково	7	66	619	47.563468	47.593542999999997	55.104830999999997	55.096209000000002	0103000020E61000000100000005000000D82B2CB81FC847405A4A9693508C4B40D82B2CB81FC84740B14D2A1A6B8D4B4086E28E37F9CB4740B14D2A1A6B8D4B4086E28E37F9CB47405A4A9693508C4B40D82B2CB81FC847405A4A9693508C4B40
52934	Новое Бахтиарово	7	66	619	47.735019000000001	47.760359999999999	55.090155000000003	55.080091000000003	0103000020E610000001000000050000002578431A15DE47401BDA006C408A4B402578431A15DE47401349F4328A8B4B40E197FA7953E147401349F4328A8B4B40E197FA7953E147401BDA006C408A4B402578431A15DE47401BDA006C408A4B40
4765	Новое Ахпердино	7	66	619	47.668903	47.711196000000001	55.094019000000003	55.080075999999998	0103000020E6100000010000000500000020990E9D9ED54740E5982CEE3F8A4B4020990E9D9ED54740F01989D0088C4B40E485747808DB4740F01989D0088C4B40E485747808DB4740E5982CEE3F8A4B4020990E9D9ED54740E5982CEE3F8A4B40
32867	Нижнее Турмышево	7	66	619	47.339193999999999	47.359496	55.039929999999998	55.027360999999999	0103000020E61000000100000005000000ED7F80B56AAB4740CA17B49080834B40ED7F80B56AAB47408C101E6D1C854B407B8505F703AE47408C101E6D1C854B407B8505F703AE4740CA17B49080834B40ED7F80B56AAB4740CA17B49080834B40
51936	Малые Арабузи	7	66	619	47.439779000000001	47.457610000000003	55.082214999999998	55.073773000000003	0103000020E61000000100000005000000DA3BA3AD4AB84740F629C76471894B40DA3BA3AD4AB84740CD1E6805868A4B404A29E8F692BA4740CD1E6805868A4B404A29E8F692BA4740F629C76471894B40DA3BA3AD4AB84740F629C76471894B40
52903	Малое Батырево	7	66	619	47.579115999999999	47.610988999999996	55.079152999999998	55.071216	0103000020E61000000100000005000000904B1C7920CA4740D9791B9B1D894B40904B1C7920CA4740AD307DAF218A4B409D9B36E334CE4740AD307DAF218A4B409D9B36E334CE4740D9791B9B1D894B40904B1C7920CA4740D9791B9B1D894B40
6028	Люля	7	66	619	47.030937000000002	47.046684999999997	55.046455000000002	55.038010999999997	0103000020E61000000100000005000000419E5DBEF5834740B2F1608BDD844B40419E5DBEF58347402BDEC83CF2854B405C1B2AC6F98547402BDEC83CF2854B405C1B2AC6F9854740B2F1608BDD844B40419E5DBEF5834740B2F1608BDD844B40
51954	Красномайск	7	66	619	47.831533999999998	47.843535000000003	54.996924	54.977294000000001	0103000020E610000001000000050000008BC1C3B46FEA4740DC4944F8177D4B408BC1C3B46FEA47407B4CA4349B7F4B40040473F4F8EB47407B4CA4349B7F4B40040473F4F8EB4740DC4944F8177D4B408BC1C3B46FEA4740DC4944F8177D4B40
51933	Кокшаново	7	66	619	47.387855999999999	47.416637999999999	55.070154000000002	55.065854999999999	0103000020E6100000010000000500000058C7F143A5B1474098A3C7EF6D884B4058C7F143A5B1474080D767CEFA884B40AB22DC6454B5474080D767CEFA884B40AB22DC6454B5474098A3C7EF6D884B4058C7F143A5B1474098A3C7EF6D884B40
40245	Кзыл-Чишма	7	66	619	47.793868000000003	47.817880000000002	55.000926	54.987068999999998	0103000020E61000000100000005000000A4AB74779DE547409DF2E846587E4B40A4AB74779DE54740A9DBD9571E804B40B806B64AB0E84740A9DBD9571E804B40B806B64AB0E847409DF2E846587E4B40A4AB74779DE547409DF2E846587E4B40
52898	Кзыл-Камыш	7	66	619	47.566485999999998	47.591684000000001	55.001742	54.993555999999998	0103000020E6100000010000000500000028D2FD9C82C847404E5FCFD72C7F4B4028D2FD9C82C84740CB83F41439804B4082C8224DBCCB4740CB83F41439804B4082C8224DBCCB47404E5FCFD72C7F4B4028D2FD9C82C847404E5FCFD72C7F4B40
51942	Именево	7	66	619	47.438225000000003	47.458247999999998	55.072690000000001	55.064611999999997	0103000020E6100000010000000500000012A5BDC117B84740EE76BD3445884B4012A5BDC117B84740855FEAE74D894B408CBAD6DEA7BA4740855FEAE74D894B408CBAD6DEA7BA4740EE76BD3445884B4012A5BDC117B84740EE76BD3445884B40
32755	Долгий Остров	7	66	619	47.518058000000003	47.559434000000003	55.124412999999997	55.110584000000003	0103000020E6100000010000000500000031B77BB94FC24740FEBAD39D278E4B4031B77BB94FC247403F19E3C3EC8F4B409F2287889BC747403F19E3C3EC8F4B409F2287889BC74740FEBAD39D278E4B4031B77BB94FC24740FEBAD39D278E4B40
51929	Верхние Бюртли Шигали	7	66	619	47.309541000000003	47.327696000000003	55.103853000000001	55.097377999999999	0103000020E61000000100000005000000B5E21B0A9FA74740C9ACDEE1768C4B40B5E21B0A9FA74740B64B1B0E4B8D4B40D88349F1F1A94740B64B1B0E4B8D4B40D88349F1F1A94740C9ACDEE1768C4B40B5E21B0A9FA74740C9ACDEE1768C4B40
52922	Булаково	7	66	619	47.685772999999998	47.702382999999998	55.079121999999998	55.071226000000003	0103000020E610000001000000050000006ABDDF68C7D74740FD4FFEEE1D894B406ABDDF68C7D74740723271AB208A4B401822A7AFE7D94740723271AB208A4B401822A7AFE7D94740FD4FFEEE1D894B406ABDDF68C7D74740FD4FFEEE1D894B40
5749	Большое Чеменево	7	66	619	47.231073000000002	47.261094999999997	55.033996999999999	55.016404000000001	0103000020E610000001000000050000008BFED0CC939D474005C3B98619824B408BFED0CC939D4740C09481035A844B4016139B8F6BA14740C09481035A844B4016139B8F6BA1474005C3B98619824B408BFED0CC939D474005C3B98619824B40
52960	Бахтигильдино	7	66	619	47.166403000000003	47.205300000000001	55.096007999999998	55.087234000000002	0103000020E61000000100000005000000687A89B14C954740B58CD47B2A8B4B40687A89B14C954740C2137AFD498C4B4035EF3845479A4740C2137AFD498C4B4035EF3845479A4740B58CD47B2A8B4B40687A89B14C954740B58CD47B2A8B4B40
3993	Батырево	7	66	619	47.576582999999999	47.640687	55.073720999999999	55.052200999999997	0103000020E61000000100000005000000FC36C478CDC94740C4E8B985AE864B40FC36C478CDC94740A30392B06F894B4076FC170802D24740A30392B06F894B4076FC170802D24740C4E8B985AE864B40FC36C478CDC94740C4E8B985AE864B40
51917	Балабаш-Нурусово	7	66	619	47.227119999999999	47.249408000000003	55.110160999999998	55.095961000000003	0103000020E610000001000000050000003E22A644129D474082583673488C4B403E22A644129D4740B72572C1198E4B402EAEF199EC9F4740B72572C1198E4B402EAEF199EC9F474082583673488C4B403E22A644129D474082583673488C4B40
6170	Балабаш-Баишево	7	66	619	47.241484999999997	47.281469000000001	55.076267000000001	55.061013000000003	0103000020E61000000100000005000000BEBC00FBE89E4740C0D02346CF874B40BEBC00FBE89E4740CC61F71DC3894B403EEB1A2D07A44740CC61F71DC3894B403EEB1A2D07A44740C0D02346CF874B40BEBC00FBE89E4740C0D02346CF874B40
52957	Бакашево	7	66	619	47.217948999999997	47.241610000000001	55.034874000000002	55.020636000000003	0103000020E610000001000000050000001399B9C0E59B4740658F5033A4824B401399B9C0E59B474088BD50C076844B407B319413ED9E474088BD50C076844B407B319413ED9E4740658F5033A4824B401399B9C0E59B4740658F5033A4824B40
6887	Алманчиково	7	66	619	47.754117000000001	47.784982999999997	54.991501	54.976571	0103000020E61000000100000005000000C72DE6E786E047406B9C4D47007D4B40C72DE6E786E04740C4793881E97E4B403E75AC527AE44740C4793881E97E4B403E75AC527AE447406B9C4D47007D4B40C72DE6E786E047406B9C4D47007D4B40
52951	Абамза	7	66	619	47.232367000000004	47.254223000000003	54.970576999999999	54.958011999999997	0103000020E61000000100000005000000B7D5AC33BE9D474078962023A07A4B40B7D5AC33BE9D4740F99FFCDD3B7C4B400D7217618AA04740F99FFCDD3B7C4B400D7217618AA0474078962023A07A4B40B7D5AC33BE9D474078962023A07A4B40
52809	Яргунькино	7	66	362	46.682768000000003	46.701219999999999	55.770207999999997	55.759419999999999	0103000020E61000000100000005000000AF601BF164574740D3F6AFAC34E14B40AF601BF1645747400C8FFD2C96E24B408BA6B393C15947400C8FFD2C96E24B408BA6B393C1594740D3F6AFAC34E14B40AF601BF164574740D3F6AFAC34E14B40
3815	Яндоба	7	66	362	46.966994999999997	46.982303000000002	55.728149999999999	55.721325999999998	0103000020E61000000100000005000000A032FE7DC67B474093E00D6954DC4B40A032FE7DC67B47408C4AEA0434DD4B40A0E1CD1ABC7D47408C4AEA0434DD4B40A0E1CD1ABC7D474093E00D6954DC4B40A032FE7DC67B474093E00D6954DC4B40
3265	Эренары	7	66	362	46.759034999999997	46.784745000000001	55.696210000000001	55.683264999999999	0103000020E610000001000000050000007AC2120F286147402FC03E3A75D74B407AC2120F28614740F792C6681DD94B408A592F8672644740F792C6681DD94B408A592F86726447402FC03E3A75D74B407AC2120F286147402FC03E3A75D74B40
52821	Шундряши	7	66	362	46.556393	46.575141000000002	55.674143000000001	55.661745000000003	0103000020E61000000100000005000000965CC5E23747474051A5660FB4D44B40965CC5E237474740E6E95C514AD64B405CCB64389E494740E6E95C514AD64B405CCB64389E49474051A5660FB4D44B40965CC5E23747474051A5660FB4D44B40
3574	Шумшеваши	7	66	362	46.544517999999997	46.572240000000001	55.793393999999999	55.778303999999999	0103000020E61000000100000005000000AA0A0DC4B2454740492C29779FE34B40AA0A0DC4B2454740DB6B41EF8DE54B4045BB0A293F494740DB6B41EF8DE54B4045BB0A293F494740492C29779FE34B40AA0A0DC4B2454740492C29779FE34B40
52828	Шерашево	7	66	362	46.580387000000002	46.599494999999997	55.734465999999998	55.722259000000001	0103000020E610000001000000050000000403081F4A4A4740EF1EA0FB72DC4B400403081F4A4A474010035DFB02DE4B40C98E8D40BC4C474010035DFB02DE4B40C98E8D40BC4C4740EF1EA0FB72DC4B400403081F4A4A4740EF1EA0FB72DC4B40
3352	Чувашская Сорма	7	66	362	46.827559000000001	46.837440000000001	55.827181000000003	55.819448999999999	0103000020E6100000010000000500000057410C74ED694740B5DE6FB4E3E84B4057410C74ED694740B16F2711E1E94B405E2EE23B316B4740B16F2711E1E94B405E2EE23B316B4740B5DE6FB4E3E84B4057410C74ED694740B5DE6FB4E3E84B40
52875	Челкасы	7	66	362	46.941178000000001	46.959854	55.747100000000003	55.734157000000003	0103000020E610000001000000050000007BDB4C8578784740939048DBF8DD4B407BDB4C8578784740BA6B09F9A0DF4B40A777F17EDC7A4740BA6B09F9A0DF4B40A777F17EDC7A4740939048DBF8DD4B407BDB4C8578784740939048DBF8DD4B40
52839	Хирлеппоси	7	66	362	46.647258000000001	46.672105000000002	55.739731999999997	55.728073999999999	0103000020E610000001000000050000008509A359D9524740B188618731DD4B408509A359D9524740FFE6C589AFDE4B40323D618907564740FFE6C589AFDE4B40323D618907564740B188618731DD4B408509A359D9524740B188618731DD4B40
2702	Устье	7	66	362	46.728223	46.761406999999998	55.808709999999998	55.799694000000002	0103000020E61000000100000005000000F6984869365D47405A677C5F5CE64B40F6984869365D47405DF92CCF83E74B4005F9D9C8756147405DF92CCF83E74B4005F9D9C8756147405A677C5F5CE64B40F6984869365D47405A677C5F5CE64B40
57897	Урмаево	7	66	362	46.731403	46.746215999999997	55.727322999999998	55.718927000000001	0103000020E6100000010000000500000020990E9D9E5D47400F9BC8CC05DC4B4020990E9D9E5D4740765089EB18DD4B403FE08101845F4740765089EB18DD4B403FE08101845F47400F9BC8CC05DC4B4020990E9D9E5D47400F9BC8CC05DC4B40
52826	Тури-Выла	7	66	362	46.514755999999998	46.542738999999997	55.682426999999997	55.666980000000002	0103000020E61000000100000005000000BBB54C86E3414740058BC3995FD54B40BBB54C86E3414740257497C459D74B40C2A1B77878454740257497C459D74B40C2A1B77878454740058BC3995FD54B40BBB54C86E3414740058BC3995FD54B40
3249	Тенеево	7	66	362	46.740547999999997	46.762160999999999	55.691612999999997	55.679920000000003	0103000020E61000000100000005000000218FE046CA5E4740BBF2599E07D74B40218FE046CA5E4740853E58C686D84B40B1A4DC7D8E614740853E58C686D84B40B1A4DC7D8E614740BBF2599E07D74B40218FE046CA5E4740BBF2599E07D74B40
57900	Таутово	7	66	362	46.615349999999999	46.638570999999999	55.714480000000002	55.701922000000003	0103000020E61000000100000005000000FBCBEEC9C34E4740E52B8194D8D94B40FBCBEEC9C34E4740B3D2A41474DB4B404696CCB1BC514740B3D2A41474DB4B404696CCB1BC514740E52B8194D8D94B40FBCBEEC9C34E4740E52B8194D8D94B40
52794	Сириккасы	7	66	362	46.494121999999997	46.525005999999998	55.747981000000003	55.737025000000003	0103000020E61000000100000005000000F71DC3633F3F4740CEAACFD556DE4B40F71DC3633F3F4740C38366D7BDDF4B40151A886533434740C38366D7BDDF4B40151A886533434740CEAACFD556DE4B40F71DC3633F3F4740CEAACFD556DE4B40
3888	Русская Сорма	7	66	362	46.888815000000001	46.912134999999999	55.773246	55.760190000000001	0103000020E61000000100000005000000DD989EB0C4714740855FEAE74DE14B40DD989EB0C4714740A4E194B9F9E24B40BB44F5D6C0744740A4E194B9F9E24B40BB44F5D6C0744740855FEAE74DE14B40DD989EB0C4714740855FEAE74DE14B40
2744	Раскильдино	7	66	362	46.559933000000001	46.602539999999998	55.692100000000003	55.675930000000001	0103000020E61000000100000005000000C07971E2AB4747405131CEDF84D64B40C07971E2AB474740E3C798BB96D84B401344DD07204D4740E3C798BB96D84B401344DD07204D47405131CEDF84D64B40C07971E2AB4747405131CEDF84D64B40
52859	Прошкино	7	66	362	46.588535	46.604785999999997	55.797857	55.789952	0103000020E6100000010000000500000093C6681D554B474074B4AA251DE54B4093C6681D554B47403DF19C2D20E64B40118AADA0694D47403DF19C2D20E64B40118AADA0694D474074B4AA251DE54B4093C6681D554B474074B4AA251DE54B40
52811	Питишево	7	66	362	46.678761999999999	46.702361000000003	55.801475000000003	55.790337000000001	0103000020E610000001000000050000003FE257ACE1564740CDE847C329E54B403FE257ACE1564740E3C798BB96E64B40317E1AF7E6594740E3C798BB96E64B40317E1AF7E6594740CDE847C329E54B403FE257ACE1564740CDE847C329E54B40
52848	Нижние Елыши	7	66	362	46.840980000000002	46.858811000000003	55.791739	55.782223000000002	0103000020E61000000100000005000000884B8E3BA56B4740EA961DE21FE44B40884B8E3BA56B4740DFFB1BB457E54B40F838D384ED6D4740DFFB1BB457E54B40F838D384ED6D4740EA961DE21FE44B40884B8E3BA56B4740EA961DE21FE44B40
52852	Мартынкино	7	66	362	46.913392999999999	46.933829000000003	55.826538999999997	55.816864000000002	0103000020E610000001000000050000009AB2D30FEA744740CFA3E2FF8EE84B409AB2D30FEA7447402CEFAA07CCE94B4038876BB5877747402CEFAA07CCE94B4038876BB587774740CFA3E2FF8EE84B409AB2D30FEA744740CFA3E2FF8EE84B40
32558	Малые Туваны	7	66	362	46.671844999999998	46.704957	55.696204000000002	55.673960999999998	0103000020E61000000100000005000000957D5704FF554740C5E3A25A44D64B40957D5704FF55474015AC71361DD94B400B0BEE073C5A474015AC71361DD94B400B0BEE073C5A4740C5E3A25A44D64B40957D5704FF554740C5E3A25A44D64B40
2562	Крымзарайкино	7	66	362	46.654786000000001	46.671683000000002	55.784638000000001	55.777088999999997	0103000020E6100000010000000500000078F01307D0534740698A00A777E34B4078F01307D053474074999A046FE44B40BC2363B5F955474074999A046FE44B40BC2363B5F9554740698A00A777E34B4078F01307D0534740698A00A777E34B40
52869	Кивой	7	66	362	46.508468000000001	46.519948999999997	55.781570000000002	55.773843999999997	0103000020E610000001000000050000000188BB7A15414740581AF8510DE34B400188BB7A1541474072C45A7C0AE44B40404B57B08D42474072C45A7C0AE44B40404B57B08D424740581AF8510DE34B400188BB7A15414740581AF8510DE34B40
52863	Ишпарайкино	7	66	362	46.598947000000003	46.623497	55.768014999999998	55.755464000000003	0103000020E61000000100000005000000C784984BAA4C474016A75A0BB3E04B40C784984BAA4C474031EBC5504EE24B40BA13ECBFCE4F474031EBC5504EE24B40BA13ECBFCE4F474016A75A0BB3E04B40C784984BAA4C474016A75A0BB3E04B40
57905	Илгышево	7	66	362	46.748139000000002	46.774934999999999	55.778830999999997	55.766461	0103000020E610000001000000050000005BEECC04C35F47406954E0641BE24B405BEECC04C35F4740340EF5BBB0E34B404CC3F01131634740340EF5BBB0E34B404CC3F011316347406954E0641BE24B405BEECC04C35F47406954E0641BE24B40
57899	Ефремкасы	7	66	362	46.818683	46.836506	55.720686999999998	55.709195999999999	0103000020E610000001000000050000004565C39ACA6847401D3A3DEFC6DA4B404565C39ACA68474080D3BB783FDC4B403274ECA0126B474080D3BB783FDC4B403274ECA0126B47401D3A3DEFC6DA4B404565C39ACA6847401D3A3DEFC6DA4B40
18911	Вотланы	7	66	362	46.864021000000001	46.880918999999999	55.740644000000003	55.729691000000003	0103000020E610000001000000050000005307793D986E4740C097C28366DD4B405307793D986E474044FD2E6CCDDE4B4067B62BF4C170474044FD2E6CCDDE4B4067B62BF4C1704740C097C28366DD4B405307793D986E4740C097C28366DD4B40
33115	Верхние Карачуры	7	66	362	46.865386999999998	46.889595999999997	55.690730000000002	55.675108000000002	0103000020E6100000010000000500000018B14F00C56E47404DA25EF069D64B4018B14F00C56E4740DC2E34D769D84B4082531F48DE714740DC2E34D769D84B4082531F48DE7147404DA25EF069D64B4018B14F00C56E47404DA25EF069D64B40
58019	Большое Ямашаево	7	66	362	46.442549999999997	46.468330999999999	55.767012999999999	55.755510000000001	0103000020E61000000100000005000000226C787AA538474086E63A8DB4E04B40226C787AA5384740AD4D637B2DE24B40FB592C45F23B4740AD4D637B2DE24B40FB592C45F23B474086E63A8DB4E04B40226C787AA538474086E63A8DB4E04B40
52845	Большие Шиуши	7	66	362	46.827038000000002	46.854849999999999	55.846204	55.835012999999996	0103000020E610000001000000050000004E469561DC6947400F5EBBB4E1EA4B404E469561DC69474048DFA46950EC4B40287E8CB96B6D474048DFA46950EC4B40287E8CB96B6D47400F5EBBB4E1EA4B404E469561DC6947400F5EBBB4E1EA4B40
52822	Большие Токташи	7	66	362	46.600257999999997	46.631124	55.677670999999997	55.664771000000002	0103000020E61000000100000005000000C8940F41D54C4740242A543717D54B40C8940F41D54C47404B395FECBDD64B4040DCD5ABC85047404B395FECBDD64B4040DCD5ABC8504740242A543717D54B40C8940F41D54C4740242A543717D54B40
2125	Большая Выла	7	66	362	46.539315999999999	46.562151999999998	55.735388	55.716174000000002	0103000020E61000000100000005000000D21A834E084547406D1FF296ABDB4B40D21A834E0845474078EFA83121DE4B40C4B0C398F447474078EFA83121DE4B40C4B0C398F44747406D1FF296ABDB4B40D21A834E084547406D1FF296ABDB4B40
1859	Аликово	7	66	362	46.730728999999997	46.772699000000003	55.744784000000003	55.730933	0103000020E61000000100000005000000909E2287885D4740994869368FDD4B40909E2287885D4740C34A051555DF4B40725303CDE7624740C34A051555DF4B40725303CDE7624740994869368FDD4B40909E2287885D4740994869368FDD4B40
151	Ялушево	7	66	107	46.529874999999997	46.546072000000002	54.870803000000002	54.863435000000003	0103000020E61000000100000005000000E7FBA9F1D2434740639CBF09856E4B40E7FBA9F1D24347401D210379766F4B4073A1F2AFE54547401D210379766F4B4073A1F2AFE5454740639CBF09856E4B40E7FBA9F1D2434740639CBF09856E4B40
23998	Явлей	7	66	107	46.557910999999997	46.585427000000003	54.924832000000002	54.903987000000001	0103000020E61000000100000005000000118AADA0694747402C8194D8B5734B40118AADA069474740AB251DE560764B4003999D45EF4A4740AB251DE560764B4003999D45EF4A47402C8194D8B5734B40118AADA0694747402C8194D8B5734B40
32935	Чуварлей	7	66	107	46.457597	46.558855000000001	54.880887999999999	54.854650999999997	0103000020E61000000100000005000000B5DFDA89923A4740313F3734656D4B40B5DFDA89923A47402CB81FF0C0704B40611A868F884747402CB81FF0C0704B40611A868F88474740313F3734656D4B40B5DFDA89923A4740313F3734656D4B40
29765	Сурский Майдан	7	66	107	46.514980999999999	46.556868999999999	55.034238999999999	55.014659000000002	0103000020E61000000100000005000000DB87BCE5EA414740C9CB9A58E0814B40DB87BCE5EA414740B69F8CF161844B40FF93BF7B47474740B69F8CF161844B40FF93BF7B47474740C9CB9A58E0814B40DB87BCE5EA414740C9CB9A58E0814B40
32497	Стемасы	7	66	107	46.596044999999997	46.687573999999998	54.804431000000001	54.770156999999998	0103000020E61000000100000005000000DFF8DA334B4C47408AE42B8194624B40DFF8DA334B4C4740BD715298F7664B403ACAC16C02584740BD715298F7664B403ACAC16C025847408AE42B8194624B40DFF8DA334B4C47408AE42B8194624B40
32410	Старые Айбеси	7	66	107	47.024317000000003	47.060222000000003	54.958488000000003	54.941553999999996	0103000020E6100000010000000500000051DEC7D11C83474080B56AD784784B4051DEC7D11C834740E2CD1ABCAF7A4B40F73FC05AB5874740E2CD1ABCAF7A4B40F73FC05AB587474080B56AD784784B4051DEC7D11C83474080B56AD784784B40
47246	Соловьевский	7	66	107	46.807329000000003	46.832185000000003	54.682606999999997	54.675953999999997	0103000020E61000000100000005000000630E828E56674740D9CC21A985564B40630E828E56674740A5828AAA5F574B40639CBF09856A4740A5828AAA5F574B40639CBF09856A4740D9CC21A985564B40630E828E56674740D9CC21A985564B40
32404	Сойгино	7	66	107	47.058847999999998	47.091430000000003	54.794969999999999	54.778793	0103000020E61000000100000005000000AEB7CD548887474047AD307DAF634B40AEB7CD54888747408BA6B393C1654B40C8EF6DFAB38B47408BA6B393C1654B40C8EF6DFAB38B474047AD307DAF634B40AEB7CD548887474047AD307DAF634B40
54713	Первомайский	7	66	107	46.923544	46.982294000000003	54.916992999999998	54.903354999999998	0103000020E61000000100000005000000613596B036764740CBD6FA22A1734B40613596B03676474099D4D00660754B404D874ECFBB7D474099D4D00660754B404D874ECFBB7D4740CBD6FA22A1734B40613596B036764740CBD6FA22A1734B40
28905	Новые Айбеси	7	66	107	47.023158000000002	47.060115000000003	54.817810999999999	54.797175000000003	0103000020E61000000100000005000000055262D7F68247402B1895D409664B40055262D7F68247408FA7E507AE684B40E17F2BD9B18747408FA7E507AE684B40E17F2BD9B18747402B1895D409664B40055262D7F68247402B1895D409664B40
31541	Миренки	7	66	107	46.374754000000003	46.407668000000001	54.908670999999998	54.890179000000003	0103000020E61000000100000005000000C90567F0F72F4740024BAE62F1714B40C90567F0F72F47406CE9D1544F744B4018D00B772E3447406CE9D1544F744B4018D00B772E344740024BAE62F1714B40C90567F0F72F4740024BAE62F1714B40
27627	Междуречье	7	66	107	46.510274000000003	46.544319999999999	54.990777999999999	54.966540999999999	0103000020E61000000100000005000000E3FF8EA8504147401F9F909DB77B4B40E3FF8EA85041474053CC41D0D17E4B4084471B47AC45474053CC41D0D17E4B4084471B47AC4547401F9F909DB77B4B40E3FF8EA8504147401F9F909DB77B4B40
47259	Кувакино	7	66	107	46.391525999999999	46.429335999999999	54.988959000000001	54.968674999999998	0103000020E6100000010000000500000050C422861D324740F5B9DA8AFD7B4B4050C422861D324740DD0A6135967E4B406B7F677BF4364740DD0A6135967E4B406B7F677BF4364740F5B9DA8AFD7B4B4050C422861D324740F5B9DA8AFD7B4B40
205	Киря	7	66	107	46.840288000000001	46.881880000000002	55.094662999999997	55.068247	0103000020E61000000100000005000000529CA38E8E6B47406A865451BC884B40529CA38E8E6B47401492CCEA1D8C4B408D7F9F71E17047401492CCEA1D8C4B408D7F9F71E17047406A865451BC884B40529CA38E8E6B47406A865451BC884B40
32230	Ичиксы	7	66	107	46.456833000000003	46.490591999999999	54.987554000000003	54.967981999999999	0103000020E61000000100000005000000E65DF580793A4740EF8E8CD5E67B4B40E65DF580793A47405A84622B687E4B40F1D6F9B7CB3E47405A84622B687E4B40F1D6F9B7CB3E4740EF8E8CD5E67B4B40E65DF580793A4740EF8E8CD5E67B4B40
32073	Иваньково-Ленино	7	66	107	46.642057000000001	46.704633000000001	54.752988000000002	54.701205000000002	0103000020E610000001000000050000007D957CEC2E5247405665DF15C1594B407D957CEC2E524740E62329E961604B405857056A315A4740E62329E961604B405857056A315A47405665DF15C1594B407D957CEC2E5247405665DF15C1594B40
54269	Восход	7	66	107	46.572724999999998	46.595433999999997	54.806905999999998	54.798805000000002	0103000020E61000000100000005000000014D840D4F494740CE70033E3F664B40014D840D4F4947401C7920B248674B4096766A2E374C47401C7920B248674B4096766A2E374C4740CE70033E3F664B40014D840D4F494740CE70033E3F664B40
32271	Березовый Майдан	7	66	107	46.350203	46.375624999999999	54.974730999999998	54.955416999999997	0103000020E6100000010000000500000005FBAF73D32C47406E85B01A4B7A4B4005FBAF73D32C4740DDB243FCC37C4B40AE47E17A14304740DDB243FCC37C4B40AE47E17A143047406E85B01A4B7A4B4005FBAF73D32C47406E85B01A4B7A4B40
32002	Ахматово	7	66	107	46.396538	46.430045	54.858207	54.848877999999999	0103000020E6100000010000000500000085CFD6C1C13247409E25C808A86C4B4085CFD6C1C132474061191BBAD96D4B407767EDB60B37474061191BBAD96D4B407767EDB60B3747409E25C808A86C4B4085CFD6C1C13247409E25C808A86C4B40
31915	Атрать	7	66	107	46.649683000000003	46.692847	55.017105999999998	55.000883999999999	0103000020E6100000010000000500000033E202D0285347407A8B87F71C804B4033E202D0285347405E48878730824B40DC10E335AF5847405E48878730824B40DC10E335AF5847407A8B87F71C804B4033E202D0285347407A8B87F71C804B40
47119	Анютино	7	66	107	46.701867	46.712736	54.831249999999997	54.826292000000002	0103000020E61000000100000005000000219221C7D65947402579AEEFC3694B40219221C7D659474066666666666A4B404757E9EE3A5B474066666666666A4B404757E9EE3A5B47402579AEEFC3694B40219221C7D65947402579AEEFC3694B40
32821	Алтышево	7	66	107	46.680486999999999	46.734034999999999	54.923786	54.888013999999998	0103000020E61000000100000005000000342DB1321A574740F0315871AA714B40342DB1321A5747405740A19E3E764B40478FDFDBF45D47405740A19E3E764B40478FDFDBF45D4740F0315871AA714B40342DB1321A574740F0315871AA714B40
56388	Шудья	7	65	\N	53.062432999999999	53.080973999999998	56.787770000000002	56.778944000000003	0103000020E610000001000000050000007898F6CDFD874A402DB5DE6FB4634C407898F6CDFD874A408D62B9A5D5644C40C4E9245B5D8A4A408D62B9A5D5644C40C4E9245B5D8A4A402DB5DE6FB4634C407898F6CDFD874A402DB5DE6FB4634C40
11375	Сарапул	7	65	\N	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
56379	Позимь	7	65	\N	53.387622999999998	53.426833999999999	56.864860999999998	56.848255999999999	0103000020E61000000100000005000000B51666A19DB14A40615111A7936C4C40B51666A19DB14A40FD4AE7C3B36E4C4012691B7FA2B64A40FD4AE7C3B36E4C4012691B7FA2B64A40615111A7936C4C40B51666A19DB14A40615111A7936C4C40
52432	Пирогово	7	65	\N	53.134881999999998	53.173023999999998	56.790373000000002	56.768546000000001	0103000020E61000000100000005000000D76839D043914A405EBC1FB75F624C40D76839D043914A401A5245F12A654C4028B682A625964A401A5245F12A654C4028B682A625964A405EBC1FB75F624C40D76839D043914A405EBC1FB75F624C40
56360	Первомайский	7	65	\N	53.338197999999998	53.382224000000001	56.861097000000001	56.845272999999999	0103000020E610000001000000050000004BC972124AAB4A408D98D9E7316C4C404BC972124AAB4A4084D72E6D386E4C4087DF4DB7ECB04A4084D72E6D386E4C4087DF4DB7ECB04A408D98D9E7316C4C404BC972124AAB4A408D98D9E7316C4C40
56361	Октябрьский	7	65	\N	53.312910000000002	53.332880000000003	56.844490999999998	56.834249999999997	0103000020E61000000100000005000000B24B546F0DA84A40105839B4C86A4C40B24B546F0DA84A401762F547186C4C400ABFD4CF9BAA4A401762F547186C4C400ABFD4CF9BAA4A40105839B4C86A4C40B24B546F0DA84A40105839B4C86A4C40
11277	Можга	7	65	\N	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
28834	Камбарка	7	65	\N	54.174968999999997	54.238982999999998	56.286762000000003	56.251871999999999	0103000020E610000001000000050000002B685A6265164B40996379573D204C402B685A6265164B4027DE019EB4244C4065A6B4FE961E4B4027DE019EB4244C4065A6B4FE961E4B40996379573D204C402B685A6265164B40996379573D204C40
70	Ижевск	7	65	\N	53.029069	53.314123000000002	56.939194999999998	56.763978000000002	0103000020E61000000100000005000000E9297288B8834A40876EF607CA614C40E9297288B8834A408AC8B08A37784C40F1F5B52E35A84A408AC8B08A37784C40F1F5B52E35A84A40876EF607CA614C40E9297288B8834A40876EF607CA614C40
56364	Завьялово	7	65	\N	53.342599	53.411850999999999	56.809072999999998	56.768166999999998	0103000020E610000001000000050000003752B648DAAB4A40E76ED74B53624C403752B648DAAB4A40CE893DB48F674C4096E99788B7B44A40CE893DB48F674C4096E99788B7B44A40E76ED74B53624C403752B648DAAB4A40E76ED74B53624C40
9492	Глазов	7	65	\N	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
8096	Воткинск	7	65	\N	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
56365	Яр	7	65	1498	51.682423	52.431922999999998	58.489387000000001	58.000250000000001	0103000020E61000000100000005000000E48409A359D7494079E9263108004D40E48409A359D74940350BB43BA43E4D40F2B1BB4049374A40350BB43BA43E4D40F2B1BB4049374A4079E9263108004D40E48409A359D7494079E9263108004D40
56406	Юр	7	65	1498	51.682423	52.431922999999998	58.489387000000001	58.000250000000001	0103000020E61000000100000005000000E48409A359D7494079E9263108004D40E48409A359D74940350BB43BA43E4D40F2B1BB4049374A40350BB43BA43E4D40F2B1BB4049374A4079E9263108004D40E48409A359D7494079E9263108004D40
17515	Юдчино	7	65	1498	51.948045999999998	51.971527999999999	58.255923000000003	58.238985999999997	0103000020E61000000100000005000000438D429259F94940D619DF17971E4D40438D429259F94940A9A5B915C2204D40FB928D075BFC4940A9A5B915C2204D40FB928D075BFC4940D619DF17971E4D40438D429259F94940D619DF17971E4D40
17917	Усть-Лекма	7	65	1498	52.051001999999997	52.070126999999999	58.321514000000001	58.309477999999999	0103000020E61000000100000005000000EA03C93B87064A406E6AA0F99C274D40EA03C93B87064A40639AE95E27294D4086C8E9EBF9084A40639AE95E27294D4086C8E9EBF9084A406E6AA0F99C274D40EA03C93B87064A406E6AA0F99C274D40
18205	Укан	7	65	1498	52.032164000000002	52.077492999999997	58.167929999999998	58.159593999999998	0103000020E61000000100000005000000E50D30F31D044A40A45181936D144D40E50D30F31D044A403602F1BA7E154D409F55664AEB094A403602F1BA7E154D409F55664AEB094A40A45181936D144D40E50D30F31D044A40A45181936D144D40
18017	Тум	7	65	1498	52.301461000000003	52.331141000000002	58.315860999999998	58.307242000000002	0103000020E610000001000000050000007E02284696264A4094FAB2B453274D407E02284696264A407A8A1C226E284D40B0AE0AD4622A4A407A8A1C226E284D40B0AE0AD4622A4A4094FAB2B453274D407E02284696264A4094FAB2B453274D40
18210	Пудем	7	65	1498	52.121941999999997	52.203868	58.316239000000003	58.294313000000002	0103000020E610000001000000050000002101A3CB9B0F4A40D2E4620CAC254D402101A3CB9B0F4A40215C01857A284D40B859BC58181A4A40215C01857A284D40B859BC58181A4A40D2E4620CAC254D402101A3CB9B0F4A40D2E4620CAC254D40
18020	Озерки	7	65	1498	52.188363000000003	52.211917	58.256373000000004	58.239350999999999	0103000020E6100000010000000500000063635E471C184A40E8A1B60DA31E4D4063635E471C184A40E94999D4D0204D40B43BA418201B4A40E94999D4D0204D40B43BA418201B4A40E8A1B60DA31E4D4063635E471C184A40E8A1B60DA31E4D40
18130	Никольское	7	65	1498	51.872956000000002	51.898826999999997	58.073489000000002	58.058664	0103000020E610000001000000050000006A6CAF05BDEF4940EDB94C4D82074D406A6CAF05BDEF4940D1CE691668094D4082E15CC30CF34940D1CE691668094D4082E15CC30CF34940EDB94C4D82074D406A6CAF05BDEF4940EDB94C4D82074D40
17722	Мосеево	7	65	1498	52.240141999999999	52.266651000000003	58.195099999999996	58.185763999999999	0103000020E61000000100000005000000B1321AF9BC1E4A401763601DC7174D40B1321AF9BC1E4A408CB96B09F9184D400D39B69E21224A408CB96B09F9184D400D39B69E21224A401763601DC7174D40B1321AF9BC1E4A401763601DC7174D40
17841	Кузьмино	7	65	1498	52.084373999999997	52.097848999999997	58.375857000000003	58.360168000000002	0103000020E61000000100000005000000FC5069C4CC0A4A406A882AFC192E4D40FC5069C4CC0A4A40817C09151C304D402079E750860C4A40817C09151C304D402079E750860C4A406A882AFC192E4D40FC5069C4CC0A4A406A882AFC192E4D40
17932	Зюино	7	65	1498	51.780205000000002	51.802025	58.200184999999998	58.187097999999999	0103000020E610000001000000050000007D96E7C1DDE34940D192C7D3F2174D407D96E7C1DDE349402B137EA99F194D4086C954C1A8E649402B137EA99F194D4086C954C1A8E64940D192C7D3F2174D407D96E7C1DDE34940D192C7D3F2174D40
17814	Елово	7	65	1498	51.949069999999999	51.975982999999999	58.351239	58.339492999999997	0103000020E61000000100000005000000AFCE31207BF94940471CB281742B4D40AFCE31207BF94940350A4966F52C4D40DA39CD02EDFC4940350A4966F52C4D40DA39CD02EDFC4940471CB281742B4D40AFCE31207BF94940471CB281742B4D40
17729	Дизьмино	7	65	1498	52.132199999999997	52.168788999999997	58.225572	58.207572999999996	0103000020E61000000100000005000000FE43FAEDEB104A402C4487C0911A4D40FE43FAEDEB104A405872158BDF1C4D405776C1E09A154A405872158BDF1C4D405776C1E09A154A402C4487C0911A4D40FE43FAEDEB104A402C4487C0911A4D40
17615	Ворца	7	65	1498	52.133727999999998	52.161144	58.116042	58.095917999999998	0103000020E610000001000000050000009D47C5FF1D114A40828C800A470C4D409D47C5FF1D114A40317BD976DA0E4D402BF9D85DA0144A40317BD976DA0E4D402BF9D85DA0144A40828C800A470C4D409D47C5FF1D114A40828C800A470C4D40
17629	Васепиево	7	65	1498	52.049987000000002	52.0625	58.072840999999997	58.065824999999997	0103000020E61000000100000005000000D21C59F965064A402D211FF46C084D40D21C59F965064A406A6798DA52094D400000000000084A406A6798DA52094D400000000000084A402D211FF46C084D40D21C59F965064A402D211FF46C084D40
17543	Бачумово	7	65	1498	51.900866000000001	51.929082000000001	58.282953999999997	58.268610000000002	0103000020E61000000100000005000000070ABC934FF3494075B0FECF61224D40070ABC934FF34940DD2230D637244D40B1A6B228ECF64940DD2230D637244D40B1A6B228ECF6494075B0FECF61224D40070ABC934FF3494075B0FECF61224D40
17414	Бармашур	7	65	1498	52.078876000000001	52.093581999999998	58.262706999999999	58.255524999999999	0103000020E610000001000000050000003B38D89B180A4A40BB270F0BB5204D403B38D89B180A4A4013B70A62A0214D4044BFB67EFA0B4A4013B70A62A0214D4044BFB67EFA0B4A40BB270F0BB5204D403B38D89B180A4A40BB270F0BB5204D40
16013	Якшур-Бодья	7	65	1401	53.140980999999996	53.190676000000003	57.195526999999998	57.170478000000003	0103000020E61000000100000005000000BE2D58AA0B924A4000581D39D2954C40BE2D58AA0B924A40143E5B0707994C40E910381268984A40143E5B0707994C40E910381268984A4000581D39D2954C40BE2D58AA0B924A4000581D39D2954C40
16203	Якшур	7	65	1401	53.155175	53.171227999999999	57.217503999999998	57.205317999999998	0103000020E6100000010000000500000012143FC6DC934A40DBA337DC479A4C4012143FC6DC934A40E55FCB2BD79B4C406A1492CCEA954A40E55FCB2BD79B4C406A1492CCEA954A40DBA337DC479A4C4012143FC6DC934A40DBA337DC479A4C40
15919	Чур	7	65	1401	52.952668000000003	52.987675000000003	57.121184	57.100332999999999	0103000020E610000001000000050000000EF96706F1794A40D3DA34B6D78C4C400EF96706F1794A40346612F5828F4C40D50968226C7E4A40346612F5828F4C40D50968226C7E4A40D3DA34B6D78C4C400EF96706F1794A40D3DA34B6D78C4C40
16410	Сюровай	7	65	1401	52.910778999999998	52.934953	57.211089999999999	57.198160000000001	0103000020E610000001000000050000001971016894744A400CB08F4E5D994C401971016894744A409E4143FF049B4C400726378AAC774A409E4143FF049B4C400726378AAC774A400CB08F4E5D994C401971016894744A400CB08F4E5D994C40
16415	Старые Зятцы	7	65	1401	52.628608999999997	52.665332999999997	57.362001999999997	57.334131999999997	0103000020E61000000100000005000000527C7C4276504A4006465ED6C4AA4C40527C7C4276504A40158BDF1456AE4C408BF9B9A129554A40158BDF1456AE4C408BF9B9A129554A4006465ED6C4AA4C40527C7C4276504A4006465ED6C4AA4C40
16741	Селычка	7	65	1401	53.182761999999997	53.198016000000003	57.075062000000003	57.067160000000001	0103000020E61000000100000005000000CC79C6BE64974A40B8CCE9B298884C40CC79C6BE64974A401096B1A19B894C40D90A9A9658994A401096B1A19B894C40D90A9A9658994A40B8CCE9B298884C40CC79C6BE64974A40B8CCE9B298884C40
16816	Пушкари	7	65	1401	53.24427	53.256532	57.212941999999998	57.201846000000003	0103000020E610000001000000050000006CB2463D449F4A400A6AF816D6994C406CB2463D449F4A40F0F8F6AE419B4C405130630AD6A04A40F0F8F6AE419B4C405130630AD6A04A400A6AF816D6994C406CB2463D449F4A400A6AF816D6994C40
16324	Порва	7	65	1401	52.752298000000003	53.052219000000001	57.294026000000002	57.208896000000003	0103000020E61000000100000005000000516C054D4B604A40F321A81ABD9A4C40516C054D4B604A403C16DBA4A2A54C406B9DB81CAF864A403C16DBA4A2A54C406B9DB81CAF864A40F321A81ABD9A4C40516C054D4B604A40F321A81ABD9A4C40
16302	Нижний Пислеглуд	7	65	1401	53.081890000000001	53.098329	57.210509000000002	57.198546	0103000020E610000001000000050000004AEF1B5F7B8A4A40356090F469994C404AEF1B5F7B8A4A40C0417BF5F19A4C40CB9F6F0B968C4A40C0417BF5F19A4C40CB9F6F0B968C4A40356090F469994C404AEF1B5F7B8A4A40356090F469994C40
16929	Мукши	7	65	1401	53.387165000000003	53.408994	57.246046999999997	57.235770000000002	0103000020E61000000100000005000000F3936A9F8EB14A4060B01BB62D9E4C40F3936A9F8EB14A40B323D5777E9F4C404F2157EA59B44A40B323D5777E9F4C404F2157EA59B44A4060B01BB62D9E4C40F3936A9F8EB14A4060B01BB62D9E4C40
16611	Малая Итча	7	65	1401	52.841329999999999	52.859251999999998	57.147336000000003	57.138795000000002	0103000020E61000000100000005000000649291B3B06B4A4096ECD808C4914C40649291B3B06B4A4001C3F2E7DB924C40E48233F8FB6D4A4001C3F2E7DB924C40E48233F8FB6D4A4096ECD808C4914C40649291B3B06B4A4096ECD808C4914C40
16725	Люкшудья	7	65	1401	53.031486000000001	53.045769	57.019736000000002	57.009067999999999	0103000020E610000001000000050000001424B6BB07844A4056B8E52329814C401424B6BB07844A40E54691B586824C40D71533C2DB854A40E54691B586824C40D71533C2DB854A4056B8E52329814C401424B6BB07844A4056B8E52329814C40
16206	Лынга	7	65	1401	53.007716000000002	53.046559999999999	57.304271999999997	57.285806000000001	0103000020E61000000100000005000000F6D37FD6FC804A4013807F4A95A44C40F6D37FD6FC804A40548B8862F2A64C40A0A696ADF5854A40548B8862F2A64C40A0A696ADF5854A4013807F4A95A44C40F6D37FD6FC804A4013807F4A95A44C40
17011	Кыква	7	65	1401	53.410547999999999	53.445591	57.293185000000001	57.282017000000003	0103000020E6100000010000000500000017B83CD68CB44A4041F50F2219A44C4017B83CD68CB44A40C156091687A54C402B323A2009B94A40C156091687A54C402B323A2009B94A4041F50F2219A44C4017B83CD68CB44A4041F50F2219A44C40
17210	Кекоран	7	65	1401	52.970841	52.997565000000002	57.215626999999998	57.207278000000002	0103000020E61000000100000005000000D74E9484447C4A401497E315889A4C40D74E9484447C4A403A9160AA999B4C402F51BD35B07F4A403A9160AA999B4C402F51BD35B07F4A401497E315889A4C40D74E9484447C4A401497E315889A4C40
17219	Иж-Забегалово	7	65	1401	53.324894	53.361733000000001	57.144742999999998	57.134169	0103000020E610000001000000050000005455682096A94A408A9125732C914C405455682096A94A4097A949F086924C40267156444DAE4A4097A949F086924C40267156444DAE4A408A9125732C914C405455682096A94A408A9125732C914C40
16534	Зеглуд	7	65	1401	52.566409999999998	52.592703999999998	57.319788000000003	57.309683	0103000020E610000001000000050000004D10751F80484A4047904AB1A3A74C404D10751F80484A409ED32CD0EEA84C40AC1A84B9DD4B4A409ED32CD0EEA84C40AC1A84B9DD4B4A4047904AB1A3A74C404D10751F80484A4047904AB1A3A74C40
17140	Выжоил	7	65	1401	53.054222000000003	53.079914000000002	57.173932999999998	57.162146999999997	0103000020E61000000100000005000000A35C1ABFF0864A407F129F3BC1944C40A35C1ABFF0864A40FB58C16F43964C400C3F389F3A8A4A40FB58C16F43964C400C3F389F3A8A4A407F129F3BC1944C40A35C1ABFF0864A407F129F3BC1944C40
15435	Варавай	7	65	1401	52.558424000000002	52.589084	57.282941000000001	57.274304999999998	0103000020E6100000010000000500000098A608707A474A408C101E6D1CA34C4098A608707A474A4049D9226937A44C40664CC11A674B4A4049D9226937A44C40664CC11A674B4A408C101E6D1CA34C4098A608707A474A408C101E6D1CA34C40
16917	Большие Ошворцы	7	65	1401	53.284829000000002	53.314500000000002	57.205508000000002	57.196340999999997	0103000020E61000000100000005000000E8F9D34675A44A4095EEAEB321994C40E8F9D34675A44A407F880D164E9A4C40C74B378941A84A407F880D164E9A4C40C74B378941A84A4095EEAEB321994C40E8F9D34675A44A4095EEAEB321994C40
16513	Алгазы	7	65	1401	52.754399999999997	52.767426	57.277442999999998	57.269545999999998	0103000020E610000001000000050000001B0DE02D90604A404162BB7B80A24C401B0DE02D90604A4087C0914083A34C40D00CE2033B624A4087C0914083A34C40D00CE2033B624A404162BB7B80A24C401B0DE02D90604A404162BB7B80A24C40
14783	Юкаменское	7	65	1368	52.222230000000003	52.264217000000002	57.903775000000003	57.882860999999998	0103000020E6100000010000000500000055185B08721C4A40F9F4D89601F14C4055185B08721C4A40A1F831E6AEF34C400C06D7DCD1214A40A1F831E6AEF34C400C06D7DCD1214A40F9F4D89601F14C4055185B08721C4A40F9F4D89601F14C40
15456	Шафеево	7	65	1368	52.128867999999997	52.153796	57.845148999999999	57.834513999999999	0103000020E610000001000000050000001EC022BF7E104A40EE06D15AD1EA4C401EC022BF7E104A40A19FA9D72DEC4C40B8205B96AF134A40A19FA9D72DEC4C40B8205B96AF134A40EE06D15AD1EA4C401EC022BF7E104A40EE06D15AD1EA4C40
15537	Шамардан	7	65	1368	52.133889000000003	52.167316	58.028444999999998	58.006092000000002	0103000020E61000000100000005000000A725564623114A403562669FC7004D40A725564623114A400B5EF415A4034D407C0C569C6A154A400B5EF415A4034D407C0C569C6A154A403562669FC7004D40A725564623114A403562669FC7004D40
56392	Татарские Ключи	7	65	1368	52.246107000000002	52.27355	57.989260000000002	57.973416999999998	0103000020E610000001000000050000008928266F801F4A406A2FA2ED98FC4C408928266F801F4A40D89E5912A0FE4C4010E9B7AF03234A40D89E5912A0FE4C4010E9B7AF03234A406A2FA2ED98FC4C408928266F801F4A406A2FA2ED98FC4C40
15238	Пышкет	7	65	1368	51.937534999999997	51.985658000000001	57.907685999999998	57.890099999999997	0103000020E610000001000000050000007CED992501F84940B515FBCBEEF14C407CED992501F84940BE840A0E2FF44C403885950A2AFE4940BE840A0E2FF44C403885950A2AFE4940B515FBCBEEF14C407CED992501F84940B515FBCBEEF14C40
15642	Починки	7	65	1368	52.251685000000002	52.277458000000003	57.961956000000001	57.951278000000002	0103000020E6100000010000000500000067F2CD3637204A40C0B33D7AC3F94C4067F2CD3637204A407218CC5F21FB4C40BD0166BE83234A407218CC5F21FB4C40BD0166BE83234A40C0B33D7AC3F94C4067F2CD3637204A40C0B33D7AC3F94C40
15730	Палагай	7	65	1368	52.344859	52.375329000000001	57.962967999999996	57.945714000000002	0103000020E610000001000000050000009A5DF756242C4A4047AF06280DF94C409A5DF756242C4A40198C118942FB4C40C51EDAC70A304A40198C118942FB4C40C51EDAC70A304A4047AF06280DF94C409A5DF756242C4A4047AF06280DF94C40
56414	Новоелово	7	65	1368	52.038542	52.052411999999997	57.985461999999998	57.972304999999999	0103000020E61000000100000005000000DFC2BAF1EE044A405F5E807D74FC4C40DFC2BAF1EE044A40B2B96A9E23FE4C407FF5B86FB5064A40B2B96A9E23FE4C407FF5B86FB5064A405F5E807D74FC4C40DFC2BAF1EE044A405F5E807D74FC4C40
15920	Малый Вениж	7	65	1368	52.484771000000002	52.510722999999999	57.883310999999999	57.874333	0103000020E610000001000000050000004D86E3F90C3E4A402368CC24EAEF4C404D86E3F90C3E4A403999B85510F14C4052280B5F5F414A403999B85510F14C4052280B5F5F414A402368CC24EAEF4C404D86E3F90C3E4A402368CC24EAEF4C40
15174	Кельдыки	7	65	1368	52.000328000000003	52.011178999999998	57.971021	57.959358000000002	0103000020E61000000100000005000000F5A276BF0A004A40F793313ECCFA4C40F5A276BF0A004A40575D876A4AFC4C4074B33F506E014A40575D876A4AFC4C4074B33F506E014A40F793313ECCFA4C40F5A276BF0A004A40F793313ECCFA4C40
14958	Камки	7	65	1368	52.206186000000002	52.222372999999997	57.818913999999999	57.808190000000003	0103000020E610000001000000050000005072874D641A4A40257A19C572E74C405072874D641A4A40471E882CD2E84C40B741EDB7761C4A40471E882CD2E84C40B741EDB7761C4A40257A19C572E74C405072874D641A4A40257A19C572E74C40
15340	Зянкино	7	65	1368	51.931553000000001	51.952069999999999	57.837944999999998	57.831074000000001	0103000020E61000000100000005000000CFBEF2203DF74940284701A260EA4C40CFBEF2203DF74940616C21C841EB4C4059C0046EDDF94940616C21C841EB4C4059C0046EDDF94940284701A260EA4C40CFBEF2203DF74940284701A260EA4C40
15807	Засеково	7	65	1368	52.409689999999998	52.440314000000001	57.864615999999998	57.846127000000003	0103000020E61000000100000005000000C6BFCFB870344A409DA1B8E34DEC4C40C6BFCFB870344A4096CCB1BCABEE4C4048FC8A355C384A4096CCB1BCABEE4C4048FC8A355C384A409DA1B8E34DEC4C40C6BFCFB870344A409DA1B8E34DEC4C40
15837	Жувам	7	65	1368	52.323604000000003	52.343673000000003	57.827584999999999	57.816062000000002	0103000020E610000001000000050000006A6D1ADB6B294A4012C138B874E84C406A6D1ADB6B294A4080D4264EEEE94C4055C2137AFD2B4A4080D4264EEEE94C4055C2137AFD2B4A4012C138B874E84C406A6D1ADB6B294A4012C138B874E84C40
15259	Ертем	7	65	1368	52.049430000000001	52.071078999999997	57.894098999999997	57.882458999999997	0103000020E610000001000000050000007CB8E4B853064A40CA87A06AF4F04C407CB8E4B853064A40723106D671F24C405837DE1D19094A40723106D671F24C405837DE1D19094A40CA87A06AF4F04C407CB8E4B853064A40CA87A06AF4F04C40
15634	Ежево	7	65	1368	52.217010000000002	52.234985999999999	58.038108000000001	58.019437000000003	0103000020E61000000100000005000000D673D2FBC61B4A408BAA5FE97C024D40D673D2FBC61B4A40A5DB12B9E0044D4049827005141E4A40A5DB12B9E0044D4049827005141E4A408BAA5FE97C024D40D673D2FBC61B4A408BAA5FE97C024D40
15346	Верхние Уни	7	65	1368	52.084418999999997	52.107630999999998	57.816757000000003	57.805332	0103000020E610000001000000050000009C14E63DCE0A4A400D36751E15E74C409C14E63DCE0A4A40B9E34D7E8BE84C40948444DAC60D4A40B9E34D7E8BE84C40948444DAC60D4A400D36751E15E74C409C14E63DCE0A4A400D36751E15E74C40
16001	Бадеро	7	65	1368	52.385292	52.404525	57.897567000000002	57.882252999999999	0103000020E6100000010000000500000089B48D3F51314A4021E692AAEDF04C4089B48D3F51314A40037CB779E3F24C400BB5A679C7334A40037CB779E3F24C400BB5A679C7334A4021E692AAEDF04C4089B48D3F51314A4021E692AAEDF04C40
14120	Шаркан	7	65	1271	53.849401999999998	53.888299000000004	57.320400999999997	57.279443000000001	0103000020E6100000010000000500000018946934B9EC4A404E0CC9C9C4A34C4018946934B9EC4A40874D64E602A94C40E60819C8B3F14A40874D64E602A94C40E60819C8B3F14A404E0CC9C9C4A34C4018946934B9EC4A404E0CC9C9C4A34C40
13718	Чужегово	7	65	1271	54.021653999999998	54.053319000000002	57.235332	57.215271999999999	0103000020E61000000100000005000000EEE9EA8EC5024B404CDF6B088E9B4C40EEE9EA8EC5024B40E4D9E55B1F9E4C40B2A03028D3064B40E4D9E55B1F9E4C40B2A03028D3064B404CDF6B088E9B4C40EEE9EA8EC5024B404CDF6B088E9B4C40
14692	Титово	7	65	1271	53.946356999999999	53.966344999999997	57.306052000000001	57.295276000000001	0103000020E610000001000000050000009BABE63922F94A4098A59D9ACBA54C409BABE63922F94A400D7041B62CA74C4099D36531B1FB4A400D7041B62CA74C4099D36531B1FB4A4098A59D9ACBA54C409BABE63922F94A4098A59D9ACBA54C40
14486	Сюрсовай	7	65	1271	53.648781	53.669325999999998	57.405748000000003	57.391941000000003	0103000020E6100000010000000500000012A27C410BD34A40147B681F2BB24C4012A27C410BD34A406E35EB8CEFB34C40662E7079ACD54A406E35EB8CEFB34C40662E7079ACD54A40147B681F2BB24C4012A27C410BD34A40147B681F2BB24C40
14479	Суроново	7	65	1271	53.512856999999997	53.527597999999998	57.332538999999997	57.319861000000003	0103000020E610000001000000050000002843554CA5C14A4008228B34F1A84C402843554CA5C14A4080D250A390AA4C40AEB7CD5488C34A4080D250A390AA4C40AEB7CD5488C34A4008228B34F1A84C402843554CA5C14A4008228B34F1A84C40
13255	Старые Быги	7	65	1271	53.748054000000003	53.770727000000001	57.223863000000001	57.211542999999999	0103000020E610000001000000050000002DD2C43BC0DF4A404F594DD7139B4C402DD2C43BC0DF4A4069E4F38AA79C4C407592AD2EA7E24A4069E4F38AA79C4C407592AD2EA7E24A404F594DD7139B4C402DD2C43BC0DF4A404F594DD7139B4C40
56412	СтароеЯгино	7	65	1271	53.757854999999999	53.777492000000002	57.353681000000002	57.340922999999997	0103000020E61000000100000005000000170E846401E14A4023BA675DA3AB4C40170E846401E14A40B91B446B45AD4C4069739CDB84E34A40B91B446B45AD4C4069739CDB84E34A4023BA675DA3AB4C40170E846401E14A4023BA675DA3AB4C40
14098	Сосновка	7	65	1271	53.497765000000001	53.544837000000001	57.268962000000002	57.247123000000002	0103000020E61000000100000005000000F60B76C3B6BF4A40728BF9B9A19F4C40F60B76C3B6BF4A40F2EEC8586DA24C404C530438BDC54A40F2EEC8586DA24C404C530438BDC54A40728BF9B9A19F4C40F60B76C3B6BF4A40728BF9B9A19F4C40
13814	Собино	7	65	1271	53.915024000000003	53.932971999999999	57.244999999999997	57.228112000000003	0103000020E610000001000000050000000E87A5811FF54A409FE925C6329D4C400E87A5811FF54A408FC2F5285C9F4C40B70A62A06BF74A408FC2F5285C9F4C40B70A62A06BF74A409FE925C6329D4C400E87A5811FF54A409FE925C6329D4C40
13261	Порозово	7	65	1271	53.944308999999997	53.971411000000003	57.285223000000002	57.264090000000003	0103000020E61000000100000005000000C328081EDFF84A40AF997CB3CDA14C40C328081EDFF84A409488F02F82A44C40C2FC153257FC4A409488F02F82A44C40C2FC153257FC4A40AF997CB3CDA14C40C328081EDFF84A40AF997CB3CDA14C40
14036	Пашур-Вишур	7	65	1271	53.654701000000003	53.682198	57.236510000000003	57.216504999999998	0103000020E610000001000000050000004AD40B3ECDD34A40D235936FB69B4C404AD40B3ECDD34A40A796ADF5459E4C40C4B2994352D74A40A796ADF5459E4C40C4B2994352D74A40D235936FB69B4C404AD40B3ECDD34A40D235936FB69B4C40
13626	Нижние Кивары	7	65	1271	54.076011000000001	54.101002000000001	57.332003999999998	57.314335	0103000020E6100000010000000500000071917BBABA094B407C7E18213CA84C4071917BBABA094B401212691B7FAA4C40516A2FA2ED0C4B401212691B7FAA4C40516A2FA2ED0C4B407C7E18213CA84C4071917BBABA094B407C7E18213CA84C40
58780	Нижние Быги	7	65	1271	53.729010000000002	53.744272000000002	57.204512999999999	57.192494000000003	0103000020E610000001000000050000007E3A1E3350DD4A408F56B5A4A3984C407E3A1E3350DD4A40AD4D637B2D9A4C400DAA0D4E44DF4A40AD4D637B2D9A4C400DAA0D4E44DF4A408F56B5A4A3984C407E3A1E3350DD4A408F56B5A4A3984C40
14409	Мувыр	7	65	1271	53.578730999999998	53.595250999999998	57.303027	57.286166000000001	0103000020E6100000010000000500000037177FDB13CA4A40139D6516A1A44C4037177FDB13CA4A400A67B796C9A64C40A5F44C2F31CC4A400A67B796C9A64C40A5F44C2F31CC4A40139D6516A1A44C4037177FDB13CA4A40139D6516A1A44C40
13817	Малый Казес	7	65	1271	53.841245000000001	53.863128000000003	57.216450999999999	57.206741000000001	0103000020E61000000100000005000000367689EAADEB4A4005DF347D769A4C40367689EAADEB4A40DF1797AAB49B4C40862172FA7AEE4A40DF1797AAB49B4C40862172FA7AEE4A4005DF347D769A4C40367689EAADEB4A4005DF347D769A4C40
14319	Кыква	7	65	1271	53.822083999999997	53.841802000000001	57.371462000000001	57.355142000000001	0103000020E610000001000000050000004D486B0C3AE94A40D0B7054B75AD4C404D486B0C3AE94A4077DA1A118CAF4C408CDAFD2AC0EB4A4077DA1A118CAF4C408CDAFD2AC0EB4A40D0B7054B75AD4C404D486B0C3AE94A40D0B7054B75AD4C40
14587	Кулак-Кучес	7	65	1271	53.587434999999999	53.612732000000001	57.355001000000001	57.343454000000001	0103000020E610000001000000050000004CC3F01131CB4A4017D7F84CF6AB4C404CC3F01131CB4A400E863AAC70AD4C40399B8E006ECE4A400E863AAC70AD4C40399B8E006ECE4A4017D7F84CF6AB4C404CC3F01131CB4A4017D7F84CF6AB4C40
13911	Козино	7	65	1271	54.022489	54.046007000000003	57.315005999999997	57.300454999999999	0103000020E6100000010000000500000087C267EBE0024B40B875374F75A64C4087C267EBE0024B409A05DA1D52A84C408C31B08EE3054B409A05DA1D52A84C408C31B08EE3054B40B875374F75A64C4087C267EBE0024B40B875374F75A64C40
13442	Кельдыш	7	65	1271	54.033088999999997	54.066237000000001	57.423372999999998	57.407691999999997	0103000020E61000000100000005000000BD6DA6423C044B40A06B5F402FB44C40BD6DA6423C044B403481221631B64C4080643A747A084B403481221631B64C4080643A747A084B40A06B5F402FB44C40BD6DA6423C044B40A06B5F402FB44C40
13654	Карсашур	7	65	1271	54.046196000000002	54.069471	57.282586000000002	57.264090000000003	0103000020E610000001000000050000005F9A22C0E9054B40AF997CB3CDA14C405F9A22C0E9054B405B272EC72BA44C409D82FC6CE4084B405B272EC72BA44C409D82FC6CE4084B40AF997CB3CDA14C405F9A22C0E9054B40AF997CB3CDA14C40
13443	Зюзино	7	65	1271	54.015383999999997	54.044929000000003	57.482691000000003	57.466071999999997	0103000020E61000000100000005000000DA70581AF8014B4068CA4E3FA8BB4C40DA70581AF8014B406A8995D1C8BD4C402DD2C43BC0054B406A8995D1C8BD4C402DD2C43BC0054B4068CA4E3FA8BB4C40DA70581AF8014B4068CA4E3FA8BB4C40
13936	Заречный Вишур	7	65	1271	53.561168000000002	53.595348999999999	57.202587999999999	57.188386999999999	0103000020E61000000100000005000000E7C75F5AD4C74A40EBFEB1101D984C40E7C75F5AD4C74A40F1475167EE994C40685A626534CC4A40F1475167EE994C40685A626534CC4A40EBFEB1101D984C40E7C75F5AD4C74A40EBFEB1101D984C40
14705	Вортчино	7	65	1271	53.710512999999999	53.730356999999998	57.313766000000001	57.297916999999998	0103000020E6100000010000000500000001310917F2DA4A4012F6ED2422A64C4001310917F2DA4A40624CFA7B29A84C40CCB392567CDD4A40624CFA7B29A84C40CCB392567CDD4A4012F6ED2422A64C4001310917F2DA4A4012F6ED2422A64C40
13372	Бородули	7	65	1271	54.149808	54.178545	57.444690000000001	57.432347	0103000020E61000000100000005000000EF5696E82C134B4009C3802557B74C40EF5696E82C134B40DB6D179AEBB84C40A2EE0390DA164B40DB6D179AEBB84C40A2EE0390DA164B4009C3802557B74C40EF5696E82C134B4009C3802557B74C40
14666	Большой Билиб	7	65	1271	53.965221999999997	53.984949	57.367986999999999	57.355423999999999	0103000020E610000001000000050000009AB0FD648CFB4A40541B9C887EAD4C409AB0FD648CFB4A40342DB1321AAF4C402C9D0FCF12FE4A40342DB1321AAF4C402C9D0FCF12FE4A40541B9C887EAD4C409AB0FD648CFB4A40541B9C887EAD4C40
13530	Байкей	7	65	1271	54.081006000000002	54.104694000000002	57.500714000000002	57.491509999999998	0103000020E61000000100000005000000D06394675E0A4B4017D4B7CCE9BE4C40D06394675E0A4B401E53776517C04C40310BED9C660D4B401E53776517C04C40310BED9C660D4B4017D4B7CCE9BE4C40D06394675E0A4B4017D4B7CCE9BE4C40
56367	Ижевск	7	65	7411	53.256073999999998	53.389311999999997	56.912655000000001	56.839433999999997	0103000020E610000001000000050000008EAD6708C7A04A404293C492726B4C408EAD6708C7A04A40F4C308E1D1744C405DF8C1F9D4B14A40F4C308E1D1744C405DF8C1F9D4B14A404293C492726B4C408EAD6708C7A04A404293C492726B4C40
11941	Чистостем	7	65	1195	52.208511999999999	52.233252	56.866101	56.856692000000002	0103000020E610000001000000050000006A696E85B01A4A40575F5D15A86D4C406A696E85B01A4A403604C765DC6E4C4001DD9733DB1D4A403604C765DC6E4C4001DD9733DB1D4A40575F5D15A86D4C406A696E85B01A4A40575F5D15A86D4C40
12460	Чекан	7	65	1195	52.647087999999997	52.674467999999997	57.121394000000002	57.106135999999999	0103000020E6100000010000000500000028D192C7D3524A40D1764CDD958D4C4028D192C7D3524A401FF7ADD6898F4C406919A9F754564A401FF7ADD6898F4C406919A9F754564A40D1764CDD958D4C4028D192C7D3524A40D1764CDD958D4C40
12754	Узей-Тукля	7	65	1195	52.135722000000001	52.158107999999999	57.060156999999997	57.048124000000001	0103000020E6100000010000000500000082ACA7565F114A408C135FED28864C4082ACA7565F114A400FD07D39B3874C40349E08E23C144A400FD07D39B3874C40349E08E23C144A408C135FED28864C4082ACA7565F114A408C135FED28864C40
12047	Ува-Тукля	7	65	1195	52.101685000000003	52.12567	56.980483	56.965344000000002	0103000020E6100000010000000500000034BF9A03040D4A40E6B16664907B4C4034BF9A03040D4A4059A48977807D4C404E0B5EF415104A4059A48977807D4C404E0B5EF415104A40E6B16664907B4C4034BF9A03040D4A40E6B16664907B4C40
12832	Ува	7	65	1195	52.151989999999998	52.211576000000001	57.011029000000001	56.964965999999997	0103000020E61000000100000005000000D6A8876874134A403FE08101847B4C40D6A8876874134A405F27F56569814C402B4F20EC141B4A405F27F56569814C402B4F20EC141B4A403FE08101847B4C40D6A8876874134A403FE08101847B4C40
12122	Сюровай	7	65	1195	52.004334	52.021428999999998	57.053421999999998	57.041823000000001	0103000020E6100000010000000500000064213A048E004A403D9CC0745A854C4064213A048E004A4086713788D6864C40CE177B2FBE024A4086713788D6864C40CE177B2FBE024A403D9CC0745A854C4064213A048E004A403D9CC0745A854C40
12089	Рябово	7	65	1195	52.056356000000001	52.099133000000002	56.932304999999999	56.902054	0103000020E61000000100000005000000797764AC36074A40ED9C668176734C40797764AC36074A40DA722EC555774C40297AE063B00C4A40DA722EC555774C40297AE063B00C4A40ED9C668176734C40797764AC36074A40ED9C668176734C40
12627	Пужмесь-Тукля	7	65	1195	52.439208999999998	52.460912	57.124926000000002	57.111459000000004	0103000020E61000000100000005000000EF8D210038384A4025ECDB49448E4C40EF8D210038384A40C6353E93FD8F4C40BF2A172AFF3A4A40C6353E93FD8F4C40BF2A172AFF3A4A4025ECDB49448E4C40EF8D210038384A4025ECDB49448E4C40
12182	Поршур-Тукля	7	65	1195	52.136611000000002	52.173262000000001	57.104948	57.084048000000003	0103000020E610000001000000050000000EA320787C114A40A9A5B915C28A4C400EA320787C114A40EBE3A1EF6E8D4C40DDD1FF722D164A40EBE3A1EF6E8D4C40DDD1FF722D164A40A9A5B915C28A4C400EA320787C114A40A9A5B915C28A4C40
11593	Петропавлово	7	65	1195	52.492595000000001	52.509708000000003	56.702134999999998	56.691018999999997	0103000020E6100000010000000500000029965B5A0D3F4A4012F5824F73584C4029965B5A0D3F4A404030478FDF594C403A419B1C3E414A404030478FDF594C403A419B1C3E414A4012F5824F73584C4029965B5A0D3F4A4012F5824F73584C40
12341	Пачегурт	7	65	1195	52.218502000000001	52.242486999999997	57.143360999999999	57.133803	0103000020E61000000100000005000000280EA0DFF71B4A40A88DEA7420914C40280EA0DFF71B4A40CC423BA759924C40425A63D0091F4A40CC423BA759924C40425A63D0091F4A40A88DEA7420914C40280EA0DFF71B4A40A88DEA7420914C40
12661	Областная	7	65	1195	52.568072000000001	52.596916999999998	56.997951	56.970005	0103000020E61000000100000005000000FCE25295B6484A406EFAB31F297C4C40FCE25295B6484A405801BEDBBC7F4C4095B6B8C6674C4A405801BEDBBC7F4C4095B6B8C6674C4A406EFAB31F297C4C40FCE25295B6484A406EFAB31F297C4C40
11758	Нылга	7	65	1195	52.330539000000002	52.390179000000003	56.775052000000002	56.748280999999999	0103000020E61000000100000005000000BA86191A4F2A4A40ED9BFBABC75F4C40BA86191A4F2A4A40865968E734634C40024BAE62F1314A40865968E734634C40024BAE62F1314A40ED9BFBABC75F4C40BA86191A4F2A4A40ED9BFBABC75F4C40
12258	Новый Мултан	7	65	1195	52.271906000000001	52.299259999999997	57.162712999999997	57.140234999999997	0103000020E6100000010000000500000008CBD8D0CD224A4095607138F3914C4008CBD8D0CD224A4028D192C7D3944C401F80D4264E264A4028D192C7D3944C401F80D4264E264A4095607138F3914C4008CBD8D0CD224A4095607138F3914C40
12546	Мушковай	7	65	1195	52.520614000000002	52.538570999999997	57.068970999999998	57.052824000000001	0103000020E610000001000000050000007DEBC37AA3424A40D238D4EFC2864C407DEBC37AA3424A40ABAFAE0AD4884C4079C9FFE4EF444A40ABAFAE0AD4884C4079C9FFE4EF444A40D238D4EFC2864C407DEBC37AA3424A40D238D4EFC2864C40
56411	Можга	7	65	1195	51.952322000000002	51.978067000000003	57.109259000000002	57.093228000000003	0103000020E6100000010000000500000073A1F2AFE5F94940278925E5EE8B4C4073A1F2AFE5F9494097E5EB32FC8D4C40FF25A94C31FD494097E5EB32FC8D4C40FF25A94C31FD4940278925E5EE8B4C4073A1F2AFE5F94940278925E5EE8B4C40
12441	Малые Сюрзи	7	65	1195	52.369131000000003	52.402943999999998	57.207135999999998	57.196195000000003	0103000020E610000001000000050000004B7842AF3F2F4A40C251F2EA1C994C404B7842AF3F2F4A4081E9B46E839A4C40490F43AB93334A4081E9B46E839A4C40490F43AB93334A40C251F2EA1C994C404B7842AF3F2F4A40C251F2EA1C994C40
11645	Лоллез-Жикья	7	65	1195	52.443843999999999	52.455863000000001	56.728228000000001	56.717450999999997	0103000020E610000001000000050000004E4354E1CF384A40C2BD326FD55B4C404E4354E1CF384A4008043A93365D4C406D3A02B8593A4A4008043A93365D4C406D3A02B8593A4A40C2BD326FD55B4C404E4354E1CF384A40C2BD326FD55B4C40
11844	Кыйлуд	7	65	1195	52.434690000000003	52.471089999999997	56.874429999999997	56.859650000000002	0103000020E61000000100000005000000FAF202ECA3374A40D200DE02096E4C40FAF202ECA3374A4015527E52ED6F4C407FBC57AD4C3C4A4015527E52ED6F4C407FBC57AD4C3C4A40D200DE02096E4C40FAF202ECA3374A40D200DE02096E4C40
11565	Кулябино	7	65	1195	52.295299	52.319284000000003	56.813048999999999	56.801912999999999	0103000020E6100000010000000500000050C58D5BCC254A405E9ECE15A5664C4050C58D5BCC254A40D38558FD11684C406B11514CDE284A40D38558FD11684C406B11514CDE284A405E9ECE15A5664C4050C58D5BCC254A405E9ECE15A5664C40
11669	Красное	7	65	1195	52.575609	52.596989000000001	56.751187999999999	56.724435	0103000020E610000001000000050000004224438EAD494A40F4893C49BA5C4C404224438EAD494A40E692AAED26604C402F89B3226A4C4A40E692AAED26604C402F89B3226A4C4A40F4893C49BA5C4C404224438EAD494A40F4893C49BA5C4C40
11964	Киби-Жикья	7	65	1195	52.144255999999999	52.164206999999998	56.887594999999997	56.872137000000002	0103000020E610000001000000050000003A2009FB76124A40D7506A2FA26F4C403A2009FB76124A40EB8B84B69C714C401B6327BC04154A40EB8B84B69C714C401B6327BC04154A40D7506A2FA26F4C403A2009FB76124A40D7506A2FA26F4C40
12523	Каркалай	7	65	1195	52.362231999999999	52.401246	56.989846	56.978937999999999	0103000020E6100000010000000500000047C8409E5D2E4A40E46723D74D7D4C4047C8409E5D2E4A40C8091346B37E4C404ED367075C334A40C8091346B37E4C404ED367075C334A40E46723D74D7D4C4047C8409E5D2E4A40E46723D74D7D4C40
12807	Возеншур	7	65	1195	52.09572	52.106355999999998	57.094763999999998	57.086064	0103000020E610000001000000050000005CC98E8D400C4A4075AE2825048B4C405CC98E8D400C4A40486B0C3A218C4C40DFDDCA129D0D4A40486B0C3A218C4C40DFDDCA129D0D4A4075AE2825048B4C405CC98E8D400C4A4075AE2825048B4C40
11868	Вишур	7	65	1195	52.473300000000002	52.491624999999999	56.915657000000003	56.902358999999997	0103000020E6100000010000000500000031992A18953C4A402920ED7F80734C4031992A18953C4A403FADA23F34754C40B0726891ED3E4A403FADA23F34754C40B0726891ED3E4A402920ED7F80734C4031992A18953C4A402920ED7F80734C40
25825	Булай	7	65	1195	52.305674000000003	52.335057999999997	56.687519000000002	56.674574999999997	0103000020E61000000100000005000000679E5C5320274A407FD93D7958564C40679E5C5320274A407730629F00584C40AF21382EE32A4A407730629F00584C40AF21382EE32A4A407FD93D7958564C40679E5C5320274A407FD93D7958564C40
11501	Большой Жужгес	7	65	1195	52.255521000000002	52.28716	56.722825	56.707935999999997	0103000020E610000001000000050000007A3881E9B4204A409DD497A59D5A4C407A3881E9B4204A4098DD9387855C4C40145CACA8C1244A4098DD9387855C4C40145CACA8C1244A409DD497A59D5A4C407A3881E9B4204A409DD497A59D5A4C40
56391	Сюрек	7	65	1128	51.4236	51.460394999999998	56.952784999999999	56.93674	0103000020E61000000100000005000000F54A598638B64940726DA818E7774C40F54A598638B64940478FDFDBF4794C40F71E2E39EEBA4940478FDFDBF4794C40F71E2E39EEBA4940726DA818E7774C40F54A598638B64940726DA818E7774C40
10389	Сюмси	7	65	1128	51.581361999999999	51.657297	57.124189000000001	57.098157	0103000020E610000001000000050000008E91EC116ACA4940CE6F9868908C4C408E91EC116ACA4940F0C2D66CE58F4C402461DF4E22D44940F0C2D66CE58F4C402461DF4E22D44940CE6F9868908C4C408E91EC116ACA4940CE6F9868908C4C40
20586	Правые Гайны	7	65	1128	51.735010000000003	51.761024999999997	57.080761000000003	57.069842000000001	0103000020E61000000100000005000000D21DC4CE14DE494091F12895F0884C40D21DC4CE14DE494069E55E60568A4C401D38674469E1494069E55E60568A4C401D38674469E1494091F12895F0884C40D21DC4CE14DE494091F12895F0884C40
22042	Пижил	7	65	1128	51.569423999999998	51.593381999999998	56.911343000000002	56.897978999999999	0103000020E610000001000000050000005CC7B8E2E2C8494055BFD2F9F0724C405CC7B8E2E2C8494022382EE3A6744C407D04FEF0F3CB494022382EE3A6744C407D04FEF0F3CB494055BFD2F9F0724C405CC7B8E2E2C8494055BFD2F9F0724C40
11120	Орловское	7	65	1128	51.427337000000001	51.442213000000002	57.120274999999999	57.110398000000004	0103000020E6100000010000000500000075AF93FAB2B649409CC58B85218E4C4075AF93FAB2B6494061C3D32B658F4C40DB6E826F9AB8494061C3D32B658F4C40DB6E826F9AB849409CC58B85218E4C4075AF93FAB2B649409CC58B85218E4C40
11097	Муки-Какси	7	65	1128	51.401879000000001	51.420904999999998	56.959454999999998	56.947670000000002	0103000020E610000001000000050000007FF964C570B349403EB324404D794C407FF964C570B34940E97DE36BCF7A4C4087DC0C37E0B54940E97DE36BCF7A4C4087DC0C37E0B549403EB324404D794C407FF964C570B349403EB324404D794C40
10654	Маркелово	7	65	1128	51.749509000000003	51.769936999999999	57.170985000000002	57.164411999999999	0103000020E61000000100000005000000628731E9EFDF4940F488D1730B954C40628731E9EFDF4940A48D23D6E2954C407C7DAD4B8DE24940A48D23D6E2954C407C7DAD4B8DE24940F488D1730B954C40628731E9EFDF4940F488D1730B954C40
58389	Лялино	7	65	1128	51.721949000000002	51.734668999999997	57.058483000000003	57.050029000000002	0103000020E61000000100000005000000A13028D368DC4940016DAB5967864C40A13028D368DC49409D2FF65E7C874C40483140A209DE49409D2FF65E7C874C40483140A209DE4940016DAB5967864C40A13028D368DC4940016DAB5967864C40
11284	Лесоучасток Ключевка	7	65	1128	51.516207999999999	51.532099000000002	57.347299999999997	57.339218000000002	0103000020E610000001000000050000007FF78E1A13C24940761BD47E6BAB4C407FF78E1A13C249404DF38E5374AC4C40FE9DEDD11BC449404DF38E5374AC4C40FE9DEDD11BC44940761BD47E6BAB4C407FF78E1A13C24940761BD47E6BAB4C40
10739	Лекшур	7	65	1128	51.830007000000002	51.869236999999998	57.152310999999997	57.137563999999998	0103000020E61000000100000005000000BD395CAB3DEA4940B08D78B29B914C40BD395CAB3DEA494018E945ED7E934C4090BC732843EF494018E945ED7E934C4090BC732843EF4940B08D78B29B914C40BD395CAB3DEA4940B08D78B29B914C40
11385	Кильмезь	7	65	1128	51.307304000000002	51.355265000000003	57.025188999999997	56.993749000000001	0103000020E610000001000000050000000AF7CABC55A7494063B7CF2A337F4C400AF7CABC55A74940069CA56439834C40EC34D25279AD4940069CA56439834C40EC34D25279AD494063B7CF2A337F4C400AF7CABC55A7494063B7CF2A337F4C40
11181	Зон	7	65	1128	51.349777000000003	51.368119999999998	57.184972999999999	57.176602000000003	0103000020E610000001000000050000004EF2237EC5AC49404034F3E49A964C404EF2237EC5AC49404ED2FC31AD974C407380608E1EAF49404ED2FC31AD974C407380608E1EAF49404034F3E49A964C404EF2237EC5AC49404034F3E49A964C40
58386	Гуртруд	7	65	1128	51.695466000000003	51.721553999999998	57.12753	57.114919	0103000020E610000001000000050000006FBDA60705D94940325871AAB58E4C406FBDA60705D9494023A12DE752904C402426A8E15BDC494023A12DE752904C402426A8E15BDC4940325871AAB58E4C406FBDA60705D94940325871AAB58E4C40
21908	Гура	7	65	1128	51.38738	51.411634999999997	57.293194999999997	57.279753999999997	0103000020E61000000100000005000000EF8FF7AA95B149406C76A4FACEA34C40EF8FF7AA95B14940E42CEC6987A54C40C971A774B0B44940E42CEC6987A54C40C971A774B0B449406C76A4FACEA34C40EF8FF7AA95B149406C76A4FACEA34C40
21996	Васькино	7	65	1128	51.557898000000002	51.583500000000001	57.040329	57.030700000000003	0103000020E610000001000000050000007D40A03369C749405DFE43FAED834C407D40A03369C749404A0A2C8029854C40A69BC420B0CA49404A0A2C8029854C40A69BC420B0CA49405DFE43FAED834C407D40A03369C749405DFE43FAED834C40
10932	Блаж-Юс	7	65	1128	51.575425000000003	51.590597000000002	56.980257999999999	56.968062000000003	0103000020E610000001000000050000008126C286A7C949400C40A374E97B4C408126C286A7C9494039D21918797D4C40D00EB8AE98CB494039D21918797D4C40D00EB8AE98CB49400C40A374E97B4C408126C286A7C949400C40A374E97B4C40
11456	Балма	7	65	1128	51.357880000000002	51.379161000000003	57.034565000000001	57.024870999999997	0103000020E610000001000000050000003DF20703CFAD494035CF11F92E834C403DF20703CFAD49400A4B3CA06C844C409775FF5888B049400A4B3CA06C844C409775FF5888B0494035CF11F92E834C403DF20703CFAD494035CF11F92E834C40
10212	Юмга-Омга	7	65	176	52.201335	52.234779000000003	57.249153	57.234361999999997	0103000020E6100000010000000500000024456458C5194A406BB6F292FF9D4C4024456458C5194A40A359D93EE49F4C40D064FF3C0D1E4A40A359D93EE49F4C40D064FF3C0D1E4A406BB6F292FF9D4C4024456458C5194A406BB6F292FF9D4C40
9784	Югдон	7	65	176	52.228400999999998	52.264864000000003	57.276435999999997	57.267116999999999	0103000020E61000000100000005000000D5AF743E3C1D4A40529ACDE330A24C40D5AF743E3C1D4A40F1B73D4162A34C40A2F14410E7214A40F1B73D4162A34C40A2F14410E7214A40529ACDE330A24C40D5AF743E3C1D4A40529ACDE330A24C40
9679	Халды	7	65	176	51.900973999999998	51.930753000000003	57.217323	57.197330999999998	0103000020E61000000100000005000000ED45B41D53F3494055BE672442994C40ED45B41D53F3494095D5743DD19B4C40B3D30FEA22F7494095D5743DD19B4C40B3D30FEA22F7494055BE672442994C40ED45B41D53F3494055BE672442994C40
56418	Уть-Сюмси	7	65	176	51.446075999999998	52.569563000000002	57.586995999999999	57.126299000000003	0103000020E61000000100000005000000E7C3B30419B949403E42CD902A904C40E7C3B30419B94940007157AF22CB4C407E01BD70E7484A40007157AF22CB4C407E01BD70E7484A403E42CD902A904C40E7C3B30419B949403E42CD902A904C40
10173	Узи	7	65	176	52.414828	52.447698000000003	57.363667	57.348771999999997	0103000020E6100000010000000500000088BB7A1519354A4058E1968FA4AC4C4088BB7A1519354A4035D1E7A38CAE4C40083E062B4E394A4035D1E7A38CAE4C40083E062B4E394A4058E1968FA4AC4C4088BB7A1519354A4058E1968FA4AC4C40
9991	Сюромошур	7	65	176	52.073442	52.097884999999998	57.235048999999997	57.225636999999999	0103000020E610000001000000050000009013268C66094A403FE257ACE19C4C409013268C66094A408FFAEB15169E4C406DE2E47E870C4A408FFAEB15169E4C406DE2E47E870C4A403FE257ACE19C4C409013268C66094A403FE257ACE19C4C40
555	Старые Копки	7	65	176	51.764457	51.774769999999997	57.370356000000001	57.364255	0103000020E6100000010000000500000061191BBAD9E14940C63368E89FAE4C4061191BBAD9E149404EF04DD367AF4C4001F6D1A92BE349404EF04DD367AF4C4001F6D1A92BE34940C63368E89FAE4C4061191BBAD9E14940C63368E89FAE4C40
10015	Селты	7	65	176	52.088991	52.151415	57.325750999999997	57.296477000000003	0103000020E61000000100000005000000B5519D0E640B4A40138255F5F2A54C40B5519D0E640B4A40D4D17135B2A94C40DA8F149161134A40D4D17135B2A94C40DA8F149161134A40138255F5F2A54C40B5519D0E640B4A40138255F5F2A54C40
58835	Рожки	7	65	176	52.340690000000002	52.364846	57.301519999999996	57.292864000000002	0103000020E610000001000000050000008109DCBA9B2B4A407F164B917CA54C408109DCBA9B2B4A40828B153598A64C40C8091346B32E4A40828B153598A64C40C8091346B32E4A407F164B917CA54C408109DCBA9B2B4A407F164B917CA54C40
9882	Новая Монья	7	65	176	52.151541000000002	52.166732000000003	57.199911	57.187334	0103000020E6100000010000000500000067800BB265134A40E5B67D8FFA974C4067800BB265134A402A8E03AF96994C402D99637957154A402A8E03AF96994C402D99637957154A40E5B67D8FFA974C4067800BB265134A40E5B67D8FFA974C40
10310	Мадьярово	7	65	176	52.137625999999997	52.158099	57.285237000000002	57.272956999999998	0103000020E61000000100000005000000268A90BA9D114A406D1B4641F0A24C40268A90BA9D114A40F94D61A582A44C40E14389963C144A40F94D61A582A44C40E14389963C144A406D1B4641F0A24C40268A90BA9D114A406D1B4641F0A24C40
9703	Копки	7	65	176	51.739592000000002	51.758581999999997	57.390152	57.371471999999997	0103000020E610000001000000050000000E315EF3AADE49409AB0FD648CAF4C400E315EF3AADE4940083C3080F0B14C40C9AA083719E14940083C3080F0B14C40C9AA083719E149409AB0FD648CAF4C400E315EF3AADE49409AB0FD648CAF4C40
9604	Колесур	7	65	176	52.239136000000002	52.266651000000003	57.322588000000003	57.313172999999999	0103000020E61000000100000005000000ECA529029C1E4A40BF7E880D16A84C40ECA529029C1E4A40810A47904AA94C400D39B69E21224A40810A47904AA94C400D39B69E21224A40BF7E880D16A84C40ECA529029C1E4A40BF7E880D16A84C40
9900	Гобгурт	7	65	176	52.048118000000002	52.068294000000002	57.161014999999999	57.151294999999998	0103000020E61000000100000005000000AA2C0ABB28064A402F8672A25D934C40AA2C0ABB28064A402D95B7239C944C40AB4198DBBD084A402D95B7239C944C40AB4198DBBD084A402F8672A25D934C40AA2C0ABB28064A402F8672A25D934C40
9557	Валамаз	7	65	176	52.050732000000004	52.077421000000001	57.461255999999999	57.450347000000001	0103000020E610000001000000050000002B6EDC627E064A40056D72F8A4B94C402B6EDC627E064A40B98AC56F0ABB4C4006836BEEE8094A40B98AC56F0ABB4C4006836BEEE8094A40056D72F8A4B94C402B6EDC627E064A40056D72F8A4B94C40
10096	Большой Кильмезь-Бия	7	65	176	52.031193999999999	52.053148999999998	57.270125	57.260039999999996	0103000020E610000001000000050000006CEA3C2AFE034A406FD39FFD48A14C406CEA3C2AFE034A407F6ABC7493A24C4055682096CD064A407F6ABC7493A24C4055682096CD064A406FD39FFD48A14C406CEA3C2AFE034A406FD39FFD48A14C40
8321	Юриха	7	65	131	53.708348000000001	53.733843	56.622340000000001	56.614677999999998	0103000020E61000000100000005000000F017B325ABDA4A400CC9C9C4AD4E4C40F017B325ABDA4A400F7F4DD6A84F4C4003B34291EEDD4A400F7F4DD6A84F4C4003B34291EEDD4A400CC9C9C4AD4E4C40F017B325ABDA4A400CC9C9C4AD4E4C40
8945	Юрино	7	65	131	53.363225	53.387963999999997	56.380178999999998	56.364077000000002	0103000020E61000000100000005000000780B24287EAE4A40E71C3C139A2E4C40780B24287EAE4A4020D099B4A9304C403E03EACDA8B14A4020D099B4A9304C403E03EACDA8B14A40E71C3C139A2E4C40780B24287EAE4A40E71C3C139A2E4C40
8688	Шевырялово	7	65	131	53.620601000000001	53.680715999999997	56.469183999999998	56.454946	0103000020E61000000100000005000000B56E83DA6FCF4A4017B9A7AB3B3A4C40B56E83DA6FCF4A403AE7A7380E3C4C4095EEAEB321D74A403AE7A7380E3C4C4095EEAEB321D74A4017B9A7AB3B3A4C40B56E83DA6FCF4A4017B9A7AB3B3A4C40
9038	Шадрино	7	65	131	53.572667000000003	53.600838000000003	56.288665999999999	56.272385	0103000020E61000000100000005000000CD3FFA264DC94A40E275FD82DD224C40CD3FFA264DC94A40CBBBEA01F3244C40D7187442E8CC4A40CBBBEA01F3244C40D7187442E8CC4A40E275FD82DD224C40CD3FFA264DC94A40E275FD82DD224C40
9320	Усть-Сарапулка	7	65	131	53.841092000000003	53.861817000000002	56.397669	56.387106000000003	0103000020E61000000100000005000000B07614E7A8EB4A40EE0A7DB08C314C40B07614E7A8EB4A4007D15AD1E6324C408411FB0450EE4A4007D15AD1E6324C408411FB0450EE4A40EE0A7DB08C314C40B07614E7A8EB4A40EE0A7DB08C314C40
284	Уральский	7	65	131	53.500568000000001	53.544522999999998	56.493535999999999	56.483804999999997	0103000020E610000001000000050000004AB6BA9C12C04A4015527E52ED3D4C404AB6BA9C12C04A4007B309302C3F4C40BC75FEEDB2C54A4007B309302C3F4C40BC75FEEDB2C54A4015527E52ED3D4C404AB6BA9C12C04A4015527E52ED3D4C40
9215	Тарасово	7	65	131	54.101505000000003	54.120063999999999	56.264952000000001	56.243385000000004	0103000020E61000000100000005000000B4B0A71DFE0C4B4022AB5B3D271F4C40B4B0A71DFE0C4B40418177F2E9214C40A6B6D4415E0F4B40418177F2E9214C40A6B6D4415E0F4B4022AB5B3D271F4C40B4B0A71DFE0C4B4022AB5B3D271F4C40
9294	Соколовка	7	65	131	54.011493999999999	54.031778000000003	56.280586	56.263376999999998	0103000020E61000000100000005000000D40CA9A278014B4061C26856B6214C40D40CA9A278014B4094DBF63DEA234C40BC5D2F4D11044B4094DBF63DEA234C40BC5D2F4D11044B4061C26856B6214C40D40CA9A278014B4061C26856B6214C40
9384	Сигаево	7	65	131	53.755248999999999	53.789628	56.430917999999998	56.413606999999999	0103000020E6100000010000000500000019ABCDFFABE04A40C632FD12F1344C4019ABCDFFABE04A40FDA02E5228374C40C100C28712E54A40FDA02E5228374C40C100C28712E54A40C632FD12F1344C4019ABCDFFABE04A40C632FD12F1344C40
8978	Пентеги	7	65	131	53.503003	53.522441999999998	56.285013999999997	56.273870000000002	0103000020E610000001000000050000001B65FD6662C04A4082AD122C0E234C401B65FD6662C04A407973B8567B244C4046072461DFC24A407973B8567B244C4046072461DFC24A4082AD122C0E234C401B65FD6662C04A4082AD122C0E234C40
9136	Оленье Болото	7	65	131	53.777591000000001	53.796267	56.338448999999997	56.322094999999997	0103000020E61000000100000005000000FC54151A88E34A40419AB1683A294C40FC54151A88E34A40942EFD4B522B4C4028F1B913ECE54A40942EFD4B522B4C4028F1B913ECE54A40419AB1683A294C40FC54151A88E34A40419AB1683A294C40
8314	Нечкино	7	65	131	53.744199999999999	53.774509000000002	56.657395000000001	56.636738999999999	0103000020E6100000010000000500000073D712F241DF4A403B8BDEA980514C4073D712F241DF4A40E7C6F48425544C4095BA641C23E34A40E7C6F48425544C4095BA641C23E34A403B8BDEA980514C4073D712F241DF4A403B8BDEA980514C40
9063	Мостовое	7	65	131	53.688189999999999	53.737157000000003	56.286012999999997	56.271481000000001	0103000020E6100000010000000500000095B7239C16D84A40213EB0E3BF224C4095B7239C16D84A408C9DF0129C244C403D821B295BDE4A408C9DF0129C244C403D821B295BDE4A40213EB0E3BF224C4095B7239C16D84A40213EB0E3BF224C40
9143	Мазунино	7	65	131	53.978876	54.011206000000001	56.330261	56.308191000000001	0103000020E610000001000000050000006E6B0BCF4BFD4A40F5F57CCD72274C406E6B0BCF4BFD4A40771211FE452A4C406EC2BD326F014B40771211FE452A4C406EC2BD326F014B40F5F57CCD72274C406E6B0BCF4BFD4A40F5F57CCD72274C40
8412	Лагуново	7	65	131	53.599103999999997	53.621741999999998	56.623488999999999	56.613173000000003	0103000020E610000001000000050000008E739B70AFCC4A4026E5EE737C4E4C408E739B70AFCC4A403735D07CCE4F4C405A46EA3D95CF4A403735D07CCE4F4C405A46EA3D95CF4A4026E5EE737C4E4C408E739B70AFCC4A4026E5EE737C4E4C40
9475	Костино	7	65	131	53.742952000000002	53.761474999999997	56.391680000000001	56.380408000000003	0103000020E61000000100000005000000B83F170D19DF4A4082919735B1304C40B83F170D19DF4A40A73FFB9122324C405DDC460378E14A40A73FFB9122324C405DDC460378E14A4082919735B1304C40B83F170D19DF4A4082919735B1304C40
8796	Кигбаево	7	65	131	53.616486999999999	53.650604999999999	56.369526	56.356951000000002	0103000020E610000001000000050000005FB4C70BE9CE4A4023A30392B02D4C405FB4C70BE9CE4A40C782C2A04C2F4C409ACE4E0647D34A40C782C2A04C2F4C409ACE4E0647D34A4023A30392B02D4C405FB4C70BE9CE4A4023A30392B02D4C40
8438	Дулесово	7	65	131	53.767871	53.785747000000001	56.557330999999998	56.542549999999999	0103000020E61000000100000005000000FE45D09849E24A40EF38454772454C40FE45D09849E24A400306499F56474C400EF7915B93E44A400306499F56474C400EF7915B93E44A40EF38454772454C40FE45D09849E24A40EF38454772454C40
8518	Девятово	7	65	131	53.635226000000003	53.658591000000001	56.548653999999999	56.536107999999999	0103000020E61000000100000005000000D2C8E7154FD14A40DE8FDB2F9F444C40D2C8E7154FD14A40E868554B3A464C405038BBB54CD44A40E868554B3A464C405038BBB54CD44A40DE8FDB2F9F444C40D2C8E7154FD14A40DE8FDB2F9F444C40
56401	Выезд	7	65	131	53.315147000000003	54.198829000000003	56.759207000000004	56.170600999999998	0103000020E610000001000000050000005D37A5BC56A84A401BD5E940D6154C405D37A5BC56A84A4078F2E9B12D614C408A3F8A3A73194B4078F2E9B12D614C408A3F8A3A73194B401BD5E940D6154C405D37A5BC56A84A401BD5E940D6154C40
56400	Яромаска	7	65	1005	53.812390999999998	53.830455999999998	56.520628000000002	56.502445000000002	0103000020E610000001000000050000004948A46DFCE74A40F584251E50404C404948A46DFCE74A40E2B034F0A3424C402C62D8614CEA4A40E2B034F0A3424C402C62D8614CEA4A40F584251E50404C404948A46DFCE74A40F584251E50404C40
8709	Северный	7	65	1005	53.730266999999998	53.749752000000001	56.467970999999999	56.459029000000001	0103000020E610000001000000050000008C2C996379DD4A4032755776C13A4C408C2C996379DD4A40FB3C4679E63B4C40280EA0DFF7DF4A40FB3C4679E63B4C40280EA0DFF7DF4A4032755776C13A4C408C2C996379DD4A4032755776C13A4C40
56369	Ижевск	7	65	7412	53.054034000000001	53.232402999999998	56.987746999999999	56.843895000000003	0103000020E61000000100000005000000A06F0B96EA864A40042159C0046C4C40A06F0B96EA864A406EDC627E6E7E4C40033FAA61BF9D4A406EDC627E6E7E4C40033FAA61BF9D4A40042159C0046C4C40A06F0B96EA864A40042159C0046C4C40
56398	д.Залесный	7	65	847	51.837077000000001	52.731619000000002	56.717796	56.184094999999999	0103000020E61000000100000005000000ED9DD15625EB4940B62DCA6C90174C40ED9DD15625EB49408D9944BDE05B4C40ED10FFB0A55D4A408D9944BDE05B4C40ED10FFB0A55D4A40B62DCA6C90174C40ED9DD15625EB4940B62DCA6C90174C40
6971	Черемушки	7	65	847	52.347006	52.364029000000002	56.449607999999998	56.439373000000003	0103000020E6100000010000000500000005C24EB16A2C4A406ADFDC5F3D384C4005C24EB16A2C4A408E0244C18C394C40D6E59480982E4A408E0244C18C394C40D6E59480982E4A406ADFDC5F3D384C4005C24EB16A2C4A406ADFDC5F3D384C40
7348	Трактор	7	65	847	52.329830000000001	52.350527	56.327640000000002	56.319429	0103000020E61000000100000005000000AE9E93DE372A4A406E32AA0CE3284C40AE9E93DE372A4A40446E861BF0294C40B8AE9811DE2C4A40446E861BF0294C40B8AE9811DE2C4A406E32AA0CE3284C40AE9E93DE372A4A406E32AA0CE3284C40
7188	Старый Березняк	7	65	847	52.429372000000001	52.457183999999998	56.338509000000002	56.325578999999998	0103000020E61000000100000005000000B8E864A9F5364A40D7A19A92AC294C40B8E864A9F5364A406A334E43542B4C4092205C01853A4A406A334E43542B4C4092205C01853A4A40D7A19A92AC294C40B8E864A9F5364A40D7A19A92AC294C40
7406	Старые Юбери	7	65	847	52.295712000000002	52.320936000000003	56.300665000000002	56.283594999999998	0103000020E6100000010000000500000073840CE4D9254A40912749D74C244C4073840CE4D9254A40A306D3307C264C40F60D4C6E14294A40A306D3307C264C40F60D4C6E14294A40912749D74C244C4073840CE4D9254A40912749D74C244C40
7478	Старые Какси	7	65	847	52.248775000000002	52.265807000000002	56.270600999999999	56.259433000000001	0103000020E61000000100000005000000FD87F4DBD71F4A406840BD1935214C40FD87F4DBD71F4A40E8A1B60DA3224C402106BAF605224A40E8A1B60DA3224C402106BAF605224A406840BD1935214C40FD87F4DBD71F4A406840BD1935214C40
7898	Сардан	7	65	847	52.060209	52.071879000000003	56.419522999999998	56.406984000000001	0103000020E6100000010000000500000062F6B2EDB4074A4065FF3C0D18344C4062F6B2EDB4074A40BC75FEEDB2354C407522C15433094A40BC75FEEDB2354C407522C15433094A4065FF3C0D18344C4062F6B2EDB4074A4065FF3C0D18344C40
6685	Русский Пычас	7	65	847	52.502206999999999	52.527639000000001	56.662149999999997	56.645985000000003	0103000020E610000001000000050000004069A85148404A40715AF0A2AF524C404069A85148404A40F085C954C1544C400D8CBCAC89434A40F085C954C1544C400D8CBCAC89434A40715AF0A2AF524C404069A85148404A40715AF0A2AF524C40
6720	Пычас	7	65	847	52.415466000000002	52.466104000000001	56.515354000000002	56.491340000000001	0103000020E61000000100000005000000CB4C69FD2D354A40BB9BA73AE43E4C40CB4C69FD2D354A4070EEAF1EF7414C407444BE4BA93B4A4070EEAF1EF7414C407444BE4BA93B4A40BB9BA73AE43E4C40CB4C69FD2D354A40BB9BA73AE43E4C40
7620	Поршур	7	65	847	52.010891999999998	52.041884000000003	56.324680999999998	56.310682	0103000020E61000000100000005000000DEE4B7E864014A405ABA826DC4274C40DEE4B7E864014A40F850A2258F294C40E31C75745C054A40F850A2258F294C40E31C75745C054A405ABA826DC4274C40DEE4B7E864014A405ABA826DC4274C40
8116	Пазял	7	65	847	52.153976	52.193033999999997	56.631039999999999	56.615917000000003	0103000020E61000000100000005000000382F4E7CB5134A407506465ED64E4C40382F4E7CB5134A40E23B31EBC5504C400E828E56B5184A40E23B31EBC5504C400E828E56B5184A407506465ED64E4C40382F4E7CB5134A407506465ED64E4C40
7562	Ныша	7	65	847	52.066740000000003	52.107191	56.355440000000002	56.341816999999999	0103000020E61000000100000005000000E3AAB2EF8A084A40C11BD2A8C02B4C40E3AAB2EF8A084A405AD8D30E7F2D4C4078B6476FB80D4A405AD8D30E7F2D4C4078B6476FB80D4A40C11BD2A8C02B4C40E3AAB2EF8A084A40C11BD2A8C02B4C40
7537	Нынек	7	65	847	51.939790000000002	51.959876999999999	56.228706000000003	56.215978999999997	0103000020E61000000100000005000000CE8DE9094BF84940B7CF2A33A51B4C40CE8DE9094BF849401233FB3C461D4C405F97E13FDDFA49401233FB3C461D4C405F97E13FDDFA4940B7CF2A33A51B4C40CE8DE9094BF84940B7CF2A33A51B4C40
7822	Новый Русский Сюгаил	7	65	847	52.112966999999998	52.127538000000001	56.425924999999999	56.417700000000004	0103000020E610000001000000050000007C43E1B3750E4A4005C58F3177354C407C43E1B3750E4A403FC6DCB584364C40A67F492A53104A403FC6DCB584364C40A67F492A53104A4005C58F3177354C407C43E1B3750E4A4005C58F3177354C40
6812	Новая Бия	7	65	847	52.471305000000001	52.493251000000001	56.506264999999999	56.495061999999997	0103000020E610000001000000050000007CB8E4B8533C4A4005BF0D315E3F4C407CB8E4B8533C4A40020EA14ACD404C4012DC48D9223F4A40020EA14ACD404C4012DC48D9223F4A4005BF0D315E3F4C407CB8E4B8533C4A4005BF0D315E3F4C40
7275	Нижний Вишур	7	65	847	52.280000000000001	52.319122	56.412770999999999	56.395710999999999	0103000020E61000000100000005000000A4703D0AD7234A406FD575A8A6324C40A4703D0AD7234A405DDE1CAED5344C4091B75CFDD8284A405DDE1CAED5344C4091B75CFDD8284A406FD575A8A6324C40A4703D0AD7234A406FD575A8A6324C40
7282	Можга	7	65	847	52.245972000000002	52.274583	56.381230000000002	56.369366999999997	0103000020E61000000100000005000000A9DDAF027C1F4A405E9CF86A472F4C40A9DDAF027C1F4A4086200725CC304C40CF84268925234A4086200725CC304C40CF84268925234A405E9CF86A472F4C40A9DDAF027C1F4A405E9CF86A472F4C40
6616	Мельниково	7	65	847	52.500518999999997	52.539613000000003	56.589587000000002	56.579177000000001	0103000020E610000001000000050000006803B00111404A4036CCD078224A4C406803B00111404A40C9923996774B4C408CBFED0912454A40C9923996774B4C408CBFED0912454A4036CCD078224A4C406803B00111404A4036CCD078224A4C40
8023	Малая Сюга	7	65	847	52.173146000000003	52.197812999999996	56.513770000000001	56.503751000000001	0103000020E6100000010000000500000074B7EBA529164A40E529ABE97A404C4074B7EBA529164A403DD52137C3414C40A0DCB6EF51194A403DD52137C3414C40A0DCB6EF51194A40E529ABE97A404C4074B7EBA529164A40E529ABE97A404C40
8103	Малая Воложикья	7	65	847	52.276792999999998	52.309024999999998	56.625450000000001	56.614569000000003	0103000020E610000001000000050000008061F9F36D234A4056116E32AA4E4C408061F9F36D234A4040A4DFBE0E504C40BD5296218E274A4040A4DFBE0E504C40BD5296218E274A4056116E32AA4E4C408061F9F36D234A4056116E32AA4E4C40
56381	Люга	7	65	847	51.939008999999999	51.955286000000001	56.436357000000001	56.424664999999997	0103000020E6100000010000000500000028D3687231F84940BF60376C5B364C4028D3687231F84940BA30D28BDA374C40D029C8CF46FA4940BA30D28BDA374C40D029C8CF46FA4940BF60376C5B364C4028D3687231F84940BF60376C5B364C40
8220	Ломеслуд	7	65	847	52.129460999999999	52.154316999999999	56.683548999999999	56.674000999999997	0103000020E61000000100000005000000C18D942D92104A40533C2EAA45564C40C18D942D92104A40541B9C887E574C40C11BD2A8C0134A40541B9C887E574C40C11BD2A8C0134A40533C2EAA45564C40C18D942D92104A40533C2EAA45564C40
7653	Комяк	7	65	847	51.960819999999998	51.995081999999996	56.332621000000003	56.317517000000002	0103000020E61000000100000005000000DEAB5626FCFA49404776A565A4284C40DEAB5626FCFA49403E7B2E53932A4C404C6BD3D85EFF49403E7B2E53932A4C404C6BD3D85EFF49404776A565A4284C40DEAB5626FCFA49404776A565A4284C40
56415	Керамик	7	65	847	52.30359	52.319814000000001	56.467602999999997	56.460591000000001	0103000020E6100000010000000500000042B28009DC264A407DEA58A5F43A4C4042B28009DC264A407841446ADA3B4C40C76647AAEF284A407841446ADA3B4C40C76647AAEF284A407DEA58A5F43A4C4042B28009DC264A407DEA58A5F43A4C40
7150	Кватчи	7	65	847	52.357039999999998	52.418636999999997	56.405569	56.393932	0103000020E6100000010000000500000092AE997CB32D4A40876C205D6C324C4092AE997CB32D4A40BEA25BAFE9334C40A1F2AFE595354A40BEA25BAFE9334C40A1F2AFE595354A40876C205D6C324C4092AE997CB32D4A40876C205D6C324C40
6294	Горняк	7	65	847	52.416193999999997	52.438715000000002	56.456144999999999	56.446981000000001	0103000020E610000001000000050000004D6551D845354A40797764AC36394C404D6551D845354A40F19D98F5623A4C40E0A128D027384A40F19D98F5623A4C40E0A128D027384A40797764AC36394C404D6551D845354A40797764AC36394C40
7113	Верхние Юри	7	65	847	52.542020999999998	52.586945999999998	56.440702000000002	56.41536	0103000020E61000000100000005000000635FB2F160454A40850838842A354C40635FB2F160454A4012A452EC68384C404E42E90B214B4A4012A452EC68384C404E42E90B214B4A40850838842A354C40635FB2F160454A40850838842A354C40
7460	Большие Сибы	7	65	847	52.226019999999998	52.271250999999999	56.339810999999997	56.328015000000001	0103000020E61000000100000005000000F71E2E39EE1C4A4079CC4065FC294C40F71E2E39EE1C4A4018E945ED7E2B4C40EF004F5AB8224A4018E945ED7E2B4C40EF004F5AB8224A4079CC4065FC294C40F71E2E39EE1C4A4079CC4065FC294C40
8195	Большая Уча	7	65	847	52.052923999999997	52.100884999999998	56.620111999999999	56.598318999999996	0103000020E610000001000000050000003596B036C6064A40A7C98CB7954C4C403596B036C6064A40B7ED7BD45F4F4C4017D4B7CCE90C4A40B7ED7BD45F4F4C4017D4B7CCE90C4A40A7C98CB7954C4C403596B036C6064A40A7C98CB7954C4C40
7930	Большая Пудга	7	65	847	52.099277000000001	52.121015999999997	56.492905	56.481791999999999	0103000020E610000001000000050000005C1FD61BB50C4A40BABC395CAB3D4C405C1FD61BB50C4A407784D382173F4C407825C9737D0F4A407784D382173F4C407825C9737D0F4A40BABC395CAB3D4C405C1FD61BB50C4A40BABC395CAB3D4C40
7073	Большая Кибья	7	65	847	52.580441999999998	52.623471000000002	56.375109999999999	56.364730000000002	0103000020E61000000100000005000000C79C67EC4B4A4A405FEFFE78AF2E4C40C79C67EC4B4A4A408733BF9A03304C409180D1E5CD4F4A408733BF9A03304C409180D1E5CD4F4A405FEFFE78AF2E4C40C79C67EC4B4A4A405FEFFE78AF2E4C40
6899	Бальзяшур	7	65	847	52.564937	52.580728999999998	56.503548000000002	56.493485999999997	0103000020E6100000010000000500000072A609DB4F484A4055849B8C2A3F4C4072A609DB4F484A40ADFBC74274404C405D6BEF53554A4A40ADFBC74274404C405D6BEF53554A4A4055849B8C2A3F4C4072A609DB4F484A4055849B8C2A3F4C40
5212	Яган-Докья	7	65	634	53.210600999999997	53.253611999999997	56.592199000000001	56.573867	0103000020E61000000100000005000000A0C03BF9F49A4A4077A04E7974494C40A0C03BF9F49A4A40A9DC442DCD4B4C40C3EFA65B76A04A40A9DC442DCD4B4C40C3EFA65B76A04A4077A04E7974494C40A0C03BF9F49A4A4077A04E7974494C40
4794	Яган	7	65	634	53.096156000000001	53.133794999999999	56.569378999999998	56.551085	0103000020E6100000010000000500000037A8FDD64E8C4A4078280AF489464C4037A8FDD64E8C4A40BC033C69E1484C4025AFCE3120914A40BC033C69E1484C4025AFCE3120914A4078280AF489464C4037A8FDD64E8C4A4078280AF489464C40
5552	Уром	7	65	634	52.713957999999998	52.747430000000001	56.575200000000002	56.555242	0103000020E61000000100000005000000D95BCAF9625B4A40CDAE7B2B12474C40D95BCAF9625B4A4061545227A0494C404F0647C9AB5F4A4061545227A0494C404F0647C9AB5F4A40CDAE7B2B12474C40D95BCAF9625B4A40CDAE7B2B12474C40
6260	Сырьезшур	7	65	634	52.627783000000001	52.646934999999999	56.493068999999998	56.482652000000002	0103000020E610000001000000050000000DFE7E315B504A40ACAC6D8AC73D4C400DFE7E315B504A40F1D58EE21C3F4C40A2D11DC4CE524A40F1D58EE21C3F4C40A2D11DC4CE524A40ACAC6D8AC73D4C400DFE7E315B504A40ACAC6D8AC73D4C40
5061	Сундуково	7	65	634	53.302534999999999	53.329797999999997	56.529817999999999	56.517122000000001	0103000020E610000001000000050000009B728577B9A64A406405BF0D31424C409B728577B9A64A40836A8313D1434C40A22424D236AA4A40836A8313D1434C40A22424D236AA4A406405BF0D31424C409B728577B9A64A406405BF0D31424C40
6517	Старая Монья	7	65	634	52.867193	52.909683000000001	56.447971000000003	56.432177000000003	0103000020E61000000100000005000000FA28232E006F4A40AD8A709351374C40FA28232E006F4A4039471D1D57394C40145D177E70744A4039471D1D57394C40145D177E70744A40AD8A709351374C40FA28232E006F4A40AD8A709351374C40
4857	Среднее Кечево	7	65	634	53.200629999999997	53.221803000000001	56.533923999999999	56.522191999999997	0103000020E61000000100000005000000594C6C3EAE994A40CD1DFD2FD7424C40594C6C3EAE994A405646239F57444C40CD936B0A649C4A405646239F57444C40CD936B0A649C4A40CD1DFD2FD7424C40594C6C3EAE994A40CD1DFD2FD7424C40
5871	Сизяшур	7	65	634	52.672311999999998	52.691589999999998	56.646737000000002	56.635773	0103000020E61000000100000005000000AB5AD2510E564A400457790261514C40AB5AD2510E564A407C0E2C47C8524C40CD1E680586584A407C0E2C47C8524C40CD1E680586584A400457790261514C40AB5AD2510E564A400457790261514C40
5318	Пуро-Можга	7	65	634	53.390228	53.413547999999999	56.559612999999999	56.543652000000002	0103000020E61000000100000005000000E3FDB8FDF2B14A40D733846396454C40E3FDB8FDF2B14A404EB51666A1474C40C1A90F24EFB44A404EB51666A1474C40C1A90F24EFB44A40D733846396454C40E3FDB8FDF2B14A40D733846396454C40
4695	Пугачево	7	65	634	53.053494999999998	53.087307000000003	56.625638000000002	56.589160999999997	0103000020E61000000100000005000000F0BF95ECD8864A40118AADA0694B4C40F0BF95ECD8864A404391EEE714504C401FDB32E02C8B4A404391EEE714504C401FDB32E02C8B4A40118AADA0694B4C40F0BF95ECD8864A40118AADA0694B4C40
5957	Норья	7	65	634	52.682814	52.724899999999998	56.677784000000003	56.663227999999997	0103000020E610000001000000050000001FA0FB7266574A404FE5B4A7E4544C401FA0FB7266574A4044E048A0C1564C40696FF085C95C4A4044E048A0C1564C40696FF085C95C4A404FE5B4A7E4544C401FA0FB7266574A404FE5B4A7E4544C40
6488	Новая Монья	7	65	634	52.778556000000002	52.801903000000003	56.431539999999998	56.416296000000003	0103000020E61000000100000005000000630D17B9A7634A4052BAF42F49354C40630D17B9A7634A403A75E5B33C374C403BC8EBC1A4664A403A75E5B33C374C403BC8EBC1A4664A4052BAF42F49354C40630D17B9A7634A4052BAF42F49354C40
6411	Нижние Юри	7	65	634	52.705927000000003	52.735689000000001	56.418064000000001	56.401001999999998	0103000020E61000000100000005000000842EE1D05B5A4A40B7D0950854334C40842EE1D05B5A4A4046D1031F83354C407383A10E2B5E4A4046D1031F83354C407383A10E2B5E4A40B7D0950854334C40842EE1D05B5A4A40B7D0950854334C40
4581	Миндерево	7	65	634	53.001105000000003	53.014704999999999	56.579906000000001	56.570003999999997	0103000020E61000000100000005000000596E693524804A406A4B1DE4F5484C40596E693524804A4089601C5C3A4A4C40390B7BDAE1814A4089601C5C3A4A4C40390B7BDAE1814A406A4B1DE4F5484C40596E693524804A406A4B1DE4F5484C40
4188	Малая Пурга	7	65	634	52.964229000000003	53.018065	56.562677999999998	56.544659000000003	0103000020E610000001000000050000006A6D1ADB6B7B4A406D3CD862B7454C406A6D1ADB6B7B4A40DF162CD505484C40E31934F44F824A40DF162CD505484C40E31934F44F824A406D3CD862B7454C406A6D1ADB6B7B4A406D3CD862B7454C40
4457	Малая Бодья	7	65	634	53.043909999999997	53.071353000000002	56.569577000000002	56.561715999999997	0103000020E61000000100000005000000D2FBC6D79E854A40E9D1544FE6474C40D2FBC6D79E854A40E3C62DE6E7484C405ABC581822894A40E3C62DE6E7484C405ABC581822894A40E9D1544FE6474C40D2FBC6D79E854A40E9D1544FE6474C40
4142	Курчум-Норья	7	65	634	52.965809999999998	52.982500999999999	56.608218999999998	56.597803999999996	0103000020E610000001000000050000002B137EA99F7B4A4080B56AD7844C4C402B137EA99F7B4A4025E7C41EDA4D4C40C6A4BF97C27D4A4025E7C41EDA4D4C40C6A4BF97C27D4A4080B56AD7844C4C402B137EA99F7B4A4080B56AD7844C4C40
5397	Курегово	7	65	634	52.894466000000001	52.911434999999997	56.543835000000001	56.532722	0103000020E6100000010000000500000025B1A4DC7D724A400BEE073C30444C4025B1A4DC7D724A40C8B5A1629C454C4002B7EEE6A9744A40C8B5A1629C454C4002B7EEE6A9744A400BEE073C30444C4025B1A4DC7D724A400BEE073C30444C40
5989	Кулаево	7	65	634	52.741483000000002	52.762180000000001	56.655298000000002	56.646414999999998	0103000020E610000001000000050000001EC539EAE85E4A4069520ABABD524C401EC539EAE85E4A402E910BCEE0534C4028D53E1D8F614A402E910BCEE0534C4028D53E1D8F614A4069520ABABD524C401EC539EAE85E4A4069520ABABD524C40
4409	Кечур	7	65	634	52.873435999999998	52.894312999999997	56.612473999999999	56.604067000000001	0103000020E61000000100000005000000149337C0CC6F4A40E2CB4411524D4C40149337C0CC6F4A403DD34B8C654E4C409EB12FD978724A403DD34B8C654E4C409EB12FD978724A40E2CB4411524D4C40149337C0CC6F4A40E2CB4411524D4C40
4950	Кечево	7	65	634	53.202049000000002	53.229376000000002	56.516719999999999	56.504313000000003	0103000020E610000001000000050000004298DBBDDC994A404DF910548D404C404298DBBDDC994A40359886E123424C40603E59315C9D4A40359886E123424C40603E59315C9D4A404DF910548D404C404298DBBDDC994A404DF910548D404C40
5629	Карашур	7	65	634	52.711030000000001	52.733604	56.518920000000001	56.504958999999999	0103000020E61000000100000005000000C93CF207035B4A4012691B7FA2404C40C93CF207035B4A40C39E76F86B424C407E1B62BCE65D4A40C39E76F86B424C407E1B62BCE65D4A4012691B7FA2404C40C93CF207035B4A4012691B7FA2404C40
6073	Капустино	7	65	634	52.732553000000003	52.765251999999997	56.708770999999999	56.696570000000001	0103000020E6100000010000000500000019CBF44BC45D4A40F7AFAC3429594C4019CBF44BC45D4A4036AD1402B95A4C406B990CC7F3614A4036AD1402B95A4C406B990CC7F3614A40F7AFAC3429594C4019CBF44BC45D4A40F7AFAC3429594C40
6607	Итешево	7	65	634	52.892947999999997	52.912441000000001	56.425691	56.415847999999997	0103000020E61000000100000005000000A983BC1E4C724A40B20DDC813A354C40A983BC1E4C724A40CC99ED0A7D364C40C843DFDDCA744A40CC99ED0A7D364C40C843DFDDCA744A40B20DDC813A354C40A983BC1E4C724A40B20DDC813A354C40
5799	Ильинское	7	65	634	52.770237999999999	52.796216999999999	56.489566000000003	56.477766000000003	0103000020E610000001000000050000007711A62897624A400492B06F273D4C407711A62897624A40E59D4319AA3E4C4076C24B70EA654A40E59D4319AA3E4C4076C24B70EA654A400492B06F273D4C407711A62897624A400492B06F273D4C40
6104	Иваново-Самарское	7	65	634	52.772852	52.804931000000003	56.703657	56.689624999999999	0103000020E61000000100000005000000F85278D0EC624A4083C0CAA145584C40F85278D0EC624A40FD4CBD6E115A4C40AF44A0FA07674A40FD4CBD6E115A4C40AF44A0FA07674A4083C0CAA145584C40F85278D0EC624A4083C0CAA145584C40
6175	Гужношур	7	65	634	52.713689000000002	52.729616	56.477313000000002	56.462226999999999	0103000020E61000000100000005000000EA4141295A5B4A40022A1C412A3B4C40EA4141295A5B4A40537AA697183D4C40B5519D0E645D4A40537AA697183D4C40B5519D0E645D4A40022A1C412A3B4C40EA4141295A5B4A40022A1C412A3B4C40
5475	Гожня	7	65	634	52.832725000000003	52.874091999999997	56.552618000000002	56.530707	0103000020E61000000100000005000000E3C798BB966A4A400F61FC34EE434C40E3C798BB966A4A402997C62FBC464C40FDD8243FE26F4A402997C62FBC464C40FDD8243FE26F4A400F61FC34EE434C40E3C798BB966A4A400F61FC34EE434C40
4966	Верхнее Кечево	7	65	634	53.210932999999997	53.230445000000003	56.501609999999999	56.491529	0103000020E61000000100000005000000D65240DAFF9A4A408E041A6CEA3E4C40D65240DAFF9A4A405CACA8C134404C406C43C5387F9D4A405CACA8C134404C406C43C5387F9D4A408E041A6CEA3E4C40D65240DAFF9A4A408E041A6CEA3E4C40
4882	Валион	7	65	634	53.161194000000002	53.180678	56.512473999999997	56.5062	0103000020E61000000100000005000000DD274701A2944A401B9E5E29CB404C40DD274701A2944A4070067FBF98414C40A88DEA7420974A4070067FBF98414C40A88DEA7420974A401B9E5E29CB404C40DD274701A2944A401B9E5E29CB404C40
5235	Бураново	7	65	634	53.316521000000002	53.343381000000001	56.595196999999999	56.581428000000002	0103000020E61000000100000005000000A5BF97C283A84A40467D923B6C4A4C40A5BF97C283A84A40B2D6506A2F4C4C40AD889AE8F3AB4A40B2D6506A2F4C4C40AD889AE8F3AB4A40467D923B6C4A4C40A5BF97C283A84A40467D923B6C4A4C40
6191	Бобья-Уча	7	65	634	52.673552000000001	52.710275000000003	56.493720000000003	56.477179	0103000020E61000000100000005000000E413B2F336564A4043AB9333143D4C40E413B2F336564A40C9B08A37323F4C404D158C4AEA5A4A40C9B08A37323F4C404D158C4AEA5A4A4043AB9333143D4C40E413B2F336564A4043AB9333143D4C40
5141	Байситово	7	65	634	53.307349000000002	53.329349000000001	56.472574999999999	56.463461000000002	0103000020E61000000100000005000000AABA473657A74A4059FCA6B0523B4C40AABA473657A74A401FF46C567D3C4C4033FCA71B28AA4A401FF46C567D3C4C4033FCA71B28AA4A4059FCA6B0523B4C40AABA473657A74A4059FCA6B0523B4C40
5720	Бажаново	7	65	634	52.783838000000003	52.800772000000002	56.528174999999997	56.517018	0103000020E6100000010000000500000058AEB7CD54644A40BFB854A52D424C4058AEB7CD54644A404BC8073D9B434C40B9C667B27F664A404BC8073D9B434C40B9C667B27F664A40BFB854A52D424C4058AEB7CD54644A40BFB854A52D424C40
5518	Алганча-Игра	7	65	634	52.810544999999998	52.833981999999999	56.573529000000001	56.563234000000001	0103000020E61000000100000005000000D97745F0BF674A4065FF3C0D18484C40D97745F0BF674A405F27F56569494C40F1B913ECBF6A4A405F27F56569494C40F1B913ECBF6A4A4065FF3C0D18484C40D97745F0BF674A4065FF3C0D18484C40
5106	Аксакшур	7	65	634	53.179591000000002	53.206755999999999	56.452742000000001	56.432594999999999	0103000020E61000000100000005000000F6D37FD6FC964A40E1B4E0455F374C40F6D37FD6FC964A4048C32973F3394C403A2009FB769A4A4048C32973F3394C403A2009FB769A4A40E1B4E0455F374C40F6D37FD6FC964A40E1B4E0455F374C40
56373	Агрыз-Бигра	7	65	634	52.924514000000002	52.952784000000001	56.525385	56.511350999999998	0103000020E61000000100000005000000DA58897956764A4071E316F373414C40DA58897956764A408C67D0D03F434C4077137CD3F4794A408C67D0D03F434C4077137CD3F4794A4071E316F373414C40DA58897956764A4071E316F373414C40
5869	Абдэс-Урдэс	7	65	634	52.822268000000001	52.845354999999998	56.495528999999998	56.485698999999997	0103000020E610000001000000050000000F46EC1340694A40965984622B3E4C400F46EC1340694A401B9C887E6D3F4C404A41B797346C4A401B9C887E6D3F4C404A41B797346C4A40965984622B3E4C400F46EC1340694A40965984622B3E4C40
40326	Ижевск	7	65	6899	53.100692000000002	53.391072000000001	56.961770999999999	56.778869999999998	0103000020E61000000100000005000000037CB779E38C4A40F2EA1C03B2634C40037CB779E38C4A40E09EE74F1B7B4C40CF30B5A50EB24A40E09EE74F1B7B4C40CF30B5A50EB24A40F2EA1C03B2634C40037CB779E38C4A40F2EA1C03B2634C40
3861	Мухино	7	65	510	52.224026000000002	52.247059	57.744235000000003	57.729883999999998	0103000020E6100000010000000500000013BA4BE2AC1C4A40D4EFC2D66CDD4C4013BA4BE2AC1C4A40F0C4AC1743DF4C405B971AA19F1F4A40F0C4AC1743DF4C405B971AA19F1F4A40D4EFC2D66CDD4C4013BA4BE2AC1C4A40D4EFC2D66CDD4C40
3812	Малягурт	7	65	510	52.536577000000001	52.553555000000003	57.665211999999997	57.650517000000001	0103000020E6100000010000000500000095641D8EAE444A40FB3E1C2444D34C4095641D8EAE444A401074B4AA25D54C40C6C4E6E3DA464A401074B4AA25D54C40C6C4E6E3DA464A40FB3E1C2444D34C4095641D8EAE444A40FB3E1C2444D34C40
3761	Курья	7	65	510	52.051963000000001	52.094515999999999	57.718122999999999	57.705309999999997	0103000020E6100000010000000500000010CD3CB9A6064A4058C51B9947DA4C4010CD3CB9A6064A40B1C05774EBDB4C407079AC19190C4A40B1C05774EBDB4C407079AC19190C4A4058C51B9947DA4C4010CD3CB9A6064A4058C51B9947DA4C40
3123	Красногорское	7	65	510	52.468386000000002	52.521377999999999	57.716858999999999	57.695264000000002	0103000020E61000000100000005000000BFF38B12F43B4A40070B2769FED84C40BFF38B12F43B4A40F06B2409C2DB4C404C6DA983BC424A40F06B2409C2DB4C404C6DA983BC424A40070B2769FED84C40BFF38B12F43B4A40070B2769FED84C40
3667	Кокман	7	65	510	52.355477	52.381886999999999	57.582548000000003	57.565781000000001	0103000020E6100000010000000500000077BD3445802D4A405ED905836BC84C4077BD3445802D4A40D42CD0EE90CA4C403FE257ACE1304A40D42CD0EE90CA4C403FE257ACE1304A405ED905836BC84C4077BD3445802D4A405ED905836BC84C40
3575	Дебы	7	65	510	52.481392999999997	52.497725000000003	57.837857999999997	57.818421000000001	0103000020E61000000100000005000000FCC22B499E3D4A4008AEF204C2E84C40FCC22B499E3D4A40925852EE3EEB4C4068B3EA73B53F4A40925852EE3EEB4C4068B3EA73B53F4A4008AEF204C2E84C40FCC22B499E3D4A4008AEF204C2E84C40
3509	Васильевское	7	65	510	52.281734	52.30659	57.729716000000003	57.714739000000002	0103000020E61000000100000005000000EC1516DC0F244A407F164B917CDB4C40EC1516DC0F244A4019AF795567DD4C40ECA353573E274A4019AF795567DD4C40ECA353573E274A407F164B917CDB4C40EC1516DC0F244A407F164B917CDB4C40
3458	Валамаз	7	65	510	52.072794999999999	52.114324000000003	57.553446000000001	57.532626999999998	0103000020E61000000100000005000000FA27B85851094A40B9FB1C1F2DC44C40FA27B85851094A400F0D8B51D7C64C40EF92382BA20E4A400F0D8B51D7C64C40EF92382BA20E4A40B9FB1C1F2DC44C40FA27B85851094A40B9FB1C1F2DC44C40
3970	Большой Селег	7	65	510	51.911349999999999	51.9375	57.668408999999997	57.651605000000004	0103000020E61000000100000005000000D49AE61DA7F449407E74EACA67D34C40D49AE61DA7F4494010AD156D8ED54C400000000000F8494010AD156D8ED54C400000000000F849407E74EACA67D34C40D49AE61DA7F449407E74EACA67D34C40
3406	Бараны	7	65	510	52.734665	52.757060000000003	57.792386999999998	57.780138000000001	0103000020E610000001000000050000000742B280095E4A40F52EDE8FDBE34C400742B280095E4A404563EDEF6CE54C400D8E9257E7604A404563EDEF6CE54C400D8E9257E7604A40F52EDE8FDBE34C400742B280095E4A40F52EDE8FDBE34C40
3339	Багыр	7	65	510	52.542577999999999	52.570821000000002	57.773760000000003	57.759400999999997	0103000020E61000000100000005000000B9C3263273454A405CC64D0D34E14C40B9C3263273454A40FB7953910AE34C405D6F9BA910494A40FB7953910AE34C405D6F9BA910494A405CC64D0D34E14C40B9C3263273454A405CC64D0D34E14C40
3281	Архангельское	7	65	510	52.663608000000004	52.695084999999999	57.793418000000003	57.781021000000003	0103000020E6100000010000000500000097AE601BF1544A409F3E027FF8E34C4097AE601BF1544A40640795B88EE54C405778978BF8584A40640795B88EE54C405778978BF8584A409F3E027FF8E34C4097AE601BF1544A409F3E027FF8E34C40
3233	Артык	7	65	510	52.338569999999997	52.374045000000002	57.736961999999998	57.722185000000003	0103000020E610000001000000050000000FB40243562B4A40B554DE8E70DC4C400FB40243562B4A40873254C554DE4C40BD1DE1B4E02F4A40873254C554DE4C40BD1DE1B4E02F4A40B554DE8E70DC4C400FB40243562B4A40B554DE8E70DC4C40
2248	Яжбахтино	7	65	369	53.259945000000002	53.277031000000001	56.404837000000001	56.382128000000002	0103000020E610000001000000050000001EE1B4E045A14A406571FF91E9304C401EE1B4E045A14A40FA9AE5B2D1334C40357D76C075A34A40FA9AE5B2D1334C40357D76C075A34A406571FF91E9304C401EE1B4E045A14A406571FF91E9304C40
2552	Чувашайка	7	65	369	53.193820000000002	53.217123000000001	56.250501999999997	56.23415	0103000020E61000000100000005000000C6A70018CF984A40E02D90A0F81D4C40C6A70018CF984A4092CA147310204C40CE1ABCAFCA9B4A4092CA147310204C40CE1ABCAFCA9B4A40E02D90A0F81D4C40C6A70018CF984A40E02D90A0F81D4C40
2750	Тавзямал	7	65	369	53.059271000000003	53.077525000000001	56.221899999999998	56.208669999999998	0103000020E61000000100000005000000F54C2F3196874A4002D4D4B2B51A4C40F54C2F3196874A40BF7D1D38671C4C40ABCFD556EC894A40BF7D1D38671C4C40ABCFD556EC894A4002D4D4B2B51A4C40F54C2F3196874A4002D4D4B2B51A4C40
2887	Старая Салья	7	65	369	53.171712999999997	53.191018	56.185080999999997	56.166581000000001	0103000020E6100000010000000500000026A60BB1FA954A404791B58652154C4026A60BB1FA954A40340EF5BBB0174C4042791F4773984A40340EF5BBB0174C4042791F4773984A404791B58652154C4026A60BB1FA954A404791B58652154C40
1893	Подгорное	7	65	369	53.017983999999998	53.042211999999999	56.391694999999999	56.376584999999999	0103000020E61000000100000005000000F6ECB94C4D824A400395F1EF33304C40F6ECB94C4D824A40DC80CF0F23324C40D7BFEB3367854A40DC80CF0F23324C40D7BFEB3367854A400395F1EF33304C40F6ECB94C4D824A400395F1EF33304C40
2140	Первомайский	7	65	369	53.225729000000001	53.250422999999998	56.380611999999999	56.368035999999996	0103000020E61000000100000005000000206118B0E49C4A4015E0BBCD1B2F4C40206118B0E49C4A408A3BDEE4B7304C40469561DC0DA04A408A3BDEE4B7304C40469561DC0DA04A4015E0BBCD1B2F4C40206118B0E49C4A4015E0BBCD1B2F4C40
3001	Нижняя Малая Салья	7	65	369	53.256334000000003	53.272773000000001	56.187475999999997	56.175462000000003	0103000020E610000001000000050000002B6D718DCFA04A406BD8EF8975164C402B6D718DCFA04A407764AC36FF174C40AC1DC539EAA24A407764AC36FF174C40AC1DC539EAA24A406BD8EF8975164C402B6D718DCFA04A406BD8EF8975164C40
2706	Мушак	7	65	369	53.035905999999997	53.080219	56.246386000000001	56.228304999999999	0103000020E6100000010000000500000076DD5B9198844A40B3412619391D4C4076DD5B9198844A409C189293891F4C4048C2BE9D448A4A409C189293891F4C4048C2BE9D448A4A40B3412619391D4C4076DD5B9198844A40B3412619391D4C40
2318	Лутоха	7	65	369	53.284928000000001	53.300370000000001	56.306866999999997	56.297542999999997	0103000020E610000001000000050000007BDB4C8578A44A40AD1397E315264C407BDB4C8578A44A405E9CF86A47274C408A592F8672A64A405E9CF86A47274C408A592F8672A64A40AD1397E315264C407BDB4C8578A44A40AD1397E315264C40
1949	Киясово	7	65	369	53.106217000000001	53.142589000000001	56.355220000000003	56.333508999999999	0103000020E61000000100000005000000BEA3C684988D4A40F9F5436CB02A4C40BEA3C684988D4A404C7155D9772D4C407AE2395B40924A404C7155D9772D4C407AE2395B40924A40F9F5436CB02A4C40BEA3C684988D4A40F9F5436CB02A4C40
2604	Карамас-Пельга	7	65	369	53.057626999999997	53.083157	56.316369000000002	56.295574999999999	0103000020E61000000100000005000000EC2E505260874A40F241CF66D5254C40EC2E505260874A40EF3B86C77E284C407CB779E3A48A4A40EF3B86C77E284C407CB779E3A48A4A40F241CF66D5254C40EC2E505260874A40F241CF66D5254C40
2367	Калашур	7	65	369	53.344009999999997	53.361283999999998	56.303975999999999	56.289520000000003	0103000020E610000001000000050000009CBF098508AC4A40DBC4C9FD0E254C409CBF098508AC4A406B6281AFE8264C40B648DA8D3EAE4A406B6281AFE8264C40B648DA8D3EAE4A40DBC4C9FD0E254C409CBF098508AC4A40DBC4C9FD0E254C40
3068	Кады-Салья	7	65	369	53.306702999999999	53.328144999999999	56.122926	56.113712	0103000020E61000000100000005000000E44A3D0B42A74A40D594641D8E0E4C40E44A3D0B42A74A40FFE9060ABC0F4C4047ACC5A700AA4A40FFE9060ABC0F4C4047ACC5A700AA4A40D594641D8E0E4C40E44A3D0B42A74A40D594641D8E0E4C40
2472	Ильдибаево	7	65	369	53.235826000000003	53.263314000000001	56.27375	56.255107000000002	0103000020E61000000100000005000000F4C5DE8B2F9E4A4087FD9E58A7204C40F4C5DE8B2F9E4A40D7A3703D0A234C401B4AED45B4A14A40D7A3703D0A234C401B4AED45B4A14A4087FD9E58A7204C40F4C5DE8B2F9E4A4087FD9E58A7204C40
2808	Ермолаево	7	65	369	53.246308999999997	53.276249999999997	56.150429000000003	56.133015999999998	0103000020E61000000100000005000000F0DAA50D879F4A4020EC14AB06114C40F0DAA50D879F4A405CAFE94141134C408FC2F5285CA34A405CAFE94141134C408FC2F5285CA34A4020EC14AB06114C40F0DAA50D879F4A4020EC14AB06114C40
2429	Дубровский	7	65	369	53.330122000000003	53.350746999999998	56.271850000000001	56.262217	0103000020E6100000010000000500000056D80C7041AA4A4045BA9F5390214C4056D80C7041AA4A4074B515FBCB224C40C6151747E5AC4A4074B515FBCB224C40C6151747E5AC4A4045BA9F5390214C4056D80C7041AA4A4045BA9F5390214C40
2950	Верхняя Малая Салья	7	65	369	53.251680999999998	53.265416000000002	56.169623999999999	56.158299999999997	0103000020E610000001000000050000002503401537A04A40787AA52C43144C402503401537A04A40F04E3E3DB6154C40E6EAC726F9A14A40F04E3E3DB6154C40E6EAC726F9A14A40787AA52C43144C402503401537A04A40787AA52C43144C40
2664	Байсары	7	65	369	53.052380999999997	53.062379	56.284959000000001	56.278108000000003	0103000020E6100000010000000500000044F7AC6BB4864A40C460FE0A99234C4044F7AC6BB4864A40B6D9588979244C40857AFA08FC874A40B6D9588979244C40857AFA08FC874A40C460FE0A99234C4044F7AC6BB4864A40C460FE0A99234C40
2079	Атабаево	7	65	369	53.109324999999998	53.136291999999997	56.445000999999998	56.425437000000002	0103000020E610000001000000050000004ED1915CFE8D4A4012C138B874364C404ED1915CFE8D4A40F9D7F2CAF5384C406C5A290472914A40F9D7F2CAF5384C406C5A290472914A4012C138B874364C404ED1915CFE8D4A4012C138B874364C40
2207	Аксарино	7	65	369	53.163601	53.181576	56.400064999999998	56.391038000000002	0103000020E61000000100000005000000E44BA8E0F0944A4023BF7E880D324C40E44BA8E0F0944A401AA3755435334C4087DEE2E13D974A401AA3755435334C4087DEE2E13D974A4023BF7E880D324C40E44BA8E0F0944A4023BF7E880D324C40
1232	Ягул	7	65	61	51.570349	51.593390999999997	56.359059999999999	56.335999000000001	0103000020E6100000010000000500000035272F3201C949408E3EE603022B4C4035272F3201C94940A0A696ADF52D4C40D05E7D3CF4CB4940A0A696ADF52D4C40D05E7D3CF4CB49408E3EE603022B4C4035272F3201C949408E3EE603022B4C40
233	Удмуртский Сарамак	7	65	61	51.547963000000003	51.570053000000001	56.037398000000003	56.022030999999998	0103000020E610000001000000050000008335CEA623C64940C43F6CE9D1024C408335CEA623C64940C9772975C9044C404CFE277FF7C84940C9772975C9044C404CFE277FF7C84940C43F6CE9D1024C408335CEA623C64940C43F6CE9D1024C40
32398	Старый Кармыж	7	65	61	51.821904000000004	51.846617000000002	56.184846	56.173693	0103000020E61000000100000005000000CE39782634E94940A6457D923B164C40CE39782634E94940F165A208A9174C406B9E23F25DEC4940F165A208A9174C406B9E23F25DEC4940A6457D923B164C40CE39782634E94940A6457D923B164C40
497	Старый Аргабаш	7	65	61	51.628622999999997	51.648287000000003	56.175536999999998	56.162080000000003	0103000020E61000000100000005000000B741EDB776D04940F8AA9509BF144C40B741EDB776D04940751E15FF77164C4003B68311FBD24940751E15FF77164C4003B68311FBD24940F8AA9509BF144C40B741EDB776D04940F8AA9509BF144C40
910	Старая Бодья	7	65	61	51.336481999999997	51.360494000000003	56.364919999999998	56.351021000000003	0103000020E61000000100000005000000A9D898D711AB4940C89A9141EE2C4C40A9D898D711AB494002D4D4B2B52E4C40BE33DAAA24AE494002D4D4B2B52E4C40BE33DAAA24AE4940C89A9141EE2C4C40A9D898D711AB4940C89A9141EE2C4C40
1363	Синяр-Бодья	7	65	61	51.390542000000003	51.406585999999997	56.340834000000001	56.326827000000002	0103000020E6100000010000000500000073DBBE47FDB1494093399677D5294C4073DBBE47FDB14940B4AED172A02B4C40778192020BB44940B4AED172A02B4C40778192020BB4494093399677D5294C4073DBBE47FDB1494093399677D5294C40
49997	Саркуз	7	65	61	51.688172000000002	51.712012999999999	56.371406	56.357255000000002	0103000020E61000000100000005000000EF02250516D849408FAA2688BA2D4C40EF02250516D84940E3C4573B8A2F4C40D6A9F23D23DB4940E3C4573B8A2F4C40D6A9F23D23DB49408FAA2688BA2D4C40EF02250516D849408FAA2688BA2D4C40
672	Русская Коса	7	65	61	51.489455999999997	51.520671999999998	56.562157999999997	56.539884999999998	0103000020E610000001000000050000005D6A847EA6BE4940EC4CA1F31A454C405D6A847EA6BE4940A69718CBF4474C40B1F84D61A5C24940A69718CBF4474C40B1F84D61A5C24940EC4CA1F31A454C405D6A847EA6BE4940EC4CA1F31A454C40
719	Муркозь-Омга	7	65	61	51.321489	51.346094000000001	56.596559999999997	56.583609000000003	0103000020E610000001000000050000000A83328D26A949405D5320B3B34A4C400A83328D26A94940060DFD135C4C4C40C1ABE5CE4CAC4940060DFD135C4C4C40C1ABE5CE4CAC49405D5320B3B34A4C400A83328D26A949405D5320B3B34A4C40
353	Крымская Слудка	7	65	61	51.418094000000004	51.440182999999998	56.005142999999997	55.991737000000001	0103000020E61000000100000005000000B153AC1A84B54940D89DEE3CF1FE4B40B153AC1A84B54940D3669C86A8004C40A9A0A2EA57B84940D3669C86A8004C40A9A0A2EA57B84940D89DEE3CF1FE4B40B153AC1A84B54940D89DEE3CF1FE4B40
852	Короленко	7	65	61	51.757468000000003	51.782145	56.428578000000002	56.414234999999998	0103000020E610000001000000050000001EE21FB6F4E04940E5ED08A705354C401EE21FB6F4E049407EE4D6A4DB364C406EDDCD531DE449407EE4D6A4DB364C406EDDCD531DE44940E5ED08A705354C401EE21FB6F4E04940E5ED08A705354C40
1252	Кизнер	7	65	61	51.501142999999999	51.532629	56.322969000000001	56.305314000000003	0103000020E6100000010000000500000046CF2D7425C049406781768714274C4046CF2D7425C04940984F560C57294C405AF3E32F2DC44940984F560C57294C405AF3E32F2DC449406781768714274C4046CF2D7425C049406781768714274C40
1448	Кизнер	7	65	61	51.490479999999998	51.548420999999998	56.301673999999998	56.266407000000001	0103000020E61000000100000005000000C9AB730CC8BE49407636E49F19224C40C9AB730CC8BE4940D906EE409D264C4045B8C9A832C64940D906EE409D264C4045B8C9A832C649407636E49F19224C40C9AB730CC8BE49407636E49F19224C40
990	Кибья	7	65	61	51.398097	51.419756	56.420234999999998	56.409125000000003	0103000020E610000001000000050000005FD1ADD7F4B24940EE7C3F355E344C405FD1ADD7F4B2494039D1AE42CA354C405F268A90BAB5494039D1AE42CA354C405F268A90BAB54940EE7C3F355E344C405FD1ADD7F4B24940EE7C3F355E344C40
597	Гыбдан	7	65	61	51.603361999999997	51.645932999999999	56.567459999999997	56.551864000000002	0103000020E6100000010000000500000017D34CF73ACD49407DEBC37AA3464C4017D34CF73ACD4940E2E47E87A2484C401E34BBEEADD24940E2E47E87A2484C401E34BBEEADD249407DEBC37AA3464C4017D34CF73ACD49407DEBC37AA3464C40
983	Вичурка	7	65	61	51.304259000000002	51.318829999999998	56.397055999999999	56.379714999999997	0103000020E61000000100000005000000C0417BF5F1A649407B6649809A304C40C0417BF5F1A649401D5723BBD2324C40E97DE36BCFA849401D5723BBD2324C40E97DE36BCFA849407B6649809A304C40C0417BF5F1A649407B6649809A304C40
32493	Верхняя Тыжма	7	65	61	51.759920999999999	51.780735	56.306432999999998	56.298622000000002	0103000020E610000001000000050000009545611745E14940DDEEE53E39264C409545611745E1494024B5503239274C40D9EBDD1FEFE3494024B5503239274C40D9EBDD1FEFE34940DDEEE53E39264C409545611745E14940DDEEE53E39264C40
32424	Верхний Бемыж	7	65	61	51.702015000000003	51.726520999999998	56.231808000000001	56.223931999999998	0103000020E610000001000000050000009626A5A0DBD949409143C4CDA91C4C409626A5A0DBD94940C07971E2AB1D4C40B96DDFA3FEDC4940C07971E2AB1D4C40B96DDFA3FEDC49409143C4CDA91C4C409626A5A0DBD949409143C4CDA91C4C40
160	Бемыж	7	65	61	51.707998000000003	51.736941999999999	56.165362999999999	56.129800000000003	0103000020E6100000010000000500000014D1AFAD9FDA4940AA8251499D104C4014D1AFAD9FDA4940F67B629D2A154C4040868E1D54DE4940F67B629D2A154C4040868E1D54DE4940AA8251499D104C4014D1AFAD9FDA4940AA8251499D104C40
1103	Безменшур	7	65	61	51.263052999999999	51.289760000000001	56.467111000000003	56.452454000000003	0103000020E61000000100000005000000AE0E80B8ABA14940E2783E03EA394C40AE0E80B8ABA149400A4D124BCA3B4C4030D80DDB16A549400A4D124BCA3B4C4030D80DDB16A54940E2783E03EA394C40AE0E80B8ABA14940E2783E03EA394C40
433	Балдейка	7	65	61	51.516603000000003	51.543399999999998	56.211924000000003	56.198891000000003	0103000020E61000000100000005000000FC010F0C20C24940003CA24275194C40FC010F0C20C24940679E5C53201B4C40BD5296218EC54940679E5C53201B4C40BD5296218EC54940003CA24275194C40FC010F0C20C24940003CA24275194C40
74	Айдуан-Чабья	7	65	61	51.659695999999997	51.685468	56.211258000000001	56.202630999999997	0103000020E61000000100000005000000A8A624EB70D44940F01307D0EF194C40A8A624EB70D449405A828C800A1B4C402E3A596ABDD749405A828C800A1B4C402E3A596ABDD74940F01307D0EF194C40A8A624EB70D44940F01307D0EF194C40
31005	Юски	7	65	1658	53.762804000000003	53.785845999999999	57.941060999999998	57.923667999999999	0103000020E6100000010000000500000006A1BC8FA3E14A404D2EC6C03AF64C4006A1BC8FA3E14A404145D5AF74F84C40A1D80A9A96E44A404145D5AF74F84C40A1D80A9A96E44A404D2EC6C03AF64C4006A1BC8FA3E14A404D2EC6C03AF64C40
31829	Юрук	7	65	1658	53.412443000000003	53.433985	57.813549999999999	57.804755999999998	0103000020E61000000100000005000000693BA6EECAB44A4040A19E3E02E74C40693BA6EECAB44A4095D4096822E84C402FFA0AD28CB74A4095D4096822E84C402FFA0AD28CB74A4040A19E3E02E74C40693BA6EECAB44A4040A19E3E02E74C40
30919	Ю-Чабья	7	65	1658	53.759515999999998	53.778390000000002	57.986001000000002	57.978499999999997	0103000020E61000000100000005000000F564FED137E14A406891ED7C3FFD4C40F564FED137E14A406269E04735FE4C4048C49448A2E34A406269E04735FE4C4048C49448A2E34A406891ED7C3FFD4C40F564FED137E14A406891ED7C3FFD4C40
30852	Ю-Тольен	7	65	1658	53.781489000000001	53.813181999999998	58.035778000000001	58.027763	0103000020E610000001000000050000008597E0D407E44A40F984ECBC8D034D408597E0D407E44A4049F59D5F94044D4012D9075916E84A4049F59D5F94044D4012D9075916E84A40F984ECBC8D034D408597E0D407E44A40F984ECBC8D034D40
31722	Чепца	7	65	1658	53.372647999999998	53.428460000000001	57.899546999999998	57.876179999999998	0103000020E61000000100000005000000BC75FEEDB2AF4A4063B48EAA26F04C40BC75FEEDB2AF4A40821B295B24F34C4074D2FBC6D7B64A40821B295B24F34C4074D2FBC6D7B64A4063B48EAA26F04C40BC75FEEDB2AF4A4063B48EAA26F04C40
30963	Филинцы	7	65	1658	53.928400000000003	53.945701	57.983300999999997	57.973979999999997	0103000020E610000001000000050000009FCDAACFD5F64A40A27A6B60ABFC4C409FCDAACFD5F64A40E28FA2CEDCFD4C40B265F9BA0CF94A40E28FA2CEDCFD4C40B265F9BA0CF94A40A27A6B60ABFC4C409FCDAACFD5F64A40A27A6B60ABFC4C40
31276	Удмурт-Зязьгор	7	65	1658	53.845844999999997	53.869138	57.867933000000001	57.856285	0103000020E61000000100000005000000183E22A644EC4A40168733BF9AED4C40183E22A644EC4A40410FB56D18EF4C40FDDAFAE93FEF4A40410FB56D18EF4C40FDDAFAE93FEF4A40168733BF9AED4C40183E22A644EC4A40168733BF9AED4C40
31239	Тортым	7	65	1658	53.923378	53.958205999999997	57.818655999999997	57.808318999999997	0103000020E6100000010000000500000046EC134031F64A4022DE3AFF76E74C4046EC134031F64A404B5645B8C9E84C405D6A847EA6FA4A404B5645B8C9E84C405D6A847EA6FA4A4022DE3AFF76E74C4046EC134031F64A4022DE3AFF76E74C40
30665	Тимены	7	65	1658	53.489761000000001	53.507809000000002	58.260359000000001	58.248430999999997	0103000020E610000001000000050000009AED0A7DB0BE4A4002284696CC1F4D409AED0A7DB0BE4A40111C977153214D40A7CEA3E2FFC04A40111C977153214D40A7CEA3E2FFC04A4002284696CC1F4D409AED0A7DB0BE4A4002284696CC1F4D40
31519	Сыга 2	7	65	1658	53.580886	53.598754	57.910646	57.903655000000001	0103000020E61000000100000005000000255AF2785ACA4A40F6EE8FF7AAF34C40255AF2785ACA4A40DA1D520C90F44C40B22C98F8A3CC4A40DA1D520C90F44C40B22C98F8A3CC4A40F6EE8FF7AAF34C40255AF2785ACA4A40F6EE8FF7AAF34C40
30603	Степаненки	7	65	1658	53.746940000000002	53.758195999999998	58.221083999999998	58.217300999999999	0103000020E610000001000000050000008109DCBA9BDF4A40AD31E884D01B4D408109DCBA9BDF4A409DD5027B4C1C4D40A0FA07910CE14A409DD5027B4C1C4D40A0FA07910CE14A40AD31E884D01B4D408109DCBA9BDF4A40AD31E884D01B4D40
31461	Стеньгурт	7	65	1658	53.601260000000003	53.629153000000002	57.854221000000003	57.837192000000002	0103000020E610000001000000050000004D327216F6CC4A40863C821B29EB4C404D327216F6CC4A4039471D1D57ED4C401497E31588D04A4039471D1D57ED4C401497E31588D04A40863C821B29EB4C404D327216F6CC4A40863C821B29EB4C40
31555	Старая Гыя	7	65	1658	53.512847999999998	53.564096999999997	58.132058999999998	58.114763000000004	0103000020E61000000100000005000000D5E8D500A5C14A403BE5D18DB00E4D40D5E8D500A5C14A403C122F4FE7104D40C7629B5434C84A403C122F4FE7104D40C7629B5434C84A403BE5D18DB00E4D40D5E8D500A5C14A403BE5D18DB00E4D40
32064	Пужмезь	7	65	1658	53.530644000000002	53.550550000000001	57.934196	57.915703999999998	0103000020E61000000100000005000000C9E88024ECC34A407F68E6C935F54C40C9E88024ECC34A40EA060ABC93F74C400A68226C78C64A40EA060ABC93F74C400A68226C78C64A407F68E6C935F54C40C9E88024ECC34A407F68E6C935F54C40
31970	Поломское	7	65	1658	53.341287999999999	53.363809000000003	57.779384	57.766824	0103000020E6100000010000000500000035423F53AFAB4A40DAE4F04927E24C4035423F53AFAB4A404983DBDAC2E34C40C87E164B91AE4A404983DBDAC2E34C40C87E164B91AE4A40DAE4F04927E24C4035423F53AFAB4A40DAE4F04927E24C40
31923	Полом	7	65	1658	53.438476999999999	53.477428000000003	57.780354000000003	57.766536000000002	0103000020E610000001000000050000002B86AB0320B84A40749A05DA1DE24C402B86AB0320B84A40C2A6CEA3E2E34C40EC18575C1CBD4A40C2A6CEA3E2E34C40EC18575C1CBD4A40749A05DA1DE24C402B86AB0320B84A40749A05DA1DE24C40
56397	Пажман	7	65	1658	53.625684999999997	53.655258000000003	57.984206999999998	57.972892000000002	0103000020E61000000100000005000000834C327216D04A4020459DB987FC4C40834C327216D04A4044BFB67EFAFD4C40A038807EDFD34A4044BFB67EFAFD4C40A038807EDFD34A4020459DB987FC4C40834C327216D04A4020459DB987FC4C40
30764	Мысы	7	65	1658	53.840113000000002	53.857135999999997	58.139555999999999	58.132035000000002	0103000020E61000000100000005000000E4F8A1D288EB4A40B476DB85E6104D40E4F8A1D288EB4A40F4FA93F8DC114D40B41CE8A1B6ED4A40F4FA93F8DC114D40B41CE8A1B6ED4A40B476DB85E6104D40E4F8A1D288EB4A40B476DB85E6104D40
31346	Липовка	7	65	1658	53.709389999999999	53.728470999999999	57.806195000000002	57.791451000000002	0103000020E61000000100000005000000020EA14ACDDA4A4079B130444EE54C40020EA14ACDDA4A407099D36531E74C40CE8AA8893EDD4A407099D36531E74C40CE8AA8893EDD4A4079B130444EE54C40020EA14ACDDA4A4079B130444EE54C40
30689	Кулига	7	65	1658	53.743347	53.780051999999998	58.201132999999999	58.166943000000003	0103000020E61000000100000005000000344A97FE25DF4A40E8A562635E154D40344A97FE25DF4A40BC92E4B9BE194D40F69672BED8E34A40BC92E4B9BE194D40F69672BED8E34A40E8A562635E154D40344A97FE25DF4A40E8A562635E154D40
31060	Кузьма	7	65	1658	54.018348000000003	54.059697999999997	57.957959000000002	57.9313	0103000020E6100000010000000500000038F92D3A59024B40E561A1D634F74C4038F92D3A59024B4056F487669EFA4C407CD11E2FA4074B4056F487669EFA4C407CD11E2FA4074B40E561A1D634F74C4038F92D3A59024B40E561A1D634F74C40
30810	Ключи	7	65	1658	53.740104000000002	53.764851999999998	58.074036	58.061117000000003	0103000020E61000000100000005000000C4D155BABBDE4A40651D8EAED2074D40C4D155BABBDE4A40035DFB027A094D40DD239BABE6E14A40035DFB027A094D40DD239BABE6E14A40651D8EAED2074D40C4D155BABBDE4A40651D8EAED2074D40
31399	Кез	7	65	1658	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
21224	Кабалуд	7	65	1658	53.849034000000003	53.886287000000003	57.928446999999998	57.917698000000001	0103000020E6100000010000000500000096986725ADEC4A4064CDC82077F54C4096986725ADEC4A40DF88EE59D7F64C405BEF37DA71F14A40DF88EE59D7F64C405BEF37DA71F14A4064CDC82077F54C4096986725ADEC4A4064CDC82077F54C40
21194	Желтопи	7	65	1658	54.035181999999999	54.053607	57.966037999999998	57.960470999999998	0103000020E6100000010000000500000035B401D880044B40D2E0B6B6F0FA4C4035B401D880044B40BC581822A7FB4C4018EB1B98DC064B40BC581822A7FB4C4018EB1B98DC064B40D2E0B6B6F0FA4C4035B401D880044B40D2E0B6B6F0FA4C40
31618	Дырпа	7	65	1658	53.411231000000001	53.432502999999997	58.058244999999999	58.048354000000003	0103000020E61000000100000005000000FA0CA837A3B44A40BE50C07630064D40FA0CA837A3B44A40E813799274074D40003620425CB74A40E813799274074D40003620425CB74A40BE50C07630064D40FA0CA837A3B44A40BE50C07630064D40
31859	Вортча	7	65	1658	53.448977999999997	53.474634000000002	57.951804000000003	57.942466000000003	0103000020E61000000100000005000000CE4F711C78B94A40C5CBD3B9A2F84C40CE4F711C78B94A40DB19A6B6D4F94C40EBC891CEC0BC4A40DB19A6B6D4F94C40EBC891CEC0BC4A40C5CBD3B9A2F84C40CE4F711C78B94A40C5CBD3B9A2F84C40
31612	Большой Олып	7	65	1658	53.513449999999999	53.542923999999999	58.055174000000001	58.043247999999998	0103000020E61000000100000005000000CB10C7BAB8C14A4007CF842689054D40CB10C7BAB8C14A4075CB0EF10F074D40541B9C887EC54A4075CB0EF10F074D40541B9C887EC54A4007CF842689054D40CB10C7BAB8C14A4007CF842689054D40
31691	Александрово	7	65	1658	53.548932999999998	53.573726999999998	58.040222999999997	58.024017000000001	0103000020E61000000100000005000000FB58C16F43C64A4026C632FD12034D40FB58C16F43C64A4004C6FA0626054D4085EAE6E26FC94A4004C6FA0626054D4085EAE6E26FC94A4026C632FD12034D40FB58C16F43C64A4026C632FD12034D40
30393	Чеганда	7	65	1629	53.504925	53.542662999999997	55.960185000000003	55.948331000000003	0103000020E6100000010000000500000066F7E461A1C04A40396403E962F94B4066F7E461A1C04A400D8E9257E7FA4B40E7DF2EFB75C54A400D8E9257E7FA4B40E7DF2EFB75C54A40396403E962F94B4066F7E461A1C04A40396403E962F94B40
30346	Усть-Сакла	7	65	1629	53.463099	53.483671000000001	56.081938999999998	56.068795999999999	0103000020E61000000100000005000000B8E7F9D346BB4A403D0CAD4ECE084C40B8E7F9D346BB4A402BA226FA7C0A4C4006836BEEE8BD4A402BA226FA7C0A4C4006836BEEE8BD4A403D0CAD4ECE084C40B8E7F9D346BB4A403D0CAD4ECE084C40
29774	Пинязь	7	65	1629	53.659731999999998	53.673214999999999	56.208289000000001	56.192104	0103000020E61000000100000005000000F50F221972D44A4024B726DD96184C40F50F221972D44A40EB8EC536A91A4C409C16BCE82BD64A40EB8EC536A91A4C409C16BCE82BD64A4024B726DD96184C40F50F221972D44A4024B726DD96184C40
30553	Ныргында	7	65	1629	53.324551999999997	53.352713999999999	55.909125000000003	55.898522999999997	0103000020E61000000100000005000000FAEC80EB8AA94A4016DA39CD02F34B40FAEC80EB8AA94A40EE7C3F355EF44B40B16B7BBB25AD4A40EE7C3F355EF44B40B16B7BBB25AD4A4016DA39CD02F34B40FAEC80EB8AA94A4016DA39CD02F34B40
56413	Малые Калмаши	7	65	1629	53.886789999999998	53.911664000000002	56.190336000000002	56.176929999999999	0103000020E61000000100000005000000BD35B05582F14A4034D769A4A5164C40BD35B05582F14A4030A017EE5C184C406478EC67B1F44A4030A017EE5C184C406478EC67B1F44A4034D769A4A5164C40BD35B05582F14A4034D769A4A5164C40
30269	Кулюшево	7	65	1629	53.558059999999998	53.575515000000003	56.065413999999997	56.047314	0103000020E61000000100000005000000569A94826EC74A404C5299620E064C40569A94826EC74A40AB59677C5F084C40C1ADBB79AAC94A40AB59677C5F084C40C1ADBB79AAC94A404C5299620E064C40569A94826EC74A404C5299620E064C40
29805	Котово	7	65	1629	53.701917000000002	53.722361999999997	56.200747999999997	56.182305999999997	0103000020E61000000100000005000000D3C08F6AD8D94A40AAEE91CD55174C40D3C08F6AD8D94A40635E471CB2194C40C3EFA65B76DC4A40635E471CB2194C40C3EFA65B76DC4A40AAEE91CD55174C40D3C08F6AD8D94A40AAEE91CD55174C40
30457	Колесниково	7	65	1629	53.551690999999998	53.583967999999999	55.993926999999999	55.970039999999997	0103000020E61000000100000005000000AF3F89CF9DC64A40EAE74D452AFC4B40AF3F89CF9DC64A4042CEFBFF38FF4B408CF4A276BFCA4A4042CEFBFF38FF4B408CF4A276BFCA4A40EAE74D452AFC4B40AF3F89CF9DC64A40EAE74D452AFC4B40
20470	Каракулино	7	65	1629	53.675829	53.741433000000001	56.025089999999999	56.001739999999998	0103000020E610000001000000050000001D588E9081D64A402A8C2D0439004C401D588E9081D64A4073BA2C2636034C406C96CB46E7DE4A4073BA2C2636034C406C96CB46E7DE4A402A8C2D0439004C401D588E9081D64A402A8C2D0439004C40
29968	Галаново	7	65	1629	54.088515000000001	54.119067000000001	56.160635999999997	56.148549000000003	0103000020E610000001000000050000004C1AA375540B4B40406D54A703134C404C1AA375540B4B40B6476FB88F144C40348463963D0F4B40B6476FB88F144C40348463963D0F4B40406D54A703134C404C1AA375540B4B40406D54A703134C40
30009	Вятское	7	65	1629	53.851567000000003	53.895108	56.074176999999999	56.050747000000001	0103000020E610000001000000050000002AADBF2500ED4A4060AFB0E07E064C402AADBF2500ED4A40C58EC6A17E094C40A93121E692F24A40C58EC6A17E094C40A93121E692F24A4060AFB0E07E064C402AADBF2500ED4A4060AFB0E07E064C40
30514	Быргында	7	65	1629	53.407718000000003	53.428837999999999	55.915624000000001	55.892646999999997	0103000020E61000000100000005000000CAFE791A30B44A40AEEFC34142F24B40CAFE791A30B44A4063B7CF2A33F54B401AA4E029E4B64A4063B7CF2A33F54B401AA4E029E4B64A40AEEFC34142F24B40CAFE791A30B44A40AEEFC34142F24B40
30056	Боярка	7	65	1629	54.014538999999999	54.038246000000001	56.063383999999999	56.051295000000003	0103000020E610000001000000050000001EC2F869DC014B4063B9A5D590064C401EC2F869DC014B407A8B87F71C084C40F699B33EE5044B407A8B87F71C084C40F699B33EE5044B4063B9A5D590064C401EC2F869DC014B4063B9A5D590064C40
29713	Арзамасцево	7	65	1629	53.687409000000002	53.709389999999999	56.155448	56.133557000000003	0103000020E61000000100000005000000F0FCA204FDD74A407193516518114C40F0FCA204FDD74A40431D56B8E5134C40020EA14ACDDA4A40431D56B8E5134C40020EA14ACDDA4A407193516518114C40F0FCA204FDD74A407193516518114C40
29528	Шолья	7	65	1608	54.044362999999997	54.075831000000001	56.363737999999998	56.341258000000003	0103000020E610000001000000050000008313D1AFAD054B40CBBF9657AE2B4C408313D1AFAD054B40FE277FF78E2E4C40F18288D4B4094B40FE277FF78E2E4C40F18288D4B4094B40CBBF9657AE2B4C408313D1AFAD054B40CBBF9657AE2B4C40
29592	Нижняя Армязь	7	65	1608	53.968842000000002	53.989620000000002	56.453189999999999	56.438059000000003	0103000020E61000000100000005000000E17EC00303FC4A40F75B3B5112384C40E17EC00303FC4A40E76F4221023A4C40D8BB3FDEABFE4A40E76F4221023A4C40D8BB3FDEABFE4A40F75B3B5112384C40E17EC00303FC4A40F75B3B5112384C40
29305	Михайловка	7	65	1608	54.262295000000002	54.287142000000003	56.420926999999999	56.405569	0103000020E61000000100000005000000C173EFE192214B40BEA25BAFE9334C40C173EFE192214B406F8099EFE0354C406EA7AD11C1244B406F8099EFE0354C406EA7AD11C1244B40BEA25BAFE9334C40C173EFE192214B40BEA25BAFE9334C40
29443	Кама	7	65	1608	54.085290999999998	54.147202	56.321385999999997	56.280296999999997	0103000020E6100000010000000500000052D2C3D0EA0A4B405D15A8C5E0234C4052D2C3D0EA0A4B4035B22B2D23294C40F1F3DF83D7124B4035B22B2D23294C40F1F3DF83D7124B405D15A8C5E0234C4052D2C3D0EA0A4B405D15A8C5E0234C40
22241	Ершовка	7	65	1608	53.866757	53.889493999999999	56.468184999999998	56.442050000000002	0103000020E610000001000000050000001F4AB4E4F1EE4A4031992A1895384C401F4AB4E4F1EE4A4027BD6F7CED3B4C407EFE7BF0DAF14A4027BD6F7CED3B4C407EFE7BF0DAF14A4031992A1895384C401F4AB4E4F1EE4A4031992A1895384C40
29673	Борок	7	65	1608	53.889763000000002	53.903022	56.435447000000003	56.429693	0103000020E610000001000000050000006E1805C1E3F14A40FA28232E00374C406E1805C1E3F14A40171230BABC374C40C5C8923996F34A40171230BABC374C40C5C8923996F34A40FA28232E00374C406E1805C1E3F14A40FA28232E00374C40
29279	Балаки	7	65	1608	54.288040000000002	54.309618	56.338698999999998	56.320307999999997	0103000020E610000001000000050000004DF8A57EDE244B40D65240DAFF284C404DF8A57EDE244B400D18247D5A2B4C4060200890A1274B400D18247D5A2B4C4060200890A1274B40D65240DAFF284C404DF8A57EDE244B40D65240DAFF284C40
40334	Ижевск	7	65	6901	53.029069	53.314123000000002	56.939194999999998	56.763978000000002	0103000020E61000000100000005000000E9297288B8834A40876EF607CA614C40E9297288B8834A408AC8B08A37784C40F1F5B52E35A84A408AC8B08A37784C40F1F5B52E35A84A40876EF607CA614C40E9297288B8834A40876EF607CA614C40
28157	Чутырь	7	65	1321	53.224471000000001	53.268416000000002	57.400550000000003	57.377431000000001	0103000020E6100000010000000500000041F33977BB9C4A4090BFB4A84FB04C4041F33977BB9C4A40D734EF3845B34C4090DC9A745BA24A40D734EF3845B34C4090DC9A745BA24A4090BFB4A84FB04C4041F33977BB9C4A4090BFB4A84FB04C40
28252	Чемошур	7	65	1321	53.076580999999997	53.154967999999997	57.582234	57.400500999999998	0103000020E610000001000000050000005B3FFD67CD894A40F581E49D43B34C405B3FFD67CD894A40444FCAA486CA4C4098F6CDFDD5934A40444FCAA486CA4C4098F6CDFDD5934A40F581E49D43B34C405B3FFD67CD894A40F581E49D43B34C40
27514	Факел	7	65	1321	53.010581999999999	53.042050000000003	57.645415999999997	57.620848000000002	0103000020E6100000010000000500000090F63FC05A814A40BDE47FF277CF4C4090F63FC05A814A405628D2FD9CD24C40FE65F7E461854A405628D2FD9CD24C40FE65F7E461854A40BDE47FF277CF4C4090F63FC05A814A40BDE47FF277CF4C40
28237	Удмурт-Лоза	7	65	1321	53.110608999999997	53.135798000000001	57.452176999999999	57.439405999999998	0103000020E6100000010000000500000056D28A6F288E4A4045D5AF743EB84C4056D28A6F288E4A406F8099EFE0B94C405D6E30D461914A406F8099EFE0B94C405D6E30D461914A4045D5AF743EB84C4056D28A6F288E4A4045D5AF743EB84C40
28350	Сундур	7	65	1321	53.094925000000003	53.127721999999999	57.531632000000002	57.518743000000001	0103000020E6100000010000000500000052499D80268C4A40B403AE2B66C24C4052499D80268C4A40E8C072840CC44C40677DCA3159904A40E8C072840CC44C40677DCA3159904A40B403AE2B66C24C4052499D80268C4A40B403AE2B66C24C40
27710	Среднее Шадбегово	7	65	1321	53.231855000000003	53.256711000000003	57.607059999999997	57.598418000000002	0103000020E610000001000000050000000135B56CAD9D4A403BAB05F698CC4C400135B56CAD9D4A40D95A5F24B4CD4C4001C3F2E7DBA04A40D95A5F24B4CD4C4001C3F2E7DBA04A403BAB05F698CC4C400135B56CAD9D4A403BAB05F698CC4C40
27939	Сеп	7	65	1321	53.297055	53.329636999999998	57.532173	57.519477999999999	0103000020E61000000100000005000000800EF3E505A64A40E97E4E417EC24C40800EF3E505A64A403868AF3E1EC44C409946938B31AA4A403868AF3E1EC44C409946938B31AA4A40E97E4E417EC24C40800EF3E505A64A40E97E4E417EC24C40
27836	Оник-Ирым	7	65	1321	53.458734	53.483131999999998	57.581972999999998	57.571381000000002	0103000020E6100000010000000500000019C8B3CBB7BA4A4024473A0323C94C4019C8B3CBB7BA4A40D7135D177ECA4C4056D3F544D7BD4A40D7135D177ECA4C4056D3F544D7BD4A4024473A0323C94C4019C8B3CBB7BA4A4024473A0323C94C40
28684	Новые Зятцы	7	65	1321	52.54927	52.591831999999997	57.469586	57.448729	0103000020E610000001000000050000004356B77A4E464A4026E2ADF36FB94C404356B77A4E464A406954E0641BBC4C40F65CA626C14B4A406954E0641BBC4C40F65CA626C14B4A4026E2ADF36FB94C404356B77A4E464A4026E2ADF36FB94C40
28052	Мужбер	7	65	1321	53.417015999999997	53.440964999999998	57.403319000000003	57.388066000000002	0103000020E6100000010000000500000051F4C0C760B54A4043588D25ACB14C4051F4C0C760B54A407F6DFDF49FB34C401FD7868A71B84A407F6DFDF49FB34C401FD7868A71B84A4043588D25ACB14C4051F4C0C760B54A4043588D25ACB14C40
27624	Менил	7	65	1321	53.076526999999999	53.119781000000003	57.648735000000002	57.625160999999999	0103000020E61000000100000005000000682101A3CB894A4009DE904605D04C40682101A3CB894A40A2629CBF09D34C4052D7DAFB548F4A40A2629CBF09D34C4052D7DAFB548F4A4009DE904605D04C40682101A3CB894A4009DE904605D04C40
28743	Малягурт	7	65	1321	52.53443	52.556232000000001	57.541283999999997	57.52505	0103000020E610000001000000050000002A00C63368444A40E561A1D634C34C402A00C63368444A408DEC4ACB48C54C408D7E349C32474A408DEC4ACB48C54C408D7E349C32474A40E561A1D634C34C402A00C63368444A40E561A1D634C34C40
28786	Магистральный	7	65	1321	52.400168000000001	52.408819000000001	57.367240000000002	57.362721000000001	0103000020E61000000100000005000000EF737CB438334A40454948A46DAE4C40EF737CB438334A403BE466B801AF4C40E17D552E54344A403BE466B801AF4C40E17D552E54344A40454948A46DAE4C40EF737CB438334A40454948A46DAE4C40
14006	Ляльшур	7	65	1321	53.241	53.252319	57.411521999999998	57.403987999999998	0103000020E61000000100000005000000022B8716D99E4A40FCFCF7E0B5B34C40022B8716D99E4A40D1CABDC0ACB44C4068942EFD4BA04A40D1CABDC0ACB44C4068942EFD4BA04A40FCFCF7E0B5B34C40022B8716D99E4A40FCFCF7E0B5B34C40
28508	Лонки-Ворцы	7	65	1321	53.178603000000003	53.205885000000002	57.479971999999997	57.466368000000003	0103000020E61000000100000005000000D7FB8D76DC964A4052F355F2B1BB4C40D7FB8D76DC964A40737FF5B86FBD4C4055DE8E705A9A4A40737FF5B86FBD4C4055DE8E705A9A4A4052F355F2B1BB4C40D7FB8D76DC964A4052F355F2B1BB4C40
27722	Лозолюк	7	65	1321	53.283670000000001	53.297522000000001	57.684694	57.675263000000001	0103000020E610000001000000050000009C6D6E4C4FA44A4074999A046FD64C409C6D6E4C4FA44A403BE2900DA4D74C4096EB6D3315A64A403BE2900DA4D74C4096EB6D3315A64A4074999A046FD64C409C6D6E4C4FA44A4074999A046FD64C40
28325	Лоза	7	65	1321	53.000062999999997	53.071973	57.531202	57.34543	0103000020E6100000010000000500000046787B1002804A405587DC0C37AC4C4046787B1002804A40EFC8586DFEC34C40F698486936894A40EFC8586DFEC34C40F698486936894A405587DC0C37AC4C4046787B1002804A405587DC0C37AC4C40
28448	Левая Кушья	7	65	1321	53.106208000000002	53.133139	57.491089000000002	57.475954999999999	0103000020E610000001000000050000006B494739988D4A4010AFEB17ECBC4C406B494739988D4A4072361D01DCBE4C403C69E1B20A914A4072361D01DCBE4C403C69E1B20A914A4010AFEB17ECBC4C406B494739988D4A4010AFEB17ECBC4C40
28518	Кушья	7	65	1321	53.084513000000001	53.122107999999997	57.463467999999999	57.446216	0103000020E610000001000000050000001E8B6D52D18A4A40D9791B9B1DB94C401E8B6D52D18A4A400B5F5FEB52BB4C403C4A253CA18F4A400B5F5FEB52BB4C403C4A253CA18F4A40D9791B9B1DB94C401E8B6D52D18A4A40D9791B9B1DB94C40
28427	Кузьмовыр	7	65	1321	53.167490999999998	53.194234000000002	57.522174999999997	57.510509999999996	0103000020E61000000100000005000000EAAF575870954A40F623456458C14C40EAAF575870954A40F7E461A1D6C24C40B9E2E2A8DC984A40F7E461A1D6C24C40B9E2E2A8DC984A40F623456458C14C40EAAF575870954A40F623456458C14C40
28597	Комсомолец	7	65	1321	53.024524	53.043523	57.534801000000002	57.521183999999998	0103000020E61000000100000005000000CAFB389A23834A4067994528B6C24C40CAFB389A23834A401E6FF25B74C44C40D9CF622992854A401E6FF25B74C44C40D9CF622992854A4067994528B6C24C40CAFB389A23834A4067994528B6C24C40
27640	Кабачигурт	7	65	1321	53.160924000000001	53.182313000000001	57.588033000000003	57.579590000000003	0103000020E610000001000000050000001D925A2899944A40598B4F0130CA4C401D925A2899944A4001FC53AA44CB4C405D514A0856974A4001FC53AA44CB4C405D514A0856974A40598B4F0130CA4C401D925A2899944A40598B4F0130CA4C40
21547	Игра	7	65	1321	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
27790	Зура	7	65	1321	53.360368000000001	53.433391999999998	57.619450000000001	57.590055	0103000020E610000001000000050000003143E38920AE4A40AFEB17EC86CB4C403143E38920AE4A40ECC039234ACF4C408C2C996379B74A40ECC039234ACF4C408C2C996379B74A40AFEB17EC86CB4C403143E38920AE4A40AFEB17EC86CB4C40
28152	Верх-Нязь	7	65	1321	53.254492999999997	53.270949999999999	57.366729999999997	57.358429000000001	0103000020E61000000100000005000000CC07043A93A04A4010786000E1AD4C40CC07043A93A04A40253B3602F1AE4C40F46C567DAEA24A40253B3602F1AE4C40F46C567DAEA24A4010786000E1AD4C40CC07043A93A04A4010786000E1AD4C40
28012	Большая Пурга	7	65	1321	53.484155999999999	53.498303999999997	57.530090000000001	57.524116999999997	0103000020E61000000100000005000000C214E5D2F8BD4A4089230F4416C34C40C214E5D2F8BD4A40E4F736FDD9C34C40A5BBEB6CC8BF4A40E4F736FDD9C34C40A5BBEB6CC8BF4A4089230F4416C34C40C214E5D2F8BD4A4089230F4416C34C40
27973	Беляевское	7	65	1321	53.454681999999998	53.467402	57.527572999999997	57.520226999999998	0103000020E61000000100000005000000390A100533BA4A4083BF5FCC96C24C40390A100533BA4A4055A0168387C34C40E10A28D4D3BB4A4055A0168387C34C40E10A28D4D3BB4A4083BF5FCC96C24C40390A100533BA4A4083BF5FCC96C24C40
28621	Бачкеево	7	65	1321	52.945813999999999	52.978557000000002	57.510984000000001	57.501927999999999	0103000020E61000000100000005000000AA0CE36E10794A402D793C2D3FC04C40AA0CE36E10794A40BF6378EC67C14C40CD22145B417D4A40BF6378EC67C14C40CD22145B417D4A402D793C2D3FC04C40AA0CE36E10794A402D793C2D3FC04C40
26811	Ягул	7	65	1575	53.301124000000002	53.332394999999998	56.955807999999998	56.941060999999998	0103000020E610000001000000050000003605323B8BA64A404145D5AF74784C403605323B8BA64A40A9A0A2EA577A4C404D2D5BEB8BAA4A40A9A0A2EA577A4C404D2D5BEB8BAA4A404145D5AF74784C403605323B8BA64A404145D5AF74784C40
26338	Юськи	7	65	1575	53.059244	53.098491000000003	56.666468000000002	56.655144	0103000020E61000000100000005000000FB3DB14E95874A40D71533C2DB534C40FB3DB14E95874A404FEACBD24E554C40A5F9635A9B8C4A404FEACBD24E554C40A5F9635A9B8C4A40D71533C2DB534C40FB3DB14E95874A40D71533C2DB534C40
26732	Шабердино	7	65	1575	52.987226	53.010178000000003	56.928862000000002	56.904668999999998	0103000020E6100000010000000500000065E1EB6B5D7E4A403E5A9C31CC734C4065E1EB6B5D7E4A40A33F34F3E4764C40C19140834D814A40A33F34F3E4764C40C19140834D814A403E5A9C31CC734C4065E1EB6B5D7E4A403E5A9C31CC734C40
24618	Чепаниха	7	65	1575	53.615355000000001	53.636949999999999	56.679375999999998	56.664099	0103000020E610000001000000050000000D37E0F3C3CE4A4035272F3201554C400D37E0F3C3CE4A40F9D7F2CAF5564C40F697DD9387D14A40F9D7F2CAF5564C40F697DD9387D14A4035272F3201554C400D37E0F3C3CE4A4035272F3201554C40
26672	Хохряки	7	65	1575	53.307870999999999	53.330553000000002	56.918973999999999	56.904679000000002	0103000020E610000001000000050000008331225168A74A4062307F85CC734C408331225168A74A40E9EFA5F0A0754C401F4C8A8F4FAA4A40E9EFA5F0A0754C401F4C8A8F4FAA4A4062307F85CC734C408331225168A74A4062307F85CC734C40
25392	Старые Тукмачи	7	65	1575	53.499158000000001	53.521076999999998	56.800814000000003	56.790225	0103000020E61000000100000005000000B5C4CA68E4BF4A40A5BDC11726654C40B5C4CA68E4BF4A40E816BA1281664C4051D9B0A6B2C24A40E816BA1281664C4051D9B0A6B2C24A40A5BDC11726654C40B5C4CA68E4BF4A40A5BDC11726654C40
26926	Старое Михайловское	7	65	1575	53.253675000000001	53.279680999999997	56.968772999999999	56.960456000000001	0103000020E610000001000000050000000A68226C78A04A409D9FE238F07A4C400A68226C78A04A40B81FF0C0007C4C4002284696CCA34A40B81FF0C0007C4C4002284696CCA34A409D9FE238F07A4C400A68226C78A04A409D9FE238F07A4C40
25120	Старое Мартьяново	7	65	1575	53.400756000000001	53.426197000000002	56.834564999999998	56.820562000000002	0103000020E6100000010000000500000080D6FCF84BB34A40912BF52C08694C4080D6FCF84BB34A4070B1A206D36A4C40A053909F8DB64A4070B1A206D36A4C40A053909F8DB64A40912BF52C08694C4080D6FCF84BB34A40912BF52C08694C40
26546	Средний Постол	7	65	1575	52.770533999999998	52.801938999999997	56.766523999999997	56.752955	0103000020E61000000100000005000000603AADDBA0624A400A2E56D460604C40603AADDBA0624A40AFCC5B751D624C408731E9EFA5664A40AFCC5B751D624C408731E9EFA5664A400A2E56D460604C40603AADDBA0624A400A2E56D460604C40
26960	Сокол	7	65	1575	53.360691000000003	53.376232000000002	57.05254	57.040911999999999	0103000020E61000000100000005000000147B681F2BAE4A40C901BB9A3C854C40147B681F2BAE4A40ADDD76A1B9864C40B6DAC35E28B04A40ADDD76A1B9864C40B6DAC35E28B04A40C901BB9A3C854C40147B681F2BAE4A40C901BB9A3C854C40
26316	Совхозный	7	65	1575	53.096173999999998	53.121713	56.694375000000001	56.680765999999998	0103000020E61000000100000005000000DD5CFC6D4F8C4A40471D1D5723574C40DD5CFC6D4F8C4A407B14AE47E1584C40C03FA54A948F4A407B14AE47E1584C40C03FA54A948F4A40471D1D5723574C40DD5CFC6D4F8C4A40471D1D5723574C40
25553	Сизево	7	65	1575	53.343767	53.377831	56.730558000000002	56.716152000000001	0103000020E61000000100000005000000D6389B8E00AC4A40857B65DEAA5B4C40D6389B8E00AC4A4064EAAEEC825D4C401E3526C45CB04A4064EAAEEC825D4C401E3526C45CB04A40857B65DEAA5B4C40D6389B8E00AC4A40857B65DEAA5B4C40
26216	Сепыч	7	65	1575	52.990020000000001	53.022584000000002	56.776029000000001	56.764071999999999	0103000020E610000001000000050000006631B1F9B87E4A4008E57D1CCD614C406631B1F9B87E4A40B1DF13EB54634C40D9B45208E4824A40B1DF13EB54634C40D9B45208E4824A4008E57D1CCD614C406631B1F9B87E4A4008E57D1CCD614C40
24565	Сапарово	7	65	1575	53.489384000000001	53.513755000000003	56.687351	56.671390000000002	0103000020E61000000100000005000000C4978922A4BE4A40446E861BF0554C40C4978922A4BE4A40BBEF181EFB574C4008944DB9C2C14A40BBEF181EFB574C4008944DB9C2C14A40446E861BF0554C40C4978922A4BE4A40446E861BF0554C40
26880	Русский Вожой	7	65	1575	53.357016999999999	53.393839	56.974612	56.953201999999997	0103000020E61000000100000005000000DA8EA9BBB2AD4A40AB3DEC85027A4C40DA8EA9BBB2AD4A4003250516C07C4C40D671FC5069B24A4003250516C07C4C40D671FC5069B24A40AB3DEC85027A4C40DA8EA9BBB2AD4A40AB3DEC85027A4C40
25056	Пычанки	7	65	1575	53.395806999999998	53.423240999999997	56.775851000000003	56.763485000000003	0103000020E610000001000000050000009143C4CDA9B24A4048FE60E0B9614C409143C4CDA9B24A40D2C8E7154F634C40C5A9D6C22CB64A40D2C8E7154F634C40C5A9D6C22CB64A4048FE60E0B9614C409143C4CDA9B24A4048FE60E0B9614C40
26635	Постол	7	65	1575	52.716850999999998	52.790019000000001	56.835608999999998	56.766820000000003	0103000020E610000001000000050000006D8D08C6C15B4A4099F5622827624C406D8D08C6C15B4A40239F573CF56A4C40FC1BB4571F654A40239F573CF56A4C40FC1BB4571F654A4099F5622827624C406D8D08C6C15B4A4099F5622827624C40
26131	Подшивалово	7	65	1575	52.937871999999999	52.985025	56.741548999999999	56.718359999999997	0103000020E61000000100000005000000C4EA8F300C784A4095607138F35B4C40C4EA8F300C784A40D5B0DF13EB5E4C40075F984C157E4A40D5B0DF13EB5E4C40075F984C157E4A4095607138F35B4C40C4EA8F300C784A4095607138F35B4C40
26002	Пирогово	7	65	1575	53.136822000000002	53.174092999999999	56.787011	56.773366000000003	0103000020E61000000100000005000000C9AF1F6283914A404FEB36A8FD624C40C9AF1F6283914A40CF4BC5C6BC644C4034BBEEAD48964A40CF4BC5C6BC644C4034BBEEAD48964A404FEB36A8FD624C40C9AF1F6283914A404FEB36A8FD624C40
24538	Пальники	7	65	1575	53.485053999999998	53.496732000000002	56.602015999999999	56.592619999999997	0103000020E61000000100000005000000A165DD3F16BE4A404E7ADFF8DA4B4C40A165DD3F16BE4A4099D53BDC0E4D4C40377007EA94BF4A4099D53BDC0E4D4C40377007EA94BF4A404E7ADFF8DA4B4C40A165DD3F16BE4A404E7ADFF8DA4B4C40
25759	Новый Сентег	7	65	1575	52.840657	52.879257000000003	56.940865000000002	56.928170000000001	0103000020E61000000100000005000000A51309A69A6B4A406D904946CE764C40A51309A69A6B4A40BC79AA436E784C40B9E34D7E8B704A40BC79AA436E784C40B9E34D7E8B704A406D904946CE764C40A51309A69A6B4A406D904946CE764C40
25247	Новокварсинское	7	65	1575	53.554332000000002	53.565831000000003	56.972762000000003	56.95355	0103000020E610000001000000050000002A90D959F4C64A40E78C28ED0D7A4C402A90D959F4C64A4052651877837C4C40100874266DC84A4052651877837C4C40100874266DC84A40E78C28ED0D7A4C402A90D959F4C64A40E78C28ED0D7A4C40
25273	Новая Казмаска	7	65	1575	53.518794999999997	53.548772	56.845681999999996	56.816065000000002	0103000020E61000000100000005000000062AE3DF67C24A40833463D174684C40062AE3DF67C24A406E68CA4E3F6C4C40F27A30293EC64A406E68CA4E3F6C4C40F27A30293EC64A40833463D174684C40062AE3DF67C24A40833463D174684C40
26515	Непременная Лудзя	7	65	1575	53.077272999999998	53.106935	56.712451000000001	56.700988000000002	0103000020E6100000010000000500000091EEE714E4894A40B9718BF9B9594C4091EEE714E4894A4052802898315B4C401DE6CB0BB08D4A4052802898315B4C401DE6CB0BB08D4A40B9718BF9B9594C4091EEE714E4894A40B9718BF9B9594C40
25486	Мещеряки	7	65	1575	53.298850999999999	53.325352000000002	56.746228000000002	56.737909999999999	0103000020E610000001000000050000003EB0E3BF40A64A4018B2BAD5735E4C403EB0E3BF40A64A4004AE2B66845F4C4017D86322A5A94A4004AE2B66845F4C4017D86322A5A94A4018B2BAD5735E4C403EB0E3BF40A64A4018B2BAD5735E4C40
24772	Макарово	7	65	1575	53.704143999999999	53.746203000000001	56.721170000000001	56.708153000000003	0103000020E610000001000000050000005AD6FD6321DA4A403BC8EBC1A45A4C405AD6FD6321DA4A409C6D6E4C4F5C4C40AB96749483DF4A409C6D6E4C4F5C4C40AB96749483DF4A403BC8EBC1A45A4C405AD6FD6321DA4A403BC8EBC1A45A4C40
26785	Люкшудья	7	65	1575	52.985573000000002	53.027020999999998	56.978653999999999	56.949058999999998	0103000020E610000001000000050000000A698D41277E4A40BB7CEBC37A794C400A698D41277E4A40BF0CC688447D4C4011A7936C75834A40BF0CC688447D4C4011A7936C75834A40BB7CEBC37A794C400A698D41277E4A40BB7CEBC37A794C40
25743	Люк	7	65	1575	52.778134000000001	52.822017000000002	56.925590999999997	56.898446	0103000020E61000000100000005000000EDF318E599634A406B9C4D4700734C40EDF318E599634A40683C11C479764C40C6E061DA37694A40683C11C479764C40C6E061DA37694A406B9C4D4700734C40EDF318E599634A406B9C4D4700734C40
26073	Лудорвай	7	65	1575	53.077030000000001	53.109954000000002	56.762765000000002	56.747511000000003	0103000020E61000000100000005000000CB67791EDC894A403C33C170AE5F4C40CB67791EDC894A4048C49448A2614C403E0801F9128E4A4048C49448A2614C403E0801F9128E4A403C33C170AE5F4C40CB67791EDC894A403C33C170AE5F4C40
26154	Ленино	7	65	1575	52.961525000000002	52.980874999999997	56.821804	56.810851999999997	0103000020E61000000100000005000000A9A44E40137B4A40B6F292FFC9674C40A9A44E40137B4A406ADC9BDF30694C40643BDF4F8D7D4A406ADC9BDF30694C40643BDF4F8D7D4A40B6F292FFC9674C40A9A44E40137B4A40B6F292FFC9674C40
25602	Кияик	7	65	1575	52.792112000000003	52.817785999999998	56.974415	56.963459	0103000020E6100000010000000500000074620FED63654A40B804E09F527B4C4074620FED63654A40ADDD76A1B97C4C4036902E36AD684A40ADDD76A1B97C4C4036902E36AD684A40B804E09F527B4C4074620FED63654A40B804E09F527B4C40
25351	Каменное	7	65	1575	53.271101999999999	53.305418000000003	56.738453	56.723733000000003	0103000020E61000000100000005000000AAF06778B3A24A409B046F48A35C4C40AAF06778B3A24A400951BEA0855E4C400CCEE0EF17A74A400951BEA0855E4C400CCEE0EF17A74A409B046F48A35C4C40AAF06778B3A24A409B046F48A35C4C40
58398	Италмас	7	65	1575	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
18952	Завьялово	7	65	1575	53.349418	53.4009	56.806905	56.775495999999997	0103000020E610000001000000050000001E51A1BAB9AC4A40E316F37343634C401E51A1BAB9AC4A404CFDBCA948674C40B37BF2B050B34A404CFDBCA948674C40B37BF2B050B34A40E316F37343634C401E51A1BAB9AC4A40E316F37343634C40
24801	Забегалово	7	65	1575	53.647621999999998	53.671778000000003	56.791325000000001	56.773242000000003	0103000020E61000000100000005000000C6151747E5D24A4063F20698F9624C40C6151747E5D24A40ECC039234A654C400E164ED2FCD54A40ECC039234A654C400E164ED2FCD54A4063F20698F9624C40C6151747E5D24A4063F20698F9624C40
24717	Докша	7	65	1575	53.729531000000001	53.759318999999998	56.821458999999997	56.805653	0103000020E610000001000000050000008735954561DD4A404F7633A31F674C408735954561DD4A409F008A9125694C409F1D705D31E14A409F008A9125694C409F1D705D31E14A404F7633A31F674C408735954561DD4A404F7633A31F674C40
25442	Динтем-Бодья	7	65	1575	53.271354000000002	53.289023999999998	56.690613999999997	56.679965000000003	0103000020E61000000100000005000000C4D155BABBA24A405BB6D61709574C40C4D155BABBA24A407214200A66584C402AE109BDFEA44A407214200A66584C402AE109BDFEA44A405BB6D61709574C40C4D155BABBA24A405BB6D61709574C40
24070	Гольяны	7	65	1575	53.707962000000002	53.750793999999999	56.769454000000003	56.746637999999997	0103000020E61000000100000005000000C767B27F9EDA4A40B5F97FD5915F4C40C767B27F9EDA4A4061E3FA777D624C403A048E041AE04A4061E3FA777D624C403A048E041AE04A40B5F97FD5915F4C40C767B27F9EDA4A40B5F97FD5915F4C40
56410	Верхняя Лудзя	7	65	1575	52.904904000000002	52.932383999999999	56.709744000000001	56.694167999999998	0103000020E610000001000000050000008202EFE4D3734A4001F73C7FDA584C408202EFE4D3734A40204432E4D85A4C4026A8E15B58774A40204432E4D85A4C4026A8E15B58774A4001F73C7FDA584C408202EFE4D3734A4001F73C7FDA584C40
56395	Верхний Женвай	7	65	1575	52.671297000000003	52.692210000000003	56.728465	56.716611	0103000020E610000001000000050000009373620FED554A40187AC4E8B95B4C409373620FED554A40ECA353573E5D4C406AFB57569A584A40ECA353573E5D4C406AFB57569A584A40187AC4E8B95B4C409373620FED554A40187AC4E8B95B4C40
24865	Вараксино	7	65	1575	53.061929999999997	53.096111000000001	56.874896999999997	56.86307	0103000020E6100000010000000500000015527E52ED874A405114E813796E4C4015527E52ED874A402B2FF99FFC6F4C4097E4805D4D8C4A402B2FF99FFC6F4C4097E4805D4D8C4A405114E813796E4C4015527E52ED874A405114E813796E4C40
25700	Большой Кияик	7	65	1575	52.746063999999997	52.768818000000003	57.028402999999997	57.012929999999997	0103000020E61000000100000005000000895C70067F5F4A409291B3B0A7814C40895C70067F5F4A40DC0DA2B5A2834C40BF49D3A068624A40DC0DA2B5A2834C40BF49D3A068624A409291B3B0A7814C40895C70067F5F4A409291B3B0A7814C40
33022	Большая Венья	7	65	1575	53.125557000000001	53.1584	56.738847999999997	56.727634999999999	0103000020E610000001000000050000005664744012904A406536C824235D4C405664744012904A40855B3E92925E4C40DCD7817346944A40855B3E92925E4C40DCD7817346944A406536C824235D4C405664744012904A406536C824235D4C40
24458	Бабино	7	65	1575	53.442931999999999	53.481434	56.664434999999997	56.642876000000001	0103000020E610000001000000050000000A2DEBFEB1B84A4010B1C1C249524C400A2DEBFEB1B84A40ACA8C1340C554C405B971AA19FBD4A40ACA8C1340C554C405B971AA19FBD4A4010B1C1C249524C400A2DEBFEB1B84A4010B1C1C249524C40
25648	Азино	7	65	1575	52.699764999999999	52.716869000000003	56.977387999999998	56.968347000000001	0103000020E6100000010000000500000056F146E691594A40011764CBF27B4C4056F146E691594A405DC0CB0C1B7D4C401442075DC25B4A405DC0CB0C1B7D4C401442075DC25B4A40011764CBF27B4C4056F146E691594A40011764CBF27B4C40
24416	Уйвай	7	65	1721	53.913837999999998	53.938757000000003	57.545216000000003	57.531056999999997	0103000020E61000000100000005000000C8EBC1A4F8F44A40EBA7FFACF9C34C40C8EBC1A4F8F44A40C3A04CA3C9C54C400FF27A3029F84A40C3A04CA3C9C54C400FF27A3029F84A40EBA7FFACF9C34C40C8EBC1A4F8F44A40EBA7FFACF9C34C40
23634	Удмуртский Лем	7	65	1721	53.999969	54.023397000000003	57.663426000000001	57.652327999999997	0103000020E61000000100000005000000C501F4FBFEFF4A40EE21E17B7FD34C40C501F4FBFEFF4A4076A8A624EBD44C408AE942ACFE024B4076A8A624EBD44C408AE942ACFE024B40EE21E17B7FD34C40C501F4FBFEFF4A40EE21E17B7FD34C40
24345	Тыловай	7	65	1721	53.773592999999998	53.807684000000002	57.508557000000003	57.482351999999999	0103000020E610000001000000050000000FB56D1805E34A408194D8B5BDBD4C400FB56D1805E34A407193516518C14C4051C0763062E74A407193516518C14C4051C0763062E74A408194D8B5BDBD4C400FB56D1805E34A408194D8B5BDBD4C40
24172	Турнес	7	65	1721	53.800767	53.821886999999997	57.717094000000003	57.706685999999998	0103000020E61000000100000005000000A75B76887FE64A404145D5AF74DA4C40A75B76887FE64A40341477BCC9DB4C40F700DD9733E94A40341477BCC9DB4C40F700DD9733E94A404145D5AF74DA4C40A75B76887FE64A404145D5AF74DA4C40
24318	Тольен	7	65	1721	53.674652999999999	53.707774000000001	57.718997999999999	57.703690000000002	0103000020E61000000100000005000000FB928D075BD64A40D942908312DA4C40FB928D075BD64A40D8F15F2008DC4C40C47AA35698DA4A40D8F15F2008DC4C40C47AA35698DA4A40D942908312DA4C40FB928D075BD64A40D942908312DA4C40
24019	Такагурт	7	65	1721	53.689466000000003	53.727733999999998	57.578918999999999	57.566727999999998	0103000020E610000001000000050000001BDA006C40D84A401EDD088B8AC84C401BDA006C40D84A403A048E041ACA4C40F817416326DD4A403A048E041ACA4C40F817416326DD4A401EDD088B8AC84C401BDA006C40D84A401EDD088B8AC84C40
24104	Сюрногурт	7	65	1721	53.623322999999999	53.657764	57.626770999999998	57.615994000000001	0103000020E610000001000000050000001CEC4D0CC9CF4A40204432E4D8CE4C401CEC4D0CC9CF4A40658A39083AD04C403A3E5A9C31D44A40658A39083AD04C403A3E5A9C31D44A40204432E4D8CE4C401CEC4D0CC9CF4A40204432E4D8CE4C40
23973	Старый Кыч	7	65	1721	53.708151000000001	53.730967999999997	57.541201999999998	57.528066000000003	0103000020E610000001000000050000009AD024B1A4DA4A409510ACAA97C34C409AD024B1A4DA4A40D0436D1B46C54C401536035C90DD4A40D0436D1B46C54C401536035C90DD4A409510ACAA97C34C409AD024B1A4DA4A409510ACAA97C34C40
23804	Нижняя Пыхта	7	65	1721	53.978318999999999	54.014961	57.698971999999998	57.682966999999998	0103000020E610000001000000050000001807978E39FD4A40A59F70766BD74C401807978E39FD4A40EC681CEA77D94C4094DBF63DEA014B40EC681CEA77D94C4094DBF63DEA014B40A59F70766BD74C401807978E39FD4A40A59F70766BD74C40
23339	Малая Чепца	7	65	1721	53.755941	53.773314999999997	57.638773999999998	57.630707999999998	0103000020E610000001000000050000004F5AB8ACC2E04A40ACA92C0ABBD04C404F5AB8ACC2E04A407EC4AF58C3D14C40CC4065FCFBE24A407EC4AF58C3D14C40CC4065FCFBE24A40ACA92C0ABBD04C404F5AB8ACC2E04A40ACA92C0ABBD04C40
24267	Лесагурт	7	65	1721	53.673017999999999	53.702221999999999	57.671754	57.653829999999999	0103000020E6100000010000000500000046CF2D7425D64A40649291B3B0D34C4046CF2D7425D64A40857AFA08FCD54C400F441669E2D94A40857AFA08FCD54C400F441669E2D94A40649291B3B0D34C4046CF2D7425D64A40649291B3B0D34C40
23764	Котегурт	7	65	1721	53.521337000000003	53.540497999999999	57.684843000000001	57.671196000000002	0103000020E61000000100000005000000EE98BA2BBBC24A405F9A22C0E9D54C40EE98BA2BBBC24A4080F277EFA8D74C40D6C6D8092FC54A4080F277EFA8D74C40D6C6D8092FC54A405F9A22C0E9D54C40EE98BA2BBBC24A405F9A22C0E9D54C40
23731	Заречная Медла	7	65	1721	53.911799000000002	53.934401000000001	57.630755999999998	57.613714000000002	0103000020E6100000010000000500000044C362D4B5F44A40768C2B2E8ECE4C4044C362D4B5F44A40BDE0D39CBCD04C40C32CB4739AF74A40BDE0D39CBCD04C40C32CB4739AF74A40768C2B2E8ECE4C4044C362D4B5F44A40768C2B2E8ECE4C40
23383	Дебесы	7	65	1721	53.771680000000003	53.837364000000001	57.666708999999997	57.635440000000003	0103000020E61000000100000005000000187D0569C6E24A40FE48111956D14C40187D0569C6E24A40747973B856D54C40836C59BE2EEB4A40747973B856D54C40836C59BE2EEB4A40FE48111956D14C40187D0569C6E24A40FE48111956D14C40
23896	Верхний Четкер	7	65	1721	53.617860999999998	53.638503999999998	57.497884999999997	57.485492000000001	0103000020E61000000100000005000000A73CBA1116CF4A401D3C139A24BE4C40A73CBA1116CF4A40A01518B2BABF4C40BE2EC37FBAD14A40A01518B2BABF4C40BE2EC37FBAD14A401D3C139A24BE4C40A73CBA1116CF4A401D3C139A24BE4C40
24189	Варни	7	65	1721	53.734166000000002	53.75949	57.688192000000001	57.675604	0103000020E61000000100000005000000E6EAC726F9DD4A40FD851E317AD64C40E6EAC726F9DD4A4036AFEAAC16D84C40CCD1E3F736E14A4036AFEAAC16D84C40CCD1E3F736E14A40FD851E317AD64C40E6EAC726F9DD4A40FD851E317AD64C40
23301	Большой Зетым	7	65	1721	53.764026000000001	53.788685000000001	57.601790000000001	57.593449999999997	0103000020E6100000010000000500000098A59D9ACBE14A40D5E76A2BF6CB4C4098A59D9ACBE14A40A987687407CD4C4042EC4CA1F3E44A40A987687407CD4C4042EC4CA1F3E44A40D5E76A2BF6CB4C4098A59D9ACBE14A40D5E76A2BF6CB4C40
23696	Большая Кизня	7	65	1721	54.041372000000003	54.070846000000003	57.622625999999997	57.609220000000001	0103000020E610000001000000050000002D7C7DAD4B054B40D908C4EBFACD4C402D7C7DAD4B054B40D4D17135B2CF4C40B686527B11094B40D4D17135B2CF4C40B686527B11094B40D908C4EBFACD4C402D7C7DAD4B054B40D908C4EBFACD4C40
23874	Ариково	7	65	1721	53.903489	53.937131000000001	57.675133000000002	57.656343999999997	0103000020E61000000100000005000000DBA50D87A5F34A408176871403D44C40DBA50D87A5F34A40A6B915C26AD64C40AD889AE8F3F74A40A6B915C26AD64C40AD889AE8F3F74A408176871403D44C40DBA50D87A5F34A408176871403D44C40
22409	Яги-Какси	7	65	1562	51.945450000000001	51.959580000000003	56.097447000000003	56.086689999999997	0103000020E6100000010000000500000069006F8104F94940F3716DA8180B4C4069006F8104F94940F20BAF24790C4C40A6F27684D3FA4940F20BAF24790C4C40A6F27684D3FA4940F3716DA8180B4C4069006F8104F94940F3716DA8180B4C40
56390	Старый Ятчи	7	65	1562	51.646040999999997	51.669631000000003	56.010106	55.993876999999998	0103000020E610000001000000050000000470B378B1D24940909F8D5C37FF4B400470B378B1D2494027BF45274B014C40A3B1F677B6D5494027BF45274B014C40A3B1F677B6D54940909F8D5C37FF4B400470B378B1D24940909F8D5C37FF4B40
23143	Старая Игра	7	65	1562	52.136260999999998	52.15455	55.938889000000003	55.925052000000001	0103000020E61000000100000005000000315C1D0071114A40B98C9B1A68F64B40315C1D0071114A407EC9C6832DF84B4064CC5D4BC8134A407EC9C6832DF84B4064CC5D4BC8134A40B98C9B1A68F64B40315C1D0071114A40B98C9B1A68F64B40
22893	Селянур	7	65	1562	51.711843000000002	51.737876	56.057423	56.045192	0103000020E610000001000000050000007A71E2AB1DDB49403A05F9D9C8054C407A71E2AB1DDB4940E48409A359074C406C4084B872DE4940E48409A359074C406C4084B872DE49403A05F9D9C8054C407A71E2AB1DDB49403A05F9D9C8054C40
22554	Порым	7	65	1562	51.972695999999999	51.990689000000003	56.014603999999999	55.998916000000001	0103000020E610000001000000050000009A79724D81FC4940BFB9BF7ADCFF4B409A79724D81FC494005323B8BDE014C40E4C0ABE5CEFE494005323B8BDE014C40E4C0ABE5CEFE4940BFB9BF7ADCFF4B409A79724D81FC4940BFB9BF7ADCFF4B40
22841	Поршур	7	65	1562	51.692735999999996	51.713064000000003	56.033731000000003	56.023052	0103000020E610000001000000050000008461C092ABD84940BF0D315EF3024C408461C092ABD8494042EE224C51044C403CFA5FAE45DB494042EE224C51044C403CFA5FAE45DB4940BF0D315EF3024C408461C092ABD84940BF0D315EF3024C40
22927	Новогорское	7	65	1562	52.147894000000001	52.190536999999999	56.093812	56.073348000000003	0103000020E6100000010000000500000027A3CA30EE124A400F9D9E7763094C4027A3CA30EE124A4076FC1708020C4C40C7D6338463184A4076FC1708020C4C40C7D6338463184A400F9D9E7763094C4027A3CA30EE124A400F9D9E7763094C40
22717	Нижние Юраши	7	65	1562	51.7624	51.786743999999999	55.971072999999997	55.963127999999998	0103000020E61000000100000005000000363CBD5296E1494052EE3EC747FB4B40363CBD5296E14940A983BC1E4CFC4B4080290307B4E44940A983BC1E4CFC4B4080290307B4E4494052EE3EC747FB4B40363CBD5296E1494052EE3EC747FB4B40
23257	Мишкино	7	65	1562	52.073081999999999	52.09863	55.930790999999999	55.919851000000001	0103000020E6100000010000000500000090F63FC05A094A40B11875ADBDF54B4090F63FC05A094A40A034D42824F74B40C63368E89F0C4A40A034D42824F74B40C63368E89F0C4A40B11875ADBDF54B4090F63FC05A094A40B11875ADBDF54B40
23080	Мари-Возжай	7	65	1562	52.095855	52.123117999999998	56.020220000000002	56.006366	0103000020E610000001000000050000003C1405FA440C4A4036E7E099D0004C403C1405FA440C4A40D15CA79196024C4043C6A354C20F4A40D15CA79196024C4043C6A354C20F4A4036E7E099D0004C403C1405FA440C4A4036E7E099D0004C40
22765	Мамаево	7	65	1562	51.842556999999999	51.858528999999997	55.978971000000001	55.967813999999997	0103000020E61000000100000005000000080264E8D8EB4940334E4354E1FB4B40080264E8D8EB4940C05DF6EB4EFD4B4073D53C47E4ED4940C05DF6EB4EFD4B4073D53C47E4ED4940334E4354E1FB4B40080264E8D8EB4940334E4354E1FB4B40
18944	Макарово	7	65	1562	52.067943999999997	52.092979999999997	56.170344999999998	56.154680999999997	0103000020E61000000100000005000000CEFA9463B2084A4002284696CC134C40CEFA9463B2084A40C0046EDDCD154C404E97C5C4E60B4A40C0046EDDCD154C404E97C5C4E60B4A4002284696CC134C40CEFA9463B2084A4002284696CC134C40
22666	Лолошур-Возжи	7	65	1562	51.758572999999998	51.783087999999999	56.005248999999999	55.990982000000002	0103000020E61000000100000005000000765089EB18E149405C76887FD8FE4B40765089EB18E1494019ABCDFFAB004C40EDF1423A3CE4494019ABCDFFAB004C40EDF1423A3CE449405C76887FD8FE4B40765089EB18E149405C76887FD8FE4B40
22319	Котловка	7	65	1562	51.999358000000001	52.023684000000003	56.119929999999997	56.113798000000003	0103000020E610000001000000050000007C7F83F6EAFF4940D42CD0EE900E4C407C7F83F6EAFF494096E7C1DD590F4C4020B8CA1308034A4096E7C1DD590F4C4020B8CA1308034A40D42CD0EE900E4C407C7F83F6EAFF4940D42CD0EE900E4C40
22973	Кокшан	7	65	1562	52.108898000000003	52.136960999999999	56.118820999999997	56.10181	0103000020E61000000100000005000000C74CA25EF00D4A40F0332E1C080D4C40C74CA25EF00D4A40FC89CA86350F4C40EAE923F087114A40FC89CA86350F4C40EAE923F087114A40F0332E1C080D4C40C74CA25EF00D4A40F0332E1C080D4C40
20687	Каменное	7	65	1562	52.011485	52.033501999999999	56.046464	56.031945999999998	0103000020E6100000010000000500000081B2295778014A40779E78CE16044C4081B2295778014A407E384888F2054C40E02C25CB49044A407E384888F2054C40E02C25CB49044A40779E78CE16044C4081B2295778014A40779E78CE16044C40
20217	Иж-Бобья	7	65	1562	52.058700000000002	52.075696000000001	56.040038000000003	56.030617999999997	0103000020E610000001000000050000003A234A7B83074A409F55664AEB034C403A234A7B83074A40734C16F71F054C4011381268B0094A40734C16F71F054C4011381268B0094A409F55664AEB034C403A234A7B83074A409F55664AEB034C40
18831	Заречный	7	65	1562	51.875596999999999	51.896940999999998	56.046846000000002	56.028258999999998	0103000020E61000000100000005000000E4BCFF8F13F04940A968ACFD9D034C40E4BCFF8F13F0494066F9BA0CFF054C4084B872F6CEF2494066F9BA0CFF054C4084B872F6CEF24940A968ACFD9D034C40E4BCFF8F13F04940A968ACFD9D034C40
18728	Грахово	7	65	1562	51.946294000000002	51.983853000000003	56.055985	56.040249000000003	0103000020E6100000010000000500000055336B2920F949402E5915E126054C4055336B2920F94940850838842A074C40278925E5EEFD4940850838842A074C40278925E5EEFD49402E5915E126054C4055336B2920F949402E5915E126054C40
23121	Верхняя Игра	7	65	1562	52.09422	52.118259000000002	55.952969000000003	55.943300999999998	0103000020E610000001000000050000008750A5660F0C4A405DA45016BEF84B408750A5660F0C4A40098D60E3FAF94B4095BA641C230F4A40098D60E3FAF94B4095BA641C230F4A405DA45016BEF84B408750A5660F0C4A405DA45016BEF84B40
23029	Большая Ерыкса	7	65	1562	52.197085999999999	52.215347999999999	56.030335999999998	56.018821000000003	0103000020E61000000100000005000000EE3F321D3A194A4030BDFDB968024C40EE3F321D3A194A401BF2CF0CE2034C4027A1F485901B4A401BF2CF0CE2034C4027A1F485901B4A4030BDFDB968024C40EE3F321D3A194A4030BDFDB968024C40
22624	Благодатное	7	65	1562	51.861896999999999	51.881292000000002	56.007423000000003	55.990412999999997	0103000020E61000000100000005000000A0C211A452EE494041446ADAC5FE4B40A0C211A452EE49407E1EA33CF3004C40FC1C1F2DCEF049407E1EA33CF3004C40FC1C1F2DCEF0494041446ADAC5FE4B40A0C211A452EE494041446ADAC5FE4B40
23211	Байтуганово	7	65	1562	52.218375999999999	52.235335999999997	55.959394000000003	55.948982000000001	0103000020E610000001000000050000009B1DA9BEF31B4A40103FFF3D78F94B409B1DA9BEF31B4A4044FD2E6CCDFA4B4025C9737D1F1E4A4044FD2E6CCDFA4B4025C9737D1F1E4A40103FFF3D78F94B409B1DA9BEF31B4A40103FFF3D78F94B40
22240	Штанигурт	7	65	1000	52.643863000000003	52.674171999999999	58.118932000000001	58.103642000000001	0103000020E610000001000000050000005F0D501A6A524A40FB3E1C24440D4D405F0D501A6A524A405439ED29390F4D4080F0A1444B564A405439ED29390F4D4080F0A1444B564A40FB3E1C24440D4D405F0D501A6A524A40FB3E1C24440D4D40
21647	Чура	7	65	1000	52.501694999999998	52.515943	58.108781999999998	58.096935999999999	0103000020E610000001000000050000008AC8B08A37404A400CE71A66680C4D408AC8B08A37404A405D328E91EC0D4D40D1CC936B0A424A405D328E91EC0D4D40D1CC936B0A424A400CE71A66680C4D408AC8B08A37404A400CE71A66680C4D40
18929	Чажайский Лесоучасток	7	65	1000	52.705522999999999	52.725771000000002	58.336620000000003	58.325488	0103000020E61000000100000005000000B4C9E1934E5A4A40C79E3D97A9294D40B4C9E1934E5A4A40FB96395D162B4D404FB16A10E65C4A40FB96395D162B4D404FB16A10E65C4A40C79E3D97A9294D40B4C9E1934E5A4A40C79E3D97A9294D40
21420	Удмуртские Ключи	7	65	1000	52.451802999999998	52.472572	58.048606999999997	58.034215000000003	0103000020E610000001000000050000000A9E42AED4394A402E04392861044D400A9E42AED4394A40A7AD11C138064D40AE80423D7D3C4A40A7AD11C138064D40AE80423D7D3C4A402E04392861044D400A9E42AED4394A402E04392861044D40
21815	Трубашур	7	65	1000	52.802289999999999	52.817901999999997	58.012157000000002	58.000487999999997	0103000020E6100000010000000500000034F44F70B1664A402D05A4FD0F004D4034F44F70B1664A4070B54E5C8E014D409FAA4203B1684A4070B54E5C8E014D409FAA4203B1684A402D05A4FD0F004D4034F44F70B1664A402D05A4FD0F004D40
22049	Сева	7	65	1000	52.952801999999998	53.010798000000001	58.472821000000003	58.448957999999998	0103000020E610000001000000050000001DC87A6AF5794A4087A3AB7477394D401DC87A6AF5794A4057EE0566853C4D405D6E30D461814A4057EE0566853C4D405D6E30D461814A4087A3AB7477394D401DC87A6AF5794A4087A3AB7477394D40
22141	Пусошур	7	65	1000	52.707912999999998	52.741743	57.954630999999999	57.941094999999997	0103000020E61000000100000005000000E5B4A7E49C5A4A40EDB60BCD75F84C40E5B4A7E49C5A4A40B75F3E5931FA4C40BA84436FF15E4A40B75F3E5931FA4C40BA84436FF15E4A40EDB60BCD75F84C40E5B4A7E49C5A4A40EDB60BCD75F84C40
21944	Понино	7	65	1000	52.796261999999999	52.825619000000003	58.257072999999998	58.240881000000002	0103000020E610000001000000050000001686C8E9EB654A40289D4830D51E4D401686C8E9EB654A40A1D79FC4E7204D4066FA25E2AD694A40A1D79FC4E7204D4066FA25E2AD694A40289D4830D51E4D401686C8E9EB654A40289D4830D51E4D40
21919	Парзи	7	65	1000	52.567802	52.597698000000001	57.949893000000003	57.932355999999999	0103000020E610000001000000050000003C4D66BCAD484A405C1D007157F74C403C4D66BCAD484A4084D9041896F94C403B71395E814C4A4084D9041896F94C403B71395E814C4A405C1D007157F74C403C4D66BCAD484A405C1D007157F74C40
22102	Отогурт	7	65	1000	52.635302000000003	52.663617000000002	57.891545000000001	57.878903000000001	0103000020E61000000100000005000000AD8A709351514A409BADBCE47FF04C40AD8A709351514A40C7F484251EF24C40EA08E066F1544A40C7F484251EF24C40EA08E066F1544A409BADBCE47FF04C40AD8A709351514A409BADBCE47FF04C40
8580	Октябрьский	7	65	1000	52.851571	52.883893	58.090494999999997	58.078913999999997	0103000020E610000001000000050000006B9C4D47006D4A4028999CDA190A4D406B9C4D47006D4A40CBB91457950B4D40E814E46723714A40CBB91457950B4D40E814E46723714A4028999CDA190A4D406B9C4D47006D4A4028999CDA190A4D40
21378	Люм	7	65	1000	52.446987999999997	52.478555	58.263010000000001	58.244661000000001	0103000020E610000001000000050000002BDA1CE736394A40A7CD380D511F4D402BDA1CE736394A40AF42CA4FAA214D402C2B4D4A413D4A40AF42CA4FAA214D402C2B4D4A413D4A40A7CD380D511F4D402BDA1CE736394A40A7CD380D511F4D40
21701	Курегово	7	65	1000	53.049497000000002	53.071559999999998	58.205604999999998	58.191799000000003	0103000020E610000001000000050000000420EEEA55864A40E833A0DE8C184D400420EEEA55864A407172BF43511A4D40D3D9C9E028894A407172BF43511A4D40D3D9C9E028894A40E833A0DE8C184D400420EEEA55864A40E833A0DE8C184D40
56383	Кочищево	7	65	1000	52.732616	52.755685	58.052168999999999	58.040452000000002	0103000020E610000001000000050000005F43705CC65D4A406687F8872D054D405F43705CC65D4A40B96E4A79AD064D40F4893C49BA604A40B96E4A79AD064D40F4893C49BA604A406687F8872D054D405F43705CC65D4A406687F8872D054D40
21557	Кожиль	7	65	1000	52.344912000000001	52.468763000000003	58.177821000000002	58.137684	0103000020E61000000100000005000000BDFF8F13262C4A405B971AA19F114D40BDFF8F13262C4A4061C5A9D6C2164D4095490D6D003C4A4061C5A9D6C2164D4095490D6D003C4A405B971AA19F114D40BDFF8F13262C4A405B971AA19F114D40
21522	Качкашур	7	65	1000	52.758460999999997	52.803511	58.111535000000003	58.096403000000002	0103000020E610000001000000050000004E25034015614A403F1EFAEE560C4D404E25034015614A4000AE64C7460E4D40F67CCD72D9664A4000AE64C7460E4D40F67CCD72D9664A403F1EFAEE560C4D404E25034015614A403F1EFAEE560C4D40
22003	Золотарево	7	65	1000	52.821396999999997	52.845219999999998	58.318862000000003	58.308542000000003	0103000020E610000001000000050000002904728923694A40A2B8E34D7E274D402904728923694A40F5F75278D0284D406AF6402B306C4A40F5F75278D0284D406AF6402B306C4A40A2B8E34D7E274D402904728923694A40A2B8E34D7E274D40
21287	Дондыкар	7	65	1000	52.688355999999999	52.711433999999997	58.260156000000002	58.247422	0103000020E61000000100000005000000B000A60C1C584A40CC272B86AB1F4D40B000A60C1C584A40D9EDB3CA4C214D4098A1F144105B4A40D9EDB3CA4C214D4098A1F144105B4A40CC272B86AB1F4D40B000A60C1C584A40CC272B86AB1F4D40
21608	Дзякино	7	65	1000	52.307884000000001	52.359645	58.185665	58.174599000000001	0103000020E61000000100000005000000187B2FBE68274A400875914259164D40187B2FBE68274A408481E7DEC3174D40C095ECD8082E4A408481E7DEC3174D40C095ECD8082E4A400875914259164D40187B2FBE68274A400875914259164D40
18655	Гулеково	7	65	1000	52.437080000000002	52.459069999999997	58.004455999999998	57.989063999999999	0103000020E610000001000000050000002BDEC83CF2374A4052D32EA699FE4C402BDEC83CF2374A40AF22A30392004D40904946CEC23A4A40AF22A30392004D40904946CEC23A4A4052D32EA699FE4C402BDEC83CF2374A4052D32EA699FE4C40
21334	Верхняя Слудка	7	65	1000	52.553187000000001	52.583872999999997	58.219866000000003	58.209848999999998	0103000020E6100000010000000500000043C9E4D4CE464A40950C0055DC1A4D4043C9E4D4CE464A404DC0AF91241C4D403A02B859BC4A4A404DC0AF91241C4D403A02B859BC4A4A40950C0055DC1A4D4043C9E4D4CE464A40950C0055DC1A4D40
21158	Адам	7	65	1000	52.816735000000001	52.852091999999999	58.146585999999999	58.133612999999997	0103000020E61000000100000005000000D13FC1C58A684A4004A9143B1A114D40D13FC1C58A684A4096067E54C3124D407497C459116D4A4096067E54C3124D407497C459116D4A4004A9143B1A114D40D13FC1C58A684A4004A9143B1A114D40
56358	Глазов	7	65	7409	52.580370000000002	52.723354999999998	58.166867000000003	58.112704999999998	0103000020E610000001000000050000002ECA6C90494A4A403F8C101E6D0E4D402ECA6C90494A4A400DE4D9E55B154D40F4328AE5965C4A400DE4D9E55B154D40F4328AE5965C4A403F8C101E6D0E4D402ECA6C90494A4A403F8C101E6D0E4D40
20158	Черновский Лесоучасток	7	65	1557	53.636401999999997	53.667591999999999	57.167749999999998	57.152745000000003	0103000020E61000000100000005000000F38DE89E75D14A4053D0ED258D934C40F38DE89E75D14A40B6F3FDD478954C401E8997A773D54A40B6F3FDD478954C401E8997A773D54A4053D0ED258D934C40F38DE89E75D14A4053D0ED258D934C40
21088	Черная	7	65	1557	53.493201999999997	53.520879000000001	57.068103999999998	57.049793999999999	0103000020E6100000010000000500000030293E3E21BF4A40BDC458A65F864C4030293E3E21BF4A40075DC2A1B7884C402B16BF29ACC24A40075DC2A1B7884C402B16BF29ACC24A40BDC458A65F864C4030293E3E21BF4A40BDC458A65F864C40
20814	Черепановка	7	65	1557	54.161414000000001	54.179371000000003	57.124032	57.110398000000004	0103000020E61000000100000005000000EB8EC536A9144B409CC58B85218E4C40EB8EC536A9144B4028D4D347E08F4C40E86C01A1F5164B4028D4D347E08F4C40E86C01A1F5164B409CC58B85218E4C40EB8EC536A9144B409CC58B85218E4C40
21013	Светлое	7	65	1557	53.611510000000003	53.642178999999999	57.072298000000004	57.049205999999998	0103000020E61000000100000005000000A796ADF545CE4A402C62D8614C864C40A796ADF545CE4A407AC8940F41894C40C896E5EB32D24A407AC8940F41894C40C896E5EB32D24A402C62D8614C864C40A796ADF545CE4A402C62D8614C864C40
18614	Пихтовка	7	65	1557	54.138866	54.159706999999997	57.155743000000001	57.145895000000003	0103000020E610000001000000050000005F43705CC6114B4031D3F6AFAC924C405F43705CC6114B405CCAF962EF934C409CF86A4771144B405CCAF962EF934C409CF86A4771144B4031D3F6AFAC924C405F43705CC6114B4031D3F6AFAC924C40
20907	Перевозное	7	65	1557	53.899779000000002	53.937930999999999	56.893441000000003	56.869441000000002	0103000020E61000000100000005000000555051F52BF34A409966BAD7496F4C40555051F52BF34A40E9F351465C724C40C9737D1F0EF84A40E9F351465C724C40C9737D1F0EF84A409966BAD7496F4C40555051F52BF34A409966BAD7496F4C40
20801	Первомайский	7	65	1557	54.111809000000001	54.147956999999998	57.077088000000003	57.054825999999998	0103000020E610000001000000050000000133DFC14F0E4B40397CD28904874C400133DFC14F0E4B4000750305DE894C406D1B4641F0124B4000750305DE894C406D1B4641F0124B40397CD28904874C400133DFC14F0E4B40397CD28904874C40
20936	Ольхово	7	65	1557	53.778452999999999	53.809508000000001	56.900106999999998	56.890510999999996	0103000020E610000001000000050000008E3C1059A4E34A4037DDB243FC714C408E3C1059A4E34A4049F3C7B436734C40D9EC48F59DE74A4049F3C7B436734C40D9EC48F59DE74A4037DDB243FC714C408E3C1059A4E34A4037DDB243FC714C40
56362	Новый	7	65	1557	54.029342999999997	54.042772999999997	56.813916999999996	56.807270000000003	0103000020E61000000100000005000000EAAEEC82C1034B405E85949F54674C40EAAEEC82C1034B404754A86E2E684C406E13EE9579054B404754A86E2E684C406E13EE9579054B405E85949F54674C40EAAEEC82C1034B405E85949F54674C40
20363	Молчаны	7	65	1557	53.626089999999998	53.655068999999997	56.879657999999999	56.862991000000001	0103000020E61000000100000005000000232D95B723D04A4005DF347D766E4C40232D95B723D04A4017D522A298704C40CCCF0D4DD9D34A4017D522A298704C40CCCF0D4DD9D34A4005DF347D766E4C40232D95B723D04A4005DF347D766E4C40
20720	Кукуй	7	65	1557	53.793337999999999	53.814250999999999	57.007523999999997	56.995730000000002	0103000020E6100000010000000500000047567E198CE54A40B3D2A414747F4C4047567E198CE54A40B1F7E28BF6804C401EDE736039E84A40B1F7E28BF6804C401EDE736039E84A40B3D2A414747F4C4047567E198CE54A40B3D2A414747F4C40
21063	Кудрино	7	65	1557	53.557862999999998	53.585045999999998	57.022103000000001	57.003048999999997	0103000020E610000001000000050000000053060E68C74A408BA4DDE863804C400053060E68C74A405E126745D4824C40EB538EC9E2CA4A405E126745D4824C40EB538EC9E2CA4A408BA4DDE863804C400053060E68C74A408BA4DDE863804C40
19815	Кельчино	7	65	1557	54.166812999999998	54.200930999999997	57.242930000000001	57.231693	0103000020E6100000010000000500000019C6DD205A154B4027DBC01DA89D4C4019C6DD205A154B40D09B8A54189F4C4054E0641BB8194B40D09B8A54189F4C4054E0641BB8194B4027DBC01DA89D4C4019C6DD205A154B4027DBC01DA89D4C40
20584	Кварса	7	65	1557	53.923620999999997	53.973325000000003	56.970990999999998	56.949722000000001	0103000020E610000001000000050000000C73823639F64A405725917D90794C400C73823639F64A40ECDADE6E497C4C408AB0E1E995FC4A40ECDADE6E497C4C408AB0E1E995FC4A405725917D90794C400C73823639F64A405725917D90794C40
20496	Камское	7	65	1557	54.197113000000002	54.227044999999997	57.043908999999999	57.021298999999999	0103000020E61000000100000005000000E84EB0FF3A194B400038F6ECB9824C40E84EB0FF3A194B40028063CF9E854C4033DC80CF0F1D4B40028063CF9E854C4033DC80CF0F1D4B400038F6ECB9824C40E84EB0FF3A194B400038F6ECB9824C40
20388	Июльское	7	65	1557	53.579098999999999	53.630456000000002	56.936253999999998	56.907200000000003	0103000020E61000000100000005000000BA1281EA1FCA4A4032772D211F744C40BA1281EA1FCA4A40E55FCB2BD7774C4093C83EC8B2D04A40E55FCB2BD7774C4093C83EC8B2D04A4032772D211F744C40BA1281EA1FCA4A4032772D211F744C40
20599	Двигатель	7	65	1557	53.903920999999997	53.932828000000001	57.016041999999999	57.003053999999999	0103000020E610000001000000050000007495EEAEB3F34A409D0FCF1264804C407495EEAEB3F34A4064AE0CAA0D824C4084656CE866F74A4064AE0CAA0D824C4084656CE866F74A409D0FCF1264804C407495EEAEB3F34A409D0FCF1264804C40
20227	Гавриловка	7	65	1557	54.055844	54.082819999999998	57.040241000000002	57.027075000000004	0103000020E61000000100000005000000C3D66CE525074B4005C58F3177834C40C3D66CE525074B40AB7AF99D26854C4034BA83D8990A4B40AB7AF99D26854C4034BA83D8990A4B4005C58F3177834C40C3D66CE525074B4005C58F3177834C40
20079	Верхняя Талица	7	65	1557	53.727392999999999	53.768554000000002	57.079684999999998	57.063177000000003	0103000020E610000001000000050000006F2BBD361BDD4A40016E162F16884C406F2BBD361BDD4A40AA7D3A1E338A4C40E19A3BFA5FE24A40AA7D3A1E338A4C40E19A3BFA5FE24A40016E162F16884C406F2BBD361BDD4A40016E162F16884C40
56384	Верхнепозимь	7	65	1557	53.652231	53.678255	56.969397000000001	56.957020999999997	0103000020E61000000100000005000000FC372F4E7CD34A40E84A04AA7F7A4C40FC372F4E7CD34A4096EB6D33157C4C409BAC510FD1D64A4096EB6D33157C4C409BAC510FD1D64A40E84A04AA7F7A4C40FC372F4E7CD34A40E84A04AA7F7A4C40
19748	Большая Кивара	7	65	1557	54.178167000000002	54.205044999999998	57.191616000000003	57.174200999999996	0103000020E61000000100000005000000FC1C1F2DCE164B401AF7E6374C964C40FC1C1F2DCE164B40F7B182DF86984C40AA9A20EA3E1A4B40F7B182DF86984C40AA9A20EA3E1A4B401AF7E6374C964C40FC1C1F2DCE164B401AF7E6374C964C40
19663	Болгуры	7	65	1557	53.751548	53.794209000000002	56.970353000000003	56.934033999999997	0103000020E61000000100000005000000E6AF90B932E04A4010AD156D8E774C40E6AF90B932E04A40AA49F086347C4C402D98F8A3A8E54A40AA49F086347C4C402D98F8A3A8E54A4010AD156D8E774C40E6AF90B932E04A4010AD156D8E774C40
20229	Беркуты	7	65	1557	54.052888000000003	54.066498000000003	56.936650999999998	56.930954999999997	0103000020E61000000100000005000000E92CB308C5064B401A868F8829774C40E92CB308C5064B400262122EE4774C40ED9FA70183084B400262122EE4774C40ED9FA70183084B401A868F8829774C40E92CB308C5064B401A868F8829774C40
56363	Воткинск	7	65	7410	53.890571999999999	54.031939999999999	57.083525000000002	57.022015000000003	0103000020E61000000100000005000000DD5D6743FEF14A40BF823463D1824C40DD5D6743FEF14A40FFB27BF2B08A4C4095B7239C16044B40FFB27BF2B08A4C4095B7239C16044B40BF823463D1824C40DD5D6743FEF14A40BF823463D1824C40
18858	Яголуд	7	65	1535	52.105196999999997	52.122570000000003	56.740921999999998	56.731960999999998	0103000020E6100000010000000500000093516518770D4A404679E6E5B05D4C4093516518770D4A4086713788D65E4C4041BCAE5FB00F4A4086713788D65E4C4041BCAE5FB00F4A404679E6E5B05D4C4093516518770D4A404679E6E5B05D4C40
56403	Уе-Докья	7	65	1535	51.999771000000003	52.023952999999999	56.752268999999998	56.741459999999996	0103000020E610000001000000050000009F3E027FF8FF494065A54929E85E4C409F3E027FF8FF4940B665C0594A604C400FD253E410034A40B665C0594A604C400FD253E410034A4065A54929E85E4C409F3E027FF8FF494065A54929E85E4C40
19235	Тыловыл-Пельга	7	65	1535	51.731929000000001	51.751288000000002	56.572870000000002	56.556170000000002	0103000020E610000001000000050000003BFF76D9AFDD494017821C9430474C403BFF76D9AFDD4940056EDDCD53494C404AF086342AE04940056EDDCD53494C404AF086342AE0494017821C9430474C403BFF76D9AFDD494017821C9430474C40
19197	Ожги	7	65	1535	51.760064	51.791308000000001	56.611305000000002	56.602967	0103000020E61000000100000005000000F86EF3C649E149409BC8CC052E4D4C40F86EF3C649E14940CE70033E3F4E4C4016889E9449E54940CE70033E3F4E4C4016889E9449E549409BC8CC052E4D4C40F86EF3C649E149409BC8CC052E4D4C40
18611	Нюрдор-Котья	7	65	1535	51.858995999999998	51.881517000000002	56.812108000000002	56.798596000000003	0103000020E6100000010000000500000089B2B794F3ED4940B45BCB6438664C4089B2B794F3ED4940F568AA27F3674C401CEF8E8CD5F04940F568AA27F3674C401CEF8E8CD5F04940B45BCB6438664C4089B2B794F3ED4940B45BCB6438664C40
19320	Новая Бия	7	65	1535	51.686599999999999	51.714061999999998	56.816971000000002	56.789470999999999	0103000020E6100000010000000500000080B74082E2D74940F911BF620D654C4080B74082E2D74940E563778192684C407EA8346266DB4940E563778192684C407EA8346266DB4940F911BF620D654C4080B74082E2D74940F911BF620D654C40
19530	Монья	7	65	1535	51.490498000000002	51.522640000000003	56.762354999999999	56.747180999999998	0103000020E61000000100000005000000706072A3C8BE4940A69883A0A35F4C40706072A3C8BE4940967840D994614C406DCA15DEE5C24940967840D994614C406DCA15DEE5C24940A69883A0A35F4C40706072A3C8BE4940A69883A0A35F4C40
18520	Лыстем	7	65	1535	51.794811000000003	51.823512000000001	56.842644	56.834603999999999	0103000020E6100000010000000500000023C0E95DBCE549402E8ECA4DD46A4C4023C0E95DBCE54940D71533C2DB6B4C4089EE59D768E94940D71533C2DB6B4C4089EE59D768E949402E8ECA4DD46A4C4023C0E95DBCE549402E8ECA4DD46A4C40
18833	Каменный Ключ	7	65	1535	52.162950000000002	52.178733000000001	56.826231999999997	56.815094000000002	0103000020E610000001000000050000000D71AC8BDB144A403A950C0055684C400D71AC8BDB144A404F745DF8C1694C40A5DB12B9E0164A404F745DF8C1694C40A5DB12B9E0164A403A950C0055684C400D71AC8BDB144A403A950C0055684C40
18532	Какмож	7	65	1535	51.838317000000004	51.874797000000001	56.858189000000003	56.846563000000003	0103000020E610000001000000050000002657B1F84DEB49407880272D5C6C4C402657B1F84DEB4940BB641C23D96D4C40C8D11C59F9EF4940BB641C23D96D4C40C8D11C59F9EF49407880272D5C6C4C402657B1F84DEB49407880272D5C6C4C40
19446	Зямбайгурт	7	65	1535	51.609245999999999	51.632899000000002	56.766055000000001	56.752802000000003	0103000020E61000000100000005000000029CDEC5FBCD4940842EE1D05B604C40029CDEC5FBCD4940F9F719170E624C40E7559DD502D14940F9F719170E624C40E7559DD502D14940842EE1D05B604C40029CDEC5FBCD4940842EE1D05B604C40
19143	Зядлуд	7	65	1535	51.740184999999997	51.762453999999998	56.728484000000002	56.716121999999999	0103000020E61000000100000005000000B0FECF61BEDE49401AF9BCE2A95B4C40B0FECF61BEDE494063D4B5F63E5D4C40295AB91798E1494063D4B5F63E5D4C40295AB91798E149401AF9BCE2A95B4C40B0FECF61BEDE49401AF9BCE2A95B4C40
54702	Зяглуд-Какся	7	65	1535	52.133457999999997	52.156365000000001	56.814424000000002	56.802695999999997	0103000020E61000000100000005000000DDB1D82615114A40A45016BEBE664C40DDB1D82615114A40EC89AE0B3F684C40999EB0C403144A40EC89AE0B3F684C40999EB0C403144A40A45016BEBE664C40DDB1D82615114A40A45016BEBE664C40
18386	Жуе-Можга	7	65	1535	51.951225999999998	51.976055000000002	56.831536	56.822065000000002	0103000020E610000001000000050000006D8D08C6C1F94940D717096D39694C406D8D08C6C1F949402CB98AC56F6A4C40740CC85EEFFC49402CB98AC56F6A4C40740CC85EEFFC4940D717096D39694C406D8D08C6C1F94940D717096D39694C40
19299	Дубровка	7	65	1535	51.772371	51.778739999999999	56.554478000000003	56.551248999999999	0103000020E610000001000000050000007DB08C0DDDE24940F279C5538F464C407DB08C0DDDE24940FE2C9622F9464C40240B98C0ADE34940FE2C9622F9464C40240B98C0ADE34940F279C5538F464C407DB08C0DDDE24940F279C5538F464C40
19066	Волипельга	7	65	1535	51.767718000000002	51.794946000000003	56.689289000000002	56.672102000000002	0103000020E6100000010000000500000078465B9544E24940C1C9367007564C4078465B9544E249400C3F389F3A584C40030B60CAC0E549400C3F389F3A584C40030B60CAC0E54940C1C9367007564C4078465B9544E24940C1C9367007564C40
19402	Водзимонье	7	65	1535	51.604295999999998	51.640732	56.823912	56.806279000000004	0103000020E61000000100000005000000438D429259CD4940CE39782634674C40438D429259CD49401764CBF275694C4016C0948103D249401764CBF275694C4016C0948103D24940CE39782634674C40438D429259CD4940CE39782634674C40
18216	Вавож	7	65	1535	51.907262000000003	51.951585000000001	56.784891000000002	56.760959	0103000020E61000000100000005000000A873452921F44940664CC11A67614C40A873452921F449405EF6EB4E77644C409D2E8B89CDF949405EF6EB4E77644C409D2E8B89CDF94940664CC11A67614C40A873452921F44940664CC11A67614C40
19498	Брызгалово	7	65	1535	51.479807999999998	51.514851	56.723719000000003	56.707935999999997	0103000020E61000000100000005000000F92D3A596ABD49409DD497A59D5A4C40F92D3A596ABD4940363FFED2A25C4C400DA837A3E6C14940363FFED2A25C4C400DA837A3E6C149409DD497A59D5A4C40F92D3A596ABD49409DD497A59D5A4C40
18932	Большое Волково	7	65	1535	51.969721999999997	51.989018000000002	56.709175999999999	56.692219999999999	0103000020E61000000100000005000000191BBAD91FFC49408DD13AAA9A584C40191BBAD91FFC4940D68D7747C65A4C40E2934E2498FE4940D68D7747C65A4C40E2934E2498FE49408DD13AAA9A584C40191BBAD91FFC49408DD13AAA9A584C40
18410	Большая Можга	7	65	1535	51.920017999999999	51.948144999999997	56.871679999999998	56.856268999999998	0103000020E610000001000000050000009CDD5A26C3F5494010CAFB389A6D4C409CDD5A26C3F54940E449D235936F4C40D66EBBD05CF94940E449D235936F4C40D66EBBD05CF9494010CAFB389A6D4C409CDD5A26C3F5494010CAFB389A6D4C40
18631	Большая Гурезь-Пудга	7	65	1535	52.068500999999998	52.089655999999998	56.779381999999998	56.764910999999998	0103000020E61000000100000005000000245F09A4C4084A40E2AC889AE8614C40245F09A4C4084A40A88B14CAC2634C40F1F109D9790B4A40A88B14CAC2634C40F1F109D9790B4A40E2AC889AE8614C40245F09A4C4084A40E2AC889AE8614C40
19047	Березек	7	65	1535	52.008564999999997	52.031706	56.677191000000001	56.663781999999998	0103000020E61000000100000005000000F3716DA818014A4034D6FECEF6544C40F3716DA818014A40A112D731AE564C40228B34F10E044A40A112D731AE564C40228B34F10E044A4034D6FECEF6544C40F3716DA818014A4034D6FECEF6544C40
16727	Ягошур	7	65	1392	52.882851000000002	52.905704	57.917879999999997	57.907972999999998	0103000020E61000000100000005000000D61EF64201714A405453927538F44C40D61EF64201714A4084D382177DF54C409EEDD11BEE734A4084D382177DF54C409EEDD11BEE734A405453927538F44C40D61EF64201714A405453927538F44C40
16613	Юнда	7	65	1392	52.869394	52.909799999999997	57.888789000000003	57.875683000000002	0103000020E6100000010000000500000058AB764D486F4A40E3546B6116F04C4058AB764D486F4A40B40584D6C3F14C404DF38E5374744A40B40584D6C3F14C404DF38E5374744A40E3546B6116F04C4058AB764D486F4A40E3546B6116F04C40
17232	Эркешево	7	65	1392	53.178925999999997	53.194225000000003	58.06532	58.056074000000002	0103000020E61000000100000005000000B933130CE7964A40F513CE6E2D074D40B933130CE7964A402AE3DF675C084D406688635DDC984A402AE3DF675C084D406688635DDC984A40F513CE6E2D074D40B933130CE7964A40F513CE6E2D074D40
17903	Шарпа	7	65	1392	53.433087	53.444343000000003	58.343190999999997	58.337017000000003	0103000020E6100000010000000500000050A912656FB74A401899805F232B4D4050A912656FB74A4009A4C4AEED2B4D40709A3E3BE0B84A4009A4C4AEED2B4D40709A3E3BE0B84A401899805F232B4D4050A912656FB74A401899805F232B4D40
16919	Ушур	7	65	1392	52.941313000000001	52.964058000000001	57.791609999999999	57.776471000000001	0103000020E610000001000000050000005B26C3F17C784A406EA5D76663E34C405B26C3F17C784A40E197FA7953E54C403DB9A640667B4A40E197FA7953E54C403DB9A640667B4A406EA5D76663E34C405B26C3F17C784A406EA5D76663E34C40
17112	Турецкое	7	65	1392	53.234406	53.261975999999997	58.007852	57.999082000000001	0103000020E610000001000000050000003BFE0B04019E4A40DA0242EBE1FF4C403BFE0B04019E4A40A69A594B01014D401F2BF86D88A14A40A69A594B01014D401F2BF86D88A14A40DA0242EBE1FF4C403BFE0B04019E4A40DA0242EBE1FF4C40
16119	Такапи	7	65	1392	53.034612000000003	53.053170999999999	57.959482000000001	57.947625000000002	0103000020E610000001000000050000004B06802A6E844A409EEFA7C64BF94C404B06802A6E844A40E38C614ED0FA4C403D0CAD4ECE864A40E38C614ED0FA4C403D0CAD4ECE864A409EEFA7C64BF94C404B06802A6E844A409EEFA7C64BF94C40
17821	Сергино	7	65	1392	53.519199	53.542268	58.412505000000003	58.401958	0103000020E61000000100000005000000D68EE21C75C24A40CB2E185C73334D40D68EE21C75C24A40DF37BEF6CC344D406BD5AE0969C54A40DF37BEF6CC344D406BD5AE0969C54A40CB2E185C73334D40D68EE21C75C24A40CB2E185C73334D40
16503	Пышкец	7	65	1392	53.201940999999998	53.230283	57.892803000000001	57.878985	0103000020E610000001000000050000005B5CE333D9994A4058569A9482F04C405B5CE333D9994A40A662635E47F24C4092E9D0E9799D4A40A662635E47F24C4092E9D0E9799D4A4058569A9482F04C405B5CE333D9994A4058569A9482F04C40
16191	Пыбья	7	65	1392	52.895732000000002	52.913590999999997	57.998246999999999	57.979807999999998	0103000020E6100000010000000500000087FD9E58A7724A40F92D3A596AFD4C4087FD9E58A7724A40412AC58EC6FF4C40C075C58CF0744A40412AC58EC6FF4C40C075C58CF0744A40F92D3A596AFD4C4087FD9E58A7724A40F92D3A596AFD4C40
16228	Подборново	7	65	1392	52.968809999999998	52.987774000000002	58.091613000000002	58.081493000000002	0103000020E61000000100000005000000D50451F7017C4A402DEDD45C6E0A4D40D50451F7017C4A40B9718BF9B90B4D4068EBE0606F7E4A40B9718BF9B90B4D4068EBE0606F7E4A402DEDD45C6E0A4D40D50451F7017C4A402DEDD45C6E0A4D40
18097	Пибаньшур	7	65	1392	53.253109000000002	53.288547999999999	57.877650000000003	57.852885000000001	0103000020E6100000010000000500000061A92EE065A04A40DE1FEF552BED4C4061A92EE065A04A40CEAACFD556F04C40C1A90F24EFA44A40CEAACFD556F04C40C1A90F24EFA44A40DE1FEF552BED4C4061A92EE065A04A40DE1FEF552BED4C40
16721	Падера	7	65	1392	52.931755000000003	52.972780999999998	57.921680000000002	57.907643	0103000020E61000000100000005000000377172BF43774A40BFB854A52DF44C40377172BF43774A404BB0389CF9F54C40C8957A16847C4A404BB0389CF9F54C40C8957A16847C4A40BFB854A52DF44C40377172BF43774A40BFB854A52DF44C40
17303	Оросово	7	65	1392	53.097377000000002	53.124155999999999	58.084729000000003	58.070656999999997	0103000020E61000000100000005000000F9307BD9768C4A40E21DE0490B094D40F9307BD9768C4A40EB025E66D80A4D4014CD0358E48F4A40EB025E66D80A4D4014CD0358E48F4A40E21DE0490B094D40F9307BD9768C4A40E21DE0490B094D40
17017	Нововолково	7	65	1392	53.075710000000001	53.098562999999999	57.844019000000003	57.821393	0103000020E6100000010000000500000076FD82DDB0894A40E814E46723E94C4076FD82DDB0894A40F01989D008EC4C403ECC5EB69D8C4A40F01989D008EC4C403ECC5EB69D8C4A40E814E46723E94C4076FD82DDB0894A40E814E46723E94C40
17019	Люк	7	65	1392	53.069817	53.114894	57.733790999999997	57.718513000000002	0103000020E6100000010000000500000038DA71C3EF884A401C60E63BF8DB4C4038DA71C3EF884A40B08C0DDDECDD4C40D940BAD8B48E4A40B08C0DDDECDD4C40D940BAD8B48E4A401C60E63BF8DB4C4038DA71C3EF884A401C60E63BF8DB4C40
56394	Котомка	7	65	1392	52.880955	52.901778	58.030155000000001	58.018512000000001	0103000020E61000000100000005000000B41F2922C3704A40B24AE9995E024D40B41F2922C3704A40CB67791EDC034D404B2025766D734A40CB67791EDC034D404B2025766D734A40B24AE9995E024D40B41F2922C3704A40B24AE9995E024D40
16818	Котегово	7	65	1392	52.797114999999998	52.824953999999998	57.917439999999999	57.903517000000001	0103000020E61000000100000005000000551344DD07664A40A530EF71A6F34C40551344DD07664A40680586AC6EF54C40295AB91798694A40680586AC6EF54C40295AB91798694A40A530EF71A6F34C40551344DD07664A40A530EF71A6F34C40
56385	Коршуново	7	65	1392	53.344853999999998	53.362569000000001	58.139594000000002	58.129707000000003	0103000020E6100000010000000500000088F2052D24AC4A40F9872D3D9A104D4088F2052D24AC4A40E25B5837DE114D408FC536A968AE4A40E25B5837DE114D408FC536A968AE4A40F9872D3D9A104D4088F2052D24AC4A40F9872D3D9A104D40
16109	Кожило	7	65	1392	52.998463999999998	53.009898999999997	58.017519999999998	57.996018999999997	0103000020E61000000100000005000000DE1D19ABCD7F4A40E998F38C7DFF4C40DE1D19ABCD7F4A40518369183E024D40ADA1D45E44814A40518369183E024D40ADA1D45E44814A40E998F38C7DFF4C40DE1D19ABCD7F4A40E998F38C7DFF4C40
17517	Киршонки	7	65	1392	53.373429999999999	53.400092000000001	58.222937000000002	58.211404000000002	0103000020E6100000010000000500000032ACE28DCCAF4A402E1F49490F1B4D4032ACE28DCCAF4A40C0081A33891C4D4014B2F33636B34A40C0081A33891C4D4014B2F33636B34A402E1F49490F1B4D4032ACE28DCCAF4A402E1F49490F1B4D40
18121	Кипрята	7	65	1392	53.465121000000003	53.475721	58.422747000000001	58.413772999999999	0103000020E6100000010000000500000067D7BD1589BB4A40E17B7F83F6344D4067D7BD1589BB4A40B6BDDD921C364D409D82FC6CE4BC4A40B6BDDD921C364D409D82FC6CE4BC4A40E17B7F83F6344D4067D7BD1589BB4A40E17B7F83F6344D40
16307	Кестым	7	65	1392	52.955866	52.988087999999998	58.035383000000003	58.023544999999999	0103000020E61000000100000005000000DEAD2CD1597A4A40FE7DC68503034D40DEAD2CD1597A4A40CDEA1D6E87044D40F7C8E6AA797E4A40CDEA1D6E87044D40F7C8E6AA797E4A40FE7DC68503034D40DEAD2CD1597A4A40FE7DC68503034D40
17624	Карсовай	7	65	1392	53.165227000000002	53.211373000000002	58.235242999999997	58.211674000000002	0103000020E6100000010000000500000046B5882826954A40EEB43522181B4D4046B5882826954A4074CE4F711C1E4D40F3203D450E9B4A4074CE4F711C1E4D40F3203D450E9B4A40EEB43522181B4D4046B5882826954A40EEB43522181B4D40
17119	Каменное Заделье	7	65	1392	53.203234999999999	53.222135000000002	57.942366	57.932155999999999	0103000020E610000001000000050000008733BF9A039A4A40956247E350F74C408733BF9A039A4A40616EF7729FF84C40032670EB6E9C4A40616EF7729FF84C40032670EB6E9C4A40956247E350F74C408733BF9A039A4A40956247E350F74C40
16827	Исаково	7	65	1392	52.908686000000003	52.935302999999998	57.850188000000003	57.836454000000003	0103000020E61000000100000005000000A22AA6D24F744A40E04DB7EC10EB4C40A22AA6D24F744A40D0B9DBF5D2EC4C40E36C3A02B8774A40D0B9DBF5D2EC4C40E36C3A02B8774A40E04DB7EC10EB4C40A22AA6D24F744A40E04DB7EC10EB4C40
16424	Заречный	7	65	1392	53.124848	53.137037999999997	57.881774999999998	57.874845000000001	0103000020E610000001000000050000004A7CEE04FB8F4A40D908C4EBFAEF4C404A7CEE04FB8F4A4017B7D100DEF04C40952710768A914A4017B7D100DEF04C40952710768A914A40D908C4EBFAEF4C404A7CEE04FB8F4A40D908C4EBFAEF4C40
16315	Гордино	7	65	1392	52.986561000000002	53.011794999999999	58.075183000000003	58.063659000000001	0103000020E6100000010000000500000029417FA1477E4A404C8C65FA25084D4029417FA1477E4A408B1BB7989F094D40CFA0A17F82814A408B1BB7989F094D40CFA0A17F82814A404C8C65FA25084D4029417FA1477E4A404C8C65FA25084D40
16399	Воегурт	7	65	1392	53.062379	53.094476	57.891036999999997	57.878109000000002	0103000020E61000000100000005000000857AFA08FC874A4061A92EE065F04C40857AFA08FC874A4052431B800DF24C40E22021CA178C4A4052431B800DF24C40E22021CA178C4A4061A92EE065F04C40857AFA08FC874A4061A92EE065F04C40
17507	Верх-Люкино	7	65	1392	53.310457999999997	53.331999000000003	58.173392999999997	58.164009	0103000020E610000001000000050000000A647616BDA74A40F59F353FFE144D400A647616BDA74A407B2DE8BD31164D4001A777F17EAA4A407B2DE8BD31164D4001A777F17EAA4A40F59F353FFE144D400A647616BDA74A40F59F353FFE144D40
16522	Быдыпи	7	65	1392	52.987073000000002	53.002380000000002	57.915370000000003	57.904124000000003	0103000020E61000000100000005000000DFE17668587E4A40ADC3D155BAF34C40DFE17668587E4A40A9DE1AD82AF54C400E15E3FC4D804A40A9DE1AD82AF54C400E15E3FC4D804A40ADC3D155BAF34C40DFE17668587E4A40ADC3D155BAF34C40
17206	Бурино	7	65	1392	53.058551999999999	53.084378999999998	57.986840999999998	57.974361999999999	0103000020E61000000100000005000000C58EC6A17E874A408A3BDEE4B7FC4C40C58EC6A17E874A400CAD4ECE50FE4C400EBC5AEECC8A4A400CAD4ECE50FE4C400EBC5AEECC8A4A408A3BDEE4B7FC4C40C58EC6A17E874A408A3BDEE4B7FC4C40
17431	Большой Варыж	7	65	1392	53.144503	53.166476000000003	58.123010000000001	58.109039000000003	0103000020E61000000100000005000000429605137F924A40897E6DFDF40D4D40429605137F924A405D8AABCABE0F4D40D2C8E7154F954A405D8AABCABE0F4D40D2C8E7154F954A40897E6DFDF40D4D40429605137F924A40897E6DFDF40D4D40
18036	Большое Сазаново	7	65	1392	53.311445999999997	53.335861999999999	58.102553	58.091970000000003	0103000020E61000000100000005000000293C6876DDA74A40481B47ACC50B4D40293C6876DDA74A40A88DEA74200D4D400DFCA886FDAA4A40A88DEA74200D4D400DFCA886FDAA4A40481B47ACC50B4D40293C6876DDA74A40481B47ACC50B4D40
16027	Балезино	7	65	1392	53.036102999999997	53.05583	58.030994	58.015880000000003	0103000020E61000000100000005000000CC24EA059F844A408B54185B08024D40CC24EA059F844A40A52F849CF7034D405E11FC6F25874A40A52F849CF7034D405E11FC6F25874A408B54185B08024D40CC24EA059F844A408B54185B08024D40
15239	Балезино	7	65	1392	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
17810	Базаны	7	65	1392	53.121262999999999	53.143658000000002	58.292831999999997	58.282603999999999	0103000020E61000000100000005000000809BC58B858F4A4001DC2C5E2C244D40809BC58B858F4A40739CDB847B254D4086E7A56263924A40739CDB847B254D4086E7A56263924A4001DC2C5E2C244D40809BC58B858F4A4001DC2C5E2C244D40
16619	Ахмади	7	65	1392	52.816699	52.836236999999997	57.826368000000002	57.818573999999998	0103000020E6100000010000000500000084D6C39789684A408EAD6708C7E84C4084D6C39789684A40003B376DC6E94C40425A63D0096B4A40003B376DC6E94C40425A63D0096B4A408EAD6708C7E84C4084D6C39789684A408EAD6708C7E84C40
16939	Андрейшур	7	65	1392	53.192042000000001	53.22739	57.790703000000001	57.777315999999999	0103000020E61000000100000005000000AEBA0ED594984A402A5437177FE34C40AEBA0ED594984A40AFEC82C135E54C40FEB7921D1B9D4A40AFEC82C135E54C40FEB7921D1B9D4A402A5437177FE34C40AEBA0ED594984A402A5437177FE34C40
17731	Андреевцы	7	65	1392	53.248320999999997	53.264105000000001	58.279879000000001	58.267848000000001	0103000020E610000001000000050000007BF486FBC89F4A404626E0D748224D407BF486FBC89F4A4029EB3713D3234D40E4DA5031CEA14A4029EB3713D3234D40E4DA5031CEA14A404626E0D748224D407BF486FBC89F4A404626E0D748224D40
56408	Удмуртское Гондырево	7	65	1333	52.242018999999999	52.259985999999998	56.129041999999998	56.113582000000001	0103000020E610000001000000050000005C01857AFA1E4A4007B5DFDA890E4C405C01857AFA1E4A40BCE7C07284104C407CB5A33847214A40BCE7C07284104C407CB5A33847214A4007B5DFDA890E4C405C01857AFA1E4A4007B5DFDA890E4C40
15452	Удмуртский Тоймобаш	7	65	1333	52.441149000000003	52.482418000000003	56.267217000000002	56.252132000000003	0103000020E61000000100000005000000E1D4079277384A40362383DC45204C40E1D4079277384A40B6F7A92A34224C4039807EDFBF3D4A40B6F7A92A34224C4039807EDFBF3D4A40362383DC45204C40E1D4079277384A40362383DC45204C40
58441	Татарский Тоймобаш	7	65	1333	52.472760999999998	52.485975000000003	56.225012999999997	56.212879999999998	0103000020E6100000010000000500000081E9B46E833C4A407AFCDEA63F1B4C4081E9B46E833C4A406116DA39CD1C4C4039D6C56D343E4A406116DA39CD1C4C4039D6C56D343E4A407AFCDEA63F1B4C4081E9B46E833C4A407AFCDEA63F1B4C40
15539	Сям-Какси	7	65	1333	52.348829000000002	52.359169000000001	56.259773000000003	56.249536999999997	0103000020E61000000100000005000000BD72BD6DA62C4A402B1213D4F01F4C40BD72BD6DA62C4A4021B1DD3D40214C40575EF23FF92D4A4021B1DD3D40214C40575EF23FF92D4A402B1213D4F01F4C40BD72BD6DA62C4A402B1213D4F01F4C40
15334	Старый Утчан	7	65	1333	52.331096000000002	52.351469999999999	56.168877000000002	56.157398000000001	0103000020E6100000010000000500000010EB8D5A612A4A40583A1F9E25144C4010EB8D5A612A4A40F705F4C29D154C4037C30DF8FC2C4A40F705F4C29D154C4037C30DF8FC2C4A40583A1F9E25144C4010EB8D5A612A4A40583A1F9E25144C40
14495	Старая Шудья	7	65	1333	52.540224000000002	52.557831	56.191237999999998	56.184054000000003	0103000020E61000000100000005000000D5415E0F26454A405859DB148F174C40D5415E0F26454A4050E09D7C7A184C40F5D8960167474A4050E09D7C7A184C40F5D8960167474A405859DB148F174C40D5415E0F26454A405859DB148F174C40
14487	Новый Утчан	7	65	1333	52.368465999999998	52.393197000000001	56.172865999999999	56.160806999999998	0103000020E610000001000000050000000ED8D5E4292F4A40E3FBE25295144C400ED8D5E4292F4A40904B1C7920164C4052F17F4754324A40904B1C7920164C4052F17F4754324A40E3FBE25295144C400ED8D5E4292F4A40E3FBE25295144C40
15553	Нижний Сырьез	7	65	1333	52.528922999999999	52.566257	56.307447000000003	56.292462999999998	0103000020E61000000100000005000000158DB5BFB3434A402025766D6F254C40158DB5BFB3434A406D205D6C5A274C40C710001C7B484A406D205D6C5A274C40C710001C7B484A402025766D6F254C40158DB5BFB3434A402025766D6F254C40
15076	Нижнее Котнырево	7	65	1333	52.394410000000001	52.412734999999998	56.111463999999998	56.102668999999999	0103000020E61000000100000005000000919BE1067C324A4011A8FE41240D4C40919BE1067C324A403657CD73440E4C4010751F80D4344A403657CD73440E4C4010751F80D4344A4011A8FE41240D4C40919BE1067C324A4011A8FE41240D4C40
15142	Нижнее Асаново	7	65	1333	52.490510999999998	52.519427999999998	56.092466000000002	56.079175999999997	0103000020E6100000010000000500000004AA7F10C93E4A4065506D70220A4C4004AA7F10C93E4A40F8FE06EDD50B4C403750E09D7C424A40F8FE06EDD50B4C403750E09D7C424A4065506D70220A4C4004AA7F10C93E4A4065506D70220A4C40
14975	Муважи	7	65	1333	52.685608000000002	52.715809	56.048993000000003	56.040058000000002	0103000020E6100000010000000500000020F0C000C2574A40BAF8DB9E20054C4020F0C000C2574A40D15D126745064C405B971AA19F5B4A40D15D126745064C405B971AA19F5B4A40BAF8DB9E20054C4020F0C000C2574A40BAF8DB9E20054C40
14861	Ляли	7	65	1333	52.790252000000002	52.818036999999997	56.158566	56.145760000000003	0103000020E610000001000000050000009FCC3FFA26654A4051888043A8124C409FCC3FFA26654A40F72004E44B144C407FF5B86FB5684A40F72004E44B144C407FF5B86FB5684A4051888043A8124C409FCC3FFA26654A4051888043A8124C40
14679	Кузюмово	7	65	1333	52.721117999999997	52.743648	56.195704999999997	56.179625999999999	0103000020E61000000100000005000000494739984D5C4A4072C119FCFD164C40494739984D5C4A40F35487DC0C194C402FDE8FDB2F5F4A40F35487DC0C194C402FDE8FDB2F5F4A4072C119FCFD164C40494739984D5C4A4072C119FCFD164C40
14888	Кузебаево	7	65	1333	52.689613999999999	52.718207	56.078839000000002	56.066800999999998	0103000020E610000001000000050000008F6E844545584A40882B67EF8C084C408F6E844545584A401E537765170A4C400F61FC34EE5B4A401E537765170A4C400F61FC34EE5B4A40882B67EF8C084C408F6E844545584A40882B67EF8C084C40
14967	Варзибаш	7	65	1333	52.632688000000002	52.651975	56.142496000000001	56.132247999999997	0103000020E610000001000000050000002C499EEBFB504A400F7BA180ED104C402C499EEBFB504A40C9E7154F3D124C40A167B3EA73534A40C9E7154F3D124C40A167B3EA73534A400F7BA180ED104C402C499EEBFB504A400F7BA180ED104C40
14775	Варзи-Ятчи	7	65	1333	52.783641000000003	52.806907000000002	56.135584000000001	56.118340000000003	0103000020E61000000100000005000000026729594E644A4082E7DEC3250F4C40026729594E644A4031EE06D15A114C40EDF483BA48674A4031EE06D15A114C40EDF483BA48674A4082E7DEC3250F4C40026729594E644A4082E7DEC3250F4C40
15039	Байтеряково	7	65	1333	52.415044000000002	52.439137000000002	56.083646999999999	56.072327999999999	0103000020E6100000010000000500000055336B2920354A40E44A3D0B42094C4055336B2920354A404AB4E4F1B40A4C4056BB26A435384A404AB4E4F1B40A4C4056BB26A435384A40E44A3D0B42094C4055336B2920354A40E44A3D0B42094C40
56386	Асановский	7	65	1333	52.567253999999998	52.585256999999999	56.079151000000003	56.066042000000003	0103000020E61000000100000005000000394371C79B484A40CB14731074084C40394371C79B484A400D39B69E210A4C40A6608DB3E94A4A400D39B69E210A4C40A6608DB3E94A4A40CB14731074084C40394371C79B484A40CB14731074084C40
14302	Алнаши	7	65	1333	52.448954999999998	52.564127999999997	56.197037999999999	56.111921000000002	0103000020E610000001000000050000001630815B77394A40295E656D530E4C401630815B77394A40DD088B8A38194C400261A75835484A40DD088B8A38194C400261A75835484A40295E656D530E4C401630815B77394A40295E656D530E4C40
14662	Азаматово	7	65	1333	52.612898000000001	52.639640999999997	56.195659999999997	56.186149	0103000020E6100000010000000500000054E41071734E4A407097FDBAD3174C4054E41071734E4A4053910A630B194C4022179CC1DF514A4053910A630B194C4022179CC1DF514A407097FDBAD3174C4054E41071734E4A407097FDBAD3174C40
61544	пос.Озерный	7	64	\N	47.257779999999997	54.268591999999998	56.675643000000001	53.974775999999999	0103000020E610000001000000050000000CC85EEFFEA047407D76C075C5FC4A400CC85EEFFEA04740BB6246787B564C40CEFBFF3861224B40BB6246787B564C40CEFBFF3861224B407D76C075C5FC4A400CC85EEFFEA047407D76C075C5FC4A40
61375	им. Кирова	7	64	\N	53.687624	53.716424000000004	55.557785000000003	55.545228000000002	0103000020E61000000100000005000000ECF82F1004D84A40876EF607CAC54B40ECF82F1004D84A408599B67F65C74B40E60819C8B3DB4A408599B67F65C74B40E60819C8B3DB4A40876EF607CAC54B40ECF82F1004D84A40876EF607CAC54B40
61430	ж/д ст. Акбаш	7	64	\N	52.581636000000003	52.607562000000001	54.425750000000001	54.412097000000003	0103000020E610000001000000050000009016670C734A4A40CEE33098BF344B409016670C734A4A40D122DBF97E364B406C257497C44D4A40D122DBF97E364B406C257497C44D4A40CEE33098BF344B409016670C734A4A40CEE33098BF344B40
61272	Шильнебаш	7	64	\N	47.257779999999997	54.268591999999998	56.675643000000001	53.974775999999999	0103000020E610000001000000050000000CC85EEFFEA047407D76C075C5FC4A400CC85EEFFEA04740BB6246787B564C40CEFBFF3861224B40BB6246787B564C40CEFBFF3861224B407D76C075C5FC4A400CC85EEFFEA047407D76C075C5FC4A40
3607	Чистополь	7	64	\N	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
40967	Усады	7	64	\N	49.201616999999999	49.232779999999998	55.687071000000003	55.671726999999997	0103000020E61000000100000005000000A8A8FA95CE9948408B6B7C26FBD54B40A8A8FA95CE994840D88349F1F1D74B40D9942BBCCB9D4840D88349F1F1D74B40D9942BBCCB9D48408B6B7C26FBD54B40A8A8FA95CE9948408B6B7C26FBD54B40
29378	Печищи	7	64	\N	48.931009000000003	48.961956000000001	55.784207000000002	55.768678999999999	0103000020E610000001000000050000000EA48B4D2B7748409D0FCF1264E24B400EA48B4D2B774840AB251DE560E44B407218CC5F217B4840AB251DE560E44B407218CC5F217B48409D0FCF1264E24B400EA48B4D2B7748409D0FCF1264E24B40
12275	Нурлат	7	64	\N	50.771701999999998	50.834853000000003	54.438696	54.410697999999996	0103000020E61000000100000005000000FF209221C76249402C4487C091344B40FF209221C76249406971C63027384B40D7FB8D76DC6A49406971C63027384B40D7FB8D76DC6A49402C4487C091344B40FF209221C76249402C4487C091344B40
8108	Новониколаевский	7	64	\N	48.956727999999998	48.96978	55.90249	55.889476999999999	0103000020E6100000010000000500000070952710767A4840A8C5E061DAF14B4070952710767A4840C87BD5CA84F34B404E2844C0217C4840C87BD5CA84F34B404E2844C0217C4840A8C5E061DAF14B4070952710767A4840A8C5E061DAF14B40
8191	Новая Тура	7	64	\N	48.832813999999999	48.850645999999998	55.873621999999997	55.860821999999999	0103000020E6100000010000000500000052D32EA6996A4840B2D6506A2FEE4B4052D32EA6996A484076887FD8D2EF4B40923CD7F7E16C484076887FD8D2EF4B40923CD7F7E16C4840B2D6506A2FEE4B4052D32EA6996A4840B2D6506A2FEE4B40
31212	Нижний Услон	7	64	\N	48.945597999999997	48.979050999999998	55.707070999999999	55.682046999999997	0103000020E61000000100000005000000DD94F25A09794840DEAAEB504DD74B40DD94F25A097948409A79724D81DA4B40DC0E0D8B517D48409A79724D81DA4B40DC0E0D8B517D4840DEAAEB504DD74B40DD94F25A09794840DEAAEB504DD74B40
61520	Нефтебаза	7	64	\N	47.257779999999997	54.268591999999998	56.675643000000001	53.974775999999999	0103000020E610000001000000050000000CC85EEFFEA047407D76C075C5FC4A400CC85EEFFEA04740BB6246787B564C40CEFBFF3861224B40BB6246787B564C40CEFBFF3861224B407D76C075C5FC4A400CC85EEFFEA047407D76C075C5FC4A40
1104	Набережные Челны	7	64	\N	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
21814	Лениногорск	7	64	\N	52.402296999999997	52.504731999999997	54.620140999999997	54.563912000000002	0103000020E61000000100000005000000B323D5777E334A4036E9B6442E484B40B323D5777E334A4051F4C0C7604F4B40519FE40E9B404A4051F4C0C7604F4B40519FE40E9B404A4036E9B6442E484B40B323D5777E334A4036E9B6442E484B40
61420	Ключищи	7	64	\N	48.439100000000003	49.493758999999997	55.967401000000002	55.371347	0103000020E6100000010000000500000039D6C56D34384840DE3B6A4C88AF4B4039D6C56D34384840118FC4CBD3FB4B40868DB27E33BF4840118FC4CBD3FB4B40868DB27E33BF4840DE3B6A4C88AF4B4039D6C56D34384840DE3B6A4C88AF4B40
61523	Карабаш	7	64	\N	52.537880000000001	52.597760999999998	54.713147999999997	54.687764000000001	0103000020E6100000010000000500000014967840D9444A40DEAE97A608584B4014967840D9444A40999A046F485B4B4081E9B46E834C4A40999A046F485B4B4081E9B46E834C4A40DEAE97A608584B4014967840D9444A40DEAE97A608584B40
134	Казань	7	64	\N	48.827953999999998	49.329726000000001	55.939070999999998	55.668802999999997	0103000020E61000000100000005000000D34B8C65FA694840BC3B32569BD54B40D34B8C65FA6948409ECF807A33F84B400952297634AA48409ECF807A33F84B400952297634AA4840BC3B32569BD54B40D34B8C65FA694840BC3B32569BD54B40
6600	Зеленодольск	7	64	\N	48.453923000000003	48.585436000000001	55.862842999999998	55.832681999999998	0103000020E610000001000000050000007CF31B261A3A4840E3FBE25295EA4B407CF31B261A3A4840904AB1A371EE4B4056F31C91EF4A4840904AB1A371EE4B4056F31C91EF4A4840E3FBE25295EA4B407CF31B261A3A4840E3FBE25295EA4B40
3350	Заинск	7	64	\N	51.967629000000002	52.097614999999998	55.331950999999997	55.266455999999998	0103000020E61000000100000005000000A2D45E44DBFB494057E9EE3A1BA24B40A2D45E44DBFB4940EF6FD05E7DAA4B40AD4CF8A57E0C4A40EF6FD05E7DAA4B40AD4CF8A57E0C4A4057E9EE3A1BA24B40A2D45E44DBFB494057E9EE3A1BA24B40
141	Елабуга	7	64	\N	51.993518000000002	52.110802999999997	55.772325000000002	55.737431000000001	0103000020E6100000010000000500000061FE0A992BFF49403E07962364DE4B4061FE0A992BFF49400D71AC8BDBE24B403BA6EECA2E0E4A400D71AC8BDBE24B403BA6EECA2E0E4A403E07962364DE4B4061FE0A992BFF49403E07962364DE4B40
31939	Высокая Гора	7	64	\N	49.287441999999999	49.335493	55.924567000000003	55.891905000000001	0103000020E6100000010000000500000098BF42E6CAA44840C7116BF129F24B4098BF42E6CAA44840FDFA213658F64B40BA84436FF1AA4840FDFA213658F64B40BA84436FF1AA4840C7116BF129F24B4098BF42E6CAA44840C7116BF129F24B40
28941	Верхний Услон	7	64	\N	48.954922000000003	48.995534999999997	55.784171999999998	55.751806999999999	0103000020E610000001000000050000008F1D54E23A7A4840B2F336363BE04B408F1D54E23A7A48402E3883BF5FE44B40FD82DDB06D7F48402E3883BF5FE44B40FD82DDB06D7F4840B2F336363BE04B408F1D54E23A7A4840B2F336363BE04B40
25001	Буинск	7	64	\N	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
22026	Бугульма	7	64	\N	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
59436	Бавлы	7	64	\N	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
60571	Бавлы	7	64	\N	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
59161	Арск	7	64	\N	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
4205	Альметьевск	7	64	\N	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
61508	Азьмушкино	7	64	\N	47.257779999999997	54.268591999999998	56.675643000000001	53.974775999999999	0103000020E610000001000000050000000CC85EEFFEA047407D76C075C5FC4A400CC85EEFFEA04740BB6246787B564C40CEFBFF3861224B40BB6246787B564C40CEFBFF3861224B407D76C075C5FC4A400CC85EEFFEA047407D76C075C5FC4A40
23555	Азнакаево	7	64	\N	53.043146	53.110142000000003	54.875158999999996	54.846384	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
61539	Агрыз	7	64	\N	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
60611	ж д ст Высокая Гора	7	64	7510	47.257779999999997	54.268591999999998	56.675643000000001	53.974775999999999	0103000020E610000001000000050000000CC85EEFFEA047407D76C075C5FC4A400CC85EEFFEA04740BB6246787B564C40CEFBFF3861224B40BB6246787B564C40CEFBFF3861224B407D76C075C5FC4A400CC85EEFFEA047407D76C075C5FC4A40
41030	п.г.т.Уруссу	7	64	923	53.029356999999997	53.640867	54.815285000000003	54.479497000000002	0103000020E610000001000000050000004F745DF8C1834A40DBC35E28603D4B404F745DF8C1834A40AEF545425B684B40F60A0BEE07D24A40AEF545425B684B40F60A0BEE07D24A40DBC35E28603D4B404F745DF8C1834A40DBC35E28603D4B40
7466	Яссы-Тугай	7	64	923	53.320554999999999	53.345329999999997	54.583801000000001	54.578879999999998	0103000020E61000000100000005000000DEC83CF207A94A407C2766BD184A4B40DEC83CF207A94A40A12FBDFDB94A4B40F12900C633AC4A40A12FBDFDB94A4B40F12900C633AC4A407C2766BD184A4B40DEC83CF207A94A407C2766BD184A4B40
7925	Ютаза	7	64	923	53.249965000000003	53.278602999999997	54.598610999999998	54.581389999999999	0103000020E61000000100000005000000841266DAFE9F4A40581CCEFC6A4A4B40841266DAFE9F4A404F0306499F4C4B40A3C85A43A9A34A404F0306499F4C4B40A3C85A43A9A34A40581CCEFC6A4A4B40841266DAFE9F4A40581CCEFC6A4A4B40
40942	Ютаза	7	64	923	53.249965000000003	53.278602999999997	54.598610999999998	54.581389999999999	0103000020E61000000100000005000000841266DAFE9F4A40581CCEFC6A4A4B40841266DAFE9F4A404F0306499F4C4B40A3C85A43A9A34A404F0306499F4C4B40A3C85A43A9A34A40581CCEFC6A4A4B40841266DAFE9F4A40581CCEFC6A4A4B40
32544	Уруссу	7	64	923	53.416252	53.481892000000002	54.607413999999999	54.587828999999999	0103000020E610000001000000050000008272DBBE47B54A40F8510DFB3D4B4B408272DBBE47B54A40F790F0BDBF4D4B401E1A16A3AEBD4A40F790F0BDBF4D4B401E1A16A3AEBD4A40F8510DFB3D4B4B408272DBBE47B54A40F8510DFB3D4B4B40
40943	Урал	7	64	923	53.118639999999999	53.138357999999997	54.692661000000001	54.683839999999996	0103000020E61000000100000005000000ACFF73982F8F4A402BD9B11188574B40ACFF73982F8F4A407A1B9B1DA9584B40EA9106B7B5914A407A1B9B1DA9584B40EA9106B7B5914A402BD9B11188574B40ACFF73982F8F4A402BD9B11188574B40
7726	Старый Каразерик	7	64	923	53.582602000000001	53.614915000000003	54.771127999999997	54.745615000000001	0103000020E61000000100000005000000C74ACCB392CA4A401A34F44F705F4B40C74ACCB392CA4A40D3838252B4624B40F168E388B5CE4A40D3838252B4624B40F168E388B5CE4A401A34F44F705F4B40C74ACCB392CA4A401A34F44F705F4B40
61310	Старые Уруссы	7	64	923	53.384298999999999	53.403531999999998	54.611866999999997	54.596958000000001	0103000020E610000001000000050000005871AAB530B14A40F48AA71E694C4B405871AAB530B14A40354069A8514E4B40DA71C3EFA6B34A40354069A8514E4B40DA71C3EFA6B34A40F48AA71E694C4B405871AAB530B14A40F48AA71E694C4B40
16532	Салкын-Чишма	7	64	923	53.252443999999997	53.259874000000003	54.646036000000002	54.643160000000002	0103000020E610000001000000050000002409C21550A04A40350C1F1153524B402409C21550A04A40F304C24EB1524B40558A1D8D43A14A40F304C24EB1524B40558A1D8D43A14A40350C1F1153524B402409C21550A04A40350C1F1153524B40
61317	Малые Уруссы	7	64	923	53.364662000000003	53.382061999999998	54.644373999999999	54.632159999999999	0103000020E61000000100000005000000070C923EADAE4A4070EB6E9EEA504B40070C923EADAE4A404432E4D87A524B40AD855968E7B04A404432E4D87A524B40AD855968E7B04A4070EB6E9EEA504B40070C923EADAE4A4070EB6E9EEA504B40
32614	Каракашлы	7	64	923	53.224120999999997	53.265272000000003	54.693331999999998	54.667624000000004	0103000020E6100000010000000500000064AC36FFAF9C4A402A0307B474554B4064AC36FFAF9C4A4098A25C1ABF584B40B345D26EF4A14A4098A25C1ABF584B40B345D26EF4A14A402A0307B474554B4064AC36FFAF9C4A402A0307B474554B40
7393	Дым-Тамак	7	64	923	53.342734	53.373969000000002	54.532620000000001	54.51914	0103000020E61000000100000005000000179D2CB5DEAB4A40D105F52D73424B40179D2CB5DEAB4A40079964E42C444B40E25B5837DEAF4A40079964E42C444B40E25B5837DEAF4A40D105F52D73424B40179D2CB5DEAB4A40D105F52D73424B40
7545	Байряка	7	64	923	53.343093000000003	53.407862000000002	54.720630999999997	54.700684000000003	0103000020E61000000100000005000000473EAF78EAAB4A404D6A6803B0594B40473EAF78EAAB4A40ECBDF8A23D5C4B40FDA36FD234B44A40ECBDF8A23D5C4B40FDA36FD234B44A404D6A6803B0594B40473EAF78EAAB4A404D6A6803B0594B40
7817	Байларово	7	64	923	53.474733000000001	53.491199000000002	54.610109999999999	54.599336000000001	0103000020E610000001000000050000007EAA0A0DC4BC4A4061A8C30AB74C4B407EAA0A0DC4BC4A40357BA015184E4B40F969DC9BDFBE4A40357BA015184E4B40F969DC9BDFBE4A4061A8C30AB74C4B407EAA0A0DC4BC4A4061A8C30AB74C4B40
61494	Алма-Ата	7	64	923	53.133839999999999	53.145311	54.647931999999997	54.642539999999997	0103000020E61000000100000005000000C5724BAB21914A40982F2FC03E524B40C5724BAB21914A4014048F6FEF524B40E15F048D99924A4014048F6FEF524B40E15F048D99924A40982F2FC03E524B40C5724BAB21914A40982F2FC03E524B40
40935	Алабакуль	7	64	923	53.338476	53.345896000000003	54.509616999999999	54.505304000000002	0103000020E610000001000000050000008E3D7B2E53AB4A40DD442DCDAD404B408E3D7B2E53AB4A40293E3E213B414B409BE8F35146AC4A40293E3E213B414B409BE8F35146AC4A40DD442DCDAD404B408E3D7B2E53AB4A40DD442DCDAD404B40
32567	Абсалямово	7	64	923	53.414122999999996	53.427723999999998	54.574522999999999	54.558351999999999	0103000020E61000000100000005000000BDC282FB01B54A40FED30D1478474B40BDC282FB01B54A4060E63BF889494B406EDBF7A8BFB64A4060E63BF889494B406EDBF7A8BFB64A40FED30D1478474B40BDC282FB01B54A40FED30D1478474B40
5360	совхоз Юлдуз	7	64	763	50.689138	50.723067	55.378369999999997	55.362214000000002	0103000020E6100000010000000500000026378AAC35584940A11342075DAE4B4026378AAC35584940CDE49B6D6EB04B408EE89E758D5C4940CDE49B6D6EB04B408EE89E758D5C4940A11342075DAE4B4026378AAC35584940A11342075DAE4B40
7153	совхоз Луч	7	64	763	50.577441	50.610247999999999	55.355331	55.343173999999998	0103000020E610000001000000050000004D2F3196E9494940336B2920EDAB4B404D2F3196E9494940A320787C7BAD4B408639419B1C4E4940A320787C7BAD4B408639419B1C4E4940336B2920EDAB4B404D2F3196E9494940336B2920EDAB4B40
6596	Чулпан	7	64	763	50.638634000000003	50.657471999999999	55.151069999999997	55.139204999999997	0103000020E610000001000000050000008D0E48C2BE51494047382D78D1914B408D0E48C2BE5149400FB4024356934B409204E10A285449400FB4024356934B409204E10A2854494047382D78D1914B408D0E48C2BE51494047382D78D1914B40
6296	Чувашский Елтан	7	64	763	50.668844999999997	50.697015999999998	55.089793999999998	55.070354999999999	0103000020E61000000100000005000000EB8B84B69C554940170E846401894B40EB8B84B69C55494042B0AA5E7E8B4B40F564FED13759494042B0AA5E7E8B4B40F564FED137594940170E846401894B40EB8B84B69C554940170E846401894B40
7273	Чистопольские Выселки	7	64	763	50.643683000000003	50.682777999999999	55.345381000000003	55.323146999999999	0103000020E61000000100000005000000DFFE5C3464524940776682E15CA94B40DFFE5C346452494074D4D17135AC4B40D236FE446557494074D4D17135AC4B40D236FE4465574940776682E15CA94B40DFFE5C3464524940776682E15CA94B40
40924	Чистополь	7	64	763	50.290295	51.245285000000003	55.489998	55.034198000000004	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
5468	Четырчи	7	64	763	50.937477000000001	50.961506999999997	55.433771999999998	55.425123999999997	0103000020E6100000010000000500000048E00F3FFF774940525F96766AB64B4048E00F3FFF774940D3F544D785B74B4002F04FA9127B4940D3F544D785B74B4002F04FA9127B4940525F96766AB64B4048E00F3FFF774940525F96766AB64B40
6710	Четыре Двора	7	64	763	50.499836000000002	50.527037	55.226416	55.213479	0103000020E6100000010000000500000086AE44A0FA3F4940FFB0A547539B4B4086AE44A0FA3F494044A51133FB9C4B401764CBF27543494044A51133FB9C4B401764CBF275434940FFB0A547539B4B4086AE44A0FA3F4940FFB0A547539B4B40
6782	Татарское Адельшино	7	64	763	50.457624000000003	50.481492000000003	55.193714999999997	55.177365000000002	0103000020E61000000100000005000000AFEE586C933A49403F3A75E5B3964B40AFEE586C933A494050DF32A7CB984B4090A4A487A13D494050DF32A7CB984B4090A4A487A13D49403F3A75E5B3964B40AFEE586C933A49403F3A75E5B3964B40
5973	Татарский Толкиш	7	64	763	50.662799	50.702460000000002	55.237940999999999	55.217111000000003	0103000020E610000001000000050000002769FE98D65449400A4D124BCA9B4B402769FE98D654494053B0C6D9749E4B40C45F9335EA59494053B0C6D9749E4B40C45F9335EA5949400A4D124BCA9B4B402769FE98D65449400A4D124BCA9B4B40
5868	Татарский Сарсаз	7	64	763	50.812288000000002	50.847250000000003	55.257406000000003	55.241632000000003	0103000020E6100000010000000500000075779D0DF967494063D520CCED9E4B4075779D0DF9674940A8E507AEF2A04B409CC420B0726C4940A8E507AEF2A04B409CC420B0726C494063D520CCED9E4B4075779D0DF967494063D520CCED9E4B40
6182	Татарский Елтан	7	64	763	50.774918	50.820354999999999	55.128140000000002	55.111984	0103000020E61000000100000005000000768A5583306349406FD6E07D558E4B40768A5583306349409CA73AE466904B40170E8464016949409CA73AE466904B40170E8464016949406FD6E07D558E4B40768A5583306349406FD6E07D558E4B40
6512	Татарская Багана	7	64	763	50.561568000000001	50.590654999999998	55.154532000000003	55.136566000000002	0103000020E61000000100000005000000753DD175E14749406EDFA3FE7A914B40753DD175E1474940BE175FB4C7934B40041C42959A4B4940BE175FB4C7934B40041C42959A4B49406EDFA3FE7A914B40753DD175E14749406EDFA3FE7A914B40
5712	Старое Ромашкино	7	64	763	50.859099000000001	50.883946000000002	55.270240999999999	55.251947000000001	0103000020E610000001000000050000005E83BEF4F66D4940A4A99ECC3FA04B405E83BEF4F66D4940E884D04197A24B400BB77C2425714940E884D04197A24B400BB77C2425714940A4A99ECC3FA04B405E83BEF4F66D4940A4A99ECC3FA04B40
6892	Старое Иванаево	7	64	763	50.414020000000001	50.433216999999999	55.319263999999997	55.306691000000001	0103000020E61000000100000005000000E9F17B9BFE344940207D93A641A74B40E9F17B9BFE34494023658BA4DDA84B401E8997A77337494023658BA4DDA84B401E8997A773374940207D93A641A74B40E9F17B9BFE344940207D93A641A74B40
6397	Нижняя Кондрата	7	64	763	50.565367999999999	50.590421999999997	55.071885999999999	55.057702999999997	0103000020E610000001000000050000003B1A87FA5D484940C7F0D8CF62874B403B1A87FA5D4849402785798F33894B40616BB6F2924B49402785798F33894B40616BB6F2924B4940C7F0D8CF62874B403B1A87FA5D484940C7F0D8CF62874B40
6818	Нарат Елга	7	64	763	50.562286999999998	50.583360999999996	55.262141999999997	55.249206999999998	0103000020E61000000100000005000000A4FB3905F94749409677D503E69F4B40A4FB3905F94749403A747ADE8DA14B408461C092AB4A49403A747ADE8DA14B408461C092AB4A49409677D503E69F4B40A4FB3905F94749409677D503E69F4B40
6608	Муслюмкино	7	64	763	50.590789999999998	50.617415999999999	55.207197000000001	55.191690000000001	0103000020E61000000100000005000000E466B8019F4B4940317C444C89984B40E466B8019F4B4940276A696E859A4B407903CC7C074F4940276A696E859A4B407903CC7C074F4940317C444C89984B40E466B8019F4B4940317C444C89984B40
5635	Малый Толкиш	7	64	763	50.924981000000002	50.958317999999998	55.353482999999997	55.334465000000002	0103000020E61000000100000005000000F03504C7657649400D54C6BFCFAA4B40F03504C765764940925852EE3EAD4B4085950A2AAA7A4940925852EE3EAD4B4085950A2AAA7A49400D54C6BFCFAA4B40F03504C7657649400D54C6BFCFAA4B40
6866	Кутлушкино	7	64	763	50.369391	50.402242999999999	55.246122999999997	55.225461000000003	0103000020E61000000100000005000000E7374C34482F494001C3F2E7DB9C4B40E7374C34482F49408EE55DF5809F4B40C005D9B27C3349408EE55DF5809F4B40C005D9B27C33494001C3F2E7DB9C4B40E7374C34482F494001C3F2E7DB9C4B40
6993	Кубассы	7	64	763	50.379362999999998	50.404021	55.395333000000001	55.381484999999998	0103000020E61000000100000005000000FE277FF78E30494010751F80D4B04B40FE277FF78E304940C90391459AB24B40D8F2CAF5B6334940C90391459AB24B40D8F2CAF5B633494010751F80D4B04B40FE277FF78E30494010751F80D4B04B40
5549	Красный Яр	7	64	763	51.212522999999997	51.227012999999999	55.392392999999998	55.381065999999997	0103000020E61000000100000005000000EB5223F4339B49400BCF4BC5C6B04B40EB5223F4339B4940F4160FEF39B24B40286211C30E9D4940F4160FEF39B24B40286211C30E9D49400BCF4BC5C6B04B40EB5223F4339B49400BCF4BC5C6B04B40
6056	Кзыл-Ялан	7	64	763	50.685895000000002	50.712063000000001	55.269722999999999	55.249806999999997	0103000020E61000000100000005000000B6BE4868CB574940EBA7FFACF99F4B40B6BE4868CB57494050FD834886A24B4088D860E1245B494050FD834886A24B4088D860E1245B4940EBA7FFACF99F4B40B6BE4868CB574940EBA7FFACF99F4B40
6084	Кзыл-Болгар	7	64	763	50.649386999999997	50.668889999999998	55.252172999999999	55.241579999999999	0103000020E6100000010000000500000049B9FB1C1F53494010AFEB17EC9E4B4049B9FB1C1F53494094F7713447A04B408B4F01309E55494094F7713447A04B408B4F01309E55494010AFEB17EC9E4B4049B9FB1C1F53494010AFEB17EC9E4B40
5846	Каргали	7	64	763	50.883020999999999	50.928629000000001	55.228115000000003	55.205697000000001	0103000020E61000000100000005000000325706D50671494052F17F47549A4B40325706D506714940105D50DF329D4B40008FA850DD764940105D50DF329D4B40008FA850DD76494052F17F47549A4B40325706D50671494052F17F47549A4B40
6382	Ишалькино	7	64	763	50.731313999999998	50.749530999999998	55.068798000000001	55.056037000000003	0103000020E61000000100000005000000B08D78B29B5D4940D82E6D382C874B40B08D78B29B5D4940DE03745FCE884B40492BBEA1F05F4940DE03745FCE884B40492BBEA1F05F4940D82E6D382C874B40B08D78B29B5D4940D82E6D382C874B40
5791	Исляйкино	7	64	763	50.957706999999999	50.988644999999998	55.297691999999998	55.282989999999998	0103000020E610000001000000050000003C139A24967A49402A8C2D0439A44B403C139A24967A4940F2237EC51AA64B404D2D5BEB8B7E4940F2237EC51AA64B404D2D5BEB8B7E49402A8C2D0439A44B403C139A24967A49402A8C2D0439A44B40
6177	Изгары	7	64	763	50.773364000000001	50.805703000000001	55.175026000000003	55.165750000000003	0103000020E61000000100000005000000AEF36F97FD624940F0A7C64B37954B40AEF36F97FD62494090F9804067964B4001A5A1462167494090F9804067964B4001A5A14621674940F0A7C64B37954B40AEF36F97FD624940F0A7C64B37954B40
7054	Данауровка	7	64	763	50.541831999999999	50.565807999999997	55.37171	55.359890999999998	0103000020E6100000010000000500000090F63FC05A454940F78F85E810AE4B4090F63FC05A4549404FCC7A3194AF4B4057E883656C4849404FCC7A3194AF4B4057E883656C484940F78F85E810AE4B4090F63FC05A454940F78F85E810AE4B40
6478	Верхняя Кондрата	7	64	763	50.578941	50.593044999999996	55.092010000000002	55.081947	0103000020E6100000010000000500000022A81ABD1A4A4940AE80423D7D8A4B4022A81ABD1A4A4940D673D2FBC68B4B40350708E6E84B4940D673D2FBC68B4B40350708E6E84B4940AE80423D7D8A4B4022A81ABD1A4A4940AE80423D7D8A4B40
5394	Булдырь	7	64	763	50.848553000000003	50.876984	55.427933000000003	55.408920000000002	0103000020E610000001000000050000001BF67B629D6C49401557957D57B44B401BF67B629D6C494089F02F82C6B64B40C18EFF024170494089F02F82C6B64B40C18EFF02417049401557957D57B44B401BF67B629D6C49401557957D57B44B40
5519	Большой Толкиш	7	64	763	51.066772	51.095742000000001	55.358606000000002	55.344023999999997	0103000020E61000000100000005000000EE2422FC8B88494001857AFA08AC4B40EE2422FC8B8849401F1329CDE6AD4B40446D1B46418C49401F1329CDE6AD4B40446D1B46418C494001857AFA08AC4B40EE2422FC8B88494001857AFA08AC4B40
7102	Белая Гора	7	64	763	50.489612999999999	50.511963000000002	55.297373999999998	55.283543000000002	0103000020E61000000100000005000000255987A3AB3E49403F0114234BA44B40255987A3AB3E49402157EA5910A64B408BE1EA00884149402157EA5910A64B408BE1EA00884149403F0114234BA44B40255987A3AB3E49403F0114234BA44B40
6684	Бахта	7	64	763	50.553708	50.574745999999998	55.197476000000002	55.184541000000003	0103000020E610000001000000050000004CC45BE7DF464940B5E21B0A9F974B404CC45BE7DF46494059DFC0E446994B40DFC0E4469149494059DFC0E446994B40DFC0E44691494940B5E21B0A9F974B404CC45BE7DF464940B5E21B0A9F974B40
6964	Байтеряково	7	64	763	50.358809000000001	50.375365000000002	55.363089000000002	55.353001999999996	0103000020E6100000010000000500000057410C74ED2D494017B6662B2FAD4B4057410C74ED2D4940C8444AB379AE4B401288D7F50B304940C8444AB379AE4B401288D7F50B30494017B6662B2FAD4B4057410C74ED2D494017B6662B2FAD4B40
5702	Александровка	7	64	763	50.772914999999998	50.797088000000002	55.351599999999998	55.337116999999999	0103000020E610000001000000050000003ECBF3E0EE6249407BF65CA626AB4B403ECBF3E0EE62494005A3923A01AD4B405C04C6FA0666494005A3923A01AD4B405C04C6FA066649407BF65CA626AB4B403ECBF3E0EE6249407BF65CA626AB4B40
6265	Акбулатово	7	64	763	50.606951000000002	50.624772999999998	55.124856000000001	55.113714999999999	0103000020E6100000010000000500000023A30392B04D494046088F368E8E4B4023A30392B04D4940CD5A0A48FB8F4B403F36C98FF84F4940CD5A0A48FB8F4B403F36C98FF84F494046088F368E8E4B4023A30392B04D494046088F368E8E4B40
40920	Чистополь	7	64	6928	50.290295	51.245285000000003	55.489998	55.034198000000004	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
61511	Шешминская Крепость	7	64	319	51.728614	51.784615000000002	54.746701000000002	54.733848000000002	0103000020E6100000010000000500000031B43A3943DD4940151E34BBEE5D4B4031B43A3943DD4940FC71FBE5935F4B40BC79AA436EE44940FC71FBE5935F4B40BC79AA436EE44940151E34BBEE5D4B4031B43A3943DD4940151E34BBEE5D4B40
3555	Чумачка	7	64	319	51.720556000000002	51.740167	54.804555000000001	54.792945000000003	0103000020E61000000100000005000000E277D32D3BDC49406C43C5387F654B40E277D32D3BDC4940A96A82A8FB664B400A4AD1CABDDE4940A96A82A8FB664B400A4AD1CABDDE49406C43C5387F654B40E277D32D3BDC49406C43C5387F654B40
3454	Черный Ключ	7	64	319	51.544252999999998	51.569468999999998	54.832790000000003	54.815907000000003	0103000020E61000000100000005000000FCDF1115AAC54940EBC9FCA36F684B40FCDF1115AAC54940CA37DBDC986A4B40FC8A355CE4C84940CA37DBDC986A4B40FC8A355CE4C84940EBC9FCA36F684B40FCDF1115AAC54940EBC9FCA36F684B40
3109	Черемшан	7	64	319	51.471193	51.521391000000001	54.665998999999999	54.638330000000003	0103000020E61000000100000005000000548D5E0D50BC4940210725CCB4514B40548D5E0D50BC494098158A743F554B40E1B6B6F0BCC2494098158A743F554B40E1B6B6F0BCC24940210725CCB4514B40548D5E0D50BC4940210725CCB4514B40
61412	Утыз Имян	7	64	319	51.009287999999998	51.913874	54.952697999999998	54.555365000000002	0103000020E61000000100000005000000641F645930814940E92B483316474B40641F645930814940787B1002F2794B401555BFD2F9F44940787B1002F2794B401555BFD2F9F44940E92B483316474B40641F645930814940E92B483316474B40
3048	Ульяновка	7	64	319	51.239347000000002	51.270356999999997	54.728701000000001	54.721333000000001	0103000020E61000000100000005000000A7B228ECA29E49404643C6A3545C4B40A7B228ECA29E494000C80913465D4B40519FE40E9BA2494000C80913465D4B40519FE40E9BA249404643C6A3545C4B40A7B228ECA29E49404643C6A3545C4B40
2990	Туйметкино	7	64	319	51.530104999999999	51.558348000000002	54.795639000000001	54.784593000000001	0103000020E6100000010000000500000019390B7BDAC34940D4D51D8B6D644B4019390B7BDAC349400936AE7FD7654B40BDE47FF277C749400936AE7FD7654B40BDE47FF277C74940D4D51D8B6D644B4019390B7BDAC34940D4D51D8B6D644B40
2931	Старый Утямыш	7	64	319	51.631523999999999	51.657539999999997	54.618118000000003	54.597458000000003	0103000020E61000000100000005000000CE5147C7D5D04940E65DF580794C4B40CE5147C7D5D04940D388997D1E4F4B40EAE74D452AD44940D388997D1E4F4B40EAE74D452AD44940E65DF580794C4B40CE5147C7D5D04940E65DF580794C4B40
2875	Старые Кутуши	7	64	319	51.091169999999998	51.135905999999999	54.706291999999998	54.684328999999998	0103000020E610000001000000050000002B306475AB8B4940295AB91798574B402B306475AB8B494095B6B8C6675A4B4043AA285E6591494095B6B8C6675A4B4043AA285E65914940295AB91798574B402B306475AB8B4940295AB91798574B40
2815	Старое Кадеево	7	64	319	51.159818999999999	51.192948999999999	54.755440999999998	54.733373999999998	0103000020E61000000100000005000000C423F1F2749449404CDE0033DF5D4B40C423F1F2749449405D876A4AB2604B40E065868DB29849405D876A4AB2604B40E065868DB29849404CDE0033DF5D4B40C423F1F2749449404CDE0033DF5D4B40
2751	Старое Ильмово	7	64	319	51.309038000000001	51.335107000000001	54.758671999999997	54.745370999999999	0103000020E61000000100000005000000529CA38E8EA7494083312251685F4B40529CA38E8EA749400932022A1C614B4091D442C9E4AA49400932022A1C614B4091D442C9E4AA494083312251685F4B40529CA38E8EA7494083312251685F4B40
2692	Подлесный Утямыш	7	64	319	51.711412000000003	51.749158999999999	54.614547000000002	54.605234000000003	0103000020E61000000100000005000000B1FD648C0FDB4940B136C64E784D4B40B1FD648C0FDB49406E6DE179A94E4B4085402E71E4DF49406E6DE179A94E4B4085402E71E4DF4940B136C64E784D4B40B1FD648C0FDB4940B136C64E784D4B40
2584	Новое Ильмово	7	64	319	51.370258	51.401330999999999	54.746679999999998	54.732148000000002	0103000020E610000001000000050000008B8A389D64AF494079EA9106B75D4B408B8A389D64AF4940E449D235935F4B407CEF6FD05EB34940E449D235935F4B407CEF6FD05EB3494079EA9106B75D4B408B8A389D64AF494079EA9106B75D4B40
61423	Нижняя Чегодайка	7	64	319	51.541961999999998	51.572828000000001	54.650959	54.630946000000002	0103000020E610000001000000050000005ED6C4025FC5494061C5A9D6C2504B405ED6C4025FC54940B804E09F52534B40D61D8B6D52C94940B804E09F52534B40D61D8B6D52C9494061C5A9D6C2504B405ED6C4025FC5494061C5A9D6C2504B40
2473	Нижняя Кармалка	7	64	319	51.622236000000001	51.642789	54.796256999999997	54.779021	0103000020E610000001000000050000006A32E36DA5CF4940D8F2CAF5B6634B406A32E36DA5CF4940041BD7BFEB654B40419DF2E846D24940041BD7BFEB654B40419DF2E846D24940D8F2CAF5B6634B406A32E36DA5CF4940D8F2CAF5B6634B40
2427	Нижняя Каменка	7	64	319	51.454610000000002	51.480759999999997	54.866574999999997	54.849505000000001	0103000020E61000000100000005000000A03715A930BA4940ED647094BC6C4B40A03715A930BA4940FE43FAEDEB6E4B40CB9C2E8B89BD4940FE43FAEDEB6E4B40CB9C2E8B89BD4940ED647094BC6C4B40A03715A930BA4940ED647094BC6C4B40
2362	Мордовское Афонькино	7	64	319	51.693562	51.715345999999997	54.699669999999998	54.682966	0103000020E61000000100000005000000CADFBDA3C6D84940D5230D6E6B574B40CADFBDA3C6D8494004FF5BC98E594B4086A92D7590DB494004FF5BC98E594B4086A92D7590DB4940D5230D6E6B574B40CADFBDA3C6D84940D5230D6E6B574B40
2306	Лашманка	7	64	319	51.435170999999997	51.479574	54.749792999999997	54.725898999999998	0103000020E610000001000000050000007495EEAEB3B749407C992842EA5C4B407495EEAEB3B7494086E28E37F95F4B4086014BAE62BD494086E28E37F95F4B4086014BAE62BD49407C992842EA5C4B407495EEAEB3B749407C992842EA5C4B40
2241	Лагерка	7	64	319	51.729647	51.748386000000004	54.673205000000003	54.656771999999997	0103000020E61000000100000005000000F04FA91265DD4940D976DA1A11544B40F04FA91265DD49407940D9942B564B406364C91CCBDF49407940D9942B564B406364C91CCBDF4940D976DA1A11544B40F04FA91265DD4940D976DA1A11544B40
2196	Кутема	7	64	319	51.358437000000002	51.400441999999998	54.854854000000003	54.835346000000001	0103000020E6100000010000000500000093567C43E1AD4940166C239EEC6A4B4093567C43E1AD49406A6D1ADB6B6D4B40F0F8F6AE41B349406A6D1ADB6B6D4B40F0F8F6AE41B34940166C239EEC6A4B4093567C43E1AD4940166C239EEC6A4B40
2127	Карамышево	7	64	319	51.399687	51.448321999999997	54.907884000000003	54.895673000000002	0103000020E6100000010000000500000074D190F128B349408274B169A5724B4074D190F128B34940E547FC8A35744B40E509849D62B94940E547FC8A35744B40E509849D62B949408274B169A5724B4074D190F128B349408274B169A5724B40
2017	Казанка	7	64	319	51.344459000000001	51.364868000000001	54.671196000000002	54.665191999999998	0103000020E610000001000000050000000CE8853B17AC4940C9C7EE0225554B400CE8853B17AC49405F9A22C0E9554B40B0AD9FFEB3AE49405F9A22C0E9554B40B0AD9FFEB3AE4940C9C7EE0225554B400CE8853B17AC4940C9C7EE0225554B40
1877	Ивашкино	7	64	319	51.314993999999999	51.342393000000001	54.890106000000003	54.875619999999998	0103000020E61000000100000005000000D63730B951A849409CDCEF5014704B40D63730B951A8494098FC4FFEEE714B408EB0A888D3AB494098FC4FFEEE714B408EB0A888D3AB49409CDCEF5014704B40D63730B951A849409CDCEF5014704B40
61398	Верхняя Чегодайка	7	64	319	51.587057999999999	51.617142000000001	54.657682999999999	54.643134000000003	0103000020E61000000100000005000000766D6FB724CB49400C79043752524B40766D6FB724CB49404D11E0F42E544B40787E5182FECE49404D11E0F42E544B40787E5182FECE49400C79043752524B40766D6FB724CB49400C79043752524B40
1766	Верхняя Кармалка	7	64	319	51.571821999999997	51.591701999999998	54.755695000000003	54.739356999999998	0103000020E6100000010000000500000010919A7631C94940CA880B40A35E4B4010919A7631C9494018601F9DBA604B40287D21E4BCCB494018601F9DBA604B40287D21E4BCCB4940CA880B40A35E4B4010919A7631C94940CA880B40A35E4B40
1721	Верхняя Каменка	7	64	319	51.456837999999998	51.481389	54.812857000000001	54.801716999999996	0103000020E61000000100000005000000F7C8E6AA79BA4940D8D2A3A99E664B40F7C8E6AA79BA49408FA9BBB20B684B40BBD39D279EBD49408FA9BBB20B684B40BBD39D279EBD4940D8D2A3A99E664B40F7C8E6AA79BA4940D8D2A3A99E664B40
1679	Беркет-Ключ	7	64	319	51.613010000000003	51.645367	54.823563999999998	54.804347999999997	0103000020E610000001000000050000007C0F971C77CE49402F4D11E0F4664B407C0F971C77CE4940DB148F8B6A694B407575C7629BD24940DB148F8B6A694B407575C7629BD249402F4D11E0F4664B407C0F971C77CE49402F4D11E0F4664B40
1577	Андреевка	7	64	319	51.789861000000002	51.811357999999998	54.723387000000002	54.716523000000002	0103000020E6100000010000000500000064B14D2A1AE5494079EA9106B75B4B4064B14D2A1AE5494000ADF9F1975C4B408AAC3594DAE7494000ADF9F1975C4B408AAC3594DAE7494079EA9106B75B4B4064B14D2A1AE5494079EA9106B75B4B40
1568	Амирово	7	64	319	51.482674000000003	51.499139999999997	54.753034999999997	54.740459000000001	0103000020E610000001000000050000009450FA42C8BD4940B2834A5CC75E4B409450FA42C8BD494026DF6C7363604B400E10CCD1E3BF494026DF6C7363604B400E10CCD1E3BF4940B2834A5CC75E4B409450FA42C8BD4940B2834A5CC75E4B40
1447	Аккиреево	7	64	319	51.387829000000004	51.418380999999997	54.911642000000001	54.901031000000003	0103000020E610000001000000050000005FB87361A4B1494052D7DAFB54734B405FB87361A4B149407CD45FAFB0744B40462234828DB549407CD45FAFB0744B40462234828DB5494052D7DAFB54734B405FB87361A4B1494052D7DAFB54734B40
41034	д.Большие Нырсы	7	64	36	49.938389000000001	50.604489000000001	56.036000000000001	55.609299	0103000020E610000001000000050000008CF678211DF84840253E7782FDCD4B408CF678211DF84840F853E3A59B044C4058E542E55F4D4940F853E3A59B044C4058E542E55F4D4940253E7782FDCD4B408CF678211DF84840253E7782FDCD4B40
219	Шармаши	7	64	36	50.237096000000001	50.267828000000002	55.827438999999998	55.810875000000003	0103000020E6100000010000000500000097016729591E49406F1283C0CAE74B4097016729591E4940AC376A85E9E94B40FF791A3048224940AC376A85E9E94B40FF791A30482249406F1283C0CAE74B4097016729591E49406F1283C0CAE74B40
419	Шадки	7	64	36	50.185425000000002	50.218178000000002	55.732235000000003	55.709622000000003	0103000020E610000001000000050000002F6EA301BC174940D542C9E4D4DA4B402F6EA301BC17494048FE60E0B9DD4B40755AB741ED1B494048FE60E0B9DD4B40755AB741ED1B4940D542C9E4D4DA4B402F6EA301BC174940D542C9E4D4DA4B40
61452	Уруширма	7	64	36	50.284734	50.312258999999997	55.899254999999997	55.892288999999998	0103000020E610000001000000050000009607E929722449404FCAA48636F24B409607E92972244940DAE1AFC91AF34B40DA70581AF8274940DAE1AFC91AF34B40DA70581AF82749404FCAA48636F24B409607E929722449404FCAA48636F24B40
44	Узяк	7	64	36	50.259914000000002	50.292333999999997	55.871257999999997	55.858539	0103000020E61000000100000005000000E3E2A8DC4421494097AB1F9BE4ED4B40E3E2A8DC442149406E30D46185EF4B4022C154336B2549406E30D46185EF4B4022C154336B25494097AB1F9BE4ED4B40E3E2A8DC4421494097AB1F9BE4ED4B40
32058	Тюлячи	7	64	36	50.227241999999997	50.248685000000002	55.896701	55.882863	0103000020E6100000010000000500000089230F44161D49409AEC9FA701F14B4089230F44161D49402FA52E19C7F24B40BD00FBE8D41F49402FA52E19C7F24B40BD00FBE8D41F49409AEC9FA701F14B4089230F44161D49409AEC9FA701F14B40
993	Трюк-Тямти	7	64	36	50.105592000000001	50.128607000000002	55.941738000000001	55.928179	0103000020E61000000100000005000000105CE509840D4940C0EAC891CEF64B40105CE509840D494042B3EBDE8AF84B40B284B5317610494042B3EBDE8AF84B40B284B53176104940C0EAC891CEF64B40105CE509840D4940C0EAC891CEF64B40
32309	Субаш	7	64	36	50.427854000000004	50.454479999999997	55.758710999999998	55.748032000000002	0103000020E610000001000000050000003DBB7CEBC3364940452E3883BFDF4B403DBB7CEBC3364940C70E2A711DE14B40D15790662C3A4940C70E2A711DE14B40D15790662C3A4940452E3883BFDF4B403DBB7CEBC3364940452E3883BFDF4B40
1228	Старый Карабаян	7	64	36	50.376658999999997	50.386710999999998	55.732246000000004	55.724722999999997	0103000020E610000001000000050000003D5FB35C363049405AD427B9C3DC4B403D5FB35C363049403C50A73CBADD4B407100FDBE7F3149403C50A73CBADD4B407100FDBE7F3149405AD427B9C3DC4B403D5FB35C363049405AD427B9C3DC4B40
32413	Старые Зюри	7	64	36	50.343232	50.369140000000002	55.878208000000001	55.862772	0103000020E610000001000000050000006878B306EF2B4940C7F319506FEE4B406878B306EF2B4940F48AA71E69F04B409ED2C1FA3F2F4940F48AA71E69F04B409ED2C1FA3F2F4940C7F319506FEE4B406878B306EF2B4940C7F319506FEE4B40
291	Сауш	7	64	36	50.180323000000001	50.211620000000003	55.804783999999998	55.791091000000002	0103000020E61000000100000005000000BADBF5D21417494079944A7842E54B40BADBF5D2141749400A2C802903E74B40FB96395D161B49400A2C802903E74B40FB96395D161B494079944A7842E54B40BADBF5D21417494079944A7842E54B40
41035	Пановая Гора	7	64	36	50.263354	50.279496999999999	55.828673000000002	55.822750999999997	0103000020E61000000100000005000000A9A27895B52149402AE09EE74FE94B40A9A27895B5214940030AF5F411EA4B40412AC58EC6234940030AF5F411EA4B40412AC58EC62349402AE09EE74FE94B40A9A27895B52149402AE09EE74FE94B40
61516	Малые Кибя Кози	7	64	36	50.194803999999998	50.208413	55.949964999999999	55.939176000000003	0103000020E61000000100000005000000A3906456EF18494014984EEB36F84B40A3906456EF1849401DACFF7398F94B40D787F546AD1A49401DACFF7398F94B40D787F546AD1A494014984EEB36F84B40A3906456EF18494014984EEB36F84B40
1100	Максабаш	7	64	36	50.098100000000002	50.119866000000002	56.008308999999997	55.995690000000003	0103000020E610000001000000050000006ADE718A8E0C4940257A19C572FF4B406ADE718A8E0C494098A1F14410014C4080F3E2C4570F494098A1F14410014C4080F3E2C4570F4940257A19C572FF4B406ADE718A8E0C4940257A19C572FF4B40
783	Лесной	7	64	36	50.005887999999999	50.023710999999999	55.937845000000003	55.928995999999998	0103000020E610000001000000050000002CB81FF0C0004940B20E4757E9F64B402CB81FF0C0004940CBDB114E0BF84B4019C748F608034940CBDB114E0BF84B4019C748F608034940B20E4757E9F64B402CB81FF0C0004940B20E4757E9F64B40
538	Кукча	7	64	36	50.144174999999997	50.171232000000003	55.870314	55.857881999999996	0103000020E610000001000000050000004DF38E5374124940DDE9CE13CFED4B404DF38E53741249401FA0FB7266EF4B40AC0320EEEA1549401FA0FB7266EF4B40AC0320EEEA154940DDE9CE13CFED4B404DF38E5374124940DDE9CE13CFED4B40
61406	Верхние Кибя-Кози	7	64	36	50.136862000000001	50.161664999999999	55.983524000000003	55.972296999999998	0103000020E610000001000000050000005708ABB184114940DC7F643A74FC4B405708ABB184114940626A4B1DE4FD4B4034F44F70B1144940626A4B1DE4FD4B4034F44F70B1144940DC7F643A74FC4B405708ABB184114940DC7F643A74FC4B40
604	Большие Метески	7	64	36	50.070971	50.097813000000002	55.893566	55.879353999999999	0103000020E6100000010000000500000072FBE59315094940ABCDFFAB8EF04B4072FBE59315094940A568E55E60F24B40D40FEA22850C4940A568E55E60F24B40D40FEA22850C4940ABCDFFAB8EF04B4072FBE59315094940ABCDFFAB8EF04B40
32231	Большая Меша	7	64	36	50.512312999999999	50.551597000000001	55.828713	55.811922000000003	0103000020E610000001000000050000006728EE78934149409373620FEDE74B406728EE78934149409162804413EA4B402EC901BB9A4649409162804413EA4B402EC901BB9A4649409373620FEDE74B406728EE78934149409373620FEDE74B40
32402	Баландыш	7	64	36	50.448506000000002	50.480395999999999	55.841462999999997	55.828172000000002	0103000020E61000000100000005000000A70705A56839494041BB438A01EA4B40A70705A568394940A3E5400FB5EB4B408A90BA9D7D3D4940A3E5400FB5EB4B408A90BA9D7D3D494041BB438A01EA4B40A70705A56839494041BB438A01EA4B40
32161	Ачи	7	64	36	50.258944	50.27214	55.918478999999998	55.909720999999998	0103000020E610000001000000050000006ABFB5132521494001BEDBBC71F44B406ABFB51325214940098849B890F54B407BF7C77BD5224940098849B890F54B407BF7C77BD522494001BEDBBC71F44B406ABFB5132521494001BEDBBC71F44B40
61460	Алан-Зире	7	64	36	50.382426000000002	50.392235999999997	55.879626999999999	55.875262999999997	0103000020E61000000100000005000000EF91CD55F33049400D33349E08F04B40EF91CD55F3304940DCD6169E97F04B402C280CCA34324940DCD6169E97F04B402C280CCA343249400D33349E08F04B40EF91CD55F33049400D33349E08F04B40
32278	Айдарово	7	64	36	50.375087000000001	50.396628	55.769499000000003	55.758651	0103000020E61000000100000005000000CF13CFD902304940F209D9791BE14B40CF13CFD90230494001A777F17EE24B40C556D0B4C432494001A777F17EE24B40C556D0B4C4324940F209D9791BE14B40CF13CFD902304940F209D9791BE14B40
30663	п. Совхоза Татарстан	7	64	1883	52.585338	52.612313999999998	55.640421000000003	55.615822000000001	0103000020E61000000100000005000000938D075BEC4A4A4023145B41D3CE4B40938D075BEC4A4A40F855B950F9D14B4004711E4E604E4A40F855B950F9D14B4004711E4E604E4A4023145B41D3CE4B40938D075BEC4A4A4023145B41D3CE4B40
61507	Янга-Буляк	7	64	1883	52.460687	52.47869	55.445599999999999	55.434818999999997	0103000020E610000001000000050000009F58A7CAF73A4A40F7562426A8B74B409F58A7CAF73A4A407E8CB96B09B94B400C76C3B6453D4A407E8CB96B09B94B400C76C3B6453D4A40F7562426A8B74B409F58A7CAF73A4A40F7562426A8B74B40
31846	Тлянче-Тамак	7	64	1883	52.609341000000001	52.641922000000001	55.480347000000002	55.464548999999998	0103000020E61000000100000005000000548EC9E2FE4D4A40DB31755776BB4B40548EC9E2FE4D4A40A9DDAF027CBD4B409D4A06802A524A40A9DDAF027CBD4B409D4A06802A524A40DB31755776BB4B40548EC9E2FE4D4A40DB31755776BB4B40
31832	Старый Дрюш	7	64	1883	52.501767000000001	52.526767	55.494633999999998	55.483320999999997	0103000020E61000000100000005000000249BABE639404A40293C6876DDBD4B40249BABE639404A40ADBEBA2A50BF4B4057CEDE196D434A40ADBEBA2A50BF4B4057CEDE196D434A40293C6876DDBD4B40249BABE639404A40293C6876DDBD4B40
31229	Старые Ерыклы	7	64	1883	52.235013000000002	52.246394000000002	55.627797999999999	55.616829000000003	0103000020E610000001000000050000004391EEE7141E4A40B91CAF40F4CE4B404391EEE7141E4A40423F53AF5BD04B401FF7ADD6891F4A40423F53AF5BD04B401FF7ADD6891F4A40B91CAF40F4CE4B404391EEE7141E4A40B91CAF40F4CE4B40
31706	Старое Абдулово	7	64	1883	52.657068000000002	52.683999999999997	55.547066000000001	55.536470999999999	0103000020E61000000100000005000000C39FE1CD1A544A404F20EC14ABC44B40C39FE1CD1A544A407460394206C64B40643BDF4F8D574A407460394206C64B40643BDF4F8D574A404F20EC14ABC44B40C39FE1CD1A544A404F20EC14ABC44B40
31600	Семекеево	7	64	1883	52.729688000000003	52.750996000000001	55.611775000000002	55.599381999999999	0103000020E610000001000000050000004F24986A665D4A40D1E7A38CB8CC4B404F24986A665D4A4055C1A8A44ECE4B40A2B60DA320604A4055C1A8A44ECE4B40A2B60DA320604A40D1E7A38CB8CC4B404F24986A665D4A40D1E7A38CB8CC4B40
31632	Саитово	7	64	1883	52.694356999999997	52.710877000000004	55.588140000000003	55.581153999999998	0103000020E61000000100000005000000D45FAFB0E0584A4044F8174163CA4B40D45FAFB0E0584A4017BCE82B48CB4B40433D7D04FE5A4A4017BCE82B48CB4B40433D7D04FE5A4A4044F8174163CA4B40D45FAFB0E0584A4044F8174163CA4B40
61217	Новый	7	64	1883	52.650779999999997	52.667605000000002	55.707318999999998	55.698503000000002	0103000020E61000000100000005000000087250C24C534A403694DA8B68D94B40087250C24C534A40726BD26D89DA4B40B3D2A41474554A40726BD26D89DA4B40B3D2A41474554A403694DA8B68D94B40087250C24C534A403694DA8B68D94B40
40917	Новотроицкое	7	64	1883	51.935172999999999	52.909989000000003	55.861206000000003	55.362617999999998	0103000020E61000000100000005000000158DB5BFB3F74940707841446AAE4B40158DB5BFB3F749403B8F8AFF3BEE4B40215C01857A744A403B8F8AFF3BEE4B40215C01857A744A40707841446AAE4B40158DB5BFB3F74940707841446AAE4B40
31455	Нижний Суык-Су	7	64	1883	52.280126000000003	52.303885999999999	55.621602000000003	55.605240999999999	0103000020E610000001000000050000003161342BDB234A4063997E8978CD4B403161342BDB234A40699082A790CF4B402BDB87BCE5264A40699082A790CF4B402BDB87BCE5264A4063997E8978CD4B403161342BDB234A4063997E8978CD4B40
31281	Мусабай-Завод	7	64	1883	52.385354999999997	52.417928000000003	55.520772000000001	55.504598000000001	0103000020E61000000100000005000000CF2C095053314A4042D0D1AA96C04B40CF2C095053314A4015562AA8A8C24B40960A2AAA7E354A4015562AA8A8C24B40960A2AAA7E354A4042D0D1AA96C04B40CF2C095053314A4042D0D1AA96C04B40
31192	Мелекес	7	64	1883	52.165689999999998	52.192253000000001	55.608465000000002	55.585082	0103000020E610000001000000050000001AA3755435154A4038BD8BF7E3CA4B401AA3755435154A405DE15D2EE2CD4B4069C70DBF9B184A405DE15D2EE2CD4B4069C70DBF9B184A4038BD8BF7E3CA4B401AA3755435154A4038BD8BF7E3CA4B40
30544	Малтабарово	7	64	1883	52.783461000000003	52.797834000000002	55.804380000000002	55.791977000000003	0103000020E610000001000000050000008258367348644A40941799805FE54B408258367348644A403BC780ECF5E64B4085D1AC6C1F664A403BC780ECF5E64B4085D1AC6C1F664A40941799805FE54B408258367348644A40941799805FE54B40
31014	Малая Шильна	7	64	1883	52.523614000000002	52.537663999999999	55.809114999999998	55.797077999999999	0103000020E6100000010000000500000027DD96C805434A40382EE3A606E64B4027DD96C805434A40FDD98F1491E74B40471E882CD2444A40FDD98F1491E74B40471E882CD2444A40382EE3A606E64B4027DD96C805434A40382EE3A606E64B40
31402	Куперле	7	64	1883	52.401991000000002	52.414980999999997	55.576655000000002	55.567672000000002	0103000020E61000000100000005000000A724EB7074334A406E6DE179A9C84B40A724EB7074334A409609BFD4CFC94B400EBBEF181E354A409609BFD4CFC94B400EBBEF181E354A406E6DE179A9C84B40A724EB7074334A406E6DE179A9C84B40
30910	Кузкеево	7	64	1883	52.771208000000001	52.826310999999997	55.778860999999999	55.765503000000002	0103000020E61000000100000005000000F03499F1B6624A40B5FE9600FCE14B40F03499F1B6624A409F909DB7B1E34B409BA9108FC4694A409F909DB7B1E34B409BA9108FC4694A40B5FE9600FCE14B40F03499F1B6624A40B5FE9600FCE14B40
31542	Кувады	7	64	1883	52.290421000000002	52.306285000000003	55.586395000000003	55.575077999999998	0103000020E610000001000000050000002B89EC832C254A401553E9279CC94B402B89EC832C254A40DBC4C9FD0ECB4B40B020CD5834274A40DBC4C9FD0ECB4B40B020CD5834274A401553E9279CC94B402B89EC832C254A401553E9279CC94B40
30857	Круглое Поле	7	64	1883	52.165779000000001	52.185192000000001	55.660902	55.647066000000002	0103000020E610000001000000050000008AAE0B3F38154A40412D060FD3D24B408AAE0B3F38154A4035EECD6F98D44B408CBD175FB4174A4035EECD6F98D44B408CBD175FB4174A40412D060FD3D24B408AAE0B3F38154A40412D060FD3D24B40
30819	Комсомолец	7	64	1883	52.482795000000003	52.512600999999997	55.588033000000003	55.580849000000001	0103000020E610000001000000050000000FD6FF39CC3D4A400875914259CA4B400FD6FF39CC3D4A4001FC53AA44CB4B40CD72D9E89C414A4001FC53AA44CB4B40CD72D9E89C414A400875914259CA4B400FD6FF39CC3D4A400875914259CA4B40
30504	Калмия	7	64	1883	52.746298000000003	52.772114999999999	55.814841000000001	55.804430000000004	0103000020E61000000100000005000000FD885FB1865F4A40EDF5EE8FF7E64B40FD885FB1865F4A405038BBB54CE84B4022E010AAD4624A405038BBB54CE84B4022E010AAD4624A40EDF5EE8FF7E64B40FD885FB1865F4A40EDF5EE8FF7E64B40
30436	Калмаш	7	64	1883	52.627009999999999	52.646441000000003	55.738601000000003	55.726233000000001	0103000020E61000000100000005000000EA211ADD41504A405323F433F5DC4B40EA211ADD41504A407EE5417A8ADE4B4093E52494BE524A407EE5417A8ADE4B4093E52494BE524A405323F433F5DC4B40EA211ADD41504A405323F433F5DC4B40
31914	Казаклар	7	64	1883	52.607354999999998	52.623821	55.460603999999996	55.451987000000003	0103000020E61000000100000005000000F20703CFBD4D4A40CC9BC3B5DAB94B40F20703CFBD4D4A4011346612F5BA4B406DC7D45DD94F4A4011346612F5BA4B406DC7D45DD94F4A40CC9BC3B5DAB94B40F20703CFBD4D4A40CC9BC3B5DAB94B40
32781	Иштеряково	7	64	1883	51.935172999999999	51.967809000000003	55.540170000000003	55.527890999999997	0103000020E61000000100000005000000158DB5BFB3F74940266DAAEE91C34B40158DB5BFB3F74940E223624A24C54B4022E3512AE1FB4940E223624A24C54B4022E3512AE1FB4940266DAAEE91C34B40158DB5BFB3F74940266DAAEE91C34B40
31107	Ильбухтино	7	64	1883	52.561217999999997	52.580036999999997	55.789866000000004	55.781427999999998	0103000020E6100000010000000500000098F6CDFDD5474A40DF162CD505E44B4098F6CDFDD5474A40761C3F541AE54B4027BC04A73E4A4A40761C3F541AE54B4027BC04A73E4A4A40DF162CD505E44B4098F6CDFDD5474A40DF162CD505E44B40
31507	Верхний Суык Су	7	64	1883	52.252934000000003	52.280817999999996	55.599646999999997	55.589224000000002	0103000020E61000000100000005000000F3052D2460204A40580229B16BCB4B40F3052D2460204A407F129F3BC1CC4B4066101FD8F1234A407F129F3BC1CC4B4066101FD8F1234A40580229B16BCB4B40F3052D2460204A40580229B16BCB4B40
30952	Верхний Байлар	7	64	1883	52.725951000000002	52.750141999999997	55.722943000000001	55.716306000000003	0103000020E61000000100000005000000CFBF5DF6EB5C4A40DCF63DEAAFDB4B40CFBF5DF6EB5C4A40A2EF6E6589DC4B4092AD2EA704604A40A2EF6E6589DC4B4092AD2EA704604A40DCF63DEAAFDB4B40CFBF5DF6EB5C4A40DCF63DEAAFDB4B40
30275	Бурдыбаш	7	64	1883	52.328400999999999	52.346781	55.522489999999998	55.508488	0103000020E61000000100000005000000A27C410B092A4A404834812216C14B40A27C410B092A4A40573ECBF3E0C24B40E5EFDE51632C4A40573ECBF3E0C24B40E5EFDE51632C4A404834812216C14B40A27C410B092A4A404834812216C14B40
30254	Бурды	7	64	1883	52.275275000000001	52.303725	55.531947000000002	55.506061000000003	0103000020E61000000100000005000000053411363C234A40FA635A9BC6C04B40053411363C234A40481ADCD616C44B4022FDF675E0264A40481ADCD616C44B4022FDF675E0264A40FA635A9BC6C04B40053411363C234A40FA635A9BC6C04B40
31046	Большая Шильна	7	64	1883	52.466867999999998	52.490772	55.797989000000001	55.788818999999997	0103000020E6100000010000000500000043C6A354C23B4A4051BB5F05F8E44B4043C6A354C23B4A40ACC8E88024E64B4071E5EC9DD13E4A40ACC8E88024E64B4071E5EC9DD13E4A4051BB5F05F8E44B4043C6A354C23B4A4051BB5F05F8E44B40
30188	Биюрган	7	64	1883	52.810231000000002	52.827531999999998	55.84308	55.829450999999999	0103000020E610000001000000050000004A9A3FA6B5674A4037514B732BEA4B404A9A3FA6B5674A40B2F4A10BEAEB4B405D328E91EC694A40B2F4A10BEAEB4B405D328E91EC694A4037514B732BEA4B404A9A3FA6B5674A4037514B732BEA4B40
30140	Биклянь	7	64	1883	52.122615000000003	52.155600999999997	55.630460999999997	55.613396999999999	0103000020E61000000100000005000000E17F2BD9B10F4A40753BFBCA83CE4B40E17F2BD9B10F4A40A43330F2B2D04B40C91CCBBBEA134A40A43330F2B2D04B40C91CCBBBEA134A40753BFBCA83CE4B40E17F2BD9B10F4A40753BFBCA83CE4B40
29963	Бетьки	7	64	1883	52.112850999999999	52.157677	55.680950000000003	55.667295000000003	0103000020E610000001000000050000001329CDE6710E4A4065E42CEC69D54B401329CDE6710E4A40091B9E5E29D74B406B2A8BC22E144A40091B9E5E29D74B406B2A8BC22E144A4065E42CEC69D54B401329CDE6710E4A4065E42CEC69D54B40
31145	Белоус	7	64	1883	52.468133999999999	52.488239	55.861206000000003	55.853299	0103000020E61000000100000005000000A5129ED0EB3B4A40D15AD1E638ED4B40A5129ED0EB3B4A403B8F8AFF3BEE4B40DDD0949D7E3E4A403B8F8AFF3BEE4B40DDD0949D7E3E4A40D15AD1E638ED4B40A5129ED0EB3B4A40D15AD1E638ED4B40
41032	Мрясево	7	64	6936	51.935172999999999	52.909989000000003	55.861206000000003	55.362617999999998	0103000020E61000000100000005000000158DB5BFB3F74940707841446AAE4B40158DB5BFB3F749403B8F8AFF3BEE4B40215C01857A744A403B8F8AFF3BEE4B40215C01857A744A40707841446AAE4B40158DB5BFB3F74940707841446AAE4B40
29817	Чувашское Черепаново	7	64	1815	48.44697	48.467793	54.798046999999997	54.787936000000002	0103000020E6100000010000000500000085251E5036394840A8AB3B16DB644B4085251E5036394840E0D5726726664B401C261AA4E03B4840E0D5726726664B401C261AA4E03B4840A8AB3B16DB644B4085251E5036394840A8AB3B16DB644B40
61505	Чувашский Чикилдым	7	64	1815	48.396323000000002	48.414971999999999	54.785443999999998	54.776772999999999	0103000020E6100000010000000500000089D349B6BA32484039B5334C6D634B4089D349B6BA324840726BD26D89644B40BB6070CD1D354840726BD26D89644B40BB6070CD1D35484039B5334C6D634B4089D349B6BA32484039B5334C6D634B40
29724	Чинчурино	7	64	1815	48.655262	48.684376	54.989387999999998	54.968581999999998	0103000020E61000000100000005000000E1270EA0DF53484044BFB67EFA7B4B40E1270EA0DF53484005871744A47E4B406A15FDA19957484005871744A47E4B406A15FDA19957484044BFB67EFA7B4B40E1270EA0DF53484044BFB67EFA7B4B40
29619	Федоровка	7	64	1815	48.638885999999999	48.662565000000001	54.934888000000001	54.922606999999999	0103000020E61000000100000005000000A6EF3504C7514840C40776FC17764B40A6EF3504C751484020B6F468AA774B40B43C0FEECE54484020B6F468AA774B40B43C0FEECE544840C40776FC17764B40A6EF3504C7514840C40776FC17764B40
29583	Урюм	7	64	1815	48.741177	48.772286000000001	54.786306000000003	54.758266999999996	0103000020E6100000010000000500000011C64FE3DE5E484069519FE40E614B4011C64FE3DE5E48400553CDACA5644B404F948444DA6248400553CDACA5644B404F948444DA62484069519FE40E614B4011C64FE3DE5E484069519FE40E614B40
29538	Тоншерма	7	64	1815	48.458280000000002	48.489792000000001	54.952877999999998	54.939397999999997	0103000020E61000000100000005000000983446EBA83A4840C2F693313E784B40983446EBA83A4840F88903E8F7794B40D5EB1681B13E4840F88903E8F7794B40D5EB1681B13E4840C2F693313E784B40983446EBA83A4840C2F693313E784B40
27321	Тетюши	7	64	1815	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
28082	Татарская Беденьга	7	64	1815	48.413310000000003	48.439604000000003	54.729424000000002	54.716669000000003	0103000020E610000001000000050000000D8E9257E73448404D874ECFBB5B4B400D8E9257E7344840717500C45D5D4B406C98A1F144384840717500C45D5D4B406C98A1F1443848404D874ECFBB5B4B400D8E9257E73448404D874ECFBB5B4B40
29488	Сюндюково	7	64	1815	48.248936	48.285929000000003	54.718822000000003	54.699019	0103000020E6100000010000000500000006668522DD1F48402D24607479594B4006668522DD1F48409AD2FA5B025C4B402FFD4B52992448409AD2FA5B025C4B402FFD4B52992448402D24607479594B4006668522DD1F48402D24607479594B40
29402	Пролей-Каша	7	64	1815	48.768754999999999	48.798777000000001	54.812266000000001	54.798482999999997	0103000020E6100000010000000500000078D1579066624840BBB4E1B034664B4078D15790666248408DD31055F8674B4004E621533E6648408DD31055F8674B4004E621533E664840BBB4E1B034664B4078D1579066624840BBB4E1B034664B40
61486	Починок-Новольяшево	7	64	1815	48.515340000000002	48.525599	54.782609000000001	54.775604999999999	0103000020E610000001000000050000000B293FA9F64148409ACE4E0647634B400B293FA9F641484013471E882C644B40B8E7F9D34643484013471E882C644B40B8E7F9D3464348409ACE4E0647634B400B293FA9F64148409ACE4E0647634B40
29263	Нармонка	7	64	1815	48.731313	48.750340000000001	54.960912	54.946586000000003	0103000020E61000000100000005000000E01115AA9B5D4840FD6CE4BA29794B40E01115AA9B5D4840BF2A172AFF7A4B40B97020240B604840BF2A172AFF7A4B40B97020240B604840FD6CE4BA29794B40E01115AA9B5D4840FD6CE4BA29794B40
29214	Монастырское	7	64	1815	48.825349000000003	48.850538	55.052680000000002	55.032350999999998	0103000020E61000000100000005000000A6643909A5694840177FDB1324844B40A6643909A56948409F93DE37BE864B40AC00DF6DDE6C48409F93DE37BE864B40AC00DF6DDE6C4840177FDB1324844B40A6643909A5694840177FDB1324844B40
29083	Малые Атряси	7	64	1815	48.760185	48.783703000000003	55.129170000000002	55.114615999999998	0103000020E6100000010000000500000073F4F8BD4D61484096CCB1BCAB8E4B4073F4F8BD4D614840EACF7EA488904B407863416150644840EACF7EA488904B40786341615064484096CCB1BCAB8E4B4073F4F8BD4D61484096CCB1BCAB8E4B40
29191	Малое Шемякино	7	64	1815	48.545434	48.567020999999997	55.071226000000003	55.056316000000002	0103000020E61000000100000005000000301004C8D0454840EB1ED95C35874B40301004C8D0454840FD4FFEEE1D894B409692E52494484840FD4FFEEE1D894B409692E52494484840EB1ED95C35874B40301004C8D0454840EB1ED95C35874B40
29060	Льяшево	7	64	1815	48.697347999999998	48.717066000000003	55.034244000000001	55.018628999999997	0103000020E610000001000000050000002BF702B342594840EBE0606F62824B402BF702B342594840C80A7E1B62844B406A8995D1C85B4840C80A7E1B62844B406A8995D1C85B4840EBE0606F62824B402BF702B342594840EBE0606F62824B40
28988	Лаптевка	7	64	1815	48.865127000000001	48.889884000000002	55.124927999999997	55.112153999999997	0103000020E610000001000000050000007CF1457BBC6E4840CB0EF10F5B8E4B407CF1457BBC6E4840662D05A4FD8F4B40E99D0AB8E7714840662D05A4FD8F4B40E99D0AB8E7714840CB0EF10F5B8E4B407CF1457BBC6E4840CB0EF10F5B8E4B40
28899	Кушкуй	7	64	1815	48.590341000000002	48.605963000000003	54.988520000000001	54.975113999999998	0103000020E61000000100000005000000753E3C4B904B484095EF1989D07C4B40753E3C4B904B484091B8C7D2877E4B4004CB1132904D484091B8C7D2877E4B4004CB1132904D484095EF1989D07C4B40753E3C4B904B484095EF1989D07C4B40
28888	Кошки-Новотимбаево	7	64	1815	48.494202999999999	48.530279	54.823382000000002	54.809728	0103000020E61000000100000005000000E44A3D0B423F4840E753C72AA5674B40E44A3D0B423F4840BB0ED59464694B40B760A92EE0434840BB0ED59464694B40B760A92EE0434840E753C72AA5674B40E44A3D0B423F4840E753C72AA5674B40
28820	Кляшево	7	64	1815	48.491965999999998	48.515385000000002	54.986103	54.975160000000002	0103000020E61000000100000005000000395FECBDF83E4840062FFA0AD27C4B40395FECBDF83E484066BE839F387E4B40ABECBB22F841484066BE839F387E4B40ABECBB22F8414840062FFA0AD27C4B40395FECBDF83E4840062FFA0AD27C4B40
28766	Киртели	7	64	1815	48.615296000000001	48.632696000000003	54.748967	54.732075000000002	0103000020E6100000010000000500000008AEF204C24E48400F9C33A2B45D4B4008AEF204C24E484041649126DE5F4B40AF27BA2EFC50484041649126DE5F4B40AF27BA2EFC5048400F9C33A2B45D4B4008AEF204C24E48400F9C33A2B45D4B40
28728	Кильдюшево	7	64	1815	48.665349999999997	48.686729999999997	54.769913000000003	54.747444000000002	0103000020E61000000100000005000000613255302A554840B4CBB73EAC5F4B40613255302A554840F4E159828C624B404E97C5C4E6574840F4E159828C624B404E97C5C4E6574840B4CBB73EAC5F4B40613255302A554840B4CBB73EAC5F4B40
28590	Кашка	7	64	1815	48.831062000000003	48.850385000000003	54.860818000000002	54.853247000000003	0103000020E610000001000000050000006479573D606A48407F349C32376D4B406479573D606A484071E7C2482F6E4B4026016A6AD96C484071E7C2482F6E4B4026016A6AD96C48407F349C32376D4B406479573D606A48407F349C32376D4B40
28686	Иоково	7	64	1815	48.665844	48.693539000000001	54.818770999999998	54.802779999999998	0103000020E61000000100000005000000711E4E603A55484002F1BA7EC1664B40711E4E603A554840E4F4F57CCD684B4012C0CDE2C5584840E4F4F57CCD684B4012C0CDE2C558484002F1BA7EC1664B40711E4E603A55484002F1BA7EC1664B40
28521	Жуково	7	64	1815	48.621971000000002	48.645902	54.807476999999999	54.791347000000002	0103000020E61000000100000005000000BC07E8BE9C4F4840D464C6DB4A654B40BC07E8BE9C4F4840D7A205685B674B40E335AFEAAC524840D7A205685B674B40E335AFEAAC524840D464C6DB4A654B40BC07E8BE9C4F4840D464C6DB4A654B40
28504	Вожжи	7	64	1815	48.331266999999997	48.357174000000001	54.738140999999999	54.726424000000002	0103000020E610000001000000050000003C9F01F5662A4840C7832D76FB5C4B403C9F01F5662A48401A6B7F677B5E4B40A27DACE0B72D48401A6B7F677B5E4B40A27DACE0B72D4840C7832D76FB5C4B403C9F01F5662A4840C7832D76FB5C4B40
28158	Верхние Тарханы	7	64	1815	48.488337000000001	48.511612	54.692265999999996	54.677900999999999	0103000020E61000000100000005000000A036AAD3813E48407D76C075C5564B40A036AAD3813E4840FD101B2C9C584B40DE1E84807C414840FD101B2C9C584B40DE1E84807C4148407D76C075C5564B40A036AAD3813E48407D76C075C5564B40
28407	Большое Шемякино	7	64	1815	48.604219999999998	48.642038999999997	55.047635999999997	55.029079000000003	0103000020E6100000010000000500000068CBB914574D48400D0055DCB8834B4068CBB914574D48405E0EBBEF18864B40D6E07D552E5248405E0EBBEF18864B40D6E07D552E5248400D0055DCB8834B4068CBB914574D48400D0055DCB8834B40
28247	Большое Бисярино	7	64	1815	48.655262	48.680720000000001	55.016719000000002	55.008102999999998	0103000020E61000000100000005000000E1270EA0DF534840EFFFE38409814B40E1270EA0DF534840651C23D923824B40D7DD3CD521574840651C23D923824B40D7DD3CD521574840EFFFE38409814B40E1270EA0DF534840EFFFE38409814B40
27967	Большие Тарханы	7	64	1815	48.511909000000003	48.563741999999998	54.717770999999999	54.693154999999997	0103000020E6100000010000000500000098C3EE3B864148408907944DB9584B4098C3EE3B8641484034828DEBDF5B4B40D9B0A6B22848484034828DEBDF5B4B40D9B0A6B2284848408907944DB9584B4098C3EE3B864148408907944DB9584B40
28228	Большие Атряси	7	64	1815	48.759124999999997	48.780980999999997	55.111918000000003	55.093055999999997	0103000020E61000000100000005000000BA490C022B61484029594E42E98B4B40BA490C022B614840B8EA3A54538E4B4010E6762FF7634840B8EA3A54538E4B4010E6762FF763484029594E42E98B4B40BA490C022B61484029594E42E98B4B40
28317	Большая Турма	7	64	1815	48.640880000000003	48.681213999999997	55.062899999999999	55.049410999999999	0103000020E610000001000000050000008B54185B085248400588821953864B408B54185B085248408E75711B0D884B40E6C93505325748408E75711B0D884B40E6C93505325748400588821953864B408B54185B085248400588821953864B40
28148	Богдашкино	7	64	1815	48.729013999999999	48.748893000000002	54.816509000000003	54.802874000000003	0103000020E61000000100000005000000BF29AC54505D484084674293C4664B40BF29AC54505D4840E1F1ED5D83684B40079ACFB9DB5F4840E1F1ED5D83684B40079ACFB9DB5F484084674293C4664B40BF29AC54505D484084674293C4664B40
28044	Бессоново	7	64	1815	48.445622	48.475634999999997	54.684896999999999	54.663936999999997	0103000020E61000000100000005000000663046240A3948405BCD3AE3FB544B40663046240A394840731074B4AA574B409EEA909BE13C4840731074B4AA574B409EEA909BE13C48405BCD3AE3FB544B40663046240A3948405BCD3AE3FB544B40
28004	Бакрчи	7	64	1815	48.441436000000003	48.465960000000003	54.760688000000002	54.743623999999997	0103000020E6100000010000000500000077A38FF980384840A6423C122F5F4B4077A38FF980384840D63A71395E614B40419FC893A43B4840D63A71395E614B40419FC893A43B4840A6423C122F5F4B4077A38FF980384840A6423C122F5F4B40
27926	Байрашево	7	64	1815	48.625689999999999	48.641356000000002	55.118045000000002	55.106737000000003	0103000020E6100000010000000500000095B7239C16504840F722DA8EA98D4B4095B7239C16504840693A3B191C8F4B40F48B12F417524840693A3B191C8F4B40F48B12F417524840F722DA8EA98D4B4095B7239C16504840F722DA8EA98D4B40
27871	Алекина Поляна	7	64	1815	48.620497	48.636218	54.881686000000002	54.869289999999999	0103000020E61000000100000005000000102219726C4F4840B35E0CE5446F4B40102219726C4F4840A8AB3B16DB704B40329067976F514840A8AB3B16DB704B40329067976F514840B35E0CE5446F4B40102219726C4F4840B35E0CE5446F4B40
27837	Алабердино	7	64	1815	48.699190000000002	48.715530000000001	55.101616999999997	55.082199000000003	0103000020E610000001000000050000005AD8D30E7F594840C861307F858A4B405AD8D30E7F594840DBDB2DC9018D4B4048A7AE7C965B4840DBDB2DC9018D4B4048A7AE7C965B4840C861307F858A4B405AD8D30E7F594840C861307F858A4B40
27060	Ямбухтино	7	64	1778	49.644945	49.681192000000003	55.014293000000002	54.998829000000001	0103000020E61000000100000005000000FF5BC98E8DD24840F0A5F0A0D97F4B40FF5BC98E8DD24840E7C75F5AD4814B40FF25A94C31D74840E7C75F5AD4814B40FF25A94C31D74840F0A5F0A0D97F4B40FF5BC98E8DD24840F0A5F0A0D97F4B40
61509	Чэчэкле (Новый Баран)	7	64	1778	48.861794000000003	49.837184000000001	55.245998999999998	54.555162000000003	0103000020E61000000100000005000000CCF10A444F6E4840B1FD648C0F474B40CCF10A444F6E4840A2EC2DE57C9F4B40035E66D828EB4840A2EC2DE57C9F4B40035E66D828EB4840B1FD648C0F474B40CCF10A444F6E4840B1FD648C0F474B40
26056	Урняк	7	64	1778	48.952145999999999	48.962432	54.915218000000003	54.904271000000001	0103000020E6100000010000000500000034828DEBDF79484051DCF126BF734B4034828DEBDF794840F35A09DD25754B40DB4FC6F8307B4840F35A09DD25754B40DB4FC6F8307B484051DCF126BF734B4034828DEBDF79484051DCF126BF734B40
26629	Тукай	7	64	1778	49.508671	49.529924999999999	55.004317999999998	54.983840000000001	0103000020E6100000010000000500000039B69E211CC14840923F1878EE7D4B4039B69E211CC148405E64027E8D804B40992A1895D4C348405E64027E8D804B40992A1895D4C34840923F1878EE7D4B4039B69E211CC14840923F1878EE7D4B40
25991	Три Озера	7	64	1778	49.031269999999999	49.071739000000001	54.92136	54.896920000000001	0103000020E6100000010000000500000047ACC5A7008448406D904946CE724B4047ACC5A700844840D9EBDD1FEF754B40836C59BE2E894840D9EBDD1FEF754B40836C59BE2E8948406D904946CE724B4047ACC5A7008448406D904946CE724B40
26795	Татарская Тахтала	7	64	1778	49.543596999999998	49.564177000000001	54.925446999999998	54.911797	0103000020E61000000100000005000000139A249694C54840A3CB9BC3B5744B40139A249694C5484035971B0C75764B40E413B2F336C8484035971B0C75764B40E413B2F336C84840A3CB9BC3B5744B40139A249694C54840A3CB9BC3B5744B40
26151	Танкеевка	7	64	1778	49.1083	49.130353999999997	54.826737999999999	54.814895999999997	0103000020E6100000010000000500000012143FC6DC8D484013D21A834E684B4012143FC6DC8D4840232E008DD2694B408E739B70AF904840232E008DD2694B408E739B70AF90484013D21A834E684B4012143FC6DC8D484013D21A834E684B40
27184	Средний Юрткуль	7	64	1778	49.482934	49.502741999999998	54.797373	54.781565999999998	0103000020E61000000100000005000000301004C8D0BD484030D5CC5A0A644B40301004C8D0BD484051DB865110664B40AE2990D959C0484051DB865110664B40AE2990D959C0484030D5CC5A0A644B40301004C8D0BD484030D5CC5A0A644B40
26310	Приволжский	7	64	1778	49.071317000000001	49.091313	54.991573000000002	54.980932000000003	0103000020E610000001000000050000000D535BEA20894840C9CC052E8F7D4B400D535BEA208948405E4C33DDEB7E4B408E59F624B08B48405E4C33DDEB7E4B408E59F624B08B4840C9CC052E8F7D4B400D535BEA20894840C9CC052E8F7D4B40
26083	Полянки	7	64	1778	48.980882999999999	48.997529	54.838582000000002	54.816654999999997	0103000020E61000000100000005000000E719FB928D7D4840B48EAA2688684B40E719FB928D7D4840D481ACA7566B4B40E2E7BF07AF7F4840D481ACA7566B4B40E2E7BF07AF7F4840B48EAA2688684B40E719FB928D7D4840B48EAA2688684B40
26382	Отрада	7	64	1778	49.352992999999998	49.368219000000003	54.859988999999999	54.849198999999999	0103000020E61000000100000005000000C45BE7DF2EAD4840E065868DB26C4B40C45BE7DF2EAD4840BAF59A1E146E4B400762D9CC21AF4840BAF59A1E146E4B400762D9CC21AF4840E065868DB26C4B40C45BE7DF2EAD4840E065868DB26C4B40
26320	Никольское	7	64	1778	49.385142999999999	49.408867999999998	54.930976999999999	54.906362000000001	0103000020E6100000010000000500000044A4A65D4CB14840282B86AB03744B4044A4A65D4CB14840022A1C412A774B40C23060C955B44840022A1C412A774B40C23060C955B44840282B86AB03744B4044A4A65D4CB14840282B86AB03744B40
26493	Куралово	7	64	1778	49.423276999999999	49.442653	55.055129999999998	55.040940999999997	0103000020E610000001000000050000001213D4F02DB648406308008E3D854B401213D4F02DB64840A583F57F0E874B40F73C7FDAA8B84840A583F57F0E874B40F73C7FDAA8B848406308008E3D854B401213D4F02DB648406308008E3D854B40
27068	Кузнечиха	7	64	1778	49.589078999999998	49.638674999999999	54.731493	54.706437999999999	0103000020E6100000010000000500000054E1CFF066CB48406953758F6C5A4B4054E1CFF066CB484060200890A15D4B40EBE2361AC0D1484060200890A15D4B40EBE2361AC0D148406953758F6C5A4B4054E1CFF066CB48406953758F6C5A4B40
26237	Красный Вал	7	64	1778	49.175485000000002	49.197009000000001	54.936202000000002	54.926822999999999	0103000020E6100000010000000500000023F8DF4A769648401E17D522A2764B4023F8DF4A7696484093399677D5774B40430246973799484093399677D5774B4043024697379948401E17D522A2764B4023F8DF4A769648401E17D522A2764B40
61488	Красная Слобода	7	64	1778	49.243335000000002	49.271434999999997	54.966856	54.953747	0103000020E61000000100000005000000707CED99259F48403DD4B661147A4B40707CED99259F48407FF8F9EFC17B4B40B0FECF61BEA248407FF8F9EFC17B4B40B0FECF61BEA248403DD4B661147A4B40707CED99259F48403DD4B661147A4B40
26587	Ким	7	64	1778	49.390568999999999	49.419297	55.002113000000001	54.985053999999998	0103000020E610000001000000050000006CEA3C2AFEB14840A165DD3F167E4B406CEA3C2AFEB14840BFF2203D45804B40CC272B86ABB54840BFF2203D45804B40CC272B86ABB54840A165DD3F167E4B406CEA3C2AFEB14840A165DD3F167E4B40
26919	Каюки	7	64	1778	49.686151000000002	49.708689	55.143034	55.127028000000003	0103000020E61000000100000005000000118FC4CBD3D7484091D6187442904B40118FC4CBD3D74840A81B28F04E924B4079043752B6DA4840A81B28F04E924B4079043752B6DA484091D6187442904B40118FC4CBD3D7484091D6187442904B40
61335	Иске-Рязяп	7	64	1778	49.642662999999999	49.696032000000002	54.604368999999998	54.581938000000001	0103000020E61000000100000005000000B4ACFBC742D248405B26C3F17C4A4B40B4ACFBC742D24840ADDBA0F65B4D4B40187C9A9317D94840ADDBA0F65B4D4B40187C9A9317D948405B26C3F17C4A4B40B4ACFBC742D248405B26C3F17C4A4B40
26958	Измери	7	64	1778	49.526232999999998	49.552266000000003	55.145328999999997	55.132849999999998	0103000020E61000000100000005000000B9895A9A5BC3484005A3923A01914B40B9895A9A5BC34840871403249A924B40AC58FCA6B0C64840871403249A924B40AC58FCA6B0C6484005A3923A01914B40B9895A9A5BC3484005A3923A01914B40
27218	Иж-Борискино	7	64	1778	49.551475000000003	49.572755999999998	54.836705000000002	54.821795000000002	0103000020E61000000100000005000000E3C798BB96C6484017821C9430694B40E3C798BB96C6484029B34126196B4B403C4B901150C9484029B34126196B4B403C4B901150C9484017821C9430694B40E3C798BB96C6484017821C9430694B40
26522	Екатериновка	7	64	1778	49.519934999999997	49.537452999999999	55.040605999999997	55.033237999999997	0103000020E61000000100000005000000DB85E63A8DC24840027E8D2441844B40DB85E63A8DC24840BC02D19332854B408C118942CBC44840BC02D19332854B408C118942CBC44840027E8D2441844B40DB85E63A8DC24840027E8D2441844B40
26726	Гусиха	7	64	1778	49.517699	49.539501000000001	54.884461999999999	54.873181000000002	0103000020E610000001000000050000000116F9F543C248408A3E1F65C46F4B400116F9F543C248400247020D36714B406494675E0EC548400247020D36714B406494675E0EC548408A3E1F65C46F4B400116F9F543C248408A3E1F65C46F4B40
26990	Вожи	7	64	1778	49.56221	49.617088000000003	55.110469999999999	55.097166999999999	0103000020E61000000100000005000000F9BD4D7FF6C748400EA0DFF76F8C4B40F9BD4D7FF6C74840359886E1238E4B40856055BDFCCE4840359886E1238E4B40856055BDFCCE48400EA0DFF76F8C4B40F9BD4D7FF6C748400EA0DFF76F8C4B40
26876	Бураково	7	64	1778	49.649428	49.669110000000003	55.130507999999999	55.122070999999998	0103000020E61000000100000005000000A88DEA7420D348401F65C405A08F4B40A88DEA7420D34840E5EE737CB4904B409AB67F65A5D54840E5EE737CB4904B409AB67F65A5D548401F65C405A08F4B40A88DEA7420D348401F65C405A08F4B40
26426	Бугровка	7	64	1778	49.306604	49.325018999999998	54.915796999999998	54.903396000000001	0103000020E610000001000000050000005169C4CC3EA748402AABE97AA2734B405169C4CC3EA7484030630AD638754B4010CAFB389AA9484030630AD638754B4010CAFB389AA948402AABE97AA2734B405169C4CC3EA748402AABE97AA2734B40
25642	Болгар	7	64	1778	49.009692000000001	49.049720999999998	54.992224	54.959184999999998	0103000020E61000000100000005000000348463963D81484029E8F692C67A4B40348463963D81484035272F32017F4B405376FA415D86484035272F32017F4B405376FA415D86484029E8F692C67A4B40348463963D81484029E8F692C67A4B40
26127	Балымеры	7	64	1778	48.946666999999998	48.971837000000001	54.862617	54.848011999999997	0103000020E61000000100000005000000E9995E622C794840CA4E3FA88B6C4B40E9995E622C794840A0FCDD3B6A6E4B407905A227657C4840A0FCDD3B6A6E4B407905A227657C4840CA4E3FA88B6C4B40E9995E622C794840CA4E3FA88B6C4B40
26684	Антоновка	7	64	1778	49.459712000000003	49.520519	54.922203000000003	54.902997999999997	0103000020E6100000010000000500000015CAC2D7D7BA48403C2D3F7095734B4015CAC2D7D7BA4840F5A276BF0A764B402BF9D85DA0C24840F5A276BF0A764B402BF9D85DA0C248403C2D3F7095734B4015CAC2D7D7BA48403C2D3F7095734B40
26787	Аграмаковка	7	64	1778	49.627554000000003	49.649715	54.951255000000003	54.93629	0103000020E61000000100000005000000AC3C81B053D0484032C9C859D8774B40AC3C81B053D0484008944DB9C2794B403E5C72DC29D3484008944DB9C2794B403E5C72DC29D3484032C9C859D8774B40AC3C81B053D0484032C9C859D8774B40
61515	Яхшы-Каран	7	64	1265	52.859225000000002	52.880470000000003	55.154480999999997	55.141129999999997	0103000020E61000000100000005000000EB73B515FB6D4A40033E3F8C10924B40EB73B515FB6D4A403B6D8D08C6934B40F88DAF3DB3704A403B6D8D08C6934B40F88DAF3DB3704A40033E3F8C10924B40EB73B515FB6D4A40033E3F8C10924B40
24870	Янурусово	7	64	1265	52.597977	52.616374	55.322536999999997	55.304611000000001	0103000020E610000001000000050000004E61A5828A4C4A403D80457EFDA64B404E61A5828A4C4A40FE5F75E448A94B40670DDE57E54E4A40FE5F75E448A94B40670DDE57E54E4A403D80457EFDA64B404E61A5828A4C4A403D80457EFDA64B40
22882	Юлтимирово	7	64	1265	52.596359999999997	52.616239999999998	55.368124000000002	55.358412000000001	0103000020E610000001000000050000003F524486554C4A403A3FC571E0AD4B403F524486554C4A40B56FEEAF1EAF4B40573ECBF3E04E4A40B56FEEAF1EAF4B40573ECBF3E04E4A403A3FC571E0AD4B403F524486554C4A403A3FC571E0AD4B40
22912	Шигаево	7	64	1265	52.537402999999998	52.558585999999998	55.417377999999999	55.399785999999999	0103000020E61000000100000005000000DAE21A9FC9444A4007B309302CB34B40DAE21A9FC9444A40F2086EA46CB54B407100FDBE7F474A40F2086EA46CB54B407100FDBE7F474A4007B309302CB34B40DAE21A9FC9444A4007B309302CB34B40
24053	Шарлиарема	7	64	1265	52.725008000000003	52.745874999999998	55.413116000000002	55.40522	0103000020E6100000010000000500000050ABE80FCD5C4A40B2D7BB3FDEB34B4050ABE80FCD5C4A4028BA2EFCE0B44B40B6F3FDD4785F4A4028BA2EFCE0B44B40B6F3FDD4785F4A40B2D7BB3FDEB34B4050ABE80FCD5C4A40B2D7BB3FDEB34B40
23329	Чурашево	7	64	1265	52.788572000000002	52.814183	55.464334999999998	55.452517999999998	0103000020E610000001000000050000004A4563EDEF644A40F86C1D1CECB94B404A4563EDEF644A40AFB14B546FBB4B40C6FA062637684A40AFB14B546FBB4B40C6FA062637684A40F86C1D1CECB94B404A4563EDEF644A40F86C1D1CECB94B40
24788	Чукмарлы	7	64	1265	52.417181999999997	52.440655	55.291468999999999	55.277020999999998	0103000020E610000001000000050000006C3D433866354A4011A7936C75A34B406C3D433866354A401F662FDB4EA54B40D1E80E6267384A401F662FDB4EA54B40D1E80E6267384A4011A7936C75A34B406C3D433866354A4011A7936C75A34B40
61426	Сырысаз-Такерман	7	64	1265	52.730173000000001	52.750672000000002	55.373240000000003	55.361569000000003	0103000020E610000001000000050000000BB6114F765D4A40AC1F9BE447AE4B400BB6114F765D4A408FC70C54C6AF4B40EF02250516604A408FC70C54C6AF4B40EF02250516604A40AC1F9BE447AE4B400BB6114F765D4A40AC1F9BE447AE4B40
24003	Сулюково	7	64	1265	52.762161999999996	52.785249	55.440514	55.431744000000002	0103000020E61000000100000005000000812040868E614A40431F2C6343B74B40812040868E614A400FB743C362B84B40BD1B0B0A83644A400FB743C362B84B40BD1B0B0A83644A40431F2C6343B74B40812040868E614A40431F2C6343B74B40
24446	Сулы-Саклово	7	64	1265	52.850655000000003	52.866681	55.412114000000003	55.401330000000002	0103000020E61000000100000005000000E6965643E26C4A40AC730CC85EB34B40E6965643E26C4A40A41CCC26C0B44B4044882B67EF6E4A40A41CCC26C0B44B4044882B67EF6E4A40AC730CC85EB34B40E6965643E26C4A40AC730CC85EB34B40
24771	Старый Мензелябаш	7	64	1265	52.672905	52.707526000000001	55.083235000000002	55.069319	0103000020E610000001000000050000004E2844C021564A40E7FEEA71DF884B404E2844C021564A40F870C971A78A4B40EC884336905A4A40F870C971A78A4B40EC884336905A4A40E7FEEA71DF884B404E2844C021564A40E7FEEA71DF884B40
24657	Старый Кашир	7	64	1265	52.532111999999998	52.56756	55.160442000000003	55.146250000000002	0103000020E6100000010000000500000092E7FA3E1C444A401F85EB51B8924B4092E7FA3E1C444A40D2730B5D89944B4046425BCEA5484A40D2730B5D89944B4046425BCEA5484A401F85EB51B8924B4092E7FA3E1C444A401F85EB51B8924B40
24519	Старый Имян	7	64	1265	52.777738999999997	52.806781000000001	55.367550999999999	55.355908999999997	0103000020E6100000010000000500000070E998F38C634A4010AD156D8EAD4B4070E998F38C634A40594E42E90BAF4B4060048D9944674A40594E42E90BAF4B4060048D9944674A4010AD156D8EAD4B4070E998F38C634A4010AD156D8EAD4B40
24611	Средний Кашир	7	64	1265	52.491643000000003	52.519877000000001	55.161172999999998	55.152732	0103000020E6100000010000000500000057276728EE3E4A40BE86E0B88C934B4057276728EE3E4A40C5FF1D51A1944B40A7785C548B424A40C5FF1D51A1944B40A7785C548B424A40BE86E0B88C934B4057276728EE3E4A40BE86E0B88C934B40
24945	Сарманово	7	64	1265	52.571198000000003	52.614946000000003	55.264947999999997	55.240169000000002	0103000020E6100000010000000500000033C51C041D494A40AB4198DBBD9E4B4033C51C041D494A40FF91E9D0E9A14B402C67EF8CB64E4A40FF91E9D0E9A14B402C67EF8CB64E4A40AB4198DBBD9E4B4033C51C041D494A40AB4198DBBD9E4B40
23523	Сарайлы	7	64	1265	52.629821999999997	52.655577000000001	55.1539	55.138331000000001	0103000020E610000001000000050000009126DE019E504A40F18288D4B4914B409126DE019E504A405D6DC5FEB2934B40418177F2E9534A405D6DC5FEB2934B40418177F2E9534A40F18288D4B4914B409126DE019E504A40F18288D4B4914B40
24338	Саклов-Баш	7	64	1265	52.870319000000002	52.891024999999999	55.390169	55.373438999999998	0103000020E61000000100000005000000310BED9C666F4A40850662D9CCAF4B40310BED9C666F4A40DE74CB0EF1B14B408E75711B0D724A40DE74CB0EF1B14B408E75711B0D724A40850662D9CCAF4B40310BED9C666F4A40850662D9CCAF4B40
24304	Рантамак	7	64	1265	52.874146000000003	52.890557999999999	55.209713999999998	55.198524999999997	0103000020E61000000100000005000000F1F62004E46F4A401D38674469994B40F1F62004E46F4A40B5C189E8D79A4B407898F6CDFD714A40B5C189E8D79A4B407898F6CDFD714A401D38674469994B40F1F62004E46F4A401D38674469994B40
24258	Рангазар	7	64	1265	52.743952999999998	52.769995000000002	55.224848999999999	55.211886999999997	0103000020E610000001000000050000006B6116DA395F4A4049B9FB1C1F9B4B406B6116DA395F4A40E7C41EDAC79C4B40B18A37328F624A40E7C41EDAC79C4B40B18A37328F624A4049B9FB1C1F9B4B406B6116DA395F4A4049B9FB1C1F9B4B40
24094	Петровский Завод	7	64	1265	52.47842	52.508656999999999	55.326138	55.311523000000001	0103000020E610000001000000050000004CE0D6DD3C3D4A40D57954FCDFA74B404CE0D6DD3C3D4A40CEFDD5E3BEA94B40D4F02DAC1B414A40CEFDD5E3BEA94B40D4F02DAC1B414A40D57954FCDFA74B404CE0D6DD3C3D4A40D57954FCDFA74B40
23887	Новый Имян	7	64	1265	52.434914999999997	52.456851999999998	55.126677999999998	55.111660000000001	0103000020E6100000010000000500000019C5724BAB374A40BC22F8DF4A8E4B4019C5724BAB374A40B48F15FC36904B405C8E57207A3A4A40B48F15FC36904B405C8E57207A3A4A40BC22F8DF4A8E4B4019C5724BAB374A40BC22F8DF4A8E4B40
13155	Новое Ахметово	7	64	1265	52.588867999999998	52.606456999999999	55.279682000000001	55.269261	0103000020E6100000010000000500000099D4D006604B4A404C8BFA2477A24B4099D4D006604B4A40D3A3A99ECCA34B4013B70A62A04D4A40D3A3A99ECCA34B4013B70A62A04D4A404C8BFA2477A24B4099D4D006604B4A404C8BFA2477A24B40
23466	Нижний Лешев	7	64	1265	52.568072000000001	52.588500000000003	55.103836999999999	55.092709999999997	0103000020E61000000100000005000000FCE25295B6484A408E01D9EBDD8B4B40FCE25295B6484A40B08EE3874A8D4B4017D9CEF7534B4A40B08EE3874A8D4B4017D9CEF7534B4A408E01D9EBDD8B4B40FCE25295B6484A408E01D9EBDD8B4B40
24165	Мустафино	7	64	1265	52.361666	52.381366	55.331234000000002	55.32687	0103000020E610000001000000050000009E094D124B2E4A4092054CE0D6A94B409E094D124B2E4A4061A92EE065AA4B4036E7E099D0304A4061A92EE065AA4B4036E7E099D0304A4092054CE0D6A94B409E094D124B2E4A4092054CE0D6A94B40
23687	Муртыш-Тамак	7	64	1265	52.591149999999999	52.614775000000002	55.22831	55.201900000000002	0103000020E61000000100000005000000E4839ECDAA4B4A40FD87F4DBD7994B40E4839ECDAA4B4A40C5AC1743399D4B40FFB27BF2B04E4A40C5AC1743399D4B40FFB27BF2B04E4A40FD87F4DBD7994B40E4839ECDAA4B4A40FD87F4DBD7994B40
23199	Муртыш-Баш	7	64	1265	52.544742999999997	52.572077999999998	55.225101000000002	55.213608000000001	0103000020E61000000100000005000000CADC7C23BA454A40FD14C781579B4B40CADC7C23BA454A4001A60C1CD09C4B406B6116DA39494A4001A60C1CD09C4B406B6116DA39494A40FD14C781579B4B40CADC7C23BA454A40FD14C781579B4B40
23609	Ляки	7	64	1265	52.461370000000002	52.487842999999998	55.353099999999998	55.338012999999997	0103000020E6100000010000000500000082AD122C0E3B4A40B94F8E0244AB4B4082AD122C0E3B4A40DA1B7C6132AD4B40904AB1A3713E4A40DA1B7C6132AD4B40904AB1A3713E4A40B94F8E0244AB4B4082AD122C0E3B4A40B94F8E0244AB4B40
23386	Лешев-Тамак	7	64	1265	52.614488000000001	52.63832	55.122107	55.113503999999999	0103000020E6100000010000000500000069E4F38AA74E4A408BFB8F4C878E4B4069E4F38AA74E4A406CCEC133A18F4B40FD304278B4514A406CCEC133A18F4B40FD304278B4514A408BFB8F4C878E4B4069E4F38AA74E4A408BFB8F4C878E4B40
23861	Кутемели	7	64	1265	52.496026999999998	52.520794000000002	55.135212000000003	55.123269999999998	0103000020E610000001000000050000006C770FD07D3F4A40F949B54FC78F4B406C770FD07D3F4A406D0377A04E914B40FDF9B660A9424A406D0377A04E914B40FDF9B660A9424A40F949B54FC78F4B406C770FD07D3F4A40F949B54FC78F4B40
23724	Кульметьево	7	64	1265	52.613346999999997	52.624279999999999	55.191201999999997	55.178198000000002	0103000020E61000000100000005000000C30C8D27824E4A40371B2B31CF964B40C30C8D27824E4A400377A04E79984B4000C63368E84F4A400377A04E79984B4000C63368E84F4A40371B2B31CF964B40C30C8D27824E4A40371B2B31CF964B40
24706	Кузяково	7	64	1265	52.605001999999999	52.626021999999999	55.090691	55.081049999999998	0103000020E61000000100000005000000DE019EB4704D4A409FABADD85F8A4B40DE019EB4704D4A4051853FC39B8B4B40CB49287D21504A4051853FC39B8B4B40CB49287D21504A409FABADD85F8A4B40DE019EB4704D4A409FABADD85F8A4B40
24864	Каташ-Каран	7	64	1265	52.615682999999997	52.647509999999997	55.304606	55.289526000000002	0103000020E6100000010000000500000001DA56B3CE4E4A40BDAB1E300FA54B4001DA56B3CE4E4A402B155454FDA64B409EEA909BE1524A402B155454FDA64B409EEA909BE1524A40BDAB1E300FA54B4001DA56B3CE4E4A40BDAB1E300FA54B40
23292	Карашай-Саклово	7	64	1265	52.820948000000001	52.851579999999998	55.480097000000001	55.466448	0103000020E61000000100000005000000BADBF5D214694A406EA46C91B4BB4B40BADBF5D214694A4030F488D173BD4B40BEF6CC92006D4A4030F488D173BD4B40BEF6CC92006D4A406EA46C91B4BB4B40BADBF5D214694A406EA46C91B4BB4B40
23245	Кавзияково	7	64	1265	52.798696	52.831780999999999	55.286557999999999	55.268912999999998	0103000020E6100000010000000500000017B9A7AB3B664A40103CBEBD6BA24B4017B9A7AB3B664A401E34BBEEADA44B409337C0CC776A4A401E34BBEEADA44B409337C0CC776A4A40103CBEBD6BA24B4017B9A7AB3B664A40103CBEBD6BA24B40
23108	Иляксаз	7	64	1265	52.520873999999999	52.549799999999998	55.247923999999998	55.237124999999999	0103000020E6100000010000000500000019ABCDFFAB424A403108AC1C5A9E4B4019ABCDFFAB424A405EF23FF9BB9F4B409FABADD85F464A405EF23FF9BB9F4B409FABADD85F464A403108AC1C5A9E4B4019ABCDFFAB424A403108AC1C5A9E4B40
24176	Димитарлау	7	64	1265	52.531618000000002	52.553033999999997	55.299833999999997	55.284210000000002	0103000020E6100000010000000500000083FB010F0C444A401C9947FE60A44B4083FB010F0C444A404B1DE4F560A64B40BCC96FD1C9464A404B1DE4F560A64B40BCC96FD1C9464A401C9947FE60A44B4083FB010F0C444A401C9947FE60A44B40
25227	Джалиль	7	64	1265	52.728897000000003	52.749899999999997	55.032499999999999	55.016326999999997	0103000020E610000001000000050000008693347F4C5D4A405985CD0017824B408693347F4C5D4A405C8FC2F528844B409CA223B9FC5F4A405C8FC2F528844B409CA223B9FC5F4A405985CD0017824B408693347F4C5D4A405985CD0017824B40
23602	Верхние Чершилы	7	64	1265	52.466715000000001	52.488472000000002	55.38776	55.380226999999998	0103000020E61000000100000005000000BDC62E51BD3B4A4031074147ABB04B40BDC62E51BD3B4A403659A31EA2B14B4080812040863E4A403659A31EA2B14B4080812040863E4A4031074147ABB04B40BDC62E51BD3B4A4031074147ABB04B40
23806	Буралы-Чишма	7	64	1265	52.479686999999998	52.493259999999999	55.088459999999998	55.081420999999999	0103000020E610000001000000050000007EA83462663D4A40931ADA006C8A4B407EA83462663D4A40888043A8528B4B406536C824233F4A40888043A8528B4B406536C824233F4A40931ADA006C8A4B407EA83462663D4A40931ADA006C8A4B40
23963	Большое Нуркеево	7	64	1265	52.643116999999997	52.686703000000001	55.388123	55.368020999999999	0103000020E61000000100000005000000354069A851524A40E09EE74F1BAF4B40354069A851524A40A7E9B303AEB14B40558847E2E5574A40A7E9B303AEB14B40558847E2E5574A40E09EE74F1BAF4B40354069A851524A40E09EE74F1BAF4B40
23065	Альметьево	7	64	1265	52.705495999999997	52.733280999999998	55.260013000000001	55.245784	0103000020E61000000100000005000000BABA63B14D5A4A40A6F0A0D9759F4B40BABA63B14D5A4A4076C4211B48A14B409BE3DC26DC5D4A4076C4211B48A14B409BE3DC26DC5D4A40A6F0A0D9759F4B40BABA63B14D5A4A40A6F0A0D9759F4B40
22960	Александровка	7	64	1265	52.755946000000002	52.790207000000002	55.151837	55.132845000000003	0103000020E6100000010000000500000061C5A9D6C2604A40F437A11001914B4061C5A9D6C2604A4050A912656F934B40FF08C38025654A4050A912656F934B40FF08C38025654A40F437A11001914B4061C5A9D6C2604A40F437A11001914B40
22830	Азалаково	7	64	1265	52.627746999999999	52.654679000000002	55.349189000000003	55.322937000000003	0103000020E61000000100000005000000C09481035A504A408DD5E6FF55A94B40C09481035A504A40BD8FA339B2AC4B4062307F85CC534A40BD8FA339B2AC4B4062307F85CC534A408DD5E6FF55A94B40C09481035A504A408DD5E6FF55A94B40
22752	Юлбат	7	64	1640	50.453761	50.479686999999998	55.960194999999999	55.943849999999998	0103000020E61000000100000005000000A29927D7143A4940302AA913D0F84B40A29927D7143A4940306475ABE7FA4B407EA83462663D4940306475ABE7FA4B407EA83462663D4940302AA913D0F84B40A29927D7143A4940302AA913D0F84B40
22431	Шикши	7	64	1640	50.456735000000002	50.491517000000002	56.107894999999999	56.101429000000003	0103000020E6100000010000000500000023F8DF4A763A4940D9EE1EA0FB0C4C4023F8DF4A763A49407233DC80CF0D4C40CA367007EA3E49407233DC80CF0D4C40CA367007EA3E4940D9EE1EA0FB0C4C4023F8DF4A763A4940D9EE1EA0FB0C4C40
22481	Шемордан	7	64	1640	50.379002999999997	50.424107999999997	56.197308	56.178994000000003	0103000020E61000000100000005000000FE0A992B8330494012178046E9164C40FE0A992B833049409D9E776341194C4069FCC22B493649409D9E776341194C4069FCC22B4936494012178046E9164C40FE0A992B8330494012178046E9164C40
20921	Уют	7	64	1640	50.274745000000003	50.297589000000002	55.955514000000001	55.943911	0103000020E61000000100000005000000A9DE1AD82A234940D6AA5D13D2F84B40A9DE1AD82A234940616F62484EFA4B401E53776517264940616F62484EFA4B401E53776517264940D6AA5D13D2F84B40A9DE1AD82A234940D6AA5D13D2F84B40
21357	Туктар	7	64	1640	50.523246	50.547285000000002	55.997205000000001	55.987684000000002	0103000020E61000000100000005000000A4E194B9F94249402864E76D6CFE4B40A4E194B9F94249402F34D769A4FF4B40B24B546F0D4649402F34D769A4FF4B40B24B546F0D4649402864E76D6CFE4B40A4E194B9F94249402864E76D6CFE4B40
22316	Тимершик	7	64	1640	50.329704	50.364387999999998	56.051949	56.039389	0103000020E6100000010000000500000021AE9CBD332A49403C69E1B20A054C4021AE9CBD332A4940AB07CC43A6064C4005871744A42E4940AB07CC43A6064C4005871744A42E49403C69E1B20A054C4021AE9CBD332A49403C69E1B20A054C40
32987	Старая Икшурма	7	64	1640	50.606510999999998	50.636299000000001	55.877172000000002	55.86009	0103000020E6100000010000000500000006D50627A24D4940EECEDA6D17EE4B4006D50627A24D4940C47B0E2C47F04B401FBDE13E72514940C47B0E2C47F04B401FBDE13E72514940EECEDA6D17EE4B4006D50627A24D4940EECEDA6D17EE4B40
61484	Ст.Мичан	7	64	1640	50.255789999999998	50.273136999999998	56.068142999999999	56.053015000000002	0103000020E6100000010000000500000069520ABABD20494046990D32C9064C4069520ABABD204940C539EAE8B8084C40ED293927F6224940C539EAE8B8084C40ED293927F622494046990D32C9064C4069520ABABD20494046990D32C9064C40
22180	Сатышево	7	64	1640	50.413156999999998	50.436154000000002	55.938288999999997	55.923352000000001	0103000020E61000000100000005000000868E1D54E23449401D59F96530F64B40868E1D54E234494028999CDA19F84B408202EFE4D337494028999CDA19F84B408202EFE4D33749401D59F96530F64B40868E1D54E23449401D59F96530F64B40
21641	Сабабаш	7	64	1640	50.596054000000002	50.615304999999999	56.037985999999997	56.027887	0103000020E6100000010000000500000033535A7F4B4C4940E57D1CCD91034C4033535A7F4B4C494059DAA9B9DC044C405B087250C24E494059DAA9B9DC044C405B087250C24E4940E57D1CCD91034C4033535A7F4B4C4940E57D1CCD91034C40
21223	Олуяз	7	64	1640	50.410049000000001	50.426766999999998	56.143082	56.134098999999999	0103000020E61000000100000005000000F660527C7C34494091B6F1272A114C40F660527C7C344940B952CF8250124C408A01124DA0364940B952CF8250124C408A01124DA036494091B6F1272A114C40F660527C7C34494091B6F1272A114C40
21550	Нижний Отар	7	64	1640	50.287922999999999	50.314585000000001	56.125349999999997	56.113838000000001	0103000020E6100000010000000500000013622EA9DA24494062855B3E920E4C4013622EA9DA244940DC4603780B104C40F5673F5244284940DC4603780B104C40F5673F524428494062855B3E920E4C4013622EA9DA24494062855B3E920E4C40
21808	Нижние Шитцы	7	64	1640	50.483711	50.508001	55.892890000000001	55.877395	0103000020E6100000010000000500000094DBF63DEA3D49404356B77A4EF04B4094DBF63DEA3D4940757632384AF24B40EBAA402D06414940757632384AF24B40EBAA402D064149404356B77A4EF04B4094DBF63DEA3D49404356B77A4EF04B40
22712	Мичанбаш	7	64	1640	50.339818999999999	50.356212999999997	56.164029999999997	56.157758999999999	0103000020E610000001000000050000009BC761307F2B494028D3687231144C409BC761307F2B49400CC85EEFFE144C407CB43863982D49400CC85EEFFE144C407CB43863982D494028D3687231144C409BC761307F2B494028D3687231144C40
61482	Мингер	7	64	1640	50.313479999999998	50.330601999999999	56.027112000000002	56.015856999999997	0103000020E610000001000000050000009CF9D51C20284940D234289A07024C409CF9D51C2028494022AAF06778034C4000FF942A512A494022AAF06778034C4000FF942A512A4940D234289A07024C409CF9D51C20284940D234289A07024C40
22227	Мамалаево	7	64	1640	50.424925000000002	50.442414999999997	55.867494999999998	55.858694999999997	0103000020E610000001000000050000005C2041F1633649408E1EBFB7E9ED4B405C2041F163364940C5387F130AEF4B404221020EA1384940C5387F130AEF4B404221020EA13849408E1EBFB7E9ED4B405C2041F1633649408E1EBFB7E9ED4B40
40912	Лесхоз	7	64	1640	50.682741999999998	50.702981000000001	56.053139999999999	56.035004000000001	0103000020E6100000010000000500000085CD001764574940569DD5027B044C4085CD001764574940020EA14ACD064C40CD5A0A48FB594940020EA14ACD064C40CD5A0A48FB594940569DD5027B044C4085CD001764574940569DD5027B044C40
22363	Кызыл-Меша	7	64	1640	50.354632000000002	50.375490999999997	56.081788000000003	56.065952000000003	0103000020E61000000100000005000000BB0ED594642D49408B8D791D71084C40BB0ED594642D4940469A7807780A4C409E78CE1610304940469A7807780A4C409E78CE16103049408B8D791D71084C40BB0ED594642D49408B8D791D71084C40
21745	Кренни	7	64	1640	50.263947000000002	50.279677	56.097814	56.087207999999997	0103000020E610000001000000050000004C70EA03C92149408BF9B9A1290B4C404C70EA03C9214940A48B4D2B850C4C40C138B874CC234940A48B4D2B850C4C40C138B874CC2349408BF9B9A1290B4C404C70EA03C92149408BF9B9A1290B4C40
21453	Корсабаш	7	64	1640	50.284185999999998	50.303859000000003	56.153176999999999	56.143484000000001	0103000020E6100000010000000500000093FDF33460244940E8BF07AF5D124C4093FDF33460244940ECBFCE4D9B134C4032CC09DAE4264940ECBFCE4D9B134C4032CC09DAE4264940E8BF07AF5D124C4093FDF33460244940E8BF07AF5D124C40
61425	Корса	7	64	1640	50.166156999999998	50.187976999999997	56.116652999999999	56.105314999999997	0103000020E610000001000000050000003080F0A1441549409D6340F67A0D4C403080F0A1441549407AFD497CEE0E4C4039B35DA10F1849407AFD497CEE0E4C4039B35DA10F1849409D6340F67A0D4C403080F0A1441549409D6340F67A0D4C40
21321	Кильдебяк	7	64	1640	50.556258999999997	50.580316000000003	56.026693999999999	56.017356999999997	0103000020E61000000100000005000000868DB27E33474940A7AD11C138024C40868DB27E33474940ED7F80B56A034C403BAC70CB474A4940ED7F80B56A034C403BAC70CB474A4940A7AD11C138024C40868DB27E33474940A7AD11C138024C40
61394	Илебер	7	64	1640	50.408208000000002	50.427520999999999	56.103397000000001	56.086319000000003	0103000020E6100000010000000500000098FBE42840344940000341800C0B4C4098FBE4284034494094C0E61C3C0D4C4036AD1402B936494094C0E61C3C0D4C4036AD1402B9364940000341800C0B4C4098FBE42840344940000341800C0B4C40
61479	Измя	7	64	1640	50.381625999999997	50.403734	56.111449	56.101568999999998	0103000020E61000000100000005000000D2A6EA1ED9304940CAA48636000D4C40D2A6EA1ED93049400116F9F5430E4C404224438EAD3349400116F9F5430E4C404224438EAD334940CAA48636000D4C40D2A6EA1ED9304940CAA48636000D4C40
21082	Евлаштау	7	64	1640	50.533557999999999	50.565708999999998	56.116517999999999	56.109506000000003	0103000020E610000001000000050000007442E8A04B4449409F5BE84A040E4C407442E8A04B4449409AB2D30FEA0E4C40C4060B27694849409AB2D30FEA0E4C40C4060B27694849409F5BE84A040E4C407442E8A04B4449409F5BE84A040E4C40
20686	Два Поля Арташ	7	64	1640	50.648668999999998	50.660868000000001	55.951118999999998	55.934244999999997	0103000020E61000000100000005000000EA76F69507534940CBB9145795F74B40EA76F6950753494057CD7344BEF94B40897C97529754494057CD7344BEF94B40897C975297544940CBB9145795F74B40EA76F69507534940CBB9145795F74B40
21048	Верхний Симет	7	64	1640	50.169175000000003	50.202260000000003	56.061312999999998	56.048872000000003	0103000020E610000001000000050000008126C286A715494056D80C7041064C408126C286A7154940EAE8B81AD9074C40FDA4DAA7E3194940EAE8B81AD9074C40FDA4DAA7E319494056D80C7041064C408126C286A715494056D80C7041064C40
21903	Верхние Шитцы	7	64	1640	50.506366	50.529919999999997	55.912157999999998	55.898688999999997	0103000020E6100000010000000500000036E7E099D04049403123BC3D08F34B4036E7E099D04049407364E597C1F44B4087BF266BD44349407364E597C1F44B4087BF266BD44349403123BC3D08F34B4036E7E099D04049403123BC3D08F34B40
20903	Большой Шинар	7	64	1640	50.258090000000003	50.277898	55.994903999999998	55.981157000000003	0103000020E610000001000000050000005BB6D61709214940E99E758D96FD4B405BB6D617092149406D54A70359FF4B40D9CF6229922349406D54A70359FF4B40D9CF622992234940E99E758D96FD4B405BB6D61709214940E99E758D96FD4B40
20809	Большие Нырты	7	64	1640	50.704453999999998	50.723686999999998	55.973683000000001	55.958598000000002	0103000020E61000000100000005000000A8C4758C2B5A49406901DA56B3FA4B40A8C4758C2B5A4940E9D500A5A1FC4B402AC58EC6A15C4940E9D500A5A1FC4B402AC58EC6A15C49406901DA56B3FA4B40A8C4758C2B5A49406901DA56B3FA4B40
20792	Большие Кибячи	7	64	1640	50.622518999999997	50.653699000000003	55.834026999999999	55.821032000000002	0103000020E61000000100000005000000BE11DDB3AE4F4940187C9A9317E94B40BE11DDB3AE4F4940917D9065C1EA4B40C636A968AC534940917D9065C1EA4B40C636A968AC534940187C9A9317E94B40BE11DDB3AE4F4940187C9A9317E94B40
21946	Богатые Сабы	7	64	1640	50.427342000000003	50.46358	56.020626999999998	55.990729999999999	0103000020E61000000100000005000000871A8524B336494042959A3DD0FE4B40871A8524B33649401135D1E7A3024C40338AE596563B49401135D1E7A3024C40338AE596563B494042959A3DD0FE4B40871A8524B336494042959A3DD0FE4B40
17139	Янчиково	7	64	1476	50.188065999999999	50.208539000000002	55.567860000000003	55.554938999999997	0103000020E61000000100000005000000A9BEF38B121849403123BC3D08C74B40A9BEF38B12184940715AF0A2AFC84B406478EC67B11A4940715AF0A2AFC84B406478EC67B11A49403123BC3D08C74B40A9BEF38B121849403123BC3D08C74B40
20489	Ямашево	7	64	1476	50.435192999999998	50.457363000000001	55.640523000000002	55.626694999999998	0103000020E610000001000000050000005C397B67B43749408AC8B08A37D04B405C397B67B4374940FCAA5CA8FCD14B4042B3EBDE8A3A4940FCAA5CA8FCD14B4042B3EBDE8A3A49408AC8B08A37D04B405C397B67B43749408AC8B08A37D04B40
20454	Юлсубино	7	64	1476	50.450921999999998	50.483162999999998	55.608047999999997	55.595602999999997	0103000020E610000001000000050000000186E5CFB7394940223317B83CCC4B400186E5CFB7394940F8325184D4CD4B4091D10149D83D4940F8325184D4CD4B4091D10149D83D4940223317B83CCC4B400186E5CFB7394940223317B83CCC4B40
40909	Шутнево-Тулуши	7	64	1476	49.782494999999997	49.803739999999998	55.610433	55.599662000000002	0103000020E610000001000000050000004A24D1CB28E44840B55373B9C1CC4B404A24D1CB28E4484018B325AB22CE4B40573ECBF3E0E6484018B325AB22CE4B40573ECBF3E0E64840B55373B9C1CC4B404A24D1CB28E44840B55373B9C1CC4B40
20343	Шумково	7	64	1476	50.050004000000001	50.074618000000001	55.590271999999999	55.575760000000002	0103000020E61000000100000005000000A855F48766064940282CF180B2C94B40A855F487660649404CDF6B088ECB4B40B2D826158D0949404CDF6B088ECB4B40B2D826158D094940282CF180B2C94B40A855F48766064940282CF180B2C94B40
20131	Шумбут	7	64	1476	50.666006000000003	50.696826999999999	55.573872000000001	55.556044	0103000020E610000001000000050000004B7842AF3F5549408A9125732CC74B404B7842AF3F554940890B40A374C94B4022FC8BA031594940890B40A374C94B4022FC8BA0315949408A9125732CC74B404B7842AF3F5549408A9125732CC74B40
18101	Шетнево-Черемышево	7	64	1476	49.875632000000003	49.889583000000002	55.597124000000001	55.589697000000001	0103000020E6100000010000000500000061AA99B514F0484050C6F8307BCB4B4061AA99B514F048400FD4298F6ECC4B40EE0912DBDDF148400FD4298F6ECC4B40EE0912DBDDF1484050C6F8307BCB4B4061AA99B514F0484050C6F8307BCB4B40
19696	Шеморбаш	7	64	1476	50.583936000000001	50.602728999999997	55.739676000000003	55.721730999999998	0103000020E61000000100000005000000817A336ABE4A494033C170AE61DC4B40817A336ABE4A49406CD102B4ADDE4B40E6AC4F39264D49406CD102B4ADDE4B40E6AC4F39264D494033C170AE61DC4B40817A336ABE4A494033C170AE61DC4B40
19423	Урахча	7	64	1476	50.431142000000001	50.452880999999998	55.503492000000001	55.488616	0103000020E610000001000000050000004DF73AA92F374940B32616F88ABE4B404DF73AA92F37494019E6046D72C04B4069FD2D01F839494019E6046D72C04B4069FD2D01F8394940B32616F88ABE4B404DF73AA92F374940B32616F88ABE4B40
19394	Троицкий Урай	7	64	1476	50.222966	50.251612999999999	55.461793	55.451185000000002	0103000020E610000001000000050000005A0F5F268A1C49400FB9196EC0B94B405A0F5F268A1C4940C84274081CBB4B40CD1FD3DA34204940C84274081CBB4B40CD1FD3DA342049400FB9196EC0B94B405A0F5F268A1C49400FB9196EC0B94B40
61524	Тебердино-Челны	7	64	1476	50.644078	50.666321000000003	55.650962999999997	55.641314999999999	0103000020E610000001000000050000005B09DD257152494095B7239C16D24B405B09DD2571524940F9F36DC152D34B40ABD1AB014A554940F9F36DC152D34B40ABD1AB014A55494095B7239C16D24B405B09DD257152494095B7239C16D24B40
19850	Тавларово	7	64	1476	50.579740999999999	50.600411000000001	55.702764000000002	55.688228000000002	0103000020E610000001000000050000003E93FDF3344A49408318E8DA17D84B403E93FDF3344A49403067B62BF4D94B404F948444DA4C49403067B62BF4D94B404F948444DA4C49408318E8DA17D84B403E93FDF3344A49408318E8DA17D84B40
17043	Старый Арыш	7	64	1476	50.158287000000001	50.185434000000001	55.611998999999997	55.599260000000001	0103000020E61000000100000005000000E43098BF4214494086E63A8DB4CC4B40E43098BF42144940A417B5FB55CE4B4082C8224DBC174940A417B5FB55CE4B4082C8224DBC17494086E63A8DB4CC4B40E43098BF4214494086E63A8DB4CC4B40
40911	Село Шестая Речка	7	64	1476	50.661451999999997	50.674782999999998	55.547611000000003	55.539924999999997	0103000020E61000000100000005000000D8EF8975AA5449407AA52C431CC54B40D8EF8975AA54494006F7031E18C64B40C972124A5F56494006F7031E18C64B40C972124A5F5649407AA52C431CC54B40D8EF8975AA5449407AA52C431CC54B40
40906	Рыбная Слобода	7	64	1476	50.121133	50.167350999999996	55.469790000000003	55.452201000000002	0103000020E61000000100000005000000B2BB4049810F4940F81BEDB8E1B94B40B2BB4049810F494072FE261422BC4B40F8F9EFC16B15494072FE261422BC4B40F8F9EFC16B154940F81BEDB8E1B94B40B2BB4049810F4940F81BEDB8E1B94B40
18939	Русский Ошняк	7	64	1476	50.012230000000002	50.043213000000002	55.48001	55.462609999999998	0103000020E61000000100000005000000DA03ADC090014940BA66F2CD36BB4B40DA03ADC09001494061E0B9F770BD4B408BE1EA008805494061E0B9F770BD4B408BE1EA0088054940BA66F2CD36BB4B40DA03ADC090014940BA66F2CD36BB4B40
20597	Полянка	7	64	1476	50.100813000000002	50.114871999999998	55.472780999999998	55.464140999999998	0103000020E610000001000000050000007E01BD70E70C4940CADDE7F868BB4B407E01BD70E70C4940C8957A1684BC4B40F19C2D20B40E4940C8957A1684BC4B40F19C2D20B40E4940CADDE7F868BB4B407E01BD70E70C4940CADDE7F868BB4B40
17336	Околоток-Янгасала	7	64	1476	50.628582000000002	50.662224000000002	55.576976000000002	55.566527000000001	0103000020E61000000100000005000000596DFE5F7550494087A6ECF483C84B40596DFE5F75504940D8497D59DAC94B402B508BC1C3544940D8497D59DAC94B402B508BC1C354494087A6ECF483C84B40596DFE5F7550494087A6ECF483C84B40
18826	Новый Арыш	7	64	1476	50.287239999999997	50.312078999999997	55.662557	55.645724999999999	0103000020E61000000100000005000000300DC347C4244940D49AE61DA7D24B40300DC347C4244940315EF3AACED44B405A626534F2274940315EF3AACED44B405A626534F2274940D49AE61DA7D24B40300DC347C4244940D49AE61DA7D24B40
61393	Новая Ирга	7	64	1476	49.811627000000001	49.828372000000002	55.601213000000001	55.589345999999999	0103000020E610000001000000050000007AC6BE64E3E74840A30392B06FCB4B407AC6BE64E3E748400C772E8CF4CC4B400876FC1708EA48400C772E8CF4CC4B400876FC1708EA4840A30392B06FCB4B407AC6BE64E3E74840A30392B06FCB4B40
18725	Нижний Тимерлек	7	64	1476	50.393025999999999	50.410497999999997	55.583668000000003	55.569031000000003	0103000020E61000000100000005000000253D0CAD4E32494081B4FF01D6C84B40253D0CAD4E32494062DC0DA2B5CA4B406589CE328B34494062DC0DA2B5CA4B406589CE328B34494081B4FF01D6C84B40253D0CAD4E32494081B4FF01D6C84B40
19533	Мельничный Починок	7	64	1476	50.466983999999997	50.492811000000003	55.516103999999999	55.498801	0103000020E61000000100000005000000ACE0B721C63B4940261B0FB6D8BF4B40ACE0B721C63B4940DAAA24B20FC24B40F60D4C6E143F4940DAAA24B20FC24B40F60D4C6E143F4940261B0FB6D8BF4B40ACE0B721C63B4940261B0FB6D8BF4B40
18414	Масловка	7	64	1476	49.976441000000001	50.019784999999999	55.445079	55.423228000000002	0103000020E610000001000000050000009DBCC804FCFC48403160C9552CB64B409DBCC804FCFC484075914259F8B84B40C6F99B508802494075914259F8B84B40C6F99B50880249403160C9552CB64B409DBCC804FCFC48403160C9552CB64B40
18392	Мамли-Козяково-Челны	7	64	1476	50.668225	50.690162000000001	55.656132999999997	55.641376000000001	0103000020E610000001000000050000004FAF9465885549403B38D89B18D24B404FAF946588554940C669882AFCD34B409278793A57584940C669882AFCD34B409278793A575849403B38D89B18D24B404FAF9465885549403B38D89B18D24B40
17745	Малый Ошняк	7	64	1476	49.975157000000003	49.993563000000002	55.526485000000001	55.512321999999998	0103000020E6100000010000000500000095BBCFF1D1FC4840BA826DC493C14B4095BBCFF1D1FC4840D36A48DC63C34B4001C287122DFF4840D36A48DC63C34B4001C287122DFF4840BA826DC493C14B4095BBCFF1D1FC4840BA826DC493C14B40
17211	Малый Атмас	7	64	1476	50.143321	50.163336000000001	55.561273	55.550891	0103000020E610000001000000050000003EEAAF57581249409354A69883C64B403EEAAF57581249405C902DCBD7C74B403621AD31E81449405C902DCBD7C74B403621AD31E81449409354A69883C64B403EEAAF57581249409354A69883C64B40
18209	Кутлу-Букаш	7	64	1476	50.600869000000003	50.665349999999997	55.644907000000003	55.622436	0103000020E6100000010000000500000012178046E94C494031ED9BFBABCF4B4012178046E94C494012FB04508CD24B40613255302A55494012FB04508CD24B40613255302A55494031ED9BFBABCF4B4012178046E94C494031ED9BFBABCF4B40
20587	Кукеево	7	64	1476	50.406185999999998	50.437761999999999	55.666716000000001	55.653334999999998	0103000020E61000000100000005000000E90B21E7FD334940842A357BA0D34B40E90B21E7FD33494027DC2BF356D54B403DB7D0950838494027DC2BF356D54B403DB7D09508384940842A357BA0D34B40E90B21E7FD334940842A357BA0D34B40
18116	Кугарчино	7	64	1476	50.44997	50.481482999999997	55.560336	55.537591999999997	0103000020E610000001000000050000002F17F19D98394940AD4B8DD0CFC44B402F17F19D98394940BF620D17B9C74B403C4A253CA13D4940BF620D17B9C74B403C4A253CA13D4940AD4B8DD0CFC44B402F17F19D98394940AD4B8DD0CFC44B40
18022	Корноухово	7	64	1476	49.879055000000001	49.908169000000001	55.560386999999999	55.541702999999998	0103000020E610000001000000050000005131CEDF84F0484092921E8656C54B405131CEDF84F04840410DDFC2BAC74B40DA1EBDE13EF44840410DDFC2BAC74B40DA1EBDE13EF4484092921E8656C54B405131CEDF84F0484092921E8656C54B40
17915	Козяково-Челны	7	64	1476	50.520325999999997	50.548802999999999	55.650906999999997	55.638668000000003	0103000020E6100000010000000500000016A1D80A9A42494039807EDFBFD14B4016A1D80A9A42494065DEAAEB50D34B402D793C2D3F46494065DEAAEB50D34B402D793C2D3F46494039807EDFBFD14B4016A1D80A9A42494039807EDFBFD14B40
40907	Зянгаркуль	7	64	1476	50.515861999999998	50.533765000000002	55.578125999999997	55.568420000000003	0103000020E61000000100000005000000E49F19C40742494038328FFCC1C84B40E49F19C407424940D07B630800CA4B40EE5F596952444940D07B630800CA4B40EE5F59695244494038328FFCC1C84B40E49F19C40742494038328FFCC1C84B40
17513	Дон-Урай	7	64	1476	50.237492000000003	50.261854	55.489702999999999	55.477077000000001	0103000020E61000000100000005000000E4874A23661E49403F56F0DB10BD4B40E4874A23661E494065E08096AEBE4B40D4298F6E8421494065E08096AEBE4B40D4298F6E842149403F56F0DB10BD4B40E4874A23661E49403F56F0DB10BD4B40
18615	Верхний Тимерлек	7	64	1476	50.372751000000001	50.400706999999997	55.603816999999999	55.584384999999997	0103000020E610000001000000050000009146054EB62F4940F0A2AF20CDCA4B409146054EB62F494069E21DE049CD4B409E23F25D4A33494069E21DE049CD4B409E23F25D4A334940F0A2AF20CDCA4B409146054EB62F4940F0A2AF20CDCA4B40
17818	Большой Салтан	7	64	1476	49.922488999999999	49.940939999999998	55.622787000000002	55.610391999999997	0103000020E61000000100000005000000BAF59A1E14F64840B9DE365321CE4B40BAF59A1E14F64840DEAF027CB7CF4B40C6BFCFB870F84840DEAF027CB7CF4B40C6BFCFB870F84840B9DE365321CE4B40BAF59A1E14F64840B9DE365321CE4B40
17725	Большой Ошняк	7	64	1476	49.919542	49.951450000000001	55.530994	55.511949999999999	0103000020E6100000010000000500000033A6608DB3F54840F697DD9387C14B4033A6608DB3F54840A52F849CF7C34B40BDE3141DC9F94840A52F849CF7C34B40BDE3141DC9F94840F697DD9387C14B4033A6608DB3F54840F697DD9387C14B40
17536	Большой Машляк	7	64	1476	50.682381999999997	50.704040999999997	55.692582000000002	55.681559	0103000020E6100000010000000500000085B01A4B58574940B1A547533DD74B4085B01A4B585749402EE6E786A6D84B408505F7031E5A49402EE6E786A6D84B408505F7031E5A4940B1A547533DD74B4085B01A4B58574940B1A547533DD74B40
17432	Большая Кульга	7	64	1476	50.346403000000002	50.372858999999998	55.520538000000002	55.509278000000002	0103000020E610000001000000050000003F1EFAEE562C49404149810530C14B403F1EFAEE562C4940A2293BFDA0C24B407782FDD7B92F4940A2293BFDA0C24B407782FDD7B92F49404149810530C14B403F1EFAEE562C49404149810530C14B40
17402	Большая Елга	7	64	1476	49.859166000000002	49.897381000000003	55.434313000000003	55.418390000000002	0103000020E61000000100000005000000E6EAC726F9ED48409A7CB3CD8DB54B40E6EAC726F9ED4840249D819197B74B40A1866F61DDF24840249D819197B74B40A1866F61DDF248409A7CB3CD8DB54B40E6EAC726F9ED48409A7CB3CD8DB54B40
17625	Бикчураево	7	64	1476	50.677225999999997	50.701382000000002	55.672296000000003	55.656300999999999	0103000020E610000001000000050000001D007157AF56494082AAD1AB01D44B401D007157AF564940A69D9ACB0DD64B406500A8E2C6594940A69D9ACB0DD64B406500A8E2C659494082AAD1AB01D44B401D007157AF56494082AAD1AB01D44B40
17310	Биектау	7	64	1476	50.662430999999998	50.68797	55.616092000000002	55.599524000000002	0103000020E61000000100000005000000A46DFC89CA5449406495D233BDCC4B40A46DFC89CA544940E3A9471ADCCE4B408750A5660F584940E3A9471ADCCE4B408750A5660F5849406495D233BDCC4B40A46DFC89CA5449406495D233BDCC4B40
17115	Бетьки	7	64	1476	50.167485999999997	50.189242999999998	55.523370999999997	55.508549000000002	0103000020E61000000100000005000000D844662E70154940EEB4352218C14B40D844662E70154940605628D2FDC24B409BFF571D39184940605628D2FDC24B409BFF571D39184940EEB4352218C14B40D844662E70154940EEB4352218C14B40
18010	Бердибяково	7	64	1476	50.585355	50.607911999999999	55.662526999999997	55.651302999999999	0103000020E6100000010000000500000069C6A2E9EC4A4940B2648EE55DD34B4069C6A2E9EC4A4940C6DB4AAFCDD44B40486C770FD04D4940C6DB4AAFCDD44B40486C770FD04D4940B2648EE55DD34B4069C6A2E9EC4A4940B2648EE55DD34B40
17018	Балыклы-Чукаево	7	64	1476	50.102682000000001	50.118537000000003	55.597648	55.583072000000001	0103000020E61000000100000005000000A6F10BAF240D49404E9B711AA2CA4B40A6F10BAF240D49408942CBBA7FCC4B40D82E6D382C0F49408942CBBA7FCC4B40D82E6D382C0F49404E9B711AA2CA4B40A6F10BAF240D49404E9B711AA2CA4B40
16948	Анатыш	7	64	1476	50.121025000000003	50.143662999999997	55.489356000000001	55.470331000000002	0103000020E61000000100000005000000CC7F48BF7D0F4940C2A563CE33BC4B40CC7F48BF7D0F4940FA0CA837A3BE4B409752978C63124940FA0CA837A3BE4B409752978C63124940C2A563CE33BC4B40CC7F48BF7D0F4940C2A563CE33BC4B40
19813	Алан-Полян	7	64	1476	50.532623999999998	50.553311999999998	55.700811000000002	55.686259	0103000020E610000001000000050000004888F2052D444940F7CABC55D7D74B404888F2052D444940AAD6C22CB4D94B40FF3D78EDD2464940AAD6C22CB4D94B40FF3D78EDD2464940F7CABC55D7D74B404888F2052D444940F7CABC55D7D74B40
16920	Янцевары	7	64	1398	50.118859999999998	50.149672000000002	55.770010999999997	55.758938999999998	0103000020E61000000100000005000000BA66F2CD360F49405854C4E924E14B40BA66F2CD360F4940B6476FB88FE24B403F90BC7328134940B6476FB88FE24B403F90BC73281349405854C4E924E14B40BA66F2CD360F49405854C4E924E14B40
16724	Шали	7	64	1398	49.643183999999998	49.676188000000003	55.697462999999999	55.665649999999999	0103000020E61000000100000005000000BDA772DA53D248408C4AEA0434D54B40BDA772DA53D24840C495B37746D94B404DF910548DD64840C495B37746D94B404DF910548DD648408C4AEA0434D54B40BDA772DA53D248408C4AEA0434D54B40
16639	Чита	7	64	1398	49.894120000000001	49.917313999999998	55.735312	55.719835000000003	0103000020E610000001000000050000008A592F8672F2484012C2A38D23DC4B408A592F8672F248409D2D20B41EDE4B40DB148F8B6AF548409D2D20B41EDE4B40DB148F8B6AF5484012C2A38D23DC4B408A592F8672F2484012C2A38D23DC4B40
16617	Татарское Ходяшево	7	64	1398	49.811357999999998	49.828408000000003	55.836154999999998	55.821133000000003	0103000020E610000001000000050000008AAC3594DAE748404C55DAE21AE94B408AAC3594DAE7484085B1852007EB4B4055DFF94509EA484085B1852007EB4B4055DFF94509EA48404C55DAE21AE94B408AAC3594DAE748404C55DAE21AE94B40
16826	Старое Шигалеево	7	64	1398	49.495716999999999	49.525280000000002	55.8371	55.818012000000003	0103000020E610000001000000050000001E8997A773BF484027DE019EB4E84B401E8997A773BF4840A5BDC11726EB4B40179F02603CC34840A5BDC11726EB4B40179F02603CC3484027DE019EB4E84B401E8997A773BF484027DE019EB4E84B40
16514	Пимери	7	64	1398	49.840705999999997	49.860801000000002	55.780912000000001	55.768875999999999	0103000020E6100000010000000500000086C613419CEB4840F3565D876AE24B4086C613419CEB4840E886A6ECF4E34B409BAE27BA2EEE4840E886A6ECF4E34B409BAE27BA2EEE4840F3565D876AE24B4086C613419CEB4840F3565D876AE24B40
16225	Пестрецы	7	64	1398	49.633105	49.683546	55.765614999999997	55.742904000000003	0103000020E6100000010000000500000090F7AA9509D14840A708707A17DF4B4090F7AA9509D14840DC291DACFFE14B40E3A7716F7ED74840DC291DACFFE14B40E3A7716F7ED74840A708707A17DF4B4090F7AA9509D14840A708707A17DF4B40
16204	Пановка	7	64	1398	49.931139000000002	49.949654000000002	55.831474	55.820430000000002	0103000020E61000000100000005000000DC8310902FF748402254A9D903E94B40DC8310902FF74840B6BC72BD6DEA4B40FF4124438EF94840B6BC72BD6DEA4B40FF4124438EF948402254A9D903E94B40DC8310902FF748402254A9D903E94B40
16132	Отар-Дубровка	7	64	1398	50.017611000000002	50.040742999999999	55.695210000000003	55.677838999999999	0103000020E610000001000000050000006286C61341024940077AA86DC3D64B406286C6134102494014ED2AA4FCD84B403D450E113705494014ED2AA4FCD84B403D450E1137054940077AA86DC3D64B406286C61341024940077AA86DC3D64B40
16110	Надеждино	7	64	1398	49.743400000000001	49.755859999999998	55.860933000000003	55.851055000000002	0103000020E6100000010000000500000057EC2FBB27DF4840740CC85EEFEC4B4057EC2FBB27DF48400A86730D33EE4B40622D3E05C0E048400A86730D33EE4B40622D3E05C0E04840740CC85EEFEC4B4057EC2FBB27DF4840740CC85EEFEC4B40
16010	Ленино-Кокушкино	7	64	1398	49.673332000000002	49.700802000000003	55.835169	55.819737000000003	0103000020E61000000100000005000000D6AC33BE2FD648401C295B24EDE84B40D6AC33BE2FD6484007D15AD1E6EA4B40577C43E1B3D9484007D15AD1E6EA4B40577C43E1B3D948401C295B24EDE84B40D6AC33BE2FD648401C295B24EDE84B40
15938	Кулаево	7	64	1398	49.558303000000002	49.584721999999999	55.721229000000001	55.703626	0103000020E610000001000000050000001D21037976C74840C24EB16A10DA4B401D21037976C74840A1F65B3B51DC4B4038A0A52BD8CA4840A1F65B3B51DC4B4038A0A52BD8CA4840C24EB16A10DA4B401D21037976C74840C24EB16A10DA4B40
15916	Кряш-Серда	7	64	1398	49.920171000000003	49.947308999999997	55.710600999999997	55.695377000000001	0103000020E6100000010000000500000023DDCF29C8F54840FFB1101D02D94B4023DDCF29C8F54840A0C03BF9F4DA4B406D1ADB6B41F94840A0C03BF9F4DA4B406D1ADB6B41F94840FFB1101D02D94B4023DDCF29C8F54840FFB1101D02D94B40
15834	Кощаково	7	64	1398	49.398322	49.411400999999998	55.818193999999998	55.807056000000003	0103000020E610000001000000050000007FA31D37FCB2484032056B9C4DE74B407FA31D37FCB2484047E4BB94BAE84B405645B8C9A8B4484047E4BB94BAE84B405645B8C9A8B4484032056B9C4DE74B407FA31D37FCB2484032056B9C4DE74B40
15809	Конь	7	64	1398	49.704683000000003	49.730510000000002	55.729680999999999	55.705984999999998	0103000020E610000001000000050000000A86730D33DA4840B83B6BB75DDA4B400A86730D33DA48409CC1DF2F66DD4B4053B3075A81DD48409CC1DF2F66DD4B4053B3075A81DD4840B83B6BB75DDA4B400A86730D33DA4840B83B6BB75DDA4B40
15746	Ковали	7	64	1398	50.036745000000003	50.057029	55.815372000000004	55.797325999999998	0103000020E6100000010000000500000051A5660FB4044940102043C70EE64B4051A5660FB40449407D09151C5EE84B4038F6ECB94C0749407D09151C5EE84B4038F6ECB94C074940102043C70EE64B4051A5660FB4044940102043C70EE64B40
15722	Кобяково	7	64	1398	49.817278000000002	49.836815999999999	55.920915999999998	55.909967999999999	0103000020E61000000100000005000000C2DEC4909CE848400934D8D479F44B40C2DEC4909CE848407B2E5393E0F54B40806264C91CEB48407B2E5393E0F54B40806264C91CEB48400934D8D479F44B40C2DEC4909CE848400934D8D479F44B40
15651	Кибячи	7	64	1398	49.969487999999998	49.990850000000002	55.763978999999999	55.746015	0103000020E61000000100000005000000A6EECA2E18FC4840A8A9656B7DDF4B40A6EECA2E18FC484057EA5910CAE14B40ED9E3C2CD4FE484057EA5910CAE14B40ED9E3C2CD4FE4840A8A9656B7DDF4B40A6EECA2E18FC4840A8A9656B7DDF4B40
15565	Карповка	7	64	1398	49.523609999999998	49.536949999999997	55.662247000000001	55.652090000000001	0103000020E61000000100000005000000E5ED08A705C348403A0664AF77D34B40E5ED08A705C34840E36F7B82C4D44B4029CB10C7BAC44840E36F7B82C4D44B4029CB10C7BAC448403A0664AF77D34B40E5ED08A705C348403A0664AF77D34B40
15543	Званка	7	64	1398	49.360987999999999	49.385556000000001	55.814926999999997	55.805047000000002	0103000020E61000000100000005000000CD1FD3DA34AE4840185FB4C70BE74B40CD1FD3DA34AE48404ED026874FE84B40676325E659B148404ED026874FE84B40676325E659B14840185FB4C70BE74B40CD1FD3DA34AE4840185FB4C70BE74B40
15466	Екатериновка	7	64	1398	49.821894999999998	49.835244000000003	55.659377999999997	55.651384	0103000020E610000001000000050000007ADFF8DA33E948409F91088D60D34B407ADFF8DA33E94840D7D9907F66D44B4012178046E9EA4840D7D9907F66D44B4012178046E9EA48409F91088D60D34B407ADFF8DA33E948409F91088D60D34B40
15444	Богородское	7	64	1398	49.366368000000001	49.400109	55.750109000000002	55.731966999999997	0103000020E6100000010000000500000085268925E5AE484028603B18B1DD4B4085268925E5AE4840B7B75B9203E04B40EAEA8EC536B34840B7B75B9203E04B40EAEA8EC536B3484028603B18B1DD4B4085268925E5AE484028603B18B1DD4B40
15369	Белкино	7	64	1398	49.862769	49.880375000000001	55.899042999999999	55.885235999999999	0103000020E610000001000000050000005680EF366FEE4840F59ECA694FF14B405680EF366FEE48404F594DD713F34B40A69BC420B0F048404F594DD713F34B40A69BC420B0F04840F59ECA694FF14B405680EF366FEE4840F59ECA694FF14B40
13177	Якушкино	7	64	1254	50.6218	50.643718999999997	54.495182	54.480438999999997	0103000020E610000001000000050000008F537424974F4940895C70067F3D4B408F537424974F4940B0C8AF1F623F4B402B685A6265524940B0C8AF1F623F4B402B685A6265524940895C70067F3D4B408F537424974F4940895C70067F3D4B40
13813	Чулпаново	7	64	1254	50.388795000000002	50.426084000000003	54.496169999999999	54.480020000000003	0103000020E6100000010000000500000096ECD808C431494085B69C4B713D4B4096ECD808C4314940CFA0A17F823F4B40A8ACA6EB89364940CFA0A17F823F4B40A8ACA6EB8936494085B69C4B713D4B4096ECD808C431494085B69C4B713D4B40
15265	Чувашский Тимерлек	7	64	1254	50.252744999999997	50.271977999999997	54.638299000000004	54.623378000000002	0103000020E610000001000000050000001F9DBAF259204940E085ADD9CA4F4B401F9DBAF259204940E60819C8B3514B40A19DD32CD0224940E60819C8B3514B40A19DD32CD0224940E085ADD9CA4F4B401F9DBAF259204940E085ADD9CA4F4B40
13065	Чувашская Менча	7	64	1254	50.732176000000003	50.750376000000003	54.466313	54.449066999999999	0103000020E61000000100000005000000437573F1B75D49403E5B07077B394B40437573F1B75D49408E59F624B03B4B4006DA1D520C6049408E59F624B03B4B4006DA1D520C6049403E5B07077B394B40437573F1B75D49403E5B07077B394B40
12970	Чишма	7	64	1254	50.727307000000003	50.740898999999999	54.421228999999997	54.411526000000002	0103000020E6100000010000000500000071935165185D494013BA4BE2AC344B4071935165185D49403A90F5D4EA354B40CE5147C7D55E49403A90F5D4EA354B40CE5147C7D55E494013BA4BE2AC344B4071935165185D494013BA4BE2AC344B40
13645	Фомкино	7	64	1254	50.474044999999997	50.513454000000003	54.420543000000002	54.398980000000002	0103000020E6100000010000000500000089EAAD81AD3C494009E1D1C611334B4089EAAD81AD3C4940E7C75F5AD4354B400D0055DCB8414940E7C75F5AD4354B400D0055DCB841494009E1D1C611334B4089EAAD81AD3C494009E1D1C611334B40
14672	Тюрнясево	7	64	1254	50.573435000000003	50.61562	54.608581999999998	54.578588000000003	0103000020E61000000100000005000000DEB06D5166494940D5EDEC2B0F4A4B40DEB06D51664949409677D503E64D4B40BB61DBA2CC4E49409677D503E64D4B40BB61DBA2CC4E4940D5EDEC2B0F4A4B40DEB06D5166494940D5EDEC2B0F4A4B40
15244	Турнояс	7	64	1254	50.259698	50.284132	54.509089000000003	54.498705999999999	0103000020E61000000100000005000000166BB8C83D214940D4282499D53F4B40166BB8C83D2149406EE00ED429414B40A0DFF76F5E2449406EE00ED429414B40A0DFF76F5E244940D4282499D53F4B40166BB8C83D214940D4282499D53F4B40
61318	Степное Озеро	7	64	1254	50.551399000000004	50.576399000000002	54.491647	54.472423999999997	0103000020E610000001000000050000000806103E9446494039ECBE63783C4B400806103E944649409816F549EE3E4B403B394371C74949409816F549EE3E4B403B394371C749494039ECBE63783C4B400806103E9446494039ECBE63783C4B40
14574	Старые Челны	7	64	1254	50.946837000000002	50.975278000000003	54.559719999999999	54.537770999999999	0103000020E6100000010000000500000046D26EF4317949405DDE1CAED5444B4046D26EF4317949406475ABE7A4474B401041D5E8D57C49406475ABE7A4474B401041D5E8D57C49405DDE1CAED5444B4046D26EF4317949405DDE1CAED5444B40
15051	Старое Альметьево	7	64	1254	50.339981000000002	50.362887999999998	54.788319999999999	54.775193999999999	0103000020E610000001000000050000007521567F842B49401807978E39634B407521567F842B4940306475ABE7644B40300E2E1D732E4940306475ABE7644B40300E2E1D732E49401807978E39634B407521567F842B49401807978E39634B40
14965	Старая Татарская Амзя	7	64	1254	50.401029999999999	50.429695000000002	54.833095999999998	54.816234000000001	0103000020E61000000100000005000000815B77F3543349400FF10F5B7A684B40815B77F354334940D636C5E3A26A4B409B20EA3E00374940D636C5E3A26A4B409B20EA3E003749400FF10F5B7A684B40815B77F3543349400FF10F5B7A684B40
14304	Средняя Камышла	7	64	1254	50.795318999999999	50.814191999999998	54.506610999999999	54.490439000000002	0103000020E6100000010000000500000097715303CD6549406BD784B4C63E4B4097715303CD6549409D6516A1D8404B4019558671376849409D6516A1D8404B4019558671376849406BD784B4C63E4B4097715303CD6549406BD784B4C63E4B40
14772	Селенгуши	7	64	1254	50.498479000000003	50.523614000000002	54.700200000000002	54.678998999999997	0103000020E61000000100000005000000145FED28CE3F494023827170E9564B40145FED28CE3F494061545227A0594B4027DD96C80543494061545227A0594B4027DD96C80543494023827170E9564B40145FED28CE3F494023827170E9564B40
13350	Салдакаево	7	64	1254	50.564720999999999	50.595632000000002	54.541772000000002	54.528995000000002	0103000020E61000000100000005000000A52E19C748484940AF5FB01BB6434B40A52E19C748484940BBF1EEC858454B40BD395CAB3D4C4940BBF1EEC858454B40BD395CAB3D4C4940AF5FB01BB6434B40A52E19C748484940AF5FB01BB6434B40
14107	Русское Богдашкино	7	64	1254	50.888869	50.910195000000002	54.612935999999998	54.596007999999998	0103000020E61000000100000005000000D0B69A75C6714940C2137AFD494C4B40D0B69A75C67149404145D5AF744E4B40CAFD0E45817449404145D5AF744E4B40CAFD0E4581744940C2137AFD494C4B40D0B69A75C6714940C2137AFD494C4B40
15170	Октябрина	7	64	1254	50.370109999999997	50.38062	54.542164	54.529772999999999	0103000020E6100000010000000500000016F6B4C35F2F4940E3A6069ACF434B4016F6B4C35F2F4940C68844A165454B400D1AFA27B8304940C68844A165454B400D1AFA27B8304940E3A6069ACF434B4016F6B4C35F2F4940E3A6069ACF434B40
40898	Нурлат	7	64	1254	50.785266	50.807490999999999	54.405819999999999	54.390037	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
12908	Новое Иглайкино	7	64	1254	50.892946999999999	50.919680999999997	54.417405000000002	54.401752999999999	0103000020E61000000100000005000000D90759164C724940F2086EA46C334B40D90759164C724940EC17EC866D354B4054E0641BB8754940EC17EC866D354B4054E0641BB8754940F2086EA46C334B40D90759164C724940F2086EA46C334B40
15341	Новая Тумба	7	64	1254	50.108170000000001	50.126406000000003	54.586848000000003	54.564528000000003	0103000020E610000001000000050000004434BA83D80D494091D6187442484B404434BA83D80D49408CDCD3D51D4B4B40540262122E1049408CDCD3D51D4B4B40540262122E10494091D6187442484B404434BA83D80D494091D6187442484B40
14893	Новая Амзя	7	64	1254	50.433934999999998	50.465187999999998	54.830984999999998	54.817692000000001	0103000020E610000001000000050000007DCB9C2E8B374940B519A721AA684B407DCB9C2E8B374940B83B6BB75D6A4B40EE3EC7478B3B4940B83B6BB75D6A4B40EE3EC7478B3B4940B519A721AA684B407DCB9C2E8B374940B519A721AA684B40
14596	Нижние Челны	7	64	1254	50.957464000000002	50.985590999999999	54.510302000000003	54.487018999999997	0103000020E61000000100000005000000768C2B2E8E7A4940EBC37AA3563E4B40768C2B2E8E7A4940AD8A709351414B40B01D8CD8277E4940AD8A709351414B40B01D8CD8277E4940EBC37AA3563E4B40768C2B2E8E7A4940EBC37AA3563E4B40
14693	Мамыково	7	64	1254	50.578456000000003	50.619383999999997	54.646321999999998	54.626193000000001	0103000020E610000001000000050000006616A1D80A4A4940F8FD9B1727504B406616A1D80A4A4940B857E6ADBA524B4034D593F9474F4940B857E6ADBA524B4034D593F9474F4940F8FD9B1727504B406616A1D80A4A4940F8FD9B1727504B40
14501	Курманаево	7	64	1254	50.876787	50.903530000000003	54.565367999999999	54.543574	0103000020E610000001000000050000006B47718E3A7049405B7A34D593454B406B47718E3A7049403B1A87FA5D484B403A7AFCDEA67349403B1A87FA5D484B403A7AFCDEA67349405B7A34D593454B406B47718E3A7049405B7A34D593454B40
15074	Кульбаево-Мараса	7	64	1254	50.286620999999997	50.310209999999998	54.846108999999998	54.823822999999997	0103000020E6100000010000000500000064AC36FFAF244940A758350873694B4064AC36FFAF244940F6ECB94C4D6C4B40327216F6B4274940F6ECB94C4D6C4B40327216F6B4274940A758350873694B4064AC36FFAF244940A758350873694B40
61470	Кривое Озеро	7	64	1254	50.527332999999999	50.560381999999997	54.528660000000002	54.523634000000001	0103000020E61000000100000005000000008DD2A57F4349406E895C7006434B40008DD2A57F434940085A8121AB434B402FA2ED98BA474940085A8121AB434B402FA2ED98BA4749406E895C7006434B40008DD2A57F4349406E895C7006434B40
14796	Кичкальня	7	64	1254	50.341382000000003	50.367469	54.743774999999999	54.729382000000001	0103000020E61000000100000005000000B7B8C667B22B49404225AE635C5D4B40B7B8C667B22B49408C4AEA04345F4B409CA56439092F49408C4AEA04345F4B409CA56439092F49404225AE635C5D4B40B7B8C667B22B49404225AE635C5D4B40
14986	Кзыл-Юл	7	64	1254	50.553761999999999	50.579723000000001	54.850561999999996	54.842832999999999	0103000020E610000001000000050000003FE257ACE1464940AA7EA5F3E16B4B403FE257ACE1464940349C3237DF6C4B4098DEFE5C344A4940349C3237DF6C4B4098DEFE5C344A4940AA7EA5F3E16B4B403FE257ACE1464940AA7EA5F3E16B4B40
14220	Караульная Гора	7	64	1254	50.667740000000002	50.693665000000003	54.540810999999998	54.523910999999998	0103000020E61000000100000005000000931D1B8178554940E08101840F434B40931D1B817855494095287B4B39454B409FB0C403CA58494095287B4B39454B409FB0C403CA584940E08101840F434B40931D1B8178554940E08101840F434B40
13456	Илюткино	7	64	1254	50.567667999999998	50.582472000000003	54.424985	54.404860999999997	0103000020E610000001000000050000002C7E5358A94849408236397CD2334B402C7E5358A9484940312592E865364B40F96A47718E4A4940312592E865364B40F96A47718E4A49408236397CD2334B402C7E5358A94849408236397CD2334B40
13913	Заречный	7	64	1254	50.361925999999997	50.400734	54.510196999999998	54.493654999999997	0103000020E610000001000000050000003AC95697532E4940E1404816303F4B403AC95697532E494037C2A2224E414B40983270404B33494037C2A2224E414B40983270404B334940E1404816303F4B403AC95697532E4940E1404816303F4B40
13739	Ерыкла	7	64	1254	50.476435000000002	50.496789999999997	54.466355	54.448225000000001	0103000020E61000000100000005000000BBD573D2FB3C4940F31FD26F5F394B40BBD573D2FB3C4940BDA94885B13B4B406B7D91D0963F4940BDA94885B13B4B406B7D91D0963F4940F31FD26F5F394B40BBD573D2FB3C4940F31FD26F5F394B40
12996	Ерепкино	7	64	1254	50.673157000000003	50.68797	54.450946999999999	54.430275000000002	0103000020E61000000100000005000000680932022A564940A9A44E4013374B40680932022A5649405A9D9CA1B8394B408750A5660F5849405A9D9CA1B8394B408750A5660F584940A9A44E4013374B40680932022A564940A9A44E4013374B40
15143	Елаур	7	64	1254	50.352072	50.368789999999997	54.578974000000002	54.558503000000002	0103000020E610000001000000050000002DEBFEB1102D4940E4DBBB067D474B402DEBFEB1102D4940FE9DEDD11B4A4B40C18BBE82342F4940FE9DEDD11B4A4B40C18BBE82342F4940E4DBBB067D474B402DEBFEB1102D4940E4DBBB067D474B40
14199	Егоркино	7	64	1254	50.698425999999998	50.722205000000002	54.507880999999998	54.486840999999998	0103000020E610000001000000050000008A56EE05665949400CAD4ECE503E4B408A56EE056659494040A19E3E02414B40FC00A436715C494040A19E3E02414B40FC00A436715C49400CAD4ECE503E4B408A56EE05665949400CAD4ECE503E4B40
13556	Гайтанкино	7	64	1254	50.507876000000003	50.526713000000001	54.518262	54.502633000000003	0103000020E610000001000000050000002F36AD1402414940F871344756404B402F36AD14024149403961C26856424B4064B0E2546B4349403961C26856424B4064B0E2546B434940F871344756404B402F36AD1402414940F871344756404B40
14388	Вишневая Поляна	7	64	1254	50.744087999999998	50.770992	54.552174999999998	54.533304999999999	0103000020E610000001000000050000004BAC8C463E5F49408AE5965643444B404BAC8C463E5F49409B559FABAD464B4023BDA8DDAF6249409B559FABAD464B4023BDA8DDAF6249408AE5965643444B404BAC8C463E5F49408AE5965643444B40
13934	Бутаиха	7	64	1254	50.448658999999999	50.468808000000003	54.642935999999999	54.629826000000001	0103000020E610000001000000050000002D077AA86D394940D3156C239E504B402D077AA86D394940E5B512BA4B524B40350D8AE6013C4940E5B512BA4B524B40350D8AE6013C4940D3156C239E504B402D077AA86D394940D3156C239E504B40
14483	Бурметьево	7	64	1254	50.832895000000001	50.874657999999997	54.577513000000003	54.559480000000001	0103000020E610000001000000050000003F00A94D9C6A49400F62670A9D474B403F00A94D9C6A4940E7012CF2EB494B40A69718CBF46F4940E7012CF2EB494B40A69718CBF46F49400F62670A9D474B403F00A94D9C6A49400F62670A9D474B40
13537	Биляр-Озеро	7	64	1254	50.449224999999998	50.492137	54.508749000000002	54.495454000000002	0103000020E61000000100000005000000D6C56D3480394940115663096B3F4B40D6C56D3480394940B56FEEAF1E414B4066136058FE3E4940B56FEEAF1E414B4066136058FE3E4940115663096B3F4B40D6C56D3480394940115663096B3F4B40
13627	Бикулово	7	64	1254	50.542074999999997	50.566994000000001	54.369853999999997	54.357998000000002	0103000020E61000000100000005000000567DAEB6624549404704E3E0D22D4B40567DAEB662454940BB253960572F4B409D83674293484940BB253960572F4B409D836742934849404704E3E0D22D4B40567DAEB6624549404704E3E0D22D4B40
40901	Ахметьево	7	64	1254	50.624620999999998	50.639702999999997	54.396521999999997	54.384841999999999	0103000020E6100000010000000500000089B2B794F34F49404910AE8042314B4089B2B794F34F49407F129F3BC1324B409813B4C9E15149407F129F3BC1324B409813B4C9E15149404910AE8042314B4089B2B794F34F49404910AE8042314B40
14010	Андреевка	7	64	1254	50.981467000000002	51.016249999999999	54.644379000000001	54.629091000000003	0103000020E61000000100000005000000378DEDB5A07D49409E9ACB0D86504B40378DEDB5A07D4940569DD5027B524B40AE47E17A14824940569DD5027B524B40AE47E17A148249409E9ACB0D86504B40378DEDB5A07D49409E9ACB0D86504B40
13084	Аксумла	7	64	1254	50.607508000000003	50.631610000000002	54.467516000000003	54.445056999999998	0103000020E61000000100000005000000790778D2C24D49408DEDB5A0F7384B40790778D2C24D4940AA2D7590D73B4B40CDE9B298D8504940AA2D7590D73B4B40CDE9B298D85049408DEDB5A0F7384B40790778D2C24D49408DEDB5A0F7384B40
13279	Абрыскино	7	64	1254	50.585687999999998	50.598973999999998	54.515872999999999	54.49718	0103000020E610000001000000050000006FD40AD3F74A4940D61C2098A33F4B406FD40AD3F74A4940D8F15F2008424B40C093162EAB4C4940D8F15F2008424B40C093162EAB4C4940D61C2098A33F4B406FD40AD3F74A4940D61C2098A33F4B40
40899	Нурлат	7	64	6927	50.785266	50.807490999999999	54.405819999999999	54.390037	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
61313	совхоз Красный Октябрь	7	64	1157	51.261840999999997	51.289661000000002	55.026159	55.003461000000001	0103000020E610000001000000050000003FE0810184A14940DEE7F86871804B403FE0810184A149407FBF982D59834B409DF6949C13A549407FBF982D59834B409DF6949C13A54940DEE7F86871804B403FE0810184A14940DEE7F86871804B40
12129	Шахмайкино	7	64	1157	51.055300000000003	51.086669000000001	55.158831999999997	55.143053999999999	0103000020E6100000010000000500000002BC051214874940EFC7ED974F924B4002BC05121487494075C7629B54944B40DC4944F8178B494075C7629B54944B40DC4944F8178B4940EFC7ED974F924B4002BC051214874940EFC7ED974F924B40
11952	Чувашская Чебоксарка	7	64	1157	50.883695000000003	50.899253999999999	55.085166999999998	55.071478999999997	0103000020E61000000100000005000000C251F2EA1C714940E6AC4F3926894B40C251F2EA1C71494066D993C0E68A4B400A664CC11A73494066D993C0E68A4B400A664CC11A734940E6AC4F3926894B40C251F2EA1C714940E6AC4F3926894B40
12249	Чертушкино	7	64	1157	51.005299999999998	51.032787999999996	55.167862999999997	55.15072	0103000020E610000001000000050000009B559FABAD804940336DFFCA4A934B409B559FABAD804940AE9AE7887C954B40C2D9AD6532844940AE9AE7887C954B40C2D9AD6532844940336DFFCA4A934B409B559FABAD804940336DFFCA4A934B40
11865	Татарское Утяшкино	7	64	1157	51.312846999999998	51.353046999999997	55.217875999999997	55.204042999999999	0103000020E610000001000000050000006BD3D85E0BA8494026FDBD141E9A4B406BD3D85E0BA84940A94A5B5CE39B4B40B779E3A430AD4940A94A5B5CE39B4B40B779E3A430AD494026FDBD141E9A4B406BD3D85E0BA8494026FDBD141E9A4B40
61307	Слобода Черемуховая	7	64	1157	51.116008000000001	51.164625000000001	54.966458000000003	54.944952000000001	0103000020E610000001000000050000008509A359D98E49401825E82FF4784B408509A359D98E4940927A4FE5B47B4B40508D976E12954940927A4FE5B47B4B40508D976E129549401825E82FF4784B408509A359D98E49401825E82FF4784B40
61316	Слобода Петропавловская	7	64	1157	51.349184000000001	51.393676999999997	55.072386000000002	55.047950999999998	0103000020E61000000100000005000000AB24B20FB2AC4940BE67244223864B40AB24B20FB2AC49401958C7F143894B40FC17080264B249401958C7F143894B40FC17080264B24940BE67244223864B40AB24B20FB2AC4940BE67244223864B40
61388	Слобода Екатерининская	7	64	1157	51.047431000000003	51.084325	55.021968000000001	55.006967000000003	0103000020E6100000010000000500000086E81038128649405C936E4BE4804B4086E81038128649407EC7F0D8CF824B401B9E5E29CB8A49407EC7F0D8CF824B401B9E5E29CB8A49405C936E4BE4804B4086E81038128649405C936E4BE4804B40
61461	Слобода Волчья	7	64	1157	51.265120000000003	51.288575000000002	54.950820999999998	54.921343999999998	0103000020E61000000100000005000000FDC1C073EFA14940D32EA699EE754B40FDC1C073EFA14940CDACA580B4794B40BBB88D06F0A44940CDACA580B4794B40BBB88D06F0A44940D32EA699EE754B40FDC1C073EFA14940D32EA699EE754B40
61499	Слобода Архангельская	7	64	1157	51.243730999999997	51.274811999999997	55.168691000000003	55.149510999999997	0103000020E61000000100000005000000BC02D193329F494035B22B2D23934B40BC02D193329F49409510ACAA97954B403046240A2DA349409510ACAA97954B403046240A2DA3494035B22B2D23934B40BC02D193329F494035B22B2D23934B40
11937	Русская Чебоксарка	7	64	1157	50.916896999999999	50.945661000000001	55.065607	55.049807999999999	0103000020E61000000100000005000000776682E15C754940228AC91B60864B40776682E15C754940C0B167CF65884B40240D6E6B0B794940C0B167CF65884B40240D6E6B0B794940228AC91B60864B40776682E15C754940228AC91B60864B40
12185	Простые Челны	7	64	1157	51.024146000000002	51.050781000000001	55.141705999999999	55.123837000000002	0103000020E61000000100000005000000242A54371783494073840CE4D98F4B40242A543717834940D0D2156C23924B400C21E7FD7F864940D0D2156C23924B400C21E7FD7F86494073840CE4D98F4B40242A54371783494073840CE4D98F4B40
11494	Новошешминск	7	64	1157	51.201680000000003	51.280938999999996	55.07855	55.052782999999998	0103000020E61000000100000005000000EF2076A6D09949407364E597C1864B40EF2076A6D0994940E78C28ED0D8A4B40E19524CFF5A34940E78C28ED0D8A4B40E19524CFF5A349407364E597C1864B40EF2076A6D09949407364E597C1864B40
11298	Новопоселенная Лебедка	7	64	1157	51.377983999999998	51.402023	54.981153999999997	54.960782999999999	0103000020E61000000100000005000000A4349BC761B04940C1C6F5EFFA7A4B40A4349BC761B04940772B4B74967D4B40B29E5A7D75B34940772B4B74967D4B40B29E5A7D75B34940C1C6F5EFFA7A4B40A4349BC761B04940C1C6F5EFFA7A4B40
11180	Новое Иванаево	7	64	1157	51.082205000000002	51.107187000000003	55.006967000000003	54.998302000000002	0103000020E61000000100000005000000AA4885B1858A494005C4245CC87F4B40AA4885B1858A49405C936E4BE4804B4037C7B94DB88D49405C936E4BE4804B4037C7B94DB88D494005C4245CC87F4B40AA4885B1858A494005C4245CC87F4B40
11396	Ленино	7	64	1157	51.234999000000002	51.265146000000001	55.207680000000003	55.186813000000001	0103000020E61000000100000005000000DECB7D72149E4940DCBB067DE9974B40DECB7D72149E494043041C42959A4B402655DB4DF0A1494043041C42959A4B402655DB4DF0A14940DCBB067DE9974B40DECB7D72149E4940DCBB067DE9974B40
11196	Ерыклы	7	64	1157	51.409362000000002	51.447989999999997	55.185265999999999	55.168064000000001	0103000020E61000000100000005000000D21C59F965B4494046D1031F83954B40D21C59F965B44940C687D9CBB6974B40AF777FBC57B94940C687D9CBB6974B40AF777FBC57B9494046D1031F83954B40D21C59F965B4494046D1031F83954B40
11379	Деревня Екатериновка	7	64	1157	51.475082999999998	51.490085000000001	54.993054999999998	54.971857999999997	0103000020E610000001000000050000005AF10D85CFBC4940902DCBD7657C4B405AF10D85CFBC49408C101E6D1C7F4B404DA1F31ABBBE49408C101E6D1C7F4B404DA1F31ABBBE4940902DCBD7657C4B405AF10D85CFBC4940902DCBD7657C4B40
11469	Горшково	7	64	1157	51.190486999999997	51.219701000000001	55.235256	55.220685000000003	0103000020E6100000010000000500000015A8C5E061984940E0DBF4673F9C4B4015A8C5E06198494009185DDE1C9E4B4002F390291F9C494009185DDE1C9E4B4002F390291F9C4940E0DBF4673F9C4B4015A8C5E061984940E0DBF4673F9C4B40
11782	Андреевка	7	64	1157	51.419693000000002	51.430194	55.035462000000003	55.030766999999997	0103000020E6100000010000000500000019AE0E80B8B54940E4654D2CF0834B4019AE0E80B8B549401920D1048A844B40BC77D49810B749401920D1048A844B40BC77D49810B74940E4654D2CF0834B4019AE0E80B8B54940E4654D2CF0834B40
61455	Акбуре	7	64	1157	50.82199	51.580877000000001	55.270097	54.854298999999997	0103000020E61000000100000005000000CCD1E3F736694940B4006DAB596D4B40CCD1E3F736694940B5DFDA8992A24B40D2FF722D5ACA4940B5DFDA8992A24B40D2FF722D5ACA4940B4006DAB596D4B40CCD1E3F736694940B4006DAB596D4B40
10936	Азеево	7	64	1157	51.078547999999998	51.116799	55.214039	55.197184	0103000020E61000000100000005000000469561DC0D8A4940B1A547533D994B40469561DC0D8A4940C68844A1659B4B404E9A0645F38E4940C68844A1659B4B404E9A0645F38E4940B1A547533D994B40469561DC0D8A4940B1A547533D994B40
9402	Шингальчи	7	64	856	51.803201000000001	51.832999000000001	55.522368	55.508544000000001	0103000020E61000000100000005000000A88E554ACFE64940DC4944F817C14B40A88E554ACFE649400C3D62F4DCC24B40E44C13B69FEA49400C3D62F4DCC24B40E44C13B69FEA4940DC4944F817C14B40A88E554ACFE64940DC4944F817C14B40
10182	Шереметьевка	7	64	856	51.535162	51.572361000000001	55.393675999999999	55.369959999999999	0103000020E61000000100000005000000EE073C3080C44940016A6AD95AAF4B40EE073C3080C449402C9CA4F963B24B40C040102043C949402C9CA4F963B24B40C040102043C94940016A6AD95AAF4B40EE073C3080C44940016A6AD95AAF4B40
9672	Туба	7	64	856	51.738990000000001	51.751935000000003	55.477082000000003	55.463973000000003	0103000020E6100000010000000500000018096D3997DE49400F9D9E7763BB4B4018096D3997DE494051C1E10511BD4B40E0DBF4673FE0494051C1E10511BD4B40E0DBF4673FE049400F9D9E7763BB4B4018096D3997DE49400F9D9E7763BB4B40
10095	Трудовой	7	64	856	51.660603000000002	51.681767000000001	55.409681999999997	55.397449000000002	0103000020E61000000100000005000000DB519CA38ED44940F969DC9BDFB24B40DB519CA38ED4494043E1B37570B44B40FB3E1C2444D7494043E1B37570B44B40FB3E1C2444D74940F969DC9BDFB24B40DB519CA38ED44940F969DC9BDFB24B40
9464	Ташлык	7	64	856	51.795825999999998	51.816702999999997	55.507320999999997	55.493298000000003	0103000020E610000001000000050000003BA759A0DDE5494053978C6324BF4B403BA759A0DDE5494079C9FFE4EFC04B40C5C551B989E8494079C9FFE4EFC04B40C5C551B989E8494053978C6324BF4B403BA759A0DDE5494053978C6324BF4B40
9786	Сухарево	7	64	856	51.627229999999997	51.656658999999998	55.455708999999999	55.439737000000001	0103000020E61000000100000005000000F888981249D04940ABEB504D49B84B40F888981249D0494016BF29AC54BA4B40E1CFF0660DD4494016BF29AC54BA4B40E1CFF0660DD44940ABEB504D49B84B40F888981249D04940ABEB504D49B84B40
10772	Старошешминск	7	64	856	51.230615	51.261158000000002	55.391033	55.368721999999998	0103000020E61000000100000005000000C87BD5CA849D494069A8514832AF4B40C87BD5CA849D494011548D5E0DB24B405D8B16A06DA1494011548D5E0DB24B405D8B16A06DA1494069A8514832AF4B40C87BD5CA849D494069A8514832AF4B40
9240	Прости	7	64	856	51.954656999999997	51.995691999999998	55.664425999999999	55.648763000000002	0103000020E61000000100000005000000E0F2583332FA49406CED7DAA0AD34B40E0F2583332FA4940594E42E90BD54B40C571E0D572FF4940594E42E90BD54B40C571E0D572FF49406CED7DAA0AD34B40E0F2583332FA49406CED7DAA0AD34B40
10390	Нижняя Уратьма	7	64	856	51.610495	51.653694999999999	55.354615000000003	55.339114000000002	0103000020E610000001000000050000008EAF3DB324CE4940D1CE691668AB4B408EAF3DB324CE4940E5D5390664AD4B4084471B47ACD34940E5D5390664AD4B4084471B47ACD34940D1CE691668AB4B408EAF3DB324CE4940D1CE691668AB4B40
10017	Нижние Челны	7	64	856	51.831012999999999	51.850264000000003	55.405005000000003	55.392623	0103000020E6100000010000000500000082C64CA25EEA49402654707841B24B4082C64CA25EEA4940B6DB2E34D7B34B40AB7B6473D5EC4940B6DB2E34D7B34B40AB7B6473D5EC49402654707841B24B4082C64CA25EEA49402654707841B24B40
6398	Нижнекамск	7	64	856	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
10278	Нариман	7	64	856	51.467618000000002	51.487506000000003	55.394765	55.381286000000003	0103000020E61000000100000005000000AE8218E8DABB49401A36CAFACDB04B40AE8218E8DABB49407F4DD6A887B24B40494DBB9866BE49407F4DD6A887B24B40494DBB9866BE49401A36CAFACDB04B40AE8218E8DABB49401A36CAFACDB04B40
10631	Кулмакса	7	64	856	51.255021999999997	51.274534000000003	55.275241999999999	55.260167000000003	0103000020E6100000010000000500000058E1968FA4A04940CD3FFA264DA14B4058E1968FA4A04940293E3E213BA34B40EED11BEE23A34940293E3E213BA34B40EED11BEE23A34940CD3FFA264DA14B4058E1968FA4A04940CD3FFA264DA14B40
9386	Красный Ключ	7	64	856	51.795988000000001	51.833815999999999	55.688751000000003	55.675773	0103000020E6100000010000000500000015014EEFE2E549408942CBBA7FD64B4015014EEFE2E549402D0B26FE28D84B40D670917BBAEA49402D0B26FE28D84B40D670917BBAEA49408942CBBA7FD64B4015014EEFE2E549408942CBBA7FD64B40
9983	Красная Кадка	7	64	856	51.781947000000002	51.806201999999999	55.421486000000002	55.409421000000002	0103000020E61000000100000005000000481ADCD616E44940D7A546E867B44B40481ADCD616E4494066DCD440F3B54B4022FC8BA031E7494066DCD440F3B54B4022FC8BA031E74940D7A546E867B44B40481ADCD616E44940D7A546E867B44B40
10643	Кармалы	7	64	856	51.162208999999997	51.190199999999997	55.310108999999997	55.298383999999999	0103000020E61000000100000005000000F50EB743C394494028D3687231A64B40F50EB743C3944940FE98D6A6B1A74B407FD93D7958984940FE98D6A6B1A74B407FD93D795898494028D3687231A64B40F50EB743C394494028D3687231A64B40
10309	Камский	7	64	856	51.485916000000003	51.506101999999998	55.355792000000001	55.342145000000002	0103000020E61000000100000005000000344DD87E32BE4940B6BE4868CBAB4B40344DD87E32BE4940D7169E978AAD4B40583849F3C7C04940D7169E978AAD4B40583849F3C7C04940B6BE4868CBAB4B40344DD87E32BE4940B6BE4868CBAB4B40
10820	Камские Поляны	7	64	856	51.283363999999999	51.43535	55.470857000000002	55.423611000000001	0103000020E610000001000000050000008F6E844545A44940E99C9FE238B64B408F6E844545A44940DD0BCC0A45BC4B4024287E8CB9B74940DD0BCC0A45BC4B4024287E8CB9B74940E99C9FE238B64B408F6E844545A44940E99C9FE238B64B40
9599	Каенлы	7	64	856	51.718274999999998	51.732773000000002	55.497072000000003	55.481602000000002	0103000020E610000001000000050000006744696FF0DB494017D86322A5BD4B406744696FF0DB4940F0E0270EA0BF4B4027327381CBDD4940F0E0270EA0BF4B4027327381CBDD494017D86322A5BD4B406744696FF0DB494017D86322A5BD4B40
10582	Елантово	7	64	856	51.191619000000003	51.216458000000003	55.304220999999998	55.279615999999997	0103000020E610000001000000050000006825ADF8869849401BB80375CAA34B406825ADF886984940D2E0B6B6F0A64B40927A4FE5B49B4940D2E0B6B6F0A64B40927A4FE5B49B49401BB80375CAA34B406825ADF8869849401BB80375CAA34B40
10722	Городище	7	64	856	51.144620000000003	51.166412999999999	55.301915000000001	55.283436000000002	0103000020E610000001000000050000007C2C7DE88292494029417FA147A44B407C2C7DE882924940FF959526A5A64B408B506C054D954940FF959526A5A64B408B506C054D95494029417FA147A44B407C2C7DE88292494029417FA147A44B40
10468	Верхняя Уратьма	7	64	856	51.739744000000002	51.766550000000002	55.263722000000001	55.248817000000003	0103000020E61000000100000005000000C4B46FEEAFDE49402CD8463CD99F4B40C4B46FEEAFDE49402C9E7AA4C1A14B40D95F764F1EE249402C9E7AA4C1A14B40D95F764F1EE249402CD8463CD99F4B40C4B46FEEAFDE49402CD8463CD99F4B40
9874	Верхние Челны	7	64	856	51.762607000000003	51.798969999999997	55.381796999999999	55.360622999999997	0103000020E61000000100000005000000B0592E1B9DE14940BB97FBE428AE4B40B0592E1B9DE14940FF5A5EB9DEB04B40183E22A644E64940FF5A5EB9DEB04B40183E22A644E64940BB97FBE428AE4B40B0592E1B9DE14940BB97FBE428AE4B40
9698	Борок	7	64	856	51.666891	51.690345999999998	55.553009000000003	55.540821999999999	0103000020E61000000100000005000000957F2DAF5CD54940897AC1A739C54B40957F2DAF5CD5494064B2B8FFC8C64B405376FA415DD8494064B2B8FFC8C64B405376FA415DD84940897AC1A739C54B40957F2DAF5CD54940897AC1A739C54B40
9154	Большое Афанасово	7	64	856	51.750937	51.822623	55.614409000000002	55.594330999999997	0103000020E610000001000000050000009D2D20B41EE04940DEFFC70913CC4B409D2D20B41EE049401DAF40F4A4CE4B40FDF7E0B54BE949401DAF40F4A4CE4B40FDF7E0B54BE94940DEFFC70913CC4B409D2D20B41EE04940DEFFC70913CC4B40
40897	Большие Аты	7	64	856	51.732512999999997	51.753722000000003	55.405755999999997	55.391938000000003	0103000020E610000001000000050000008A7269FCC2DD4940A3073E062BB24B408A7269FCC2DD4940F01307D0EFB34B404B2366F679E04940F01307D0EFB34B404B2366F679E04940A3073E062BB24B408A7269FCC2DD4940A3073E062BB24B40
9804	Болгар	7	64	856	51.591729000000001	51.625532999999997	55.422201000000001	55.407254000000002	0103000020E61000000100000005000000228C9FC6BDCB4940259529E620B44B40228C9FC6BDCB494054ABAFAE0AB64B40CDC8207711D0494054ABAFAE0AB64B40CDC8207711D04940259529E620B44B40228C9FC6BDCB4940259529E620B44B40
10540	Благодатная	7	64	856	51.524248	51.545240999999997	55.143425000000001	55.131923	0103000020E61000000100000005000000287FF78E1AC349408C4B55DAE2904B40287FF78E1AC34940E3361AC05B924B401BB80375CAC54940E3361AC05B924B401BB80375CAC549408C4B55DAE2904B40287FF78E1AC349408C4B55DAE2904B40
9571	Балчиклы	7	64	856	51.795476000000001	51.827016	55.557943000000002	55.533562000000003	0103000020E610000001000000050000005F605628D2E54940B63176C24BC44B405F605628D2E549401D041DAD6AC74B4066A208A9DBE949401D041DAD6AC74B4066A208A9DBE94940B63176C24BC44B405F605628D2E54940B63176C24BC44B40
40860	Шуганга	7	64	32	53.091501999999998	53.115011000000003	55.183256	55.164963	0103000020E6100000010000000500000061C26856B68B4A406806F1811D954B4061C26856B68B4A40DC65BFEE74974B4013D731AEB88E4A40DC65BFEE74974B4013D731AEB88E4A406806F1811D954B4061C26856B68B4A406806F1811D954B40
904	Уразметьево	7	64	32	53.596966000000002	53.628532999999997	55.404012999999999	55.387157000000002	0103000020E610000001000000050000007769C36169CC4A4070B54E5C8EB14B407769C36169CC4A405514AFB2B6B34B4077BAF3C473D04A405514AFB2B6B34B4077BAF3C473D04A4070B54E5C8EB14B407769C36169CC4A4070B54E5C8EB14B40
790	Тойгильдино	7	64	32	53.012801000000003	53.03763	55.282313000000002	55.271005000000002	0103000020E61000000100000005000000952D9276A3814A40B806B64AB0A24B40952D9276A3814A402A1E17D522A44B409BAC510FD1844A402A1E17D522A44B409BAC510FD1844A40B806B64AB0A24B40952D9276A3814A40B806B64AB0A24B40
345	Тогашево	7	64	32	53.025305000000003	53.041052999999998	55.398885999999997	55.386850000000003	0103000020E6100000010000000500000070B6B9313D834A40933A014D84B14B4070B6B9313D834A40876A4AB20EB34B408B33863941854A40876A4AB20EB34B408B33863941854A40933A014D84B14B4070B6B9313D834A40933A014D84B14B40
847	Ташлияр	7	64	32	52.924002000000002	52.953332000000003	55.267943000000002	55.249622000000002	0103000020E6100000010000000500000024B891B245764A405A2E1B9DF39F4B4024B891B245764A409818CBF44BA24B407A1D71C8067A4A409818CBF44BA24B407A1D71C8067A4A405A2E1B9DF39F4B4024B891B245764A405A2E1B9DF39F4B40
32349	Таш-Елга	7	64	32	53.264544999999998	53.288161000000002	55.412461999999998	55.400931	0103000020E6100000010000000500000000A94D9CDCA14A40EE79FEB451B34B4000A94D9CDCA14A40DF6B088ECBB44B40C87DAB75E2A44A40DF6B088ECBB44B40C87DAB75E2A44A40EE79FEB451B34B4000A94D9CDCA14A40EE79FEB451B34B40
32158	Татарское Булярово	7	64	32	53.562992000000001	53.583204000000002	55.448974999999997	55.435870999999999	0103000020E610000001000000050000006FF4311F10C84A402D23F59ECAB74B406FF4311F10C84A405DDC460378B94B40BD72BD6DA6CA4A405DDC460378B94B40BD72BD6DA6CA4A402D23F59ECAB74B406FF4311F10C84A402D23F59ECAB74B40
995	Татарская Смыловка	7	64	32	53.346317999999997	53.353513999999997	55.184541000000003	55.176994999999998	0103000020E610000001000000050000001002F22554AC4A401B47ACC5A7964B401002F22554AC4A40B5E21B0A9F974B40CD565EF23FAD4A40B5E21B0A9F974B40CD565EF23FAD4A401B47ACC5A7964B401002F22554AC4A401B47ACC5A7964B40
40861	Старый Варяш	7	64	32	53.210690999999997	53.230193	55.332856999999997	55.320253000000001	0103000020E61000000100000005000000E04735ECF79A4A4013B9E00CFEA84B40E04735ECF79A4A40519FE40E9BAA4B405262D7F6769D4A40519FE40E9BAA4B405262D7F6769D4A4013B9E00CFEA84B40E04735ECF79A4A4013B9E00CFEA84B40
723	Старые Карамалы	7	64	32	53.536060999999997	53.567051999999997	55.323956000000003	55.310313999999998	0103000020E610000001000000050000009DD497A59DC44A40D7BE805EB8A74B409DD497A59DC44A40E7ABE46377A94B40D190F12895C84A40E7ABE46377A94B40D190F12895C84A40D7BE805EB8A74B409DD497A59DC44A40D7BE805EB8A74B40
540	Семяково	7	64	32	53.410871	53.427579999999999	55.414479999999998	55.401370999999997	0103000020E61000000100000005000000FAEFC16B97B44A400A48FB1F60B34B40FAEFC16B97B44A404C6C3EAE0DB54B403B3602F1BAB64A404C6C3EAE0DB54B403B3602F1BAB64A400A48FB1F60B34B40FAEFC16B97B44A400A48FB1F60B34B40
38	Салауз-Мухан	7	64	32	53.248429000000002	53.270797000000002	55.279589999999999	55.267204999999997	0103000020E6100000010000000500000062307F85CC9F4A40F12900C633A24B4062307F85CC9F4A40F224E99AC9A34B406E6DE179A9A24A40F224E99AC9A34B406E6DE179A9A24A40F12900C633A24B4062307F85CC9F4A40F12900C633A24B40
980	Русский Шуган	7	64	32	53.184873000000003	53.210932999999997	55.205280999999999	55.188246999999997	0103000020E61000000100000005000000EB7420EBA9974A40F9484A7A18984B40EB7420EBA9974A40BEBED6A5469A4B40D65240DAFF9A4A40BEBED6A5469A4B40D65240DAFF9A4A40F9484A7A18984B40EB7420EBA9974A40F9484A7A18984B40
481	Октябрь	7	64	32	53.599696999999999	53.634830000000001	55.333419999999997	55.323915	0103000020E6100000010000000500000031410DDFC2CC4A4088D7F50B76A94B4031410DDFC2CC4A4089EAAD81ADAA4B408542041C42D14A4089EAAD81ADAA4B408542041C42D14A4088D7F50B76A94B4031410DDFC2CC4A4088D7F50B76A94B40
420	Новые Усы	7	64	32	53.338296	53.380921999999998	55.282974000000003	55.258012000000001	0103000020E610000001000000050000000E2F88484DAB4A40DFFC868906A14B400E2F88484DAB4A4025CFF57D38A44B40D829560DC2B04A4025CFF57D38A44B40D829560DC2B04A40DFFC868906A14B400E2F88484DAB4A40DFFC868906A14B40
40864	Новое Саитово	7	64	32	53.513728	53.538639000000003	55.408056000000002	55.399438000000004	0103000020E610000001000000050000000E85CFD6C1C14A40CC63CDC820B34B400E85CFD6C1C14A40E277D32D3BB44B40D2AC6C1FF2C44A40E277D32D3BB44B40D2AC6C1FF2C44A40CC63CDC820B34B400E85CFD6C1C14A40CC63CDC820B34B40
287	Нижний Табын	7	64	32	53.027174000000002	53.042921	55.372114000000003	55.364552000000003	0103000020E6100000010000000500000098A608707A834A4080D8D2A3A9AE4B4098A608707A834A401F317A6EA1AF4B40E3A7716F7E854A401F317A6EA1AF4B40E3A7716F7E854A4080D8D2A3A9AE4B4098A608707A834A4080D8D2A3A9AE4B40
31500	Муслюмово	7	64	32	53.172395999999999	53.219116999999997	55.315939	55.282569000000002	0103000020E6100000010000000500000009FB761211964A4085EE92382BA44B4009FB761211964A40F6436CB070A84B40B27F9E060C9C4A40F6436CB070A84B40B27F9E060C9C4A4085EE92382BA44B4009FB761211964A4085EE92382BA44B40
147	Михайловка	7	64	32	52.915370000000003	52.94849	55.249048000000002	55.232447999999998	0103000020E61000000100000005000000A9DE1AD82A754A40A30227DBC09D4B40A9DE1AD82A754A402E910BCEE09F4B40A14ACD1E68794A402E910BCEE09F4B40A14ACD1E68794A40A30227DBC09D4B40A9DE1AD82A754A40A30227DBC09D4B40
32498	Митряево	7	64	32	53.253954	53.283867999999998	55.309426999999999	55.292715000000001	0103000020E610000001000000050000001D588E9081A04A403A0664AF77A54B401D588E9081A04A40ECBFCE4D9BA74B40C23060C955A44A40ECBFCE4D9BA74B40C23060C955A44A403A0664AF77A54B401D588E9081A04A403A0664AF77A54B40
61338	Меллятамак	7	64	32	53.083120999999998	53.111857999999998	55.331100999999997	55.304149000000002	0103000020E610000001000000050000002F4E7CB5A38A4A40390EBC5AEEA64B402F4E7CB5A38A4A4021567F8461AA4B40E2E5E95C518E4A4021567F8461AA4B40E2E5E95C518E4A40390EBC5AEEA64B402F4E7CB5A38A4A40390EBC5AEEA64B40
32276	Мари-Буляр	7	64	32	53.471454000000001	53.491019000000001	55.420985000000002	55.409855	0103000020E61000000100000005000000C1C8CB9A58BC4A40118DEE2076B44B40C1C8CB9A58BC4A40A48D23D6E2B54B40795BE9B5D9BE4A40A48D23D6E2B54B40795BE9B5D9BE4A40118DEE2076B44B40C1C8CB9A58BC4A40118DEE2076B44B40
32403	Кряш-Шуран	7	64	32	53.143298999999999	53.154375000000002	55.439292999999999	55.427075000000002	0103000020E610000001000000050000005646239F57924A4038F8C264AAB64B405646239F57924A404D2EC6C03AB84B40F6285C8FC2934A404D2EC6C03AB84B40F6285C8FC2934A4038F8C264AAB64B405646239F57924A4038F8C264AAB64B40
671	Елгабаш	7	64	32	53.388745999999998	53.397593999999998	55.429516999999997	55.416586000000002	0103000020E61000000100000005000000B439CE6DC2B14A4059FCA6B052B54B40B439CE6DC2B14A40BB09BE69FAB64B40FC8A355CE4B24A40BB09BE69FAB64B40FC8A355CE4B24A4059FCA6B052B54B40B439CE6DC2B14A4059FCA6B052B54B40
214	Верхний Табын	7	64	32	52.985025	53.014614999999999	55.367510000000003	55.354562999999999	0103000020E61000000100000005000000075F984C157E4A4092AF045262AD4B40075F984C157E4A40FB7953910AAF4B40F98381E7DE814A40FB7953910AAF4B40F98381E7DE814A4092AF045262AD4B40075F984C157E4A4092AF045262AD4B40
32078	Варяш-Баш	7	64	32	53.242437000000002	53.266655999999998	55.369489999999999	55.352936	0103000020E61000000100000005000000912BF52C089F4A4060CAC0012DAD4B40912BF52C089F4A407A19C5724BAF4B401EA4A7C821A24A407A19C5724BAF4B401EA4A7C821A24A4060CAC0012DAD4B40912BF52C089F4A4060CAC0012DAD4B40
61495	Большой Чекман	7	64	32	53.147539000000002	53.168613999999998	55.236601	55.221845000000002	0103000020E6100000010000000500000039F1D58EE2924A40FCE3BD6A659C4B4039F1D58EE2924A40B7990AF1489E4B40E9D2BF2495954A40B7990AF1489E4B40E9D2BF2495954A40FCE3BD6A659C4B4039F1D58EE2924A40FCE3BD6A659C4B40
61405	Баюкова	7	64	32	53.571714999999998	53.609147	55.233763000000003	55.213500000000003	0103000020E61000000100000005000000FAD005F52DC94A4017D9CEF7539B4B40FAD005F52DC94A40E7012CF2EB9D4B406FBA6587F8CD4A40E7012CF2EB9D4B406FBA6587F8CD4A4017D9CEF7539B4B40FAD005F52DC94A4017D9CEF7539B4B40
31844	Баланны	7	64	32	53.020122000000001	53.058992000000003	55.199604000000001	55.184818999999997	0103000020E610000001000000050000000EF7915B93824A40F7562426A8974B400EF7915B93824A404D13B69F8C994B40E25CC30C8D874A404D13B69F8C994B40E25CC30C8D874A40F7562426A8974B400EF7915B93824A40F7562426A8974B40
31831	Амикеево	7	64	32	53.693947999999999	53.728344999999997	55.373111999999999	55.359327999999998	0103000020E61000000100000005000000F38FBE49D3D84A40BF44BC75FEAD4B40F38FBE49D3D84A4061DF4E22C2AF4B40419AB1683ADD4A4061DF4E22C2AF4B40419AB1683ADD4A40BF44BC75FEAD4B40F38FBE49D3D84A40BF44BC75FEAD4B40
29484	Ямаково	7	64	1856	52.912970999999999	52.928207	55.549138999999997	55.536746000000001	0103000020E610000001000000050000002499D53BDC744A402121CA17B4C44B402499D53BDC744A40A4FACE2F4AC64B408A75AA7CCF764A40A4FACE2F4AC64B408A75AA7CCF764A402121CA17B4C44B402499D53BDC744A402121CA17B4C44B40
61490	Юртово	7	64	1856	52.626364000000002	53.491943999999997	55.942397999999997	55.388900999999997	0103000020E6100000010000000500000025B20FB22C504A40DB300A82C7B14B4025B20FB22C504A406CE8667FA0F84B4051BB5F05F8BE4A406CE8667FA0F84B4051BB5F05F8BE4A40DB300A82C7B14B4025B20FB22C504A40DB300A82C7B14B40
30252	Холодный Ключ	7	64	1856	53.063583000000001	53.081665999999998	55.682051999999999	55.672915000000003	0103000020E6100000010000000500000071CADC7C23884A4072FE261422D64B4071CADC7C23884A40F015DD7A4DD74B40FA980F08748A4A40F015DD7A4DD74B40FA980F08748A4A4072FE261422D64B4071CADC7C23884A4072FE261422D64B40
29663	Усаево	7	64	1856	52.869501999999997	52.880325999999997	55.635299000000003	55.625231999999997	0103000020E610000001000000050000003EE76ED74B6F4A40D234289A07D04B403EE76ED74B6F4A403C17467A51D14B40C4E8B985AE704A403C17467A51D14B40C4E8B985AE704A40D234289A07D04B403EE76ED74B6F4A40D234289A07D04B40
30500	Урусово	7	64	1856	52.855308000000001	52.868397000000002	55.778101999999997	55.772021000000002	0103000020E61000000100000005000000EB0088BB7A6D4A40A1698995D1E24B40EB0088BB7A6D4A40E179A9D898E34B40E67805A2276F4A40E179A9D898E34B40E67805A2276F4A40A1698995D1E24B40EB0088BB7A6D4A40A1698995D1E24B40
30396	Тулубаево	7	64	1856	52.826796000000002	52.846235	55.764718000000002	55.753418000000003	0103000020E61000000100000005000000583B8A73D4694A40DF1B430070E04B40583B8A73D4694A40CE548847E2E14B4083DDB06D516C4A40CE548847E2E14B4083DDB06D516C4A40DF1B430070E04B40583B8A73D4694A40DF1B430070E04B40
29580	Топасево	7	64	1856	52.937235000000001	52.948175999999997	55.638694000000001	55.614652999999997	0103000020E6100000010000000500000052D50451F7774A40B3B112F3ACCE4B4052D50451F7774A40621399B9C0D14B40116DC7D45D794A40621399B9C0D14B40116DC7D45D794A40B3B112F3ACCE4B4052D50451F7774A40B3B112F3ACCE4B40
40836	Татарская Мишуга	7	64	1856	53.406353000000003	53.423096999999999	55.456847000000003	55.446437000000003	0103000020E61000000100000005000000D5D0066003B44A40B85CFDD824B94B40D5D0066003B44A404B2366F679BA4B409204E10A28B64A404B2366F679BA4B409204E10A28B64A40B85CFDD824B94B40D5D0066003B44A40B85CFDD824B94B40
29464	Старый Иркеняш	7	64	1856	53.264284000000004	53.286436999999999	55.502960999999999	55.491942000000002	0103000020E61000000100000005000000946DE00ED4A14A40B1C398F4F7BE4B40946DE00ED4A14A40EC14AB0661C04B40A3AEB5F7A9A44A40EC14AB0661C04B40A3AEB5F7A9A44A40B1C398F4F7BE4B40946DE00ED4A14A40B1C398F4F7BE4B40
30186	Старое Мазино	7	64	1856	53.049605	53.069547	55.656184000000003	55.635879000000003	0103000020E61000000100000005000000EA5BE67459864A404A9BAA7B64D14B40EA5BE67459864A4049145AD6FDD34B40784485EAE6884A4049145AD6FDD34B40784485EAE6884A404A9BAA7B64D14B40EA5BE67459864A404A9BAA7B64D14B40
30272	Старая Матвеевка	7	64	1856	53.270060000000001	53.305858000000001	55.546785999999997	55.528120999999999	0103000020E6100000010000000500000098FA795391A24A4058AA0B7899C34B4098FA795391A24A4090F46915FDC54B40289CDD5A26A74A4090F46915FDC54B40289CDD5A26A74A4058AA0B7899C34B4098FA795391A24A4058AA0B7899C34B40
30351	Старая Александровка	7	64	1856	53.356056000000002	53.378855000000001	55.585520000000002	55.573475000000002	0103000020E61000000100000005000000B5C5353E93AD4A406C09F9A067C94B40B5C5353E93AD4A40B493C151F2CA4B408A7615527EB04A40B493C151F2CA4B408A7615527EB04A406C09F9A067C94B40B5C5353E93AD4A406C09F9A067C94B40
29887	Русский Каран	7	64	1856	53.117131000000001	53.141511000000001	55.533369	55.524543999999999	0103000020E61000000100000005000000842C0B26FE8E4A4011A8FE4124C34B40842C0B26FE8E4A40A1D9756F45C44B401B834E081D924A40A1D9756F45C44B401B834E081D924A4011A8FE4124C34B40842C0B26FE8E4A4011A8FE4124C34B40
40842	Подгорный Текермен	7	64	1856	52.706277999999998	52.734493999999998	55.676828999999998	55.657595999999998	0103000020E6100000010000000500000030F14751675A4A407EFD101B2CD44B4030F14751675A4A4000FE2955A2D64B40DA8D3EE6035E4A4000FE2955A2D64B40DA8D3EE6035E4A407EFD101B2CD44B4030F14751675A4A407EFD101B2CD44B40
30097	Подгорный Байлар	7	64	1856	52.979069000000003	52.993082999999999	55.762124999999997	55.756543000000001	0103000020E6100000010000000500000083C30B22527D4A404582A966D6E04B4083C30B22527D4A40643BDF4F8DE14B40569BFF571D7F4A40643BDF4F8DE14B40569BFF571D7F4A404582A966D6E04B4083C30B22527D4A404582A966D6E04B40
30010	Новый Мелькен	7	64	1856	53.280920999999999	53.331145999999997	55.701084999999999	55.690480999999998	0103000020E610000001000000050000003BE12538F5A34A4033C170AE61D84B403BE12538F5A34A40AB5B3D27BDD94B40C119FCFD62AA4A40AB5B3D27BDD94B40C119FCFD62AA4A4033C170AE61D84B403BE12538F5A34A4033C170AE61D84B40
29961	Новое Мазино	7	64	1856	53.097107999999999	53.121918999999998	55.471311	55.453003000000002	0103000020E610000001000000050000000917F2086E8C4A40B5FE9600FCB94B400917F2086E8C4A405E9F39EB53BC4B4069E1B20A9B8F4A405E9F39EB53BC4B4069E1B20A9B8F4A40B5FE9600FCB94B400917F2086E8C4A40B5FE9600FCB94B40
29719	Новая Александровка	7	64	1856	52.826329000000001	52.840620999999999	55.670087000000002	55.661999000000002	0103000020E61000000100000005000000425E0F26C5694A400B7E1B62BCD44B40425E0F26C5694A40C53C2B69C5D54B4058AA0B78996B4A40C53C2B69C5D54B4058AA0B78996B4A400B7E1B62BCD44B40425E0F26C5694A400B7E1B62BCD44B40
29875	Николаевка	7	64	1856	53.177309000000001	53.196973	55.535488000000001	55.523071000000002	0103000020E61000000100000005000000AB24B20FB2964A40363E93FDF3C24B40AB24B20FB2964A4042B3EBDE8AC44B40F698486936994A4042B3EBDE8AC44B40F698486936994A40363E93FDF3C24B40AB24B20FB2964A40363E93FDF3C24B40
29753	Наратлы-Кичу	7	64	1856	52.837826999999997	52.850501999999999	55.571637000000003	55.561385000000001	0103000020E61000000100000005000000575A46EA3D6B4A4084BBB376DBC74B40575A46EA3D6B4A407F17B6662BC94B405F97E13FDD6C4A407F17B6662BC94B405F97E13FDD6C4A4084BBB376DBC74B40575A46EA3D6B4A4084BBB376DBC74B40
30688	Мензелинск	7	64	1856	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
29139	Куяново	7	64	1856	53.342230999999998	53.359057	55.630206999999999	55.623930000000001	0103000020E61000000100000005000000B456B439CEAB4A40247F30F0DCCF4B40B456B439CEAB4A40EA5A7B9FAAD04B402F336C94F5AD4A40EA5A7B9FAAD04B402F336C94F5AD4A40247F30F0DCCF4B40B456B439CEAB4A40247F30F0DCCF4B40
29618	Кузембетьево	7	64	1856	52.743817999999997	52.776831000000001	55.636671	55.626247999999997	0103000020E610000001000000050000008B16A06D355F4A40BB97FBE428D04B408B16A06D355F4A40E3A7716F7ED14B406EC2BD326F634A40E3A7716F7ED14B406EC2BD326F634A40BB97FBE428D04B408B16A06D355F4A40BB97FBE428D04B40
29533	Коноваловка	7	64	1856	52.934323999999997	52.960707999999997	55.698141999999997	55.687334999999997	0103000020E6100000010000000500000017EFC7ED97774A40B532E197FAD74B4017EFC7ED97774A4065FB90B75CD94B40B680D07AF87A4A4065FB90B75CD94B40B680D07AF87A4A40B532E197FAD74B4017EFC7ED97774A40B532E197FAD74B40
40852	Кзыл-Тюбяк	7	64	1856	53.296345000000002	53.315291000000002	55.486682999999999	55.474995	0103000020E61000000100000005000000A4AA09A2EEA54A40BB61DBA2CCBC4B40A4AA09A2EEA54A407442E8A04BBE4B4090DC9A745BA84A407442E8A04BBE4B4090DC9A745BA84A40BB61DBA2CCBC4B40A4AA09A2EEA54A40BB61DBA2CCBC4B40
61510	Калтаново	7	64	1856	53.329089000000003	53.346130000000002	55.444327999999999	55.433016000000002	0103000020E61000000100000005000000973C9E961FAA4A4087527B116DB74B40973C9E961FAA4A403A596ABDDFB84B400E15E3FC4DAC4A403A596ABDDFB84B400E15E3FC4DAC4A4087527B116DB74B40973C9E961FAA4A4087527B116DB74B40
29452	Кадряково	7	64	1856	52.948175999999997	52.962575999999999	55.543104	55.521026999999997	0103000020E61000000100000005000000116DC7D45D794A409FAA4203B1C24B40116DC7D45D794A40D4298F6E84C54B400EF5BBB0357B4A40D4298F6E84C54B400EF5BBB0357B4A409FAA4203B1C24B40116DC7D45D794A409FAA4203B1C24B40
61467	Имени Воровского	7	64	1856	53.153109000000001	53.178108999999999	55.720418000000002	55.691657999999997	0103000020E6100000010000000500000094DC611399934A402502D53F88D84B4094DC611399934A4091B932A836DC4B40C70F9546CC964A4091B932A836DC4B40C70F9546CC964A402502D53F88D84B4094DC611399934A402502D53F88D84B40
30041	Дусай-Кичу	7	64	1856	53.340685999999998	53.365183000000002	55.701141	55.693793999999997	0103000020E610000001000000050000003F1A4E999BAB4A409C14E63DCED84B403F1A4E999BAB4A403F7100FDBED94B4010070951BEAE4A403F7100FDBED94B4010070951BEAE4A409C14E63DCED84B403F1A4E999BAB4A409C14E63DCED84B40
29058	Дружба	7	64	1856	53.169969999999999	53.182941999999997	55.663871999999998	55.651653000000003	0103000020E610000001000000050000008BA6B393C1954A408FAB915D69D34B408BA6B393C1954A40745DF8C1F9D44B404C88B9A46A974A40745DF8C1F9D44B404C88B9A46A974A408FAB915D69D34B408BA6B393C1954A408FAB915D69D34B40
30139	Деуково	7	64	1856	52.896028999999999	52.916421	55.773150000000001	55.758761999999997	0103000020E6100000010000000500000040A20914B1724A4049B9FB1C1FE14B4040A20914B1724A4082734694F6E24B400E2F88484D754A4082734694F6E24B400E2F88484D754A4049B9FB1C1FE14B4040A20914B1724A4049B9FB1C1FE14B40
30542	Гулюково	7	64	1856	52.902101000000002	52.91554	55.802957999999997	55.794334999999997	0103000020E610000001000000050000002E58AA0B78734A40B988EFC4ACE54B402E58AA0B78734A40E107E753C7E64B4005172B6A30754A40E107E753C7E64B4005172B6A30754A40B988EFC4ACE54B402E58AA0B78734A40B988EFC4ACE54B40
40838	Верхний Текермен	7	64	1856	52.678223000000003	52.708703	55.658779000000003	55.645806999999998	0103000020E610000001000000050000009032E202D0564A409143C4CDA9D24B409032E202D0564A405325CADE52D44B40DEC9A7C7B65A4A405325CADE52D44B40DEC9A7C7B65A4A409143C4CDA9D24B409032E202D0564A409143C4CDA9D24B40
30658	Верхние Юшады	7	64	1856	53.010393000000001	53.030920000000002	55.561925000000002	55.548777000000001	0103000020E61000000100000005000000BD8DCD8E54814A4004E621533EC64B40BD8DCD8E54814A4004E78C28EDC74B406B65C22FF5834A4004E78C28EDC74B406B65C22FF5834A4004E621533EC64B40BD8DCD8E54814A4004E621533EC64B40
29077	Бикбулово	7	64	1856	53.418022000000001	53.459614000000002	55.662654000000003	55.637672000000002	0103000020E610000001000000050000001781B1BE81B54A4097C9703C9FD14B401781B1BE81B54A402448A5D8D1D44B405264ADA1D4BA4A402448A5D8D1D44B405264ADA1D4BA4A4097C9703C9FD14B401781B1BE81B54A4097C9703C9FD14B40
28884	Атрякле	7	64	1856	53.343209999999999	53.355184999999999	55.471643	55.456561000000001	0103000020E6100000010000000500000080D4264EEEAB4A4085D0419770BA4B4080D4264EEEAB4A4094313ECC5EBC4B40CF83BBB376AD4A4094313ECC5EBC4B40CF83BBB376AD4A4085D0419770BA4B4080D4264EEEAB4A4085D0419770BA4B40
28814	Тураево	7	64	1814	52.564155	52.588158	55.956688	55.947177000000003	0103000020E61000000100000005000000FC6F253B36484A40FF428F183DF94B40FC6F253B36484A40E23C9CC074FA4B40BD70E7C2484B4A40E23C9CC074FA4B40BD70E7C2484B4A40FF428F183DF94B40FC6F253B36484A40FF428F183DF94B40
28312	Тойма	7	64	1814	52.385705000000002	52.403635000000001	56.020395999999998	56.005561	0103000020E61000000100000005000000AC730CC85E314A4008910C39B6004C40AC730CC85E314A400F7C0C569C024C40AF42CA4FAA334A400F7C0C569C024C40AF42CA4FAA334A4008910C39B6004C40AC730CC85E314A4008910C39B6004C40
28762	Тойгузино	7	64	1814	52.444940000000003	52.491616	56.064298000000001	56.052923999999997	0103000020E6100000010000000500000054573ECBF3384A403596B036C6064C4054573ECBF3384A405F99B7EA3A084C405D18E945ED3E4A405F99B7EA3A084C405D18E945ED3E4A403596B036C6064C4054573ECBF3384A403596B036C6064C40
28725	Тихоново	7	64	1814	52.226137000000001	52.239880999999997	55.808669999999999	55.798444000000003	0103000020E6100000010000000500000031B5A50EF21C4A40FED7B96933E64B4031B5A50EF21C4A40CFA0A17F82E74B4044F7AC6BB41E4A40CFA0A17F82E74B4044F7AC6BB41E4A40FED7B96933E64B4031B5A50EF21C4A40FED7B96933E64B40
28677	Татарские Челны	7	64	1814	52.213318000000001	52.228608000000001	55.864711999999997	55.854466000000002	0103000020E61000000100000005000000F6D214014E1B4A40A0C552245FED4B40F6D214014E1B4A40B83A00E2AEEE4B404FCDE506431D4A40B83A00E2AEEE4B404FCDE506431D4A40A0C552245FED4B40F6D214014E1B4A40A0C552245FED4B40
28079	Старое Гришкино	7	64	1814	52.248263000000001	52.273513999999999	55.943669	55.936998000000003	0103000020E6100000010000000500000047E7FC14C71F4A406E35EB8CEFF74B4047E7FC14C71F4A40E09F5225CAF84B40C37FBA8102234A40E09F5225CAF84B40C37FBA8102234A406E35EB8CEFF74B4047E7FC14C71F4A406E35EB8CEFF74B40
28146	Сетяково	7	64	1814	52.391300999999999	52.405718999999998	55.948633999999998	55.939832000000003	0103000020E6100000010000000500000030F2B22616324A40FDDD3B6A4CF84B4030F2B22616324A40D4EFC2D66CF94B40D32EA699EE334A40D4EFC2D66CF94B40D32EA699EE334A40FDDD3B6A4CF84B4030F2B22616324A40FDDD3B6A4CF84B40
28608	Псеево	7	64	1814	52.503312000000001	52.529912000000003	55.975062999999999	55.964649999999999	0103000020E6100000010000000500000099D711876C404A400F0BB5A679FB4B4099D711876C404A40134548DDCEFC4B4005E10A28D4434A40134548DDCEFC4B4005E10A28D4434A400F0BB5A679FB4B4099D711876C404A400F0BB5A679FB4B40
28585	Мунайка	7	64	1814	52.249510999999998	52.268025999999999	55.897830999999996	55.886144999999999	0103000020E61000000100000005000000027FF8F9EF1F4A40C84109336DF14B40027FF8F9EF1F4A40E02A4F20ECF24B40253D0CAD4E224A40E02A4F20ECF24B40253D0CAD4E224A40C84109336DF14B40027FF8F9EF1F4A40C84109336DF14B40
28428	Монашево	7	64	1814	52.280216000000003	52.306977000000003	56.04853	56.037588999999997	0103000020E6100000010000000500000071E82D1EDE234A403CD862B7CF044C4071E82D1EDE234A40FC6F253B36064C40E6CFB7054B274A40FC6F253B36064C40E6CFB7054B274A403CD862B7CF044C4071E82D1EDE234A403CD862B7CF044C40
27253	Менделеевск	7	64	1814	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
28405	Камаево	7	64	1814	52.317746999999997	52.347436999999999	56.013699000000003	56.001151999999998	0103000020E6100000010000000500000078B306EFAB284A409929ADBF25004C4078B306EFAB284A40747E8AE3C0014C40CE35CCD0782C4A40747E8AE3C0014C40CE35CCD0782C4A409929ADBF25004C4078B306EFAB284A409929ADBF25004C40
28499	Ильнеть	7	64	1814	52.226630999999998	52.25385	56.024149000000001	56.009658000000002	0103000020E6100000010000000500000040A19E3E021D4A4088122D793C014C4040A19E3E021D4A40959D7E5017034C40780B24287E204A40959D7E5017034C40780B24287E204A4088122D793C014C4040A19E3E021D4A4088122D793C014C40
28336	Ижевка	7	64	1814	52.622115000000001	52.639730999999998	55.969562000000003	55.960588000000001	0103000020E61000000100000005000000EFACDD76A14F4A400C772E8CF4FA4B40EFACDD76A14F4A40E1B88C9B1AFC4B40629E95B4E2514A40E1B88C9B1AFC4B40629E95B4E2514A400C772E8CF4FA4B40EFACDD76A14F4A400C772E8CF4FA4B40
28244	Енабердино	7	64	1814	52.322319999999998	52.338939000000003	55.987048999999999	55.973027999999999	0103000020E61000000100000005000000616C21C841294A40D00B772E8CFC4B40616C21C841294A405646239F57FE4B40632B685A622B4A405646239F57FE4B40632B685A622B4A40D00B772E8CFC4B40616C21C841294A40D00B772E8CFC4B40
40834	Брюшли	7	64	1814	52.071879000000003	52.767766999999999	56.098832999999999	55.790098999999998	0103000020E610000001000000050000007522C15433094A4018CDCAF621E54B407522C15433094A40FE614B8FA60C4C4059F9653046624A40FE614B8FA60C4C4059F9653046624A4018CDCAF621E54B407522C15433094A4018CDCAF621E54B40
28039	Бизяки	7	64	1814	52.444777999999999	52.461396999999998	55.934654000000002	55.917409999999997	0103000020E610000001000000050000007AFD497CEE384A40FD82DDB06DF54B407AFD497CEE384A40AD8905BEA2F74B407BBC900E0F3B4A40AD8905BEA2F74B407BBC900E0F3B4A40FD82DDB06DF54B407AFD497CEE384A40FD82DDB06DF54B40
61529	ферма 2 Совхоза Мамадышский	7	64	1755	51.278647999999997	51.292940000000002	55.633052999999997	55.621206000000001	0103000020E61000000100000005000000438CD7BCAAA349401C0A9FAD83CF4B40438CD7BCAAA349403DD175E107D14B405AD8D30E7FA549403DD175E107D14B405AD8D30E7FA549401C0A9FAD83CF4B40438CD7BCAAA349401C0A9FAD83CF4B40
61391	совхоз Пятилетка	7	64	1755	51.408095000000003	51.421120999999999	55.665872999999998	55.654736	0103000020E61000000100000005000000A054FB743CB44940C6C1A563CED34B40A054FB743CB449400B2593533BD54B405454FD4AE7B549400B2593533BD54B405454FD4AE7B54940C6C1A563CED34B40A054FB743CB44940C6C1A563CED34B40
61226	совхоз Мамадышский	7	64	1755	51.352310000000003	51.377436000000003	55.714820000000003	55.702058999999998	0103000020E61000000100000005000000E2067C7E18AD4940656EBE11DDD94B40E2067C7E18AD49406C43C5387FDB4B40A22AA6D24FB049406C43C5387FDB4B40A22AA6D24FB04940656EBE11DDD94B40E2067C7E18AD4940656EBE11DDD94B40
27217	Шемяк	7	64	1755	51.00441	51.034171999999998	55.915861	55.907021	0103000020E610000001000000050000003FE3C2819080494082E49D4319F44B403FE3C281908049404757E9EE3AF54B402E3883BF5F8449404757E9EE3AF54B402E3883BF5F84494082E49D4319F44B403FE3C2819080494082E49D4319F44B40
27180	Шадчи	7	64	1755	51.258921000000001	51.287388999999997	55.929837999999997	55.918691000000003	0103000020E61000000100000005000000B29FC55224A149409510ACAA97F54B40B29FC55224A14940FD497CEE04F74B40751DAA29C9A44940FD497CEE04F74B40751DAA29C9A449409510ACAA97F54B40B29FC55224A149409510ACAA97F54B40
27136	Хасаншино	7	64	1755	51.108175000000003	51.122162000000003	55.818644999999997	55.806944999999999	0103000020E61000000100000005000000569FABADD88D4940DA5548F949E74B40569FABADD88D49405704FF5BC9E84B4030682101A38F49405704FF5BC9E84B4030682101A38F4940DA5548F949E74B40569FABADD88D4940DA5548F949E74B40
27067	Усали	7	64	1755	50.843440999999999	50.868181	55.702120000000001	55.684874000000001	0103000020E61000000100000005000000828DEBDFF56B4940BBF083F3A9D74B40828DEBDFF56B49400BEF7211DFD94B401901158E206F49400BEF7211DFD94B401901158E206F4940BBF083F3A9D74B40828DEBDFF56B4940BBF083F3A9D74B40
27059	Уразбахтино	7	64	1755	51.124991000000001	51.153188999999998	55.597200000000001	55.583534999999998	0103000020E61000000100000005000000ADA580B4FF8F494022895E46B1CA4B40ADA580B4FF8F4940EA95B20C71CC4B40B08D78B29B934940EA95B20C71CC4B40B08D78B29B93494022895E46B1CA4B40ADA580B4FF8F494022895E46B1CA4B40
26986	Тулбай	7	64	1755	51.056323999999996	51.073509000000001	55.916924999999999	55.904300999999997	0103000020E610000001000000050000006DFDF49F35874940BB5E9A22C0F34B406DFDF49F3587494041F163CC5DF54B40187B2FBE6889494041F163CC5DF54B40187B2FBE68894940BB5E9A22C0F34B406DFDF49F35874940BB5E9A22C0F34B40
26948	Тавели	7	64	1755	50.973067999999998	51.013699000000003	55.871405000000003	55.856476999999998	0103000020E610000001000000050000005E64027E8D7C49405A63D009A1ED4B405E64027E8D7C49401349F4328AEF4B40747E8AE3C08149401349F4328AEF4B40747E8AE3C08149405A63D009A1ED4B405E64027E8D7C49405A63D009A1ED4B40
26912	Старый Кумазан	7	64	1755	51.254744000000002	51.284109999999998	55.837130999999999	55.828136999999998	0103000020E61000000100000005000000166D8E739BA04940C4CDA96400EA4B40166D8E739BA04940E0BBCD1B27EB4B40B83B6BB75DA44940E0BBCD1B27EB4B40B83B6BB75DA44940C4CDA96400EA4B40166D8E739BA04940C4CDA96400EA4B40
26870	Средние Кирмени	7	64	1755	51.111975000000001	51.135223000000003	55.690040000000003	55.666339999999998	0103000020E610000001000000050000001C7C6132558E494021020EA14AD54B401C7C6132558E49404777103B53D84B406155BDFC4E9149404777103B53D84B406155BDFC4E91494021020EA14AD54B401C7C6132558E494021020EA14AD54B40
26791	Соколка	7	64	1755	51.497666000000002	51.515416999999999	55.560189000000001	55.534505000000003	0103000020E61000000100000005000000632AFD84B3BF49403546EBA86AC44B40632AFD84B3BF49401B4AED45B4C74B40B6662B2FF9C149401B4AED45B4C74B40B6662B2FF9C149403546EBA86AC44B40632AFD84B3BF49403546EBA86AC44B40
26719	Секинесь	7	64	1755	51.294925999999997	51.332636999999998	55.559958999999999	55.546491000000003	0103000020E61000000100000005000000BB5E9A22C0A549407847C66AF3C54B40BB5E9A22C0A54940E90C8CBCACC74B40433866D993AA4940E90C8CBCACC74B40433866D993AA49407847C66AF3C54B40BB5E9A22C0A549407847C66AF3C54B40
26668	Рагозино	7	64	1755	51.237344	51.265542000000003	55.540664	55.532043999999999	0103000020E610000001000000050000006FF3C649619E49403A048E041AC44B406FF3C649619E4940F10F5B7A34C54B4073DBBE47FDA14940F10F5B7A34C54B4073DBBE47FDA149403A048E041AC44B406FF3C649619E49403A048E041AC44B40
26586	Пойкино	7	64	1755	51.301806999999997	51.319763999999999	55.988449000000003	55.976775000000004	0103000020E61000000100000005000000185A9D9CA1A64940744694F606FD4B40185A9D9CA1A64940C861307F85FE4B401538D906EEA84940C861307F85FE4B401538D906EEA84940744694F606FD4B40185A9D9CA1A64940744694F606FD4B40
26521	Отарка	7	64	1755	51.419908	51.451017	55.632525000000001	55.615969999999997	0103000020E6100000010000000500000015AA9B8BBFB5494097A8DE1AD8CE4B4015AA9B8BBFB5494082734694F6D04B405378D0ECBAB9494082734694F6D04B405378D0ECBAB9494097A8DE1AD8CE4B4015AA9B8BBFB5494097A8DE1AD8CE4B40
26490	Омары	7	64	1755	51.172710000000002	51.196389000000003	55.552205000000001	55.535147000000002	0103000020E6100000010000000500000099D87C5C1B964940B9C667B27FC44B4099D87C5C1B96494006D847A7AEC64B40A72556462399494006D847A7AEC64B40A725564623994940B9C667B27FC44B4099D87C5C1B964940B9C667B27FC44B40
26423	Олуяз	7	64	1755	51.136867000000002	51.157933	55.917163000000002	55.903680999999999	0103000020E6100000010000000500000069739CDB849149401F82AAD1ABF34B4069739CDB84914940F60CE19865F54B40C6FA062637944940F60CE19865F54B40C6FA0626379449401F82AAD1ABF34B4069739CDB849149401F82AAD1ABF34B40
61311	Новый	7	64	1755	50.847017000000001	50.857554	55.514580000000002	55.505234999999999	0103000020E61000000100000005000000F913950D6B6C4940B4E55C8AABC04B40F913950D6B6C49407D96E7C1DDC14B40E9465854C46D49407D96E7C1DDC14B40E9465854C46D4940B4E55C8AABC04B40F913950D6B6C4940B4E55C8AABC04B40
26309	Никифорово	7	64	1755	50.869276999999997	50.912072999999999	55.852763000000003	55.838707999999997	0103000020E610000001000000050000001E15FF77446F49406072A3C85AEB4B401E15FF77446F4940931E865627ED4B404548DDCEBE744940931E865627ED4B404548DDCEBE7449406072A3C85AEB4B401E15FF77446F49406072A3C85AEB4B40
26209	Нижняя Уча	7	64	1755	51.016052999999999	51.033399000000003	55.980870000000003	55.972811	0103000020E61000000100000005000000580053060E8249403318231285FC4B40580053060E82494053D0ED258DFD4B400C5C1E6B4684494053D0ED258DFD4B400C5C1E6B468449403318231285FC4B40580053060E8249403318231285FC4B40
26126	Нижняя Сунь	7	64	1755	50.907221999999997	50.931646999999998	55.661490999999998	55.644607999999998	0103000020E61000000100000005000000191BBAD91F744940B75ED38382D24B40191BBAD91F74494096CCB1BCABD44B4050357A354077494096CCB1BCABD44B4050357A3540774940B75ED38382D24B40191BBAD91F744940B75ED38382D24B40
26079	Нижняя Ошма	7	64	1755	51.270060000000001	51.321956	55.736184000000002	55.721634999999999	0103000020E6100000010000000500000098FA795391A24940115322895EDC4B4098FA795391A2494053EBFD463BDE4B402060ADDA35A9494053EBFD463BDE4B402060ADDA35A94940115322895EDC4B4098FA795391A24940115322895EDC4B40
25411	Нижняя Кузгунча	7	64	1755	51.171146999999998	51.194116999999999	55.908645999999997	55.899441000000003	0103000020E610000001000000050000007DE71725E89549403DD7F7E120F34B407DE71725E895494013D21A834EF44B407F4C6BD3D898494013D21A834EF44B407F4C6BD3D89849403DD7F7E120F34B407DE71725E89549403DD7F7E120F34B40
26145	Нижний Таканыш	7	64	1755	51.034747000000003	51.065379	55.947187	55.925525999999998	0103000020E610000001000000050000002B51F6967284494081CCCEA277F64B402B51F696728449402219726C3DF94B402F6CCD565E8849402219726C3DF94B402F6CCD565E88494081CCCEA277F64B402B51F6967284494081CCCEA277F64B40
61402	Нижние Янки	7	64	1755	51.046999999999997	51.067050000000002	55.642377000000003	55.626593999999997	0103000020E61000000100000005000000BC7493180486494056EF703B34D04B40BC74931804864940EF59D76839D24B4031992A1895884940EF59D76839D24B4031992A189588494056EF703B34D04B40BC7493180486494056EF703B34D04B40
25669	Мамадыш	7	64	1755	51.375611999999997	51.427076999999997	55.734997999999997	55.679093000000002	0103000020E6100000010000000500000019FED30D14B04940A5F8F884ECD64B4019FED30D14B049400D501A6A14DE4B40D8EF8975AAB649400D501A6A14DE4B40D8EF8975AAB64940A5F8F884ECD64B4019FED30D14B04940A5F8F884ECD64B40
25568	Малые Кирмени	7	64	1755	51.068379	51.098401000000003	55.746091	55.731231999999999	0103000020E61000000100000005000000D95DA0A4C0884940F3E49A0299DD4B40D95DA0A4C0884940836BEEE87FDF4B4065726A67988C4940836BEEE87FDF4B4065726A67988C4940F3E49A0299DD4B40D95DA0A4C0884940F3E49A0299DD4B40
25531	Малмыжка	7	64	1755	51.344225000000002	51.364328999999998	55.818841999999997	55.807881000000002	0103000020E6100000010000000500000099BB96900FAC4940A70705A568E74B4099BB96900FAC4940AD4B8DD0CFE84B4000FE2955A2AE4940AD4B8DD0CFE84B4000FE2955A2AE4940A70705A568E74B4099BB96900FAC4940A70705A568E74B40
25633	Малая Сунь	7	64	1755	50.921424000000002	50.943226000000003	55.715094000000001	55.700380000000003	0103000020E61000000100000005000000F0DFBC38F1754940E162450DA6D94B40F0DFBC38F17549406DC83F3388DB4B40535E2BA1BB7849406DC83F3388DB4B40535E2BA1BB784940E162450DA6D94B40F0DFBC38F1754940E162450DA6D94B40
26319	Куюк-Ерыкса	7	64	1755	51.330939000000001	51.361975999999999	55.855137999999997	55.847588999999999	0103000020E6100000010000000500000048FC8A355CAA494084B9DDCB7DEC4B4048FC8A355CAA49408EC8772975ED4B40ECF7C43A55AE49408EC8772975ED4B40ECF7C43A55AE494084B9DDCB7DEC4B4048FC8A355CAA494084B9DDCB7DEC4B40
25467	Кулущи	7	64	1755	50.874136999999997	50.899856	55.626223000000003	55.609181999999997	0103000020E610000001000000050000009D9CA1B8E36F4940EBA7FFACF9CD4B409D9CA1B8E36F49406380441328D04B40008E3D7B2E7349406380441328D04B40008E3D7B2E734940EBA7FFACF9CD4B409D9CA1B8E36F4940EBA7FFACF9CD4B40
25395	Красная Горка	7	64	1755	51.358364999999999	51.377794999999999	55.707284000000001	55.691831000000001	0103000020E61000000100000005000000F98381E7DEAD4940F3AD0FEB8DD84B40F98381E7DEAD4940F67D384888DA4B40D1CB28965BB04940F67D384888DA4B40D1CB28965BB04940F3AD0FEB8DD84B40F98381E7DEAD4940F3AD0FEB8DD84B40
25352	Кемеш-Куль	7	64	1755	51.118766000000001	51.148581	55.963797999999997	55.954338999999997	0103000020E6100000010000000500000039F06AB9338F49400F26C5C727FA4B4039F06AB9338F4940A0F99CBB5DFB4B404BE7C3B304934940A0F99CBB5DFB4B404BE7C3B3049349400F26C5C727FA4B4039F06AB9338F49400F26C5C727FA4B40
25292	Катмыш	7	64	1755	50.822232	50.859081000000003	55.646197999999998	55.629623000000002	0103000020E61000000100000005000000C2DCEEE53E6949409BE7887C97D04B40C2DCEEE53E694940CC5EB69DB6D24B40B8CEBF5DF66D4940CC5EB69DB6D24B40B8CEBF5DF66D49409BE7887C97D04B40C2DCEEE53E6949409BE7887C97D04B40
24672	Ишкеево	7	64	1755	50.949604000000001	50.976688000000003	55.837175999999999	55.821396	0103000020E610000001000000050000004D13B69F8C79494059880E8123E94B404D13B69F8C794940807F4A9528EB4B40A532C51C047D4940807F4A9528EB4B40A532C51C047D494059880E8123E94B404D13B69F8C79494059880E8123E94B40
25195	Зюри	7	64	1755	51.335574000000001	51.364195000000002	55.955770999999999	55.938521000000001	0103000020E61000000100000005000000A7B1BD16F4AA4940FBCDC47421F84B40A7B1BD16F4AA49408CBB41B456FA4B40F12E17F19DAE49408CBB41B456FA4B40F12E17F19DAE4940FBCDC47421F84B40A7B1BD16F4AA4940FBCDC47421F84B40
61296	Зверосовхоза	7	64	1755	50.619185999999999	51.578882999999998	56.072001999999998	55.440697	0103000020E610000001000000050000000E12A27C414F4940003961C268B84B400E12A27C414F4940909F8D5C37094C40ED9A90D618CA4940909F8D5C37094C40ED9A90D618CA4940003961C268B84B400E12A27C414F4940003961C268B84B40
25061	Дюсьметьево	7	64	1755	51.243640999999997	51.265407000000003	55.868167	55.859923000000002	0103000020E610000001000000050000007C7BD7A02F9F4940030AF5F411EE4B407C7BD7A02F9F4940B43BA41820EF4B40939048DBF8A14940B43BA41820EF4B40939048DBF8A14940030AF5F411EE4B407C7BD7A02F9F4940030AF5F411EE4B40
32003	Дусаево	7	64	1755	51.090128	51.115065000000001	55.919044	55.914166000000002	0103000020E61000000100000005000000193A7650898B4940BD8E386403F54B40193A7650898B4940E2CAD93BA3F54B4006F52D73BA8E4940E2CAD93BA3F54B4006F52D73BA8E4940BD8E386403F54B40193A7650898B4940BD8E386403F54B40
40831	Дружба	7	64	1755	50.619185999999999	51.578882999999998	56.072001999999998	55.440697	0103000020E610000001000000050000000E12A27C414F4940003961C268B84B400E12A27C414F4940909F8D5C37094C40ED9A90D618CA4940909F8D5C37094C40ED9A90D618CA4940003961C268B84B400E12A27C414F4940003961C268B84B40
24972	Дигитли	7	64	1755	51.026679999999999	51.045040999999998	55.590057999999999	55.582115999999999	0103000020E6100000010000000500000088BA0F406A8349403A3DEFC682CA4B4088BA0F406A834940205F420587CB4B4054FD4AE7C3854940205F420587CB4B4054FD4AE7C38549403A3DEFC682CA4B4088BA0F406A8349403A3DEFC682CA4B40
24951	Гришкино	7	64	1755	51.437092999999997	51.446677999999999	55.889543000000003	55.882182	0103000020E61000000100000005000000BF27D6A9F2B74940588FFB56EBF04B40BF27D6A9F2B7494060B1868BDCF14B40DDEBA4BE2CB9494060B1868BDCF14B40DDEBA4BE2CB94940588FFB56EBF04B40BF27D6A9F2B74940588FFB56EBF04B40
24720	Владимирово	7	64	1755	50.841717000000003	50.866895999999997	55.744374000000001	55.721797000000002	0103000020E610000001000000050000005EBEF561BD6B4940EBAC16D863DC4B405EBEF561BD6B494011FFB0A547DF4B404084B872F66E494011FFB0A547DF4B404084B872F66E4940EBAC16D863DC4B405EBEF561BD6B4940EBAC16D863DC4B40
24868	Верхняя Сунь	7	64	1755	50.939283000000003	50.978799000000002	55.754643999999999	55.735191	0103000020E610000001000000050000002A58E36C3A78494022A81ABD1ADE4B402A58E36C3A784940B20FB22C98E04B40C32D1F49497D4940B20FB22C98E04B40C32D1F49497D494022A81ABD1ADE4B402A58E36C3A78494022A81ABD1ADE4B40
24803	Верхняя Ошма	7	64	1755	51.198481999999998	51.219538999999997	55.769454000000003	55.751674999999999	0103000020E610000001000000050000001E6CB1DB67994940431CEBE236E04B401E6CB1DB6799494061E3FA777DE24B4028999CDA199C494061E3FA777DE24B4028999CDA199C4940431CEBE236E04B401E6CB1DB67994940431CEBE236E04B40
24778	Верхний Берсут	7	64	1755	50.790638000000001	50.820939000000003	55.731526000000002	55.714511000000002	0103000020E61000000100000005000000C87C40A033654940EED0B01875DB4B40C87C40A0336549403C16DBA4A2DD4B4067817687146949403C16DBA4A2DD4B406781768714694940EED0B01875DB4B40C87C40A033654940EED0B01875DB4B40
61496	Верхние Яки	7	64	1755	50.619185999999999	51.578882999999998	56.072001999999998	55.440697	0103000020E610000001000000050000000E12A27C414F4940003961C268B84B400E12A27C414F4940909F8D5C37094C40ED9A90D618CA4940909F8D5C37094C40ED9A90D618CA4940003961C268B84B400E12A27C414F4940003961C268B84B40
24629	Большая Шия	7	64	1755	51.315066000000002	51.336813999999997	55.897911999999998	55.888199999999998	0103000020E61000000100000005000000700A2B1554A849405227A089B0F14B40700A2B1554A84940CD57C9C7EEF24B40DF6A9DB81CAB4940CD57C9C7EEF24B40DF6A9DB81CAB49405227A089B0F14B40700A2B1554A849405227A089B0F14B40
24529	Албай	7	64	1755	50.720669000000001	50.750582000000001	55.774056000000002	55.762196000000003	0103000020E61000000100000005000000DA1EBDE13E5C49402E9276A38FE14B40DA1EBDE13E5C4940E4A25A4414E34B40AF7B2B1213604940E4A25A4414E34B40AF7B2B12136049402E9276A38FE14B40DA1EBDE13E5C49402E9276A38FE14B40
23397	имени Мичурина	7	64	970	51.828543000000003	51.844695000000002	54.570844000000001	54.544587	0103000020E61000000100000005000000352A70B20DEA4940D369DD06B5454B40352A70B20DEA4940158F8B6A11494B40200C3CF71EEC4940158F8B6A11494B40200C3CF71EEC4940D369DD06B5454B40352A70B20DEA4940D369DD06B5454B40
24068	Юлтимирово	7	64	970	52.246223999999998	52.262895999999998	54.497587000000003	54.488264000000001	0103000020E61000000100000005000000C2BE9D44841F4A4036E84B6F7F3E4B40C2BE9D44841F4A4017F549EEB03F4B40E61F7D93A6214A4017F549EEB03F4B40E61F7D93A6214A4036E84B6F7F3E4B40C2BE9D44841F4A4036E84B6F7F3E4B40
24466	Шугурово	7	64	970	52.113453	52.142378000000001	54.525827999999997	54.502302999999998	0103000020E610000001000000050000000951BEA0850E4A4062D7F6764B404B400951BEA0850E4A4019A9F7544E434B40BFD53A7139124A4019A9F7544E434B40BFD53A7139124A4062D7F6764B404B400951BEA0850E4A4062D7F6764B404B40
24364	Федотовка	7	64	970	51.976936000000002	51.996096999999999	54.686281000000001	54.664254999999997	0103000020E610000001000000050000007D24253D0CFD49402C9ACE4E06554B407D24253D0CFD4940DF6E490ED8574B406552431B80FF4940DF6E490ED8574B406552431B80FF49402C9ACE4E06554B407D24253D0CFD49402C9ACE4E06554B40
61517	Урняк-Кумяк	7	64	970	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
24272	Урмышла	7	64	970	51.891263000000002	51.929845999999998	54.763897999999998	54.747636	0103000020E610000001000000050000004391EEE714F24940F8A75489B25F4B404391EEE714F249406ABDDF68C7614B408028983105F749406ABDDF68C7614B408028983105F74940F8A75489B25F4B404391EEE714F24940F8A75489B25F4B40
24206	Туктарово-Урдала	7	64	970	52.112141000000001	52.136656000000002	54.427007000000003	54.403807	0103000020E6100000010000000500000037C5E3A25A0E4A40AC72A1F2AF334B4037C5E3A25A0E4A40E014562AA8364B40AE669DF17D114A40E014562AA8364B40AE669DF17D114A40AC72A1F2AF334B4037C5E3A25A0E4A40AC72A1F2AF334B40
24111	Тимяшево	7	64	970	52.346601	52.389316000000001	54.576616000000001	54.560602000000003	0103000020E6100000010000000500000065E1EB6B5D2C4A403E096CCEC1474B4065E1EB6B5D2C4A40D82C978DCE494B409FE74F1BD5314A40D82C978DCE494B409FE74F1BD5314A403E096CCEC1474B4065E1EB6B5D2C4A403E096CCEC1474B40
24028	Сугушла	7	64	970	52.266750000000002	52.304406999999998	54.535749000000003	54.516317999999998	0103000020E61000000100000005000000A01A2FDD24224A40062B4EB516424B40A01A2FDD24224A40AFEE586C93444B4034D6FECEF6264A40AFEE586C93444B4034D6FECEF6264A40062B4EB516424B40A01A2FDD24224A40062B4EB516424B40
23907	Старый Кувак	7	64	970	51.932577000000002	51.968761000000001	54.634427000000002	54.607159000000003	0103000020E610000001000000050000003B00E2AE5EF749406D3CD862B74D4B403B00E2AE5EF74940865968E734514B40F451465C00FC4940865968E734514B40F451465C00FC49406D3CD862B74D4B403B00E2AE5EF749406D3CD862B74D4B40
23819	Старый Иштеряк	7	64	970	52.009166999999998	52.029998999999997	54.557501000000002	54.539045999999999	0103000020E61000000100000005000000E9995E622C014A4012859675FF444B40E9995E622C014A40603E59315C474B40D3F4D901D7034A40603E59315C474B40D3F4D901D7034A4012859675FF444B40E9995E622C014A4012859675FF444B40
23977	Старое Шугурово	7	64	970	52.093231000000003	52.116138999999997	54.533617999999997	54.512104999999998	0103000020E6100000010000000500000098FC4FFEEE0B4A401D8F19A88C414B4098FC4FFEEE0B4A40494739984D444B4023658BA4DD0E4A40494739984D444B4023658BA4DD0E4A401D8F19A88C414B4098FC4FFEEE0B4A401D8F19A88C414B40
23741	Старая Письмянка	7	64	970	52.595291000000003	52.660068000000003	54.566026000000001	54.541736	0103000020E61000000100000005000000344DD87E324C4A406E88F19A57454B40344DD87E324C4A40C5573B8A73484B406D91B41B7D544A40C5573B8A73484B406D91B41B7D544A406E88F19A57454B40344DD87E324C4A406E88F19A57454B40
22981	Спиридоновка	7	64	970	52.054926999999999	52.083044999999998	54.472189	54.450113999999999	0103000020E610000001000000050000006D5512D907074A4062BCE6559D394B406D5512D907074A40F6436CB0703C4B40548CF337A10A4A40F6436CB0703C4B40548CF337A10A4A4062BCE6559D394B406D5512D907074A4062BCE6559D394B40
23781	Сарабикулово	7	64	970	51.886125	51.909086000000002	54.674048999999997	54.648103999999996	0103000020E610000001000000050000008195438B6CF1494011346612F5524B408195438B6CF149406473D53C47564B4030A017EE5CF449406473D53C47564B4030A017EE5CF4494011346612F5524B408195438B6CF1494011346612F5524B40
40868	Подлесный	7	64	970	52.500698	52.512466000000003	54.594099	54.586190999999999	0103000020E6100000010000000500000018963FDF16404A40D21A834E084B4B4018963FDF16404A400CCB9F6F0B4C4B40EE27637C98414A400CCB9F6F0B4C4B40EE27637C98414A40D21A834E084B4B4018963FDF16404A40D21A834E084B4B40
23608	Новый Иштеряк	7	64	970	52.004244	52.036368000000003	54.506495999999999	54.490727	0103000020E61000000100000005000000249A40118B004A40D1217024D03E4B40249A40118B004A4004C765DCD4404B407B4FE5B4A7044A4004C765DCD4404B407B4FE5B4A7044A40D1217024D03E4B40249A40118B004A40D1217024D03E4B40
23637	Новочершилинский	7	64	970	52.378312000000001	52.396296	54.647244999999998	54.636277	0103000020E6100000010000000500000099D711876C304A403719558671514B4099D711876C304A40F0BF95ECD8524B408FC4CBD3B9324A40F0BF95ECD8524B408FC4CBD3B9324A403719558671514B4099D711876C304A403719558671514B40
23444	Новое Сережкино	7	64	970	51.708545999999998	51.735000999999997	54.572201	54.559776999999997	0103000020E6100000010000000500000016DBA4A2B1DA4940C806D2C5A6474B4016DBA4A2B1DA494087DEE2E13D494B407EC3448314DE494087DEE2E13D494B407EC3448314DE4940C806D2C5A6474B4016DBA4A2B1DA4940C806D2C5A6474B40
8104	Новое Елхово	7	64	970	51.876136000000002	51.883690000000001	54.792146000000002	54.780112000000003	0103000020E61000000100000005000000946C753925F04940CC9BC3B5DA634B40946C753925F0494020D4450A65654B40B0E600C11CF1494020D4450A65654B40B0E600C11CF14940CC9BC3B5DA634B40946C753925F04940CC9BC3B5DA634B40
23834	Нижняя Вязовка	7	64	970	52.381222000000001	52.388319000000003	54.470770999999999	54.467182000000001	0103000020E610000001000000050000000342EBE1CB304A40D3A3A99ECC3B4B400342EBE1CB304A40DE736039423C4B402DB5DE6FB4314A40DE736039423C4B402DB5DE6FB4314A40D3A3A99ECC3B4B400342EBE1CB304A40D3A3A99ECC3B4B40
23545	Нижние Чершилы	7	64	970	52.089368999999998	52.131832000000003	54.669967	54.657094000000001	0103000020E610000001000000050000005B238271700B4A40EC32FCA71B544B405B238271700B4A401A33897AC1554B407C48F8DEDF104A401A33897AC1554B407C48F8DEDF104A40EC32FCA71B544B405B238271700B4A40EC32FCA71B544B40
23492	Мукмин-Каратай	7	64	970	52.037275000000001	52.057648999999998	54.591794	54.576574000000001	0103000020E61000000100000005000000ADFA5C6DC5044A40A9DC442DCD494B40ADFA5C6DC5044A4009FCE1E7BF4B4B40D4D2DC0A61074A4009FCE1E7BF4B4B40D4D2DC0A61074A40A9DC442DCD494B40ADFA5C6DC5044A40A9DC442DCD494B40
23265	Мордовская Кармалка	7	64	970	51.812660999999999	51.846499999999999	54.631905000000003	54.608389000000003	0103000020E6100000010000000500000009DE904605E84940821FD5B0DF4D4B4009DE904605E84940E6965643E2504B403108AC1C5AEC4940E6965643E2504B403108AC1C5AEC4940821FD5B0DF4D4B4009DE904605E84940821FD5B0DF4D4B40
23088	Михайловка	7	64	970	52.553331	52.574925999999998	54.444611999999999	54.428091000000002	0103000020E61000000100000005000000766EDA8CD3464A40215B96AFCB364B40766EDA8CD3464A405FB4C70BE9384B405FCFD72C97494A405FB4C70BE9384B405FCFD72C97494A40215B96AFCB364B40766EDA8CD3464A40215B96AFCB364B40
40765	Лениногорск	7	64	970	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
24426	Кузьминовка	7	64	970	52.007289999999998	52.035488000000001	54.666550999999998	54.660881000000003	0103000020E610000001000000050000003ECBF3E0EE004A401EC6A4BF97544B403ECBF3E0EE004A40DC0E0D8B51554B4042B3EBDE8A044A40DC0E0D8B51554B4042B3EBDE8A044A401EC6A4BF97544B403ECBF3E0EE004A401EC6A4BF97544B40
23349	Куакбаш	7	64	970	52.178049999999999	52.211719000000002	54.664057	54.647854000000002	0103000020E61000000100000005000000C286A757CA164A40994A3FE1EC524B40C286A757CA164A4006D7DCD1FF544B408E78B29B191B4A4006D7DCD1FF544B408E78B29B191B4A40994A3FE1EC524B40C286A757CA164A40994A3FE1EC524B40
23307	Керлигач	7	64	970	51.874222000000003	51.907162999999997	54.707124999999998	54.694378	0103000020E61000000100000005000000CCB8A981E6EF4940EC87D860E1584B40CCB8A981E6EF49408D976E12835A4B401492CCEA1DF449408D976E12835A4B401492CCEA1DF44940EC87D860E1584B40CCB8A981E6EF4940EC87D860E1584B40
23125	Каркали	7	64	970	52.174224000000002	52.224995999999997	54.515397999999998	54.492457999999999	0103000020E61000000100000005000000D316D7F84C164A40A8531EDD083F4B40D316D7F84C164A403F36C98FF8414B408BDD3EABCC1C4A403F36C98FF8414B408BDD3EABCC1C4A40A8531EDD083F4B40D316D7F84C164A40A8531EDD083F4B40
23033	Ивановка	7	64	970	52.425311999999998	52.471009000000002	54.510181000000003	54.501545	0103000020E61000000100000005000000554CA59F70364A40753C66A032404B40554CA59F70364A4032056B9C4D414B40938FDD054A3C4A4032056B9C4D414B40938FDD054A3C4A40753C66A032404B40554CA59F70364A40753C66A032404B40
61271	Зеленая Роща	7	64	970	52.030996000000002	52.058062	54.491166	54.475704999999998	0103000020E6100000010000000500000046274BADF7034A4097C5C4E6E33C4B4046274BADF7034A401D740987DE3E4B40F7915B936E074A401D740987DE3E4B40F7915B936E074A4097C5C4E6E33C4B4046274BADF7034A4097C5C4E6E33C4B40
22903	Зай-Каратай	7	64	970	52.355791000000004	52.400599	54.715592000000001	54.691718999999999	0103000020E61000000100000005000000079B3A8F8A2D4A40CB82893F8A584B40079B3A8F8A2D4A40BEA3C684985B4B40B8E7F9D346334A40BEA3C684985B4B40B8E7F9D346334A40CB82893F8A584B40079B3A8F8A2D4A40CB82893F8A584B40
9395	Булгар	7	64	970	51.858044	51.865561999999997	54.755555000000001	54.750701999999997	0103000020E61000000100000005000000B743C362D4ED49405985CD0017604B40B743C362D4ED494026AAB706B6604B40865451BCCAEE494026AAB706B6604B40865451BCCAEE49405985CD0017604B40B743C362D4ED49405985CD0017604B40
23873	Бакирово	7	64	970	52.032882999999998	52.050767999999998	54.546106999999999	54.534632000000002	0103000020E6100000010000000500000014CC988235044A4092B245D26E444B4014CC988235044A40EF8E8CD5E6454B4077D7D9907F064A40EF8E8CD5E6454B4077D7D9907F064A4092B245D26E444B4014CC988235044A4092B245D26E444B40
40766	Лениногорск	7	64	6920	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
48581	совхоз Имени 25-го Октября	7	64	971	49.583320999999998	49.613055000000003	55.499738999999998	55.479076999999997	0103000020E61000000100000005000000F6083543AACA484005A2276552BD4B40F6083543AACA484093C49272F7BF4B401CD3139678CE484093C49272F7BF4B401CD3139678CE484005A2276552BD4B40F6083543AACA484005A2276552BD4B40
20355	Шуран	7	64	971	49.808906	49.835963	55.379024999999999	55.362997	0103000020E61000000100000005000000E3C4573B8AE74840E7C589AF76AE4B40E3C4573B8AE74840E6AE25E483B04B4041D5E8D500EB4840E6AE25E483B04B4041D5E8D500EB4840E7C589AF76AE4B40E3C4573B8AE74840E7C589AF76AE4B40
20155	Чирпы	7	64	971	49.705356999999999	49.724814000000002	55.453232999999997	55.436545000000002	0103000020E6100000010000000500000099805F2349DA4840BD1DE1B4E0B74B4099805F2349DA4840E63BF88903BA4B406BD784B4C6DC4840E63BF88903BA4B406BD784B4C6DC4840BD1DE1B4E0B74B4099805F2349DA4840BD1DE1B4E0B74B40
21760	Тетеево	7	64	971	49.202703999999997	49.223697999999999	55.443572000000003	55.424531000000002	0103000020E610000001000000050000005A626534F2994840B091240857B64B405A626534F2994840EEB5A0F7C6B84B401E17D522A29C4840EEB5A0F7C6B84B401E17D522A29C4840B091240857B64B405A626534F2994840B091240857B64B40
19443	Ташкирмень	7	64	971	49.367877999999997	49.393371999999999	55.326512000000001	55.314638000000002	0103000020E610000001000000050000007D7555A016AF4840180AD80E46A84B407D7555A016AF484033E02C25CBA94B40C09481035AB2484033E02C25CBA94B40C09481035AB24840180AD80E46A84B407D7555A016AF4840180AD80E46A84B40
20475	Татарский Янтык	7	64	971	49.747244999999999	49.784632999999999	55.559821999999997	55.546408999999997	0103000020E61000000100000005000000BD8C62B9A5DF4840BA9EE8BAF0C54B40BD8C62B9A5DF484068CA4E3FA8C74B40622EA9DA6EE4484068CA4E3FA8C74B40622EA9DA6EE44840BA9EE8BAF0C54B40BD8C62B9A5DF4840BA9EE8BAF0C54B40
21705	Татарский Кабан	7	64	971	49.237549999999999	49.256199000000002	55.494833	55.485142000000003	0103000020E610000001000000050000001895D409689E484041F50F2219BE4B401895D409689E4840A4FD0FB056BF4B404B22FB20CBA04840A4FD0FB056BF4B404B22FB20CBA0484041F50F2219BE4B401895D409689E484041F50F2219BE4B40
19408	Татарские Саралы	7	64	971	49.252578999999997	49.287083000000003	55.347413000000003	55.337567999999997	0103000020E610000001000000050000000454388254A048408B16A06D35AB4B400454388254A04840469A780778AC4B40691EC022BFA44840469A780778AC4B40691EC022BFA448408B16A06D35AB4B400454388254A048408B16A06D35AB4B40
19309	Тангачи	7	64	971	49.299318	49.316367999999997	55.415559000000002	55.403528000000001	0103000020E61000000100000005000000548D5E0D50A64840998235CEA6B34B40548D5E0D50A648407C478D0931B54B401EC022BF7EA848407C478D0931B54B401EC022BF7EA84840998235CEA6B34B40548D5E0D50A64840998235CEA6B34B40
40754	Столбище	7	64	971	49.200971000000003	49.230435	55.658053000000002	55.622146000000001	0103000020E61000000100000005000000E338F06AB99948402AABE97AA2CF4B40E338F06AB99948407104A9143BD44B40486DE2E47E9D48407104A9143BD44B40486DE2E47E9D48402AABE97AA2CF4B40E338F06AB99948402AABE97AA2CF4B40
8302	Столбище	7	64	971	49.200971000000003	49.230435	55.658053000000002	55.622146000000001	0103000020E61000000100000005000000E338F06AB99948402AABE97AA2CF4B40E338F06AB99948407104A9143BD44B40486DE2E47E9D48407104A9143BD44B40486DE2E47E9D48402AABE97AA2CF4B40E338F06AB99948402AABE97AA2CF4B40
20389	Среднее Девятово	7	64	971	49.648555999999999	49.679502999999997	55.513871000000002	55.486193	0103000020E61000000100000005000000F2CF0CE203D34840A6457D923BBE4B40F2CF0CE203D3484071AE6186C6C14B4056444DF4F9D6484071AE6186C6C14B4056444DF4F9D64840A6457D923BBE4B40F2CF0CE203D34840A6457D923BBE4B40
20804	Сокуры	7	64	971	49.384892000000001	49.423608999999999	55.626537999999996	55.610737999999998	0103000020E61000000100000005000000FB3E1C2444B148405436ACA92CCE4B40FB3E1C2444B14840C2D9AD6532D04B4048A5D8D138B64840C2D9AD6532D04B4048A5D8D138B648405436ACA92CCE4B40FB3E1C2444B148405436ACA92CCE4B40
19337	Сингели	7	64	971	49.292831999999997	49.312344000000003	55.395885	55.382497999999998	0103000020E61000000100000005000000739CDB847BA548408864C8B1F5B04B40739CDB847BA548400DFD135CACB24B40098D60E3FAA748400DFD135CACB24B40098D60E3FAA748408864C8B1F5B04B40739CDB847BA548408864C8B1F5B04B40
21526	Пиголи	7	64	971	49.155650999999999	49.186022999999999	55.572177000000003	55.552999	0103000020E610000001000000050000007B4B395FEC93484040DCD5ABC8C64B407B4B395FEC934840FF428F183DC94B40E3A6069ACF974840FF428F183DC94B40E3A6069ACF97484040DCD5ABC8C64B407B4B395FEC93484040DCD5ABC8C64B40
21369	Песчаные Ковали	7	64	971	49.123292999999997	49.159827999999997	55.634410000000003	55.618836999999999	0103000020E61000000100000005000000B169A510C88F48400247020D36CF4B40B169A510C88F4840B020CD5834D14B40177E703E75944840B020CD5834D14B40177E703E759448400247020D36CF4B40B169A510C88F48400247020D36CF4B40
20592	Пелево	7	64	971	49.580311000000002	49.606290999999999	55.577159000000002	55.560091999999997	0103000020E6100000010000000500000029417FA147CA484028603B18B1C74B4029417FA147CA4840C9CB9A58E0C94B40F86D88F19ACD4840C9CB9A58E0C94B40F86D88F19ACD484028603B18B1C74B4029417FA147CA484028603B18B1C74B40
40758	Орел	7	64	971	49.058245999999997	49.086840000000002	55.573703999999999	55.556140999999997	0103000020E61000000100000005000000B88FDC9A748748407C7BD7A02FC74B40B88FDC9A74874840CDCAF6216FC94B4009FEB7921D8B4840CDCAF6216FC94B4009FEB7921D8B48407C7BD7A02FC74B40B88FDC9A748748407C7BD7A02FC74B40
21568	Никольское	7	64	971	49.170741999999997	49.206144999999999	55.543653999999997	55.524355	0103000020E61000000100000005000000DD06B5DFDA9548403E3F8C101EC34B40DD06B5DFDA954840772B4B7496C54B40F19D98F5629A4840772B4B7496C54B40F19D98F5629A48403E3F8C101EC34B40DD06B5DFDA9548403E3F8C101EC34B40
8423	Нармонка	7	64	971	49.287191	49.304932999999998	55.497081999999999	55.482540999999998	0103000020E610000001000000050000004F5AB8ACC2A4484054FD4AE7C3BD4B404F5AB8ACC2A4484013B70A62A0BF4B404F3C670B08A7484013B70A62A0BF4B404F3C670B08A7484054FD4AE7C3BD4B404F5AB8ACC2A4484054FD4AE7C3BD4B40
40761	Нармонка	7	64	971	49.287191	49.304932999999998	55.497081999999999	55.482540999999998	0103000020E610000001000000050000004F5AB8ACC2A4484054FD4AE7C3BD4B404F5AB8ACC2A4484013B70A62A0BF4B404F3C670B08A7484013B70A62A0BF4B404F3C670B08A7484054FD4AE7C3BD4B404F5AB8ACC2A4484054FD4AE7C3BD4B40
21003	Малые Кабаны	7	64	971	49.265658000000002	49.300522000000001	55.658890999999997	55.604666000000002	0103000020E61000000100000005000000DCF5D21401A2484067800BB265CD4B40DCF5D21401A248407A50508A56D44B4040DD408177A648407A50508A56D44B4040DD408177A6484067800BB265CD4B40DCF5D21401A2484067800BB265CD4B40
20223	Малая Елга	7	64	971	49.826557000000001	49.853085	55.424551000000001	55.405873999999997	0103000020E61000000100000005000000D3A3A99ECCE94840FA25E2ADF3B34B40D3A3A99ECCE94840F73DEAAF57B64B40A5DAA7E331ED4840F73DEAAF57B64B40A5DAA7E331ED4840FA25E2ADF3B34B40D3A3A99ECCE94840FA25E2ADF3B34B40
8112	Лаишево	7	64	971	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
40732	Лаишево	7	64	971	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
61491	Кутенчи	7	64	971	49.198743	49.225656000000001	55.522224999999999	55.508794000000002	0103000020E610000001000000050000008BA71E697099484055336B2920C14B408BA71E6970994840A913D044D8C24B40B612BA4BE29C4840A913D044D8C24B40B612BA4BE29C484055336B2920C14B408BA71E697099484055336B2920C14B40
19613	Курманаково	7	64	971	49.368668	49.384784000000003	55.447978999999997	55.435948000000003	0103000020E61000000100000005000000768A558330AF4840D960E124CDB74B40768A558330AF4840BB25396057B94B401503249A40B14840BB25396057B94B401503249A40B14840D960E124CDB74B40768A558330AF4840D960E124CDB74B40
20826	Кирби	7	64	971	49.303612000000001	49.331145999999997	55.570782000000001	55.556406000000003	0103000020E610000001000000050000002A560DC2DCA648402BA6D24F38C74B402A560DC2DCA648409F9273620FC94B40C119FCFD62AA48409F9273620FC94B40C119FCFD62AA48402BA6D24F38C74B402A560DC2DCA648402BA6D24F38C74B40
20914	Карадули	7	64	971	49.301645000000001	49.325414000000002	55.522438999999999	55.503227000000003	0103000020E610000001000000050000003F00A94D9CA648406BBB09BE69C04B403F00A94D9CA64840D593F947DFC24B408DD47B2AA7A94840D593F947DFC24B408DD47B2AA7A948406BBB09BE69C04B403F00A94D9CA648406BBB09BE69C04B40
20611	Каипы	7	64	971	49.472208000000002	49.494720000000001	55.583478999999997	55.571444	0103000020E610000001000000050000006D74CE4F71BC48406ABFB51325C94B406D74CE4F71BC48408E739B70AFCA4B40AC5626FC52BF48408E739B70AFCA4B40AC5626FC52BF48406ABFB51325C94B406D74CE4F71BC48406ABFB51325C94B40
20096	Именьково	7	64	971	49.711419999999997	49.737310000000001	55.434206000000003	55.41657	0103000020E6100000010000000500000033DC80CF0FDB4840533F6F2A52B54B4033DC80CF0FDB48400EDDEC0F94B74B40C381902C60DE48400EDDEC0F94B74B40C381902C60DE4840533F6F2A52B54B4033DC80CF0FDB4840533F6F2A52B54B40
19230	Дятлово	7	64	971	49.309863999999997	49.339275000000001	55.449342000000001	55.434981999999998	0103000020E61000000100000005000000971AA19FA9A74840A12C7C7DADB74B40971AA19FA9A74840105CE50984B94B40DAACFA5C6DAB4840105CE50984B94B40DAACFA5C6DAB4840A12C7C7DADB74B40971AA19FA9A74840A12C7C7DADB74B40
20498	Державино	7	64	971	49.550173000000001	49.573619000000001	55.559756	55.546236	0103000020E610000001000000050000003412A1116CC64840EDF2AD0FEBC54B403412A1116CC64840B1DEA815A6C74B409FAEEE586CC94840B1DEA815A6C74B409FAEEE586CC94840EDF2AD0FEBC54B403412A1116CC64840EDF2AD0FEBC54B40
19494	Габишево	7	64	971	49.137746999999997	49.151671	55.617251000000003	55.606313999999998	0103000020E61000000100000005000000A10F96B1A1914840B08D78B29BCD4B40A10F96B1A19148402F36AD1402CF4B40356090F4699348402F36AD1402CF4B40356090F469934840B08D78B29BCD4B40A10F96B1A1914840B08D78B29BCD4B40
21431	Боровое Матюшино	7	64	971	49.011946999999999	49.027695000000001	55.624901000000001	55.600847000000002	0103000020E610000001000000050000008524B37A878148402A73F38DE8CC4B408524B37A878148406D1E87C1FCCF4B40A1A17F828B8348406D1E87C1FCCF4B40A1A17F828B8348402A73F38DE8CC4B408524B37A878148402A73F38DE8CC4B40
20945	Большие Кабаны	7	64	971	49.293874000000002	49.323186	55.653075999999999	55.639192000000001	0103000020E610000001000000050000008692C9A99DA54840B3EE1F0BD1D14B408692C9A99DA54840B8E68EFE97D34B403543AA285EA94840B8E68EFE97D34B403543AA285EA94840B3EE1F0BD1D14B408692C9A99DA54840B3EE1F0BD1D14B40
20701	Бима	7	64	971	49.48677	49.526448000000002	55.621581999999997	55.613833999999997	0103000020E610000001000000050000004356B77A4EBE48402096CD1C92CE4B404356B77A4EBE484021E4BCFF8FCF4B40B685E7A562C3484021E4BCFF8FCF4B40B685E7A562C348402096CD1C92CE4B404356B77A4EBE48402096CD1C92CE4B40
20713	Березовка	7	64	971	49.419629999999998	49.440057000000003	55.552785	55.545558999999997	0103000020E61000000100000005000000D235936FB6B54840EC8497E0D4C54B40D235936FB6B54840145CACA8C1C64B401DB0ABC953B84840145CACA8C1C64B401DB0ABC953B84840EC8497E0D4C54B40D235936FB6B54840EC8497E0D4C54B40
21056	Атабаево	7	64	971	49.335870999999997	49.368614000000001	55.294150000000002	55.273117999999997	0103000020E61000000100000005000000605628D2FDAA484076F9D687F5A24B40605628D2FDAA4840280F0BB5A6A54B40836C59BE2EAF4840280F0BB5A6A54B40836C59BE2EAF484076F9D687F5A24B40605628D2FDAA484076F9D687F5A24B40
61527	Александровский	7	64	971	49.011946999999999	49.853085	55.658890999999997	55.273117999999997	0103000020E610000001000000050000008524B37A8781484076F9D687F5A24B408524B37A878148407A50508A56D44B40A5DAA7E331ED48407A50508A56D44B40A5DAA7E331ED484076F9D687F5A24B408524B37A8781484076F9D687F5A24B40
40968	Усады	7	64	6931	49.011946999999999	49.853085	55.658890999999997	55.273117999999997	0103000020E610000001000000050000008524B37A8781484076F9D687F5A24B408524B37A878148407A50508A56D44B40A5DAA7E331ED48407A50508A56D44B40A5DAA7E331ED484076F9D687F5A24B408524B37A8781484076F9D687F5A24B40
15055	Ятмас-Дусай	7	64	289	50.790323999999998	50.816536999999997	55.999566000000002	55.983378000000002	0103000020E61000000100000005000000389F3A56296549408ECD8E54DFFD4B40389F3A5629654940C61858C7F1FF4B40AA7CCF4884684940C61858C7F1FF4B40AA7CCF48846849408ECD8E54DFFD4B40389F3A56296549408ECD8E54DFFD4B40
14957	Яныль	7	64	289	50.559815999999998	50.592398000000003	56.261457999999998	56.249411000000002	0103000020E6100000010000000500000086E3F90CA84749409F211CB3EC1F4C4086E3F90CA847494087A3AB7477214C40A01B9AB2D34B494087A3AB7477214C40A01B9AB2D34B49409F211CB3EC1F4C4086E3F90CA84749409F211CB3EC1F4C40
15638	Янцобино	7	64	289	50.788186000000003	50.802531999999999	56.233769000000002	56.219633000000002	0103000020E6100000010000000500000021956247E3644940AA0F24EF1C1C4C4021956247E3644940C9E88024EC1D4C402AFF5A5EB9664940C9E88024EC1D4C402AFF5A5EB9664940AA0F24EF1C1C4C4021956247E3644940AA0F24EF1C1C4C40
19147	Ядыгерь	7	64	289	50.497545000000002	50.524628999999997	56.236151	56.225548000000003	0103000020E61000000100000005000000E8A4F78DAF3F4940D0D6C1C1DE1C4C40E8A4F78DAF3F494077F52A323A1E4C403FC4060B2743494077F52A323A1E4C403FC4060B27434940D0D6C1C1DE1C4C40E8A4F78DAF3F4940D0D6C1C1DE1C4C40
15910	Чишма-Баш	7	64	289	50.625141999999997	50.656357999999997	56.304985000000002	56.294201000000001	0103000020E6100000010000000500000092AD2EA704504940AAB9DC60A8254C4092AD2EA704504940A2629CBF09274C40E63BF88903544940A2629CBF09274C40E63BF88903544940AAB9DC60A8254C4092AD2EA704504940AAB9DC60A8254C40
18864	Челны	7	64	289	50.888896000000003	50.909198000000004	56.287396999999999	56.277847999999999	0103000020E61000000100000005000000CAC51858C771494027A1F48590234C40CAC51858C7714940F8FBC56CC9244C4058CB9D9960744940F8FBC56CC9244C4058CB9D996074494027A1F48590234C40CAC51858C771494027A1F48590234C40
41033	Чарли	7	64	289	50.311387000000003	51.647388999999997	56.409951999999997	55.842700999999998	0103000020E6100000010000000500000025B37A87DB2749403BA759A0DDEB4B4025B37A87DB2749400377A04E79344C4023658BA4DDD249400377A04E79344C4023658BA4DDD249403BA759A0DDEB4B4025B37A87DB2749403BA759A0DDEB4B40
17815	Урясьбаш	7	64	289	50.941626999999997	50.960994999999997	56.049590999999999	56.038077000000001	0103000020E61000000100000005000000EA03C93B877849406ADD06B5DF044C40EA03C93B87784940859675FF58064C404C4F58E2017B4940859675FF58064C404C4F58E2017B49406ADD06B5DF044C40EA03C93B877849406ADD06B5DF044C40
17913	Туркаш	7	64	289	50.878889000000001	50.907347000000001	55.958728999999998	55.946255000000001	0103000020E6100000010000000500000036E84B6F7F704940975643E21EF94B4036E84B6F7F704940075DC2A1B7FA4B40D68F4DF223744940075DC2A1B7FA4B40D68F4DF223744940975643E21EF94B4036E84B6F7F704940975643E21EF94B40
18828	Туембаш	7	64	289	50.846127000000003	50.878025999999998	56.272199999999998	56.263482000000003	0103000020E610000001000000050000009DA1B8E34D6C4940D78A36C7B9214C409DA1B8E34D6C494050FC1873D7224C40D384ED276370494050FC1873D7224C40D384ED2763704940D78A36C7B9214C409DA1B8E34D6C4940D78A36C7B9214C40
18512	Трыш	7	64	289	50.507596999999997	50.534734999999998	56.362057	56.352536999999998	0103000020E610000001000000050000001B4641F0F8404940A2D0B2EE1F2D4C401B4641F0F8404940D9243FE2572E4C4066834C3272444940D9243FE2572E4C4066834C3272444940A2D0B2EE1F2D4C401B4641F0F8404940A2D0B2EE1F2D4C40
19070	Татарская Тулба	7	64	289	51.265739000000004	51.298160000000003	56.075212000000001	56.067484	0103000020E61000000100000005000000C9224DBC03A249406B80D250A3084C40C9224DBC03A249402522FC8BA0094C40D97C5C1B2AA649402522FC8BA0094C40D97C5C1B2AA649406B80D250A3084C40C9224DBC03A249406B80D250A3084C40
1351	Тактамыш	7	64	289	50.702683999999998	50.726013999999999	55.873444999999997	55.861908	0103000020E6100000010000000500000013B69F8CF15949409414580053EE4B4013B69F8CF159494067EDB60BCDEF4B401538D906EE5C494067EDB60BCDEF4B401538D906EE5C49409414580053EE4B4013B69F8CF15949409414580053EE4B40
16506	Старый Каенсар	7	64	289	50.985850999999997	50.997332	56.064895999999997	56.057212	0103000020E610000001000000050000004CDD955D307E494029780AB952074C404CDD955D307E494013D21A834E084C408CA03193A87F494013D21A834E084C408CA03193A87F494029780AB952074C404CDD955D307E494029780AB952074C40
18141	Старая Юмья	7	64	289	50.706223999999999	50.734377000000002	56.158872000000002	56.142837	0103000020E610000001000000050000003DD34B8C655A494052D4997B48124C403DD34B8C655A49400420EEEA55144C40A1F7C610005E49400420EEEA55144C40A1F7C610005E494052D4997B48124C403DD34B8C655A494052D4997B48124C40
18646	Средний Кумор	7	64	289	50.777855000000002	50.793297000000003	56.158591000000001	56.146006	0103000020E61000000100000005000000DA03ADC09063494088821953B0124C40DA03ADC0906349405038BBB54C144C40E9818FC18A6549405038BBB54C144C40E9818FC18A65494088821953B0124C40DA03ADC09063494088821953B0124C40
18618	Село-Чура	7	64	289	50.471134999999997	50.486891	56.27225	56.258597999999999	0103000020E610000001000000050000001F80D4264E3C4940CF6740BD19214C401F80D4264E3C4940022B8716D9224C40BEDBBC71523E4940022B8716D9224C40BEDBBC71523E4940CF6740BD19214C401F80D4264E3C4940CF6740BD19214C40
18398	Сардек-Баш	7	64	289	50.565736000000001	50.599350999999999	56.324675999999997	56.316578999999997	0103000020E61000000100000005000000BE1589096A484940D9CC21A985284C40BE1589096A484940E6E5B0FB8E294C4096E99788B74C4940E6E5B0FB8E294C4096E99788B74C4940D9CC21A985284C40BE1589096A484940D9CC21A985284C40
16314	Саз-Тамак	7	64	289	50.752146000000003	50.776004999999998	56.210712000000001	56.20487	0103000020E610000001000000050000009BE8F351466049403CF71E2E391A4C409BE8F35146604940F86F5E9CF81A4C402844C02154634940F86F5E9CF81A4C402844C021546349403CF71E2E391A4C409BE8F351466049403CF71E2E391A4C40
19195	Починок-Шемордан	7	64	289	50.467568	50.484321999999999	56.223196000000002	56.213875999999999	0103000020E61000000100000005000000FC53AA44D93B49401CB3EC49601B4C40FC53AA44D93B49408C4CC0AF911C4C40DD5D6743FE3D49408C4CC0AF911C4C40DD5D6743FE3D49401CB3EC49601B4C40FC53AA44D93B49401CB3EC49601B4C40
17612	Починок-Кучук	7	64	289	50.865324000000001	50.888446999999999	56.086911000000001	56.069991999999999	0103000020E61000000100000005000000D238D4EFC26E4940A67D737FF5084C40D238D4EFC26E4940D2544FE61F0B4C405A9D9CA1B8714940D2544FE61F0B4C405A9D9CA1B8714940A67D737FF5084C40D238D4EFC26E4940A67D737FF5084C40
16402	Починок Сутер	7	64	289	51.0227	51.038806999999998	56.073484000000001	56.063915999999999	0103000020E6100000010000000500000042CF66D5E782494077D844662E084C4042CF66D5E7824940BF6378EC67094C408DEDB5A0F7844940BF6378EC67094C408DEDB5A0F784494077D844662E084C4042CF66D5E782494077D844662E084C40
18537	Поршур	7	64	289	50.473308000000003	50.494346999999998	56.301349000000002	56.290973999999999	0103000020E61000000100000005000000B477465B953C49403FFED2A23E254C40B477465B953C494056D7A19A92264C4017F032C3463F494056D7A19A92264C4017F032C3463F49403FFED2A23E254C40B477465B953C49403FFED2A23E254C40
16932	Ошторма-Юмья	7	64	289	50.721710999999999	50.743549000000002	56.132638999999998	56.123313000000003	0103000020E61000000100000005000000EC14AB06615C4940F9156BB8C80F4C40EC14AB06615C49404A969350FA104C409CFC169D2C5F49404A969350FA104C409CFC169D2C5F4940F9156BB8C80F4C40EC14AB06615C4940F9156BB8C80F4C40
18014	Олуяз	7	64	289	50.655999000000001	50.671844999999998	56.271965000000002	56.256777999999997	0103000020E61000000100000005000000B79A75C6F7534940882AFC19DE204C40B79A75C6F75349400D54C6BFCF224C40957D5704FF5549400D54C6BFCF224C40957D5704FF554940882AFC19DE204C40B79A75C6F7534940882AFC19DE204C40
17929	Нырья	7	64	289	50.575203999999999	50.585507999999997	56.204694000000003	56.195704999999997	0103000020E61000000100000005000000A243E048A0494940F35487DC0C194C40A243E048A0494940FED7B969331A4C40EFC517EDF14A4940FED7B969331A4C40EFC517EDF14A4940F35487DC0C194C40A243E048A0494940F35487DC0C194C40
61384	Ныртинский	7	64	289	50.810572000000001	50.844977	55.945034999999997	55.930472999999999	0103000020E61000000100000005000000D386C3D2C0674940CF6740BD19F74B40D386C3D2C0674940A54929E8F6F84B40A46FD234286C4940A54929E8F6F84B40A46FD234286C4940CF6740BD19F74B40D386C3D2C0674940CF6740BD19F74B40
18426	Новый Сардек	7	64	289	50.589137000000001	50.609861000000002	56.381329999999998	56.373694	0103000020E6100000010000000500000089EE59D7684B4940105B7A34D52F4C4089EE59D7684B4940E97DE36BCF304C408D0DDDEC0F4E4940E97DE36BCF304C408D0DDDEC0F4E4940105B7A34D52F4C4089EE59D7684B4940105B7A34D52F4C40
17723	Нижняя Русь	7	64	289	50.970751	50.998112999999996	56.015002000000003	56.008333999999998	0103000020E6100000010000000500000097C79A91417C4940F1B8A81611014C4097C79A91417C4940F3AFE595EB014C40315BB22AC27F4940F3AFE595EB014C40315BB22AC27F4940F1B8A81611014C4097C79A91417C4940F1B8A81611014C40
18755	Нижний Кумор	7	64	289	50.813491999999997	50.838599000000002	56.145524999999999	56.138724000000003	0103000020E6100000010000000500000060C77F8120684940CD9541B5C1114C4060C77F81206849400DE02D90A0124C40AABA4736576B49400DE02D90A0124C40AABA4736576B4940CD9541B5C1114C4060C77F8120684940CD9541B5C1114C40
18104	Нижний Казаклар	7	64	289	50.632939	50.647967999999999	56.273964999999997	56.267867000000003	0103000020E6100000010000000500000075AE282504514940BD56427749224C4075AE282504514940D39FFD4811234C40616D8C9DF0524940D39FFD4811234C40616D8C9DF0524940BD56427749224C4075AE282504514940BD56427749224C40
17419	Нижний Искубаш	7	64	289	51.115155000000001	51.125387000000003	56.021835000000003	56.002591000000002	0103000020E61000000100000005000000467C2766BD8E4940C921E2E654004C40467C2766BD8E49403F74417DCB024C40FA2B64AE0C9049403F74417DCB024C40FA2B64AE0C904940C921E2E654004C40467C2766BD8E4940C921E2E654004C40
16836	Маскара	7	64	289	50.823211000000001	50.840674999999997	56.345973000000001	56.334318000000003	0103000020E610000001000000050000008E5A61FA5E694940693BA6EECA2A4C408E5A61FA5E6949404626E0D7482C4C404BC8073D9B6B49404626E0D7482C4C404BC8073D9B6B4940693BA6EECA2A4C408E5A61FA5E694940693BA6EECA2A4C40
15535	Манзарас	7	64	289	50.905515000000001	50.930272000000002	56.180638000000002	56.172916000000001	0103000020E61000000100000005000000CB845FEAE7734940427A8A1C22164C40CB845FEAE77349401A355F251F174C4038312427137749401A355F251F174C403831242713774940427A8A1C22164C40CB845FEAE7734940427A8A1C22164C40
17198	Мамашир	7	64	289	50.833784000000001	50.867103	56.374467000000003	56.362166999999999	0103000020E61000000100000005000000CBF6216FB96A49406058FE7C5B2E4C40CBF6216FB96A49403337DF88EE2F4C40BAA1293BFD6E49403337DF88EE2F4C40BAA1293BFD6E49406058FE7C5B2E4C40CBF6216FB96A49406058FE7C5B2E4C40
17301	Люга	7	64	289	50.909953000000002	50.936965000000001	56.148257999999998	56.138939999999998	0103000020E61000000100000005000000D4F2035779744940990D32C9C8114C40D4F203577974494068AF3E1EFA124C40923F1878EE77494068AF3E1EFA124C40923F1878EE774940990D32C9C8114C40D4F2035779744940990D32C9C8114C40
17103	Лубяны	7	64	289	51.382089000000001	51.412551000000001	56.055245999999997	56.022905999999999	0103000020E61000000100000005000000A794D74AE8B04940EB707495EE024C40A794D74AE8B049400E9E094D12074C404F779E78CEB449400E9E094D12074C404F779E78CEB44940EB707495EE024C40A794D74AE8B04940EB707495EE024C40
17004	Лельвиж	7	64	289	50.509816000000001	50.529210999999997	56.323262999999997	56.309967999999998	0103000020E61000000100000005000000207D93A6414149403C670B08AD274C40207D93A641414940E08096AE60294C407BD7A02FBD434940E08096AE60294C407BD7A02FBD4349403C670B08AD274C40207D93A6414149403C670B08AD274C40
14579	Кукмор	7	64	289	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
16817	Кошкино	7	64	289	50.794654000000001	50.821190000000001	56.337052	56.324351	0103000020E610000001000000050000005BD1E638B765494063B6645584294C405BD1E638B765494094861A85242B4C40B0E600C11C69494094861A85242B4C40B0E600C11C69494063B6645584294C405BD1E638B765494063B6645584294C40
16016	Копки	7	64	289	50.706152000000003	50.721854	56.272435000000002	56.260407999999998	0103000020E61000000100000005000000A4005130635A4940F2CEA10C55214C40A4005130635A494094A46B26DF224C404F3E3DB6655C494094A46B26DF224C404F3E3DB6655C4940F2CEA10C55214C40A4005130635A4940F2CEA10C55214C40
18303	Княгор	7	64	289	50.920318999999999	50.934745999999997	56.096201999999998	56.088020999999998	0103000020E6100000010000000500000097715303CD7549403C2EAA45440B4C4097715303CD754940A7E7DD58500C4C408D08C6C1A5774940A7E7DD58500C4C408D08C6C1A57749403C2EAA45440B4C4097715303CD7549403C2EAA45440B4C40
18221	Кня-Баш	7	64	289	50.849666999999997	50.864218999999999	56.060147000000001	56.049888000000003	0103000020E61000000100000005000000C6BE64E3C16C49403F3BE0BA62064C40C6BE64E3C16C4940ECF99AE5B2074C4079CA6ABA9E6E4940ECF99AE5B2074C4079CA6ABA9E6E49403F3BE0BA62064C40C6BE64E3C16C49403F3BE0BA62064C40
17316	Качимир	7	64	289	50.956800000000001	50.968738000000002	56.194623999999997	56.184970999999997	0103000020E610000001000000050000000A68226C787A4940ADDA3521AD174C400A68226C787A494023827170E9184C403C32569BFF7B494023827170E9184C403C32569BFF7B4940ADDA3521AD174C400A68226C787A4940ADDA3521AD174C40
16610	Каркаусь	7	64	289	51.131512999999998	51.153647999999997	56.109732000000001	56.102353000000001	0103000020E61000000100000005000000DAFF006BD5904940E1D231E7190D4C40DAFF006BD59049408FA9BBB20B0E4C40438CD7BCAA9349408FA9BBB20B0E4C40438CD7BCAA934940E1D231E7190D4C40DAFF006BD5904940E1D231E7190D4C40
31794	Камышлы	7	64	289	50.859296999999998	50.883111	56.129047	56.120266999999998	0103000020E610000001000000050000008446B071FD6D4940DEE4B7E8640F4C408446B071FD6D4940CE52B29C84104C4072DEFFC709714940CE52B29C84104C4072DEFFC709714940DEE4B7E8640F4C408446B071FD6D4940DEE4B7E8640F4C40
16517	Каенсар	7	64	289	50.620237000000003	50.645048000000003	56.183283000000003	56.173217000000001	0103000020E6100000010000000500000074620FED634F49403D0E83F92B164C4074620FED634F4940D6743DD175174C40D42CD0EE90524940D6743DD175174C40D42CD0EE905249403D0E83F92B164C4074620FED634F49403D0E83F92B164C40
61492	Иштуган	7	64	289	50.511387999999997	50.537070999999997	56.169607999999997	56.159267999999997	0103000020E610000001000000050000008EC877297541494050A6D1E462144C408EC8772975414940EA9106B7B5154C40A45016BEBE444940EA9106B7B5154C40A45016BEBE44494050A6D1E462144C408EC877297541494050A6D1E462144C40
15720	Иске-Юрт	7	64	289	50.747132999999998	50.764228000000003	56.233569000000003	56.226894000000001	0103000020E610000001000000050000009561DC0DA25F49404ED4D2DC0A1D4C409561DC0DA25F4940022EC896E51D4C4000581D39D2614940022EC896E51D4C4000581D39D26149404ED4D2DC0A1D4C409561DC0DA25F49404ED4D2DC0A1D4C40
16419	Верхняя Шунь	7	64	289	51.032356999999998	51.059612000000001	56.098140000000001	56.089433	0103000020E61000000100000005000000F9653046248449407217618A720B4C40F965304624844940F836FDD98F0C4C407E39B35DA1874940F836FDD98F0C4C407E39B35DA18749407217618A720B4C40F9653046248449407217618A720B4C40
17502	Верхний Искубаш	7	64	289	51.113655000000001	51.130732000000002	56.063685	56.049455000000002	0103000020E6100000010000000500000071033E3F8C8E4940D5CF9B8A54064C4071033E3F8C8E4940751F80D426084C40354580D3BB904940751F80D426084C40354580D3BB904940D5CF9B8A54064C4071033E3F8C8E4940D5CF9B8A54064C40
18941	Верхний Арбаш	7	64	289	50.901823	50.924864999999997	55.986823000000001	55.974589000000002	0103000020E61000000100000005000000EBE3A1EF6E7349404B051555BFFC4B40EBE3A1EF6E73494066F84F3750FE4B40861BF0F96176494066F84F3750FE4B40861BF0F9617649404B051555BFFC4B40EBE3A1EF6E7349404B051555BFFC4B40
15041	Вахитово	7	64	289	50.517226999999998	50.551453000000002	56.278891999999999	56.268380999999998	0103000020E61000000100000005000000D9CD8C7E3442494013EF004F5A224C40D9CD8C7E34424940DA8EA9BBB2234C40FB230C0396464940DA8EA9BBB2234C40FB230C039646494013EF004F5A224C40D9CD8C7E3442494013EF004F5A224C40
15816	Большой Сардек	7	64	289	50.680667	50.715924999999999	56.304765000000003	56.287562000000001	0103000020E61000000100000005000000B43BA4182057494043C9E4D4CE244C40B43BA4182057494094FB1D8A02274C40C4B12E6EA35B494094FB1D8A02274C40C4B12E6EA35B494043C9E4D4CE244C40B43BA4182057494043C9E4D4CE244C40
15547	Большой Кукмор	7	64	289	50.835833000000001	50.863213000000002	56.204759000000003	56.193161000000003	0103000020E6100000010000000500000073F56393FC6A49406CEEE87FB9184C4073F56393FC6A4940E547FC8A351A4C40B43D7AC37D6E4940E547FC8A351A4C40B43D7AC37D6E49406CEEE87FB9184C4073F56393FC6A49406CEEE87FB9184C40
17520	Битлянгур	7	64	289	51.117427999999997	51.133417999999999	56.040464999999998	56.028132999999997	0103000020E610000001000000050000003DD175E1078F49401C78B5DC99034C403DD175E1078F4940FAD005F52D054C404F594DD713914940FAD005F52D054C404F594DD7139149401C78B5DC99034C403DD175E1078F49401C78B5DC99034C40
1467	Березняк	7	64	289	50.790405	50.805531999999999	56.116342000000003	56.102684000000004	0103000020E6100000010000000500000025CCB4FD2B65494047E9D2BF240D4C4025CCB4FD2B6549405C936E4BE40E4C40D4F02DAC1B6749405C936E4BE40E4C40D4F02DAC1B67494047E9D2BF240D4C4025CCB4FD2B65494047E9D2BF240D4C40
18037	Балыклы	7	64	289	50.636245000000002	50.650762	56.253492000000001	56.239852999999997	0103000020E610000001000000050000002C9FE579705149407A6CCB80B31E4C402C9FE5797051494019E6046D72204C4062BD512B4C53494019E6046D72204C4062BD512B4C5349407A6CCB80B31E4C402C9FE579705149407A6CCB80B31E4C40
16303	Байлянгар	7	64	289	50.705182000000001	50.735714999999999	56.212259000000003	56.202480999999999	0103000020E610000001000000050000002BDD5D67435A4940DB87BCE5EA194C402BDD5D67435A49400EA48B4D2B1B4C409C16BCE82B5E49400EA48B4D2B1B4C409C16BCE82B5E4940DB87BCE5EA194C402BDD5D67435A4940DB87BCE5EA194C40
16105	Аш-Бузи	7	64	289	50.731332000000002	50.744284999999998	56.292693	56.281196000000001	0103000020E61000000100000005000000574277499C5D49400DE2033BFE234C40574277499C5D49405262D7F676254C40A1F31ABB445F49405262D7F676254C40A1F31ABB445F49400DE2033BFE234C40574277499C5D49400DE2033BFE234C40
18326	Асан-Елга	7	64	289	50.934800000000003	50.950754000000003	56.127301000000003	56.109898000000001	0103000020E610000001000000050000008126C286A7774940AAF23D23110E4C408126C286A7774940C2DF2F664B104C4046459C4EB2794940C2DF2F664B104C4046459C4EB2794940AAF23D23110E4C408126C286A7774940AAF23D23110E4C40
16196	Адаево	7	64	289	50.742784999999998	50.759889000000001	56.317253000000001	56.303072	0103000020E61000000100000005000000CC7A3194135F4940AA2A3410CB264C40CC7A3194135F494069C70DBF9B284C408ACBF10A4461494069C70DBF9B284C408ACBF10A44614940AA2A3410CB264C40CC7A3194135F4940AA2A3410CB264C40
1238	Абди	7	64	289	50.733074000000002	50.763787999999998	55.881995000000003	55.869070999999998	0103000020E6100000010000000500000022C66B5ED55D49407573F1B73DEF4B4022C66B5ED55D4940261E5036E5F04B40E38920CEC3614940261E5036E5F04B40E38920CEC36149407573F1B73DEF4B4022C66B5ED55D49407573F1B73DEF4B40
41027	Ташлы-Елга	7	64	6935	51.171002999999999	51.193145999999999	56.117019999999997	56.105877	0103000020E610000001000000050000004A42226DE39549400533A6608D0D4C404A42226DE39549402C7DE882FA0E4C4036AD1402B99849402C7DE882FA0E4C4036AD1402B99849400533A6608D0D4C404A42226DE39549400533A6608D0D4C40
14764	совхоз Осинники	7	64	1238	48.882904000000003	48.902540999999999	55.477373	55.466442999999998	0103000020E61000000100000005000000F9C08EFF027148405C397B67B4BB4B40F9C08EFF02714840287FF78E1ABD4B404A26A77686734840287FF78E1ABD4B404A26A776867348405C397B67B4BB4B40F9C08EFF027148405C397B67B4BB4B40
40976	п.г.т.Тенишево	7	64	1238	48.712296000000002	49.420492000000003	55.509298999999999	55.043700999999999	0103000020E610000001000000050000002B89EC832C5B4840B8E68EFE97854B402B89EC832C5B48405871AAB530C14B40651D8EAED2B548405871AAB530C14B40651D8EAED2B54840B8E68EFE97854B402B89EC832C5B4840B8E68EFE97854B40
13923	Челны	7	64	1238	48.897987000000001	48.908650000000002	55.233331	55.223807000000001	0103000020E61000000100000005000000D89DEE3CF1724840D5CE30B5A59C4B40D89DEE3CF17248404D124BCADD9D4B4055C1A8A44E7448404D124BCADD9D4B4055C1A8A44E744840D5CE30B5A59C4B40D89DEE3CF1724840D5CE30B5A59C4B40
14566	Уразлино	7	64	1238	49.169987999999996	49.193182	55.186931000000001	55.176665999999997	0103000020E61000000100000005000000315BB22AC29548405628D2FD9C964B40315BB22AC2954840E6CDE15AED974B4083161230BA984840E6CDE15AED974B4083161230BA9848405628D2FD9C964B40315BB22AC29548405628D2FD9C964B40
14665	Теньки	7	64	1238	48.950799000000004	49.006638000000002	55.444690999999999	55.42427	0103000020E61000000100000005000000E60819C8B37948404356B77A4EB64B40E60819C8B3794840ABE97AA2EBB84B4097749483D9804840ABE97AA2EBB84B4097749483D98048404356B77A4EB64B40E60819C8B37948404356B77A4EB64B40
13806	Сюкеево	7	64	1238	48.994734999999999	49.036147999999997	55.116551999999999	55.099294	0103000020E61000000100000005000000E197FA79537F4840325871AAB58C4B40E197FA79537F484046240A2DEB8E4B406CE8667FA084484046240A2DEB8E4B406CE8667FA0844840325871AAB58C4B40E197FA79537F4840325871AAB58C4B40
13157	Старое Казеево	7	64	1238	48.830595000000002	48.850394000000001	55.314351000000002	55.303283	0103000020E610000001000000050000004E9CDCEF506A4840653733FAD1A64B404E9CDCEF506A4840823B50A73CA84B40795BE9B5D96C4840823B50A73CA84B40795BE9B5D96C4840653733FAD1A64B404E9CDCEF506A4840653733FAD1A64B40
12982	Старое Барышево	7	64	1238	48.728223	48.747169	55.315821	55.301628000000001	0103000020E61000000100000005000000F6984869365D484069C70DBF9BA64B40F6984869365D4840EC3191D26CA84B40E2CAD93BA35F4840EC3191D26CA84B40E2CAD93BA35F484069C70DBF9BA64B40F6984869365D484069C70DBF9BA64B40
12721	Салтыганово	7	64	1238	49.130785000000003	49.142417999999999	55.178511	55.172604	0103000020E6100000010000000500000058E71890BD90484053944BE317964B4058E71890BD904840F67CCD72D9964B404D2EC6C03A924840F67CCD72D9964B404D2EC6C03A92484053944BE317964B4058E71890BD90484053944BE317964B40
13258	Мордовский Каратай	7	64	1238	49.060887000000001	49.085393000000003	55.120294999999999	55.104717999999998	0103000020E6100000010000000500000033E02C25CB874840B9A64066678D4B4033E02C25CB874840A86F99D3658F4B4057276728EE8A4840A86F99D3658F4B4057276728EE8A4840B9A64066678D4B4033E02C25CB874840B9A64066678D4B40
14200	Малые Салтыки	7	64	1238	49.080613999999997	49.108642000000003	55.289023999999998	55.279046999999998	0103000020E61000000100000005000000C4CC3E8F518A48400186E5CFB7A34B40C4CC3E8F518A48402AE109BDFEA44B406C7C26FBE78D48402AE109BDFEA44B406C7C26FBE78D48400186E5CFB7A34B40C4CC3E8F518A48400186E5CFB7A34B40
14489	Малые Кармалы	7	64	1238	49.153557999999997	49.175800000000002	55.201058000000003	55.191541000000001	0103000020E610000001000000050000000305DEC9A7934840EC6B5D6A84984B400305DEC9A7934840B24CBF44BC994B408351499D80964840B24CBF44BC994B408351499D80964840EC6B5D6A84984B400305DEC9A7934840EC6B5D6A84984B40
14863	Малые Буртасы	7	64	1238	48.917389999999997	48.934665000000003	55.271180000000001	55.261208000000003	0103000020E61000000100000005000000B6D617096D7548400FBA84436FA14B40B6D617096D75484026AAB706B6A24B40A1DB4B1AA377484026AAB706B6A24B40A1DB4B1AA37748400FBA84436FA14B40B6D617096D7548400FBA84436FA14B40
14293	Малое Мереткозино	7	64	1238	49.144250999999997	49.171909999999997	55.258161000000001	55.243495000000003	0103000020E6100000010000000500000028B517D176924840A9DE1AD82A9F4B4028B517D176924840240D6E6B0BA14B407CED992501964840240D6E6B0BA14B407CED992501964840A9DE1AD82A9F4B4028B517D176924840A9DE1AD82A9F4B40
40648	Куйбышевский Затон	7	64	1238	49.147826000000002	49.186794999999996	55.168166999999997	55.144818999999998	0103000020E61000000100000005000000CFBF5DF6EB924840726BD26D89924B40CFBF5DF6EB9248401AA20A7F86954B40350708E6E89748401AA20A7F86954B40350708E6E8974840726BD26D89924B40CFBF5DF6EB924840726BD26D89924B40
14779	Красновидово	7	64	1238	49.064058000000003	49.090477999999997	55.372042999999998	55.349307000000003	0103000020E610000001000000050000000A86730D33884840C7A17E17B6AC4B400A86730D3388484055DAE21A9FAF4B40F58079C8948B484055DAE21A9FAF4B40F58079C8948B4840C7A17E17B6AC4B400A86730D33884840C7A17E17B6AC4B40
14002	Клянчеево	7	64	1238	48.834853000000003	48.859341000000001	55.227032000000001	55.207639	0103000020E61000000100000005000000D7FB8D76DC6A4840E42F2DEA939A4B40D7FB8D76DC6A48409F9273620F9D4B40548EC9E2FE6D48409F9273620F9D4B40548EC9E2FE6D4840E42F2DEA939A4B40D7FB8D76DC6A4840E42F2DEA939A4B40
13706	Кирельское	7	64	1238	49.124659000000001	49.156827	55.142662999999999	55.127305999999997	0103000020E6100000010000000500000077137CD3F48F4840D34A21904B904B4077137CD3F48F4840B4ACFBC742924B409D103AE812944840B4ACFBC742924B409D103AE812944840D34A21904B904B4077137CD3F48F4840D34A21904B904B40
13071	Картапа	7	64	1238	48.748283000000001	48.761172999999999	55.294386000000003	55.282564000000001	0103000020E610000001000000050000008E93C2BCC75F48407383A10E2BA44B408E93C2BCC75F48403C33C170AEA54B4092CCEA1D6E6148403C33C170AEA54B4092CCEA1D6E6148407383A10E2BA44B408E93C2BCC75F48407383A10E2BA44B40
13146	Караталга	7	64	1238	48.823768000000001	48.850250000000003	55.290264999999998	55.279358999999999	0103000020E61000000100000005000000E4BED53A71694840F06B2409C2A34B40E4BED53A7169484033164D6727A54B4046B6F3FDD46C484033164D6727A54B4046B6F3FDD46C4840F06B2409C2A34B40E4BED53A71694840F06B2409C2A34B40
13338	Камское Устье	7	64	1238	49.242759999999997	49.289499999999997	55.213531000000003	55.185105999999998	0103000020E6100000010000000500000073637AC2129F48408D25AC8DB1974B4073637AC2129F484052D7DAFB549B4B40931804560EA5484052D7DAFB549B4B40931804560EA548408D25AC8DB1974B4073637AC2129F48408D25AC8DB1974B40
13715	Ишимово	7	64	1238	49.050699999999999	49.068280999999999	55.154933	55.147762	0103000020E610000001000000050000001FF46C567D864840B8CB7EDDE9924B401FF46C567D8648401C0934D8D4934B4016F88A6EBD8848401C0934D8D4934B4016F88A6EBD884840B8CB7EDDE9924B401FF46C567D864840B8CB7EDDE9924B40
14387	Данышево	7	64	1238	49.023077000000001	49.037244000000001	55.23366	55.225594000000001	0103000020E610000001000000050000001825E82FF48248404016A243E09C4B401825E82FF482484012312592E89D4B4072FC5069C484484012312592E89D4B4072FC5069C48448404016A243E09C4B401825E82FF48248404016A243E09C4B40
14874	Варварино	7	64	1238	48.857114000000003	48.882795999999999	55.37726	55.353171000000003	0103000020E61000000100000005000000CD785BE9B56D4840A47213B534AD4B40CD785BE9B56D4840630B410E4AB04B4012859675FF704840630B410E4AB04B4012859675FF704840A47213B534AD4B40CD785BE9B56D4840A47213B534AD4B40
14303	Большие Салтыки	7	64	1238	49.053826999999998	49.079940999999998	55.265579000000002	55.255015	0103000020E6100000010000000500000026529ACDE3864840A67EDE54A4A04B4026529ACDE386484090C01F7EFEA14B40054EB6813B8A484090C01F7EFEA14B40054EB6813B8A4840A67EDE54A4A04B4026529ACDE3864840A67EDE54A4A04B40
13902	Большие Кляри	7	64	1238	48.954490999999997	48.975394999999999	55.230046000000002	55.218609999999998	0103000020E61000000100000005000000C5A9D6C22C7A48400E4A9869FB9B4B40C5A9D6C22C7A4840AE49B725729D4B4049D74CBED97C4840AE49B725729D4B4049D74CBED97C48400E4A9869FB9B4B40C5A9D6C22C7A48400E4A9869FB9B4B40
14397	Большие Кармалы	7	64	1238	49.116610000000001	49.134810000000002	55.216289000000003	55.208326999999997	0103000020E610000001000000050000007B319413ED8E4840D8EF8975AA9A4B407B319413ED8E484006BEA25BAF9B4B403E963E744191484006BEA25BAF9B4B403E963E7441914840D8EF8975AA9A4B407B319413ED8E4840D8EF8975AA9A4B40
14096	Большие Буртасы	7	64	1238	48.904203000000003	48.916868999999998	55.280369	55.269544000000003	0103000020E61000000100000005000000F9F884ECBC734840A16AF46A80A24B40F9F884ECBC734840F7E7A221E3A34B40ADDBA0F65B754840F7E7A221E3A34B40ADDBA0F65B754840A16AF46A80A24B40F9F884ECBC734840A16AF46A80A24B40
14191	Большая Янгасала	7	64	1238	48.977595999999998	48.997115999999998	55.288193999999997	55.271467000000001	0103000020E61000000100000005000000A759A0DD217D4840BC783F6EBFA24B40A759A0DD217D4840A3737E8AE3A44B40BF28417FA17F4840A3737E8AE3A44B40BF28417FA17F4840BC783F6EBFA24B40A759A0DD217D4840BC783F6EBFA24B40
14475	Баргузино	7	64	1238	49.044941999999999	49.065325000000001	55.222113	55.213084000000002	0103000020E61000000100000005000000C11BD2A8C085484083A62556469B4B40C11BD2A8C08548401B82E3326E9C4B403C4ED1915C8848401B82E3326E9C4B403C4ED1915C88484083A62556469B4B40C11BD2A8C085484083A62556469B4B40
14111	Балчиклы	7	64	1238	48.899208999999999	48.925538000000003	55.310195999999998	55.303673000000003	0103000020E610000001000000050000006AA2CF4719734840D0D6C1C1DEA64B406AA2CF4719734840CDACA580B4A74B40469A780778764840CDACA580B4A74B40469A780778764840D0D6C1C1DEA64B406AA2CF4719734840D0D6C1C1DEA64B40
13242	Атабаево	7	64	1238	48.845982999999997	48.864282000000003	55.274799999999999	55.265799000000001	0103000020E6100000010000000500000069FCC22B496C48409E279EB305A24B4069FCC22B496C48406C787AA52CA34B40C042E6CAA06E48406C787AA52CA34B40C042E6CAA06E48409E279EB305A24B4069FCC22B496C48409E279EB305A24B40
12971	Азимово-Курлебаш	7	64	1238	48.863796999999998	48.883631999999999	55.331857999999997	55.321599999999997	0103000020E6100000010000000500000003B16CE6906E4840613255302AA94B4003B16CE6906E48403E75AC527AAA4B407BD976DA1A7148403E75AC527AAA4B407BD976DA1A714840613255302AA94B4003B16CE6906E4840613255302AA94B40
40592	станция Куланга	7	64	1168	48.421044000000002	48.421970000000002	55.460496999999997	55.460241000000003	0103000020E61000000100000005000000A91611C5E4354840A1A3552DE9BA4B40A91611C5E4354840FB73D190F1BA4B4052F2EA1C03364840FB73D190F1BA4B4052F2EA1C03364840A1A3552DE9BA4B40A91611C5E4354840A1A3552DE9BA4B40
40835	д.Имянле Буртас	7	64	1168	47.645583000000002	48.579489000000002	55.541397000000003	55.213911000000003	0103000020E6100000010000000500000042EDB776A2D2474099A0866F619B4B4042EDB776A2D247408693347F4CC54B4025B20FB22C4A48408693347F4CC54B4025B20FB22C4A484099A0866F619B4B4042EDB776A2D2474099A0866F619B4B40
11841	Янсуринское	7	64	1168	47.742725999999998	47.761330999999998	55.331330999999999	55.320523999999999	0103000020E61000000100000005000000C7F143A511DF4740A3CA30EE06A94B40C7F143A511DF47405393E00D69AA4B402A37514B73E147405393E00D69AA4B402A37514B73E14740A3CA30EE06A94B40C7F143A511DF4740A3CA30EE06A94B40
12343	Эбалаково	7	64	1168	48.175947999999998	48.210686000000003	55.358150999999999	55.343480999999997	0103000020E61000000100000005000000F7E5CC768516484010E6762FF7AB4B40F7E5CC7685164840CD0358E4D7AD4B40CFDC43C2F71A4840CD0358E4D7AD4B40CFDC43C2F71A484010E6762FF7AB4B40F7E5CC768516484010E6762FF7AB4B40
11390	Шушерма	7	64	1168	48.344687999999998	48.369652000000002	55.497674000000004	55.486096000000003	0103000020E610000001000000050000006DA983BC1E2C4840B45BCB6438BE4B406DA983BC1E2C4840E60819C8B3BF4B405473B9C1502F4840E60819C8B3BF4B405473B9C1502F4840B45BCB6438BE4B406DA983BC1E2C4840B45BCB6438BE4B40
11954	Чутеево	7	64	1168	47.751575000000003	47.790643000000003	55.291550999999998	55.276871999999997	0103000020E61000000100000005000000E0BE0E9C33E04740CC96AC8A70A34B40E0BE0E9C33E04740DC0E0D8B51A54B40DAE731CA33E54740DC0E0D8B51A54B40DAE731CA33E54740CC96AC8A70A34B40E0BE0E9C33E04740CC96AC8A70A34B40
11866	Хозесаново	7	64	1168	47.820898	47.843940000000003	55.374313999999998	55.358058999999997	0103000020E6100000010000000500000008AD872F13E94740EC8497E0D4AD4B4008AD872F13E94740AC376A85E9AF4B40A4E4D53906EC4740AC376A85E9AF4B40A4E4D53906EC4740EC8497E0D4AD4B4008AD872F13E94740EC8497E0D4AD4B40
11169	Федоровское	7	64	1168	48.365672000000004	48.392532000000003	55.459980999999999	55.447575999999998	0103000020E610000001000000050000000E881057CE2E4840BC3C9D2B4AB94B400E881057CE2E484004E44BA8E0BA4B401651137D3E32484004E44BA8E0BA4B401651137D3E324840BC3C9D2B4AB94B400E881057CE2E4840BC3C9D2B4AB94B40
12891	Ульянково	7	64	1168	48.051485999999997	48.083637000000003	55.426758	55.404806000000001	0103000020E61000000100000005000000D619DF1797064840BF9CD9AED0B34B40D619DF179706484037A79201A0B64B4027DE019EB40A484037A79201A0B64B4027DE019EB40A4840BF9CD9AED0B34B40D619DF1797064840BF9CD9AED0B34B40
11939	Турминское	7	64	1168	47.873359000000001	47.891074000000003	55.359369000000001	55.337302000000001	0103000020E6100000010000000500000069554B3ACAEF47400D7041B62CAB4B4069554B3ACAEF47401E19ABCDFFAD4B4070287CB60EF247401E19ABCDFFAD4B4070287CB60EF247400D7041B62CAB4B4069554B3ACAEF47400D7041B62CAB4B40
12084	Старые Чечкабы	7	64	1168	48.097937999999999	48.115599000000003	55.410387	55.395117999999997	0103000020E6100000010000000500000090847D3B890C4840CC07043A93B24B4090847D3B890C48400EDAAB8F87B44B40A439B2F2CB0E48400EDAAB8F87B44B40A439B2F2CB0E4840CC07043A93B24B4090847D3B890C4840CC07043A93B24B40
11763	Старое Тябердино	7	64	1168	47.707881	47.737786	55.346829	55.334556999999997	0103000020E61000000100000005000000DA3A38D89BDA4740EDD286C3D2AA4B40DA3A38D89BDA4740F62686E464AC4B402CB98AC56FDE4740F62686E464AC4B402CB98AC56FDE4740EDD286C3D2AA4B40DA3A38D89BDA4740EDD286C3D2AA4B40
61383	ПолеваяБуа	7	64	1168	47.838667000000001	47.849409999999999	55.311886999999999	55.306327000000003	0103000020E61000000100000005000000029EB47059EB4740DF701FB935A74B40029EB47059EB47401686C8E9EBA74B409B728577B9EC47401686C8E9EBA74B409B728577B9EC4740DF701FB935A74B40029EB47059EB4740DF701FB935A74B40
11096	Надеждино	7	64	1168	48.009939000000003	48.042234000000001	55.501299000000003	55.492635	0103000020E610000001000000050000003CFA5FAE45014840B7EEE6A90EBF4B403CFA5FAE450148403E42CD902AC04B40BF6378EC670548403E42CD902AC04B40BF6378EC67054840B7EEE6A90EBF4B403CFA5FAE45014840B7EEE6A90EBF4B40
11103	Мурали	7	64	1168	48.319687000000002	48.343933	55.439118999999998	55.420223999999997	0103000020E610000001000000050000006AFAEC80EB284840457F68E6C9B54B406AFAEC80EB284840AF06280D35B84B40F1811DFF052C4840AF06280D35B84B40F1811DFF052C4840457F68E6C9B54B406AFAEC80EB284840457F68E6C9B54B40
11654	Молькеево	7	64	1168	47.798512000000002	47.821103999999998	55.332273000000001	55.314121	0103000020E6100000010000000500000056BB26A435E6474050FEEE1D35A84B4056BB26A435E64740022CF2EB87AA4B40B14E95EF19E94740022CF2EB87AA4B40B14E95EF19E9474050FEEE1D35A84B4056BB26A435E6474050FEEE1D35A84B40
11464	Малые Меми	7	64	1168	48.507561000000003	48.519581000000002	55.457709999999999	55.438848999999998	0103000020E61000000100000005000000CFDC43C2F7404840EF703B342CB84B40CFDC43C2F7404840AD86C43D96BA4B40BE4F55A181424840AD86C43D96BA4B40BE4F55A181424840EF703B342CB84B40CFDC43C2F7404840EF703B342CB84B40
12252	Малые Кушманы	7	64	1168	48.252161000000001	48.274287000000001	55.418492000000001	55.409007000000003	0103000020E61000000100000005000000D029C8CF46204840E46A64575AB44B40D029C8CF462048409ED1562591B54B40E65B1FD61B2348409ED1562591B54B40E65B1FD61B234840E46A64575AB44B40D029C8CF46204840E46A64575AB44B40
12276	Малые Кайбицы	7	64	1168	48.165132	48.178615999999998	55.380395999999998	55.363717999999999	0103000020E61000000100000005000000F4C29D0B23154840B77BB94F8EAE4B40F4C29D0B23154840BDC3EDD0B0B04B406B459BE3DC164840BDC3EDD0B0B04B406B459BE3DC164840B77BB94F8EAE4B40F4C29D0B23154840B77BB94F8EAE4B40
12560	Малое Русаково	7	64	1168	48.329819999999998	48.357821000000001	55.356636000000002	55.346435	0103000020E610000001000000050000008AC8B08A372A48404A9869FB57AC4B408AC8B08A372A4840C3499A3FA6AD4B4038691A14CD2D4840C3499A3FA6AD4B4038691A14CD2D48404A9869FB57AC4B408AC8B08A372A48404A9869FB57AC4B40
12834	Малое Подберезье	7	64	1168	47.907674999999998	47.930061000000002	55.427545000000002	55.416550000000001	0103000020E61000000100000005000000CA32C4B12EF447400C93A98251B54B40CA32C4B12EF44740BF4868CBB9B64B407D24253D0CF74740BF4868CBB9B64B407D24253D0CF747400C93A98251B54B40CA32C4B12EF447400C93A98251B54B40
12910	Корноухово	7	64	1168	48.019893000000003	48.031238000000002	55.389074000000001	55.378850999999997	0103000020E61000000100000005000000AD3594DA8B024840488787307EB04B40AD3594DA8B024840A9DC442DCDB14B403C32569BFF034840A9DC442DCDB14B403C32569BFF034840488787307EB04B40AD3594DA8B024840488787307EB04B40
40653	Каргалы	7	64	1168	48.019793999999997	48.048791000000001	55.287891000000002	55.281508000000002	0103000020E6100000010000000500000019541B9C88024840FCC7427408A44B4019541B9C8802484008E8BE9CD9A44B4069AB92C83E06484008E8BE9CD9A44B4069AB92C83E064840FCC7427408A44B4019541B9C88024840FCC7427408A44B40
11376	Бурундуки	7	64	1168	48.427512	48.452835999999998	55.511741000000001	55.491630000000001	0103000020E61000000100000005000000E35295B6B8364840C2DD59BBEDBE4B40E35295B6B8364840DC82A5BA80C14B40C939B187F6394840DC82A5BA80C14B40C939B187F6394840C2DD59BBEDBE4B40E35295B6B8364840C2DD59BBEDBE4B40
12045	Большое Тябердино	7	64	1168	47.713144999999997	47.735190000000003	55.280903000000002	55.268707999999997	0103000020E610000001000000050000002827DA5548DB47403716140665A24B402827DA5548DB4740952C27A1F4A34B40522CB7B41ADE4740952C27A1F4A34B40522CB7B41ADE47403716140665A24B402827DA5548DB47403716140665A24B40
12531	Большое Русаково	7	64	1168	48.377647000000003	48.422131	55.367888000000001	55.357092000000002	0103000020E610000001000000050000005D37A5BC56304840E5D4CE30B5AD4B405D37A5BC56304840A14B38F416AF4B405BD07B6308364840A14B38F416AF4B405BD07B6308364840E5D4CE30B5AD4B405D37A5BC56304840E5D4CE30B5AD4B40
12749	Большое Подберезье	7	64	1168	47.962760000000003	47.992080999999999	55.369453999999998	55.345630999999997	0103000020E61000000100000005000000D0F23CB83BFB4740ECBDF8A23DAC4B40D0F23CB83BFB47402DB0C7444AAF4B40D2FD9C82FCFE47402DB0C7444AAF4B40D2FD9C82FCFE4740ECBDF8A23DAC4B40D0F23CB83BFB4740ECBDF8A23DAC4B40
12136	Большие Кайбицы	7	64	1168	48.174852000000001	48.198262	55.412590000000002	55.394995000000002	0103000020E61000000100000005000000F2D1E28C61164840B18A37328FB24B40F2D1E28C611648400D54C6BFCFB44B40100533A6601948400D54C6BFCFB44B40100533A660194840B18A37328FB24B40F2D1E28C61164840B18A37328FB24B40
12458	Берлибаш	7	64	1168	48.113892	48.152295000000002	55.361288000000002	55.349193999999997	0103000020E6100000010000000500000055A35703940E4840CEFA9463B2AC4B4055A35703940E4840F83768AF3EAE4B40132C0E677E134840F83768AF3EAE4B40132C0E677E134840CEFA9463B2AC4B4055A35703940E4840CEFA9463B2AC4B40
11269	Беляево	7	64	1168	48.402313999999997	48.421250999999998	55.475102	55.461441000000001	0103000020E61000000100000005000000895C70067F3348404B04AA7F10BB4B40895C70067F334840D1217024D0BC4B402234828DEB354840D1217024D0BC4B402234828DEB3548404B04AA7F10BB4B40895C70067F3348404B04AA7F10BB4B40
12633	Багаево	7	64	1168	48.133780999999999	48.161557000000002	55.493482	55.481606999999997	0103000020E61000000100000005000000C0E95DBC1F1148402843554CA5BD4B40C0E95DBC1F11484014950D6B2ABF4B404EB857E6AD14484014950D6B2ABF4B404EB857E6AD1448402843554CA5BD4B40C0E95DBC1F1148402843554CA5BD4B40
12189	Афанасьевка	7	64	1168	48.203409000000001	48.219560999999999	55.434007000000001	55.426104000000002	0103000020E61000000100000005000000255B5D4E091A4840EF586C938AB64B40255B5D4E091A4840179E978A8DB74B40103D29931A1C4840179E978A8DB74B40103D29931A1C4840EF586C938AB64B40255B5D4E091A4840EF586C938AB64B40
12676	Арасланово	7	64	1168	48.184994000000003	48.204918999999997	55.491987000000002	55.482444000000001	0103000020E6100000010000000500000066FA25E2AD174840621399B9C0BD4B4066FA25E2AD1748405187156EF9BE4B401DAA29C93A1A48405187156EF9BE4B401DAA29C93A1A4840621399B9C0BD4B4066FA25E2AD174840621399B9C0BD4B40
10480	Утяшки	7	64	947	48.344993000000002	48.367783000000003	55.575434000000001	55.564281999999999	0103000020E61000000100000005000000AA2C0ABB282C484059DC7F643AC84B40AA2C0ABB282C4840D48041D2A7C94B402C836A83132F4840D48041D2A7C94B402C836A83132F484059DC7F643AC84B40AA2C0ABB282C484059DC7F643AC84B40
10548	Утяково	7	64	947	48.443393999999998	48.454641000000002	55.571193999999998	55.557006000000001	0103000020E610000001000000050000000E9F7422C138484080D6FCF84BC74B400E9F7422C1384840F1D58EE21CC94B40DB3521AD313A4840F1D58EE21CC94B40DB3521AD313A484080D6FCF84BC74B400E9F7422C138484080D6FCF84BC74B40
8783	Уразла	7	64	947	48.713822999999998	48.733739	56.039821000000003	56.027565000000003	0103000020E61000000100000005000000F910548D5E5B4840D3C1FA3F87034C40F910548D5E5B4840D658C2DA18054C405E66D828EB5D4840D658C2DA18054C405E66D828EB5D4840D3C1FA3F87034C40F910548D5E5B4840D3C1FA3F87034C40
61415	Товлино	7	64	947	48.263973999999997	48.281472999999998	55.654482000000002	55.641204000000002	0103000020E61000000100000005000000457F68E6C92148403E0801F912D24B40457F68E6C92148400CE9F010C6D34B407FDAA84E072448400CE9F010C6D34B407FDAA84E072448403E0801F912D24B40457F68E6C92148403E0801F912D24B40
10770	Татарское Танаево	7	64	947	48.178742	48.203122	55.520349000000003	55.509568999999999	0103000020E61000000100000005000000F8359204E11648401807978E39C14B40F8359204E1164840CFC0C8CB9AC24B408F8CD5E6FF194840CFC0C8CB9AC24B408F8CD5E6FF1948401807978E39C14B40F8359204E11648401807978E39C14B40
11005	Сунчелеево	7	64	947	48.082693999999996	48.098010000000002	55.676082999999998	55.661897000000003	0103000020E61000000100000005000000A7C98CB7950A48400729780AB9D44B40A7C98CB7950A4840D73043E389D64B402A5778978B0C4840D73043E389D64B402A5778978B0C48400729780AB9D44B40A7C98CB7950A48400729780AB9D44B40
9685	Свияжск	7	64	947	48.647095999999998	48.671315	55.777453999999999	55.765796999999999	0103000020E61000000100000005000000ABAFAE0AD4524840FD2FD7A205E24B40ABAFAE0AD45248407B12D89C83E34B40392861A6ED5548407B12D89C83E34B40392861A6ED554840FD2FD7A205E24B40ABAFAE0AD4524840FD2FD7A205E24B40
10578	Русское Азелеево	7	64	947	48.286549000000001	48.314791999999997	55.516807	55.505296999999999	0103000020E61000000100000005000000CBD93BA3AD2448402AE27492ADC04B40CBD93BA3AD24484004AC55BB26C24B406E85B01A4B28484004AC55BB26C24B406E85B01A4B2848402AE27492ADC04B40CBD93BA3AD2448402AE27492ADC04B40
32928	Раифа	7	64	947	48.724575999999999	48.741850999999997	55.909135999999997	55.898254999999999	0103000020E61000000100000005000000B6BB07E8BE5C4840F73B1405FAF24B40B6BB07E8BE5C4840E1CE85915EF44B40A0C03BF9F45E4840E1CE85915EF44B40A0C03BF9F45E4840F73B1405FAF24B40B6BB07E8BE5C4840F73B1405FAF24B40
9902	Протопоповка	7	64	947	48.514245000000003	48.535274000000001	55.777008000000002	55.770183000000003	0103000020E61000000100000005000000D690B8C7D2414840B477465B95E24B40D690B8C7D24148407D5D86FF74E34B401633C2DB834448407D5D86FF74E34B401633C2DB83444840B477465B95E24B40D690B8C7D2414840B477465B95E24B40
40643	Осиново	7	64	947	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10273	Нурлаты	7	64	947	48.274062000000001	48.314000999999998	55.623950999999998	55.600454999999997	0103000020E61000000100000005000000C689AF76142348401EDC9DB5DBCC4B40C689AF76142348403BA759A0DDCF4B40A5F44C2F312848403BA759A0DDCF4B40A5F44C2F312848401EDC9DB5DBCC4B40C689AF76142348401EDC9DB5DBCC4B40
8404	Новопольский	7	64	947	48.750295000000001	48.773066999999998	55.877172000000002	55.870151999999997	0103000020E6100000010000000500000019ADA3AA096048404546072461EF4B4019ADA3AA09604840C47B0E2C47F04B40F44E05DCF3624840C47B0E2C47F04B40F44E05DCF36248404546072461EF4B4019ADA3AA096048404546072461EF4B40
10181	Нижние Ураспуги	7	64	947	48.290078999999999	48.308827000000001	55.703378000000001	55.694747999999997	0103000020E61000000100000005000000D120054F212548400F7BA180EDD84B40D120054F21254840EA5C514A08DA4B40978FA4A487274840EA5C514A08DA4B40978FA4A4872748400F7BA180EDD84B40D120054F212548400F7BA180EDD84B40
9781	Нижние Вязовые	7	64	947	48.499898000000002	48.536881999999999	55.817526999999998	55.777726999999999	0103000020E61000000100000005000000FCAA5CA8FC3F4840AC1BEF8E8CE34B40FCAA5CA8FC3F48406A4C88B9A4E84B40D1E7A38CB84448406A4C88B9A4E84B40D1E7A38CB8444840AC1BEF8E8CE34B40FCAA5CA8FC3F4840AC1BEF8E8CE34B40
10409	Молвино	7	64	947	48.371456999999999	48.404767	55.621800999999998	55.601258999999999	0103000020E61000000100000005000000656F29E78B2F48407CB60E0EF6CC4B40656F29E78B2F48405FCFD72C97CF4B4001C0B167CF3348405FCFD72C97CF4B4001C0B167CF3348407CB60E0EF6CC4B40656F29E78B2F48407CB60E0EF6CC4B40
10731	Мамадыш-Акилово	7	64	947	48.128839999999997	48.149430000000002	55.539211999999999	55.529730999999998	0103000020E61000000100000005000000543541D47D104840B456B439CEC34B40543541D47D1048402DCE18E604C54B404985B185201348402DCE18E604C54B404985B18520134840B456B439CEC34B40543541D47D104840B456B439CEC34B40
10000	Малые Ширданы	7	64	947	48.348730000000003	48.378267000000001	55.762925000000003	55.743507000000001	0103000020E610000001000000050000002A91442FA32C48406DACC43C2BDF4B402A91442FA32C48408126C286A7E14B40F913950D6B3048408126C286A7E14B40F913950D6B3048406DACC43C2BDF4B402A91442FA32C48406DACC43C2BDF4B40
10912	Кугушево	7	64	947	48.157226999999999	48.175274000000002	55.663217000000003	55.650637000000003	0103000020E610000001000000050000002B86AB0320144840A648BE1248D34B402B86AB03201448405C936E4BE4D44B4068EBE0606F1648405C936E4BE4D44B4068EBE0606F164840A648BE1248D34B402B86AB0320144840A648BE1248D34B40
10814	Кугеево	7	64	947	48.202035000000002	48.221986999999999	55.620941000000002	55.606614	0103000020E61000000100000005000000DDD26A48DC194840DBA50D87A5CD4B40DDD26A48DC1948406EDFA3FE7ACF4B408E91EC116A1C48406EDFA3FE7ACF4B408E91EC116A1C4840DBA50D87A5CD4B40DDD26A48DC194840DBA50D87A5CD4B40
8419	Красный Яр	7	64	947	48.613517000000002	48.663338000000003	55.862074999999997	55.843055	0103000020E6100000010000000500000020459DB9874E484059DDEA39E9EB4B4020459DB9874E48407FD93D7958EE4B40D7187442E85448407FD93D7958EE4B40D7187442E854484059DDEA39E9EB4B4020459DB9874E484059DDEA39E9EB4B40
10386	Косяково	7	64	947	48.305529999999997	48.330593	55.673071999999998	55.659936999999999	0103000020E6100000010000000500000033F9669B1B274840CE35CCD078D44B4033F9669B1B27484039ED293927D64B40ADA415DF502A484039ED293927D64B40ADA415DF502A4840CE35CCD078D44B4033F9669B1B274840CE35CCD078D44B40
10653	Карашам	7	64	947	48.258566000000002	48.280332000000001	55.555346	55.541713000000001	0103000020E61000000100000005000000C4EDD0B018214840B66801DA56C54B40C4EDD0B01821484072FBE59315C74B40DA0242EBE123484072FBE59315C74B40DA0242EBE1234840B66801DA56C54B40C4EDD0B018214840B66801DA56C54B40
8853	Каратмень	7	64	947	48.757697	48.770218999999997	56.022131999999999	56.015264000000002	0103000020E610000001000000050000007FA31D37FC6048403067B62BF4014C407FA31D37FC604840F818AC38D5024C4000E1438996624840F818AC38D5024C4000E14389966248403067B62BF4014C407FA31D37FC6048403067B62BF4014C40
40686	Васюково	7	64	947	48.246160000000003	48.258836000000002	55.714795000000002	55.699406000000003	0103000020E61000000100000005000000ACCABE2B821F48402750C42286D94B40ACCABE2B821F4840132C0E677EDB4B408483BD8921214840132C0E677EDB4B408483BD89212148402750C42286D94B40ACCABE2B821F48402750C42286D94B40
9064	Васильево	7	64	947	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
8966	Большой Кульбаш	7	64	947	48.864640999999999	48.895094	56.035637000000001	56.022801000000001	0103000020E61000000100000005000000EFE3688EAC6E484076A8A624EB024C40EFE3688EAC6E484087C3D2C08F044C40446CB0709272484087C3D2C08F044C40446CB0709272484076A8A624EB024C40EFE3688EAC6E484076A8A624EB024C40
10087	Большое Ходяшево	7	64	947	48.457569999999997	48.485920999999998	55.741987000000002	55.725639999999999	0103000020E61000000100000005000000BBD05CA7913A4840B05582C5E1DC4B40BBD05CA7913A48405187156EF9DE4B4045B8C9A8323E48405187156EF9DE4B4045B8C9A8323E4840B05582C5E1DC4B40BBD05CA7913A4840B05582C5E1DC4B40
8862	Большие Яки	7	64	947	48.770524999999999	48.805441999999999	56.030653000000001	56.010869999999997	0103000020E610000001000000050000000DE02D90A0624840F6402B3064014C400DE02D90A06248401C430070EC034C40946934B9186748401C430070EC034C40946934B918674840F6402B3064014C400DE02D90A0624840F6402B3064014C40
9978	Большие Ширданы	7	64	947	48.437178000000003	48.456257999999998	55.764221999999997	55.753999999999998	0103000020E61000000100000005000000EE43DE72F53748408D976E1283E04B40EE43DE72F53748401D71C806D2E14B40E94482A9663A48401D71C806D2E14B40E94482A9663A48408D976E1283E04B40EE43DE72F53748408D976E1283E04B40
8935	Большие Кургузи	7	64	947	48.822375999999998	48.848956999999999	56.020299999999999	56.002138000000002	0103000020E61000000100000005000000F581E49D43694840180AD80E46004C40F581E49D43694840ED0DBE3099024C40EA5A7B9FAA6C4840ED0DBE3099024C40EA5A7B9FAA6C4840180AD80E46004C40F581E49D43694840180AD80E46004C40
8700	Большие Ключи	7	64	947	48.772365999999998	48.823723000000001	55.992094999999999	55.972800999999997	0103000020E610000001000000050000006B459BE3DC6248400F4240BE84FC4B406B459BE3DC62484037C30DF8FCFE4B4044FB58C16F69484037C30DF8FCFE4B4044FB58C16F6948400F4240BE84FC4B406B459BE3DC6248400F4240BE84FC4B40
10215	Большие Ачасыры	7	64	947	48.327305000000003	48.355826999999998	55.717253999999997	55.700049999999997	0103000020E610000001000000050000009D685721E52948404BC8073D9BD94B409D685721E52948406C76A4FACEDB4B40530438BD8B2D48406C76A4FACEDB4B40530438BD8B2D48404BC8073D9BD94B409D685721E52948404BC8073D9BD94B40
8762	Бишня	7	64	947	48.930039000000001	48.952254000000003	56.002223999999998	55.991672000000001	0103000020E61000000100000005000000958098840B774840F12DAC1BEFFE4B40958098840B77484016A243E048004C401BBE8575E379484016A243E048004C401BBE8575E3794840F12DAC1BEFFE4B40958098840B774840F12DAC1BEFFE4B40
8583	Бело-Безводное	7	64	947	48.757356000000001	48.771341999999997	55.932096999999999	55.923845999999998	0103000020E61000000100000005000000F6B6990AF16048402C45F29540F64B40F6B6990AF160484090D959F44EF74B40FF03AC55BB62484090D959F44EF74B40FF03AC55BB6248402C45F29540F64B40F6B6990AF16048402C45F29540F64B40
10938	Акзигитово	7	64	947	48.055124999999997	48.076720000000002	55.646746	55.631813000000001	0103000020E61000000100000005000000931804560E0748400518963FDFD04B40931804560E074840CF68AB92C8D24B407D7901F6D1094840CF68AB92C8D24B407D7901F6D10948400518963FDFD04B40931804560E0748400518963FDFD04B40
8487	Айша	7	64	947	48.610714999999999	48.642228000000003	55.876959999999997	55.864787999999997	0103000020E610000001000000050000009C16BCE82B4E484093FC885FB1EE4B409C16BCE82B4E484038F3AB3940F04B40AA49F0863452484038F3AB3940F04B40AA49F0863452484093FC885FB1EE4B409C16BCE82B4E484093FC885FB1EE4B40
40640	Осиново	7	64	6906	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
60582	Октябрьский	7	64	6906	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
5853	Шикмамаево	7	64	639	52.239485999999999	52.256203999999997	55.476897999999998	55.462170999999998	0103000020E61000000100000005000000C8EC2C7AA71E4A406E14596B28BB4B40C8EC2C7AA71E4A408FC360FE0ABD4B405C8DEC4ACB204A408FC360FE0ABD4B405C8DEC4ACB204A406E14596B28BB4B40C8EC2C7AA71E4A406E14596B28BB4B40
40524	Чубуклы	7	64	639	51.915247999999998	51.950831000000001	55.204622999999998	55.191915999999999	0103000020E610000001000000050000005DDDB1D826F5494021CA17B490984B405DDDB1D826F5494034812216319A4B40F18288D4B4F9494034812216319A4B40F18288D4B4F9494021CA17B490984B405DDDB1D826F5494021CA17B490984B40
6404	Урсаево	7	64	639	52.227080000000001	52.25562	55.104692	55.084069999999997	0103000020E61000000100000005000000B0C91AF5101D4A40904946CEC28A4B40B0C91AF5101D4A409013268C668D4B400D1AFA27B8204A409013268C668D4B400D1AFA27B8204A40904946CEC28A4B40B0C91AF5101D4A40904946CEC28A4B40
21628	Тюгеевка	7	64	639	51.764771000000003	51.801755	55.140796000000002	55.126919999999998	0103000020E61000000100000005000000F1F62004E4E14940AA9A20EA3E904B40F1F62004E4E149402DB4739A05924B40C63368E89FE649402DB4739A05924B40C63368E89FE64940AA9A20EA3E904B40F1F62004E4E14940AA9A20EA3E904B40
5558	Тонгузино	7	64	639	52.071151	52.086593000000001	55.418424999999999	55.409103999999999	0103000020E61000000100000005000000F209D9791B094A40D65416855DB44B40F209D9791B094A40166A4DF38EB54B400188BB7A150B4A40166A4DF38EB54B400188BB7A150B4A40D65416855DB44B40F209D9791B094A40D65416855DB44B40
6523	Суык-Чишма	7	64	639	51.829360000000001	51.851368999999998	55.179036000000004	55.170774000000002	0103000020E61000000100000005000000274EEE7728EA4940E98024ECDB954B40274EEE7728EA49404167D2A6EA964B4003EACDA8F9EC49404167D2A6EA964B4003EACDA8F9EC4940E98024ECDB954B40274EEE7728EA4940E98024ECDB954B40
6273	Старое Маврино	7	64	639	51.989404	52.013587000000001	55.074154	55.063910999999997	0103000020E610000001000000050000000B444FCAA4FE4940656D533C2E884B400B444FCAA4FE49400D6FD6E07D894B404C530438BD014A400D6FD6E07D894B404C530438BD014A40656D533C2E884B400B444FCAA4FE4940656D533C2E884B40
40833	Село Пусташит	7	64	639	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
61385	Светлое Озеро	7	64	639	52.003346000000001	52.018859999999997	55.195616000000001	55.172203000000003	0103000020E61000000100000005000000454948A46D004A40F5A276BF0A964B40454948A46D004A408449F1F109994B40ED9925016A024A408449F1F109994B40ED9925016A024A40F5A276BF0A964B40454948A46D004A40F5A276BF0A964B40
6097	Сармаш-Баш	7	64	639	52.336081999999998	52.356212999999997	55.228279000000001	55.214706999999997	0103000020E610000001000000050000001B6327BC042B4A40739CDB847B9B4B401B6327BC042B4A408AAE0B3F389D4B407CB43863982D4A408AAE0B3F389D4B407CB43863982D4A40739CDB847B9B4B401B6327BC042B4A40739CDB847B9B4B40
6067	Сарапала	7	64	639	51.897947000000002	51.935110000000002	55.231242000000002	55.219658000000003	0103000020E610000001000000050000004A4563EDEFF249400327DBC01D9C4B404A4563EDEFF2494017BB7D56999D4B40CF143AAFB1F7494017BB7D56999D4B40CF143AAFB1F749400327DBC01D9C4B404A4563EDEFF249400327DBC01D9C4B40
6192	Савалеево	7	64	639	52.001064	52.040132	55.108632	55.092185000000001	0103000020E61000000100000005000000FA997ADD22004A404417D4B7CC8B4B40FA997ADD22004A4048A643A7E78D4B40F4C29D0B23054A4048A643A7E78D4B40F4C29D0B23054A404417D4B7CC8B4B40FA997ADD22004A404417D4B7CC8B4B40
61504	Поручиково	7	64	639	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
5965	Поповка	7	64	639	52.124574000000003	52.137833000000001	55.381951000000001	55.370441	0103000020E6100000010000000500000049F7730AF20F4A407C0C569C6AAF4B4049F7730AF20F4A4056D636C5E3B04B40A0A70183A4114A4056D636C5E3B04B40A0A70183A4114A407C0C569C6AAF4B4049F7730AF20F4A407C0C569C6AAF4B40
5878	Новоспасск	7	64	639	52.195656999999997	52.223793000000001	55.152742000000003	55.132643999999999	0103000020E61000000100000005000000E21DE0490B194A405C01857AFA904B40E21DE0490B194A40E25CC30C8D934B407009C03FA51C4A40E25CC30C8D934B407009C03FA51C4A405C01857AFA904B40E21DE0490B194A405C01857AFA904B40
61473	Нижние Лузы	7	64	639	52.000965000000001	52.021726000000001	55.451996999999999	55.441887000000001	0103000020E6100000010000000500000067B8019F1F004A4087C3D2C08FB84B4067B8019F1F004A40EF71A609DBB94B4088BCE5EAC7024A40EF71A609DBB94B4088BCE5EAC7024A4087C3D2C08FB84B4067B8019F1F004A4087C3D2C08FB84B40
5643	Нижнее Бишево	7	64	639	52.240896999999997	52.259869000000002	55.447448000000001	55.436469000000002	0103000020E610000001000000050000002D5A80B6D51E4A40E25B5837DEB74B402D5A80B6D51E4A408F54DFF945B94B40431F2C6343214A408F54DFF945B94B40431F2C6343214A40E25B5837DEB74B402D5A80B6D51E4A40E25B5837DEB74B40
5709	Куш-Елга	7	64	639	52.191578999999997	52.211494999999999	55.449658999999997	55.435662000000001	0103000020E61000000100000005000000D9CC21A985184A40130EBDC5C3B74B40D9CC21A985184A4010AD156D8EB94B403E22A644121B4A4010AD156D8EB94B403E22A644121B4A40130EBDC5C3B74B40D9CC21A985184A40130EBDC5C3B74B40
40500	Гулькино	7	64	639	51.810423999999998	51.822695000000003	55.088732999999998	55.077612000000002	0103000020E610000001000000050000005EF23FF9BBE749407AE3A430EF894B405EF23FF9BBE74940B9895A9A5B8B4B4097CADB114EE94940B9895A9A5B8B4B4097CADB114EE949407AE3A430EF894B405EF23FF9BBE749407AE3A430EF894B40
61458	Верхние Лузы	7	64	639	51.957047000000003	51.975355	55.457807000000003	55.447167	0103000020E6100000010000000500000012DE1E8480FA4940DB6CACC43CB94B4012DE1E8480FA4940A070766B99BA4B40BB7EC16ED8FC4940A070766B99BA4B40BB7EC16ED8FC4940DB6CACC43CB94B4012DE1E8480FA4940DB6CACC43CB94B40
6389	Алексеевка	7	64	639	51.669486999999997	51.68112	55.158205000000002	55.148508	0103000020E610000001000000050000006F0C01C0B1D54940E198654F02934B406F0C01C0B1D549402788BA0F40944B406553AEF02ED749402788BA0F40944B406553AEF02ED74940E198654F02934B406F0C01C0B1D54940E198654F02934B40
61457	Александровская Слобода	7	64	639	52.103408999999999	52.135568999999997	55.245738000000003	55.224192000000002	0103000020E61000000100000005000000588E90813C0D4A402E03CE52B29C4B40588E90813C0D4A4036B1C057749F4B40FBAC32535A114A4036B1C057749F4B40FBAC32535A114A402E03CE52B29C4B40588E90813C0D4A402E03CE52B29C4B40
40999	Старый Токмак	7	64	6913	51.970880999999999	52.002088000000001	55.400393999999999	55.386220999999999	0103000020E6100000010000000500000065A71FD445FC4940A30392B06FB14B4065A71FD445FC4940DFC14F1C40B34B4066DB696B44004A40DFC14F1C40B34B4066DB696B44004A40A30392B06FB14B4065A71FD445FC4940A30392B06FB14B40
41004	Средний Багряж	7	64	6913	52.220370000000003	52.247508000000003	55.355935000000002	55.347321000000001	0103000020E6100000010000000500000080828B15351C4A40651BB80375AC4B4080828B15351C4A403A4030478FAD4B40CBBF9657AE1F4A403A4030478FAD4B40CBBF9657AE1F4A40651BB80375AC4B4080828B15351C4A40651BB80375AC4B40
40527	Село Новое Маврино	7	64	6913	52.069498000000003	52.086162000000002	55.087017000000003	55.075721000000001	0103000020E6100000010000000500000097917A4FE5084A406A4FC939B1894B4097917A4FE5084A401899805F238B4B4038143E5B070B4A401899805F238B4B4038143E5B070B4A406A4FC939B1894B4097917A4FE5084A406A4FC939B1894B40
41002	Сарсаз Багряж	7	64	6913	52.210039000000002	52.235039999999998	55.332084000000002	55.315586000000003	0103000020E6100000010000000500000039F1D58EE21A4A40A9893E1F65A84B4039F1D58EE21A4A402FC37FBA81AA4B403CA06CCA151E4A402FC37FBA81AA4B403CA06CCA151E4A40A9893E1F65A84B4039F1D58EE21A4A40A9893E1F65A84B40
41006	Керекес	7	64	6913	51.981507999999998	52.004351999999997	55.5154	55.500621000000002	0103000020E610000001000000050000009561DC0DA2FD49406D58535914C04B409561DC0DA2FD4940E02D90A0F8C14B400AD6389B8E004A40E02D90A0F8C14B400AD6389B8E004A406D58535914C04B409561DC0DA2FD49406D58535914C04B40
41005	Карманово	7	64	6913	52.045935	52.063282000000001	55.474035999999998	55.460940999999998	0103000020E61000000100000005000000F25EB532E1054A4059315C1D00BB4B40F25EB532E1054A4036902E36ADBC4B407636E49F19084A4036902E36ADBC4B407636E49F19084A4059315C1D00BB4B40F25EB532E1054A4059315C1D00BB4B40
40691	Кадырово	7	64	6913	52.098235000000003	52.121653999999999	55.456795999999997	55.445318999999998	0103000020E610000001000000050000004A29E8F6920C4A40CAA4863600B94B404A29E8F6920C4A40C878944A78BA4B40BBB6B75B920F4A40C878944A78BA4B40BBB6B75B920F4A40CAA4863600B94B404A29E8F6920C4A40CAA4863600B94B40
41015	Имянлебаш	7	64	6913	51.810369999999999	51.834767999999997	55.356164999999997	55.340220000000002	0103000020E610000001000000050000006BD44334BAE74940FAB836548CAB4B406BD44334BAE749406B7D91D096AD4B40A8DF85ADD9EA49406B7D91D096AD4B40A8DF85ADD9EA4940FAB836548CAB4B406BD44334BAE74940FAB836548CAB4B40
41017	Зычебаш	7	64	6913	52.324871000000002	52.347310999999998	55.461767999999999	55.451904999999996	0103000020E610000001000000050000009C35785F95294A400EF3E505D8B94B409C35785F95294A406F2BBD361BBB4B404145D5AF742C4A406F2BBD361BBB4B404145D5AF742C4A400EF3E505D8B94B409C35785F95294A400EF3E505D8B94B40
40480	Заинск	7	64	6913	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
41016	Дурт-Мунча	7	64	6913	52.297480999999998	52.326253999999999	55.440524000000003	55.428516000000002	0103000020E6100000010000000500000037177FDB13264A4008E8BE9CD9B64B4037177FDB13264A40338D261763B84B403718EAB0C2294A40338D261763B84B403718EAB0C2294A4008E8BE9CD9B64B4037177FDB13264A4008E8BE9CD9B64B40
41000	Вторая Бугульда	7	64	6913	52.001738000000003	52.008287000000003	55.339118999999997	55.330342999999999	0103000020E610000001000000050000008A9466F338004A4034BBEEAD48AA4B408A9466F338004A40E2395B4068AB4B40B1FD648C0F014A40E2395B4068AB4B40B1FD648C0F014A4034BBEEAD48AA4B408A9466F338004A4034BBEEAD48AA4B40
41009	Верхний Налим	7	64	6913	52.240913999999997	52.259779000000002	55.269067	55.255071999999998	0103000020E6100000010000000500000003931B45D61E4A400A100533A6A04B4003931B45D61E4A4067B796C970A24B400398327040214A4067B796C970A24B400398327040214A400A100533A6A04B4003931B45D61E4A400A100533A6A04B40
41001	Верхний Багряж	7	64	6913	52.283450000000002	52.305863000000002	55.347259000000001	55.336339000000002	0103000020E610000001000000050000008E06F01648244A4047AF06280DAB4B408E06F01648244A40EF1EA0FB72AC4B403A07CF8426274A40EF1EA0FB72AC4B403A07CF8426274A4047AF06280DAB4B408E06F01648244A4047AF06280DAB4B40
41014	Верхние Шипки	7	64	6913	51.848306000000001	51.879854999999999	55.338991	55.320376000000003	0103000020E6100000010000000500000013807F4A95EC49402F36AD1402A94B4013807F4A95EC4940B5519D0E64AB4B406D1CB1169FF04940B5519D0E64AB4B406D1CB1169FF049402F36AD1402A94B4013807F4A95EC49402F36AD1402A94B40
41013	Верхние Пинячи	7	64	6913	52.105331999999997	52.117638999999997	55.508386000000002	55.500295000000001	0103000020E61000000100000005000000739CDB847B0D4A4019ADA3AA09C04B40739CDB847B0D4A4044DFDDCA12C14B40F8DD74CB0E0F4A4044DFDDCA12C14B40F8DD74CB0E0F4A4019ADA3AA09C04B40739CDB847B0D4A4019ADA3AA09C04B40
41008	Бухарай	7	64	6913	52.303482000000002	52.327305000000003	55.148291999999998	55.139411000000003	0103000020E610000001000000050000005C76887FD8264A40F1D93A38D8914B405C76887FD8264A401421753BFB924B409D685721E5294A401421753BFB924B409D685721E5294A40F1D93A38D8914B405C76887FD8264A40F1D93A38D8914B40
41010	Бура-Кирта	7	64	6913	52.205475999999997	52.236503999999996	55.491951999999998	55.486336000000001	0103000020E61000000100000005000000730E9E094D1A4A40096F0F4240BE4B40730E9E094D1A4A40D4997B48F8BE4B40C4AF58C3451E4A40D4997B48F8BE4B40C4AF58C3451E4A40096F0F4240BE4B40730E9E094D1A4A40096F0F4240BE4B40
41003	Бегишево	7	64	6913	52.020603000000001	52.046968	55.494782000000001	55.480291000000001	0103000020E6100000010000000500000089997D1EA3024A4015C8EC2C7ABD4B4089997D1EA3024A4022533E0455BF4B40B1FA230C03064A4022533E0455BF4B40B1FA230C03064A4015C8EC2C7ABD4B4089997D1EA3024A4015C8EC2C7ABD4B40
41018	Ахметьево	7	64	6913	52.149070999999999	52.175615999999998	55.466672000000003	55.457112000000002	0103000020E6100000010000000500000019E42EC214134A40F94D61A582BA4B4019E42EC214134A40BEFA78E8BBBB4B40C153C8957A164A40BEFA78E8BBBB4B40C153C8957A164A40F94D61A582BA4B4019E42EC214134A40F94D61A582BA4B40
40998	Аксарино	7	64	6913	51.899679999999996	51.927455999999999	55.348922999999999	55.333584000000002	0103000020E61000000100000005000000C16ED8B628F34940043C69E1B2AA4B40C16ED8B628F349403EE94482A9AC4B404F3DD2E0B6F649403EE94482A9AC4B404F3DD2E0B6F64940043C69E1B2AA4B40C16ED8B628F34940043C69E1B2AA4B40
2234	Малоречинский	7	64	173	51.857728999999999	51.874051999999999	55.829268999999996	55.820860000000003	0103000020E6100000010000000500000057EA5910CAED49401B4CC3F011E94B4057EA5910CAED4940164B917C25EA4B406F8099EFE0EF4940164B917C25EA4B406F8099EFE0EF49401B4CC3F011E94B4057EA5910CAED49401B4CC3F011E94B40
2467	Лекарево	7	64	173	51.797066000000001	51.829917000000002	55.791127000000003	55.775505000000003	0103000020E610000001000000050000007460394206E64940377172BF43E34B407460394206E64940C6FD47A643E54B407DB262B83AEA4940C6FD47A643E54B407DB262B83AEA4940377172BF43E34B407460394206E64940377172BF43E34B40
2299	Большой Шурняк	7	64	173	51.554071999999998	51.580283999999999	55.892254000000001	55.877172000000002	0103000020E610000001000000050000008DD0CFD4EBC64940C47B0E2C47F04B408DD0CFD4EBC64940D3DC0A6135F24B402F3201BF46CA4940D3DC0A6135F24B402F3201BF46CA4940C47B0E2C47F04B408DD0CFD4EBC64940C47B0E2C47F04B40
2191	Большая Качка	7	64	173	51.949275999999998	51.973835999999999	55.825370999999997	55.812631000000003	0103000020E6100000010000000500000058703FE081F949409F5BE84A04E84B4058703FE081F949408D08C6C1A5E94B406FD575A8A6FC49408D08C6C1A5E94B406FD575A8A6FC49409F5BE84A04E84B4058703FE081F949409F5BE84A04E84B40
40995	Яковлево	7	64	1949	51.544558000000002	51.565246999999999	55.748578999999999	55.732773000000002	0103000020E6100000010000000500000039639813B4C5494027327381CBDD4B4039639813B4C5494077BCC96FD1DF4B40C09481035AC8494077BCC96FD1DF4B40C09481035AC8494027327381CBDD4B4039639813B4C5494027327381CBDD4B40
40903	Хлыстово	7	64	1949	51.953885	51.985083000000003	55.807611999999999	55.79768	0103000020E610000001000000050000008E9257E718FA49402E56D4601AE64B408E9257E718FA4940B7ED7BD45FE74B403C6C223317FE4940B7ED7BD45FE74B403C6C223317FE49402E56D4601AE64B408E9257E718FA49402E56D4601AE64B40
40994	Татарский Дюм-Дюм	7	64	1949	51.542825000000001	51.572200000000002	55.856341	55.842509	0103000020E61000000100000005000000C139234A7BC54940F7CABC55D7EB4B40C139234A7BC54940AA9CF6949CED4B40B7627FD93DC94940AA9CF6949CED4B40B7627FD93DC94940F7CABC55D7EB4B40C139234A7BC54940F7CABC55D7EB4B40
40992	Танайка	7	64	1949	51.880186999999999	51.946114000000001	55.749257999999998	55.732838999999998	0103000020E61000000100000005000000A3AEB5F7A9F04940DE1D19ABCDDD4B40A3AEB5F7A9F049401822A7AFE7DF4B40D52478431AF949401822A7AFE7DF4B40D52478431AF94940DE1D19ABCDDD4B40A3AEB5F7A9F04940DE1D19ABCDDD4B40
40991	Старый Юраш	7	64	1949	51.722946	51.749949000000001	55.918666000000002	55.896397999999998	0103000020E610000001000000050000001363997E89DC494093196F2BBDF24B401363997E89DC49403CF9F4D896F54B407E552E54FEDF49403CF9F4D896F54B407E552E54FEDF494093196F2BBDF24B401363997E89DC494093196F2BBDF24B40
40990	Старый Куклюк	7	64	1949	51.588647999999999	51.606228000000002	55.915593999999999	55.902484999999999	0103000020E610000001000000050000008B6D52D158CB4940B610E4A084F34B408B6D52D158CB4940F834272F32F54B40B2F50CE198CD4940F834272F32F54B40B2F50CE198CD4940B610E4A084F34B408B6D52D158CB4940B610E4A084F34B40
40985	Старая Мурзиха	7	64	1949	51.639420999999999	51.645789999999998	55.736502999999999	55.732362000000002	0103000020E6100000010000000500000014B01D8CD8D14940A56ABB09BEDD4B4014B01D8CD8D14940F433F5BA45DE4B40BB0A293FA9D24940F433F5BA45DE4B40BB0A293FA9D24940A56ABB09BEDD4B4014B01D8CD8D14940A56ABB09BEDD4B40
40987	Поспелово	7	64	1949	52.218339999999998	52.236503999999996	55.780642999999998	55.770764999999997	0103000020E610000001000000050000004EB4AB90F21B4A4062F3716DA8E24B404EB4AB90F21B4A40F86C1D1CECE34B40C4AF58C3451E4A40F86C1D1CECE34B40C4AF58C3451E4A4062F3716DA8E24B404EB4AB90F21B4A4062F3716DA8E24B40
40986	Покровское	7	64	1949	51.704512000000001	51.729719000000003	55.717508000000002	55.698816999999998	0103000020E61000000100000005000000DDD1FF722DDA4940C571E0D572D94B40DDD1FF722DDA4940274F594DD7DB4B408A22A46E67DD4940274F594DD7DB4B408A22A46E67DD4940C571E0D572D94B40DDD1FF722DDA4940C571E0D572D94B40
40268	Морты	7	64	1949	51.713746999999998	51.739258999999997	55.820262999999997	55.801202000000004	0103000020E610000001000000050000001E4FCB0F5CDB4940B2BE81C98DE64B401E4FCB0F5CDB4940368FC360FEE84B400723F609A0DE4940368FC360FEE84B400723F609A0DE4940B2BE81C98DE64B401E4FCB0F5CDB4940B2BE81C98DE64B40
40989	Мальцево	7	64	1949	52.168222999999998	52.18927	55.749085999999998	55.743183000000002	0103000020E61000000100000005000000AEB7CD5488154A40BAF8DB9E20DF4B40AEB7CD5488154A401BF2CF0CE2DF4B40950ED6FF39184A401BF2CF0CE2DF4B40950ED6FF39184A40BAF8DB9E20DF4B40AEB7CD5488154A40BAF8DB9E20DF4B40
40996	Котловка	7	64	1949	51.651099000000002	51.677185999999999	55.644297999999999	55.631020999999997	0103000020E61000000100000005000000AABA473657D349406B0BCF4BC5D04B40AABA473657D3494069705B5B78D24B408FA7E507AED6494069705B5B78D24B408FA7E507AED649406B0BCF4BC5D04B40AABA473657D349406B0BCF4BC5D04B40
40982	Костенеево	7	64	1949	51.588396000000003	51.613512999999998	55.704746999999998	55.691633000000003	0103000020E61000000100000005000000728C648F50CB4940CDEA1D6E87D84B40728C648F50CB4940207A522635DA4B40DE550F9887CE4940207A522635DA4B40DE550F9887CE4940CDEA1D6E87D84B40728C648F50CB4940CDEA1D6E87D84B40
40993	Колосовка	7	64	1949	51.925443999999999	51.952914999999997	55.779504000000003	55.769241000000001	0103000020E61000000100000005000000C423F1F274F6494005DF347D76E24B40C423F1F274F64940F48C7DC9C6E34B40156F641EF9F94940F48C7DC9C6E34B40156F641EF9F9494005DF347D76E24B40C423F1F274F6494005DF347D76E24B40
40980	Гари	7	64	1949	52.010029000000003	52.030484000000001	55.872905000000003	55.867213	0103000020E610000001000000050000007C8159A148014A4041D5E8D500EF4B407C8159A148014A40E8C1DD59BBEF4B40908653E6E6034A40E8C1DD59BBEF4B40908653E6E6034A4041D5E8D500EF4B407C8159A148014A4041D5E8D500EF4B40
40902	Большое Елово	7	64	1949	51.552931000000001	51.580993999999997	55.795994999999998	55.786833999999999	0103000020E61000000100000005000000E8F86871C6C64940C0B0FCF9B6E44B40E8F86871C6C64940C763062AE3E54B400B96EA025ECA4940C763062AE3E54B400B96EA025ECA4940C0B0FCF9B6E44B40E8F86871C6C64940C0B0FCF9B6E44B40
40236	Большие Армалы	7	64	1949	51.755600000000001	51.770933999999997	55.781550000000003	55.766278	0103000020E61000000100000005000000C66D3480B7E0494078D2C26515E24B40C66D3480B7E049402B1895D409E44B40EEAF1EF7ADE249402B1895D409E44B40EEAF1EF7ADE2494078D2C26515E24B40C66D3480B7E0494078D2C26515E24B40
40239	Бехтерево	7	64	1949	52.112625999999999	52.133656000000002	55.84075	55.822989	0103000020E61000000100000005000000F3565D876A0E4A40DFFB1BB457E94B40F3565D876A0E4A40560E2DB29DEB4B400475CAA31B114A40560E2DB29DEB4B400475CAA31B114A40DFFB1BB457E94B40F3565D876A0E4A40DFFB1BB457E94B40
40979	Альметьево	7	64	1949	51.722793000000003	51.743606999999997	55.893183000000001	55.880046	0103000020E610000001000000050000008D63247B84DC4940E17CEA58A5F04B408D63247B84DC4940ED2B0FD253F24B40D009A1832EDF4940ED2B0FD253F24B40D009A1832EDF4940E17CEA58A5F04B408D63247B84DC4940E17CEA58A5F04B40
2857	Шланга	7	64	376	47.377265000000001	47.411454999999997	54.823537999999999	54.806283000000001	0103000020E61000000100000005000000757632384AB047400F29064834674B40757632384AB04740B28174B169694B404963B48EAAB44740B28174B169694B404963B48EAAB447400F29064834674B40757632384AB047400F29064834674B40
3258	Чувашское Дрожжаное	7	64	376	47.511769999999999	47.539411000000001	54.719408999999999	54.698390000000003	0103000020E610000001000000050000007689EAAD81C147403EEDF0D764594B407689EAAD81C147405AB91798155C4B40240D6E6B0BC547405AB91798155C4B40240D6E6B0BC547403EEDF0D764594B407689EAAD81C147403EEDF0D764594B40
2404	Чувашская Бездна	7	64	376	47.433095000000002	47.455714999999998	54.687603000000003	54.668384000000003	0103000020E61000000100000005000000D3872EA86FB74740B8955E9B8D554B40D3872EA86FB74740D5D0066003584B40F8A57EDE54BA4740D5D0066003584B40F8A57EDE54BA4740B8955E9B8D554B40D3872EA86FB74740B8955E9B8D554B40
3976	Чепкас-Ильметьево	7	64	376	47.722092000000004	47.752859000000001	54.902656	54.882862000000003	0103000020E61000000100000005000000045ABA826DDC4740CA703C9F01714B40045ABA826DDC4740E3C4573B8A734B40E8BF07AF5DE04740E3C4573B8A734B40E8BF07AF5DE04740CA703C9F01714B40045ABA826DDC4740CA703C9F01714B40
3875	Хорновар Шигали	7	64	376	47.684659000000003	47.717312999999997	54.822848	54.812561000000002	0103000020E61000000100000005000000BFF4F6E7A2D74740A680B4FF01684B40BFF4F6E7A2D747401DCA501553694B4071FF91E9D0DB47401DCA501553694B4071FF91E9D0DB4740A680B4FF01684B40BFF4F6E7A2D74740A680B4FF01684B40
3324	Хайбулдино	7	64	376	47.516477000000002	47.530751000000002	54.728394000000002	54.719773000000004	0103000020E610000001000000050000006F1118EB1BC247409CC58B85215C4B406F1118EB1BC24740234DBC033C5D4B40DFA815A6EFC34740234DBC033C5D4B40DFA815A6EFC347409CC58B85215C4B406F1118EB1BC247409CC58B85215C4B40
3748	Убей	7	64	376	47.752608000000002	47.779935000000002	54.793230999999999	54.781171000000001	0103000020E610000001000000050000009F5A7D7555E04740B4CA4C69FD634B409F5A7D7555E047403196E99788654B40BD00FBE8D4E347403196E99788654B40BD00FBE8D4E34740B4CA4C69FD634B409F5A7D7555E04740B4CA4C69FD634B40
2101	Татарские Шатрашаны	7	64	376	47.375458999999999	47.400621000000001	54.554133	54.546039	0103000020E6100000010000000500000093FE5E0A0FB0474097AB1F9BE4454B4093FE5E0A0FB04740335184D4ED464B40A08B868C47B34740335184D4ED464B40A08B868C47B3474097AB1F9BE4454B4093FE5E0A0FB0474097AB1F9BE4454B40
3017	Татарские Тюки	7	64	376	47.413539	47.430354999999999	54.874932000000001	54.859487000000001	0103000020E610000001000000050000006E4F90D8EEB44740282B86AB036E4B406E4F90D8EEB44740A81C93C5FD6F4B40C55565DF15B74740A81C93C5FD6F4B40C55565DF15B74740282B86AB036E4B406E4F90D8EEB44740282B86AB036E4B40
2680	Татарская Бездна	7	64	376	47.408867999999998	47.443767000000001	54.712014000000003	54.691881000000002	0103000020E61000000100000005000000C23060C955B44740A5DC7D8E8F584B40C23060C955B44740A7255646235B4B40A305685BCDB84740A7255646235B4B40A305685BCDB84740A5DC7D8E8F584B40C23060C955B44740A5DC7D8E8F584B40
2451	Старые Чукалы	7	64	376	47.521057999999996	47.556379999999997	54.664259999999999	54.637855999999999	0103000020E61000000100000005000000DAA84E07B2C2474058C7F143A5514B40DAA84E07B2C247403E05C07806554B400113B87537C747403E05C07806554B400113B87537C7474058C7F143A5514B40DAA84E07B2C2474058C7F143A5514B40
2981	Старые Какерли	7	64	376	47.500369999999997	47.537712999999997	54.844067000000003	54.820357999999999	0103000020E6100000010000000500000023F3C81F0CC047408881AE7D01694B4023F3C81F0CC04740015130630A6C4B4028D192C7D3C44740015130630A6C4B4028D192C7D3C447408881AE7D01694B4023F3C81F0CC047408881AE7D01694B40
3140	Старые Ишли	7	64	376	47.470213999999999	47.496003999999999	54.816586999999998	54.799168000000002	0103000020E61000000100000005000000880FECF82FBC47403F0114234B664B40880FECF82FBC47405CAB3DEC85684B40B4571F0F7DBF47405CAB3DEC85684B40B4571F0F7DBF47403F0114234B664B40880FECF82FBC47403F0114234B664B40
1990	Старое Шаймурзино	7	64	376	47.948583999999997	48.007154999999997	54.764063999999998	54.742341000000003	0103000020E6100000010000000500000022C154336BF947406FBDA607055F4B4022C154336BF94740850662D9CC614B405E807D74EA004840850662D9CC614B405E807D74EA0048406FBDA607055F4B4022C154336BF947406FBDA607055F4B40
3373	Старое Ильмово	7	64	376	47.567599999999999	47.589635999999999	54.696033	54.683273	0103000020E61000000100000005000000D49AE61DA7C84740B29E5A7D75574B40D49AE61DA7C84740E8F7FD9B17594B40AA45443179CB4740E8F7FD9B17594B40AA45443179CB4740B29E5A7D75574B40D49AE61DA7C84740B29E5A7D75574B40
3587	Старое Дуваново	7	64	376	47.673394000000002	47.691343000000003	54.787505000000003	54.779743000000003	0103000020E610000001000000050000004CA94BC631D6474079245E9ECE634B404CA94BC631D64740DF37BEF6CC644B40C6A86BED7DD84740DF37BEF6CC644B40C6A86BED7DD8474079245E9ECE634B404CA94BC631D6474079245E9ECE634B40
3446	Старое Дрожжаное	7	64	376	47.532611000000003	47.577607	54.735199000000001	54.717422999999997	0103000020E61000000100000005000000B43EE5982CC44740F8325184D45B4B40B43EE5982CC44740A58636001B5E4B406878B306EFC94740A58636001B5E4B406878B306EFC94740F8325184D45B4B40B43EE5982CC44740F8325184D45B4B40
3687	Старая Задоровка	7	64	376	47.620789000000002	47.654682999999999	54.714078999999998	54.700242000000003	0103000020E61000000100000005000000B85B920376CF474090A4A487A1594B40B85B920376CF474054E1CFF0665B4B40A31F0DA7CCD3474054E1CFF0665B4B40A31F0DA7CCD3474090A4A487A1594B40B85B920376CF474090A4A487A1594B40
3791	Новый Убей	7	64	376	47.769604000000001	47.803803000000002	54.782479000000002	54.759929	0103000020E61000000100000005000000766F456282E2474018247D5A45614B40766F456282E247404567994528644B409EB64604E3E647404567994528644B409EB64604E3E6474018247D5A45614B40766F456282E2474018247D5A45614B40
2558	Новые Чукалы	7	64	376	47.610539000000003	47.639302999999998	54.648724000000001	54.631127999999997	0103000020E610000001000000050000005EF7562426CE474081CB63CDC8504B405EF7562426CE4740AE10566309534B400A9E42AED4D14740AE10566309534B400A9E42AED4D1474081CB63CDC8504B405EF7562426CE474081CB63CDC8504B40
3223	Новые Какерли	7	64	376	47.569423	47.615211000000002	54.828206000000002	54.809370000000001	0103000020E610000001000000050000008C4B55DAE2C84740882EA86F99674B408C4B55DAE2C84740ED2C7AA7026A4B40DA91EA3BBFCE4740ED2C7AA7026A4B40DA91EA3BBFCE4740882EA86F99674B408C4B55DAE2C84740882EA86F99674B40
3091	Новые Ишли	7	64	376	47.540812000000003	47.567509999999999	54.803460000000001	54.787292000000001	0103000020E6100000010000000500000066A4DE5339C547408333F8FBC5644B4066A4DE5339C5474074D2FBC6D7664B409413ED2AA4C8474074D2FBC6D7664B409413ED2AA4C847408333F8FBC5644B4066A4DE5339C547408333F8FBC5644B40
2289	Новое Чекурское	7	64	376	47.465318000000003	47.491522000000003	54.571125000000002	54.557422000000003	0103000020E61000000100000005000000BD1E4C8A8FBB47401409A69A59474B40BD1E4C8A8FBB4740C976BE9F1A494B40DCA16131EABE4740C976BE9F1A494B40DCA16131EABE47401409A69A59474B40BD1E4C8A8FBB47401409A69A59474B40
2523	Новое Ильмово	7	64	376	47.613225	47.654584	54.678139999999999	54.663594000000003	0103000020E61000000100000005000000780B24287ECE474032E9EFA5F0544B40780B24287ECE4740020EA14ACD564B40103E9468C9D34740020EA14ACD564B40103E9468C9D3474032E9EFA5F0544B40780B24287ECE474032E9EFA5F0544B40
3538	Новое Дрожжаное	7	64	376	47.546283000000003	47.572361000000001	54.745797000000003	54.731310999999998	0103000020E610000001000000050000002EAEF199ECC547403F1A4E999B5D4B402EAEF199ECC547403B3AAE46765F4B40C040102043C947403B3AAE46765F4B40C040102043C947403F1A4E999B5D4B402EAEF199ECC547403F1A4E999B5D4B40
2632	Нижний Каракитан	7	64	376	47.320993999999999	47.347071999999997	54.735235000000003	54.721041999999997	0103000020E610000001000000050000002A1BD65416A947406E85B01A4B5C4B402A1BD65416A94740F2EF332E1C5E4B40BCADF4DA6CAC4740F2EF332E1C5E4B40BCADF4DA6CAC47406E85B01A4B5C4B402A1BD65416A947406E85B01A4B5C4B40
2174	Нижнее Чекурское	7	64	376	47.399687	47.425702000000001	54.599769000000002	54.58954	0103000020E6100000010000000500000074D190F128B3474088D7F50B764B4B4074D190F128B34740CB13083BC54C4B40C0EB33677DB64740CB13083BC54C4B40C0EB33677DB6474088D7F50B764B4B4074D190F128B3474088D7F50B764B4B40
2783	Мочалей	7	64	376	47.377372999999999	47.418390000000002	54.781877000000001	54.758693000000001	0103000020E610000001000000050000005BB22AC24DB04740215A2BDA1C614B405BB22AC24DB047404F3FA88B14644B409A7CB3CD8DB547404F3FA88B14644B409A7CB3CD8DB54740215A2BDA1C614B405BB22AC24DB04740215A2BDA1C614B40
2740	Матаки	7	64	376	47.415883000000001	47.468983000000001	54.790708000000002	54.769678999999996	0103000020E610000001000000050000002FFB75A73BB5474080B56AD784624B402FFB75A73BB54740C15774EB35654B40A3B08BA207BC4740C15774EB35654B40A3B08BA207BC474080B56AD784624B402FFB75A73BB5474080B56AD784624B40
3844	Малый Убей	7	64	376	47.781793999999998	47.811897000000002	54.789524	54.774788999999998	0103000020E61000000100000005000000C11A67D311E44740782634492C634B40C11A67D311E447401CB4571F0F654B403A5CAB3DECE747401CB4571F0F654B403A5CAB3DECE74740782634492C634B40C11A67D311E44740782634492C634B40
4050	Малая Цильна	7	64	376	47.850740000000002	47.895080999999998	54.778574999999996	54.758105999999998	0103000020E6100000010000000500000014B35E0CE5EC474060730E9E09614B4014B35E0CE5EC4740D93D7958A8634B40AF22A30392F24740D93D7958A8634B40AF22A30392F2474060730E9E09614B4014B35E0CE5EC474060730E9E09614B40
3941	Коршанга Шигали	7	64	376	47.632773	47.653362000000001	54.859979000000003	54.851354999999998	0103000020E610000001000000050000005A65A6B4FED047409E245D33F96C4B405A65A6B4FED04740971FB8CA136E4B407E39B35DA1D34740971FB8CA136E4B407E39B35DA1D347409E245D33F96C4B405A65A6B4FED047409E245D33F96C4B40
2215	Городище	7	64	376	47.503971999999997	47.549408999999997	54.593510000000002	54.568547000000002	0103000020E61000000100000005000000C30C8D2782C04740959EE925C6484B40C30C8D2782C04740ABECBB22F84B4B406490BB0853C64740ABECBB22F84B4B406490BB0853C64740959EE925C6484B40C30C8D2782C04740959EE925C6484B40
61381	Бурундуки	7	64	376	47.257779999999997	48.114691999999998	54.909753000000002	54.496384999999997	0103000020E610000001000000050000000CC85EEFFEA04740CB9C2E8B893F4B400CC85EEFFEA047400D384BC972744B40718E3A3AAE0E48400D384BC972744B40718E3A3AAE0E4840CB9C2E8B893F4B400CC85EEFFEA04740CB9C2E8B893F4B40
1932	Большая Цильна	7	64	376	47.836087999999997	47.871698000000002	54.699762999999997	54.679676000000001	0103000020E61000000100000005000000FD497CEE04EB474024F0879FFF564B40FD497CEE04EB4740B5F97FD591594B408BFED0CC93EF4740B5F97FD591594B408BFED0CC93EF474024F0879FFF564B40FD497CEE04EB474024F0879FFF564B40
2329	Большая Акса	7	64	376	47.481406999999997	47.523502000000001	54.636980999999999	54.616506999999999	0103000020E6100000010000000500000061889CBE9EBD4740A6608DB3E94E4B4061889CBE9EBD47403196E99788514B40FFB1101D02C347403196E99788514B40FFB1101D02C34740A6608DB3E94E4B4061889CBE9EBD4740A6608DB3E94E4B40
3657	Алешкин Саплык	7	64	376	47.632745999999997	47.659219	54.758989	54.745078999999997	0103000020E61000000100000005000000605628D2FDD04740DBF7A8BF5E5F4B40605628D2FDD047400A83328D26614B406FF3C64961D447400A83328D26614B406FF3C64961D44740DBF7A8BF5E5F4B40605628D2FDD04740DBF7A8BF5E5F4B40
61191	совхоз Бирюлинский	7	64	13	49.360304999999997	49.408723999999999	55.98359	55.970649999999999	0103000020E61000000100000005000000EACA67791EAE484063EE5A423EFC4B40EACA67791EAE48401956F146E6FD4B408F8B6A1151B448401956F146E6FD4B408F8B6A1151B4484063EE5A423EFC4B40EACA67791EAE484063EE5A423EFC4B40
31311	Янга-Аул	7	64	13	48.902163999999999	48.917247000000003	56.119925000000002	56.10913	0103000020E6100000010000000500000074D0251C7A7348409981CAF8F70D4C4074D0251C7A734840857CD0B3590F4C4054AD855968754840857CD0B3590F4C4054AD8559687548409981CAF8F70D4C4074D0251C7A7348409981CAF8F70D4C40
649	Ямашурма	7	64	13	49.585872000000002	49.620457000000002	55.982833999999997	55.967908999999999	0103000020E6100000010000000500000031D28BDAFDCA484085402E71E4FB4B4031D28BDAFDCA4840CCB22781CDFD4B4082C98D226BCF4840CCB22781CDFD4B4082C98D226BCF484085402E71E4FB4B4031D28BDAFDCA484085402E71E4FB4B40
31980	Юртыш	7	64	13	48.905020999999998	48.934935000000003	56.052833999999997	56.039942000000003	0103000020E61000000100000005000000BB9866BAD773484051DEC7D11C054C40BB9866BAD7734840F50EB743C3064C40617138F3AB774840F50EB743C3064C40617138F3AB77484051DEC7D11C054C40BB9866BAD773484051DEC7D11C054C40
61395	Шуманы	7	64	13	49.332906000000001	49.351222999999997	56.117460999999999	56.105499999999999	0103000020E610000001000000050000003352EFA99CAA48402FDD2406810D4C403352EFA99CAA484019C748F6080F4C402F4D11E0F4AC484019C748F6080F4C402F4D11E0F4AC48402FDD2406810D4C403352EFA99CAA48402FDD2406810D4C40
577	Шапши	7	64	13	49.485304999999997	49.508994000000001	55.959591000000003	55.946838999999997	0103000020E61000000100000005000000EACA67791EBE4840E6C9350532F94B40EACA67791EBE48409A44BDE0D3FA4B401CEE23B726C148409A44BDE0D3FA4B401CEE23B726C14840E6C9350532F94B40EACA67791EBE4840E6C9350532F94B40
31746	Чувашли	7	64	13	49.000134000000003	49.018118999999999	56.071342999999999	56.058684999999997	0103000020E6100000010000000500000010CF12640480484004E275FD82074C4010CF12640480484036E675C421094C40D63730B95182484036E675C421094C40D63730B95182484004E275FD82074C4010CF12640480484004E275FD82074C40
61376	Чирши	7	64	13	49.205471000000003	49.239849999999997	56.091898999999998	56.084063999999998	0103000020E6100000010000000500000062A3ACDF4C9A4840AE62F19BC20A4C4062A3ACDF4C9A48407EC4AF58C30B4C4009F9A067B39E48407EC4AF58C30B4C4009F9A067B39E4840AE62F19BC20A4C4062A3ACDF4C9A4840AE62F19BC20A4C40
1591	Чернышевка	7	64	13	49.282905999999997	49.298285	55.969642	55.963531000000003	0103000020E61000000100000005000000CCEB884336A4484052D7DAFB54FB4B40CCEB884336A44840FD69A33A1DFC4B4095F1EF332EA64840FD69A33A1DFC4B4095F1EF332EA6484052D7DAFB54FB4B40CCEB884336A4484052D7DAFB54FB4B40
1639	Чепчуги	7	64	13	49.502903000000003	49.530500000000004	56.008017000000002	55.994616999999998	0103000020E61000000100000005000000B80721205FC04840D7851F9C4FFF4B40B80721205FC04840F16778B306014C4096438B6CE7C34840F16778B306014C4096438B6CE7C34840D7851F9C4FFF4B40B80721205FC04840D7851F9C4FFF4B40
1524	Усады	7	64	13	49.294269999999997	49.317383	55.999696999999998	55.988695999999997	0103000020E61000000100000005000000D218ADA3AAA54840CFD72C978DFE4B40D218ADA3AAA5484064744012F6FF4B4037A79201A0A8484064744012F6FF4B4037A79201A0A84840CFD72C978DFE4B40D218ADA3AAA54840CFD72C978DFE4B40
1399	Ташлы-Ковали	7	64	13	49.456702999999997	49.490408000000002	56.073213000000003	56.060997	0103000020E61000000100000005000000177E703E75BA4840BA13ECBFCE074C40177E703E75BA48402F52280B5F094C4030D978B0C5BE48402F52280B5F094C4030D978B0C5BE4840BA13ECBFCE074C40177E703E75BA4840BA13ECBFCE074C40
1752	Татарская Айша	7	64	13	49.668588999999997	49.689349	56.043984999999999	56.036256000000002	0103000020E6100000010000000500000090BB085394D5484053245F09A4044C4090BB085394D54840DD41EC4CA1054C40E14389963CD84840DD41EC4CA1054C40E14389963CD8484053245F09A4044C4090BB085394D5484053245F09A4044C40
1175	Суксу	7	64	13	49.106566999999998	49.129249000000002	56.102820000000001	56.092028999999997	0103000020E610000001000000050000009AEAC9FCA38D48404CA4349BC70B4C409AEAC9FCA38D4840F7AFAC34290D4C403605323B8B904840F7AFAC34290D4C403605323B8B9048404CA4349BC70B4C409AEAC9FCA38D48404CA4349BC70B4C40
1136	Средний Алат	7	64	13	49.197988000000002	49.217678999999997	56.178268000000003	56.168767000000003	0103000020E610000001000000050000000F80B8AB5799484070D234289A154C400F80B8AB5799484030F65E7CD1164C405303CDE7DC9B484030F65E7CD1164C405303CDE7DC9B484070D234289A154C400F80B8AB5799484070D234289A154C40
1362	Сосновка	7	64	13	49.441054000000001	49.459209000000001	56.023274000000001	56.009360999999998	0103000020E610000001000000050000008FE21C7574B84840CE6DC2BD32014C408FE21C7574B848406E6C76A4FA024C40B2834A5CC7BA48406E6C76A4FA024C40B2834A5CC7BA4840CE6DC2BD32014C408FE21C7574B84840CE6DC2BD32014C40
999	Семиозерка	7	64	13	49.093496000000002	49.106045999999999	55.954763	55.944550999999997	0103000020E6100000010000000500000046274BADF78B4840B933130CE7F84B4046274BADF78B484026378AAC35FA4B4091EF52EA928D484026378AAC35FA4B4091EF52EA928D4840B933130CE7F84B4046274BADF78B4840B933130CE7F84B40
31368	Сая	7	64	13	49.168604000000002	49.192419000000001	56.060765000000004	56.044915000000003	0103000020E61000000100000005000000C6FCDCD094954840C80C54C6BF054C40C6FCDCD094954840E8DEC325C7074C408410902FA1984840E8DEC325C7074C408410902FA1984840C80C54C6BF054C40C6FCDCD094954840C80C54C6BF054C40
935	Пановка	7	64	13	49.385016999999998	49.406748	55.886372000000001	55.876565999999997	0103000020E61000000100000005000000B7B3AF3C48B148408C648F5033F04B40B7B3AF3C48B14840890B40A374F14B4051DB865110B44840890B40A374F14B4051DB865110B448408C648F5033F04B40B7B3AF3C48B148408C648F5033F04B40
61534	Наратлык	7	64	13	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
822	Мульма	7	64	13	49.575783999999999	49.596651999999999	56.057664000000003	56.045886000000003	0103000020E61000000100000005000000B0C7444AB3C9484011ACAA97DF054C40B0C7444AB3C948400A14B18861074C40E78BBD175FCC48400A14B18861074C40E78BBD175FCC484011ACAA97DF054C40B0C7444AB3C9484011ACAA97DF054C40
697	Мемдель	7	64	13	48.924118999999997	48.949451000000003	56.065604999999998	56.050576	0103000020E610000001000000050000005D4E09884976484033FB3C4679064C405D4E0988497648401FBAA0BE65084C40C713419C877948401FBAA0BE65084C40C713419C8779484033FB3C4679064C405D4E09884976484033FB3C4679064C40
32362	Малый Сулабаш	7	64	13	49.243093000000002	49.260789000000003	56.131098999999999	56.123052000000001	0103000020E610000001000000050000007A71E2AB1D9F48408CDAFD2AC00F4C407A71E2AB1D9F4840E7C41EDAC7104C400A14B18861A14840E7C41EDAC7104C400A14B18861A148408CDAFD2AC00F4C407A71E2AB1D9F48408CDAFD2AC00F4C40
1302	Малая Рясь	7	64	13	49.043585999999998	49.059925999999997	56.118816000000002	56.106735	0103000020E610000001000000050000001F48DE3994854840562B137EA90D4C401F48DE3994854840EB1ED95C350F4C400D17B9A7AB874840EB1ED95C350F4C400D17B9A7AB874840562B137EA90D4C401F48DE3994854840562B137EA90D4C40
1702	Куркачи	7	64	13	49.591710999999997	49.614123999999997	56.005284000000003	55.995840999999999	0103000020E610000001000000050000007BD7A02FBDCB48400A82C7B777FF4B407BD7A02FBDCB484096986725AD004C4027D87F9D9BCE484096986725AD004C4027D87F9D9BCE48400A82C7B777FF4B407BD7A02FBDCB48400A82C7B777FF4B40
60614	Куркачи	7	64	13	49.548133999999997	49.575505	56.018383	56.002616000000003	0103000020E61000000100000005000000AFE9414129C64840223999B855004C40AFE9414129C64840B4E6C75F5A024C409DD7D825AAC94840B4E6C75F5A024C409DD7D825AAC94840223999B855004C40AFE9414129C64840223999B855004C40
32240	Калинино	7	64	13	49.355077000000001	49.373590999999998	55.950786000000001	55.943632999999998	0103000020E61000000100000005000000E947C32973AD4840933655F7C8F84B40E947C32973AD484051BF0B5BB3F94B403B8A73D4D1AF484051BF0B5BB3F94B403B8A73D4D1AF4840933655F7C8F84B40E947C32973AD4840933655F7C8F84B40
32452	Казаклар	7	64	13	49.193631000000003	49.221623000000001	56.251547000000002	56.240597999999999	0103000020E61000000100000005000000F33E8EE6C8984840D3BD4EEACB1E4C40F33E8EE6C898484016342DB132204C404D8578245E9C484016342DB132204C404D8578245E9C4840D3BD4EEACB1E4C40F33E8EE6C8984840D3BD4EEACB1E4C40
31662	Инся	7	64	13	49.319341999999999	49.334423999999999	56.060161999999998	56.051537000000003	0103000020E610000001000000050000009F1EDB32E0A8484059C4B0C398064C409F1EDB32E0A84840213B6F63B3074C40AE7FD767CEAA4840213B6F63B3074C40AE7FD767CEAA484059C4B0C398064C409F1EDB32E0A8484059C4B0C398064C40
32288	Дубъязы	7	64	13	49.183686999999999	49.211005	56.128841999999999	56.112186999999999	0103000020E61000000100000005000000A5D93C0E83974840A704C4245C0E4C40A5D93C0E83974840F52C08E57D104C4070253B36029B4840F52C08E57D104C4070253B36029B4840A704C4245C0E4C40A5D93C0E83974840A704C4245C0E4C40
31522	Гарь	7	64	13	49.044808000000003	49.063367	56.250906999999998	56.238531999999999	0103000020E61000000100000005000000B24CBF44BC85484055867137881E4C40B24CBF44BC85484032AB77B81D204C40A452EC681C88484032AB77B81D204C40A452EC681C88484055867137881E4C40B24CBF44BC85484055867137881E4C40
61535	Высокая Гора	7	64	13	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
524	Большой Куюк	7	64	13	48.970184000000003	48.990440999999997	56.155949	56.142651000000001	0103000020E610000001000000050000001E8D43FD2E7C4840F0DE516342124C401E8D43FD2E7C4840056C0723F6134C400BCF4BC5C67E4840056C0723F6134C400BCF4BC5C67E4840F0DE516342124C401E8D43FD2E7C4840F0DE516342124C40
31798	Большой Битаман	7	64	13	49.046684999999997	49.069017000000002	56.181579999999997	56.169041999999997	0103000020E610000001000000050000005C1B2AC6F985484041D3122BA3154C405C1B2AC6F9854840C8CD70033E174C401CEF8E8CD5884840C8CD70033E174C401CEF8E8CD588484041D3122BA3154C405C1B2AC6F985484041D3122BA3154C40
31669	Большие Ковали	7	64	13	49.049621999999999	49.082419999999999	56.037061000000001	56.024099	0103000020E61000000100000005000000C09481035A864840E36E10AD15034C40C09481035A864840817A336ABE044C40A64412BD8C8A4840817A336ABE044C40A64412BD8C8A4840E36E10AD15034C40C09481035A864840E36E10AD15034C40
31879	Бикнарат	7	64	13	49.001607999999997	49.026904000000002	56.187907000000003	56.179003999999999	0103000020E61000000100000005000000BBB4E1B03480484035ED629AE9164C40BBB4E1B03480484041D829560D184C40D8101C977183484041D829560D184C40D8101C977183484035ED629AE9164C40BBB4E1B03480484035ED629AE9164C40
61537	Березовка	7	64	13	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
31611	Березка	7	64	13	49.261490000000002	49.273688999999997	56.071193000000001	56.060352999999999	0103000020E61000000100000005000000931D1B8178A14840959BA8A5B9074C40931D1B8178A14840215A2BDA1C094C403123BC3D08A34840215A2BDA1C094C403123BC3D08A34840959BA8A5B9074C40931D1B8178A14840959BA8A5B9074C40
31323	Альдермыш	7	64	13	49.213690999999997	49.244143999999999	56.027659999999997	56.013824	0103000020E610000001000000050000008A39083A5A9B484030F31DFCC4014C408A39083A5A9B484024B4E55C8A034C40DFC14F1C409F484024B4E55C8A034C40DFC14F1C409F484030F31DFCC4014C408A39083A5A9B484030F31DFCC4014C40
31430	Алан-Бексерь	7	64	13	49.096245000000003	49.114975000000001	56.183188000000001	56.175732000000004	0103000020E61000000100000005000000A7B393C1518C48402B6EDC627E164C40A7B393C1518C4840848252B472174C40C66D3480B78E4840848252B472174C40C66D3480B78E48402B6EDC627E164C40A7B393C1518C48402B6EDC627E164C40
444	Айбаш	7	64	13	48.975600999999997	49.009028000000001	56.107759000000001	56.092717	0103000020E61000000100000005000000F2785A7EE07C484041649126DE0B4C40F2785A7EE07C4840C26C020CCB0D4C40C85F5AD427814840C26C020CCB0D4C40C85F5AD42781484041649126DE0B4C40F2785A7EE07C484041649126DE0B4C40
30931	Янга-Юл	7	64	1872	48.902783999999997	48.912925999999999	55.564816	55.557623	0103000020E6100000010000000500000010AD156D8E734840AB3FC23060C74B4010AD156D8E734840F72004E44BC84B4084D558C2DA744840F72004E44BC84B4084D558C2DA744840AB3FC23060C74B4010AD156D8E734840AB3FC23060C74B40
30610	Ямбулатово	7	64	1872	48.765386999999997	48.782454999999999	55.498525000000001	55.488289999999999	0103000020E610000001000000050000004BE48233F86148405F7B664980BE4B404BE48233F8614840849ECDAACFBF4B40BCCB457C27644840849ECDAACFBF4B40BCCB457C276448405F7B664980BE4B404BE48233F86148405F7B664980BE4B40
30728	Шеланга	7	64	1872	48.981673999999998	49.028098999999997	55.537745000000001	55.518076000000001	0103000020E61000000100000005000000B0AA5E7EA77D4840D76B7A5050C24B40B0AA5E7EA77D4840344B02D4D4C44B4070067FBF98834840344B02D4D4C44B4070067FBF98834840D76B7A5050C24B40B0AA5E7EA77D4840D76B7A5050C24B40
30167	Чулпаниха	7	64	1872	48.459105999999998	48.479695	55.553131	55.539771999999999	0103000020E61000000100000005000000DDB243FCC33A4840F4A5B73F17C54B40DDB243FCC33A4840AFB321FFCCC64B40018750A5663D4840AFB321FFCCC64B40018750A5663D4840F4A5B73F17C54B40DDB243FCC33A4840F4A5B73F17C54B40
30028	Уланово	7	64	1872	48.689093	48.710059000000001	55.562621999999998	55.547173000000001	0103000020E6100000010000000500000086730D33345848408A20CEC309C64B4086730D33345848404B0169FF03C84B40809D9B36E35A48404B0169FF03C84B40809D9B36E35A48408A20CEC309C64B4086730D33345848408A20CEC309C64B40
29565	Татарское Бурнашево	7	64	1872	48.641446000000002	48.663274999999999	55.707973000000003	55.696762999999997	0103000020E6100000010000000500000034130CE71A5248400B08AD872FD94B4034130CE71A524840BBB9F8DB9EDA4B4090A0F831E6544840BBB9F8DB9EDA4B4090A0F831E65448400B08AD872FD94B4034130CE71A5248400B08AD872FD94B40
30717	Старое Русское-Маматкозино	7	64	1872	48.782949000000002	48.801355000000001	55.569443	55.556700999999997	0103000020E61000000100000005000000CCB73EAC37644840435376FA41C74B40CCB73EAC37644840D3F71A82E3C84B4038BEF6CC92664840D3F71A82E3C84B4038BEF6CC92664840435376FA41C74B40CCB73EAC37644840435376FA41C74B40
30129	Соболевское	7	64	1872	48.445362000000003	48.475222000000002	55.629708999999998	55.594163000000002	0103000020E61000000100000005000000CA703C9F0139484023BF7E880DCC4B40CA703C9F01394840997FF44D9AD04B407C2B1213D43C4840997FF44D9AD04B407C2B1213D43C484023BF7E880DCC4B40CA703C9F0139484023BF7E880DCC4B40
29834	Сеитово	7	64	1872	48.771262	48.804571000000003	55.619030000000002	55.609121000000002	0103000020E61000000100000005000000E35295B6B862484046274BADF7CD4B40E35295B6B8624840179F02603CCF4B40AF27BA2EFC664840179F02603CCF4B40AF27BA2EFC66484046274BADF7CD4B40E35295B6B862484046274BADF7CD4B40
29844	Русское Макулово	7	64	1872	48.694051000000002	48.734394999999999	55.610686999999999	55.574247999999997	0103000020E61000000100000005000000C860C5A9D65848408EE55DF580C94B40C860C5A9D6584840D28BDAFD2ACE4B4047ACC5A7005E4840D28BDAFD2ACE4B4047ACC5A7005E48408EE55DF580C94B40C860C5A9D65848408EE55DF580C94B40
29604	Русское Бурнашево	7	64	1872	48.716788000000001	48.746566999999999	55.676966	55.662602999999997	0103000020E6100000010000000500000027158DB5BF5B4840A19DD32CD0D44B4027158DB5BF5B4840814067D2A6D64B40ECA2E8818F5F4840814067D2A6D64B40ECA2E8818F5F4840A19DD32CD0D44B4027158DB5BF5B4840A19DD32CD0D44B40
30408	Патрикеево	7	64	1872	48.566985000000003	48.587232999999998	55.470973999999998	55.456606999999998	0103000020E610000001000000050000004A29E8F692484840F50F221972BA4B404A29E8F69248484016A243E048BC4B40E41071732A4B484016A243E048BC4B40E41071732A4B4840F50F221972BA4B404A29E8F692484840F50F221972BA4B40
61536	Октябрьский	7	64	1872	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
61440	Нижнее Озеро	7	64	1872	48.706322	48.721665999999999	55.376359999999998	55.368082999999999	0103000020E61000000100000005000000003961C2685A4840569BFF571DAF4B40003961C2685A4840E3C281902CB04B404C512E8D5F5C4840E3C281902CB04B404C512E8D5F5C4840569BFF571DAF4B40003961C2685A4840569BFF571DAF4B40
30927	Нариман	7	64	1872	48.976202999999998	48.996136999999997	55.559873000000003	55.550707000000003	0103000020E61000000100000005000000E8A04B38F47C4840D25625917DC64B40E8A04B38F47C4840EB7420EBA9C74B40F3AACE6A817F4840EB7420EBA9C74B40F3AACE6A817F4840D25625917DC64B40E8A04B38F47C4840D25625917DC64B40
61301	Набережные Моркваши	7	64	1872	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
31081	Матюшино	7	64	1872	48.946451000000003	48.958893000000003	55.655183000000001	55.644027999999999	0103000020E610000001000000050000001D226E4E25794840A9DA6E826FD24B401D226E4E2579484095F25A09DDD34B4082AE7D01BD7A484095F25A09DDD34B4082AE7D01BD7A4840A9DA6E826FD24B401D226E4E25794840A9DA6E826FD24B40
30527	Майдан	7	64	1872	48.781196999999999	48.810805000000002	55.463104999999999	55.441009000000001	0103000020E61000000100000005000000DD5D6743FE634840EF1EA0FB72B84B40DD5D6743FE6348409ACE4E0647BB4B4076374F75C86748409ACE4E0647BB4B4076374F75C8674840EF1EA0FB72B84B40DD5D6743FE634840EF1EA0FB72B84B40
29656	Куралово	7	64	1872	48.714613999999997	48.752414999999999	55.654888999999997	55.635838	0103000020E61000000100000005000000C2A1B778785B4840EBC6BB2363D14B40C2A1B778785B48404CC11A67D3D34B408A027D224F6048404CC11A67D3D34B408A027D224F604840EBC6BB2363D14B40C2A1B778785B4840EBC6BB2363D14B40
30310	Коргуза	7	64	1872	48.641069000000002	48.669905	55.509141	55.488677000000003	0103000020E610000001000000050000005EBD8A8C0E52484059A7CAF78CBE4B405EBD8A8C0E524840C00644882BC14B40A4367172BF554840C00644882BC14B40A4367172BF55484059A7CAF78CBE4B405EBD8A8C0E52484059A7CAF78CBE4B40
30024	Клянчино	7	64	1872	48.593215000000001	48.615735999999998	55.604748000000001	55.597805000000001	0103000020E61000000100000005000000923F1878EE4B48405131CEDF84CC4B40923F1878EE4B48402429E96168CD4B40247CEF6FD04E48402429E96168CD4B40247CEF6FD04E48405131CEDF84CC4B40923F1878EE4B48405131CEDF84CC4B40
30120	Кильдеево	7	64	1872	48.637403999999997	48.668799999999997	55.546138999999997	55.531982999999997	0103000020E61000000100000005000000772B4B74965148409483D90418C44B40772B4B7496514840FA08FCE1E7C54B404BC8073D9B554840FA08FCE1E7C54B404BC8073D9B5548409483D90418C44B40772B4B74965148409483D90418C44B40
30314	Егидерево	7	64	1872	48.705613	48.733846999999997	55.513554999999997	55.496327000000001	0103000020E61000000100000005000000F450DB86515A4840978FA4A487BF4B40F450DB86515A484040D9942BBCC14B4044A2D0B2EE5D484040D9942BBCC14B4044A2D0B2EE5D4840978FA4A487BF4B40F450DB86515A4840978FA4A487BF4B40
61372	Верхний Услон	7	64	1872	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
61533	Введенская Слобода	7	64	1872	48.684950999999998	48.705351999999998	55.762135000000001	55.752637	0103000020E61000000100000005000000662E7079AC5748403961C26856E04B40662E7079AC5748408811C2A38DE14B4087156EF9485A48408811C2A38DE14B4087156EF9485A48403961C26856E04B40662E7079AC5748403961C26856E04B40
30418	Большие Меми	7	64	1872	48.657463	48.689129000000001	55.408040999999997	55.394499000000003	0103000020E610000001000000050000003FAA61BF2754484001A777F17EB24B403FAA61BF27544840AC36FFAF3AB44B40D3DC0A6135584840AC36FFAF3AB44B40D3DC0A613558484001A777F17EB24B403FAA61BF2754484001A777F17EB24B40
61444	Бахчи-Сарай	7	64	1872	48.942013000000003	48.955668000000003	55.645974000000002	55.637627000000002	0103000020E6100000010000000500000014B4C9E193784840F705F4C29DD14B4014B4C9E1937848407D08AA46AFD24B40B8EA3A54537A48407D08AA46AFD24B40B8EA3A54537A4840F705F4C29DD14B4014B4C9E193784840F705F4C29DD14B40
61380	Яшевка	7	64	1742	48.483342999999998	48.509762000000002	54.895941999999998	54.879598999999999	0103000020E6100000010000000500000011E0F42EDE3D4840124C35B396704B4011E0F42EDE3D4840718E3A3AAE724B402D5F97E13F414840718E3A3AAE724B402D5F97E13F414840124C35B396704B4011E0F42EDE3D4840124C35B396704B40
25943	Яскуль	7	64	1742	48.301658000000003	48.314863000000003	54.770468999999999	54.759098000000002	0103000020E61000000100000005000000D449B6BA9C264840C13A8E1F2A614B40D449B6BA9C26484079CA6ABA9E624B4038DC476E4D28484079CA6ABA9E624B4038DC476E4D284840C13A8E1F2A614B40D449B6BA9C264840C13A8E1F2A614B40
28798	Энтуганы	7	64	1742	47.844973000000003	47.870494000000001	54.914369000000001	54.902175	0103000020E610000001000000050000006380441328EC474068226C787A734B406380441328EC4740F5BC1B0B0A754B409FAEEE586CEF4740F5BC1B0B0A754B409FAEEE586CEF474068226C787A734B406380441328EC474068226C787A734B40
28198	Шаймурзино	7	64	1742	48.083772000000003	48.106130999999998	54.810324999999999	54.795203000000001	0103000020E610000001000000050000000729780AB90A48402E573F36C9654B400729780AB90A4840CB10C7BAB8674B40BF0B5BB3950D4840CB10C7BAB8674B40BF0B5BB3950D48402E573F36C9654B400729780AB90A48402E573F36C9654B40
27950	Чураково	7	64	1742	48.209940000000003	48.238075000000002	54.990611999999999	54.978952999999997	0103000020E61000000100000005000000A60F5D50DF1A484019A9F7544E7D4B40A60F5D50DF1A48403883BF5FCC7E4B40637FD93D791E48403883BF5FCC7E4B40637FD93D791E484019A9F7544E7D4B40A60F5D50DF1A484019A9F7544E7D4B40
28653	Чувашские Кищаки	7	64	1742	48.154020000000003	48.183548000000002	54.785761000000001	54.769606000000003	0103000020E61000000100000005000000087767EDB613484017670C7382624B40087767EDB613484073BC02D193644B40849F38807E17484073BC02D193644B40849F38807E17484017670C7382624B40087767EDB613484017670C7382624B40
26567	Чувашская Беловолжка	7	64	1742	48.074922999999998	48.092737	55.059704000000004	55.048735000000001	0103000020E61000000100000005000000EE5BAD1397094840D595CFF23C864B40EE5BAD13970948405FB87361A4874B40881057CEDE0B48405FB87361A4874B40881057CEDE0B4840D595CFF23C864B40EE5BAD1397094840D595CFF23C864B40
28511	Черки-Кильдуразы	7	64	1742	48.261045000000003	48.280825999999998	55.113281999999998	55.095049000000003	0103000020E6100000010000000500000065E42CEC692148403E42CD902A8C4B4065E42CEC69214840DC9C4A06808E4B40E9EE3A1BF2234840DC9C4A06808E4B40E9EE3A1BF22348403E42CD902A8C4B4065E42CEC692148403E42CD902A8C4B40
26366	Черки-Дюртиле	7	64	1742	48.345424000000001	48.367683999999997	55.085718999999997	55.074731	0103000020E6100000010000000500000073A087DA362C4840AA7F10C990894B4073A087DA362C4840AAD216D7F88A4B4098A1F144102F4840AAD216D7F88A4B4098A1F144102F4840AA7F10C990894B4073A087DA362C4840AA7F10C990894B40
28469	Черки-Гришино	7	64	1742	48.273927	48.315348999999998	55.058579999999999	55.040322000000003	0103000020E61000000100000005000000E63E390A1023484098A7734529854B40E63E390A102348408F19A88C7F874B40C4E9245B5D2848408F19A88C7F874B40C4E9245B5D28484098A7734529854B40E63E390A1023484098A7734529854B40
26653	Тойгильды	7	64	1742	48.042458000000003	48.064943	55.055289999999999	55.045202000000003	0103000020E610000001000000050000000FBA84436F0548405EDBDB2DC9854B400FBA84436F054840DEE522BE13874B40548D5E0D50084840DEE522BE13874B40548D5E0D500848405EDBDB2DC9854B400FBA84436F0548405EDBDB2DC9854B40
26075	Тингаш	7	64	1742	48.188488	48.219031000000001	54.943525000000001	54.932927999999997	0103000020E610000001000000050000001FD8F15F20184840E7C2482F6A774B401FD8F15F20184840ADFA5C6DC5784B40B4E73235091C4840ADFA5C6DC5784B40B4E73235091C4840E7C2482F6A774B401FD8F15F20184840E7C2482F6A774B40
28378	Тимбаево	7	64	1742	47.895457999999998	47.923862999999997	54.941859999999998	54.933993000000001	0103000020E610000001000000050000008578245E9EF24740B2D826158D774B408578245E9EF247408DB454DE8E784B40027E8D2441F647408DB454DE8E784B40027E8D2441F64740B2D826158D774B408578245E9EF24740B2D826158D774B40
27151	Татарское Пимурзино	7	64	1742	48.231482	48.241705000000003	54.812036999999997	54.804341999999998	0103000020E610000001000000050000006CCEC133A11D48404D66BCADF4664B406CCEC133A11D48402B1213D4F0674B40CD237F30F01E48402B1213D4F0674B40CD237F30F01E48404D66BCADF4664B406CCEC133A11D48404D66BCADF4664B40
26564	Татарская Беловолжка	7	64	1742	48.100462999999998	48.114835999999997	55.035384999999998	55.028187000000003	0103000020E61000000100000005000000A1BAB9F8DB0C48401096B1A19B834B40A1BAB9F8DB0C48406DE2E47E87844B40A43330F2B20E48406DE2E47E87844B40A43330F2B20E48401096B1A19B834B40A1BAB9F8DB0C48401096B1A19B834B40
28745	Таковары	7	64	1742	48.10163	48.138497000000001	54.747667	54.736623000000002	0103000020E6100000010000000500000070253B36020D48409F3D97A9495E4B4070253B36020D484033A6608DB35F4B400CCC0A45BA11484033A6608DB35F4B400CCC0A45BA1148409F3D97A9495E4B4070253B36020D48409F3D97A9495E4B40
26840	Степные-Енали	7	64	1742	48.209231000000003	48.222076000000001	55.040878999999997	55.032783999999999	0103000020E610000001000000050000009A27D714C81A484081EA1F4432844B409A27D714C81A4840ED0BE8853B854B40FE9C82FC6C1C4840ED0BE8853B854B40FE9C82FC6C1C484081EA1F4432844B409A27D714C81A484081EA1F4432844B40
26279	Степановка	7	64	1742	48.368538000000001	48.384160000000001	55.009377999999998	55.000754999999998	0103000020E61000000100000005000000A8AAD0402C2F48407C2766BD18804B40A8AAD0402C2F4840A4A65D4C33814B403737A6272C314840A4A65D4C33814B403737A6272C3148407C2766BD18804B40A8AAD0402C2F48407C2766BD18804B40
28104	Старый Студенец	7	64	1742	48.218232	48.279541999999999	54.892597000000002	54.872537999999999	0103000020E610000001000000050000006878B306EF1B484035423F53AF6F4B406878B306EF1B4840FDC0559E40724B40E1ED4108C8234840FDC0559E40724B40E1ED4108C823484035423F53AF6F4B406878B306EF1B484035423F53AF6F4B40
28191	Старые Тинчали	7	64	1742	48.140096	48.175589000000002	54.846913000000001	54.832245999999998	0103000020E6100000010000000500000074266DAAEE114840081D7409876A4B4074266DAAEE11484054C72AA5676C4B40C8444AB37916484054C72AA5676C4B40C8444AB379164840081D7409876A4B4074266DAAEE114840081D7409876A4B40
27278	Старые Мертли	7	64	1742	48.312483	48.33663	54.777603999999997	54.768656	0103000020E610000001000000050000002AC76471FF274840E5EFDE5163624B402AC76471FF274840909E228788634B401E6D1CB1162B4840909E228788634B401E6D1CB1162B4840E5EFDE5163624B402AC76471FF274840E5EFDE5163624B40
26413	Старые Бурундуки	7	64	1742	48.383530999999998	48.408377999999999	54.812202999999997	54.797823999999999	0103000020E610000001000000050000004700378B1731484061FBC9181F664B404700378B17314840465B9544F6674B40F433F5BA45344840465B9544F6674B40F433F5BA4534484061FBC9181F664B404700378B1731484061FBC9181F664B40
28245	Старостуденецкие Выселки	7	64	1742	48.095432000000002	48.114134999999997	54.854843000000002	54.844538999999997	0103000020E61000000100000005000000F67EA31D370C484028999CDA196C4B40F67EA31D370C4840761BD47E6B6D4B401B2AC6F99B0E4840761BD47E6B6D4B401B2AC6F99B0E484028999CDA196C4B40F67EA31D370C484028999CDA196C4B40
28031	Сорок-Сайдак	7	64	1742	47.806956	47.837211000000003	54.953668999999998	54.941766999999999	0103000020E61000000100000005000000CEA78E554AE74740DCB930D28B784B40CEA78E554AE74740C11A67D3117A4B40FD6CE4BA29EB4740C11A67D3117A4B40FD6CE4BA29EB4740DCB930D28B784B40CEA78E554AE74740DCB930D28B784B40
28289	Сарсаз	7	64	1742	48.032010999999997	48.056013999999998	54.849758999999999	54.836176000000002	0103000020E610000001000000050000005E0EBBEF180448409DD9AED0076B4B405E0EBBEF18044840A73D25E7C46C4B401F0F7D772B074840A73D25E7C46C4B401F0F7D772B0748409DD9AED0076B4B405E0EBBEF180448409DD9AED0076B4B40
27026	Русские Кищаки	7	64	1742	48.439109000000002	48.464315999999997	54.847290999999998	54.837378999999999	0103000020E610000001000000050000008C3045B934384840B8AD2D3C2F6B4B408C3045B934384840FA980F08746C4B403881E9B46E3B4840FA980F08746C4B403881E9B46E3B4840B8AD2D3C2F6B4B408C3045B934384840B8AD2D3C2F6B4B40
27936	Рунга	7	64	1742	48.138128999999999	48.16957	54.961522000000002	54.947346000000003	0103000020E6100000010000000500000089D00836AE1148408BFF3BA242794B4089D00836AE11484038312427137B4B40FD304278B415484038312427137B4B40FD304278B41548408BFF3BA242794B4089D00836AE1148408BFF3BA242794B40
26027	Раково	7	64	1742	48.214207000000002	48.246834	54.750900000000001	54.737600999999998	0103000020E6100000010000000500000082C98D226B1B48409A3FA6B5695E4B4082C98D226B1B48408048BF7D1D604B403BC5AA41981F48408048BF7D1D604B403BC5AA41981F48409A3FA6B5695E4B4082C98D226B1B48409A3FA6B5695E4B40
24120	Плодопитомник	7	64	1742	48.360201000000004	48.365186999999999	54.979010000000002	54.976137000000001	0103000020E61000000100000005000000467EFD101B2E484031B5A50EF27C4B40467EFD101B2E48407E3A1E33507D4B4051F69672BE2E48407E3A1E33507D4B4051F69672BE2E484031B5A50EF27C4B40467EFD101B2E484031B5A50EF27C4B40
27852	Нурлаты	7	64	1742	48.157666999999996	48.178984	55.039507	55.028703	0103000020E610000001000000050000004754A86E2E1448400726378AAC834B404754A86E2E144840467BBC900E854B40EE409DF2E8164840467BBC900E854B40EE409DF2E81648400726378AAC834B404754A86E2E1448400726378AAC834B40
27714	Новые Чечкабы	7	64	1742	48.118231000000002	48.148487000000003	55.082358999999997	55.059142000000001	0103000020E61000000100000005000000CB2F8331220F4840F7E80DF791874B40CB2F8331220F484000C45DBD8A8A4B40CA703C9F0113484000C45DBD8A8A4B40CA703C9F01134840F7E80DF791874B40CB2F8331220F4840F7E80DF791874B40
27581	Новые Тинчали	7	64	1742	47.967368	48.009993000000001	54.830280000000002	54.804212999999997	0103000020E610000001000000050000003599F1B6D2FB47404F029B73F0664B403599F1B6D2FB4740EE42739D466A4B402F185C7347014840EE42739D466A4B402F185C73470148404F029B73F0664B403599F1B6D2FB47404F029B73F0664B40
27116	Новые Мертли	7	64	1742	48.184742999999997	48.209041999999997	54.821883	54.812032000000002	0103000020E610000001000000050000001C959BA8A51748401AA721AAF0674B401C959BA8A5174840B6114F7633694B40C6BE64E3C11A4840B6114F7633694B40C6BE64E3C11A48401AA721AAF0674B401C959BA8A51748401AA721AAF0674B40
28755	Новоселки	7	64	1742	48.164907999999997	48.181337999999997	54.742471000000002	54.734378	0103000020E61000000100000005000000A46C91B41B15484071732A19005E4B40A46C91B41B1548403D9D2B4A095F4B40D2C26515361748403D9D2B4A095F4B40D2C265153617484071732A19005E4B40A46C91B41B15484071732A19005E4B40
27677	Новая Цильна	7	64	1742	47.900812000000002	47.921931000000001	54.823366999999998	54.814366999999997	0103000020E6100000010000000500000014ECBFCE4DF3474087F8872D3D684B4014ECBFCE4DF3474085CD001764694B409415C3D501F6474085CD001764694B409415C3D501F6474087F8872D3D684B4014ECBFCE4DF3474087F8872D3D684B40
27482	Нижний Наратбаш	7	64	1742	48.311639	48.333171	55.022576999999998	55.004029000000003	0103000020E610000001000000050000003E9468C9E3274840289EB30584804B403E9468C9E327484026529ACDE3824B40E17CEA58A52A484026529ACDE3824B40E17CEA58A52A4840289EB30584804B403E9468C9E3274840289EB30584804B40
26142	Мулланур-Вахитов	7	64	1742	48.115248999999999	48.135012000000003	54.939155	54.928024000000001	0103000020E61000000100000005000000C7F2AE7AC00E484099F38C7DC9764B40C7F2AE7AC00E4840FC6F253B36784B40A648BE1248114840FC6F253B36784B40A648BE124811484099F38C7DC9764B40C7F2AE7AC00E484099F38C7DC9764B40
27389	Мокрая Савалеевка	7	64	1742	47.99156	48.027214000000001	54.943944000000002	54.929219000000003	0103000020E61000000100000005000000C9022670EBFE474032E9EFA5F0764B40C9022670EBFE4740B2A03028D3784B4026FF93BF7B034840B2A03028D3784B4026FF93BF7B03484032E9EFA5F0764B40C9022670EBFE474032E9EFA5F0764B40
27374	Мещеряково	7	64	1742	48.269795000000002	48.287033999999998	54.947274	54.930568999999998	0103000020E61000000100000005000000EACF7EA488224840F1D58EE21C774B40EACF7EA488224840F12C414640794B40876BB587BD244840F12C414640794B40876BB587BD244840F1D58EE21C774B40EACF7EA488224840F1D58EE21C774B40
27284	Малая Буинка	7	64	1742	48.229227000000002	48.248837000000002	54.962823999999998	54.947899	0103000020E610000001000000050000001B2E724F571D48409F7422C154794B401B2E724F571D4840E6E61BD13D7B4B4073840CE4D91F4840E6E61BD13D7B4B4073840CE4D91F48409F7422C154794B401B2E724F571D48409F7422C154794B40
61453	Лащи	7	64	1742	48.232883000000001	48.243358000000001	55.057279999999999	55.049456999999997	0103000020E61000000100000005000000AE65321CCF1D484075C7629B54864B40AE65321CCF1D4840815B77F354874B40289CDD5A261F4840815B77F354874B40289CDD5A261F484075C7629B54864B40AE65321CCF1D484075C7629B54864B40
61454	Кыр-Тавгельдино	7	64	1742	48.139161999999999	48.150489999999998	55.110239	55.100653999999999	0103000020E61000000100000005000000486C770FD0114840151BF33AE28C4B40486C770FD011484033DFC14F1C8E4B4001309E414313484033DFC14F1C8E4B4001309E4143134840151BF33AE28C4B40486C770FD0114840151BF33AE28C4B40
61407	КощаковоЧерки	7	64	1742	48.278841	48.296025999999998	55.069412	55.061492999999999	0103000020E6100000010000000500000058E4D70FB12348406AF7AB00DF874B4058E4D70FB123484098F90E7EE2884B400262122EE425484098F90E7EE2884B400262122EE42548406AF7AB00DF874B4058E4D70FB12348406AF7AB00DF874B40
27208	Кошки-Шемякино	7	64	1742	48.260767000000001	48.279111	54.800356999999998	54.791367000000001	0103000020E61000000100000005000000227024D0602148401B118C834B654B40227024D060214840F50F221972664B40187AC4E8B9234840F50F221972664B40187AC4E8B92348401B118C834B654B40227024D0602148401B118C834B654B40
27106	Кошки-Теняково	7	64	1742	48.212923000000004	48.239369000000003	54.841189999999997	54.827210000000001	0103000020E610000001000000050000007AC8940F411B48404B766C04E2694B407AC8940F411B484072DC291DAC6B4B408F56B5A4A31E484072DC291DAC6B4B408F56B5A4A31E48404B766C04E2694B407AC8940F411B48404B766C04E2694B40
27021	Козловка	7	64	1742	48.363121	48.578986	54.922865000000002	54.856169999999999	0103000020E61000000100000005000000D3BEB9BF7A2E48407DE882FA966D4B40D3BEB9BF7A2E4840C0CFB87020764B40C26B97361C4A4840C0CFB87020764B40C26B97361C4A48407DE882FA966D4B40D3BEB9BF7A2E48407DE882FA966D4B40
26946	Кият	7	64	1742	48.392612999999997	48.419248000000003	54.892664000000003	54.872548999999999	0103000020E61000000100000005000000027E8D2441324840299485AFAF6F4B40027E8D244132484085285FD042724B40EB7420EBA935484085285FD042724B40EB7420EBA9354840299485AFAF6F4B40027E8D2441324840299485AFAF6F4B40
26192	Каменный Брод	7	64	1742	47.865661000000003	47.890050000000002	54.931541000000003	54.917918999999998	0103000020E610000001000000050000001A36CAFACDEE474042B0AA5E7E754B401A36CAFACDEE47400BF148BC3C774B4004E78C28EDF147400BF148BC3C774B4004E78C28EDF1474042B0AA5E7E754B401A36CAFACDEE474042B0AA5E7E754B40
26830	Кайбицы	7	64	1742	48.173810000000003	48.208835000000001	55.015495000000001	55.001854999999999	0103000020E61000000100000005000000E0DBF4673F164840C32ADEC83C804B40E0DBF4673F16484032207BBDFB814B404DA1F31ABB1A484032207BBDFB814B404DA1F31ABB1A4840C32ADEC83C804B40E0DBF4673F164840C32ADEC83C804B40
28568	Ишмяково-Черки	7	64	1742	48.248981000000001	48.265284999999999	55.083534	55.068814000000003	0103000020E61000000100000005000000A629029CDE1F4840E4C0ABE5CE884B40A629029CDE1F4840520DFB3DB18A4B40478FDFDBF4214840520DFB3DB18A4B40478FDFDBF4214840E4C0ABE5CE884B40A629029CDE1F4840E4C0ABE5CE884B40
26664	Исаково	7	64	1742	47.919784	47.946086999999999	55.089480000000002	55.081184	0103000020E6100000010000000500000029B16B7BBBF54740AF7AC03C648A4B4029B16B7BBBF54740B3D2A414748B4B40DB15FA6019F94740B3D2A414748B4B40DB15FA6019F94740AF7AC03C648A4B4029B16B7BBBF54740AF7AC03C648A4B40
27429	Ембулатово	7	64	1742	47.936978000000003	47.969389	54.943027999999998	54.932063999999997	0103000020E61000000100000005000000278925E5EEF74740B4E386DF4D774B40278925E5EEF747402C9B3924B5784B40130D52F014FC47402C9B3924B5784B40130D52F014FC4740B4E386DF4D774B40278925E5EEF74740B4E386DF4D774B40
28859	Вольный Стан	7	64	1742	47.787103000000002	47.815759999999997	54.888992999999999	54.867482000000003	0103000020E61000000100000005000000B0CA85CABFE4474031EF71A6096F4B40B0CA85CABFE44740BCAFCA85CA714B4046B1DCD26AE84740BCAFCA85CA714B4046B1DCD26AE8474031EF71A6096F4B40B0CA85CABFE4474031EF71A6096F4B40
26893	Верхний Наратбаш	7	64	1742	48.232802	48.255313999999998	55.026231000000003	55.014178999999999	0103000020E61000000100000005000000C138B874CC1D48401EA5129ED0814B40C138B874CC1D4840199293895B834B40001B1021AE204840199293895B834B40001B1021AE2048401EA5129ED0814B40C138B874CC1D48401EA5129ED0814B40
26500	Верхние Лащи	7	64	1742	48.043275999999999	48.063012000000001	55.038876999999999	55.024951000000001	0103000020E61000000100000005000000D15966118A0548405280289831834B40D15966118A05484086C8E9EBF9844B40B6A0F7C61008484086C8E9EBF9844B40B6A0F7C6100848405280289831834B40D15966118A0548405280289831834B40
26368	Бюрганы	7	64	1742	48.281258000000001	48.332830000000001	54.821410999999998	54.798940000000002	0103000020E6100000010000000500000083DE1B4300244840AEBB79AA43664B4083DE1B43002448408EC9E2FE23694B405890662C9A2A48408EC9E2FE23694B405890662C9A2A4840AEBB79AA43664B4083DE1B4300244840AEBB79AA43664B40
26229	Большое Фролово	7	64	1742	48.387141999999997	48.433585000000001	55.057367999999997	55.045851999999996	0103000020E610000001000000050000003A747ADE8D314840643A747ADE854B403A747ADE8D31484020EBA9D557874B40A18499B67F37484020EBA9D557874B40A18499B67F374840643A747ADE854B403A747ADE8D314840643A747ADE854B40
27574	Большая Карланга	7	64	1742	48.402521	48.423254	54.990198999999997	54.983732000000003	0103000020E61000000100000005000000037AE1CE85334840AC0320EEEA7D4B40037AE1CE8533484015C440D7BE7E4B405AF3E32F2D36484015C440D7BE7E4B405AF3E32F2D364840AC0320EEEA7D4B40037AE1CE85334840AC0320EEEA7D4B40
26147	Бик-Утеево	7	64	1742	48.079082999999997	48.101495999999997	55.136946000000002	55.125076999999997	0103000020E61000000100000005000000B45549641F0A4840AB3DEC8502904B40B45549641F0A4840B5A84F7287914B40605628D2FD0C4840B5A84F7287914B40605628D2FD0C4840AB3DEC8502904B40B45549641F0A4840AB3DEC8502904B40
27845	Ахмаметьево	7	64	1742	48.168886999999998	48.191678000000003	55.086599999999997	55.076855000000002	0103000020E610000001000000050000001ADCD6169E1548405DC47762D6894B401ADCD6169E154840B3EA73B5158B4B406DAE9AE788184840B3EA73B5158B4B406DAE9AE7881848405DC47762D6894B401ADCD6169E1548405DC47762D6894B40
26754	Атабай-Анкебе	7	64	1742	47.966515000000001	47.979325000000003	55.093086999999997	55.087156	0103000020E61000000100000005000000F60B76C3B6FB474039D384ED278B4B40F60B76C3B6FB474064575A46EA8B4B40DE9387855AFD474064575A46EA8B4B40DE9387855AFD474039D384ED278B4B40F60B76C3B6FB474039D384ED278B4B40
26030	Альшихово	7	64	1742	48.147615000000002	48.187249000000001	54.943038999999999	54.924551999999998	0103000020E6100000010000000500000014B35E0CE5124840C7B94DB857764B4014B35E0CE512484020ED7F80B5784B40B79A75C6F717484020ED7F80B5784B40B79A75C6F7174840C7B94DB857764B4014B35E0CE5124840C7B94DB857764B40
25936	Альшеево	7	64	1742	48.267719999999997	48.298586	54.760126999999997	54.745063999999999	0103000020E61000000100000005000000183E22A644224840A6B6D4415E5F4B40183E22A6442248403EE76ED74B614B409085E810382648403EE76ED74B614B409085E81038264840A6B6D4415E5F4B40183E22A644224840A6B6D4415E5F4B40
26755	Алькеево	7	64	1742	48.002088000000001	48.02619	55.105958999999999	55.088872000000002	0103000020E6100000010000000500000066DB696B44004840DBC35E28608B4B4066DB696B44004840C2DB8310908D4B40BABDA4315A034840C2DB8310908D4B40BABDA4315A034840DBC35E28608B4B4066DB696B44004840DBC35E28608B4B40
25798	Аксу	7	64	1742	48.076334000000003	48.097057999999997	55.190086999999998	55.173226	0103000020E6100000010000000500000054C90050C5094840906802452C964B4054C90050C5094840873254C554984B4057E883656C0C4840873254C554984B4057E883656C0C4840906802452C964B4054C90050C5094840906802452C964B40
25758	Адав-Тулумбаево	7	64	1742	48.333143999999997	48.352753999999997	54.956890000000001	54.934614000000003	0103000020E61000000100000005000000E76D6C76A42A48401F317A6EA1774B40E76D6C76A42A48404AEF1B5F7B7A4B403FC4060B272D48404AEF1B5F7B7A4B403FC4060B272D48401F317A6EA1774B40E76D6C76A42A48401F317A6EA1774B40
24834	Татарская-Дымская	7	64	1683	52.954760999999998	52.973427999999998	54.351171999999998	54.336067	0103000020E61000000100000005000000853FC39B357A4A40E621533E042B4B40853FC39B357A4A40ADA23F34F32C4B405E81E849997C4A40ADA23F34F32C4B405E81E849997C4A40E621533E042B4B40853FC39B357A4A40E621533E042B4B40
23610	Таллы-Буляк	7	64	1683	52.722295000000003	52.736829	54.569727	54.563969	0103000020E610000001000000050000003C889D29745C4A409A7ADD2230484B403C889D29745C4A40F85278D0EC484B4048DFA469505E4A40F85278D0EC484B4048DFA469505E4A409A7ADD2230484B403C889D29745C4A409A7ADD2230484B40
24547	Старое Сумароково	7	64	1683	52.893298000000001	52.915927000000003	54.715555999999999	54.70082	0103000020E6100000010000000500000086CABF9657724A40FD304278B4594B4086CABF9657724A40713AC956975B4B40FF428F183D754A40713AC956975B4B40FF428F183D754A40FD304278B4594B4086CABF9657724A40FD304278B4594B40
24739	Старое Исаково	7	64	1683	53.009369	53.027318000000001	54.461216	54.453699999999998	0103000020E61000000100000005000000514CDE0033814A40FC1873D7123A4B40514CDE0033814A402B323A20093B4B40CB4BFE277F834A402B323A20093B4B40CB4BFE277F834A40FC1873D7123A4B40514CDE0033814A40FC1873D7123A4B40
24631	Спасское	7	64	1683	52.926130999999998	52.949973	54.434449000000001	54.415371999999998	0103000020E61000000100000005000000E867EA758B764A4049D6E1E82A354B40E867EA758B764A40D4635B069C374B40A08A1BB798794A40D4635B069C374B40A08A1BB798794A4049D6E1E82A354B40E867EA758B764A4049D6E1E82A354B40
24437	Соколка	7	64	1683	52.856368000000003	52.886237000000001	54.670566000000001	54.641596999999997	0103000020E61000000100000005000000A4AB74779D6D4A40191BBAD91F524B40A4AB74779D6D4A409FE74F1BD5554B40A9C0C93670714A409FE74F1BD5554B40A9C0C93670714A40191BBAD91F524B40A4AB74779D6D4A40191BBAD91F524B40
24324	Ростовка	7	64	1683	53.046263000000003	53.063969	54.705257000000003	54.693286000000001	0103000020E61000000100000005000000E7012CF2EB854A4028637C98BD584B40E7012CF2EB854A40362383DC455A4B409A7ADD2230884A40362383DC455A4B409A7ADD2230884A4028637C98BD584B40E7012CF2EB854A4028637C98BD584B40
23740	Прогресс	7	64	1683	52.764974000000002	52.786928000000003	54.569783999999999	54.558300000000003	0103000020E61000000100000005000000292504ABEA614A40ACADD85F76474B40292504ABEA614A405CE49EAEEE484B404227840EBA644A405CE49EAEEE484B404227840EBA644A40ACADD85F76474B40292504ABEA614A40ACADD85F76474B40
24422	Подгорный	7	64	1683	52.880012000000001	52.910600000000002	54.643357999999999	54.629866999999997	0103000020E61000000100000005000000350BB43BA4704A4031EA5A7B9F504B40350BB43BA4704A405BCF108E59524B406ADE718A8E744A405BCF108E59524B406ADE718A8E744A4031EA5A7B9F504B40350BB43BA4704A4031EA5A7B9F504B40
23935	Победа	7	64	1683	52.658549999999998	52.673965000000003	54.679274999999997	54.667758999999997	0103000020E61000000100000005000000F163CC5D4B544A40094E7D2079554B40F163CC5D4B544A40C5FEB27BF2564B4007D3307C44564A40C5FEB27BF2564B4007D3307C44564A40094E7D2079554B40F163CC5D4B544A40094E7D2079554B40
24325	Петровка	7	64	1683	52.767552000000002	53.059018999999999	54.432281000000003	54.387107	0103000020E610000001000000050000005DFDD8243F624A40BE86E0B88C314B405DFDD8243F624A4052D7DAFB54374B40DB6B41EF8D874A4052D7DAFB54374B40DB6B41EF8D874A40BE86E0B88C314B405DFDD8243F624A40BE86E0B88C314B40
24241	Новое Сумароково	7	64	1683	53.016475	53.038133000000002	54.657417000000002	54.641466999999999	0103000020E61000000100000005000000CE1951DA1B824A404B3B35971B524B40CE1951DA1B824A40CF6A813D26544B40FEF2C98AE1844A40CF6A813D26544B40FEF2C98AE1844A404B3B35971B524B40CE1951DA1B824A404B3B35971B524B40
24132	Новая Александровка	7	64	1683	52.905963999999997	52.921388	54.576448999999997	54.565686999999997	0103000020E610000001000000050000003AADDBA0F6734A40DC627E6E68484B403AADDBA0F6734A40EC67B114C9494B40A376BF0AF0754A40EC67B114C9494B40A376BF0AF0754A40DC627E6E68484B403AADDBA0F6734A40DC627E6E68484B40
24174	Наратлы	7	64	1683	53.060096999999999	53.086894000000001	54.418844999999997	54.403398000000003	0103000020E610000001000000050000003ACB2C42B1874A40CBA2B08BA2334B403ACB2C42B1874A40EB8B84B69C354B40FC1BB4571F8B4A40EB8B84B69C354B40FC1BB4571F8B4A40CBA2B08BA2334B403ACB2C42B1874A40CBA2B08BA2334B40
24033	Малая Бугульма	7	64	1683	52.869743999999997	52.901733	54.522066000000002	54.499872000000003	0103000020E6100000010000000500000034F279C5536F4A40D31742CEFB3F4B4034F279C5536F4A40412D060FD3424B40AB5CA8FC6B734A40412D060FD3424B40AB5CA8FC6B734A40D31742CEFB3F4B4034F279C5536F4A40D31742CEFB3F4B40
24025	Кудашево	7	64	1683	52.587296000000002	52.623578999999999	54.750193000000003	54.735937	0103000020E610000001000000050000002B89EC832C4B4A404B75012F335E4B402B89EC832C4B4A401558005306604B4077BCC96FD14F4A401558005306604B4077BCC96FD14F4A404B75012F335E4B402B89EC832C4B4A404B75012F335E4B40
23872	Ключи	7	64	1683	53.011021999999997	53.032958999999998	54.562418999999998	54.551986999999997	0103000020E61000000100000005000000ACC43C2B69814A4098689082A7464B40ACC43C2B69814A4013D38558FD474B40EF8D210038844A4013D38558FD474B40EF8D210038844A4098689082A7464B40ACC43C2B69814A4098689082A7464B40
23446	Карабаш	7	64	1683	52.537880000000001	52.597760999999998	54.713147999999997	54.687764000000001	0103000020E6100000010000000500000014967840D9444A40DEAE97A608584B4014967840D9444A40999A046F485B4B4081E9B46E834C4A40999A046F485B4B4081E9B46E834C4A40DEAE97A608584B4014967840D9444A40DEAE97A608584B40
23743	Зеленая Роща	7	64	1683	52.732112999999998	52.764183000000003	54.453778999999997	54.433171000000002	0103000020E61000000100000005000000FCFCF7E0B55D4A40AE49B72572374B40FCFCF7E0B55D4A40484E266E153A4B406094A0BFD0614A40484E266E153A4B406094A0BFD0614A40AE49B72572374B40FCFCF7E0B55D4A40AE49B72572374B40
23820	Забугоровка	7	64	1683	52.772888000000002	52.79663	54.505085000000001	54.498094999999999	0103000020E6100000010000000500000045BC75FEED624A408BA6B393C13F4B4045BC75FEED624A409F5912A0A6404B409981CAF8F7654A409F5912A0A6404B409981CAF8F7654A408BA6B393C13F4B4045BC75FEED624A408BA6B393C13F4B40
24638	Ефановка	7	64	1683	52.835526999999999	52.849820000000001	54.479100000000003	54.464925999999998	0103000020E6100000010000000500000066F6798CF26A4A40B187F6B1823B4B4066F6798CF26A4A40BEC11726533D4B404DBED9E6C66C4A40BEC11726533D4B404DBED9E6C66C4A40B187F6B1823B4B4066F6798CF26A4A40B187F6B1823B4B40
24781	Восточный	7	64	1683	52.945625	52.966636000000001	54.507866	54.494408	0103000020E61000000100000005000000D7A3703D0A794A40BD70E7C2483F4B40D7A3703D0A794A400B60CAC001414B4071917BBABA7B4A400B60CAC001414B4071917BBABA7B4A40BD70E7C2483F4B40D7A3703D0A794A40BD70E7C2483F4B40
23560	Березовка	7	64	1683	52.782024	52.787872	54.578218	54.571218999999999	0103000020E61000000100000005000000F357C85C19644A404AED45B41D494B40F357C85C19644A40B1FA230C034A4B4091B75CFDD8644A40B1FA230C034A4B4091B75CFDD8644A404AED45B41D494B40F357C85C19644A404AED45B41D494B40
24491	Батыр	7	64	1683	52.861147000000003	52.873814000000003	54.612336999999997	54.604421000000002	0103000020E6100000010000000500000036069D103A6E4A400002D6AA5D4D4B4036069D103A6E4A40BC900E0F614E4B40BB641C23D96F4A40BC900E0F614E4B40BB641C23D96F4A400002D6AA5D4D4B4036069D103A6E4A400002D6AA5D4D4B40
23451	Андреевка	7	64	1683	52.586145999999999	52.607408999999997	54.381743	54.362341999999998	0103000020E61000000100000005000000325706D5064B4A40CEFBFF38612E4B40325706D5064B4A400C3D62F4DC304B40E525FF93BF4D4A400C3D62F4DC304B40E525FF93BF4D4A40CEFBFF38612E4B40325706D5064B4A40CEFBFF38612E4B40
40934	Акбаш	7	64	1683	52.581636000000003	52.607562000000001	54.425750000000001	54.412097000000003	0103000020E610000001000000050000009016670C734A4A40CEE33098BF344B409016670C734A4A40D122DBF97E364B406C257497C44D4A40D122DBF97E364B406C257497C44D4A40CEE33098BF344B409016670C734A4A40CEE33098BF344B40
40336	Бугульма	7	64	6902	52.486764999999998	53.145159	54.804498000000002	54.266773000000001	0103000020E6100000010000000500000031EBC5504E3E4A40583A1F9E25224B4031EBC5504E3E4A4045D95BCAF9664B402BDCF29194924A4045D95BCAF9664B402BDCF29194924A40583A1F9E25224B4031EBC5504E3E4A40583A1F9E25224B40
21527	Ярак-Чурма	7	64	1620	50.148198999999998	50.159311000000002	56.384000999999998	56.377592	0103000020E610000001000000050000006326512FF8124940999D45EF54304C406326512FF8124940CE50DCF126314C405072874D64144940CE50DCF126314C405072874D64144940999D45EF54304C406326512FF8124940999D45EF54304C40
21672	Янгулово	7	64	1620	50.378312000000001	50.416525999999998	56.420752	56.400638000000001	0103000020E6100000010000000500000099D711876C30494076C4211B48334C4099D711876C30494001DD9733DB354C4083F755B95035494001DD9733DB354C4083F755B95035494076C4211B48334C4099D711876C30494076C4211B48334C40
21390	Шишинер	7	64	1620	50.478375	50.498353999999999	56.476472999999999	56.455278999999997	0103000020E61000000100000005000000AC1C5A643B3D49401DC70F95463A4C40AC1C5A643B3D4940A8363811FD3C4C4057EA5910CA3F4940A8363811FD3C4C4057EA5910CA3F49401DC70F95463A4C40AC1C5A643B3D49401DC70F95463A4C40
20976	Чутай	7	64	1620	50.500104999999998	50.524799999999999	56.517063	56.507547000000002	0103000020E6100000010000000500000075C8CD70034049406A17D34CF7404C4075C8CD70034049405F7CD11E2F424C406C787AA52C4349405F7CD11E2F424C406C787AA52C4349406A17D34CF7404C4075C8CD70034049406A17D34CF7404C40
21531	Ципья	7	64	1620	50.278391999999997	50.320757	56.533749999999998	56.518548000000003	0103000020E61000000100000005000000E8BB5B59A2234940FFB3E6C75F424C40E8BB5B59A2234940B81E85EB51444C40467BBC900E294940B81E85EB51444C40467BBC900E294940FFB3E6C75F424C40E8BB5B59A2234940FFB3E6C75F424C40
21349	Тюнтер	7	64	1620	50.231122999999997	50.257731	56.478546000000001	56.463312000000002	0103000020E610000001000000050000003C2D3F70951D494014ECBFCE4D3B4C403C2D3F70951D4940D9D0CDFE403D4C402B155454FD204940D9D0CDFE403D4C402B155454FD20494014ECBFCE4D3B4C403C2D3F70951D494014ECBFCE4D3B4C40
21738	Старый Кушкет	7	64	1620	50.310524999999998	50.332839	56.43262	56.415793000000001	0103000020E6100000010000000500000092CB7F48BF274940EF737CB438354C4092CB7F48BF2749403ACC971760374C40ABEAE5779A2A49403ACC971760374C40ABEAE5779A2A4940EF737CB438354C4092CB7F48BF274940EF737CB438354C40
21122	Старая Салаусь	7	64	1620	50.315995999999998	50.338956000000003	56.374332000000003	56.357095999999999	0103000020E610000001000000050000005AD5928E7228494026C45C52B52D4C405AD5928E7228494053EC681CEA2F4C40396403E9622B494053EC681CEA2F4C40396403E9622B494026C45C52B52D4C405AD5928E7228494026C45C52B52D4C40
21342	Средний Кушкет	7	64	1620	50.267288999999998	50.287995000000002	56.451678000000001	56.441772	0103000020E610000001000000050000004FCAA48636224940EE2422FC8B384C404FCAA486362249404E29AF95D0394C40AD342905DD2449404E29AF95D0394C40AD342905DD244940EE2422FC8B384C404FCAA48636224940EE2422FC8B384C40
21254	Смаиль	7	64	1620	50.441561999999998	50.463427000000003	56.487065999999999	56.466171000000003	0103000020E610000001000000050000000394861A85384940FCABC77DAB3B4C400394861A853849402C7FBE2D583E4C40AD8A7093513B49402C7FBE2D583E4C40AD8A7093513B4940FCABC77DAB3B4C400394861A85384940FCABC77DAB3B4C40
21061	Пижмар	7	64	1620	50.351298999999997	50.370882999999999	56.600866000000003	56.58578	0103000020E610000001000000050000000A0F9A5DF72C49405053CBD6FA4A4C400A0F9A5DF72C4940A1A3552DE94C4C4039D21918792F4940A1A3552DE94C4C4039D21918792F49405053CBD6FA4A4C400A0F9A5DF72C49405053CBD6FA4A4C40
20968	Нуринер	7	64	1620	50.448748999999999	50.48451	56.537894999999999	56.517598999999997	0103000020E610000001000000050000006D8E739B703949409DB81CAF40424C406D8E739B7039494049D74CBED9444C40E04A766C043E494049D74CBED9444C40E04A766C043E49409DB81CAF40424C406D8E739B703949409DB81CAF40424C40
20806	Норма	7	64	1620	50.269148000000001	50.294786000000002	56.341383	56.329346999999999	0103000020E6100000010000000500000054E41071732249409204E10A282A4C4054E410717322494087342A70B22B4C40CAA8328CBB25494087342A70B22B4C40CAA8328CBB2549409204E10A282A4C4054E41071732249409204E10A282A4C40
21177	Нижняя Сосна	7	64	1620	50.217441000000001	50.245055999999998	56.389054000000002	56.357460000000003	0103000020E610000001000000050000009FE74F1BD51B494068D0D03FC12D4C409FE74F1BD51B494062307F85CC314C4023D8B8FE5D1F494062307F85CC314C4023D8B8FE5D1F494068D0D03FC12D4C409FE74F1BD51B494068D0D03FC12D4C40
20648	Нижняя Кня	7	64	1620	50.016057000000004	50.041936999999997	56.338369	56.329211999999998	0103000020E610000001000000050000009AEFE0270E024940B2B96A9E232A4C409AEFE0270E024940787DE6AC4F2B4C4005BF0D315E054940787DE6AC4F2B4C4005BF0D315E054940B2B96A9E232A4C409AEFE0270E024940B2B96A9E232A4C40
21826	Малые Лызи	7	64	1620	50.135613999999997	50.153733000000003	56.351500000000001	56.343767999999997	0103000020E610000001000000050000009B70AFCC5B114940A6B4FE96002C4C409B70AFCC5B114940A245B6F3FD2C4C4072A8DF85AD134940A245B6F3FD2C4C4072A8DF85AD134940A6B4FE96002C4C409B70AFCC5B114940A6B4FE96002C4C40
20550	Кушкетбаш	7	64	1620	50.158583999999998	50.190545999999998	56.451787000000003	56.439070000000001	0103000020E610000001000000050000009DD5027B4C144940CE531D7233384C409DD5027B4C14494005E10A28D4394C401A31B3CF6318494005E10A28D4394C401A31B3CF63184940CE531D7233384C409DD5027B4C144940CE531D7233384C40
20752	Кугунур	7	64	1620	50.222552999999998	50.262706999999999	56.619853999999997	56.600569	0103000020E610000001000000050000003750E09D7C1C4940E7FEEA71DF4C4C403750E09D7C1C4940BB253960574F4C4013B70A62A0214940BB253960574F4C4013B70A62A0214940E7FEEA71DF4C4C403750E09D7C1C4940E7FEEA71DF4C4C40
20869	Килеево	7	64	1620	50.285640999999998	50.307865999999997	56.310687000000001	56.300998999999997	0103000020E61000000100000005000000C8B260E28F24494079909E2287264C40C8B260E28F2449406C257497C4274C4071C63027682749406C257497C4274C4071C630276827494079909E2287264C40C8B260E28F24494079909E2287264C40
20642	Карадуван	7	64	1620	50.092432000000002	50.108789999999999	56.346131999999997	56.340535000000003	0103000020E610000001000000050000004C8DD0CFD40B49405A12A0A6962B4C404C8DD0CFD40B4940AE0CAA0D4E2C4C40E010AAD4EC0D4940AE0CAA0D4E2C4C40E010AAD4EC0D49405A12A0A6962B4C404C8DD0CFD40B49405A12A0A6962B4C40
20762	Дурга	7	64	1620	50.288803999999999	50.312258999999997	56.600222000000002	56.586959999999998	0103000020E610000001000000050000001C7A8B87F7244940B3075A81214B4C401C7A8B87F72449407C2B1213D44C4C40DA70581AF82749407C2B1213D44C4C40DA70581AF8274940B3075A81214B4C401C7A8B87F7244940B3075A81214B4C40
21444	Верхний Шубан	7	64	1620	50.063451999999998	50.079037999999997	56.377282999999998	56.366878999999997	0103000020E61000000100000005000000D26EF4311F0849406A4B1DE4F52E4C40D26EF4311F0849401B2B31CF4A304C401492CCEA1D0A49401B2B31CF4A304C401492CCEA1D0A49406A4B1DE4F52E4C40D26EF4311F0849406A4B1DE4F52E4C40
20484	Верхний Субаш	7	64	1620	50.107595000000003	50.131005000000002	56.492016	56.484878999999999	0103000020E61000000100000005000000481B47ACC50D494033C2DB83103E4C40481B47ACC50D4940EB8D5A61FA3E4C40664E97C5C4104940EB8D5A61FA3E4C40664E97C5C410494033C2DB83103E4C40481B47ACC50D494033C2DB83103E4C40
21257	Бурнак	7	64	1620	50.375967000000003	50.404156	56.437094000000002	56.425412000000001	0103000020E6100000010000000500000008B0C8AF1F304940B9A981E673364C4008B0C8AF1F30494090A339B2F2374C40B83D4162BB33494090A339B2F2374C40B83D4162BB334940B9A981E673364C4008B0C8AF1F304940B9A981E673364C40
20422	Бурбаш	7	64	1620	50.393520000000002	50.428401999999998	56.305619	56.293767000000003	0103000020E61000000100000005000000352905DD5E32494070D234289A254C40352905DD5E324940A304FD851E274C403FC571E0D5364940A304FD851E274C403FC571E0D536494070D234289A254C40352905DD5E32494070D234289A254C40
59178	Балтаси	7	64	1620	50.182129000000003	50.239638999999997	56.353430000000003	56.337322	0103000020E610000001000000050000009C53C90050174940541C075E2D2B4C409C53C9005017494070B6B9313D2D4C404EECA17DAC1E494070B6B9313D2D4C404EECA17DAC1E4940541C075E2D2B4C409C53C90050174940541C075E2D2B4C40
20291	Балтаси	7	64	1620	50.182129000000003	50.239638999999997	56.353430000000003	56.337322	0103000020E610000001000000050000009C53C90050174940541C075E2D2B4C409C53C9005017494070B6B9313D2D4C404EECA17DAC1E494070B6B9313D2D4C404EECA17DAC1E4940541C075E2D2B4C409C53C90050174940541C075E2D2B4C40
21067	Атня	7	64	1620	50.350769	50.372993999999998	56.638945999999997	56.631025000000001	0103000020E61000000100000005000000AEB9A3FFE52C4940ADFA5C6DC5504C40AEB9A3FFE52C49407BF486FBC8514C4057CD7344BE2F49407BF486FBC8514C4057CD7344BE2F4940ADFA5C6DC5504C40AEB9A3FFE52C4940ADFA5C6DC5504C40
21616	Арбор	7	64	1620	50.193114999999999	50.235793999999999	56.553699999999999	56.538316999999999	0103000020E61000000100000005000000FBAE08FEB7184940BFF04A92E7444C40FBAE08FEB7184940C9E53FA4DF464C40E84B6F7F2E1E4940C9E53FA4DF464C40E84B6F7F2E1E4940BFF04A92E7444C40FBAE08FEB7184940BFF04A92E7444C40
61366	п.Новозареченск	7	64	1546	52.950000000000003	53.504125000000002	54.573400999999997	53.974775999999999	0103000020E610000001000000050000009A99999999794A407D76C075C5FC4A409A99999999794A40313F373465494B404A0C022B87C04A40313F373465494B404A0C022B87C04A407D76C075C5FC4A409A99999999794A407D76C075C5FC4A40
19724	Шалты	7	64	1546	53.436580999999997	53.461950000000002	54.109009999999998	54.086185	0103000020E610000001000000050000000987DEE2E1B74A40F0332E1C080B4B400987DEE2E1B74A40EE77280AF40D4B409031772D21BB4A40EE77280AF40D4B409031772D21BB4A40F0332E1C080B4B400987DEE2E1B74A40F0332E1C080B4B40
19730	Хансверкино	7	64	1546	53.354914999999998	53.373187000000001	54.048358	54.036689000000003	0103000020E610000001000000050000000FEECEDA6DAD4A40BD8FA339B2044B400FEECEDA6DAD4A40FF3F4E9830064B406C257497C4AF4A40FF3F4E9830064B406C257497C4AF4A40BD8FA339B2044B400FEECEDA6DAD4A40BD8FA339B2044B40
20179	Удмуртские Ташлы	7	64	1546	53.129465000000003	53.159657000000003	54.308782000000001	54.292641000000003	0103000020E61000000100000005000000037D224F92904A40003CA24275254B40037D224F92904A40F7CB272B86274B40EBC9FCA36F944A40F7CB272B86274B40EBC9FCA36F944A40003CA24275254B40037D224F92904A40003CA24275254B40
19056	Уба	7	64	1546	53.400029000000004	53.414850999999999	54.500143999999999	54.487202000000003	0103000020E61000000100000005000000CE39782634B34A40DD4598A25C3E4B40CE39782634B34A4033A5F5B704404B4040DB6AD619B54A4033A5F5B704404B4040DB6AD619B54A40DD4598A25C3E4B40CE39782634B34A40DD4598A25C3E4B40
61421	Ташлы	7	64	1546	53.220680000000002	53.241610999999999	54.493837999999997	54.481783	0103000020E61000000100000005000000CE70033E3F9C4A406762BA10AB3D4B40CE70033E3F9C4A40D2C26515363F4B404BADF71BED9E4A40D2C26515363F4B404BADF71BED9E4A406762BA10AB3D4B40CE70033E3F9C4A406762BA10AB3D4B40
19932	Татарский Кандыз	7	64	1546	53.10566	53.157870000000003	54.138764999999999	54.119708000000003	0103000020E61000000100000005000000683F5244868D4A40E8887C97520F4B40683F5244868D4A402B6A300DC3114B4080828B1535944A402B6A300DC3114B4080828B1535944A40E8887C97520F4B40683F5244868D4A40E8887C97520F4B40
19512	Татарская Тумбарла	7	64	1546	53.249453000000003	53.287542000000002	54.322358000000001	54.312784000000001	0103000020E61000000100000005000000CE716E13EE9F4A40255B5D4E09284B40CE716E13EE9F4A404FCDE50643294B40FC1C1F2DCEA44A404FCDE50643294B40FC1C1F2DCEA44A40255B5D4E09284B40CE716E13EE9F4A40255B5D4E09284B40
19840	Салихово	7	64	1546	53.281613	53.315587000000001	54.106788000000002	54.097670000000001	0103000020E61000000100000005000000719010E50BA44A4071E65773800C4B40719010E50BA44A4079CDAB3AAB0D4B407905A22765A84A4079CDAB3AAB0D4B407905A22765A84A4071E65773800C4B40719010E50BA44A4071E65773800C4B40
20286	Потапово-Тумбарла	7	64	1546	53.148240000000001	53.192329000000001	54.369891000000003	54.352179	0103000020E61000000100000005000000C2FA3F87F9924A4043AB9333142D4B40C2FA3F87F9924A40D90A9A96582F4B404489963C9E984A40D90A9A96582F4B404489963C9E984A4043AB9333142D4B40C2FA3F87F9924A4043AB9333142D4B40
20056	Поповка	7	64	1546	53.214446000000002	53.268030000000003	54.202603000000003	54.176900000000003	0103000020E6100000010000000500000007616EF7729B4A40CA54C1A8A4164B4007616EF7729B4A40278925E5EE194B40672C9ACE4EA24A40278925E5EE194B40672C9ACE4EA24A40CA54C1A8A4164B4007616EF7729B4A40CA54C1A8A4164B40
19523	Покровский Урустамак	7	64	1546	53.353541	53.406928000000001	54.260857000000001	54.252768000000003	0103000020E61000000100000005000000C765DCD440AD4A40D8BCAAB35A204B40C765DCD440AD4A4062F71DC363214B40D1E9793716B44A4062F71DC363214B40D1E9793716B44A40D8BCAAB35A204B40C765DCD440AD4A40D8BCAAB35A204B40
19780	Новые Чути	7	64	1546	53.323653999999998	53.345635999999999	54.076703999999999	54.063747999999997	0103000020E610000001000000050000001B9C887E6DA94A40BB97FBE428084B401B9C887E6DA94A4077BCC96FD1094B40FE28EACC3DAC4A4077BCC96FD1094B40FE28EACC3DAC4A40BB97FBE428084B401B9C887E6DA94A40BB97FBE428084B40
19617	Николашкино	7	64	1546	53.356504999999999	53.388036	54.206600000000002	54.191136	0103000020E6100000010000000500000024EEB1F4A1AD4A404C8BFA2477184B4024EEB1F4A1AD4A4043AD69DE711A4B40D8D5E429ABB14A4043AD69DE711A4B40D8D5E429ABB14A404C8BFA2477184B4024EEB1F4A1AD4A404C8BFA2477184B40
19410	Муртаза	7	64	1546	53.116501999999997	53.144233	54.483677	54.466805000000001	0103000020E6100000010000000500000094F59B89E98E4A40FD4D2844C03B4B4094F59B89E98E4A40E869C020E93D4B408200193A76924A40E869C020E93D4B408200193A76924A40FD4D2844C03B4B4094F59B89E98E4A40FD4D2844C03B4B40
19351	Крым-Сарай	7	64	1546	53.102102000000002	53.130021999999997	54.561093	54.515790000000003	0103000020E61000000100000005000000986DA7AD118D4A404BCD1E6805424B40986DA7AD118D4A40DC813AE5D1474B4058E1968FA4904A40DC813AE5D1474B4058E1968FA4904A404BCD1E6805424B40986DA7AD118D4A404BCD1E6805424B40
19011	Кзыл-Яр	7	64	1546	53.373942	53.393103000000004	54.427529999999997	54.403655000000001	0103000020E61000000100000005000000E84CDA54DDAF4A40F6EE8FF7AA334B40E84CDA54DDAF4A408907944DB9364B40D17AF83251B24A408907944DB9364B40D17AF83251B24A40F6EE8FF7AA334B40E84CDA54DDAF4A40F6EE8FF7AA334B40
19415	Исергапово	7	64	1546	53.365299999999998	53.401547000000001	54.340445000000003	54.319386000000002	0103000020E61000000100000005000000499D8026C2AE4A406F66F4A3E1284B40499D8026C2AE4A401A8BA6B3932B4B40496760E465B34A401A8BA6B3932B4B40496760E465B34A406F66F4A3E1284B40499D8026C2AE4A406F66F4A3E1284B40
20044	Верхняя Фоминовка	7	64	1546	53.05292	53.087828000000002	54.195503000000002	54.163986000000001	0103000020E61000000100000005000000F4A62215C6864A403D80457EFD144B40F4A62215C6864A408CA2073E06194B4028D6A9F23D8B4A408CA2073E06194B4028D6A9F23D8B4A403D80457EFD144B40F4A62215C6864A403D80457EFD144B40
19266	Васькино Туйралы	7	64	1546	53.161785999999999	53.182493000000001	54.409084	54.392229	0103000020E61000000100000005000000AF795567B5944A407AC5538F34324B40AF795567B5944A408FA850DD5C344B40DD5F3DEE5B974A408FA850DD5C344B40DD5F3DEE5B974A407AC5538F34324B40AF795567B5944A407AC5538F34324B40
60491	Бавлы	7	64	1546	53.374993000000003	53.383023999999999	54.377237999999998	54.367179	0103000020E610000001000000050000004E9D47C5FFAF4A409563B2B8FF2E4B404E9D47C5FFAF4A407B67B45549304B40A3CA30EE06B14A407B67B45549304B40A3CA30EE06B14A409563B2B8FF2E4B404E9D47C5FFAF4A409563B2B8FF2E4B40
20113	Алексеевка	7	64	1546	53.188583000000001	53.212128	54.256439	54.229322000000003	0103000020E6100000010000000500000071CADC7C23984A406D205D6C5A1D4B4071CADC7C23984A40A0353FFED2204B406F48A302279B4A40A0353FFED2204B406F48A302279B4A406D205D6C5A1D4B4071CADC7C23984A406D205D6C5A1D4B40
19116	Александровка	7	64	1546	53.267096000000002	53.293227999999999	54.476326999999998	54.457076000000001	0103000020E610000001000000050000003B72A43330A24A40ACE46377813A4B403B72A43330A24A40D4997B48F83C4B40C022BF7E88A54A40D4997B48F83C4B40C022BF7E88A54A40ACE46377813A4B403B72A43330A24A40ACE46377813A4B40
61532	Татарская Чишма	7	64	1481	49.576259999999998	49.596131	56.340690000000002	56.328403999999999	0103000020E6100000010000000500000019FF3EE3C2C9484013F06B24092A4C4019FF3EE3C2C948408109DCBA9B2B4C40DE9046054ECC48408109DCBA9B2B4C40DE9046054ECC484013F06B24092A4C4019FF3EE3C2C9484013F06B24092A4C40
18349	Старый Югуп	7	64	1481	49.424939000000002	49.455679000000003	56.372418000000003	56.363618000000002	0103000020E61000000100000005000000C1E5B16664B64840541EDD088B2E4C40C1E5B16664B648408B389D64AB2F4C40AC3C81B053BA48408B389D64AB2F4C40AC3C81B053BA4840541EDD088B2E4C40C1E5B16664B64840541EDD088B2E4C40
32507	Старый Узюм	7	64	1481	49.551098000000003	49.577958000000002	56.349249999999998	56.337217000000003	0103000020E610000001000000050000000D7217618AC64840DF5339ED292B4C400D7217618AC6484062105839B42C4C40153B1A87FAC9484062105839B42C4C40153B1A87FAC94840DF5339ED292B4C400D7217618AC64840DF5339ED292B4C40
18257	Новые Шаши	7	64	1481	49.454394000000001	49.468308999999998	56.370553000000001	56.357334999999999	0103000020E61000000100000005000000D3BF249529BA4840AB5B3D27BD2D4C40D3BF249529BA4840A437DC476E2F4C4013B69F8CF1BB4840A437DC476E2F4C4013B69F8CF1BB4840AB5B3D27BD2D4C40D3BF249529BA4840AB5B3D27BD2D4C40
17872	Нижний Куюк	7	64	1481	49.277003999999998	49.304636000000002	56.294626000000001	56.282265000000002	0103000020E610000001000000050000003B6EF8DD74A3484019E76F4221244C403B6EF8DD74A348409146054EB6254C409697FC4FFEA648409146054EB6254C409697FC4FFEA6484019E76F4221244C403B6EF8DD74A3484019E76F4221244C40
17164	Нижнее Береске	7	64	1481	49.315578000000002	49.353648	56.247301	56.224516999999999	0103000020E6100000010000000500000026AB22DC64A84840B1321AF9BC1C4C4026AB22DC64A8484051A2258FA71F4C40DD25715644AD484051A2258FA71F4C40DD25715644AD4840B1321AF9BC1C4C4026AB22DC64A84840B1321AF9BC1C4C40
17072	Малая Атня	7	64	1481	49.455544000000003	49.474561999999999	56.235491000000003	56.223176000000002	0103000020E61000000100000005000000CCF10A444FBA484045A0FA07911C4C40CCF10A444FBA48404DC0AF91241E4C4051F69672BEBC48404DC0AF91241E4C4051F69672BEBC484045A0FA07911C4C40CCF10A444FBA484045A0FA07911C4C40
61468	Кызыл-Утар	7	64	1481	49.553263000000001	49.561177000000001	56.380527999999998	56.368594000000002	0103000020E610000001000000050000001E8B6D52D1C648403CC093162E2F4C401E8B6D52D1C648402C9B3924B5304C403A22DFA5D4C748402C9B3924B5304C403A22DFA5D4C748403CC093162E2F4C401E8B6D52D1C648403CC093162E2F4C40
17781	Кшклово	7	64	1481	49.479314000000002	49.507430999999997	56.353754000000002	56.337226999999999	0103000020E61000000100000005000000EA4141295ABD4840022A1C412A2B4C40EA4141295ABD4840236AA2CF472D4C4000FDBE7FF3C04840236AA2CF472D4C4000FDBE7FF3C04840022A1C412A2B4C40EA4141295ABD4840022A1C412A2B4C40
17518	Кунгер	7	64	1481	49.472873	49.495500999999997	56.323757000000001	56.311906	0103000020E61000000100000005000000A9143B1A87BC48408DB62A89EC274C40A9143B1A87BC4840F06C8FDE70294C405111A7936CBF4840F06C8FDE70294C405111A7936CBF48408DB62A89EC274C40A9143B1A87BC48408DB62A89EC274C40
17673	Кулле-Кими	7	64	1481	49.274676999999997	49.301600000000001	56.338639000000001	56.325684000000003	0103000020E6100000010000000500000050FBAD9D28A348404D6A6803B0294C4050FBAD9D28A348403813D385582B4C409F3C2CD49AA648403813D385582B4C409F3C2CD49AA648404D6A6803B0294C4050FBAD9D28A348404D6A6803B0294C40
17583	Кубян	7	64	1481	49.369799999999998	49.405678999999999	56.310248000000001	56.280411999999998	0103000020E61000000100000005000000C8073D9B55AF4840F6B3588AE4234C40C8073D9B55AF484020D3DA34B6274C4045D61A4AEDB3484020D3DA34B6274C4045D61A4AEDB34840F6B3588AE4234C40C8073D9B55AF4840F6B3588AE4234C40
18119	Кошар	7	64	1481	49.504547000000002	49.525855	56.293407000000002	56.281376000000002	0103000020E61000000100000005000000C02500FF94C048408DF0F62004244C40C02500FF94C0484070B54E5C8E254C4013B875374FC3484070B54E5C8E254C4013B875374FC348408DF0F62004244C40C02500FF94C048408DF0F62004244C40
17465	Коморгузя	7	64	1481	49.444037000000002	49.473654000000003	56.164721999999998	56.143794999999997	0103000020E61000000100000005000000639B5434D6B84840062AE3DF67124C40639B5434D6B848404277499C15154C404FCFBBB1A0BC48404277499C15154C404FCFBBB1A0BC4840062AE3DF67124C40639B5434D6B84840062AE3DF67124C40
18362	Ключи-Сап	7	64	1481	49.416063000000001	49.436490999999997	56.429912000000002	56.416046999999999	0103000020E61000000100000005000000AF09698D41B54840A94C310741354C40AF09698D41B5484038143E5B07374C40C9FFE4EFDEB7484038143E5B07374C40C9FFE4EFDEB74840A94C310741354C40AF09698D41B54840A94C310741354C40
17362	Каенсар	7	64	1481	49.325871999999997	49.333920999999997	56.311416000000001	56.305309000000001	0103000020E610000001000000050000004F57772CB6A948405516855D14274C404F57772CB6A94840BFB9BF7ADC274C404B395FECBDAA4840BFB9BF7ADC274C404B395FECBDAA48405516855D14274C404F57772CB6A948405516855D14274C40
17676	Ислейтар	7	64	1481	49.145428000000003	49.170644000000003	56.333329999999997	56.318230999999997	0103000020E610000001000000050000001BF67B629D92484064C91CCBBB284C401BF67B629D9248404963B48EAA2A4C401BA19FA9D79548404963B48EAA2A4C401BA19FA9D795484064C91CCBBB284C401BF67B629D92484064C91CCBBB284C40
17214	Дусюм	7	64	1481	49.433895	49.451250000000002	56.303986000000002	56.294086	0103000020E61000000100000005000000EF7211DF89B74840111B2C9CA4254C40EF7211DF89B748408F386403E9264C40F6285C8FC2B948408F386403E9264C40F6285C8FC2B94840111B2C9CA4254C40EF7211DF89B74840111B2C9CA4254C40
17451	Верхняя Серда	7	64	1481	49.557153	49.574283999999999	56.134801000000003	56.12256	0103000020E6100000010000000500000024EF1CCA50C748401DE6CB0BB00F4C4024EF1CCA50C74840EB3BBF2841114C40DB4E5B2382C94840EB3BBF2841114C40DB4E5B2382C948401DE6CB0BB00F4C4024EF1CCA50C748401DE6CB0BB00F4C40
17974	Верхний Куюк	7	64	1481	49.245733999999999	49.275449999999999	56.31561	56.307541000000001	0103000020E61000000100000005000000F4C13236749F4840EE96E4805D274C40F4C13236749F4840312592E865284C4073D712F241A34840312592E865284C4073D712F241A34840EE96E4805D274C40F4C13236749F4840EE96E4805D274C40
18062	Большой Менгер	7	64	1481	49.558095999999999	49.583249000000002	56.248491000000001	56.231377999999999	0103000020E61000000100000005000000A30392B06FC74840C78157CB9D1D4C40A30392B06FC74840D82C978DCE1F4C405D363AE7A7CA4840D82C978DCE1F4C405D363AE7A7CA4840C78157CB9D1D4C40A30392B06FC74840C78157CB9D1D4C40
17174	Большие Берези	7	64	1481	49.257897	49.276654000000001	56.231952999999997	56.210932999999997	0103000020E61000000100000005000000465ED6C402A14840D65240DAFF1A4C40465ED6C402A14840C39ACAA2B01D4C405F27F56569A34840C39ACAA2B01D4C405F27F56569A34840D65240DAFF1A4C40465ED6C402A14840D65240DAFF1A4C40
16979	Большая Атня	7	64	1481	49.430444999999999	49.467357	56.267896999999998	56.241404000000003	0103000020E6100000010000000500000005DD5ED218B74840D28F8653E61E4C4005DD5ED218B7484027D9EA724A224C404147AB5AD2BB484027D9EA724A224C404147AB5AD2BB4840D28F8653E61E4C4005DD5ED218B74840D28F8653E61E4C40
18073	Бахтияр	7	64	1481	49.590381000000001	49.616424000000002	56.215608000000003	56.203381999999998	0103000020E610000001000000050000000397C79A91CB48402B4CDF6B081A4C400397C79A91CB4840C460FE0A991B4C40193C4CFBE6CE4840C460FE0A991B4C40193C4CFBE6CE48402B4CDF6B081A4C400397C79A91CB48402B4CDF6B081A4C40
16926	Янга-Сала	7	64	1263	49.970790999999998	49.994039000000001	55.993746000000002	55.979742000000002	0103000020E61000000100000005000000252026E142FC48404242942F68FD4B40252026E142FC4840F243A51133FF4B406AF981AB3CFF4840F243A51133FF4B406AF981AB3CFF48404242942F68FD4B40252026E142FC48404242942F68FD4B40
16779	Шушмабаш	7	64	1263	49.862535000000001	49.890203	56.397120999999999	56.384509999999999	0103000020E61000000100000005000000E353008C67EE4840137EA99F37314C40E353008C67EE484004C765DCD4324C408AE6012CF2F1484004C765DCD4324C408AE6012CF2F14840137EA99F37314C40E353008C67EE4840137EA99F37314C40
14527	Шурабаш	7	64	1263	49.700029999999998	49.720762999999998	56.484695000000002	56.470134000000002	0103000020E61000000100000005000000041C42959AD948406C5ED5592D3C4C40041C42959AD9484072C45A7C0A3E4C405B9544F641DC484072C45A7C0A3E4C405B9544F641DC48406C5ED5592D3C4C40041C42959AD948406C5ED5592D3C4C40
14575	Шура	7	64	1263	49.668140000000001	49.684694999999998	56.497813999999998	56.481872000000003	0103000020E6100000010000000500000021938C9C85D54840D76D50FBAD3D4C4021938C9C85D54840D7BE805EB83F4C400B5EF415A4D74840D7BE805EB83F4C400B5EF415A4D74840D76D50FBAD3D4C4021938C9C85D54840D76D50FBAD3D4C40
15782	Штырь	7	64	1263	49.792465999999997	49.810899999999997	55.968952000000002	55.952772000000003	0103000020E610000001000000050000009198A0866FE54840B345D26EF4F94B409198A0866FE5484068B27F9E06FC4B40C7293A92CBE7484068B27F9E06FC4B40C7293A92CBE74840B345D26EF4F94B409198A0866FE54840B345D26EF4F94B40
16880	Шека	7	64	1263	49.821446000000002	49.846544999999999	56.409199999999998	56.393818000000003	0103000020E610000001000000050000000BB77C2425E94840BF49D3A068324C400BB77C2425E94840F8C264AA60344C40D1CB28965BEC4840F8C264AA60344C40D1CB28965BEC4840BF49D3A068324C400BB77C2425E94840BF49D3A068324C40
14076	Хасаншаих	7	64	1263	50.010199999999998	50.029074000000001	56.364505999999999	56.353585000000002	0103000020E61000000100000005000000A835CD3B4E01494097ADF545422D4C40A835CD3B4E0149400F99F221A82E4C40FB9463B2B80349400F99F221A82E4C40FB9463B2B803494097ADF545422D4C40A835CD3B4E01494097ADF545422D4C40
14870	Учили	7	64	1263	49.798242999999999	49.814044000000003	56.185903000000003	56.174109000000001	0103000020E6100000010000000500000066A19DD32CE648403A78263449164C4066A19DD32CE64840399D64ABCB174C40A5C0029832E84840399D64ABCB174C40A5C0029832E848403A78263449164C4066A19DD32CE648403A78263449164C40
16576	Утар-Аты	7	64	1263	49.649661000000002	49.668489999999998	56.159328000000002	56.146391999999999	0103000020E610000001000000050000004B3E761728D34840B1321AF9BC124C404B3E761728D3484026AB22DC64144C40FDD98F1491D5484026AB22DC64144C40FDD98F1491D54840B1321AF9BC124C404B3E761728D34840B1321AF9BC124C40
16259	Урняк	7	64	1263	49.901269999999997	50.012130999999997	56.306583000000003	56.223225999999997	0103000020E61000000100000005000000D66EBBD05CF34840F6CE68AB921C4C40D66EBBD05CF348403A419B1C3E274C40462234828D0149403A419B1C3E274C40462234828D014940F6CE68AB921C4C40D66EBBD05CF34840F6CE68AB921C4C40
18510	Тюбяк-Чекурча	7	64	1263	49.909993	49.947434999999999	56.085605999999999	56.076467999999998	0103000020E61000000100000005000000624B8FA67AF44840639813B4C9094C40624B8FA67AF44840B22B2D23F50A4C40FA0AD28C45F94840B22B2D23F50A4C40FA0AD28C45F94840639813B4C9094C40624B8FA67AF44840639813B4C9094C40
61526	Ташкич	7	64	1263	50.212778999999998	50.233009000000003	56.202446000000002	56.195219999999999	0103000020E6100000010000000500000046239F573C1B494037C30DF8FC184C4046239F573C1B49405F9A22C0E9194C403B56293DD31D49405F9A22C0E9194C403B56293DD31D494037C30DF8FC184C4046239F573C1B494037C30DF8FC184C40
14435	Сюрда	7	64	1263	49.635027999999998	49.656101999999997	56.402346000000001	56.388520999999997	0103000020E61000000100000005000000AB05F69848D1484094675E0EBB314C40AB05F69848D1484095D6DF1280334C408B6B7C26FBD3484095D6DF1280334C408B6B7C26FBD3484094675E0EBB314C40AB05F69848D1484094675E0EBB314C40
15450	Старый Яваш	7	64	1263	49.815966000000003	49.830455999999998	56.232357999999998	56.222821000000003	0103000020E61000000100000005000000F052EA9271E8484057EE0566851C4C40F052EA9271E84840637B2DE8BD1D4C402C62D8614CEA4840637B2DE8BD1D4C402C62D8614CEA484057EE0566851C4C40F052EA9271E8484057EE0566851C4C40
15396	Старый Кырлай	7	64	1263	49.887203	49.913164000000002	56.203381999999998	56.189194000000001	0103000020E61000000100000005000000E0F42EDE8FF14840BA4C4D8237184C40E0F42EDE8FF148402B4CDF6B081A4C4039F1D58EE2F448402B4CDF6B081A4C4039F1D58EE2F44840BA4C4D8237184C40E0F42EDE8FF14840BA4C4D8237184C40
14723	Старый Кишит	7	64	1263	49.625532	49.653272000000001	56.255968000000003	56.245595000000002	0103000020E61000000100000005000000FD4CBD6E11D04840D3872EA86F1F4C40FD4CBD6E11D048404969368FC3204C403EB2B96A9ED348404969368FC3204C403EB2B96A9ED34840D3872EA86F1F4C40FD4CBD6E11D04840D3872EA86F1F4C40
16160	Старый Ашит	7	64	1263	49.654269999999997	49.675021000000001	56.354621999999999	56.341327999999997	0103000020E6100000010000000500000080608E1EBFD34840C39ACAA2B02B4C4080608E1EBFD348409738F240642D4C407E8E8F1667D648409738F240642D4C407E8E8F1667D64840C39ACAA2B02B4C4080608E1EBFD34840C39ACAA2B02B4C40
16555	Старые Турнали	7	64	1263	49.957836999999998	49.972372	56.202821999999998	56.194477999999997	0103000020E610000001000000050000000AF31E679AFA48404FE5B4A7E4184C400AF31E679AFA484064744012F6194C40E7C589AF76FC484064744012F6194C40E7C589AF76FC48404FE5B4A7E4184C400AF31E679AFA48404FE5B4A7E4184C40
15678	Старое Чурилино	7	64	1263	49.715580000000003	49.740589	56.033484999999999	56.022714999999998	0103000020E61000000100000005000000FAD51C2098DB484077103B53E8024C40FAD51C2098DB48400AF4893C49044C408063CF9ECBDE48400AF4893C49044C408063CF9ECBDE484077103B53E8024C40FAD51C2098DB484077103B53E8024C40
15286	Средняя Серда	7	64	1263	49.572046999999998	49.591315999999999	56.114680999999997	56.098877999999999	0103000020E6100000010000000500000030630AD638C948409E25C808A80C4C4030630AD638C948407D3CF4DDAD0E4C40FFCC203EB0CB48407D3CF4DDAD0E4C40FFCC203EB0CB48409E25C808A80C4C4030630AD638C948409E25C808A80C4C40
15289	Средняя Корса	7	64	1263	50.039943000000001	50.059176000000001	56.104391	56.095593999999998	0103000020E61000000100000005000000215A2BDA1C054940CFD8976C3C0C4C40215A2BDA1C054940957F2DAF5C0D4C40A35A441493074940957F2DAF5C0D4C40A35A441493074940CFD8976C3C0C4C40215A2BDA1C054940CFD8976C3C0C4C40
16367	Средний Пшалым	7	64	1263	49.934562	49.966470000000001	56.253447000000001	56.241439	0103000020E61000000100000005000000CC0A45BA9FF748404E7D2079E71E4C40CC0A45BA9FF74840792288F370204C405648F949B5FB4840792288F370204C405648F949B5FB48404E7D2079E71E4C40CC0A45BA9FF748404E7D2079E71E4C40
15096	Смак-Корса	7	64	1263	50.089288000000003	50.114457999999999	56.113526999999998	56.100273999999999	0103000020E610000001000000050000006FF607CA6D0B4940CE5147C7D50C4C406FF607CA6D0B4940431B800D880E4C40FE614B8FA60E4940431B800D880E4C40FE614B8FA60E4940CE5147C7D50C4C406FF607CA6D0B4940CE5147C7D50C4C40
15094	Сикертан	7	64	1263	50.124150999999998	50.143796999999999	56.170225000000002	56.158380999999999	0103000020E610000001000000050000000262122EE40F494065A71FD445144C400262122EE40F494016FBCBEEC9154C40A721AAF06712494016FBCBEEC9154C40A721AAF06712494065A71FD445144C400262122EE40F494065A71FD445144C40
15010	Сиза	7	64	1263	50.189638000000002	50.206122999999998	56.184936	56.173633000000002	0103000020E61000000100000005000000180AD80E46184940D1402C9B39164C40180AD80E4618494031ED9BFBAB174C4009FA0B3D621A494031ED9BFBAB174C4009FA0B3D621A4940D1402C9B39164C40180AD80E46184940D1402C9B39164C40
13967	Пшенгер	7	64	1263	49.973090999999997	50.003785999999998	56.419840999999998	56.408696999999997	0103000020E610000001000000050000001684F23E8EFC4840957CEC2E50344C401684F23E8EFC48408D429259BD354C406117450F7C0049408D429259BD354C406117450F7C004940957CEC2E50344C401684F23E8EFC4840957CEC2E50344C40
16788	Нуса	7	64	1263	49.905330999999997	49.931381999999999	56.433574999999998	56.421843000000003	0103000020E610000001000000050000000987DEE2E1F34840F58590F3FE354C400987DEE2E1F348407DAEB6627F374C40A20A7F8637F748407DAEB6627F374C40A20A7F8637F74840F58590F3FE354C400987DEE2E1F34840F58590F3FE354C40
14827	Новый Кырлай	7	64	1263	49.784849000000001	49.802230999999999	56.282339999999998	56.260038000000002	0103000020E610000001000000050000002FA699EE75E44840CFDBD8EC48214C402FA699EE75E44840232D95B723244C402F6B6281AFE64840232D95B723244C402F6B6281AFE64840CFDBD8EC48214C402FA699EE75E44840CFDBD8EC48214C40
14643	Новый Кишит	7	64	1263	49.650388999999997	49.678991000000003	56.268695999999998	56.252186999999999	0103000020E61000000100000005000000CD565EF23FD34840F9BCE2A947204C40CD565EF23FD3484073486AA164224C40A1A3552DE9D6484073486AA164224C40A1A3552DE9D64840F9BCE2A947204C40CD565EF23FD34840F9BCE2A947204C40
13862	Новый Кинер	7	64	1263	49.687821999999997	49.735998000000002	56.410893000000002	56.385899999999999	0103000020E6100000010000000500000012BC218D0AD8484061C3D32B65314C4012BC218D0AD84840E2934E2498344C40F1F5B52E35DE4840E2934E2498344C40F1F5B52E35DE484061C3D32B65314C4012BC218D0AD8484061C3D32B65314C40
17065	Новая Атня	7	64	1263	49.612633000000002	49.625613000000001	56.489933000000001	56.482298999999998	0103000020E61000000100000005000000A6B915C26ACE48405EF23FF9BB3D4C40A6B915C26ACE4840971DE21FB63E4C40EA79371614D04840971DE21FB63E4C40EA79371614D048405EF23FF9BB3D4C40A6B915C26ACE48405EF23FF9BB3D4C40
14437	Нижняя Ура	7	64	1263	49.594765000000002	49.619855000000001	56.406854000000003	56.396956000000003	0103000020E6100000010000000500000019E76F4221CC4840BAF94674CF324C4019E76F4221CC4840971FB8CA13344C408CA19C6857CF4840971FB8CA13344C408CA19C6857CF4840BAF94674CF324C4019E76F4221CC4840BAF94674CF324C40
15505	Нижние Метески	7	64	1263	49.896625999999998	49.925407999999997	56.146918999999997	56.133808000000002	0103000020E61000000100000005000000245F09A4C4F24840BAF8DB9E20114C40245F09A4C4F248409C14E63DCE124C4077BAF3C473F648409C14E63DCE124C4077BAF3C473F64840BAF8DB9E20114C40245F09A4C4F24840BAF8DB9E20114C40
15210	Нижние Аты	7	64	1263	49.679341999999998	49.703183000000003	56.124431000000001	56.115273000000002	0103000020E610000001000000050000004D66BCADF4D64840508E0244C10E4C404D66BCADF4D64840E6CDE15AED0F4C40350D8AE601DA4840E6CDE15AED0F4C40350D8AE601DA4840508E0244C10E4C404D66BCADF4D64840508E0244C10E4C40
14243	Наласа	7	64	1263	49.725254	49.750954999999998	56.121110000000002	56.106524	0103000020E6100000010000000500000087A5811FD5DC48409B1E1494A20D4C4087A5811FD5DC4840FA9B5088800F4C4043E21E4B1FE04840FA9B5088800F4C4043E21E4B1FE048409B1E1494A20D4C4087A5811FD5DC48409B1E1494A20D4C40
15590	Мендюш	7	64	1263	49.894101999999997	49.916254000000002	56.178708999999998	56.16395	0103000020E61000000100000005000000E3A430EF71F24840F0164850FC144C40E3A430EF71F248401C40BFEFDF164C40236AA2CF47F548401C40BFEFDF164C40236AA2CF47F54840F0164850FC144C40E3A430EF71F24840F0164850FC144C40
14823	Кшкар	7	64	1263	49.646903000000002	49.676259999999999	56.289434999999997	56.266992000000002	0103000020E610000001000000050000009757AEB7CDD2484096253ACB2C224C409757AEB7CDD24840ACA8C1340C254C40E6CB0BB08FD64840ACA8C1340C254C40E6CB0BB08FD6484096253ACB2C224C409757AEB7CDD2484096253ACB2C224C40
15586	Кошлауч	7	64	1263	49.551206000000001	49.569558000000001	56.165157999999998	56.154559999999996	0103000020E61000000100000005000000F3AD0FEB8DC6484087A2409FC8134C40F3AD0FEB8DC648401D56B8E523154C406C96CB46E7C848401D56B8E523154C406C96CB46E7C8484087A2409FC8134C40F3AD0FEB8DC6484087A2409FC8134C40
14151	Качелино	7	64	1263	49.791164000000002	49.825443999999997	56.070247999999999	56.052497000000002	0103000020E61000000100000005000000E3E2A8DC44E54840AE11C138B8064C40E3E2A8DC44E54840014EEFE2FD084C40F7562426A8E94840014EEFE2FD084C40F7562426A8E94840AE11C138B8064C40E3E2A8DC44E54840AE11C138B8064C40
16469	Казанбаш	7	64	1263	49.964781000000002	49.989035999999999	56.163212999999999	56.14575	0103000020E61000000100000005000000AE669DF17DFB48402DB29DEFA7124C40AE669DF17DFB48401AA4E029E4144C4088484DBB98FE48401AA4E029E4144C4088484DBB98FE48402DB29DEFA7124C40AE669DF17DFB48402DB29DEFA7124C40
14929	Верхние Верези	7	64	1263	49.797587	49.813854999999997	56.161924999999997	56.153131000000002	0103000020E610000001000000050000007D5BB05417E648407C80EECB99134C407D5BB05417E64840D0B359F5B9144C40D15790662CE84840D0B359F5B9144C40D15790662CE848407C80EECB99134C407D5BB05417E648407C80EECB99134C40
16621	Верхние Аты	7	64	1263	49.687911	49.705348000000001	56.155358	56.140960999999997	0103000020E6100000010000000500000082C7B7770DD84840778192020B124C4082C7B7770DD8484003965CC5E2134C404626E0D748DA484003965CC5E2134C404626E0D748DA4840778192020B124C4082C7B7770DD84840778192020B124C40
15865	Венета	7	64	1263	49.899959000000003	49.911493	55.965234000000002	55.956798999999997	0103000020E61000000100000005000000D55E44DB31F3484039ECBE6378FA4B40D55E44DB31F348405F7EA7C98CFB4B4037C478CDABF448405F7EA7C98CFB4B4037C478CDABF4484039ECBE6378FA4B40D55E44DB31F3484039ECBE6378FA4B40
61450	Байкал	7	64	1263	49.731597000000001	49.756525000000003	56.516437000000003	56.497526000000001	0103000020E61000000100000005000000056D72F8A4DD4840717495EEAE3F4C40056D72F8A4DD4840E1B88C9B1A424C409FCDAACFD5E04840E1B88C9B1A424C409FCDAACFD5E04840717495EEAE3F4C40056D72F8A4DD4840717495EEAE3F4C40
15971	Ашитбаш	7	64	1263	49.755572999999998	49.793086000000002	56.338259999999998	56.313442999999999	0103000020E61000000100000005000000CC5EB69DB6E048407F1475E61E284C40CC5EB69DB6E04840C1C58A1A4C2B4C402E7590D783E54840C1C58A1A4C2B4C402E7590D783E548407F1475E61E284C40CC5EB69DB6E048407F1475E61E284C40
13111	Арск	7	64	1263	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
13864	Апазово	7	64	1263	49.972318000000001	49.988928000000001	56.395048000000003	56.381774	0103000020E61000000100000005000000F4A78DEA74FC4840473B6EF8DD304C40F4A78DEA74FC4840D42CD0EE90324C40A20C553195FE4840D42CD0EE90324C40A20C553195FE4840473B6EF8DD304C40F4A78DEA74FC4840473B6EF8DD304C40
61361	Акчишма	7	64	1263	49.851477000000003	49.871617000000001	56.337420999999999	56.329371999999999	0103000020E61000000100000005000000EA25C632FDEC4840EB1B98DC282A4C40EA25C632FDEC4840E7FD7F9C302B4C409ED1562591EF4840E7FD7F9C302B4C409ED1562591EF4840EB1B98DC282A4C40EA25C632FDEC4840EB1B98DC282A4C40
11098	Ясашно-Барышево	7	64	950	48.688580999999999	48.719437999999997	55.318587999999998	55.304395	0103000020E61000000100000005000000D0D2156C235848407008556AF6A64B40D0D2156C23584840F372D87DC7A84B40F4BF5C8B165C4840F372D87DC7A84B40F4BF5C8B165C48407008556AF6A64B40D0D2156C235848407008556AF6A64B40
13021	Эбалаково	7	64	950	48.358575000000002	48.382686	55.265466000000004	55.254660999999999	0103000020E61000000100000005000000E4141DC9E52D484088484DBB98A04B40E4141DC9E52D4840981936CAFAA14B408B51D7DAFB304840981936CAFAA14B408B51D7DAFB30484088484DBB98A04B40E4141DC9E52D484088484DBB98A04B40
11143	Шонгуты	7	64	950	48.571719000000002	48.601291000000003	55.284399999999998	55.266615000000002	0103000020E610000001000000050000003CC093162E494840C0CFB87020A24B403CC093162E494840BF7D1D3867A44B4088307E1AF74C4840BF7D1D3867A44B4088307E1AF74C4840C0CFB87020A24B403CC093162E494840C0CFB87020A24B40
12146	Шигаево	7	64	950	48.511020000000002	48.526784999999997	55.370789000000002	55.361989000000001	0103000020E610000001000000050000000CCD751A694148408141D2A755AE4B400CCD751A69414840B85B920376AF4B40FD82DDB06D434840B85B920376AF4B40FD82DDB06D4348408141D2A755AE4B400CCD751A694148408141D2A755AE4B40
12345	Шемяково	7	64	950	48.230241999999997	48.253490999999997	55.214959	55.203668	0103000020E610000001000000050000003315E291781D4840F19E03CB119A4B403315E291781D48408D7DC9C6839B4B40486AA164722048408D7DC9C6839B4B40486AA16472204840F19E03CB119A4B403315E291781D4840F19E03CB119A4B40
12896	Шамбулыхчи	7	64	950	48.400841	48.424117000000003	55.301966	55.288305999999999	0103000020E61000000100000005000000AEF204C24E334840CB9E0436E7A44B40AEF204C24E334840814067D2A6A64B40BD56427749364840814067D2A6A64B40BD56427749364840CB9E0436E7A44B40AEF204C24E334840CB9E0436E7A44B40
61428	Чури Барышево	7	64	950	48.004854999999999	48.852694	55.435395999999997	55.101401000000003	0103000020E610000001000000050000006D1CB1169F0048400F643DB5FA8C4B406D1CB1169F00484094675E0EBBB74B406ABFB513256D484094675E0EBBB74B406ABFB513256D48400F643DB5FA8C4B406D1CB1169F0048400F643DB5FA8C4B40
61436	Черемшан	7	64	950	48.095576000000001	48.129550000000002	55.267609999999998	55.252501000000002	0103000020E61000000100000005000000292499D53B0C4840899AE8F351A04B40292499D53B0C4840910A630B41A24B4031992A1895104840910A630B41A24B4031992A1895104840899AE8F351A04B40292499D53B0C4840899AE8F351A04B40
61362	Чатбаш	7	64	950	48.210120000000003	48.235514999999999	55.173267000000003	55.167138000000001	0103000020E61000000100000005000000261E5036E51A48409DF529C764954B40261E5036E51A4840EF3CF19C2D964B40D55B035B251E4840EF3CF19C2D964B40D55B035B251E48409DF529C764954B40261E5036E51A48409DF529C764954B40
11515	Утямишево	7	64	950	48.522841	48.545003000000001	55.323822999999997	55.316201	0103000020E6100000010000000500000004013274EC42484033FB3C4679A84B4004013274EC424840A758350873A94B40679C86A8C2454840A758350873A94B40679C86A8C245484033FB3C4679A84B4004013274EC42484033FB3C4679A84B40
12588	Тюбяк-Черки	7	64	950	48.433926	48.452728	55.127425000000002	55.114666999999997	0103000020E610000001000000050000002A711DE38A37484018778368AD8E4B402A711DE38A374840AED85F764F904B40E3FDB8FDF2394840AED85F764F904B40E3FDB8FDF239484018778368AD8E4B402A711DE38A37484018778368AD8E4B40
12648	Тутаево	7	64	950	48.122633	48.139845000000001	55.190041000000001	55.175164000000002	0103000020E6100000010000000500000087342A70B20F4840E1B721C66B964B4087342A70B20F484017F3734353984B402BC1E270E611484017F3734353984B402BC1E270E6114840E1B721C66B964B4087342A70B20F4840E1B721C66B964B40
12855	Танай-Тураево	7	64	950	48.597670999999998	48.615251000000001	55.203384999999997	55.192245	0103000020E610000001000000050000004162BB7B804C4840E6E8F17B9B984B404162BB7B804C48409CBF0985089A4B4068EA758BC04E48409CBF0985089A4B4068EA758BC04E4840E6E8F17B9B984B404162BB7B804C4840E6E8F17B9B984B40
12533	Табар-Черки	7	64	950	48.440753000000001	48.455486000000001	55.166218000000001	55.149290000000001	0103000020E61000000100000005000000944E24986A38484057CF49EF1B934B40944E24986A384840D600A5A146954B4097E4805D4D3A4840D600A5A146954B4097E4805D4D3A484057CF49EF1B934B40944E24986A38484057CF49EF1B934B40
61404	Старые Юмралы	7	64	950	48.580289	48.602558000000002	55.141222999999997	55.126888999999998	0103000020E61000000100000005000000419DF2E8464A48406F9C14E63D904B40419DF2E8464A4840B438639813924B40BAF8DB9E204D4840B438639813924B40BAF8DB9E204D48406F9C14E63D904B40419DF2E8464A48406F9C14E63D904B40
10552	Старые Енали	7	64	950	48.519482000000004	48.540196999999999	55.193714999999997	55.178094999999999	0103000020E610000001000000050000002B6EDC627E424840624A24D1CB964B402B6EDC627E42484050DF32A7CB984B40DB32E02C2545484050DF32A7CB984B40DB32E02C25454840624A24D1CB964B402B6EDC627E424840624A24D1CB964B40
12102	Старое Бурнашево	7	64	950	48.291929000000003	48.305439999999997	55.184545999999997	55.176819999999999	0103000020E6100000010000000500000083E0F1ED5D254840ADA3AA09A2964B4083E0F1ED5D254840C64D0D349F974B40F3716DA818274840C64D0D349F974B40F3716DA818274840ADA3AA09A2964B4083E0F1ED5D254840ADA3AA09A2964B40
13028	Средний Биябаш	7	64	950	48.280593000000003	48.309060000000002	55.298589	55.288136999999999	0103000020E61000000100000005000000473EAF78EA2348403FE257ACE1A44B40473EAF78EA23484001F9122A38A64B403A4030478F27484001F9122A38A64B403A4030478F2748403FE257ACE1A44B40473EAF78EA2348403FE257ACE1A44B40
12264	Среднее Балтаево	7	64	950	48.265312000000002	48.292566999999998	55.234414999999998	55.218995	0103000020E61000000100000005000000419E5DBEF5214840677E3507089C4B40419E5DBEF52148408E588B4F019E4B40C571E0D5722548408E588B4F019E4B40C571E0D572254840677E3507089C4B40419E5DBEF5214840677E3507089C4B40
11848	Свияжский	7	64	950	48.437474999999999	48.461027999999999	55.239049999999999	55.224947	0103000020E61000000100000005000000A7E8482EFF374840AA2A3410CB9C4B40A7E8482EFF374840ED0DBE30999E4B4028452BF7023B4840ED0DBE30999E4B4028452BF7023B4840AA2A3410CB9C4B40A7E8482EFF374840AA2A3410CB9C4B40
12143	Сатламышево	7	64	950	48.447940000000003	48.474440000000001	55.385325999999999	55.373654000000002	0103000020E61000000100000005000000FE481119563948408202EFE4D3AF4B40FE481119563948403526C45C52B14B4006F52D73BA3C48403526C45C52B14B4006F52D73BA3C48408202EFE4D3AF4B40FE481119563948408202EFE4D3AF4B40
12939	Нижний Биябаш	7	64	950	48.315277000000002	48.335093999999998	55.291074999999999	55.281922999999999	0103000020E610000001000000050000002B172AFF5A284840BF7E880D16A44B402B172AFF5A28484073D712F241A54B40FC8A355CE42A484073D712F241A54B40FC8A355CE42A4840BF7E880D16A44B402B172AFF5A284840BF7E880D16A44B40
11847	Мурзино	7	64	950	48.368609999999997	48.377090000000003	55.246256000000002	55.240862	0103000020E61000000100000005000000417DCB9C2E2F4840B16CE690D49E4B40417DCB9C2E2F4840CE380D51859F4B4007D3307C44304840CE380D51859F4B4007D3307C44304840B16CE690D49E4B40417DCB9C2E2F4840B16CE690D49E4B40
11053	Малые Кокузы	7	64	950	48.621845	48.645947	55.329262	55.315795999999999	0103000020E610000001000000050000002F17F19D984F4840931ADA006CA84B402F17F19D984F484064E8D84125AA4B4083F92B64AE52484064E8D84125AA4B4083F92B64AE524840931ADA006CA84B402F17F19D984F4840931ADA006CA84B40
10967	Малые Болгояры	7	64	950	48.756565000000002	48.782041	55.208702000000002	55.200302000000001	0103000020E610000001000000050000002D26361FD760484065A9F57EA3994B402D26361FD76048400E4E44BFB69A4B40C99063EB196448400E4E44BFB69A4B40C99063EB1964484065A9F57EA3994B402D26361FD760484065A9F57EA3994B40
11680	Мазиково	7	64	950	48.567802	48.580989000000002	55.17718	55.168377	0103000020E610000001000000050000003C4D66BCAD4848400533A6608D954B403C4D66BCAD484840ADC090D5AD964B40FA2AF9D85D4A4840ADC090D5AD964B40FA2AF9D85D4A48400533A6608D954B403C4D66BCAD4848400533A6608D954B40
11986	Куштово	7	64	950	48.272103999999999	48.297103999999997	55.156688000000003	55.141134999999998	0103000020E610000001000000050000002E8ECA4DD422484015A930B610924B402E8ECA4DD42248407CD6355A0E944B4061C1FD80072648407CD6355A0E944B4061C1FD800726484015A930B610924B402E8ECA4DD422484015A930B610924B40
11325	Курмашево	7	64	950	48.484250000000003	48.517280999999997	55.287824000000001	55.274175	0103000020E61000000100000005000000448B6CE7FB3D4840BE30992A18A34B40448B6CE7FB3D48408080B56AD7A44B40CCEB8843364248408080B56AD7A44B40CCEB884336424840BE30992A18A34B40448B6CE7FB3D4840BE30992A18A34B40
11612	Кулганы	7	64	950	48.327907000000003	48.349494	55.154089999999997	55.144202	0103000020E61000000100000005000000939048DBF829484047020D3675924B40939048DBF829484000529B38B9934B40F9122A38BC2C484000529B38B9934B40F9122A38BC2C484047020D3675924B40939048DBF829484047020D3675924B40
61291	Коратун	7	64	950	48.349528999999997	48.410111999999998	55.247883000000002	55.218929000000003	0103000020E610000001000000050000007500C45DBD2C4840B0928FDD059C4B407500C45DBD2C4840001E51A1BA9F4B403CD9CD8C7E344840001E51A1BA9F4B403CD9CD8C7E344840B0928FDD059C4B407500C45DBD2C4840B0928FDD059C4B40
61349	Кильдуразы	7	64	950	48.304271999999997	48.312742999999998	55.172978999999998	55.164437999999997	0103000020E61000000100000005000000548B8862F22648401D1CEC4D0C954B40548B8862F226484088F2052D24964B40C6866EF60728484088F2052D24964B40C6866EF6072848401D1CEC4D0C954B40548B8862F22648401D1CEC4D0C954B40
11901	Кзыл-Тау	7	64	950	48.175409000000002	48.200149000000003	55.197533	55.180182000000002	0103000020E61000000100000005000000483657CD73164840F8A92A3410974B40483657CD73164840BD70E7C248994B40DFA9807B9E194840BD70E7C248994B40DFA9807B9E194840F8A92A3410974B40483657CD73164840F8A92A3410974B40
11382	Карамасары	7	64	950	48.442227000000003	48.466211999999999	55.411189	55.399330999999997	0103000020E610000001000000050000004034F3E49A384840B5A338471DB34B404034F3E49A384840CBBC55D7A1B44B405A80B6D5AC3B4840CBBC55D7A1B44B405A80B6D5AC3B4840B5A338471DB34B404034F3E49A384840B5A338471DB34B40
12478	Карабаево	7	64	950	48.606321999999999	48.624504000000002	55.140599999999999	55.132973	0103000020E61000000100000005000000336C94F59B4D484021205F4205914B40336C94F59B4D4840A7E8482EFF914B40501C40BFEF4F4840A7E8482EFF914B40501C40BFEF4F484021205F4205914B40336C94F59B4D484021205F4205914B40
12253	Кабы-Копры	7	64	950	48.545667999999999	48.576245999999998	55.345134999999999	55.334080999999998	0103000020E61000000100000005000000A33CF372D8454840849B8C2AC3AA4B40A33CF372D84548403CDA38622DAC4B40B439CE6DC24948403CDA38622DAC4B40B439CE6DC2494840849B8C2AC3AA4B40A33CF372D8454840849B8C2AC3AA4B40
61472	Идрязь-Тенькиево	7	64	950	48.004854999999999	48.852694	55.435395999999997	55.101401000000003	0103000020E610000001000000050000006D1CB1169F0048400F643DB5FA8C4B406D1CB1169F00484094675E0EBBB74B406ABFB513256D484094675E0EBBB74B406ABFB513256D48400F643DB5FA8C4B406D1CB1169F0048400F643DB5FA8C4B40
11570	Деушево	7	64	950	48.344408999999999	48.369508000000003	55.186062	55.164351000000003	0103000020E610000001000000050000005AB91798152C48404F081D7409954B405AB91798152C4840A1832EE1D0974B4021CEC3094C2F4840A1832EE1D0974B4021CEC3094C2F48404F081D7409954B405AB91798152C48404F081D7409954B40
10866	Девликеево	7	64	950	48.353940000000001	48.381923	55.221829999999997	55.20711	0103000020E61000000100000005000000855FEAE74D2D484058569A94829A4B40855FEAE74D2D4840C6A2E9EC649C4B408C4B55DAE2304840C6A2E9EC649C4B408C4B55DAE230484058569A94829A4B40855FEAE74D2D484058569A94829A4B40
11468	Верхние Индырчи	7	64	950	48.471637000000001	48.489576999999997	55.308115999999998	55.297696999999999	0103000020E61000000100000005000000B24AE9995E3C4840048F6FEF1AA64B40B24AE9995E3C4840EAAF575870A74B40D8EF8975AA3E4840EAAF575870A74B40D8EF8975AA3E4840048F6FEF1AA64B40B24AE9995E3C4840048F6FEF1AA64B40
12339	Верхнее Балтаево	7	64	950	48.236944000000001	48.271816000000001	55.242997000000003	55.235272000000002	0103000020E61000000100000005000000E17D552E541E48400FD594641D9E4B40E17D552E541E4840580394861A9F4B40C843DFDDCA224840580394861A9F4B40C843DFDDCA2248400FD594641D9E4B40E17D552E541E48400FD594641D9E4B40
7757	Бурнашево	7	64	950	48.758982000000003	48.781646000000002	55.245358000000003	55.233880999999997	0103000020E6100000010000000500000058207A5226614840F01307D0EF9D4B4058207A5226614840EFE714E4679F4B404D86E3F90C644840EFE714E4679F4B404D86E3F90C644840F01307D0EF9D4B4058207A5226614840F01307D0EF9D4B40
11225	Булым-Булыхчи	7	64	950	48.475779000000003	48.493071	55.263931999999997	55.251721000000003	0103000020E61000000100000005000000D28F8653E63C4840B45BCB6438A04B40D28F8653E63C4840162F1686C8A14B4092CD55F31C3F4840162F1686C8A14B4092CD55F31C3F4840B45BCB6438A04B40D28F8653E63C4840B45BCB6438A04B40
11006	Большие Кокузы	7	64	950	48.635041000000001	48.669975999999998	55.313803	55.304267000000003	0103000020E61000000100000005000000404F03064951484043209738F2A64B40404F0306495148407F315BB22AA84B406D8D08C6C15548407F315BB22AA84B406D8D08C6C155484043209738F2A64B40404F03064951484043209738F2A64B40
10921	Большие Болгояры	7	64	950	48.798786	48.819609	55.231800999999997	55.216576000000003	0103000020E610000001000000050000005740A19E3E6648409C8C2AC3B89B4B405740A19E3E6648400D17B9A7AB9D4B40EE409DF2E86848400D17B9A7AB9D4B40EE409DF2E86848409C8C2AC3B89B4B405740A19E3E6648409C8C2AC3B89B4B40
10793	Бишево	7	64	950	48.427107999999997	48.437159999999999	55.234281000000003	55.224038	0103000020E6100000010000000500000013EE9579AB364840D787F546AD9C4B4013EE9579AB3648407F8978EBFC9D4B40478FDFDBF43748407F8978EBFC9D4B40478FDFDBF4374840D787F546AD9C4B4013EE9579AB364840D787F546AD9C4B40
9630	Бакрче	7	64	950	48.187185999999997	48.215465000000002	55.256323999999999	55.242159999999998	0103000020E610000001000000050000007022FAB5F51748401E335019FF9E4B407022FAB5F517484007978E39CFA04B4061376C5B941B484007978E39CFA04B4061376C5B941B48401E335019FF9E4B407022FAB5F51748401E335019FF9E4B40
61462	Багищево	7	64	950	48.080959999999997	48.101145000000002	55.281517999999998	55.268605000000001	0103000020E610000001000000050000005F24B4E55C0A484063450DA661A24B405F24B4E55C0A48401F9E25C808A44B40B493C151F20C48401F9E25C808A44B40B493C151F20C484063450DA661A24B405F24B4E55C0A484063450DA661A24B40
61451	Аюкудерган	7	64	950	48.004854999999999	48.852694	55.435395999999997	55.101401000000003	0103000020E610000001000000050000006D1CB1169F0048400F643DB5FA8C4B406D1CB1169F00484094675E0EBBB74B406ABFB513256D484094675E0EBBB74B406ABFB513256D48400F643DB5FA8C4B406D1CB1169F0048400F643DB5FA8C4B40
10343	Апастово	7	64	950	48.484313	48.533298000000002	55.211497000000001	55.192101000000001	0103000020E610000001000000050000008A03E8F7FD3D4840B343FCC396984B408A03E8F7FD3D4840DF196D55129B4B40D882DE1B43444840DF196D55129B4B40D882DE1B43444840B343FCC396984B408A03E8F7FD3D4840B343FCC396984B40
10608	Альмендерово	7	64	950	48.714424999999999	48.732688000000003	55.261198	55.251721000000003	0103000020E61000000100000005000000EF384547725B4840B45BCB6438A04B40EF384547725B4840EBE3A1EF6EA14B40F9156BB8C85D4840EBE3A1EF6EA14B40F9156BB8C85D4840B45BCB6438A04B40EF384547725B4840B45BCB6438A04B40
25756	Азимово	7	64	950	48.700240999999998	48.716724999999997	55.277087999999999	55.268917999999999	0103000020E61000000100000005000000BF28417FA159484022A7AFE76BA24B40BF28417FA1594840990E9D9E77A34B40E09C11A5BD5B4840990E9D9E77A34B40E09C11A5BD5B484022A7AFE76BA24B40BF28417FA159484022A7AFE76BA24B40
11370	Азбаба	7	64	950	48.523972999999998	48.542909999999999	55.426093999999999	55.406702000000003	0103000020E61000000100000005000000567E198C11434840E19BA6CF0EB44B40567E198C11434840CB82893F8AB64B40EF552B137E454840CB82893F8AB64B40EF552B137E454840E19BA6CF0EB44B40567E198C11434840E19BA6CF0EB44B40
9889	Ямаши	7	64	151	51.587561000000001	51.624850000000002	55.129128000000001	55.100551000000003	0103000020E61000000100000005000000D9B3E73235CB4940414AECDADE8C4B40D9B3E73235CB4940BB7F2C4487904B40EB73B515FBCF4940BB7F2C4487904B40EB73B515FBCF4940414AECDADE8C4B40D9B3E73235CB4940414AECDADE8C4B40
10004	Ямаш	7	64	151	52.164648	52.193860999999998	55.040446000000003	55.027985000000001	0103000020E6100000010000000500000008AD872F13154A40A8E3310395834B4008AD872F13154A4084A0A3552D854B40247CEF6FD0184A4084A0A3552D854B40247CEF6FD0184A40A8E3310395834B4008AD872F13154A40A8E3310395834B40
8647	Чупаево	7	64	151	52.122463000000003	52.146887999999997	54.803164000000002	54.787188	0103000020E610000001000000050000002BFC19DEAC0F4A40DEE68D93C2644B402BFC19DEAC0F4A408BA9F413CE664B406116DA39CD124A408BA9F413CE664B406116DA39CD124A40DEE68D93C2644B402BFC19DEAC0F4A40DEE68D93C2644B40
9310	Чувашское Сиренькино	7	64	151	51.680078000000002	51.701279	54.934877999999998	54.924635000000002	0103000020E61000000100000005000000535DC0CB0CD7494055DE8E705A764B40535DC0CB0CD74940FCDF1115AA774B40902FA182C3D94940FCDF1115AA774B40902FA182C3D9494055DE8E705A764B40535DC0CB0CD7494055DE8E705A764B40
61355	Урсалабаш	7	64	151	52.639460999999997	52.672823999999999	55.006745000000002	54.995626999999999	0103000020E61000000100000005000000A208A9DBD9514A40DE019EB4707F4B40A208A9DBD9514A40AD342905DD804B4061FBC9181F564A40AD342905DD804B4061FBC9181F564A40DE019EB4707F4B40A208A9DBD9514A40DE019EB4707F4B40
9793	Тайсуганово	7	64	151	52.489486999999997	52.520273000000003	54.807107999999999	54.790942000000001	0103000020E6100000010000000500000098689082A73E4A40348463963D654B4098689082A73E4A40842BA0504F674B40F4FE3F4E98424A40842BA0504F674B40F4FE3F4E98424A40348463963D654B4098689082A73E4A40348463963D654B40
9583	Сулеево	7	64	151	52.601973999999998	52.634943	54.998179	54.986319999999999	0103000020E610000001000000050000006A85E97B0D4D4A4003B2D7BB3F7E4B406A85E97B0D4D4A40E9465854C47F4B407DE9EDCF45514A40E9465854C47F4B407DE9EDCF45514A4003B2D7BB3F7E4B406A85E97B0D4D4A4003B2D7BB3F7E4B40
9483	Старое Суркино	7	64	151	52.197929999999999	52.221438999999997	54.755389000000001	54.732999999999997	0103000020E61000000100000005000000DA722EC555194A40E7FBA9F1D25D4B40DA722EC555194A400B613596B0604B408B87F71C581C4A400B613596B0604B408B87F71C581C4A40E7FBA9F1D25D4B40DA722EC555194A40E7FBA9F1D25D4B40
9311	Старая Михайловка	7	64	151	52.532120999999997	52.549216000000001	55.058956000000002	55.049075000000002	0103000020E61000000100000005000000E5417A8A1C444A408E06F01648864B40E5417A8A1C444A4095F3C5DE8B874B405038BBB54C464A4095F3C5DE8B874B405038BBB54C464A408E06F01648864B40E5417A8A1C444A408E06F01648864B40
5315	Старая Елань	7	64	151	51.863028999999997	51.882432999999999	55.052669999999999	55.040621000000002	0103000020E61000000100000005000000F23FF9BB77EE4940F243A51133854B40F23FF9BB77EE49407BBDFBE3BD864B40A1F48590F3F049407BBDFBE3BD864B40A1F48590F3F04940F243A51133854B40F23FF9BB77EE4940F243A51133854B40
9151	Русский Акташ	7	64	151	52.098936000000002	52.141390000000001	55.050865000000002	55.025395000000003	0103000020E61000000100000005000000D33252EFA90C4A40B03DB32440834B40D33252EFA90C4A406AC18BBE82864B40A0FD481119124A406AC18BBE82864B40A0FD481119124A40B03DB32440834B40D33252EFA90C4A40B03DB32440834B40
9100	Новотроицкое	7	64	151	51.450989999999997	51.471319000000001	55.028444999999998	55.010122000000003	0103000020E610000001000000050000005969520ABAB949402D7C7DAD4B814B405969520ABAB949400B5EF415A4834B40E17D552E54BC49400B5EF415A4834B40E17D552E54BC49402D7C7DAD4B814B405969520ABAB949402D7C7DAD4B814B40
9099	Новоникольск	7	64	151	52.325508999999997	52.356869000000003	55.062626999999999	55.045051999999998	0103000020E61000000100000005000000DEC66647AA294A40484F9143C4854B40DEC66647AA294A405D6C5A2904884B4066FA25E2AD2D4A405D6C5A2904884B4066FA25E2AD2D4A40484F9143C4854B40DEC66647AA294A40484F9143C4854B40
9536	Новое Суркино	7	64	151	52.235928999999999	52.249187999999997	54.727249999999998	54.711556000000002	0103000020E61000000100000005000000C896E5EB321E4A40E4A25A44145B4B40C896E5EB321E4A400C022B87165D4B401F477364E51F4A400C022B87165D4B401F477364E51F4A40E4A25A44145B4B40C896E5EB321E4A40E4A25A44145B4B40
9059	Новое Надырово	7	64	151	52.452700999999998	52.484169000000001	54.905783	54.884317000000003	0103000020E61000000100000005000000E9EE3A1BF2394A40FF25A94C31714B40E9EE3A1BF2394A40EA2285B2F0734B40575EF23FF93D4A40EA2285B2F0734B40575EF23FF93D4A40FF25A94C31714B40E9EE3A1BF2394A40FF25A94C31714B40
32598	Новое Каширово	7	64	151	52.509439	52.551597000000001	54.975605000000002	54.948478999999999	0103000020E610000001000000050000004A27124C35414A40ADF886C267794B404A27124C35414A403468E89FE07C4B402EC901BB9A464A403468E89FE07C4B402EC901BB9A464A40ADF886C267794B404A27124C35414A40ADF886C267794B40
9789	Новая Михайловка	7	64	151	52.577558000000003	52.599082000000003	55.020119999999999	55.005071999999998	0103000020E6100000010000000500000087C5A86BED494A400A100533A6804B4087C5A86BED494A406DFFCA4A93824B40A7CF0EB8AE4C4A406DFFCA4A93824B40A7CF0EB8AE4C4A400A100533A6804B4087C5A86BED494A400A100533A6804B40
7382	Нижняя Мактама	7	64	151	52.392856000000002	52.450589999999998	54.893839999999997	54.828470000000003	0103000020E61000000100000005000000C904FC1A49324A40CBDB114E0B6A4B40C904FC1A49324A40A6ED5F5969724B40CBF3E0EEAC394A40A6ED5F5969724B40CBF3E0EEAC394A40CBDB114E0B6A4B40C904FC1A49324A40CBDB114E0B6A4B40
8821	Нижнее Абдулово	7	64	151	51.587344999999999	51.632233999999997	54.897221000000002	54.871740000000003	0103000020E610000001000000050000000C3CF71E2ECB4940BA4E232D956F4B400C3CF71E2ECB494068244223D8724B40AAB5300BEDD0494068244223D8724B40AAB5300BEDD04940BA4E232D956F4B400C3CF71E2ECB4940BA4E232D956F4B40
8384	Нагорное	7	64	151	52.030152000000001	52.056148999999998	54.886341999999999	54.871678000000003	0103000020E610000001000000050000005AF44E05DC034A4044520B25936F4B405AF44E05DC034A401E8997A773714B40FF59F3E32F074A401E8997A773714B40FF59F3E32F074A4044520B25936F4B405AF44E05DC034A4044520B25936F4B40
8768	Миннибаево	7	64	151	52.221393999999997	52.282739999999997	54.839053999999997	54.804845999999998	0103000020E61000000100000005000000EBC37AA3561C4A408028983105674B40EBC37AA3561C4A40FBC9181F666B4B40B1A206D330244A40FBC9181F666B4B40B1A206D330244A408028983105674B40EBC37AA3561C4A408028983105674B40
8706	Маметьево	7	64	151	52.073936000000003	52.098315999999997	54.821660000000001	54.808788999999997	0103000020E61000000100000005000000A0FF1EBC76094A40A92EE06586674B40A0FF1EBC76094A403737A6272C694B403656629E950C4A403737A6272C694B403656629E950C4A40A92EE06586674B40A0FF1EBC76094A40A92EE06586674B40
8591	Кульшарипово	7	64	151	52.147821999999998	52.213022000000002	54.900886	54.860523000000001	0103000020E610000001000000050000008DD0CFD4EB124A40583A1F9E256E4B408DD0CFD4EB124A404EB6813B50734B400DAA0D4E441B4A404EB6813B50734B400DAA0D4E441B4A40583A1F9E256E4B408DD0CFD4EB124A40583A1F9E256E4B40
8510	Кузайкино	7	64	151	51.764026000000001	51.793365000000001	55.030839	55.009960999999997	0103000020E6100000010000000500000098A59D9ACBE14940239EEC6646814B4098A59D9ACBE149407E384888F2834B404165FCFB8CE549407E384888F2834B404165FCFB8CE54940239EEC6646814B4098A59D9ACBE14940239EEC6646814B40
8503	Клементейкино	7	64	151	51.683293999999997	51.708213999999998	54.884819	54.86786	0103000020E61000000100000005000000C9C6832D76D74940D7C05609166F4B40C9C6832D76D7494091F0BDBF41714B40E048A0C1A6DA494091F0BDBF41714B40E048A0C1A6DA4940D7C05609166F4B40C9C6832D76D74940D7C05609166F4B40
8414	Кичучатово	7	64	151	52.065877999999998	52.097588000000002	54.847487999999998	54.837871999999997	0103000020E6100000010000000500000050C3B7B06E084A40F71DC3633F6B4B4050C3B7B06E084A4050E09D7C7A6C4B40B43D7AC37D0C4A4050E09D7C7A6C4B40B43D7AC37D0C4A40F71DC3633F6B4B4050C3B7B06E084A40F71DC3633F6B4B40
8320	Кичуй	7	64	151	51.968347999999999	51.998162999999998	54.902262999999998	54.885554999999997	0103000020E61000000100000005000000D192C7D3F2FB494096E7C1DD59714B40D192C7D3F2FB494007B29E5A7D734B40E38920CEC3FF494007B29E5A7D734B40E38920CEC3FF494096E7C1DD59714B40D192C7D3F2FB494096E7C1DD59714B40
61435	Кительга	7	64	151	51.705877999999998	51.722155000000001	54.980998999999997	54.965744999999998	0103000020E61000000100000005000000A27BD6355ADA494044A33B889D7B4B40A27BD6355ADA494050340F60917D4B404AD235936FDC494050340F60917D4B404AD235936FDC494044A33B889D7B4B40A27BD6355ADA494044A33B889D7B4B40
8304	Кама-Исмагилово	7	64	151	52.530620999999996	52.565187999999999	54.908956000000003	54.880034000000002	0103000020E6100000010000000500000010C99063EB434A401DAF40F4A4704B4010C99063EB434A4062C092AB58744B40BB0B941458484A4062C092AB58744B40BB0B941458484A401DAF40F4A4704B4010C99063EB434A401DAF40F4A4704B40
30044	Кама-Елга	7	64	151	52.633172999999999	52.642578	54.830767999999999	54.823917000000002	0103000020E61000000100000005000000E8DA17D00B514A4029CFBC1C76694B40E8DA17D00B514A401B48179B566A4B408690F3FE3F524A401B48179B566A4B408690F3FE3F524A4029CFBC1C76694B40E8DA17D00B514A4029CFBC1C76694B40
8223	Калейкино	7	64	151	52.125283000000003	52.204371000000002	54.942118000000001	54.906652000000001	0103000020E6100000010000000500000055DFF94509104A402F6D382C0D744B4055DFF94509104A40897C975297784B401BA034D4281A4A40897C975297784B401BA034D4281A4A402F6D382C0D744B4055DFF94509104A402F6D382C0D744B40
7629	Ильтень-Бута	7	64	151	51.892547999999998	51.913083	54.964033999999998	54.947474999999997	0103000020E610000001000000050000001B0E4B033FF2494088635DDC46794B401B0E4B033FF24940B41D5377657B4B404CC45BE7DFF44940B41D5377657B4B404CC45BE7DFF4494088635DDC46794B401B0E4B033FF2494088635DDC46794B40
9891	Зай-Чишма	7	64	151	52.126325000000001	52.141022	55.073509999999999	55.060775999999997	0103000020E6100000010000000500000067D5E76A2B104A40DB300A82C7874B4067D5E76A2B104A40E8F692C668894B401D0247020D124A40E8F692C668894B401D0247020D124A40DB300A82C7874B4067D5E76A2B104A40DB300A82C7874B40
8208	Ерсубайкино	7	64	151	51.738109000000001	51.761150999999998	54.937835999999997	54.921453	0103000020E610000001000000050000000FF10F5B7ADE49408AE6012CF2754B400FF10F5B7ADE4940778192020B784B40AA285E656DE14940778192020B784B40AA285E656DE149408AE6012CF2754B400FF10F5B7ADE49408AE6012CF2754B40
7547	Дербедень	7	64	151	52.002654	52.027510999999997	54.953850000000003	54.939791	0103000020E610000001000000050000000F9A5DF756004A409E094D124B784B400F9A5DF756004A4012A5BDC1177A4B40DFA3FE7A85034A4012A5BDC1177A4B40DFA3FE7A85034A409E094D124B784B400F9A5DF756004A409E094D124B784B40
7638	Дальняя Ивановка	7	64	151	51.526287000000004	51.552804999999999	54.943824999999997	54.931970999999997	0103000020E61000000100000005000000ADA7565F5DC3494003E962D34A774B40ADA7565F5DC34940D712F241CF784B405B087250C2C64940D712F241CF784B405B087250C2C6494003E962D34A774B40ADA7565F5DC3494003E962D34A774B40
8102	Верхняя Мактама	7	64	151	52.344005000000003	52.377125999999997	54.837581	54.816716999999997	0103000020E610000001000000050000008B54185B082C4A402A8BC22E8A684B408B54185B082C4A402060ADDA356B4B40533C2EAA45304A402060ADDA356B4B40533C2EAA45304A402A8BC22E8A684B408B54185B082C4A402A8BC22E8A684B40
8046	Верхний Акташ	7	64	151	52.126766000000003	52.174151999999999	54.971919999999997	54.949739999999998	0103000020E61000000100000005000000541F48DE39104A40FDD98F1491794B40541F48DE39104A40062AE3DF677C4B403944DC9C4A164A40062AE3DF677C4B403944DC9C4A164A40FDD98F1491794B40541F48DE39104A40FDD98F1491794B40
7964	Васильевка	7	64	151	52.278984999999999	52.299942999999999	54.775309	54.760958000000002	0103000020E610000001000000050000008B89CDC7B5234A4096D05D1267614B408B89CDC7B5234A40B1A547533D634B4002D53F8864264A40B1A547533D634B4002D53F8864264A4096D05D1267614B408B89CDC7B5234A4096D05D1267614B40
7911	Бута	7	64	151	51.928831000000002	51.952573000000001	55.025342999999999	55.008809999999997	0103000020E61000000100000005000000684128EFE3F649405AF0A2AF20814B40684128EFE3F649405D177E703E834B40BC067DE9EDF949405D177E703E834B40BC067DE9EDF949405AF0A2AF20814B40684128EFE3F649405AF0A2AF20814B40
7809	Борискино	7	64	151	51.632063000000002	51.652096	55.038960000000003	55.026747	0103000020E610000001000000050000007E01BD70E7D04940102219726C834B407E01BD70E7D0494014ED2AA4FC844B401CEDB8E177D3494014ED2AA4FC844B401CEDB8E177D34940102219726C834B407E01BD70E7D04940102219726C834B40
7716	Бишмунча	7	64	151	52.580603000000004	52.609977999999998	54.868326000000003	54.848193000000002	0103000020E61000000100000005000000D17AF832514A4A401BD99596916C4B40D17AF832514A4A401D226E4E256F4B40C6A354C2134E4A401D226E4E256F4B40C6A354C2134E4A401BD99596916C4B40D17AF832514A4A401BD99596916C4B40
9017	Бикасаз	7	64	151	52.419705999999998	52.446629000000001	55.020538000000002	55.012357000000002	0103000020E61000000100000005000000ADF71BEDB8354A40377007EA94814B40ADF71BEDB8354A40A2293BFDA0824B40FC389A232B394A40A2293BFDA0824B40FC389A232B394A40377007EA94814B40ADF71BEDB8354A40377007EA94814B40
7900	Березовка	7	64	151	51.704566	51.728372	55.031835000000001	55.014431999999999	0103000020E61000000100000005000000D0EFFB372FDA4940080264E8D8814B40D0EFFB372FDA494020EF552B13844B403BA92F4B3BDD494020EF552B13844B403BA92F4B3BDD4940080264E8D8814B40D0EFFB372FDA4940080264E8D8814B40
7557	Аппаково	7	64	151	51.900129999999997	51.918725000000002	54.940649000000001	54.922829	0103000020E610000001000000050000000113B87537F349407366BB421F764B400113B87537F34940EF01BA2F67784B404182E2C798F54940EF01BA2F67784B404182E2C798F549407366BB421F764B400113B87537F349407366BB421F764B40
60590	Абдрахманово	7	64	151	52.464630999999997	52.498812000000001	54.785553	54.764532000000003	0103000020E6100000010000000500000098DA5207793B4A406C5F402FDC614B4098DA5207793B4A4029232E008D644B401A6D5512D93F4A4029232E008D644B401A6D5512D93F4A406C5F402FDC614B4098DA5207793B4A406C5F402FDC614B40
59389	Альметьевск	7	64	7477	52.248362	52.385624	54.921101	54.861719999999998	0103000020E61000000100000005000000DAC87553CA1F4A40912749D74C6E4B40DAC87553CA1F4A400DA837A3E6754B40BF4692205C314A400DA837A3E6754B40BF4692205C314A40912749D74C6E4B40DAC87553CA1F4A40912749D74C6E4B40
3937	Юхмачи	7	64	310	49.957649000000004	49.996402000000003	54.629513000000003	54.619045999999997	0103000020E610000001000000050000000806103E94FA48401C5C3AE63C4F4B400806103E94FA484014B4C9E193504B40A2D5C9198AFF484014B4C9E193504B40A2D5C9198AFF48401C5C3AE63C4F4B400806103E94FA48401C5C3AE63C4F4B40
3789	Чувашское Шапкино	7	64	310	49.791136999999999	49.807898999999999	54.821966000000003	54.814433999999999	0103000020E61000000100000005000000E9D32AFA43E548400F60915F3F684B40E9D32AFA43E548404436902E36694B404DBC033C69E748404436902E36694B404DBC033C69E748400F60915F3F684B40E9D32AFA43E548400F60915F3F684B40
3747	Чувашское Бурнаево	7	64	310	49.801872000000003	49.832352	54.727587999999997	54.706620000000001	0103000020E6100000010000000500000000CADFBDA3E648408A592F86725A4B4000CADFBDA3E64840247B849A215D4B404E61A5828AEA4840247B849A215D4B404E61A5828AEA48408A592F86725A4B4000CADFBDA3E648408A592F86725A4B40
3684	Чувашский Брод	7	64	310	50.055079999999997	50.114378000000002	54.747537999999999	54.733347999999999	0103000020E61000000100000005000000F35487DC0C074940234BE658DE5D4B40F35487DC0C07494035423F53AF5F4B40E2B034F0A30E494035423F53AF5F4B40E2B034F0A30E4940234BE658DE5D4B40F35487DC0C074940234BE658DE5D4B40
3653	Хлебодаровка	7	64	310	49.824150000000003	49.842582999999998	55.026128	55.015542000000003	0103000020E61000000100000005000000CC7F48BF7DE9484073DBBE47FD814B40CC7F48BF7DE9484044C18C2958834B4031957EC2D9EB484044C18C2958834B4031957EC2D9EB484073DBBE47FD814B40CC7F48BF7DE9484073DBBE47FD814B40
3447	Тяжбердино	7	64	310	49.923036000000003	49.94332	54.865062000000002	54.851412000000003	0103000020E61000000100000005000000ED832C0B26F6484003B68311FB6C4B40ED832C0B26F648409581035ABA6E4B40D4D4B2B5BEF848409581035ABA6E4B40D4D4B2B5BEF8484003B68311FB6C4B40ED832C0B26F6484003B68311FB6C4B40
3372	Татарское Тюгульбаево	7	64	310	49.656066000000003	49.683095999999999	54.808934999999998	54.796542000000002	0103000020E610000001000000050000003F027FF8F9D34840FAF19716F5654B403F027FF8F9D348407DCB9C2E8B674B40A30392B06FD748407DCB9C2E8B674B40A30392B06FD74840FAF19716F5654B403F027FF8F9D34840FAF19716F5654B40
3328	Татарское Муллино	7	64	310	50.140321	50.162159000000003	54.906300000000002	54.891629000000002	0103000020E6100000010000000500000094F8DC09F6114940259529E620724B4094F8DC09F6114940B22E6EA301744B4044E048A0C1144940B22E6EA301744B4044E048A0C1144940259529E620724B4094F8DC09F6114940259529E620724B40
3257	Татарское Бурнаево	7	64	310	49.836725999999999	49.872174000000001	54.741118999999998	54.726953999999999	0103000020E6100000010000000500000040DB6AD619EB484023D923D40C5D4B4040DB6AD619EB4840DCB8C5FCDC5E4B40F435CB65A3EF4840DCB8C5FCDC5E4B40F435CB65A3EF484023D923D40C5D4B4040DB6AD619EB484023D923D40C5D4B40
4167	Татарское Ахметьево	7	64	310	50.036808000000001	50.062365	54.707966999999996	54.690396999999997	0103000020E61000000100000005000000971DE21FB6044940D520CCED5E584B40971DE21FB6044940D8D2A3A99E5A4B4020B58993FB074940D8D2A3A99E5A4B4020B58993FB074940D520CCED5E584B40971DE21FB6044940D520CCED5E584B40
3848	Татарские Шибаши	7	64	310	49.862589	49.904468000000001	54.66639	54.652130999999997	0103000020E61000000100000005000000D671FC5069EE484098DA520779534B40D671FC5069EE4840D3307C444C554B40A723809BC5F34840D3307C444C554B40A723809BC5F3484098DA520779534B40D671FC5069EE484098DA520779534B40
3224	Старые Челны	7	64	310	50.044910999999999	50.065249000000001	54.988287999999997	54.970132	0103000020E61000000100000005000000861DC6A4BF054940CB660E492D7C4B40861DC6A4BF054940BE839F38807E4B40618C48145A084940BE839F38807E4B40618C48145A084940CB660E492D7C4B40861DC6A4BF054940CB660E492D7C4B40
3473	Старые Ургагары	7	64	310	50.008844000000003	50.036754000000002	54.899276	54.886434999999999	0103000020E610000001000000050000000762D9CC21014940CF83BBB376714B400762D9CC21014940F209D9791B734B40A4FFE55AB4044940F209D9791B734B40A4FFE55AB4044940CF83BBB376714B400762D9CC21014940CF83BBB376714B40
2785	Старые Салманы	7	64	310	49.721122000000001	49.748593	54.938529000000003	54.924163999999998	0103000020E610000001000000050000008B36C7B94DDC4840FD1186014B764B408B36C7B94DDC48407EACE0B721784B40DC813AE5D1DF48407EACE0B721784B40DC813AE5D1DF4840FD1186014B764B408B36C7B94DDC4840FD1186014B764B40
2979	Старые Матаки	7	64	310	49.828183000000003	49.860962999999998	54.876252000000001	54.861414000000003	0103000020E61000000100000005000000350D8AE601EA484085285FD0426E4B40350D8AE601EA4840FD86890629704B4074081C0934EE4840FD86890629704B4074081C0934EE484085285FD0426E4B40350D8AE601EA484085285FD0426E4B40
3979	Старое Ямкино	7	64	310	50.169732000000003	50.187527000000003	54.770187999999997	54.755460999999997	0103000020E61000000100000005000000D78A36C7B9154940A43330F2B2604B40D78A36C7B9154940C5E2378595624B40FA0E7EE200184940C5E2378595624B40FA0E7EE200184940A43330F2B2604B40D78A36C7B9154940A43330F2B2604B40
2912	Старое Камкино	7	64	310	50.107289999999999	50.131805	54.846010999999997	54.828578999999998	0103000020E610000001000000050000000B98C0ADBB0D494081936DE00E6A4B400B98C0ADBB0D49403387A4164A6C4B4082397AFCDE1049403387A4164A6C4B4082397AFCDE10494081936DE00E6A4B400B98C0ADBB0D494081936DE00E6A4B40
2861	Старое Алпарово	7	64	310	50.151505	50.194066999999997	54.887103000000003	54.867750999999998	0103000020E610000001000000050000001A170E84641349402009FB76126F4B401A170E84641349407D9752978C714B40CD1DFD2FD71849407D9752978C714B40CD1DFD2FD71849402009FB76126F4B401A170E84641349402009FB76126F4B40
3591	Старая Хурада	7	64	310	49.926504000000001	49.951163000000001	54.784001000000004	54.771948999999999	0103000020E610000001000000050000007DCEDDAE97F6484007978E39CF624B407DCEDDAE97F6484002840F255A644B4027158DB5BFF9484002840F255A644B4027158DB5BFF9484007978E39CF624B407DCEDDAE97F6484007978E39CF624B40
3088	Старая Тахтала	7	64	310	49.654502999999998	49.679755	54.894275	54.886181000000001	0103000020E6100000010000000500000023111AC1C6D3484015AB06616E714B4023111AC1C6D34840B1506B9A77724B4070253B3602D74840B1506B9A77724B4070253B3602D7484015AB06616E714B4023111AC1C6D3484015AB06616E714B40
2739	Среднее Алькеево	7	64	310	50.006903000000001	50.041048000000004	54.82846	54.815280000000001	0103000020E61000000100000005000000459F8F32E20049409C8A54185B684B40459F8F32E2004940A7052FFA0A6A4B407AC8940F41054940A7052FFA0A6A4B407AC8940F410549409C8A54185B684B40459F8F32E20049409C8A54185B684B40
61476	Сиктерме-Хузангаево	7	64	310	49.578892000000003	50.257192000000003	55.056600000000003	54.501153000000002	0103000020E6100000010000000500000041F50F2219CA48406AA510C825404B4041F50F2219CA4840107A36AB3E874B407C65DEAAEB204940107A36AB3E874B407C65DEAAEB2049406AA510C825404B4041F50F2219CA48406AA510C825404B40
2555	Новые Челны	7	64	310	50.013308000000002	50.039045000000002	54.958322000000003	54.943085000000004	0103000020E6100000010000000500000039639813B4014940912C6002B7784B4039639813B4014940C784984BAA7A4B404209336DFF044940C784984BAA7A4B404209336DFF044940912C6002B7784B4039639813B4014940912C6002B7784B40
61371	Новые Салманы	7	64	310	49.766209000000003	49.781201000000003	54.963211999999999	54.951037999999997	0103000020E610000001000000050000005073F22213E248406AA0F99CBB794B405073F22213E24840B08EE3874A7B4B401F4DF564FEE34840B08EE3874A7B4B401F4DF564FEE348406AA0F99CBB794B405073F22213E248406AA0F99CBB794B40
4053	Нижнее Колчурино	7	64	310	49.807476999999999	49.830177999999997	54.765166000000001	54.757269000000001	0103000020E61000000100000005000000D7A205685BE7484027A3CA30EE604B40D7A205685BE748406D01A1F5F0614B40E9EDCF4543EA48406D01A1F5F0614B40E9EDCF4543EA484027A3CA30EE604B40D7A205685BE7484027A3CA30EE604B40
2065	Нижнее Качеево	7	64	310	49.961413	50.006337000000002	54.681576	54.670358	0103000020E610000001000000050000008179C8940FFB4840554E7B4ACE554B408179C8940FFB484087DEE2E13D574B409CE09BA6CF00494087DEE2E13D574B409CE09BA6CF004940554E7B4ACE554B408179C8940FFB4840554E7B4ACE554B40
2520	Нижнее Биктимирово	7	64	310	49.955421000000001	49.967861999999997	54.889904000000001	54.880929999999999	0103000020E61000000100000005000000B0743E3C4BFA48405B087250C2704B40B0743E3C4BFA4840304AD05FE8714B404485EAE6E2FB4840304AD05FE8714B404485EAE6E2FB48405B087250C2704B40B0743E3C4BFA48405B087250C2704B40
2452	Нижнее Альмурзино	7	64	310	49.974133000000002	49.991767000000003	54.616152999999997	54.596691999999997	0103000020E61000000100000005000000297AE063B0FC484075E44867604C4B40297AE063B0FC4840882AFC19DE4E4B4043209738F2FE4840882AFC19DE4E4B4043209738F2FE484075E44867604C4B40297AE063B0FC484075E44867604C4B40
2407	Нижнее Алькеево	7	64	310	50.019722000000002	50.049689999999998	54.789664999999999	54.769077000000003	0103000020E6100000010000000500000080812040860249408B8D791D71624B408081204086024940DEE522BE13654B401878EE3D5C064940DEE522BE13654B401878EE3D5C0649408B8D791D71624B4080812040860249408B8D791D71624B40
2328	Кошки	7	64	310	49.618813000000003	49.645277	54.836098	54.820658999999999	0103000020E610000001000000050000007AABAE4335CF48408315A75A0B694B407AABAE4335CF484021205F42056B4B4035EECD6F98D2484021205F42056B4B4035EECD6F98D248408315A75A0B694B407AABAE4335CF48408315A75A0B694B40
2219	Каргополь	7	64	310	49.903973999999998	49.935468999999998	55.005749000000002	54.992440999999999	0103000020E610000001000000050000009737876BB5F34840D21A834E087F4B409737876BB5F348400B7E1B62BC804B40FEB5BC72BDF748400B7E1B62BC804B40FEB5BC72BDF74840D21A834E087F4B409737876BB5F34840D21A834E087F4B40
2173	Карамалы	7	64	310	50.202331999999998	50.22222	54.821863	54.807839999999999	0103000020E610000001000000050000009677D503E61949404833164D67674B409677D503E61949406F6589CE32694B40314278B4711C49406F6589CE32694B40314278B4711C49404833164D67674B409677D503E61949404833164D67674B40
2290	Каракули	7	64	310	49.980178000000002	49.995925999999997	54.570081000000002	54.556978999999998	0103000020E610000001000000050000001D21037976FD484086C77E164B474B401D21037976FD48401689096AF8484B40389ECF807AFF48401689096AF8484B40389ECF807AFF484086C77E164B474B401D21037976FD484086C77E164B474B40
1985	Верхние Матаки	7	64	310	49.787705000000003	49.812615999999998	54.869605999999997	54.858004999999999	0103000020E61000000100000005000000A6F27684D3E44840F9669B1BD36D4B40A6F27684D3E44840E333D93F4F6F4B40691A14CD03E84840E333D93F4F6F4B40691A14CD03E84840F9669B1BD36D4B40A6F27684D3E44840F9669B1BD36D4B40
1931	Верхнее Колчурино	7	64	310	49.76885	49.796266000000003	54.761643999999997	54.737594999999999	0103000020E61000000100000005000000CAC342AD69E24840B8585183695E4B40CAC342AD69E24840E998F38C7D614B405875560BECE54840E998F38C7D614B405875560BECE54840B8585183695E4B40CAC342AD69E24840B8585183695E4B40
2106	Верхнее Качеево	7	64	310	49.925030999999997	49.942934000000001	54.695298999999999	54.681961000000001	0103000020E61000000100000005000000A164726A67F64840E012807F4A574B40A164726A67F6484083F8C08EFF584B40AB24B20FB2F8484083F8C08EFF584B40AB24B20FB2F84840E012807F4A574B40A164726A67F64840E012807F4A574B40
1853	Верхнее Альмурзино	7	64	310	49.894101999999997	49.931265000000003	54.618744	54.610469999999999	0103000020E61000000100000005000000E3A430EF71F24840359886E1234E4B40E3A430EF71F24840514CDE00334F4B40697407B133F74840514CDE00334F4B40697407B133F74840359886E1234E4B40E3A430EF71F24840359886E1234E4B40
1817	Верхнее Алькеево	7	64	310	49.972920000000002	49.992809000000001	54.78546	54.775064999999998	0103000020E61000000100000005000000EACF7EA488FC48401AA3755435634B40EACF7EA488FC484078280AF489644B405516855D14FF484078280AF489644B405516855D14FF48401AA3755435634B40EACF7EA488FC48401AA3755435634B40
1753	Борискино	7	64	310	50.101540999999997	50.126100999999998	54.798591999999999	54.779161999999999	0103000020E61000000100000005000000001AA54BFF0C49409A249694BB634B40001AA54BFF0C4940726C3D4338664B40177FDB1324104940726C3D4338664B40177FDB13241049409A249694BB634B40001AA54BFF0C49409A249694BB634B40
1710	Бибаево-Челны	7	64	310	50.054755999999998	50.078327999999999	55.012748999999999	54.998080000000002	0103000020E6100000010000000500000040A19E3E020749405665DF15C17F4B4040A19E3E0207494042075DC2A1814B40382EE3A6060A494042075DC2A1814B40382EE3A6060A49405665DF15C17F4B4040A19E3E020749405665DF15C17F4B40
1397	Базарные Матаки	7	64	310	49.904873000000002	49.948251999999997	54.920222000000003	54.892561000000001	0103000020E610000001000000050000004704E3E0D2F34840B05758703F724B404704E3E0D2F34840A587A1D5C9754B40EC2E505260F94840A587A1D5C9754B40EC2E505260F94840B05758703F724B404704E3E0D2F34840B05758703F724B40
4092	Аппаково	7	64	310	49.946806000000002	49.979593999999999	54.540371999999998	54.525154000000001	0103000020E610000001000000050000000BD462F030F948408AAE0B3F38434B400BD462F030F9484049D6E1E82A454B40CDAD105663FD484049D6E1E82A454B40CDAD105663FD48408AAE0B3F38434B400BD462F030F948408AAE0B3F38434B40
40355	Старая Тумба	7	64	6904	49.578892000000003	50.257192000000003	55.056600000000003	54.501153000000002	0103000020E6100000010000000500000041F50F2219CA48406AA510C825404B4041F50F2219CA4840107A36AB3E874B407C65DEAAEB204940107A36AB3E874B407C65DEAAEB2049406AA510C825404B4041F50F2219CA48406AA510C825404B40
1299	Ялкын	7	64	20	49.868445999999999	49.890436999999999	55.089036999999998	55.077008999999997	0103000020E61000000100000005000000C72B103D29EF4840B33F506EDB894B40C72B103D29EF484025917D90658B4B40FD12F1D6F9F1484025917D90658B4B40FD12F1D6F9F14840B33F506EDB894B40C72B103D29EF4840B33F506EDB894B40
31528	Шама	7	64	20	50.472535999999998	50.495649999999998	54.990167999999997	54.971848000000001	0103000020E610000001000000050000006117450F7C3C49406D57E883657C4B406117450F7C3C4940DAC534D3BD7E4B4096218E75713F4940DAC534D3BD7E4B4096218E75713F49406D57E883657C4B406117450F7C3C49406D57E883657C4B40
446	Чувашская Майна	7	64	20	50.508477999999997	50.540080000000003	55.057363000000002	55.048197999999999	0103000020E61000000100000005000000245E9ECE15414940C6DD205A2B864B40245E9ECE154149400F80B8AB57874B40A29C6857214549400F80B8AB57874B40A29C685721454940C6DD205A2B864B40245E9ECE15414940C6DD205A2B864B40
700	Тиган-Буляк	7	64	20	50.246806999999997	50.259985999999998	55.159695999999997	55.149517000000003	0103000020E6100000010000000500000041B62C5F971F49401899805F23934B4041B62C5F971F4940A8A624EB70944B407CB5A33847214940A8A624EB70944B407CB5A338472149401899805F23934B4041B62C5F971F49401899805F23934B40
32290	Сухие Курнали	7	64	20	50.011358999999999	50.037266000000002	55.155962000000002	55.140856999999997	0103000020E61000000100000005000000F4C1323674014940D234289A07924B40F4C13236740149409AB51490F6934B405AA0DD21C50449409AB51490F6934B405AA0DD21C5044940D234289A07924B40F4C1323674014940D234289A07924B40
1134	Степная Шентала	7	64	20	50.257379999999998	50.289396000000004	55.294817000000002	55.275221000000002	0103000020E610000001000000050000007E52EDD3F1204940121615713AA34B407E52EDD3F120494005A73E90BCA54B40EFCB99ED0A25494005A73E90BCA54B40EFCB99ED0A254940121615713AA34B407E52EDD3F1204940121615713AA34B40
32111	Старое Муллино	7	64	20	50.148397000000003	50.181472999999997	54.938684000000002	54.927573000000002	0103000020E610000001000000050000008AE942ACFE12494089D349B6BA764B408AE942ACFE124940A5A31CCC26784B40B20DDC813A174940A5A31CCC26784B40B20DDC813A17494089D349B6BA764B408AE942ACFE12494089D349B6BA764B40
1006	Средние Тиганы	7	64	20	50.179631000000001	50.208745999999998	55.177720000000001	55.153816999999997	0103000020E61000000100000005000000842C0B26FE164940CF488446B0934B40842C0B26FE1649402DEC6987BF964B40DD955D30B81A49402DEC6987BF964B40DD955D30B81A4940CF488446B0934B40842C0B26FE164940CF488446B0934B40
893	Сахаровка	7	64	20	50.262949999999996	50.312249999999999	55.318064999999997	55.304385000000003	0103000020E61000000100000005000000D93D7958A82149404D327216F6A64B40D93D7958A821494049809A5AB6A84B408716D9CEF727494049809A5AB6A84B408716D9CEF72749404D327216F6A64B40D93D7958A82149404D327216F6A64B40
132	Саконы	7	64	20	50.195782999999999	50.214458999999998	55.378979000000001	55.365233000000003	0103000020E610000001000000050000006F0ED76A0F194940C23577F4BFAE4B406F0ED76A0F194940766F456282B04B409BAA7B64731B4940766F456282B04B409BAA7B64731B4940C23577F4BFAE4B406F0ED76A0F194940C23577F4BFAE4B40
31369	Сабакайка	7	64	20	50.015186	50.031778000000003	55.248837000000002	55.238044000000002	0103000020E61000000100000005000000B4AD669DF10149402881CD39789E4B40B4AD669DF101494073840CE4D99F4B40BC5D2F4D1104494073840CE4D99F4B40BC5D2F4D110449402881CD39789E4B40B4AD669DF10149402881CD39789E4B40
821	Ромодан	7	64	20	49.983106999999997	50.020746000000003	55.067715999999997	55.054355999999999	0103000020E61000000100000005000000FDBB3E73D6FD4840B22B2D23F5864B40FDBB3E73D6FD48403DB5FAEAAA884B40ECC20FCEA70249403DB5FAEAAA884B40ECC20FCEA7024940B22B2D23F5864B40FDBB3E73D6FD4840B22B2D23F5864B40
651	Родники	7	64	20	50.244795000000003	50.262348000000003	55.146759000000003	55.129669	0103000020E61000000100000005000000B79C4B71551F49400B2769FE98904B40B79C4B71551F494064B2B8FFC8924B40E415889E9421494064B2B8FFC8924B40E415889E942149400B2769FE98904B40B79C4B71551F49400B2769FE98904B40
933	Речное	7	64	20	50.255673999999999	50.290205	55.371296000000001	55.358421999999997	0103000020E610000001000000050000000038F6ECB92049405D15A8C5E0AD4B400038F6ECB92049405C9198A086AF4B405E11FC6F252549405C9198A086AF4B405E11FC6F252549405D15A8C5E0AD4B400038F6ECB92049405D15A8C5E0AD4B40
32514	Приозерная	7	64	20	50.261862999999998	50.287196000000002	54.957442999999998	54.941285999999998	0103000020E6100000010000000500000027840EBA842149406117450F7C784B4027840EBA842149405E64027E8D7A4B4061C5A9D6C22449405E64027E8D7A4B4061C5A9D6C22449406117450F7C784B4027840EBA842149406117450F7C784B40
523	Подлесная Шентала	7	64	20	50.336136000000003	50.360875	55.120325999999999	55.104140999999998	0103000020E610000001000000050000000F812381062B49401C96067E548D4B400F812381062B4940E36DA5D7668F4B40D578E926312E4940E36DA5D7668F4B40D578E926312E49401C96067E548D4B400F812381062B49401C96067E548D4B40
61363	Новоспасск	7	64	20	49.957613000000002	49.976081999999998	55.214737999999997	55.201577	0103000020E61000000100000005000000BB9C121093FA48401A506F46CD994B40BB9C121093FA4840AE9AE7887C9B4B406D1B4641F0FC4840AE9AE7887C9B4B406D1B4641F0FC48401A506F46CD994B40BB9C121093FA48401A506F46CD994B40
1056	Нижние Тиганы	7	64	20	50.222472000000003	50.251927999999999	55.194865999999998	55.182968000000002	0103000020E610000001000000050000004B2366F6791C4940761BD47E6B974B404B2366F6791C4940198D7C5EF1984B402D793C2D3F204940198D7C5EF1984B402D793C2D3F204940761BD47E6B974B404B2366F6791C4940761BD47E6B974B40
31883	Мокрые Курнали	7	64	20	49.968536	50.003157000000002	55.299577999999997	55.278430999999998	0103000020E61000000100000005000000D47FD6FCF8FB4840A69883A0A3A34B40D47FD6FCF8FB4840F04C689258A64B4072E0D57267004940F04C689258A64B4072E0D57267004940A69883A0A3A34B40D47FD6FCF8FB4840A69883A0A3A34B40
767	Масловка	7	64	20	49.989502999999999	50.012140000000002	55.11562	55.096755000000002	0103000020E610000001000000050000009E25C808A8FE4840BC5CC477628C4B409E25C808A8FE4840BB61DBA2CC8E4B409A7CB3CD8D014940BB61DBA2CC8E4B409A7CB3CD8D014940BC5CC477628C4B409E25C808A8FE4840BC5CC477628C4B40
32200	Мараса	7	64	20	50.218358000000002	50.240968000000002	54.884762000000002	54.872202000000001	0103000020E61000000100000005000000F568AA27F31B4940BEC0AC50A46F4B40F568AA27F31B49402D5F97E13F714B40F7B0170AD81E49402D5F97E13F714B40F7B0170AD81E4940BEC0AC50A46F4B40F568AA27F31B4940BEC0AC50A46F4B40
1178	Малый Красный Яр	7	64	20	50.241003999999997	50.255431000000002	55.243746000000002	55.228839000000001	0103000020E61000000100000005000000431A1538D91E49405186AA984A9D4B40431A1538D91E4940F243A511339F4B403AB187F6B1204940F243A511339F4B403AB187F6B12049405186AA984A9D4B40431A1538D91E49405186AA984A9D4B40
182	Левашево	7	64	20	49.899456000000001	49.926450000000003	55.149697000000003	55.129328999999998	0103000020E610000001000000050000007218CC5F21F3484052B648DA8D904B407218CC5F21F3484098A7734529934B408AB0E1E995F6484098A7734529934B408AB0E1E995F6484052B648DA8D904B407218CC5F21F3484052B648DA8D904B40
25	Лебяжье	7	64	20	50.142099999999999	50.165374999999997	55.333359000000002	55.312845000000003	0103000020E610000001000000050000007C61325530124940CBDB114E0BA84B407C61325530124940E469F981ABAA4B40BA490C022B154940E469F981ABAA4B40BA490C022B154940CBDB114E0BA84B407C61325530124940CBDB114E0BA84B40
32360	Лебедино	7	64	20	49.804423	49.855922999999997	55.234023999999998	55.217275000000001	0103000020E610000001000000050000003A933655F7E64840849ECDAACF9B4B403A933655F7E64840533D997FF49D4B40757286E28EED4840533D997FF49D4B40757286E28EED4840849ECDAACF9B4B403A933655F7E64840849ECDAACF9B4B40
32239	Куркуль	7	64	20	50.099933	50.124617999999998	55.201324999999997	55.188564999999997	0103000020E610000001000000050000004565C39ACA0C4940CA15DEE522984B404565C39ACA0C4940006F8104C5994B40183F8D7BF30F4940006F8104C5994B40183F8D7BF30F4940CA15DEE522984B404565C39ACA0C4940CA15DEE522984B40
31665	Красный Баран	7	64	20	50.186737000000001	50.215823999999998	55.028945	55.015329999999999	0103000020E6100000010000000500000001FA7DFFE6174940E7525C55F6814B4001FA7DFFE6174940FD304278B4834B4090D8EE1EA01B4940FD304278B4834B4090D8EE1EA01B4940E7525C55F6814B4001FA7DFFE6174940E7525C55F6814B40
1247	Караваево	7	64	20	49.829386999999997	49.867888999999998	55.101534999999998	55.087007	0103000020E61000000100000005000000205D6C5A29EA4840F4C29D0B238B4B40205D6C5A29EA48401E335019FF8C4B4071C79BFC16EF48401E335019FF8C4B4071C79BFC16EF4840F4C29D0B238B4B40205D6C5A29EA4840F4C29D0B238B4B40
32109	Ерыкла	7	64	20	50.215949999999999	50.235956000000002	54.960937999999999	54.946038000000001	0103000020E610000001000000050000001DC9E53FA41B4940FA62EFC517794B401DC9E53FA41B4940E8BD3104007B4B40C2A563CE331E4940E8BD3104007B4B40C2A563CE331E4940FA62EFC517794B401DC9E53FA41B4940FA62EFC517794B40
317	Горка	7	64	20	50.403086999999999	50.423057	55.029125999999998	55.017446999999997	0103000020E61000000100000005000000AC38D55A98334940E7340BB43B824B40AC38D55A983349404DBB9866BA834B4004AC55BB263649404DBB9866BA834B4004AC55BB26364940E7340BB43B824B40AC38D55A98334940E7340BB43B824B40
31981	Войкино	7	64	20	49.780329999999999	49.810397000000002	55.115212999999997	55.097903000000002	0103000020E61000000100000005000000390B7BDAE1E348401497E315888C4B40390B7BDAE1E348407A89B14CBF8E4B4065E3C116BBE748407A89B14CBF8E4B4065E3C116BBE748401497E315888C4B40390B7BDAE1E348401497E315888C4B40
398	Верхняя Татарская Майна	7	64	20	50.438023000000001	50.458387000000002	55.080348999999998	55.065973	0103000020E61000000100000005000000AAF23D2311384940A2B5A2CD71884B40AAF23D231138494016A243E0488A4B40AEF4DA6CAC3A494016A243E0488A4B40AEF4DA6CAC3A4940A2B5A2CD71884B40AAF23D2311384940A2B5A2CD71884B40
31931	Бутлеровка	7	64	20	49.944209999999998	49.966307999999998	55.258946000000002	55.248005999999997	0103000020E6100000010000000500000030478FDFDBF848401B9B1DA9BE9F4B4030478FDFDBF848400BB77C2425A14B407CEE04FBAFFB48400BB77C2425A14B407CEE04FBAFFB48401B9B1DA9BE9F4B4030478FDFDBF848401B9B1DA9BE9F4B40
31745	Большие Тиганы	7	64	20	50.135973	50.166058	55.141993999999997	55.122430999999999	0103000020E61000000100000005000000CB113290671149401F82AAD1AB8F4B40CB11329067114940361D01DC2C924B409D9E776341154940361D01DC2C924B409D9E7763411549401F82AAD1AB8F4B40CB113290671149401F82AAD1AB8F4B40
31615	Большие Полянки	7	64	20	50.209598999999997	50.238399000000001	55.060285999999998	55.040709	0103000020E610000001000000050000001C23D923D41A494091D3D7F335854B401C23D923D41A49400D349F73B7874B401633C2DB831E49400D349F73B7874B401633C2DB831E494091D3D7F335854B401C23D923D41A494091D3D7F335854B40
31431	Билярск	7	64	20	50.357246000000004	50.404434999999999	54.998353999999999	54.970002999999998	0103000020E610000001000000050000003C50A73CBA2D4940CD02ED0E297C4B403C50A73CBA2D494057EA5910CA7F4B40CB2DAD86C433494057EA5910CA7F4B40CB2DAD86C4334940CD02ED0E297C4B403C50A73CBA2D4940CD02ED0E297C4B40
32490	Березовая Грива	7	64	20	49.734489000000004	49.754288000000003	55.206180000000003	55.198093	0103000020E61000000100000005000000C9224DBC03DE48408448861C5B994B40C9224DBC03DE48406E8B321B649A4B40F4E159828CE048406E8B321B649A4B40F4E159828CE048408448861C5B994B40C9224DBC03DE48408448861C5B994B40
31938	Балахчино	7	64	20	49.918374	49.936357999999998	55.312567999999999	55.299475999999999	0103000020E6100000010000000500000094BF7B478DF54840ECF7C43A55A64B4094BF7B478DF5484058E36C3A02A84B408AAC3594DAF7484058E36C3A02A84B408AAC3594DAF74840ECF7C43A55A64B4094BF7B478DF54840ECF7C43A55A64B40
32039	Базяково	7	64	20	49.718094999999998	49.737301000000002	55.144947999999999	55.127898000000002	0103000020E61000000100000005000000E7357689EADB4840A69C2FF65E904B40E7357689EADB484070CFF3A78D924B40702711E15FDE484070CFF3A78D924B40702711E15FDE4840A69C2FF65E904B40E7357689EADB4840A69C2FF65E904B40
578	Арбузов-Баран	7	64	20	50.297679000000002	50.314055000000003	55.028269000000002	55.0017	0103000020E610000001000000050000005EDA70581A2649409C33A2B437804B405EDA70581A264940CD3E8F519E834B40991249F432284940CD3E8F519E834B40991249F4322849409C33A2B437804B405EDA70581A2649409C33A2B437804B40
31084	Алексеевское	7	64	20	50.072696000000001	50.141219	55.319633000000003	55.295344	0103000020E6100000010000000500000067463F1A4E094940F0880AD5CDA54B4067463F1A4E09494077DCF0BBE9A84B407349D5761312494077DCF0BBE9A84B407349D57613124940F0880AD5CDA54B4067463F1A4E094940F0880AD5CDA54B40
31667	Александровка	7	64	20	50.126226000000003	50.148172000000002	55.039037	55.029533000000001	0103000020E61000000100000005000000D4F36E2C281049408E93C2BCC7834B40D4F36E2C28104940BF2A172AFF844B406A17D34CF7124940BF2A172AFF844B406A17D34CF71249408E93C2BCC7834B40D4F36E2C281049408E93C2BCC7834B40
31026	Шарипово	7	64	1851	53.922471000000002	53.937714999999997	55.708004000000003	55.698324999999997	0103000020E6100000010000000500000014419C8713F64A40567DAEB662D94B4014419C8713F64A40F6B704E09FDA4B40FCFB8C0B07F84A40F6B704E09FDA4B40FCFB8C0B07F84A40567DAEB662D94B4014419C8713F64A40567DAEB662D94B40
30930	Чуракаево	7	64	1851	53.847551000000003	53.884005000000002	55.417648999999997	55.400660000000002	0103000020E610000001000000050000009758198D7CEC4A405E68AED348B34B409758198D7CEC4A40821ABE8575B54B4010406A1327F14A40821ABE8575B54B4010406A1327F14A405E68AED348B34B409758198D7CEC4A405E68AED348B34B40
30925	Чишма	7	64	1851	54.000292000000002	54.015760999999998	55.588084000000002	55.56953	0103000020E61000000100000005000000A839799109004B40A20BEA5BE6C84B40A839799109004B4083A6255646CB4B40B0C6D97404024B4083A6255646CB4B40B0C6D97404024B40A20BEA5BE6C84B40A839799109004B40A20BEA5BE6C84B40
30845	Чатово	7	64	1851	53.655482999999997	53.675505999999999	55.669035999999998	55.659880999999999	0103000020E61000000100000005000000BF0AF0DDE6D34A403A2009FB76D44B40BF0AF0DDE6D34A405FECBDF8A2D54B403A2009FB76D64A405FECBDF8A2D54B403A2009FB76D64A403A2009FB76D44B40BF0AF0DDE6D34A403A2009FB76D44B40
30778	Чалманарат	7	64	1851	53.763297999999999	53.786878999999999	55.779989999999998	55.765985000000001	0103000020E61000000100000005000000158DB5BFB3E14A40001DE6CB0BE24B40158DB5BFB3E14A40809A5AB6D6E34B4060747973B8E44A40809A5AB6D6E34B4060747973B8E44A40001DE6CB0BE24B40158DB5BFB3E14A40001DE6CB0BE24B40
30733	Усы	7	64	1851	53.611375000000002	53.634174999999999	55.569077	55.562612000000001	0103000020E61000000100000005000000C74B378941CE4A40282B86AB03C84B40C74B378941CE4A40F1F3DF83D7C84B406C787AA52CD14A40F1F3DF83D7C84B406C787AA52CD14A40282B86AB03C84B40C74B378941CE4A40282B86AB03C84B40
30719	Уразаево	7	64	1851	53.924384000000003	53.946941000000002	55.761015999999998	55.74982	0103000020E610000001000000050000000C79043752F64A4080F10C1AFADF4B400C79043752F64A40CADDE7F868E14B40EB1ED95C35F94A40CADDE7F868E14B40EB1ED95C35F94A4080F10C1AFADF4B400C79043752F64A4080F10C1AFADF4B40
30612	Улиманово	7	64	1851	53.659776999999998	53.67971	55.486539999999998	55.474336999999998	0103000020E6100000010000000500000095D39E9273D44A4031242713B7BC4B4095D39E9273D44A40111956F146BE4B40D061BEBC00D74A40111956F146BE4B40D061BEBC00D74A4031242713B7BC4B4095D39E9273D44A4031242713B7BC4B40
30614	Тюково	7	64	1851	53.535108000000001	53.560755	55.610595000000004	55.594071999999997	0103000020E61000000100000005000000FBE93F6B7EC44A4012BC218D0ACC4B40FBE93F6B7EC44A40F20C1AFA27CE4B40C408E1D1C6C74A40F20C1AFA27CE4B40C408E1D1C6C74A4012BC218D0ACC4B40FBE93F6B7EC44A4012BC218D0ACC4B40
30422	Татарские Ямалы	7	64	1851	53.746087000000003	53.769424999999998	55.832439000000001	55.823146000000001	0103000020E61000000100000005000000427C60C77FDF4A40A7EA1ED95CE94B40427C60C77FDF4A401D75745C8DEA4B40C6DCB5847CE24A401D75745C8DEA4B40C6DCB5847CE24A40A7EA1ED95CE94B40427C60C77FDF4A40A7EA1ED95CE94B40
30417	Татарские Суксы	7	64	1851	53.646642999999997	53.666702999999998	55.762799000000001	55.745548999999997	0103000020E61000000100000005000000FA97A432C5D24A4062484E266EDF4B40FA97A432C5D24A40F435CB65A3E14B4092921E8656D54A40F435CB65A3E14B4092921E8656D54A4062484E266EDF4B40FA97A432C5D24A4062484E266EDF4B40
30313	Такталачук	7	64	1851	53.853678000000002	53.884597999999997	55.777596000000003	55.758685999999997	0103000020E6100000010000000500000048A8195245ED4A406EF7729F1CE14B4048A8195245ED4A400EC0064488E34B40B20DDC813AF14A400EC0064488E34B40B20DDC813AF14A406EF7729F1CE14B4048A8195245ED4A406EF7729F1CE14B40
61429	Табанлы-Куль	7	64	1851	53.735602999999998	53.756515999999998	55.438603999999998	55.424627999999998	0103000020E6100000010000000500000074EB353D28DE4A40A27BD6355AB64B4074EB353D28DE4A4088F2052D24B84B404B732B84D5E04A4088F2052D24B84B404B732B84D5E04A40A27BD6355AB64B4074EB353D28DE4A40A27BD6355AB64B40
61464	Старые Урьяды	7	64	1851	53.602904000000002	53.615614999999998	55.702145000000002	55.692439999999998	0103000020E61000000100000005000000555051F52BCD4A409B38B9DFA1D84B40555051F52BCD4A4064062AE3DFD94B40A9F6E978CCCE4A4064062AE3DFD94B40A9F6E978CCCE4A409B38B9DFA1D84B40555051F52BCD4A409B38B9DFA1D84B40
32547	Старые Бугады	7	64	1851	53.880259000000002	53.943105000000003	55.620016	55.607472999999999	0103000020E610000001000000050000003D81B053ACF04A40FC19DEACC1CD4B403D81B053ACF04A40957F2DAF5CCF4B40D8D825AAB7F84A40957F2DAF5CCF4B40D8D825AAB7F84A40FC19DEACC1CD4B403D81B053ACF04A40FC19DEACC1CD4B40
30470	Старое Тлякеево	7	64	1851	53.845475999999998	53.877034000000002	55.711696000000003	55.699334999999998	0103000020E61000000100000005000000C5C6BC8E38EC4A405DF92CCF83D94B40C5C6BC8E38EC4A40D658C2DA18DB4B4073BD6DA642F04A40D658C2DA18DB4B4073BD6DA642F04A405DF92CCF83D94B40C5C6BC8E38EC4A405DF92CCF83D94B40
32563	Старое Сафарово	7	64	1851	53.775002999999998	53.802950000000003	55.557785000000003	55.540199999999999	0103000020E61000000100000005000000A4A65D4C33E34A404CA60A4625C54B40A4A65D4C33E34A408599B67F65C74B405F29CB10C7E64A408599B67F65C74B405F29CB10C7E64A404CA60A4625C54B40A4A65D4C33E34A404CA60A4625C54B40
32555	Старое Курмашево	7	64	1851	53.751683	53.771132000000001	55.675311000000001	55.660941999999999	0103000020E61000000100000005000000C6FA062637E04A40C34659BF99D44B40C6FA062637E04A4085D0419770D64B4015731074B4E24A4085D0419770D64B4015731074B4E24A40C34659BF99D44B40C6FA062637E04A40C34659BF99D44B40
61417	Старое Бикчентаево	7	64	1851	53.676305999999997	53.695646000000004	55.641157999999997	55.628759000000002	0103000020E61000000100000005000000560BEC3191D64A406808C72C7BD04B40560BEC3191D64A40CDC8207711D24B40EFCB99ED0AD94A40CDC8207711D24B40EFCB99ED0AD94A406808C72C7BD04B40560BEC3191D64A406808C72C7BD04B40
32543	Старое Байсарово	7	64	1851	53.853974000000001	53.887768999999999	55.486677999999998	55.474229999999999	0103000020E6100000010000000500000031D120054FED4A401B649291B3BC4B4031D120054FED4A4062D7F6764BBE4B4089B3226AA2F14A4062D7F6764BBE4B4089B3226AA2F14A401B649291B3BC4B4031D120054FED4A401B649291B3BC4B40
61448	Старое Алимово	7	64	1851	54.032245000000003	54.054290000000002	55.630699999999997	55.618893	0103000020E61000000100000005000000D23AAA9A20044B40965CC5E237CF4B40D23AAA9A20044B4029CB10C7BAD04B40FB3F87F9F2064B4029CB10C7BAD04B40FB3F87F9F2064B40965CC5E237CF4B40D23AAA9A20044B40965CC5E237CF4B40
61368	Старое Айманово	7	64	1851	53.515058000000003	53.544153999999999	55.516154999999998	55.505020999999999	0103000020E6100000010000000500000087C5A86BEDC14A4088653387A4C04B4087C5A86BEDC14A405C55F65D11C24B4069FE98D6A6C54A405C55F65D11C24B4069FE98D6A6C54A4088653387A4C04B4087C5A86BEDC14A4088653387A4C04B40
61501	Старое Агбязово	7	64	1851	53.818347000000003	53.842449000000002	55.400522000000002	55.384031999999998	0103000020E61000000100000005000000CEE33098BFE84A40094FE8F527B14B40CEE33098BFE84A400DAA0D4E44B34B4022C66B5ED5EB4A400DAA0D4E44B34B4022C66B5ED5EB4A40094FE8F527B14B40CEE33098BFE84A40094FE8F527B14B40
29883	Поисево	7	64	1851	53.473303999999999	53.514769999999999	55.547035999999999	55.527462999999997	0103000020E610000001000000050000007288B83995BC4A40CE6C57E883C34B407288B83995BC4A4009DE904605C64B40207BBDFBE3C14A4009DE904605C64B40207BBDFBE3C14A40CE6C57E883C34B407288B83995BC4A40CE6C57E883C34B40
61445	Новое Курмашево	7	64	1851	53.706552000000002	53.724060000000001	55.719048999999998	55.704670999999998	0103000020E610000001000000050000003276C24B70DA4A4045B8C9A832DA4B403276C24B70DA4A405A9C31CC09DC4B40BF2B82FFADDC4A405A9C31CC09DC4B40BF2B82FFADDC4A4045B8C9A832DA4B403276C24B70DA4A4045B8C9A832DA4B40
33137	Новое Алимово	7	64	1851	54.021034	54.064045	55.685158000000001	55.669305000000001	0103000020E61000000100000005000000520DFB3DB1024B404F0647C9ABD54B40520DFB3DB1024B40E04BE141B3D74B40753C66A032084B40E04BE141B3D74B40753C66A032084B404F0647C9ABD54B40520DFB3DB1024B404F0647C9ABD54B40
61364	Нижнее Гареево	7	64	1851	53.805410999999999	53.820430999999999	55.789937000000002	55.781686000000001	0103000020E61000000100000005000000596B28B517E74A40DBDE6E490EE44B40596B28B517E74A403F73D6A71CE54B40F2CF0CE203E94A403F73D6A71CE54B40F2CF0CE203E94A40DBDE6E490EE44B40596B28B517E74A40DBDE6E490EE44B40
29737	Мари-Суксы	7	64	1851	53.633546000000003	53.658707999999997	55.751852	55.739341000000003	0103000020E610000001000000050000007D410B0918D14A40C5CBD3B9A2DE4B407D410B0918D14A4052B7B3AF3CE04B4089CE328B50D44A4052B7B3AF3CE04B4089CE328B50D44A40C5CBD3B9A2DE4B407D410B0918D14A40C5CBD3B9A2DE4B40
29660	Куяново	7	64	1851	53.990743000000002	54.025219999999997	55.744931000000001	55.726117000000002	0103000020E61000000100000005000000D7DEA7AAD0FE4A40EA08E066F1DC4B40D7DEA7AAD0FE4A40676325E659DF4B40419AB1683A034B40676325E659DF4B40419AB1683A034B40EA08E066F1DC4B40D7DEA7AAD0FE4A40EA08E066F1DC4B40
61424	Кузякино	7	64	1851	53.566575999999998	53.600524	55.658346999999999	55.641823000000002	0103000020E610000001000000050000006859F78F85C84A400A698D4127D24B406859F78F85C84A40B935E9B644D44B40473B6EF8DDCC4A40B935E9B644D44B40473B6EF8DDCC4A400A698D4127D24B406859F78F85C84A400A698D4127D24B40
29471	Качкиново	7	64	1851	53.566037000000001	53.577114000000002	55.554561999999997	55.538941999999999	0103000020E61000000100000005000000B9A981E673C84A406D382C0DFCC44B40B9A981E673C84A405BCD3AE3FBC64B4029081EDFDEC94A405BCD3AE3FBC64B4029081EDFDEC94A406D382C0DFCC44B40B9A981E673C84A406D382C0DFCC44B40
29465	Казкеево	7	64	1851	54.172598000000001	54.210667999999998	55.675224999999998	55.653095999999998	0103000020E6100000010000000500000071ADF6B017164B40FF9254A698D34B4071ADF6B017164B408638D6C56DD64B402828452BF71A4B408638D6C56DD64B402828452BF71A4B40FF9254A698D34B4071ADF6B017164B40FF9254A698D34B40
29335	Имени Кирова	7	64	1851	53.687624	53.716424000000004	55.557785000000003	55.545228000000002	0103000020E61000000100000005000000ECF82F1004D84A40876EF607CAC54B40ECF82F1004D84A408599B67F65C74B40E60819C8B3DB4A408599B67F65C74B40E60819C8B3DB4A40876EF607CAC54B40ECF82F1004D84A40876EF607CAC54B40
61413	Верхнее Яхшеево	7	64	1851	53.719172999999998	53.737175000000001	55.477817000000002	55.465774000000003	0103000020E61000000100000005000000469561DC0DDC4A40DFA9807B9EBB4B40469561DC0DDC4A40863C821B29BD4B40E3361AC05BDE4A40863C821B29BD4B40E3361AC05BDE4A40DFA9807B9EBB4B40469561DC0DDC4A40DFA9807B9EBB4B40
29292	Барсуково	7	64	1851	53.842036	53.858367000000001	55.819817999999998	55.808532999999997	0103000020E61000000100000005000000FF06EDD5C7EB4A404E5E64027EE74B40FF06EDD5C7EB4A400856D5CBEFE84B409A7B48F8DEED4A400856D5CBEFE84B409A7B48F8DEED4A404E5E64027EE74B40FF06EDD5C7EB4A404E5E64027EE74B40
29201	Атясево	7	64	1851	53.630231000000002	53.642304000000003	55.620586000000003	55.611795000000001	0103000020E6100000010000000500000073F6CE68ABD04A409C6D6E4C4FCE4B4073F6CE68ABD04A40802DAF5C6FCF4B40850B790437D24A40802DAF5C6FCF4B40850B790437D24A409C6D6E4C4FCE4B4073F6CE68ABD04A409C6D6E4C4FCE4B40
28752	Актаныш	7	64	1851	54.043528000000002	54.097498999999999	55.732109000000001	55.702297000000002	0103000020E61000000100000005000000EB3A545392054B401A8A3BDEE4D94B40EB3A545392054B40BB0D6ABFB5DD4B404432E4D87A0C4B40BB0D6ABFB5DD4B404432E4D87A0C4B401A8A3BDEE4D94B40EB3A545392054B401A8A3BDEE4D94B40
29199	Аккузово	7	64	1851	53.919201000000001	53.942377999999998	55.528477000000002	55.514845000000001	0103000020E61000000100000005000000AAB9DC60A8F54A402BC1E270E6C14B40AAB9DC60A8F54A4017D86322A5C34B40253CA1D79FF84A4017D86322A5C34B40253CA1D79FF84A402BC1E270E6C14B40AAB9DC60A8F54A402BC1E270E6C14B40
29073	Аишево	7	64	1851	54.117871999999998	54.142684000000003	55.635843000000001	55.622216999999999	0103000020E610000001000000050000009B8E006E160F4B40F30181CEA4CF4B409B8E006E160F4B40FD31AD4D63D14B40CCD4247843124B40FD31AD4D63D14B40CCD4247843124B40F30181CEA4CF4B409B8E006E160F4B40F30181CEA4CF4B40
29032	Адаево	7	64	1851	53.534928999999998	53.559722000000001	55.716357000000002	55.706659999999999	0103000020E610000001000000050000004B57B08D78C44A4018B2BAD573DA4B404B57B08D78C44A405EA10F96B1DB4B40056D72F8A4C74A405EA10F96B1DB4B40056D72F8A4C74A4018B2BAD573DA4B404B57B08D78C44A4018B2BAD573DA4B40
28287	Щербень	7	64	1802	50.586855999999997	50.613922000000002	54.833469000000001	54.818927000000002	0103000020E610000001000000050000000EBBEF181E4B4940DC679599D2684B400EBBEF181E4B49406B9DB81CAF6A4B40C02500FF944E49406B9DB81CAF6A4B40C02500FF944E4940DC679599D2684B400EBBEF181E4B4940DC679599D2684B40
27025	Чувашское Енорускино	7	64	1802	50.941304000000002	50.976652999999999	54.918456999999997	54.900368	0103000020E6100000010000000500000008CC43A67C784940B62E35423F734B4008CC43A67C78494021E4BCFF8F754B4028452BF7027D494021E4BCFF8F754B4028452BF7027D4940B62E35423F734B4008CC43A67C784940B62E35423F734B40
61487	Чувашский Адам	7	64	1802	50.534978000000002	50.548560000000002	54.952258	54.932316999999998	0103000020E610000001000000050000002D0ABB287A4449409E40D82956774B402D0ABB287A4449405CAD1397E3794B4067F2CD36374649405CAD1397E3794B4067F2CD36374649409E40D82956774B402D0ABB287A4449409E40D82956774B40
26842	Урмандеево	7	64	1802	50.804490000000001	50.825780000000002	55.012047000000003	55.000197999999997	0103000020E61000000100000005000000C2FA3F87F966494026C3F17C06804B40C2FA3F87F9664940E9818FC18A814B406FD8B628B3694940E9818FC18A814B406FD8B628B369494026C3F17C06804B40C2FA3F87F966494026C3F17C06804B40
27951	Трудолюбово	7	64	1802	50.559978000000001	50.588248	54.761445999999999	54.746898000000002	0103000020E61000000100000005000000603DEE5BAD47494052B9895A9A5F4B40603DEE5BAD474940C3D5011077614B40FDF7E0B54B4B4940C3D5011077614B40FDF7E0B54B4B494052B9895A9A5F4B40603DEE5BAD47494052B9895A9A5F4B40
28651	Тахтала	7	64	1802	50.629975000000002	50.655900000000003	54.987937000000002	54.969253999999999	0103000020E6100000010000000500000018265305A350494033C2DB83107C4B4018265305A350494012C138B8747E4B4024B9FC87F453494012C138B8747E4B4024B9FC87F453494033C2DB83107C4B4018265305A350494033C2DB83107C4B40
27769	Татарское Сунчелеево	7	64	1802	50.717264	50.740566000000001	54.722087000000002	54.712935000000002	0103000020E61000000100000005000000904C874ECF5B49403E963E74415B4B40904C874ECF5B4940F2EEC8586D5C4B40C843DFDDCA5E4940F2EEC8586D5C4B40C843DFDDCA5E49403E963E74415B4B40904C874ECF5B49403E963E74415B4B40
27024	Тарханка	7	64	1802	50.850465999999997	50.864561000000002	54.956518000000003	54.946364000000003	0103000020E61000000100000005000000122EE411DC6C49404E0E9F7422794B40122EE411DC6C494086048C2E6F7A4B40D33252EFA96E494086048C2E6F7A4B40D33252EFA96E49404E0E9F7422794B40122EE411DC6C49404E0E9F7422794B40
27843	Сунчелеево	7	64	1802	50.670650000000002	50.691113999999999	54.705984999999998	54.688389000000001	0103000020E61000000100000005000000FD87F4DBD75549408CF678211D584B40FD87F4DBD7554940B83B6BB75D5A4B4064E76D6C76584940B83B6BB75D5A4B4064E76D6C765849408CF678211D584B40FD87F4DBD75549408CF678211D584B40
28513	Старый Татарский Адам	7	64	1802	50.586953999999999	50.613832000000002	55.022478999999997	55.005940000000002	0103000020E61000000100000005000000D120054F214B49407FDE54A4C2804B40D120054F214B494063EC8497E0824B40809E060C924E494063EC8497E0824B40809E060C924E49407FDE54A4C2804B40D120054F214B49407FDE54A4C2804B40
26835	Старые Савруши	7	64	1802	50.708145999999999	50.744115000000001	55.005386999999999	54.991981000000003	0103000020E6100000010000000500000088653387A45A49406FA0C03BF97E4B4088653387A45A49406A696E85B0804B4045BB0A293F5F49406A696E85B0804B4045BB0A293F5F49406FA0C03BF97E4B4088653387A45A49406FA0C03BF97E4B40
28655	Старые Киязлы	7	64	1802	51.060968000000003	51.084629999999997	54.747408	54.727696999999999	0103000020E61000000100000005000000200DA7CCCD874940DB32E02C255D4B40200DA7CCCD8749406762BA10AB5F4B405721E527D58A49406762BA10AB5F4B405721E527D58A4940DB32E02C255D4B40200DA7CCCD874940DB32E02C255D4B40
27572	Старое Узеево	7	64	1802	50.880721000000001	50.905909999999999	54.706192999999999	54.690964999999998	0103000020E6100000010000000500000041F33977BB7049401FD7868A71584B4041F33977BB70494002D53F88645A4B40478FDFDBF473494002D53F88645A4B40478FDFDBF47349401FD7868A71584B4041F33977BB7049401FD7868A71584B40
27281	Старое Тимошкино	7	64	1802	50.975026999999997	51.013590999999998	54.749766999999999	54.720584000000002	0103000020E61000000100000005000000C6DB4AAFCD7C4940AC02B5183C5C4B40C6DB4AAFCD7C49405D4F745DF85F4B408D429259BD8149405D4F745DF85F4B408D429259BD814940AC02B5183C5C4B40C6DB4AAFCD7C4940AC02B5183C5C4B40
27672	Старое Мокшино	7	64	1802	50.789866000000004	50.826185000000002	54.716008000000002	54.703040999999999	0103000020E61000000100000005000000761C3F541A654940A25F5B3FFD594B40761C3F541A65494052D66F26A65B4B400FB9196EC069494052D66F26A65B4B400FB9196EC0694940A25F5B3FFD594B40761C3F541A654940A25F5B3FFD594B40
26944	Старое Ильдеряково	7	64	1802	50.855362	50.888474000000002	54.901062000000003	54.883648999999998	0103000020E61000000100000005000000DE1E84807C6D4940511212691B714B40DE1E84807C6D49408DD5E6FF55734B4054AC1A84B97149408DD5E6FF55734B4054AC1A84B9714940511212691B714B40DE1E84807C6D4940511212691B714B40
27105	Старое Ибрайкино	7	64	1802	51.009126999999999	51.056046000000002	54.872523000000001	54.848959999999998	0103000020E610000001000000050000005B41D3122B8149405BCEA5B8AA6C4B405B41D3122B81494000016BD5AE6F4B402B89EC832C87494000016BD5AE6F4B402B89EC832C8749405BCEA5B8AA6C4B405B41D3122B8149405BCEA5B8AA6C4B40
26750	Старая Киреметь	7	64	1802	50.763285000000003	50.796315999999997	54.922519000000001	54.904519999999998	0103000020E610000001000000050000008143A852B3614940F949B54FC7734B408143A852B36149402578431A15764B4009A4C4AEED6549402578431A15764B4009A4C4AEED654940F949B54FC7734B408143A852B3614940F949B54FC7734B40
61441	Сосновка	7	64	1802	50.571440000000003	50.594535999999998	54.921152999999997	54.910017000000003	0103000020E6100000010000000500000029D027F224494940EBE6E26F7B744B4029D027F2244949405FCE6C57E8754B40B72572C1194C49405FCE6C57E8754B40B72572C1194C4940EBE6E26F7B744B4029D027F224494940EBE6E26F7B744B40
26891	Савгачево	7	64	1802	50.754390999999998	50.787252000000002	55.004038999999999	54.993133	0103000020E61000000100000005000000C8B260E28F60494008CA6DFB1E7F4B40C8B260E28F6049404B74965984804B40F5DA6CACC46449404B74965984804B40F5DA6CACC464494008CA6DFB1E7F4B40C8B260E28F60494008CA6DFB1E7F4B40
28243	Русская Киреметь	7	64	1802	50.677711000000002	50.733424999999997	54.900202999999998	54.876246999999999	0103000020E61000000100000005000000DA91EA3BBF564940EB1B98DC28704B40DA91EA3BBF5649406B6116DA39734B40CE88D2DEE05D49406B6116DA39734B40CE88D2DEE05D4940EB1B98DC28704B40DA91EA3BBF564940EB1B98DC28704B40
27715	Пионер	7	64	1802	50.713616999999999	50.731591999999999	54.672513000000002	54.663108999999999	0103000020E61000000100000005000000506F46CD575B4940755776C1E0544B40506F46CD575B49404391EEE714564B40F30181CEA45D49404391EEE714564B40F30181CEA45D4940755776C1E0544B40506F46CD575B4940755776C1E0544B40
27988	Октябрь	7	64	1802	50.605235	50.616706999999998	54.714348999999999	54.710572999999997	0103000020E6100000010000000500000081B22957784D4940D6355A0EF45A4B4081B22957784D49401477BCC96F5B4B406D1B4641F04E49401477BCC96F5B4B406D1B4641F04E4940D6355A0EF45A4B4081B22957784D4940D6355A0EF45A4B40
28373	Новый Чувашский Адам	7	64	1802	50.567075000000003	50.583450999999997	54.991045999999997	54.976317999999999	0103000020E610000001000000050000008AB0E1E995484940813FFCFCF77C4B408AB0E1E995484940726A6798DA7E4B40C4E8B985AE4A4940726A6798DA7E4B40C4E8B985AE4A4940813FFCFCF77C4B408AB0E1E995484940813FFCFCF77C4B40
27386	Новое Узеево	7	64	1802	50.907508999999997	50.935715999999999	54.717604999999999	54.701245999999998	0103000020E61000000100000005000000AFE9414129744940B439CE6DC2594B40AFE941412974494019390B7BDA5B4B40062CB98AC577494019390B7BDA5B4B40062CB98AC5774940B439CE6DC2594B40AFE9414129744940B439CE6DC2594B40
27372	Новое Тимошкино	7	64	1802	50.976759999999999	51.011166000000003	54.790480000000002	54.767108	0103000020E610000001000000050000003E05C078067D4940FF3F4E9830624B403E05C078067D49403012DA722E654B40E06932E36D8149403012DA722E654B40E06932E36D814940FF3F4E9830624B403E05C078067D4940FF3F4E9830624B40
27579	Новое Мокшино	7	64	1802	50.856744999999997	50.876795999999999	54.746160000000003	54.72607	0103000020E610000001000000050000007901F6D1A96D4940A94D9CDCEF5C4B407901F6D1A96D4940ACCABE2B825F4B40BEA1F0D93A704940ACCABE2B825F4B40BEA1F0D93A704940A94D9CDCEF5C4B407901F6D1A96D4940A94D9CDCEF5C4B40
26662	Новое Ильдеряково	7	64	1802	50.892319000000001	50.911920000000002	54.908152999999999	54.892125999999998	0103000020E61000000100000005000000BA4C4D8237724940A5F44C2F31724B40BA4C4D8237724940D461855B3E744B40BF4868CBB9744940D461855B3E744B40BF4868CBB9744940A5F44C2F31724B40BA4C4D8237724940A5F44C2F31724B40
27115	Новое Ибрайкино	7	64	1802	51.147520999999998	51.193587000000001	54.877370999999997	54.857652000000002	0103000020E61000000100000005000000923CD7F7E1924940ACAC6D8AC76D4B40923CD7F7E1924940BABA63B14D704B4023F77475C7984940BABA63B14D704B4023F77475C7984940ACAC6D8AC76D4B40923CD7F7E1924940ACAC6D8AC76D4B40
28189	Новое Демкино	7	64	1802	50.688859000000001	50.713383	54.817360000000001	54.803682999999999	0103000020E6100000010000000500000013471E882C584940F3ACA415DF664B4013471E882C5849407F87A2409F684B40DD425722505B49407F87A2409F684B40DD425722505B4940F3ACA415DF664B4013471E882C584940F3ACA415DF664B40
27153	Новое Аксубаево	7	64	1802	50.879212000000003	50.911920000000002	54.843279000000003	54.831389999999999	0103000020E610000001000000050000001920D1048A704940581CCEFC6A6A4B401920D1048A704940A933F790F06B4B40BF4868CBB9744940A933F790F06B4B40BF4868CBB9744940581CCEFC6A6A4B401920D1048A704940581CCEFC6A6A4B40
28201	Новая Киреметь	7	64	1802	50.694932000000001	50.719869000000003	54.855801999999997	54.841413000000003	0103000020E61000000100000005000000D1782288F3584940F2B6D26BB36B4B40D1782288F3584940FAEC80EB8A6D4B40BE33DAAA245C4940FAEC80EB8A6D4B40BE33DAAA245C4940F2B6D26BB36B4B40D1782288F3584940F2B6D26BB36B4B40
28569	Нижняя Татарская Майна	7	64	1802	50.510032000000002	50.529426000000001	55.043886000000001	55.029336999999998	0103000020E61000000100000005000000EDF483BA4841494008C89750C1834B40EDF483BA484149404A60730E9E854B4078D32D3BC44349404A60730E9E854B4078D32D3BC443494008C89750C1834B40EDF483BA4841494008C89750C1834B40
28108	Нижняя Баланда	7	64	1802	50.741249000000003	50.764291	54.797497	54.779541000000002	0103000020E61000000100000005000000AB984A3FE15E49401172DEFFC7634B40AB984A3FE15E49403DD4B66114664B4046D09849D46149403DD4B66114664B4046D09849D46149401172DEFFC7634B40AB984A3FE15E49401172DEFFC7634B40
26756	Нижние Савруши	7	64	1802	50.671143999999998	50.688653000000002	55.044288999999999	55.035493000000002	0103000020E610000001000000050000000C74ED0BE8554940541EDD088B844B400C74ED0BE855494049490F43AB854B406AA510C82558494049490F43AB854B406AA510C825584940541EDD088B844B400C74ED0BE8554940541EDD088B844B40
27656	Мюд	7	64	1802	50.763787999999998	50.796028	54.716611	54.703446999999997	0103000020E61000000100000005000000E38920CEC361494012BC218D0A5A4B40E38920CEC3614940187AC4E8B95B4B40A359D93EE4654940187AC4E8B95B4B40A359D93EE465494012BC218D0A5A4B40E38920CEC361494012BC218D0A5A4B40
27851	Малое Сунчелеево	7	64	1802	50.642138000000003	50.655172	54.661406999999997	54.650620000000004	0103000020E610000001000000050000006AC2F69331524940D00F238447534B406AC2F69331524940382C0DFCA8544B40A1A014ADDC534940382C0DFCA8544B40A1A014ADDC534940D00F238447534B406AC2F69331524940D00F238447534B40
27206	Малое Аксубаево	7	64	1802	50.903816999999997	50.913536999999998	54.816130999999999	54.807144000000001	0103000020E61000000100000005000000CF488446B0734940D1949D7E50674B40CF488446B07349403A2009FB76684B40CD57C9C7EE7449403A2009FB76684B40CD57C9C7EE744940D1949D7E50674B40CF488446B0734940D1949D7E50674B40
28102	Кривоозерки	7	64	1802	50.714703999999998	50.747681	54.777603999999997	54.758209999999998	0103000020E610000001000000050000000229B16B7B5B494005C078060D614B400229B16B7B5B4940909E228788634B40986BD102B45F4940909E228788634B40986BD102B45F494005C078060D614B400229B16B7B5B494005C078060D614B40
27280	Кисы	7	64	1802	50.853853000000001	50.876221000000001	54.861544000000002	54.849671000000001	0103000020E61000000100000005000000B64B1B0E4B6D494008AEF204C26C4B40B64B1B0E4B6D49405308E412476E4B40C2887D02287049405308E412476E4B40C2887D022870494008AEF204C26C4B40B64B1B0E4B6D494008AEF204C26C4B40
28742	Кзыл-Тау	7	64	1802	51.063493000000001	51.079725000000003	54.768807000000002	54.757497999999998	0103000020E610000001000000050000003143E389208849408864C8B1F5604B403143E38920884940CBF78C4468624B4039D6C56D348A4940CBF78C4468624B4039D6C56D348A49408864C8B1F5604B403143E389208849408864C8B1F5604B40
27938	Караса	7	64	1802	50.668062999999997	50.692273	54.749116999999998	54.728087000000002	0103000020E610000001000000050000007555A0168355494046D26EF4315D4B407555A0168355494056F0DB10E35F4B40B073D3669C58494056F0DB10E35F4B40B073D3669C58494046D26EF4315D4B407555A0168355494046D26EF4315D4B40
28377	Емелькино	7	64	1802	50.550618	50.566867999999999	54.976678999999997	54.966085999999997	0103000020E61000000100000005000000624B8FA67A464940CD8FBFB4A87B4B40624B8FA67A46494051D845D1037D4B40109370218F48494051D845D1037D4B40109370218F484940CD8FBFB4A87B4B40624B8FA67A464940CD8FBFB4A87B4B40
27430	Беловка	7	64	1802	50.943207999999998	50.974874	54.718015999999999	54.705975000000002	0103000020E61000000100000005000000ACA92C0ABB784940956588635D5A4B40ACA92C0ABB7849409B00C3F2E75B4B4040DCD5ABC87C49409B00C3F2E75B4B4040DCD5ABC87C4940956588635D5A4B40ACA92C0ABB784940956588635D5A4B40
27484	Алексеевка	7	64	1802	50.964785999999997	50.987198999999997	54.678925999999997	54.667489000000003	0103000020E61000000100000005000000BFD18E1B7E7B49404AB8904770554B40BFD18E1B7E7B4940B933130CE7564B406BD26D895C7E4940B933130CE7564B406BD26D895C7E49404AB8904770554B40BFD18E1B7E7B49404AB8904770554B40
26496	Аксубаево	7	64	1802	50.778869999999998	50.851095000000001	54.874527	54.825643999999997	0103000020E61000000100000005000000F2EA1C03B2634940BE11DDB3AE694B40F2EA1C03B2634940083C3080F06F4B40026553AEF06C4940083C3080F06F4B40026553AEF06C4940BE11DDB3AE694B40F2EA1C03B2634940BE11DDB3AE694B40
26367	Чубар-Абдуллово	7	64	1309	52.892533999999998	52.908757999999999	55.097588999999999	55.079889999999999	0103000020E61000000100000005000000B648DA8D3E724A4083A3E4D5398A4B40B648DA8D3E724A4084B9DDCB7D8C4B403BFDA02E52744A4084B9DDCB7D8C4B403BFDA02E52744A4083A3E4D5398A4B40B648DA8D3E724A4083A3E4D5398A4B40
24724	Чемодурово	7	64	1309	52.845498999999997	52.871828000000001	54.770192999999999	54.760458999999997	0103000020E610000001000000050000007DE6AC4F396C4A40747973B856614B407DE6AC4F396C4A40D74D29AF95624B4059DE550F986F4A40D74D29AF95624B4059DE550F986F4A40747973B856614B407DE6AC4F396C4A40747973B856614B40
61403	Чекан	7	64	1309	52.685572000000001	53.650452000000001	55.191299999999998	54.650396000000001	0103000020E61000000100000005000000D386C3D2C0574A4080B9162D40534B40D386C3D2C0574A40C6DCB5847C984B4014CFD90242D34A40C6DCB5847C984B4014CFD90242D34A4080B9162D40534B40D386C3D2C0574A4080B9162D40534B40
26149	Чалпы	7	64	1309	53.049227999999999	53.098939999999999	55.102801999999997	55.071148999999998	0103000020E610000001000000050000001406651A4D864A40511212691B894B401406651A4D864A4050FBAD9D288D4B401422E010AA8C4A4050FBAD9D288D4B401422E010AA8C4A40511212691B894B401406651A4D864A40511212691B894B40
25934	Учалле	7	64	1309	53.291412999999999	53.317635000000003	54.918818999999999	54.904297	0103000020E610000001000000050000008B506C054DA54A407A6F0C01C0734B408B506C054DA54A40C2F869DC9B754B4051888043A8A84A40C2F869DC9B754B4051888043A8A84A407A6F0C01C0734B408B506C054DA54A407A6F0C01C0734B40
26029	Урсаево	7	64	1309	53.210996000000002	53.249318000000002	55.095605999999997	55.069566000000002	0103000020E610000001000000050000001DCBBBEA019B4A40EF74E789E7884B401DCBBBEA019B4A4093A641D13C8C4B40EE26F8A6E99F4A4093A641D13C8C4B40EE26F8A6E99F4A40EF74E789E7884B401DCBBBEA019B4A40EF74E789E7884B40
25551	Урманаево	7	64	1309	53.340389999999999	53.368659999999998	54.847073999999999	54.824969000000003	0103000020E6100000010000000500000056F146E691AB4A405F9B8D9598694B4056F146E691AB4A405DA5BBEB6C6C4B40F3AB394030AF4A405DA5BBEB6C6C4B40F3AB394030AF4A405F9B8D9598694B4056F146E691AB4A405F9B8D9598694B40
25161	Уразаево	7	64	1309	53.148716	53.187918000000003	54.878169	54.863424999999999	0103000020E610000001000000050000002B323A2009934A403FC6DCB5846E4B402B323A2009934A4036AE7FD767704B40352A70B20D984A4036AE7FD767704B40352A70B20D984A403FC6DCB5846E4B402B323A2009934A403FC6DCB5846E4B40
26026	Тумутук	7	64	1309	53.282519999999998	53.320383999999997	55.030720000000002	55.006301000000001	0103000020E61000000100000005000000A33B889D29A44A404F779E78CE804B40A33B889D29A44A40A4AA09A2EE834B40B114C95702A94A40A4AA09A2EE834B40B114C95702A94A404F779E78CE804B40A33B889D29A44A404F779E78CE804B40
26227	Татарский Шуган	7	64	1309	53.016232000000002	53.062854999999999	55.154722999999997	55.138120000000001	0103000020E610000001000000050000000893E2E313824A40367689EAAD914B400893E2E313824A40317898F6CD934B40EEB1F4A10B884A40317898F6CD934B40EEB1F4A10B884A40367689EAAD914B400893E2E313824A40367689EAAD914B40
25457	Таллы-Буляк	7	64	1309	53.250746999999997	53.261229999999998	54.747044000000002	54.740220000000001	0103000020E61000000100000005000000F9484A7A18A04A402DEC6987BF5E4B40F9484A7A18A04A40265646239F5F4B40F65D11FC6FA14A40265646239F5F4B40F65D11FC6FA14A402DEC6987BF5E4B40F9484A7A18A04A402DEC6987BF5E4B40
61500	Тайкино	7	64	1309	53.069934000000003	53.096632	54.816079000000002	54.804737000000003	0103000020E610000001000000050000007270E998F3884A40CA703C9F01674B407270E998F3884A40E8F9D34675684B40A0DFF76F5E8C4A40E8F9D34675684B40A0DFF76F5E8C4A40CA703C9F01674B407270E998F3884A40CA703C9F01674B40
25799	Сарлы	7	64	1309	53.436985	53.483240000000002	54.968736999999997	54.948979999999999	0103000020E61000000100000005000000D9EBDD1FEFB74A406F47382D78794B40D9EBDD1FEFB74A406BB6F292FF7B4B403D0FEECEDABD4A406BB6F292FF7B4B403D0FEECEDABD4A406F47382D78794B40D9EBDD1FEFB74A406F47382D78794B40
25252	Сапеево	7	64	1309	53.121065999999999	53.142994000000002	54.908909000000001	54.899037999999997	0103000020E610000001000000050000002A5437177F8F4A403DEE5BAD13734B402A5437177F8F4A4021054F2157744B401AC39CA04D924A4021054F2157744B401AC39CA04D924A403DEE5BAD13734B402A5437177F8F4A403DEE5BAD13734B40
25606	Победа	7	64	1309	53.391333000000003	53.410125999999998	54.872838999999999	54.859414000000001	0103000020E610000001000000050000003C6C223317B24A40BEDC2747016E4B403C6C223317B24A4030D63730B96F4B40A19E3E027FB44A4030D63730B96F4B40A19E3E027FB44A40BEDC2747016E4B403C6C223317B24A40BEDC2747016E4B40
52144	Первое Мая	7	64	1309	53.315891999999998	53.338180000000001	54.765675000000002	54.755772999999998	0103000020E61000000100000005000000B58828266FA84A4093196F2BBD604B40B58828266FA84A40B22E6EA301624B40A514747B49AB4A40B22E6EA301624B40A514747B49AB4A4093196F2BBD604B40B58828266FA84A4093196F2BBD604B40
61411	Мяняус	7	64	1309	53.020561999999998	53.036166000000001	54.889884000000002	54.873207000000001	0103000020E610000001000000050000002AC58EC6A1824A40B3D1393FC56F4B402AC58EC6A1824A40E99D0AB8E7714B40139D6516A1844A40E99D0AB8E7714B40139D6516A1844A40B3D1393FC56F4B402AC58EC6A1824A40B3D1393FC56F4B40
26277	Мяндей	7	64	1309	52.877541999999998	52.894744000000003	55.133045000000003	55.117592000000002	0103000020E61000000100000005000000E76ED74B53704A40B82231410D8F4B40E76ED74B53704A40BBF2599E07914B406825ADF886724A40BBF2599E07914B406825ADF886724A40B82231410D8F4B40E76ED74B53704A40B82231410D8F4B40
26074	Муслюмово	7	64	1309	53.150098999999997	53.174453	55.045484999999999	55.034739999999999	0103000020E61000000100000005000000C614AC7136934A4078EE3D5C72844B40C614AC7136934A40B2BAD573D2854B4034D8D47954964A40B2BAD573D2854B4034D8D47954964A4078EE3D5C72844B40C614AC7136934A4078EE3D5C72844B40
25365	Митряево	7	64	1309	53.279178000000002	53.317087000000001	54.827438000000001	54.813220000000001	0103000020E61000000100000005000000A0E1CD1ABCA34A40003ACC9717684B40A0E1CD1ABCA34A40DCBB067DE9694B404E7E8B4E96A84A40DCBB067DE9694B404E7E8B4E96A84A40003ACC9717684B40A0E1CD1ABCA34A40003ACC9717684B40
24421	Микулино	7	64	1309	52.738185999999999	52.748641999999997	54.740006999999999	54.711638999999998	0103000020E61000000100000005000000BA2EFCE07C5E4A4071C79BFC165B4B40BA2EFCE07C5E4A40D1E7A38CB85E4B40BD344580D35F4A40D1E7A38CB85E4B40BD344580D35F4A4071C79BFC165B4B40BA2EFCE07C5E4A4071C79BFC165B4B40
24838	Масягутово	7	64	1309	52.883417000000001	52.912216999999998	55.004344000000003	54.991830999999998	0103000020E610000001000000050000007FDDE9CE13714A4059147651F47E4B407FDDE9CE13714A4088F71C588E804B4078EDD286C3744A4088F71C588E804B4078EDD286C3744A4059147651F47E4B407FDDE9CE13714A4059147651F47E4B40
24734	Мальбагуш	7	64	1309	52.804822999999999	52.830334999999998	54.893445999999997	54.878179000000003	0103000020E61000000100000005000000C808A87004674A405A84622B68704B40C808A87004674A40FA5E43705C724B40B1DCD26A486A4A40FA5E43705C724B40B1DCD26A486A4A405A84622B68704B40C808A87004674A405A84622B68704B40
25938	Кук-Тяка	7	64	1309	53.375028999999998	53.399740999999999	55.013765999999997	54.993665	0103000020E610000001000000050000009A0645F300B04A4005172B6A307F4B409A0645F300B04A40FBE59315C3814B4067EF8CB62AB34A40FBE59315C3814B4067EF8CB62AB34A4005172B6A307F4B409A0645F300B04A4005172B6A307F4B40
25454	Карамалы	7	64	1309	53.172144000000003	53.201636000000001	54.793053999999998	54.778309999999998	0103000020E61000000100000005000000F01989D008964A402B137EA99F634B40F01989D008964A4022FB20CB82654B401FD95C35CF994A4022FB20CB82654B401FD95C35CF994A402B137EA99F634B40F01989D008964A402B137EA99F634B40
24917	Какре-Елга	7	64	1309	52.903843999999999	52.93524	54.955091000000003	54.936439999999997	0103000020E61000000100000005000000C9570229B1734A4047551344DD774B40C9570229B1734A401BDA006C407A4B409DF4BEF1B5774A401BDA006C407A4B409DF4BEF1B5774A4047551344DD774B40C9570229B1734A4047551344DD774B40
26143	Ирекле	7	64	1309	52.912010000000002	53.032735000000002	55.045284000000002	55.013849	0103000020E61000000100000005000000FFCF61BEBC744A40890AD5CDC5814B40FFCF61BEBC744A401B84B9DDCB854B40A03715A930844A401B84B9DDCB854B40A03715A930844A40890AD5CDC5814B40FFCF61BEBC744A40890AD5CDC5814B40
24911	Ильбяково	7	64	1309	52.847529000000002	52.869734999999999	55.039161	55.028238000000002	0103000020E61000000100000005000000AFB48CD47B6C4A409240834D9D834B40AFB48CD47B6C4A40AB23473A03854B40E197FA79536F4A40AB23473A03854B40E197FA79536F4A409240834D9D834B40AFB48CD47B6C4A409240834D9D834B40
25750	Верхнее Стярле	7	64	1309	53.451394000000001	53.477435999999997	54.912159000000003	54.894917	0103000020E6100000010000000500000029CE5147C7B94A4035D1E7A38C724B4029CE5147C7B94A4044E048A0C1744B406EF7729F1CBD4A4044E048A0C1744B406EF7729F1CBD4A4035D1E7A38C724B4029CE5147C7B94A4035D1E7A38C724B40
26422	Буралы	7	64	1309	52.825367	52.859808999999998	55.083410000000001	55.070974	0103000020E610000001000000050000004C1938A0A5694A40E36E10AD15894B404C1938A0A5694A406614CB2DAD8A4B403AE7A7380E6E4A406614CB2DAD8A4B403AE7A7380E6E4A40E36E10AD15894B404C1938A0A5694A40E36E10AD15894B40
25882	Буляк	7	64	1309	53.412264	53.435377000000003	54.988835000000002	54.975005000000003	0103000020E61000000100000005000000B9A81611C5B44A40DF37BEF6CC7C4B40B9A81611C5B44A40F1113125927E4B401E37FC6EBAB74A40F1113125927E4B401E37FC6EBAB74A40DF37BEF6CC7C4B40B9A81611C5B44A40DF37BEF6CC7C4B40
25264	Большой Сухояш	7	64	1309	53.133004	53.157322000000001	54.998756999999998	54.984419000000003	0103000020E610000001000000050000005C1E6B4606914A40D0471971017E4B405C1E6B4606914A4056D3F544D77F4B407D78962023944A4056D3F544D77F4B407D78962023944A40D0471971017E4B405C1E6B4606914A40D0471971017E4B40
24635	Бирючевка	7	64	1309	52.794654000000001	52.806027	54.697161999999999	54.689605999999998	0103000020E610000001000000050000005BD1E638B7654A400C90680245584B405BD1E638B7654A40C901BB9A3C594B40B4588AE42B674A40C901BB9A3C594B40B4588AE42B674A400C90680245584B405BD1E638B7654A400C90680245584B40
13816	Балтачево	7	64	1309	53.015891000000003	53.057608999999999	54.798031999999999	54.775801999999999	0103000020E610000001000000050000007FA65EB708824A40F015DD7A4D634B407FA65EB708824A40AB949EE925664B40467A51BB5F874A40AB949EE925664B40467A51BB5F874A40F015DD7A4D634B407FA65EB708824A40F015DD7A4D634B40
26188	Балан-Буляк	7	64	1309	52.975960999999998	52.992956999999997	55.093699999999998	55.084363000000003	0103000020E61000000100000005000000F295404AEC7C4A4009FF2268CC8A4B40F295404AEC7C4A404ED1915CFE8B4B40C9AA0837197F4A404ED1915CFE8B4B40C9AA0837197F4A4009FF2268CC8A4B40F295404AEC7C4A4009FF2268CC8A4B40
25310	Асеево	7	64	1309	53.230786000000002	53.253900000000002	54.844543999999999	54.827494999999999	0103000020E61000000100000005000000F52F49658A9D4A40404D2D5BEB694B40F52F49658A9D4A403A048E041A6C4B402A3A92CB7FA04A403A048E041A6C4B402A3A92CB7FA04A40404D2D5BEB694B40F52F49658A9D4A40404D2D5BEB694B40
24786	Алькеево	7	64	1309	52.770533999999998	52.806412999999999	54.939869000000002	54.927495999999998	0103000020E61000000100000005000000603AADDBA0624A40DD955D30B8764B40603AADDBA0624A401AC39CA04D784B40DD088B8A38674A401AC39CA04D784B40DD088B8A38674A40DD955D30B8764B40603AADDBA0624A40DD955D30B8764B40
24436	Актюбинский	7	64	1309	52.766043000000003	52.831933999999997	54.822702999999997	54.805748999999999	0103000020E61000000100000005000000352A70B20D624A4071E481C822674B40352A70B20D624A4019A9F7544E694B40193735D07C6A4A4019A9F7544E694B40193735D07C6A4A4071E481C822674B40352A70B20D624A4071E481C822674B40
24993	Агерзе	7	64	1309	52.993146000000003	53.012801000000003	54.837363000000003	54.823340999999999	0103000020E610000001000000050000009D137B681F7F4A405C3AE63C63694B409D137B681F7F4A40B3F0F5B52E6B4B40952D9276A3814A40B3F0F5B52E6B4B40952D9276A3814A405C3AE63C63694B409D137B681F7F4A405C3AE63C63694B40
22214	Янга-Аул	7	64	1646	52.807975999999996	52.843378999999999	56.219723000000002	56.208253999999997	0103000020E61000000100000005000000F8F9EFC16B674A406EA12B11A81A4C40F8F9EFC16B674A40EA961DE21F1C4C400C91D3D7F36B4A40EA961DE21F1C4C400C91D3D7F36B4A406EA12B11A81A4C40F8F9EFC16B674A406EA12B11A81A4C40
22780	Ямурзино	7	64	1646	53.003261000000002	53.024864999999998	56.011681000000003	55.998840999999999	0103000020E61000000100000005000000172D40DB6A804A40B4739A05DAFF4B40172D40DB6A804A40077E54C37E014C4053E8BCC62E834A40077E54C37E014C4053E8BCC62E834A40B4739A05DAFF4B40172D40DB6A804A40B4739A05DAFF4B40
22659	Шаршада	7	64	1646	53.008166000000003	53.033309000000003	56.105541000000002	56.093550999999998	0103000020E6100000010000000500000036785F950B814A4009C1AA7AF90B4C4036785F950B814A408EB1135E820D4C40CCD4247843844A408EB1135E820D4C40CCD4247843844A4009C1AA7AF90B4C4036785F950B814A4009C1AA7AF90B4C40
23379	Утяганово	7	64	1646	53.516226000000003	53.535836000000003	56.165303000000002	56.152780999999997	0103000020E6100000010000000500000026AC8DB113C24A409F39EB538E134C4026AC8DB113C24A40217711A628154C407E02284696C44A40217711A628154C407E02284696C44A409F39EB538E134C4026AC8DB113C24A409F39EB538E134C40
22831	Уразаево	7	64	1646	52.940261999999997	52.961381000000003	56.010649000000001	56.000784000000003	0103000020E61000000100000005000000F5D555815A784A40172EABB019004C40F5D555815A784A40185E49F25C014C4076FF58880E7B4A40185E49F25C014C4076FF58880E7B4A40172EABB019004C40F5D555815A784A40172EABB019004C40
21918	Терси	7	64	1646	52.866672000000001	52.913437999999999	56.342669999999998	56.319105	0103000020E61000000100000005000000F12DAC1BEF6E4A40BB7EC16ED8284C40F12DAC1BEF6E4A4000A94D9CDC2B4C403A765089EB744A4000A94D9CDC2B4C403A765089EB744A40BB7EC16ED8284C40F12DAC1BEF6E4A40BB7EC16ED8284C40
22119	Табарле	7	64	1646	52.672249999999998	52.693899000000002	56.287196999999999	56.274628999999997	0103000020E61000000100000005000000355EBA490C564A403FC4060B27234C40355EBA490C564A4031410DDFC2244C4012DDB3AED1584A4031410DDFC2244C4012DDB3AED1584A403FC4060B27234C40355EBA490C564A403FC4060B27234C40
22201	Сукман	7	64	1646	52.588220999999997	52.608235999999998	56.254237000000003	56.242899000000001	0103000020E6100000010000000500000003E962D34A4B4A40959D7E50171F4C4003E962D34A4B4A40723788D68A204C40FB1F60ADDA4D4A40723788D68A204C40FB1F60ADDA4D4A40959D7E50171F4C4003E962D34A4B4A40959D7E50171F4C40
23320	Старое Сляково	7	64	1646	53.504009000000003	53.516190000000002	56.187570999999998	56.169257999999999	0103000020E61000000100000005000000E1F1ED5D83C04A400E4B033FAA154C40E1F1ED5D83C04A40C956975302184C40D942908312C24A40C956975302184C40D942908312C24A400E4B033FAA154C40E1F1ED5D83C04A400E4B033FAA154C40
22741	Старая Чекалда	7	64	1646	53.132860999999998	53.154581999999998	56.088006	56.064704999999996	0103000020E61000000100000005000000F9F4D89601914A409F71E14048084C40F9F4D89601914A4007EDD5C7430B4C406F46CD57C9934A4007EDD5C7430B4C406F46CD57C9934A409F71E14048084C40F9F4D89601914A409F71E14048084C40
23450	Сосново	7	64	1646	53.444684000000002	53.464267	56.225352999999998	56.219608000000001	0103000020E61000000100000005000000F986C267EBB84A4051F86C1D1C1C4C40F986C267EBB84A401A87FA5DD81C4C4057CEDE196DBB4A401A87FA5DD81C4C4057CEDE196DBB4A4051F86C1D1C1C4C40F986C267EBB84A4051F86C1D1C1C4C40
21968	Сарсак-Омга	7	64	1646	52.805461000000001	52.840747	56.317942000000002	56.304181	0103000020E610000001000000050000000B9A965819674A4044882B67EF264C400B9A965819674A402E03CE52B2284C40E59A02999D6B4A402E03CE52B2284C40E59A02999D6B4A4044882B67EF264C400B9A965819674A4044882B67EF264C40
61387	Салауш	7	64	1646	52.868630000000003	52.903143999999998	55.999259000000002	55.987915999999998	0103000020E61000000100000005000000892991442F6F4A40FA980F0874FE4B40892991442F6F4A40E99D0AB8E7FF4B4010CAFB389A734A40E99D0AB8E7FF4B4010CAFB389A734A40FA980F0874FE4B40892991442F6F4A40FA980F0874FE4B40
23106	Пелемеш	7	64	1646	53.280005000000003	53.304896999999997	56.031140999999998	56.021115000000002	0103000020E61000000100000005000000B6DB2E34D7A34A403F3A75E5B3024C40B6DB2E34D7A34A404948A46DFC034C4002D369DD06A74A404948A46DFC034C4002D369DD06A74A403F3A75E5B3024C40B6DB2E34D7A34A403F3A75E5B3024C40
22117	Новое Аккузино	7	64	1646	52.729624999999999	52.754534999999997	56.276499000000001	56.257998000000001	0103000020E6100000010000000500000008AC1C5A645D4A407A37161406214C4008AC1C5A645D4A403830B95164234C40FB57569A94604A403830B95164234C40FB57569A94604A407A37161406214C4008AC1C5A645D4A407A37161406214C40
22309	Нижнее Кучуково	7	64	1646	52.913411000000004	52.944412	56.215228000000003	56.195295000000002	0103000020E610000001000000050000004167D2A6EA744A404209336DFF184C404167D2A6EA744A407D9752978C1B4C4098F90E7EE2784A407D9752978C1B4C4098F90E7EE2784A404209336DFF184C404167D2A6EA744A404209336DFF184C40
61459	Кулегаш	7	64	1646	52.556600000000003	53.578505999999997	56.543840000000003	55.842897999999998	0103000020E61000000100000005000000107A36AB3E474A4091EEE714E4EB4B40107A36AB3E474A40DA20938C9C454C4017450F7C0CCA4A40DA20938C9C454C4017450F7C0CCA4A4091EEE714E4EB4B40107A36AB3E474A4091EEE714E4EB4B40
21824	Кудашево	7	64	1646	52.805326000000001	52.827666999999998	56.374332000000003	56.362875000000003	0103000020E610000001000000050000002B4F20EC14674A409CC420B0722E4C402B4F20EC14674A4053EC681CEA2F4C403D7D04FEF0694A4053EC681CEA2F4C403D7D04FEF0694A409CC420B0722E4C402B4F20EC14674A409CC420B0722E4C40
22473	Крынды	7	64	1646	52.895220000000002	52.936615000000003	56.150354	56.133026000000001	0103000020E61000000100000005000000D15CA79196724A4044C2F7FE06114C40D15CA79196724A405169C4CC3E134C40B6F81400E3774A405169C4CC3E134C40B6F81400E3774A4044C2F7FE06114C40D15CA79196724A4044C2F7FE06114C40
23041	Красный Бор	7	64	1646	53.063133000000001	53.099389000000002	55.903937999999997	55.882767000000001	0103000020E610000001000000050000003126FDBD14884A40787E5182FEF04B403126FDBD14884A404ACE893DB4F34B40844A5CC7B88C4A404ACE893DB4F34B40844A5CC7B88C4A40787E5182FEF04B403126FDBD14884A40787E5182FEF04B40
61369	Кичкетан	7	64	1646	52.556600000000003	53.578505999999997	56.543840000000003	55.842897999999998	0103000020E61000000100000005000000107A36AB3E474A4091EEE714E4EB4B40107A36AB3E474A40DA20938C9C454C4017450F7C0CCA4A40DA20938C9C454C4017450F7C0CCA4A4091EEE714E4EB4B40107A36AB3E474A4091EEE714E4EB4B40
22994	Каменный Ключ	7	64	1646	53.218209999999999	53.232933000000003	55.986687000000003	55.976826000000003	0103000020E6100000010000000500000080D4264EEE9B4A40F6F065A208FD4B4080D4264EEE9B4A40B63176C24BFE4B406094A0BFD09D4A40B63176C24BFE4B406094A0BFD09D4A40F6F065A208FD4B4080D4264EEE9B4A40F6F065A208FD4B40
23274	Кадыбаш	7	64	1646	53.409343999999997	53.433732999999997	56.167273000000002	56.150058000000001	0103000020E610000001000000050000002B685A6265B44A406840BD1935134C402B685A6265B44A407D40A03369154C4015191D9084B74A407D40A03369154C4015191D9084B74A406840BD1935134C402B685A6265B44A406840BD1935134C40
22737	Кадряково	7	64	1646	53.129356999999999	53.150494999999999	56.15428	56.131113999999997	0103000020E610000001000000050000001C412AC58E904A401C06F357C8104C401C412AC58E904A40A4367172BF134C40139B8F6B43934A40A4367172BF134C40139B8F6B43934A401C06F357C8104C401C412AC58E904A401C06F357C8104C40
23266	Исенбаево	7	64	1646	53.407009000000002	53.429403999999998	56.058563999999997	56.038434000000002	0103000020E61000000100000005000000BE16F4DE18B44A40F986C267EB044C40BE16F4DE18B44A40895C70067F074C40C362D4B5F6B64A40895C70067F074C40C362D4B5F6B64A40F986C267EB044C40BE16F4DE18B44A40F986C267EB044C40
21637	Иж-Бобья	7	64	1646	52.980029999999999	53.008363000000003	56.477587	56.463082999999997	0103000020E61000000100000005000000A88C7F9F717D4A40B22AC24D463B4C40A88C7F9F717D4A4054FF2092213D4C408CBFED0912814A4054FF2092213D4C408CBFED0912814A40B22AC24D463B4C40A88C7F9F717D4A40B22AC24D463B4C40
21674	Иж-Байки	7	64	1646	52.955587000000001	52.970868000000003	56.409449000000002	56.399841000000002	0103000020E61000000100000005000000CBBDC0AC507A4A40CB4C69FD2D334C40CBBDC0AC507A4A40A13028D368344C40D15D1267457C4A40A13028D368344C40D15D1267457C4A40CB4C69FD2D334C40CBBDC0AC507A4A40CB4C69FD2D334C40
23459	Девятерня	7	64	1646	53.384613999999999	53.407376999999997	56.209235	56.194684000000002	0103000020E61000000100000005000000B8CA13083BB14A40F986C267EB184C40B8CA13083BB14A40DB166536C81A4C404012F6ED24B44A40DB166536C81A4C404012F6ED24B44A40F986C267EB184C40B8CA13083BB14A40F986C267EB184C40
61519	Варкледбодья	7	64	1646	52.867525000000001	52.889741000000001	56.216518999999998	56.204639	0103000020E6100000010000000500000030BB270F0B6F4A403A3E5A9C311A4C4030BB270F0B6F4A4037FB03E5B61B4C4086747808E3714A4037FB03E5B61B4C4086747808E3714A403A3E5A9C311A4C4030BB270F0B6F4A403A3E5A9C311A4C40
61483	Варзипельга	7	64	1646	52.886327000000001	52.903708999999999	56.068665000000003	56.058940999999997	0103000020E61000000100000005000000E947C32973714A405FB2F1608B074C40E947C32973714A409FB0C403CA084C40E90C8CBCAC734A409FB0C403CA084C40E90C8CBCAC734A405FB2F1608B074C40E947C32973714A405FB2F1608B074C40
22654	Варзи-Омга	7	64	1646	52.764308999999997	52.795777000000001	56.061101999999998	56.052270999999998	0103000020E61000000100000005000000EC8497E0D4614A40BDC3EDD0B0064C40EC8497E0D4614A402FDCB930D2074C405AF44E05DC654A402FDCB930D2074C405AF44E05DC654A40BDC3EDD0B0064C40EC8497E0D4614A40BDC3EDD0B0064C40
23182	Бима	7	64	1646	53.334398	53.357053000000001	56.012591999999998	56.001266999999999	0103000020E6100000010000000500000085ECBC8DCDAA4A4032C85D8429004C4085ECBC8DCDAA4A407A185A9D9C014C4027F8A6E9B3AD4A407A185A9D9C014C4027F8A6E9B3AD4A4032C85D8429004C4085ECBC8DCDAA4A4032C85D8429004C40
21737	Биктово	7	64	1646	52.893836999999998	52.917247000000003	56.389558000000001	56.379033	0103000020E61000000100000005000000357A354069724A40698D412784304C40357A354069724A4095F25A09DD314C4054AD855968754A4095F25A09DD314C4054AD855968754A40698D412784304C40357A354069724A40698D412784304C40
22905	Азево	7	64	1646	53.128377999999998	53.157519000000001	56.008253000000003	55.993510000000001	0103000020E6100000010000000500000050C3B7B06E904A40DE1FEF552BFF4B4050C3B7B06E904A40058C2E6F0E014C40D3BF249529944A40058C2E6F0E014C40D3BF249529944A40DE1FEF552BFF4B4050C3B7B06E904A40DE1FEF552BFF4B40
20870	Агрыз	7	64	1646	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
40921	Чистополь	7	64	6930	50.290295	51.245285000000003	55.489998	55.034198000000004	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
61389	Елабуга	7	64	6923	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
56537	Темников	7	63	\N	43.188150999999998	43.233452999999997	54.653922999999999	54.616011999999998	0103000020E61000000100000005000000D7DAFB5415984540C6F8307BD94E4B40D7DAFB5415984540158DB5BFB3534B409813B4C9E19D4540158DB5BFB3534B409813B4C9E19D4540C6F8307BD94E4B40D7DAFB5415984540C6F8307BD94E4B40
1332	Саранск	7	63	\N	45.089354999999998	45.267094999999998	54.244281999999998	54.116135999999997	0103000020E61000000100000005000000F65D11FC6F8B4640B2F1608BDD0E4B40F65D11FC6F8B46403080F0A1441F4B406AF6402B30A246403080F0A1441F4B406AF6402B30A24640B2F1608BDD0E4B40F65D11FC6F8B4640B2F1608BDD0E4B40
32650	Рузаевка	7	63	\N	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
56533	Краснослободск	7	63	\N	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
12510	Ковылкино	7	63	\N	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
56539	Инсар	7	63	\N	44.340411000000003	44.412672000000001	53.876137999999997	53.855001000000001	0103000020E610000001000000050000006E197096922B46400E863AAC70ED4A406E197096922B464034643C4A25F04A40CAFCA36FD234464034643C4A25F04A40CAFCA36FD23446400E863AAC70ED4A406E197096922B46400E863AAC70ED4A40
62088	Берсеневка	7	63	\N	42.164313999999997	46.730441999999996	55.190255999999998	53.644064	0103000020E610000001000000050000003123BC3D08154540F6436CB070D24A403123BC3D0815454013EF004F5A984B40FACF9A1F7F5D474013EF004F5A984B40FACF9A1F7F5D4740F6436CB070D24A403123BC3D08154540F6436CB070D24A40
56536	Ардатов	7	63	\N	46.219982999999999	46.258817000000001	54.867097999999999	54.821078999999997	0103000020E6100000010000000500000086562767281C47405837DE1D19694B4086562767281C4740A8363811FD6E4B400D535BEA20214740A8363811FD6E4B400D535BEA202147405837DE1D19694B4086562767281C47405837DE1D19694B40
24809	Чамзинка	7	63	1108	45.749040999999998	45.810980000000001	54.422806000000001	54.391793999999997	0103000020E610000001000000050000007B2E5393E0DF46406F62484E26324B407B2E5393E0DF4640BB46CB811E364B40E4DA5031CEE74640BB46CB811E364B40E4DA5031CEE746406F62484E26324B407B2E5393E0DF46406F62484E26324B40
25950	Сабур-Мачкасы	7	63	1108	45.856534000000003	45.897820000000003	54.484994999999998	54.467176000000002	0103000020E61000000100000005000000BFF4F6E7A2ED4640F1BC546CCC3B4B40BFF4F6E7A2ED46409CDCEF50143E4B40EDD808C4EBF246409CDCEF50143E4B40EDD808C4EBF24640F1BC546CCC3B4B40BFF4F6E7A2ED4640F1BC546CCC3B4B40
56540	Репьевка	7	63	1108	45.729818000000002	45.751781000000001	54.406438000000001	54.393135999999998	0103000020E610000001000000050000001D041DAD6ADD4640AC70CB4752324B401D041DAD6ADD464003ED0E2906344B4089601C5C3AE0464003ED0E2906344B4089601C5C3AE04640AC70CB4752324B401D041DAD6ADD4640AC70CB4752324B40
25800	Пянгелей	7	63	1108	45.688693000000001	45.718184000000001	54.286665999999997	54.275123000000001	0103000020E61000000100000005000000F8FD9B1727D846404FB0FF3A37234B40F8FD9B1727D846400470B378B1244B4057410C74EDDB46400470B378B1244B4057410C74EDDB46404FB0FF3A37234B40F8FD9B1727D846404FB0FF3A37234B40
56557	Печеуры	7	63	1108	45.812750000000001	45.852131999999997	54.329804000000003	54.301921	0103000020E6100000010000000500000079E9263108E84640E17CEA58A5264B4079E9263108E84640850B7904372A4B4002F04FA912ED4640850B7904372A4B4002F04FA912ED4640E17CEA58A5264B4079E9263108E84640E17CEA58A5264B40
45559	Отрадное	7	63	1108	45.652095000000003	45.680472999999999	54.441580999999999	54.422628000000003	0103000020E610000001000000050000004C7155D977D34640DC2F9FAC18364B404C7155D977D346407AC4E8B985384B40CF6740BD19D746407AC4E8B985384B40CF6740BD19D74640DC2F9FAC18364B404C7155D977D34640DC2F9FAC18364B40
45487	Новоселки	7	63	1108	45.692016000000002	45.721760000000003	54.540512999999997	54.525410000000001	0103000020E610000001000000050000008527F4FA93D84640E57E87A240434B408527F4FA93D846400B08AD872F454B40CEC7B5A162DC46400B08AD872F454B40CEC7B5A162DC4640E57E87A240434B408527F4FA93D84640E57E87A240434B40
25240	Наченалы	7	63	1108	45.66592	45.700172999999999	54.497247999999999	54.480721000000003	0103000020E610000001000000050000004CE0D6DD3CD546400EC00644883D4B404CE0D6DD3CD546402E008DD2A53F4B406745D4449FD946402E008DD2A53F4B406745D4449FD946400EC00644883D4B404CE0D6DD3CD546400EC00644883D4B40
25784	Мокшалей	7	63	1108	45.609406999999997	45.642851999999998	54.266278999999997	54.243451	0103000020E610000001000000050000000B7A6F0C01CE4640D9960167291F4B400B7A6F0C01CE4640484E266E15224B4087156EF948D24640484E266E15224B4087156EF948D24640D9960167291F4B400B7A6F0C01CE4640D9960167291F4B40
45483	Мичурино	7	63	1108	45.736905	45.758904999999999	54.558576000000002	54.542414999999998	0103000020E6100000010000000500000023A12DE752DE46400FEECEDA6D454B4023A12DE752DE46404E2A1A6B7F474B40ACE28DCC23E146404E2A1A6B7F474B40ACE28DCC23E146400FEECEDA6D454B4023A12DE752DE46400FEECEDA6D454B40
25505	Медаево	7	63	1108	45.973602	46.030124000000001	54.449674999999999	54.429552000000001	0103000020E61000000100000005000000FCA886FD9EFC464038F7578FFB364B40FCA886FD9EFC4640166A4DF38E394B4090696D1ADB034740166A4DF38E394B4090696D1ADB03474038F7578FFB364B40FCA886FD9EFC464038F7578FFB364B40
25599	Мачказерово	7	63	1108	46.035065000000003	46.065275	54.394120999999998	54.378917000000001	0103000020E61000000100000005000000FC1D8A027D04474000732D5A80304B40FC1D8A027D0447405AD5928E72324B408A1F63EE5A0847405AD5928E72324B408A1F63EE5A08474000732D5A80304B40FC1D8A027D04474000732D5A80304B40
25497	Малое Маресево	7	63	1108	45.582808	45.609864999999999	54.322530999999998	54.305472000000002	0103000020E6100000010000000500000070ECD97399CA4640FFEBDCB419274B4070ECD97399CA46401C7920B248294B40CEFC6A0E10CE46401C7920B248294B40CEFC6A0E10CE4640FFEBDCB419274B4070ECD97399CA4640FFEBDCB419274B40
25406	Кульмино	7	63	1108	45.584927999999998	45.612650000000002	54.440769000000003	54.422255999999997	0103000020E61000000100000005000000E141B3EBDECA464017450F7C0C364B40E141B3EBDECA46409A0B5C1E6B384B407CF2B0506BCE46409A0B5C1E6B384B407CF2B0506BCE464017450F7C0C364B40E141B3EBDECA464017450F7C0C364B40
45403	Красный Поселок	7	63	1108	45.651350000000001	45.678370999999999	54.594296999999997	54.587536999999998	0103000020E61000000100000005000000F31FD26F5FD3464050189469344B4B40F31FD26F5FD34640328E91EC114C4B4004C765DCD4D64640328E91EC114C4B4004C765DCD4D6464050189469344B4B40F31FD26F5FD3464050189469344B4B40
49497	Комсомольский	7	63	1108	45.806542999999998	45.836168999999998	54.446821999999997	54.426000999999999	0103000020E61000000100000005000000ABE80FCD3CE746401A88653387364B40ABE80FCD3CE7464010919A7631394B40EA76F69507EB464010919A7631394B40EA76F69507EB46401A88653387364B40ABE80FCD3CE746401A88653387364B40
25132	Киржеманы	7	63	1108	45.829495000000001	45.859723000000002	54.436726999999998	54.415671000000003	0103000020E61000000100000005000000079964E42CEA4640A47213B534354B40079964E42CEA4640DD239BABE6374B403C4F3C670BEE4640DD239BABE6374B403C4F3C670BEE4640A47213B534354B40079964E42CEA4640A47213B534354B40
25304	Большое Маресево	7	63	1108	45.656694999999999	45.695430000000002	54.360191	54.339689	0103000020E610000001000000050000002E39EE940ED44640CDE7DCED7A2B4B402E39EE940ED4464022A81ABD1A2E4B402254A9D903D9464022A81ABD1A2E4B402254A9D903D94640CDE7DCED7A2B4B402E39EE940ED44640CDE7DCED7A2B4B40
25318	Большие Ремезенки	7	63	1108	45.541387	45.582017999999998	54.375554999999999	54.362101000000003	0103000020E6100000010000000500000062BD512B4CC54640A96C5853592E4B4062BD512B4CC54640B56CAD2F12304B4077D7D9907FCA4640B56CAD2F12304B4077D7D9907FCA4640A96C5853592E4B4062BD512B4CC54640A96C5853592E4B40
25188	Апраксино	7	63	1108	45.750227000000002	45.789726000000002	54.510039999999996	54.488635000000002	0103000020E61000000100000005000000C1C9367007E046402A5778978B3E4B40C1C9367007E046406FD39FFD48414B408466D7BD15E546406FD39FFD48414B408466D7BD15E546402A5778978B3E4B40C1C9367007E046402A5778978B3E4B40
56574	Центральный	7	63	838	43.042138999999999	43.062916999999999	54.106639999999999	54.096023000000002	0103000020E610000001000000050000006D718DCF64854540F8544E7B4A0C4B406D718DCF6485454004392861A60D4B4064AE0CAA0D88454004392861A60D4B4064AE0CAA0D884540F8544E7B4A0C4B406D718DCF64854540F8544E7B4A0C4B40
24487	Хилково	7	63	838	43.215181999999999	43.250225	54.184545	54.154017000000003	0103000020E610000001000000050000000C5872158B9B454097033DD4B6134B400C5872158B9B4540F6D1A92B9F174B4020D26F5F07A04540F6D1A92B9F174B4020D26F5F07A0454097033DD4B6134B400C5872158B9B454097033DD4B6134B40
49253	Торбеево	7	63	838	43.21405	43.262926999999998	54.088819999999998	54.063991999999999	0103000020E61000000100000005000000BADA8AFD659B4540529ACDE330084B40BADA8AFD659B4540889D29745E0B4B40211E8997A7A14540889D29745E0B4B40211E8997A7A14540529ACDE330084B40BADA8AFD659B4540529ACDE330084B40
24159	Татарские Юнки	7	63	838	43.331207999999997	43.352362999999997	54.195371000000002	54.174880999999999	0103000020E610000001000000050000003716140665AA45408CD8278062164B403716140665AA45401DCBBBEA01194B4004A9143B1AAD45401DCBBBEA01194B4004A9143B1AAD45408CD8278062164B403716140665AA45408CD8278062164B40
19739	Сургодь	7	63	838	43.062935000000003	43.108047999999997	54.048563999999999	54.027842	0103000020E610000001000000050000000B630B410E88454045BA9F5390034B400B630B410E884540A8E15B5837064B40F8325184D48D4540A8E15B5837064B40F8325184D48D454045BA9F5390034B400B630B410E88454045BA9F5390034B40
18409	Старые Пичуры	7	63	838	43.454807000000002	43.494441000000002	54.010469000000001	54.000112999999999	0103000020E61000000100000005000000F67EA31D37BA4540F8A6E9B303004B40F67EA31D37BA4540984F560C57014B409966BAD749BF4540984F560C57014B409966BAD749BF4540F8A6E9B303004B40F67EA31D37BA4540F8A6E9B303004B40
9608	Слаим	7	63	838	43.136220000000002	43.158192	54.038254000000002	54.024970000000003	0103000020E61000000100000005000000D3872EA86F914540C9B08A3732034B40D3872EA86F9145407978CF81E5044B40923EADA23F9445407978CF81E5044B40923EADA23F944540C9B08A3732034B40D3872EA86F914540C9B08A3732034B40
17812	Семивражки	7	63	838	43.388547000000003	43.412047000000001	54.047792000000001	54.029634999999999	0103000020E61000000100000005000000BEFA78E8BBB1454092E86514CB034B40BEFA78E8BBB1454056815A0C1E064B401CB5C2F4BDB4454056815A0C1E064B401CB5C2F4BDB4454092E86514CB034B40BEFA78E8BBB1454092E86514CB034B40
27981	Салазгорь	7	63	838	43.135832999999998	43.170904	54.141359999999999	54.108350000000002	0103000020E61000000100000005000000D95BCAF962914540C442AD69DE0D4B40D95BCAF962914540357BA01518124B40B760A92EE0954540357BA01518124B40B760A92EE0954540C442AD69DE0D4B40D95BCAF962914540C442AD69DE0D4B40
17942	Савва	7	63	838	43.054338000000001	43.105604999999997	54.083818999999998	54.070073000000001	0103000020E610000001000000050000000C772E8CF486454093AAED26F8084B400C772E8CF486454047E4BB94BA0A4B40A4A5F276848D454047E4BB94BA0A4B40A4A5F276848D454093AAED26F8084B400C772E8CF486454093AAED26F8084B40
24567	Носакино	7	63	838	43.165126999999998	43.201661999999999	54.240073000000002	54.219847000000001	0103000020E61000000100000005000000E257ACE122954540D68F4DF2231C4B40E257ACE12295454089D349B6BA1E4B40486C770FD099454089D349B6BA1E4B40486C770FD0994540D68F4DF2231C4B40E257ACE122954540D68F4DF2231C4B40
56604	Никольское	7	63	838	43.135742999999998	43.159809000000003	54.061439	54.044714999999997	0103000020E6100000010000000500000099D4D0066091454000529B38B9054B4099D4D0066091454077D9AF3BDD074B40A14D0E9F7494454077D9AF3BDD074B40A14D0E9F7494454000529B38B9054B4099D4D0066091454000529B38B9054B40
24193	Мордовские Юнки	7	63	838	43.437541000000003	43.477004000000001	54.154549000000003	54.135331000000001	0103000020E610000001000000050000005FD4EE5701B845404791B58652114B405FD4EE5701B845409450FA42C8134B40D50792770EBD45409450FA42C8134B40D50792770EBD45404791B58652114B405FD4EE5701B845404791B58652114B40
49353	Мальцево	7	63	838	43.102012000000002	43.125539000000003	54.174860000000002	54.159421000000002	0103000020E6100000010000000500000058E6ADBA0E8D4540D7A546E867144B4058E6ADBA0E8D454075B0FECF61164B40B0AF75A91190454075B0FECF61164B40B0AF75A911904540D7A546E867144B4058E6ADBA0E8D4540D7A546E867144B40
48369	Лопатино	7	63	838	43.100745000000003	43.128773000000002	54.013421999999998	53.996778999999997	0103000020E61000000100000005000000261E5036E58C4540772B4B7496FF4A40261E5036E58C45400186E5CFB7014B40CDCD37A27B9045400186E5CFB7014B40CDCD37A27B904540772B4B7496FF4A40261E5036E58C4540772B4B7496FF4A40
48734	Краснополье	7	63	838	43.331702	43.349102000000002	54.068351	54.056137999999997	0103000020E6100000010000000500000047020D3675AA45400B08AD872F074B4047020D3675AA45400FD3BEB9BF084B40EE7BD45FAFAC45400FD3BEB9BF084B40EE7BD45FAFAC45400B08AD872F074B4047020D3675AA45400B08AD872F074B40
56546	Красноармеец	7	63	838	43.433050000000001	43.458409000000003	54.085551000000002	54.072076000000003	0103000020E6100000010000000500000033C4B12E6EB74540CB694FC939094B4033C4B12E6EB74540EF91CD55F30A4B4096986725ADBA4540EF91CD55F30A4B4096986725ADBA4540CB694FC939094B4033C4B12E6EB74540CB694FC939094B40
20579	Красаевка	7	63	838	43.475836999999999	43.499633000000003	54.043542000000002	54.021622000000001	0103000020E61000000100000005000000069D103AE8BC4540E36F7B82C4024B40069D103AE8BC45405000C5C892054B404E8061F9F3BF45405000C5C892054B404E8061F9F3BF4540E36F7B82C4024B40069D103AE8BC4540E36F7B82C4024B40
6189	Кажлодка	7	63	838	43.147897999999998	43.190074000000003	54.027540000000002	53.99192	0103000020E6100000010000000500000068925852EE924540C91F0C3CF7FE4A4068925852EE9245407AAA436E86034B40F3E84658549845407AAA436E86034B40F3E8465854984540C91F0C3CF7FE4A4068925852EE924540C91F0C3CF7FE4A40
32998	Жуково	7	63	838	43.273473000000003	43.306801	54.112658000000003	54.089454000000003	0103000020E6100000010000000500000065ABCB2901A345408A3F8A3A730B4B4065ABCB2901A34540FFD0CC936B0E4B40A7B0524145A74540FFD0CC936B0E4B40A7B0524145A745408A3F8A3A730B4B4065ABCB2901A345408A3F8A3A730B4B40
47003	Дракино	7	63	838	43.237693	43.280192999999997	54.066026000000001	54.028841	0103000020E610000001000000050000007BBE66B96C9E454058E4D70FB1034B407BBE66B96C9E4540C5573B8A73084B40B8C83D5DDDA34540C5573B8A73084B40B8C83D5DDDA3454058E4D70FB1034B407BBE66B96C9E454058E4D70FB1034B40
24583	Виндрей	7	63	838	42.965288000000001	43.014910999999998	54.265121999999998	54.241531000000002	0103000020E61000000100000005000000529CA38E8E7B45402FFCE07CEA1E4B40529CA38E8E7B45409DB98784EF214B40E2AC889AE88145409DB98784EF214B40E2AC889AE88145402FFCE07CEA1E4B40529CA38E8E7B45402FFCE07CEA1E4B40
24360	Варжеляй	7	63	838	43.103062999999999	43.128449000000003	54.193379999999998	54.176640999999996	0103000020E61000000100000005000000BD361B2B318D4540FD101B2C9C164B40BD361B2B318D4540A9D903ADC0184B401A1A4F0471904540A9D903ADC0184B401A1A4F0471904540FD101B2C9C164B40BD361B2B318D4540FD101B2C9C164B40
47476	Аксеновка	7	63	838	43.101024000000002	43.122681999999998	54.005479999999999	53.985979999999998	0103000020E61000000100000005000000390EBC5AEE8C45404A41B79734FE4A40390EBC5AEE8C45401B649291B3004B4068E7340BB48F45401B649291B3004B4068E7340BB48F45404A41B79734FE4A40390EBC5AEE8C45404A41B79734FE4A40
49186	Шокша	7	63	1711	42.502924999999998	42.533154000000003	54.783835000000003	54.761741999999998	0103000020E610000001000000050000009FABADD85F404540ACFE08C380614B409FABADD85F404540E73A8DB454644B40A5DDE8633E444540E73A8DB454644B40A5DDE8633E444540ACFE08C380614B409FABADD85F404540ACFE08C380614B40
23279	Широмасово	7	63	1711	42.520693999999999	42.542397000000001	54.716298999999999	54.702827999999997	0103000020E61000000100000005000000999CDA19A6424540465B9544F6594B40999CDA19A6424540299485AFAF5B4B406939D0436D454540299485AFAF5B4B406939D0436D454540465B9544F6594B40999CDA19A6424540465B9544F6594B40
23774	Хлебино	7	63	1711	42.813796000000004	42.832993000000002	54.638002	54.627943999999999	0103000020E61000000100000005000000CDCEA2772A68454016DC0F7860504B40CDCEA2772A6845402C64AE0CAA514B400266BE839F6A45402C64AE0CAA514B400266BE839F6A454016DC0F7860504B40CDCEA2772A68454016DC0F7860504B40
56538	Теньгушево	7	63	1711	42.695847000000001	42.731932999999998	54.785024	54.753050999999999	0103000020E610000001000000050000008602B683115945402C9CA4F963604B408602B683115945409D499BAA7B644B407CEE04FBAF5D45409D499BAA7B644B407CEE04FBAF5D45402C9CA4F963604B408602B683115945402C9CA4F963604B40
23205	Телимерки	7	63	1711	42.772168000000001	42.783963	54.746980999999998	54.737636999999999	0103000020E610000001000000050000004582A966D6624540E7A8A3E36A5E4B404582A966D6624540DFDDCA129D5F4B4014234BE658644540DFDDCA129D5F4B4014234BE658644540E7A8A3E36A5E4B404582A966D6624540E7A8A3E36A5E4B40
23671	Такушево	7	63	1711	42.944681000000003	42.970444000000001	54.729745999999999	54.713251999999997	0103000020E610000001000000050000008813984EEB7845403EE76ED74B5B4B408813984EEB78454083312251685D4B40BA4C4D82377C454083312251685D4B40BA4C4D82377C45403EE76ED74B5B4B408813984EEB7845403EE76ED74B5B4B40
23483	Стандрово	7	63	1711	42.644418999999999	42.671709999999997	54.650167000000003	54.634172	0103000020E61000000100000005000000E4F560527C524540FB04508C2C514B40E4F560527C5245401FF818AC38534B40B532E197FA5545401FF818AC38534B40B532E197FA554540FB04508C2C514B40E4F560527C524540FB04508C2C514B40
23817	Сакаево	7	63	1711	42.586846000000001	42.607660000000003	54.764932000000002	54.752670999999999	0103000020E61000000100000005000000EBE40CC51D4B4540E5D2F88557604B40EBE40CC51D4B4540FAD4B14AE9614B402F8B89CDC74D4540FAD4B14AE9614B402F8B89CDC74D4540E5D2F88557604B40EBE40CC51D4B4540E5D2F88557604B40
49116	Садовый	7	63	1711	42.882418999999999	42.902002000000003	54.71114	54.703961999999997	0103000020E610000001000000050000003C2F151BF370454039D0436D1B5A4B403C2F151BF37045405070B1A2065B4B409B7631CD747345405070B1A2065B4B409B7631CD7473454039D0436D1B5A4B403C2F151BF370454039D0436D1B5A4B40
23416	Нароватово	7	63	1711	42.678654000000002	42.701003999999998	54.734392999999997	54.720438999999999	0103000020E6100000010000000500000059A65F22DE564540A8E15B58375C4B4059A65F22DE564540A6B4FE96005E4B40BE2EC37FBA594540A6B4FE96005E4B40BE2EC37FBA594540A8E15B58375C4B4059A65F22DE564540A8E15B58375C4B40
49104	Нагорная	7	63	1711	42.925753	42.950026000000001	54.728726999999999	54.720537999999998	0103000020E61000000100000005000000429605137F7645403BC3D4963A5C4B40429605137F764540295B24ED465D4B40C32CB4739A794540295B24ED465D4B40C32CB4739A7945403BC3D4963A5C4B40429605137F7645403BC3D4963A5C4B40
61830	Мельсетьево	7	63	1711	42.416687000000003	42.441533999999997	54.763851000000003	54.748753000000001	0103000020E610000001000000050000008DD5E6FF5535454015E46723D75F4B408DD5E6FF553545402A029CDEC5614B403909A52F843845402A029CDEC5614B403909A52F8438454015E46723D75F4B408DD5E6FF5535454015E46723D75F4B40
56566	Куликово	7	63	1711	42.545847000000002	42.575617000000001	54.739455999999997	54.730286999999997	0103000020E6100000010000000500000053CF8250DE454540D3D85E0B7A5D4B4053CF8250DE4545405D6A847EA65E4B40C5025FD1AD4945405D6A847EA65E4B40C5025FD1AD494540D3D85E0B7A5D4B4053CF8250DE454540D3D85E0B7A5D4B40
22931	Дудниково	7	63	1711	42.684547000000002	42.711891000000001	54.803024000000001	54.794964	0103000020E6100000010000000500000097C9703C9F574540A9BF5E61C1654B4097C9703C9F57454099F38C7DC9664B408BA8893E1F5B454099F38C7DC9664B408BA8893E1F5B4540A9BF5E61C1654B4097C9703C9F574540A9BF5E61C1654B40
23037	Вичкидеево	7	63	1711	42.745947000000001	42.768394999999998	54.787613999999998	54.775064999999998	0103000020E6100000010000000500000050C6F8307B5F45401AA3755435634B4050C6F8307B5F454095EF1989D0644B4078B471C45A62454095EF1989D0644B4078B471C45A6245401AA3755435634B4050C6F8307B5F45401AA3755435634B40
49151	Веденяпино	7	63	1711	42.964649999999999	43.013742999999998	54.735844	54.723964000000002	0103000020E610000001000000050000000F0BB5A6797B45409DBD33DAAA5C4B400F0BB5A6797B45409A7ADD22305E4B4043C6A354C28145409A7ADD22305E4B4043C6A354C28145409DBD33DAAA5C4B400F0BB5A6797B45409DBD33DAAA5C4B40
22984	Башкирцы	7	63	1711	42.730504000000003	42.747483000000003	54.775796999999997	54.765403999999997	0103000020E6100000010000000500000071CCB227815D4540211D1EC2F8614B4071CCB227815D4540DEAAEB504D634B4072A8DF85AD5F4540DEAAEB504D634B4072A8DF85AD5F4540211D1EC2F8614B4071CCB227815D4540211D1EC2F8614B40
56592	Чумартово	7	63	1600	43.333875999999997	43.352865999999999	54.679312000000003	54.667645	0103000020E61000000100000005000000AB75E272BCAA4540412B306475554B40AB75E272BCAA4540E3E313B2F3564B4067EF8CB62AAD4540E3E313B2F3564B4067EF8CB62AAD4540412B306475554B40AB75E272BCAA4540412B306475554B40
56581	Чекаевка	7	63	1600	43.56371	43.577634000000003	54.600811999999998	54.594349999999999	0103000020E61000000100000005000000CE3637A627C8454055302AA9134C4B40CE3637A627C84540AD855968E74C4B40628731E9EFC94540AD855968E74C4B40628731E9EFC9454055302AA9134C4B40CE3637A627C8454055302AA9134C4B40
56562	Ушаковка	7	63	1600	43.139175000000002	43.152551000000003	54.639913999999997	54.632185999999997	0103000020E61000000100000005000000DDB5847CD0914540997E8978EB504B40DDB5847CD09145405320B3B3E8514B406EFC89CA869345405320B3B3E8514B406EFC89CA86934540997E8978EB504B40DDB5847CD0914540997E8978EB504B40
22667	Урей 3-й	7	63	1600	43.529349000000003	43.566504000000002	54.613390000000003	54.586806000000003	0103000020E61000000100000005000000CD9541B5C1C345405D8C81751C4B4B40CD9541B5C1C34540C3D84290834E4B40CF86FC3383C84540C3D84290834E4B40CF86FC3383C845405D8C81751C4B4B40CD9541B5C1C345405D8C81751C4B4B40
56553	Тювеево	7	63	1600	43.246245000000002	43.264525999999996	54.666749000000003	54.655433000000002	0103000020E61000000100000005000000DAE6C6F4849F45400EDC813AE5534B40DAE6C6F4849F454003D2FE0758554B408978EBFCDBA1454003D2FE0758554B408978EBFCDBA145400EDC813AE5534B40DAE6C6F4849F45400EDC813AE5534B40
19573	Темников	7	63	1600	43.188150999999998	43.233452999999997	54.653922999999999	54.616011999999998	0103000020E61000000100000005000000D7DAFB5415984540C6F8307BD94E4B40D7DAFB5415984540158DB5BFB3534B409813B4C9E19D4540158DB5BFB3534B409813B4C9E19D4540C6F8307BD94E4B40D7DAFB5415984540C6F8307BD94E4B40
48755	Тарханы	7	63	1600	43.404815999999997	43.420895999999999	54.545783	54.530520000000003	0103000020E61000000100000005000000E272BC02D1B34540DDEF5014E8434B40E272BC02D1B345403CDBA337DC454B4034828DEBDFB545403CDBA337DC454B4034828DEBDFB54540DDEF5014E8434B40E272BC02D1B34540DDEF5014E8434B40
22515	Старый Ковыляй	7	63	1600	43.476717000000001	43.507995999999999	54.636021999999997	54.623451000000003	0103000020E610000001000000050000003F390A1005BD45404AD40B3ECD4F4B403F390A1005BD4540ACC43C2B69514B40D93F4F0306C14540ACC43C2B69514B40D93F4F0306C145404AD40B3ECD4F4B403F390A1005BD45404AD40B3ECD4F4B40
56593	Старый Город	7	63	1600	43.086579	43.121881999999999	54.685256000000003	54.671388	0103000020E610000001000000050000009CC24A05158B4540A376BF0AF0554B409CC24A05158B4540A3B1F677B6574B404CFC51D4998F4540A3B1F677B6574B404CFC51D4998F4540A376BF0AF0554B409CC24A05158B4540A376BF0AF0554B40
22448	Русское Караево	7	63	1600	43.227137999999997	43.251348	54.696902000000001	54.676057999999998	0103000020E61000000100000005000000E4D6A4DB129D45407E198C1189564B40E4D6A4DB129D45402D42B11534594B401FF5D72B2CA045402D42B11534594B401FF5D72B2CA045407E198C1189564B40E4D6A4DB129D45407E198C1189564B40
22511	Пушта	7	63	1600	43.222045000000001	43.229492	54.715395000000001	54.711067	0103000020E61000000100000005000000C39E76F86B9C4540E621533E045B4B40C39E76F86B9C4540685C3810925B4B40C9586DFE5F9D4540685C3810925B4B40C9586DFE5F9D4540E621533E045B4B40C39E76F86B9C4540E621533E045B4B40
22407	Пурдошки	7	63	1600	43.524732	43.578989999999997	54.676943000000001	54.650213999999998	0103000020E6100000010000000500000014950D6B2AC345405FB35C363A534B4014950D6B2AC34540C9207711A6564B40035B25581CCA4540C9207711A6564B40035B25581CCA45405FB35C363A534B4014950D6B2AC345405FB35C363A534B40
22189	Подгорное Канаково	7	63	1600	43.282617999999999	43.310716999999997	54.597698000000001	54.577554999999997	0103000020E6100000010000000500000066A19DD32CA4454015527E52ED494B4066A19DD32CA445403B71395E814C4B40D6A71C93C5A745403B71395E814C4B40D6A71C93C5A7454015527E52ED494B4066A19DD32CA4454015527E52ED494B40
30141	Оброчное	7	63	1600	43.094932999999997	43.104545000000002	54.565759999999997	54.560893999999998	0103000020E61000000100000005000000D427B9C3268C4540E542E55FCB474B40D427B9C3268C454046B1DCD26A484B40ECFA05BB618D454046B1DCD26A484B40ECFA05BB618D4540E542E55FCB474B40D427B9C3268C4540E542E55FCB474B40
48738	Нижние Борки	7	63	1600	43.454394000000001	43.470500999999999	54.66677	54.651812999999997	0103000020E61000000100000005000000D3BF249529BA4540C70DBF9B6E534B40D3BF249529BA45401AFA27B858554B401EDE736039BC45401AFA27B858554B401EDE736039BC4540C70DBF9B6E534B40D3BF249529BA4540C70DBF9B6E534B40
22333	Митрялы	7	63	1600	43.376061	43.398671	54.659813	54.644030000000001	0103000020E61000000100000005000000892650C422B045404AD235936F524B40892650C422B04540E23C9CC074544B408B6EBDA607B34540E23C9CC074544B408B6EBDA607B345404AD235936F524B40892650C422B045404AD235936F524B40
21906	Лесное Цибаево	7	63	1600	43.154122999999998	43.170822999999999	54.561818000000002	54.554409999999997	0103000020E61000000100000005000000DC476E4DBA934540A54929E8F6464B40DC476E4DBA934540EE26F8A6E9474B40CA332F87DD954540EE26F8A6E9474B40CA332F87DD954540A54929E8F6464B40DC476E4DBA934540A54929E8F6464B40
21947	Лесное Ардашево	7	63	1600	43.120444999999997	43.145805000000003	54.591563999999998	54.579135999999998	0103000020E61000000100000005000000BDFBE3BD6A8F4540D7F7E120214A4B40BDFBE3BD6A8F4540D7BE805EB84B4B40F14BFDBCA9924540D7BE805EB84B4B40F14BFDBCA9924540D7F7E120214A4B40BDFBE3BD6A8F4540D7F7E120214A4B40
48789	Лаврентьево	7	63	1600	43.038832999999997	43.058632000000003	54.500765999999999	54.48762	0103000020E61000000100000005000000B680D07AF8844540117008556A3E4B40B680D07AF88445407079AC1919404B40E23FDD40818745407079AC1919404B40E23FDD4081874540117008556A3E4B40B680D07AF8844540117008556A3E4B40
22062	Кушки	7	63	1600	43.257699000000002	43.286687000000001	54.511436000000003	54.496499999999997	0103000020E61000000100000005000000209BE447FCA04540643BDF4F8D3F4B40209BE447FCA04540A0FF1EBC76414B401C98DC28B2A44540A0FF1EBC76414B401C98DC28B2A44540643BDF4F8D3F4B40209BE447FCA04540643BDF4F8D3F4B40
22152	Кондровка	7	63	1600	43.293289999999999	43.323014999999998	54.616028	54.602220000000003	0103000020E61000000100000005000000361FD7868AA54540A27F828B154D4B40361FD7868AA54540CCB56801DA4E4B40088F368E58A94540CCB56801DA4E4B40088F368E58A94540A27F828B154D4B40361FD7868AA54540A27F828B154D4B40
22269	Ишейки	7	63	1600	43.327857000000002	43.345446000000003	54.562021999999999	54.547103999999997	0103000020E61000000100000005000000E161DA37F7A9454061C1FD8007464B40E161DA37F7A94540F6D03E56F0474B405B44149337AC4540F6D03E56F0474B405B44149337AC454061C1FD8007464B40E161DA37F7A9454061C1FD8007464B40
48597	Жегалово	7	63	1600	43.388672999999997	43.442222000000001	54.730291999999999	54.697256000000003	0103000020E610000001000000050000004AEB6F09C0B145404B7842AF3F594B404AEB6F09C0B14540E54350357A5D4B402EC901BB9AB84540E54350357A5D4B402EC901BB9AB845404B7842AF3F594B404AEB6F09C0B145404B7842AF3F594B40
22705	Булаево	7	63	1600	43.548482999999997	43.569826999999997	54.561838999999999	54.549084000000001	0103000020E61000000100000005000000BBB4E1B034C64540E1606F6248464B40BBB4E1B034C64540054F2157EA474B405BB05417F0C84540054F2157EA474B405BB05417F0C84540E1606F6248464B40BBB4E1B034C64540E1606F6248464B40
40323	Андреевка	7	63	1600	43.319780999999999	43.472197999999999	54.734554000000003	54.632238000000001	0103000020E61000000100000005000000EB707495EEA84540ECA4BE2CED504B40EB707495EEA84540B0928FDD055E4B40499EEBFB70BC4540B0928FDD055E4B40499EEBFB70BC4540ECA4BE2CED504B40EB707495EEA84540ECA4BE2CED504B40
48040	Алексеевка	7	63	1600	43.124037999999999	43.144807	54.637912999999998	54.626021000000001	0103000020E610000001000000050000000ABB287AE08F4540FBCDC47421504B400ABB287AE08F4540BC581822A7514B40AE9D280989924540BC581822A7514B40AE9D280989924540FBCDC47421504B400ABB287AE08F4540FBCDC47421504B40
22068	Аксел	7	63	1600	43.401600000000002	43.433140000000002	54.602924000000002	54.589790000000001	0103000020E610000001000000050000006C09F9A067B3454001C11C3D7E4B4B406C09F9A067B345409CFC169D2C4D4B40734BAB2171B745409CFC169D2C4D4B40734BAB2171B7454001C11C3D7E4B4B406C09F9A067B3454001C11C3D7E4B4B40
21654	Шувары	7	63	1631	44.438282999999998	44.489145000000001	54.198779000000002	54.176146000000003	0103000020E6100000010000000500000046B247A8193846401EA9BEF38B164B4046B247A819384640D8101C9771194B403F00A94D9C3E4640D8101C9771194B403F00A94D9C3E46401EA9BEF38B164B4046B247A8193846401EA9BEF38B164B40
21613	Шигонь	7	63	1631	44.768225000000001	44.799064000000001	54.433250000000001	54.419448000000003	0103000020E610000001000000050000001C7C613255624640B22FD978B0354B401C7C613255624640FA7E6ABC74374B409AB4A9BA47664640FA7E6ABC74374B409AB4A9BA47664640B22FD978B0354B401C7C613255624640B22FD978B0354B40
21499	Старое Шайгово	7	63	1631	44.4482	44.487223	54.318792000000002	54.284117000000002	0103000020E610000001000000050000009A081B9E5E3946406B9E23F25D244B409A081B9E5E394640FC1C1F2DCE284B40F46DC1525D3E4640FC1C1F2DCE284B40F46DC1525D3E46406B9E23F25D244B409A081B9E5E3946406B9E23F25D244B40
21482	Старая Федоровка	7	63	1631	44.734385000000003	44.771414	54.497487999999997	54.483117	0103000020E6100000010000000500000024D6E253005E4640219221C7D63D4B4024D6E253005E46408313D1AFAD3F4B4099D6A6B1BD6246408313D1AFAD3F4B4099D6A6B1BD624640219221C7D63D4B4024D6E253005E4640219221C7D63D4B40
21382	Старая Теризморга	7	63	1631	44.510579	44.549861999999997	54.27854	54.241694000000003	0103000020E610000001000000050000001F8315A75A414640D9D138D4EF1E4B401F8315A75A4146405D50DF32A7234B4015A8C5E0614646405D50DF32A7234B4015A8C5E061464640D9D138D4EF1E4B401F8315A75A414640D9D138D4EF1E4B40
20563	Совхоз Восход	7	63	1631	44.537744000000004	44.560220000000001	54.169463	54.157432999999997	0103000020E6100000010000000500000064CF9ECBD4444640D427B9C326144B4064CF9ECBD4444640E770ADF6B0154B405648F949B5474640E770ADF6B0154B405648F949B5474640D427B9C326144B4064CF9ECBD4444640D427B9C326144B40
21294	Рязановка	7	63	1631	44.560569999999998	44.585704999999997	54.218321000000003	54.200333000000001	0103000020E61000000100000005000000328FFCC1C0474640A0A70183A4194B40328FFCC1C0474640D88349F1F11B4B40450DA661F84A4640D88349F1F11B4B40450DA661F84A4640A0A70183A4194B40328FFCC1C0474640A0A70183A4194B40
56605	Новотроицкое	7	63	1631	44.765098999999999	44.804454	54.378999999999998	54.364823999999999	0103000020E61000000100000005000000E59997C3EE614640E065868DB22E4B40E59997C3EE6146408D976E1283304B4075914259F86646408D976E1283304B4075914259F8664640E065868DB22E4B40E59997C3EE614640E065868DB22E4B40
20929	Новое Акшино	7	63	1631	44.769526999999997	44.794761000000001	54.311087999999998	54.292400000000001	0103000020E61000000100000005000000CA3159DC7F624640DAACFA5C6D254B40CA3159DC7F624640CA1649BBD1274B4071917BBABA654640CA1649BBD1274B4071917BBABA654640DAACFA5C6D254B40CA3159DC7F624640DAACFA5C6D254B40
21102	Новая Федоровка	7	63	1631	44.581482999999999	44.599054000000002	54.464951999999997	54.445743	0103000020E610000001000000050000000917F2086E4A4640E1B54B1B0E394B400917F2086E4A4640DA1A118C833B4B40DD442DCDAD4C4640DA1A118C833B4B40DD442DCDAD4C4640E1B54B1B0E394B400917F2086E4A4640E1B54B1B0E394B40
40458	Новая Александровка	7	63	1631	44.420971999999999	44.447823	54.519813999999997	54.494664	0103000020E610000001000000050000000F441669E235464018416326513F4B400F441669E23546406000E14389424B40C4B29943523946406000E14389424B40C4B299435239464018416326513F4B400F441669E235464018416326513F4B40
20915	Мельцаны	7	63	1631	44.701785999999998	44.756421000000003	54.465176999999997	54.443255999999998	0103000020E610000001000000050000003465A71FD4594640BDE0D39CBC384B403465A71FD4594640FAEC80EB8A3B4B40FA804067D2604640FAEC80EB8A3B4B40FA804067D2604640BDE0D39CBC384B403465A71FD4594640BDE0D39CBC384B40
20836	Летки	7	63	1631	44.543762999999998	44.579416999999999	54.322521000000002	54.301321999999999	0103000020E610000001000000050000002EE3A6069A4546405CC823B891264B402EE3A6069A454640F9A23D5E48294B408BDF14562A4A4640F9A23D5E48294B408BDF14562A4A46405CC823B891264B402EE3A6069A4546405CC823B891264B40
20748	Лемдяй	7	63	1631	44.696638	44.735418000000003	54.351255999999999	54.336376000000001	0103000020E610000001000000050000004F93196F2B5946406494675E0E2B4B404F93196F2B5946400B43E4F4F52C4B40E371512D225E46400B43E4F4F52C4B40E371512D225E46406494675E0E2B4B404F93196F2B5946406494675E0E2B4B40
56595	Кулдым	7	63	1631	44.581707999999999	44.623353999999999	54.424309000000001	54.409089999999999	0103000020E6100000010000000500000029E96168754A4640718FA50F5D344B4029E96168754A46400133DFC14F364B4057EA5910CA4F46400133DFC14F364B4057EA5910CA4F4640718FA50F5D344B4029E96168754A4640718FA50F5D344B40
56607	Конолать	7	63	1631	44.887979000000001	44.909143999999998	54.356276999999999	54.347240999999997	0103000020E610000001000000050000007444BE4BA9714640486AA164722C4B407444BE4BA971464093A8177C9A2D4B4064ADA1D45E74464093A8177C9A2D4B4064ADA1D45E744640486AA164722C4B407444BE4BA9714640486AA164722C4B40
20641	Ингенер-Пятина	7	63	1631	44.829858000000002	44.857894999999999	54.399372999999997	54.387332000000001	0103000020E61000000100000005000000782975C9386A4640DE58501894314B40782975C9386A4640E4F38AA71E334B407233DC80CF6D4640E4F38AA71E334B407233DC80CF6D4640DE58501894314B40782975C9386A4640DE58501894314B40
21131	Вертелим	7	63	1631	44.503436999999998	44.547572000000002	54.497880000000002	54.464292999999998	0103000020E61000000100000005000000554CA59F704046408061F9F36D3B4B40554CA59F704046408FAA2688BA3F4B40481ADCD6164646408FAA2688BA3F4B40481ADCD6164646408061F9F36D3B4B40554CA59F704046408061F9F36D3B4B40
20521	Богдановка	7	63	1631	44.374763000000002	44.381509000000001	54.311608	54.299393000000002	0103000020E610000001000000050000001C60E63BF82F46405FD3838252264B401C60E63BF82F464003965CC5E2274B4099107349D530464003965CC5E2274B4099107349D53046405FD3838252264B401C60E63BF82F46405FD3838252264B40
56541	Озерный	7	63	7414	45.282708	45.292535999999998	54.237805000000002	54.230753999999997	0103000020E61000000100000005000000A62897C62FA44640E9B5D958891D4B40A62897C62FA44640A3E9EC64701E4B408A73D4D171A54640A3E9EC64701E4B408A73D4D171A54640E9B5D958891D4B40A62897C62FA44640E9B5D958891D4B40
56559	Монастырское	7	63	7414	45.119914999999999	45.141115999999997	54.092210999999999	54.077131000000001	0103000020E6100000010000000500000061A6ED5F598F4640FF40B96DDF094B4061A6ED5F598F46406DAAEE91CD0B4B409E78CE16109246406DAAEE91CD0B4B409E78CE1610924640FF40B96DDF094B4061A6ED5F598F4640FF40B96DDF094B40
19725	совхоз Красное Сельцо	7	63	1514	44.877899999999997	44.904750999999997	54.026662000000002	54.014310999999999	0103000020E610000001000000050000004694F6065F7046408D7C5EF1D4014B404694F6065F704640E20511A969034B40FB027AE1CE734640E20511A969034B40FB027AE1CE7346408D7C5EF1D4014B404694F6065F7046408D7C5EF1D4014B40
19456	Шишкеево	7	63	1514	44.742255	44.775232000000003	54.201892000000001	54.176341000000001	0103000020E6100000010000000500000070253B36025F4640D3F8855792164B4070253B36025F46407AA9D898D7194B4006685BCD3A6346407AA9D898D7194B4006685BCD3A634640D3F8855792164B4070253B36025F4640D3F8855792164B40
20339	Хованщина	7	63	1514	44.585166000000001	44.610193000000002	54.080289999999998	54.061629000000003	0103000020E61000000100000005000000965D30B8E64A46401BBE8575E3074B40965D30B8E64A4640111956F1460A4B40C39FE1CD1A4E4640111956F1460A4B40C39FE1CD1A4E46401BBE8575E3074B40965D30B8E64A46401BBE8575E3074B40
20215	Трускляй	7	63	1514	44.832185000000003	44.860894999999999	54.032009000000002	54.025582999999997	0103000020E61000000100000005000000639CBF09856A4640B22AC24D46034B40639CBF09856A4640BE16F4DE18044B401C25AFCE316E4640BE16F4DE18044B401C25AFCE316E4640B22AC24D46034B40639CBF09856A4640B22AC24D46034B40
20046	Татарская Пишля	7	63	1514	44.890161999999997	44.93347	54.069429	54.054414999999999	0103000020E610000001000000050000002B1213D4F0714640B7B41A12F7064B402B1213D4F07146406E32AA0CE3084B4008E6E8F17B7746406E32AA0CE3084B4008E6E8F17B774640B7B41A12F7064B402B1213D4F0714640B7B41A12F7064B40
18676	Сузгарье	7	63	1514	44.908442999999998	44.935975999999997	54.127924	54.112146000000003	0103000020E61000000100000005000000DBA337DC477446404930D5CC5A0E4B40DBA337DC47744640CF2F4AD05F104B40A2EBC20FCE774640CF2F4AD05F104B40A2EBC20FCE7746404930D5CC5A0E4B40DBA337DC477446404930D5CC5A0E4B40
56600	Стрелецкая Слобода	7	63	1514	44.685803999999997	44.716177000000002	54.205025999999997	54.187795999999999	0103000020E61000000100000005000000A5BBEB6CC8574640E92807B309184B40A5BBEB6CC8574640336ABE4A3E1A4B40DE921CB0AB5B4640336ABE4A3E1A4B40DE921CB0AB5B4640E92807B309184B40A5BBEB6CC8574640E92807B309184B40
19899	Русское Баймаково	7	63	1514	44.676606	44.706519999999998	54.045672000000003	54.033431999999998	0103000020E61000000100000005000000812381069B564640E751F17F47044B40812381069B564640E52B8194D8054B4026FC523F6F5A4640E52B8194D8054B4026FC523F6F5A4640E751F17F47044B40812381069B564640E751F17F47044B40
18772	Плодопитомнический	7	63	1514	45.014443999999997	45.029698000000003	54.024272000000003	54.013283999999999	0103000020E61000000100000005000000CCCF0D4DD9814640B0C7444AB3014B40CCCF0D4DD9814640B11A4B581B034B40D960E124CD834640B11A4B581B034B40D960E124CD834640B0C7444AB3014B40CCCF0D4DD9814640B0C7444AB3014B40
18717	Перхляй	7	63	1514	44.893737999999999	44.925601	54.199348000000001	54.175651000000002	0103000020E61000000100000005000000A298BC01667246403E4162BB7B164B40A298BC0166724640F2423A3C84194B408C12F4177A764640F2423A3C84194B408C12F4177A7646403E4162BB7B164B40A298BC01667246403E4162BB7B164B40
19885	Палаевка	7	63	1514	44.723103000000002	44.748705000000001	53.949105000000003	53.933295000000001	0103000020E61000000100000005000000DB519CA38E5C46409A42E73576F74A40DB519CA38E5C46402CBCCB457CF94A4004ADC090D55F46402CBCCB457CF94A4004ADC090D55F46409A42E73576F74A40DB519CA38E5C46409A42E73576F74A40
56567	Пайгарма	7	63	1514	44.821925999999998	44.851472000000001	54.085107000000001	54.069408000000003	0103000020E61000000100000005000000B5DD04DF34694640570A815CE2084B40B5DD04DF3469464091D442C9E40A4B40D8BAD408FD6C464091D442C9E40A4B40D8BAD408FD6C4640570A815CE2084B40B5DD04DF34694640570A815CE2084B40
19984	Новый Усад	7	63	1514	44.716966999999997	44.736541000000003	54.058537999999999	54.049895999999997	0103000020E61000000100000005000000D6A71C93C55B4640C119FCFD62064B40D6A71C93C55B464060C9552C7E074B40E294B9F9465E464060C9552C7E074B40E294B9F9465E4640C119FCFD62064B40D6A71C93C55B4640C119FCFD62064B40
19572	Новая Муравьевка	7	63	1514	44.692855999999999	44.714883	54.004834000000002	53.992035999999999	0103000020E610000001000000050000002F6B6281AF584640323A2009FBFE4A402F6B6281AF58464056F487669E004B40B2BB4049815B464056F487669E004B40B2BB4049815B4640323A2009FBFE4A402F6B6281AF584640323A2009FBFE4A40
19774	Мордовская Пишля	7	63	1514	44.782390999999997	44.812942999999997	54.114114000000001	54.100807000000003	0103000020E61000000100000005000000A5D76663256446409C1A683EE70C4B40A5D766632564464004029D499B0E4B408D4127840E68464004029D499B0E4B408D4127840E6846409C1A683EE70C4B40A5D76663256446409C1A683EE70C4B40
18835	Левженский	7	63	1514	45.068989999999999	45.094475000000003	54.111759999999997	54.103394000000002	0103000020E6100000010000000500000022E010AAD4884640234DBC033C0D4B4022E010AAD48846401F80D4264E0E4B4012A5BDC1178C46401F80D4264E0E4B4012A5BDC1178C4640234DBC033C0D4B4022E010AAD4884640234DBC033C0D4B40
18605	Левжа	7	63	1514	44.998435999999998	45.021225999999999	54.094501999999999	54.074320999999998	0103000020E61000000100000005000000149337C0CC7F4640F833BC5983094B40149337C0CC7F46400BB43BA4180C4B4096E99788B78246400BB43BA4180C4B4096E99788B7824640F833BC5983094B40149337C0CC7F4640F833BC5983094B40
18561	Красный Клин	7	63	1514	44.968504000000003	44.979464	54.051761999999997	54.045270000000002	0103000020E61000000100000005000000C90567F0F77B4640B6BE4868CB054B40C90567F0F77B464078962023A0064B40FFCD8B135F7D464078962023A0064B40FFCD8B135F7D4640B6BE4868CB054B40C90567F0F77B4640B6BE4868CB054B40
18460	Ключарево	7	63	1514	44.992120999999997	45.008893	54.149434999999997	54.135415999999999	0103000020E61000000100000005000000605628D2FD7E464075ADBD4F55114B40605628D2FD7E46405AF0A2AF20134B40E814E467238146405AF0A2AF20134B40E814E4672381464075ADBD4F55114B40605628D2FD7E464075ADBD4F55114B40
20266	Инсар-Акшино	7	63	1514	44.767380000000003	44.794249000000001	54.014194000000003	54.007230999999997	0103000020E6100000010000000500000060CD018239624640394206F2EC004B4060CD01823962464054E6E61BD1014B40BBF083F3A965464054E6E61BD1014B40BBF083F3A9654640394206F2EC004B4060CD018239624640394206F2EC004B40
19670	Верхний Урледим	7	63	1514	44.673363000000002	44.691329000000003	53.935909000000002	53.927802999999997	0103000020E6100000010000000500000011AB3FC230564640BA10AB3FC2F64A4011AB3FC2305646401B84B9DDCBF74A4061E3FA777D5846401B84B9DDCBF74A4061E3FA777D584640BA10AB3FC2F64A4011AB3FC230564640BA10AB3FC2F64A40
19466	Болдово	7	63	1514	44.605522000000001	44.657111999999998	53.997996000000001	53.976449000000002	0103000020E610000001000000050000001781B1BE814D4640209BE447FCFC4A401781B1BE814D4640F8C43A55BEFF4A4092E7FA3E1C544640F8C43A55BEFF4A4092E7FA3E1C544640209BE447FCFC4A401781B1BE814D4640209BE447FCFC4A40
32937	Архангельское Голицыно	7	63	1514	45.045616000000003	45.071396999999997	54.053004000000001	54.033040999999997	0103000020E610000001000000050000005116BEBED6854640AC36FFAF3A044B405116BEBED68546405247C7D5C8064B4029047289238946405247C7D5C8064B402904728923894640AC36FFAF3A044B405116BEBED6854640AC36FFAF3A044B40
18330	Аргамаково	7	63	1514	45.082814999999997	45.102334999999997	53.988394	53.979011999999997	0103000020E61000000100000005000000224F92AE998A46401E32E54350FD4A40224F92AE998A464004C8D0B183FE4A403A1E3350198D464004C8D0B183FE4A403A1E3350198D46401E32E54350FD4A40224F92AE998A46401E32E54350FD4A40
40362	Рузаевка	7	63	6907	44.517954000000003	45.144385	54.262393000000003	53.927802999999997	0103000020E610000001000000050000008C6A11514C424640BA10AB3FC2F64A408C6A11514C42464084D9041896214B4038842A357B92464084D9041896214B4038842A357B924640BA10AB3FC2F64A408C6A11514C424640BA10AB3FC2F64A40
17664	Уришка	7	63	1380	45.238124999999997	45.273204	54.514426	54.491239	0103000020E6100000010000000500000014AE47E17A9E464087C267EBE03E4B4014AE47E17A9E4640261B0FB6D8414B4075914259F8A24640261B0FB6D8414B4075914259F8A2464087C267EBE03E4B4014AE47E17A9E464087C267EBE03E4B40
17620	Трофимовщина	7	63	1380	45.211480999999999	45.250008999999999	54.525174999999997	54.505701999999999	0103000020E61000000100000005000000D95C35CF119B4640CAC2D7D7BA404B40D95C35CF119B4640A1D634EF38434B40535A7F4B00A04640A1D634EF38434B40535A7F4B00A04640CAC2D7D7BA404B40D95C35CF119B4640CAC2D7D7BA404B40
16751	Старая Михайловка	7	63	1380	45.161768000000002	45.170085999999998	54.358784999999997	54.351759999999999	0103000020E6100000010000000500000009C556D0B49446403E05C078062D4B4009C556D0B4944640CEA5B8AAEC2D4B40F4C0C760C5954640CEA5B8AAEC2D4B40F4C0C760C59546403E05C078062D4B4009C556D0B49446403E05C078062D4B40
17101	Совхоз Садвинтрест	7	63	1380	45.410187999999998	45.427759000000002	54.427300000000002	54.419217000000003	0103000020E61000000100000005000000179B560A81B44640B07614E7A8354B40179B560A81B4464058CA32C4B1364B40EBC891CEC0B6464058CA32C4B1364B40EBC891CEC0B64640B07614E7A8354B40179B560A81B44640B07614E7A8354B40
56583	Ромодановский Махоркосовхоз	7	63	1380	45.018199000000003	45.632295999999997	54.591397000000001	54.267898000000002	0103000020E61000000100000005000000F3E8465854824640F8544E7B4A224B40F3E8465854824640ECF99AE5B24B4B4020B24813EFD04640ECF99AE5B24B4B4020B24813EFD04640F8544E7B4A224B40F3E8465854824640F8544E7B4A224B40
16286	Ромоданово	7	63	1380	45.305804000000002	45.380319	54.439093999999997	54.401795	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
17488	Пушкино	7	63	1380	45.363115999999998	45.381540999999999	54.531658999999998	54.494100000000003	0103000020E61000000100000005000000C153C8957AAE4640107A36AB3E3F4B40C153C8957AAE4640E1CFF0660D444B40A48AE255D6B04640E1CFF0660D444B40A48AE255D6B04640107A36AB3E3F4B40C153C8957AAE4640107A36AB3E3F4B40
17404	Малые Березники	7	63	1380	45.448438000000003	45.474930000000001	54.394441	54.365516	0103000020E610000001000000050000004F24986A66B946401615713AC92E4B404F24986A66B94640CC99ED0A7D324B40D4F19881CABC4640CC99ED0A7D324B40D4F19881CABC46401615713AC92E4B404F24986A66B946401615713AC92E4B40
17325	Липки	7	63	1380	45.112881999999999	45.131881	54.435554000000003	54.419710000000002	0103000020E610000001000000050000004E27D9EA728E4640EFE6A90EB9354B404E27D9EA728E46402DD2C43BC0374B405DFB027AE19046402DD2C43BC0374B405DFB027AE1904640EFE6A90EB9354B404E27D9EA728E4640EFE6A90EB9354B40
17244	Курмачкасы	7	63	1380	45.520887000000002	45.557673000000001	54.562789000000002	54.545726000000002	0103000020E61000000100000005000000AEF4DA6CACC24640D8497D59DA454B40AEF4DA6CACC2464037C64E7809484B405D6E30D461C7464037C64E7809484B405D6E30D461C74640D8497D59DA454B40AEF4DA6CACC24640D8497D59DA454B40
17135	Курилово	7	63	1380	45.462515000000003	45.485368000000001	54.465595999999998	54.454098000000002	0103000020E61000000100000005000000697407B133BB4640EA961DE21F3A4B40697407B133BB4640FF9254A6983B4B403143E38920BE4640FF9254A6983B4B403143E38920BE4640EA961DE21F3A4B40697407B133BB4640EA961DE21F3A4B40
17296	Красный Узел	7	63	1380	45.228628999999998	45.251742999999998	54.437449000000001	54.432637	0103000020E6100000010000000500000066F50EB7439D4640100533A660374B4066F50EB7439D46407E552E54FE374B409BFF571D39A046407E552E54FE374B409BFF571D39A04640100533A660374B4066F50EB7439D4640100533A660374B40
17038	Кочуново	7	63	1380	45.441924999999998	45.461652000000001	54.426960000000001	54.415104999999997	0103000020E61000000100000005000000742497FF90B84640FAB31F2922354B40742497FF90B846409F5912A0A6364B400611A96917BB46409F5912A0A6364B400611A96917BB4640FAB31F2922354B40742497FF90B84640FAB31F2922354B40
16950	Константиновка	7	63	1380	45.363826000000003	45.376465000000003	54.476489000000001	54.460676999999997	0103000020E610000001000000050000009EB7B1D991AE46407B82C476F73A4B409EB7B1D991AE4640AEF36F97FD3C4B40598B4F0130B04640AEF36F97FD3C4B40598B4F0130B046407B82C476F73A4B409EB7B1D991AE46407B82C476F73A4B40
15069	Инят	7	63	1380	45.380642000000002	45.397826999999999	54.320194999999998	54.305807999999999	0103000020E61000000100000005000000F5BD86E0B8B04640766D6FB724274B40F5BD86E0B8B04640DEAB5626FC284B409F3BC1FEEBB24640DEAB5626FC284B409F3BC1FEEBB24640766D6FB724274B40F5BD86E0B8B04640766D6FB724274B40
16992	Ивановка	7	63	1380	45.394423000000003	45.412289999999999	54.454065999999997	54.443815999999998	0103000020E6100000010000000500000026E5EE737CB2464084B872F6CE384B4026E5EE737CB24640DE1CAED51E3A4B40E23B31EBC5B44640DE1CAED51E3A4B40E23B31EBC5B4464084B872F6CE384B4026E5EE737CB2464084B872F6CE384B40
16905	Вырыпаево	7	63	1380	45.136983000000001	45.162512999999997	54.459153999999998	54.444586000000001	0103000020E61000000100000005000000D28DB0A8889146403621AD31E8384B40D28DB0A888914640EEE9EA8EC53A4B406116DA39CD944640EEE9EA8EC53A4B406116DA39CD9446403621AD31E8384B40D28DB0A8889146403621AD31E8384B40
17194	Болтино	7	63	1380	45.507269000000001	45.536949	54.497577	54.479607000000001	0103000020E6100000010000000500000027A3CA30EEC0464062F71DC3633D4B4027A3CA30EEC04640F31E679AB03F4B40594FADBEBAC44640F31E679AB03F4B40594FADBEBAC4464062F71DC3633D4B4027A3CA30EEC0464062F71DC3633D4B40
16845	Белозерье	7	63	1380	45.357106999999999	45.388539000000002	54.353417999999998	54.328086999999996	0103000020E610000001000000050000001A16A3AEB5AD4640129F3BC1FE294B401A16A3AEB5AD4640ABE80FCD3C2D4B403B1C5DA5BBB14640ABE80FCD3C2D4B403B1C5DA5BBB14640129F3BC1FE294B401A16A3AEB5AD4640129F3BC1FE294B40
16704	Анненково	7	63	1380	45.291476000000003	45.306809999999999	54.391520999999997	54.373074000000003	0103000020E61000000100000005000000D2C8E7154FA54640747E8AE3C02F4B40D2C8E7154FA546403E59315C1D324B40FA0AD28C45A746403E59315C1D324B40FA0AD28C45A74640747E8AE3C02F4B40D2C8E7154FA54640747E8AE3C02F4B40
16637	Алтары	7	63	1380	45.321945999999997	45.349381000000001	54.381034999999997	54.366675000000001	0103000020E61000000100000005000000FC89CA8635A9464062A1D634EF2E4B40FC89CA8635A94640D0D03FC1C5304B40016C4084B8AC4640D0D03FC1C5304B40016C4084B8AC464062A1D634EF2E4B40FC89CA8635A9464062A1D634EF2E4B40
15941	Черемишево	7	63	1391	45.068908999999998	45.088554999999999	54.272252000000002	54.249001	0103000020E6100000010000000500000035B39602D2884640EDD5C743DF1F4B4035B39602D2884640A3224E27D9224B40DA722EC5558B4640A3224E27D9224B40DA722EC5558B4640EDD5C743DF1F4B4035B39602D2884640EDD5C743DF1F4B40
28176	Татарская Тавла	7	63	1391	45.342193999999999	45.366458000000002	54.234622000000002	54.212887000000002	0103000020E6100000010000000500000097715303CDAB46402D5F97E13F1B4B4097715303CDAB46400876FC17081E4B40C5AD8218E8AE46400876FC17081E4B40C5AD8218E8AE46402D5F97E13F1B4B4097715303CDAB46402D5F97E13F1B4B40
33141	Татарская Свербейка	7	63	1391	44.937018000000002	45.046469000000002	54.252251999999999	54.206541999999999	0103000020E61000000100000005000000B5E1B034F07746400EA0DFF76F1A4B40B5E1B034F0774640E02C25CB49204B4090A339B2F2854640E02C25CB49204B4090A339B2F28546400EA0DFF76F1A4B40B5E1B034F07746400EA0DFF76F1A4B40
56598	Суркино	7	63	1391	45.258471	45.273508999999997	54.345540999999997	54.336722999999999	0103000020E6100000010000000500000072FBE59315A14640CF6740BD192B4B4072FBE59315A14640AC36FFAF3A2C4B40B114C95702A34640AC36FFAF3A2C4B40B114C95702A34640CF6740BD192B4B4072FBE59315A14640CF6740BD192B4B40
29365	Смольково	7	63	1391	44.954822999999998	44.980685000000001	54.371653000000002	54.357971999999997	0103000020E61000000100000005000000FB3BDBA3377A46401D71C806D22D4B40FB3BDBA3377A4640EB3A5453922F4B40C1560916877D4640EB3A5453922F4B40C1560916877D46401D71C806D22D4B40FB3BDBA3377A46401D71C806D22D4B40
49324	Скрябино	7	63	1391	45.563575	45.589635000000001	54.200006999999999	54.184561000000002	0103000020E61000000100000005000000EEEBC03923C84640FC8EE1B19F174B40EEEBC03923C846404CFC51D499194B40DAC9E02879CB46404CFC51D499194B40DAC9E02879CB4640FC8EE1B19F174B40EEEBC03923C84640FC8EE1B19F174B40
16127	Протасово	7	63	1391	45.516728000000001	45.550792000000001	54.267772000000001	54.255198	0103000020E61000000100000005000000B876A22424C246409700FC53AA204B40B876A22424C246406B64575A46224B4000732D5A80C646406B64575A46224B4000732D5A80C646409700FC53AA204B40B876A22424C246409700FC53AA204B40
32594	Первомайск	7	63	1391	45.015971	45.043962999999998	54.440125000000002	54.421030000000002	0103000020E610000001000000050000009B5775560B8246404451A04FE4354B409B5775560B8246407593180456384B40F59D5F94A08546407593180456384B40F59D5F94A08546404451A04FE4354B409B5775560B8246404451A04FE4354B40
16088	Пензятка	7	63	1391	44.971719999999998	45.009225000000001	54.246339999999996	54.225532000000001	0103000020E610000001000000050000003F6F2A52617C4640CA198A3BDE1C4B403F6F2A52617C46402BD9B111881F4B401EA7E8482E8146402BD9B111881F4B401EA7E8482E814640CA198A3BDE1C4B403F6F2A52617C4640CA198A3BDE1C4B40
61828	Новая Михайловка	7	63	1391	45.072287000000003	45.085850999999998	54.327230999999998	54.317731999999999	0103000020E6100000010000000500000086764EB34089464043723271AB284B4086764EB340894640629E95B4E2294B4019AA622AFD8A4640629E95B4E2294B4019AA622AFD8A464043723271AB284B4086764EB34089464043723271AB284B40
45962	Масловка	7	63	1391	44.870265000000003	44.881970000000003	54.306355000000003	54.297201999999999	0103000020E610000001000000050000003EEDF0D7646F4640242713B70A264B403EEDF0D7646F4640A9FB00A436274B40CD069964E4704640A9FB00A436274B40CD069964E4704640242713B70A264B403EEDF0D7646F4640242713B70A264B40
15800	Лямбирь	7	63	1391	45.099091999999999	45.150421999999999	54.295341999999998	54.267398999999997	0103000020E61000000100000005000000CAA5F10BAF8C4640D6FD63213A224B40CAA5F10BAF8C46404F9143C4CD254B40A94C3107419346404F9143C4CD254B40A94C310741934640D6FD63213A224B40CAA5F10BAF8C4640D6FD63213A224B40
15708	Кривозерье	7	63	1391	45.284962999999998	45.299677000000003	54.342350000000003	54.328516999999998	0103000020E61000000100000005000000F7C8E6AA79A446400B9755D80C2A4B40F7C8E6AA79A446408FE4F21FD22B4B40842EE1D05BA646408FE4F21FD22B4B40842EE1D05BA646400B9755D80C2A4B40F7C8E6AA79A446400B9755D80C2A4B40
15560	Большая Елховка	7	63	1391	45.302489000000001	45.348761000000003	54.288873000000002	54.258642999999999	0103000020E610000001000000050000002B33A5F5B7A646406F2BBD361B214B402B33A5F5B7A6464045D95BCAF9244B40658F5033A4AC464045D95BCAF9244B40658F5033A4AC46406F2BBD361B214B402B33A5F5B7A646406F2BBD361B214B40
45943	Болотниково	7	63	1391	44.916150000000002	44.932940000000002	54.280000999999999	54.271357999999999	0103000020E610000001000000050000007E1D38674475464005C1E3DBBB224B407E1D38674475464074ECA012D7234B40AC90F2936A77464074ECA012D7234B40AC90F2936A77464005C1E3DBBB224B407E1D38674475464005C1E3DBBB224B40
15365	Блохино	7	63	1391	45.067650999999998	45.094008000000002	54.242820000000002	54.235390000000002	0103000020E610000001000000050000005645B8C9A888464019E76F42211E4B405645B8C9A88846404968CBB9141F4B40FCC74274088C46404968CBB9141F4B40FCC74274088C464019E76F42211E4B405645B8C9A888464019E76F42211E4B40
15225	Атемар	7	63	1391	45.380076000000003	45.421444000000001	54.190783000000003	54.169822000000003	0103000020E610000001000000050000004CFF9254A6B04640171230BABC154B404CFF9254A6B04640FFD0CC936B184B40378C82E0F1B54640FFD0CC936B184B40378C82E0F1B54640171230BABC154B404CFF9254A6B04640171230BABC154B40
61824	Александровка	7	63	1391	45.248797000000003	45.276069	54.273929000000003	54.260525999999999	0103000020E61000000100000005000000E52B8194D89F4640FCE07CEA58214B40E52B8194D89F46408736001B10234B403F389F3A56A346408736001B10234B403F389F3A56A34640FCE07CEA58214B40E52B8194D89F4640FCE07CEA58214B40
45763	Аксеново	7	63	1391	45.328539999999997	45.366996999999998	54.255982000000003	54.240125999999997	0103000020E61000000100000005000000C3B645990DAA4640AB75E272BC1E4B40C3B645990DAA4640AE2EA704C4204B40745DF8C1F9AE4640AE2EA704C4204B40745DF8C1F9AE4640AB75E272BC1E4B40C3B645990DAA4640AB75E272BC1E4B40
14950	Шаверки	7	63	287	43.743147999999998	43.782485999999999	54.334082000000002	54.315578000000002	0103000020E610000001000000050000003D0B42791FDF454026AB22DC64284B403D0B42791FDF45405517F032C32A4B40F7C9518028E445405517F032C32A4B40F7C9518028E4454026AB22DC64284B403D0B42791FDF454026AB22DC64284B40
1219	Чукалы	7	63	287	43.625324999999997	43.647837000000003	54.530932999999997	54.515675000000002	0103000020E61000000100000005000000832F4CA60AD04540B22E6EA301424B40832F4CA60AD04540FFAECF9CF5434B40C311A452ECD24540FFAECF9CF5434B40C311A452ECD24540B22E6EA301424B40832F4CA60AD04540B22E6EA301424B40
14600	Старые Горяши	7	63	287	43.776116999999999	43.801538999999998	54.460881000000001	54.433799	0103000020E61000000100000005000000506F46CD57E34540CD04C3B986374B40506F46CD57E34540842C0B26FE3A4B40F9BB77D498E64540842C0B26FE3A4B40F9BB77D498E64540CD04C3B986374B40506F46CD57E34540CD04C3B986374B40
14896	Старое-Синдрово	7	63	287	44.080025999999997	44.138981999999999	54.428499000000002	54.401538000000002	0103000020E61000000100000005000000336ABE4A3E0A4640F60CE19865334B40336ABE4A3E0A464032AF230ED9364B40C85D8429CA11464032AF230ED9364B40C85D8429CA114640F60CE19865334B40336ABE4A3E0A4640F60CE19865334B40
14753	Старое Зубарево	7	63	287	43.803291000000002	43.820898	54.406899000000003	54.392893999999998	0103000020E61000000100000005000000E8154F3DD2E64540B665C0594A324B40E8154F3DD2E6454037E3344415344B4008AD872F13E9454037E3344415344B4008AD872F13E94540B665C0594A324B40E8154F3DD2E64540B665C0594A324B40
14849	Старая Рябка	7	63	287	43.904727999999999	43.940956999999997	54.344963999999997	54.329641000000002	0103000020E6100000010000000500000043E38920CEF34540DB3521AD312A4B4043E38920CEF345400F26C5C7272C4B409CF86A4771F845400F26C5C7272C4B409CF86A4771F84540DB3521AD312A4B4043E38920CEF34540DB3521AD312A4B40
14552	Слободские Дубровки	7	63	287	43.522441000000001	43.557555999999998	54.408245999999998	54.385900999999997	0103000020E61000000100000005000000768BC058DFC24540313F373465314B40768BC058DFC24540855CA96741344B4023D8B8FE5DC74540855CA96741344B4023D8B8FE5DC74540313F373465314B40768BC058DFC24540313F373465314B40
14500	Сивинь	7	63	287	44.235182999999999	44.275543999999996	54.363449000000003	54.340628000000002	0103000020E610000001000000050000009FC9FE791A1E46400B0DC4B2992B4B409FC9FE791A1E4640C861307F852E4B40F44D9A0645234640C861307F852E4B40F44D9A06452346400B0DC4B2992B4B409FC9FE791A1E46400B0DC4B2992B4B40
14472	Селищи	7	63	287	43.487307999999999	43.530185000000003	54.480103999999997	54.45693	0103000020E61000000100000005000000228AC91B60BE4540D847A7AE7C3A4B40228AC91B60BE4540E256410C743D4B4036EA211ADDC34540E256410C743D4B4036EA211ADDC34540D847A7AE7C3A4B40228AC91B60BE4540D847A7AE7C3A4B40
14285	Русское Маскино	7	63	287	43.791091000000002	43.828425000000003	54.523383000000003	54.502110000000002	0103000020E6100000010000000500000079944A7842E545404E7FF62345404B4079944A7842E545402524D236FE424B402B1895D409EA45402524D236FE424B402B1895D409EA45404E7FF62345404B4079944A7842E545404E7FF62345404B40
14687	Пригородное	7	63	287	43.754475999999997	43.781219	54.419642000000003	54.405264000000003	0103000020E61000000100000005000000F6CE68AB92E04540821FD5B0DF334B40F6CE68AB92E0454097033DD4B6354B40C501F4FBFEE3454097033DD4B6354B40C501F4FBFEE34540821FD5B0DF334B40F6CE68AB92E04540821FD5B0DF334B40
56551	Преображенский	7	63	287	43.404591000000003	44.365501000000002	54.570791	54.235095000000001	0103000020E61000000100000005000000C3A04CA3C9B34540003ACC97171E4B40C3A04CA3C9B34540F2ECF2AD0F494B40E1D39CBCC82E4640F2ECF2AD0F494B40E1D39CBCC82E4640003ACC97171E4B40C3A04CA3C9B34540003ACC97171E4B40
14027	Плужное	7	63	287	43.735709999999997	43.758465000000001	54.383378999999998	54.367798000000001	0103000020E610000001000000050000008AABCABE2BDE454061C43E01142F4B408AABCABE2BDE4540917C259012314B409014916115E14540917C259012314B409014916115E1454061C43E01142F4B408AABCABE2BDE454061C43E01142F4B40
14408	Новая Карьга	7	63	287	43.947550999999997	44.013496000000004	54.427818000000002	54.399037999999997	0103000020E610000001000000050000006325E65949F945403DEE5BAD13334B406325E65949F94540F0517FBDC2364B403C50A73CBA014640F0517FBDC2364B403C50A73CBA0146403DEE5BAD13334B406325E65949F945403DEE5BAD13334B40
14379	Мордовские Парки	7	63	287	43.488250999999998	43.518749	54.422255999999997	54.410929000000003	0103000020E61000000100000005000000A19E3E027FBE45402FFD4B5299344B40A19E3E027FBE454017450F7C0C364B4096EA025E66C2454017450F7C0C364B4096EA025E66C245402FFD4B5299344B40A19E3E027FBE45402FFD4B5299344B40
14308	Куликово	7	63	287	43.637003	43.664447000000003	54.418421000000002	54.402124999999998	0103000020E61000000100000005000000193A765089D14540B6F3FDD478334B40193A765089D14540D57ABFD18E354B4071766B990CD54540D57ABFD18E354B4071766B990CD54540B6F3FDD478334B40193A765089D14540B6F3FDD478334B40
13614	Краснослободск	7	63	287	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
14221	Красная Подгора	7	63	287	43.783465	43.806317999999997	54.494486999999999	54.474747000000001	0103000020E61000000100000005000000C347C49448E44540E36F7B82C43C4B40C347C49448E4454009A69A594B3F4B408B16A06D35E7454009A69A594B3F4B408B16A06D35E74540E36F7B82C43C4B40C347C49448E44540E36F7B82C43C4B40
14128	Колопино	7	63	287	44.131337000000002	44.169111000000001	54.369681	54.348227999999999	0103000020E610000001000000050000009CE09BA6CF10464097C62FBC922C4B409CE09BA6CF104640EE79FEB4512F4B406A32E36DA5154640EE79FEB4512F4B406A32E36DA515464097C62FBC922C4B409CE09BA6CF10464097C62FBC922C4B40
14658	Заречное	7	63	287	43.801817	43.823484999999998	54.423979000000003	54.405301000000001	0103000020E610000001000000050000003C3080F0A1E645409F0436E7E0334B403C3080F0A1E645406C98A1F144364B408FDFDBF467E945406C98A1F144364B408FDFDBF467E945409F0436E7E0334B403C3080F0A1E645409F0436E7E0334B40
14184	Желтоногово	7	63	287	43.75515	43.774490999999998	54.486668000000002	54.462952999999999	0103000020E6100000010000000500000086C954C1A8E04540E44A3D0B423B4B4086C954C1A8E045403F0114234B3E4B40EE05668522E345403F0114234B3E4B40EE05668522E34540E44A3D0B423B4B4086C954C1A8E04540E44A3D0B423B4B40
14093	Ефаево	7	63	287	43.751933999999999	43.787892999999997	54.313267000000003	54.295825999999998	0103000020E610000001000000050000000F60915F3FE045403BA759A0DD254B400F60915F3FE0454041F50F2219284B40A8DF85ADD9E4454041F50F2219284B40A8DF85ADD9E445403BA759A0DD254B400F60915F3FE045403BA759A0DD254B40
13993	Гумны	7	63	287	43.703136999999998	43.746858000000003	54.395657	54.380521000000002	0103000020E61000000100000005000000C4CDA96400DA45407A3881E9B4304B40C4CDA96400DA45407CB779E3A4324B40C460FE0A99DF45407CB779E3A4324B40C460FE0A99DF45407A3881E9B4304B40C4CDA96400DA45407A3881E9B4304B40
13148	Татарский Умыс	7	63	1256	45.599553	45.640965000000001	53.953995999999997	53.94556	0103000020E61000000100000005000000FE9B1727BECC4640F0332E1C08F94A40FE9B1727BECC4640E5417A8A1CFA4A40B97020240BD24640E5417A8A1CFA4A40B97020240BD24640F0332E1C08F94A40FE9B1727BECC4640F0332E1C08F94A40
13552	Старые Турдаки	7	63	1256	45.449714	45.494790999999999	53.928210999999997	53.902873	0103000020E61000000100000005000000D446753A90B9464080B8AB5791F34A40D446753A90B94640CB64389ECFF64A4075ADBD4F55BF4640CB64389ECFF64A4075ADBD4F55BF464080B8AB5791F34A40D446753A90B9464080B8AB5791F34A40
13466	Семилей	7	63	1256	45.326186	45.339967000000001	53.949947999999999	53.931451000000003	0103000020E61000000100000005000000DF347D76C0A94640CB694FC939F74A40DF347D76C0A94640477364E597F94A40105CE50984AB4640477364E597F94A40105CE50984AB4640CB694FC939F74A40DF347D76C0A94640CB694FC939F74A40
30639	Сабаево	7	63	1256	45.683446000000004	45.768085999999997	54.003146000000001	53.979551999999998	0103000020E61000000100000005000000804A95287BD746409E5DBEF561FD4A40804A95287BD746407E8E8F1667004B40FA415DA450E246407E8E8F1667004B40FA415DA450E246409E5DBEF561FD4A40804A95287BD746409E5DBEF561FD4A40
13379	Подлесная Тавла	7	63	1256	45.458579999999998	45.493119999999998	54.104629000000003	54.087018999999998	0103000020E61000000100000005000000C24CDBBFB2BA4640B8904770230B4B40C24CDBBFB2BA46404A9BAA7B640D4B407380608E1EBF46404A9BAA7B640D4B407380608E1EBF4640B8904770230B4B40C24CDBBFB2BA4640B8904770230B4B40
13526	Новые Турдаки	7	63	1256	45.336678999999997	45.366889	53.917808000000001	53.883718000000002	0103000020E61000000100000005000000FF1F274C18AB46407A71E2AB1DF14A40FF1F274C18AB4640EB0088BB7AF54A408E210038F6AE4640EB0088BB7AF54A408E210038F6AE46407A71E2AB1DF14A40FF1F274C18AB46407A71E2AB1DF14A40
13337	Новая Пырма	7	63	1256	45.444001	45.472701999999998	54.021785999999999	54.000118999999998	0103000020E6100000010000000500000016325706D5B84640DA8D3EE603004B4016325706D5B846405DC136E2C9024B407C60C77F81BC46405DC136E2C9024B407C60C77F81BC4640DA8D3EE603004B4016325706D5B84640DA8D3EE603004B40
13286	Мурань	7	63	1256	45.543802999999997	45.588071999999997	54.044234000000003	54.037058999999999	0103000020E61000000100000005000000BC3B32569BC54640E0826C59BE044B40BC3B32569BC5464086AFAF75A9054B40BED87BF145CB464086AFAF75A9054B40BED87BF145CB4640E0826C59BE044B40BC3B32569BC54640E0826C59BE044B40
13236	Мордовское Давыдово	7	63	1256	45.724212000000001	45.750109999999999	53.978000999999999	53.965645000000002	0103000020E6100000010000000500000075AF93FAB2DC4640E1455F419AFB4A4075AF93FAB2DC4640473A03232FFD4A408733BF9A03E04640473A03232FFD4A408733BF9A03E04640E1455F419AFB4A4075AF93FAB2DC4640E1455F419AFB4A40
13173	Красномайский	7	63	1256	45.412765999999998	45.434998999999998	53.968601	53.949185	0103000020E610000001000000050000004B732B84D5B44640486DE2E47EF94A404B732B84D5B44640BBEF181EFBFB4A407765170CAEB74640BBEF181EFBFB4A407765170CAEB74640486DE2E47EF94A404B732B84D5B44640486DE2E47EF94A40
12952	Кочкурово	7	63	1256	45.386930999999997	45.456802000000003	54.049632000000003	54.025376999999999	0103000020E610000001000000050000007F677BF486B146400989B48D3F034B407F677BF486B14640E46A64575A064B40AB5FE97C78BA4640E46A64575A064B40AB5FE97C78BA46400989B48D3F034B407F677BF486B146400989B48D3F034B40
13091	Качелай	7	63	1256	45.642771000000003	45.690246999999999	53.953572000000001	53.929440999999997	0103000020E610000001000000050000009BE8F35146D24640E04735ECF7F64A409BE8F35146D24640CF30B5A50EFA4A40C09481035AD84640CF30B5A50EFA4A40C09481035AD84640E04735ECF7F64A409BE8F35146D24640E04735ECF7F64A40
56549	Горяйновка	7	63	1256	45.320993999999999	45.353997999999997	54.113143000000001	54.102544000000002	0103000020E610000001000000050000002A1BD65416A9464055336B29200D4B402A1BD65416A94640BB6246787B0E4B40B96C74CE4FAD4640BB6246787B0E4B40B96C74CE4FAD464055336B29200D4B402A1BD65416A9464055336B29200D4B40
13054	Воеводское	7	63	1256	45.236732000000003	45.388080000000002	53.979664	53.944828999999999	0103000020E6100000010000000500000056F5F23B4D9E4640FCA71B28F0F84A4056F5F23B4D9E4640C68844A165FD4A40A81DFE9AACB14640C68844A165FD4A40A81DFE9AACB14640FCA71B28F0F84A4056F5F23B4D9E4640FCA71B28F0F84A40
12999	Булгаково	7	63	1256	45.23021	45.250017999999997	54.060867999999999	54.049193000000002	0103000020E61000000100000005000000289B7285779D46409818CBF44B064B40289B7285779D4640BCAFCA85CA074B40A6B4FE9600A04640BCAFCA85CA074B40A6B4FE9600A046409818CBF44B064B40289B7285779D46409818CBF44B064B40
50006	Янгужинский Майдан	7	63	698	43.994892	44.025893000000003	53.824908000000001	53.803941999999999	0103000020E61000000100000005000000A986FD9E58FF4540BFF04A92E7E64A40A986FD9E58FF4540B91AD99596E94A4001193A7650034640B91AD99596E94A4001193A7650034640BFF04A92E7E64A40A986FD9E58FF4540BFF04A92E7E64A40
33151	Шадым	7	63	698	44.034354999999998	44.053336999999999	53.910229999999999	53.892946000000002	0103000020E610000001000000050000001FBAA0BE65044640098CF50D4CF24A401FBAA0BE6504464046EBA86A82F44A4058552FBFD306464046EBA86A82F44A4058552FBFD3064640098CF50D4CF24A401FBAA0BE65044640098CF50D4CF24A40
22700	Чепурновка	7	63	698	43.711410999999998	43.732126000000001	53.986843	53.968510999999999	0103000020E61000000100000005000000E08101840FDB45407B681F2BF8FB4A40E08101840FDB4540ADA415DF50FE4A409146054EB6DD4540ADA415DF50FE4A409146054EB6DD45407B681F2BF8FB4A40E08101840FDB45407B681F2BF8FB4A40
11262	Унуевский Майдан	7	63	698	44.246600000000001	44.274098000000002	54.109369000000001	54.091951999999999	0103000020E61000000100000005000000C898BB96901F4640A1664815C50B4B40C898BB96901F46401E19ABCDFF0D4B4013F3ACA4152346401E19ABCDFF0D4B4013F3ACA415234640A1664815C50B4B40C898BB96901F4640A1664815C50B4B40
50007	Троицк	7	63	698	43.795071	43.842106999999999	54.109918	54.071916999999999	0103000020E61000000100000005000000BF7FF3E2C4E545406283859334094B40BF7FF3E2C4E54540F19E03CB110E4B40C85D8429CAEB4540F19E03CB110E4B40C85D8429CAEB45406283859334094B40BF7FF3E2C4E545406283859334094B40
11201	Токмово	7	63	698	44.083098	44.110047000000002	54.066749999999999	54.034722000000002	0103000020E61000000100000005000000772E8CF4A20A4640D2393FC571044B40772E8CF4A20A4640068195438B084B40EF022505160E4640068195438B084B40EF022505160E4640D2393FC571044B40772E8CF4A20A4640D2393FC571044B40
56606	Старое Пшеново	7	63	698	44.182065000000001	44.230978	54.113930000000003	54.102786000000002	0103000020E61000000100000005000000855FEAE74D1746404B3E7617280D4B40855FEAE74D17464043041C42950E4B40390CE6AF901D464043041C42950E4B40390CE6AF901D46404B3E7617280D4B40855FEAE74D1746404B3E7617280D4B40
31057	Старое Дракино	7	63	698	43.927007000000003	43.962733	53.906055000000002	53.881875999999998	0103000020E61000000100000005000000E014562AA8F645404B901150E1F04A40E014562AA8F645404BB0389CF9F34A40D6E3BED53AFB45404BB0389CF9F34A40D6E3BED53AFB45404B901150E1F04A40E014562AA8F645404B901150E1F04A40
11747	Старое Аллагулово	7	63	698	43.488	43.514060000000001	54.226790000000001	54.206853000000002	0103000020E610000001000000050000005839B4C876BE45402D0ABB287A1A4B405839B4C876BE4540A9876874071D4B404417D4B7CCC14540A9876874071D4B404417D4B7CCC145402D0ABB287A1A4B405839B4C876BE45402D0ABB287A1A4B40
11779	Старая Самаевка	7	63	698	43.670510999999998	43.690120999999998	54.226838000000001	54.212260999999998	0103000020E61000000100000005000000DB4DF04DD3D54540AE9B525E2B1B4B40DB4DF04DD3D54540BABE0F07091D4B4033A48AE255D84540BABE0F07091D4B4033A48AE255D84540AE9B525E2B1B4B40DB4DF04DD3D54540AE9B525E2B1B4B40
45818	Силикатный	7	63	698	43.904594000000003	43.915633999999997	54.111781000000001	54.106582000000003	0103000020E61000000100000005000000341477BCC9F34540D02B9E7AA40D4B40341477BCC9F3454037A8FDD64E0E4B40868DB27E33F5454037A8FDD64E0E4B40868DB27E33F54540D02B9E7AA40D4B40341477BCC9F34540D02B9E7AA40D4B40
12021	Самозлейка	7	63	698	43.873108000000002	43.904710000000001	54.320577999999998	54.305661000000001	0103000020E6100000010000000500000020F0C000C2EF4540D2544FE61F274B4020F0C000C2EF454096E82CB308294B409D2E8B89CDF3454096E82CB308294B409D2E8B89CDF34540D2544FE61F274B4020F0C000C2EF4540D2544FE61F274B40
11454	Самаевка	7	63	698	43.630921999999998	43.667852000000003	54.022013000000001	53.976322000000003	0103000020E61000000100000005000000D829560DC2D04540C32E8A1EF8FC4A40D829560DC2D045401E8B6D52D1024B40BB48A12C7CD545401E8B6D52D1024B40BB48A12C7CD54540C32E8A1EF8FC4A40D829560DC2D04540C32E8A1EF8FC4A40
11923	Рыбкино	7	63	698	43.764626999999997	43.774777999999998	54.269576000000001	54.254651000000003	0103000020E61000000100000005000000BD512B4CDFE1454065726A6798204B40BD512B4CDFE14540ACE4637781224B4084D4EDEC2BE34540ACE4637781224B4084D4EDEC2BE3454065726A6798204B40BD512B4CDFE1454065726A6798204B40
50008	Русская Лашма	7	63	698	43.810386999999999	44.109121999999999	54.233322000000001	54.000124	0103000020E61000000100000005000000410DDFC2BAE74540ECF82F1004004B40410DDFC2BAE74540FAB7CB7EDD1D4B4016A3AEB5F70D4640FAB7CB7EDD1D4B4016A3AEB5F70D4640ECF82F1004004B40410DDFC2BAE74540ECF82F1004004B40
56543	Примокшанский	7	63	698	43.476689999999998	44.344695999999999	54.336995999999999	53.736611000000003	0103000020E61000000100000005000000452A8C2D04BD4540DB6FED4449DE4A40452A8C2D04BD4540007157AF222B4B40F0879FFF1E2C4640007157AF222B4B40F0879FFF1E2C4640DB6FED4449DE4A40452A8C2D04BD4540DB6FED4449DE4A40
16897	Польцо	7	63	698	43.762103000000003	43.793337000000001	54.205936999999999	54.195846000000003	0103000020E610000001000000050000007D9752978CE14540B686527B11194B407D9752978CE14540A704C4245C1A4B4077DA1A118CE54540A704C4245C1A4B4077DA1A118CE54540B686527B11194B407D9752978CE14540B686527B11194B40
49415	Покровск	7	63	698	43.581513999999999	43.651322999999998	54.078014000000003	54.054960000000001	0103000020E610000001000000050000004415FE0C6FCA4540494BE5ED08074B404415FE0C6FCA4540A950DD5CFC094B40F910548D5ED34540A950DD5CFC094B40F910548D5ED34540494BE5ED08074B404415FE0C6FCA4540494BE5ED08074B40
56572	Первомайский	7	63	698	44.041829	44.062086000000001	54.135942999999997	54.117412999999999	0103000020E610000001000000050000001F8315A75A0546400890A163070F4B401F8315A75A054640608F899466114B400DC51D6FF2074640608F899466114B400DC51D6FF20746400890A163070F4B401F8315A75A0546400890A163070F4B40
10094	Парапино	7	63	698	43.884633000000001	43.912740999999997	54.005082999999999	53.975400999999998	0103000020E610000001000000050000002FFB75A73BF145402BBEA1F0D9FC4A402FFB75A73BF14540FE614B8FA6004B40F25B74B2D4F44540FE614B8FA6004B40F25B74B2D4F445402BBEA1F0D9FC4A402FFB75A73BF145402BBEA1F0D9FC4A40
10657	Паньжа	7	63	698	43.790498999999997	43.821347000000003	53.960957000000001	53.945723999999998	0103000020E61000000100000005000000A6423C122FE545406A85E97B0DF94A40A6423C122FE545405FEE93A300FB4A4078D503E621E945405FEE93A300FB4A4078D503E621E945406A85E97B0DF94A40A6423C122FE545406A85E97B0DF94A40
48000	Октябрьский	7	63	698	44.047739999999997	44.060747999999997	53.756238000000003	53.746724	0103000020E61000000100000005000000035B25581C064640B491EBA694DF4A40035B25581C06464009FF2268CCE04A4011A62897C607464009FF2268CCE04A4011A62897C6074640B491EBA694DF4A40035B25581C064640B491EBA694DF4A40
11160	Новое Пшенево	7	63	698	44.151432999999997	44.167251999999998	54.049292999999999	54.035435999999997	0103000020E610000001000000050000008044132862134640EF8CB62A89044B408044132862134640FB75A73B4F064B406518778368154640FB75A73B4F064B406518778368154640EF8CB62A89044B408044132862134640EF8CB62A89044B40
56590	Новая Самаевка	7	63	698	44.037903999999997	44.048647000000003	54.236694999999997	54.228758999999997	0103000020E610000001000000050000009C31CC09DA04464034D593F9471D4B409C31CC09DA044640381092054C1E4B4036069D103A064640381092054C1E4B4036069D103A06464034D593F9471D4B409C31CC09DA04464034D593F9471D4B40
56594	Мордовское Вечкино	7	63	698	43.852797000000002	43.871059000000002	53.973382999999998	53.959907999999999	0103000020E610000001000000050000003F90BC7328ED45409A95ED43DEFA4A403F90BC7328ED4540BEBD6BD097FC4A4078F17EDC7EEF4540BEBD6BD097FC4A4078F17EDC7EEF45409A95ED43DEFA4A403F90BC7328ED45409A95ED43DEFA4A40
11024	Мордов Коломасово	7	63	698	44.121267000000003	44.146608999999998	53.971958999999998	53.959282999999999	0103000020E61000000100000005000000C28A53AD850F4640EC4D0CC9C9FA4A40C28A53AD850F4640C4060B2769FC4A404E266E15C4124640C4060B2769FC4A404E266E15C4124640EC4D0CC9C9FA4A40C28A53AD850F4640EC4D0CC9C9FA4A40
48900	Михайловское	7	63	698	43.562685999999999	43.600658000000003	54.146123000000003	54.131565000000002	0103000020E6100000010000000500000062F5471806C845402D26361FD7104B4062F5471806C84540C2189128B4124B40570A815CE2CC4540C2189128B4124B40570A815CE2CC45402D26361FD7104B4062F5471806C845402D26361FD7104B40
11955	Мамолаево	7	63	698	43.949527000000003	43.990642999999999	54.306711999999997	54.287291000000003	0103000020E61000000100000005000000A2D5C9198AF94540B3B794F3C5244B40A2D5C9198AF9454037A5BC5642274B407381CB63CDFE454037A5BC5642274B407381CB63CDFE4540B3B794F3C5244B40A2D5C9198AF94540B3B794F3C5244B40
30738	Курнино	7	63	698	43.860118	43.902329999999999	54.064922000000003	54.041966000000002	0103000020E61000000100000005000000B859BC5818EE4540A0C552245F054B40B859BC5818EE45403D65355D4F084B408F19A88C7FF345403D65355D4F084B408F19A88C7FF34540A0C552245F054B40B859BC5818EE4540A0C552245F054B40
10796	Красный Шадым	7	63	698	44.079225999999998	44.117494000000001	53.859706000000003	53.834744999999998	0103000020E61000000100000005000000177FDB13240A4640F0BF95ECD8EA4A40177FDB13240A46406616A1D80AEE4A40F5BC1B0B0A0F46406616A1D80AEE4A40F5BC1B0B0A0F4640F0BF95ECD8EA4A40177FDB13240A4640F0BF95ECD8EA4A40
32609	Красная Пресня	7	63	698	44.01585	44.041254000000002	54.105615999999998	54.095368000000001	0103000020E6100000010000000500000020D26F5F07024640DF8AC404350C4B4020D26F5F0702464098F738D3840D4B40236AA2CF4705464098F738D3840D4B40236AA2CF47054640DF8AC404350C4B4020D26F5F07024640DF8AC404350C4B40
11071	Кочелаево	7	63	698	44.021194999999999	44.064413000000002	54.030147999999997	54.006644000000001	0103000020E610000001000000050000005BEB8B84B6024640795BE9B5D9004B405BEB8B84B60246401805C1E3DB034B40F83768AF3E0846401805C1E3DB034B40F83768AF3E084640795BE9B5D9004B405BEB8B84B6024640795BE9B5D9004B40
46371	Клиновка	7	63	698	43.662039	43.679412999999997	53.974882000000001	53.970205999999997	0103000020E6100000010000000500000099D6A6B1BDD445400531D0B52FFC4A4099D6A6B1BDD44540C3BAF1EEC8FC4A4016BD5301F7D64540C3BAF1EEC8FC4A4016BD5301F7D645400531D0B52FFC4A4099D6A6B1BDD445400531D0B52FFC4A40
56603	Казенный Майдан	7	63	698	44.022111000000002	44.049213000000002	53.940773999999998	53.919155000000003	0103000020E61000000100000005000000E1F08288D40246403A7AFCDEA6F54A40E1F08288D4024640AB764D486BF84A40DFC4909C4C064640AB764D486BF84A40DFC4909C4C0646403A7AFCDEA6F54A40E1F08288D40246403A7AFCDEA6F54A40
4870	Изосимовка	7	63	698	43.732261000000001	43.744486999999999	54.123381000000002	54.113481	0103000020E6100000010000000500000071917BBABADD4540D3DB9F8B860E4B4071917BBABADD454051F9D7F2CA0F4B4009A69A594BDF454051F9D7F2CA0F4B4009A69A594BDF4540D3DB9F8B860E4B4071917BBABADD4540D3DB9F8B860E4B40
56585	Ежовка	7	63	698	43.697262000000002	43.716810000000002	54.094344	54.080311000000002	0103000020E610000001000000050000002D5F97E13FD9454029417FA1470A4B402D5F97E13FD945407349D576130C4B400FB9196EC0DB45407349D576130C4B400FB9196EC0DB454029417FA1470A4B402D5F97E13FD9454029417FA1470A4B40
20090	Гумны	7	63	698	43.715265000000002	43.748843999999998	54.024715999999998	54.017749000000002	0103000020E610000001000000050000009A7CB3CD8DDB4540B344679945024B409A7CB3CD8DDB45400ED8D5E429034B4025E7C41EDADF45400ED8D5E429034B4025E7C41EDADF4540B344679945024B409A7CB3CD8DDB4540B344679945024B40
12135	Волгапино	7	63	698	43.760908000000001	43.786060999999997	54.165863000000002	54.151147999999999	0103000020E61000000100000005000000E4A1EF6E65E145408B6D52D158134B40E4A1EF6E65E14540E84EB0FF3A154B409DD497A59DE44540E84EB0FF3A154B409DD497A59DE445408B6D52D158134B40E4A1EF6E65E145408B6D52D158134B40
56589	Васильевка	7	63	698	43.856110999999999	43.873817000000003	53.933872999999998	53.924002000000002	0103000020E61000000100000005000000785F950B95ED454024B891B245F64A40785F950B95ED454007CF842689F74A402CD8463CD9EF454007CF842689F74A402CD8463CD9EF454024B891B245F64A40785F950B95ED454024B891B245F64A40
11632	Большой Азясь	7	63	698	43.663899000000001	43.692411999999997	54.179217999999999	54.166659000000003	0103000020E610000001000000050000006E6C76A4FAD44540C34A051555154B406E6C76A4FAD44540616D8C9DF0164B40D1ADD7F4A0D84540616D8C9DF0164B40D1ADD7F4A0D84540C34A051555154B406E6C76A4FAD44540C34A051555154B40
32381	Алькино	7	63	698	43.945422000000001	43.968491	53.825392000000001	53.801510999999998	0103000020E610000001000000050000009F758D9603F945402F3196E997E64A409F758D9603F94540A530EF71A6E94A4034BC5983F7FB4540A530EF71A6E94A4034BC5983F7FB45402F3196E997E64A409F758D9603F945402F3196E997E64A40
8019	Ямщина	7	63	963	44.24015	44.261161999999999	53.966110999999998	53.953895000000003	0103000020E610000001000000050000003411363CBD1E4640B2683A3B19FA4A403411363CBD1E464026A77686A9FB4A409E7AA4C16D21464026A77686A9FB4A409E7AA4C16D214640B2683A3B19FA4A403411363CBD1E4640B2683A3B19FA4A40
10715	Сиалеевский Майдан	7	63	963	44.191515000000003	44.211638000000001	54.090905999999997	54.068604000000001	0103000020E61000000100000005000000C3D8429083184640F92F1004C8084B40C3D84290831846404D81CCCEA20B4B40A14B38F4161B46404D81CCCEA20B4B40A14B38F4161B4640F92F1004C8084B40C3D8429083184640F92F1004C8084B40
10522	Пушкино	7	63	963	44.357379999999999	44.392271000000001	54.100807000000003	54.087294	0103000020E610000001000000050000004B1FBAA0BE2D46408A9125732C0B4B404B1FBAA0BE2D46409C1A683EE70C4B40A915A6EF353246409C1A683EE70C4B40A915A6EF353246408A9125732C0B4B404B1FBAA0BE2D46408A9125732C0B4B40
10407	Паево	7	63	963	44.203203000000002	44.244039999999998	54.027842	54.010992999999999	0103000020E610000001000000050000007CB94F8E021A464012BEF73768014B407CB94F8E021A464045BA9F5390034B403A75E5B33C1F464045BA9F5390034B403A75E5B33C1F464012BEF73768014B407CB94F8E021A464012BEF73768014B40
10473	Нагаево	7	63	963	44.406275999999998	44.440815999999998	54.149729999999998	54.125644999999999	0103000020E6100000010000000500000029931ADA00344640F5F3A62215104B4029931ADA00344640739D465A2A134B40DAC69FA86C384640739D465A2A134B40DAC69FA86C384640F5F3A62215104B4029931ADA00344640F5F3A62215104B40
56597	Латышевка	7	63	963	44.392845999999999	44.417442000000001	53.966588000000002	53.942326999999999	0103000020E61000000100000005000000A52E19C748324640A391CF2B9EF84A40A52E19C748324640605AD427B9FB4A4009FD4CBD6E354640605AD427B9FB4A4009FD4CBD6E354640A391CF2B9EF84A40A52E19C748324640A391CF2B9EF84A40
9956	Кадошкино	7	63	963	44.373154999999997	44.434626999999999	54.043505000000003	54.017283999999997	0103000020E6100000010000000500000060AB048BC32F46403D5FB35C36024B4060AB048BC32F4640331B649291054B40B37A87DBA1374640331B649291054B40B37A87DBA13746403D5FB35C36024B4060AB048BC32F46403D5FB35C36024B40
52959	Инсар	7	63	963	44.283171000000003	44.302124999999997	54.073307	54.059669	0103000020E610000001000000050000007B1684F23E244640E2CAD93BA3074B407B1684F23E244640B0C8AF1F62094B40E9263108AC264640B0C8AF1F62094B40E9263108AC264640E2CAD93BA3074B407B1684F23E244640E2CAD93BA3074B40
10385	Глушково	7	63	963	44.242764000000001	44.270854999999997	54.028857000000002	54.021853999999998	0103000020E61000000100000005000000B55208E4121F4640B5A4A31CCC024B40B55208E4121F46405EA10F96B1034B40A27A6B60AB2246405EA10F96B1034B40A27A6B60AB224640B5A4A31CCC024B40B55208E4121F4640B5A4A31CCC024B40
10315	Большая Поляна	7	63	963	44.299321999999997	44.335631999999997	54.011327000000001	53.992783000000003	0103000020E61000000100000005000000957CEC2E502646402C836A8313FF4A40957CEC2E50264640E947C32973014B40DBBE47FDF52A4640E947C32973014B40DBBE47FDF52A46402C836A8313FF4A40957CEC2E502646402C836A8313FF4A40
10248	Адашево	7	63	963	44.31268	44.336728000000001	53.964315999999997	53.935909000000002	0103000020E61000000100000005000000800EF3E5052846401B84B9DDCBF74A40800EF3E5052846403881E9B46EFB4A40E1D231E7192B46403881E9B46EFB4A40E1D231E7192B46401B84B9DDCBF74A40800EF3E5052846401B84B9DDCBF74A40
9194	Ульянка	7	63	866	45.352075999999997	45.366951999999998	54.659745000000001	54.649270999999999	0103000020E610000001000000050000006EDA8CD310AD4640E09EE74F1B534B406EDA8CD310AD46408A592F8672544B40D4997B48F8AE46408A592F8672544B40D4997B48F8AE4640E09EE74F1B534B406EDA8CD310AD4640E09EE74F1B534B40
47890	Троицкий	7	63	866	45.440694999999998	45.456522999999997	54.700695000000003	54.694592	0103000020E610000001000000050000005F419AB168B8464018080264E8584B405F419AB168B8464041BCAE5FB0594B40976F7D586FBA464041BCAE5FB0594B40976F7D586FBA464018080264E8584B405F419AB168B8464018080264E8584B40
9794	Тарханово	7	63	866	45.640326999999999	45.680346999999998	54.7697	54.751190999999999	0103000020E6100000010000000500000076DF313CF6D146405706D50627604B4076DF313CF6D1464098DD938785624B404277499C15D7464098DD938785624B404277499C15D746405706D50627604B4076DF313CF6D146405706D50627604B40
32577	Смольный	7	63	866	45.272288000000003	45.312531999999997	54.732089999999999	54.718775000000001	0103000020E61000000100000005000000F08B4B55DAA246405917B7D1005C4B40F08B4B55DAA2464044DD0720B55D4B400B7A6F0C01A8464044DD0720B55D4B400B7A6F0C01A846405917B7D1005C4B40F08B4B55DAA246405917B7D1005C4B40
9783	Селищи	7	63	866	45.617609000000002	45.656677000000002	54.745286999999998	54.732734999999998	0103000020E610000001000000050000008E5BCCCF0DCF464039D1AE42CA5D4B408E5BCCCF0DCF464025917D90655F4B408884EFFD0DD4464025917D90655F4B408884EFFD0DD4464039D1AE42CA5D4B408E5BCCCF0DCF464039D1AE42CA5D4B40
47816	Рождествено	7	63	866	45.262514000000003	45.316862	54.700611000000002	54.677500000000002	0103000020E61000000100000005000000FF5E0A0F9AA146401F85EB51B8564B40FF5E0A0F9AA14640E31B0A9FAD594B402EAC1BEF8EA84640E31B0A9FAD594B402EAC1BEF8EA846401F85EB51B8564B40FF5E0A0F9AA146401F85EB51B8564B40
9514	Резоватово	7	63	866	45.452804	45.493991999999999	54.63646	54.614364999999999	0103000020E61000000100000005000000BEBF417BF5B946404D672783A34E4B40BEBF417BF5B94640289B728577514B40293E3E213BBF4640289B728577514B40293E3E213BBF46404D672783A34E4B40BEBF417BF5B946404D672783A34E4B40
47763	Пермеево	7	63	866	45.173194000000002	45.206980000000001	54.603054999999998	54.579521999999997	0103000020E6100000010000000500000085EE92382B96464000A8E2C62D4A4B4085EE92382B9646403A58FFE7304D4B408A7615527E9A46403A58FFE7304D4B408A7615527E9A464000A8E2C62D4A4B4085EE92382B96464000A8E2C62D4A4B40
9424	Парадеево	7	63	866	45.652023	45.670330999999997	54.673596000000003	54.655042000000002	0103000020E61000000100000005000000B29E5A7D75D34640D3C08F6AD8534B40B29E5A7D75D34640B45BCB6438564B405B3FFD67CDD54640B45BCB6438564B405B3FFD67CDD54640D3C08F6AD8534B40B29E5A7D75D34640D3C08F6AD8534B40
9707	Папулево	7	63	866	45.573574000000001	45.599947999999998	54.747906	54.733181999999999	0103000020E61000000100000005000000FFEA71DF6AC94640080264E8D85D4B40FFEA71DF6AC94640B83D4162BB5F4B407AA69718CBCC4640B83D4162BB5F4B407AA69718CBCC4640080264E8D85D4B40FFEA71DF6AC94640080264E8D85D4B40
33005	Оброчное	7	63	866	45.322288	45.358246999999999	54.666832999999997	54.656860000000002	0103000020E6100000010000000500000056F2B1BB40A9464079060DFD13544B4056F2B1BB40A946406072A3C85A554B40EF71A609DBAD46406072A3C85A554B40EF71A609DBAD464079060DFD13544B4056F2B1BB40A9464079060DFD13544B40
9019	Новые Ичалки	7	63	866	45.386895000000003	45.430095000000001	54.732615000000003	54.719169999999998	0103000020E6100000010000000500000033FE7DC685B14640D52137C30D5C4B4033FE7DC685B146408FC70C54C65D4B4029965B5A0DB746408FC70C54C65D4B4029965B5A0DB74640D52137C30D5C4B4033FE7DC685B14640D52137C30D5C4B40
8756	Лобаски	7	63	866	45.138348999999998	45.168182000000002	54.633853999999999	54.609740000000002	0103000020E610000001000000050000009737876BB59146401288D7F50B4E4B409737876BB59146402A38BC2022514B4050E3DEFC869546402A38BC2022514B4050E3DEFC869546401288D7F50B4E4B409737876BB59146401288D7F50B4E4B40
47964	Лада	7	63	866	45.412298999999997	45.451618000000003	54.601939000000002	54.566558000000001	0103000020E610000001000000050000003596B036C6B44640C2A4F8F884484B403596B036C6B44640EE974F560C4D4B4079245E9ECEB94640EE974F560C4D4B4079245E9ECEB94640C2A4F8F884484B403596B036C6B44640C2A4F8F884484B40
8230	Кергуды	7	63	866	45.180847999999997	45.205039999999997	54.722341999999998	54.704191000000002	0103000020E6100000010000000500000004C6FA06269746409B9141EE225A4B4004C6FA06269746407C43E1B3755C4B40982F2FC03E9A46407C43E1B3755C4B40982F2FC03E9A46409B9141EE225A4B4004C6FA06269746409B9141EE225A4B40
8180	Кендя	7	63	866	45.045544	45.072744999999998	54.729875999999997	54.714750000000002	0103000020E61000000100000005000000B743C362D4854640736891ED7C5B4B40B743C362D48546405111A7936C5D4B4048F949B54F8946405111A7936C5D4B4048F949B54F894640736891ED7C5B4B40B743C362D4854640736891ED7C5B4B40
6530	Кемля	7	63	866	45.212316000000001	45.270617000000001	54.708404000000002	54.673226	0103000020E610000001000000050000007235B22B2D9B4640906802452C564B407235B22B2D9B4640842D76FBAC5A4B40EE5EEE93A3A24640842D76FBAC5A4B40EE5EEE93A3A24640906802452C564B407235B22B2D9B4640906802452C564B40
48085	Камаево	7	63	866	45.518129999999999	45.550989999999999	54.609864999999999	54.597631	0103000020E61000000100000005000000CA89761552C24640B309302C7F4C4B40CA89761552C24640CEFC6A0E104E4B4026361FD786C64640CEFC6A0E104E4B4026361FD786C64640B309302C7F4C4B40CA89761552C24640B309302C7F4C4B40
8439	Ичалки	7	63	866	45.250520999999999	45.332771000000001	54.690361000000003	54.666826999999998	0103000020E6100000010000000500000009FB761211A046407E8B4E965A554B4009FB761211A0464089B7CEBF5D584B405307793D98AA464089B7CEBF5D584B405307793D98AA46407E8B4E965A554B4009FB761211A046407E8B4E965A554B40
56579	Инсаровка	7	63	866	45.384765999999999	45.408318999999999	54.600848999999997	54.564736000000003	0103000020E610000001000000050000006E4E250340B14640DB6FED4449484B406E4E250340B14640CA6ABA9EE84C4B40EFAA07CC43B44640CA6ABA9EE84C4B40EFAA07CC43B44640DB6FED4449484B406E4E250340B14640DB6FED4449484B40
56571	Инелей	7	63	866	45.716540000000002	45.738280000000003	54.738140999999999	54.722160000000002	0103000020E610000001000000050000004F232D95B7DB46405C3D27BD6F5C4B404F232D95B7DB46401A6B7F677B5E4B403CA583F57FDE46401A6B7F677B5E4B403CA583F57FDE46405C3D27BD6F5C4B404F232D95B7DB46405C3D27BD6F5C4B40
47979	Дубровское	7	63	866	45.401654000000001	45.436356000000004	54.661411999999999	54.643624000000003	0103000020E610000001000000050000005F27F56569B34640DA756F4562524B405F27F56569B346404A97FE25A9544B40EAB46E83DAB746404A97FE25A9544B40EAB46E83DAB74640DA756F4562524B405F27F56569B34640DA756F4562524B40
56542	Дубенки	7	63	866	45.639366000000003	45.658887	54.677750000000003	54.658475000000003	0103000020E610000001000000050000005116BEBED6D14640E71DA7E848544B405116BEBED6D14640986E1283C0564B403961C26856D44640986E1283C0564B403961C26856D44640E71DA7E848544B405116BEBED6D14640E71DA7E848544B40
47528	Гуляево	7	63	866	45.109594000000001	45.139175000000002	54.743713	54.723996	0103000020E610000001000000050000003EEB1A2D078E4640A837A3E6AB5C4B403EEB1A2D078E4640164ED2FC315F4B40DDB5847CD0914640164ED2FC315F4B40DDB5847CD0914640A837A3E6AB5C4B403EEB1A2D078E4640A837A3E6AB5C4B40
9440	Вечкусы	7	63	866	45.590192000000002	45.620879000000002	54.69558	54.674053999999998	0103000020E61000000100000005000000302E55698BCB464076DEC66647564B40302E55698BCB464037E0F3C308594B40F8E28BF678CF464037E0F3C308594B40F8E28BF678CF464076DEC66647564B40302E55698BCB464076DEC66647564B40
9864	Ведянцы	7	63	866	45.718255999999997	45.758122999999998	54.774566	54.753430000000002	0103000020E61000000100000005000000F01307D0EFDB4640A3E9EC6470604B40F01307D0EFDB4640F94B8BFA24634B4036ACA92C0AE14640F94B8BFA24634B4036ACA92C0AE14640A3E9EC6470604B40F01307D0EFDB4640A3E9EC6470604B40
8831	Большая Пестровка	7	63	866	45.234019000000004	45.279392999999999	54.570191000000001	54.554791000000002	0103000020E6100000010000000500000042D2A755F49D4640BD8E386403474B4042D2A755F49D46409DBCC804FC484B409CDD5A26C3A346409DBCC804FC484B409CDD5A26C3A34640BD8E386403474B4042D2A755F49D4640BD8E386403474B40
9609	Болдасево	7	63	866	45.527894000000003	45.573044000000003	54.720261999999998	54.698113999999997	0103000020E6100000010000000500000098E0D40792C346409B70AFCC5B594B4098E0D40792C346409946938B315C4B40A3957B8159C946409946938B315C4B40A3957B8159C946409B70AFCC5B594B4098E0D40792C346409B70AFCC5B594B40
9631	Береговые Сыреси	7	63	866	45.586914	45.624104000000003	54.744985999999997	54.725945000000003	0103000020E6100000010000000500000043C879FF1FCB4640EDD808C4EB5C4B4043C879FF1FCB46402AFD84B35B5F4B40C2A6CEA3E2CF46402AFD84B35B5F4B40C2A6CEA3E2CF4640EDD808C4EB5C4B4043C879FF1FCB4640EDD808C4EB5C4B40
58366	Баево	7	63	866	45.308219999999999	45.347997999999997	54.689928999999999	54.666826999999998	0103000020E610000001000000050000008FFCC1C073A746407E8B4E965A554B408FFCC1C073A74640EFC7ED974F584B406589CE328BAC4640EFC7ED974F584B406589CE328BAC46407E8B4E965A554B408FFCC1C073A746407E8B4E965A554B40
8084	Яндовище	7	63	903	44.552027000000002	44.567559000000003	53.902023999999997	53.893768000000001	0103000020E6100000010000000500000027C11BD2A84646400D1B65FD66F24A4027C11BD2A8464640821ABE8575F34A4076C6F7C5A5484640821ABE8575F34A4076C6F7C5A54846400D1B65FD66F24A4027C11BD2A84646400D1B65FD66F24A40
7970	Языкова Пятина	7	63	903	44.549162000000003	44.56888	53.792682999999997	53.769309999999997	0103000020E610000001000000050000005D1ABFF04A4646402D3E05C078E24A405D1ABFF04A4646402E8CF4A276E54A409BAC510FD14846402E8CF4A276E54A409BAC510FD14846402D3E05C078E24A405D1ABFF04A4646402D3E05C078E24A40
56577	Шадым-Рыскино	7	63	903	44.642110000000002	44.665188000000001	53.730384000000001	53.699401999999999	0103000020E61000000100000005000000A03715A930524640E560360186D94A40A03715A930524640C6C210397DDD4A4088D860E124554640C6C210397DDD4A4088D860E124554640E560360186D94A40A03715A930524640E560360186D94A40
7887	Челмодеевский Майдан	7	63	903	44.210030000000003	44.239333000000002	53.901918000000002	53.885151	0103000020E61000000100000005000000E6965643E21A4640C782C2A04CF14A40E6965643E21A46403DD68C0C72F34A4042EDB776A21E46403DD68C0C72F34A4042EDB776A21E4640C782C2A04CF14A40E6965643E21A4640C782C2A04CF14A40
7793	Старые Верхиссы	7	63	903	44.517802000000003	44.558998000000003	53.8748	53.861702000000001	0103000020E61000000100000005000000D6E6FF5547424640EB724A404CEE4A40D6E6FF554742464039454772F9EF4A40C443183F8D47464039454772F9EF4A40C443183F8D474640EB724A404CEE4A40D6E6FF5547424640EB724A404CEE4A40
7739	Сиалеевская Пятина	7	63	903	44.499575	44.535867000000003	53.824339999999999	53.804378	0103000020E610000001000000050000001973D712F23F46409ACFB9DBF5E64A401973D712F23F46406F641EF983E94A40B900344A974446406F641EF983E94A40B900344A974446409ACFB9DBF5E64A401973D712F23F46409ACFB9DBF5E64A40
7572	Русская Паевка	7	63	903	44.298864000000002	44.323846000000003	53.910170999999998	53.895651999999998	0103000020E61000000100000005000000D3F9F02C412646406A4C88B9A4F24A40D3F9F02C412646404162BB7B80F44A40607825C9732946404162BB7B80F44A40607825C9732946406A4C88B9A4F24A40D3F9F02C412646406A4C88B9A4F24A40
56587	Новые Верхисы	7	63	903	44.555612000000004	44.580871999999999	53.855924999999999	53.842449000000002	0103000020E61000000100000005000000F1A1444B1E47464022C66B5ED5EB4A40F1A1444B1E474640166A4DF38EED4A40C09481035A4A4640166A4DF38EED4A40C09481035A4A464022C66B5ED5EB4A40F1A1444B1E47464022C66B5ED5EB4A40
7538	Новлей	7	63	903	44.541696999999999	44.563948000000003	53.933492000000001	53.920253000000002	0103000020E61000000100000005000000B0ABC95356454640E085ADD9CAF54A40B0ABC95356454640F08975AA7CF74A408352B4722F484640F08975AA7CF74A408352B4722F484640E085ADD9CAF54A40B0ABC95356454640E085ADD9CAF54A40
56596	Нижняя Вязерка	7	63	903	44.442872999999999	44.480521000000003	53.838867999999998	53.826842999999997	0103000020E6100000010000000500000005A4FD0FB038464098F6CDFDD5E94A4005A4FD0FB038464099D4D00660EB4A4047054EB6813D464099D4D00660EB4A4047054EB6813D464098F6CDFDD5E94A4005A4FD0FB038464098F6CDFDD5E94A40
7434	Мордовская Паевка	7	63	903	44.251747999999999	44.271447999999999	53.750146999999998	53.733623000000001	0103000020E61000000100000005000000AD6A494739204640F54BC45BE7DD4A40AD6A494739204640A41820D104E04A404548DDCEBE224640A41820D104E04A404548DDCEBE224640F54BC45BE7DD4A40AD6A494739204640F54BC45BE7DD4A40
56582	Лухманский Майдан	7	63	903	44.142781999999997	44.177303999999999	53.750999	53.717401000000002	0103000020E610000001000000050000008E3A3AAE46124640118FC4CBD3DB4A408E3A3AAE46124640132A38BC20E04A4099B9C0E5B1164640132A38BC20E04A4099B9C0E5B1164640118FC4CBD3DB4A408E3A3AAE46124640118FC4CBD3DB4A40
7613	Кульмеж	7	63	903	44.285048000000003	44.305996999999998	53.886637	53.871513999999998	0103000020E6100000010000000500000026E5EE737C244640C90050C58DEF4A4026E5EE737C24464037363B527DF14A4049D6E1E82A27464037363B527DF14A4049D6E1E82A274640C90050C58DEF4A4026E5EE737C244640C90050C58DEF4A40
7258	Кочетовка	7	63	903	44.237904	44.276010999999997	53.807127000000001	53.785373999999997	0103000020E6100000010000000500000036CB65A3731E464079909E2287E44A4036CB65A3731E4640FB5B02F04FE74A400A2B155454234640FB5B02F04FE74A400A2B15545423464079909E2287E44A4036CB65A3731E464079909E2287E44A40
7482	Казеевка	7	63	903	44.387357000000002	44.410992	53.827469999999998	53.795513	0103000020E61000000100000005000000377007EA943146407C45B75ED3E54A40377007EA94314640E7357689EAE94A407575C7629B344640E7357689EAE94A407575C7629B3446407C45B75ED3E54A40377007EA943146407C45B75ED3E54A40
32694	Инсар	7	63	903	44.340411000000003	44.412672000000001	53.876137999999997	53.855001000000001	0103000020E610000001000000050000006E197096922B46400E863AAC70ED4A406E197096922B464034643C4A25F04A40CAFCA36FD234464034643C4A25F04A40CAFCA36FD23446400E863AAC70ED4A406E197096922B46400E863AAC70ED4A40
46839	Горки	7	63	903	44.289836000000001	44.302906999999998	53.829287999999998	53.824095	0103000020E610000001000000050000000B9A96581925464008E6E8F17BE94A400B9A9658192546408D7BF31B26EA4A405F5D15A8C52646408D7BF31B26EA4A405F5D15A8C526464008E6E8F17BE94A400B9A96581925464008E6E8F17BE94A40
7198	Верхняя Лухма	7	63	903	44.181489999999997	44.205781000000002	53.789315999999999	53.769959999999998	0103000020E61000000100000005000000884677103B174640349D9D0C8EE24A40884677103B174640D21A834E08E54A40B0912408571A4640D21A834E08E54A40B0912408571A4640349D9D0C8EE24A40884677103B174640349D9D0C8EE24A40
7300	Арбузовка	7	63	903	44.311422999999998	44.341723000000002	53.841248	53.821427	0103000020E61000000100000005000000711C78B5DC27464094861A8524E94A40711C78B5DC274640A7E9B303AEEB4A4040A54A94BD2B4640A7E9B303AEEB4A4040A54A94BD2B464094861A8524E94A40711C78B5DC27464094861A8524E94A40
4326	Ясная Поляна	7	63	475	42.821953000000001	42.843601999999997	54.130493999999999	54.118273000000002	0103000020E61000000100000005000000AFEC82C135694540FA7FD591230F4B40AFEC82C13569454080290307B4104B408B6B7C26FB6B454080290307B4104B408B6B7C26FB6B4540FA7FD591230F4B40AFEC82C135694540FA7FD591230F4B40
6469	Явас	7	63	475	42.823290999999998	42.866670999999997	54.425843999999998	54.409483000000002	0103000020E61000000100000005000000AA0B7899616945404DA25EF069344B40AA0B7899616945405299620E82364B4020B24813EF6E45405299620E82364B4020B24813EF6E45404DA25EF069344B40AA0B7899616945404DA25EF069344B40
56588	Школа Тракторных Бригадиров	7	63	475	42.164313999999997	43.181080999999999	54.508974000000002	53.733350999999999	0103000020E610000001000000050000003123BC3D0815454094BE1072DEDD4A403123BC3D08154540D5415E0F26414B40A77686A92D974540D5415E0F26414B40A77686A92D97454094BE1072DEDD4A403123BC3D0815454094BE1072DEDD4A40
6414	Ширингуши	7	63	475	42.748201000000002	42.795650000000002	53.861123999999997	53.837274000000001	0103000020E61000000100000005000000D1EAE40CC55F454043E55FCB2BEB4A40D1EAE40CC55F45407DE6AC4F39EE4A40FD87F4DBD76545407DE6AC4F39EE4A40FD87F4DBD765454043E55FCB2BEB4A40D1EAE40CC55F454043E55FCB2BEB4A40
6250	Умет	7	63	475	42.676785000000002	42.718207	54.129511999999998	54.104016000000001	0103000020E6100000010000000500000031B610E4A056454060217365500D4B4031B610E4A0564540433866D993104B400F61FC34EE5B4540433866D993104B400F61FC34EE5B454060217365500D4B4031B610E4A056454060217365500D4B40
5300	Ударный	7	63	475	42.848489000000001	42.861784	54.347813000000002	54.337741000000001	0103000020E6100000010000000500000004029D499B6C454059C2DA183B2B4B4004029D499B6C4540D40FEA22852C4B40A81B28F04E6E4540D40FEA22852C4B40A81B28F04E6E454059C2DA183B2B4B4004029D499B6C454059C2DA183B2B4B40
6190	Уголок	7	63	475	42.852764999999998	42.863517999999999	54.021737999999999	54.012729	0103000020E6100000010000000500000033164D67276D4540FB5A971AA1014B4033164D67276D45404C8A8F4FC8024B40F0C000C2876E45404C8A8F4FC8024B40F0C000C2876E4540FB5A971AA1014B4033164D67276D4540FB5A971AA1014B40
6171	Тарханская Потьма	7	63	475	42.960132000000002	42.992210999999998	53.942428	53.919341000000003	0103000020E61000000100000005000000EAEBF99AE57A45409C6F44F7ACF54A40EAEBF99AE57A4540D76A0F7BA1F84A40A0DD21C5007F4540D76A0F7BA1F84A40A0DD21C5007F45409C6F44F7ACF54A40EAEBF99AE57A45409C6F44F7ACF54A40
6100	Студенец	7	63	475	42.307039000000003	42.343753	54.169437000000002	54.155382000000003	0103000020E610000001000000050000005CCCCF0D4D2745408C31B08EE3134B405CCCCF0D4D274540BEDD921CB0154B4071732A19002C4540BEDD921CB0154B4071732A19002C45408C31B08EE3134B405CCCCF0D4D2745408C31B08EE3134B40
6044	Старое Бадиково	7	63	475	42.670972999999996	42.715718000000003	53.853014000000002	53.824886999999997	0103000020E61000000100000005000000DFBF7971E2554540A1F2AFE595E94A40DFBF7971E2554540DC8310902FED4A404B94BDA59C5B4540DC8310902FED4A404B94BDA59C5B4540A1F2AFE595E94A40DFBF7971E2554540A1F2AFE595E94A40
56556	Сосновка	7	63	475	42.868737000000003	42.898454000000001	54.276589000000001	54.258947999999997	0103000020E610000001000000050000009FE925C6326F4540ABAE433525214B409FE925C6326F454078B7B24467234B40EE7A698A0073454078B7B24467234B40EE7A698A00734540ABAE433525214B409FE925C6326F4540ABAE433525214B40
5351	Свеженькая	7	63	475	42.420738	42.447786999999998	54.012528000000003	54.000563	0103000020E610000001000000050000009C1727BEDA354540384BC97212004B409C1727BEDA35454064247B849A014B4077499C155139454064247B849A014B4077499C1551394540384BC97212004B409C1727BEDA354540384BC97212004B40
4793	Русский Лундан	7	63	475	42.882365	42.905217999999998	53.846666999999997	53.830691000000002	0103000020E6100000010000000500000049111956F1704540700A2B1554EA4A4049111956F17045401CCD91955FEC4A4011E0F42EDE7345401CCD91955FEC4A4011E0F42EDE734540700A2B1554EA4A4049111956F1704540700A2B1554EA4A40
5831	Потьма	7	63	475	42.889156	42.926400000000001	54.128093	54.109591000000002	0103000020E61000000100000005000000668522DDCF714540CD77F013070E4B40668522DDCF7145405BECF65965104B40D8817346947645405BECF65965104B40D881734694764540CD77F013070E4B40668522DDCF714540CD77F013070E4B40
5039	Покровские Селищи	7	63	475	42.991213999999999	43.013635000000001	54.013739000000001	53.987727	0103000020E610000001000000050000002EABB019E07E454027309DD66DFE4A402EABB019E07E454002D71533C2014B405D8AABCABE81454002D71533C2014B405D8AABCABE81454027309DD66DFE4A402EABB019E07E454027309DD66DFE4A40
5771	Подлясово	7	63	475	42.662016999999999	42.685704999999999	54.316004	54.292647000000002	0103000020E61000000100000005000000B1321AF9BC544540E222F77475254B40B1321AF9BC544540DDB3AED172284B4012DA722EC5574540DDB3AED172284B4012DA722EC5574540E222F77475254B40B1321AF9BC544540E222F77475254B40
5734	Пичпанда	7	63	475	42.945624000000002	42.979022999999998	53.880549000000002	53.860778000000003	0103000020E6100000010000000500000007280D350A794540E38E37F92DEE4A4007280D350A79454044C362D4B5F04A4012842BA0507D454044C362D4B5F04A4012842BA0507D4540E38E37F92DEE4A4007280D350A794540E38E37F92DEE4A40
6831	Парца	7	63	475	42.708891000000001	42.866869000000001	54.375314000000003	54.257196999999998	0103000020E61000000100000005000000E1B6B6F0BC5A45408DD0CFD4EB204B40E1B6B6F0BC5A454090DD054A0A304B4047753A90F56E454090DD054A0A304B4047753A90F56E45408DD0CFD4EB204B40E1B6B6F0BC5A45408DD0CFD4EB204B40
6771	Озерный	7	63	475	42.688040999999998	42.701255000000003	54.414957999999999	54.404352000000003	0103000020E6100000010000000500000050A73CBA115845403E096CCEC1334B4050A73CBA11584540569BFF571D354B4008944DB9C2594540569BFF571D354B4008944DB9C25945403E096CCEC1334B4050A73CBA115845403E096CCEC1334B40
5572	Новые Выселки	7	63	475	42.961281999999997	42.982714999999999	54.005453000000003	53.983105000000002	0103000020E61000000100000005000000E21DE0490B7B45405DC47762D6FD4A40E21DE0490B7B4540225514AFB2004B40F224E99AC97D4540225514AFB2004B40F224E99AC97D45405DC47762D6FD4A40E21DE0490B7B45405DC47762D6FD4A40
5505	Новое Бадиково	7	63	475	42.725402000000003	42.746125999999997	53.807679999999998	53.780937000000002	0103000020E61000000100000005000000FC3905F9D95C4540419E5DBEF5E34A40FC3905F9D95C45400FD1E80E62E74A40FF58880E815F45400FD1E80E62E74A40FF58880E815F4540419E5DBEF5E34A40FC3905F9D95C4540419E5DBEF5E34A40
5699	Новая Потьма	7	63	475	42.960158999999997	43.003889000000001	54.057909000000002	54.032808000000003	0103000020E61000000100000005000000E3FA777DE67A45400A86730D33044B40E3FA777DE67A45407192E68F69074B4036E84B6F7F8045407192E68F69074B4036E84B6F7F8045400A86730D33044B40E3FA777DE67A45400A86730D33044B40
5409	Мордовский Пимбур	7	63	475	43.119466000000003	43.159908000000001	53.862673999999998	53.845413000000001	0103000020E61000000100000005000000F27D71A94A8F45407F4E417E36EC4A40F27D71A94A8F4540048E041A6CEE4A40342F87DD77944540048E041A6CEE4A40342F87DD779445407F4E417E36EC4A40F27D71A94A8F45407F4E417E36EC4A40
5457	Мордовская Поляна	7	63	475	42.824513000000003	42.837547999999998	53.976523999999998	53.941325999999997	0103000020E610000001000000050000003D1059A489694540EF6FD05E7DF84A403D1059A4896945402AE109BDFEFC4A40446ADAC5346B45402AE109BDFEFC4A40446ADAC5346B4540EF6FD05E7DF84A403D1059A489694540EF6FD05E7DF84A40
5991	Молочница	7	63	475	42.868772999999997	42.897033999999998	54.243755999999998	54.230812	0103000020E61000000100000005000000EB5223F4336F45401EC3633F8B1D4B40EB5223F4336F4540151A8865331F4B4035B39602D2724540151A8865331F4B4035B39602D27245401EC3633F8B1D4B40EB5223F4336F45401EC3633F8B1D4B40
6726	Лесной	7	63	475	42.701543000000001	42.724980000000002	54.469175	54.457165000000003	0103000020E610000001000000050000006EDE3829CC5945401CF0F961843A4B406EDE3829CC594540E78C28ED0D3C4B4086200725CC5C4540E78C28ED0D3C4B4086200725CC5C45401CF0F961843A4B406EDE3829CC5945401CF0F961843A4B40
5234	Леплей	7	63	475	42.846423000000001	42.863571999999998	54.314574999999998	54.304715999999999	0103000020E6100000010000000500000086CABF96576C4540B24813EF00274B4086CABF96576C4540D1915CFE43284B40E3DEFC86896E4540D1915CFE43284B40E3DEFC86896E4540B24813EF00274B4086CABF96576C4540B24813EF00274B40
5190	Каргашино	7	63	475	42.598846999999999	42.619076999999997	54.218525999999997	54.185304000000002	0103000020E610000001000000050000006327BC04A74C4540B4E89D0AB8174B406327BC04A74C4540B0A9F3A8F81B4B40575A46EA3D4F4540B0A9F3A8F81B4B40575A46EA3D4F4540B4E89D0AB8174B406327BC04A74C4540B4E89D0AB8174B40
5080	Каргал	7	63	475	42.975977999999998	42.992283	53.987012999999997	53.969920000000002	0103000020E61000000100000005000000C8CEDBD8EC7C454040DEAB5626FC4A40C8CEDBD8EC7C454009DD257156FE4A403AB01C21037F454009DD257156FE4A403AB01C21037F454040DEAB5626FC4A40C8CEDBD8EC7C454040DEAB5626FC4A40
5142	Известь	7	63	475	42.433898999999997	42.454586999999997	53.943795000000001	53.929780999999998	0103000020E6100000010000000500000030629F008A37454099B8551003F74A4030629F008A3745406D904946CEF84A40E71725E82F3A45406D904946CEF84A40E71725E82F3A454099B8551003F74A4030629F008A37454099B8551003F74A40
4046	Зубова Поляна	7	63	475	42.797384000000001	42.864488000000001	54.098134999999999	54.059626999999999	0103000020E61000000100000005000000452DCDAD10664540B37A87DBA1074B40452DCDAD10664540E6CB0BB08F0C4B4069E4F38AA76E4540E6CB0BB08F0C4B4069E4F38AA76E4540B37A87DBA1074B40452DCDAD10664540B37A87DBA1074B40
4977	Зарубкино	7	63	475	42.998409000000002	43.00759	53.985047999999999	53.959887000000002	0103000020E610000001000000050000001B84B9DDCB7F4540836DC493DDFA4A401B84B9DDCB7F4540BF7E880D16FE4A4069E388B5F8804540BF7E880D16FE4A4069E388B5F8804540836DC493DDFA4A401B84B9DDCB7F4540836DC493DDFA4A40
4942	Журавкино	7	63	475	42.554955999999997	42.596260000000001	54.134507999999997	54.116025	0103000020E61000000100000005000000075C57CC084745405B423EE8D90E4B40075C57CC084745407286E28E37114B40DCF4673F524C45407286E28E37114B40DCF4673F524C45405B423EE8D90E4B40075C57CC084745405B423EE8D90E4B40
4876	Жуковка	7	63	475	42.714604000000001	42.744078000000002	53.879354999999997	53.866284999999998	0103000020E610000001000000050000009FCBD424785B4540F701486DE2EE4A409FCBD424785B45407B4963B48EF04A4028D6A9F23D5F45407B4963B48EF04A4028D6A9F23D5F4540F701486DE2EE4A409FCBD424785B4540F701486DE2EE4A40
4835	Дубитель	7	63	475	42.567514000000003	42.589773999999998	54.167523000000003	54.156241999999999	0103000020E61000000100000005000000D6027B4CA44845407D21E4BCFF134B40D6027B4CA4484540F629C76471154B40FB03E5B67D4B4540F629C76471154B40FB03E5B67D4B45407D21E4BCFF134B40D6027B4CA44845407D21E4BCFF134B40
2835	Горенка	7	63	475	42.889550999999997	42.906627999999998	53.868721999999998	53.854905000000002	0103000020E61000000100000005000000E28FA2CEDC714540EC17EC866DED4A40E28FA2CEDC71454069A8514832EF4A40A6D1E4620C74454069A8514832EF4A40A6D1E4620C744540EC17EC866DED4A40E28FA2CEDC714540EC17EC866DED4A40
4631	Выша	7	63	475	42.366678	42.384554000000001	53.858750000000001	53.837375000000002	0103000020E61000000100000005000000D314014EEF2E454077BE9F1A2FEB4A40D314014EEF2E454052B81E85EBED4A40E3C5C2103931454052B81E85EBED4A40E3C5C2103931454077BE9F1A2FEB4A40D314014EEF2E454077BE9F1A2FEB4A40
4662	Вадовские Селищи	7	63	475	42.626623000000002	42.651237000000002	54.290508000000003	54.271478999999999	0103000020E61000000100000005000000F1F5B52E355045408046E9D2BF224B40F1F5B52E35504540FA9CBB5D2F254B40FB78E8BB5B534540FA9CBB5D2F254B40FB78E8BB5B5345408046E9D2BF224B40F1F5B52E355045408046E9D2BF224B40
4568	Булдыгино	7	63	475	42.862575	42.893171000000002	53.907269999999997	53.889443999999997	0103000020E6100000010000000500000071AC8BDB686E4540CCCF0D4DD9F14A4071AC8BDB686E45402A52616C21F44A40295E656D537245402A52616C21F44A40295E656D53724540CCCF0D4DD9F14A4071AC8BDB686E4540CCCF0D4DD9F14A40
4504	Ачадово	7	63	475	42.990620999999997	43.015540000000001	53.919829	53.901493000000002	0103000020E610000001000000050000008BDD3EABCC7E45405649641F64F34A408BDD3EABCC7E4540C974E8F4BCF54A40D2E3F736FD814540C974E8F4BCF54A40D2E3F736FD8145405649641F64F34A408BDD3EABCC7E45405649641F64F34A40
4440	Анаево	7	63	475	42.544625000000003	42.582974	54.244624000000002	54.227922	0103000020E61000000100000005000000C1CAA145B6454540FB04508C2C1D4B40C1CAA145B64545408AE8D7D64F1F4B408B355CE49E4A45408AE8D7D64F1F4B408B355CE49E4A4540FB04508C2C1D4B40C1CAA145B6454540FB04508C2C1D4B40
5614	Аким-Сергеевка	7	63	475	42.879679000000003	42.899720000000002	54.054895999999999	54.040131000000002	0103000020E610000001000000050000002FFD4B529970454024473A0323054B402FFD4B5299704540325706D506074B4050C763062A734540325706D506074B4050C763062A73454024473A0323054B402FFD4B529970454024473A0323054B40
2741	Старые Пичингуши	7	63	466	43.824598999999999	43.841918	54.582256000000001	54.572367999999997	0103000020E610000001000000050000003BA8C4758CE9454072A3C85A43494B403BA8C4758CE945402CF3565D874A4B40F5F411F8C3EB45402CF3565D874A4B40F5F411F8C3EB454072A3C85A43494B403BA8C4758CE9454072A3C85A43494B40
52621	Старотештелимские Выселки	7	63	466	44.055653999999997	44.067385999999999	54.559933999999998	54.550973999999997	0103000020E610000001000000050000001FF296AB1F0746402079E75086464B401FF296AB1F07464090F5D4EAAB474B40A81ABD1AA008464090F5D4EAAB474B40A81ABD1AA00846402079E75086464B401FF296AB1F0746402079E75086464B40
3558	Стародевичье	7	63	466	43.747369999999997	43.783537000000003	54.596978999999997	54.575937000000003	0103000020E610000001000000050000007901F6D1A9DF454037C7B94DB8494B407901F6D1A9DF45400BB3D0CE694C4B405D1ABFF04AE445400BB3D0CE694C4B405D1ABFF04AE4454037C7B94DB8494B407901F6D1A9DF454037C7B94DB8494B40
3660	Софьино	7	63	466	43.930025000000001	43.954998000000003	54.700558999999998	54.684756	0103000020E6100000010000000500000030BB270F0BF74540B1DEA815A6574B4030BB270F0BF7454090F5D4EAAB594B406ADFDC5F3DFA454090F5D4EAAB594B406ADFDC5F3DFA4540B1DEA815A6574B4030BB270F0BF74540B1DEA815A6574B40
56564	Петровка	7	63	466	43.963343000000002	43.981247000000003	54.583174999999997	54.575577000000003	0103000020E610000001000000050000004FEACBD24EFB454037AAD381AC494B404FEACBD24EFB4540226C787AA54A4B4029266F8099FD4540226C787AA54A4B4029266F8099FD454037AAD381AC494B404FEACBD24EFB454037AAD381AC494B40
3299	Новый Ковыляй	7	63	466	43.644091000000003	43.673295000000003	54.798591999999999	54.790308000000003	0103000020E61000000100000005000000F052EA9271D2454033E202D028654B40F052EA9271D24540726C3D4338664B40B9C7D2872ED64540726C3D4338664B40B9C7D2872ED6454033E202D028654B40F052EA9271D2454033E202D028654B40
3521	Новые Пичингуши	7	63	466	43.688136	43.707026999999997	54.573573000000003	54.563535999999999	0103000020E61000000100000005000000A29927D714D84540300F99F221484B40A29927D714D845402F6F0ED76A494B40CA3159DC7FDA45402F6F0ED76A494B40CA3159DC7FDA4540300F99F221484B40A29927D714D84540300F99F221484B40
56591	Новоямская Слобода	7	63	466	43.723106999999999	43.738844999999998	54.749434000000001	54.730552000000003	0103000020E610000001000000050000001C412AC58EDC454082035ABA825D4B401C412AC58EDC454057410C74ED5F4B4014E8137992DE454057410C74ED5F4B4014E8137992DE454082035ABA825D4B401C412AC58EDC454082035ABA825D4B40
3920	Новоусадские Выселки	7	63	466	44.060657999999997	44.074851000000002	54.496568000000003	54.488639999999997	0103000020E61000000100000005000000D11E2FA4C30746403BC269C18B3E4B40D11E2FA4C3074640BD1E4C8A8F3F4B405589B2B794094640BD1E4C8A8F3F4B405589B2B7940946403BC269C18B3E4B40D11E2FA4C30746403BC269C18B3E4B40
3628	Новоникольское	7	63	466	44.016057000000004	44.046976999999998	54.696292999999997	54.669195999999999	0103000020E610000001000000050000009AEFE0270E024640984EEB36A8554B409AEFE0270E02464084B7072120594B400455A3570306464084B7072120594B400455A35703064640984EEB36A8554B409AEFE0270E024640984EEB36A8554B40
3951	Новодевичье	7	63	466	43.950218999999997	43.993194000000003	54.576338999999997	54.564272000000003	0103000020E61000000100000005000000D784B4C6A0F9454036069D103A484B40D784B4C6A0F945406534F279C5494B40AE4A22FB20FF45406534F279C5494B40AE4A22FB20FF454036069D103A484B40D784B4C6A0F9454036069D103A484B40
3723	Надеждино	7	63	466	44.062489999999997	44.087356	54.645135000000003	54.626099000000004	0103000020E61000000100000005000000DC291DACFF0746407787140324504B40DC291DACFF074640A3409FC893524B40008E3D7B2E0B4640A3409FC893524B40008E3D7B2E0B46407787140324504B40DC291DACFF0746407787140324504B40
3340	Мордовское Корино	7	63	466	43.642159999999997	43.655464000000002	54.686703000000001	54.678541000000003	0103000020E610000001000000050000005166834C32D2454061FF756EDA564B405166834C32D24540558847E2E5574B4049DA8D3EE6D34540558847E2E5574B4049DA8D3EE6D3454061FF756EDA564B405166834C32D2454061FF756EDA564B40
3852	Мордовско-Маскинские Выселки	7	63	466	43.943705999999999	43.960118000000001	54.514614000000002	54.507066000000002	0103000020E61000000100000005000000FD84B35BCBF84540EF74E789E7404B40FD84B35BCBF8454029081EDFDE414B4085268925E5FA454029081EDFDE414B4085268925E5FA4540EF74E789E7404B40FD84B35BCBF84540EF74E789E7404B40
3824	Каньгуши	7	63	466	43.776099000000002	43.799607000000002	54.541767	54.527400999999998	0103000020E61000000100000005000000AABA473657E3454058703FE081434B40AABA473657E34540A986FD9E58454B408B53AD8559E64540A986FD9E58454B408B53AD8559E6454058703FE081434B40AABA473657E3454058703FE081434B40
2864	Ельники	7	63	466	43.832261000000003	43.889716999999997	54.639189999999999	54.605061999999997	0103000020E610000001000000050000003E5E488787EA4540B306EFAB724D4B403E5E488787EA454012F758FAD0514B40FDD8243FE2F1454012F758FAD0514B40FDD8243FE2F14540B306EFAB724D4B403E5E488787EA4540B306EFAB724D4B40
3449	Вачеевка	7	63	466	43.696767999999999	43.707287999999998	54.635750999999999	54.628742000000003	0103000020E610000001000000050000001D739EB12FD9454092CF2B9E7A504B401D739EB12FD945401CB3EC4960514B40376DC66988DA45401CB3EC4960514B40376DC66988DA454092CF2B9E7A504B401D739EB12FD9454092CF2B9E7A504B40
3189	Большой Уркат	7	63	466	43.836545999999998	43.864770999999998	54.691678000000003	54.678213	0103000020E61000000100000005000000C0CC77F013EB45406C5CFFAECF564B40C0CC77F013EB45406DAE9AE788584B40BDC3EDD0B0EE45406DAE9AE788584B40BDC3EDD0B0EE45406C5CFFAECF564B40C0CC77F013EB45406C5CFFAECF564B40
3414	Большие Мордовские Пошаты	7	63	466	43.690911	43.707431	54.668478	54.651021	0103000020E610000001000000050000002CB98AC56FD845402E01F8A754534B402CB98AC56FD84540390CE6AF90554B409A9658198DDA4540390CE6AF90554B409A9658198DDA45402E01F8A754534B402CB98AC56FD845402E01F8A754534B40
3750	Алексеевка	7	63	466	44.136305	44.157065000000003	54.625098000000001	54.620136000000002	0103000020E6100000010000000500000001A43671721146404089CF9D604F4B4001A4367172114640C365153603504B40522CB7B41A144640C365153603504B40522CB7B41A1446404089CF9D604F4B4001A43671721146404089CF9D604F4B40
3103	Акчеево	7	63	466	43.734910999999997	43.752876999999998	54.641967000000001	54.632077000000002	0103000020E610000001000000050000003E3C4B9011DE4540E3C62DE6E7504B403E3C4B9011DE45403D0E83F92B524B408E7406465EE045403D0E83F92B524B408E7406465EE04540E3C62DE6E7504B403E3C4B9011DE4540E3C62DE6E7504B40
2705	Чиндяново	7	63	321	46.380538999999999	46.40889	54.475757000000002	54.451684999999998	0103000020E6100000010000000500000020ED7F80B5304740008C67D0D0394B4020ED7F80B5304740EAEBF99AE53C4B40AAD4EC8156344740EAEBF99AE53C4B40AAD4EC8156344740008C67D0D0394B4020ED7F80B5304740008C67D0D0394B40
2633	Чеберчино	7	63	321	46.454937999999999	46.489702000000001	54.380107000000002	54.350043999999997	0103000020E6100000010000000500000094DA8B683B3A47409C14E63DCE2C4B4094DA8B683B3A474087FD9E58A7304B4095641D8EAE3E474087FD9E58A7304B4095641D8EAE3E47409C14E63DCE2C4B4094DA8B683B3A47409C14E63DCE2C4B40
2597	Пуркаево	7	63	321	46.609088999999997	46.661423999999997	54.381570000000004	54.366481	0103000020E610000001000000050000003AADDBA0F64D47407DCD72D9E82E4B403AADDBA0F64D47403F912749D7304B400E65A88AA95447403F912749D7304B400E65A88AA95447407DCD72D9E82E4B403AADDBA0F64D47407DCD72D9E82E4B40
2406	Поводимово	7	63	321	46.278410000000001	46.340437999999999	54.480679000000002	54.454464000000002	0103000020E610000001000000050000008F705AF0A2234740CC9A58E02B3A4B408F705AF0A2234740DF6FB4E3863D4B406728EE78932B4740DF6FB4E3863D4B406728EE78932B4740CC9A58E02B3A4B408F705AF0A2234740CC9A58E02B3A4B40
49483	Неклюдово	7	63	321	46.124906000000003	46.138758000000003	54.358480999999998	54.347535000000001	0103000020E610000001000000050000007F8978EBFC0F4740919BE1067C2C4B407F8978EBFC0F4740629E95B4E22D4B40790778D2C2114740629E95B4E22D4B40790778D2C2114740919BE1067C2C4B407F8978EBFC0F4740919BE1067C2C4B40
2251	Морга	7	63	321	46.430889999999998	46.472760000000001	54.414078000000003	54.391357999999997	0103000020E6100000010000000500000033164D67273747409483D90418324B4033164D67273747401EFF058200354B40B16D5166833C47401EFF058200354B40B16D5166833C47409483D90418324B4033164D67273747409483D90418324B40
2148	Ломаты	7	63	321	46.112912999999999	46.148665999999999	54.383741000000001	54.349640000000001	0103000020E610000001000000050000008925E5EE730E4740CDAFE600C12C4B408925E5EE730E47403291D26C1E314B407903CC7C071347403291D26C1E314B407903CC7C07134740CDAFE600C12C4B408925E5EE730E4740CDAFE600C12C4B40
49459	Красино	7	63	321	46.420613000000003	46.452790999999998	54.375717999999999	54.353628	0103000020E61000000100000005000000E0A293A5D63547409679ABAE432D4B40E0A293A5D63547405F42058717304B402976340EF53947405F42058717304B402976340EF53947409679ABAE432D4B40E0A293A5D63547409679ABAE432D4B40
1940	Кайбичево	7	63	321	46.228929999999998	46.276980999999999	54.351202999999998	54.326101999999999	0103000020E61000000100000005000000618907944D1D47408194D8B5BD294B40618907944D1D4740E8A04B38F42C4B40834E081D74234740E8A04B38F42C4B40834E081D742347408194D8B5BD294B40618907944D1D47408194D8B5BD294B40
32695	Дубенки	7	63	321	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
62111	Березовское сельское поселение	7	63	321	\N	\N	\N	\N	\N
49581	Антоновка	7	63	321	46.248252999999998	46.290841999999998	54.515340000000002	54.507542000000001	0103000020E6100000010000000500000023111AC1C61F474058ACE122F7404B4023111AC1C61F47400B293FA9F6414B40D026874F3A2547400B293FA9F6414B40D026874F3A25474058ACE122F7404B4023111AC1C61F474058ACE122F7404B40
50005	Чукалы	7	63	226	45.504655	45.532808000000003	55.043861	55.028588999999997	0103000020E61000000100000005000000A661F88898C046403E03EACDA8834B40A661F88898C04640F148BC3C9D854B400A86730D33C44640F148BC3C9D854B400A86730D33C446403E03EACDA8834B40A661F88898C046403E03EACDA8834B40
6949	Хухорево	7	63	226	45.831263999999997	45.853389999999997	54.969895000000001	54.955334000000001	0103000020E61000000100000005000000CB2BD7DB66EA4640E1606F62487A4B40CB2BD7DB66EA4640E7C6F484257C4B40E15D2EE23BED4640E7C6F484257C4B40E15D2EE23BED4640E1606F62487A4B40CB2BD7DB66EA4640E1606F62487A4B40
1261	Старые Селищи	7	63	226	45.441457999999997	45.468038999999997	55.049235000000003	55.024306000000003	0103000020E610000001000000050000005E471CB281B846405D8C81751C834B405E471CB281B84640C7681D554D864B405320B3B3E8BB4640C7681D554D864B405320B3B3E8BB46405D8C81751C834B405E471CB281B846405D8C81751C834B40
1008	Старое Чамзино	7	63	226	45.612029999999997	45.628649000000003	55.074596999999997	55.051957999999999	0103000020E61000000100000005000000DF15C1FF56CE4640FE614B8FA6864B40DF15C1FF56CE46409AB0FD648C894B40E1D4079277D046409AB0FD648C894B40E1D4079277D04640FE614B8FA6864B40DF15C1FF56CE4640FE614B8FA6864B40
50004	Спасское	7	63	226	45.660521000000003	45.683689000000001	55.130971000000002	55.118014000000002	0103000020E610000001000000050000001EA9BEF38BD446402E3C2F151B8F4B401EA9BEF38BD44640BADC60A8C3904B4046D1031F83D74640BADC60A8C3904B4046D1031F83D746402E3C2F151B8F4B401EA9BEF38BD446402E3C2F151B8F4B40
22597	Протасово	7	63	226	45.482475000000001	45.510772000000003	54.969135000000001	54.954579000000003	0103000020E610000001000000050000009D11A5BDC1BD4640653909A52F7A4B409D11A5BDC1BD464059349D9D0C7C4B4034DB15FA60C1464059349D9D0C7C4B4034DB15FA60C14640653909A52F7A4B409D11A5BDC1BD4640653909A52F7A4B40
15620	Новое Качаево	7	63	226	45.586851000000003	45.615955999999997	54.934153000000002	54.912578000000003	0103000020E61000000100000005000000FD4FFEEE1DCB464049861C5BCF744B40FD4FFEEE1DCB4640EB3A545392774B4032E36DA5D7CE4640EB3A545392774B4032E36DA5D7CE464049861C5BCF744B40FD4FFEEE1DCB464049861C5BCF744B40
19361	Новое Баево	7	63	226	45.719676	45.745807999999997	54.896743999999998	54.887269000000003	0103000020E61000000100000005000000A9DBD9571EDC464098E0D40792714B40A9DBD9571EDC46402E71E481C8724B402E8CF4A276DF46402E71E481C8724B402E8CF4A276DF464098E0D40792714B40A9DBD9571EDC464098E0D40792714B40
56580	Новая Александровка	7	63	226	45.445383999999997	45.465353	54.897784999999999	54.883954000000003	0103000020E61000000100000005000000B114C95702B946408E95986725714B40B114C95702B9464070EB6E9EEA724B40390CE6AF90BB464070EB6E9EEA724B40390CE6AF90BB46408E95986725714B40B114C95702B946408E95986725714B40
12278	Кучкаево	7	63	226	45.672271000000002	45.704216000000002	55.038423000000002	55.020274999999998	0103000020E610000001000000050000004D86E3F90CD6464094F6065F98824B404D86E3F90CD6464005357C0BEB844B40F4A8F8BF23DA464005357C0BEB844B40F4A8F8BF23DA464094F6065F98824B404D86E3F90CD6464094F6065F98824B40
49603	Красная Нива	7	63	226	45.668975000000003	45.686751999999998	54.991365999999999	54.979139000000004	0103000020E61000000100000005000000BA6B09F9A0D546407C9E3F6D547D4B40BA6B09F9A0D54640E42EC214E57E4B40363B527DE7D74640E42EC214E57E4B40363B527DE7D746407C9E3F6D547D4B40BA6B09F9A0D546407C9E3F6D547D4B40
58364	Козловка	7	63	226	45.785907999999999	45.808923	54.877800999999998	54.867896000000002	0103000020E6100000010000000500000017D522A298E44640242A5437176F4B4017D522A298E44640B3B27DC85B704B40B9FDF2C98AE74640B3B27DC85B704B40B9FDF2C98AE74640242A5437176F4B4017D522A298E44640242A5437176F4B40
47731	Калыша	7	63	226	45.492483	45.518669000000003	54.901936999999997	54.893047000000003	0103000020E61000000100000005000000016BD5AE09BF46403D65355D4F724B40016BD5AE09BF4640B306EFAB72734B407A39ECBE63C24640B306EFAB72734B407A39ECBE63C246403D65355D4F724B40016BD5AE09BF46403D65355D4F724B40
2414	Вармазейка	7	63	226	45.541907999999999	45.580534999999998	54.976612000000003	54.966551000000003	0103000020E610000001000000050000006BB8C83D5DC54640437573F1B77B4B406BB8C83D5DC54640CA703C9F017D4B4078978BF84ECA4640CA703C9F017D4B4078978BF84ECA4640437573F1B77B4B406BB8C83D5DC54640437573F1B77B4B40
1673	Большое Игнатово	7	63	226	45.550918000000003	45.591799999999999	55.033526999999999	55.007157999999997	0103000020E610000001000000050000008D63247B84C64640CFF3A78DEA804B408D63247B84C646403944DC9C4A844B40EBE2361AC0CB46403944DC9C4A844B40EBE2361AC0CB4640CFF3A78DEA804B408D63247B84C64640CFF3A78DEA804B40
1132	Аржадеево	7	63	226	45.599606999999999	45.635368999999997	55.115028000000002	55.103008000000003	0103000020E61000000100000005000000F1B913ECBFCC4640FA9CBB5D2F8D4B40F1B913ECBFCC4640E90FCD3CB98E4B4034F279C553D14640E90FCD3CB98E4B4034F279C553D14640FA9CBB5D2F8D4B40F1B913ECBFCC4640FA9CBB5D2F8D4B40
780	Шугурово	7	63	67	46.064844000000001	46.129460000000002	54.281314999999999	54.255166000000003	0103000020E61000000100000005000000C1ABE5CE4C0847408C868C47A9204B40C1ABE5CE4C084740E76F422102244B40F111312592104740E76F422102244B40F1113125921047408C868C47A9204B40C1ABE5CE4C0847408C868C47A9204B40
739	Черная Промза	7	63	67	46.236080999999999	46.266542999999999	54.286177000000002	54.271495000000002	0103000020E610000001000000050000007E1AF7E6371E474086032159C0224B407E1AF7E6371E474007EFAB72A1244B4026FDBD141E22474007EFAB72A1244B4026FDBD141E22474086032159C0224B407E1AF7E6371E474086032159C0224B40
658	Тазино	7	63	67	46.061619	46.09554	54.319448999999999	54.302309000000001	0103000020E61000000100000005000000F7E7A221E3074740AB24B20FB2264B40F7E7A221E3074740B5DE6FB4E3284B40DCBA9BA73A0C4740B5DE6FB4E3284B40DCBA9BA73A0C4740AB24B20FB2264B40F7E7A221E3074740AB24B20FB2264B40
280	Судосево	7	63	67	45.777455000000003	45.835656999999998	54.162072999999999	54.146518	0103000020E610000001000000050000004C8E3BA583E346403E23111AC1124B404C8E3BA583E346404548DDCEBE144B4034D6FECEF6EA46404548DDCEBE144B4034D6FECEF6EA46403E23111AC1124B404C8E3BA583E346403E23111AC1124B40
623	Старые Найманы	7	63	67	45.923270000000002	45.940992999999999	54.283607000000003	54.245403000000003	0103000020E6100000010000000500000060B01BB62DF646408FAB915D691F4B4060B01BB62DF6464056F5F23B4D244B40E961687572F8464056F5F23B4D244B40E961687572F846408FAB915D691F4B4060B01BB62DF646408FAB915D691F4B40
526	Симкино	7	63	67	46.15596	46.189655999999999	54.262087999999999	54.245977000000003	0103000020E61000000100000005000000F9BD4D7FF6134740BB48A12C7C1F4B40F9BD4D7FF613474047567E198C214B40BEBED6A54618474047567E198C214B40BEBED6A546184740BB48A12C7C1F4B40F9BD4D7FF6134740BB48A12C7C1F4B40
507	Русские Найманы	7	63	67	46.036690999999998	46.079774	54.239967999999998	54.223700999999998	0103000020E610000001000000050000005D876A4AB20447408F8AFF3BA21C4B405D876A4AB2044740130B7C45B71E4B401A89D008360A4740130B7C45B71E4B401A89D008360A47408F8AFF3BA21C4B405D876A4AB20447408F8AFF3BA21C4B40
56578	Присурский	7	63	67	45.571489	46.331895000000003	54.378695999999998	54.021098000000002	0103000020E610000001000000050000000A83328D26C946406901DA56B3024B400A83328D26C9464021904B1C79304B405C5A0D897B2A474021904B1C79304B405C5A0D897B2A47406901DA56B3024B400A83328D26C946406901DA56B3024B40
232	Починки	7	63	67	45.835441000000003	45.868841000000003	54.211196999999999	54.198937000000001	0103000020E61000000100000005000000685E0EBBEFEA4640707B82C476194B40685E0EBBEFEA4640B401D880081B4B404436902E36EF4640B401D880081B4B404436902E36EF4640707B82C476194B40685E0EBBEFEA4640707B82C476194B40
144	Пермиси	7	63	67	45.796356000000003	45.841631	54.104734000000001	54.083168999999998	0103000020E6100000010000000500000098FC4FFEEEE5464040852348A50A4B4098FC4FFEEEE54640BF6378EC670D4B405F268A90BAEB4640BF6378EC670D4B405F268A90BAEB464040852348A50A4B4098FC4FFEEEE5464040852348A50A4B40
363	Паракино	7	63	67	46.165581000000003	46.215698000000003	54.315871999999999	54.284495	0103000020E6100000010000000500000064EB19C231154740117008556A244B4064EB19C2311547406EDC627E6E284B4004E8F7FD9B1B47406EDC627E6E284B4004E8F7FD9B1B4740117008556A244B4064EB19C231154740117008556A244B40
32255	Николаевка	7	63	67	46.002446999999997	46.042934000000002	54.153221000000002	54.139629999999997	0103000020E61000000100000005000000957CEC2E500047402EC55565DF114B40957CEC2E50004740BC07E8BE9C134B4078F17EDC7E054740BC07E8BE9C134B4078F17EDC7E0547402EC55565DF114B40957CEC2E500047402EC55565DF114B40
82	Марьяновка	7	63	67	45.896625999999998	45.937652	54.142341000000002	54.126758000000002	0103000020E61000000100000005000000245F09A4C4F24640D1402C9B39104B40245F09A4C4F24640A2F0D93A38124B40B68311FB04F84640A2F0D93A38124B40B68311FB04F84640D1402C9B39104B40245F09A4C4F24640D1402C9B39104B40
32212	Мариуполь	7	63	67	45.937857999999999	45.957082	54.213597999999998	54.196651000000003	0103000020E610000001000000050000005F251FBB0BF84640E4DC26DC2B194B405F251FBB0BF84640D93EE42D571B4B408ECBB8A981FA4640D93EE42D571B4B408ECBB8A981FA4640E4DC26DC2B194B405F251FBB0BF84640E4DC26DC2B194B40
32469	Косогоры	7	63	67	45.758913999999997	45.800846999999997	54.224006000000003	54.205604999999998	0103000020E61000000100000005000000FF3C0D1824E146407172BF43511A4B40FF3C0D1824E14640CC0D863AAC1C4B40C30C8D2782E64640CC0D863AAC1C4B40C30C8D2782E646407172BF43511A4B40FF3C0D1824E146407172BF43511A4B40
56602	Елизаветинка	7	63	67	45.876520999999997	45.895744999999998	54.243414000000001	54.228811999999998	0103000020E61000000100000005000000ECA012D731F0464057772CB6491D4B40ECA012D731F04640BCB1A030281F4B401B47ACC5A7F24640BCB1A030281F4B401B47ACC5A7F2464057772CB6491D4B40ECA012D731F0464057772CB6491D4B40
32386	Дегилевка	7	63	67	45.667582000000003	45.693058000000001	54.167006999999998	54.147266999999999	0103000020E61000000100000005000000FBB2B45373D54640D86322A5D9124B40FBB2B45373D54640FE99417C60154B40971DE21FB6D84640FE99417C60154B40971DE21FB6D84640D86322A5D9124B40FBB2B45373D54640D86322A5D9124B40
32355	Гузынцы	7	63	67	45.679934000000003	45.718642000000003	54.197262000000002	54.178465000000003	0103000020E6100000010000000500000020B8CA1308D74640863DEDF0D7164B4020B8CA1308D746402D5F97E13F194B401AC40776FCDB46402D5F97E13F194B401AC40776FCDB4640863DEDF0D7164B4020B8CA1308D74640863DEDF0D7164B40
32316	Гарт	7	63	67	45.608472999999996	45.655949	54.152161	54.137272000000003	0103000020E61000000100000005000000DFBF7971E2CD46400954FF2092114B40DFBF7971E2CD4640035DFB027A134B40056C0723F6D34640035DFB027A134B40056C0723F6D346400954FF2092114B40DFBF7971E2CD46400954FF2092114B40
408	Бузаево	7	63	67	46.150075999999999	46.176783	54.337899	54.318697999999998	0103000020E610000001000000050000000EF5BBB0351347407AA69718CB284B400EF5BBB035134740F12C4146402B4B4090BE49D3A0164740F12C4146402B4B4090BE49D3A01647407AA69718CB284B400EF5BBB0351347407AA69718CB284B40
31954	Большие Березники	7	63	67	45.939287	45.993265999999998	54.187116000000003	54.162841999999998	0103000020E610000001000000050000006B47718E3AF846402635B401D8144B406B47718E3AF846407847C66AF3174B40471D1D5723FF46407847C66AF3174B40471D1D5723FF46402635B401D8144B406B47718E3AF846402635B401D8144B40
31863	Шейн-Майдан	7	63	270	46.090733999999998	46.137284000000001	54.503050999999999	54.47842	0103000020E610000001000000050000005051F52B9D0B47404CE0D6DD3C3D4B405051F52B9D0B47402C9CA4F963404B40CD21A985921147402C9CA4F963404B40CD21A985921147404CE0D6DD3C3D4B405051F52B9D0B47404CE0D6DD3C3D4B40
30894	Чукалы-на-Вежне	7	63	270	45.777957999999998	45.820771999999998	54.725971000000001	54.713729999999998	0103000020E61000000100000005000000AED4B32094E34640481630815B5B4B40AED4B32094E34640166C239EEC5C4B407BBC900E0FE94640166C239EEC5C4B407BBC900E0FE94640481630815B5B4B40AED4B32094E34640481630815B5B4B40
48528	Челпаново	7	63	270	45.787947000000003	45.822074000000001	54.609380000000002	54.593119000000002	0103000020E610000001000000050000009CFD8172DBE4464070D1C952EB4B4B409CFD8172DBE44640126BF129004E4B402A7288B839E94640126BF129004E4B402A7288B839E9464070D1C952EB4B4B409CFD8172DBE4464070D1C952EB4B4B40
48330	Тетюши	7	63	270	46.016919000000001	46.055196000000002	54.580064999999998	54.567425	0103000020E610000001000000050000002CD7DB662A02474066F7E461A1484B402CD7DB662A024740F146E6913F4A4B405D6F9BA910074740F146E6913F4A4B405D6F9BA91007474066F7E461A1484B402CD7DB662A02474066F7E461A1484B40
48676	Тарасово	7	63	270	46.226748000000001	46.258358999999999	54.592691000000002	54.569346000000003	0103000020E610000001000000050000007A371614061D4740E10D6954E0484B407A371614061D474018D1764CDD4B4B404AD05FE81121474018D1764CDD4B4B404AD05FE811214740E10D6954E0484B407A371614061D4740E10D6954E0484B40
6041	Тазнеево	7	63	270	45.746167	45.769568	54.637262	54.613379000000002	0103000020E610000001000000050000005E2D776682DF4640CF86FC33834E4B405E2D776682DF4640E57D1CCD91514B402906483481E24640E57D1CCD91514B402906483481E24640CF86FC33834E4B405E2D776682DF4640CF86FC33834E4B40
31808	Сосуновка	7	63	270	46.119013000000002	46.153830999999997	54.693123999999997	54.677962999999998	0103000020E61000000100000005000000416667D13B0F4740F372D87DC7564B40416667D13B0F47404E098849B8584B40340EF5BBB01347404E098849B8584B40340EF5BBB0134740F372D87DC7564B40416667D13B0F4740F372D87DC7564B40
31621	Селищи	7	63	270	46.242818	46.271304000000001	54.659917	54.640476999999997	0103000020E61000000100000005000000A87004A9141F47408B6B7C26FB514B40A87004A9141F47408789062978544B4012A3E716BA2247408789062978544B4012A3E716BA2247408B6B7C26FB514B40A87004A9141F47408B6B7C26FB514B40
31559	Сабанчеево	7	63	270	46.268825	46.297336999999999	54.592221000000002	54.572467000000003	0103000020E6100000010000000500000071AC8BDB682247400685419946494B4071AC8BDB682247409180D1E5CD4B4B40047289230F2647409180D1E5CD4B4B40047289230F2647400685419946494B4071AC8BDB682247400685419946494B40
31478	Русские Дубровки	7	63	270	45.892619000000003	45.930410999999999	54.530990000000003	54.507880999999998	0103000020E61000000100000005000000E564E25641F2464040A19E3E02414B40E564E25641F246406440F67AF7434B40596B28B517F746406440F67AF7434B40596B28B517F7464040A19E3E02414B40E564E25641F2464040A19E3E02414B40
48578	Покровское	7	63	270	45.820214999999997	45.843516999999999	54.775843999999999	54.763077000000003	0103000020E6100000010000000500000025581CCEFCE8464037AAD381AC614B4025581CCEFCE846401F662FDB4E634B405D4F745DF8EB46401F662FDB4E634B405D4F745DF8EB464037AAD381AC614B4025581CCEFCE8464037AAD381AC614B40
31157	Пилесево	7	63	270	45.926071999999998	45.961179000000001	54.720106000000001	54.702421999999999	0103000020E61000000100000005000000E3DEFC8689F64640D6FECEF6E8594B40E3DEFC8689F64640A2D3F36E2C5C4B400E4DD9E907FB4640A2D3F36E2C5C4B400E4DD9E907FB4640D6FECEF6E8594B40E3DEFC8689F64640D6FECEF6E8594B40
56570	Низовка	7	63	270	45.735944000000003	45.756425999999998	54.711868000000003	54.700907999999998	0103000020E61000000100000005000000FED7B96933DE46409CC0745AB7594B40FED7B96933DE4640D388997D1E5B4B400BEC3191D2E04640D388997D1E5B4B400BEC3191D2E046409CC0745AB7594B40FED7B96933DE46409CC0745AB7594B40
31396	Наборные Сыреси	7	63	270	45.851108000000004	45.880070000000003	54.685735000000001	54.663936999999997	0103000020E6100000010000000500000097AE601BF1EC46405BCD3AE3FB544B4097AE601BF1EC46407D5C1B2AC6574B406A183E22A6F046407D5C1B2AC6574B406A183E22A6F046405BCD3AE3FB544B4097AE601BF1EC46405BCD3AE3FB544B40
18136	Мордовские Сыреси	7	63	270	46.434348	46.470829000000002	54.576407000000003	54.562747999999999	0103000020E61000000100000005000000A08A1BB798374740D8F15F2008484B40A08A1BB798374740BE175FB4C7494B401381EA1F443C4740BE175FB4C7494B401381EA1F443C4740D8F15F2008484B40A08A1BB798374740D8F15F2008484B40
31601	Мордовские Дубровки	7	63	270	46.285794000000003	46.314979999999998	54.598882000000003	54.572507999999999	0103000020E610000001000000050000004FB2D5E594244740645930F147494B404FB2D5E594244740E014562AA84C4B407172BF4351284740E014562AA84C4B407172BF4351284740645930F147494B404FB2D5E594244740645930F147494B40
3548	Лобаски	7	63	270	45.71116	45.750506000000001	54.657088999999999	54.631191000000001	0103000020E61000000100000005000000971C774A07DB4640C843DFDDCA504B40971C774A07DB4640DAC70A7E1B544B40D4B9A29410E04640DAC70A7E1B544B40D4B9A29410E04640C843DFDDCA504B40971C774A07DB4640C843DFDDCA504B40
1587	Капасово	7	63	270	46.161180000000002	46.198279999999997	54.560549999999999	54.541511	0103000020E610000001000000050000007862D68BA11447404EB6813B50454B407862D68BA1144740EBE2361AC0474B40B6B9313D61194740EBE2361AC0474B40B6B9313D611947404EB6813B50454B407862D68BA11447404EB6813B50454B40
56573	Знаменское	7	63	270	45.834282999999999	45.851179999999999	54.788060999999999	54.774222999999999	0103000020E61000000100000005000000EC4D0CC9C9EA4640CF6740BD19634B40EC4D0CC9C9EA46406420CF2EDF644B4030815B77F3EC46406420CF2EDF644B4030815B77F3EC4640CF6740BD19634B40EC4D0CC9C9EA4640CF6740BD19634B40
30989	Дюрки	7	63	270	46.340994999999999	46.382812000000001	54.661301999999999	54.636887000000002	0103000020E61000000100000005000000BD8C62B9A52B4740B01F628385514B40BD8C62B9A52B4740C3633F8BA5544B401842CEFBFF304740C3633F8BA5544B401842CEFBFF304740B01F628385514B40BD8C62B9A52B4740B01F628385514B40
30792	Вечерлей	7	63	270	45.940373999999998	45.982154000000001	54.621955	54.596932000000002	0103000020E610000001000000050000001D01DC2C5EF84640CBF78C44684C4B401D01DC2C5EF84640B64AB0389C4F4B405BD1E638B7FD4640B64AB0389C4F4B405BD1E638B7FD4640CBF78C44684C4B401D01DC2C5EF84640CBF78C44684C4B40
30709	Большие Манадыши	7	63	270	45.971249	46.013263000000002	54.574601000000001	54.553418000000001	0103000020E61000000100000005000000E8A221E351FC46404582A966D6464B40E8A221E351FC4640DC9F8B868C494B40999F1B9AB2014740DC9F8B868C494B40999F1B9AB20147404582A966D6464B40E8A221E351FC46404582A966D6464B40
30559	Батушево	7	63	270	46.118634999999998	46.154145999999997	54.583826999999999	54.566009999999999	0103000020E610000001000000050000009A94826E2F0F4740BF9A030473484B409A94826E2F0F4740CAC2D7D7BA4A4B4094675E0EBB134740CAC2D7D7BA4A4B4094675E0EBB134740BF9A030473484B409A94826E2F0F4740BF9A030473484B40
30865	Ахматово	7	63	270	45.858142000000001	45.878911000000002	54.600833000000002	54.587719	0103000020E610000001000000050000007AA9D898D7ED4640711E4E603A4B4B407AA9D898D7ED4640C5AD8218E84C4B401E8CD82780F04640C5AD8218E84C4B401E8CD82780F04640711E4E603A4B4B407AA9D898D7ED4640711E4E603A4B4B40
1137	Атяшево	7	63	270	46.04889	46.146518999999998	54.605432999999998	54.551412999999997	0103000020E61000000100000005000000FC8C0B07420647406CCB80B394464B40FC8C0B0742064740A7751BD47E4D4B400E9F7422C1124740A7751BD47E4D4B400E9F7422C11247406CCB80B394464B40FC8C0B07420647406CCB80B394464B40
56569	Андреевка	7	63	270	45.978920000000002	46.007936000000001	54.661833999999999	54.648375000000001	0103000020E610000001000000050000003EB324404DFD4640A245B6F3FD524B403EB324404DFD4640C0B0FCF9B6544B40043BFE0B04014740C0B0FCF9B6544B40043BFE0B04014740A245B6F3FD524B403EB324404DFD4640A245B6F3FD524B40
30604	Алово	7	63	270	46.408495000000002	46.481025000000002	54.650770999999999	54.613571999999998	0103000020E610000001000000050000002ECA6C9049344740E3DEFC86894E4B402ECA6C9049344740B517D1764C534B407AC7293A923D4740B517D1764C534B407AC7293A923D4740E3DEFC86894E4B402ECA6C9049344740E3DEFC86894E4B40
56601	Алашевка	7	63	270	46.209750999999997	46.239755000000002	54.645468000000001	54.625332999999998	0103000020E61000000100000005000000D2A6EA1ED91A4740060E68E90A504B40D2A6EA1ED91A4740A94E07B29E524B40B806B64AB01E4740A94E07B29E524B40B806B64AB01E4740060E68E90A504B40D2A6EA1ED91A4740060E68E90A504B40
56599	Шуструй	7	63	1801	43.356153999999997	43.386203000000002	54.243383000000001	54.230817000000002	0103000020E61000000100000005000000772B4B7496AD4540302E55698B1D4B40772B4B7496AD454081B3942C271F4B40FD4E93196FB1454081B3942C271F4B40FD4E93196FB14540302E55698B1D4B40772B4B7496AD4540302E55698B1D4B40
47948	Чудинка	7	63	1801	43.136606	43.160240999999999	54.318503999999997	54.299083000000003	0103000020E61000000100000005000000FC372F4E7C91454011E50B5A48264B40FC372F4E7C91454095D233BDC4284B403A3DEFC68294454095D233BDC4284B403A3DEFC68294454011E50B5A48264B40FC372F4E7C91454011E50B5A48264B40
56584	Усть-Рахмановка	7	63	1801	43.436194	43.464706999999997	54.233047999999997	54.221021	0103000020E61000000100000005000000105B7A34D5B74540575D876A4A1C4B40105B7A34D5B74540F8325184D41D4B40739CDB847BBB4540F8325184D41D4B40739CDB847BBB4540575D876A4A1C4B40105B7A34D5B74540575D876A4A1C4B40
46193	Стрельниково	7	63	1801	43.184584999999998	43.261454000000001	54.458578000000003	54.375329000000001	0103000020E61000000100000005000000842A357BA0974540C51EDAC70A304B40842A357BA0974540225514AFB23A4B4046B41D5377A14540225514AFB23A4B4046B41D5377A14540C51EDAC70A304B40842A357BA0974540C51EDAC70A304B40
29674	Русская Велязьма	7	63	1801	43.332726000000001	43.341970000000003	54.346632999999997	54.339982999999997	0103000020E61000000100000005000000B343FCC396AA454015191D90842B4B40B343FCC396AA4540705B5B785E2C4B40481B47ACC5AB4540705B5B785E2C4B40481B47ACC5AB454015191D90842B4B40B343FCC396AA454015191D90842B4B40
26468	Пичеполонга	7	63	1801	43.210177999999999	43.233291999999999	54.423073000000002	54.408351000000003	0103000020E610000001000000050000005A2BDA1CE79A4540FB2477D844344B405A2BDA1CE79A45400A698D4127364B408F352383DC9D45400A698D4127364B408F352383DC9D4540FB2477D844344B405A2BDA1CE79A4540FB2477D844344B40
48089	Оброчное	7	63	1801	43.454520000000002	43.477533999999999	54.315342000000001	54.303669999999997	0103000020E6100000010000000500000060B01BB62DBA45405E6397A8DE264B4060B01BB62DBA454012876C205D284B40315D88D51FBD454012876C205D284B40315D88D51FBD45405E6397A8DE264B4060B01BB62DBA45405E6397A8DE264B40
30276	Новочадово	7	63	1801	43.320490999999997	43.338079999999998	54.407868999999998	54.390996999999999	0103000020E61000000100000005000000C7D45DD905A94540C4EA8F300C324B40C7D45DD905A94540AF06280D35344B4041B7973446AB4540AF06280D35344B4041B7973446AB4540C4EA8F300C324B40C7D45DD905A94540C4EA8F300C324B40
62027	Новая Карьга	7	63	1801	43.361714999999997	43.391593	54.413150000000002	54.401862999999999	0103000020E610000001000000050000007FBC57AD4CAE4540793C2D3F70334B407FBC57AD4CAE4540D42B6519E2344B40D82B2CB81FB24540D42B6519E2344B40D82B2CB81FB24540793C2D3F70334B407FBC57AD4CAE4540793C2D3F70334B40
30187	Мордовская Козловка	7	63	1801	43.302965	43.320256999999998	54.464711999999999	54.454914000000002	0103000020E61000000100000005000000946A9F8EC7A645400C3F389F3A3A4B40946A9F8EC7A645408507CDAE7B3B4B4054A86E2EFEA845408507CDAE7B3B4B4054A86E2EFEA845400C3F389F3A3A4B40946A9F8EC7A645400C3F389F3A3A4B40
30117	Курташки	7	63	1801	43.429887999999998	43.454177999999999	54.33634	54.314973999999999	0103000020E61000000100000005000000AF78EA9106B745408F8B6A1151284B40AF78EA9106B74540172B6A300D2B4B400648348122BA4540172B6A300D2B4B400648348122BA45408F8B6A1151284B40AF78EA9106B745408F8B6A1151284B40
29422	Клопинка	7	63	1801	43.270463999999997	43.303719000000001	54.438177000000003	54.427714000000002	0103000020E61000000100000005000000675F79909EA245404B051555BF364B40675F79909EA24540016E162F16384B404016A243E0A64540016E162F16384B404016A243E0A645404B051555BF364B40675F79909EA245404B051555BF364B40
30068	Кишалы	7	63	1801	43.173509000000003	43.224946000000003	54.383735000000001	54.371285999999998	0103000020E61000000100000005000000E547FC8A3596454038BBB54C862F4B40E547FC8A3596454050AA7D3A1E314B40DAAED007CB9C454050AA7D3A1E314B40DAAED007CB9C454038BBB54C862F4B40E547FC8A3596454038BBB54C862F4B40
61822	Каменка	7	63	1801	43.303485999999999	43.325620000000001	54.291773999999997	54.277073000000001	0103000020E610000001000000050000009D6516A1D8A6454064CDC82077234B409D6516A1D8A645405BE9B5D958254B40367689EAADA945405BE9B5D958254B40367689EAADA9454064CDC82077234B409D6516A1D8A6454064CDC82077234B40
30369	Духонькино	7	63	1801	43.381936000000003	43.403117999999999	54.351576000000001	54.338261000000003	0103000020E6100000010000000500000021956247E3B045409241EE224C2B4B4021956247E3B045407D073F71002D4B40E736E15E99B345407D073F71002D4B40E736E15E99B345409241EE224C2B4B4021956247E3B045409241EE224C2B4B40
29971	Дмитриев Усад	7	63	1801	43.262352	43.310789	54.236716000000001	54.220753000000002	0103000020E61000000100000005000000250516C094A1454038BF61A2411C4B40250516C094A145405038BBB54C1E4B40707A17EFC7A745405038BBB54C1E4B40707A17EFC7A7454038BF61A2411C4B40250516C094A1454038BF61A2411C4B40
29909	Вольно-Никольское	7	63	1801	43.481245000000001	43.496578999999997	54.263438999999998	54.247627999999999	0103000020E61000000100000005000000882EA86F99BD454075C93846B21F4B40882EA86F99BD4540D7BE805EB8214B40B07092E68FBF4540D7BE805EB8214B40B07092E68FBF454075C93846B21F4B40882EA86F99BD454075C93846B21F4B40
61823	Барашево	7	63	1801	43.258147999999998	43.277245999999998	54.495229000000002	54.480324000000003	0103000020E610000001000000050000008FC360FE0AA14540F1BDBF417B3D4B408FC360FE0AA14540F183F3A9633F4B40317903CC7CA34540F183F3A9633F4B40317903CC7CA34540F1BDBF417B3D4B408FC360FE0AA14540F1BDBF417B3D4B40
29552	Атюрьево	7	63	1801	43.312595000000002	43.359568000000003	54.338366000000001	54.309432999999999	0103000020E6100000010000000500000052F2EA1C03A84540CEA623809B274B4052F2EA1C03A84540070ABC934F2B4B401558005306AE4540070ABC934F2B4B401558005306AE4540CEA623809B274B4052F2EA1C03A84540CEA623809B274B40
47931	Арга	7	63	1801	43.130766999999999	43.142085999999999	54.343981999999997	54.331750999999997	0103000020E61000000100000005000000B1321AF9BC90454028B517D1762A4B40B1321AF9BC904540D234289A072C4B40179CC1DF2F924540D234289A072C4B40179CC1DF2F92454028B517D1762A4B40B1321AF9BC90454028B517D1762A4B40
29513	Чукалы	7	63	1824	46.275202999999998	46.308719000000004	54.728810000000003	54.702452999999998	0103000020E610000001000000050000006B6116DA3923474011FDDAFAE9594B406B6116DA39234740B77F65A5495D4B40B153AC1A84274740B77F65A5495D4B40B153AC1A8427474011FDDAFAE9594B406B6116DA3923474011FDDAFAE9594B40
29418	Урусово	7	63	1824	46.248576999999997	46.279370999999998	55.039785000000002	55.01979	0103000020E61000000100000005000000D6C4025FD11F4740D8648D7A88824B40D6C4025FD11F474089EFC4AC17854B40B439CE6DC223474089EFC4AC17854B40B439CE6DC2234740D8648D7A88824B40D6C4025FD11F4740D8648D7A88824B40
29320	Турдаково	7	63	1824	46.185102000000001	46.205897999999998	54.816909000000003	54.802007000000003	0103000020E610000001000000050000004C361E6CB1174740E014562AA8664B404C361E6CB11747406F675F7990684B40E9279CDD5A1A47406F675F7990684B40E9279CDD5A1A4740E014562AA8664B404C361E6CB1174740E014562AA8664B40
56535	Тургенево	7	63	1824	46.286242999999999	46.356670999999999	54.854610000000001	54.827874000000001	0103000020E61000000100000005000000BEDA519CA3244740B79A75C6F7694B40BEDA519CA3244740D36A48DC636D4B403F373465A72D4740D36A48DC636D4B403F373465A72D4740B79A75C6F7694B40BEDA519CA3244740B79A75C6F7694B40
29266	Старое Ардатово	7	63	1824	46.194884000000002	46.217377999999997	55.005536999999997	54.985762000000001	0103000020E61000000100000005000000C0417BF5F1184740DDD1FF722D7E4B40C0417BF5F11847407FF5B86FB5804B40586FD40AD31B47407FF5B86FB5804B40586FD40AD31B4740DDD1FF722D7E4B40C0417BF5F1184740DDD1FF722D7E4B40
28827	Спасские Мурзы	7	63	1824	45.892097999999997	45.918886000000001	54.806230999999997	54.792721999999998	0103000020E61000000100000005000000DB696B4430F24640EC681CEA77654B40DB696B4430F24640BC02D19332674B404A60730E9EF54640BC02D19332674B404A60730E9EF54640EC681CEA77654B40DB696B4430F24640EC681CEA77654B40
29208	Солдатское	7	63	1824	45.932253000000003	45.960648999999997	54.981329000000002	54.970658999999998	0103000020E61000000100000005000000884CF91054F74640B648DA8D3E7C4B40884CF91054F74640E6CE4C309C7D4B40B1F7E28BF6FA4640E6CE4C309C7D4B40B1F7E28BF6FA4640B648DA8D3E7C4B40884CF91054F74640B648DA8D3E7C4B40
29178	Силино	7	63	1824	46.022641	46.035091999999999	54.989733999999999	54.979320000000001	0103000020E610000001000000050000003D4679E6E5024740CC28965B5A7D4B403D4679E6E5024740A0DE8C9AAF7E4B40F52C08E57D044740A0DE8C9AAF7E4B40F52C08E57D044740CC28965B5A7D4B403D4679E6E5024740CC28965B5A7D4B40
29111	Редкодубье	7	63	1824	46.158906999999999	46.183681999999997	54.829611	54.796314000000002	0103000020E61000000100000005000000800D88105714474069ACFD9DED654B40800D88105714474070B378B1306A4B40936E4BE48217474070B378B1306A4B40936E4BE48217474069ACFD9DED654B40800D88105714474069ACFD9DED654B40
28467	Полое	7	63	1824	46.135452000000001	46.177878999999997	54.778044999999999	54.751502000000002	0103000020E61000000100000005000000C216BB7D561147407670B03731604B40C216BB7D561147407DE882FA96634B4095D233BDC41647407DE882FA96634B4095D233BDC41647407670B03731604B40C216BB7D561147407670B03731604B40
29042	Пиксяси	7	63	1824	46.297265000000003	46.318339999999999	54.664848999999997	54.644181000000003	0103000020E610000001000000050000006B9F8EC70C26474030DAE38574524B406B9F8EC70C2647409FE3A3C519554B401B81785DBF2847409FE3A3C519554B401B81785DBF28474030DAE38574524B406B9F8EC70C26474030DAE38574524B40
29019	Октябрьский	7	63	1824	46.199860999999999	46.230269	54.914974000000001	54.883944	0103000020E61000000100000005000000785F950B951947406ABFB51325714B40785F950B951947405C5837DE1D754B402D246074791D47405C5837DE1D754B402D246074791D47406ABFB51325714B40785F950B951947406ABFB51325714B40
28982	Низовка	7	63	1824	46.292019000000003	46.322966000000001	54.765804000000003	54.750453	0103000020E61000000100000005000000C367EBE060254740B1170AD80E604B40C367EBE060254740B0928FDD05624B4027DC2BF356294740B0928FDD05624B4027DC2BF356294740B1170AD80E604B40C367EBE060254740B1170AD80E604B40
28915	Манадыши 2-е	7	63	1824	45.984453999999999	46.007638999999998	54.960354000000002	54.932338000000001	0103000020E610000001000000050000004C35B39602FE4640B66801DA56774B404C35B39602FE4640994A3FE1EC7A4B404A969350FA004740994A3FE1EC7A4B404A969350FA004740B66801DA56774B404C35B39602FE4640B66801DA56774B40
28882	Манадыши 1-е	7	63	1824	45.984453999999999	46.007638999999998	54.960354000000002	54.932338000000001	0103000020E610000001000000050000004C35B39602FE4640B66801DA56774B404C35B39602FE4640994A3FE1EC7A4B404A969350FA004740994A3FE1EC7A4B404A969350FA004740B66801DA56774B404C35B39602FE4640B66801DA56774B40
28573	Малое Кузьмино	7	63	1824	46.114125999999999	46.142324000000002	55.022948999999997	55.000518	0103000020E61000000100000005000000C8CF46AE9B0E474098874CF910804B40C8CF46AE9B0E4740EA3C2AFEEF824B40CCB73EAC37124740EA3C2AFEEF824B40CCB73EAC3712474098874CF910804B40C8CF46AE9B0E474098874CF910804B40
56561	Луньгинский Майдан	7	63	1824	45.793176000000003	45.823647000000001	54.827106000000001	54.803553999999998	0103000020E610000001000000050000006EFC89CA86E54640F54883DBDA664B406EFC89CA86E54640A629029CDE694B406939D0436DE94640A629029CDE694B406939D0436DE94640F54883DBDA664B406EFC89CA86E54640F54883DBDA664B40
28724	Луньга	7	63	1824	45.937058999999998	45.971015000000001	54.799017999999997	54.780864999999999	0103000020E6100000010000000500000013B69F8CF1F74640A7CB6262F3634B4013B69F8CF1F746402975C93846664B40757632384AFC46402975C93846664B40757632384AFC4640A7CB6262F3634B4013B69F8CF1F74640A7CB6262F3634B40
28665	Лесозавод	7	63	1824	46.016784000000001	46.028570000000002	54.828927	54.816540000000003	0103000020E610000001000000050000004C8C65FA250247401CF0F96184684B404C8C65FA25024740BDE2A9471A6A4B40C8D2872EA8034740BDE2A9471A6A4B40C8D2872EA80347401CF0F96184684B404C8C65FA250247401CF0F96184684B40
28633	Кученяево	7	63	1824	46.366084999999998	46.423594999999999	54.739103	54.723860000000002	0103000020E6100000010000000500000030478FDFDB2E4740F870C971A75C4B4030478FDFDB2E474010B056ED9A5E4B40E3DF675C3836474010B056ED9A5E4B40E3DF675C38364740F870C971A75C4B4030478FDFDB2E4740F870C971A75C4B40
28487	Куракино	7	63	1824	46.129828000000003	46.149707999999997	54.967311000000002	54.948979999999999	0103000020E61000000100000005000000740D33349E1047406F47382D78794B40740D33349E104740D107CBD8D07B4B408BF9B9A129134740D107CBD8D07B4B408BF9B9A1291347406F47382D78794B40740D33349E1047406F47382D78794B40
28362	Кечушево	7	63	1824	46.094659	46.130924	54.751610999999997	54.728445999999998	0103000020E61000000100000005000000D3A23EC91D0C47407573F1B73D5D4B40D3A23EC91D0C47402C280CCA34604B4079211D1EC21047402C280CCA34604B4079211D1EC21047407573F1B73D5D4B40D3A23EC91D0C47407573F1B73D5D4B40
28274	Кельвядни	7	63	1824	46.328158000000002	46.346035000000001	54.706978999999997	54.692405999999998	0103000020E61000000100000005000000DCF5D214012A4740EFC682C2A0584B40DCF5D214012A4740B9FAB1497E5A4B40BC22F8DF4A2C4740B9FAB1497E5A4B40BC22F8DF4A2C4740EFC682C2A0584B40DCF5D214012A4740EFC682C2A0584B40
28234	Каласево	7	63	1824	46.018222000000002	46.051045999999999	54.789586999999997	54.773449999999997	0103000020E61000000100000005000000AB08371955024740AC8BDB6800634B40AB08371955024740622CD32F11654B40BA4BE2AC88064740622CD32F11654B40BA4BE2AC88064740AC8BDB6800634B40AB08371955024740AC8BDB6800634B40
28170	Жаренки	7	63	1824	46.235433999999998	46.257730000000002	54.726610999999998	54.712398999999998	0103000020E61000000100000005000000E82E89B3221E4740FF59F3E32F5B4B40E82E89B3221E4740F9F4D896015D4B405B99F04BFD204740F9F4D896015D4B405B99F04BFD204740FF59F3E32F5B4B40E82E89B3221E4740FF59F3E32F5B4B40
28147	Жабино	7	63	1824	46.207712000000001	46.233834999999999	55.038789999999999	55.026566000000003	0103000020E610000001000000050000004E7E8B4E961A4740C097C28366834B404E7E8B4E961A4740B7B41A12F7844B4080D4264EEE1D4740B7B41A12F7844B4080D4264EEE1D4740C097C28366834B404E7E8B4E961A4740C097C28366834B40
28547	Большое Кузьмино	7	63	1824	46.075516	46.106929999999998	54.955975000000002	54.941591000000003	0103000020E6100000010000000500000091291F82AA0947409E9ACB0D86784B4091291F82AA094740956588635D7A4B400B7BDAE1AF0D4740956588635D7A4B400B7BDAE1AF0D47409E9ACB0D86784B4091291F82AA0947409E9ACB0D86784B40
29137	Большие Поляны	7	63	1824	46.096814999999999	46.127259000000002	54.853822000000001	54.838166999999999	0103000020E610000001000000050000009161156F640C474010CB660E496B4B409161156F640C47407B4D0F0A4A6D4B40938FDD054A1047407B4D0F0A4A6D4B40938FDD054A10474010CB660E496B4B409161156F640C474010CB660E496B4B40
28400	Безводное	7	63	1824	46.062922	46.088541999999997	54.761482999999998	54.742507000000003	0103000020E610000001000000050000007619FED30D0847408A0629780A5F4B407619FED30D084740E0BA624678614B4045292158550B4740E0BA624678614B4045292158550B47408A0629780A5F4B407619FED30D0847408A0629780A5F4B40
28087	Баево	7	63	1824	46.352027	46.385956	54.850282	54.82	0103000020E610000001000000050000008D2782380F2D4740295C8FC2F5684B408D2782380F2D47405130630AD66C4B40F5D89601673147405130630AD66C4B40F5D8960167314740295C8FC2F5684B408D2782380F2D4740295C8FC2F5684B40
56555	Ардатов	7	63	1824	46.252951000000003	46.278419	54.777287000000001	54.754151999999998	0103000020E61000000100000005000000C93EC8B260204740431B800D88604B40C93EC8B260204740904DF2237E634B40E2CAD93BA3234740904DF2237E634B40E2CAD93BA3234740431B800D88604B40C93EC8B260204740431B800D88604B40
32696	Ардатов	7	63	1824	46.219982999999999	46.258817000000001	54.867097999999999	54.821078999999997	0103000020E6100000010000000500000086562767281C47405837DE1D19694B4086562767281C4740A8363811FD6E4B400D535BEA20214740A8363811FD6E4B400D535BEA202147405837DE1D19694B4086562767281C47405837DE1D19694B40
28303	Андреевка	7	63	1824	46.382658999999997	46.403464	54.704918999999997	54.692765000000001	0103000020E61000000100000005000000914259F8FA3047401F680586AC584B40914259F8FA3047401DAA29C93A5A4B40828E56B5A43347401DAA29C93A5A4B40828E56B5A43347401F680586AC584B40914259F8FA3047401F680586AC584B40
7823	Козьмодемьянск	7	62	\N	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
1218	Йошкар-Ола	7	62	\N	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
57932	Звенигово	7	62	\N	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
6770	Волжск	7	62	\N	48.390250000000002	48.410516000000001	55.865192	55.84395	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
26701	Юркино	7	62	1792	46.195675000000001	46.225453999999999	56.525261	56.503548000000002	0103000020E6100000010000000500000089D2DEE00B194740ADFBC74274404C4089D2DEE00B194740A06EA0C03B434C404E603AADDB1C4740A06EA0C03B434C404E603AADDB1C4740ADFBC74274404C4089D2DEE00B194740ADFBC74274404C40
26130	Юрино	7	62	1792	46.252377000000003	46.321843000000001	56.305619	56.283259999999999	0103000020E610000001000000050000009DA1B8E34D204740EA211ADD41244C409DA1B8E34D204740A304FD851E274C4028B9C32632294740A304FD851E274C4028B9C32632294740EA211ADD41244C409DA1B8E34D204740EA211ADD41244C40
26300	Суходол	7	62	1792	46.273091999999998	46.292800999999997	56.341332999999999	56.325155000000002	0103000020E610000001000000050000004D66BCADF4224740C190D5AD9E294C404D66BCADF4224740D505BCCCB02B4C40389ECF807A254740D505BCCCB02B4C40389ECF807A254740C190D5AD9E294C404D66BCADF4224740C190D5AD9E294C40
26463	Починок	7	62	1792	46.093499999999999	46.139071999999999	56.282775000000001	56.273260000000001	0103000020E610000001000000050000008716D9CEF70B474009A7052FFA224C408716D9CEF70B47402E90A0F831244C4008E57D1CCD1147402E90A0F831244C4008E57D1CCD11474009A7052FFA224C408716D9CEF70B474009A7052FFA224C40
26601	Марьино	7	62	1792	46.000084999999999	46.023736999999997	56.580689	56.547511999999998	0103000020E610000001000000050000002E1C08C90200474072158BDF14464C402E1C08C902004740CF126404544A4C40425A63D009034740CF126404544A4C40425A63D00903474072158BDF14464C402E1C08C90200474072158BDF14464C40
26610	Красная Люнда	7	62	1792	46.019848000000003	46.050741000000002	56.529738999999999	56.517952000000001	0103000020E610000001000000050000000D7217618A024740EB724A404C424C400D7217618A0247403735D07CCE434C407EC85BAE7E0647403735D07CCE434C407EC85BAE7E064740EB724A404C424C400D7217618A024740EB724A404C424C40
26553	Козиково	7	62	1792	45.912076999999996	45.943823000000002	56.724904000000002	56.692526999999998	0103000020E6100000010000000500000086376BF0BEF446406A4C88B9A4584C4086376BF0BEF44640AB5E7EA7C95C4C40371B2B31CFF84640AB5E7EA7C95C4C40371B2B31CFF846406A4C88B9A4584C4086376BF0BEF446406A4C88B9A4584C40
58060	Горный Шимец	7	62	1792	46.146833000000001	46.176873000000001	56.283205000000002	56.275328999999999	0103000020E610000001000000050000009E7C7A6CCB124740F8510DFB3D234C409E7C7A6CCB1247402788BA0F40244C40D04543C6A31647402788BA0F40244C40D04543C6A3164740F8510DFB3D234C409E7C7A6CCB124740F8510DFB3D234C40
26329	Васильевское	7	62	1792	45.791442000000004	45.825578	56.530239999999999	56.507109	0103000020E610000001000000050000002657B1F84DE54640EE409DF2E8404C402657B1F84DE54640F98381E7DE434C400726378AACE94640F98381E7DE434C400726378AACE94640EE409DF2E8404C402657B1F84DE54640EE409DF2E8404C40
26246	Быковка	7	62	1792	46.261637999999998	46.305520999999999	56.310637	56.293351999999999	0103000020E6100000010000000500000007B29E5A7D214740AC1BEF8E8C254C4007B29E5A7D214740BAF605F4C2274C40E09EE74F1B274740BAF605F4C2274C40E09EE74F1B274740AC1BEF8E8C254C4007B29E5A7D214740AC1BEF8E8C254C40
58086	пос. Голубой	7	62	1765	48.129998999999998	48.809494000000001	56.985996	56.447996000000003	0103000020E61000000100000005000000A0C1A6CEA3104840925ED4EE57394C40A0C1A6CEA310484050FEEE1D357E4C407427D87F9D67484050FEEE1D357E4C407427D87F9D674840925ED4EE57394C40A0C1A6CEA3104840925ED4EE57394C40
25778	Шуарсола	7	62	1765	48.183861999999998	48.204828999999997	56.795658000000003	56.780053000000002	0103000020E61000000100000005000000137D3ECA88174840C712D6C6D8634C40137D3ECA881748408066101FD8654C40DD2230D6371A48408066101FD8654C40DD2230D6371A4840C712D6C6D8634C40137D3ECA88174840C712D6C6D8634C40
25953	Чкарино	7	62	1765	48.414378999999997	48.445495999999999	56.708182999999998	56.693505000000002	0103000020E610000001000000050000001893FE5E0A354840664E97C5C4584C401893FE5E0A354840A54A94BDA55A4C40D93F4F0306394840A54A94BDA55A4C40D93F4F0306394840664E97C5C4584C401893FE5E0A354840664E97C5C4584C40
25303	Ургакш	7	62	1765	48.410687000000003	48.437159999999999	56.755096999999999	56.74024	0103000020E6100000010000000500000039F240649134484074982F2FC05E4C4039F24064913448406327BC04A7604C40478FDFDBF43748406327BC04A7604C40478FDFDBF437484074982F2FC05E4C4039F240649134484074982F2FC05E4C40
25699	Средний Кадам	7	62	1765	48.383647000000003	48.403742999999999	56.937373000000001	56.924014	0103000020E61000000100000005000000B11A4B581B314840E8853B1746764C40B11A4B581B314840A393A5D6FB774C40957EC2D9AD334840A393A5D6FB774C40957EC2D9AD334840E8853B1746764C40B11A4B581B314840E8853B1746764C40
26033	Солнечный	7	62	1765	48.390663000000004	48.413355000000003	56.546653999999997	56.536068	0103000020E61000000100000005000000EE60C43E01324840503750E09D444C40EE60C43E01324840211D1EC2F8454C40AD510FD1E8344840211D1EC2F8454C40AD510FD1E8344840503750E09D444C40EE60C43E01324840503750E09D444C40
25112	Советский	7	62	1765	48.458396	48.494571000000001	56.772669999999998	56.743439000000002	0103000020E61000000100000005000000014F5AB8AC3A484015C95702295F4C40014F5AB8AC3A4840D74CBED9E6624C4067463F1A4E3F4840D74CBED9E6624C4067463F1A4E3F484015C95702295F4C40014F5AB8AC3A484015C95702295F4C40
57930	Семеновка	7	62	1765	48.319580000000002	48.336899000000003	56.678674000000001	56.669713000000002	0103000020E61000000100000005000000543A58FFE7284840605AD427B9554C40543A58FFE7284840A05225CADE564C400E87A5811F2B4840A05225CADE564C400E87A5811F2B4840605AD427B9554C40543A58FFE7284840605AD427B9554C40
25928	Ронга	7	62	1765	48.498165	48.532552000000003	56.713276	56.697122999999998	0103000020E610000001000000050000008481E7DEC33F48400B2593533B594C408481E7DEC33F4840C782C2A04C5B4C40AFB5F7A92A444840C782C2A04C5B4C40AFB5F7A92A4448400B2593533B594C408481E7DEC33F48400B2593533B594C40
25511	Орша	7	62	1765	48.496934000000003	48.515636999999998	56.915813999999997	56.902884999999998	0103000020E610000001000000050000009F2287889B3F4840448655BC91734C409F2287889B3F4840069CA56439754C40C4CDA96400424840069CA56439754C40C4CDA96400424840448655BC91734C409F2287889B3F4840448655BC91734C40
25879	Михайловка	7	62	1765	48.247804000000002	48.265689999999999	56.663842000000002	56.651651000000001	0103000020E61000000100000005000000B4E89D0AB81F4840EEB3CA4C69534C40B4E89D0AB81F48400ADB4FC6F8544C40E76F4221022248400ADB4FC6F8544C40E76F422102224840EEB3CA4C69534C40B4E89D0AB81F4840EEB3CA4C69534C40
25410	Кукмарь	7	62	1765	48.656098	48.698281999999999	56.881216999999999	56.869199999999999	0103000020E610000001000000050000004A7CEE04FB53484073D712F2416F4C404A7CEE04FB534840F1D6F9B7CB704C4057B1F84D61594840F1D6F9B7CB704C4057B1F84D6159484073D712F2416F4C404A7CEE04FB53484073D712F2416F4C40
25639	Кужмара	7	62	1765	48.313237999999998	48.328194000000003	56.852854000000001	56.844968000000001	0103000020E61000000100000005000000A6EECA2E18284840511553E9276C4C40A6EECA2E18284840A321E3512A6D4C40295FD042022A4840A321E3512A6D4C40295FD042022A4840511553E9276C4C40A6EECA2E18284840511553E9276C4C40
25597	Колянур	7	62	1765	48.535912000000003	48.553618	56.832270000000001	56.813004999999997	0103000020E6100000010000000500000059C4B0C398444840033E3F8C10684C4059C4B0C39844484091B8C7D2876A4C400C3D62F4DC46484091B8C7D2876A4C400C3D62F4DC464840033E3F8C10684C4059C4B0C398444840033E3F8C10684C40
25705	Кельмаксола	7	62	1765	48.250552999999996	48.281455000000001	56.822459000000002	56.811132999999998	0103000020E610000001000000050000001475E61E122048406ADAC534D3674C401475E61E1220484083A6255646694C40D925AAB70624484083A6255646694C40D925AAB7062448406ADAC534D3674C401475E61E122048406ADAC534D3674C40
25496	Вятское	7	62	1765	48.512008000000002	48.529111999999998	56.787430000000001	56.777014999999999	0103000020E610000001000000050000002BA5677A894148402FC03E3A75634C402BA5677A89414840D4F19881CA644C40E8F527F1B9434840D4F19881CA644C40E8F527F1B94348402FC03E3A75634C402BA5677A894148402FC03E3A75634C40
25401	Верхний Ушнур	7	62	1765	48.634224000000003	48.658172999999998	56.782859000000002	56.768087999999999	0103000020E610000001000000050000004E2B85402E5148409B3924B550624C404E2B85402E5148408C3045B934644C401B0E4B033F5448408C3045B934644C401B0E4B033F5448409B3924B550624C404E2B85402E5148409B3924B550624C40
26013	Великополье	7	62	1765	48.484572999999997	48.509689999999999	56.678803000000002	56.668689000000001	0103000020E6100000010000000500000026C3F17C063E4840F418E59997554C4026C3F17C063E48409EB64604E3564C40938C9C853D4148409EB64604E3564C40938C9C853D414840F418E59997554C4026C3F17C063E4840F418E59997554C40
25311	Алексеевский	7	62	1765	48.332255000000004	48.360399000000001	56.753019000000002	56.742086999999998	0103000020E610000001000000050000005C77F354872A4840B4E4F1B4FC5E4C405C77F354872A4840212235ED62604C406C41EF8D212E4840212235ED62604C406C41EF8D212E4840B4E4F1B4FC5E4C405C77F354872A4840B4E4F1B4FC5E4C40
24418	Эшполдино	7	62	1730	49.141663999999999	49.150288000000003	57.303440999999999	57.299337000000001	0103000020E61000000100000005000000A182C30B22924840CBBDC0AC50A64C40A182C30B22924840FDA19927D7A64C409A7D1EA33C934840FDA19927D7A64C409A7D1EA33C934840CBBDC0AC50A64C40A182C30B22924840CBBDC0AC50A64C40
24279	Читово	7	62	1730	49.065953999999998	49.085861000000001	57.262794999999997	57.243938	0103000020E610000001000000050000002B85402E718848403620425C399F4C402B85402E71884840B2463D44A3A14C403D80457EFD8A4840B2463D44A3A14C403D80457EFD8A48403620425C399F4C402B85402E718848403620425C399F4C40
24889	Чендемерово	7	62	1730	49.080902000000002	49.103566000000001	56.910727999999999	56.899763	0103000020E610000001000000050000002B172AFF5A8A48404F93196F2B734C402B172AFF5A8A484097C62FBC92744C40207D93A6418D484097C62FBC92744C40207D93A6418D48404F93196F2B734C402B172AFF5A8A48404F93196F2B734C40
24569	Чашкаял	7	62	1730	49.261327999999999	49.283031999999999	56.972217999999998	56.961613999999997	0103000020E61000000100000005000000B9C3263273A1484018B0E42A167B4C40B9C3263273A14840904AB1A3717C4C4059DC7F643AA44840904AB1A3717C4C4059DC7F643AA4484018B0E42A167B4C40B9C3263273A1484018B0E42A167B4C40
23975	Тамшинер	7	62	1730	49.301302999999997	49.330499000000003	56.877640999999997	56.866539000000003	0103000020E61000000100000005000000E597C11891A64840B2DAFCBFEA6E4C40E597C11891A648407A50508A56704C402C2E8ECA4DAA48407A50508A56704C402C2E8ECA4DAA4840B2DAFCBFEA6E4C40E597C11891A64840B2DAFCBFEA6E4C40
23578	Сернур	7	62	1730	49.110798000000003	49.168658000000001	56.952893000000003	56.922589000000002	0103000020E610000001000000050000002A3BFDA02E8E48401E53776517764C402A3BFDA02E8E48402ECBD765F8794C40B91AD995969548402ECBD765F8794C40B91AD995969548401E53776517764C402A3BFDA02E8E48401E53776517764C40
24475	Нижний Рушенер	7	62	1730	49.095256999999997	49.111004000000001	57.224643	57.215808000000003	0103000020E6100000010000000500000087DBA161318C48408B1BB7989F9B4C4087DBA161318C48403E23111AC19C4C40D3DC0A61358E48403E23111AC19C4C40D3DC0A61358E48408B1BB7989F9B4C4087DBA161318C48408B1BB7989F9B4C40
23814	Нижний Кугенер	7	62	1730	49.214796	49.225090000000002	56.892555999999999	56.886803999999998	0103000020E61000000100000005000000E3A7716F7E9B484022FB20CB82714C40E3A7716F7E9B48409EEC66463F724C400D54C6BFCF9C48409EEC66463F724C400D54C6BFCF9C484022FB20CB82714C40E3A7716F7E9B484022FB20CB82714C40
24978	Мустаево	7	62	1730	49.010573000000001	49.026958	56.944557000000003	56.931077000000002	0103000020E610000001000000050000003D9CC0745A8148406687F8872D774C403D9CC0745A8148409C1A683EE7784C40CB2E185C738348409C1A683EE7784C40CB2E185C738348406687F8872D774C403D9CC0745A8148406687F8872D774C40
24726	Марисола	7	62	1730	49.081682999999998	49.098751	57.044119000000002	57.035476000000003	0103000020E61000000100000005000000D0D1AA96748A48407EE5417A8A844C40D0D1AA96748A4840ED10FFB0A5854C4041B96DDFA38C4840ED10FFB0A5854C4041B96DDFA38C48407EE5417A8A844C40D0D1AA96748A48407EE5417A8A844C40
24810	Мари-Кугунур	7	62	1730	49.002344000000001	49.020769000000001	57.038645000000002	57.028354	0103000020E61000000100000005000000C1ABE5CE4C804840FB5A971AA1834C40C1ABE5CE4C804840B493C151F2844C40A4E2FF8EA8824840B493C151F2844C40A4E2FF8EA8824840FB5A971AA1834C40C1ABE5CE4C804840FB5A971AA1834C40
25041	Малый Шокшем	7	62	1730	48.964883999999998	48.985582000000001	56.962704000000002	56.956077999999998	0103000020E610000001000000050000008237A451817B484069368FC3607A4C408237A451817B48403CDD79E2397B4C405DC30C8D277E48403CDD79E2397B4C405DC30C8D277E484069368FC3607A4C408237A451817B484069368FC3607A4C40
24067	Лоскутово	7	62	1730	49.217015000000004	49.237945000000003	57.027267000000002	57.014498000000003	0103000020E61000000100000005000000E8DEC325C79B4840C0ED0912DB814C40E8DEC325C79B484049A12C7C7D834C40959F54FB749E484049A12C7C7D834C40959F54FB749E4840C0ED0912DB814C40E8DEC325C79B4840C0ED0912DB814C40
24588	Летник	7	62	1730	49.283535000000001	49.293092999999999	56.992007999999998	56.988688000000003	0103000020E61000000100000005000000BC22F8DF4AA448404DF910548D7E4C40BC22F8DF4AA4484068AF3E1EFA7E4C40E0D7481284A5484068AF3E1EFA7E4C40E0D7481284A548404DF910548D7E4C40BC22F8DF4AA448404DF910548D7E4C40
58053	Лажьял	7	62	1730	49.263241999999998	49.280659999999997	56.881345000000003	56.872413000000002	0103000020E610000001000000050000008177F2E9B1A1484079CDAB3AAB6F4C408177F2E9B1A148401FBFB7E9CF704C40CEA5B8AAECA348401FBFB7E9CF704C40CEA5B8AAECA3484079CDAB3AAB6F4C408177F2E9B1A1484079CDAB3AAB6F4C40
24367	Купсола	7	62	1730	49.135509999999996	49.151122999999998	57.259222000000001	57.251043000000003	0103000020E61000000100000005000000F623456458914840E371512D22A04C40F623456458914840AD33BE2F2EA14C4032569BFF57934840AD33BE2F2EA14C4032569BFF57934840E371512D22A04C40F623456458914840E371512D22A04C40
24925	Куприяново	7	62	1730	49.048130999999998	49.075018	56.903562999999998	56.896219000000002	0103000020E610000001000000050000003E76172829864840E486DF4DB7724C403E761728298648401570CFF3A7734C40404E98309A8948401570CFF3A7734C40404E98309A894840E486DF4DB7724C403E76172829864840E486DF4DB7724C40
58066	Кункур	7	62	1730	49.038977000000003	49.073068999999997	57.241517999999999	57.221601999999997	0103000020E61000000100000005000000EA25C632FD844840355D4F745D9C4C40EA25C632FD8448409AB2D30FEA9E4C40FBAC32535A8948409AB2D30FEA9E4C40FBAC32535A894840355D4F745D9C4C40EA25C632FD844840355D4F745D9C4C40
24676	Кочанур	7	62	1730	49.219521	49.233255999999997	56.942312999999999	56.930635000000002	0103000020E6100000010000000500000082E49D43199C4840A9C1340C1F774C4082E49D43199C48403ECC5EB69D784C4042CC2555DB9D48403ECC5EB69D784C4042CC2555DB9D4840A9C1340C1F774C4082E49D43199C4840A9C1340C1F774C40
24157	Калеево	7	62	1730	49.487848	49.521237999999997	56.986652999999997	56.975132000000002	0103000020E61000000100000005000000A2B5A2CD71BE48403CA41820D17C4C40A2B5A2CD71BE484009C03FA54A7E4C405AB741EDB7C2484009C03FA54A7E4C405AB741EDB7C248403CA41820D17C4C40A2B5A2CD71BE48403CA41820D17C4C40
24199	Казанское	7	62	1730	49.112442000000001	49.139580000000002	57.158285999999997	57.142462000000002	0103000020E610000001000000050000003259DC7F648E48401D76DF313C924C403259DC7F648E484013B534B742944C407D96E7C1DD91484013B534B742944C407D96E7C1DD9148401D76DF313C924C403259DC7F648E48401D76DF313C924C40
24752	Йошкар-Памаш	7	62	1730	49.109855000000003	49.127003000000002	57.060352999999999	57.049211	0103000020E61000000100000005000000AB2688BA0F8E48403ECDC98B4C864C40AB2688BA0F8E4840959BA8A5B9874C4038BF61A241904840959BA8A5B9874C4038BF61A2419048403ECDC98B4C864C40AB2688BA0F8E48403ECDC98B4C864C40
24079	Зашижемье	7	62	1730	49.371794000000001	49.389231000000002	56.970377999999997	56.961987000000001	0103000020E61000000100000005000000AD6C1FF296AF4840AD16D863227B4C40AD6C1FF296AF48400261A758357C4C4071CB4752D2B148400261A758357C4C4071CB4752D2B14840AD16D863227B4C40AD6C1FF296AF4840AD16D863227B4C40
23979	Дубники	7	62	1730	49.116098000000001	49.126060000000003	56.975862999999997	56.968896000000001	0103000020E61000000100000005000000C5909C4CDC8E4840D49CBCC8047C4C40C5909C4CDC8E48402F302B14E97C4C40B9AAECBB229048402F302B14E97C4C40B9AAECBB22904840D49CBCC8047C4C40C5909C4CDC8E4840D49CBCC8047C4C40
25046	Горняк	7	62	1730	49.050566000000003	49.064669000000002	56.865141000000001	56.858837999999999	0103000020E6100000010000000500000010255AF278864840F1475167EE6D4C4010255AF278864840E1B6B6F0BC6E4C405308E41247884840E1B6B6F0BC6E4C405308E41247884840F1475167EE6D4C4010255AF278864840F1475167EE6D4C40
24484	Большой Сердеж	7	62	1730	49.255310000000001	49.283517000000003	56.94276	56.932800999999998	0103000020E61000000100000005000000BF2B82FFADA048408A56EE0566774C40BF2B82FFADA048400DFD135CAC784C40166EF9484AA448400DFD135CAC784C40166EF9484AA448408A56EE0566774C40BF2B82FFADA048408A56EE0566774C40
24840	Большие Ключи	7	62	1730	48.982931999999998	49.013869999999997	57.015791999999998	57.003597999999997	0103000020E610000001000000050000008F183DB7D07D48405E2A36E675804C408F183DB7D07D4840EBC4E57805824C40A032FE7DC6814840EBC4E57805824C40A032FE7DC68148405E2A36E675804C408F183DB7D07D48405E2A36E675804C40
23849	Большая Мушка	7	62	1730	49.132474000000002	49.150872	56.902059000000001	56.891657000000002	0103000020E6100000010000000500000000C974E8F4904840EF1F0BD121724C4000C974E8F4904840FF0758AB76734C40E9F010C64F934840FF0758AB76734C40E9F010C64F934840EF1F0BD121724C4000C974E8F4904840EF1F0BD121724C40
23544	Усола	7	62	1707	49.456263	49.479125000000003	56.729956000000001	56.716166000000001	0103000020E61000000100000005000000FBAF73D366BA4840EA40D653AB5B4C40FBAF73D366BA48406EC2BD326F5D4C4017D9CEF753BD48406EC2BD326F5D4C4017D9CEF753BD4840EA40D653AB5B4C40FBAF73D366BA4840EA40D653AB5B4C40
23413	Русская Ляжмарь	7	62	1707	49.482970000000002	49.508805000000002	56.890726999999998	56.876539999999999	0103000020E610000001000000050000007D7901F6D1BD484063D1747632704C407D7901F6D1BD48400455A35703724C404985B18520C148400455A35703724C404985B18520C1484063D1747632704C407D7901F6D1BD484063D1747632704C40
23394	Портянур	7	62	1707	49.258211000000003	49.284343	56.692596000000002	56.674481	0103000020E61000000100000005000000D63BDC0E0DA14840FE62B66455564C40D63BDC0E0DA1484093AB58FCA6584C405BECF65965A4484093AB58FCA6584C405BECF65965A44840FE62B66455564C40D63BDC0E0DA14840FE62B66455564C40
23128	Помосъял	7	62	1707	49.388179999999998	49.409163999999997	56.882962999999997	56.873086999999998	0103000020E610000001000000050000000B7BDAE1AFB1484008C89750C16F4C400B7BDAE1AFB14840FD497CEE04714C40AB59677C5FB44840FD497CEE04714C40AB59677C5FB4484008C89750C16F4C400B7BDAE1AFB1484008C89750C16F4C40
22842	Параньга	7	62	1707	49.386418999999997	49.424470999999997	56.716664999999999	56.691710999999998	0103000020E61000000100000005000000C9C6832D76B1484048A46DFC89584C40C9C6832D76B148400B98C0ADBB5B4C40DA8CD31055B648400B98C0ADBB5B4C40DA8CD31055B6484048A46DFC89584C40C9C6832D76B1484048A46DFC89584C40
23479	Олоры	7	62	1707	49.545330999999997	49.570951000000001	56.750818000000002	56.736454000000002	0103000020E610000001000000050000005B3FFD67CDC548401381EA1F445E4C405B3FFD67CDC54840C39FE1CD1A604C402B4F20EC14C94840C39FE1CD1A604C402B4F20EC14C948401381EA1F445E4C405B3FFD67CDC548401381EA1F445E4C40
23285	Мурзанаево	7	62	1707	49.238269000000003	49.259469000000003	56.749431000000001	56.736153000000002	0103000020E6100000010000000500000048533D997F9E484018EDF1423A5E4C4048533D997F9E4840E6CDE15AED5F4C40B5A9BA4736A14840E6CDE15AED5F4C40B5A9BA4736A1484018EDF1423A5E4C4048533D997F9E484018EDF1423A5E4C40
23036	Куянково	7	62	1707	49.452300999999999	49.472881999999998	56.77525	56.760159000000002	0103000020E610000001000000050000005B79C9FFE4B948404A61DEE34C614C405B79C9FFE4B94840AC1C5A643B634C40FC6EBA6587BC4840AC1C5A643B634C40FC6EBA6587BC48404A61DEE34C614C405B79C9FFE4B948404A61DEE34C614C40
23237	Куракино	7	62	1707	49.277830999999999	49.291620000000002	56.734833999999999	56.725135999999999	0103000020E61000000100000005000000516859F78FA348407D93A641D15C4C40516859F78FA3484093FE5E0A0F5E4C40056EDDCD53A5484093FE5E0A0F5E4C40056EDDCD53A548407D93A641D15C4C40516859F78FA348407D93A641D15C4C40
23337	Ирнур	7	62	1707	49.282671999999998	49.307124999999999	56.698413000000002	56.688527999999998	0103000020E6100000010000000500000059BF99982EA44840AD307DAF21584C4059BF99982EA44840F60CE19865594C405A643BDF4FA74840F60CE19865594C405A643BDF4FA74840AD307DAF21584C4059BF99982EA44840AD307DAF21584C40
23197	Ильпанур	7	62	1707	49.384784000000003	49.412497000000002	56.799818000000002	56.784373000000002	0103000020E610000001000000050000001503249A40B14840C66E9F5566644C401503249A40B148404660AC6F60664C405C59A2B3CCB448404660AC6F60664C405C59A2B3CCB44840C66E9F5566644C401503249A40B14840C66E9F5566644C40
23173	Илеть	7	62	1707	49.491118	49.510907000000003	56.584819000000003	56.564760999999997	0103000020E610000001000000050000000C3D62F4DCBE48403387A4164A484C400C3D62F4DCBE48402B8A5759DB4A4C4014268C6665C148402B8A5759DB4A4C4014268C6665C148403387A4164A484C400C3D62F4DCBE48403387A4164A484C40
23050	Елеево	7	62	1707	49.407277999999998	49.426924	56.861786000000002	56.849328999999997	0103000020E61000000100000005000000AD307DAF21B44840AE450BD0B66C4C40AD307DAF21B448404913EF004F6E4C4052F01472A5B648404913EF004F6E4C4052F01472A5B64840AE450BD0B66C4C40AD307DAF21B44840AE450BD0B66C4C40
22976	Алашайка	7	62	1707	49.467320999999998	49.505589000000001	56.786385000000003	56.763939000000001	0103000020E61000000100000005000000F4DDAD2CD1BB4840C991CEC0C8614C40F4DDAD2CD1BB484051888043A8644C40D21BEE23B7C0484051888043A8644C40D21BEE23B7C04840C991CEC0C8614C40F4DDAD2CD1BB4840C991CEC0C8614C40
22789	Шулка	7	62	1677	48.155835000000003	48.178930000000001	56.946972000000002	56.935969	0103000020E610000001000000050000003D49BA66F2134840F0880AD5CD774C403D49BA66F2134840261DE56036794C40FB22A12DE7164840261DE56036794C40FB22A12DE7164840F0880AD5CD774C403D49BA66F2134840F0880AD5CD774C40
22710	Чирки	7	62	1677	48.214764000000002	48.256644000000001	56.915740999999997	56.889882	0103000020E61000000100000005000000D82D02637D1B484048A643A7E7714C40D82D02637D1B48409C4D470037754C40795BE9B5D92048409C4D470037754C40795BE9B5D920484048A643A7E7714C40D82D02637D1B484048A643A7E7714C40
22670	Упша	7	62	1677	47.710773000000003	47.748421999999998	56.883237999999999	56.857007000000003	0103000020E610000001000000050000009EF0129CFADA4740B7B8C667B26D4C409EF0129CFADA4740CF4A5AF10D714C40AFCDC64ACCDF4740CF4A5AF10D714C40AFCDC64ACCDF4740B7B8C667B26D4C409EF0129CFADA4740B7B8C667B26D4C40
22645	Табашино	7	62	1677	47.694837	47.816217999999999	56.984721	56.958703999999997	0103000020E610000001000000050000007F86376BF0D84740AE450BD0B67A4C407F86376BF0D847409B5775560B7E4C400934D8D479E847409B5775560B7E4C400934D8D479E84740AE450BD0B67A4C407F86376BF0D84740AE450BD0B67A4C40
22596	Старое Крещено	7	62	1677	47.984903000000003	48.009112999999999	56.807958999999997	56.795766	0103000020E61000000100000005000000BC5D2F4D11FE474066A208A9DB654C40BC5D2F4D11FE474022C154336B674C40F67B629D2A01484022C154336B674C40F67B629D2A01484066A208A9DB654C40BC5D2F4D11FE474066A208A9DB654C40
22756	Отары	7	62	1677	48.289783	48.319372999999999	56.981969999999997	56.967163999999997	0103000020E61000000100000005000000E8F7FD9B172548402CEFAA07CC7B4C40E8F7FD9B1725484099D36531B17D4C40DA1CE736E128484099D36531B17D4C40DA1CE736E12848402CEFAA07CC7B4C40E8F7FD9B172548402CEFAA07CC7B4C40
22149	Оршанка	7	62	1677	47.862247000000004	47.917583999999998	56.931156000000001	56.910119000000002	0103000020E610000001000000050000007D09151C5EEE4740EF3B86C77E744C407D09151C5EEE4740B2BCAB1E30774C409BAA7B6473F54740B2BCAB1E30774C409BAA7B6473F54740EF3B86C77E744C407D09151C5EEE4740EF3B86C77E744C40
21902	Марково	7	62	1677	47.902124000000001	47.924734000000001	56.873804999999997	56.851337999999998	0103000020E61000000100000005000000E6779ACC78F34740C8EBC1A4F86C4C40E6779ACC78F34740670A9DD7D86F4C40E8BF07AF5DF64740670A9DD7D86F4C40E8BF07AF5DF64740C8EBC1A4F86C4C40E6779ACC78F34740C8EBC1A4F86C4C40
22408	Малый Пуял	7	62	1677	48.107802	48.122641999999999	56.857577999999997	56.849600000000002	0103000020E61000000100000005000000C138B874CC0D48403F575BB1BF6C4C40C138B874CC0D484071E2AB1DC56D4C40DA8EA9BBB20F484071E2AB1DC56D4C40DA8EA9BBB20F48403F575BB1BF6C4C40C138B874CC0D48403F575BB1BF6C4C40
22510	Малый Кугланур	7	62	1677	48.312600000000003	48.327772000000003	57.077855999999997	57.072122	0103000020E61000000100000005000000645DDC46032848403BA92F4B3B894C40645DDC460328484010E6762FF7894C40B345D26EF429484010E6762FF7894C40B345D26EF42948403BA92F4B3B894C40645DDC46032848403BA92F4B3B894C40
22446	Малая Каракша	7	62	1677	47.911977999999998	47.931094000000002	56.943482000000003	56.926755	0103000020E61000000100000005000000F355F2B1BBF44740C63368E89F764C40F355F2B1BBF44740AE2EA704C4784C403CC093162EF74740AE2EA704C4784C403CC093162EF74740C63368E89F764C40F355F2B1BBF44740C63368E89F764C40
22519	Лужбеляк	7	62	1677	48.207946	48.240150999999997	57.019477000000002	57.003675999999999	0103000020E61000000100000005000000C1AA7AF99D1A4840DAE3857478804C40C1AA7AF99D1A48401903EB387E824C40048D9944BD1E48401903EB387E824C40048D9944BD1E4840DAE3857478804C40C1AA7AF99D1A4840DAE3857478804C40
22353	Великополье	7	62	1677	48.055331000000002	48.104990000000001	56.823385000000002	56.807186000000002	0103000020E610000001000000050000003DBA11161507484000E5EFDE51674C403DBA1116150748402C82FFAD64694C401A34F44F700D48402C82FFAD64694C401A34F44F700D484000E5EFDE51674C403DBA11161507484000E5EFDE51674C40
22336	Большая Орша	7	62	1677	47.810836999999999	47.854118	56.929372999999998	56.913898000000003	0103000020E6100000010000000500000081B1BE81C9E747409EF0129CFA744C4081B1BE81C9E747408864C8B1F5764C40647616BD53ED47408864C8B1F5764C40647616BD53ED47409EF0129CFA744C4081B1BE81C9E747409EF0129CFA744C40
21694	Шура	7	62	1661	48.304937000000002	48.332478999999999	57.127887000000001	57.115124000000002	0103000020E61000000100000005000000912BF52C082748400B7E1B62BC8E4C40912BF52C08274840B24AE9995E904C40ABCDFFAB8E2A4840B24AE9995E904C40ABCDFFAB8E2A48400B7E1B62BC8E4C40912BF52C082748400B7E1B62BC8E4C40
22063	Чуксола	7	62	1661	48.759816999999998	48.770696000000001	57.008915999999999	57.004446000000002	0103000020E61000000100000005000000F0F8F6AE416148408C4CC0AF91804C40F0F8F6AE41614840A034D42824814C403A94A12AA6624840A034D42824814C403A94A12AA66248408C4CC0AF91804C40F0F8F6AE416148408C4CC0AF91804C40
21778	Токтарсола	7	62	1661	48.710014000000001	48.7271	56.928021999999999	56.915087	0103000020E61000000100000005000000E0D91EBDE15A484054FF209221754C40E0D91EBDE15A4840F8FBC56CC9764C40F775E09C115D4840F8FBC56CC9764C40F775E09C115D484054FF209221754C40E0D91EBDE15A484054FF209221754C40
21772	Старый Торъял	7	62	1661	48.768369	48.803609999999999	56.970545000000001	56.954134000000003	0103000020E610000001000000050000004F2157EA5962484037001B10217A4C404F2157EA59624840EE258DD13A7C4C40895E46B1DC664840EE258DD13A7C4C40895E46B1DC66484037001B10217A4C404F2157EA5962484037001B10217A4C40
61561	Старокрещено	7	62	1661	48.221905999999997	48.944195999999998	57.174191	56.867198000000002	0103000020E61000000100000005000000A164726A671C48400C941458006F4C40A164726A671C4840F72004E44B964C40CB811E6ADB784840F72004E44B964C40CB811E6ADB7848400C941458006F4C40A164726A671C48400C941458006F4C40
21638	Пектубаево	7	62	1661	48.380135000000003	48.394337	57.038375000000002	57.026384999999998	0103000020E6100000010000000500000051888043A83048406F0D6C9560834C4051888043A8304840F4FDD478E9844C40274D83A279324840F4FDD478E9844C40274D83A2793248406F0D6C9560834C4051888043A83048406F0D6C9560834C40
21241	Новый Торъял	7	62	1661	48.712152000000003	48.748443999999999	57.023715000000003	56.993366000000002	0103000020E61000000100000005000000F8E3F6CB275B4840AB7AF99D267F4C40F8E3F6CB275B48405BB6D61709834C4097715303CD5F48405BB6D61709834C4097715303CD5F4840AB7AF99D267F4C40F8E3F6CB275B4840AB7AF99D267F4C40
21936	Немда-Обалыш	7	62	1661	48.797753	48.818944000000002	57.077846000000001	57.060191000000003	0103000020E6100000010000000500000098A432C51C664840BC41B456B4874C4098A432C51C664840ED0F94DBF6894C40B2A03028D3684840ED0F94DBF6894C40B2A03028D3684840BC41B456B4874C4098A432C51C664840BC41B456B4874C40
21484	Масканур	7	62	1661	48.641105000000003	48.655397000000001	57.127589	57.114674000000001	0103000020E61000000100000005000000AB2688BA0F524840CBD93BA3AD8E4C40AB2688BA0F524840282A1BD654904C40C172840CE4534840282A1BD654904C40C172840CE4534840CBD93BA3AD8E4C40AB2688BA0F524840CBD93BA3AD8E4C40
21861	Кузнецы	7	62	1661	48.872996000000001	48.888195000000003	56.945720000000001	56.93479	0103000020E61000000100000005000000F8C43A55BE6F48405D50DF32A7774C40F8C43A55BE6F484029965B5A0D794C4041BCAE5FB071484029965B5A0D794C4041BCAE5FB07148405D50DF32A7774C40F8C43A55BE6F48405D50DF32A7774C40
58075	Куан-Памаш	7	62	1661	48.557903000000003	48.577513000000003	57.087629	57.079113	0103000020E610000001000000050000008FAB915D694748401FD8F15F208A4C408FAB915D694748403197546D378B4C40E7012CF2EB4948403197546D378B4C40E7012CF2EB4948401FD8F15F208A4C408FAB915D694748401FD8F15F208A4C40
21611	Кремленки	7	62	1661	48.456986000000001	48.474781999999998	57.082600999999997	57.071255999999998	0103000020E610000001000000050000006C5D6A847E3A484067D2A6EA1E894C406C5D6A847E3A4840F6CE68AB928A4C405F5D15A8C53C4840F6CE68AB928A4C405F5D15A8C53C484067D2A6EA1E894C406C5D6A847E3A484067D2A6EA1E894C40
21566	Елембаево	7	62	1661	48.584995999999997	48.602459000000003	56.983299000000002	56.959234000000002	0103000020E6100000010000000500000039252026E14A48400B9B012EC87A4C4039252026E14A48404298DBBDDC7D4C40271763601D4D48404298DBBDDC7D4C40271763601D4D48400B9B012EC87A4C4039252026E14A48400B9B012EC87A4C40
22078	Большой Шуйбеляк	7	62	1661	48.710256999999999	48.733065000000003	56.979948999999998	56.963503000000003	0103000020E61000000100000005000000A6608DB3E95A4840884CF910547B4C40A6608DB3E95A4840BB5F05F86E7D4C40CF6BEC12D55D4840BB5F05F86E7D4C40CF6BEC12D55D4840884CF910547B4C40A6608DB3E95A4840884CF910547B4C40
58072	Большой Ломарь	7	62	1661	48.705064999999998	48.733946000000003	57.125791	57.104453999999997	0103000020E61000000100000005000000F146E6913F5A4840DBF7A8BF5E8D4C40F146E6913F5A4840C99063EB19904C40D88349F1F15D4840C99063EB19904C40D88349F1F15D4840DBF7A8BF5E8D4C40F146E6913F5A4840DBF7A8BF5E8D4C40
20473	Ямбатор	7	62	1583	49.492221999999998	49.499678000000003	56.439418000000003	56.428821999999997	0103000020E61000000100000005000000942F682101BF484014E7A8A3E3364C40942F682101BF48400AA359D93E384C40EE43DE72F5BF48400AA359D93E384C40EE43DE72F5BF484014E7A8A3E3364C40942F682101BF484014E7A8A3E3364C40
20561	Шоруньжа	7	62	1583	49.498376	49.522692999999997	56.470671000000003	56.454144999999997	0103000020E610000001000000050000003F8EE6C8CABF48402A52616C213A4C403F8EE6C8CABF48407B1684F23E3C4C408F6CAE9AE7C248407B1684F23E3C4C408F6CAE9AE7C248402A52616C213A4C403F8EE6C8CABF48402A52616C213A4C40
20072	Шордур	7	62	1583	49.087027999999997	49.110132999999998	56.579161999999997	56.563169000000002	0103000020E610000001000000050000000BEBC6BB238B48407E8FFAEB15484C400BEBC6BB238B4840008BFCFA214A4C40ED9A90D6188E4840008BFCFA214A4C40ED9A90D6188E48407E8FFAEB15484C400BEBC6BB238B48407E8FFAEB15484C40
20338	Шиньша	7	62	1583	49.351519000000003	49.376384999999999	56.441667000000002	56.409703	0103000020E6100000010000000500000019761893FEAC48405B09DD2571344C4019761893FEAC4840795C548B88384C403CDA38622DB04840795C548B88384C403CDA38622DB048405B09DD2571344C4019761893FEAC48405B09DD2571344C40
21039	Шереганово	7	62	1583	48.695435000000003	48.719213000000003	56.347423999999997	56.328907999999998	0103000020E6100000010000000500000034BF9A030459484046B247A8192A4C4034BF9A030459484039ECBE63782C4C40D5EDEC2B0F5C484039ECBE63782C4C40D5EDEC2B0F5C484046B247A8192A4C4034BF9A030459484046B247A8192A4C40
58070	Уньжа	7	62	1583	49.497055000000003	49.519801000000001	56.522570000000002	56.513035000000002	0103000020E610000001000000050000001AA88C7F9FBF4840085A8121AB414C401AA88C7F9FBF484074EFE192E3424C40CCB6D3D688C2484074EFE192E3424C40CCB6D3D688C24840085A8121AB414C401AA88C7F9FBF4840085A8121AB414C40
19669	Тыгыде-Морко	7	62	1583	48.851185000000001	48.872186999999997	56.443314000000001	56.431804	0103000020E6100000010000000500000042EC4CA1F36C484018247D5A45374C4042EC4CA1F36C4840F2ED5D83BE384C40887FD8D2A36F4840F2ED5D83BE384C40887FD8D2A36F484018247D5A45374C4042EC4CA1F36C484018247D5A45374C40
20252	Токпердино	7	62	1583	49.348168999999999	49.363205999999998	56.392094	56.384180999999998	0103000020E61000000100000005000000923D42CD90AC48404E5FCFD72C314C40923D42CD90AC48409A7ADD2230324C4001DBC1887DAE48409A7ADD2230324C4001DBC1887DAE48404E5FCFD72C314C40923D42CD90AC48404E5FCFD72C314C40
20378	Татарский Чодраял	7	62	1583	49.332816000000001	49.349193	56.416131999999998	56.400627999999998	0103000020E61000000100000005000000F3CAF5B699AA484052EE3EC747334C40F3CAF5B699AA4840D76839D043354C40FE7E315BB2AC4840D76839D043354C40FE7E315BB2AC484052EE3EC747334C40F3CAF5B699AA484052EE3EC747334C40
19367	Старое Мазиково	7	62	1583	49.101042	49.111103	56.404817000000001	56.391845000000004	0103000020E61000000100000005000000DFC2BAF1EE8C4840F20C1AFA27324C40DFC2BAF1EE8C4840B3EE1F0BD1334C4066BE839F388E4840B3EE1F0BD1334C4066BE839F388E4840F20C1AFA27324C40DFC2BAF1EE8C4840F20C1AFA27324C40
19889	Семисола	7	62	1583	49.073112999999999	49.092571	56.523646999999997	56.51088	0103000020E61000000100000005000000CBF44BC45B8948401A170E8464414C40CBF44BC45B89484002D369DD06434C406DC7D45DD98B484002D369DD06434C406DC7D45DD98B48401A170E8464414C40CBF44BC45B8948401A170E8464414C40
19720	Себеусад	7	62	1583	48.803528999999997	48.829832000000003	56.486941000000002	56.476458000000001	0103000020E610000001000000050000009C31CC09DA66484073F56393FC3C4C409C31CC09DA664840700A2B15543E4C404F965AEF376A4840700A2B15543E4C404F965AEF376A484073F56393FC3C4C409C31CC09DA66484073F56393FC3C4C40
20023	Петровское	7	62	1583	49.246595999999997	49.275692999999997	56.562196999999998	56.548231999999999	0103000020E6100000010000000500000086A92D75909F4840724F57772C464C4086A92D75909F484064744012F6474C40395E81E849A3484064744012F6474C40395E81E849A34840724F57772C464C4086A92D75909F4840724F57772C464C40
20779	Осипсола	7	62	1583	48.725698999999999	48.735041000000002	56.422424999999997	56.414169999999999	0103000020E61000000100000005000000B5DE6FB4E35C4840FE7DC68503354C40B5DE6FB4E35C4840A301BC0512364C400D1CD0D2155E4840A301BC0512364C400D1CD0D2155E4840FE7DC68503354C40B5DE6FB4E35C4840FE7DC68503354C40
21139	Октябрьский	7	62	1583	48.587547000000001	48.617443000000002	56.321311000000001	56.303721000000003	0103000020E6100000010000000500000074EE76BD344B4840E10D6954E0264C4074EE76BD344B48402B6C06B820294C4073124A5F084F48402B6C06B820294C4073124A5F084F4840E10D6954E0264C4074EE76BD344B4840E10D6954E0264C40
20139	Нуж-Ключ	7	62	1583	49.284334000000001	49.298518999999999	56.418094000000004	56.390255000000003	0103000020E610000001000000050000000892770E65A44840DD0C37E0F3314C400892770E65A44840B153AC1A84354C40081EDFDE35A64840B153AC1A84354C40081EDFDE35A64840DD0C37E0F3314C400892770E65A44840DD0C37E0F3314C40
19100	Морки	7	62	1583	48.963115000000002	49.025115999999997	56.447806999999997	56.420687999999998	0103000020E61000000100000005000000BEA4315A477B4840EAE8B81AD9354C40BEA4315A477B4840BEF561BD51394C409C4D470037834840BEF561BD51394C409C4D470037834840EAE8B81AD9354C40BEA4315A477B4840EAE8B81AD9354C40
19452	Мари-Кужеры	7	62	1583	49.034477000000003	49.061039999999998	56.364604999999997	56.352342999999998	0103000020E610000001000000050000006BBB09BE69844840BDFC4E93192D4C406BBB09BE69844840A27A6B60AB2E4C40B9DFA128D0874840A27A6B60AB2E4C40B9DFA128D0874840BDFC4E93192D4C406BBB09BE69844840BDFC4E93192D4C40
19464	Кучко-Памаш	7	62	1583	48.949998999999998	48.979841	56.384216000000002	56.370828000000003	0103000020E61000000100000005000000C91D3691997948407638BA4A772F4C40C91D369199794840CB4C69FD2D314C40D5230D6E6B7D4840CB4C69FD2D314C40D5230D6E6B7D48407638BA4A772F4C40C91D3691997948407638BA4A772F4C40
21108	Кутюк-Кинер	7	62	1583	48.665143999999998	48.694267000000004	56.363079999999997	56.354267999999998	0103000020E61000000100000005000000B890477023554840790261A7582D4C40B89047702355484074EACA67792E4C4095D8B5BDDD58484074EACA67792E4C4095D8B5BDDD584840790261A7582D4C40B890477023554840790261A7582D4C40
20925	Кульбаш	7	62	1583	48.784951999999997	48.809530000000002	56.297553000000001	56.278627	0103000020E610000001000000050000000377A04E796448402C64AE0CAA234C400377A04E79644840D1E9793716264C40C190D5AD9E674840D1E9793716264C40C190D5AD9E6748402C64AE0CAA234C400377A04E796448402C64AE0CAA234C40
21197	Красный Стекловар	7	62	1583	48.774199000000003	48.807006000000001	56.229996999999997	56.215592999999998	0103000020E6100000010000000500000047CCECF3186348408E1F2A8D981B4C4047CCECF318634840CC96AC8A701D4C4080D6FCF84B674840CC96AC8A701D4C4080D6FCF84B6748408E1F2A8D981B4C4047CCECF3186348408E1F2A8D981B4C40
20911	Коркатово	7	62	1583	48.746234000000001	48.767586999999999	56.356447000000003	56.338898	0103000020E61000000100000005000000E6948098845F484004577902612B4C40E6948098845F4840F0E0270EA02D4C40D9EA724A40624840F0E0270EA02D4C40D9EA724A4062484004577902612B4C40E6948098845F484004577902612B4C40
19797	Изи-Кугунур	7	62	1583	48.744661999999998	48.761802000000003	56.615792999999996	56.603026999999997	0103000020E6100000010000000500000077499C15515F484070CD1DFD2F4D4C4077499C15515F4840880D164ED24E4C4082035ABA82614840880D164ED24E4C4082035ABA8261484070CD1DFD2F4D4C4077499C15515F484070CD1DFD2F4D4C40
20830	Изи Шурга	7	62	1583	48.701759000000003	48.713141	56.475265	56.463849000000003	0103000020E610000001000000050000003B56293DD359484023A46E675F3B4C403B56293DD35948407BF7C77BD53C4C40E7374C34485B48407BF7C77BD53C4C40E7374C34485B484023A46E675F3B4C403B56293DD359484023A46E675F3B4C40
19881	Зеленогорск	7	62	1583	48.774639000000001	48.799450999999998	56.532544000000001	56.509518999999997	0103000020E61000000100000005000000639AE95E2763484066D828EB37414C40639AE95E276348402CD7DB662A444C4093E00D69546648402CD7DB662A444C4093E00D695466484066D828EB37414C40639AE95E2763484066D828EB37414C40
20206	Досметкино	7	62	1583	49.279034000000003	49.292301999999999	56.362805000000002	56.351948999999998	0103000020E610000001000000050000006D3CD862B7A34840116E32AA0C2D4C406D3CD862B7A34840A3E9EC64702E4C401747E5266AA54840A3E9EC64702E4C401747E5266AA54840116E32AA0C2D4C406D3CD862B7A34840116E32AA0C2D4C40
19746	Весьшурга	7	62	1583	48.791392999999999	48.816113999999999	56.559289999999997	56.546207000000003	0103000020E6100000010000000500000044A4A65D4C65484053EC681CEA454C4044A4A65D4C6548406B7D91D096474C4064E76D6C766848406B7D91D096474C4064E76D6C7668484053EC681CEA454C4044A4A65D4C65484053EC681CEA454C40
58063	Большой Кожлоял	7	62	1583	48.89893	48.917444000000003	56.450752000000001	56.442812000000004	0103000020E6100000010000000500000057B263231073484060234910AE384C4057B2632310734840A54DD53DB2394C40AAF413CE6E754840A54DD53DB2394C40AAF413CE6E75484060234910AE384C4057B263231073484060234910AE384C40
20697	Большие Шали	7	62	1583	48.825726000000003	48.847079000000001	56.428109999999997	56.410744000000001	0103000020E610000001000000050000007CBABA63B16948409D83674293344C407CBABA63B1694840978BF84ECC364C406F10AD156D6C4840978BF84ECC364C406F10AD156D6C48409D83674293344C407CBABA63B16948409D83674293344C40
19972	Алмаметьево	7	62	1583	49.060150999999998	49.085321999999998	56.498325999999999	56.486086999999998	0103000020E610000001000000050000002DE92807B387484060014C19383E4C402DE92807B38748408D5F7825C93F4C408DD0CFD4EB8A48408D5F7825C93F4C408DD0CFD4EB8A484060014C19383E4C402DE92807B387484060014C19383E4C40
20751	Азъял	7	62	1583	48.843584999999997	48.922071000000003	56.440871000000001	56.395746000000003	0103000020E61000000100000005000000B532E197FA6B4840ECC20FCEA7324C40B532E197FA6B48409E60FF756E384C4086CB2A6C067648409E60FF756E384C4086CB2A6C06764840ECC20FCEA7324C40B532E197FA6B4840ECC20FCEA7324C40
19560	Адымаш	7	62	1583	48.958317999999998	48.981682999999997	56.351550000000003	56.338234999999997	0103000020E6100000010000000500000085950A2AAA7A484068AED3484B2B4C4085950A2AAA7A484054742497FF2C4C400305DEC9A77D484054742497FF2C4C400305DEC9A77D484068AED3484B2B4C4085950A2AAA7A484068AED3484B2B4C40
58054	поселение Юбилейный	7	62	1452	47.184693000000003	48.364593999999997	56.924112000000001	56.319294999999997	0103000020E610000001000000050000006B662D05A49747405E6397A8DE284C406B662D05A4974740ABEB504D49764C40AE282504AB2E4840ABEB504D49764C40AE282504AB2E48405E6397A8DE284C406B662D05A49747405E6397A8DE284C40
18012	Яныкайсола	7	62	1452	47.642887999999999	47.673332000000002	56.795893999999997	56.781917	0103000020E61000000100000005000000D47E6B274AD24740DD9733DB15644C40D47E6B274AD24740938AC6DADF654C40D6AC33BE2FD64740938AC6DADF654C40D6AC33BE2FD64740DD9733DB15644C40D47E6B274AD24740DD9733DB15644C40
58061	Якимово	7	62	1452	47.987050000000004	47.998396	56.698126999999999	56.678713999999999	0103000020E6100000010000000500000027C286A757FE47402EABB019E0564C4027C286A757FE474030BABC395C594C40863AAC70CBFF474030BABC395C594C40863AAC70CBFF47402EABB019E0564C4027C286A757FE47402EABB019E0564C40
18805	Шойбулак	7	62	1452	47.900866000000001	47.926791000000001	56.729061999999999	56.717767000000002	0103000020E61000000100000005000000070ABC934FF34740F392FFC9DF5B4C40070ABC934FF34740D06053E7515D4C40139D6516A1F64740D06053E7515D4C40139D6516A1F64740F392FFC9DF5B4C40070ABC934FF34740F392FFC9DF5B4C40
17293	Шеклянур	7	62	1452	47.610377999999997	47.643192999999997	56.662070999999997	56.644995000000002	0103000020E610000001000000050000005419C6DD20CE4740B18A37328F524C405419C6DD20CE4740A45016BEBE544C401002F22554D24740A45016BEBE544C401002F22554D24740B18A37328F524C405419C6DD20CE4740B18A37328F524C40
18951	Цибикнур	7	62	1452	47.808348000000002	47.844802000000001	56.742649	56.724621999999997	0103000020E61000000100000005000000BDE47FF277E7474026FBE769C05C4C40BDE47FF277E747401CB4571F0F5F4C4036CCD07822EC47401CB4571F0F5F4C4036CCD07822EC474026FBE769C05C4C40BDE47FF277E7474026FBE769C05C4C40
17452	Томшарово	7	62	1452	48.101621000000002	48.133718000000002	56.774977999999997	56.765557000000001	0103000020E610000001000000050000001DCBBBEA010D4840A81C93C5FD614C401DCBBBEA010D48404B8FA67A32634C407A71E2AB1D1148404B8FA67A32634C407A71E2AB1D114840A81C93C5FD614C401DCBBBEA010D4840A81C93C5FD614C40
17807	Сурок	7	62	1452	48.104666999999999	48.136997000000001	56.455956	56.437009000000003	0103000020E6100000010000000500000037FC6EBA650D4840628731E9EF374C4037FC6EBA650D48401E3526C45C3A4C403753211E891148401E3526C45C3A4C403753211E89114840628731E9EF374C4037FC6EBA650D4840628731E9EF374C40
18780	Средняя Турша	7	62	1452	47.572118000000003	47.592042999999997	56.885067999999997	56.875191999999998	0103000020E61000000100000005000000FAB9A1293BC9474044DC9C4A06704C40FAB9A1293BC94740395E81E849714C40B169A510C8CB4740395E81E849714C40B169A510C8CB474044DC9C4A06704C40FAB9A1293BC9474044DC9C4A06704C40
58079	Средние Шапы	7	62	1452	47.184693000000003	48.364593999999997	56.924112000000001	56.319294999999997	0103000020E610000001000000050000006B662D05A49747405E6397A8DE284C406B662D05A4974740ABEB504D49764C40AE282504AB2E4840ABEB504D49764C40AE282504AB2E48405E6397A8DE284C406B662D05A49747405E6397A8DE284C40
17235	Среднее Азяково	7	62	1452	47.638503999999998	47.655455000000003	56.626103999999998	56.615045000000002	0103000020E61000000100000005000000BE2EC37FBAD14740BF4868CBB94E4C40BE2EC37FBAD1474088F2052D24504C40F67F0EF3E5D3474088F2052D24504C40F67F0EF3E5D34740BF4868CBB94E4C40BE2EC37FBAD14740BF4868CBB94E4C40
17756	Силикатный	7	62	1452	48.177269000000003	48.207093	56.393295000000002	56.368754000000003	0103000020E610000001000000050000001DCC26C0B01648407522C154332F4C401DCC26C0B01648401557957D57324C40821DFF05821A48401557957D57324C40821DFF05821A48407522C154332F4C401DCC26C0B01648407522C154332F4C40
18487	Сенькино	7	62	1452	47.904297	47.920566000000001	56.681511999999998	56.673239000000002	0103000020E610000001000000050000007A6F0C01C0F3474025B20FB22C564C407A6F0C01C0F3474070EA03C93B574C409FE74F1BD5F5474070EA03C93B574C409FE74F1BD5F5474025B20FB22C564C407A6F0C01C0F3474025B20FB22C564C40
18406	Руэм	7	62	1452	47.749994000000001	47.768211999999998	56.637045000000001	56.621271	0103000020E610000001000000050000001E19ABCDFFDF4740037AE1CE854F4C401E19ABCDFFDF4740488AC8B08A514C40873254C554E24740488AC8B08A514C40873254C554E24740037AE1CE854F4C401E19ABCDFFDF4740037AE1CE854F4C40
18319	Русский Кукмор	7	62	1452	48.134751000000001	48.159680000000002	56.679321999999999	56.667392999999997	0103000020E61000000100000005000000390D51853F114840274A42226D554C40390D51853F11484006BAF605F4564C40A3E9EC647014484006BAF605F4564C40A3E9EC6470144840274A42226D554C40390D51853F114840274A42226D554C40
18288	Пижма	7	62	1452	47.37086	47.395778999999997	56.836070999999997	56.819310999999999	0103000020E6100000010000000500000081B2295778AF47406420CF2EDF684C4081B2295778AF47402711E15F046B4C40C7B8E2E2A8B247402711E15F046B4C40C7B8E2E2A8B247406420CF2EDF684C4081B2295778AF47406420CF2EDF684C40
17884	Пемба	7	62	1452	48.039548000000003	48.061636999999997	56.521183999999998	56.507924000000003	0103000020E61000000100000005000000A54FABE80F054840406D54A703414C40A54FABE80F05484067994528B6424C409D9CA1B8E307484067994528B6424C409D9CA1B8E3074840406D54A703414C40A54FABE80F054840406D54A703414C40
18191	Пекшиксола	7	62	1452	47.710962000000002	47.745538000000003	56.680365000000002	56.672468000000002	0103000020E61000000100000005000000715985CD00DB4740A3CD716E13564C40715985CD00DB4740E92B483316574C406FF607CA6DDF4740E92B483316574C406FF607CA6DDF4740A3CD716E13564C40715985CD00DB4740A3CD716E13564C40
18935	Орешкино	7	62	1452	47.846741999999999	47.856588000000002	56.732849000000002	56.724770999999997	0103000020E610000001000000050000002713B70A62EC47406B0BCF4BC55C4C402713B70A62EC474002F4FBFECD5D4C40B212F3ACA4ED474002F4FBFECD5D4C40B212F3ACA4ED47406B0BCF4BC55C4C402713B70A62EC47406B0BCF4BC55C4C40
18025	Нурма	7	62	1452	47.698403999999996	47.725155000000001	56.718266	56.701723999999999	0103000020E61000000100000005000000A2B2614D65D94740BE688F17D2594C40A2B2614D65D9474014EAE923F05B4C40F4C308E1D1DC474014EAE923F05B4C40F4C308E1D1DC4740BE688F17D2594C40A2B2614D65D94740BE688F17D2594C40
18233	Новый	7	62	1452	47.810549000000002	47.829332999999998	56.681576	56.672631000000003	0103000020E610000001000000050000001B67D311C0E747404DA3C9C518564C401B67D311C0E7474087DEE2E13D574C402D3F709527EA474087DEE2E13D574C402D3F709527EA47404DA3C9C518564C401B67D311C0E747404DA3C9C518564C40
17670	Новое Комино	7	62	1452	48.017898000000002	48.032666999999996	56.724198000000001	56.716704999999997	0103000020E61000000100000005000000F8544E7B4A02484099F04BFDBC5B4C40F8544E7B4A02484010EA2285B25C4C404754A86E2E04484010EA2285B25C4C404754A86E2E04484099F04BFDBC5B4C40F8544E7B4A02484099F04BFDBC5B4C40
16500	Медведево	7	62	1452	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
17945	Люльпаны	7	62	1452	47.547792000000001	47.579889000000001	56.835721999999997	56.815286	0103000020E6100000010000000500000056815A0C1EC647407E71A94A5B684C4056815A0C1EC647401B4641F0F86A4C40B32781CD39CA47401B4641F0F86A4C40B32781CD39CA47407E71A94A5B684C4056815A0C1EC647407E71A94A5B684C40
17619	Кузнецово	7	62	1452	48.025184000000003	48.057091999999997	56.697786000000001	56.686965000000001	0103000020E61000000100000005000000F530B43A39034840923F1878EE574C40F530B43A39034840A7CD380D51594C407E6E68CA4E074840A7CD380D51594C407E6E68CA4E074840923F1878EE574C40F530B43A39034840923F1878EE574C40
17097	Краснооктябрьский	7	62	1452	47.639949999999999	47.686940999999997	56.685155999999999	56.667344	0103000020E61000000100000005000000A089B0E1E9D14740469737876B554C40A089B0E1E9D147403F541A31B3574C4009A4C4AEEDD747403F541A31B3574C4009A4C4AEEDD74740469737876B554C40A089B0E1E9D14740469737876B554C40
17702	Ким	7	62	1452	48.089081	48.111241999999997	56.735975000000003	56.722715999999998	0103000020E61000000100000005000000F5D89601670B4840E12538F5815C4C40F5D89601670B484039D6C56D345E4C4087F8872D3D0E484039D6C56D345E4C4087F8872D3D0E4840E12538F5815C4C40F5D89601670B4840E12538F5815C4C40
17480	Знаменский	7	62	1452	47.989215000000002	47.997326999999999	56.641708000000001	56.633426999999998	0103000020E6100000010000000500000038DBDC989EFE4740A2B3CC2214514C4038DBDC989EFE474071CADC7C23524C407A354069A8FF474071CADC7C23524C407A354069A8FF4740A2B3CC2214514C4038DBDC989EFE4740A2B3CC2214514C40
17400	Ежово	7	62	1452	48.107478	48.136305	56.723812000000002	56.706923000000003	0103000020E610000001000000050000000E85CFD6C10D484026E5EE737C5A4C400E85CFD6C10D4840E73922DFA55C4C4001A4367172114840E73922DFA55C4C4001A436717211484026E5EE737C5A4C400E85CFD6C10D484026E5EE737C5A4C40
58064	Аэропорт	7	62	1452	47.184693000000003	48.364593999999997	56.924112000000001	56.319294999999997	0103000020E610000001000000050000006B662D05A49747405E6397A8DE284C406B662D05A4974740ABEB504D49764C40AE282504AB2E4840ABEB504D49764C40AE282504AB2E48405E6397A8DE284C406B662D05A49747405E6397A8DE284C40
18106	Арбаны	7	62	1452	47.749644000000004	47.782046000000001	56.723190000000002	56.710805999999998	0103000020E6100000010000000500000042D2A755F4DF474079E6E5B0FB5A4C4042D2A755F4DF4740AA656B7D915C4C40DBFB54151AE44740AA656B7D915C4C40DBFB54151AE4474079E6E5B0FB5A4C4042D2A755F4DF474079E6E5B0FB5A4C40
58103	Аксарка	7	62	1452	47.954334000000003	47.974932000000003	56.770913999999998	56.764130999999999	0103000020E61000000100000005000000FEBAD39D27FA47400D6E6B0BCF614C40FEBAD39D27FA4740A703594FAD624C4075E95F92CAFC4740A703594FAD624C4075E95F92CAFC47400D6E6B0BCF614C40FEBAD39D27FA47400D6E6B0BCF614C40
17197	Азаново	7	62	1452	48.202483999999998	48.236476000000003	56.723373000000002	56.709265000000002	0103000020E610000001000000050000004CFBE6FEEA19484046990D32C95A4C404CFBE6FEEA1948409BE7887C975C4C40FB2477D8441E48409BE7887C975C4C40FB2477D8441E484046990D32C95A4C404CFBE6FEEA19484046990D32C95A4C40
16427	Хлебниково	7	62	1390	49.926566999999999	49.962373999999997	56.659874000000002	56.637143999999999	0103000020E61000000100000005000000C34659BF99F64840DB6B41EF8D514C40C34659BF99F6484088BD50C076544C40A6423C122FFB484088BD50C076544C40A6423C122FFB4840DB6B41EF8D514C40C34659BF99F64840DB6B41EF8D514C40
15619	Тат-Китня	7	62	1390	49.694459999999999	49.724274999999999	56.812488000000002	56.795381999999996	0103000020E61000000100000005000000A930B610E4D84840DDE9CE13CF654C40A930B610E4D848403C32569BFF674C40BB270F0BB5DC48403C32569BFF674C40BB270F0BB5DC4840DDE9CE13CF654C40A930B610E4D84840DDE9CE13CF654C40
15832	Сысоево	7	62	1390	49.623322999999999	49.647756999999999	57.011876000000001	56.992674999999998	0103000020E610000001000000050000001CEC4D0CC9CF4840454772F90F7F4C401CEC4D0CC9CF4840BCCD1B2785814C40A6608DB3E9D24840BCCD1B2785814C40A6608DB3E9D24840454772F90F7F4C401CEC4D0CC9CF4840454772F90F7F4C40
58067	Совхоз Павловский	7	62	1390	49.806686999999997	49.821508999999999	56.484614999999998	56.474260999999998	0103000020E61000000100000005000000DE8D058541E7484056629E95B43C4C40DE8D058541E74840551344DD073E4C40512FF83427E94840551344DD073E4C40512FF83427E9484056629E95B43C4C40DE8D058541E7484056629E95B43C4C40
15993	Сенда	7	62	1390	49.901198000000001	49.933357999999998	56.799137999999999	56.781069000000002	0103000020E610000001000000050000003D9CC0745AF34840B075A911FA634C403D9CC0745AF34840D47E6B274A664C40E0BA624678F74840D47E6B274A664C40E0BA624678F74840B075A911FA634C403D9CC0745AF34840B075A911FA634C40
15738	Сардаял	7	62	1390	49.961413	49.987139999999997	56.454487999999998	56.441608000000002	0103000020E610000001000000050000008179C8940FFB484074D3669C86384C408179C8940FFB48405436ACA92C3A4C406649809A5AFE48405436ACA92C3A4C406649809A5AFE484074D3669C86384C408179C8940FFB484074D3669C86384C40
16121	Мариец	7	62	1390	49.812184000000002	49.853102999999997	56.523831000000001	56.508302	0103000020E61000000100000005000000D02A33A5F5E74840E63E390A10414C40D02A33A5F5E74840C4D0EAE40C434C404B8FA67A32ED4840C4D0EAE40C434C404B8FA67A32ED4840E63E390A10414C40D02A33A5F5E74840E63E390A10414C40
15262	Мари-Турек	7	62	1390	49.598188	49.638854000000002	56.797994000000003	56.778543999999997	0103000020E61000000100000005000000096EA46C91CC48409E3F6D54A7634C40096EA46C91CC4840BE33DAAA24664C409B75C6F7C5D14840BE33DAAA24664C409B75C6F7C5D148409E3F6D54A7634C40096EA46C91CC48409E3F6D54A7634C40
15431	Мари-Купта	7	62	1390	49.697380000000003	49.719909000000001	56.859684999999999	56.842058999999999	0103000020E61000000100000005000000377172BF43D94840B726DD96C86B4C40377172BF43D948404EEE77280A6E4C404C8C65FA25DC48404EEE77280A6E4C404C8C65FA25DC4840B726DD96C86B4C40377172BF43D94840B726DD96C86B4C40
15371	Мари-Китня	7	62	1390	49.643166000000001	49.658194999999999	56.829044000000003	56.816473999999999	0103000020E6100000010000000500000017F3734353D248406404543882684C4017F3734353D24840F778211D1E6A4C4003B2D7BB3FD44840F778211D1E6A4C4003B2D7BB3FD448406404543882684C4017F3734353D248406404543882684C40
15904	Мари-Билямор	7	62	1390	49.889915999999999	49.913325999999998	56.851303000000001	56.832467000000001	0103000020E61000000100000005000000F4177AC4E8F14840E7FF55478E6A4C40F4177AC4E8F148404CFE277FF76C4C40124BCADDE7F448404CFE277FF76C4C40124BCADDE7F44840E7FF55478E6A4C40F4177AC4E8F14840E7FF55478E6A4C40
15715	Лопово	7	62	1390	50.160846999999997	50.177484	56.562950999999998	56.553814000000003	0103000020E6100000010000000500000071546EA29614494092088D60E3464C4071546EA296144940102043C70E484C4019C8B3CBB7164940102043C70E484C4019C8B3CBB716494092088D60E3464C4071546EA29614494092088D60E3464C40
16294	Лом	7	62	1390	49.969892999999999	49.990786999999997	56.614519999999999	56.606118000000002	0103000020E6100000010000000500000046CF2D7425FC48402BC24D46954D4C4046CF2D7425FC4840745E6397A84E4C40A626C11BD2FE4840745E6397A84E4C40A626C11BD2FE48402BC24D46954D4C4046CF2D7425FC48402BC24D46954D4C40
16227	Крупино	7	62	1390	49.981363999999999	50.016900999999997	56.715727000000001	56.707149999999999	0103000020E6100000010000000500000062BCE6559DFD4840E6AE25E4835A4C4062BCE6559DFD48409EEE3CF19C5B4C408522DDCF290249409EEE3CF19C5B4C408522DDCF29024940E6AE25E4835A4C4062BCE6559DFD4840E6AE25E4835A4C40
15796	Косолапово	7	62	1390	49.585414	49.616647999999998	56.941865999999997	56.912851000000003	0103000020E610000001000000050000006E4F90D8EECA48407A8F334DD8744C406E4F90D8EECA48406F9BA9108F784C4068925852EECE48406F9BA9108F784C4068925852EECE48407A8F334DD8744C406E4F90D8EECA48407A8F334DD8744C40
16331	Ивская Вершина	7	62	1390	49.959400000000002	49.978560999999999	56.675261999999996	56.665166999999997	0103000020E6100000010000000500000026E4839ECDFA484070B0373124554C4026E4839ECDFA4840A31D37FC6E564C400E12A27C41FD4840A31D37FC6E564C400E12A27C41FD484070B0373124554C4026E4839ECDFA484070B0373124554C40
15943	Елымбаево	7	62	1390	49.802850999999997	49.842925000000001	56.819153999999997	56.802159000000003	0103000020E61000000100000005000000CB4752D2C3E6484096986725AD664C40CB4752D2C3E648409C31CC09DA684C408BFD65F7E4EB48409C31CC09DA684C408BFD65F7E4EB484096986725AD664C40CB4752D2C3E6484096986725AD664C40
16087	Дружино	7	62	1390	49.936269000000003	49.952419999999996	56.545175	56.533050000000003	0103000020E610000001000000050000001BA19FA9D7F7484000917EFB3A444C401BA19FA9D7F7484064CC5D4BC8454C40350708E6E8F9484064CC5D4BC8454C40350708E6E8F9484000917EFB3A444C401BA19FA9D7F7484000917EFB3A444C40
15653	Большой Карлыган	7	62	1390	50.04889	50.076514000000003	56.572305	56.558864	0103000020E61000000100000005000000FC8C0B0742064940B47405DB88474C40FC8C0B07420649402C2B4D4A41494C40D4D7F335CB0949402C2B4D4A41494C40D4D7F335CB094940B47405DB88474C40FC8C0B0742064940B47405DB88474C40
16390	Большое Опарино	7	62	1390	49.833177999999997	49.856310000000001	56.664707	56.648364999999998	0103000020E6100000010000000500000093DFA293A5EA48407E6FD39FFD524C4093DFA293A5EA48400D36751E15554C406F9EEA909BED48400D36751E15554C406F9EEA909BED48407E6FD39FFD524C4093DFA293A5EA48407E6FD39FFD524C40
15224	Алексеевское	7	62	1390	49.723115999999997	49.743364	56.723284	56.716833000000001	0103000020E610000001000000050000006F9BA9108FDC4840C7D8092FC15B4C406F9BA9108FDC48402BDCF291945C4C400A83328D26DF48402BDCF291945C4C400A83328D26DF4840C7D8092FC15B4C406F9BA9108FDC4840C7D8092FC15B4C40
15168	Юледур	7	62	1334	49.156880999999998	49.190325999999999	56.814881999999997	56.802627000000001	0103000020E61000000100000005000000902E36AD149448407CF1457BBC664C40902E36AD14944840AE0CAA0D4E684C400CCA349A5C984840AE0CAA0D4E684C400CCA349A5C9848407CF1457BBC664C40902E36AD149448407CF1457BBC664C40
14887	Шорсола	7	62	1334	49.066716999999997	49.09064	56.826587000000004	56.820847999999998	0103000020E610000001000000050000002A8BC22E8A884840567E198C11694C402A8BC22E8A8848403E26529ACD694C40CFDA6D179A8B48403E26529ACD694C40CFDA6D179A8B4840567E198C11694C402A8BC22E8A884840567E198C11694C40
14949	Шой-Шудумарь	7	62	1334	49.077910000000003	49.095778000000003	56.768329000000001	56.758871999999997	0103000020E61000000100000005000000040473F4F8894840D0ECBAB722614C40040473F4F8894840C1C8CB9A58624C4091D61874428C4840C1C8CB9A58624C4091D61874428C4840D0ECBAB722614C40040473F4F8894840D0ECBAB722614C40
14792	Тумьюмучаш	7	62	1334	48.763275999999998	48.786316999999997	56.836686999999998	56.827345000000001	0103000020E610000001000000050000002DE92807B36148402BC1E270E6694C402DE92807B361484082FE428F186B4C40F8A41309A664484082FE428F186B4C40F8A41309A66448402BC1E270E6694C402DE92807B36148402BC1E270E6694C40
14694	Токтайбеляк	7	62	1334	48.913536999999998	48.939228999999997	56.878709000000001	56.86121	0103000020E61000000100000005000000CD57C9C7EE7448407C7E18213C6E4C40CD57C9C7EE744840B6D9588979704C40363AE7A738784840B6D9588979704C40363AE7A7387848407C7E18213C6E4C40CD57C9C7EE7448407C7E18213C6E4C40
14652	Салтакъял	7	62	1334	48.915827	48.934368999999997	56.712035999999998	56.704644999999999	0103000020E610000001000000050000009BE5B2D1397548401C25AFCE315A4C409BE5B2D1397548408EC9E2FE235B4C40B7B24467997748408EC9E2FE235B4C40B7B24467997748401C25AFCE315A4C409BE5B2D1397548401C25AFCE315A4C40
14550	Русские Шои	7	62	1334	49.125906999999998	49.152327	56.674129000000001	56.664796000000003	0103000020E6100000010000000500000032AB77B81D9048407D410B0918554C4032AB77B81D9048408124ECDB49564C401EA67D737F9348408124ECDB49564C401EA67D737F9348407D410B0918554C4032AB77B81D9048407D410B0918554C40
14599	Мари-Шои	7	62	1334	49.084603000000001	49.109045999999999	56.691631999999998	56.681229999999999	0103000020E610000001000000050000005E126745D48A4840EC866D8B32574C405E126745D48A4840FC6EBA6587584C403BE12538F58D4840FC6EBA6587584C403BE12538F58D4840EC866D8B32574C405E126745D48A4840EC866D8B32574C40
14314	Куженер	7	62	1334	48.894635999999998	48.928359	56.824252000000001	56.796968999999997	0103000020E6100000010000000500000081E9B46E837248408176871403664C4081E9B46E83724840D0D4EB1681694C4040F9BB77D4764840D0D4EB1681694C4040F9BB77D47648408176871403664C4081E9B46E837248408176871403664C40
58084	Кугунур	7	62	1334	49.143371000000002	49.174424999999999	56.757795999999999	56.749288	0103000020E61000000100000005000000F0181EFB5992484083A44FABE85F4C40F0181EFB5992484012859675FF604C406A4DF38E5396484012859675FF604C406A4DF38E5396484083A44FABE85F4C40F0181EFB5992484083A44FABE85F4C40
14853	Конганур	7	62	1334	48.784413000000001	48.804319999999997	56.865957999999999	56.854709	0103000020E6100000010000000500000054C72AA567644840664CC11A676D4C4054C72AA567644840D3DA34B6D76E4C4065C22FF5F3664840D3DA34B6D76E4C4065C22FF5F3664840664CC11A676D4C4054C72AA567644840664CC11A676D4C40
14503	Иштымбал	7	62	1334	48.812683	48.826965999999999	56.798231000000001	56.783397000000001	0103000020E61000000100000005000000F1811DFF056848406B64575A46644C40F1811DFF05684840A2D3F36E2C664C40B4739A05DA694840A2D3F36E2C664C40B4739A05DA6948406B64575A46644C40F1811DFF056848406B64575A46644C40
15121	Ивансола	7	62	1334	49.136876000000001	49.158785999999999	56.854311000000003	56.847650999999999	0103000020E61000000100000005000000BCCD1B2785914840FAB5F5D37F6C4C40BCCD1B278591484079CE16105A6D4C40058882195394484079CE16105A6D4C400588821953944840FAB5F5D37F6C4C40BCCD1B2785914840FAB5F5D37F6C4C40
14763	Верхний Ушут	7	62	1334	48.746980000000001	48.767353999999997	56.805131000000003	56.797052999999998	0103000020E610000001000000050000000F62670A9D5F4840DF162CD505664C400F62670A9D5F484076FF58880E674C40363AE7A73862484076FF58880E674C40363AE7A738624840DF162CD505664C400F62670A9D5F4840DF162CD505664C40
15066	Большой Ляждур	7	62	1334	49.243129000000003	49.264175999999999	56.835706999999999	56.825074999999998	0103000020E61000000100000005000000C7DADFD91E9F4840A4DFBE0E9C694C40C7DADFD91E9F4840E6046D72F86A4C40AD31E884D0A14840E6046D72F86A4C40AD31E884D0A14840A4DFBE0E9C694C40C7DADFD91E9F4840A4DFBE0E9C694C40
14277	Юксары	7	62	1284	47.022035000000002	47.051139999999997	56.325150000000001	56.310907	0103000020E61000000100000005000000062FFA0AD28247407A8CF2CCCB274C40062FFA0AD2824740AF25E4839E294C403BC269C18B864740AF25E4839E294C403BC269C18B8647407A8CF2CCCB274C40062FFA0AD28247407A8CF2CCCB274C40
14188	Широкундыш	7	62	1284	46.906844	46.929499999999997	56.749341999999999	56.730331	0103000020E610000001000000050000007349D57613744740A320787C7B5D4C407349D5761374474076C24B70EA5F4C40E5D022DBF976474076C24B70EA5F4C40E5D022DBF9764740A320787C7B5D4C407349D57613744740A320787C7B5D4C40
13928	Озерный	7	62	1284	47.109000999999999	47.132796999999997	56.585462999999997	56.570231999999997	0103000020E610000001000000050000009B1DA9BEF38D4740FB90B75CFD484C409B1DA9BEF38D47404F029B73F04A4C40E200FA7DFF9047404F029B73F04A4C40E200FA7DFF904740FB90B75CFD484C409B1DA9BEF38D4740FB90B75CFD484C40
14091	Нежнур	7	62	1284	46.632075999999998	46.658002000000003	56.938851	56.925620000000002	0103000020E61000000100000005000000124BCADDE7504740034356B77A764C40124BCADDE7504740906802452C784C40EF59D76839544740906802452C784C40EF59D76839544740034356B77A764C40124BCADDE7504740034356B77A764C40
13700	Механизаторов	7	62	1284	46.746333	46.765439999999998	56.423675000000003	56.415787999999999	0103000020E610000001000000050000007976F9D6875F4740DD088B8A38354C407976F9D6875F474000917EFB3A364C406E861BF0F961474000917EFB3A364C406E861BF0F9614740DD088B8A38354C407976F9D6875F4740DD088B8A38354C40
14032	Майский	7	62	1284	46.463669000000003	46.49935	56.720438999999999	56.705717	0103000020E61000000100000005000000A3957B81593B4740999D45EF545A4C40A3957B81593B4740A8E15B58375C4C40F9A067B3EA3F4740A8E15B58375C4C40F9A067B3EA3F4740999D45EF545A4C40A3957B81593B4740999D45EF545A4C40
13989	Кумья	7	62	1284	46.634107	46.657291999999998	56.689635000000003	56.680301	0103000020E6100000010000000500000014950D6B2A514740D237691A14574C4014950D6B2A514740A796ADF545584C4012F6ED2422544740A796ADF545584C4012F6ED2422544740D237691A14574C4014950D6B2A514740D237691A14574C40
13898	Красный Мост	7	62	1284	47.141717999999997	47.167696999999997	56.565486	56.556468000000002	0103000020E6100000010000000500000094A0BFD023924740A1A2EA573A474C4094A0BFD023924740452C62D861484C409351651877954740452C62D861484C409351651877954740A1A2EA573A474C4094A0BFD023924740A1A2EA573A474C40
13450	Килемары	7	62	1284	46.843046000000001	46.898902999999997	56.802616999999998	56.768931000000002	0103000020E6100000010000000500000006836BEEE86B4740B7F0BC546C624C4006836BEEE86B4740581B6327BC664C405DA3E5400F734740581B6327BC664C405DA3E5400F734740B7F0BC546C624C4006836BEEE86B4740B7F0BC546C624C40
13647	Ершово	7	62	1284	46.842973999999998	46.863438000000002	56.401668999999998	56.390300000000003	0103000020E610000001000000050000006CB07092E66B47407DD0B359F5314C406CB07092E66B47409468C9E369334C40D40FEA22856E47409468C9E369334C40D40FEA22856E47407DD0B359F5314C406CB07092E66B47407DD0B359F5314C40
57931	Визимъяры	7	62	1284	46.907679999999999	46.965432	56.449478999999997	56.422415000000001	0103000020E61000000100000005000000DC9DB5DB2E744740802BD9B111364C40DC9DB5DB2E744740909E228788394C4085419946937B4740909E228788394C4085419946937B4740802BD9B111364C40DC9DB5DB2E744740802BD9B111364C40
13733	Большое Кибеево	7	62	1284	47.065001000000002	47.080713000000003	56.915058000000002	56.908034999999998	0103000020E61000000100000005000000899AE8F351884740CA4FAA7D3A744C40899AE8F351884740BAF8DB9E20754C4058AEB7CD548A4740BAF8DB9E20754C4058AEB7CD548A4740CA4FAA7D3A744C40899AE8F351884740CA4FAA7D3A744C40
13619	Арда	7	62	1284	46.770498000000003	46.790899000000003	56.410485000000001	56.399532000000001	0103000020E6100000010000000500000014D1AFAD9F6247404DDA54DD23334C4014D1AFAD9F624740D13FC1C58A344C4035B8AD2D3C654740D13FC1C58A344C4035B8AD2D3C6547404DDA54DD23334C4014D1AFAD9F6247404DDA54DD23334C40
13558	Алешкино	7	62	1284	46.707912	46.740817	56.433570000000003	56.418308000000003	0103000020E61000000100000005000000153944DC9C5A4740DDD3D51D8B354C40153944DC9C5A47406C43C5387F374C4011A96917D35E47406C43C5387F374C4011A96917D35E4740DDD3D51D8B354C40153944DC9C5A4740DDD3D51D8B354C40
14218	Алатайкино	7	62	1284	46.913176999999997	46.936748999999999	56.273584999999997	56.262182000000003	0103000020E61000000100000005000000CD3AE3FBE2744740C9CC052E8F214C40CD3AE3FBE27447408CD651D504234C40C5C72764E77747408CD651D504234C40C5C72764E7774740C9CC052E8F214C40CD3AE3FBE2744740C9CC052E8F214C40
14127	Актаюж	7	62	1284	47.000700000000002	47.015881999999998	56.676215999999997	56.663916	0103000020E61000000100000005000000B98D06F01680474044A51133FB544C40B98D06F0168047401684F23E8E564C402B4CDF6B088247401684F23E8E564C402B4CDF6B0882474044A51133FB544C40B98D06F01680474044A51133FB544C40
57933	Семеновка	7	62	1520	47.954467999999999	47.997390000000003	56.650368999999998	56.641713000000003	0103000020E610000001000000050000000D8AE6012CFA47408335CEA623524C400D8AE6012CFA474086AA984A3F534C40C1ADBB79AAFF474086AA984A3F534C40C1ADBB79AAFF47408335CEA623524C400D8AE6012CFA47408335CEA623524C40
18667	Светлый	7	62	1520	47.837480999999997	47.843032000000001	56.553719000000001	56.550291000000001	0103000020E61000000100000005000000BC02D19332EB47403E247CEF6F464C40BC02D19332EB47404016A243E0464C40A1BDFA78E8EB47404016A243E0464C40A1BDFA78E8EB47403E247CEF6F464C40BC02D19332EB47403E247CEF6F464C40
57927	Савино	7	62	1520	47.998800000000003	48.020530000000001	56.666345	56.650269999999999	0103000020E61000000100000005000000569FABADD8FF4740F3C81F0C3C534C40569FABADD8FF4740336DFFCA4A554C401F4B1FBAA0024840336DFFCA4A554C401F4B1FBAA0024840F3C81F0C3C534C40569FABADD8FF4740F3C81F0C3C534C40
58081	Нолька	7	62	1520	47.894154999999998	47.910100999999997	56.592680000000001	56.586891000000001	0103000020E610000001000000050000000647C9AB73F247408BA8893E1F4B4C400647C9AB73F24740247F30F0DC4B4C40488787307EF44740247F30F0DC4B4C40488787307EF447408BA8893E1F4B4C400647C9AB73F247408BA8893E1F4B4C40
17855	Куяр	7	62	1520	47.973934999999997	47.993563000000002	56.557698000000002	56.542484999999999	0103000020E6100000010000000500000002B7EEE6A9FC474008C9022670454C4002B7EEE6A9FC4740B685E7A562474C4001C287122DFF4740B685E7A562474C4001C287122DFF474008C9022670454C4002B7EEE6A9FC474008C9022670454C40
18709	Зеленый	7	62	1520	47.798682999999997	47.813324999999999	56.575875000000003	56.571586000000003	0103000020E61000000100000005000000826F9A3E3BE64740FD6CE4BA29494C40826F9A3E3BE64740C1CAA145B6494C4075029A081BE84740C1CAA145B6494C4075029A081BE84740FD6CE4BA29494C40826F9A3E3BE64740FD6CE4BA29494C40
13143	Шимшурга	7	62	1199	47.891739000000001	47.908295000000003	56.198003999999997	56.180903000000001	0103000020E61000000100000005000000ACC8E88024F24740C85F5AD427174C40ACC8E88024F24740143DF03158194C40670FB40243F44740143DF03158194C40670FB40243F44740C85F5AD427174C40ACC8E88024F24740C85F5AD427174C40
13371	Шелангер	7	62	1199	48.233457999999999	48.268915	56.236145999999998	56.207572999999996	0103000020E61000000100000005000000AA7EA5F3E11D48402C4487C0911A4C40AA7EA5F3E11D4840658A39083A1E4C40B13385CE6B224840658A39083A1E4C40B13385CE6B2248402C4487C0911A4C40AA7EA5F3E11D48402C4487C0911A4C40
58082	Черное Озеро	7	62	1199	47.393577999999998	47.414419000000002	56.363886999999998	56.350940999999999	0103000020E6100000010000000500000069368FC360B24740ABE97AA2EB2C4C4069368FC360B24740433866D9932E4C40A7EB89AE0BB54740433866D9932E4C40A7EB89AE0BB54740ABE97AA2EB2C4C4069368FC360B24740ABE97AA2EB2C4C40
13425	Филиппсола	7	62	1199	48.495128000000001	48.516480999999999	56.288851000000001	56.280441000000003	0103000020E61000000100000005000000BDAAB35A603F484091BA9D7DE5234C40BDAAB35A603F48405D35CF11F9244C40B000A60C1C4248405D35CF11F9244C40B000A60C1C42484091BA9D7DE5234C40BDAAB35A603F484091BA9D7DE5234C40
12314	Трубный	7	62	1199	48.351675999999998	48.359079000000001	56.134329999999999	56.127547	0103000020E61000000100000005000000E0641BB8032D4840F9D9C87553104C40E0641BB8032D4840936FB6B931114C4017D7F84CF62D4840936FB6B931114C4017D7F84CF62D4840F9D9C87553104C40E0641BB8032D4840F9D9C87553104C40
12226	Ташнур	7	62	1199	48.226810999999998	48.263075999999998	56.165073	56.144702000000002	0103000020E61000000100000005000000C0AF9124081D484039D55A9885124C40C0AF9124081D4840EF39B01C21154C40662E7079AC214840EF39B01C21154C40662E7079AC21484039D55A9885124C40C0AF9124081D484039D55A9885124C40
13058	Таир	7	62	1199	47.836213999999998	47.863684999999997	56.276369000000003	56.261243	0103000020E610000001000000050000008A3A730F09EB47408BA71E6970214C408A3A730F09EB47406A50340F60234C40DB85E63A8DEE47406A50340F60234C40DB85E63A8DEE47408BA71E6970214C408A3A730F09EB47408BA71E6970214C40
12428	Суслонгер	7	62	1199	48.233449	48.274681999999999	56.324435999999999	56.298611999999999	0103000020E61000000100000005000000572426A8E11D4840B91803EB38264C40572426A8E11D484091D26C1E87294C4062669FC72823484091D26C1E87294C4062669FC728234840B91803EB38264C40572426A8E11D4840B91803EB38264C40
52796	Сосновка	7	62	1199	48.034553000000002	48.050310000000003	56.036406999999997	56.018025999999999	0103000020E61000000100000005000000467D923B6C044840253D0CAD4E024C40467D923B6C044840382C0DFCA8044C40B554DE8E70064840382C0DFCA8044C40B554DE8E70064840253D0CAD4E024C40467D923B6C044840253D0CAD4E024C40
13238	Сидельниково	7	62	1199	47.624499	47.651187999999998	56.175001000000002	56.154977000000002	0103000020E610000001000000050000003EB14E95EFCF4740EC504D49D6134C403EB14E95EFCF474037E2C96E66164C4019C6DD205AD3474037E2C96E66164C4019C6DD205AD34740EC504D49D6134C403EB14E95EFCF4740EC504D49D6134C40
13076	Семеновка	7	62	1199	47.840823	47.885207999999999	56.149586999999997	56.132955000000003	0103000020E61000000100000005000000C05C8B16A0EB47407B6B60AB04114C40C05C8B16A0EB47401074B4AA25134C402B14E97E4EF147401074B4AA25134C402B14E97E4EF147407B6B60AB04114C40C05C8B16A0EB47407B6B60AB04114C40
12954	Поянсола	7	62	1199	48.088461000000002	48.116309000000001	56.170791000000001	56.156725999999999	0103000020E6100000010000000500000059FCA6B0520B48406937FA980F144C4059FCA6B0520B4840BFB9BF7ADC154C40809D9B36E30E4840BFB9BF7ADC154C40809D9B36E30E48406937FA980F144C4059FCA6B0520B48406937FA980F144C40
12829	Нуктуж	7	62	1199	48.111763000000003	48.150785999999997	56.126899999999999	56.114821999999997	0103000020E6100000010000000500000091F3FE3F4E0E48403F6EBF7CB20E4C4091F3FE3F4E0E484063EE5A423E104C40EA58A5F44C13484063EE5A423E104C40EA58A5F44C1348403F6EBF7CB20E4C4091F3FE3F4E0E48403F6EBF7CB20E4C40
13277	Новая Липша	7	62	1199	47.451141999999997	47.463529999999999	56.259563	56.249256000000003	0103000020E610000001000000050000000FED6305BFB94740782AE09EE71F4C400FED6305BFB947403620425C39214C40815B77F354BB47403620425C39214C40815B77F354BB4740782AE09EE71F4C400FED6305BFB94740782AE09EE71F4C40
58057	Нижние Помьялы	7	62	1199	48.005259000000002	48.049025	56.112958999999996	56.099797000000002	0103000020E610000001000000050000003D81B053AC004840959EE925C60C4C403D81B053AC004840F964C570750E4C40DCD7817346064840F964C570750E4C40DCD7817346064840959EE925C60C4C403D81B053AC004840959EE925C60C4C40
12360	Мочалище	7	62	1199	48.345998999999999	48.363937999999997	56.341158	56.319468999999998	0103000020E610000001000000050000006FB9FAB1492C4840FC8A355CE4284C406FB9FAB1492C48406762BA10AB2B4C40C5E23785952E48406762BA10AB2B4C40C5E23785952E4840FC8A355CE4284C406FB9FAB1492C4840FC8A355CE4284C40
12872	Малая Кужмара	7	62	1199	48.175894	48.197454	56.165283000000002	56.155577999999998	0103000020E6100000010000000500000004C8D0B18316484011FDDAFAE9134C4004C8D0B183164840DACA4BFE27154C40713B342C46194840DACA4BFE27154C40713B342C4619484011FDDAFAE9134C4004C8D0B18316484011FDDAFAE9134C40
12568	Кукшенеры	7	62	1199	48.209283999999997	48.218555000000002	55.954954000000001	55.941853999999999	0103000020E61000000100000005000000BCC96FD1C91A4840ABCDFFAB8EF84B40BCC96FD1C91A48409A97C3EE3BFA4B404BB0389CF91B48409A97C3EE3BFA4B404BB0389CF91B4840ABCDFFAB8EF84B40BCC96FD1C91A4840ABCDFFAB8EF84B40
12780	Кужмара	7	62	1199	48.051765000000003	48.078831000000001	56.154245000000003	56.135032000000002	0103000020E61000000100000005000000EA094B3CA0064840EDF483BA48114C40EA094B3CA00648402849D74CBE134C409B745B22170A48402849D74CBE134C409B745B22170A4840EDF483BA48114C40EA094B3CA0064840EDF483BA48114C40
12612	Красный Яр	7	62	1199	48.006740999999998	48.039726999999999	56.046444000000001	56.023418999999997	0103000020E610000001000000050000006B459BE3DC004840718DCF64FF024C406B459BE3DC004840378C82E0F1054C4054E23AC615054840378C82E0F1054C4054E23AC615054840718DCF64FF024C406B459BE3DC004840718DCF64FF024C40
12022	Красногорский	7	62	1199	48.300832	48.348576999999999	56.169733999999998	56.137524999999997	0103000020E610000001000000050000008ECBB8A981264840F2B0506B9A114C408ECBB8A9812648407782FDD7B9154C40A391CF2B9E2C48407782FDD7B9154C40A391CF2B9E2C4840F2B0506B9A114C408ECBB8A981264840F2B0506B9A114C40
13178	Кокшамары	7	62	1199	47.705553999999999	47.772469999999998	56.170110000000001	56.152956000000003	0103000020E61000000100000005000000EFC7ED974FDA47400EDDEC0F94134C40EFC7ED974FDA47407D5C1B2AC6154C401092054CE0E247407D5C1B2AC6154C401092054CE0E247400EDDEC0F94134C40EFC7ED974FDA47400EDDEC0F94134C40
12993	Кокшайск	7	62	1199	47.802303000000002	47.832118000000001	56.151606999999998	56.133603000000001	0103000020E61000000100000005000000C93D5DDDB1E64740E1D231E719114C40C93D5DDDB1E647401E6CB1DB67134C40DB34B6D782EA47401E6CB1DB67134C40DB34B6D782EA4740E1D231E719114C40C93D5DDDB1E64740E1D231E719114C40
12499	Исменцы	7	62	1199	48.201981000000004	48.225363999999999	55.982064000000001	55.970720999999998	0103000020E61000000100000005000000EAB46E83DA1948402C45F29540FC4B40EAB46E83DA1948401B4AED45B4FD4B400ED940BAD81C48401B4AED45B4FD4B400ED940BAD81C48402C45F29540FC4B40EAB46E83DA1948402C45F29540FC4B40
12758	Иркино	7	62	1199	47.992386000000003	48.013711999999998	56.075031000000003	56.052410999999999	0103000020E610000001000000050000000F81238106FF4740AF795567B5064C400F81238106FF4740D597A59D9A094C4008C89750C1014840D597A59D9A094C4008C89750C1014840AF795567B5064C400F81238106FF4740AF795567B5064C40
11963	Илеть	7	62	1199	48.343879000000001	48.358989000000001	56.121943000000002	56.107532999999997	0103000020E61000000100000005000000FE63213A042C4840D11E2FA4C30D4C40FE63213A042C4840F27C06D49B0F4C40D74FFF59F32D4840F27C06D49B0F4C40D74FFF59F32D4840D11E2FA4C30D4C40FE63213A042C4840D11E2FA4C30D4C40
11587	Звенигово	7	62	1199	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
58087	Деревня Чуваш-Отары	7	62	1199	47.238197	48.609788999999999	56.480896999999999	55.913030999999997	0103000020E61000000100000005000000AE80423D7D9E4740F99D2633DEF44B40AE80423D7D9E47404CDF6B088E3D4C40F33AE2900D4E48404CDF6B088E3D4C40F33AE2900D4E4840F99D2633DEF44B40AE80423D7D9E4740F99D2633DEF44B40
11266	Яштуга	7	62	1095	46.208440000000003	46.231454999999997	56.075221999999997	56.067659999999997	0103000020E61000000100000005000000D1967329AE1A4740A99F3715A9084C40D1967329AE1A474048F8DEDFA0094C4072BF4351A01D474048F8DEDFA0094C4072BF4351A01D4740A99F3715A9084C40D1967329AE1A4740A99F3715A9084C40
10170	Юнга-Кушерга	7	62	1095	46.435938	46.469462999999998	56.138413	56.125484999999998	0103000020E61000000100000005000000B58AFED0CC374740BC9179E40F104C40B58AFED0CC374740AE2B6684B7114C404DD7135D173C4740AE2B6684B7114C404DD7135D173C4740BC9179E40F104C40B58AFED0CC374740BC9179E40F104C40
10713	Юлъялы	7	62	1095	46.722025000000002	46.739111000000001	56.209085000000002	56.202106000000001	0103000020E610000001000000050000007CF2B0506B5C4740A629029CDE194C407CF2B0506B5C4740C68A1A4CC31A4C40938E72309B5E4740C68A1A4CC31A4C40938E72309B5E4740A629029CDE194C407CF2B0506B5C4740A629029CDE194C40
10474	Четнаево	7	62	1095	46.598452000000002	46.614567999999998	56.269610999999998	56.255958	0103000020E61000000100000005000000E71C3C139A4C47402593533BC3204C40E71C3C139A4C474028D2FD9C82224C4085950A2AAA4E474028D2FD9C82224C4085950A2AAA4E47402593533BC3204C40E71C3C139A4C47402593533BC3204C40
11449	Чекеево	7	62	1095	46.466804000000003	46.477764000000001	56.251702000000002	56.242004000000001	0103000020E610000001000000050000002DD2C43BC03B474027C0B0FCF91E4C402DD2C43BC03B47403D2B69C537204C40639AE95E273D47403D2B69C537204C40639AE95E273D474027C0B0FCF91E4C402DD2C43BC03B474027C0B0FCF91E4C40
11543	Усола	7	62	1095	46.597779000000003	46.609986999999997	56.239978000000001	56.233344000000002	0103000020E61000000100000005000000289EB305844C4740E25B5837DE1D4C40289EB305844C474037E15E99B71E4C4019FED30D144E474037E15E99B71E4C4019FED30D144E4740E25B5837DE1D4C40289EB305844C4740E25B5837DE1D4C40
9867	Тушналы	7	62	1095	46.592469999999999	46.610131000000003	56.198089000000003	56.190241	0103000020E6100000010000000500000039EE940ED64B4740DEAD2CD159184C4039EE940ED64B47404359F8FA5A194C404DA3C9C5184E47404359F8FA5A194C404DA3C9C5184E4740DEAD2CD159184C4039EE940ED64B4740DEAD2CD159184C40
11399	Троицкий Посад	7	62	1095	46.450617000000001	46.476469999999999	56.301454	56.284028999999997	0103000020E61000000100000005000000C5025FD1AD394740CB0EF10F5B244C40C5025FD1AD394740CB9F6F0B96264C4037C30DF8FC3C4740CB9F6F0B96264C4037C30DF8FC3C4740CB0EF10F5B244C40C5025FD1AD394740CB0EF10F5B244C40
11028	Три Рутки	7	62	1095	46.619346999999998	46.634914999999999	56.532344999999999	56.520856999999999	0103000020E6100000010000000500000017F032C3464F474043723271AB424C4017F032C3464F4740359886E123444C40B35E0CE544514740359886E123444C40B35E0CE54451474043723271AB424C4017F032C3464F474043723271AB424C40
10612	Токари	7	62	1095	46.773479999999999	46.800555000000003	56.197122999999998	56.185988000000002	0103000020E61000000100000005000000170E84640163474067B96C74CE174C40170E8464016347400B2593533B194C401CD31396786647400B2593533B194C401CD313967866474067B96C74CE174C40170E84640163474067B96C74CE174C40
58135	Пичужкино	7	62	1095	46.043616999999998	46.813769999999998	56.637298000000001	56.017885	0103000020E610000001000000050000005A46EA3D95054740630B410E4A024C405A46EA3D9505474032E719FB92514C40A33B889D2968474032E719FB92514C40A33B889D29684740630B410E4A024C405A46EA3D95054740630B410E4A024C40
10093	Пертюково	7	62	1095	46.353904	46.377090000000003	56.160209999999999	56.152500000000003	0103000020E6100000010000000500000038F6ECB94C2D4740EC51B81E85134C4038F6ECB94C2D4740FF3EE3C281144C4007D3307C44304740FF3EE3C281144C4007D3307C44304740EC51B81E85134C4038F6ECB94C2D4740EC51B81E85134C40
10319	Пертнуры	7	62	1095	46.424574999999997	46.438310000000001	56.230491999999998	56.225487999999999	0103000020E610000001000000050000007FD93D7958364740FAD170CADC1C4C407FD93D7958364740ACFE08C3801D4C4040C1C58A1A384740ACFE08C3801D4C4040C1C58A1A384740FAD170CADC1C4C407FD93D7958364740FAD170CADC1C4C40
9799	Паратмары	7	62	1095	46.541831999999999	46.559204999999999	56.140158	56.132975999999999	0103000020E6100000010000000500000090F63FC05A4547409293895B05114C4090F63FC05A454740EA2285B2F0114C403D61890794474740EA2285B2F0114C403D618907944747409293895B05114C4090F63FC05A4547409293895B05114C40
11163	Пайгусово	7	62	1095	46.294255999999997	46.310650000000003	56.185462000000001	56.172345	0103000020E610000001000000050000006D533C2EAA2547408750A5660F164C406D533C2EAA2547404C530438BD174C404F401361C32747404C530438BD174C404F401361C32747408750A5660F164C406D533C2EAA2547408750A5660F164C40
10404	Октябрьский	7	62	1095	46.523927999999998	46.532964999999997	56.293906	56.285283	0103000020E61000000100000005000000B6BA9C1210434740698D412784244C40B6BA9C1210434740910C39B69E254C40D174763238444740910C39B69E254C40D174763238444740698D412784244C40B6BA9C1210434740698D412784244C40
10939	Озерки	7	62	1095	46.506833	46.560310000000001	56.420707999999998	56.381694000000003	0103000020E610000001000000050000004CC45BE7DF4047402B8A5759DB304C404CC45BE7DF40474031957EC2D9354C4096CFF23CB847474031957EC2D9354C4096CFF23CB84747402B8A5759DB304C404CC45BE7DF4047402B8A5759DB304C40
11498	Носелы	7	62	1095	46.641903999999997	46.667380000000001	56.237777000000001	56.228980999999997	0103000020E61000000100000005000000F69507E929524740E333D93F4F1D4C40F69507E929524740D95E0B7A6F1E4C40930035B56C554740D95E0B7A6F1E4C40930035B56C554740E333D93F4F1D4C40F69507E929524740E333D93F4F1D4C40
11200	Новая Слобода	7	62	1095	46.080312999999997	46.097723000000002	56.103296	56.093822000000003	0103000020E61000000100000005000000C93846B2470A47409AD2FA5B020C4C40C93846B2470A474060E7A6CD380D4C409488F02F820C474060E7A6CD380D4C409488F02F820C47409AD2FA5B020C4C40C93846B2470A47409AD2FA5B020C4C40
10531	Нижние Шелаболки	7	62	1095	46.579920000000001	46.604112000000001	56.278368	56.268431	0103000020E61000000100000005000000EE258DD13A4A4740C51D6FF25B224C40EE258DD13A4A474060200890A1234C40828FC18A534D474060200890A1234C40828FC18A534D4740C51D6FF25B224C40EE258DD13A4A4740C51D6FF25B224C40
11364	Мумариха	7	62	1095	46.478383999999998	46.500033000000002	56.312049999999999	56.307017000000002	0103000020E61000000100000005000000FF76D9AF3B3D4740742843554C274C40FF76D9AF3B3D4740C05B2041F1274C40DCF5D21401404740C05B2041F1274C40DCF5D21401404740742843554C274C40FF76D9AF3B3D4740742843554C274C40
10844	Микряково	7	62	1095	46.223216999999998	46.243582000000004	56.212494999999997	56.198625	0103000020E61000000100000005000000A374E95F921C47408195438B6C194C40A374E95F921C474021C84109331B4C4078F2E9B12D1F474021C84109331B4C4078F2E9B12D1F47408195438B6C194C40A374E95F921C47408195438B6C194C40
11293	Малая Юнга	7	62	1095	46.504866	46.511648000000001	56.264991999999999	56.259962999999999	0103000020E61000000100000005000000616EF7729F404740C495B37746214C40616EF7729F404740CFD90242EB214C402B8881AE7D414740CFD90242EB214C402B8881AE7D414740C495B37746214C40616EF7729F404740C495B37746214C40
11117	Макаркино	7	62	1095	46.252394000000002	46.266677999999999	56.163825000000003	56.156635999999999	0103000020E6100000010000000500000073DA53724E20474029B000A60C144C4073DA53724E20474034A2B437F8144C40064834812222474034A2B437F8144C40064834812222474029B000A60C144C4073DA53724E20474029B000A60C144C40
10380	Кулаково	7	62	1095	46.540672999999998	46.561038000000003	56.256717999999999	56.243254	0103000020E61000000100000005000000446ADAC534454740834F73F2221F4C40446ADAC534454740B325AB22DC204C4019E8DA17D0474740B325AB22DC204C4019E8DA17D0474740834F73F2221F4C40446ADAC534454740834F73F2221F4C40
10583	Кузнецово	7	62	1095	46.695390000000003	46.731143000000003	56.168340999999998	56.154535000000003	0103000020E6100000010000000500000094FB1D8A025947402F8B89CDC7134C4094FB1D8A02594740B8C9A8328C154C4084D90418965D4740B8C9A8328C154C4084D90418965D47402F8B89CDC7134C4094FB1D8A025947402F8B89CDC7134C40
9782	Кожважи	7	62	1095	46.651452999999997	46.670129000000003	56.129995999999998	56.117967999999998	0103000020E61000000100000005000000C7F0D8CF62534740BDFC4E93190F4C40C7F0D8CF625347402F4E7CB5A3104C40F48C7DC9C65547402F4E7CB5A3104C40F48C7DC9C6554740BDFC4E93190F4C40C7F0D8CF62534740BDFC4E93190F4C40
10083	Картуково	7	62	1095	46.513553000000002	46.525796999999997	56.205185	56.198360000000001	0103000020E61000000100000005000000A0E1CD1ABC414740D36A48DC63194C40A0E1CD1ABC4147409C508880431A4C40DEAAEB504D4347409C508880431A4C40DEAAEB504D434740D36A48DC63194C40A0E1CD1ABC414740D36A48DC63194C40
10895	Еникеево	7	62	1095	46.419203000000003	46.448227000000003	56.404702	56.392313000000001	0103000020E610000001000000050000004BB1A371A8354740D865F84F37324C404BB1A371A83547401A506F46CD334C40941799805F3947401A506F46CD334C40941799805F394740D865F84F37324C404BB1A371A8354740D865F84F37324C40
10242	Емешево	7	62	1095	46.336567000000002	46.352988000000003	56.232784000000002	56.221079000000003	0103000020E61000000100000005000000D8F4A0A0142B47408C6A11514C1C4C40D8F4A0A0142B47401B84B9DDCB1D4C40B3F0F5B52E2D47401B84B9DDCB1D4C40B3F0F5B52E2D47408C6A11514C1C4C40D8F4A0A0142B47408C6A11514C1C4C40
10021	Емелево	7	62	1095	46.375841000000001	46.401578000000001	56.145102999999999	56.136532000000003	0103000020E610000001000000050000007BBFD18E1B304740C26D6DE179114C407BBFD18E1B30474097C62FBC92124C4084656CE86633474097C62FBC92124C4084656CE866334740C26D6DE179114C407BBFD18E1B304740C26D6DE179114C40
10795	Емангаши	7	62	1095	46.229765999999998	46.257514999999998	56.239578000000002	56.227184999999999	0103000020E61000000100000005000000CADDE7F8681D47402592E865141D4C40CADDE7F8681D4740A96BED7DAA1E4C405E9D6340F6204740A96BED7DAA1E4C405E9D6340F62047402592E865141D4C40CADDE7F8681D47402592E865141D4C40
9961	Еласы	7	62	1095	46.448515	46.479092999999999	56.173192	56.164596000000003	0103000020E61000000100000005000000FA6184F068394740B686527B11154C40FA6184F068394740E4F6CB272B164C400B5F5FEB523D4740E4F6CB272B164C400B5F5FEB523D4740B686527B11154C40FA6184F068394740B686527B11154C40
9716	Виловатово	7	62	1095	46.588875999999999	46.627485999999998	56.181434000000003	56.164797	0103000020E610000001000000050000001CB3EC49604B47404DBD6E1118154C401CB3EC49604B4740F530B43A39174C405359147651504740F530B43A39174C4053591476515047404DBD6E1118154C401CB3EC49604B47404DBD6E1118154C40
11074	Верхнее Акчерино	7	62	1095	46.303086	46.317737999999999	56.216363999999999	56.208550000000002	0103000020E610000001000000050000000FF0A485CB26474058CA32C4B11A4C400FF0A485CB2647401004C8D0B11B4C40255987A3AB2847401004C8D0B11B4C40255987A3AB28474058CA32C4B11A4C400FF0A485CB26474058CA32C4B11A4C40
10773	Березово	7	62	1095	46.188524000000001	46.300787	56.162812000000002	56.150339000000002	0103000020E610000001000000050000006C41EF8D211847401C28F04E3E134C406C41EF8D21184740BCB20B06D7144C40EE073C3080264740BCB20B06D7144C40EE073C30802647401C28F04E3E134C406C41EF8D211847401C28F04E3E134C40
9011	Ярамор	7	62	878	48.715341000000002	48.740377000000002	56.133983999999998	56.117682000000002	0103000020E61000000100000005000000753E3C4B905B4840F8A92A34100F4C40753E3C4B905B4840F817416326114C40F5DA6CACC45E4840F817416326114C40F5DA6CACC45E4840F8A92A34100F4C40753E3C4B905B4840F8A92A34100F4C40
9635	Эмеково	7	62	878	48.398560000000003	48.473874000000002	55.999994000000001	55.984214000000001	0103000020E6100000010000000500000034BF9A0304334840F7216FB9FAFD4B4034BF9A03043348401E19ABCDFFFF4B405D363AE7A73C48401E19ABCDFFFF4B405D363AE7A73C4840F7216FB9FAFD4B4034BF9A0304334840F7216FB9FAFD4B40
9532	Шарибоксад	7	62	878	48.757669999999997	48.772114999999999	56.165678999999997	56.157654000000001	0103000020E6100000010000000500000085949F54FB604840B30A9B012E144C4085949F54FB60484026512FF834154C4022E010AAD462484026512FF834154C4022E010AAD4624840B30A9B012E144C4085949F54FB604840B30A9B012E144C40
8813	Чодраял	7	62	878	48.853214999999999	48.915702000000003	56.180041000000003	56.154901000000002	0103000020E6100000010000000500000073BA2C26366D4840118FC4CBD3134C4073BA2C26366D484036785F950B174C40DF701FB93575484036785F950B174C40DF701FB935754840118FC4CBD3134C4073BA2C26366D4840118FC4CBD3134C40
9300	Часовенная	7	62	878	48.319803999999998	48.370621999999997	55.936182000000002	55.909225999999997	0103000020E61000000100000005000000A3906456EF28484021567F8461F44B40A3906456EF2848404C8DD0CFD4F74B40CC96AC8A702F48404C8DD0CFD4F74B40CC96AC8A702F484021567F8461F44B40A3906456EF28484021567F8461F44B40
9171	Учейкино	7	62	878	48.770829999999997	48.793647999999997	56.072704999999999	56.061186999999997	0103000020E610000001000000050000004963B48EAA6248405DF8C1F9D4074C404963B48EAA624840BAA0BE654E094C409544F64196654840BAA0BE654E094C409544F641966548405DF8C1F9D4074C404963B48EAA6248405DF8C1F9D4074C40
9517	Сотнур	7	62	878	48.762017999999998	48.793934999999998	56.150218000000002	56.131444999999999	0103000020E610000001000000050000004E7B4ACE89614840821C9430D3104C404E7B4ACE89614840A1A2EA573A134C402B137EA99F654840A1A2EA573A134C402B137EA99F654840821C9430D3104C404E7B4ACE89614840821C9430D3104C40
9308	Приволжский	7	62	878	48.399259999999998	48.442227000000003	55.978079999999999	55.950069999999997	0103000020E61000000100000005000000EC4CA1F31A3348409274CDE49BF94B40EC4CA1F31A334840936FB6B931FD4B404034F3E49A384840936FB6B931FD4B404034F3E49A3848409274CDE49BF94B40EC4CA1F31A3348409274CDE49BF94B40
9250	Помары	7	62	878	48.329470000000001	48.369813000000001	55.979697000000002	55.958427	0103000020E61000000100000005000000AE81AD122C2A48403C4D66BCADFA4B40AE81AD122C2A4840A27E17B666FD4B405D514A08562F4840A27E17B666FD4B405D514A08562F48403C4D66BCADFA4B40AE81AD122C2A48403C4D66BCADFA4B40
8913	Полевая	7	62	878	48.331634999999999	48.359814999999998	56.036994999999997	56.012214	0103000020E61000000100000005000000BF9A0304732A4840D446753A90014C40BF9A0304732A4840C98E8D40BC044C401CCEFC6A0E2E4840C98E8D40BC044C401CCEFC6A0E2E4840D446753A90014C40BF9A0304732A4840D446753A90014C40
8986	Петъялы	7	62	878	48.684314000000001	48.704894000000003	56.105590999999997	56.089739000000002	0103000020E61000000100000005000000F418E599975748407F164B917C0B4C40F418E599975748403FE08101840D4C40C59272F7395A48403FE08101840D4C40C59272F7395A48407F164B917C0B4C40F418E599975748407F164B917C0B4C40
58068	Памашенер	7	62	878	48.220792000000003	48.996037999999999	56.206296999999999	55.828313999999999	0103000020E61000000100000005000000F69B89E9421C4840D368723106EA4B40F69B89E9421C4840A721AAF0671A4C4060C9552C7E7F4840A721AAF0671A4C4060C9552C7E7F4840D368723106EA4B40F69B89E9421C4840D368723106EA4B40
8697	Отымбал	7	62	878	48.662880000000001	48.675877999999997	56.012199000000003	56.006301000000001	0103000020E6100000010000000500000014967840D95448404F779E78CE004C4014967840D95448409F05A1BC8F014C40FE0A992B835648409F05A1BC8F014C40FE0A992B835648404F779E78CE004C4014967840D95448404F779E78CE004C40
9438	Нуршари	7	62	878	48.796711000000002	48.824351999999998	56.174278999999999	56.158461000000003	0103000020E6100000010000000500000086AE44A0FA6548408258367348144C4086AE44A0FA65484096B036C64E164C403332C85D8469484096B036C64E164C403332C85D846948408258367348144C4086AE44A0FA6548408258367348144C40
8755	Новый Карамас	7	62	878	48.956997000000001	48.975681999999999	56.186143000000001	56.171447999999998	0103000020E6100000010000000500000060AFB0E07E7A4840787B1002F2154C4060AFB0E07E7A48408EB0A888D3174C40DFA5D425E37C48408EB0A888D3174C40DFA5D425E37C4840787B1002F2154C4060AFB0E07E7A4840787B1002F2154C40
9607	Моркиялы	7	62	878	48.497922000000003	48.516480999999999	55.959102000000001	55.943860000000001	0103000020E61000000100000005000000BEFA78E8BB3F484054008C67D0F84B40BEFA78E8BB3F48409CC3B5DAC3FA4B40B000A60C1C4248409CC3B5DAC3FA4B40B000A60C1C42484054008C67D0F84B40BEFA78E8BB3F484054008C67D0F84B40
8891	Кленовая Гора	7	62	878	48.422733000000001	48.429470999999999	56.137630999999999	56.132779999999997	0103000020E6100000010000000500000051F86C1D1C3648400CC85EEFFE104C4051F86C1D1C36484038F581E49D114C404BCADDE7F836484038F581E49D114C404BCADDE7F83648400CC85EEFFE104C4051F86C1D1C3648400CC85EEFFE104C40
8842	Кичиер	7	62	878	48.346026000000002	48.355117	56.077351999999998	56.072006999999999	0103000020E6100000010000000500000069C878944A2C4840A20A7F8637094C4069C878944A2C4840DD239BABE6094C4077A04E79742D4840DD239BABE6094C4077A04E79742D4840A20A7F8637094C4069C878944A2C4840A20A7F8637094C40
9138	Карай	7	62	878	48.633029000000001	48.661918999999997	56.052717999999999	56.035587	0103000020E61000000100000005000000B535221807514840D594641D8E044C40B5352218075148408CF4A276BF064C40EECC04C3B95448408CF4A276BF064C40EECC04C3B9544840D594641D8E044C40B535221807514840D594641D8E044C40
9086	Инерымбал	7	62	878	48.613266000000003	48.634321999999997	56.070117000000003	56.060062000000002	0103000020E61000000100000005000000D7DF12807F4E4840BEDD921CB0074C40D7DF12807F4E484063F20698F9084C4010919A763151484063F20698F9084C4010919A7631514840BEDD921CB0074C40D7DF12807F4E4840BEDD921CB0074C40
6592	Волжск	7	62	878	48.390250000000002	48.410516000000001	55.865192	55.84395	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
57928	Большие Параты	7	62	878	48.648398999999998	48.671207000000003	55.989738000000003	55.965671999999998	0103000020E610000001000000050000002AE109BDFE524840DA54DD239BFB4B402AE109BDFE524840E2CD1ABCAFFE4B4053EC681CEA554840E2CD1ABCAFFE4B4053EC681CEA554840DA54DD239BFB4B402AE109BDFE524840DA54DD239BFB4B40
58085	Бизергуб	7	62	878	48.617964000000001	48.644716000000003	55.965088000000002	55.955815999999999	0103000020E610000001000000050000007C0DC171194F48402C7FBE2D58FA4B407C0DC171194F48408BE1EA0088FB4B409E9ACB0D865248408BE1EA0088FB4B409E9ACB0D865248402C7FBE2D58FA4B407C0DC171194F48402C7FBE2D58FA4B40
58069	Березняки	7	62	878	48.282451999999999	48.310308999999997	55.967163999999997	55.955851000000003	0103000020E610000001000000050000004B581B6327244840A96C585359FA4B404B581B63272448402CEFAA07CCFB4B40C5538F34B82748402CEFAA07CCFB4B40C5538F34B8274840A96C585359FA4B404B581B6327244840A96C585359FA4B40
58326	Ярмухаметово	7	61	\N	57.819318000000003	57.833402999999997	52.618350999999997	52.598199000000001	0103000020E6100000010000000500000017838769DFE84C40FDBFEAC8914C4A4017838769DFE84C4075392520264F4A40B3B112F3ACEA4C4075392520264F4A40B3B112F3ACEA4C40FDBFEAC8914C4A4017838769DFE84C40FDBFEAC8914C4A40
58690	Япарсаз	7	61	\N	57.929541	57.950938999999998	52.255631000000001	52.240169999999999	0103000020E6100000010000000500000044A51133FBF64C407BBDFBE3BD1E4A4044A51133FBF64C40016C4084B8204A40D7BE805EB8F94C40016C4084B8204A40D7BE805EB8F94C407BBDFBE3BD1E4A4044A51133FBF64C407BBDFBE3BD1E4A40
58088	Янаул	7	61	\N	54.878439999999998	54.960959000000003	56.294801	56.242694	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
58467	Ялангачево	7	61	\N	56.274358999999997	56.300221999999998	55.957428999999998	55.947212	0103000020E610000001000000050000007F2E1A321E234C407B30293E3EF94B407F2E1A321E234C40F99E91088DFA4B4015C5ABAC6D264C40F99E91088DFA4B4015C5ABAC6D264C407B30293E3EF94B407F2E1A321E234C407B30293E3EF94B40
58648	Ябалаково	7	61	\N	54.223711999999999	54.245567999999999	55.672255	55.653553000000002	0103000020E6100000010000000500000083DC4598A21C4B40F299EC9FA7D34B4083DC4598A21C4B4047C9AB730CD64B40D978B0C56E1F4B4047C9AB730CD64B40D978B0C56E1F4B40F299EC9FA7D34B4083DC4598A21C4B40F299EC9FA7D34B40
58303	Юсупово	7	61	\N	54.644159000000002	54.679983999999997	55.717365999999998	55.699756000000001	0103000020E61000000100000005000000483657CD73524B400397C79A91D94B40483657CD73524B4094A12AA6D2DB4B40D1E638B709574B4094A12AA6D2DB4B40D1E638B709574B400397C79A91D94B40483657CD73524B400397C79A91D94B40
58601	Юнусово	7	61	\N	58.377926000000002	58.397041999999999	55.829315000000001	55.819004	0103000020E61000000100000005000000702711E15F304D4087A5811FD5E84B40702711E15F304D40878A71FE26EA4B40B891B245D2324D40878A71FE26EA4B40B891B245D2324D4087A5811FD5E84B40702711E15F304D4087A5811FD5E84B40
58452	Юмакаево	7	61	\N	55.591343000000002	55.619182000000002	55.925131999999998	55.914721	0103000020E61000000100000005000000F9DB9E20B1CB4B4072FBE59315F54B40F9DB9E20B1CB4B40D53DB2B96AF64B40CD22145B41CF4B40D53DB2B96AF64B40CD22145B41CF4B4072FBE59315F54B40F9DB9E20B1CB4B4072FBE59315F54B40
58670	Юлдыбаево	7	61	\N	57.862976000000003	57.890554000000002	52.350141000000001	52.332512000000001	0103000020E61000000100000005000000D09D60FF75EE4C4087C3D2C08F2A4A40D09D60FF75EE4C408FFE976BD12C4A4037A968ACFDF14C408FFE976BD12C4A4037A968ACFDF14C4087C3D2C08F2A4A40D09D60FF75EE4C4087C3D2C08F2A4A40
58230	Юлдашево	7	61	\N	59.258319999999998	59.273950999999997	55.661811	55.651769999999999	0103000020E610000001000000050000008CF337A110A14D40C84109336DD34B408CF337A110A14D4008910C39B6D44B406EDA8CD310A34D4008910C39B6D44B406EDA8CD310A34D40C84109336DD34B408CF337A110A14D40C84109336DD34B40
58474	Юкаликулево	7	61	\N	58.360138999999997	58.384376000000003	55.338858000000002	55.319971000000002	0103000020E61000000100000005000000CF81E508192E4D408F554ACFF4A84B40CF81E508192E4D4076FEEDB25FAB4B4004AF963B33314D4076FEEDB25FAB4B4004AF963B33314D408F554ACFF4A84B40CF81E508192E4D408F554ACFF4A84B40
8159	Шмидтово	7	61	\N	56.168923999999997	56.230592999999999	54.668118999999997	54.633062000000002	0103000020E6100000010000000500000037C1374D9F154C40912BF52C08514B4037C1374D9F154C40096B63EC84554B40E0D74812841D4C40096B63EC84554B40E0D74812841D4C40912BF52C08514B4037C1374D9F154C40912BF52C08514B40
58313	Шарлык	7	61	\N	55.124192000000001	55.165523999999998	54.911755999999997	54.894227999999998	0103000020E6100000010000000500000061360186E58F4B407095271076724B4061360186E58F4B4044F7AC6BB4744B40FF59F3E32F954B4044F7AC6BB4744B40FF59F3E32F954B407095271076724B4061360186E58F4B407095271076724B40
58207	Шарипово	7	61	\N	58.117432999999998	58.130701000000002	53.589160999999997	53.582864000000001	0103000020E610000001000000050000004F3C670B080F4D4004029D499BCA4A404F3C670B080F4D40118AADA069CB4A40FA4674CFBA104D40118AADA069CB4A40FA4674CFBA104D4004029D499BCA4A404F3C670B080F4D4004029D499BCA4A40
58604	Чуракаево	7	61	\N	54.754733000000002	54.779527000000002	54.015929999999997	53.993174000000003	0103000020E61000000100000005000000221B48179B604B40679E5C5320FF4A40221B48179B604B403C8386FE09024B40ACAC6D8AC7634B403C8386FE09024B40ACAC6D8AC7634B40679E5C5320FF4A40221B48179B604B40679E5C5320FF4A40
58571	Чураево	7	61	\N	54.565134999999998	54.583289999999998	53.704982999999999	53.698160000000001	0103000020E610000001000000050000009869FB5756484B400CB08F4E5DD94A409869FB5756484B40349E08E23CDA4A40BB0A293FA94A4B40349E08E23CDA4A40BB0A293FA94A4B400CB08F4E5DD94A409869FB5756484B400CB08F4E5DD94A40
58455	Чукадыбашево	7	61	\N	54.147939000000001	54.189701999999997	54.410283999999997	54.395341999999999	0103000020E61000000100000005000000C76647AAEF124B401C5E10919A324B40C76647AAEF124B403909A52F84344B402EFEB62748184B403909A52F84344B402EFEB62748184B401C5E10919A324B40C76647AAEF124B401C5E10919A324B40
58482	Чкаловское	7	61	\N	56.564497000000003	56.575043000000001	54.655073999999999	54.646666000000003	0103000020E6100000010000000500000056D80C7041484C40B3B794F3C5524B4056D80C7041484C40DE3AFF76D9534B4099654F029B494C40DE3AFF76D9534B4099654F029B494C40B3B794F3C5524B4056D80C7041484C40B3B794F3C5524B40
58450	Чишма	7	61	\N	54.497770000000003	54.511001999999998	56.264496999999999	56.253906999999998	0103000020E61000000100000005000000087767EDB63F4B40DC9C4A0680204C40087767EDB63F4B40EF71A609DB214C406518778368414B40EF71A609DB214C406518778368414B40DC9C4A0680204C40087767EDB63F4B40DC9C4A0680204C40
58365	Чингизово	7	61	\N	57.995001000000002	58.020738000000001	52.658501999999999	52.648062000000003	0103000020E61000000100000005000000603E59315CFF4C40E3E313B2F3524A40603E59315CFF4C40E02C25CB49544A4069E4F38AA7024D40E02C25CB49544A4069E4F38AA7024D40E3E313B2F3524A40603E59315CFF4C40E3E313B2F3524A40
8386	Чесноковка	7	61	\N	55.903677999999999	55.982263000000003	54.628210000000003	54.591470000000001	0103000020E61000000100000005000000AE0E80B8ABF34B405648F949B54B4B40AE0E80B8ABF34B4095826E2F69504B40128942CBBAFD4B4095826E2F69504B40128942CBBAFD4B405648F949B54B4B40AE0E80B8ABF34B405648F949B54B4B40
58176	Чекмагуш	7	61	\N	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
58472	Чандар	7	61	\N	56.705469999999998	56.726166999999997	55.316051999999999	55.285921999999999	0103000020E61000000100000005000000912749D74C5A4C407C9A931799A44B40912749D74C5A4C40EEEA556474A84B409B374E0AF35C4C40EEEA556474A84B409B374E0AF35C4C407C9A931799A44B40912749D74C5A4C407C9A931799A44B40
58653	Худайбердино	7	61	\N	56.036332999999999	56.051423999999997	52.804146000000003	52.790304999999996	0103000020E61000000100000005000000FE614B8FA6044C40C16ED8B628654A40FE614B8FA6044C40C89A9141EE664A40601DC70F95064C40C89A9141EE664A40601DC70F95064C40C16ED8B628654A40FE614B8FA6044C40C16ED8B628654A40
58435	Хлебодаровка	7	61	\N	55.007717	55.016682000000003	54.740813000000003	54.734127999999998	0103000020E61000000100000005000000C64FE3DEFC804B40F88903E8F75D4B40C64FE3DEFC804B40D0B9DBF5D25E4B404837C2A222824B40D0B9DBF5D25E4B404837C2A222824B40F88903E8F75D4B40C64FE3DEFC804B40F88903E8F75D4B40
58576	Хамитово	7	61	\N	57.967585	58.002842999999999	53.510942	53.497349	0103000020E61000000100000005000000D28C45D3D9FB4C4062D9CC21A9BF4A40D28C45D3D9FB4C409013268C66C14A40E202D0285D004D409013268C66C14A40E202D0285D004D4062D9CC21A9BF4A40D28C45D3D9FB4C4062D9CC21A9BF4A40
16756	Федоровка	7	61	\N	55.943221999999999	55.981814	54.580629000000002	54.560654	0103000020E61000000100000005000000116F9D7FBBF84B40902FA182C3474B40116F9D7FBBF84B40FA0D130D524A4B40A260C614ACFD4B40FA0D130D524A4B40A260C614ACFD4B40902FA182C3474B40116F9D7FBBF84B40902FA182C3474B40
58712	Уязыбашево	7	61	\N	55.045777999999999	55.068137	53.559936	53.548268999999998	0103000020E610000001000000050000002A70B20DDC854B408F34B8AD2DC64A402A70B20DDC854B4031ED9BFBABC74A40E35295B6B8884B4031ED9BFBABC74A40E35295B6B8884B408F34B8AD2DC64A402A70B20DDC854B408F34B8AD2DC64A40
58097	Учалы	7	61	\N	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
59	Уфа	7	61	\N	55.764502	56.311235000000003	54.968240999999999	54.492655999999997	0103000020E6100000010000000500000001DD9733DBE14B40CE16105A0F3F4B4001DD9733DBE14B40BBD23252EF7B4B406F2F698CD6274C40BBD23252EF7B4B406F2F698CD6274C40CE16105A0F3F4B4001DD9733DBE14B40CE16105A0F3F4B40
58354	Утяганово	7	61	\N	56.446297000000001	56.469338	54.326112999999999	54.313975999999997	0103000020E61000000100000005000000C6A6954220394C404CDD955D30284B40C6A6954220394C4075E61E12BE294B4091628044133C4C4075E61E12BE294B4091628044133C4C404CDD955D30284B40C6A6954220394C404CDD955D30284B40
58333	Усмангали	7	61	\N	57.501170000000002	57.520816000000003	54.230038	54.224248000000003	0103000020E6100000010000000500000040DEAB5626C04C40C2189128B41C4B4040DEAB5626C04C402B6B9BE2711D4B40E59D4319AAC24C402B6B9BE2711D4B40E59D4319AAC24C40C2189128B41C4B4040DEAB5626C04C40C2189128B41C4B40
9468	Уршак	7	61	\N	55.883125	55.916758000000002	54.578839000000002	54.560251999999998	0103000020E61000000100000005000000D7A3703D0AF14B4061C26856B6474B40D7A3703D0AF14B401E537765174A4B40562C7E5358F54B401E537765174A4B40562C7E5358F54B4061C26856B6474B40D7A3703D0AF14B4061C26856B6474B40
58578	Урмиязы	7	61	\N	56.865873000000001	56.901626	56.094253999999999	56.080205999999997	0103000020E61000000100000005000000A5BE2CEDD46E4C40B378B130440A4C40A5BE2CEDD46E4C4033C2DB83100C4C40959C137B68734C4033C2DB83100C4C40959C137B68734C40B378B130440A4C40A5BE2CEDD46E4C40B378B130440A4C40
58401	Урметово	7	61	\N	54.227431000000003	54.266129999999997	55.331608000000003	55.313279999999999	0103000020E610000001000000050000005D8C81751C1D4B40D53E1D8F19A84B405D8C81751C1D4B40C68B852172AA4B40033E3F8C10224B40C68B852172AA4B40033E3F8C10224B40D53E1D8F19A84B405D8C81751C1D4B40D53E1D8F19A84B40
58158	Ургуш	7	61	\N	56.653502000000003	56.677694000000002	55.743335000000002	55.729244999999999	0103000020E6100000010000000500000070EF1AF4A5534C40C1E270E657DD4B4070EF1AF4A5534C40707CED9925DF4B4004594FADBE564C40707CED9925DF4B4004594FADBE564C40C1E270E657DD4B4070EF1AF4A5534C40C1E270E657DD4B40
58367	Умирово	7	61	\N	53.792566000000001	53.823943999999997	55.320995000000003	55.300033999999997	0103000020E61000000100000005000000F5F57CCD72E54A4012D89C8367A64B40F5F57CCD72E54A40FB96395D16A94B4022DE3AFF76E94A40FB96395D16A94B4022DE3AFF76E94A4012D89C8367A64B40F5F57CCD72E54A4012D89C8367A64B40
58612	Удряк	7	61	\N	55.184936	55.205615000000002	54.496479000000001	54.486041	0103000020E6100000010000000500000031ED9BFBAB974B40F0C16B97363E4B4031ED9BFBAB974B404D13B69F8C3F4B409548A297519A4B404D13B69F8C3F4B409548A297519A4B40F0C16B97363E4B4031ED9BFBAB974B40F0C16B97363E4B40
58561	Тятербаш	7	61	\N	55.198950000000004	55.226087999999997	53.497017	53.485151000000002	0103000020E6100000010000000500000005C58F3177994B40944F8F6D19BE4A4005C58F3177994B402C47C8409EBF4A404F029B73F09C4B402C47C8409EBF4A404F029B73F09C4B40944F8F6D19BE4A4005C58F3177994B40944F8F6D19BE4A40
58188	Тюменяк	7	61	\N	53.778039999999997	53.811214999999997	54.694133999999998	54.673105999999997	0103000020E610000001000000050000006B7D91D096E34A40E55E605628564B406B7D91D096E34A4055850662D9584B402783A3E4D5E74A4055850662D9584B402783A3E4D5E74A40E55E605628564B406B7D91D096E34A40E55E605628564B40
58461	Тюканово 2-е	7	61	\N	55.477203000000003	55.485495	52.737225000000002	52.73169	0103000020E61000000100000005000000CC46E7FC14BD4B40B6679604A85D4A40CC46E7FC14BD4B40956588635D5E4A408EAF3DB324BE4B40956588635D5E4A408EAF3DB324BE4B40B6679604A85D4A40CC46E7FC14BD4B40B6679604A85D4A40
58462	Тыканово	7	61	\N	55.702185999999998	55.723108000000003	56.085836999999998	56.069876000000001	0103000020E61000000100000005000000C2DA183BE1D94B403D635FB2F1084C40C2DA183BE1D94B40B4E4F1B4FC0A4C40EDBC8DCD8EDC4B40B4E4F1B4FC0A4C40EDBC8DCD8EDC4B403D635FB2F1084C40C2DA183BE1D94B403D635FB2F1084C40
58096	Туймазы	7	61	\N	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
58593	Тугаряково	7	61	\N	54.999828999999998	55.013007999999999	55.774436000000001	55.763376000000001	0103000020E61000000100000005000000D34B8C65FA7F4B409146054EB6E14B40D34B8C65FA7F4B402B6C06B820E34B400E4B033FAA814B402B6C06B820E34B400E4B033FAA814B409146054EB6E14B40D34B8C65FA7F4B409146054EB6E14B40
27931	Тугай	7	61	\N	55.951189999999997	55.986961000000001	54.943871000000001	54.918649000000002	0103000020E6100000010000000500000020240B98C0F94B4066C0594A96754B4020240B98C0F94B404852D2C3D0784B40B7B6F0BC54FE4B404852D2C3D0784B40B7B6F0BC54FE4B4066C0594A96754B4020240B98C0F94B4066C0594A96754B40
58570	Тошкурово	7	61	\N	56.067118000000001	56.094974999999998	56.115158000000001	56.093214000000003	0103000020E61000000100000005000000897C975297084C40C2C3B46FEE0B4C40897C975297084C40B7EF517FBD0E4C4003780B24280C4C40B7EF517FBD0E4C4003780B24280C4C40C2C3B46FEE0B4C40897C975297084C40C2C3B46FEE0B4C40
58179	Тирлянский	7	61	\N	58.551291999999997	58.608012000000002	54.228022000000003	54.187010999999998	0103000020E61000000100000005000000F1457BBC90464D40027FF8F9EF174B40F1457BBC90464D405F622CD32F1D4B40ACC95356D34D4D405F622CD32F1D4B40ACC95356D34D4D40027FF8F9EF174B40F1457BBC90464D40027FF8F9EF174B40
58425	Тимербаево	7	61	\N	55.320753000000003	55.347459000000001	52.672941999999999	52.663466999999997	0103000020E61000000100000005000000058C2E6F0EA94B40D47C957CEC544A40058C2E6F0EA94B406B0DA5F622564A40B6D9588979AC4B406B0DA5F622564A40B6D9588979AC4B40D47C957CEC544A40058C2E6F0EA94B40D47C957CEC544A40
58468	Тепляки	7	61	\N	55.495699000000002	55.517519	56.053527000000003	56.037180999999997	0103000020E6100000010000000500000078D4981073BF4B402B84D558C2044C4078D4981073BF4B40FC3905F9D9064C40810706103EC24B40FC3905F9D9064C40810706103EC24B402B84D558C2044C4078D4981073BF4B402B84D558C2044C40
58615	Темяково	7	61	\N	54.013165000000001	54.038111000000001	54.929720000000003	54.921422	0103000020E61000000100000005000000D6390664AF014B404FE8F527F1754B40D6390664AF014B40F437A11001774B40164F3DD2E0044B40F437A11001774B40164F3DD2E0044B404FE8F527F1754B40D6390664AF014B404FE8F527F1754B40
58456	Таштимерово	7	61	\N	58.675232000000001	58.689076	53.477274000000001	53.466473999999998	0103000020E61000000100000005000000399B8E006E564D409737876BB5BB4A40399B8E006E564D40959D7E5017BD4A40B03A72A433584D40959D7E5017BD4A40B03A72A433584D409737876BB5BB4A40399B8E006E564D409737876BB5BB4A40
58131	Ташкиново	7	61	\N	54.254900999999997	54.296996	56.054884999999999	56.039163000000002	0103000020E61000000100000005000000DD5B9198A0204B404C1B0E4B03054C40DD5B9198A0204B403E05C07806074C407B8505F703264B403E05C07806074C407B8505F703264B404C1B0E4B03054C40DD5B9198A0204B404C1B0E4B03054C40
58449	Таукай-Гайна	7	61	\N	54.952568999999997	54.965207999999997	53.467503000000001	53.455843000000002	0103000020E610000001000000050000007A17EFC7ED794B40268E3C1059BA4A407A17EFC7ED794B4015E46723D7BB4A4035EB8CEF8B7B4B4015E46723D7BB4A4035EB8CEF8B7B4B40268E3C1059BA4A407A17EFC7ED794B40268E3C1059BA4A40
58335	Таубаш-Бадраково	7	61	\N	55.152929	55.164383000000001	55.559002	55.550417000000003	0103000020E6100000010000000500000014CE6E2D93934B40CB14731074C64B4014CE6E2D93934B400533A6608DC74B405A828C800A954B400533A6608DC74B405A828C800A954B40CB14731074C64B4014CE6E2D93934B40CB14731074C64B40
58489	Татарский Малояз	7	61	\N	58.137169	58.170155000000001	55.215913999999998	55.199587999999999	0103000020E610000001000000050000003483F8C08E114D4047567E198C994B403483F8C08E114D40D05FE811A39B4B401D2098A3C7154D40D05FE811A39B4B401D2098A3C7154D4047567E198C994B403483F8C08E114D4047567E198C994B40
58714	Таскаклы	7	61	\N	54.875861999999998	54.893613000000002	55.222154000000003	55.208855999999997	0103000020E6100000010000000500000092E7FA3E1C704B4064C91CCBBB9A4B4092E7FA3E1C704B407A56D28A6F9C4B40E62329E961724B407A56D28A6F9C4B40E62329E961724B4064C91CCBBB9A4B4092E7FA3E1C704B4064C91CCBBB9A4B40
8259	Таптыково	7	61	\N	55.767035999999997	55.811250999999999	54.619813000000001	54.592137999999998	0103000020E61000000100000005000000656D533C2EE24B40035C902DCB4B4B40656D533C2EE24B405D514A08564F4B4074ECA012D7E74B405D514A08564F4B4074ECA012D7E74B40035C902DCB4B4B40656D533C2EE24B40035C902DCB4B4B40
58357	Тамьян-Таймас	7	61	\N	54.548704000000001	54.567425	53.600261000000003	53.588402000000002	0103000020E610000001000000050000009A97C3EE3B464B405473B9C150CB4A409A97C3EE3B464B403A083A5AD5CC4A4066F7E461A1484B403A083A5AD5CC4A4066F7E461A1484B405473B9C150CB4A409A97C3EE3B464B405473B9C150CB4A40
58521	Таллы-Сыза	7	61	\N	53.477229999999999	53.503433999999999	54.989212999999999	54.976281999999998	0103000020E61000000100000005000000C55565DF15BD4A4034D6FECEF67C4B40C55565DF15BD4A4097E315889E7E4B40E4D87A8670C04A4097E315889E7E4B40E4D87A8670C04A4034D6FECEF67C4B40C55565DF15BD4A4034D6FECEF67C4B40
58371	Табулда	7	61	\N	55.428711999999997	55.461041999999999	53.300584000000001	53.288915000000003	0103000020E610000001000000050000008DB3E908E0B64B407429AE2AFBA44A408DB3E908E0B64B40B6D9588979A64A408D0A9C6C03BB4B40B6D9588979A64A408D0A9C6C03BB4B407429AE2AFBA44A408DB3E908E0B64B407429AE2AFBA44A40
58731	Суюндюково	7	61	\N	56.438059000000003	56.458962999999997	55.735799	55.723638000000001	0103000020E61000000100000005000000F75B3B5112384C404912842BA0DC4B40F75B3B5112384C40FAB660A92EDE4B407A89B14CBF3A4C40FAB660A92EDE4B407A89B14CBF3A4C404912842BA0DC4B40F75B3B5112384C404912842BA0DC4B40
1043	Суук-Чишма	7	61	\N	55.932513999999998	55.973855	54.473543999999997	54.450386999999999	0103000020E61000000100000005000000F487669E5CF74B4093C5FD47A6394B40F487669E5CF74B40C79BFC169D3C4B40E605D847A7FC4B40C79BFC169D3C4B40E605D847A7FC4B4093C5FD47A6394B40F487669E5CF74B4093C5FD47A6394B40
58304	Суерметово	7	61	\N	53.479681999999997	53.492528	54.114589000000002	54.103456999999999	0103000020E610000001000000050000006C3D433866BD4A4069C537143E0D4B406C3D433866BD4A409DBD33DAAA0E4B40A12E52280BBF4A409DBD33DAAA0E4B40A12E52280BBF4A4069C537143E0D4B406C3D433866BD4A4069C537143E0D4B40
58362	Субханкулово	7	61	\N	55.576566	55.593535000000003	54.225321999999998	54.217947000000002	0103000020E6100000010000000500000026FE28EACCC94B4073A1F2AFE51B4B4026FE28EACCC94B40DF88EE59D71C4B40040473F4F8CB4B40DF88EE59D71C4B40040473F4F8CB4B4073A1F2AFE51B4B4026FE28EACCC94B4073A1F2AFE51B4B40
33034	Стуколкино	7	61	\N	55.853515999999999	55.898629999999997	54.529501000000003	54.503328000000003	0103000020E610000001000000050000006E4E250340ED4B409F94490D6D404B406E4E250340ED4B40831953B0C6434B402C9ACE4E06F34B40831953B0C6434B402C9ACE4E06F34B409F94490D6D404B406E4E250340ED4B409F94490D6D404B40
15983	Стерлитамак	7	61	\N	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
58368	Старый Курдым	7	61	\N	55.474041	55.499526000000003	56.259887999999997	56.243724999999998	0103000020E6100000010000000500000048FB1F60ADBC4B40DA1B7C61321F4C4048FB1F60ADBC4B40B94F8E0244214C4038C0CC77F0BF4B40B94F8E0244214C4038C0CC77F0BF4B40DA1B7C61321F4C4048FB1F60ADBC4B40DA1B7C61321F4C40
58538	Старый Калкаш	7	61	\N	55.375540999999998	55.409334999999999	53.488692999999998	53.479182000000002	0103000020E6100000010000000500000050A73CBA11B04B407B6AF5D555BD4A4050A73CBA11B04B405E64027E8DBE4A40D80DDB1665B44B405E64027E8DBE4A40D80DDB1665B44B407B6AF5D555BD4A4050A73CBA11B04B407B6AF5D555BD4A40
58498	Старый Акбуляк	7	61	\N	56.732410000000002	56.757221999999999	55.900950000000002	55.885666000000001	0103000020E61000000100000005000000B6A1629CBF5D4C40EE96E4805DF14B40B6A1629CBF5D4C4065AA605452F34B40E6E786A6EC604C4065AA605452F34B40E6E786A6EC604C40EE96E4805DF14B40B6A1629CBF5D4C40EE96E4805DF14B40
32224	Старые Киешки	7	61	\N	56.035398000000001	56.079954999999998	54.583029000000003	54.552509000000001	0103000020E61000000100000005000000022CF2EB87044C4072DF6A9DB8464B40022CF2EB87044C404FCFBBB1A04A4B406A1327F73B0A4C404FCFBBB1A04A4B406A1327F73B0A4C4072DF6A9DB8464B40022CF2EB87044C4072DF6A9DB8464B40
58311	Старые Каргалы	7	61	\N	55.641730000000003	55.661572999999997	55.969828999999997	55.958320999999998	0103000020E61000000100000005000000596E693524D24B40F6083543AAFA4B40596E693524D24B402FDB4E5B23FC4B4053758F6CAED44B402FDB4E5B23FC4B4053758F6CAED44B40F6083543AAFA4B40596E693524D24B40F6083543AAFA4B40
58352	Старые Балыклы	7	61	\N	53.717880000000001	53.751153000000002	55.135840000000002	55.112009999999998	0103000020E61000000100000005000000EB39E97DE3DB4A409869FB57568E4B40EB39E97DE3DB4A408CBE823463914B406AA510C825E04A408CBE823463914B406AA510C825E04A409869FB57568E4B40EB39E97DE3DB4A409869FB57568E4B40
58319	Старосултанбеково	7	61	\N	54.834736999999997	54.857761000000004	55.454799999999999	55.436632000000003	0103000020E610000001000000050000006DE179A9D86A4B408C31B08EE3B74B406DE179A9D86A4B40431CEBE236BA4B406364C91CCB6D4B40431CEBE236BA4B406364C91CCB6D4B408C31B08EE3B74B406DE179A9D86A4B408C31B08EE3B74B40
58433	Старомурапталово	7	61	\N	55.792026999999997	55.802931999999998	52.435746000000002	52.429870999999999	0103000020E610000001000000050000004546072461E54B40D93F4F0306374A404546072461E54B4071AE6186C6374A40B874CC79C6E64B4071AE6186C6374A40B874CC79C6E64B40D93F4F0306374A404546072461E54B40D93F4F0306374A40
58534	Старомрясово	7	61	\N	55.514645000000002	55.527858999999999	54.279753999999997	54.268166999999998	0103000020E6100000010000000500000064062AE3DFC14B40E76ED74B53224B4064062AE3DFC14B406C76A4FACE234B401BF33AE290C34B406C76A4FACE234B401BF33AE290C34B40E76ED74B53224B4064062AE3DFC14B40E76ED74B53224B40
58325	Старокочкильдино	7	61	\N	56.840198999999998	56.871352000000002	56.094906000000002	56.088749999999997	0103000020E61000000100000005000000E2900DA48B6B4C408FC2F5285C0B4C40E2900DA48B6B4C40DB183BE1250C4C40F0A65B76886F4C40DB183BE1250C4C40F0A65B76886F4C408FC2F5285C0B4C40E2900DA48B6B4C408FC2F5285C0B4C40
58668	Старокангышево	7	61	\N	54.939273999999997	54.960546000000001	55.59543	55.58379	0103000020E61000000100000005000000D6FD63213A784B40ADDD76A1B9CA4B40D6FD63213A784B405587DC0C37CC4B40DD26DC2BF37A4B405587DC0C37CC4B40DD26DC2BF37A4B40ADDD76A1B9CA4B40D6FD63213A784B40ADDD76A1B9CA4B40
58608	Староихсаново	7	61	\N	55.044646	55.063294999999997	55.080627	55.068570999999999	0103000020E61000000100000005000000D8F2CAF5B6854B401D3A3DEFC6884B40D8F2CAF5B6854B4059164CFC518A4B400A80F10C1A884B4059164CFC518A4B400A80F10C1A884B401D3A3DEFC6884B40D8F2CAF5B6854B401D3A3DEFC6884B40
58625	Старогусево	7	61	\N	54.169687000000003	54.205027000000001	55.080457000000003	55.070895999999998	0103000020E6100000010000000500000037C7B94DB8154B4067B5C01E13894B4037C7B94DB8154B40FDDD3B6A4C8A4B4004E621533E1A4B40FDDD3B6A4C8A4B4004E621533E1A4B4067B5C01E13894B4037C7B94DB8154B4067B5C01E13894B40
58522	Старобедеево	7	61	\N	56.58276	56.614173999999998	55.204535999999997	55.195365000000002	0103000020E610000001000000050000005FB532E1974A4C403BE466B801994B405FB532E1974A4C40656D533C2E9A4B40D906EE409D4E4C40656D533C2E9A4B40D906EE409D4E4C403BE466B801994B405FB532E1974A4C403BE466B801994B40
58422	Старобаскаково	7	61	\N	55.289895000000001	55.311813999999998	55.154758999999999	55.143234999999997	0103000020E61000000100000005000000102384471BA54B403F52448655924B40102384471BA54B407EE19524CF934B40AC376A85E9A74B407EE19524CF934B40AC376A85E9A74B403F52448655924B40102384471BA54B403F52448655924B40
58245	Старобабичево	7	61	\N	56.129362	56.147615999999999	54.195276999999997	54.182738000000001	0103000020E610000001000000050000002EAC1BEF8E104C4044DE72F563174B402EAC1BEF8E104C409B5434D6FE184B40E42EC214E5124C409B5434D6FE184B40E42EC214E5124C4044DE72F563174B402EAC1BEF8E104C4044DE72F563174B40
58594	Староаккулаево	7	61	\N	54.977559999999997	54.998033	54.131601000000003	54.122405000000001	0103000020E610000001000000050000005AF0A2AF207D4B40F6EE8FF7AA0F4B405AF0A2AF207D4B407A8F334DD8104B4015AA9B8BBF7F4B407A8F334DD8104B4015AA9B8BBF7F4B40F6EE8FF7AA0F4B405AF0A2AF207D4B40F6EE8FF7AA0F4B40
58599	Староабсалямово	7	61	\N	55.644100999999999	55.666649	54.128193000000003	54.112552000000001	0103000020E610000001000000050000001329CDE671D24B40B98C9B1A680E4B401329CDE671D24B40BF49D3A068104B409F7422C154D54B40BF49D3A068104B409F7422C154D54B40B98C9B1A680E4B401329CDE671D24B40B98C9B1A680E4B40
58432	Старая Отрада	7	61	\N	55.83661	55.858277000000001	52.596316999999999	52.572620000000001	0103000020E61000000100000005000000D7C0560916EB4B408C84B69C4B494A40D7C0560916EB4B4040868E1D544C4A405AF44E05DCED4B4040868E1D544C4A405AF44E05DCED4B408C84B69C4B494A40D7C0560916EB4B408C84B69C4B494A40
58404	Старая Мушта	7	61	\N	54.229424999999999	54.262509999999999	55.809848000000002	55.792569	0103000020E6100000010000000500000041F163CC5D1D4B406669A7E672E54B4041F163CC5D1D4B40925D6919A9E74B40BD6F7CED99214B40925D6919A9E74B40BD6F7CED99214B406669A7E672E54B4041F163CC5D1D4B406669A7E672E54B40
58736	Сосновый Бор	7	61	\N	54.319840999999997	54.333100000000002	54.240715000000002	54.224373999999997	0103000020E61000000100000005000000C075C58CF0284B404E098849B81C4B40C075C58CF0284B400D54C6BFCF1E4B4018265305A32A4B400D54C6BFCF1E4B4018265305A32A4B404E098849B81C4B40C075C58CF0284B404E098849B81C4B40
15877	Сибай	7	61	\N	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
58372	Сибады	7	61	\N	55.231712000000002	55.250576000000002	56.198214999999998	56.184365	0103000020E610000001000000050000009E0B23BDA89D4B4076C3B64599174C409E0B23BDA89D4B40CF49EF1B5F194C40CD94D6DF12A04B40CF49EF1B5F194C40CD94D6DF12A04B4076C3B64599174C409E0B23BDA89D4B4076C3B64599174C40
58674	Селивановский	7	61	\N	58.680011999999998	58.702505000000002	53.395685	53.384338	0103000020E610000001000000050000009B711AA20A574D40164ED2FC31B14A409B711AA20A574D4046425BCEA5B24A40642310AFEB594D4046425BCEA5B24A40642310AFEB594D40164ED2FC31B14A409B711AA20A574D40164ED2FC31B14A40
58491	Сараштыбаш	7	61	\N	55.386921999999998	55.409227999999999	56.258043000000001	56.250497000000003	0103000020E610000001000000050000002C0DFCA886B14B40815F234910204C402C0DFCA886B14B401AFB928D07214C40C24D469561B44B401AFB928D07214C40C24D469561B44B40815F234910204C402C0DFCA886B14B40815F234910204C40
58529	Сарайсино	7	61	\N	55.585287999999998	55.599328999999997	53.35718	53.345500000000001	0103000020E61000000100000005000000E15E99B7EACA4B404E62105839AC4A40E15E99B7EACA4B4084640113B8AD4A40AE450BD0B6CC4B4084640113B8AD4A40AE450BD0B6CC4B404E62105839AC4A40E15E99B7EACA4B404E62105839AC4A40
58471	Саннинское	7	61	\N	56.132505999999999	56.151119000000001	55.289597999999998	55.272830999999996	0103000020E610000001000000050000000B43E4F4F5104C40E02A4F20ECA24B400B43E4F4F5104C40567E198C11A54B40F1660DDE57134C40567E198C11A54B40F1660DDE57134C40E02A4F20ECA24B400B43E4F4F5104C40E02A4F20ECA24B40
58370	Санжаровка	7	61	\N	55.48659	55.509542000000003	54.626207999999998	54.615147	0103000020E61000000100000005000000C347C49448BE4B40C39D0B23BD4E4B40C347C49448BE4B402D3F709527504B401FF818AC38C14B402D3F709527504B401FF818AC38C14B40C39D0B23BD4E4B40C347C49448BE4B40C39D0B23BD4E4B40
58481	Сандин 2-й	7	61	\N	55.627966999999998	55.633904999999999	52.669037000000003	52.656410000000001	0103000020E61000000100000005000000CEFBFF3861D04B4039622D3E05544A40CEFBFF3861D04B4030682101A3554A40ACE28DCC23D14B4030682101A3554A40ACE28DCC23D14B4039622D3E05544A40CEFBFF3861D04B4039622D3E05544A40
58531	Самарино	7	61	\N	54.951490999999997	54.972861999999999	54.636083999999997	54.618133999999998	0103000020E610000001000000050000001BB80375CA794B40D845D1031F4F4B401BB80375CA794B4022C154336B514B40B5C2F4BD867C4B4022C154336B514B40B5C2F4BD867C4B40D845D1031F4F4B401BB80375CA794B40D845D1031F4F4B40
58702	Салихово	7	61	\N	55.410646999999997	55.434793999999997	56.195751000000001	56.183352999999997	0103000020E61000000100000005000000AA99B51490B44B40CE4F711C78174C40AA99B51490B44B406494675E0E194C409E3F6D54A7B74B406494675E0E194C409E3F6D54A7B74B40CE4F711C78174C40AA99B51490B44B40CE4F711C78174C40
58689	Салимовка	7	61	\N	55.469082	55.482216000000001	56.017060000000001	56.010060000000003	0103000020E61000000100000005000000369204E10ABC4B40B77F65A549014C40369204E10ABC4B40EE08A7052F024C40D1CDFE40B9BD4B40EE08A7052F024C40D1CDFE40B9BD4B40B77F65A549014C40369204E10ABC4B40B77F65A549014C40
58446	Салаватово	7	61	\N	58.569851	58.584600999999999	53.472585000000002	53.464491000000002	0103000020E61000000100000005000000E44BA8E0F0484D40A724EB7074BB4A40E44BA8E0F0484D4043CA4FAA7DBC4A40BD1AA034D44A4D4043CA4FAA7DBC4A40BD1AA034D44A4D40A724EB7074BB4A40E44BA8E0F0484D40A724EB7074BB4A40
7789	Салават	7	61	\N	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
58159	Сазово	7	61	\N	55.025475999999998	55.046928000000001	55.954994999999997	55.947409	0103000020E610000001000000050000009C6A2DCC42834B40D177B7B244F94B409C6A2DCC42834B40F86BB2463DFA4B4023A298BC01864B40F86BB2463DFA4B4023A298BC01864B40D177B7B244F94B409C6A2DCC42834B40D177B7B244F94B40
58181	Редькино	7	61	\N	54.500680000000003	54.543925000000002	55.820869999999999	55.808326000000001	0103000020E6100000010000000500000072E1404816404B40D540F33977E74B4072E1404816404B403E22A64412E94B40083D9B559F454B403E22A64412E94B40083D9B559F454B40D540F33977E74B4072E1404816404B40D540F33977E74B40
3847	Покровка	7	61	\N	55.790140000000001	55.830824999999997	54.795696	54.774991999999997	0103000020E6100000010000000500000077A1B94E23E54B40B05417F032634B4077A1B94E23E54B406DC7D45DD9654B407FD93D7958EA4B406DC7D45DD9654B407FD93D7958EA4B40B05417F032634B4077A1B94E23E54B40B05417F032634B40
58315	Петряево	7	61	\N	55.585099999999997	55.609417000000001	54.350195999999997	54.335997999999996	0103000020E61000000100000005000000DE718A8EE4CA4B40BDC282FB012B4B40DE718A8EE4CA4B405298F738D32C4B402F50526001CE4B405298F738D32C4B402F50526001CE4B40BDC282FB012B4B40DE718A8EE4CA4B40BDC282FB012B4B40
58314	Петропавловка	7	61	\N	56.033943000000001	56.067431999999997	56.170780999999998	56.154685999999998	0103000020E61000000100000005000000CD76853E58044C40149337C0CC134C40CD76853E58044C409BE3DC26DC154C40185A9D9CA1084C409BE3DC26DC154C40185A9D9CA1084C40149337C0CC134C40CD76853E58044C40149337C0CC134C40
58248	Пахарь	7	61	\N	54.284042999999997	54.301461000000003	54.052787000000002	54.040987999999999	0103000020E6100000010000000500000030D461855B244B40A4C343183F054B4030D461855B244B40B55373B9C1064B407E02284696264B40B55373B9C1064B407E02284696264B40A4C343183F054B4030D461855B244B40A4C343183F054B40
58711	Павловка	7	61	\N	56.406654000000003	56.431690000000003	54.048664000000002	54.040109999999999	0103000020E61000000100000005000000D064FF3C0D344C400C1F115322054B40D064FF3C0D344C400C3F389F3A064B405001309E41374C400C3F389F3A064B405001309E41374C400C1F115322054B40D064FF3C0D344C400C1F115322054B40
7989	Октябрьский	7	61	\N	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
58405	Новый Янзигит	7	61	\N	54.184060000000002	54.208818000000001	55.872374999999998	55.858907000000002	0103000020E610000001000000050000003A4030478F174B401AA721AAF0ED4B403A4030478F174B408B6CE7FBA9EF4B407768588CBA1A4B408B6CE7FBA9EF4B407768588CBA1A4B401AA721AAF0ED4B403A4030478F174B401AA721AAF0ED4B40
58631	Новый Биктяш	7	61	\N	53.917521000000001	53.946654000000002	53.776335000000003	53.759618000000003	0103000020E610000001000000050000005532005471F54A40FAB9A1293BE14A405532005471F54A40BEDEFDF15EE34A40555051F52BF94A40BEDEFDF15EE34A40555051F52BF94A40FAB9A1293BE14A405532005471F54A40FAB9A1293BE14A40
58253	Новый Актанышбаш	7	61	\N	54.296655000000001	54.326030000000003	55.925657000000001	55.908358	0103000020E61000000100000005000000F29881CAF8254B40AD872F1345F44B40F29881CAF8254B402028B7ED7BF64B40E8C1DD59BB294B402028B7ED7BF64B40E8C1DD59BB294B40AD872F1345F44B40F29881CAF8254B40AD872F1345F44B40
58692	Новые Татышлы	7	61	\N	55.927726	55.943420000000003	56.231318000000002	56.217826000000002	0103000020E610000001000000050000000FD3BEB9BFF64B40F81BEDB8E11B4C400FD3BEB9BFF64B40F27C06D49B1D4C4038328FFCC1F84B40F27C06D49B1D4C4038328FFCC1F84B40F81BEDB8E11B4C400FD3BEB9BFF64B40F81BEDB8E11B4C40
58583	Новые Бишинды	7	61	\N	53.658769999999997	53.679144000000001	54.467678999999997	54.458368999999998	0103000020E61000000100000005000000FFCA4A9352D44A400740DCD5AB3A4B40FFCA4A9352D44A405303CDE7DC3B4B4027A3CA30EED64A405303CDE7DC3B4B4027A3CA30EED64A400740DCD5AB3A4B40FFCA4A9352D44A400740DCD5AB3A4B40
58458	Новошиликово	7	61	\N	54.887306000000002	54.898184999999998	55.760975000000002	55.753447999999999	0103000020E61000000100000005000000B5C5353E93714B40499EEBFB70E04B40B5C5353E93714B406C09F9A067E14B40FE60E0B9F7724B406C09F9A067E14B40FE60E0B9F7724B40499EEBFB70E04B40B5C5353E93714B40499EEBFB70E04B40
58361	Новошареево	7	61	\N	56.678232999999999	56.696244	54.534522000000003	54.521993000000002	0103000020E61000000100000005000000B308C556D0564C40D7DEA7AAD0424B40B308C556D0564C400B7F86376B444B40A304FD851E594C400B7F86376B444B40A304FD851E594C40D7DEA7AAD0424B40B308C556D0564C40D7DEA7AAD0424B40
58295	Новоуртаево	7	61	\N	55.254671999999999	55.274875999999999	55.409435999999999	55.400869999999998	0103000020E610000001000000050000007C9A931799A04B4048F949B54FB34B407C9A931799A04B400CE71A6668B44B40473A03232FA34B400CE71A6668B44B40473A03232FA34B4048F949B54FB34B407C9A931799A04B4048F949B54FB34B40
58703	Новоурсаево	7	61	\N	53.389401999999997	53.425773999999997	55.142910000000001	55.130744999999997	0103000020E610000001000000050000009D7FBBECD7B14A40C98E8D40BC904B409D7FBBECD7B14A40BC22F8DF4A924B4059BE2EC37FB64A40BC22F8DF4A924B4059BE2EC37FB64A40C98E8D40BC904B409D7FBBECD7B14A40C98E8D40BC904B40
58698	Новониколаевское	7	61	\N	56.522860000000001	56.546225	52.685155000000002	52.671249000000003	0103000020E610000001000000050000007B319413ED424C40823CBB7CEB554A407B319413ED424C406FD8B628B3574A40F9A067B3EA454C406FD8B628B3574A40F9A067B3EA454C40823CBB7CEB554A407B319413ED424C40823CBB7CEB554A40
58234	Новомуслюмово	7	61	\N	58.443871000000001	58.487349999999999	55.957177000000001	55.92718	0103000020E610000001000000050000004852D2C3D0384D40ADC090D5ADF64B404852D2C3D0384D40E0BDA3C684FA4B4051DA1B7C613E4D40E0BDA3C684FA4B4051DA1B7C613E4D40ADC090D5ADF64B404852D2C3D0384D40ADC090D5ADF64B40
58369	Новокуручево	7	61	\N	54.029190999999997	54.053193999999998	55.083694000000001	55.067937000000001	0103000020E61000000100000005000000342BDB87BC034B401C98DC28B2884B40342BDB87BC034B408B6F287CB68A4B40F52B9D0FCF064B408B6F287CB68A4B40F52B9D0FCF064B401C98DC28B2884B40342BDB87BC034B401C98DC28B2884B40
58229	Новокангышево	7	61	\N	55.036346000000002	55.053800000000003	55.560015	55.546649000000002	0103000020E6100000010000000500000093AB58FCA6844B4010B22C98F8C54B4093AB58FCA6844B407D224F92AEC74B402D431CEBE2864B407D224F92AEC74B402D431CEBE2864B4010B22C98F8C54B4093AB58FCA6844B4010B22C98F8C54B40
58373	Новокайпаново	7	61	\N	55.769846999999999	55.786825	56.357385000000001	56.344192	0103000020E610000001000000050000003CF6B3588AE24B40BDC5C37B0E2C4C403CF6B3588AE24B405D8AABCABE2D4C406D567DAEB6E44B405D8AABCABE2D4C406D567DAEB6E44B40BDC5C37B0E2C4C403CF6B3588AE24B40BDC5C37B0E2C4C40
58191	Новокабаново	7	61	\N	53.901755999999999	53.931274000000002	55.926735999999998	55.910845999999999	0103000020E61000000100000005000000637C98BD6CF34A40A1D80A9A96F44B40637C98BD6CF34A404F0306499FF64B40BCCE86FC33F74A404F0306499FF64B40BCCE86FC33F74A40A1D80A9A96F44B40637C98BD6CF34A40A1D80A9A96F44B40
58430	Новая Уралка	7	61	\N	55.818078	55.832630999999999	52.691001999999997	52.676600000000001	0103000020E61000000100000005000000DEC9A7C7B6E84B409F3C2CD49A564A40DEC9A7C7B6E84B403CBCE7C072584A40615111A793EA4B403CBCE7C072584A40615111A793EA4B409F3C2CD49A564A40DEC9A7C7B6E84B409F3C2CD49A564A40
58403	Нижняя Татья	7	61	\N	54.422006000000003	54.445030000000003	55.909398000000003	55.892885	0103000020E610000001000000050000009F5BE84A04364B40630B410E4AF24B409F5BE84A04364B401F86562767F44B4094DE37BEF6384B401F86562767F44B4094DE37BEF6384B40630B410E4AF24B409F5BE84A04364B40630B410E4AF24B40
58770	Нижный Чат	7	61	\N	55.398349000000003	55.41442	56.090482000000002	56.079357000000002	0103000020E6100000010000000500000079B29B19FDB24B40B6DAC35E280A4C4079B29B19FDB24B40377007EA940B4C407767EDB60BB54B40377007EA940B4C407767EDB60BB54B40B6DAC35E280A4C4079B29B19FDB24B40B6DAC35E280A4C40
58353	Нижний Тюкунь	7	61	\N	56.378411	56.399557000000001	54.206041999999997	54.194902999999996	0103000020E610000001000000050000002CB98AC56F304C403672DD94F2184B402CB98AC56F304C401CCD91955F1A4B40A6F10BAF24334C401CCD91955F1A4B40A6F10BAF24334C403672DD94F2184B402CB98AC56F304C403672DD94F2184B40
58533	Нижний Ташбукан	7	61	\N	56.558478000000001	56.580936000000001	53.750391999999998	53.732968	0103000020E610000001000000050000008BC404357C474C40DC813AE5D1DD4A408BC404357C474C400B9755D80CE04A40D788601C5C4A4C400B9755D80CE04A40D788601C5C4A4C40DC813AE5D1DD4A408BC404357C474C40DC813AE5D1DD4A40
58638	Нижний Муйнак	7	61	\N	56.699181000000003	56.709691999999997	51.989610999999996	51.983144000000003	0103000020E61000000100000005000000077E54C37E594C401BA19FA9D7FD4940077E54C37E594C408461C092ABFE4940CD1DFD2FD75A4C408461C092ABFE4940CD1DFD2FD75A4C401BA19FA9D7FD4940077E54C37E594C401BA19FA9D7FD4940
58247	Нижний Искуш	7	61	\N	58.721361000000002	58.764983000000001	55.828121000000003	55.810906000000003	0103000020E6100000010000000500000010CEA78E555C4D40AA108FC4CBE74B4010CEA78E555C4D40BF1072DEFFE94B407C7F83F6EA614D40BF1072DEFFE94B407C7F83F6EA614D40AA108FC4CBE74B4010CEA78E555C4D40AA108FC4CBE74B40
58650	Нижние Киги	7	61	\N	58.474719999999998	58.534601000000002	55.553508000000001	55.529511999999997	0103000020E61000000100000005000000E960FD9FC33C4D40766B990CC7C34B40E960FD9FC33C4D408509A359D9C64B4057B439CE6D444D408509A359D9C64B4057B439CE6D444D40766B990CC7C34B40E960FD9FC33C4D40766B990CC7C34B40
58227	Нижнебалтачево	7	61	\N	56.104218000000003	56.134428999999997	56.215178000000002	56.202545999999998	0103000020E61000000100000005000000C8D3F203570D4C40C2F7FE06ED194C40C8D3F203570D4C40CB68E4F38A1B4C4026512FF834114C40CB68E4F38A1B4C4026512FF834114C40C2F7FE06ED194C40C8D3F203570D4C40C2F7FE06ED194C40
2298	Нижегородка	7	61	\N	55.816110999999999	55.879252999999999	54.636512000000003	54.596207	0103000020E61000000100000005000000F373435376E84B40B952CF82504C4B40F373435376E84B407BC1A73979514B4077F4BF5C8BF04B407BC1A73979514B4077F4BF5C8BF04B40B952CF82504C4B40F373435376E84B40B952CF82504C4B40
8531	Нефтекамск	7	61	\N	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
58684	Набережный	7	61	\N	56.347931000000003	56.362375999999998	54.504263999999999	54.498863	0103000020E61000000100000005000000DE21C500892C4C409C1727BEDA3F4B40DE21C500892C4C406B4606B98B404B407A6D3656622E4C406B4606B98B404B407A6D3656622E4C409C1727BEDA3F4B40DE21C500892C4C409C1727BEDA3F4B40
58607	Мукасово 1-е	7	61	\N	58.619374999999998	58.630352999999999	52.796686999999999	52.786433000000002	0103000020E61000000100000005000000E17A14AE474F4D4062BF27D6A9644A40E17A14AE474F4D40FD12F1D6F9654A40BEF73768AF504D40FD12F1D6F9654A40BEF73768AF504D4062BF27D6A9644A40E17A14AE474F4D4062BF27D6A9644A40
58394	Мичуринск	7	61	\N	54.137895999999998	54.152458000000003	54.938538999999999	54.929957999999999	0103000020E61000000100000005000000E61F7D93A6114B40A8531EDD08774B40E61F7D93A6114B40A182C30B22784B40BD0166BE83134B40A182C30B22784B40BD0166BE83134B40A8531EDD08774B40E61F7D93A6114B40A8531EDD08774B40
7265	Михайловка	7	61	\N	55.843940000000003	55.917791000000001	54.831119999999999	54.786040999999997	0103000020E61000000100000005000000A4E4D53906EC4B405628D2FD9C644B40A4E4D53906EC4B409886E123626A4B4015C8EC2C7AF54B409886E123626A4B4015C8EC2C7AF54B405628D2FD9C644B40A4E4D53906EC4B405628D2FD9C644B40
58165	Мирный	7	61	\N	54.114593999999997	54.119138999999997	53.774003999999998	53.770949999999999	0103000020E61000000100000005000000AE282504AB0E4B40F46C567DAEE24A40AE282504AB0E4B40917C259012E34A40CD565EF23F0F4B40917C259012E34A40CD565EF23F0F4B40F46C567DAEE24A40AE282504AB0E4B40F46C567DAEE24A40
58196	Миндяк	7	61	\N	58.774065	58.831125999999998	54.063853999999999	54.002273000000002	0103000020E6100000010000000500000037FDD98F14634D40F8544E7B4A004B4037FDD98F14634D4001DC2C5E2C084B407A6D3656626A4D4001DC2C5E2C084B407A6D3656626A4D40F8544E7B4A004B4037FDD98F14634D40F8544E7B4A004B40
6151	Миловка	7	61	\N	55.805097000000004	55.860227000000002	54.795115000000003	54.766115999999997	0103000020E61000000100000005000000CA8D226B0DE74B409E78CE1610624B40CA8D226B0DE74B408FC70C54C6654B406F1118EB1BEE4B408FC70C54C6654B406F1118EB1BEE4B409E78CE1610624B40CA8D226B0DE74B409E78CE1610624B40
58250	Микяшево	7	61	\N	54.636955	54.664164999999997	54.236806000000001	54.214908999999999	0103000020E610000001000000050000000803CFBD87514B40DB4E5B23821B4B400803CFBD87514B4090BFB4A84F1E4B40EC12D55B03554B4090BFB4A84F1E4B40EC12D55B03554B40DB4E5B23821B4B400803CFBD87514B40DB4E5B23821B4B40
58673	Мечетлино	7	61	\N	57.991731000000001	58.019804000000001	55.373562	55.352474999999998	0103000020E61000000100000005000000F6B6990AF1FE4C402CD49AE61DAD4B40F6B6990AF1FE4C40A1832EE1D0AF4B403D2AFEEF88024D40A1832EE1D0AF4B403D2AFEEF88024D402CD49AE61DAD4B40F6B6990AF1FE4C402CD49AE61DAD4B40
58094	Мелеуз	7	61	\N	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
58345	Масяково	7	61	\N	58.595354	58.622689999999999	55.595933000000002	55.583342000000002	0103000020E610000001000000050000007AC5538F344C4D400E315EF3AACA4B407AC5538F344C4D40B8CD548847CC4B40EBC5504EB44F4D40B8CD548847CC4B40EBC5504EB44F4D400E315EF3AACA4B407AC5538F344C4D400E315EF3AACA4B40
58338	Манышта	7	61	\N	57.596570999999997	57.609067000000003	54.271411000000001	54.262340000000002	0103000020E61000000100000005000000FA5E43705CCC4C4061376C5B94214B40FA5E43705CCC4C4028637C98BD224B4053094FE8F5CD4C4028637C98BD224B4053094FE8F5CD4C4061376C5B94214B40FA5E43705CCC4C4061376C5B94214B40
58339	Маломаксютово	7	61	\N	56.308342000000003	56.324897999999997	53.424610000000001	53.413286999999997	0103000020E61000000100000005000000DBFD2AC077274C40546EA296E6B44A40DBFD2AC077274C40FCC6D79E59B64A409544F64196294C40FCC6D79E59B64A409544F64196294C40546EA296E6B44A40DBFD2AC077274C40546EA296E6B44A40
58587	Майгашта	7	61	\N	58.199008999999997	58.213192999999997	53.536171000000003	53.529705999999997	0103000020E61000000100000005000000094E7D2079194D405B3FFD67CDC34A40094E7D2079194D4025085740A1C44A40395E81E8491B4D4025085740A1C44A40395E81E8491B4D405B3FFD67CDC34A40094E7D2079194D405B3FFD67CDC34A40
58331	Левали	7	61	\N	58.613014999999997	58.637898	55.725042000000002	55.703586000000001	0103000020E610000001000000050000008D7A8846774E4D4034F6251B0FDA4B408D7A8846774E4D40FC1C1F2DCEDC4B40871744A4A6514D40FC1C1F2DCEDC4B40871744A4A6514D4034F6251B0FDA4B408D7A8846774E4D4034F6251B0FDA4B40
58669	Кызыл-Юлдуз	7	61	\N	54.590584	54.604579999999999	55.649540000000002	55.636792999999997	0103000020E610000001000000050000003BC5AA41984B4B402EA9DA6E82D14B403BC5AA41984B4B40D0B8702024D34B4068E89FE0624D4B40D0B8702024D34B4068E89FE0624D4B402EA9DA6E82D14B403BC5AA41984B4B402EA9DA6E82D14B40
58642	Кызлар-Бирган	7	61	\N	57.252768000000003	57.272989000000003	52.919282000000003	52.908822999999998	0103000020E61000000100000005000000D8BCAAB35AA04C40226DE34F54744A40D8BCAAB35AA04C4097E65608AB754A407995B54DF1A24C4097E65608AB754A407995B54DF1A24C40226DE34F54744A40D8BCAAB35AA04C40226DE34F54744A40
58589	Кутуево	7	61	\N	59.027569999999997	59.041988000000003	54.181105000000002	54.171255000000002	0103000020E61000000100000005000000E42CEC6987834D40642310AFEB154B40E42CEC6987834D403012DA722E174B408869DFDC5F854D403012DA722E174B408869DFDC5F854D40642310AFEB154B40E42CEC6987834D40642310AFEB154B40
58337	Кусепеево	7	61	\N	57.959184999999998	57.977637000000001	55.356681999999999	55.349164000000002	0103000020E6100000010000000500000029E8F692C6FA4C406478EC67B1AC4B4029E8F692C6FA4C4033897AC1A7AD4B40062E8F3523FD4C4033897AC1A7AD4B40062E8F3523FD4C406478EC67B1AC4B4029E8F692C6FA4C406478EC67B1AC4B40
58709	Кусекеево	7	61	\N	54.725062000000001	54.754534999999997	54.998556000000001	54.975009999999997	0103000020E6100000010000000500000043C9E4D4CE5C4B40F0A2AF20CD7C4B4043C9E4D4CE5C4B40BF9CD9AED07F4B40FB57569A94604B40BF9CD9AED07F4B40FB57569A94604B40F0A2AF20CD7C4B4043C9E4D4CE5C4B40F0A2AF20CD7C4B40
58605	Кусеево	7	61	\N	58.414442999999999	58.436191000000001	52.989238999999998	52.978276999999999	0103000020E610000001000000050000002F87DD770C354D40E9B6442E387D4A402F87DD770C354D40C07630629F7E4A409FE74F1BD5374D40C07630629F7E4A409FE74F1BD5374D40E9B6442E387D4A402F87DD770C354D40E9B6442E387D4A40
58360	Кумурлы	7	61	\N	56.565054000000003	56.581861000000004	54.510725000000001	54.495705000000001	0103000020E61000000100000005000000AC3C81B053484C405ABBED42733F4B40AC3C81B053484C40F31FD26F5F414B40B0E8D66B7A4A4C40F31FD26F5F414B40B0E8D66B7A4A4C405ABBED42733F4B40AC3C81B053484C405ABBED42733F4B40
8146	Кумертау	7	61	\N	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
1267	Кулушево	7	61	\N	56.164386999999998	56.205269999999999	54.511116999999999	54.492060000000002	0103000020E610000001000000050000009B711AA20A154C40BBD573D2FB3E4B409B711AA20A154C40FEB627486C414B40CA6C9049461A4C40FEB627486C414B40CA6C9049461A4C40BBD573D2FB3E4B409B711AA20A154C40BBD573D2FB3E4B40
58652	Кузгово	7	61	\N	54.050499000000002	54.078643	55.896549	55.882171999999997	0103000020E6100000010000000500000088BD50C076064B4034B91803EBF04B4088BD50C076064B4079211D1EC2F24B4098874CF9100A4B4079211D1EC2F24B4098874CF9100A4B4034B91803EBF04B4088BD50C076064B4034B91803EBF04B40
58704	Кувыково	7	61	\N	55.649033000000003	55.664996000000002	55.066592	55.056569000000003	0103000020E610000001000000050000002C836A8313D34B40D57B2AA73D874B402C836A8313D34B406E162F1686884B4044FCC3961ED54B406E162F1686884B4044FCC3961ED54B40D57B2AA73D874B402C836A8313D34B40D57B2AA73D874B40
58494	Кубиязы	7	61	\N	56.718235	56.766914	56.114586000000003	56.092998000000001	0103000020E61000000100000005000000D9EBDD1FEF5B4C40F54BC45BE70B4C40D9EBDD1FEF5B4C402C4A09C1AA0E4C401A6CEA3C2A624C402C4A09C1AA0E4C401A6CEA3C2A624C40F54BC45BE70B4C40D9EBDD1FEF5B4C40F54BC45BE70B4C40
58647	Красный Октябрь	7	61	\N	55.369988999999997	55.3797	54.740988999999999	54.729652000000002	0103000020E610000001000000050000009B70AFCC5BAF4B4002BB9A3C655D4B409B70AFCC5BAF4B400ED940BAD85E4B40462575029AB04B400ED940BAD85E4B40462575029AB04B4002BB9A3C655D4B409B70AFCC5BAF4B4002BB9A3C655D4B40
58681	Красный Клин	7	61	\N	55.224299999999999	55.246479999999998	53.896639	53.886248999999999	0103000020E61000000100000005000000143FC6DCB59C4B406D8E739B70F14A40143FC6DCB59C4B40B9A81611C5F24A401D8F19A88C9F4B40B9A81611C5F24A401D8F19A88C9F4B406D8E739B70F14A40143FC6DCB59C4B406D8E739B70F14A40
58695	Комсомольск	7	61	\N	59.722999999999999	59.745054000000003	54.623029000000002	54.612257999999997	0103000020E61000000100000005000000068195438BDC4D40705B5B785E4E4B40068195438BDC4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40705B5B785E4E4B40068195438BDC4D40705B5B785E4E4B40
58707	Комсомол	7	61	\N	58.130260999999997	58.143124	55.280374999999999	55.269455999999998	0103000020E61000000100000005000000DD787764AC104D4001DBC1887DA24B40DD787764AC104D40D9CEF753E3A34B40E8A221E351124D40D9CEF753E3A34B40E8A221E351124D4001DBC1887DA24B40DD787764AC104D4001DBC1887DA24B40
58501	Козлоялово	7	61	\N	54.558433000000001	54.576408000000001	56.044513000000002	56.035763000000003	0103000020E61000000100000005000000EB0088BB7A474B4014B4C9E193044C40EB0088BB7A474B40999F1B9AB2054C408E93C2BCC7494B40999F1B9AB2054C408E93C2BCC7494B4014B4C9E193044C40EB0088BB7A474B4014B4C9E193044C40
58527	Кожай-Икские Вершины	7	61	\N	54.058259999999997	54.079819999999998	53.886429999999997	53.861862000000002	0103000020E610000001000000050000001D554D1075074B4024D5777E51EE4A401D554D1075074B40BD18CA8976F14A408AC8B08A370A4B40BD18CA8976F14A408AC8B08A370A4B4024D5777E51EE4A401D554D1075074B4024D5777E51EE4A40
58528	Кистенли-Ивановка	7	61	\N	54.171331000000002	54.193600000000004	53.841562000000003	53.827039999999997	0103000020E610000001000000050000003FE5982CEE154B40EE3D5C72DCE94A403FE5982CEE154B4037C7B94DB8EB4A40B84082E2C7184B4037C7B94DB8EB4A40B84082E2C7184B40EE3D5C72DCE94A403FE5982CEE154B40EE3D5C72DCE94A40
7621	Кириллово	7	61	\N	56.286054999999998	56.325491	54.818142999999999	54.787697000000001	0103000020E61000000100000005000000BBED42739D244C4023145B41D3644B40BBED42739D244C40C539EAE8B8684B40381268B0A9294C40C539EAE8B8684B40381268B0A9294C4023145B41D3644B40BBED42739D244C4023145B41D3644B40
58267	Кир-Тлявли	7	61	\N	54.126441999999997	54.151775000000001	54.767595999999998	54.756433000000001	0103000020E61000000100000005000000A06B5F402F104B40BE4EEACBD2604B40A06B5F402F104B402C45F29540624B40DAACFA5C6D134B402C45F29540624B40DAACFA5C6D134B40BE4EEACBD2604B40A06B5F402F104B40BE4EEACBD2604B40
58710	Кинзябаево	7	61	\N	56.168897000000001	56.185533999999997	52.669392000000002	52.664667999999999	0103000020E610000001000000050000003EB2B96A9E154C404F594DD713554A403EB2B96A9E154C401E1A16A3AE554A40E525FF93BF174C401E1A16A3AE554A40E525FF93BF174C404F594DD713554A403EB2B96A9E154C404F594DD713554A40
58611	Киндеркулево	7	61	\N	54.864849	54.895535000000002	55.077390999999999	55.063040000000001	0103000020E61000000100000005000000397D3D5FB36E4B40802BD9B111884B40397D3D5FB36E4B409B00C3F2E7894B4031B610E4A0724B409B00C3F2E7894B4031B610E4A0724B40802BD9B111884B40397D3D5FB36E4B40802BD9B111884B40
58282	Кашкаково	7	61	\N	55.449399999999997	55.473188	56.114581000000001	56.097703000000003	0103000020E6100000010000000500000044696FF085B94B404DDC2A88810C4C4044696FF085B94B401ADF1797AA0E4C40096EA46C91BC4B401ADF1797AA0E4C40096EA46C91BC4B404DDC2A88810C4C4044696FF085B94B404DDC2A88810C4C40
58682	Кармышево	7	61	\N	54.968200000000003	54.990710999999997	54.030850999999998	54.016669999999998	0103000020E610000001000000050000005DFE43FAED7B4B408369183E22024B405DFE43FAED7B4B404206F2ECF2034B40CB64389ECF7E4B404206F2ECF2034B40CB64389ECF7E4B408369183E22024B405DFE43FAED7B4B408369183E22024B40
58348	Кармасан	7	61	\N	55.484802999999999	55.507556999999998	54.913639000000003	54.901615999999997	0103000020E61000000100000005000000580053060EBE4B4071C6302768734B40580053060EBE4B40D2AC6C1FF2744B408DEDB5A0F7C04B40D2AC6C1FF2744B408DEDB5A0F7C04B4071C6302768734B40580053060EBE4B4071C6302768734B40
58356	Каран	7	61	\N	54.355387	54.379739999999998	55.133338999999999	55.120953999999998	0103000020E6100000010000000500000037363B527D2D4B400229B16B7B8F4B4037363B527D2D4B4003249A4011914B40D47D00529B304B4003249A4011914B40D47D00529B304B400229B16B7B8F4B4037363B527D2D4B400229B16B7B8F4B40
58292	Каралачук	7	61	\N	54.633631000000001	54.664586999999997	55.416018999999999	55.399872999999999	0103000020E61000000100000005000000AB5D13D21A514B40D6C6D8092FB34B40AB5D13D21A514B40DFC14F1C40B54B40622CD32F11554B40DFC14F1C40B54B40622CD32F11554B40D6C6D8092FB34B40AB5D13D21A514B40D6C6D8092FB34B40
6894	Камышлы	7	61	\N	55.915761000000003	55.974527999999999	54.533335999999998	54.503135	0103000020E61000000100000005000000E4F90CA837F54B408A3C49BA66404B40E4F90CA837F54B40C5E3A25A44444B40A5846055BDFC4B40C5E3A25A44444B40A5846055BDFC4B408A3C49BA66404B40E4F90CA837F54B408A3C49BA66404B40
58355	Калмакларово	7	61	\N	58.180197999999997	58.192414999999997	55.173960999999998	55.158518999999998	0103000020E61000000100000005000000FD6662BA10174D40B665C0594A944B40FD6662BA10174D40C5E3A25A44964B404221020EA1184D40C5E3A25A44964B404221020EA1184D40B665C0594A944B40FD6662BA10174D40B665C0594A944B40
58621	Казанчи	7	61	\N	53.460836	53.514726000000003	55.218913000000001	55.206344000000001	0103000020E61000000100000005000000E4688EACFCBA4A40E8DCED7A699A4B40E4688EACFCBA4A40AAD55757059C4B405133A48AE2C14A40AAD55757059C4B405133A48AE2C14A40E8DCED7A699A4B40E4688EACFCBA4A40E8DCED7A699A4B40
32179	Кабаково	7	61	\N	56.116022000000001	56.176299	54.552368000000001	54.516772000000003	0103000020E61000000100000005000000EACE13CFD90E4C4088BEBB9525424B40EACE13CFD90E4C40B0AD9FFEB3464B40A4A833F790164C40B0AD9FFEB3464B40A4A833F790164C4088BEBB9525424B40EACE13CFD90E4C4088BEBB9525424B40
58626	Иштиряково	7	61	\N	55.943320999999997	55.958098	55.882171999999997	55.869045999999997	0103000020E61000000100000005000000A45016BEBEF84B401C5C3AE63CEF4B40A45016BEBEF84B4034B91803EBF04B40772E8CF4A2FA4B4034B91803EBF04B40772E8CF4A2FA4B401C5C3AE63CEF4B40A45016BEBEF84B401C5C3AE63CEF4B40
58177	Ишмурзино	7	61	\N	58.153849999999998	58.177053999999998	52.456023000000002	52.438980000000001	0103000020E61000000100000005000000AB3E575BB1134D408ECC237F30384A40AB3E575BB1134D40A69C2FF65E3A4A4020D099B4A9164D40A69C2FF65E3A4A4020D099B4A9164D408ECC237F30384A40AB3E575BB1134D408ECC237F30384A40
57936	Ишимбай	7	61	\N	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
58477	Иткулово	7	61	\N	56.832284999999999	56.850323000000003	51.880192999999998	51.869422999999998	0103000020E61000000100000005000000C6F99B50886A4C40F2B1BB4049EF4940C6F99B50886A4C4085950A2AAAF04940B0045262D76C4C4085950A2AAAF04940B0045262D76C4C40F2B1BB4049EF4940C6F99B50886A4C40F2B1BB4049EF4940
58236	Исмайлово	7	61	\N	54.611325999999998	54.646639	55.572471999999998	55.547280000000001	0103000020E61000000100000005000000E5982CEE3F4E4B40A0E062450DC64B40E5982CEE3F4E4B4017F032C346C94B40B9A81611C5524B4017F032C346C94B40B9A81611C5524B40A0E062450DC64B40E5982CEE3F4E4B40A0E062450DC64B40
58715	Искужино	7	61	\N	58.426318000000002	58.435597999999999	53.190494000000001	53.186360999999998	0103000020E610000001000000050000001BD9959691364D40FB1F60ADDA974A401BD9959691364D40C80A7E1B62984A40FC19DEACC1374D40C80A7E1B62984A40FC19DEACC1374D40FB1F60ADDA974A401BD9959691364D40FB1F60ADDA974A40
58637	Искандарово	7	61	\N	55.389842000000002	55.405284000000002	54.182485	54.168461999999998	0103000020E61000000100000005000000BA4DB857E6B14B40334FAE2990154B40BA4DB857E6B14B405A8121AB5B174B40C9CB9A58E0B34B405A8121AB5B174B40C9CB9A58E0B34B40334FAE2990154B40BA4DB857E6B14B40334FAE2990154B40
58672	Ирныкши	7	61	\N	56.551606	56.586056999999997	54.437130000000003	54.419710000000002	0103000020E61000000100000005000000812381069B464C40EFE6A90EB9354B40812381069B464C40DD0C37E0F3374B40C24B70EA034B4C40DD0C37E0F3374B40C24B70EA034B4C40EFE6A90EB9354B40812381069B464C40EFE6A90EB9354B40
58206	Инзер	7	61	\N	57.536087999999999	57.584597000000002	54.229447999999998	54.203218999999997	0103000020E6100000010000000500000097E315889EC44C4081768714031A4B4097E315889EC44C40F910548D5E1D4B407C2B1213D4CA4C40F910548D5E1D4B407C2B1213D4CA4C4081768714031A4B4097E315889EC44C4081768714031A4B40
58644	Илякшиде	7	61	\N	54.573766999999997	54.606501999999999	55.301695000000002	55.290813	0103000020E610000001000000050000001343723271494B403620425C39A54B401343723271494B40F12E17F19DA64B40B37A87DBA14D4B40F12E17F19DA64B40B37A87DBA14D4B403620425C39A54B401343723271494B403620425C39A54B40
58602	Ильтуганово	7	61	\N	55.991928999999999	56.010883	54.341064000000003	54.327530000000003	0103000020E610000001000000050000001C7A8B87F7FE4B40BD3AC780EC294B401C7A8B87F7FE4B40E6EB32FCA72B4B408B8A389D64014C40E6EB32FCA72B4B408B8A389D64014C40BD3AC780EC294B401C7A8B87F7FE4B40BD3AC780EC294B40
58322	Ильтебаново	7	61	\N	59.253244000000002	59.285189000000003	54.343798	54.334639000000003	0103000020E6100000010000000500000041F4A44C6AA04D40AB7B6473D52A4B4041F4A44C6AA04D401137A792012C4B40E816BA1281A44D401137A792012C4B40E816BA1281A44D40AB7B6473D52A4B4041F4A44C6AA04D40AB7B6473D52A4B40
58447	Ильинка	7	61	\N	59.547919	59.558123999999999	54.486390999999998	54.480502000000001	0103000020E61000000100000005000000B3EDB43522C64D40D0D4EB16813D4B40B3EDB43522C64D40CC086F0F423E4B406D8E739B70C74D40CC086F0F423E4B406D8E739B70C74D40D0D4EB16813D4B40B3EDB43522C64D40D0D4EB16813D4B40
58700	Игубаево	7	61	\N	56.500869000000002	56.506205000000001	52.758969999999998	52.743608999999999	0103000020E61000000100000005000000454AB3791C404C40710168942E5F4A40454AB3791C404C409352D0ED25614A402D095053CB404C409352D0ED25614A402D095053CB404C40710168942E5F4A40454AB3791C404C40710168942E5F4A40
58643	Игметово	7	61	\N	54.523794000000002	54.554400000000001	55.405873999999997	55.389882	0103000020E61000000100000005000000A7EB89AE0B434B4048A643A7E7B14B40A7EB89AE0B434B40FA25E2ADF3B34B4082734694F6464B40FA25E2ADF3B34B4082734694F6464B4048A643A7E7B14B40A7EB89AE0B434B4048A643A7E7B14B40
58492	Ивано-Кувалат	7	61	\N	57.460673999999997	57.493445000000001	52.643313999999997	52.620843999999998	0103000020E610000001000000050000000A0F9A5DF7BA4C407BF5F1D0774F4A400A0F9A5DF7BA4C408B87F71C58524A40F7AFAC3429BF4C408B87F71C58524A40F7AFAC3429BF4C407BF5F1D0774F4A400A0F9A5DF7BA4C407BF5F1D0774F4A40
1370	Ибрагимово	7	61	\N	56.216822000000001	56.257893000000003	54.516103000000001	54.491892999999997	0103000020E61000000100000005000000D386C3D2C01B4C40CF108E59F63E4B40D386C3D2C01B4C400A2FC1A90F424B40056F48A302214C400A2FC1A90F424B40056F48A302214C40CF108E59F63E4B40D386C3D2C01B4C40CF108E59F63E4B40
1776	Зубово	7	61	\N	55.872245999999997	55.937581000000002	54.639659000000002	54.597312000000002	0103000020E610000001000000050000008D08C6C1A5EF4B4012C138B8744C4B408D08C6C1A5EF4B40C9CB9A58E0514B40ED2C7AA702F84B40C9CB9A58E0514B40ED2C7AA702F84B4012C138B8744C4B408D08C6C1A5EF4B4012C138B8744C4B40
58663	Зиримзи	7	61	\N	55.577725000000001	55.591647999999999	56.326233000000002	56.315185999999997	0103000020E61000000100000005000000728A8EE4F2C94B401A14CD0358284C40728A8EE4F2C94B4020F0C000C2294C40355F251FBBCB4B4020F0C000C2294C40355F251FBBCB4B401A14CD0358284C40728A8EE4F2C94B401A14CD0358284C40
58465	Еремеево	7	61	\N	55.326062	55.346147999999999	54.618378999999997	54.602220000000003	0103000020E61000000100000005000000F33B4D66BCA94B40A27F828B154D4B40F33B4D66BCA94B403FC4060B274F4B40B4C9E1934EAC4B403FC4060B274F4B40B4C9E1934EAC4B40A27F828B154D4B40F33B4D66BCA94B40A27F828B154D4B40
20835	Енгалышево	7	61	\N	55.742395000000002	55.802824000000001	54.522129	54.494351000000002	0103000020E6100000010000000500000062DBA2CC06DF4B4059DFC0E4463F4B4062DBA2CC06DF4B4087A5811FD5424B40D238D4EFC2E64B4087A5811FD5424B40D238D4EFC2E64B4059DFC0E4463F4B4062DBA2CC06DF4B4059DFC0E4463F4B40
58104	Дюртюли	7	61	\N	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
58434	Дуван-Мечетлино	7	61	\N	58.287483999999999	58.323695000000001	55.687249000000001	55.666207999999997	0103000020E61000000100000005000000C70F9546CC244D40B22AC24D46D54B40C70F9546CC244D40B79A75C6F7D74B407A7077D66E294D40B79A75C6F7D74B407A7077D66E294D40B22AC24D46D54B40C70F9546CC244D40B22AC24D46D54B40
58163	Дуван	7	61	\N	57.853713999999997	57.924393999999999	55.715971000000003	55.663791000000003	0103000020E610000001000000050000009411178046ED4C4088307E1AF7D44B409411178046ED4C4035F10EF0A4DB4B402F4FE78A52F64C4035F10EF0A4DB4B402F4FE78A52F64C4088307E1AF7D44B409411178046ED4C4088307E1AF7D44B40
5667	Дмитриевка	7	61	\N	55.770180000000003	55.826943999999997	54.828688	54.793796999999998	0103000020E6100000010000000500000043041C4295E24B40DA54DD239B654B4043041C4295E24B40384BC972126A4B40CCCF0D4DD9E94B40384BC972126A4B40CCCF0D4DD9E94B40DA54DD239B654B4043041C4295E24B40DA54DD239B654B40
58584	Даутово	7	61	\N	58.508082999999999	58.520992	53.366970999999999	53.361581000000001	0103000020E61000000100000005000000A8531EDD08414D4070ED444948AE4A40A8531EDD08414D404BCADDE7F8AE4A4023BDA8DDAF424D404BCADDE7F8AE4A4023BDA8DDAF424D4070ED444948AE4A40A8531EDD08414D4070ED444948AE4A40
58100	Давлеканово	7	61	\N	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
58675	Гусевка	7	61	\N	58.083089999999999	58.112006999999998	55.243105	55.236227	0103000020E61000000100000005000000F44F70B1A20A4D4052B7B3AF3C9E4B40F44F70B1A20A4D403E3F8C101E9F4B4027F6D03E560E4D403E3F8C101E9F4B4027F6D03E560E4D4052B7B3AF3C9E4B40F44F70B1A20A4D4052B7B3AF3C9E4B40
58374	Гудбурово	7	61	\N	54.791311999999998	54.809089999999998	56.21743	56.205590999999998	0103000020E6100000010000000500000057772CB649654B400CAD4ECE501A4C4057772CB649654B40AB9509BFD41B4C40A4C2D84290674B40AB9509BFD41B4C40A4C2D84290674B400CAD4ECE501A4C4057772CB649654B400CAD4ECE501A4C40
58258	Геофизик	7	61	\N	55.899807000000003	55.933134000000003	54.586748999999998	54.566068000000001	0103000020E610000001000000050000001FDB32E02CF34B40F4A78DEA74484B401FDB32E02CF34B40F8FA5A971A4B4B40916456EF70F74B40F8FA5A971A4B4B40916456EF70F74B40F4A78DEA74484B401FDB32E02CF34B40F4A78DEA74484B40
58269	Вотикеево	7	61	\N	56.212519	56.227189000000003	54.882058999999998	54.866776999999999	0103000020E61000000100000005000000AA6395D2331B4C4066F6798CF26E4B40AA6395D2331B4C403C122F4FE7704B4067817687141D4C403C122F4FE7704B4067817687141D4C4066F6798CF26E4B40AA6395D2331B4C4066F6798CF26E4B40
58729	Вострецово	7	61	\N	55.181019999999997	55.200350999999998	55.616031	55.605947999999998	0103000020E6100000010000000500000001F6D1A92B974B40CE893DB48FCD4B4001F6D1A92B974B403D29931ADACE4B40465C001AA5994B403D29931ADACE4B40465C001AA5994B40CE893DB48FCD4B4001F6D1A92B974B40CE893DB48FCD4B40
58344	Верхний Тыхтем	7	61	\N	54.614192000000003	54.630648999999998	55.986066999999998	55.973889	0103000020E6100000010000000500000080BBECD79D4E4B4092770E65A8FC4B4080BBECD79D4E4B401955867137FE4B40A7203F1BB9504B401955867137FE4B40A7203F1BB9504B4092770E65A8FC4B4080BBECD79D4E4B4092770E65A8FC4B40
58616	Верхний Нугуш	7	61	\N	56.952336000000003	56.964705000000002	53.215730999999998	53.210856	0103000020E61000000100000005000000D8666325E6794C402B155454FD9A4A40D8666325E6794C40DFDDCA129D9B4A40D3A414747B7B4C40DFDDCA129D9B4A40D3A414747B7B4C402B155454FD9A4A40D8666325E6794C402B155454FD9A4A40
58506	Верхний Бегеняш	7	61	\N	55.595565000000001	55.611358000000003	53.828234999999999	53.821257000000003	0103000020E6100000010000000500000035D252793BCC4B40384E0AF31EE94A4035D252793BCC4B408733BF9A03EA4A40F1129CFA40CE4B408733BF9A03EA4A40F1129CFA40CE4B40384E0AF31EE94A4035D252793BCC4B40384E0AF31EE94A40
58581	Верхние Абдряшево	7	61	\N	58.754015000000003	58.772682000000003	52.959225000000004	52.945568999999999	0103000020E61000000100000005000000C3D8429083604D40438EAD6708794A40C3D8429083604D40B84082E2C77A4A409C1A683EE7624D40B84082E2C77A4A409C1A683EE7624D40438EAD6708794A40C3D8429083604D40438EAD6708794A40
58705	Верхнесаитово	7	61	\N	54.984468	55.010455999999998	54.978064000000003	54.965662000000002	0103000020E61000000100000005000000B1FA230C037E4B40B77EFACF9A7B4B40B1FA230C037E4B408EB27E33317D4B400306499F56814B408EB27E33317D4B400306499F56814B40B77EFACF9A7B4B40B1FA230C037E4B40B77EFACF9A7B4B40
58332	Васелга	7	61	\N	58.715055	58.739857000000001	55.645963999999999	55.634613000000002	0103000020E61000000100000005000000AFEB17EC865B4D40E84EB0FF3AD14B40AFEB17EC865B4D405932C7F2AED24B40BC5B59A2B35E4D405932C7F2AED24B40BC5B59A2B35E4D40E84EB0FF3AD14B40AFEB17EC865B4D40E84EB0FF3AD14B40
13289	Вавилово	7	61	\N	55.828336999999998	55.871904999999998	54.826064000000002	54.796900000000001	0103000020E610000001000000050000008B8862F206EA4B405917B7D100664B408B8862F206EA4B4094331477BC694B40041C42959AEF4B4094331477BC694B40041C42959AEF4B405917B7D100664B408B8862F206EA4B405917B7D100664B40
58590	Бургынбаш	7	61	\N	55.412362999999999	55.427858999999998	56.283749	56.272069999999999	0103000020E610000001000000050000004C8A8F4FC8B44B40821C9430D3224C404C8A8F4FC8B44B40E8A221E351244C404E266E15C4B64B40E8A221E351244C404E266E15C4B64B40821C9430D3224C404C8A8F4FC8B44B40821C9430D3224C40
58439	Бургаджино	7	61	\N	57.901387999999997	57.923324999999998	55.962381999999998	55.949702000000002	0103000020E61000000100000005000000E08096AE60F34C401079CBD58FF94B40E08096AE60F34C40292158552FFB4B40234A7B832FF64C40292158552FFB4B40234A7B832FF64C401079CBD58FF94B40E08096AE60F34C401079CBD58FF94B40
58171	Бураево	7	61	\N	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
2245	Булгаково	7	61	\N	55.825057999999999	55.940894999999998	54.513756999999998	54.467134000000001	0103000020E61000000100000005000000CEA623809BE94B40C26C020CCB3B4B40CEA623809BE94B40A88B14CAC2414B4026FC523F6FF84B40A88B14CAC2414B4026FC523F6FF84B40C26C020CCB3B4B40CEA623809BE94B40C26C020CCB3B4B40
58603	Бузюрово	7	61	\N	53.553299000000003	53.584947	55.103589999999997	55.088506000000002	0103000020E610000001000000050000006BF46A80D2C64A40F9BF232A548B4B406BF46A80D2C64A40A818E76F428D4B405872158BDFCA4A40A818E76F428D4B405872158BDFCA4A40F9BF232A548B4B406BF46A80D2C64A40F9BF232A548B4B40
58392	Бужан	7	61	\N	56.784072000000002	56.795687000000001	51.786320000000003	51.776240999999999	0103000020E61000000100000005000000CBDAA6785C644C403C6876DD5BE34940CBDAA6785C644C406A183E22A6E449401A6D5512D9654C406A183E22A6E449401A6D5512D9654C403C6876DD5BE34940CBDAA6785C644C403C6876DD5BE34940
58463	Богородское	7	61	\N	55.922220000000003	55.949178000000003	55.254050999999997	55.233941999999999	0103000020E61000000100000005000000CBDB114E0BF64B409694BBCFF19D4B40CBDB114E0BF64B400F4240BE84A04B40960A2AAA7EF94B400F4240BE84A04B40960A2AAA7EF94B409694BBCFF19D4B40CBDB114E0BF64B409694BBCFF19D4B40
58327	Богачево	7	61	\N	58.271036000000002	58.285229000000001	52.401857999999997	52.382061999999998	0103000020E61000000100000005000000F304C24EB1224D40AD855968E7304A40F304C24EB1224D4067D13B1570334A40766F456282244D4067D13B1570334A40766F456282244D40AD855968E7304A40F304C24EB1224D40AD855968E7304A40
57935	Благовещенск	7	61	\N	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
58102	Бирск	7	61	\N	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
58743	Бикбау	7	61	\N	56.738059999999997	56.749164	52.211832000000001	52.201946999999997	0103000020E610000001000000050000002D3E05C0785E4C403D433866D9194A402D3E05C0785E4C40861F9C4F1D1B4A4097AB1F9BE45F4C40861F9C4F1D1B4A4097AB1F9BE45F4C403D433866D9194A402D3E05C0785E4C403D433866D9194A40
58132	Бижбуляк	7	61	\N	54.247320000000002	54.287852000000001	53.707574000000001	53.687261999999997	0103000020E61000000100000005000000C8D2872EA81F4B404BE48233F8D74A40C8D2872EA81F4B40FDBFEAC891DA4A404A0B9755D8244B40FDBFEAC891DA4A404A0B9755D8244B404BE48233F8D74A40C8D2872EA81F4B404BE48233F8D74A40
58688	Бигинеево	7	61	\N	56.022965999999997	56.032901000000003	56.219327	56.208710000000004	0103000020E61000000100000005000000C075C58CF0024C40912C6002B71A4C40C075C58CF0024C409D103AE8121C4C40BB80971936044C409D103AE8121C4C40BB80971936044C40912C6002B71A4C40C075C58CF0024C40912C6002B71A4C40
58306	Бигильдино	7	61	\N	56.169373	56.205449000000002	55.912264	55.895963999999999	0103000020E61000000100000005000000A7E9B303AE154C405932C7F2AEF24B40A7E9B303AE154C40B9A81611C5F44B407AFF1F274C1A4C40B9A81611C5F44B407AFF1F274C1A4C405932C7F2AEF24B40A7E9B303AE154C405932C7F2AEF24B40
58093	Белорецк	7	61	\N	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
57937	Белебей	7	61	\N	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
58320	Баш-Ильчикеево	7	61	\N	58.466436999999999	58.492102000000003	55.080224999999999	55.062260999999999	0103000020E610000001000000050000007A522635B43B4D407B681F2BF8874B407A522635B43B4D402AA913D0448A4B40EA25C632FD3E4D402AA913D0448A4B40EA25C632FD3E4D407B681F2BF8874B407A522635B43B4D407B681F2BF8874B40
58437	Басурмановка	7	61	\N	56.263309999999997	56.274915999999997	52.997104	52.977696999999999	0103000020E61000000100000005000000D95A5F24B4214C40DB32E02C257D4A40D95A5F24B4214C40FB5A971AA17F4A40D5928E7230234C40FB5A971AA17F4A40D5928E7230234C40DB32E02C257D4A40D95A5F24B4214C40DB32E02C257D4A40
58691	Балтаево	7	61	\N	54.072372999999999	54.103993000000003	54.456380000000003	54.433867999999997	0103000020E61000000100000005000000840EBA8443094B40F56393FC88374B40840EBA8443094B403546EBA86A3A4B40A80183A44F0D4B403546EBA86A3A4B40A80183A44F0D4B40F56393FC88374B40840EBA8443094B40F56393FC88374B40
58658	Байталлы	7	61	\N	55.114624999999997	55.144610999999998	55.055914000000001	55.045490999999998	0103000020E61000000100000005000000E9263108AC8E4B4094A12AA6D2854B40E9263108AC8E4B40BCB1A03028874B4028D2FD9C82924B40BCB1A03028874B4028D2FD9C82924B4094A12AA6D2854B40E9263108AC8E4B4094A12AA6D2854B40
58090	Баймак	7	61	\N	58.282525	58.343341000000002	52.612741	52.564118999999998	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
58299	Ахуново	7	61	\N	58.042853999999998	58.081643999999997	55.328960000000002	55.317357999999999	0103000020E610000001000000050000005B40683D7C054D40DE8FDB2F9FA84B405B40683D7C054D4099D87C5C1BAA4B4012F5824F730A4D4099D87C5C1BAA4B4012F5824F730A4D40DE8FDB2F9FA84B405B40683D7C054D40DE8FDB2F9FA84B40
58423	Ахта	7	61	\N	55.255167	55.272359999999999	55.039543000000002	55.030720000000002	0103000020E610000001000000050000005C02F04FA9A04B40A4AA09A2EE834B405C02F04FA9A04B4093E4B9BE0F854B40895E46B1DCA24B4093E4B9BE0F854B40895E46B1DCA24B40A4AA09A2EE834B405C02F04FA9A04B40A4AA09A2EE834B40
58665	Асавды	7	61	\N	55.880583000000001	55.896042999999999	56.194654	56.181870000000004	0103000020E61000000100000005000000F03499F1B6F04B40D00F238447174C40F03499F1B6F04B408E041A6CEA184C40A5677A89B1F24B408E041A6CEA184C40A5677A89B1F24B40D00F238447174C40F03499F1B6F04B40D00F238447174C40
58388	Артакуль	7	61	\N	56.438381999999997	56.478160000000003	55.860570000000003	55.843145999999997	0103000020E61000000100000005000000D993C0E61C384C4069E04735ECEB4B40D993C0E61C384C4099F5622827EE4B40B020CD58343D4C4099F5622827EE4B40B020CD58343D4C4069E04735ECEB4B40D993C0E61C384C4069E04735ECEB4B40
58417	Ардатово	7	61	\N	56.52984	56.561855999999999	52.371308999999997	52.360173000000003	0103000020E610000001000000050000006B0E10CCD1434C407CF31B261A2E4A406B0E10CCD1434C40F0DAA50D872F4A40DB87BCE5EA474C40F0DAA50D872F4A40DB87BCE5EA474C407CF31B261A2E4A406B0E10CCD1434C407CF31B261A2E4A40
58537	Анзяк	7	61	\N	58.268816999999999	58.312331	55.456601999999997	55.424643000000003	0103000020E61000000100000005000000EECD6F9868224D40D8BCAAB35AB64B40EECD6F9868224D40E3A430EF71BA4B4074435376FA274D40E3A430EF71BA4B4074435376FA274D40D8BCAAB35AB64B40EECD6F9868224D40D8BCAAB35AB64B40
58445	Аминево	7	61	\N	55.279152000000003	55.321111999999999	54.717193999999999	54.697963000000001	0103000020E61000000100000005000000774EB340BBA34B40B66801DA56594B40774EB340BBA34B4097715303CD5B4B40342DB1321AA94B4097715303CD5B4B40342DB1321AA94B40B66801DA56594B40774EB340BBA34B40B66801DA56594B40
58679	Амангильдино	7	61	\N	58.8735	58.888599999999997	54.063034999999999	54.057254	0103000020E610000001000000050000002B8716D9CE6F4D4058C85C1954074B402B8716D9CE6F4D406EC0E78711084B40E09C11A5BD714D406EC0E78711084B40E09C11A5BD714D4058C85C1954074B402B8716D9CE6F4D4058C85C1954074B40
6002	Алексеевка	7	61	\N	55.967153000000003	56.022821999999998	54.854885000000003	54.810195	0103000020E61000000100000005000000399D64ABCBFB4B40FD304278B4674B40399D64ABCBFB4B40A56B26DF6C6D4B408DD0CFD4EB024C40A56B26DF6C6D4B408DD0CFD4EB024C40FD304278B4674B40399D64ABCBFB4B40FD304278B4674B40
58301	Алайгирово	7	61	\N	56.178292999999996	56.203930999999997	54.228875000000002	54.215829999999997	0103000020E61000000100000005000000880D164ED2164C4072BF4351A01B4B40880D164ED2164C409EEFA7C64B1D4B40FED137691A1A4C409EEFA7C64B1D4B40FED137691A1A4C4072BF4351A01B4B40880D164ED2164C4072BF4351A01B4B40
19288	Акбердино	7	61	\N	56.161287999999999	56.201946	54.606309000000003	54.579768000000001	0103000020E610000001000000050000005E9ECE15A5144C4038A27BD6354A4B405E9ECE15A5144C409F2287889B4D4B406DC7D45DD9194C409F2287889B4D4B406DC7D45DD9194C4038A27BD6354A4B405E9ECE15A5144C4038A27BD6354A4B40
58645	Айтуган	7	61	\N	55.962077999999998	55.981050000000003	53.036672000000003	53.026539	0103000020E61000000100000005000000BD19355F25FB4B40C68844A165834A40BD19355F25FB4B40E75608ABB1844A40D3DEE00B93FD4B40E75608ABB1844A40D3DEE00B93FD4B40C68844A165834A40BD19355F25FB4B40C68844A165834A40
58577	Агурда	7	61	\N	57.111876000000002	57.130516	51.911887999999998	51.899318999999998	0103000020E61000000100000005000000899AE8F3518E4C40F1D58EE21CF34940899AE8F3518E4C40B3CEF8BEB8F4494068CD8FBFB4904C40B3CEF8BEB8F4494068CD8FBFB4904C40F1D58EE21CF34940899AE8F3518E4C40F1D58EE21CF34940
57934	Агидель	7	61	\N	53.926253000000003	53.950319	55.904614000000002	55.869757999999997	0103000020E61000000100000005000000346953758FF64A4099B7EA3A54EF4B40346953758FF64A407BC03C64CAF34B403BE2900DA4F94A407BC03C64CAF34B403BE2900DA4F94A4099B7EA3A54EF4B40346953758FF64A4099B7EA3A54EF4B40
58233	Абзаково	7	61	\N	59.545628000000001	59.562939	54.586916000000002	54.579996999999999	0103000020E6100000010000000500000015E46723D7C54D40996379573D4A4B4015E46723D7C54D40E4BF4010204B4B404C5299620EC84D40E4BF4010204B4B404C5299620EC84D40996379573D4A4B4015E46723D7C54D40996379573D4A4B40
58661	Абдулово	7	61	\N	53.434254000000003	53.450828000000001	54.249985000000002	54.224122000000001	0103000020E610000001000000050000001F1494A295B74A4035289A07B01C4B401F1494A295B74A40CBBE2B82FF1F4B40800F5EBBB4B94A40CBBE2B82FF1F4B40800F5EBBB4B94A4035289A07B01C4B401F1494A295B74A4035289A07B01C4B40
58748	Абдрашитово	7	61	\N	58.297742	58.313867000000002	55.609715999999999	55.597078000000003	0103000020E61000000100000005000000A452EC681C264D409F94490D6DCC4B40A452EC681C264D4089EC832C0BCE4B4096253ACB2C284D4089EC832C0BCE4B4096253ACB2C284D409F94490D6DCC4B40A452EC681C264D409F94490D6DCC4B40
24735	Янаул	7	61	1613	54.878439999999998	54.960959000000003	56.294801	56.242694	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
27135	Ямады	7	61	1613	55.313592999999997	55.344154000000003	56.146070999999999	56.135494000000001	0103000020E6100000010000000500000094A0BFD023A84B40F1660DDE57114C4094A0BFD023A84B406FF25B74B2124C40D064FF3C0DAC4B406FF25B74B2124C40D064FF3C0DAC4B40F1660DDE57114C4094A0BFD023A84B40F1660DDE57114C40
25262	Юссуково	7	61	1613	55.141278	55.156154000000001	56.201709999999999	56.188617999999998	0103000020E6100000010000000500000078D2C26515924B40EDB776A224184C4078D2C26515924B4059A31EA2D1194C40DE91B1DAFC934B4059A31EA2D1194C40DE91B1DAFC934B40EDB776A224184C4078D2C26515924B40EDB776A224184C40
27215	Югамаш	7	61	1613	55.371741	55.396839999999997	56.179730999999997	56.166986999999999	0103000020E610000001000000050000008ACA863595AF4B40B7ED7BD45F154C408ACA863595AF4B40E789E76C01174C4050DF32A7CBB24B40E789E76C01174C4050DF32A7CBB24B40B7ED7BD45F154C408ACA863595AF4B40B7ED7BD45F154C40
58157	Энергетик	7	61	1613	54.327314999999999	55.508347999999998	56.533661000000002	55.988700999999999	0103000020E61000000100000005000000C03E3A75E5294B40E1421EC18DFE4B40C03E3A75E5294B404913EF004F444C40567E198C11C14B404913EF004F444C40567E198C11C14B40E1421EC18DFE4B40C03E3A75E5294B40E1421EC18DFE4B40
27099	Шудек	7	61	1613	54.877352999999999	54.886094	56.253382000000002	56.243729999999999	0103000020E610000001000000050000001406651A4D704B40EC866D8B321F4C401406651A4D704B4092B245D26E204C40469737876B714B4092B245D26E204C40469737876B714B40EC866D8B321F4C401406651A4D704B40EC866D8B321F4C40
58523	Урал	7	61	1613	55.423484000000002	55.437327000000003	56.217300000000002	56.209069999999997	0103000020E610000001000000050000008C3045B934B64B40904946CEC21A4C408C3045B934B64B40DDB5847CD01B4C403354C554FAB74B40DDB5847CD01B4C403354C554FAB74B40904946CEC21A4C408C3045B934B64B40904946CEC21A4C40
26528	Татарская Урада	7	61	1613	54.903619999999997	54.925170000000001	56.324351	56.312764000000001	0103000020E610000001000000050000007901F6D1A9734B40DEAE97A608284C407901F6D1A9734B4063B6645584294C40C39E76F86B764B4063B6645584294C40C39E76F86B764B40DEAE97A608284C407901F6D1A9734B40DEAE97A608284C40
26674	Сусады-Эбалак	7	61	1613	54.900601000000002	54.919258999999997	56.189855000000001	56.183202999999999	0103000020E6100000010000000500000059DFC0E446734B40B9C3263273174C4059DFC0E446734B40B5FD2B2B4D184C40DEC66647AA754B40B5FD2B2B4D184C40DEC66647AA754B40B9C3263273174C4059DFC0E446734B40B9C3263273174C40
58840	Старый Сусадыбаш	7	61	1613	54.327314999999999	55.508347999999998	56.533661000000002	55.988700999999999	0103000020E61000000100000005000000C03E3A75E5294B40E1421EC18DFE4B40C03E3A75E5294B404913EF004F444C40567E198C11C14B404913EF004F444C40567E198C11C14B40E1421EC18DFE4B40C03E3A75E5294B40E1421EC18DFE4B40
58569	Старый Куюк	7	61	1613	54.327314999999999	55.508347999999998	56.533661000000002	55.988700999999999	0103000020E61000000100000005000000C03E3A75E5294B40E1421EC18DFE4B40C03E3A75E5294B404913EF004F444C40567E198C11C14B404913EF004F444C40567E198C11C14B40E1421EC18DFE4B40C03E3A75E5294B40E1421EC18DFE4B40
26942	Старый Варяш	7	61	1613	55.271794	55.297494999999998	56.089086000000002	56.082416000000002	0103000020E61000000100000005000000E09F5225CAA24B406555849B8C0A4C40E09F5225CAA24B400744882B670B4C409CDCEF5014A64B400744882B670B4C409CDCEF5014A64B406555849B8C0A4C40E09F5225CAA24B406555849B8C0A4C40
58781	Староый Артаул	7	61	1613	54.806404000000001	54.823884999999997	56.254992000000001	56.243915000000001	0103000020E610000001000000050000008AAE0B3F38674B407E00529B381F4C408AAE0B3F38674B40EE5EEE93A3204C401D554D1075694B40EE5EEE93A3204C401D554D1075694B407E00529B381F4C408AAE0B3F38674B407E00529B381F4C40
27012	Старокудашево	7	61	1613	54.684933999999998	54.713869000000003	56.135589000000003	56.122127999999996	0103000020E6100000010000000500000090F5D4EAAB574B4083F6EAE3A10F4C4090F5D4EAAB574B404359F8FA5A114C406A50340F605B4B404359F8FA5A114C406A50340F605B4B4083F6EAE3A10F4C4090F5D4EAAB574B4083F6EAE3A10F4C40
58786	Староая Орья	7	61	1613	54.73462	54.747843000000003	56.161368000000003	56.154375000000002	0103000020E61000000100000005000000677E3507085E4B40F6285C8FC2134C40677E3507085E4B407B4FE5B4A7144C4072C5C551B95F4B407B4FE5B4A7144C4072C5C551B95F4B40F6285C8FC2134C40677E3507085E4B40F6285C8FC2134C40
33033	Сандугач	7	61	1613	55.182977999999999	55.204906000000001	56.264032	56.249276000000002	0103000020E6100000010000000500000099F1B6D26B974B40BFD6A546E81F4C4099F1B6D26B974B407A8CF2CCCB214C4089601C5C3A9A4B407A8CF2CCCB214C4089601C5C3A9A4B40BFD6A546E81F4C4099F1B6D26B974B40BFD6A546E81F4C40
20092	Салихово	7	61	1613	55.410646999999997	55.434793999999997	56.195751000000001	56.183352999999997	0103000020E61000000100000005000000AA99B51490B44B40CE4F711C78174C40AA99B51490B44B406494675E0E194C409E3F6D54A7B74B406494675E0E194C409E3F6D54A7B74B40CE4F711C78174C40AA99B51490B44B40CE4F711C78174C40
26930	Рабак	7	61	1613	55.22448	55.244593000000002	56.328902999999997	56.307901000000001	0103000020E61000000100000005000000944DB9C2BB9C4B40EEB3CA4C69274C40944DB9C2BB9C4B403447567E192A4C404FEACBD24E9F4B403447567E192A4C404FEACBD24E9F4B40EEB3CA4C69274C40944DB9C2BB9C4B40EEB3CA4C69274C40
26161	Прогресс	7	61	1613	54.714506	54.728268999999997	56.251027000000001	56.238267	0103000020E61000000100000005000000DC65BFEE745B4B40A75B76887F1E4C40DC65BFEE745B4B40DDB419A721204C4066D828EB375D4B40DDB419A721204C4066D828EB375D4B40A75B76887F1E4C40DC65BFEE745B4B40A75B76887F1E4C40
26390	Ошья-Тау	7	61	1613	54.729903999999998	54.742201999999999	56.291409000000002	56.285293000000003	0103000020E610000001000000050000001B9C887E6D5D4B408D63247B84244C401B9C887E6D5D4B404A61DEE34C254C404D83A279005F4B404A61DEE34C254C404D83A279005F4B408D63247B84244C401B9C887E6D5D4B408D63247B84244C40
26445	Новый Артаул	7	61	1613	54.807653000000002	54.828709000000003	56.328943000000002	56.306493000000003	0103000020E6100000010000000500000016C26A2C61674B40FAB9A1293B274C4016C26A2C61674B40C39FE1CD1A2A4C405073F222136A4B40C39FE1CD1A2A4C405073F222136A4B40FAB9A1293B274C4016C26A2C61674B40FAB9A1293B274C40
26270	Месягутово	7	61	1613	55.341827000000002	55.355293000000003	56.091939000000004	56.083240000000004	0103000020E61000000100000005000000E5F1B4FCC0AB4B400ADCBA9BA70A4C40E5F1B4FCC0AB4B400D1D3BA8C40B4C40B6BFB33D7AAD4B400D1D3BA8C40B4C40B6BFB33D7AAD4B400ADCBA9BA70A4C40E5F1B4FCC0AB4B400ADCBA9BA70A4C40
26189	Максимово	7	61	1613	55.303432999999998	55.328935999999999	56.245919999999998	56.232979	0103000020E610000001000000050000007AC37DE4D6A64B40D0D38041D21D4C407AC37DE4D6A64B4056B77A4E7A1F4C40103D29931AAA4B4056B77A4E7A1F4C40103D29931AAA4B40D0D38041D21D4C407AC37DE4D6A64B40D0D38041D21D4C40
26095	Кумово	7	61	1613	54.384051999999997	54.407238	56.216358999999997	56.202857000000002	0103000020E6100000010000000500000050FBAD9D28314B40E161DA37F7194C4050FBAD9D28314B40FE98D6A6B11B4C401FD8F15F20344B40FE98D6A6B11B4C401FD8F15F20344B40E161DA37F7194C4050FBAD9D28314B40E161DA37F7194C40
27030	Кумалак	7	61	1613	54.667147	54.679974999999999	56.179996000000003	56.163648999999999	0103000020E61000000100000005000000F04FA91265554B40F5824F73F2144C40F04FA91265554B4096B4E21B0A174C407E8CB96B09574B4096B4E21B0A174C407E8CB96B09574B40F5824F73F2144C40F04FA91265554B40F5824F73F2144C40
26115	Кисак-Каин	7	61	1613	54.633477999999997	54.652540999999999	56.235686000000001	56.220247999999998	0103000020E61000000100000005000000245E9ECE15514B4034812216311C4C40245E9ECE15514B40021077F52A1E4C404A26A77686534B40021077F52A1E4C404A26A77686534B4034812216311C4C40245E9ECE15514B4034812216311C4C40
26034	Карманово	7	61	1613	54.521953000000003	54.547122999999999	56.240613000000003	56.221694999999997	0103000020E6100000010000000500000049861C5BCF424B40E6577380601C4C4049861C5BCF424B4009FF2268CC1E4C40D8F15F2008464B4009FF2268CC1E4C40D8F15F2008464B40E6577380601C4C4049861C5BCF424B40E6577380601C4C40
26005	Каймашабаш	7	61	1613	55.063861000000003	55.076608	56.193171	56.174729999999997	0103000020E61000000100000005000000B43EE5982C884B40A6D0798D5D164C40B43EE5982C884B408FC4CBD3B9184C40554E7B4ACE894B408FC4CBD3B9184C40554E7B4ACE894B40A6D0798D5D164C40B43EE5982C884B40A6D0798D5D164C40
25944	Иткинеево	7	61	1613	54.957751999999999	54.978682999999997	56.229376000000002	56.212079000000003	0103000020E61000000100000005000000DCD6169E977A4B408E959867251B4C40DCD6169E977A4B40603E59315C1D4C4059130B7C457D4B40603E59315C1D4C4059130B7C457D4B408E959867251B4C40DCD6169E977A4B408E959867251B4C40
25816	Истяк	7	61	1613	55.014040999999999	55.029833000000004	56.285882999999998	56.273715000000003	0103000020E61000000100000005000000CDE67118CC814B405BB6D61709234C40CDE67118CC814B40BEBD6BD097244C40B9AB5791D1834B40BEBD6BD097244C40B9AB5791D1834B405BB6D61709234C40CDE67118CC814B405BB6D61709234C40
25657	Ижболдино	7	61	1613	55.064247999999999	55.089894000000001	56.045619000000002	56.032840999999998	0103000020E61000000100000005000000AD6A494739884B40E57B462234044C40AD6A494739884B40C289E8D7D6054C40A60D87A5818B4B40C289E8D7D6054C40A60D87A5818B4B40E57B462234044C40AD6A494739884B40E57B462234044C40
48714	Зайцево	7	61	1613	54.935186999999999	54.958022	56.105139000000001	56.087916	0103000020E610000001000000050000007A522635B4774B40C765DCD4400B4C407A522635B4774B405F44DB31750D4C409C6C0377A07A4B405F44DB31750D4C409C6C0377A07A4B40C765DCD4400B4C407A522635B4774B40C765DCD4400B4C40
25559	Вояды	7	61	1613	54.646594	54.661479	56.379874999999998	56.363532999999997	0103000020E6100000010000000500000019E59997C3524B402502D53F882E4C4019E59997C3524B40B4C876BE9F304C40D2FE0758AB544B40B4C876BE9F304C40D2FE0758AB544B402502D53F882E4C4019E59997C3524B402502D53F882E4C40
26254	Верхняя Барабановка	7	61	1613	55.314481999999998	55.327041000000001	56.299421000000002	56.288311	0103000020E61000000100000005000000209738F240A84B40DD09F65FE7244C40209738F240A84B40295E656D53264C40BFB9BF7ADCA94B40295E656D53264C40BFB9BF7ADCA94B40DD09F65FE7244C40209738F240A84B40DD09F65FE7244C40
26467	Варяш	7	61	1613	54.832410000000003	54.848095000000001	56.355100999999998	56.345348999999999	0103000020E61000000100000005000000836E2F698C6A4B40685A6265342C4C40836E2F698C6A4B4071E316F3732D4C40587380608E6C4B4071E316F3732D4C40587380608E6C4B40685A6265342C4C40836E2F698C6A4B40685A6265342C4C40
26854	Барабановка	7	61	1613	55.221308999999998	55.235447999999998	56.278972000000003	56.265506999999999	0103000020E61000000100000005000000BDA772DA539C4B40F6ED2422FC214C40BDA772DA539C4B40F73FC05AB5234C404DF4F928239E4B40F73FC05AB5234C404DF4F928239E4B40F6ED2422FC214C40BDA772DA539C4B40F6ED2422FC214C40
25850	Ахтиял	7	61	1613	55.022081	55.047961000000001	56.257362999999998	56.243043999999998	0103000020E61000000100000005000000766EDA8CD3824B4098BED7101C1F4C40766EDA8CD3824B40A8195245F1204C40E23D079623864B40A8195245F1204C40E23D079623864B4098BED7101C1F4C40766EDA8CD3824B4098BED7101C1F4C40
25771	Атлегач	7	61	1613	55.03172	55.057806999999997	56.071503999999997	56.060253000000003	0103000020E610000001000000050000008750A5660F844B40323ECC5EB6074C408750A5660F844B403FC4060B27094C406C3D433866874B403FC4060B27094C406C3D433866874B40323ECC5EB6074C408750A5660F844B40323ECC5EB6074C40
25172	Асавдыбаш	7	61	1613	55.170132000000002	55.197153	56.184564999999999	56.172891	0103000020E610000001000000050000006500A8E2C6954B40E962D34A21164C406500A8E2C6954B403D7E6FD39F174C4076A73B4F3C994B403D7E6FD39F174C4076A73B4F3C994B40E962D34A21164C406500A8E2C6954B40E962D34A21164C40
25631	Акылбай	7	61	1613	54.649343000000002	54.661991	56.340190999999997	56.322594000000002	0103000020E610000001000000050000007A71E2AB1D534B4063F19BC24A294C407A71E2AB1D534B405FB2F1608B2B4C40889FFF1EBC544B405FB2F1608B2B4C40889FFF1EBC544B4063F19BC24A294C407A71E2AB1D534B4063F19BC24A294C40
25433	Айбуляк	7	61	1613	54.715916999999997	54.735877000000002	56.21313	56.201990000000002	0103000020E6100000010000000500000041D3122BA35B4B403D0FEECEDA194C4041D3122BA35B4B40F3E505D8471B4C407670B037315E4B40F3E505D8471B4C407670B037315E4B403D0FEECEDA194C4041D3122BA35B4B403D0FEECEDA194C40
22806	Янгаулово	7	61	1348	54.211691999999999	54.243726000000002	54.903447999999997	54.891530000000003	0103000020E61000000100000005000000946934B9181B4B4092B3B0A71D724B40946934B9181B4B407CD11E2FA4734B40AB97DF69321F4B407CD11E2FA4734B40AB97DF69321F4B4092B3B0A71D724B40946934B9181B4B4092B3B0A71D724B40
24408	Юмадыбаш	7	61	1348	53.957272000000003	53.995745999999997	54.752786	54.718000000000004	0103000020E6100000010000000500000032B08EE387FA4A4096438B6CE75B4B4032B08EE387FA4A407E71A94A5B604B40B88FDC9A74FF4A407E71A94A5B604B40B88FDC9A74FF4A4096438B6CE75B4B4032B08EE387FA4A4096438B6CE75B4B40
23424	Шаранбаш-Князево	7	61	1348	54.111637999999999	54.157138000000003	54.973398000000003	54.957712000000001	0103000020E61000000100000005000000D47E6B274A0E4B404E7E8B4E967A4B40D47E6B274A0E4B40F4FE3F4E987C4B40BC7A15191D144B40F4FE3F4E987C4B40BC7A15191D144B404E7E8B4E967A4B40D47E6B274A0E4B404E7E8B4E967A4B40
24450	Шаран	7	61	1348	53.968761000000001	54.017251999999999	54.833038999999999	54.805084000000001	0103000020E61000000100000005000000F451465C00FC4A40354415FE0C674B40F451465C00FC4A4072A59E05A16A4B4032E5435035024B4072A59E05A16A4B4032E5435035024B40354415FE0C674B40F451465C00FC4A40354415FE0C674B40
48682	Чупаево	7	61	1348	54.072876000000001	54.088911000000003	54.810481000000003	54.797918000000003	0103000020E61000000100000005000000E754320054094B40E371512D22664B40E754320054094B40C38366D7BD674B4099A0866F610B4B40C38366D7BD674B4099A0866F610B4B40E371512D22664B40E754320054094B40E371512D22664B40
23746	Чекан-Тамак	7	61	1348	53.629781999999999	53.650533000000003	54.851905000000002	54.843294999999998	0103000020E6100000010000000500000003CE52B29CD04A40AEF02E17F16B4B4003CE52B29CD04A40422619390B6D4B4001FC53AA44D34A40422619390B6D4B4001FC53AA44D34A40AEF02E17F16B4B4003CE52B29CD04A40AEF02E17F16B4B40
24334	Чалмалы	7	61	1348	53.891677000000001	53.919092999999997	54.776586000000002	54.754854000000002	0103000020E6100000010000000500000036CCD07822F24A409DA04D0E9F604B4036CCD07822F24A400744882B67634B40C37DE4D6A4F54A400744882B67634B40C37DE4D6A4F54A409DA04D0E9F604B4036CCD07822F24A409DA04D0E9F604B40
47151	Урсаево	7	61	1348	54.112788000000002	54.131732999999997	54.849069	54.842055000000002	0103000020E61000000100000005000000CDB051D66F0E4B4076374F75C86B4B40CDB051D66F0E4B401286014BAE6C4B40E8667FA0DC104B401286014BAE6C4B40E8667FA0DC104B4076374F75C86B4B40CDB051D66F0E4B4076374F75C86B4B40
23590	Три Ключа	7	61	1348	54.297266	54.309438	54.981515000000002	54.976461999999998	0103000020E610000001000000050000003B1BF2CF0C264B40B4E4F1B4FC7C4B403B1BF2CF0C264B4048C49448A27D4B40E01115AA9B274B4048C49448A27D4B40E01115AA9B274B40B4E4F1B4FC7C4B403B1BF2CF0C264B40B4E4F1B4FC7C4B40
47872	Тархан	7	61	1348	54.031320000000001	54.055799	54.767398999999997	54.757570999999999	0103000020E61000000100000005000000F9DA334B02044B40F2B22616F8604B40F9DA334B02044B40D6FD63213A624B402313F06B24074B40D6FD63213A624B402313F06B24074B40F2B22616F8604B40F9DA334B02044B40F2B22616F8604B40
23676	Старочикеево	7	61	1348	54.268906000000001	54.286855000000003	55.030853999999998	55.019516000000003	0103000020E610000001000000050000005ED905836B224B40D7DF12807F824B405ED905836B224B40B3791C06F3834B40D8D825AAB7244B40B3791C06F3834B40D8D825AAB7244B40D7DF12807F824B405ED905836B224B40D7DF12807F824B40
24234	Старотумбагушево	7	61	1348	54.020997999999999	54.046788999999997	54.882472999999997	54.870491999999999	0103000020E6100000010000000500000005A4FD0FB0024B40FEB627486C6F4B4005A4FD0FB0024B402F4D11E0F4704B400168942EFD054B402F4D11E0F4704B400168942EFD054B40FEB627486C6F4B4005A4FD0FB0024B40FEB627486C6F4B40
47489	Соколовка	7	61	1348	54.203437000000001	54.213093999999998	55.001787999999998	54.994517000000002	0103000020E61000000100000005000000EFE53E390A1A4B40742843554C7F4B40EFE53E390A1A4B403BC3D4963A804B40A67C08AA461B4B403BC3D4963A804B40A67C08AA461B4B40742843554C7F4B40EFE53E390A1A4B40742843554C7F4B40
24213	Сакты	7	61	1348	54.024042999999999	54.041632	54.999778999999997	54.990637999999997	0103000020E610000001000000050000004F594DD713034B406116DA39CD7E4B404F594DD713034B40211D1EC2F87F4B40C93B873254054B40211D1EC2F87F4B40C93B873254054B406116DA39CD7E4B404F594DD713034B406116DA39CD7E4B40
46401	Покровка	7	61	1348	54.333432000000002	54.344642999999998	54.923547999999997	54.916367000000001	0103000020E610000001000000050000004EB857E6AD2A4B401B118C834B754B404EB857E6AD2A4B40A22424D236764B40CDE506431D2C4B40A22424D236764B40CDE506431D2C4B401B118C834B754B404EB857E6AD2A4B401B118C834B754B40
58827	Писарево	7	61	1348	53.931821999999997	53.958950999999999	54.97701	54.965378000000001	0103000020E61000000100000005000000BED87BF145F74A4092239D81917B4B40BED87BF145F74A40B7EEE6A90E7D4B40B6BB07E8BEFA4A40B7EEE6A90E7D4B40B6BB07E8BEFA4A4092239D81917B4B40BED87BF145F74A4092239D81917B4B40
23953	Нуреево	7	61	1348	54.192647999999998	54.227978999999998	54.796526999999998	54.777464000000002	0103000020E61000000100000005000000E5D18DB0A8184B409FE8BAF083634B40E5D18DB0A8184B40C4B0C398F4654B405F96766A2E1D4B40C4B0C398F4654B405F96766A2E1D4B409FE8BAF083634B40E5D18DB0A8184B409FE8BAF083634B40
23464	Новоюмашево	7	61	1348	54.178984999999997	54.209069	54.957768999999999	54.951073999999998	0103000020E61000000100000005000000BEBC00FBE8164B40B709F7CABC794B40BEBC00FBE8164B40B20FB22C987A4B40C0CDE2C5C21A4B40B20FB22C987A4B40C0CDE2C5C21A4B40B709F7CABC794B40BEBC00FBE8164B40B709F7CABC794B40
23900	Новоюзеево	7	61	1348	53.737938999999997	53.751944000000002	54.975476	54.959842000000002	0103000020E61000000100000005000000B2B8FFC874DE4A40E3A9471ADC7A4B40B2B8FFC874DE4A403604C765DC7C4B40333674B33FE04A403604C765DC7C4B40333674B33FE04A40E3A9471ADC7A4B40B2B8FFC874DE4A40E3A9471ADC7A4B40
22755	Новотавларово	7	61	1348	54.171303999999999	54.193043000000003	54.891095	54.878867999999997	0103000020E6100000010000000500000045D61A4AED154B401EC022BF7E704B4045D61A4AED154B408750A5660F724B4062DC0DA2B5184B408750A5660F724B4062DC0DA2B5184B401EC022BF7E704B4045D61A4AED154B401EC022BF7E704B40
24460	Новоалександровка	7	61	1348	54.063426	54.074044000000001	54.977469999999997	54.972261000000003	0103000020E61000000100000005000000A9DBD9571E084B409016670C737C4B40A9DBD9571E084B401A69A9BC1D7D4B40863B17467A094B401A69A9BC1D7D4B40863B17467A094B409016670C737C4B40A9DBD9571E084B409016670C737C4B40
23832	Нижние Ташлы	7	61	1348	53.734524999999998	53.769666999999998	54.939081999999999	54.918514000000002	0103000020E61000000100000005000000158C4AEA04DE4A408675E3DD91754B40158C4AEA04DE4A409221C7D633784B40BCE7C07284E24A409221C7D633784B40BCE7C07284E24A408675E3DD91754B40158C4AEA04DE4A408675E3DD91754B40
23729	Нижнезаитово	7	61	1348	53.644694000000001	53.687283000000001	54.847203	54.824202	0103000020E61000000100000005000000B6F63E5585D24A401EA67D737F694B40B6F63E5585D24A405B09DD25716C4B40630CACE3F8D74A405B09DD25716C4B40630CACE3F8D74A401EA67D737F694B40B6F63E5585D24A401EA67D737F694B40
24648	Наратасты	7	61	1348	53.956184999999998	53.983359	54.806553000000001	54.783414	0103000020E610000001000000050000007FF6234564FA4A40419DF2E846644B407FF6234564FA4A40CFBEF2203D674B40179D2CB5DEFD4A40CFBEF2203D674B40179D2CB5DEFD4A40419DF2E846644B407FF6234564FA4A40419DF2E846644B40
22818	Мещерево	7	61	1348	54.078598	54.099259000000004	54.832500000000003	54.818765999999997	0103000020E61000000100000005000000F8C3CF7F0F0A4B40D2890453CD684B40F8C3CF7F0F0A4B40C3F5285C8F6A4B40B66AD784B40C4B40C3F5285C8F6A4B40B66AD784B40C4B40D2890453CD684B40F8C3CF7F0F0A4B40D2890453CD684B40
23280	Куртутель	7	61	1348	53.757010000000001	53.800902000000001	54.899130999999997	54.881520000000002	0103000020E610000001000000050000005B5F24B4E5E04A408D62B9A5D5704B405B5F24B4E5E04A40EEE87FB916734B4087A6ECF483E64A40EEE87FB916734B4087A6ECF483E64A408D62B9A5D5704B405B5F24B4E5E04A408D62B9A5D5704B40
23811	Кугарчи-Буляк	7	61	1348	53.673744999999997	53.701287999999998	54.893321999999998	54.881659999999997	0103000020E61000000100000005000000F86BB2463DD64A407E18213CDA704B40F86BB2463DD64A400E66136058724B40E38920CEC3D94A400E66136058724B40E38920CEC3D94A407E18213CDA704B40F86BB2463DD64A407E18213CDA704B40
58783	Источник	7	61	1348	53.827806000000002	53.860514000000002	54.902703000000002	54.890427000000003	0103000020E610000001000000050000005FB7088CF5E94A40DA3C0E83F9714B405FB7088CF5E94A4024809BC58B734B4005E09F5225EE4A4024809BC58B734B4005E09F5225EE4A40DA3C0E83F9714B405FB7088CF5E94A40DA3C0E83F9714B40
21410	Зириклы	7	61	1348	53.750236999999998	53.784875999999997	54.860430000000001	54.838219000000002	0103000020E61000000100000005000000E49F19C407E04A4063F19BC24A6B4B40E49F19C407E04A40A73FFB91226E4B4028B517D176E44A40A73FFB91226E4B4028B517D176E44A4063F19BC24A6B4B40E49F19C407E04A4063F19BC24A6B4B40
23097	Еремкино	7	61	1348	53.746940000000002	53.764403000000001	54.769652999999998	54.755279999999999	0103000020E610000001000000050000008109DCBA9BDF4A4054A9D903AD604B408109DCBA9BDF4A40572250FD83624B406EFB1EF5D7E14A40572250FD83624B406EFB1EF5D7E14A4054A9D903AD604B408109DCBA9BDF4A4054A9D903AD604B40
24052	Енахметово	7	61	1348	54.206626	54.247247999999999	54.829030000000003	54.814174999999999	0103000020E610000001000000050000006C4084B8721A4B40431CEBE236684B406C4084B8721A4B4092B3B0A71D6A4B402E008DD2A51F4B4092B3B0A71D6A4B402E008DD2A51F4B40431CEBE236684B406C4084B8721A4B40431CEBE236684B40
23990	Емметово	7	61	1348	54.227592999999999	54.241003999999997	54.760277000000002	54.741061999999999	0103000020E6100000010000000500000036E675C4211D4B4078279F1EDB5E4B4036E675C4211D4B405473B9C150614B40431A1538D91E4B405473B9C150614B40431A1538D91E4B4078279F1EDB5E4B4036E675C4211D4B4078279F1EDB5E4B40
23012	Дмитриева Поляна	7	61	1348	53.914009	53.936726999999998	54.854823000000003	54.840255999999997	0103000020E61000000100000005000000F59F353FFEF44A40462234828D6B4B40F59F353FFEF44A402F6F0ED76A6D4B40DD239BABE6F74A402F6F0ED76A6D4B40DD239BABE6F74A40462234828D6B4B40F59F353FFEF44A40462234828D6B4B40
14451	Биккулово	7	61	1348	54.128202999999999	54.141641999999997	54.855932000000003	54.850566999999998	0103000020E61000000100000005000000E21FB6F468104B4046072461DF6C4B40E21FB6F468104B40C9CC052E8F6D4B40B9DE365321124B40C9CC052E8F6D4B40B9DE365321124B4046072461DF6C4B40E21FB6F468104B4046072461DF6C4B40
22936	Базгиево	7	61	1348	54.069623999999997	54.090285000000002	54.733832	54.715873000000002	0103000020E6100000010000000500000023827170E9084B40728BF9B9A15B4B4023827170E9084B400F61FC34EE5D4B40E12879758E0B4B400F61FC34EE5D4B40E12879758E0B4B40728BF9B9A15B4B4023827170E9084B40728BF9B9A15B4B40
24134	Анисимова Поляна	7	61	1348	53.840446	53.874079000000002	54.988318999999997	54.970286999999999	0103000020E61000000100000005000000EA060ABC93EB4A40F25D4A5D327C4B40EA060ABC93EB4A40F981AB3C817E4B40698F17D2E1EF4A40F981AB3C817E4B40698F17D2E1EF4A40F25D4A5D327C4B40EA060ABC93EB4A40F25D4A5D327C4B40
23347	Алпаево	7	61	1348	53.812390999999998	53.835800999999996	54.846322000000001	54.834522	0103000020E610000001000000050000004948A46DFCE74A4071E5EC9DD16A4B404948A46DFCE74A4052F17F47546C4B40677BF486FBEA4A4052F17F47546C4B40677BF486FBEA4A4071E5EC9DD16A4B404948A46DFCE74A4071E5EC9DD16A4B40
22703	Акбарисово	7	61	1348	54.174134000000002	54.208511999999999	54.873243000000002	54.850499999999997	0103000020E61000000100000005000000938FDD054A164B40BE9F1A2FDD6C4B40938FDD054A164B40003B376DC66F4B406A696E85B01A4B40003B376DC66F4B406A696E85B01A4B40BE9F1A2FDD6C4B40938FDD054A164B40BE9F1A2FDD6C4B40
58758	санаторий Алкинский	7	61	357	55.577041999999999	55.594414999999998	54.641722000000001	54.633104000000003	0103000020E610000001000000050000008F352383DCC94B40C07B478D09514B408F352383DCC94B40D68F4DF223524B403CA06CCA15CC4B40D68F4DF223524B403CA06CCA15CC4B40C07B478D09514B408F352383DCC94B40C07B478D09514B40
22095	Ябалаклы	7	61	357	55.260170000000002	55.275539999999999	54.405729999999998	54.389330000000001	0103000020E610000001000000050000003EB324404DA14B4004ADC090D5314B403EB324404DA14B40C780ECF5EE334B40B35E0CE544A34B40C780ECF5EE334B40B35E0CE544A34B4004ADC090D5314B403EB324404DA14B4004ADC090D5314B40
22131	Шингак-Куль	7	61	357	55.195860000000003	55.224148	54.398440000000001	54.373629999999999	0103000020E610000001000000050000001B4CC3F011994B40F9669B1BD32F4B401B4CC3F011994B4089B5F81400334B405EBBB4E1B09C4B4089B5F81400334B405EBBB4E1B09C4B40F9669B1BD32F4B401B4CC3F011994B40F9669B1BD32F4B40
5640	Чувалкипово	7	61	357	55.407924999999999	55.443021999999999	54.379105000000003	54.360731999999999	0103000020E61000000100000005000000431CEBE236B44B40724F57772C2E4B40431CEBE236B44B4003603C8386304B404AB4E4F1B4B84B4003603C8386304B404AB4E4F1B4B84B40724F57772C2E4B40431CEBE236B44B40724F57772C2E4B40
21689	Чишмы	7	61	357	55.320303000000003	55.387300000000003	54.582236000000002	54.563484000000003	0103000020E61000000100000005000000C5E74EB0FFA84B40DEE8633E20484B40C5E74EB0FFA84B40E54691B5864A4B40D3DEE00B93B14B40E54691B5864A4B40D3DEE00B93B14B40DEE8633E20484B40C5E74EB0FFA84B40DEE8633E20484B40
46624	Чишмы	7	61	357	55.353963	55.432296000000001	54.602151999999997	54.580027999999999	0103000020E610000001000000050000003D7FDAA84EAD4B40D461855B3E4A4B403D7FDAA84EAD4B40499C1551134D4B408718AF7955B74B40499C1551134D4B408718AF7955B74B40D461855B3E4A4B403D7FDAA84EAD4B40D461855B3E4A4B40
20134	Уразбахты	7	61	357	55.461635000000001	55.491405	54.690731	54.677438000000002	0103000020E6100000010000000500000030D80DDB16BB4B40A988D349B6564B4030D80DDB16BB4B40ACAA97DF69584B40A20BEA5BE6BE4B40ACAA97DF69584B40A20BEA5BE6BE4B40A988D349B6564B4030D80DDB16BB4B40A988D349B6564B40
58330	Узытамак	7	61	357	54.891421000000001	55.784993	54.828071000000001	54.317405999999998	0103000020E61000000100000005000000DBFB54151A724B40EFC682C2A0284B40DBFB54151A724B400DE2033BFE694B40624B8FA67AE44B400DE2033BFE694B40624B8FA67AE44B40EFC682C2A0284B40DBFB54151A724B40EFC682C2A0284B40
21934	Теперишево	7	61	357	55.381326000000001	55.413592999999999	54.331457	54.317405999999998	0103000020E61000000100000005000000A88E554ACFB04B40EFC682C2A0284B40A88E554ACFB04B40E083D72E6D2A4B40616D8C9DF0B44B40E083D72E6D2A4B40616D8C9DF0B44B40EFC682C2A0284B40A88E554ACFB04B40EFC682C2A0284B40
1831	Старомусино	7	61	357	55.495294999999999	55.528551	54.395746000000003	54.379880999999997	0103000020E61000000100000005000000A86F99D365BF4B4096AFCBF09F304B40A86F99D365BF4B40ECC20FCEA7324B4051A2258FA7C34B40ECC20FCEA7324B4051A2258FA7C34B4096AFCBF09F304B40A86F99D365BF4B4096AFCBF09F304B40
10303	Сафарово	7	61	357	55.196767000000001	55.240972999999997	54.563122999999997	54.550431000000003	0103000020E610000001000000050000004DF73AA92F994B4030DAE38574464B404DF73AA92F994B400D501A6A14484B40081C0934D89E4B400D501A6A14484B40081C0934D89E4B4030DAE38574464B404DF73AA92F994B4030DAE38574464B40
58696	Салихово	7	61	357	55.524895000000001	55.557772999999997	54.701324	54.685713999999997	0103000020E61000000100000005000000BE6A65C22FC34B406534F279C5574B40BE6A65C22FC34B4030F31DFCC4594B40C0CB0C1B65C74B4030F31DFCC4594B40C0CB0C1B65C74B406534F279C5574B40BE6A65C22FC34B406534F279C5574B40
58560	Сайраново	7	61	357	55.616568000000001	55.643723999999999	54.507185999999997	54.493367999999997	0103000020E610000001000000050000004CE141B3EBCE4B404B72C0AE263F4B404CE141B3EBCE4B40997E8978EB404B403DD34B8C65D24B40997E8978EB404B403DD34B8C65D24B404B72C0AE263F4B404CE141B3EBCE4B404B72C0AE263F4B40
21986	Новоусманово	7	61	357	55.248249000000001	55.268462	54.454720999999999	54.446131000000001	0103000020E61000000100000005000000E2218C9FC69F4B40AB5D13D21A394B40E2218C9FC69F4B40F7E6374C343A4B40001C7BF65CA24B40F7E6374C343A4B40001C7BF65CA24B40AB5D13D21A394B40E2218C9FC69F4B40AB5D13D21A394B40
46652	Новотроицкое	7	61	357	55.511636000000003	55.538440999999999	54.482624999999999	54.467846000000002	0103000020E6100000010000000500000067BAD7497DC14B403FC8B260E23B4B4067BAD7497DC14B40B29DEFA7C63D4B40ABE97AA2EBC44B40B29DEFA7C63D4B40ABE97AA2EBC44B403FC8B260E23B4B4067BAD7497DC14B403FC8B260E23B4B40
58793	Нижнии Термы	7	61	357	55.241970000000002	55.275388	54.598089000000002	54.589649000000001	0103000020E610000001000000050000007B4E7ADFF89E4B403F8F519E794B4B407B4E7ADFF89E4B40768C2B2E8E4C4B40FDDAFAE93FA34B40768C2B2E8E4C4B40FDDAFAE93FA34B403F8F519E794B4B407B4E7ADFF89E4B403F8F519E794B4B40
20324	Кляшево	7	61	357	55.640830999999999	55.668266000000003	54.563243999999997	54.549641999999999	0103000020E61000000100000005000000A9A10DC006D24B40074147AB5A464B40A9A10DC006D24B4088D51F6118484B40AE8383BD89D54B4088D51F6118484B40AE8383BD89D54B40074147AB5A464B40A9A10DC006D24B40074147AB5A464B40
19338	Карамалы	7	61	357	55.141736000000002	55.158031999999999	54.560853000000002	54.554519999999997	0103000020E610000001000000050000003B55BE6724924B402C7DE882FA464B403B55BE6724924B40876EF607CA474B4059DC7F643A944B40876EF607CA474B4059DC7F643A944B402C7DE882FA464B403B55BE6724924B402C7DE882FA464B40
21320	Кара-Якупово	7	61	357	55.462516000000001	55.476582999999998	54.566271	54.552796000000001	0103000020E6100000010000000500000039F06AB933BB4B4008AEF204C2464B4039F06AB933BB4B402CD670917B484B402F6AF7AB00BD4B402CD670917B484B402F6AF7AB00BD4B4008AEF204C2464B4039F06AB933BB4B4008AEF204C2464B40
20990	Калмашево	7	61	357	55.200296999999999	55.24409	54.663760000000003	54.647948	0103000020E61000000100000005000000533E0455A3994B401AC1C6F5EF524B40533E0455A3994B404D327216F6544B40ECA353573E9F4B404D327216F6544B40ECA353573E9F4B401AC1C6F5EF524B40533E0455A3994B401AC1C6F5EF524B40
58237	Игнатовка	7	61	357	55.315398999999999	55.327615999999999	54.531407999999999	54.517817000000001	0103000020E61000000100000005000000761893FE5EA84B400B28D4D347424B40761893FE5EA84B40986A662D05444B40BBD23252EFA94B40986A662D05444B40BBD23252EFA94B400B28D4D347424B40761893FE5EA84B400B28D4D347424B40
21143	Ибрагимово	7	61	357	55.588576000000003	55.620007999999999	54.404089999999997	54.392589999999998	0103000020E61000000100000005000000F29A577556CB4B404A5E9D6340324B40F29A577556CB4B4000529B38B9334B4012A1116C5CCF4B4000529B38B9334B4012A1116C5CCF4B404A5E9D6340324B40F29A577556CB4B404A5E9D6340324B40
46167	Дурасово	7	61	357	55.284613	55.294513000000002	54.432003000000002	54.416733999999998	0103000020E610000001000000050000001B82E3326EA44B40CD902A8A57354B401B82E3326EA44B400F63D2DF4B374B40999F1B9AB2A54B400F63D2DF4B374B40999F1B9AB2A54B40CD902A8A57354B401B82E3326EA44B40CD902A8A57354B40
22029	Дмитриевка	7	61	357	55.332008000000002	55.347208000000002	54.775958000000003	54.754925999999998	0103000020E610000001000000050000005401F73C7FAA4B403673486AA1604B405401F73C7FAA4B40E8887C9752634B406D74CE4F71AC4B40E8887C9752634B406D74CE4F71AC4B403673486AA1604B405401F73C7FAA4B403673486AA1604B40
58497	Горный	7	61	357	55.427311000000003	55.444001	54.547955999999999	54.539484000000002	0103000020E610000001000000050000004C1C7920B2B64B408E5BCCCF0D454B404C1C7920B2B64B40D0D2156C23464B4016325706D5B84B40D0D2156C23464B4016325706D5B84B408E5BCCCF0D454B404C1C7920B2B64B408E5BCCCF0D454B40
58747	Вишневка	7	61	357	55.688423999999998	55.703201	54.416949000000002	54.408423999999997	0103000020E6100000010000000500000008E412471ED84B406473D53C47344B4008E412471ED84B40CA8CB7955E354B40DBC1887D02DA4B40CA8CB7955E354B40DBC1887D02DA4B406473D53C47344B4008E412471ED84B406473D53C47344B40
58829	Верхний	7	61	357	55.028655999999998	55.042040999999998	54.443696000000003	54.431967	0103000020E61000000100000005000000C66AF3FFAA834B40C2F9D4B14A374B40C66AF3FFAA834B40DAAED007CB384B40AA0B789961854B40DAAED007CB384B40AA0B789961854B40C2F9D4B14A374B40C66AF3FFAA834B40C2F9D4B14A374B40
21045	Верхние Термы	7	61	357	55.167634999999997	55.200755999999998	54.610151999999999	54.600237999999997	0103000020E610000001000000050000001D554D1075954B4081E84999D44C4B401D554D1075954B4064CBF275194E4B40E63C635FB2994B4064CBF275194E4B40E63C635FB2994B4081E84999D44C4B401D554D1075954B4081E84999D44C4B40
20735	Булякбашево	7	61	357	55.360852999999999	55.372872999999998	54.385272000000001	54.378444999999999	0103000020E61000000100000005000000EDD45C6E30AE4B40D82AC1E270304B40EDD45C6E30AE4B404208C89750314B40DC476E4DBAAF4B404208C89750314B40DC476E4DBAAF4B40D82AC1E270304B40EDD45C6E30AE4B40D82AC1E270304B40
20546	Бишкази	7	61	357	55.256137000000003	55.276133000000002	54.786425000000001	54.773111999999998	0103000020E61000000100000005000000D525E318C9A04B4094128255F5624B40D525E318C9A04B40DFE00B93A9644B40562C7E5358A34B40DFE00B93A9644B40562C7E5358A34B4094128255F5624B40D525E318C9A04B4094128255F5624B40
21507	Барсуанбашево	7	61	357	55.583841999999997	55.607908000000002	54.488163999999998	54.473246000000003	0103000020E61000000100000005000000FF03AC55BBCA4B403E7B2E53933C4B40FF03AC55BBCA4B40D28A6F287C3E4B40077DE9EDCFCD4B40D28A6F287C3E4B40077DE9EDCFCD4B403E7B2E53933C4B40FF03AC55BBCA4B403E7B2E53933C4B40
20854	Балагушево	7	61	357	55.736671999999999	55.751880999999997	54.448565000000002	54.438329000000003	0103000020E6100000010000000500000080F0A1444BDE4B40B7F1272A1B384B4080F0A1444BDE4B40AC90F2936A394B40ECBDF8A23DE04B40AC90F2936A394B40ECBDF8A23DE04B40B7F1272A1B384B4080F0A1444BDE4B40B7F1272A1B384B40
20406	Арсланово	7	61	357	55.394979999999997	55.430643000000003	54.687192000000003	54.670586999999998	0103000020E610000001000000050000007B4963B48EB24B40B60F79CBD5554B407B4963B48EB24B4053094FE8F5574B402CA0504F1FB74B4053094FE8F5574B402CA0504F1FB74B40B60F79CBD5554B407B4963B48EB24B40B60F79CBD5554B40
20244	Арово	7	61	357	55.573205999999999	55.600999999999999	54.575983999999998	54.560727	0103000020E610000001000000050000007CEF6FD05EC94B40FA7DFFE6C5474B407CEF6FD05EC94B407782FDD7B9494B40B0726891EDCC4B407782FDD7B9494B40B0726891EDCC4B40FA7DFFE6C5474B407CEF6FD05EC94B40FA7DFFE6C5474B40
20764	Альбеево	7	61	357	55.279870000000003	55.292670999999999	54.343798	54.332486000000003	0103000020E61000000100000005000000D690B8C7D2A34B405E30B8E68E2A4B40D690B8C7D2A34B401137A792012C4B406ABE4A3E76A54B401137A792012C4B406ABE4A3E76A54B405E30B8E68E2A4B40D690B8C7D2A34B405E30B8E68E2A4B40
58156	Алкино 2-е	7	61	357	55.547308000000001	55.610163	54.666514999999997	54.637417999999997	0103000020E610000001000000050000006A6B44300EC64B40DCF0BBE996514B406A6B44300EC64B408FA50F5D50554B40581D39D219CE4B408FA50F5D50554B40581D39D219CE4B40DCF0BBE996514B406A6B44300EC64B40DCF0BBE996514B40
21841	Абраево	7	61	357	55.451411999999998	55.474679000000002	54.402963	54.387877000000003	0103000020E61000000100000005000000CF8250DEC7B94B4070EF1AF4A5314B40CF8250DEC7B94B40C03FA54A94334B408B8C0E48C2BC4B40C03FA54A94334B408B8C0E48C2BC4B4070EF1AF4A5314B40CF8250DEC7B94B4070EF1AF4A5314B40
18345	Юмашево	7	61	317	54.397446000000002	54.436639999999997	55.007876000000003	54.991334999999999	0103000020E6100000010000000500000088F6B182DF324B40A930B610E47E4B4088F6B182DF324B402F36AD1402814B400E10CCD1E3374B402F36AD1402814B400E10CCD1E3374B40A930B610E47E4B4088F6B182DF324B40A930B610E47E4B40
17073	Чекмагуш	7	61	317	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
19245	Урняк	7	61	317	54.747033999999999	54.791375000000002	55.045692000000003	55.023263	0103000020E61000000100000005000000028063CF9E5F4B407A1A3048FA824B40028063CF9E5F4B402CD8463CD9854B409EEFA7C64B654B402CD8463CD9854B409EEFA7C64B654B407A1A3048FA824B40028063CF9E5F4B407A1A3048FA824B40
18361	Уйбулатово	7	61	317	54.410651000000001	54.447617000000001	54.975557999999999	54.957039999999999	0103000020E61000000100000005000000EC88433690344B405F7B6649807A4B40EC88433690344B40F3ACA415DF7C4B401B118C834B394B40F3ACA415DF7C4B401B118C834B394B405F7B6649807A4B40EC88433690344B405F7B6649807A4B40
58864	Тяйняшево	7	61	317	54.398246	54.419508999999998	55.182968000000002	55.169317999999997	0103000020E61000000100000005000000A4E194B9F9324B40E34F5436AC954B40A4E194B9F9324B40761BD47E6B974B4057B08D78B2354B40761BD47E6B974B4057B08D78B2354B40E34F5436AC954B40A4E194B9F9324B40E34F5436AC954B40
58613	Тукаево	7	61	317	54.481501000000002	54.495362	55.148435999999997	55.142169000000003	0103000020E61000000100000005000000E3FE23D3A13D4B40A5C0029832924B40E3FE23D3A13D4B4047C66AF3FF924B4030D7A205683F4B4047C66AF3FF924B4030D7A205683F4B40A5C0029832924B40E3FE23D3A13D4B40A5C0029832924B40
19537	Тузлукушево	7	61	317	54.806341000000003	54.843755999999999	55.213849000000003	55.199711999999998	0103000020E610000001000000050000004436902E36674B40334FAE2990994B404436902E36674B4023A46E675F9B4B40E2E65432006C4B4023A46E675F9B4B40E2E65432006C4B40334FAE2990994B404436902E36674B40334FAE2990994B40
19082	Ташкалмашево	7	61	317	54.944906000000003	54.979365999999999	55.130147999999998	55.119013000000002	0103000020E61000000100000005000000A8E507AEF2784B40416667D13B8F4B40A8E507AEF2784B40E5D18DB0A8904B403C6876DD5B7D4B40E5D18DB0A8904B403C6876DD5B7D4B40416667D13B8F4B40A8E507AEF2784B40416667D13B8F4B40
19918	Тамьяново	7	61	317	54.530971999999998	54.567397999999997	55.245860999999998	55.233172000000003	0103000020E61000000100000005000000BD8BF7E3F6434B40E52B8194D89D4B40BD8BF7E3F6434B40512E8D5F789F4B406CE8667FA0484B40512E8D5F789F4B406CE8667FA0484B40E52B8194D89D4B40BD8BF7E3F6434B40E52B8194D89D4B40
19604	Сыйрышбашево	7	61	317	54.739201000000001	54.768045999999998	55.219611999999998	55.205779	0103000020E61000000100000005000000D3156C239E5E4B400F9A5DF7569A4B40D3156C239E5E4B4092E7FA3E1C9C4B406CE9D1544F624B4092E7FA3E1C9C4B406CE9D1544F624B400F9A5DF7569A4B40D3156C239E5E4B400F9A5DF7569A4B40
18178	Старосурметово	7	61	317	54.248379999999997	54.283782000000002	55.072313999999999	55.050189000000003	0103000020E61000000100000005000000807D74EACA1F4B403ACFD8976C864B40807D74EACA1F4B407F85CC9541894B40C498F4F752244B407F85CC9541894B40C498F4F752244B403ACFD8976C864B40807D74EACA1F4B403ACFD8976C864B40
18275	Старопучкаково	7	61	317	54.460957000000001	54.477890000000002	54.999231999999999	54.985084999999998	0103000020E610000001000000050000005FEE93A3003B4B40DC63E943177E4B405FEE93A3003B4B40EF8E8CD5E67F4B40F08AE07F2B3D4B40EF8E8CD5E67F4B40F08AE07F2B3D4B40DC63E943177E4B405FEE93A3003B4B40DC63E943177E4B40
1997	Старокалмашево	7	61	317	54.791178000000002	54.859107999999999	55.134157000000002	55.114280999999998	0103000020E6100000010000000500000048A8195245654B40EFC682C2A08E4B4048A8195245654B40C6C37B0E2C914B40B1DD3D40F76D4B40C6C37B0E2C914B40B1DD3D40F76D4B40EFC682C2A08E4B4048A8195245654B40EFC682C2A08E4B40
18708	Старобиккино	7	61	317	54.564298999999998	54.599944000000001	55.031447999999997	55.019021000000002	0103000020E610000001000000050000002F151BF33A484B40F777B6476F824B402F151BF33A484B4026C3F17C06844B4039B709F7CA4C4B4026C3F17C06844B4039B709F7CA4C4B40F777B6476F824B402F151BF33A484B40F777B6476F824B40
18002	Старобалаково	7	61	317	54.349350000000001	54.380611999999999	55.176645000000001	55.161399000000003	0103000020E61000000100000005000000C66D3480B72C4B40B64DF1B8A8944B40C66D3480B72C4B403F00A94D9C964B408A3BDEE4B7304B403F00A94D9C964B408A3BDEE4B7304B40B64DF1B8A8944B40C66D3480B72C4B40B64DF1B8A8944B40
18089	Резяпово	7	61	317	54.271034999999998	54.315089	55.104337000000001	55.090639000000003	0103000020E6100000010000000500000022895E46B1224B40FF5E0A0F9A8B4B4022895E46B1224B40A26131EA5A8D4B40282A1BD654284B40A26131EA5A8D4B40282A1BD654284B40FF5E0A0F9A8B4B4022895E46B1224B40FF5E0A0F9A8B4B40
1440	Рапатово	7	61	317	54.587197000000003	54.628484	55.074139000000002	55.056553000000001	0103000020E6100000010000000500000098A77345294B4B40CFBEF2203D874B4098A77345294B4B40D82D02637D894B409607E92972504B40D82D02637D894B409607E92972504B40CFBEF2203D874B4098A77345294B4B40CFBEF2203D874B40
17831	Новые Карьявды	7	61	317	54.343736	54.37321	55.050721000000003	55.038687000000003	0103000020E610000001000000050000009B3A8F8AFF2B4B40E3E313B2F3844B409B3A8F8AFF2B4B40371C96067E864B4024456458C52F4B40371C96067E864B4024456458C52F4B40E3E313B2F3844B409B3A8F8AFF2B4B40E3E313B2F3844B40
58350	Новосеменкино	7	61	317	54.429031000000002	54.446198000000003	54.985787999999999	54.973211999999997	0103000020E610000001000000050000002FFCE07CEA364B409109F835927C4B402FFCE07CEA364B4006651A4D2E7E4B4033C51C041D394B4006651A4D2E7E4B4033C51C041D394B409109F835927C4B402FFCE07CEA364B409109F835927C4B40
2303	Новокутово	7	61	317	54.570174000000002	54.595649999999999	55.222836999999998	55.197363000000003	0103000020E61000000100000005000000C7832D76FB484B406138D73043994B40C7832D76FB484B405CAB3DEC859C4B4063EE5A423E4C4B405CAB3DEC859C4B4063EE5A423E4C4B406138D73043994B40C7832D76FB484B406138D73043994B40
19000	Новокалмашево	7	61	317	55.037405999999997	55.068092	55.129688999999999	55.117390999999998	0103000020E610000001000000050000004B5645B8C9844B4020EC14AB068F4B404B5645B8C9844B4052D32EA699904B40438F183DB7884B4052D32EA699904B40438F183DB7884B4020EC14AB068F4B404B5645B8C9844B4020EC14AB068F4B40
19173	Новоихсаново	7	61	317	54.914687000000001	55.045310999999998	55.079942000000003	55.061864	0103000020E61000000100000005000000C689AF7614754B405E66D828EB874B40C689AF7614754B40D6C9198A3B8A4B40149337C0CC854B40D6C9198A3B8A4B40149337C0CC854B405E66D828EB874B40C689AF7614754B405E66D828EB874B40
18600	Новобиккино	7	61	317	54.667327	54.685509000000003	55.070112999999999	55.061245	0103000020E61000000100000005000000705E9CF86A554B4092054CE0D6874B40705E9CF86A554B4021037976F9884B408D0E48C2BE574B4021037976F9884B408D0E48C2BE574B4092054CE0D6874B40705E9CF86A554B4092054CE0D6874B40
17703	Новобалтачево	7	61	317	54.411189999999998	54.440125000000002	55.127023000000001	55.103023	0103000020E610000001000000050000009B38B9DFA1344B402FDE8FDB2F8D4B409B38B9DFA1344B407F6B274A42904B407593180456384B407F6B274A42904B407593180456384B402FDE8FDB2F8D4B409B38B9DFA1344B402FDE8FDB2F8D4B40
18138	Новобалаково	7	61	317	54.250337999999999	54.279344999999999	55.139215999999998	55.129216	0103000020E61000000100000005000000187959130B204B405A0F5F268A904B40187959130B204B403B8A73D4D1914B408BA6B393C1234B403B8A73D4D1914B408BA6B393C1234B405A0F5F268A904B40187959130B204B405A0F5F268A904B40
18878	Новая Муртаза	7	61	317	54.917417999999998	54.947332000000003	55.188571000000003	55.177283000000003	0103000020E610000001000000050000008061F9F36D754B4082919735B1964B408061F9F36D754B40ADFC321823984B40263ACB2C42794B40ADFC321823984B40263ACB2C42794B4082919735B1964B408061F9F36D754B4082919735B1964B40
49378	Нариманово	7	61	317	54.645021999999997	54.654463	55.176546999999999	55.167853000000001	0103000020E61000000100000005000000AA99B51490524B408BC404357C954B40AA99B51490524B407C9A931799964B4095B88E71C5534B407C9A931799964B4095B88E71C5534B408BC404357C954B40AA99B51490524B408BC404357C954B40
18223	Митро-Аюповское	7	61	317	54.455494999999999	54.47833	55.036447000000003	55.013455999999998	0103000020E61000000100000005000000EA3E00A94D3A4B40ADF71BEDB8814B40EA3E00A94D3A4B40C784984BAA844B400C59DDEA393D4B40C784984BAA844B400C59DDEA393D4B40ADF71BEDB8814B40EA3E00A94D3A4B40ADF71BEDB8814B40
49404	Ленино	7	61	317	54.437627999999997	54.457605999999998	55.100735999999998	55.089243000000003	0103000020E610000001000000050000002DE8BD3104384B40CF328B506C8B4B402DE8BD3104384B40D2C3D0EAE48C4B40083A5AD5923A4B40D2C3D0EAE48C4B40083A5AD5923A4B40CF328B506C8B4B402DE8BD3104384B40CF328B506C8B4B40
18458	Караталово	7	61	317	54.350842	54.367721000000003	54.953932999999999	54.946202999999997	0103000020E6100000010000000500000018080264E82C4B4044300E2E1D794B4018080264E82C4B409FC9FE791A7A4B40B686527B112F4B409FC9FE791A7A4B40B686527B112F4B4044300E2E1D794B4018080264E82C4B4044300E2E1D794B40
47158	Каран	7	61	317	54.355387	54.379739999999998	55.133338999999999	55.120953999999998	0103000020E6100000010000000500000037363B527D2D4B400229B16B7B8F4B4037363B527D2D4B4003249A4011914B40D47D00529B304B4003249A4011914B40D47D00529B304B400229B16B7B8F4B4037363B527D2D4B400229B16B7B8F4B40
19687	Каразириково	7	61	317	54.794421	54.814202000000002	55.298174000000003	55.282513000000002	0103000020E61000000100000005000000B8205B96AF654B40F1D8CF6229A44B40B8205B96AF654B403E42CD902AA64B403D2B69C537684B403E42CD902AA64B403D2B69C537684B40F1D8CF6229A44B40B8205B96AF654B40F1D8CF6229A44B40
18643	Калмашбашево	7	61	317	54.578626999999997	54.650734999999997	55.024765000000002	54.991356000000003	0103000020E6100000010000000500000092CA1473104A4B40C158DFC0E47E4B4092CA1473104A4B40F08AE07F2B834B4068AED3484B534B40F08AE07F2B834B4068AED3484B534B40C158DFC0E47E4B4092CA1473104A4B40C158DFC0E47E4B40
58878	Калиновка	7	61	317	54.535589000000002	54.55095	55.118529000000002	55.110984999999999	0103000020E61000000100000005000000768C2B2E8E444B405CACA8C1348E4B40768C2B2E8E444B40555051F52B8F4B4098DD938785464B40555051F52B8F4B4098DD938785464B405CACA8C1348E4B40768C2B2E8E444B405CACA8C1348E4B40
19755	Имянликулево	7	61	317	54.639820999999998	54.673426999999997	55.291167000000002	55.276676999999999	0103000020E61000000100000005000000A2258FA7E5514B401747E5266AA34B40A2258FA7E5514B405456D3F544A54B40279F1EDB32564B405456D3F544A54B40279F1EDB32564B401747E5266AA34B40A2258FA7E5514B401747E5266AA34B40
19784	Верхний Аташ	7	61	317	54.674576000000002	54.699576	55.338192999999997	55.316876999999998	0103000020E610000001000000050000005055A18158564B4063EDEF6C8FA84B405055A18158564B40395E81E849AB4B408388D4B48B594B40395E81E849AB4B408388D4B48B594B4063EDEF6C8FA84B405055A18158564B4063EDEF6C8FA84B40
19492	Бардаслы	7	61	317	54.769159999999999	54.784171000000001	54.945283000000003	54.932890999999998	0103000020E6100000010000000500000018B2BAD573624B40CADDE7F868774B4018B2BAD573624B407E3B8908FF784B405EBC1FB75F644B407E3B8908FF784B405EBC1FB75F644B40CADDE7F868774B4018B2BAD573624B40CADDE7F868774B40
18031	Ахметово	7	61	317	54.400033000000001	54.422373999999998	55.232104	55.218522999999998	0103000020E610000001000000050000000F29064834334B403F36C98FF89B4B400F29064834334B40A9A27895B59D4B402157EA5910364B40A9A27895B59D4B402157EA5910364B403F36C98FF89B4B400F29064834334B403F36C98FF89B4B40
4462	Аблаево	7	61	317	54.814300000000003	54.888807	54.997692999999998	54.962792999999998	0103000020E6100000010000000500000000917EFB3A684B40ABE80FCD3C7B4B4000917EFB3A684B405C397B67B47F4B405ABA826DC4714B405C397B67B47F4B405ABA826DC4714B40ABE80FCD3C7B4B4000917EFB3A684B40ABE80FCD3C7B4B40
15126	Янтышево	7	61	106	57.708142000000002	57.747120000000002	51.895696000000001	51.881532999999997	0103000020E610000001000000050000004776A565A4DA4C4021ACC612D6F049404776A565A4DA4C403A94A12AA6F249400118CFA0A1DF4C403A94A12AA6F249400118CFA0A1DF4C4021ACC612D6F049404776A565A4DA4C4021ACC612D6F04940
58504	Яковлевка	7	61	106	57.965131999999997	57.985847	52.004781999999999	51.993648	0103000020E610000001000000050000005A29047289FB4C402FDE8FDB2FFF49405A29047289FB4C4003CE52B29C004A400BEE073C30FE4C4003CE52B29C004A400BEE073C30FE4C402FDE8FDB2FFF49405A29047289FB4C402FDE8FDB2FFF4940
15879	Юлбарсово	7	61	106	57.990724999999998	58.003661000000001	52.06944	52.059823000000002	0103000020E61000000100000005000000302AA913D0FE4C403946B247A8074A40302AA913D0FE4C406284F068E3084A40A5A2B1F677004D406284F068E3084A40A5A2B1F677004D403946B247A8074A40302AA913D0FE4C403946B247A8074A40
33038	Целинное	7	61	106	58.643296999999997	58.658793000000003	52.241239999999998	52.229546999999997	0103000020E61000000100000005000000B54E5C8E57524D408CF2CCCB611D4A40B54E5C8E57524D40573ECBF3E01E4A40B8EA3A5453544D40573ECBF3E01E4A40B8EA3A5453544D408CF2CCCB611D4A40B54E5C8E57524D408CF2CCCB611D4A40
15856	Хворостянское	7	61	106	58.134779000000002	58.150221000000002	52.106167999999997	52.098970999999999	0103000020E610000001000000050000000398327040114D404F20EC14AB0C4A400398327040114D40DCF0BBE9960D4A40121615713A134D40DCF0BBE9960D4A40121615713A134D404F20EC14AB0C4A400398327040114D404F20EC14AB0C4A40
16366	Уфимский	7	61	106	58.276631999999999	58.304713	52.218888999999997	52.205562	0103000020E61000000100000005000000778368AD68234D4072A609DB4F1A4A40778368AD68234D40213A048E041C4A4041D5E8D500274D40213A048E041C4A4041D5E8D500274D4072A609DB4F1A4A40778368AD68234D4072A609DB4F1A4A40
14531	Урняк	7	61	106	57.632747000000002	57.647533000000003	51.840324000000003	51.832405000000001	0103000020E6100000010000000500000031D28BDAFDD04C4071033E3F8CEA494031D28BDAFDD04C409F05A1BC8FEB4940570A815CE2D24C409F05A1BC8FEB4940570A815CE2D24C4071033E3F8CEA494031D28BDAFDD04C4071033E3F8CEA4940
14749	Уразбаево	7	61	106	57.436725000000003	57.452437000000003	51.971266	51.963354000000002	0103000020E610000001000000050000003D2CD49AE6B74C40433C122F4FFB49403D2CD49AE6B74C40BEDBBC7152FC49400C40A374E9B94C40BEDBBC7152FC49400C40A374E9B94C40433C122F4FFB49403D2CD49AE6B74C40433C122F4FFB4940
58794	Таштугай	7	61	106	57.299686999999999	58.713113999999997	52.379731999999997	51.719147999999997	0103000020E61000000100000005000000A704C4245CA64C40ED7DAA0A0DDC4940A704C4245CA64C40519FE40E9B304A40ED28CE51475B4D40519FE40E9B304A40ED28CE51475B4D40ED7DAA0A0DDC4940A704C4245CA64C40ED7DAA0A0DDC4940
16253	Татыр-Узяк	7	61	106	58.134177000000001	58.152268999999997	51.980930000000001	51.953636000000003	0103000020E610000001000000050000000D7041B62C114D40E62494BE10FA49400D7041B62C114D4028D53E1D8FFD4940E998F38C7D134D4028D53E1D8FFD4940E998F38C7D134D40E62494BE10FA49400D7041B62C114D40E62494BE10FA4940
32819	Степной	7	61	106	58.138919999999999	58.176172999999999	51.825736999999997	51.812291999999999	0103000020E6100000010000000500000052616C21C8114D40B6662B2FF9E7494052616C21C8114D406F0C01C0B1E9494017B83CD68C164D406F0C01C0B1E9494017B83CD68C164D40B6662B2FF9E7494052616C21C8114D40B6662B2FF9E74940
15765	Самарское	7	61	106	58.142837	58.158952999999997	52.051200999999999	52.015070999999999	0103000020E6100000010000000500000052D4997B48124D401B0FB6D8ED014A4052D4997B48124D40E1421EC18D064A40F04C689258144D40E1421EC18D064A40F04C689258144D401B0FB6D8ED014A4052D4997B48124D401B0FB6D8ED014A40
33160	Сакмар-Назаргулово	7	61	106	57.510019	57.528011999999997	51.839511000000002	51.832683000000003	0103000020E6100000010000000500000058AB764D48C14C40B477465B95EA494058AB764D48C14C40EED0B01875EB4940A1F2AFE595C34C40EED0B01875EB4940A1F2AFE595C34C40B477465B95EA494058AB764D48C14C40B477465B95EA4940
47255	Садовый	7	61	106	58.196080000000002	58.214602999999997	51.909042999999997	51.898257999999998	0103000020E6100000010000000500000029B3412619194D4068AF3E1EFAF2494029B3412619194D4030D461855BF44940CE4F711C781B4D4030D461855BF44940CE4F711C781B4D4068AF3E1EFAF2494029B3412619194D4068AF3E1EFAF24940
58580	Сагитово	7	61	106	58.469419000000002	58.486244999999997	51.812503	51.802078999999999	0103000020E610000001000000050000007E8FFAEB153C4D4079E75086AAE649407E8FFAEB153C4D4071732A1900E84940F86BB2463D3E4D4071732A1900E84940F86BB2463D3E4D4079E75086AAE649407E8FFAEB153C4D4079E75086AAE64940
16158	Савельевка	7	61	106	58.539892000000002	58.557391000000003	52.080328999999999	52.075479999999999	0103000020E610000001000000050000009FAF592E1B454D4044C02154A9094A409FAF592E1B454D40CFF57D38480A4A40D90A9A9658474D40CFF57D38480A4A40D90A9A9658474D4044C02154A9094A409FAF592E1B454D4044C02154A9094A40
48661	Пугачево	7	61	106	57.818041999999998	57.831426999999998	51.947085999999999	51.938986	0103000020E610000001000000050000009160AA99B5E84C4070B378B130F849409160AA99B5E84C40EE3F321D3AF9494075012F336CEA4C40EE3F321D3AF9494075012F336CEA4C4070B378B130F849409160AA99B5E84C4070B378B130F84940
8757	Подольск	7	61	106	58.425635999999997	58.450401999999997	52.051572	52.033602000000002	0103000020E6100000010000000500000008008E3D7B364D40448A01124D044A4008008E3D7B364D40D5B14AE999064A40C806D2C5A6394D40D5B14AE999064A40C806D2C5A6394D40448A01124D044A4008008E3D7B364D40448A01124D044A40
33026	Петропавловский	7	61	106	58.057623	58.071376000000001	52.176229999999997	52.166530999999999	0103000020E61000000100000005000000AB3FC23060074D40956247E350154A40AB3FC23060074D407B4963B48E164A4012DC48D922094D407B4963B48E164A4012DC48D922094D40956247E350154A40AB3FC23060074D40956247E350154A40
3500	Новый Зирган	7	61	106	58.267972	58.318961000000002	51.805670999999997	51.793495999999998	0103000020E61000000100000005000000321F10E84C224D40DFC0E44691E54940321F10E84C224D40F52A323A20E7494088D9CBB6D3284D40F52A323A20E7494088D9CBB6D3284D40DFC0E44691E54940321F10E84C224D40DFC0E44691E54940
16136	Новоукраинка	7	61	106	58.584521000000002	58.600268	52.092691000000002	52.083705000000002	0103000020E61000000100000005000000A1698995D14A4D407FC16ED8B60A4A40A1698995D14A4D4018D1764CDD0B4A40EC6AF294D54C4D4018D1764CDD0B4A40EC6AF294D54C4D407FC16ED8B60A4A40A1698995D14A4D407FC16ED8B60A4A40
58719	Мурзино 1-е	7	61	106	58.208404999999999	58.220424000000001	52.318465000000003	52.310195999999998	0103000020E6100000010000000500000054A9D903AD1A4D40CDACA580B4274A4054A9D903AD1A4D40D8F50B76C3284A4073A087DA361C4D40D8F50B76C3284A4073A087DA361C4D40CDACA580B4274A4054A9D903AD1A4D40CDACA580B4274A40
58302	Михайловка	7	61	106	57.850633000000002	57.872236999999998	52.045755999999997	52.030310999999998	0103000020E61000000100000005000000FEF2C98AE1EC4C40C2DA183BE1034A40FEF2C98AE1EC4C4042CC2555DB054A403AAE4676A5EF4C4042CC2555DB054A403AAE4676A5EF4C40C2DA183BE1034A40FEF2C98AE1EC4C40C2DA183BE1034A40
2239	Мамбетово	7	61	106	58.426732000000001	58.449657000000002	51.865518999999999	51.850411000000001	0103000020E610000001000000050000000E1478279F364D404F948444DAEC49400E1478279F364D4087889B53C9EE494070B54E5C8E394D4087889B53C9EE494070B54E5C8E394D404F948444DAEC49400E1478279F364D404F948444DAEC4940
14417	Малоарслангулово	7	61	106	57.482745999999999	57.505364999999998	51.801583000000001	51.787385	0103000020E610000001000000050000002D23F59ECABD4C40342E1C08C9E449402D23F59ECABD4C40C90391459AE6494082C5E1CCAFC04C40C90391459AE6494082C5E1CCAFC04C40342E1C08C9E449402D23F59ECABD4C40342E1C08C9E44940
15573	Макан	7	61	106	58.331142	58.360894000000002	51.978662	51.951881999999998	0103000020E61000000100000005000000802A6EDC622A4D4056D3F544D7F94940802A6EDC622A4D4042EBE1CB44FD49404CA94BC6312E4D4042EBE1CB44FD49404CA94BC6312E4D4056D3F544D7F94940802A6EDC622A4D4056D3F544D7F94940
49208	Исянгильдино	7	61	106	58.470317999999999	58.489182	52.311264000000001	52.303896999999999	0103000020E610000001000000050000002D5C5661333C4D401F2DCE18E6264A402D5C5661333C4D400936AE7FD7274A405CE509849D3E4D400936AE7FD7274A405CE509849D3E4D401F2DCE18E6264A402D5C5661333C4D401F2DCE18E6264A40
15674	Илячево	7	61	106	58.196888999999999	58.218618999999997	51.770282999999999	51.758946000000002	0103000020E6100000010000000500000098F8A3A833194D400BB77C2425E1494098F8A3A833194D4017D522A298E2494061A417B5FB1B4D4017D522A298E2494061A417B5FB1B4D400BB77C2425E1494098F8A3A833194D400BB77C2425E14940
33150	Ивановка	7	61	106	57.871868999999997	57.906480999999999	51.993637	51.967016000000001	0103000020E61000000100000005000000B7B2446799EF4C40B85A272EC7FB4940B7B2446799EF4C403B8C497F2FFF494002B9C49107F44C403B8C497F2FFF494002B9C49107F44C40B85A272EC7FB4940B7B2446799EF4C40B85A272EC7FB4940
40337	Деревня Адель	7	61	106	57.299686999999999	58.713113999999997	52.379731999999997	51.719147999999997	0103000020E61000000100000005000000A704C4245CA64C40ED7DAA0A0DDC4940A704C4245CA64C40519FE40E9B304A40ED28CE51475B4D40519FE40E9B304A40ED28CE51475B4D40ED7DAA0A0DDC4940A704C4245CA64C40ED7DAA0A0DDC4940
149	Галиахметово	7	61	106	57.528677000000002	57.554279000000001	51.957599000000002	51.942328000000003	0103000020E61000000100000005000000DE921CB0ABC34C40740D33349EF84940DE921CB0ABC34C4056D7A19A92FA494007EE409DF2C64C4056D7A19A92FA494007EE409DF2C64C40740D33349EF84940DE921CB0ABC34C40740D33349EF84940
58609	Воздвиженка	7	61	106	58.352414000000003	58.365879999999997	52.124240999999998	52.114581000000001	0103000020E610000001000000050000008753E6E61B2D4D401ADF1797AA0E4A408753E6E61B2D4D4042E90B21E70F4A405721E527D52E4D4042E90B21E70F4A405721E527D52E4D401ADF1797AA0E4A408753E6E61B2D4D401ADF1797AA0E4A40
12476	Бурибай	7	61	106	58.141651000000003	58.18159	51.977896000000001	51.941817	0103000020E610000001000000050000000D39B69E21124D408EE89E758DF849400D39B69E21124D40D27135B22BFD4940ECA353573E174D40D27135B22BFD4940ECA353573E174D408EE89E758DF849400D39B69E21124D408EE89E758DF84940
15778	Бузавлык	7	61	106	58.103042000000002	58.122318999999997	52.097991999999998	52.087572999999999	0103000020E61000000100000005000000A60EF27A300D4D409D819197350B4A40A60EF27A300D4D4083A279008B0C4A40F7562426A80F4D4083A279008B0C4A40F7562426A80F4D409D819197350B4A40A60EF27A300D4D409D819197350B4A40
14441	Большеарслангулово	7	61	106	57.535522	57.552050999999999	51.813979000000003	51.805894000000002	0103000020E61000000100000005000000EE2422FC8BC44C407505DB8827E74940EE2422FC8BC44C40BE50C07630E84940AF5C6F9BA9C64C40BE50C07630E84940AF5C6F9BA9C64C407505DB8827E74940EE2422FC8BC44C407505DB8827E74940
14344	Большеабишево	7	61	106	57.487399000000003	57.512597	51.781990999999998	51.766894999999998	0103000020E61000000100000005000000338D261763BE4C40A33B889D29E24940338D261763BE4C401762F54718E449408C834BC79CC14C401762F54718E449408C834BC79CC14C40A33B889D29E24940338D261763BE4C40A33B889D29E24940
58843	Бакаловская	7	61	106	58.512422000000001	58.531637000000003	52.003224000000003	51.985762000000001	0103000020E610000001000000050000001EE0490B97414D40DDD1FF722DFE49401EE0490B97414D40FA47DFA469004A40FA2B64AE0C444D40FA47DFA469004A40FA2B64AE0C444D40DDD1FF722DFE49401EE0490B97414D40DDD1FF722DFE4940
16233	Байгускарово	7	61	106	57.971967999999997	57.991155999999997	51.930562000000002	51.917760000000001	0103000020E6100000010000000500000017618A7269FC4C40DAC9E02879F5494017618A7269FC4C403F73D6A71CF74940F99D2633DEFE4C403F73D6A71CF74940F99D2633DEFE4C40DAC9E02879F5494017618A7269FC4C40DAC9E02879F54940
15183	Антинган	7	61	106	57.883547	57.912849999999999	51.897584999999999	51.875827999999998	0103000020E610000001000000050000004DBD6E1118F14C40E675C4211BF049404DBD6E1118F14C40A930B610E4F24940A913D044D8F44C40A930B610E4F24940A913D044D8F44C40E675C4211BF049404DBD6E1118F14C40E675C4211BF04940
16477	Алибаевское	7	61	106	58.286738	58.302898999999996	52.246549999999999	52.226078000000001	0103000020E610000001000000050000009E42AED4B3244D402C2CB81FF01C4A409E42AED4B3244D40166A4DF38E1F4A40DC7EF964C5264D40166A4DF38E1F4A40DC7EF964C5264D402C2CB81FF01C4A409E42AED4B3244D402C2CB81FF01C4A40
14789	Акъяр	7	61	106	58.188066999999997	58.234321000000001	51.876550999999999	51.845626000000003	0103000020E61000000100000005000000793A579412184D40DB5207793DEC4940793A579412184D405723BBD232F049400DE2033BFE1D4D405723BBD232F049400DE2033BFE1D4D40DB5207793DEC4940793A579412184D40DB5207793DEC4940
14683	Акъюлово	7	61	106	57.493758999999997	57.511510000000001	51.900809000000002	51.890210000000003	0103000020E61000000100000005000000868DB27E33BF4C403D49BA66F2F14940868DB27E33BF4C40A37895B54DF34940DAC9E02879C14C40A37895B54DF34940DAC9E02879C14C403D49BA66F2F14940868DB27E33BF4C403D49BA66F2F14940
15419	Акташево	7	61	106	57.791003000000003	57.797947000000001	51.950195000000001	51.937824999999997	0103000020E61000000100000005000000DA0418963FE54C40832F4CA60AF84940DA0418963FE54C404FE960FD9FF949407D78962023E64C404FE960FD9FF949407D78962023E64C40832F4CA60AF84940DA0418963FE54C40832F4CA60AF84940
58806	Акназарово	7	61	106	57.639403000000001	57.651592999999998	51.920321000000001	51.912759999999999	0103000020E610000001000000050000006EFB1EF5D7D14C40698CD651D5F449406EFB1EF5D7D14C4038691A14CDF54940B9A6406667D34C4038691A14CDF54940B9A6406667D34C40698CD651D5F449406EFB1EF5D7D14C40698CD651D5F44940
16797	Абубакирово	7	61	106	57.952528999999998	57.980116000000002	51.874566000000002	51.861624999999997	0103000020E61000000100000005000000ECBE6378ECF94C403F355EBA49EE4940ECBE6378ECF94C40C61858C7F1EF4940A724EB7074FD4C40C61858C7F1EF4940A724EB7074FD4C403F355EBA49EE4940ECBE6378ECF94C403F355EBA49EE4940
17062	Абдулнасырово	7	61	106	58.40325	58.414101000000002	52.269922999999999	52.265431	0103000020E61000000100000005000000560E2DB29D334D401B2C9CA4F9214A40560E2DB29D334D4017B83CD68C224A40D61EF64201354D4017B83CD68C224A40D61EF64201354D401B2C9CA4F9214A40560E2DB29D334D401B2C9CA4F9214A40
33601	Федоровка	7	61	1261	55.161696999999997	55.214616999999997	53.189991999999997	53.164318000000002	0103000020E610000001000000050000003F6EBF7CB2944B4073124A5F08954A403F6EBF7CB2944B40354069A851984A403315E291789B4B40354069A851984A403315E291789B4B4073124A5F08954A403F6EBF7CB2944B4073124A5F08954A40
45679	Новояушево	7	61	1261	55.362237	55.386042000000003	53.042670999999999	53.026685999999998	0103000020E61000000100000005000000593332C85DAE4B406AA164726A834A40593332C85DAE4B406ABE4A3E76854A40F47002D369B14B406ABE4A3E76854A40F47002D369B14B406AA164726A834A40593332C85DAE4B406AA164726A834A40
58842	Каралачик	7	61	1261	55.202407999999998	55.232987000000001	53.112298000000003	53.097349999999999	0103000020E6100000010000000500000071395E81E8994B40FF21FDF6758C4A4071395E81E8994B40FFB3E6C75F8E4A4053B29C84D29D4B40FFB3E6C75F8E4A4053B29C84D29D4B40FF21FDF6758C4A4071395E81E8994B40FF21FDF6758C4A40
32580	Денискино	7	61	1261	55.130175000000001	55.152273000000001	53.023485000000001	53.001596999999997	0103000020E61000000100000005000000DFE00B93A9904B40C7629B5434804A40DFE00B93A9904B402979758E01834A402B8881AE7D934B402979758E01834A402B8881AE7D934B40C7629B5434804A40DFE00B93A9904B40C7629B5434804A40
32601	Гончаровка	7	61	1261	55.102488999999998	55.124336	53.178438999999997	53.166445000000003	0103000020E6100000010000000500000091990B5C1E8D4B4097CADB114E954A4091990B5C1E8D4B405CAAD216D7964A4094DBF63DEA8F4B405CAAD216D7964A4094DBF63DEA8F4B4097CADB114E954A4091990B5C1E8D4B4097CADB114E954A40
33108	Балыклы	7	61	1261	55.290677000000002	55.317267000000001	53.104377999999997	53.084283999999997	0103000020E61000000100000005000000865968E734A54B40BCC96FD1C98A4A40865968E734A54B40003620425C8D4A40CE8C7E349CA84B40003620425C8D4A40CE8C7E349CA84B40BCC96FD1C98A4A40865968E734A54B40BCC96FD1C98A4A40
11421	Учалы	7	61	659	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
58183	Учалы	7	61	659	59.410907999999999	59.453937000000003	54.382429999999999	54.343640999999998	0103000020E6100000010000000500000017D522A298B44D404948A46DFC2B4B4017D522A298B44D4030815B77F3304B40E1B88C9B1ABA4D4030815B77F3304B40E1B88C9B1ABA4D404948A46DFC2B4B4017D522A298B44D404948A46DFC2B4B40
46927	Уральск	7	61	659	59.105840000000001	59.135483999999998	54.133600999999999	54.112436000000002	0103000020E61000000100000005000000E84D452A8C8D4D405072874D640E4B40E84D452A8C8D4D4040DB6AD619114B40CD902A8A57914D4040DB6AD619114B40CD902A8A57914D405072874D640E4B40E84D452A8C8D4D405072874D640E4B40
10890	Уразово	7	61	659	59.11777	59.138494000000001	54.277456999999998	54.255661000000003	0103000020E6100000010000000500000097395D16138F4D406CEEE87FB9204B4097395D16138F4D40EC8502B683234B409B58E02BBA914D40EC8502B683234B409B58E02BBA914D406CEEE87FB9204B4097395D16138F4D406CEEE87FB9204B40
10488	Тунгатарово	7	61	659	59.714852999999998	59.740239000000003	54.608347999999999	54.596457000000001	0103000020E610000001000000050000004739984D80DB4D40323CF6B3584C4B404739984D80DB4D40234BE658DE4D4B40A41CCC26C0DE4D40234BE658DE4D4B40A41CCC26C0DE4D40323CF6B3584C4B404739984D80DB4D40323CF6B3584C4B40
8822	Сураманово	7	61	659	59.000045	59.010770999999998	54.026328999999997	54.018278000000002	0103000020E61000000100000005000000A0C37C7901804D403F1EFAEE56024B40A0C37C7901804D40DBF7A8BF5E034B40635FB2F160814D40DBF7A8BF5E034B40635FB2F160814D403F1EFAEE56024B40A0C37C7901804D403F1EFAEE56024B40
31502	Сулейманово	7	61	659	59.867691999999998	59.882928	54.775863999999999	54.770479000000002	0103000020E610000001000000050000001B800D8810EF4D409DA04D0E9F624B401B800D8810EF4D406612F5824F634B40815CE2C803F14D406612F5824F634B40815CE2C803F14D409DA04D0E9F624B401B800D8810EF4D409DA04D0E9F624B40
10419	Старомуйнаково	7	61	659	59.710971999999998	59.731048999999999	54.575660999999997	54.563963999999999	0103000020E61000000100000005000000942F682101DB4D40880FECF82F484B40942F682101DB4D40944A7842AF494B4002637D0393DD4D40944A7842AF494B4002637D0393DD4D40880FECF82F484B40942F682101DB4D40880FECF82F484B40
10622	Старобалбуково	7	61	659	59.670009	59.684255999999998	54.666265000000003	54.657271000000001	0103000020E610000001000000050000004983DBDAC2D54D40FBCDC47421544B404983DBDAC2D54D4017BCE82B48554B40BF0B5BB395D74D4017BCE82B48554B40BF0B5BB395D74D40FBCDC47421544B404983DBDAC2D54D40FBCDC47421544B40
10670	Старобайрамгулово	7	61	659	59.699688999999999	59.713838000000003	54.732396999999999	54.727235	0103000020E610000001000000050000007B2FBE688FD94D40D7C05609165D4B407B2FBE688FD94D402158552FBF5D4B402F52280B5FDB4D402158552FBF5D4B402F52280B5FDB4D40D7C05609165D4B407B2FBE688FD94D40D7C05609165D4B40
11523	Сайтаково	7	61	659	59.547119000000002	59.573718	54.344712000000001	54.331242000000003	0103000020E610000001000000050000009702D2FE07C64D40E4874A23662A4B409702D2FE07C64D40F644D7851F2C4B40329067976FC94D40F644D7851F2C4B40329067976FC94D40E4874A23662A4B409702D2FE07C64D40E4874A23662A4B40
9371	Рысаево	7	61	659	59.371535000000002	59.396157000000002	54.480584999999998	54.461163999999997	0103000020E61000000100000005000000E12879758EAF4D40D80B056C073B4B40E12879758EAF4D405DF92CCF833D4B406E8AC745B5B24D405DF92CCF833D4B406E8AC745B5B24D40D80B056C073B4B40E12879758EAF4D40D80B056C073B4B40
9500	Расулево	7	61	659	59.226106000000001	59.245365999999997	54.218736999999997	54.207380000000001	0103000020E61000000100000005000000F6B6990AF19C4D4018EC866D8B1A4B40F6B6990AF19C4D406BB6F292FF1B4B4071C63027689F4D406BB6F292FF1B4B4071C63027689F4D4018EC866D8B1A4B40F6B6990AF19C4D4018EC866D8B1A4B40
58592	Поляковка	7	61	659	59.684364000000002	59.716011999999999	54.636198999999998	54.625114000000004	0103000020E61000000100000005000000A647533D99D74D40C9224DBC03504B40A647533D99D74D40BB5F05F86E514B4093C5FD47A6DB4D40BB5F05F86E514B4093C5FD47A6DB4D40C9224DBC03504B40A647533D99D74D40C9224DBC03504B40
10376	Первый Май	7	61	659	59.688811000000001	59.705438000000001	54.436464999999998	54.421422999999997	0103000020E61000000100000005000000021077F52AD84D401F645930F1354B40021077F52AD84D40A06CCA15DE374B4086ADD9CA4BDA4D40A06CCA15DE374B4086ADD9CA4BDA4D401F645930F1354B40021077F52AD84D401F645930F1354B40
45770	Октябрьск	7	61	659	59.217447	59.234074	54.102105000000002	54.092041999999999	0103000020E6100000010000000500000081CEA44DD59B4D40E1ED4108C80B4B4081CEA44DD59B4D4009E1D1C6110D4B40056C0723F69D4D4009E1D1C6110D4B40056C0723F69D4D40E1ED4108C80B4B4081CEA44DD59B4D40E1ED4108C80B4B40
9975	Озерный	7	61	659	58.842903	58.859350999999997	53.955590999999998	53.948399999999999	0103000020E61000000100000005000000A359D93EE46B4D4061C3D32B65F94A40A359D93EE46B4D400CAD4ECE50FA4A407764AC36FF6D4D400CAD4ECE50FA4A407764AC36FF6D4D4061C3D32B65F94A40A359D93EE46B4D4061C3D32B65F94A40
10143	Новобайрамгулово	7	61	659	59.022314999999999	59.047099000000003	54.105457999999999	54.094909000000001	0103000020E61000000100000005000000E99AC937DB824D404C8C65FA250C4B40E99AC937DB824D40008DD2A57F0D4B4050560C5707864D40008DD2A57F0D4B4050560C5707864D404C8C65FA250C4B40E99AC937DB824D404C8C65FA250C4B40
46529	Наурузово	7	61	659	59.074857000000002	59.096604999999997	54.056449999999998	54.035642000000003	0103000020E61000000100000005000000377007EA94894D40992EC4EA8F044B40377007EA94894D40FAEDEBC039074B40A6D0798D5D8C4D40FAEDEBC039074B40A6D0798D5D8C4D40992EC4EA8F044B40377007EA94894D40992EC4EA8F044B40
9158	Мулдашево	7	61	659	59.382494000000001	59.398197000000003	54.405012999999997	54.390509000000002	0103000020E6100000010000000500000047753A90F5B04D4097E5EB32FC314B4047753A90F5B04D4038BA4A77D7334B40C32E8A1EF8B24D4038BA4A77D7334B40C32E8A1EF8B24D4097E5EB32FC314B4047753A90F5B04D4097E5EB32FC314B40
58496	Москово	7	61	659	59.093559999999997	59.111634000000002	53.986986000000002	53.973377999999997	0103000020E610000001000000050000005C1B2AC6F98B4D40AC527AA697FC4A405C1B2AC6F98B4D4010CEA78E55FE4A40938FDD054A8E4D4010CEA78E55FE4A40938FDD054A8E4D40AC527AA697FC4A405C1B2AC6F98B4D40AC527AA697FC4A40
9838	Миндяк	7	61	659	58.774065	58.831125999999998	54.063853999999999	54.002273000000002	0103000020E6100000010000000500000037FDD98F14634D40F8544E7B4A004B4037FDD98F14634D4001DC2C5E2C084B407A6D3656626A4D4001DC2C5E2C084B407A6D3656626A4D40F8544E7B4A004B4037FDD98F14634D40F8544E7B4A004B40
32736	Мансурово	7	61	659	59.520798999999997	59.531326999999997	54.489638999999997	54.481442999999999	0103000020E610000001000000050000000E65A88AA9C24D40AEF199EC9F3D4B400E65A88AA9C24D404EECA17DAC3E4B40AB3DEC8502C44D404EECA17DAC3E4B40AB3DEC8502C44D40AEF199EC9F3D4B400E65A88AA9C24D40AEF199EC9F3D4B40
8900	Малоказаккулово	7	61	659	58.938330999999998	58.950243	54.058326000000001	54.051777999999999	0103000020E6100000010000000500000057E9EE3A1B784D407E5358A9A0064B4057E9EE3A1B784D40D540F33977074B4060200890A1794D40D540F33977074B4060200890A1794D407E5358A9A0064B4057E9EE3A1B784D407E5358A9A0064B40
46100	Кучуково	7	61	659	59.904998999999997	59.918716000000003	54.841101999999999	54.832670999999998	0103000020E61000000100000005000000D3F4D901D7F34D40EFA99CF6946A4B40D3F4D901D7F34D40D34CF73AA96B4B40EE27637C98F54D40D34CF73AA96B4B40EE27637C98F54D40EFA99CF6946A4B40D3F4D901D7F34D40EFA99CF6946A4B40
10576	Курамино	7	61	659	59.807423999999997	59.818204000000001	54.643441000000003	54.630842000000001	0103000020E61000000100000005000000B4006DAB59E74D40BC783F6EBF504B40B4006DAB59E74D40E9F351465C524B406BBA9EE8BAE84D40E9F351465C524B406BBA9EE8BAE84D40BC783F6EBF504B40B4006DAB59E74D40BC783F6EBF504B40
9615	Кунакбаево	7	61	659	59.299641999999999	59.320861000000001	54.345483000000002	54.335106000000003	0103000020E61000000100000005000000074147AB5AA64D40C158DFC0E42A4B40074147AB5AA64D40782975C9382C4B40EBC726F911A94D40782975C9382C4B40EBC726F911A94D40C158DFC0E42A4B40074147AB5AA64D40C158DFC0E42A4B40
46243	Кудашево	7	61	659	59.263764000000002	59.275047000000001	54.218246999999998	54.211596999999998	0103000020E610000001000000050000005BEECC04C3A14D404277499C151B4B405BEECC04C3A14D409DB98784EF1B4B4074EE76BD34A34D409DB98784EF1B4B4074EE76BD34A34D404277499C151B4B405BEECC04C3A14D404277499C151B4B40
9917	Кубагушево	7	61	659	58.709350000000001	58.726095000000001	53.937223000000003	53.925905	0103000020E6100000010000000500000074B515FBCB5A4D40F819170E84F64A4074B515FBCB5A4D408E075BECF6F74A40026553AEF05C4D408E075BECF6F74A40026553AEF05C4D40F819170E84F64A4074B515FBCB5A4D40F819170E84F64A40
46686	Комсомольск	7	61	659	59.722999999999999	59.745054000000003	54.623029000000002	54.612257999999997	0103000020E61000000100000005000000068195438BDC4D40705B5B785E4E4B40068195438BDC4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40705B5B785E4E4B40068195438BDC4D40705B5B785E4E4B40
7183	Кирябинское	7	61	659	59.254196999999998	59.274884999999998	54.560423999999998	54.543014999999997	0103000020E61000000100000005000000E3DEFC8689A04D40641EF98381454B40E3DEFC8689A04D405EF23FF9BB474B409A94826E2FA34D405EF23FF9BB474B409A94826E2FA34D40641EF98381454B40E3DEFC8689A04D40641EF98381454B40
9124	Каримово	7	61	659	59.806265000000003	59.828130000000002	54.706178000000001	54.683684	0103000020E61000000100000005000000697407B133E74D40346612F582574B40697407B133E74D40CD936B0A645A4B40126BF12900EA4D40CD936B0A645A4B40126BF12900EA4D40346612F582574B40697407B133E74D40346612F582574B40
11134	Калканово	7	61	659	59.299948000000001	59.319944	54.414141000000001	54.406379999999999	0103000020E61000000100000005000000144031B264A64D40CEDF844204344B40144031B264A64D406477819202354B409546CCECF3A84D406477819202354B409546CCECF3A84D40CEDF844204344B40144031B264A64D40CEDF844204344B40
10704	Кажаево	7	61	659	59.601827	59.610827999999998	54.692698	54.686197999999997	0103000020E61000000100000005000000C66CC9AA08CD4D40514A0856D5574B40C66CC9AA08CD4D409700FC53AA584B4094BDA59C2FCE4D409700FC53AA584B4094BDA59C2FCE4D40514A0856D5574B40C66CC9AA08CD4D40514A0856D5574B40
10769	Ишмекеево	7	61	659	59.107277000000003	59.128360999999998	54.206226000000001	54.198726999999998	0103000020E61000000100000005000000774EB340BB8D4D4085EAE6E26F194B40774EB340BB8D4D40DECA129D651A4B407A8A1C226E904D40DECA129D651A4B407A8A1C226E904D4085EAE6E26F194B40774EB340BB8D4D4085EAE6E26F194B40
10980	Ишкиново	7	61	659	59.163089999999997	59.178584999999998	54.172809999999998	54.162331000000002	0103000020E61000000100000005000000FE261422E0944D4041102043C7144B40FE261422E0944D40FC3559A31E164B4030478FDFDB964D40FC3559A31E164B4030478FDFDB964D4041102043C7144B40FE261422E0944D4041102043C7144B40
10956	Истамгулово	7	61	659	59.155327999999997	59.176653999999999	54.144303000000001	54.135579	0103000020E610000001000000050000009813B4C9E1934D401F8315A75A114B409813B4C9E1934D407BDB4C8578124B40925A28999C964D407BDB4C8578124B40925A28999C964D401F8315A75A114B409813B4C9E1934D401F8315A75A114B40
58289	Имангулово	7	61	659	59.301519999999996	59.330823000000002	54.281540999999997	54.266441999999998	0103000020E61000000100000005000000828B153598A64D40F2237EC51A224B40828B153598A64D40D7BD158909244B40DFE1766858AA4D40D7BD158909244B40DFE1766858AA4D40F2237EC51A224B40828B153598A64D40F2237EC51A224B40
9347	Ильчино	7	61	659	59.521652000000003	59.545377000000002	54.430934999999998	54.409745000000001	0103000020E610000001000000050000004EF2237EC5C24D408A592F8672344B404EF2237EC5C24D40D3D9C9E028374B40CC7EDDE9CEC54D40D3D9C9E028374B40CC7EDDE9CEC54D408A592F8672344B404EF2237EC5C24D408A592F8672344B40
32626	Ильчигулово	7	61	659	59.799824000000001	59.809769000000003	54.759180999999998	54.756126000000002	0103000020E61000000100000005000000284701A260E64D40E1D39CBCC8604B40284701A260E64D404E5FCFD72C614B404628B682A6E74D404E5FCFD72C614B404628B682A6E74D40E1D39CBCC8604B40284701A260E64D40E1D39CBCC8604B40
46605	Вознесенка	7	61	659	59.572038999999997	59.601782	54.651817999999999	54.638893000000003	0103000020E61000000100000005000000AD84EE9238C94D405952EE3EC7514B40AD84EE9238C94D40D978B0C56E534B4026A94C3107CD4D40D978B0C56E534B4026A94C3107CD4D405952EE3EC7514B40AD84EE9238C94D405952EE3EC7514B40
9150	Буйда	7	61	659	59.487175000000001	59.5154	54.258505999999997	54.247013000000003	0103000020E61000000100000005000000E3361AC05BBE4D40EB573A1F9E1F4B40E3361AC05BBE4D40EEE87FB916214B40E02D90A0F8C14D40EEE87FB916214B40E02D90A0F8C14D40EB573A1F9E1F4B40E3361AC05BBE4D40EB573A1F9E1F4B40
4468	Батталово	7	61	659	58.865388000000003	58.881827000000001	53.887591999999998	53.880974000000002	0103000020E61000000100000005000000E92CB308C56E4D402B508BC1C3F04A40E92CB308C56E4D407A185A9D9CF14A406ADD06B5DF704D407A185A9D9CF14A406ADD06B5DF704D402B508BC1C3F04A40E92CB308C56E4D402B508BC1C3F04A40
8920	Ахуново	7	61	659	59.585864000000001	59.630896	54.221637000000001	54.198836999999997	0103000020E61000000100000005000000AEF36F97FDCA4D400C1EA67D73194B40AEF36F97FDCA4D40B24AE9995E1C4B40AF963B33C1D04D40B24AE9995E1C4B40AF963B33C1D04D400C1EA67D73194B40AEF36F97FDCA4D400C1EA67D73194B40
47810	Аслаево	7	61	659	58.925897999999997	58.935681000000002	53.92221	53.915008	0103000020E6100000010000000500000045B75ED383764D4008CA6DFB1EF54A4045B75ED383764D40A7052FFA0AF64A408A3E1F65C4774D40A7052FFA0AF64A408A3E1F65C4774D4008CA6DFB1EF54A4045B75ED383764D4008CA6DFB1EF54A40
9745	Абзаково	7	61	659	59.545628000000001	59.562939	54.586916000000002	54.579996999999999	0103000020E6100000010000000500000015E46723D7C54D40996379573D4A4B4015E46723D7C54D40E4BF4010204B4B404C5299620EC84D40E4BF4010204B4B404C5299620EC84D40996379573D4A4B4015E46723D7C54D40996379573D4A4B40
58260	санаторий Юматово	7	61	284	55.622326000000001	55.643130999999997	54.622022999999999	54.605620000000002	0103000020E61000000100000005000000AAB9DC60A8CF4B40DAE6C6F4844D4B40AAB9DC60A8CF4B400E2E1D739E4F4B409A05DA1D52D24B400E2E1D739E4F4B409A05DA1D52D24B40DAE6C6F4844D4B40AAB9DC60A8CF4B40DAE6C6F4844D4B40
45892	Юматово	7	61	284	55.671886000000001	55.703740000000003	54.632192000000003	54.615094999999997	0103000020E61000000100000005000000F451465C00D64B407077D66EBB4E4B40F451465C00D64B407C65DEAAEB504B408B71FE2614DA4B407C65DEAAEB504B408B71FE2614DA4B407077D66EBB4E4B40F451465C00D64B407077D66EBB4E4B40
8641	Шемяк	7	61	284	55.482683000000002	55.507854000000002	54.797860999999997	54.781632999999999	0103000020E61000000100000005000000E7AA798EC8BD4B40B83CD68C0C644B40E7AA798EC8BD4B407EE02A4F20664B404792205C01C14B407EE02A4F20664B404792205C01C14B40B83CD68C0C644B40E7AA798EC8BD4B40B83CD68C0C644B40
58546	Чуварез	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
58137	Чесноковка	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
7731	Чернолесовский	7	61	284	55.808079999999997	55.826495000000001	54.867674000000001	54.84966	0103000020E610000001000000050000009D465A2A6FE74B40145CACA8C16C4B409D465A2A6FE74B4075CB0EF10F6F4B405DA79196CAE94B4075CB0EF10F6F4B405DA79196CAE94B40145CACA8C16C4B409D465A2A6FE74B40145CACA8C16C4B40
58636	Черкасы	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
7377	Сергеевка	7	61	284	55.732872999999998	55.758060999999998	54.710796999999999	54.696756000000001	0103000020E610000001000000050000008A8F4FC8CEDD4B4059A5F44C2F594B408A8F4FC8CEDD4B40268C6665FB5A4B40C0AF912408E14B40268C6665FB5A4B40C0AF912408E14B4059A5F44C2F594B408A8F4FC8CEDD4B4059A5F44C2F594B40
58168	Русский Юрмаш	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
7167	Подымалово	7	61	284	55.714035000000003	55.763164000000003	54.874811999999999	54.859938	0103000020E610000001000000050000008599B67F65DB4B40384BC972126E4B408599B67F65DB4B40FD12F1D6F96F4B4006BEA25BAFE14B40FD12F1D6F96F4B4006BEA25BAFE14B40384BC972126E4B408599B67F65DB4B40384BC972126E4B40
8627	Первомайский	7	61	284	55.421768	55.441253000000003	54.782874	54.772686	0103000020E61000000100000005000000EA3F6B7EFCB54B40DD09F65FE7624B40EA3F6B7EFCB54B40C171193735644B40862172FA7AB84B40C171193735644B40862172FA7AB84B40DD09F65FE7624B40EA3F6B7EFCB54B40DD09F65FE7624B40
58195	Ольховое	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
8479	Октябрьский	7	61	284	55.465615	55.500397999999997	54.769778000000002	54.753788	0103000020E6100000010000000500000076C3B64599BB4B40020F0C207C604B4076C3B64599BB4B401497E31588624B40ED7DAA0A0DC04B401497E31588624B40ED7DAA0A0DC04B40020F0C207C604B4076C3B64599BB4B40020F0C207C604B40
8001	Нурлино	7	61	284	55.554215999999997	55.584498000000004	54.822034000000002	54.806230999999997	0103000020E61000000100000005000000C075C58CF0C64B40BC02D19332674B40C075C58CF0C64B409C19FD6838694B40E94999D4D0CA4B409C19FD6838694B40E94999D4D0CA4B40BC02D19332674B40C075C58CF0C64B40BC02D19332674B40
8559	Новотроевка	7	61	284	55.413504000000003	55.430562999999999	54.730817000000002	54.718910000000001	0103000020E61000000100000005000000F261F6B2EDB44B4039622D3E055C4B40F261F6B2EDB44B40302E55698B5D4B400FEF39B01CB74B40302E55698B5D4B400FEF39B01CB74B4039622D3E055C4B40F261F6B2EDB44B4039622D3E055C4B40
7993	Николаевка	7	61	284	55.682181	55.704808999999997	54.824601000000001	54.814298999999998	0103000020E61000000100000005000000EE79FEB451D74B402F151BF33A684B40EE79FEB451D74B40DC9F8B868C694B4096766A2E37DA4B40DC9F8B868C694B4096766A2E37DA4B402F151BF33A684B40EE79FEB451D74B402F151BF33A684B40
58134	Нижегородка	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
58152	Михайловка	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
58321	Мармылево	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
1203	Кумлекуль	7	61	284	55.857405999999997	55.883555999999999	54.953721000000002	54.941471999999997	0103000020E6100000010000000500000074B2D47ABFED4B40C30C8D2782784B4074B2D47ABFED4B4014419C87137A4B40A017EE5C18F14B4014419C87137A4B40A017EE5C18F14B40C30C8D2782784B4074B2D47ABFED4B40C30C8D2782784B40
7650	Красный Яр	7	61	284	55.891182999999998	55.931660999999998	54.897841999999997	54.886549000000002	0103000020E6100000010000000500000026E0D74812F24B4098A608707A714B4026E0D74812F24B40D47C957CEC724B40B5FAEAAA40F74B40D47C957CEC724B40B5FAEAAA40F74B4098A608707A714B4026E0D74812F24B4098A608707A714B40
58123	Жуково	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
58139	Дмитриевка	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
7267	Волково	7	61	284	55.610791999999996	55.624760000000002	54.905771999999999	54.885289999999998	0103000020E610000001000000050000004754A86E2ECE4B40E8BCC62E51714B404754A86E2ECE4B40F6D03E56F0734B40ABECBB22F8CF4B40F6D03E56F0734B40ABECBB22F8CF4B40E8BCC62E51714B404754A86E2ECE4B40E8BCC62E51714B40
8543	Бейгулово	7	61	284	55.484003000000001	55.509712999999998	54.728606999999997	54.715701000000003	0103000020E610000001000000050000003C1570CFF3BD4B40755B22179C5B4B403C1570CFF3BD4B407E5182FE425D4B404BAC8C463EC14B407E5182FE425D4B404BAC8C463EC14B40755B22179C5B4B403C1570CFF3BD4B40755B22179C5B4B40
7567	Асаново	7	61	284	55.473897000000001	55.495924000000002	54.901994000000002	54.887397999999997	0103000020E6100000010000000500000015562AA8A8BC4B409544F64196714B4015562AA8A8BC4B401898158A74734B4098A608707ABF4B401898158A74734B4098A608707ABF4B409544F64196714B4015562AA8A8BC4B409544F64196714B40
58098	Алексеевка	7	61	284	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
6717	Авдон	7	61	284	55.706543000000003	55.724896000000001	54.673178999999998	54.665703000000001	0103000020E61000000100000005000000DF1B430070DA4B40AFEC82C135554B40DF1B430070DA4B404FADBEBA2A564B4028806264C9DC4B404FADBEBA2A564B4028806264C9DC4B40AFEC82C135554B40DF1B430070DA4B40AFEC82C135554B40
13131	совхоза Имени 1-го Мая	7	61	308	53.983699999999999	53.998136000000002	54.542822000000001	54.535069999999997	0103000020E61000000100000005000000A089B0E1E9FD4A400D897B2C7D444B40A089B0E1E9FD4A4050C6F8307B454B40EA7AA2EBC2FF4A4050C6F8307B454B40EA7AA2EBC2FF4A400D897B2C7D444B40A089B0E1E9FD4A400D897B2C7D444B40
4343	Япрыково	7	61	308	53.514645000000002	53.541567000000001	54.608660999999998	54.598429000000003	0103000020E6100000010000000500000064062AE3DFC14A402FFD4B52994C4B4064062AE3DFC14A40E2AC889AE84D4B40E2CB441152C54A40E2AC889AE84D4B40E2CB441152C54A402FFD4B52994C4B4064062AE3DFC14A402FFD4B52994C4B40
5010	Чукадытамак	7	61	308	54.092100000000002	54.111700999999996	54.362499999999997	54.346285999999999	0103000020E6100000010000000500000016FBCBEEC90B4B4005888219532C4B4016FBCBEEC90B4B4066666666662E4B401AF7E6374C0E4B4066666666662E4B401AF7E6374C0E4B4005888219532C4B4016FBCBEEC90B4B4005888219532C4B40
6156	Чуваш-Улканово	7	61	308	53.844056999999999	53.862634	54.636432999999997	54.633234000000002	0103000020E61000000100000005000000DD7A4D0F0AEC4A408E5BCCCF0D514B40DD7A4D0F0AEC4A402E8CF4A276514B40763579CA6AEE4A402E8CF4A276514B40763579CA6AEE4A408E5BCCCF0D514B40DD7A4D0F0AEC4A408E5BCCCF0D514B40
58556	Фрунзе	7	61	308	53.718786999999999	53.737561999999997	54.341825	54.33466	0103000020E610000001000000050000001DE5603601DC4A40C2A38D23D62A4B401DE5603601DC4A4044FAEDEBC02B4B40DC627E6E68DE4A4044FAEDEBC02B4B40DC627E6E68DE4A40C2A38D23D62A4B401DE5603601DC4A40C2A38D23D62A4B40
5309	Уязытамак	7	61	308	53.404260000000001	53.434722000000001	54.377495000000003	54.364545999999997	0103000020E610000001000000050000005D8AABCABEB34A409DF17D71A92E4B405D8AABCABEB34A40A7B393C151304B40056D72F8A4B74A40A7B393C151304B40056D72F8A4B74A409DF17D71A92E4B405D8AABCABEB34A409DF17D71A92E4B40
5663	Урмекеево	7	61	308	54.209347999999999	54.229371	54.551600999999998	54.537796999999998	0103000020E61000000100000005000000D3BD4EEACB1A4B4086713788D6444B40D3BD4EEACB1A4B406FB88FDC9A464B404ED367075C1D4B406FB88FDC9A464B404ED367075C1D4B4086713788D6444B40D3BD4EEACB1A4B4086713788D6444B40
3858	Туктагулово	7	61	308	54.045917000000003	54.079425000000001	54.655042000000002	54.637459999999997	0103000020E610000001000000050000004CAAB69BE0054B400B410E4A98514B404CAAB69BE0054B40D3C08F6AD8534B400EBE30992A0A4B40D3C08F6AD8534B400EBE30992A0A4B400B410E4A98514B404CAAB69BE0054B400B410E4A98514B40
2300	Туймазы	7	61	308	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
6364	Тирян-Елга	7	61	308	53.913308000000001	53.942836	54.697338999999999	54.683320000000002	0103000020E610000001000000050000006C96CB46E7F44A40F3599E0777574B406C96CB46E7F44A40D89C836742594B40E8BE9CD9AEF84A40D89C836742594B40E8BE9CD9AEF84A40F3599E0777574B406C96CB46E7F44A40F3599E0777574B40
6091	Татар-Улканово	7	61	308	53.882047	53.906427000000001	54.632040000000003	54.616210000000002	0103000020E61000000100000005000000784485EAE6F04A40EDBB22F8DF4E4B40784485EAE6F04A40C6E1CCAFE6504B400F9BC8CC05F44A40C6E1CCAFE6504B400F9BC8CC05F44A40EDBB22F8DF4E4B40784485EAE6F04A40EDBB22F8DF4E4B40
49199	Субханкулово	7	61	308	53.790498999999997	53.822038999999997	54.560617999999998	54.552165000000002	0103000020E61000000100000005000000A6423C122FE54A40787FBC57AD464B40A6423C122FE54A4043C6A354C2474B40AD84EE9238E94A4043C6A354C2474B40AD84EE9238E94A40787FBC57AD464B40A6423C122FE54A40787FBC57AD464B40
5887	Старые Туймазы	7	61	308	53.594900000000003	53.621462999999999	54.554707000000001	54.538736999999998	0103000020E61000000100000005000000F931E6AE25CC4A4094128255F5444B40F931E6AE25CC4A405FEE93A300474B4047567E198CCF4A405FEE93A300474B4047567E198CCF4A4094128255F5444B40F931E6AE25CC4A4094128255F5444B40
4711	Старые Кандры	7	61	308	54.035694999999997	54.066676999999999	54.549610999999999	54.538048000000003	0103000020E61000000100000005000000BBD05CA791044B40D0D6C1C1DE444B40BBD05CA791044B40CC423BA759464B409C3237DF88084B40CC423BA759464B409C3237DF88084B40D0D6C1C1DE444B40BBD05CA791044B40D0D6C1C1DE444B40
5758	Серафимовский	7	61	308	53.784885000000003	53.81541	54.430039000000001	54.418405	0103000020E610000001000000050000007C0F971C77E44A40CFBD874B8E354B407C0F971C77E44A40958098840B374B406A6AD95A5FE84A40958098840B374B406A6AD95A5FE84A40CFBD874B8E354B407C0F971C77E44A40CFBD874B8E354B40
5636	Сайраново	7	61	308	54.180250999999998	54.207614	54.487113000000001	54.469081000000003	0103000020E610000001000000050000002009FB7612174B406616A1D80A3C4B402009FB7612174B406D3A02B8593E4B408B187618931A4B406D3A02B8593E4B408B187618931A4B406616A1D80A3C4B402009FB7612174B406616A1D80A3C4B40
6587	Райманово	7	61	308	53.698861999999998	53.717089000000001	54.640216000000002	54.627084000000004	0103000020E6100000010000000500000065355D4F74D94A4025ECDB4944504B4065355D4F74D94A401F300F99F2514B4022A98592C9DB4A401F300F99F2514B4022A98592C9DB4A4025ECDB4944504B4065355D4F74D94A4025ECDB4944504B40
6061	Нуркеево	7	61	308	53.789726999999999	53.801431999999998	54.577523999999997	54.568165999999998	0103000020E6100000010000000500000054E23AC615E54A407D59DAA9B9484B4054E23AC615E54A40DA53724EEC494B40E3FBE25295E64A40DA53724EEC494B40E3FBE25295E64A407D59DAA9B9484B4054E23AC615E54A407D59DAA9B9484B40
58720	Никитинка	7	61	308	53.864026000000003	53.879756	54.526313999999999	54.512836999999998	0103000020E6100000010000000500000065726A6798EE4A40E1968FA4A4414B4065726A6798EE4A40A6B6D4415E434B40DA3A38D89BF04A40A6B6D4415E434B40DA3A38D89BF04A40E1968FA4A4414B4065726A6798EE4A40E1968FA4A4414B40
58775	Нижний Сардык	7	61	308	53.384163999999998	54.355513000000002	54.797055999999998	54.265000999999998	0103000020E61000000100000005000000782634492CB14A402234828DEB214B40782634492CB14A40508A56EE05664B40C4263273812D4B40508A56EE05664B40C4263273812D4B402234828DEB214B40782634492CB14A402234828DEB214B40
58278	Нижнии Бишинды	7	61	308	53.729486000000001	53.752096000000002	54.498413999999997	54.480826	0103000020E61000000100000005000000E77118CC5FDD4A408388D4B48B3D4B40E77118CC5FDD4A402CEFAA07CC3F4B40E9B985AE44E04A402CEFAA07CC3F4B40E9B985AE44E04A408388D4B48B3D4B40E77118CC5FDD4A408388D4B48B3D4B40
5342	Нижнетроицкий	7	61	308	53.659461999999998	53.714528999999999	54.350757000000002	54.330832999999998	0103000020E61000000100000005000000357A354069D44A4002B859BC582A4B40357A354069D44A40EAEBF99AE52C4B409485AFAF75DB4A40EAEBF99AE52C4B409485AFAF75DB4A4002B859BC582A4B40357A354069D44A4002B859BC582A4B40
5022	Метевтамак	7	61	308	54.110658999999998	54.134860000000003	54.315851000000002	54.30171	0103000020E610000001000000050000000801F9122A0E4B402670EB6E9E264B400801F9122A0E4B4057B439CE6D284B40F0C4AC1743114B4057B439CE6D284B40F0C4AC1743114B402670EB6E9E264B400801F9122A0E4B402670EB6E9E264B40
30197	Киска-Елга	7	61	308	53.832926999999998	53.847487999999998	54.639350999999998	54.634714000000002	0103000020E610000001000000050000004A7A185A9DEA4A401C28F04E3E514B404A7A185A9DEA4A401BD5E940D6514B4050E09D7C7AEC4A401BD5E940D6514B4050E09D7C7AEC4A401C28F04E3E514B404A7A185A9DEA4A401C28F04E3E514B40
5571	Кендектамак	7	61	308	53.913739	53.929900000000004	54.484869000000003	54.469771999999999	0103000020E61000000100000005000000350A4966F5F44A40CB49287D213C4B40350A4966F5F44A4010ECF82F103E4B40744694F606F74A4010ECF82F103E4B40744694F606F74A40CB49287D213C4B40350A4966F5F44A40CB49287D213C4B40
5229	Каратово	7	61	308	53.417222000000002	53.435367999999997	54.345697999999999	54.335290000000001	0103000020E61000000100000005000000FB95CE8767B54A40825660C8EA2A4B40FB95CE8767B54A40742502D53F2C4B40CADC7C23BAB74A40742502D53F2C4B40CADC7C23BAB74A40825660C8EA2A4B40FB95CE8767B54A40825660C8EA2A4B40
4921	Карамалы-Губеево	7	61	308	54.043734000000001	54.072130000000001	54.361224999999997	54.340806999999998	0103000020E6100000010000000500000094DC611399054B40BA9F53909F2B4B4094DC611399054B40B1BFEC9E3C2E4B40BE874B8E3B094B40B1BFEC9E3C2E4B40BE874B8E3B094B40BA9F53909F2B4B4094DC611399054B40BA9F53909F2B4B40
5507	Кандрыкуль	7	61	308	53.999268000000001	54.039161999999997	54.502361000000001	54.485444000000001	0103000020E610000001000000050000003CF88903E8FF4A400C056C07233E4B403CF88903E8FF4A4097E4805D4D404B407B9FAA4203054B4097E4805D4D404B407B9FAA4203054B400C056C07233E4B403CF88903E8FF4A400C056C07233E4B40
4790	Кандры-Кутуй	7	61	308	54.084904000000002	54.119435000000003	54.519092999999998	54.507112999999997	0103000020E6100000010000000500000059A65F22DE0A4B402F302B14E9404B4059A65F22DE0A4B40904AB1A371424B40B77F65A5490F4B40904AB1A371424B40B77F65A5490F4B402F302B14E9404B4059A65F22DE0A4B402F302B14E9404B40
4490	Кандры	7	61	308	54.083556999999999	54.135767000000001	54.565102000000003	54.536130999999997	0103000020E610000001000000050000000A2DEBFEB10A4B4096AFCBF09F444B400A2DEBFEB10A4B40BD73284355484B40227024D060114B40BD73284355484B40227024D060114B4096AFCBF09F444B400A2DEBFEB10A4B4096AFCBF09F444B40
5097	Кальшали	7	61	308	54.057172999999999	54.094138999999998	54.321413	54.304758	0103000020E610000001000000050000006B9BE27151074B40E198654F02274B406B9BE27151074B402FC1A90F24294B409A232BBF0C0C4B402FC1A90F24294B409A232BBF0C0C4B40E198654F02274B406B9BE27151074B40E198654F02274B40
4372	Какрыбашево	7	61	308	53.642654999999998	53.659157	54.705537999999997	54.691510999999998	0103000020E6100000010000000500000031CEDF8442D24A4081E9B46E83584B4031CEDF8442D24A40E90AB6114F5A4B40F9F6AE415FD44A40E90AB6114F5A4B40F9F6AE415FD44A4081E9B46E83584B4031CEDF8442D24A4081E9B46E83584B40
4264	Ильчимбетово	7	61	308	53.561428999999997	53.587462000000002	54.645432	54.632337999999997	0103000020E610000001000000050000005303CDE7DCC74A404F029B73F0504B405303CDE7DCC74A405CE509849D524B4046D26EF431CB4A405CE509849D524B4046D26EF431CB4A404F029B73F0504B405303CDE7DCC74A404F029B73F0504B40
4825	Ермухаметово	7	61	308	54.156491000000003	54.192324999999997	54.595512999999997	54.572032999999998	0103000020E61000000100000005000000268FA7E507144B40CB9D996038494B40268FA7E507144B40E2AB1DC5394C4B40029A081B9E184B40E2AB1DC5394C4B40029A081B9E184B40CB9D996038494B40268FA7E507144B40CB9D996038494B40
3902	Ермyнчино	7	61	308	54.222158	54.260596999999997	54.655417	54.639116999999999	0103000020E61000000100000005000000BB4560AC6F1C4B40A8A8FA95CE514B40BB4560AC6F1C4B40081F4AB4E4534B40C537143E5B214B40081F4AB4E4534B40C537143E5B214B40A8A8FA95CE514B40BB4560AC6F1C4B40A8A8FA95CE514B40
1381	Дуслык	7	61	308	53.769145999999999	53.785541000000002	54.554211000000002	54.544325999999998	0103000020E61000000100000005000000B3EC496073E24A40662E7079AC454B40B3EC496073E24A40AF0AD462F0464B406555849B8CE44A40AF0AD462F0464B406555849B8CE44A40662E7079AC454B40B3EC496073E24A40662E7079AC454B40
4222	Гафурово	7	61	308	53.682817999999997	53.709677999999997	54.532124000000003	54.517760000000003	0103000020E61000000100000005000000608F899466D74A40A796ADF545424B40608F899466D74A4057B5A4A31C444B4068588CBAD6DA4A4057B5A4A31C444B4068588CBAD6DA4A40A796ADF545424B40608F899466D74A40A796ADF545424B40
6298	Верхний Сардык	7	61	308	53.955331000000001	53.974079000000003	54.649250000000002	54.635187999999999	0103000020E6100000010000000500000070ED444948FA4A40E46723D74D514B4070ED444948FA4A40C976BE9F1A534B40365CE49EAEFC4A40C976BE9F1A534B40365CE49EAEFC4A40E46723D74D514B4070ED444948FA4A40E46723D74D514B40
3947	Верхние Бишинды	7	61	308	53.693697	53.722712999999999	54.486469999999997	54.469425999999999	0103000020E61000000100000005000000AA2A3410CBD84A4030F2B226163C4B40AA2A3410CBD84A40183E22A6443E4B4070B20DDC81DC4A40183E22A6443E4B4070B20DDC81DC4A4030F2B226163C4B40AA2A3410CBD84A4030F2B226163C4B40
4119	Верхнетроицкое	7	61	308	53.757837000000002	53.808008000000001	54.353554000000003	54.337941000000001	0103000020E61000000100000005000000715985CD00E14A40207D93A6412B4B40715985CD00E14A405CAFE941412D4B4004745FCE6CE74A405CAFE941412D4B4004745FCE6CE74A40207D93A6412B4B40715985CD00E14A40207D93A6412B4B40
58555	Бишкураево	7	61	308	54.164144999999998	54.203086999999996	54.680222999999998	54.65699	0103000020E61000000100000005000000A5660FB402154B4047E6913F18544B40A5660FB402154B40567E198C11574B40129F3BC1FE194B40567E198C11574B40129F3BC1FE194B4047E6913F18544B40A5660FB402154B4047E6913F18544B40
6206	Аднагулово	7	61	308	53.877609	53.909823000000003	54.593389999999999	54.583232000000002	0103000020E610000001000000050000006FD6E07D55F04A4087FD9E58A74A4B406FD6E07D55F04A4000E31934F44B4B4006137F1475F44A4000E31934F44B4B4006137F1475F44A4087FD9E58A74A4B406FD6E07D55F04A4087FD9E58A74A4B40
6471	Агиртамак	7	61	308	53.764088999999998	53.771867999999998	54.628757	54.621752000000001	0103000020E61000000100000005000000DE1D19ABCDE14A407E1CCD91954F4B40DE1D19ABCDE14A40C710001C7B504B401A6A1492CCE24A40C710001C7B504B401A6A1492CCE24A407E1CCD91954F4B40DE1D19ABCDE14A407E1CCD91954F4B40
2194	Аблаево	7	61	308	53.631982999999998	53.660603000000002	54.775396999999998	54.758875000000003	0103000020E610000001000000050000006150A6D1E4D04A404260E5D022614B406150A6D1E4D04A4050357A3540634B40DB519CA38ED44A4050357A3540634B40DB519CA38ED44A404260E5D022614B406150A6D1E4D04A404260E5D022614B40
2130	Ялгыз-Нарат	7	61	102	55.728264000000003	55.759318999999998	56.146157000000002	56.131782000000001	0103000020E61000000100000005000000556D37C137DD4B40CA198A3BDE104C40556D37C137DD4B406E8AC745B5124C409F1D705D31E14B406E8AC745B5124C409F1D705D31E14B40CA198A3BDE104C40556D37C137DD4B40CA198A3BDE104C40
142	Юда	7	61	102	55.883502	55.902951000000002	56.362386999999998	56.351613999999998	0103000020E61000000100000005000000ADF9F19716F14B406A6803B0012D4C40ADF9F19716F14B406EBF7CB2622E4C40FC71FBE593F34B406EBF7CB2622E4C40FC71FBE593F34B406A6803B0012D4C40ADF9F19716F14B406A6803B0012D4C40
1944	Шулганово	7	61	102	55.481515000000002	55.518849000000003	56.162365999999999	56.144405999999996	0103000020E6100000010000000500000048C49448A2BD4B404FAC53E57B124C4048C49448A2BD4B40BDFDB968C8144C40FA47DFA469C24B40BDFDB968C8144C40FA47DFA469C24B404FAC53E57B124C4048C49448A2BD4B404FAC53E57B124C40
32227	Чургулды	7	61	102	55.635953000000001	55.661034000000001	56.147019	56.131756000000003	0103000020E6100000010000000500000084656CE866D14B40A1866F61DD104C4084656CE866D14B400072C284D1124C40A4C519C39CD44B400072C284D1124C40A4C519C39CD44B40A1866F61DD104C4084656CE866D14B40A1866F61DD104C40
1887	Уразгильды	7	61	102	55.863163999999998	55.885362000000001	56.261857999999997	56.247456	0103000020E61000000100000005000000D28A6F287CEE4B40789961A3AC1F4C40D28A6F287CEE4B4015191D9084214C40828FC18A53F14B4015191D9084214C40828FC18A53F14B40789961A3AC1F4C40D28A6F287CEE4B40789961A3AC1F4C40
58792	Старый Шардак	7	61	102	55.324354999999997	56.204982000000001	56.455936000000001	56.069203000000002	0103000020E61000000100000005000000A4A5F27684A94B407EE4D6A4DB084C40A4A5F27684A94B40D788601C5C3A4C406422A5D93C1A4C40D788601C5C3A4C406422A5D93C1A4C407EE4D6A4DB084C40A4A5F27684A94B407EE4D6A4DB084C40
58762	Старый Сикияз	7	61	102	55.324354999999997	56.204982000000001	56.455936000000001	56.069203000000002	0103000020E61000000100000005000000A4A5F27684A94B407EE4D6A4DB084C40A4A5F27684A94B40D788601C5C3A4C406422A5D93C1A4C40D788601C5C3A4C406422A5D93C1A4C407EE4D6A4DB084C40A4A5F27684A94B407EE4D6A4DB084C40
1205	Старый Курдым	7	61	102	55.474041	55.499526000000003	56.259887999999997	56.243724999999998	0103000020E6100000010000000500000048FB1F60ADBC4B40DA1B7C61321F4C4048FB1F60ADBC4B40B94F8E0244214C4038C0CC77F0BF4B40B94F8E0244214C4038C0CC77F0BF4B40DA1B7C61321F4C4048FB1F60ADBC4B40DA1B7C61321F4C40
58803	Староый Кызыл-Яр	7	61	102	56.146375999999997	56.164163000000002	56.249791999999999	56.238621999999999	0103000020E61000000100000005000000AB75E272BC124C40950D6B2A8B1E4C40AB75E272BC124C40B6662B2FF91F4C404C1B0E4B03154C40B6662B2FF91F4C404C1B0E4B03154C40950D6B2A8B1E4C40AB75E272BC124C40950D6B2A8B1E4C40
215	Старочукурово	7	61	102	55.656956000000001	55.675713000000002	56.335929	56.327845000000003	0103000020E610000001000000050000009B745B2217D44B401D9430D3F6294C409B745B2217D44B409563B2B8FF2A4C40B43D7AC37DD64B409563B2B8FF2A4C40B43D7AC37DD64B401D9430D3F6294C409B745B2217D44B401D9430D3F6294C40
58752	Старосолодово	7	61	102	55.752302999999998	55.776612	56.42933	56.423555	0103000020E6100000010000000500000062D7F6764BE04B405587DC0C37364C4062D7F6764BE04B4089981249F4364C4030D7A20568E34B4089981249F4364C4030D7A20568E34B405587DC0C37364C4062D7F6764BE04B405587DC0C37364C40
605	Старокальмиярово	7	61	102	56.024430000000002	56.048864000000002	56.174073999999997	56.163845000000002	0103000020E610000001000000050000004985B18520034C407B4E7ADFF8144C404985B18520034C40BD8A8C0E48164C40D3F9F02C41064C40BD8A8C0E48164C40D3F9F02C41064C407B4E7ADFF8144C404985B18520034C407B4E7ADFF8144C40
31766	Старокайпаново	7	61	102	55.728290999999999	55.759768000000001	56.381779000000002	56.363852999999999	0103000020E610000001000000050000004E7CB5A338DD4B4097C62FBC922E4C404E7CB5A338DD4B4059A65F22DE304C400F46EC1340E14B4059A65F22DE304C400F46EC1340E14B4097C62FBC922E4C404E7CB5A338DD4B4097C62FBC922E4C40
19032	Староакбулатово	7	61	102	55.583140999999998	55.60727	56.131616000000001	56.116162000000003	0103000020E6100000010000000500000076FA415DA4CA4B40DC847B65DE0E4C4076FA415DA4CA4B40AFD007CBD8104C40C4EBFA05BBCD4B40AFD007CBD8104C40C4EBFA05BBCD4B40DC847B65DE0E4C4076FA415DA4CA4B40DC847B65DE0E4C40
662	Савкияз	7	61	102	55.918599	55.938226999999998	56.166651000000002	56.153557999999997	0103000020E61000000100000005000000B491EBA694F54B400305DEC9A7134C40B491EBA694F54B40406CE9D154154C40B29C84D217F84B40406CE9D154154C40B29C84D217F84B400305DEC9A7134C40B491EBA694F54B400305DEC9A7134C40
1319	Савалеево	7	61	102	55.596606999999999	55.612031000000002	56.108984	56.098030000000001	0103000020E6100000010000000500000047C8409E5DCC4B4071033E3F8C0C4C4047C8409E5DCC4B40C5E40D30F30D4C40B091240857CE4B40C5E40D30F30D4C40B091240857CE4B4071033E3F8C0C4C4047C8409E5DCC4B4071033E3F8C0C4C40
46175	Новоакбулатово	7	61	102	55.577958000000002	55.593705999999997	56.105395000000001	56.101272999999999	0103000020E61000000100000005000000153B1A87FAC94B40E17B7F83F60C4C40153B1A87FAC94B40BA1457957D0D4C4030B8E68EFECB4B40BA1457957D0D4C4030B8E68EFECB4B40E17B7F83F60C4C40153B1A87FAC94B40E17B7F83F60C4C40
31031	Маматаево	7	61	102	55.6965	55.723934	56.350617	56.335850000000001	0103000020E61000000100000005000000FED478E926D94B40492EFF21FD2A4C40FED478E926D94B40F8359204E12C4C40323B8BDEA9DC4B40F8359204E12C4C40323B8BDEA9DC4B40492EFF21FD2A4C40FED478E926D94B40492EFF21FD2A4C40
58429	Малая Бальзюга	7	61	102	55.991686000000001	56.015411	56.221238999999997	56.211162999999999	0103000020E6100000010000000500000056F31C91EFFE4B400890A163071B4C4056F31C91EFFE4B40C4CC3E8F511C4C40D47FD6FCF8014C40C4CC3E8F511C4C40D47FD6FCF8014C400890A163071B4C4056F31C91EFFE4B400890A163071B4C40
1720	Кыткы-Елга	7	61	102	56.149411999999998	56.173369999999998	56.296489000000001	56.283324999999998	0103000020E61000000100000005000000A2D0B2EE1F134C40D1915CFE43244C40A2D0B2EE1F134C40D74FFF59F3254C40C30DF8FC30164C40D74FFF59F3254C40C30DF8FC30164C40D1915CFE43244C40A2D0B2EE1F134C40D1915CFE43244C40
1142	Кардагушево	7	61	102	55.603119999999997	55.620251000000003	56.273375000000001	56.262901999999997	0103000020E6100000010000000500000021C8410933CD4B40C806D2C5A6214C4021C8410933CD4B40A245B6F3FD224C40D927806264CF4B40A245B6F3FD224C40D927806264CF4B40C806D2C5A6214C4021C8410933CD4B40C806D2C5A6214C40
791	Кальтяево	7	61	102	55.933484	55.963397999999998	56.285358000000002	56.269621000000001	0103000020E610000001000000050000006DAB59677CF74B404CA8E0F082224C406DAB59677CF74B4074D3669C86244C4012842BA050FB4B4074D3669C86244C4012842BA050FB4B404CA8E0F082224C406DAB59677CF74B404CA8E0F082224C40
58801	Ильметово	7	61	102	55.629584000000001	55.644793	56.367403000000003	56.353214999999999	0103000020E61000000100000005000000DD0A613596D04B4073BA2C26362D4C40DD0A613596D04B40E5B9BE0F072F4C4049D8B79388D24B40E5B9BE0F072F4C4049D8B79388D24B4073BA2C26362D4C40DD0A613596D04B4073BA2C26362D4C40
2000	Гарибашево	7	61	102	55.558123000000002	55.589834000000003	56.178502999999999	56.161273000000001	0103000020E610000001000000050000009D12109370C74B40295DFA97A4144C409D12109370C74B40739EB12FD9164C40D10836AE7FCB4B40739EB12FD9164C40D10836AE7FCB4B40295DFA97A4144C409D12109370C74B40295DFA97A4144C40
282	Верхние Татышлы	7	61	102	55.827294999999999	55.875723000000001	56.303750999999998	56.280226999999996	0103000020E61000000100000005000000799274CDE4E94B40643A747ADE234C40799274CDE4E94B404B901150E1264C4071ADF6B017F04B404B901150E1264C4071ADF6B017F04B40643A747ADE234C40799274CDE4E94B40643A747ADE234C40
940	Верхнекудашево	7	61	102	55.682935000000001	55.709454000000001	56.293142000000003	56.278063000000003	0103000020E610000001000000050000009A25016A6AD74B40249D819197234C409A25016A6AD74B40C28A53AD85254C4019028063CFDA4B40C28A53AD85254C4019028063CFDA4B40249D819197234C409A25016A6AD74B40249D819197234C40
28945	Буль-Кайпаново	7	61	102	55.763002	55.802151000000002	56.335225999999999	56.321167000000003	0103000020E610000001000000050000002C64AE0CAAE14B40F8C610001C294C402C64AE0CAAE14B406B6281AFE82A4C4013BA4BE2ACE64B406B6281AFE82A4C4013BA4BE2ACE64B40F8C610001C294C402C64AE0CAAE14B40F8C610001C294C40
47331	Беляшево	7	61	102	55.879002	55.900354999999998	56.427961000000003	56.410857999999998	0103000020E610000001000000050000002E8F352383F04B4065A6B4FE96344C402E8F352383F04B40537B116DC7364C4021E527D53EF34B40537B116DC7364C4021E527D53EF34B4065A6B4FE96344C402E8F352383F04B4065A6B4FE96344C40
2198	Башкибаш	7	61	102	55.687607	55.701441000000003	56.121983	56.111921000000002	0103000020E6100000010000000500000016C0948103D84B40295E656D530E4C4016C0948103D84B4080D591239D0F4C406A8995D1C8D94B4080D591239D0F4C406A8995D1C8D94B40295E656D530E4C4016C0948103D84B40295E656D530E4C40
32455	Бадряшево	7	61	102	55.877626999999997	55.903094000000003	56.385586000000004	56.370434000000003	0103000020E61000000100000005000000158BDF1456F04B40CAA99D616A2F4C40158BDF1456F04B40D2E5CDE15A314C405F9B8D9598F34B40D2E5CDE15A314C405F9B8D9598F34B40CAA99D616A2F4C40158BDF1456F04B40CAA99D616A2F4C40
32315	Артаулово	7	61	102	55.504691999999999	55.525720999999997	56.353999000000002	56.343229000000001	0103000020E61000000100000005000000C34659BF99C04B40F70489EDEE2B4C40C34659BF99C04B408AE8D7D64F2D4C4003E962D34AC34B408AE8D7D64F2D4C4003E962D34AC34B40F70489EDEE2B4C40C34659BF99C04B40F70489EDEE2B4C40
27367	Арибашево	7	61	102	55.753669000000002	55.76735	56.257463000000001	56.238216999999999	0103000020E610000001000000050000002881CD3978E04B40F52C08E57D1E4C402881CD3978E04B400C772E8CF4204C40F54A598638E24B400C772E8CF4204C40F54A598638E24B40F52C08E57D1E4C402881CD3978E04B40F52C08E57D1E4C40
32242	Аксаитово	7	61	102	55.580410999999998	55.616315999999998	56.370494000000001	56.355944000000001	0103000020E610000001000000050000008C9E5BE84ACA4B408D9AAF928F2D4C408C9E5BE84ACA4B409FAEEE586C2F4C4032005471E3CE4B409FAEEE586C2F4C4032005471E3CE4B408D9AAF928F2D4C408C9E5BE84ACA4B408D9AAF928F2D4C40
1483	2-й Зиримзибаш	7	61	102	55.449193999999999	55.464024999999999	56.268141	56.258443	0103000020E610000001000000050000009BC761307FB94B40A87004A914214C409BC761307FB94B40BEDBBC7152224C4061C3D32B65BB4B40BEDBBC7152224C4061C3D32B65BB4B40A87004A914214C409BC761307FB94B40A87004A914214C40
58215	совхоза Первомайский	7	61	130	55.417555	55.438692000000003	53.855069999999998	53.841774000000001	0103000020E6100000010000000500000001A4367172B54B40C24F1C40BFEB4A4001A4367172B54B4036E50AEF72ED4A402882380F27B84B4036E50AEF72ED4A402882380F27B84B40C24F1C40BFEB4A4001A4367172B54B40C24F1C40BFEB4A40
58874	с. Нижние Услы	7	61	130	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
58911	с. Большое Аксаково	7	61	130	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
30724	отделение Совхоза Южное Первомайский	7	61	130	55.419072999999997	55.436321	53.716372	53.704689999999999	0103000020E610000001000000050000007CD11E2FA4B54B40BCE82B4833DA4A407CD11E2FA4B54B4093E2E313B2DB4A406DC7D45DD9B74B4093E2E313B2DB4A406DC7D45DD9B74B40BCE82B4833DA4A407CD11E2FA4B54B40BCE82B4833DA4A40
58889	отделение Красноармейское	7	61	130	55.371479999999998	55.392699	53.905662999999997	53.896155999999998	0103000020E610000001000000050000001D8F19A88CAF4B409D0E643DB5F24A401D8F19A88CAF4B403F19E3C3ECF34A400116F9F543B24B403F19E3C3ECF34A400116F9F543B24B409D0E643DB5F24A401D8F19A88CAF4B409D0E643DB5F24A40
31324	отделение Бегеняш Совхоза Первомайский	7	61	130	55.488683999999999	55.506281999999999	53.795985999999999	53.784410999999999	0103000020E610000001000000050000000B0A83328DBE4B40B3CF639467E44A400B0A83328DBE4B40740987DEE2E54A40D8463CD9CDC04B40740987DEE2E54A40D8463CD9CDC04B40B3CF639467E44A400B0A83328DBE4B40B3CF639467E44A40
58821	база Заготовки Скота	7	61	130	55.852510000000002	55.863352999999996	53.640439999999998	53.632517	0103000020E61000000100000005000000A9C1340C1FED4B40FF942A51F6D04A40A9C1340C1FED4B406E861BF0F9D14A40A5F3E15982EE4B406E861BF0F9D14A40A5F3E15982EE4B40FF942A51F6D04A40A9C1340C1FED4B40FF942A51F6D04A40
29282	Юрактау	7	61	130	56.120541000000003	56.135210000000001	53.747512	53.737580000000001	0103000020E61000000100000005000000E06932E36D0F4C4083177D0569DE4A40E06932E36D0F4C400CAF2479AEDF4A40CC0BB08F4E114C400CAF2479AEDF4A40CC0BB08F4E114C4083177D0569DE4A40E06932E36D0F4C4083177D0569DE4A40
32041	Чуртан	7	61	130	55.502544999999998	55.525371	53.741366999999997	53.725732999999998	0103000020E6100000010000000500000058E2016553C04B406150A6D1E4DC4A4058E2016553C04B40B4AA251DE5DE4A4027A25F5B3FC34B40B4AA251DE5DE4A4027A25F5B3FC34B406150A6D1E4DC4A4058E2016553C04B406150A6D1E4DC4A40
58888	Чувашский Чуганак	7	61	130	56.014736999999997	56.037472999999999	53.776276000000003	53.766734999999997	0103000020E610000001000000050000004485EAE6E2014C406AD95A5F24E24A404485EAE6E2014C40B95510035DE34A40D3BD4EEACB044C40B95510035DE34A40D3BD4EEACB044C406AD95A5F24E24A404485EAE6E2014C406AD95A5F24E24A40
32099	Услыбаш	7	61	130	55.549579999999999	55.579053999999999	53.769570999999999	53.754646000000001	0103000020E6100000010000000500000091442FA358C64B405307793D98E04A4091442FA358C64B409A79724D81E24A401A4F04711ECA4B409A79724D81E24A401A4F04711ECA4B405307793D98E04A4091442FA358C64B405307793D98E04A40
31918	Тюрюшля	7	61	130	55.598449000000002	55.662255999999999	53.473554999999998	53.447724999999998	0103000020E6100000010000000500000076A911FA99CC4B40014D840D4FB94A4076A911FA99CC4B40BBED42739DBC4A4036CAFACDC4D44B40BBED42739DBC4A4036CAFACDC4D44B40014D840D4FB94A4076A911FA99CC4B40014D840D4FB94A40
29563	Талачево	7	61	130	55.777374999999999	55.810523000000003	53.768917000000002	53.747681999999998	0103000020E610000001000000050000002FDD240681E34B4068E7340BB4DF4A402FDD240681E34B40522B4CDF6BE24A40F2D3B837BFE74B40522B4CDF6BE24A40F2D3B837BFE74B4068E7340BB4DF4A402FDD240681E34B4068E7340BB4DF4A40
31626	Талалаевка	7	61	130	56.000256	56.041632999999997	53.820549999999997	53.807673999999999	0103000020E610000001000000050000005BD07B6308004C402DEA93DC61E74A405BD07B6308004C40CC5D4BC807E94A4099B7EA3A54054C40CC5D4BC807E94A4099B7EA3A54054C402DEA93DC61E74A405BD07B6308004C402DEA93DC61E74A40
58117	Стерлитамак	7	61	130	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
30687	Северное Отделение	7	61	130	55.629863	55.646211999999998	53.624502	53.610138999999997	0103000020E61000000100000005000000F0FACC599FD04B40CF81E50819CE4A40F0FACC599FD04B40AF2479AEEFCF4A4031242713B7D24B40AF2479AEEFCF4A4031242713B7D24B40CF81E50819CE4A40F0FACC599FD04B40CF81E50819CE4A40
29622	Садовка	7	61	130	55.730609000000001	55.763505000000002	53.791981	53.761242000000003	0103000020E61000000100000005000000E694809884DD4B40BB2BBB6070E14A40E694809884DD4B40D50627A25FE54A408FAA2688BAE14B40D50627A25FE54A408FAA2688BAE14B40BB2BBB6070E14A40E694809884DD4B40BB2BBB6070E14A40
31737	Рязановка	7	61	130	55.736133000000002	55.793256999999997	53.677892	53.658468999999997	0103000020E61000000100000005000000D1402C9B39DE4B40043752B648D44A40D1402C9B39DE4B402A1C412AC5D64A405A29047289E54B402A1C412AC5D64A405A29047289E54B40043752B648D44A40D1402C9B39DE4B40043752B648D44A40
31677	Рощинский	7	61	130	55.917997	55.928686999999996	53.752330000000001	53.742980000000003	0103000020E61000000100000005000000BE69FAEC80F54B4082CAF8F719DF4A40BE69FAEC80F54B405CE674594CE04A40349C3237DFF64B405CE674594CE04A40349C3237DFF64B4082CAF8F719DF4A40BE69FAEC80F54B4082CAF8F719DF4A40
30581	Преображеновка	7	61	130	55.710037	55.750767000000003	53.575166000000003	53.558936000000003	0103000020E6100000010000000500000098F90E7EE2DA4B404E4700378BC74A4098F90E7EE2DA4B40B5E21B0A9FC94A4041F50F2219E04B40B5E21B0A9FC94A4041F50F2219E04B404E4700378BC74A4098F90E7EE2DA4B404E4700378BC74A40
29138	Помряскино	7	61	130	55.824832999999998	55.866047999999999	53.525418999999999	53.496572999999998	0103000020E61000000100000005000000AED4B32094E94B40CE893DB48FBF4A40AED4B32094E94B4038D906EE40C34A4013622EA9DAEE4B4038D906EE40C34A4013622EA9DAEE4B40CE893DB48FBF4A40AED4B32094E94B40CE893DB48FBF4A40
29995	Покровка	7	61	130	55.931956999999997	56.165447	53.861060000000002	53.534550000000003	0103000020E610000001000000050000009E23F25D4AF74B40D50968226CC44A409E23F25D4AF74B4067F2CD3637EE4A40541C075E2D154C4067F2CD3637EE4A40541C075E2D154C40D50968226CC44A409E23F25D4AF74B40D50968226CC44A40
31526	Подлесное	7	61	130	55.918644	55.940725	53.821283999999999	53.806659000000003	0103000020E610000001000000050000005455682096F54B401503249A40E74A405455682096F54B40315D88D51FE94A40CAC342AD69F84B40315D88D51FE94A40CAC342AD69F84B401503249A40E74A405455682096F54B401503249A40E74A40
58869	Октябрьское	7	61	130	55.44914	55.459775999999998	53.870538000000003	53.859419000000003	0103000020E61000000100000005000000A8A9656B7DB94B40D047197101EE4A40A8A9656B7DB94B406FF607CA6DEF4A402BBEA1F0D9BA4B406FF607CA6DEF4A402BBEA1F0D9BA4B40D047197101EE4A40A8A9656B7DB94B40D047197101EE4A40
29357	Новофедоровское	7	61	130	55.730671999999998	55.747165000000003	53.429519999999997	53.407297	0103000020E610000001000000050000002C0DFCA886DD4B402461DF4E22B44A402C0DFCA886DD4B402C7DE882FAB64A40A1DB4B1AA3DF4B402C7DE882FAB64A40A1DB4B1AA3DF4B402461DF4E22B44A402C0DFCA886DD4B402461DF4E22B44A40
29652	Новое Барятино	7	61	130	55.898764	55.922452999999997	53.711058999999999	53.695452000000003	0103000020E610000001000000050000003C69E1B20AF34B400AF8359204D94A403C69E1B20AF34B40634337FB03DB4A406D8C9DF012F64B40634337FB03DB4A406D8C9DF012F64B400AF8359204D94A403C69E1B20AF34B400AF8359204D94A40
30909	Новая Отрадовка	7	61	130	55.887194000000001	55.907254000000002	53.599907999999999	53.587141000000003	0103000020E610000001000000050000008D9AAF928FF14B400492B06F27CB4A408D9AAF928FF14B40EC4D0CC9C9CC4A40259529E620F44B40EC4D0CC9C9CC4A40259529E620F44B400492B06F27CB4A408D9AAF928FF14B400492B06F27CB4A40
29451	Новая Васильевка	7	61	130	55.824545999999998	55.846330000000002	53.474262000000003	53.461708999999999	0103000020E6100000010000000500000018062CB98AE94B406AA2CF4719BB4A4018062CB98AE94B4027DE019EB4BC4A40D5CF9B8A54EC4B4027DE019EB4BC4A40D5CF9B8A54EC4B406AA2CF4719BB4A4018062CB98AE94B406AA2CF4719BB4A40
30524	Николаевка	7	61	130	55.546993000000001	55.592547000000003	53.539563999999999	53.515937999999998	0103000020E610000001000000050000000A12DBDD03C64B40BF61A2410AC24A400A12DBDD03C64B40AA0CE36E10C54A40E52B8194D8CB4B40AA0CE36E10C54A40E52B8194D8CB4B40BF61A2410AC24A400A12DBDD03C64B40BF61A2410AC24A40
30201	Наумовка	7	61	130	55.884625	55.928840000000001	53.532387999999997	53.506743999999998	0103000020E61000000100000005000000AC1C5A643BF14B40DCB8C5FCDCC04A40AC1C5A643BF14B4034643C4A25C44A40BB9BA73AE4F64B4034643C4A25C44A40BB9BA73AE4F64B40DCB8C5FCDCC04A40AC1C5A643BF14B40DCB8C5FCDCC04A40
29475	Мурдашево	7	61	130	55.799069000000003	55.812257000000002	53.401198999999998	53.387205999999999	0103000020E61000000100000005000000AC1F9BE447E64B40516859F78FB14A40AC1F9BE447E64B400D18247D5AB34A403A799109F8E74B400D18247D5AB34A403A799109F8E74B40516859F78FB14A40AC1F9BE447E64B40516859F78FB14A40
31401	Матвеевка	7	61	130	55.525730000000003	55.537281999999998	53.867676000000003	53.863512999999998	0103000020E610000001000000050000005743E21E4BC34B40DE550F9887EE4A405743E21E4BC34B4016C3D50110EF4A405F5D15A8C5C44B4016C3D50110EF4A405F5D15A8C5C44B40DE550F9887EE4A405743E21E4BC34B40DE550F9887EE4A40
31000	Мариинский	7	61	130	55.828741000000001	55.861763000000003	53.661996000000002	53.644038000000002	0103000020E610000001000000050000005BED612F14EA4B40CDB051D66FD24A405BED612F14EA4B409A0AF148BCD44A4091F3FE3F4EEE4B409A0AF148BCD44A4091F3FE3F4EEE4B40CDB051D66FD24A405BED612F14EA4B40CDB051D66FD24A40
30096	Максимовка	7	61	130	55.458258000000001	55.489977000000003	53.608280000000001	53.600138000000001	0103000020E61000000100000005000000B090B932A8BA4B401E8B6D52D1CC4A40B090B932A8BA4B40CB67791EDCCD4A406765FB90B7BE4B40CB67791EDCCD4A406765FB90B7BE4B401E8B6D52D1CC4A40B090B932A8BA4B401E8B6D52D1CC4A40
31816	Кучербаево	7	61	130	55.652706999999999	55.691477999999996	53.687742	53.673310999999998	0103000020E61000000100000005000000656F29E78BD34B40BE840A0E2FD64A40656F29E78BD34B40F60A0BEE07D84A40A5F3E15982D84B40F60A0BEE07D84A40A5F3E15982D84B40BE840A0E2FD64A40656F29E78BD34B40BE840A0E2FD64A40
58885	Кузьминовка	7	61	130	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
29815	Косяковка	7	61	130	55.999529000000003	56.007344000000003	53.705174999999997	53.698880000000003	0103000020E61000000100000005000000A933F790F0FF4B400CEA5BE674D94A40A933F790F0FF4B40787AA52C43DA4A4032E9EFA5F0004C40787AA52C43DA4A4032E9EFA5F0004C400CEA5BE674D94A40A933F790F0FF4B400CEA5BE674D94A40
29761	Константиноградовка	7	61	130	55.373483999999998	55.386212999999998	53.776871999999997	53.752643999999997	0103000020E6100000010000000500000025CADE52CEAF4B40EBC37AA356E04A4025CADE52CEAF4B40CC96AC8A70E34A402025766D6FB14B40CC96AC8A70E34A402025766D6FB14B40EBC37AA356E04A4025CADE52CEAF4B40EBC37AA356E04A40
30807	Кононовский	7	61	130	55.646535999999998	55.658070000000002	53.559871999999999	53.555410999999999	0103000020E61000000100000005000000E4D70FB1C1D24B40596B28B517C74A40E4D70FB1C1D24B401AF9BCE2A9C74A40473D44A33BD44B401AF9BCE2A9C74A40473D44A33BD44B40596B28B517C74A40E4D70FB1C1D24B40596B28B517C74A40
283	Кармаскалы	7	61	130	55.854486999999999	55.888190999999999	53.747053999999999	53.729520999999998	0103000020E61000000100000005000000B7ED7BD45FED4B40635FB2F160DD4A40B7ED7BD45FED4B40492C29779FDF4A40FFCC203EB0F14B40492C29779FDF4A40FFCC203EB0F14B40635FB2F160DD4A40B7ED7BD45FED4B40635FB2F160DD4A40
30483	Кантюковка	7	61	130	55.931068000000003	55.943095999999997	53.452464999999997	53.440485000000002	0103000020E61000000100000005000000132D793C2DF74B4075B0FECF61B84A40132D793C2DF74B40D5CA845FEAB94A40847EA65EB7F84B40D5CA845FEAB94A40847EA65EB7F84B4075B0FECF61B84A40132D793C2DF74B4075B0FECF61B84A40
31598	Ишпарсово	7	61	130	55.946510000000004	55.991120000000002	53.811731000000002	53.801937000000002	0103000020E6100000010000000500000022AB5B3D27F94B40E73922DFA5E64A4022AB5B3D27F94B401F1329CDE6E74A40AD342905DDFE4B401F1329CDE6E74A40AD342905DDFE4B40E73922DFA5E64A4022AB5B3D27F94B40E73922DFA5E64A40
31850	Золотоношка	7	61	130	55.500146000000001	55.572361999999998	53.431413999999997	53.410040000000002	0103000020E61000000100000005000000D49CBCC804C04B40A306D3307CB44A40D49CBCC804C04B40AD84EE9238B74A4090BC732843C94B40AD84EE9238B74A4090BC732843C94B40A306D3307CB44A40D49CBCC804C04B40A306D3307CB44A40
58900	Заливной	7	61	130	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
58884	Загородный	7	61	130	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
29165	Забельское	7	61	130	56.130744999999997	56.144992999999999	53.723047999999999	53.711362999999999	0103000020E61000000100000005000000C98E8D40BC104C40CF4A5AF10DDB4A40C98E8D40BC104C4017B83CD68CDC4A40109370218F124C4017B83CD68CDC4A40109370218F124C40CF4A5AF10DDB4A40C98E8D40BC104C40CF4A5AF10DDB4A40
31129	Дергачевка	7	61	130	55.513800000000003	55.525424999999998	53.848089999999999	53.835515000000001	0103000020E61000000100000005000000A857CA32C4C14B40A228D027F2EA4A40A857CA32C4C14B4046088F368EEC4A401AC05B2041C34B4046088F368EEC4A401AC05B2041C34B40A228D027F2EA4A40A857CA32C4C14B40A228D027F2EA4A40
58824	Восточный	7	61	130	55.919874999999998	55.945602999999998	53.727682999999999	53.719479	0103000020E6100000010000000500000039B4C876BEF54B4053944BE317DC4A4039B4C876BEF54B40766D6FB724DD4A40EFFFE38409F94B40766D6FB724DD4A40EFFFE38409F94B4053944BE317DC4A4039B4C876BEF54B4053944BE317DC4A40
30840	Веселый	7	61	130	55.775767000000002	55.792700000000004	53.563707000000001	53.551667000000002	0103000020E61000000100000005000000742843554CE34B4027A435069DC64A40742843554CE34B405DC30C8D27C84A4005C58F3177E54B405DC30C8D27C84A4005C58F3177E54B4027A435069DC64A40742843554CE34B4027A435069DC64A40
31957	Верхние Услы	7	61	130	55.582459	55.609578999999997	53.732354999999998	53.714917	0103000020E6100000010000000500000064213A048ECA4B405E2D776682DB4A4064213A048ECA4B40F20703CFBDDD4A4008AA46AF06CE4B40F20703CFBDDD4A4008AA46AF06CE4B405E2D776682DB4A4064213A048ECA4B405E2D776682DB4A40
29535	Буриказганово	7	61	130	55.767142999999997	55.809517	53.724736999999998	53.710500000000003	0103000020E610000001000000050000007B2DE8BD31E24B406DE7FBA9F1DA4A407B2DE8BD31E24B40BF99982EC4DC4A402C47C8409EE74B40BF99982EC4DC4A402C47C8409EE74B406DE7FBA9F1DA4A407B2DE8BD31E24B406DE7FBA9F1DA4A40
30048	Бугуруслановка	7	61	130	55.519297999999999	55.567394	53.666429000000001	53.650047999999998	0103000020E6100000010000000500000069705B5B78C24B40446ADAC534D34A4069705B5B78C24B40910DA48B4DD54A402BF9D85DA0C84B40910DA48B4DD54A402BF9D85DA0C84B40446ADAC534D34A4069705B5B78C24B40446ADAC534D34A40
29933	Большой Куганак	7	61	130	56.058205999999998	56.117738000000003	53.819837999999997	53.790210000000002	0103000020E610000001000000050000002A37514B73074C40707CED9925E54A402A37514B73074C404F029B73F0E84A408CBFED09120F4C404F029B73F0E84A408CBFED09120F4C40707CED9925E54A402A37514B73074C40707CED9925E54A40
29376	Аючево	7	61	130	55.776791000000003	55.790939999999999	53.440973	53.429470999999999	0103000020E61000000100000005000000E06932E36DE34B404BCADDE7F8B64A40E06932E36DE34B40A2B5A2CD71B84A40938C9C853DE54B40A2B5A2CD71B84A40938C9C853DE54B404BCADDE7F8B64A40E06932E36DE34B404BCADDE7F8B64A40
30133	Алга	7	61	130	55.381622	55.399571000000002	53.643743999999998	53.630814000000001	0103000020E6100000010000000500000091B75CFDD8B04B40F2ED5D83BED04A4091B75CFDD8B04B40847F113466D24A400BB77C2425B34B40847F113466D24A400BB77C2425B34B40F2ED5D83BED04A4091B75CFDD8B04B40F2ED5D83BED04A40
29097	Айгулево	7	61	130	55.795845	55.818725000000001	53.495930000000001	53.474342999999998	0103000020E61000000100000005000000B2D7BB3FDEE54B40130B7C45B7BC4A40B2D7BB3FDEE54B407A8D5DA27ABF4A4074B515FBCBE84B407A8D5DA27ABF4A4074B515FBCBE84B40130B7C45B7BC4A40B2D7BB3FDEE54B40130B7C45B7BC4A40
58092	Стерлитамак	7	61	7457	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
27667	Яшерганово	7	61	368	54.831772999999998	54.859026999999998	53.341231000000001	53.319268999999998	0103000020E610000001000000050000001059A489776A4B4035D07CCEDDA84A401059A489776A4B40D1B01875ADAB4A40C4B0C398F46D4B40D1B01875ADAB4A40C4B0C398F46D4B4035D07CCEDDA84A401059A489776A4B4035D07CCEDDA84A40
29015	Янгурча	7	61	368	55.163826	55.185682	53.577278	53.552233999999999	0103000020E61000000100000005000000041E1840F8944B40A0DE8C9AAFC64A40041E1840F8944B40A359D93EE4C94A405ABA826DC4974B40A359D93EE4C94A405ABA826DC4974B40A0DE8C9AAFC64A40041E1840F8944B40A0DE8C9AAFC64A40
1884	Юмагузино	7	61	368	55.289355999999998	55.312578000000002	53.555058000000002	53.543722000000002	0103000020E6100000010000000500000060730E9E09A54B40D00EB8AE98C54A4060730E9E09A54B400CB1FA230CC74A407CB94F8E02A84B400CB1FA230CC74A407CB94F8E02A84B40D00EB8AE98C54A4060730E9E09A54B40D00EB8AE98C54A40
27855	Халикеево	7	61	368	55.241188999999999	55.257826000000001	53.387672999999999	53.363402999999998	0103000020E61000000100000005000000D593F947DF9E4B40572250FD83AE4A40D593F947DF9E4B406745D4449FB14A407D073F7100A14B406745D4449FB14A407D073F7100A14B40572250FD83AE4A40D593F947DF9E4B40572250FD83AE4A40
27838	Учуган-Асаново	7	61	368	54.599997999999999	54.615367999999997	53.324696000000003	53.306728999999997	0103000020E610000001000000050000002CD505BCCC4C4B400DDE57E542A74A402CD505BCCC4C4B402E9276A38FA94A40A180ED60C44E4B402E9276A38FA94A40A180ED60C44E4B400DDE57E542A74A402CD505BCCC4C4B400DDE57E542A74A40
27540	Тятер-Арасланово	7	61	368	54.924515	54.968218	53.348559000000002	53.329832000000003	0103000020E61000000100000005000000AAD4EC8156764B404F965AEF37AA4A40AAD4EC8156764B40FDDCD0949DAC4A4003B34291EE7B4B40FDDCD0949DAC4A4003B34291EE7B4B404F965AEF37AA4A40AAD4EC8156764B404F965AEF37AA4A40
28932	Турмаево	7	61	368	55.196649999999998	55.218038999999997	53.525917	53.517110000000002	0103000020E610000001000000050000001361C3D32B994B40A03715A930C24A401361C3D32B994B4089B48D3F51C34A405320B3B3E89B4B4089B48D3F51C34A405320B3B3E89B4B40A03715A930C24A401361C3D32B994B40A03715A930C24A40
27759	Стерлибашево	7	61	368	55.234046999999997	55.286850000000001	53.448217999999997	53.42915	0103000020E610000001000000050000000B5D8940F59D4B40098A1F63EEB64A400B5D8940F59D4B4040BD19355FB94A40C66D3480B7A44B4040BD19355FB94A40C66D3480B7A44B40098A1F63EEB64A400B5D8940F59D4B40098A1F63EEB64A40
58741	Раевка	7	61	368	55.406793	55.438791000000002	53.258442000000002	53.253146999999998	0103000020E61000000100000005000000F19E03CB11B44B404E0AF31E67A04A40F19E03CB11B44B40D8F4A0A014A14A40BB63B14D2AB84B40D8F4A0A014A14A40BB63B14D2AB84B404E0AF31E67A04A40F19E03CB11B44B404E0AF31E67A04A40
48648	Первомайск	7	61	368	55.287111000000003	55.305121999999997	53.462876999999999	53.455660999999999	0103000020E6100000010000000500000033A9A10DC0A44B400588821953BA4A4033A9A10DC0A44B400989B48D3FBB4A4022A5D93C0EA74B400989B48D3FBB4A4022A5D93C0EA74B400588821953BA4A4033A9A10DC0A44B400588821953BA4A40
28878	Новый Калкаш	7	61	368	55.435791000000002	55.452365	53.485135	53.478484999999999	0103000020E610000001000000050000001172DEFFC7B74B40335019FF3EBD4A401172DEFFC7B74B408E9257E718BE4A40726DA818E7B94B408E9257E718BE4A40726DA818E7B94B40335019FF3EBD4A401172DEFFC7B74B40335019FF3EBD4A40
58280	Нижный Аллагуват	7	61	368	55.516692999999997	55.539752999999997	53.224438999999997	53.212560000000003	0103000020E610000001000000050000003B8908FF22C24B400938842A359B4A403B8908FF22C24B403579CA6ABA9C4A407D7555A016C54B403579CA6ABA9C4A407D7555A016C54B400938842A359B4A403B8908FF22C24B400938842A359B4A40
27655	Нижнеибраево	7	61	368	54.809378000000002	54.838115000000002	53.302472000000002	53.292392	0103000020E610000001000000050000000B0DC4B299674B4057CEDE196DA54A400B0DC4B299674B4055FA0967B7A64A40BEA4315A476B4B4055FA0967B7A64A40BEA4315A476B4B4057CEDE196DA54A400B0DC4B299674B4057CEDE196DA54A40
28659	Муртаза	7	61	368	55.264876999999998	55.279663999999997	53.505758	53.499662999999998	0103000020E61000000100000005000000363B527DE7A14B40B8020AF5F4BF4A40363B527DE7A14B405ED89AADBCC04A402CEFAA07CCA34B405ED89AADBCC04A402CEFAA07CCA34B40B8020AF5F4BF4A40363B527DE7A14B40B8020AF5F4BF4A40
28202	Кундряк	7	61	368	55.419891	55.453164000000001	53.278584000000002	53.259977999999997	0103000020E610000001000000050000003F7100FDBEB54B40F9D687F546A14A403F7100FDBEB54B402D98F8A3A8A34A40BEDC274701BA4B402D98F8A3A8A34A40BEDC274701BA4B40F9D687F546A14A403F7100FDBEB54B40F9D687F546A14A40
28731	Куганакбаш	7	61	368	55.350791999999998	55.385485000000003	53.594499999999996	53.572738999999999	0103000020E6100000010000000500000066D993C0E6AC4B406612F5824FC94A4066D993C0E6AC4B406ABC749318CC4A409E0C8E9257B14B406ABC749318CC4A409E0C8E9257B14B406612F5824FC94A4066D993C0E6AC4B406612F5824FC94A40
27975	Карагуш	7	61	368	55.253559000000003	55.286365000000004	53.301578999999997	53.289409999999997	0103000020E61000000100000005000000A14D0E9F74A04B4053910A630BA54A40A14D0E9F74A04B40871403249AA64A400ADCBA9BA7A44B40871403249AA64A400ADCBA9BA7A44B4053910A630BA54A40A14D0E9F74A04B4053910A630BA54A40
27995	Кабакуш	7	61	368	55.321893000000003	55.368875000000003	53.27496	53.261851999999998	0103000020E61000000100000005000000DAE731CA33A94B403332C85D84A14A40DAE731CA33A94B40A5DAA7E331A34A40F0A7C64B37AF4B40A5DAA7E331A34A40F0A7C64B37AF4B403332C85D84A14A40DAE731CA33A94B403332C85D84A14A40
28565	Ибракаево	7	61	368	55.342761000000003	55.361716000000001	53.475313	53.464753999999999	0103000020E6100000010000000500000011ACAA97DFAB4B40B4571F0F7DBB4A4011ACAA97DFAB4B408C2E6F0ED7BC4A405038BBB54CAE4B408C2E6F0ED7BC4A405038BBB54CAE4B40B4571F0F7DBB4A4011ACAA97DFAB4B40B4571F0F7DBB4A40
24885	Елимбетово	7	61	368	55.624284000000003	55.646607000000003	53.360543999999997	53.348134000000002	0103000020E6100000010000000500000042B5C189E8CF4B401650A8A78FAC4A4042B5C189E8CF4B406F62484E26AE4A40AE2EA704C4D24B406F62484E26AE4A40AE2EA704C4D24B401650A8A78FAC4A4042B5C189E8CF4B401650A8A78FAC4A40
29026	Верхний Гулюм	7	61	368	55.115046999999997	55.125188999999999	53.555025999999998	53.542732000000001	0103000020E610000001000000050000005F402FDCB98E4B40103FFF3D78C54A405F402FDCB98E4B4000378B170BC74A40D368723106904B4000378B170BC74A40D368723106904B40103FFF3D78C54A405F402FDCB98E4B40103FFF3D78C54A40
28180	Верхнешакарово	7	61	368	55.504700999999997	55.525630999999997	53.299329999999998	53.282547000000001	0103000020E6100000010000000500000016A1D80A9AC04B409D4A06802AA44A4016A1D80A9AC04B40185B087250A64A40C36169E047C34B40185B087250A64A40C36169E047C34B409D4A06802AA44A4016A1D80A9AC04B409D4A06802AA44A40
46426	Васильевка	7	61	368	55.109558999999997	55.123311999999999	53.462088999999999	53.447864000000003	0103000020E61000000100000005000000C1FD8007068E4B402387889B53B94A40C1FD8007068E4B40B16B7BBB25BB4A40289A07B0C88F4B40B16B7BBB25BB4A40289A07B0C88F4B402387889B53B94A40C1FD8007068E4B402387889B53B94A40
27753	Бузат	7	61	368	54.677128000000003	54.710391999999999	53.317982999999998	53.293345000000002	0103000020E610000001000000050000005B9A5B21AC564B40FAB836548CA54A405B9A5B21AC564B408CD7BCAAB3A84A4086AB0320EE5A4B408CD7BCAAB3A84A4086AB0320EE5A4B40FAB836548CA54A405B9A5B21AC564B40FAB836548CA54A40
28313	Бакеево	7	61	368	55.346443999999998	55.367536999999999	53.368614999999998	53.345995000000002	0103000020E610000001000000050000009DF2E84658AC4B402ECA6C9049AC4A409DF2E84658AC4B4053E8BCC62EAF4A40F488D1730BAF4B4053E8BCC62EAF4A40F488D1730BAF4B402ECA6C9049AC4A409DF2E84658AC4B402ECA6C9049AC4A40
27921	Амирово	7	61	368	55.181047	55.216358999999997	53.348193000000002	53.335366	0103000020E61000000100000005000000FB04508C2C974B405D18E945EDAA4A40FB04508C2C974B401BD9959691AC4A40FE98D6A6B19B4B401BD9959691AC4A40FE98D6A6B19B4B405D18E945EDAA4A40FB04508C2C974B405D18E945EDAA4A40
27505	Айдарали	7	61	368	55.001005999999997	55.053584999999998	53.394401999999999	53.369135999999997	0103000020E61000000100000005000000C58CF0F620804B405CE333D93FAF4A40C58CF0F620804B400EBDC5C37BB24A4030478FDFDB864B400EBDC5C37BB24A4030478FDFDB864B405CE333D93FAF4A40C58CF0F620804B405CE333D93FAF4A40
58130	Сибай	7	61	7458	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
58375	Янгантау	7	61	787	57.473655000000001	58.826419000000001	55.519626000000002	54.907536999999998	0103000020E610000001000000050000001F4B1FBAA0BC4C407974232C2A744B401F4B1FBAA0BC4C405E13D21A83C24B4082E50819C8694D405E13D21A83C24B4082E50819C8694D407974232C2A744B401F4B1FBAA0BC4C407974232C2A744B40
26170	Язги-Юрт	7	61	787	58.347391999999999	58.385112999999997	55.281713000000003	55.264271000000001	0103000020E610000001000000050000002E724F57772C4D40FF23D3A1D3A14B402E724F57772C4D40D5EDEC2B0FA44B40D921FE614B314D40D5EDEC2B0FA44B40D921FE614B314D40FF23D3A1D3A14B402E724F57772C4D40FF23D3A1D3A14B40
58755	Юлаево	7	61	787	57.992998	58.008403999999999	55.133513999999998	55.124357000000003	0103000020E61000000100000005000000287FF78E1AFF4C40AC0320EEEA8F4B40287FF78E1AFF4C4071C79BFC16914B40EA93DC6113014D4071C79BFC16914B40EA93DC6113014D40AC0320EEEA8F4B40287FF78E1AFF4C40AC0320EEEA8F4B40
58622	Шарипово	7	61	787	58.155529999999999	58.199305000000003	55.456183000000003	55.442749999999997	0103000020E6100000010000000500000000C63368E8134D40E9263108ACB84B4000C63368E8134D40DFFE5C3464BA4B40F37684D382194D40DFFE5C3464BA4B40F37684D382194D40E9263108ACB84B4000C63368E8134D40E9263108ACB84B40
58683	Чулпан	7	61	787	58.090699000000001	58.116247000000001	55.296866999999999	55.290858999999998	0103000020E61000000100000005000000D4635B069C0B4D40A65F22DE3AA54B40D4635B069C0B4D407D21E4BCFFA54B400AA1832EE10E4D407D21E4BCFFA54B400AA1832EE10E4D40A65F22DE3AA54B40D4635B069C0B4D40A65F22DE3AA54B40
49014	Чебаркуль	7	61	787	58.408845999999997	58.441212	55.216180999999999	55.207926999999998	0103000020E61000000100000005000000DA8CD31055344D404A7A185A9D9A4B40DA8CD31055344D401F82AAD1AB9B4B40274D83A279384D401F82AAD1AB9B4B40274D83A279384D404A7A185A9D9A4B40DA8CD31055344D404A7A185A9D9A4B40
26252	Урманчино	7	61	787	58.511856000000002	58.529741000000001	55.151465999999999	55.138243000000003	0103000020E610000001000000050000007521567F84414D4052F355F2B1914B407521567F84414D405C3AE63C63934B40D82C978DCE434D405C3AE63C63934B40D82C978DCE434D4052F355F2B1914B407521567F84414D4052F355F2B1914B40
27168	Урмантау	7	61	787	57.696418999999999	57.722740000000002	55.487845999999998	55.456066	0103000020E6100000010000000500000011A8FE4124D94C40A568E55E60BA4B4011A8FE4124D94C4001BEDBBC71BE4B406AC18BBE82DC4C4001BEDBBC71BE4B406AC18BBE82DC4C40A568E55E60BA4B4011A8FE4124D94C40A568E55E60BA4B40
27288	Турналы	7	61	787	58.252952000000001	58.263373000000001	55.339241999999999	55.327710000000003	0103000020E6100000010000000500000099BA2BBB60204D403D49BA66F2A94B4099BA2BBB60204D40FEB627486CAB4B4020D3DA34B6214D40FEB627486CAB4B4020D3DA34B6214D403D49BA66F2A94B4099BA2BBB60204D403D49BA66F2A94B40
27214	Терменево	7	61	787	58.603555999999998	58.654921999999999	55.085884	55.070092000000002	0103000020E61000000100000005000000FCA6B052414D4D400ADB4FC6F8884B40FCA6B052414D4D40F59F353FFE8A4B4028B7ED7BD4534D40F59F353FFE8A4B4028B7ED7BD4534D400ADB4FC6F8884B40FCA6B052414D4D400ADB4FC6F8884B40
27132	Таймеево	7	61	787	57.832469000000003	57.868023999999998	55.478510999999997	55.461818999999998	0103000020E6100000010000000500000088F71C588EEA4C40F1D58EE21CBB4B4088F71C588EEA4C405CE333D93FBD4B40511212691BEF4C405CE333D93FBD4B40511212691BEF4C40F1D58EE21CBB4B4088F71C588EEA4C40F1D58EE21CBB4B40
26618	Саргамыш	7	61	787	58.087913999999998	58.124079999999999	55.414976000000003	55.398145	0103000020E61000000100000005000000266E15C4400B4D407008556AF6B24B40266E15C4400B4D40FD4FFEEE1DB54B40390B7BDAE10F4D40FD4FFEEE1DB54B40390B7BDAE10F4D407008556AF6B24B40266E15C4400B4D407008556AF6B24B40
16791	Первомайский	7	61	787	58.686577999999997	58.752271999999998	55.112164999999997	55.083657000000002	0103000020E610000001000000050000009813B4C9E1574D406E8AC745B58A4B409813B4C9E1574D40BF60376C5B8E4B4027D9EA724A604D40BF60376C5B8E4B4027D9EA724A604D406E8AC745B58A4B409813B4C9E1574D406E8AC745B58A4B40
25658	Новые Каратавлы	7	61	787	58.130566000000002	58.149898	55.141506	55.131799999999998	0103000020E610000001000000050000001AFCFD62B6104D4070CE88D2DE904B401AFCFD62B6104D4009185DDE1C924B402FDE8FDB2F134D4009185DDE1C924B402FDE8FDB2F134D4070CE88D2DE904B401AFCFD62B6104D4070CE88D2DE904B40
26859	Насибаш	7	61	787	58.313229	58.342433999999997	55.174244000000002	55.161676999999997	0103000020E6100000010000000500000053944BE317284D40F8C1F9D4B1944B4053944BE317284D401AC39CA04D964B40EC8497E0D42B4D401AC39CA04D964B40EC8497E0D42B4D40F8C1F9D4B1944B4053944BE317284D40F8C1F9D4B1944B40
26799	Мурсалимкино	7	61	787	58.542766999999998	58.586281	55.050674000000001	55.025951999999997	0103000020E610000001000000050000008C2C996379454D4005A2276552834B408C2C996379454D40F660527C7C864B4012A27C410B4B4D40F660527C7C864B4012A27C410B4B4D4005A2276552834B408C2C996379454D4005A2276552834B40
26003	Миндишево	7	61	787	57.966444000000003	57.997003999999997	54.945309000000002	54.936532999999997	0103000020E610000001000000050000002DB5DE6FB4FB4C40F84F3750E0774B402DB5DE6FB4FB4C40A7CEA3E2FF784B4097FDBAD39DFF4C40A7CEA3E2FF784B4097FDBAD39DFF4C40F84F3750E0774B402DB5DE6FB4FB4C40F84F3750E0774B40
26576	Мещегарово	7	61	787	58.191544	58.220820000000003	55.430906	55.414414000000001	0103000020E610000001000000050000005DDF878384184D40958098840BB54B405DDF878384184D4039D384ED27B74B40C0266BD4431C4D4039D384ED27B74B40C0266BD4431C4D40958098840BB54B405DDF878384184D40958098840BB54B40
27009	Малояз	7	61	787	58.146205999999999	58.186576000000002	55.194963999999999	55.166207	0103000020E610000001000000050000004F3DD2E0B6124D40E2AE5E4546954B404F3DD2E0B6124D40DCF29194F4984B40F81BEDB8E1174D40DCF29194F4984B40F81BEDB8E1174D40E2AE5E4546954B404F3DD2E0B6124D40E2AE5E4546954B40
26191	Лаклы	7	61	787	58.529471999999998	58.571548999999997	55.204639	55.185111999999997	0103000020E61000000100000005000000E8120EBDC5434D406F0C01C0B1974B40E8120EBDC5434D403A3E5A9C319A4B40DF87838428494D403A3E5A9C319A4B40DF87838428494D406F0C01C0B1974B40E8120EBDC5434D406F0C01C0B1974B40
26094	Лагерево	7	61	787	58.434241	58.455316000000003	55.274754000000001	55.250509999999998	0103000020E610000001000000050000008ACA863595374D4015A930B610A04B408ACA863595374D40FC389A232BA34B403BAC70CB473A4D40FC389A232BA34B403BAC70CB473A4D4015A930B610A04B408ACA863595374D4015A930B610A04B40
25906	Куселярово	7	61	787	57.868456000000002	57.890877000000003	55.401370999999997	55.392940000000003	0103000020E61000000100000005000000EB01F39029EF4C4027A5A0DB4BB24B40EB01F39029EF4C400A48FB1F60B34B401AE1ED4108F24C400A48FB1F60B34B401AE1ED4108F24C4027A5A0DB4BB24B40EB01F39029EF4C4027A5A0DB4BB24B40
5566	Комсомол	7	61	787	58.130260999999997	58.143124	55.280374999999999	55.269455999999998	0103000020E61000000100000005000000DD787764AC104D4001DBC1887DA24B40DD787764AC104D40D9CEF753E3A34B40E8A221E351124D40D9CEF753E3A34B40E8A221E351124D4001DBC1887DA24B40DD787764AC104D4001DBC1887DA24B40
26783	Карагулово	7	61	787	58.475223	58.509932999999997	55.041961999999998	55.024538	0103000020E610000001000000050000004CA7751BD43C4D402FC1A90F24834B404CA7751BD43C4D405ED6C4025F854B4059130B7C45414D405ED6C4025F854B4059130B7C45414D402FC1A90F24834B404CA7751BD43C4D402FC1A90F24834B40
25945	Ишимбаево	7	61	787	58.015366	58.034114000000002	54.940793999999997	54.928064999999997	0103000020E6100000010000000500000034BC5983F7014D40F7C77BD5CA764B4034BC5983F7014D40F22213F06B784B40FA2AF9D85D044D40F22213F06B784B40FA2AF9D85D044D40F7C77BD5CA764B4034BC5983F7014D40F7C77BD5CA764B40
27360	Ильтаево	7	61	787	58.137546	58.149538	55.271410000000003	55.262542000000003	0103000020E610000001000000050000000AD9791B9B114D40C9E9EBF99AA14B400AD9791B9B114D4058E71890BDA24B402FC1A90F24134D4058E71890BDA24B402FC1A90F24134D40C9E9EBF99AA14B400AD9791B9B114D40C9E9EBF99AA14B40
58836	Идрисово	7	61	787	58.119273999999997	58.134751999999999	55.058306000000002	55.048063999999997	0103000020E61000000100000005000000ADA1D45E440F4D40B60E0EF626864B40ADA1D45E440F4D408E942D9276874B400989B48D3F114D408E942D9276874B400989B48D3F114D40B60E0EF626864B40ADA1D45E440F4D40B60E0EF626864B40
58810	Идельбаево 2-е	7	61	787	57.805177999999998	57.819389999999999	55.425863999999997	55.419584999999998	0103000020E61000000100000005000000B6BA9C1210E74C40327216F6B4B54B40B6BA9C1210E74C40994528B682B64B40B05582C5E1E84C40994528B682B64B40B05582C5E1E84C40327216F6B4B54B40B6BA9C1210E74C40327216F6B4B54B40
6362	Еланыш	7	61	787	58.222383000000001	58.239702000000001	55.400613999999997	55.374222000000003	0103000020E61000000100000005000000DB17D00B771C4D40CCB8A981E6AF4B40DB17D00B771C4D40ED28CE5147B34B4095641D8EAE1E4D40ED28CE5147B34B4095641D8EAE1E4D40CCB8A981E6AF4B40DB17D00B771C4D40CCB8A981E6AF4B40
30905	Бияз	7	61	787	57.59093	57.599446	55.377864000000002	55.372298000000001	0103000020E61000000100000005000000D61C2098A3CB4C40E02EFB75A7AF4B40D61C2098A3CB4C40FA2AF9D85DB04B40E8DB82A5BACC4C40FA2AF9D85DB04B40E8DB82A5BACC4C40E02EFB75A7AF4B40D61C2098A3CB4C40E02EFB75A7AF4B40
25848	Бешевлярово	7	61	787	57.945979999999999	57.963937000000001	55.384982999999998	55.375070999999998	0103000020E61000000100000005000000C55565DF15F94C40C956975302B04B40C55565DF15F94C400B42791F47B14B40C233A14962FB4C400B42791F47B14B40C233A14962FB4C40C956975302B04B40C55565DF15F94C40C956975302B04B40
58550	Ахуново	7	61	787	58.042853999999998	58.081643999999997	55.328960000000002	55.317357999999999	0103000020E610000001000000050000005B40683D7C054D40DE8FDB2F9FA84B405B40683D7C054D4099D87C5C1BAA4B4012F5824F730A4D4099D87C5C1BAA4B4012F5824F730A4D40DE8FDB2F9FA84B405B40683D7C054D40DE8FDB2F9FA84B40
25815	Аркаулово	7	61	787	57.911152000000001	57.937356000000001	55.409319000000004	55.389918000000002	0103000020E61000000100000005000000AED7F4A0A0F44C40950F41D5E8B14B40AED7F4A0A0F44C40D350A39064B44B40CD5A0A48FBF74C40D350A39064B44B40CD5A0A48FBF74C40950F41D5E8B14B40AED7F4A0A0F44C40950F41D5E8B14B40
48807	Алькино	7	61	787	58.064576000000002	58.092486000000001	55.095497999999999	55.080410999999998	0103000020E61000000100000005000000A20DC00644084D408C9E5BE84A8A4B40A20DC00644084D40AD6A4947398C4B403FABCC94D60B4D40AD6A4947398C4B403FABCC94D60B4D408C9E5BE84A8A4B40A20DC00644084D408C9E5BE84A8A4B40
58753	Айская	7	61	787	58.362797999999998	58.396574999999999	55.394561000000003	55.378565000000002	0103000020E61000000100000005000000F086342A702E4D40833463D174B04B40F086342A702E4D4077A38FF980B24B40A2B437F8C2324D4077A38FF980B24B40A2B437F8C2324D40833463D174B04B40F086342A702E4D40833463D174B04B40
25335	Яман-Порт	7	61	944	56.609943000000001	56.630766000000001	55.421306999999999	55.406221000000002	0103000020E610000001000000050000004AB6BA9C124E4C4066F9BA0CFFB34B404AB6BA9C124E4C40B6494563EDB54B40E1B6B6F0BC504C40B6494563EDB54B40E1B6B6F0BC504C4066F9BA0CFFB34B404AB6BA9C124E4C4066F9BA0CFFB34B40
24118	Укарлино	7	61	944	56.473281999999998	56.494177000000001	55.035921000000002	55.026705999999997	0103000020E610000001000000050000008AE42B81943C4C40B14D2A1A6B834B408AE42B81943C4C40AC1E300F99844B40BBB72231413F4C40AC1E300F99844B40BBB72231413F4C40B14D2A1A6B834B408AE42B81943C4C40B14D2A1A6B834B40
24413	Старокулево	7	61	944	56.628107	56.657831999999999	55.139097	55.113945999999999	0103000020E61000000100000005000000C0B167CF65504C4048C153C8958E4B40C0B167CF65504C4061FC34EECD914B409221C7D633544C4061FC34EECD914B409221C7D633544C4048C153C8958E4B40C0B167CF65504C4048C153C8958E4B40
24465	Староисаево	7	61	944	56.652954000000001	56.685653000000002	55.111217000000003	55.097903000000002	0103000020E610000001000000050000006DE525FF93534C401497E315888C4B406DE525FF93534C402FE1D05B3C8E4B40C0B33D7AC3574C402FE1D05B3C8E4B40C0B33D7AC3574C401497E315888C4B406DE525FF93534C401497E315888C4B40
24936	Старобирючево	7	61	944	56.582220999999997	56.602981	55.261685	55.244228999999997	0103000020E61000000100000005000000AF05BD37864A4C400DDE57E5429F4B40AF05BD37864A4C40486DE2E47EA14B40008E3D7B2E4D4C40486DE2E47EA14B40008E3D7B2E4D4C400DDE57E5429F4B40AF05BD37864A4C400DDE57E5429F4B40
24335	Сатлык	7	61	944	56.715980000000002	56.729858999999998	55.032975	55.024177000000002	0103000020E61000000100000005000000884B8E3BA55B4C405F28603B18834B40884B8E3BA55B4C40F54A598638844B407BD80B056C5D4C40F54A598638844B407BD80B056C5D4C405F28603B18834B40884B8E3BA55B4C405F28603B18834B40
25095	Сарва	7	61	944	57.031235000000002	57.067067999999999	55.247163999999998	55.226903	0103000020E61000000100000005000000CBBE2B82FF834C40A12E52280B9D4B40CBBE2B82FF834C40D05FE811A39F4B40D74D29AF95884C40D05FE811A39F4B40D74D29AF95884C40A12E52280B9D4B40CBBE2B82FF834C40A12E52280B9D4B40
32552	Павловка	7	61	944	56.530665999999997	56.575842999999999	55.429603999999998	55.409503000000001	0103000020E61000000100000005000000B08C0DDDEC434C40944E24986AB44B40B08C0DDDEC434C408A1D8D43FDB64B40B5503239B5494C408A1D8D43FDB64B40B5503239B5494C40944E24986AB44B40B08C0DDDEC434C40944E24986AB44B40
25017	Новый Субай	7	61	944	56.992679000000003	57.013987	55.150956999999998	55.137734000000002	0103000020E610000001000000050000008736001B107F4C400DC68844A1914B408736001B107F4C40170D198F52934B40DAC87553CA814C40170D198F52934B40DAC87553CA814C400DC68844A1914B408736001B107F4C400DC68844A1914B40
24311	Новокулево	7	61	944	56.598785999999997	56.637323000000002	55.097974999999998	55.066550999999997	0103000020E61000000100000005000000BDA60705A54C4C400F4240BE84884B40BDA60705A54C4C40AD69DE718A8C4B408BFED0CC93514C40AD69DE718A8C4B408BFED0CC93514C400F4240BE84884B40BDA60705A54C4C400F4240BE84884B40
24825	Новобирючево	7	61	944	56.621530999999997	56.639749000000002	55.247610999999999	55.234727999999997	0103000020E610000001000000050000009F39EB538E4F4C404DBA2D910B9E4B409F39EB538E4F4C409F909DB7B19F4B400953944BE3514C409F909DB7B19F4B400953944BE3514C404DBA2D910B9E4B409F39EB538E4F4C404DBA2D910B9E4B40
24205	Нимислярово	7	61	944	56.548067000000003	56.584690999999999	55.069814000000001	55.055517000000002	0103000020E610000001000000050000002882380F27464C409FAF592E1B874B402882380F27464C40C76647AAEF884B40FDA19927D74A4C40C76647AAEF884B40FDA19927D74A4C409FAF592E1B874B402882380F27464C409FAF592E1B874B40
24961	Никольское	7	61	944	56.779598999999997	56.827308000000002	55.196094000000002	55.178491000000001	0103000020E61000000100000005000000457F68E6C9634C40AFD007CBD8964B40457F68E6C9634C408E78B29B19994B400EDC813AE5694C408E78B29B19994B400EDC813AE5694C40AFD007CBD8964B40457F68E6C9634C40AFD007CBD8964B40
24232	Кызыл-Баржау	7	61	944	56.569572000000001	56.591455000000003	55.010508999999999	55.003512999999998	0103000020E61000000100000005000000D15B3CBCE7484C40300E2E1D73804B40D15B3CBCE7484C4026A8E15B58814B40210725CCB44B4C4026A8E15B58814B40210725CCB44B4C40300E2E1D73804B40D15B3CBCE7484C40300E2E1D73804B40
23987	Кушкулево	7	61	944	56.598292000000001	56.605432999999998	54.984718000000001	54.972230000000003	0103000020E61000000100000005000000AEBA0ED5944C4C4055185B08727C4B40AEBA0ED5944C4C402AE44A3D0B7E4B40A7751BD47E4D4C402AE44A3D0B7E4B40A7751BD47E4D4C4055185B08727C4B40AEBA0ED5944C4C4055185B08727C4B40
32533	Красный Ключ	7	61	944	56.611443000000001	56.684961000000001	55.397402999999997	55.370963000000003	0103000020E610000001000000050000001F2FA4C3434E4C40568330B77BAF4B401F2FA4C3434E4C40882AFC19DEB24B408A0453CDAC574C40882AFC19DEB24B408A0453CDAC574C40568330B77BAF4B401F2FA4C3434E4C40568330B77BAF4B40
24654	Красная Горка	7	61	944	56.646262	56.692633000000001	55.215615999999997	55.178629999999998	0103000020E61000000100000005000000E35295B6B8524C40D00A0C59DD964B40E35295B6B8524C40463F1A4E999B4B40B090B932A8584C40463F1A4E999B4B40B090B932A8584C40D00A0C59DD964B40E35295B6B8524C40D00A0C59DD964B40
46898	Каргино	7	61	944	56.430154000000002	56.444840999999997	55.010523999999997	54.998122000000002	0103000020E610000001000000050000002E1F49490F374C4085B53176C27F4B402E1F49490F374C405BE9B5D958814B40C075C58CF0384C405BE9B5D958814B40C075C58CF0384C4085B53176C27F4B402E1F49490F374C4085B53176C27F4B40
24486	Ишмуратово	7	61	944	56.803080999999999	56.831781999999997	55.080942	55.070824000000002	0103000020E61000000100000005000000FD84B35BCB664C40CEE2C5C210894B40FD84B35BCB664C40B96FB54E5C8A4B4063B323D5776A4C40B96FB54E5C8A4B4063B323D5776A4C40CEE2C5C210894B40FD84B35BCB664C40CEE2C5C210894B40
24126	Истриково	7	61	944	56.482337000000001	56.495479000000003	55.055093999999997	55.046470999999997	0103000020E610000001000000050000004C530438BD3D4C40309B00C3F2854B404C530438BD3D4C40581AF8510D874B406A6D1ADB6B3F4C40581AF8510D874B406A6D1ADB6B3F4C40309B00C3F2854B404C530438BD3D4C40309B00C3F2854B40
24592	Большие Шиды	7	61	944	56.743324999999999	56.757418999999999	55.165816	55.151487000000003	0103000020E610000001000000050000004CA60A46255F4C4074620FED63934B404CA60A46255F4C40A7936C7539954B403C2F151BF3604C40A7936C7539954B403C2F151BF3604C4074620FED63934B404CA60A46255F4C4074620FED63934B40
24062	Большетенькашево	7	61	944	56.492668000000002	56.518611	55.012335999999998	54.998499000000002	0103000020E6100000010000000500000093E4B9BE0F3F4C405B0BB3D0CE7F4B4093E4B9BE0F3F4C401F48DE3994814B40452C62D861424C401F48DE3994814B40452C62D861424C405B0BB3D0CE7F4B4093E4B9BE0F3F4C405B0BB3D0CE7F4B40
23949	Бикмурзино	7	61	944	56.434869999999997	56.452109	54.993994999999998	54.983612999999998	0103000020E610000001000000050000007901F6D1A9374C40D175E107E77D4B407901F6D1A9374C409AB1683A3B7F4B40179D2CB5DE394C409AB1683A3B7F4B40179D2CB5DE394C40D175E107E77D4B407901F6D1A9374C40D175E107E77D4B40
24560	Баш-Шиды	7	61	944	56.713464999999999	56.733182999999997	55.150647999999997	55.139854	0103000020E610000001000000050000009AEB34D2525B4C407E1B62BCE6914B409AEB34D2525B4C40999A046F48934B40D87DC7F0D85D4C40999A046F48934B40D87DC7F0D85D4C407E1B62BCE6914B409AEB34D2525B4C407E1B62BCE6914B40
23901	Байгильдино	7	61	944	56.503295000000001	56.522661999999997	54.986542	54.974606999999999	0103000020E61000000100000005000000C39E76F86B404C40F1B913ECBF7C4B40C39E76F86B404C40B2101D02477E4B40546EA296E6424C40B2101D02477E4B40546EA296E6424C40F1B913ECBF7C4B40C39E76F86B404C40F1B913ECBF7C4B40
30681	Атняш	7	61	944	57.212398	57.229680999999999	55.587234000000002	55.562300999999998	0103000020E610000001000000050000002FDE8FDB2F9B4C4009C1AA7AF9C74B402FDE8FDB2F9B4C40B58CD47B2ACB4B409CC1DF2F669D4C40B58CD47B2ACB4B409CC1DF2F669D4C4009C1AA7AF9C74B402FDE8FDB2F9B4C4009C1AA7AF9C74B40
22391	Шатмантамак	7	61	271	54.553995999999998	54.576858000000001	53.447735999999999	53.433532999999997	0103000020E61000000100000005000000B20E4757E9464B404E5E64027EB74A40B20E4757E9464B40F59ECA694FB94A40CE37A27BD6494B40F59ECA694FB94A40CE37A27BD6494B404E5E64027EB74A40B20E4757E9464B404E5E64027EB74A40
21741	Чятай-Бурзян	7	61	271	54.827801999999998	54.841124000000001	53.814995000000003	53.806716999999999	0103000020E610000001000000050000001DC87A6AF5694B404910AE8042E74A401DC87A6AF5694B40A7B393C151E84A40BBF083F3A96B4B40A7B393C151E84A40BBF083F3A96B4B404910AE8042E74A401DC87A6AF5694B404910AE8042E74A40
23805	Уршакбашкарамалы	7	61	271	55.129680999999998	55.158884999999998	53.635902000000002	53.620618999999998	0103000020E61000000100000005000000CFF4126399904B405B23827170CF4A40CFF4126399904B4002BB9A3C65D14A409869FB5756944B4002BB9A3C65D14A409869FB5756944B405B23827170CF4A40CFF4126399904B405B23827170CF4A40
23828	Уршак	7	61	271	55.211787000000001	55.237200000000001	53.647427	53.633254000000001	0103000020E61000000100000005000000E65B1FD61B9B4B40D50792770ED14A40E65B1FD61B9B4B4011C64FE3DED24A403C4ED1915C9E4B4011C64FE3DED24A403C4ED1915C9E4B40D50792770ED14A40E65B1FD61B9B4B40D50792770ED14A40
22684	Софиевка	7	61	271	55.116762999999999	55.132078999999997	53.733623000000001	53.717554999999997	0103000020E6100000010000000500000001310917F28E4B40670A9DD7D8DB4A4001310917F28E4B40F54BC45BE7DD4A4083BEF4F6E7904B40F54BC45BE7DD4A4083BEF4F6E7904B40670A9DD7D8DB4A4001310917F28E4B40670A9DD7D8DB4A40
47503	Сафарово	7	61	271	54.450321000000002	54.464495999999997	53.566144999999999	53.556624999999997	0103000020E61000000100000005000000DCD9571EA4394B406891ED7C3FC74A40DCD9571EA4394B409FE5797077C84A40B88FDC9A743B4B409FE5797077C84A40B88FDC9A743B4B406891ED7C3FC74A40DCD9571EA4394B406891ED7C3FC74A40
23673	Сатыево	7	61	271	54.727676000000002	54.741528000000002	53.518774999999998	53.490236000000003	0103000020E61000000100000005000000C40AB77C245D4B4033A9A10DC0BE4A40C40AB77C245D4B40BF7D1D3867C24A40BE88B663EA5E4B40BF7D1D3867C24A40BE88B663EA5E4B4033A9A10DC0BE4A40C40AB77C245D4B4033A9A10DC0BE4A40
58802	Саккул-Михайловка	7	61	271	54.740558	54.758201	53.691015999999998	53.671097000000003	0103000020E610000001000000050000004565C39ACA5E4B40CCB8A981E6D54A404565C39ACA5E4B40A181583673D84A40B265F9BA0C614B40A181583673D84A40B265F9BA0C614B40CCB8A981E6D54A404565C39ACA5E4B40CCB8A981E6D54A40
58340	Родниковка	7	61	271	54.361117999999998	55.346362999999997	53.868901999999999	53.346725999999997	0103000020E610000001000000050000009BFF571D392E4B4021567F8461AC4A409BFF571D392E4B40E9B6442E38EF4A40B0C56E9F55AC4B40E9B6442E38EF4A40B0C56E9F55AC4B4021567F8461AC4A409BFF571D392E4B4021567F8461AC4A40
48008	Новый Мир	7	61	271	55.037002000000001	55.074686	53.698283000000004	53.684702999999999	0103000020E610000001000000050000007CF1457BBC844B408E3C1059A4D74A407CF1457BBC844B40282D5C5661D94A400ABC934F8F894B40282D5C5661D94A400ABC934F8F894B408E3C1059A4D74A407CF1457BBC844B408E3C1059A4D74A40
23728	Новые Омельники	7	61	271	54.701273999999998	54.724235	53.553314	53.540768	0103000020E610000001000000050000007EC4AF58C3594B40965CC5E237C54A407EC4AF58C3594B40A0353FFED2C64A402DCF83BBB35C4B40A0353FFED2C64A402DCF83BBB35C4B40965CC5E237C54A407EC4AF58C3594B40965CC5E237C54A40
58565	Новые Карамалы	7	61	271	54.697816000000003	54.72296	53.664166999999999	53.647657000000002	0103000020E610000001000000050000001250E10852594B404303B16CE6D24A401250E10852594B408D0A9C6C03D54A4078280AF4895C4B408D0A9C6C03D54A4078280AF4895C4B404303B16CE6D24A401250E10852594B404303B16CE6D24A40
22751	Новые Ишлы	7	61	271	54.837504000000003	54.855649999999997	53.500906000000001	53.478093999999999	0103000020E610000001000000050000007522C154336B4B40F834272F32BD4A407522C154336B4B40622F14B01DC04A4044696FF0856D4B40622F14B01DC04A4044696FF0856D4B40F834272F32BD4A407522C154336B4B40F834272F32BD4A40
22478	Нарыстау	7	61	271	55.032932000000002	55.044215000000001	53.856912000000001	53.840159	0103000020E61000000100000005000000F67EA31D37844B40543882548AEB4A40F67EA31D37844B4065C6DB4AAFED4A400F7F4DD6A8854B4065C6DB4AAFED4A400F7F4DD6A8854B40543882548AEB4A40F67EA31D37844B40543882548AEB4A40
22925	Миякитамак	7	61	271	54.734467000000002	54.753250999999999	53.790390000000002	53.775658999999997	0103000020E61000000100000005000000E17EC003035E4B408DEC4ACB48E34A40E17EC003035E4B40F08AE07F2BE54A40F3565D876A604B40F08AE07F2BE54A40F3565D876A604B408DEC4ACB48E34A40E17EC003035E4B408DEC4ACB48E34A40
22958	Менеузтамак	7	61	271	54.509124999999997	54.539406999999997	53.717955000000003	53.691197000000003	0103000020E61000000100000005000000BA490C022B414B40F20BAF2479D84A40BA490C022B414B40F67F0EF3E5DB4A40E21DE0490B454B40F67F0EF3E5DB4A40E21DE0490B454B40F20BAF2479D84A40BA490C022B414B40F20BAF2479D84A40
22134	Малые Каркалы	7	61	271	54.941619000000003	54.970050000000001	53.520847000000003	53.505265999999999	0103000020E610000001000000050000006825ADF886784B40EFE3688EACC04A406825ADF886784B40209C4F1DABC24A400EBE30992A7C4B40209C4F1DABC24A400EBE30992A7C4B40EFE3688EACC04A406825ADF886784B40EFE3688EACC04A40
23170	Курманайбаш	7	61	271	54.833120000000001	54.848841	53.557540000000003	53.548189000000001	0103000020E610000001000000050000005FD218ADA36A4B407383A10E2BC64A405FD218ADA36A4B401E1B81785DC74A40814067D2A66C4B401E1B81785DC74A40814067D2A66C4B407383A10E2BC64A405FD218ADA36A4B407383A10E2BC64A40
22560	Куль-Кункас	7	61	271	54.926617	54.94267	53.801760999999999	53.794182999999997	0103000020E610000001000000050000007575C7629B764B400305DEC9A7E54A407575C7629B764B40A81ABD1AA0E64A40CD751A69A9784B40A81ABD1AA0E64A40CD751A69A9784B400305DEC9A7E54A407575C7629B764B400305DEC9A7E54A40
21990	Култай-Каран	7	61	271	54.487430000000003	54.503419999999998	53.560065000000002	53.553057000000003	0103000020E610000001000000050000006E8B321B643E4B4075E95F92CAC64A406E8B321B643E4B402F51BD35B0C74A407F130A1170404B402F51BD35B0C74A407F130A1170404B4075E95F92CAC64A406E8B321B643E4B4075E95F92CAC64A40
58281	Кочеганово	7	61	271	54.864426000000002	54.890279999999997	53.472814999999997	53.461280000000002	0103000020E61000000100000005000000F3E7DB82A56E4B40422619390BBB4A40F3E7DB82A56E4B407407B13385BC4A403524EEB1F4714B407407B13385BC4A403524EEB1F4714B40422619390BBB4A40F3E7DB82A56E4B40422619390BBB4A40
58562	Комсомольский	7	61	271	55.011021999999997	55.027937999999999	53.751019999999997	53.736221999999998	0103000020E61000000100000005000000ACC43C2B69814B40404CC2853CDE4A40ACC43C2B69814B402A52616C21E04A406728EE7893834B402A52616C21E04A406728EE7893834B40404CC2853CDE4A40ACC43C2B69814B40404CC2853CDE4A40
22822	Кожай-Семеновка	7	61	271	54.694248999999999	54.725788999999999	53.747874000000003	53.731209999999997	0103000020E61000000100000005000000EE23B726DD584B400B410E4A98DD4A40EE23B726DD584B40ADC3D155BADF4A40F56569A7E65C4B40ADC3D155BADF4A40F56569A7E65C4B400B410E4A98DD4A40EE23B726DD584B400B410E4A98DD4A40
23213	Киргиз-Мияки	7	61	271	54.782428000000003	54.819536999999997	53.648018999999998	53.620533999999999	0103000020E61000000100000005000000C3BCC79926644B402D077AA86DCF4A40C3BCC79926644B40E3175E49F2D24A40546EA296E6684B40E3175E49F2D24A40546EA296E6684B402D077AA86DCF4A40C3BCC79926644B402D077AA86DCF4A40
22888	Кекен-Васильевка	7	61	271	54.702306999999998	54.735069000000003	53.722861999999999	53.708553999999999	0103000020E610000001000000050000003D601E32E5594B4099B9C0E5B1DA4A403D601E32E5594B40B5C2F4BD86DC4A40D7A6B1BD165E4B40B5C2F4BD86DC4A40D7A6B1BD165E4B4099B9C0E5B1DA4A403D601E32E5594B4099B9C0E5B1DA4A40
22545	Каран-Кункас	7	61	271	54.918424000000002	54.938384999999997	53.773935000000002	53.762391000000001	0103000020E6100000010000000500000046EEE9EA8E754B40E3E13D0796E14A4046EEE9EA8E754B40691D554D10E34A404A07EBFF1C784B40691D554D10E34A404A07EBFF1C784B40E3E13D0796E14A4046EEE9EA8E754B40E3E13D0796E14A40
21939	Канбеково	7	61	271	54.562359000000001	54.5976	53.671374	53.655591999999999	0103000020E610000001000000050000003ECE3461FB474B4076C24B70EAD34A403ECE3461FB474B403EB14E95EFD54A40780B24287E4C4B403EB14E95EFD54A40780B24287E4C4B4076C24B70EAD34A403ECE3461FB474B4076C24B70EAD34A40
22345	Исламгулово	7	61	271	54.465242000000003	54.484797999999998	53.442737000000001	53.436267999999998	0103000020E61000000100000005000000E25CC30C8D3B4B404A253CA1D7B74A40E25CC30C8D3B4B4055DD239BABB84A40469561DC0D3E4B4055DD239BABB84A40469561DC0D3E4B404A253CA1D7B74A40E25CC30C8D3B4B404A253CA1D7B74A40
22423	Ильчигулово	7	61	271	54.989939	55.013770999999998	53.829543000000001	53.816622000000002	0103000020E6100000010000000500000079043752B67E4B40D998D71187E84A4079043752B67E4B4018D00B772EEA4A400D51853FC3814B4018D00B772EEA4A400D51853FC3814B40D998D71187E84A4079043752B67E4B40D998D71187E84A40
22311	Зильдярово	7	61	271	54.610534999999999	54.643664999999999	53.442255000000003	53.415692	0103000020E610000001000000050000001C08C902264E4B40BB9A3C6535B54A401C08C902264E4B400ABFD4CF9BB84A40384A5E9D63524B400ABFD4CF9BB84A40384A5E9D63524B40BB9A3C6535B54A401C08C902264E4B40BB9A3C6535B54A40
1139	Ерлыково	7	61	271	54.827595000000002	54.842975000000003	53.619525000000003	53.607837000000004	0103000020E61000000100000005000000A4AA09A2EE694B403E26529ACDCD4A40A4AA09A2EE694B40F7065F984CCF4A403D2CD49AE66B4B40F7065F984CCF4A403D2CD49AE66B4B403E26529ACDCD4A40A4AA09A2EE694B403E26529ACDCD4A40
22221	Енебей-Урсаево	7	61	271	54.506726	54.521836	53.628143999999999	53.619160999999998	0103000020E610000001000000050000003604C765DC404B40B5FAEAAA40CF4A403604C765DC404B40DD96C80567D04A400FF0A485CB424B40DD96C80567D04A400FF0A485CB424B40B5FAEAAA40CF4A403604C765DC404B40B5FAEAAA40CF4A40
46164	Воскресенка	7	61	271	54.926957999999999	54.932698000000002	53.554747999999996	53.550077999999999	0103000020E61000000100000005000000FE614B8FA6764B40E21FB6F468C64A40FE614B8FA6764B40BDC282FB01C74A40B685E7A562774B40BDC282FB01C74A40B685E7A562774B40E21FB6F468C64A40FE614B8FA6764B40E21FB6F468C64A40
22092	Большие Каркалы	7	61	271	54.99991	55.026868999999998	53.507894999999998	53.492769000000003	0103000020E61000000100000005000000C078060DFD7F4B40C7BDF90D13BF4A40C078060DFD7F4B40A5660FB402C14A405B23827170834B40A5660FB402C14A405B23827170834B40C7BDF90D13BF4A40C078060DFD7F4B40C7BDF90D13BF4A40
47711	Богданово	7	61	271	54.546008999999998	54.561425	53.628650999999998	53.615358000000001	0103000020E610000001000000050000002C29779FE3454B407EAA0A0DC4CE4A402C29779FE3454B4081CCCEA277D04A4012143FC6DC474B4081CCCEA277D04A4012143FC6DC474B407EAA0A0DC4CE4A402C29779FE3454B407EAA0A0DC4CE4A40
45714	Биккулово	7	61	271	54.880038999999996	54.898446	53.749636000000002	53.734858000000003	0103000020E610000001000000050000002E1A321EA5704B401C9AB2D30FDE4A402E1A321EA5704B40BFF38B12F4DF4A406B9C4D4700734B40BFF38B12F4DF4A406B9C4D4700734B401C9AB2D30FDE4A402E1A321EA5704B401C9AB2D30FDE4A40
58620	Баязитово	7	61	271	54.744213999999999	54.774037999999997	53.461756999999999	53.446331000000001	0103000020E61000000100000005000000D89C8367425F4B407218CC5F21B94A40D89C8367425F4B407BD976DA1ABB4A403DEE5BAD13634B407BD976DA1ABB4A403DEE5BAD13634B407218CC5F21B94A40D89C8367425F4B407218CC5F21B94A40
58284	Анясево	7	61	271	54.361117999999998	55.346362999999997	53.868901999999999	53.346725999999997	0103000020E610000001000000050000009BFF571D392E4B4021567F8461AC4A409BFF571D392E4B40E9B6442E38EF4A40B0C56E9F55AC4B40E9B6442E38EF4A40B0C56E9F55AC4B4021567F8461AC4A409BFF571D392E4B4021567F8461AC4A40
18898	Яндыганово	7	61	798	55.963614	55.983907000000002	55.417005000000003	55.407009000000002	0103000020E61000000100000005000000DFFB1BB457FB4B40BE16F4DE18B44B40DFFB1BB457FB4B405EA27A6B60B54B401AA721AAF0FD4B405EA27A6B60B54B401AA721AAF0FD4B40BE16F4DE18B44B40DFFB1BB457FB4B40BE16F4DE18B44B40
18877	Янагушево	7	61	798	56.028607000000001	56.060451999999998	55.381746	55.363022999999998	0103000020E61000000100000005000000E5B7E864A9034C401059A48977AE4B40E5B7E864A9034C407DB08C0DDDB04B40287D21E4BC074C407DB08C0DDDB04B40287D21E4BC074C401059A48977AE4B40E5B7E864A9034C401059A48977AE4B40
58359	Чураево	7	61	798	55.570053000000001	55.591056000000002	55.634872999999999	55.618588000000003	0103000020E610000001000000050000004CFE277FF7C84B405AD93EE42DCF4B404CFE277FF7C84B40840EBA8443D14B40630D17B9A7CB4B40840EBA8443D14B40630D17B9A7CB4B405AD93EE42DCF4B404CFE277FF7C84B405AD93EE42DCF4B40
18746	Урьяды	7	61	798	56.049340000000001	56.077115999999997	55.431345999999998	55.417133	0103000020E610000001000000050000003C31EBC550064C408B8A389D64B54B403C31EBC550064C4055A1815836B74B40C9FFE4EFDE094C4055A1815836B74B40C9FFE4EFDE094C408B8A389D64B54B403C31EBC550064C408B8A389D64B54B40
20210	Укозяш	7	61	798	56.126443000000002	56.145181000000001	55.686878	55.676051999999999	0103000020E6100000010000000500000071E7C2482F104C409C3237DF88D64B4071E7C2482F104C40C32B499EEBD74B4013807F4A95124C40C32B499EEBD74B4013807F4A95124C409C3237DF88D64B4071E7C2482F104C409C3237DF88D64B40
21040	Тынбаево	7	61	798	55.447800999999998	55.467258999999999	55.608145	55.593955000000001	0103000020E61000000100000005000000DC0E0D8B51B94B40D925AAB706CC4B40DC0E0D8B51B94B40EB1C03B2D7CD4B407EE19524CFBB4B40EB1C03B2D7CD4B407EE19524CFBB4B40D925AAB706CC4B40DC0E0D8B51B94B40D925AAB706CC4B40
21416	Тигирменево	7	61	798	55.654234000000002	55.667771999999999	55.683858000000001	55.675767999999998	0103000020E6100000010000000500000034F790F0BDD34B4077D7D9907FD64B4034F790F0BDD34B40D28DB0A888D74B409E978A8D79D54B40D28DB0A888D74B409E978A8D79D54B4077D7D9907FD64B4034F790F0BDD34B4077D7D9907FD64B40
20447	Терекеево	7	61	798	55.908375999999997	55.934624999999997	55.715915000000003	55.706218	0103000020E61000000100000005000000533C2EAA45F44B405BECF65965DA4B40533C2EAA45F44B40A1DB4B1AA3DB4B401283C0CAA1F74B40A1DB4B1AA3DB4B401283C0CAA1F74B405BECF65965DA4B40533C2EAA45F44B405BECF65965DA4B40
20240	Татарбаево	7	61	798	55.971124000000003	55.993600000000001	55.642432999999997	55.625104999999998	0103000020E610000001000000050000002C2E8ECA4DFC4B4075C8CD7003D04B402C2E8ECA4DFC4B40826F9A3E3BD24B401EA7E8482EFF4B40826F9A3E3BD24B401EA7E8482EFF4B4075C8CD7003D04B402C2E8ECA4DFC4B4075C8CD7003D04B40
20984	Старокульчубаево	7	61	798	55.499293000000002	55.539608999999999	55.626506999999997	55.614260999999999	0103000020E61000000100000005000000950F41D5E8BF4B40A81ABD1AA0CE4B40950F41D5E8BF4B4087DBA16131D04B404AD05FE811C54B4087DBA16131D04B404AD05FE811C54B40A81ABD1AA0CE4B40950F41D5E8BF4B40A81ABD1AA0CE4B40
19060	Староваськино	7	61	798	55.964880999999998	55.983583000000003	55.517769999999999	55.508830000000003	0103000020E6100000010000000500000011C4793881FB4B40A29C685721C14B4011C4793881FB4B40CA6C904946C24B4067F3380CE6FD4B40CA6C904946C24B4067F3380CE6FD4B40A29C685721C14B4011C4793881FB4B40A29C685721C14B40
20373	Староатнагулово	7	61	798	55.956212000000001	55.977466	55.701942000000003	55.687558000000003	0103000020E610000001000000050000007905A22765FA4B40350D8AE601D84B407905A22765FA4B402CD8463CD9D94B40D9791B9B1DFD4B402CD8463CD9D94B40D9791B9B1DFD4B40350D8AE601D84B407905A22765FA4B40350D8AE601D84B40
19961	Староарзаматово	7	61	798	56.080871000000002	56.111700999999996	55.632443000000002	55.611398999999999	0103000020E61000000100000005000000F0181EFB590A4C404FE78A5242CE4B40F0181EFB590A4C40C5CA68E4F3D04B401AF7E6374C0E4C40C5CA68E4F3D04B401AF7E6374C0E4C404FE78A5242CE4B40F0181EFB590A4C404FE78A5242CE4B40
46186	Староакбулатово	7	61	798	55.973612000000003	55.984095000000003	55.486325999999998	55.477786000000002	0103000020E61000000100000005000000207F69519FFC4B404B3E761728BD4B40207F69519FFC4B40E5982CEE3FBE4B401D9430D3F6FD4B40E5982CEE3FBE4B401D9430D3F6FD4B404B3E761728BD4B40207F69519FFC4B404B3E761728BD4B40
46909	Сосновка	7	61	798	55.575991000000002	55.594990000000003	55.561971	55.547412000000001	0103000020E610000001000000050000002AE5B512BAC94B400FB8AE9811C64B402AE5B512BAC94B4074266DAAEEC74B4039B9DFA128CC4B4074266DAAEEC74B4039B9DFA128CC4B400FB8AE9811C64B402AE5B512BAC94B400FB8AE9811C64B40
18804	Сабаево	7	61	798	56.028553000000002	56.059859000000003	55.41724	55.404172000000003	0103000020E61000000100000005000000F299EC9FA7034C40BEFA78E8BBB34B40F299EC9FA7034C40A14ACD1E68B54B4086AFAF75A9074C40A14ACD1E68B54B4086AFAF75A9074C40BEFA78E8BBB34B40F299EC9FA7034C40BEFA78E8BBB34B40
5641	Октябрь	7	61	798	55.621526000000003	55.636780000000002	55.612045000000002	55.604610000000001	0103000020E610000001000000050000008ECEF9298ECF4B40D36A48DC63CD4B408ECEF9298ECF4B401557957D57CE4B409A5FCD0182D14B401557957D57CE4B409A5FCD0182D14B40D36A48DC63CD4B408ECEF9298ECF4B40D36A48DC63CD4B40
19628	Новоключево	7	61	798	55.770090000000003	55.787121999999997	55.591315000000002	55.578330000000001	0103000020E61000000100000005000000037D224F92E24B40D925AAB706CA4B40037D224F92E24B402F51BD35B0CB4B4026FBE769C0E44B402F51BD35B0CB4B4026FBE769C0E44B40D925AAB706CA4B40037D224F92E24B40D925AAB706CA4B40
58865	Новокильметово	7	61	798	55.568292	55.583464999999997	55.65466	55.646222999999999	0103000020E610000001000000050000000A4AD1CABDC84B4025766D6FB7D24B400A4AD1CABDC84B40EBFF1CE6CBD34B4029AE2AFBAECA4B40EBFF1CE6CBD34B4029AE2AFBAECA4B4025766D6FB7D24B400A4AD1CABDC84B4025766D6FB7D24B40
58825	Новокарачево	7	61	798	56.005969	56.019893000000003	55.673493999999998	55.658617	0103000020E6100000010000000500000019E59997C3004C4079CBD58F4DD44B4019E59997C3004C40AF06280D35D64B40AD3594DA8B024C40AF06280D35D64B40AD3594DA8B024C4079CBD58F4DD44B4019E59997C3004C4079CBD58F4DD44B40
19131	Нововаськино	7	61	798	56.000031999999997	56.013326999999997	55.530149000000002	55.518092000000003	0103000020E610000001000000050000000B7A6F0C01004C40DD28B2D650C24B400B7A6F0C01004C40E98024ECDBC34B40AF93FAB2B4014C40E98024ECDBC34B40AF93FAB2B4014C40DD28B2D650C24B400B7A6F0C01004C40DD28B2D650C24B40
19761	Нижнесорокино	7	61	798	55.941209999999998	55.953921000000001	55.607259999999997	55.595511000000002	0103000020E610000001000000050000008655BC9179F84B4042B456B439CC4B408655BC9179F84B40A01518B2BACD4B40DBFB54151AFA4B40A01518B2BACD4B40DBFB54151AFA4B4042B456B439CC4B408655BC9179F84B4042B456B439CC4B40
33060	Мишкино	7	61	798	55.945261000000002	55.981383000000001	55.551476000000001	55.516593	0103000020E610000001000000050000009697FC4FFEF84B40D82B2CB81FC24B409697FC4FFEF84B40B343FCC396C64B40D9EC48F59DFD4B40B343FCC396C64B40D9EC48F59DFD4B40D82B2CB81FC24B409697FC4FFEF84B40D82B2CB81FC24B40
20619	Малые Шады	7	61	798	55.793401000000003	55.810253000000003	55.611007000000001	55.600745000000003	0103000020E610000001000000050000008ECEF9298EE54B40261E5036E5CC4B408ECEF9298EE54B404450357A35CE4B40323ECC5EB6E74B404450357A35CE4B40323ECC5EB6E74B40261E5036E5CC4B408ECEF9298EE54B40261E5036E5CC4B40
58851	Малонакоряково	7	61	798	56.113956000000002	56.141058000000001	55.651994000000002	55.640065999999997	0103000020E610000001000000050000006C97361C960E4C4009A4C4AEEDD14B406C97361C960E4C401898158A74D34B406A6B44300E124C401898158A74D34B406A6B44300E124C4009A4C4AEEDD14B406C97361C960E4C4009A4C4AEEDD14B40
21448	Лепешкино	7	61	798	55.666676000000002	55.682262000000001	55.711326	55.699086000000001	0103000020E610000001000000050000009983A0A355D54B40B58B69A67BD94B409983A0A355D54B40B265F9BA0CDB4B40DBA6785C54D74B40B265F9BA0CDB4B40DBA6785C54D74B40B58B69A67BD94B409983A0A355D54B40B58B69A67BD94B40
58170	Красный Ключ	7	61	798	56.205575000000003	56.222275000000003	55.439712	55.431673000000004	0103000020E6100000010000000500000007F01648501A4C407AC8940F41B74B4007F01648501A4C4052D4997B48B84B40F5DBD781731C4C4052D4997B48B84B40F5DBD781731C4C407AC8940F41B74B4007F01648501A4C407AC8940F41B74B40
19548	Кигазытамаково	7	61	798	55.829118000000001	55.853166000000002	55.491436999999998	55.468035	0103000020E610000001000000050000003143E38920EA4B4012312592E8BB4B403143E38920EA4B40AD855968E7BE4B409207228B34ED4B40AD855968E7BE4B409207228B34ED4B4012312592E8BB4B403143E38920EA4B4012312592E8BB4B40
11033	Камеево	7	61	798	56.077897999999998	56.101703000000001	55.481923999999999	55.456463999999997	0103000020E610000001000000050000003F36C98FF8094C4092E68F696DBA4B403F36C98FF8094C40299485AFAFBD4B40DA73999A040D4C40299485AFAFBD4B40DA73999A040D4C4092E68F696DBA4B403F36C98FF8094C4092E68F696DBA4B40
20774	Кайраково	7	61	798	55.704934999999999	55.724285000000002	55.557327000000001	55.547809999999998	0103000020E610000001000000050000002367614F3BDA4B40FC3559A31EC64B402367614F3BDA4B40C216BB7D56C74B40DFFDF15EB5DC4B40C216BB7D56C74B40DFFDF15EB5DC4B40FC3559A31EC64B402367614F3BDA4B40FC3559A31EC64B40
20510	Иштыбаево	7	61	798	55.881759000000002	55.903129999999997	55.657271000000001	55.643571000000001	0103000020E6100000010000000500000012FA997ADDF04B40B7D3D68860D24B4012FA997ADDF04B40FBCDC47421D44B40AB048BC399F34B40FBCDC47421D44B40AB048BC399F34B40B7D3D68860D24B4012FA997ADDF04B40B7D3D68860D24B40
47180	Ишимово	7	61	798	55.630465000000001	55.640355	55.753042999999998	55.741003999999997	0103000020E61000000100000005000000E622BE13B3D04B40431A1538D9DE4B40E622BE13B3D04B40A9BD88B663E04B40406A1327F7D14B40A9BD88B663E04B40406A1327F7D14B40431A1538D9DE4B40E622BE13B3D04B40431A1538D9DE4B40
19792	Ирсаево	7	61	798	55.949412000000002	55.963586999999997	55.576090999999998	55.558086000000003	0103000020E610000001000000050000000937195586F94B40802DAF5C6FC74B400937195586F94B408D429259BDC94B40E5EC9DD156FB4B408D429259BDC94B40E5EC9DD156FB4B40802DAF5C6FC74B400937195586F94B40802DAF5C6FC74B40
21075	Изимарино	7	61	798	55.386355999999999	55.413009000000002	55.606482	55.596426999999998	0103000020E61000000100000005000000834E081D74B14B40C7B94DB857CC4B40834E081D74B14B406CCEC133A1CD4B4012FA997ADDB44B406CCEC133A1CD4B4012FA997ADDB44B40C7B94DB857CC4B40834E081D74B14B40C7B94DB857CC4B40
46546	Елышево	7	61	798	56.005592	56.023108999999998	55.609706000000003	55.595877000000002	0103000020E61000000100000005000000438F183DB7004C4024B891B245CC4B40438F183DB7004C406616A1D80ACE4B40239F573CF5024C406616A1D80ACE4B40239F573CF5024C4024B891B245CC4B40438F183DB7004C4024B891B245CC4B40
19707	Верхнесорокино	7	61	798	55.896006999999997	55.909742000000001	55.602418	55.587494	0103000020E6100000010000000500000058FE7C5BB0F24B40514CDE0033CB4B4058FE7C5BB0F24B40C84274081CCD4B4019E6046D72F44B40C84274081CCD4B4019E6046D72F44B40514CDE0033CB4B4058FE7C5BB0F24B40514CDE0033CB4B40
21354	Букленды	7	61	798	55.62547	55.644128000000002	55.650663000000002	55.642026999999999	0103000020E610000001000000050000008750A5660FD04B401213D4F02DD24B408750A5660FD04B40CFDBD8EC48D34B400D384BC972D24B40CFDBD8EC48D34B400D384BC972D24B401213D4F02DD24B408750A5660FD04B401213D4F02DD24B40
20556	Большие Шады	7	61	798	55.800094000000001	55.823692000000001	55.664147	55.648198999999998	0103000020E61000000100000005000000E8DCED7A69E64B406326512FF8D24B40E8DCED7A69E64B40465ED6C402D54B4009FD4CBD6EE94B40465ED6C402D54B4009FD4CBD6EE94B406326512FF8D24B40E8DCED7A69E64B406326512FF8D24B40
20944	Большесухоязово	7	61	798	55.531478999999997	55.567466000000003	55.578152000000003	55.557856999999998	0103000020E6100000010000000500000061C1FD8007C44B401E6CB1DB67C74B4061C1FD8007C44B40FA0E7EE200CA4B40C5CBD3B9A2C84B40FA0E7EE200CA4B40C5CBD3B9A2C84B401E6CB1DB67C74B4061C1FD8007C44B401E6CB1DB67C74B40
6889	Бирюбаш	7	61	798	56.201639999999998	56.221251000000002	55.702703	55.680067000000001	0103000020E6100000010000000500000060C8EA56CF194C405F0B7A6F0CD74B4060C8EA56CF194C408AE6012CF2D94B40899AE8F3511C4C408AE6012CF2D94B40899AE8F3511C4C405F0B7A6F0CD74B4060C8EA56CF194C405F0B7A6F0CD74B40
20731	Бикшиково	7	61	798	55.679251999999998	55.698773000000003	55.522872	55.514783999999999	0103000020E610000001000000050000000DDFC2BAF1D64B4085402E71E4C14B400DDFC2BAF1D64B403FFF3D78EDC24B40F629C76471D94B403FFF3D78EDC24B40F629C76471D94B4085402E71E4C14B400DDFC2BAF1D64B4085402E71E4C14B40
18710	Байтурово	7	61	798	56.195675999999999	56.227521000000003	55.409875999999997	55.401221999999997	0103000020E61000000100000005000000594E42E90B194C40C537143E5BB34B40594E42E90B194C4028B517D176B44B409D137B681F1D4C4028B517D176B44B409D137B681F1D4C40C537143E5BB34B40594E42E90B194C40C537143E5BB34B40
46005	Бабаево	7	61	798	56.113354000000001	56.144418000000002	55.508682	55.491840000000003	0103000020E61000000100000005000000766F4562820E4C40AD6EF59CF4BE4B40766F4562820E4C402D08E57D1CC14B40147AFD497C124C402D08E57D1CC14B40147AFD497C124C40AD6EF59CF4BE4B40766F4562820E4C40AD6EF59CF4BE4B40
58542	Юнусово	7	61	237	58.377926000000002	58.397041999999999	55.829315000000001	55.819004	0103000020E61000000100000005000000702711E15F304D4087A5811FD5E84B40702711E15F304D40878A71FE26EA4B40B891B245D2324D40878A71FE26EA4B40B891B245D2324D4087A5811FD5E84B40702711E15F304D4087A5811FD5E84B40
17193	Такино	7	61	237	58.589578000000003	58.608209000000002	56.075251999999999	56.058720000000001	0103000020E610000001000000050000007638BA4A774B4D4081CF0F2384074C407638BA4A774B4D40B37A87DBA1094C400211E2CAD94D4D40B37A87DBA1094C400211E2CAD94D4D4081CF0F2384074C407638BA4A774B4D4081CF0F2384074C40
17531	Таишево	7	61	237	58.435445000000001	58.470793999999998	55.765239999999999	55.755282000000001	0103000020E61000000100000005000000761A69A9BC374D40F5A0A014ADE04B40761A69A9BC374D40A7CB6262F3E14B40969350FA423C4D40A7CB6262F3E14B40969350FA423C4D40F5A0A014ADE04B40761A69A9BC374D40F5A0A014ADE04B40
45704	Сулейманово	7	61	237	58.324413	58.351425999999996	55.804409999999997	55.794705	0103000020E61000000100000005000000D9B27C5D86294D40DD7BB8E4B8E54B40D9B27C5D86294D40A54929E8F6E64B40677BF486FB2C4D40A54929E8F6E64B40677BF486FB2C4D40DD7BB8E4B8E54B40D9B27C5D86294D40DD7BB8E4B8E54B40
58788	Степной	7	61	237	58.114063999999999	58.132021000000002	56.037906	56.028188	0103000020E6100000010000000500000052D32EA6990E4D40E01115AA9B034C4052D32EA6990E4D403D29931ADA044C404FB16A10E6104D403D29931ADA044C404FB16A10E6104D40E01115AA9B034C4052D32EA6990E4D40E01115AA9B034C40
17798	Старомещерово	7	61	237	58.402808999999998	58.417954999999999	55.741616999999998	55.730781	0103000020E6100000010000000500000069C4CC3E8F334D40E3C4573B8ADD4B4069C4CC3E8F334D402D944C4EEDDE4B408F19A88C7F354D402D944C4EEDDE4B408F19A88C7F354D40E3C4573B8ADD4B4069C4CC3E8F334D40E3C4573B8ADD4B40
58860	Средняя Ока	7	61	237	57.896096999999997	58.831674	56.173006000000001	55.613128000000003	0103000020E610000001000000050000009885764EB3F24C40862172FA7ACE4B409885764EB3F24C408201840F25164C407D772B4B746A4D408201840F25164C407D772B4B746A4D40862172FA7ACE4B409885764EB3F24C40862172FA7ACE4B40
58724	Сосновка	7	61	237	58.089486000000001	58.104587000000002	55.979948999999998	55.971626999999998	0103000020E6100000010000000500000095B9F946740B4D408E7406465EFC4B4095B9F946740B4D40BB5F05F86EFD4B401B4B581B630D4D40BB5F05F86EFD4B401B4B581B630D4D408E7406465EFC4B4095B9F946740B4D408E7406465EFC4B40
58544	Сальзигутово	7	61	237	58.216903000000002	58.233719000000001	55.920689000000003	55.911814999999997	0103000020E61000000100000005000000C0B33D7AC31B4D4049809A5AB6F44B40C0B33D7AC31B4D40BB641C23D9F54B4017BA1281EA1D4D40BB641C23D9F54B4017BA1281EA1D4D4049809A5AB6F44B40C0B33D7AC31B4D4049809A5AB6F44B40
17920	Сабанаково	7	61	237	58.245441999999997	58.268358999999997	55.881359000000003	55.873106999999997	0103000020E610000001000000050000004C88B9A46A1F4D404F745DF8C1EF4B404C88B9A46A1F4D408484285FD0F04B402B4B749659224D408484285FD0F04B402B4B749659224D404F745DF8C1EF4B404C88B9A46A1F4D404F745DF8C1EF4B40
17632	Новомещерово	7	61	237	58.385921000000003	58.413876999999999	55.709870000000002	55.692577	0103000020E6100000010000000500000079EBFCDB65314D401C7BF65CA6D84B4079EBFCDB65314D40AD342905DDDA4B4086C8E9EBF9344D40AD342905DDDA4B4086C8E9EBF9344D401C7BF65CA6D84B4079EBFCDB65314D401C7BF65CA6D84B40
16678	Нижние Тукбаево	7	61	237	58.182380999999999	58.211136000000003	55.68974	55.677371999999998	0103000020E61000000100000005000000B534B74258174D40F19C2D20B4D64B40B534B74258174D401C5F7B6649D84B400F812381061B4D401C5F7B6649D84B400F812381061B4D40F19C2D20B4D64B40B534B74258174D40F19C2D20B4D64B40
17071	Нижние Бобино	7	61	237	58.356527999999997	58.403078999999998	55.999625999999999	55.984597000000001	0103000020E61000000100000005000000DC0DA2B5A22D4D40AF5E454607FE4B40DC0DA2B5A22D4D409B1DA9BEF3FF4B40295AB91798334D409B1DA9BEF3FF4B40295AB91798334D40AF5E454607FE4B40DC0DA2B5A22D4D40AF5E454607FE4B40
18135	Мелекасово	7	61	237	57.966012999999997	57.992037000000003	55.936101000000001	55.919347000000002	0103000020E6100000010000000500000063416150A6FB4C407E569929ADF54B4063416150A6FB4C405F605628D2F74B4003B68311FBFE4C405F605628D2F74B4003B68311FBFE4C407E569929ADF54B4063416150A6FB4C407E569929ADF54B40
17051	Малоустьикинское	7	61	237	58.299520999999999	58.362718000000001	55.998725	55.977606999999999	0103000020E610000001000000050000008CBB41B456264D409BABE63922FD4B408CBB41B456264D404B598638D6FF4B40D4D51D8B6D2E4D404B598638D6FF4B40D4D51D8B6D2E4D409BABE63922FD4B408CBB41B456264D409BABE63922FD4B40
29945	Лемез-Тамак	7	61	237	58.252206999999999	58.283746999999998	55.838531000000003	55.822079000000002	0103000020E610000001000000050000004069A85148204D403CDD79E239E94B404069A85148204D4052D7DAFB54EB4B4047AB5AD251244D4052D7DAFB54EB4B4047AB5AD251244D403CDD79E239E94B404069A85148204D403CDD79E239E94B40
17149	Кургатово	7	61	237	58.501919999999998	58.543098999999998	56.149099999999997	56.1342	0103000020E61000000100000005000000AA9A20EA3E404D40C58F31772D114C40AA9A20EA3E404D40B3EA73B515134C40C2BE9D4484454D40B3EA73B515134C40C2BE9D4484454D40C58F31772D114C40AA9A20EA3E404D40C58F31772D114C40
58800	Ключевой	7	61	237	58.056176000000001	58.080888999999999	56.079583	56.070746	0103000020E61000000100000005000000F96871C630074D40522976340E094C40F96871C630074D40A62897C62F0A4C4096CD1C925A0A4D40A62897C62F0A4C4096CD1C925A0A4D40522976340E094C40F96871C630074D40522976340E094C40
58444	Каранаево	7	61	237	58.288570999999997	58.302629000000003	55.642640999999998	55.636854	0103000020E6100000010000000500000079C9FFE4EF244D40D4298F6E84D14B4079C9FFE4EF244D40CC086F0F42D24B401DE90C8CBC264D40CC086F0F42D24B401DE90C8CBC264D40D4298F6E84D14B4079C9FFE4EF244D40D4298F6E84D14B40
5576	Ишалино	7	61	237	58.534807999999998	58.557049999999997	56.010618999999998	55.998479000000003	0103000020E61000000100000005000000D0D1AA9674444D40145FED28CEFF4B40D0D1AA9674444D40ADDBA0F65B014C404F1E166A4D474D40ADDBA0F65B014C404F1E166A4D474D40145FED28CEFF4B40D0D1AA9674444D40145FED28CEFF4B40
26539	Еланыш	7	61	237	58.291113000000003	58.322930999999997	55.701962999999999	55.689791	0103000020E610000001000000050000006138D73043254D409E094D124BD84B406138D73043254D40430070ECD9D94B40AAEE91CD55294D40430070ECD9D94B40AAEE91CD55294D409E094D124BD84B406138D73043254D409E094D124BD84B40
47236	Гумерово	7	61	237	58.313282999999998	58.332228999999998	55.662674000000003	55.653979999999997	0103000020E6100000010000000500000046B247A819284D40791EDC9DB5D34B4046B247A819284D406BF46A80D2D44B4032E4D87A862A4D406BF46A80D2D44B4032E4D87A862A4D40791EDC9DB5D34B4046B247A819284D40791EDC9DB5D34B40
18035	Буртаковка	7	61	237	58.099170000000001	58.114792000000001	55.904840999999998	55.894672	0103000020E61000000100000005000000465F419AB10C4D40CE52B29C84F24B40465F419AB10C4D403B8A73D4D1F34B40D5EB1681B10E4D403B8A73D4D1F34B40D5EB1681B10E4D40CE52B29C84F24B40465F419AB10C4D40CE52B29C84F24B40
8327	Буранчино	7	61	237	58.235947000000003	58.253087000000001	55.680509000000001	55.669365999999997	0103000020E610000001000000050000006F4BE482331E4D40F486FBC8ADD54B406F4BE482331E4D401CD13DEB1AD74B407905A22765204D401CD13DEB1AD74B407905A22765204D40F486FBC8ADD54B406F4BE482331E4D40F486FBC8ADD54B40
58146	Большеустьикинское	7	61	237	57.896096999999997	58.831674	56.173006000000001	55.613128000000003	0103000020E610000001000000050000009885764EB3F24C40862172FA7ACE4B409885764EB3F24C408201840F25164C407D772B4B746A4D408201840F25164C407D772B4B746A4D40862172FA7ACE4B409885764EB3F24C40862172FA7ACE4B40
18247	Большекызылбаево	7	61	237	58.060785000000003	58.089809000000002	55.974936999999997	55.957242000000001	0103000020E610000001000000050000002F8B89CDC7074D40C72DE6E786FA4B402F8B89CDC7074D40865451BCCAFC4B4078F17EDC7E0B4D40865451BCCAFC4B4078F17EDC7E0B4D40C72DE6E786FA4B402F8B89CDC7074D40C72DE6E786FA4B40
18390	Большая Ока	7	61	237	58.181562999999997	58.234205000000003	56.098782999999997	56.052546999999997	0103000020E61000000100000005000000F294D5743D174D405F402FDCB9064C40F294D5743D174D404C33DDEBA40C4C40A4C7EF6DFA1D4D404C33DDEBA40C4C40A4C7EF6DFA1D4D405F402FDCB9064C40F294D5743D174D405F402FDCB9064C40
58145	Болшеустьикинское	7	61	237	58.241939000000002	58.29909	55.962553999999997	55.927230000000002	0103000020E6100000010000000500000040506EDBF71E4D405FEFFE78AFF64B4040506EDBF71E4D4026512FF834FB4B40C347C49448264D4026512FF834FB4B40C347C49448264D405FEFFE78AFF64B4040506EDBF71E4D405FEFFE78AFF64B40
17384	Аюпово	7	61	237	58.295406999999997	58.312663000000001	55.865257999999997	55.854835000000001	0103000020E61000000100000005000000360186E5CF254D40F33CB83B6BED4B40360186E5CF254D401A4D2EC6C0EE4B40AAD5575705284D401A4D2EC6C0EE4B40AAD5575705284D40F33CB83B6BED4B40360186E5CF254D40F33CB83B6BED4B40
18099	Алегазово	7	61	237	58.092136000000004	58.149133999999997	55.945104999999998	55.928865000000002	0103000020E610000001000000050000006364C91CCB0B4D4014B35E0CE5F64B406364C91CCB0B4D409E245D33F9F84B405F5CAAD216134D409E245D33F9F84B405F5CAAD216134D4014B35E0CE5F64B406364C91CCB0B4D4014B35E0CE5F64B40
931	Азикеево	7	61	237	58.241830999999998	58.278986000000003	56.039852000000003	56.017543000000003	0103000020E6100000010000000500000059147651F41E4D400AA359D93E024C4059147651F41E4D401157CEDE19054C405C0531D0B5234D401157CEDE19054C405C0531D0B5234D400AA359D93E024C4059147651F41E4D400AA359D93E024C40
17599	Азангулово	7	61	237	58.433225999999998	58.456474999999998	55.749890999999998	55.742164000000002	0103000020E6100000010000000500000071E316F373374D406022DE3AFFDE4B4071E316F373374D404948A46DFCDF4B408638D6C56D3A4D404948A46DFCDF4B408638D6C56D3A4D406022DE3AFFDE4B4071E316F373374D406022DE3AFFDE4B40
5479	Абдуллино	7	61	237	57.933394999999997	57.996932999999999	56.078190999999997	56.058855000000001	0103000020E61000000100000005000000FD9FC37C79F74C40611A868F88074C40FD9FC37C79F74C40B7EBA529020A4C40CEA623809BFF4C40B7EBA529020A4C40CEA623809BFF4C40611A868F88074C40FD9FC37C79F74C40611A868F88074C40
17428	Абдрахимово	7	61	237	58.305135999999997	58.330368999999997	55.834381	55.818396999999997	0103000020E61000000100000005000000876A4AB20E274D407F129F3BC1E84B40876A4AB20E274D40AFB321FFCCEA4B405D4E0988492A4D40AFB321FFCCEA4B405D4E0988492A4D407F129F3BC1E84B40876A4AB20E274D407F129F3BC1E84B40
58376	д. Первомайский	7	61	179	55.553156000000001	56.902928000000003	53.390208000000001	52.814706000000001	0103000020E6100000010000000500000008CBD8D0CDC64B4070ED444948684A4008CBD8D0CDC64B409C51F355F2B14A4044520B2593734C409C51F355F2B14A4044520B2593734C4070ED444948684A4008CBD8D0CDC64B4070ED444948684A40
15671	Юмаково	7	61	179	55.962536	55.980502000000001	53.183813999999998	53.162725999999999	0103000020E61000000100000005000000809C306134FB4B40BD1AA034D4944A40809C306134FB4B400246973787974A40D0D4EB1681FD4B400246973787974A40D0D4EB1681FD4B40BD1AA034D4944A40809C306134FB4B40BD1AA034D4944A40
16747	Узя	7	61	179	56.056562999999997	56.065069999999999	52.985920999999998	52.966867000000001	0103000020E61000000100000005000000F294D5743D074C40734A404CC27B4A40F294D5743D074C4045B8C9A8327E4A40B1F9B83654084C4045B8C9A8327E4A40B1F9B83654084C40734A404CC27B4A40F294D5743D074C40734A404CC27B4A40
15124	Троицкое	7	61	179	55.785046999999999	55.855286	53.033324999999998	52.997391	0103000020E6100000010000000500000055698B6B7CE44B4091291F82AA7F4A4055698B6B7CE44B40D1915CFE43844A40035DFB027AED4B40D1915CFE43844A40035DFB027AED4B4091291F82AA7F4A4055698B6B7CE44B4091291F82AA7F4A40
15509	Сухаревка	7	61	179	55.767853000000002	55.786169999999998	53.285792999999998	53.262045999999998	0103000020E610000001000000050000005891D10149E24B4018062CB98AA14A405891D10149E24B407E3672DD94A44A40548CF337A1E44B407E3672DD94A44A40548CF337A1E44B4018062CB98AA14A405891D10149E24B4018062CB98AA14A40
15853	Смаково	7	61	179	56.060299999999998	56.077385999999997	53.042546000000002	53.028174999999997	0103000020E6100000010000000500000072F90FE9B7074C404BC8073D9B834A4072F90FE9B7074C40AE49B72572854A408995D1C8E7094C40AE49B72572854A408995D1C8E7094C404BC8073D9B834A4072F90FE9B7074C404BC8073D9B834A40
16161	Сергеевка	7	61	179	56.477997999999999	56.494410000000002	53.072816000000003	53.063650000000003	0103000020E61000000100000005000000D6C6D8092F3D4C40F931E6AE25884A40D6C6D8092F3D4C401250E10852894A405E68AED3483F4C401250E10852894A405E68AED3483F4C40F931E6AE25884A40D6C6D8092F3D4C40F931E6AE25884A40
16263	Сарышево	7	61	179	56.311639	56.340474999999998	52.913156999999998	52.901045000000003	0103000020E610000001000000050000003E9468C9E3274C40B79C4B7155734A403E9468C9E3274C40868E1D54E2744A40840D4FAF942B4C40868E1D54E2744A40840D4FAF942B4C40B79C4B7155734A403E9468C9E3274C40B79C4B7155734A40
16558	Самаро-Ивановка	7	61	179	56.049906	56.067863000000003	52.955627999999997	52.934949000000003	0103000020E61000000100000005000000E5EFDE5163064C40C636A968AC774A40E5EFDE5163064C402992AF04527A4A40E2CD1ABCAF084C402992AF04527A4A40E2CD1ABCAF084C40C636A968AC774A40E5EFDE5163064C40C636A968AC774A40
15030	Саитовский	7	61	179	55.608823999999998	55.628318	53.042541	53.031024000000002	0103000020E610000001000000050000008C82E0F1EDCD4B4010B22C98F8834A408C82E0F1EDCD4B409CDEC5FB71854A407BBE66B96CD04B409CDEC5FB71854A407BBE66B96CD04B4010B22C98F8834A408C82E0F1EDCD4B4010B22C98F8834A40
15580	Сабашево	7	61	179	55.949627	55.964655999999998	53.259093999999997	53.247646000000003	0103000020E610000001000000050000000533A6608DF94B401C7E37DDB29F4A400533A6608DF94B407F4B00FE29A14A40F1F109D979FB4B407F4B00FE29A14A40F1F109D979FB4B401C7E37DDB29F4A400533A6608DF94B401C7E37DDB29F4A40
46848	Рассвет	7	61	179	55.871366000000002	55.891964000000002	52.933357999999998	52.918157999999998	0103000020E61000000100000005000000556CCCEB88EF4B40C7478B3386754A40556CCCEB88EF4B40E0BA624678774A40CC9A58E02BF24B40E0BA624678774A40CC9A58E02BF24B40C7478B3386754A40556CCCEB88EF4B40C7478B3386754A40
14974	Петропавловка	7	61	179	55.689276999999997	55.705151000000001	53.123111999999999	53.099929000000003	0103000020E6100000010000000500000047718E3A3AD84B4004763579CA8C4A4047718E3A3AD84B4061DF4E22C28F4A40F0DE516342DA4B4061DF4E22C28F4A40F0DE516342DA4B4004763579CA8C4A4047718E3A3AD84B4004763579CA8C4A40
58742	Озерки	7	61	179	55.776170999999998	55.802070000000001	52.924737999999998	52.913749000000003	0103000020E61000000100000005000000438D429259E34B4059E02BBAF5744A40438D429259E34B4029AF95D05D764A40268DD13AAAE64B4029AF95D05D764A40268DD13AAAE64B4059E02BBAF5744A40438D429259E34B4059E02BBAF5744A40
16144	Нугуш	7	61	179	56.427621000000002	56.451785000000001	53.047818999999997	53.036428000000001	0103000020E610000001000000050000009A0AF148BC364C40505436ACA9844A409A0AF148BC364C404F90D8EE1E864A4064E94317D4394C404F90D8EE1E864A4064E94317D4394C40505436ACA9844A409A0AF148BC364C40505436ACA9844A40
15209	Нордовка	7	61	179	55.583519000000003	55.611339999999998	53.254941000000002	53.227995999999997	0103000020E610000001000000050000001DCC26C0B0CA4B4035CF11F92E9D4A401DCC26C0B0CA4B406CB41CE8A1A04A404A5E9D6340CE4B406CB41CE8A1A04A404A5E9D6340CE4B4035CF11F92E9D4A401DCC26C0B0CA4B4035CF11F92E9D4A40
46136	Новый Краснояр	7	61	179	55.662318999999997	55.683016000000002	53.345295999999998	53.334097	0103000020E610000001000000050000007C4276DEC6D44B408A58C4B0C3AA4A407C4276DEC6D44B4045B8C9A832AC4A4087527B116DD74B4045B8C9A832AC4A4087527B116DD74B408A58C4B0C3AA4A407C4276DEC6D44B408A58C4B0C3AA4A40
13759	Мелеуз	7	61	179	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
14852	Кутушево	7	61	179	55.953175000000002	55.968643999999998	53.015137000000003	53.003428	0103000020E61000000100000005000000B22E6EA301FA4B4002F2255470804A40B22E6EA301FA4B40D3FA5B02F0814A40BABBCE86FCFB4B40D3FA5B02F0814A40BABBCE86FCFB4B4002F2255470804A40B22E6EA301FA4B4002F2255470804A40
15363	Корнеевка	7	61	179	55.787965999999997	55.805115000000001	53.340398	53.314109999999999	0103000020E61000000100000005000000122EE411DCE44B405CACA8C134A84A40122EE411DCE44B40D9CF622992AB4A40704221020EE74B40D9CF622992AB4A40704221020EE74B405CACA8C134A84A40122EE411DCE44B405CACA8C134A84A40
58118	Константиновка	7	61	179	55.861061999999997	55.874833000000002	53.337774000000003	53.330461	0103000020E6100000010000000500000007EA944737EE4B403ECDC98B4CAA4A4007EA944737EE4B4035B8AD2D3CAB4A40153B1A87FAEF4B4035B8AD2D3CAB4A40153B1A87FAEF4B403ECDC98B4CAA4A4007EA944737EE4B403ECDC98B4CAA4A40
559	Кизрай	7	61	179	56.131535999999997	56.149152000000001	52.972057	52.961378000000003	0103000020E61000000100000005000000921FF12BD6104C40058C2E6F0E7B4A40921FF12BD6104C40876C205D6C7C4A400611A96917134C40876C205D6C7C4A400611A96917134C40058C2E6F0E7B4A40921FF12BD6104C40058C2E6F0E7B4A40
14785	Каран	7	61	179	55.912391999999997	55.924025	52.928918000000003	52.919586000000002	0103000020E61000000100000005000000E690D442C9F44B4003EE79FEB4754A40E690D442C9F44B403755F7C8E6764A40DCD7817346F64B403755F7C8E6764A40DCD7817346F64B4003EE79FEB4754A40E690D442C9F44B4003EE79FEB4754A40
5950	Иштуганово	7	61	179	56.425986000000002	56.454543000000001	52.973233999999998	52.954006	0103000020E61000000100000005000000E54691B586364C4009185DDE1C7A4A40E54691B586364C4079AD84EE927C4A4018D00B772E3A4C4079AD84EE927C4A4018D00B772E3A4C4009185DDE1C7A4A40E54691B586364C4009185DDE1C7A4A40
15677	Зирган	7	61	179	55.906472000000001	55.936036000000001	53.250114000000004	53.202632000000001	0103000020E61000000100000005000000AF5E454607F44B40C18F6AD8EF994A40AF5E454607F44B40C9224DBC03A04A4078F01307D0F74B40C9224DBC03A04A4078F01307D0F74B40C18F6AD8EF994A40AF5E454607F44B40C18F6AD8EF994A40
15277	Дмитриевка	7	61	179	55.725363000000002	55.741757	53.229894000000002	53.215251000000002	0103000020E610000001000000050000003E5DDDB1D8DC4B4035B742588D9B4A403E5DDDB1D8DC4B40F8C5A52A6D9D4A401F4AB4E4F1DE4B40F8C5A52A6D9D4A401F4AB4E4F1DE4B4035B742588D9B4A403E5DDDB1D8DC4B4035B742588D9B4A40
15058	Дарьино	7	61	179	55.853327999999998	55.912759999999999	53.060760000000002	53.035420999999999	0103000020E610000001000000050000006B6116DA39ED4B40BA4BE2AC88844A406B6116DA39ED4B40D673D2FBC6874A40698CD651D5F44B40D673D2FBC6874A40698CD651D5F44B40BA4BE2AC88844A406B6116DA39ED4B40BA4BE2AC88844A40
15488	Даниловка	7	61	179	55.642763000000002	55.668894999999999	53.332596000000002	53.321916000000002	0103000020E61000000100000005000000180AD80E46D24B409207228B34A94A40180AD80E46D24B40E563778192AA4A409DBAF2599ED54B40E563778192AA4A409DBAF2599ED54B409207228B34A94A40180AD80E46D24B409207228B34A94A40
46777	Восточное	7	61	179	56.280144	56.296520999999998	52.964545999999999	52.954737999999999	0103000020E61000000100000005000000D71533C2DB234C40CD1FD3DA347A4A40D71533C2DB234C406ABE4A3E767B4A40E2C96E66F4254C406ABE4A3E767B4A40E2C96E66F4254C40CD1FD3DA347A4A40D71533C2DB234C40CD1FD3DA347A4A40
58213	Воскресенское	7	61	179	56.122526000000001	56.161467999999999	53.138207999999999	53.108822000000004	0103000020E61000000100000005000000717495EEAE0F4C40EC8A19E1ED8D4A40717495EEAE0F4C40D505BCCCB0914A40DEACC1FBAA144C40D505BCCCB0914A40DEACC1FBAA144C40EC8A19E1ED8D4A40717495EEAE0F4C40EC8A19E1ED8D4A40
15872	Воскресенское	7	61	179	56.122526000000001	56.161467999999999	53.138207999999999	53.108822000000004	0103000020E61000000100000005000000717495EEAE0F4C40EC8A19E1ED8D4A40717495EEAE0F4C40D505BCCCB0914A40DEACC1FBAA144C40D505BCCCB0914A40DEACC1FBAA144C40EC8A19E1ED8D4A40717495EEAE0F4C40EC8A19E1ED8D4A40
15594	Верхнеюлдашево	7	61	179	55.966551000000003	55.986009000000003	53.317138999999997	53.303721000000003	0103000020E61000000100000005000000437573F1B7FB4B40E10D6954E0A64A40437573F1B7FB4B40A0A4C00298A84A40E547FC8A35FE4B40A0A4C00298A84A40E547FC8A35FE4B40E10D6954E0A64A40437573F1B7FB4B40E10D6954E0A64A40
15181	Васильевка	7	61	179	55.949339999999999	55.974313000000002	53.106406	53.081828999999999	0103000020E610000001000000050000006F641EF983F94B40A46E675F798A4A406F641EF983F94B40910C39B69E8D4A40A988D349B6FC4B40910C39B69E8D4A40A988D349B6FC4B40A46E675F798A4A406F641EF983F94B40A46E675F798A4A40
15309	Варварино	7	61	179	55.721338000000003	55.735081999999998	53.198014000000001	53.179150999999997	0103000020E6100000010000000500000058AEB7CD54DC4B40D905836BEE964A4058AEB7CD54DC4B403813D38558994A406BF0BE2A17DE4B403813D38558994A406BF0BE2A17DE4B40D905836BEE964A4058AEB7CD54DC4B40D905836BEE964A40
5876	Береговка	7	61	179	55.956068000000002	55.973261999999998	53.126905999999998	53.105508	0103000020E610000001000000050000004660AC6F60FA4B40B2BB4049818D4A404660AC6F60FA4B4045D5AF743E904A40433866D993FC4B4045D5AF743E904A40433866D993FC4B40B2BB4049818D4A404660AC6F60FA4B40B2BB4049818D4A40
16356	Аптраково	7	61	179	56.164952999999997	56.183351000000002	52.894418000000002	52.883485999999998	0103000020E6100000010000000500000044300E2E1D154C40A73CBA1116714A4044300E2E1D154C40147AFD497C724A402E58AA0B78174C40147AFD497C724A402E58AA0B78174C40A73CBA1116714A4044300E2E1D154C40A73CBA1116714A40
14894	Антоновка	7	61	179	55.725875000000002	55.754693000000003	52.911202000000003	52.901279000000002	0103000020E61000000100000005000000F4FDD478E9DC4B402AC93A1C5D734A40F4FDD478E9DC4B4060066344A2744A4094C2BCC799E04B4060066344A2744A4094C2BCC799E04B402AC93A1C5D734A40F4FDD478E9DC4B402AC93A1C5D734A40
15962	Александровка	7	61	179	56.236162999999998	56.261063999999998	53.051873999999998	53.018279	0103000020E610000001000000050000003BC3D4963A1E4C400F9A5DF756824A403BC3D4963A1E4C40A0C1A6CEA3864A40DB148F8B6A214C40A0C1A6CEA3864A40DB148F8B6A214C400F9A5DF756824A403BC3D4963A1E4C400F9A5DF756824A40
16365	Абитово	7	61	179	56.331159999999997	56.353833000000002	53.008896	53.001238999999998	0103000020E6100000010000000500000026DF6C73632A4C40683D7C9928804A4026DF6C73632A4C4059880E8123814A406F9F55664A2D4C4059880E8123814A406F9F55664A2D4C40683D7C9928804A4026DF6C73632A4C40683D7C9928804A40
12820	Ямансарово	7	61	531	55.996295000000003	56.007720999999997	52.585031000000001	52.579996999999999	0103000020E610000001000000050000008C15359886FF4B40996379573D4A4A408C15359886FF4B40B612BA4BE24A4A40073F7100FD004C40B612BA4BE24A4A40073F7100FD004C40996379573D4A4A408C15359886FF4B40996379573D4A4A40
13075	Ямангулово	7	61	531	55.929451	55.939602000000001	52.549258999999999	52.534669000000001	0103000020E61000000100000005000000041E1840F8F64B40AF97A60870444A40041E1840F8F64B404F04711E4E464A40CBA0DAE044F84B404F04711E4E464A40CBA0DAE044F84B40AF97A60870444A40041E1840F8F64B40AF97A60870444A40
12041	Ялчикаево	7	61	531	55.547136999999999	55.570556000000003	52.804102999999998	52.792603	0103000020E610000001000000050000003DB7D09508C64B4012DBDD0374654A403DB7D09508C64B40C8CEDBD8EC664A40AF44A0FA07C94B40C8CEDBD8EC664A40AF44A0FA07C94B4012DBDD0374654A403DB7D09508C64B4012DBDD0374654A40
13697	Якшимбетово	7	61	531	55.561366	55.584829999999997	52.566598999999997	52.555813999999998	0103000020E610000001000000050000000D8B51D7DAC74B405854C4E924474A400D8B51D7DAC74B402079E75086484A401EDC9DB5DBCA4B402079E75086484A401EDC9DB5DBCA4B405854C4E924474A400D8B51D7DAC74B405854C4E924474A40
58875	Якутово	7	61	531	55.105902	56.202907000000003	52.962105000000001	52.346147000000002	0103000020E610000001000000050000005E4A5D328E8D4B40E44D7E8B4E2C4A405E4A5D328E8D4B40B728B341267B4A40939048DBF8194C40B728B341267B4A40939048DBF8194C40E44D7E8B4E2C4A405E4A5D328E8D4B40E44D7E8B4E2C4A40
13636	Якупово	7	61	531	55.543723	55.564689999999999	52.635050999999997	52.621062999999999	0103000020E61000000100000005000000A08A1BB798C54B40B9E00CFE7E4F4A40A08A1BB798C54B406325E65949514A406A300DC347C84B406325E65949514A406A300DC347C84B40B9E00CFE7E4F4A40A08A1BB798C54B40B9E00CFE7E4F4A40
13605	Язлав	7	61	531	55.683186999999997	55.693868000000002	52.522818000000001	52.512383999999997	0103000020E61000000100000005000000B306EFAB72D74B40307F85CC95414A40B306EFAB72D74B404CE141B3EB424A40D7DEA7AAD0D84B404CE141B3EB424A40D7DEA7AAD0D84B40307F85CC95414A40B306EFAB72D74B40307F85CC95414A40
13192	Юшатырка	7	61	531	55.79898	55.806552000000003	52.497968	52.489513000000002	0103000020E610000001000000050000003C1405FA44E64B40C2FBAA5CA83E4A403C1405FA44E64B402E3A596ABD3F4A40FF428F183DE74B402E3A596ABD3F4A40FF428F183DE74B40C2FBAA5CA83E4A403C1405FA44E64B40C2FBAA5CA83E4A40
12325	Юмагузино	7	61	531	55.832234999999997	55.851854000000003	52.906531000000001	52.896901	0103000020E6100000010000000500000014CB2DAD86EA4B40F65FE7A6CD724A4014CB2DAD86EA4B40B4E7323509744A40C07B478D09ED4B40B4E7323509744A40C07B478D09ED4B40F65FE7A6CD724A4014CB2DAD86EA4B40F65FE7A6CD724A40
3948	Шабагиш	7	61	531	55.692404000000003	55.721141000000003	52.734972999999997	52.720750000000002	0103000020E610000001000000050000004FCFBBB1A0D84B40C74B3789415C4A404FCFBBB1A0D84B40B4386398135E4A40026729594EDC4B40B4386398135E4A40026729594EDC4B40C74B3789415C4A404FCFBBB1A0D84B40C74B3789415C4A40
12408	Холодный Ключ	7	61	531	55.620798999999998	55.645386000000002	52.744208999999998	52.731259999999999	0103000020E61000000100000005000000DB31755776CF4B40BD6F7CED995D4A40DB31755776CF4B40C631923D425F4A40ECA529029CD24B40C631923D425F4A40ECA529029CD24B40BD6F7CED995D4A40DB31755776CF4B40BD6F7CED995D4A40
11921	Свобода	7	61	531	55.425325000000001	55.451546999999998	52.763907000000003	52.744073	0103000020E61000000100000005000000EA95B20C71B64B40166BB8C83D5F4A40EA95B20C71B64B40BE175FB4C7614A40AFCDC64ACCB94B40BE175FB4C7614A40AFCDC64ACCB94B40166BB8C83D5F4A40EA95B20C71B64B40166BB8C83D5F4A40
12760	Павловка	7	61	531	56.083556999999999	56.095872999999997	52.671335999999997	52.664603	0103000020E610000001000000050000000A2DEBFEB10A4C4068E90AB611554A400A2DEBFEB10A4C4050508A56EE554A40E2C80391450C4C4050508A56EE554A40E2C80391450C4C4068E90AB611554A400A2DEBFEB10A4C4068E90AB611554A40
11947	Новотаймасово	7	61	531	55.449733000000002	55.472136999999996	52.793545000000002	52.780206999999997	0103000020E610000001000000050000004B77D7D990B94B401D8EAED2DD634A404B77D7D990B94B40C173EFE192654A40A31D37FC6EBC4B40C173EFE192654A40A31D37FC6EBC4B401D8EAED2DD634A404B77D7D990B94B401D8EAED2DD634A40
12236	Новомусино	7	61	531	55.660927000000001	55.681372000000003	52.845148000000002	52.829752999999997	0103000020E610000001000000050000008E05854199D44B400261A758356A4A408E05854199D44B40D12346CF2D6C4A407F349C3237D74B40D12346CF2D6C4A407F349C3237D74B400261A758356A4A408E05854199D44B400261A758356A4A40
13290	Новомурапталово	7	61	531	55.773755000000001	55.790832000000002	52.431151	52.418222999999998	0103000020E61000000100000005000000E90E62670AE34B40AEB7CD5488354A40E90E62670AE34B40A051BAF42F374A40AD50A4FB39E54B40A051BAF42F374A40AD50A4FB39E54B40AEB7CD5488354A40E90E62670AE34B40AEB7CD5488354A40
13435	Новокалтаево	7	61	531	55.634058000000003	55.649042000000001	52.408396000000003	52.400666000000001	0103000020E6100000010000000500000033E202D028D14B40404F030649334A4033E202D028D14B409BE8F35146344A407FDDE9CE13D34B409BE8F35146344A407FDDE9CE13D34B40404F030649334A4033E202D028D14B40404F030649334A40
13001	Новая Отрада	7	61	531	55.83343	55.845278999999998	52.649745000000003	52.630482000000001	0103000020E61000000100000005000000ADC090D5ADEA4B40BC5B59A2B3504A40ADC090D5ADEA4B40A9DE1AD82A534A406F7F2E1A32EC4B40A9DE1AD82A534A406F7F2E1A32EC4B40BC5B59A2B3504A40ADC090D5ADEA4B40BC5B59A2B3504A40
13502	Нижние Бабаларово	7	61	531	55.525334999999998	55.538558000000002	52.403973999999998	52.398045000000003	0103000020E61000000100000005000000DA38622D3EC34B400DAB7823F3324A40DA38622D3EC34B409737876BB5334A40E57FF277EFC44B409737876BB5334A40E57FF277EFC44B400DAB7823F3324A40DA38622D3EC34B400DAB7823F3324A40
11709	Молоканово	7	61	531	55.709085000000002	55.729145000000003	52.630422000000003	52.616284	0103000020E61000000100000005000000C68A1A4CC3DA4B402786E464E24E4A40C68A1A4CC3DA4B40E75608ABB1504A405E85949F54DD4B40E75608ABB1504A405E85949F54DD4B402786E464E24E4A40C68A1A4CC3DA4B402786E464E24E4A40
12161	Михайловка	7	61	531	55.204618000000004	55.224758999999999	52.955601000000001	52.947673999999999	0103000020E61000000100000005000000231631EC309A4B407FA2B2614D794A40231631EC309A4B4030833122517A4A40A73D25E7C49C4B4030833122517A4A40A73D25E7C49C4B407FA2B2614D794A40231631EC309A4B407FA2B2614D794A40
12137	Марьевка	7	61	531	55.315677000000001	55.329492999999999	52.896292000000003	52.885111000000002	0103000020E61000000100000005000000B98C9B1A68A84B40392A37514B714A40B98C9B1A68A84B404ED53DB2B9724A4066A19DD32CAA4B404ED53DB2B9724A4066A19DD32CAA4B40392A37514B714A40B98C9B1A68A84B40392A37514B714A40
12574	Мамбеткулово	7	61	531	55.95711	55.979793000000001	52.884611	52.870148999999998	0103000020E6100000010000000500000058569A9482FA4B40D4D2DC0A616F4A4058569A9482FA4B404757E9EE3A714A40C4EC65DB69FD4B404757E9EE3A714A40C4EC65DB69FD4B40D4D2DC0A616F4A4058569A9482FA4B40D4D2DC0A616F4A40
4235	Куюргазы	7	61	531	55.556111000000001	55.569837	52.500473	52.493997999999998	0103000020E6100000010000000500000012F92EA52EC74B400B2593533B3F4A4012F92EA52EC74B40F8C3CF7F0F404A407F86376BF0C84B40F8C3CF7F0F404A407F86376BF0C84B400B2593533B3F4A4012F92EA52EC74B400B2593533B3F4A40
13564	Кутлуюлово	7	61	531	55.530689000000002	55.539231999999998	52.528517000000001	52.519705999999999	0103000020E6100000010000000500000069ACFD9DEDC34B407AC4E8B985424A4069ACFD9DEDC34B40A530EF71A6434A40747ADE8D05C54B40A530EF71A6434A40747ADE8D05C54B407AC4E8B985424A4069ACFD9DEDC34B407AC4E8B985424A40
12693	Кривле-Илюшкино	7	61	531	56.034787000000001	56.054729999999999	52.694882	52.678369000000004	0103000020E61000000100000005000000B9A981E673044C4064CF9ECBD4564A40B9A981E673044C401F4AB4E4F1584A40170E846401074C401F4AB4E4F1584A40170E846401074C4064CF9ECBD4564A40B9A981E673044C4064CF9ECBD4564A40
29476	Красный Маяк	7	61	531	55.696626000000002	55.705519000000002	52.422584000000001	52.413339999999998	0103000020E610000001000000050000008BC56F0A2BD94B4077103B53E8344A408BC56F0A2BD94B400CE8853B17364A4073DA53724EDA4B400CE8853B17364A4073DA53724EDA4B4077103B53E8344A408BC56F0A2BD94B4077103B53E8344A40
12395	Канчура	7	61	531	55.731892999999999	55.743032999999997	52.794722	52.783203	0103000020E61000000100000005000000EE9579ABAEDD4B408690F3FE3F644A40EE9579ABAEDD4B40B3B45373B9654A40A46C91B41BDF4B40B3B45373B9654A40A46C91B41BDF4B408690F3FE3F644A40EE9579ABAEDD4B408690F3FE3F644A40
3239	Илькинеево	7	61	531	55.771383	55.794280999999998	52.869213999999999	52.859684000000001	0103000020E610000001000000050000005ED89AADBCE24B407E7214200A6E4A405ED89AADBCE24B40D89C8367426F4A40C66AF3FFAAE54B40D89C8367426F4A40C66AF3FFAAE54B407E7214200A6E4A405ED89AADBCE24B407E7214200A6E4A40
12057	Зяк-Ишметово	7	61	531	55.404961	55.435827000000003	52.87885	52.861586000000003	0103000020E61000000100000005000000E69315C3D5B34B4082583673486E4A40E69315C3D5B34B40780B24287E704A405EDBDB2DC9B74B40780B24287E704A405EDBDB2DC9B74B4082583673486E4A40E69315C3D5B34B4082583673486E4A40
3292	Ермолаево	7	61	531	55.778579000000001	55.829352	52.726815000000002	52.677588999999998	0103000020E610000001000000050000001B2D077AA8E34B408E90813CBB564A401B2D077AA8E34B40029F1F46085D4A40A46FD23428EA4B40029F1F46085D4A40A46FD23428EA4B408E90813CBB564A401B2D077AA8E34B408E90813CBB564A40
12882	Горный Ключ	7	61	531	55.892691999999997	55.905349000000001	52.614528999999997	52.606250000000003	0103000020E610000001000000050000004EB340BB43F24B409A999999994D4A404EB340BB43F24B40C7B8E2E2A84E4A40B03BDD79E2F34B40C7B8E2E2A84E4A40B03BDD79E2F34B409A999999994D4A404EB340BB43F24B409A999999994D4A40
12505	Бугульчан	7	61	531	55.943697999999998	55.984310999999998	52.842292	52.829360999999999	0103000020E610000001000000050000007AA69718CBF84B40F7C95180286A4A407AA69718CBF84B405AD76839D06B4A40E90B21E7FDFD4B405AD76839D06B4A40E90B21E7FDFD4B40F7C95180286A4A407AA69718CBF84B40F7C95180286A4A40
12923	Бахмут	7	61	531	55.898890000000002	55.915948999999998	52.66516	52.643968999999998	0103000020E61000000100000005000000C959D8D30EF34B40A45181936D524A40C959D8D30EF34B40BE4D7FF623554A40E6E61BD13DF54B40BE4D7FF623554A40E6E61BD13DF54B40A45181936D524A40C959D8D30EF34B40A45181936D524A40
4115	Бальза	7	61	531	55.914746000000001	55.932136999999997	52.763460000000002	52.747261999999999	0103000020E61000000100000005000000CB129D6516F54B4093C5FD47A65F4A40CB129D6516F54B40EFE6A90EB9614A401E32E54350F74B40EFE6A90EB9614A401E32E54350F74B4093C5FD47A65F4A40CB129D6516F54B4093C5FD47A65F4A40
13134	Аксарово	7	61	531	55.817726999999998	55.836511000000002	52.488042999999998	52.478313999999997	0103000020E6100000010000000500000031074147ABE84B40069CA564393D4A4031074147ABE84B4057056A31783E4A4044DFDDCA12EB4B4057056A31783E4A4044DFDDCA12EB4B40069CA564393D4A4031074147ABE84B40069CA564393D4A40
58740	.Кинья-Абыз	7	61	531	55.105902	56.202907000000003	52.962105000000001	52.346147000000002	0103000020E610000001000000050000005E4A5D328E8D4B40E44D7E8B4E2C4A405E4A5D328E8D4B40B728B341267B4A40939048DBF8194C40B728B341267B4A40939048DBF8194C40E44D7E8B4E2C4A405E4A5D328E8D4B40E44D7E8B4E2C4A40
10218	Якупово	7	61	1041	55.198824000000002	55.216718999999998	55.120835	55.111505999999999	0103000020E6100000010000000500000078D4981073994B4065A71FD4458E4B4078D4981073994B40289B7285778F4B40FEB5BC72BD9B4B40289B7285778F4B40FEB5BC72BD9B4B4065A71FD4458E4B4078D4981073994B4065A71FD4458E4B40
10014	Чирша-Тартыш	7	61	1041	55.130741	55.162118999999997	55.166058	55.158369	0103000020E61000000100000005000000889FFF1EBC904B40A1D9756F45944B40889FFF1EBC904B409D9E776341954B40B587BD50C0944B409D9E776341954B40B587BD50C0944B40A1D9756F45944B40889FFF1EBC904B40A1D9756F45944B40
11155	Угузево	7	61	1041	55.301977999999998	55.344701999999998	54.943731999999997	54.929855000000003	0103000020E61000000100000005000000450E1137A7A64B40D482177D05774B40450E1137A7A64B402618CE35CC784B40D26EF4311FAC4B402618CE35CC784B40D26EF4311FAC4B40D482177D05774B40450E1137A7A64B40D482177D05774B40
10071	Толбазы	7	61	1041	55.019601000000002	55.046622999999997	55.197256000000003	55.177694000000002	0103000020E6100000010000000500000005FC1A4982824B4004594FADBE964B4005FC1A4982824B404B7842AF3F994B40E61E12BEF7854B404B7842AF3F994B40E61E12BEF7854B4004594FADBE964B4005FC1A4982824B4004594FADBE964B40
9418	Тарабердино	7	61	1041	55.384810999999999	55.405966999999997	55.092891000000002	55.072231000000002	0103000020E610000001000000050000000E12A27C41B14B40F2608BDD3E894B400E12A27C41B14B40DF8B2FDAE38B4B40AB2006BAF6B34B40DF8B2FDAE38B4B40AB2006BAF6B34B40F2608BDD3E894B400E12A27C41B14B40F2608BDD3E894B40
10523	Султанаево	7	61	1041	55.440300000000001	55.459614000000002	54.855682999999999	54.842163999999997	0103000020E61000000100000005000000E3361AC05BB84B402CEFAA07CC6B4B40E3361AC05BB84B40205F4205876D4B405264ADA1D4BA4B40205F4205876D4B405264ADA1D4BA4B402CEFAA07CC6B4B40E3361AC05BB84B402CEFAA07CC6B4B40
10960	Старые Тукмаклы	7	61	1041	55.250413999999999	55.285286999999997	54.948086000000004	54.927801000000002	0103000020E61000000100000005000000F33AE2900DA04B401A19E42EC2764B40F33AE2900DA04B40D2E5CDE15A794B40AA7CCF4884A44B40D2E5CDE15A794B40AA7CCF4884A44B401A19E42EC2764B40F33AE2900DA04B401A19E42EC2764B40
10629	Старые Камышлы	7	61	1041	55.756354999999999	55.777869000000003	54.961336000000003	54.939025999999998	0103000020E6100000010000000500000042959A3DD0E04B40FE0B040132784B4042959A3DD0E04B40D63BDC0E0D7B4B403FC91D3691E34B40D63BDC0E0D7B4B403FC91D3691E34B40FE0B040132784B4042959A3DD0E04B40FE0B040132784B40
10703	Старокурмашево	7	61	1041	55.265847000000001	55.298150999999997	55.096167000000001	55.077803000000003	0103000020E61000000100000005000000AF5E454607A24B40EE43DE72F5894B40AF5E454607A24B402BFA43334F8C4B408522DDCF29A64B402BFA43334F8C4B408522DDCF29A64B40EE43DE72F5894B40AF5E454607A24B40EE43DE72F5894B40
10415	Старогумерово	7	61	1041	55.290039	55.323959000000002	54.840614000000002	54.817655999999999	0103000020E6100000010000000500000043C879FF1FA54B4068B0A9F3A8684B4043C879FF1FA54B40A647533D996B4B40581F0F7D77A94B40A647533D996B4B40581F0F7D77A94B4068B0A9F3A8684B4043C879FF1FA54B4068B0A9F3A8684B40
9924	Саитово	7	61	1041	55.028072000000002	55.040604000000002	55.278477000000002	55.262675000000002	0103000020E6100000010000000500000077F700DD97834B40083D9B559FA14B4077F700DD97834B4017D86322A5A34B401C0B0A8332854B4017D86322A5A34B401C0B0A8332854B40083D9B559FA14B4077F700DD97834B40083D9B559FA14B40
10288	Расмекеево	7	61	1041	55.08587	55.102103	55.084842999999999	55.071407000000001	0103000020E6100000010000000500000090DAC4C9FD8A4B404DDA54DD23894B4090DAC4C9FD8A4B40B325AB22DC8A4B4068E90AB6118D4B40B325AB22DC8A4B4068E90AB6118D4B404DDA54DD23894B4090DAC4C9FD8A4B404DDA54DD23894B40
10569	Первушино	7	61	1041	55.718266	55.748530000000002	55.019815999999999	55.002000000000002	0103000020E6100000010000000500000014EAE923F0DB4B40C74B378941804B4014EAE923F0DB4B4001F8A75489824B409609BFD4CFDF4B4001F8A75489824B409609BFD4CFDF4B40C74B378941804B4014EAE923F0DB4B40C74B378941804B40
11061	Новые-Тукмаклы	7	61	1041	55.284730000000003	55.302804000000002	55.012278999999999	54.997914999999999	0103000020E6100000010000000500000055185B0872A44B400B98C0ADBB7F4B4055185B0872A44B40BBB6B75B92814B408B8C0E48C2A64B40BBB6B75B92814B408B8C0E48C2A64B400B98C0ADBB7F4B4055185B0872A44B400B98C0ADBB7F4B40
10800	Новокурмашево	7	61	1041	55.163350000000001	55.181145000000001	55.025834000000003	55.013142000000002	0103000020E610000001000000050000009BE61DA7E8944B401E1A16A3AE814B409BE61DA7E8944B40FC8F4C874E834B40BE6A65C22F974B40FC8F4C874E834B40BE6A65C22F974B401E1A16A3AE814B409BE61DA7E8944B401E1A16A3AE814B40
10478	Новогумерово	7	61	1041	55.283841000000002	55.313125999999997	54.888910000000003	54.882064	0103000020E61000000100000005000000C921E2E654A44B404E7D2079E7704B40C921E2E654A44B402F8B89CDC7714B407EC3448314A84B402F8B89CDC7714B407EC3448314A84B404E7D2079E7704B40C921E2E654A44B404E7D2079E7704B40
9663	Медведерово	7	61	1041	55.581730999999998	55.604565999999998	55.058610999999999	55.047286	0103000020E61000000100000005000000E108522976CA4B4082C7B7770D864B40E108522976CA4B40CA17B49080874B4003232F6B62CD4B40CA17B49080874B4003232F6B62CD4B4082C7B7770D864B40E108522976CA4B4082C7B7770D864B40
11249	Мамяково	7	61	1041	55.564438000000003	55.606631999999998	55.008479999999999	54.992688999999999	0103000020E61000000100000005000000514F1F813FC84B40AA0CE36E107F4B40514F1F813FC84B40C55565DF15814B40815A0C1EA6CD4B40C55565DF15814B40815A0C1EA6CD4B40AA0CE36E107F4B40514F1F813FC84B40AA0CE36E107F4B40
9117	Кушнаренково	7	61	1041	55.324202	55.389474	55.123821	55.090350999999998	0103000020E610000001000000050000001EA67D737FA94B4098141F9F908B4B401EA67D737FA94B406DC7D45DD98F4B403752B648DAB14B406DC7D45DD98F4B403752B648DAB14B4098141F9F908B4B401EA67D737FA94B4098141F9F908B4B40
9970	Карача-Елга	7	61	1041	55.112056000000003	55.137379000000003	55.212862999999999	55.193119000000003	0103000020E6100000010000000500000009A9DBD9578E4B403D9E961FB8984B4009A9DBD9578E4B40A4C343183F9B4B401F1494A295914B40A4C343183F9B4B401F1494A295914B403D9E961FB8984B4009A9DBD9578E4B403D9E961FB8984B40
10976	Каратяки	7	61	1041	55.202857999999999	55.236868000000001	54.974581999999998	54.958953000000001	0103000020E61000000100000005000000B1DD3D40F7994B4057B3CEF8BE7A4B40B1DD3D40F7994B4098A25C1ABF7C4B4006BCCCB0519E4B4098A25C1ABF7C4B4006BCCCB0519E4B4057B3CEF8BE7A4B40B1DD3D40F7994B4057B3CEF8BE7A4B40
9497	Канлы	7	61	1041	55.532926000000003	55.557592999999997	55.117910999999999	55.111803999999999	0103000020E6100000010000000500000014984EEB36C44B40EFC7ED974F8E4B4014984EEB36C44B40596B28B5178F4B4040BD19355FC74B40596B28B5178F4B4040BD19355FC74B40EFC7ED974F8E4B4014984EEB36C44B40EFC7ED974F8E4B40
11308	Калтаево	7	61	1041	55.394979999999997	55.428505000000001	55.009559000000003	54.996454	0103000020E610000001000000050000007B4963B48EB24B40F4FBFECD8B7F4B407B4963B48EB24B40F530B43A39814B4014967840D9B64B40F530B43A39814B4014967840D9B64B40F4FBFECD8B7F4B407B4963B48EB24B40F4FBFECD8B7F4B40
11133	Казарма	7	61	1041	55.354726999999997	55.386788000000003	54.948453000000001	54.939036000000002	0103000020E610000001000000050000000C01C0B167AD4B4022E2E65432784B400C01C0B167AD4B4084656CE866794B401D3EE94482B14B4084656CE866794B401D3EE94482B14B4022E2E65432784B400C01C0B167AD4B4022E2E65432784B40
10668	Ильмурзино	7	61	1041	55.777357000000002	55.806947999999998	54.972431999999998	54.954078000000003	0103000020E610000001000000050000008928266F80E34B40A3EA573A1F7A4B408928266F80E34B40BCCADAA6787C4B404BC972124AE74B40BCCADAA6787C4B404BC972124AE74B40A3EA573A1F7A4B408928266F80E34B40A3EA573A1F7A4B40
9835	Иликово	7	61	1041	54.940235000000001	54.975727999999997	55.227822000000003	55.204618000000004	0103000020E61000000100000005000000FCC6D79E59784B40231631EC309A4B40FCC6D79E59784B4098A77345299D4B404FE5B4A7E47C4B4098A77345299D4B404FE5B4A7E47C4B40231631EC309A4B40FCC6D79E59784B40231631EC309A4B40
58591	Ибрагимово	7	61	1041	55.181432999999998	55.196874999999999	55.032356	55.021937000000001	0103000020E6100000010000000500000024B5503239974B4043C9E4D4CE824B4024B5503239974B4029EACC3D24844B403333333333994B4029EACC3D24844B403333333333994B4043C9E4D4CE824B4024B5503239974B4043C9E4D4CE824B40
11346	Гургуреево	7	61	1041	55.340372000000002	55.362560000000002	55.005186000000002	54.996572	0103000020E61000000100000005000000B03C484F91AB4B40FE0DDAAB8F7F4B40B03C484F91AB4B40D33252EFA9804B403C6BB75D68AE4B40D33252EFA9804B403C6BB75D68AE4B40FE0DDAAB8F7F4B40B03C484F91AB4B40FE0DDAAB8F7F4B40
9849	Гумерово	7	61	1041	55.039014000000002	55.056702000000001	55.221522	55.207552	0103000020E61000000100000005000000070B2769FE844B40151C5E10919A4B40070B2769FE844B4019AC38D55A9C4B4014CFD90242874B4019AC38D55A9C4B4014CFD90242874B40151C5E10919A4B40070B2769FE844B40151C5E10919A4B40
47332	Горный	7	61	1041	55.461770000000001	55.474319999999999	55.154018000000001	55.147551	0103000020E61000000100000005000000102384471BBB4B40FDBE7FF3E2924B40102384471BBB4B40677FA0DCB6934B405BEB8B84B6BC4B40677FA0DCB6934B405BEB8B84B6BC4B40FDBE7FF3E2924B40102384471BBB4B40FDBE7FF3E2924B40
10883	Бейкеево	7	61	1041	55.061041000000003	55.079509999999999	54.971826999999998	54.959060999999998	0103000020E610000001000000050000008A5B0531D0874B403DEFC682C27A4B408A5B0531D0874B40552FBFD3647C4B403CDA38622D8A4B40552FBFD3647C4B403CDA38622D8A4B403DEFC682C27A4B408A5B0531D0874B403DEFC682C27A4B40
10139	Бардовка	7	61	1041	55.245185999999997	55.263108000000003	55.183210000000003	55.165441000000001	0103000020E61000000100000005000000F1B73D41629F4B407235B22B2D954B40F1B73D41629F4B406C26DF6C73974B4072A8DF85ADA14B406C26DF6C73974B4072A8DF85ADA14B407235B22B2D954B40F1B73D41629F4B407235B22B2D954B40
9706	Бакаево	7	61	1041	55.022376999999999	55.046442999999996	55.044738000000002	55.015830999999999	0103000020E610000001000000050000005F97E13FDD824B40A9A10DC006824B405F97E13FDD824B40B9718BF9B9854B4066101FD8F1854B40B9718BF9B9854B4066101FD8F1854B40A9A10DC006824B405F97E13FDD824B40A9A10DC006824B40
9465	Ахметово	7	61	1041	55.479376999999999	55.518732	55.108193999999997	55.088785000000001	0103000020E6100000010000000500000030BABC395CBD4B400CB08F4E5D8B4B4030BABC395CBD4B40CCCF0D4DD98D4B40C0B167CF65C24B40CCCF0D4DD98D4B40C0B167CF65C24B400CB08F4E5D8B4B4030BABC395CBD4B400CB08F4E5D8B4B40
9570	Ахлыстино	7	61	1041	55.657468000000001	55.674805999999997	55.16686	55.157108999999998	0103000020E61000000100000005000000511553E927D44B402174D0251C944B40511553E927D44B405A8121AB5B954B408192020B60D64B405A8121AB5B954B408192020B60D64B402174D0251C944B40511553E927D44B402174D0251C944B40
7832	Янаул	7	61	258	56.444374000000003	56.460436000000001	52.589861999999997	52.574590000000001	0103000020E61000000100000005000000AB984A3FE1384C40E84D452A8C494A40AB984A3FE1384C409A931799804B4A4056F31C91EF3A4C409A931799804B4A4056F31C91EF3A4C40E84D452A8C494A40AB984A3FE1384C40E84D452A8C494A40
6426	Ялчино	7	61	258	56.441769000000001	56.458683999999998	52.874220000000001	52.863793999999999	0103000020E610000001000000050000007DB1F7E28B384C40923D42CD906E4A407DB1F7E28B384C402BC1E270E66F4A4067994528B63A4C402BC1E270E66F4A4067994528B63A4C40923D42CD906E4A407DB1F7E28B384C40923D42CD906E4A40
7170	Юмагузино	7	61	258	56.372284000000001	56.400841999999997	52.914797	52.880155000000002	0103000020E610000001000000050000007B698A00A72F4C40983446EBA8704A407B698A00A72F4C404DBD6E1118754A407E6E68CA4E334C404DBD6E1118754A407E6E68CA4E334C40983446EBA8704A407B698A00A72F4C40983446EBA8704A40
58717	Юлдыбай	7	61	258	55.980421	57.182384999999996	53.005113999999999	52.233711999999997	0103000020E61000000100000005000000E3A7716F7EFD4B4064575A46EA1D4A40E3A7716F7EFD4B4039605793A7804A40F623456458974C4039605793A7804A40F623456458974C4064575A46EA1D4A40E3A7716F7EFD4B4064575A46EA1D4A40
58760	Хлебодаровка	7	61	258	56.241328000000003	56.273119000000001	52.883871999999997	52.877409999999998	0103000020E61000000100000005000000F7CDFDD5E31E4C4078978BF84E704A40F7CDFDD5E31E4C40D0ECBAB722714A4047753A90F5224C40D0ECBAB722714A4047753A90F5224C4078978BF84E704A40F7CDFDD5E31E4C4078978BF84E704A40
7046	Тюлебаево	7	61	258	56.542856999999998	56.563042000000003	52.869506999999999	52.855528999999997	0103000020E61000000100000005000000CCB392567C454C40C9E369F9816D4A40CCB392567C454C40505260014C6F4A402123A0C211484C40505260014C6F4A402123A0C211484C40C9E369F9816D4A40CCB392567C454C40C9E369F9816D4A40
58426	Тупчаново 1-е	7	61	258	56.727091999999999	56.744321999999997	52.669283	52.659194999999997	0103000020E610000001000000050000007497C459115D4C40E657738060544A407497C459115D4C406762BA10AB554A40BED87BF1455F4C406762BA10AB554A40BED87BF1455F4C40E657738060544A407497C459115D4C40E657738060544A40
58541	Тукатово 1-е	7	61	258	56.756816999999998	56.767049	52.522725000000001	52.517316999999998	0103000020E6100000010000000500000046072461DF604C401955867137424A4046072461DF604C409BE61DA7E8424A40FAB660A92E624C409BE61DA7E8424A40FAB660A92E624C401955867137424A4046072461DF604C401955867137424A40
8175	Туембетово	7	61	258	56.468341000000002	56.482785999999997	52.346873000000002	52.339686999999998	0103000020E610000001000000050000001F300F99F23B4C402CF015DD7A2B4A401F300F99F23B4C40C66E9F55662C4A40BB7B80EECB3D4C40C66E9F55662C4A40BB7B80EECB3D4C402CF015DD7A2B4A401F300F99F23B4C402CF015DD7A2B4A40
6630	Тляумбетово	7	61	258	56.302898999999996	56.326650000000001	52.669725	52.662320000000001	0103000020E61000000100000005000000DC7EF964C5264C404DBED9E6C6544A40DC7EF964C5264C4024287E8CB9554A40849ECDAACF294C4024287E8CB9554A40849ECDAACF294C404DBED9E6C6544A40DC7EF964C5264C404DBED9E6C6544A40
6716	Таваканово	7	61	258	56.330755000000003	56.355172000000003	52.606490999999998	52.595863000000001	0103000020E6100000010000000500000087FE092E562A4C40BFF2203D454C4A4087FE092E562A4C40BF28417FA14D4A403B3AAE46762D4C40BF28417FA14D4A403B3AAE46762D4C40BFF2203D454C4A4087FE092E562A4C40BFF2203D454C4A40
6149	Султангулово	7	61	258	56.623938000000003	56.641716000000002	52.769018000000003	52.761476000000002	0103000020E61000000100000005000000A75D4C33DD4F4C402E58AA0B78614A40A75D4C33DD4F4C4086048C2E6F624A40F4A8F8BF23524C4086048C2E6F624A40F4A8F8BF23524C402E58AA0B78614A40A75D4C33DD4F4C402E58AA0B78614A40
6978	Семено-Петровское	7	61	258	56.397491000000002	56.416463999999998	52.873469999999998	52.85622	0103000020E6100000010000000500000028BA2EFCE0324C402F17F19D986D4A4028BA2EFCE0324C40C0046EDDCD6F4A400DFB3DB14E354C40C0046EDDCD6F4A400DFB3DB14E354C402F17F19D986D4A4028BA2EFCE0324C402F17F19D986D4A40
8823	Сатлыки	7	61	258	56.77393	56.799748000000001	52.604117000000002	52.593401999999998	0103000020E6100000010000000500000057B2632310634C40C4B0C398F44B4A4057B2632310634C4094FAB2B4534D4A404D8578245E664C4094FAB2B4534D4A404D8578245E664C40C4B0C398F44B4A4057B2632310634C40C4B0C398F44B4A40
8542	Сапыково	7	61	258	56.537018000000003	56.54645	52.526603999999999	52.518872999999999	0103000020E6100000010000000500000082AE7D01BD444C4082E3326E6A424A4082AE7D01BD444C40ADF886C267434A401973D712F2454C40ADF886C267434A401973D712F2454C4082E3326E6A424A4082AE7D01BD444C4082E3326E6A424A40
7724	Саиткулово	7	61	258	56.527324999999998	56.540906999999997	52.606048000000001	52.592745000000001	0103000020E610000001000000050000007DAEB6627F434C400BEF7211DF4B4A407DAEB6627F434C4032E719FB924D4A40B796C9703C454C4032E719FB924D4A40B796C9703C454C400BEF7211DF4B4A407DAEB6627F434C400BEF7211DF4B4A40
1085	Прибельский	7	61	258	56.515861999999998	56.526282999999999	52.974952999999999	52.969427000000003	0103000020E61000000100000005000000E49F19C407424C40016E162F167C4A40E49F19C407424C408C118942CB7C4A406BB8C83D5D434C408C118942CB7C4A406BB8C83D5D434C40016E162F167C4A40E49F19C407424C40016E162F167C4A40
6809	Подгорное	7	61	258	56.328733999999997	56.377558000000001	52.733468000000002	52.702838999999997	0103000020E61000000100000005000000A88AA9F4132A4C403AADDBA0F6594A40A88AA9F4132A4C40CE548847E25D4A40ED2B0FD253304C40CE548847E25D4A40ED2B0FD253304C403AADDBA0F6594A40A88AA9F4132A4C403AADDBA0F6594A40
27601	Побоище	7	61	258	57.123617000000003	57.145176999999997	52.72195	52.712595	0103000020E61000000100000005000000651D8EAED28F4C4085251E50365B4A40651D8EAED28F4C4071AC8BDB685C4A40D190F12895924C4071AC8BDB685C4A40D190F12895924C4085251E50365B4A40651D8EAED28F4C4085251E50365B4A40
9024	Нукаево	7	61	258	56.677694000000002	56.695408	52.561864	52.551105	0103000020E6100000010000000500000004594FADBE564C40BFD4CF9B8A464A4004594FADBE564C405E66D828EB474A403AB01C2103594C405E66D828EB474A403AB01C2103594C40BFD4CF9B8A464A4004594FADBE564C40BFD4CF9B8A464A40
58539	Новохвалынский	7	61	258	56.733801999999997	56.752442000000002	52.631864999999998	52.622517000000002	0103000020E61000000100000005000000A4DE5339ED5D4C401E1A16A3AE4F4A40A4DE5339ED5D4C40573ECBF3E0504A408411FB0450604C40573ECBF3E0504A408411FB0450604C401E1A16A3AE4F4A40A4DE5339ED5D4C401E1A16A3AE4F4A40
6262	Новопокровское	7	61	258	56.535338000000003	56.551606	52.657677	52.643428	0103000020E610000001000000050000002D27A1F485444C4054AA44D95B524A402D27A1F485444C406B2A8BC22E544A40812381069B464C406B2A8BC22E544A40812381069B464C4054AA44D95B524A402D27A1F485444C4054AA44D95B524A40
7709	Новопетровское	7	61	258	56.4938	56.509619000000001	52.624977000000001	52.606228000000002	0103000020E61000000100000005000000E561A1D6343F4C40B2F50CE1984D4A40E561A1D6343F4C4048E00F3FFF4F4A40CA3505323B414C4048E00F3FFF4F4A40CA3505323B414C40B2F50CE1984D4A40E561A1D6343F4C40B2F50CE1984D4A40
7374	Нижнебиккузино	7	61	258	56.494734000000001	56.512537999999999	52.962831999999999	52.953127000000002	0103000020E61000000100000005000000111C9771533F4C40A1F7C610007A4A40111C9771533F4C4069C537143E7B4A4087FA5DD89A414C4069C537143E7B4A4087FA5DD89A414C40A1F7C610007A4A40111C9771533F4C40A1F7C610007A4A40
8157	Назаркино	7	61	258	56.484071	56.496971000000002	52.315426000000002	52.286662999999997	0103000020E6100000010000000500000094F8DC09F63D4C4093FC885FB1244A4094F8DC09F63D4C40702711E15F284A40BC07E8BE9C3F4C40702711E15F284A40BC07E8BE9C3F4C4093FC885FB1244A4094F8DC09F63D4C4093FC885FB1244A40
58291	Мурадым	7	61	258	55.980421	57.182384999999996	53.005113999999999	52.233711999999997	0103000020E61000000100000005000000E3A7716F7EFD4B4064575A46EA1D4A40E3A7716F7EFD4B4039605793A7804A40F623456458974C4039605793A7804A40F623456458974C4064575A46EA1D4A40E3A7716F7EFD4B4064575A46EA1D4A40
7912	Мукачево	7	61	258	56.486649	56.501362999999998	52.484194000000002	52.465131999999997	0103000020E61000000100000005000000C8D0B1834A3E4C405A290472893B4A40C8D0B1834A3E4C40B075A911FA3D4A405436ACA92C404C40B075A911FA3D4A405436ACA92C404C405A290472893B4A40C8D0B1834A3E4C405A290472893B4A40
5881	Мраково	7	61	258	56.598345000000002	56.655459999999998	52.723570000000002	52.704149000000001	0103000020E61000000100000005000000D15CA791964C4C406C41EF8D215A4A40D15CA791964C4C40F12E17F19D5C4A4007EBFF1CE6534C40F12E17F19D5C4A4007EBFF1CE6534C406C41EF8D215A4A40D15CA791964C4C406C41EF8D215A4A40
8008	Максютово	7	61	258	56.519258000000001	56.538319999999999	52.329804000000003	52.313983999999998	0103000020E61000000100000005000000DB17D00B77424C40CFBBB1A030284A40DB17D00B77424C40850B7904372A4A40306475ABE7444C40850B7904372A4A40306475ABE7444C40CFBBB1A030284A40DB17D00B77424C40CFBBB1A030284A40
6304	Кузьминовка	7	61	258	56.667830000000002	56.697375999999998	52.699396	52.683855999999999	0103000020E61000000100000005000000D3A414747B554C403196E99788574A40D3A414747B554C40037AE1CE85594A40F581E49D43594C40037AE1CE85594A40F581E49D43594C403196E99788574A40D3A414747B554C403196E99788574A40
8390	Кугарчи	7	61	258	56.563167	56.599882000000001	52.448042999999998	52.429524999999998	0103000020E61000000100000005000000DD9733DB15484C403EE8D9ACFA364A40DD9733DB15484C40D219187959394A40C3BAF1EEC84C4C40D219187959394A40C3BAF1EEC84C4C403EE8D9ACFA364A40DD9733DB15484C403EE8D9ACFA364A40
6575	Калдарово	7	61	258	56.250500000000002	56.263480999999999	52.785366000000003	52.768129999999999	0103000020E61000000100000005000000F2D24D6210204C40CA89761552624A40F2D24D6210204C40F7B182DF86644A40060FD3BEB9214C40F7B182DF86644A40060FD3BEB9214C40CA89761552624A40F2D24D6210204C40CA89761552624A40
7884	Исимово	7	61	258	56.499028000000003	56.520811999999999	52.549435000000003	52.526248000000002	0103000020E61000000100000005000000E7E44526E03F4C40EFCA2E185C434A40E7E44526E03F4C408E23D6E253464A40A3AEB5F7A9424C408E23D6E253464A40A3AEB5F7A9424C40EFCA2E185C434A40E7E44526E03F4C40EFCA2E185C434A40
7614	Иртюбяк	7	61	258	56.472572	56.502755999999998	52.713237999999997	52.701939000000003	0103000020E61000000100000005000000AE80423D7D3C4C40BB641C23D9594A40AE80423D7D3C4C40D921FE614B5B4A4013EF004F5A404C40D921FE614B5B4A4013EF004F5A404C40BB641C23D9594A40AE80423D7D3C4C40BB641C23D9594A40
8558	Ижбердино	7	61	258	56.591203999999998	56.626238000000001	52.520287000000003	52.510745999999997	0103000020E61000000100000005000000D7A19A92AC4B4C400A48FB1F60414A40D7A19A92AC4B4C4059C4B0C398424A4098C1189128504C4059C4B0C398424A4098C1189128504C400A48FB1F60414A40D7A19A92AC4B4C400A48FB1F60414A40
8801	Ибрагимово	7	61	258	56.679876999999998	56.697330999999998	52.679291999999997	52.669370000000001	0103000020E61000000100000005000000BB26A43506574C40367689EAAD554A40BB26A43506574C409B374E0AF3564A4055BE672442594C409B374E0AF3564A4055BE672442594C40367689EAAD554A40BB26A43506574C40367689EAAD554A40
8086	Зирекля	7	61	258	56.576138999999998	56.589021000000002	52.296163999999997	52.289692000000002	0103000020E610000001000000050000009E7939ECBE494C40D8F4A0A014254A409E7939ECBE494C405320B3B3E8254A4020D4450A654B4C405320B3B3E8254A4020D4450A654B4C40D8F4A0A014254A409E7939ECBE494C40D8F4A0A014254A40
6688	Даут-Каюпово	7	61	258	56.223218000000003	56.234428999999999	52.615425999999999	52.610050999999999	0103000020E6100000010000000500000074F04C68921C4C4030F2B226164E4A4074F04C68921C4C40D68D7747C64E4A40F31DFCC4011E4C40D68D7747C64E4A40F31DFCC4011E4C4030F2B226164E4A4074F04C68921C4C4030F2B226164E4A40
6862	Воскресенское	7	61	258	56.356617999999997	56.372877000000003	52.804152000000002	52.783399000000003	0103000020E610000001000000050000001C959BA8A52D4C400C5C1E6B46644A401C959BA8A52D4C40AA81E673EE664A401E37FC6EBA2F4C40AA81E673EE664A401E37FC6EBA2F4C400C5C1E6B46644A401C959BA8A52D4C400C5C1E6B46644A40
6518	Волостновка	7	61	258	56.222220999999998	56.243321999999999	52.827559999999998	52.799894000000002	0103000020E6100000010000000500000001BEDBBC711C4C40212235ED62664A4001BEDBBC711C4C4027BD6F7CED694A40DB32E02C251F4C4027BD6F7CED694A40DB32E02C251F4C40212235ED62664A4001BEDBBC711C4C40212235ED62664A40
8478	Верхнесюрюбаево	7	61	258	56.506070999999999	56.516661999999997	52.447093000000002	52.438184	0103000020E610000001000000050000001D3A3DEFC6404C40B3D0CE6916384A401D3A3DEFC6404C40A1A2EA573A394A40008BFCFA21424C40A1A2EA573A394A40008BFCFA21424C40B3D0CE6916384A401D3A3DEFC6404C40B3D0CE6916384A40
7992	Верхнесанзяпово	7	61	258	56.379111999999999	56.399611	52.488624999999999	52.475517000000004	0103000020E61000000100000005000000B5C2F4BD86304C4095D8B5BDDD3C4A40B5C2F4BD86304C40068195438B3E4A40990F087426334C40068195438B3E4A40990F087426334C4095D8B5BDDD3C4A40B5C2F4BD86304C4095D8B5BDDD3C4A40
7649	Верхнемурсаляево	7	61	258	56.487546999999999	56.498462000000004	52.426143000000003	52.413702999999998	0103000020E61000000100000005000000A721AAF0673E4C40E8A04B38F4344A40A721AAF0673E4C40AD3594DA8B364A403E26529ACD3F4C40AD3594DA8B364A403E26529ACD3F4C40E8A04B38F4344A40A721AAF0673E4C40E8A04B38F4344A40
8257	Верхнее Сазово	7	61	258	56.588526999999999	56.621808999999999	52.394444999999997	52.387262	0103000020E6100000010000000500000010E84CDA544B4C40E57D1CCD91314A4010E84CDA544B4C400D897B2C7D324A40E2ADF36F974F4C400D897B2C7D324A40E2ADF36F974F4C40E57D1CCD91314A4010E84CDA544B4C40E57D1CCD91314A40
7457	Верхнебиккузино	7	61	258	56.518251999999997	56.537025999999997	53.001466999999998	52.990864999999999	0103000020E61000000100000005000000158BDF1456424C4022E010AAD47E4A40158BDF1456424C40F982161230804A40048D9944BD444C40F982161230804A40048D9944BD444C4022E010AAD47E4A40158BDF1456424C4022E010AAD47E4A40
8622	Бикбулатово	7	61	258	56.747556000000003	56.767398999999997	52.737907	52.717384000000003	0103000020E61000000100000005000000DCF63DEAAF5F4C403B56293DD35B4A40DCF63DEAAF5F4C40A73E90BC735E4A40D6FD63213A624C40A73E90BC735E4A40D6FD63213A624C403B56293DD35B4A40DCF63DEAAF5F4C403B56293DD35B4A40
6787	Бекечево	7	61	258	56.346952000000002	56.375456	52.662559999999999	52.653782	0103000020E6100000010000000500000012A452EC682C4C40535BEA20AF534A4012A452EC682C4C40A2D11DC4CE544A40228B34F10E304C40A2D11DC4CE544A40228B34F10E304C40535BEA20AF534A4012A452EC682C4C40535BEA20AF534A40
8988	Багдашкино	7	61	258	56.865954000000002	56.877290000000002	52.621282000000001	52.606403	0103000020E6100000010000000500000092EBA694D76E4C4020990E9D9E4D4A4092EBA694D76E4C40F7CB272B864F4A40CE8DE9094B704C40F7CB272B864F4A40CE8DE9094B704C4020990E9D9E4D4A4092EBA694D76E4C4020990E9D9E4D4A40
58847	Аралбай	7	61	258	55.980421	57.182384999999996	53.005113999999999	52.233711999999997	0103000020E61000000100000005000000E3A7716F7EFD4B4064575A46EA1D4A40E3A7716F7EFD4B4039605793A7804A40F623456458974C4039605793A7804A40F623456458974C4064575A46EA1D4A40E3A7716F7EFD4B4064575A46EA1D4A40
7468	Альмясово	7	61	258	56.573669000000002	56.603008000000003	52.823844000000001	52.808315999999998	0103000020E6100000010000000500000051DD5CFC6D494C40B16A10E676674A4051DD5CFC6D494C40BF805EB873694A40FA9CBB5D2F4D4C40BF805EB873694A40FA9CBB5D2F4D4C40B16A10E676674A4051DD5CFC6D494C40B16A10E676674A40
7081	Александровка	7	61	258	56.323039000000001	56.352080999999998	52.895336	52.875546	0103000020E61000000100000005000000912A8A5759294C4062122EE411704A40912A8A5759294C403A77BB5E9A724A4080457EFD102D4C403A77BB5E9A724A4080457EFD102D4C4062122EE411704A40912A8A5759294C4062122EE411704A40
4721	Янгузнарат	7	61	482	54.365996000000003	54.389909000000003	55.761031000000003	55.752930999999997	0103000020E61000000100000005000000C13BF9F4D82E4B408192020B60E04B40C13BF9F4D82E4B40001FBC7669E14B4042B5C189E8314B40001FBC7669E14B4042B5C189E8314B408192020B60E04B40C13BF9F4D82E4B408192020B60E04B40
5096	Шушнур	7	61	482	54.351694999999999	54.372948999999998	55.901237999999999	55.887422000000001	0103000020E6100000010000000500000057957D57042D4B401EE0490B97F14B4057957D57042D4B40CBF44BC45BF34B40B709F7CABC2F4B40CBF44BC45BF34B40B709F7CABC2F4B401EE0490B97F14B4057957D57042D4B401EE0490B97F14B40
5298	Староянзигитово	7	61	482	54.099035000000001	54.123342999999998	55.821527000000003	55.793824000000001	0103000020E610000001000000050000006614CB2DAD0C4B40D4635B069CE54B406614CB2DAD0C4B40F8E3F6CB27E94B40639813B4C90F4B40F8E3F6CB27E94B40639813B4C90F4B40D4635B069CE54B406614CB2DAD0C4B40D4635B069CE54B40
58841	СтарБуртюк	7	61	482	54.555478000000001	54.571342000000001	55.727516000000001	55.712572999999999	0103000020E61000000100000005000000E1D231E719474B409D81919735DB4B40E1D231E719474B408BA8893E1FDD4B40666A12BC21494B408BA8893E1FDD4B40666A12BC21494B409D81919735DB4B40E1D231E719474B409D81919735DB4B40
5625	Саузбаш	7	61	482	53.862481000000002	53.934868000000002	55.990876	55.975436000000002	0103000020E61000000100000005000000F03504C765EE4A40A8AB3B16DBFC4B40F03504C765EE4A4016325706D5FE4B40D9092FC1A9F74A4016325706D5FE4B40D9092FC1A9F74A40A8AB3B16DBFC4B40F03504C765EE4A40A8AB3B16DBFC4B40
5660	Саклово	7	61	482	54.001064	54.034256999999997	56.006210000000003	55.988545000000002	0103000020E61000000100000005000000FA997ADD22004B40EACF7EA488FE4B40FA997ADD22004B403F74417DCB004C405C548B8862044B403F74417DCB004C405C548B8862044B40EACF7EA488FE4B40FA997ADD22004B40EACF7EA488FE4B40
33072	Раздолье	7	61	482	54.400041999999999	54.419967	56.145946000000002	56.132835	0103000020E610000001000000050000006283859334334B40D061BEBC00114C406283859334334B40B37DC85BAE124C401A33897AC1354B40B37DC85BAE124C401A33897AC1354B40D061BEBC00114C406283859334334B40D061BEBC00114C40
4598	Новый Каинлык	7	61	482	54.465296000000002	54.501632999999998	55.807577000000002	55.787669999999999	0103000020E61000000100000005000000D57ABFD18E3B4B402905DD5ED2E44B40D57ABFD18E3B4B403B00E2AE5EE74B4014CC988235404B403B00E2AE5EE74B4014CC988235404B402905DD5ED2E44B40D57ABFD18E3B4B402905DD5ED2E44B40
4814	Новохазино	7	61	482	54.636631999999999	54.653565	55.850423999999997	55.839325000000002	0103000020E6100000010000000500000025CB49287D514B408CDB68006FEB4B4025CB49287D514B40E3DD91B1DAEC4B40B6679604A8534B40E3DD91B1DAEC4B40B6679604A8534B408CDB68006FEB4B4025CB49287D514B408CDB68006FEB4B40
49085	Новоуразаево	7	61	482	54.199385999999997	54.218268000000002	56.019767000000002	56.009003	0103000020E61000000100000005000000DFA3FE7A85194B406F48A30227014C40DFA3FE7A85194B4020459DB987024C40B5E1B034F01B4B4020459DB987024C40B5E1B034F01B4B406F48A30227014C40DFA3FE7A85194B406F48A30227014C40
5246	Новонагаево	7	61	482	54.228113999999998	54.259760999999997	55.932454999999997	55.911911000000003	0103000020E610000001000000050000003FE1ECD6321D4B406CEEE87FB9F44B403FE1ECD6321D4B40EFFE78AF5AF74B405CE333D93F214B40EFFE78AF5AF74B405CE333D93F214B406CEEE87FB9F44B403FE1ECD6321D4B406CEEE87FB9F44B40
5128	Новая Мушта	7	61	482	54.372608	54.397644	55.869304	55.861994000000003	0103000020E610000001000000050000002E1D739EB12F4B4093ACC3D155EE4B402E1D739EB12F4B4018247D5A45EF4B40AEB9A3FFE5324B4018247D5A45EF4B40AEB9A3FFE5324B4093ACC3D155EE4B402E1D739EB12F4B4093ACC3D155EE4B40
4369	Новая Бура	7	61	482	54.575249999999997	54.597527999999997	55.778855999999998	55.764693000000001	0103000020E610000001000000050000001283C0CAA1494B40753DD175E1E14B401283C0CAA1494B408D25AC8DB1E34B40DE3829CC7B4C4B408D25AC8DB1E34B40DE3829CC7B4C4B40753DD175E1E14B401283C0CAA1494B40753DD175E1E14B40
58856	НовБуртюк	7	61	482	54.581240999999999	54.620659000000003	55.740400999999999	55.727491000000001	0103000020E61000000100000005000000130CE71A664A4B403291D26C1EDD4B40130CE71A664A4B407D76C075C5DE4B40EA7B0DC1714F4B407D76C075C5DE4B40EA7B0DC1714F4B403291D26C1EDD4B40130CE71A664A4B403291D26C1EDD4B40
7722	Никольское	7	61	482	54.542856	54.558784000000003	56.184761000000002	56.172370000000001	0103000020E61000000100000005000000FC372F4E7C454B40E0675C3810164C40FC372F4E7C454B40C3499A3FA6174C4098C3EE3B86474B40C3499A3FA6174C4098C3EE3B86474B40E0675C3810164C40FC372F4E7C454B40E0675C3810164C40
5757	Николо-Березовка	7	61	482	54.131689000000001	54.190680999999998	56.147123999999998	56.114745999999997	0103000020E61000000100000005000000191F662FDB104B4064AC36FFAF0E4C40191F662FDB104B40753A90F5D4124C40FA7B293C68184B40753A90F5D4124C40FA7B293C68184B4064AC36FFAF0E4C40191F662FDB104B4064AC36FFAF0E4C40
58558	Мурзино	7	61	482	54.381644999999999	54.385831000000003	56.159213000000001	56.155437999999997	0103000020E6100000010000000500000049D74CBED9304B401F477364E5134C4049D74CBED9304B408D0C721761144C40396403E962314B408D0C721761144C40396403E962314B401F477364E5134C4049D74CBED9304B401F477364E5134C40
4068	Музяк	7	61	482	54.378725000000003	54.388669999999998	56.181660000000001	56.163874999999997	0103000020E61000000100000005000000BC96900F7A304B40E5D022DBF9144C40BC96900F7A304B40E57E87A240174C40D97745F0BF314B40E57E87A240174C40D97745F0BF314B40E5D022DBF9144C40BC96900F7A304B40E5D022DBF9144C40
4556	Маняк	7	61	482	54.666877999999997	54.685364999999997	55.755955999999998	55.739823000000001	0103000020E61000000100000005000000003620425C554B4010EA2285B2DE4B40003620425C554B40849B8C2AC3E04B405969520ABA574B40849B8C2AC3E04B405969520ABA574B4010EA2285B2DE4B40003620425C554B4010EA2285B2DE4B40
33049	Кутлинка	7	61	482	54.339891000000001	54.356904999999998	56.067228	56.061137000000002	0103000020E61000000100000005000000359A5C8C812B4B40ACC95356D3074C40359A5C8C812B4B4010B056ED9A084C40B2632310AF2D4B4010B056ED9A084C40B2632310AF2D4B40ACC95356D3074C40359A5C8C812B4B40ACC95356D3074C40
4676	Купербаш	7	61	482	54.469698000000001	54.485975000000003	55.858497999999997	55.847825999999998	0103000020E61000000100000005000000917F66101F3C4B406859F78F85EC4B40917F66101F3C4B4038D73043E3ED4B4039D6C56D343E4B4038D73043E3ED4B4039D6C56D343E4B406859F78F85EC4B40917F66101F3C4B406859F78F85EC4B40
49195	Кувакино	7	61	482	54.498758000000002	54.513562	56.177230999999999	56.167172999999998	0103000020E61000000100000005000000274F594DD73F4B4019E3C3EC65154C40274F594DD73F4B402F6B6281AF164C40F33B4D66BC414B402F6B6281AF164C40F33B4D66BC414B4019E3C3EC65154C40274F594DD73F4B4019E3C3EC65154C40
3906	Кариево	7	61	482	54.417344	54.433369999999996	56.026009999999999	56.010745	0103000020E61000000100000005000000469737876B354B403ACC971760014C40469737876B354B403AAFB14B54034C40A4880CAB78374B403AAFB14B54034C40A4880CAB78374B403ACC971760014C40469737876B354B403ACC971760014C40
4008	Енактаево	7	61	482	54.367415000000001	54.384492000000002	55.995533000000002	55.987195	0103000020E61000000100000005000000A9876874072F4B402AE3DF675CFE4B40A9876874072F4B405D8B16A06DFF4B406DC9AA0837314B405D8B16A06DFF4B406DC9AA0837314B402AE3DF675CFE4B40A9876874072F4B402AE3DF675CFE4B40
49156	Воробьево	7	61	482	54.261747	54.277782000000002	56.138744000000003	56.130150999999998	0103000020E61000000100000005000000BE69FAEC80214B405645B8C9A8104C40BE69FAEC80214B401442075DC2114C4070B54E5C8E234B401442075DC2114C4070B54E5C8E234B405645B8C9A8104C40BE69FAEC80214B405645B8C9A8104C40
4340	Ведресево	7	61	482	54.593324000000003	54.609690999999998	56.165694000000002	56.155527999999997	0103000020E6100000010000000500000049F7730AF24B4B405FCE6C57E8134C4049F7730AF24B4B405C92037635154C4030D5CC5A0A4E4B405C92037635154C4030D5CC5A0A4E4B405FCE6C57E8134C4049F7730AF24B4B405FCE6C57E8134C40
2874	Бурнюш	7	61	482	54.356752	54.376677000000001	55.800873000000003	55.785229999999999	0103000020E610000001000000050000002C64AE0CAA2D4B4046EBA86A82E44B402C64AE0CAA2D4B40ED9FA70183E64B40E413B2F336304B40ED9FA70183E64B40E413B2F336304B4046EBA86A82E44B402C64AE0CAA2D4B4046EBA86A82E44B40
4890	Барьязибаш	7	61	482	54.541518000000003	54.557175999999998	55.842438000000001	55.835259999999998	0103000020E6100000010000000500000001193A7650454B4017D4B7CCE9EA4B4001193A7650454B402E742502D5EB4B40DC0E0D8B51474B402E742502D5EB4B40DC0E0D8B51474B4017D4B7CCE9EA4B4001193A7650454B4017D4B7CCE9EA4B40
58861	Бакчитау	7	61	482	54.052968999999997	54.076622	55.841068999999997	55.832844000000001	0103000020E61000000100000005000000D5592DB0C7064B40BD55D7A19AEA4B40D5592DB0C7064B40F7562426A8EB4B40BA13ECBFCE094B40F7562426A8EB4B40BA13ECBFCE094B40BD55D7A19AEA4B40D5592DB0C7064B40BD55D7A19AEA4B40
3811	Арлан	7	61	482	54.240546000000002	54.255960999999999	55.979509999999998	55.965510999999999	0103000020E6100000010000000500000081971936CA1E4B40D1764CDD95FB4B4081971936CA1E4B406F0D6C9560FD4B4096067E54C3204B406F0D6C9560FD4B4096067E54C3204B40D1764CDD95FB4B4081971936CA1E4B40D1764CDD95FB4B40
6159	Агидель	7	61	482	53.926253000000003	53.950319	55.904614000000002	55.869757999999997	0103000020E61000000100000005000000346953758FF64A4099B7EA3A54EF4B40346953758FF64A407BC03C64CAF34B403BE2900DA4F94A407BC03C64CAF34B403BE2900DA4F94A4099B7EA3A54EF4B40346953758FF64A4099B7EA3A54EF4B40
58221	Уршак	7	61	6677	55.883125	55.916758000000002	54.578839000000002	54.560251999999998	0103000020E61000000100000005000000D7A3703D0AF14B4061C26856B6474B40D7A3703D0AF14B401E537765174A4B40562C7E5358F54B401E537765174A4B40562C7E5358F54B4061C26856B6474B40D7A3703D0AF14B4061C26856B6474B40
3342	Ягуново	7	61	207	58.509726999999998	58.543072000000002	55.270082000000002	55.261105000000001	0103000020E61000000100000005000000B071FDBB3E414D403AE97DE36BA14B40B071FDBB3E414D40809E060C92A24B40C9AF1F6283454D40809E060C92A24B40C9AF1F6283454D403AE97DE36BA14B40B071FDBB3E414D403AE97DE36BA14B40
58660	Юкаликулево	7	61	207	58.360138999999997	58.384376000000003	55.338858000000002	55.319971000000002	0103000020E61000000100000005000000CF81E508192E4D408F554ACFF4A84B40CF81E508192E4D4076FEEDB25FAB4B4004AF963B33314D4076FEEDB25FAB4B4004AF963B33314D408F554ACFF4A84B40CF81E508192E4D408F554ACFF4A84B40
2934	Тукаево	7	61	207	58.521576000000003	58.533935999999997	55.484254999999997	55.477117999999997	0103000020E6100000010000000500000073309B00C3424D409D2ADF3312BD4B4073309B00C3424D4055F65D11FCBD4B401A14CD0358444D4055F65D11FCBD4B401A14CD0358444D409D2ADF3312BD4B4073309B00C3424D409D2ADF3312BD4B40
2481	Тугузлы	7	61	207	58.742542999999998	58.776518000000003	55.324421999999998	55.311841000000001	0103000020E61000000100000005000000D66F26A60B5F4D40A646E867EAA74B40D66F26A60B5F4D402C0DFCA886A94B40AF601BF164634D402C0DFCA886A94B40AF601BF164634D40A646E867EAA74B40D66F26A60B5F4D40A646E867EAA74B40
2424	Сюрбаево	7	61	207	59.067391999999998	59.089481999999997	55.429434999999998	55.420265000000001	0103000020E610000001000000050000008A01124DA0884D40A453573ECBB54B408A01124DA0884D40FE60E0B9F7B64B4053CA6B25748B4D40FE60E0B9F7B64B4053CA6B25748B4D40A453573ECBB54B408A01124DA0884D40A453573ECBB54B40
1051	Султановка	7	61	207	58.473515999999996	58.482481	55.587142999999998	55.571061999999998	0103000020E61000000100000005000000FD101B2C9C3C4D4082FE428F18C94B40FD101B2C9C3C4D40A489778027CB4B407FF8F9EFC13D4D40A489778027CB4B407FF8F9EFC13D4D4082FE428F18C94B40FD101B2C9C3C4D4082FE428F18C94B40
3234	Старомухаметово	7	61	207	58.468826999999997	58.492398000000001	55.285722	55.267220000000002	0103000020E61000000100000005000000AB3DEC85023C4D40276BD44334A24B40AB3DEC85023C4D40B5DFDA8992A44B40D34ECDE5063F4D40B5DFDA8992A44B40D34ECDE5063F4D40276BD44334A24B40AB3DEC85023C4D40276BD44334A24B40
2824	Сагирово	7	61	207	58.574738000000004	58.594895999999999	55.458627999999997	55.445835000000002	0103000020E610000001000000050000005DE2C80391494D40C2340C1F11B94B405DE2C80391494D40D3838252B4BA4B40B742588D254C4D40D3838252B4BA4B40B742588D254C4D40C2340C1F11B94B405DE2C80391494D40C2340C1F11B94B40
1077	Нижние Киги	7	61	207	58.474719999999998	58.534601000000002	55.553508000000001	55.529511999999997	0103000020E61000000100000005000000E960FD9FC33C4D40766B990CC7C34B40E960FD9FC33C4D408509A359D9C64B4057B439CE6D444D408509A359D9C64B4057B439CE6D444D40766B990CC7C34B40E960FD9FC33C4D40766B990CC7C34B40
3612	Леуза	7	61	207	58.741636	58.866258999999999	55.453217000000002	55.426707	0103000020E61000000100000005000000A4C4AEEDED5E4D40B5FCC0559EB64B40A4C4AEEDED5E4D40E17EC00303BA4B40CE6E2D93E16E4D40E17EC00303BA4B40CE6E2D93E16E4D40B5FCC0559EB64B40A4C4AEEDED5E4D40B5FCC0559EB64B40
3557	Кургашево	7	61	207	58.748821999999997	58.768127	55.375833	55.361435999999998	0103000020E610000001000000050000003D433866D95F4D406CCCEB8843AE4B403D433866D95F4D40F8E0B54B1BB04B4059164CFC51624D40F8E0B54B1BB04B4059164CFC51624D406CCCEB8843AE4B403D433866D95F4D406CCCEB8843AE4B40
3102	Кульметово	7	61	207	58.702047	58.724038	55.180793999999999	55.168233000000001	0103000020E61000000100000005000000A1A014ADDC594D40D28DB0A888954B40A1A014ADDC594D4011A8FE4124974B40D787F546AD5C4D4011A8FE4124974B40D787F546AD5C4D40D28DB0A888954B40A1A014ADDC594D40D28DB0A888954B40
2344	Кулбаково	7	61	207	59.134774999999998	59.153962999999997	55.346108000000001	55.339339000000002	0103000020E61000000100000005000000C1A8A44E40914D40F1A0D9756FAB4B40C1A8A44E40914D40267156444DAC4B40A3E5400FB5934D40267156444DAC4B40A3E5400FB5934D40F1A0D9756FAB4B40C1A8A44E40914D40F1A0D9756FAB4B40
3397	Кандаковка	7	61	207	58.460588999999999	58.501030999999998	55.611750000000001	55.591121000000001	0103000020E61000000100000005000000DCF29194F43A4D404A7D59DAA9CB4B40DCF29194F43A4D40FCA9F1D24DCE4B401EA4A7C821404D40FCA9F1D24DCE4B401EA4A7C821404D404A7D59DAA9CB4B40DCF29194F43A4D404A7D59DAA9CB4B40
855	Идрисово	7	61	207	58.850278000000003	58.886372000000001	55.376553999999999	55.369408	0103000020E610000001000000050000001041D5E8D56C4D40BD70E7C248AF4B401041D5E8D56C4D40C896E5EB32B04B40890B40A374714D40C896E5EB32B04B40890B40A374714D40BD70E7C248AF4B401041D5E8D56C4D40BD70E7C248AF4B40
3169	Ибраево	7	61	207	58.442343999999999	58.464083000000002	55.327033999999998	55.312480999999998	0103000020E6100000010000000500000079CA6ABA9E384D4089CF9D60FFA74B4079CA6ABA9E384D400C570740DCA94B4096D05D12673B4D400C570740DCA94B4096D05D12673B4D4089CF9D60FFA74B4079CA6ABA9E384D4089CF9D60FFA74B40
939	Еланлино	7	61	207	58.587656000000003	58.620651000000002	55.236992000000001	55.217587999999999	0103000020E610000001000000050000002BA6D24F384B4D40430070ECD99B4B402BA6D24F384B4D40F2B4FCC0559E4B40679DF17D714F4D40F2B4FCC0559E4B40679DF17D714F4D40430070ECD99B4B402BA6D24F384B4D40430070ECD99B4B40
2753	Душанбеково	7	61	207	58.483953999999997	58.518071999999997	55.450296999999999	55.432158000000001	0103000020E610000001000000050000005A626534F23D4D40365A0EF450B74B405A626534F23D4D40533E0455A3B94B40957CEC2E50424D40533E0455A3B94B40957CEC2E50424D40365A0EF450B74B405A626534F23D4D40365A0EF450B74B40
2537	Верхние Киги	7	61	207	58.566698000000002	58.641851000000003	55.422747999999999	55.387908000000003	0103000020E61000000100000005000000B45A608F89484D40ABED26F8A6B14B40B45A608F89484D408639419B1CB64B40D4F36E2C28524D408639419B1CB64B40D4F36E2C28524D40ABED26F8A6B14B40B45A608F89484D40ABED26F8A6B14B40
3054	Вакиярово	7	61	207	58.634349999999998	58.662188999999998	55.282389999999999	55.271963999999997	0103000020E61000000100000005000000DA1B7C6132514D403CD862B7CFA24B40DA1B7C6132514D40D55B035B25A44B40AE62F19BC2544D40D55B035B25A44B40AE62F19BC2544D403CD862B7CFA24B40DA1B7C6132514D403CD862B7CFA24B40
2242	Асылгужино	7	61	207	59.070779000000002	59.084252999999997	55.317466000000003	55.308827999999998	0103000020E610000001000000050000002E1F49490F894D40670B08AD87A74B402E1F49490F894D40C5CBD3B9A2A84B4081CB63CDC88A4D40C5CBD3B9A2A84B4081CB63CDC88A4D40670B08AD87A74B402E1F49490F894D40670B08AD87A74B40
2187	Арсланово	7	61	207	58.979680000000002	59.001204000000001	55.364331999999997	55.351686999999998	0103000020E61000000100000005000000CC457C27667D4D40D4B6611404AD4B40CC457C27667D4D407171546EA2AE4B40EC4FE27327804D407171546EA2AE4B40EC4FE27327804D40D4B6611404AD4B40CC457C27667D4D40D4B6611404AD4B40
2070	Алагузово	7	61	207	58.759647000000001	58.790882000000003	55.599193999999997	55.581448999999999	0103000020E6100000010000000500000094C0E61C3C614D405DA5BBEB6CCA4B4094C0E61C3C614D40CEFA9463B2CC4B405F7F129F3B654D40CEFA9463B2CC4B405F7F129F3B654D405DA5BBEB6CCA4B4094C0E61C3C614D405DA5BBEB6CCA4B40
782	Абзаево	7	61	207	58.662602	58.706611000000002	55.607030999999999	55.588622999999998	0103000020E61000000100000005000000D1217024D0544D4032569BFF57CB4B40D1217024D0544D403F541A31B3CD4B4037FFAF3A725A4D403F541A31B3CD4B4037FFAF3A725A4D4032569BFF57CB4B40D1217024D0544D4032569BFF57CB4B40
154	Шарипкулово	7	61	64	56.275813999999997	56.301622999999999	54.370126999999997	54.356287999999999	0103000020E61000000100000005000000B4E386DF4D234C4087FA5DD89A2D4B40B4E386DF4D234C40EC2E5052602F4B40575C1C959B264C40EC2E5052602F4B40575C1C959B264C4087FA5DD89A2D4B40B4E386DF4D234C4087FA5DD89A2D4B40
1955	Шаймуратово	7	61	64	56.027411999999998	56.060110999999999	54.374930999999997	54.349445000000003	0103000020E610000001000000050000004CC2853C82034C4018601F9DBA2C4B404CC2853C82034C40D7A02FBDFD2F4B409F909DB7B1074C40D7A02FBDFD2F4B409F909DB7B1074C4018601F9DBA2C4B404CC2853C82034C4018601F9DBA2C4B40
851	Утяганово	7	61	64	56.446297000000001	56.469338	54.326112999999999	54.313975999999997	0103000020E61000000100000005000000C6A6954220394C404CDD955D30284B40C6A6954220394C4075E61E12BE294B4091628044133C4C4075E61E12BE294B4091628044133C4C404CDD955D30284B40C6A6954220394C404CDD955D30284B40
79	Урал	7	61	64	56.236198999999999	56.255547999999997	54.404142999999998	54.391441999999998	0103000020E61000000100000005000000882CD2C43B1E4C40F2237EC51A324B40882CD2C43B1E4C4023F433F5BA334B407347FFCBB5204C4023F433F5BA334B407347FFCBB5204C40F2237EC51A324B40882CD2C43B1E4C40F2237EC51A324B40
32439	Улукулево	7	61	64	56.297823000000001	56.345999999999997	54.441481000000003	54.419981999999997	0103000020E61000000100000005000000917F66101F264C404F745DF8C1354B40917F66101F264C4017670C7382384B403F355EBA492C4C4017670C7382384B403F355EBA492C4C404F745DF8C1354B40917F66101F264C404F745DF8C1354B40
1601	Старошареево	7	61	64	56.451048999999998	56.468933999999997	54.450622000000003	54.433197	0103000020E610000001000000050000005EF23FF9BB394C40D7DCD1FF72374B405EF23FF9BB394C40D76D50FBAD394B40C1FD8007063C4C40D76D50FBAD394B40C1FD8007063C4C40D7DCD1FF72374B405EF23FF9BB394C40D7DCD1FF72374B40
32827	Старомусино	7	61	64	55.922812	55.945782000000001	54.357453	54.3414	0103000020E610000001000000050000009D2D20B41EF64B405D6DC5FEB22B4B409D2D20B41EF64B40B56D1805C12D4B409F9273620FF94B40B56D1805C12D4B409F9273620FF94B405D6DC5FEB22B4B409D2D20B41EF64B405D6DC5FEB22B4B40
1545	Староакташево	7	61	64	56.427387000000003	56.447949999999999	54.462111	54.449894999999998	0103000020E6100000010000000500000027DE019EB4364C4024D1CB2896394B4027DE019EB4364C40990F0874263B4B40211FF46C56394C40990F0874263B4B40211FF46C56394C4024D1CB2896394B4027DE019EB4364C4024D1CB2896394B40
58877	Сихонкино	7	61	64	55.540129999999998	56.529705	54.517122000000001	54.122267999999998	0103000020E6100000010000000500000053CBD6FA22C54B4075AC527AA60F4B4053CBD6FA22C54B406405BF0D31424B408BC3995FCD434C406405BF0D31424B408BC3995FCD434C4075AC527AA60F4B4053CBD6FA22C54B4075AC527AA60F4B40
1481	Сахаево	7	61	64	56.349888999999997	56.397984999999998	54.440696000000003	54.420893999999997	0103000020E61000000100000005000000751DAA29C92C4C40938AC6DADF354B40751DAA29C92C4C4030BDFDB968384B4037A6272CF1324C4030BDFDB968384B4037A6272CF1324C40938AC6DADF354B40751DAA29C92C4C40938AC6DADF354B40
793	Сарт-Чишма	7	61	64	56.442542000000003	56.462843999999997	54.367708999999998	54.357546999999997	0103000020E61000000100000005000000A08D5C37A5384C4036E49F19C42D4B40A08D5C37A5384C40F1B8A816112F4B402D93E1783E3B4C40F1B8A816112F4B402D93E1783E3B4C4036E49F19C42D4B40A08D5C37A5384C4036E49F19C42D4B40
58572	Сарсаз	7	61	64	55.947130000000001	55.964979	54.435318000000002	54.426676999999998	0103000020E61000000100000005000000BE874B8E3BF94B404A7A185A9D364B40BE874B8E3BF94B4019AE0E80B8374B40D4298F6E84FB4B4019AE0E80B8374B40D4298F6E84FB4B404A7A185A9D364B40BE874B8E3BF94B404A7A185A9D364B40
32746	Савалеево	7	61	64	56.227063000000001	56.254613999999997	54.479433999999998	54.460692999999999	0103000020E61000000100000005000000DA907F66101D4C40813FFCFCF73A4B40DA907F66101D4C40944BE3175E3D4B40478D093197204C40944BE3175E3D4B40478D093197204C40813FFCFCF73A4B40DA907F66101D4C40813FFCFCF73A4B40
717	Новые Киешки	7	61	64	56.415511000000002	56.445874000000003	54.345241999999999	54.330233999999997	0103000020E610000001000000050000006B10E6762F354C407D03931B452A4B406B10E6762F354C40529ACDE3302C4B408011346612394C40529ACDE3302C4B408011346612394C407D03931B452A4B406B10E6762F354C407D03931B452A4B40
45944	Николаевка	7	61	64	56.129344000000003	56.161360000000002	54.472963	54.454934999999999	0103000020E6100000010000000500000088F71C588E104C402367614F3B3A4B4088F71C588E104C40E99B340D8A3C4B40F870C971A7144C40E99B340D8A3C4B40F870C971A7144C402367614F3B3A4B4088F71C588E104C402367614F3B3A4B40
47689	Никитино	7	61	64	55.596580000000003	55.603327	54.251373999999998	54.244546	0103000020E610000001000000050000004EB9C2BB5CCC4B400E2F88484D1F4B404EB9C2BB5CCC4B404888F2052D204B409BE5B2D139CD4B404888F2052D204B409BE5B2D139CD4B400E2F88484D1F4B404EB9C2BB5CCC4B400E2F88484D1F4B40
603	Мукаево	7	61	64	56.287483000000002	56.30527	54.312826000000001	54.301336999999997	0103000020E61000000100000005000000F793313ECC244C409109F83592264B40F793313ECC244C4054ABAFAE0A284B4097395D1613274C4054ABAFAE0A284B4097395D1613274C409109F83592264B40F793313ECC244C409109F83592264B40
32354	Малаево	7	61	64	56.411990000000003	56.426112000000003	54.266672999999997	54.254525000000001	0103000020E61000000100000005000000B8239C16BC344C40D881734694204B40B8239C16BC344C40F4DC425722224B40723788D68A364C40F4DC425722224B40723788D68A364C40D881734694204B40B8239C16BC344C40D881734694204B40
31912	Кустугулово	7	61	64	56.338175	56.349719	54.384763	54.375959000000002	0103000020E6100000010000000500000093A98251492B4C4085D1AC6C1F304B4093A98251492B4C40FDDAFAE93F314B4019E59997C32C4C40FDDAFAE93F314B4019E59997C32C4C4085D1AC6C1F304B4093A98251492B4C4085D1AC6C1F304B40
206	Кармаскалы	7	61	64	56.159526999999997	56.202817000000003	54.384647999999999	54.352389000000002	0103000020E610000001000000050000001CEA77616B144C402E3C2F151B2D4B401CEA77616B144C40643C4A253C314B4053094FE8F5194C40643C4A253C314B4053094FE8F5194C402E3C2F151B2D4B401CEA77616B144C402E3C2F151B2D4B40
1651	Карламанбаш	7	61	64	56.099088999999999	56.116489000000001	54.254888000000001	54.238779000000001	0103000020E610000001000000050000005932C7F2AE0C4C405DFC6D4F901E4B405932C7F2AE0C4C404912842BA0204B4000AC8E1CE90E4C404912842BA0204B4000AC8E1CE90E4C405DFC6D4F901E4B405932C7F2AE0C4C405DFC6D4F901E4B40
439	Карламан	7	61	64	56.117548999999997	56.145127000000002	54.324956999999998	54.303821999999997	0103000020E61000000100000005000000B8567BD80B0F4C4014E7A8A3E3264B40B8567BD80B0F4C409ACDE33098294B402062838593124C409ACDE33098294B402062838593124C4014E7A8A3E3264B40B8567BD80B0F4C4014E7A8A3E3264B40
32293	Камышлинка	7	61	64	56.318438999999998	56.349457999999998	54.250973999999999	54.235280000000003	0103000020E61000000100000005000000AE62F19BC2284C4092B3B0A71D1E4B40AE62F19BC2284C40BA1281EA1F204B40ACA92C0ABB2C4C40BA1281EA1F204B40ACA92C0ABB2C4C4092B3B0A71D1E4B40AE62F19BC2284C4092B3B0A71D1E4B40
1890	Ильтеряково	7	61	64	56.013102000000003	56.043464999999998	54.428463000000001	54.406784000000002	0103000020E6100000010000000500000090C18A53AD014C409E44847F11344B4090C18A53AD014C40E54526E0D7364B40A4C2D84290054C40E54526E0D7364B40A4C2D84290054C409E44847F11344B4090C18A53AD014C409E44847F11344B40
32119	Ефремкино	7	61	64	56.244363999999997	56.275050999999998	54.274113	54.259405999999998	0103000020E61000000100000005000000ED28CE51471F4C406E313F3734214B40ED28CE51471F4C404834812216234B40B5DD04DF34234C404834812216234B40B5DD04DF34234C406E313F3734214B40ED28CE51471F4C406E313F3734214B40
49514	Восток	7	61	64	55.980960000000003	55.988748999999999	54.301642000000001	54.296519000000004	0103000020E610000001000000050000009357E71890FD4B4042D2A755F4254B409357E71890FD4B40CE8C7E349C264B40F279C5538FFE4B40CE8C7E349C264B40F279C5538FFE4B4042D2A755F4254B409357E71890FD4B4042D2A755F4254B40
32032	Бузовьязы	7	61	64	55.797479000000003	55.836098	54.304794000000001	54.280909999999999	0103000020E61000000100000005000000971FB8CA13E64B40478FDFDBF4234B40971FB8CA13E64B402E02637D03274B4021205F4205EB4B402E02637D03274B4021205F4205EB4B40478FDFDBF4234B40971FB8CA13E64B40478FDFDBF4234B40
1204	Бишаул-Унгарово	7	61	64	56.258063999999997	56.283943999999998	54.459938999999999	54.445554999999999	0103000020E610000001000000050000003123BC3D08214C40DEC83CF207394B403123BC3D08214C40D593F947DF3A4B409DF2E84658244C40D593F947DF3A4B409DF2E84658244C40DEC83CF207394B403123BC3D08214C40DEC83CF207394B40
31966	Адзитарово	7	61	64	55.654836000000003	55.679468	54.331226000000001	54.313425000000002	0103000020E610000001000000050000002A1F82AAD1D34B40D95F764F1E284B402A1F82AAD1D34B40DECA129D652A4B40DA56B3CEF8D64B40DECA129D652A4B40DA56B3CEF8D64B40D95F764F1E284B402A1F82AAD1D34B40D95F764F1E284B40
30299	Янбак	7	61	518	56.837665999999999	56.866484	55.569280999999997	55.558441999999999	0103000020E610000001000000050000004E7CB5A3386B4C403E5B07077BC74B404E7CB5A3386B4C40F99D2633DEC84B40EE409DF2E86E4C40F99D2633DEC84B40EE409DF2E86E4C403E5B07077BC74B404E7CB5A3386B4C403E5B07077BC74B40
58600	Якупово	7	61	518	56.729410000000001	56.749127999999999	55.878677000000003	55.86795	0103000020E610000001000000050000000CB08F4E5D5D4C40174850FC18EF4B400CB08F4E5D5D4C40AB5FE97C78F04B404A42226DE35F4C40AB5FE97C78F04B404A42226DE35F4C40174850FC18EF4B400CB08F4E5D5D4C40174850FC18EF4B40
31841	Явгильдино	7	61	518	56.448703999999999	56.471333000000001	55.788666999999997	55.771818000000003	0103000020E61000000100000005000000CDCAF6216F394C40693BA6EECAE24B40CDCAF6216F394C409B374E0AF3E44B404643C6A3543C4C409B374E0AF3E44B404643C6A3543C4C40693BA6EECAE24B40CDCAF6216F394C40693BA6EECAE24B40
5517	Шамратово	7	61	518	57.13411	57.150378000000003	55.605521000000003	55.595663999999999	0103000020E61000000100000005000000850838842A914C40C8B3CBB73ECC4B40850838842A914C4047054EB681CD4B40DA0418963F934C4047054EB681CD4B40DA0418963F934C40C8B3CBB73ECC4B40850838842A914C40C8B3CBB73ECC4B40
47526	Чебыково	7	61	518	56.799909	56.819259000000002	55.691870999999999	55.680751999999998	0103000020E610000001000000050000005663096B63664C40E257ACE122D74B405663096B63664C4081069B3A8FD84B4012FA997ADD684C4081069B3A8FD84B4012FA997ADD684C40E257ACE122D74B405663096B63664C40E257ACE122D74B40
29944	Чапаш	7	61	518	56.972700000000003	56.987926999999999	55.946345000000001	55.931679000000003	0103000020E61000000100000005000000DC68006F817C4C405CAFE94141F74B40DC68006F817C4C40D7DD3CD521F94B40EEEA5564747E4C40D7DD3CD521F94B40EEEA5564747E4C405CAFE94141F74B40DC68006F817C4C405CAFE94141F74B40
58735	Халилово	7	61	518	56.695390000000003	56.715504000000003	55.905512000000002	55.895626	0103000020E6100000010000000500000094FB1D8A02594C4041B96DDFA3F24B4094FB1D8A02594C405A1135D1E7F34B401F1494A2955B4C405A1135D1E7F34B401F1494A2955B4C4041B96DDFA3F24B4094FB1D8A02594C4041B96DDFA3F24B40
58766	Урюш-Битуллино	7	61	518	56.521619999999999	56.542290999999999	55.633226000000001	55.623640999999999	0103000020E610000001000000050000004278B471C4424C40EDB8E177D3CF4B404278B471C4424C400B7DB08C0DD14B4023F59ECA69454C400B7DB08C0DD14B4023F59ECA69454C40EDB8E177D3CF4B404278B471C4424C40EDB8E177D3CF4B40
58518	Уразаево	7	61	518	56.271538	56.288822000000003	55.615726000000002	55.606329000000002	0103000020E6100000010000000500000085CFD6C1C1224C40E6CE4C309CCD4B4085CFD6C1C1224C4001A60C1CD0CE4B40C32E8A1EF8244C4001A60C1CD0CE4B40C32E8A1EF8244C40E6CE4C309CCD4B4085CFD6C1C1224C40E6CE4C309CCD4B40
31290	Тегерменево	7	61	518	56.642291	56.670893	55.909846999999999	55.895493999999999	0103000020E61000000100000005000000F0C16B9736524C40D2E1218C9FF24B40F0C16B9736524C408EAED2DD75F44B40C30E63D2DF554C408EAED2DD75F44B40C30E63D2DF554C40D2E1218C9FF24B40F0C16B9736524C40D2E1218C9FF24B40
31817	Тайкаш	7	61	518	56.352710000000002	56.384563999999997	55.807161999999998	55.791941000000001	0103000020E61000000100000005000000707CED99252D4C4047AE9B525EE54B40707CED99252D4C4077499C1551E74B40069CA56439314C4077499C1551E74B40069CA56439314C4047AE9B525EE54B40707CED99252D4C4047AE9B525EE54B40
8483	Суюндюково	7	61	518	56.438059000000003	56.458962999999997	55.735799	55.723638000000001	0103000020E61000000100000005000000F75B3B5112384C404912842BA0DC4B40F75B3B5112384C40FAB660A92EDE4B407A89B14CBF3A4C40FAB660A92EDE4B407A89B14CBF3A4C404912842BA0DC4B40F75B3B5112384C404912842BA0DC4B40
30006	Старые Багазы	7	61	518	56.873679000000003	56.896217999999998	55.896129999999999	55.874172999999999	0103000020E61000000100000005000000DB19A6B6D46F4C40EA059FE6E4EF4B40DB19A6B6D46F4C40747B4963B4F24B40130B7C45B7724C40747B4963B4F24B40130B7C45B7724C40EA059FE6E4EF4B40DB19A6B6D46F4C40EA059FE6E4EF4B40
29442	Старооткустино	7	61	518	56.507364000000003	56.531655000000001	55.890033000000003	55.875971	0103000020E610000001000000050000007995B54DF1404C40499F56D11FF04B407995B54DF1404C402EAEF199ECF14B40A0E062450D444C402EAEF199ECF14B40A0E062450D444C40499F56D11FF04B407995B54DF1404C40499F56D11FF04B40
46743	Седяш	7	61	518	56.482993	56.512394999999998	55.593277999999998	55.577831000000003	0103000020E610000001000000050000003599F1B6D23D4C40B8CEBF5DF6C94B403599F1B6D23D4C40D8B79388F0CB4B4024D1CB2896414C40D8B79388F0CB4B4024D1CB2896414C40B8CEBF5DF6C94B403599F1B6D23D4C40B8CEBF5DF6C94B40
30993	Подлубово	7	61	518	56.279578000000001	56.310443999999997	55.689933000000003	55.674849000000002	0103000020E610000001000000050000002E573F36C9234C40815EB87361D64B402E573F36C9234C4031B77BB94FD84B40A59E05A1BC274C4031B77BB94FD84B40A59E05A1BC274C40815EB87361D64B402E573F36C9234C40815EB87361D64B40
46570	Озерки	7	61	518	57.430680000000002	57.445151000000003	56.048867000000001	56.022100999999999	0103000020E610000001000000050000004985B18520B74C40BD1AA034D4024C404985B18520B74C40446D1B4641064C400F643DB5FAB84C40446D1B4641064C400F643DB5FAB84C40BD1AA034D4024C404985B18520B74C40BD1AA034D4024C40
30584	Новый Бердяш	7	61	518	57.109909000000002	57.127678000000003	55.628286000000003	55.621648	0103000020E610000001000000050000009E44847F118E4C40D9CF622992CF4B409E44847F118E4C407044F7AC6BD04B409835B1C057904C407044F7AC6BD04B409835B1C057904C40D9CF622992CF4B409E44847F118E4C40D9CF622992CF4B40
29646	Новоянсаитово	7	61	518	56.841465999999997	56.869700000000002	55.715859999999999	55.703763000000002	0103000020E6100000010000000500000014596B28B56B4C404391EEE714DA4B4014596B28B56B4C40DD41EC4CA1DB4B4065AA6054526F4C40DD41EC4CA1DB4B4065AA6054526F4C404391EEE714DA4B4014596B28B56B4C404391EEE714DA4B40
30730	Новомуллакаево	7	61	518	57.090415999999998	57.110798000000003	55.955523999999997	55.944721999999999	0103000020E610000001000000050000007F8461C0928B4C40E6E786A6ECF84B407F8461C0928B4C408445459C4EFA4B402A3BFDA02E8E4C408445459C4EFA4B402A3BFDA02E8E4C40E6E786A6ECF84B407F8461C0928B4C40E6E786A6ECF84B40
29899	Нижние Балмазы	7	61	518	56.989561999999999	57.015793000000002	55.894661999999997	55.876899999999999	0103000020E61000000100000005000000A3AEB5F7A97E4C4063EE5A423EF04B40A3AEB5F7A97E4C40AA7CCF4884F24B40BC40498105824C40AA7CCF4884F24B40BC40498105824C4063EE5A423EF04B40A3AEB5F7A97E4C4063EE5A423EF04B40
31030	Нагретдиново	7	61	518	56.302898999999996	56.326442999999998	55.611465000000003	55.596421999999997	0103000020E61000000100000005000000DC7EF964C5264C40B54E5C8E57CC4B40DC7EF964C5264C4007D3307C44CE4B400A815CE2C8294C4007D3307C44CE4B400A815CE2C8294C40B54E5C8E57CC4B40DC7EF964C5264C40B54E5C8E57CC4B40
31760	Мрясимово	7	61	518	56.461531999999998	56.495255	55.676296000000001	55.663069999999998	0103000020E610000001000000050000005B07077B133B4C40B77A4E7ADFD44B405B07077B133B4C40333509DE90D64B401A170E84643F4C40333509DE90D64B401A170E84643F4C40B77A4E7ADFD44B405B07077B133B4C40B77A4E7ADFD44B40
30492	Магинск	7	61	518	56.951141	56.974901000000003	55.772421000000001	55.750145000000003	0103000020E610000001000000050000003F7100FDBE794C40042159C004E04B403F7100FDBE794C402FDFFAB0DEE24B403AEB538EC97C4C402FDFFAB0DEE24B403AEB538EC97C4C40042159C004E04B403F7100FDBE794C40042159C004E04B40
30319	Куртлыкуль	7	61	518	56.344410000000003	56.377521999999999	55.724226000000002	55.707684	0103000020E610000001000000050000002B357BA0152C4C4084F3A96395DA4B402B357BA0152C4C40DA740470B3DC4B40A0C211A452304C40DA740470B3DC4B40A0C211A452304C4084F3A96395DA4B402B357BA0152C4C4084F3A96395DA4B40
30835	Круш	7	61	518	57.421453999999997	57.435575	56.005209000000001	55.985326999999998	0103000020E610000001000000050000005A626534F2B54C40D26EF4311FFE4B405A626534F2B54C408B5242B0AA004C4044FAEDEBC0B74C408B5242B0AA004C4044FAEDEBC0B74C40D26EF4311FFE4B405A626534F2B54C40D26EF4311FFE4B40
31736	Красный Урюш	7	61	518	56.443179000000001	56.464146	55.641702000000002	55.628124	0103000020E6100000010000000500000012A3E716BA384C4096EA025E66D04B4012A3E716BA384C408FE3874A23D24B40DC48D922693B4C408FE3874A23D24B40DC48D922693B4C4096EA025E66D04B4012A3E716BA384C4096EA025E66D04B40
47644	Комсомольский	7	61	518	57.126645000000003	57.151770999999997	55.708241999999998	55.697422000000003	0103000020E61000000100000005000000D99942E735904C4066C1C41F45D94B40D99942E735904C40AAD381ACA7DA4B4098BD6C3B6D934C40AAD381ACA7DA4B4098BD6C3B6D934C4066C1C41F45D94B40D99942E735904C4066C1C41F45D94B40
29166	Кирзя	7	61	518	56.750188000000001	56.815738000000003	55.626613999999996	55.600430000000003	0103000020E6100000010000000500000003ED0E2906604C40C6C4E6E3DACC4B4003ED0E2906604C409D9B36E334D04B405F0D501A6A684C409D9B36E334D04B405F0D501A6A684C40C6C4E6E3DACC4B4003ED0E2906604C40C6C4E6E3DACC4B40
32979	Караяр	7	61	518	57.015334000000003	57.032446999999998	55.705219	55.696027000000001	0103000020E610000001000000050000002942EA76F6814C400611A96917D94B402942EA76F6814C4048C2BE9D44DA4B4039ED293927844C4048C2BE9D44DA4B4039ED293927844C400611A96917D94B402942EA76F6814C400611A96917D94B40
29756	Караидель	7	61	518	56.861246000000001	56.931665000000002	55.85772	55.822012999999998	0103000020E61000000100000005000000C9E7154F3D6E4C4084F1D3B837E94B40C9E7154F3D6E4C400490DAC4C9ED4B40F7E978CC40774C400490DAC4C9ED4B40F7E978CC40774C4084F1D3B837E94B40C9E7154F3D6E4C4084F1D3B837E94B40
3167	Калтасы	7	61	518	56.455855	56.471189000000003	55.562378000000002	55.555280000000003	0103000020E61000000100000005000000EA5BE674593A4C40BB0F406A13C74B40EA5BE674593A4C40B5FE9600FCC74B40139ED0EB4F3C4C40B5FE9600FCC74B40139ED0EB4F3C4C40BB0F406A13C74B40EA5BE674593A4C40BB0F406A13C74B40
47471	Зуевка	7	61	518	56.737988999999999	56.757041999999998	55.75094	55.736741000000002	0103000020E6100000010000000500000064E76D6C765E4C40A94F72874DDE4B4064E76D6C765E4C400EA14ACD1EE04B4066D993C0E6604C400EA14ACD1EE04B4066D993C0E6604C40A94F72874DDE4B4064E76D6C765E4C40A94F72874DDE4B40
58573	Дубровка	7	61	518	56.605486999999997	56.627719999999997	55.650886	55.639578	0103000020E610000001000000050000009A931799804D4C40DC9E20B1DDD14B409A931799804D4C404EB6813B50D34B40C685032159504C404EB6813B50D34B40C685032159504C40DC9E20B1DDD14B409A931799804D4C40DC9E20B1DDD14B40
47028	Деушево	7	61	518	56.318897999999997	56.339576999999998	55.735889999999998	55.722517000000003	0103000020E61000000100000005000000416150A6D1284C40EBE6E26F7BDC4B40416150A6D1284C400ABABDA431DE4B40A5BC5642772B4C400ABABDA431DE4B40A5BC5642772B4C40EBE6E26F7BDC4B40416150A6D1284C40EBE6E26F7BDC4B40
17180	Бердяш	7	61	518	56.935205000000003	56.953449999999997	55.799430999999998	55.785406999999999	0103000020E61000000100000005000000210725CCB4774C405586713788E44B40210725CCB4774C404C3448C153E64B40832F4CA60A7A4C404C3448C153E64B40832F4CA60A7A4C405586713788E44B40210725CCB4774C405586713788E44B40
47252	Бартым	7	61	518	57.489564000000001	57.505212999999998	55.813344000000001	55.803463999999998	0103000020E6100000010000000500000044A67C08AABE4C40B5C189E8D7E64B4044A67C08AABE4C40EC32FCA71BE84B40CC41D0D1AAC04C40EC32FCA71BE84B40CC41D0D1AAC04C40B5C189E8D7E64B4044A67C08AABE4C40B5C189E8D7E64B40
29473	Байкибашево	7	61	518	56.551346000000002	56.603655000000003	55.816439000000003	55.798054999999998	0103000020E61000000100000005000000E563778192464C4063B48EAA26E64B40E563778192464C40E816BA1281E84B4090882991444D4C40E816BA1281E84B4090882991444D4C4063B48EAA26E64B40E563778192464C4063B48EAA26E64B40
5011	Байки-Юнусово	7	61	518	56.594276000000001	56.616976999999999	55.885427999999997	55.874718000000001	0103000020E610000001000000050000001B66683C114C4C407C9C69C2F6EF4B401B66683C114C4C40397B67B455F14B402DB1321AF94E4C40397B67B455F14B402DB1321AF94E4C407C9C69C2F6EF4B401B66683C114C4C407C9C69C2F6EF4B40
29568	Байки	7	61	518	56.789560999999999	56.849595000000001	55.850459000000001	55.82976	0103000020E610000001000000050000003999B85510654C40B5C35F9335EA4B403999B85510654C4060CB2BD7DBEC4B402DEC6987BF6C4C4060CB2BD7DBEC4B402DEC6987BF6C4C40B5C35F9335EA4B403999B85510654C40B5C35F9335EA4B40
46968	Атамановка	7	61	518	56.696216999999997	56.707113999999997	55.581093000000003	55.56841	0103000020E61000000100000005000000A9F57EA31D594C40145CACA8C1C84B40A9F57EA31D594C409F77634161CA4B40994528B6825A4C409F77634161CA4B40994528B6825A4C40145CACA8C1C84B40A9F57EA31D594C40145CACA8C1C84B40
29851	Абызово	7	61	518	56.912216999999998	56.945867999999997	55.830193999999999	55.812443999999999	0103000020E6100000010000000500000078EDD286C3744C406CEA3C2AFEE74B4078EDD286C3744C40EFAA07CC43EA4B409D2ADF3312794C40EFAA07CC43EA4B409D2ADF3312794C406CEA3C2AFEE74B4078EDD286C3744C406CEA3C2AFEE74B40
29375	Абуталипово	7	61	518	56.411181999999997	56.426946999999998	55.837985000000003	55.819595	0103000020E61000000100000005000000185A9D9CA1344C40897B2C7DE8E84B40185A9D9CA1344C40F0C4AC1743EB4B400A100533A6364C40F0C4AC1743EB4B400A100533A6364C40897B2C7DE8E84B40185A9D9CA1344C40897B2C7DE8E84B40
30092	Абдуллино	7	61	518	57.003323999999999	57.081693000000001	55.726239	55.709353	0103000020E610000001000000050000005DA5BBEB6C804C40E5284014CCDA4B405DA5BBEB6C804C40350A4966F5DC4B40F4A78DEA748A4C40350A4966F5DC4B40F4A78DEA748A4C40E5284014CCDA4B405DA5BBEB6C804C40E5284014CCDA4B40
28041	Чумара	7	61	706	54.770282999999999	54.790145000000003	55.803736999999998	55.789188000000003	0103000020E6100000010000000500000017D522A298624B40A532C51C04E54B4017D522A298624B40E6CAA0DAE0E64B40890CAB7823654B40E6CAA0DAE0E64B40890CAB7823654B40A532C51C04E54B4017D522A298624B40A532C51C04E54B40
28301	Чилибеево	7	61	706	54.450589999999998	54.472419000000002	56.09798	56.087077000000001	0103000020E61000000100000005000000CBF3E0EEAC394B40ED9DD156250B4C40CBF3E0EEAC394B40BFD4CF9B8A0C4C402881CD39783C4B40BFD4CF9B8A0C4C402881CD39783C4B40ED9DD156250B4C40CBF3E0EEAC394B40ED9DD156250B4C40
28561	Тюльди	7	61	706	54.855936999999997	54.874406999999998	56.057110999999999	56.039800999999997	0103000020E61000000100000005000000DA37F7578F6D4B408EACFC3218054C40DA37F7578F6D4B40F59ECA694F074C405D328E91EC6F4B40F59ECA694F074C405D328E91EC6F4B408EACFC3218054C40DA37F7578F6D4B408EACFC3218054C40
28546	Старый Орьебаш	7	61	706	54.715108000000001	54.735509	56.095685000000003	56.083295	0103000020E61000000100000005000000D28DB0A8885B4B40CD751A69A90A4C40D28DB0A8885B4B40E0DBF4673F0C4C40F374AE28255E4B40E0DBF4673F0C4C40F374AE28255E4B40CD751A69A90A4C40D28DB0A8885B4B40CD751A69A90A4C40
58826	Старые Калтасы	7	61	706	54.410418	55.422153999999999	56.151300999999997	55.718806000000001	0103000020E6100000010000000500000049D8B79388344B409415C3D501DC4B4049D8B79388344B40116DC7D45D134C4013F06B2409B64B40116DC7D45D134C4013F06B2409B64B409415C3D501DC4B4049D8B79388344B409415C3D501DC4B40
28872	Старояшево	7	61	706	55.332700000000003	55.346831000000002	56.041384999999998	56.029893999999999	0103000020E610000001000000050000008AB0E1E995AA4B405E2C0C91D3034C408AB0E1E995AA4B40C1C58A1A4C054C40971E4DF564AC4B40C1C58A1A4C054C40971E4DF564AC4B405E2C0C91D3034C408AB0E1E995AA4B405E2C0C91D3034C40
58525	Норкино	7	61	706	54.431626999999999	54.443196999999998	56.098917999999998	56.091918999999997	0103000020E610000001000000050000000989B48D3F374B40C5707500C40B4C400989B48D3F374B402C7E5358A90C4C40B857E6ADBA384B402C7E5358A90C4C40B857E6ADBA384B40C5707500C40B4C400989B48D3F374B40C5707500C40B4C40
28727	Новокильбахтино	7	61	706	55.144269000000001	55.166691	55.986747000000001	55.976030000000002	0103000020E61000000100000005000000CF69166877924B401BF5108DEEFC4B40CF69166877924B408B36C7B94DFE4B40CEC4742156954B408B36C7B94DFE4B40CEC4742156954B401BF5108DEEFC4B40CF69166877924B401BF5108DEEFC4B40
28455	Нижний Качмаш	7	61	706	54.709251000000002	54.729886	55.989708	55.971803999999999	0103000020E61000000100000005000000E1D39CBCC85A4B409D0FCF1264FC4B40E1D39CBCC85A4B40774B72C0AEFE4B4075E789E76C5D4B40774B72C0AEFE4B4075E789E76C5D4B409D0FCF1264FC4B40E1D39CBCC85A4B409D0FCF1264FC4B40
58393	Надеждино	7	61	706	54.868343000000003	54.893881999999998	55.859518999999999	55.846567999999998	0103000020E61000000100000005000000F35A09DD256F4B4089EB18575CEC4B40F35A09DD256F4B4033A5F5B704EE4B40D53DB2B96A724B4033A5F5B704EE4B40D53DB2B96A724B4089EB18575CEC4B40F35A09DD256F4B4089EB18575CEC4B40
58099	Куяново	7	61	706	55.083956999999998	55.096451999999999	55.967748	55.951658000000002	0103000020E6100000010000000500000098A25C1ABF8A4B40077DE9EDCFF94B4098A25C1ABF8A4B407C629D2ADFFB4B4020D1048A588C4B407C629D2ADFFB4B4020D1048A588C4B40077DE9EDCFF94B4098A25C1ABF8A4B40077DE9EDCFF94B40
28809	Кучаш	7	61	706	55.257241999999998	55.282107000000003	56.001770999999998	55.994446000000003	0103000020E610000001000000050000002D944C4EEDA04B40ABD1AB014AFF4B402D944C4EEDA04B40658A39083A004C40817C09151CA44B40658A39083A004C40817C09151CA44B40ABD1AB014AFF4B402D944C4EEDA04B40ABD1AB014AFF4B40
28179	Кутерем	7	61	706	54.508755999999998	54.538831999999999	56.004479000000003	55.985211	0103000020E6100000010000000500000067D2A6EA1E414B406954E0641BFE4B4067D2A6EA1E414B40684293C492004C40E6046D72F8444B40684293C492004C40E6046D72F8444B406954E0641BFE4B4067D2A6EA1E414B406954E0641BFE4B40
29030	Кугарчино	7	61	706	55.071497000000001	55.100261000000003	55.882044999999998	55.864823000000001	0103000020E610000001000000050000008D614ED026894B4010EA2285B2EE4B408D614ED026894B40D74CBED9E6F04B403A083A5AD58C4B40D74CBED9E6F04B403A083A5AD58C4B4010EA2285B2EE4B408D614ED026894B4010EA2285B2EE4B40
4918	Краснохолмский	7	61	706	55.032932000000002	55.060816000000003	55.999842999999998	55.973365000000001	0103000020E61000000100000005000000F67EA31D37844B4018096D3997FC4B40F67EA31D37844B403811FDDAFAFF4B406A8995D1C8874B403811FDDAFAFF4B406A8995D1C8874B4018096D3997FC4B40F67EA31D37844B4018096D3997FC4B40
28475	Кокуш	7	61	706	54.672967999999997	54.691510000000001	55.993369000000001	55.978628999999998	0103000020E6100000010000000500000094A0BFD023564B4066F50EB743FD4B4094A0BFD023564B401CEE23B726FF4B40B16D516683584B401CEE23B726FF4B40B16D516683584B4066F50EB743FD4B4094A0BFD023564B4066F50EB743FD4B40
29013	Качкинтурай	7	61	706	55.164158	55.18835	55.963793000000003	55.956511999999996	0103000020E610000001000000050000003AB01C2103954B40A31D37FC6EFA4B403AB01C2103954B408F8EAB915DFB4B40CE1951DA1B984B408F8EAB915DFB4B40CE1951DA1B984B40A31D37FC6EFA4B403AB01C2103954B40A31D37FC6EFA4B40
48421	Каменка	7	61	706	54.619303000000002	54.621558	56.014654999999998	56.010708999999999	0103000020E6100000010000000500000048A81952454F4B40ED629AE95E014C4048A81952454F4B4087DC0C37E0014C40994869368F4F4B4087DC0C37E0014C40994869368F4F4B40ED629AE95E014C4048A81952454F4B40ED629AE95E014C40
27922	Калмиябаш	7	61	706	54.925708999999998	54.952748999999997	55.899743999999998	55.889668999999998	0103000020E61000000100000005000000724EECA17D764B40ECA17DACE0F14B40724EECA17D764B40D862B7CF2AF34B40FA25E2ADF3794B40D862B7CF2AF34B40FA25E2ADF3794B40ECA17DACE0F14B40724EECA17D764B40ECA17DACE0F14B40
28265	Калегино	7	61	706	54.544697999999997	54.562385999999996	56.103411999999999	56.084204	0103000020E610000001000000050000002A1900AAB8454B40A0185932C70A4C402A1900AAB8454B40C901BB9A3C0D4C4037DDB243FC474B40C901BB9A3C0D4C4037DDB243FC474B40A0185932C70A4C402A1900AAB8454B40A0185932C70A4C40
28112	Графское	7	61	706	54.450420000000001	54.464900999999998	55.935091999999997	55.918393000000002	0103000020E610000001000000050000006FBBD05CA7394B400BF0DDE68DF54B406FBBD05CA7394B4028603B18B1F74B4058703FE0813B4B4028603B18B1F74B4058703FE0813B4B400BF0DDE68DF54B406FBBD05CA7394B400BF0DDE68DF54B40
28544	Верхний Качмаш	7	61	706	54.701031999999998	54.713248999999998	56.019570999999999	56.008972999999997	0103000020E6100000010000000500000088B9A46ABB594B4004C6FA0626014C4088B9A46ABB594B409A79724D81024C40CD7344BE4B5B4B409A79724D81024C40CD7344BE4B5B4B4004C6FA0626014C4088B9A46ABB594B4004C6FA0626014C40
28095	Большой Кельтей	7	61	706	54.531995999999999	54.562232999999999	55.976371999999998	55.955573999999999	0103000020E6100000010000000500000029CDE67118444B403674B33F50FA4B4029CDE67118444B40745DF8C1F9FC4B40B1DD3D40F7474B40745DF8C1F9FC4B40B1DD3D40F7474B403674B33F50FA4B4029CDE67118444B403674B33F50FA4B40
28642	Большетуганеево	7	61	706	54.815970999999998	54.834423000000001	56.037804999999999	56.028841999999997	0103000020E6100000010000000500000001BEDBBC71684B4028603B18B1034C4001BEDBBC71684B40095053CBD6044C40DE03745FCE6A4B40095053CBD6044C40DE03745FCE6A4B4028603B18B1034C4001BEDBBC71684B4028603B18B1034C40
29140	Большекуразово	7	61	706	54.951320000000003	54.970939999999999	56.022665000000003	56.012797999999997	0103000020E61000000100000005000000EF0390DAC4794B4023BA675DA3014C40EF0390DAC4794B40C6E1CCAFE6024C406A300DC3477C4B40C6E1CCAFE6024C406A300DC3477C4B4023BA675DA3014C40EF0390DAC4794B4023BA675DA3014C40
28951	Большекачаково	7	61	706	55.149462	55.180714000000002	55.924325000000003	55.916431000000003	0103000020E6100000010000000500000054FF209221934B4032056B9C4DF54B4054FF209221934B4007F0164850F64B40F5F6E7A221974B4007F0164850F64B40F5F6E7A221974B4032056B9C4DF54B4054FF209221934B4032056B9C4DF54B40
47282	Барсуково	7	61	706	54.761640999999997	54.775421000000001	55.931970999999997	55.925153000000002	0103000020E610000001000000050000007825C9737D614B40ED65DB696BF64B407825C9737D614B4003E962D34AF74B40D9D0CDFE40634B4003E962D34AF74B40D9D0CDFE40634B40ED65DB696BF64B407825C9737D614B40ED65DB696BF64B40
58296	Бабаево	7	61	706	55.032465000000002	55.053089999999997	55.899521999999997	55.891990999999997	0103000020E61000000100000005000000E0A128D027844B40C5A9D6C22CF24B40E0A128D027844B402904728923F34B4050DF32A7CB864B402904728923F34B4050DF32A7CB864B40C5A9D6C22CF24B40E0A128D027844B40C5A9D6C22CF24B40
28338	Амзибаш	7	61	706	54.604041000000002	54.628124	56.069906000000003	56.055432000000003	0103000020E61000000100000005000000B9382A37514D4B407193516518074C40B9382A37514D4B40A8E507AEF2084C4096EA025E66504B40A8E507AEF2084C4096EA025E66504B407193516518074C40B9382A37514D4B407193516518074C40
28925	Актуганово	7	61	706	55.301780000000001	55.327435999999999	55.999535999999999	55.990841000000003	0103000020E610000001000000050000001F4B1FBAA0A64B409A44BDE0D3FE4B401F4B1FBAA0A64B405B96AFCBF0FF4B403BC43F6CE9A94B405B96AFCBF0FF4B403BC43F6CE9A94B409A44BDE0D3FE4B401F4B1FBAA0A64B409A44BDE0D3FE4B40
26166	Яр-Бишкадак	7	61	300	56.021816000000001	56.036737000000002	53.512104000000001	53.493561999999997	0103000020E61000000100000005000000C843DFDDCA024C403046240A2DBF4A40C843DFDDCA024C404D13B69F8CC14A40CEC64ACCB3044C404D13B69F8CC14A40CEC64ACCB3044C403046240A2DBF4A40C843DFDDCA024C403046240A2DBF4A40
32638	Янурусово	7	61	300	56.340744999999998	56.366768999999998	53.694598999999997	53.676628000000001	0103000020E6100000010000000500000044A33B889D2B4C4069C70DBF9BD64A4044A33B889D2B4C40CA6ABA9EE8D84A40E3175E49F22E4C40CA6ABA9EE8D84A40E3175E49F22E4C4069C70DBF9BD64A4044A33B889D2B4C4069C70DBF9BD64A40
58917	Шихан	7	61	300	56.078355999999999	56.089998000000001	53.568161000000003	53.562615999999998	0103000020E6100000010000000500000002B9C491070A4C40691A14CD03C84A4002B9C491070A4C406CEEE87FB9C84A404B5AF10D850B4C406CEEE87FB9C84A404B5AF10D850B4C40691A14CD03C84A4002B9C491070A4C40691A14CD03C84A40
58129	Шахтау	7	61	300	56.059939999999997	56.078679000000001	53.663531999999996	53.640002000000003	0103000020E6100000010000000500000072DC291DAC074C40F3AFE595EBD14A4072DC291DAC074C40BBECD79DEED44A40E5F04927120A4C40BBECD79DEED44A40E5F04927120A4C40F3AFE595EBD14A4072DC291DAC074C40F3AFE595EBD14A40
26187	Урман-Бишкадак	7	61	300	56.068834000000003	56.093178000000002	53.533495000000002	53.520895000000003	0103000020E610000001000000050000002B6D718DCF084C4031D3F6AFACC24A402B6D718DCF084C402ECA6C9049C44A40755AB741ED0B4C402ECA6C9049C44A40755AB741ED0B4C4031D3F6AFACC24A402B6D718DCF084C4031D3F6AFACC24A40
27383	Уразбаево	7	61	300	56.327755000000003	56.356267000000003	53.341273999999999	53.323594	0103000020E61000000100000005000000DD0C37E0F3294C40469737876BA94A40DD0C37E0F3294C40D07CCEDDAEAB4A4070D234289A2D4C40D07CCEDDAEAB4A4070D234289A2D4C40469737876BA94A40DD0C37E0F3294C40469737876BA94A40
26534	Тимашевка	7	61	300	56.317478000000001	56.349431000000003	53.544711999999997	53.531216000000001	0103000020E6100000010000000500000089997D1EA3284C40548EC9E2FEC34A4089997D1EA3284C408FDE701FB9C54A40B39AAE27BA2C4C408FDE701FB9C54A40B39AAE27BA2C4C40548EC9E2FEC34A4089997D1EA3284C40548EC9E2FEC34A40
27597	Скворчиха	7	61	300	56.105035999999998	56.139774000000003	53.316633000000003	53.290174999999998	0103000020E610000001000000050000008A73D4D1710D4C40F38E537424A54A408A73D4D1710D4C40CDEA1D6E87A84A40626A4B1DE4114C40CDEA1D6E87A84A40626A4B1DE4114C40F38E537424A54A408A73D4D1710D4C40F38E537424A54A40
21549	Сайраново	7	61	300	56.384977999999997	56.414155000000001	53.453516	53.440372000000004	0103000020E61000000100000005000000F9D687F546314C407D09151C5EB84A40F9D687F546314C403B1BF2CF0CBA4A40C93CF20703354C403B1BF2CF0CBA4A40C93CF20703354C407D09151C5EB84A40F9D687F546314C407D09151C5EB84A40
58559	Павловка	7	61	300	56.411199000000003	56.432310000000001	53.581479999999999	53.564765999999999	0103000020E61000000100000005000000EF92382BA2344C4045F295404AC84A40EF92382BA2344C4098A3C7EF6DCA4A40ECDD1FEF55374C4098A3C7EF6DCA4A40ECDD1FEF55374C4045F295404AC84A40EF92382BA2344C4045F295404AC84A40
27271	Новоаптиково	7	61	300	56.286109000000003	56.306545999999997	53.492507000000003	53.474347999999999	0103000020E61000000100000005000000AF0B3F389F244C4025766D6FB7BC4A40AF0B3F389F244C408A0629780ABF4A401C5C3AE63C274C408A0629780ABF4A401C5C3AE63C274C4025766D6FB7BC4A40AF0B3F389F244C4025766D6FB7BC4A40
26670	Нижнеарметово	7	61	300	56.490547999999997	56.509008000000001	53.680719000000003	53.654845000000002	0103000020E61000000100000005000000218FE046CA3E4C407D7901F6D1D34A40218FE046CA3E4C400762D9CC21D74A4081B3942C27414C400762D9CC21D74A4081B3942C27414C407D7901F6D1D34A40218FE046CA3E4C407D7901F6D1D34A40
58136	Кулгунино	7	61	300	56.914983999999997	56.950907000000001	53.586227000000001	53.573669000000002	0103000020E610000001000000050000007F2E1A321E754C4051DD5CFC6DC94A407F2E1A321E754C401F84807C09CB4A40CC441152B7794C401F84807C09CB4A40CC441152B7794C4051DD5CFC6DC94A407F2E1A321E754C4051DD5CFC6DC94A40
27096	Кузяново	7	61	300	56.460391000000001	56.500222999999998	53.568578000000002	53.558166	0103000020E61000000100000005000000B62FA017EE3A4C409CDEC5FB71C74A40B62FA017EE3A4C40D09CF529C7C84A407FDAA84E07404C40D09CF529C7C84A407FDAA84E07404C409CDEC5FB71C74A40B62FA017EE3A4C409CDEC5FB71C74A40
27649	Кинзекеево	7	61	300	56.044507000000003	56.059356000000001	53.300094000000001	53.288156000000001	0103000020E61000000100000005000000B7B8C667B2054C40B612BA4BE2A44A40B7B8C667B2054C40E8DCED7A69A64A40236937FA98074C40E8DCED7A69A64A40236937FA98074C40B612BA4BE2A44A40B7B8C667B2054C40B612BA4BE2A44A40
27509	Кинзебулатово	7	61	300	56.184842000000003	56.208917	53.413576999999997	53.394364000000003	0103000020E61000000100000005000000B07614E7A8174C40215C01857AB24A40B07614E7A8174C405BB05417F0B44A400A4AD1CABD1A4C405BB05417F0B44A400A4AD1CABD1A4C40215C01857AB24A40B07614E7A8174C40215C01857AB24A40
26249	Карайганово	7	61	300	56.034211999999997	56.055745000000002	53.603076999999999	53.586739999999999	0103000020E61000000100000005000000BC900E0F61044C40A5A0DB4B1ACB4A40BC900E0F61044C4022FC8BA031CD4A4030F5F3A622074C4022FC8BA031CD4A4030F5F3A622074C40A5A0DB4B1ACB4A40BC900E0F61044C40A5A0DB4B1ACB4A40
26385	Канакаево	7	61	300	56.193339999999999	56.212967999999996	53.566353999999997	53.552672000000001	0103000020E610000001000000050000001B81785DBF184C401CB5C2F4BDC64A401B81785DBF184C40B9FAB1497EC84A40198C1189421B4C40B9FAB1497EC84A40198C1189421B4C401CB5C2F4BDC64A401B81785DBF184C401CB5C2F4BDC64A40
1315	Ишимбай	7	61	300	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
32671	Ишеево	7	61	300	56.114063999999999	56.15155	53.625629000000004	53.611299000000002	0103000020E6100000010000000500000052D32EA6990E4C40EC89AE0B3FCE4A4052D32EA6990E4C40F0366F9C14D04A40BADA8AFD65134C40F0366F9C14D04A40BADA8AFD65134C40EC89AE0B3FCE4A4052D32EA6990E4C40EC89AE0B3FCE4A40
27671	Верхотор	7	61	300	56.257748999999997	56.301721999999998	53.197685	53.181137	0103000020E61000000100000005000000D1C952EBFD204C403B8C497F2F974A40D1C952EBFD204C4073F4F8BD4D994A40EA3D95D39E264C4073F4F8BD4D994A40EA3D95D39E264C403B8C497F2F974A40D1C952EBFD204C403B8C497F2F974A40
27289	Верхнеиткулово	7	61	300	56.309106	56.342486999999998	53.390847000000001	53.364977000000003	0103000020E61000000100000005000000AA7F10C990274C406765FB90B7AE4A40AA7F10C990274C40AF5E454607B24A400F27309DD62B4C40AF5E454607B24A400F27309DD62B4C406765FB90B7AE4A40AA7F10C990274C406765FB90B7AE4A40
33109	Верхнеарметово	7	61	300	56.481762000000003	56.501741000000003	53.707312000000002	53.682158999999999	0103000020E61000000100000005000000503A9160AA3D4C4006D671FC50D74A40503A9160AA3D4C40C0081A3389DA4A40FB07910C39404C40C0081A3389DA4A40FB07910C39404C4006D671FC50D74A40503A9160AA3D4C4006D671FC50D74A40
27129	Биксяново	7	61	300	56.317469000000003	56.329498000000001	53.471705999999998	53.459854	0103000020E61000000100000005000000363FFED2A2284C40A777F17EDCBA4A40363FFED2A2284C40DAA9B9DC60BC4A40780C8FFD2C2A4C40DAA9B9DC60BC4A40780C8FFD2C2A4C40A777F17EDCBA4A40363FFED2A2284C40A777F17EDCBA4A40
26465	Бердышла	7	61	300	56.355665999999999	56.374960999999999	53.583013999999999	53.565755000000003	0103000020E610000001000000050000004A26A776862D4C403546EBA86AC84A404A26A776862D4C40198EE733A0CA4A404223D8B8FE2F4C40198EE733A0CA4A404223D8B8FE2F4C403546EBA86AC84A404A26A776862D4C403546EBA86AC84A40
48168	Байгузино	7	61	300	56.138094000000002	56.169677999999998	53.435581999999997	53.421042	0103000020E610000001000000050000000DE36E10AD114C40081F4AB4E4B54A400DE36E10AD114C40F65CA626C1B74A40E36C3A02B8154C40F65CA626C1B74A40E36C3A02B8154C40081F4AB4E4B54A400DE36E10AD114C40081F4AB4E4B54A40
32623	Ахмерово	7	61	300	56.188588000000003	56.227241999999997	53.604075999999999	53.579132999999999	0103000020E610000001000000050000008335CEA623184C406684B70721CA4A408335CEA623184C403526C45C52CD4A4089230F44161D4C403526C45C52CD4A4089230F44161D4C406684B70721CA4A408335CEA623184C406684B70721CA4A40
26923	Арметрахимово	7	61	300	56.440978999999999	56.469104999999999	53.648536999999997	53.637380999999998	0103000020E61000000100000005000000849CF7FF71384C40BF0B5BB395D14A40849CF7FF71384C407B9FAA4203D34A40EEB1F4A10B3C4C407B9FAA4203D34A40EEB1F4A10B3C4C40BF0B5BB395D14A40849CF7FF71384C40BF0B5BB395D14A40
27209	Аптиково	7	61	300	56.266435999999999	56.289954000000002	53.501795000000001	53.489784999999998	0103000020E61000000100000005000000103D29931A224C4022895E46B1BE4A40103D29931A224C40EE258DD13AC04A4015AC71361D254C40EE258DD13AC04A4015AC71361D254C4022895E46B1BE4A40103D29931A224C4022895E46B1BE4A40
21079	Азнаево	7	61	300	56.349601999999997	56.377853999999999	53.410871999999998	53.402579000000003	0103000020E61000000100000005000000DF4E22C2BF2C4C4038876BB587B34A40DF4E22C2BF2C4C40CA6B257497B44A40D65416855D304C40CA6B257497B44A40D65416855D304C4038876BB587B34A40DF4E22C2BF2C4C4038876BB587B34A40
23465	Янтуганово	7	61	293	54.384250000000002	54.399548000000003	55.312609000000002	55.301842999999998	0103000020E6100000010000000500000077BE9F1A2F314B4065C39ACAA2A64B4077BE9F1A2F314B40B7B75B9203A84B4053978C6324334B40B7B75B9203A84B4053978C6324334B4065C39ACAA2A64B4077BE9F1A2F314B4065C39ACAA2A64B40
6810	Шамметово	7	61	293	54.118006999999999	54.134571999999999	55.594051	55.583953000000001	0103000020E610000001000000050000007BD976DA1A0F4B4057B3CEF8BECA4B407BD976DA1A0F4B40FB93F8DC09CC4B40897AC1A739114B40FB93F8DC09CC4B40897AC1A739114B4057B3CEF8BECA4B407BD976DA1A0F4B4057B3CEF8BECA4B40
6991	Чуй-Атасево	7	61	293	54.528042999999997	54.545515000000002	55.666274000000001	55.656936000000002	0103000020E61000000100000005000000DCF0BBE996434B4054C8957A16D44B40DCF0BBE996434B406A16687748D54B401D3D7E6FD3454B406A16687748D54B401D3D7E6FD3454B4054C8957A16D44B40DCF0BBE996434B4054C8957A16D44B40
23290	Уяндыково	7	61	293	54.353149999999999	54.362060999999997	55.705325999999999	55.693824999999997	0103000020E610000001000000050000008C4AEA04342D4B40D712F241CFD84B408C4AEA04342D4B405E82531F48DA4B401A14CD03582E4B405E82531F48DA4B401A14CD03582E4B40D712F241CFD84B408C4AEA04342D4B40D712F241CFD84B40
21938	Урняково	7	61	293	54.249305	54.275060000000003	55.248894	55.241267000000001	0103000020E6100000010000000500000059DDEA39E91F4B40514D49D6E19E4B4059DDEA39E91F4B40D71533C2DB9F4B400938842A35234B40D71533C2DB9F4B400938842A35234B40514D49D6E19E4B4059DDEA39E91F4B40514D49D6E19E4B40
32541	Улу-Ялан	7	61	293	54.141973999999998	54.161180000000002	55.516955000000003	55.509345000000003	0103000020E61000000100000005000000EF703B342C124B40C9B08A3732C14B40EF703B342C124B407940D9942BC24B407862D68BA1144B407940D9942BC24B407862D68BA1144B40C9B08A3732C14B40EF703B342C124B40C9B08A3732C14B40
22226	Турачи	7	61	293	54.005116000000001	54.032846999999997	55.518932999999997	55.494543	0103000020E61000000100000005000000DA571EA4A7004B409DBB5D2F4DBF4B40DA571EA4A7004B4057E883656CC24B40C7629B5434044B4057E883656CC24B40C7629B5434044B409DBB5D2F4DBF4B40DA571EA4A7004B409DBB5D2F4DBF4B40
23734	Тупеево	7	61	293	54.161396000000003	54.194678000000003	55.277692999999999	55.261572000000001	0103000020E6100000010000000500000045DAC69FA8144B4050C6F8307BA14B4045DAC69FA8144B4000AAB8718BA34B4017A06D35EB184B4000AAB8718BA34B4017A06D35EB184B4050C6F8307BA14B4045DAC69FA8144B4050C6F8307BA14B40
7271	Тукай-Тамак	7	61	293	53.907046999999999	53.926693	55.419677	55.410913000000001	0103000020E61000000100000005000000AB77B81D1AF44A40294014CC98B44B40AB77B81D1AF44A4013F1D6F9B7B54B40503750E09DF64A4013F1D6F9B7B54B40503750E09DF64A40294014CC98B44B40AB77B81D1AF44A40294014CC98B44B40
58849	Телепаново	7	61	293	54.481186999999998	54.500428999999997	55.543582000000001	55.529429999999998	0103000020E6100000010000000500000053211E89973D4B40B9C2BB5CC4C34B4053211E89973D4B40DE58501894C54B40287CB60E0E404B40DE58501894C54B40287CB60E0E404B40B9C2BB5CC4C34B4053211E89973D4B40B9C2BB5CC4C34B40
22398	Телекеево	7	61	293	54.301147	54.327809000000002	55.620508999999998	55.609217000000001	0103000020E61000000100000005000000EE2422FC8B264B40689599D2FACD4B40EE2422FC8B264B40D4EFC2D66CCF4B40D02A33A5F5294B40D4EFC2D66CCF4B40D02A33A5F5294B40689599D2FACD4B40EE2422FC8B264B40689599D2FACD4B40
21508	Ташкичи	7	61	293	54.461720999999997	54.483604	55.608089	55.598872999999998	0103000020E610000001000000050000002E7079AC193B4B408CBAD6DEA7CC4B402E7079AC193B4B40570740DCD5CD4B407E1B62BCE63D4B40570740DCD5CD4B407E1B62BCE63D4B408CBAD6DEA7CC4B402E7079AC193B4B408CBAD6DEA7CC4B40
7042	Татарский Менеуз	7	61	293	54.470578000000003	54.482005000000001	55.626584000000001	55.620657000000001	0103000020E61000000100000005000000CA1B60E63B3C4B40498446B071CF4B40CA1B60E63B3C4B4033198EE733D04B4016C1FF56B23D4B4033198EE733D04B4016C1FF56B23D4B40498446B071CF4B40CA1B60E63B3C4B40498446B071CF4B40
23006	Тазеево	7	61	293	54.542928000000003	54.564810999999999	55.620829999999998	55.600785999999999	0103000020E61000000100000005000000960A2AAA7E454B4084F23E8EE6CC4B40960A2AAA7E454B401630815B77CF4B40E5B512BA4B484B401630815B77CF4B40E5B512BA4B484B4084F23E8EE6CC4B40960A2AAA7E454B4084F23E8EE6CC4B40
23436	Сюльтино	7	61	293	54.407255999999997	54.429290999999999	55.301479	55.291407999999997	0103000020E61000000100000005000000C58CF0F620344B4079E57ADB4CA54B40C58CF0F620344B4024B726DD96A64B40CBBBEA01F3364B4024B726DD96A64B40CBBBEA01F3364B4079E57ADB4CA54B40C58CF0F620344B4079E57ADB4CA54B40
22801	Сынгряново	7	61	293	53.891066000000002	53.916981999999997	55.369838000000001	55.358699000000001	0103000020E61000000100000005000000ED4960730EF24A40D00D4DD9E9AD4B40ED4960730EF24A40B66801DA56AF4B40A5828AAA5FF54A40B66801DA56AF4B40A5828AAA5FF54A40D00D4DD9E9AD4B40ED4960730EF24A40D00D4DD9E9AD4B40
24113	Старотатышево	7	61	293	54.188130000000001	54.217469000000001	55.749592	55.735368000000001	0103000020E61000000100000005000000C0B2D2A414184B403143E38920DE4B40C0B2D2A414184B40EFAB72A1F2DF4B4069723106D61B4B40EFAB72A1F2DF4B4069723106D61B4B403143E38920DE4B40C0B2D2A414184B403143E38920DE4B40
23532	Старокуктово	7	61	293	54.211522000000002	54.246941999999997	55.468927999999998	55.459119000000001	0103000020E6100000010000000500000038312427131B4B4072FC5069C4BA4B4038312427131B4B40DF162CD505BC4B402101A3CB9B1F4B40DF162CD505BC4B402101A3CB9B1F4B4072FC5069C4BA4B4038312427131B4B4072FC5069C4BA4B40
23175	Старокиргизово	7	61	293	54.297274999999999	54.325077999999998	55.693596999999997	55.678423000000002	0103000020E610000001000000050000008E75711B0D264B4057ED9A90D6D64B408E75711B0D264B4046CD57C9C7D84B401553E9279C294B4046CD57C9C7D84B401553E9279C294B4057ED9A90D6D64B408E75711B0D264B4057ED9A90D6D64B40
22702	Саиткулово	7	61	293	54.544392999999999	54.563374000000003	55.490631	55.483989999999999	0103000020E61000000100000005000000EE9579ABAE454B40A7CB6262F3BD4B40EE9579ABAE454B40AFB321FFCCBE4B4057B5A4A31C484B40AFB321FFCCBE4B4057B5A4A31C484B40A7CB6262F3BD4B40EE9579ABAE454B40A7CB6262F3BD4B40
23374	Рсаево	7	61	293	54.340637000000001	54.390089000000003	55.365918999999998	55.350996000000002	0103000020E610000001000000050000005E6743FE992B4B406F83DA6FEDAC4B405E6743FE992B4B4015FE0C6FD6AE4B40C2C3B46FEE314B4015FE0C6FD6AE4B40C2C3B46FEE314B406F83DA6FEDAC4B405E6743FE992B4B406F83DA6FEDAC4B40
21412	Новонадырово	7	61	293	54.512790000000003	54.528976999999998	55.627305	55.619405999999998	0103000020E61000000100000005000000A1DB4B1AA3414B401C7920B248CF4B40A1DB4B1AA3414B4003CFBD874BD04B4008ABB184B5434B4003CFBD874BD04B4008ABB184B5434B401C7920B248CF4B40A1DB4B1AA3414B401C7920B248CF4B40
23093	Новомедведево	7	61	293	54.290222999999997	54.313094	55.709012999999999	55.690694000000001	0103000020E6100000010000000500000004C6FA0626254B408FC536A968D84B4004C6FA0626254B402CB81FF0C0DA4B407349D57613284B402CB81FF0C0DA4B407349D57613284B408FC536A968D84B4004C6FA0626254B408FC536A968D84B40
22891	Новокуктово	7	61	293	54.204065999999997	54.235245999999997	55.416907999999999	55.404263999999998	0103000020E61000000100000005000000DE1CAED51E1A4B409E7939ECBEB34B40DE1CAED51E1A4B406BB8C83D5DB54B40E5417A8A1C1E4B406BB8C83D5DB54B40E5417A8A1C1E4B409E7939ECBEB34B40DE1CAED51E1A4B409E7939ECBEB34B40
21989	Нижнеяркеево	7	61	293	54.317836999999997	54.348407000000002	55.468020000000003	55.456566000000002	0103000020E61000000100000005000000B83A00E2AE284B40973B33C170BA4B40B83A00E2AE284B40DDEF5014E8BB4B404759BF99982C4B40DDEF5014E8BB4B404759BF99982C4B40973B33C170BA4B40B83A00E2AE284B40973B33C170BA4B40
23745	Нижнечерекулево	7	61	293	54.390034999999997	54.418503000000001	55.503171000000002	55.487009	0103000020E61000000100000005000000CEA5B8AAEC314B40C8ED974F56BE4B40CEA5B8AAEC314B40D7A546E867C04B4092239D8191354B40D7A546E867C04B4092239D8191354B40C8ED974F56BE4B40CEA5B8AAEC314B40C8ED974F56BE4B40
21325	Марино	7	61	293	54.496988000000002	54.507966000000003	55.690694000000001	55.680565000000001	0103000020E610000001000000050000009240834D9D3F4B40B0E600C11CD74B409240834D9D3F4B408FC536A968D84B406FBDA60705414B408FC536A968D84B406FBDA60705414B40B0E600C11CD74B409240834D9D3F4B40B0E600C11CD74B40
21645	Мари-Менеуз	7	61	293	54.482939000000002	54.512160999999999	55.651369000000003	55.643875999999999	0103000020E61000000100000005000000427BF5F1D03D4B40F3565D876AD24B40427BF5F1D03D4B406A50340F60D34B40B1A4DC7D8E414B406A50340F60D34B40B1A4DC7D8E414B40F3565D876AD24B40427BF5F1D03D4B40F3565D876AD24B40
21811	Мало-Бишкураево	7	61	293	54.556789000000002	54.573740000000001	55.322384	55.310693000000001	0103000020E61000000100000005000000E3E2A8DC44474B404E0CC9C9C4A74B40E3E2A8DC44474B40786000E143A94B401A34F44F70494B40786000E143A94B401A34F44F70494B404E0CC9C9C4A74B40E3E2A8DC44474B404E0CC9C9C4A74B40
22680	Лаяшты	7	61	293	54.594347999999997	54.616123000000002	55.478934000000002	55.463115000000002	0103000020E61000000100000005000000B4386398134C4B40BEA4315A47BB4B40B4386398134C4B40A37895B54DBD4B401EA8531EDD4E4B40A37895B54DBD4B401EA8531EDD4E4B40BEA4315A47BB4B40B4386398134C4B40BEA4315A47BB4B40
22957	Кужбахты	7	61	293	54.546081000000001	54.567326999999999	55.604309999999998	55.580782999999997	0103000020E61000000100000005000000C6FB71FBE5454B405089EB1857CA4B40C6FB71FBE5454B40A852B3075ACD4B40A391CF2B9E484B40A852B3075ACD4B40A391CF2B9E484B405089EB1857CA4B40C6FB71FBE5454B405089EB1857CA4B40
23346	Красноярово	7	61	293	54.315564999999999	54.321556000000001	55.661104999999999	55.650973	0103000020E610000001000000050000009161156F64284B401DCA501553D34B409161156F64284B406D1CB1169FD44B4092EA3BBF28294B406D1CB1169FD44B4092EA3BBF28294B401DCA501553D34B409161156F64284B401DCA501553D34B40
58913	Кипчаково	7	61	293	53.845934	54.697096999999999	55.829901	55.203400999999999	0103000020E610000001000000050000008849B89047EC4A40A27C410B099A4B408849B89047EC4A4077F52A323AEA4B40E29178793A594B4077F52A323AEA4B40E29178793A594B40A27C410B099A4B408849B89047EC4A40A27C410B099A4B40
22815	Карабашево	7	61	293	54.160955999999999	54.197499000000001	55.401902	55.387106000000003	0103000020E61000000100000005000000280CCA349A144B40EE0A7DB08CB14B40280CCA349A144B403719558671B34B4011FFB0A547194B403719558671B34B4011FFB0A547194B40EE0A7DB08CB14B40280CCA349A144B40EE0A7DB08CB14B40
22748	Кадырово	7	61	293	54.007280999999999	54.048082000000001	55.369500000000002	55.354450999999997	0103000020E61000000100000005000000EB707495EE004B406A847EA65EAD4B40EB707495EE004B409EEFA7C64BAF4B405DC30C8D27064B409EEFA7C64BAF4B405DC30C8D27064B406A847EA65EAD4B40EB707495EE004B406A847EA65EAD4B40
22934	Иштеряково	7	61	293	54.181688999999999	54.209923000000003	55.387172	55.370288000000002	0103000020E610000001000000050000007F85CC9541174B40F60CE19865AF4B407F85CC9541174B40A5F622DA8EB14B40D0D6C1C1DE1A4B40A5F622DA8EB14B40D0D6C1C1DE1A4B40F60CE19865AF4B407F85CC9541174B40F60CE19865AF4B40
22642	Ишкарово	7	61	293	54.510866999999998	54.541849999999997	55.484245000000001	55.469627000000003	0103000020E6100000010000000500000085CD001764414B40C828CFBC1CBC4B4085CD001764414B4032207BBDFBBD4B4036AB3E575B454B4032207BBDFBBD4B4036AB3E575B454B40C828CFBC1CBC4B4085CD001764414B40C828CFBC1CBC4B40
22479	Итеево	7	61	293	54.436487	54.478582000000003	55.529995999999997	55.510567999999999	0103000020E61000000100000005000000881057CEDE374B402B31CF4A5AC14B40881057CEDE374B406281AFE8D6C34B40263ACB2C423D4B406281AFE8D6C34B40263ACB2C423D4B402B31CF4A5AC14B40881057CEDE374B402B31CF4A5AC14B40
22347	Исанбаево	7	61	293	54.206966999999999	54.236449999999998	55.571855999999997	55.543464999999998	0103000020E61000000100000005000000F52C08E57D1A4B40A4C2D84290C54B40F52C08E57D1A4B40BC02D19332C94B40D1915CFE431E4B40BC02D19332C94B40D1915CFE431E4B40A4C2D84290C54B40F52C08E57D1A4B40A4C2D84290C54B40
7192	Исаметово	7	61	293	54.045710999999997	54.072543000000003	55.473025999999997	55.452635000000001	0103000020E61000000100000005000000A208A9DBD9054B40320395F1EFB94B40A208A9DBD9054B402F14B01D8CBC4B40E146CA1649094B402F14B01D8CBC4B40E146CA1649094B40320395F1EFB94B40A208A9DBD9054B40320395F1EFB94B40
23993	Илишево	7	61	293	54.184024000000001	54.203006000000002	55.638770000000001	55.620952000000003	0103000020E61000000100000005000000EDD632198E174B406231EA5A7BCF4B40EDD632198E174B403DD52137C3D14B402672C119FC194B403DD52137C3D14B402672C119FC194B406231EA5A7BCF4B40EDD632198E174B406231EA5A7BCF4B40
58862	Ибрагим	7	61	293	53.845934	54.697096999999999	55.829901	55.203400999999999	0103000020E610000001000000050000008849B89047EC4A40A27C410B099A4B408849B89047EC4A4077F52A323AEA4B40E29178793A594B4077F52A323AEA4B40E29178793A594B40A27C410B099A4B408849B89047EC4A40A27C410B099A4B40
7297	Зяйлево	7	61	293	54.031652000000001	54.044426000000001	55.484918	55.476453999999997	0103000020E610000001000000050000002F6D382C0D044B403106D671FCBC4B402F6D382C0D044B40F19E03CB11BE4B40CA8B4CC0AF054B40F19E03CB11BE4B40CA8B4CC0AF054B403106D671FCBC4B402F6D382C0D044B403106D671FCBC4B40
7085	Дюмеево	7	61	293	54.324108000000003	54.368977999999998	55.268928000000002	55.242483999999997	0103000020E610000001000000050000009D2FF65E7C294B40D1E638B7099F4B409D2FF65E7C294B40467D923B6CA24B40C478CDAB3A2F4B40467D923B6CA24B40C478CDAB3A2F4B40D1E638B7099F4B409D2FF65E7C294B40D1E638B7099F4B40
23219	Груздевка	7	61	293	54.310237999999998	54.320729999999998	55.701495999999999	55.697223999999999	0103000020E61000000100000005000000FCFCF7E0B5274B403FFED2A23ED94B40FCFCF7E0B5274B402D23F59ECAD94B404C6C3EAE0D294B402D23F59ECAD94B404C6C3EAE0D294B403FFED2A23ED94B40FCFCF7E0B5274B403FFED2A23ED94B40
23077	Гремучий Ключ	7	61	293	54.445999999999998	54.642263999999997	55.715133999999999	55.611077999999999	0103000020E610000001000000050000000C022B8716394B400DA7CCCD37CE4B400C022B8716394B40FB20CB8289DB4B40F6B2EDB435524B40FB20CB8289DB4B40F6B2EDB435524B400DA7CCCD37CE4B400C022B8716394B400DA7CCCD37CE4B40
58649	Верхние Юлдашево	7	61	293	54.258701000000002	54.259106000000003	55.693317	55.693083999999999	0103000020E61000000100000005000000A438471D1D214B40C0B0FCF9B6D84B40A438471D1D214B406361889CBED84B404419AA622A214B406361889CBED84B404419AA622A214B40C0B0FCF9B6D84B40A438471D1D214B40C0B0FCF9B6D84B40
1272	Верхнеяркеево	7	61	293	54.302143999999998	54.334232	55.461210999999999	55.431626999999999	0103000020E61000000100000005000000605793A7AC264B400989B48D3FB74B40605793A7AC264B4019C748F608BB4B406AA33A1DC82A4B4019C748F608BB4B406AA33A1DC82A4B400989B48D3FB74B40605793A7AC264B400989B48D3FB74B40
58297	Верхнеюнново	7	61	293	54.318672999999997	54.336638999999998	55.410243999999999	55.395153999999998	0103000020E61000000100000005000000218FE046CA284B401971016894B24B40218FE046CA284B40ABB019E082B44B4071C79BFC162B4B40ABB019E082B44B4071C79BFC162B4B401971016894B24B40218FE046CA284B401971016894B24B40
23807	Верхнечерекулево	7	61	293	54.345756999999999	54.372967000000003	55.496122999999997	55.484796000000003	0103000020E6100000010000000500000079AEEFC3412C4B40A69D9ACB0DBE4B4079AEEFC3412C4B408EE55DF580BF4B405EBEF561BD2F4B408EE55DF580BF4B405EBEF561BD2F4B40A69D9ACB0DBE4B4079AEEFC3412C4B40A69D9ACB0DBE4B40
22138	Верхнеманчарово	7	61	293	54.540475999999998	54.569177000000003	55.374079000000002	55.355939999999997	0103000020E61000000100000005000000EE224C512E454B404BAB21718FAD4B40EE224C512E454B40698F17D2E1AF4B405551BCCADA484B40698F17D2E1AF4B405551BCCADA484B404BAB21718FAD4B40EE224C512E454B404BAB21718FAD4B40
32505	Буралы	7	61	293	54.381518999999997	54.400993999999997	55.540698999999996	55.532787999999996	0103000020E61000000100000005000000BCE6559DD5304B40C2D9AD6532C44B40BCE6559DD5304B406DFDF49F35C54B4034F279C553334B406DFDF49F35C54B4034F279C553334B40C2D9AD6532C44B40BCE6559DD5304B40C2D9AD6532C44B40
3813	Бишкураево	7	61	293	54.532220000000002	54.559305000000002	55.316983999999998	55.303154999999997	0103000020E610000001000000050000007923F3C81F444B40374F75C8CDA64B407923F3C81F444B4079AD84EE92A84B40A1BE654E97474B4079AD84EE92A84B40A1BE654E97474B40374F75C8CDA64B407923F3C81F444B40374F75C8CDA64B40
21362	Базитамак	7	61	293	54.521628999999997	54.548363000000002	55.652805999999998	55.640827999999999	0103000020E6100000010000000500000095D233BDC4424B40382EE3A606D24B4095D233BDC4424B40F850A2258FD34B4011AB3FC230464B40F850A2258FD34B4011AB3FC230464B40382EE3A606D24B4095D233BDC4424B40382EE3A606D24B40
7173	База-Куяново	7	61	293	54.304138000000002	54.328977000000002	55.280045999999999	55.273724000000001	0103000020E6100000010000000500000045BC75FEED264B40AE10566309A34B4045BC75FEED264B4014B01D8CD8A34B406F1118EB1B2A4B4014B01D8CD8A34B406F1118EB1B2A4B40AE10566309A34B4045BC75FEED264B40AE10566309A34B40
21228	Андреевка	7	61	293	54.372590000000002	54.402782000000002	55.709028000000004	55.684888999999998	0103000020E6100000010000000500000088687407B12F4B40F0315871AAD74B4088687407B12F4B4062F9F36DC1DA4B4070B54E5C8E334B4062F9F36DC1DA4B4070B54E5C8E334B40F0315871AAD74B4088687407B12F4B40F0315871AAD74B40
21269	Аначево	7	61	293	54.402746	54.424619999999997	55.713968000000001	55.702098999999997	0103000020E61000000100000005000000234C512E8D334B40F3C64961DED94B40234C512E8D334B40FD31AD4D63DB4B401F9DBAF259364B40FD31AD4D63DB4B401F9DBAF259364B40F3C64961DED94B40234C512E8D334B40F3C64961DED94B40
21076	Аккузево	7	61	293	54.116219999999998	54.144632999999999	55.565677000000001	55.548242999999999	0103000020E610000001000000050000001092054CE00E4B4066A19DD32CC64B401092054CE00E4B40B98C9B1A68C84B4010768A5583124B40B98C9B1A68C84B4010768A5583124B4066A19DD32CC64B401092054CE00E4B4066A19DD32CC64B40
27752	Абдуллино	7	61	293	54.568629000000001	54.588805000000001	55.412681999999997	55.400649999999999	0103000020E610000001000000050000005247C7D5C8484B403A92CB7F48B34B405247C7D5C8484B40EDD286C3D2B44B40535C55F65D4B4B40EDD286C3D2B44B40535C55F65D4B4B403A92CB7F48B34B405247C7D5C8484B403A92CB7F48B34B40
58808	Ясная Поляна	7	61	877	56.417856	56.437727000000002	54.764386000000002	54.756833	0103000020E61000000100000005000000FC372F4E7C354C404CC45BE7DF604B40FC372F4E7C354C4098C28366D7614B40C1C9367007384C4098C28366D7614B40C1C9367007384C404CC45BE7DF604B40FC372F4E7C354C404CC45BE7DF604B40
20949	Чуваш-Кубово	7	61	877	56.550033999999997	56.602406000000002	54.893720999999999	54.875424000000002	0103000020E6100000010000000500000012D89C8367464C401711C5E40D704B4012D89C8367464C40CC5F217365724B400475CAA31B4D4C40CC5F217365724B400475CAA31B4D4C401711C5E40D704B4012D89C8367464C401711C5E40D704B40
19369	Урунда	7	61	877	56.324458	56.339433	54.567622999999998	54.55724	0103000020E610000001000000050000007976F9D687294C40F302ECA353474B407976F9D687294C408CBAD6DEA7484B407217618A722B4C408CBAD6DEA7484B407217618A722B4C40F302ECA353474B407976F9D687294C40F302ECA353474B40
19223	Урман	7	61	877	56.841887999999997	56.893073999999999	54.889417999999999	54.856988999999999	0103000020E610000001000000050000008A7269FCC26B4C401004C8D0B16D4B408A7269FCC26B4C40A33CF372D8714B403674B33F50724C40A33CF372D8714B403674B33F50724C401004C8D0B16D4B408A7269FCC26B4C401004C8D0B16D4B40
19059	Улу-Теляк	7	61	877	56.961461999999997	56.997394999999997	54.924396999999999	54.901321000000003	0103000020E61000000100000005000000622CD32F117B4C4059198D7C5E734B40622CD32F117B4C40A0C211A452764B40D218ADA3AA7F4C40A0C211A452764B40D218ADA3AA7F4C4059198D7C5E734B40622CD32F117B4C4059198D7C5E734B40
6589	Улу-Карамалы	7	61	877	56.991466000000003	57.007123999999997	54.80921	54.797248000000003	0103000020E61000000100000005000000488C9E5BE87E4C409566F3380C664B40488C9E5BE87E4C404FCC7A3194674B4023827170E9804C404FCC7A3194674B4023827170E9804C409566F3380C664B40488C9E5BE87E4C409566F3380C664B40
20734	Уктеево	7	61	877	56.477702000000001	56.496737000000003	54.961227000000001	54.945681	0103000020E61000000100000005000000ED9DD156253D4C406BB933130C794B40ED9DD156253D4C401F84807C097B4B4049DBF813953F4C401F84807C097B4B4049DBF813953F4C406BB933130C794B40ED9DD156253D4C406BB933130C794B40
20664	Турбаслы	7	61	877	56.294373999999998	56.317585999999999	54.661223999999997	54.644613999999997	0103000020E610000001000000050000007765170CAE254C40994528B682524B407765170CAE254C4047AAEFFCA2544B406FD575A8A6284C4047AAEFFCA2544B406FD575A8A6284C40994528B682524B407765170CAE254C40994528B682524B40
20439	Тикеево	7	61	877	56.85962	56.890424000000003	54.828201	54.820414999999997	0103000020E61000000100000005000000677E3507086E4C40EC12D55B03694B40677E3507086E4C40DBC1887D026A4B4069C9E369F9714C40DBC1887D026A4B4069C9E369F9714C40EC12D55B03694B40677E3507086E4C40EC12D55B03694B40
48075	Ташлы-Елга	7	61	877	57.002974000000002	57.012279999999997	54.795779000000003	54.789306000000003	0103000020E61000000100000005000000815EB87361804C40AF44A0FA07654B40815EB87361804C40FBEB1516DC654B408B321B6492814C40FBEB1516DC654B408B321B6492814C40AF44A0FA07654B40815EB87361804C40AF44A0FA07654B40
7459	Тау	7	61	877	57.067428	57.089525999999999	54.722242999999999	54.712529000000004	0103000020E61000000100000005000000D76A0F7BA1884C40CE397826345B4B40D76A0F7BA1884C40E9616875725C4B4023128596758B4C40E9616875725C4B4023128596758B4C40CE397826345B4B40D76A0F7BA1884C40CE397826345B4B40
20562	Тавтиманово	7	61	877	56.627667000000002	56.660041999999997	54.899254999999997	54.869249000000003	0103000020E61000000100000005000000A4E36A6457504C40558A1D8D436F4B40A4E36A6457504C40DAE1AFC91A734B4043FE99417C544C40DAE1AFC91A734B4043FE99417C544C40558A1D8D436F4B40A4E36A6457504C40558A1D8D436F4B40
7474	Старокубово	7	61	877	56.494571999999998	56.515431	54.857295000000001	54.844534000000003	0103000020E6100000010000000500000037C2A2224E3F4C40172EABB0196C4B4037C2A2224E3F4C401D03B2D7BB6D4B401B2C9CA4F9414C401D03B2D7BB6D4B401B2C9CA4F9414C40172EABB0196C4B4037C2A2224E3F4C40172EABB0196C4B40
58817	Саратовская Лобово	7	61	877	56.485832000000002	56.510148999999998	54.903024000000002	54.885497999999998	0103000020E61000000100000005000000D6AC33BE2F3E4C4032569BFF57714B40D6AC33BE2F3E4C4066C0594A96734B40268BFB8F4C414C4066C0594A96734B40268BFB8F4C414C4032569BFF57714B40D6AC33BE2F3E4C4032569BFF57714B40
20306	Расмикеево	7	61	877	57.048788000000002	57.070222000000001	54.897199999999998	54.888133000000003	0103000020E61000000100000005000000F83768AF3E864C40CBBF9657AE714B40F83768AF3E864C4050FC1873D7724B40D8BAD408FD884C4050FC1873D7724B40D8BAD408FD884C40CBBF9657AE714B40F83768AF3E864C40CBBF9657AE714B40
19472	Пятилетка	7	61	877	56.781520999999998	56.812863	54.857838999999998	54.728644000000003	0103000020E61000000100000005000000901150E108644C409C36E334445D4B40901150E108644C40DE1D19ABCD6D4B40719010E50B684C40DE1D19ABCD6D4B40719010E50B684C409C36E334445D4B40901150E108644C409C36E334445D4B40
7371	Пушкинское	7	61	877	56.514757000000003	56.530577000000001	54.704217	54.694336999999997	0103000020E610000001000000050000008C31B08EE3414C408DB3E908E0584B408C31B08EE3414C40C4245CC8235A4B40418177F2E9434C40C4245CC8235A4B40418177F2E9434C408DB3E908E0584B408C31B08EE3414C408DB3E908E0584B40
20627	Покровка	7	61	877	56.639955	56.663077999999999	54.945582999999999	54.930677000000003	0103000020E61000000100000005000000B2F4A10BEA514C40D811876C20774B40B2F4A10BEA514C40A8531EDD08794B403A596ABDDF544C40A8531EDD08794B403A596ABDDF544C40D811876C20774B40B2F4A10BEA514C40D811876C20774B40
58105	Петровское	7	61	877	56.687908	56.705945999999997	54.721676000000002	54.710895999999998	0103000020E6100000010000000500000011548D5E0D584C40B96DDFA3FE5A4B4011548D5E0D584C40702711E15F5C4B40FA5E43705C5A4C40702711E15F5C4B40FA5E43705C5A4C40B96DDFA3FE5A4B4011548D5E0D584C40B96DDFA3FE5A4B40
46731	Первомайское	7	61	877	56.606332000000002	56.613599000000001	54.730406000000002	54.721895000000004	0103000020E61000000100000005000000574277499C4D4C40AE122C0E675C4B40574277499C4D4C40AE669DF17D5D4B40DDED7A698A4E4C40AE669DF17D5D4B40DDED7A698A4E4C40AE122C0E675C4B40574277499C4D4C40AE122C0E675C4B40
28550	Первомайский	7	61	877	57.124965000000003	57.136642999999999	55.083790999999998	55.075695000000003	0103000020E61000000100000005000000841266DAFE8F4C4041BCAE5FB0894B40841266DAFE8F4C407D59DAA9B98A4B40191D90847D914C407D59DAA9B98A4B40191D90847D914C4041BCAE5FB0894B40841266DAFE8F4C4041BCAE5FB0894B40
20511	Охлебинино	7	61	877	56.350383999999998	56.384897000000002	54.511837999999997	54.484147	0103000020E6100000010000000500000055850662D92C4C406FBA6587F83D4B4055850662D92C4C40CE6C57E883414B400DAA0D4E44314C40CE6C57E883414B400DAA0D4E44314C406FBA6587F83D4B4055850662D92C4C406FBA6587F83D4B40
21036	Новокубово	7	61	877	56.541401	56.563068999999999	54.847695999999999	54.836264	0103000020E61000000100000005000000C782C2A04C454C403C69E1B20A6B4B40C782C2A04C454C409A79724D816C4B401A321EA512484C409A79724D816C4B401A321EA512484C403C69E1B20A6B4B40C782C2A04C454C403C69E1B20A6B4B40
20055	Нижние Лемезы	7	61	877	56.977812	57.007689999999997	54.766993999999997	54.741925000000002	0103000020E6100000010000000500000074D190F1287D4C40DB8AFD65F75E4B4074D190F1287D4C40361D01DC2C624B40CC4065FCFB804C40361D01DC2C624B40CC4065FCFB804C40DB8AFD65F75E4B4074D190F1287D4C40DB8AFD65F75E4B40
19753	Михайловка	7	61	877	57.045211999999999	57.061974999999997	55.076833999999998	55.064256	0103000020E6100000010000000500000081B1BE81C9854C403049658A39884B4081B1BE81C9854C40459C4EB2D5894B40B515FBCBEE874C40459C4EB2D5894B40B515FBCBEE874C403049658A39884B4081B1BE81C9854C403049658A39884B40
20769	Минзитарово	7	61	877	56.459322	56.478968000000002	54.924480000000003	54.907051000000003	0103000020E61000000100000005000000AA2A3410CB3A4C40ED66463F1A744B40AA2A3410CB3A4C402EE7525C55764B404FEACBD24E3D4C402EE7525C55764B404FEACBD24E3D4C40ED66463F1A744B40AA2A3410CB3A4C40ED66463F1A744B40
20243	Майский	7	61	877	57.046712999999997	57.071353000000002	54.869092999999999	54.854641000000001	0103000020E6100000010000000500000026A60BB1FA854C400E6954E0646D4B4026A60BB1FA854C405D177E703E6F4B405ABC581822894C405D177E703E6F4B405ABC581822894C400E6954E0646D4B4026A60BB1FA854C400E6954E0646D4B40
46439	Ленинское	7	61	877	56.489299000000003	56.556134	54.770156999999998	54.642868	0103000020E61000000100000005000000967B8159A13E4C408DD2A57F49524B40967B8159A13E4C408AE42B8194624B40CA181F662F474C408AE42B8194624B40CA181F662F474C408DD2A57F49524B40967B8159A13E4C408DD2A57F49524B40
18973	Кудеевский	7	61	877	56.732239	56.796855000000001	54.889308999999997	54.866404000000003	0103000020E6100000010000000500000089EDEE01BA5D4C40D28F8653E66E4B4089EDEE01BA5D4C40EC8497E0D4714B40B9533A58FF654C40EC8497E0D4714B40B9533A58FF654C40D28F8653E66E4B4089EDEE01BA5D4C40D28F8653E66E4B40
19637	Красный Восход	7	61	877	57.001536000000002	57.062415000000001	54.983643999999998	54.96407	0103000020E6100000010000000500000022E2E65432804C40018750A5667B4B4022E2E65432804C400C74ED0BE87D4B40D2E3F736FD874C400C74ED0BE87D4B40D2E3F736FD874C40018750A5667B4B4022E2E65432804C40018750A5667B4B40
20880	Кляшево	7	61	877	56.385120999999998	56.400680000000001	54.920304000000002	54.903773999999999	0103000020E610000001000000050000005C001AA54B314C40D07CCEDDAE734B405C001AA54B314C4062307F85CC754B40A514747B49334C4062307F85CC754B40A514747B49334C40D07CCEDDAE734B405C001AA54B314C40D07CCEDDAE734B40
19954	Кальтовка	7	61	877	56.609008000000003	56.636290000000002	54.685119999999998	54.670014000000002	0103000020E610000001000000050000004E8061F9F34D4C405BEECC04C3554B404E8061F9F34D4C40F2EA1C03B2574B40CC6262F371514C40F2EA1C03B2574B40CC6262F371514C405BEECC04C3554B404E8061F9F34D4C405BEECC04C3554B40
19786	Калтыманово	7	61	877	56.406455999999999	56.421044999999999	54.723699000000003	54.710895999999998	0103000020E61000000100000005000000A9A10DC006344C40B96DDFA3FE5A4B40A9A10DC006344C40EF92382BA25C4B40799274CDE4354C40EF92382BA25C4B40799274CDE4354C40B96DDFA3FE5A4B40A9A10DC006344C40B96DDFA3FE5A4B40
19712	Казаяк	7	61	877	57.104348999999999	57.137371000000002	54.992317	54.975656000000001	0103000020E61000000100000005000000662FDB4E5B8D4C40B612BA4BE27C4B40662FDB4E5B8D4C40E621533E047F4B409C35785F95914C40E621533E047F4B409C35785F95914C40B612BA4BE27C4B40662FDB4E5B8D4C40B612BA4BE27C4B40
18563	Иглино	7	61	877	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
19614	Ивано-Казанка	7	61	877	56.403796999999997	56.440503	54.611579999999996	54.600248999999998	0103000020E61000000100000005000000889CBE9EAF334C40753A90F5D44C4B40889CBE9EAF334C409F71E140484E4B401B65FD6662384C409F71E140484E4B401B65FD6662384C40753A90F5D44C4B40889CBE9EAF334C40753A90F5D44C4B40
19553	Балтика	7	61	877	56.517892000000003	56.553007999999998	54.779494	54.764578999999998	0103000020E61000000100000005000000166EF9484A424C40AC1A84B9DD614B40166EF9484A424C40D0B69A75C6634B40933655F7C8464C40D0B69A75C6634B40933655F7C8464C40AC1A84B9DD614B40166EF9484A424C40AC1A84B9DD614B40
19437	Ауструм	7	61	877	56.745328000000001	56.762431999999997	54.816068000000001	54.804943999999999	0103000020E6100000010000000500000084656CE8665F4C40438EAD6708674B4084656CE8665F4C40F4A78DEA74684B4041B62C5F97614C40F4A78DEA74684B4041B62C5F97614C40438EAD6708674B4084656CE8665F4C40438EAD6708674B40
19842	Алаторка	7	61	877	56.357804000000002	56.379579	54.783906999999999	54.769913000000003	0103000020E6100000010000000500000062307F85CC2D4C40F4E159828C624B4062307F85CC2D4C40800D881057644B40CB9F6F0B96304C40800D881057644B40CB9F6F0B96304C40F4E159828C624B4062307F85CC2D4C40F4E159828C624B40
18424	Ямансаз	7	61	831	57.992162999999998	58.022993	52.310124000000002	52.295591999999999	0103000020E610000001000000050000008FA67A32FFFE4C40C87A6AF5D5254A408FA67A32FFFE4C4034DAAA24B2274A40BA84436FF1024D4034DAAA24B2274A40BA84436FF1024D40C87A6AF5D5254A408FA67A32FFFE4C40C87A6AF5D5254A40
18387	Юмагужино	7	61	831	57.749887000000001	57.776817999999999	52.216918999999997	52.208824	0103000020E610000001000000050000000859164CFCDF4C40594FADBEBA1A4A400859164CFCDF4C40C5707500C41B4A40D978B0C56EE34C40C5707500C41B4A40D978B0C56EE34C40594FADBEBA1A4A400859164CFCDF4C40594FADBEBA1A4A40
18245	Чуюнчи-Чупаново	7	61	831	57.050458999999996	57.074893000000003	52.456252999999997	52.437716999999999	0103000020E61000000100000005000000F964C57075864C409DF3531C07384A40F964C57075864C40D7D9907F663A4A4084D9041896894C40D7D9907F663A4A4084D9041896894C409DF3531C07384A40F964C57075864C409DF3531C07384A40
18131	Султантимирово	7	61	831	58.134033000000002	58.147238999999999	52.308577	52.300300999999997	0103000020E61000000100000005000000DACA4BFE27114D4061FA5E4370264A40DACA4BFE27114D401EA67D737F274A400ED940BAD8124D401EA67D737F274A400ED940BAD8124D4061FA5E4370264A40DACA4BFE27114D4061FA5E4370264A40
58413	Староякупово	7	61	831	57.841039000000002	57.849500999999997	52.235047000000002	52.229101	0103000020E610000001000000050000008DD47B2AA7EB4C408E3D7B2E531D4A408DD47B2AA7EB4C40EF022505161E4A40AB75E272BCEC4C40EF022505161E4A40AB75E272BCEC4C408E3D7B2E531D4A408DD47B2AA7EB4C408E3D7B2E531D4A40
58410	Сидоровка	7	61	831	57.966200999999998	57.992215999999999	52.173932000000001	52.166894999999997	0103000020E61000000100000005000000662E7079ACFB4C40D66EBBD05C154A40662E7079ACFB4C402BDD5D6743164A40B24813EF00FF4C402BDD5D6743164A40B24813EF00FF4C40D66EBBD05C154A40662E7079ACFB4C40D66EBBD05C154A40
17978	Саляхово	7	61	831	57.691586000000001	57.706229	52.201627000000002	52.194257999999998	0103000020E610000001000000050000008C2FDAE385D84C40417E3672DD184A408C2FDAE385D84C40CC7EDDE9CE194A404F3E3DB665DA4C40CC7EDDE9CE194A404F3E3DB665DA4C40417E3672DD184A408C2FDAE385D84C40417E3672DD184A40
17890	Сабырово	7	61	831	57.749420000000001	57.770305999999998	52.070447999999999	52.057502999999997	0103000020E61000000100000005000000F27B9BFEECDF4C40003620425C074A40F27B9BFEECDF4C40C808A87004094A40CFF4126399E24C40C808A87004094A40CFF4126399E24C40003620425C074A40F27B9BFEECDF4C40003620425C074A40
58734	Петровка	7	61	831	57.434218999999999	57.460026999999997	52.361812	52.344017000000001	0103000020E61000000100000005000000A226FA7C94B74C404F22C2BF082C4A40A226FA7C94B74C4072A609DB4F2E4A4074232C2AE2BA4C4072A609DB4F2E4A4074232C2AE2BA4C404F22C2BF082C4A40A226FA7C94B74C404F22C2BF082C4A40
58893	Новопреображенский	7	61	831	57.601385999999998	57.618642999999999	52.173772	52.165503000000001	0103000020E61000000100000005000000D9226937FACC4C40E831CA332F154A40D9226937FACC4C40F27A30293E164A401D739EB12FCF4C40F27A30293E164A401D739EB12FCF4C40E831CA332F154A40D9226937FACC4C40E831CA332F154A40
58892	Новопокровский	7	61	831	57.160052999999998	57.180354999999999	52.477781999999998	52.467002999999998	0103000020E610000001000000050000003750E09D7C944C4023111AC1C63B4A403750E09D7C944C40094FE8F5273D4A40C55565DF15974C40094FE8F5273D4A40C55565DF15974C4023111AC1C63B4A403750E09D7C944C4023111AC1C63B4A40
16742	Матраево	7	61	831	58.018303000000003	58.032290000000003	52.258789	52.240380000000002	0103000020E610000001000000050000009835B1C057024D40664E97C5C41E4A409835B1C057024D4043C879FF1F214A4072FE261422044D4043C879FF1F214A4072FE261422044D40664E97C5C41E4A409835B1C057024D40664E97C5C41E4A40
58816	Малоюлдыбаево	7	61	831	57.835613000000002	57.850875000000002	52.337321000000003	52.325983999999998	0103000020E61000000100000005000000658EE55DF5EA4C407782FDD7B9294A40658EE55DF5EA4C4084A0A3552D2B4A40F4FDD478E9EC4C4084A0A3552D2B4A40F4FDD478E9EC4C407782FDD7B9294A40658EE55DF5EA4C407782FDD7B9294A40
58406	Максютово	7	61	831	57.772748999999997	57.782127000000003	52.273885	52.268143000000002	0103000020E6100000010000000500000023827170E9E24C405FD3838252224A4023827170E9E24C40B7EEE6A90E234A40C828CFBC1CE44C40B7EEE6A90E234A40C828CFBC1CE44C405FD3838252224A4023827170E9E24C405FD3838252224A40
46775	Кашкарово	7	61	831	57.757584999999999	57.774923000000001	52.344898000000001	52.335582000000002	0103000020E610000001000000050000005778978BF8E04C402A90D959F42A4A405778978BF8E04C40583A1F9E252C4A4088F546AD30E34C40583A1F9E252C4A4088F546AD30E34C402A90D959F42A4A405778978BF8E04C402A90D959F42A4A40
7168	Картлазма	7	61	831	57.094144	57.116179000000002	52.404825000000002	52.393642999999997	0103000020E61000000100000005000000AC8E1CE90C8C4C4050A6D1E462324A40AC8E1CE90C8C4C4036CD3B4ED1334A40B2BD16F4DE8E4C4036CD3B4ED1334A40B2BD16F4DE8E4C4050A6D1E462324A40AC8E1CE90C8C4C4050A6D1E462324A40
32595	Кананикольское	7	61	831	57.458545000000001	57.505859999999998	52.792482999999997	52.771453000000001	0103000020E61000000100000005000000465F419AB1BA4C4057B3CEF8BE624A40465F419AB1BA4C4067D13B1570654A40622D3E05C0C04C4067D13B1570654A40622D3E05C0C04C4057B3CEF8BE624A40465F419AB1BA4C4057B3CEF8BE624A40
17541	Кадырша	7	61	831	57.621859000000001	57.637875999999999	51.99438	51.987924999999997	0103000020E6100000010000000500000094DC611399CF4C404DF38E5374FE494094DC611399CF4C40F3E505D847FF49409F73B7EBA5D14C40F3E505D847FF49409F73B7EBA5D14C404DF38E5374FE494094DC611399CF4C404DF38E5374FE4940
6000	Зилаир	7	61	831	57.426206000000001	57.463639000000001	52.248392000000003	52.214773000000001	0103000020E61000000100000005000000F3AD0FEB8DB64C402B8881AE7D1B4A40F3AD0FEB8DB64C40454B1E4FCB1F4A403813D38558BB4C40454B1E4FCB1F4A403813D38558BB4C402B8881AE7D1B4A40F3AD0FEB8DB64C402B8881AE7D1B4A40
17332	Верхнегалеево	7	61	831	57.856670000000001	57.869551000000001	52.144207999999999	52.133988000000002	0103000020E610000001000000050000006FBBD05CA7ED4C403A07CF8426114A406FBBD05CA7ED4C4029E9616875124A40209A79724DEF4C4029E9616875124A40209A79724DEF4C403A07CF8426114A406FBBD05CA7ED4C403A07CF8426114A40
58739	Васильевка	7	61	831	57.583123999999998	57.598018000000003	52.105741999999999	52.094506000000003	0103000020E61000000100000005000000A0C1A6CEA3CA4C404DA3C9C5180C4A40A0C1A6CEA3CA4C4025E82FF4880D4A40AD3594DA8BCC4C4025E82FF4880D4A40AD3594DA8BCC4C404DA3C9C5180C4A40A0C1A6CEA3CA4C404DA3C9C5180C4A40
46067	Бердяш	7	61	831	57.195995000000003	57.217877999999999	52.187041999999998	52.170856000000001	0103000020E61000000100000005000000FB96395D16994C40A629029CDE154A40FB96395D16994C403D7D04FEF0174A404A42226DE39B4C403D7D04FEF0174A404A42226DE39B4C40A629029CDE154A40FB96395D16994C40A629029CDE154A40
17136	Балапан	7	61	831	58.02814	58.036324	52.235619999999997	52.228963	0103000020E61000000100000005000000CFDA6D179A034D403D7FDAA84E1D4A40CFDA6D179A034D404A24D1CB281E4A40AB07CC43A6044D404A24D1CB281E4A40AB07CC43A6044D403D7FDAA84E1D4A40CFDA6D179A034D403D7FDAA84E1D4A40
17079	Байгужино	7	61	831	57.869002999999999	57.884436999999998	52.078955999999998	52.073	0103000020E610000001000000050000001D90847D3BEF4C40D34D621058094A401D90847D3BEF4C4057E9EE3A1B0A4A40A92F4B3B35F14C4057E9EE3A1B0A4A40A92F4B3B35F14C40D34D621058094A401D90847D3BEF4C40D34D621058094A40
17046	Ашкадарово	7	61	831	57.674284999999998	57.684489999999997	52.018312999999999	52.008429999999997	0103000020E6100000010000000500000078978BF84ED64C401327F73B14014A4078978BF84ED64C40BB0B941458024A4032384A5E9DD74C40BB0B941458024A4032384A5E9DD74C401327F73B14014A4078978BF84ED64C401327F73B14014A40
58520	Анновка	7	61	831	57.483294000000001	57.501682000000002	52.132302000000003	52.114144000000003	0103000020E61000000100000005000000302DEA93DCBD4C406F8445459C0E4A40302DEA93DCBD4C4003999D45EF104A40F67EA31D37C04C4003999D45EF104A40F67EA31D37C04C406F8445459C0E4A40302DEA93DCBD4C406F8445459C0E4A40
58899	ферма 3	7	61	184	56.865594000000002	56.883192000000001	51.686684999999997	51.677320000000002	0103000020E6100000010000000500000092CEC0C8CB6E4C409F76F86BB2D6494092CEC0C8CB6E4C40AED3484BE5D749405F0B7A6F0C714C40AED3484BE5D749405F0B7A6F0C714C409F76F86BB2D6494092CEC0C8CB6E4C409F76F86BB2D64940
16712	Яныбаево	7	61	184	57.256065	57.279483999999997	51.698186	51.680202000000001	0103000020E610000001000000050000003B53E8BCC6A04C403F56F0DB10D749403B53E8BCC6A04C403543AA285ED94940ACE0B721C6A34C403543AA285ED94940ACE0B721C6A34C403F56F0DB10D749403B53E8BCC6A04C403F56F0DB10D74940
16549	Юнаево	7	61	184	57.062199999999997	57.077731	51.737724	51.723694999999999	0103000020E61000000100000005000000D5E76A2BF6874C40ADA3AA09A2DC4940D5E76A2BF6874C40B6BC72BD6DDE49405471E316F3894C40B6BC72BD6DDE49405471E316F3894C40ADA3AA09A2DC4940D5E76A2BF6874C40ADA3AA09A2DC4940
13996	Юлдыбаево	7	61	184	56.627513999999998	56.654221	51.861179999999997	51.854894999999999	0103000020E610000001000000050000001DE4F56052504C40C84109336DED49401DE4F56052504C4011FC6F253BEE49409FAD8383BD534C4011FC6F253BEE49409FAD8383BD534C40C84109336DED49401DE4F56052504C40C84109336DED4940
16247	Худабандино	7	61	184	56.955191999999997	56.966259999999998	52.157983999999999	52.154023000000002	0103000020E610000001000000050000004EB340BB437A4C4079EA9106B7134A404EB340BB437A4C4048A5D8D138144A406BB75D68AE7B4C4048A5D8D138144A406BB75D68AE7B4C4079EA9106B7134A404EB340BB437A4C4079EA9106B7134A40
16492	Утягулово	7	61	184	57.024003	57.056891	51.708354999999997	51.696449999999999	0103000020E61000000100000005000000C100C28712834C404CA60A4625D94940C100C28712834C40A27A6B60ABDA4940E7374C3448874C40A27A6B60ABDA4940E7374C3448874C404CA60A4625D94940C100C28712834C404CA60A4625D94940
15457	Умбетово	7	61	184	56.799415000000003	56.815693000000003	52.068415999999999	52.058903999999998	0103000020E610000001000000050000004777103B53664C4042CD902A8A074A404777103B53664C40F64201DBC1084A40BF49D3A068684C40F64201DBC1084A40BF49D3A068684C4042CD902A8A074A404777103B53664C4042CD902A8A074A40
14695	Трушино	7	61	184	56.746972	56.764282000000001	52.242348	52.231158000000001	0103000020E610000001000000050000008C834BC79C5F4C40B91AD995961D4A408C834BC79C5F4C4021205F42051F4A40F37519FED3614C4021205F42051F4A40F37519FED3614C40B91AD995961D4A408C834BC79C5F4C40B91AD995961D4A40
16339	Тазларово	7	61	184	56.663221999999998	56.699756000000001	52.155332000000001	52.142733	0103000020E610000001000000050000006DFE5F75E4544C40AD872F1345124A406DFE5F75E4544C40DA0242EBE1134A400397C79A91594C40DA0242EBE1134A400397C79A91594C40AD872F1345124A406DFE5F75E4544C40AD872F1345124A40
14511	Серегулово	7	61	184	56.890557999999999	56.909934999999997	52.257962999999997	52.243402000000003	0103000020E610000001000000050000007898F6CDFD714C40F8E3F6CB271F4A407898F6CDFD714C40FD497CEE04214A402D3E05C078744C40FD497CEE04214A402D3E05C078744C40F8E3F6CB271F4A407898F6CDFD714C40F8E3F6CB271F4A40
14177	Сагитово	7	61	184	57.102201999999998	57.114660999999998	51.820008000000001	51.808855999999999	0103000020E61000000100000005000000FBCA83F4148D4C403196E99788E74940FBCA83F4148D4C40AC3AAB05F6E8494036902E36AD8E4C40AC3AAB05F6E8494036902E36AD8E4C403196E99788E74940FBCA83F4148D4C403196E99788E74940
15859	Новые Чебенки	7	61	184	56.335498000000001	56.375024000000003	52.208917999999997	52.190978999999999	0103000020E61000000100000005000000CCEF3499F12A4C40849CF7FF71184A40CCEF3499F12A4C40DAC534D3BD1A4A40899B53C900304C40DAC534D3BD1A4A40899B53C900304C40849CF7FF71184A40CCEF3499F12A4C40849CF7FF71184A40
15643	Новопетровское	7	61	184	56.552891000000002	56.574801000000001	52.237402000000003	52.209001000000001	0103000020E610000001000000050000005AA0DD21C5464C4068EA758BC01A4A405AA0DD21C5464C40A4005130631E4A40A35A441493494C40A4005130631E4A40A35A441493494C4068EA758BC01A4A405AA0DD21C5464C4068EA758BC01A4A40
15071	Новопавловка	7	61	184	56.563338000000002	56.580891000000001	52.177726	52.169457999999999	0103000020E610000001000000050000000A4CA7751B484C40D505BCCCB0154A400A4CA7751B484C400FD3BEB9BF164A4037C5E3A25A4A4C400FD3BEB9BF164A4037C5E3A25A4A4C40D505BCCCB0154A400A4CA7751B484C40D505BCCCB0154A40
15882	Новониколаевка	7	61	184	56.414648999999997	56.425069000000001	52.271895999999998	52.261116000000001	0103000020E61000000100000005000000D828EB3713354C402E3BC43F6C214A40D828EB3713354C40E4F4F57CCD224A408FC536A968364C40E4F4F57CCD224A408FC536A968364C402E3BC43F6C214A40D828EB3713354C402E3BC43F6C214A40
14748	Нижняя Бикберда	7	61	184	56.777684999999998	56.788429000000001	52.266032000000003	52.250287999999998	0103000020E610000001000000050000007DCB9C2E8B634C40664AEB6F09204A407DCB9C2E8B634C4041D829560D224A40E71BD13DEB644C4041D829560D224A40E71BD13DEB644C40664AEB6F09204A407DCB9C2E8B634C40664AEB6F09204A40
15358	Нижняя Акберда	7	61	184	56.749029	56.779885999999998	52.004344000000003	51.992933000000001	0103000020E61000000100000005000000B760A92EE05F4C40410FB56D18FF4940B760A92EE05F4C4088F71C588E004A40DB4DF04DD3634C4088F71C588E004A40DB4DF04DD3634C40410FB56D18FF4940B760A92EE05F4C40410FB56D18FF4940
13847	Мухамедьяново	7	61	184	56.940441999999997	56.947682	51.976199000000001	51.968459000000003	0103000020E6100000010000000500000075E4486760784C402942EA76F6FB494075E4486760784C40A7B1BD16F4FC49400281CEA44D794C40A7B1BD16F4FC49400281CEA44D794C402942EA76F6FB494075E4486760784C402942EA76F6FB4940
660	Малый Муйнак	7	61	184	56.757185999999997	56.765369	52.127127000000002	52.123722000000001	0103000020E61000000100000005000000997E8978EB604C40DAE55B1FD60F4A40997E8978EB604C4024B891B245104A40A52F849CF7614C4024B891B245104A40A52F849CF7614C40DAE55B1FD60F4A40997E8978EB604C40DAE55B1FD60F4A40
14044	Малиновка	7	61	184	56.867544000000002	56.883730999999997	51.784275999999998	51.772635000000001	0103000020E61000000100000005000000A7EB89AE0B6F4C405B5F24B4E5E24940A7EB89AE0B6F4C40D384ED2763E449400EBBEF181E714C40D384ED2763E449400EBBEF181E714C405B5F24B4E5E24940A7EB89AE0B6F4C405B5F24B4E5E24940
15563	Мазитово	7	61	184	56.893585999999999	56.905946999999998	52.064928000000002	52.057170999999997	0103000020E61000000100000005000000EC14AB0661724C40CAA31B6151074A40EC14AB0661724C401F4C8A8F4F084A4064744012F6734C401F4C8A8F4F084A4064744012F6734C40CAA31B6151074A40EC14AB0661724C40CAA31B6151074A40
58756	Лукьяновский	7	61	184	56.958534	56.973697999999999	51.874003999999999	51.863433000000001	0103000020E61000000100000005000000520DFB3DB17A4C40C2A4F8F884EE4940520DFB3DB17A4C405E49F25CDFEF49401E17D522A27C4C405E49F25CDFEF49401E17D522A27C4C40C2A4F8F884EE4940520DFB3DB17A4C40C2A4F8F884EE4940
15787	Кузебеково	7	61	184	56.401874999999997	56.415331999999999	52.219583999999998	52.215093000000003	0103000020E610000001000000050000003D0AD7A370334C409D4CDC2A881B4A403D0AD7A370334C40C85C19541B1C4A40BB7D569929354C40C85C19541B1C4A40BB7D569929354C409D4CDC2A881B4A403D0AD7A370334C409D4CDC2A881B4A40
16846	Кужанак	7	61	184	57.169592999999999	57.185799000000003	51.605398000000001	51.591366000000001	0103000020E61000000100000005000000B5503239B5954C40B1FB8EE1B1CB4940B5503239B5954C402B8881AE7DCD49409450FA42C8974C402B8881AE7DCD49409450FA42C8974C40B1FB8EE1B1CB4940B5503239B5954C40B1FB8EE1B1CB4940
16091	Кугарчи	7	61	184	56.817785999999998	56.845283000000002	52.154625000000003	52.142263	0103000020E6100000010000000500000036902E36AD684C4026378AAC35124A4036902E36AD684C406F1283C0CA134A40B16EBC3B326C4C406F1283C0CA134A40B16EBC3B326C4C4026378AAC35124A4036902E36AD684C4026378AAC35124A40
16171	Кинзябулатово	7	61	184	56.795650999999999	56.80256	52.161724999999997	52.155095000000003	0103000020E61000000100000005000000CD0358E4D7654C40F6622827DA134A40CD0358E4D7654C4009F9A067B3144A40F4893C49BA664C4009F9A067B3144A40F4893C49BA664C40F6622827DA134A40CD0358E4D7654C40F6622827DA134A40
58811	Карагала	7	61	184	57.089993	57.102884000000003	52.126745999999997	52.117024999999998	0103000020E6100000010000000500000039EFFFE3848B4C403EE8D9ACFA0E4A4039EFFFE3848B4C400C73823639104A400EA48B4D2B8D4C400C73823639104A400EA48B4D2B8D4C403EE8D9ACFA0E4A4039EFFFE3848B4C403EE8D9ACFA0E4A40
15260	Казанка	7	61	184	57.144970000000001	57.174211	51.821266999999999	51.801271	0103000020E61000000100000005000000587380608E924C40DA1D520C90E64940587380608E924C405B24ED461FE949403ECDC98B4C964C405B24ED461FE949403ECDC98B4C964C40DA1D520C90E64940587380608E924C40DA1D520C90E64940
58329	Ишемгул	7	61	184	56.199835	57.401107000000003	52.462915000000002	51.572012999999998	0103000020E610000001000000050000004FCC7A3194194C4084F1D3B837C949404FCC7A3194194C40F7E978CC403B4A402D99637957B34C40F7E978CC403B4A402D99637957B34C4084F1D3B837C949404FCC7A3194194C4084F1D3B837C94940
5239	Исянгулово	7	61	184	56.554884999999999	56.605477999999998	52.205407999999998	52.179676000000001	0103000020E610000001000000050000003E05C07806474C4024F0879FFF164A403E05C07806474C401B2B31CF4A1A4A404739984D804D4C401B2B31CF4A1A4A404739984D804D4C4024F0879FFF164A403E05C07806474C4024F0879FFF164A40
14416	Ильмаля	7	61	184	57.096812	57.110106999999999	51.879686999999997	51.870863	0103000020E6100000010000000500000020EEEA55648C4C40F225547078EF494020EEEA55648C4C40B1DB679599F04940C40776FC178E4C40B1DB679599F04940C40776FC178E4C40F225547078EF494020EEEA55648C4C40F225547078EF4940
16569	Идяш	7	61	184	56.999218999999997	57.012549999999997	51.746462999999999	51.733696999999999	0103000020E610000001000000050000005A457F68E67F4C402F1686C8E9DD49405A457F68E67F4C4047567E198CDF49404BC8073D9B814C4047567E198CDF49404BC8073D9B814C402F1686C8E9DD49405A457F68E67F4C402F1686C8E9DD4940
15213	Идельбаково	7	61	184	57.109361	57.149534000000003	51.786130999999997	51.750315999999998	0103000020E610000001000000050000009B3A8F8AFF8D4C4030D5CC5A0AE049409B3A8F8AFF8D4C4096AFCBF09FE44940EED11BEE23934C4096AFCBF09FE44940EED11BEE23934C4030D5CC5A0AE049409B3A8F8AFF8D4C4030D5CC5A0AE04940
14539	Ибраево	7	61	184	56.946784000000001	56.973517999999999	52.260255999999998	52.253982000000001	0103000020E610000001000000050000002330D63730794C40E7E26F7B82204A402330D63730794C403C4B901150214A409E08E23C9C7C4C403C4B901150214A409E08E23C9C7C4C40E7E26F7B82204A402330D63730794C40E7E26F7B82204A40
15611	Габбасово	7	61	184	56.884369	56.896335000000001	52.111156999999999	52.108629999999998	0103000020E61000000100000005000000514CDE0033714C40A7AE7C96E70D4A40514CDE0033714C4059DC7F643A0E4A404DA1F31ABB724C4059DC7F643A0E4A404DA1F31ABB724C40A7AE7C96E70D4A40514CDE0033714C40A7AE7C96E70D4A40
14784	Верхняя Бикберда	7	61	184	56.770569999999999	56.782688999999998	52.283825	52.274227000000003	0103000020E61000000100000005000000ADA3AA09A2624C401157CEDE19234A40ADA3AA09A2624C40C364AA6054244A402FF834272F644C40C364AA6054244A402FF834272F644C401157CEDE19234A40ADA3AA09A2624C401157CEDE19234A40
15298	Верхний Муйнак	7	61	184	56.740898999999999	56.768639	52.040505000000003	52.026215999999998	0103000020E61000000100000005000000CE5147C7D55E4C40E350BF0B5B034A40CE5147C7D55E4C40892991442F054A400FB743C362624C40892991442F054A400FB743C362624C40E350BF0B5B034A40CE5147C7D55E4C40E350BF0B5B034A40
58848	Верхние Мамбетшино	7	61	184	57.286284000000002	57.306244999999997	51.724314	51.714047999999998	0103000020E610000001000000050000001DAF40F4A4A44C4019E3C3EC65DB49401DAF40F4A4A44C4079043752B6DC494021C8410933A74C4079043752B6DC494021C8410933A74C4019E3C3EC65DB49401DAF40F4A4A44C4019E3C3EC65DB4940
14442	Биштиряк	7	61	184	57.173842	57.204636000000001	51.948990000000002	51.938675000000003	0103000020E61000000100000005000000EB55647440964C4052499D8026F84940EB55647440964C40931D1B8178F94940C9CA2F83319A4C40931D1B8178F94940C9CA2F83319A4C4052499D8026F84940EB55647440964C4052499D8026F84940
16400	Биккужа	7	61	184	56.624540000000003	56.635328999999999	52.104885000000003	52.098224000000002	0103000020E610000001000000050000009D853DEDF04F4C4056D7A19A920C4A409D853DEDF04F4C40A56B26DF6C0D4A40A699EE7552514C40A56B26DF6C0D4A40A699EE7552514C4056D7A19A920C4A409D853DEDF04F4C4056D7A19A920C4A40
16893	Башкирский Бармак	7	61	184	57.194324000000002	57.207321999999998	51.672142999999998	51.66263	0103000020E61000000100000005000000F969DC9BDF984C409BAC510FD1D44940F969DC9BDF984C401F9E25C808D64940E3DEFC86899A4C401F9E25C808D64940E3DEFC86899A4C409BAC510FD1D44940F969DC9BDF984C409BAC510FD1D44940
13901	Башкирская Чумаза	7	61	184	56.773705999999997	56.795265000000001	51.949384000000002	51.936604000000003	0103000020E61000000100000005000000075C57CC08634C40C2A6CEA3E2F74940075C57CC08634C403FAC376A85F94940A453573ECB654C403FAC376A85F94940A453573ECB654C40C2A6CEA3E2F74940075C57CC08634C40C2A6CEA3E2F74940
15697	Башкирская Ургинка	7	61	184	56.648992999999997	56.670399000000003	52.275627	52.253667999999998	0103000020E610000001000000050000009D2ADF3312534C4057056A3178204A409D2ADF3312534C408272DBBE47234A40B4226AA2CF554C408272DBBE47234A40B4226AA2CF554C4057056A3178204A409D2ADF3312534C4057056A3178204A40
14611	Байдавлетово	7	61	184	56.879922000000001	56.892040999999999	52.214683999999998	52.203178000000001	0103000020E61000000100000005000000F583BA48A1704C4023A298BC011A4A40F583BA48A1704C40BB7CEBC37A1B4A4077D844662E724C40BB7CEBC37A1B4A4077D844662E724C4023A298BC011A4A40F583BA48A1704C4023A298BC011A4A40
14219	Баишево	7	61	184	57.078809	57.099713000000001	51.845098	51.833078	0103000020E61000000100000005000000B3D0CE69168A4C403082C64CA2EA4940B3D0CE69168A4C401FF5D72B2CEC494037FE4465C38C4C401FF5D72B2CEC494037FE4465C38C4C403082C64CA2EA4940B3D0CE69168A4C403082C64CA2EA4940
15158	Аютово	7	61	184	56.500492000000001	56.516680000000001	52.168242999999997	52.162962	0103000020E610000001000000050000006FF4311F10404C40D13E56F0DB144A406FF4311F10404C40F56393FC88154A40A73FFB9122424C40F56393FC88154A40A73FFB9122424C40D13E56F0DB144A406FF4311F10404C40D13E56F0DB144A40
13778	Алибаево	7	61	184	56.920239000000002	56.933650999999998	51.940123999999997	51.928980000000003	0103000020E610000001000000050000007BC03C64CA754C40AD510FD1E8F649407BC03C64CA754C40A417B5FB55F8494058703FE081774C40A417B5FB55F8494058703FE081774C40AD510FD1E8F649407BC03C64CA754C40AD510FD1E8F64940
14350	Акдавлетово	7	61	184	57.010438999999998	57.021461000000002	51.888693000000004	51.880431999999999	0103000020E610000001000000050000002DCDAD1056814C400A2DEBFEB1F049402DCDAD1056814C40929735B1C0F14940DA91EA3BBF824C40929735B1C0F14940DA91EA3BBF824C400A2DEBFEB1F049402DCDAD1056814C400A2DEBFEB1F04940
14133	Абуляисово	7	61	184	56.882967999999998	56.898311	51.758355000000002	51.748280000000001	0103000020E610000001000000050000000FB56D1805714C401D2098A3C7DF49400FB56D1805714C4009E1D1C611E149408B51D7DAFB724C4009E1D1C611E149408B51D7DAFB724C401D2098A3C7DF49400FB56D1805714C401D2098A3C7DF4940
13760	Абзаново	7	61	184	56.744168999999999	56.783344999999997	51.859206	51.843913000000001	0103000020E6100000010000000500000038D906EE405F4C40AAD5575705EC494038D906EE405F4C4074435376FAED4940183E22A644644C4074435376FAED4940183E22A644644C40AAD5575705EC494038D906EE405F4C40AAD5575705EC4940
58845	участок Санатория Имени Глуховского	7	61	144	53.926774000000002	53.930708000000003	53.840823	53.837577000000003	0103000020E610000001000000050000003D64CA87A0F64A40DF701FB935EB4A403D64CA87A0F64A40C05C8B16A0EB4A401310937021F74A40C05C8B16A0EB4A401310937021F74A40DF701FB935EB4A403D64CA87A0F64A40DF701FB935EB4A40
12503	имени 8 Марта	7	61	144	53.741838000000001	53.772739999999999	53.902490999999998	53.891497000000001	0103000020E610000001000000050000000C772E8CF4DE4A40B6BDDD921CF24A400C772E8CF4DE4A4098F738D384F34A40D027F224E9E24A4098F738D384F34A40D027F224E9E24A40B6BDDD921CF24A400C772E8CF4DE4A40B6BDDD921CF24A40
4902	Усман-Ташлы	7	61	144	53.550874	53.576619000000001	54.277825	54.258600999999999	0103000020E61000000100000005000000BD1B0B0A83C64A4040DB6AD619214B40BD1B0B0A83C64A406F8104C58F234B4049A0C1A6CEC94A406F8104C58F234B4049A0C1A6CEC94A4040DB6AD619214B40BD1B0B0A83C64A4040DB6AD619214B40
13637	Тарказы	7	61	144	53.614834000000002	53.650623000000003	53.844462	53.828496000000001	0103000020E61000000100000005000000043C69E1B2CE4A40F46E2C280CEA4A40043C69E1B2CE4A407D5BB05417EC4A4041834D9D47D34A407D5BB05417EC4A4041834D9D47D34A40F46E2C280CEA4A40043C69E1B2CE4A40F46E2C280CEA4A40
13608	Суккулово	7	61	144	53.720027000000002	53.749679999999998	54.251874000000001	54.216456999999998	0103000020E61000000100000005000000569E40D829DC4A40C1FEEBDCB41B4B40569E40D829DC4A403A5B40683D204B408E3BA583F5DF4A403A5B40683D204B408E3BA583F5DF4A40C1FEEBDCB41B4B40569E40D829DC4A40C1FEEBDCB41B4B40
13480	Старые Сулли	7	61	144	53.560513	53.592708000000002	54.202182000000001	54.177773999999999	0103000020E61000000100000005000000CEFDD5E3BEC74A40200A664CC1164B40CEFDD5E3BEC74A4081EB8A19E1194B40EE0912DBDDCB4A4081EB8A19E1194B40EE0912DBDDCB4A40200A664CC1164B40CEFDD5E3BEC74A40200A664CC1164B40
13576	Старошахово	7	61	144	53.575757000000003	53.642673000000002	54.306176000000001	54.286351000000003	0103000020E61000000100000005000000B7B8C667B2C94A40A5164A26A7244B40B7B8C667B2C94A40F96871C630274B40D882DE1B43D24A40F96871C630274B40D882DE1B43D24A40A5164A26A7244B40B7B8C667B2C94A40A5164A26A7244B40
448	Старотураево	7	61	144	53.471983999999999	53.521714000000003	54.285221	54.266899000000002	0103000020E610000001000000050000001D1EC2F869BC4A40E52A16BF29224B401D1EC2F869BC4A40F390291F82244B40C4EE3B86C7C24A40F390291F82244B40C4EE3B86C7C24A40E52A16BF29224B401D1EC2F869BC4A40E52A16BF29224B40
445	Средние Карамалы	7	61	144	53.583007000000002	53.613612000000003	53.991315999999998	53.970830999999997	0103000020E61000000100000005000000672B2FF99FCA4A40B378B13044FC4A40672B2FF99FCA4A4032005471E3FE4A40723788D68ACE4A4032005471E3FE4A40723788D68ACE4A40B378B13044FC4A40672B2FF99FCA4A40B378B13044FC4A40
13328	Спартак	7	61	144	53.784427000000001	53.813685	53.988844	53.972546999999999	0103000020E61000000100000005000000B98C9B1A68E44A4055698B6B7CFC4A40B98C9B1A68E44A40446CB07092FE4A40751F80D426E84A40446CB07092FE4A40751F80D426E84A4055698B6B7CFC4A40B98C9B1A68E44A4055698B6B7CFC4A40
13292	Семено-Макарово	7	61	144	53.785639000000003	53.807944999999997	54.108772999999999	54.095807000000001	0103000020E6100000010000000500000028BB99D18FE44A402BDD5D67430C4B4028BB99D18FE44A400AD80E46EC0D4B40BDFBE3BD6AE74A400AD80E46EC0D4B40BDFBE3BD6AE74A402BDD5D67430C4B4028BB99D18FE44A402BDD5D67430C4B40
13218	Рятамак	7	61	144	53.507503	53.555436999999998	54.1004	54.071463000000001	0103000020E610000001000000050000009ACFB9DBF5C04A40E1EF17B325094B409ACFB9DBF5C04A405B423EE8D90C4B4082FE428F18C74A405B423EE8D90C4B4082FE428F18C74A40E1EF17B325094B409ACFB9DBF5C04A40E1EF17B325094B40
12213	Приютово	7	61	144	53.908555999999997	53.961897999999998	53.912866000000001	53.874015	0103000020E61000000100000005000000D34A21904BF44A40529B38B9DFEF4A40D34A21904BF44A40AFD007CBD8F44A403D0B42791FFB4A40AFD007CBD8F44A403D0B42791FFB4A40529B38B9DFEF4A40D34A21904BF44A40529B38B9DFEF4A40
13138	Пионерский	7	61	144	53.741774999999997	53.762562000000003	53.983111000000001	53.978620999999997	0103000020E61000000100000005000000C5FEB27BF2DE4A40E316F37343FD4A40C5FEB27BF2DE4A403FABCC94D6FD4A401096B1A19BE14A403FABCC94D6FD4A401096B1A19BE14A40E316F37343FD4A40C5FEB27BF2DE4A40E316F37343FD4A40
13202	Новый	7	61	144	53.962778	53.974626999999998	53.885171999999997	53.878399000000002	0103000020E6100000010000000500000076A73B4F3CFB4A4068EBE0606FF04A4076A73B4F3CFB4A40DEAAEB504DF14A403866D993C0FC4A40DEAAEB504DF14A403866D993C0FC4A4068EBE0606FF04A4076A73B4F3CFB4A4068EBE0606FF04A40
343	Новые Сулли	7	61	144	53.593210999999997	53.625371000000001	54.175381999999999	54.152766999999997	0103000020E6100000010000000500000050508A56EECB4A403A747ADE8D134B4050508A56EECB4A404E27D9EA72164B40F46E2C280CD04A404E27D9EA72164B40F46E2C280CD04A403A747ADE8D134B4050508A56EECB4A403A747ADE8D134B40
13045	Новошахово	7	61	144	53.825650000000003	53.838217999999998	53.816918999999999	53.804532000000002	0103000020E61000000100000005000000A1F831E6AEE94A40F14A92E7FAE64A40A1F831E6AEE94A40923D42CD90E84A40927538BA4AEB4A40923D42CD90E84A40927538BA4AEB4A40F14A92E7FAE64A40A1F831E6AEE94A40F14A92E7FAE64A40
13085	Новотураево	7	61	144	53.825363000000003	53.84854	53.835738999999997	53.823261000000002	0103000020E610000001000000050000000B2AAA7EA5E94A404089CF9D60E94A400B2AAA7EA5E94A40F17EDC7EF9EA4A4086AC6EF59CEC4A40F17EDC7EF9EA4A4086AC6EF59CEC4A404089CF9D60E94A400B2AAA7EA5E94A404089CF9D60E94A40
58846	Нижнии Карамалы	7	61	144	53.563459000000002	53.582953000000003	53.955404999999999	53.943361000000003	0103000020E6100000010000000500000085D1AC6C1FC84A4033A9A10DC0F84A4085D1AC6C1FC84A40AAB706B64AFA4A40740D33349ECA4A40AAB706B64AFA4A40740D33349ECA4A4033A9A10DC0F84A4085D1AC6C1FC84A4033A9A10DC0F84A40
12943	Нижнеулу-Елга	7	61	144	53.730491999999998	53.752949999999998	54.068277000000002	54.056581999999999	0103000020E61000000100000005000000ACFE08C380DD4A4069C537143E074B40ACFE08C380DD4A40D508FD4CBD084B40F8C264AA60E04A40D508FD4CBD084B40F8C264AA60E04A4069C537143E074B40ACFE08C380DD4A4069C537143E074B40
12886	Купченеево	7	61	144	53.696033	53.714762	54.172888999999998	54.153674000000002	0103000020E61000000100000005000000E8F7FD9B17D94A406D1FF296AB134B40E8F7FD9B17D94A40486B0C3A21164B4037363B527DDB4A40486B0C3A21164B4037363B527DDB4A406D1FF296AB134B40E8F7FD9B17D94A406D1FF296AB134B40
4673	Кулбаево	7	61	144	53.457934000000002	53.476610000000001	54.168098000000001	54.156247	0103000020E61000000100000005000000FDDCD0949DBA4A408F8CD5E6FF134B40FDDCD0949DBA4A40F2423A3C84154B402979758E01BD4A40F2423A3C84154B402979758E01BD4A408F8CD5E6FF134B40FDDCD0949DBA4A408F8CD5E6FF134B40
10285	Исламбахты	7	61	144	53.710954000000001	53.751899000000002	53.762720999999999	53.750185000000002	0103000020E61000000100000005000000EE7A698A00DB4A409279E40F06E04A40EE7A698A00DB4A40787C7BD7A0E14A409372F7393EE04A40787C7BD7A0E14A409372F7393EE04A409279E40F06E04A40EE7A698A00DB4A409279E40F06E04A40
12607	Ермекеево	7	61	144	53.648952000000001	53.695340999999999	54.089458999999998	54.066253000000003	0103000020E610000001000000050000003F56F0DB10D34A40862172FA7A084B403F56F0DB10D34A409BAA7B64730B4B40B24813EF00D94A409BAA7B64730B4B40B24813EF00D94A40862172FA7A084B403F56F0DB10D34A40862172FA7A084B40
12470	Верхнеулу-Елга	7	61	144	53.731687000000001	53.743904000000001	54.035229999999999	54.019970999999998	0103000020E6100000010000000500000045F46BEBA7DD4A4028EFE3688E024B4045F46BEBA7DD4A4046EBA86A82044B408AAE0B3F38DF4A4046EBA86A82044B408AAE0B3F38DF4A4028EFE3688E024B4045F46BEBA7DD4A4028EFE3688E024B40
58850	Больщеезингереево	7	61	144	53.823369	53.832514000000003	54.046908999999999	54.037556000000002	0103000020E6100000010000000500000026C5C72764E94A4061E28FA2CE044B4026C5C72764E94A40AC71361D01064B4028BB99D18FEA4A40AC71361D01064B4028BB99D18FEA4A4061E28FA2CE044B4026C5C72764E94A4061E28FA2CE044B40
12406	Бекетово	7	61	144	53.863154999999999	53.890599000000002	53.922072	53.911555999999997	0103000020E610000001000000050000007F30F0DC7BEE4A407D3CF4DDADF44A407F30F0DC7BEE4A4056478E7406F64A40D76CE525FFF14A4056478E7406F64A40D76CE525FFF14A407D3CF4DDADF44A407F30F0DC7BEE4A407D3CF4DDADF44A40
12382	Атамкуль	7	61	144	53.598700000000001	53.617564999999999	53.876308000000002	53.868960999999999	0103000020E61000000100000005000000BF0E9C33A2CC4A40EE3F321D3AEF4A40BF0E9C33A2CC4A40919C4CDC2AF04A40BE13B35E0CCF4A40919C4CDC2AF04A40BE13B35E0CCF4A40EE3F321D3AEF4A40BF0E9C33A2CC4A40EE3F321D3AEF4A40
12318	Абдулово	7	61	144	53.434254000000003	53.450828000000001	54.249985000000002	54.224122000000001	0103000020E610000001000000050000001F1494A295B74A4035289A07B01C4B401F1494A295B74A40CBBE2B82FF1F4B40800F5EBBB4B94A40CBBE2B82FF1F4B40800F5EBBB4B94A4035289A07B01C4B401F1494A295B74A4035289A07B01C4B40
12268	Абдулкаримово	7	61	144	53.589348999999999	53.621724	54.086306	54.075341000000002	0103000020E610000001000000050000001477BCC96FCB4A4023861DC6A4094B401477BCC96FCB4A406BB933130C0B4B40B491EBA694CF4A406BB933130C0B4B40B491EBA694CF4A4023861DC6A4094B401477BCC96FCB4A4023861DC6A4094B40
12212	Юсупово	7	61	133	54.644159000000002	54.679983999999997	55.717365999999998	55.699756000000001	0103000020E61000000100000005000000483657CD73524B400397C79A91D94B40483657CD73524B4094A12AA6D2DB4B40D1E638B709574B4094A12AA6D2DB4B40D1E638B709574B400397C79A91D94B40483657CD73524B400397C79A91D94B40
12154	Черлак	7	61	133	54.740718999999999	54.767130000000002	55.744155999999997	55.732768	0103000020E610000001000000050000004E4354E1CF5E4B4015C78157CBDD4B404E4354E1CF5E4B40A38FF98040DF4B40E7E3DA5031624B40A38FF98040DF4B40E7E3DA5031624B4015C78157CBDD4B404E4354E1CF5E4B4015C78157CBDD4B40
11959	Учпили	7	61	133	55.007950000000001	55.027155999999998	55.453279000000002	55.442458999999999	0103000020E6100000010000000500000069006F8104814B4012691B7FA2B84B4069006F8104814B40577BD80B05BA4B40F1F109D979834B40577BD80B05BA4B40F1F109D979834B4012691B7FA2B84B4069006F8104814B4012691B7FA2B84B40
10487	Урман-Асты	7	61	133	54.914265	54.942104	55.272661999999997	55.261721000000001	0103000020E610000001000000050000005070B1A206754B4095D6DF1280A14B405070B1A206754B40546EA296E6A24B4024B726DD96784B40546EA296E6A24B4024B726DD96784B4095D6DF1280A14B405070B1A206754B4095D6DF1280A14B40
58866	ТатЯрмино	7	61	133	55.017122000000001	55.037405999999997	55.654477	55.646720999999999	0103000020E610000001000000050000006405BF0D31824B407651F4C0C7D24B406405BF0D31824B40FA7DFFE6C5D34B404B5645B8C9844B40FA7DFFE6C5D34B404B5645B8C9844B407651F4C0C7D24B406405BF0D31824B407651F4C0C7D24B40
11807	Такарликово	7	61	133	54.776364000000001	54.794744000000001	55.468214000000003	55.455474000000002	0103000020E6100000010000000500000058E542E55F634B40D316D7F84CBA4B4058E542E55F634B40C2C3B46FEEBB4B409B58E02BBA654B40C2C3B46FEEBB4B409B58E02BBA654B40D316D7F84CBA4B4058E542E55F634B40D316D7F84CBA4B40
11597	Таймурзино	7	61	133	54.825609999999998	54.851275000000001	55.380831000000001	55.365718999999999	0103000020E6100000010000000500000012A0A696AD694B404E4354E1CFAE4B4012A0A696AD694B40C826F911BFB04B4082734694F66C4B40C826F911BFB04B4082734694F66C4B404E4354E1CFAE4B4012A0A696AD694B404E4354E1CFAE4B40
11627	Султанбеково	7	61	133	54.827775000000003	54.849576999999996	55.415818999999999	55.402577000000001	0103000020E6100000010000000500000024B9FC87F4694B40978FA4A487B34B4024B9FC87F4694B401807978E39B54B4086376BF0BE6C4B401807978E39B54B4086376BF0BE6C4B40978FA4A487B34B4024B9FC87F4694B40978FA4A487B34B40
11511	Суккулово	7	61	133	54.901760000000003	54.928269999999998	55.420994999999998	55.405194000000002	0103000020E61000000100000005000000A56B26DF6C734B408944A165DDB34B40A56B26DF6C734B40C763062AE3B54B40D0ED258DD1764B40C763062AE3B54B40D0ED258DD1764B408944A165DDB34B40A56B26DF6C734B408944A165DDB34B40
11309	Староянтузово	7	61	133	55.068362	55.085340000000002	55.477106999999997	55.461190999999999	0103000020E6100000010000000500000003250516C0884B40D21A834E08BB4B4003250516C0884B40A9D898D711BD4B403485CE6BEC8A4B40A9D898D711BD4B403485CE6BEC8A4B40D21A834E08BB4B4003250516C0884B40D21A834E08BB4B40
11215	Староуртаево	7	61	133	55.120840999999999	55.153333000000003	55.405571999999999	55.393864999999998	0103000020E610000001000000050000000A82C7B7778F4B40FF04172B6AB24B400A82C7B7778F4B402F1686C8E9B34B40E4326E6AA0934B402F1686C8E9B34B40E4326E6AA0934B40FF04172B6AB24B400A82C7B7778F4B40FF04172B6AB24B40
9612	Старобалтачево	7	61	133	54.699603000000003	54.732194	55.536436000000002	55.525633999999997	0103000020E610000001000000050000007D9752978C594B4034D593F947C34B407D9752978C594B40D33252EFA9C44B40E9297288B85D4B40D33252EFA9C44B40E9297288B85D4B4034D593F947C34B407D9752978C594B4034D593F947C34B40
11165	Старобаишево	7	61	133	55.105786000000002	55.124605000000003	55.425716000000001	55.410305000000001	0103000020E61000000100000005000000F52F49658A8D4B405131CEDF84B44B40F52F49658A8D4B4025B1A4DC7DB64B4084F57F0EF38F4B4025B1A4DC7DB64B4084F57F0EF38F4B405131CEDF84B44B40F52F49658A8D4B405131CEDF84B44B40
10300	Сикаликуль	7	61	133	54.509923999999998	54.525438000000001	55.534458999999998	55.524583999999997	0103000020E6100000010000000500000006B98B3045414B409F008A9125C34B4006B98B3045414B40C4060B2769C44B40AF09698D41434B40C4060B2769C44B40AF09698D41434B409F008A9125C34B4006B98B3045414B409F008A9125C34B40
10887	Семилетка	7	61	133	54.603223	54.627189999999999	55.366849999999999	55.353560000000002	0103000020E61000000100000005000000F6984869364D4B403E963E7441AD4B40F6984869364D4B40D044D8F0F4AE4B406A300DC347504B40D044D8F0F4AE4B406A300DC347504B403E963E7441AD4B40F6984869364D4B403E963E7441AD4B40
11429	Сабанаево	7	61	133	55.163215000000001	55.181351999999997	55.475530999999997	55.467249000000002	0103000020E61000000100000005000000BB9BA73AE4944B405B0BB3D0CEBB4B40BB9BA73AE4944B40F99D2633DEBC4B403788D68A36974B40F99D2633DEBC4B403788D68A36974B405B0BB3D0CEBB4B40BB9BA73AE4944B405B0BB3D0CEBB4B40
11931	Новобиктово	7	61	133	54.821792000000002	54.863599999999998	55.568888999999999	55.554634	0103000020E61000000100000005000000A60EF27A30694B40F59F353FFEC64B40A60EF27A30694B40EE06D15AD1C84B40AD69DE718A6E4B40EE06D15AD1C84B40AD69DE718A6E4B40F59F353FFEC64B40A60EF27A30694B40F59F353FFEC64B40
11131	Нижнеманчарово	7	61	133	54.608334999999997	54.636136999999998	55.398988000000003	55.383372000000001	0103000020E610000001000000050000008E01D9EBDD4D4B40DF196D5512B14B408E01D9EBDD4D4B408CBFED0912B34B404563EDEF6C514B408CBFED0912B34B404563EDEF6C514B40DF196D5512B14B408E01D9EBDD4D4B40DF196D5512B14B40
11035	Нижнеаташево	7	61	133	54.717722000000002	54.744537000000001	55.378754000000001	55.362029999999997	0103000020E6100000010000000500000053CF8250DE5B4B40DF15C1FF56AE4B4053CF8250DE5B4B40569DD5027BB04B40BBD408FD4C5F4B40569DD5027BB04B40BBD408FD4C5F4B40DF15C1FF56AE4B4053CF8250DE5B4B40DF15C1FF56AE4B40
10153	Нижнеалькашево	7	61	133	54.643818000000003	54.661245000000001	55.528049000000003	55.515518	0103000020E61000000100000005000000BF49D3A068524B40EA3F6B7EFCC14B40BF49D3A068524B40BFD7101C97C34B405FD218ADA3544B40BFD7101C97C34B405FD218ADA3544B40EA3F6B7EFCC14B40BF49D3A068524B40EA3F6B7EFCC14B40
10696	Москово	7	61	133	55.060349000000002	55.109710999999997	55.330261	55.307997999999998	0103000020E6100000010000000500000054AC1A84B9874B40E09D7C7A6CA74B4054AC1A84B9874B40771211FE45AA4B40778192020B8E4B40771211FE45AA4B40778192020B8E4B40E09D7C7A6CA74B4054AC1A84B9874B40E09D7C7A6CA74B40
10617	Миништы	7	61	133	55.008274	55.038474999999998	55.625501	55.61327	0103000020E610000001000000050000001CB4571F0F814B4018CFA0A17FCE4B401CB4571F0F814B40C24EB16A10D04B40575BB1BFEC844B40C24EB16A10D04B40575BB1BFEC844B4018CFA0A17FCE4B401CB4571F0F814B4018CFA0A17FCE4B40
10527	Маядык	7	61	133	54.948518	54.967830999999997	55.624439000000002	55.610148000000002	0103000020E610000001000000050000006BD5AE0969794B4023DC645419CE4B406BD5AE0969794B4069ACFD9DEDCF4B400987DEE2E17B4B4069ACFD9DEDCF4B400987DEE2E17B4B4023DC645419CE4B406BD5AE0969794B4023DC645419CE4B40
11883	Кушулево	7	61	133	54.760958000000002	54.799505000000003	55.516359000000001	55.502737000000003	0103000020E6100000010000000500000096D05D1267614B409DBE9EAF59C04B4096D05D1267614B4065FF3C0D18C24B4087FE092E56664B4065FF3C0D18C24B4087FE092E56664B409DBE9EAF59C04B4096D05D1267614B409DBE9EAF59C04B40
10392	Куккуяново	7	61	133	54.930399000000001	54.962440999999998	55.323796999999999	55.310509000000003	0103000020E61000000100000005000000959D7E5017774B408D0E48C2BEA74B40959D7E5017774B407EC51A2E72A94B402EAA4544317B4B407EC51A2E72A94B402EAA4544317B4B408D0E48C2BEA74B40959D7E5017774B408D0E48C2BEA74B40
10070	Исмайлово	7	61	133	54.611325999999998	54.646639	55.572471999999998	55.547280000000001	0103000020E61000000100000005000000E5982CEE3F4E4B40A0E062450DC64B40E5982CEE3F4E4B4017F032C346C94B40B9A81611C5524B4017F032C346C94B40B9A81611C5524B40A0E062450DC64B40E5982CEE3F4E4B40A0E062450DC64B40
10858	Имай-Утарово	7	61	133	54.982374999999998	55.003548000000002	55.342559999999999	55.331893999999998	0103000020E6100000010000000500000039B4C876BE7D4B408BDEA9807BAA4B4039B4C876BE7D4B4079758E01D9AB4B40ADFBC74274804B4079758E01D9AB4B40ADFBC74274804B408BDEA9807BAA4B4039B4C876BE7D4B408BDEA9807BAA4B40
10417	Ивачево	7	61	133	54.989390999999998	55.01493	55.296703000000001	55.283378999999996	0103000020E6100000010000000500000076FA415DA47E4B40C4AF58C345A44B4076FA415DA47E4B4003D0285DFAA54B4059DDEA39E9814B4003D0285DFAA54B4059DDEA39E9814B40C4AF58C345A44B4076FA415DA47E4B40C4AF58C345A44B40
11716	Иванаево	7	61	133	54.810743000000002	54.840153999999998	55.499713	55.484678000000002	0103000020E61000000100000005000000003B376DC6674B409C8BBFED09BE4B40003B376DC6674B406A317898F6BF4B4042CD902A8A6B4B406A317898F6BF4B4042CD902A8A6B4B409C8BBFED09BE4B40003B376DC6674B409C8BBFED09BE4B40
12048	Зейлево	7	61	133	55.029617999999999	55.046964000000003	55.460543000000001	55.453676999999999	0103000020E61000000100000005000000BCAFCA85CA834B4044F9821612BA4B40BCAFCA85CA834B406CB3B112F3BA4B40700B96EA02864B406CB3B112F3BA4B40700B96EA02864B4044F9821612BA4B40BCAFCA85CA834B4044F9821612BA4B40
295	Дюртюли	7	61	133	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
11725	Гублюкучуково	7	61	133	54.791725999999997	54.810105	55.491906	55.474831999999999	0103000020E610000001000000050000004AB20E4757654B40118C834BC7BC4B404AB20E4757654B40645A9BC6F6BE4B40BDA94885B1674B40645A9BC6F6BE4B40BDA94885B1674B40118C834BC7BC4B404AB20E4757654B40118C834BC7BC4B40
11439	Байгильды	7	61	133	55.151527999999999	55.162281	55.532848999999999	55.518926999999998	0103000020E61000000100000005000000D236FE4465934B4075012F336CC24B40D236FE4465934B40685A626534C44B408FE1B19FC5944B40685A626534C44B408FE1B19FC5944B4075012F336CC24B40D236FE4465934B4075012F336CC24B40
10018	Асяново	7	61	133	54.696064	54.742165999999997	55.453488	55.435319999999997	0103000020E6100000010000000500000023F609A018594B40B9A5D590B8B74B4023F609A018594B40719010E50BBA4B40001AA54BFF5E4B40719010E50BBA4B40001AA54BFF5E4B40B9A5D590B8B74B4023F609A018594B40B9A5D590B8B74B40
9931	Ангасяк	7	61	133	54.775798999999999	54.830353000000002	55.653731000000001	55.617663	0103000020E610000001000000050000007FA2B2614D634B408179C8940FCF4B407FA2B2614D634B40D1B01875ADD34B405891D101496A4B40D1B01875ADD34B405891D101496A4B408179C8940FCF4B407FA2B2614D634B408179C8940FCF4B40
11347	Аканеево	7	61	133	55.104663000000002	55.128639	55.445503000000002	55.430793999999999	0103000020E61000000100000005000000F60CE198658D4B4011A8FE4124B74B40F60CE198658D4B408CA2073E06B94B40BDFE243E77904B408CA2073E06B94B40BDFE243E77904B4011A8FE4124B74B40F60CE198658D4B4011A8FE4124B74B40
8919	Ярославка	7	61	119	57.925876000000002	58.005088999999998	55.872869999999999	55.828794000000002	0103000020E610000001000000050000005E13D21A83F64C407E8FFAEB15EA4B405E13D21A83F64C406BD44334BAEF4B40E048A0C1A6004D406BD44334BAEF4B40E048A0C1A6004D407E8FFAEB15EA4B405E13D21A83F64C407E8FFAEB15EA4B40
8658	Чертан	7	61	119	57.894182999999998	57.926684000000002	55.738697999999999	55.719611999999998	0103000020E61000000100000005000000D0D1AA9674F24C4092E7FA3E1CDC4B40D0D1AA9674F24C4070CFF3A78DDE4B40FDDCD0949DF64C4070CFF3A78DDE4B40FDDCD0949DF64C4092E7FA3E1CDC4B40D0D1AA9674F24C4092E7FA3E1CDC4B40
8476	Улькунды	7	61	119	57.957954999999998	57.994309000000001	55.670304999999999	55.651313000000002	0103000020E610000001000000050000001405FA449EFA4C40D63A71395ED34B401405FA449EFA4C4032ACE28DCCD54B402A8F6E8445FF4C4032ACE28DCCD54B402A8F6E8445FF4C40D63A71395ED34B401405FA449EFA4C40D63A71395ED34B40
8816	Тастуба	7	61	119	57.851090999999997	57.919075999999997	55.773135000000003	55.751199	0103000020E61000000100000005000000C075C58CF0EC4C40DAE4F04927E04B40C075C58CF0EC4C404D327216F6E24B40ED444948A4F54C404D327216F6E24B40ED444948A4F54C40DAE4F04927E04B40C075C58CF0EC4C40DAE4F04927E04B40
7923	Старохалилово	7	61	119	58.333621000000001	58.355792000000001	55.584567999999997	55.572732000000002	0103000020E610000001000000050000002121CA17B42A4D40B4AF3C484FC94B402121CA17B42A4D40E124CD1FD3CA4B40D7169E978A2D4D40E124CD1FD3CA4B40D7169E978A2D4D40B4AF3C484FC94B402121CA17B42A4D40B4AF3C484FC94B40
8301	Сикияз	7	61	119	58.136836000000002	58.171304999999997	55.499004999999997	55.472428999999998	0103000020E610000001000000050000002E7590D783114D404B57B08D78BC4B402E7590D783114D402EC55565DFBF4B4015527E52ED154D402EC55565DFBF4B4015527E52ED154D404B57B08D78BC4B402E7590D783114D404B57B08D78BC4B40
9078	Сальевка	7	61	119	57.938650000000003	57.980196999999997	55.918706	55.883454	0103000020E61000000100000005000000F931E6AE25F84C409CC24A0515F14B40F931E6AE25F84C40CA51802898F54B409351651877FD4C40CA51802898F54B409351651877FD4C409CC24A0515F14B40F931E6AE25F84C409CC24A0515F14B40
8158	Рухтино	7	61	119	58.355297	58.396836	55.468673000000003	55.447733999999997	0103000020E61000000100000005000000F7AE415F7A2D4D4054A703594FB94B40F7AE415F7A2D4D4055C2137AFDBB4B400FF0A485CB324D4055C2137AFDBB4B400FF0A485CB324D4054A703594FB94B40F7AE415F7A2D4D4054A703594FB94B40
8730	Октябрьский	7	61	119	57.479134999999999	57.516171999999997	55.627453000000003	55.606766	0103000020E610000001000000050000003AAFB14B54BD4C4091291F82AACD4B403AAFB14B54BD4C407863416150D04B40328E91EC11C24C407863416150D04B40328E91EC11C24C4091291F82AACD4B403AAFB14B54BD4C4091291F82AACD4B40
8388	Михайловка	7	61	119	57.906543999999997	57.958331999999999	55.592820000000003	55.565117000000001	0103000020E61000000100000005000000483140A209F44C40F2B4FCC055C84B40483140A209F44C4016359886E1CB4B40EA5A7B9FAAFA4C4016359886E1CB4B40EA5A7B9FAAFA4C40F2B4FCC055C84B40483140A209F44C40F2B4FCC055C84B40
8437	Митрофановка	7	61	119	57.920549000000001	57.942709999999998	55.637656999999997	55.623066000000001	0103000020E61000000100000005000000C9AEB48CD4F54C40F19F6EA0C0CF4B40C9AEB48CD4F54C4061889CBE9ED14B405BCEA5B8AAF84C4061889CBE9ED14B405BCEA5B8AAF84C40F19F6EA0C0CF4B40C9AEB48CD4F54C40F19F6EA0C0CF4B40
9120	Метели	7	61	119	57.933070999999998	57.976460000000003	56.025643000000002	56.001353000000002	0103000020E610000001000000050000004AECDADE6EF74C403160C9552C004C404AECDADE6EF74C40882F134548034C4014ED2AA4FCFC4C40882F134548034C4014ED2AA4FCFC4C403160C9552C004C404AECDADE6EF74C403160C9552C004C40
7454	Месягутово	7	61	119	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
8804	Лемазы	7	61	119	58.052430000000001	58.096384999999998	55.752986999999997	55.735753000000003	0103000020E6100000010000000500000026AAB706B6064D408A7780272DDE4B4026AAB706B6064D4015A8C5E061E04B409869FB57560C4D4015A8C5E061E04B409869FB57560C4D408A7780272DDE4B4026AAB706B6064D408A7780272DDE4B40
8081	Каракулево	7	61	119	58.168501999999997	58.182110999999999	55.571668000000003	55.564301999999998	0103000020E61000000100000005000000C1A7397991154D40A088450C3BC84B40C1A7397991154D40BA15C26A2CC94B40F59ECA694F174D40BA15C26A2CC94B40F59ECA694F174D40A088450C3BC84B40C1A7397991154D40A088450C3BC84B40
8738	Калмаш	7	61	119	57.461661999999997	57.481667999999999	55.630831999999998	55.619695999999998	0103000020E6100000010000000500000029E78BBD17BB4C4023BBD23252CF4B4029E78BBD17BB4C4098A25C1ABFD04B40CEC3094CA7BD4C4098A25C1ABFD04B40CEC3094CA7BD4C4023BBD23252CF4B4029E78BBD17BB4C4023BBD23252CF4B40
216	Кадырово	7	61	119	58.272086999999999	58.296106999999999	55.389018	55.378830999999998	0103000020E6100000010000000500000058552FBFD3224D4001DBC1887DB04B4058552FBFD3224D4015C78157CBB14B40EF8E8CD5E6254D4015C78157CBB14B40EF8E8CD5E6254D4001DBC1887DB04B4058552FBFD3224D4001DBC1887DB04B40
9162	Заимка	7	61	119	57.559435000000001	57.589950999999999	56.096724000000002	56.082988999999998	0103000020E610000001000000050000006F9EEA909BC74C40C07630629F0A4C406F9EEA909BC74C40815EB873610C4C400A9FAD8383CB4C40815EB873610C4C400A9FAD8383CB4C40C07630629F0A4C406F9EEA909BC74C40C07630629F0A4C40
8530	Дуван	7	61	119	57.853713999999997	57.924393999999999	55.715971000000003	55.663791000000003	0103000020E610000001000000050000009411178046ED4C4088307E1AF7D44B409411178046ED4C4035F10EF0A4DB4B402F4FE78A52F64C4035F10EF0A4DB4B402F4FE78A52F64C4088307E1AF7D44B409411178046ED4C4088307E1AF7D44B40
8903	Вознесенка	7	61	119	57.894703999999997	57.981876999999997	55.819569999999999	55.779463999999997	0103000020E61000000100000005000000D9CC21A985F24C406534F279C5E34B40D9CC21A985F24C40306475ABE7E84B40E8D84125AEFD4C40306475ABE7E84B40E8D84125AEFD4C406534F279C5E34B40D9CC21A985F24C406534F279C5E34B40
8005	Ариево	7	61	119	58.199852999999997	58.218241999999996	55.618090000000002	55.608561999999999	0103000020E61000000100000005000000F58079C894194D404FCB0F5CE5CD4B40F58079C894194D4009FEB7921DCF4B408B4E965AEF1B4D4009FEB7921DCF4B408B4E965AEF1B4D404FCB0F5CE5CD4B40F58079C894194D404FCB0F5CE5CD4B40
58778	ЧуюнчиНиколаевка	7	61	732	55.417006999999998	55.436644000000001	54.103245999999999	54.086754999999997	0103000020E61000000100000005000000FE99417C60B54B40DAE1AFC91A0B4B40FE99417C60B54B40AEB8382A370D4B4050FF59F3E3B74B40AEB8382A370D4B4050FF59F3E3B74B40DAE1AFC91A0B4B40FE99417C60B54B40DAE1AFC91A0B4B40
7260	Чуюнчи	7	61	732	55.354709	55.388053999999997	54.109305999999997	54.093688999999998	0103000020E61000000100000005000000664CC11A67AD4B405A7F4B00FE0B4B40664CC11A67AD4B40D7A02FBDFD0D4B407E8AE3C0ABB14B40D7A02FBDFD0D4B407E8AE3C0ABB14B405A7F4B00FE0B4B40664CC11A67AD4B405A7F4B00FE0B4B40
6374	Хусаиново	7	61	732	55.552491000000003	55.571480999999999	54.124879999999997	54.104576000000002	0103000020E61000000100000005000000CC2A6C06B8C64B4027F911BF620D4B40CC2A6C06B8C64B4055F65D11FC0F4B4087A4164A26C94B4055F65D11FC0F4B4087A4164A26C94B4027F911BF620D4B40CC2A6C06B8C64B4027F911BF620D4B40
6269	Ташлы-Шарипово	7	61	732	55.302183999999997	55.324596999999997	54.232669000000001	54.220078999999998	0103000020E61000000100000005000000EEAF1EF7ADA64B40A8C4758C2B1C4B40EEAF1EF7ADA64B4082E50819C81D4B409AB0FD648CA94B4082E50819C81D4B409AB0FD648CA94B40A8C4758C2B1C4B40EEAF1EF7ADA64B40A8C4758C2B1C4B40
7187	Соколовка	7	61	732	55.102874999999997	55.132249999999999	54.205047	54.195650999999998	0103000020E61000000100000005000000BA490C022B8D4B4000378B170B194B40BA490C022B8D4B404B92E7FA3E1A4B40B0726891ED904B404B92E7FA3E1A4B40B0726891ED904B4000378B170B194B40BA490C022B8D4B4000378B170B194B40
7087	Сергиополь	7	61	732	54.914569999999998	54.961677999999999	54.219321000000001	54.206831999999999	0103000020E610000001000000050000008CF337A110754B4015E29178791A4B408CF337A110754B40BB29E5B5121C4B402FA4C343187B4B40BB29E5B5121C4B402FA4C343187B4B4015E29178791A4B408CF337A110754B4015E29178791A4B40
5954	Романовка	7	61	732	54.798149000000002	54.827308000000002	54.320205000000001	54.311796999999999	0103000020E61000000100000005000000E52A16BF29664B40D6FECEF6E8274B40E52A16BF29664B400282397AFC284B400EDC813AE5694B400282397AFC284B400EDC813AE5694B40D6FECEF6E8274B40E52A16BF29664B40D6FECEF6E8274B40
6981	Рассвет	7	61	732	54.947142999999997	54.972368000000003	54.293745000000001	54.285305000000001	0103000020E6100000010000000500000052D158FB3B794B405131CEDF84244B4052D158FB3B794B40882EA86F99254B40A6D6FB8D767C4B40882EA86F99254B40A6D6FB8D767C4B405131CEDF84244B4052D158FB3B794B405131CEDF84244B40
6886	Раево	7	61	732	55.164121999999999	55.182510999999998	54.129854999999999	54.118963999999998	0103000020E61000000100000005000000ED461FF301954B405FB35C363A0F4B40ED461FF301954B406D1CB1169F104B4083143C855C974B406D1CB1169F104B4083143C855C974B405FB35C363A0F4B40ED461FF301954B405FB35C363A0F4B40
6865	Поляковка	7	61	732	55.027515000000001	55.057313000000001	54.335794	54.310436000000003	0103000020E6100000010000000500000021938C9C85834B4023C0E95DBC274B4021938C9C85834B40B5183C4CFB2A4B405D514A0856874B40B5183C4CFB2A4B405D514A0856874B4023C0E95DBC274B4021938C9C85834B4023C0E95DBC274B40
6467	Новояппарово	7	61	732	55.182510999999998	55.212325999999997	54.327047	54.318593	0103000020E6100000010000000500000083143C855C974B4005DEC9A7C7284B4083143C855C974B40A1A014ADDC294B40950B957F2D9B4B40A1A014ADDC294B40950B957F2D9B4B4005DEC9A7C7284B4083143C855C974B4005DEC9A7C7284B40
6302	Новоянбеково	7	61	732	55.556291000000002	55.565489999999997	54.198188999999999	54.18974	0103000020E610000001000000050000009207228B34C74B401C5F7B6649184B409207228B34C74B40A6B6D4415E194B40861BF0F961C84B40A6B6D4415E194B40861BF0F961C84B401C5F7B6649184B409207228B34C74B401C5F7B6649184B40
6727	Новоаккулаево	7	61	732	55.000413000000002	55.017814000000001	54.139482000000001	54.130809999999997	0103000020E6100000010000000500000023BF7E880D804B40B0FECF61BE104B4023BF7E880D804B40BA30D28BDA114B409AB4A9BA47824B40BA30D28BDA114B409AB4A9BA47824B40B0FECF61BE104B4023BF7E880D804B40B0FECF61BE104B40
7049	Ленинский	7	61	732	54.709386000000002	54.726776999999998	54.361393	54.348978000000002	0103000020E61000000100000005000000C11E1329CD5A4B400283A44FAB2C4B40C11E1329CD5A4B406D003620422E4B40143E5B07075D4B406D003620422E4B40143E5B07075D4B400283A44FAB2C4B40C11E1329CD5A4B400283A44FAB2C4B40
5765	Курятмасово	7	61	732	54.552145000000003	54.577737999999997	54.256287	54.240299999999998	0103000020E6100000010000000500000031D3F6AFAC464B40499D8026C21E4B4031D3F6AFAC464B40EAB12D03CE204B4006D49B51F3494B40EAB12D03CE204B4006D49B51F3494B40499D8026C21E4B4031D3F6AFAC464B40499D8026C21E4B40
33123	Комсомольский	7	61	732	54.928646999999998	54.946586000000003	54.243834999999997	54.233606000000002	0103000020E61000000100000005000000A643A7E7DD764B401F1329CDE61D4B40A643A7E7DD764B40614F3BFC351F4B40FD6CE4BA29794B40614F3BFC351F4B40FD6CE4BA29794B401F1329CDE61D4B40A643A7E7DD764B401F1329CDE61D4B40
6577	Кидрячево	7	61	732	54.445740000000001	54.464469000000001	54.327919000000001	54.312511000000001	0103000020E61000000100000005000000704221020E394B40F451465C00284B40704221020E394B40575EF23FF9294B40BF805EB8733B4B40575EF23FF9294B40BF805EB8733B4B40F451465C00284B40704221020E394B40F451465C00284B40
6423	Казангулово	7	61	732	55.211067999999997	55.225208000000002	54.2883	54.272824999999997	0103000020E61000000100000005000000B69DB646049B4B40FE43FAEDEB224B40B69DB646049B4B40E9B7AF03E7244B401766A19DD39C4B40E9B7AF03E7244B401766A19DD39C4B40FE43FAEDEB224B40B69DB646049B4B40FE43FAEDEB224B40
58857	Имай-Кармалы	7	61	732	55.383732999999999	55.417771000000002	54.230274999999999	54.219836999999998	0103000020E61000000100000005000000AFB2B6291EB14B40B2B96A9E231C4B40AFB2B6291EB14B400F0BB5A6791D4B40CE1B278579B54B400F0BB5A6791D4B40CE1B278579B54B40B2B96A9E231C4B40AFB2B6291EB14B40B2B96A9E231C4B40
6088	Ивановка	7	61	732	54.606645999999998	54.651246999999998	54.404246999999998	54.376064	0103000020E61000000100000005000000E61F7D93A64D4B40FA997ADD22304B40E61F7D93A64D4B40C8409E5DBE334B401E4FCB0F5C534B40C8409E5DBE334B401E4FCB0F5C534B40FA997ADD22304B40E61F7D93A64D4B40FA997ADD22304B40
7342	Ивангород	7	61	732	54.825907000000001	54.874020000000002	54.422701000000004	54.407397000000003	0103000020E61000000100000005000000CC441152B7694B4088BEBB9525344B40CC441152B7694B40467EFD101B364B4064062AE3DF6F4B40467EFD101B364B4064062AE3DF6F4B4088BEBB9525344B40CC441152B7694B4088BEBB9525344B40
6693	Дюртюли	7	61	732	55.062505000000002	55.073653	54.150815999999999	54.135553000000002	0103000020E61000000100000005000000126BF12900884B40F6EFFACC59114B40126BF12900884B4055DB4DF04D134B404B2025766D894B4055DB4DF04D134B404B2025766D894B40F6EFFACC59114B40126BF12900884B40F6EFFACC59114B40
5107	Давлеканово	7	61	732	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
58685	Вязовка	7	61	732	55.270384	55.282062000000003	54.149180999999999	54.139414000000002	0103000020E610000001000000050000004BAE62F19BA24B40624D6551D8114B404BAE62F19BA24B40A017EE5C18134B40E1B88C9B1AA44B40A017EE5C18134B40E1B88C9B1AA44B40624D6551D8114B404BAE62F19BA24B40624D6551D8114B40
6799	Вперед	7	61	732	55.113016999999999	55.131199000000002	54.304983	54.289608999999999	0103000020E610000001000000050000002E724F57778E4B404AD05FE811254B402E724F57778E4B40016BD5AE09274B404B22FB20CB904B40016BD5AE09274B404B22FB20CB904B404AD05FE811254B402E724F57778E4B404AD05FE811254B40
6636	Бурангулово	7	61	732	54.499504000000002	54.517927999999998	54.301206000000001	54.287754	0103000020E61000000100000005000000501C40BFEF3F4B4087A5811FD5244B40501C40BFEF3F4B40F3AD0FEB8D264B4062D7F6764B424B40F3AD0FEB8D264B4062D7F6764B424B4087A5811FD5244B40501C40BFEF3F4B4087A5811FD5244B40
5843	Алга	7	61	732	54.625061000000002	54.644716000000003	54.285325999999998	54.276164000000001	0103000020E61000000100000005000000A680B4FF01504B40912A8A5759234B40A680B4FF01504B406859F78F85244B409E9ACB0D86524B406859F78F85244B409E9ACB0D86524B40912A8A5759234B40A680B4FF01504B40912A8A5759234B40
69	Янгискаин	7	61	57	56.277548000000003	56.323442999999997	53.792209999999997	53.762588000000001	0103000020E61000000100000005000000FD885FB186234C403929CC7B9CE14A40FD885FB186234C4036C8242367E54A40608F899466294C4036C8242367E54A40608F899466294C403929CC7B9CE14A40FD885FB186234C403929CC7B9CE14A40
58723	Якты-Куль	7	61	57	56.528644999999997	56.544626000000001	54.307426	54.294859000000002	0103000020E61000000100000005000000D218ADA3AA434C4034F790F0BD254B40D218ADA3AA434C4055F833BC59274B409146054EB6454C4055F833BC59274B409146054EB6454C4034F790F0BD254B40D218ADA3AA434C4034F790F0BD254B40
3911	Явгильды	7	61	57	56.508954000000003	56.527009999999997	54.151676000000002	54.140543000000001	0103000020E610000001000000050000008E95986725414C4043572250FD114B408E95986725414C4047CB811E6A134B401D554D1075434C4047CB811E6A134B401D554D1075434C4043572250FD114B408E95986725414C4043572250FD114B40
4371	Юлуково	7	61	57	56.633963999999999	56.666266999999998	54.236499999999999	54.220174	0103000020E61000000100000005000000B16B7BBB25514C40FAB660A92E1C4B40B16B7BBB25514C4083C0CAA1451E4B40B7B3AF3C48554C4083C0CAA1451E4B40B7B3AF3C48554C40FAB660A92E1C4B40B16B7BBB25514C40FAB660A92E1C4B40
4253	Юзимяново	7	61	57	56.586388999999997	56.605397000000004	54.159874000000002	54.142356999999997	0103000020E61000000100000005000000F8DD74CB0E4B4C40A7AD11C138124B40F8DD74CB0E4B4C4088BD50C076144B405B0C1EA67D4D4C4088BD50C076144B405B0C1EA67D4D4C40A7AD11C138124B40F8DD74CB0E4B4C40A7AD11C138124B40
4822	Утяково	7	61	57	56.418422	56.442982000000001	53.738720000000001	53.715898000000003	0103000020E61000000100000005000000A5F622DA8E354C40CBA2B08BA2DB4A40A5F622DA8E354C40587380608EDE4A40BC5B59A2B3384C40587380608EDE4A40BC5B59A2B3384C40CBA2B08BA2DB4A40A5F622DA8E354C40CBA2B08BA2DB4A40
4011	Узбяково	7	61	57	56.45749	56.477404999999997	54.194406999999998	54.181472999999997	0103000020E610000001000000050000009F1F46088F3A4C40B20DDC813A174B409F1F46088F3A4C40868E1D54E2184B4033F9669B1B3D4C40868E1D54E2184B4033F9669B1B3D4C40B20DDC813A174B409F1F46088F3A4C40B20DDC813A174B40
4892	Тугаево	7	61	57	56.332363000000001	56.354480000000002	53.751179999999998	53.737696999999997	0103000020E6100000010000000500000042B3EBDE8A2A4C40BCADF4DA6CDE4A4042B3EBDE8A2A4C4063B48EAA26E04A40058BC3995F2D4C4063B48EAA26E04A40058BC3995F2D4C40BCADF4DA6CDE4A4042B3EBDE8A2A4C40BCADF4DA6CDE4A40
4669	Толпарово	7	61	57	57.091808	57.117069000000001	54.032437999999999	54.018706999999999	0103000020E610000001000000050000006EC1525DC08B4C40679AB0FD64024B406EC1525DC08B4C40E692AAED26044B400E30F31DFC8E4C40E692AAED26044B400E30F31DFC8E4C40679AB0FD64024B406EC1525DC08B4C40679AB0FD64024B40
4727	Ташла	7	61	57	56.628734999999999	56.653070999999997	53.906458999999998	53.890638000000003	0103000020E61000000100000005000000DF6C73637A504C4095490D6D00F24A40DF6C73637A504C401A1538D906F44A40A67B9DD497534C401A1538D906F44A40A67B9DD497534C4095490D6D00F24A40DF6C73637A504C4095490D6D00F24A40
3614	Татарский Саскуль	7	61	57	56.263066999999999	56.286810000000003	53.946026000000003	53.936677000000003	0103000020E6100000010000000500000013D4F02DAC214C402CF52C08E5F74A4013D4F02DAC214C403695456117F94A403815A930B6244C403695456117F94A403815A930B6244C402CF52C08E5F74A4013D4F02DAC214C402CF52C08E5F74A40
2240	Табынское	7	61	57	56.369472999999999	56.396278000000002	53.999758999999997	53.963155999999998	0103000020E61000000100000005000000A4E029E44A2F4C401C7920B248FB4A40A4E029E44A2F4C40DA70581AF8FF4A40E90FCD3CB9324C40DA70581AF8FF4A40E90FCD3CB9324C401C7920B248FB4A40A4E029E44A2F4C401C7920B248FB4A40
4124	Саитбаба	7	61	57	56.683739000000003	56.718288999999999	54.098125000000003	54.074764999999999	0103000020E61000000100000005000000F8FF71C284574C4056F146E691094B40F8FF71C284574C40C3F5285C8F0C4B40CC09DAE4F05B4C40C3F5285C8F0C4B40CC09DAE4F05B4C4056F146E691094B40F8FF71C284574C4056F146E691094B40
3663	Русский Саскуль	7	61	57	56.216714000000003	56.241129999999998	53.911428000000001	53.897758000000003	0103000020E61000000100000005000000ED4ACB48BD1B4C4077DCF0BBE9F24A40ED4ACB48BD1B4C40505436ACA9F44A40D00A0C59DD1E4C40505436ACA9F44A40D00A0C59DD1E4C4077DCF0BBE9F24A40ED4ACB48BD1B4C4077DCF0BBE9F24A40
33014	Родина	7	61	57	56.388292	56.403410999999998	53.950541000000001	53.937711	0103000020E6100000010000000500000033A6608DB3314C40BB0CFFE906F84A4033A6608DB3314C40EA40D653ABF94A405FECBDF8A2334C40EA40D653ABF94A405FECBDF8A2334C40BB0CFFE906F84A4033A6608DB3314C40BB0CFFE906F84A40
5006	Мраково	7	61	57	56.175634000000002	56.205404000000001	53.793066000000003	53.778334999999998	0103000020E610000001000000050000006808C72C7B164C40842A357BA0E34A406808C72C7B164C40E7C8CA2F83E54A40DA3BA3AD4A1A4C40E7C8CA2F83E54A40DA3BA3AD4A1A4C40842A357BA0E34A406808C72C7B164C40842A357BA0E34A40
4785	Мендим	7	61	57	56.774945000000002	56.793298	53.932951000000003	53.910133999999999	0103000020E610000001000000050000007099D36531634C40247D5A457FF44A407099D36531634C40A0E238F06AF74A40B9FDF2C98A654C40A0E238F06AF74A40B9FDF2C98A654C40247D5A457FF44A407099D36531634C40247D5A457FF44A40
3393	Кутлугуза	7	61	57	56.277000000000001	56.298873999999998	53.848121999999996	53.829048	0103000020E61000000100000005000000FA7E6ABC74234C403868AF3E1EEA4A40FA7E6ABC74234C405182FE428FEC4A40F6CFD38041264C405182FE428FEC4A40F6CFD38041264C403868AF3E1EEA4A40FA7E6ABC74234C403868AF3E1EEA4A40
58138	Курорт	7	61	57	56.517595999999998	56.532831000000002	53.932102999999998	53.917729000000001	0103000020E610000001000000050000002C45F29540424C409FCBD42478F54A402C45F29540424C4072C0AE264FF74A40C2A563CE33444C4072C0AE264FF74A40C2A563CE33444C409FCBD42478F54A402C45F29540424C409FCBD42478F54A40
3816	Курмантау	7	61	57	56.381061000000003	56.405486000000003	54.139212999999998	54.129137999999998	0103000020E61000000100000005000000FA635A9BC6304C40DE550F9887104B40FA635A9BC6304C40CA1649BBD1114B40317E1AF7E6334C40CA1649BBD1114B40317E1AF7E6334C40DE550F9887104B40FA635A9BC6304C40DE550F9887104B40
4565	Кургашла	7	61	57	56.605378999999999	56.635769000000003	53.818626000000002	53.810003000000002	0103000020E61000000100000005000000B4571F0F7D4D4C40B954A52DAEE74A40B4571F0F7D4D4C40E1D39CBCC8E84A40C367EBE060514C40E1D39CBCC8E84A40C367EBE060514C40B954A52DAEE74A40B4571F0F7D4D4C40B954A52DAEE74A40
2641	Красноусольский	7	61	57	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
4350	Коварды	7	61	57	56.746406	56.781340999999998	54.217509999999997	54.204335999999998	0103000020E61000000100000005000000E3C4573B8A5F4C409EB29AAE271A4B40E3C4573B8A5F4C40C746205ED71B4B4010035DFB02644C40C746205ED71B4B4010035DFB02644C409EB29AAE271A4B40E3C4573B8A5F4C409EB29AAE271A4B40
4484	Карагаево	7	61	57	56.690125999999999	56.710303000000003	54.146075000000003	54.135441999999998	0103000020E61000000100000005000000450F7C0C56584C409E40D82956114B40450F7C0C56584C40B1E1E995B2124B4017A06D35EB5A4C40B1E1E995B2124B4017A06D35EB5A4C409E40D82956114B40450F7C0C56584C409E40D82956114B40
3334	Инзелга	7	61	57	56.293528999999999	56.314190000000004	53.884614999999997	53.869895	0103000020E61000000100000005000000BBB6B75B92254C401AFA27B858EF4A40BBB6B75B92254C40884677103BF14A40795DBF6037284C40884677103BF14A40795DBF6037284C401AFA27B858EF4A40BBB6B75B92254C401AFA27B858EF4A40
4469	Имендяшево	7	61	57	56.748210999999998	56.772457000000003	54.146887	54.128171999999999	0103000020E61000000100000005000000F4C0C760C55F4C40A721AAF067104B40F4C0C760C55F4C40919A7631CD124B407C48F8DEDF624C40919A7631CD124B407C48F8DEDF624C40A721AAF067104B40F4C0C760C55F4C40A721AAF067104B40
4071	Ибрагимово	7	61	57	56.588428	56.607903999999998	54.250616000000001	54.233179999999997	0103000020E610000001000000050000007D06D49B514B4C40670A9DD7D81D4B407D06D49B514B4C405BED612F14204B40C58D5BCCCF4D4C405BED612F14204B40C58D5BCCCF4D4C40670A9DD7D81D4B407D06D49B514B4C40670A9DD7D81D4B40
3959	Зилим-Караново	7	61	57	56.536262999999998	56.561343999999998	54.240763000000001	54.226748000000001	0103000020E6100000010000000500000005871744A4444C407A371614061D4B4005871744A4444C401E8B6D52D11E4B4025E7C41EDA474C401E8B6D52D11E4B4025E7C41EDA474C407A371614061D4B4005871744A4444C407A371614061D4B40
5018	Буруновка	7	61	57	56.219408999999999	56.232227999999999	53.729222999999998	53.711944000000003	0103000020E610000001000000050000005AB91798151C4C40AE4A22FB20DB4A405AB91798151C4C40D93EE42D57DD4A40959BA8A5B91D4C40D93EE42D57DD4A40959BA8A5B91D4C40AE4A22FB20DB4A405AB91798151C4C40AE4A22FB20DB4A40
3712	Бурлы	7	61	57	56.458531999999998	56.484780000000001	54.140216000000002	54.121102	0103000020E61000000100000005000000B115342DB13A4C4077BD3445800F4B40B115342DB13A4C401F300F99F2114B40A0E062450D3E4C401F300F99F2114B40A0E062450D3E4C4077BD3445800F4B40B115342DB13A4C4077BD3445800F4B40
3285	Березовка	7	61	57	56.477108999999999	56.493215999999997	54.083728999999998	54.072768000000003	0103000020E610000001000000050000004AD05FE8113D4C4001193A7650094B404AD05FE8113D4C40075DC2A1B70A4B4095EEAEB3213F4C40075DC2A1B70A4B4095EEAEB3213F4C4001193A7650094B404AD05FE8113D4C4001193A7650094B40
58194	Белое Озеро	7	61	57	56.219203	56.243600999999998	54.008692000000003	53.98292	0103000020E61000000100000005000000B1170AD80E1C4C40CB4A9352D0FD4A40B1170AD80E1C4C4051DEC7D11C014B40EE224C512E1F4C4051DEC7D11C014B40EE224C512E1F4C40CB4A9352D0FD4A40B1170AD80E1C4C40CB4A9352D0FD4A40
3754	Баимбетово	7	61	57	56.441670000000002	56.455370000000002	54.177715999999997	54.161161	0103000020E61000000100000005000000EACF7EA488384C40013274ECA0144B40EACF7EA488384C40EBFCDB65BF164B402ECA6C90493A4C40EBFCDB65BF164B402ECA6C90493A4C40013274ECA0144B40EACF7EA488384C40013274ECA0144B40
3232	Архангельское	7	61	57	56.394392000000003	56.417892000000002	54.078257000000001	54.061947000000004	0103000020E61000000100000005000000EBE6E26F7B324C40EC8A19E1ED074B40EBE6E26F7B324C406FD74B53040A4B4049A12C7C7D354C406FD74B53040A4B4049A12C7C7D354C40EC8A19E1ED074B40EBE6E26F7B324C40EC8A19E1ED074B40
3562	Антоновка	7	61	57	56.266345999999999	56.292622000000001	54.006427000000002	53.981045999999999	0103000020E61000000100000005000000D0B52FA017224C4091EF52EA92FD4A40D0B52FA017224C40DC679599D2004B40890B40A374254C40DC679599D2004B40890B40A374254C4091EF52EA92FD4A40D0B52FA017224C4091EF52EA92FD4A40
1090	Яумбаево	7	61	158	57.621760000000002	57.64367	53.331730999999998	53.322738000000001	0103000020E6100000010000000500000001FBE8D495CF4C409696917A4FA94A4001FBE8D495CF4C40E108522976AA4A404AB54FC763D24C40E108522976AA4A404AB54FC763D24C409696917A4FA94A4001FBE8D495CF4C409696917A4FA94A40
9346	Тимирово	7	61	158	57.526843999999997	57.549275000000002	53.184936	53.175955999999999	0103000020E61000000100000005000000020CCB9F6FC34C407AC4E8B985964A40020CCB9F6FC34C4031ED9BFBAB974A4055C1A8A44EC64C4031ED9BFBAB974A4055C1A8A44EC64C407AC4E8B985964A40020CCB9F6FC34C407AC4E8B985964A40
2007	Старосубхангулово	7	61	158	57.409703999999998	57.448259999999998	53.125284999999998	53.083776	0103000020E610000001000000050000002B85402E71B44C404818062CB98A4A402B85402E71B44C40F5D6C05609904A406F0D6C9560B94C40F5D6C05609904A406F0D6C9560B94C404818062CB98A4A402B85402E71B44C404818062CB98A4A40
2479	Старомусятово	7	61	158	57.414096999999998	57.422773999999997	53.163378999999999	53.155804000000003	0103000020E61000000100000005000000942F682101B54C40024BAE62F1934A40942F682101B54C4035ED629AE9944A40AFCC5B751DB64C4035ED629AE9944A40AFCC5B751DB64C40024BAE62F1934A40942F682101B54C40024BAE62F1934A40
2077	Старомунасипово	7	61	158	57.567591999999998	57.585557999999999	53.233080000000001	53.222836999999998	0103000020E6100000010000000500000051BCCADAA6C84C405CAB3DEC859C4A4051BCCADAA6C84C4004ADC090D59D4A40A1F48590F3CA4C4004ADC090D59D4A40A1F48590F3CA4C405CAB3DEC859C4A4051BCCADAA6C84C405CAB3DEC859C4A40
1827	Саргая	7	61	158	57.778506999999998	57.792960999999998	53.349456000000004	53.340671999999998	0103000020E61000000100000005000000815A0C1EA6E34C40DA54DD239BAB4A40815A0C1EA6E34C400CB265F9BAAC4A407100FDBE7FE54C400CB265F9BAAC4A407100FDBE7FE54C40DA54DD239BAB4A40815A0C1EA6E34C40DA54DD239BAB4A40
784	Новоусманово	7	61	158	57.646374000000002	57.661285999999997	53.070380999999998	53.063195999999998	0103000020E610000001000000050000000B7E1B62BCD24C40779E78CE16884A400B7E1B62BCD24C4040A19E3E02894A40BDA60705A5D44C4040A19E3E02894A40BDA60705A5D44C40779E78CE16884A400B7E1B62BCD24C40779E78CE16884A40
2432	Новосубхангулово	7	61	158	57.433562999999999	57.452103999999999	53.149366999999998	53.140022999999999	0103000020E61000000100000005000000B9E00CFE7EB74C400AD80E46EC914A40B9E00CFE7EB74C40020D36751E934A4005323B8BDEB94C40020D36751E934A4005323B8BDEB94C400AD80E46EC914A40B9E00CFE7EB74C400AD80E46EC914A40
2363	Новомусятово	7	61	158	57.368256000000002	57.377544	53.206499000000001	53.197518000000002	0103000020E6100000010000000500000024473A0323AF4C40882F134548994A4024473A0323AF4C400FD4298F6E9A4A4088669E5C53B04C400FD4298F6E9A4A4088669E5C53B04C40882F134548994A4024473A0323AF4C40882F134548994A40
1957	Новомунасипово	7	61	158	57.539752999999997	57.547235999999998	53.240819000000002	53.231479	0103000020E610000001000000050000007D7555A016C54C40FB5A971AA19D4A407D7555A016C54C40B2A03028D39E4A40D09849D40BC64C40B2A03028D39E4A40D09849D40BC64C40FB5A971AA19D4A407D7555A016C54C40FB5A971AA19D4A40
716	Набиево	7	61	158	57.535584999999998	57.546067999999998	53.270651999999998	53.253577999999997	0103000020E61000000100000005000000349D9D0C8EC44C40177E703E75A04A40349D9D0C8EC44C406A4C88B9A4A24A4031B2648EE5C54C406A4C88B9A4A24A4031B2648EE5C54C40177E703E75A04A40349D9D0C8EC44C40177E703E75A04A40
1049	Мурадымово	7	61	158	57.517654	57.529952000000002	53.345215000000003	53.338386999999997	0103000020E6100000010000000500000061527C7C42C24C401E32E54350AB4A4061527C7C42C24C40598B4F0130AC4A4093399677D5C34C40598B4F0130AC4A4093399677D5C34C401E32E54350AB4A4061527C7C42C24C401E32E54350AB4A40
1561	Миндигулово	7	61	158	57.334676999999999	57.342429000000003	53.056041	53.051364999999997	0103000020E6100000010000000500000098DC28B2D6AA4C405B94D92093864A4098DC28B2D6AA4C40191EFB592C874A40DB19A6B6D4AB4C40191EFB592C874A40DB19A6B6D4AB4C405B94D92093864A4098DC28B2D6AA4C405B94D92093864A40
1712	Малый Кипчак	7	61	158	57.783538	57.790131000000002	53.286718999999998	53.283661000000002	0103000020E610000001000000050000002D9622F94AE44C404913EF004FA44A402D9622F94AE44C4027124C35B3A44A4024473A0323E54C4027124C35B3A44A4024473A0323E54C404913EF004FA44A402D9622F94AE44C404913EF004FA44A40
1377	Максютово	7	61	158	56.946973	56.959459000000003	53.007069999999999	53.002122	0103000020E61000000100000005000000F698486936794C40124DA08845804A40F698486936794C40306475ABE7804A402B6D718DCF7A4C40306475ABE7804A402B6D718DCF7A4C40124DA08845804A40F698486936794C40124DA08845804A40
942	Магадеево	7	61	158	57.610208	57.628866000000002	53.393273999999998	53.379268000000003	0103000020E61000000100000005000000F8E0B54B1BCE4C40AD3594DA8BB04A40F8E0B54B1BCE4C40FD2E6CCD56B24A407EC85BAE7ED04C40FD2E6CCD56B24A407EC85BAE7ED04C40AD3594DA8BB04A40F8E0B54B1BCE4C40AD3594DA8BB04A40
1324	Кутаново	7	61	158	57.023051000000002	57.042715000000001	52.986674999999998	52.981465	0103000020E61000000100000005000000EF91CD55F3824C40969526A5A07D4A40EF91CD55F3824C40F163CC5D4B7E4A403A0664AF77854C40F163CC5D4B7E4A403A0664AF77854C40969526A5A07D4A40EF91CD55F3824C40969526A5A07D4A40
925	Кургашлы	7	61	158	57.539797999999998	57.552985	53.279995	53.275137999999998	0103000020E610000001000000050000001D39D21918C54C4084F1D3B837A34A401D39D21918C54C4092054CE0D6A34A40DB166536C8C64C4092054CE0D6A34A40DB166536C8C64C4084F1D3B837A34A401D39D21918C54C4084F1D3B837A34A40
1775	Кулганино	7	61	158	57.941740000000003	57.960918999999997	53.366455000000002	53.359045000000002	0103000020E61000000100000005000000E3AAB2EF8AF84C406B65C22FF5AD4A40E3AAB2EF8AF84C40543A58FFE7AE4A40718DCF64FFFA4C40543A58FFE7AE4A40718DCF64FFFA4C406B65C22FF5AD4A40E3AAB2EF8AF84C406B65C22FF5AD4A40
1657	Кильдигулово	7	61	158	57.850318999999999	57.869821000000002	53.282153999999998	53.276935999999999	0103000020E610000001000000050000006E15C440D7EC4C40E38A8BA372A34A406E15C440D7EC4C40C1374D9F1DA44A40E02F664B56EF4C40C1374D9F1DA44A40E02F664B56EF4C40E38A8BA372A34A406E15C440D7EC4C40E38A8BA372A34A40
1496	Киекбаево	7	61	158	57.254474999999999	57.261589999999998	53.051910999999997	53.041485000000002	0103000020E61000000100000005000000265305A392A04C40252367614F854A40265305A392A04C40BDA60705A5864A40F67AF7C77BA14C40BDA60705A5864A40F67AF7C77BA14C40252367614F854A40265305A392A04C40252367614F854A40
614	Исламбаево	7	61	158	57.275972000000003	57.294916999999998	53.418438999999999	53.409986000000004	0103000020E610000001000000050000004D4EED0C53A34C40B0E8D66B7AB44A404D4EED0C53A34C407B2FBE688FB54A4068041BD7BFA54C407B2FBE688FB54A4068041BD7BFA54C40B0E8D66B7AB44A404D4EED0C53A34C40B0E8D66B7AB44A40
33107	Иргизлы	7	61	158	57.015245	57.034638999999999	52.964165999999999	52.953941	0103000020E61000000100000005000000B936548CF3814C4022A81ABD1A7A4A40B936548CF3814C4023F59ECA697B4A404415FE0C6F844C4023F59ECA697B4A404415FE0C6F844C4022A81ABD1A7A4A40B936548CF3814C4022A81ABD1A7A4A40
1201	Галиакберово	7	61	158	57.052013000000002	57.068057000000003	53.276662000000002	53.259908000000003	0103000020E61000000100000005000000C2FBAA5CA8864C4001FC53AA44A14A40C2FBAA5CA8864C40E20511A969A34A40C7A17E17B6884C40E20511A969A34A40C7A17E17B6884C4001FC53AA44A14A40C2FBAA5CA8864C4001FC53AA44A14A40
1441	Гадельгареево	7	61	158	57.041727000000002	57.062631000000003	53.082889000000002	53.073735999999997	0103000020E610000001000000050000001B2E724F57854C40D844662E70894A401B2E724F57854C405D19541B9C8A4A409F5BE84A04884C405D19541B9C8A4A409F5BE84A04884C40D844662E70894A401B2E724F57854C40D844662E70894A40
563	Бретяк	7	61	158	57.194135000000003	57.214311000000002	53.543945999999998	53.533999000000001	0103000020E6100000010000000500000026016A6AD9984C40618C48145AC44A4026016A6AD9984C401F65C405A0C54A402716F88A6E9B4C401F65C405A0C54A402716F88A6E9B4C40618C48145AC44A4026016A6AD9984C40618C48145AC44A40
845	Байназарово	7	61	158	57.533222000000002	57.554791000000002	53.301918000000001	53.286459999999998	0103000020E61000000100000005000000FDC0559E40C44C405BCEA5B8AAA44A40FDC0559E40C44C407009C03FA5A64A40BD8E386403C74C407009C03FA5A64A40BD8E386403C74C405BCEA5B8AAA44A40FDC0559E40C44C405BCEA5B8AAA44A40
715	Байгазино	7	61	158	57.715176	57.734552999999998	53.170580000000001	53.155096999999998	0103000020E610000001000000050000002A711DE38ADB4C40965AEF37DA934A402A711DE38ADB4C4004ADC090D5954A40DF162CD505DE4C4004ADC090D5954A40DF162CD505DE4C40965AEF37DA934A402A711DE38ADB4C40965AEF37DA934A40
667	Атиково	7	61	158	57.355373999999998	57.374768000000003	53.016182999999998	53.004696000000003	0103000020E61000000100000005000000A2EC2DE57CAD4C400536E7E099804A40A2EC2DE57CAD4C4026E0D74812824A402ECBD765F8AF4C4026E0D74812824A402ECBD765F8AF4C400536E7E099804A40A2EC2DE57CAD4C400536E7E099804A40
459	Аскарово	7	61	158	57.333283999999999	57.351044000000002	53.467986000000003	53.453972	0103000020E61000000100000005000000D923D40CA9AA4C405DA626C11BBA4A40D923D40CA9AA4C40317E1AF7E6BB4A4080BA8102EFAC4C40317E1AF7E6BB4A4080BA8102EFAC4C405DA626C11BBA4A40D923D40CA9AA4C405DA626C11BBA4A40
1610	Абдулмамбетово	7	61	158	57.715733	57.736134	53.285254999999999	53.273904999999999	0103000020E6100000010000000500000080D591239DDB4C40FE9AAC510FA34A4080D591239DDB4C409F02603C83A44A40A1BC8FA339DE4C409F02603C83A44A40A1BC8FA339DE4C40FE9AAC510FA34A4080D591239DDB4C40FE9AAC510FA34A40
58771	Шабаево	7	61	58	55.343651000000001	55.376815999999998	55.806559999999998	55.795236000000003	0103000020E610000001000000050000006D1E87C1FCAB4B400A4D124BCAE54B406D1E87C1FCAB4B408121AB5B3DE74B40054EB6813BB04B408121AB5B3DE74B40054EB6813BB04B400A4D124BCAE54B406D1E87C1FCAB4B400A4D124BCAE54B40
32511	Чишма-Бураево	7	61	58	55.513835999999998	55.532584	55.865186999999999	55.855305000000001	0103000020E61000000100000005000000F4C0C760C5C14B407A8D5DA27AED4B40F4C0C760C5C14B4051F69672BEEE4B40BA2F67B62BC44B4051F69672BEEE4B40BA2F67B62BC44B407A8D5DA27AED4B40F4C0C760C5C14B407A8D5DA27AED4B40
347	Челкаково	7	61	58	55.034126999999998	55.065280999999999	55.713836000000001	55.684742	0103000020E610000001000000050000008E7406465E844B404C1938A0A5D74B408E7406465E844B408E5A61FA5EDB4B406C06B8205B884B408E5A61FA5EDB4B406C06B8205B884B404C1938A0A5D74B408E7406465E844B404C1938A0A5D74B40
32433	Тангатарово	7	61	58	54.932563999999999	54.967140000000001	55.796247999999999	55.778309999999998	0103000020E61000000100000005000000A6B6D4415E774B402B137EA99FE34B40A6B6D4415E774B40B1C05774EBE54B40A453573ECB7B4B40B1C05774EBE54B40A453573ECB7B4B402B137EA99FE34B40A6B6D4415E774B402B137EA99FE34B40
32252	Старотазларово	7	61	58	55.625397999999997	55.639474999999997	55.875723000000001	55.859554000000003	0103000020E61000000100000005000000ED7DAA0A0DD04B40B0928FDD05EE4B40ED7DAA0A0DD04B4071ADF6B017F04B4007CE1951DAD14B4071ADF6B017F04B4007CE1951DAD14B40B0928FDD05EE4B40ED7DAA0A0DD04B40B0928FDD05EE4B40
32192	Старокизганово	7	61	58	55.676161999999998	55.698143999999999	55.914045000000002	55.907147000000002	0103000020E610000001000000050000002366F6798CD64B400FD594641DF44B402366F6798CD64B404209336DFFF44B4006F357C85CD94B404209336DFFF44B4006F357C85CD94B400FD594641DF44B402366F6798CD64B400FD594641DF44B40
31719	Старокарагушево	7	61	58	55.785809999999998	55.811933000000003	55.747889999999998	55.737121999999999	0103000020E61000000100000005000000546F0D6C95E44B40C09481035ADE4B40546F0D6C95E44B40B28009DCBADF4B4087C5A86BEDE74B40B28009DCBADF4B4087C5A86BEDE74B40C09481035ADE4B40546F0D6C95E44B40C09481035ADE4B40
31029	Старобикметово	7	61	58	55.348860999999999	55.368417000000001	55.747225999999998	55.734363999999999	0103000020E61000000100000005000000C8EC2C7AA7AC4B400CAEB9A3FFDD4B40C8EC2C7AA7AC4B40465C001AA5DF4B402D25CB4928AF4B40465C001AA5DF4B402D25CB4928AF4B400CAEB9A3FFDD4B40C8EC2C7AA7AC4B400CAEB9A3FFDD4B40
58863	Силасово	7	61	58	55.305579999999999	55.320869000000002	55.704641000000002	55.691166000000003	0103000020E61000000100000005000000E527D53E1DA74B40B70DA32078D84B40E527D53E1DA74B40DB3521AD31DA4B406EA6423C12A94B40DB3521AD31DA4B406EA6423C12A94B40B70DA32078D84B40E527D53E1DA74B40B70DA32078D84B40
71	Саит-Курзя	7	61	58	55.019295999999997	55.038268000000002	55.831569999999999	55.818325999999999	0103000020E61000000100000005000000C878944A78824B40B6BB07E8BEE84B40C878944A78824B40D82AC1E270EA4B40DE3D40F7E5844B40D82AC1E270EA4B40DE3D40F7E5844B40B6BB07E8BEE84B40C878944A78824B40B6BB07E8BEE84B40
32221	Новотазларово	7	61	58	55.559085000000003	55.578541999999999	55.851019999999998	55.838410000000003	0103000020E610000001000000050000009357E71890C74B40D751D50451EB4B409357E71890C74B40F71E2E39EEEC4B4064AE0CAA0DCA4B40F71E2E39EEEC4B4064AE0CAA0DCA4B40D751D50451EB4B409357E71890C74B40D751D50451EB4B40
30800	Новомустафино	7	61	58	55.542897000000004	55.559704000000004	55.702809999999999	55.690049999999999	0103000020E610000001000000050000005B0C1EA67DC54B406A4DF38E53D84B405B0C1EA67DC54B40A0A696ADF5D94B405FB87361A4C74B40A0A696ADF5D94B405FB87361A4C74B406A4DF38E53D84B405B0C1EA67DC54B406A4DF38E53D84B40
32116	Новокизганово	7	61	58	55.682037000000001	55.706021999999997	55.895772000000001	55.879944999999999	0103000020E61000000100000005000000BBD408FD4CD74B40ADA3AA09A2F04B40BBD408FD4CD74B4015562AA8A8F24B40D520CCED5EDA4B4015562AA8A8F24B40D520CCED5EDA4B40ADA3AA09A2F04B40BBD408FD4CD74B40ADA3AA09A2F04B40
31319	Новоельдяково	7	61	58	55.227058	55.264150000000001	55.568441	55.557240999999998	0103000020E61000000100000005000000C8258E3C109D4B40C37E4FAC53C74B40C8258E3C109D4B404F5AB8ACC2C84B40849ECDAACFA14B404F5AB8ACC2C84B40849ECDAACFA14B40C37E4FAC53C74B40C8258E3C109D4B40C37E4FAC53C74B40
31400	Новобикметово	7	61	58	55.110734999999998	55.156863999999999	55.670304999999999	55.659658	0103000020E61000000100000005000000E3C281902C8E4B40BB4560AC6FD44B40E3C281902C8E4B4032ACE28DCCD54B40BAF59A1E14944B4032ACE28DCCD54B40BAF59A1E14944B40BB4560AC6FD44B40E3C281902C8E4B40BB4560AC6FD44B40
46467	Николаевка	7	61	58	55.556291000000002	55.573287000000001	56.011122	56.005555999999999	0103000020E610000001000000050000009207228B34C74B40F6251B0FB6004C409207228B34C74B40102219726C014C40691CEA7761C94B40102219726C014C40691CEA7761C94B40F6251B0FB6004C409207228B34C74B40F6251B0FB6004C40
29569	Муллино	7	61	58	55.427922000000002	55.464564000000003	55.760807999999997	55.745189000000003	0103000020E61000000100000005000000959EE925C6B64B40632B685A62DF4B40959EE925C6B64B408044132862E14B40117349D576BB4B408044132862E14B40117349D576BB4B40632B685A62DF4B40959EE925C6B64B40632B685A62DF4B40
31128	Минлино	7	61	58	55.434057000000003	55.451511000000004	55.999898000000002	55.982456999999997	0103000020E61000000100000005000000C9CC052E8FB74B40F65CA626C1FD4B40C9CC052E8FB74B40FCAA5CA8FCFF4B406364C91CCBB94B40FCAA5CA8FCFF4B406364C91CCBB94B40F65CA626C1FD4B40C9CC052E8FB74B40F65CA626C1FD4B40
30727	Мамады	7	61	58	55.593283	55.609112000000003	55.781422999999997	55.776097	0103000020E61000000100000005000000EA2285B2F0CB4B4009C3802557E34B40EA2285B2F0CB4B40CDAB3AAB05E44B40F3CCCB61F7CD4B40CDAB3AAB05E44B40F3CCCB61F7CD4B4009C3802557E34B40EA2285B2F0CB4B4009C3802557E34B40
31909	Кушманаково	7	61	58	55.247647999999998	55.261895000000003	55.820565999999999	55.799501999999997	0103000020E61000000100000005000000BC75FEEDB29F4B40158BDF1456E64B40BC75FEEDB29F4B40D21A834E08E94B4033FE7DC685A14B40D21A834E08E94B4033FE7DC685A14B40158BDF1456E64B40BC75FEEDB29F4B40158BDF1456E64B40
31529	Кулаево	7	61	58	55.207089000000003	55.234082999999998	55.785477999999998	55.770612999999997	0103000020E61000000100000005000000412E71E4819A4B40AC6F6072A3E24B40412E71E4819A4B401EDD088B8AE44B4058C6866EF69D4B401EDD088B8AE44B4058C6866EF69D4B40AC6F6072A3E24B40412E71E4819A4B40AC6F6072A3E24B40
31782	Кузбаево	7	61	58	55.307690999999998	55.325575999999998	55.914388000000002	55.901490000000003	0103000020E6100000010000000500000003232F6B62A74B40E5D5390664F34B4003232F6B62A74B406CED7DAA0AF54B40662E7079ACA94B406CED7DAA0AF54B40662E7079ACA94B40E5D5390664F34B4003232F6B62A74B40E5D5390664F34B40
58718	Кудашево	7	61	58	55.269368999999998	55.298051999999998	55.862838000000004	55.844324	0103000020E6100000010000000500000032C7F2AE7AA24B402C9D0FCF12EC4B4032C7F2AE7AA24B407FDFBF7971EE4B40F240649126A64B407FDFBF7971EE4B40F240649126A64B402C9D0FCF12EC4B4032C7F2AE7AA24B402C9D0FCF12EC4B40
31595	Кашкалево	7	61	58	55.737121999999999	55.761313000000001	55.793621999999999	55.776319999999998	0103000020E61000000100000005000000C09481035ADE4B40889D29745EE34B40C09481035ADE4B406CB1DB6795E54B40848252B472E14B406CB1DB6795E54B40848252B472E14B40889D29745EE34B40C09481035ADE4B40889D29745EE34B40
58823	Касиярово	7	61	58	55.602150000000002	55.617044	55.897114999999999	55.887599000000002	0103000020E61000000100000005000000A9A44E4013CD4B402D7B12D89CF14B40A9A44E4013CD4B4022E010AAD4F24B40B5183C4CFBCE4B4022E010AAD4F24B40B5183C4CFBCE4B402D7B12D89CF14B40A9A44E4013CD4B402D7B12D89CF14B40
32097	Каратамак	7	61	58	55.194566000000002	55.213377000000001	55.827919000000001	55.819913999999997	0103000020E61000000100000005000000EF74E789E7984B402AC423F1F2E84B40EF74E789E7984B40575EF23FF9E94B40FB5B02F04F9B4B40575EF23FF9E94B40FB5B02F04F9B4B402AC423F1F2E84B40EF74E789E7984B402AC423F1F2E84B40
48051	Карабаево	7	61	58	55.129420000000003	55.143110999999998	55.744768999999998	55.729036999999998	0103000020E6100000010000000500000063B9A5D590904B4077499C1551DD4B4063B9A5D590904B408D09319754DF4B405359147651924B408D09319754DF4B405359147651924B4077499C1551DD4B4063B9A5D590904B4077499C1551DD4B40
31427	Каинлыково	7	61	58	55.134135999999998	55.142086999999997	55.771768000000002	55.767128999999997	0103000020E61000000100000005000000AE9B525E2B914B401668774831E24B40AE9B525E2B914B40B70C384BC9E24B40E71725E82F924B40B70C384BC9E24B40E71725E82F924B401668774831E24B40AE9B525E2B914B401668774831E24B40
31624	Даутларово	7	61	58	55.698062999999998	55.722954999999999	55.774856	55.762104999999998	0103000020E6100000010000000500000019C6DD205AD94B401D8F19A88CE14B4019C6DD205AD94B40008E3D7B2EE34B4066BD18CA89DC4B40008E3D7B2EE34B4066BD18CA89DC4B401D8F19A88CE14B4019C6DD205AD94B401D8F19A88CE14B40
31101	Ваныш-Алпаутово	7	61	58	55.412309	55.439663000000003	55.948487999999998	55.930714999999999	0103000020E61000000100000005000000596C938AC6B44B40C5724BAB21F74B40596C938AC6B44B400053060E68F94B4071218FE046B84B400053060E68F94B4071218FE046B84B40C5724BAB21F74B40596C938AC6B44B40C5724BAB21F74B40
31849	Бустанаево	7	61	58	55.238458000000001	55.262093	55.944046999999998	55.935142999999997	0103000020E610000001000000050000001BBCAFCA859E4B40AA0A0DC4B2F74B401BBCAFCA859E4B4086713788D6F84B4059C16F438CA14B4086713788D6F84B4059C16F438CA14B40AA0A0DC4B2F74B401BBCAFCA859E4B40AA0A0DC4B2F74B40
10311	Бураево	7	61	58	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
31188	Большешукшаново	7	61	58	55.536347999999997	55.556192000000003	55.950493999999999	55.940437000000003	0103000020E6100000010000000500000033A31F0DA7C44B406479573D60F84B4033A31F0DA7C44B40A98592C9A9F94B40FF25A94C31C74B40A98592C9A9F94B40FF25A94C31C74B406479573D60F84B4033A31F0DA7C44B406479573D60F84B40
30903	Большебадраково	7	61	58	55.247297000000003	55.273150999999999	55.699350000000003	55.685665	0103000020E6100000010000000500000010B3976DA79F4B408481E7DEC3D74B4010B3976DA79F4B40933A014D84D94B4052EFA99CF6A24B40933A014D84D94B4052EFA99CF6A24B408481E7DEC3D74B4010B3976DA79F4B408481E7DEC3D74B40
30932	Берлячево	7	61	58	55.207655000000003	55.228307000000001	55.738571	55.724383000000003	0103000020E61000000100000005000000EAEC6470949A4B40A2630795B8DC4B40EAEC6470949A4B401363997E89DE4B405439ED29399D4B401363997E89DE4B405439ED29399D4B40A2630795B8DC4B40EAEC6470949A4B40A2630795B8DC4B40
5884	Бакалы	7	61	58	55.714933000000002	55.729944000000003	55.826210000000003	55.815958999999999	0103000020E6100000010000000500000064EAAEEC82DB4B403DF0315871E84B4064EAAEEC82DB4B4068D0D03FC1E94B40AAF413CE6EDD4B4068D0D03FC1E94B40AAF413CE6EDD4B403DF0315871E84B4064EAAEEC82DB4B403DF0315871E84B40
278	Байшады	7	61	58	55.601027000000002	55.618679	56.080959	56.070177999999999	0103000020E61000000100000005000000AA81E673EECC4B400873BB97FB084C40AA81E673EECC4B408FA850DD5C0A4C406ADC9BDF30CF4B408FA850DD5C0A4C406ADC9BDF30CF4B400873BB97FB084C40AA81E673EECC4B400873BB97FB084C40
210	Арняшево	7	61	58	55.581291	55.601826000000003	56.016486	56.004095999999997	0103000020E61000000100000005000000C53A55BE67CA4B40AF05BD3786004C40C53A55BE67CA4B40C26B97361C024C40F6F065A208CD4B40C26B97361C024C40F6F065A208CD4B40AF05BD3786004C40C53A55BE67CA4B40AF05BD3786004C40
31830	Алтаево	7	61	58	55.352328	55.372872999999998	55.944122	55.923841000000003	0103000020E6100000010000000500000088BB7A1519AD4B401BDA006C40F64B4088BB7A1519AD4B4091B75CFDD8F84B40DC476E4DBAAF4B4091B75CFDD8F84B40DC476E4DBAAF4B401BDA006C40F64B4088BB7A1519AD4B401BDA006C40F64B40
30683	Азяково	7	61	58	55.504044999999998	55.523125	55.771245999999998	55.761107000000003	0103000020E610000001000000050000002D5BEB8B84C04B40DBE044F46BE14B402D5BEB8B84C04B40DD955D30B8E24B40295C8FC2F5C24B40DD955D30B8E24B40295C8FC2F5C24B40DBE044F46BE14B402D5BEB8B84C04B40DBE044F46BE14B40
48301	Абзаево	7	61	58	55.151311999999997	55.168559999999999	55.812776999999997	55.801475000000003	0103000020E6100000010000000500000005BF0D315E934B40E3C798BB96E64B4005BF0D315E934B4072F8A41309E84B40F6B4C35F93954B4072F8A41309E84B40F6B4C35F93954B40E3C798BB96E64B4005BF0D315E934B40E3C798BB96E64B40
58779	отделение Сарайгирское Совхоза Уртакульский	7	61	1021	54.445819999999998	54.464317000000001	54.467883	54.456201999999998	0103000020E610000001000000050000008CF337A110394B40552FBFD3643A4B408CF337A110394B405CAD1397E33B4B4009FD4CBD6E3B4B405CAD1397E33B4B4009FD4CBD6E3B4B40552FBFD3643A4B408CF337A110394B40552FBFD3643A4B40
47227	Якупово	7	61	1021	54.518313999999997	54.554803999999997	54.820394999999998	54.807279000000001	0103000020E610000001000000050000008B87F71C58424B40B1DF13EB54674B408B87F71C58424B40A5660FB402694B4051D845D103474B40A5660FB402694B4051D845D103474B40B1DF13EB54674B408B87F71C58424B40B1DF13EB54674B40
28088	Юлдузлы	7	61	1021	54.318727000000003	54.337572999999999	54.613858999999998	54.602085000000002	0103000020E6100000010000000500000015ADDC0BCC284B40C2340C1F114D4B4015ADDC0BCC284B4079AD84EE924E4B409D819197352B4B4079AD84EE924E4B409D819197352B4B40C2340C1F114D4B4015ADDC0BCC284B40C2340C1F114D4B40
58772	Шланлыкулево	7	61	1021	54.405701999999998	54.462888	54.606183999999999	54.583874000000002	0103000020E61000000100000005000000FDF50A0BEE334B400B7E1B62BC4A4B40FDF50A0BEE334B40E2ADF36F974D4B40FDDAFAE93F3B4B40E2ADF36F974D4B40FDDAFAE93F3B4B400B7E1B62BC4A4B40FDF50A0BEE334B400B7E1B62BC4A4B40
29374	Шарбаш	7	61	1021	54.516095999999997	54.532077000000001	54.755913	54.74747	0103000020E6100000010000000500000057CC086F0F424B40DD5ED218AD5F4B4057CC086F0F424B4085CFD6C1C1604B4016FA60191B444B4085CFD6C1C1604B4016FA60191B444B40DD5ED218AD5F4B4057CC086F0F424B40DD5ED218AD5F4B40
58630	Чишма	7	61	1021	54.657032000000001	54.675744000000002	54.910462000000003	54.903799999999997	0103000020E610000001000000050000007636E49F19544B40F90FE9B7AF734B407636E49F19544B401920D1048A744B40EF3B86C77E564B401920D1048A744B40EF3B86C77E564B40F90FE9B7AF734B407636E49F19544B40F90FE9B7AF734B40
58834	Уртакульский	7	61	1021	54.445819999999998	54.464317000000001	54.467883	54.456201999999998	0103000020E610000001000000050000008CF337A110394B40552FBFD3643A4B408CF337A110394B405CAD1397E33B4B4009FD4CBD6E3B4B405CAD1397E33B4B4009FD4CBD6E3B4B40552FBFD3643A4B408CF337A110394B40552FBFD3643A4B40
28106	Урзайбаш	7	61	1021	54.351928000000001	54.394804999999998	54.710245999999998	54.686884999999997	0103000020E61000000100000005000000FA4509FA0B2D4B40758E01D9EB574B40FA4509FA0B2D4B40B20E4757E95A4B400DA661F888324B40B20E4757E95A4B400DA661F888324B40758E01D9EB574B40FA4509FA0B2D4B40758E01D9EB574B40
29161	Ураново	7	61	1021	54.471412999999998	54.496737000000003	54.713886000000002	54.698442	0103000020E6100000010000000500000062F4DC42573C4B409013268C66594B4062F4DC42573C4B404089CF9D605B4B4049DBF813953F4B404089CF9D605B4B4049DBF813953F4B409013268C66594B4062F4DC42573C4B409013268C66594B40
29752	Тюрюшево	7	61	1021	54.541697999999997	54.589686	54.919170999999999	54.896340000000002	0103000020E6100000010000000500000080272D5C56454B405F0CE544BB724B4080272D5C56454B403F373465A7754B405C74B2D47A4B4B403F373465A7754B405C74B2D47A4B4B405F0CE544BB724B4080272D5C56454B405F0CE544BB724B40
58551	Ташлыкуль	7	61	1021	54.524746	54.549754999999998	54.512977999999997	54.502522999999997	0103000020E61000000100000005000000795A7EE02A434B40703E75AC52404B40795A7EE02A434B40A3C85A43A9414B40FFE7305F5E464B40A3C85A43A9414B40FFE7305F5E464B40703E75AC52404B40795A7EE02A434B40703E75AC52404B40
28772	Таллыкулево	7	61	1021	54.367083000000001	54.391086000000001	54.416268000000002	54.403503000000001	0103000020E6100000010000000500000073F56393FC2E4B40406B7EFCA5334B4073F56393FC2E4B40882F134548354B4034F6251B0F324B40882F134548354B4034F6251B0F324B40406B7EFCA5334B4073F56393FC2E4B40406B7EFCA5334B40
58807	Старый Шигай	7	61	1021	54.182721999999998	54.843693000000002	54.990101000000003	54.306196999999997	0103000020E610000001000000050000003E213B6F63174B4010919A7631274B403E213B6F63174B40535E2BA1BB7E4B409C6ED921FE6B4B40535E2BA1BB7E4B409C6ED921FE6B4B4010919A7631274B403E213B6F63174B4010919A7631274B40
30137	Старый Буздяк	7	61	1021	54.524459	54.565314000000001	54.625588	54.600983999999997	0103000020E61000000100000005000000E38BF67821434B40AAB5300BED4C4B40E38BF67821434B409162804413504B4048FC8A355C484B409162804413504B4048FC8A355C484B40AAB5300BED4C4B40E38BF67821434B40AAB5300BED4C4B40
58773	Староый Богады	7	61	1021	54.439936000000003	54.474468000000002	54.63673	54.625812000000003	0103000020E61000000100000005000000A22AA6D24F384B40E1B88C9B1A504B40A22AA6D24F384B40E8305F5E80514B40D07F0F5EBB3C4B40E8305F5E80514B40D07F0F5EBB3C4B40E1B88C9B1A504B40A22AA6D24F384B40E1B88C9B1A504B40
29997	Старотавларово	7	61	1021	54.384259	54.425913999999999	54.825933999999997	54.806941999999999	0103000020E61000000100000005000000CA181F662F314B4069E21DE049674B40CA181F662F314B40C5538F34B8694B404B74965984364B40C5538F34B8694B404B74965984364B4069E21DE049674B40CA181F662F314B4069E21DE049674B40
29133	Староактау	7	61	1021	54.445343999999999	54.471404	54.728831	54.709750999999997	0103000020E6100000010000000500000023BC3D0801394B40D2A6EA1ED95A4B4023BC3D0801394B40CEA78E554A5D4B400F9A5DF7563C4B40CEA78E554A5D4B400F9A5DF7563C4B40D2A6EA1ED95A4B4023BC3D0801394B40D2A6EA1ED95A4B40
58596	Сергеевка	7	61	1021	54.627764999999997	54.647500999999998	54.594824000000003	54.570749999999997	0103000020E610000001000000050000006649809A5A504B40931804560E494B406649809A5A504B401E705D31234C4B404B901150E1524B401E705D31234C4B404B901150E1524B40931804560E494B406649809A5A504B40931804560E494B40
29896	Севадыбашево	7	61	1021	54.640988	54.666294000000001	54.968654000000001	54.950526000000004	0103000020E61000000100000005000000719010E50B524B40B5FF01D6AA794B40719010E50B524B40DE91B1DAFC7B4B40B1C22D1F49554B40DE91B1DAFC7B4B40B1C22D1F49554B40B5FF01D6AA794B40719010E50B524B40B5FF01D6AA794B40
47109	Сабанаево	7	61	1021	54.456330999999999	54.477477	54.748213	54.738670999999997	0103000020E610000001000000050000005393E00D693A4B4076C075C58C5E4B405393E00D693A4B4095B88E71C55F4B40CDCB61F71D3D4B4095B88E71C55F4B40CDCB61F71D3D4B4076C075C58C5E4B405393E00D693A4B4076C075C58C5E4B40
29566	Сабаево	7	61	1021	54.447617000000001	54.482489999999999	54.884321999999997	54.863311000000003	0103000020E610000001000000050000001B118C834B394B4077A38FF9806E4B401B118C834B394B4010919A7631714B40D252793BC23D4B4010919A7631714B40D252793BC23D4B4077A38FF9806E4B401B118C834B394B4077A38FF9806E4B40
29027	Новоактау	7	61	1021	54.337187	54.358953	54.764864000000003	54.749164	0103000020E6100000010000000500000074D190F1282B4B4097AB1F9BE45F4B4074D190F1282B4B40A2F14410E7614B408AE6012CF22D4B40A2F14410E7614B408AE6012CF22D4B4097AB1F9BE45F4B4074D190F1282B4B4097AB1F9BE45F4B40
58548	Никольское	7	61	1021	54.547851000000001	54.585166999999998	54.465183000000003	54.447145999999996	0103000020E610000001000000050000005B0A48FB1F464B40C34483143C394B405B0A48FB1F464B40DDD3D51D8B3B4B4066D993C0E64A4B40DDD3D51D8B3B4B4066D993C0E64A4B40C34483143C394B405B0A48FB1F464B40C34483143C394B40
58777	Нижняя Чатра	7	61	1021	54.182721999999998	54.843693000000002	54.990101000000003	54.306196999999997	0103000020E610000001000000050000003E213B6F63174B4010919A7631274B403E213B6F63174B40535E2BA1BB7E4B409C6ED921FE6B4B40535E2BA1BB7E4B409C6ED921FE6B4B4010919A7631274B403E213B6F63174B4010919A7631274B40
58454	Кызыл-Яр	7	61	1021	54.456394000000003	54.479435000000002	54.907133999999999	54.902470000000001	0103000020E610000001000000050000009A0B5C1E6B3A4B4081CF0F2384734B409A0B5C1E6B3A4B407A8B87F71C744B4065C746205E3D4B407A8B87F71C744B4065C746205E3D4B4081CF0F2384734B409A0B5C1E6B3A4B4081CF0F2384734B40
58552	Кузьминка	7	61	1021	54.486235999999998	54.499476999999999	54.410772000000001	54.404536	0103000020E61000000100000005000000A51133FB3C3E4B40FF06EDD5C7334B40A51133FB3C3E4B40670E492D94344B40560DC2DCEE3F4B40670E492D94344B40560DC2DCEE3F4B40FF06EDD5C7334B40A51133FB3C3E4B40FF06EDD5C7334B40
10805	Кузеево	7	61	1021	54.595677000000002	54.629489999999997	54.891120999999998	54.870621	0103000020E610000001000000050000005DFDD8243F4C4B40FC1A4982706F4B405DFDD8243F4C4B40B0E3BF4010724B405B94D92093504B40B0E3BF4010724B405B94D92093504B40FC1A4982706F4B405DFDD8243F4C4B40FC1A4982706F4B40
28940	Копей-Кубово	7	61	1021	54.348379999999999	54.383952999999998	54.534255000000002	54.510741000000003	0103000020E610000001000000050000004D4A41B7972C4B40F9DC09F65F414B404D4A41B7972C4B40BC5CC47762444B40BD19355F25314B40BC5CC47762444B40BD19355F25314B40F9DC09F65F414B404D4A41B7972C4B40F9DC09F65F414B40
29294	Килимово	7	61	1021	54.593449999999997	54.642569000000002	54.780417999999997	54.756230000000002	0103000020E61000000100000005000000D5E76A2BF64B4B4086200725CC604B40D5E76A2BF64B4B40D89AADBCE4634B40333674B33F524B40D89AADBCE4634B40333674B33F524B4086200725CC604B40D5E76A2BF64B4B4086200725CC604B40
30052	Картамак	7	61	1021	54.460759000000003	54.486882000000001	54.818776	54.809977000000003	0103000020E61000000100000005000000392BA226FA3A4B4090C18A53AD674B40392BA226FA3A4B40F65FE7A6CD684B406B813D26523E4B40F65FE7A6CD684B406B813D26523E4B4090C18A53AD674B40392BA226FA3A4B4090C18A53AD674B40
29847	Каразирек	7	61	1021	54.455925999999998	54.474035999999998	54.946829000000001	54.928691000000001	0103000020E61000000100000005000000B3B27DC85B3A4B40768BC058DF764B40B3B27DC85B3A4B40C3F352B131794B4036902E36AD3C4B40C3F352B131794B4036902E36AD3C4B40768BC058DF764B40B3B27DC85B3A4B40768BC058DF764B40
28732	Канлы-Туркеево	7	61	1021	54.426577999999999	54.465403999999999	54.382612999999999	54.371049999999997	0103000020E61000000100000005000000B7989F1B9A364B402497FF907E2F4B40B7989F1B9A364B4021037976F9304B40BBB6B75B923B4B4021037976F9304B40BBB6B75B923B4B402497FF907E2F4B40B7989F1B9A364B402497FF907E2F4B40
8898	Казаклар-Кубово	7	61	1021	54.312016	54.339154000000001	54.461095999999998	54.454076999999998	0103000020E6100000010000000500000014EAE923F0274B40D26EF4311F3A4B4014EAE923F0274B4080289831053B4B405F27F565692B4B4080289831053B4B405F27F565692B4B40D26EF4311F3A4B4014EAE923F0274B40D26EF4311F3A4B40
29707	Идяшбаш	7	61	1021	54.309635999999998	54.338318999999998	54.872838999999999	54.863864999999997	0103000020E6100000010000000500000006D50627A2274B405B94D920936E4B4006D50627A2274B4030D63730B96F4B40C64E78094E2B4B4030D63730B96F4B40C64E78094E2B4B405B94D920936E4B4006D50627A2274B405B94D920936E4B40
28454	Гафури	7	61	1021	54.664416000000003	54.681071000000003	54.556524000000003	54.539270000000002	0103000020E6100000010000000500000036785F950B554B4062DBA2CC06454B4036785F950B554B4035B8AD2D3C474B4084A0A3552D574B4035B8AD2D3C474B4084A0A3552D574B4062DBA2CC06454B4036785F950B554B4062DBA2CC06454B40
28173	Буздяк	7	61	1021	54.501579	54.560302	54.586075999999998	54.556263000000001	0103000020E6100000010000000500000021AE9CBD33404B40C87C40A033474B4021AE9CBD33404B40397CD289044B4B4013F1D6F9B7474B40397CD289044B4B4013F1D6F9B7474B40C87C40A033474B4021AE9CBD33404B40C87C40A033474B40
29010	Большая Устюба	7	61	1021	54.366194	54.391202999999997	54.578086999999996	54.561568000000001	0103000020E61000000100000005000000E7FEEA71DF2E4B40753DD175E1474B40E7FEEA71DF2E4B40129F3BC1FE494B406D8C9DF012324B40129F3BC1FE494B406D8C9DF012324B40753DD175E1474B40E7FEEA71DF2E4B40753DD175E1474B40
58543	Арасланово	7	61	1021	54.382883999999997	54.417603999999997	54.661985000000001	54.646385000000002	0103000020E61000000100000005000000B114C95702314B40FFCF61BEBC524B40B114C95702314B40A6B8AAECBB544B40E256410C74354B40A6B8AAECBB544B40E256410C74354B40FFCF61BEBC524B40B114C95702314B40FFCF61BEBC524B40
27130	Эманино	7	61	497	56.667937999999999	56.692856999999997	55.301068999999998	55.287987999999999	0103000020E61000000100000005000000B9E00CFE7E554C40FAD170CADCA44B40B9E00CFE7E554C40726BD26D89A64B40FFE6C589AF584C40726BD26D89A64B40FFE6C589AF584C40FAD170CADCA44B40B9E00CFE7E554C40FAD170CADCA44B40
32887	Удельно-Дуваней	7	61	497	55.825111999999997	55.849932000000003	55.182855000000004	55.163620999999999	0103000020E61000000100000005000000C1C41F459DE94B402BF86D88F1944B40C1C41F459DE94B407E74EACA67974B4075E95F92CAEC4B407E74EACA67974B4075E95F92CAEC4B402BF86D88F1944B40C1C41F459DE94B402BF86D88F1944B40
27749	Турушла	7	61	497	56.214334000000001	56.241202000000001	55.036808999999998	55.023319999999998	0103000020E61000000100000005000000DF35E84B6F1B4C40DEAB5626FC824B40DF35E84B6F1B4C4067994528B6844B406ADD06B5DF1E4C4067994528B6844B406ADD06B5DF1E4C40DEAB5626FC824B40DF35E84B6F1B4C40DEAB5626FC824B40
46460	Трошкино	7	61	497	56.104801999999999	56.126074000000003	55.131171999999999	55.122585999999998	0103000020E610000001000000050000001747E5266A0D4C404679E6E5B08F4B401747E5266A0D4C4051137D3ECA904B401E705D3123104C4051137D3ECA904B401E705D3123104C404679E6E5B08F4B401747E5266A0D4C404679E6E5B08F4B40
27292	Старонадеждино	7	61	497	56.447384	56.480370000000001	55.224854999999998	55.205271000000003	0103000020E61000000100000005000000786000E143394C409BE8F351469A4B40786000E143394C40C9AB730CC89C4B4061FD9FC37C3D4C40C9AB730CC89C4B4061FD9FC37C3D4C409BE8F351469A4B40786000E143394C409BE8F351469A4B40
58502	Староиликово	7	61	497	56.223919000000002	56.252592999999997	55.352060999999999	55.336841	0103000020E61000000100000005000000FDF9B660A91C4C40D9791B9B1DAB4B40FDF9B660A91C4C403999B85510AD4B406919A9F754204C403999B85510AD4B406919A9F754204C40D9791B9B1DAB4B40FDF9B660A91C4C40D9791B9B1DAB4B40
46376	Петровка	7	61	497	56.033062999999999	56.039971000000001	55.205019	55.200626	0103000020E6100000010000000500000094DA8B683B044C40185DDE1CAE994B4094DA8B683B044C40810706103E9A4B40EBE40CC51D054C40810706103E9A4B40EBE40CC51D054C40185DDE1CAE994B4094DA8B683B044C40185DDE1CAE994B40
58391	Осиповка	7	61	497	56.334043000000001	56.369059	55.469524999999997	55.458081999999997	0103000020E61000000100000005000000973AC8EBC12A4C407171546EA2BA4B40973AC8EBC12A4C40C3D32B6519BC4B40B1A547533D2F4C40C3D32B6519BC4B40B1A547533D2F4C407171546EA2BA4B40973AC8EBC12A4C407171546EA2BA4B40
58725	Орловка	7	61	497	55.989511999999998	56.239513000000002	55.291930999999998	55.185934000000003	0103000020E61000000100000005000000F17F4754A8FE4B40749B70AFCC974B40F17F4754A8FE4B4023D8B8FE5DA54B40C2FBAA5CA81E4C4023D8B8FE5DA54B40C2FBAA5CA81E4C40749B70AFCC974B40F17F4754A8FE4B40749B70AFCC974B40
33023	Новонадеждино	7	61	497	56.082659	56.107838000000001	55.185929000000002	55.168515999999997	0103000020E610000001000000050000002BDCF291940A4C40266DAAEE91954B402BDCF291940A4C4062307F85CC974B400EA2B5A2CD0D4C4062307F85CC974B400EA2B5A2CD0D4C40266DAAEE91954B402BDCF291940A4C40266DAAEE91954B40
58844	Нижний Изяк	7	61	497	55.741073999999998	57.050961999999998	55.837772999999999	54.939838000000002	0103000020E610000001000000050000003CF54883DBDE4B40DFC4909C4C784B403CF54883DBDE4B40643C4A253CEB4B405CAB3DEC85864C40643C4A253CEB4B405CAB3DEC85864C40DFC4909C4C784B403CF54883DBDE4B40DFC4909C4C784B40
27093	Карагайкуль	7	61	497	56.444329000000003	56.466059999999999	55.512616999999999	55.499499	0103000020E610000001000000050000000BD5CDC5DF384C403EB14E95EFBF4B400BD5CDC5DF384C40D32F116F9DC14B40A4FCA4DAA73B4C40D32F116F9DC14B40A4FCA4DAA73B4C403EB14E95EFBF4B400BD5CDC5DF384C403EB14E95EFBF4B40
58142	Ильино-Поляна	7	61	497	56.159824	56.196061999999998	55.054104000000002	55.036478000000002	0103000020E61000000100000005000000D68EE21C75144C400283A44FAB844B40D68EE21C75144C40994A3FE1EC864B4082FE428F18194C40994A3FE1EC864B4082FE428F18194C400283A44FAB844B40D68EE21C75144C400283A44FAB844B40
32952	Ежовка	7	61	497	56.295074	56.316795999999997	55.421925000000002	55.399115999999999	0103000020E6100000010000000500000030F31DFCC4254C40B9A7AB3B16B34B4030F31DFCC4254C40B22E6EA301B64B4076C075C58C284C40B22E6EA301B64B4076C075C58C284C40B9A7AB3B16B34B4030F31DFCC4254C40B9A7AB3B16B34B40
58706	Гумерово	7	61	497	56.279282000000002	56.296332	55.357035000000003	55.346286999999997	0103000020E61000000100000005000000452E3883BF234C40D503E62153AC4B40452E3883BF234C408143A852B3AD4B400F61FC34EE254C408143A852B3AD4B400F61FC34EE254C40D503E62153AC4B40452E3883BF234C40D503E62153AC4B40
58595	Волково	7	61	497	56.343826	56.367910000000002	55.181646999999998	55.171221000000003	0103000020E61000000100000005000000DBC1887D022C4C40B8B1D991EA954B40DBC1887D022C4C4050357A3540974B4089EFC4AC172F4C4050357A3540974B4089EFC4AC172F4C40B8B1D991EA954B40DBC1887D022C4C40B8B1D991EA954B40
27841	Верхний Изяк	7	61	497	56.235245999999997	56.252403999999999	54.990876	54.98368	0103000020E61000000100000005000000E5417A8A1C1E4C4059DDEA39E97D4B40E5417A8A1C1E4C4016325706D57E4B4096B036C64E204C4016325706D57E4B4096B036C64E204C4059DDEA39E97D4B40E5417A8A1C1E4C4059DDEA39E97D4B40
46035	Богородское	7	61	497	55.922220000000003	55.949178000000003	55.254050999999997	55.233941999999999	0103000020E61000000100000005000000CBDB114E0BF64B409694BBCFF19D4B40CBDB114E0BF64B400F4240BE84A04B40960A2AAA7EF94B400F4240BE84A04B40960A2AAA7EF94B409694BBCFF19D4B40CBDB114E0BF64B409694BBCFF19D4B40
39011	Благовещенск	7	61	497	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
26927	Биштиново	7	61	497	56.179219000000003	56.204982000000001	55.385981000000001	55.369771	0103000020E6100000010000000500000032E9EFA5F0164C402E01F8A754AF4B4032E9EFA5F0164C404EF04DD367B14B406422A5D93C1A4C404EF04DD367B14B406422A5D93C1A4C402E01F8A754AF4B4032E9EFA5F0164C402E01F8A754AF4B40
27162	Бедеева-Поляна	7	61	497	56.359340000000003	56.399386999999997	55.339216999999998	55.310851999999997	0103000020E61000000100000005000000841266DAFE2D4C40B6F292FFC9A74B40841266DAFE2D4C40A59F70766BAB4B4049B9FB1C1F334C40A59F70766BAB4B4049B9FB1C1F334C40B6F292FFC9A74B40841266DAFE2D4C40B6F292FFC9A74B40
58473	Ахлыстино	7	61	497	56.510427	56.529687000000003	55.138989000000002	55.127059000000003	0103000020E6100000010000000500000069FF03AC55414C40CCD4247843904B4069FF03AC55414C407BC03C64CA914B40E50E9BC8CC434C407BC03C64CA914B40E50E9BC8CC434C40CCD4247843904B4069FF03AC55414C40CCD4247843904B40
58628	Александровка	7	61	497	56.068770999999998	56.420963999999998	55.291828000000002	55.266471000000003	0103000020E61000000100000005000000E4F4F57CCD084C408D2AC3B81BA24B40E4F4F57CCD084C404F07B29E5AA54B408C65FA25E2354C404F07B29E5AA54B408C65FA25E2354C408D2AC3B81BA24B40E4F4F57CCD084C408D2AC3B81BA24B40
25775	Янышево	7	61	642	55.074326999999997	55.105220000000003	54.933052000000004	54.914389999999997	0103000020E61000000100000005000000DA1A118C83894B400CE544BB0A754B40DA1A118C83894B40D4BB783F6E774B404C7155D9778D4B40D4BB783F6E774B404C7155D9778D4B400CE544BB0A754B40DA1A118C83894B400CE544BB0A754B40
25731	Ямакай	7	61	642	55.077058000000001	55.092858999999997	54.624228000000002	54.615620999999997	0103000020E6100000010000000500000095F25A09DD894B408BDD3EABCC4E4B4095F25A09DD894B40AE9FFEB3E64F4B40D311C0CDE28B4B40AE9FFEB3E64F4B40D311C0CDE28B4B408BDD3EABCC4E4B4095F25A09DD894B408BDD3EABCC4E4B40
45494	Языково	7	61	642	55.000638000000002	55.031728999999999	54.703946000000002	54.679124000000002	0103000020E610000001000000050000004391EEE714804B40E0F60489ED564B404391EEE714804B4034130CE71A5A4B40DAAA24B20F844B4034130CE71A5A4B40DAAA24B20F844B40E0F60489ED564B404391EEE714804B40E0F60489ED564B40
4228	Усманово	7	61	642	54.904643999999998	54.917758999999997	54.854557999999997	54.847031999999999	0103000020E61000000100000005000000E542E55FCB734B402E55698B6B6C4B40E542E55FCB734B4080441328626D4B40094E7D2079754B4080441328626D4B40094E7D2079754B402E55698B6B6C4B40E542E55FCB734B402E55698B6B6C4B40
25426	Удрякбаш	7	61	642	54.933812000000003	54.969987000000003	54.539572999999997	54.514938000000001	0103000020E61000000100000005000000624ED02687774B40DCBB067DE9414B40624ED02687774B40FD6662BA10454B40C845B588287C4B40FD6662BA10454B40C845B588287C4B40DCBB067DE9414B40624ED02687774B40DCBB067DE9414B40
45411	Троицкий 1-й	7	61	642	54.777513999999996	54.800251000000003	54.804445999999999	54.791170000000001	0103000020E610000001000000050000005017299485634B40C5C9FD0E45654B405017299485634B40F2B22616F8664B40B0CBF09F6E664B40F2B22616F8664B40B0CBF09F6E664B40C5C9FD0E45654B405017299485634B40C5C9FD0E45654B40
25162	Тан	7	61	642	55.000135	55.025044999999999	54.827562999999998	54.811673999999996	0103000020E61000000100000005000000E04A766C04804B40BA8102EFE4674B40E04A766C04804B4098309A95ED694B40D3F6AFAC34834B4098309A95ED694B40D3F6AFAC34834B40BA8102EFE4674B40E04A766C04804B40BA8102EFE4674B40
25243	Такчура	7	61	642	54.873283999999998	54.894888000000002	54.841349999999998	54.827500000000001	0103000020E610000001000000050000005E0F26C5C76F4B4052B81E85EB694B405E0F26C5C76F4B40AB3E575BB16B4B409BCAA2B08B724B40AB3E575BB16B4B409BCAA2B08B724B4052B81E85EB694B405E0F26C5C76F4B4052B81E85EB694B40
25149	Сынташтамак	7	61	642	54.998662000000003	55.014921000000001	54.913344000000002	54.905414999999998	0103000020E6100000010000000500000005E10A28D47F4B40672783A3E4734B4005E10A28D47F4B40B9FFC874E8744B4006836BEEE8814B40B9FFC874E8744B4006836BEEE8814B40672783A3E4734B4005E10A28D47F4B40672783A3E4734B40
25091	Старые Санны	7	61	642	54.726202999999998	54.746630000000003	54.676344999999998	54.664161	0103000020E61000000100000005000000E8A04B38F45C4B40AB23473A03554B40E8A04B38F45C4B4014E8137992564B40331B6492915F4B4014E8137992564B40331B6492915F4B40AB23473A03554B40E8A04B38F45C4B40AB23473A03554B40
24732	Старокучербаево	7	61	642	54.823830999999998	54.879868000000002	54.920315000000002	54.894803000000003	0103000020E610000001000000050000002A37514B73694B406DAE9AE788724B402A37514B73694B405682C5E1CC754B400266BE839F704B405682C5E1CC754B400266BE839F704B406DAE9AE788724B402A37514B73694B406DAE9AE788724B40
24828	Староабзаново	7	61	642	54.777793000000003	54.813546000000002	54.912402	54.896014000000001	0103000020E61000000100000005000000640795B88E634B400B613596B0724B40640795B88E634B400A67B796C9744B4054E57B4622684B400A67B796C9744B4054E57B4622684B400B613596B0724B40640795B88E634B400B613596B0724B40
24303	Сарайлы	7	61	642	55.023716	55.043649000000002	54.551642000000001	54.535321000000003	0103000020E610000001000000050000002B323A2009834B4057EE056685444B402B323A2009834B40CE8C7E349C464B4066C0594A96854B40CE8C7E349C464B4066C0594A96854B4057EE056685444B402B323A2009834B4057EE056685444B40
24229	Пришиб	7	61	642	55.148617000000002	55.172953	54.848954999999997	54.833246000000003	0103000020E610000001000000050000009850C1E105934B40ECC20FCEA76A4B409850C1E105934B404963B48EAA6C4B405F5FEB5223964B404963B48EAA6C4B405F5FEB5223964B40ECC20FCEA76A4B409850C1E105934B40ECC20FCEA76A4B40
58161	Первомайский	7	61	642	54.780954999999999	54.806789999999999	54.678359	54.669077000000001	0103000020E61000000100000005000000E7525C55F6634B40BEC0AC50A4554B40E7525C55F6634B4040F9BB77D4564B40B35E0CE544674B4040F9BB77D4564B40B35E0CE544674B40BEC0AC50A4554B40E7525C55F6634B40BEC0AC50A4554B40
49372	Новоалександровка	7	61	642	54.857410000000002	54.882877999999998	54.660635999999997	54.643071999999997	0103000020E61000000100000005000000B6A1629CBF6D4B40957CEC2E50524B40B6A1629CBF6D4B40B6476FB88F544B40CF2D742502714B40B6476FB88F544B40CF2D742502714B40957CEC2E50524B40B6A1629CBF6D4B40957CEC2E50524B40
58764	Нижнии Каргалы	7	61	642	54.743603	54.776615999999997	54.568646000000001	54.552754999999998	0103000020E610000001000000050000008F1A13622E5F4B40A9D903ADC0464B408F1A13622E5F4B4028806264C9484B4071C6302768634B4028806264C9484B4071C6302768634B40A9D903ADC0464B408F1A13622E5F4B40A9D903ADC0464B40
49505	Ломово	7	61	642	54.765863000000003	54.803134	54.870046000000002	54.853816999999999	0103000020E61000000100000005000000B51B7DCC07624B4069E21DE0496D4B40B51B7DCC07624B400002D6AA5D6F4B4020274C18CD664B400002D6AA5D6F4B4020274C18CD664B4069E21DE0496D4B40B51B7DCC07624B4069E21DE0496D4B40
25459	Куллекул	7	61	642	54.887791	54.905425000000001	54.488503999999999	54.475400999999998	0103000020E610000001000000050000007157AF22A3714B402BBEA1F0D93C4B407157AF22A3714B408BFB8F4C873E4B408BFD65F7E4734B408BFB8F4C873E4B408BFD65F7E4734B402BBEA1F0D93C4B407157AF22A3714B402BBEA1F0D93C4B40
24933	Коб-Покровка	7	61	642	55.006028000000001	55.022584000000002	54.729906999999997	54.709516999999998	0103000020E610000001000000050000001E6E8786C5804B405F7AFB73D15A4B401E6E8786C5804B408C0FB3976D5D4B40D9B45208E4824B408C0FB3976D5D4B40D9B45208E4824B405F7AFB73D15A4B401E6E8786C5804B405F7AFB73D15A4B40
24714	Кашкалаши	7	61	642	55.162953999999999	55.192158999999997	54.738292000000001	54.724696999999999	0103000020E610000001000000050000004E603AADDB944B4031410DDFC25C4B404E603AADDB944B4000732D5A805E4B40E75086AA98984B4000732D5A805E4B40E75086AA98984B4031410DDFC25C4B404E603AADDB944B4031410DDFC25C4B40
58812	Западное Отделение Совхоза Благоварский	7	61	642	55.129644999999996	55.150486000000001	54.791040000000002	54.778367000000003	0103000020E61000000100000005000000828B153598904B4090A4A487A1634B40828B153598904B40F7E978CC40654B40C040102043934B40F7E978CC40654B40C040102043934B4090A4A487A1634B40828B153598904B4090A4A487A1634B40
24332	Благовар	7	61	642	54.912711000000002	54.950215	54.590234000000002	54.569198999999998	0103000020E6100000010000000500000088D9CBB6D3744B403CF54883DB484B4088D9CBB6D3744B405F7EA7C98C4B4B40969526A5A0794B405F7EA7C98C4B4B40969526A5A0794B403CF54883DB484B4088D9CBB6D3744B403CF54883DB484B40
58708	Ахметово	7	61	642	54.893262	54.917400000000001	54.914591999999999	54.904758000000001	0103000020E610000001000000050000003961C26856724B40AE65321CCF734B403961C26856724B407497C45911754B40DAACFA5C6D754B407497C45911754B40DAACFA5C6D754B40AE65321CCF734B403961C26856724B40AE65321CCF734B40
58530	Алкино 6-е	7	61	642	54.704571000000001	54.723498999999997	54.744056	54.732028	0103000020E61000000100000005000000E25AED612F5A4B40CEE0EF17B35D4B40E25AED612F5A4B4040321D3A3D5F4B4027D87F9D9B5C4B4040321D3A3D5F4B4027D87F9D9B5C4B40CEE0EF17B35D4B40E25AED612F5A4B40CEE0EF17B35D4B40
25256	Агарды	7	61	642	55.038699000000001	55.065486999999997	54.855666999999997	54.846907999999999	0103000020E61000000100000005000000A7B1BD16F4844B40425C397B676C4B40A7B1BD16F4844B401AA20A7F866D4B4015A8C5E061884B401AA20A7F866D4B4015A8C5E061884B40425C397B676C4B40A7B1BD16F4844B40425C397B676C4B40
23693	Шелканово	7	61	1594	55.141018000000003	55.170473000000001	55.283523000000002	55.268825	0103000020E61000000100000005000000DC12B9E00C924B4071AC8BDB68A24B40DC12B9E00C924B40F8544E7B4AA44B40EEEC2B0FD2954B40F8544E7B4AA44B40EEEC2B0FD2954B4071AC8BDB68A24B40DC12B9E00C924B4071AC8BDB68A24B40
58763	Угузево	7	61	1594	55.675282000000003	55.701988999999998	55.2836	55.265861000000001	0103000020E61000000100000005000000EBC9FCA36FD64B401424B6BB07A24B40EBC9FCA36FD64B40A3923A014DA44B406C938AC6DAD94B40A3923A014DA44B406C938AC6DAD94B401424B6BB07A24B40EBC9FCA36FD64B401424B6BB07A24B40
33124	Суслово	7	61	1594	55.691343000000003	55.707172	55.434649999999998	55.420836999999999	0103000020E61000000100000005000000C6A86BED7DD84B402FF99FFCDDB54B40C6A86BED7DD84B406B9A779CA2B74B40CE52B29C84DA4B406B9A779CA2B74B40CE52B29C84DA4B402FF99FFCDDB54B40C6A86BED7DD84B402FF99FFCDDB54B40
23343	Старобурново	7	61	1594	55.608007000000001	55.629818	55.445436000000001	55.434773	0103000020E610000001000000050000009A5E622CD3CD4B40871744A4A6B74B409A5E622CD3CD4B40043BFE0B04B94B40503750E09DD04B40043BFE0B04B94B40503750E09DD04B40871744A4A6B74B409A5E622CD3CD4B40871744A4A6B74B40
23868	Старобазаново	7	61	1594	55.303738000000003	55.323708000000003	55.308874000000003	55.295893	0103000020E61000000100000005000000B74604E3E0A64B40C30E63D2DFA54B40B74604E3E0A64B40D84AE82E89A74B400FBA84436FA94B40D84AE82E89A74B400FBA84436FA94B40C30E63D2DFA54B40B74604E3E0A64B40C30E63D2DFA54B40
23815	Силантьево	7	61	1594	55.512112000000002	55.534264	55.331152000000003	55.318024000000001	0103000020E61000000100000005000000D0F1D1E28CC14B40EBABAB02B5A84B40D0F1D1E28CC14B40A400513063AA4B400FB743C362C44B40A400513063AA4B400FB743C362C44B40EBABAB02B5A84B40D0F1D1E28CC14B40EBABAB02B5A84B40
48932	Пономаревка	7	61	1594	55.543849000000002	55.569037999999999	55.404611000000003	55.388644999999997	0103000020E610000001000000050000002D7B12D89CC54B4080608E1EBFB14B402D7B12D89CC54B400A4D124BCAB34B403317B83CD6C84B400A4D124BCAB34B403317B83CD6C84B4080608E1EBFB14B402D7B12D89CC54B4080608E1EBFB14B40
23891	Питяково	7	61	1594	55.498663999999998	55.526088999999999	55.246609999999997	55.231406	0103000020E61000000100000005000000A5D8D138D4BF4B40910C39B69E9D4B40A5D8D138D4BF4B40EB6E9EEA909F4B4086E464E256C34B40EB6E9EEA909F4B4086E464E256C34B40910C39B69E9D4B40A5D8D138D4BF4B40910C39B69E9D4B40
49053	Печенкино	7	61	1594	55.325657	55.356729999999999	55.225594000000001	55.211373000000002	0103000020E61000000100000005000000535BEA20AFA94B40F3203D450E9B4B40535BEA20AFA94B404016A243E09C4B4044C02154A9AD4B404016A243E09C4B4044C02154A9AD4B40F3203D450E9B4B40535BEA20AFA94B40F3203D450E9B4B40
33100	Осиновка	7	61	1594	55.714672999999998	55.738658000000001	55.369587000000003	55.354497000000002	0103000020E61000000100000005000000C72AA5677ADB4B40DBC35E2860AD4B40C72AA5677ADB4B406D0377A04EAF4B40E27668588CDE4B406D0377A04EAF4B40E27668588CDE4B40DBC35E2860AD4B40C72AA5677ADB4B40DBC35E2860AD4B40
23212	Новоянтузово	7	61	1594	55.248303	55.279439000000004	55.518977999999997	55.505526000000003	0103000020E61000000100000005000000D53F8864C89F4B408CA37213B5C04B40D53F8864C89F4B40F7AB00DF6DC24B400D1D3BA8C4A34B40F7AB00DF6DC24B400D1D3BA8C4A34B408CA37213B5C04B40D53F8864C89F4B408CA37213B5C04B40
23092	Новокульчубаево	7	61	1594	55.423349000000002	55.443292	55.510067999999997	55.501983000000003	0103000020E61000000100000005000000ACE5CE4C30B64B40F1129CFA40C04B40ACE5CE4C30B64B40395E81E849C14B400A4AD1CABDB84B40395E81E849C14B400A4AD1CABDB84B40F1129CFA40C04B40ACE5CE4C30B64B40F1129CFA40C04B40
49082	Николаевка	7	61	1594	55.596525999999997	55.621777999999999	55.400103000000001	55.384670999999997	0103000020E610000001000000050000005A9BC6F65ACC4B401C5C3AE63CB14B405A9BC6F65ACC4B4008043A9336B34B40A7AFE76B96CF4B4008043A9336B34B40A7AFE76B96CF4B401C5C3AE63CB14B405A9BC6F65ACC4B401C5C3AE63CB14B40
23622	Маядыково	7	61	1594	55.209864000000003	55.234020000000001	55.251742	55.241863000000002	0103000020E61000000100000005000000CB4DD4D2DC9A4B40658EE55DF59E4B40CB4DD4D2DC9A4B40CB83F41439A04B40124E0B5EF49D4B40CB83F41439A04B40124E0B5EF49D4B40658EE55DF59E4B40CB4DD4D2DC9A4B40658EE55DF59E4B40
24045	Малосухоязово	7	61	1594	55.833601000000002	55.852780000000003	55.409370000000003	55.389769999999999	0103000020E61000000100000005000000DA740470B3EA4B40207BBDFBE3B14B40DA740470B3EA4B4055FB743C66B44B40695721E527ED4B4055FB743C66B44B40695721E527ED4B40207BBDFBE3B14B40DA740470B3EA4B40207BBDFBE3B14B40
19342	Кусекеево	7	61	1594	55.365344999999998	55.388198000000003	55.409610000000001	55.395778	0103000020E61000000100000005000000E960FD9FC3AE4B40F73C7FDAA8B24B40E960FD9FC3AE4B40AA0EB9196EB44B40B22FD978B0B14B40AA0EB9196EB44B40B22FD978B0B14B40F73C7FDAA8B24B40E960FD9FC3AE4B40F73C7FDAA8B24B40
58797	Кузово	7	61	1594	55.173212999999997	55.194457999999997	55.365422000000002	55.352300999999997	0103000020E61000000100000005000000FB1EF5D72B964B408EACFC3218AD4B40FB1EF5D72B964B40959EE925C6AE4B400839EFFFE3984B40959EE925C6AE4B400839EFFFE3984B408EACFC3218AD4B40FB1EF5D72B964B408EACFC3218AD4B40
58814	Кандаковка	7	61	1594	55.451287000000001	55.460180000000001	55.398660999999997	55.393906000000001	0103000020E61000000100000005000000130EBDC5C3B94B405ED905836BB24B40130EBDC5C3B94B406798DA5207B34B40FB22A12DE7BA4B406798DA5207B34B40FB22A12DE7BA4B405ED905836BB24B40130EBDC5C3B94B405ED905836BB24B40
23418	Калинники	7	61	1594	55.738630999999998	55.755420000000001	55.250976999999999	55.235339000000003	0103000020E61000000100000005000000E867EA758BDE4B40973C9E961F9E4B40E867EA758BDE4B402B86AB0320A04B40465F419AB1E04B402B86AB0320A04B40465F419AB1E04B40973C9E961F9E4B40E867EA758BDE4B40973C9E961F9E4B40
23772	Емашево	7	61	1594	55.890903999999999	55.916739999999997	55.368267000000003	55.359051999999998	0103000020E6100000010000000500000013F06B2409F24B401DC87A6AF5AD4B4013F06B2409F24B401899805F23AF4B40AF777FBC57F54B401899805F23AF4B40AF777FBC57F54B401DC87A6AF5AD4B4013F06B2409F24B401DC87A6AF5AD4B40
23167	Верхнелачентау	7	61	1594	55.36018	55.377884999999999	55.476419	55.466182000000003	0103000020E610000001000000050000002E56D4601AAE4B40F0FD0DDAABBB4B402E56D4601AAE4B40B5183C4CFBBC4B40115322895EB04B40B5183C4CFBBC4B40115322895EB04B40F0FD0DDAABBB4B402E56D4601AAE4B40F0FD0DDAABBB4B40
22315	Бирск	7	61	1594	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
23962	Бекмурзино	7	61	1594	55.569774000000002	55.582144	55.231960999999998	55.218671999999998	0103000020E61000000100000005000000390EBC5AEEC84B408446B071FD9B4B40390EBC5AEEC84B404679E6E5B09D4B4004C8D0B183CA4B404679E6E5B09D4B4004C8D0B183CA4B408446B071FD9B4B40390EBC5AEEC84B408446B071FD9B4B40
23074	Бахтыбаево	7	61	1594	55.457808	55.477760000000004	55.545284000000002	55.529654000000001	0103000020E6100000010000000500000070ECD97399BA4B400919C8B3CBC34B4070ECD97399BA4B401B84B9DDCBC54B4022AB5B3D27BD4B401B84B9DDCBC54B4022AB5B3D27BD4B400919C8B3CBC34B4070ECD97399BA4B400919C8B3CBC34B40
33043	Баженово	7	61	1594	55.578406999999999	55.595151999999999	55.497118	55.485984000000002	0103000020E610000001000000050000008463963D09CA4B408C3045B934BE4B408463963D09CA4B4060200890A1BF4B401213D4F02DCC4B4060200890A1BF4B401213D4F02DCC4B408C3045B934BE4B408463963D09CA4B408C3045B934BE4B40
58754	Андреевка	7	61	1594	55.254834000000002	55.260807999999997	55.380865999999997	55.376744000000002	0103000020E6100000010000000500000056F487669EA04B406C7BBB2539B04B4056F487669EA04B4044149337C0B04B408044132862A14B4044149337C0B04B408044132862A14B406C7BBB2539B04B4056F487669EA04B406C7BBB2539B04B40
23582	Акудибашево	7	61	1594	55.268920000000001	55.286256999999999	55.350192	55.341755999999997	0103000020E61000000100000005000000C39E76F86BA24B401B9B1DA9BEAB4B40C39E76F86BA24B4011A96917D3AC4B4023A0C211A4A44B4011A96917D3AC4B4023A0C211A4A44B401B9B1DA9BEAB4B40C39E76F86BA24B401B9B1DA9BEAB4B40
48261	Хомутовка	7	61	1414	54.283377999999999	54.303823999999999	53.416566000000003	53.402594999999998	0103000020E61000000100000005000000F433F5BA45244B403D44A33B88B34A40F433F5BA45244B401250E10852B54A40B5DE6FB4E3264B401250E10852B54A40B5DE6FB4E3264B403D44A33B88B34A40F433F5BA45244B403D44A33B88B34A40
58193	Сухоречка	7	61	1414	53.984095000000003	54.002294999999997	53.741067999999999	53.730656000000003	0103000020E610000001000000050000001D9430D3F6FD4A402750C42286DD4A401D9430D3F6FD4A405A0EF450DBDE4A40DFF8DA334B004B405A0EF450DBDE4A40DFF8DA334B004B402750C42286DD4A401D9430D3F6FD4A402750C42286DD4A40
20871	Седякбаш	7	61	1414	54.118205000000003	54.135848000000003	53.712769999999999	53.701129000000002	0103000020E61000000100000005000000A29C6857210F4B407BA35698BED94A40A29C6857210F4B40F3C81F0C3CDB4A400F9D9E7763114B40F3C81F0C3CDB4A400F9D9E7763114B407BA35698BED94A40A29C6857210F4B407BA35698BED94A40
58633	Ольховка	7	61	1414	54.009509000000001	54.019516000000003	53.5852	53.577314999999999	0103000020E610000001000000050000004302469737014B40C03E3A75E5C94A404302469737014B4042CF66D5E7CA4A40D7DF12807F024B4042CF66D5E7CA4A40D7DF12807F024B40C03E3A75E5C94A404302469737014B40C03E3A75E5C94A40
32902	Михайловка	7	61	1414	54.129711999999998	54.145845999999999	53.907328	53.903944000000003	0103000020E610000001000000050000000AF31E679A104B402DB5DE6FB4F34A400AF31E679A104B405F5FEB5223F44A404F20EC14AB124B405F5FEB5223F44A404F20EC14AB124B402DB5DE6FB4F34A400AF31E679A104B402DB5DE6FB4F34A40
21889	Менеуз-Москва	7	61	1414	54.310220000000001	54.327610999999997	53.886270000000003	53.865625999999999	0103000020E610000001000000050000005648F949B5274B409D4830D5CCEE4A405648F949B5274B4085B69C4B71F14A40A9674128EF294B4085B69C4B71F14A40A9674128EF294B409D4830D5CCEE4A405648F949B5274B409D4830D5CCEE4A40
21445	Малый Седяк	7	61	1414	54.064036000000002	54.095647999999997	53.666493000000003	53.650064	0103000020E6100000010000000500000022E2E65432084B404A27124C35D34A4022E2E65432084B40A80183A44FD54A40C2F693313E0C4B40A80183A44FD54A40C2F693313E0C4B404A27124C35D34A4022E2E65432084B404A27124C35D34A40
21991	Малый Менеуз	7	61	1414	54.187842000000003	54.197336999999997	53.984772999999997	53.970767000000002	0103000020E610000001000000050000005A68E7340B184B409D84D21742FC4A405A68E7340B184B40ED7DAA0A0DFE4A4037A5BC5642194B40ED7DAA0A0DFE4A4037A5BC5642194B409D84D21742FC4A405A68E7340B184B409D84D21742FC4A40
21503	Лысогорка	7	61	1414	53.996060999999997	54.012203999999997	53.663842000000002	53.645319000000001	0103000020E6100000010000000500000018E945ED7EFF4A40643E20D099D24A4018E945ED7EFF4A400ADB4FC6F8D44A40B07092E68F014B400ADB4FC6F8D44A40B07092E68F014B40643E20D099D24A4018E945ED7EFF4A40643E20D099D24A40
21734	Кунакулово	7	61	1414	54.424629000000003	54.457031000000001	53.722254999999997	53.712535000000003	0103000020E6100000010000000500000073F7393E5A364B40B020CD5834DB4A4073F7393E5A364B40AD2F12DA72DC4A400C21E7FD7F3A4B40AD2F12DA72DC4A400C21E7FD7F3A4B40B020CD5834DB4A4073F7393E5A364B40B020CD5834DB4A40
21792	Кош-Елга	7	61	1414	54.216327999999997	54.246555999999998	53.926690000000001	53.900655	0103000020E61000000100000005000000C39ACAA2B01B4B404CFDBCA948F34A40C39ACAA2B01B4B40DFC325C79DF64A40F850A2258F1F4B40DFC325C79DF64A40F850A2258F1F4B404CFDBCA948F34A40C39ACAA2B01B4B404CFDBCA948F34A40
20369	Кистенли-Богданово	7	61	1414	54.250822999999997	54.289054999999998	53.814681	53.803356999999998	0103000020E61000000100000005000000D40AD3F71A204B409F01F566D4E64A40D40AD3F71A204B4017D68D7747E84A4065DF15C1FF244B4017D68D7747E84A4065DF15C1FF244B409F01F566D4E64A40D40AD3F71A204B409F01F566D4E64A40
21686	Кенгер-Менеуз	7	61	1414	54.388409000000003	54.421692	53.682676000000001	53.668846000000002	0103000020E610000001000000050000006D3CD862B7314B40BC07E8BE9CD54A406D3CD862B7314B40CEE15AED61D74A400F7EE200FA354B40CEE15AED61D74A400F7EE200FA354B40BC07E8BE9CD54A406D3CD862B7314B40BC07E8BE9CD54A40
21358	Качкиново	7	61	1414	54.292721	54.30509	53.526029000000001	53.514727999999998	0103000020E610000001000000050000001CEDB8E177254B40F12A6B9BE2C14A401CEDB8E177254B40B1DF13EB54C34A40172B6A300D274B40B1DF13EB54C34A40172B6A300D274B40F12A6B9BE2C14A401CEDB8E177254B40F12A6B9BE2C14A40
46048	Каримово	7	61	1414	54.154048000000003	54.175480999999998	53.559139000000002	53.552864999999997	0103000020E61000000100000005000000D20149D8B7134B40300DC347C4C64A40D20149D8B7134B408675E3DD91C74A40E108522976164B408675E3DD91C74A40E108522976164B40300DC347C4C64A40D20149D8B7134B40300DC347C4C64A40
17178	Каныкаево	7	61	1414	54.145909000000003	54.163021999999998	53.426537000000003	53.40945	0103000020E6100000010000000500000096986725AD124B4071AC8BDB68B44A4096986725AD124B4059C4B0C398B64A40A643A7E7DD144B4059C4B0C398B64A40A643A7E7DD144B4071AC8BDB68B44A4096986725AD124B4071AC8BDB68B44A40
27037	Исякаево	7	61	1414	53.820349999999998	53.837049999999998	53.729259999999996	53.711858999999997	0103000020E6100000010000000500000005A3923A01E94A407F2E1A321EDB4A4005A3923A01E94A40F623456458DD4A40F38E537424EB4A40F623456458DD4A40F38E537424EB4A407F2E1A321EDB4A4005A3923A01E94A407F2E1A321EDB4A40
58646	Зириклы	7	61	1414	54.122849000000002	54.139746000000002	53.654066	53.629634000000003	0103000020E6100000010000000500000054AC1A84B90F4B408F39CFD897D04A4054AC1A84B90F4B4078B6476FB8D34A4098DF6932E3114B4078B6476FB8D34A4098DF6932E3114B408F39CFD897D04A4054AC1A84B90F4B408F39CFD897D04A40
21318	Елбулактамак	7	61	1414	54.244993000000001	54.271538	53.542282	53.528281999999997	0103000020E61000000100000005000000DD5F3DEE5B1F4B4061889CBE9EC34A40DD5F3DEE5B1F4B40D09A1F7F69C54A4085CFD6C1C1224B40D09A1F7F69C54A4085CFD6C1C1224B4061889CBE9EC34A40DD5F3DEE5B1F4B4061889CBE9EC34A40
20825	Елбулак-Матвеевка	7	61	1414	54.197660999999997	54.215259000000003	53.656238000000002	53.642442000000003	0103000020E61000000100000005000000EA58A5F44C194B40D6C9198A3BD24A40EA58A5F44C194B403C32569BFFD34A40B8955E9B8D1B4B403C32569BFFD34A40B8955E9B8D1B4B40D6C9198A3BD24A40EA58A5F44C194B40D6C9198A3BD24A40
47927	Егоровка	7	61	1414	54.349134999999997	54.364846	53.740110000000001	53.734017000000001	0103000020E61000000100000005000000C971A774B02C4B40A1DAE044F4DD4A40C971A774B02C4B40A6B8AAECBBDE4A40C8091346B32E4B40A6B8AAECBBDE4A40C8091346B32E4B40A1DAE044F4DD4A40C971A774B02C4B40A1DAE044F4DD4A40
15694	Дюсяново	7	61	1414	54.173388000000003	54.193492999999997	53.488959999999999	53.476722000000002	0103000020E610000001000000050000006AC2F69331164B4051A4FB3905BD4A406AC2F69331164B40AD86C43D96BE4A40A180ED60C4184B40AD86C43D96BE4A40A180ED60C4184B4051A4FB3905BD4A406AC2F69331164B4051A4FB3905BD4A40
21034	Демский	7	61	1414	54.438597999999999	54.471153000000001	53.546926999999997	53.529133000000002	0103000020E61000000100000005000000A60BB1FA23384B40001E51A1BAC34A40A60BB1FA23384B40522635B401C64A40C634D3BD4E3C4B40522635B401C64A40C634D3BD4E3C4B40001E51A1BAC34A40A60BB1FA23384B40001E51A1BAC34A40
20942	Верхняя Курмаза	7	61	1414	54.301541999999998	54.313623999999997	53.633676000000001	53.623071000000003	0103000020E610000001000000050000006A2FA2ED98264B40030B60CAC0CF4A406A2FA2ED98264B404B21904B1CD14A40CF9ECBD424284B404B21904B1CD14A40CF9ECBD424284B40030B60CAC0CF4A406A2FA2ED98264B40030B60CAC0CF4A40
48269	Боголюбовка	7	61	1414	54.290725999999999	54.322355999999999	53.503037999999997	53.494784000000003	0103000020E61000000100000005000000670C738236254B40C34A051555BF4A40670C738236254B409752978C63C04A40AED51EF642294B409752978C63C04A40AED51EF642294B40C34A051555BF4A40670C738236254B40C34A051555BF4A40
20446	Бижбуляк	7	61	1414	54.247320000000002	54.287852000000001	53.707574000000001	53.687261999999997	0103000020E61000000100000005000000C8D2872EA81F4B404BE48233F8D74A40C8D2872EA81F4B40FDBFEAC891DA4A404A0B9755D8244B40FDBFEAC891DA4A404A0B9755D8244B404BE48233F8D74A40C8D2872EA81F4B404BE48233F8D74A40
20239	Базлык	7	61	1414	54.262681000000001	54.305207000000003	53.760071000000003	53.732643000000003	0103000020E61000000100000005000000EA23F0879F214B405952EE3EC7DD4A40EA23F0879F214B40ABD1AB014AE14A4051C1E10511274B40ABD1AB014AE14A4051C1E10511274B405952EE3EC7DD4A40EA23F0879F214B405952EE3EC7DD4A40
20053	Аитово	7	61	1414	54.186593999999999	54.225454999999997	53.534646000000002	53.519883	0103000020E610000001000000050000009ED0EB4FE2174B40895FB1868BC24A409ED0EB4FE2174B40F777B6476FC44A401EDC9DB5DB1C4B40F777B6476FC44A401EDC9DB5DB1C4B40895FB1868BC24A409ED0EB4FE2174B40895FB1868BC24A40
27363	Азнаево	7	61	1414	54.385939	54.408253000000002	53.500884999999997	53.485788999999997	0103000020E610000001000000050000001FA0FB7266314B40D6E07D552EBE4A401FA0FB7266314B404A07EBFF1CC04A4038BF61A241344B404A07EBFF1CC04A4038BF61A241344B40D6E07D552EBE4A401FA0FB7266314B40D6E07D552EBE4A40
19787	Шигаево	7	61	1403	58.192846000000003	58.212600000000002	53.810572000000001	53.796379000000002	0103000020E610000001000000050000000C957F2DAF184D40501C40BFEFE54A400C957F2DAF184D40D386C3D2C0E74A4097900F7A361B4D40D386C3D2C0E74A4097900F7A361B4D40501C40BFEFE54A400C957F2DAF184D40501C40BFEFE54A40
19955	Хусаиново	7	61	1403	58.234563999999999	58.249448999999998	53.73122	53.721705999999998	0103000020E61000000100000005000000D3687231061E4D40DAA9B9DC60DC4A40D3687231061E4D402F17F19D98DD4A408C82E0F1ED1F4D402F17F19D98DD4A408C82E0F1ED1F4D40DAA9B9DC60DC4A40D3687231061E4D40DAA9B9DC60DC4A40
19893	Уткалево	7	61	1403	58.228231000000001	58.249754000000003	53.780090999999999	53.766793	0103000020E61000000100000005000000797764AC361D4D409FE6E44526E24A40797764AC361D4D40B4739A05DAE34A40C90567F0F71F4D40B4739A05DAE34A40C90567F0F71F4D409FE6E44526E24A40797764AC361D4D409FE6E44526E24A40
19841	Узянбаш	7	61	1403	58.221305000000001	58.252881000000002	53.686664999999998	53.672964	0103000020E610000001000000050000007CB8E4B8531C4D4053B131AF23D64A407CB8E4B8531C4D40672783A3E4D74A40D06394675E204D40672783A3E4D74A40D06394675E204D4053B131AF23D64A407CB8E4B8531C4D4053B131AF23D64A40
19714	Узян	7	61	1403	57.845018000000003	57.884310999999997	53.706555999999999	53.686404000000003	0103000020E610000001000000050000000344C18C29EC4C40FBEB1516DCD74A400344C18C29EC4C407365506D70DA4A401C3F541A31F14C407365506D70DA4A401C3F541A31F14C40FBEB1516DCD74A400344C18C29EC4C40FBEB1516DCD74A40
19550	Тукан	7	61	1403	57.430284	57.492024999999998	53.855569000000003	53.828420999999999	0103000020E61000000100000005000000FCFECD8B13B74C40E92807B309EA4A40FCFECD8B13B74C40583CF54883ED4A403EE8D9ACFABE4C40583CF54883ED4A403EE8D9ACFABE4C40E92807B309EA4A40FCFECD8B13B74C40E92807B309EA4A40
19277	Тирлянский	7	61	1403	58.551291999999997	58.608012000000002	54.228022000000003	54.187010999999998	0103000020E61000000100000005000000F1457BBC90464D40027FF8F9EF174B40F1457BBC90464D405F622CD32F1D4B40ACC95356D34D4D405F622CD32F1D4B40ACC95356D34D4D40027FF8F9EF174B40F1457BBC90464D40027FF8F9EF174B40
19201	Сосновка	7	61	1403	58.284267999999997	58.303995	53.862302	53.849541000000002	0103000020E6100000010000000500000050A6D1E462244D403ACE6DC2BDEC4A4050A6D1E462244D4040A374E95FEE4A40E292E34EE9264D4040A374E95FEE4A40E292E34EE9264D403ACE6DC2BDEC4A4050A6D1E462244D403ACE6DC2BDEC4A40
19137	Серменево	7	61	1403	58.082622999999998	58.143411999999998	53.912945000000001	53.868499	0103000020E61000000100000005000000DE72F563930A4D40EACDA8F92AEF4A40DE72F563930A4D40FB05BB61DBF44A404EED0C535B124D40FB05BB61DBF44A404EED0C535B124D40EACDA8F92AEF4A40DE72F563930A4D40EACDA8F92AEF4A40
19233	Рысакаево	7	61	1403	58.261163000000003	58.276659000000002	53.804431000000001	53.793453999999997	0103000020E610000001000000050000006FF607CA6D214D40B07092E68FE54A406FF607CA6D214D40BD715298F7E64A407192E68F69234D40BD715298F7E64A407192E68F69234D40B07092E68FE54A406FF607CA6D214D40B07092E68FE54A40
19030	Отнурок	7	61	1403	58.248578000000002	58.259177999999999	54.062998	54.058691000000003	0103000020E61000000100000005000000A7406667D11F4D40E7C8CA2F83074B40A7406667D11F4D4051DB865110084B40DDEBA4BE2C214D4051DB865110084B40DDEBA4BE2C214D40E7C8CA2F83074B40A7406667D11F4D40E7C8CA2F83074B40
18560	Нукатово	7	61	1403	57.369351999999999	57.393579000000003	54.180092999999999	54.170470000000002	0103000020E61000000100000005000000295B24ED46AF4C407D7901F6D1154B40295B24ED46AF4C40889E94490D174B403AB2F2CB60B24C40889E94490D174B403AB2F2CB60B24C407D7901F6D1154B40295B24ED46AF4C407D7901F6D1154B40
20039	Новобельское	7	61	1403	58.163893000000002	58.178482000000002	53.857926999999997	53.852356	0103000020E610000001000000050000008C852172FA144D4052465C001AED4A408C852172FA144D407DAD4B8DD0ED4A405C76887FD8164D407DAD4B8DD0ED4A405C76887FD8164D4052465C001AED4A408C852172FA144D4052465C001AED4A40
17143	Новоабзаково	7	61	1403	58.640377999999998	58.650089000000001	53.813161000000001	53.805978000000003	0103000020E61000000100000005000000F88903E8F7514D40D3A57F492AE74A40F88903E8F7514D40FBB0DEA815E84A40A33EC91D36534D40FBB0DEA815E84A40A33EC91D36534D40D3A57F492AE74A40F88903E8F7514D40D3A57F492AE74A40
18879	Николаевка	7	61	1403	58.730614000000003	58.749766000000001	54.377825999999999	54.365721000000001	0103000020E61000000100000005000000F8FF71C2845D4D40EF3A1BF2CF2E4B40F8FF71C2845D4D400CCA349A5C304B408DD31055F85F4D400CCA349A5C304B408DD31055F85F4D40EF3A1BF2CF2E4B40F8FF71C2845D4D40EF3A1BF2CF2E4B40
17076	Мухаметово	7	61	1403	58.465277999999998	58.476480000000002	53.702013999999998	53.692131000000003	0103000020E610000001000000050000002EC6C03A8E3B4D401EC6A4BF97D84A402EC6C03A8E3B4D40C5AA4198DBD94A405B99F04BFD3C4D40C5AA4198DBD94A405B99F04BFD3C4D401EC6A4BF97D84A402EC6C03A8E3B4D401EC6A4BF97D84A40
17592	Мулдакаево	7	61	1403	57.644621999999998	57.666119000000002	54.594150999999997	54.580764000000002	0103000020E610000001000000050000001C2444F982D24C40DA588979564A4B401C2444F982D24C405EF1D4230D4C4B40431F2C6343D54C405EF1D4230D4C4B40431F2C6343D54C40DA588979564A4B401C2444F982D24C40DA588979564A4B40
58121	Межгорье	7	61	1403	56.931207000000001	59.049219000000001	54.716678999999999	53.362419000000003	0103000020E6100000010000000500000034677DCA31774C407A39ECBE63AE4A4034677DCA31774C40705D3123BC5B4B40C1ABE5CE4C864D40705D3123BC5B4B40C1ABE5CE4C864D407A39ECBE63AE4A4034677DCA31774C407A39ECBE63AE4A40
18803	Махмутово	7	61	1403	58.786192	58.811534000000002	54.335425999999998	54.323807000000002	0103000020E610000001000000050000003C3080F0A1644D40A29BFD8172294B403C3080F0A1644D40321D3A3DEF2A4B40C9CB9A58E0674D40321D3A3DEF2A4B40C9CB9A58E0674D40A29BFD8172294B403C3080F0A1644D40A29BFD8172294B40
18750	Ломовка	7	61	1403	58.353366000000001	58.383262000000002	53.931731999999997	53.910165999999997	0103000020E6100000010000000500000059C2DA183B2D4D402FF7C95180F44A4059C2DA183B2D4D407E5182FE42F74A4058E6ADBA0E314D407E5182FE42F74A4058E6ADBA0E314D402FF7C95180F44A4059C2DA183B2D4D402FF7C95180F44A40
17341	Кузгун-Ахмерово	7	61	1403	58.238427000000001	58.258853999999999	53.996996000000003	53.986573	0103000020E61000000100000005000000E0BDA3C6841E4D40ED0E290648FE4A40E0BDA3C6841E4D40151F9F909DFF4A402A38BC2022214D40151F9F909DFF4A402A38BC2022214D40ED0E290648FE4A40E0BDA3C6841E4D40ED0E290648FE4A40
19763	Кагарманово	7	61	1403	57.779819000000003	57.801045999999999	53.646129999999999	53.630535999999999	0103000020E6100000010000000500000054E6E61BD1E34C40AF795567B5D04A4054E6E61BD1E34C40747B4963B4D24A40BA4BE2AC88E64C40747B4963B4D24A40BA4BE2AC88E64C40AF795567B5D04A4054E6E61BD1E34C40AF795567B5D04A40
18721	Кага	7	61	1403	57.678964999999998	57.703721999999999	53.534956999999999	53.514096000000002	0103000020E6100000010000000500000077103B53E8D64C409180D1E5CDC14A4077103B53E8D64C4015E2917879C44A40E4BCFF8F13DA4C4015E2917879C44A40E4BCFF8F13DA4C409180D1E5CDC14A4077103B53E8D64C409180D1E5CDC14A40
18588	Ишля	7	61	1403	57.792816999999999	57.823853999999997	53.903812000000002	53.893583	0103000020E610000001000000050000003E5B07077BE54C407BA180ED60F24A403E5B07077BE54C40BEDD921CB0F34A40E256410C74E94C40BEDD921CB0F34A40E256410C74E94C407BA180ED60F24A403E5B07077BE54C407BA180ED60F24A40
17795	Исмакаево	7	61	1403	57.544119000000002	57.555940999999997	53.703341999999999	53.689331000000003	0103000020E61000000100000005000000ED10FFB0A5C54C403B8F8AFF3BD84A40ED10FFB0A5C54C409DF3531C07DA4A40B5C01E1329C74C409DF3531C07DA4A40B5C01E1329C74C403B8F8AFF3BD84A40ED10FFB0A5C54C403B8F8AFF3BD84A40
17651	Искушта	7	61	1403	57.578676999999999	57.600307999999998	54.545265999999998	54.531612000000003	0103000020E6100000010000000500000044F9821612CA4C40A114ADDC0B444B4044F9821612CA4C4074CFBA46CB454B407AC37DE4D6CC4C4074CFBA46CB454B407AC37DE4D6CC4C40A114ADDC0B444B4044F9821612CA4C40A114ADDC0B444B40
18102	Инзер	7	61	1403	57.536087999999999	57.584597000000002	54.229447999999998	54.203218999999997	0103000020E6100000010000000500000097E315889EC44C4081768714031A4B4097E315889EC44C40F910548D5E1D4B407C2B1213D4CA4C40F910548D5E1D4B407C2B1213D4CA4C4081768714031A4B4097E315889EC44C4081768714031A4B40
17982	Зуяково	7	61	1403	57.347234999999998	57.385601999999999	54.412123000000001	54.397874000000002	0103000020E6100000010000000500000066834C3272AC4C40E0F60489ED324B4066834C3272AC4C40F7764B72C0344B40D7A205685BB14C40F7764B72C0344B40D7A205685BB14C40E0F60489ED324B4066834C3272AC4C40E0F60489ED324B40
17888	Зигаза	7	61	1403	57.319648000000001	57.338448999999997	53.847825	53.827353000000002	0103000020E61000000100000005000000AC1DC539EAA84C40AE9FFEB3E6E94A40AC1DC539EAA84C4098DD938785EC4A40942EFD4B52AB4C4098DD938785EC4A40942EFD4B52AB4C40AE9FFEB3E6E94A40AC1DC539EAA84C40AE9FFEB3E6E94A40
18045	Габдюково	7	61	1403	57.265084000000002	57.280831999999997	54.460493999999997	54.444146000000003	0103000020E61000000100000005000000B058C345EEA14C401A53B0C6D9384B40B058C345EEA14C408A00A777F13A4B40CBD58F4DF2A34C408A00A777F13A4B40CBD58F4DF2A34C401A53B0C6D9384B40B058C345EEA14C401A53B0C6D9384B40
17694	Верхний Авзян	7	61	1403	57.504755000000003	57.591558999999997	53.547626999999999	53.504221000000001	0103000020E610000001000000050000000ABFD4CF9BC04C406C7A50508AC04A400ABFD4CF9BC04C400BB43BA418C64A40C5538F34B8CB4C400BB43BA418C64A40C5538F34B8CB4C406C7A50508AC04A400ABFD4CF9BC04C406C7A50508AC04A40
58809	Верхнебельский	7	61	1403	56.931207000000001	59.049219000000001	54.716678999999999	53.362419000000003	0103000020E6100000010000000500000034677DCA31774C407A39ECBE63AE4A4034677DCA31774C40705D3123BC5B4B40C1ABE5CE4C864D40705D3123BC5B4B40C1ABE5CE4C864D407A39ECBE63AE4A4034677DCA31774C407A39ECBE63AE4A40
18899	Верхнеаршинский	7	61	1403	58.517282000000002	58.545667999999999	54.374071000000001	54.355952000000002	0103000020E610000001000000050000009D67EC4B36424D401079CBD58F2D4B409D67EC4B36424D40E6B0FB8EE12F4B40A33CF372D8454D40E6B0FB8EE12F4B40A33CF372D8454D401079CBD58F2D4B409D67EC4B36424D401079CBD58F2D4B40
17378	Буганак	7	61	1403	58.224044999999997	58.242271000000002	53.914307999999998	53.897849000000001	0103000020E6100000010000000500000089EAAD81AD1C4D4087DF4DB7ECF24A4089EAAD81AD1C4D404F3C670B08F54A4076E272BC021F4D404F3C670B08F54A4076E272BC021F4D4087DF4DB7ECF24A4089EAAD81AD1C4D4087DF4DB7ECF24A40
17475	Бриштамак	7	61	1403	57.471902999999998	57.500855999999999	54.387017999999998	54.372109000000002	0103000020E6100000010000000500000030F1475167BC4C400DC68844A12F4B4030F1475167BC4C404E7B4ACE89314B40B000A60C1CC04C404E7B4ACE89314B40B000A60C1CC04C400DC68844A12F4B4030F1475167BC4C400DC68844A12F4B40
17542	Бриш	7	61	1403	57.499004999999997	57.507008999999996	54.412709999999997	54.401035	0103000020E610000001000000050000002EC55565DFBF4C4093C6681D55334B402EC55565DFBF4C40B75D68AED3344B408AE3C0ABE5C04C40B75D68AED3344B408AE3C0ABE5C04C4093C6681D55334B402EC55565DFBF4C4093C6681D55334B40
18382	Бердагулово	7	61	1403	57.774158999999997	57.792090000000002	54.164149999999999	54.154859999999999	0103000020E61000000100000005000000B87361A417E34C40B2BAD573D2134B40B87361A417E34C40B7D100DE02154B408CBE823463E54C40B7D100DE02154B408CBE823463E54C40B2BAD573D2134B40B87361A417E34C40B2BAD573D2134B40
48339	Бельский	7	61	1403	57.641585999999997	57.651251999999999	53.521548000000003	53.511574000000003	0103000020E6100000010000000500000025C9737D1FD24C40F1BDBF417BC14A4025C9737D1FD24C40A9A5B915C2C24A4030BABC395CD34C40A9A5B915C2C24A4030BABC395CD34C40F1BDBF417BC14A4025C9737D1FD24C40F1BDBF417BC14A40
15455	Белорецк	7	61	1403	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
17437	Ассы	7	61	1403	57.553758000000002	57.589447999999997	54.380887999999999	54.361854000000001	0103000020E61000000100000005000000FEF2C98AE1C64C40A1F65B3B512E4B40FEF2C98AE1C64C402CB81FF0C0304B40A758350873CB4C402CB81FF0C0304B40A758350873CB4C40A1F65B3B512E4B40FEF2C98AE1C64C40A1F65B3B512E4B40
17288	Азналкино	7	61	1403	58.140537000000002	58.159365999999999	53.930846000000003	53.922198999999999	0103000020E610000001000000050000006170CD1DFD114D40B3B3E89D0AF64A406170CD1DFD114D4064CE33F625F74A40130CE71A66144D4064CE33F625F74A40130CE71A66144D40B3B3E89D0AF64A406170CD1DFD114D40B3B3E89D0AF64A40
19065	Азнагулово	7	61	1403	57.971214000000003	57.987302999999997	53.840387999999997	53.828496000000001	0103000020E610000001000000050000006CB587BD50FC4C40F46E2C280CEA4A406CB587BD50FC4C40B5F97FD591EB4A40101FD8F15FFE4C40B5F97FD591EB4A40101FD8F15FFE4C40F46E2C280CEA4A406CB587BD50FC4C40F46E2C280CEA4A40
17242	Азикеево	7	61	1403	58.229973999999999	58.248505999999999	53.937812000000001	53.926535999999999	0103000020E610000001000000050000001477BCC96F1D4D4088484DBB98F64A401477BCC96F1D4D40EFE53E390AF84A400D6E6B0BCF1F4D40EFE53E390AF84A400D6E6B0BCF1F4D4088484DBB98F64A401477BCC96F1D4D4088484DBB98F64A40
14374	Яныбаево	7	61	1325	58.695382000000002	58.737917000000003	55.770856000000002	55.751102000000003	0103000020E61000000100000005000000111D024702594D40E8FA3E1C24E04B40111D024702594D4073F6CE68ABE24B40CB147310745E4D4073F6CE68ABE24B40CB147310745E4D40E8FA3E1C24E04B40111D024702594D40E8FA3E1C24E04B40
14745	Шакарла	7	61	1325	59.119539000000003	59.172899000000001	55.771701999999998	55.755333	0103000020E610000001000000050000005CCCCF0D4D8F4D40774B72C0AEE04B405CCCCF0D4D8F4D40FF209221C7E24B406C41EF8D21964D40FF209221C7E24B406C41EF8D21964D40774B72C0AEE04B405CCCCF0D4D8F4D40774B72C0AEE04B40
14922	Ургала	7	61	1325	59.489888000000001	59.506030000000003	55.555163	55.540979999999998	0103000020E61000000100000005000000F75965A6B4BE4D4021E527D53EC54B40F75965A6B4BE4D408179C8940FC74B40BF654E97C5C04D408179C8940FC74B40BF654E97C5C04D4021E527D53EC54B40F75965A6B4BE4D4021E527D53EC54B40
58799	Ураковская Ферма Совхоза	7	61	1325	59.081972	59.108911999999997	55.671976000000001	55.658611000000001	0103000020E610000001000000050000000798F90E7E8A4D4097E4805D4DD44B400798F90E7E8A4D4034D93F4F03D64B402B1213D4F08D4D4034D93F4F03D64B402B1213D4F08D4D4097E4805D4DD44B400798F90E7E8A4D4097E4805D4DD44B40
14684	Старобелокатай	7	61	1325	58.961767999999999	59.01361	55.797942999999997	55.767432999999997	0103000020E610000001000000050000006F2BBD361B7B4D40826F9A3E3BE24B406F2BBD361B7B4D403B8908FF22E64B400473F4F8BD814D403B8908FF22E64B400473F4F8BD814D40826F9A3E3BE24B406F2BBD361B7B4D40826F9A3E3BE24B40
14492	Соколки	7	61	1325	58.876527000000003	58.900008999999997	55.74597	55.730187999999998	0103000020E61000000100000005000000CF87670932704D4040F7E5CC76DD4B40CF87670932704D4008E6E8F17BDF4B40868DB27E33734D4008E6E8F17BDF4B40868DB27E33734D4040F7E5CC76DD4B40CF87670932704D4040F7E5CC76DD4B40
14119	Ногуши	7	61	1325	58.631413000000002	58.675637000000002	56.004237000000003	55.954006999999997	0103000020E6100000010000000500000077A22424D2504D40D993C0E61CFA4B4077A22424D2504D40723788D68A004C40D97BF1457B564D40723788D68A004C40D97BF1457B564D40D993C0E61CFA4B4077A22424D2504D40D993C0E61CFA4B40
14553	Новобелокатай	7	61	1325	58.917014000000002	58.992068000000003	55.722729999999999	55.692053999999999	0103000020E61000000100000005000000B1FCF9B660754D407288B83995D84B40B1FCF9B660754D4046EBA86A82DC4B403EB48F15FC7E4D4046EBA86A82DC4B403EB48F15FC7E4D407288B83995D84B40B1FCF9B660754D407288B83995D84B40
14787	Нижнеутяшево	7	61	1325	58.957061000000003	58.980058	55.665619	55.646070999999999	0103000020E6100000010000000500000077A38FF9807A4D406FF25B74B2D24B4077A38FF9807A4D40514CDE0033D54B407217618A727D4D40514CDE0033D54B407217618A727D4D406FF25B74B2D24B4077A38FF9807A4D406FF25B74B2D24B40
58815	Медятовская Ферма	7	61	1325	58.652002000000003	58.679409999999997	55.762180999999998	55.746364999999997	0103000020E610000001000000050000009B7631CD74534D4084F068E388DF4B409B7631CD74534D40F850A2258FE14B40A54929E8F6564D40F850A2258FE14B40A54929E8F6564D4084F068E388DF4B409B7631CD74534D4084F068E388DF4B40
15169	Майгаза	7	61	1325	58.855435	58.890945000000002	55.615360000000003	55.599463	0103000020E61000000100000005000000486DE2E47E6D4D40BE141E34BBCC4B40486DE2E47E6D4D401FA2D11DC4CE4B4072C45A7C0A724D401FA2D11DC4CE4B4072C45A7C0A724D40BE141E34BBCC4B40486DE2E47E6D4D40BE141E34BBCC4B40
15414	Кирикеево	7	61	1325	59.223232000000003	59.246299999999998	56.073514000000003	56.061171999999999	0103000020E61000000100000005000000D9B5BDDD929C4D4028B7ED7BD4074C40D9B5BDDD929C4D402AE620E868094C409D8026C2869F4D402AE620E868094C409D8026C2869F4D4028B7ED7BD4074C40D9B5BDDD929C4D4028B7ED7BD4074C40
14167	Карлыханово	7	61	1325	58.664704	58.737414000000001	55.968131	55.926443999999996	0103000020E610000001000000050000009CC24A0515554D40A7C98CB795F64B409CC24A0515554D40349F73B7EBFB4B4068CEFA94635E4D40349F73B7EBFB4B4068CEFA94635E4D40A7C98CB795F64B409CC24A0515554D40A7C98CB795F64B40
14909	Карантрав	7	61	1325	59.152067000000002	59.206603999999999	55.610813999999998	55.598160999999998	0103000020E6100000010000000500000082E673EE76934D400F5F268A90CC4B4082E673EE76934D402FF834272FCE4B40849CF7FF719A4D402FF834272FCE4B40849CF7FF719A4D400F5F268A90CC4B4082E673EE76934D400F5F268A90CC4B40
15113	Кадырово	7	61	1325	59.156855	59.174228999999997	55.527600999999997	55.517913	0103000020E61000000100000005000000679B1BD313944D402D9622F94AC24B40679B1BD313944D401F2BF86D88C34B40E481C8224D964D401F2BF86D88C34B40E481C8224D964D402D9622F94AC24B40679B1BD313944D402D9622F94AC24B40
14084	Емаши	7	61	1325	58.578223000000001	58.638375000000003	55.953251000000002	55.926428999999999	0103000020E61000000100000005000000C3651536034A4D407288B83995F64B40C3651536034A4D408DF0F62004FA4B40C1CAA145B6514D408DF0F62004FA4B40C1CAA145B6514D407288B83995F64B40C3651536034A4D407288B83995F64B40
15361	Белянка	7	61	1325	59.209280999999997	59.261527000000001	56.051274999999997	56.035145	0103000020E610000001000000050000004B5645B8C99A4D4018CFA0A17F044C404B5645B8C99A4D401B0DE02D90064C40B0027CB779A14D401B0DE02D90064C40B0027CB779A14D4018CFA0A17F044C404B5645B8C99A4D4018CFA0A17F044C40
15319	Ашаево	7	61	1325	59.182242000000002	59.204906000000001	55.929071	55.916657999999998	0103000020E6100000010000000500000094FAB2B453974D40F2CEA10C55F54B4094FAB2B453974D40BD546CCCEBF64B4089601C5C3A9A4D40BD546CCCEBF64B4089601C5C3A9A4D40F2CEA10C55F54B4094FAB2B453974D40F2CEA10C55F54B40
14847	Апутово	7	61	1325	59.021523999999999	59.041367999999999	55.703859999999999	55.690942999999997	0103000020E61000000100000005000000200A664CC1824D403733FAD170D84B40200A664CC1824D40357BA01518DA4B40EB8CEF8B4B854D40357BA01518DA4B40EB8CEF8B4B854D403733FAD170D84B40200A664CC1824D403733FAD170D84B40
14240	Айдакаево	7	61	1325	58.709907000000001	58.730991000000003	55.917262999999998	55.899053000000002	0103000020E61000000100000005000000CA198A3BDE5A4D40732F302B14F34B40CA198A3BDE5A4D40596ABDDF68F54B40CE55F31C915D4D40596ABDDF68F54B40CE55F31C915D4D40732F302B14F34B40CA198A3BDE5A4D40732F302B14F34B40
14402	Айгырьял	7	61	1325	58.795113000000001	58.822017000000002	55.725994999999998	55.709935999999999	0103000020E61000000100000005000000EECF4543C6654D406420CF2EDFDA4B40EECF4543C6654D409E077767EDDC4B40C6E061DA37694D409E077767EDDC4B40C6E061DA37694D406420CF2EDFDA4B40EECF4543C6654D406420CF2EDFDA4B40
14997	Абсалямово	7	61	1325	59.502859000000001	59.520592000000001	55.532176999999997	55.516731	0103000020E61000000100000005000000E8BF07AF5DC04D4029EACC3D24C24B40E8BF07AF5DC04D4079573D601EC44B40954737C2A2C24D4079573D601EC44B40954737C2A2C24D4029EACC3D24C24B40E8BF07AF5DC04D4029EACC3D24C24B40
58144	совхоза Имени М. Горького	7	61	1158	54.291893999999999	54.313848999999998	54.010226000000003	53.993492000000003	0103000020E6100000010000000500000006F357C85C254B40386BF0BE2AFF4A4006F357C85C254B40D2C8E7154F014B40EF703B342C284B40D2C8E7154F014B40EF703B342C284B40386BF0BE2AFF4A4006F357C85C254B40386BF0BE2AFF4A40
13968	Шаровка	7	61	1158	54.376012000000003	54.395595999999998	54.031364000000004	54.012855999999999	0103000020E61000000100000005000000A873452921304B4058C7F143A5014B40A873452921304B40C9224DBC03044B40D636C5E3A2324B40C9224DBC03044B40D636C5E3A2324B4058C7F143A5014B40A873452921304B4058C7F143A5014B40
13884	Усень-Ивановское	7	61	1158	54.321314000000001	54.358961999999998	54.201587000000004	54.174275000000002	0103000020E610000001000000050000009CDF30D120294B4055C1A8A44E164B409CDF30D120294B403E26529ACD194B40DD408177F22D4B403E26529ACD194B40DD408177F22D4B4055C1A8A44E164B409CDF30D120294B4055C1A8A44E164B40
13820	Тузлукуш	7	61	1158	54.126531999999997	54.144911999999998	54.267198999999998	54.249417000000001	0103000020E61000000100000005000000E0F2583332104B40810871E5EC1F4B40E0F2583332104B400F43AB9333224B402366F6798C124B400F43AB9333224B402366F6798C124B40810871E5EC1F4B40E0F2583332104B40810871E5EC1F4B40
13678	Старосеменкино	7	61	1158	54.283073000000002	54.308881	54.349713000000001	54.338538999999997	0103000020E61000000100000005000000B8B06EBC3B244B40D4B5F63E552B4B40B8B06EBC3B244B4037FE4465C32C4B408AADA06989274B4037FE4465C32C4B408AADA06989274B40D4B5F63E552B4B40B8B06EBC3B244B40D4B5F63E552B4B40
13796	Слакбаш	7	61	1158	54.399360000000001	54.430405	53.986462000000003	53.961153000000003	0103000020E6100000010000000500000050AA7D3A1E334B40E5B9BE0F07FB4A4050AA7D3A1E334B40965F066344FE4A407784D38217374B40965F066344FE4A407784D38217374B40E5B9BE0F07FB4A4050AA7D3A1E334B40E5B9BE0F07FB4A40
13663	Рассвет	7	61	1158	53.972318000000001	53.993105	54.047373999999998	54.040289999999999	0103000020E61000000100000005000000F4A78DEA74FC4A408C2D043928054B40F4A78DEA74FC4A402157EA5910064B403E3F8C101EFF4A402157EA5910064B403E3F8C101EFF4A408C2D043928054B40F4A78DEA74FC4A408C2D043928054B40
13742	Новосеменкино	7	61	1158	54.311135999999998	54.339181000000004	54.394450999999997	54.374175999999999	0103000020E61000000100000005000000DB4DF04DD3274B405B79C9FFE42F4B40DB4DF04DD3274B40EF6FD05E7D324B40593673486A2B4B40EF6FD05E7D324B40593673486A2B4B405B79C9FFE42F4B40DB4DF04DD3274B405B79C9FFE42F4B40
13262	Новосараево	7	61	1158	54.432130000000001	54.450671	54.078642000000002	54.067858999999999	0103000020E610000001000000050000006CCF2C0950374B40A0DE8C9AAF084B406CCF2C0950374B40C80BE9F0100A4B40B8205B96AF394B40C80BE9F0100A4B40B8205B96AF394B40A0DE8C9AAF084B406CCF2C0950374B40A0DE8C9AAF084B40
12751	Надеждино	7	61	1158	54.145072999999996	54.164180999999999	54.041331999999997	54.029476000000003	0103000020E610000001000000050000002C4487C091124B402A029CDEC5034B402C4487C091124B409E23F25D4A054B40F2CF0CE203154B409E23F25D4A054B40F2CF0CE203154B402A029CDEC5034B402C4487C091124B402A029CDEC5034B40
13545	Метевбаш	7	61	1158	54.215770999999997	54.264629999999997	54.301164	54.286766	0103000020E610000001000000050000006D3656629E1B4B4068CD8FBFB4244B406D3656629E1B4B40C45DBD8A8C264B402EC55565DF214B40C45DBD8A8C264B402EC55565DF214B4068CD8FBFB4244B406D3656629E1B4B4068CD8FBFB4244B40
58089	Междугорное	7	61	1158	54.247642999999997	54.254334999999998	54.115940000000002	54.111263999999998	0103000020E61000000100000005000000AA0A0DC4B21F4B406F9C14E63D0E4B40AA0A0DC4B21F4B402D26361FD70E4B40349D9D0C8E204B402D26361FD70E4B40349D9D0C8E204B406F9C14E63D0E4B40AA0A0DC4B21F4B406F9C14E63D0E4B40
13185	Малоалександровка	7	61	1158	53.895404999999997	53.927591	54.262151000000003	54.232410999999999	0103000020E6100000010000000500000062D68BA19CF24A40861DC6A4BF1D4B4062D68BA19CF24A408ECEF9298E214B402F88484DBBF64A408ECEF9298E214B402F88484DBBF64A40861DC6A4BF1D4B4062D68BA19CF24A40861DC6A4BF1D4B40
13461	Малиновка	7	61	1158	54.076289000000003	54.084608000000003	54.006072000000003	53.995857999999998	0103000020E61000000100000005000000B40584D6C3094B40E0BA624678FF4A40B40584D6C3094B40EEB5A0F7C6004B40707D586FD40A4B40EEB5A0F7C6004B40707D586FD40A4B40E0BA624678FF4A40B40584D6C3094B40E0BA624678FF4A40
12912	Илькино	7	61	1158	54.059769000000003	54.096572999999999	54.194338999999999	54.172877999999997	0103000020E610000001000000050000004628B682A6074B405419C6DD20164B404628B682A6074B402EABB019E0184B409B560A815C0C4B402EABB019E0184B409B560A815C0C4B405419C6DD20164B404628B682A6074B405419C6DD20164B40
13237	Знаменка	7	61	1158	54.369858999999998	54.407867000000003	54.121882999999997	54.082926	0103000020E61000000100000005000000CD902A8A572F4B407AFEB4519D0A4B40CD902A8A572F4B401C78B5DC990F4B400F0F61FC34344B401C78B5DC990F4B400F0F61FC34344B407AFEB4519D0A4B40CD902A8A572F4B407AFEB4519D0A4B40
13112	Ермолкино	7	61	1158	53.898494999999997	53.926890999999998	54.204762000000002	54.181362999999997	0103000020E610000001000000050000004C4F58E201F34A402BDA1CE736174B404C4F58E201F34A4056BB26A4351A4B4076FA415DA4F64A4056BB26A4351A4B4076FA415DA4F64A402BDA1CE736174B404C4F58E201F34A402BDA1CE736174B40
13949	Веровка	7	61	1158	54.486981	54.518197999999998	54.174754999999998	54.156968999999997	0103000020E61000000100000005000000FE62B664553E4B402FBE688F17144B40FE62B664553E4B40FFE7305F5E164B40226DE34F54424B40FFE7305F5E164B40226DE34F54424B402FBE688F17144B40FE62B664553E4B402FBE688F17144B40
10973	Белебей	7	61	1158	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
13103	Баймурзино	7	61	1158	53.887642999999997	53.904361000000002	54.172088000000002	54.148164000000001	0103000020E61000000100000005000000FCC22B499EF14A40E738B709F7124B40FCC22B499EF14A405C04C6FA06164B409163EB19C2F34A405C04C6FA06164B409163EB19C2F34A40E738B709F7124B40FCC22B499EF14A40E738B709F7124B40
12962	Баженово	7	61	1158	53.889924999999998	53.913012000000002	53.983539	53.966206999999997	0103000020E610000001000000050000004772F90FE9F14A404815C5ABACFB4A404772F90FE9F14A4097AB1F9BE4FD4A40836DC493DDF44A4097AB1F9BE4FD4A40836DC493DDF44A404815C5ABACFB4A404772F90FE9F14A404815C5ABACFB4A40
12874	Анновка	7	61	1158	54.046940999999997	54.071753000000001	54.255381999999997	54.235148000000002	0103000020E61000000100000005000000B7EBA52902064B4023DC6454191E4B40B7EBA52902064B4058FE7C5BB0204B40E831CA332F094B4058FE7C5BB0204B40E831CA332F094B4023DC6454191E4B40B7EBA52902064B4023DC6454191E4B40
13592	Алексеевка	7	61	1158	54.017854	54.032181999999999	54.107357999999998	54.095663999999999	0103000020E61000000100000005000000280D350A49024B40C8B3CBB73E0C4B40280D350A49024B40637B2DE8BD0D4B408BC22E8A1E044B40637B2DE8BD0D4B408BC22E8A1E044B40C8B3CBB73E0C4B40280D350A49024B40C8B3CBB73E0C4B40
12767	Аксаково	7	61	1158	54.138829999999999	54.164738	54.028593000000001	54.005003000000002	0103000020E6100000010000000500000012DA722EC5114B40E2B034F0A3004B4012DA722EC5114B4080F277EFA8034B404834812216154B4080F277EFA8034B404834812216154B40E2B034F0A3004B4012DA722EC5114B40E2B034F0A3004B40
13042	Аделькино	7	61	1158	53.959553	53.985729999999997	54.189782000000001	54.171259999999997	0103000020E61000000100000005000000ACE3F8A1D2FA4A40758E01D9EB154B40ACE3F8A1D2FA4A404BAFCDC64A184B40D15790662CFE4A404BAFCDC64A184B40D15790662CFE4A40758E01D9EB154B40ACE3F8A1D2FA4A40758E01D9EB154B40
8991	Янтимирово	7	61	607	56.130735999999999	56.145029000000001	55.979484999999997	55.967269999999999	0103000020E6100000010000000500000076340EF5BB104C407233DC80CFFB4B4076340EF5BB104C4016F6B4C35FFD4B405DFC6D4F90124C4016F6B4C35FFD4B405DFC6D4F90124C407233DC80CFFB4B4076340EF5BB104C407233DC80CFFB4B40
10862	Штанды	7	61	607	56.129747999999999	56.165599999999998	56.086233	56.071193000000001	0103000020E61000000100000005000000575C1C959B104C40215A2BDA1C094C40575C1C959B104C40016BD5AE090B4C40DA1B7C6132154C40016BD5AE090B4C40DA1B7C6132154C40215A2BDA1C094C40575C1C959B104C40215A2BDA1C094C40
58782	Шавьяды	7	61	607	55.818770000000001	55.849708	56.088242000000001	56.069443999999997	0103000020E6100000010000000500000014799274CDE84B40A3737E8AE3084C4014799274CDE84B401B118C834B0B4C402593533BC3EC4B401B118C834B0B4C402593533BC3EC4B40A3737E8AE3084C4014799274CDE84B40A3737E8AE3084C40
9128	Чуртанлыкуль	7	61	607	55.963433999999999	55.979998999999999	55.797316000000002	55.786904999999997	0103000020E610000001000000050000005FED28CE51FB4B408907944DB9E44B405FED28CE51FB4B40ED4960730EE64B406D8E739B70FD4B40ED4960730EE64B406D8E739B70FD4B408907944DB9E44B405FED28CE51FB4B408907944DB9E44B40
48372	Чукалы	7	61	607	56.188363000000003	56.209932000000002	55.892552000000002	55.882485000000003	0103000020E6100000010000000500000063635E471C184C40F41ABB44F5F04B4063635E471C184C405DFDD8243FF24B402331410DDF1A4C405DFDD8243FF24B402331410DDF1A4C40F41ABB44F5F04B4063635E471C184C40F41ABB44F5F04B40
58632	Чишма	7	61	607	55.955978000000002	55.970027999999999	55.870227999999997	55.861656000000004	0103000020E6100000010000000500000006D9B27C5DFA4B407B336ABE4AEE4B4006D9B27C5DFA4B40200890A163EF4B40261AA4E029FC4B40200890A163EF4B40261AA4E029FC4B407B336ABE4AEE4B4006D9B27C5DFA4B407B336ABE4AEE4B40
58795	Усманово	7	61	607	55.780825	55.795763999999998	55.926473999999999	55.910860999999997	0103000020E610000001000000050000001973D712F2E34B40D619DF1797F44B401973D712F2E34B40124C35B396F64B40C5AA4198DBE54B40124C35B396F64B40C5AA4198DBE54B40D619DF1797F44B401973D712F2E34B40D619DF1797F44B40
10572	Тучубаево	7	61	607	55.684426000000002	55.718670000000003	55.994017999999997	55.980150000000002	0103000020E610000001000000050000001C446B459BD74B405396218E75FD4B401C446B459BD74B4052D158FB3BFF4B40E44EE960FDDB4B4052D158FB3BFF4B40E44EE960FDDB4B405396218E75FD4B401C446B459BD74B405396218E75FD4B40
58785	Тутагачево	7	61	607	55.950848999999998	55.972785999999999	56.091636999999999	56.077472999999998	0103000020E610000001000000050000009737876BB5F94B4058A9A0A2EA094C409737876BB5F94B40410DDFC2BA0B4C40DA006C4084FC4B40410DDFC2BA0B4C40DA006C4084FC4B4058A9A0A2EA094C409737876BB5F94B4058A9A0A2EA094C40
9922	Туктаево	7	61	607	56.026721000000002	56.038021000000001	56.036124999999998	56.028182999999999	0103000020E61000000100000005000000E78EFE976B034C40CEA623809B034C40E78EFE976B034C40B4C876BE9F044C40D6C743DFDD044C40B4C876BE9F044C40D6C743DFDD044C40CEA623809B034C40E78EFE976B034C40CEA623809B034C40
4263	Тузлубино	7	61	607	55.952663000000001	55.963120000000004	55.991726999999997	55.983820999999999	0103000020E61000000100000005000000FC8D76DCF0F94B401B0FB6D8EDFD4B40FC8D76DCF0F94B40B4C70BE9F0FE4B40D00F238447FB4B40B4C70BE9F0FE4B40D00F238447FB4B401B0FB6D8EDFD4B40FC8D76DCF0F94B401B0FB6D8EDFD4B40
58789	Тибелеево	7	61	607	55.866677000000003	55.887571000000001	56.083134000000001	56.075598999999997	0103000020E6100000010000000500000003999D45EFEE4B401E4E603AAD094C4003999D45EFEE4B40C4978922A40A4C4063F030ED9BF14B40C4978922A40A4C4063F030ED9BF14B401E4E603AAD094C4003999D45EFEE4B401E4E603AAD094C40
10011	Староянбаево	7	61	607	56.139935000000001	56.168016999999999	55.921708000000002	55.906244000000001	0103000020E610000001000000050000006B48DC63E9114C401E19ABCDFFF34B406B48DC63E9114C40153B1A87FAF54B400516C09481154C40153B1A87FAF54B400516C09481154C401E19ABCDFFF34B406B48DC63E9114C401E19ABCDFFF34B40
10289	Староямурзино	7	61	607	55.827142000000002	55.840148999999997	55.947817000000001	55.934134	0103000020E61000000100000005000000F392FFC9DFE94B40740AF2B391F74B40F392FFC9DFE94B40E2CB441152F94B4030629F008AEB4B40E2CB441152F94B4030629F008AEB4B40740AF2B391F74B40F392FFC9DFE94B40740AF2B391F74B40
9839	Староякшеево	7	61	607	55.867565999999997	55.891021000000002	56.015056999999999	56.002284000000003	0103000020E610000001000000050000008E8F16670CEF4B40ECA694D74A004C408E8F16670CEF4B40B6494563ED014C404D86E3F90CF24B40B6494563ED014C404D86E3F90CF24B40ECA694D74A004C408E8F16670CEF4B40ECA694D74A004C40
8535	Старотимкино	7	61	607	56.084276000000003	56.109006000000001	55.871040999999998	55.851216999999998	0103000020E610000001000000050000003AEB538EC90A4C404D66BCADF4EC4B403AEB538EC90A4C40D13C80457EEF4B40AD889AE8F30D4C40D13C80457EEF4B40AD889AE8F30D4C404D66BCADF4EC4B403AEB538EC90A4C404D66BCADF4EC4B40
9747	Старобалтачево	7	61	607	55.910711999999997	55.939782000000001	56.013845000000003	55.992426999999999	0103000020E610000001000000050000009109F83592F44B406D5512D907FF4B409109F83592F44B40481B47ACC5014C404BAFCDC64AF84B40481B47ACC5014C404BAFCDC64AF84B406D5512D907FF4B409109F83592F44B406D5512D907FF4B40
10222	Сейтяково	7	61	607	55.772398000000003	55.806355000000003	55.980899999999998	55.962598999999997	0103000020E6100000010000000500000077BF0AF0DDE24B40C614AC7136FB4B4077BF0AF0DDE24B40BD5296218EFD4B40A9FB00A436E74B40BD5296218EFD4B40A9FB00A436E74B40C614AC7136FB4B4077BF0AF0DDE24B40C614AC7136FB4B40
8645	Новоямурзино	7	61	607	55.922578999999999	55.944785000000003	55.923766000000001	55.909523999999998	0103000020E61000000100000005000000FA7C941117F64B40AB764D486BF44B40FA7C941117F64B401094DBF63DF64B402D6002B7EEF84B401094DBF63DF64B402D6002B7EEF84B40AB764D486BF44B40FA7C941117F64B40AB764D486BF44B40
6508	Новобалтачево	7	61	607	56.010092999999998	56.034948999999997	56.061388999999998	56.041319999999999	0103000020E61000000100000005000000927538BA4A014C40DA5548F949054C40927538BA4A014C40C5AA4198DB074C409203763579044C40C5AA4198DB074C409203763579044C40DA5548F949054C40927538BA4A014C40DA5548F949054C40
4342	Нижнесикиязово	7	61	607	55.880932999999999	55.919462000000003	56.129393999999998	56.113621999999999	0103000020E61000000100000005000000CC7B9C69C2F04B40950D6B2A8B0E4C40CC7B9C69C2F04B4039268BFB8F104C4017F549EEB0F54B4039268BFB8F104C4017F549EEB0F54B40950D6B2A8B0E4C40CC7B9C69C2F04B40950D6B2A8B0E4C40
9031	Нижнекарышево	7	61	607	55.965499999999999	55.987122999999997	55.843105999999999	55.826321	0103000020E61000000100000005000000DD24068195FB4B40BF7FF3E2C4E94B40DD24068195FB4B40DB87BCE5EAEB4B409010E50B5AFE4B40DB87BCE5EAEB4B409010E50B5AFE4B40BF7FF3E2C4E94B40DD24068195FB4B40BF7FF3E2C4E94B40
8818	Нижнеиванаево	7	61	607	55.985244999999999	56.004387999999999	55.961419999999997	55.951033000000002	0103000020E6100000010000000500000015C616821CFE4B4059350873BBF94B4015C616821CFE4B4033DC80CF0FFB4B40573F36C98F004C4033DC80CF0FFB4B40573F36C98F004C4059350873BBF94B4015C616821CFE4B4059350873BBF94B40
58839	Начарово	7	61	607	55.897956000000001	55.915168000000001	55.818007000000001	55.805427000000002	0103000020E610000001000000050000009D9FE238F0F24B405F28603B18E74B409D9FE238F0F24B4015731074B4E84B40412C9B3924F54B4015731074B4E84B40412C9B3924F54B405F28603B18E74B409D9FE238F0F24B405F28603B18E74B40
10265	Мата	7	61	607	56.199646000000001	56.231177000000002	56.076211999999998	56.062499000000003	0103000020E610000001000000050000007C6308008E194C4030849CF7FF074C407C6308008E194C4008C89750C1094C40304B3B35971D4C4008C89750C1094C40304B3B35971D4C4030849CF7FF074C407C6308008E194C4030849CF7FF074C40
58798	Магашлы-Алмантаево	7	61	607	55.986691999999998	55.998036999999997	56.132649000000001	56.118636000000002	0103000020E61000000100000005000000C79C67EC4BFE4B406B10E6762F0F4C40C79C67EC4BFE4B406E6C76A4FA104C40569929ADBFFF4B406E6C76A4FA104C40569929ADBFFF4B406B10E6762F0F4C40C79C67EC4BFE4B406B10E6762F0F4C40
8805	Курачево	7	61	607	56.283926000000001	56.313229	55.917006000000001	55.900041999999999	0103000020E61000000100000005000000F73DEAAF57244C406283859334F34B40F73DEAAF57244C402E1EDE7360F54B4053944BE317284C402E1EDE7360F54B4053944BE317284C406283859334F34B40F73DEAAF57244C406283859334F34B40
8905	Кунтугушево	7	61	607	56.054747999999996	56.079506000000002	55.970841	55.958793999999997	0103000020E61000000100000005000000BDC282FB01074C40EECC04C3B9FA4B40BDC282FB01074C40D74E948444FC4B40FBEAAA402D0A4C40D74E948444FC4B40FBEAAA402D0A4C40EECC04C3B9FA4B40BDC282FB01074C40EECC04C3B9FA4B40
8744	Кундашлы	7	61	607	56.175967	56.226973000000001	55.859988999999999	55.839416	0103000020E610000001000000050000006E162F1686164C409CDEC5FB71EB4B406E162F1686164C40BAF59A1E14EE4B409A0986730D1D4C40BAF59A1E14EE4B409A0986730D1D4C409CDEC5FB71EB4B406E162F1686164C409CDEC5FB71EB4B40
9848	Кумьязы	7	61	607	55.993212999999997	56.021599999999999	56.012501	56.000250000000001	0103000020E61000000100000005000000247B849A21FF4B4079E9263108004C40247B849A21FF4B406A15FDA199014C40FBCBEEC9C3024C406A15FDA199014C40FBCBEEC9C3024C4079E9263108004C40247B849A21FF4B4079E9263108004C40
29446	Кузеево	7	61	607	55.807873000000001	55.828417000000002	56.040717000000001	56.031723999999997	0103000020E610000001000000050000002429E96168E74B40C83F33880F044C402429E96168E74B4014B2F33636054C40A839799109EA4B4014B2F33636054C40A839799109EA4B40C83F33880F044C402429E96168E74B40C83F33880F044C40
9159	Кизганбашево	7	61	607	55.830824999999997	55.854073	55.760742	55.751294999999999	0103000020E610000001000000050000007FD93D7958EA4B40FC523F6F2AE04B407FD93D7958EA4B40C9586DFE5FE14B40C4B2994352ED4B40C9586DFE5FE14B40C4B2994352ED4B40FC523F6F2AE04B407FD93D7958EA4B40FC523F6F2AE04B40
58805	Иликеево	7	61	607	55.950291999999997	55.963704	56.04569	56.027332999999999	0103000020E6100000010000000500000041D3122BA3F94B40008DD2A57F034C4041D3122BA3F94B408BE07F2BD9054C401F8315A75AFB4B408BE07F2BD9054C401F8315A75AFB4B40008DD2A57F034C4041D3122BA3F94B40008DD2A57F034C40
8620	Верхнеянактаево	7	61	607	55.931409000000002	55.943635	55.959806999999998	55.949224000000001	0103000020E610000001000000050000009C19FD6838F74B40064A0A2C80F94B409C19FD6838F74B4066BCADF4DAFA4B40342E1C08C9F84B4066BCADF4DAFA4B40342E1C08C9F84B40064A0A2C80F94B409C19FD6838F74B40064A0A2C80F94B40
58796	Верхнекарышево	7	61	607	55.971617999999999	55.998001000000002	55.817050999999999	55.801763999999999	0103000020E610000001000000050000003B1A87FA5DFC4B40198EE733A0E64B403B1A87FA5DFC4B4001158E2095E84B400A302C7FBEFF4B4001158E2095E84B400A302C7FBEFF4B40198EE733A0E64B403B1A87FA5DFC4B40198EE733A0E64B40
10619	Верхнекансиярово	7	61	607	55.720790000000001	55.743239000000003	56.017904999999999	56.004997000000003	0103000020E6100000010000000500000055A4C2D842DC4B4000CADFBDA3004C4055A4C2D842DC4B40AAB706B64A024C404E0E9F7422DF4B40AAB706B64A024C404E0E9F7422DF4B4000CADFBDA3004C4055A4C2D842DC4B4000CADFBDA3004C40
47349	Богданово	7	61	607	56.056967	56.086556999999999	55.853682999999997	55.837566000000002	0103000020E61000000100000005000000C2F9D4B14A074C40EB1ED95C35EB4B40C2F9D4B14A074C4059130B7C45ED4B40B41EBE4C140B4C4059130B7C45ED4B40B41EBE4C140B4C40EB1ED95C35EB4B40C2F9D4B14A074C40EB1ED95C35EB4B40
10408	Асавка	7	61	607	56.097875999999999	56.116973999999999	56.147385	56.128906999999998	0103000020E610000001000000050000001A886533870C4C40DC9C4A0680104C401A886533870C4C40E275FD82DD124C40BC3D0801F90E4C40E275FD82DD124C40BC3D0801F90E4C40DC9C4A0680104C401A886533870C4C40DC9C4A0680104C40
6683	Юльтимировка	7	61	846	53.627042000000003	53.672865000000002	55.142854	55.131495999999999	0103000020E61000000100000005000000F69B89E942D04A4004C765DCD4904B40F69B89E942D04A40280D350A49924B40C0CFB87020D64A40280D350A49924B40C0CFB87020D64A4004C765DCD4904B40F69B89E942D04A4004C765DCD4904B40
58820	Шарашли	7	61	846	53.758034000000002	53.787283000000002	55.228613000000003	55.219467999999999	0103000020E61000000100000005000000C7A0134207E14A405F420587179C4B40C7A0134207E14A406138D730439D4B4030D978B0C5E44A406138D730439D4B4030D978B0C5E44A405F420587179C4B40C7A0134207E14A405F420587179C4B40
7347	Утарово	7	61	846	53.746212	53.798718999999998	55.008097999999997	54.994495999999998	0103000020E61000000100000005000000FEF0F3DF83DF4A405C001AA54B7F4B40FEF0F3DF83DF4A40DD94F25A09814B40CFD8976C3CE64A40DD94F25A09814B40CFD8976C3CE64A405C001AA54B7F4B40FEF0F3DF83DF4A405C001AA54B7F4B40
6808	Устюмово	7	61	846	53.718328999999997	53.728721999999998	54.999763999999999	54.992930999999999	0103000020E610000001000000050000005A626534F2DB4A40A017EE5C187F4B405A626534F2DB4A40ECDB4944F87F4B4017F032C346DD4A40ECDB4944F87F4B4017F032C346DD4A40A017EE5C187F4B405A626534F2DB4A40A017EE5C187F4B40
47608	Урманаево	7	61	846	53.520600999999999	53.537739999999999	54.931556999999998	54.921877000000002	0103000020E61000000100000005000000E8A1B60DA3C24A40A1F7C61000764B40E8A1B60DA3C24A4010AE80423D774B4022E010AAD4C44A4010AE80423D774B4022E010AAD4C44A40A1F7C61000764B40E8A1B60DA3C24A40A1F7C61000764B40
6417	Токбердино	7	61	846	53.874788000000002	53.894452000000001	55.145888999999997	55.129201000000002	0103000020E6100000010000000500000075779D0DF9EF4A4025CE8AA889904B4075779D0DF9EF4A404EECA17DAC924B40C0EB33677DF24A404EECA17DAC924B40C0EB33677DF24A4025CE8AA889904B4075779D0DF9EF4A4025CE8AA889904B40
8170	Тактагулово	7	61	846	54.182830000000003	54.207659	55.232880000000002	55.214584000000002	0103000020E61000000100000005000000255D33F966174B40581F0F7D779B4B40255D33F966174B403DF20703CF9D4B402BDCF291941A4B403DF20703CF9D4B402BDCF291941A4B40581F0F7D779B4B40255D33F966174B40581F0F7D779B4B40
7984	Старые Маты	7	61	846	53.924950000000003	53.961061999999998	55.243704999999999	55.224516000000001	0103000020E61000000100000005000000B537F8C264F64A40E1B6B6F0BC9C4B40B537F8C264F64A40936FB6B9319F4B40D4B6611404FB4A40936FB6B9319F4B40D4B6611404FB4A40E1B6B6F0BC9C4B40B537F8C264F64A40E1B6B6F0BC9C4B40
6359	Старокуяново	7	61	846	53.824401999999999	53.867674000000001	55.124417999999999	55.100999000000002	0103000020E61000000100000005000000E560360186E94A40E0F60489ED8C4B40E560360186E94A405184D4EDEC8F4B4075CB0EF10FEF4A405184D4EDEC8F4B4075CB0EF10FEF4A40E0F60489ED8C4B40E560360186E94A40E0F60489ED8C4B40
7640	Старокуручево	7	61	846	54.039935	54.085614	55.148287000000003	55.126303	0103000020E610000001000000050000009E7B0F971C054B407F315BB22A904B409E7B0F971C054B4003B68311FB924B40350A4966F50A4B4003B68311FB924B40350A4966F50A4B407F315BB22A904B409E7B0F971C054B407F315BB22A904B40
58776	Старокостеевко	7	61	846	53.622281000000001	53.671877000000002	55.212195000000001	55.195298000000001	0103000020E610000001000000050000000AF65FE7A6CF4A40B37C5D86FF984B400AF65FE7A6CF4A40F7AFAC34299B4B40A1F7C61000D64A40F7AFAC34299B4B40A1F7C61000D64A40B37C5D86FF984B400AF65FE7A6CF4A40B37C5D86FF984B40
7455	Старокатаево	7	61	846	53.894981999999999	53.960766	55.183312999999998	55.171498999999997	0103000020E610000001000000050000001C412AC58EF24A40FA25E2ADF3954B401C412AC58EF24A4040F7E5CC76974B40EB8D5A61FAFA4A4040F7E5CC76974B40EB8D5A61FAFA4A40FA25E2ADF3954B401C412AC58EF24A40FA25E2ADF3954B40
6987	Староиликово	7	61	846	53.854495	53.873117000000001	55.331684000000003	55.319443	0103000020E610000001000000050000003ACC971760ED4A40D3F71A82E3A84B403ACC971760ED4A40A14D0E9F74AA4B40734A404CC2EF4A40A14D0E9F74AA4B40734A404CC2EF4A40D3F71A82E3A84B403ACC971760ED4A40D3F71A82E3A84B40
6712	Старое Азмеево	7	61	846	53.547441999999997	53.585090999999998	55.162483999999999	55.153339000000003	0103000020E61000000100000005000000793A579412C64A40C619C39CA0934B40793A579412C64A40C70F9546CC944B408B170B43E4CA4A40C70F9546CC944B408B170B43E4CA4A40C619C39CA0934B40793A579412C64A40C619C39CA0934B40
58804	Сосновая	7	61	846	53.157313000000002	54.240223	55.359389	54.879680999999998	0103000020E610000001000000050000002A1E17D522944A40CFF4126399704B402A1E17D522944A4065C5707500AE4B409E5F94A0BF1E4B4065C5707500AE4B409E5F94A0BF1E4B40CFF4126399704B402A1E17D522944A40CFF4126399704B40
7178	Новый Тумутук	7	61	846	53.353397000000001	53.378999	55.047167000000002	55.029420000000002	0103000020E6100000010000000500000094C0E61C3CAD4A4096ECD808C4834B4094C0E61C3CAD4A40A839799109864B40BD1B0B0A83B04A40A839799109864B40BD1B0B0A83B04A4096ECD808C4834B4094C0E61C3CAD4A4096ECD808C4834B40
8006	Новые Маты	7	61	846	54.032927999999998	54.054935999999998	55.259315000000001	55.247338999999997	0103000020E61000000100000005000000B48F15FC36044B403E03EACDA89F4B40B48F15FC36044B405E2EE23B31A14B40C0AF912408074B405E2EE23B31A14B40C0AF912408074B403E03EACDA89F4B40B48F15FC36044B403E03EACDA89F4B40
6293	Новые Балыклы	7	61	846	53.762408999999998	53.790984000000002	55.140965000000001	55.125571999999998	0103000020E6100000010000000500000089963C9E96E14A408BA548BE12904B4089963C9E96E14A40B97020240B924B4063D4B5F63EE54A40B97020240B924B4063D4B5F63EE54A408BA548BE12904B4089963C9E96E14A408BA548BE12904B40
7169	Новосасыкуль	7	61	846	53.431199999999997	53.455356000000002	55.008778999999997	54.992255	0103000020E610000001000000050000008104C58F31B74A4070253B36027F4B408104C58F31B74A401FF296AB1F814B40C904FC1A49BA4A401FF296AB1F814B40C904FC1A49BA4A4070253B36027F4B408104C58F31B74A4070253B36027F4B40
58377	Новоиликово	7	61	846	53.874456000000002	53.895251999999999	55.353161	55.33446	0103000020E610000001000000050000003FE5982CEEEF4A40FBE8D495CFAA4B403FE5982CEEEF4A40809C306134AD4B40DCD6169E97F24A40809C306134AD4B40DCD6169E97F24A40FBE8D495CFAA4B403FE5982CEEEF4A40FBE8D495CFAA4B40
6888	Новоальметьево	7	61	846	53.722406999999997	53.750911000000002	55.293556000000002	55.281303000000001	0103000020E6100000010000000500000063B323D577DC4A4023A298BC01A44B4063B323D577DC4A40B5C5353E93A54B40749A05DA1DE04A40B5C5353E93A54B40749A05DA1DE04A4023A298BC01A44B4063B323D577DC4A4023A298BC01A44B40
8154	Новоагбязово	7	61	846	53.691693999999998	53.718428000000003	55.276021	55.267020000000002	0103000020E61000000100000005000000726BD26D89D84A4060B01BB62DA24B40726BD26D89D84A402E01F8A754A34B40EE43DE72F5DB4A402E01F8A754A34B40EE43DE72F5DB4A4060B01BB62DA24B40726BD26D89D84A4060B01BB62DA24B40
7532	Нагайбаково	7	61	846	53.258902999999997	53.274211000000001	55.166463999999998	55.147658999999997	0103000020E610000001000000050000000BEBC6BB23A14A40E3FA777DE6924B400BEBC6BB23A14A400DFB3DB14E954B400B9A965819A34A400DFB3DB14E954B400B9A965819A34A40E3FA777DE6924B400BEBC6BB23A14A40E3FA777DE6924B40
7379	Мустафино	7	61	846	53.582863000000003	53.633949999999999	55.028480999999999	55.009647000000001	0103000020E61000000100000005000000348639419BCA4A4094C0E61C3C814B40348639419BCA4A4058C7F143A5834B404CA60A4625D14A4058C7F143A5834B404CA60A4625D14A4094C0E61C3C814B40348639419BCA4A4094C0E61C3C814B40
8330	Мирзаитово	7	61	846	53.609884000000001	53.634425999999998	54.965791000000003	54.952677000000001	0103000020E61000000100000005000000452DCDAD10CE4A406153E751F1794B40452DCDAD10CE4A40B5E21B0A9F7B4B40B5DD04DF34D14A40B5E21B0A9F7B4B40B5DD04DF34D14A406153E751F1794B40452DCDAD10CE4A406153E751F1794B40
7077	Куштиряково	7	61	846	53.391790999999998	53.431569000000003	55.031221000000002	55.006435000000003	0103000020E61000000100000005000000FEEE1D3526B24A405F46B1DCD2804B40FEEE1D3526B24A4066F9BA0CFF834B40D57B2AA73DB74A4066F9BA0CFF834B40D57B2AA73DB74A405F46B1DCD2804B40FEEE1D3526B24A405F46B1DCD2804B40
32117	Курчеево	7	61	846	53.481262999999998	53.509757999999998	55.076673999999997	55.062193999999998	0103000020E610000001000000050000002EE3A6069ABD4A40F30016F9F5874B402EE3A6069ABD4A400C3A2174D0894B40EB6F09C03FC14A400C3A2174D0894B40EB6F09C03FC14A40F30016F9F5874B402EE3A6069ABD4A40F30016F9F5874B40
7836	Килькабызово	7	61	846	53.981706000000003	53.996932000000001	55.158796000000002	55.142431999999999	0103000020E61000000100000005000000BC24CE8AA8FD4A40B2F336363B924B40BC24CE8AA8FD4A40295E656D53944B40FE2AC0779BFF4A40295E656D53944B40FE2AC0779BFF4A40B2F336363B924B40BC24CE8AA8FD4A40B2F336363B924B40
47020	Килеево	7	61	846	53.812283999999998	53.857289000000002	55.289332000000002	55.277251999999997	0103000020E6100000010000000500000033880FECF8E74A40136058FE7CA34B4033880FECF8E74A40D8D7BAD408A54B403B1C5DA5BBED4A40D8D7BAD408A54B403B1C5DA5BBED4A40136058FE7CA34B4033880FECF8E74A40136058FE7CA34B40
6784	Камышлытамак	7	61	846	53.704467999999999	53.740149000000002	55.045361999999997	55.020048000000003	0103000020E610000001000000050000000D8AE6012CDA4A40D42CD0EE90824B400D8AE6012CDA4A40963D096CCE854B406495D233BDDE4A40963D096CCE854B406495D233BDDE4A40D42CD0EE90824B400D8AE6012CDA4A40D42CD0EE90824B40
7718	Камаево	7	61	846	54.201757000000001	54.216957000000001	55.196387000000001	55.177230999999999	0103000020E610000001000000050000009A5E622CD3194B402F6B6281AF964B409A5E622CD3194B40062E8F3523994B40B3D1393FC51B4B40062E8F3523994B40B3D1393FC51B4B402F6B6281AF964B409A5E622CD3194B402F6B6281AF964B40
6624	Дияшево	7	61	846	53.643130999999997	53.673943000000001	55.088428999999998	55.074235999999999	0103000020E610000001000000050000009A05DA1D52D24A40CA17B49080894B409A05DA1D52D24A404D8237A4518B4B401F2FA4C343D64A404D8237A4518B4B401F2FA4C343D64A40CA17B49080894B409A05DA1D52D24A40CA17B49080894B40
58761	Гурдыбашево	7	61	846	54.084069	54.093356999999997	55.218364000000001	55.204355999999997	0103000020E61000000100000005000000C0CDE2C5C20A4B40E55E6056289A4B40C0CDE2C5C20A4B40D74FFF59F39B4B4024ED461FF30B4B40D74FFF59F39B4B4024ED461FF30B4B40E55E6056289A4B40C0CDE2C5C20A4B40E55E6056289A4B40
7284	Бугабашево	7	61	846	53.907361000000002	53.936143000000001	55.063684000000002	55.049111000000003	0103000020E610000001000000050000003B55BE6724F44A40DB6FED4449864B403B55BE6724F44A40A5A31CCC26884B408EB0A888D3F74A40A5A31CCC26884B408EB0A888D3F74A40DB6FED4449864B403B55BE6724F44A40DB6FED4449864B40
47484	Балчиклы	7	61	846	54.076864	54.095846000000002	55.080787000000001	55.066251999999999	0103000020E61000000100000005000000B01EF7ADD6094B40B5A50EF27A884B40B01EF7ADD6094B409278793A578A4B40E9B985AE440C4B409278793A578A4B40E9B985AE440C4B40B5A50EF27A884B40B01EF7ADD6094B40B5A50EF27A884B40
32794	Бакалы	7	61	846	53.782792000000001	53.818373999999999	55.194614000000001	55.161234	0103000020E6100000010000000500000004C93B8732E44A406B80D250A3944B4004C93B8732E44A4000AC8E1CE9984B40C7F2AE7AC0E84A4000AC8E1CE9984B40C7F2AE7AC0E84A406B80D250A3944B4004C93B8732E44A406B80D250A3944B40
46850	Ахманово	7	61	846	53.697569000000001	53.743732999999999	55.150782	55.133529000000003	0103000020E610000001000000050000000ADAE4F049D94A40A708707A17914B400ADAE4F049D94A40A96917D34C934B405DFA97A432DF4A40A96917D34C934B405DFA97A432DF4A40A708707A17914B400ADAE4F049D94A40A708707A17914B40
2687	Яратово	7	61	322	57.955466000000001	57.97231	52.572822000000002	52.559499000000002	0103000020E610000001000000050000005038BBB54CFA4C408692C9A99D474A405038BBB54CFA4C40F436363B52494A4071C971A774FC4C40F436363B52494A4071C971A774FC4C408692C9A99D474A405038BBB54CFA4C408692C9A99D474A40
5127	Янзигитово	7	61	322	58.583182000000001	58.597940999999999	52.624622000000002	52.616174999999998	0103000020E61000000100000005000000D5CE30B5A54A4D4070CE88D2DE4E4A40D5CE30B5A54A4D405A2E1B9DF34F4A4001F8A754894C4D405A2E1B9DF34F4A4001F8A754894C4D4070CE88D2DE4E4A40D5CE30B5A54A4D4070CE88D2DE4E4A40
5766	Янгазино	7	61	322	58.479678	58.492012000000003	52.357627000000001	52.352775000000001	0103000020E610000001000000050000002B4EB516663D4D4057EC2FBB272D4A402B4EB516663D4D405395B6B8C62D4A40AA9ECC3FFA3E4D405395B6B8C62D4A40AA9ECC3FFA3E4D4057EC2FBB272D4A402B4EB516663D4D4057EC2FBB272D4A40
2347	Юмашево	7	61	322	57.930636999999997	57.951577	52.513382	52.500610000000002	0103000020E6100000010000000500000049B9FB1C1FF74C4079060DFD13404A4049B9FB1C1FF74C40732D5A80B6414A401A506F46CDF94C40732D5A80B6414A401A506F46CDF94C4079060DFD13404A4049B9FB1C1FF74C4079060DFD13404A40
2413	Юлук	7	61	322	57.789197000000001	57.801296999999998	52.524571999999999	52.513623000000003	0103000020E61000000100000005000000F88C446804E54C4099BC0166BE414A40F88C446804E54C40DB32E02C25434A4003B16CE690E64C40DB32E02C25434A4003B16CE690E64C4099BC0166BE414A40F88C446804E54C4099BC0166BE414A40
2996	Шулька	7	61	322	57.704234	57.724069	52.694626	52.685991000000001	0103000020E610000001000000050000009A5DF75624DA4C40D82C978DCE574A409A5DF75624DA4C40C4793881E9584A401286014BAEDC4C40C4793881E9584A401286014BAEDC4C40D82C978DCE574A409A5DF75624DA4C40D82C978DCE574A40
58651	Уральское	7	61	322	58.890217	58.904859999999999	52.280206	52.270313999999999	0103000020E61000000100000005000000EFAB72A1F2714D4052D32EA699224A40EFAB72A1F2714D404D124BCADD234A40B2BAD573D2734D404D124BCADD234A40B2BAD573D2734D4052D32EA699224A40EFAB72A1F2714D4052D32EA699224A40
4255	Уметбаево	7	61	322	58.169741000000002	58.195793000000002	53.136251999999999	53.123176999999998	0103000020E610000001000000050000002AE5B512BA154D40484F9143C48F4A402AE5B512BA154D40DE019EB470914A4093E4B9BE0F194D40DE019EB470914A4093E4B9BE0F194D40484F9143C48F4A402AE5B512BA154D40484F9143C48F4A40
58510	Туркменево 2-е	7	61	322	58.507660999999999	58.528151000000001	52.880175999999999	52.866159000000003	0103000020E61000000100000005000000323A2009FB404D406B11514CDE6E4A40323A2009FB404D40AF5C6F9BA9704A40C32CB4739A434D40AF5C6F9BA9704A40C32CB4739A434D406B11514CDE6E4A40323A2009FB404D406B11514CDE6E4A40
4589	Туркменево 1-е	7	61	322	58.507660999999999	58.528151000000001	52.880175999999999	52.866159000000003	0103000020E61000000100000005000000323A2009FB404D406B11514CDE6E4A40323A2009FB404D40AF5C6F9BA9704A40C32CB4739A434D40AF5C6F9BA9704A40C32CB4739A434D406B11514CDE6E4A40323A2009FB404D406B11514CDE6E4A40
4348	Тубинский	7	61	322	58.208359999999999	58.242818999999997	52.907812999999997	52.878329000000001	0103000020E61000000100000005000000B4E55C8AAB1A4D406F10AD156D704A40B4E55C8AAB1A4D401BF1643733744A4078EC67B1141F4D401BF1643733744A4078EC67B1141F4D406F10AD156D704A40B4E55C8AAB1A4D406F10AD156D704A40
3809	Темясово	7	61	322	58.081086999999997	58.139539999999997	53.001786000000003	52.977967999999997	0103000020E61000000100000005000000BC900E0F610A4D406B44300E2E7D4A40BC900E0F610A4D409BCB0D863A804A40EE3D5C72DC114D409BCB0D863A804A40EE3D5C72DC114D406B44300E2E7D4A40BC900E0F610A4D406B44300E2E7D4A40
5001	Татлыбаево	7	61	322	58.586936999999999	58.606986999999997	52.581135000000003	52.570348000000003	0103000020E61000000100000005000000FBE769C0204B4D4065ABCB2901494A40FBE769C0204B4D40CEC7B5A1624A4A406F0C01C0B14D4D40CEC7B5A1624A4A406F0C01C0B14D4D4065ABCB2901494A40FBE769C0204B4D4065ABCB2901494A40
4883	Старый Сибай	7	61	322	58.545507000000001	58.576867	52.715175000000002	52.699717999999997	0103000020E610000001000000050000009A5E622CD3454D401536035C90594A409A5E622CD3454D405AF5B9DA8A5B4A40219221C7D6494D405AF5B9DA8A5B4A40219221C7D6494D401536035C90594A409A5E622CD3454D401536035C90594A40
3954	Сакмар	7	61	322	58.131374000000001	58.150588999999997	52.830655999999998	52.816980999999998	0103000020E61000000100000005000000B9C5FCDCD0104D40083A5AD592684A40B9C5FCDCD0104D40F31C91EF526A4A409411178046134D40F31C91EF526A4A409411178046134D40083A5AD592684A40B9C5FCDCD0104D40083A5AD592684A40
58540	Покровка	7	61	322	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
2872	Первое Иткулово	7	61	322	57.934634000000003	57.982030000000002	52.641204000000002	52.620942999999997	0103000020E6100000010000000500000066DD3F16A2F74C400ED76A0F7B4F4A4066DD3F16A2F74C403E0801F912524A406FD8B628B3FD4C403E0801F912524A406FD8B628B3FD4C400ED76A0F7B4F4A4066DD3F16A2F74C400ED76A0F7B4F4A40
58746	Октябрь	7	61	322	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
4012	Нижнетагирово	7	61	322	58.157604999999997	58.171556000000002	53.046190000000003	53.027996000000002	0103000020E61000000100000005000000D15790662C144D409C35785F95834A40D15790662C144D407DB3CD8DE9854A405FB7088CF5154D407DB3CD8DE9854A405FB7088CF5154D409C35785F95834A40D15790662C144D409C35785F95834A40
61546	Нижнетавлыкаево	7	61	322	58.064988999999997	58.079605000000001	52.699297000000001	52.686366999999997	0103000020E61000000100000005000000C4CC3E8F51084D40DD06B5DFDA574A40C4CC3E8F51084D407098689082594A408ECC237F300A4D407098689082594A408ECC237F300A4D40DD06B5DFDA574A40C4CC3E8F51084D40DD06B5DFDA574A40
3450	Нигаматово	7	61	322	58.027861999999999	58.069704999999999	52.794820000000001	52.784047999999999	0103000020E610000001000000050000008C6665FB90034D40423F53AF5B644A408C6665FB90034D40761A69A9BC654A4010AFEB17EC084D40761A69A9BC654A4010AFEB17EC084D40423F53AF5B644A408C6665FB90034D40423F53AF5B644A40
58598	Муллакаево	7	61	322	58.091777	58.113202000000001	52.904021999999998	52.893445	0103000020E6100000010000000500000033C34659BF0B4D402AE3DF675C724A4033C34659BF0B4D40A86E2EFEB6734A40C0EB33677D0E4D40A86E2EFEB6734A40C0EB33677D0E4D402AE3DF675C724A4033C34659BF0B4D402AE3DF675C724A40
4376	Мерясово	7	61	322	58.307839000000001	58.327970999999998	52.687354999999997	52.676375999999998	0103000020E6100000010000000500000078B7B24467274D404FE61F7D93564A4078B7B24467274D40FCDEA63FFB574A40A98427F4FA294D40FCDEA63FFB574A40A98427F4FA294D404FE61F7D93564A4078B7B24467274D404FE61F7D93564A40
3288	Куянтаево	7	61	322	58.162635999999999	58.188543000000003	52.672280999999998	52.659194999999997	0103000020E610000001000000050000007D93A641D1144D40E657738060544A407D93A641D1144D40705CC64D0D564A40E371512D22184D40705CC64D0D564A40E371512D22184D40E657738060544A407D93A641D1144D40E657738060544A40
3617	Кульчурово	7	61	322	58.065266999999999	58.081454999999998	52.934683	52.920324000000001	0103000020E61000000100000005000000074147AB5A084D40A9DC442DCD754A40074147AB5A084D4047904AB1A3774A403F8C101E6D0A4D4047904AB1A3774A403F8C101E6D0A4D40A9DC442DCD754A40074147AB5A084D40A9DC442DCD754A40
58852	Культубанское	7	61	322	58.694806999999997	58.704552999999997	52.634974	52.621675000000003	0103000020E6100000010000000500000014048F6FEF584D40D3DEE00B934F4A4014048F6FEF584D40B8E7F9D346514A403BA6EECA2E5A4D40B8E7F9D346514A403BA6EECA2E5A4D40D3DEE00B934F4A4014048F6FEF584D40D3DEE00B934F4A40
58716	Кугидель	7	61	322	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
2596	Крепостной Зилаир	7	61	322	57.670699999999997	57.691280999999996	52.423672000000003	52.414296	0103000020E61000000100000005000000AEB6627FD9D54C408B6EBDA607354A40AEB6627FD9D54C408F1D54E23A364A404FAC53E57BD84C408F1D54E23A364A404FAC53E57BD84C408B6EBDA607354A40AEB6627FD9D54C408B6EBDA607354A40
5016	Карышкино	7	61	322	58.601571	58.619833	52.531523999999997	52.523437999999999	0103000020E610000001000000050000006B9C4D47004D4D40E8BD310400434A406B9C4D47004D4D4001857AFA08444A40A4FD0FB0564F4D4001857AFA08444A40A4FD0FB0564F4D40E8BD310400434A406B9C4D47004D4D40E8BD310400434A40
2189	Каратал	7	61	322	58.106428000000001	58.121142999999996	52.630541999999998	52.619816	0103000020E6100000010000000500000079B0C56E9F0D4D40CEC47421564F4A4079B0C56E9F0D4D409160AA99B5504A40D591239D810F4D409160AA99B5504A40D591239D810F4D40CEC47421564F4A4079B0C56E9F0D4D40CEC47421564F4A40
4914	Калинино	7	61	322	58.738985999999997	58.762045999999998	52.715741999999999	52.708371999999997	0103000020E61000000100000005000000D619DF17975E4D4078B306EFAB5A4A40D619DF17975E4D40D32F116F9D5B4A4018062CB98A614D40D32F116F9D5B4A4018062CB98A614D4078B306EFAB5A4A40D619DF17975E4D4078B306EFAB5A4A40
4777	Казанка	7	61	322	58.721882000000001	58.734926000000002	52.792903000000003	52.780137000000003	0103000020E6100000010000000500000019C91EA1665C4D4025B37A87DB634A4019C91EA1665C4D403DF372D87D654A40747D1F0E125E4D403DF372D87D654A40747D1F0E125E4D4025B37A87DB634A4019C91EA1665C4D4025B37A87DB634A40
5754	Ишмухаметово	7	61	322	58.457920999999999	58.476148000000002	52.392670000000003	52.383502999999997	0103000020E610000001000000050000006893C3279D3A4D407D7555A016314A406893C3279D3A4D40670FB40243324A402507EC6AF23C4D40670FB40243324A402507EC6AF23C4D407D7555A016314A406893C3279D3A4D407D7555A016314A40
4118	Ишей	7	61	322	57.835487000000001	57.859670000000001	52.966774999999998	52.952449000000001	0103000020E61000000100000005000000D89DEE3CF1EA4C40D00D4DD9E9794A40D89DEE3CF1EA4C4092CB7F48BF7B4A4019ADA3AA09EE4C4092CB7F48BF7B4A4019ADA3AA09EE4C40D00D4DD9E9794A40D89DEE3CF1EA4C40D00D4DD9E9794A40
2474	Ишберда	7	61	322	57.652689000000002	57.666784	52.490758	52.474930000000001	0103000020E61000000100000005000000BFBA2A508BD34C40D4F19881CA3C4A40BFBA2A508BD34C400C207C28D13E4A407FBF982D59D54C400C207C28D13E4A407FBF982D59D54C40D4F19881CA3C4A40BFBA2A508BD34C40D4F19881CA3C4A40
3560	Исяново	7	61	322	58.240240999999997	58.249116999999998	52.822662999999999	52.816203000000002	0103000020E6100000010000000500000044149337C01E4D40D4F2035779684A4044149337C01E4D408B506C054D694A4056F0DB10E31F4D408B506C054D694A4056F0DB10E31F4D40D4F2035779684A4044149337C01E4D40D4F2035779684A40
4561	Исянбетово	7	61	322	58.369922000000003	58.386307000000002	52.929910999999997	52.920036000000003	0103000020E610000001000000050000001409A69A592F4D40439259BDC3754A401409A69A592F4D406798DA5207774A40A29BFD8172314D406798DA5207774A40A29BFD8172314D40439259BDC3754A401409A69A592F4D40439259BDC3754A40
58791	Зелимово	7	61	322	57.681345	57.692259999999997	52.600873999999997	52.583799999999997	0103000020E6100000010000000500000085251E5036D74C40D0B359F5B94A4A4085251E5036D74C4023827170E94C4A401B2AC6F99BD84C4023827170E94C4A401B2AC6F99BD84C40D0B359F5B94A4A4085251E5036D74C40D0B359F5B94A4A40
2747	Гумерово	7	61	322	57.951225999999998	57.976576999999999	52.590468999999999	52.581288000000001	0103000020E610000001000000050000006D8D08C6C1F94C4054C72AA5674A4A406D8D08C6C1F94C40A226FA7C944B4A404D83A27900FD4C40A226FA7C944B4A404D83A27900FD4C4054C72AA5674A4A406D8D08C6C1F94C4054C72AA5674A4A40
2938	Гадельбаево	7	61	322	57.920234000000001	57.941173999999997	52.618608000000002	52.609056000000002	0103000020E6100000010000000500000069554B3ACAF54C405FB7088CF54D4A4069554B3ACAF54C40A185048C2E4F4A4039ECBE6378F84C40A185048C2E4F4A4039ECBE6378F84C405FB7088CF54D4A4069554B3ACAF54C405FB7088CF54D4A40
58192	Второе Иткулово	7	61	322	57.960551000000002	57.991615000000003	52.837477999999997	52.813057000000001	0103000020E61000000100000005000000EF91CD55F3FA4C405664744012684A40EF91CD55F3FA4C404B8FA67A326B4A408D9C853DEDFE4C404B8FA67A326B4A408D9C853DEDFE4C405664744012684A40EF91CD55F3FA4C405664744012684A40
58853	Верхне-Яикбаево	7	61	322	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
2527	Бурзян-Елга	7	61	322	57.553713000000002	57.562831000000003	52.409638000000001	52.400830999999997	0103000020E610000001000000050000005E2F4D11E0C64C408A1C226E4E334A405E2F4D11E0C64C4074999A046F344A406616A1D80AC84C4074999A046F344A406616A1D80AC84C408A1C226E4E334A405E2F4D11E0C64C408A1C226E4E334A40
3163	Буранбаево	7	61	322	57.988101999999998	58.007578000000002	52.643695999999998	52.633569999999999	0103000020E610000001000000050000005C8E57207AFE4C4005DD5ED218514A405C8E57207AFE4C4073486AA164524A40A515DF50F8004D4073486AA164524A40A515DF50F8004D4005DD5ED218514A405C8E57207AFE4C4005DD5ED218514A40
58666	Большебасаево	7	61	322	58.419077999999999	58.437322999999999	52.905639999999998	52.898313000000002	0103000020E610000001000000050000008E3C1059A4354D402C499EEBFB724A408E3C1059A4354D4087F9F202EC734A40F1643733FA374D4087F9F202EC734A40F1643733FA374D402C499EEBFB724A408E3C1059A4354D402C499EEBFB724A40
4172	Билялово	7	61	322	58.208917	58.231347999999997	53.084977000000002	53.071500999999998	0103000020E610000001000000050000000A4AD1CABD1A4D40CE50DCF126894A400A4AD1CABD1A4D40C3F4BD86E08A4A405CFFAECF9C1D4D40C3F4BD86E08A4A405CFFAECF9C1D4D40CE50DCF126894A400A4AD1CABD1A4D40CE50DCF126894A40
58879	Бетеря	7	61	322	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
3226	Бекешево	7	61	322	58.071384999999999	58.102215000000001	52.749290000000002	52.729771	0103000020E610000001000000050000006536C82423094D40DC48D922695D4A406536C82423094D40249C16BCE85F4A4090149161150D4D40249C16BCE85F4A4090149161150D4D40DC48D922695D4A406536C82423094D40DC48D922695D4A40
47212	Баймурзино	7	61	322	58.425240000000002	58.441706000000003	52.437233999999997	52.434176000000001	0103000020E61000000100000005000000BC79AA436E364D40A35A441493374A40BC79AA436E364D408159A148F7374A4037397CD289384D408159A148F7374A4037397CD289384D40A35A441493374A40BC79AA436E364D40A35A441493374A40
1475	Баймак	7	61	322	58.282525	58.343341000000002	52.612741	52.564118999999998	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
5837	Баишево	7	61	322	58.510534999999997	58.534061999999999	52.479098	52.46472	0103000020E610000001000000050000004F3BFC3559414D4008E6E8F17B3B4A404F3BFC3559414D401DCA5015533D4A40A704C4245C444D401DCA5015533D4A40A704C4245C444D4008E6E8F17B3B4A404F3BFC3559414D4008E6E8F17B3B4A40
3392	Баимово	7	61	322	57.982694000000002	58.005431000000002	52.871974999999999	52.859363000000002	0103000020E61000000100000005000000DBFCBFEAC8FD4C403C32569BFF6D4A40DBFCBFEAC8FD4C40FDF675E09C6F4A403AB187F6B1004D40FDF675E09C6F4A403AB187F6B1004D403C32569BFF6D4A40DBFCBFEAC8FD4C403C32569BFF6D4A40
4712	Ахмерово	7	61	322	58.520417000000002	58.532283999999997	52.838484999999999	52.828598999999997	0103000020E6100000010000000500000027A435069D424D40C83F33880F6A4A4027A435069D424D40E197FA79536B4A408F17D2E121444D40E197FA79536B4A408F17D2E121444D40C83F33880F6A4A4027A435069D424D40C83F33880F6A4A40
3900	Аминево	7	61	322	58.072068000000002	58.086638000000001	52.973337000000001	52.966867000000001	0103000020E61000000100000005000000488B338639094D40734A404CC27B4A40488B338639094D404E7E8B4E967C4A40A14B38F4160B4D404E7E8B4E967C4A40A14B38F4160B4D40734A404CC27B4A40488B338639094D40734A404CC27B4A40
2003	Алгазино	7	61	322	57.801495000000003	57.819704000000002	52.460034	52.448504	0103000020E610000001000000050000002A745E6397E64C4006103E9468394A402A745E6397E64C402786E464E23A4A404033880FECE84C402786E464E23A4A404033880FECE84C4006103E9468394A402A745E6397E64C4006103E9468394A40
2141	Актау	7	61	322	58.156213000000001	58.181482000000003	52.577638	52.567464000000001	0103000020E61000000100000005000000E31A9FC9FE134D4024D40CA9A2484A40E31A9FC9FE134D40A376BF0AF0494A4006685BCD3A174D40A376BF0AF0494A4006685BCD3A174D4024D40CA9A2484A40E31A9FC9FE134D4024D40CA9A2484A40
2067	Акмурун	7	61	322	58.114539999999998	58.140115000000002	52.545420999999997	52.528379999999999	0103000020E61000000100000005000000BB0A293FA90E4D4024EEB1F4A1434A40BB0A293FA90E4D409BC6F65AD0454A40EB56CF49EF114D409BC6F65AD0454A40EB56CF49EF114D4024EEB1F4A1434A40BB0A293FA90E4D4024EEB1F4A1434A40
1946	Абдулкаримово	7	61	322	57.856228999999999	57.879216999999997	52.427109000000002	52.417597000000001	0103000020E61000000100000005000000827170E998ED4C4030F488D173354A40827170E998ED4C40E469F981AB364A402A8BC22E8AF04C40E469F981AB364A402A8BC22E8AF04C4030F488D173354A40827170E998ED4C4030F488D173354A40
5094	Абдрахманово	7	61	322	58.616959000000001	58.631996999999998	52.560457	52.552370000000003	0103000020E6100000010000000500000087FC3383F84E4D4051A5660FB4464A4087FC3383F84E4D403AE8120EBD474A40C6151747E5504D403AE8120EBD474A40C6151747E5504D4051A5660FB4464A4087FC3383F84E4D4051A5660FB4464A40
45365	Юлдашево	7	61	55	55.646552999999997	55.654179999999997	53.918444999999998	53.908082	0103000020E61000000100000005000000BA10AB3FC2D24B400B0BEE073CF44A40BA10AB3FC2D24B405D16139B8FF54A4040D9942BBCD34B405D16139B8FF54A4040D9942BBCD34B400B0BEE073CF44A40BA10AB3FC2D24B400B0BEE073CF44A40
786	Юламаново	7	61	55	55.819676999999999	55.837383000000003	54.038561000000001	54.027132999999999	0103000020E6100000010000000500000046240A2DEBE84B4039D2191879034B4046240A2DEBE84B4056F31C91EF044B40FA9CBB5D2FEB4B4056F31C91EF044B40FA9CBB5D2FEB4B4039D2191879034B4046240A2DEBE84B4039D2191879034B40
32463	Шланлы	7	61	55	55.654018000000001	55.68289	53.878394	53.862195999999997	0103000020E61000000100000005000000677FA0DCB6D34B40FA5E43705CEE4A40677FA0DCB6D34B405680EF366FF04A40FA6184F068D74B405680EF366FF04A40FA6184F068D74B40FA5E43705CEE4A40677FA0DCB6D34B40FA5E43705CEE4A40
67	Шеверли	7	61	55	55.675839000000003	55.698529999999998	53.897720999999997	53.886392000000001	0103000020E61000000100000005000000412E71E481D64B40D0B7054B75F14A40412E71E481D64B4059F78F85E8F24A402FA3586E69D94B4059F78F85E8F24A402FA3586E69D94B40D0B7054B75F14A40412E71E481D64B40D0B7054B75F14A40
1427	Чуваш-Карамалы	7	61	55	56.151865000000001	56.187778999999999	53.964315999999997	53.945740000000001	0103000020E610000001000000050000001A34F44F70134C40704221020EF94A401A34F44F70134C403881E9B46EFB4A4013F06B2409184C403881E9B46EFB4A4013F06B2409184C40704221020EF94A401A34F44F70134C40704221020EF94A40
32096	Утеймуллино	7	61	55	56.230179999999997	56.253509000000001	54.132503999999997	54.120657999999999	0103000020E61000000100000005000000BD18CA89761D4C401900AAB8710F4B40BD18CA89761D4C406A4B1DE4F5104B40EF1EA0FB72204C406A4B1DE4F5104B40EF1EA0FB72204C401900AAB8710F4B40BD18CA89761D4C401900AAB8710F4B40
1213	Усманово	7	61	55	55.536006999999998	55.554583999999998	54.076101000000001	54.061281000000001	0103000020E61000000100000005000000AAB69BE09BC44B40DF6E490ED8074B40AAB69BE09BC44B40B11875ADBD094B404371C79BFCC64B40B11875ADBD094B404371C79BFCC64B40DF6E490ED8074B40AAB69BE09BC44B40DF6E490ED8074B40
1153	Турумбет	7	61	55	55.511645000000001	55.534722000000002	54.019961000000002	54.001458	0103000020E61000000100000005000000BA1457957DC14B40A62897C62F004B40BA1457957DC14B40051901158E024B40D2393FC571C44B40051901158E024B40D2393FC571C44B40A62897C62F004B40BA1457957DC14B40A62897C62F004B40
936	Тукаево	7	61	55	55.810890999999998	55.832737999999999	54.224696000000002	54.210628	0103000020E6100000010000000500000074CFBA46CBE74B409ACFB9DBF51A4B4074CFBA46CBE74B4061C5A9D6C21C4B407711A62897EA4B4061C5A9D6C21C4B407711A62897EA4B409ACFB9DBF51A4B4074CFBA46CBE74B409ACFB9DBF51A4B40
844	Тряпино	7	61	55	56.161664999999999	56.190465000000003	54.092289999999998	54.081674	0103000020E6100000010000000500000034F44F70B1144C407D772B4B740A4B4034F44F70B1144C40B9DFA128D00B4B402E04392861184C40B9DFA128D00B4B402E04392861184C407D772B4B740A4B4034F44F70B1144C407D772B4B740A4B40
461	Толбазы	7	61	55	55.869318	55.919128999999998	54.033115000000002	53.978769	0103000020E610000001000000050000007DE9EDCF45EF4B4058AB764D48FD4A407DE9EDCF45EF4B40E700C11C3D044B4010E7E104A6F54B40E700C11C3D044B4010E7E104A6F54B4058AB764D48FD4A407DE9EDCF45EF4B4058AB764D48FD4A40
342	Таштамак	7	61	55	55.736690000000003	55.755932000000001	53.969664999999999	53.952798000000001	0103000020E6100000010000000500000027A5A0DB4BDE4B40DCD8EC48F5F94A4027A5A0DB4BDE4B40B58993FB1DFC4A40FCFF3861C2E04B40B58993FB1DFC4A40FCFF3861C2E04B40DCD8EC48F5F94A4027A5A0DB4BDE4B40DCD8EC48F5F94A40
32031	Татарский Нагадак	7	61	55	56.280943999999998	56.296503000000001	54.103065999999998	54.087319999999998	0103000020E61000000100000005000000F30016F9F5234C40B324404D2D0B4B40F30016F9F5234C402EAA4544310D4B403C1570CFF3254C402EAA4544310D4B403C1570CFF3254C40B324404D2D0B4B40F30016F9F5234C40B324404D2D0B4B40
274	Султанмуратово	7	61	55	55.712282999999999	55.748359999999998	54.112546999999999	54.088656999999998	0103000020E61000000100000005000000963FDF162CDB4B40DEC7D11C590B4B40963FDF162CDB4B40A721AAF0670E4B4039D1AE42CADF4B40A721AAF0670E4B4039D1AE42CADF4B40DEC7D11C590B4B40963FDF162CDB4B40DEC7D11C590B4B40
153	Степановка	7	61	55	55.678255	55.692889000000001	54.007877000000001	53.997096999999997	0103000020E610000001000000050000009BAC510FD1D64B4048F8DEDFA0FF4A409BAC510FD1D64B40FFB1101D02014B400B613596B0D84B40FFB1101D02014B400B613596B0D84B4048F8DEDFA0FF4A409BAC510FD1D64B4048F8DEDFA0FF4A40
31920	Старомакарово	7	61	55	55.874662999999998	55.908098000000003	53.903700000000001	53.886408000000003	0103000020E61000000100000005000000B8020AF5F4EF4B40D6743DD175F14A40B8020AF5F4EF4B4096B20C71ACF34A4011C8258E3CF44B4096B20C71ACF34A4011C8258E3CF44B40D6743DD175F14A40B8020AF5F4EF4B40D6743DD175F14A40
31735	Старокузяково	7	61	55	55.916677	55.932721000000001	54.261315000000003	54.248049000000002	0103000020E6100000010000000500000069FF03AC55F54B401B67D311C01F4B4069FF03AC55F54B40257A19C572214B406EA5D76663F74B40257A19C572214B406EA5D76663F74B401B67D311C01F4B4069FF03AC55F54B401B67D311C01F4B40
32297	Семенкино	7	61	55	55.670834999999997	55.721195000000002	53.825493000000002	53.800660999999998	0103000020E610000001000000050000008E01D9EBDDD54B406117450F7CE64A408E01D9EBDDD54B40D9092FC1A9E94A40F584251E50DC4B40D9092FC1A9E94A40F584251E50DC4B406117450F7CE64A408E01D9EBDDD54B406117450F7CE64A40
45948	Салихово	7	61	55	55.521562000000003	55.529502999999998	54.038952000000002	54.031326999999997	0103000020E610000001000000050000000E6B2A8BC2C24B40AB3DEC8502044B400E6B2A8BC2C24B40910E0F61FC044B4023111AC1C6C34B40910E0F61FC044B4023111AC1C6C34B40AB3DEC8502044B400E6B2A8BC2C24B40AB3DEC8502044B40
3910	Новые Карамалы	7	61	55	55.923341999999998	55.944049	54.059382999999997	54.042521000000001	0103000020E61000000100000005000000F982161230F64B405532005471054B40F982161230F64B401C78B5DC99074B402769FE98D6F84B401C78B5DC99074B402769FE98D6F84B405532005471054B40F982161230F64B405532005471054B40
31535	Новофедоровка	7	61	55	56.069471	56.090797000000002	54.122146000000001	54.107273999999997	0103000020E610000001000000050000009D82FC6CE4084C4005DB8827BB0D4B409D82FC6CE4084C402AABE97AA20F4B4097C9703C9F0B4C402AABE97AA20F4B4097C9703C9F0B4C4005DB8827BB0D4B409D82FC6CE4084C4005DB8827BB0D4B40
31635	Новотимошкино	7	61	55	55.977483999999997	55.994058000000003	54.208654000000003	54.197673000000002	0103000020E610000001000000050000007F2E1A321EFD4B40AF264F594D194B407F2E1A321EFD4B40FD169D2CB51A4B40E129E44A3DFF4B40FD169D2CB51A4B40E129E44A3DFF4B40AF264F594D194B407F2E1A321EFD4B40AF264F594D194B40
31316	Новоитикеево	7	61	55	55.955322000000002	55.969399000000003	54.030904	54.024794999999997	0103000020E610000001000000050000001D93C5FD47FA4B405A0D897B2C034B401D93C5FD47FA4B4065A88AA9F4034B4037E3344415FC4B4065A88AA9F4034B4037E3344415FC4B405A0D897B2C034B401D93C5FD47FA4B405A0D897B2C034B40
58774	Нижный Бегеняш	7	61	55	55.549365000000002	55.567888000000004	53.794539	53.781787999999999	0103000020E610000001000000050000009548A29751C64B40DF3312A111E44A409548A29751C64B40C2323674B3E54A403BE5D18DB0C84B40C2323674B3E54A403BE5D18DB0C84B40DF3312A111E44A409548A29751C64B40DF3312A111E44A40
31215	Наумкино	7	61	55	55.765275000000003	55.791038999999998	53.906717999999998	53.881774999999998	0103000020E6100000010000000500000024B9FC87F4E14B4017B7D100DEF04A4024B9FC87F4E14B40E658DE550FF44A40266E15C440E54B40E658DE550FF44A40266E15C440E54B4017B7D100DEF04A4024B9FC87F4E14B4017B7D100DEF04A40
31412	Мустафино	7	61	55	56.093178000000002	56.119515999999997	54.075901000000002	54.058284	0103000020E61000000100000005000000755AB741ED0B4C40A6F0A0D975074B40755AB741ED0B4C40EA5DBC1FB7094B40A3ACDF4C4C0F4C40EA5DBC1FB7094B40A3ACDF4C4C0F4C40A6F0A0D975074B40755AB741ED0B4C40A6F0A0D975074B40
58380	Мурадымово	7	61	55	55.462561000000001	56.391877000000001	54.291207	53.763508999999999	0103000020E61000000100000005000000D9B3E73235BB4B40D099B4A9BAE14A40D9B3E73235BB4B40E2AE5E4546254B40FD86890629324C40E2AE5E4546254B40FD86890629324C40D099B4A9BAE14A40D9B3E73235BB4B40D099B4A9BAE14A40
31962	Михайловка	7	61	55	55.615957000000002	55.739061999999997	53.968426000000001	53.905917000000002	0103000020E61000000100000005000000035FD1ADD7CE4B40FAF19716F5F34A40035FD1ADD7CE4B404D4C1762F5FB4A40B1DB679599DE4B404D4C1762F5FB4A40B1DB679599DE4B40FAF19716F5F34A40035FD1ADD7CE4B40FAF19716F5F34A40
31821	Месели	7	61	55	55.801279000000001	55.837148999999997	53.847883000000003	53.834229999999998	0103000020E610000001000000050000005DFC6D4F90E64B40C9AB730CC8EA4A405DFC6D4F90E64B40CDEA1D6E87EC4A408670CCB227EB4B40CDEA1D6E87EC4A408670CCB227EB4B40C9AB730CC8EA4A405DFC6D4F90E64B40C9AB730CC8EA4A40
31851	Манеево	7	61	55	55.763945	55.787975000000003	53.861080999999999	53.843904000000002	0103000020E61000000100000005000000AB7823F3C8E14B40577BD80B05EC4A40AB7823F3C8E14B407E1AF7E637EE4A406688635DDCE44B407E1AF7E637EE4A406688635DDCE44B40577BD80B05EC4A40AB7823F3C8E14B40577BD80B05EC4A40
932	Малый Нагадак	7	61	55	56.217514000000001	56.235534000000001	54.067807000000002	54.053595999999999	0103000020E610000001000000050000000936AE7FD71B4C402499D53BDC064B400936AE7FD71B4C404EB857E6AD084B404C8C65FA251E4C404EB857E6AD084B404C8C65FA251E4C402499D53BDC064B400936AE7FD71B4C402499D53BDC064B40
31518	Малое Ибраево	7	61	55	56.008654999999997	56.027133999999997	54.141260000000003	54.131053000000001	0103000020E6100000010000000500000033F9669B1B014C4077853E58C6104B4033F9669B1B014C40D21DC4CE14124B40094E7D2079034C40D21DC4CE14124B40094E7D2079034C4077853E58C6104B4033F9669B1B014C4077853E58C6104B40
58876	Макарово	7	61	55	55.746374000000003	55.756084999999999	54.229033000000001	54.224316999999999	0103000020E61000000100000005000000D84AE82E89DF4B40EA77616BB61C4B40D84AE82E89DF4B40365A0EF4501D4B4082FFAD64C7E04B40365A0EF4501D4B4082FFAD64C7E04B40EA77616BB61C4B40D84AE82E89DF4B40EA77616BB61C4B40
32248	Кшанны	7	61	55	55.797893000000002	55.826324	54.108445000000003	54.090595	0103000020E610000001000000050000008A5A9A5B21E64B402F17F19D980B4B408A5A9A5B21E64B4016359886E10D4B4030F31DFCC4E94B4016359886E10D4B4030F31DFCC4E94B402F17F19D980B4B408A5A9A5B21E64B402F17F19D980B4B40
1326	Курманаево	7	61	55	55.620538000000003	55.648116999999999	54.145499999999998	54.128942000000002	0103000020E610000001000000050000006FF607CA6DCF4B40598AE42B81104B406FF607CA6DCF4B40B4C876BE9F124B40A67D737FF5D24B40B4C876BE9F124B40A67D737FF5D24B40598AE42B81104B406FF607CA6DCF4B40598AE42B81104B40
31284	Куезбашево	7	61	55	56.030799000000002	56.04766	54.027301999999999	54.009348000000003	0103000020E61000000100000005000000F0DFBC38F1034C403A24B55032014B40F0DFBC38F1034C40C58EC6A17E034B40E7A90EB919064C40C58EC6A17E034B40E7A90EB919064C403A24B55032014B40F0DFBC38F1034C403A24B55032014B40
31761	Кебячево	7	61	55	55.919569000000003	55.952789000000003	53.948453000000001	53.934674000000001	0103000020E610000001000000050000002DB5DE6FB4F54B40F435CB65A3F74A402DB5DE6FB4F54B4084656CE866F94A40897E6DFDF4F94B4084656CE866F94A40897E6DFDF4F94B40F435CB65A3F74A402DB5DE6FB4F54B40F435CB65A3F74A40
58787	Кальчирбуран	7	61	55	55.462561000000001	56.391877000000001	54.291207	53.763508999999999	0103000020E61000000100000005000000D9B3E73235BB4B40D099B4A9BAE14A40D9B3E73235BB4B40E2AE5E4546254B40FD86890629324C40E2AE5E4546254B40FD86890629324C40D099B4A9BAE14A40D9B3E73235BB4B40D099B4A9BAE14A40
31682	Ишлы	7	61	55	55.888640000000002	55.920701000000001	54.207889999999999	54.187654000000002	0103000020E610000001000000050000006FF59CF4BEF14B40577BD80B05184B406FF59CF4BEF14B402D95B7239C1A4B407F32C687D9F54B402D95B7239C1A4B407F32C687D9F54B40577BD80B05184B406FF59CF4BEF14B40577BD80B05184B40
31599	Исмагилово	7	61	55	55.932963000000001	55.970998000000002	54.175566000000003	54.162430999999998	0103000020E6100000010000000500000064B0E2546BF74B40A46DFC89CA144B4064B0E2546BF74B4010255AF278164B409F3D97A949FC4B4010255AF278164B409F3D97A949FC4B40A46DFC89CA144B4064B0E2546BF74B40A46DFC89CA144B40
1047	Болотино	7	61	55	55.816470000000002	55.843743000000003	54.178918000000003	54.162878999999997	0103000020E610000001000000050000002315C61682E84B40431A1538D9144B402315C61682E84B403755F7C8E6164B404E9D47C5FFEB4B403755F7C8E6164B404E9D47C5FFEB4B40431A1538D9144B402315C61682E84B40431A1538D9144B40
31429	Бишкаин	7	61	55	56.095261999999998	56.145541000000001	53.990336999999997	53.972662999999997	0103000020E610000001000000050000009946938B310C4C40BE839F3880FC4A409946938B310C4C406682E15CC3FE4A40139D6516A1124C406682E15CC3FE4A40139D6516A1124C40BE839F3880FC4A409946938B310C4C40BE839F3880FC4A40
28776	Балыклыкуль	7	61	55	55.804765000000003	55.831291999999998	53.962524999999999	53.943801000000001	0103000020E6100000010000000500000094FB1D8A02E74B404F779E78CEF84A4094FB1D8A02E74B408C4AEA0434FB4A4095B6B8C667EA4B408C4AEA0434FB4A4095B6B8C667EA4B404F779E78CEF84A4094FB1D8A02E74B404F779E78CEF84A40
32425	Асавбашево	7	61	55	55.686124	55.710711000000003	53.843113000000002	53.826991999999997	0103000020E61000000100000005000000178046E9D2D74B40DD06B5DFDAE94A40178046E9D2D74B408EEA7420EBEB4A4028F4FA93F8DA4B408EEA7420EBEB4A4028F4FA93F8DA4B40DD06B5DFDAE94A40178046E9D2D74B40DD06B5DFDAE94A40
1089	Андреевка	7	61	55	55.700083999999997	55.713146000000002	54.242010000000001	54.229774999999997	0103000020E61000000100000005000000F7393E5A9CD94B401D386744691D4B40F7393E5A9CD94B4009A7052FFA1E4B40F9A23D5E48DB4B4009A7052FFA1E4B40F9A23D5E48DB4B401D386744691D4B40F7393E5A9CD94B401D386744691D4B40
11407	Амзя	7	61	55	55.733941999999999	55.753103000000003	53.870691999999998	53.860635000000002	0103000020E610000001000000050000009694BBCFF1DD4B408065A54929EE4A409694BBCFF1DD4B40C571E0D572EF4A407FC2D9AD65E04B40C571E0D572EF4A407FC2D9AD65E04B408065A54929EE4A409694BBCFF1DD4B408065A54929EE4A40
224	Александровка	7	61	55	55.721114	55.730024999999998	54.052554999999998	54.039073999999999	0103000020E610000001000000050000000858AB764DDC4B40DC0F786000054B400858AB764DDC4B40E21E4B1FBA064B4096218E7571DD4B40E21E4B1FBA064B4096218E7571DD4B40DC0F786000054B400858AB764DDC4B40DC0F786000054B40
30899	Чурашево	7	61	998	57.165047999999999	57.189777999999997	56.085656	56.070222999999999	0103000020E610000001000000050000009622F94A20954C40A8363811FD084C409622F94A20954C40645A9BC6F60A4C4009C03FA54A984C40645A9BC6F60A4C4009C03FA54A984C40A8363811FD084C409622F94A20954C40A8363811FD084C40
29560	Чишма-Уракаево	7	61	998	56.373668000000002	56.395757000000003	55.918908000000002	55.905245000000001	0103000020E61000000100000005000000E7C75F5AD42F4C400BEF7211DFF34B40E7C75F5AD42F4C40320400C79EF54B40E014562AA8324C40320400C79EF54B40E014562AA8324C400BEF7211DFF34B40E7C75F5AD42F4C400BEF7211DFF34B40
30325	Утяшино	7	61	998	56.785932000000003	56.813214000000002	56.097552999999998	56.084169000000003	0103000020E61000000100000005000000A070766B99644C40242BBF0CC60A4C40A070766B99644C403750E09D7C0C4C401E53776517684C403750E09D7C0C4C401E53776517684C40242BBF0CC60A4C40A070766B99644C40242BBF0CC60A4C40
31127	Усть-Табаска	7	61	998	57.450127999999999	57.477804999999996	56.139958	56.122886000000001	0103000020E61000000100000005000000C78157CB9DB94C4071917BBABA0F4C40C78157CB9DB94C402368CC24EA114C40C16ED8B628BD4C402368CC24EA114C40C16ED8B628BD4C4071917BBABA0F4C40C78157CB9DB94C4071917BBABA0F4C40
31110	Уршады	7	61	998	57.071990999999997	57.090263	56.158119999999997	56.141382	0103000020E610000001000000050000009C4D470037894C401D1F2DCE18124C409C4D470037894C40F86BB2463D144C40F984ECBC8D8B4C40F86BB2463D144C40F984ECBC8D8B4C401D1F2DCE18124C409C4D470037894C401D1F2DCE18124C40
29709	Упканкуль	7	61	998	56.483333999999999	56.519526999999997	55.934305999999999	55.922367999999999	0103000020E61000000100000005000000BE8575E3DD3D4C403F70952710F64B40BE8575E3DD3D4C40713AC95697F74B40CA3159DC7F424C40713AC95697F74B40CA3159DC7F424C403F70952710F64B40BE8575E3DD3D4C403F70952710F64B40
47344	Улуелга	7	61	998	56.341948000000002	56.376137999999997	56.354661999999998	56.340116000000002	0103000020E610000001000000050000006077BAF3C42B4C40556CCCEB882B4C406077BAF3C42B4C4025917D90652D4C4034643C4A25304C4025917D90652D4C4034643C4A25304C40556CCCEB882B4C406077BAF3C42B4C40556CCCEB882B4C40
29372	Тюйск	7	61	998	56.603546999999999	56.629041000000001	56.267412	56.256633000000001	0103000020E61000000100000005000000A94C3107414D4C408509A359D9204C40A94C3107414D4C406B47718E3A224C40EC6B5D6A84504C406B47718E3A224C40EC6B5D6A84504C408509A359D9204C40A94C3107414D4C408509A359D9204C40
29275	Тульгузбаш	7	61	998	56.468341000000002	56.499305999999997	56.240098000000003	56.227054000000003	0103000020E610000001000000050000001F300F99F23B4C408736001B101D4C401F300F99F23B4C40E2EA0088BB1E4C4029594E42E93F4C40E2EA0088BB1E4C4029594E42E93F4C408736001B101D4C401F300F99F23B4C408736001B101D4C40
30841	Султанбеково	7	61	998	57.128864	57.149892999999999	56.042254999999997	56.018177000000001	0103000020E61000000100000005000000DDD0949D7E904C400B45BA9F53024C40DDD0949D7E904C40D68BA19C68054C401D739EB12F934C40D68BA19C68054C401D739EB12F934C400B45BA9F53024C40DDD0949D7E904C400B45BA9F53024C40
29642	Султанай	7	61	998	56.473336000000003	56.489685000000001	56.033419000000002	56.023902	0103000020E610000001000000050000007E022846963C4C408D2782380F034C407E022846963C4C405308E41247044C40BF2B82FFAD3E4C405308E41247044C40BF2B82FFAD3E4C408D2782380F034C407E022846963C4C408D2782380F034C40
30625	Старый Мутабаш	7	61	998	56.273003000000003	56.296512	56.226148999999999	56.216743999999998	0103000020E61000000100000005000000DE5A26C3F1224C4057CD7344BE1B4C40DE5A26C3F1224C40F5824F73F21C4C408F6FEF1AF4254C40F5824F73F21C4C408F6FEF1AF4254C4057CD7344BE1B4C40DE5A26C3F1224C4057CD7344BE1B4C40
29751	Старые Казанчи	7	61	998	56.208989000000003	56.242415000000001	56.214171999999998	56.194918999999999	0103000020E61000000100000005000000A41CCC26C01A4C403C2F151BF3184C40A41CCC26C01A4C4005DCF3FC691B4C40A9876874071F4C4005DCF3FC691B4C40A9876874071F4C403C2F151BF3184C40A41CCC26C01A4C403C2F151BF3184C40
8554	Новые Казанчи	7	61	998	56.268816000000001	56.291328	56.293607000000002	56.271590000000003	0103000020E610000001000000050000001E520C9068224C40D8F50B76C3224C401E520C9068224C40377007EA94254C405D34643C4A254C40377007EA94254C405D34643C4A254C40D8F50B76C3224C401E520C9068224C40D8F50B76C3224C40
58822	Новые Багазы	7	61	998	56.136890000000001	57.596876999999999	56.405748000000003	55.878708000000003	0103000020E6100000010000000500000021938C9C85114C40E65DF58079F04B4021938C9C85114C406E35EB8CEF334C40075E2D7766CC4C406E35EB8CEF334C40075E2D7766CC4C40E65DF58079F04B4021938C9C85114C40E65DF58079F04B40
31001	Новокочкильдино	7	61	998	56.844321999999998	56.869025999999998	56.089633999999997	56.083163999999996	0103000020E610000001000000050000008BA548BE126C4C402E1A321EA50A4C408BA548BE126C4C40094E7D20790B4C40D5AF743E3C6F4C40094E7D20790B4C40D5AF743E3C6F4C402E1A321EA50A4C408BA548BE126C4C402E1A321EA50A4C40
29856	Новая Кара	7	61	998	56.244911999999999	56.267065000000002	56.135418000000001	56.126634000000003	0103000020E61000000100000005000000F032C346591F4C40E547FC8A35104C40F032C346591F4C4016A5846055114C400074982F2F224C4016A5846055114C400074982F2F224C40E547FC8A35104C40F032C346591F4C40E547FC8A35104C40
29349	Новая Бурма	7	61	998	56.667955999999997	56.688276000000002	56.171422999999997	56.147004000000003	0103000020E610000001000000050000005F950B957F554C40CB30EE06D1124C405F950B957F554C401F645930F1154C40944F8F6D19584C401F645930F1154C40944F8F6D19584C40CB30EE06D1124C405F950B957F554C40CB30EE06D1124C40
30706	Мута-Елга	7	61	998	56.331726000000003	56.358477000000001	56.217965999999997	56.201815000000003	0103000020E61000000100000005000000D09D60FF752A4C40CF6BEC12D5194C40D09D60FF752A4C40E9D1544FE61B4C4021AF0793E22D4C40E9D1544FE61B4C4021AF0793E22D4C40CF6BEC12D5194C40D09D60FF752A4C40CF6BEC12D5194C40
30387	Матала	7	61	998	56.758291	56.779795999999997	56.058453	56.041922999999997	0103000020E61000000100000005000000F2ECF2AD0F614C40A0F99CBB5D054C40F2ECF2AD0F614C4032AD4D637B074C409BC6F65AD0634C4032AD4D637B074C409BC6F65AD0634C40A0F99CBB5D054C40F2ECF2AD0F614C40A0F99CBB5D054C40
30498	Кшлау-Елга	7	61	998	56.336226000000003	56.361756	56.293951	56.278373000000002	0103000020E610000001000000050000004F081D74092B4C40728BF9B9A1234C404F081D74092B4C4031D0B52FA0254C40DE9046054E2E4C4031D0B52FA0254C40DE9046054E2E4C40728BF9B9A1234C404F081D74092B4C40728BF9B9A1234C40
29445	Куяштыр	7	61	998	56.556097999999999	56.592336000000003	56.025858999999997	56.002329000000003	0103000020E610000001000000050000007DAF21382E474C408C6A11514C004C407DAF21382E474C4054A703594F034C402A1F82AAD14B4C4054A703594F034C402A1F82AAD14B4C408C6A11514C004C407DAF21382E474C408C6A11514C004C40
30416	Кунгак	7	61	998	57.289842	57.322387999999997	56.227640000000001	56.201214	0103000020E61000000100000005000000ED80EB8A19A54C40A9BF5E61C1194C40ED80EB8A19A54C4077A1B94E231D4C40B94F8E0244A94C4077A1B94E231D4C40B94F8E0244A94C40A9BF5E61C1194C40ED80EB8A19A54C40A9BF5E61C1194C40
30217	Кубиязы	7	61	998	56.718235	56.766914	56.114586000000003	56.092998000000001	0103000020E61000000100000005000000D9EBDD1FEF5B4C40F54BC45BE70B4C40D9EBDD1FEF5B4C402C4A09C1AA0E4C401A6CEA3C2A624C402C4A09C1AA0E4C401A6CEA3C2A624C40F54BC45BE70B4C40D9EBDD1FEF5B4C40F54BC45BE70B4C40
30205	Ключи	7	61	998	56.369050999999999	56.385956999999998	55.992159999999998	55.976900999999998	0103000020E610000001000000050000002EC72B103D2F4C4000378B170BFD4B402EC72B103D2F4C401E335019FFFE4B40C554FA0967314C401E335019FFFE4B40C554FA0967314C4000378B170BFD4B402EC72B103D2F4C4000378B170BFD4B40
30798	Кигазы	7	61	998	56.310597000000001	56.361226000000002	56.064051999999997	56.042084000000003	0103000020E610000001000000050000002C9E7AA4C1274C40AAD72D0263054C402C9E7AA4C1274C40279F1EDB32084C40823B50A73C2E4C40279F1EDB32084C40823B50A73C2E4C40AAD72D0263054C402C9E7AA4C1274C40AAD72D0263054C40
29902	Кашкино	7	61	998	56.979607999999999	57.011175000000001	56.031005	56.013250999999997	0103000020E61000000100000005000000327381CB637D4C40D4D17135B2014C40327381CB637D4C409981CAF8F7034C4033C4B12E6E814C409981CAF8F7034C4033C4B12E6E814C40D4D17135B2014C40327381CB637D4C40D4D17135B2014C40
30138	Карткисяк	7	61	998	56.572034000000002	56.607284	55.954138	55.933025000000001	0103000020E610000001000000050000009C19FD6838494C40DAACFA5C6DF74B409C19FD6838494C4078EFA83121FA4B4029B16B7BBB4D4C4078EFA83121FA4B4029B16B7BBB4D4C40DAACFA5C6DF74B409C19FD6838494C40DAACFA5C6DF74B40
29623	Евбуляк	7	61	998	56.505406000000001	56.519230999999998	56.001810999999996	55.988202999999999	0103000020E61000000100000005000000E199D024B1404C409067976F7DFE4B40E199D024B1404C40F3E2C4573B004C40E108522976424C40F3E2C4573B004C40E108522976424C409067976F7DFE4B40E199D024B1404C409067976F7DFE4B40
30110	Гумбино	7	61	998	57.043056	57.061363999999998	56.002288999999998	55.990749999999998	0103000020E61000000100000005000000C3F2E7DB82854C40894160E5D0FE4B40C3F2E7DB82854C40FD1186014B004C406C938AC6DA874C40FD1186014B004C406C938AC6DA874C40894160E5D0FE4B40C3F2E7DB82854C40894160E5D0FE4B40
30043	Бильгиш	7	61	998	56.886201999999997	56.923068999999998	56.010483000000001	55.996172999999999	0103000020E610000001000000050000002CD32F116F714C404014CC9882FF4B402CD32F116F714C40FD14C78157014C40C879FF1F27764C40FD14C78157014C40C879FF1F27764C404014CC9882FF4B402CD32F116F714C404014CC9882FF4B40
29291	Барахаевка	7	61	998	56.539209	56.561092000000002	56.149335999999998	56.137414999999997	0103000020E61000000100000005000000BC5AEECC04454C406B7D91D096114C40BC5AEECC04454C40C70E2A711D134C400C06D7DCD1474C40C70E2A711D134C400C06D7DCD1474C406B7D91D096114C40BC5AEECC04454C406B7D91D096114C40
28737	Базанчатово	7	61	998	56.391437000000003	56.421979	56.355269999999997	56.340355000000002	0103000020E61000000100000005000000E1B88C9B1A324C40DA03ADC0902B4C40E1B88C9B1A324C40FD9FC37C792D4C40A54C6A6803364C40FD9FC37C792D4C40A54C6A6803364C40DA03ADC0902B4C40E1B88C9B1A324C40DA03ADC0902B4C40
29025	Аскино	7	61	998	56.537539000000002	56.613104999999997	56.110971999999997	56.075031000000003	0103000020E610000001000000050000008BA9F413CE444C40D597A59D9A094C408BA9F413CE444C40C7629B54340E4C40CD0182397A4E4C40C7629B54340E4C40CD0182397A4E4C40D597A59D9A094C408BA9F413CE444C40D597A59D9A094C40
29534	Арбашево	7	61	998	56.354146999999998	56.376739999999998	55.958033	55.945846000000003	0103000020E61000000100000005000000FE7C5BB0542D4C40B686527B11F94B40FE7C5BB0542D4C4090BE49D3A0FA4B402A8C2D0439304C4090BE49D3A0FA4B402A8C2D0439304C40B686527B11F94B40FE7C5BB0542D4C40B686527B11F94B40
29280	Амирово	7	61	998	56.961300999999999	56.987836999999999	56.044165999999997	56.029772999999999	0103000020E61000000100000005000000594E42E90B7B4C40E3A6069ACF034C40594E42E90B7B4C402DCC423BA7054C40AE635C71717E4C402DCC423BA7054C40AE635C71717E4C40E3A6069ACF034C40594E42E90B7B4C40E3A6069ACF034C40
29007	Узунларово	7	61	931	56.929968000000002	56.959612	54.526743000000003	54.510897	0103000020E61000000100000005000000CC29013109774C40F04FA91265414B40CC29013109774C40CF328B506C434B40B16CE690D47A4C40CF328B506C434B40B16CE690D47A4C40F04FA91265414B40CC29013109774C40F04FA91265414B40
13952	Убалары	7	61	931	56.824981000000001	56.840828000000002	54.235390000000002	54.222515999999999	0103000020E61000000100000005000000236937FA98694C401A6B7F677B1C4B40236937FA98694C4019E76F42211E4B40D2C77C40A06B4C4019E76F42211E4B40D2C77C40A06B4C401A6B7F677B1C4B40236937FA98694C401A6B7F677B1C4B40
58553	Троицкое	7	61	931	56.668908000000002	56.699199	54.633733999999997	54.620662000000003	0103000020E61000000100000005000000320400C79E554C405BEF37DA714F4B40320400C79E554C407F2E1A321E514B40AD32535A7F594C407F2E1A321E514B40AD32535A7F594C405BEF37DA714F4B40320400C79E554C405BEF37DA714F4B40
7491	Тереклы	7	61	931	56.930892999999998	56.983713999999999	54.438476000000001	54.423873999999998	0103000020E61000000100000005000000A489778027774C40F6CFD38041364B40A489778027774C405B0A48FB1F384B40054F2157EA7D4C405B0A48FB1F384B40054F2157EA7D4C40F6CFD38041364B40A489778027774C40F6CFD38041364B40
28870	Тавакачево	7	61	931	56.739291000000001	56.775224000000001	54.473731999999998	54.463104999999999	0103000020E61000000100000005000000139D6516A15E4C409ACE4E06473B4B40139D6516A15E4C40CA880B40A33C4B4083893F8A3A634C40CA880B40A33C4B4083893F8A3A634C409ACE4E06473B4B40139D6516A15E4C409ACE4E06473B4B40
47461	Сагитово	7	61	931	56.785249	56.801867999999999	54.596190999999997	54.589346999999997	0103000020E61000000100000005000000BD1B0B0A83644C40737FF5B86F4B4B40BD1B0B0A83644C40B39597FC4F4C4B40BEDA519CA3664C40B39597FC4F4C4B40BEDA519CA3664C40737FF5B86F4B4B40BD1B0B0A83644C40737FF5B86F4B4B40
28803	Приуралье	7	61	931	56.736550999999999	56.752254000000001	54.449863000000001	54.444637999999998	0103000020E61000000100000005000000056B9C4D475E4C408847E2E5E9384B40056B9C4D475E4C4019575C1C95394B408124ECDB49604C4019575C1C95394B408124ECDB49604C408847E2E5E9384B40056B9C4D475E4C408847E2E5E9384B40
58623	Орловка	7	61	931	56.563400999999999	56.589551	54.337226999999999	54.322678000000003	0103000020E6100000010000000500000050C422861D484C40C19140834D294B4050C422861D484C40022A1C412A2B4B407C293C68764B4C40022A1C412A2B4B407C293C68764B4C40C19140834D294B4050C422861D484C40C19140834D294B40
32842	Максим Горький	7	61	931	56.779032999999998	56.803027	54.308325000000004	54.291454000000002	0103000020E610000001000000050000009CC0745AB7634C40EA245B5D4E254B409CC0745AB7634C4005C58F3177274B400A67B796C9664C4005C58F3177274B400A67B796C9664C40EA245B5D4E254B409CC0745AB7634C40EA245B5D4E254B40
28453	Кысынды	7	61	931	56.666212999999999	56.681161000000003	54.339829999999999	54.326349	0103000020E61000000100000005000000C495B37746554C40890AD5CDC5294B40C495B37746554C408F19A88C7F2B4B40C4279D4830574C408F19A88C7F2B4B40C4279D4830574C40890AD5CDC5294B40C495B37746554C40890AD5CDC5294B40
28406	Красный Зилим	7	61	931	56.603017000000001	56.624549000000002	54.328989999999997	54.312232999999999	0103000020E610000001000000050000004DF73AA92F4D4C40B1DD3D40F7274B404DF73AA92F4D4C40035B25581C2A4B40F0DFBC38F14F4C40035B25581C2A4B40F0DFBC38F14F4C40B1DD3D40F7274B404DF73AA92F4D4C40B1DD3D40F7274B40
27830	Кизги	7	61	931	57.109298000000003	57.125818000000002	54.416173000000001	54.401721000000002	0103000020E6100000010000000500000055C2137AFD8D4C40E78EFE976B334B4055C2137AFD8D4C40363D282845354B40C39FE1CD1A904C40363D282845354B40C39FE1CD1A904C40E78EFE976B334B4055C2137AFD8D4C40E78EFE976B334B40
28723	Карташевка	7	61	931	56.493602000000003	56.514792999999997	54.381638000000002	54.365468999999997	0103000020E61000000100000005000000BF9EAF592E3F4C40D5592DB0C72E4B40BF9EAF592E3F4C4097749483D9304B40D89AADBCE4414C4097749483D9304B40D89AADBCE4414C40D5592DB0C72E4B40BF9EAF592E3F4C40D5592DB0C72E4B40
58448	Казанка	7	61	931	56.829635000000003	56.849567999999998	54.524773000000003	54.502847000000003	0103000020E61000000100000005000000F94ECC7A316A4C4024F25D4A5D404B40F94ECC7A316A4C407369FCC22B434B4033DDEBA4BE6C4C407369FCC22B434B4033DDEBA4BE6C4C4024F25D4A5D404B40F94ECC7A316A4C4024F25D4A5D404B40
47372	Заря	7	61	931	56.807409999999997	56.826777999999997	54.283113	54.274318000000001	0103000020E610000001000000050000004F3BFC3559674C40215A2BDA1C234B404F3BFC3559674C404609FA0B3D244B40B1868BDCD3694C404609FA0B3D244B40B1868BDCD3694C40215A2BDA1C234B404F3BFC3559674C40215A2BDA1C234B40
28334	Заитово	7	61	931	56.692129999999999	56.712539	54.319113000000002	54.306007999999999	0103000020E610000001000000050000004D4A41B797584C403D2828452B274B404D4A41B797584C403E5DDDB1D8284B40F10F5B7A345B4C403E5DDDB1D8284B40F10F5B7A345B4C403D2828452B274B404D4A41B797584C403D2828452B274B40
33045	Валентиновка	7	61	931	56.873688000000001	56.891322000000002	54.550503999999997	54.532755999999999	0103000020E610000001000000050000002E742502D56F4C40B75F3E5931444B402E742502D56F4C40992842EA76464B40481ADCD616724C40992842EA76464B40481ADCD616724C40B75F3E5931444B402E742502D56F4C40B75F3E5931444B40
58184	Благовещенка	7	61	931	56.638716000000002	56.659108000000003	54.519176000000002	54.496426999999997	0103000020E610000001000000050000004AB72572C1514C40FAEC80EB8A3F4B404AB72572C1514C401E6FF25B74424B401844A4A65D544C401E6FF25B74424B401844A4A65D544C40FAEC80EB8A3F4B404AB72572C1514C40FAEC80EB8A3F4B40
27732	Бакалдинское	7	61	931	56.886678000000003	56.921038000000003	54.443471000000002	54.420819999999999	0103000020E61000000100000005000000960A2AAA7E714C4059C0046EDD354B40960A2AAA7E714C40BADC60A8C3384B40C72FBC92E4754C40BADC60A8C3384B40C72FBC92E4754C4059C0046EDD354B40960A2AAA7E714C4059C0046EDD354B40
47303	Архангельское	7	61	931	56.753906999999998	56.805667999999997	54.417169000000001	54.390546000000001	0103000020E61000000100000005000000DC9C4A0680604C40B4CA4C69FD314B40DC9C4A0680604C40D8F335CB65354B4084B7072120674C40D8F335CB65354B4084B7072120674C40B4CA4C69FD314B40DC9C4A0680604C40B4CA4C69FD314B40
28944	Айтмембетово	7	61	931	57.036948000000002	57.072637999999998	54.489162999999998	54.480407	0103000020E6100000010000000500000089D349B6BA844C407EE200FA7D3D4B4089D349B6BA844C40E5B4A7E49C3E4B403239B5334C894C40E5B4A7E49C3E4B403239B5334C894C407EE200FA7D3D4B4089D349B6BA844C407EE200FA7D3D4B40
47632	Азово	7	61	931	57.081639000000003	57.106153999999997	54.462345999999997	54.445737999999999	0103000020E61000000100000005000000018A9125738A4C40CF4A5AF10D394B40018A9125738A4C40DCB75A272E3B4B40772B4B74968D4C40DCB75A272E3B4B40772B4B74968D4C40CF4A5AF10D394B40018A9125738A4C40CF4A5AF10D394B40
28043	Абзаново	7	61	931	56.651156999999998	56.690333000000003	54.462387999999997	54.452674000000002	0103000020E61000000100000005000000DEC7D11C59534C40F0DFBC38F1394B40DEC7D11C59534C400B08AD872F3B4B40BF2CEDD45C584C400B08AD872F3B4B40BF2CEDD45C584C40F0DFBC38F1394B40DEC7D11C59534C40F0DFBC38F1394B40
58838	с. Дим	7	61	672	54.345621999999999	55.497954	54.245803000000002	53.702905000000001	0103000020E61000000100000005000000996379573D2C4B40F29881CAF8D94A40996379573D2C4B401D210379761F4B40C974E8F4BCBF4B401D210379761F4B40C974E8F4BCBF4B40F29881CAF8D94A40996379573D2C4B40F29881CAF8D94A40
27863	Шафраново	7	61	672	54.759825999999997	54.790387000000003	53.991888000000003	53.972138999999999	0103000020E61000000100000005000000435376FA41614B404415FE0C6FFC4A40435376FA41614B40BEA59C2FF6FE4A407F17B6662B654B40BEA59C2FF6FE4A407F17B6662B654B404415FE0C6FFC4A40435376FA41614B404415FE0C6FFC4A40
26861	Чураево	7	61	672	54.992894	55.014391000000003	54.004320999999997	53.995455999999997	0103000020E6100000010000000500000083328D26177F4B40B14D2A1A6BFF4A4083328D26177F4B40CFD72C978D004B40AA2D7590D7814B40CFD72C978D004B40AA2D7590D7814B40B14D2A1A6BFF4A4083328D26177F4B40B14D2A1A6BFF4A40
27840	Чебенли	7	61	672	54.99682	55.013223000000004	53.869692999999998	53.860698999999997	0103000020E61000000100000005000000D6FF39CC977F4B40965984622BEE4A40D6FF39CC977F4B40B247A81952EF4A400B47904AB1814B40B247A81952EF4A400B47904AB1814B40965984622BEE4A40D6FF39CC977F4B40965984622BEE4A40
26336	Ханжарово	7	61	672	54.586388999999997	54.616526999999998	53.951633000000001	53.944955999999998	0103000020E61000000100000005000000F8DD74CB0E4B4B4059147651F4F84A40F8DD74CB0E4B4B40AE65321CCFF94A40ED0C535BEA4E4B40AE65321CCFF94A40ED0C535BEA4E4B4059147651F4F84A40F8DD74CB0E4B4B4059147651F4F84A40
27094	Уразметово	7	61	672	55.403038000000002	55.419747000000001	53.825589000000001	53.814627999999999	0103000020E61000000100000005000000CB85CABF96B34B40F433F5BA45E84A40CB85CABF96B34B40FB777DE6ACE94A400CCC0A45BAB54B40FB777DE6ACE94A400CCC0A45BAB54B40F433F5BA45E84A40CB85CABF96B34B40F433F5BA45E84A40
26804	Уваровка	7	61	672	54.863779999999998	54.876624999999997	53.992539000000001	53.984116999999998	0103000020E610000001000000050000002D78D157906E4B400438BD8BF7FD4A402D78D157906E4B40958098840BFF4A4091ED7C3F35704B40958098840BFF4A4091ED7C3F35704B400438BD8BF7FD4A402D78D157906E4B400438BD8BF7FD4A40
27750	Трунтаишево	7	61	672	54.724198999999999	54.763832999999998	54.107959999999999	54.086115999999997	0103000020E61000000100000005000000E065868DB25C4B40C7D45DD9050B4B40E065868DB25C4B4059A31EA2D10D4B40834D9D47C5614B4059A31EA2D10D4B40834D9D47C5614B40C7D45DD9050B4B40E065868DB25C4B40C7D45DD9050B4B40
27663	Ташлы	7	61	672	54.666482999999999	54.706493999999999	54.186126000000002	54.164355	0103000020E61000000100000005000000842BA0504F554B4090F7AA9509154B40842BA0504F554B40B8770DFAD2174B40FD6838656E5A4B40B8770DFAD2174B40FD6838656E5A4B4090F7AA9509154B40842BA0504F554B4090F7AA9509154B40
27034	Тавричанка	7	61	672	55.236248000000003	55.258381999999997	53.798406	53.780436999999999	0103000020E610000001000000050000006ADFDC5F3D9E4B404FCB0F5CE5E34A406ADFDC5F3D9E4B401077F52A32E64A4002F04FA912A14B401077F52A32E64A4002F04FA912A14B404FCB0F5CE5E34A406ADFDC5F3D9E4B404FCB0F5CE5E34A40
27595	Слак	7	61	672	54.692390000000003	54.736012000000002	53.972577999999999	53.954636999999998	0103000020E61000000100000005000000EA094B3CA0584B409946938B31FA4A40EA094B3CA0584B409067976F7DFC4A4056BB26A4355E4B409067976F7DFC4A4056BB26A4355E4B409946938B31FA4A40EA094B3CA0584B409946938B31FA4A40
27761	Сараево	7	61	672	54.602809999999998	54.628312999999999	54.085968000000001	54.060234000000001	0103000020E61000000100000005000000D3D9C9E0284D4B40BB0D6ABFB5074B40D3D9C9E0284D4B405340DAFF000B4B406953758F6C504B405340DAFF000B4B406953758F6C504B40BB0D6ABFB5074B40D3D9C9E0284D4B40BB0D6ABFB5074B40
4593	Раевский	7	61	672	54.912899000000003	54.962648000000002	54.086312	54.046999	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
27011	Отрада	7	61	672	55.116224000000003	55.134127999999997	53.976100000000002	53.965131	0103000020E610000001000000050000005281936DE08E4B408AADA06989FB4A405281936DE08E4B4014D044D8F0FC4A402BBD361B2B914B4014D044D8F0FC4A402BBD361B2B914B408AADA06989FB4A405281936DE08E4B408AADA06989FB4A40
58554	Новотроицкое	7	61	672	54.643341999999997	54.654660999999997	54.149867	54.141618999999999	0103000020E610000001000000050000005512D90759524B4001BF469220124B405512D90759524B40F4DF83D72E134B40BB7B80EECB534B40F4DF83D72E134B40BB7B80EECB534B4001BF469220124B405512D90759524B4001BF469220124B40
26614	Новосепяшево	7	61	672	55.026491	55.041772000000002	54.087299000000002	54.072377000000003	0103000020E61000000100000005000000B5519D0E64834B40C6FD47A643094B40B5519D0E64834B409CFC169D2C0B4B40BBF1EEC858854B409CFC169D2C0B4B40BBF1EEC858854B40C6FD47A643094B40B5519D0E64834B40C6FD47A643094B40
25015	Новоконстантиновка	7	61	672	55.173743000000002	55.205489999999998	53.808674000000003	53.787624000000001	0103000020E610000001000000050000005874EB353D964B40B9C5FCDCD0E44A405874EB353D964B4011902FA182E74A40D8D30E7F4D9A4B4011902FA182E74A40D8D30E7F4D9A4B40B9C5FCDCD0E44A405874EB353D964B40B9C5FCDCD0E44A40
27388	Никифарово	7	61	672	54.680667	54.716760999999998	53.836860000000001	53.816876999999998	0103000020E61000000100000005000000B43BA41820574B4063EDEF6C8FE84A40B43BA41820574B4050AA7D3A1EEB4A402D060FD3BE5B4B4050AA7D3A1EEB4A402D060FD3BE5B4B4063EDEF6C8FE84A40B43BA41820574B4063EDEF6C8FE84A40
27513	Нижнее Аврюзово	7	61	672	54.880533	54.912854000000003	53.925465000000003	53.910229999999999	0103000020E610000001000000050000003E062B4EB5704B4046EBA86A82F44A403E062B4EB5704B40DC4B1AA375F64A40EB025E66D8744B40DC4B1AA375F64A40EB025E66D8744B4046EBA86A82F44A403E062B4EB5704B4046EBA86A82F44A40
58858	Нижегородка	7	61	672	54.345621999999999	55.497954	54.245803000000002	53.702905000000001	0103000020E61000000100000005000000996379573D2C4B40F29881CAF8D94A40996379573D2C4B401D210379761F4B40C974E8F4BCBF4B401D210379761F4B40C974E8F4BCBF4B40F29881CAF8D94A40996379573D2C4B40F29881CAF8D94A40
27211	Нигматуллино	7	61	672	55.332763	55.364474000000001	54.019970999999998	54.003818000000003	0103000020E61000000100000005000000D0285DFA97AA4B406D91B41B7D004B40D0285DFA97AA4B4028EFE3688E024B40041F8315A7AE4B4028EFE3688E024B40041F8315A7AE4B406D91B41B7D004B40D0285DFA97AA4B406D91B41B7D004B40
27357	Нефорощанка	7	61	672	55.435872000000003	55.461402	53.974744000000001	53.965936999999997	0103000020E61000000100000005000000FE9E58A7CAB74B40887FD8D2A3FB4A40FE9E58A7CAB74B4072FC5069C4FC4A408D2782380FBB4B4072FC5069C4FC4A408D2782380FBB4B40887FD8D2A3FB4A40FE9E58A7CAB74B40887FD8D2A3FB4A40
27164	Мендяново	7	61	672	54.761560000000003	54.780748000000003	53.922910000000002	53.907105999999999	0103000020E610000001000000050000008CF84ECC7A614B40B000A60C1CF44A408CF84ECC7A614B40609335EA21F64A406E35EB8CEF634B40609335EA21F64A406E35EB8CEF634B40B000A60C1CF44A408CF84ECC7A614B40B000A60C1CF44A40
26185	Крымский	7	61	672	55.269027999999999	55.283284000000002	54.075198	54.067267999999999	0103000020E61000000100000005000000A9DA6E826FA24B409E08E23C9C084B40A9DA6E826FA24B40C05C8B16A0094B4073BD6DA642A44B40C05C8B16A0094B4073BD6DA642A44B409E08E23C9C084B40A9DA6E826FA24B409E08E23C9C084B40
26939	Кипчак-Аскарово	7	61	672	55.041896999999999	55.080426000000003	53.944552999999999	53.925831000000002	0103000020E61000000100000005000000776682E15C854B40BE4F55A181F64A40776682E15C854B405A2BDA1CE7F84A40C2DF2F664B8A4B405A2BDA1CE7F84A40C2DF2F664B8A4B40BE4F55A181F64A40776682E15C854B40BE4F55A181F64A40
26379	Кайраклы	7	61	672	54.493223999999998	54.531869999999998	53.941977999999999	53.921149	0103000020E6100000010000000500000018CDCAF6213F4B401EDFDE35E8F54A4018CDCAF6213F4B4097C62FBC92F84A409CDCEF5014444B4097C62FBC92F84A409CDCEF5014444B401EDFDE35E8F54A4018CDCAF6213F4B401EDFDE35E8F54A40
26660	Казанка	7	61	672	54.786776000000003	54.840018999999998	54.143279999999997	54.129866	0103000020E610000001000000050000008CA37213B5644B40616EF7729F104B408CA37213B5644B40DF15C1FF56124B4062821ABE856B4B40DF15C1FF56124B4062821ABE856B4B40616EF7729F104B408CA37213B5644B40616EF7729F104B40
27964	Идрисово	7	61	672	54.837234000000002	54.884207000000004	54.025181000000003	54.013416999999997	0103000020E61000000100000005000000B58CD47B2A6B4B40EF1AF4A5B7014B40B58CD47B2A6B4B4084BD892139034B4078F2E9B12D714B4084BD892139034B4078F2E9B12D714B40EF1AF4A5B7014B40B58CD47B2A6B4B40EF1AF4A5B7014B40
26544	Зеленый Клин	7	61	672	55.133327999999999	55.160663999999997	53.833390000000001	53.824356000000002	0103000020E610000001000000050000000FD253E410914B407521567F84E94A400FD253E410914B401F680586ACEA4A4080D250A390944B401F680586ACEA4A4080D250A390944B407521567F84E94A400FD253E410914B407521567F84E94A40
26472	Гайниямак	7	61	672	54.578581999999997	54.627738000000001	53.805585000000001	53.790832000000002	0103000020E61000000100000005000000F20698F90E4A4B40AD50A4FB39E54A40F20698F90E4A4B40F792C6681DE74A406D3A02B859504B40F792C6681DE74A406D3A02B859504B40AD50A4FB39E54A40F20698F90E4A4B40AD50A4FB39E54A40
26431	Воздвиженка	7	61	672	54.503599999999999	54.534905999999999	53.879826999999999	53.871927999999997	0103000020E61000000100000005000000FF21FDF675404B40BC3B32569BEF4A40FF21FDF675404B40A391CF2B9EF04A409337C0CC77444B40A391CF2B9EF04A409337C0CC77444B40BC3B32569BEF4A40FF21FDF675404B40BC3B32569BEF4A40
27467	Балгазы	7	61	672	54.834935000000002	54.846783000000002	53.839224000000002	53.830765	0103000020E6100000010000000500000094A46B26DF6A4B40AAD4EC8156EA4A4094A46B26DF6A4B40580229B16BEB4A4086E7A562636C4B40580229B16BEB4A4086E7A562636C4B40AAD4EC8156EA4A4094A46B26DF6A4B40AAD4EC8156EA4A40
27285	Байдаковка	7	61	672	55.341540000000002	55.366458999999999	53.957417999999997	53.936736000000003	0103000020E610000001000000050000004F232D95B7AB4B40317E1AF7E6F74A404F232D95B7AB4B40054D4BAC8CFA4A409529E620E8AE4B40054D4BAC8CFA4A409529E620E8AE4B40317E1AF7E6F74A404F232D95B7AB4B40317E1AF7E6F74A40
26247	Аксеново	7	61	672	54.589362000000001	54.618288	53.923959000000004	53.909385999999998	0103000020E61000000100000005000000A9C0C936704B4B405AB8ACC266F44A40A9C0C936704B4B4025ECDB4944F64A402FC1A90F244F4B4025ECDB4944F64A402FC1A90F244F4B405AB8ACC266F44A40A9C0C936704B4B405AB8ACC266F44A40
26168	Абдрашитово	7	61	672	55.187874000000001	55.217149999999997	54.024351000000003	54.008066999999997	0103000020E6100000010000000500000065E256410C984B40A296E65608014B4065E256410C984B40FD4FFEEE1D034B40C7293A92CB9B4B40FD4FFEEE1D034B40C7293A92CB9B4B40A296E65608014B4065E256410C984B40A296E65608014B40
32926	отделение Озерное Совхоза Красная Башкирия	7	61	571	58.832644000000002	58.857185999999999	53.399647000000002	53.382393999999998	0103000020E61000000100000005000000F69A1E14946A4D40E3175E49F2B04A40F69A1E14946A4D40E67805A227B34A40664B5645B86D4D40E67805A227B34A40664B5645B86D4D40E3175E49F2B04A40F69A1E14946A4D40E3175E49F2B04A40
61565	Янгильский	7	61	571	58.779769000000002	58.807608000000002	53.264125	53.251734999999996	0103000020E61000000100000005000000A2B77878CF634D4018213CDA38A04A40A2B77878CF634D402B8716D9CEA14A4076FEEDB25F674D402B8716D9CEA14A4076FEEDB25F674D4018213CDA38A04A40A2B77878CF634D4018213CDA38A04A40
4489	Шарипово	7	61	571	58.117432999999998	58.130701000000002	53.589160999999997	53.582864000000001	0103000020E610000001000000050000004F3C670B080F4D4004029D499BCA4A404F3C670B080F4D40118AADA069CB4A40FA4674CFBA104D40118AADA069CB4A40FA4674CFBA104D4004029D499BCA4A404F3C670B080F4D4004029D499BCA4A40
8076	Целинный	7	61	571	58.717750000000002	58.747205000000001	53.028461999999998	53.013181000000003	0103000020E610000001000000050000001D5A643BDF5B4D40DCF63DEAAF814A401D5A643BDF5B4D40E1968FA4A4834A402F34D769A45F4D40E1968FA4A4834A402F34D769A45F4D40DCF63DEAAF814A401D5A643BDF5B4D40DCF63DEAAF814A40
25334	Халилово	7	61	571	58.541077999999999	58.570013000000003	53.058411999999997	53.041868999999998	0103000020E61000000100000005000000E44A3D0B42454D40ADDBA0F65B854A40E44A3D0B42454D40D3D85E0B7A874A40BEA59C2FF6484D40D3D85E0B7A874A40BEA59C2FF6484D40ADDBA0F65B854A40E44A3D0B42454D40ADDBA0F65B854A40
25151	Тупаково	7	61	571	58.646836999999998	58.661883000000003	53.446415999999999	53.432572	0103000020E61000000100000005000000DF6B088ECB524D402995F0845EB74A40DF6B088ECB524D40A034D42824B94A40A2630795B8544D40A034D42824B94A40A2630795B8544D402995F0845EB74A40DF6B088ECB524D402995F0845EB74A40
24457	Тепяново	7	61	571	58.548651	58.557904000000001	53.145564999999998	53.134960999999997	0103000020E6100000010000000500000077F52A323A464D40239EEC6646914A4077F52A323A464D409B38B9DFA1924A405F27F56569474D409B38B9DFA1924A405F27F56569474D40239EEC6646914A4077F52A323A464D40239EEC6646914A40
17231	Теляшево	7	61	571	58.640728000000003	58.650089000000001	53.665111000000003	53.658814999999997	0103000020E61000000100000005000000D5D0066003524D409F8EC70C54D44A40D5D0066003524D40DD9A745B22D54A40A33EC91D36534D40DD9A745B22D54A40A33EC91D36534D409F8EC70C54D44A40D5D0066003524D409F8EC70C54D44A40
58902	Таштуй	7	61	571	57.854460000000003	58.989113000000003	53.877538999999999	52.857525000000003	0103000020E61000000100000005000000BEDEFDF15EED4C404F401361C36D4A40BEDEFDF15EED4C4076FBAC3253F04A40348639419B7E4D4076FBAC3253F04A40348639419B7E4D404F401361C36D4A40BEDEFDF15EED4C404F401361C36D4A40
24808	Ташбулатово	7	61	571	58.684835	58.712198000000001	53.631770000000003	53.615614999999998	0103000020E61000000100000005000000FD135CACA8574D40A9F6E978CCCE4A40FD135CACA8574D40064CE0D6DDD04A406823D74D295B4D40064CE0D6DDD04A406823D74D295B4D40A9F6E978CCCE4A40FD135CACA8574D40A9F6E978CCCE4A40
23667	Тал-Кускарово	7	61	571	58.448408000000001	58.464587000000002	53.251423000000003	53.240102	0103000020E61000000100000005000000E4A1EF6E65394D4023DA8EA9BB9E4A40E4A1EF6E65394D402A3BFDA02EA04A40C9923996773B4D402A3BFDA02EA04A40C9923996773B4D4023DA8EA9BB9E4A40E4A1EF6E65394D4023DA8EA9BB9E4A40
3772	Таксырово	7	61	571	58.647267999999997	58.667048999999999	53.243718000000001	53.231338999999998	0103000020E61000000100000005000000A8DF85ADD9524D4009A52F849C9D4A40A8DF85ADD9524D4028B9C326329F4A402DEA93DC61554D4028B9C326329F4A402DEA93DC61554D4009A52F849C9D4A40A8DF85ADD9524D4009A52F849C9D4A40
23363	Старобалапаново	7	61	571	58.797978000000001	58.817974999999997	53.696629999999999	53.689587000000003	0103000020E61000000100000005000000B876A22424664D40965F066344D84A40B876A22424664D40CCB4FD2B2BD94A4009F9A067B3684D40CCB4FD2B2BD94A4009F9A067B3684D40965F066344D84A40B876A22424664D40965F066344D84A40
46521	Северный	7	61	571	58.778359000000002	58.791789000000001	53.135835999999998	53.125230999999999	0103000020E610000001000000050000000DC68844A1634D4002B9C49107904A400DC68844A1634D404ACFF41263914A40912A8A5759654D404ACFF41263914A40912A8A5759654D4002B9C49107904A400DC68844A1634D4002B9C49107904A40
58784	Самарское	7	61	571	58.724010999999997	58.737279000000001	53.525702000000003	53.520305999999998	0103000020E61000000100000005000000DD787764AC5C4D40CFF4126399C24A40DD787764AC5C4D408DB800344AC34A40888384285F5E4D408DB800344AC34A40888384285F5E4D40CFF4126399C24A40DD787764AC5C4D40CFF4126399C24A40
22926	Рыскужино	7	61	571	58.335903000000002	58.353887	53.319011000000003	53.311480000000003	0103000020E610000001000000050000006CD097DEFE2A4D40D6AD9E93DEA74A406CD097DEFE2A4D403A083A5AD5A84A4062BD512B4C2D4D403A083A5AD5A84A4062BD512B4C2D4D40D6AD9E93DEA74A406CD097DEFE2A4D40D6AD9E93DEA74A40
3665	Рахметово	7	61	571	58.880012000000001	58.892767999999997	53.827741000000003	53.820751999999999	0103000020E61000000100000005000000350BB43BA4704D403410CB660EE94A40350BB43BA4704D407847C66AF3E94A402975C93846724D407847C66AF3E94A402975C93846724D403410CB660EE94A40350BB43BA4704D403410CB660EE94A40
24412	Равилово	7	61	571	58.512512000000001	58.525087999999997	53.211351999999998	53.203446	0103000020E610000001000000050000005E6743FE99414D404240BE840A9A4A405E6743FE99414D40DBF813950D9B4A40D2C2651536434D40DBF813950D9B4A40D2C2651536434D404240BE840A9A4A405E6743FE99414D404240BE840A9A4A40
58582	Первомайский	7	61	571	58.846145999999997	58.860474000000004	53.242046999999999	53.234475000000003	0103000020E6100000010000000500000013D21A834E6C4D40645DDC46039E4A4013D21A834E6C4D40268C6665FB9E4A4077871403246E4D40268C6665FB9E4A4077871403246E4D40645DDC46039E4A4013D21A834E6C4D40645DDC46039E4A40
23281	Новобалапаново	7	61	571	58.744672000000001	58.759827000000001	53.750104999999998	53.741115999999998	0103000020E610000001000000050000009B1F7F69515F4D406B459BE3DCDE4A409B1F7F69515F4D4075C8CD7003E04A4014CFD90242614D4075C8CD7003E04A4014CFD90242614D406B459BE3DCDE4A409B1F7F69515F4D406B459BE3DCDE4A40
24731	Ниязгулово	7	61	571	58.719006999999998	58.733524000000003	53.707931000000002	53.700372999999999	0103000020E610000001000000050000002B4CDF6B085C4D402E008DD2A5D94A402B4CDF6B085C4D408C69A67B9DDA4A40626A4B1DE45D4D408C69A67B9DDA4A40626A4B1DE45D4D402E008DD2A5D94A402B4CDF6B085C4D402E008DD2A5D94A40
23233	Муракаево	7	61	571	58.688986	58.706898000000002	53.770327000000002	53.757387999999999	0103000020E6100000010000000500000070B378B130584D4001310917F2E04A4070B378B130584D40E71C3C139AE24A40CDCD37A27B5A4D40E71C3C139AE24A40CDCD37A27B5A4D4001310917F2E04A4070B378B130584D4001310917F2E04A40
58656	Махмутово	7	61	571	58.534573999999999	58.544438	53.129401999999999	53.109994999999998	0103000020E610000001000000050000005DA5BBEB6C444D409CDCEF50148E4A405DA5BBEB6C444D40BC04A73E90904A408E59F624B0454D40BC04A73E90904A408E59F624B0454D409CDCEF50148E4A405DA5BBEB6C444D409CDCEF50148E4A40
23803	Кушеево	7	61	571	58.610446000000003	58.628456999999997	53.349628000000003	53.344951999999999	0103000020E61000000100000005000000ADFC3218234E4D404B581B6327AC4A40ADFC3218234E4D4009E23C9CC0AC4A409CF86A4771504D4009E23C9CC0AC4A409CF86A4771504D404B581B6327AC4A40ADFC3218234E4D404B581B6327AC4A40
58275	Кусимовский Рудник	7	61	571	58.633865	58.680109999999999	53.615651999999997	53.597909999999999	0103000020E610000001000000050000001E8A027D22514D40C6F99B5088CC4A401E8A027D22514D40C6DB4AAFCDCE4A405ED72FD80D574D40C6DB4AAFCDCE4A405ED72FD80D574D40C6F99B5088CC4A401E8A027D22514D40C6F99B5088CC4A40
24716	Кусимово	7	61	571	58.607633999999997	58.623364000000002	53.627952000000001	53.620587	0103000020E6100000010000000500000005F86EF3C64D4D4050A912656FCF4A4005F86EF3C64D4D4099BA2BBB60D04A407BC03C64CA4F4D4099BA2BBB60D04A407BC03C64CA4F4D4050A912656FCF4A4005F86EF3C64D4D4050A912656FCF4A40
24939	Кужаново	7	61	571	58.567399000000002	58.592694999999999	53.455506	53.443123	0103000020E610000001000000050000003D64CA87A0484D407E8D2441B8B84A403D64CA87A0484D40DE9046054EBA4A4059C0046EDD4B4D40DE9046054EBA4A4059C0046EDD4B4D407E8D2441B8B84A403D64CA87A0484D407E8D2441B8B84A40
58122	Красная Башкирия	7	61	571	58.813223000000001	58.836461999999997	53.520102999999999	53.511670000000002	0103000020E6100000010000000500000071ADF6B017684D40132C0E677EC14A4071ADF6B017684D4097C62FBC92C24A40622CD32F116B4D4097C62FBC92C24A40622CD32F116B4D40132C0E677EC14A4071ADF6B017684D40132C0E677EC14A40
23992	Кирдасово	7	61	571	58.252324000000002	58.272382999999998	53.229737999999998	53.219085	0103000020E610000001000000050000007AFF1F274C204D40A7052FFA0A9C4A407AFF1F274C204D400053060E689D4A40417E3672DD224D400053060E689D4A40417E3672DD224D40A7052FFA0A9C4A407AFF1F274C204D40A7052FFA0A9C4A40
22884	Казмашево	7	61	571	58.305908000000002	58.329318000000001	53.319318000000003	53.306207000000001	0103000020E61000000100000005000000DACA4BFE27274D4034677DCA31A74A40DACA4BFE27274D4017838769DFA84A40F8FD9B17272A4D4017838769DFA84A40F8FD9B17272A4D4034677DCA31A74A40DACA4BFE27274D4034677DCA31A74A40
24331	Ишкулово	7	61	571	58.536712000000001	58.561523999999999	53.169651999999999	53.160117999999997	0103000020E6100000010000000500000075AF93FAB2444D401EC022BF7E944A4075AF93FAB2444D40BAD91F28B7954A40A5F5B704E0474D40BAD91F28B7954A40A5F5B704E0474D401EC022BF7E944A4075AF93FAB2444D401EC022BF7E944A40
23457	Ишкильдино	7	61	571	58.278599	58.293349999999997	53.434074000000003	53.423848	0103000020E6100000010000000500000062D9CC21A9234D40CD3CB9A640B64A4062D9CC21A9234D409F05A1BC8FB74A400B24287E8C254D409F05A1BC8FB74A400B24287E8C254D40CD3CB9A640B64A4062D9CC21A9234D40CD3CB9A640B64A40
25239	Ишбулдино	7	61	571	58.584071000000002	58.601956999999999	53.080838999999997	53.069516	0103000020E6100000010000000500000061C5A9D6C24A4D403D4679E6E5884A4061C5A9D6C24A4D40E49EAEEE588A4A40944C4EED0C4D4D40E49EAEEE588A4A40944C4EED0C4D4D403D4679E6E5884A4061C5A9D6C24A4D403D4679E6E5884A40
12631	Еникеево	7	61	571	58.776328999999997	58.791510000000002	53.771768999999999	53.760832000000001	0103000020E61000000100000005000000DBF7A8BF5E634D4009E066F162E14A40DBF7A8BF5E634D4087889B53C9E24A407E3A1E3350654D4087889B53C9E24A407E3A1E3350654D4009E066F162E14A40DBF7A8BF5E634D4009E066F162E14A40
24230	Давлетшино	7	61	571	58.622304	58.634269000000003	53.197944	53.191119999999998	0103000020E61000000100000005000000C21550A8A74F4D4046CEC29E76984A40C21550A8A74F4D403F389F3A56994A40EEEE01BA2F514D403F389F3A56994A40EEEE01BA2F514D4046CEC29E76984A40C21550A8A74F4D4046CEC29E76984A40
32901	Давлетово	7	61	571	58.663302999999999	58.682229999999997	53.352912000000003	53.345387000000002	0103000020E610000001000000050000005A2BDA1CE7544D4056BB26A435AC4A405A2BDA1CE7544D40D82E6D382CAD4A40CF2C095053574D40D82E6D382CAD4A40CF2C095053574D4056BB26A435AC4A405A2BDA1CE7544D4056BB26A435AC4A40
23580	Гусево	7	61	571	58.718108999999998	58.756825999999997	53.271191000000002	53.264232999999997	0103000020E610000001000000050000004CFBE6FEEA5B4D4011C30E63D2A14A404CFBE6FEEA5B4D401AFCFD62B6A24A409961A3ACDF604D401AFCFD62B6A24A409961A3ACDF604D4011C30E63D2A14A404CFBE6FEEA5B4D4011C30E63D2A14A40
23417	Бурангулово	7	61	571	58.341023	58.357866999999999	53.480527000000002	53.464711000000001	0103000020E61000000100000005000000871744A4A62B4D40B58B69A67BBB4A40871744A4A62B4D4029ECA2E881BD4A40A8A8FA95CE2D4D4029ECA2E881BD4A40A8A8FA95CE2D4D40B58B69A67BBB4A40871744A4A62B4D40B58B69A67BBB4A40
58453	Булатово	7	61	571	58.659466999999999	58.672573	53.057015	53.049633	0103000020E6100000010000000500000047E5266A69544D40B4E6C75F5A864A4047E5266A69544D40D3307C444C874A4018963FDF16564D40D3307C444C874A4018963FDF16564D40B4E6C75F5A864A4047E5266A69544D40B4E6C75F5A864A40
58110	Баимово	7	61	571	58.831369000000002	58.848256999999997	53.741653999999997	53.717027999999999	0103000020E6100000010000000500000041F4A44C6A6A4D407C28D192C7DB4A4041F4A44C6A6A4D404A79AD84EEDE4A4031CD74AF936C4D404A79AD84EEDE4A4031CD74AF936C4D407C28D192C7DB4A4041F4A44C6A6A4D407C28D192C7DB4A40
24584	Аюсазово	7	61	571	58.705964000000002	58.719231999999998	53.590972999999998	53.581977000000002	0103000020E61000000100000005000000A11342075D5A4D401903EB387ECA4A40A11342075D5A4D40D5E8D500A5CB4A404B1E4FCB0F5C4D40D5E8D500A5CB4A404B1E4FCB0F5C4D401903EB387ECA4A40A11342075D5A4D401903EB387ECA4A40
58385	Ахметово	7	61	571	58.173811000000001	58.188192999999998	53.233144000000003	53.225408999999999	0103000020E61000000100000005000000B05758703F164D40AE9CBD33DA9C4A40B05758703F164D401BA19FA9D79D4A40062B4EB516184D401BA19FA9D79D4A40062B4EB516184D40AE9CBD33DA9C4A40B05758703F164D40AE9CBD33DA9C4A40
58831	Атавды	7	61	571	58.650025999999997	58.702936999999999	53.182076000000002	53.147897999999998	0103000020E610000001000000050000005CC64D0D34534D4068925852EE924A405CC64D0D34534D4079B130444E974A40FD12F1D6F9594D4079B130444E974A40FD12F1D6F9594D4068925852EE924A405CC64D0D34534D4068925852EE924A40
49432	Аскарово	7	61	571	58.496962000000003	58.525770999999999	53.348106999999999	53.326718	0103000020E6100000010000000500000069AD68739C3F4D40DC813AE5D1A94A4069AD68739C3F4D401C412AC58EAC4A40B517D1764C434D401C412AC58EAC4A40B517D1764C434D40DC813AE5D1A94A4069AD68739C3F4D40DC813AE5D1A94A40
22558	Альмухаметово	7	61	571	58.677218000000003	58.775457000000003	53.027681999999999	53.007199999999997	0103000020E610000001000000050000009B215514AF564D40FE43FAEDEB804A409B215514AF564D400C5872158B834A40263ACB2C42634D400C5872158B834A40263ACB2C42634D40FE43FAEDEB804A409B215514AF564D40FE43FAEDEB804A40
58855	Авняш	7	61	571	57.854460000000003	58.989113000000003	53.877538999999999	52.857525000000003	0103000020E61000000100000005000000BEDEFDF15EED4C404F401361C36D4A40BEDEFDF15EED4C4076FBAC3253F04A40348639419B7E4D4076FBAC3253F04A40348639419B7E4D404F401361C36D4A40BEDEFDF15EED4C404F401361C36D4A40
24832	Абзелилово	7	61	571	58.650843000000002	58.673121000000002	53.470847999999997	53.464716000000003	0103000020E610000001000000050000004FEACBD24E534D40C7F65AD07BBB4A404FEACBD24E534D4089B14CBF44BC4A401BA034D428564D4089B14CBF44BC4A401BA034D428564D40C7F65AD07BBB4A404FEACBD24E534D40C7F65AD07BBB4A40
25163	Абдулмамбетово	7	61	571	58.537852999999998	58.550986000000002	53.113227000000002	53.099922999999997	0103000020E610000001000000050000001A87FA5DD8444D40218FE046CA8C4A401A87FA5DD8444D401903EB387E8E4A40E54691B586464D401903EB387E8E4A40E54691B586464D40218FE046CA8C4A401A87FA5DD8444D40218FE046CA8C4A40
22799	Абдулгазино	7	61	571	58.241463000000003	58.256805999999997	53.348466999999999	53.334634000000001	0103000020E61000000100000005000000D7187442E81E4D4099107349D5AA4A40D7187442E81E4D401C5E10919AAC4A4052B5DD04DF204D401C5E10919AAC4A4052B5DD04DF204D4099107349D5AA4A40D7187442E81E4D4099107349D5AA4A40
6621	рабочий поселок Ишеевка	7	74	\N	48.239944000000001	48.302143000000001	54.437072000000001	54.415104999999997	0103000020E610000001000000050000008B6F287CB61E4840FAB31F2922354B408B6F287CB61E4840A8FFACF9F1374B4090DB2F9FAC264840A8FFACF9F1374B4090DB2F9FAC264840FAB31F2922354B408B6F287CB61E4840FAB31F2922354B40
72	Ульяновск	7	74	\N	48.142719	48.692982000000001	54.421596000000001	54.184033999999997	0103000020E6100000010000000500000048C2BE9D4412484010AD156D8E174B4048C2BE9D44124840ED0F94DBF6354B40BC5B59A2B3584840ED0F94DBF6354B40BC5B59A2B358484010AD156D8E174B4048C2BE9D4412484010AD156D8E174B40
55840	Лаишевка	7	74	\N	48.200445000000002	48.213569	54.412416999999998	54.401972999999998	0103000020E61000000100000005000000C8D2872EA81948400070ECD973334B40C8D2872EA81948403FA88B14CA344B403F389F3A561B48403FA88B14CA344B403F389F3A561B48400070ECD973334B40C8D2872EA81948400070ECD973334B40
22727	Колхозный	7	74	\N	48.560462999999999	48.576866000000003	54.326715999999998	54.314475000000002	0103000020E610000001000000050000001CCF6740BD4748406E3480B740284B401CCF6740BD4748403B8A73D4D1294B405116BEBED64948403B8A73D4D1294B405116BEBED64948406E3480B740284B401CCF6740BD4748406E3480B740284B40
55765	Ишеевка	7	74	\N	48.239944000000001	48.302143000000001	54.437072000000001	54.415104999999997	0103000020E610000001000000050000008B6F287CB61E4840FAB31F2922354B408B6F287CB61E4840A8FFACF9F1374B4090DB2F9FAC264840A8FFACF9F1374B4090DB2F9FAC264840FAB31F2922354B408B6F287CB61E4840FAB31F2922354B40
12983	Димитровград	7	74	\N	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
23336	Барыш	7	74	\N	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
22638	Чувашский Калмаюр	7	74	1666	48.968764999999998	48.985528000000002	54.202534999999997	54.190994000000003	0103000020E610000001000000050000003541D47D007C4840BADDCB7D72184B403541D47D007C4840CEA5B8AAEC194B406AA510C8257E4840CEA5B8AAEC194B406AA510C8257E4840BADDCB7D72184B403541D47D007C4840BADDCB7D72184B40
21430	Чердаклы	7	74	1666	48.811326000000001	48.879814000000003	54.385680999999998	54.333022	0103000020E610000001000000050000007F32C687D96748409C6C0377A02A4B407F32C687D967484023D8B8FE5D314B400F48C2BE9D70484023D8B8FE5D314B400F48C2BE9D7048409C6C0377A02A4B407F32C687D96748409C6C0377A02A4B40
22682	Уразгильдино	7	74	1666	48.865997999999998	48.892031000000003	54.157381000000001	54.144455999999998	0103000020E610000001000000050000006133C005D96E484001DBC1887D124B406133C005D96E48408201840F25144B40540262122E7248408201840F25144B40540262122E72484001DBC1887D124B406133C005D96E484001DBC1887D124B40
22185	Суходол	7	74	1666	49.014471	49.069187999999997	54.046756000000002	54.004140999999997	0103000020E61000000100000005000000C6DE8B2FDA8148404FC939B187004B40C6DE8B2FDA8148402672C119FC054B4048A30227DB8848402672C119FC054B4048A30227DB8848404FC939B187004B40C6DE8B2FDA8148404FC939B187004B40
22140	Старый Белый Яр	7	74	1666	48.882086999999999	48.922097999999998	53.999139999999997	53.962387999999997	0103000020E61000000100000005000000069D103AE87048400B08AD872FFB4A40069D103AE87048400E10CCD1E3FF4A407FDAA84E077648400E10CCD1E3FF4A407FDAA84E077648400B08AD872FFB4A40069D103AE87048400B08AD872FFB4A40
47687	Старое Уренбаш	7	74	1666	48.955838	48.972062000000001	54.344124000000001	54.331162999999997	0103000020E6100000010000000500000014234BE6587A48409752978C632A4B4014234BE6587A484065E256410C2C4B4099D711876C7C484065E256410C2C4B4099D711876C7C48409752978C632A4B4014234BE6587A48409752978C632A4B40
22330	Старое Матюшкино	7	74	1666	49.123635	49.150421999999999	54.360830999999997	54.346811000000002	0103000020E610000001000000050000000BD28C45D38F48405072874D642C4B400BD28C45D38F48400531D0B52F2E4B40A94C3107419348400531D0B52F2E4B40A94C3107419348405072874D642C4B400BD28C45D38F48405072874D642C4B40
22497	Старое Еремкино	7	74	1666	49.257348999999998	49.292409999999997	54.325955	54.309438	0103000020E610000001000000050000004354E1CFF0A04840E01115AA9B274B404354E1CFF0A04840DD7BB8E4B8294B40FD82DDB06DA54840DD7BB8E4B8294B40FD82DDB06DA54840E01115AA9B274B404354E1CFF0A04840E01115AA9B274B40
22406	Станция Бряндино	7	74	1666	49.343003000000003	49.366683000000002	54.347824000000003	54.334245000000003	0103000020E6100000010000000500000007B7B585E7AB4840FFEC478AC82A4B4007B7B585E7AB4840C861307F852C4B40E57FF277EFAE4840C861307F852C4B40E57FF277EFAE4840FFEC478AC82A4B4007B7B585E7AB4840FFEC478AC82A4B40
23256	Пятисотенный	7	74	1666	48.812117000000001	48.830775000000003	54.236879000000002	54.22099	0103000020E6100000010000000500000048C32973F36748401C5F7B66491C4B4048C32973F3674840FA0D130D521E4B40CEAACFD5566A4840FA0D130D521E4B40CEAACFD5566A48401C5F7B66491C4B4048C32973F36748401C5F7B66491C4B40
22589	Поповка	7	74	1666	48.913600000000002	48.951400999999997	54.247281000000001	54.231633000000002	0103000020E6100000010000000500000014D044D8F074484052D66F26A61D4B4014D044D8F07448400AF65FE7A61F4B40DB300A82C77948400AF65FE7A61F4B40DB300A82C779484052D66F26A61D4B4014D044D8F074484052D66F26A61D4B40
22272	Петровское	7	74	1666	49.001894999999998	49.034773000000001	54.390791999999998	54.374538000000001	0103000020E61000000100000005000000518369183E804840FC8D76DCF02F4B40518369183E804840EBC4E57805324B4054E4107173844840EBC4E57805324B4054E4107173844840FC8D76DCF02F4B40518369183E804840FC8D76DCF02F4B40
23198	Первомайский	7	74	1666	48.709071000000002	48.737323000000004	54.291778999999998	54.273282999999999	0103000020E6100000010000000500000061C5A9D6C25A4840C1C6F5EFFA224B4061C5A9D6C25A48406D54A70359254B4058CB9D99605E48406D54A70359254B4058CB9D99605E4840C1C6F5EFFA224B4061C5A9D6C25A4840C1C6F5EFFA224B40
23119	Октябрьский	7	74	1666	48.673633000000002	48.726849000000001	54.347335999999999	54.329410000000003	0103000020E61000000100000005000000D1402C9B39564840D97C5C1B2A2A4B40D1402C9B395648409A5C8C81752C4B40AE105663095D48409A5C8C81752C4B40AE105663095D4840D97C5C1B2A2A4B40D1402C9B39564840D97C5C1B2A2A4B40
22971	Озерки	7	74	1666	49.063752999999998	49.099677	54.301726000000002	54.269570999999999	0103000020E61000000100000005000000CD02ED0E298848409A79724D81224B40CD02ED0E298848402C2D23F59E264B40EA944737C28C48402C2D23F59E264B40EA944737C28C48409A79724D81224B40CD02ED0E298848409A79724D81224B40
22104	Новый Белый Яр	7	74	1666	48.935267000000003	48.995947999999999	53.981506000000003	53.962901000000002	0103000020E6100000010000000500000097033DD4B67748409224085740FB4A4097033DD4B6774840F56915FDA1FD4A4020425C397B7F4840F56915FDA1FD4A4020425C397B7F48409224085740FB4A4097033DD4B67748409224085740FB4A40
22883	Мирный	7	74	1666	48.712090000000003	48.750897000000002	54.374049999999997	54.357505000000003	0103000020E6100000010000000500000082E7DEC3255B484008944DB9C22D4B4082E7DEC3255B4840CE88D2DEE02F4B400FD594641D604840CE88D2DEE02F4B400FD594641D60484008944DB9C22D4B4082E7DEC3255B484008944DB9C22D4B40
22924	Малаевка	7	74	1666	49.000726999999998	49.024362000000004	54.327677000000001	54.315116000000003	0103000020E61000000100000005000000B29C84D217804840223999B855284B40B29C84D2178048406153E751F1294B40F1A1444B1E8348406153E751F1294B40F1A1444B1E834840223999B855284B40B29C84D217804840223999B855284B40
22788	Крестово-Городище	7	74	1666	48.611173000000001	48.652208000000002	54.198163000000001	54.171571	0103000020E610000001000000050000005F99B7EA3A4E484094F8DC09F6154B405F99B7EA3A4E48407D23BA675D194B4044183F8D7B5348407D23BA675D194B4044183F8D7B53484094F8DC09F6154B405F99B7EA3A4E484094F8DC09F6154B40
22754	Красный Яр	7	74	1666	48.536487000000001	48.568691000000001	54.249758999999997	54.234138000000002	0103000020E6100000010000000500000055DD239BAB4448401C60E63BF81D4B4055DD239BAB444840DA70581AF81F4B40C843DFDDCA484840DA70581AF81F4B40C843DFDDCA4848401C60E63BF81D4B4055DD239BAB4448401C60E63BF81D4B40
21842	Енганаево	7	74	1666	48.879266000000001	48.910536	54.434815	54.417248000000001	0103000020E610000001000000050000000C3ECDC98B7048402429E96168354B400C3ECDC98B704840B6679604A8374B4053EA92718C744840B6679604A8374B4053EA92718C7448402429E96168354B400C3ECDC98B7048402429E96168354B40
22230	Богдашкино	7	74	1666	49.069744999999998	49.097251	54.393712000000001	54.381722000000003	0103000020E610000001000000050000009E077767ED884840F5143944DC304B409E077767ED8848407905A22765324B406C4084B8728C48407905A22765324B406C4084B8728C4840F5143944DC304B409E077767ED884840F5143944DC304B40
22837	Архангельское	7	74	1666	48.640413000000002	48.678331	54.440967999999998	54.419065000000003	0103000020E6100000010000000500000075779D0DF9514840FAF202ECA3354B4075779D0DF9514840904AB1A371384B40766EDA8CD3564840904AB1A371384B40766EDA8CD3564840FAF202ECA3354B4075779D0DF9514840FAF202ECA3354B40
22539	Андреевка	7	74	1666	48.817892999999998	48.855711999999997	54.15437	54.139724999999999	0103000020E610000001000000050000004C50C3B7B068484080B74082E2114B404C50C3B7B0684840E4BD6A65C2134B40BA6587F8876D4840E4BD6A65C2134B40BA6587F8876D484080B74082E2114B404C50C3B7B068484080B74082E2114B40
55836	Абдулово	7	74	1666	49.449596999999997	49.473923999999997	54.430202000000001	54.413674	0103000020E610000001000000050000009AB0FD648CB948404E9A0645F3344B409AB0FD648CB948403F56F0DB10374B400E65A88AA9BC48403F56F0DB10374B400E65A88AA9BC48404E9A0645F3344B409AB0FD648CB948404E9A0645F3344B40
21660	Чириково	7	74	1610	47.693921000000003	47.735235000000003	54.493974000000001	54.481181999999997	0103000020E61000000100000005000000FA804067D2D8474041B62C5F973D4B40FA804067D2D8474083893F8A3A3F4B40F2EF332E1CDE474083893F8A3A3F4B40F2EF332E1CDE474041B62C5F973D4B40FA804067D2D8474041B62C5F973D4B40
20019	Цильна	7	74	1610	48.122759000000002	48.166471000000001	54.605364999999999	54.580561000000003	0103000020E6100000010000000500000014252191B60F4840A22AA6D24F4A4B4014252191B60F48404F92AE997C4D4B40C05DF6EB4E1548404F92AE997C4D4B40C05DF6EB4E154840A22AA6D24F4A4B4014252191B60F4840A22AA6D24F4A4B40
21612	Устеренка	7	74	1610	47.775398000000003	47.793813999999998	54.452302000000003	54.431108000000002	0103000020E6100000010000000500000021B1DD3D40E34740A185048C2E374B4021B1DD3D40E347402CF52C08E5394B40B08D78B29BE547402CF52C08E5394B40B08D78B29BE54740A185048C2E374B4021B1DD3D40E34740A185048C2E374B40
21555	Тимофеевка	7	74	1610	47.558356000000003	47.579610000000002	54.419443000000001	54.409933000000002	0103000020E6100000010000000500000040C39B3578C747408D463EAF78344B4040C39B3578C74740A0C4E74EB0354B40A03715A930CA4740A0C4E74EB0354B40A03715A930CA47408D463EAF78344B4040C39B3578C747408D463EAF78344B40
19949	Телешовка	7	74	1610	48.180340999999999	48.199852	54.602803999999999	54.587927999999998	0103000020E610000001000000050000006090F469151748408B338639414B4B406090F46915174840F1F274AE284D4B40250516C094194840F1F274AE284D4B40250516C0941948408B338639414B4B406090F469151748408B338639414B4B40
21377	Сухая Бугурна	7	74	1610	48.059534999999997	48.084651999999998	54.643754000000001	54.634447999999999	0103000020E61000000100000005000000D2FBC6D79E0748409D81919735514B40D2FBC6D79E074840A855F48766524B403FC571E0D50A4840A855F48766524B403FC571E0D50A48409D81919735514B40D2FBC6D79E0748409D81919735514B40
20458	Степное Анненково	7	74	1610	47.836599999999997	47.871220999999998	54.402920999999999	54.373629999999999	0103000020E61000000100000005000000B3EA73B515EB4740F9669B1BD32F4B40B3EA73B515EB474091EF52EA92334B40514B732B84EF474091EF52EA92334B40514B732B84EF4740F9669B1BD32F4B40B3EA73B515EB4740F9669B1BD32F4B40
20353	Старые Алгаши	7	74	1610	47.717357999999997	47.763379	54.679170999999997	54.642977999999999	0103000020E6100000010000000500000011C30E63D2DB47401406651A4D524B4011C30E63D2DB474020B24813EF564B4002BA2F67B6E1474020B24813EF564B4002BA2F67B6E147401406651A4D524B4011C30E63D2DB47401406651A4D524B40
55827	Средний Алгаши	7	74	1610	47.762013000000003	47.788307000000003	54.705022999999997	54.689539000000003	0103000020E610000001000000050000003D1059A489E1474085285FD042584B403D1059A489E14740C2F693313E5A4B409C1A683EE7E44740C2F693313E5A4B409C1A683EE7E4474085285FD042584B403D1059A489E1474085285FD042584B40
21812	Средние Тимерсяны	7	74	1610	47.694541000000001	47.741514000000002	54.559818999999997	54.54242	0103000020E61000000100000005000000965D30B8E6D847402159C0046E454B40965D30B8E6D84740F7562426A8474B4059C345EEE9DE4740F7562426A8474B4059C345EEE9DE47402159C0046E454B40965D30B8E6D847402159C0046E454B40
21006	Солнце	7	74	1610	47.979971999999997	48.005564999999997	54.451528000000003	54.446151	0103000020E61000000100000005000000737FF5B86FFD4740F209D9791B394B40737FF5B86FFD4740399D64ABCB394B4049809A5AB6004840399D64ABCB394B4049809A5AB6004840F209D9791B394B40737FF5B86FFD4740F209D9791B394B40
55814	Садки	7	74	1610	47.974131999999997	47.994757999999997	54.552123000000002	54.541124000000003	0103000020E6100000010000000500000058FE7C5BB0FC4740558A1D8D43454B4058FE7C5BB0FC4740492F6AF7AB464B4099B7EA3A54FF4740492F6AF7AB464B4099B7EA3A54FF4740558A1D8D43454B4058FE7C5BB0FC4740558A1D8D43454B40
21341	Русская Цильна	7	74	1610	47.932496	47.976045999999997	54.713240999999996	54.698805999999998	0103000020E610000001000000050000004ED367075CF74740D11F9A7972594B404ED367075CF747404A95287B4B5B4B4020B24813EFFC47404A95287B4B5B4B4020B24813EFFC4740D11F9A7972594B404ED367075CF74740D11F9A7972594B40
21285	Покровское	7	74	1610	48.060639999999999	48.092520999999998	54.602257000000002	54.584108999999998	0103000020E610000001000000050000002B6A300DC30748404E266E15C44A4B402B6A300DC3074840BF64E3C1164D4B40BB9866BAD70B4840BF64E3C1164D4B40BB9866BAD70B48404E266E15C44A4B402B6A300DC30748404E266E15C44A4B40
20384	Пилюгино	7	74	1610	47.883096999999999	47.911456999999999	54.449841999999997	54.430295999999998	0103000020E610000001000000050000000D198F5209F14740C0CC77F013374B400D198F5209F14740012F336C94394B40EA5A7B9FAAF44740012F336C94394B40EA5A7B9FAAF44740C0CC77F013374B400D198F5209F14740C0CC77F013374B40
20916	Орловка	7	74	1610	47.818930999999999	47.838146000000002	54.614713999999999	54.604306000000001	0103000020E610000001000000050000001D5723BBD2E84740676325E6594D4B401D5723BBD2E847405932C7F2AE4E4B40F9A23D5E48EB47405932C7F2AE4E4B40F9A23D5E48EB4740676325E6594D4B401D5723BBD2E84740676325E6594D4B40
20798	Норовка	7	74	1610	47.913200000000003	47.933250000000001	54.519840000000002	54.512993000000002	0103000020E61000000100000005000000865AD3BCE3F44740D9092FC1A9414B40865AD3BCE3F447408A93FB1D8A424B40FA7E6ABC74F747408A93FB1D8A424B40FA7E6ABC74F74740D9092FC1A9414B40865AD3BCE3F44740D9092FC1A9414B40
20805	Новые Тимерсяны	7	74	1610	47.827959	47.865004999999996	54.549517000000002	54.532071999999999	0103000020E61000000100000005000000E5B67D8FFAE94740048F6FEF1A444B40E5B67D8FFAE947404BCCB39256464B4030F0DC7BB8EE47404BCCB39256464B4030F0DC7BB8EE4740048F6FEF1A444B40E5B67D8FFAE94740048F6FEF1A444B40
20222	Новые Алгаши	7	74	1610	47.723323000000001	47.769505000000002	54.727167000000001	54.705433999999997	0103000020E61000000100000005000000E9B81AD995DC474044BE4BA94B5A4B40E9B81AD995DC47407FDDE9CE135D4B40E38DCC237FE247407FDDE9CE135D4B40E38DCC237FE2474044BE4BA94B5A4B40E9B81AD995DC474044BE4BA94B5A4B40
21513	Новое Никулино	7	74	1610	47.677976000000001	47.696418000000001	54.449261	54.432746999999999	0103000020E6100000010000000500000088BCE5EAC7D647409738F24064374B4088BCE5EAC7D64740232F6B6281394B40412C9B3924D94740232F6B6281394B40412C9B3924D947409738F24064374B4088BCE5EAC7D647409738F24064374B40
20711	Новая Воля	7	74	1610	47.913451000000002	47.929855000000003	54.600816999999999	54.593071999999999	0103000020E61000000100000005000000CFBF5DF6EBF447402F1686C8E94B4B40CFBF5DF6EBF44740BFF04A92E74C4B40D482177D05F74740BFF04A92E74C4B40D482177D05F747402F1686C8E94B4B40CFBF5DF6EBF447402F1686C8E94B4B40
21757	Нижние Тимерсяны	7	74	1610	47.739313000000003	47.794657999999998	54.558832000000002	54.539583999999998	0103000020E61000000100000005000000FB40F2CEA1DE4740F1B8A81611454B40FB40F2CEA1DE4740A9FA95CE87474B409CC0745AB7E54740A9FA95CE87474B409CC0745AB7E54740F1B8A81611454B40FB40F2CEA1DE4740F1B8A81611454B40
21221	Мокрая Бугурна	7	74	1610	48.030645999999997	48.064746	54.684100000000001	54.669018999999999	0103000020E6100000010000000500000069E04735EC03484089B3226AA2554B4069E04735EC034840C898BB9690574B40FE45D09849084840C898BB9690574B40FE45D0984908484089B3226AA2554B4069E04735EC03484089B3226AA2554B40
20699	Малое Нагаткино	7	74	1610	47.880986	47.911951000000002	54.636819000000003	54.620662000000003	0103000020E61000000100000005000000EF1D3526C4F047405BEF37DA714F4B40EF1D3526C4F04740583CF54883514B40FA4674CFBAF44740583CF54883514B40FA4674CFBAF447405BEF37DA714F4B40EF1D3526C4F047405BEF37DA714F4B40
55828	Кундрюковка	7	74	1610	48.107047000000001	48.141191999999997	54.730145999999998	54.714744000000003	0103000020E61000000100000005000000451152B7B30D484091813CBB7C5B4B40451152B7B30D484011A7936C755D4B40793A57941212484011A7936C755D4B40793A57941212484091813CBB7C5B4B40451152B7B30D484091813CBB7C5B4B40
20601	Крестниково	7	74	1610	48.042476000000001	48.083241999999998	54.518507	54.498685000000002	0103000020E61000000100000005000000B56E83DA6F054840BD00FBE8D43F4B40B56E83DA6F054840A0DFF76F5E424B40AAD381ACA70A4840A0DFF76F5E424B40AAD381ACA70A4840BD00FBE8D43F4B40B56E83DA6F054840BD00FBE8D43F4B40
21456	Карабаевка	7	74	1610	47.706865999999998	47.732719000000003	54.435203000000001	54.421889	0103000020E61000000100000005000000C153C8957ADA474065C5707500364B40C153C8957ADA4740800F5EBBB4374B40341477BCC9DD4740800F5EBBB4374B40341477BCC9DD474065C5707500364B40C153C8957ADA474065C5707500364B40
21090	Кайсарово	7	74	1610	48.197076000000003	48.214378000000004	54.718671000000001	54.698562000000003	0103000020E61000000100000005000000CB694FC9391948403B1DC87A6A594B40CB694FC939194840B4CA4C69FD5B4B40AF7D01BD701B4840B4CA4C69FD5B4B40AF7D01BD701B48403B1DC87A6A594B40CB694FC9391948403B1DC87A6A594B40
55792	Елховое Озеро	7	74	1610	48.180458000000002	48.209249	54.699071000000004	54.676433000000003	0103000020E610000001000000050000009A266C3F19174840B477465B95564B409A266C3F19174840804A95287B594B4040DCD5ABC81A4840804A95287B594B4040DCD5ABC81A4840B477465B95564B409A266C3F19174840B477465B95564B40
21691	Верхний Тимерсяны	7	74	1610	47.634892999999998	47.675676000000003	54.551673999999998	54.534846000000002	0103000020E61000000100000005000000CBBA7F2C44D14740BE326FD575444B40CBBA7F2C44D14740D906EE409D464B409758198D7CD64740D906EE409D464B409758198D7CD64740BE326FD575444B40CBBA7F2C44D14740BE326FD575444B40
20481	Большое Нагаткино	7	74	1610	47.945880000000002	47.986727000000002	54.526423999999999	54.507657000000002	0103000020E6100000010000000500000062F8889812F94740F14A92E7FA404B4062F8889812F947402DEA93DC61434B40448A01124DFE47402DEA93DC61434B40448A01124DFE4740F14A92E7FA404B4062F8889812F94740F14A92E7FA404B40
21185	Богородская Репьевка	7	74	1610	48.071311999999999	48.107326	54.571449000000001	54.554833000000002	0103000020E61000000100000005000000FBE769C020094840ECDE8AC404474B40FBE769C0200948407C2AA73D25494B405801BEDBBC0D48407C2AA73D25494B405801BEDBBC0D4840ECDE8AC404474B40FBE769C020094840ECDE8AC404474B40
20144	Богдашкино	7	74	1610	47.654988000000003	47.693966000000003	54.627637	54.600696999999997	0103000020E61000000100000005000000E0A293A5D6D3474014E7A8A3E34C4B40E0A293A5D6D347403961C26856504B409A44BDE0D3D847403961C26856504B409A44BDE0D3D8474014E7A8A3E34C4B40E0A293A5D6D3474014E7A8A3E34C4B40
19921	Арбузовка	7	74	1610	48.220180999999997	48.243698999999999	54.572367999999997	54.538685000000001	0103000020E61000000100000005000000AC1919E42E1C484042EC4CA1F3444B40AC1919E42E1C484072A3C85A43494B40B1886187311F484072A3C85A43494B40B1886187311F484042EC4CA1F3444B40AC1919E42E1C484042EC4CA1F3444B40
18733	разъезд Большие Ключищи	7	74	505	48.274053000000002	48.282640999999998	54.12041	54.114130000000003	0103000020E61000000100000005000000732F302B142348400ABFD4CF9B0E4B40732F302B14234840410E4A98690F4B401EC18D942D244840410E4A98690F4B401EC18D942D2448400ABFD4CF9B0E4B40732F302B142348400ABFD4CF9B0E4B40
55778	п. Тимирязевский	7	74	505	47.820799000000001	48.549529999999997	54.694524000000001	54.053797000000003	0103000020E6100000010000000500000075CB0EF10FE94740BCCFF1D1E2064B4075CB0EF10FE94740C0249529E6584B40DF15C1FF56464840C0249529E6584B40DF15C1FF56464840BCCFF1D1E2064B4075CB0EF10FE94740BCCFF1D1E2064B40
19544	Шумовка	7	74	505	48.199537999999997	48.233826000000001	54.521528000000004	54.506082999999997	0103000020E61000000100000005000000952710768A194840E107E753C7404B40952710768A19484062F9F36DC1424B402D7AA702EE1D484062F9F36DC1424B402D7AA702EE1D4840E107E753C7404B40952710768A194840E107E753C7404B40
19599	Ундоры	7	74	505	48.373182	48.416426999999999	54.616897999999999	54.597641000000003	0103000020E610000001000000050000005ABA826DC42F4840D7DF12807F4C4B405ABA826DC42F4840E17B7F83F64E4B40F015DD7A4D354840E17B7F83F64E4B40F015DD7A4D354840D7DF12807F4C4B405ABA826DC42F4840D7DF12807F4C4B40
3044	Салмановка	7	74	505	48.251486999999997	48.283718999999998	54.481228999999999	54.449413	0103000020E61000000100000005000000402FDCB930204840D9B27C5D86394B40402FDCB930204840827170E9983D4B407D2079E750244840827170E9983D4B407D2079E750244840D9B27C5D86394B40402FDCB930204840D9B27C5D86394B40
19807	Русская Беденьга	7	74	505	48.332478999999999	48.349485000000001	54.685156999999997	54.668202000000001	0103000020E61000000100000005000000ABCDFFAB8E2A4840978FA4A487554B40ABCDFFAB8E2A48400FD07D39B3574B40A6B8AAECBB2C48400FD07D39B3574B40A6B8AAECBB2C4840978FA4A487554B40ABCDFFAB8E2A4840978FA4A487554B40
18834	Поникий Ключ	7	74	505	48.207720999999999	48.224834000000001	54.080596999999997	54.06982	0103000020E61000000100000005000000A1D80A9A961A4840A94D9CDCEF084B40A1D80A9A961A4840EE93A300510A4B40B2834A5CC71C4840EE93A300510A4B40B2834A5CC71C4840A94D9CDCEF084B40A1D80A9A961A4840A94D9CDCEF084B40
55815	Панская Слобода	7	74	505	48.470658	48.503680000000003	54.118822000000002	54.108941999999999	0103000020E61000000100000005000000E6CC76853E3C48409694BBCFF10D4B40E6CC76853E3C4840CD052E8F350F4B401CD3139678404840CD052E8F350F4B401CD31396784048409694BBCFF10D4B40E6CC76853E3C48409694BBCFF10D4B40
55788	Охотничья	7	74	505	48.066398	48.089044999999999	54.216852000000003	54.205505000000002	0103000020E610000001000000050000008942CBBA7F0848400E15E3FC4D1A4B408942CBBA7F0848403E096CCEC11B4B40A86F99D3650B48403E096CCEC11B4B40A86F99D3650B48400E15E3FC4D1A4B408942CBBA7F0848400E15E3FC4D1A4B40
19405	Новый Урень	7	74	505	48.114674000000001	48.150956999999998	54.429640999999997	54.412244000000001	0103000020E61000000100000005000000CBD93BA3AD0E484072FC5069C4344B40CBD93BA3AD0E4840A702EE79FE364B40170D198F52134840A702EE79FE364B40170D198F5213484072FC5069C4344B40CBD93BA3AD0E484072FC5069C4344B40
18656	Новая Беденьга	7	74	505	48.344408999999999	48.374322999999997	54.501660000000001	54.491427000000002	0103000020E610000001000000050000005AB91798152C48408AAF7614E73E4B405AB91798152C48400EDB166536404B40FF91E9D0E92F48400EDB166536404B40FF91E9D0E92F48408AAF7614E73E4B405AB91798152C48408AAF7614E73E4B40
55791	Меловой	7	74	505	48.313839000000002	48.339477000000002	54.123533999999999	54.113486000000002	0103000020E61000000100000005000000CC9A58E02B284840E54691B5860E4B40CC9A58E02B284840D7F84CF6CF0F4B40425F7AFB732B4840D7F84CF6CF0F4B40425F7AFB732B4840E54691B5860E4B40CC9A58E02B284840E54691B5860E4B40
18844	Ломы	7	74	505	48.319471999999998	48.337501000000003	54.087980999999999	54.077454000000003	0103000020E610000001000000050000006DFE5F75E4284840E2783E03EA094B406DFE5F75E4284840AED51EF6420B4B4004AF963B332B4840AED51EF6420B4B4004AF963B332B4840E2783E03EA094B406DFE5F75E4284840E2783E03EA094B40
55779	Липки	7	74	505	48.390878999999998	48.413490000000003	54.116985	54.107638000000001	0103000020E61000000100000005000000BAD8B4520832484047E7FC14C70D4B40BAD8B45208324840B08F4E5DF90E4B408D9C853DED344840B08F4E5DF90E4B408D9C853DED34484047E7FC14C70D4B40BAD8B4520832484047E7FC14C70D4B40
19750	Крутояр	7	74	505	48.389918000000002	48.408718999999998	54.647708000000002	54.638299000000004	0103000020E61000000100000005000000950F41D5E8314840E60819C8B3514B40950F41D5E8314840C5AD8218E8524B407D2079E750344840C5AD8218E8524B407D2079E750344840E60819C8B3514B40950F41D5E8314840E60819C8B3514B40
55762	Криуши	7	74	505	48.511172000000002	48.549529999999997	54.112895000000002	54.090077000000001	0103000020E61000000100000005000000C25087156E414840978FA4A4870B4B40C25087156E414840E370E657730E4B40DF15C1FF56464840E370E657730E4B40DF15C1FF56464840978FA4A4870B4B40C25087156E414840978FA4A4870B4B40
19048	Ивановка	7	74	505	48.089593000000001	48.111080999999999	54.199168999999998	54.180135	0103000020E61000000100000005000000AB798EC8770B4840B7EEE6A90E174B40AB798EC8770B484042B0AA5E7E194B407E1AF7E6370E484042B0AA5E7E194B407E1AF7E6370E4840B7EEE6A90E174B40AB798EC8770B4840B7EEE6A90E174B40
55780	Зеленая Роща	7	74	505	48.010586000000004	48.031264999999998	54.167824000000003	54.154153999999998	0103000020E61000000100000005000000D2E5CDE15A01484017467A51BB134B40D2E5CDE15A014840F1BDBF417B154B403541D47D00044840F1BDBF417B154B403541D47D0004484017467A51BB134B40D2E5CDE15A01484017467A51BB134B40
19310	Загудаевка	7	74	505	47.950426	47.979415000000003	54.405631	54.390388999999999	0103000020E6100000010000000500000051A2258FA7F94740ECDB4944F8314B4051A2258FA7F94740349F73B7EB334B401E1B81785DFD4740349F73B7EB334B401E1B81785DFD4740ECDB4944F8314B4051A2258FA7F94740ECDB4944F8314B40
18937	Елшанка	7	74	505	48.091991	48.116542000000003	54.094793000000003	54.070892000000001	0103000020E610000001000000050000005F43705CC60B484026C632FD12094B405F43705CC60B4840E371512D220C4B40234E27D9EA0E4840E371512D220C4B40234E27D9EA0E484026C632FD12094B405F43705CC60B484026C632FD12094B40
12756	Екатериновка	7	74	505	48.505952999999998	48.530244000000003	54.073380999999998	54.053797000000003	0103000020E6100000010000000500000013286211C3404840BCCFF1D1E2064B4013286211C3404840EA92718C64094B403B730F09DF434840EA92718C64094B403B730F09DF434840BCCFF1D1E2064B4013286211C3404840BCCFF1D1E2064B40
19869	Вышки	7	74	505	48.337681000000003	48.364485999999999	54.558962999999999	54.547291999999999	0103000020E6100000010000000500000084BD8921392B484064AE0CAA0D464B4084BD8921392B484047567E198C474B40C8EC2C7AA72E484047567E198C474B40C8EC2C7AA72E484064AE0CAA0D464B4084BD8921392B484064AE0CAA0D464B40
19224	Волостниковка	7	74	505	47.965536	47.987293000000001	54.244256	54.233168999999997	0103000020E610000001000000050000002A8E03AF96FB474073B8567BD81D4B402A8E03AF96FB474007EDD5C7431F4B40ED48F59D5FFE474007EDD5C7431F4B40ED48F59D5FFE474073B8567BD81D4B402A8E03AF96FB474073B8567BD81D4B40
55804	Бирючевка	7	74	505	48.105538000000003	48.112867999999999	54.414349999999999	54.407507000000003	0103000020E610000001000000050000001D3EE944820D48400FF27A3029344B401D3EE944820D48407E8CB96B09354B40E9616875720E48407E8CB96B09354B40E9616875720E48400FF27A3029344B401D3EE944820D48400FF27A3029344B40
55841	Арское	7	74	505	47.820799000000001	48.549529999999997	54.694524000000001	54.053797000000003	0103000020E6100000010000000500000075CB0EF10FE94740BCCFF1D1E2064B4075CB0EF10FE94740C0249529E6584B40DF15C1FF56464840C0249529E6584B40DF15C1FF56464840BCCFF1D1E2064B4075CB0EF10FE94740BCCFF1D1E2064B40
55795	Отрада	7	74	1773	48.112724999999998	48.131715	54.277729999999998	54.265163999999999	0103000020E610000001000000050000008638D6C56D0E4840CC09DAE4F0214B408638D6C56D0E48401D8F19A88C234B4042B28009DC1048401D8F19A88C234B4042B28009DC104840CC09DAE4F0214B408638D6C56D0E4840CC09DAE4F0214B40
25285	Новоульяновск	7	74	1773	48.371529000000002	48.413426999999999	54.154876000000002	54.130974000000002	0103000020E61000000100000005000000FF4124438E2F48402B508BC1C3104B40FF4124438E2F4840B8770DFAD2134B4046240A2DEB344840B8770DFAD2134B4046240A2DEB3448402B508BC1C3104B40FF4124438E2F48402B508BC1C3104B40
55775	Кротовка	7	74	1773	48.128678999999998	48.158771999999999	54.306916999999999	54.297559999999997	0103000020E610000001000000050000004B57B08D78104840834C327216264B404B57B08D7810484010CB660E49274B40A0C211A45214484010CB660E49274B40A0C211A452144840834C327216264B404B57B08D78104840834C327216264B40
18298	Ясашная Ташла	7	74	1471	48.23901	48.307577999999999	53.924675000000001	53.903917999999997	0103000020E610000001000000050000005FB532E1971E48400322C495B3F34A405FB532E1971E4840E3361AC05BF64A400B7C45B75E274840E3361AC05BF64A400B7C45B75E2748400322C495B3F34A405FB532E1971E48400322C495B3F34A40
17306	Федькино	7	74	1471	48.312142000000001	48.350670000000001	53.793326999999998	53.775835000000001	0103000020E61000000100000005000000A1DAE044F4274840CC0BB08F4EE34A40A1DAE044F4274840530438BD8BE54A401BD82AC1E22C4840530438BD8BE54A401BD82AC1E22C4840CC0BB08F4EE34A40A1DAE044F4274840CC0BB08F4EE34A40
17230	Тумкино	7	74	1471	48.287761000000003	48.320836999999997	53.758431000000002	53.736446000000001	0103000020E610000001000000050000003A083A5AD524484090A2CEDC43DE4A403A083A5AD5244840E4A25A4414E14A40622CD32F11294840E4A25A4414E14A40622CD32F1129484090A2CEDC43DE4A403A083A5AD524484090A2CEDC43DE4A40
17105	Тереньга	7	74	1471	48.341858000000002	48.392128	53.729680999999999	53.704115000000002	0103000020E6100000010000000500000020F0C000C22B4840C0CFB87020DA4A4020F0C000C22B48409CC1DF2F66DD4A4046EC1340313248409CC1DF2F66DD4A4046EC134031324840C0CFB87020DA4A4020F0C000C22B4840C0CFB87020DA4A40
18204	Суровка	7	74	1471	48.108412999999999	48.136358999999999	53.915129999999998	53.892510999999999	0103000020E610000001000000050000000ABB287AE00D4840FE28EACC3DF24A400ABB287AE00D484053CBD6FA22F54A40F4C132367411484053CBD6FA22F54A40F4C1323674114840FE28EACC3DF24A400ABB287AE00D4840FE28EACC3DF24A40
17639	Сосновка	7	74	1471	48.129379	48.171976999999998	53.624951000000003	53.597375	0103000020E6100000010000000500000004E5B67D8F1048405839B4C876CC4A4004E5B67D8F1048401F4DF564FECF4A400455A357031648401F4DF564FECF4A400455A357031648405839B4C876CC4A4004E5B67D8F1048405839B4C876CC4A40
18225	Солдатская Ташла	7	74	1471	48.188372000000001	48.218904999999999	54.025413999999998	53.998900999999996	0103000020E61000000100000005000000B6BDDD921C1848408978EBFCDBFF4A40B6BDDD921C184840266E15C440034B4027F73B14051C4840266E15C440034B4027F73B14051C48408978EBFCDBFF4A40B6BDDD921C1848408978EBFCDBFF4A40
18137	Скугареевка	7	74	1471	48.227744999999999	48.249932999999999	53.981574999999999	53.964956999999998	0103000020E61000000100000005000000EC6987BF261D4840EC8502B683FB4A40EC6987BF261D48401DC9E53FA4FD4A407898F6CDFD1F48401DC9E53FA4FD4A407898F6CDFD1F4840EC8502B683FB4A40EC6987BF261D4840EC8502B683FB4A40
18103	Подкуровка	7	74	1471	48.228786999999997	48.251944999999999	53.965831000000001	53.941172000000002	0103000020E61000000100000005000000FE5F75E4481D484099F4F75278F84A40FE5F75E4481D4840433BA759A0FB4A4003B2D7BB3F204840433BA759A0FB4A4003B2D7BB3F20484099F4F75278F84A40FE5F75E4481D484099F4F75278F84A40
17322	Назайкино	7	74	1471	48.199959999999997	48.237760999999999	53.795672000000003	53.775398000000003	0103000020E610000001000000050000000B410E4A9819484021B1DD3D40E34A400B410E4A98194840E52B8194D8E54A40D3A1D3F36E1E4840E52B8194D8E54A40D3A1D3F36E1E484021B1DD3D40E34A400B410E4A9819484021B1DD3D40E34A40
17527	Молвино	7	74	1471	48.441670000000002	48.468969000000001	53.785012000000002	53.771168000000003	0103000020E61000000100000005000000EACF7EA48838484062DC0DA2B5E24A40EACF7EA488384840D97BF1457BE44A403EEB1A2D073C4840D97BF1457BE44A403EEB1A2D073C484062DC0DA2B5E24A40EACF7EA48838484062DC0DA2B5E24A40
17909	Михайловка	7	74	1471	48.306365	48.334086999999997	53.545450000000002	53.533388000000002	0103000020E61000000100000005000000CCD1E3F736274840180AD80E46C44A40CCD1E3F73627484036CD3B4ED1C54A406682E15CC32A484036CD3B4ED1C54A406682E15CC32A4840180AD80E46C44A40CCD1E3F736274840180AD80E46C44A40
17816	Красноборск	7	74	1471	48.021616999999999	48.064638000000002	53.76905	53.742559	0103000020E61000000100000005000000D1048A58C4024840DC2C5E2C0CDF4A40D1048A58C4024840917EFB3A70E24A40180AD80E46084840917EFB3A70E24A40180AD80E46084840DC2C5E2C0CDF4A40D1048A58C4024840DC2C5E2C0CDF4A40
18023	Калиновка	7	74	1471	48.360004000000004	48.397615999999999	53.551789999999997	53.545310999999998	0103000020E61000000100000005000000F0366F9C142E4840149337C0CCC54A40F0366F9C142E48404221020EA1C64A40E42EC214E53248404221020EA1C64A40E42EC214E5324840149337C0CCC54A40F0366F9C142E4840149337C0CCC54A40
17836	Зеленец	7	74	1471	48.003543000000001	48.068176999999999	53.845821999999998	53.824196000000001	0103000020E610000001000000050000009B90D618740048403CBF28417FE94A409B90D61874004840601E32E543EC4A4071AB2006BA084840601E32E543EC4A4071AB2006BA0848403CBF28417FE94A409B90D618740048403CBF28417FE94A40
17933	Елшанка	7	74	1471	48.224097999999998	48.271098000000002	53.535085000000002	53.525478	0103000020E61000000100000005000000AC8C463EAF1C48403D62F4DC42C34A40AC8C463EAF1C484043CA4FAA7DC44A406901DA56B322484043CA4FAA7DC44A406901DA56B32248403D62F4DC42C34A40AC8C463EAF1C48403D62F4DC42C34A40
17394	Гладчиха	7	74	1471	48.263103000000001	48.303922	53.674174999999998	53.660325999999998	0103000020E61000000100000005000000603DEE5BAD2148406859F78F85D44A40603DEE5BAD214840F163CC5D4BD64A40784485EAE6264840F163CC5D4BD64A40784485EAE62648406859F78F85D44A40603DEE5BAD2148406859F78F85D44A40
16844	Гавриловка	7	74	1471	48.309941000000002	48.360281999999998	53.561878	53.546686000000001	0103000020E6100000010000000500000043588D25AC2748402D978DCEF9C54A4043588D25AC274840C32B499EEBC74A4032AB77B81D2E4840C32B499EEBC74A4032AB77B81D2E48402D978DCEF9C54A4043588D25AC2748402D978DCEF9C54A40
17716	Большая Борла	7	74	1471	48.038164000000002	48.087041999999997	53.534115999999997	53.515889000000001	0103000020E6100000010000000500000039F1D58EE2044840DEAE97A608C24A4039F1D58EE20448409A22C0E95DC44A4070B03731240B48409A22C0E95DC44A4070B03731240B4840DEAE97A608C24A4039F1D58EE2044840DEAE97A608C24A40
17614	Белогорское	7	74	1471	48.157218	48.196258999999998	53.591791000000001	53.574069999999999	0103000020E61000000100000005000000D82B2CB81F144840AFCE31207BC94A40D82B2CB81F1448409888B7CEBFCB4A40D845D1031F1948409888B7CEBFCB4A40D845D1031F194840AFCE31207BC94A40D82B2CB81F144840AFCE31207BC94A40
17498	Байдулино	7	74	1471	48.373801999999998	48.402413000000003	53.767735000000002	53.742750999999998	0103000020E61000000100000005000000F69672BED82F48402009FB7612DF4A40F69672BED82F48404E7FF62345E24A401D3EE944823348404E7FF62345E24A401D3EE944823348402009FB7612DF4A40F69672BED82F48402009FB7612DF4A40
17744	Алешкино	7	74	1471	48.119255000000003	48.155690999999997	53.495046000000002	53.484422000000002	0103000020E61000000100000005000000377172BF430F484041BB438A01BE4A40377172BF430F48400002D6AA5DBF4A4009A4C4AEED1348400002D6AA5DBF4A4009A4C4AEED13484041BB438A01BE4A40377172BF430F484041BB438A01BE4A40
16909	Шатрашаны	7	74	1361	47.340649999999997	47.375055000000003	54.562376999999998	54.546379000000002	0103000020E61000000100000005000000F2B0506B9AAB4740501C40BFEF454B40F2B0506B9AAB4740E48233F8FB474B40C4995FCD01B04740E48233F8FB474B40C4995FCD01B04740501C40BFEF454B40F2B0506B9AAB4740501C40BFEF454B40
16735	Чирково	7	74	1361	46.526874999999997	46.545136999999997	54.655265999999997	54.639637999999998	0103000020E610000001000000050000003D0AD7A370434740B1A371A8DF514B403D0AD7A37043474022179CC1DF534B40766B990CC745474022179CC1DF534B40766B990CC7454740B1A371A8DF514B403D0AD7A370434740B1A371A8DF514B40
17025	Чеботаевка	7	74	1361	47.190899999999999	47.215558999999999	54.538621999999997	54.526398	0103000020E61000000100000005000000386744696F9847400457790261434B40386744696F984740FB73D190F1444B40E2ADF36F979B4740FB73D190F1444B40E2ADF36F979B47400457790261434B40386744696F9847400457790261434B40
16634	Хмелевка	7	74	1361	46.545406999999997	46.587797999999999	54.611939999999997	54.594537000000003	0103000020E61000000100000005000000360186E5CF45474088A1D5C9194C4B40360186E5CF4547409F8EC70C544E4B40BD5301F73C4B47409F8EC70C544E4B40BD5301F73C4B474088A1D5C9194C4B40360186E5CF45474088A1D5C9194C4B40
16005	Сурское	7	74	1361	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
15823	Сара	7	74	1361	46.737178999999998	46.768763999999997	54.661974000000001	54.627861000000003	0103000020E610000001000000050000002426A8E15B5E474089B7CEBF5D504B402426A8E15B5E4740B2666490BB544B40CB2BD7DB66624740B2666490BB544B40CB2BD7DB6662474089B7CEBF5D504B402426A8E15B5E474089B7CEBF5D504B40
15566	Ружеевщино	7	74	1361	47.278190000000002	47.300423000000002	54.439444000000002	54.417865999999997	0103000020E610000001000000050000008109DCBA9BA347401F0E12A27C354B408109DCBA9BA34740333674B33F384B40ADFBC74274A64740333674B33F384B40ADFBC74274A647401F0E12A27C354B408109DCBA9BA347401F0E12A27C354B40
15336	Паркино	7	74	1361	47.229509999999998	47.254913999999999	54.626198000000002	54.618098000000003	0103000020E610000001000000050000006F0D6C95609D47408CDCD3D51D4F4B406F0D6C95609D47400A698D4127504B4072A59E05A1A047400A698D4127504B4072A59E05A1A047408CDCD3D51D4F4B406F0D6C95609D47408CDCD3D51D4F4B40
15650	Никитино	7	74	1361	47.056080999999999	47.086587999999999	54.472842999999997	54.452381000000003	0103000020E61000000100000005000000A77686A92D874740782AE09EE7394B40A77686A92D8747403E92921E863C4B40EF1CCA50158B47403E92921E863C4B40EF1CCA50158B4740782AE09EE7394B40A77686A92D874740782AE09EE7394B40
15438	Лава	7	74	1361	46.875978000000003	46.918512999999997	54.487374000000003	54.469347999999997	0103000020E61000000100000005000000FC010F0C20704740B4386398133C4B40FC010F0C20704740DA756F45623E4B40B5F97FD591754740DA756F45623E4B40B5F97FD591754740B4386398133C4B40FC010F0C20704740B4386398133C4B40
15541	Красная Якла	7	74	1361	47.221147000000002	47.240281000000003	54.489272999999997	54.475636999999999	0103000020E61000000100000005000000E44D7E8B4E9C47403FE257ACE13C4B40E44D7E8B4E9C47406CE8667FA03E4B40D36C1E87C19E47406CE8667FA03E4B40D36C1E87C19E47403FE257ACE13C4B40E44D7E8B4E9C47403FE257ACE13C4B40
16528	Княжуха	7	74	1361	46.544409999999999	46.583379000000001	54.573870999999997	54.548169999999999	0103000020E61000000100000005000000C4CE143AAF454740FC523F6F2A464B40C4CE143AAF454740B88FDC9A74494B402B16BF29AC4A4740B88FDC9A74494B402B16BF29AC4A4740FC523F6F2A464B40C4CE143AAF454740FC523F6F2A464B40
52682	Кирзять	7	74	1361	46.692317000000003	46.731152000000002	54.409514000000001	54.396202000000002	0103000020E6100000010000000500000080BBECD79D5847400E4E44BFB6324B4080BBECD79D58474088A06AF46A344B40D7338463965D474088A06AF46A344B40D7338463965D47400E4E44BFB6324B4080BBECD79D5847400E4E44BFB6324B40
16305	Ждамирово	7	74	1361	46.518332000000001	46.553330000000003	54.703232999999997	54.687961999999999	0103000020E61000000100000005000000323CF6B358424740047289230F584B40323CF6B358424740E63BF889035A4B40A6F27684D3464740E63BF889035A4B40A6F27684D3464740047289230F584B40323CF6B358424740047289230F584B40
15810	Елховка	7	74	1361	46.628259	46.668188999999998	54.683886999999999	54.667321999999999	0103000020E61000000100000005000000763579CA6A5047405EF3AACE6A554B40763579CA6A5047406C94F59B89574B4002469737875547406C94F59B89574B4002469737875547405EF3AACE6A554B40763579CA6A5047405EF3AACE6A554B40
16412	Гулюшево	7	74	1361	46.563966000000001	46.596305000000001	54.440019999999997	54.423853000000001	0103000020E610000001000000050000002907B30930484740DFA7AAD040364B402907B30930484740FFCA4A9352384B407CB8E4B8534C4740FFCA4A9352384B407CB8E4B8534C4740DFA7AAD040364B402907B30930484740DFA7AAD040364B40
15712	Выползово	7	74	1361	47.021532000000001	47.043056	54.499845999999998	54.481332999999999	0103000020E61000000100000005000000A3E8818FC182474027BEDA519C3D4B40A3E8818FC1824740A98427F4FA3F4B40C3F2E7DB82854740A98427F4FA3F4B40C3F2E7DB8285474027BEDA519C3D4B40A3E8818FC182474027BEDA519C3D4B40
14682	Большой Кувай	7	74	1361	47.073220999999997	47.113528000000002	54.630889000000003	54.607664999999997	0103000020E61000000100000005000000B130444E5F89474040F67AF7C74D4B40B130444E5F894740FD3383F8C0504B401497E315888E4740FD3383F8C0504B401497E315888E474040F67AF7C74D4B40B130444E5F89474040F67AF7C74D4B40
15462	Белый Ключ	7	74	1361	46.805047000000002	46.850878999999999	54.449162000000001	54.431274999999999	0103000020E61000000100000005000000185FB4C70B6747408C4AEA0434374B40185FB4C70B674740904DF2237E394B4035ED629AE96C4740904DF2237E394B4035ED629AE96C47408C4AEA0434374B40185FB4C70B6747408C4AEA0434374B40
55835	Барышская Слобода	7	74	1361	46.771486000000003	46.798696	54.598318999999996	54.574590999999998	0103000020E6100000010000000500000033A9A10DC0624740B8C9A8328C494B4033A9A10DC0624740A7C98CB7954C4B4017B9A7AB3B664740A7C98CB7954C4B4017B9A7AB3B664740B8C9A8328C494B4033A9A10DC0624740B8C9A8328C494B40
15139	Астрадамовка	7	74	1361	47.118631000000001	47.156764000000003	54.552822999999997	54.540644	0103000020E6100000010000000500000059A5F44C2F8F4740AA6395D233454B4059A5F44C2F8F474001BD70E7C2464B405798BED71094474001BD70E7C2464B405798BED710944740AA6395D233454B4059A5F44C2F8F4740AA6395D233454B40
17015	Архангельское	7	74	1361	47.307366999999999	47.321550999999999	54.536658000000003	54.523716999999998	0103000020E61000000100000005000000506F46CD57A74740FBAD9D2809434B40506F46CD57A7474082919735B1444B40807F4A9528A9474082919735B1444B40807F4A9528A94740FBAD9D2809434B40506F46CD57A74740FBAD9D2809434B40
16612	Араповка	7	74	1361	46.601030999999999	46.620829000000001	54.589101999999997	54.572575999999998	0103000020E61000000100000005000000EB707495EE4C4740BC3C9D2B4A494B40EB707495EE4C47400C01C0B1674B4B4046B41D53774F47400C01C0B1674B4B4046B41D53774F4740BC3C9D2B4A494B40EB707495EE4C4740BC3C9D2B4A494B40
55807	Алейкино	7	74	1361	47.183525000000003	47.206350999999998	54.578499000000001	54.566777000000002	0103000020E61000000100000005000000CC7F48BF7D974740009013268C484B40CC7F48BF7D97474065E256410C4A4B409A3FA6B5699A474065E256410C4A4B409A3FA6B5699A4740009013268C484B40CC7F48BF7D974740009013268C484B40
55824	Ясашное Помряскино	7	74	1316	48.599314999999997	49.584327000000002	54.890044000000003	54.351092999999999	0103000020E6100000010000000500000049809A5AB64C4840616D8C9DF02C4B4049809A5AB64C4840220038F6EC714B40BC95253ACBCA4840220038F6EC714B40BC95253ACBCA4840616D8C9DF02C4B4049809A5AB64C4840616D8C9DF02C4B40
14496	Шмелевка	7	74	1316	49.154958999999998	49.181953	54.798551000000003	54.777095000000003	0103000020E61000000100000005000000459C4EB2D59348404C7155D977634B40459C4EB2D593484014984EEB36664B405D34643C4A97484014984EEB36664B405D34643C4A9748404C7155D977634B40459C4EB2D59348404C7155D977634B40
15047	Татарское Урайкино	7	74	1316	49.228324000000001	49.277982999999999	54.435715999999999	54.410561999999999	0103000020E610000001000000050000002A7288B8399D48407C7DAD4B8D344B402A7288B8399D4840062CB98AC5374B4007EC6AF294A34840062CB98AC5374B4007EC6AF294A348407C7DAD4B8D344B402A7288B8399D48407C7DAD4B8D344B40
14973	Старое Рождествено	7	74	1316	49.501179	49.544297999999998	54.590994999999999	54.573286000000003	0103000020E6100000010000000500000093382BA226C0484099A0866F61494B4093382BA226C04840BD8C62B9A54B4B409CA38E8EABC54840BD8C62B9A54B4B409CA38E8EABC5484099A0866F61494B4093382BA226C0484099A0866F61494B40
13908	Старая Майна	7	74	1316	48.890306000000002	48.958165000000001	54.617164000000002	54.593958000000001	0103000020E610000001000000050000005FB7088CF57148404A99D4D0064C4B405FB7088CF57148406022DE3AFF4E4B40FF959526A57A48406022DE3AFF4E4B40FF959526A57A48404A99D4D0064C4B405FB7088CF57148404A99D4D0064C4B40
14668	Русский Юрткуль	7	74	1316	49.355220000000003	49.3857	54.756745000000002	54.734954999999999	0103000020E610000001000000050000004C7155D977AD48400E846401135E4B404C7155D977AD4840AD342905DD604B409A081B9E5EB14840AD342905DD604B409A081B9E5EB148400E846401135E4B404C7155D977AD48400E846401135E4B40
14295	Прибрежное	7	74	1316	48.940666	48.958497000000001	54.544128000000001	54.528832999999999	0103000020E61000000100000005000000C53A55BE67784840D505BCCCB0434B40C53A55BE67784840406B7EFCA5454B4035289A07B07A4840406B7EFCA5454B4035289A07B07A4840D505BCCCB0434B40C53A55BE67784840D505BCCCB0434B40
14210	Новиковка	7	74	1316	49.150243000000003	49.184792000000002	54.503746	54.480773999999997	0103000020E61000000100000005000000FAB9A1293B93484030629F008A3D4B40FAB9A1293B934840D3BEB9BF7A404B40FE47A643A7974840D3BEB9BF7A404B40FE47A643A797484030629F008A3D4B40FAB9A1293B93484030629F008A3D4B40
14476	Матвеевка	7	74	1316	49.181719999999999	49.215226999999999	54.786606999999997	54.772941000000003	0103000020E61000000100000005000000BA83D89942974840685E0EBBEF624B40BA83D89942974840FFE6C589AF644B40AC1BEF8E8C9B4840FFE6C589AF644B40AC1BEF8E8C9B4840685E0EBBEF624B40BA83D89942974840685E0EBBEF624B40
14862	Малая Кандала	7	74	1316	49.363430999999999	49.407547000000001	54.504148999999998	54.477766000000003	0103000020E6100000010000000500000021AD31E884AE48400492B06F273D4B4021AD31E884AE4840D2A755F487404B409D4A06802AB44840D2A755F487404B409D4A06802AB448400492B06F273D4B4021AD31E884AE48400492B06F273D4B40
14964	Лесное-Никольское	7	74	1316	49.438189000000001	49.466971000000001	54.608400000000003	54.585231	0103000020E61000000100000005000000C53BC09316B848407DCD72D9E84A4B40C53BC09316B8484076711B0DE04D4B401897AAB4C5BB484076711B0DE04D4B401897AAB4C5BB48407DCD72D9E84A4B40C53BC09316B848407DCD72D9E84A4B40
14790	Лесная Поляна	7	74	1316	49.268101999999999	49.28022	54.576396000000003	54.568359000000001	0103000020E6100000010000000500000000FF942A51A2484092B1DAFCBF484B4000FF942A51A24840CAC51858C7494B40B2D7BB3FDEA34840CAC51858C7494B40B2D7BB3FDEA3484092B1DAFCBF484B4000FF942A51A2484092B1DAFCBF484B40
14383	Кременки	7	74	1316	48.849020000000003	48.884979000000001	54.516489999999997	54.500923	0103000020E6100000010000000500000031D3F6AFAC6C48403868AF3E1E404B4031D3F6AFAC6C4840035B25581C424B40CA52EBFD46714840035B25581C424B40CA52EBFD467148403868AF3E1E404B4031D3F6AFAC6C48403868AF3E1E404B40
55793	Красная Река	7	74	1316	49.101958000000003	49.140765999999999	54.596482999999999	54.562168	0103000020E6100000010000000500000065C8B1F50C8D4840CA6DFB1EF5474B4065C8B1F50C8D48405BCF108E594C4B40C231CB9E049248405BCF108E594C4B40C231CB9E04924840CA6DFB1EF5474B4065C8B1F50C8D4840CA6DFB1EF5474B40
14121	Жедяевка	7	74	1316	49.150754999999997	49.172189000000003	54.737090999999999	54.716793000000003	0103000020E61000000100000005000000AF5A99F04B93484039807EDFBF5B4B40AF5A99F04B934840859675FF585E4B4090DD054A0A964840859675FF585E4B4090DD054A0A96484039807EDFBF5B4B40AF5A99F04B93484039807EDFBF5B4B40
14884	Ертуганово	7	74	1316	49.411599000000002	49.435979000000003	54.464664999999997	54.452249999999999	0103000020E610000001000000050000007D08AA46AFB44840D9CEF753E3394B407D08AA46AFB44840444C89247A3B4B40145FED28CEB74840444C89247A3B4B40145FED28CEB74840D9CEF753E3394B407D08AA46AFB44840D9CEF753E3394B40
14393	Дмитриево-Помряскино	7	74	1316	48.913356999999998	48.940171999999997	54.444879	54.425047999999997	0103000020E610000001000000050000004D49D6E1E8744840779D0DF967364B404D49D6E1E8744840AED689CBF1384B40B54E5C8E57784840AED689CBF1384B40B54E5C8E57784840779D0DF967364B404D49D6E1E8744840779D0DF967364B40
14568	Грибовка	7	74	1316	49.255803999999998	49.283192999999997	54.814926999999997	54.797865999999999	0103000020E61000000100000005000000CE177B2FBEA04840904B1C7920664B40CE177B2FBEA048404ED026874F684B4062BA10AB3FA448404ED026874F684B4062BA10AB3FA44840904B1C7920664B40CE177B2FBEA04840904B1C7920664B40
14318	Восход	7	74	1316	48.978566000000001	48.995291999999999	54.529041999999997	54.518935999999997	0103000020E61000000100000005000000207D93A6417D4840C85BAE7E6C424B40207D93A6417D4840EF1AF4A5B7434B4037FC6EBA657F4840EF1AF4A5B7434B4037FC6EBA657F4840C85BAE7E6C424B40207D93A6417D4840C85BAE7E6C424B40
14100	Волостниковка	7	74	1316	49.004041999999998	49.036633000000002	54.731233000000003	54.715738000000002	0103000020E61000000100000005000000BCE7C072848048409240834D9D5B4B40BCE7C07284804840C460FE0A995D4B40297AE063B0844840C460FE0A995D4B40297AE063B08448409240834D9D5B4B40BCE7C072848048409240834D9D5B4B40
14769	Большая Кандала	7	74	1316	49.326726000000001	49.363188000000001	54.571281999999997	54.531063000000003	0103000020E610000001000000050000005F605628D2A94840CE8E54DFF9434B405F605628D2A948409065C1C41F494B405B26C3F17CAE48409065C1C41F494B405B26C3F17CAE4840CE8E54DFF9434B405F605628D2A94840CE8E54DFF9434B40
14585	Базарно-Мордовский Юрткуль	7	74	1316	49.436230000000002	49.456738999999999	54.790142000000003	54.777064000000003	0103000020E610000001000000050000005DC47762D6B74840117349D576634B405DC47762D6B748401899805F23654B4064E76D6C76BA48401899805F23654B4064E76D6C76BA4840117349D576634B405DC47762D6B74840117349D576634B40
14031	Арчиловка	7	74	1316	49.042695999999999	49.055137999999999	54.678311999999998	54.670712000000002	0103000020E61000000100000005000000C3D501107785484073840CE4D9554B40C3D5011077854840FF3D78EDD2564B40286211C30E874840FF3D78EDD2564B40286211C30E87484073840CE4D9554B40C3D501107785484073840CE4D9554B40
13251	Усть-Кулатка	7	74	1253	47.745341000000003	47.765616000000001	52.61927	52.605238	0103000020E6100000010000000500000019AF795567DF4740F2255470784D4A4019AF795567DF47406CB2463D444F4A40ADA580B4FFE147406CB2463D444F4A40ADA580B4FFE14740F2255470784D4A4019AF795567DF4740F2255470784D4A40
55790	Старый Мостяк	7	74	1253	47.391179999999999	47.418111000000003	52.713053000000002	52.687192000000003	0103000020E61000000100000005000000B56CAD2F12B2474053094FE8F5574A40B56CAD2F12B2474048A81952455B4A40878C47A984B5474048A81952455B4A40878C47A984B5474053094FE8F5574A40B56CAD2F12B2474053094FE8F5574A40
13548	Старый Атлаш	7	74	1253	47.284604000000002	47.326402000000002	52.795189999999998	52.776328999999997	0103000020E61000000100000005000000C82764E76DA44740DBF7A8BF5E634A40C82764E76DA44740990D32C9C8654A40ACAC6D8AC7A94740990D32C9C8654A40ACAC6D8AC7A94740DBF7A8BF5E634A40C82764E76DA44740DBF7A8BF5E634A40
13260	Старое Зеленое	7	74	1253	47.898781999999997	47.938892000000003	52.796213000000002	52.766043000000003	0103000020E61000000100000005000000E21DE0490BF34740352A70B20D624A40E21DE0490BF3474035D3BD4EEA654A40EF3CF19C2DF8474035D3BD4EEA654A40EF3CF19C2DF84740352A70B20D624A40E21DE0490BF34740352A70B20D624A40
13163	Старая Яндовка	7	74	1253	47.486707000000003	47.502417999999999	52.816769000000001	52.802219000000001	0103000020E61000000100000005000000FDDD3B6A4CBE47406B9DB81CAF664A40FDDD3B6A4CBE47407DB1F7E28B684A40FB75A73B4FC047407DB1F7E28B684A40FB75A73B4FC047406B9DB81CAF664A40FDDD3B6A4CBE47406B9DB81CAF664A40
12888	Старая Кулатка	7	74	1253	47.592663000000002	47.643301000000001	52.746575	52.709763000000002	0103000020E610000001000000050000004E469561DCCB474097749483D95A4A404E469561DCCB47406F8104C58F5F4A40F73DEAAF57D247406F8104C58F5F4A40F73DEAAF57D2474097749483D95A4A404E469561DCCB474097749483D95A4A40
13711	Средняя Терешка	7	74	1253	47.486707000000003	47.537793999999998	52.897421999999999	52.883952999999998	0103000020E61000000100000005000000FDDD3B6A4CBE4740BD19355F25714A40FDDD3B6A4CBE4740FF5A5EB9DE724A4015FE0C6FD6C44740FF5A5EB9DE724A4015FE0C6FD6C44740BD19355F25714A40FDDD3B6A4CBE4740BD19355F25714A40
13536	Новый Мостяк	7	74	1253	47.428719999999998	47.447648000000001	52.731411999999999	52.715595	0103000020E610000001000000050000001092054CE0B647402F17F19D985B4A401092054CE0B6474073F38DE89E5D4A40560F98874CB9474073F38DE89E5D4A40560F98874CB947402F17F19D985B4A401092054CE0B647402F17F19D985B4A40
13062	Новые Зимницы	7	74	1253	47.544046000000002	47.572432999999997	52.681814000000003	52.663308000000001	0103000020E6100000010000000500000083C2A04CA3C547406C96CB46E7544A4083C2A04CA3C547403CFA5FAE45574A4059130B7C45C947403CFA5FAE45574A4059130B7C45C947406C96CB46E7544A4083C2A04CA3C547406C96CB46E7544A40
13433	Новое Зеленое	7	74	1253	48.003399999999999	48.023530999999998	52.790751999999998	52.781089999999999	0103000020E61000000100000005000000386744696F004840C79DD2C1FA634A40386744696F004840909F8D5C37654A4099B8551003034840909F8D5C37654A4099B8551003034840C79DD2C1FA634A40386744696F004840C79DD2C1FA634A40
13154	Новая Яндовка	7	74	1253	47.566952999999998	47.580571999999997	52.764620999999998	52.750968999999998	0103000020E610000001000000050000003EAF78EA91C84740A8A78FC01F604A403EAF78EA91C84740DB6AD619DF614A40957CEC2E50CA4740DB6AD619DF614A40957CEC2E50CA4740A8A78FC01F604A403EAF78EA91C84740A8A78FC01F604A40
13825	Новая Терешка	7	74	1253	47.534829000000002	47.565748999999997	52.907634000000002	52.887892999999998	0103000020E61000000100000005000000E8F9D34675C4474075AC527AA6714A40E8F9D34675C447406C5ED5592D744A40525F96766AC847406C5ED5592D744A40525F96766AC8474075AC527AA6714A40E8F9D34675C4474075AC527AA6714A40
13086	Новая Кулатка	7	74	1253	47.639671999999997	47.671956999999999	52.660763000000003	52.646439000000001	0103000020E610000001000000050000005D15A8C5E0D14740F2ED5D83BE524A405D15A8C5E0D1474014B4C9E193544A40BDA8DDAF02D6474014B4C9E193544A40BDA8DDAF02D64740F2ED5D83BE524A405D15A8C5E0D14740F2ED5D83BE524A40
13635	Мосеевка	7	74	1253	47.264778	47.288995999999997	52.739248000000003	52.723412000000003	0103000020E61000000100000005000000A359D93EE4A1474059C4B0C3985C4A40A359D93EE4A1474014D1AFAD9F5E4A40605628D2FDA4474014D1AFAD9F5E4A40605628D2FDA4474059C4B0C3985C4A40A359D93EE4A1474059C4B0C3985C4A40
13810	Кирюшкино	7	74	1253	47.623384999999999	47.662309	52.915996999999997	52.897649999999999	0103000020E6100000010000000500000092E86514CBCF474090A0F831E6724A4092E86514CBCF4740F71DC3633F754A40596C938AC6D44740F71DC3633F754A40596C938AC6D4474090A0F831E6724A4092E86514CBCF474090A0F831E6724A40
13620	Кармалей	7	74	1253	47.358248000000003	47.391188999999997	52.840029000000001	52.829436999999999	0103000020E61000000100000005000000C0ED0912DBAD4740D28BDAFD2A6A4A40C0ED0912DBAD47408658FD11866B4A4008C72C7B12B247408658FD11866B4A4008C72C7B12B24740D28BDAFD2A6A4A40C0ED0912DBAD4740D28BDAFD2A6A4A40
13360	Зарыклей	7	74	1253	47.930816	47.941245000000002	52.699052000000002	52.689090999999998	0103000020E61000000100000005000000F94B8BFA24F74740E57B462234584A40F94B8BFA24F74740091A33897A594A40034356B77AF84740091A33897A594A40034356B77AF84740E57B462234584A40F94B8BFA24F74740E57B462234584A40
13344	Вязовый Гай	7	74	1253	48.005789	48.032998999999997	52.685690000000001	52.672254000000002	0103000020E6100000010000000500000099D6A6B1BD004840774D486B0C564A4099D6A6B1BD004840DD989EB0C4574A407DE6AC4F39044840DD989EB0C4574A407DE6AC4F39044840774D486B0C564A4099D6A6B1BD004840774D486B0C564A40
13730	Верхняя Терешка	7	74	1253	47.348275999999998	47.391044999999998	52.904195999999999	52.890163999999999	0103000020E61000000100000005000000A8FDD64E94AC4740CC09DAE4F0714A40A8FDD64E94AC47404696CCB1BC734A40D52137C30DB247404696CCB1BC734A40D52137C30DB24740CC09DAE4F0714A40A8FDD64E94AC4740CC09DAE4F0714A40
12972	Бахтеевка	7	74	1253	47.739277000000001	47.766226000000003	52.706614999999999	52.692988	0103000020E61000000100000005000000AED7F4A0A0DE47409E42AED4B3584A40AED7F4A0A0DE474078EE3D5C725A4A4026AC8DB113E2474078EE3D5C725A4A4026AC8DB113E247409E42AED4B3584A40AED7F4A0A0DE47409E42AED4B3584A40
12824	Шиловка	7	74	1184	48.630837	48.660876999999999	54.064140000000002	54.040602	0103000020E61000000100000005000000AA0D4E44BF5048407B13437232054B40AA0D4E44BF504840C72E51BD35084B40DCD6169E97544840C72E51BD35084B40DCD6169E975448407B13437232054B40AA0D4E44BF5048407B13437232054B40
12803	Тушна	7	74	1184	48.496045000000002	48.534475	54.052903999999998	54.004219999999997	0103000020E61000000100000005000000132C0E677E3F48409BFEEC478A004B40132C0E677E3F4840EEE9EA8EC5064B40CAC342AD69444840EEE9EA8EC5064B40CAC342AD694448409BFEEC478A004B40132C0E677E3F48409BFEEC478A004B40
11949	Силикатный	7	74	1184	48.313246999999997	48.340394000000003	53.995381999999999	53.983111000000001	0103000020E61000000100000005000000F9484A7A182848403FABCC94D6FD4A40F9484A7A18284840778368AD68FF4A4098E0D407922B4840778368AD68FF4A4098E0D407922B48403FABCC94D6FD4A40F9484A7A182848403FABCC94D6FD4A40
11291	Сенгилей	7	74	1184	48.752656999999999	48.827595000000002	53.973500000000001	53.947885999999997	0103000020E61000000100000005000000800D8810576048400A2B155454F94A40800D881057604840F853E3A59BFC4A40A4AA09A2EE694840F853E3A59BFC4A40A4AA09A2EE6948400A2B155454F94A40800D8810576048400A2B155454F94A40
55789	Сенгилеевский Цементный Завод 1 километр	7	74	1184	48.716239999999999	48.749854999999997	54.011020000000002	53.993237999999998	0103000020E61000000100000005000000240B98C0AD5B48407D923B6C22FF4A40240B98C0AD5B48400CCD751A69014B40FCDEA63FFB5F48400CCD751A69014B40FCDEA63FFB5F48407D923B6C22FF4A40240B98C0AD5B48407D923B6C22FF4A40
12632	Русская Бектяшка	7	74	1184	48.827379000000001	48.867435	53.772711000000001	53.763919000000001	0103000020E61000000100000005000000D732198EE769484082E50819C8E14A40D732198EE76948403621AD31E8E24A40F0332E1C086F48403621AD31E8E24A40F0332E1C086F484082E50819C8E14A40D732198EE769484082E50819C8E14A40
12674	Мордово	7	74	1184	48.870471000000002	48.898364000000001	53.810029999999998	53.796348000000002	0103000020E61000000100000005000000E78EFE976B6F4840151E34BBEEE54A40E78EFE976B6F4840B2632310AFE74A40AEF36F97FD724840B2632310AFE74A40AEF36F97FD724840151E34BBEEE54A40E78EFE976B6F4840151E34BBEEE54A40
12542	Кротково	7	74	1184	48.533873	48.569329000000003	53.787188	53.759874000000003	0103000020E61000000100000005000000D49B51F355444840558A1D8D43E14A40D49B51F355444840DEE68D93C2E44A400BD5CDC5DF484840DEE68D93C2E44A400BD5CDC5DF484840558A1D8D43E14A40D49B51F355444840558A1D8D43E14A40
12088	Красный Гуляй	7	74	1184	48.321843000000001	48.340699000000001	54.043246000000003	54.012549	0103000020E6100000010000000500000028B9C326322948407B4CA4349B014B4028B9C3263229484067D7BD1589054B40D4635B069C2B484067D7BD1589054B40D4635B069C2B48407B4CA4349B014B4028B9C326322948407B4CA4349B014B40
12334	Каранино	7	74	1184	48.681348999999997	48.701157000000002	53.956448999999999	53.94679	0103000020E61000000100000005000000C614AC713657484005172B6A30F94A40C614AC71365748405DA5BBEB6CFA4A40452E3883BF5948405DA5BBEB6CFA4A40452E3883BF59484005172B6A30F94A40C614AC713657484005172B6A30F94A40
12438	Елаур	7	74	1184	48.774082	48.830955000000003	53.851027999999999	53.825705999999997	0103000020E610000001000000050000000D36751E15634840340EF5BBB0E94A400D36751E156348407AFD497CEEEC4A404EB9C2BB5C6A48407AFD497CEEEC4A404EB9C2BB5C6A4840340EF5BBB0E94A400D36751E15634840340EF5BBB0E94A40
12251	Вырыстайкино	7	74	1184	48.847923999999999	48.875034999999997	53.846533999999998	53.830882000000003	0103000020E610000001000000050000002BBF0CC6886C4840E46A64575AEA4A402BBF0CC6886C4840DD79E2395BEC4A407CED992501704840DD79E2395BEC4A407CED992501704840E46A64575AEA4A402BBF0CC6886C4840E46A64575AEA4A40
12519	Бекетовка	7	74	1184	48.725672000000003	48.763050999999997	53.767207999999997	53.744556000000003	0103000020E61000000100000005000000BCCFF1D1E25C484032056B9C4DDF4A40BCCFF1D1E25C4840629D2ADF33E24A400D17B9A7AB614840629D2ADF33E24A400D17B9A7AB61484032056B9C4DDF4A40BCCFF1D1E25C484032056B9C4DDF4A40
12711	Артюшкино	7	74	1184	48.420954999999999	48.452314999999999	53.970210999999999	53.953327999999999	0103000020E61000000100000005000000390B7BDAE1354840382EE3A606FA4A40390B7BDAE1354840179CC1DF2FFC4A40C03E3A75E5394840179CC1DF2FFC4A40C03E3A75E5394840382EE3A606FA4A40390B7BDAE1354840382EE3A606FA4A40
12174	Алешкино	7	74	1184	48.792003999999999	48.823157000000002	53.882055999999999	53.863990999999999	0103000020E610000001000000050000008D26176360654840E884D04197EE4A408D26176360654840CB9E0436E7F04A409B3C65355D694840CB9E0436E7F04A409B3C65355D694840E884D04197EE4A408D26176360654840E884D04197EE4A40
11656	Шевченко	7	74	1130	48.144030999999998	48.193375000000003	52.909323000000001	52.898031000000003	0103000020E610000001000000050000001A4E999B6F124840A8E507AEF2724A401A4E999B6F124840144031B264744A40986E1283C0184840144031B264744A40986E1283C0184840A8E507AEF2724A401A4E999B6F124840A8E507AEF2724A40
10723	Чауши	7	74	1130	47.729934	47.746265999999999	52.785179999999997	52.774411000000001	0103000020E61000000100000005000000861E317A6EDD4740D2544FE61F634A40861E317A6EDD474094BC3AC780644A40F10EF0A485DF474094BC3AC780644A40F10EF0A485DF4740D2544FE61F634A40861E317A6EDD4740D2544FE61F634A40
11590	Средниково	7	74	1130	48.076343000000001	48.099322000000001	52.966206	52.949378000000003	0103000020E61000000100000005000000A723809BC50948405DC5E23785794A40A723809BC5094840789961A3AC7B4A40FCE25295B60C4840789961A3AC7B4A40FCE25295B60C48405DC5E23785794A40A723809BC50948405DC5E23785794A40
11555	Софьино	7	74	1130	48.026944	48.064709999999998	52.948146000000001	52.925113000000003	0103000020E610000001000000050000006669A7E6720348405F0D501A6A764A406669A7E672034840A7EA1ED95C794A40B1DCD26A48084840A7EA1ED95C794A40B1DCD26A480848405F0D501A6A764A406669A7E6720348405F0D501A6A764A40
10842	Соловчиха	7	74	1130	47.779701000000003	47.804090000000002	52.954489000000002	52.940468000000003	0103000020E610000001000000050000004AD40B3ECDE347409F77634161784A404AD40B3ECDE3474025B20FB22C7A4A403485CE6BECE6474025B20FB22C7A4A403485CE6BECE647409F77634161784A404AD40B3ECDE347409F77634161784A40
11111	Рябина	7	74	1130	48.307937000000003	48.324323	52.920448999999998	52.906883999999998	0103000020E610000001000000050000003B1DC87A6A27484001A260C614744A403B1DC87A6A2748406551D845D1754A40992B836A832948406551D845D1754A40992B836A8329484001A260C614744A403B1DC87A6A27484001A260C614744A40
10428	Радищево	7	74	1130	47.834848999999998	47.897891999999999	52.868164999999998	52.845365000000001	0103000020E61000000100000005000000950C0055DCEA47406E179AEB346C4A40950C0055DCEA47401344DD07206F4A4086AB0320EEF247401344DD07206F4A4086AB0320EEF247406E179AEB346C4A40950C0055DCEA47406E179AEB346C4A40
11080	Паньшино	7	74	1130	48.437798000000001	48.462797999999999	52.935681000000002	52.914476000000001	0103000020E610000001000000050000008A20CEC3093848400B7DB08C0D754A408A20CEC3093848408A3E1F65C4774A40BD5301F73C3B48408A3E1F65C4774A40BD5301F73C3B48400B7DB08C0D754A408A20CEC3093848400B7DB08C0D754A40
11378	Ореховка	7	74	1130	48.197256000000003	48.236736999999998	52.954163000000001	52.928288000000002	0103000020E610000001000000050000004B7842AF3F19484077A22424D2764A404B7842AF3F194840D1066003227A4A406760E4654D1E4840D1066003227A4A406760E4654D1E484077A22424D2764A404B7842AF3F19484077A22424D2764A40
11173	Октябрьский	7	74	1130	47.905681000000001	47.942861999999998	53.029615999999997	53.011594000000002	0103000020E61000000100000005000000E6CDE15AEDF34740386A85E97B814A40E6CDE15AEDF347401BB80375CA834A401152B7B3AFF847401BB80375CA834A401152B7B3AFF84740386A85E97B814A40E6CDE15AEDF34740386A85E97B814A40
10648	Новая Дмитриевка	7	74	1130	47.957971999999998	47.984336999999996	52.826797999999997	52.814891000000003	0103000020E61000000100000005000000EA3D95D39EFA4740026729594E684A40EA3D95D39EFA4740F8325184D4694A40129F3BC1FEFD4740F8325184D4694A40129F3BC1FEFD4740026729594E684A40EA3D95D39EFA4740026729594E684A40
11275	Нижняя Маза	7	74	1130	47.912121999999997	47.931139000000002	52.933461000000001	52.916947	0103000020E6100000010000000500000026FBE769C0F447402995F0845E754A4026FBE769C0F44740B58B69A67B774A40DC8310902FF74740B58B69A67B774A40DC8310902FF747402995F0845E754A4026FBE769C0F447402995F0845E754A40
55818	Мордовская Курагужа	7	74	1130	48.160164999999999	48.185389000000001	52.836928999999998	52.813046	0103000020E610000001000000050000005F7B66498014484062122EE411684A405F7B66498014484078094E7D206B4A40E204A6D3BA17484078094E7D206B4A40E204A6D3BA17484062122EE411684A405F7B66498014484062122EE411684A40
11021	Кубра	7	74	1130	48.268096999999997	48.299627999999998	52.984653000000002	52.970799	0103000020E61000000100000005000000EE93A30051224840A8FE4124437C4A40EE93A300512248404374081C097E4A40A27BD6355A2648404374081C097E4A40A27BD6355A264840A8FE4124437C4A40EE93A30051224840A8FE4124437C4A40
10905	Калиновка	7	74	1130	48.304783999999998	48.334823999999998	52.970002000000001	52.947364999999998	0103000020E610000001000000050000000A2C80290327484001309E4143794A400A2C802903274840FD868906297C4A403CF54883DB2A4840FD868906297C4A403CF54883DB2A484001309E4143794A400A2C80290327484001309E4143794A40
10767	Дмитриевка	7	74	1130	47.69941	47.724670000000003	52.957526999999999	52.943697	0103000020E61000000100000005000000683F524486D94740AA2A3410CB784A40683F524486D94740BC04A73E907A4A4038328FFCC1DC4740BC04A73E907A4A4038328FFCC1DC4740AA2A3410CB784A40683F524486D94740AA2A3410CB784A40
10811	Гремячий	7	74	1130	47.688271	47.704996999999999	53.000127999999997	52.987748000000003	0103000020E6100000010000000500000082E49D4319D847403F58C6866E7E4A4082E49D4319D847402DE8BD3104804A40996379573DDA47402DE8BD3104804A40996379573DDA47403F58C6866E7E4A4082E49D4319D847403F58C6866E7E4A40
11007	Вязовка	7	74	1130	48.354821000000001	48.389567	52.869469000000002	52.851522000000003	0103000020E610000001000000050000008E7747C66A2D48408AE942ACFE6C4A408E7747C66A2D484063F19BC24A6F4A40E84CDA54DD31484063F19BC24A6F4A40E84CDA54DD3148408AE942ACFE6C4A408E7747C66A2D48408AE942ACFE6C4A40
11455	Волчанка	7	74	1130	48.122956000000002	48.171312999999998	53.025207000000002	53.003033000000002	0103000020E610000001000000050000006A6CAF05BD0F484086E7A56263804A406A6CAF05BD0F4840AD50A4FB39834A4098309A95ED154840AD50A4FB39834A4098309A95ED15484086E7A56263804A406A6CAF05BD0F484086E7A56263804A40
11389	Володарский	7	74	1130	48.224583000000003	48.240842000000001	52.863999999999997	52.851522000000003	0103000020E61000000100000005000000691EC022BF1C48408AE942ACFE6C4A40691EC022BF1C48403BDF4F8D976E4A406AC020E9D31E48403BDF4F8D976E4A406AC020E9D31E48408AE942ACFE6C4A40691EC022BF1C48408AE942ACFE6C4A40
10935	Вишневый	7	74	1130	48.252718000000002	48.273667000000003	53.022357999999997	53.00526	0103000020E61000000100000005000000268E3C10592048400DFD135CAC804A40268E3C1059204840E8667FA0DC824A404A7F2F8507234840E8667FA0DC824A404A7F2F85072348400DFD135CAC804A40268E3C10592048400DFD135CAC804A40
11198	Верхняя Маза	7	74	1130	47.925597000000003	47.948287999999998	52.981178	52.947240000000001	0103000020E610000001000000050000004B2366F679F6474045BB0A293F794A404B2366F679F6474000C79E3D977D4A4039984D8061F9474000C79E3D977D4A4039984D8061F9474045BB0A293F794A404B2366F679F6474045BB0A293F794A40
10634	Адоевщина	7	74	1130	47.713952999999997	47.750452000000003	52.900719000000002	52.879845000000003	0103000020E61000000100000005000000C7F0D8CF62DB47404A46CEC29E704A40C7F0D8CF62DB474063F19BC24A734A40E19BA6CF0EE0474063F19BC24A734A40E19BA6CF0EE047404A46CEC29E704A40C7F0D8CF62DB47404A46CEC29E704A40
10224	Шиковка	7	74	1044	47.382268000000003	47.416207	52.618110999999999	52.590989	0103000020E6100000010000000500000057276728EEB04740DBA50D87A54B4A4057276728EEB047402026E1421E4F4A40E2AE5E4546B547402026E1421E4F4A40E2AE5E4546B54740DBA50D87A54B4A4057276728EEB04740DBA50D87A54B4A40
10085	Шаховское	7	74	1044	47.242274999999999	47.294800000000002	52.632334999999998	52.619171000000001	0103000020E61000000100000005000000B7D100DE029F4740D9D0CDFE404F4A40B7D100DE029F4740DE8E705AF0504A402F6EA301BCA54740DE8E705AF0504A402F6EA301BCA54740D9D0CDFE404F4A40B7D100DE029F4740D9D0CDFE404F4A40
9400	Шалкино	7	74	1044	47.044673000000003	47.074955000000003	52.637849000000003	52.610258999999999	0103000020E61000000100000005000000D20149D8B78547407A8B87F71C4E4A40D20149D8B7854740A6643909A5514A40FAD51C2098894740A6643909A5514A40FAD51C20988947407A8B87F71C4E4A40D20149D8B78547407A8B87F71C4E4A40
9881	Холстовка	7	74	1044	47.209800999999999	47.240136999999997	52.858814000000002	52.837065000000003	0103000020E6100000010000000500000084D558C2DA9A474029D027F2246B4A4084D558C2DA9A474069ACFD9DED6D4A409FC728CFBC9E474069ACFD9DED6D4A409FC728CFBC9E474029D027F2246B4A4084D558C2DA9A474029D027F2246B4A40
10275	Татарский Шмалак	7	74	1044	46.986516000000002	47.010491999999999	52.736494	52.724344000000002	0103000020E61000000100000005000000897D0228467E4740E486DF4DB75C4A40897D0228467E4740A1D9756F455E4A40506F46CD57814740A1D9756F455E4A40506F46CD57814740E486DF4DB75C4A40897D0228467E4740E486DF4DB75C4A40
9668	Старый Пичеур	7	74	1044	47.050296000000003	47.07676	52.880850000000002	52.859270000000002	0103000020E61000000100000005000000508F6D19708647408B37328FFC6D4A40508F6D19708647403F575BB1BF704A400BD28C45D38947403F575BB1BF704A400BD28C45D38947408B37328FFC6D4A40508F6D19708647408B37328FFC6D4A40
9801	Старое Чирково	7	74	1044	46.953547999999998	46.986317999999997	52.905124000000001	52.887588000000001	0103000020E61000000100000005000000469561DC0D7A47403929CC7B9C714A40469561DC0D7A474090696D1ADB734A4062BA10AB3F7E474090696D1ADB734A4062BA10AB3F7E47403929CC7B9C714A40469561DC0D7A47403929CC7B9C714A40
9560	Плетьма	7	74	1044	46.850887999999998	46.884475999999999	52.664433000000002	52.652132000000002	0103000020E610000001000000050000008847E2E5E96C47406956B60F79534A408847E2E5E96C47400CB1FA230C554A40670C7382367147400CB1FA230C554A40670C7382367147406956B60F79534A408847E2E5E96C47406956B60F79534A40
9157	Павловка	7	74	1044	47.115586	47.170347	52.698625999999997	52.675623000000002	0103000020E610000001000000050000000FF0A485CB8E474074B680D07A564A400FF0A485CB8E47405111A7936C594A4061FC34EECD9547405111A7936C594A4061FC34EECD95474074B680D07A564A400FF0A485CB8E474074B680D07A564A40
10003	Октябрьское	7	74	1044	47.117471999999999	47.147205999999997	52.754522000000001	52.733179	0103000020E610000001000000050000000D198F52098F4740978E39CFD85D4A400D198F52098F4740670E492D94604A4032E36DA5D7924740670E492D94604A4032E36DA5D7924740978E39CFD85D4A400D198F52098F4740978E39CFD85D4A40
9985	Новая Камаевка	7	74	1044	47.168658000000001	47.183723000000001	52.808202000000001	52.795261000000004	0103000020E61000000100000005000000B91AD995969547406364C91CCB654A40B91AD99596954740E947C32973674A40F2423A3C84974740E947C32973674A40F2423A3C849747406364C91CCB654A40B91AD995969547406364C91CCB654A40
10184	Новая Андреевка	7	74	1044	47.375368999999999	47.387182000000003	52.650044999999999	52.640318999999998	0103000020E61000000100000005000000537765170CB04740F30016F9F5514A40537765170CB04740D3F6AFAC34534A40C9CC052E8FB14740D3F6AFAC34534A40C9CC052E8FB14740F30016F9F5514A40537765170CB04740F30016F9F5514A40
9788	Новая Алексеевка	7	74	1044	47.104590000000002	47.127740000000003	52.840378000000001	52.826369	0103000020E610000001000000050000008CBE8234638D4740D0B69A75C6694A408CBE8234638D474092239D81916B4A400E32C9C85990474092239D81916B4A400E32C9C859904740D0B69A75C6694A408CBE8234638D4740D0B69A75C6694A40
9505	Муратовка	7	74	1044	46.884340999999999	46.900860999999999	52.693173999999999	52.678986000000002	0103000020E6100000010000000500000087C1FC15327147408F386403E9564A4087C1FC15327147400038F6ECB9584A40F59ECA694F7347400038F6ECB9584A40F59ECA694F7347408F386403E9564A4087C1FC15327147408F386403E9564A40
10382	Мордовский Шмалак	7	74	1044	46.973221000000002	46.997591999999997	52.800711	52.783453999999999	0103000020E61000000100000005000000E5637781927C4740CFF57D3848644A40E5637781927C47401346B3B27D664A4028603B18B17F47401346B3B27D664A4028603B18B17F4740CFF57D3848644A40E5637781927C4740CFF57D3848644A40
9690	Лапаевка	7	74	1044	47.008308999999997	47.032257999999999	52.858580000000003	52.848117000000002	0103000020E6100000010000000500000098A1F1441081474040170D198F6C4A4098A1F14410814740F67F0EF3E56D4A406684B70721844740F67F0EF3E56D4A406684B7072184474040170D198F6C4A4098A1F1441081474040170D198F6C4A40
9380	Кадышевка	7	74	1044	47.205435000000001	47.227308999999998	52.674061000000002	52.658442000000001	0103000020E61000000100000005000000153AAFB14B9A47400B28D4D347544A40153AAFB14B9A474029417FA147564A40118B1876189D474029417FA147564A40118B1876189D47400B28D4D347544A40153AAFB14B9A47400B28D4D347544A40
9315	Илюшкино	7	74	1044	47.087792	47.114310000000003	52.603762000000003	52.589485000000003	0103000020E61000000100000005000000DB6CACC43C8B4740C53D963E744B4A40DB6CACC43C8B4740A648BE12484D4A408ACDC7B5A18E4740A648BE12484D4A408ACDC7B5A18E4740C53D963E744B4A40DB6CACC43C8B4740C53D963E744B4A40
9898	Ивановка	7	74	1044	47.200170999999997	47.219799000000002	52.828425000000003	52.818891999999998	0103000020E61000000100000005000000C64D0D349F9947405F7AFB73D1684A40C64D0D349F9947402B1895D4096A4A40C558A65F229C47402B1895D4096A4A40C558A65F229C47405F7AFB73D1684A40C64D0D349F9947405F7AFB73D1684A40
9298	Евлейка	7	74	1044	47.213493	47.239257000000002	52.742704000000003	52.731400999999998	0103000020E61000000100000005000000647616BD539B47407FA1478C9E5D4A40647616BD539B4740E04DB7EC105F4A40672B2FF99F9E4740E04DB7EC105F4A40672B2FF99F9E47407FA1478C9E5D4A40647616BD539B47407FA1478C9E5D4A40
10106	Гремучий	7	74	1044	47.343237000000002	47.369225	52.632263999999999	52.621850000000002	0103000020E610000001000000050000007AE3A430EFAB47404182E2C7984F4A407AE3A430EFAB47401538D906EE504A40CCEEC9C342AF47401538D906EE504A40CCEEC9C342AF47404182E2C7984F4A407AE3A430EFAB47404182E2C7984F4A40
9470	Баклуши	7	74	1044	46.898722999999997	46.922393999999997	52.68432	52.668982999999997	0103000020E61000000100000005000000DD94F25A097347403C4A253CA1554A40DD94F25A09734740D6FF39CC97574A406803B00111764740D6FF39CC97574A406803B001117647403C4A253CA1554A40DD94F25A097347403C4A253CA1554A40
9070	Фабричные Выселки	7	74	660	47.858725999999997	47.878525000000003	53.24944	53.235073999999997	0103000020E61000000100000005000000C91CCBBBEAED4740E811A3E7169E4A40C91CCBBBEAED4740392861A6ED9F4A40F5DBD78173F04740392861A6ED9F4A40F5DBD78173F04740E811A3E7169E4A40C91CCBBBEAED4740E811A3E7169E4A40
8870	Троицкий Сунгур	7	74	660	47.595033999999998	47.641782999999997	53.293829000000002	53.275122000000003	0103000020E610000001000000050000000801F9122ACC47407F349C3237A34A400801F9122ACC4740E6CE4C309CA54A407B1002F225D24740E6CE4C309CA54A407B1002F225D247407F349C3237A34A400801F9122ACC47407F349C3237A34A40
8409	Суруловка	7	74	660	47.735880999999999	47.749625999999999	53.095782	53.082493999999997	0103000020E61000000100000005000000B75F3E5931DE4740E00ED4298F8A4A40B75F3E5931DE4740D2C5A695428C4A409B1DA9BEF3DF4740D2C5A695428C4A409B1DA9BEF3DF4740E00ED4298F8A4A40B75F3E5931DE4740E00ED4298F8A4A40
8520	Старое Томышево	7	74	660	47.873646999999998	47.925398999999999	53.204692000000001	53.171869999999998	0103000020E61000000100000005000000CF9F36AAD3EF4740EE940ED6FF954A40CF9F36AAD3EF47405DE0F258339A4A402460747973F647405DE0F258339A4A402460747973F64740EE940ED6FF954A40CF9F36AAD3EF4740EE940ED6FF954A40
8800	Свирино	7	74	660	47.575505	47.603568000000003	53.154631999999999	53.136111999999997	0103000020E610000001000000050000009DD7D825AAC94740EC4B361E6C914A409DD7D825AAC9474021753BFBCA934A40C1745AB741CD474021753BFBCA934A40C1745AB741CD4740EC4B361E6C914A409DD7D825AAC94740EC4B361E6C914A40
8972	Самайкино	7	74	660	47.808762000000002	47.829692000000001	53.290168999999999	53.267696000000001	0103000020E61000000100000005000000B01F628385E7474090A2CEDC43A24A40B01F628385E7474011A8FE4124A54A405DE0F25833EA474011A8FE4124A54A405DE0F25833EA474090A2CEDC43A24A40B01F628385E7474090A2CEDC43A24A40
55794	Садовое	7	74	660	47.636977000000002	47.686303000000002	53.137981000000003	53.122360999999998	0103000020E61000000100000005000000F0A65B7688D1474026A77686A98F4A40F0A65B7688D14740153C855CA9914A40C712D6C6D8D74740153C855CA9914A40C712D6C6D8D7474026A77686A98F4A40F0A65B7688D1474026A77686A98F4A40
4485	Рокотушка	7	74	660	47.688566999999999	47.701735999999997	53.231161	53.218767	0103000020E610000001000000050000006B0DA5F622D84740D6389B8E009C4A406B0DA5F622D847402A8E03AF969D4A408236397CD2D947402A8E03AF969D4A408236397CD2D94740D6389B8E009C4A406B0DA5F622D84740D6389B8E009C4A40
8691	Репьевка	7	74	660	48.070853999999997	48.113255000000002	53.179335000000002	53.149031999999998	0103000020E6100000010000000500000038656EBE110948405B07077B13934A4038656EBE110948409B030473F4964A40E38DCC237F0E48409B030473F4964A40E38DCC237F0E48405B07077B13934A4038656EBE110948405B07077B13934A40
9042	Плодопитомник	7	74	660	47.851925999999999	47.858770999999997	53.251627999999997	53.246617000000001	0103000020E61000000100000005000000594E42E90BED47409ED15625919F4A40594E42E90BED47400261A75835A04A4069E04735ECED47400261A75835A04A4069E04735ECED47409ED15625919F4A40594E42E90BED47409ED15625919F4A40
7937	Новоспасское	7	74	660	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
7703	Новое Томышево	7	74	660	47.866540999999998	47.937435999999998	53.157083999999998	53.146315999999999	0103000020E6100000010000000500000052D2C3D0EAEE4740D670917BBA924A4052D2C3D0EAEE4740C85C19541B944A40E90B21E7FDF74740C85C19541B944A40E90B21E7FDF74740D670917BBA924A4052D2C3D0EAEE4740D670917BBA924A40
8858	Новая Лава	7	74	660	47.536805999999999	47.560979000000003	53.061242	53.044002999999996	0103000020E61000000100000005000000F6251B0FB6C4474083F6EAE3A1854A40F6251B0FB6C44740219221C7D6874A40145FED28CEC74740219221C7D6874A40145FED28CEC7474083F6EAE3A1854A40F6251B0FB6C4474083F6EAE3A1854A40
8326	Малая Андреевка	7	74	660	47.796311000000003	47.835765000000002	53.148038	53.141471000000003	0103000020E61000000100000005000000F838D384EDE547408D2AC3B81B924A40F838D384EDE547405A48C0E8F2924A401B12F758FAEA47405A48C0E8F2924A401B12F758FAEA47408D2AC3B81B924A40F838D384EDE547408D2AC3B81B924A40
8611	Крупозавод	7	74	660	48.112931000000003	48.147894000000001	53.155529000000001	53.148384	0103000020E6100000010000000500000030DAE385740E4840F59F353FFE924A4030DAE385740E4840304AD05FE8934A4027A3CA30EE124840304AD05FE8934A4027A3CA30EE124840F59F353FFE924A4030DAE385740E4840F59F353FFE924A40
8696	Красный	7	74	660	48.047085000000003	48.083170000000003	53.147962999999997	53.140341999999997	0103000020E61000000100000005000000EB909BE106064840AB2006BAF6914A40EB909BE1060648404F029B73F0924A4011018750A50A48404F029B73F0924A4011018750A50A4840AB2006BAF6914A40EB909BE106064840AB2006BAF6914A40
8588	Красносельск	7	74	660	48.110021000000003	48.140824000000002	53.178843999999998	53.168810000000001	0103000020E61000000100000005000000C66F0A2B150E48406F9EEA909B954A40C66F0A2B150E4840FC8A355CE4964A40F73E558506124840FC8A355CE4964A40F73E5585061248406F9EEA909B954A40C66F0A2B150E48406F9EEA909B954A40
8484	Коптевка	7	74	660	47.912067999999998	47.966721	53.190908999999998	53.172474999999999	0103000020E6100000010000000500000033DDEBA4BEF4474055302AA913964A4033DDEBA4BEF447408BC1C3B46F984A409FAD8383BDFB47408BC1C3B46F984A409FAD8383BDFB474055302AA913964A4033DDEBA4BEF4474055302AA913964A40
8949	Комаровка	7	74	660	47.709228000000003	47.735315	53.289695999999999	53.274566999999998	0103000020E6100000010000000500000029B4ACFBC7DA4740C9C7EE0225A34A4029B4ACFBC7DA474019E42EC214A54A400EA14ACD1EDE474019E42EC214A54A400EA14ACD1EDE4740C9C7EE0225A34A4029B4ACFBC7DA4740C9C7EE0225A34A40
8430	Алакаевка	7	74	660	47.948135000000001	47.973619999999997	53.296756999999999	53.281641999999998	0103000020E61000000100000005000000B398D87C5CF947400B9755D80CA44A40B398D87C5CF94740F6ED2422FCA54A40A25D85949FFC4740F6ED2422FCA54A40A25D85949FFC47400B9755D80CA44A40B398D87C5CF947400B9755D80CA44A40
7349	Эчкаюн	7	74	892	50.140670999999998	50.168816	54.180535999999996	54.168993999999998	0103000020E61000000100000005000000703FE08101124940309C6B98A1154B40703FE0810112494015E0BBCD1B174B4051853FC39B15494015E0BBCD1B174B4051853FC39B154940309C6B98A1154B40703FE08101124940309C6B98A1154B40
7646	Старый Сантимир	7	74	892	50.057011000000003	50.074491999999999	54.335819999999998	54.321491999999999	0103000020E610000001000000050000009241EE224C0749407BF65CA626294B409241EE224C074940DEAB5626FC2A4B4025E82FF488094940DEAB5626FC2A4B4025E82FF4880949407BF65CA626294B409241EE224C0749407BF65CA626294B40
7543	Старая Тюгальбуга	7	74	892	50.142504000000002	50.174258999999999	54.321207999999999	54.293582000000001	0103000020E610000001000000050000004CC631923D124940DE58501894254B404CC631923D124940569BFF571D294B404F04711E4E164940569BFF571D294B404F04711E4E164940DE58501894254B404CC631923D124940DE58501894254B40
7894	Старая Малыкла	7	74	892	49.822074999999998	49.846283999999997	54.236441999999997	54.217778000000003	0103000020E61000000100000005000000FAEDEBC039E94840E7E44526E01B4B40FAEDEBC039E948404EB340BB431E4B406490BB0853EC48404EB340BB431E4B406490BB0853EC4840E7E44526E01B4B40FAEDEBC039E94840E7E44526E01B4B40
7264	Старая Куликовка	7	74	892	49.969551000000003	49.991487999999997	54.231811	54.217289000000001	0103000020E61000000100000005000000ED66463F1AFC4840E9633E20D01B4B40ED66463F1AFC484031ED9BFBAB1D4B402F302B14E9FE484031ED9BFBAB1D4B402F302B14E9FE4840E9633E20D01B4B40ED66463F1AFC4840E9633E20D01B4B40
7626	Старая Бесовка	7	74	892	49.949168	49.992342000000001	54.308340000000001	54.284678999999997	0103000020E61000000100000005000000723447567EF94840D26D895C70244B40723447567EF948403A0664AF77274B403F390A1005FF48403A0664AF77274B403F390A1005FF4840D26D895C70244B40723447567EF94840D26D895C70244B40
55839	Станция Якушка	7	74	892	50.070926	50.101900000000001	54.200617999999999	54.191152000000002	0103000020E61000000100000005000000D237691A14094940524832AB77184B40D237691A14094940957EC2D9AD194B4030BB270F0B0D4940957EC2D9AD194B4030BB270F0B0D4940524832AB77184B40D237691A14094940524832AB77184B40
7818	Средняя Якушка	7	74	892	49.790706	49.831713999999998	54.173838000000003	54.160207	0103000020E610000001000000050000002060ADDA35E548408ECBB8A981144B402060ADDA35E54840AA66D65240164B400BD0B69A75EA4840AA66D65240164B400BD0B69A75EA48408ECBB8A981144B402060ADDA35E548408ECBB8A981144B40
7564	Средний Сантимир	7	74	892	50.077734999999997	50.104523	54.294223000000002	54.253445999999997	0103000020E6100000010000000500000095607138F3094940A8A624EB70204B4095607138F3094940925D6919A9254B4004577902610D4940925D6919A9254B4004577902610D4940A8A624EB70204B4095607138F3094940A8A624EB70204B40
7439	Новочеремшанск	7	74	892	50.119103000000003	50.190097000000002	54.391212000000003	54.336123999999998	0103000020E6100000010000000500000081ED60C43E0F49404AB3791C062B4B4081ED60C43E0F4940C1E61C3C13324B40AB08371955184940C1E61C3C13324B40AB083719551849404AB3791C062B4B4081ED60C43E0F49404AB3791C062B4B40
7156	Новая Малыкла	7	74	892	49.900371999999997	49.968707000000002	54.212614000000002	54.187196	0103000020E61000000100000005000000F71DC3633FF3484094F8DC09F6174B40F71DC3633FF34840FC5580EF361B4B4001344A97FEFB4840FC5580EF361B4B4001344A97FEFB484094F8DC09F6174B40F71DC3633FF3484094F8DC09F6174B40
7063	Новая Куликовка	7	74	892	50.035245000000003	50.068635	54.135637000000003	54.117348999999997	0103000020E610000001000000050000007C2C7DE882044940F19BC24A050F4B407C2C7DE88204494054909F8D5C114B40342E1C08C908494054909F8D5C114B40342E1C08C9084940F19BC24A050F4B407C2C7DE882044940F19BC24A050F4B40
6994	Новая Бесовка	7	74	892	50.129469	50.162446000000003	54.135590000000001	54.115470999999999	0103000020E61000000100000005000000446CB070921049407651F4C0C70E4B40446CB0709210494013D55B035B114B40DAAED007CB14494013D55B035B114B40DAAED007CB1449407651F4C0C70E4B40446CB070921049407651F4C0C70E4B40
7807	Нижняя Якушка	7	74	892	49.771059999999999	49.810046	54.218330999999999	54.201171000000002	0103000020E610000001000000050000007BA01518B2E24840AAF3A8F8BF194B407BA01518B2E24840FB592C45F21B4B40B8205B96AFE74840FB592C45F21B4B40B8205B96AFE74840AAF3A8F8BF194B407BA01518B2E24840AAF3A8F8BF194B40
6969	Елховый Куст	7	74	892	49.960667000000001	49.998136000000002	54.079175999999997	54.060070000000003	0103000020E6100000010000000500000058ACE122F7FA484041BCAE5FB0074B4058ACE122F7FA484065506D70220A4B40EA7AA2EBC2FF484065506D70220A4B40EA7AA2EBC2FF484041BCAE5FB0074B4058ACE122F7FA484041BCAE5FB0074B40
6893	Высокий Колок	7	74	892	50.086143999999997	50.109706000000003	54.085312999999999	54.067368000000002	0103000020E61000000100000005000000915F3FC4060B49400266BE839F084B40915F3FC4060B49403A765089EB0A4B406616A1D80A0E49403A765089EB0A4B406616A1D80A0E49400266BE839F084B40915F3FC4060B49400266BE839F084B40
7389	Вороний Куст	7	74	892	50.181024000000001	50.214162000000002	54.311644000000001	54.296886999999998	0103000020E6100000010000000500000043E55FCB2B174940C4CDA96400264B4043E55FCB2B17494050FF59F3E3274B40E20511A9691B494050FF59F3E3274B40E20511A9691B4940C4CDA96400264B4043E55FCB2B174940C4CDA96400264B40
7715	Верхняя Якушка	7	74	892	49.856355000000001	49.890185000000002	54.143844000000001	54.115043	0103000020E610000001000000050000000F62670A9DED48401E51A1BAB90E4B400F62670A9DED4840E8DCED7A69124B40E4310395F1F14840E8DCED7A69124B40E4310395F1F148401E51A1BAB90E4B400F62670A9DED48401E51A1BAB90E4B40
55843	Андреево	7	74	892	50.018878000000001	50.040391999999997	54.024540999999999	54.007432000000001	0103000020E61000000100000005000000944E24986A024940D1782288F3004B40944E24986A024940A034D42824034B409082A7902B054940A034D42824034B409082A7902B054940D1782288F3004B40944E24986A024940D1782288F3004B40
7100	Александровка	7	74	892	50.024762000000003	50.099564000000001	54.247906999999998	54.147266999999999	0103000020E610000001000000050000007F17B6662B034940D86322A5D9124B407F17B6662B03494088B9A46ABB1F4B40F2ED5D83BE0C494088B9A46ABB1F4B40F2ED5D83BE0C4940D86322A5D9124B407F17B6662B034940D86322A5D9124B40
6602	Эзекеево	7	74	154	46.988205000000001	47.026409999999998	53.311059999999998	53.297710000000002	0103000020E61000000100000005000000315F5E807D7E474099D87C5C1BA64A40315F5E807D7E4740008C67D0D0A74A40C824236761834740008C67D0D0A74A40C82423676183474099D87C5C1BA64A40315F5E807D7E474099D87C5C1BA64A40
55829	ЧувашскийСайман	7	74	154	47.084684000000003	47.124828999999998	53.303623999999999	53.291159999999998	0103000020E610000001000000050000004B3FE1ECD68A4740A1F31ABB44A54A404B3FE1ECD68A4740EE23B726DDA64A40D34B8C65FA8F4740EE23B726DDA64A40D34B8C65FA8F4740A1F31ABB44A54A404B3FE1ECD68A4740A1F31ABB44A54A40
5856	Топорнино	7	74	154	47.209809999999997	47.244574999999998	53.286703000000003	53.276985000000003	0103000020E61000000100000005000000D72FD80DDB9A4740C53D963E74A34A40D72FD80DDB9A4740225514AFB2A44A40A835CD3B4E9F4740225514AFB2A44A40A835CD3B4E9F4740C53D963E74A34A40D72FD80DDB9A4740C53D963E74A34A40
5647	Тепловка	7	74	154	47.414014999999999	47.439473	53.238754999999998	53.223846000000002	0103000020E61000000100000005000000D7868A71FEB4474093AB58FCA69C4A40D7868A71FEB44740D4601A868F9E4A40CD3CB9A640B84740D4601A868F9E4A40CD3CB9A640B8474093AB58FCA69C4A40D7868A71FEB4474093AB58FCA69C4A40
5570	Телятниково	7	74	154	47.246020999999999	47.291286999999997	53.025640000000003	53.007123999999997	0103000020E610000001000000050000008A90BA9D7D9F474023827170E9804A408A90BA9D7D9F474017BCE82B48834A40FE5F75E448A5474017BCE82B48834A40FE5F75E448A5474023827170E9804A408A90BA9D7D9F474023827170E9804A40
6482	Татарский Сайман	7	74	154	47.094619000000002	47.154321000000003	53.300094000000001	53.284866999999998	0103000020E61000000100000005000000454AB3791C8C4740D55A988576A44A40454AB3791C8C4740E8DCED7A69A64A40030B60CAC0934740E8DCED7A69A64A40030B60CAC0934740D55A988576A44A40454AB3791C8C4740D55A988576A44A40
6785	Сухая Терешка	7	74	154	47.459631000000002	47.512011999999999	52.988160000000001	52.971992	0103000020E61000000100000005000000289D4830D5BA4740A0FCDD3B6A7C4A40289D4830D5BA4740919BE1067C7E4A406C94F59B89C14740919BE1067C7E4A406C94F59B89C14740A0FCDD3B6A7C4A40289D4830D5BA4740A0FCDD3B6A7C4A40
6692	Славкино	7	74	154	47.155012999999997	47.197189000000002	52.969768999999999	52.947082999999999	0103000020E6100000010000000500000038BA4A77D79347407DCC07043A794A4038BA4A77D79347405AD6FD63217C4A40C310397D3D9947405AD6FD63217C4A40C310397D3D9947407DCC07043A794A4038BA4A77D79347407DCC07043A794A40
6292	Рызлей	7	74	154	46.956135000000003	46.990144999999998	53.195711000000003	53.181288000000002	0103000020E61000000100000005000000CEC7B5A1627A47402194F77134974A40CEC7B5A1627A4740D63BDC0E0D994A4022A64412BD7E4740D63BDC0E0D994A4022A64412BD7E47402194F77134974A40CEC7B5A1627A47402194F77134974A40
6515	Поспеловка	7	74	154	47.038384000000001	47.067777	53.310457	53.303311999999998	0103000020E61000000100000005000000475854C4E9844740FF3D78EDD2A64A40475854C4E98447403AE8120EBDA74A40E335AFEAAC8847403AE8120EBDA74A40E335AFEAAC884740FF3D78EDD2A64A40475854C4E9844740FF3D78EDD2A64A40
5320	Поника	7	74	154	47.136184	47.163114999999998	53.197712000000003	53.181569000000003	0103000020E61000000100000005000000861E317A6E914740D57B2AA73D974A40861E317A6E9147406D0377A04E994A40573ECBF3E09447406D0377A04E994A40573ECBF3E0944740D57B2AA73D974A40861E317A6E914740D57B2AA73D974A40
55837	Никулино	7	74	154	47.047412000000001	47.060257999999997	53.154324000000003	53.147849000000001	0103000020E610000001000000050000000FB8AE981186474087DF4DB7EC924A400FB8AE9811864740747E8AE3C0934A4043A9BD88B6874740747E8AE3C0934A4043A9BD88B687474087DF4DB7EC924A400FB8AE981186474087DF4DB7EC924A40
6259	Никулино	7	74	154	47.046666999999999	47.068261999999997	53.175341000000003	53.160252999999997	0103000020E61000000100000005000000B6662B2FF9854740FE0A992B83944A40B6662B2FF9854740F052EA9271964A409FC728CFBC884740F052EA9271964A409FC728CFBC884740FE0A992B83944A40B6662B2FF9854740FE0A992B83944A40
55764	Николаевка	7	74	154	47.181781999999998	47.237279999999998	53.141140999999998	53.119492000000001	0103000020E610000001000000050000003080F0A1449747401B118C834B8F4A403080F0A144974740F78F85E810924A4058FFE7305F9E4740F78F85E810924A4058FFE7305F9E47401B118C834B8F4A403080F0A1449747401B118C834B8F4A40
6819	Куроедово	7	74	154	47.434227	47.447341999999999	53.090725999999997	53.074553000000002	0103000020E61000000100000005000000250516C094B74740CB68E4F38A894A40250516C094B74740CD72D9E89C8B4A404910AE8042B94740CD72D9E89C8B4A404910AE8042B94740CB68E4F38A894A40250516C094B74740CB68E4F38A894A40
6181	Курмаевка	7	74	154	46.957276	46.979114000000003	53.133881000000002	53.126527000000003	0103000020E61000000100000005000000739F1C05887A4740CF87670932904A40739F1C05887A474024473A0323914A402387889B537D474024473A0323914A402387889B537D4740CF87670932904A40739F1C05887A4740CF87670932904A40
6101	Крутец	7	74	154	47.388745	47.426996000000003	53.148724000000001	53.137965000000001	0103000020E61000000100000005000000E4BD6A65C2B147400F7F4DD6A8914A40E4BD6A65C2B14740AE10566309934A40ECC20FCEA7B64740AE10566309934A40ECC20FCEA7B647400F7F4DD6A8914A40E4BD6A65C2B147400F7F4DD6A8914A40
5713	Кравково	7	74	154	47.285601	47.320967000000003	53.296143999999998	53.286428000000001	0103000020E610000001000000050000003A5AD5928EA44740505436ACA9A44A403A5AD5928EA447400C74ED0BE8A54A40310C587215A947400C74ED0BE8A54A40310C587215A94740505436ACA9A44A403A5AD5928EA44740505436ACA9A44A40
15626	Кезьмино	7	74	154	47.184325000000001	47.205579	53.290390000000002	53.281377999999997	0103000020E61000000100000005000000E86A2BF6979747402DE8BD3104A44A40E86A2BF697974740F08AE07F2BA54A4048DFA469509A4740F08AE07F2BA54A4048DFA469509A47402DE8BD3104A44A40E86A2BF6979747402DE8BD3104A44A40
5789	Канасаево	7	74	154	47.450792	47.478397000000001	53.350487999999999	53.311878	0103000020E6100000010000000500000033A6608DB3B94740C32B499EEBA74A4033A6608DB3B94740FAD170CADCAC4A4094C0E61C3CBD4740FAD170CADCAC4A4094C0E61C3CBD4740C32B499EEBA74A4033A6608DB3B94740C32B499EEBA74A40
6052	Канадей	7	74	154	47.477786000000002	47.556100999999998	53.183976000000001	53.146552999999997	0103000020E610000001000000050000004B3E761728BD4740BA10AB3FC2924A404B3E761728BD4740DC9F8B868C974A40EE224C512EC74740DC9F8B868C974A40EE224C512EC74740BA10AB3FC2924A404B3E761728BD4740BA10AB3FC2924A40
5864	Дубровка	7	74	154	47.012881	47.040036999999998	53.095624999999998	53.081384999999997	0103000020E61000000100000005000000B1DEA815A681474046B1DCD26A8A4A40B1DEA815A68147400AD7A3703D8C4A40A2D0B2EE1F8547400AD7A3703D8C4A40A2D0B2EE1F85474046B1DCD26A8A4A40B1DEA815A681474046B1DCD26A8A4A40
5390	Давыдовка	7	74	154	47.149433999999999	47.174703999999998	53.078637000000001	53.057761999999997	0103000020E610000001000000050000008A743FA720934740CC79C6BE64874A408A743FA720934740B6A0F7C6108A4A407D3D5FB35C964740B6A0F7C6108A4A407D3D5FB35C964740CC79C6BE64874A408A743FA720934740CC79C6BE64874A40
5532	Губашево	7	74	154	47.097583	47.124012	53.074012000000003	53.054726000000002	0103000020E61000000100000005000000A2D288997D8C4740D61EF64201874A40A2D288997D8C47407BC1A73979894A40E1270EA0DF8F47407BC1A73979894A40E1270EA0DF8F4740D61EF64201874A40A2D288997D8C4740D61EF64201874A40
5707	Головино	7	74	154	47.346497999999997	47.372297000000003	53.288311999999998	53.272860000000001	0103000020E610000001000000050000009010E50B5AAC47407B319413EDA24A409010E50B5AAC4740AD855968E7A44A4010B3976DA7AF4740AD855968E7A44A4010B3976DA7AF47407B319413EDA24A409010E50B5AAC47407B319413EDA24A40
6180	Большой Чирклей	7	74	154	46.995049999999999	47.03904	53.156937999999997	53.139012999999998	0103000020E6100000010000000500000041F163CC5D7F4740035C902DCB914A4041F163CC5D7F4740F4BF5C8B16944A40309E4143FF844740F4BF5C8B16944A40309E4143FF844740035C902DCB914A4041F163CC5D7F4740035C902DCB914A40
5466	Болдасьево	7	74	154	47.098823000000003	47.124389000000001	53.029794000000003	53.015928000000002	0103000020E61000000100000005000000DB8B683BA68C47409C8BBFED09824A40DB8B683BA68C4740FBCE2F4AD0834A40B77D8FFAEB8F4740FBCE2F4AD0834A40B77D8FFAEB8F47409C8BBFED09824A40DB8B683BA68C47409C8BBFED09824A40
55805	Белое Озеро	7	74	154	46.980280999999998	46.998041000000001	53.029415	53.012146000000001	0103000020E61000000100000005000000F1F109D9797D47407C6308008E814A40F1F109D9797D47408481E7DEC3834A409888B7CEBF7F47408481E7DEC3834A409888B7CEBF7F47407C6308008E814A40F1F109D9797D47407C6308008E814A40
5362	Барановка	7	74	154	47.144646000000002	47.180489000000001	53.030807000000003	53.008533	0103000020E61000000100000005000000A5BF97C283924740E8F7FD9B17814A40A5BF97C28392474073BED87BF1834A40D52478431A97474073BED87BF1834A40D52478431A974740E8F7FD9B17814A40A5BF97C283924740E8F7FD9B17814A40
5226	Баевка	7	74	154	47.243541999999998	47.267122000000001	53.104140999999998	53.083668000000003	0103000020E61000000100000005000000E9995E622C9F474062DC0DA2B58A4A40E9995E622C9F47401C96067E548D4A406405BF0D31A247401C96067E548D4A406405BF0D31A2474062DC0DA2B58A4A40E9995E622C9F474062DC0DA2B58A4A40
6387	Ахметлей	7	74	154	46.977488000000001	47.011766999999999	53.247219999999999	53.224249999999998	0103000020E61000000100000005000000C11DA8531E7D474062105839B49C4A40C11DA8531E7D47406475ABE7A49F4A400516C094818147406475ABE7A49F4A400516C0948181474062105839B49C4A40C11DA8531E7D474062105839B49C4A40
6708	Андреевка	7	74	154	47.064436000000001	47.09337	52.973576000000001	52.957977	0103000020E61000000100000005000000B05758703F884740FCA886FD9E7A4A40B05758703F884740D3156C239E7C4A40B936548CF38B4740D3156C239E7C4A40B936548CF38B4740FCA886FD9E7A4A40B05758703F884740FCA886FD9E7A4A40
2697	Щербаковка	7	74	411	49.873449000000001	49.891488000000003	54.106973000000004	54.099054000000002	0103000020E61000000100000005000000A9DC442DCDEF4840DD442DCDAD0C4B40A9DC442DCDEF48400B47904AB10D4B4063635E471CF248400B47904AB10D4B4063635E471CF24840DD442DCDAD0C4B40A9DC442DCDEF4840DD442DCDAD0C4B40
4192	Чувашский Сускан	7	74	411	49.196523999999997	49.233400000000003	53.888319000000003	53.871552000000001	0103000020E610000001000000050000008670CCB227994840B76114048FEF4A408670CCB2279948402DB5DE6FB4F14A4076711B0DE09D48402DB5DE6FB4F14A4076711B0DE09D4840B76114048FEF4A408670CCB227994840B76114048FEF4A40
55834	Черная Речка	7	74	411	49.733778999999998	49.763855	54.186179000000003	54.167918999999998	0103000020E61000000100000005000000ECBE6378ECDD484042B0AA5E7E154B40ECBE6378ECDD4840DB19A6B6D4174B406BF12900C6E14840DB19A6B6D4174B406BF12900C6E1484042B0AA5E7E154B40ECBE6378ECDD484042B0AA5E7E154B40
3770	Филипповка	7	74	411	49.746687999999999	49.780402000000002	54.01511	53.987732999999999	0103000020E610000001000000050000006728EE7893DF48400917F2086EFE4A406728EE7893DF4840D9EBDD1FEF014B40D3DD7536E4E34840D9EBDD1FEF014B40D3DD7536E4E348400917F2086EFE4A406728EE7893DF48400917F2086EFE4A40
3609	Уткин	7	74	411	49.631811999999996	49.651566000000003	53.913179	53.901662999999999	0103000020E61000000100000005000000349C3237DFD04840B28174B169F34A40349C3237DFD048406E32AA0CE3F44A40C097C28366D348406E32AA0CE3F44A40C097C28366D34840B28174B169F34A40349C3237DFD04840B28174B169F34A40
4955	Тинарка	7	74	411	49.586239999999997	49.613055000000003	54.510302000000003	54.487839999999998	0103000020E61000000100000005000000B3CD8DE909CB48401FD7868A713E4B40B3CD8DE909CB4840AD8A709351414B401CD3139678CE4840AD8A709351414B401CD3139678CE48401FD7868A713E4B40B3CD8DE909CB48401FD7868A713E4B40
4622	Тиинск	7	74	411	49.619549999999997	49.666361000000002	54.408408000000001	54.369140999999999	0103000020E610000001000000050000004F1E166A4DCF48406E4E2503402F4B404F1E166A4DCF48405FB69DB646344B40392A37514BD548405FB69DB646344B40392A37514BD548406E4E2503402F4B404F1E166A4DCF48406E4E2503402F4B40
4862	Терентьевка	7	74	411	49.751871000000001	49.764285999999998	54.395699	54.376047999999997	0103000020E61000000100000005000000C9E7154F3DE04840F4DC425722304B40C9E7154F3DE04840AB07CC43A6324B403465A71FD4E14840AB07CC43A6324B403465A71FD4E14840F4DC425722304B40C9E7154F3DE04840F4DC425722304B40
3116	Степная Васильевка	7	74	411	49.500765000000001	49.525730000000003	54.064599000000001	54.045386999999998	0103000020E61000000100000005000000A0FD481119C04840EF54C03DCF054B40A0FD481119C048405A2DB0C744084B405743E21E4BC348405A2DB0C744084B405743E21E4BC34840EF54C03DCF054B40A0FD481119C04840EF54C03DCF054B40
49157	Старое Письмирь	7	74	411	49.893732999999997	49.915579999999999	54.377679000000001	54.372571000000001	0103000020E61000000100000005000000902DCBD765F2484011381268B02F4B40902DCBD765F2484068B114C957304B40936FB6B931F5484068B114C957304B40936FB6B931F5484011381268B02F4B40902DCBD765F2484011381268B02F4B40
4233	Старая Сахча	7	74	411	49.928750000000001	49.961682000000003	54.430180999999997	54.412531999999999	0103000020E610000001000000050000007B14AE47E1F64840D8463CD9CD344B407B14AE47E1F64840272EC72B10374B407193516518FB4840272EC72B10374B407193516518FB4840D8463CD9CD344B407B14AE47E1F64840D8463CD9CD344B40
55833	Слобода Выходцева	7	74	411	49.637937999999998	49.668686999999998	54.361666	54.346952999999999	0103000020E610000001000000050000001570CFF3A7D14840E21FB6F4682C4B401570CFF3A7D148409E094D124B2E4B4053211E8997D548409E094D124B2E4B4053211E8997D54840E21FB6F4682C4B401570CFF3A7D14840E21FB6F4682C4B40
2944	Сабакаево	7	74	411	49.637569999999997	49.684992000000001	54.153151999999999	54.134650999999998	0103000020E610000001000000050000009274CDE49BD14840D5AF743E3C114B409274CDE49BD1484093A8177C9A134B40C5025FD1ADD7484093A8177C9A134B40C5025FD1ADD74840D5AF743E3C114B409274CDE49BD14840D5AF743E3C114B40
3871	Рязаново	7	74	411	49.391790999999998	49.424103000000002	53.994222999999998	53.969431999999998	0103000020E61000000100000005000000FEEE1D3526B2484012D9075916FC4A40FEEE1D3526B248402BF702B342FF4A405891D10149B648402BF702B342FF4A405891D10149B6484012D9075916FC4A40FEEE1D3526B2484012D9075916FC4A40
4782	Русский Мелекесс	7	74	411	49.519404999999999	49.553280999999998	54.318098999999997	54.294916999999998	0103000020E610000001000000050000007F30F0DC7BC2484068041BD7BF254B407F30F0DC7BC24840F5F1D077B7284B40C43F6CE9D1C64840F5F1D077B7284B40C43F6CE9D1C6484068041BD7BF254B407F30F0DC7BC2484068041BD7BF254B40
3559	Просторы	7	74	411	49.902814999999997	49.922775999999999	53.875039000000001	53.861856000000003	0103000020E610000001000000050000004BAB21718FF3484042EE224C51EE4A404BAB21718FF34840BEDC274701F04A4050C422861DF64840BEDC274701F04A4050C422861DF6484042EE224C51EE4A404BAB21718FF3484042EE224C51EE4A40
2886	Приморское	7	74	411	49.446111999999999	49.467016000000001	54.062258	54.049678999999998	0103000020E61000000100000005000000342DB1321AB948402426A8E15B064B40342DB1321AB948400AF5F411F8074B40B85A272EC7BB48400AF5F411F8074B40B85A272EC7BB48402426A8E15B064B40342DB1321AB948402426A8E15B064B40
3403	Новоселки	7	74	411	49.726529999999997	49.797874	53.915686999999998	53.888567999999999	0103000020E610000001000000050000000CC85EEFFEDC4840D522A298BCF14A400CC85EEFFEDC4840A92F4B3B35F54A40132A38BC20E64840A92F4B3B35F54A40132A38BC20E64840D522A298BCF14A400CC85EEFFEDC4840D522A298BCF14A40
3807	Новая Сахча	7	74	411	50.007182	50.023800999999999	54.466402000000002	54.454396000000003	0103000020E61000000100000005000000588FFB56EB00494074B7EBA5293A4B40588FFB56EB004940FE648C0FB33B4B40594E42E90B034940FE648C0FB33B4B40594E42E90B03494074B7EBA5293A4B40588FFB56EB00494074B7EBA5293A4B40
2422	Новая Майна	7	74	411	49.712542999999997	49.790140000000001	54.164208000000002	54.133997000000001	0103000020E6100000010000000500000032FFE89B34DB48408D614ED026114B4032FFE89B34DB4840ECDE8AC404154B4077A1B94E23E54840ECDE8AC404154B4077A1B94E23E548408D614ED026114B4032FFE89B34DB48408D614ED026114B40
3241	Никольское-на-Черемшане	7	74	411	49.153019	49.209702	54.068984999999998	54.039005000000003	0103000020E610000001000000050000005455682096934840B4B0A71DFE044B40545568209693484010751F80D4084B40F1F3DF83D79A484010751F80D4084B40F1F3DF83D79A4840B4B0A71DFE044B405455682096934840B4B0A71DFE044B40
2193	Мулловка	7	74	411	49.362496999999998	49.421723	54.243850999999999	54.166601	0103000020E61000000100000005000000F5F23B4D66AE48408E3D7B2E53154B40F5F23B4D66AE4840670C7382361F4B404A7CEE04FBB54840670C7382361F4B404A7CEE04FBB548408E3D7B2E53154B40F5F23B4D66AE48408E3D7B2E53154B40
3714	Мордово-Озеро	7	74	411	49.685009999999998	49.716137000000003	53.988197999999997	53.968167000000001	0103000020E610000001000000050000006BB75D68AED74840810871E5ECFB4A406BB75D68AED748407EFCA5457DFE4A40503A9160AADB48407EFCA5457DFE4A40503A9160AADB4840810871E5ECFB4A406BB75D68AED74840810871E5ECFB4A40
3672	Моисеевка	7	74	411	49.736465000000003	49.770997000000001	54.059283000000001	54.034166999999997	0103000020E6100000010000000500000007D3307C44DE48401CCD91955F044B4007D3307C44DE4840B91AD99596074B4035289A07B0E24840B91AD99596074B4035289A07B0E248401CCD91955F044B4007D3307C44DE48401CCD91955F044B40
2373	Лесной	7	74	411	49.158265	49.17615	54.268245999999998	54.253335999999997	0103000020E61000000100000005000000FC8C0B0742944840217365506D204B40FC8C0B074294484033A48AE255224B405F984C158C96484033A48AE255224B405F984C158C964840217365506D204B40FC8C0B0742944840217365506D204B40
4752	Лесная Хмелевка	7	74	411	49.640669000000003	49.694333999999998	54.542048999999999	54.512931000000002	0103000020E61000000100000005000000D047197101D24840630D17B9A7414B40D047197101D248402DEA93DC61454B401C40BFEFDFD848402DEA93DC61454B401C40BFEFDFD84840630D17B9A7414B40D047197101D24840630D17B9A7414B40
4691	Лесная Васильевка	7	74	411	49.648763000000002	49.675595999999999	54.468929000000003	54.461900999999997	0103000020E610000001000000050000006CED7DAA0AD34840AE7E6C921F3B4B406CED7DAA0AD34840B0928FDD053C4B407AA702EE79D64840B0928FDD053C4B407AA702EE79D64840AE7E6C921F3B4B406CED7DAA0AD34840AE7E6C921F3B4B40
2759	Лебяжье	7	74	411	49.589770000000001	49.628138	54.138041999999999	54.107854000000003	0103000020E61000000100000005000000BA1457957DCB4840145FED28CE0D4B40BA1457957DCB4840BABC395CAB114B40FBAF73D366D04840BABC395CAB114B40FBAF73D366D04840145FED28CE0D4B40BA1457957DCB4840145FED28CE0D4B40
3181	Куликовка	7	74	411	49.458652000000001	49.476618999999999	54.036388000000002	54.023277	0103000020E610000001000000050000005C1FD61BB5BA4840DFDFA0BDFA024B405C1FD61BB5BA4840C2FBAA5CA8044B407CD3F4D901BD4840C2FBAA5CA8044B407CD3F4D901BD4840DFDFA0BDFA024B405C1FD61BB5BA4840DFDFA0BDFA024B40
3501	Ковыльный	7	74	411	49.913784	49.940634000000003	53.997674000000004	53.979235000000003	0103000020E61000000100000005000000D5CDC5DFF6F448409E0C8E9257FD4A40D5CDC5DFF6F44840E60819C8B3FF4A40BAC0E5B166F84840E60819C8B3FF4A40BAC0E5B166F848409E0C8E9257FD4A40D5CDC5DFF6F448409E0C8E9257FD4A40
3353	Кипрей	7	74	411	49.143037999999997	49.174551000000001	54.161302999999997	54.143358999999997	0103000020E61000000100000005000000E90AB6114F9248402B4B749659124B40E90AB6114F92484093DFA293A5144B40F73DEAAF5796484093DFA293A5144B40F73DEAAF579648402B4B749659124B40E90AB6114F9248402B4B749659124B40
3295	Ерыклинск	7	74	411	49.284863999999999	49.328028000000003	54.131062999999997	54.10201	0103000020E6100000010000000500000064E76D6C76A44840B7EEE6A90E0D4B4064E76D6C76A448409A5B21ACC6104B400E164ED2FCA948409A5B21ACC6104B400E164ED2FCA94840B7EEE6A90E0D4B4064E76D6C76A44840B7EEE6A90E0D4B40
4140	Дубравка	7	74	411	49.436221000000003	49.453245000000003	53.870113000000003	53.861485000000002	0103000020E610000001000000050000000A6AF816D6B748404E7FF62345EE4A400A6AF816D6B748408869DFDC5FEF4A40AB09A2EE03BA48408869DFDC5FEF4A40AB09A2EE03BA48404E7FF62345EE4A400A6AF816D6B748404E7FF62345EE4A40
3912	Дивный	7	74	411	49.471345999999997	49.506433999999999	53.951155999999997	53.931573	0103000020E61000000100000005000000DA8CD31055BC4840166BB8C83DF74A40DA8CD31055BC484074B2D47ABFF94A408ECA4DD4D2C0484074B2D47ABFF94A408ECA4DD4D2C04840166BB8C83DF74A40DA8CD31055BC4840166BB8C83DF74A40
4041	Вишенка	7	74	411	49.540210000000002	49.560305999999997	53.916651999999999	53.906776999999998	0103000020E61000000100000005000000707CED9925C54840EBE1CB4411F44A40707CED9925C5484010E84CDA54F54A4054E0641BB8C7484010E84CDA54F54A4054E0641BB8C74840EBE1CB4411F44A40707CED9925C54840EBE1CB4411F44A40
3461	Видный	7	74	411	49.843966999999999	49.869909999999997	53.960486000000003	53.944648999999998	0103000020E610000001000000050000009DF3531C07EC48407C992842EAF84A409DF3531C07EC484008228B34F1FA4A404F3BFC3559EF484008228B34F1FA4A404F3BFC3559EF48407C992842EAF84A409DF3531C07EC48407C992842EAF84A40
2590	Верхний Мелекесс	7	74	411	49.772379999999998	49.801270000000002	54.117776999999997	54.093721000000002	0103000020E61000000100000005000000D00A0C59DDE2484066F9BA0CFF0B4B40D00A0C59DDE24840499C1551130F4B400AA2EE0390E64840499C1551130F4B400AA2EE0390E6484066F9BA0CFF0B4B40D00A0C59DDE2484066F9BA0CFF0B4B40
4385	Бригадировка	7	74	411	49.744047000000002	49.804558	54.314380999999997	54.296014999999997	0103000020E61000000100000005000000EDD79DEE3CDF48400E10CCD1E3254B40EDD79DEE3CDF4840ECBDF8A23D284B401ADEACC1FBE64840ECBDF8A23D284B401ADEACC1FBE648400E10CCD1E3254B40EDD79DEE3CDF48400E10CCD1E3254B40
4356	Боровка	7	74	411	49.928229000000002	49.962473000000003	54.498173000000001	54.486046000000002	0103000020E6100000010000000500000072193735D0F64840022D5DC1363E4B4072193735D0F6484007600322C43F4B403A24B55032FB484007600322C43F4B403A24B55032FB4840022D5DC1363E4B4072193735D0F64840022D5DC1363E4B40
4029	Бирля	7	74	411	49.2288	49.257537999999997	53.928953999999997	53.910674999999998	0103000020E6100000010000000500000093A98251499D4840742497FF90F44A4093A98251499D484083BEF4F6E7F64A4016BD5301F7A0484083BEF4F6E7F64A4016BD5301F7A04840742497FF90F44A4093A98251499D4840742497FF90F44A40
4303	Аппаково	7	74	411	49.903193000000002	49.927286000000002	54.533357000000002	54.518816000000001	0103000020E61000000100000005000000F27C06D49BF348401E520C9068424B40F27C06D49BF34840DD0BCC0A45444B40F304C24EB1F64840DD0BCC0A45444B40F304C24EB1F648401E520C9068424B40F27C06D49BF348401E520C9068424B40
2828	Аллагулово	7	74	411	49.553882999999999	49.587983000000001	54.059103	54.040142000000003	0103000020E61000000100000005000000BA675DA3E5C648401899805F23054B40BA675DA3E5C64840390CE6AF90074B404FCDE50643CB4840390CE6AF90074B404FCDE50643CB48401899805F23054B40BA675DA3E5C648401899805F23054B40
3952	Александровка	7	74	411	49.381962999999999	49.415722000000002	53.936725000000003	53.910404999999997	0103000020E610000001000000050000001AA4E029E4B04840B48EAA2688F44A401AA4E029E4B048403D2CD49AE6F74A40261DE56036B548403D2CD49AE6F74A40261DE56036B54840B48EAA2688F44A401AA4E029E4B04840B48EAA2688F44A40
55819	п. Новоанненковский	7	74	50	47.253495000000001	48.055098000000001	54.567357000000001	53.764392999999998	0103000020E610000001000000050000008A592F8672A047404A253CA1D7E14A408A592F8672A047400E1478279F484B409A0986730D0748400E1478279F484B409A0986730D0748404A253CA1D7E14A408A592F8672A047404A253CA1D7E14A40
1838	Чуфарово	7	74	50	47.487847000000002	47.513710000000003	54.460796999999999	54.444282000000001	0103000020E61000000100000005000000D2393FC571BE4740CA198A3BDE384B40D2393FC571BE4740268C6665FB3A4B4068D0D03FC1C14740268C6665FB3A4B4068D0D03FC1C14740CA198A3BDE384B40D2393FC571BE4740CA198A3BDE384B40
1769	Чирикеево	7	74	50	47.503622	47.532026999999999	54.530839	54.515743000000001	0103000020E61000000100000005000000E7C589AF76C047400A12DBDD03424B40E7C589AF76C047407E384888F2434B4064CBF27519C447407E384888F2434B4064CBF27519C447400A12DBDD03424B40E7C589AF76C047400A12DBDD03424B40
2071	Уржумское	7	74	50	47.817224000000003	47.848826000000003	54.293025	54.286791999999998	0103000020E61000000100000005000000CFC0C8CB9AE847409160AA99B5244B40CFC0C8CB9AE8474088F4DBD781254B404CFF9254A6EC474088F4DBD781254B404CFF9254A6EC47409160AA99B5244B40CFC0C8CB9AE847409160AA99B5244B40
1878	Тагай	7	74	50	47.596238	47.651834999999998	54.315043000000003	54.288290000000003	0103000020E61000000100000005000000F450DB8651CC4740C6E1CCAFE6244B40F450DB8651CC4740B8EA3A5453284B40AFB14B546FD34740B8EA3A5453284B40AFB14B546FD34740C6E1CCAFE6244B40F450DB8651CC4740C6E1CCAFE6244B40
1000	Сущевка	7	74	50	47.400855	47.415236999999998	54.162052000000003	54.154148999999997	0103000020E6100000010000000500000013B875374FB3474005DB8827BB134B4013B875374FB347402E20B41EBE144B40698B6B7C26B547402E20B41EBE144B40698B6B7C26B5474005DB8827BB134B4013B875374FB3474005DB8827BB134B40
1461	Сухаревка	7	74	50	47.768363999999998	47.786366999999998	53.968632999999997	53.961433999999997	0103000020E610000001000000050000003DB665C059E2474098A1F14410FB4A403DB665C059E24740C669882AFCFB4A40AAD381ACA7E44740C669882AFCFB4A40AAD381ACA7E4474098A1F14410FB4A403DB665C059E2474098A1F14410FB4A40
1581	Степное Матюнино	7	74	50	47.804009999999998	47.859166000000002	53.969082999999998	53.960036000000002	0103000020E6100000010000000500000017D4B7CCE9E64740C87DAB75E2FA4A4017D4B7CCE9E64740060E68E90AFC4A40E6EAC726F9ED4740060E68E90AFC4A40E6EAC726F9ED4740C87DAB75E2FA4A4017D4B7CCE9E64740C87DAB75E2FA4A40
1681	Старые Маклауши	7	74	50	47.439436999999998	47.472127	54.465277	54.449654000000002	0103000020E6100000010000000500000080D3BB783FB84740FF4124438E394B4080D3BB783FB847405E4A5D328E3B4B40804754A86EBC47405E4A5D328E3B4B40804754A86EBC4740FF4124438E394B4080D3BB783FB84740FF4124438E394B40
413	Сосновка	7	74	50	47.634425999999998	47.660926000000003	53.997107	53.982723999999997	0103000020E61000000100000005000000B5DD04DF34D14740457F68E6C9FD4A40B5DD04DF34D147406CCEC133A1FF4A40BE89213999D447406CCEC133A1FF4A40BE89213999D44740457F68E6C9FD4A40B5DD04DF34D14740457F68E6C9FD4A40
2136	Сиуч	7	74	50	47.763199	47.788397000000003	54.342880000000001	54.329279	0103000020E6100000010000000500000082AB3C81B0E147403A2174D0252A4B4082AB3C81B0E14740EB39E97DE32B4B40DCA16131EAE44740EB39E97DE32B4B40DCA16131EAE447403A2174D0252A4B4082AB3C81B0E147403A2174D0252A4B40
55802	Родниковые Пруды	7	74	50	47.520671999999998	47.539760999999999	53.888542000000001	53.870038000000001	0103000020E61000000100000005000000B1F84D61A5C247407D23BA675DEF4A40B1F84D61A5C24740AC8F87BEBBF14A40005471E316C54740AC8F87BEBBF14A40005471E316C547407D23BA675DEF4A40B1F84D61A5C247407D23BA675DEF4A40
1569	Репьевка-Космынка	7	74	50	47.874518000000002	47.896751999999999	54.080285000000003	54.069671999999997	0103000020E61000000100000005000000B5E1B034F0EF474034B91803EB084B40B5E1B034F0EF474000AE64C7460A4B40B14F00C5C8F2474000AE64C7460A4B40B14F00C5C8F2474034B91803EB084B40B5E1B034F0EF474034B91803EB084B40
853	Репьевка Колхозная	7	74	50	47.430363999999997	47.472234999999998	54.066364	54.036921999999997	0103000020E6100000010000000500000018B0E42A16B747405F402FDCB9044B4018B0E42A16B74740DDD0949D7E084B4066834C3272BC4740DDD0949D7E084B4066834C3272BC47405F402FDCB9044B4018B0E42A16B747405F402FDCB9044B40
297	Поповка	7	74	50	47.583365000000001	47.627509000000003	53.937323999999997	53.926392999999997	0103000020E61000000100000005000000C6504EB4ABCA4740251FBB0B94F64A40C6504EB4ABCA4740C1E09A3BFAF74A400C79043752D04740C1E09A3BFAF74A400C79043752D04740251FBB0B94F64A40C6504EB4ABCA4740251FBB0B94F64A40
1336	Полбино	7	74	50	47.898575000000001	47.925758000000002	54.138922999999998	54.120373000000001	0103000020E6100000010000000500000069006F8104F347402429E961680F4B4069006F8104F34740C3D4963AC8114B405401F73C7FF64740C3D4963AC8114B405401F73C7FF647402429E961680F4B4069006F8104F347402429E961680F4B40
2029	Подлесное	7	74	50	47.579970000000003	47.614384000000001	54.323503000000002	54.308083000000003	0103000020E61000000100000005000000A054FB743CCA47400FBA84436F274B40A054FB743CCA47403694DA8B68294B40C4978922A4CE47403694DA8B68294B40C4978922A4CE47400FBA84436F274B40A054FB743CCA47400FBA84436F274B40
1722	Новые Маклауши	7	74	50	47.460081000000002	47.490029999999997	54.515574999999998	54.492038999999998	0103000020E61000000100000005000000684128EFE3BA4740A3AD4A22FB3E4B40684128EFE3BA47404ED1915CFE414B408907944DB9BE47404ED1915CFE414B408907944DB9BE4740A3AD4A22FB3E4B40684128EFE3BA4740A3AD4A22FB3E4B40
479	Майна	7	74	50	47.578308	47.644334000000001	54.128445999999997	54.098621000000001	0103000020E61000000100000005000000F1811DFF05CA474073D9E89C9F0C4B40F1811DFF05CA4740A8A624EB70104B40B6D9588979D24740A8A624EB70104B40B6D9588979D2474073D9E89C9F0C4B40F1811DFF05CA474073D9E89C9F0C4B40
1968	Копышовка	7	74	50	47.639437999999998	47.668615000000003	54.291249000000001	54.274065999999998	0103000020E61000000100000005000000EAE8B81AD9D1474007793D9814234B40EAE8B81AD9D1474011FFB0A547254B40BA4E232D95D5474011FFB0A547254B40BA4E232D95D5474007793D9814234B40EAE8B81AD9D1474007793D9814234B40
1445	Карлинское	7	74	50	47.756667999999998	47.787427000000001	54.007998000000001	53.986054000000003	0103000020E6100000010000000500000001F73C7FDAE04740850B790437FE4A4001F73C7FDAE047407A37161406014B40637E6E68CAE447407A37161406014B40637E6E68CAE44740850B790437FE4A4001F73C7FDAE04740850B790437FE4A40
58	Игнатовка	7	74	50	47.627876999999998	47.68121	53.961291000000003	53.938547999999997	0103000020E610000001000000050000008E7406465ED04740F4DC425722F84A408E7406465ED0474036785F950BFB4A40A5DAA7E331D7474036785F950BFB4A40A5DAA7E331D74740F4DC425722F84A408E7406465ED04740F4DC425722F84A40
221	Загоскино	7	74	50	47.635224999999998	47.667439000000002	53.888244999999998	53.866858000000001	0103000020E61000000100000005000000014D840D4FD147405323F433F5EE4A40014D840D4FD14740F2EA1C03B2F14A40988922A46ED54740F2EA1C03B2F14A40988922A46ED547405323F433F5EE4A40014D840D4FD147405323F433F5EE4A40
55817	Гимова	7	74	50	47.905582000000003	47.932226	54.019955000000003	54.003473999999997	0103000020E6100000010000000500000053EC681CEAF34740723106D671004B4053EC681CEAF347402332ACE28D024B408E3D7B2E53F747402332ACE28D024B408E3D7B2E53F74740723106D671004B4053EC681CEAF34740723106D671004B40
787	Вязовка	7	74	50	47.724113000000003	47.742978000000001	54.058526999999998	54.041459000000003	0103000020E61000000100000005000000E2CD1ABCAFDC4740FC8F4C874E054B40E2CD1ABCAFDC47406C770FD07D074B40E1D231E719DF47406C770FD07D074B40E1D231E719DF4740FC8F4C874E054B40E2CD1ABCAFDC4740FC8F4C874E054B40
1111	Выры	7	74	50	47.780589999999997	47.887382000000002	54.200991000000002	54.168472000000001	0103000020E61000000100000005000000D5CA845FEAE347405725917D90154B40D5CA845FEAE347402AE5B512BA194B409087BEBB95F147402AE5B512BA194B409087BEBB95F147405725917D90154B40D5CA845FEAE347405725917D90154B40
732	Большое Жеребятниково	7	74	50	47.518416999999999	47.538935000000002	54.170189999999998	54.159773999999999	0103000020E610000001000000050000006058FE7C5BC247402460747973144B406058FE7C5BC24740990D32C9C8154B40BBD573D2FBC44740990D32C9C8154B40BBD573D2FBC447402460747973144B406058FE7C5BC247402460747973144B40
30451	Березовка	7	74	50	47.612695000000002	47.636456000000003	54.065392000000003	54.037714999999999	0103000020E610000001000000050000001CB62DCA6CCE4740C9C859D8D3044B401CB62DCA6CCE4740C4B5DAC35E084B40E7ABE46377D14740C4B5DAC35E084B40E7ABE46377D14740C9C859D8D3044B401CB62DCA6CCE4740C9C859D8D3044B40
55803	Белое Озеро	7	74	50	47.567061000000002	47.603828999999998	53.862085	53.837294999999997	0103000020E6100000010000000500000025EB707495C847405A0D897B2CEB4A4025EB707495C84740A3AF20CD58EE4A402DB0C7444ACD4740A3AF20CD58EE4A402DB0C7444ACD47405A0D897B2CEB4A4025EB707495C847405A0D897B2CEB4A40
55813	Безречный	7	74	50	47.253495000000001	48.055098000000001	54.567357000000001	53.764392999999998	0103000020E610000001000000050000008A592F8672A047404A253CA1D7E14A408A592F8672A047400E1478279F484B409A0986730D0748400E1478279F484B409A0986730D0748404A253CA1D7E14A408A592F8672A047404A253CA1D7E14A40
55823	Безлесный	7	74	50	47.253495000000001	48.055098000000001	54.567357000000001	53.764392999999998	0103000020E610000001000000050000008A592F8672A047404A253CA1D7E14A408A592F8672A047400E1478279F484B409A0986730D0748400E1478279F484B409A0986730D0748404A253CA1D7E14A408A592F8672A047404A253CA1D7E14A40
55784	Анненково	7	74	50	47.381703000000002	47.417769999999997	54.123412999999999	54.100631999999997	0103000020E610000001000000050000007EE4D6A4DBB047402D776682E10C4B407EE4D6A4DBB047405C7347FFCB0F4B40FD9FC37C79B547405C7347FFCB0F4B40FD9FC37C79B547402D776682E10C4B407EE4D6A4DBB047402D776682E10C4B40
26593	Абрамовка	7	74	50	47.673456999999999	47.706209999999999	54.206789999999998	54.193658999999997	0103000020E610000001000000050000009221C7D633D64740BCC96FD1C9184B409221C7D633D64740E6913F18781A4B40D80DDB1665DA4740E6913F18781A4B40D80DDB1665DA4740BCC96FD1C9184B409221C7D633D64740BCC96FD1C9184B40
31414	Чириково	7	74	1910	47.821392000000003	47.854486000000001	53.760938000000003	53.744301	0103000020E610000001000000050000001899805F23E94740A7B0524145DF4A401899805F23E947404F24986A66E14A40E77118CC5FED47404F24986A66E14A40E77118CC5FED4740A7B0524145DF4A401899805F23E94740A7B0524145DF4A40
31349	Чертановка	7	74	1910	47.804772999999997	47.848153000000003	53.831614999999999	53.817248999999997	0103000020E6100000010000000500000016DA39CD02E7474027D87F9D9BE84A4016DA39CD02E7474078EE3D5C72EA4A408D800A4790EC474078EE3D5C72EA4A408D800A4790EC474027D87F9D9BE84A4016DA39CD02E7474027D87F9D9BE84A40
31302	Хвостиха	7	74	1910	47.888209000000003	47.912148999999999	53.797767999999998	53.786043999999997	0103000020E61000000100000005000000A6811FD5B0F14740C79BFC169DE44A40A6811FD5B0F14740CDE506431DE64A40200A664CC1F44740CDE506431DE64A40200A664CC1F44740C79BFC169DE44A40A6811FD5B0F14740C79BFC169DE44A40
31610	Уваровка	7	74	1910	47.760216999999997	47.783869000000003	53.671849000000002	53.658405000000002	0103000020E610000001000000050000007E6E68CA4EE14740EE42739D46D44A407E6E68CA4EE14740D76CE525FFD54A4093ACC3D155E44740D76CE525FFD54A4093ACC3D155E44740EE42739D46D44A407E6E68CA4EE14740EE42739D46D44A40
32279	Томылово	7	74	1910	47.854728000000001	47.887417999999997	53.490836000000002	53.466473999999998	0103000020E61000000100000005000000DD7C23BA67ED47409737876BB5BB4A40DD7C23BA67ED474088D9CBB6D3BE4A40DCF0BBE996F1474088D9CBB6D3BE4A40DCF0BBE996F147409737876BB5BB4A40DD7C23BA67ED47409737876BB5BB4A40
32314	Студенец	7	74	1910	47.950076000000003	47.988244999999999	53.418852999999999	53.400543999999996	0103000020E61000000100000005000000755B22179CF94740F44D9A0645B34A40755B22179CF947406E6AA0F99CB54A40BFB7E9CF7EFE47406E6AA0F99CB54A40BFB7E9CF7EFE4740F44D9A0645B34A40755B22179CF94740F44D9A0645B34A40
31104	Стоговка	7	74	1910	48.002401999999996	48.024151000000003	53.982989000000003	53.962128	0103000020E61000000100000005000000F5B86FB54E0048406F48A30227FB4A40F5B86FB54E004840F4A96395D2FD4A403695456117034840F4A96395D2FD4A4036954561170348406F48A30227FB4A40F5B86FB54E0048406F48A30227FB4A40
31136	Спешневка	7	74	1910	47.952061	47.968283999999997	53.895732000000002	53.875836	0103000020E6100000010000000500000006668522DDF947406954E0641BF04A4006668522DDF9474087FD9E58A7F24A40BA9EE8BAF0FB474087FD9E58A7F24A40BA9EE8BAF0FB47406954E0641BF04A4006668522DDF947406954E0641BF04A40
31458	Смышляевка	7	74	1910	47.716621000000004	47.753236999999999	53.763599999999997	53.744321999999997	0103000020E610000001000000050000003C50A73CBADB4740BED87BF145DF4A403C50A73CBADB4740E09C11A5BDE14A408E91EC116AE04740E09C11A5BDE14A408E91EC116AE04740BED87BF145DF4A403C50A73CBADB4740BED87BF145DF4A40
32089	Приволье	7	74	1910	47.841468999999996	47.869199999999999	53.580388999999997	53.568519999999999	0103000020E6100000010000000500000085CC9541B5EB47409B8F6B43C5C84A4085CC9541B5EB4740A4FACE2F4ACA4A4073D712F241EF4740A4FACE2F4ACA4A4073D712F241EF47409B8F6B43C5C84A4085CC9541B5EB47409B8F6B43C5C84A40
31243	Порецкое	7	74	1910	47.890284000000001	47.912723999999997	53.823993999999999	53.811560999999998	0103000020E6100000010000000500000077137CD3F4F14740C2DA183BE1E74A4077137CD3F4F14740D40CA9A278E94A401C23D923D4F44740D40CA9A278E94A401C23D923D4F44740C2DA183BE1E74A4077137CD3F4F14740C2DA183BE1E74A40
31195	Первомайский	7	74	1910	47.851486000000001	47.881560999999998	53.899360999999999	53.886583999999999	0103000020E610000001000000050000003D80457EFDEC47401494A2957BF14A403D80457EFDEC47402026E1421EF34A40EB36A8FDD6F047402026E1421EF34A40EB36A8FDD6F047401494A2957BF14A403D80457EFDEC47401494A2957BF14A40
31840	Никольское	7	74	1910	47.782620999999999	47.808734999999999	53.374496999999998	53.354180999999997	0103000020E61000000100000005000000D714C8EC2CE44740AAEE91CD55AD4A40D714C8EC2CE447409DB98784EFAF4A40B610E4A084E747409DB98784EFAF4A40B610E4A084E74740AAEE91CD55AD4A40D714C8EC2CE44740AAEE91CD55AD4A40
55785	Налейка	7	74	1910	47.458742000000001	47.507008999999996	53.567867	53.550280999999998	0103000020E610000001000000050000009CA6CF0EB8BA47401A4E999B6FC64A409CA6CF0EB8BA474023BDA8DDAFC84A408AE3C0ABE5C0474023BDA8DDAFC84A408AE3C0ABE5C047401A4E999B6FC64A409CA6CF0EB8BA47401A4E999B6FC64A40
32144	Малая Борла	7	74	1910	48.003633000000001	48.032944999999998	53.540596999999998	53.526580000000003	0103000020E61000000100000005000000DB17D00B77004840255D33F966C34A40DB17D00B7700484069A8514832C54A408AC8B08A3704484069A8514832C54A408AC8B08A37044840255D33F966C34A40DB17D00B77004840255D33F966C34A40
31778	Лесное Матюнино	7	74	1910	47.405517000000003	47.444656000000002	53.469219000000002	53.430405	0103000020E610000001000000050000006C7C26FBE7B347407784D38217B74A406C7C26FBE7B34740B7D4415E0FBC4A402FFCE07CEAB84740B7D4415E0FBC4A402FFCE07CEAB847407784D38217B74A406C7C26FBE7B347407784D38217B74A40
31623	Кузоватово	7	74	1910	47.600496	47.638603000000003	53.570995000000003	53.538150999999999	0103000020E610000001000000050000007DB08C0DDDCC4740A4A7C821E2C44A407DB08C0DDDCC4740FB96395D16C94A4052103CBEBDD14740FB96395D16C94A4052103CBEBDD14740A4A7C821E2C44A407DB08C0DDDCC4740A4A7C821E2C44A40
32357	Кузоватово	7	74	1910	47.656317999999999	47.705159000000002	53.557293999999999	53.533163999999999	0103000020E6100000010000000500000058E36C3A02D44740C8B3CBB73EC44A4058E36C3A02D44740E620E86855C74A4073BD6DA642DA4740E620E86855C74A4073BD6DA642DA4740C8B3CBB73EC44A4058E36C3A02D44740C8B3CBB73EC44A40
31838	Красная Балтия	7	74	1910	47.551161	47.568606000000003	53.429160000000003	53.416218000000001	0103000020E6100000010000000500000053EA92718CC64740D600A5A146B54A4053EA92718CC647402D6002B7EEB64A409A27D714C8C847402D6002B7EEB64A409A27D714C8C84740D600A5A146B54A4053EA92718CC64740D600A5A146B54A40
31554	Коромысловка	7	74	1910	47.687058	47.719990000000003	53.616132999999998	53.597113	0103000020E61000000100000005000000433A3C84F1D747401B82E3326ECC4A40433A3C84F1D74740417E3672DDCE4A4039B9DFA128DC4740417E3672DDCE4A4039B9DFA128DC47401B82E3326ECC4A40433A3C84F1D747401B82E3326ECC4A40
32008	Кивать	7	74	1910	47.663530999999999	47.699283999999999	53.478586999999997	53.451597	0103000020E61000000100000005000000EB707495EED4474061FC34EECDB94A40EB707495EED4474037A5BC5642BD4A40DB4E5B2382D9474037A5BC5642BD4A40DB4E5B2382D9474061FC34EECDB94A40EB707495EED4474061FC34EECDB94A40
31964	Еделево	7	74	1910	47.726385999999998	47.775092999999998	53.417361	53.396344999999997	0103000020E61000000100000005000000D9226937FADC47407077D66EBBB24A40D9226937FADC47401CD0D2156CB54A40E42D573F36E347401CD0D2156CB54A40E42D573F36E347407077D66EBBB24A40D9226937FADC47407077D66EBBB24A40
32065	Волынщина	7	74	1910	47.790697000000002	47.817537999999999	53.573337000000002	53.555523000000001	0103000020E61000000100000005000000CD052E8F35E547408196AE601BC74A40CD052E8F35E547401B4B581B63C94A405E9ECE15A5E847401B4B581B63C94A405E9ECE15A5E847408196AE601BC74A40CD052E8F35E547408196AE601BC74A40
31510	Бестужевка	7	74	1910	47.723061999999999	47.754269999999998	53.727049000000001	53.719558999999997	0103000020E610000001000000050000007C7DAD4B8DDC47406F4562821ADC4A407C7DAD4B8DDC474075CB0EF10FDD4A404D2D5BEB8BE0474075CB0EF10FDD4A404D2D5BEB8BE047406F4562821ADC4A407C7DAD4B8DDC47406F4562821ADC4A40
32513	Безводовка	7	74	1910	47.921886000000001	47.974043000000002	53.540714999999999	53.491585999999998	0103000020E61000000100000005000000F451465C00F64740F295404AECBE4A40F451465C00F6474073BA2C2636C54A40E9F2E670ADFC474073BA2C2636C54A40E9F2E670ADFC4740F295404AECBE4A40F451465C00F64740F295404AECBE4A40
31693	Баевка	7	74	1910	47.587983000000001	47.632350000000002	53.604829000000002	53.588979000000002	0103000020E610000001000000050000004FCDE50643CB4740F183F3A963CB4A404FCDE50643CB4740115663096BCD4A4014D044D8F0D04740115663096BCD4A4014D044D8F0D04740F183F3A963CB4A404FCDE50643CB4740F183F3A963CB4A40
55798	пос. Чулочно-носочной фабрики	7	74	1869	46.430692000000001	47.509695000000001	54.445	54.005898000000002	0103000020E610000001000000050000000D535BEA20374740508E0244C1004B400D535BEA20374740295C8FC2F5384B40A5F78DAF3DC14740295C8FC2F5384B40A5F78DAF3DC14740508E0244C1004B400D535BEA20374740508E0244C1004B40
29881	Языково	7	74	1869	47.363726999999997	47.412253999999997	54.306784999999998	54.281461999999998	0103000020E610000001000000050000000AD6389B8EAE47408B8862F206244B400AD6389B8EAE4740A1F31ABB44274B4095D233BDC4B44740A1F31ABB44274B4095D233BDC4B447408B8862F206244B400AD6389B8EAE47408B8862F206244B40
30281	Усть-Урень	7	74	1869	47.049559000000002	47.101967000000002	54.382792000000002	54.358932000000003	0103000020E610000001000000050000007A1C06F35786474073BED87BF12D4B407A1C06F357864740D1950854FF304B40B82231410D8D4740D1950854FF304B40B82231410D8D474073BED87BF12D4B407A1C06F35786474073BED87BF12D4B40
30921	Урено-Карлинское	7	74	1869	47.207546000000001	47.274641000000003	54.314616999999998	54.255403000000001	0103000020E61000000100000005000000333509DE909A47407026A60BB1204B40333509DE909A474000E2AE5E45284B400492B06F27A3474000E2AE5E45284B400492B06F27A347407026A60BB1204B40333509DE909A47407026A60BB1204B40
30867	Уразовка	7	74	1869	46.668664999999997	46.689416000000001	54.130012999999998	54.119048999999997	0103000020E610000001000000050000006B7D91D0965547408DCF64FF3C0F4B406B7D91D09655474005871744A4104B4069AB92C83E58474005871744A4104B4069AB92C83E5847408DCF64FF3C0F4B406B7D91D0965547408DCF64FF3C0F4B40
31062	Теньковка	7	74	1869	47.291611000000003	47.326959000000002	54.359861000000002	54.336328999999999	0103000020E61000000100000005000000B2135E8253A5474023D923D40C2B4B40B2135E8253A547408D0DDDEC0F2E4B400211E2CAD9A947408D0DDDEC0F2E4B400211E2CAD9A9474023D923D40C2B4B40B2135E8253A5474023D923D40C2B4B40
55800	Татарскии Горенки	7	74	1869	46.69415	46.721324000000003	54.267387999999997	54.245635	0103000020E610000001000000050000005B423EE8D958474061E0B9F7701F4B405B423EE8D9584740E2AB1DC539224B40F3E84658545C4740E2AB1DC539224B40F3E84658545C474061E0B9F7701F4B405B423EE8D958474061E0B9F7701F4B40
30575	Татарская Голышевка	7	74	1869	46.650564000000003	46.672688999999998	54.282729000000003	54.271779000000002	0103000020E610000001000000050000003CFA5FAE45534740AB5E7EA7C9224B403CFA5FAE45534740BE50C07630244B4081B053AC1A564740BE50C07630244B4081B053AC1A564740AB5E7EA7C9224B403CFA5FAE45534740AB5E7EA7C9224B40
29722	Таволжанка	7	74	1869	47.002783999999998	47.046945000000001	54.178764999999999	54.157729000000003	0103000020E61000000100000005000000DD79E2395B804740BE50C07630144B40DD79E2395B804740B05582C5E1164B40F9DA334B02864740B05582C5E1164B40F9DA334B02864740BE50C07630144B40DD79E2395B804740BE50C07630144B40
30761	Сухой Карсун	7	74	1869	46.613778000000003	46.647195000000004	54.191673999999999	54.174258999999999	0103000020E610000001000000050000008D800A47904E47404F04711E4E164B408D800A47904E47402BBF0CC688184B403F912749D75247402BBF0CC688184B403F912749D75247404F04711E4E164B408D800A47904E47404F04711E4E164B40
30816	Сосновка	7	74	1869	46.617542	46.663418999999998	54.117480999999998	54.100574000000002	0103000020E6100000010000000500000006F4C29D0B4F4740F969DC9BDF0C4B4006F4C29D0B4F474060730E9E090F4B40C345EEE9EA54474060730E9E090F4B40C345EEE9EA544740F969DC9BDF0C4B4006F4C29D0B4F4740F969DC9BDF0C4B40
30020	Прислониха	7	74	1869	47.433166999999997	47.476762000000001	54.276131999999997	54.262151000000003	0103000020E610000001000000050000006C5A290472B747408ECEF9298E214B406C5A290472B7474085B01A4B58234B40DFFC868906BD474085B01A4B58234B40DFFC868906BD47408ECEF9298E214B406C5A290472B747408ECEF9298E214B40
30200	Потьма	7	74	1869	46.918810000000001	46.971747000000001	54.334670000000003	54.322495000000004	0103000020E610000001000000050000006F9EEA909B754740D00F238447294B406F9EEA909B754740E6797077D62A4B40397EA834627C4740E6797077D62A4B40397EA834627C4740D00F238447294B406F9EEA909B754740D00F238447294B40
55809	Пески	7	74	1869	46.430692000000001	47.509695000000001	54.445	54.005898000000002	0103000020E610000001000000050000000D535BEA20374740508E0244C1004B400D535BEA20374740295C8FC2F5384B40A5F78DAF3DC14740295C8FC2F5384B40A5F78DAF3DC14740508E0244C1004B400D535BEA20374740508E0244C1004B40
55816	Новое Погорелово	7	74	1869	46.768827000000002	46.811729999999997	54.166648000000002	54.137366999999998	0103000020E6100000010000000500000012A452EC686247405A46EA3D95114B4012A452EC68624740CFF8BEB854154B404E97C5C4E6674740CFF8BEB854154B404E97C5C4E66747405A46EA3D95114B4012A452EC686247405A46EA3D95114B40
30686	Нагаево	7	74	1869	46.707005000000002	46.748497999999998	54.190499000000003	54.174258999999999	0103000020E61000000100000005000000E38DCC237F5A47404F04711E4E164B40E38DCC237F5A4740DA756F4562184B408A8F4FC8CE5F4740DA756F4562184B408A8F4FC8CE5F47404F04711E4E164B40E38DCC237F5A47404F04711E4E164B40
29825	Малое Станичное	7	74	1869	47.001212000000002	47.023516999999998	54.322142999999997	54.289057	0103000020E610000001000000050000006F2EFEB62780474006D7DCD1FF244B406F2EFEB62780474052D158FB3B294B4034F3E49A0283474052D158FB3B294B4034F3E49A0283474006D7DCD1FF244B406F2EFEB62780474006D7DCD1FF244B40
55811	Краснополка	7	74	1869	46.907428000000003	46.946837000000002	54.172925999999997	54.160871	0103000020E61000000100000005000000C3BCC79926744740FAEFC16B97144B40C3BCC7992674474065506D7022164B4046D26EF43179474065506D7022164B4046D26EF431794740FAEFC16B97144B40C3BCC79926744740FAEFC16B97144B40
30506	Котяково	7	74	1869	46.688104000000003	46.717281999999997	54.301352999999999	54.287706999999997	0103000020E61000000100000005000000971FB8CA1358474046EA3D95D3244B40971FB8CA1358474097C62FBC92264B40360186E5CF5B474097C62FBC92264B40360186E5CF5B474046EA3D95D3244B40971FB8CA1358474046EA3D95D3244B40
30116	Комаровка	7	74	1869	46.862422000000002	46.898166000000003	54.286687000000001	54.273099000000002	0103000020E61000000100000005000000EBAC16D8636E474000C974E8F4224B40EBAC16D8636E47401C98DC28B2244B4088307E1AF77247401C98DC28B2244B4088307E1AF772474000C974E8F4224B40EBAC16D8636E474000C974E8F4224B40
29479	Карсун	7	74	1869	46.960042000000001	47.019734999999997	54.221995	54.161867000000001	0103000020E61000000100000005000000AA6400A8E27A47409CA6CF0EB8144B40AA6400A8E27A4740117008556A1C4B4014CB2DAD86824740117008556A1C4B4014CB2DAD868247409CA6CF0EB8144B40AA6400A8E27A47409CA6CF0EB8144B40
30515	Кадышево	7	74	1869	46.707526000000001	46.744348000000002	54.353208000000002	54.307789	0103000020E61000000100000005000000EC884336905A4740C68844A165274B40EC884336905A4740C15774EB352D4B40E86B96CB465F4740C15774EB352D4B40E86B96CB465F4740C68844A165274B40EC884336905A4740C68844A165274B40
30151	Вальдиватское	7	74	1869	46.973202999999998	47.017569999999999	54.358553999999998	54.345851000000003	0103000020E610000001000000050000003EAF78EA917C4740FB2477D8442C4B403EAF78EA917C4740CCECF318E52D4B4003B2D7BB3F824740CCECF318E52D4B4003B2D7BB3F824740FB2477D8442C4B403EAF78EA917C4740FB2477D8442C4B40
30255	Большой Кандарать	7	74	1869	46.948804000000003	46.997152	54.407857999999997	54.394461999999997	0103000020E610000001000000050000003128D36872794740E3C116BB7D324B403128D36872794740BBB4E1B034344B400C923EADA27F4740BBB4E1B034344B400C923EADA27F4740E3C116BB7D324B403128D36872794740E3C116BB7D324B40
55825	Большии Поселки	7	74	1869	46.959198000000001	46.990386999999998	54.299261999999999	54.245761000000002	0103000020E61000000100000005000000BE310400C77A4740EED0B018751F4B40BE310400C77A4740C0779B374E264B4018B14F00C57E4740C0779B374E264B4018B14F00C57E4740EED0B018751F4B40BE310400C77A4740EED0B018751F4B40
30958	Белозерье	7	74	1869	47.133552000000002	47.199478999999997	54.350411000000001	54.308692000000001	0103000020E610000001000000050000005F28603B18914740B7442E3883274B405F28603B189147404F948444DA2C4B40909E2287889947404F948444DA2C4B40909E228788994740B7442E3883274B405F28603B18914740B7442E3883274B40
30534	Беловодье	7	74	1869	46.605091000000002	46.635767999999999	54.266379000000001	54.250990000000002	0103000020E610000001000000050000004E0D349F734D4740C0CFB87020204B404E0D349F734D4740ACAB02B518224B40F2EB87D860514740ACAB02B518224B40F2EB87D860514740C0CFB87020204B404E0D349F734D4740C0CFB87020204B40
31021	Базарный Урень	7	74	1869	47.270572000000001	47.292113999999998	54.319947999999997	54.293723999999997	0103000020E610000001000000050000004E9B711AA2A2474070067FBF98254B404E9B711AA2A24740D6355A0EF4284B40145AD6FD63A54740D6355A0EF4284B40145AD6FD63A5474070067FBF98254B404E9B711AA2A2474070067FBF98254B40
55821	станция Дубенки	7	74	186	46.459007	46.459814999999999	53.905619999999999	53.905375999999997	0103000020E610000001000000050000004AD1CABDC03A4740A94A5B5CE3F34A404AD1CABDC03A4740404D2D5BEBF34A40E99AC937DB3A4740404D2D5BEBF34A40E99AC937DB3A4740A94A5B5CE3F34A404AD1CABDC03A4740A94A5B5CE3F34A40
55844	с. Палатово	7	74	186	45.796517000000001	46.802791999999997	54.272447	53.580795999999999	0103000020E61000000100000005000000A1DAE044F4E54640E5D2F88557CA4A40A1DAE044F4E546405872158BDF224B40C6BE64E3C16647405872158BDF224B40C6BE64E3C1664740E5D2F88557CA4A40A1DAE044F4E54640E5D2F88557CA4A40
29194	Юлово	7	74	186	46.472239000000002	46.498452	53.973875999999997	53.960760999999998	0103000020E61000000100000005000000A872DA53723C4740D9226937FAFA4A40A872DA53723C4740FD2D01F8A7FC4A401A506F46CD3F4740FD2D01F8A7FC4A401A506F46CD3F4740D9226937FAFA4A40A872DA53723C4740D9226937FAFA4A40
28687	Чумакино	7	74	186	46.318581999999999	46.341228999999998	54.171165999999999	54.153379000000001	0103000020E61000000100000005000000118C834BC728474054724EECA1134B40118C834BC7284740F4177AC4E8154B4030B95164AD2B4740F4177AC4E8154B4030B95164AD2B474054724EECA1134B40118C834BC728474054724EECA1134B40
29456	Черемушки	7	74	186	46.430117000000003	46.453158999999999	53.753245999999997	53.739412000000002	0103000020E61000000100000005000000113AE8120E3747408E226B0DA5DE4A40113AE8120E374740E1EB6B5D6AE04A40AC71361D013A4740E1EB6B5D6AE04A40AC71361D013A47408E226B0DA5DE4A40113AE8120E3747408E226B0DA5DE4A40
28616	Чамзинка	7	74	186	46.435687000000001	46.462259000000003	54.081620999999998	54.060963999999998	0103000020E610000001000000050000006C257497C4374740DE1D19ABCD074B406C257497C43747405AD5928E720A4B400EA48B4D2B3B47405AD5928E720A4B400EA48B4D2B3B4740DE1D19ABCD074B406C257497C4374740DE1D19ABCD074B40
29146	Труслейка	7	74	186	46.376289999999997	46.410452999999997	53.916159	53.899270000000001	0103000020E61000000100000005000000EAE74D452A304740102384471BF34A40EAE74D452A304740D177B7B244F54A40C5C551B989344740D177B7B244F54A40C5C551B989344740102384471BF34A40EAE74D452A304740102384471BF34A40
27881	Троицкое	7	74	186	46.405673999999998	46.425454999999999	53.850768000000002	53.841084000000002	0103000020E61000000100000005000000336B2920ED3347402D98F8A3A8EB4A40336B2920ED334740DE3D40F7E5EC4A40B875374F75364740DE3D40F7E5EC4A40B875374F753647402D98F8A3A8EB4A40336B2920ED3347402D98F8A3A8EB4A40
28420	Тияпино	7	74	186	46.097408000000001	46.137635000000003	54.149861999999999	54.133848999999998	0103000020E61000000100000005000000342F87DD770C474018CDCAF621114B40342F87DD770C4740E27492AD2E134B407AE40F069E114740E27492AD2E134B407AE40F069E11474018CDCAF621114B40342F87DD770C474018CDCAF621114B40
28970	Сюксюм	7	74	186	46.443089000000001	46.470424999999999	53.827635000000001	53.816138000000002	0103000020E61000000100000005000000D21BEE23B7384740ED82C13577E84A40D21BEE23B7384740320395F1EFE94A40431CEBE2363C4740320395F1EFE94A40431CEBE2363C4740ED82C13577E84A40D21BEE23B7384740ED82C13577E84A40
28901	Свет	7	74	186	46.205233	46.222247000000003	53.861128999999998	53.855393999999997	0103000020E61000000100000005000000AD872F13451A4740E998F38C7DED4A40AD872F13451A47408F519E7939EE4A402B51F696721C47408F519E7939EE4A402B51F696721C4740E998F38C7DED4A40AD872F13451A4740E998F38C7DED4A40
29387	Репьевка	7	74	186	46.368716999999997	46.391517	53.790889999999997	53.780665999999997	0103000020E61000000100000005000000573D601E322F4740B08C0DDDECE34A40573D601E322F4740E15D2EE23BE54A40FD69A33A1D324740E15D2EE23BE54A40FD69A33A1D324740B08C0DDDECE34A40573D601E322F4740B08C0DDDECE34A40
28329	Пятино	7	74	186	46.121150999999998	46.155025999999999	54.125244000000002	54.094163999999999	0103000020E6100000010000000500000058703FE0810F4740F33AE2900D0C4B4058703FE0810F47409702D2FE07104B40CD0358E4D71347409702D2FE07104B40CD0358E4D7134740F33AE2900D0C4B4058703FE0810F4740F33AE2900D0C4B40
28583	Проломиха	7	74	186	46.416373	46.442954	54.114134999999997	54.086765999999997	0103000020E61000000100000005000000FDF7E0B54B354740CE33F6251B0B4B40FDF7E0B54B3547401B2AC6F99B0E4B40F2D077B7B23847401B2AC6F99B0E4B40F2D077B7B2384740CE33F6251B0B4B40FDF7E0B54B354740CE33F6251B0B4B40
29362	Поддубное	7	74	186	46.443170000000002	46.457721999999997	53.738335999999997	53.717326	0103000020E61000000100000005000000BF4868CBB938474006499F56D1DB4A40BF4868CBB9384740CFBA46CB81DE4A4071546EA2963A4740CFBA46CB81DE4A4071546EA2963A474006499F56D1DB4A40BF4868CBB938474006499F56D1DB4A40
28320	Первомайское	7	74	186	45.897371	45.932208000000003	54.025055000000002	54.009771000000001	0103000020E610000001000000050000007DB08C0DDDF2464080B9162D40014B407DB08C0DDDF24640F7CC920035034B40E8887C9752F74640F7CC920035034B40E8887C9752F7464080B9162D40014B407DB08C0DDDF2464080B9162D40014B40
28889	Панциревка	7	74	186	46.285372000000002	46.308225	53.818142000000002	53.791736	0103000020E61000000100000005000000D998D711872447406E88F19A57E54A40D998D71187244740F5BD86E0B8E84A40A167B3EA73274740F5BD86E0B8E84A40A167B3EA732747406E88F19A57E54A40D998D711872447406E88F19A57E54A40
28824	Оськино	7	74	186	46.272894000000001	46.304721000000001	53.845444999999998	53.819737000000003	0103000020E6100000010000000500000027A3CA30EE2247401C295B24EDE84A4027A3CA30EE2247408AC8B08A37EC4A40C4B30419012747408AC8B08A37EC4A40C4B30419012747401C295B24EDE84A4027A3CA30EE2247401C295B24EDE84A40
28519	Новосурск	7	74	186	46.439433000000001	46.456904999999999	54.237090000000002	54.219963	0103000020E610000001000000050000003FE42D573F3847403FAA61BF271C4B403FE42D573F384740B51A12F7581E4B407F30F0DC7B3A4740B51A12F7581E4B407F30F0DC7B3A47403FAA61BF271C4B403FE42D573F3847403FAA61BF271C4B40
28033	Неклюдовский	7	74	186	46.675078999999997	46.699738000000004	53.899419000000002	53.888084999999997	0103000020E61000000100000005000000B29B19FD68564740B988EFC4ACF14A40B29B19FD6856474055336B2920F34A405DE2C8039159474055336B2920F34A405DE2C80391594740B988EFC4ACF14A40B29B19FD68564740B988EFC4ACF14A40
28091	Неклюдово	7	74	186	46.688625000000002	46.714756999999999	53.867421	53.860019000000001	0103000020E61000000100000005000000A01A2FDD245847402578431A15EE4A40A01A2FDD245847408B6EBDA607EF4A4025CB49287D5B47408B6EBDA607EF4A4025CB49287D5B47402578431A15EE4A40A01A2FDD245847402578431A15EE4A40
28505	Коржевка	7	74	186	46.359850999999999	46.404263999999998	54.190114000000001	54.173569000000001	0103000020E610000001000000050000006937FA980F2E4740BA4C4D8237164B406937FA980F2E47408141D2A755184B409E7939ECBE3347408141D2A755184B409E7939ECBE334740BA4C4D8237164B406937FA980F2E4740BA4C4D8237164B40
27225	Инза	7	74	186	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
28773	Забалуйка	7	74	186	46.237042000000002	46.268653999999998	53.883122999999998	53.872343000000001	0103000020E61000000100000005000000A4E36A64571E474080F277EFA8EF4A40A4E36A64571E474036ACA92C0AF14A4044F817416322474036ACA92C0AF14A4044F817416322474080F277EFA8EF4A40A4E36A64571E474080F277EFA8EF4A40
28432	Дракино	7	74	186	46.443151999999998	46.469203	54.197325999999997	54.182063999999997	0103000020E6100000010000000500000018946934B9384740B4E386DF4D174B4018946934B9384740435376FA41194B40B1170AD80E3C4740435376FA41194B40B1170AD80E3C4740B4E386DF4D174B4018946934B9384740B4E386DF4D174B40
29055	Городищи	7	74	186	46.145746000000003	46.171365999999999	54.007840000000002	53.988197999999997	0103000020E61000000100000005000000ECC20FCEA71247407EFCA5457DFE4A40ECC20FCEA7124740E2CCAFE600014B40BBD23252EF154740E2CCAFE600014B40BBD23252EF1547407EFCA5457DFE4A40ECC20FCEA71247407EFCA5457DFE4A40
27934	Глотовка	7	74	186	46.675671999999999	46.719580999999998	53.966206999999997	53.944490000000002	0103000020E6100000010000000500000055698B6B7C56474014B35E0CE5F84A4055698B6B7C5647404815C5ABACFB4A4057E9EE3A1B5C47404815C5ABACFB4A4057E9EE3A1B5C474014B35E0CE5F84A4055698B6B7C56474014B35E0CE5F84A40
28231	Валгуссы	7	74	186	46.187015000000002	46.226064999999998	54.071542000000001	54.051397000000001	0103000020E61000000100000005000000446E861BF0174740670E492D94064B40446E861BF01747402D25CB4928094B4097E2AAB2EF1C47402D25CB4928094B4097E2AAB2EF1C4740670E492D94064B40446E861BF0174740670E492D94064B40
29323	Бояркино	7	74	186	46.403095999999998	46.421304999999997	53.772965999999997	53.756270000000001	0103000020E61000000100000005000000FF9254A69833474014799274CDE04A40FF9254A698334740C075C58CF0E24A4015527E52ED354740C075C58CF0E24A4015527E52ED35474014799274CDE04A40FF9254A69833474014799274CDE04A40
28166	Большое Шуватово	7	74	186	46.219813000000002	46.242702000000001	54.160259000000003	54.144598999999999	0103000020E610000001000000050000002A1E17D5221C47406404543882124B402A1E17D5221C4740E1F1ED5D83144B403F56F0DB101F4740E1F1ED5D83144B403F56F0DB101F47406404543882124B402A1E17D5221C47406404543882124B40
29260	Большая Борисовка	7	74	186	46.455629000000002	46.478023999999998	53.678527000000003	53.664866000000004	0103000020E61000000100000005000000FA0D130D523A4740761C3F541AD54A40FA0D130D523A4740FC3905F9D9D64A40FF59F3E32F3D4740FC3905F9D9D64A40FF59F3E32F3D4740761C3F541AD54A40FA0D130D523A4740761C3F541AD54A40
29226	Аристовка	7	74	186	46.540304999999996	46.569284000000003	53.638651000000003	53.617618	0103000020E61000000100000005000000C16ED8B628454740E1B54B1B0ECF4A40C16ED8B6284547406347E350BFD14A406B11514CDE4847406347E350BFD14A406B11514CDE484740E1B54B1B0ECF4A40C16ED8B628454740E1B54B1B0ECF4A40
28998	Аргаш	7	74	186	46.227718000000003	46.268177999999999	53.973526	53.953000000000003	0103000020E61000000100000005000000F35A09DD251D4740448B6CE7FBF94A40F35A09DD251D474021E7FD7F9CFC4A40DBC01DA85322474021E7FD7F9CFC4A40DBC01DA853224740448B6CE7FBF94A40F35A09DD251D4740448B6CE7FBF94A40
52000	Андрияновка	7	74	186	46.307147000000001	46.319265000000001	53.777563999999998	53.77037	0103000020E610000001000000050000004208C89750274740E6E8F17B9BE24A404208C897502747400246973787E34A40F4E0EEACDD2847400246973787E34A40F4E0EEACDD284740E6E8F17B9BE24A404208C89750274740E6E8F17B9BE24A40
28150	Аксаур	7	74	186	46.074744000000003	46.124403000000001	54.070802	54.052523000000001	0103000020E610000001000000050000003FC91D3691094740D7A4DB12B9064B403FC91D3691094740E63E390A10094B401C430070EC0F4740E63E390A10094B401C430070EC0F4740D7A4DB12B9064B403FC91D3691094740D7A4DB12B9064B40
26878	Шарлово	7	74	1787	46.826625	46.864092999999997	53.975009	53.955452999999999	0103000020E610000001000000050000002B8716D9CE694740BBEEAD484CFA4A402B8716D9CE69474020274C18CDFC4A40ECD973999A6E474020274C18CDFC4A40ECD973999A6E4740BBEEAD484CFA4A402B8716D9CE694740BBEEAD484CFA4A40
26432	Чуфарово	7	74	1787	47.298977000000001	47.359748000000003	54.104492	54.085555999999997	0103000020E61000000100000005000000CBA0DAE044A6474000FDBE7FF30A4B40CBA0DAE044A64740C9586DFE5F0D4B409566F3380CAE4740C9586DFE5F0D4B409566F3380CAE474000FDBE7FF30A4B40CBA0DAE044A6474000FDBE7FF30A4B40
26373	Ховрино	7	74	1787	47.15795	47.186993000000001	54.119239	54.103731000000003	0103000020E610000001000000050000009C33A2B4379447406B4AB20E470D4B409C33A2B43794474031B43A39430F4B405CCAF962EF97474031B43A39430F4B405CCAF962EF9747406B4AB20E470D4B409C33A2B4379447406B4AB20E470D4B40
55797	Стемас	7	74	1787	47.388188	47.407088999999999	53.968595999999998	53.949916000000002	0103000020E610000001000000050000008E59F624B0B147403CF9F4D896F94A408E59F624B0B14740A98427F4FAFB4A40DAC70A7E1BB44740A98427F4FAFB4A40DAC70A7E1BB447403CF9F4D896F94A408E59F624B0B147403CF9F4D896F94A40
26666	Старое Погорелово	7	74	1787	46.846657	46.879643000000002	54.140912	54.108910000000002	0103000020E61000000100000005000000F9F6AE415F6C47408B1A4CC3F00D4B40F9F6AE415F6C474096CE876709124B40E2934E249870474096CE876709124B40E2934E24987047408B1A4CC3F00D4B40F9F6AE415F6C47408B1A4CC3F00D4B40
27063	Нижняя Туарма	7	74	1787	47.149487999999998	47.168056	53.902729000000001	53.888165000000001	0103000020E610000001000000050000007D923B6C22934740D6390664AFF14A407D923B6C229347404D13B69F8CF34A40C3F2E7DB829547404D13B69F8CF34A40C3F2E7DB82954740D6390664AFF14A407D923B6C22934740D6390664AFF14A40
55822	Мордово-Белый Ключ	7	74	1787	46.933065999999997	46.968747	53.944071000000001	53.928852999999997	0103000020E610000001000000050000003881E9B46E7747404FE5B4A7E4F64A403881E9B46E7747400F0D8B51D7F84A408F8CD5E6FF7B47400F0D8B51D7F84A408F8CD5E6FF7B47404FE5B4A7E4F64A403881E9B46E7747404FE5B4A7E4F64A40
55783	Красный Бор	7	74	1787	47.221029999999999	47.267940000000003	54.016283999999999	53.980707000000002	0103000020E61000000100000005000000AAB706B64A9C4740A9FA95CE87FD4A40AAB706B64A9C47405AB9179815024B4027A5A0DB4BA247405AB9179815024B4027A5A0DB4BA24740A9FA95CE87FD4A40AAB706B64A9C4740A9FA95CE87FD4A40
26985	Коченяевка	7	74	1787	46.978054	47.005721999999999	53.881068999999997	53.867432000000001	0103000020E610000001000000050000006ADC9BDF307D47407FC0030308EF4A406ADC9BDF307D47407C4276DEC6F04A40116F9D7FBB8047407C4276DEC6F04A40116F9D7FBB8047407FC0030308EF4A406ADC9BDF307D47407FC0030308EF4A40
26951	Каргино	7	74	1787	47.053485000000002	47.1265	53.934201999999999	53.911152999999999	0103000020E61000000100000005000000CDE9B298D88647407E5358A9A0F44A40CDE9B298D8864740CCED5EEE93F74A40D578E92631904740CCED5EEE93F74A40D578E926319047407E5358A9A0F44A40CDE9B298D88647407E5358A9A0F44A40
26788	Зимненки	7	74	1787	46.839551	46.862189000000001	54.056095999999997	54.035330000000002	0103000020E610000001000000050000007C293C68766B4740AA4885B185044B407C293C68766B4740DCB75A272E074B4048FC8A355C6E4740DCB75A272E074B4048FC8A355C6E4740AA4885B185044B407C293C68766B4740AA4885B185044B40
55831	Залесный	7	74	1787	46.682993000000003	47.488197999999997	54.219299999999997	53.805594999999997	0103000020E61000000100000005000000CF328B506C5747401A69A9BC1DE74A40CF328B506C574740A301BC05121C4B407EFCA5457DBE4740A301BC05121C4B407EFCA5457DBE47401A69A9BC1DE74A40CF328B506C5747401A69A9BC1DE74A40
26718	Ермоловка	7	74	1787	46.861846999999997	46.878646000000003	54.022579	53.991311000000003	0103000020E61000000100000005000000EE93A300516E474021956247E3FE4A40EE93A300516E4740C74961DEE3024B407061DD7877704740C74961DEE3024B407061DD787770474021956247E3FE4A40EE93A300516E474021956247E3FE4A40
26223	Вешкайма	7	74	1787	47.001759999999997	47.043917999999998	54.089374999999997	54.035907000000002	0103000020E610000001000000050000007138F3AB398047404759BF9998044B407138F3AB398047403D0AD7A3700B4B4055DAE21A9F8547403D0AD7A3700B4B4055DAE21A9F8547404759BF9998044B407138F3AB398047404759BF9998044B40
26046	Вешкайма	7	74	1787	47.101903999999998	47.142885	54.065407999999998	54.034500000000001	0103000020E6100000010000000500000071AAB5300B8D474023DBF97E6A044B4071AAB5300B8D4740C972124A5F084B40630B410E4A924740C972124A5F084B40630B410E4A92474023DBF97E6A044B4071AAB5300B8D474023DBF97E6A044B40
26537	Березовка	7	74	1787	47.310187999999997	47.333444999999998	54.060429999999997	54.035483999999997	0103000020E610000001000000050000004ACE893DB4A7474000C45DBD8A044B404ACE893DB4A7474040D9942BBC074B40E2016553AEAA474040D9942BBC074B40E2016553AEAA474000C45DBD8A044B404ACE893DB4A7474000C45DBD8A044B40
26215	Белый Ключ	7	74	1787	47.121515000000002	47.148051000000002	54.159236999999997	54.143416999999999	0103000020E610000001000000050000009A7CB3CD8D8F47406058FE7C5B124B409A7CB3CD8D8F474015A8C5E061144B40EF91CD55F392474015A8C5E061144B40EF91CD55F39247406058FE7C5B124B409A7CB3CD8D8F47406058FE7C5B124B40
27190	Беклемишево	7	74	1787	47.387208999999999	47.432152000000002	53.871090000000002	53.847687000000001	0103000020E61000000100000005000000C2DB831090B14740471FF30181EC4A40C2DB831090B14740B3EF8AE07FEF4A405473B9C150B74740B3EF8AE07FEF4A405473B9C150B74740471FF30181EC4A40C2DB831090B14740471FF30181EC4A40
26630	Бекетовка	7	74	1787	46.856259999999999	46.887351000000002	54.112161	54.062882000000002	0103000020E61000000100000005000000BD6F7CED996D4740E8C072840C084B40BD6F7CED996D47407E71A94A5B0E4B405589B2B7947147407E71A94A5B0E4B405589B2B794714740E8C072840C084B40BD6F7CED996D4740E8C072840C084B40
27069	Ахматово-Белый Ключ	7	74	1787	47.009521999999997	47.03454	53.944156	53.932839999999999	0103000020E61000000100000005000000D74B5304388147404833164D67F74A40D74B5304388147403D29931ADAF84A40B13385CE6B8447403D29931ADAF84A40B13385CE6B8447404833164D67F74A40D74B5304388147404833164D67F74A40
24410	имени В. И.Ленина	7	74	162	46.972538	46.988779000000001	53.576059000000001	53.553928999999997	0103000020E61000000100000005000000020F0C207C7C47402AA73D25E7C64A40020F0C207C7C474082C8224DBCC94A405DFC6D4F907E474082C8224DBCC94A405DFC6D4F907E47402AA73D25E7C64A40020F0C207C7C47402AA73D25E7C64A40
25811	Чувашская Решетка	7	74	162	47.014777000000002	47.045031999999999	53.702365999999998	53.683822999999997	0103000020E61000000100000005000000D3DD7536E481474055A0168387D74A40D3DD7536E481474042E90B21E7D94A4001A3CB9BC385474042E90B21E7D94A4001A3CB9BC385474055A0168387D74A40D3DD7536E481474055A0168387D74A40
24791	Сурские Вершины	7	74	162	46.930829000000003	46.946505000000002	53.394767000000002	53.380938	0103000020E610000001000000050000008E95986725774740DEE68D93C2B04A408E9598672577474020459DB987B24A4010406A132779474020459DB987B24A4010406A1327794740DEE68D93C2B04A408E95986725774740DEE68D93C2B04A40
24859	Старотимошкино	7	74	162	47.510449000000001	47.558599000000001	53.731881000000001	53.709983000000001	0103000020E6100000010000000500000051A3906456C14740A5DB12B9E0DA4A4051A3906456C147402AC8CF46AEDD4A40064A0A2C80C747402AC8CF46AEDD4A40064A0A2C80C74740A5DB12B9E0DA4A4051A3906456C14740A5DB12B9E0DA4A40
25774	Старая Савадерка	7	74	162	46.976157999999998	47.004356000000001	53.761555999999999	53.749215999999997	0103000020E6100000010000000500000048DDCEBEF27C4740E9D1544FE6DF4A4048DDCEBEF27C47404A09C1AA7AE14A404CC5C6BC8E8047404A09C1AA7AE14A404CC5C6BC8E804740E9D1544FE6DF4A4048DDCEBEF27C4740E9D1544FE6DF4A40
25028	Смольково	7	74	162	47.662452999999999	47.675452	53.723996999999997	53.712141000000003	0103000020E610000001000000050000008C118942CBD447400492B06F27DB4A408C118942CBD4474078B306EFABDC4A4047020D3675D6474078B306EFABDC4A4047020D3675D647400492B06F27DB4A408C118942CBD447400492B06F27DB4A40
62068	Самородки	7	74	162	46.689900999999999	47.720799	53.886699999999998	53.320597999999997	0103000020E61000000100000005000000253D0CAD4E584740DD94F25A09A94A40253D0CAD4E5847407DAEB6627FF14A40A8FE412443DC47407DAEB6627FF14A40A8FE412443DC4740DD94F25A09A94A40253D0CAD4E584740DD94F25A09A94A40
24776	Русская Бекшанка	7	74	162	47.087657	47.102398000000001	53.402734000000002	53.386228000000003	0103000020E61000000100000005000000FB213658388B474056664AEB6FB14A40FB213658388B47405F7EA7C98CB34A408196AE601B8D47405F7EA7C98CB34A408196AE601B8D474056664AEB6FB14A40FB213658388B474056664AEB6FB14A40
24710	Румянцево	7	74	162	46.973131000000002	47.004123	53.541935000000002	53.515605999999998	0103000020E61000000100000005000000A5DC7D8E8F7C474089CF9D60FFC14A40A5DC7D8E8F7C474065C746205EC54A40A9143B1A8780474065C746205EC54A40A9143B1A8780474089CF9D60FFC14A40A5DC7D8E8F7C474089CF9D60FFC14A40
25856	Поливаново	7	74	162	47.348455999999999	47.381065	53.620587	53.605513000000002	0103000020E61000000100000005000000280CCA349AAC4740C426327381CD4A40280CCA349AAC474050A912656FCF4A403B53E8BCC6B0474050A912656FCF4A403B53E8BCC6B04740C426327381CD4A40280CCA349AAC4740C426327381CD4A40
24101	Павловка	7	74	162	46.754669	46.781196999999999	53.599555000000002	53.587654000000001	0103000020E610000001000000050000000B2769FE986047408AAE0B3F38CB4A400B2769FE986047409F93DE37BECC4A40DD5D6743FE6347409F93DE37BECC4A40DD5D6743FE6347408AAE0B3F38CB4A400B2769FE986047408AAE0B3F38CB4A40
25282	Осока	7	74	162	47.282007999999998	47.301572999999998	53.496316	53.474379999999996	0103000020E61000000100000005000000ED9A90D618A4474030F0DC7BB8BC4A40ED9A90D618A44740A33D5E4887BF4A40A52DAEF199A64740A33D5E4887BF4A40A52DAEF199A6474030F0DC7BB8BC4A40ED9A90D618A4474030F0DC7BB8BC4A40
25740	Новый Дол	7	74	162	47.139535000000002	47.171748000000001	53.815165	53.802453	0103000020E61000000100000005000000DDD26A48DC914740DEC9A7C7B6E64A40DDD26A48DC91474003ECA35357E84A40A393A5D6FB95474003ECA35357E84A40A393A5D6FB954740DEC9A7C7B6E64A40DDD26A48DC914740DEC9A7C7B6E64A40
24347	Новая Ханинеевка	7	74	162	47.204591000000001	47.2273	53.669145	53.661248999999998	0103000020E610000001000000050000002907B309309A4740A0C1A6CEA3D44A402907B309309A474016A4198BA6D54A40BE30992A189D474016A4198BA6D54A40BE30992A189D4740A0C1A6CEA3D44A402907B309309A4740A0C1A6CEA3D44A40
55838	Новая Деревня	7	74	162	47.139535000000002	47.171748000000001	53.815165	53.802453	0103000020E61000000100000005000000DDD26A48DC914740DEC9A7C7B6E64A40DDD26A48DC91474003ECA35357E84A40A393A5D6FB95474003ECA35357E84A40A393A5D6FB954740DEC9A7C7B6E64A40DDD26A48DC914740DEC9A7C7B6E64A40
24662	Новая Бекшанка	7	74	162	47.039687000000001	47.077506	53.395851	53.380557000000003	0103000020E61000000100000005000000C689AF7614854740C7A17E17B6B04A40C689AF7614854740618BDD3EABB24A40349F73B7EB894740618BDD3EABB24A40349F73B7EB894740C7A17E17B6B04A40C689AF7614854740C7A17E17B6B04A40
25578	Малый Хомутерь	7	74	162	47.059252000000001	47.096308000000001	53.766489999999997	53.746915000000001	0103000020E610000001000000050000007E1CCD919587474028F224E99ADF4A407E1CCD9195874740035B25581CE24A40ED2B0FD2538C4740035B25581CE24A40ED2B0FD2538C474028F224E99ADF4A407E1CCD919587474028F224E99ADF4A40
24306	Ляховка	7	74	162	47.309559	47.327497999999999	53.818998000000001	53.810938999999998	0103000020E610000001000000050000005B971AA19FA74740850662D9CCE74A405B971AA19FA74740A5BE2CEDD4E84A40B1C05774EBA94740A5BE2CEDD4E84A40B1C05774EBA94740850662D9CCE74A405B971AA19FA74740850662D9CCE74A40
25530	Лесная Дача	7	74	162	47.021757000000001	47.039642000000001	53.617761999999999	53.607719000000003	0103000020E61000000100000005000000C3BAF1EEC8824740341477BCC9CD4A40C3BAF1EEC8824740145B41D312CF4A4026C632FD12854740145B41D312CF4A4026C632FD12854740341477BCC9CD4A40C3BAF1EEC8824740341477BCC9CD4A40
25216	Кудажлейка	7	74	162	47.227128999999998	47.246129000000003	53.497810000000001	53.485391999999997	0103000020E61000000100000005000000917C2590129D4740B9DE365321BE4A40917C2590129D474096CFF23CB8BF4A4071CCB227819F474096CFF23CB8BF4A4071CCB227819F4740B9DE365321BE4A40917C2590129D4740B9DE365321BE4A40
24622	Красная Поляна	7	74	162	46.774379000000003	46.796315	53.439915999999997	53.422845000000002	0103000020E61000000100000005000000C7DADFD91E6347407923F3C81FB64A40C7DADFD91E6347405A7EE02A4FB84A40392861A6ED6547405A7EE02A4FB84A40392861A6ED6547407923F3C81FB64A40C7DADFD91E6347407923F3C81FB64A40
25485	Красная Зорька	7	74	162	47.000062	47.026975999999998	53.609059999999999	53.601041000000002	0103000020E6100000010000000500000076FC1708028047400F4757E9EECC4A4076FC170802804740A0A696ADF5CD4A4071E316F373834740A0A696ADF5CD4A4071E316F3738347400F4757E9EECC4A4076FC1708028047400F4757E9EECC4A40
25441	Конновка	7	74	162	47.169547000000001	47.191664000000003	53.573086000000004	53.557299	0103000020E61000000100000005000000451152B7B3954740F88BD99255C74A40451152B7B3954740D2E5CDE15AC94A4008E9297288984740D2E5CDE15AC94A4008E9297288984740F88BD99255C74A40451152B7B3954740F88BD99255C74A40
25177	Киселевка	7	74	162	47.190998999999998	47.216610000000003	53.456755000000001	53.437196	0103000020E61000000100000005000000CB48BDA77298474094F8DC09F6B74A40CB48BDA7729847406AA4A5F276BA4A4048FE60E0B99B47406AA4A5F276BA4A4048FE60E0B99B474094F8DC09F6B74A40CB48BDA77298474094F8DC09F6B74A40
25148	Кармалейка	7	74	162	47.077111000000002	47.104267	53.523235	53.509785000000001	0103000020E61000000100000005000000B894F3C5DE894740E57E87A240C14A40B894F3C5DE894740B08F4E5DF9C24A40A986FD9E588D4740B08F4E5DF9C24A40A986FD9E588D4740E57E87A240C14A40B894F3C5DE894740E57E87A240C14A40
24959	Калда	7	74	162	47.485619999999997	47.514131999999996	53.791550000000001	53.776100999999997	0103000020E610000001000000050000004A24D1CB28BE47404AB20E4757E34A404A24D1CB28BE47400C93A98251E54A40DDE9CE13CFC147400C93A98251E54A40DDE9CE13CFC147404AB20E4757E34A404A24D1CB28BE47404AB20E4757E34A40
24182	Измайлово	7	74	162	47.224254999999999	47.259379000000003	53.734219000000003	53.708368	0103000020E61000000100000005000000747B4963B49C474037C478CDABDA4A40747B4963B49C4740098D60E3FADD4A407522C15433A14740098D60E3FADD4A407522C15433A1474037C478CDABDA4A40747B4963B49C474037C478CDABDA4A40
25373	Земляничный	7	74	162	47.064749999999997	47.092140000000001	53.651333999999999	53.635662000000004	0103000020E610000001000000050000003F355EBA49884740ADA7565F5DD14A403F355EBA49884740ED629AE95ED34A40A453573ECB8B4740ED629AE95ED34A40A453573ECB8B4740ADA7565F5DD14A403F355EBA49884740ADA7565F5DD14A40
24946	Заречное	7	74	162	47.573447999999999	47.605553999999998	53.733266	53.717996999999997	0103000020E6100000010000000500000072FA7ABE66C9474024D06053E7DB4A4072FA7ABE66C9474066A208A9DBDD4A4022FB20CB82CD474066A208A9DBDD4A4022FB20CB82CD474024D06053E7DB4A4072FA7ABE66C9474024D06053E7DB4A40
25114	Загарино	7	74	162	47.226599	47.273311999999997	53.428972999999999	53.408563999999998	0103000020E6100000010000000500000035272F32019D474056293DD34BB44A4035272F32019D4740FAEE5696E8B64A405BCD3AE3FBA24740FAEE5696E8B64A405BCD3AE3FBA2474056293DD34BB44A4035272F32019D474056293DD34BB44A40
25050	Живайкино	7	74	162	47.110599999999998	47.149731000000003	53.488168000000002	53.474493000000002	0103000020E6100000010000000500000003780B24288E47402997C62FBCBC4A4003780B24288E4740147AFD497CBE4A404419AA622A934740147AFD497CBE4A404419AA622A9347402997C62FBCBC4A4003780B24288E47402997C62FBCBC4A40
23957	Жадовка	7	74	162	46.926724	46.972673	53.580950999999999	53.567568000000001	0103000020E610000001000000050000008B355CE49E764740C9207711A6C84A408B355CE49E7647400CCA349A5CCA4A40E259828C807C47400CCA349A5CCA4A40E259828C807C4740C9207711A6C84A408B355CE49E764740C9207711A6C84A40
24546	Головцево	7	74	162	46.848804000000001	46.875456999999997	53.487535000000001	53.468522	0103000020E61000000100000005000000645B069CA56C47406FBA6587F8BB4A40645B069CA56C4740E353008C67BE4A40F20698F90E704740E353008C67BE4A40F20698F90E7047406FBA6587F8BB4A40645B069CA56C47406FBA6587F8BB4A40
24512	Воецкое	7	74	162	46.919195999999999	46.952109999999998	53.525199000000001	53.506214	0103000020E61000000100000005000000984EEB36A87547408063CF9ECBC04A40984EEB36A87547402A7288B839C34A40E71890BDDE7947402A7288B839C34A40E71890BDDE7947408063CF9ECBC04A40984EEB36A87547408063CF9ECBC04A40
25980	Водорацк	7	74	162	47.295454999999997	47.316054000000001	53.640951999999999	53.628379000000002	0103000020E6100000010000000500000047382D78D1A54740213F1BB96ED04A4047382D78D1A54740242713B70AD24A408FE21C7574A84740242713B70AD24A408FE21C7574A84740213F1BB96ED04A4047382D78D1A54740213F1BB96ED04A40
25674	Барышская Дурасовка	7	74	162	47.154761000000001	47.176023999999998	53.859243999999997	53.834446999999997	0103000020E610000001000000050000001FD95C35CF934740669FC728CFEA4A401FD95C35CF93474061A417B5FBED4A40D2A755F48796474061A417B5FBED4A40D2A755F487964740669FC728CFEA4A401FD95C35CF934740669FC728CFEA4A40
25637	Алинкино	7	74	162	46.983550999999999	47.015729	53.720267	53.712743000000003	0103000020E610000001000000050000005B79C9FFE47D4740FAB9A1293BDB4A405B79C9FFE47D4740ABB184B531DC4A40A54C6A6803824740ABB184B531DC4A40A54C6A6803824740FAB9A1293BDB4A405B79C9FFE47D4740FAB9A1293BDB4A40
25915	Акшуат	7	74	162	47.412101999999997	47.451106000000003	53.685710999999998	53.661430000000003	0103000020E61000000100000005000000DF4E22C2BFB44740F14BFDBCA9D44A40DF4E22C2BFB44740F4C0C760C5D74A40C38366D7BDB94740F4C0C760C5D74A40C38366D7BDB94740F14BFDBCA9D44A40DF4E22C2BFB44740F14BFDBCA9D44A40
55808	п. Сосновый Бор	7	74	1691	46.443277000000002	46.993693	53.933799	53.429788000000002	0103000020E61000000100000005000000D508FD4CBD3847404C1B0E4B03B74A40D508FD4CBD384740CD04C3B986F74A40CFA10C55317F4740CD04C3B986F74A40CFA10C55317F47404C1B0E4B03B74A40D508FD4CBD3847404C1B0E4B03B74A40
22840	Ясачный Сызган	7	74	1691	46.812520999999997	46.853700000000003	53.733840999999998	53.71528	0103000020E61000000100000005000000172829B000684740CFBD874B8EDB4A40172829B00068474062BB7B80EEDD4A40304CA60A466D474062BB7B80EEDD4A40304CA60A466D4740CFBD874B8EDB4A40172829B000684740CFBD874B8EDB4A40
23139	Юрловка	7	74	1691	46.777656999999998	46.809440000000002	53.652188000000002	53.641502000000003	0103000020E61000000100000005000000B340BB438A634740C828CFBC1CD24A40B340BB438A634740FD6B79E57AD34A408109DCBA9B674740FD6B79E57AD34A408109DCBA9B674740C828CFBC1CD24A40B340BB438A634740C828CFBC1CD24A40
22633	Черный Ключ	7	74	1691	46.648749000000002	46.666274999999999	53.695687	53.686351000000002	0103000020E6100000010000000500000007280D350A534740D8497D59DAD74A4007280D350A5347404DA088450CD94A403A92CB7F485547404DA088450CD94A403A92CB7F48554740D8497D59DAD74A4007280D350A534740D8497D59DAD74A40
22886	Русская Хомутерь	7	74	1691	46.884898	46.907643999999998	53.791863999999997	53.785715000000003	0103000020E61000000100000005000000DD25715644714740037D224F92E44A40DD257156447147409B70AFCC5BE54A408F34B8AD2D7447409B70AFCC5BE54A408F34B8AD2D744740037D224F92E44A40DD25715644714740037D224F92E44A40
55832	Раздолье	7	74	1691	46.443277000000002	46.993693	53.933799	53.429788000000002	0103000020E61000000100000005000000D508FD4CBD3847404C1B0E4B03B74A40D508FD4CBD384740CD04C3B986F74A40CFA10C55317F4740CD04C3B986F74A40CFA10C55317F47404C1B0E4B03B74A40D508FD4CBD3847404C1B0E4B03B74A40
23192	Патрикеево	7	74	1691	46.821764999999999	46.842362999999999	53.677039000000001	53.671646000000003	0103000020E61000000100000005000000ACFF73982F6947409F3E027FF8D54A40ACFF73982F694740EB8EC536A9D64A40232E008DD26B4740EB8EC536A9D64A40232E008DD26B47409F3E027FF8D54A40ACFF73982F6947409F3E027FF8D54A40
23068	Папузы	7	74	1691	46.636513999999998	46.673372000000001	53.586418999999999	53.572069999999997	0103000020E610000001000000050000001BB96E4A79514740E882FA9639C94A401BB96E4A7951474063601DC70FCB4A406405BF0D3156474063601DC70FCB4A406405BF0D31564740E882FA9639C94A401BB96E4A79514740E882FA9639C94A40
23111	Папуз-Гора	7	74	1691	46.606977000000001	46.625995000000003	53.597454999999997	53.590262000000003	0103000020E610000001000000050000004C361E6CB14D4740290989B48DCB4A404C361E6CB14D474074EACA6779CC4A40D23AAA9A2050474074EACA6779CC4A40D23AAA9A20504740290989B48DCB4A404C361E6CB14D4740290989B48DCB4A40
55820	Лапшаур	7	74	1691	46.443277000000002	46.993693	53.933799	53.429788000000002	0103000020E61000000100000005000000D508FD4CBD3847404C1B0E4B03B74A40D508FD4CBD384740CD04C3B986F74A40CFA10C55317F4740CD04C3B986F74A40CFA10C55317F47404C1B0E4B03B74A40D508FD4CBD3847404C1B0E4B03B74A40
22750	Красная Сосна	7	74	1691	46.786146000000002	46.812987999999997	53.872024000000003	53.858559	0103000020E61000000100000005000000CCF09F6EA0644740DE57E542E5ED4A40CCF09F6EA0644740DFA9807B9EEF4A402D05A4FD0F684740DFA9807B9EEF4A402D05A4FD0F684740DE57E542E5ED4A40CCF09F6EA0644740DE57E542E5ED4A40
23248	Иевлевка	7	74	1691	46.730100999999998	46.754319000000002	53.637295000000002	53.630515000000003	0103000020E6100000010000000500000071E316F3735D474098512CB7B4D04A4071E316F3735D4740C173EFE192D14A402FE065868D604740C173EFE192D14A402FE065868D60474098512CB7B4D04A4071E316F3735D474098512CB7B4D04A40
55842	Дубки	7	74	1691	46.443277000000002	46.993693	53.933799	53.429788000000002	0103000020E61000000100000005000000D508FD4CBD3847404C1B0E4B03B74A40D508FD4CBD384740CD04C3B986F74A40CFA10C55317F4740CD04C3B986F74A40CFA10C55317F47404C1B0E4B03B74A40D508FD4CBD3847404C1B0E4B03B74A40
22576	Должниково	7	74	1691	46.626156999999999	46.666473000000003	53.738453	53.724988000000003	0103000020E61000000100000005000000AB949EE92550474009FF2268CCDC4A40AB949EE9255047400951BEA085DE4A406155BDFC4E5547400951BEA085DE4A406155BDFC4E55474009FF2268CCDC4A40AB949EE92550474009FF2268CCDC4A40
22972	Годяйкино	7	74	1691	46.569975999999997	46.593494	53.522019999999998	53.505330000000001	0103000020E61000000100000005000000A0C03BF9F448474006D847A7AEC04A40A0C03BF9F4484740D0ED258DD1C24A40A52F849CF74B4740D0ED258DD1C24A40A52F849CF74B474006D847A7AEC04A40A0C03BF9F448474006D847A7AEC04A40
23026	Вороновка	7	74	1691	46.677585000000001	46.702872999999997	53.518293	53.505699	0103000020E610000001000000050000004DA1F31ABB564740594FADBEBAC04A404DA1F31ABB564740745FCE6C57C24A40E61E12BEF7594740745FCE6C57C24A40E61E12BEF7594740594FADBEBAC04A404DA1F31ABB564740594FADBEBAC04A40
22393	Базарный Сызган	7	74	1691	46.735346999999997	46.794438	53.774355	53.733575000000002	0103000020E61000000100000005000000191BBAD91F5E4740E4141DC9E5DD4A40191BBAD91F5E47403E3F8C101EE34A408E59F624B06547403E3F8C101EE34A408E59F624B0654740E4141DC9E5DD4A40191BBAD91F5E4740E4141DC9E5DD4A40
1193	Энгельс	7	73	\N	46.046940999999997	46.192270000000001	51.512884	51.440165999999998	0103000020E61000000100000005000000B7EBA52902064740D367075C57B84940B7EBA529020647402252D32EA6C149403F00A94D9C1847402252D32EA6C149403F00A94D9C184740D367075C57B84940B7EBA52902064740D367075C57B84940
11330	Шумейка	7	73	\N	46.240015999999997	46.257846999999998	51.571089999999998	51.553145000000001	0103000020E61000000100000005000000244223D8B81E474014799274CDC64940244223D8B81E47404C89247A19C94940942F6821012147404C89247A19C94940942F68210121474014799274CDC64940244223D8B81E474014799274CDC64940
1659	Хвалынск	7	73	\N	48.069713	48.116847999999997	52.519984999999998	52.465800999999999	0103000020E61000000100000005000000938D075BEC084840D8B8FE5D9F3B4A40938D075BEC0848408DB454DE8E424A402F4D11E0F40E48408DB454DE8E424A402F4D11E0F40E4840D8B8FE5D9F3B4A40938D075BEC084840D8B8FE5D9F3B4A40
53189	Соколовый	7	73	\N	45.818832	45.851979	51.57835	51.559919999999998	0103000020E610000001000000050000008A75AA7CCFE846402B306475ABC749408A75AA7CCFE8464020D26F5F07CA49407CF0DAA50DED464020D26F5F07CA49407CF0DAA50DED46402B306475ABC749408A75AA7CCFE846402B306475ABC74940
29	Саратов	7	73	\N	45.808976999999999	46.199942	51.686087000000001	51.38897	0103000020E61000000100000005000000AC1BEF8E8CE746400490DAC4C9B14940AC1BEF8E8CE74640FA9AE5B2D1D74940658C0FB397194740FA9AE5B2D1D74940658C0FB3971947400490DAC4C9B14940AC1BEF8E8CE746400490DAC4C9B14940
23458	Ртищево	7	73	\N	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
53214	Расково	7	73	\N	45.977410999999996	46.050013	51.629449999999999	51.614839000000003	0103000020E6100000010000000500000015E0BBCD1BFD464016A75A0BB3CE494015E0BBCD1BFD4640CD3B4ED191D04940FBAF73D366064740CD3B4ED191D04940FBAF73D36606474016A75A0BB3CE494015E0BBCD1BFD464016A75A0BB3CE4940
2278	Пугачев	7	73	\N	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
19941	Петровск	7	73	\N	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
53190	Новоузенск	7	73	\N	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
2574	Маркс	7	73	\N	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
23	Красноармейск	7	73	\N	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
32022	Кокурино	7	73	\N	45.834417000000002	45.843516999999999	51.474983000000002	51.469310999999998	0103000020E61000000100000005000000FC1C1F2DCEEA46409753026212BC4940FC1C1F2DCEEA4640F793313ECCBC49405D4F745DF8EB4640F793313ECCBC49405D4F745DF8EB46409753026212BC4940FC1C1F2DCEEA46409753026212BC4940
53162	Калининск	7	73	\N	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
53183	ЗАТО Михайловский	7	73	\N	42.501936999999998	50.833129	52.818674000000001	49.801195999999997	0103000020E6100000010000000500000080D3BB783F404540CFD72C978DE6484080D3BB783F404540F20A444FCA684A40B22C98F8A36A4940F20A444FCA684A40B22C98F8A36A4940CFD72C978DE6484080D3BB783F404540CFD72C978DE64840
3738	Вольск	7	73	\N	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
53204	Водник	7	73	\N	45.905850999999998	45.929521999999999	51.423668999999997	51.414304999999999	0103000020E610000001000000050000004206F2ECF2F34640DEC83CF207B549404206F2ECF2F346401DAA29C93AB64940CD74AF93FAF646401DAA29C93AB64940CD74AF93FAF64640DEC83CF207B549404206F2ECF2F34640DEC83CF207B54940
4360	Балашов	7	73	\N	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
6127	Балаково	7	73	\N	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
6079	Аткарск	7	73	\N	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
53168	Аркадак	7	73	\N	43.463304999999998	43.553711999999997	51.951937999999998	51.907364999999999	0103000020E61000000100000005000000618907944DBB45407C444C8924F44940618907944DBB4540EAE8B81AD9F949408DB3E908E0C64540EAE8B81AD9F949408DB3E908E0C645407C444C8924F44940618907944DBB45407C444C8924F44940
53211	Александровка	7	73	\N	45.811033999999999	45.865580000000001	51.452711999999998	51.437139999999999	0103000020E61000000100000005000000D7F84CF6CFE7464000E31934F4B74940D7F84CF6CFE74640DD408177F2B949402D095053CBEE4640DD408177F2B949402D095053CBEE464000E31934F4B74940D7F84CF6CFE7464000E31934F4B74940
53188	ст. Анисовка	7	73	7271	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
53202	пос. Анисовский	7	73	288	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
53136	Энгельс	7	73	288	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
53192	Энгель-19	7	73	288	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
12723	Широкополье	7	73	288	46.625383999999997	46.658720000000002	51.287058000000002	51.274326000000002	0103000020E6100000010000000500000088B839950C504740A438471D1DA3494088B839950C50474010070951BEA449404E9CDCEF5054474010070951BEA449404E9CDCEF50544740A438471D1DA3494088B839950C504740A438471D1DA34940
12486	Шевченко	7	73	288	46.477880999999996	46.491022999999998	51.133513999999998	51.122017	0103000020E610000001000000050000009C3061342B3D47402C47C8409E8F49409C3061342B3D474071C79BFC16914940BA4A77D7D93E474071C79BFC16914940BA4A77D7D93E47402C47C8409E8F49409C3061342B3D47402C47C8409E8F4940
11564	Усть-Караман	7	73	288	46.544606999999999	46.561083000000004	51.664836000000001	51.656199000000001	0103000020E610000001000000050000001A16A3AEB54547407E552E54FED349401A16A3AEB54547400B9A965819D54940B9AB5791D14747400B9A965819D54940B9AB5791D14747407E552E54FED349401A16A3AEB54547407E552E54FED34940
11056	Узморье	7	73	288	45.905070000000002	45.931426000000002	51.263173000000002	51.240566999999999	0103000020E610000001000000050000009D4B7155D9F3464098BF42E6CA9E49409D4B7155D9F34640591822A7AFA14940725298F738F74640591822A7AFA14940725298F738F7464098BF42E6CA9E49409D4B7155D9F3464098BF42E6CA9E4940
12727	Титоренко	7	73	288	46.585382000000003	46.619311000000003	51.305683000000002	51.293050999999998	0103000020E6100000010000000500000063D520CCED4A4740B187F6B182A5494063D520CCED4A4740BAF8DB9E20A74940CB863595454F4740BAF8DB9E20A74940CB863595454F4740B187F6B182A5494063D520CCED4A4740B187F6B182A54940
10965	Терновка	7	73	288	45.953130000000002	45.978749999999998	51.311565999999999	51.295248000000001	0103000020E61000000100000005000000126BF12900FA4640CE1ABCAFCAA54940126BF12900FA4640D4450A65E1A74940E17A14AE47FD4640D4450A65E1A74940E17A14AE47FD4640CE1ABCAFCAA54940126BF12900FA4640CE1ABCAFCAA54940
11230	Степное	7	73	288	45.941937000000003	45.958511000000001	51.127890000000001	51.112772999999997	0103000020E6100000010000000500000039F2406491F84640976F7D586F8E494039F2406491F8464023BE13B35E9049409AED0A7DB0FA464023BE13B35E9049409AED0A7DB0FA4640976F7D586F8E494039F2406491F84640976F7D586F8E4940
11607	Старицкое	7	73	288	46.485928999999999	46.512466000000003	51.569398999999997	51.554124999999999	0103000020E61000000100000005000000C896E5EB323E4740B0726891EDC64940C896E5EB323E474003B00111E2C84940EE27637C9841474003B00111E2C84940EE27637C98414740B0726891EDC64940C896E5EB323E4740B0726891EDC64940
12009	Совхоза Имени Карла Маркса	7	73	288	46.214153000000003	46.236530000000002	51.379368999999997	51.366948999999998	0103000020E610000001000000050000008FAB915D691B47406326512FF8AE49408FAB915D691B4740E00ED4298FB04940EE42739D461E4740E00ED4298FB04940EE42739D461E47406326512FF8AE49408FAB915D691B47406326512FF8AE4940
11050	Смеловка	7	73	288	45.940347000000003	45.953318000000003	51.288612999999998	51.276946000000002	0103000020E6100000010000000500000024F25D4A5DF8464007616EF772A3494024F25D4A5DF84640A8195245F1A449401558005306FA4640A8195245F1A449401558005306FA464007616EF772A3494024F25D4A5DF8464007616EF772A34940
53220	Село Новая Терновка	7	73	288	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
11722	Пробуждение	7	73	288	46.144165000000001	46.160649999999997	51.439605	51.419747999999998	0103000020E610000001000000050000002A1DACFF73124740DC476E4DBAB549402A1DACFF731247403C1405FA44B849401B0DE02D901447403C1405FA44B849401B0DE02D90144740DC476E4DBAB549402A1DACFF73124740DC476E4DBAB54940
12407	Прилужный	7	73	288	46.475096000000001	46.488193000000003	51.245676000000003	51.233027999999997	0103000020E61000000100000005000000EF3A1BF2CF3C4740B1868BDCD39D4940EF3A1BF2CF3C4740C0B4A84F729F49406D91B41B7D3E4740C0B4A84F729F49406D91B41B7D3E4740B1868BDCD39D4940EF3A1BF2CF3C4740B1868BDCD39D4940
11850	Придорожный	7	73	288	46.285138000000003	46.311441000000002	51.398209000000001	51.383102000000001	0103000020E61000000100000005000000666CE8667F2447401F84807C09B14940666CE8667F24474087FC3383F8B2494018D1764CDD27474087FC3383F8B2494018D1764CDD2747401F84807C09B14940666CE8667F2447401F84807C09B14940
11463	Подстепное	7	73	288	46.461666000000001	46.488840000000003	51.670589999999997	51.656551	0103000020E610000001000000050000006BD619DF173B4740FB93F8DC09D449406BD619DF173B47402783A3E4D5D54940037D224F923E47402783A3E4D5D54940037D224F923E4740FB93F8DC09D449406BD619DF173B4740FB93F8DC09D44940
12257	Первомайское	7	73	288	46.506303000000003	46.527261000000003	51.351892999999997	51.337333000000001	0103000020E61000000100000005000000F06E6589CE404740486E4DBA2DAB4940F06E6589CE4047407D586FD40AAD494067BAD7497D4347407D586FD40AAD494067BAD7497D434740486E4DBA2DAB4940F06E6589CE404740486E4DBA2DAB4940
11670	Осиновка	7	73	288	46.549908000000002	46.568637000000003	51.549432000000003	51.529572999999999	0103000020E6100000010000000500000086E7A562634647401CEC4D0CC9C3494086E7A562634647401DB0ABC953C64940D525E318C94847401DB0ABC953C64940D525E318C94847401CEC4D0CC9C3494086E7A562634647401CEC4D0CC9C34940
12001	Новопушкинское	7	73	288	46.116605	46.143087000000001	51.397641	51.382736000000001	0103000020E6100000010000000500000069C6A2E9EC0E47403D80457EFDB0494069C6A2E9EC0E47403D4679E6E5B24940CBBDC0AC501247403D4679E6E5B24940CBBDC0AC501247403D80457EFDB0494069C6A2E9EC0E47403D80457EFDB04940
12578	Межевой	7	73	288	46.420864999999999	46.443987	51.274420999999997	51.263995999999999	0103000020E61000000100000005000000F98381E7DE3547402D23F59ECAA14940F98381E7DE354740F52A323A20A34940B16CE690D4384740F52A323A20A34940B16CE690D43847402D23F59ECAA14940F98381E7DE3547402D23F59ECAA14940
12095	Лощинный	7	73	288	46.273271000000001	46.298622000000002	51.366567000000003	51.356274999999997	0103000020E61000000100000005000000FDF84B8BFA224740F2B0506B9AAD4940FDF84B8BFA2247407C65DEAAEBAE4940DDEEE53E392647407C65DEAAEBAE4940DDEEE53E39264740F2B0506B9AAD4940FDF84B8BFA224740F2B0506B9AAD4940
11663	Липовка	7	73	288	46.606105999999997	46.622248999999996	51.536301999999999	51.517749000000002	0103000020E6100000010000000500000066F4A3E1944D4740B344679945C2494066F4A3E1944D4740C3633F8BA5C44940FE7BF0DAA54F4740C3633F8BA5C44940FE7BF0DAA54F4740B344679945C2494066F4A3E1944D4740B344679945C24940
11477	Ленинское	7	73	288	46.481805999999999	46.505279000000002	51.619548000000002	51.604810000000001	0103000020E610000001000000050000001F82AAD1AB3D47409A25016A6ACD49401F82AAD1AB3D4740AF264F594DCF4940842D76FBAC404740AF264F594DCF4940842D76FBAC4047409A25016A6ACD49401F82AAD1AB3D47409A25016A6ACD4940
11387	Красный Яр	7	73	288	46.397579999999998	46.448217999999997	51.639628999999999	51.618200000000002	0103000020E6100000010000000500000097C5C4E6E33247409031772D21CF494097C5C4E6E33247405E49F25CDFD1494040BD19355F3947405E49F25CDFD1494040BD19355F3947409031772D21CF494097C5C4E6E33247409031772D21CF4940
12333	Красный Партизан	7	73	288	46.457524999999997	46.478752	51.326557000000001	51.315057000000003	0103000020E610000001000000050000001B0DE02D903A47401DB0ABC953A849401B0DE02D903A4740D3A3A99ECCA949408272DBBE473D4740D3A3A99ECCA949408272DBBE473D47401DB0ABC953A849401B0DE02D903A47401DB0ABC953A84940
11144	Красноармейское	7	73	288	45.908105999999997	45.924249000000003	51.211778000000002	51.194158999999999	0103000020E6100000010000000500000093A641D13CF44640AE9CBD33DA98494093A641D13CF446409301A08A1B9B49402C2E8ECA4DF646409301A08A1B9B49402C2E8ECA4DF64640AE9CBD33DA98494093A641D13CF44640AE9CBD33DA984940
11774	Коминтерн	7	73	288	46.172130000000003	46.196196	51.439115999999999	51.420051999999998	0103000020E610000001000000050000008B54185B08164740484F9143C4B549408B54185B081647403E93FDF334B8494092CD55F31C1947403E93FDF334B8494092CD55F31C194740484F9143C4B549408B54185B08164740484F9143C4B54940
12598	Кирово	7	73	288	46.368124000000002	46.395288999999998	51.038888	51.016590999999998	0103000020E61000000100000005000000B56FEEAF1E2F4740373465A71F824940B56FEEAF1E2F47407A1A3048FA844940F9BB77D4983247407A1A3048FA844940F9BB77D498324740373465A71F824940B56FEEAF1E2F4740373465A71F824940
12488	Калинино	7	73	288	46.483305999999999	46.575474	51.099691999999997	51.075980999999999	0103000020E61000000100000005000000F4FA93F8DC3D4740060FD3BEB9894940F4FA93F8DC3D47401FD61BB5C28C494062D9CC21A94947401FD61BB5C28C494062D9CC21A9494740060FD3BEB9894940F4FA93F8DC3D4740060FD3BEB9894940
12349	Зеленый Дол	7	73	288	46.439801000000003	46.458979999999997	51.258353999999997	51.244588	0103000020E61000000100000005000000C2DF2F664B3847403D7FDAA84E9F4940C2DF2F664B38474038656EBE11A1494050C24CDBBF3A474038656EBE11A1494050C24CDBBF3A47403D7FDAA84E9F4940C2DF2F664B3847403D7FDAA84E9F4940
2511	Звонаревка	7	73	288	46.506734000000002	46.540511000000002	51.634827999999999	51.615588000000002	0103000020E61000000100000005000000B9E2E2A8DC404740B0E76B96CBCE4940B9E2E2A8DC404740E44A3D0B42D149406B10E6762F454740E44A3D0B42D149406B10E6762F454740B0E76B96CBCE4940B9E2E2A8DC404740B0E76B96CBCE4940
11855	Голубьевка	7	73	288	46.309176999999998	46.323827999999999	51.458077000000003	51.441727	0103000020E6100000010000000500000073D6A71C932747404E61A5828AB8494073D6A71C9327474060066344A2BA4940B9C326327329474060066344A2BA4940B9C32632732947404E61A5828AB8494073D6A71C932747404E61A5828AB84940
11331	Генеральское	7	73	288	46.323549999999997	46.357577999999997	51.602258999999997	51.583342000000002	0103000020E61000000100000005000000764F1E166A2947400E315EF3AACA4940764F1E166A2947405F5CAAD216CD494071E2AB1DC52D47405F5CAAD216CD494071E2AB1DC52D47400E315EF3AACA4940764F1E166A2947400E315EF3AACA4940
12642	Воскресенка	7	73	288	46.435453000000003	46.477314999999997	51.005710000000001	50.980176	0103000020E61000000100000005000000F9F884ECBC3747407C293C68767D4940F9F884ECBC3747404DA1F31ABB804940F3716DA8183D47404DA1F31ABB804940F3716DA8183D47407C293C68767D4940F9F884ECBC3747407C293C68767D4940
53232	Взлетный	7	73	288	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
12806	Бурный	7	73	288	46.398783999999999	46.418591999999997	51.286095000000003	51.274223999999997	0103000020E610000001000000050000008315A75A0B3347409FE3A3C519A349408315A75A0B3347404A46CEC29EA44940012F336C943547404A46CEC29EA44940012F336C943547409FE3A3C519A349408315A75A0B3347409FE3A3C519A34940
11183	Березовка	7	73	288	45.909345999999999	45.948926	51.190496000000003	51.172021999999998	0103000020E61000000100000005000000CC5F217365F44640A41820D104964940CC5F217365F446406902452C629849407C293C6876F946406902452C629849407C293C6876F94640A41820D104964940CC5F217365F44640A41820D104964940
12109	Безымянное	7	73	288	46.423065000000001	46.456086999999997	51.342796999999997	51.321519000000002	0103000020E61000000100000005000000878A71FE263647407505DB8827A94940878A71FE263647405D15A8C5E0AB4940BC900E0F613A47405D15A8C5E0AB4940BC900E0F613A47407505DB8827A94940878A71FE263647407505DB8827A94940
53243	станция Возрождения	7	73	626	47.492176999999998	48.427987999999999	52.818674000000001	52.230798999999998	0103000020E61000000100000005000000F46BEBA7FFBE4740897956D28A1D4A40F46BEBA7FFBE4740F20A444FCA684A404C8A8F4FC8364840F20A444FCA684A404C8A8F4FC8364840897956D28A1D4A40F46BEBA7FFBE4740897956D28A1D4A40
53150	Хвалынск	7	73	626	47.492176999999998	48.427987999999999	52.818674000000001	52.230798999999998	0103000020E61000000100000005000000F46BEBA7FFBE4740897956D28A1D4A40F46BEBA7FFBE4740F20A444FCA684A404C8A8F4FC8364840F20A444FCA684A404C8A8F4FC8364840897956D28A1D4A40F46BEBA7FFBE4740897956D28A1D4A40
7084	Ульянино	7	73	626	47.877411000000002	47.926450000000003	52.446719999999999	52.427076	0103000020E610000001000000050000004913EF004FF047400874266DAA364A404913EF004FF047400C3CF71E2E394A408AB0E1E995F647400C3CF71E2E394A408AB0E1E995F647400874266DAA364A404913EF004FF047400874266DAA364A40
7017	Старая Лебежайка	7	73	626	47.854278999999998	47.882361000000003	52.697589000000001	52.672609000000001	0103000020E610000001000000050000006D54A70359ED474065FF3C0D18564A406D54A70359ED47405186AA984A594A4008228B34F1F047405186AA984A594A4008228B34F1F0474065FF3C0D18564A406D54A70359ED474065FF3C0D18564A40
7030	Сосновая Маза	7	73	626	47.839053	47.902932	52.503039000000001	52.483387	0103000020E610000001000000050000002B4EB51666EB4740E1270EA0DF3D4A402B4EB51666EB474068CEFA9463404A408541994693F3474068CEFA9463404A408541994693F34740E1270EA0DF3D4A402B4EB51666EB4740E1270EA0DF3D4A40
6548	Селитьба	7	73	626	47.875920000000001	47.914628	52.370479000000003	52.332759000000003	0103000020E61000000100000005000000C7F484251EF047408F39CFD8972A4A40C7F484251EF047406A6D1ADB6B2F4A40C100C28712F547406A6D1ADB6B2F4A40C100C28712F547408F39CFD8972A4A40C7F484251EF047408F39CFD8972A4A40
6796	Северный	7	73	626	48.206823	48.234931000000003	52.732492000000001	52.711978000000002	0103000020E61000000100000005000000C287122D791A48405ABC5818225B4A40C287122D791A4840734A404CC25D4A4086E81038121E4840734A404CC25D4A4086E81038121E48405ABC5818225B4A40C287122D791A48405ABC5818225B4A40
6935	Поповка	7	73	626	47.829827000000002	47.847074999999997	52.609537000000003	52.593165999999997	0103000020E610000001000000050000003D2B69C537EA4740B08C0DDDEC4B4A403D2B69C537EA4740DA59F44E054E4A402D211FF46CEC4740DA59F44E054E4A402D211FF46CEC4740B08C0DDDEC4B4A403D2B69C537EA4740B08C0DDDEC4B4A40
4043	Ивановка	7	73	626	48.107343999999998	48.127529000000003	52.427185999999999	52.411918	0103000020E61000000100000005000000FEB5BC72BD0D48401E51A1BAB9344A40FEB5BC72BD0D48408FA7E507AE364A405325CADE521048408FA7E507AE364A405325CADE521048401E51A1BAB9344A40FEB5BC72BD0D48401E51A1BAB9344A40
6931	Елшанка	7	73	626	47.963918999999997	47.99783	52.597673999999998	52.567267000000001	0103000020E610000001000000050000001B7FA2B261FB4740CE8C7E349C484A401B7FA2B261FB4740B2D5E594804C4A40DD7BB8E4B8FF4740B2D5E594804C4A40DD7BB8E4B8FF4740CE8C7E349C484A401B7FA2B261FB4740CE8C7E349C484A40
7132	Елховка	7	73	626	47.792456999999999	47.813819000000002	52.536662999999997	52.521782999999999	0103000020E610000001000000050000003E3E213B6FE54740EC4D0CC9C9424A403E3E213B6FE5474093FC885FB1444A4085EE92382BE8474093FC885FB1444A4085EE92382BE84740EC4D0CC9C9424A403E3E213B6FE54740EC4D0CC9C9424A40
6878	Горюши	7	73	626	47.596345999999997	47.620564999999999	52.576937999999998	52.555540000000001	0103000020E61000000100000005000000DA8CD31055CC474057CF49EF1B474A40DA8CD31055CC4740EAE8B81AD9494A40680586AC6ECF4740EAE8B81AD9494A40680586AC6ECF474057CF49EF1B474A40DA8CD31055CC474057CF49EF1B474A40
6705	Возрождение	7	73	626	48.147461999999997	48.226649000000002	52.720776999999998	52.682360000000003	0103000020E610000001000000050000008DB3E908E01248409E0C8E9257574A408DB3E908E0124840C05AB56B425C4A40E7559DD5021D4840C05AB56B425C4A40E7559DD5021D48409E0C8E9257574A408DB3E908E01248409E0C8E9257574A40
6552	Благодатное	7	73	626	48.085729999999998	48.117674000000001	52.700989	52.687753999999998	0103000020E610000001000000050000009E245D33F90A4840BAD8B45208584A409E245D33F90A484089EDEE01BA594A4075CB0EF10F0F484089EDEE01BA594A4075CB0EF10F0F4840BAD8B45208584A409E245D33F90A4840BAD8B45208584A40
6795	Апалиха	7	73	626	47.698368000000002	47.735737999999998	52.324888999999999	52.297562999999997	0103000020E610000001000000050000005649641F64D94740F4BF5C8B16264A405649641F64D9474042EA76F695294A405436ACA92CDE474042EA76F695294A405436ACA92CDE4740F4BF5C8B16264A405649641F64D94740F4BF5C8B16264A40
6497	Алексеевка	7	73	626	48.004953999999998	48.049663000000002	52.331564999999998	52.285786999999999	0103000020E6100000010000000500000000FE2955A20048409C4F1DAB94244A4000FE2955A2004840C6BFCFB8702A4A401F69705B5B064840C6BFCFB8702A4A401F69705B5B0648409C4F1DAB94244A4000FE2955A20048409C4F1DAB94244A40
7221	Акатная Маза	7	73	626	47.644342999999999	47.679834999999997	52.460095000000003	52.447482999999998	0103000020E610000001000000050000000934D8D479D247400B42791F47394A400934D8D479D24740CD069964E43A4A408CD651D504D74740CD069964E43A4A408CD651D504D747400B42791F47394A400934D8D479D247400B42791F47394A40
1454	Федоровка	7	73	218	47.493696	47.520958999999998	51.371318000000002	51.347056000000002	0103000020E610000001000000050000004015376E31BF4740B7F0BC546CAC49404015376E31BF47404435255987AF494047C7D5C8AEC247404435255987AF494047C7D5C8AEC24740B7F0BC546CAC49404015376E31BF4740B7F0BC546CAC4940
1580	Тамбовка	7	73	218	47.112234999999998	47.149918999999997	51.370733000000001	51.353220999999998	0103000020E61000000100000005000000B83B6BB75D8E474055A1815836AD4940B83B6BB75D8E47402446CF2D74AF49404606B98B309347402446CF2D74AF49404606B98B3093474055A1815836AD4940B83B6BB75D8E474055A1815836AD4940
5870	Спартак	7	73	218	47.774931000000002	47.796221000000003	51.385800000000003	51.367652	0103000020E610000001000000050000000BD462F030E347408D2782380FAF49400BD462F030E34740FE65F7E461B14940B8B1D991EAE54740FE65F7E461B14940B8B1D991EAE547408D2782380FAF49400BD462F030E347408D2782380FAF4940
53159	Солнечный	7	73	218	47.927672000000001	47.948531000000003	51.180903999999998	51.170102	0103000020E610000001000000050000001CB5C2F4BDF64740FA7DFFE6C59549401CB5C2F4BDF6474098DBBDDC27974940001FBC7669F9474098DBBDDC27974940001FBC7669F94740FA7DFFE6C59549401CB5C2F4BDF64740FA7DFFE6C5954940
5430	Семеновка	7	73	218	47.591082	47.619675000000001	51.192273999999998	51.172879999999999	0103000020E610000001000000050000008CA03193A8CB4740F5108DEE209649408CA03193A8CB474080EF366F9C9849400C93A98251CF474080EF366F9C9849400C93A98251CF4740F5108DEE209649408CA03193A8CB4740F5108DEE20964940
6195	Романовка	7	73	218	47.358544000000002	47.390343999999999	51.395252999999997	51.372280000000003	0103000020E61000000100000005000000A91611C5E4AD47403A7AFCDEA6AF4940A91611C5E4AD4740AC527AA697B249404C18CDCAF6B14740AC527AA697B249404C18CDCAF6B147403A7AFCDEA6AF4940A91611C5E4AD47403A7AFCDEA6AF4940
5865	Плес	7	73	218	47.766675999999997	47.789053000000003	51.297747999999999	51.287711000000002	0103000020E6100000010000000500000065506D7022E2474088D9CBB6D3A4494065506D7022E247408639419B1CA64940C5E74EB0FFE447408639419B1CA64940C5E74EB0FFE4474088D9CBB6D3A4494065506D7022E2474088D9CBB6D3A44940
5977	Первомайское	7	73	218	47.593831000000002	47.637614999999997	51.470809000000003	51.453924000000001	0103000020E61000000100000005000000ED2C7AA702CC47404C6F7F2E1ABA4940ED2C7AA702CC4740CCD4247843BC494032384A5E9DD14740CCD4247843BC494032384A5E9DD147404C6F7F2E1ABA4940ED2C7AA702CC47404C6F7F2E1ABA4940
5489	Николаевка	7	73	218	47.666549000000003	47.689124	51.196095	51.184415999999999	0103000020E610000001000000050000003C17467A51D54740F86D88F19A9749403C17467A51D547405EF415A419994940C171193735D847405EF415A419994940C171193735D84740F86D88F19A9749403C17467A51D54740F86D88F19A974940
5928	Мунино	7	73	218	47.894623000000003	47.918346999999997	51.319375000000001	51.307406	0103000020E61000000100000005000000ED9FA70183F247400E4C6E1459A74940ED9FA70183F247407B14AE47E1A849409AB0FD648CF547407B14AE47E1A849409AB0FD648CF547400E4C6E1459A74940ED9FA70183F247400E4C6E1459A74940
5666	Морцы	7	73	218	47.831085000000002	47.853667999999999	51.301031000000002	51.277301000000001	0103000020E610000001000000050000001C9947FE60EA4740F51263997EA349401C9947FE60EA4740850A0E2F88A6494024D236FE44ED4740850A0E2F88A6494024D236FE44ED4740F51263997EA349401C9947FE60EA4740F51263997EA34940
829	Мокроус	7	73	218	47.483625000000004	47.531711999999999	51.250912999999997	51.225763000000001	0103000020E6100000010000000500000096438B6CE7BD4740CCD24ECDE59C494096438B6CE7BD47401492CCEA1DA04940047289230FC447401492CCEA1DA04940047289230FC44740CCD24ECDE59C494096438B6CE7BD4740CCD24ECDE59C4940
1352	Митрофановка	7	73	218	47.536760999999998	47.567042999999998	51.164816000000002	51.153151000000001	0103000020E6100000010000000500000056629E95B4C44740C32CB4739A93494056629E95B4C44740C4EDD0B0189549407E3672DD94C84740C4EDD0B0189549407E3672DD94C84740C32CB4739A93494056629E95B4C44740C32CB4739A934940
6282	Калуга	7	73	218	47.158498000000002	47.180624000000002	51.379223000000003	51.362703000000003	0103000020E610000001000000050000009F3D97A9499447409F94490D6DAE49409F3D97A9499447400D7217618AB04940B56FEEAF1E9747400D7217618AB04940B56FEEAF1E9747409F94490D6DAE49409F3D97A9499447409F94490D6DAE4940
5598	Калдино	7	73	218	47.719298000000002	47.747397999999997	51.230817000000002	51.217030999999999	0103000020E61000000100000005000000030AF5F411DC4740ED9BFBABC79B4940030AF5F411DC4740302E55698B9D4940438CD7BCAADF4740302E55698B9D4940438CD7BCAADF4740ED9BFBABC79B4940030AF5F411DC4740ED9BFBABC79B4940
887	Ивановка	7	73	218	47.491898999999997	47.522478	51.168086000000002	51.158014999999999	0103000020E61000000100000005000000B1F7E28BF6BE474083A3E4D539944940B1F7E28BF6BE47402E7590D7839549409370218FE0C247402E7590D7839549409370218FE0C2474083A3E4D539944940B1F7E28BF6BE474083A3E4D539944940
6338	Еруслан	7	73	218	47.308041000000003	47.337856000000002	51.239626000000001	51.223709999999997	0103000020E61000000100000005000000E06932E36DA74740E2E47E87A29C4940E06932E36DA74740BAA29410AC9E4940F2608BDD3EAB4740BAA29410AC9E4940F2608BDD3EAB4740E2E47E87A29C4940E06932E36DA74740E2E47E87A29C4940
6399	Долина	7	73	218	47.403602999999997	47.432744999999997	51.152416000000002	51.12923	0103000020E61000000100000005000000A3C85A43A9B34740BFD4CF9B8A904940A3C85A43A9B347408EB1135E82934940F6402B3064B747408EB1135E82934940F6402B3064B74740BFD4CF9B8A904940A3C85A43A9B34740BFD4CF9B8A904940
6124	Воскресенка	7	73	218	47.491107999999997	47.513809000000002	51.398809999999997	51.384613999999999	0103000020E61000000100000005000000E8667FA0DCBE4740B8CA13083BB14940E8667FA0DCBE4740ACA8C1340CB34940FBB1497EC4C14740ACA8C1340CB34940FBB1497EC4C14740B8CA13083BB14940E8667FA0DCBE4740B8CA13083BB14940
1417	Борисоглебовка	7	73	218	47.741351999999999	47.776755000000001	51.029502999999998	51.005994000000001	0103000020E610000001000000050000007F69519FE4DE474072FC5069C48049407F69519FE4DE474023111AC1C6834940930035B56CE3474023111AC1C6834940930035B56CE3474072FC5069C48049407F69519FE4DE474072FC5069C4804940
758	Шепелевка	7	73	201	43.201760999999998	43.244439999999997	51.93506	51.908042999999999	0103000020E61000000100000005000000DB4DF04DD39945404D2EC6C03AF44940DB4DF04DD39945401DE6CB0BB0F74940C8EA56CF499F45401DE6CB0BB0F74940C8EA56CF499F45404D2EC6C03AF44940DB4DF04DD39945404D2EC6C03AF44940
4962	Чернавка	7	73	201	43.021926999999998	43.061031	51.966872000000002	51.939680000000003	0103000020E610000001000000050000001FF30181CE824540475A2A6F47F849401FF30181CE82454085B53176C2FB4940668522DDCF87454085B53176C2FB4940668522DDCF874540475A2A6F47F849401FF30181CE824540475A2A6F47F84940
4153	Турки	7	73	201	43.247683000000002	43.295904	52.007719999999999	51.959946000000002	0103000020E6100000010000000500000039639813B49F454088F6B182DFFA494039639813B49F454037C30DF8FC004A40B760A92EE0A5454037C30DF8FC004A40B760A92EE0A5454088F6B182DFFA494039639813B49F454088F6B182DFFA4940
4362	Трубетчино	7	73	201	43.263457000000002	43.297682999999999	52.053891999999998	52.021045999999998	0103000020E610000001000000050000007E737FF5B8A1454016DBA4A2B1024A407E737FF5B8A145400DC2DCEEE5064A409FC9FE791AA645400DC2DCEEE5064A409FC9FE791AA6454016DBA4A2B1024A407E737FF5B8A1454016DBA4A2B1024A40
4958	Студенка	7	73	201	43.079805	43.112253000000003	52.1188	52.099938999999999	0103000020E610000001000000050000005587DC0C378A4540274C18CDCA0C4A405587DC0C378A4540E561A1D6340F4A405FF0694E5E8E4540E561A1D6340F4A405FF0694E5E8E4540274C18CDCA0C4A405587DC0C378A4540274C18CDCA0C4A40
4911	Рязанка	7	73	201	42.936433999999998	42.975330999999997	52.126868000000002	52.107689000000001	0103000020E61000000100000005000000656EBE11DD774540C991CEC0C80D4A40656EBE11DD7745405874EB353D104A4032E36DA5D77C45405874EB353D104A4032E36DA5D77C4540C991CEC0C80D4A40656EBE11DD774540C991CEC0C80D4A40
4852	Перевесино-Михайловка	7	73	201	42.939515	43.016573000000001	52.238742000000002	52.222889000000002	0103000020E61000000100000005000000FC8C0B0742784540AFD172A0871C4A40FC8C0B074278454040170D198F1E4A40917F66101F82454040170D198F1E4A40917F66101F824540AFD172A0871C4A40FC8C0B0742784540AFD172A0871C4A40
4710	Перевесинка	7	73	201	43.242113000000003	43.272520999999998	52.229078000000001	52.194749000000002	0103000020E61000000100000005000000DE770C8FFD9E4540E0F60489ED184A40DE770C8FFD9E4540D61D8B6D521D4A40923CD7F7E1A24540D61D8B6D521D4A40923CD7F7E1A24540E0F60489ED184A40DE770C8FFD9E4540E0F60489ED184A40
4702	Марьино	7	73	201	42.768673999999997	42.788778000000001	52.127370999999997	52.111007999999998	0103000020E610000001000000050000008BA4DDE86362454014CC9882350E4A408BA4DDE863624540BABA63B14D104A40F3E670ADF6644540BABA63B14D104A40F3E670ADF664454014CC9882350E4A408BA4DDE86362454014CC9882350E4A40
4594	Лунино	7	73	201	42.857643000000003	42.878906000000001	52.046475999999998	52.030825999999998	0103000020E610000001000000050000005952EE3EC76D4540E9EE3A1BF2034A405952EE3EC76D45404206F2ECF2054A400C21E7FD7F7045404206F2ECF2054A400C21E7FD7F704540E9EE3A1BF2034A405952EE3EC76D4540E9EE3A1BF2034A40
4587	Каменка	7	73	201	43.161669000000003	43.188223000000001	52.020591000000003	52.007277000000002	0103000020E6100000010000000500000076E3DD91B1944540AA81E673EE004A4076E3DD91B1944540C5CBD3B9A2024A4071ADF6B017984540C5CBD3B9A2024A4071ADF6B017984540AA81E673EE004A4076E3DD91B1944540AA81E673EE004A40
4522	Дмитриевка	7	73	201	43.043891000000002	43.066716999999997	52.235630999999998	52.223474000000003	0103000020E610000001000000050000005CCB64389E854540CFC0C8CB9A1C4A405CCB64389E8545403E761728291E4A402A8BC22E8A8845403E761728291E4A402A8BC22E8A884540CFC0C8CB9A1C4A405CCB64389E854540CFC0C8CB9A1C4A40
4435	Бороно-Михайловка	7	73	201	43.167337000000003	43.194232999999997	52.157167000000001	52.137580999999997	0103000020E6100000010000000500000094347F4C6B95454086C613419C114A4094347F4C6B95454056815A0C1E144A40E8667FA0DC98454056815A0C1E144A40E8667FA0DC98454086C613419C114A4094347F4C6B95454086C613419C114A40
3983	Ягодная Поляна	7	73	219	45.583410000000001	45.623583000000004	51.979182999999999	51.964081	0103000020E610000001000000050000006614CB2DADCA4640F5D8960167FB49406614CB2DADCA46404BE658DE55FD4940B9AB5791D1CF46404BE658DE55FD4940B9AB5791D1CF4640F5D8960167FB49406614CB2DADCA4640F5D8960167FB4940
3892	Широкое	7	73	219	45.765391000000001	45.789707999999997	51.713869000000003	51.696846000000001	0103000020E610000001000000050000008DD31055F8E14640992CEE3F32D949408DD31055F8E146406A50340F60DB4940DDB1D82615E546406A50340F60DB4940DDB1D82615E54640992CEE3F32D949408DD31055F8E14640992CEE3F32D94940
3794	Татищево	7	73	219	45.568416999999997	45.643552	51.697342999999996	51.658696999999997	0103000020E61000000100000005000000C6BE64E3C1C84640957CEC2E50D44940C6BE64E3C1C84640198C118942D9494040A374E95FD24640198C118942D9494040A374E95FD24640957CEC2E50D44940C6BE64E3C1C84640957CEC2E50D44940
53184	Сторожевка	7	73	219	44.908901	46.040562999999999	52.061445999999997	51.544210999999997	0103000020E610000001000000050000009E2633DE56744640CD8FBFB4A8C549409E2633DE56744640293C6876DD074A40BD361B2B31054740293C6876DD074A40BD361B2B31054740CD8FBFB4A8C549409E2633DE56744640CD8FBFB4A8C54940
3275	Сокур	7	73	219	45.776511999999997	45.801225000000002	52.023888999999997	51.982495	0103000020E61000000100000005000000CC79C6BE64E34640E4BD6A65C2FD4940CC79C6BE64E34640F8DD74CB0E034A406ADE718A8EE64640F8DD74CB0E034A406ADE718A8EE64640E4BD6A65C2FD4940CC79C6BE64E34640E4BD6A65C2FD4940
2922	Слепцовка	7	73	219	45.455939000000001	45.499093999999999	51.754525000000001	51.737985999999999	0103000020E6100000010000000500000048FC8A355CBA4640F373435376DE494048FC8A355CBA4640D881734694E049409ED0EB4FE2BF4640D881734694E049409ED0EB4FE2BF4640F373435376DE494048FC8A355CBA4640F373435376DE4940
3439	Садовый	7	73	219	45.305506999999999	45.322035999999997	51.765897000000002	51.755845999999998	0103000020E610000001000000050000007BD976DA1AA74640FD67CD8FBFE049407BD976DA1AA74640618DB3E908E249403C11C47938A94640618DB3E908E249403C11C47938A94640FD67CD8FBFE049407BD976DA1AA74640FD67CD8FBFE04940
3497	Полянское	7	73	219	45.307716999999997	45.319045000000003	51.789456999999999	51.776513999999999	0103000020E610000001000000050000002CB6494563A746406D718DCF64E349402CB6494563A74640944C4EED0CE54940E6797077D6A84640944C4EED0CE54940E6797077D6A846406D718DCF64E349402CB6494563A746406D718DCF64E34940
2616	Полчаниновка	7	73	219	45.586410000000001	45.612264000000003	51.868510999999998	51.852685999999999	0103000020E6100000010000000500000010069E7B0FCB4640E7E099D024ED494010069E7B0FCB4640AE9B525E2BEF49405342B0AA5ECE4640AE9B525E2BEF49405342B0AA5ECE4640E7E099D024ED494010069E7B0FCB4640E7E099D024ED4940
3315	Октябрьский Городок	7	73	219	45.435169999999999	45.473959000000001	51.643613999999999	51.631759000000002	0103000020E61000000100000005000000A4198BA6B3B7464012FA997ADDD04940A4198BA6B3B74640B69F8CF161D249408B5242B0AABC4640B69F8CF161D249408B5242B0AABC464012FA997ADDD04940A4198BA6B3B7464012FA997ADDD04940
2731	Нееловка	7	73	219	45.842196999999999	45.867941999999999	51.798425000000002	51.780754000000002	0103000020E6100000010000000500000008E57D1CCDEB4640501C40BFEFE3494008E57D1CCDEB464087A757CA32E64940946934B918EF464087A757CA32E64940946934B918EF4640501C40BFEFE3494008E57D1CCDEB4640501C40BFEFE34940
3150	Мизино-Лапшиновка	7	73	219	45.787759000000001	45.835576000000003	51.858972000000001	51.836289000000001	0103000020E6100000010000000500000099107349D5E44640958098840BEB494099107349D5E44640011764CBF2ED494048A98427F4EA4640011764CBF2ED494048A98427F4EA4640958098840BEB494099107349D5E44640958098840BEB4940
832	Малая Скатовка	7	73	219	45.865606999999997	45.885854999999999	51.717429000000003	51.705894000000001	0103000020E610000001000000050000002618CE35CCEE4640A8380EBC5ADA49402618CE35CCEE4640DB19A6B6D4DB4940C1FF56B263F14640DB19A6B6D4DB4940C1FF56B263F14640A8380EBC5ADA49402618CE35CCEE4640A8380EBC5ADA4940
2851	Македоновка	7	73	219	45.499093999999999	45.511994000000001	51.799109999999999	51.784187000000003	0103000020E610000001000000050000009ED0EB4FE2BF46406479573D60E449409ED0EB4FE2BF46400AF4893C49E64940C6DFF60489C146400AF4893C49E64940C6DFF60489C146406479573D60E449409ED0EB4FE2BF46406479573D60E44940
3706	Курдюм	7	73	219	45.681677000000001	45.777769999999997	51.653036	51.600468999999997	0103000020E61000000100000005000000BBB7223141D7464083A10E2BDCCC4940BBB7223141D746402A8E03AF96D34940ABE7A4F78DE346402A8E03AF96D34940ABE7A4F78DE3464083A10E2BDCCC4940BBB7223141D7464083A10E2BDCCC4940
3074	Куликовка	7	73	219	45.280318999999999	45.297072	51.592374	51.576016000000003	0103000020E6100000010000000500000045B9347EE1A3464083FC6CE4BAC9494045B9347EE1A34640178046E9D2CB494056478E7406A64640178046E9D2CB494056478E7406A6464083FC6CE4BAC9494045B9347EE1A3464083FC6CE4BAC94940
3381	Кувыка	7	73	219	45.484065000000001	45.524202000000002	51.635717	51.627090000000003	0103000020E61000000100000005000000B21188D7F5BD464007D3307C44D04940B21188D7F5BD46407041B62C5FD14940B83F170D19C346407041B62C5FD14940B83F170D19C3464007D3307C44D04940B21188D7F5BD464007D3307C44D04940
3214	Корсаковка	7	73	219	45.742573999999998	45.773322999999998	51.885891000000001	51.864629000000001	0103000020E61000000100000005000000116E32AA0CDF46402B16BF29ACEE4940116E32AA0CDF46400E6954E064F149404F1F813FFCE246400E6954E064F149404F1F813FFCE246402B16BF29ACEE4940116E32AA0CDF46402B16BF29ACEE4940
3041	Карякино	7	73	219	45.276859999999999	45.297978999999998	51.699145999999999	51.685903000000003	0103000020E6100000010000000500000008C9022670A34640399D64ABCBD7494008C9022670A346408A90BA9D7DD9494088F2052D24A646408A90BA9D7DD9494088F2052D24A64640399D64ABCBD7494008C9022670A34640399D64ABCBD74940
2970	Карамышка	7	73	219	45.345033000000001	45.370482000000003	51.653064000000001	51.642620000000001	0103000020E610000001000000050000003885950A2AAC4640B5E0455F41D249403885950A2AAC4640F418E59997D34940DBE044F46BAF4640F418E59997D34940DBE044F46BAF4640B5E0455F41D249403885950A2AAC4640B5E0455F41D24940
3648	Ильиновка	7	73	219	45.683033000000002	45.703271999999998	51.664673999999998	51.652098000000002	0103000020E610000001000000050000005D8B16A06DD74640BDE47FF277D349405D8B16A06DD746403140A20914D54940A41820D104DA46403140A20914D54940A41820D104DA4640BDE47FF277D349405D8B16A06DD74640BDE47FF277D34940
2802	Идолга	7	73	219	45.620626999999999	45.647163999999997	51.723008	51.701233000000002	0103000020E61000000100000005000000DE019EB470CF464020F0C000C2D94940DE019EB470CF4640895FB1868BDC494003931B45D6D24640895FB1868BDC494003931B45D6D2464020F0C000C2D94940DE019EB470CF464020F0C000C2D94940
53171	ЗАТО Светлый	7	73	219	44.908901	46.040562999999999	52.061445999999997	51.544210999999997	0103000020E610000001000000050000009E2633DE56744640CD8FBFB4A8C549409E2633DE56744640293C6876DD074A40BD361B2B31054740293C6876DD074A40BD361B2B31054740CD8FBFB4A8C549409E2633DE56744640CD8FBFB4A8C54940
2696	Вязовка	7	73	219	45.758752000000001	45.805149999999998	51.814490999999997	51.791629999999998	0103000020E6100000010000000500000026E318C91EE146402844C02154E5494026E318C91EE1464073F1B73D41E84940EC2FBB270FE7464073F1B73D41E84940EC2FBB270FE746402844C02154E5494026E318C91EE146402844C02154E54940
4102	Большая Федоровка	7	73	219	45.482250999999998	45.515622999999998	51.854111000000003	51.836672999999998	0103000020E610000001000000050000004DBB9866BABD46401D39D21918EB49404DBB9866BABD4640B2135E8253ED49405F0839EFFFC14640B2135E8253ED49405F0839EFFFC146401D39D21918EB49404DBB9866BABD46401D39D21918EB4940
3928	Большая Каменка	7	73	219	45.730922	45.753542000000003	51.76923	51.750889999999998	0103000020E61000000100000005000000A5F622DA8EDD46405C72DC291DE04940A5F622DA8EDD4640118DEE2076E24940CB14731074E04640118DEE2076E24940CB14731074E046405C72DC291DE04940A5F622DA8EDD46405C72DC291DE04940
2575	Большая Ивановка	7	73	219	45.605437000000002	45.631245	51.819178999999998	51.802824999999999	0103000020E61000000100000005000000E964A9F57ECD4640A2B437F8C2E64940E964A9F57ECD4640F54883DBDAE84940BB61DBA2CCD04640F54883DBDAE84940BB61DBA2CCD04640A2B437F8C2E64940E964A9F57ECD4640A2B437F8C2E64940
1523	Степное	7	73	327	46.825358000000001	46.862305999999997	51.398629999999997	51.362450000000003	0103000020E61000000100000005000000F9BEB854A5694740B537F8C264AE4940F9BEB854A56947402C9ACE4E06B349408192020B606E47402C9ACE4E06B349408192020B606E4740B537F8C264AE4940F9BEB854A5694740B537F8C264AE4940
1869	Советское	7	73	327	46.718674	46.752585000000003	51.455624999999998	51.430289999999999	0103000020E61000000100000005000000253E7782FD5B4740DEE522BE13B74940253E7782FD5B4740B81E85EB51BA4940E73A8DB454604740B81E85EB51BA4940E73A8DB454604740DEE522BE13B74940253E7782FD5B4740DEE522BE13B74940
2158	Розовое	7	73	327	46.750196000000003	46.806080000000001	51.241802	51.210965999999999	0103000020E6100000010000000500000086CB2A6C06604740B24813EF009B494086CB2A6C06604740BF0D315EF39E4940D7FA22A12D674740BF0D315EF39E4940D7FA22A12D674740B24813EF009B494086CB2A6C06604740B24813EF009B4940
1913	Пушкино	7	73	327	46.959378000000001	46.98657	51.24492	51.218114	0103000020E610000001000000050000003E40F7E5CC7A47405E66D828EB9B49403E40F7E5CC7A47407311DF89599F49407C9BFEEC477E47407311DF89599F49407C9BFEEC477E47405E66D828EB9B49403E40F7E5CC7A47405E66D828EB9B4940
2280	Пионерское	7	73	327	46.855316999999999	46.88223	51.301819999999999	51.287796	0103000020E610000001000000050000003E5B07077B6D4740B6F5D37FD6A449403E5B07077B6D4740ADA3AA09A2A6494069C6A2E9EC704740ADA3AA09A2A6494069C6A2E9EC704740B6F5D37FD6A449403E5B07077B6D4740B6F5D37FD6A44940
2517	Новолиповка	7	73	327	46.952272000000001	46.975735999999998	51.358604	51.345548000000001	0103000020E61000000100000005000000C172840CE47947405F99B7EA3AAC4940C172840CE47947407E1B62BCE6AD4940D2C3D0EAE47C47407E1B62BCE6AD4940D2C3D0EAE47C47405F99B7EA3AAC4940C172840CE47947405F99B7EA3AAC4940
2459	Новокривовка	7	73	327	47.010528000000001	47.042938999999997	51.291040000000002	51.277565000000003	0103000020E610000001000000050000009DD843FB58814740D3C1FA3F87A349409DD843FB58814740F7E978CC40A54940895C70067F854740F7E978CC40A54940895C70067F854740D3C1FA3F87A349409DD843FB58814740D3C1FA3F87A34940
1998	Новоантоновка	7	73	327	46.938167999999997	46.955641	51.266390999999999	51.258274999999998	0103000020E61000000100000005000000AD1397E315784740EC2FBB270FA14940AD1397E3157847407079AC1919A24940BEDBBC71527A47407079AC1919A24940BEDBBC71527A4740EC2FBB270FA14940AD1397E315784740EC2FBB270FA14940
2356	Мечетное	7	73	327	47.005012000000001	47.019061999999998	51.448462999999997	51.423819999999999	0103000020E61000000100000005000000350BB43BA480474003B2D7BB3FB64940350BB43BA4804740A73B4F3C67B94940554CA59F70824740A73B4F3C67B94940554CA59F7082474003B2D7BB3FB64940350BB43BA480474003B2D7BB3FB64940
2394	Любимово	7	73	327	47.083058000000001	47.106422999999999	51.445892000000001	51.432276999999999	0103000020E61000000100000005000000E9D500A5A18A474010E84CDA54B74940E9D500A5A18A474026C632FD12B949406745D4449F8D474026C632FD12B949406745D4449F8D474010E84CDA54B74940E9D500A5A18A474010E84CDA54B74940
2052	Золотая Степь	7	73	327	46.775151000000001	46.800403000000003	51.286015999999996	51.274354000000002	0103000020E61000000100000005000000193BE125386347406EC328081EA34940193BE12538634740FD101B2C9CA44940664F029B73664740FD101B2C9CA44940664F029B736647406EC328081EA34940193BE125386347406EC328081EA34940
2121	Александровка	7	73	327	46.832455000000003	46.860247999999999	51.272275	51.255000000000003	0103000020E610000001000000050000002332ACE28D6A4740713D0AD7A3A049402332ACE28D6A47405B423EE8D9A249408639419B1C6E47405B423EE8D9A249408639419B1C6E4740713D0AD7A3A049402332ACE28D6A4740713D0AD7A3A04940
53186	Зоринский	7	73	7270	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
53194	с. Свинцовка	7	73	25	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
583	Юрловка	7	73	25	45.429178	45.441836000000002	51.450730999999998	51.436169	0103000020E61000000100000005000000D314014EEFB64640B743C362D4B74940D314014EEFB646408D25AC8DB1B94940051901158EB846408D25AC8DB1B94940051901158EB84640B743C362D4B74940D314014EEFB64640B743C362D4B74940
32195	Шевыревка	7	73	25	46.165554	46.187617000000003	51.813918000000001	51.799878999999997	0103000020E610000001000000050000006ADC9BDF30154740EBE0606F62E649406ADC9BDF3015474018D00B772EE849403A9677D50318474018D00B772EE849403A9677D503184740EBE0606F62E649406ADC9BDF30154740EBE0606F62E64940
1420	Усть-Курдюм	7	73	25	46.178480999999998	46.218187	51.661138000000001	51.640512000000001	0103000020E610000001000000050000008BFA2477D81647400859164CFCD149408BFA2477D81647404912842BA0D44940C8B4368DED1B47404912842BA0D44940C8B4368DED1B47400859164CFCD149408BFA2477D81647400859164CFCD14940
516	Сосновка	7	73	25	45.522675	45.548268	51.458835000000001	51.439605	0103000020E61000000100000005000000E9B7AF03E7C246403C1405FA44B84940E9B7AF03E7C246404DA1F31ABBBA4940BFB854A52DC646404DA1F31ABBBA4940BFB854A52DC646403C1405FA44B84940E9B7AF03E7C246403C1405FA44B84940
32191	Совхоза Хмелевский	7	73	25	45.804288	45.837893999999999	51.388936000000001	51.373629000000001	0103000020E610000001000000050000005A48C0E8F2E6464029EB3713D3AF49405A48C0E8F2E64640581EA4A7C8B14940DFC14F1C40EB4640581EA4A7C8B14940DFC14F1C40EB464029EB3713D3AF49405A48C0E8F2E6464029EB3713D3AF4940
53237	Совхоза 15 Лет Октября	7	73	25	45.804288	45.837893999999999	51.388936000000001	51.373629000000001	0103000020E610000001000000050000005A48C0E8F2E6464029EB3713D3AF49405A48C0E8F2E64640581EA4A7C8B14940DFC14F1C40EB4640581EA4A7C8B14940DFC14F1C40EB464029EB3713D3AF49405A48C0E8F2E6464029EB3713D3AF4940
1195	Синенькие	7	73	25	45.753191999999999	45.779836000000003	51.245229999999999	51.229067999999998	0103000020E61000000100000005000000EECD6F9868E04640B247A819529D4940EECD6F9868E04640C1FF56B2639F49402A1F82AAD1E34640C1FF56B2639F49402A1F82AAD1E34640B247A819529D4940EECD6F9868E04640B247A819529D4940
1236	Сергиевский	7	73	25	45.637146999999999	45.665470999999997	51.299821000000001	51.280923000000001	0103000020E610000001000000050000004CDF6B088ED14640DCD8EC48F5A349404CDF6B088ED14640B7D3D68860A64940DCB75A272ED54640B7D3D68860A64940DCB75A272ED54640DCD8EC48F5A349404CDF6B088ED14640DCD8EC48F5A34940
32287	Сабуровка	7	73	25	46.185200000000002	46.208305000000003	51.700837	51.681659000000003	0103000020E610000001000000050000000F9C33A2B41747401503249A40D749400F9C33A2B4174740D369DD06B5D94940F14BFDBCA91A4740D369DD06B5D94940F14BFDBCA91A47401503249A40D749400F9C33A2B41747401503249A40D74940
955	Рыбушка	7	73	25	45.438322999999997	45.456657999999997	51.295591000000002	51.267547	0103000020E61000000100000005000000D40AD3F71AB846404B92E7FA3EA24940D40AD3F71AB84640F8FE06EDD5A5494077BAF3C473BA4640F8FE06EDD5A5494077BAF3C473BA46404B92E7FA3EA24940D40AD3F71AB846404B92E7FA3EA24940
53167	Пристанное	7	73	25	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
1125	Поповка	7	73	25	45.567770000000003	45.595627	51.428234000000003	51.412064000000001	0103000020E6100000010000000500000031D3F6AFACC84640F2ED5D83BEB4494031D3F6AFACC846408484285FD0B64940ABCE6A813DCC46408484285FD0B64940ABCE6A813DCC4640F2ED5D83BEB4494031D3F6AFACC84640F2ED5D83BEB44940
53210	Новый Увек	7	73	25	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
32454	Новая Липовка	7	73	25	46.071869	46.088065999999998	51.728102	51.716715000000001	0103000020E61000000100000005000000514CDE0033094740BDC62E51BDDB4940514CDE00330947407B13437232DD4940DCF126BF450B47407B13437232DD4940DCF126BF450B4740BDC62E51BDDB4940514CDE0033094740BDC62E51BDDB4940
324	Михайловка	7	73	25	45.701664000000001	45.727544999999999	51.501010999999998	51.486094999999999	0103000020E61000000100000005000000E9633E20D0D94640E3DF675C38BE4940E9633E20D0D94640D7F7E12021C0494025AFCE3120DD4640D7F7E12021C0494025AFCE3120DD4640E3DF675C38BE4940E9633E20D0D94640E3DF675C38BE4940
199	Красный Текстильщик	7	73	25	45.817501999999998	45.847532999999999	51.368231000000002	51.340406000000002	0103000020E610000001000000050000001135D1E7A3E846405CAE7E6C92AB49401135D1E7A3E84640CB2F833122AF4940F0A31AF67BEC4640CB2F833122AF4940F0A31AF67BEC46405CAE7E6C92AB49401135D1E7A3E846405CAE7E6C92AB4940
117	Красный Октябрь	7	73	25	45.669584999999998	45.717205	51.549404000000003	51.533321000000001	0103000020E61000000100000005000000327216F6B4D5464090A2CEDC43C44940327216F6B4D546405325CADE52C649408BC3995FCDDB46405325CADE52C649408BC3995FCDDB464090A2CEDC43C44940327216F6B4D5464090A2CEDC43C44940
385	Константиновка	7	73	25	45.615479999999998	45.634740000000001	51.443444999999997	51.434292999999997	0103000020E61000000100000005000000C9AB730CC8CE4640DCF0BBE996B74940C9AB730CC8CE4640904946CEC2B8494045BB0A293FD14640904946CEC2B8494045BB0A293FD14640DCF0BBE996B74940C9AB730CC8CE4640DCF0BBE996B74940
466	Колотов Буерак	7	73	25	45.731586999999998	45.75656	51.386080999999997	51.379942	0103000020E61000000100000005000000E1968FA4A4DD46403C3080F0A1B04940E1968FA4A4DD4640B14D2A1A6BB149401BBB44F5D6E04640B14D2A1A6BB149401BBB44F5D6E046403C3080F0A1B04940E1968FA4A4DD46403C3080F0A1B04940
32458	Клещевка	7	73	25	46.033610000000003	46.051253000000003	51.733150000000002	51.725251	0103000020E61000000100000005000000C7681D554D04474016325706D5DC4940C7681D554D044740FD87F4DBD7DD4940346953758F064740FD87F4DBD7DD4940346953758F06474016325706D5DC4940C7681D554D04474016325706D5DC4940
646	Ивановский	7	73	25	45.681066000000001	45.695743999999998	51.394264	51.381684999999997	0103000020E610000001000000050000007235B22B2DD74640D72FD80DDBB049407235B22B2DD74640BDFE243E77B24940B131AF230ED94640BDFE243E77B24940B131AF230ED94640D72FD80DDBB049407235B22B2DD74640D72FD80DDBB04940
53205	Дубки	7	73	25	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
53165	Бартоломеевский	7	73	25	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
32118	Багаевка	7	73	25	45.807360000000003	45.839312999999997	51.421500999999999	51.410513999999999	0103000020E610000001000000050000009E0C8E9257E746406B4606B98BB449409E0C8E9257E746409B1DA9BEF3B54940C70DBF9B6EEB46409B1DA9BEF3B54940C70DBF9B6EEB46406B4606B98BB449409E0C8E9257E746406B4606B98BB44940
53193	Рейник	7	73	7267	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
53172	Березина Речка	7	73	7267	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
22459	Южный	7	73	826	43.471561000000001	43.480148999999997	51.240442999999999	51.226061999999999	0103000020E61000000100000005000000D788601C5CBC4540266F8099EF9C4940D788601C5CBC4540ACC612D6C69E4940821ABE8575BD4540ACC612D6C69E4940821ABE8575BD4540266F8099EF9C4940D788601C5CBC4540266F8099EF9C4940
6928	Хрущевка	7	73	826	43.98254	44.006472000000002	51.208188999999997	51.180672999999999	0103000020E610000001000000050000008481E7DEC3FD45409622F94A209749408481E7DEC3FD45408731E9EFA59A49407C2B1213D40046408731E9EFA59A49407C2B1213D40046409622F94A209749408481E7DEC3FD45409622F94A20974940
30735	Тюменевка	7	73	826	43.117085000000003	43.147098	51.137549999999997	51.129145000000001	0103000020E6100000010000000500000014ED2AA4FC8E454091B8C7D28790494014ED2AA4FC8E45404BC8073D9B9149404CA7751BD49245404BC8073D9B9149404CA7751BD492454091B8C7D28790494014ED2AA4FC8E454091B8C7D287904940
31523	Тульский	7	73	826	43.380291999999997	43.394350000000003	51.315157999999997	51.304375999999998	0103000020E6100000010000000500000018778368ADB04540F9D7F2CAF5A6494018778368ADB045405089EB1857A84940BC96900F7AB245405089EB1857A84940BC96900F7AB24540F9D7F2CAF5A6494018778368ADB04540F9D7F2CAF5A64940
31418	Святославка	7	73	826	43.411220999999998	43.456020000000002	51.344856	51.314652000000002	0103000020E61000000100000005000000D636C5E3A2B445407DCF488446A84940D636C5E3A2B4454029EACC3D24AC4940352905DD5EBA454029EACC3D24AC4940352905DD5EBA45407DCF488446A84940D636C5E3A2B445407DCF488446A84940
24576	Самородовка	7	73	826	43.569018999999997	43.592886999999997	51.418844	51.407384	0103000020E61000000100000005000000BCE6559DD5C84540F374AE2825B44940BCE6559DD5C845401B1021AE9CB549409D9CA1B8E3CB45401B1021AE9CB549409D9CA1B8E3CB4540F374AE2825B44940BCE6559DD5C84540F374AE2825B44940
23131	Самойловка	7	73	826	43.675469	43.750712	51.209515000000003	51.151302999999999	0103000020E610000001000000050000001D3BA8C475D64540B2648EE55D9349401D3BA8C475D64540BF823463D19A49407D5BB05417E04540BF823463D19A49407D5BB05417E04540B2648EE55D9349401D3BA8C475D64540B2648EE55D934940
31757	Садовый	7	73	826	44.118769999999998	44.148018999999998	51.188006000000001	51.173642999999998	0103000020E610000001000000050000007ADFF8DA330F4640F4160FEF399649407ADFF8DA330F4640D4B9A29410984940E3175E49F2124640D4B9A29410984940E3175E49F2124640F4160FEF399649407ADFF8DA330F4640F4160FEF39964940
30670	Полтавка	7	73	826	43.265056000000001	43.286228999999999	51.152664999999999	51.123911	0103000020E61000000100000005000000E6CDE15AEDA14540AD4ECE50DC8F4940E6CDE15AEDA14540361FD7868A9349405915E126A3A44540361FD7868A9349405915E126A3A44540AD4ECE50DC8F4940E6CDE15AEDA14540AD4ECE50DC8F4940
22387	Полоцкое	7	73	826	43.320203999999997	43.350144	51.079456	51.056980000000003	0103000020E610000001000000050000003106D671FCA845405743E21E4B8749403106D671FCA8454049BC3C9D2B8A49400072C284D1AC454049BC3C9D2B8A49400072C284D1AC45405743E21E4B8749403106D671FCA845405743E21E4B874940
31325	Песчанка	7	73	826	43.654988000000003	43.700667000000003	51.327142000000002	51.281492	0103000020E61000000100000005000000E0A293A5D6D34540F60A0BEE07A44940E0A293A5D6D34540F392FFC9DFA949407731CD74AFD94540F392FFC9DFA949407731CD74AFD94540F60A0BEE07A44940E0A293A5D6D34540F60A0BEE07A44940
11846	Передовой	7	73	826	43.374965000000003	43.397683000000001	51.418979	51.405512999999999	0103000020E61000000100000005000000841266DAFEAF45402A8D98D9E7B34940841266DAFEAF4540FB5A971AA1B549406C96CB46E7B24540FB5A971AA1B549406C96CB46E7B245402A8D98D9E7B34940841266DAFEAF45402A8D98D9E7B34940
30519	Ольшанка	7	73	826	43.654907000000001	43.682583999999999	51.184629999999999	51.138967999999998	0103000020E61000000100000005000000F37519FED3D34540639813B4C9914940F37519FED3D3454024EEB1F4A1974940ED629AE95ED7454024EEB1F4A1974940ED629AE95ED74540639813B4C9914940F37519FED3D34540639813B4C9914940
6400	Новомихайловка	7	73	826	43.461660999999999	43.483947999999998	51.369120000000002	51.351269000000002	0103000020E61000000100000005000000596B28B517BB4540A08CF161F6AC4940596B28B517BB45405726FC523FAF4940787B1002F2BD45405726FC523FAF4940787B1002F2BD4540A08CF161F6AC4940596B28B517BB4540A08CF161F6AC4940
30974	Новоалександровка	7	73	826	43.458858999999997	43.484963999999998	51.329956000000003	51.313772999999998	0103000020E61000000100000005000000D53C47E4BBBA454014AFB2B629A84940D53C47E4BBBA45403B8F8AFF3BAA494061DEE34C13BE45403B8F8AFF3BAA494061DEE34C13BE454014AFB2B629A84940D53C47E4BBBA454014AFB2B629A84940
31210	Николаевка	7	73	826	43.237765000000003	43.273608000000003	51.271079999999998	51.252761999999997	0103000020E61000000100000005000000159161156F9E4540F5D555815AA04940159161156F9E4540C24CDBBFB2A2494045F6419605A34540C24CDBBFB2A2494045F6419605A34540F5D555815AA04940159161156F9E4540F5D555815AA04940
30830	Низовка	7	73	826	43.474497999999997	43.495356999999998	51.146974999999998	51.125408999999998	0103000020E610000001000000050000003A02B859BCBC4540E1CFF0660D9049403A02B859BCBC4540302AA913D09249401E6CB1DB67BF4540302AA913D09249401E6CB1DB67BF4540E1CFF0660D9049403A02B859BCBC4540E1CFF0660D904940
31262	Криуша	7	73	826	43.702931	43.735396000000001	51.323658000000002	51.299449000000003	0103000020E610000001000000050000001B2C9CA4F9D94540F3E8465854A649401B2C9CA4F9D945405D8B16A06DA94940FBCDC47421DE45405D8B16A06DA94940FBCDC47421DE4540F3E8465854A649401B2C9CA4F9D94540F3E8465854A64940
31420	Крийнички	7	73	826	43.649777	43.678621999999997	51.419102000000002	51.400962	0103000020E61000000100000005000000B4588AE42BD3454029780AB952B34940B4588AE42BD3454017D86322A5B549404D2CF015DDD6454017D86322A5B549404D2CF015DDD6454029780AB952B34940B4588AE42BD3454029780AB952B34940
22555	Красный	7	73	826	43.557564999999997	43.580005	51.455697999999998	51.445633999999998	0103000020E610000001000000050000007632384A5EC745402AFEEF880AB949407632384A5EC74540226DE34F54BA49401C42959A3DCA4540226DE34F54BA49401C42959A3DCA45402AFEEF880AB949407632384A5EC745402AFEEF880AB94940
9477	Краснознаменский	7	73	826	43.356189999999998	43.3902	51.358969000000002	51.344152999999999	0103000020E61000000100000005000000C49448A297AD4540FFE89B340DAC4940C49448A297AD454090A339B2F2AD49401973D712F2B1454090A339B2F2AD49401973D712F2B14540FFE89B340DAC4940C49448A297AD4540FFE89B340DAC4940
30616	Красавка	7	73	826	43.376654000000002	43.445338999999997	51.186121	51.146416000000002	0103000020E610000001000000050000002CF4C13236B045403ACE6DC2BD9249402CF4C13236B04540A60C1CD0D297494011514CDE00B94540A60C1CD0D297494011514CDE00B945403ACE6DC2BD9249402CF4C13236B045403ACE6DC2BD924940
31211	Каменка	7	73	826	43.746049999999997	43.779080999999998	51.349024	51.327750000000002	0103000020E610000001000000050000002497FF907EDF4540CBA145B6F3A949402497FF907EDF454072C284D1ACAC4940ADF71BEDB8E3454072C284D1ACAC4940ADF71BEDB8E34540CBA145B6F3A949402497FF907EDF4540CBA145B6F3A94940
5927	Залесянка	7	73	826	43.644908999999998	43.690193000000001	51.229005999999998	51.176014000000002	0103000020E61000000100000005000000B2F2CB608CD24540AFD172A087964940B2F2CB608CD245403C4B9011509D4940CD76853E58D845403C4B9011509D4940CD76853E58D84540AFD172A087964940B2F2CB608CD24540AFD172A087964940
30611	Еловатка	7	73	826	43.629305000000002	43.668973999999999	51.131428999999997	51.094386	0103000020E61000000100000005000000CA1AF5108DD04540A29927D7148C4940CA1AF5108DD045407C5F5CAAD2904940E9EFA5F0A0D545407C5F5CAAD2904940E9EFA5F0A0D54540A29927D7148C4940CA1AF5108DD04540A29927D7148C4940
30421	Елизаветино	7	73	826	43.948709999999998	43.973466999999999	51.362428000000001	51.345407000000002	0103000020E61000000100000005000000AFB14B546FF945409D67EC4B36AC4940AFB14B546FF94540CD936B0A64AE49401C5E10919AFC4540CD936B0A64AE49401C5E10919AFC45409D67EC4B36AC4940AFB14B546FF945409D67EC4B36AC4940
30832	Воронино	7	73	826	43.475118000000002	43.512774999999998	51.077587999999999	51.057999000000002	0103000020E61000000100000005000000D7DEA7AAD0BC4540B119E0826C874940D7DEA7AAD0BC4540F1475167EE8949406B9A779CA2C14540F1475167EE8949406B9A779CA2C14540B119E0826C874940D7DEA7AAD0BC4540B119E0826C874940
22457	Воздвиженка	7	73	826	43.398231000000003	43.422854000000001	51.257294999999999	51.242562999999997	0103000020E610000001000000050000006FA0C03BF9B245401D1CEC4D0C9F49406FA0C03BF9B245405036E50AEFA04940CC7D721420B645405036E50AEFA04940CC7D721420B645401D1CEC4D0C9F49406FA0C03BF9B245401D1CEC4D0C9F4940
30364	Благовещенка	7	73	826	44.028596999999998	44.062832	51.336956000000001	51.310108	0103000020E61000000100000005000000C1E10511A90346402E1D739EB1A74940C1E10511A90346407218CC5F21AB4940369204E10A0846407218CC5F21AB4940369204E10A0846402E1D739EB1A74940C1E10511A90346402E1D739EB1A74940
30312	Алексеевский	7	73	826	43.666925999999997	43.690148000000001	51.275013000000001	51.243938999999997	0103000020E61000000100000005000000116DC7D45DD54540069CA564399F4940116DC7D45DD54540C87C40A033A349402DB308C556D84540C87C40A033A349402DB308C556D84540069CA564399F4940116DC7D45DD54540069CA564399F4940
30518	Александровка	7	73	826	44.033942000000003	44.054828000000001	51.299680000000002	51.278618999999999	0103000020E61000000100000005000000FDFA213658044640A98592C9A9A34940FDFA213658044640F5A10BEA5BA64940DA73999A04074640F5A10BEA5BA64940DA73999A04074640A98592C9A9A34940FDFA213658044640A98592C9A9A34940
29736	Шило-Голицыно	7	73	1712	43.726880000000001	43.752374000000003	52.231776000000004	52.212218	0103000020E61000000100000005000000E90E62670ADD4540AFCF9CF5291B4A40E90E62670ADD4540B5FF01D6AA1D4A402C2E8ECA4DE04540B5FF01D6AA1D4A402C2E8ECA4DE04540AFCF9CF5291B4A40E90E62670ADD4540AFCF9CF5291B4A40
30026	Урусово	7	73	1712	43.764169000000003	43.800254000000002	52.395259000000003	52.376719000000001	0103000020E61000000100000005000000FBCE2F4AD0E145401364045438304A40FBCE2F4AD0E145408F39CFD897324A40213F1BB96EE645408F39CFD897324A40213F1BB96EE645401364045438304A40FBCE2F4AD0E145401364045438304A40
29200	Темп	7	73	1712	43.877724999999998	43.897120000000001	52.270243000000001	52.259478999999999	0103000020E61000000100000005000000D8F0F44A59F04540D87F9D9B36214A40D8F0F44A59F04540897C975297224A40344B02D4D4F24540897C975297224A40344B02D4D4F24540D87F9D9B36214A40D8F0F44A59F04540D87F9D9B36214A40
53231	Стройидустрия	7	73	1712	43.763908000000001	43.780878000000001	52.298223999999998	52.285037000000003	0103000020E610000001000000050000008E93C2BCC7E145403293A8177C244A408E93C2BCC7E14540EF703B342C264A403C1570CFF3E34540EF703B342C264A403C1570CFF3E345403293A8177C244A408E93C2BCC7E145403293A8177C244A40
53175	Совхоза Выдвиженец	7	73	1712	43.734712999999999	43.746158000000001	52.263078	52.255156999999997	0103000020E61000000100000005000000187959130BDE4540382C0DFCA8204A40187959130BDE45400726378AAC214A400BD3F71A82DF45400726378AAC214A400BD3F71A82DF4540382C0DFCA8204A40187959130BDE4540382C0DFCA8204A40
28933	Сланцы	7	73	1712	43.572352000000002	43.598078999999998	52.187263000000002	52.176285	0103000020E610000001000000050000006DE690D442C945403FE3C28190164A406DE690D442C945401C60E63BF8174A4052B648DA8DCC45401C60E63BF8174A4052B648DA8DCC45403FE3C28190164A406DE690D442C945403FE3C28190164A40
29120	Северка	7	73	1712	43.026606999999998	43.044142000000001	52.353110999999998	52.336413	0103000020E610000001000000050000001E6CB1DB678345408179C8940F2B4A401E6CB1DB67834540CE6DC2BD322D4A40A530EF71A6854540CE6DC2BD322D4A40A530EF71A68545408179C8940F2B4A401E6CB1DB678345408179C8940F2B4A40
29299	Сапожок	7	73	1712	43.970674000000002	43.993957999999999	52.336523	52.321482000000003	0103000020E61000000100000005000000EC89AE0B3FFC454058207A5226294A40EC89AE0B3FFC454008AD872F132B4A407DCC07043AFF454008AD872F132B4A407DCC07043AFF454058207A5226294A40EC89AE0B3FFC454058207A5226294A40
29469	Салтыковка	7	73	1712	44.058447999999999	44.090966999999999	52.125402000000001	52.105521000000003	0103000020E6100000010000000500000020425C397B07464047054EB6810D4A4020425C397B0746402F6D382C0D104A40F30181CEA40B46402F6D382C0D104A40F30181CEA40B464047054EB6810D4A4020425C397B07464047054EB6810D4A40
29932	Ртищевский	7	73	1712	43.866819	43.908617999999997	52.346058999999997	52.325747999999997	0103000020E610000001000000050000009546CCECF3EE4540635E471CB2294A409546CCECF3EE454044BE4BA94B2C4A40494739984DF4454044BE4BA94B2C4A40494739984DF44540635E471CB2294A409546CCECF3EE4540635E471CB2294A40
29116	Репьевка	7	73	1712	43.235097000000003	43.262135999999998	52.414335000000001	52.393324	0103000020E61000000100000005000000A13193A8179E4540AF5DDA7058324A40A13193A8179E4540494BE5ED08354A40588D25AC8DA14540494BE5ED08354A40588D25AC8DA14540AF5DDA7058324A40A13193A8179E4540AF5DDA7058324A40
29370	Правда	7	73	1712	44.027743999999998	44.056570999999998	52.324244999999998	52.305405999999998	0103000020E6100000010000000500000082548A1D8D0346404700378B17274A4082548A1D8D0346401D7233DC80294A407573F1B73D0746401D7233DC80294A407573F1B73D0746404700378B17274A4082548A1D8D0346404700378B17274A40
28987	Потьма	7	73	1712	43.377076000000002	43.396712999999998	52.286068	52.258398	0103000020E61000000100000005000000A20DC00644B0454008AD872F13214A40A20DC00644B04540503750E09D244A40F372D87DC7B24540503750E09D244A40F372D87DC7B2454008AD872F13214A40A20DC00644B0454008AD872F13214A40
28657	Подгоренка	7	73	1712	43.544459000000003	43.565300000000001	52.387839	52.371122	0103000020E61000000100000005000000A6811FD5B0C54540BE69FAEC802F4A40A6811FD5B0C54540828E56B5A4314A40E3361AC05BC84540828E56B5A4314A40E3361AC05BC84540BE69FAEC802F4A40A6811FD5B0C54540BE69FAEC802F4A40
29373	Первомайский	7	73	1712	44.193752000000003	44.21895	52.239083999999998	52.225945000000003	0103000020E610000001000000050000006EC493DDCC184640EDD808C4EB1C4A406EC493DDCC184640997FF44D9A1E4A40C7BAB88D061C4640997FF44D9A1E4A40C7BAB88D061C4640EDD808C4EB1C4A406EC493DDCC184640EDD808C4EB1C4A40
28848	Ободной	7	73	1712	43.278143999999998	43.291314	52.203443	52.197856999999999	0103000020E6100000010000000500000010CAFB389AA345407024D06053194A4010CAFB389AA34540D1CC936B0A1A4A40F86EF3C649A54540D1CC936B0A1A4A40F86EF3C649A545407024D06053194A4010CAFB389AA345407024D06053194A40
29641	Малиновка	7	73	1712	43.947119999999998	43.998485000000002	52.112882999999997	52.087839000000002	0103000020E610000001000000050000009AB1683A3BF945401C28F04E3E0B4A409AB1683A3BF945401EA33CF3720E4A40F645425BCEFF45401EA33CF3720E4A40F645425BCEFF45401C28F04E3E0B4A409AB1683A3BF945401C28F04E3E0B4A40
29035	Макарово	7	73	1712	43.303234000000003	43.353935	52.28669	52.261550999999997	0103000020E610000001000000050000008484285FD0A64540389ECF807A214A408484285FD0A645408D0B0742B2244A4073F4F8BD4DAD45408D0B0742B2244A4073F4F8BD4DAD4540389ECF807A214A408484285FD0A64540389ECF807A214A40
29244	Луч	7	73	1712	43.969101999999999	43.984040999999998	52.234346000000002	52.228029999999997	0103000020E610000001000000050000007D3ECA880BFC4540E1404816301D4A407D3ECA880BFC454066F9BA0CFF1D4A402976340EF5FD454066F9BA0CFF1D4A402976340EF5FD4540E1404816301D4A407D3ECA880BFC4540E1404816301D4A40
28950	Лопатино	7	73	1712	43.488162000000003	43.514743000000003	52.153675	52.137144999999997	0103000020E610000001000000050000003293A8177CBE4540ABE7A4F78D114A403293A8177CBE45403D9B559FAB134A40276C3F19E3C145403D9B559FAB134A40276C3F19E3C14540ABE7A4F78D114A403293A8177CBE4540ABE7A4F78D114A40
30030	Курган	7	73	1712	43.984121000000002	43.991208999999998	52.217911999999998	52.210551000000002	0103000020E6100000010000000500000046274BADF7FD4540EF91CD55F31A4A4046274BADF7FD4540F6B3588AE41B4A401C40BFEFDFFE4540F6B3588AE41B4A401C40BFEFDFFE4540EF91CD55F31A4A4046274BADF7FD4540EF91CD55F31A4A40
29515	Крутец	7	73	1712	44.033546999999999	44.086458	52.082940999999998	52.059857000000001	0103000020E6100000010000000500000080F0A1444B044640E5B7E864A9074A4080F0A1444B044640AF3F89CF9D0A4A40213D450E110B4640AF3F89CF9D0A4A40213D450E110B4640E5B7E864A9074A4080F0A1444B044640E5B7E864A9074A40
29728	Красные Гривки	7	73	1712	43.778210000000001	43.806758000000002	52.188035999999997	52.167496999999997	0103000020E61000000100000005000000C8B5A1629CE34540CC96AC8A70154A40C8B5A1629CE345403E3C4B9011184A40A8E49CD843E745403E3C4B9011184A40A8E49CD843E74540CC96AC8A70154A40C8B5A1629CE34540CC96AC8A70154A40
28845	Красная Звезда	7	73	1712	43.422055	43.459477999999997	52.203443	52.189422	0103000020E61000000100000005000000800EF3E505B645404B92E7FA3E184A40800EF3E505B64540D1CC936B0A1A4A40A19DD32CD0BA4540D1CC936B0A1A4A40A19DD32CD0BA45404B92E7FA3E184A40800EF3E505B645404B92E7FA3E184A40
28761	Ключи	7	73	1712	43.424624000000001	43.460628	52.234175	52.221063000000001	0103000020E61000000100000005000000618C48145AB6454086ADD9CA4B1C4A40618C48145AB6454039454772F91D4A409ACFB9DBF5BA454039454772F91D4A409ACFB9DBF5BA454086ADD9CA4B1C4A40618C48145AB6454086ADD9CA4B1C4A40
29571	Каменка	7	73	1712	43.943302000000003	43.964205999999997	52.049101999999998	52.029851000000001	0103000020E610000001000000050000002E20B41EBEF845405F605628D2034A402E20B41EBEF8454087156EF948064A40B14D2A1A6BFB454087156EF948064A40B14D2A1A6BFB45405F605628D2034A402E20B41EBEF845405F605628D2034A40
29649	Ерышевка	7	73	1712	43.875264000000001	43.896185000000003	52.148220999999999	52.126258999999997	0103000020E61000000100000005000000DEAE97A608F04540AFE9414129104A40DEAE97A608F045404BCADDE7F8124A403815A930B6F245404BCADDE7F8124A403815A930B6F24540AFE9414129104A40DEAE97A608F04540AFE9414129104A40
29466	Елань	7	73	1712	44.147793999999998	44.225445000000001	52.226683999999999	52.187908999999998	0103000020E61000000100000005000000C345EEE9EA124640E1CFF0660D184A40C345EEE9EA124640634337FB031D4A40FB05BB61DB1C4640634337FB031D4A40FB05BB61DB1C4640E1CFF0660D184A40C345EEE9EA124640E1CFF0660D184A40
24646	Голицыно	7	73	1712	43.449534	43.461221000000002	52.218722999999997	52.202371999999997	0103000020E61000000100000005000000543882548AB9454024D06053E7194A40543882548AB9454006F1811DFF1B4A403D9D2B4A09BB454006F1811DFF1B4A403D9D2B4A09BB454024D06053E7194A40543882548AB9454024D06053E7194A40
28696	Владыкино	7	73	1712	43.480176	43.503334000000002	52.346333999999999	52.317397	0103000020E610000001000000050000007C293C6876BD45409C6C0377A0284A407C293C6876BD454016BF29AC542C4A40817B9E3F6DC0454016BF29AC542C4A40817B9E3F6DC045409C6C0377A0284A407C293C6876BD45409C6C0377A0284A40
29198	Васильевка	7	73	1712	43.046585999999998	43.071164000000003	52.315970999999998	52.295195	0103000020E61000000100000005000000C939B187F6854540AB7823F3C8254A40C939B187F685454001BEDBBC71284A408753E6E61B89454001BEDBBC71284A408753E6E61B894540AB7823F3C8254A40C939B187F6854540AB7823F3C8254A40
28649	Александровка	7	73	1712	43.601483999999999	43.871284000000003	52.340425000000003	52.261274999999998	0103000020E610000001000000050000009C887E6DFDCC454096218E7571214A409C887E6DFDCC4540D3DEE00B932B4A4098C3EE3B86EF4540D3DEE00B932B4A4098C3EE3B86EF454096218E7571214A409C887E6DFDCC454096218E7571214A40
22999	Усть-Щербедино	7	73	622	42.85228	42.882103999999998	51.899341999999997	51.846417000000002	0103000020E610000001000000050000007784D382176D4540A4E36A6457EC49407784D382176D4540A9F57EA31DF34940DCD5ABC8E8704540A9F57EA31DF34940DCD5ABC8E8704540A4E36A6457EC49407784D382176D4540A4E36A6457EC4940
23367	Таволжанский	7	73	622	42.910975999999998	42.930109999999999	51.688096999999999	51.682296000000001	0103000020E610000001000000050000006FB88FDC9A7445408718AF7955D749406FB88FDC9A744540E4BCFF8F13D849405ED72FD80D774540E4BCFF8F13D849405ED72FD80D7745408718AF7955D749406FB88FDC9A7445408718AF7955D74940
4298	Романовка	7	73	622	42.722994999999997	42.774431999999997	51.777796000000002	51.723734	0103000020E61000000100000005000000F415A4198B5C45406B80D250A3DC4940F415A4198B5C4540D57ABFD18EE34940E97C789620634540D57ABFD18EE34940E97C7896206345406B80D250A3DC4940F415A4198B5C45406B80D250A3DC4940
4586	Подгорное	7	73	622	42.779246999999998	42.838149999999999	51.687806999999999	51.647106999999998	0103000020E61000000100000005000000C8409E5DBE6345409F01F566D4D24940C8409E5DBE634540DD7A4D0F0AD849403A92CB7F486B4540DD7A4D0F0AD849403A92CB7F486B45409F01F566D4D24940C8409E5DBE6345409F01F566D4D24940
9734	Памятка	7	73	622	43.160868999999998	43.192894000000003	51.872537000000001	51.857275999999999	0103000020E6100000010000000500000059F8FA5A97944540A6D24F38BBED494059F8FA5A9794454065C6DB4AAFEF49401DCC26C0B098454065C6DB4AAFEF49401DCC26C0B0984540A6D24F38BBED494059F8FA5A97944540A6D24F38BBED4940
22995	Осиновка	7	73	622	42.767237000000002	42.794086999999998	51.897485000000003	51.866525000000003	0103000020E61000000100000005000000FDA36FD2346245404D158C4AEAEE4940FDA36FD23462454046D3D9C9E0F24940E1968FA4A465454046D3D9C9E0F24940E1968FA4A46545404D158C4AEAEE4940FDA36FD2346245404D158C4AEAEE4940
20753	Мордовский Карай	7	73	622	42.842246000000003	42.897744000000003	51.832132000000001	51.795974000000001	0103000020E61000000100000005000000EA9788B7CE6B4540B03BDD79E2E54940EA9788B7CE6B454040FA264D83EA494012178046E972454040FA264D83EA494012178046E9724540B03BDD79E2E54940EA9788B7CE6B4540B03BDD79E2E54940
3982	Малое Щербедино	7	73	622	42.813499999999998	42.847797999999997	52.008845999999998	51.982323000000001	0103000020E61000000100000005000000E3A59BC420684540E78D93C2BCFD4940E3A59BC420684540A759A0DD21014A409ECE15A5846C4540A759A0DD21014A409ECE15A5846C4540E78D93C2BCFD4940E3A59BC420684540E78D93C2BCFD4940
23356	Красноармейский	7	73	622	42.798228000000002	42.814155999999997	51.767670000000003	51.724888999999997	0103000020E610000001000000050000003160C9552C664540751DAA29C9DC49403160C9552C664540670FB40243E24940CCEB884336684540670FB40243E24940CCEB884336684540751DAA29C9DC49403160C9552C664540751DAA29C9DC4940
23406	Инясево	7	73	622	42.785508	42.821925999999998	51.619570000000003	51.594572999999997	0103000020E61000000100000005000000895FB1868B644540D40AD3F71ACC4940895FB1868B64454097CADB114ECF4940B5DD04DF3469454097CADB114ECF4940B5DD04DF34694540D40AD3F71ACC4940895FB1868B644540D40AD3F71ACC4940
22807	Бык	7	73	622	42.931241999999997	42.961551	51.878275000000002	51.862487000000002	0103000020E61000000100000005000000B05417F032774540D21C59F965EE4940B05417F0327745407CF2B0506BF04940D237691A147B45407CF2B0506BF04940D237691A147B4540D21C59F965EE4940B05417F032774540D21C59F965EE4940
17685	Большой Карай	7	73	622	42.640681999999998	42.708171999999998	51.614789000000002	51.586072999999999	0103000020E61000000100000005000000649126DE01524540C808A87004CB4940649126DE015245406478EC67B1CE4940B1F84D61A55A45406478EC67B1CE4940B1F84D61A55A4540C808A87004CB4940649126DE01524540C808A87004CB4940
22906	Бобылевка	7	73	622	42.772851000000003	42.831637000000001	51.851005999999998	51.806373000000001	0103000020E6100000010000000500000028D714C8EC6245404FB0FF3A37E7494028D714C8EC6245409259BDC3EDEC49406092CA14736A45409259BDC3EDEC49406092CA14736A45404FB0FF3A37E7494028D714C8EC6245404FB0FF3A37E74940
23190	Алексеевский	7	73	622	43.021225999999999	43.055829000000003	51.891233	51.877313000000001	0103000020E6100000010000000500000096E99788B782454086ADD9CA4BF0494096E99788B7824540D80E46EC13F249408E95986725874540D80E46EC13F249408E9598672587454086ADD9CA4BF0494096E99788B782454086ADD9CA4BF04940
26365	Яблоновка	7	73	1698	46.006588000000001	46.031723	51.061967000000003	51.050128999999998	0103000020E61000000100000005000000E54526E0D700474064CA87A06A864940E54526E0D70047403337DF88EE874940F8C3CF7F0F0447403337DF88EE874940F8C3CF7F0F04474064CA87A06A864940E54526E0D700474064CA87A06A864940
26359	Чкаловское	7	73	1698	46.054234999999998	46.075606000000001	51.038027	51.022596999999998	0103000020E6100000010000000500000037A6272CF10647406DFE5F75E482494037A6272CF1064740B8AE9811DE844940D1B01875AD094740B8AE9811DE844940D1B01875AD0947406DFE5F75E482494037A6272CF10647406DFE5F75E4824940
26657	Циково	7	73	1698	46.166327000000003	46.185271999999998	50.658651999999996	50.645156999999998	0103000020E610000001000000050000008DB800344A1547408AE42B81945249408DB800344A154740F5B86FB54E544940A86E2EFEB6174740F5B86FB54E544940A86E2EFEB61747408AE42B81945249408DB800344A1547408AE42B8194524940
26273	Тарлыковка	7	73	1698	46.074869	46.102511	51.030562000000003	51.014364	0103000020E61000000100000005000000FB3DB14E95094740B01EF7ADD6814940FB3DB14E950947400C40A374E9834940793D98141F0D47400C40A374E9834940793D98141F0D4740B01EF7ADD6814940FB3DB14E95094740B01EF7ADD6814940
26267	Скатовка	7	73	1698	46.091200999999998	46.116523999999998	50.990127000000001	50.966825	0103000020E61000000100000005000000662E7079AC0B474044FAEDEBC07B4940662E7079AC0B47407CF1457BBC7E49407C992842EA0E47407CF1457BBC7E49407C992842EA0E474044FAEDEBC07B4940662E7079AC0B474044FAEDEBC07B4940
26144	Серебряный Бор	7	73	1698	46.091586999999997	46.107540999999998	50.901136999999999	50.891444999999997	0103000020E610000001000000050000008FDE701FB90B47406397A8DE1A7249408FDE701FB90B4740971B0C755873494054FD4AE7C30D4740971B0C755873494054FD4AE7C30D47406397A8DE1A7249408FDE701FB90B47406397A8DE1A724940
22603	Ровное	7	73	1698	46.030177999999999	46.088684999999998	50.789790000000004	50.754792000000002	0103000020E61000000100000005000000838769DFDC03474027A435069D604940838769DFDC0347409B5AB6D617654940A852B3075A0B47409B5AB6D617654940A852B3075A0B474027A435069D604940838769DFDC03474027A435069D604940
26194	Привольное	7	73	1698	46.065204000000001	46.098728999999999	50.941206999999999	50.918345000000002	0103000020E61000000100000005000000C1C8CB9A58084740FAB836548C754940C1C8CB9A5808474015E29178797849405915E126A30C474015E29178797849405915E126A30C4740FAB836548C754940C1C8CB9A58084740FAB836548C754940
26457	Приволжское	7	73	1698	45.936366999999997	45.965651999999999	51.101660000000003	51.078600999999999	0103000020E61000000100000005000000DD06B5DFDAF746406937FA980F8A4940DD06B5DFDAF74640DBA7E331038D494093A8177C9AFB4640DBA7E331038D494093A8177C9AFB46406937FA980F8A4940DD06B5DFDAF746406937FA980F8A4940
26749	Первомайское	7	73	1698	46.194820999999997	46.228113	50.581746000000003	50.567743	0103000020E6100000010000000500000079C9FFE4EF18474037C478CDAB48494079C9FFE4EF184740174A26A7764A49406F6589CE321D4740174A26A7764A49406F6589CE321D474037C478CDAB48494079C9FFE4EF18474037C478CDAB484940
26070	Новопривольное	7	73	1698	46.08061	46.091586999999997	50.801330999999998	50.787837000000003	0103000020E6100000010000000500000083DDB06D510A474015CAC2D7D764494083DDB06D510A4740AF22A303926649408FDE701FB90B4740AF22A303926649408FDE701FB90B474015CAC2D7D764494083DDB06D510A474015CAC2D7D7644940
26508	Новокаменка	7	73	1698	46.401280999999997	46.423397999999999	50.830962999999997	50.815480999999998	0103000020E61000000100000005000000CAC0012D5D33474033C170AE61684940CAC0012D5D334740D097DEFE5C6A49408D98D9E731364740D097DEFE5C6A49408D98D9E73136474033C170AE61684940CAC0012D5D33474033C170AE61684940
26570	Луговское	7	73	1698	46.454766999999997	46.499125999999997	50.648007	50.627144000000001	0103000020E61000000100000005000000672618CE353A4740FAF02C4146504940672618CE353A47401F4AB4E4F1524940A94A5B5CE33F47401F4AB4E4F1524940A94A5B5CE33F4740FAF02C4146504940672618CE353A4740FAF02C4146504940
26028	Лиманный	7	73	1698	46.060226999999998	46.08202	50.703831999999998	50.691240000000001	0103000020E6100000010000000500000008ABB184B5074740F1D7648D7A58494008ABB184B50747406BF0BE2A175A494018CFA0A17F0A47406BF0BE2A175A494018CFA0A17F0A4740F1D7648D7A58494008ABB184B5074740F1D7648D7A584940
26561	Кривояр	7	73	1698	46.477890000000002	46.503168000000002	50.875760999999997	50.855266999999998	0103000020E61000000100000005000000F08AE07F2B3D47408C2C9963796D4940F08AE07F2B3D47405E0EBBEF1870494066321CCF674047405E0EBBEF1870494066321CCF674047408C2C9963796D4940F08AE07F2B3D47408C2C9963796D4940
26141	Кочетное	7	73	1698	46.111933999999998	46.148449999999997	50.862054999999998	50.836106000000001	0103000020E61000000100000005000000BDA772DA530E4740A4FE7A85056B4940BDA772DA530E4740382D78D1576E4940AC8BDB6800134740382D78D1576E4940AC8BDB6800134740A4FE7A85056B4940BDA772DA530E4740A4FE7A85056B4940
26658	Владимирский	7	73	1698	46.257703999999997	46.273235	50.658115000000002	50.644443000000003	0103000020E610000001000000050000003106D671FC2047406D91B41B7D5249403106D671FC204740E700C11C3D544940B08F4E5DF9224740E700C11C3D544940B08F4E5DF92247406D91B41B7D5249403106D671FC2047406D91B41B7D524940
53244	Береговое	7	73	1698	45.837696000000001	46.619590000000002	51.147399	50.526026999999999	0103000020E61000000100000005000000B9FE5D9F39EB464010E84CDA54434940B9FE5D9F39EB4640473B6EF8DD924940DE76A1B94E4F4740473B6EF8DD924940DE76A1B94E4F474010E84CDA54434940B9FE5D9F39EB464010E84CDA54434940
25451	Чапаевский	7	73	1233	49.134765000000002	49.151842000000002	51.851551999999998	51.83108	0103000020E610000001000000050000009ED2C1FA3F9148400A2E56D460EA49409ED2C1FA3F914840F46BEBA7FFEC49406214048F6F934840F46BEBA7FFEC49406214048F6F9348400A2E56D460EA49409ED2C1FA3F9148400A2E56D460EA4940
24953	Успенка	7	73	1233	48.869779999999999	48.893459	52.06474	52.048847000000002	0103000020E61000000100000005000000815B77F3546F4840FDC0559E40064A40815B77F3546F48401C5F7B6649084A408FA850DD5C7248401C5F7B6649084A408FA850DD5C724840FDC0559E40064A40815B77F3546F4840FDC0559E40064A40
24920	Тургеневский	7	73	1233	48.705595000000002	48.722850999999999	52.053725999999997	52.034860000000002	0103000020E610000001000000050000004E9CDCEF505A484023F8DF4A76044A404E9CDCEF505A4840F2785A7EE0064A40C170AE61865C4840F2785A7EE0064A40C170AE61865C484023F8DF4A76044A404E9CDCEF505A484023F8DF4A76044A40
25353	Старая Порубежка	7	73	1233	49.136597000000002	49.211337	52.070563999999997	52.041890000000002	0103000020E61000000100000005000000A9DDAF027C914840C503CAA65C054A40A9DDAF027C9148403123BC3D08094A40A6B73F170D9B48403123BC3D08094A40A6B73F170D9B4840C503CAA65C054A40A9DDAF027C914840C503CAA65C054A40
24826	Солянский	7	73	1233	48.413156999999998	48.438578999999997	52.088624000000003	52.068055999999999	0103000020E61000000100000005000000868E1D54E2344840F6251B0FB6084A40868E1D54E234484003D2FE07580B4A402FDB4E5B2338484003D2FE07580B4A402FDB4E5B23384840F6251B0FB6084A40868E1D54E2344840F6251B0FB6084A40
24686	Селезниха	7	73	1233	48.648237000000002	48.685715000000002	52.247162000000003	52.217708000000002	0103000020E610000001000000050000005187156EF9524840EE0912DBDD1B4A405187156EF952484030682101A31F4A4036B05582C557484030682101A31F4A4036B05582C5574840EE0912DBDD1B4A405187156EF9524840EE0912DBDD1B4A40
25460	Рахмановка	7	73	1233	49.470087999999997	49.491342000000003	51.968026000000002	51.949007000000002	0103000020E61000000100000005000000FB1EF5D72BBC48406956B60F79F94940FB1EF5D72BBC4840BFD6A546E8FB49405C936E4BE4BE4840BFD6A546E8FB49405C936E4BE4BE48406956B60F79F94940FB1EF5D72BBC48406956B60F79F94940
24039	Пугачевский	7	73	1233	48.827415000000002	48.851616	52.040838000000001	52.027208000000002	0103000020E61000000100000005000000249C16BCE869484044183F8D7B034A40249C16BCE86948408F37F92D3A054A400B60CAC0016D48408F37F92D3A054A400B60CAC0016D484044183F8D7B034A40249C16BCE869484044183F8D7B034A40
53132	Пугачев	7	73	1233	48.245190000000001	49.789690999999998	52.393098999999999	51.537097000000003	0103000020E6100000010000000500000033A7CB62621F4840CEE33098BFC4494033A7CB62621F48408F8B6A1151324A4007793D9814E548408F8B6A1151324A4007793D9814E54840CEE33098BFC4494033A7CB62621F4840CEE33098BFC44940
25006	Преображенка	7	73	1233	48.911875000000002	48.951220999999997	52.071554999999996	52.047018999999999	0103000020E610000001000000050000001F85EB51B874484033A5F5B704064A401F85EB51B8744840C16ED8B628094A405B22179CC1794840C16ED8B628094A405B22179CC179484033A5F5B704064A401F85EB51B874484033A5F5B704064A40
25565	Новопавловка	7	73	1233	48.583477999999999	48.600149999999999	52.224466999999997	52.212967999999996	0103000020E61000000100000005000000BEF73768AF4A4840198C1189421B4A40BEF73768AF4A4840FF03AC55BB1C4A40E25817B7D14C4840FF03AC55BB1C4A40E25817B7D14C4840198C1189421B4A40BEF73768AF4A4840198C1189421B4A40
25650	Новая Порубежка	7	73	1233	49.661428999999998	49.683985999999997	51.765400999999997	51.748314000000001	0103000020E6100000010000000500000020D099B4A9D44840C991CEC0C8DF494020D099B4A9D44840B0A9F3A8F8E14940FF756EDA8CD74840B0A9F3A8F8E14940FF756EDA8CD74840C991CEC0C8DF494020D099B4A9D44840C991CEC0C8DF4940
24741	Надеждинка	7	73	1233	48.658568000000002	48.688464000000003	52.223224999999999	52.206389999999999	0103000020E610000001000000050000009818CBF44B544840581CCEFC6A1A4A409818CBF44B544840265305A3921C4A40973C9E961F584840265305A3921C4A40973C9E961F584840581CCEFC6A1A4A409818CBF44B544840581CCEFC6A1A4A40
25078	Малая Таволожка	7	73	1233	48.989615000000001	49.001967	52.063898999999999	52.051859999999998	0103000020E61000000100000005000000C6504EB4AB7E48403BFC3559A3064A40C6504EB4AB7E4840A19FA9D72D084A40EB55647440804840A19FA9D72D084A40EB556474408048403BFC3559A3064A40C6504EB4AB7E48403BFC3559A3064A40
24641	Мавринка	7	73	1233	48.709178999999999	48.730756999999997	52.350442999999999	52.340660999999997	0103000020E610000001000000050000004701A260C65A4840E60297C79A2B4A404701A260C65A48405A0EF450DB2C4A405A290472895D48405A0EF450DB2C4A405A290472895D4840E60297C79A2B4A404701A260C65A4840E60297C79A2B4A40
25655	Любицкое	7	73	1233	49.308697000000002	49.337757000000003	51.760323	51.741622	0103000020E61000000100000005000000C9AF1F6283A748403FFF3D78EDDE4940C9AF1F6283A74840C4B2994352E149405F7F129F3BAB4840C4B2994352E149405F7F129F3BAB48403FFF3D78EDDE4940C9AF1F6283A748403FFF3D78EDDE4940
24909	Красная Речка	7	73	1233	48.587367	48.613076999999997	52.126547000000002	52.105868999999998	0103000020E61000000100000005000000F4DF83D72E4B484082548A1D8D0D4A40F4DF83D72E4B484016342DB132104A400377A04E794E484016342DB132104A400377A04E794E484082548A1D8D0D4A40F4DF83D72E4B484082548A1D8D0D4A40
22567	Клинцовка	7	73	1233	49.170985000000002	49.210177999999999	51.682792999999997	51.663657999999998	0103000020E61000000100000005000000A48D23D6E295484048DDCEBEF2D44940A48D23D6E29548400778D2C265D749405A2BDA1CE79A48400778D2C265D749405A2BDA1CE79A484048DDCEBEF2D44940A48D23D6E295484048DDCEBEF2D44940
25508	Карловка	7	73	1233	49.507314000000001	49.527920999999999	51.809902999999998	51.793368000000001	0103000020E61000000100000005000000C76647AAEFC04840B2D826158DE54940C76647AAEFC0484055F7C8E6AAE7494091EF52EA92C3484055F7C8E6AAE7494091EF52EA92C34840B2D826158DE54940C76647AAEFC04840B2D826158DE54940
25170	Каменка	7	73	1233	48.658307000000001	48.708927000000003	51.958171	51.924824999999998	0103000020E610000001000000050000002BDD5D6743544840F8C264AA60F649402BDD5D6743544840E17CEA58A5FA49402E20B41EBE5A4840E17CEA58A5FA49402E20B41EBE5A4840F8C264AA60F649402BDD5D6743544840F8C264AA60F64940
25358	Камелик	7	73	1233	49.392302999999998	49.426205000000003	52.105206000000003	52.087772000000001	0103000020E61000000100000005000000B48F15FC36B2484094C0E61C3C0B4A40B48F15FC36B24840E7ABE463770D4A402332ACE28DB64840E7ABE463770D4A402332ACE28DB6484094C0E61C3C0B4A40B48F15FC36B2484094C0E61C3C0B4A40
25268	Заречный	7	73	1233	48.911389999999997	48.922896999999999	52.049101999999998	52.043894999999999	0103000020E6100000010000000500000062F3716DA87448409DBAF2599E054A4062F3716DA874484087156EF948064A40CB49287D2176484087156EF948064A40CB49287D217648409DBAF2599E054A4062F3716DA87448409DBAF2599E054A40
25158	Заволжский	7	73	1233	48.490546999999999	48.536208000000002	51.932955999999997	51.913570999999997	0103000020E6100000010000000500000051137D3ECA3E484079C9FFE4EFF4494051137D3ECA3E4840B14D2A1A6BF7494042EDB776A2444840B14D2A1A6BF7494042EDB776A244484079C9FFE4EFF4494051137D3ECA3E484079C9FFE4EFF44940
25836	Жестянка	7	73	1233	49.380616000000003	49.414391999999999	51.611404999999998	51.593632999999997	0103000020E61000000100000005000000CC2A6C06B8B04840C669882AFCCB4940CC2A6C06B8B0484031CEDF8442CE4940ADDC0BCC0AB5484031CEDF8442CE4940ADDC0BCC0AB54840C669882AFCCB4940CC2A6C06B8B04840C669882AFCCB4940
25208	Давыдовка	7	73	1233	48.847411999999998	48.888311999999999	51.993597999999999	51.961595000000003	0103000020E61000000100000005000000751E15FF776C4840A27F828B15FB4940751E15FF776C48407DAF21382EFF49407A522635B47148407DAF21382EFF49407A522635B4714840A27F828B15FB4940751E15FF776C4840A27F828B15FB4940
25082	Большая Таволожка	7	73	1233	49.031323999999998	49.082627000000002	52.111528	52.089216	0103000020E610000001000000050000003ACAC16C02844840D5230D6E6B0B4A403ACAC16C028448404D4BAC8C460E4A4020628385938A48404D4BAC8C460E4A4020628385938A4840D5230D6E6B0B4A403ACAC16C02844840D5230D6E6B0B4A40
12646	Березово	7	73	1233	48.442272000000003	48.488553000000003	51.934221999999998	51.917698999999999	0103000020E61000000100000005000000E0F76F5E9C38484034492C2977F54940E0F76F5E9C384840139A249694F749406DAE9AE7883E4840139A249694F749406DAE9AE7883E484034492C2977F54940E0F76F5E9C38484034492C2977F54940
20765	Бажановский	7	73	1233	48.330053999999997	48.346088999999999	52.088115000000002	52.081386000000002	0103000020E61000000100000005000000FDF49F353F2A4840172D40DB6A0A4A40FDF49F353F2A4840BEA4315A470B4A40AF40F4A44C2C4840BEA4315A470B4A40AF40F4A44C2C4840172D40DB6A0A4A40FDF49F353F2A4840172D40DB6A0A4A40
53207	Пугачёв	7	73	7265	48.728475000000003	48.852477999999998	52.048171000000004	51.982500000000002	0103000020E61000000100000005000000107A36AB3E5D4840F6285C8FC2FD4940107A36AB3E5D4840CDCEA2772A064A409D47C5FF1D6D4840CDCEA2772A064A409D47C5FF1D6D4840F6285C8FC2FD4940107A36AB3E5D4840F6285C8FC2FD4940
53164	Пугачев	7	73	7265	48.728475000000003	48.852477999999998	52.048171000000004	51.982500000000002	0103000020E61000000100000005000000107A36AB3E5D4840F6285C8FC2FD4940107A36AB3E5D4840CDCEA2772A064A409D47C5FF1D6D4840CDCEA2772A064A409D47C5FF1D6D4840F6285C8FC2FD4940107A36AB3E5D4840F6285C8FC2FD4940
53224	Ясновиовка	7	73	387	46.907266	47.884794999999997	50.991895999999997	50.371308999999997	0103000020E61000000100000005000000E962D34A21744740F0DAA50D872F4940E962D34A217447404084B872F67E494008556AF640F147404084B872F67E494008556AF640F14740F0DAA50D872F4940E962D34A21744740F0DAA50D872F4940
52032	Трудовик	7	73	387	47.695932999999997	47.726520999999998	50.787574999999997	50.766393000000001	0103000020E61000000100000005000000849A215514D947401171732A19624940849A215514D94740D712F241CF644940B96DDFA3FEDC4740D712F241CF644940B96DDFA3FEDC47401171732A19624940849A215514D947401171732A19624940
2218	Руновский	7	73	387	47.292445999999998	47.309908999999998	50.450429999999997	50.438073000000003	0103000020E610000001000000050000004AECDADE6EA547405C21ACC6123849404AECDADE6EA547409291B3B0A739494037DE1D19ABA747409291B3B0A739494037DE1D19ABA747405C21ACC6123849404AECDADE6EA547405C21ACC612384940
53160	Решетников	7	73	387	47.443237000000003	47.458750999999999	50.573937999999998	50.563513999999998	0103000020E6100000010000000500000047B071FDBBB84740486B0C3A2148494047B071FDBBB8474040F7E5CC76494940EF004F5AB8BA474040F7E5CC76494940EF004F5AB8BA4740486B0C3A2148494047B071FDBBB84740486B0C3A21484940
21917	Приозерный	7	73	387	47.505229999999997	47.522117999999999	50.476008999999998	50.466487000000001	0103000020E61000000100000005000000A27A6B60ABC047402C8194D8B53B4940A27A6B60ABC0474003CDE7DCED3C494093533BC3D4C2474003CDE7DCED3C494093533BC3D4C247402C8194D8B53B4940A27A6B60ABC047402C8194D8B53B4940
22821	Привольный	7	73	387	47.529251000000002	47.553083000000001	50.827362000000001	50.817126000000002	0103000020E610000001000000050000000A302C7FBEC347400C5BB395976849400A302C7FBEC3474001FA7DFFE66949409E7C7A6CCBC6474001FA7DFFE66949409E7C7A6CCBC647400C5BB395976849400A302C7FBEC347400C5BB39597684940
1992	Питерка	7	73	387	47.416665000000002	47.439535999999997	50.623348999999997	50.608077999999999	0103000020E61000000100000005000000A5315A4755B5474063B5F97FD54D4940A5315A4755B54740457F68E6C94F494013B534B742B84740457F68E6C94F494013B534B742B8474063B5F97FD54D4940A5315A4755B5474063B5F97FD54D4940
49416	Питерка	7	73	387	47.416044999999997	47.468597000000003	50.691862	50.656979	0103000020E6100000010000000500000008556AF640B5474053944BE31754494008556AF640B547402EAC1BEF8E5849407A008BFCFABB47402EAC1BEF8E5849407A008BFCFABB474053944BE31754494008556AF640B5474053944BE317544940
23370	Первопитерский	7	73	387	47.299579000000001	47.316485	50.573743999999998	50.563668999999997	0103000020E61000000100000005000000C1C8CB9A58A647406F62484E26484940C1C8CB9A58A647405B2382717049494058569A9482A847405B2382717049494058569A9482A847406F62484E26484940C1C8CB9A58A647406F62484E26484940
22914	Опытная Станция	7	73	387	47.663091000000001	47.680419000000001	50.957850000000001	50.945611	0103000020E61000000100000005000000CFA2772AE0D4474072DEFFC709794940CFA2772AE0D447409F3C2CD49A7A4940DC4944F817D747409F3C2CD49A7A4940DC4944F817D7474072DEFFC709794940CFA2772AE0D4474072DEFFC709794940
21834	Новотулка	7	73	387	47.552534999999999	47.578353	50.846207999999997	50.828966999999999	0103000020E610000001000000050000009B728577B9C647404B3B35971B6A49409B728577B9C6474089CE328B506C494091459A7807CA474089CE328B506C494091459A7807CA47404B3B35971B6A49409B728577B9C647404B3B35971B6A4940
2049	Новореченский	7	73	387	47.367240000000002	47.404502000000001	50.783230000000003	50.765110999999997	0103000020E610000001000000050000003BE466B801AF4740A9674128EF6149403BE466B801AF4740809F71E1406449405395B6B8C6B34740809F71E1406449405395B6B8C6B34740A9674128EF6149403BE466B801AF4740A9674128EF614940
23086	Нива	7	73	387	47.371282000000001	47.394359999999999	50.436357999999998	50.416553999999998	0103000020E61000000100000005000000F7CB272B86AF47404D8237A451354940F7CB272B86AF47408AAC3594DA374940DF6C73637AB247408AAC3594DA374940DF6C73637AB247404D8237A451354940F7CB272B86AF47404D8237A451354940
23405	Нариманово	7	73	387	47.457332000000001	47.473142000000003	50.618715000000002	50.61009	0103000020E6100000010000000500000007B5DFDA89BA4740EECEDA6D174E494007B5DFDA89BA4740B745990D324F4940992EC4EA8FBC4740B745990D324F4940992EC4EA8FBC4740EECEDA6D174E494007B5DFDA89BA4740EECEDA6D174E4940
22608	Моршанка	7	73	387	47.432242000000002	47.454402999999999	50.748106999999997	50.733001999999999	0103000020E6100000010000000500000094FAB2B453B7474088F37002D35D494094FAB2B453B747404F745DF8C15F4940261AA4E029BA47404F745DF8C15F4940261AA4E029BA474088F37002D35D494094FAB2B453B7474088F37002D35D4940
21716	Мироновка	7	73	387	47.441080999999997	47.469701999999998	50.764997000000001	50.738948000000001	0103000020E6100000010000000500000088F19A5775B84740E9B81AD9955E494088F19A5775B84740E144F46BEB614940D26EF4311FBC4740E144F46BEB614940D26EF4311FBC4740E9B81AD9955E494088F19A5775B84740E9B81AD9955E4940
2161	Малый Узень	7	73	387	47.604323000000001	47.652706000000002	50.496051999999999	50.472121999999999	0103000020E610000001000000050000003D9CC0745ACD47406EDC627E6E3C49403D9CC0745ACD4740C58EC6A17E3F494095F3C5DE8BD34740C58EC6A17E3F494095F3C5DE8BD347406EDC627E6E3C49403D9CC0745ACD47406EDC627E6E3C4940
21775	Козловка	7	73	387	47.563637999999997	47.582673999999997	50.872264999999999	50.853577999999999	0103000020E6100000010000000500000034643C4A25C84740E44A3D0B426D494034643C4A25C8474004392861A66F4940601DC70F95CA474004392861A66F4940601DC70F95CA4740E44A3D0B426D494034643C4A25C84740E44A3D0B426D4940
21729	Зеленый Луг	7	73	387	47.386895000000003	47.40531	50.793160999999998	50.775553000000002	0103000020E6100000010000000500000033FE7DC685B1474048A819524563494033FE7DC685B1474038BBB54C86654940F25EB532E1B3474038BBB54C86654940F25EB532E1B3474048A819524563494033FE7DC685B1474048A8195245634940
23188	Запрудное	7	73	387	47.150440000000003	47.180605999999997	50.554575999999997	50.538412000000001	0103000020E610000001000000050000005001309E4193474011E335AFEA4449405001309E41934740C092AB58FC4649400EBBEF181E974740C092AB58FC4649400EBBEF181E97474011E335AFEA4449405001309E4193474011E335AFEA444940
22859	Алексашкино	7	73	387	47.692708000000003	47.73704	50.964050999999998	50.949311000000002	0103000020E61000000100000005000000BBD6DEA7AAD84740D55DD90583794940BBD6DEA7AAD847408A56EE05667B494003ECA35357DE47408A56EE05667B494003ECA35357DE4740D55DD90583794940BBD6DEA7AAD84740D55DD90583794940
18167	Августовка	7	73	387	47.662291000000003	47.676054000000001	50.415985999999997	50.406469000000001	0103000020E61000000100000005000000B3B794F3C5D447403EEB1A2D07344940B3B794F3C5D4474003CC7C073F3549403D2AFEEF88D6474003CC7C073F3549403D2AFEEF88D647403EEB1A2D07344940B3B794F3C5D447403EEB1A2D07344940
21619	Тракторный	7	73	366	44.973956999999999	44.997376000000003	52.204641000000002	52.184116000000003	0103000020E61000000100000005000000EA5A7B9FAA7C4640CE55F31C91174A40EA5A7B9FAA7C4640DB3521AD311A4A405CE84A04AA7F4640DB3521AD311A4A405CE84A04AA7F4640CE55F31C91174A40EA5A7B9FAA7C4640CE55F31C91174A40
22304	Татарская Пакаевка	7	73	366	45.720475	45.743713999999997	52.438865	52.426285999999998	0103000020E61000000100000005000000F54A598638DC46400F5F268A90364A40F54A598638DC4640F52D73BA2C384A40E6C9350532DF4640F52D73BA2C384A40E6C9350532DF46400F5F268A90364A40F54A598638DC46400F5F268A90364A40
22064	Таволожка	7	73	366	45.679592999999997	45.696553000000002	52.200274999999998	52.184280999999999	0103000020E6100000010000000500000096CB46E7FCD646401823128596174A4096CB46E7FCD646406B9A779CA2194A40217711A628D946406B9A779CA2194A40217711A628D946401823128596174A4096CB46E7FCD646401823128596174A40
21483	Студеный	7	73	366	45.074595000000002	45.095166999999996	52.111268000000003	52.086444	0103000020E61000000100000005000000FAB836548C894640BC77D498100B4A40FAB836548C894640B18BA2073E0E4A404754A86E2E8C4640B18BA2073E0E4A404754A86E2E8C4640BC77D498100B4A40FAB836548C894640BC77D498100B4A40
21781	Сосновоборское	7	73	366	45.177210000000002	45.208516000000003	52.277324	52.256098999999999	0103000020E61000000100000005000000184339D1AE964640E7C41EDAC7204A40184339D1AE964640AD32535A7F234A40AC58FCA6B09A4640AD32535A7F234A40AC58FCA6B09A4640E7C41EDAC7204A40184339D1AE964640E7C41EDAC7204A40
22200	Синенькие	7	73	366	45.566845000000001	45.592374999999997	52.331482999999999	52.317832000000003	0103000020E61000000100000005000000587380608EC84640A7CF0EB8AE284A40587380608EC846400917F2086E2A4A40E7FBA9F1D2CB46400917F2086E2A4A40E7FBA9F1D2CB4640A7CF0EB8AE284A40587380608EC84640A7CF0EB8AE284A40
22390	Савкино	7	73	366	45.673763000000001	45.693463000000001	52.448872000000001	52.433062	0103000020E610000001000000050000009F20B1DD3DD64640F7915B936E374A409F20B1DD3DD64640890B40A374394A4037FE4465C3D84640890B40A374394A4037FE4465C3D84640F7915B936E374A409F20B1DD3DD64640F7915B936E374A40
21923	Пригородный	7	73	366	45.413260000000001	45.438583999999999	52.286529999999999	52.272860000000001	0103000020E610000001000000050000005B5F24B4E5B446407B319413ED224A405B5F24B4E5B4464054A9D903AD244A404146408523B8464054A9D903AD244A404146408523B846407B319413ED224A405B5F24B4E5B446407B319413ED224A40
21921	Оркино	7	73	366	45.550693000000003	45.601745000000001	52.058433000000001	52.039386	0103000020E610000001000000050000006D91B41B7DC64640CBF5B6990A054A406D91B41B7DC64640EB0088BB7A074A4009C4EBFA05CD4640EB0088BB7A074A4009C4EBFA05CD4640CBF5B6990A054A406D91B41B7DC64640CBF5B6990A054A40
20750	Озерки	7	73	366	45.464436999999997	45.514240000000001	52.025101999999997	51.99718	0103000020E61000000100000005000000B306EFAB72BB4640D61C2098A3FF4940B306EFAB72BB46403788D68A36034A40C425C79DD2C146403788D68A36034A40C425C79DD2C14640D61C2098A3FF4940B306EFAB72BB4640D61C2098A3FF4940
22294	Ножкино	7	73	366	45.602041	45.629009000000003	52.385223000000003	52.373085000000003	0103000020E61000000100000005000000F2ECF2AD0FCD464068D0D03FC12F4A40F2ECF2AD0FCD46406155BDFC4E314A40E1F1ED5D83D046406155BDFC4E314A40E1F1ED5D83D0464068D0D03FC12F4A40F2ECF2AD0FCD464068D0D03FC12F4A40
21837	Новозахаркино	7	73	366	45.312891	45.335143000000002	52.194346000000003	52.160542	0103000020E610000001000000050000003B1BF2CF0CA8464035D1E7A38C144A403B1BF2CF0CA84640E10D6954E0184A40DE3D40F7E5AA4640E10D6954E0184A40DE3D40F7E5AA464035D1E7A38C144A403B1BF2CF0CA8464035D1E7A38C144A40
22341	Новодубровка	7	73	366	45.481459999999998	45.506720999999999	52.408990000000003	52.388306999999998	0103000020E61000000100000005000000842A357BA0BD464068E7340BB4314A40842A357BA0BD46400E32C9C859344A402499D53BDCC046400E32C9C859344A402499D53BDCC0464068E7340BB4314A40842A357BA0BD464068E7340BB4314A40
3835	Новая Усть-Уза	7	73	366	45.167642999999998	45.193676000000004	52.137399000000002	52.128056000000001	0103000020E61000000100000005000000A0336953759546403E07962364104A40A03369537595464066C0594A96114A4093020B60CA98464066C0594A96114A4093020B60CA9846403E07962364104A40A0336953759546403E07962364104A40
22023	Мирный	7	73	366	45.406064999999998	45.423627000000003	52.225757999999999	52.211742999999998	0103000020E610000001000000050000006E861BF0F9B34640161406651A1B4A406E861BF0F9B34640BA675DA3E51C4A40EF59D76839B64640BA675DA3E51C4A40EF59D76839B64640161406651A1B4A406E861BF0F9B34640161406651A1B4A40
1873	Колки	7	73	366	45.495294000000001	45.514868999999997	52.152662999999997	52.141882000000003	0103000020E61000000100000005000000D8F335CB65BF46400FF27A3029124A40D8F335CB65BF4640952710768A134A40B35C363AE7C14640952710768A134A40B35C363AE7C146400FF27A3029124A40D8F335CB65BF46400FF27A3029124A40
21538	Кожевино	7	73	366	45.149380000000001	45.173966999999998	52.192016000000002	52.179416000000003	0103000020E61000000100000005000000975643E21E93464088307E1AF7164A40975643E21E9346408527F4FA93184A40A7CAF78C449646408527F4FA93184A40A7CAF78C4496464088307E1AF7164A40975643E21E93464088307E1AF7164A40
21622	Грачевка	7	73	366	45.249406999999998	45.275530000000003	52.359233000000003	52.345205999999997	0103000020E610000001000000050000005D328E91EC9F46400531D0B52F2C4A405D328E91EC9F46406E52D158FB2D4A409088299144A346406E52D158FB2D4A409088299144A346400531D0B52F2C4A405D328E91EC9F46400531D0B52F2C4A40
22204	Вязьмино	7	73	366	45.648879000000001	45.679628999999998	52.288266	52.273769999999999	0103000020E61000000100000005000000D50792770ED346401E5036E50A234A40D50792770ED346403D4679E6E5244A40E3344415FED646403D4679E6E5244A40E3344415FED646401E5036E50A234A40D50792770ED346401E5036E50A234A40
22012	Березовка 1-я	7	73	366	45.316313999999998	45.340055999999997	52.282195000000002	52.271455000000003	0103000020E610000001000000050000002BA226FA7CA84640F8AA9509BF224A402BA226FA7CA84640200C3CF71E244A407F677BF486AB4640200C3CF71E244A407F677BF486AB4640F8AA9509BF224A402BA226FA7CA84640F8AA9509BF224A40
21437	Березовка	7	73	366	45.106665	45.140011000000001	52.105604	52.079912999999998	0103000020E610000001000000050000005D50DF32A78D46403BC3D4963A0A4A405D50DF32A78D4640D4298F6E840D4A40460A65E1EB914640D4298F6E840D4A40460A65E1EB9146403BC3D4963A0A4A405D50DF32A78D46403BC3D4963A0A4A40
21732	Асметовка	7	73	366	44.905802000000001	44.955621999999998	52.345145000000002	52.327966000000004	0103000020E610000001000000050000006153E751F1734640981936CAFA294A406153E751F173464060B01BB62D2C4A4047AB5AD2517A464060B01BB62D2C4A4047AB5AD2517A4640981936CAFA294A406153E751F1734640981936CAFA294A40
21714	Абодим	7	73	366	45.196883	45.217975000000003	52.310394000000002	52.291691999999998	0103000020E61000000100000005000000B6114F76339946409E40D82956254A40B6114F7633994640F46F97FDBA274A403D2CD49AE69B4640F46F97FDBA274A403D2CD49AE69B46409E40D82956254A40B6114F76339946409E40D82956254A40
20050	Целинный	7	73	678	50.164171000000003	50.187015000000002	51.681899000000001	51.665244000000001	0103000020E61000000100000005000000CFF9298E031549401CEE23B726D54940CFF9298E031549406A16687748D74940446E861BF01749406A16687748D74940446E861BF01749401CEE23B726D54940CFF9298E031549401CEE23B726D54940
20045	Холманка	7	73	678	50.418331999999999	50.439720000000001	51.667389	51.656064999999998	0103000020E61000000100000005000000656F29E78B3549406E861BF0F9D34940656F29E78B354940E65AB4006DD54940D5B2B5BE48384940E65AB4006DD54940D5B2B5BE483849406E861BF0F9D34940656F29E78B3549406E861BF0F9D34940
20175	Харитоновка	7	73	678	50.213462	50.229298999999997	51.678052000000001	51.667271999999997	0103000020E6100000010000000500000029780AB9521B4940ACC43C2B69D5494029780AB9521B4940637E6E68CAD64940B4006DAB591D4940637E6E68CAD64940B4006DAB591D4940ACC43C2B69D5494029780AB9521B4940ACC43C2B69D54940
20850	Тепловский	7	73	678	49.828533999999998	49.860180999999997	52.118015	52.095021000000003	0103000020E61000000100000005000000E1CFF0660DEA484074B7EBA5290C4A40E1CFF0660DEA4840FEB7921D1B0F4A40FED137691AEE4840FEB7921D1B0F4A40FED137691AEE484074B7EBA5290C4A40E1CFF0660DEA484074B7EBA5290C4A40
53221	Тараховка	7	73	678	50.737602000000003	50.751390999999998	51.737260999999997	51.728631999999998	0103000020E610000001000000050000006BBB09BE695E4940D76839D043DD49406BBB09BE695E4940E1CE85915EDE49401EC18D942D604940E1CE85915EDE49401EC18D942D604940D76839D043DD49406BBB09BE695E4940D76839D043DD4940
19886	Смородинка	7	73	678	49.921481999999997	49.943707000000003	51.983747999999999	51.975206	0103000020E6100000010000000500000024ED461FF3F54840766EDA8CD3FC494024ED461FF3F54840B1C05774EBFD4940CE001764CBF84840B1C05774EBFD4940CE001764CBF84840766EDA8CD3FC494024ED461FF3F54840766EDA8CD3FC4940
20547	Пригорки	7	73	678	50.080682000000003	50.101657000000003	52.072108999999998	52.057220999999998	0103000020E610000001000000050000001DB0ABC9530A49407CD2890453074A401DB0ABC9530A4940A65F22DE3A094A406A34B918030D4940A65F22DE3A094A406A34B918030D49407CD2890453074A401DB0ABC9530A49407CD2890453074A40
19726	Перелюб	7	73	678	50.328392000000001	50.368879	51.878163000000001	51.846254999999999	0103000020E610000001000000050000004F22C2BF082A4940CA89761552EC49404F22C2BF082A494054C72AA567F049403197546D372F494054C72AA567F049403197546D372F4940CA89761552EC49404F22C2BF082A4940CA89761552EC4940
20426	Октябрьский	7	73	678	50.062733000000001	50.081435999999997	51.901375000000002	51.886085999999999	0103000020E61000000100000005000000A3B08BA207084940C3B81B446BF14940A3B08BA2070849404C37894160F34940C85BAE7E6C0A49404C37894160F34940C85BAE7E6C0A4940C3B81B446BF14940A3B08BA207084940C3B81B446BF14940
4706	Новый Перелюб	7	73	678	49.951127	49.963092000000003	51.975855000000003	51.973674000000003	0103000020E61000000100000005000000DAAB8F87BEF94840967B8159A1FC4940DAAB8F87BEF94840AD510FD1E8FC49400685419946FB4840AD510FD1E8FC49400685419946FB4840967B8159A1FC4940DAAB8F87BEF94840967B8159A1FC4940
20163	Нижняя Покровка	7	73	678	50.102519999999998	50.134149999999998	51.672355000000003	51.659472999999998	0103000020E61000000100000005000000CC9717601F0D494029CC7B9C69D44940CC9717601F0D4940AB2688BA0FD649401361C3D32B114940AB2688BA0FD649401361C3D32B11494029CC7B9C69D44940CC9717601F0D494029CC7B9C69D44940
19835	Натальин Яр	7	73	678	50.566741999999998	50.582687	51.784582	51.767859000000001	0103000020E6100000010000000500000083A279008B4849403A78263449E2494083A279008B484940E083D72E6DE44940F566D47C954A4940E083D72E6DE44940F566D47C954A49403A78263449E2494083A279008B4849403A78263449E24940
20659	Молодежный	7	73	678	49.529547000000001	49.553001999999999	51.954374000000001	51.941279000000002	0103000020E61000000100000005000000F3583332C8C34840AFB48CD47BF84940F3583332C8C348408C135FED28FA4940B14F00C5C8C648408C135FED28FA4940B14F00C5C8C64840AFB48CD47BF84940F3583332C8C34840AFB48CD47BF84940
19945	Кучумбетово	7	73	678	50.306905	50.334311999999997	51.700000000000003	51.689498999999998	0103000020E610000001000000050000004CFDBCA948274940F6CFD38041D849404CFDBCA9482749409A99999999D94940865451BCCA2A49409A99999999D94940865451BCCA2A4940F6CFD38041D849404CFDBCA948274940F6CFD38041D84940
20304	Кузябаево	7	73	678	49.932388000000003	49.948863000000003	51.684199999999997	51.678609999999999	0103000020E6100000010000000500000068976F7D58F74840895E46B1DCD6494068976F7D58F748402BF697DD93D7494036B1C05774F948402BF697DD93D7494036B1C05774F94840895E46B1DCD6494068976F7D58F74840895E46B1DCD64940
20235	Калинин	7	73	678	49.799005999999999	49.819190999999996	51.715860999999997	51.702193999999999	0103000020E6100000010000000500000065A71FD445E6484045B9347EE1D9494065A71FD445E64840ADBD4F55A1DB4940B9162D40DBE84840ADBD4F55A1DB4940B9162D40DBE8484045B9347EE1D9494065A71FD445E6484045B9347EE1D94940
19828	Иваниха	7	73	678	50.506762000000002	50.535544000000002	51.924785999999997	51.908431999999998	0103000020E61000000100000005000000836DC493DD404940E751F17F47F44940836DC493DD4049403AE63C635FF64940D6C8AEB48C4449403AE63C635FF64940D6C8AEB48C444940E751F17F47F44940836DC493DD404940E751F17F47F44940
20594	Грачев Куст	7	73	678	49.798144000000001	49.847057	52.008496999999998	51.986533000000001	0103000020E61000000100000005000000D3BF249529E648405FB69DB646FE4940D3BF249529E648409B8E006E16014A40876C205D6CEC48409B8E006E16014A40876C205D6CEC48405FB69DB646FE4940D3BF249529E648405FB69DB646FE4940
20756	Большая Тарасовка	7	73	678	49.495401999999999	49.522765	51.988368999999999	51.978839000000001	0103000020E61000000100000005000000BE2F2E5569BF48405186AA984AFD4940BE2F2E5569BF4840ABB019E082FE4940293FA9F6E9C24840ABB019E082FE4940293FA9F6E9C248405186AA984AFD4940BE2F2E5569BF48405186AA984AFD4940
18997	Старые Озинки	7	73	432	49.664070000000002	49.696058999999998	51.182389000000001	51.169553999999998	0103000020E610000001000000050000009B20EA3E00D54840F7730AF2B39549409B20EA3E00D548403813D38558974940118B187618D948403813D38558974940118B187618D94840F7730AF2B39549409B20EA3E00D54840F7730AF2B3954940
19574	Солянка	7	73	432	50.080035000000002	50.103974999999998	51.500607000000002	51.481765000000003	0103000020E6100000010000000500000087C43D963E0A4940C1ADBB79AABD494087C43D963E0A49400893E2E313C04940014D840D4F0D49400893E2E313C04940014D840D4F0D4940C1ADBB79AABD494087C43D963E0A4940C1ADBB79AABD4940
18477	Сланцевый Рудник	7	73	432	49.620556000000001	49.654888999999997	51.174551999999998	51.160189000000003	0103000020E6100000010000000500000015AB06616ECF4840E816BA128194494015AB06616ECF4840C7B94DB8579649404CC11A67D3D34840C7B94DB8579649404CC11A67D3D34840E816BA128194494015AB06616ECF4840E816BA1281944940
2456	Синегорский	7	73	432	49.899580999999998	49.930168999999999	51.331553999999997	51.309218999999999	0103000020E610000001000000050000002E8D5F7825F34840A226FA7C94A749402E8D5F7825F34840D26D895C70AA494063601DC70FF74840D26D895C70AA494063601DC70FF74840A226FA7C94A749402E8D5F7825F34840A226FA7C94A74940
19217	Пигари	7	73	432	49.674948999999998	49.709434999999999	51.433743	51.412883999999998	0103000020E61000000100000005000000E4BB94BA64D6484055850662D9B44940E4BB94BA64D6484039EFFFE384B74940A2D11DC4CEDA484039EFFFE384B74940A2D11DC4CEDA484055850662D9B44940E4BB94BA64D6484055850662D9B44940
19407	Первоцелинный	7	73	432	49.804791000000002	49.827060000000003	51.638741000000003	51.620570999999998	0103000020E61000000100000005000000BD8E386403E748404AECDADE6ECF4940BD8E386403E74840A3CEDC43C2D1494036EA211ADDE94840A3CEDC43C2D1494036EA211ADDE948404AECDADE6ECF4940BD8E386403E748404AECDADE6ECF4940
4104	Озинки	7	73	432	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
19411	Новочерниговка	7	73	432	49.952986000000003	49.978183999999999	51.615957000000002	51.598886	0103000020E61000000100000005000000DFC5FB71FBF948402104E44BA8CC4940DFC5FB71FBF94840035FD1ADD7CE494038BC202235FD4840035FD1ADD7CE494038BC202235FD48402104E44BA8CC4940DFC5FB71FBF948402104E44BA8CC4940
4703	Новозаволжский	7	73	432	50.282550999999998	50.307174000000003	51.537277000000003	51.51484	0103000020E61000000100000005000000DE3994A12A2449401956F146E6C14940DE3994A12A2449404EF2237EC5C449403C17467A512749404EF2237EC5C449403C17467A512749401956F146E6C14940DE3994A12A2449401956F146E6C14940
9306	Непряхин	7	73	432	49.729773000000002	49.774876999999996	51.279660999999997	51.261308	0103000020E610000001000000050000007D40A03369DD48407217618A72A149407D40A03369DD4840BB7B80EECBA3494017B6662B2FE34840BB7B80EECBA3494017B6662B2FE348407217618A72A149407D40A03369DD48407217618A72A14940
2353	Модин	7	73	432	49.383220999999999	49.429842999999998	51.179904999999998	51.155987000000003	0103000020E61000000100000005000000F911BF620DB14840F3CCCB61F7934940F911BF620DB1484085B18520079749400FB56D1805B7484085B18520079749400FB56D1805B74840F3CCCB61F7934940F911BF620DB14840F3CCCB61F7934940
19111	Липовский	7	73	432	49.511913999999997	49.534030000000001	51.390931000000002	51.374118000000003	0103000020E61000000100000005000000A92EE06586C14840276C3F19E3AF4940A92EE06586C148400DFFE9060AB249409C8A54185BC448400DFFE9060AB249409C8A54185BC44840276C3F19E3AF4940A92EE06586C14840276C3F19E3AF4940
18999	Горный	7	73	432	49.771481999999999	49.785674999999998	51.162607000000001	51.151415999999998	0103000020E61000000100000005000000F1B913ECBFE24840AA0B789961934940F1B913ECBFE24840E38C614ED0944940742497FF90E44840E38C614ED0944940742497FF90E44840AA0B789961934940F1B913ECBFE24840AA0B789961934940
19517	Белоглинный	7	73	432	50.067998000000003	50.080188	51.431722000000001	51.411423999999997	0103000020E61000000100000005000000C2189128B40849400E65A88AA9B44940C2189128B40849405B7B9FAA42B749400DC4B299430A49405B7B9FAA42B749400DC4B299430A49400E65A88AA9B44940C2189128B40849400E65A88AA9B44940
19319	Балаши	7	73	432	49.911394000000001	49.926772999999997	51.420012	51.399529000000001	0103000020E61000000100000005000000A4E2FF8EA8F44840DC662AC423B34940A4E2FF8EA8F44840BAF605F4C2B549406CE8667FA0F64840BAF605F4C2B549406CE8667FA0F64840DC662AC423B34940A4E2FF8EA8F44840DC662AC423B34940
17168	Шукеев	7	73	615	48.958210000000001	48.979239	50.681601000000001	50.670265000000001	0103000020E610000001000000050000009F5912A0A67A4840A453573ECB5549409F5912A0A67A4840E0F599B33E574940DFFB1BB4577D4840E0F599B33E574940DFFB1BB4577D4840A453573ECB5549409F5912A0A67A4840A453573ECB554940
17455	Чилижный	7	73	615	48.701740999999998	48.709367999999998	50.615456999999999	50.611685000000001	0103000020E6100000010000000500000094A12AA6D2594840153AAFB14B4E494094A12AA6D2594840118C834BC74E49401A6A1492CC5A4840118C834BC74E49401A6A1492CC5A4840153AAFB14B4E494094A12AA6D2594840153AAFB14B4E4940
18211	Чертанла	7	73	615	48.217413999999998	48.245666	50.594236000000002	50.584892000000004	0103000020E61000000100000005000000A5D8D138D41B484095D8B5BDDD4A4940A5D8D138D41B48408D0DDDEC0F4C49409CDEC5FB711F48408D0DDDEC0F4C49409CDEC5FB711F484095D8B5BDDD4A4940A5D8D138D41B484095D8B5BDDD4A4940
16969	Труба	7	73	615	48.111502999999999	48.128328000000003	50.174129999999998	50.162450999999997	0103000020E61000000100000005000000F433F5BA450E4840EB19C231CB144940F433F5BA450E484051A04FE4491649409F94490D6D10484051A04FE4491649409F94490D6D104840EB19C231CB144940F433F5BA450E4840EB19C231CB144940
17024	Таловка	7	73	615	48.169238	48.245612000000001	50.795302	50.769942	0103000020E61000000100000005000000C79E3D97A91548408EE89E758D624940C79E3D97A9154840C138B874CC654940A9C0C936701F4840C138B874CC654940A9C0C936701F48408EE89E758D624940C79E3D97A91548408EE89E758D624940
18162	Степной	7	73	615	48.661335000000001	48.689065999999997	50.716129000000002	50.694491999999997	0103000020E610000001000000050000009F5912A0A6544840B4AA251DE55849409F5912A0A6544840CD5B751DAA5B49408C648F5033584840CD5B751DAA5B49408C648F5033584840B4AA251DE55849409F5912A0A6544840B4AA251DE5584940
53177	Солянка	7	73	615	48.234859999999998	48.275480999999999	50.466475000000003	50.448044000000003	0103000020E61000000100000005000000BC9179E40F1E4840A3957B8159394940BC9179E40F1E484068B3EA73B53B4940AED51EF64223484068B3EA73B53B4940AED51EF642234840A3957B8159394940BC9179E40F1E4840A3957B8159394940
17988	Радищево	7	73	615	48.040779000000001	48.096572999999999	50.472512000000002	50.459147000000002	0103000020E610000001000000050000008AAE0B3F380548403C873254C53A49408AAE0B3F38054840D97BF1457B3C49409B560A815C0C4840D97BF1457B3C49409B560A815C0C48403C873254C53A49408AAE0B3F380548403C873254C53A4940
17921	Пограничное	7	73	615	48.618628999999999	48.651246999999998	50.538795	50.513306999999998	0103000020E61000000100000005000000B8AD2D3C2F4F484068E7340BB4414940B8AD2D3C2F4F4840C91F0C3CF74449401E4FCB0F5C534840C91F0C3CF74449401E4FCB0F5C53484068E7340BB4414940B8AD2D3C2F4F484068E7340BB4414940
17860	Петропавловка	7	73	615	47.905383999999998	47.930573000000003	50.262962000000002	50.249952	0103000020E610000001000000050000002C29779FE3F34740EFC8586DFE1F49402C29779FE3F347409E0B23BDA821494033C51C041DF747409E0B23BDA821494033C51C041DF74740EFC8586DFE1F49402C29779FE3F34740EFC8586DFE1F4940
17162	Песчаный Мар	7	73	615	48.686442999999997	48.706555999999999	50.763441999999998	50.746898999999999	0103000020E61000000100000005000000B8C83D5DDD5748402235ED629A5F4940B8C83D5DDD5748404832AB77B86149407365506D705A48404832AB77B86149407365506D705A48402235ED629A5F4940B8C83D5DDD5748402235ED629A5F4940
16800	Первомайский	7	73	615	48.313184	48.333458999999998	50.388829000000001	50.379139000000002	0103000020E61000000100000005000000B3D0CE6916284840AFD172A087304940B3D0CE6916284840425E0F26C531494047C7D5C8AE2A4840425E0F26C531494047C7D5C8AE2A4840AFD172A087304940B3D0CE6916284840AFD172A087304940
17081	Основной	7	73	615	48.739649999999997	48.775897000000001	50.692649000000003	50.671629000000003	0103000020E61000000100000005000000423EE8D9AC5E4840C90567F0F7554940423EE8D9AC5E4840B64DF1B8A85849404208C89750634840B64DF1B8A85849404208C89750634840C90567F0F7554940423EE8D9AC5E4840C90567F0F7554940
17770	Олоновка	7	73	615	48.389539999999997	48.419435999999997	50.729598000000003	50.711435000000002	0103000020E61000000100000005000000EE3D5C72DC314840691D554D105B4940EE3D5C72DC3148400F9D9E77635D4940ED612F14B03548400F9D9E77635D4940ED612F14B0354840691D554D105B4940EE3D5C72DC314840691D554D105B4940
9228	Новоузенск	7	73	615	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
16876	Мирный	7	73	615	48.113047999999999	48.125418000000003	50.354908999999999	50.343936999999997	0103000020E6100000010000000500000069705B5B780E48403271AB20062C494069705B5B780E48402D077AA86D2D4940352A70B20D1048402D077AA86D2D4940352A70B20D1048403271AB20062C494069705B5B780E48403271AB20062C4940
53242	Лохматовка	7	73	615	47.985917999999998	47.997641000000002	50.183214999999997	50.173465999999998	0103000020E61000000100000005000000D4449F8F32FE4740E57B462234164940D4449F8F32FE47407D91D096731749400A1346B3B2FF47407D91D096731749400A1346B3B2FF4740E57B462234164940D4449F8F32FE4740E57B462234164940
16870	Ленинский	7	73	615	48.162374	48.190688999999999	50.258054999999999	50.249053000000004	0103000020E6100000010000000500000040DCD5ABC814484040FCFCF7E01F494040DCD5ABC8144840DEC83CF2072149407D5A457F68184840DEC83CF2072149407D5A457F6818484040FCFCF7E01F494040DCD5ABC814484040FCFCF7E01F4940
3891	Куриловка	7	73	615	48.003704999999997	48.067791	50.746831	50.698697000000003	0103000020E6100000010000000500000074EACA67790048401B683EE76E59494074EACA6779004840CA518028985F494048FB1F60AD084840CA518028985F494048FB1F60AD0848401B683EE76E59494074EACA67790048401B683EE76E594940
17314	Кубанка	7	73	615	48.008242000000003	48.020108	50.590800000000002	50.584332000000003	0103000020E61000000100000005000000113AE8120E014840CE001764CB4A4940113AE8120E014840083D9B559F4B4940A93121E692024840083D9B559F4B4940A93121E692024840CE001764CB4A4940113AE8120E014840CE001764CB4A4940
17577	Крепость-Узень	7	73	615	47.991819999999997	48.023764	50.706449999999997	50.686874000000003	0103000020E6100000010000000500000065C22FF5F3FE4740823CBB7CEB57494065C22FF5F3FE47402D211FF46C5A49403C69E1B20A0348402D211FF46C5A49403C69E1B20A034840823CBB7CEB57494065C22FF5F3FE4740823CBB7CEB574940
3927	Киевка	7	73	615	48.441625000000002	48.463714000000003	50.788035999999998	50.773485000000001	0103000020E610000001000000050000004A0C022B873848402979758E016349404A0C022B873848400B09185DDE6449404359F8FA5A3B48400B09185DDE6449404359F8FA5A3B48402979758E016349404A0C022B873848402979758E01634940
13773	Карев	7	73	615	47.709507000000002	47.733455999999997	50.536842999999998	50.523902999999997	0103000020E610000001000000050000003CA41820D1DA47405DA3E5400F4349403CA41820D1DA4740130B7C45B74449400987DEE2E1DD4740130B7C45B74449400987DEE2E1DD47405DA3E5400F4349403CA41820D1DA47405DA3E5400F434940
17379	Дюрский	7	73	615	48.561073999999998	48.574593	50.669043000000002	50.641655	0103000020E610000001000000050000006551D845D14748404E2844C0215249406551D845D1474840124F7633A355494059C16F438C494840124F7633A355494059C16F438C4948404E2844C0215249406551D845D14748404E2844C021524940
17258	Дмитриевка	7	73	615	47.962724000000001	47.981516999999997	50.649622999999998	50.629246000000002	0103000020E6100000010000000500000083893F8A3AFB4740C59107228B50494083893F8A3AFB47405DDDB1D826534940E8BB5B59A2FD47405DDDB1D826534940E8BB5B59A2FD4740C59107228B50494083893F8A3AFB4740C59107228B504940
18068	Дейков	7	73	615	47.953156999999997	47.972892999999999	50.452683999999998	50.443328000000001	0103000020E610000001000000050000000B7A6F0C01FA474057B3CEF8BE3849400B7A6F0C01FA474013B69F8CF1394940F0C000C287FC474013B69F8CF1394940F0C000C287FC474057B3CEF8BE3849400B7A6F0C01FA474057B3CEF8BE384940
4040	Ближний	7	73	615	48.171042999999997	48.193868999999999	50.531387000000002	50.52026	0103000020E61000000100000005000000D89AADBCE41548405FB532E197424940D89AADBCE415484081423D7D04444940A75A0BB3D018484081423D7D04444940A75A0BB3D01848405FB532E197424940D89AADBCE41548405FB532E197424940
16974	Бессоновка	7	73	615	48.250642999999997	48.284294000000003	50.786180000000002	50.769708000000001	0103000020E6100000010000000500000054FCDF11152048401BBCAFCA8562494054FCDF11152048407862D68BA16449407A39ECBE632448407862D68BA16449407A39ECBE632448401BBCAFCA8562494054FCDF11152048401BBCAFCA85624940
17265	Алексеевка	7	73	615	47.988028999999997	48.001908	50.604751	50.595773999999999	0103000020E61000000100000005000000F23FF9BB77FE47404FE78A52424C4940F23FF9BB77FE4740959C137B684D4940E6CC76853E004840959C137B684D4940E6CC76853E0048404FE78A52424C4940F23FF9BB77FE47404FE78A52424C4940
16730	Алгайский	7	73	615	48.118743000000002	48.149115000000002	50.416589000000002	50.396833999999998	0103000020E6100000010000000500000081D07AF8320F48406EF8DD74CB32494081D07AF8320F4840CA6FD1C952354940E92B483316134840CA6FD1C952354940E92B4833161348406EF8DD74CB32494081D07AF8320F48406EF8DD74CB324940
2684	Чернышевка	7	73	462	46.059454000000002	46.108016999999997	51.972619999999999	51.956944	0103000020E61000000100000005000000E6CE4C309C0747403D0D18247DFA4940E6CE4C309C074740BFB7E9CF7EFC4940BD344580D30D4740BFB7E9CF7EFC4940BD344580D30D47403D0D18247DFA4940E6CE4C309C0747403D0D18247DFA4940
15504	Тепловка	7	73	462	46.113568999999998	46.147407999999999	52.083416999999997	52.054091999999997	0103000020E61000000100000005000000726BD26D890E4740D47C957CEC064A40726BD26D890E474018778368AD0A4A409A95ED43DE12474018778368AD0A4A409A95ED43DE124740D47C957CEC064A40726BD26D890E4740D47C957CEC064A40
53143	Тарханы	7	73	462	46.184024000000001	46.203670000000002	51.835338	51.812669999999997	0103000020E61000000100000005000000EDD632198E1747405C38109205E84940EDD632198E174740938D075BECEA49409296CADB111A4740938D075BECEA49409296CADB111A47405C38109205E84940EDD632198E1747405C38109205E84940
15200	Радищево	7	73	462	46.167369000000001	46.177250000000001	51.877518999999999	51.862777000000001	0103000020E610000001000000050000009FAEEE586C154740D95E0B7A6FEE49409FAEEE586C1547402F4FE78A52F04940A69BC420B01647402F4FE78A52F04940A69BC420B0164740D95E0B7A6FEE49409FAEEE586C154740D95E0B7A6FEE4940
15299	Новые Бурасы	7	73	462	46.039081000000003	46.106346000000002	52.145606999999998	52.114144000000003	0103000020E610000001000000050000008F72309B000547406F8445459C0E4A408F72309B00054740CA880B40A3124A40BC07E8BE9C0D4740CA880B40A3124A40BC07E8BE9C0D47406F8445459C0E4A408F72309B000547406F8445459C0E4A40
15395	Новоалексеевка	7	73	462	46.340654000000001	46.358162	51.970422999999997	51.952447999999997	0103000020E6100000010000000500000034A0DE8C9A2B4740FF91E9D0E9F9494034A0DE8C9A2B4740A22424D236FC4940C1559E40D82D4740A22424D236FC4940C1559E40D82D4740FF91E9D0E9F9494034A0DE8C9A2B4740FF91E9D0E9F94940
15603	Марьино-Лашмино	7	73	462	45.913406000000002	45.938963000000001	52.038438999999997	52.013424999999998	0103000020E610000001000000050000002FFCE07CEAF4464072F90FE9B7014A402FFCE07CEAF446400AF2B391EB044A40B89388F02FF846400AF2B391EB044A40B89388F02FF8464072F90FE9B7014A402FFCE07CEAF4464072F90FE9B7014A40
16071	Малые Озерки	7	73	462	45.829988999999998	45.854953000000002	52.301391000000002	52.276051000000002	0103000020E6100000010000000500000016855D143DEA46409983A0A355234A4016855D143DEA46408527F4FA93264A40FD4E93196FED46408527F4FA93264A40FD4E93196FED46409983A0A355234A4016855D143DEA46409983A0A355234A40
2807	Лох	7	73	462	45.842457000000003	45.869208999999998	52.154553	52.110509999999998	0103000020E61000000100000005000000A5A487A1D5EB4640C3F01131250E4A40A5A487A1D5EB4640D53F8864C8134A40C631923D42EF4640D53F8864C8134A40C631923D42EF4640C3F01131250E4A40A5A487A1D5EB4640C3F01131250E4A40
16114	Леляевка	7	73	462	45.879880999999997	45.906039999999997	52.405527999999997	52.383392999999998	0103000020E6100000010000000500000096AFCBF09FF04640F641960513314A4096AFCBF09FF046405FCE6C57E8334A40156F641EF9F346405FCE6C57E8334A40156F641EF9F34640F641960513314A4096AFCBF09FF04640F641960513314A40
16058	Кутьино	7	73	462	45.702795999999999	45.734408000000002	52.289037	52.269229000000003	0103000020E610000001000000050000003BE12538F5D9464041118B1876224A403BE12538F5D94640BF2A172AFF244A40DCF5D21401DE4640BF2A172AFF244A40DCF5D21401DE464041118B1876224A403BE12538F5D9464041118B1876224A40
2732	Ириновка	7	73	462	46.228175999999998	46.248944999999999	52.011263	51.991413000000001	0103000020E61000000100000005000000B5DD04DF341D474025EA059FE6FE4940B5DD04DF341D4740D253E41071014A4059C0046EDD1F4740D253E41071014A4059C0046EDD1F474025EA059FE6FE4940B5DD04DF341D474025EA059FE6FE4940
15550	Елшанка	7	73	462	46.002375000000001	46.043104999999997	52.079011000000001	52.048043999999997	0103000020E61000000100000005000000FCA9F1D24D0047406F62484E26064A40FCA9F1D24D0047401B834E081D0A4A40A4A5F276840547401B834E081D0A4A40A4A5F276840547406F62484E26064A40FCA9F1D24D0047406F62484E26064A40
53241	Динамо	7	73	462	46.076971	46.109499	52.370137999999997	52.353842999999998	0103000020E61000000100000005000000C6DE8B2FDA094740927538BA4A2D4A40C6DE8B2FDA094740E08096AE602F4A40ECF82F10040E4740E08096AE602F4A40ECF82F10040E4740927538BA4A2D4A40C6DE8B2FDA094740927538BA4A2D4A40
15676	Гремячка	7	73	462	45.712542999999997	45.756011999999998	52.101101	52.080947999999999	0103000020E6100000010000000500000032FFE89B34DB46409B560A815C0A4A4032FFE89B34DB4640E44BA8E0F00C4A4018B14F00C5E04640E44BA8E0F00C4A4018B14F00C5E046409B560A815C0A4A4032FFE89B34DB46409B560A815C0A4A40
15964	Вихляйка	7	73	462	45.803794000000003	45.833672	52.266672	52.258861000000003	0103000020E610000001000000050000004B5CC7B8E2E64640DD9A745B22214A404B5CC7B8E2E646402461DF4E22224A40A3CB9BC3B5EA46402461DF4E22224A40A3CB9BC3B5EA4640DD9A745B22214A404B5CC7B8E2E64640DD9A745B22214A40
15889	Бурасы	7	73	462	46.104137000000001	46.143932	52.216417	52.203079000000002	0103000020E61000000100000005000000DBA6785C540D474090C01F7EFE194A40DBA6785C540D474033A6608DB31B4A40876C205D6C12474033A6608DB31B4A40876C205D6C12474090C01F7EFE194A40DBA6785C540D474090C01F7EFE194A40
15957	Белоярский	7	73	462	45.841468999999996	45.873252000000001	52.250371000000001	52.232664	0103000020E6100000010000000500000085CC9541B5EB4640707A17EFC71D4A4085CC9541B5EB4640F46E2C280C204A405395B6B8C6EF4640F46E2C280C204A405395B6B8C6EF4640707A17EFC71D4A4085CC9541B5EB4640707A17EFC71D4A40
15251	Аряш	7	73	462	46.153965999999997	46.166713000000001	51.934100000000001	51.911444000000003	0103000020E6100000010000000500000014596B28B513474056116E32AAF4494014596B28B5134740C898BB9690F74940B66801DA56154740C898BB9690F74940B66801DA5615474056116E32AAF4494014596B28B513474056116E32AAF44940
12934	Ястребовка	7	73	1239	47.049182000000002	47.072915999999999	51.862336999999997	51.848303000000001	0103000020E61000000100000005000000A4C684984B864740A20C553195EC4940A4C684984B864740BC900E0F61EE494075ADBD4F55894740BC900E0F61EE494075ADBD4F55894740A20C553195EC4940A4C684984B864740A20C553195EC4940
13818	Яблоня	7	73	1239	47.741495999999998	47.754773	51.575836000000002	51.567383999999997	0103000020E61000000100000005000000B20E4757E9DE47400723F609A0C84940B20E4757E9DE474003EE79FEB4C94940B073D3669CE0474003EE79FEB4C94940B073D3669CE047400723F609A0C84940B20E4757E9DE47400723F609A0C84940
13544	Чкаловка	7	73	1239	47.306711	47.318784999999998	51.560167	51.548121000000002	0103000020E610000001000000050000006729594E42A747401BA034D428C649406729594E42A7474033A6608DB3C7494049BA66F2CDA8474033A6608DB3C7494049BA66F2CDA847401BA034D428C649406729594E42A747401BA034D428C64940
13879	Фурманово	7	73	1239	47.333956999999998	47.355364000000002	51.67107	51.649861999999999	0103000020E6100000010000000500000098A25C1ABFAA4740E27492AD2ED3494098A25C1ABFAA4740D2A92B9FE5D549407F164B917CAD4740D2A92B9FE5D549407F164B917CAD4740E27492AD2ED3494098A25C1ABFAA4740E27492AD2ED34940
14634	Фурмановка	7	73	1239	46.588822999999998	46.608441999999997	51.542940000000002	51.531612000000003	0103000020E61000000100000005000000F910548D5E4B4740A114ADDC0BC44940F910548D5E4B47405AD8D30E7FC54940A4C16D6DE14D47405AD8D30E7FC54940A4C16D6DE14D4740A114ADDC0BC44940F910548D5E4B4740A114ADDC0BC44940
13110	Степное	7	73	1239	47.215801999999996	47.222152999999999	51.611767999999998	51.603507	0103000020E61000000100000005000000A83462669F9B47401BF4A5B73FCD4940A83462669F9B4740A25EF0694ECE4940A9DA6E826F9C4740A25EF0694ECE4940A9DA6E826F9C47401BF4A5B73FCD4940A83462669F9B47401BF4A5B73FCD4940
13596	Солнечный	7	73	1239	47.479312999999998	47.491979999999998	51.488484	51.481831999999997	0103000020E6100000010000000500000019C6DD205ABD47404815C5ABACBD494019C6DD205ABD4740444FCAA486BE49409E245D33F9BE4740444FCAA486BE49409E245D33F9BE47404815C5ABACBD494019C6DD205ABD47404815C5ABACBD4940
12976	Семеновка	7	73	1239	47.335287000000001	47.354708000000002	51.774424000000003	51.759687	0103000020E6100000010000000500000011E335AFEAAA47402219726C3DE1494011E335AFEAAA4740679E5C5320E3494096D05D1267AD4740679E5C5320E3494096D05D1267AD47402219726C3DE1494011E335AFEAAA47402219726C3DE14940
14620	Раскатово	7	73	1239	46.623614000000003	46.642640999999998	51.512703999999999	51.503701999999997	0103000020E61000000100000005000000F4A96395D24F47400377A04E79C04940F4A96395D24F4740A243E048A0C14940CC086F0F42524740A243E048A0C14940CC086F0F425247400377A04E79C04940F4A96395D24F47400377A04E79C04940
13039	Пугачевка	7	73	1239	47.273384	47.286113	51.638668000000003	51.630578999999997	0103000020E61000000100000005000000F59F353FFEA24740AE450BD0B6D04940F59F353FFEA2474039807EDFBFD14940F0FACC599FA4474039807EDFBFD14940F0FACC599FA44740AE450BD0B6D04940F59F353FFEA24740AE450BD0B6D04940
14346	Приволжское	7	73	1239	46.699916999999999	46.739299000000003	51.697806	51.684339999999999	0103000020E610000001000000050000000C7558E1965947401DACFF7398D749400C7558E196594740EE79FEB451D94940967B8159A15E4740EE79FEB451D94940967B8159A15E47401DACFF7398D749400C7558E1965947401DACFF7398D74940
53235	Полековская	7	73	1239	47.219951999999999	47.236210999999997	51.683858999999998	51.667695999999999	0103000020E610000001000000050000004B581B63279C4740C3D5011077D549404B581B63279C4740A20914B188D749404CFA7B293C9E4740A20914B188D749404CFA7B293C9E4740C3D5011077D549404B581B63279C4740C3D5011077D54940
13210	Подлесное	7	73	1239	47.009422999999998	47.029204	51.827461999999997	51.812821	0103000020E61000000100000005000000446ADAC5348147404240BE840AE84940446ADAC53481474064575A46EAE94940C974E8F4BC83474064575A46EAE94940C974E8F4BC8347404240BE840AE84940446ADAC5348147404240BE840AE84940
14247	Павловка	7	73	1239	46.677325000000003	46.712592000000001	51.685507000000001	51.671841000000001	0103000020E61000000100000005000000B1E1E995B2564740548EC9E2FED54940B1E1E995B2564740EC1681B1BED7494014B2F336365B4740EC1681B1BED7494014B2F336365B4740548EC9E2FED54940B1E1E995B2564740548EC9E2FED54940
14528	Осиновский	7	73	1239	46.799270999999997	46.828071000000001	51.582917000000002	51.569752000000001	0103000020E6100000010000000500000013D21A834E664740516A2FA2EDC8494013D21A834E66474027A435069DCA49400DE2033BFE69474027A435069DCA49400DE2033BFE694740516A2FA2EDC8494013D21A834E664740516A2FA2EDC84940
14826	Орловское	7	73	1239	46.872421000000003	46.917057999999997	51.767161999999999	51.754072999999998	0103000020E61000000100000005000000FCABC77DAB6F4740F7E5CC7685E04940FCABC77DAB6F4740F25D4A5D32E249408044132862754740F25D4A5D32E249408044132862754740F7E5CC7685E04940FCABC77DAB6F4740F7E5CC7685E04940
12932	Михайловка	7	73	1239	47.015172	47.045642999999998	51.839399999999998	51.822330000000001	0103000020E610000001000000050000004FE8F527F18147408542041C42E949404FE8F527F181474096218E7571EB49404A253CA1D785474096218E7571EB49404A253CA1D78547408542041C42E949404FE8F527F18147408542041C42E94940
13487	Липовка	7	73	1239	47.384802000000001	47.421354000000001	51.555956000000002	51.535623999999999	0103000020E61000000100000005000000BBB7223141B14740F279C5538FC44940BBB7223141B14740EB01F39029C74940F70489EDEEB54740EB01F39029C74940F70489EDEEB54740F279C5538FC44940BBB7223141B14740F279C5538FC44940
14454	Красная Поляна	7	73	1239	46.595523999999997	46.618637999999997	51.687266000000001	51.675952000000002	0103000020E61000000100000005000000D6FD63213A4C474039D55A9885D64940D6FD63213A4C47408DD31055F8D749400B08AD872F4F47408DD31055F8D749400B08AD872F4F474039D55A9885D64940D6FD63213A4C474039D55A9885D64940
13766	Красная Звезда	7	73	1239	47.595187000000003	47.603594999999999	51.673175999999998	51.662394999999997	0103000020E610000001000000050000008F006E162FCC47405704FF5BC9D449408F006E162FCC4740DE3994A12AD64940BA83D89942CD4740DE3994A12AD64940BA83D89942CD47405704FF5BC9D449408F006E162FCC47405704FF5BC9D44940
12854	Колос	7	73	1239	47.246650000000002	47.272162000000002	51.771096999999997	51.759960999999997	0103000020E610000001000000050000007AC7293A929F4740239EEC6646E149407AC7293A929F47409885764EB3E24940639B5434D6A247409885764EB3E24940639B5434D6A24740239EEC6646E149407AC7293A929F4740239EEC6646E14940
13962	Кировское	7	73	1239	47.209496000000001	47.236866999999997	51.572578999999998	51.553178000000003	0103000020E610000001000000050000004852D2C3D09A4740F06E6589CEC649404852D2C3D09A47402DB0C7444AC94940354069A8519E47402DB0C7444AC94940354069A8519E4740F06E6589CEC649404852D2C3D09A4740F06E6589CEC64940
13400	Караман	7	73	1239	47.021137000000003	47.047781000000001	51.711827	51.695723999999998	0103000020E6100000010000000500000027DE019EB48247406A85E97B0DD9494027DE019EB482474074B4AA251DDB4940622F14B01D86474074B4AA251DDB4940622F14B01D8647406A85E97B0DD9494027DE019EB48247406A85E97B0DD94940
14244	Каменка	7	73	1239	46.881269000000003	46.904876999999999	51.583928999999998	51.568817000000003	0103000020E6100000010000000500000044FD2E6CCD7047405534D6FECEC8494044FD2E6CCD704740CE177B2FBECA494088F37002D3734740CE177B2FBECA494088F37002D37347405534D6FECEC8494044FD2E6CCD7047405534D6FECEC84940
14059	Калининское	7	73	1239	47.078691999999997	47.105857	51.519424999999998	51.500757999999998	0103000020E61000000100000005000000793A5794128A4740ED9A90D618C04940793A5794128A4740C6DCB5847CC24940BE86E0B88C8D4740C6DCB5847CC24940BE86E0B88C8D4740ED9A90D618C04940793A5794128A4740ED9A90D618C04940
13673	Имени Тельмана	7	73	1239	47.591405000000002	47.611275999999997	51.533904	51.514487000000003	0103000020E610000001000000050000006FD8B628B3CB4740CC9BC3B5DAC149406FD8B628B3CB47400F9A5DF756C44940336ABE4A3ECE47400F9A5DF756C44940336ABE4A3ECE4740CC9BC3B5DAC149406FD8B628B3CB4740CC9BC3B5DAC14940
12729	Зоркино	7	73	1239	47.163376	47.192742000000003	51.903225999999997	51.892755999999999	0103000020E61000000100000005000000C4793881E994474065A71FD445F24940C4793881E9944740CD72D9E89CF34940674815C5AB984740CD72D9E89CF34940674815C5AB98474065A71FD445F24940C4793881E994474065A71FD445F24940
13676	Заря	7	73	1239	47.570177999999999	47.596175000000002	51.598427000000001	51.582430000000002	0103000020E610000001000000050000000873BB97FBC84740CA1AF5108DCA49400873BB97FBC847408E05854199CC4940AED85F764FCC47408E05854199CC4940AED85F764FCC4740CA1AF5108DCA49400873BB97FBC84740CA1AF5108DCA4940
12805	Георгиевка	7	73	1239	47.261715000000002	47.287550000000003	51.939030000000002	51.927501999999997	0103000020E61000000100000005000000B3EF8AE07FA14740BF7CB262B8F64940B3EF8AE07FA1474040FB912232F849407FFB3A70CEA4474040FB912232F849407FFB3A70CEA44740BF7CB262B8F64940B3EF8AE07FA14740BF7CB262B8F64940
12852	Воротаевка	7	73	1239	47.246659000000001	47.267581	51.927129999999998	51.915970999999999	0103000020E61000000100000005000000CD21A985929F4740CE8AA8893EF54940CD21A985929F4740FB912232ACF64940F7031E1840A24740FB912232ACF64940F7031E1840A24740CE8AA8893EF54940CD21A985929F4740CE8AA8893EF54940
13966	Вознесенка	7	73	1239	47.293084	47.310124999999999	51.508383000000002	51.491669000000002	0103000020E610000001000000050000008D7DC9C683A5474080BA8102EFBE49408D7DC9C683A54740D36BB3B112C1494004560E2DB2A74740D36BB3B112C1494004560E2DB2A7474080BA8102EFBE49408D7DC9C683A5474080BA8102EFBE4940
14071	Водопьяновка	7	73	1239	47.094465999999997	47.114310000000003	51.594600999999997	51.583437000000004	0103000020E61000000100000005000000BE4A3E76178C474060234910AECA4940BE4A3E76178C47409E95B4E21BCC49408ACDC7B5A18E47409E95B4E21BCC49408ACDC7B5A18E474060234910AECA4940BE4A3E76178C474060234910AECA4940
12730	Васильевка	7	73	1239	47.188349000000002	47.217491000000003	51.911926999999999	51.900219999999997	0103000020E61000000100000005000000FE9DEDD11B984740419AB1683AF34940FE9DEDD11B98474071AB2006BAF449405116BEBED69B474071AB2006BAF449405116BEBED69B4740419AB1683AF34940FE9DEDD11B984740419AB1683AF34940
14163	Бородаевка	7	73	1239	46.854598000000003	46.883172999999999	51.684479000000003	51.668075999999999	0103000020E610000001000000050000000F9D9E77636D47400A9FAD8383D549400F9D9E77636D47403FE603029DD74940E8DA17D00B7147403FE603029DD74940E8DA17D00B7147400A9FAD8383D549400F9D9E77636D47400A9FAD8383D54940
14395	Бобровка	7	73	1239	46.615079999999999	46.650348000000001	51.652343999999999	51.643385000000002	0103000020E610000001000000050000003B3602F1BA4E474055DE8E705AD249403B3602F1BA4E4740F4DE180280D349406F826F9A3E534740F4DE180280D349406F826F9A3E53474055DE8E705AD249403B3602F1BA4E474055DE8E705AD24940
13503	Бобово	7	73	1239	47.487093000000002	47.503245	51.579777	51.572583999999999	0103000020E61000000100000005000000268E3C1059BE47403F1BB96E4AC94940268E3C1059BE47408BFCFA2136CA4940117008556AC047408BFCFA2136CA4940117008556AC047403F1BB96E4AC94940268E3C1059BE47403F1BB96E4AC94940
14114	Березовка	7	73	1239	46.823759000000003	46.845193000000002	51.668925000000002	51.650449000000002	0103000020E61000000100000005000000916456EF70694740A35BAFE941D34940916456EF70694740083D9B559FD5494071E7C2482F6C4740083D9B559FD5494071E7C2482F6C4740A35BAFE941D34940916456EF70694740A35BAFE941D34940
13321	Баскатовка	7	73	1239	46.973588999999997	47.000314000000003	51.806077000000002	51.787022	0103000020E61000000100000005000000675F79909E7C4740C39D0B23BDE44940675F79909E7C47406687F8872DE7494090DD054A0A8047406687F8872DE7494090DD054A0A804740C39D0B23BDE44940675F79909E7C4740C39D0B23BDE44940
13394	Александровка	7	73	1239	46.932364999999997	46.949334	51.766877999999998	51.759197	0103000020E61000000100000005000000AF777FBC57774740541C075E2DE14940AF777FBC57774740CD02ED0E29E249408D7DC9C683794740CD02ED0E29E249408D7DC9C683794740541C075E2DE14940AF777FBC57774740541C075E2DE14940
14743	1-я Андреевка	7	73	1239	46.765180000000001	46.786560000000001	51.674515999999997	51.667814	0103000020E61000000100000005000000D2C6116BF1614740CDE7DCED7AD54940D2C6116BF16147407A50508A56D64940BF2B82FFAD6447407A50508A56D64940BF2B82FFAD644740CDE7DCED7AD54940D2C6116BF1614740CDE7DCED7AD54940
3075	Яблочный	7	73	503	44.631824999999999	44.670560000000002	51.640445	51.625922000000003	0103000020E61000000100000005000000C9E53FA4DF50464068EC4B361ED04940C9E53FA4DF50464080F10C1AFAD14940BD00FBE8D455464080F10C1AFAD14940BD00FBE8D455464068EC4B361ED04940C9E53FA4DF50464068EC4B361ED04940
11997	Юнгеровка	7	73	503	45.094709000000002	45.130201	51.560648	51.552573000000002	0103000020E6100000010000000500000085D1AC6C1F8C464089D349B6BAC6494085D1AC6C1F8C4640AE484C50C3C749400874266DAA904640AE484C50C3C749400874266DAA90464089D349B6BAC6494085D1AC6C1F8C464089D349B6BAC64940
53155	Энгельс	7	73	503	44.536890999999997	45.458993	51.701495999999999	51.079065	0103000020E61000000100000005000000244223D8B84446400EA14ACD1E8A4940244223D8B84446402D23F59ECAD94940E50B5A48C0BA46402D23F59ECAD94940E50B5A48C0BA46400EA14ACD1E8A4940244223D8B84446400EA14ACD1E8A4940
12263	Широкий Карамыш	7	73	503	45.059575000000002	45.080379999999998	51.354531000000001	51.324637000000003	0103000020E6100000010000000500000061545227A0874640290989B48DA9494061545227A08746408735954561AD494051A04FE4498A46408735954561AD494051A04FE4498A4640290989B48DA9494061545227A0874640290989B48DA94940
11849	Шереметьевка	7	73	503	44.806870000000004	44.841743000000001	51.635123999999998	51.617635	0103000020E61000000100000005000000D00F238447674640B7EEE6A90ECF4940D00F238447674640CD7344BE4BD149408751103CBE6B4640CD7344BE4BD149408751103CBE6B4640B7EEE6A90ECF4940D00F238447674640B7EEE6A90ECF4940
11673	Чадаевка	7	73	503	44.745767000000001	44.775069999999999	51.391505000000002	51.372430999999999	0103000020E61000000100000005000000D0B7054B755F46401F82AAD1ABAF4940D0B7054B755F4640399CF9D51CB249402C0E677E35634640399CF9D51CB249402C0E677E356346401F82AAD1ABAF4940D0B7054B755F46401F82AAD1ABAF4940
9221	Урицкое	7	73	503	44.914569	44.952388999999997	51.446576999999998	51.421832000000002	0103000020E61000000100000005000000BC77D4981075464001344A97FEB54940BC77D49810754640A912656F29B94940FA08FCE1E7794640A912656F29B94940FA08FCE1E779464001344A97FEB54940BC77D4981075464001344A97FEB54940
12577	Раздольное	7	73	503	45.230218999999998	45.256163000000001	51.246724999999998	51.23556	0103000020E610000001000000050000007BF5F1D0779D4640751F80D4269E49407BF5F1D0779D4640840D4FAF949F4940FEB8FDF2C9A04640840D4FAF949F4940FEB8FDF2C9A04640751F80D4269E49407BF5F1D0779D4640751F80D4269E4940
11905	Октябрьский	7	73	503	45.040270999999997	45.064804000000002	51.555261000000002	51.544983999999999	0103000020E6100000010000000500000015FDA19927854640F06B2409C2C5494015FDA1992785464044DFDDCA12C7494033535A7F4B88464044DFDDCA12C7494033535A7F4B884640F06B2409C2C5494015FDA19927854640F06B2409C2C54940
11856	Новая Красавка	7	73	503	44.931547999999999	44.952756999999998	51.564270999999998	51.543180999999997	0103000020E61000000100000005000000BD5301F73C7746407F677BF486C54940BD5301F73C774640658A39083AC849407D04FEF0F3794640658A39083AC849407D04FEF0F37946407F677BF486C54940BD5301F73C7746407F677BF486C54940
12410	Невежкино	7	73	503	44.930973000000002	44.961478999999997	51.233235999999998	51.208240000000004	0103000020E61000000100000005000000C13A8E1F2A7746400ADCBA9BA79A4940C13A8E1F2A774640FB1F60ADDA9D494038656EBE117B4640FB1F60ADDA9D494038656EBE117B46400ADCBA9BA79A4940C13A8E1F2A7746400ADCBA9BA79A4940
3039	Лысые Горы	7	73	503	44.822816000000003	44.858586000000003	51.566929999999999	51.534939999999999	0103000020E610000001000000050000001250E108526946403FA9F6E978C449401250E10852694640868F882991C84940D8666325E66D4640868F882991C84940D8666325E66D46403FA9F6E978C449401250E108526946403FA9F6E978C44940
3151	Ключи	7	73	503	45.172314	45.204546000000001	51.440739000000001	51.426729000000002	0103000020E610000001000000050000004C5299620E9646409DA04D0E9FB649404C5299620E9646402F89B3226AB84940894336902E9A46402F89B3226AB84940894336902E9A46409DA04D0E9FB649404C5299620E9646409DA04D0E9FB64940
12492	Двоенка	7	73	503	45.278683999999998	45.308014	51.394061999999998	51.380735000000001	0103000020E6100000010000000500000090F5D4EAABA34640A6B8AAECBBB0494090F5D4EAABA34640554CA59F70B24940E65AB4006DA74640554CA59F70B24940E65AB4006DA74640A6B8AAECBBB0494090F5D4EAABA34640A6B8AAECBBB04940
12002	Гремячий	7	73	503	45.203414000000002	45.225566000000001	51.485864999999997	51.465983999999999	0103000020E6100000010000000500000037C64E78099A4640C93A1C5DA5BB494037C64E78099A4640B1A206D330BE4940768BC058DF9C4640B1A206D330BE4940768BC058DF9C4640C93A1C5DA5BB494037C64E78099A4640C93A1C5DA5BB4940
11659	Бутырки	7	73	503	44.791491000000001	44.829372999999997	51.538761000000001	51.506723000000001	0103000020E61000000100000005000000070ABC934F654640C5909C4CDCC04940070ABC934F6546401DAED51EF6C44940BB97FBE4286A46401DAED51EF6C44940BB97FBE4286A4640C5909C4CDCC04940070ABC934F654640C5909C4CDCC04940
12350	Большие Копены	7	73	503	44.981233000000003	45.016438000000001	51.201608999999998	51.180937999999998	0103000020E61000000100000005000000C460FE0A997D4640444DF4F928974940C460FE0A997D464025CADE52CE994940B134F0A31A82464025CADE52CE994940B134F0A31A824640444DF4F928974940C460FE0A997D4640444DF4F928974940
11726	Большая Рельня	7	73	503	44.718305999999998	44.765332000000001	51.610996999999998	51.590197000000003	0103000020E61000000100000005000000A2427573F15B4640429946938BCB4940A2427573F15B4640207A522635CE4940884A2366F6614640207A522635CE4940884A2366F6614640429946938BCB4940A2427573F15B4640429946938BCB4940
12601	Большая Каменка	7	73	503	45.172277999999999	45.195787000000003	51.330540999999997	51.316138000000002	0103000020E61000000100000005000000FFE89B340D964640ED82C13577A84940FFE89B340D9646405A7EE02A4FAA4940B1FD648C0F9946405A7EE02A4FAA4940B1FD648C0F994640ED82C13577A84940FFE89B340D964640ED82C13577A84940
12484	Большая Дмитриевка	7	73	503	45.242427999999997	45.270473000000003	51.354633	51.341704999999997	0103000020E610000001000000050000003DD175E1079F464099F04BFDBCAB49403DD175E1079F46408B8A389D64AD4940BBB9F8DB9EA246408B8A389D64AD4940BBB9F8DB9EA2464099F04BFDBCAB49403DD175E1079F464099F04BFDBCAB4940
12331	Барсучий	7	73	503	45.0045	45.011983000000001	51.317061000000002	51.308430000000001	0103000020E610000001000000050000007F6ABC74938046407A8D5DA27AA749407F6ABC749380464025EB707495A84940D28DB0A88881464025EB707495A84940D28DB0A8888146407A8D5DA27AA749407F6ABC74938046407A8D5DA27AA74940
3212	Атаевка	7	73	503	44.825484000000003	44.845193000000002	51.300806000000001	51.283554000000002	0103000020E6100000010000000500000086AFAF75A969464033535A7F4BA4494086AFAF75A969464065389ECF80A6494071E7C2482F6C464065389ECF80A6494071E7C2482F6C464033535A7F4BA4494086AFAF75A969464033535A7F4BA44940
11182	Чистопольский	7	73	193	48.852801999999997	48.885472999999998	51.746613000000004	51.728135000000002	0103000020E6100000010000000500000050FBAD9D286D48405709168733DD494050FBAD9D286D48405DE2C80391DF4940D93EE42D577148405DE2C80391DF4940D93EE42D577148405709168733DD494050FBAD9D286D48405709168733DD4940
10969	Толстовка	7	73	193	48.733514	48.766643999999999	51.922493000000003	51.903565	0103000020E610000001000000050000003E9468C9E35D4840B6679604A8F349403E9468C9E35D4840FCE4284014F649405AD6FD6321624840FCE4284014F649405AD6FD6321624840B6679604A8F349403E9468C9E35D4840B6679604A8F34940
10873	Сулак	7	73	193	48.332776000000003	48.379748999999997	51.870663	51.825702999999997	0103000020E6100000010000000500000065726A67982A4840C39ACAA2B0E9494065726A67982A48402B6B9BE271EF494027D87F9D9B3048402B6B9BE271EF494027D87F9D9B304840C39ACAA2B0E9494065726A67982A4840C39ACAA2B0E94940
53178	Светлый	7	73	193	48.956943000000003	48.976823000000003	51.737501000000002	51.723025	0103000020E610000001000000050000006D91B41B7D7A48405F984C158CDC49406D91B41B7D7A484037E2C96E66DE4940857D3B89087D484037E2C96E66DE4940857D3B89087D48405F984C158CDC49406D91B41B7D7A48405F984C158CDC4940
10799	Савельевка	7	73	193	48.484681000000002	48.51773	51.707299999999996	51.694673999999999	0103000020E610000001000000050000000DFFE9060A3E4840D5B0DF13EBD849400DFFE9060A3E4840FB3A70CE88DA49403C1405FA44424840FB3A70CE88DA49403C1405FA44424840D5B0DF13EBD849400DFFE9060A3E4840D5B0DF13EBD84940
11391	Римско-Корсаковка	7	73	193	48.523434000000002	48.552880999999999	51.583896000000003	51.570222000000001	0103000020E61000000100000005000000A7CEA3E2FF424840D8BAD408FDC84940A7CEA3E2FF424840F321A81ABDCA494036CAFACDC4464840F321A81ABDCA494036CAFACDC4464840D8BAD408FDC84940A7CEA3E2FF424840D8BAD408FDC84940
11054	Раздольное	7	73	193	48.885553999999999	48.917237999999998	51.826521	51.805320000000002	0103000020E61000000100000005000000C66B5ED5597148404968CBB914E74940C66B5ED559714840863AAC70CBE949400053060E68754840863AAC70CBE949400053060E687548404968CBB914E74940C66B5ED5597148404968CBB914E74940
11334	Подшибаловка	7	73	193	48.542335000000001	48.565663999999998	51.543258999999999	51.528167000000003	0103000020E61000000100000005000000F33CB83B6B454840C9E9EBF99AC34940F33CB83B6B454840FB20CB8289C5494024438EAD67484840FB20CB8289C5494024438EAD67484840C9E9EBF99AC34940F33CB83B6B454840C9E9EBF99AC34940
10966	Петровский	7	73	193	48.728996000000002	48.769609000000003	51.829248999999997	51.809207000000001	0103000020E610000001000000050000001975ADBD4F5D4840DE58501894E749401975ADBD4F5D4840CF9ECBD424EA494088DA368C82624840CF9ECBD424EA494088DA368C82624840DE58501894E749401975ADBD4F5D4840DE58501894E74940
11228	Октябрьский	7	73	193	49.109639000000001	49.12491	51.639958999999998	51.628442999999997	0103000020E61000000100000005000000DEAE97A6088E48403733FAD170D04940DEAE97A6088E4840F3E32F2DEAD14940C078060DFD8F4840F3E32F2DEAD14940C078060DFD8F48403733FAD170D04940DEAE97A6088E48403733FAD170D04940
11279	Милорадовка	7	73	193	48.759520999999999	48.788643999999998	51.628152999999998	51.610968999999997	0103000020E6100000010000000500000007D0EFFB3761484056EF703B34CE494007D0EFFB3761484030F1475167D04940E3175E49F264484030F1475167D04940E3175E49F264484056EF703B34CE494007D0EFFB3761484056EF703B34CE4940
11052	Корнеевка	7	73	193	48.728062000000001	48.775348999999999	51.770662000000002	51.742620000000002	0103000020E61000000100000005000000EDBAB722315D484082AD122C0EDF4940EDBAB722315D48408E226B0DA5E249403FFED2A23E6348408E226B0DA5E249403FFED2A23E63484082AD122C0EDF4940EDBAB722315D484082AD122C0EDF4940
2974	Емельяновка	7	73	193	48.521081000000002	48.542389	51.618808999999999	51.604005000000001	0103000020E6100000010000000500000093C83EC8B24248406CCF2C0950CD494093C83EC8B242484038BC202235CF4940E65AB4006D45484038BC202235CF4940E65AB4006D4548406CCF2C0950CD494093C83EC8B24248406CCF2C0950CD4940
11141	Дальний	7	73	193	48.785671000000001	48.800232000000001	51.681542	51.667428000000001	0103000020E61000000100000005000000333509DE90644840A437DC476ED54940333509DE90644840DB6CACC43CD74940399B8E006E664840DB6CACC43CD74940399B8E006E664840A437DC476ED54940333509DE90644840A437DC476ED54940
707	Горный	7	73	193	48.516724000000004	48.595255000000002	51.801822999999999	51.739457999999999	0103000020E610000001000000050000007787140324424840FE614B8FA6DE494077871403244248401E17D522A2E64940E7E3DA50314C48401E17D522A2E64940E7E3DA50314C4840FE614B8FA6DE49407787140324424840FE614B8FA6DE4940
11326	Головинщено	7	73	193	48.714326	48.739972999999999	51.536766999999998	51.520422000000003	0103000020E610000001000000050000005C57CC086F5B4840390F27309DC249405C57CC086F5B48403849F3C7B4C4494025766D6FB75E48403849F3C7B4C4494025766D6FB75E4840390F27309DC249405C57CC086F5B4840390F27309DC24940
10878	Большая Сакма	7	73	193	48.500509000000001	48.534996	51.892906000000004	51.867576	0103000020E61000000100000005000000452DCDAD10404840B265F9BA0CEF4940452DCDAD104048407B336ABE4AF24940D3BEB9BF7A4448407B336ABE4AF24940D3BEB9BF7A444840B265F9BA0CEF4940452DCDAD10404840B265F9BA0CEF4940
9993	Ямское	7	73	166	47.214813999999997	47.244987999999999	50.982149	50.964725999999999	0103000020E61000000100000005000000895C70067F9B4740EACC3D247C7B4940895C70067F9B47404966F50EB77D4940CBF44BC45B9F47404966F50EB77D4940CBF44BC45B9F4740EACC3D247C7B4940895C70067F9B4740EACC3D247C7B4940
10190	Чкалово	7	73	166	47.034728000000001	47.065055000000001	50.736457000000001	50.717104999999997	0103000020E61000000100000005000000B42094F7718447402766BD18CA5B4940B42094F77184474084F41439445E49407CB8E4B85388474084F41439445E49407CB8E4B8538847402766BD18CA5B4940B42094F7718447402766BD18CA5B4940
10097	Усатово	7	73	166	46.881610000000002	46.932662000000001	50.803209000000003	50.760359000000001	0103000020E61000000100000005000000CDE9B298D8704740111C977153614940CDE9B298D87047402B6D718DCF664940691CEA77617747402B6D718DCF664940691CEA7761774740111C977153614940CDE9B298D8704740111C977153614940
53169	Студгородок	7	73	166	46.519697000000001	47.437497	51.201298999999999	50.522430999999997	0103000020E61000000100000005000000276A696E8542474052B5DD04DF424940276A696E85424740D7DB662AC49949408F8CD5E6FFB74740D7DB662AC49949408F8CD5E6FFB7474052B5DD04DF424940276A696E8542474052B5DD04DF424940
9592	Семенной	7	73	166	47.047907000000002	47.065334	50.92165	50.909055000000002	0103000020E61000000100000005000000EF1F0BD121864740F5A10BEA5B744940EF1F0BD121864740E02D90A0F87549408FA850DD5C884740E02D90A0F87549408FA850DD5C884740F5A10BEA5B744940EF1F0BD121864740F5A10BEA5B744940
9797	Репное	7	73	166	47.284038000000002	47.312280999999999	51.104498999999997	51.089543999999997	0103000020E610000001000000050000001F69705B5BA44740C9C6832D768B49401F69705B5BA447407BBB2539608D4940C214E5D2F8A747407BBB2539608D4940C214E5D2F8A74740C9C6832D768B49401F69705B5BA44740C9C6832D768B4940
10556	Рекорд	7	73	166	46.653447	46.674486000000002	50.973399000000001	50.957731000000003	0103000020E61000000100000005000000AC55BB26A4534740C5AEEDED967A4940AC55BB26A4534740C47AA356987C494010CEA78E55564740C47AA356987C494010CEA78E55564740C5AEEDED967A4940AC55BB26A4534740C5AEEDED967A4940
10496	Первомайское	7	73	166	46.734071	46.780684999999998	50.938845999999998	50.922092999999997	0103000020E6100000010000000500000094F8DC09F65D47406D6FB7240776494094F8DC09F65D47407EFD101B2C78494027BD6F7CED6347407EFD101B2C78494027BD6F7CED6347406D6FB7240776494094F8DC09F65D47406D6FB72407764940
10606	Норки	7	73	166	46.954580999999997	46.980443000000001	50.937358000000003	50.928344000000003	0103000020E610000001000000050000000531D0B52F7A47400BB8E7F9D37649400531D0B52F7A47406E52D158FB774940CB4BFE277F7D47406E52D158FB774940CB4BFE277F7D47400BB8E7F9D37649400531D0B52F7A47400BB8E7F9D3764940
9634	Логиновка	7	73	166	47.048904	47.072690999999999	51.010652	50.983448000000003	0103000020E6100000010000000500000061527C7C4286474087A8C29FE17D494061527C7C4286474089D1730B5D81494055DB4DF04D89474089D1730B5D81494055DB4DF04D89474087A8C29FE17D494061527C7C4286474087A8C29FE17D4940
10253	Лепехинка	7	73	166	46.907238999999997	46.927774999999997	50.661267000000002	50.630046	0103000020E61000000100000005000000EF53556820744740E17CEA58A5504940EF535568207447404776A565A4544940F085C954C17647404776A565A4544940F085C954C1764740E17CEA58A5504940EF53556820744740E17CEA58A5504940
9729	Лебедевка	7	73	166	47.128017999999997	47.153953000000001	51.085622999999998	51.067995000000003	0103000020E6100000010000000500000050A6D1E46290474051A5660FB488494050A6D1E4629047408864C8B1F58A4940800F5EBBB49347408864C8B1F58A4940800F5EBBB493474051A5660FB488494050A6D1E46290474051A5660FB4884940
10400	Лавровка	7	73	166	46.908183000000001	46.934189000000003	50.966296999999997	50.940916999999999	0103000020E610000001000000050000003FE42D573F7447400EA0DFF76F7849403FE42D573F744740889CBE9EAF7B494038A4518193774740889CBE9EAF7B494038A45181937747400EA0DFF76F7849403FE42D573F7447400EA0DFF76F784940
512	Красный Кут	7	73	166	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
10062	Комсомольское	7	73	166	47.027973000000003	47.062027999999998	50.794186000000003	50.775798000000002	0103000020E61000000100000005000000E415889E94834740AF264F594D634940E415889E94834740757808E3A7654940D8B79388F0874740757808E3A7654940D8B79388F0874740AF264F594D634940E415889E94834740AF264F594D634940
10334	Кирово	7	73	166	46.686092000000002	46.716689000000002	50.812264999999996	50.799093999999997	0103000020E610000001000000050000000C06D7DCD1574740043752B6486649400C06D7DCD1574740BC57AD4CF867494094331477BC5B4740BC57AD4CF867494094331477BC5B4740043752B6486649400C06D7DCD1574740043752B648664940
9885	Карпенка	7	73	166	47.247773000000002	47.277695999999999	51.110199999999999	51.092910000000003	0103000020E6100000010000000500000079EA9106B79F474056BC9179E48B494079EA9106B79F474075029A081B8E4940711DE38A8BA3474075029A081B8E4940711DE38A8BA3474056BC9179E48B494079EA9106B79F474056BC9179E48B4940
10506	Интернациональное	7	73	166	46.695821000000002	46.732076999999997	51.096428000000003	51.080235999999999	0103000020E610000001000000050000005D6F9BA9105947401EFB592C458A49405D6F9BA9105947409835B1C0578C4940AF93FAB2B45D47409835B1C0578C4940AF93FAB2B45D47401EFB592C458A49405D6F9BA9105947401EFB592C458A4940
9527	Загородный	7	73	166	46.968873000000002	47.005488	50.981836999999999	50.960147999999997	0103000020E610000001000000050000001C7DCC07047C4740EFA83121E67A49401C7DCC07047C47405A80B6D5AC7D49409E42AED4B38047405A80B6D5AC7D49409E42AED4B3804740EFA83121E67A49401C7DCC07047C4740EFA83121E67A4940
9992	Журавлевка	7	73	166	47.121074	47.145085999999999	50.893666000000003	50.882483999999998	0103000020E61000000100000005000000AD32535A7F8F4740239F573CF5704940AD32535A7F8F474009C6C1A563724940C18D942D9292474009C6C1A563724940C18D942D92924740239F573CF5704940AD32535A7F8F4740239F573CF5704940
9736	Ждановка	7	73	166	47.140936000000004	47.162011	51.071832999999998	51.054036000000004	0103000020E610000001000000050000001F6ADB300A9247404167D2A6EA8649401F6ADB300A92474004E3E0D231894940CF4BC5C6BC94474004E3E0D231894940CF4BC5C6BC9447404167D2A6EA8649401F6ADB300A9247404167D2A6EA864940
10192	Дьяковка	7	73	166	46.756565000000002	46.803879000000002	50.737112000000003	50.699747000000002	0103000020E610000001000000050000002D26361FD7604740B03C484F915949402D26361FD76047409DBE9EAF595E49407978CF81E56647409DBE9EAF595E49407978CF81E5664740B03C484F915949402D26361FD7604740B03C484F91594940
9941	Верхний Еруслан	7	73	166	46.998832	47.023103999999996	50.961526999999997	50.943340999999997	0103000020E6100000010000000500000061191BBAD97F4740EBFCDB65BF78494061191BBAD97F4740499C1551137B494011346612F5824740499C1551137B494011346612F5824740EBFCDB65BF78494061191BBAD97F4740EBFCDB65BF784940
10397	Ахмат	7	73	166	46.917256000000002	46.952064999999997	50.945531000000003	50.922649	0103000020E61000000100000005000000A70705A568754740F357C85C19764940A70705A568754740562DE9280779494047551344DD794740562DE9280779494047551344DD794740F357C85C19764940A70705A568754740F357C85C19764940
8830	Усть-Золиха	7	73	116	45.531128000000002	45.560457999999997	50.980804999999997	50.969479999999997	0103000020E61000000100000005000000B5FE9600FCC346402310AFEB177C4940B5FE9600FCC346406B60AB048B7D49400A647616BDC746406B60AB048B7D49400A647616BDC746402310AFEB177C4940B5FE9600FCC346402310AFEB177C4940
9016	Старая Топовка	7	73	116	45.292796000000003	45.327238000000001	50.981496999999997	50.966388000000002	0103000020E610000001000000050000002733DE567AA54640999F1B9AB27B49402733DE567AA54640A10F96B1A17D494015014EEFE2A94640A10F96B1A17D494015014EEFE2A94640999F1B9AB27B49402733DE567AA54640999F1B9AB27B4940
470	Сплавнуха	7	73	116	45.363169999999997	45.392006000000002	51.074362000000001	51.058360999999998	0103000020E61000000100000005000000B471C45A7CAE4640512E8D5F78874940B471C45A7CAE46405708ABB184894940FBEAAA402DB246405708ABB184894940FBEAAA402DB24640512E8D5F78874940B471C45A7CAE4640512E8D5F78874940
7819	Сосновка	7	73	116	45.764662999999999	45.790444999999998	51.196474000000002	51.183179000000003	0103000020E610000001000000050000000ABB287AE0E146403128D368729749400ABB287AE0E14640D5415E0F26994940B324404D2DE54640D5415E0F26994940B324404D2DE546403128D368729749400ABB287AE0E146403128D36872974940
7920	Садовое	7	73	116	45.839995999999999	45.872183	51.044528999999997	51.033014999999999	0103000020E61000000100000005000000AA622AFD84EB464083A3E4D539844940AA622AFD84EB46409E5C5320B385494047904AB1A3EF46409E5C5320B385494047904AB1A3EF464083A3E4D539844940AA622AFD84EB464083A3E4D539844940
8274	Рогаткино	7	73	116	45.703946000000002	45.735809000000003	50.902937000000001	50.890273999999998	0103000020E6100000010000000500000034130CE71ADA4640533D997FF471494034130CE71ADA464097AC8A70937349401E8D43FD2EDE464097AC8A70937349401E8D43FD2EDE4640533D997FF471494034130CE71ADA4640533D997FF4714940
8054	Ревино	7	73	116	45.849141000000003	45.869613000000001	50.935048000000002	50.921207000000003	0103000020E61000000100000005000000AC58FCA6B0EC464053EC681CEA754940AC58FCA6B0EC4640591822A7AF7749409696917A4FEF4640591822A7AF7749409696917A4FEF464053EC681CEA754940AC58FCA6B0EC464053EC681CEA754940
8597	Первомайское	7	73	116	45.470519000000003	45.498313000000003	50.790393999999999	50.777985000000001	0103000020E61000000100000005000000C59272F739BC4640A8E3310395634940C59272F739BC4640317A6EA12B654940F9156BB8C8BF4640317A6EA12B654940F9156BB8C8BF4640A8E3310395634940C59272F739BC4640A8E3310395634940
53191	Паницкая	7	73	116	45.485880000000002	45.522792000000003	51.196016	51.167966999999997	0103000020E61000000100000005000000E7E3DA5031BE464053E751F17F954940E7E3DA5031BE464012BF620D17994940234E27D9EAC2464012BF620D17994940234E27D9EAC2464053E751F17F954940E7E3DA5031BE464053E751F17F954940
8382	Нижняя Банновка	7	73	116	45.640335999999998	45.657386000000002	50.734718000000001	50.726461999999998	0103000020E61000000100000005000000C939B187F6D14640B4E4F1B4FC5C4940C939B187F6D146402AE44A3D0B5E4940946C753925D446402AE44A3D0B5E4940946C753925D44640B4E4F1B4FC5C4940C939B187F6D14640B4E4F1B4FC5C4940
9102	Некрасово	7	73	116	45.282870000000003	45.325170999999997	51.171508000000003	51.154032000000001	0103000020E6100000010000000500000080828B1535A44640CC441152B793494080828B1535A446404E8061F9F3954940C64D0D349FA946404E8061F9F3954940C64D0D349FA94640CC441152B793494080828B1535A44640CC441152B7934940
203	Мордово	7	73	116	45.792555999999998	45.819459999999999	51.127007999999996	51.115549000000001	0103000020E61000000100000005000000D11F9A7972E54640F20A444FCA8E4940D11F9A7972E54640492A53CC41904940A930B610E4E84640492A53CC41904940A930B610E4E84640F20A444FCA8E4940D11F9A7972E54640F20A444FCA8E4940
8319	Меловое	7	73	116	45.616073	45.639932000000002	50.792152999999999	50.782769000000002	0103000020E610000001000000050000006C79E57ADBCE46404CA94BC6316449406C79E57ADBCE4640D236FE4465654940FAD4B14AE9D14640D236FE4465654940FAD4B14AE9D146404CA94BC6316449406C79E57ADBCE46404CA94BC631644940
7287	Луганское	7	73	116	45.651924999999999	45.677607000000002	51.177872000000001	51.161346999999999	0103000020E61000000100000005000000EF38454772D346406327BC04A7944940EF38454772D34640E36F7B82C4964940354580D3BBD64640E36F7B82C4964940354580D3BBD646406327BC04A7944940EF38454772D346406327BC04A7944940
53158	Красноармейск	7	73	116	45.082715999999998	46.067494000000003	51.246195	50.550558000000002	0103000020E610000001000000050000008F6D1970968A46408D463EAF784649408F6D1970968A464028B85851839F49408F56B5A4A308474028B85851839F49408F56B5A4A30847408D463EAF784649408F6D1970968A46408D463EAF78464940
251	Ключи	7	73	116	45.679206000000001	45.706246	50.977390999999997	50.964770999999999	0103000020E610000001000000050000009D9FE238F0D646408A90BA9D7D7B49409D9FE238F0D64640CE33F6251B7D49402577D84466DA4640CE33F6251B7D49402577D84466DA46408A90BA9D7D7B49409D9FE238F0D646408A90BA9D7D7B4940
8705	Карамышевка	7	73	116	45.389149000000003	45.412469999999999	50.928032000000002	50.915444000000001	0103000020E61000000100000005000000B4226AA2CFB14640E3A8DC442D754940B4226AA2CFB146401CD2A8C0C9764940624A24D1CBB446401CD2A8C0C9764940624A24D1CBB44640E3A8DC442D754940B4226AA2CFB14640E3A8DC442D754940
326	Карамыш	7	73	116	45.514608000000003	45.541682999999999	51.039777000000001	50.959949000000002	0103000020E610000001000000050000004721C9ACDEC14640F969DC9BDF7A49404721C9ACDEC146400611A969178549404BE658DE55C546400611A969178549404BE658DE55C54640F969DC9BDF7A49404721C9ACDEC14640F969DC9BDF7A4940
8644	Каменский	7	73	116	45.467931999999998	45.509433999999999	50.902585000000002	50.875442	0103000020E610000001000000050000003D601E32E5BB4640BDC5C37B0E7049403D601E32E5BB46401A6EC0E78773494038BC202235C146401A6EC0E78773494038BC202235C14640BDC5C37B0E7049403D601E32E5BB4640BDC5C37B0E704940
8502	Каменка	7	73	116	45.418452000000002	45.432034999999999	50.703147000000001	50.688220999999999	0103000020E610000001000000050000001079CBD58FB54640D0B52FA0175849401079CBD58FB54640E8A38CB8005A49401ADD41EC4CB74640E8A38CB8005A49401ADD41EC4CB74640D0B52FA0175849401079CBD58FB54640D0B52FA017584940
8203	Золотое	7	73	116	45.871383000000002	45.916576999999997	50.841976000000003	50.818081999999997	0103000020E610000001000000050000002BA5677A89EF46401FB935E9B66849402BA5677A89EF46402A029CDEC56B494005A2276552F546402A029CDEC56B494005A2276552F546401FB935E9B66849402BA5677A89EF46401FB935E9B6684940
8557	Елшанка	7	73	116	45.454385000000002	45.461176000000002	50.739313000000003	50.732118	0103000020E610000001000000050000008065A54929BA46400E68E90AB65D49408065A54929BA4640FB40F2CEA15E49409DD9AED007BB4640FB40F2CEA15E49409DD9AED007BB46400E68E90AB65D49408065A54929BA46400E68E90AB65D4940
8115	Дубовка	7	73	116	46.000245999999997	46.035164000000002	50.857968	50.848471000000004	0103000020E6100000010000000500000037FA980F080047405E4D9EB29A6C494037FA980F08004740DC813AE5D16D49408FFF024180044740DC813AE5D16D49408FFF0241800447405E4D9EB29A6C494037FA980F080047405E4D9EB29A6C4940
8312	Гусево	7	73	116	45.702347000000003	45.718803999999999	50.853440999999997	50.846224999999997	0103000020E61000000100000005000000CCB8A981E6D946405F07CE19516C4940CCB8A981E6D946406308008E3D6D4940F31DFCC401DC46406308008E3D6D4940F31DFCC401DC46405F07CE19516C4940CCB8A981E6D946405F07CE19516C4940
8415	Гвардейское	7	73	116	45.381971999999998	45.402650999999999	50.651125	50.635387999999999	0103000020E610000001000000050000006DFE5F75E4B04640AB22DC64545149406DFE5F75E4B04640D34D621058534940D15966118AB34640D34D621058534940D15966118AB34640AB22DC64545149406DFE5F75E4B04640AB22DC6454514940
388	Высокое	7	73	116	45.463349999999998	45.482151999999999	51.010102000000003	50.998233999999997	0103000020E61000000100000005000000014D840D4FBB4640ACE0B721C67F4940014D840D4FBB4640E6CFB7054B814940BAD91F28B7BD4640E6CFB7054B814940BAD91F28B7BD4640ACE0B721C67F4940014D840D4FBB4640ACE0B721C67F4940
7958	Ваулино	7	73	116	45.781345000000002	45.801825999999998	50.962037000000002	50.952494000000002	0103000020E6100000010000000500000052F2EA1C03E4464070D1C952EB79494052F2EA1C03E446405F454607247B49408F8AFF3BA2E646405F454607247B49408F8AFF3BA2E6464070D1C952EB79494052F2EA1C03E4464070D1C952EB794940
9015	Бобровка	7	73	116	45.511274999999998	45.535808000000003	51.096598	51.069982000000003	0103000020E6100000010000000500000096218E7571C1464083A7902BF588494096218E7571C14640F46DC1525D8C4940B477465B95C44640F46DC1525D8C4940B477465B95C4464083A7902BF588494096218E7571C1464083A7902BF5884940
6402	Шклово	7	73	727	44.505288	44.528824	51.372003999999997	51.352404999999997	0103000020E61000000100000005000000D787F546AD40464033F9669B1BAD4940D787F546AD40464097FDBAD39DAF494082AB3C81B043464097FDBAD39DAF494082AB3C81B043464033F9669B1BAD4940D787F546AD40464033F9669B1BAD4940
5594	Широкий Уступ	7	73	727	44.398065000000003	44.427557	51.677917999999998	51.656534000000001	0103000020E6100000010000000500000054573ECBF3324640255B5D4E09D4494054573ECBF332464053AF5B04C6D6494083161230BA36464053AF5B04C6D6494083161230BA364640255B5D4E09D4494054573ECBF3324640255B5D4E09D44940
5975	Федоровка	7	73	727	44.355494	44.370424	51.434477999999999	51.420456000000001	0103000020E610000001000000050000004DF6CFD3802D464018B49080D1B549404DF6CFD3802D46406E6AA0F99CB74940A6D3BA0D6A2F46406E6AA0F99CB74940A6D3BA0D6A2F464018B49080D1B549404DF6CFD3802D464018B49080D1B54940
6197	Таловка	7	73	727	44.215212999999999	44.248271000000003	51.322380000000003	51.296666999999999	0103000020E6100000010000000500000047567E198C1B4640B6662B2FF9A5494047567E198C1B4640377172BF43A94940CAC51858C71F4640377172BF43A94940CAC51858C71F4640B6662B2FF9A5494047567E198C1B4640B6662B2FF9A54940
7020	Славновка	7	73	727	44.273837	44.301909000000002	51.714606000000003	51.704225000000001	0103000020E61000000100000005000000A6B73F170D2346404703780B24DA4940A6B73F170D23464040C39B3578DB49401DAF40F4A426464040C39B3578DB49401DAF40F4A42646404703780B24DA4940A6B73F170D2346404703780B24DA4940
6128	Симоновка	7	73	727	44.736209000000002	44.766258000000001	51.379649999999998	51.353552999999998	0103000020E61000000100000005000000AC02B5183C5E46408B33863941AD4940AC02B5183C5E464094F6065F98B049403126FDBD1462464094F6065F98B049403126FDBD146246408B33863941AD4940AC02B5183C5E46408B33863941AD4940
6797	Сергиевка	7	73	727	44.041452	44.079450999999999	51.617640999999999	51.59798	0103000020E61000000100000005000000492D944C4E054640BFD4CF9B8ACC4940492D944C4E05464099D53BDC0ECF494037514B732B0A464099D53BDC0ECF494037514B732B0A4640BFD4CF9B8ACC4940492D944C4E054640BFD4CF9B8ACC4940
6336	Свердлово	7	73	727	44.555621000000002	44.585408999999999	51.271790000000003	51.243386999999998	0103000020E6100000010000000500000044FCC3961E474640C2A2224E279F494044FCC3961E4746409FB0C403CAA249405CE49EAEEE4A46409FB0C403CAA249405CE49EAEEE4A4640C2A2224E279F494044FCC3961E474640C2A2224E279F4940
5857	Салтыково	7	73	727	44.597033000000003	44.626075	51.440435000000001	51.423713999999997	0103000020E61000000100000005000000FFD0CC936B4C4640BD6DA6423CB64940FFD0CC936B4C4640C381902C60B84940EEEBC03923504640C381902C60B84940EEEBC03923504640BD6DA6423CB64940FFD0CC936B4C4640BD6DA6423CB64940
6699	Песчаный	7	73	727	44.065193999999998	44.079909000000001	51.509464999999999	51.497937999999998	0103000020E610000001000000050000009DF2E84658084640C3B7B06EBCBF49409DF2E8465808464073BA2C2636C14940FAD346753A0A464073BA2C2636C14940FAD346753A0A4640C3B7B06EBCBF49409DF2E84658084640C3B7B06EBCBF4940
5863	Первомайское	7	73	727	44.557713999999997	44.596834999999999	51.507165999999998	51.470123999999998	0103000020E61000000100000005000000BB421F2C634746404888F2052DBC4940BB421F2C6347464052D2C3D0EAC04940D80DDB16654C464052D2C3D0EAC04940D80DDB16654C46404888F2052DBC4940BB421F2C634746404888F2052DBC4940
6285	Орловка	7	73	727	44.274465999999997	44.293168999999999	51.282736999999997	51.262801000000003	0103000020E6100000010000000500000095EEAEB321234640952D9276A3A1494095EEAEB321234640402FDCB930A44940BB99D18F86254640402FDCB930A44940BB99D18F86254640952D9276A3A1494095EEAEB321234640952D9276A3A14940
6549	Озерки	7	73	727	44.111350000000002	44.131220999999996	51.444538999999999	51.421905000000002	0103000020E610000001000000050000006E3480B7400E46406B82A8FB00B649406E3480B7400E4640F56569A7E6B8494032C687D9CB104640F56569A7E6B8494032C687D9CB1046406B82A8FB00B649406E3480B7400E46406B82A8FB00B64940
6874	Новые Выселки	7	73	727	44.168267	44.199663000000001	51.563195999999998	51.540754999999997	0103000020E610000001000000050000007EFFE6C5891546400113B87537C549407EFFE6C589154640779E78CE16C84940529CA38E8E194640779E78CE16C84940529CA38E8E1946400113B87537C549407EFFE6C5891546400113B87537C54940
5718	Новая Ивановка	7	73	727	44.554516	44.591346999999999	51.470680000000002	51.453778	0103000020E61000000100000005000000EB8D5A61FA46464078D2C26515BA4940EB8D5A61FA464640CE70033E3FBC49403ACB2C42B14B4640CE70033E3FBC49403ACB2C42B14B464078D2C26515BA4940EB8D5A61FA46464078D2C26515BA4940
6620	Нижегороды	7	73	727	44.138488000000002	44.162024000000002	51.381397999999997	51.370767000000001	0103000020E61000000100000005000000B9718BF9B9114640D0B7054B75AF4940B9718BF9B9114640416150A6D1B049406495D233BD144640416150A6D1B049406495D233BD144640D0B7054B75AF4940B9718BF9B9114640D0B7054B75AF4940
6134	Монастырское	7	73	727	44.660525999999997	44.684097999999999	51.420602000000002	51.407654000000001	0103000020E610000001000000050000002F14B01D8C544640B30A9B012EB449402F14B01D8C544640EC504D49D6B5494027A1F48590574640EC504D49D6B5494027A1F48590574640B30A9B012EB449402F14B01D8C544640B30A9B012EB44940
6278	Михайловка	7	73	727	44.401612999999998	44.421709	51.337277	51.325696000000001	0103000020E610000001000000050000000053060E6833464011381268B0A949400053060E68334640B4588AE42BAB4940E5B67D8FFA354640B4588AE42BAB4940E5B67D8FFA35464011381268B0A949400053060E6833464011381268B0A94940
5924	Малая Екатериновка	7	73	727	44.265554999999999	44.293464999999998	51.420327	51.400018000000003	0103000020E610000001000000050000000725CCB4FD214640DAE731CA33B349400725CCB4FD2146401A506F46CDB54940A4C2D842902546401A506F46CDB54940A4C2D84290254640DAE731CA33B349400725CCB4FD214640DAE731CA33B34940
6494	Красноармейское	7	73	727	44.392423999999998	44.415618000000002	51.220883999999998	51.206688	0103000020E610000001000000050000002F151BF33A324640E23C9CC0749A49402F151BF33A324640D61A4AED459C494081D07AF832354640D61A4AED459C494081D07AF832354640E23C9CC0749A49402F151BF33A324640E23C9CC0749A4940
6547	Колокольцовка	7	73	727	44.578429	44.613076999999997	51.212263	51.185313999999998	0103000020E610000001000000050000006C0723F6094A4640D7BE805EB89749406C0723F6094A46404F93196F2B9B49400377A04E794E46404F93196F2B9B49400377A04E794E4640D7BE805EB89749406C0723F6094A4640D7BE805EB8974940
5060	Калининск	7	73	727	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
6703	Казачка	7	73	727	43.904350999999998	43.961779999999997	51.485421000000002	51.457504999999998	0103000020E610000001000000050000006D8D08C6C1F34540D4601A868FBA49406D8D08C6C1F3454054E57B4622BE494033F9669B1BFB454054E57B4622BE494033F9669B1BFB4540D4601A868FBA49406D8D08C6C1F34540D4601A868FBA4940
5806	Дубравный	7	73	727	44.581716999999998	44.604785	51.555866000000002	51.544894999999997	0103000020E610000001000000050000007C43E1B3754A464080608E1EBFC549407C43E1B3754A4640AB7AF99D26C74940410E4A98694D4640AB7AF99D26C74940410E4A98694D464080608E1EBFC549407C43E1B3754A464080608E1EBFC54940
6076	Большая Ольшанка	7	73	727	44.266489	44.303364999999999	51.523890999999999	51.501392000000003	0103000020E6100000010000000500000033DFC14F1C224640EF3CF19C2DC0494033DFC14F1C22464099D53BDC0EC3494022E010AAD426464099D53BDC0EC3494022E010AAD4264640EF3CF19C2DC0494033DFC14F1C224640EF3CF19C2DC04940
6933	Ахтуба	7	73	727	44.358899000000001	44.397364000000003	51.631501999999998	51.594489000000003	0103000020E6100000010000000500000097C80567F02D4640776A2E3718CC494097C80567F02D4640E6ADBA0ED5D04940CB4DD4D2DC324640E6ADBA0ED5D04940CB4DD4D2DC324640776A2E3718CC494097C80567F02D4640776A2E3718CC4940
5661	Анастасьино	7	73	727	44.489981	44.513129999999997	51.717680000000001	51.702756999999998	0103000020E61000000100000005000000A85489B2B73E46407D04FEF0F3D94940A85489B2B73E4640247F30F0DCDB4940594C6C3EAE414640247F30F0DCDB4940594C6C3EAE4146407D04FEF0F3D94940A85489B2B73E46407D04FEF0F3D94940
6927	Александровка 3-я	7	73	727	44.134383	44.165571999999997	51.688220000000001	51.670456000000001	0103000020E61000000100000005000000B6114F763311464018B49080D1D54940B6114F7633114640003ACC9717D8494010919A7631154640003ACC9717D8494010919A763115464018B49080D1D54940B6114F763311464018B49080D1D54940
4909	Яблоневый Гай	7	73	633	49.581837999999998	49.615516	52.211334999999998	52.199109999999997	0103000020E61000000100000005000000F7C8E6AA79CA48403D27BD6F7C194A40F7C8E6AA79CA484005C078060D1B4A401615713AC9CE484005C078060D1B4A401615713AC9CE48403D27BD6F7C194A40F7C8E6AA79CA48403D27BD6F7C194A40
4768	Чернава	7	73	633	49.371749000000001	49.413117	52.325356999999997	52.306131999999998	0103000020E610000001000000050000000DA9A27895AF4840292158552F274A400DA9A27895AF48402843554CA5294A40F8359204E1B448402843554CA5294A40F8359204E1B44840292158552F274A400DA9A27895AF4840292158552F274A40
4359	Раевка	7	73	633	48.923535000000001	48.943496000000003	52.300769000000003	52.281059999999997	0103000020E610000001000000050000000EDB1665367648405C1B2AC6F9234A400EDB16653676484048533D997F264A4013F4177AC478484048533D997F264A4013F4177AC47848405C1B2AC6F9234A400EDB1665367648405C1B2AC6F9234A40
4156	Николаевка	7	73	633	49.195239000000001	49.238636999999997	52.459513000000001	52.445830999999998	0103000020E61000000100000005000000AEF36F97FD98484080457EFD10394A40AEF36F97FD9848401E8B6D52D13A4A40CA4E3FA88B9E48401E8B6D52D13A4A40CA4E3FA88B9E484080457EFD10394A40AEF36F97FD98484080457EFD10394A40
4365	Мирный	7	73	633	48.881934000000001	48.893037	52.224190999999998	52.210562000000003	0103000020E61000000100000005000000809D9B36E3704840E3E313B2F31A4A40809D9B36E37048405D876A4AB21C4A40198F52094F7248405D876A4AB21C4A40198F52094F724840E3E313B2F31A4A40809D9B36E3704840E3E313B2F31A4A40
4964	Клевенка	7	73	633	49.497100000000003	49.554915999999999	52.115637	52.101981000000002	0103000020E61000000100000005000000BA6B09F9A0BF48401DE8A1B60D0D4A40BA6B09F9A0BF4840919A7631CD0E4A407903CC7C07C74840919A7631CD0E4A407903CC7C07C748401DE8A1B60D0D4A40BA6B09F9A0BF48401DE8A1B60D0D4A40
4956	Канаевка	7	73	633	49.630527000000001	49.663423000000002	52.199756000000001	52.179273000000002	0103000020E610000001000000050000005C1FD61BB5D048402507EC6AF2164A405C1FD61BB5D048400397C79A91194A4005357C0BEBD448400397C79A91194A4005357C0BEBD448402507EC6AF2164A405C1FD61BB5D048402507EC6AF2164A40
4430	Ивантеевка	7	73	633	49.075358999999999	49.133524999999999	52.286011999999999	52.255746000000002	0103000020E61000000100000005000000C93A1C5DA58948409A0AF148BC204A40C93A1C5DA5894840BC218D0A9C244A406519E25817914840BC218D0A9C244A406519E258179148409A0AF148BC204A40C93A1C5DA58948409A0AF148BC204A40
4707	Ивановка	7	73	633	49.277057999999997	49.319969999999998	52.216991	52.186577999999997	0103000020E610000001000000050000002E8CF4A276A348409813B4C9E1174A402E8CF4A276A348405F43705CC61B4A40BED9E6C6F4A848405F43705CC61B4A40BED9E6C6F4A848409813B4C9E1174A402E8CF4A276A348409813B4C9E1174A40
4211	Знаменский	7	73	633	49.150288000000003	49.17765	52.330447999999997	52.312123	0103000020E610000001000000050000009A7D1EA33C9348402AAA7EA5F3274A409A7D1EA33C934840A983BC1E4C2A4A403411363CBD964840A983BC1E4C2A4A403411363CBD9648402AAA7EA5F3274A409A7D1EA33C9348402AAA7EA5F3274A40
4855	Восточный	7	73	633	49.557144000000001	49.575055999999996	52.344540000000002	52.332324999999997	0103000020E61000000100000005000000D1949D7E50C74840545227A0892A4A40D1949D7E50C74840F91400E3192C4A402DAF5C6F9BC94840F91400E3192C4A402DAF5C6F9BC94840545227A0892A4A40D1949D7E50C74840545227A0892A4A40
4108	Бартеневка	7	73	633	49.053421999999998	49.092202999999998	52.440072999999998	52.416981999999997	0103000020E6100000010000000500000086713788D6864840A5828AAA5F354A4086713788D6864840226DE34F54384A40EACBD24ECD8B4840226DE34F54384A40EACBD24ECD8B4840A5828AAA5F354A4086713788D6864840A5828AAA5F354A40
4306	Арбузовка	7	73	633	49.040540999999997	49.065756	52.308318	52.294671999999998	0103000020E61000000100000005000000D5928E72308548400186E5CFB7254A40D5928E72308548405262D7F676274A4005C24EB16A8848405262D7F676274A4005C24EB16A8848400186E5CFB7254A40D5928E72308548400186E5CFB7254A40
2222	Южный	7	73	267	48.387419999999999	48.410732000000003	51.498308000000002	51.482044999999999	0103000020E610000001000000050000007DE882FA96314840A4198BA6B3BD49407DE882FA96314840E7AA798EC8BF4940D9B5BDDD92344840E7AA798EC8BF4940D9B5BDDD92344840A4198BA6B3BD49407DE882FA96314840A4198BA6B3BD4940
3033	Чугунка	7	73	267	47.853245999999999	47.868509000000003	51.417034999999998	51.406457000000003	0103000020E61000000100000005000000AEB8382A37ED47407A1D71C806B44940AEB8382A37ED4740C824236761B549400EA48B4D2BEF4740C824236761B549400EA48B4D2BEF47407A1D71C806B44940AEB8382A37ED47407A1D71C806B44940
3144	Чкалово	7	73	267	47.855716999999999	47.879558000000003	51.509408999999998	51.490316999999997	0103000020E61000000100000005000000CCD0782288ED47401FD61BB5C2BE4940CCD0782288ED4740DFA4695034C14940B477465B95F04740DFA4695034C14940B477465B95F047401FD61BB5C2BE4940CCD0782288ED47401FD61BB5C2BE4940
2513	Черная Падина	7	73	267	47.865031999999999	47.891820000000003	51.030177000000002	51.019396	0103000020E610000001000000050000002AFF5A5EB9EE47402CD670917B8249402AFF5A5EB9EE4740B30B06D7DC83494099F5622827F24740B30B06D7DC83494099F5622827F247402CD670917B8249402AFF5A5EB9EE47402CD670917B824940
3314	Чапаевка	7	73	267	48.040446000000003	48.061601000000003	51.646157000000002	51.630070000000003	0103000020E6100000010000000500000084A0A3552D0548406A183E22A6D0494084A0A3552D0548406E8AC745B5D249405133A48AE20748406E8AC745B5D249405133A48AE20748406A183E22A6D0494084A0A3552D0548406A183E22A6D04940
2349	Целинный	7	73	267	48.509430000000002	48.534132999999997	51.353304999999999	51.336123999999998	0103000020E61000000100000005000000F7CC9200354148404AB3791C06AB4940F7CC920035414840B341261939AD4940705B5B785E444840B341261939AD4940705B5B785E4448404AB3791C06AB4940F7CC9200354148404AB3791C06AB4940
1915	Учебный	7	73	267	48.208933999999999	48.241821000000002	51.354970000000002	51.335915	0103000020E61000000100000005000000E0826C59BE1A4840309E4143FFAA4940E0826C59BE1A4840D3872EA86FAD4940363E93FDF31E4840D3872EA86FAD4940363E93FDF31E4840309E4143FFAA4940E0826C59BE1A4840309E4143FFAA4940
2053	Тулайково	7	73	267	48.224761999999998	48.246456999999999	51.377884999999999	51.369962999999998	0103000020E6100000010000000500000018B14F00C51C484072DD94F25AAF494018B14F00C51C4840115322895EB04940656F29E78B1F4840115322895EB04940656F29E78B1F484072DD94F25AAF494018B14F00C51C484072DD94F25AAF4940
53138	Трудовое	7	73	267	48.232047999999999	48.257649999999998	50.943573000000001	50.924681999999997	0103000020E61000000100000005000000158DB5BFB31D48409599D2FA5B764940158DB5BFB31D4840BE310400C77849403EE8D9ACFA204840BE310400C77849403EE8D9ACFA2048409599D2FA5B764940158DB5BFB31D48409599D2FA5B764940
3317	Сокорная Балка	7	73	267	48.081589000000001	48.095557999999997	51.324058000000001	51.311909999999997	0103000020E610000001000000050000004F5B2382710A4840CEA5B8AAECA749404F5B2382710A4840EB0088BB7AA94940826F9A3E3B0C4840EB0088BB7AA94940826F9A3E3B0C4840CEA5B8AAECA749404F5B2382710A4840CEA5B8AAECA74940
2285	Семено-Полтавка	7	73	267	48.525581000000003	48.543610000000001	51.492600000000003	51.473199000000001	0103000020E610000001000000050000001233FB3C46434840FDBFEAC891BC49401233FB3C464348403B014D840DBF4940A8E33103954548403B014D840DBF4940A8E3310395454840FDBFEAC891BC49401233FB3C46434840FDBFEAC891BC4940
2682	Садовый	7	73	267	48.318779999999997	48.339449999999999	51.667831	51.653500000000001	0103000020E61000000100000005000000374F75C8CD284840CFF753E3A5D34940374F75C8CD284840A320787C7BD549404850FC18732B4840A320787C7BD549404850FC18732B4840CFF753E3A5D34940374F75C8CD284840CFF753E3A5D34940
3889	Рефлектор	7	73	267	48.483359999999998	48.512619000000001	51.326529000000001	51.312787999999998	0103000020E61000000100000005000000E71890BDDE3D4840664AEB6F09A84940E71890BDDE3D48400919C8B3CBA949407427D87F9D4148400919C8B3CBA949407427D87F9D414840664AEB6F09A84940E71890BDDE3D4840664AEB6F09A84940
2118	Полуденный	7	73	267	48.294992999999998	48.316758999999998	51.441575	51.425662000000003	0103000020E6100000010000000500000043C6A354C22548403293A8177CB6494043C6A354C225484098DD938785B8494059DB148F8B28484098DD938785B8494059DB148F8B2848403293A8177CB6494043C6A354C22548403293A8177CB64940
3796	Перекопное	7	73	267	48.034517000000001	48.080331000000001	51.217289999999998	51.187685000000002	0103000020E61000000100000005000000F913950D6B0448409279E40F06984940F913950D6B044840B9DFA128D09B494070ED4449480A4840B9DFA128D09B494070ED4449480A48409279E40F06984940F913950D6B0448409279E40F06984940
3493	Осинов Гай	7	73	267	48.528680000000001	48.551533999999997	51.112529000000002	51.099086999999997	0103000020E610000001000000050000004F0647C9AB434840B83A00E2AE8C49404F0647C9AB434840016DAB59678E4940E75086AA98464840016DAB59678E4940E75086AA98464840B83A00E2AE8C49404F0647C9AB434840B83A00E2AE8C4940
3651	Орлов Гай	7	73	267	48.173442000000001	48.228104000000002	50.938879999999997	50.900694000000001	0103000020E610000001000000050000005DE0F258331648400ADAE4F0497349405DE0F258331648402A6F47382D7849401C0B0A83321D48402A6F47382D7849401C0B0A83321D48400ADAE4F0497349405DE0F258331648400ADAE4F049734940
29790	Новый	7	73	267	48.559583000000003	48.582894000000003	51.338954000000001	51.314971999999997	0103000020E61000000100000005000000E4326E6AA0474840EE93A30051A84940E4326E6AA0474840986C3CD862AB49406F8445459C4A4840986C3CD862AB49406F8445459C4A4840EE93A30051A84940E4326E6AA0474840EE93A30051A84940
3531	Новосельский	7	73	267	48.104675999999998	48.124626999999997	51.668322000000003	51.658479	0103000020E610000001000000050000008A56EE05660D4840280D350A49D449408A56EE05660D4840429946938BD549406B990CC7F30F4840429946938BD549406B990CC7F30F4840280D350A49D449408A56EE05660D4840280D350A49D44940
3434	Новорепное	7	73	267	48.398235999999997	48.455835999999998	51.085746999999998	51.061729	0103000020E61000000100000005000000800BB265F93248407E1B62BCE6874940800BB265F9324840745DF8C1F98A4940732B84D5583A4840745DF8C1F98A4940732B84D5583A48407E1B62BCE6874940800BB265F93248407E1B62BCE6874940
3278	Новая Краснянка	7	73	267	48.215527999999999	48.243662999999998	51.332943999999998	51.305383999999997	0103000020E61000000100000005000000A7AFE76B961B48405F5CAAD216A74940A7AFE76B961B484020B3B3E89DAA4940641F6459301F484020B3B3E89DAA4940641F6459301F48405F5CAAD216A74940A7AFE76B961B48405F5CAAD216A74940
3081	Нестерово	7	73	267	47.922272999999997	47.972417	51.457275000000003	51.434164000000003	0103000020E61000000100000005000000ED7DAA0A0DF64740DF8C9AAF92B74940ED7DAA0A0DF64740A323B9FC87BA49408789062978FC4740A323B9FC87BA49408789062978FC4740DF8C9AAF92B74940ED7DAA0A0DF64740DF8C9AAF92B74940
3211	Моховое	7	73	267	48.247247000000002	48.269849000000001	51.248935000000003	51.237917000000003	0103000020E610000001000000050000005E8429CAA51F4840CB147310749E49405E8429CAA51F484036EA211ADD9F4940DDED7A698A22484036EA211ADD9F4940DDED7A698A224840CB147310749E49405E8429CAA51F4840CB147310749E4940
2733	Михайло-Вербовка	7	73	267	48.236125999999999	48.260956	51.672333000000002	51.664177000000002	0103000020E610000001000000050000001EDE7360391E4840B1E07EC003D549401EDE7360391E4840C382FB010FD64940F5D8960167214840C382FB010FD64940F5D8960167214840B1E07EC003D549401EDE7360391E4840B1E07EC003D54940
2971	Миусс	7	73	267	47.913325999999998	47.939709000000001	51.451365000000003	51.436982999999998	0103000020E61000000100000005000000124BCADDE7F4474038F4160FEFB74940124BCADDE7F447408FC70C54C6B94940E1606F6248F847408FC70C54C6B94940E1606F6248F8474038F4160FEFB74940124BCADDE7F4474038F4160FEFB74940
2848	Марьевка	7	73	267	48.197535000000002	48.217145000000002	51.477680999999997	51.463661000000002	0103000020E610000001000000050000005E68AED34819484020B75F3E59BB49405E68AED348194840D575A8A624BD4940B6BE4868CB1B4840D575A8A624BD4940B6BE4868CB1B484020B75F3E59BB49405E68AED34819484020B75F3E59BB4940
26181	Лобки 2-е	7	73	267	48.177546999999997	48.202905999999999	51.583638000000001	51.566744999999997	0103000020E610000001000000050000005F402FDCB9164840F415A4198BC849405F402FDCB9164840F75965A6B4CA4940C214E5D2F8194840F75965A6B4CA4940C214E5D2F8194840F415A4198BC849405F402FDCB9164840F415A4198BC84940
3377	Лесной	7	73	267	48.075040000000001	48.088164999999996	51.355083	51.340905999999997	0103000020E6100000010000000500000028F224E99A0948404D81CCCEA2AB494028F224E99A094840CB2E185C73AD49406FD39FFD480B4840CB2E185C73AD49406FD39FFD480B48404D81CCCEA2AB494028F224E99A0948404D81CCCEA2AB4940
2617	Кушумский	7	73	267	48.328581	48.351838000000001	51.639490000000002	51.623114999999999	0103000020E61000000100000005000000228B34F10E2A4840D252793BC2CF4940228B34F10E2A48403D0FEECEDAD14940BABE0F07092D48403D0FEECEDAD14940BABE0F07092D4840D252793BC2CF4940228B34F10E2A4840D252793BC2CF4940
2453	Краснянка	7	73	267	47.910567999999998	47.939996999999998	51.060336999999997	51.045088999999997	0103000020E610000001000000050000005E64027E8DF447406534F279C58549405E64027E8DF447408FDE701FB987494047AB5AD251F847408FDE701FB987494047AB5AD251F847406534F279C58549405E64027E8DF447406534F279C5854940
2913	Красный Боец	7	73	267	48.133178999999998	48.172345999999997	51.400170000000003	51.384062999999998	0103000020E61000000100000005000000CAC16C020C114840444DF4F928B14940CAC16C020C114840906B43C538B3494057CC086F0F164840906B43C538B3494057CC086F0F164840444DF4F928B14940CAC16C020C114840444DF4F928B14940
1120	Ершов	7	73	267	48.237797	48.320881999999997	51.368226	51.334063999999998	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
2578	Еремеевка	7	73	267	48.023764	48.074762	51.068007000000001	51.049970000000002	0103000020E610000001000000050000003C69E1B20A034840FCE3BD6A658649403C69E1B20A03484015731074B4884940E57D1CCD9109484015731074B4884940E57D1CCD91094840FCE3BD6A658649403C69E1B20A034840FCE3BD6A65864940
3981	Дмитриевка	7	73	267	47.969873999999997	47.996941	51.612836999999999	51.599170999999998	0103000020E61000000100000005000000CF9ECBD424FC474016DBA4A2B1CC4940CF9ECBD424FC4740AE635C7171CE494051853FC39BFF4740AE635C7171CE494051853FC39BFF474016DBA4A2B1CC4940CF9ECBD424FC474016DBA4A2B1CC4940
2806	Верхний Кушум	7	73	267	48.284312	48.306994000000003	51.543253999999997	51.528210999999999	0103000020E6100000010000000500000020EEEA55642448409831056B9CC3494020EEEA5564244840E9B5D95889C54940BC0853944B274840E9B5D95889C54940BC0853944B2748409831056B9CC3494020EEEA55642448409831056B9CC34940
3838	Васильевка	7	73	267	48.047919999999998	48.070225000000001	51.119993000000001	51.100574000000002	0103000020E610000001000000050000008369183E22064840F969DC9BDF8C49408369183E22064840DD5F3DEE5B8F4940492EFF21FD084840DD5F3DEE5B8F4940492EFF21FD084840F969DC9BDF8C49408369183E22064840F969DC9BDF8C4940
2164	Антоновка	7	73	267	48.369553000000003	48.396250999999999	51.388745	51.3675	0103000020E61000000100000005000000C19140834D2F4840D7A3703D0AAF4940C19140834D2F4840E4BD6A65C2B14940EF004F5AB8324840E4BD6A65C2B14940EF004F5AB8324840D7A3703D0AAF4940C19140834D2F4840D7A3703D0AAF4940
253	Юбилейный	7	73	28	44.290851000000004	44.316121000000003	51.852147000000002	51.839905999999999	0103000020E610000001000000050000002481069B3A2546406ADB300A82EB49402481069B3A2546403831242713ED4940174A26A7762846403831242713ED4940174A26A7762846406ADB300A82EB49402481069B3A2546406ADB300A82EB4940
209	Упоровка	7	73	28	44.273153999999998	44.286853999999998	51.789183999999999	51.772818999999998	0103000020E61000000100000005000000C362D4B5F62246401C5DA5BBEBE24940C362D4B5F6224640634337FB03E54940075DC2A1B7244640634337FB03E54940075DC2A1B72446401C5DA5BBEBE24940C362D4B5F62246401C5DA5BBEBE24940
1064	Сластуха	7	73	28	44.524816999999999	44.562331	51.963214999999998	51.938763999999999	0103000020E6100000010000000500000042B115342D434640C154336B29F8494042B115342D43464021020EA14AFB494074435376FA47464021020EA14AFB494074435376FA474640C154336B29F8494042B115342D434640C154336B29F84940
959	Прудовой	7	73	28	44.372256999999998	44.395558999999999	52.000107999999997	51.988495999999998	0103000020E61000000100000005000000815A0C1EA62F4640081D740987FE4940815A0C1EA62F4640E63BF88903004A40B95164ADA1324640E63BF88903004A40B95164ADA1324640081D740987FE4940815A0C1EA62F4640081D740987FE4940
992	Переезд	7	73	28	44.403517999999998	44.437024999999998	52.017204999999997	52.007553999999999	0103000020E6100000010000000500000075AC527AA63346401C7A8B87F7004A4075AC527AA6334640F12900C633024A406744696FF0374640F12900C633024A406744696FF03746401C7A8B87F7004A4075AC527AA63346401C7A8B87F7004A40
830	Новоселовка	7	73	28	44.256338	44.281024000000002	51.958680999999999	51.944820999999997	0103000020E610000001000000050000006C5CFFAECF20464079C9FFE4EFF849406C5CFFAECF204640F6251B0FB6FA494010B22C98F8234640F6251B0FB6FA494010B22C98F823464079C9FFE4EFF849406C5CFFAECF20464079C9FFE4EFF84940
393	Михайловка	7	73	28	44.617514999999997	44.644373999999999	52.370759	52.360861	0103000020E610000001000000050000000CE544BB0A4F464070B378B1302E4A400CE544BB0A4F46404DD9E907752F4A404432E4D87A5246404DD9E907752F4A404432E4D87A52464070B378B1302E4A400CE544BB0A4F464070B378B1302E4A40
885	Малая Екатериновка	7	73	28	44.306724000000003	44.334707000000002	52.042304999999999	52.033658000000003	0103000020E61000000100000005000000FC7266BB42274640D89FC4E74E044A40FC7266BB4227464088BA0F406A054A40035FD1ADD72A464088BA0F406A054A40035FD1ADD72A4640D89FC4E74E044A40FC7266BB42274640D89FC4E74E044A40
714	Кручи	7	73	28	44.734161	44.778699000000003	52.300179	52.284436999999997	0103000020E61000000100000005000000D47FD6FCF85D4640DC627E6E68244A40D47FD6FCF85D464016F9F5436C264A40C636A968AC63464016F9F5436C264A40C636A968AC634640DC627E6E68244A40D47FD6FCF85D4640DC627E6E68244A40
755	Крутояр	7	73	28	44.644795999999999	44.675752000000003	52.135072000000001	52.119624000000002	0103000020E61000000100000005000000BA4BE2AC885246408AE8D7D64F0F4A40BA4BE2AC885246407B4D0F0A4A114A40721AA20A7F5646407B4D0F0A4A114A40721AA20A7F5646408AE8D7D64F0F4A40BA4BE2AC885246408AE8D7D64F0F4A40
644	Комаровка	7	73	28	44.769464999999997	44.804929999999999	52.376603000000003	52.352302000000002	0103000020E61000000100000005000000543541D47D6246405F28603B182D4A40543541D47D624640AA49F08634304A40DEC83CF207674640AA49F08634304A40DEC83CF2076746405F28603B182D4A40543541D47D6246405F28603B182D4A40
467	Колено	7	73	28	44.094029999999997	44.134562000000003	51.887075000000003	51.85089	0103000020E61000000100000005000000E36BCF2C090C4640293FA9F6E9EC4940E36BCF2C090C4640B30C71AC8BF1494066A4DE5339114640B30C71AC8BF1494066A4DE5339114640293FA9F6E9EC4940E36BCF2C090C4640293FA9F6E9EC4940
586	Киселевка	7	73	28	44.146554999999999	44.195396000000002	51.856268999999998	51.842744000000003	0103000020E610000001000000050000005B087250C21246403B730F09DFEB49405B087250C212464010CAFB389AED494076E272BC0219464010CAFB389AED494076E272BC021946403B730F09DFEB49405B087250C21246403B730F09DFEB4940
330	Индустриальный	7	73	28	44.318268000000003	44.371169999999999	52.142085999999999	52.120736000000001	0103000020E6100000010000000500000082AE7D01BD28464095B9F946740F4A4082AE7D01BD284640179CC1DF2F124A40CFA0A17F822F4640179CC1DF2F124A40CFA0A17F822F464095B9F946740F4A4082AE7D01BD28464095B9F946740F4A40
32461	Ивановка	7	73	28	44.549359000000003	44.568781000000001	52.465532000000003	52.454211999999998	0103000020E61000000100000005000000B3614D6551464640B2B96A9E233A4A40B3614D6551464640E99E758D963B4A4008CBD8D0CD484640E99E758D963B4A4008CBD8D0CD484640B2B96A9E233A4A40B3614D6551464640B2B96A9E233A4A40
30924	Екатериновка	7	73	28	44.328823	44.374879999999997	52.065542999999998	52.039845999999997	0103000020E6100000010000000500000018963FDF162A46402E7079AC19054A4018963FDF162A4640A9BD88B663084A4055F65D11FC2F4640A9BD88B663084A4055F65D11FC2F46402E7079AC19054A4018963FDF162A46402E7079AC19054A40
510	Гривки	7	73	28	44.095252000000002	44.122802999999998	51.955196000000001	51.915315999999997	0103000020E610000001000000050000007670B037310C4640B5C01E1329F549407670B037310C464090A2CEDC43FA4940E36C3A02B80F464090A2CEDC43FA4940E36C3A02B80F4640B5C01E1329F549407670B037310C4640B5C01E1329F54940
122	Галахово	7	73	28	44.415052000000003	44.451048	51.857326	51.849603999999999	0103000020E61000000100000005000000D811876C203546408046E9D2BFEC4940D811876C203546405801BEDBBCED49408E76DCF0BB3946405801BEDBBCED49408E76DCF0BB3946408046E9D2BFEC4940D811876C203546408046E9D2BFEC4940
34	Вязовка	7	73	28	44.584707999999999	44.605414000000003	52.028205	52.007475999999997	0103000020E61000000100000005000000D3DA34B6D74A4640A0C03BF9F4004A40D3DA34B6D74A4640B64AB0389C034A403145B9347E4D4640B64AB0389C034A403145B9347E4D4640A0C03BF9F4004A40D3DA34B6D74A4640A0C03BF9F4004A40
32367	Воронцовка	7	73	28	44.346663999999997	44.385013000000001	52.305163	52.282679000000002	0103000020E61000000100000005000000AB59677C5F2C46400C2252D32E244A40AB59677C5F2C46408179C8940F274A4076C4211B483146408179C8940F274A4076C4211B483146400C2252D32E244A40AB59677C5F2C46400C2252D32E244A40
32323	Бутурлинка	7	73	28	44.476156000000003	44.545281000000003	52.360041000000002	52.340634000000001	0103000020E61000000100000005000000A8E507AEF23C4640EDF318E5992B4A40A8E507AEF23C46400D1CD0D2152E4A40AA108FC4CB4546400D1CD0D2152E4A40AA108FC4CB454640EDF318E5992B4A40A8E507AEF23C4640EDF318E5992B4A40
32453	Бакуры	7	73	28	44.662582999999998	44.727198999999999	52.378202999999999	52.347830000000002	0103000020E610000001000000050000005AF10D85CF544640AA4885B1852C4A405AF10D85CF544640E21FB6F468304A408A5759DB145D4640E21FB6F468304A408A5759DB145D4640AA4885B1852C4A405AF10D85CF544640AA4885B1852C4A40
32286	Андреевка	7	73	28	44.565277999999999	44.587285999999999	52.294533999999999	52.273570999999997	0103000020E61000000100000005000000FB928D075B4846402711E15F04234A40FB928D075B484640B0C7444AB3254A4007B309302C4B4640B0C7444AB3254A4007B309302C4B46402711E15F04234A40FB928D075B4846402711E15F04234A40
16562	Альшанка	7	73	28	44.513399999999997	44.548209999999997	52.223441000000001	52.180304999999997	0103000020E6100000010000000500000019E25817B74146401327F73B14174A4019E25817B7414640F3CAF5B6991C4A408AABCABE2B464640F3CAF5B6991C4A408AABCABE2B4646401327F73B14174A4019E25817B74146401327F73B14174A40
31419	Теликовка	7	73	239	48.363992000000003	48.390797999999997	52.525109	52.50647	0103000020E61000000100000005000000B900344A972E4840DB334B02D4404A40B900344A972E4840EAEA8EC536434A40CDAB3AAB05324840EAEA8EC536434A40CDAB3AAB05324840DB334B02D4404A40B900344A972E4840DB334B02D4404A40
32021	Софьинка	7	73	239	48.161682999999996	48.181176000000001	52.270187999999997	52.248778000000001	0103000020E61000000100000005000000DAA84E07B21448406EFB1EF5D71F4A40DAA84E07B2144840C5E2378595224A40F96871C630174840C5E2378595224A40F96871C6301748406EFB1EF5D71F4A40DAA84E07B21448406EFB1EF5D71F4A40
31932	Росляково	7	73	239	48.242359999999998	48.265250000000002	52.324294999999999	52.314920000000001	0103000020E61000000100000005000000E5ED08A7051F48409C6D6E4C4F284A40E5ED08A7051F4840CFA0A17F82294A40CBA145B6F3214840CFA0A17F82294A40CBA145B6F32148409C6D6E4C4F284A40E5ED08A7051F48409C6D6E4C4F284A40
32027	Полеводинский	7	73	239	48.460849000000003	48.488354999999999	52.267592	52.240931000000003	0103000020E6100000010000000500000079B29B19FD3A4840DACBB6D3D61E4A4079B29B19FD3A4840EB55647440224A4046EBA86A823E4840EB55647440224A4046EBA86A823E4840DACBB6D3D61E4A4079B29B19FD3A4840DACBB6D3D61E4A40
31799	Озерки	7	73	239	48.301146000000003	48.328150000000001	52.357286000000002	52.339671000000003	0103000020E610000001000000050000001EA9BEF38B2648402733DE567A2B4A401EA9BEF38B264840CAA8328CBB2D4A405917B7D1002A4840CAA8328CBB2D4A405917B7D1002A48402733DE567A2B4A401EA9BEF38B2648402733DE567A2B4A40
32066	Новозахаркино	7	73	239	48.458863000000001	48.495092	52.178119000000002	52.165287999999997	0103000020E61000000100000005000000172CD505BC3A4840EB353D2828154A40172CD505BC3A4840EBE5779ACC164A407041B62C5F3F4840EBE5779ACC164A407041B62C5F3F4840EB353D2828154A40172CD505BC3A4840EB353D2828154A40
17626	Никольское	7	73	239	48.600805999999999	48.660184999999998	52.515514000000003	52.483322000000001	0103000020E61000000100000005000000CB9E0436E74C4840FAB7CB7EDD3D4A40CB9E0436E74C4840A950DD5CFC414A40A6272CF180544840A950DD5CFC414A40A6272CF180544840FAB7CB7EDD3D4A40CB9E0436E74C4840FAB7CB7EDD3D4A40
952	Липовка	7	73	239	48.380521000000002	48.421061999999999	52.419701000000003	52.396901999999997	0103000020E610000001000000050000007A3881E9B4304840C6DB4AAFCD324A407A3881E9B43048409C8C2AC3B8354A404FCB0F5CE53548409C8C2AC3B8354A404FCB0F5CE5354840C6DB4AAFCD324A407A3881E9B4304840C6DB4AAFCD324A40
31743	Левенка	7	73	239	48.503006999999997	48.540278000000001	52.352576999999997	52.338202000000003	0103000020E610000001000000050000005C548B88624048408DB800344A2B4A405C548B886240484030293E3E212D4A40C85F5AD42745484030293E3E212D4A40C85F5AD4274548408DB800344A2B4A405C548B88624048408DB800344A2B4A40
29514	Духовницкое	7	73	239	48.194659999999999	48.241992000000003	52.510351	52.465049	0103000020E6100000010000000500000070EB6E9EEA184840CD04C3B9863B4A4070EB6E9EEA1848408E3D7B2E53414A4063F20698F91E48408E3D7B2E53414A4063F20698F91E4840CD04C3B9863B4A4070EB6E9EEA184840CD04C3B9863B4A40
987	Дмитриевка	7	73	239	48.194758999999998	48.213048000000001	52.430173000000003	52.408605000000001	0103000020E6100000010000000500000003CDE7DCED184840B5FD2B2B4D344A4003CDE7DCED184840A54FABE80F374A40363D2828451B4840A54FABE80F374A40363D2828451B4840B5FD2B2B4D344A4003CDE7DCED184840B5FD2B2B4D344A40
31531	Григорьевка	7	73	239	48.573264000000002	48.595111000000003	52.608738000000002	52.590415	0103000020E61000000100000005000000B1FCF9B660494840AF08FEB7924B4A40B1FCF9B6604948408EEA7420EB4D4A40B43EE5982C4C48408EEA7420EB4D4A40B43EE5982C4C4840AF08FEB7924B4A40B1FCF9B660494840AF08FEB7924B4A40
53233	Горяиновка	7	73	239	48.219237999999997	48.249789999999997	52.293123999999999	52.279769999999999	0103000020E610000001000000050000002D05A4FD0F1C48407233DC80CF234A402D05A4FD0F1C48401BD6541685254A40156F641EF91F48401BD6541685254A40156F641EF91F48407233DC80CF234A402D05A4FD0F1C48407233DC80CF234A40
31572	Брыковка	7	73	239	48.569212	48.598793999999998	52.562395000000002	52.525032000000003	0103000020E61000000100000005000000D13E56F0DB4848403FADA23F34434A40D13E56F0DB4848408B37328FFC474A4040852348A54C48408B37328FFC474A4040852348A54C48403FADA23F34434A40D13E56F0DB4848403FADA23F34434A40
31668	Богородское	7	73	239	48.775421000000001	48.817956000000002	52.466360999999999	52.437558000000003	0103000020E61000000100000005000000D9D0CDFE40634840350D8AE601384A40D9D0CDFE406348409F909DB7B13B4A4093C83EC8B26848409F909DB7B13B4A4093C83EC8B2684840350D8AE601384A40D9D0CDFE40634840350D8AE601384A40
31520	Березовая Лука	7	73	239	48.423882999999996	48.453401999999997	52.628492000000001	52.600999999999999	0103000020E61000000100000005000000492A53CC41364840B0726891ED4C4A40492A53CC4136484019E6046D72504A4072F8A413093A484019E6046D72504A4072F8A413093A4840B0726891ED4C4A40492A53CC41364840B0726891ED4C4A40
30609	Тимонин	7	73	844	49.218451999999999	49.242203000000003	51.182563999999999	51.164453999999999	0103000020E6100000010000000500000076DF313CF69B484023D923D40C95494076DF313CF69B4840A6B6D4415E9749401EFF0582009F4840A6B6D4415E9749401EFF0582009F484023D923D40C95494076DF313CF69B484023D923D40C954940
6284	Советский	7	73	844	48.775016000000001	48.792200999999999	51.21096	51.191229999999997	0103000020E6100000010000000500000039F06AB933634840CD0182397A98494039F06AB933634840D061BEBC009B4940E36DA5D766654840D061BEBC009B4940E36DA5D766654840CD0182397A98494039F06AB933634840CD0182397A984940
31125	Сафаровка	7	73	844	48.861640999999999	48.898822000000003	50.924261999999999	50.906430999999998	0103000020E6100000010000000500000045F295404A6E4840508A56EE0574494045F295404A6E4840C0779B374E76494071766B990C734840C0779B374E76494071766B990C734840508A56EE0574494045F295404A6E4840508A56EE05744940
6280	Петропавловка	7	73	844	48.776085000000002	48.811084000000001	51.256787000000003	51.243471	0103000020E6100000010000000500000045F5D6C0566348402043C70E2A9F494045F5D6C056634840DC847B65DEA049408927BB99D1674840DC847B65DEA049408927BB99D16748402043C70E2A9F494045F5D6C0566348402043C70E2A9F4940
30836	Первомайский	7	73	844	48.877972	48.917417	51.369328000000003	51.346279000000003	0103000020E61000000100000005000000E066F162617048405325CADE52AC4940E066F16261704840A1BFD02346AF4940B0E595EB6D754840A1BFD02346AF4940B0E595EB6D7548405325CADE52AC4940E066F162617048405325CADE52AC4940
31037	Орошаемый	7	73	844	48.752153999999997	48.783603999999997	51.044018999999999	51.031264	0103000020E610000001000000050000001DC70F954660484065C57075008449401DC70F954660484089B3226AA2854940E481C8224D64484089B3226AA2854940E481C8224D64484065C57075008449401DC70F954660484065C5707500844940
30973	Октябрьский	7	73	844	49.123204000000001	49.144151999999998	50.960205000000002	50.940804	0103000020E61000000100000005000000425E0F26C58F484016F9F5436C784940425E0F26C58F4840543A58FFE77A494095D39E9273924840543A58FFE77A494095D39E927392484016F9F5436C784940425E0F26C58F484016F9F5436C784940
30615	Новоросляевка	7	73	844	48.998615999999998	49.023347000000001	51.250005999999999	51.232142000000003	0103000020E6100000010000000500000094A12AA6D27F484097033DD4B69D494094A12AA6D27F4840E2E6543200A04940D8BAD408FD824840E2E6543200A04940D8BAD408FD82484097033DD4B69D494094A12AA6D27F484097033DD4B69D4940
29462	Мирный	7	73	844	48.507731999999997	48.535201999999998	50.910980000000002	50.897818999999998	0103000020E61000000100000005000000FB90B75CFD4048401C5DA5BBEB724940FB90B75CFD404840B1A71DFE9A7449407C60C77F81444840B1A71DFE9A7449407C60C77F814448401C5DA5BBEB724940FB90B75CFD4048401C5DA5BBEB724940
30929	Красноозерный	7	73	844	49.125782000000001	49.149757999999999	50.908974999999998	50.888229000000003	0103000020E610000001000000050000007636E49F19904840ED2DE57CB17149407636E49F19904840D8F0F44A597449403D2828452B934840D8F0F44A597449403D2828452B934840ED2DE57CB17149407636E49F19904840ED2DE57CB1714940
30831	Камышево	7	73	844	48.890251999999997	48.917399000000003	51.479981000000002	51.448272000000003	0103000020E610000001000000050000006B990CC7F371484034DB15FA60B949406B990CC7F3714840C7D9740470BD49400A3197546D754840C7D9740470BD49400A3197546D75484034DB15FA60B949406B990CC7F371484034DB15FA60B94940
30731	Зерновой	7	73	844	48.291220000000003	48.318744000000002	50.954849000000003	50.936518	0103000020E6100000010000000500000077F86BB246254840C30E63D2DF77494077F86BB24625484025CFF57D387A4940EBE5779ACC28484025CFF57D387A4940EBE5779ACC284840C30E63D2DF77494077F86BB246254840C30E63D2DF774940
30667	Жадовка	7	73	844	49.219512000000002	49.239364999999999	51.433748999999999	51.417760000000001	0103000020E610000001000000050000002F8A1EF8189C4840DAC9E02879B549402F8A1EF8189C48401BD6541685B749404D672783A39E48401BD6541685B749404D672783A39E4840DAC9E02879B549402F8A1EF8189C4840DAC9E02879B54940
29202	Дергачи	7	73	844	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
30522	Демьяс	7	73	844	49.112018999999997	49.137602999999999	51.213742000000003	51.189892	0103000020E61000000100000005000000EBC37AA3568E4840D2E28C614E984940EBC37AA3568E48400DE4D9E55B9B49406E6AA0F99C9148400DE4D9E55B9B49406E6AA0F99C914840D2E28C614E984940EBC37AA3568E4840D2E28C614E984940
30517	Восточный	7	73	844	49.266717999999997	49.296156000000003	51.028064000000001	51.015067000000002	0103000020E6100000010000000500000094A0BFD023A24840DA1F28B7ED81494094A0BFD023A24840F418E59997834940D1419770E8A54840F418E59997834940D1419770E8A54840DA1F28B7ED81494094A0BFD023A24840DA1F28B7ED814940
30420	Верхазовка	7	73	844	48.741607999999999	48.791932000000003	50.921514000000002	50.904761000000001	0103000020E61000000100000005000000DA39CD02ED5E48401FD95C35CF734940DA39CD02ED5E48403067B62BF4754940F4531C075E6548403067B62BF4754940F4531C075E6548401FD95C35CF734940DA39CD02ED5E48401FD95C35CF734940
30311	Васильевка 1-я	7	73	844	48.660471999999999	48.682310000000001	51.295467000000002	51.282698000000003	0103000020E610000001000000050000003CF6B3588A5448408352B4722FA449403CF6B3588A5448400C06D7DCD1A54940ECDD1FEF555748400C06D7DCD1A54940ECDD1FEF555748408352B4722FA449403CF6B3588A5448408352B4722FA44940
29468	Антоновка	7	73	844	48.791465000000002	48.819510000000001	51.329191000000002	51.313209999999998	0103000020E61000000100000005000000DE76A1B94E654840DC63E94317A84940DE76A1B94E6548409B9141EE22AA49405B5F24B4E56848409B9141EE22AA49405B5F24B4E5684840DC63E94317A84940DE76A1B94E654840DC63E94317A84940
30315	Алтата	7	73	844	48.705334000000001	48.743045000000002	51.109188000000003	51.091213000000003	0103000020E61000000100000005000000E1606F62485A48402BFC19DEAC8B4940E1606F62485A4840CE8E54DFF98D4940693A3B191C5F4840CE8E54DFF98D4940693A3B191C5F48402BFC19DEAC8B4940E1606F62485A48402BFC19DEAC8B4940
25840	Чардым	7	73	742	46.315815999999998	46.350275000000003	51.794052999999998	51.785305999999999	0103000020E61000000100000005000000DAC69FA86C28474021AD31E884E44940DAC69FA86C28474035255987A3E549409FCDAACFD52C474035255987A3E549409FCDAACFD52C474021AD31E884E44940DAC69FA86C28474021AD31E884E44940
25933	Усовка	7	73	742	46.475822999999998	46.523650000000004	51.813488999999997	51.797863	0103000020E61000000100000005000000A1D79FC4E73C47401FD8F15F20E64940A1D79FC4E73C4740EF53556820E84940744694F606434740EF53556820E84940744694F6064347401FD8F15F20E64940A1D79FC4E73C47401FD8F15F20E64940
5225	Студеновка	7	73	742	46.560111999999997	46.587429999999998	51.922187000000001	51.911777000000001	0103000020E610000001000000050000006F0C01C0B14747405C1FD61BB5F449406F0C01C0B1474740EFE53E390AF649403A58FFE7304B4740EFE53E390AF649403A58FFE7304B47405C1FD61BB5F449406F0C01C0B14747405C1FD61BB5F44940
25760	Славянка	7	73	742	46.238129000000001	46.259751999999999	51.848925999999999	51.834336	0103000020E61000000100000005000000569DD5027B1E47400FF0A485CBEA4940569DD5027B1E4740AF5C6F9BA9EC49400989B48D3F214740AF5C6F9BA9EC49400989B48D3F2147400FF0A485CBEA4940569DD5027B1E47400FF0A485CBEA4940
26024	Синодское	7	73	742	46.650097000000002	46.680081999999999	52.000124999999997	51.977241999999997	0103000020E61000000100000005000000261DE5603653474089230F4416FD4940261DE56036534740BC74931804004A40944C4EED0C574740BC74931804004A40944C4EED0C57474089230F4416FD4940261DE5603653474089230F4416FD4940
53149	Новая Алексеевка	7	73	742	46.798678000000002	46.820138999999998	51.965229000000001	51.949567000000002	0103000020E610000001000000050000007104A9143B664740302E55698BF949407104A9143B6647404D13B69F8CFB49404A969350FA6847404D13B69F8CFB49404A969350FA684740302E55698BF949407104A9143B664740302E55698BF94940
26071	Медяниково	7	73	742	46.671225	46.695686000000002	51.979371999999998	51.960318000000001	0103000020E61000000100000005000000F9A067B3EA5547404CE141B3EBFA4940F9A067B3EA5547401E4FCB0F5CFD49407D24253D0C5947401E4FCB0F5CFD49407D24253D0C5947404CE141B3EBFA4940F9A067B3EA5547404CE141B3EBFA4940
5323	Кошели	7	73	742	46.575887000000002	46.607193000000002	51.833941000000003	51.822429999999997	0103000020E6100000010000000500000085984BAAB6494740E89FE06245E9494085984BAAB649474093E52494BEEA494019AE0E80B84D474093E52494BEEA494019AE0E80B84D4740E89FE06245E9494085984BAAB6494740E89FE06245E94940
25845	Коммуна 3-я	7	73	742	46.363399000000001	46.373865000000002	51.872998000000003	51.862209	0103000020E610000001000000050000001633C2DB832E47408FA850DD5CEE49401633C2DB832E474099BC0166BEEF49403D0FEECEDA2F474099BC0166BEEF49403D0FEECEDA2F47408FA850DD5CEE49401633C2DB832E47408FA850DD5CEE4940
53225	Каломка	7	73	742	46.853726999999999	46.875546999999997	51.931261999999997	51.922615	0103000020E61000000100000005000000295B24ED466D474047E6913F18F64940295B24ED466D4740F700DD9733F74940328E91EC11704740F700DD9733F74940328E91EC1170474047E6913F18F64940295B24ED466D474047E6913F18F64940
5210	Елшанка	7	73	742	46.376621999999998	46.41057	51.826326999999999	51.804378999999997	0103000020E61000000100000005000000207A5226353047406A4B1DE4F5E64940207A522635304740A1664815C5E94940FF5BC98E8D344740A1664815C5E94940FF5BC98E8D3447406A4B1DE4F5E64940207A5226353047406A4B1DE4F5E64940
29733	Воскресенское	7	73	742	46.906925000000001	46.955443000000002	51.840541000000002	51.809719000000001	0103000020E6100000010000000500000060764F1E1674474094F947DFA4E7494060764F1E167447403CF9F4D896EB49409818CBF44B7A47403CF9F4D896EB49409818CBF44B7A474094F947DFA4E7494060764F1E1674474094F947DFA4E74940
29570	Булгаковка	7	73	742	46.848436	46.884520999999999	52.000140999999999	51.986593999999997	0103000020E61000000100000005000000E15F048D996C4740043752B648FE4940E15F048D996C4740C231CB9E04004A4007D0EFFB37714740C231CB9E04004A4007D0EFFB37714740043752B648FE4940E15F048D996C4740043752B648FE4940
26072	Букатовка	7	73	742	46.596646999999997	46.618889000000003	51.869872999999998	51.853332000000002	0103000020E61000000100000005000000D520CCED5E4C4740AD50A4FB39ED4940D520CCED5E4C474032569BFF57EF4940556D37C1374F474032569BFF57EF4940556D37C1374F4740AD50A4FB39ED4940D520CCED5E4C4740AD50A4FB39ED4940
29643	Биктимировка	7	73	742	46.832194000000001	46.852586000000002	51.943182999999998	51.930218000000004	0103000020E61000000100000005000000B6F63E55856A47404513286211F74940B6F63E55856A474053927538BAF849408483BD89216D474053927538BAF849408483BD89216D47404513286211F74940B6F63E55856A47404513286211F74940
26137	Березняки	7	73	742	46.683414999999997	46.711478	51.754871000000001	51.735956000000002	0103000020E61000000100000005000000444C89247A574740C2A563CE33DE4940444C89247A57474073D9E89C9FE0494068E90AB6115B474073D9E89C9FE0494068E90AB6115B4740C2A563CE33DE4940444C89247A574740C2A563CE33DE4940
25942	Андреевка	7	73	742	46.487735000000001	46.506329999999998	51.911816000000002	51.897613	0103000020E61000000100000005000000AA0EB9196E3E474073BB97FBE4F24940AA0EB9196E3E47401AFCFD62B6F44940E97DE36BCF4047401AFCFD62B6F44940E97DE36BCF40474073BB97FBE4F24940AA0EB9196E3E474073BB97FBE4F24940
27625	Юловая Маза	7	73	663	47.463836000000001	47.488773000000002	52.354745000000001	52.336418999999999	0103000020E610000001000000050000008E5A61FA5EBB474063601DC70F2B4A408E5A61FA5EBB4740B3B5BE48682D4A407B15191D90BE4740B3B5BE48682D4A407B15191D90BE474063601DC70F2B4A408E5A61FA5EBB474063601DC70F2B4A40
53217	Шиханы	7	73	663	47.130201	47.228405000000002	52.133927	52.083699000000003	0103000020E610000001000000050000000874266DAA9047409DDA19A6B60A4A400874266DAA90474094861A8524114A40179F02603C9D474094861A8524114A40179F02603C9D47409DDA19A6B60A4A400874266DAA9047409DDA19A6B60A4A40
28694	Широкий Буерак	7	73	663	47.752409999999998	47.785046000000001	52.129106999999998	52.105066999999998	0103000020E6100000010000000500000078978BF84EE04740C571E0D5720D4A4078978BF84EE04740A357039486104A4085ED27637CE44740A357039486104A4085ED27637CE44740C571E0D5720D4A4078978BF84EE04740C571E0D5720D4A40
27848	Шировка	7	73	663	46.765072000000004	46.790638000000001	52.196322000000002	52.185727999999997	0103000020E61000000100000005000000EC8A19E1ED614740CAF962EFC5174A40EC8A19E1ED6147401FBE4C1421194A40C87C40A0336547401FBE4C1421194A40C87C40A033654740CAF962EFC5174A40EC8A19E1ED614740CAF962EFC5174A40
28556	Черкасское	7	73	663	47.181845000000003	47.238726999999997	52.443354999999997	52.406923999999997	0103000020E6100000010000000500000077F86BB2469747408FFAEB1516344A4077F86BB24697474050C24CDBBF384A400AD6389B8E9E474050C24CDBBF384A400AD6389B8E9E47408FFAEB1516344A4077F86BB2469747408FFAEB1516344A40
28954	Труевая Маза	7	73	663	47.388485000000003	47.406972000000003	52.325961999999997	52.308897000000002	0103000020E6100000010000000500000048FE60E0B9B14740906AD8EF89274A4048FE60E0B9B147408FDE701FB9294A40A13193A817B447408FDE701FB9294A40A13193A817B44740906AD8EF89274A4048FE60E0B9B14740906AD8EF89274A40
25706	Тополевый	7	73	663	47.601035000000003	47.61354	52.065958000000002	52.05104	0103000020E610000001000000050000002D6002B7EECC4740D8648D7A88064A402D6002B7EECC47406D74CE4F71084A40D8648D7A88CE47406D74CE4F71084A40D8648D7A88CE4740D8648D7A88064A402D6002B7EECC4740D8648D7A88064A40
26656	Терса	7	73	663	47.495500999999997	47.570897000000002	52.102378999999999	52.067442	0103000020E610000001000000050000005111A7936CBF47403C3080F0A1084A405111A7936CBF47400A664CC11A0D4A403831242713C947400A664CC11A0D4A403831242713C947403C3080F0A1084A405111A7936CBF47403C3080F0A1084A40
28429	Тепловка	7	73	663	47.492573	47.515650000000001	52.167524999999998	52.138598000000002	0103000020E6100000010000000500000041F2CEA10CBF474040A54A94BD114A4041F2CEA10CBF474096218E7571154A405917B7D100C2474096218E7571154A405917B7D100C2474040A54A94BD114A4041F2CEA10CBF474040A54A94BD114A40
28279	Талалихино	7	73	663	47.63306	47.664473999999998	52.116377999999997	52.101322000000003	0103000020E61000000100000005000000F0332E1C08D14740C32E8A1EF80C4A40F0332E1C08D14740A8FC6B79E50E4A406A85E97B0DD54740A8FC6B79E50E4A406A85E97B0DD54740C32E8A1EF80C4A40F0332E1C08D14740C32E8A1EF80C4A40
4521	Спасское	7	73	663	47.076877000000003	47.088923999999999	52.508411000000002	52.493147999999998	0103000020E610000001000000050000004568041BD78947403D0B42791F3F4A404568041BD78947409DF6949C13414A402DEA93DC618B47409DF6949C13414A402DEA93DC618B47403D0B42791F3F4A404568041BD78947403D0B42791F3F4A40
28027	Сенной	7	73	663	46.941859999999998	46.982716000000003	52.170563000000001	52.144756000000001	0103000020E610000001000000050000008DB454DE8E7847402CF3565D87124A408DB454DE8E7847402E742502D5154A40C3A04CA3C97D47402E742502D5154A40C3A04CA3C97D47402CF3565D87124A408DB454DE8E7847402CF3565D87124A40
5117	Покурлей	7	73	663	47.336221000000002	47.394351	52.530045000000001	52.513508000000002	0103000020E610000001000000050000003D9D2B4A09AB4740001E51A1BA414A403D9D2B4A09AB47404434BA83D8434A408C12F4177AB247404434BA83D8434A408C12F4177AB24740001E51A1BA414A403D9D2B4A09AB4740001E51A1BA414A40
28852	Покровка	7	73	663	47.267617000000001	47.281962999999998	52.349040000000002	52.331553999999997	0103000020E61000000100000005000000446D1B4641A24740D26D895C702A4A40446D1B4641A24740787FBC57AD2C4A404DD7135D17A44740787FBC57AD2C4A404DD7135D17A44740D26D895C702A4A40446D1B4641A24740D26D895C702A4A40
53163	Откормсовхоз	7	73	663	46.717398000000003	47.981490000000001	52.638314000000001	51.911794	0103000020E61000000100000005000000A01B9AB2D35B4740325871AAB5F44940A01B9AB2D35B47401B4AED45B4514A40EFACDD76A1FD47401B4AED45B4514A40EFACDD76A1FD4740325871AAB5F44940A01B9AB2D35B4740325871AAB5F44940
28938	Осиновка	7	73	663	47.350163000000002	47.379519999999999	52.398533999999998	52.389543000000003	0103000020E6100000010000000500000077A22424D2AC474060B1868BDC314A4077A22424D2AC47400A2C802903334A40C616821C94B047400A2C802903334A40C616821C94B0474060B1868BDC314A4077A22424D2AC474060B1868BDC314A40
28020	Николаевка	7	73	663	47.009188999999999	47.030909999999999	52.341794999999998	52.331553999999997	0103000020E61000000100000005000000D13DEB1A2D814740D26D895C702A4A40D13DEB1A2D814740D97745F0BF2B4A40478FDFDBF4834740D97745F0BF2B4A40478FDFDBF4834740D26D895C702A4A40D13DEB1A2D814740D26D895C702A4A40
27893	Нижняя Чернавка	7	73	663	47.218406999999999	47.247638000000002	52.292133	52.270733	0103000020E61000000100000005000000D61BB5C2F49B474057790261A7224A40D61BB5C2F49B47408B8A389D64254A40999F1B9AB29F47408B8A389D64254A40999F1B9AB29F474057790261A7224A40D61BB5C2F49B474057790261A7224A40
28985	Междуречье	7	73	663	47.489958999999999	47.528523	52.520401999999997	52.499195999999998	0103000020E61000000100000005000000C0B0FCF9B6BE4740A2258FA7E53F4A40C0B0FCF9B6BE4740F16261889C424A40871744A4A6C34740F16261889C424A40871744A4A6C34740A2258FA7E53F4A40C0B0FCF9B6BE4740A2258FA7E53F4A40
27757	Куриловка	7	73	663	46.835732999999998	46.896594	52.174982	52.145727999999998	0103000020E610000001000000050000000F98874CF96A4740450E1137A7124A400F98874CF96A4740C0B167CF65164A4019E59997C3724740C0B167CF65164A4019E59997C3724740450E1137A7124A400F98874CF96A4740450E1137A7124A40
22013	Куликовка	7	73	663	47.574544000000003	47.613216000000001	52.259825999999997	52.224074999999999	0103000020E61000000100000005000000780E65A88AC94740F46C567DAE1C4A40780E65A88AC94740435376FA41214A4025B1A4DC7DCE4740435376FA41214A4025B1A4DC7DCE4740F46C567DAE1C4A40780E65A88AC94740F46C567DAE1C4A40
27954	Кряжим	7	73	663	47.104536000000003	47.136111999999997	52.277478000000002	52.261358000000001	0103000020E6100000010000000500000099A0866F618D47402446CF2D74214A4099A0866F618D474004AE2B6684234A40EC4B361E6C91474004AE2B6684234A40EC4B361E6C9147402446CF2D74214A4099A0866F618D47402446CF2D74214A40
10740	Колояр	7	73	663	46.918612000000003	46.966087999999999	52.579247000000002	52.550863999999997	0103000020E6100000010000000500000049DBF81395754740994528B682464A4049DBF813957547402FA704C4244A4A406E8786C5A87B47402FA704C4244A4A406E8786C5A87B4740994528B682464A4049DBF81395754740994528B682464A40
28207	Ключи	7	73	663	47.050718000000003	47.085582000000002	52.177517000000002	52.158138999999998	0103000020E61000000100000005000000C6A86BED7D8647406F9C14E63D144A40C6A86BED7D864740F5BD86E0B8164A402A90D959F48A4740F5BD86E0B8164A402A90D959F48A47406F9C14E63D144A40C6A86BED7D8647406F9C14E63D144A40
53200	Клены	7	73	663	47.463996999999999	47.474499000000002	52.092415000000003	52.087201999999998	0103000020E610000001000000050000009738F24064BB4740A912656F290B4A409738F24064BB474076543541D40B4A400B7E1B62BCBC474076543541D40B4A400B7E1B62BCBC4740A912656F290B4A409738F24064BB4740A912656F290B4A40
28656	Калмантай	7	73	663	47.109127000000001	47.137019000000002	52.572324000000002	52.546269000000002	0103000020E61000000100000005000000280EA0DFF78D4740C9E88024EC454A40280EA0DFF78D4740A35BAFE941494A401FF7ADD689914740A35BAFE941494A401FF7ADD689914740C9E88024EC454A40280EA0DFF78D4740C9E88024EC454A40
12166	Заветное	7	73	663	47.736716999999999	47.750739000000003	52.207864000000001	52.193666999999998	0103000020E6100000010000000500000020B41EBE4CDE47403FA88B14CA184A4020B41EBE4CDE474004029D499B1A4A40776A2E3718E0474004029D499B1A4A40776A2E3718E047403FA88B14CA184A4020B41EBE4CDE47403FA88B14CA184A40
16252	Ерыкла	7	73	663	47.015163000000001	47.03922	52.532263999999998	52.523513999999999	0103000020E61000000100000005000000FC8D76DCF0814740C37FBA8102434A40FC8D76DCF0814740486B0C3A21444A40B0AC342905854740486B0C3A21444A40B0AC342905854740C37FBA8102434A40FC8D76DCF0814740C37FBA8102434A40
27762	Елховка	7	73	663	46.939857000000003	46.964587999999999	52.215021	52.199049000000002	0103000020E6100000010000000500000056F5F23B4D78474098A608707A194A4056F5F23B4D784740037AE1CE851B4A40990E9D9E777B4740037AE1CE851B4A40990E9D9E777B474098A608707A194A4056F5F23B4D78474098A608707A194A40
28478	Девичьи Горки	7	73	663	47.631362000000003	47.664904999999997	52.075595999999997	52.057110000000002	0103000020E61000000100000005000000F5F75278D0D04740252367614F074A40F5F75278D0D04740ADDA3521AD094A4033F9669B1BD54740ADDA3521AD094A4033F9669B1BD54740252367614F074A40F5F75278D0D04740252367614F074A40
53133	Вольск	7	73	663	47.310124999999999	47.310834	52.085735999999997	52.085419999999999	0103000020E6100000010000000500000004560E2DB2A747405036E50AEF0A4A4004560E2DB2A74740800BB265F90A4A40103E9468C9A74740800BB265F90A4A40103E9468C9A747405036E50AEF0A4A4004560E2DB2A747405036E50AEF0A4A40
27676	Верхняя Чернавка	7	73	663	47.259891000000003	47.299425999999997	52.191426	52.154933999999997	0103000020E610000001000000050000002BC3B81B44A14740EC8497E0D4134A402BC3B81B44A1474053CDACA580184A403AC9569753A6474053CDACA580184A403AC9569753A64740EC8497E0D4134A402BC3B81B44A14740EC8497E0D4134A40
28847	Богородское	7	73	663	47.809705000000001	47.842250999999997	52.197403999999999	52.183419999999998	0103000020E610000001000000050000002F34D769A4E7474056B77A4E7A174A402F34D769A4E74740BF0CC68844194A40FB027AE1CEEB4740BF0CC68844194A40FB027AE1CEEB474056B77A4E7A174A402F34D769A4E7474056B77A4E7A174A40
28757	Богатое	7	73	663	47.720438999999999	47.739725999999997	52.229283000000002	52.212184999999998	0103000020E61000000100000005000000A8E15B5837DC4740D3D9C9E0281B4A40A8E15B5837DC4740AF433525591D4A401D007157AFDE4740AF433525591D4A401D007157AFDE4740D3D9C9E0281B4A40A8E15B5837DC4740D3D9C9E0281B4A40
27580	Белогорное	7	73	663	47.537424999999999	47.620026000000003	52.419595999999999	52.372117000000003	0103000020E61000000100000005000000C286A757CAC4474090A4A487A12F4A40C286A757CAC4474026C45C52B5354A40B95510035DCF474026C45C52B5354A40B95510035DCF474090A4A487A12F4A40C286A757CAC4474090A4A487A12F4A40
27577	Барановка	7	73	663	46.911515000000001	46.952433999999997	52.137172	52.100205000000003	0103000020E610000001000000050000001F680586AC744740A6F27684D30C4A401F680586AC744740A5F622DA8E114A409ACC785BE9794740A5F622DA8E114A409ACC785BE9794740A6F27684D30C4A401F680586AC744740A6F27684D30C4A40
25651	Царевщина	7	73	1497	46.690295999999996	46.742345	52.460631999999997	52.428806000000002	0103000020E61000000100000005000000A1478C9E5B5847400F2A711DE3364A40A1478C9E5B584740DBBE47FDF53A4A40B0AC3429055F4740DBBE47FDF53A4A40B0AC3429055F47400F2A711DE3364A40A1478C9E5B5847400F2A711DE3364A40
25458	Старое Сарайкино	7	73	1497	46.616247999999999	46.647050999999998	52.37182	52.359578999999997	0103000020E61000000100000005000000DA1CE736E14E474008AA46AF062E4A40DA1CE736E14E4740D6FF39CC972F4A400BEC3191D2524740D6FF39CC972F4A400BEC3191D252474008AA46AF062E4A40DA1CE736E14E474008AA46AF062E4A40
25504	Сосновка	7	73	1497	46.904401	46.948185000000002	52.381523999999999	52.361004000000001	0103000020E610000001000000050000001FBC7669C3734740D3DC0A61352E4A401FBC7669C3734740CE5147C7D5304A4065C746205E794740CE5147C7D5304A4065C746205E794740D3DC0A61352E4A401FBC7669C3734740D3DC0A61352E4A40
25452	Садовка	7	73	1497	46.580657000000002	46.6036	52.499809999999997	52.470858999999997	0103000020E61000000100000005000000C498F4F7524A47407D03931B453C4A40C498F4F7524A47405C1B2AC6F93F4A40CCEEC9C3424D47405C1B2AC6F93F4A40CCEEC9C3424D47407D03931B453C4A40C498F4F7524A47407D03931B453C4A40
25360	Пилюгино	7	73	1497	46.366560999999997	46.406734	52.628464999999998	52.613025999999998	0103000020E61000000100000005000000997E8978EB2E474081CCCEA2774E4A40997E8978EB2E47401FD7868A71504A40EC1516DC0F3447401FD7868A71504A40EC1516DC0F34474081CCCEA2774E4A40997E8978EB2E474081CCCEA2774E4A40
25354	Осановка	7	73	1497	46.605539999999998	46.623480000000001	52.436894000000002	52.426274999999997	0103000020E61000000100000005000000BD35B055824D47401B0DE02D90364A40BD35B055824D4740C9E88024EC374A40E4DA5031CE4F4740C9E88024EC374A40E4DA5031CE4F47401B0DE02D90364A40BD35B055824D47401B0DE02D90364A40
25267	Новая Лопастейка	7	73	1497	46.912134999999999	46.946074000000003	52.431524000000003	52.406094000000003	0103000020E61000000100000005000000BB44F5D6C0744740098D60E3FA334A40BB44F5D6C074474035B8AD2D3C374A4047CCECF31879474035B8AD2D3C374A4047CCECF318794740098D60E3FA334A40BB44F5D6C0744740098D60E3FA334A40
25221	Малая Караваевка	7	73	1497	46.646189	46.65793	52.537461999999998	52.522374999999997	0103000020E6100000010000000500000079043752B6524740BE9F1A2FDD424A4079043752B6524740DF6B088ECB444A405587DC0C37544740DF6B088ECB444A405587DC0C37544740BE9F1A2FDD424A4079043752B6524740BE9F1A2FDD424A40
25168	Журавлиха	7	73	1497	46.556896000000002	46.589613	52.666553	52.659387000000002	0103000020E61000000100000005000000F9A23D5E484747402B3410CB66544A40F9A23D5E484747407D06D49B51554A40F2255470784B47407D06D49B51554A40F2255470784B47402B3410CB66544A40F9A23D5E484747402B3410CB66544A40
25159	Донгуз	7	73	1497	46.747186999999997	46.829742000000003	52.527639999999998	52.482362000000002	0103000020E61000000100000005000000887FD8D2A35F4740A56ABB09BE3D4A40887FD8D2A35F4740DD0720B589434A400F0F61FC346A4740DD0720B589434A400F0F61FC346A4740A56ABB09BE3D4A40887FD8D2A35F4740A56ABB09BE3D4A40
25083	Всеволодчино	7	73	1497	46.472033000000003	46.488948000000001	52.505056000000003	52.489063000000002	0103000020E61000000100000005000000FFD0CC936B3C47408257CB9D993E4A40FFD0CC936B3C47400553CDACA5404A40E9B81AD9953E47400553CDACA5404A40E9B81AD9953E47408257CB9D993E4A40FFD0CC936B3C47408257CB9D993E4A40
25079	Большие Озерки	7	73	1497	46.529542999999997	46.553742999999997	52.614846	52.589686999999998	0103000020E61000000100000005000000B169A510C84347402CF015DD7A4B4A40B169A510C8434740C8091346B34E4A40C8B1F50CE1464740C8091346B34E4A40C8B1F50CE14647402CF015DD7A4B4A40B169A510C84347402CF015DD7A4B4A40
25004	Барнуковка	7	73	1497	46.709341000000002	46.790188999999998	52.346367000000001	52.311109999999999	0103000020E61000000100000005000000215B96AFCB5A4740B2BAD573D2274A40215B96AFCB5A4740F2B4FCC0552C4A405854C4E924654740F2B4FCC0552C4A405854C4E924654740B2BAD573D2274A40215B96AFCB5A4740B2BAD573D2274A40
17376	Балтай	7	73	1497	46.601506999999998	46.663688	52.476152999999996	52.455160999999997	0103000020E6100000010000000500000054A86E2EFE4C474013B534B7423A4A4054A86E2EFE4C47403672DD94F23C4A40B35F77BAF35447403672DD94F23C4A40B35F77BAF354474013B534B7423A4A4054A86E2EFE4C474013B534B7423A4A40
17166	Хоперское	7	73	595	43.204078000000003	43.262253000000001	51.586806000000003	51.554437999999998	0103000020E61000000100000005000000A3EA573A1F9A45406FD40AD3F7C64940A3EA573A1F9A45405D8C81751CCB494092239D8191A145405D8C81751CCB494092239D8191A145406FD40AD3F7C64940A3EA573A1F9A45406FD40AD3F7C64940
23508	Устиновка	7	73	595	43.350396000000003	43.387514000000003	51.459952000000001	51.444662999999998	0103000020E610000001000000050000001A53B0C6D9AC4540E15E99B7EAB849401A53B0C6D9AC45406ADD06B5DFBA4940FF5E0A0F9AB145406ADD06B5DFBA4940FF5E0A0F9AB14540E15E99B7EAB849401A53B0C6D9AC4540E15E99B7EAB84940
32369	Тростянка	7	73	595	43.054617	43.106512000000002	51.521206999999997	51.491663000000003	0103000020E610000001000000050000001F679AB0FD8645409ED32CD0EEBE49401F679AB0FD8645401FB935E9B6C24940D7506A2FA28D45401FB935E9B6C24940D7506A2FA28D45409ED32CD0EEBE49401F679AB0FD8645409ED32CD0EEBE4940
24743	Терновка	7	73	595	42.908101000000002	42.943593999999997	51.341030000000003	51.311481999999998	0103000020E61000000100000005000000823B50A73C74454076A565A4DEA74940823B50A73C7445403A7AFCDEA6AB4940D5592DB0C77845403A7AFCDEA6AB4940D5592DB0C778454076A565A4DEA74940823B50A73C74454076A565A4DEA74940
24824	Сухая Елань	7	73	595	42.947861000000003	42.977739	51.261392000000001	51.245427999999997	0103000020E61000000100000005000000B2135E8253794540E7C2482F6A9F4940B2135E8253794540D0B7054B75A149400A83328D267D4540D0B7054B75A149400A83328D267D4540E7C2482F6A9F4940B2135E8253794540E7C2482F6A9F4940
24685	Старый Хопер	7	73	595	42.942076	42.985697999999999	51.511992999999997	51.487844000000003	0103000020E610000001000000050000005A2C45F29578454061C614AC71BE49405A2C45F295784540F56393FC88C14940C6DD205A2B7E4540F56393FC88C14940C6DD205A2B7E454061C614AC71BE49405A2C45F29578454061C614AC71BE4940
5976	Соцземледельский	7	73	595	43.671965999999998	43.694719999999997	51.666182999999997	51.649498999999999	0103000020E6100000010000000500000010035DFB02D6454071E481C822D3494010035DFB02D6454059130B7C45D5494045F0BF95ECD8454059130B7C45D5494045F0BF95ECD8454071E481C822D3494010035DFB02D6454071E481C822D34940
23924	Садовый	7	73	595	43.129697999999998	43.152838000000003	51.748837999999999	51.735861	0103000020E61000000100000005000000A52DAEF19990454070B378B130DE4940A52DAEF199904540430070ECD9DF494004CB113290934540430070ECD9DF494004CB11329093454070B378B130DE4940A52DAEF19990454070B378B130DE4940
24441	Родничок	7	73	595	42.888770000000001	42.926256000000002	51.431789000000002	51.412457000000003	0103000020E610000001000000050000003DD52137C3714540CE001764CBB449403DD52137C3714540E3E2A8DC44B74940A5DC7D8E8F764540E3E2A8DC44B74940A5DC7D8E8F764540CE001764CBB449403DD52137C3714540CE001764CBB44940
6875	Репное	7	73	595	43.146011000000001	43.206755000000001	51.615051000000001	51.576177999999999	0103000020E610000001000000050000009AED0A7DB09245405C566133C0C949409AED0A7DB0924540A12FBDFDB9CE49406AA4A5F2769A4540A12FBDFDB9CE49406AA4A5F2769A45405C566133C0C949409AED0A7DB09245405C566133C0C94940
23920	Репная Вершина	7	73	595	43.150717999999998	43.185482999999998	51.723896000000003	51.702534	0103000020E61000000100000005000000927538BA4A934540FE2955A2ECD94940927538BA4A93454045DAC69FA8DC4940637B2DE8BD97454045DAC69FA8DC4940637B2DE8BD974540FE2955A2ECD94940927538BA4A934540FE2955A2ECD94940
31259	Рассказань	7	73	595	42.637700000000002	42.678061	51.576087999999999	51.557310999999999	0103000020E6100000010000000500000061545227A0514540BC5983F755C7494061545227A05145401CCF6740BDC94940B6D8EDB3CA5645401CCF6740BDC94940B6D8EDB3CA564540BC5983F755C7494061545227A0514540BC5983F755C74940
24136	Пинеровка	7	73	595	43.033524	43.090567	51.579777	51.547902999999998	0103000020E61000000100000005000000C8D0B1834A844540AD307DAF21C64940C8D0B1834A8445408BFCFA2136CA4940658C0FB3978B45408BFCFA2136CA4940658C0FB3978B4540AD307DAF21C64940C8D0B1834A844540AD307DAF21C64940
24037	Первомайский	7	73	595	43.158031000000001	43.184738000000003	51.449148000000001	51.428632999999998	0103000020E6100000010000000500000089601C5C3A944540417E3672DDB6494089601C5C3A9445402B8881AE7DB949400B2AAA7EA59745402B8881AE7DB949400B2AAA7EA5974540417E3672DDB6494089601C5C3A944540417E3672DDB64940
24023	Пады	7	73	595	43.229149999999997	43.268433999999999	51.736246000000001	51.712401	0103000020E610000001000000050000006FF085C9549D4540A051BAF42FDB49406FF085C9549D4540C9E7154F3DDE49403691990B5CA24540C9E7154F3DDE49403691990B5CA24540A051BAF42FDB49406FF085C9549D4540A051BAF42FDB4940
23837	Октябрьский	7	73	595	43.148383000000003	43.180911000000002	51.756369999999997	51.736289999999997	0103000020E610000001000000050000002524D236FE924540982F2FC03EDE49402524D236FE92454077D66EBBD0E049404B3E76172897454077D66EBBD0E049404B3E761728974540982F2FC03EDE49402524D236FE924540982F2FC03EDE4940
23749	Новопокровское	7	73	595	43.580193999999999	43.626682000000002	51.591768999999999	51.562255	0103000020E61000000100000005000000EFAA07CC43CA45409981CAF8F7C74940EFAA07CC43CA4540B0E42A16BFCB4940F67EA31D37D04540B0E42A16BFCB4940F67EA31D37D045409981CAF8F7C74940EFAA07CC43CA45409981CAF8F7C74940
53197	Нижная Глебовка	7	73	595	43.412407000000002	43.434308000000001	51.529359999999997	51.516627999999997	0103000020E610000001000000050000001CD2A8C0C9B445405419C6DD20C249401CD2A8C0C9B44540C0E78711C2C349401232906797B74540C0E78711C2C349401232906797B745405419C6DD20C249401CD2A8C0C9B445405419C6DD20C24940
24530	Михайловка	7	73	595	42.894680999999999	42.911209999999997	51.378273	51.356167999999997	0103000020E6100000010000000500000021AD31E884724540DCF0BBE996AD494021AD31E884724540DBFAE93F6BB04940E2E47E87A2744540DBFAE93F6BB04940E2E47E87A2744540DCF0BBE996AD494021AD31E884724540DCF0BBE996AD4940
24827	Малый Мелик	7	73	595	43.382466000000001	43.414454999999997	51.661065000000001	51.642764999999997	0103000020E610000001000000050000007DEA58A5F4B04540B8019F1F46D249407DEA58A5F4B04540DFC325C79DD44940F35487DC0CB54540DFC325C79DD44940F35487DC0CB54540B8019F1F46D249407DEA58A5F4B04540B8019F1F46D24940
23652	Малая Семеновка	7	73	595	43.603414999999998	43.632798999999999	51.507238999999998	51.492516000000002	0103000020E610000001000000050000003A75E5B33CCD4540DD60A8C30ABF49403A75E5B33CCD4540BC202235EDC0494083F8C08EFFD04540BC202235EDC0494083F8C08EFFD04540DD60A8C30ABF49403A75E5B33CCD4540DD60A8C30ABF4940
24640	Львовка	7	73	595	43.605580000000003	43.628981000000003	51.714427000000001	51.704867	0103000020E610000001000000050000004C8E3BA583CD4540CB83F41439DA49404C8E3BA583CD454090300C5872DB494017670C7382D0454090300C5872DB494017670C7382D04540CB83F41439DA49404C8E3BA583CD4540CB83F41439DA4940
53215	Лопатино	7	73	595	43.081601999999997	43.107796999999998	51.596229000000001	51.570681	0103000020E61000000100000005000000E3A430EF718A45406BB933130CC94940E3A430EF718A4540A1F65B3B51CC4940AFCDC64ACC8D4540A1F65B3B51CC4940AFCDC64ACC8D45406BB933130CC94940E3A430EF718A45406BB933130CC94940
30365	Лесное	7	73	595	42.743090000000002	42.773218999999997	51.587791000000003	51.564163999999998	0103000020E6100000010000000500000009FEB7921D5F45404FCAA48636C8494009FEB7921D5F45400BF148BC3CCB4940AAD216D7F86245400BF148BC3CCB4940AAD216D7F86245404FCAA48636C8494009FEB7921D5F45404FCAA48636C84940
21168	Красная Кудрявка	7	73	595	43.044178000000002	43.071182	51.413080999999998	51.399777	0103000020E61000000100000005000000F299EC9FA7854540B4588AE42BB34940F299EC9FA7854540ABCC94D6DFB449402D08E57D1C894540ABCC94D6DFB449402D08E57D1C894540B4588AE42BB34940F299EC9FA7854540B4588AE42BB34940
23452	Котоврас	7	73	595	43.293829000000002	43.337730000000001	51.718640000000001	51.697113999999999	0103000020E61000000100000005000000E6CE4C309CA54540B8CA13083BD94940E6CE4C309CA5454079CC4065FCDB4940657094BC3AAB454079CC4065FCDB4940657094BC3AAB4540B8CA13083BD94940E6CE4C309CA54540B8CA13083BD94940
23568	Конный	7	73	595	42.786226999999997	42.810921999999998	51.486801	51.470785999999997	0103000020E61000000100000005000000B81D1A16A364454013B534B742BC4940B81D1A16A36445407E54C37E4FBE4940AFCDC64ACC6745407E54C37E4FBE4940AFCDC64ACC67454013B534B742BC4940B81D1A16A364454013B534B742BC4940
9940	Кардаил	7	73	595	42.873911999999997	42.902549999999998	51.410851000000001	51.395977999999999	0103000020E610000001000000050000007DCA3159DC6F4540BEF73768AFB249407DCA3159DC6F4540B343FCC396B449409D8026C286734540B343FCC396B449409D8026C286734540BEF73768AFB249407DCA3159DC6F4540BEF73768AFB24940
24329	Заречное	7	73	595	43.110627000000001	43.150160999999997	51.681508999999998	51.653925000000001	0103000020E61000000100000005000000FD868906298E4540B6847CD0B3D34940FD868906298E4540FF76D9AF3BD749403C11C47938934540FF76D9AF3BD749403C11C47938934540B6847CD0B3D34940FD868906298E4540B6847CD0B3D34940
24533	Дуплятка	7	73	595	42.800024999999998	42.822204999999997	51.443466999999998	51.430154999999999	0103000020E61000000100000005000000BF7D1D3867664540FE9AAC510FB74940BF7D1D386766454078EDD286C3B84940C8CD70033E69454078EDD286C3B84940C8CD70033E694540FE9AAC510FB74940BF7D1D3867664540FE9AAC510FB74940
24837	Данилкино	7	73	595	43.078395	43.116411999999997	51.283396000000003	51.248584999999999	0103000020E61000000100000005000000C095ECD8088A454059A31EA2D19F4940C095ECD8088A45409BE8F35146A44940546EA296E68E45409BE8F35146A44940546EA296E68E454059A31EA2D19F4940C095ECD8088A454059A31EA2D19F4940
23655	Гусевка	7	73	595	43.702849999999998	43.721606999999999	51.523107000000003	51.508550999999997	0103000020E610000001000000050000002EFF21FDF6D945408EACFC3218C149402EFF21FDF6D9454083A7902BF5C2494047C8409E5DDC454083A7902BF5C2494047C8409E5DDC45408EACFC3218C149402EFF21FDF6D945408EACFC3218C14940
24080	Ветельный	7	73	595	43.207869000000002	43.229968	51.486263000000001	51.473928000000001	0103000020E61000000100000005000000166D8E739B9A4540505436ACA9BC4940166D8E739B9A45409F20B1DD3DBE4940329067976F9D45409F20B1DD3DBE4940329067976F9D4540505436ACA9BC4940166D8E739B9A4540505436ACA9BC4940
23181	Большой Мелик	7	73	595	43.26202	43.328127000000002	51.638651000000003	51.608105000000002	0103000020E61000000100000005000000EF7211DF89A145405DC47762D6CD4940EF7211DF89A145406347E350BFD14940A1F7C61000AA45406347E350BFD14940A1F7C61000AA45405DC47762D6CD4940EF7211DF89A145405DC47762D6CD4940
23736	Березовка	7	73	595	43.503666000000003	43.527085999999997	51.535859000000002	51.522395000000003	0103000020E61000000100000005000000B70DA32078C04540064CE0D6DDC24940B70DA32078C045403622180797C44940F816D68D77C345403622180797C44940F816D68D77C34540064CE0D6DDC24940B70DA32078C04540064CE0D6DDC24940
23453	Барки	7	73	595	43.415937	43.446165000000001	51.495756999999998	51.480862000000002	0103000020E610000001000000050000002219726C3DB54540D0F1D1E28CBD49402219726C3DB54540ACE122F774BF494057CF49EF1BB94540ACE122F774BF494057CF49EF1BB94540D0F1D1E28CBD49402219726C3DB54540D0F1D1E28CBD4940
53127	Балашов	7	73	595	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
24226	Алмазово	7	73	595	42.887844000000001	42.946387999999999	51.566572000000001	51.552646000000003	0103000020E6100000010000000500000094F947DFA4714540F321A81ABDC6494094F947DFA4714540276A696E85C84940D6A9F23D23794540276A696E85C84940D6A9F23D23794540F321A81ABDC6494094F947DFA4714540F321A81ABDC64940
23785	Александровский	7	73	595	43.544172000000003	43.563045000000002	51.634357999999999	51.612971000000002	0103000020E6100000010000000500000010B3976DA7C54540BE326FD575CE494010B3976DA7C545405DFA97A432D149409296CADB11C845405DFA97A432D149409296CADB11C84540BE326FD575CE494010B3976DA7C54540BE326FD575CE4940
53195	Ветлянка	7	73	7273	43.147286999999999	43.170140000000004	51.535915000000003	51.516286000000001	0103000020E610000001000000050000001F10E84CDA924540FBB0DEA815C249401F10E84CDA924540CA37DBDC98C44940E8DEC325C7954540CA37DBDC98C44940E8DEC325C7954540FBB0DEA815C249401F10E84CDA924540FBB0DEA815C24940
21355	Хлебновка	7	73	588	48.352853000000003	48.375112999999999	52.149807000000003	52.131191000000001	0103000020E61000000100000005000000D3A57F492A2D4840C843DFDDCA104A40D3A57F492A2D48401FDB32E02C134A40F8A6E9B3033048401FDB32E02C134A40F8A6E9B303304840C843DFDDCA104A40D3A57F492A2D4840C843DFDDCA104A40
20861	Сухой Отрог	7	73	588	48.171250000000001	48.210388999999999	51.895873999999999	51.871451999999998	0103000020E6100000010000000500000052B81E85EB154840530438BD8BEF494052B81E85EB15484019ABCDFFABF249401538D906EE1A484019ABCDFFABF249401538D906EE1A4840530438BD8BEF494052B81E85EB154840530438BD8BEF4940
20299	Пылковка	7	73	588	47.836232000000003	47.857126999999998	51.833433999999997	51.821733999999999	0103000020E6100000010000000500000031EF71A609EB4740710168942EE9494031EF71A609EB4740EEAF1EF7ADEA494061C26856B6ED4740EEAF1EF7ADEA494061C26856B6ED4740710168942EE9494031EF71A609EB4740710168942EE94940
20767	Подсосенки	7	73	588	47.888827999999997	47.911285999999997	52.012371000000002	51.997070000000001	0103000020E6100000010000000500000071E2AB1DC5F147404FE960FD9FFF494071E2AB1DC5F147409C35785F95014A40BDA60705A5F447409C35785F95014A40BDA60705A5F447404FE960FD9FFF494071E2AB1DC5F147404FE960FD9FFF4940
19833	Плеханы	7	73	588	47.327849000000001	47.390802000000001	51.977024999999998	51.960661999999999	0103000020E610000001000000050000005E83BEF4F6A947404641F0F8F6FA49405E83BEF4F6A94740EC2FBB270FFD49400F9BC8CC05B24740EC2FBB270FFD49400F9BC8CC05B247404641F0F8F6FA49405E83BEF4F6A947404641F0F8F6FA4940
20967	Перекопная Лука	7	73	588	48.294812999999998	48.314979999999998	51.862521000000001	51.854160999999998	0103000020E61000000100000005000000C3B7B06EBC2548406342CC2555ED4940C3B7B06EBC2548407E8E8F1667EE49407172BF43512848407E8E8F1667EE49407172BF43512848406342CC2555ED4940C3B7B06EBC2548406342CC2555ED4940
20289	Новый Елюзань	7	73	588	47.779080999999998	47.804647000000003	51.743344999999998	51.720202	0103000020E61000000100000005000000ADF71BEDB8E34740C44142942FDC4940ADF71BEDB8E347409352D0ED25DF49408AE942ACFEE647409352D0ED25DF49408AE942ACFEE64740C44142942FDC4940ADF71BEDB8E34740C44142942FDC4940
19992	Новополеводино	7	73	588	47.461644	47.498995999999998	51.759821000000002	51.750476999999997	0103000020E6100000010000000500000083328D2617BB474039B35DA10FE0494083328D2617BB474032E884D041E14940DB6AD619DFBF474032E884D041E14940DB6AD619DFBF474039B35DA10FE0494083328D2617BB474039B35DA10FE04940
21164	Новониколаевский	7	73	588	48.168447	48.201065	52.055990999999999	52.043407999999999	0103000020E61000000100000005000000FE0DDAAB8F1548404031B2648E054A40FE0DDAAB8F15484067EF8CB62A074A4064AF777FBC19484067EF8CB62A074A4064AF777FBC1948404031B2648E054A40FE0DDAAB8F1548404031B2648E054A40
20167	Никольское-Казаково	7	73	588	47.669432999999998	47.693472	51.740763000000001	51.717970000000001	0103000020E610000001000000050000007CEE04FBAFD547402BC1E270E6DB49407CEE04FBAFD547401E8B6D52D1DE49408A58C4B0C3D847401E8B6D52D1DE49408A58C4B0C3D847402BC1E270E6DB49407CEE04FBAFD547402BC1E270E6DB4940
21302	Николевский	7	73	588	48.196196	48.208466999999999	52.134624000000002	52.114956999999997	0103000020E6100000010000000500000092CD55F31C1948401FB935E9B60E4A4092CD55F31C194840DCA0F65B3B114A40CAA5F10BAF1A4840DCA0F65B3B114A40CAA5F10BAF1A48401FB935E9B60E4A4092CD55F31C1948401FB935E9B60E4A40
21264	Николаевка	7	73	588	48.052205000000001	48.085118999999999	52.181288000000002	52.159846000000002	0103000020E6100000010000000500000006D847A7AE064840BE326FD575144A4006D847A7AE0648402194F77134174A4055A2EC2DE50A48402194F77134174A4055A2EC2DE50A4840BE326FD575144A4006D847A7AE064840BE326FD575144A40
20532	Наумовка	7	73	588	47.963946	47.989179	51.842449000000002	51.823403999999996	0103000020E61000000100000005000000158E209562FB4740A2B2614D65E94940158E209562FB474022C66B5ED5EB4940EB71DF6A9DFE474022C66B5ED5EB4940EB71DF6A9DFE4740A2B2614D65E94940158E209562FB4740A2B2614D65E94940
21169	Натальино	7	73	588	47.905357000000002	47.936610000000002	52.072031000000003	52.055593000000002	0103000020E61000000100000005000000331AF9BCE2F347407A71E2AB1D074A40331AF9BCE2F347402BA6D24F38094A40A48D23D6E2F747402BA6D24F38094A40A48D23D6E2F747407A71E2AB1D074A40331AF9BCE2F347407A71E2AB1D074A40
19935	Маянга	7	73	588	47.600712000000001	47.650955000000003	51.910049000000001	51.888609000000002	0103000020E610000001000000050000004A287D21E4CC474034F790F0BDF149404A287D21E4CC4740F660527C7CF449407715527E52D34740F660527C7CF449407715527E52D3474034F790F0BDF149404A287D21E4CC474034F790F0BDF14940
3705	Матвеевка	7	73	588	47.999321000000002	48.019002999999998	52.161304999999999	52.140051999999997	0103000020E610000001000000050000005F9A22C0E9FF4740A4DE5339ED114A405F9A22C0E9FF474034D769A4A5144A4050C3B7B06E02484034D769A4A5144A4050C3B7B06E024840A4DE5339ED114A405F9A22C0E9FF4740A4DE5339ED114A40
20367	Малый Кушум	7	73	588	47.871805000000002	47.890895	51.856825000000001	51.839010000000002	0103000020E61000000100000005000000A1BE654E97EF47402C82FFAD64EB4940A1BE654E97EF474096B20C71ACED4940C095ECD808F2474096B20C71ACED4940C095ECD808F247402C82FFAD64EB4940A1BE654E97EF47402C82FFAD64EB4940
20979	Малоперекопное	7	73	588	48.302314000000003	48.344830999999999	51.918604000000002	51.898240999999999	0103000020E61000000100000005000000BD8FA339B22648409276A38FF9F24940BD8FA339B2264840C6FCDCD094F54940D0D2156C232C4840C6FCDCD094F54940D0D2156C232C48409276A38FF9F24940BD8FA339B22648409276A38FF9F24940
20063	Малая Быковка	7	73	588	47.723196999999999	47.772308000000002	51.904693000000002	51.881810999999999	0103000020E610000001000000050000005CC823B891DC47406420CF2EDFF049405CC823B891DC4740C7F5EFFACCF34940373811FDDAE24740C7F5EFFACCF34940373811FDDAE247406420CF2EDFF049405CC823B891DC47406420CF2EDFF04940
20656	Криволучье-Сура	7	73	588	48.078848999999998	48.119058000000003	51.862515000000002	51.845008999999997	0103000020E6100000010000000500000041295AB9170A4840AFE9414129EC494041295AB9170A48409CA73AE466EE4940E129E44A3D0F48409CA73AE466EE4940E129E44A3D0F4840AFE9414129EC494041295AB9170A4840AFE9414129EC4940
19827	Красный Яр	7	73	588	47.608733999999998	47.650585999999997	51.971766000000002	51.952914	0103000020E610000001000000050000004CFBE6FEEACD474045F30016F9F949404CFBE6FEEACD4740B0AE0AD462FC4940239EEC6646D34740B0AE0AD462FC4940239EEC6646D3474045F30016F9F949404CFBE6FEEACD474045F30016F9F94940
20643	Кормежка	7	73	588	47.992691999999998	48.031103999999999	51.905904	51.888897999999998	0103000020E610000001000000050000001B800D8810FF47406ABDDF68C7F149401B800D8810FF474065A88AA9F4F349402C634337FB03484065A88AA9F4F349402C634337FB0348406ABDDF68C7F149401B800D8810FF47406ABDDF68C7F14940
53157	Комсомольское	7	73	588	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
19742	Ивановка	7	73	588	47.477857999999998	47.761024999999997	52.000086000000003	51.708975000000002	0103000020E61000000100000005000000E41071732ABD47403F575BB1BFDA4940E41071732ABD4740FF976BD102004A401D38674469E14740FF976BD102004A401D38674469E147403F575BB1BFDA4940E41071732ABD47403F575BB1BFDA4940
20855	Затонский	7	73	588	47.842089000000001	47.887875999999999	52.066706000000003	52.044764999999998	0103000020E6100000010000000500000022A98592C9EB4740B28009DCBA054A4022A98592C9EB474037397CD289084A409F73B7EBA5F1474037397CD289084A409F73B7EBA5F14740B28009DCBA054A4022A98592C9EB4740B28009DCBA054A40
19929	Еланка	7	73	588	47.465083999999997	47.485143999999998	51.947735000000002	51.922092999999997	0103000020E6100000010000000500000049F25CDF87BB47406D6FB72407F6494049F25CDF87BB4740252367614FF94940E1ECD63219BE4740252367614FF94940E1ECD63219BE47406D6FB72407F6494049F25CDF87BB47406D6FB72407F64940
21077	Грачи	7	73	588	48.098765	48.110424999999999	51.999077	51.990431999999998	0103000020E61000000100000005000000A67EDE54A40C4840B874CC79C6FE4940A67EDE54A40C4840C89750C1E1FF494095D40968220E4840C89750C1E1FF494095D40968220E4840B874CC79C6FE4940A67EDE54A40C4840B874CC79C6FE4940
21020	Головановский	7	73	588	48.097247000000003	48.135452000000001	51.973047000000001	51.961561000000003	0103000020E610000001000000050000002B51F696720C4840F60D4C6E14FB49402B51F696720C4840473CD9CD8CFC4940C216BB7D56114840473CD9CD8CFC4940C216BB7D56114840F60D4C6E14FB49402B51F696720C4840F60D4C6E14FB4940
20172	Быков Отрог	7	73	588	47.796446000000003	47.823072000000003	51.9437	51.919215000000001	0103000020E61000000100000005000000D88349F1F1E547400F7F4DD6A8F54940D88349F1F1E547401B9E5E29CBF849406D205D6C5AE947401B9E5E29CBF849406D205D6C5AE947400F7F4DD6A8F54940D88349F1F1E547400F7F4DD6A8F54940
20543	Большой Кушум	7	73	588	48.087491	48.117880999999997	51.780118999999999	51.757831000000003	0103000020E61000000100000005000000E0D8B3E7320B48408F72309B00E14940E0D8B3E7320B48407EFE7BF0DAE34940EEE87FB9160F48407EFE7BF0DAE34940EEE87FB9160F48408F72309B00E14940E0D8B3E7320B48408F72309B00E14940
20708	Береговой	7	73	588	48.111916000000001	48.124096999999999	51.822363000000003	51.816628999999999	0103000020E6100000010000000500000017F37343530E48408BFB8F4C87E8494017F37343530E48406138D73043E949400F441669E20F48406138D73043E949400F441669E20F48408BFB8F4C87E8494017F37343530E48408BFB8F4C87E84940
40350	Балаково	7	73	588	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
53156	Балаково	7	73	7264	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
53135	Балаково	7	73	7255	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
53228	с. Большой Содом	7	73	793	45.931497999999998	46.829391000000001	52.612057999999998	51.923898000000001	0103000020E610000001000000050000000B2593533BF746407F6B274A42F649400B2593533BF74640A9A0A2EA574E4A40624CFA7B296A4740A9A0A2EA574E4A40624CFA7B296A47407F6B274A42F649400B2593533BF746407F6B274A42F64940
16665	Яковлевка	7	73	793	46.162464	46.187913000000002	52.516379999999998	52.506765999999999	0103000020E610000001000000050000008063CF9ECB144740C45C52B5DD404A408063CF9ECB1447407C2766BD18424A4023BF7E880D1847407C2766BD18424A4023BF7E880D184740C45C52B5DD404A408063CF9ECB144740C45C52B5DD404A40
16672	Шняево	7	73	793	46.155825999999998	46.193787999999998	52.582841999999999	52.564129999999999	0103000020E61000000100000005000000E9EE3A1BF2134740A3586E6935484A40E9EE3A1BF21347401C5E10919A4A4A40BA2D910BCE1847401C5E10919A4A4A40BA2D910BCE184740A3586E6935484A40E9EE3A1BF2134740A3586E6935484A40
16357	Хватовка	7	73	793	46.545774999999999	46.583342999999999	52.365931000000003	52.336826000000002	0103000020E61000000100000005000000B9FC87F4DB454740A438471D1D2B4A40B9FC87F4DB454740DACBB6D3D62E4A40DEACC1FBAA4A4740DACBB6D3D62E4A40DEACC1FBAA4A4740A438471D1D2B4A40B9FC87F4DB454740A438471D1D2B4A40
16873	Ханеневка 1-я	7	73	793	46.056516999999999	46.089153000000003	52.417651999999997	52.404407999999997	0103000020E610000001000000050000008255F5F23B074740D11E2FA4C3334A408255F5F23B074740F38DE89E75354A408FAB915D690B4740F38DE89E75354A408FAB915D690B4740D11E2FA4C3334A408255F5F23B074740D11E2FA4C3334A40
16489	Тепляковка	7	73	793	46.295172000000001	46.327717999999997	52.354860000000002	52.338124999999998	0103000020E61000000100000005000000F3583332C8254740E17A14AE472B4A40F3583332C82547404C546F0D6C2D4A40BF27D6A9F22947404C546F0D6C2D4A40BF27D6A9F2294740E17A14AE472B4A40F3583332C8254740E17A14AE472B4A40
15961	Сухой Карабулак	7	73	793	46.395406000000001	46.440537999999997	52.025357	52.001821	0103000020E610000001000000050000003352EFA99C32474017B9A7AB3B004A403352EFA99C324740C2DCEEE53E034A409752978C63384740C2DCEEE53E034A409752978C6338474017B9A7AB3B004A403352EFA99C32474017B9A7AB3B004A40
16111	Стригай	7	73	793	46.598587000000002	46.647168000000001	52.231119	52.209888999999997	0103000020E61000000100000005000000C767B27F9E4C474023658BA4DD1A4A40C767B27F9E4C4740FB3DB14E951D4A404582A966D6524740FB3DB14E951D4A404582A966D652474023658BA4DD1A4A40C767B27F9E4C474023658BA4DD1A4A40
16872	Старые Бурасы	7	73	793	46.119776000000002	46.184598999999999	52.270209999999999	52.245821999999997	0103000020E61000000100000005000000406CE9D1540F474093516518771F4A40406CE9D1540F4740AD86C43D96224A40E9EFA5F0A0174740AD86C43D96224A40E9EFA5F0A017474093516518771F4A40406CE9D1540F474093516518771F4A40
5804	Старая Жуковка	7	73	793	46.498497	46.528725000000001	52.211345999999999	52.191088999999998	0103000020E61000000100000005000000BA13ECBFCE3F47400BD0B69A75184A40BA13ECBFCE3F4740F911BF620D1B4A40EFC9C342AD434740F911BF620D1B4A40EFC9C342AD4347400BD0B69A75184A40BA13ECBFCE3F47400BD0B69A75184A40
16421	Свободный	7	73	793	46.346843	46.392342999999997	52.341645999999997	52.317210000000003	0103000020E610000001000000050000005BECF659652C47406AFB57569A284A405BECF659652C474094675E0EBB2B4A4042E8A04B3832474094675E0EBB2B4A4042E8A04B383247406AFB57569A284A405BECF659652C47406AFB57569A284A40
16802	Репьевка	7	73	793	46.097166000000001	46.116658999999999	52.543602	52.529158000000002	0103000020E610000001000000050000003E247CEF6F0C474059350873BB434A403E247CEF6F0C4740250516C094454A405CE49EAEEE0E4740250516C094454A405CE49EAEEE0E474059350873BB434A403E247CEF6F0C474059350873BB434A40
15545	Марьино	7	73	793	45.965643	45.997757999999997	52.316693000000001	52.305472000000002	0103000020E61000000100000005000000404E98309AFB4640FFEBDCB419274A40404E98309AFB4640A2EF6E6589284A4043A9BD88B6FF4640A2EF6E6589284A4043A9BD88B6FF4640FFEBDCB419274A40404E98309AFB4640FFEBDCB419274A40
16057	Максимовка	7	73	793	46.541058999999997	46.578681000000003	52.070304	52.04569	0103000020E610000001000000050000006D1ADB6B414547408BE07F2BD9054A406D1ADB6B414547409563B2B8FF084A4086E81038124A47409563B2B8FF084A4086E81038124A47408BE07F2BD9054A406D1ADB6B414547408BE07F2BD9054A40
27196	Липовка	7	73	793	46.171950000000002	46.220728999999999	52.456391000000004	52.418745000000001	0103000020E610000001000000050000000B46257502164740882EA86F99354A400B46257502164740299831056B3A4A40AF230ED9401C4740299831056B3A4A40AF230ED9401C4740882EA86F99354A400B46257502164740882EA86F99354A40
16363	Лесная Нееловка	7	73	793	46.395567999999997	46.415528999999999	52.322076000000003	52.306083000000001	0103000020E610000001000000050000000CACE3F8A1324740486E4DBA2D274A400CACE3F8A1324740CB694FC939294A4011C5E40D30354740CB694FC939294A4011C5E40D30354740486E4DBA2D274A400CACE3F8A1324740486E4DBA2D274A40
5664	Ключи	7	73	793	46.486593999999997	46.536656999999998	51.992505999999999	51.974007	0103000020E61000000100000005000000043752B6483E47409C89E942ACFC4940043752B6483E4740B98AC56F0AFF4940B115342DB1444740B98AC56F0AFF4940B115342DB14447409C89E942ACFC4940043752B6483E47409C89E942ACFC4940
16257	Казанла	7	73	793	46.623703999999996	46.665188000000001	52.296863999999999	52.266302000000003	0103000020E6100000010000000500000033315D88D54F4740016E162F16224A4033315D88D54F47400CAEB9A3FF254A4088D860E1245547400CAEB9A3FF254A4088D860E124554740016E162F16224A4033315D88D54F4740016E162F16224A40
15890	Ивановка	7	73	793	46.235577999999997	46.276173	52.157243999999999	52.142350999999998	0103000020E610000001000000050000001BD47E6B271E4740C5C6BC8E38124A401BD47E6B271E474001BF469220144A40E48409A35923474001BF469220144A40E48409A359234740C5C6BC8E38124A401BD47E6B271E4740C5C6BC8E38124A40
16062	Вязовка	7	73	793	46.690466999999998	46.753520000000002	52.178654000000002	52.149408999999999	0103000020E61000000100000005000000CEFBFF3861584740315D88D51F134A40CEFBFF386158474059A65F22DE164A40E370E6577360474059A65F22DE164A40E370E65773604740315D88D51F134A40CEFBFF3861584740315D88D51F134A40
17022	Большая Чечуйка	7	73	793	45.998800000000003	46.039870999999998	52.370885000000001	52.362681000000002	0103000020E61000000100000005000000569FABADD8FF4640B7F0BC546C2E4A40569FABADD8FF4640DAC9E028792F4A408787307E1A054740DAC9E028792F4A408787307E1A054740B7F0BC546C2E4A40569FABADD8FF4640B7F0BC546C2E4A40
16972	Большая Гусиха	7	73	793	46.282066	46.302079999999997	52.517662000000001	52.502918000000001	0103000020E6100000010000000500000022A81ABD1A244740ED48F59D5F404A4022A81ABD1A244740E43098BF42424A404963B48EAA264740E43098BF42424A404963B48EAA264740ED48F59D5F404A4022A81ABD1A244740ED48F59D5F404A40
5855	Березовка	7	73	793	46.280332000000001	46.316974000000002	52.396731000000003	52.375751000000001	0103000020E61000000100000005000000DA0242EBE12347403B38D89B18304A40DA0242EBE12347409A27D714C8324A4056D7A19A922847409A27D714C8324A4056D7A19A922847403B38D89B18304A40DA0242EBE12347403B38D89B18304A40
16728	Белая Гора	7	73	793	46.193742999999998	46.222983999999997	52.591498000000001	52.581632999999997	0103000020E610000001000000050000001A6A1492CC1847401EA33CF3724A4A401A6A1492CC18474020D3DA34B64B4A4000C45DBD8A1C474020D3DA34B64B4A4000C45DBD8A1C47401EA33CF3724A4A401A6A1492CC1847401EA33CF3724A4A40
5595	Базарный Карабулак	7	73	793	46.388911	46.442279999999997	52.300691999999998	52.250751999999999	0103000020E61000000100000005000000FF06EDD5C73147400BB43BA418204A40FF06EDD5C73147409C1551137D264A4062D68BA19C3847409C1551137D264A4062D68BA19C3847400BB43BA418204A40FF06EDD5C73147400BB43BA418204A40
15817	Алексеевка	7	73	793	46.304461000000003	46.375877000000003	52.243257999999997	52.212549000000003	0103000020E6100000010000000500000028F4FA93F826474015E63DCE341B4A4028F4FA93F8264740C43E0114231F4A40C828CFBC1C304740C43E0114231F4A40C828CFBC1C30474015E63DCE341B4A4028F4FA93F826474015E63DCE341B4A40
14394	Умет	7	73	819	44.879193999999998	44.904895000000003	52.181840999999999	52.167050000000003	0103000020E61000000100000005000000726BD26D89704640FE65F7E461154A40726BD26D897046403509DE9046174A402FA86F99D37346403509DE9046174A402FA86F99D3734640FE65F7E461154A40726BD26D89704640FE65F7E461154A40
14623	Тургенево	7	73	819	44.954265999999997	44.973866999999998	51.916137999999997	51.901947999999997	0103000020E61000000100000005000000A5D76663257A4640A758350873F34940A5D76663257A4640B94F8E0244F54940AAD381ACA77C4640B94F8E0244F54940AAD381ACA77C4640A758350873F34940A5D76663257A4640A758350873F34940
14970	Сазоново	7	73	819	45.083964999999999	45.099891999999997	51.990403999999998	51.982455999999999	0103000020E610000001000000050000001B81785DBF8A464026E1421EC1FD49401B81785DBF8A4640EEE9EA8EC5FE4940E690D442C98C4640EEE9EA8EC5FE4940E690D442C98C464026E1421EC1FD49401B81785DBF8A464026E1421EC1FD4940
14530	Прокудино	7	73	819	45.017687000000002	45.042524999999998	52.065055999999998	52.052508000000003	0103000020E610000001000000050000003D484F9143824640A2630795B8064A403D484F91438246404C3448C153084A4096218E75718546404C3448C153084A4096218E7571854640A2630795B8064A403D484F9143824640A2630795B8064A40
15301	Приречное	7	73	819	44.929777999999999	44.946010000000001	51.748894	51.738627000000001	0103000020E6100000010000000500000028452BF702774640A7785C548BDE494028452BF702774640D71533C2DBDF494030D80DDB16794640D71533C2DBDF494030D80DDB16794640A7785C548BDE494028452BF702774640A7785C548BDE4940
14928	Петрово	7	73	819	45.170482	45.194403999999999	51.998427999999997	51.982112000000001	0103000020E610000001000000050000004147AB5AD29546402C8194D8B5FD49404147AB5AD295464091B41B7DCCFF4940151BF33AE298464091B41B7DCCFF4940151BF33AE29846402C8194D8B5FD49404147AB5AD29546402C8194D8B5FD4940
14915	Песчанка	7	73	819	45.435673000000001	45.465183000000003	51.944504999999999	51.938220000000001	0103000020E6100000010000000500000007600322C4B74640003ACC9717F8494007600322C4B7464049F4328AE5F84940DDD3D51D8BBB464049F4328AE5F84940DDD3D51D8BBB4640003ACC9717F8494007600322C4B74640003ACC9717F84940
15398	Озерное	7	73	819	44.899262	44.949576999999998	51.680917000000001	51.653489	0103000020E610000001000000050000008D4468041B734640DBA50D87A5D349408D4468041B7346402D25CB4928D74940530438BD8B7946402D25CB4928D74940530438BD8B794640DBA50D87A5D349408D4468041B734640DBA50D87A5D34940
14825	Марфино	7	73	819	45.248491000000001	45.263843000000001	51.855696000000002	51.846978	0103000020E61000000100000005000000D82C978DCE9F46403B376DC669EC4940D82C978DCE9F4640B5A84F7287ED4940A723809BC5A14640B5A84F7287ED4940A723809BC5A146403B376DC669EC4940D82C978DCE9F46403B376DC669EC4940
14674	Малые Копены	7	73	819	44.749611999999999	44.798552000000001	51.960768000000002	51.93797	0103000020E6100000010000000500000036583849F35F46408750A5660FF8494036583849F35F46408C852172FAFA4940E413B2F3366646408C852172FAFA4940E413B2F3366646408750A5660FF8494036583849F35F46408750A5660FF84940
15397	Малая Осиновка	7	73	819	45.062199	45.091276999999998	51.764336	51.748085000000003	0103000020E61000000100000005000000056C0723F687464068D0D03FC1DF4940056C0723F6874640E69315C3D5E1494041F0F8F6AE8B4640E69315C3D5E1494041F0F8F6AE8B464068D0D03FC1DF4940056C0723F687464068D0D03FC1DF4940
14738	Лопуховка	7	73	819	44.689326000000001	44.866393000000002	52.000092000000002	51.669131999999998	0103000020E61000000100000005000000292499D53B584640815A0C1EA6D54940292499D53B584640E17EC00303004A40DE3D40F7E56E4640E17EC00303004A40DE3D40F7E56E4640815A0C1EA6D54940292499D53B584640815A0C1EA6D54940
15203	Кочетовка	7	73	819	44.685957000000002	44.727108999999999	51.745525999999998	51.728313999999997	0103000020E610000001000000050000002CBB6070CD574640069CA56439DD49402CBB6070CD574640AA285E656DDF49404AD05FE8115D4640AA285E656DDF49404AD05FE8115D4640069CA56439DD49402CBB6070CD574640069CA56439DD4940
15489	Иваново-Языковка	7	73	819	45.203628999999999	45.221846999999997	51.659796999999998	51.650114000000002	0103000020E6100000010000000500000033C2DB83109A4640FC5580EF36D3494033C2DB83109A4640DC7F643A74D449409CDB847B659C4640DC7F643A74D449409CDB847B659C4640FC5580EF36D3494033C2DB83109A4640FC5580EF36D34940
14632	Земляные Хутора	7	73	819	44.662483999999999	44.711128000000002	51.916893000000002	51.901263999999998	0103000020E61000000100000005000000C70F9546CC544640F487669E5CF34940C70F9546CC5446403677F4BF5CF549408CA2073E065B46403677F4BF5CF549408CA2073E065B4640F487669E5CF34940C70F9546CC544640F487669E5CF34940
14819	Ершовка	7	73	819	45.209449999999997	45.228306000000003	51.839616999999997	51.825425000000003	0103000020E61000000100000005000000D712F241CF9A46408126C286A7E94940D712F241CF9A46403315E29178EB494084BD8921399D46403315E29178EB494084BD8921399D46408126C286A7E94940D712F241CF9A46408126C286A7E94940
15095	Елизаветино	7	73	819	44.825060999999998	44.848875999999997	51.843750999999997	51.817881999999997	0103000020E610000001000000050000003F1A4E999B69464058FE7C5BB0E849403F1A4E999B694640D07B630800EC4940FD2D01F8A76C4640D07B630800EC4940FD2D01F8A76C464058FE7C5BB0E849403F1A4E999B69464058FE7C5BB0E84940
14526	Даниловка	7	73	819	44.881368000000002	44.899037999999997	51.988273999999997	51.955179000000001	0103000020E61000000100000005000000D7DEA7AAD0704640BA69334E43FA4940D7DEA7AAD070464059BE2EC37FFE49403DEE5BAD1373464059BE2EC37FFE49403DEE5BAD13734640BA69334E43FA4940D7DEA7AAD0704640BA69334E43FA4940
15192	Вяжля	7	73	819	44.491408999999997	44.572563000000002	51.786147999999997	51.769987999999998	0103000020E61000000100000005000000E3FA777DE63E4640FE277FF78EE24940E3FA777DE63E46406CE8667FA0E4494028F38FBE494946406CE8667FA0E4494028F38FBE49494640FE277FF78EE24940E3FA777DE63E4640FE277FF78EE24940
9537	Большая Осиновка	7	73	819	45.177354000000001	45.208714000000001	51.776786999999999	51.760663000000001	0103000020E610000001000000050000004BE82E89B39646407D23BA675DE149404BE82E89B39646409E7AA4C16DE34940D21BEE23B79A46409E7AA4C16DE34940D21BEE23B79A46407D23BA675DE149404BE82E89B39646407D23BA675DE14940
5862	Большая Екатериновка	7	73	819	44.834853000000003	44.860868000000004	52.136111	52.114519999999999	0103000020E61000000100000005000000D7FB8D76DC6A4640745E6397A80E4A40D7FB8D76DC6A46401CD0D2156C114A40231631EC306E46401CD0D2156C114A40231631EC306E4640745E6397A80E4A40D7FB8D76DC6A4640745E6397A80E4A40
15247	Белгаза	7	73	819	44.761766000000001	44.777710999999996	51.685913999999997	51.667026	0103000020E61000000100000005000000359A5C8C8161464075CAA31B61D54940359A5C8C816146402CEFAA07CCD74940A65EB7088C6346402CEFAA07CCD74940A65EB7088C63464075CAA31B61D54940359A5C8C8161464075CAA31B61D54940
15025	Барановка	7	73	819	45.049281000000001	45.070777	51.908465999999997	51.895479000000002	0103000020E6100000010000000500000037A8FDD64E8646409DA04D0E9FF2494037A8FDD64E86464093C3279D48F449408D2782380F89464093C3279D48F449408D2782380F8946409DA04D0E9FF2494037A8FDD64E8646409DA04D0E9FF24940
53151	Аткарск	7	73	819	44.490493000000001	45.539392999999997	52.233297999999998	51.564796999999999	0103000020E610000001000000050000005EF58079C83E464080F0A1444BC849405EF58079C83E4640711C78B5DC1D4A407D586FD40AC54640711C78B5DC1D4A407D586FD40AC5464080F0A1444BC849405EF58079C83E464080F0A1444BC84940
12978	Шебалов	7	73	568	43.753667999999998	43.773412999999998	51.768734000000002	51.749685999999997	0103000020E6100000010000000500000057056A3178E045407022FAB5F5DF494057056A3178E0454061A92EE065E249408FA67A32FFE2454061A92EE065E249408FA67A32FFE245407022FAB5F5DF494057056A3178E045407022FAB5F5DF4940
12733	Чиганак	7	73	568	43.29974	43.641800000000003	52.150016999999998	51.770600999999999	0103000020E61000000100000005000000CAA65CE15DA64540E8A1B60DA3E24940CAA65CE15DA64540096CCEC133134A4052499D8026D24540096CCEC133134A4052499D8026D24540E8A1B60DA3E24940CAA65CE15DA64540E8A1B60DA3E24940
13107	Софьино	7	73	568	43.893284000000001	43.912948	51.689287	51.670924999999997	0103000020E6100000010000000500000021054F2157F24540CE88D2DEE0D5494021054F2157F245406B47718E3AD849406C79E57ADBF445406B47718E3AD849406C79E57ADBF44540CE88D2DEE0D5494021054F2157F24540CE88D2DEE0D54940
12644	Семеновка	7	73	568	43.340757000000004	43.36891	51.893577999999998	51.870773999999997	0103000020E610000001000000050000000971E5EC9DAB4540821ABE8575EF49400971E5EC9DAB454069368FC360F249406C95607138AF454069368FC360F249406C95607138AF4540821ABE8575EF49400971E5EC9DAB4540821ABE8575EF4940
12933	Росташи	7	73	568	43.579358999999997	43.623016999999997	51.871402000000003	51.848570000000002	0103000020E6100000010000000500000056D28A6F28CA4540F12E17F19DEC494056D28A6F28CA4540A2D5C9198AEF49400FED6305BFCF4540A2D5C9198AEF49400FED6305BFCF4540F12E17F19DEC494056D28A6F28CA4540F12E17F19DEC4940
13601	Подгорное	7	73	568	43.490605000000002	43.510106999999998	51.991878999999997	51.969906999999999	0103000020E6100000010000000500000086200725CCBE4540AB949EE925FC494086200725CCBE45406A4B1DE4F5FE4940F73AA92F4BC145406A4B1DE4F5FE4940F73AA92F4BC14540AB949EE925FC494086200725CCBE4540AB949EE925FC4940
12728	Памятка	7	73	568	43.237054999999998	43.277596000000003	51.849392999999999	51.819591000000003	0103000020E61000000100000005000000382D78D1579E4540488C9E5BE8E84940382D78D1579E4540C539EAE8B8EC49400EC0064488A34540C539EAE8B8EC49400EC0064488A34540488C9E5BE8E84940382D78D1579E4540488C9E5BE8E84940
12857	Ольшанка	7	73	568	43.460754000000001	43.505715000000002	51.874648999999998	51.845726999999997	0103000020E6100000010000000500000027C0B0FCF9BA45400E2C47C840EC494027C0B0FCF9BA4540533D997FF4EF49405F0CE544BBC04540533D997FF4EF49405F0CE544BBC045400E2C47C840EC494027C0B0FCF9BA45400E2C47C840EC4940
13674	Октябрьский	7	73	568	43.542977	43.563924999999998	51.973680000000002	51.958764000000002	0103000020E6100000010000000500000077BD344580C54540844A5CC7B8FA494077BD344580C545407862D68BA1FC4940CA32C4B12EC845407862D68BA1FC4940CA32C4B12EC84540844A5CC7B8FA494077BD344580C54540844A5CC7B8FA4940
13034	Новосельское	7	73	568	43.690722999999998	43.723959999999998	51.735576000000002	51.719293	0103000020E6100000010000000500000029CC7B9C69D84540F19E03CB11DC494029CC7B9C69D845407BDCB75A27DE49405BCEA5B8AADC45407BDCB75A27DE49405BCEA5B8AADC4540F19E03CB11DC494029CC7B9C69D84540F19E03CB11DC4940
13483	Мещеряковка	7	73	568	43.715040000000002	43.763064	51.989494000000001	51.980276000000003	0103000020E610000001000000050000007AAA436E86DB4540E08618AF79FD49407AAA436E86DB45404BCB48BDA7FE4940A260C614ACE145404BCB48BDA7FE4940A260C614ACE14540E08618AF79FD49407AAA436E86DB4540E08618AF79FD4940
12853	Малиновка	7	73	568	43.385269000000001	43.442346999999998	51.792304000000001	51.760289	0103000020E61000000100000005000000D1949D7E50B145401841632651E14940D1949D7E50B14540B83EAC376AE54940EA3D95D39EB84540B83EAC376AE54940EA3D95D39EB845401841632651E14940D1949D7E50B145401841632651E14940
13211	Львовка	7	73	568	43.695824999999999	43.726080000000003	51.921393000000002	51.902931000000002	0103000020E610000001000000050000009E5E29CB10D94540B5C5353E93F349409E5E29CB10D94540B5E1B034F0F54940CD237F30F0DC4540B5E1B034F0F54940CD237F30F0DC4540B5C5353E93F349409E5E29CB10D94540B5C5353E93F34940
3650	Летяжевский	7	73	568	43.367607999999997	43.391359000000001	51.878886000000001	51.867170000000002	0103000020E61000000100000005000000BDDF68C70DAF45404209336DFFEE4940BDDF68C70DAF4540C57421567FF0494065FF3C0D18B24540C57421567FF0494065FF3C0D18B245404209336DFFEE4940BDDF68C70DAF45404209336DFFEE4940
13263	Крутец	7	73	568	43.622872999999998	43.651933	51.916831999999999	51.905115000000002	0103000020E61000000100000005000000DC476E4DBACF45403D0FEECEDAF34940DC476E4DBACF454090F63FC05AF549407217618A72D3454090F63FC05AF549407217618A72D345403D0FEECEDAF34940DC476E4DBACF45403D0FEECEDAF34940
53161	Красный Полуостров	7	73	568	43.392418999999997	43.437443000000002	51.922431000000003	51.901614000000002	0103000020E610000001000000050000001DAA29C93AB24540D1CE691668F349401DAA29C93AB2454086E8103812F649409C6ED921FEB7454086E8103812F649409C6ED921FEB74540D1CE691668F349401DAA29C93AB24540D1CE691668F34940
13319	Красное Знамя	7	73	568	43.517339	43.564276	52.063167999999997	52.046199999999999	0103000020E6100000010000000500000001F9122A38C24540A089B0E1E9054A4001F9122A38C24540AD1397E315084A4077F52A323AC84540AD1397E315084A4077F52A323AC84540A089B0E1E9054A4001F9122A38C24540A089B0E1E9054A40
13397	Кистендей	7	73	568	43.649849000000003	43.704467000000001	52.113607000000002	52.091921999999997	0103000020E610000001000000050000004E2B85402ED3454036E49F19C40B4A404E2B85402ED3454060CC96AC8A0E4A403D0E83F92BDA454060CC96AC8A0E4A403D0E83F92BDA454036E49F19C40B4A404E2B85402ED3454036E49F19C40B4A40
13205	Ивановка	7	73	568	43.777023999999997	43.816217000000002	51.893738999999997	51.874538000000001	0103000020E61000000100000005000000821ABE8575E34540FC8D76DCF0EF4940821ABE8575E345407214200A66F2494039B874CC79E845407214200A66F2494039B874CC79E84540FC8D76DCF0EF4940821ABE8575E34540FC8D76DCF0EF4940
12936	Грачевка	7	73	568	43.623097000000001	43.659219	51.833067	51.814920000000001	0103000020E610000001000000050000002C9E7AA4C1CF45409C6D6E4C4FE849402C9E7AA4C1CF45403C3080F0A1EA49406FF3C64961D445403C3080F0A1EA49406FF3C64961D445409C6D6E4C4FE849402C9E7AA4C1CF45409C6D6E4C4FE84940
13539	Большая Журавка	7	73	568	43.312657999999999	43.358246999999999	52.071787999999998	52.051682999999997	0103000020E61000000100000005000000986A662D05A845402C616D8C9D064A40986A662D05A84540641F645930094A40EF71A609DBAD4540641F645930094A40EF71A609DBAD45402C616D8C9D064A40986A662D05A845402C616D8C9D064A40
13396	Беловка	7	73	568	43.606873999999998	43.641880999999998	52.070397999999997	52.060349000000002	0103000020E610000001000000050000007765170CAECD454054AC1A84B9074A407765170CAECD454016DA39CD02094A403E76172829D2454016DA39CD02094A403E76172829D2454054AC1A84B9074A407765170CAECD454054AC1A84B9074A40
13500	Баклуши	7	73	568	43.346946000000003	43.387172999999997	52.124833000000002	52.094811	0103000020E6100000010000000500000030BDFDB968AC4540892650C4220C4A4030BDFDB968AC4540153B1A87FA0F4A40757286E28EB14540153B1A87FA0F4A40757286E28EB14540892650C4220C4A4030BDFDB968AC4540892650C4220C4A40
3529	Аркадак	7	73	568	43.463304999999998	43.553711999999997	51.951937999999998	51.907364999999999	0103000020E61000000100000005000000618907944DBB45407C444C8924F44940618907944DBB4540EAE8B81AD9F949408DB3E908E0C64540EAE8B81AD9F949408DB3E908E0C645407C444C8924F44940618907944DBB45407C444C8924F44940
13115	Алексеевка	7	73	568	43.899895000000001	43.964781000000002	51.849398999999998	51.829031999999998	0103000020E61000000100000005000000BE6A65C22FF3454032AB77B81DEA4940BE6A65C22FF34540A7203F1BB9EC4940AE669DF17DFB4540A7203F1BB9EC4940AE669DF17DFB454032AB77B81DEA4940BE6A65C22FF3454032AB77B81DEA4940
12115	Сысоев	7	73	556	48.344040999999997	48.363894000000002	50.09487	50.085166000000001	0103000020E61000000100000005000000D7BD1589092C4840965D30B8E60A4940D7BD1589092C48408EAF3DB3240C4940F69A1E14942E48408EAF3DB3240C4940F69A1E14942E4840965D30B8E60A4940D7BD1589092C4840965D30B8E60A4940
11776	Приузенский	7	73	556	48.729363999999997	48.747546	50.099936999999997	50.090026999999999	0103000020E610000001000000050000009B70AFCC5B5D4840E5603601860B49409B70AFCC5B5D4840865451BCCA0C4940B8205B96AF5F4840865451BCCA0C4940B8205B96AF5F4840E5603601860B49409B70AFCC5B5D4840E5603601860B4940
53240	Новостепной	7	73	556	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
3437	Новоалександровка	7	73	556	48.567909999999998	48.593071999999999	50.137706000000001	50.121172999999999	0103000020E6100000010000000500000022895E46B14848404014CC98820F494022895E46B1484840433BA759A01149402F1686C8E94B4840433BA759A01149402F1686C8E94B48404014CC98820F494022895E46B14848404014CC98820F4940
11727	Монахов	7	73	556	48.530199000000003	48.551515999999999	50.280079000000001	50.271265	0103000020E610000001000000050000009BAF928FDD43484054C6BFCFB82249409BAF928FDD434840F0A5F0A0D9234940419C871398464840F0A5F0A0D9234940419C87139846484054C6BFCFB82249409BAF928FDD43484054C6BFCFB8224940
11478	Луков Кордон	7	73	556	48.340268000000002	48.364027999999998	50.369494000000003	50.354725999999999	0103000020E610000001000000050000000BF0DDE68D2B48403C855CA9672D49400BF0DDE68D2B4840BC0853944B2F4940056A3178982E4840BC0853944B2F4940056A3178982E48403C855CA9672D49400BF0DDE68D2B48403C855CA9672D4940
11664	Канавка	7	73	556	48.540340999999998	48.563687999999999	50.396707999999997	50.379455	0103000020E610000001000000050000000ED8D5E429454840DFA63FFB913049400ED8D5E429454840E107E753C7324940E692AAED26484840E107E753C7324940E692AAED26484840DFA63FFB913049400ED8D5E429454840DFA63FFB91304940
11474	Камышки	7	73	556	48.349583000000003	48.387771000000001	50.277287000000001	50.250349	0103000020E61000000100000005000000691EC022BF2C48400CCB9F6F0B204940691EC022BF2C4840904DF2237E2349402AABE97AA2314840904DF2237E2349402AABE97AA23148400CCB9F6F0B204940691EC022BF2C48400CCB9F6F0B204940
3498	Ветелки	7	73	556	48.274214999999998	48.293007000000003	49.945073000000001	49.936295000000001	0103000020E610000001000000050000004C89247A192348404434BA83D8F748404C89247A1923484093AAED26F8F84840E23FDD408125484093AAED26F8F84840E23FDD40812548404434BA83D8F748404C89247A192348404434BA83D8F74840
53227	Васильки	7	73	556	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
12006	Варфоломеевка	7	73	556	48.176406	48.201002000000003	50.021422000000001	50.000540999999998	0103000020E61000000100000005000000BA68C8789416484050A73CBA11004940BA68C878941648401CB5C2F4BD0249401E37FC6EBA1948401CB5C2F4BD0249401E37FC6EBA19484050A73CBA11004940BA68C8789416484050A73CBA11004940
12000	Байгужа	7	73	556	48.440492999999996	48.461405999999997	49.993366000000002	49.986908999999997	0103000020E61000000100000005000000F78E1A13623848406490BB0853FE4840F78E1A1362384840AB7AF99D26FF4840CE16105A0F3B4840AB7AF99D26FF4840CE16105A0F3B48406490BB0853FE4840F78E1A13623848406490BB0853FE4840
11185	Бабошкин	7	73	556	48.653421000000002	48.668036000000001	50.405785000000002	50.400216	0103000020E6100000010000000500000083C2A04CA353484000AB23473A33494083C2A04CA35348408B1A4CC3F03349407C462234825548408B1A4CC3F03349407C4622348255484000AB23473A33494083C2A04CA353484000AB23473A334940
11859	Ахматов	7	73	556	48.690475999999997	48.705064999999998	50.185015	50.175404999999998	0103000020E6100000010000000500000021567F84615848400647C9AB7316494021567F84615848407D224F92AE174940F146E6913F5A48407D224F92AE174940F146E6913F5A48400647C9AB7316494021567F84615848400647C9AB73164940
10970	Александров Гай	7	73	556	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
53141	Передовой	7	73	7258	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
53216	Соколовый	7	73	7275	45.818832	45.851979	51.57835	51.559919999999998	0103000020E610000001000000050000008A75AA7CCFE846402B306475ABC749408A75AA7CCFE8464020D26F5F07CA49407CF0DAA50DED464020D26F5F07CA49407CF0DAA50DED46402B306475ABC749408A75AA7CCFE846402B306475ABC74940
53173	Пугачев	7	73	7268	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
50003	Ширяево	7	72	\N	50.012248	50.027079000000001	53.420709000000002	53.404150999999999	0103000020E6100000010000000500000080B8AB5791014940A6D24F38BBB34A4080B8AB57910149400211E2CAD9B54A4046B41D53770349400211E2CAD9B54A4046B41D5377034940A6D24F38BBB34A4080B8AB5791014940A6D24F38BBB34A40
4596	Чапаевск	7	72	\N	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
463	Тольятти	7	72	\N	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
55877	Тимофеевка	7	72	\N	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
5112	Сызрань	7	72	\N	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
55917	Студеный овраг	7	72	\N	50.196475	50.201613000000002	53.304076000000002	53.303522000000001	0103000020E61000000100000005000000A5BDC11726194940EACE13CFD9A64A40A5BDC11726194940CFBF5DF6EBA64A4067B96C74CE194940CFBF5DF6EBA64A4067B96C74CE194940EACE13CFD9A64A40A5BDC11726194940EACE13CFD9A64A40
32	Самара	7	72	\N	50.007325000000002	50.390833999999998	53.396335000000001	53.091963999999997	0103000020E61000000100000005000000BBB88D06F00049406534F279C58B4A40BBB88D06F00049404DA1F31ABBB24A401A1538D9063249404DA1F31ABBB24A401A1538D9063249406534F279C58B4A40BBB88D06F00049406534F279C58B4A40
55868	Рощинский	7	72	\N	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
62070	Рождествено	7	72	\N	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
55926	Рождествено	7	72	\N	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
55921	Привольный	7	72	\N	50.542299	50.556708	54.213197999999998	54.207990000000002	0103000020E61000000100000005000000A6D3BA0D6A45494091F2936A9F1A4B40A6D3BA0D6A4549404BC972124A1B4B40F6B52E35424749404BC972124A1B4B40F6B52E354247494091F2936A9F1A4B40A6D3BA0D6A45494091F2936A9F1A4B40
55920	Преображенка	7	72	\N	49.441763999999999	49.469620999999997	52.800733000000001	52.783911000000003	0103000020E610000001000000050000006B4606B98BB84840C2FC153257644A406B4606B98BB84840FBE93F6B7E664A40E5417A8A1CBC4840FBE93F6B7E664A40E5417A8A1CBC4840C2FC153257644A406B4606B98BB84840C2FC153257644A40
2221	Похвистнево	7	72	\N	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
55924	Переволоки	7	72	\N	49.302705000000003	49.326861000000001	52.895688999999997	52.881692999999999	0103000020E61000000100000005000000F8AA9509BFA648405A0EF450DB704A40F8AA9509BFA648408731E9EFA5724A403FABCC94D6A948408731E9EFA5724A403FABCC94D6A948405A0EF450DB704A40F8AA9509BFA648405A0EF450DB704A40
55940	Первомайский	7	72	\N	51.359110000000001	51.370680999999998	53.898696999999999	53.892766000000002	0103000020E6100000010000000500000052D50451F7AD4940897D022846F24A4052D50451F7AD4940B401D88008F34A40D11F9A7972AF4940B401D88008F34A40D11F9A7972AF4940897D022846F24A4052D50451F7AD4940897D022846F24A40
2111	Отрадный	7	72	\N	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
55898	Октябрьский	7	72	\N	52.029442000000003	52.069479999999999	53.428452	53.411366000000001	0103000020E610000001000000050000007E9065C1C4034A40DA571EA4A7B44A407E9065C1C4034A40F1F3DF83D7B64A40F0DC7BB8E4084A40F1F3DF83D7B64A40F0DC7BB8E4084A40DA571EA4A7B44A407E9065C1C4034A40DA571EA4A7B44A40
4034	Октябрьск	7	72	\N	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
55034	Новокуйбышевск	7	72	\N	49.747847	49.985289999999999	53.115876	52.991498999999997	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
55859	Нефтегорск	7	72	\N	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
55872	Мехзавод	7	72	\N	50.298937000000002	50.300769000000003	53.312227	53.310161000000001	0103000020E610000001000000050000003D484F914326494051BF0B5BB3A74A403D484F9143264940CFF6E80DF7A74A4048533D997F264940CFF6E80DF7A74A4048533D997F26494051BF0B5BB3A74A403D484F914326494051BF0B5BB3A74A40
7140	Кинель	7	72	\N	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
61156	Жигулёвск	7	72	\N	49.015531000000003	50.070189999999997	53.749178000000001	53.119382999999999	0103000020E610000001000000050000007F8978EBFC814840645930F1478F4A407F8978EBFC814840FC709010E5DF4A40CC4065FCFB084940FC709010E5DF4A40CC4065FCFB084940645930F1478F4A407F8978EBFC814840645930F1478F4A40
55973	Жигулевск	7	72	\N	49.015531000000003	50.070189999999997	53.749178000000001	53.119382999999999	0103000020E610000001000000050000007F8978EBFC814840645930F1478F4A407F8978EBFC814840FC709010E5DF4A40CC4065FCFB084940FC709010E5DF4A40CC4065FCFB084940645930F1478F4A407F8978EBFC814840645930F1478F4A40
55874	Волжский Утес	7	72	\N	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
50002	Богатырь	7	72	\N	49.917206	49.990355999999998	53.437626000000002	53.424588999999997	0103000020E61000000100000005000000F5D8960167F54840E49EAEEE58B64A40F5D8960167F548408DF0F62004B84A40DDB243FCC3FE48408DF0F62004B84A40DDB243FCC3FE4840E49EAEEE58B64A40F5D8960167F54840E49EAEEE58B64A40
49999	Бахилова Поляна	7	72	\N	49.653891999999999	49.682485999999997	53.440404000000001	53.431977000000003	0103000020E61000000100000005000000DA8EA9BBB2D34840E6CFB7054BB74A40DA8EA9BBB2D34840888384285FB84A402AFD84B35BD74840888384285FB84A402AFD84B35BD74840E6CFB7054BB74A40DA8EA9BBB2D34840E6CFB7054BB74A40
4584	Шигоны	7	72	671	48.642245000000003	48.646979999999999	53.336210000000001	53.333516000000003	0103000020E6100000010000000500000080828B1535524840AC58FCA6B0AA4A4080828B1535524840494BE5ED08AB4A4042959A3DD0524840494BE5ED08AB4A4042959A3DD0524840AC58FCA6B0AA4A4080828B1535524840AC58FCA6B0AA4A40
25927	Шигоны	7	72	671	48.643619999999999	48.710050000000003	53.402814999999997	53.377124000000002	0103000020E610000001000000050000009886E12362524840B344679945B04A409886E123625248404BAB21718FB34A402D431CEBE25A48404BAB21718FB34A402D431CEBE25A4840B344679945B04A409886E12362524840B344679945B04A40
46516	Усолье	7	72	671	49.043253	49.080812000000002	53.403067	53.382243000000003	0103000020E61000000100000005000000193A765089854840FE0FB056EDB04A40193A765089854840658C0FB397B34A40EB8F300C588A4840658C0FB397B34A40EB8F300C588A4840FE0FB056EDB04A40193A765089854840FE0FB056EDB04A40
48747	Тайдаково	7	72	671	48.886730999999997	48.921639999999996	53.426698000000002	53.413502000000001	0103000020E61000000100000005000000B8ACC26680714840516A2FA2EDB44A40B8ACC2668071484062A2410A9EB64A40BC57AD4CF875484062A2410A9EB64A40BC57AD4CF8754840516A2FA2EDB44A40B8ACC26680714840516A2FA2EDB44A40
25656	Суринск	7	72	671	48.454830000000001	48.497554000000001	53.534978000000002	53.513956999999998	0103000020E61000000100000005000000AE9E93DE373A48406F46CD57C9C14A40AE9E93DE373A48402D0ABB287AC44A403BFF76D9AF3F48402D0ABB287AC44A403BFF76D9AF3F48406F46CD57C9C14A40AE9E93DE373A48406F46CD57C9C14A40
4698	Старый Тукшум	7	72	671	48.537322000000003	48.558360999999998	53.714022	53.695211999999998	0103000020E61000000100000005000000EEB5A0F7C6444840B4E4F1B4FCD84A40EEB5A0F7C6444840F04FA91265DB4A40512E8D5F78474840F04FA91265DB4A40512E8D5F78474840B4E4F1B4FCD84A40EEB5A0F7C6444840B4E4F1B4FCD84A40
55913	Сенькино	7	72	671	48.781762999999998	48.795157000000003	53.717714999999998	53.707647999999999	0103000020E61000000100000005000000861C5BCF10644840378AAC3594DA4A40861C5BCF10644840A06CCA15DEDB4A40BE175FB4C7654840A06CCA15DEDB4A40BE175FB4C7654840378AAC3594DA4A40861C5BCF10644840378AAC3594DA4A40
49009	Подвалье	7	72	671	48.813806	48.849110000000003	53.693857999999999	53.675887000000003	0103000020E61000000100000005000000F0A485CB2A6848405265187783D64A40F0A485CB2A684840B308C556D0D84A40715AF0A2AF6C4840B308C556D0D84A40715AF0A2AF6C48405265187783D64A40F0A485CB2A6848405265187783D64A40
48909	Пионерский	7	72	671	48.636882999999997	48.662906999999997	53.350574000000002	53.337128999999997	0103000020E610000001000000050000006E30D461855148403FC4060B27AB4A406E30D46185514840F969DC9BDFAC4A400DA5F622DA544840F969DC9BDFAC4A400DA5F622DA5448403FC4060B27AB4A406E30D461855148403FC4060B27AB4A40
48537	Новодевичье	7	72	671	48.817399000000002	48.862763999999999	53.620716000000002	53.595616999999997	0103000020E610000001000000050000003D64CA87A068484087F8872D3DCC4A403D64CA87A06848404E0D349F73CF4A404415FE0C6F6E48404E0D349F73CF4A404415FE0C6F6E484087F8872D3DCC4A403D64CA87A068484087F8872D3DCC4A40
55937	Новая Жизнь	7	72	671	48.490789999999997	48.493619000000002	53.652822999999998	53.651761	0103000020E61000000100000005000000179AEB34D23E484075E789E76CD34A40179AEB34D23E4840CE893DB48FD34A4095D74AE82E3F4840CE893DB48FD34A4095D74AE82E3F484075E789E76CD34A40179AEB34D23E484075E789E76CD34A40
26025	Муранка	7	72	671	48.788159	48.818728999999998	53.342205	53.323067000000002	0103000020E610000001000000050000002786E464E26448405BB56B425AA94A402786E464E26448408BC3995FCDAB4A40B5A4A31CCC6848408BC3995FCDAB4A40B5A4A31CCC6848405BB56B425AA94A402786E464E26448405BB56B425AA94A40
25753	Малячкино	7	72	671	48.571539000000001	48.617452	53.413336000000001	53.379182	0103000020E61000000100000005000000BCB1A03028494840AE9D280989B04A40BCB1A030284948403621AD31E8B44A40C66CC9AA084F48403621AD31E8B44A40C66CC9AA084F4840AE9D280989B04A40BCB1A03028494840AE9D280989B04A40
46159	Маза	7	72	671	48.844169000000001	48.876094999999999	53.523266999999997	53.504247999999997	0103000020E6100000010000000500000005A6D3BA0D6C48406589CE328BC04A4005A6D3BA0D6C4840BB09BE69FAC24A40359886E123704840BB09BE69FAC24A40359886E1237048406589CE328BC04A4005A6D3BA0D6C48406589CE328BC04A40
26031	Львовка	7	72	671	48.950789999999998	48.975107000000001	53.353901	53.347273999999999	0103000020E6100000010000000500000092AE997CB37948402460747973AC4A4092AE997CB3794840C782C2A04CAD4A40E38C614ED07C4840C782C2A04CAD4A40E38C614ED07C48402460747973AC4A4092AE997CB37948402460747973AC4A40
49031	Луговской	7	72	671	48.733379999999997	48.764848000000001	53.658670999999998	53.643317000000003	0103000020E610000001000000050000002EC55565DF5D4840FDFA213658D24A402EC55565DF5D48406CE9D1544FD44A409C340D8AE66148406CE9D1544FD44A409C340D8AE6614840FDFA213658D24A402EC55565DF5D4840FDFA213658D24A40
48926	Кяхта	7	72	671	48.736389000000003	48.762611	53.490369000000001	53.469883000000003	0103000020E610000001000000050000002C11A8FE415E484023F94A2025BC4A402C11A8FE415E484072FC5069C4BE4A40F148BC3C9D61484072FC5069C4BE4A40F148BC3C9D61484023F94A2025BC4A402C11A8FE415E484023F94A2025BC4A40
26272	Кузькино	7	72	671	48.700707999999999	48.725825	53.540216999999998	53.523480999999997	0103000020E61000000100000005000000D505BCCCB0594840E789E76C01C34A40D505BCCCB059484022DFA5D425C54A4042CF66D5E75C484022DFA5D425C54A4042CF66D5E75C4840E789E76C01C34A40D505BCCCB0594840E789E76C01C34A40
49067	Комаровка	7	72	671	49.126285000000003	49.147368	53.316510000000001	53.296838000000001	0103000020E61000000100000005000000D97C5C1B2A904840E31A9FC9FEA54A40D97C5C1B2A904840B16D516683A84A400C3D62F4DC924840B16D516683A84A400C3D62F4DC924840E31A9FC9FEA54A40D97C5C1B2A904840E31A9FC9FEA54A40
49557	Климовка	7	72	671	49.000467	49.027174000000002	53.495919000000001	53.482258000000002	0103000020E6100000010000000500000016DD7A4D0F804840001E51A1BABD4A4016DD7A4D0F804840863B17467ABF4A4098A608707A834840863B17467ABF4A4098A608707A834840001E51A1BABD4A4016DD7A4D0F804840001E51A1BABD4A40
26264	Бичевная	7	72	671	48.548775999999997	48.568961000000002	53.509635000000003	53.493112000000004	0103000020E61000000100000005000000336ABE4A3E464840F1A1444B1EBF4A40336ABE4A3E464840D0F23CB83BC14A4088D9CBB6D3484840D0F23CB83BC14A4088D9CBB6D3484840F1A1444B1EBF4A40336ABE4A3E464840F1A1444B1EBF4A40
48833	Береговой	7	72	671	48.480629999999998	48.505189999999999	53.594344999999997	53.578454000000001	0103000020E61000000100000005000000FDBCA948853D4840C51EDAC70ACA4A40FDBCA948853D484043C5387F13CC4A401422E010AA40484043C5387F13CC4A401422E010AA404840C51EDAC70ACA4A40FDBCA948853D4840C51EDAC70ACA4A40
48875	Байдеряково	7	72	671	48.533082	48.557138999999999	53.468147000000002	53.438929000000002	0103000020E610000001000000050000000B0BEE073C4448400C2252D32EB84A400B0BEE073C4448403A5CAB3DECBB4A40BF29AC54504748403A5CAB3DECBB4A40BF29AC54504748400C2252D32EB84A400B0BEE073C4448400C2252D32EB84A40
55899	станция Шентала	7	72	1591	51.466279	51.467806000000003	54.436689999999999	54.435957000000002	0103000020E61000000100000005000000E2E7BF07AFBB49402CBB6070CD374B40E2E7BF07AFBB4940C03E3A75E5374B40B16F2711E1BB4940C03E3A75E5374B40B16F2711E1BB49402CBB6070CD374B40E2E7BF07AFBB49402CBB6070CD374B40
55847	Шентала	7	72	1591	51.443579	51.499679	54.444822000000002	54.406557999999997	0103000020E61000000100000005000000A0185932C7B84940ADF6B0170A344B40A0185932C7B849404A4563EDEF384B40BEBF417BF5BF49404A4563EDEF384B40BEBF417BF5BF4940ADF6B0170A344B40A0185932C7B84940ADF6B0170A344B40
20437	Четырла	7	72	1591	51.697263	51.727581000000001	54.519202	54.500028999999998	0103000020E61000000100000005000000FDDAFAE93FD949409A0645F300404B40FDDAFAE93FD9494047020D3675424B407218CC5F21DD494047020D3675424B407218CC5F21DD49409A0645F300404B40FDDAFAE93FD949409A0645F300404B40
20359	Туарма	7	72	1591	51.552509000000001	51.592052000000002	54.535901000000003	54.523147999999999	0103000020E6100000010000000500000072DF6A9DB8C64940E17B7F83F6424B4072DF6A9DB8C6494065726A6798444B4005C4245CC8CB494065726A6798444B4005C4245CC8CB4940E17B7F83F6424B4072DF6A9DB8C64940E17B7F83F6424B40
55948	Толчеречье	7	72	1591	51.531469999999999	51.550612999999998	54.496384999999997	54.488121999999997	0103000020E610000001000000050000000E677E3507C44940A33A1DC87A3E4B400E677E3507C44940CB9C2E8B893F4B4050E09D7C7AC64940CB9C2E8B893F4B4050E09D7C7AC64940A33A1DC87A3E4B400E677E3507C44940A33A1DC87A3E4B40
19934	Тимяшево	7	72	1591	51.439087000000001	51.464751999999997	54.576698999999998	54.545256000000002	0103000020E61000000100000005000000A48CB80034B8494051F9D7F2CA454B40A48CB80034B849406551D845D1494B40136058FE7CBB49406551D845D1494B40136058FE7CBB494051F9D7F2CA454B40A48CB80034B8494051F9D7F2CA454B40
19621	Татарское Абдикеево	7	72	1591	51.743175999999998	51.770313999999999	54.401375000000002	54.383651999999998	0103000020E610000001000000050000000796236420DF4940C2853C821B314B400796236420DF49404C37894160334B4052D32EA699E249404C37894160334B4052D32EA699E24940C2853C821B314B400796236420DF4940C2853C821B314B40
47051	Старое Суркино	7	72	1591	51.622855999999999	51.641010999999999	54.308193000000003	54.296340999999998	0103000020E61000000100000005000000060FD3BEB9CF494062BB7B80EE254B40060FD3BEB9CF494096ED43DE72274B4029B000A60CD2494096ED43DE72274B4029B000A60CD2494062BB7B80EE254B40060FD3BEB9CF494062BB7B80EE254B40
19926	Старое Афонькино	7	72	1591	51.583230999999998	51.611977000000003	54.602721000000003	54.579537999999999	0103000020E61000000100000005000000B6813B50A7CA494006651A4D2E4A4B40B6813B50A7CA494064CE33F6254D4B40BD73284355CE494064CE33F6254D4B40BD73284355CE494006651A4D2E4A4B40B6813B50A7CA494006651A4D2E4A4B40
19991	Старая Шентала	7	72	1591	51.472890999999997	51.510153000000003	54.408712000000001	54.383741000000001	0103000020E610000001000000050000004FC939B187BC49403291D26C1E314B404FC939B187BC4940CBBDC0AC50344B40687A89B14CC14940CBBDC0AC50344B40687A89B14CC149403291D26C1E314B404FC939B187BC49403291D26C1E314B40
20538	Семеново-Шарла	7	72	1591	51.825811999999999	51.840437000000001	54.532929000000003	54.518642999999997	0103000020E610000001000000050000007A522635B4E9494050A6D1E462424B407A522635B4E94940850B790437444B4097AC8A7093EB4940850B790437444B4097AC8A7093EB494050A6D1E462424B407A522635B4E9494050A6D1E462424B40
19826	Салейкино	7	72	1591	51.513306	51.532808000000003	54.615689000000003	54.592153000000003	0103000020E61000000100000005000000986BD102B4C14940399D64ABCB4B4B40986BD102B4C14940E4C0ABE5CE4E4B400A86730D33C44940E4C0ABE5CE4E4B400A86730D33C44940399D64ABCB4B4B40986BD102B4C14940399D64ABCB4B4B40
47152	Романовка	7	72	1591	51.350315999999999	51.383347000000001	54.493628999999999	54.477111999999998	0103000020E61000000100000005000000FDA19927D7AC4940BB438A01123D4B40FDA19927D7AC4940B8AD2D3C2F3F4B408602B68311B14940B8AD2D3C2F3F4B408602B68311B14940BB438A01123D4B40FDA19927D7AC4940BB438A01123D4B40
19820	Новый Кувак	7	72	1591	51.864718000000003	51.888595000000002	54.468479000000002	54.447209000000001	0103000020E610000001000000050000009B215514AFEE49400ABDFE243E394B409B215514AFEE494070EEAF1EF73B4B40CF31207BBDF1494070EEAF1EF73B4B40CF31207BBDF149400ABDFE243E394B409B215514AFEE49400ABDFE243E394B40
20162	Крепость Кондурча	7	72	1591	51.307977999999999	51.336212000000003	54.307746999999999	54.296115	0103000020E6100000010000000500000099F1B6D26BA74940726DA818E7254B4099F1B6D26BA749409738F24064274B40EA42ACFE08AB49409738F24064274B40EA42ACFE08AB4940726DA818E7254B4099F1B6D26BA74940726DA818E7254B40
45541	Красный Яр	7	72	1591	51.740858000000003	51.756678000000001	54.543882000000004	54.535316000000002	0103000020E61000000100000005000000707D586FD4DE49404583143C85444B40707D586FD4DE49400971E5EC9D454B4025CD1FD3DAE049400971E5EC9D454B4025CD1FD3DAE049404583143C85444B40707D586FD4DE49404583143C85444B40
19360	Костюнькино	7	72	1591	51.322046	51.352184000000001	54.424759999999999	54.417226999999997	0103000020E6100000010000000500000060E7A6CD38A949400C01C0B167354B4060E7A6CD38A94940115322895E364B405516855D14AD4940115322895E364B405516855D14AD49400C01C0B167354B4060E7A6CD38A949400C01C0B167354B40
19678	Карабикулово	7	72	1591	51.764367	51.783428999999998	54.431379999999997	54.419694	0103000020E61000000100000005000000219221C7D6E14940E9297288B8354B40219221C7D6E149400113B87537374B4076DEC66647E449400113B87537374B4076DEC66647E44940E9297288B8354B40219221C7D6E14940E9297288B8354B40
19538	Денискино	7	72	1591	51.600684999999999	51.637956000000003	54.495057000000003	54.391939999999998	0103000020E610000001000000050000005019FF3EE3CC494043FF04172B324B405019FF3EE3CC4940F4531C075E3F4B40BC24CE8AA8D14940F4531C075E3F4B40BC24CE8AA8D1494043FF04172B324B405019FF3EE3CC494043FF04172B324B40
49223	Вязовка	7	72	1591	51.651511999999997	51.663207999999997	54.336024999999999	54.320388999999999	0103000020E61000000100000005000000CC79C6BE64D34940C37FBA8102294B40CC79C6BE64D34940B7D100DE022B4B400839EFFFE3D44940B7D100DE022B4B400839EFFFE3D44940C37FBA8102294B40CC79C6BE64D34940C37FBA8102294B40
20171	Баландаево	7	72	1591	51.562668000000002	51.594154000000003	54.512324	54.499245000000002	0103000020E61000000100000005000000BC40498105C8494084D89942E73F4B40BC40498105C849405B7A34D593414B40D064FF3C0DCC49405B7A34D593414B40D064FF3C0DCC494084D89942E73F4B40BC40498105C8494084D89942E73F4B40
20062	Багана	7	72	1591	51.390470000000001	51.424309999999998	54.362808999999999	54.334066999999997	0103000020E61000000100000005000000D908C4EBFAB149401FD61BB5C22A4B40D908C4EBFAB14940E4D87A86702E4B40D1AE42CA4FB64940E4D87A86702E4B40D1AE42CA4FB649401FD61BB5C22A4B40D908C4EBFAB149401FD61BB5C22A4B40
19305	Артюшкино	7	72	1591	51.348734999999998	51.384765999999999	54.425708	54.412762999999998	0103000020E610000001000000050000003BFC3559A3AC4940DAFF006BD5344B403BFC3559A3AC4940A2D288997D364B406E4E250340B14940A2D288997D364B406E4E250340B14940DAFF006BD5344B403BFC3559A3AC4940DAFF006BD5344B40
47359	Аксаково	7	72	1591	51.634058000000003	51.651161999999999	54.529004999999998	54.509596000000002	0103000020E6100000010000000500000033E202D028D14940121615713A414B4033E202D028D14940D235936FB6434B40F032C34659D34940D235936FB6434B40F032C34659D34940121615713A414B4033E202D028D14940121615713A414B40
18306	Шламка	7	72	959	50.842883999999998	50.860796999999998	54.360405999999998	54.345146999999997	0103000020E610000001000000050000002C29779FE36B494000A8E2C62D2C4B402C29779FE36B49401EA4A7C8212E4B4059BF99982E6E49401EA4A7C8212E4B4059BF99982E6E494000A8E2C62D2C4B402C29779FE36B494000A8E2C62D2C4B40
19200	Чувашское Эштебенькино	7	72	959	51.141959999999997	51.171937	54.614662000000003	54.596550999999998	0103000020E610000001000000050000008AABCABE2B924940B3B27DC85B4C4B408AABCABE2B924940070C923EAD4E4B4076FC170802964940070C923EAD4E4B4076FC170802964940B3B27DC85B4C4B408AABCABE2B924940B3B27DC85B4C4B40
19101	Чувашское Урметьево	7	72	959	51.269854000000002	51.303756	54.489393	54.468532000000003	0103000020E61000000100000005000000EF586C938AA24940939048DBF83B4B40EF586C938AA2494017F2086EA43E4B405DFB027AE1A6494017F2086EA43E4B405DFB027AE1A64940939048DBF83B4B40EF586C938AA24940939048DBF83B4B40
46642	Чистовка	7	72	959	50.908003000000001	50.935068999999999	54.232258999999999	54.208016999999998	0103000020E61000000100000005000000BFD53A71397449408A01124DA01A4B40BFD53A7139744940D099B4A9BA1D4B4070404B57B0774940D099B4A9BA1D4B4070404B57B07749408A01124DA01A4B40BFD53A71397449408A01124DA01A4B40
18629	Челно-Вершины	7	72	959	51.063133000000001	51.103808999999998	54.428620000000002	54.398266999999997	0103000020E610000001000000050000003126FDBD14884940BB09BE69FA324B403126FDBD14884940AD342905DD364B40E603029D498D4940AD342905DD364B40E603029D498D4940BB09BE69FA324B403126FDBD14884940BB09BE69FA324B40
18580	Токмакла	7	72	959	51.131279999999997	51.165829000000002	54.345305000000003	54.326501	0103000020E61000000100000005000000374F75C8CD9049403F8EE6C8CA294B40374F75C8CD904940991249F4322C4B403CDD79E239954940991249F4322C4B403CDD79E2399549403F8EE6C8CA294B40374F75C8CD9049403F8EE6C8CA294B40
19104	Старое Эштебенькино	7	72	959	51.154384	51.188564999999997	54.597098000000003	54.586033999999998	0103000020E610000001000000050000004983DBDAC29349400A2C8029034B4B404983DBDAC2934940E6400FB56D4C4B40CA15DEE522984940E6400FB56D4C4B40CA15DEE5229849400A2C8029034B4B404983DBDAC29349400A2C8029034B4B40
18573	Старое Аделяково	7	72	959	51.014076000000003	51.044682000000002	54.535541000000002	54.519562999999998	0103000020E610000001000000050000004AD40B3ECD814940179B560A81424B404AD40B3ECD8149406555849B8C444B40255CC823B88549406555849B8C444B40255CC823B8854940179B560A81424B404AD40B3ECD814940179B560A81424B40
7960	Советский Нурлат	7	72	959	50.914614999999998	50.924450999999998	54.339168999999998	54.328591000000003	0103000020E610000001000000050000002CB7B41A12754940466117450F2A4B402CB7B41A127549409468C9E3692B4B4093E00D69547649409468C9E3692B4B4093E00D6954764940466117450F2A4B402CB7B41A12754940466117450F2A4B40
18466	Сиделькино	7	72	959	51.093676000000002	51.137324999999997	54.547772999999999	54.527056000000002	0103000020E61000000100000005000000C6353E93FD8B49408E942D9276434B40C6353E93FD8B4940DF50F86C1D464B402BF697DD93914940DF50F86C1D464B402BF697DD939149408E942D9276434B40C6353E93FD8B49408E942D9276434B40
45817	Покровка	7	72	959	51.190576999999998	51.206001000000001	54.473581000000003	54.468359	0103000020E61000000100000005000000552FBFD364984940C5E40D30F33B4B40552FBFD364984940E5805D4D9E3C4B40BEF8A23D5E9A4940E5805D4D9E3C4B40BEF8A23D5E9A4940C5E40D30F33B4B40552FBFD364984940C5E40D30F33B4B40
19206	Новое Эштебенькино	7	72	959	51.236139999999999	51.261454000000001	54.544471999999999	54.530645999999997	0103000020E6100000010000000500000083A3E4D5399E494069E04735EC434B4083A3E4D5399E49403ACB2C42B1454B4046B41D5377A149403ACB2C42B1454B4046B41D5377A1494069E04735EC434B4083A3E4D5399E494069E04735EC434B40
19014	Новое Аделяково	7	72	959	51.123491000000001	51.155830000000002	54.490788999999999	54.475935	0103000020E61000000100000005000000D82C978DCE8F4940C9022670EB3C4B40D82C978DCE8F4940471E882CD23E4B402BDEC83CF2934940471E882CD23E4B402BDEC83CF2934940C9022670EB3C4B40D82C978DCE8F4940C9022670EB3C4B40
18165	Новая Таяба	7	72	959	51.296219000000001	51.327454000000003	54.576579000000002	54.562184000000002	0103000020E6100000010000000500000017BA1281EAA54940D02A33A5F5474B4017BA1281EAA54940BB473657CD494B40E2783E03EAA94940BB473657CD494B40E2783E03EAA94940D02A33A5F5474B4017BA1281EAA54940D02A33A5F5474B40
18266	Малый Нурлат	7	72	959	50.908344999999997	50.930120000000002	54.327697999999998	54.311307999999997	0103000020E61000000100000005000000183E22A644744940D87DC7F0D8274B40183E22A644744940787B1002F2294B4082AD122C0E774940787B1002F2294B4082AD122C0E774940D87DC7F0D8274B40183E22A644744940D87DC7F0D8274B40
17965	Малое Девлезеркино	7	72	959	51.218936999999997	51.243316999999998	54.482782	54.467725999999999	0103000020E610000001000000050000003271AB20069C494094BE1072DE3B4B403271AB20069C49407A8CF2CCCB3D4B40C9C7EE02259F49407A8CF2CCCB3D4B40C9C7EE02259F494094BE1072DE3B4B403271AB20069C494094BE1072DE3B4B40
11235	Кротовка	7	72	959	50.938564	50.971406000000002	54.246361	54.237152999999999	0103000020E61000000100000005000000FA997ADD22784940FB928D075B1E4B40FA997ADD227849404301DBC1881F4B40B0912408577C49404301DBC1881F4B40B0912408577C4940FB928D075B1E4B40FA997ADD22784940FB928D075B1E4B40
18021	Красный Строитель	7	72	959	51.102542	51.149686000000003	54.293083000000003	54.271647000000002	0103000020E61000000100000005000000B43BA418208D49403C873254C5224B40B43BA418208D4940BD0166BE83254B40A4552DE928934940BD0166BE83254B40A4552DE9289349403C873254C5224B40B43BA418208D49403C873254C5224B40
18252	Краснояриха	7	72	959	50.848875999999997	50.867238	54.295189999999998	54.285457000000001	0103000020E61000000100000005000000FD2D01F8A76C494007B5DFDA89244B40FD2D01F8A76C4940990D32C9C8254B409AEC9FA7016F4940990D32C9C8254B409AEC9FA7016F494007B5DFDA89244B40FD2D01F8A76C494007B5DFDA89244B40
48185	Красная Горка	7	72	959	51.139284000000004	51.151491999999998	54.316566000000002	54.30397	0103000020E61000000100000005000000946DE00ED4914940897B2C7DE8264B40946DE00ED49149404583143C85284B4085CD0017649349404583143C85284B4085CD001764934940897B2C7DE8264B40946DE00ED4914940897B2C7DE8264B40
18161	Красная Багана	7	72	959	51.212361000000001	51.244287999999997	54.630116999999998	54.616664	0103000020E6100000010000000500000012F92EA52E9B49406E4F90D8EE4E4B4012F92EA52E9B4940AAD381ACA7504B40126745D4449F4940AAD381ACA7504B40126745D4449F49406E4F90D8EE4E4B4012F92EA52E9B49406E4F90D8EE4E4B40
55892	Каменный Брод	7	72	959	51.264913	51.308292999999999	54.638658	54.623404000000001	0103000020E6100000010000000500000083A44FABE8A149400919C8B3CB4F4B4083A44FABE8A1494015AA9B8BBF514B40F94A202576A7494015AA9B8BBF514B40F94A202576A749400919C8B3CB4F4B4083A44FABE8A149400919C8B3CB4F4B40
46459	Зубовка	7	72	959	51.087522999999997	51.115459999999999	54.270243999999998	54.252409999999998	0103000020E61000000100000005000000EB5223F4338B494078978BF84E204B40EB5223F4338B494059F8FA5A97224B4082FFAD64C78E494059F8FA5A97224B4082FFAD64C78E494078978BF84E204B40EB5223F4338B494078978BF84E204B40
17863	Девлезеркино	7	72	959	51.184764999999999	51.214311000000002	54.441785000000003	54.407994000000002	0103000020E6100000010000000500000004392861A69749406C7BBB2539344B4004392861A6974940836E2F698C384B402716F88A6E9B4940836E2F698C384B402716F88A6E9B49406C7BBB2539344B4004392861A69749406C7BBB2539344B40
45827	Воскресенка	7	72	959	50.829777999999997	50.862881000000002	54.291091000000002	54.278624000000001	0103000020E610000001000000050000005B785E2A366A4940BBF083F3A9234B405B785E2A366A494079944A7842254B407EAB75E2726E494079944A7842254B407EAB75E2726E4940BBF083F3A9234B405B785E2A366A4940BBF083F3A9234B40
47679	Александровка	7	72	959	50.999200000000002	51.009377999999998	54.227300999999997	54.217956999999998	0103000020E61000000100000005000000E4141DC9E57F49409677D503E61B4B40E4141DC9E57F49408EACFC32181D4B40A4A65D4C338149408EACFC32181D4B40A4A65D4C338149409677D503E61B4B40E4141DC9E57F49409677D503E61B4B40
55916	Чувичи	7	72	1751	48.882742	48.913742999999997	52.508629999999997	52.488899000000004	0103000020E610000001000000050000001F679AB0FD7048400806103E943E4A401F679AB0FD704840DAE1AFC91A414A4076F9D687F5744840DAE1AFC91A414A4076F9D687F57448400806103E943E4A401F679AB0FD7048400806103E943E4A40
55914	Чагра	7	72	1751	49.303603000000003	49.319845000000001	52.666542	52.654125999999998	0103000020E61000000100000005000000D7FB8D76DCA648404DBB9866BA534A40D7FB8D76DCA6484089B48D3F51554A40026553AEF0A8484089B48D3F51554A40026553AEF0A848404DBB9866BA534A40D7FB8D76DCA648404DBB9866BA534A40
55856	Хворостянка	7	72	1751	48.932319999999997	48.992255999999998	52.632941000000002	52.594315000000002	0103000020E610000001000000050000000FB4024356774840D9429083124C4A400FB402435677484016A6EF3504514A4040A19E3E027F484016A6EF3504514A4040A19E3E027F4840D9429083124C4A400FB4024356774840D9429083124C4A40
55935	Тополек	7	72	1751	49.072609999999997	49.091088999999997	52.862076000000002	52.849907000000002	0103000020E6100000010000000500000068AED3484B8948401CD2A8C0C96C4A4068AED3484B8948405055A181586E4A403E03EACDA88B48405055A181586E4A403E03EACDA88B48401CD2A8C0C96C4A4068AED3484B8948401CD2A8C0C96C4A40
55949	Студенцы	7	72	1751	49.186695999999998	49.223275999999998	52.801326000000003	52.779226999999999	0103000020E61000000100000005000000A2258FA7E59748408194D8B5BD634A40A2258FA7E59748409EB7B1D991664A40A8FDD64E949C48409EB7B1D991664A40A8FDD64E949C48408194D8B5BD634A40A2258FA7E59748408194D8B5BD634A40
55954	Соловьево	7	72	1751	48.901561999999998	48.918818999999999	52.799169999999997	52.787680000000002	0103000020E610000001000000050000007EA83462667348404DDBBFB2D2644A407EA8346266734840DFF8DA334B664A40C2F869DC9B754840DFF8DA334B664A40C2F869DC9B7548404DDBBFB2D2644A407EA83462667348404DDBBFB2D2644A40
55896	Романовка	7	72	1751	49.404125000000001	49.433230000000002	52.753628999999997	52.726672999999998	0103000020E610000001000000050000007D3F355EBAB348406FF1F09E035D4A407D3F355EBAB34840992842EA76604A40B3D2A41474B74840992842EA76604A40B3D2A41474B748406FF1F09E035D4A407D3F355EBAB348406FF1F09E035D4A40
55906	Прогресс	7	72	1751	49.009180000000001	49.040028	52.521858999999999	52.507671000000002	0103000020E610000001000000050000007EE36BCF2C8148405610035DFB404A407EE36BCF2C814840C70F9546CC424A404F7633A31F854840C70F9546CC424A404F7633A31F8548405610035DFB404A407EE36BCF2C8148405610035DFB404A40
55942	Приовражный	7	72	1751	49.122340999999999	49.139381999999998	52.751001000000002	52.739133000000002	0103000020E61000000100000005000000DFFAB0DEA88F48407B32FFE89B5E4A40DFFAB0DEA88F4840B421FFCC20604A4056D3F544D7914840B421FFCC20604A4056D3F544D79148407B32FFE89B5E4A40DFFAB0DEA88F48407B32FFE89B5E4A40
55902	Новотулка	7	72	1751	48.723705000000002	48.793467999999997	52.671925999999999	52.646259000000001	0103000020E61000000100000005000000D1798D5DA25C484072DF6A9DB8524A40D1798D5DA25C484082AAD1AB01564A401536035C9065484082AAD1AB01564A401536035C9065484072DF6A9DB8524A40D1798D5DA25C484072DF6A9DB8524A40
55903	Новокуровка	7	72	1751	49.267598999999997	49.301124000000002	52.677844999999998	52.652634999999997	0103000020E610000001000000050000009DB81CAF40A24840CB9C2E8B89534A409DB81CAF40A24840E960FD9FC3564A403605323B8BA64840E960FD9FC3564A403605323B8BA64840CB9C2E8B89534A409DB81CAF40A24840CB9C2E8B89534A40
55911	Михайло-Лебяжье	7	72	1751	49.223140999999998	49.249479999999998	52.645172000000002	52.623939	0103000020E61000000100000005000000C8B260E28F9C484077D9AF3BDD4F4A40C8B260E28F9C4840C02500FF94524A40C780ECF5EE9F4840C02500FF94524A40C780ECF5EE9F484077D9AF3BDD4F4A40C8B260E28F9C484077D9AF3BDD4F4A40
55888	Масленниково	7	72	1751	49.067472000000002	49.101213000000001	52.829203	52.806716000000002	0103000020E61000000100000005000000A7B228ECA288484079944A7842674A40A7B228ECA28848405F5FEB52236A4A400C772E8CF48C48405F5FEB52236A4A400C772E8CF48C484079944A7842674A40A7B228ECA288484079944A7842674A40
55930	Липовка	7	72	1751	49.151392999999999	49.174686000000001	52.635362000000001	52.621609999999997	0103000020E61000000100000005000000F2EB87D860934840EB6E9EEA904F4A40F2EB87D860934840828FC18A53514A40D788601C5C964840828FC18A53514A40D788601C5C964840EB6E9EEA904F4A40F2EB87D860934840EB6E9EEA904F4A40
55915	Иерусалимский	7	72	1751	49.317500000000003	49.329106000000003	52.796953999999999	52.792608999999999	0103000020E61000000100000005000000713D0AD7A3A84840F4C1323674654A40713D0AD7A3A848404C35B39602664A406D75392520AA48404C35B39602664A406D75392520AA4840F4C1323674654A40713D0AD7A3A84840F4C1323674654A40
55941	Елань	7	72	1751	49.320706999999999	49.354698999999997	52.711362000000001	52.690531999999997	0103000020E61000000100000005000000944C4EED0CA94840B56B425A63584A40944C4EED0CA94840FFCEF6E80D5B4A404276DEC666AD4840FFCEF6E80D5B4A404276DEC666AD4840B56B425A63584A40944C4EED0CA94840B56B425A63584A40
55945	Высотино	7	72	1751	48.805352999999997	48.826031999999998	52.762326999999999	52.750532999999997	0103000020E61000000100000005000000245E9ECE15674840CDC8207711604A40245E9ECE15674840CCED5EEE93614A4088B9A46ABB694840CCED5EEE93614A4088B9A46ABB694840CDC8207711604A40245E9ECE15674840CDC8207711604A40
55886	Владимировка	7	72	1751	48.910330000000002	48.951642999999997	52.732742999999999	52.678544000000002	0103000020E61000000100000005000000AA4885B185744840D272A087DA564A40AA4885B185744840BCAFCA85CA5D4A40D13B1570CF794840BCAFCA85CA5D4A40D13B1570CF794840D272A087DA564A40AA4885B185744840D272A087DA564A40
25080	Березовая Роща	7	72	1751	49.146774999999998	49.165118999999997	52.545929999999998	52.529749000000002	0103000020E61000000100000005000000696FF085C99248405B0BB3D0CE434A40696FF085C9924840E0F3C308E1454A405F79909E22954840E0F3C308E1454A405F79909E229548405B0BB3D0CE434A40696FF085C99248405B0BB3D0CE434A40
55905	Абашево	7	72	1751	48.639882999999998	48.687485000000002	52.700164999999998	52.682366000000002	0103000020E610000001000000050000001822A7AFE751484080F3E2C457574A401822A7AFE7514840E466B8019F594A40CBBE2B82FF574840E466B8019F594A40CBBE2B82FF57484080F3E2C457574A401822A7AFE751484080F3E2C457574A40
55850	Сызрань	7	72	617	48.473578000000003	48.474727999999999	53.150350000000003	53.149740000000001	0103000020E61000000100000005000000740D33349E3C4840977329AE2A934A40740D33349E3C4840107A36AB3E934A406C3F19E3C33C4840107A36AB3E934A406C3F19E3C33C4840977329AE2A934A40740D33349E3C4840977329AE2A934A40
55908	станция Новообразцовое	7	72	647	48.356454999999997	48.35783	53.160971000000004	53.160938999999999	0103000020E6100000010000000500000072BF4351A02D484052D32EA699944A4072BF4351A02D48405E4D9EB29A944A408BC3995FCD2D48405E4D9EB29A944A408BC3995FCD2D484052D32EA699944A4072BF4351A02D484052D32EA699944A40
55878	Приморский	7	72	248	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
55870	городской округ Сызрань	7	72	647	47.926988999999999	49.220391999999997	53.493316	52.939784000000003	0103000020E6100000010000000500000039605793A7F64740ECA694D74A784A4039605793A7F64740F94B8BFA24BF4A40672618CE359C4840F94B8BFA24BF4A40672618CE359C4840ECA694D74A784A4039605793A7F64740ECA694D74A784A40
24377	Чекалино	7	72	647	48.435533999999997	48.454155999999998	53.329278000000002	53.308805999999997	0103000020E61000000100000005000000E525FF93BF3748407F677BF486A74A40E525FF93BF3748406AA510C825AA4A401EA4A7C8213A48406AA510C825AA4A401EA4A7C8213A48407F677BF486A74A40E525FF93BF3748407F677BF486A74A40
24228	Усинское	7	72	647	48.674055000000003	48.714281	53.334536999999997	53.313954000000003	0103000020E61000000100000005000000475A2A6F47564840653909A52FA84A40475A2A6F47564840A626C11BD2AA4A40BC934F8F6D5B4840A626C11BD2AA4A40BC934F8F6D5B4840653909A52FA84A40475A2A6F47564840653909A52FA84A40
23784	Уваровка	7	72	647	48.347248	48.383980000000001	53.128909999999998	53.118631999999998	0103000020E61000000100000005000000FBCC599F722C4840292158552F8F4A40FBCC599F722C48404D10751F80904A40B728B341263148404D10751F80904A40B728B34126314840292158552F8F4A40FBCC599F722C4840292158552F8F4A40
21830	Трубетчино	7	72	647	48.222571000000002	48.257066000000002	53.315460999999999	53.305039000000001	0103000020E61000000100000005000000DE04DF347D1C4840958098840BA74A40DE04DF347D1C4840EC14AB0661A84A40EF74E789E7204840EC14AB0661A84A40EF74E789E7204840958098840BA74A40DE04DF347D1C4840958098840BA74A40
47609	Троицкое	7	72	647	48.370154999999997	48.399636999999998	53.394069000000002	53.363016000000002	0103000020E61000000100000005000000B6B9313D612F48405EF6EB4E77AE4A40B6B9313D612F484008AF5DDA70B24A40C2A2224E2733484008AF5DDA70B24A40C2A2224E273348405EF6EB4E77AE4A40B6B9313D612F48405EF6EB4E77AE4A40
55871	Старая Рачейка	7	72	647	48.002761999999997	48.0428	53.394970999999998	53.366573000000002	0103000020E61000000100000005000000F5D555815A0048405E4C33DDEBAE4A40F5D555815A00484028EFE3688EB24A4068226C787A05484028EFE3688EB24A4068226C787A0548405E4C33DDEBAE4A40F5D555815A0048405E4C33DDEBAE4A40
24139	Смолькино	7	72	647	48.115141000000001	48.134014999999998	53.455575000000003	53.440441999999997	0103000020E61000000100000005000000E1B6B6F0BC0E484075E4486760B84A40E1B6B6F0BC0E484007F0164850BA4A4033164D672711484007F0164850BA4A4033164D672711484075E4486760B84A40E1B6B6F0BC0E484075E4486760B84A40
23179	Сборный	7	72	647	48.574323999999997	48.612341000000001	53.218286999999997	53.205156000000002	0103000020E6100000010000000500000069A7E67283494840024A438D429A4A4069A7E672834948402B1213D4F09B4A40FE7F9C30614E48402B1213D4F09B4A40FE7F9C30614E4840024A438D429A4A4069A7E67283494840024A438D429A4A40
24038	Рамено	7	72	647	48.327314000000001	48.375554000000001	53.241152999999997	53.224632999999997	0103000020E61000000100000005000000F0C2D66CE52948401A4D2EC6C09C4A40F0C2D66CE5294840882AFC19DE9E4A40E5F0492712304840882AFC19DE9E4A40E5F04927123048401A4D2EC6C09C4A40F0C2D66CE52948401A4D2EC6C09C4A40
4304	Печерское	7	72	647	48.990566999999999	49.031342000000002	53.249591000000002	53.231591999999999	0103000020E6100000010000000500000098BF42E6CA7E4840F30181CEA49D4A4098BF42E6CA7E48401F300F99F29F4A40E17EC003038448401F300F99F29F4A40E17EC00303844840F30181CEA49D4A4098BF42E6CA7E4840F30181CEA49D4A40
24333	Печерские Выселки	7	72	647	48.840691999999997	48.864049000000001	53.258113999999999	53.246578999999997	0103000020E610000001000000050000002101A3CB9B6B4840B07092E68F9F4A402101A3CB9B6B4840E3512AE109A14A401D925A28996E4840E3512AE109A14A401D925A28996E4840B07092E68F9F4A402101A3CB9B6B4840B07092E68F9F4A40
55895	Петровка	7	72	647	48.503061000000002	48.515349000000001	53.286923000000002	53.282251000000002	0103000020E610000001000000050000005072874D64404840B421FFCC20A44A405072874D6440484030BC92E4B9A44A405E83BEF4F641484030BC92E4B9A44A405E83BEF4F6414840B421FFCC20A44A405072874D64404840B421FFCC20A44A40
23747	Новый Ризадей	7	72	647	48.237589999999997	48.285677	53.134447999999999	53.128678000000001	0103000020E61000000100000005000000A6ED5F59691E48407BDB4C8578904A40A6ED5F59691E48409D81919735914A40151C5E10912448409D81919735914A40151C5E10912448407BDB4C8578904A40A6ED5F59691E48407BDB4C8578904A40
55960	Новыи Озерки	7	72	647	48.657822000000003	48.667973000000003	53.211405999999997	53.202593999999998	0103000020E610000001000000050000006F4BE48233544840D32EA699EE994A406F4BE48233544840CE16105A0F9B4A4036CEA62380554840CE16105A0F9B4A4036CEA62380554840D32EA699EE994A406F4BE48233544840D32EA699EE994A40
23919	Новорепьевский	7	72	647	48.136701000000002	48.156032000000003	53.176226	53.171216999999999	0103000020E610000001000000050000004E2A1A6B7F11484076C24B70EA954A404E2A1A6B7F1148403A5AD5928E964A40939048DBF81348403A5AD5928E964A40939048DBF813484076C24B70EA954A404E2A1A6B7F11484076C24B70EA954A40
23839	Новозаборовский	7	72	647	48.337726000000004	48.350588999999999	53.188502999999997	53.182032999999997	0103000020E610000001000000050000002481069B3A2B484079E57ADB4C974A402481069B3A2B48405419C6DD20984A402EABB019E02C48405419C6DD20984A402EABB019E02C484079E57ADB4C974A402481069B3A2B484079E57ADB4C974A40
23732	Новая Рачейка	7	72	647	48.232577999999997	48.273989999999998	53.094965000000002	53.077295999999997	0103000020E6100000010000000500000071E2AB1DC51D4840490ED8D5E4894A4071E2AB1DC51D4840E0A128D0278C4A402CB7B41A12234840E0A128D0278C4A402CB7B41A12234840490ED8D5E4894A4071E2AB1DC51D4840490ED8D5E4894A40
23355	Новая Крымза	7	72	647	48.482165999999999	48.496521000000001	53.212187999999998	53.204098999999999	0103000020E610000001000000050000001F9F909DB73D4840BA1281EA1F9A4A401F9F909DB73D4840444DF4F9289B4A407C6308008E3F4840444DF4F9289B4A407C6308008E3F4840BA1281EA1F9A4A401F9F909DB73D4840BA1281EA1F9A4A40
55904	Междуреченск	7	72	647	49.096218	49.167535000000001	53.275644	53.255969999999998	0103000020E61000000100000005000000ADA415DF508C4840E960FD9FC3A04A40ADA415DF508C484058AB764D48A34A40BAF770C97195484058AB764D48A34A40BAF770C971954840E960FD9FC3A04A40ADA415DF508C4840E960FD9FC3A04A40
23570	Кошелевка	7	72	647	48.508172000000002	48.538724000000002	53.251837999999999	53.240485	0103000020E61000000100000005000000185FB4C70B414840DB166536C89E4A40185FB4C70B414840EDF1423A3CA04A4000C974E8F4444840EDF1423A3CA04A4000C974E8F4444840DB166536C89E4A40185FB4C70B414840DB166536C89E4A40
20536	Кашпир	7	72	647	48.393771000000001	48.432254999999998	53.058726	53.031050999999998	0103000020E610000001000000050000007E8E8F166732484009C1AA7AF9834A407E8E8F166732484063B6645584874A402844C0215437484063B6645584874A402844C0215437484009C1AA7AF9834A407E8E8F166732484009C1AA7AF9834A40
23504	Ивашевка	7	72	647	48.436836999999997	48.477997999999999	53.27881	53.268348000000003	0103000020E6100000010000000500000064575A46EA37484038F92D3A59A24A4064575A46EA3748401DE6CB0BB0A34A40D6C6D8092F3D48401DE6CB0BB0A34A40D6C6D8092F3D484038F92D3A59A24A4064575A46EA37484038F92D3A59A24A40
23448	Заборовка	7	72	647	48.213498000000001	48.279801999999997	53.245911	53.21022	0103000020E6100000010000000500000076E107E7531B4840897B2C7DE89A4A4076E107E7531B4840035DFB027A9F4A407DAD4B8DD0234840035DFB027A9F4A407DAD4B8DD0234840897B2C7DE89A4A4076E107E7531B4840897B2C7DE89A4A40
23447	Жемковка	7	72	647	48.159644	48.181221000000001	53.294119999999999	53.271540999999999	0103000020E610000001000000050000005680EF366F144840F64201DBC1A24A405680EF366F144840BD8C62B9A5A54A40992CEE3F32174840BD8C62B9A5A54A40992CEE3F32174840F64201DBC1A24A405680EF366F144840F64201DBC1A24A40
23360	Демидовка	7	72	647	48.311673999999996	48.338389999999997	53.311878	53.303597000000003	0103000020E61000000100000005000000BA8102EFE4274840F5143944DCA64A40BA8102EFE4274840C32B499EEBA74A408FA50F5D502B4840C32B499EEBA74A408FA50F5D502B4840F5143944DCA64A40BA8102EFE4274840F5143944DCA64A40
24317	Губино	7	72	647	48.716921999999997	48.743026999999998	53.318043000000003	53.307805000000002	0103000020E6100000010000000500000036E49F19C45B4840CC457C2766A74A4036E49F19C45B484062DC0DA2B5A84A40C2853C821B5F484062DC0DA2B5A84A40C2853C821B5F4840CC457C2766A74A4036E49F19C45B4840CC457C2766A74A40
23925	Взгорье	7	72	647	48.348416	48.361288000000002	53.204146999999999	53.199832000000001	0103000020E610000001000000050000009AB33EE5982C4840DE58501894994A409AB33EE5982C4840CB49287D219A4A40F83768AF3E2E4840CB49287D219A4A40F83768AF3E2E4840DE58501894994A409AB33EE5982C4840DE58501894994A40
55894	Васильевка	7	72	647	48.492865000000002	48.498263999999999	53.291052000000001	53.288361000000002	0103000020E61000000100000005000000E92B4833163F48408F386403E9A44A40E92B4833163F4840BBB7223141A54A401763601DC73F4840BBB7223141A54A401763601DC73F48408F386403E9A44A40E92B4833163F48408F386403E9A44A40
23276	Варламово	7	72	647	48.401111	48.434311999999998	53.200625000000002	53.186247000000002	0103000020E610000001000000050000006E88F19A5733484033FD12F1D6974A406E88F19A5733484048E17A14AE994A4053211E899737484048E17A14AE994A4053211E899737484033FD12F1D6974A406E88F19A5733484033FD12F1D6974A40
23091	Ягодное	7	72	248	49.026769000000002	49.064427000000002	53.621896	53.599310000000003	0103000020E61000000100000005000000F8C5A52A6D8348403815A930B6CC4A40F8C5A52A6D834840B1C1C2499ACF4A405DFDD8243F884840B1C1C2499ACF4A405DFDD8243F8848403815A930B6CC4A40F8C5A52A6D8348403815A930B6CC4A40
23087	Хрящевка	7	72	248	49.074568999999997	49.105874999999997	53.829160000000002	53.801138999999999	0103000020E61000000100000005000000D0251C7A8B8948406B4606B98BE64A40D0251C7A8B894840609335EA21EA4A40643BDF4F8D8D4840609335EA21EA4A40643BDF4F8D8D48406B4606B98BE64A40D0251C7A8B8948406B4606B98BE64A40
23007	Узюково	7	72	248	49.658518999999998	49.719648999999997	53.657801999999997	53.626921000000003	0103000020E61000000100000005000000B665C0594AD448407B1684F23ED04A40B665C0594AD44840279F1EDB32D44A40AFCC5B751DDC4840279F1EDB32D44A40AFCC5B751DDC48407B1684F23ED04A40B665C0594AD448407B1684F23ED04A40
55864	Тимофеевка	7	72	248	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
22820	Ташелка	7	72	248	49.439957999999997	49.469720000000002	53.822788000000003	53.792203999999998	0103000020E6100000010000000500000089CE328B50B8484054E1CFF066E54A4089CE328B50B8484048C5FF1D51E94A407923F3C81FBC484048C5FF1D51E94A407923F3C81FBC484054E1CFF066E54A4089CE328B50B8484054E1CFF066E54A40
4152	Сосновый Солонец	7	72	248	49.510987999999998	49.548205000000003	53.295051000000001	53.268089000000003	0103000020E610000001000000050000000053060E68C148406CB587BD50A24A400053060E68C1484078D32D3BC4A54A407940D9942BC6484078D32D3BC4A54A407940D9942BC648406CB587BD50A24A400053060E68C148406CB587BD50A24A40
50001	Солнечная Поляна	7	72	248	49.869289999999999	49.919749000000003	53.447870000000002	53.430925000000002	0103000020E61000000100000005000000B35E0CE544EF4840B003E78C28B74A40B35E0CE544EF4840056EDDCD53B94A40ADC3D155BAF54840056EDDCD53B94A40ADC3D155BAF54840B003E78C28B74A40B35E0CE544EF4840B003E78C28B74A40
2572	Севрюкаево	7	72	248	49.489339000000001	49.514321000000002	53.184666	53.170698999999999	0103000020E6100000010000000500000024D40CA9A2BE4840DE3AFF76D9954A4024D40CA9A2BE48407157AF22A3974A40B1524145D5C148407157AF22A3974A40B1524145D5C14840DE3AFF76D9954A4024D40CA9A2BE4840DE3AFF76D9954A40
24320	Прибрежный	7	72	248	49.840868	49.881849000000003	53.495384000000001	53.477863999999997	0103000020E6100000010000000500000060200890A1EB4840C6F7C5A52ABD4A4060200890A1EB4840187B2FBE68BF4A405281936DE0F04840187B2FBE68BF4A405281936DE0F04840C6F7C5A52ABD4A4060200890A1EB4840C6F7C5A52ABD4A40
22414	Подстепки	7	72	248	49.098768999999997	49.166941999999999	53.524782000000002	53.507579	0103000020E61000000100000005000000E76D6C76A48C484075914259F8C04A40E76D6C76A48C4840C6C37B0E2CC34A40172AFF5A5E954840C6C37B0E2CC34A40172AFF5A5E95484075914259F8C04A40E76D6C76A48C484075914259F8C04A40
22298	Пискалы	7	72	248	49.796374	49.834992999999997	53.641554999999997	53.623972999999999	0103000020E610000001000000050000003EB14E95EFE54840234BE658DECF4A403EB14E95EFE54840EACA67791ED24A40C8B1F50CE1EA4840EACA67791ED24A40C8B1F50CE1EA4840234BE658DECF4A403EB14E95EFE54840234BE658DECF4A40
22384	Осиновка	7	72	248	49.631748999999999	49.653407000000001	53.199055000000001	53.180526999999998	0103000020E61000000100000005000000EE23B726DDD04840C2853C821B974A40EE23B726DDD048407A8D5DA27A994A401EFD2FD7A2D348407A8D5DA27A994A401EFD2FD7A2D34840C2853C821B974A40EE23B726DDD04840C2853C821B974A40
52181	Новая Васильевка	7	72	248	49.446938000000003	49.462335000000003	53.615876	53.601489999999998	0103000020E610000001000000050000007AABAE4335B948407E6FD39FFDCC4A407AABAE4335B9484016325706D5CE4A40E96514CB2DBB484016325706D5CE4A40E96514CB2DBB48407E6FD39FFDCC4A407AABAE4335B948407E6FD39FFDCC4A40
22218	Новая Бинарадка	7	72	248	49.899797	49.930897000000002	53.815351	53.793118999999997	0103000020E61000000100000005000000FB04508C2CF34840096B63EC84E54A40FB04508C2CF3484065E1EB6B5DE84A40E67805A227F7484065E1EB6B5DE84A40E67805A227F74840096B63EC84E54A40FB04508C2CF34840096B63EC84E54A40
22161	Нижнее Санчелеево	7	72	248	49.413862000000002	49.459235999999997	53.692940999999998	53.660063999999998	0103000020E610000001000000050000005187156EF9B448402BA226FA7CD44A405187156EF9B448405D876A4AB2D84A40AB92C83EC8BA48405D876A4AB2D84A40AB92C83EC8BA48402BA226FA7CD44A405187156EF9B448402BA226FA7CD44A40
22112	Мусорка	7	72	248	49.709533999999998	49.747182000000002	53.771656999999998	53.737703000000003	0103000020E6100000010000000500000035B39602D2DA48409F94490D6DDE4A4035B39602D2DA48405F5D15A8C5E24A407714E7A8A3DF48405F5D15A8C5E24A407714E7A8A3DF48409F94490D6DDE4A4035B39602D2DA48409F94490D6DDE4A40
21872	Луначарский	7	72	248	49.055065999999997	49.093128	53.686067999999999	53.664183000000001	0103000020E610000001000000050000008E8F16670C87484093C7D3F203D54A408E8F16670C874840836A8313D1D74A40C32B499EEB8B4840836A8313D1D74A40C32B499EEB8B484093C7D3F203D54A408E8F16670C87484093C7D3F203D54A40
21720	Лопатино	7	72	248	49.368462000000001	49.391889999999997	53.753442999999997	53.739736999999998	0103000020E61000000100000005000000CDE847C329AF48401152B7B3AFDE4A40CDE847C329AF48403733FAD170E04A4091D0967329B248403733FAD170E04A4091D0967329B248401152B7B3AFDE4A40CDE847C329AF48401152B7B3AFDE4A40
22296	Кирилловка	7	72	248	49.785153999999999	49.824948999999997	53.862355999999998	53.845626000000003	0103000020E610000001000000050000006B2920ED7FE44840DB5207793DEC4A406B2920ED7FE4484033C170AE61EE4A4017EFC7ED97E9484033C170AE61EE4A4017EFC7ED97E94840DB5207793DEC4A406B2920ED7FE44840DB5207793DEC4A40
50000	Зольное	7	72	248	49.747793000000001	49.849626000000001	53.449151000000001	53.422271000000002	0103000020E61000000100000005000000C09657AEB7DF48404D86E3F90CB64A40C09657AEB7DF48409CFBABC77DB94A4068EA758BC0EC48409CFBABC77DB94A4068EA758BC0EC48404D86E3F90CB64A40C09657AEB7DF48404D86E3F90CB64A40
991	Жигули	7	72	248	49.288386000000003	49.321128999999999	53.375931999999999	53.346457000000001	0103000020E61000000100000005000000E84F1BD5E9A44840323CF6B358AC4A40E84F1BD5E9A448408BC22E8A1EB04A400A664CC11AA948408BC22E8A1EB04A400A664CC11AA94840323CF6B358AC4A40E84F1BD5E9A44840323CF6B358AC4A40
21821	Выселки	7	72	248	49.266717999999997	49.321956	53.656520999999998	53.629019999999997	0103000020E6100000010000000500000094A0BFD023A24840D44334BA83D04A4094A0BFD023A24840901150E108D44A402060ADDA35A94840901150E108D44A402060ADDA35A94840D44334BA83D04A4094A0BFD023A24840D44334BA83D04A40
22947	Верхний Сускан	7	72	248	49.254348999999998	49.286498999999999	53.783538999999998	53.768911000000003	0103000020E6100000010000000500000099620E828EA048407044F7AC6BE24A4099620E828EA04840FD1186014BE44A4019ABCDFFABA44840FD1186014BE44A4019ABCDFFABA448407044F7AC6BE24A4099620E828EA048407044F7AC6BE24A40
21935	Верхние Белозерки	7	72	248	49.153917	49.195903999999999	53.738097000000003	53.718561999999999	0103000020E6100000010000000500000033A6608DB3934840FD12F1D6F9DB4A4033A6608DB39348404B2366F679DE4A40EA93DC61139948404B2366F679DE4A40EA93DC6113994840FD12F1D6F9DB4A4033A6608DB3934840FD12F1D6F9DB4A40
21719	Верхнее Санчелеево	7	72	248	49.491567000000003	49.540489000000001	53.71902	53.698405000000001	0103000020E610000001000000050000007C65DEAAEBBE4840732EC55565D94A407C65DEAAEBBE4840C095ECD808DC4A40836C59BE2EC54840C095ECD808DC4A40836C59BE2EC54840732EC55565D94A407C65DEAAEBBE4840732EC55565D94A40
22015	Валы	7	72	248	49.391710000000003	49.418129	53.335026999999997	53.320791	0103000020E6100000010000000500000012C2A38D23B24840F2ECF2AD0FA94A4012C2A38D23B2484074232C2AE2AA4A402D41464085B5484074232C2AE2AA4A402D41464085B54840F2ECF2AD0FA94A4012C2A38D23B24840F2ECF2AD0FA94A40
55907	Большой Рязань	7	72	248	49.287298999999997	49.313673000000001	53.273721999999999	53.251493000000004	0103000020E610000001000000050000003596B036C6A44840231631EC30A04A403596B036C6A448400D198F5209A34A40B151D66F26A848400D198F5209A34A40B151D66F26A84840231631EC30A04A403596B036C6A44840231631EC30A04A40
22812	Березовый Солонец	7	72	248	49.548906000000002	49.566853999999999	53.250038000000004	53.237434	0103000020E61000000100000005000000024A438D42C64840AF7AC03C649E4A40024A438D42C64840EE60C43E01A04A40ABCDFFAB8EC84840EE60C43E01A04A40ABCDFFAB8EC84840AF7AC03C649E4A40024A438D42C64840AF7AC03C649E4A40
21441	Бахилово	7	72	248	49.623384999999999	49.644441999999998	53.409357999999997	53.390503000000002	0103000020E6100000010000000500000092E86514CBCF4840B5FE9600FCB14A4092E86514CBCF4840902DCBD765B44A409C1551137DD24840902DCBD765B44A409C1551137DD24840B5FE9600FCB14A4092E86514CBCF4840B5FE9600FCB14A40
47940	Александровка	7	72	248	49.458373999999999	49.486006000000003	53.366486999999999	53.342773999999999	0103000020E6100000010000000500000019ABCDFFABBA4840A5F5B704E0AB4A4019ABCDFFABBA48405FB4C70BE9AE4A4074D4D17135BE48405FB4C70BE9AE4A4074D4D17135BE4840A5F5B704E0AB4A4019ABCDFFABBA4840A5F5B704E0AB4A40
55866	Тимофеевка	7	72	7382	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
17858	Черновка	7	72	583	50.761335000000003	50.781700000000001	53.721961	53.693004999999999	0103000020E610000001000000050000006C26DF6C73614940747B4963B4D84A406C26DF6C7361494065FED13769DC4A4040A4DFBE0E64494065FED13769DC4A4040A4DFBE0E644940747B4963B4D84A406C26DF6C73614940747B4963B4D84A40
17371	Чекалино	7	72	583	50.896737999999999	50.937342000000001	53.890059000000001	53.865186000000001	0103000020E610000001000000050000004C8A8F4FC8724940817A336ABEEE4A404C8A8F4FC872494057410C74EDF14A40689599D2FA77494057410C74EDF14A40689599D2FA774940817A336ABEEE4A404C8A8F4FC8724940817A336ABEEE4A40
16666	Успенка	7	72	583	51.041116000000002	51.079850999999998	54.018051	54.006622999999998	0103000020E61000000100000005000000D2AB014A438549406133C005D9004B40D2AB014A438549407E54C37E4F024B40C5C6BC8E388A49407E54C37E4F024B40C5C6BC8E388A49406133C005D9004B40D2AB014A438549406133C005D9004B40
16794	Суходол	7	72	583	51.191097999999997	51.253467999999998	53.909937999999997	53.883288	0103000020E610000001000000050000005E2A36E6759849408179C8940FF14A405E2A36E6759849409EB12FD978F44A40904AB1A371A049409EB12FD978F44A40904AB1A371A049408179C8940FF14A405E2A36E6759849408179C8940FF14A40
16971	Сургут	7	72	583	51.172987999999997	51.230238	53.933052000000004	53.907206000000002	0103000020E61000000100000005000000DB4C857824964940145E82531FF44A40DB4C857824964940D4BB783F6EF74A40F2255470789D4940D4BB783F6EF74A40F2255470789D4940145E82531FF44A40DB4C857824964940145E82531FF44A40
17567	Старое Якушкино	7	72	583	51.432799000000003	51.473295	53.910117999999997	53.893047000000003	0103000020E61000000100000005000000EA5E27F565B749403D65355D4FF24A40EA5E27F565B749401EC022BF7EF44A401F2E39EE94BC49401EC022BF7EF44A401F2E39EE94BC49403D65355D4FF24A40EA5E27F565B749403D65355D4FF24A40
16359	Старая Дмитриевка	7	72	583	50.910212999999999	50.945462999999997	54.141803000000003	54.129623000000002	0103000020E6100000010000000500000070B20DDC817449409BE7887C97104B4070B20DDC81744940C3BCC79926124B40FD497CEE04794940C3BCC79926124B40FD497CEE047949409BE7887C97104B4070B20DDC817449409BE7887C97104B40
17413	Спасское	7	72	583	50.829149000000001	50.875754000000001	54.052993999999998	54.004564000000002	0103000020E610000001000000050000006C41EF8D216A4940965E9B8D95004B406C41EF8D216A49402E71E481C8064B40ACAB02B5187049402E71E481C8064B40ACAB02B518704940965E9B8D95004B406C41EF8D216A4940965E9B8D95004B40
17667	Сидоровка	7	72	583	51.410305000000001	51.464905000000002	53.735050000000001	53.725909000000001	0103000020E610000001000000050000005131CEDF84B44940A06F0B96EADC4A405131CEDF84B4494060764F1E16DE4A409A5FCD0182BB494060764F1E16DE4A409A5FCD0182BB4940A06F0B96EADC4A405131CEDF84B44940A06F0B96EADC4A40
17117	Серноводск	7	72	583	51.242617000000003	51.270986000000001	53.930988999999997	53.909624999999998	0103000020E61000000100000005000000113AE8120E9F4940DF4F8D976EF44A40113AE8120E9F4940C6F7C5A52AF74A4041D653ABAFA24940C6F7C5A52AF74A4041D653ABAFA24940DF4F8D976EF44A40113AE8120E9F4940DF4F8D976EF44A40
16462	Сергиевск	7	72	583	51.132573000000001	51.186785999999998	53.959617000000001	53.930284	0103000020E6100000010000000500000093AAED26F8904940FCFECD8B13F74A4093AAED26F8904940C3D7D7BAD4FA4A40E2AC889AE8974940C3D7D7BAD4FA4A40E2AC889AE8974940FCFECD8B13F74A4093AAED26F8904940FCFECD8B13F74A40
50011	Светлодольск	7	72	583	51.146138000000001	51.176932000000001	53.903843000000002	53.884417999999997	0103000020E61000000100000005000000F75965A6B492494032FFE89B34F14A40F75965A6B4924940F9DB9E20B1F34A40D5CE30B5A5964940F9DB9E20B1F34A40D5CE30B5A596494032FFE89B34F14A40F75965A6B492494032FFE89B34F14A40
17074	Нероновка	7	72	583	50.991475000000001	51.030084000000002	53.882390999999998	53.862535999999999	0103000020E610000001000000050000009BE61DA7E87E4940B3CF639467EE4A409BE61DA7E87E494072A43330F2F04A400211E2CAD983494072A43330F2F04A400211E2CAD9834940B3CF639467EE4A409BE61DA7E87E4940B3CF639467EE4A40
17261	Мордовская Селитьба	7	72	583	50.691006000000002	50.730496000000002	53.833182999999998	53.818041000000001	0103000020E610000001000000050000007EAB75E272584940C1E44691B5E84A407EAB75E272584940A54A94BDA5EA4A40EEED96E4805D4940A54A94BDA5EA4A40EEED96E4805D4940C1E44691B5E84A407EAB75E272584940C1E44691B5E84A40
16270	Липовка	7	72	583	51.027380000000001	51.057715999999999	54.124504999999999	54.109389999999998	0103000020E6100000010000000500000041481630818349403541D47D000E4B4041481630818349402098A3C7EF0F4B405C3AE63C638749402098A3C7EF0F4B405C3AE63C638749403541D47D000E4B4041481630818349403541D47D000E4B40
17720	Кутузовский	7	72	583	51.216763	51.252301000000003	54.216524999999997	54.202356000000002	0103000020E61000000100000005000000CEFDD5E3BE9B49401F1329CDE6194B40CEFDD5E3BE9B494019E25817B71B4B40C2DF2F664BA0494019E25817B71B4B40C2DF2F664BA049401F1329CDE6194B40CEFDD5E3BE9B49401F1329CDE6194B40
17783	Красный Городок	7	72	583	51.135708000000001	51.159647999999997	54.155388000000002	54.144108000000003	0103000020E610000001000000050000001DE736E15E914940C68B852172124B401DE736E15E9149406E1805C1E3134B40976F7D586F9449406E1805C1E3134B40976F7D586F944940C68B852172124B401DE736E15E914940C68B852172124B40
17683	Красносельское	7	72	583	50.920831	50.940334	54.040649999999999	54.020696000000001	0103000020E610000001000000050000004D124BCADD7549403A94A12AA6024B404D124BCADD7549408C4AEA0434054B408FA850DD5C7849408C4AEA0434054B408FA850DD5C7849403A94A12AA6024B404D124BCADD7549403A94A12AA6024B40
3649	Кармало-Аделяково	7	72	583	51.387560000000001	51.417321000000001	53.856699999999996	53.839272000000001	0103000020E610000001000000050000006F9EEA909BB149406939D0436DEB4A406F9EEA909BB14940D93D7958A8ED4A408E7747C66AB54940D93D7958A8ED4A408E7747C66AB549406939D0436DEB4A406F9EEA909BB149406939D0436DEB4A40
50012	Кандабулак	7	72	583	50.704768000000001	50.762746	53.980034000000003	53.957954000000001	0103000020E6100000010000000500000038A27BD6355A49404489963C9EFA4A4038A27BD6355A4940EA7B0DC171FD4A40D19332A9A1614940EA7B0DC171FD4A40D19332A9A16149404489963C9EFA4A4038A27BD6355A49404489963C9EFA4A40
50010	Калиновка	7	72	583	51.276015999999998	51.309747999999999	53.843389000000002	53.820545000000003	0103000020E610000001000000050000001C96067E54A34940BBF2599E07E94A401C96067E54A349403067B62BF4EB4A402E008DD2A5A749403067B62BF4EB4A402E008DD2A5A74940BBF2599E07E94A401C96067E54A34940BBF2599E07E94A40
17566	Захаркино	7	72	583	51.449382	51.483697999999997	53.781990999999998	53.762231999999997	0103000020E610000001000000050000009EB4705985B949407AFB73D190E14A409EB4705985B949401762F54718E44A40FF91E9D0E9BD49401762F54718E44A40FF91E9D0E9BD49407AFB73D190E14A409EB4705985B949407AFB73D190E14A40
17358	Елшанка	7	72	583	50.831969999999998	50.859647000000002	53.835690999999997	53.815229000000002	0103000020E6100000010000000500000066A032FE7D6A49401AE0826C59E84A4066A032FE7D6A4940E04735ECF7EA4A40618DB3E9086E4940E04735ECF7EA4A40618DB3E9086E49401AE0826C59E84A4066A032FE7D6A49401AE0826C59E84A40
16782	Воротнее	7	72	583	51.163573999999997	51.182051999999999	53.690919999999998	53.676910999999997	0103000020E61000000100000005000000EA3C2AFEEF944940BDA60705A5D64A40EA3C2AFEEF9449407F130A1170D84A40F015DD7A4D9749407F130A1170D84A40F015DD7A4D974940BDA60705A5D64A40EA3C2AFEEF944940BDA60705A5D64A40
49998	Верхняя Орлянка	7	72	583	51.040199000000001	51.088797999999997	53.737127000000001	53.711837000000003	0103000020E610000001000000050000007C2AA73D25854940988A8D791DDB4A407C2AA73D25854940D2FF722D5ADE4A40A0F99CBB5D8B4940D2FF722D5ADE4A40A0F99CBB5D8B4940988A8D791DDB4A407C2AA73D25854940988A8D791DDB4A40
16577	Боровка	7	72	583	51.282062000000003	51.310825999999999	54.028328000000002	54.008586000000001	0103000020E61000000100000005000000E1B88C9B1AA449400B9A965819014B40E1B88C9B1AA44940D2C77C40A0034B408D5F7825C9A74940D2C77C40A0034B408D5F7825C9A749400B9A965819014B40E1B88C9B1AA449400B9A965819014B40
17267	Большая Чесноковка	7	72	583	50.738455000000002	50.760382999999997	53.792592999999997	53.776994999999999	0103000020E61000000100000005000000AA4885B1855E4940E813799274E34A40AA4885B1855E4940EE04FBAF73E54A4099B7EA3A54614940EE04FBAF73E54A4099B7EA3A54614940E813799274E34A40AA4885B1855E4940E813799274E34A40
16675	Антоновка	7	72	583	51.311993999999999	51.326932999999997	53.959167000000001	53.946582999999997	0103000020E610000001000000050000002C465D6BEFA749408BF9B9A129F94A402C465D6BEFA749408333F8FBC5FA4A40D87DC7F0D8A949408333F8FBC5FA4A40D87DC7F0D8A949408BF9B9A129F94A402C465D6BEFA749408BF9B9A129F94A40
47080	Федоровка	7	72	94	48.525787999999999	48.555145000000003	52.821432999999999	52.797013999999997	0103000020E610000001000000050000008B506C054D434840213A048E04664A408B506C054D434840766D6FB724694A40DBC4C9FD0E474840766D6FB724694A40DBC4C9FD0E474840213A048E04664A408B506C054D434840213A048E04664A40
20776	Томанский	7	72	94	48.670372	48.696800000000003	52.873742	52.859526000000002	0103000020E61000000100000005000000BA13ECBFCE554840E607AEF2046E4A40BA13ECBFCE554840219221C7D66F4A4029ED0DBE30594840219221C7D66F4A4029ED0DBE30594840E607AEF2046E4A40BA13ECBFCE554840E607AEF2046E4A40
46817	Степняки	7	72	94	48.823166000000001	48.845300999999999	52.963098000000002	52.951228	0103000020E61000000100000005000000EE96E4805D6948400E85CFD6C1794A40EE96E4805D694840E86B96CB467B4A405723BBD2326C4840E86B96CB467B4A405723BBD2326C48400E85CFD6C1794A40EE96E4805D6948400E85CFD6C1794A40
20975	Приволжье	7	72	94	48.569716	48.618135000000002	52.873311999999999	52.841346000000001	0103000020E6100000010000000500000004013274EC4848406A4FC939B16B4A4004013274EC484840289A07B0C86F4A40A9C1340C1F4F4840289A07B0C86F4A40A9C1340C1F4F48406A4FC939B16B4A4004013274EC4848406A4FC939B16B4A40
20969	Озерецкое	7	72	94	48.735014999999997	48.769159000000002	52.803682999999999	52.786650999999999	0103000020E61000000100000005000000E388B5F8145E4840CF2EDFFAB0644A40E388B5F8145E4840F3ACA415DF664A40483657CD73624840F3ACA415DF664A40483657CD73624840CF2EDFFAB0644A40E388B5F8145E4840CF2EDFFAB0644A40
826	Обшаровка	7	72	94	48.788688999999998	48.888922999999998	53.136020000000002	53.108179	0103000020E6100000010000000500000083DBDAC2F3644840978E39CFD88D4A4083DBDAC2F36448400CCD751A69914A40C3D4963AC87148400CCD751A69914A40C3D4963AC8714840978E39CFD88D4A4083DBDAC2F3644840978E39CFD88D4A40
116	Новоспасский	7	72	94	48.761361999999998	48.802782999999998	53.009946999999997	52.983432999999998	0103000020E6100000010000000500000065355D4F746148405167EE21E17D4A4065355D4F74614840BED87BF145814A407364E597C1664840BED87BF145814A407364E597C16648405167EE21E17D4A4065355D4F746148405167EE21E17D4A40
20064	Нижнепечерское	7	72	94	48.925960000000003	48.950474999999997	53.186867999999997	53.175874999999998	0103000020E61000000100000005000000BCB376DB857648408D976E1283964A40BCB376DB857648409F55664AEB974A403255302AA97948409F55664AEB974A403255302AA97948408D976E1283964A40BCB376DB857648408D976E1283964A40
55951	Нижнеозерецкое	7	72	94	48.806727000000002	48.825681000000003	52.876165999999998	52.856915999999998	0103000020E610000001000000050000006DE690D442674840A6B5696CAF6D4A406DE690D442674840FEEE1D3526704A40DCF63DEAAF694840FEEE1D3526704A40DCF63DEAAF694840A6B5696CAF6D4A406DE690D442674840A6B5696CAF6D4A40
46918	Ильмень	7	72	94	48.743315000000003	48.770353999999998	52.910598999999998	52.892625000000002	0103000020E6100000010000000500000029D027F2245F4840C74B378941724A4029D027F2245F484099620E828E744A40E02BBAF59A62484099620E828E744A40E02BBAF59A624840C74B378941724A4029D027F2245F4840C74B378941724A40
20654	Заволжье	7	72	94	48.599871999999998	48.622796999999998	52.962246	52.941943999999999	0103000020E610000001000000050000009FE40E9BC84C4840EB54F99E91784A409FE40E9BC84C4840795A7EE02A7B4A400186E5CFB74F4840795A7EE02A7B4A400186E5CFB74F4840EB54F99E91784A409FE40E9BC84C4840EB54F99E91784A40
47114	Давыдовка	7	72	94	48.404372000000002	48.427764000000003	52.757083999999999	52.741145000000003	0103000020E6100000010000000500000085B53176C2334840064CE0D6DD5E4A4085B53176C23348409529E620E8604A40FD3383F8C03648409529E620E8604A40FD3383F8C0364840064CE0D6DD5E4A4085B53176C2334840064CE0D6DD5E4A40
20360	Бестужевка	7	72	94	48.554175000000001	48.619895	53.114773	53.069716	0103000020E6100000010000000500000062A1D634EF46484004013274EC884A4062A1D634EF4648405EBBB4E1B08E4A401AFA27B8584F48405EBBB4E1B08E4A401AFA27B8584F484004013274EC884A4062A1D634EF46484004013274EC884A40
49392	Таволжанка	7	72	393	52.050085000000003	52.056750999999998	53.660043000000002	53.657690000000002	0103000020E6100000010000000500000095826E2F69064A400074982F2FD44A4095826E2F69064A40147AFD497CD44A40F581E49D43074A40147AFD497CD44A40F581E49D43074A400074982F2FD44A4095826E2F69064A400074982F2FD44A40
45536	Султангулово	7	72	393	52.282595999999998	52.310533999999997	53.797362999999997	53.781388999999997	0103000020E610000001000000050000007EFD101B2C244A40213A048E04E44A407EFD101B2C244A402D05A4FD0FE64A40E525FF93BF274A402D05A4FD0FE64A40E525FF93BF274A40213A048E04E44A407EFD101B2C244A40213A048E04E44A40
16159	Стюхино	7	72	393	52.252009000000001	52.284796999999998	53.853402000000003	53.817818000000003	0103000020E610000001000000050000001AA6B6D441204A40420A9E42AEE84A401AA6B6D441204A40A62BD8463CED4A40DC7F643A74244A40A62BD8463CED4A40DC7F643A74244A40420A9E42AEE84A401AA6B6D441204A40420A9E42AEE84A40
16059	Старый Аманак	7	72	393	51.934679000000003	51.994965000000001	53.722051999999998	53.691682999999998	0103000020E6100000010000000500000006A1BC8FA3F749407E198C1189D84A4006A1BC8FA3F7494075012F336CDC4A4013D55B035BFF494075012F336CDC4A4013D55B035BFF49407E198C1189D84A4006A1BC8FA3F749407E198C1189D84A40
16205	Старопохвистнево	7	72	393	52.119543	52.137625999999997	53.703395	53.677722000000003	0103000020E610000001000000050000009DBB5D2F4D0F4A40CEE33098BFD64A409DBB5D2F4D0F4A40C095ECD808DA4A40268A90BA9D114A40C095ECD808DA4A40268A90BA9D114A40CEE33098BFD64A409DBB5D2F4D0F4A40CEE33098BFD64A40
16149	Староганькино	7	72	393	52.220216999999998	52.257748999999997	53.911178999999997	53.885877999999998	0103000020E61000000100000005000000F9821612301C4A40791F477364F14A40F9821612301C4A40A7E67283A1F44A40D1C952EBFD204A40A7E67283A1F44A40D1C952EBFD204A40791F477364F14A40F9821612301C4A40791F477364F14A40
15917	Среднее Аверкино	7	72	393	52.043824000000001	52.079604000000003	53.621079000000002	53.589562000000001	0103000020E61000000100000005000000D4635B069C054A40707B82C476CB4A40D4635B069C054A40BF9D44847FCF4A40BE50C076300A4A40BF9D44847FCF4A40BE50C076300A4A40707B82C476CB4A40D4635B069C054A40707B82C476CB4A40
55936	Сосновка	7	72	393	51.793086000000002	51.814492999999999	53.830260000000003	53.805610999999999	0103000020E610000001000000050000002E7590D783E549402026E1421EE74A402E7590D783E54940A796ADF545EA4A4014E97E4E41E84940A796ADF545EA4A4014E97E4E41E849402026E1421EE74A402E7590D783E549402026E1421EE74A40
15878	Северный Ключ	7	72	393	51.675702999999999	51.702320999999998	53.711016999999998	53.694097999999997	0103000020E610000001000000050000009067976F7DD64940081C0934D8D84A409067976F7DD6494034F3E49A02DB4A40A2258FA7E5D9494034F3E49A02DB4A40A2258FA7E5D94940081C0934D8D84A409067976F7DD64940081C0934D8D84A40
15863	Савруха	7	72	393	51.675021000000001	51.711455999999998	53.624561	53.588935999999997	0103000020E610000001000000050000007E8E8F1667D64940F1B73D4162CB4A407E8E8F1667D64940B4AD669DF1CF4A4080457EFD10DB4940B4AD669DF1CF4A4080457EFD10DB4940F1B73D4162CB4A407E8E8F1667D64940F1B73D4162CB4A40
15771	Рысайкино	7	72	393	52.218169000000003	52.241605999999997	53.761502999999998	53.740493000000001	0103000020E61000000100000005000000220038F6EC1B4A405EF58079C8DE4A40220038F6EC1B4A40276728EE78E14A40394206F2EC1E4A40276728EE78E14A40394206F2EC1E4A405EF58079C8DE4A40220038F6EC1B4A405EF58079C8DE4A40
15632	Подбельск	7	72	393	51.787588999999997	51.823701	53.614659000000003	53.593249999999998	0103000020E610000001000000050000003CD862B7CFE449400E2DB29DEFCB4A403CD862B7CFE4494096986725ADCE4A405C57CC086FE9494096986725ADCE4A405C57CC086FE949400E2DB29DEFCB4A403CD862B7CFE449400E2DB29DEFCB4A40
45409	Передовка	7	72	393	51.694847000000003	51.715983999999999	53.536653000000001	53.524985000000001	0103000020E61000000100000005000000A35C1ABFF0D84940FEF15EB532C34A40A35C1ABFF0D849407026A60BB1C44A40C93A1C5DA5DB49407026A60BB1C44A40C93A1C5DA5DB4940FEF15EB532C34A40A35C1ABFF0D84940FEF15EB532C34A40
2054	Октябрьский	7	72	393	52.029442000000003	52.069479999999999	53.428452	53.411366000000001	0103000020E610000001000000050000007E9065C1C4034A40DA571EA4A7B44A407E9065C1C4034A40F1F3DF83D7B64A40F0DC7BB8E4084A40F1F3DF83D7B64A40F0DC7BB8E4084A40DA571EA4A7B44A407E9065C1C4034A40DA571EA4A7B44A40
15017	Нугайка	7	72	393	52.226568	52.240214000000002	53.676703000000003	53.668061999999999	0103000020E61000000100000005000000FA28232E001D4A40A5D93C0E83D54A40FA28232E001D4A40740D33349ED64A404B051555BF1E4A40740D33349ED64A404B051555BF1E4A40A5D93C0E83D54A40FA28232E001D4A40A5D93C0E83D54A40
15582	Новое Мансуркино	7	72	393	51.83811	51.875767000000003	53.887045000000001	53.865296999999998	0103000020E61000000100000005000000AC39403047EB4940D829560DC2EE4A40AC39403047EB4940488AC8B08AF14A4041F50F2219F04940488AC8B08AF14A4041F50F2219F04940D829560DC2EE4A40AC39403047EB4940D829560DC2EE4A40
15688	Нижнеягодное	7	72	393	51.782018999999998	51.801341999999998	53.583024999999999	53.575642000000002	0103000020E61000000100000005000000E1ECD63219E449401E1A16A3AEC94A40E1ECD63219E449400DE02D90A0CA4A40A374E95F92E649400DE02D90A0CA4A40A374E95F92E649401E1A16A3AEC94A40E1ECD63219E449401E1A16A3AEC94A40
15973	Нижнеаверкино	7	72	393	52.013973	52.039997	53.649146000000002	53.640915	0103000020E61000000100000005000000750305DEC9014A400742B28009D24A40750305DEC9014A40242A543717D34A401478279F1E054A40242A543717D34A401478279F1E054A400742B28009D24A40750305DEC9014A400742B28009D24A40
15496	Мочалеевка	7	72	393	51.772038999999999	51.831282999999999	53.675038999999998	53.640349000000001	0103000020E61000000100000005000000471E882CD2E249405E83BEF4F6D14A40471E882CD2E2494024438EAD67D64A40425C397B67EA494024438EAD67D64A40425C397B67EA49405E83BEF4F6D14A40471E882CD2E249405E83BEF4F6D14A40
15347	Малый Толкай	7	72	393	51.768256999999998	51.816927999999997	53.525098	53.494788999999997	0103000020E6100000010000000500000027F6D03E56E24940D4B5F63E55BF4A4027F6D03E56E24940F698486936C34A40E597C11891E84940F698486936C34A40E597C11891E84940D4B5F63E55BF4A4027F6D03E56E24940D4B5F63E55BF4A40
15492	Малое Ибряйкино	7	72	393	52.148001999999998	52.172795000000001	53.636836000000002	53.621180000000003	0103000020E610000001000000050000000DDFC2BAF1124A40F37684D382CF4A400DDFC2BAF1124A402E7590D783D14A40C7F484251E164A402E7590D783D14A40C7F484251E164A40F37684D382CF4A400DDFC2BAF1124A40F37684D382CF4A40
49583	Кротково	7	72	393	52.108718000000003	52.152844000000002	53.867601999999998	53.848568	0103000020E61000000100000005000000473EAF78EA0D4A40503750E09DEC4A40473EAF78EA0D4A40DBF813950DEF4A40E6B1666490134A40DBF813950DEF4A40E6B1666490134A40503750E09DEC4A40473EAF78EA0D4A40503750E09DEC4A40
15100	Красные Ключи	7	72	393	51.896303000000003	51.928632999999998	53.586483000000001	53.559519000000002	0103000020E610000001000000050000004227840EBAF24940CD3E8F519EC74A404227840EBAF249407A54FCDF11CB4A40417E3672DDF649407A54FCDF11CB4A40417E3672DDF64940CD3E8F519EC74A404227840EBAF24940CD3E8F519EC74A40
49601	Исаково	7	72	393	52.046187000000003	52.072156999999997	53.911943000000001	53.898857	0103000020E610000001000000050000000C40A374E9054A40ED6305BF0DF34A400C40A374E9054A407768588CBAF44A40B796C9703C094A407768588CBAF44A40B796C9703C094A40ED6305BF0DF34A400C40A374E9054A40ED6305BF0DF34A40
15056	Большой Толкай	7	72	393	51.908143000000003	51.997821000000002	53.500804000000002	53.463172	0103000020E61000000100000005000000B18BA2073EF449402236583849BB4A40B18BA2073EF449405EDA70581AC04A408A213999B8FF49405EDA70581AC04A408A213999B8FF49402236583849BB4A40B18BA2073EF449402236583849BB4A40
15191	Большая Ега	7	72	393	51.977635999999997	51.994281999999998	53.565716999999999	53.549157999999998	0103000020E6100000010000000500000035B22B2D23FD49401B2B31CF4AC64A4035B22B2D23FD494047E5266A69C84A403080F0A144FF494047E5266A69C84A403080F0A144FF49401B2B31CF4AC64A4035B22B2D23FD49401B2B31CF4AC64A40
16056	Ахрат	7	72	393	52.018886999999999	52.042107999999999	53.508119999999998	53.499647000000003	0103000020E61000000100000005000000E7A8A3E36A024A40B345D26EF4BF4A40E7A8A3E36A024A40C5387F130AC14A40327381CB63054A40C5387F130AC14A40327381CB63054A40B345D26EF4BF4A40E7A8A3E36A024A40B345D26EF4BF4A40
15007	Алькино	7	72	393	52.232551000000001	52.265976999999999	53.740861000000002	53.720235000000002	0103000020E6100000010000000500000078D32D3BC41D4A40A03715A930DC4A4078D32D3BC41D4A40E1F08288D4DE4A407D3ECA880B224A40E1F08288D4DE4A407D3ECA880B224A40A03715A930DC4A4078D32D3BC41D4A40A03715A930DC4A40
15294	Абдул-Завод	7	72	393	51.967207000000002	51.994577999999997	53.898873000000002	53.888084999999997	0103000020E610000001000000050000002CBB6070CDFB4940B988EFC4ACF14A402CBB6070CDFB4940F3203D450EF34A4019A9F7544EFF4940F3203D450EF34A4019A9F7544EFF4940B988EFC4ACF14A402CBB6070CDFB4940B988EFC4ACF14A40
751	Тяглое Озеро	7	72	194	49.911304000000001	49.936278000000001	52.344419000000002	52.328994999999999	0103000020E61000000100000005000000645B069CA5F4484015C616821C2A4A40645B069CA5F448407E8FFAEB152C4A406EFB1EF5D7F748407E8FFAEB152C4A406EFB1EF5D7F7484015C616821C2A4A40645B069CA5F4484015C616821C2A4A40
19508	Тростянь	7	72	194	49.465775999999998	49.484057	52.434083000000001	52.415031999999997	0103000020E610000001000000050000007FA1478C9EBB48409065C1C41F354A407FA1478C9EBB4840F25F200890374A402F336C94F5BD4840F25F200890374A402F336C94F5BD48409065C1C41F354A407FA1478C9EBB48409065C1C41F354A40
46349	Тепловка	7	72	194	49.776646999999997	49.799455000000002	52.287638000000001	52.269278	0103000020E61000000100000005000000ACC43C2B69E3484022C495B377224A40ACC43C2B69E348401E8B6D52D1244A40D5CF9B8A54E648401E8B6D52D1244A40D5CF9B8A54E6484022C495B377224A40ACC43C2B69E3484022C495B377224A40
19733	Пестравка	7	72	194	49.935029	49.981704999999998	52.426242000000002	52.386262000000002	0103000020E61000000100000005000000E2E7BF07AFF7484002D8800871314A40E2E7BF07AFF7484040170D198F364A40EBA86A82A8FD484040170D198F364A40EBA86A82A8FD484002D8800871314A40E2E7BF07AFF7484002D8800871314A40
19516	Падовка	7	72	194	49.485143999999998	49.545475000000003	52.476131000000002	52.454189999999997	0103000020E61000000100000005000000E1ECD63219BE4840CA15DEE5223A4A40E1ECD63219BE48404FCE50DCF13C4A408FE4F21FD2C548404FCE50DCF13C4A408FE4F21FD2C54840CA15DEE5223A4A40E1ECD63219BE4840CA15DEE5223A4A40
55938	Овсянка	7	72	194	50.040222	50.060541999999998	52.285550000000001	52.277901999999997	0103000020E61000000100000005000000344A97FE250549401ABFF04A92234A40344A97FE25054940B8AF03E78C244A4068041BD7BF074940B8AF03E78C244A4068041BD7BF0749401ABFF04A92234A40344A97FE250549401ABFF04A92234A40
19359	Мосты	7	72	194	49.793121999999997	49.841065	52.321702000000002	52.291753	0103000020E610000001000000050000007ADE8D0585E5484044C18C2958254A407ADE8D0585E548406687F8872D294A40B6679604A8EB48406687F8872D294A40B6679604A8EB484044C18C2958254A407ADE8D0585E5484044C18C2958254A40
46270	Михеевка	7	72	194	50.043284999999997	50.065176999999998	52.216681999999999	52.201439000000001	0103000020E6100000010000000500000024B4E55C8A054940C991CEC0C8194A4024B4E55C8A054940E1D05B3CBC1B4A40C7B94DB857084940E1D05B3CBC1B4A40C7B94DB857084940C991CEC0C8194A4024B4E55C8A054940C991CEC0C8194A40
710	Михайло-Овсянка	7	72	194	49.716639999999998	49.756633000000001	52.379204000000001	52.351542999999999	0103000020E61000000100000005000000B28009DCBADB4840A1116C5CFF2C4A40B28009DCBADB48409641B5C189304A408509A359D9E048409641B5C189304A408509A359D9E04840A1116C5CFF2C4A40B28009DCBADB4840A1116C5CFF2C4A40
19417	Малоархангельское	7	72	194	49.469684000000001	49.504907000000003	52.373525000000001	52.355013999999997	0103000020E610000001000000050000002CBAF59A1EBC4840A2CF4719712D4A402CBAF59A1EBC4840849ECDAACF2F4A40C042E6CAA0C04840849ECDAACF2F4A40C042E6CAA0C04840A2CF4719712D4A402CBAF59A1EBC4840A2CF4719712D4A40
46200	Майское	7	72	194	50.025174999999997	50.057684999999999	52.286079000000001	52.261761	0103000020E61000000100000005000000A1D634EF38034940232F6B6281214A40A1D634EF380349404489963C9E244A40213CDA38620749404489963C9E244A40213CDA3862074940232F6B6281214A40A1D634EF38034940232F6B6281214A40
46324	Ломовка	7	72	194	49.801502999999997	49.831668999999998	52.284542000000002	52.269857000000002	0103000020E61000000100000005000000AC527AA697E6484060CC96AC8A224A40AC527AA697E64840522B4CDF6B244A406B0C3A2174EA4840522B4CDF6B244A406B0C3A2174EA484060CC96AC8A224A40AC527AA697E6484060CC96AC8A224A40
46278	Лозовой	7	72	194	49.966605000000001	49.982649000000002	52.205992999999999	52.195936000000003	0103000020E6100000010000000500000036936FB6B9FB4840F60D4C6E14194A4036936FB6B9FB48403B1A87FA5D1A4A403B394371C7FD48403B1A87FA5D1A4A403B394371C7FD4840F60D4C6E14194A4036936FB6B9FB4840F60D4C6E14194A40
46224	Крюково	7	72	194	50.197014000000003	50.214001000000003	52.290320000000001	52.279352000000003	0103000020E61000000100000005000000556D37C1371949403E096CCEC1234A40556D37C137194940F7AFAC3429254A40D9278062641B4940F7AFAC3429254A40D9278062641B49403E096CCEC1234A40556D37C1371949403E096CCEC1234A40
46476	Красная Поляна	7	72	194	49.546695999999997	49.579224000000004	52.558759000000002	52.529108000000001	0103000020E61000000100000005000000506D7022FAC54840A7069ACFB9434A40506D7022FAC548403FAC376A85474A407787140324CA48403FAC376A85474A407787140324CA4840A7069ACFB9434A40506D7022FAC54840A7069ACFB9434A40
19674	Идакра	7	72	194	49.697828999999999	49.724015000000001	52.499136	52.484406999999997	0103000020E61000000100000005000000A699EE7552D948400B7A6F0C013E4A40A699EE7552D94840CD203EB0E33F4A401F680586ACDC4840CD203EB0E33F4A401F680586ACDC48400B7A6F0C013E4A40A699EE7552D948400B7A6F0C013E4A40
46168	Высокое	7	72	194	50.019264	50.056311000000001	52.406869	52.388120000000001	0103000020E61000000100000005000000BDFE243E77024940367689EAAD314A40BDFE243E77024940CC608C4814344A40D9B3E73235074940CC608C4814344A40D9B3E73235074940367689EAAD314A40BDFE243E77024940367689EAAD314A40
55849	Октябрьск	7	72	648	48.666716000000001	48.66818	53.161186999999998	53.160912000000003	0103000020E6100000010000000500000027DC2BF35655484059C4B0C398944A4027DC2BF3565548402AC58EC6A1944A40AFEB17EC865548402AC58EC6A1944A40AFEB17EC8655484059C4B0C398944A4027DC2BF35655484059C4B0C398944A40
55857	Маяк	7	72	7381	49.795493999999998	49.820844000000001	53.064526999999998	53.048955999999997	0103000020E61000000100000005000000051555BFD2E54840B378B13044864A40051555BFD2E54840C05AB56B42884A40158F8B6A11E94840C05AB56B42884A40158F8B6A11E94840B378B13044864A40051555BFD2E54840B378B13044864A40
45836	Семеновка	7	72	68	49.868715000000002	49.884183999999998	53.004691000000001	52.991498999999997	0103000020E61000000100000005000000B745990D32EF484023827170E97E4A40B745990D32EF4840F3CAF5B699804A40BFD2F9F02CF14840F3CAF5B699804A40BFD2F9F02CF1484023827170E97E4A40B745990D32EF484023827170E97E4A40
50009	Имени Шмидта	7	72	68	49.778668000000003	49.799670999999996	53.055652000000002	53.044333000000002	0103000020E610000001000000050000008B389D64ABE34840199128B4AC854A408B389D64ABE348407FFACF9A1F874A40A1478C9E5BE648407FFACF9A1F874A40A1478C9E5BE64840199128B4AC854A408B389D64ABE34840199128B4AC854A40
17356	Утевка	7	72	1496	50.901994000000002	50.977424999999997	52.921410000000002	52.888893000000003	0103000020E610000001000000050000001898158A747349405952EE3EC7714A401898158A747349408B1A4CC3F0754A407AA52C431C7D49408B1A4CC3F0754A407AA52C431C7D49405952EE3EC7714A401898158A747349405952EE3EC7714A40
18307	Трофимовка	7	72	1496	50.838456000000001	50.859791000000001	52.832875999999999	52.815604	0103000020E610000001000000050000004791B586526B49404F3E3DB665684A404791B586526B4940C8CF46AE9B6A4A409432A9A10D6E4940C8CF46AE9B6A4A409432A9A10D6E49404F3E3DB665684A404791B586526B49404F3E3DB665684A40
18265	Песчаный Дол	7	72	1496	50.914085	50.927739000000003	52.734831	52.728206	0103000020E61000000100000005000000D061BEBC007549402060ADDA355D4A40D061BEBC00754940228B34F10E5E4A40A41CCC26C0764940228B34F10E5E4A40A41CCC26C07649402060ADDA355D4A40D061BEBC007549402060ADDA355D4A40
18364	Нефтегорск	7	72	1496	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
45787	Кулешовка	7	72	1496	51.086255999999999	51.115217999999999	52.794029999999999	52.765618000000003	0103000020E61000000100000005000000B98AC56F0A8B49404E9D47C5FF614A40B98AC56F0A8B49407D0569C6A2654A408CF4A276BF8E49407D0569C6A2654A408CF4A276BF8E49404E9D47C5FF614A40B98AC56F0A8B49404E9D47C5FF614A40
45744	Зуевка	7	72	1496	51.026204	51.094323000000003	52.746352000000002	52.724448000000002	0103000020E610000001000000050000001F8315A75A83494089D349B6BA5C4A401F8315A75A834940F0A65B76885F4A405C21ACC6128C4940F0A65B76885F4A405C21ACC6128C494089D349B6BA5C4A401F8315A75A83494089D349B6BA5C4A40
55939	Ветлянка	7	72	1496	51.109217000000001	51.126078	52.865794000000001	52.852811000000003	0103000020E61000000100000005000000689599D2FA8D4940A4552DE9286D4A40689599D2FA8D494059897956D26E4A405F5FEB522390494059897956D26E4A405F5FEB5223904940A4552DE9286D4A40689599D2FA8D4940A4552DE9286D4A40
17861	Верхняя Домашка	7	72	1496	50.652990000000003	50.681851999999999	52.903522000000002	52.885843999999999	0103000020E61000000100000005000000BA4E232D95534940CDAD105663714A40BA4E232D95534940B79BE09BA6734A40295B24ED46574940B79BE09BA6734A40295B24ED46574940CDAD105663714A40BA4E232D95534940CDAD105663714A40
17971	Верхнесъезжее	7	72	1496	51.218882999999998	51.242617000000003	52.751268000000003	52.733975000000001	0103000020E610000001000000050000003F53AF5B049C4940728A8EE4F25D4A403F53AF5B049C49400344C18C29604A40113AE8120E9F49400344C18C29604A40113AE8120E9F4940728A8EE4F25D4A403F53AF5B049C4940728A8EE4F25D4A40
45694	Богдановка	7	72	1496	50.722771000000002	50.790728000000001	52.729984000000002	52.682977000000001	0103000020E61000000100000005000000A5BF97C2835C4940C97553CA6B574A40A5BF97C2835C4940384D9F1D705D4A4008043A9336654940384D9F1D705D4A4008043A9336654940C97553CA6B574A40A5BF97C2835C4940C97553CA6B574A40
17687	Бариновка	7	72	1496	50.808487999999997	50.847825	52.928733000000001	52.911423999999997	0103000020E61000000100000005000000AE9AE7887C6749400E65A88AA9744A40AE9AE7887C674940A5DB12B9E0764A4098DD9387856C4940A5DB12B9E0764A4098DD9387856C49400E65A88AA9744A40AE9AE7887C6749400E65A88AA9744A40
28559	Шилан	7	72	460	50.607148000000002	50.627397000000002	53.505164000000001	53.476953000000002	0103000020E6100000010000000500000079EA9106B74D4940535DC0CB0CBD4A4079EA9106B74D4940EB8EC536A9C04A40E44D7E8B4E504940EB8EC536A9C04A40E44D7E8B4E504940535DC0CB0CBD4A4079EA9106B74D4940535DC0CB0CBD4A40
28648	Чапаево	7	72	460	50.693269999999998	50.708074000000003	53.471415999999998	53.458469999999998	0103000020E6100000010000000500000022A64412BD5849403B191C25AFBA4A4022A64412BD584940D367075C57BC4A40EF92382BA25A4940D367075C57BC4A40EF92382BA25A49403B191C25AFBA4A4022A64412BD5849403B191C25AFBA4A40
28369	Хорошенькое	7	72	460	50.582247000000002	50.612124999999999	53.555276999999997	53.534126999999998	0103000020E61000000100000005000000D998D711874A49408E7406465EC44A40D998D711874A4940499C155113C74A403108AC1C5A4E4940499C155113C74A403108AC1C5A4E49408E7406465EC44A40D998D711874A49408E7406465EC44A40
28204	Хилково	7	72	460	50.932707000000001	50.982159000000003	53.488055000000003	53.464506999999998	0103000020E6100000010000000500000009E066F162774940ACE122F774BB4A4009E066F1627749401CD3139678BE4A406D3CD862B77D49401CD3139678BE4A406D3CD862B77D4940ACE122F774BB4A4009E066F162774940ACE122F774BB4A40
27118	Угловой	7	72	460	50.377315000000003	50.393143000000002	53.550440999999999	53.543528999999999	0103000020E6100000010000000500000027A5A0DB4B304940BBB6B75B92C54A4027A5A0DB4B30494053B0C6D974C64A405FD383825232494053B0C6D974C64A405FD3838252324940BBB6B75B92C54A4027A5A0DB4B304940BBB6B75B92C54A40
28284	Тростянка	7	72	460	50.792174000000003	50.814390000000003	53.523330999999999	53.504789000000002	0103000020E61000000100000005000000EA5E27F565654940B6300BED9CC04A40EA5E27F565654940D2FD9C82FCC24A40401878EE3D684940D2FD9C82FCC24A40401878EE3D684940B6300BED9CC04A40EA5E27F565654940B6300BED9CC04A40
28110	Старый Буян	7	72	460	50.214387000000002	50.258521000000002	53.653159000000002	53.634824000000002	0103000020E6100000010000000500000002D88008711B4940A35BAFE941D14A4002D88008711B4940460BD0B69AD34A40242A543717214940460BD0B69AD34A40242A543717214940A35BAFE941D14A4002D88008711B4940A35BAFE941D14A40
4429	Старосемейкино	7	72	460	50.251092	50.287796999999998	53.417425000000001	53.404322999999998	0103000020E61000000100000005000000C4245CC823204940A30227DBC0B34A40C4245CC82320494033C4B12E6EB54A4086713788D624494033C4B12E6EB54A4086713788D6244940A30227DBC0B34A40C4245CC823204940A30227DBC0B34A40
28155	Старая Бинарадка	7	72	460	49.940705999999999	49.985343999999998	53.600543999999999	53.569242000000003	0103000020E610000001000000050000005393E00D69F848403CC1FEEBDCC84A405393E00D69F848408EE733A0DECC4A40A8A78FC01FFE48408EE733A0DECC4A40A8A78FC01FFE48403CC1FEEBDCC84A405393E00D69F848403CC1FEEBDCC84A40
28558	Светлый Ключ	7	72	460	50.752468999999998	50.781331999999999	53.585948999999999	53.563823999999997	0103000020E610000001000000050000007D2079E750604940965984622BC84A407D2079E750604940DC0F786000CB4A40BDA8DDAF02644940DC0F786000CB4A40BDA8DDAF02644940965984622BC84A407D2079E750604940965984622BC84A40
27896	Светлое Поле	7	72	460	50.252124999999999	50.265663000000004	53.505828000000001	53.495950999999998	0103000020E6100000010000000500000083C0CAA14520494091B586527BBF4A4083C0CAA14520494057B3CEF8BEC04A40EE60C43E0122494057B3CEF8BEC04A40EE60C43E0122494091B586527BBF4A4083C0CAA14520494091B586527BBF4A40
26753	Русская Селитьба	7	72	460	50.638418999999999	50.660651999999999	53.779553999999997	53.759027000000003	0103000020E610000001000000050000009012BBB6B7514940F8E3F6CB27E14A409012BBB6B7514940A5BBEB6CC8E34A40BC04A73E90544940A5BBEB6CC8E34A40BC04A73E90544940F8E3F6CB27E14A409012BBB6B7514940F8E3F6CB27E14A40
55858	Рощинский	7	72	460	49.826988999999998	51.024084000000002	53.841599000000002	53.318596999999997	0103000020E610000001000000050000006C938AC6DAE9484046CD57C9C7A84A406C938AC6DAE9484054AC1A84B9EB4A40AE2D3C2F1583494054AC1A84B9EB4A40AE2D3C2F1583494046CD57C9C7A84A406C938AC6DAE9484046CD57C9C7A84A40
4851	Новый Буян	7	72	460	50.019227999999998	50.074151000000001	53.697114999999997	53.669673000000003	0103000020E610000001000000050000007095271076024940D20149D8B7D54A407095271076024940884677103BD94A409CFBABC77D094940884677103BD94A409CFBABC77D094940D20149D8B7D54A407095271076024940D20149D8B7D54A40
27847	Новоурайкино	7	72	460	50.032046999999999	50.047902000000001	53.794943000000004	53.769390000000001	0103000020E61000000100000005000000AB77B81D1A0449404AEF1B5F7BE24A40AB77B81D1A044940929735B1C0E54A40DDB419A721064940929735B1C0E54A40DDB419A7210649404AEF1B5F7BE24A40AB77B81D1A0449404AEF1B5F7BE24A40
27331	Новосемейкино	7	72	460	50.317981000000003	50.369706000000001	53.387720999999999	53.363509999999998	0103000020E61000000100000005000000ECDFF599B32849406DE2E47E87AE4A40ECDFF599B3284940787C7BD7A0B14A404791B586522F4940787C7BD7A0B14A404791B586522F49406DE2E47E87AE4A40ECDFF599B32849406DE2E47E87AE4A40
46388	Николаевка	7	72	460	50.136611000000002	50.151667000000003	53.660342	53.650132999999997	0103000020E610000001000000050000000EA320787C1149407286E28E37D34A400EA320787C1149406E162F1686D44A40F47002D3691349406E162F1686D44A40F47002D3691349407286E28E37D34A400EA320787C1149407286E28E37D34A40
27956	Молгачи	7	72	460	50.098235000000003	50.123891	53.561616000000001	53.522806000000003	0103000020E610000001000000050000004A29E8F6920C49408813984EEBC24A404A29E8F6920C494086747808E3C74A4066A208A9DB0F494086747808E3C74A4066A208A9DB0F49408813984EEBC24A404A29E8F6920C49408813984EEBC24A40
4761	Мирный	7	72	460	50.252943000000002	50.286127	53.515192999999996	53.501758000000002	0103000020E610000001000000050000004660AC6F60204940D1402C9B39C04A404660AC6F6020494066101FD8F1C14A4055C03DCF9F24494066101FD8F1C14A4055C03DCF9F244940D1402C9B39C04A404660AC6F60204940D1402C9B39C04A40
28021	Малая Царевщина	7	72	460	50.16816	50.186584000000003	53.451393000000003	53.437154	0103000020E61000000100000005000000683F52448615494065A88AA9F4B74A40683F5244861549405952EE3EC7B94A407BFA08FCE11749405952EE3EC7B94A407BFA08FCE117494065A88AA9F4B74A40683F52448615494065A88AA9F4B74A40
27195	Малая Каменка	7	72	460	50.379533000000002	50.400976	53.630792	53.616405	0103000020E610000001000000050000005B608F8994304940A20BEA5BE6CE4A405B608F89943049400A4AD1CABDD04A408E3D7B2E533349400A4AD1CABDD04A408E3D7B2E53334940A20BEA5BE6CE4A405B608F8994304940A20BEA5BE6CE4A40
28426	Лопатино	7	72	460	50.615349999999999	50.634430000000002	53.626820000000002	53.616036999999999	0103000020E61000000100000005000000FBCBEEC9C34E49401F10E84CDACE4A40FBCBEEC9C34E4940473D44A33BD04A40F7CC920035514940473D44A33BD04A40F7CC9200355149401F10E84CDACE4A40FBCBEEC9C34E49401F10E84CDACE4A40
28385	Кривое Озеро	7	72	460	50.498282000000003	50.524863000000003	53.571396	53.560946999999999	0103000020E61000000100000005000000BE175FB4C73F494008E57D1CCDC74A40BE175FB4C73F494059880E8123C94A40B3F0F5B52E43494059880E8123C94A40B3F0F5B52E43494008E57D1CCDC74A40BE175FB4C73F494008E57D1CCDC74A40
4705	Красный Яр	7	72	460	50.378132000000001	50.406689	53.512377000000001	53.476979	0103000020E6100000010000000500000019C91EA1663049407CF0DAA50DBD4A4019C91EA1663049407E1CCD9195C14A404C5299620E3449407E1CCD9195C14A404C5299620E3449407CF0DAA50DBD4A4019C91EA1663049407CF0DAA50DBD4A40
28479	Конезавод	7	72	460	50.641931	50.663328999999997	53.589765	53.581159	0103000020E61000000100000005000000F0A485CB2A5249405663096B63CA4A40F0A485CB2A524940A8A9656B7DCB4A4083BEF4F6E7544940A8A9656B7DCB4A4083BEF4F6E75449405663096B63CA4A40F0A485CB2A5249405663096B63CA4A40
26844	Коммунарский	7	72	460	50.310121000000002	50.332515999999998	53.744950000000003	53.731316	0103000020E61000000100000005000000C366800BB227494051853FC39BDD4A40C366800BB2274940DE9387855ADF4A40C8B260E28F2A4940DE9387855ADF4A40C8B260E28F2A494051853FC39BDD4A40C366800BB227494051853FC39BDD4A40
28026	Колодинка	7	72	460	50.195504	50.237113999999998	53.542752999999998	53.524470999999998	0103000020E610000001000000050000005C1E6B4606194940A759A0DD21C34A405C1E6B4606194940276728EE78C54A403DB665C0591E4940276728EE78C54A403DB665C0591E4940A759A0DD21C34A405C1E6B4606194940A759A0DD21C34A40
26933	Калиновка	7	72	460	50.227386000000003	50.268932999999997	53.749583000000001	53.737239000000002	0103000020E61000000100000005000000BDC804FC1A1D4940FA2AF9D85DDE4A40BDC804FC1A1D49409C51F355F2DF4A4057E883656C2249409C51F355F2DF4A4057E883656C224940FA2AF9D85DDE4A40BDC804FC1A1D4940FA2AF9D85DDE4A40
28101	Екатериновка	7	72	460	50.291795	50.311763999999997	53.593719999999998	53.581201999999998	0103000020E610000001000000050000007311DF8959254940552FBFD364CA4A407311DF8959254940957D5704FFCB4A40FA08FCE1E7274940957D5704FFCB4A40FA08FCE1E7274940552FBFD364CA4A407311DF8959254940552FBFD364CA4A40
5213	Волжский	7	72	460	50.088766999999997	50.134383	53.442726	53.422345999999997	0103000020E6100000010000000500000065FB90B75C0B494057CC086F0FB64A4065FB90B75C0B4940618BDD3EABB84A40B6114F7633114940618BDD3EABB84A40B6114F763311494057CC086F0FB64A4065FB90B75C0B494057CC086F0FB64A40
2681	Водино	7	72	460	50.403931999999998	50.431877999999998	53.383547999999998	53.371344000000001	0103000020E6100000010000000500000068E7340BB43349406DC83F3388AF4A4068E7340BB43349401D39D21918B14A4052EE3EC7473749401D39D21918B14A4052EE3EC7473749406DC83F3388AF4A4068E7340BB43349406DC83F3388AF4A40
26659	Большая Раковка	7	72	460	50.598883999999998	50.643396000000003	53.701956000000003	53.683934999999998	0103000020E61000000100000005000000800C1D3BA84C49407DCB9C2E8BD74A40800C1D3BA84C4940919DB7B1D9D94A404930D5CC5A524940919DB7B1D9D94A404930D5CC5A5249407DCB9C2E8BD74A40800C1D3BA84C49407DCB9C2E8BD74A40
26654	Большая Каменка	7	72	460	50.481627000000003	50.528357	53.681690000000003	53.650795000000002	0103000020E6100000010000000500000070EF1AF4A53D49403EB324404DD34A4070EF1AF4A53D49405001309E41D74A406CCEC133A14349405001309E41D74A406CCEC133A14349403EB324404DD34A4070EF1AF4A53D49403EB324404DD34A40
24233	Береза	7	72	460	50.132064999999997	50.154370999999998	53.525221000000002	53.514052999999997	0103000020E610000001000000050000001EF98381E710494091B41B7DCCC14A401EF98381E7104940121615713AC34A40B439CE6DC2134940121615713AC34A40B439CE6DC213494091B41B7DCCC14A401EF98381E710494091B41B7DCCC14A40
47750	Белозерка	7	72	460	50.351165000000002	50.371988000000002	53.449483999999998	53.429659000000001	0103000020E61000000100000005000000FB3F87F9F22C49404EB7EC10FFB64A40FB3F87F9F22C4940A20914B188B94A409240834D9D2F4940A20914B188B94A409240834D9D2F49404EB7EC10FFB64A40FB3F87F9F22C49404EB7EC10FFB64A40
46604	Алексеевка	7	72	460	50.406671000000003	50.417236000000003	53.782283	53.777175	0103000020E61000000100000005000000A69D9ACB0D34494068226C787AE34A40A69D9ACB0D344940BF9B6ED921E44A40605B3FFD67354940BF9B6ED921E44A40605B3FFD6735494068226C787AE34A40A69D9ACB0D34494068226C787AE34A40
55881	Управленческий	7	72	7380	50.132083000000002	50.328409999999998	53.396335000000001	53.264254000000001	0103000020E61000000100000005000000C5AD8218E810494029EB3713D3A14A40C5AD8218E81049404DA1F31ABBB24A40F5D6C056092A49404DA1F31ABBB24A40F5D6C056092A494029EB3713D3A14A40C5AD8218E810494029EB3713D3A14A40
55854	Красная Глинка	7	72	7380	50.132083000000002	50.328409999999998	53.396335000000001	53.264254000000001	0103000020E61000000100000005000000C5AD8218E810494029EB3713D3A14A40C5AD8218E81049404DA1F31ABBB24A40F5D6C056092A49404DA1F31ABBB24A40F5D6C056092A494029EB3713D3A14A40C5AD8218E810494029EB3713D3A14A40
17668	Чапаевский	7	72	455	49.834147999999999	49.866531999999999	52.897922000000001	52.884045999999998	0103000020E610000001000000050000000C03965CC5EA48406E14596B28714A400C03965CC5EA4840F12DAC1BEF724A40FF774485EAEE4840F12DAC1BEF724A40FF774485EAEE48406E14596B28714A400C03965CC5EA48406E14596B28714A40
17372	Софинский	7	72	455	50.197372999999999	50.201459999999997	52.640991	52.633432999999997	0103000020E61000000100000005000000840EBA8443194940849A215514514A40840EBA8443194940E2033BFE0B524A40E0B9F770C9194940E2033BFE0B524A40E0B9F770C9194940849A215514514A40840EBA8443194940849A215514514A40
16970	Павловка	7	72	455	49.710135999999999	49.731712999999999	52.674815000000002	52.658382000000003	0103000020E610000001000000050000002BDB87BCE5DA4840362383DC45544A402BDB87BCE5DA4840D5EC815660564A406E8786C5A8DD4840D5EC815660564A406E8786C5A8DD4840362383DC45544A402BDB87BCE5DA4840362383DC45544A40
48263	Новопавловка	7	72	455	49.868895000000002	49.884292000000002	52.756031999999998	52.745403000000003	0103000020E6100000010000000500000037548CF337EF48408FAB915D695F4A4037548CF337EF48405F5D15A8C5604A40A60EF27A30F148405F5D15A8C5604A40A60EF27A30F148408FAB915D695F4A4037548CF337EF48408FAB915D695F4A40
17416	Новая-Вязовка	7	72	455	50.303455	50.316102999999998	52.714934999999997	52.708360999999996	0103000020E6100000010000000500000062670A9DD72649408461C092AB5A4A4062670A9DD726494004E275FD825B4A40709527107628494004E275FD825B4A4070952710762849408461C092AB5A4A4062670A9DD72649408461C092AB5A4A40
16673	Медведевский	7	72	455	49.894506	49.915877000000002	52.600966999999997	52.590009999999999	0103000020E61000000100000005000000B309302C7FF248400F289B72854B4A40B309302C7FF24840D47C957CEC4C4A404D1421753BF54840D47C957CEC4C4A404D1421753BF548400F289B72854B4A40B309302C7FF248400F289B72854B4A40
16362	Любицкий	7	72	455	50.024348000000003	50.034939999999999	52.780861000000002	52.769889999999997	0103000020E610000001000000050000008CDCD3D51D0349403BC269C18B624A408CDCD3D51D03494066DCD440F3634A403FA9F6E97804494066DCD440F3634A403FA9F6E9780449403BC269C18B624A408CDCD3D51D0349403BC269C18B624A40
16670	Любимовка	7	72	455	49.785854999999998	49.798304999999999	52.508000000000003	52.498286	0103000020E61000000100000005000000F4328AE596E44840FF06EDD5C73F4A40F4328AE596E448401B2FDD2406414A40DC9DB5DB2EE648401B2FDD2406414A40DC9DB5DB2EE64840FF06EDD5C73F4A40F4328AE596E44840FF06EDD5C73F4A40
17259	Ленинский	7	72	455	50.118582000000004	50.153759999999998	52.753546999999998	52.733392000000002	0103000020E6100000010000000500000078F2E9B12D0F4940F392FFC9DF5D4A4078F2E9B12D0F4940DC7F643A74604A406BB75D68AE134940DC7F643A74604A406BB75D68AE134940F392FFC9DF5D4A4078F2E9B12D0F4940F392FFC9DF5D4A40
16792	Куйбышевский	7	72	455	49.588118000000001	49.617168999999997	52.660113000000003	52.641953000000001	0103000020E610000001000000050000002F185C7347CB4840D84812842B524A402F185C7347CB48400D5531957E544A40718DCF64FFCE48400D5531957E544A40718DCF64FFCE4840D84812842B524A402F185C7347CB4840D84812842B524A40
16884	Криволучье-Ивановка	7	72	455	49.531253999999997	49.577148999999999	52.751699000000002	52.733238999999998	0103000020E6100000010000000500000041EF8D2100C448406C938AC6DA5D4A4041EF8D2100C44840CCB73EAC37604A40A5F5B704E0C94840CCB73EAC37604A40A5F5B704E0C948406C938AC6DA5D4A4041EF8D2100C448406C938AC6DA5D4A40
16208	Красноармейское	7	72	455	50.013461	50.045054999999998	52.731940999999999	52.697868	0103000020E61000000100000005000000BF620D17B9014940647616BD53594A40BF620D17B9014940FFCC203EB05D4A40B9C2BB5CC4054940FFCC203EB05D4A40B9C2BB5CC4054940647616BD53594A40BF620D17B9014940647616BD53594A40
17263	Кочетковский	7	72	455	50.203400999999999	50.214064	52.720657000000003	52.715093000000003	0103000020E61000000100000005000000A27C410B091A49409D4CDC2A885B4A40A27C410B091A49401651137D3E5C4A401FA0FB72661B49401651137D3E5C4A401FA0FB72661B49409D4CDC2A885B4A40A27C410B091A49409D4CDC2A885B4A40
17574	Колывань	7	72	455	50.000461999999999	50.047848000000002	52.928733000000001	52.904147000000002	0103000020E61000000100000005000000047289230F00494065E3C116BB734A40047289230F004940A5DB12B9E0764A40EA961DE21F064940A5DB12B9E0764A40EA961DE21F06494065E3C116BB734A40047289230F00494065E3C116BB734A40
17075	Колыбеловка	7	72	455	49.902096999999998	49.917979000000003	52.679018999999997	52.667485999999997	0103000020E61000000100000005000000EC681CEA77F34840D844662E70554A40EC681CEA77F348406A2E3718EA564A4018B5FB5580F548406A2E3718EA564A4018B5FB5580F54840D844662E70554A40EC681CEA77F34840D844662E70554A40
16777	Колокольцовка	7	72	455	49.801414000000001	49.817529	52.603400999999998	52.587395000000001	0103000020E610000001000000050000003D47E4BB94E64840BE6A65C22F4B4A403D47E4BB94E64840D5AF743E3C4D4A400B444FCAA4E84840D5AF743E3C4D4A400B444FCAA4E84840BE6A65C22F4B4A403D47E4BB94E64840BE6A65C22F4B4A40
17064	Кировский	7	72	455	49.835692999999999	49.861403000000003	52.680089000000002	52.667869000000003	0103000020E61000000100000005000000813FFCFCF7EA484091813CBB7C554A40813FFCFCF7EA484047AF06280D574A4091D6187442EE484047AF06280D574A4091D6187442EE484091813CBB7C554A40813FFCFCF7EA484091813CBB7C554A40
17565	Каменный Брод	7	72	455	49.953274	49.982486999999999	52.902365000000003	52.881034999999997	0103000020E610000001000000050000004510E7E104FA4840D0D03FC1C5704A404510E7E104FA48400C0742B280734A4061DF4E22C2FD48400C0742B280734A4061DF4E22C2FD4840D0D03FC1C5704A404510E7E104FA4840D0D03FC1C5704A40
16515	Дубовка	7	72	455	50.061017999999997	50.075490000000002	52.554867000000002	52.541406000000002	0103000020E61000000100000005000000D13B1570CF074940D9EDB3CA4C454A40D13B1570CF0749409850C1E105474A40689604A8A90949409850C1E105474A40689604A8A9094940D9EDB3CA4C454A40D13B1570CF074940D9EDB3CA4C454A40
17469	Дергачи	7	72	455	50.023063999999998	50.049087999999998	52.905624000000003	52.887403999999997	0103000020E6100000010000000500000083DBDAC2F3024940772B4B7496714A4083DBDAC2F3024940823CBB7CEB734A402250FD8348064940823CBB7CEB734A402250FD8348064940772B4B7496714A4083DBDAC2F3024940772B4B7496714A40
16967	Гражданский	7	72	455	49.674382999999999	49.712040000000002	52.783579000000003	52.765802999999998	0103000020E610000001000000050000003BFDA02E52D64840DF162CD505624A403BFDA02E52D648408C6A11514C644A40D0B8702024DB48408C6A11514C644A40D0B8702024DB4840DF162CD505624A403BFDA02E52D64840DF162CD505624A40
16464	Волчанка	7	72	455	49.966856	49.995989000000002	52.569609	52.540311000000003	0103000020E610000001000000050000007FF8F9EFC1FB4840A4552DE928454A407FF8F9EFC1FB4840EE409DF2E8484A407F164B917CFF4840EE409DF2E8484A407F164B917CFF4840A4552DE928454A407FF8F9EFC1FB4840A4552DE928454A40
17118	Братский	7	72	455	49.921500000000002	49.939304999999997	52.780468999999997	52.765546999999998	0103000020E61000000100000005000000CBA145B6F3F548408446B071FD614A40CBA145B6F3F548405A457F68E6634A4011FC6F253BF848405A457F68E6634A4011FC6F253BF848408446B071FD614A40CBA145B6F3F548408446B071FD614A40
16474	Арсентьевка	7	72	455	49.990734000000003	50.008709000000003	52.634115999999999	52.619701999999997	0103000020E610000001000000050000008484285FD0FE484005A22765524F4A408484285FD0FE484067EF8CB62A514A40271763601D01494067EF8CB62A514A40271763601D01494005A22765524F4A408484285FD0FE484005A22765524F4A40
2624	Андросовка	7	72	455	49.563746000000002	49.608077999999999	52.699657999999999	52.675185999999997	0103000020E610000001000000050000001BA034D428C84840C85BAE7E6C564A401BA034D428C848404031B2648E594A4063B5F97FD5CD48404031B2648E594A4063B5F97FD5CD4840C85BAE7E6C564A401BA034D428C84840C85BAE7E6C564A40
16584	Алексеевский	7	72	455	49.827429000000002	49.839762999999998	52.538487000000003	52.528215000000003	0103000020E6100000010000000500000089618731E9E94840DA20938C9C434A4089618731E9E948401C295B24ED444A4007B29E5A7DEB48401C295B24ED444A4007B29E5A7DEB4840DA20938C9C434A4089618731E9E94840DA20938C9C434A40
13628	Ягодный	7	72	392	50.369140000000002	50.375571999999998	54.184271000000003	54.178876000000002	0103000020E610000001000000050000009ED2C1FA3F2F49400805A568E5164B409ED2C1FA3F2F4940F54C2F3196174B408BA548BE12304940F54C2F3196174B408BA548BE123049400805A568E5164B409ED2C1FA3F2F49400805A568E5164B40
14717	Юмратка	7	72	392	50.331662000000001	50.353554000000003	54.433987999999999	54.420160000000003	0103000020E61000000100000005000000B9A981E6732A49402F8B89CDC7354B40B9A981E6732A4940A06D35EB8C374B405CAFE941412D4940A06D35EB8C374B405CAFE941412D49402F8B89CDC7354B40B9A981E6732A49402F8B89CDC7354B40
13873	Шпановка	7	72	392	50.667200999999999	50.679175000000001	54.197226000000001	54.175491999999998	0103000020E61000000100000005000000E36DA5D766554940D55A988576164B40E36DA5D766554940E0F599B33E194B4062A1D634EF564940E0F599B33E194B4062A1D634EF564940D55A988576164B40E36DA5D766554940D55A988576164B40
13681	Четыровка	7	72	392	50.407407999999997	50.426659000000001	54.107030999999999	54.092834000000003	0103000020E610000001000000050000007B1002F2253449407BFA08FCE10B4B407B1002F2253449403F541A31B30D4B40A4C519C39C3649403F541A31B30D4B40A4C519C39C3649407BFA08FCE10B4B407B1002F2253449407BFA08FCE10B4B40
14063	Тенеево	7	72	392	50.621045000000002	50.647204000000002	54.332191999999999	54.312432000000001	0103000020E61000000100000005000000132C0E677E4F4940A81C93C5FD274B40132C0E677E4F494015FF7744852A4B4092EBA694D752494015FF7744852A4B4092EBA694D7524940A81C93C5FD274B40132C0E677E4F4940A81C93C5FD274B40
14731	Степная Шентала	7	72	392	50.312779999999997	50.335183999999998	54.320734999999999	54.306874999999998	0103000020E61000000100000005000000E36BCF2C09284940E17A14AE47274B40E36BCF2C092849405ED72FD80D294B403C122F4FE72A49405ED72FD80D294B403C122F4FE72A4940E17A14AE47274B40E36BCF2C09284940E17A14AE47274B40
14537	Старое Юреево	7	72	392	50.299179000000002	50.315834000000002	54.390949999999997	54.369204000000003	0103000020E6100000010000000500000033535A7F4B264940B5C6A013422F4B4033535A7F4B264940832F4CA60A324B40817B9E3F6D284940832F4CA60A324B40817B9E3F6D284940B5C6A013422F4B4033535A7F4B264940B5C6A013422F4B40
14832	Старое Фейзуллово	7	72	392	50.296968999999997	50.321537999999997	54.344422999999999	54.329158	0103000020E610000001000000050000008176871403264940BF9B6ED9212A4B408176871403264940BF7E880D162C4B40EB353D2828294940BF7E880D162C4B40EB353D2828294940BF9B6ED9212A4B408176871403264940BF9B6ED9212A4B40
7078	Старое Максимкино	7	72	392	50.340707999999999	50.381715999999997	54.484121000000002	54.461461999999997	0103000020E6100000010000000500000027BEDA519C2B4940622CD32F113B4B4027BEDA519C2B494046274BADF73D4B40122EE411DC30494046274BADF73D4B40122EE411DC304940622CD32F113B4B4027BEDA519C2B4940622CD32F113B4B40
14626	Старая Кармала	7	72	392	50.281824	50.313237999999998	54.419694	54.402261000000003	0103000020E610000001000000050000002C9D0FCF1224494067BAD7497D334B402C9D0FCF12244940E9297288B8354B40A6EECA2E18284940E9297288B8354B40A6EECA2E1828494067BAD7497D334B402C9D0FCF1224494067BAD7497D334B40
13970	Старая Ивановка	7	72	392	50.785283999999997	50.831817000000001	54.160907999999999	54.152392999999996	0103000020E610000001000000050000003909A52F84644940D591239D81134B403909A52F8464494017D522A298144B40E0A0BDFA786A494017D522A298144B40E0A0BDFA786A4940D591239D81134B403909A52F84644940D591239D81134B40
14054	Русская Васильевка	7	72	392	50.686748000000001	50.733479000000003	54.312553000000001	54.287202000000001	0103000020E61000000100000005000000F54BC45BE757494043ACFE08C3244B40F54BC45BE757494023A298BC01284B40C2A6CEA3E25D494023A298BC01284B40C2A6CEA3E25D494043ACFE08C3244B40F54BC45BE757494043ACFE08C3244B40
13856	Рахмановка	7	72	392	50.548955999999997	50.568548	54.110610000000001	54.091931000000002	0103000020E61000000100000005000000B378B130444649408A3E1F65C40B4B40B378B13044464940274EEE77280E4B40651A4D2EC6484940274EEE77280E4B40651A4D2EC64849408A3E1F65C40B4B40B378B130444649408A3E1F65C40B4B40
13481	Погрузная	7	72	392	50.427619999999997	50.469912999999998	54.242694	54.216462	0103000020E61000000100000005000000C98E8D40BC364940D369DD06B51B4B40C98E8D40BC364940BC77D498101F4B408D7BF31B263C4940BC77D498101F4B408D7BF31B263C4940D369DD06B51B4B40C98E8D40BC364940D369DD06B51B4B40
13489	Орловка	7	72	392	50.294336999999999	50.337546000000003	54.194397000000002	54.177289000000002	0103000020E610000001000000050000005A80B6D5AC2549406478EC67B1164B405A80B6D5AC25494063B83A00E2184B40A47213B5342B494063B83A00E2184B40A47213B5342B49406478EC67B1164B405A80B6D5AC2549406478EC67B1164B40
14149	Новое Фейзуллово	7	72	392	50.627675000000004	50.653744000000003	54.274697000000003	54.261394000000003	0103000020E6100000010000000500000027C286A75750494071AFCC5B75214B4027C286A75750494098A7734529234B4066FA25E2AD53494098A7734529234B4066FA25E2AD53494071AFCC5B75214B4027C286A75750494071AFCC5B75214B40
14484	Новая Кармала	7	72	392	50.312699000000002	50.334617999999999	54.401040000000002	54.370671999999999	0103000020E61000000100000005000000F73E5585062849407EC51A2E722F4B40F73E558506284940A5315A4755334B4093533BC3D42A4940A5315A4755334B4093533BC3D42A49407EC51A2E722F4B40F73E5585062849407EC51A2E722F4B40
13771	Нижняя Быковка	7	72	392	50.683064999999999	50.707014000000001	54.119929999999997	54.094613000000003	0103000020E61000000100000005000000680586AC6E57494063635E471C0C4B40680586AC6E57494096E7C1DD590F4B4036E84B6F7F5A494096E7C1DD590F4B4036E84B6F7F5A494063635E471C0C4B40680586AC6E57494063635E471C0C4B40
13590	Надеждино	7	72	392	50.339675	50.392882	54.139541000000001	54.092934	0103000020E6100000010000000500000068226C787A2B4940DE57E542E50B4B4068226C787A2B4940BFB9BF7ADC114B40F29716F549324940BFB9BF7ADC114B40F29716F549324940DE57E542E50B4B4068226C787A2B4940DE57E542E50B4B40
14622	Моховой	7	72	392	50.245010999999998	50.266497999999999	54.396779000000002	54.382016	0103000020E6100000010000000500000083143C855C1F49403D4679E6E5304B4083143C855C1F4940AB5E7EA7C9324B408639419B1C224940AB5E7EA7C9324B408639419B1C2249403D4679E6E5304B4083143C855C1F49403D4679E6E5304B40
14156	Мамыково	7	72	392	50.721269999999997	50.749890999999998	54.382755000000003	54.366785	0103000020E61000000100000005000000FFCA4A93525C4940E9D495CFF22E4B40FFCA4A93525C4940B4B0A71DFE304B404948A46DFC5F4940B4B0A71DFE304B404948A46DFC5F4940E9D495CFF22E4B40FFCA4A93525C4940E9D495CFF22E4B40
14447	Малое Максимкино	7	72	392	50.310910999999997	50.343313000000002	54.452956999999998	54.439695999999998	0103000020E61000000100000005000000BB7B80EECB2749404C1762F547384B40BB7B80EECB27494044BFB67EFA394B4055A52DAEF12B494044BFB67EFA394B4055A52DAEF12B49404C1762F547384B40BB7B80EECB2749404C1762F547384B40
13916	Левый Салаван	7	72	392	50.532786000000002	50.550266999999998	54.206373999999997	54.197040999999999	0103000020E6100000010000000500000022E2E654324449404E7CB5A338194B4022E2E65432444940525F96766A1A4B40B58828266F464940525F96766A1A4B40B58828266F4649404E7CB5A338194B4022E2E654324449404E7CB5A338194B40
13581	Красновка	7	72	392	50.291677999999997	50.315313000000003	54.154823999999998	54.143490999999997	0103000020E61000000100000005000000397B67B4552549409A22C0E95D124B40397B67B4552549406551D845D1134B407880272D5C2849406551D845D1134B407880272D5C2849409A22C0E95D124B40397B67B4552549409A22C0E95D124B40
7069	Кошки	7	72	392	50.440232999999999	50.499063	54.220410999999999	54.185735999999999	0103000020E610000001000000050000005BCF108E593849404DD87E32C6174B405BCF108E59384940DE567A6D361C4B4063D2DF4BE13F4940DE567A6D361C4B4063D2DF4BE13F49404DD87E32C6174B405BCF108E593849404DD87E32C6174B40
14254	Залесье	7	72	392	50.542012	50.562269000000001	54.259011000000001	54.244272000000002	0103000020E61000000100000005000000100533A6604549400DAA0D4E441F4B40100533A660454940F226BF4527214B40FE463B6EF8474940F226BF4527214B40FE463B6EF84749400DAA0D4E441F4B40100533A6604549400DAA0D4E441F4B40
14338	Ерандаево	7	72	392	50.419849999999997	50.438651	54.392166000000003	54.379944000000002	0103000020E61000000100000005000000E09C11A5BD354940DD274701A2304B40E09C11A5BD354940344DD87E32324B40C9AD49B725384940344DD87E32324B40C9AD49B725384940DD274701A2304B40E09C11A5BD354940DD274701A2304B40
55952	Городок	7	72	392	50.349494	50.375912999999997	54.275374999999997	54.262051	0103000020E61000000100000005000000F9122A38BC2C49402A711DE38A214B40F9122A38BC2C49406891ED7C3F234B401492CCEA1D3049406891ED7C3F234B401492CCEA1D3049402A711DE38A214B40F9122A38BC2C49402A711DE38A214B40
14337	Большое Ермаково	7	72	392	50.428868999999999	50.472544999999997	54.358029999999999	54.343834999999999	0103000020E6100000010000000500000055A2EC2DE53649402E1C08C9022C4B4055A2EC2DE5364940527E52EDD32D4B40B471C45A7C3C4940527E52EDD32D4B40B471C45A7C3C49402E1C08C9022C4B4055A2EC2DE53649402E1C08C9022C4B40
14203	Большая Романовка	7	72	392	50.463076999999998	50.495047999999997	54.301620999999997	54.269460000000002	0103000020E61000000100000005000000D0436D1B463B494043CA4FAA7D224B40D0436D1B463B4940B66455849B264B40A0F99CBB5D3F4940B66455849B264B40A0F99CBB5D3F494043CA4FAA7D224B40D0436D1B463B494043CA4FAA7D224B40
14908	Большая Константиновка	7	72	392	50.285075999999997	50.313021999999997	54.258496000000001	54.253498999999998	0103000020E61000000100000005000000EF6FD05E7D244940CB48BDA772204B40EF6FD05E7D244940CB129D6516214B40D976DA1A11284940CB129D6516214B40D976DA1A11284940CB48BDA772204B40EF6FD05E7D244940CB48BDA772204B40
13767	Белоозерная	7	72	392	50.454425999999998	50.468817000000001	54.144778000000002	54.133274	0103000020E61000000100000005000000DE3994A12A3A49401CB4571F0F114B40DE3994A12A3A49401497E31588124B4088670932023C49401497E31588124B4088670932023C49401CB4571F0F114B40DE3994A12A3A49401CB4571F0F114B40
55889	Андреевка	7	72	392	50.454937999999999	50.467263000000003	54.404378000000001	54.390183999999998	0103000020E6100000010000000500000094DA8B683B3A494013B69F8CF1314B4094DA8B683B3A4940679C86A8C2334B40C0D02346CF3B4940679C86A8C2334B40C0D02346CF3B494013B69F8CF1314B4094DA8B683B3A494013B69F8CF1314B40
46650	Алексеевка	7	72	392	50.221339999999998	50.245297999999998	54.342471000000003	54.332191999999999	0103000020E61000000100000005000000F8A57EDE541C494015FF7744852A4B40F8A57EDE541C49400A6AF816D62B4B4019E3C3EC651F49400A6AF816D62B4B4019E3C3EC651F494015FF7744852A4B40F8A57EDE541C494015FF7744852A4B40
13122	Чувашское Абдикеево	7	72	542	51.759534000000002	51.773665000000001	54.346617000000002	54.334912000000003	0103000020E610000001000000050000009C19FD6838E14940DC847B65DE2A4B409C19FD6838E149406B9E23F25D2C4B40A987687407E349406B9E23F25D2C4B40A987687407E34940DC847B65DE2A4B409C19FD6838E14940DC847B65DE2A4B40
48931	Черный Ключ	7	72	542	51.830438000000001	51.858339999999998	54.341341999999997	54.322510000000001	0103000020E6100000010000000500000086ADD9CA4BEA49400551F70148294B4086ADD9CA4BEA494028603B18B12B4B40A06CCA15DEED494028603B18B12B4B40A06CCA15DEED49400551F70148294B4086ADD9CA4BEA49400551F70148294B40
3840	Усакла	7	72	542	51.909714999999998	51.932189999999999	54.366622999999997	54.353292000000003	0103000020E610000001000000050000001FD7868A71F449401FF818AC382D4B401FD7868A71F449400F7BA180ED2E4B4041D47D0052F749400F7BA180ED2E4B4041D47D0052F749401FF818AC382D4B401FD7868A71F449401FF818AC382D4B40
7370	Старый Маклауш	7	72	542	52.189000999999998	52.294336999999999	54.316676000000001	54.293087999999997	0103000020E61000000100000005000000A5F44C2F31184A40CE6C57E883254B40A5F44C2F31184A40CCB6D3D688284B405A80B6D5AC254A40CCB6D3D688284B405A80B6D5AC254A40CE6C57E883254B40A5F44C2F31184A40CE6C57E883254B40
4069	Ива	7	70	463	43.945467000000001	43.987355000000001	53.705734999999997	53.671005999999998	0103000020E610000001000000050000003F390A1005F94540BBB54C86E3D54A403F390A1005F945403F52448655DA4A4063450DA661FE45403F52448655DA4A4063450DA661FE4540BBB54C86E3D54A403F390A1005F94540BBB54C86E3D54A40
12725	Старый Байтермиш	7	72	542	51.887706000000001	51.910998999999997	54.212893000000001	54.190283000000001	0103000020E61000000100000005000000433BA759A0F149400DFE7E315B184B40433BA759A0F149400F46EC13401B4B4027D87F9D9BF449400F46EC13401B4B4027D87F9D9BF449400DFE7E315B184B40433BA759A0F149400DFE7E315B184B40
12654	Старые Сосны	7	72	542	52.013299000000004	52.054406	54.151881000000003	54.139451000000001	0103000020E61000000100000005000000E60819C8B3014A407F32C687D9114B40E60819C8B3014A4020F12BD670134B40645A9BC6F6064A4020F12BD670134B40645A9BC6F6064A407F32C687D9114B40E60819C8B3014A407F32C687D9114B40
7228	Старое Семенкино	7	72	542	52.225966999999997	52.252934000000003	54.250990000000002	54.238379000000002	0103000020E61000000100000005000000D47C957CEC1C4A40CF86FC33831E4B40D47C957CEC1C4A40C0CFB87020204B40F3052D2460204A40C0CFB87020204B40F3052D2460204A40CF86FC33831E4B40D47C957CEC1C4A40CF86FC33831E4B40
7324	Старое Резяпкино	7	72	542	51.868698000000002	51.895198000000001	54.383893	54.367845000000003	0103000020E61000000100000005000000E10CFE7E31EF4940A27F828B152F4B40E10CFE7E31EF4940E814E46723314B40E9B81AD995F24940E814E46723314B40E9B81AD995F24940A27F828B152F4B40E10CFE7E31EF4940A27F828B152F4B40
13019	Русское Добрино	7	72	542	52.449511999999999	52.492263000000001	54.380668	54.341143000000002	0103000020E610000001000000050000006C94F59B89394A403221E692AA2B4B406C94F59B89394A401E51A1BAB9304B40F3035779023F4A401E51A1BAB9304B40F3035779023F4A403221E692AA2B4B406C94F59B89394A403221E692AA2B4B40
55918	Пронино	7	72	542	51.860926999999997	51.887185000000002	54.266016	54.24776	0103000020E61000000100000005000000279F1EDB32EE4940E4A08499B61F4B40279F1EDB32EE49403B1BF2CF0C224B403A4030478FF149403B1BF2CF0C224B403A4030478FF14940E4A08499B61F4B40279F1EDB32EE4940E4A08499B61F4B40
12594	Новые Сосны	7	72	542	52.036628999999998	52.06118	54.230674999999998	54.208601000000002	0103000020E61000000100000005000000E78A5242B0044A40DA740470B31A4B40E78A5242B0044A409D8026C2861D4B40AB9509BFD4074A409D8026C2861D4B40AB9509BFD4074A40DA740470B31A4B40E78A5242B0044A40DA740470B31A4B40
12496	Новое Семенкино	7	72	542	52.192711000000003	52.21622	54.237304999999999	54.216773000000003	0103000020E610000001000000050000002C4A09C1AA184A40F2D3B837BF1B4B402C4A09C1AA184A40B1169F02601E4B40DD5ED218AD1B4A40B1169F02601E4B40DD5ED218AD1B4A40F2D3B837BF1B4B402C4A09C1AA184A40F2D3B837BF1B4B40
12930	Назаровка	7	72	542	52.208646999999999	52.242145000000001	54.404798	54.391117000000001	0103000020E610000001000000050000004AB4E4F1B41A4A406FF4311F10324B404AB4E4F1B41A4A403CBEBD6BD0334B40E9F17B9BFE1E4A403CBEBD6BD0334B40E9F17B9BFE1E4A406FF4311F10324B404AB4E4F1B41A4A406FF4311F10324B40
3316	Клявлино	7	72	542	51.986834999999999	52.040832999999999	54.303297000000001	54.244602999999998	0103000020E610000001000000050000002AC6F99B50FE494072C0AE264F1F4B402AC6F99B50FE4940CAFCA36FD2264B407DCC07043A054A40CAFCA36FD2264B407DCC07043A054A4072C0AE264F1F4B402AC6F99B50FE494072C0AE264F1F4B40
48801	Ерыкла	7	72	542	52.010235999999999	52.035173	54.414188000000003	54.403565999999998	0103000020E61000000100000005000000F59ECA694F014A4086E3F90CA8334B40F59ECA694F014A40A532C51C04354B40E259828C80044A40A532C51C04354B40E259828C80044A4086E3F90CA8334B40F59ECA694F014A4086E3F90CA8334B40
3793	Ерилкино	7	72	542	52.313102999999998	52.345450999999997	54.247923	54.235348000000002	0103000020E61000000100000005000000C6A354C213284A40EA961DE21F1E4B40C6A354C213284A408E76DCF0BB1F4B406CAF05BD372C4A408E76DCF0BB1F4B406CAF05BD372C4A40EA961DE21F1E4B40C6A354C213284A40EA961DE21F1E4B40
7226	Борискино-Игар	7	72	542	51.778435000000002	51.823960999999997	54.253056999999998	54.217283999999999	0103000020E61000000100000005000000E88711C2A3E34940D7F84CF6CF1B4B40E88711C2A3E349400E83F92B64204B40F816D68D77E949400E83F92B64204B40F816D68D77E94940D7F84CF6CF1B4B40E88711C2A3E34940D7F84CF6CF1B4B40
6944	Балахоновка	7	72	542	52.421126000000001	52.442982000000001	54.425382999999997	54.403450999999997	0103000020E6100000010000000500000066BFEE74E7354A40ED444948A4334B4066BFEE74E7354A401EA33CF372364B40BC5B59A2B3384A401EA33CF372364B40BC5B59A2B3384A40ED444948A4334B4066BFEE74E7354A40ED444948A4334B40
9746	Чубовка	7	72	364	50.536181999999997	50.580126999999997	53.412309999999998	53.389519999999997	0103000020E61000000100000005000000185A9D9CA1444940A79196CADBB14A40185A9D9CA144494029E8F692C6B44A406743FE99414A494029E8F692C6B44A406743FE99414A4940A79196CADBB14A40185A9D9CA1444940A79196CADBB14A40
9481	Филипповка	7	72	364	50.971290000000003	50.986902000000001	53.209282000000002	53.194043999999998	0103000020E610000001000000050000004777103B537C494015FE0C6FD6984A404777103B537C49401CD2A8C0C99A4A40B22D03CE527E49401CD2A8C0C99A4A40B22D03CE527E494015FE0C6FD6984A404777103B537C494015FE0C6FD6984A40
55853	Усть-Кинельский	7	72	364	50.551183000000002	50.672052000000001	53.286611000000001	53.261975999999997	0103000020E610000001000000050000003B8E1F2A8D4649401F2BF86D88A14A403B8E1F2A8D46494041D653ABAFA44A400F9BC8CC0556494041D653ABAFA44A400F9BC8CC055649401F2BF86D88A14A403B8E1F2A8D4649401F2BF86D88A14A40
9268	Угорье	7	72	364	50.738903999999998	50.750591	53.231203999999998	53.219763999999998	0103000020E6100000010000000500000019710168945E4940486B0C3A219C4A4019710168945E4940295AB917989D4A4002D6AA5D13604940295AB917989D4A4002D6AA5D13604940486B0C3A219C4A4019710168945E4940486B0C3A219C4A40
9790	Сырейка	7	72	364	50.511496000000001	50.539155000000001	53.352321000000003	53.331892000000003	0103000020E61000000100000005000000750470B378414940EBE6E26F7BAA4A40750470B378414940D658C2DA18AD4A40C93CF20703454940D658C2DA18AD4A40C93CF20703454940EBE6E26F7BAA4A40750470B378414940EBE6E26F7BAA4A40
9638	Сколково	7	72	364	50.72719	50.75414	53.332326999999999	53.314030000000002	0103000020E6100000010000000500000037FDD98F145D494040FB912232A84A4037FDD98F145D4940F549EEB089AA4A407F4DD6A887604940F549EEB089AA4A407F4DD6A88760494040FB912232A84A4037FDD98F145D494040FB912232A84A40
9403	Покровка	7	72	364	50.844358	50.859853999999999	53.295057	53.270082000000002	0103000020E61000000100000005000000D80E46EC136C4940809E060C92A24A40D80E46EC136C49405ABA826DC4A54A40DAAA24B20F6E49405ABA826DC4A54A40DAAA24B20F6E4940809E060C92A24A40D80E46EC136C4940809E060C92A24A40
9356	Павловка	7	72	364	50.848759000000001	50.880488	53.276732000000003	53.258161999999999	0103000020E61000000100000005000000C4978922A46C4940F488D1730BA14A40C4978922A46C4940DBE044F46BA34A409E42AED4B3704940DBE044F46BA34A409E42AED4B3704940F488D1730BA14A40C4978922A46C4940F488D1730BA14A40
9581	Новый Сарбай	7	72	364	51.021362000000003	51.05583	53.348897000000001	53.333984000000001	0103000020E6100000010000000500000047B071FDBB82494092B1DAFCBFAA4A4047B071FDBB82494015562AA8A8AC4A405E11FC6F2587494015562AA8A8AC4A405E11FC6F2587494092B1DAFCBFAA4A4047B071FDBB82494092B1DAFCBFAA4A40
1918	Малая Малышевка	7	72	364	50.937432000000001	50.994646000000003	53.081921000000001	53.041339000000001	0103000020E61000000100000005000000A81C93C5FD7749405186AA984A854A40A81C93C5FD77494085ED27637C8A4A40728C648F507F494085ED27637C8A4A40728C648F507F49405186AA984A854A40A81C93C5FD7749405186AA984A854A40
9058	Кутулук	7	72	364	51.191034999999999	51.208975000000002	53.192068999999996	53.185578	0103000020E6100000010000000500000018B2BAD573984940B56D1805C1974A4018B2BAD573984940A7C98CB795984A403F575BB1BF9A4940A7C98CB795984A403F575BB1BF9A4940B56D1805C1974A4018B2BAD573984940B56D1805C1974A40
9486	Красносамарское	7	72	364	50.768441000000003	50.827308000000002	53.068975000000002	53.048127999999998	0103000020E61000000100000005000000E9F351465C624940CD02ED0E29864A40E9F351465C624940ED9E3C2CD4884A400EDC813AE5694940ED9E3C2CD4884A400EDC813AE5694940CD02ED0E29864A40E9F351465C624940CD02ED0E29864A40
9272	Комсомольский	7	72	364	50.828232999999997	50.864443999999999	53.251859000000003	53.224012999999999	0103000020E61000000100000005000000E63BF889036A49407E703E75AC9C4A40E63BF889036A4940051A6CEA3CA04A40999CDA19A66E4940051A6CEA3CA04A40999CDA19A66E49407E703E75AC9C4A40E63BF889036A49407E703E75AC9C4A40
9218	Кинельский	7	72	364	50.637152	50.670299999999997	53.261437000000001	53.252484000000003	0103000020E610000001000000050000005E4A5D328E514940B3614D6551A04A405E4A5D328E514940707B82C476A14A402041F163CC554940707B82C476A14A402041F163CC554940B3614D6551A04A405E4A5D328E514940B3614D6551A04A40
55910	Казахский	7	72	364	50.856178999999997	50.870148	53.353755999999997	53.346919	0103000020E61000000100000005000000D0420246976D494036AE7FD767AC4A40D0420246976D4940C36169E047AD4A4004577902616F4940C36169E047AD4A4004577902616F494036AE7FD767AC4A40D0420246976D494036AE7FD767AC4A40
9110	Домашка	7	72	364	50.753878999999998	50.790233999999998	53.009925000000003	52.967730000000003	0103000020E610000001000000050000001212691B7F604940D6AD9E93DE7B4A401212691B7F604940D734EF3845814A40F817416326654940D734EF3845814A40F817416326654940D6AD9E93DE7B4A401212691B7F604940D6AD9E93DE7B4A40
8961	Гурьевка	7	72	364	51.128368999999999	51.145229999999998	53.303296000000003	53.288215000000001	0103000020E61000000100000005000000FD6838656E904940BB9BA73AE4A44A40FD6838656E904940FA804067D2A64A40F4328AE596924940FA804067D2A64A40F4328AE596924940BB9BA73AE4A44A40FD6838656E904940BB9BA73AE4A44A40
9313	Грачевка	7	72	364	51.092751	51.119062	53.172696000000002	53.154308	0103000020E61000000100000005000000EDD5C743DF8B49406EC1525DC0934A40EDD5C743DF8B494034130CE71A964A402219726C3D8F494034130CE71A964A402219726C3D8F49406EC1525DC0934A40EDD5C743DF8B49406EC1525DC0934A40
8863	Георгиевка	7	72	364	50.949612999999999	51.026446	53.285603999999999	53.260958000000002	0103000020E61000000100000005000000A06D35EB8C79494096D05D1267A14A40A06D35EB8C794940ABCDFFAB8EA44A40158E209562834940ABCDFFAB8EA44A40158E20956283494096D05D1267A14A40A06D35EB8C79494096D05D1267A14A40
9722	Бузаевка	7	72	364	50.636263	50.677388000000001	53.353831999999997	53.336199000000001	0103000020E61000000100000005000000D253E4107151494055F99E9108AB4A40D253E410715149409E23F25D4AAD4A40F75965A6B45649409E23F25D4AAD4A40F75965A6B456494055F99E9108AB4A40D253E4107151494055F99E9108AB4A40
8951	Большая Малышевка	7	72	364	51.12377	51.163421	53.259551999999999	53.235570000000003	0103000020E61000000100000005000000EB1C03B2D78F494099F56228279E4A40EB1C03B2D78F494042CEFBFF38A14A40643DB5FAEA94494042CEFBFF38A14A40643DB5FAEA94494099F56228279E4A40EB1C03B2D78F494099F56228279E4A40
8780	Богдановка	7	72	364	50.866985999999997	50.916159999999998	53.339581000000003	53.312905000000001	0103000020E61000000100000005000000800BB265F96E4940A0E062450DA84A40800BB265F96E4940E7ABE46377AB4A40A1F31ABB44754940E7ABE46377AB4A40A1F31ABB44754940A0E062450DA84A40800BB265F96E4940A0E062450DA84A40
1994	Бобровка	7	72	364	50.636380000000003	50.707697000000003	53.167012	53.144343999999997	0103000020E610000001000000050000000CEA5BE674514940D9AF3BDD79924A400CEA5BE674514940100533A660954A40193DB7D0955A4940100533A660954A40193DB7D0955A4940D9AF3BDD79924A400CEA5BE674514940D9AF3BDD79924A40
1866	Алакаевка	7	72	364	50.733415999999998	50.760958000000002	53.427303999999999	53.412540999999997	0103000020E610000001000000050000007B2E5393E05D49402BA1BB24CEB44A407B2E5393E05D494099B9C0E5B1B64A4096D05D126761494099B9C0E5B1B64A4096D05D12676149402BA1BB24CEB44A407B2E5393E05D49402BA1BB24CEB44A40
48522	Черновка	7	72	342	51.354035000000003	51.435772	53.352063000000001	53.322502	0103000020E61000000100000005000000D751D50451AD49408272DBBE47A94A40D751D50451AD4940DA907F6610AD4A409A417C60C7B74940DA907F6610AD4A409A417C60C7B749408272DBBE47A94A40D751D50451AD49408272DBBE47A94A40
48448	Чернигово	7	72	342	51.189463000000003	51.203612	53.423043999999997	53.411189	0103000020E61000000100000005000000AA66D65240984940CBBC55D7A1B44A40AA66D652409849406F62484E26B64A405D8940F50F9A49406F62484E26B64A405D8940F50F9A4940CBBC55D7A1B44A40AA66D65240984940CBBC55D7A1B44A40
47965	Тоузаково	7	72	342	51.446804	51.471795	53.422604	53.413781	0103000020E610000001000000050000006ADC9BDF30B94940645A9BC6F6B44A406ADC9BDF30B9494053944BE317B64A404AB54FC763BC494053944BE317B64A404AB54FC763BC4940645A9BC6F6B44A406ADC9BDF30B94940645A9BC6F6B44A40
46576	Тимашево	7	72	342	51.143541999999997	51.198033000000002	53.359189999999998	53.333984000000001	0103000020E610000001000000050000001CCD91955F92494092B1DAFCBFAA4A401CCD91955F9249406E861BF0F9AD4A40AF433525599949406E861BF0F9AD4A40AF4335255999494092B1DAFCBFAA4A401CCD91955F92494092B1DAFCBFAA4A40
55958	Степановка	7	72	342	51.000117000000003	51.022233	53.565696000000003	53.551720000000003	0103000020E610000001000000050000003A9677D5038049404A46CEC29EC64A403A9677D50380494030BDFDB968C84A402CF2EB87D882494030BDFDB968C84A402CF2EB87D88249404A46CEC29EC64A403A9677D5038049404A46CEC29EC64A40
55901	Семеновка	7	72	342	51.308939000000002	51.364212999999999	53.550586000000003	53.532414000000003	0103000020E61000000100000005000000BFBA2A508BA749405EF7562426C44A40BFBA2A508BA7494057D11F9A79C64A4097E315889EAE494057D11F9A79C64A4097E315889EAE49405EF7562426C44A40BFBA2A508BA749405EF7562426C44A40
47865	Сарбай	7	72	342	51.134990000000002	51.541494999999998	53.640588999999999	53.522635000000001	0103000020E61000000100000005000000BEA4315A479149405B5F24B4E5C24A40BEA4315A47914940B39602D2FED14A4048F949B54FC54940B39602D2FED14A4048F949B54FC549405B5F24B4E5C24A40BEA4315A479149405B5F24B4E5C24A40
11731	Садгород	7	72	342	51.153323999999998	51.179195999999997	53.393247000000002	53.375894000000002	0103000020E6100000010000000500000090D8EE1EA09349409E616A4B1DB04A4090D8EE1EA09349400420EEEA55B24A4079C9FFE4EF9649400420EEEA55B24A4079C9FFE4EF9649409E616A4B1DB04A4090D8EE1EA09349409E616A4B1DB04A40
48439	Репьевка	7	72	342	51.062379	51.083094000000003	53.408853999999998	53.389805000000003	0103000020E61000000100000005000000857AFA08FC8749409D685721E5B14A40857AFA08FC8749405D6BEF5355B44A40363FFED2A28A49405D6BEF5355B44A40363FFED2A28A49409D685721E5B14A40857AFA08FC8749409D685721E5B14A40
11674	Пустовалово	7	72	342	51.198644000000002	51.21414	53.226610999999998	53.209874999999997	0103000020E61000000100000005000000F8C5A52A6D994940BE9F1A2FDD9A4A40F8C5A52A6D994940F9F4D896019D4A40FA6184F0689B4940F9F4D896019D4A40FA6184F0689B4940BE9F1A2FDD9A4A40F8C5A52A6D994940BE9F1A2FDD9A4A40
11106	Прокопенки	7	72	342	51.573878999999998	51.587417000000002	53.487257	53.475388000000002	0103000020E610000001000000050000003B6EF8DD74C9494097749483D9BC4A403B6EF8DD74C94940A0DFF76F5EBE4A40A60EF27A30CB4940A0DFF76F5EBE4A40A60EF27A30CB494097749483D9BC4A403B6EF8DD74C9494097749483D9BC4A40
1660	Полудни	7	72	342	51.721113000000003	51.741289000000002	53.428575000000002	53.409008999999998	0103000020E6100000010000000500000038DC476E4DDC494084622B685AB44A4038DC476E4DDC49400D71AC8BDBB64A4039F1D58EE2DE49400D71AC8BDBB64A4039F1D58EE2DE494084622B685AB44A4038DC476E4DDC494084622B685AB44A40
48385	Подгорный	7	72	342	51.169879999999999	51.185842999999998	53.258512000000003	53.244509999999998	0103000020E610000001000000050000004B1FBAA0BE954940C1C58A1A4C9F4A404B1FBAA0BE954940D1CFD4EB16A14A40639813B4C9974940D1CFD4EB16A14A40639813B4C9974940C1C58A1A4C9F4A404B1FBAA0BE954940C1C58A1A4C9F4A40
48355	Новые Ключи	7	72	342	51.859535000000001	51.893725000000003	53.322001999999998	53.292129000000003	0103000020E6100000010000000500000039622D3E05EE49404A9BAA7B64A54A4039622D3E05EE4940909F8D5C37A94A400E4FAF9465F24940909F8D5C37A94A400E4FAF9465F249404A9BAA7B64A54A4039622D3E05EE49404A9BAA7B64A54A40
48319	Муханово	7	72	342	51.271110999999998	51.302363999999997	53.343091999999999	53.331795	0103000020E61000000100000005000000FD4AE7C3B3A24940F8FC304278AA4A40FD4AE7C3B3A2494076C24B70EAAB4A406EBE11DDB3A6494076C24B70EAAB4A406EBE11DDB3A64940F8FC304278AA4A40FD4AE7C3B3A24940F8FC304278AA4A40
11573	Лозовка	7	72	342	51.792529000000002	51.828094	53.412422999999997	53.387453000000001	0103000020E61000000100000005000000D8101C9771E5494059DE550F98B14A40D8101C9771E54940218FE046CAB44A40C501F4FBFEE94940218FE046CAB44A40C501F4FBFEE9494059DE550F98B14A40D8101C9771E5494059DE550F98B14A40
48260	Кротовка	7	72	342	51.153880999999998	51.196632000000001	53.297913999999999	53.267975999999997	0103000020E61000000100000005000000E63C635FB2934940730E9E094DA24A40E63C635FB2934940A182C30B22A64A406DACC43C2B994940A182C30B22A64A406DACC43C2B994940730E9E094DA24A40E63C635FB2934940730E9E094DA24A40
10194	Коханы	7	72	342	51.676036000000003	51.696868000000002	53.319968000000003	53.307256000000002	0103000020E610000001000000050000009775FF5888D64940F9BF232A54A74A409775FF5888D649401EE21FB6F4A84A4081D07AF832D949401EE21FB6F4A84A4081D07AF832D94940F9BF232A54A74A409775FF5888D64940F9BF232A54A74A40
55861	Кинель-Черкасы	7	72	342	51.443435000000001	51.562703999999997	53.486592000000002	53.439498	0103000020E610000001000000050000006D73637AC2B849402654707841B84A406D73637AC2B84940643F8BA548BE4A4008AA46AF06C84940643F8BA548BE4A4008AA46AF06C849402654707841B84A406D73637AC2B849402654707841B84A40
55865	Кинель-Черкассы	7	72	342	50.812188999999996	52.210802999999999	53.724401999999998	53.185200999999999	0103000020E61000000100000005000000E19524CFF5674940DF1797AAB4974A40E19524CFF567494018946934B9DC4A400873BB97FB1A4A4018946934B9DC4A400873BB97FB1A4A40DF1797AAB4974A40E19524CFF5674940DF1797AAB4974A40
10256	Кабановка	7	72	342	51.264518000000002	51.301358	53.680607000000002	53.629553999999999	0103000020E61000000100000005000000079ACFB9DBA149407288B83995D04A40079ACFB9DBA14940DF3653211ED74A40A93121E692A64940DF3653211ED74A40A93121E692A649407288B83995D04A40079ACFB9DBA149407288B83995D04A40
10051	Ерзовка	7	72	342	51.645834999999998	51.676036000000003	53.506529	53.485542000000002	0103000020E610000001000000050000005BCEA5B8AAD24940CF6A813D26BE4A405BCEA5B8AAD24940E0BC38F1D5C04A409775FF5888D64940E0BC38F1D5C04A409775FF5888D64940CF6A813D26BE4A405BCEA5B8AAD24940CF6A813D26BE4A40
10006	Дубовый Колок	7	72	342	52.128275000000002	52.149878999999999	53.373137999999997	53.361291000000001	0103000020E610000001000000050000007CF2B0506B104A4069AB92C83EAE4A407CF2B0506B104A408A7269FCC2AF4A40B8AD2D3C2F134A408A7269FCC2AF4A40B8AD2D3C2F134A4069AB92C83EAE4A407CF2B0506B104A4069AB92C83EAE4A40
47789	Вязники	7	72	342	51.651476000000002	51.673116	53.370505999999999	53.360436	0103000020E610000001000000050000008010C99063D34940892650C422AE4A408010C99063D34940637C98BD6CAF4A40093543AA28D64940637C98BD6CAF4A40093543AA28D64940892650C422AE4A408010C99063D34940892650C422AE4A40
10747	Вольная Солянка	7	72	342	51.298698999999999	51.334882999999998	53.481721999999998	53.468060999999999	0103000020E61000000100000005000000882CD2C43BA649403BC43F6CE9BB4A40882CD2C43BA64940C1E10511A9BD4A40417E3672DDAA4940C1E10511A9BD4A40417E3672DDAA49403BC43F6CE9BB4A40882CD2C43BA649403BC43F6CE9BB4A40
47838	Богородское	7	72	342	51.141331999999998	51.198490999999997	53.644689	53.621020000000001	0103000020E610000001000000050000006BF0BE2A17924940BA1457957DCF4A406BF0BE2A17924940A48B4D2B85D24A4071C6302768994940A48B4D2B85D24A4071C6302768994940BA1457957DCF4A406BF0BE2A17924940BA1457957DCF4A40
55893	Березовка	7	72	342	50.974145999999998	50.987127000000001	53.621634	53.616464000000001	0103000020E61000000100000005000000BDC3EDD0B07C4940A794D74AE8CE4A40BDC3EDD0B07C4940740AF2B391CF4A40D2FF722D5A7E4940740AF2B391CF4A40D2FF722D5A7E4940A794D74AE8CE4A40BDC3EDD0B07C4940A794D74AE8CE4A40
47718	Березняки	7	72	342	52.118088	52.150264999999997	53.440505999999999	53.4238	0103000020E610000001000000050000006806F1811D0F4A40BC0512143FB64A406806F1811D0F4A408CD8278062B84A40E15D2EE23B134A408CD8278062B84A40E15D2EE23B134A40BC0512143FB64A406806F1811D0F4A40BC0512143FB64A40
9943	Безречье	7	72	342	50.926661000000003	50.938491999999997	53.540008	53.527082999999998	0103000020E6100000010000000500000045BDE0D39C76494087A3AB7477C34A4045BDE0D39C76494008CA6DFB1EC54A4060C77F812078494008CA6DFB1EC54A4060C77F812078494087A3AB7477C34A4045BDE0D39C76494087A3AB7477C34A40
10678	Алтухово	7	72	342	51.389634999999998	51.412219	53.407431000000003	53.398637999999998	0103000020E610000001000000050000004030478FDFB14940AF78EA9106B34A404030478FDFB149403430F2B226B44A4019E59997C3B449403430F2B226B44A4019E59997C3B44940AF78EA9106B34A404030478FDFB14940AF78EA9106B34A40
55846	Алексеевка	7	72	7379	50.475059999999999	50.550868999999999	53.261626	53.234648	0103000020E61000000100000005000000A2D11DC4CE3C4940310917F2089E4A40A2D11DC4CE3C494043E4F4F57CA14A40ABB019E08246494043E4F4F57CA14A40ABB019E082464940310917F2089E4A40A2D11DC4CE3C4940310917F2089E4A40
55961	Чулпан	7	72	960	52.017611000000002	52.034284	54.027403	54.013728999999998	0103000020E610000001000000050000006286C61341024A40DE0033DFC1014B406286C61341024A40F96706F181034B405663096B63044A40F96706F181034B405663096B63044A40DE0033DFC1014B406286C61341024A40DE0033DFC1014B40
55962	Татарский Байтуган	7	72	960	52.257102000000003	52.273622000000003	54.113249000000003	54.097057999999997	0103000020E610000001000000050000003CDEE4B7E8204A4057E883656C0C4B403CDEE4B7E8204A4001A777F17E0E4B40AABBB20B06234A4001A777F17E0E4B40AABBB20B06234A4057E883656C0C4B403CDEE4B7E8204A4057E883656C0C4B40
55956	Старое Усманово	7	72	960	52.345720999999998	52.369194	54.054273000000002	54.038105999999999	0103000020E610000001000000050000002C45F295402C4A4004E44BA8E0044B402C45F295402C4A402507EC6AF2064B4091F0BDBF412F4A402507EC6AF2064B4091F0BDBF412F4A4004E44BA8E0044B402C45F295402C4A4004E44BA8E0044B40
55971	Старое Ермаково	7	72	960	51.942404000000003	51.979613000000001	54.083686999999998	54.058295000000001	0103000020E610000001000000050000004FCFBBB1A0F849409A42E73576074B404FCFBBB1A0F84940D80C7041B60A4B4044DE72F563FD4940D80C7041B60A4B4044DE72F563FD49409A42E73576074B404FCFBBB1A0F849409A42E73576074B40
55966	Старая Балыкла	7	72	960	52.152968999999999	52.177377	53.998907000000003	53.975389999999997	0103000020E61000000100000005000000A226FA7C94134A40376C5B94D9FC4A40A226FA7C94134A406C5F402FDCFF4A4003081F4AB4164A406C5F402FDCFF4A4003081F4AB4164A40376C5B94D9FC4A40A226FA7C94134A40376C5B94D9FC4A40
47396	Софьино	7	72	960	52.059113000000004	52.068266999999999	54.108941999999999	54.099592000000001	0103000020E610000001000000050000005DE2C80391074A40BC783F6EBF0C4B405DE2C80391074A409694BBCFF10D4B40B1321AF9BC084A409694BBCFF10D4B40B1321AF9BC084A40BC783F6EBF0C4B405DE2C80391074A40BC783F6EBF0C4B40
55959	Русский Байтуган	7	72	960	52.248064999999997	52.274062000000001	54.094017000000001	54.083053	0103000020E6100000010000000500000020240B98C01F4A40D76A0F7BA10A4B4020240B98C01F4A404F22C2BF080C4B40C689AF7614234A404F22C2BF080C4B40C689AF7614234A40D76A0F7BA10A4B4020240B98C01F4A40D76A0F7BA10A4B40
55965	Новое Усманово	7	72	960	52.320757	52.363463000000003	54.129036999999997	54.101129	0103000020E61000000100000005000000467BBC900E294A40AED689CBF10C4B40467BBC900E294A40AA7CCF4884104B402D27A1F4852E4A40AA7CCF4884104B402D27A1F4852E4A40AED689CBF10C4B40467BBC900E294A40AED689CBF10C4B40
55955	Новое Ермаково	7	72	960	51.889341000000002	51.923000999999999	54.065697999999998	54.051270000000002	0103000020E61000000100000005000000F8FE06EDD5F149400AA2EE0390064B40F8FE06EDD5F14940D0B4C4CA68084B40709692E524F64940D0B4C4CA68084B40709692E524F649400AA2EE0390064B40F8FE06EDD5F149400AA2EE0390064B40
55967	Никиткино	7	72	960	52.399071999999997	52.420425000000002	54.066046999999998	54.043224000000002	0103000020E61000000100000005000000E95F92CA14334A407F33315D88054B40E95F92CA14334A40DC7F643A74084B40DDB5847CD0354A40DC7F643A74084B40DDB5847CD0354A407F33315D88054B40E95F92CA14334A407F33315D88054B40
55957	Неклюдово	7	72	960	52.358260999999999	52.372624999999999	53.975163000000002	53.964559000000001	0103000020E610000001000000050000005437177FDB2D4A40FF0758AB76FB4A405437177FDB2D4A4077A22424D2FC4A4004560E2DB22F4A4077A22424D2FC4A4004560E2DB22F4A40FF0758AB76FB4A405437177FDB2D4A40FF0758AB76FB4A40
8209	Камышла	7	72	960	52.124735000000001	52.155979000000002	54.132683	54.096203000000003	0103000020E6100000010000000500000052D50451F70F4A4078634161500C4B4052D50451F70F4A401ADEACC1FB104B4070EEAF1EF7134A401ADEACC1FB104B4070EEAF1EF7134A4078634161500C4B4052D50451F70F4A4078634161500C4B40
7812	Сухарь Матак	7	72	329	51.545448	51.571013999999998	53.930221000000003	53.917107999999999	0103000020E6100000010000000500000095D5743DD1C54940327381CB63F54A4095D5743DD1C54940B686527B11F74A4071C79BFC16C94940B686527B11F74A4071C79BFC16C94940327381CB63F54A4095D5743DD1C54940327381CB63F54A40
55944	Старый Шунгут	7	72	329	51.56221	51.585405000000002	54.021478999999999	54.010733999999999	0103000020E61000000100000005000000F9BD4D7FF6C74940467A51BB5F014B40F9BD4D7FF6C749408046E9D2BF024B401BF5108DEECA49408046E9D2BF024B401BF5108DEECA4940467A51BB5F014B40F9BD4D7FF6C74940467A51BB5F014B40
2156	Старое Вечканово	7	72	329	51.715983999999999	51.768877000000003	54.090409999999999	54.069364999999998	0103000020E61000000100000005000000C93A1C5DA5DB4940573ECBF3E0084B40C93A1C5DA5DB49409D9D0C8E920B4B40C4D2C08F6AE249409D9D0C8E920B4B40C4D2C08F6AE24940573ECBF3E0084B40C93A1C5DA5DB4940573ECBF3E0084B40
7375	Старая Чесноковка	7	72	329	51.300593999999997	51.312533000000002	54.185440999999997	54.172114000000001	0103000020E61000000100000005000000D9AF3BDD79A649408597E0D407164B40D9AF3BDD79A64940342BDB87BC174B40DCF5D21401A84940342BDB87BC174B40DCF5D21401A849408597E0D407164B40D9AF3BDD79A649408597E0D407164B40
7904	Сокский	7	72	329	51.851413999999998	51.867781000000001	54.078282999999999	54.061031999999997	0103000020E61000000100000005000000A3AD4A22FBEC4940360186E5CF074B40A3AD4A22FBEC4940986A662D050A4B408B8BA37213EF4940986A662D050A4B408B8BA37213EF4940360186E5CF074B40A3AD4A22FBEC4940360186E5CF074B40
46651	Смольково	7	72	329	51.311211999999998	51.340927999999998	54.136808000000002	54.108905	0103000020E61000000100000005000000B60F79CBD5A7494079AF5A99F00D4B40B60F79CBD5A7494064EAAEEC82114B4035255987A3AB494064EAAEEC82114B4035255987A3AB494079AF5A99F00D4B40B60F79CBD5A7494079AF5A99F00D4B40
7136	Саперкино	7	72	329	51.623699999999999	51.648161000000002	54.086655	54.068330000000003	0103000020E61000000100000005000000F241CF66D5CF4940F8AA9509BF084B40F241CF66D5CF49407784D382170B4B4076C58CF0F6D249407784D382170B4B4076C58CF0F6D24940F8AA9509BF084B40F241CF66D5CF4940F8AA9509BF084B40
7763	Самсоновка	7	72	329	51.494306999999999	51.516522000000002	53.899307999999998	53.884084000000001	0103000020E610000001000000050000008997A77345BF49405C751DAA29F14A408997A77345BF4940FD8348861CF34A400FD594641DC24940FD8348861CF34A400FD594641DC249405C751DAA29F14A408997A77345BF49405C751DAA29F14A40
46502	Пригорки	7	72	329	51.560746000000002	51.576314000000004	54.062412000000002	54.049156000000004	0103000020E6100000010000000500000071AE6186C6C749407B336ABE4A064B4071AE6186C6C749406170CD1DFD074B400D1D3BA8C4C949406170CD1DFD074B400D1D3BA8C4C949407B336ABE4A064B4071AE6186C6C749407B336ABE4A064B40
6660	Новое Якушкино	7	72	329	51.509532999999998	51.534210000000002	53.958097000000002	53.937441	0103000020E61000000100000005000000CB9D996038C14940FB761211FEF74A40CB9D996038C14940A7B228ECA2FA4A401C9947FE60C44940A7B228ECA2FA4A401C9947FE60C44940FB761211FEF74A40CB9D996038C14940FB761211FEF74A40
7633	Новое Ганькино	7	72	329	51.822820999999998	51.869200999999997	53.956470000000003	53.932065999999999	0103000020E6100000010000000500000023BBD23252E9494055DB4DF04DF74A4023BBD23252E9494075CDE49B6DFA4A40435376FA41EF494075CDE49B6DFA4A40435376FA41EF494055DB4DF04DF74A4023BBD23252E9494055DB4DF04DF74A40
7499	Новая Чесноковка	7	72	329	51.389958	51.399740999999999	54.087409999999998	54.077882000000002	0103000020E610000001000000050000002368CC24EAB149403A799109F8094B402368CC24EAB14940F3AB3940300B4B4067EF8CB62AB34940F3AB3940300B4B4067EF8CB62AB349403A799109F8094B402368CC24EAB149403A799109F8094B40
7224	Мордово-Ишуткино	7	72	329	51.671382999999999	51.706848000000001	53.837347999999999	53.809258999999997	0103000020E61000000100000005000000910BCEE0EFD54940307F85CC95E74A40910BCEE0EFD549407DAF21382EEB4A401B9FC9FE79DA49407DAF21382EEB4A401B9FC9FE79DA4940307F85CC95E74A40910BCEE0EFD54940307F85CC95E74A40
55947	Мордово-Аделякова	7	72	329	51.565624	51.615138999999999	53.819119999999998	53.781288000000004	0103000020E6100000010000000500000096EA025E66C84940EE60C43E01E44A4096EA025E66C84940F0BF95ECD8E84A4040BFEFDFBCCE4940F0BF95ECD8E84A4040BFEFDFBCCE4940EE60C43E01E44A4096EA025E66C84940EE60C43E01E44A40
7227	Малое Ишуткино	7	72	329	51.729790999999999	51.758051999999999	53.856785000000002	53.848323999999998	0103000020E6100000010000000500000023F59ECA69DD4940B9347EE195EC4A4023F59ECA69DD4940085A8121ABED4A406D5512D907E14940085A8121ABED4A406D5512D907E14940B9347EE195EC4A4023F59ECA69DD4940B9347EE195EC4A40
46468	Красный Берег	7	72	329	51.603963999999998	51.623547000000002	54.121707999999998	54.113813	0103000020E610000001000000050000000DFB3DB14ECD4940096EA46C910E4B400DFB3DB14ECD4940AED4B320940F4B406C425A63D0CF4940AED4B320940F4B406C425A63D0CF4940096EA46C910E4B400DFB3DB14ECD4940096EA46C910E4B40
46598	Ключи	7	72	329	51.405687999999998	51.433841000000001	54.161814	54.138463999999999	0103000020E6100000010000000500000098309A95EDB3494030D63730B9114B4098309A95EDB3494079043752B6144B40FC54151A88B7494079043752B6144B40FC54151A88B7494030D63730B9114B4098309A95EDB3494030D63730B9114B40
55934	Каменка	7	72	329	51.751539000000001	51.759759000000003	53.936374999999998	53.930072000000003	0103000020E610000001000000050000009355116E32E0494071766B990CF74A409355116E32E0494060E5D022DBF74A40BCEB6CC83FE1494060E5D022DBF74A40BCEB6CC83FE1494071766B990CF74A409355116E32E0494071766B990CF74A40
6871	Исаклы	7	72	329	51.505786999999998	51.557538999999998	54.146566	54.122304999999997	0103000020E61000000100000005000000F8DEDFA0BDC049409291B3B0A70F4B40F8DEDFA0BDC049404F5AB8ACC2124B404D9F1D705DC749404F5AB8ACC2124B404D9F1D705DC749409291B3B0A70F4B40F8DEDFA0BDC049409291B3B0A70F4B40
55925	Ивановка	7	72	329	51.549858999999998	51.561078000000002	53.801751000000003	53.795098000000003	0103000020E61000000100000005000000A4349BC761C64940B98E71C5C5E54A40A4349BC761C649408544DAC69FE64A40A7406667D1C749408544DAC69FE64A40A7406667D1C74940B98E71C5C5E54A40A4349BC761C64940B98E71C5C5E54A40
46619	Зеленовский	7	72	329	51.463503000000003	51.481892000000002	54.210017999999998	54.194355000000002	0103000020E61000000100000005000000884CF91054BB49403468E89FE0184B40884CF91054BB494021C9ACDEE11A4B401E1A16A3AEBD494021C9ACDEE11A4B401E1A16A3AEBD49403468E89FE0184B40884CF91054BB49403468E89FE0184B40
7070	Два Ключа	7	72	329	51.562641999999997	51.588315000000001	54.098562999999999	54.084009000000002	0103000020E6100000010000000500000092AD2EA704C84940EBC891CEC00A4B4092AD2EA704C849403ECC5EB69D0C4B40855FEAE74DCB49403ECC5EB69D0C4B40855FEAE74DCB4940EBC891CEC00A4B4092AD2EA704C84940EBC891CEC00A4B40
7685	Ганькин Матак	7	72	329	51.772146999999997	51.795313999999998	53.928742	53.916716000000001	0103000020E610000001000000050000002D5A80B6D5E2494027DC2BF356F54A402D5A80B6D5E24940F8359204E1F64A40850662D9CCE54940F8359204E1F64A40850662D9CCE5494027DC2BF356F54A402D5A80B6D5E2494027DC2BF356F54A40
7511	Большое Микушкино	7	72	329	51.673934000000003	51.703434000000001	53.959510999999999	53.930405999999998	0103000020E61000000100000005000000CCD4247843D649404700378B17F74A40CCD4247843D649407D93A641D1FA4A407E7214200ADA49407D93A641D1FA4A407E7214200ADA49404700378B17F74A40CCD4247843D649404700378B17F74A40
6940	Багряш	7	72	329	51.676234000000001	51.706282000000002	54.213182000000003	54.197789	0103000020E61000000100000005000000BD38F1D58ED649401841632651194B40BD38F1D58ED64940460C3B8C491B4B4072E0D57267DA4940460C3B8C491B4B4072E0D57267DA49401841632651194B40BD38F1D58ED649401841632651194B40
26559	Теплый Стан	7	72	1725	50.145774000000003	50.187860000000001	53.986339999999998	53.966583	0103000020E61000000100000005000000B64DF1B8A81249404EEFE2FDB8FB4A40B64DF1B8A81249404A5E9D6340FE4A40001DE6CB0B1849404A5E9D6340FE4A40001DE6CB0B1849404EEFE2FDB8FB4A40B64DF1B8A81249404EEFE2FDB8FB4A40
26460	Сухие Аврали	7	72	1725	50.051369999999999	50.079810000000002	53.83381	53.810971000000002	0103000020E610000001000000050000006DFFCA4A930649409180D1E5CDE74A406DFFCA4A93064940F4893C49BAEA4A4067F2CD36370A4940F4893C49BAEA4A4067F2CD36370A49409180D1E5CDE74A406DFFCA4A930649409180D1E5CDE74A40
26363	Никитинка	7	72	1725	50.543359000000002	50.567138	53.944654	53.929504999999999	0103000020E610000001000000050000005F7EA7C98C454940F73B1405FAF64A405F7EA7C98C4549408E041A6CEAF84A40D0285DFA974849408E041A6CEAF84A40D0285DFA97484940F73B1405FAF64A405F7EA7C98C454940F73B1405FAF64A40
25652	Нижняя Кондурча	7	72	1725	50.365088	50.379722000000001	53.980262000000003	53.972360999999999	0103000020E61000000100000005000000BE141E34BB2E4940F373435376FC4A40BE141E34BB2E49407BC1A73979FD4A402EC901BB9A3049407BC1A73979FD4A402EC901BB9A304940F373435376FC4A40BE141E34BB2E4940F373435376FC4A40
26506	Мулловка	7	72	1725	50.153823000000003	50.173845999999998	53.779336000000001	53.768197999999998	0103000020E61000000100000005000000B22FD978B0134940226DE34F54E24A40B22FD978B0134940384C3448C1E34A402C45F29540164940384C3448C1E34A402C45F29540164940226DE34F54E24A40B22FD978B0134940226DE34F54E24A40
23358	Кубань-Озеро	7	72	1725	49.964053999999997	49.987921999999998	53.933369999999996	53.918911000000001	0103000020E61000000100000005000000FBC9181F66FB4840A3772AE09EF54A40FBC9181F66FB4840A4880CAB78F74A40DC7F643A74FE4840A4880CAB78F74A40DC7F643A74FE4840A3772AE09EF54A40FBC9181F66FB4840A3772AE09EF54A40
25000	Красные Дома	7	72	1725	50.358665000000002	50.384402000000001	53.830599999999997	53.821607999999998	0103000020E61000000100000005000000249C16BCE82D4940E41071732AE94A40249C16BCE82D49405F07CE1951EA4A402D42B115343149405F07CE1951EA4A402D42B11534314940E41071732AE94A40249C16BCE82D4940E41071732AE94A40
55848	Елховка	7	72	1725	50.272300999999999	50.309851000000002	53.894027999999999	53.856126000000003	0103000020E6100000010000000500000084D558C2DA224940AEA0698995ED4A4084D558C2DA224940A9DA6E826FF24A4003D19332A9274940A9DA6E826FF24A4003D19332A9274940AEA0698995ED4A4084D558C2DA224940AEA0698995ED4A40
26568	Борма	7	72	1725	50.250912999999997	50.271286000000003	54.029660999999997	54.009512000000001	0103000020E610000001000000050000001492CCEA1D204940B47570B037014B401492CCEA1D204940BB7B80EECB034B406CEEE87FB9224940BB7B80EECB034B406CEEE87FB9224940B47570B037014B401492CCEA1D204940B47570B037014B40
6080	Яблоновый Овраг	7	72	268	50.362304000000002	50.413615	52.846778999999998	52.818418000000001	0103000020E61000000100000005000000E19A3BFA5F2E4940973AC8EBC1684A40E19A3BFA5F2E494044F81741636C4A4049111956F134494044F81741636C4A4049111956F1344940973AC8EBC1684A40E19A3BFA5F2E4940973AC8EBC1684A40
6750	Черноречье	7	72	268	50.361530999999999	50.409329999999997	53.171351999999999	53.153297999999999	0103000020E61000000100000005000000BEBED6A5462E49406745D4449F934A40BEBED6A5462E4940560DC2DCEE954A40C6A2E9EC64344940560DC2DCEE954A40C6A2E9EC643449406745D4449F934A40BEBED6A5462E49406745D4449F934A40
6698	Черновский	7	72	268	50.448784000000003	50.489756999999997	53.194594000000002	53.172485999999999	0103000020E61000000100000005000000EA7B0DC1713949404982700514964A40EA7B0DC171394940B9FFC874E8984A4058FE7C5BB03E4940B9FFC874E8984A4058FE7C5BB03E49404982700514964A40EA7B0DC1713949404982700514964A40
1303	Сухая Вязовка	7	72	268	50.188578	50.244211	52.890191000000002	52.870958999999999	0103000020E610000001000000050000005F5FEB52231849401494A2957B6F4A405F5FEB5223184940C61858C7F1714A406729594E421F4940C61858C7F1714A406729594E421F49401494A2957B6F4A405F5FEB52231849401494A2957B6F4A40
55869	Стройкерамика	7	72	268	49.574724000000003	50.663814000000002	53.516638999999998	52.719059000000001	0103000020E61000000100000005000000F81C588E90C948407E7214200A5C4A40F81C588E90C94840486B0C3A21C24A4040506EDBF7544940486B0C3A21C24A4040506EDBF75449407E7214200A5C4A40F81C588E90C948407E7214200A5C4A40
6188	Спиридоновка	7	72	268	50.629921000000003	50.663814000000002	53.114752000000003	53.074823000000002	0103000020E6100000010000000500000025085740A15049408BFED0CC93894A4025085740A150494047938B31B08E4A4040506EDBF754494047938B31B08E4A4040506EDBF75449408BFED0CC93894A4025085740A15049408BFED0CC93894A40
5959	Самарский	7	72	268	50.239693000000003	50.253374000000001	53.039226999999997	53.030796000000002	0103000020E61000000100000005000000420A9E42AE1E49407F6C921FF1834A40420A9E42AE1E4940620FED6305854A400FD4298F6E204940620FED6305854A400FD4298F6E2049407F6C921FF1834A40420A9E42AE1E49407F6C921FF1834A40
1124	Ровно-Владимировка	7	72	268	50.353994	50.393214999999998	52.917701999999998	52.905706000000002	0103000020E61000000100000005000000787DE6AC4F2D49403FE5982CEE734A40787DE6AC4F2D4940A5BC564277754A40F8A57EDE54324940A5BC564277754A40F8A57EDE543249403FE5982CEE734A40787DE6AC4F2D49403FE5982CEE734A40
5967	Просвет	7	72	268	50.476514999999999	50.500571999999998	53.023333000000001	53.005611999999999	0103000020E61000000100000005000000D7868A71FE3C49408A3BDEE4B7804A40D7868A71FE3C494073F56393FC824A408BA548BE1240494073F56393FC824A408BA548BE124049408A3BDEE4B7804A40D7868A71FE3C49408A3BDEE4B7804A40
61378	Поселок Смышляевка	7	72	268	49.574724000000003	50.663814000000002	53.516638999999998	52.719059000000001	0103000020E61000000100000005000000F81C588E90C948407E7214200A5C4A40F81C588E90C94840486B0C3A21C24A4040506EDBF7544940486B0C3A21C24A4040506EDBF75449407E7214200A5C4A40F81C588E90C948407E7214200A5C4A40
6069	Подъем-Михайловка	7	72	268	50.503141999999997	50.548839000000001	52.830134000000001	52.804254999999998	0103000020E610000001000000050000003C9F01F5664049407E52EDD3F1664A403C9F01F5664049401AA6B6D4416A4A407AE2395B404649401AA6B6D4416A4A407AE2395B404649407E52EDD3F1664A403C9F01F5664049407E52EDD3F1664A40
5273	Петра-Дубрава	7	72	268	50.353859999999997	50.389567999999997	53.317977999999997	53.284592000000004	0103000020E6100000010000000500000068AED3484B2D4940045ABA826DA44A4068AED3484B2D49407A6CCB80B3A84A40B8C83D5DDD3149407A6CCB80B3A84A40B8C83D5DDD314940045ABA826DA44A4068AED3484B2D4940045ABA826DA44A40
55912	Озерки	7	72	268	50.534582999999998	50.544373999999998	52.745659000000003	52.739553000000001	0103000020E61000000100000005000000B0FF3A376D444940505436ACA95E4A40B0FF3A376D444940EA7B0DC1715F4A407765170CAE454940EA7B0DC1715F4A407765170CAE454940505436ACA95E4A40B0FF3A376D444940505436ACA95E4A40
5811	Лопатино	7	72	268	50.201298999999999	50.237015999999997	53.083035000000002	53.069001999999998	0103000020E61000000100000005000000D7DB662AC4194940E6ADBA0ED5884A40D7DB662AC419494031B610E4A08A4A407A50508A561E494031B610E4A08A4A407A50508A561E4940E6ADBA0ED5884A40D7DB662AC4194940E6ADBA0ED5884A40
4528	Курумоч	7	72	268	50.017620000000001	50.056516999999999	53.496834999999997	53.481566000000001	0103000020E61000000100000005000000B5E0455F41024940CA6E66F4A3BD4A40B5E0455F410249400B410E4A98BF4A408255F5F23B0749400B410E4A98BF4A408255F5F23B074940CA6E66F4A3BD4A40B5E0455F41024940CA6E66F4A3BD4A40
5808	Калинка	7	72	268	50.163775999999999	50.178598000000001	52.991455999999999	52.977924000000002	0103000020E6100000010000000500000052EFA99CF61449409CFC169D2C7D4A4052EFA99CF614494024B6BB07E87E4A40C5909C4CDC16494024B6BB07E87E4A40C5909C4CDC1649409CFC169D2C7D4A4052EFA99CF61449409CFC169D2C7D4A40
45852	Журавли	7	72	268	49.966676999999997	49.98856	52.994323000000001	52.979528999999999	0103000020E61000000100000005000000CF656A12BCFB4840E63DCE34617D4A40CF656A12BCFB48408F54DFF9457F4A401F11532289FE48408F54DFF9457F4A401F11532289FE4840E63DCE34617D4A40CF656A12BCFB4840E63DCE34617D4A40
5659	Дубовый Умет	7	72	268	50.270747	50.307577999999999	52.989705000000001	52.959566000000002	0103000020E61000000100000005000000BC3E73D6A7224940412D060FD37A4A40BC3E73D6A722494006D847A7AE7E4A400B7C45B75E27494006D847A7AE7E4A400B7C45B75E274940412D060FD37A4A40BC3E73D6A7224940412D060FD37A4A40
6281	Языково	7	72	555	52.031543999999997	52.074043000000003	53.285890000000002	53.266156000000002	0103000020E61000000100000005000000483140A209044A402DD1596611A24A40483140A209044A407120240B98A44A40B6BFB33D7A094A407120240B98A44A40B6BFB33D7A094A402DD1596611A24A40483140A209044A402DD1596611A24A40
5929	Широченка	7	72	555	51.510216	51.528083000000002	53.020457	53.007334999999998	0103000020E61000000100000005000000AEF204C24EC14940DE8E705AF0804A40AEF204C24EC14940B5FCC0559E824A406B49473998C34940B5FCC0559E824A406B49473998C34940DE8E705AF0804A40AEF204C24EC14940DE8E705AF0804A40
16162	Усманка	7	72	555	51.689582000000001	51.708680999999999	52.844124999999998	52.805065999999997	0103000020E6100000010000000500000084F4143944D849408E8F16670C674A4084F4143944D84940355EBA490C6C4A40F6251B0FB6DA4940355EBA490C6C4A40F6251B0FB6DA49408E8F16670C674A4084F4143944D849408E8F16670C674A40
47889	Тростянка	7	72	555	51.979343	51.992790999999997	53.196601000000001	53.189253000000001	0103000020E610000001000000050000008448861C5BFD4940BFD53A7139984A408448861C5BFD494032AEB8382A994A40AE6186C613FF494032AEB8382A994A40AE6186C613FF4940BFD53A7139984A408448861C5BFD4940BFD53A7139984A40
16151	Старая Таволжанка	7	72	555	51.705275999999998	51.722271999999997	52.778714999999998	52.756037999999997	0103000020E61000000100000005000000AC53E57B46DA494041446ADAC5604A40AC53E57B46DA4940CBF3E0EEAC634A408368AD6873DC4940CBF3E0EEAC634A408368AD6873DC494041446ADAC5604A40AC53E57B46DA494041446ADAC5604A40
15876	Соковнинка	7	72	555	51.938738999999998	51.967827	53.134042999999998	53.113951999999998	0103000020E61000000100000005000000683D7C9928F849402AA8A8FA958E4A40683D7C9928F84940FDA02E5228914A40C89750C1E1FB4940FDA02E5228914A40C89750C1E1FB49402AA8A8FA958E4A40683D7C9928F849402AA8A8FA958E4A40
15190	Покровка	7	72	555	51.483051000000003	51.505437000000001	52.94265	52.909582999999998	0103000020E610000001000000050000006AA67B9DD4BD4940B0FF3A376D744A406AA67B9DD4BD494086C954C1A8784A401C98DC28B2C0494086C954C1A8784A401C98DC28B2C04940B0FF3A376D744A406AA67B9DD4BD4940B0FF3A376D744A40
15918	Подсолнечное	7	72	555	52.005285999999998	52.031337999999998	53.161290000000001	53.145105999999998	0103000020E6100000010000000500000036902E36AD004A40083A5AD592924A4036902E36AD004A40FF959526A5944A409F8F32E202044A40FF959526A5944A409F8F32E202044A40083A5AD592924A4036902E36AD004A40083A5AD592924A40
6291	Подгорное	7	72	555	51.787498999999997	51.814754000000001	53.229619	53.216366999999998	0103000020E61000000100000005000000FC5069C4CCE449408177F2E9B19B4A40FC5069C4CCE4494026C5C727649D4A408124ECDB49E8494026C5C727649D4A408124ECDB49E849408177F2E9B19B4A40FC5069C4CCE449408177F2E9B19B4A40
6142	Новый Кутулук	7	72	555	51.594926999999998	51.626629000000001	53.207118999999999	53.192208999999998	0103000020E61000000100000005000000F240649126CC4940997FF44D9A984A40F240649126CC4940ABB019E0829A4A40D3DC0A6135D04940ABB019E0829A4A40D3DC0A6135D04940997FF44D9A984A40F240649126CC4940997FF44D9A984A40
55943	Новогеранькино	7	72	555	51.838540999999999	51.859247000000003	53.191232999999997	53.173262999999999	0103000020E6100000010000000500000075ADBD4F55EB4940AD4D637B2D964A4075ADBD4F55EB49403E75AC527A984A40D31742CEFBED49403E75AC527A984A40D31742CEFBED4940AD4D637B2D964A4075ADBD4F55EB4940AD4D637B2D964A40
15593	Новоборский	7	72	555	51.731991999999998	51.753785000000001	53.049508000000003	53.040857000000003	0103000020E610000001000000050000008177F2E9B1DD494006685BCD3A854A408177F2E9B1DD4940F871344756864A40919BE1067CE04940F871344756864A40919BE1067CE0494006685BCD3A854A408177F2E9B1DD494006685BCD3A854A40
6187	Новая Покровка	7	72	555	51.964619999999996	51.989834999999999	53.254106	53.238377	0103000020E61000000100000005000000A4880CAB78FB49402E8F3523839E4A40A4880CAB78FB4940D3DB9F8B86A04A40D4B7CCE9B2FE4940D3DB9F8B86A04A40D4B7CCE9B2FE49402E8F3523839E4A40A4880CAB78FB49402E8F3523839E4A40
6071	Неприк	7	72	555	51.840490000000003	51.859948000000003	53.132784000000001	53.114303	0103000020E61000000100000005000000BA4E232D95EB4940D76A0F7BA18E4A40BA4E232D95EB49404EB7EC10FF904A405C21ACC612EE49404EB7EC10FF904A405C21ACC612EE4940D76A0F7BA18E4A40BA4E232D95EB4940D76A0F7BA18E4A40
19619	Марьевка	7	72	555	51.578631999999999	51.584237000000002	53.287999999999997	53.273764999999997	0103000020E61000000100000005000000A435069D10CA49400CE544BB0AA34A40A435069D10CA4940BE9F1A2FDDA44A407C0E2C47C8CA4940BE9F1A2FDDA44A407C0E2C47C8CA49400CE544BB0AA34A40A435069D10CA49400CE544BB0AA34A40
5861	Лесной	7	72	555	51.855609000000001	51.900964999999999	53.038285000000002	53.025433999999997	0103000020E61000000100000005000000E694809884ED49406D1ADB6B41834A40E694809884ED4940B476DB85E6844A409AEB34D252F34940B476DB85E6844A409AEB34D252F349406D1ADB6B41834A40E694809884ED49406D1ADB6B41834A40
15499	Коноваловка	7	72	555	51.518301000000001	51.569918000000001	53.120004999999999	53.090162999999997	0103000020E61000000100000005000000F73DEAAF57C24940952710768A8B4A40F73DEAAF57C24940A12DE7525C8F4A406CB3B112F3C84940A12DE7525C8F4A406CB3B112F3C84940952710768A8B4A40F73DEAAF57C24940952710768A8B4A40
15495	Имени Клары Цеткин	7	72	555	51.794702999999998	51.830914	52.971905	52.955584999999999	0103000020E610000001000000050000003C84F1D3B8E549402AC6F99B507A4A403C84F1D3B8E54940D1E80E62677C4A40EFE4D3635BEA4940D1E80E62677C4A40EFE4D3635BEA49402AC6F99B507A4A403C84F1D3B8E549402AC6F99B507A4A40
15407	Заплавное	7	72	555	51.673609999999996	51.737535000000001	52.983806999999999	52.962007	0103000020E6100000010000000500000018213CDA38D64940F4C29D0B237B4A4018213CDA38D64940B6494563ED7D4A40E353008C67DE4940B6494563ED7D4A40E353008C67DE4940F4C29D0B237B4A4018213CDA38D64940F4C29D0B237B4A40
55863	Елховка	7	72	555	51.661079000000001	51.671247999999999	53.209060999999998	53.204039000000002	0103000020E610000001000000050000004489963C9ED44940E50D30F31D9A4A404489963C9ED449403DEFC682C29A4A40B1C05774EBD549403DEFC682C29A4A40B1C05774EBD54940E50D30F31D9A4A404489963C9ED44940E50D30F31D9A4A40
3432	Долматовка	7	72	555	51.721094999999998	51.752554000000003	53.142254000000001	53.120837000000002	0103000020E61000000100000005000000912749D74CDC4940C9923996778F4A40912749D74CDC4940D3DC0A6135924A40AC3C81B053E04940D3DC0A6135924A40AC3C81B053E04940C9923996778F4A40912749D74CDC4940C9923996778F4A40
16055	Гостевка	7	72	555	51.670169999999999	51.691189999999999	52.722261000000003	52.705053999999997	0103000020E6100000010000000500000052616C21C8D54940FDF49F353F5A4A4052616C21C8D549409016670C735C4A403FA9F6E978D849409016670C735C4A403FA9F6E978D84940FDF49F353F5A4A4052616C21C8D54940FDF49F353F5A4A40
15050	Гвардейцы	7	72	555	51.568264999999997	51.609974000000001	53.001559	52.983753	0103000020E61000000100000005000000103B53E8BCC84940C32B499EEB7D4A40103B53E8BCC84940DA01D71533804A4085B4C6A013CE4940DA01D71533804A4085B4C6A013CE4940C32B499EEB7D4A40103B53E8BCC84940C32B499EEB7D4A40
15975	Васильевка	7	72	555	52.055287	52.112321000000001	53.191966999999998	53.170197000000002	0103000020E610000001000000050000006D72F8A413074A404C70EA03C9954A406D72F8A413074A40A374E95F92984A40B7D3D688600E4A40A374E95F92984A40B7D3D688600E4A404C70EA03C9954A406D72F8A413074A404C70EA03C9954A40
5866	Борское	7	72	555	51.668418000000003	51.730204000000001	53.044890000000002	53.016328999999999	0103000020E61000000100000005000000640795B88ED54940FA7C941117824A40640795B88ED549406FF59CF4BE854A4046B41D5377DD49406FF59CF4BE854A4046B41D5377DD4940FA7C941117824A40640795B88ED54940FA7C941117824A40
14728	Большое Алдаркино	7	72	555	51.885218000000002	51.910200000000003	53.112876	53.094338	0103000020E610000001000000050000004FEACBD24EF1494091628044138C4A404FEACBD24EF149406C4084B8728E4A40DC68006F81F449406C4084B8728E4A40DC68006F81F4494091628044138C4A404FEACBD24EF1494091628044138C4A40
15197	Благодаровка	7	72	555	51.448439	51.470097000000003	52.860407000000002	52.842374	0103000020E610000001000000050000001FA0FB7266B94940178046E9D26B4A401FA0FB7266B94940EF1F0BD1216E4A404F7974232CBC4940EF1F0BD1216E4A404F7974232CBC4940178046E9D26B4A401FA0FB7266B94940178046E9D26B4A40
6081	Алексеевка	7	72	555	51.647460000000002	51.676251000000001	52.913052999999998	52.895059000000003	0103000020E61000000100000005000000EDBB22F8DFD24940C87E164B91724A40EDBB22F8DFD24940E141B3EBDE744A4093718C648FD64940E141B3EBDE744A4093718C648FD64940C87E164B91724A40EDBB22F8DFD24940C87E164B91724A40
13765	Шумовский	7	72	123	50.649351000000003	50.669697999999997	52.065719999999999	52.049373000000003	0103000020E61000000100000005000000FD4FFEEE1D5349401827BEDA51064A40FD4FFEEE1D534940B858518369084A402A1900AAB8554940B858518369084A402A1900AAB85549401827BEDA51064A40FD4FFEEE1D5349401827BEDA51064A40
14719	Утекаево	7	72	123	50.844034000000001	50.867156999999999	52.205309	52.200628000000002	0103000020E61000000100000005000000255B5D4E096C4940B954A52DAE194A40255B5D4E096C49408849B890471A4A40ADBF2500FF6E49408849B890471A4A40ADBF2500FF6E4940B954A52DAE194A40255B5D4E096C4940B954A52DAE194A40
13861	Устряловский	7	72	123	50.957841999999999	50.975726999999999	51.944021999999997	51.933633	0103000020E610000001000000050000001C5E10919A7A4940B2BB404981F749401C5E10919A7A49402D5A80B6D5F849407F69519FE47C49402D5A80B6D5F849407F69519FE47C4940B2BB404981F749401C5E10919A7A4940B2BB404981F74940
55897	Украинка	7	72	123	51.013464999999997	51.065216999999997	52.170248000000001	52.153266000000002	0103000020E6100000010000000500000000529B38B98149405CCB64389E134A4000529B38B9814940CE1ABCAFCA154A405512D90759884940CE1ABCAFCA154A405512D907598849405CCB64389E134A4000529B38B98149405CCB64389E134A40
14065	Торшиловский	7	72	123	50.598101999999997	50.622042999999998	52.111085000000003	52.092773999999999	0103000020E610000001000000050000000AD6389B8E4C4940A5F5B704E00B4A400AD6389B8E4C4940C0098508380E4A4055DAE21A9F4F4940C0098508380E4A4055DAE21A9F4F4940A5F5B704E00B4A400AD6389B8E4C4940A5F5B704E00B4A40
48811	Сестры	7	72	123	50.198279999999997	50.223908999999999	52.044083999999998	52.032549000000003	0103000020E61000000100000005000000B6B9313D611949403E42CD902A044A40B6B9313D611949407023658BA4054A40D923D40CA91C49407023658BA4054A40D923D40CA91C49403E42CD902A044A40B6B9313D611949403E42CD902A044A40
40260	Полянский	7	72	123	50.899757000000001	50.911399000000003	51.894405999999996	51.882761000000002	0103000020E610000001000000050000006DACC43C2B7349409697FC4FFEF049406DACC43C2B7349404FAC53E57BF24940B64DF1B8A87449404FAC53E57BF24940B64DF1B8A87449409697FC4FFEF049406DACC43C2B7349409697FC4FFEF04940
48922	Поляков	7	72	123	50.806224	50.825026000000001	51.938741999999998	51.925291999999999	0103000020E610000001000000050000000AA01859326749400EA0DFF76FF649400AA0185932674940D9B0A6B228F84940C32CB4739A694940D9B0A6B228F84940C32CB4739A6949400EA0DFF76FF649400AA01859326749400EA0DFF76FF64940
14433	Пензено	7	72	123	50.440511000000001	50.461289000000001	52.126247999999997	52.100216000000003	0103000020E610000001000000050000009E4319AA623849409A44BDE0D30C4A409E4319AA62384940BB97FBE428104A40958098840B3B4940BB97FBE428104A40958098840B3B49409A44BDE0D30C4A409E4319AA623849409A44BDE0D30C4A40
248	Пекилянка	7	72	123	50.669410999999997	50.690278999999997	52.240577999999999	52.225509000000002	0103000020E61000000100000005000000944A7842AF55494012FA997ADD1C4A40944A7842AF5549408C118942CB1E4A40CB0EF10F5B5849408C118942CB1E4A40CB0EF10F5B58494012FA997ADD1C4A40944A7842AF55494012FA997ADD1C4A40
14449	Новый Камелик	7	72	123	50.445585999999999	50.469481999999999	52.032688	52.013213999999998	0103000020E6100000010000000500000019C748F608394940B7EC10FFB0014A4019C748F6083949405F7CD11E2F044A40C40776FC173C49405F7CD11E2F044A40C40776FC173C4940B7EC10FFB0014A4019C748F608394940B7EC10FFB0014A40
13482	Малая Черниговка	7	72	123	50.717227999999999	50.730730000000001	52.146684	52.134816999999998	0103000020E6100000010000000500000043E38920CE5B4940F0F8F6AE41114A4043E38920CE5B4940596C938AC6124A40611A868F885D4940596C938AC6124A40611A868F885D4940F0F8F6AE41114A4043E38920CE5B4940F0F8F6AE41114A40
48821	Краснооктябрьский	7	72	123	51.120804999999997	51.160879000000001	52.164912000000001	52.153939999999999	0103000020E61000000100000005000000BD18CA89768F4940EBC5504EB4134A40BD18CA89768F4940E65B1FD61B154A407DCEDDAE97944940E65B1FD61B154A407DCEDDAE97944940EBC5504EB4134A40BD18CA89768F4940EBC5504EB4134A40
48863	Костино	7	72	123	51.295859999999998	51.314535999999997	52.177677000000003	52.169387	0103000020E61000000100000005000000E71890BDDEA549400CAF2479AE154A40E71890BDDEA549402E20B41EBE164A4013B534B742A849402E20B41EBE164A4013B534B742A849400CAF2479AE154A40E71890BDDEA549400CAF2479AE154A40
48837	Исток	7	72	123	51.252929000000002	51.270733999999997	52.173982000000002	52.166944999999998	0103000020E61000000100000005000000E19A3BFA5FA04940889D29745E154A40E19A3BFA5FA04940DD0BCC0A45164A4027F56569A7A24940DD0BCC0A45164A4027F56569A7A24940889D29745E154A40E19A3BFA5FA04940889D29745E154A40
5719	Иргизский	7	72	123	50.904428000000003	50.924002000000002	52.185363000000002	52.176732000000001	0103000020E6100000010000000500000019CBF44BC47349400E1478279F164A4019CBF44BC4734940B9718BF9B9174A4024B891B245764940B9718BF9B9174A4024B891B2457649400E1478279F164A4019CBF44BC47349400E1478279F164A40
13973	Глушицкий	7	72	123	50.415556000000002	50.445729999999998	52.173721999999998	52.137244000000003	0103000020E610000001000000050000000BD462F0303549403FC91D3691114A400BD462F030354940404CC2853C164A404C6C3EAE0D394940404CC2853C164A404C6C3EAE0D3949403FC91D3691114A400BD462F0303549403FC91D3691114A40
48655	Восточный	7	72	123	51.081907999999999	51.110492999999998	51.965130000000002	51.943615999999999	0103000020E61000000100000005000000F0A31AF67B8A4940BDFDB968C8F84940F0A31AF67B8A4940BA313D6189FB4940EDB776A2248E4940BA313D6189FB4940EDB776A2248E4940BDFDB968C8F84940F0A31AF67B8A4940BDFDB968C8F84940
13919	Верхние Росташи	7	72	123	51.164023	51.182690000000001	52.058000999999997	52.047046999999999	0103000020E610000001000000050000005A65A6B4FE944940FD2FD7A205064A405A65A6B4FE9449405111A7936C074A4033A7CB62629749405111A7936C074A4033A7CB6262974940FD2FD7A205064A405A65A6B4FE944940FD2FD7A205064A40
5596	Большая Черниговка	7	72	123	50.830955000000003	50.886308999999997	52.109492000000003	52.077112999999997	0103000020E610000001000000050000004EB9C2BB5C6A4940588CBAD6DE094A404EB9C2BB5C6A49403A9677D5030E4A404293C492727149403A9677D5030E4A404293C49272714940588CBAD6DE094A404EB9C2BB5C6A4940588CBAD6DE094A40
48748	Благодатовка	7	72	123	50.436261999999999	50.459384999999997	52.234495000000003	52.221730000000001	0103000020E61000000100000005000000683EE76ED737494063450DA6611C4A40683EE76ED7374940AB09A2EE031E4A40F0A2AF20CD3A4940AB09A2EE031E4A40F0A2AF20CD3A494063450DA6611C4A40683EE76ED737494063450DA6611C4A40
48923	Алексеевский	7	72	123	50.854598000000003	50.868091	51.992972000000002	51.982944000000003	0103000020E610000001000000050000000F9D9E77636D494054E6E61BD1FD49400F9D9E77636D4940FFEBDCB419FF4940D9791B9B1D6F4940FFEBDCB419FF4940D9791B9B1D6F494054E6E61BD1FD49400F9D9E77636D494054E6E61BD1FD4940
14161	Аверьяновский	7	72	123	50.304254999999998	50.336019	52.085225999999999	52.071460999999999	0103000020E610000001000000050000007E52EDD3F126494040F850A225094A407E52EDD3F12649406B6281AFE80A4A40D5EAABAB022B49406B6281AFE80A4A40D5EAABAB022B494040F850A225094A407E52EDD3F126494040F850A225094A40
13314	Августовка	7	72	123	50.712997000000001	50.757688000000002	52.264212999999998	52.232542000000002	0103000020E61000000100000005000000B492567C435B49402579AEEFC31D4A40B492567C435B4940CA1649BBD1214A402C499EEBFB604940CA1649BBD1214A402C499EEBFB6049402579AEEFC31D4A40B492567C435B49402579AEEFC31D4A40
24026	Южный	7	72	766	51.043801999999999	51.081404999999997	52.345469999999999	52.324585999999996	0103000020E61000000100000005000000ECBFCE4D9B854940A65EB7088C294A40ECBFCE4D9B854940E3DF675C382C4A408D5DA27A6B8A4940E3DF675C382C4A408D5DA27A6B8A4940A65EB7088C294A40ECBFCE4D9B854940A65EB7088C294A40
48316	Фрунзенский	7	72	766	50.785885999999998	50.815091000000002	52.402743000000001	52.391598999999999	0103000020E610000001000000050000002F3196E997644940BA1281EA1F324A402F3196E997644940B2D826158D334A40C921E2E654684940B2D826158D334A40C921E2E654684940BA1281EA1F324A402F3196E997644940BA1281EA1F324A40
12591	Таш-Кустьяново	7	72	766	51.228341999999998	51.247486000000002	52.306072	52.294187000000001	0103000020E61000000100000005000000D026874F3A9D494045F46BEBA7254A40D026874F3A9D4940541C075E2D274A40E31B0A9FAD9F4940541C075E2D274A40E31B0A9FAD9F494045F46BEBA7254A40D026874F3A9D494045F46BEBA7254A40
48270	Тамбовка	7	72	766	50.572285000000001	50.611567999999998	52.376483	52.348737999999997	0103000020E61000000100000005000000E57E87A240494940AC6F6072A32C4A40E57E87A240494940FF3F4E9830304A40DBA337DC474E4940FF3F4E9830304A40DBA337DC474E4940AC6F6072A32C4A40E57E87A240494940AC6F6072A32C4A40
12107	Среднедольск	7	72	766	50.717309	50.732104	52.577064	52.565471000000002	0103000020E61000000100000005000000301004C8D05B494010EB8D5A61484A40301004C8D05B494077D9AF3BDD494A40A9A27895B55D494077D9AF3BDD494A40A9A27895B55D494010EB8D5A61484A40301004C8D05B494010EB8D5A61484A40
48091	Озерск	7	72	766	50.888599999999997	50.902999999999999	52.447718999999999	52.437103	0103000020E61000000100000005000000E09C11A5BD714940E3FDB8FDF2374A40E09C11A5BD7149401F662FDB4E394A40DD240681957349401F662FDB4E394A40DD24068195734940E3FDB8FDF2374A40E09C11A5BD714940E3FDB8FDF2374A40
12650	Муратшино	7	72	766	51.108533999999999	51.130299999999998	52.324674000000002	52.314368999999999	0103000020E6100000010000000500000085402E71E48D494028F04E3E3D284A4085402E71E48D494046EEE9EA8E294A409B559FABAD90494046EEE9EA8E294A409B559FABAD90494028F04E3E3D284A4085402E71E48D494028F04E3E3D284A40
12337	Морша	7	72	766	50.724854999999998	50.784638000000001	52.414487999999999	52.389961	0103000020E61000000100000005000000C9AB730CC85C494094DBF63DEA314A40C9AB730CC85C4940CF4A5AF10D354A4074999A046F644940CF4A5AF10D354A4074999A046F64494094DBF63DEA314A40C9AB730CC85C494094DBF63DEA314A40
12158	Мокша	7	72	766	50.398181999999998	50.430602999999998	52.681296000000003	52.660795999999998	0103000020E610000001000000050000008DEDB5A0F7324940EFA99CF694544A408DEDB5A0F7324940A47213B534574A409D47C5FF1D374940A47213B534574A409D47C5FF1D374940EFA99CF694544A408DEDB5A0F7324940EFA99CF694544A40
12929	Малый Каралык	7	72	766	50.817883999999999	50.842686999999998	52.394660000000002	52.386251000000001	0103000020E61000000100000005000000F9F5436CB06849400E863AAC70314A40F9F5436CB06849400A85083884324A40D6E1E82ADD6B49400A85083884324A40D6E1E82ADD6B49400E863AAC70314A40F9F5436CB06849400E863AAC70314A40
48125	Малороссийский	7	72	766	50.973723999999997	51.012855000000002	52.358764999999998	52.344721999999997	0103000020E6100000010000000500000047AAEFFCA27C4940191BBAD91F2C4A4047AAEFFCA27C494087F9F202EC2D4A40884B8E3BA581494087F9F202EC2D4A40884B8E3BA5814940191BBAD91F2C4A4047AAEFFCA27C4940191BBAD91F2C4A40
12724	Малая Глушица	7	72	766	50.182461000000004	50.225175999999998	52.450096000000002	52.424413000000001	0103000020E61000000100000005000000D2E5CDE15A174940A67F492A53364A40D2E5CDE15A174940BC07E8BE9C394A400BEC3191D21C4940BC07E8BE9C394A400BEC3191D21C4940A67F492A53364A40D2E5CDE15A174940A67F492A53364A40
12097	Малая Вязовка	7	72	766	50.556770999999998	50.569769999999998	52.648417000000002	52.631701	0103000020E610000001000000050000003C2EAA4544474940DDEC0F94DB504A403C2EAA4544474940D1950854FF524A40F71E2E39EE484940D1950854FF524A40F71E2E39EE484940DDEC0F94DB504A403C2EAA4544474940DDEC0F94DB504A40
12245	Ледяйка	7	72	766	50.493000000000002	50.499782000000003	52.572969999999998	52.563800999999998	0103000020E61000000100000005000000C976BE9F1A3F4940DE3994A12A484A40C976BE9F1A3F494068CBB91457494A40939048DBF83F494068CBB91457494A40939048DBF83F4940DE3994A12A484A40C976BE9F1A3F4940DE3994A12A484A40
12495	Кочевной	7	72	766	51.021326000000002	51.036624000000003	52.299683999999999	52.290540999999997	0103000020E61000000100000005000000FA4674CFBA824940D5928E7230254A40FA4674CFBA8249403691990B5C264A40D61F6118B08449403691990B5C264A40D61F6118B0844940D5928E7230254A40FA4674CFBA824940D5928E7230254A40
55890	Константиновка	7	72	766	50.132083000000002	50.179371000000003	52.457022000000002	52.432825000000001	0103000020E61000000100000005000000C5AD8218E810494013F241CF66374A40C5AD8218E8104940B9C667B27F3A4A40E86C01A1F5164940B9C667B27F3A4A40E86C01A1F516494013F241CF66374A40C5AD8218E810494013F241CF66374A40
48452	Кобзевка	7	72	766	50.573901999999997	50.591500000000003	52.299866000000002	52.279544000000001	0103000020E61000000100000005000000F38DE89E7549494082E50819C8234A40F38DE89E754949405797530262264A40C1CAA145B64B49405797530262264A40C1CAA145B64B494082E50819C8234A40F38DE89E7549494082E50819C8234A40
12389	Верхнедольск	7	72	766	50.738481999999998	50.752423999999998	52.520670000000003	52.506832000000003	0103000020E61000000100000005000000A3570394865E49407C48F8DEDF404A40A3570394865E494011018750A5424A40DD5CFC6D4F60494011018750A5424A40DD5CFC6D4F6049407C48F8DEDF404A40A3570394865E49407C48F8DEDF404A40
12298	Большая Дергуновка	7	72	766	50.315834000000002	50.344642999999998	52.510395000000003	52.467370000000003	0103000020E61000000100000005000000817B9E3F6D284940D690B8C7D23B4A40817B9E3F6D2849405E85949F54414A40CDE506431D2C49405E85949F54414A40CDE506431D2C4940D690B8C7D23B4A40817B9E3F6D284940D690B8C7D23B4A40
5371	Большая Глушица	7	72	766	50.443655	50.517991000000002	52.424813999999998	52.371617000000001	0103000020E610000001000000050000007BDAE1AFC93849409ED15625912F4A407BDAE1AFC938494004711E4E60364A40A94F72874D42494004711E4E60364A40A94F72874D4249409ED15625912F4A407BDAE1AFC93849409ED15625912F4A40
55891	Александровка	7	72	766	50.590305000000001	50.625366	52.618001	52.576400999999997	0103000020E6100000010000000500000028D53E1D8F4B4940DB300A82C7494A4028D53E1D8F4B494099F221A81A4F4A40E2033BFE0B50494099F221A81A4F4A40E2033BFE0B504940DB300A82C7494A4028D53E1D8F4B4940DB300A82C7494A40
47919	Центральный	7	72	726	51.109172000000001	51.131180999999998	53.037765	53.029442000000003	0103000020E61000000100000005000000C8D11C59F98D49407E9065C1C4834A40C8D11C59F98D49407BF7C77BD5844A40A46DFC89CA9049407BF7C77BD5844A40A46DFC89CA9049407E9065C1C4834A40C8D11C59F98D49407E9065C1C4834A40
5059	Съезжее	7	72	726	51.180551999999999	51.231225999999999	53.026035999999998	52.997965999999998	0103000020E610000001000000050000001B9DF3531C9749408D429259BD7F4A401B9DF3531C9749406342CC2555834A4011FE45D0989D49406342CC2555834A4011FE45D0989D49408D429259BD7F4A401B9DF3531C9749408D429259BD7F4A40
11842	Печинено	7	72	726	51.205885000000002	51.237793000000003	53.070998000000003	53.057702999999997	0103000020E6100000010000000500000055DE8E705A9A4940C7F0D8CF62874A4055DE8E705A9A49406C0A647616894A40DF1B4300709E49406C0A647616894A40DF1B4300709E4940C7F0D8CF62874A4055DE8E705A9A4940C7F0D8CF62874A40
55922	Петровский	7	72	726	51.128368999999999	51.13984	53.036898999999998	53.031841	0103000020E61000000100000005000000FD6838656E90494002D6AA5D13844A40FD6838656E904940A7203F1BB9844A401956F146E6914940A7203F1BB9844A401956F146E691494002D6AA5D13844A40FD6838656E90494002D6AA5D13844A40
47824	Максимовка	7	72	726	51.115873000000001	51.162658	52.990312000000003	52.965744999999998	0103000020E61000000100000005000000A5BE2CEDD48E494044A33B889D7B4A40A5BE2CEDD48E49400E6B2A8BC27E4A40653733FAD19449400E6B2A8BC27E4A40653733FAD194494044A33B889D7B4A40A5BE2CEDD48E494044A33B889D7B4A40
11569	Кураповка	7	72	726	51.338960999999998	51.392643999999997	53.0794	53.056733999999999	0103000020E610000001000000050000004ACFF41263AB49401F49490F43874A404ACFF41263AB4940B5A679C7298A4A403D7C992842B24940B5A679C7298A4A403D7C992842B249401F49490F43874A404ACFF41263AB49401F49490F43874A40
5325	Заливной	7	72	726	51.429986999999997	51.446390999999998	53.056404000000001	53.046698999999997	0103000020E61000000100000005000000425A63D009B74940C1E09A3BFA854A40425A63D009B749408AAE0B3F38874A40471D1D5723B949408AAE0B3F38874A40471D1D5723B94940C1E09A3BFA854A40425A63D009B74940C1E09A3BFA854A40
11675	Виловатое	7	72	726	51.414535999999998	51.482205999999998	53.031782	53.017406999999999	0103000020E61000000100000005000000E08101840FB5494059DC7F643A824A40E08101840FB54940FD4CBD6E11844A40ADF71BEDB8BD4940FD4CBD6E11844A40ADF71BEDB8BD494059DC7F643A824A40E08101840FB5494059DC7F643A824A40
11336	Богатое	7	72	726	51.311211999999998	51.353918	53.072302000000001	53.048929000000001	0103000020E61000000100000005000000B60F79CBD5A74940BA69334E43864A40B60F79CBD5A74940BBB7223141894A409DBB5D2F4DAD4940BBB7223141894A409DBB5D2F4DAD4940BA69334E43864A40B60F79CBD5A74940BA69334E43864A40
47659	Беловка	7	72	726	51.348455999999999	51.391790999999998	53.194215999999997	53.175519000000001	0103000020E61000000100000005000000280CCA349AAC4940CF69166877964A40280CCA349AAC4940122EE411DC984A40FEEE1D3526B24940122EE411DC984A40FEEE1D3526B24940CF69166877964A40280CCA349AAC4940CF69166877964A40
11222	Арзамасцевка	7	72	726	51.348770999999999	51.386750999999997	53.176338999999999	53.162229000000004	0103000020E6100000010000000500000088653387A4AC49403DBB7CEBC3944A4088653387A4AC49403201BF4692964A40FF58880E81B149403201BF4692964A40FF58880E81B149403DBB7CEBC3944A4088653387A4AC49403DBB7CEBC3944A40
11237	Аверьяновка	7	72	726	51.295293999999998	51.324893000000003	53.166466999999997	53.151516000000001	0103000020E610000001000000050000003E5A9C31CCA549400E6954E064934A403E5A9C31CCA549407E6E68CA4E954A4084D9041896A949407E6E68CA4E954A4084D9041896A949400E6954E064934A403E5A9C31CCA549400E6954E064934A40
55862	станция Звезда	7	72	705	49.613233999999999	49.614268000000003	52.957326000000002	52.957059999999998	0103000020E61000000100000005000000CB65A3737ECE4840A6272CF1807A4A40CB65A3737ECE484025CE8AA8897A4A405B7D7555A0CE484025CE8AA8897A4A405B7D7555A0CE4840A6272CF1807A4A40CB65A3737ECE4840A6272CF1807A4A40
55909	ст.Мыльная	7	72	705	49.079312000000002	49.080146999999997	53.049323999999999	53.049112999999998	0103000020E61000000100000005000000161747E5268A48407B67B45549864A40161747E5268A48403674B33F50864A40AEEFC341428A48403674B33F50864A40AEEFC341428A48407B67B45549864A40161747E5268A48407B67B45549864A40
24225	Троицкое	7	72	705	49.730266999999998	49.749265999999999	52.871926000000002	52.854311000000003	0103000020E610000001000000050000008C2C996379DD484079CE16105A6D4A408C2C996379DD48401C446B459B6F4A409B00C3F2E7DF48401C446B459B6F4A409B00C3F2E7DF484079CE16105A6D4A408C2C996379DD484079CE16105A6D4A40
47596	Прибой	7	72	705	49.642924000000001	49.663037000000003	52.874763000000002	52.861086	0103000020E6100000010000000500000021E868554BD248409085E810386E4A4021E868554BD248401C60E63BF86F4A40DC847B65DED448401C60E63BF86F4A40DC847B65DED448409085E810386E4A4021E868554BD248409085E810386E4A40
11045	Преполовенка	7	72	705	48.98462	49.035527999999999	53.081791000000003	53.066875000000003	0103000020E61000000100000005000000677E3507087E4840C3F5285C8F884A40677E3507087E4840B70DA320788A4A40D00B772E8C844840B70DA320788A4A40D00B772E8C844840C3F5285C8F884A40677E3507087E4840C3F5285C8F884A40
47516	Песочное	7	72	705	49.418084	49.449894	52.932158999999999	52.921725000000002	0103000020E610000001000000050000008D7DC9C683B54840EB73B515FB754A408D7DC9C683B5484006D671FC50774A405455682096B9484006D671FC50774A405455682096B94840EB73B515FB754A408D7DC9C683B54840EB73B515FB754A40
47300	Осинки	7	72	705	49.502867000000002	49.528002000000001	52.859242999999999	52.837603000000001	0103000020E610000001000000050000006B9E23F25DC0484008043A93366B4A406B9E23F25DC048409128B4ACFB6D4A407E1CCD9195C348409128B4ACFB6D4A407E1CCD9195C3484008043A93366B4A406B9E23F25DC0484008043A93366B4A40
55860	Ольгино	7	72	705	49.101419	49.128405000000001	52.883338999999999	52.871322999999997	0103000020E61000000100000005000000B5183C4CFB8C484055A01683876F4A40B5183C4CFB8C484003249A4011714A404AD235936F90484003249A4011714A404AD235936F90484055A01683876F4A40B5183C4CFB8C484055A01683876F4A40
10974	Новомихайловка	7	72	705	49.387703000000002	49.400728999999998	52.844712999999999	52.831167999999998	0103000020E61000000100000005000000D2C77C40A0B14840A9BD88B6636A4A40D2C77C40A0B14840C6C03A8E1F6C4A4086C77E164BB34840C6C03A8E1F6C4A4086C77E164BB34840A9BD88B6636A4A40D2C77C40A0B14840A9BD88B6636A4A40
47653	Никольское	7	72	705	49.448025000000001	49.484605000000002	53.048068000000001	53.032035999999998	0103000020E610000001000000050000002C6519E258B94840B72572C119844A402C6519E258B94840F8FD9B1727864A40323D618907BE4840F8FD9B1727864A40323D618907BE4840B72572C119844A402C6519E258B94840B72572C119844A40
47431	Натальино	7	72	705	49.034970999999999	49.061380999999997	52.952368	52.927408999999997	0103000020E610000001000000050000007AA702EE798448400E828E56B5764A407AA702EE79844840E3E0D231E7794A4042CC2555DB874840E3E0D231E7794A4042CC2555DB8748400E828E56B5764A407AA702EE798448400E828E56B5764A40
11221	Макарьевка	7	72	705	48.963977	48.981566000000001	52.857384000000003	52.842253999999997	0103000020E61000000100000005000000508C2C99637B48406C76A4FACE6B4A40508C2C99637B48408D0E48C2BE6D4A40CA6E66F4A37D48408D0E48C2BE6D4A40CA6E66F4A37D48406C76A4FACE6B4A40508C2C99637B48406C76A4FACE6B4A40
10259	Купино	7	72	705	49.544783000000002	49.578955000000001	53.002598999999996	52.983725999999997	0103000020E6100000010000000500000059350873BBC54840C91CCBBBEA7D4A4059350873BBC548404B00FE2955804A40876D8B321BCA48404B00FE2955804A40876D8B321BCA4840C91CCBBBEA7D4A4059350873BBC54840C91CCBBBEA7D4A40
10869	Красноселки	7	72	705	49.286760000000001	49.295625999999999	52.969188000000003	52.956457999999998	0103000020E6100000010000000500000086E63A8DB4A44840B0FF3A376D7A4A4086E63A8DB4A448407CD6355A0E7C4A4074ECA012D7A548407CD6355A0E7C4A4074ECA012D7A54840B0FF3A376D7A4A4086E63A8DB4A44840B0FF3A376D7A4A40
10681	Кануевка	7	72	705	49.251931999999996	49.31335	53.166753	53.131622999999998	0103000020E610000001000000050000006E68CA4E3FA048406133C005D9904A406E68CA4E3FA0484044C18C2958954A40CE1951DA1BA8484044C18C2958954A40CE1951DA1BA848406133C005D9904A406E68CA4E3FA048406133C005D9904A40
47517	Заволжский	7	72	705	49.315280999999999	49.325279999999999	52.982343	52.972468999999997	0103000020E610000001000000050000006C06B8205BA84840D9AF3BDD797C4A406C06B8205BA848402E3A596ABD7D4A407D0569C6A2A948402E3A596ABD7D4A407D0569C6A2A94840D9AF3BDD797C4A406C06B8205BA84840D9AF3BDD797C4A40
47383	Екатериновка	7	72	705	49.417276000000001	49.461328999999999	53.106990000000003	53.064770000000003	0103000020E61000000100000005000000EEB3CA4C69B5484087E123624A884A40EEB3CA4C69B54840E17F2BD9B18D4A4023D923D40CBB4840E17F2BD9B18D4A4023D923D40CBB484087E123624A884A40EEB3CA4C69B5484087E123624A884A40
45709	Дмитриевка	7	72	705	49.442706999999999	49.456398	52.966845999999997	52.955703999999997	0103000020E61000000100000005000000EA5A7B9FAAB8484004543882547A4A40EA5A7B9FAAB848405B22179CC17B4A40DBFAE93F6BBA48405B22179CC17B4A40DBFAE93F6BBA484004543882547A4A40EA5A7B9FAAB8484004543882547A4A40
4908	Безенчук	7	72	705	49.393228000000001	49.478513999999997	52.998610999999997	52.965023000000002	0103000020E610000001000000050000008DEF8B4B55B24840A471A8DF857B4A408DEF8B4B55B248408236397CD27F4A40CD565EF23FBD48408236397CD27F4A40CD565EF23FBD4840A471A8DF857B4A408DEF8B4B55B24840A471A8DF857B4A40
9484	Шариповка	7	72	664	51.282071000000002	51.307592	52.367097000000001	52.353782000000002	0103000020E6100000010000000500000034130CE71AA44940EDF483BA482D4A4034130CE71AA44940D8BAD408FD2E4A407041B62C5FA74940D8BAD408FD2E4A407041B62C5FA74940EDF483BA482D4A4034130CE71AA44940EDF483BA482D4A40
46699	Субботинский	7	72	664	51.413933999999998	51.436059999999998	52.612479	52.598455999999999	0103000020E61000000100000005000000EA5910CAFBB44940280CCA349A4C4A40EA5910CAFBB449404F3E3DB6654E4A40008C67D0D0B749404F3E3DB6654E4A40008C67D0D0B74940280CCA349A4C4A40EA5910CAFBB44940280CCA349A4C4A40
47045	Славинка	7	72	664	50.959980000000002	50.995158000000004	52.543590999999999	52.530006999999998	0103000020E610000001000000050000003468E89FE07A494056D3F544D7434A403468E89FE07A494031B3CF6394454A40282D5C56617F494031B3CF6394454A40282D5C56617F494056D3F544D7434A403468E89FE07A494056D3F544D7434A40
9264	Седыши	7	72	664	51.371687000000001	51.390101999999999	52.783203	52.770254999999999	0103000020E6100000010000000500000097AC8A7093AF49404D4A41B797624A4097AC8A7093AF49408690F3FE3F644A40560DC2DCEEB149408690F3FE3F644A40560DC2DCEEB149404D4A41B797624A4097AC8A7093AF49404D4A41B797624A40
9883	Самовольно-Ивановка	7	72	664	50.851543999999997	50.899613000000002	52.558891000000003	52.536366999999998	0103000020E61000000100000005000000718DCF64FF6C4940AAD381ACA7444A40718DCF64FF6C4940AE8383BD89474A403A07CF8426734940AE8383BD89474A403A07CF8426734940AAD381ACA7444A40718DCF64FF6C4940AAD381ACA7444A40
9216	Первокоммунарский	7	72	664	51.306100999999998	51.329537999999999	52.869714000000002	52.851216999999998	0103000020E61000000100000005000000EE224C512EA749404D66BCADF46C4A40EE224C512EA74940CA6FD1C9526F4A4006651A4D2EAA4940CA6FD1C9526F4A4006651A4D2EAA49404D66BCADF46C4A40EE224C512EA749404D66BCADF46C4A40
4523	Патровка	7	72	664	51.310124999999999	51.334567999999997	52.520490000000002	52.492972999999999	0103000020E6100000010000000500000004560E2DB2A74940CF6740BD193F4A4004560E2DB2A7494091F2936A9F424A40E124CD1FD3AA494091F2936A9F424A40E124CD1FD3AA4940CF6740BD193F4A4004560E2DB2A74940CF6740BD193F4A40
9275	Осиповка	7	72	664	51.287685000000003	51.313763000000002	52.725642000000001	52.715273000000003	0103000020E610000001000000050000005F46B1DCD2A449401D5BCF108E5B4A405F46B1DCD2A44940514D49D6E15C4A40F1D8CF6229A84940514D49D6E15C4A40F1D8CF6229A849401D5BCF108E5B4A405F46B1DCD2A449401D5BCF108E5B4A40
9791	Ореховка	7	72	664	50.850726999999999	50.922592000000002	52.573255000000003	52.542343000000002	0103000020E610000001000000050000007F69519FE46C4940761BD47E6B454A407F69519FE46C49405EA27A6B60494A408FC6A17E177649405EA27A6B60494A408FC6A17E17764940761BD47E6B454A407F69519FE46C4940761BD47E6B454A40
46720	Новотроевка	7	72	664	51.307358000000001	51.319180000000003	52.547589000000002	52.533639000000001	0103000020E61000000100000005000000FD14C78157A74940616F62484E444A40FD14C78157A749401E53776517464A40C6C4E6E3DAA849401E53776517464A40C6C4E6E3DAA84940616F62484E444A40FD14C78157A74940616F62484E444A40
8955	Несмеяновка	7	72	664	51.087828000000002	51.110672000000001	52.622031	52.601070999999997	0103000020E6100000010000000500000028D6A9F23D8B494079C9FFE4EF4C4A4028D6A9F23D8B4940910C39B69E4F4A409D4A06802A8E4940910C39B69E4F4A409D4A06802A8E494079C9FFE4EF4C4A4028D6A9F23D8B494079C9FFE4EF4C4A40
9723	Летниково	7	72	664	50.974497	51.021380000000001	52.548552999999998	52.527202000000003	0103000020E610000001000000050000006A865451BC7C49406231EA5A7B434A406A865451BC7C4940B48F15FC36464A40ED647094BC824940B48F15FC36464A40ED647094BC8249406231EA5A7B434A406A865451BC7C49406231EA5A7B434A40
46752	Ленинградский	7	72	664	51.135734999999997	51.147243000000003	52.440973	52.433791999999997	0103000020E6100000010000000500000016F6B4C35F9149401AA20A7F86374A4016F6B4C35F914940A2B5A2CD71384A4050C8CEDBD8924940A2B5A2CD71384A4050C8CEDBD89249401AA20A7F86374A4016F6B4C35F9149401AA20A7F86374A40
9582	Корнеевка	7	72	664	51.346677999999997	51.384613000000002	52.719014999999999	52.703744999999998	0103000020E61000000100000005000000101FD8F15FAC49409CDCEF50145A4A40101FD8F15FAC4940AE2AFBAE085C4A40E84EB0FF3AB14940AE2AFBAE085C4A40E84EB0FF3AB149409CDCEF50145A4A40101FD8F15FAC49409CDCEF50145A4A40
9942	Калашиновка	7	72	664	51.080345000000001	51.098087	52.476213000000001	52.462657	0103000020E61000000100000005000000D5B2B5BE488A4940FB213658383B4A40D5B2B5BE488A49400C772E8CF43C4A40D594641D8E8C49400C772E8CF43C4A40D594641D8E8C4940FB213658383B4A40D5B2B5BE488A4940FB213658383B4A40
46687	Ильичевский	7	72	664	51.171506000000001	51.187109999999997	52.506853999999997	52.493017000000002	0103000020E61000000100000005000000AD889AE8F39549409FAF592E1B3F4A40AD889AE8F395494063EC8497E0404A4095607138F397494063EC8497E0404A4095607138F39749409FAF592E1B3F4A40AD889AE8F39549409FAF592E1B3F4A40
46995	Дальний	7	72	664	51.494458999999999	51.516970999999998	52.757193000000001	52.747228999999997	0103000020E610000001000000050000003F1BB96E4ABF4940B7CF2A33A55F4A403F1BB96E4ABF49404CE141B3EB604A407EFD101B2CC249404CE141B3EB604A407EFD101B2CC24940B7CF2A33A55F4A403F1BB96E4ABF4940B7CF2A33A55F4A40
46952	Герасимовка	7	72	664	51.491216000000001	51.525531999999998	52.712529000000004	52.696993999999997	0103000020E61000000100000005000000CFA2772AE0BE49400DC1711937594A40CFA2772AE0BE4940CE397826345B4A403080F0A144C34940CE397826345B4A403080F0A144C349400DC1711937594A40CFA2772AE0BE49400DC1711937594A40
46933	Гавриловский	7	72	664	51.384909999999998	51.406083000000002	52.417399000000003	52.405369	0103000020E61000000100000005000000A1F31ABB44B14940F7E7A221E3334A40A1F31ABB44B149400A3197546D354A40153B1A87FAB349400A3197546D354A40153B1A87FAB34940F7E7A221E3334A40A1F31ABB44B14940F7E7A221E3334A40
46865	Гавриловка	7	72	664	51.326537000000002	51.349516000000001	52.466213000000003	52.452916999999999	0103000020E610000001000000050000008CF7E3F6CBA94940B6662B2FF9394A408CF7E3F6CBA949402BFC19DEAC3B4A40E1B6B6F0BCAC49402BFC19DEAC3B4A40E1B6B6F0BCAC4940B6662B2FF9394A408CF7E3F6CBA94940B6662B2FF9394A40
46843	Антоновка	7	72	664	51.230525	51.244808999999997	52.678997000000003	52.659424999999999	0103000020E6100000010000000500000088F4DBD7819D49401895D40968544A4088F4DBD7819D4940838AAA5FE9564A401B62BCE6559F4940838AAA5FE9564A401B62BCE6559F49401895D40968544A4088F4DBD7819D49401895D40968544A40
55900	Алексеевка	7	72	664	51.256090999999998	51.293039	52.600009999999997	52.565170000000002	0103000020E6100000010000000500000064E60297C7A049401557957D57484A4064E60297C7A04940F0A2AF20CD4C4A40EDB94C4D82A54940F0A2AF20CD4C4A40EDB94C4D82A549401557957D57484A4064E60297C7A049401557957D57484A40
46770	Авангард	7	72	664	51.257106999999998	51.296712999999997	52.634372999999997	52.612572	0103000020E610000001000000050000004D49D6E1E8A04940003961C2684E4A404D49D6E1E8A04940923B6C2233514A4026A60BB1FAA54940923B6C2233514A4026A60BB1FAA54940003961C2684E4A404D49D6E1E8A04940003961C2684E4A40
56219	Юго-Камский	7	71	\N	55.549562000000002	55.623672999999997	57.719743000000001	57.676831999999997	0103000020E61000000100000005000000EB8F300C58C64B407171546EA2D64C40EB8F300C58C64B403143E38920DC4C40F8325184D4CF4B403143E38920DC4C40F8325184D4CF4B407171546EA2D64C40EB8F300C58C64B407171546EA2D64C40
58016	Шибаново	7	71	\N	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
22804	Чусовой	7	71	\N	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
56221	Чернушка	7	71	\N	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
16298	Чайковский	7	71	\N	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
56226	Фоки	7	71	\N	54.332974	54.388759	56.710416000000002	56.674163999999998	0103000020E610000001000000050000008B355CE49E2A4B40FD1186014B564C408B355CE49E2A4B400F4757E9EE5A4C404983DBDAC2314B400F4757E9EE5A4C404983DBDAC2314B40FD1186014B564C408B355CE49E2A4B40FD1186014B564C40
56231	Ферма	7	71	\N	56.28734	56.323855999999999	57.914155000000001	57.886645999999999	0103000020E61000000100000005000000946A9F8EC7244C408A90BA9D7DF14C40946A9F8EC7244C40C93CF20703F54C40834E081D74294C40C93CF20703F54C40834E081D74294C408A90BA9D7DF14C40946A9F8EC7244C408A90BA9D7DF14C40
58113	Успенка	7	71	\N	57.060583000000001	57.078603000000001	58.218134999999997	58.209398	0103000020E61000000100000005000000C7D8092FC1874C4085ECBC8DCD1A4D40C7D8092FC1874C40758E01D9EB1B4D400A2FC1A90F8A4C40758E01D9EB1B4D400A2FC1A90F8A4C4085ECBC8DCD1A4D40C7D8092FC1874C4085ECBC8DCD1A4D40
56236	Уральский	7	71	\N	55.502867999999999	55.574131000000001	57.959105000000001	57.927334000000002	0103000020E610000001000000050000003B1A87FA5DC04B40043C69E1B2F64C403B1A87FA5DC04B400D37E0F3C3FA4C40554FE61F7DC94B400D37E0F3C3FA4C40554FE61F7DC94B40043C69E1B2F64C403B1A87FA5DC04B40043C69E1B2F64C40
56233	Углеуральский	7	71	\N	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
56232	Сылва	7	71	\N	56.745058	56.784036	58.041218999999998	58.028111000000003	0103000020E61000000100000005000000C4CF7F0F5E5F4C4035D4282499034D40C4CF7F0F5E5F4C40A67C08AA46054D407E71A94A5B644C40A67C08AA46054D407E71A94A5B644C4035D4282499034D40C4CF7F0F5E5F4C4035D4282499034D40
6221	Соликамск	7	71	\N	56.727145999999998	56.811793999999999	59.665312	59.598647	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
29156	Скобелевка	7	71	\N	56.282983000000002	56.299852999999999	58.23901	58.225135999999999	0103000020E61000000100000005000000782975C938244C407D93A641D11C4D40782975C938244C405FB532E1971E4D40C24D469561264C405FB532E1971E4D40C24D469561264C407D93A641D11C4D40782975C938244C407D93A641D11C4D40
56251	Прикамский	7	71	\N	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
56224	Полазна	7	71	\N	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
56214	Платошино	7	71	\N	56.538167000000001	56.557229999999997	57.645054999999999	57.627854999999997	0103000020E61000000100000005000000AA6400A8E2444C40A6D0798D5DD04C40AA6400A8E2444C40868F882991D24C40CF2C095053474C40868F882991D24C40CF2C095053474C40A6D0798D5DD04C40AA6400A8E2444C40A6D0798D5DD04C40
83	Пермь	7	71	\N	55.789924999999997	56.661560000000001	58.184322000000002	57.860244999999999	0103000020E610000001000000050000007AA52C431CE54B4015C616821CEE4C407AA52C431CE54B4077F700DD97174D40BF2B82FFAD544C4077F700DD97174D40BF2B82FFAD544C4015C616821CEE4C407AA52C431CE54B4015C616821CEE4C40
58014	Парма	7	71	\N	57.179025000000003	57.201501	58.843718000000003	58.827902999999999	0103000020E610000001000000050000004D158C4AEA964C4051A1BAB9F8694D404D158C4AEA964C40F58590F3FE6B4D403F8EE6C8CA994C40F58590F3FE6B4D403F8EE6C8CA994C4051A1BAB9F8694D404D158C4AEA964C4051A1BAB9F8694D40
56229	Очер	7	71	\N	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
56216	Оса	7	71	\N	55.409264	55.483517999999997	57.294829	57.263398000000002	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
56213	Нытва	7	71	\N	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
58147	Нижний Лух	7	71	\N	56.304029999999997	56.360463000000003	58.764946000000002	58.755485999999998	0103000020E610000001000000050000005E807D74EA264C40FD4AE7C3B3604D405E807D74EA264C405F9A22C0E9614D408335CEA6232E4C405F9A22C0E9614D408335CEA6232E4C40FD4AE7C3B3604D405E807D74EA264C40FD4AE7C3B3604D40
58007	Нижние Муллы	7	71	\N	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
58078	Нагорнский	7	71	\N	57.532179999999997	57.564681	58.783864000000001	58.759878	0103000020E61000000100000005000000EACA67791EC44C409679ABAE43614D40EACA67791EC44C408141D2A755644D4017D68D7747C84C408141D2A755644D4017D68D7747C84C409679ABAE43614D40EACA67791EC44C409679ABAE43614D40
58035	Маховляне	7	71	\N	58.197454	58.219571000000002	57.761139	57.747664	0103000020E61000000100000005000000713B342C46194D40C2323674B3DF4C40713B342C46194D40E65AB4006DE14C4034130CE71A1C4D40E65AB4006DE14C4034130CE71A1C4D40C2323674B3DF4C40713B342C46194D40C2323674B3DF4C40
58150	Матвеево	7	71	\N	57.825031000000003	57.868248999999999	57.791148999999997	57.767677999999997	0103000020E61000000100000005000000D597A59D9AE94C40E9EDCF4543E24C40D597A59D9AE94C40ADA1D45E44E54C4071E481C822EF4C40ADA1D45E44E54C4071E481C822EF4C40E9EDCF4543E24C40D597A59D9AE94C40E9EDCF4543E24C40
56217	Ляды	7	71	\N	56.603501999999999	56.651957000000003	58.100546000000001	58.057330999999998	0103000020E610000001000000050000000989B48D3F4D4C400306499F56074D400989B48D3F4D4C402FDFFAB0DE0C4D40FBB2B45373534C402FDFFAB0DE0C4D40FBB2B45373534C400306499F56074D400989B48D3F4D4C400306499F56074D40
15896	Лысьва	7	71	\N	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
58033	Ломовка	7	71	\N	57.874851999999997	57.900084999999997	57.785521000000003	57.772602999999997	0103000020E610000001000000050000008B6B7C26FBEF4C404FE5B4A7E4E24C408B6B7C26FBEF4C401EA9BEF38BE44C40614F3BFC35F34C401EA9BEF38BE44C40614F3BFC35F34C404FE5B4A7E4E24C408B6B7C26FBEF4C404FE5B4A7E4E24C40
58149	Ласьва	7	71	\N	55.958601000000002	55.959589000000001	58.071190000000001	58.071066000000002	0103000020E61000000100000005000000DA740470B3FA4B40C4EDD0B018094D40DA740470B3FA4B40B0E600C11C094D40F94CF6CFD3FA4B40B0E600C11C094D40F94CF6CFD3FA4B40C4EDD0B018094D40DA740470B3FA4B40C4EDD0B018094D40
32907	Кунгур	7	71	\N	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
56218	Кукуштан	7	71	\N	56.448695000000001	56.529463	57.663421	57.631638000000002	0103000020E610000001000000050000007A7077D66E394C4097749483D9D04C407A7077D66E394C40643DB5FAEAD44C4095B88E71C5434C40643DB5FAEAD44C4095B88E71C5434C4097749483D9D04C407A7077D66E394C4097749483D9D04C40
2524	Кудымкар	7	71	\N	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
56211	Краснокамск	7	71	\N	55.438701000000002	56.208044999999998	58.351872	58.003321	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
56210	Красновишерск	7	71	\N	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
10335	Кондратово	7	71	\N	56.082659	56.125418000000003	57.992671000000001	57.968119000000002	0103000020E610000001000000050000002BDCF291940A4C4070D1C952EBFB4C402BDCF291940A4C400458E4D70FFF4C40352A70B20D104C400458E4D70FFF4C40352A70B20D104C4070D1C952EBFB4C402BDCF291940A4C4070D1C952EBFB4C40
7570	Кизел	7	71	\N	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
58030	Ивакинский карьер	7	71	\N	57.473438999999999	57.496893999999998	59.257745	59.245975999999999	0103000020E6100000010000000500000052D32EA699BC4C40EACC3D247C9F4D4052D32EA699BC4C4090DAC4C9FDA04D4010CAFB389ABF4C4090DAC4C9FDA04D4010CAFB389ABF4C40EACC3D247C9F4D4052D32EA699BC4C40EACC3D247C9F4D40
56265	ЗАТО Звездный	7	71	\N	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
1505	Добрянка	7	71	\N	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
120	Губаха	7	71	\N	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
77	Гремячинск	7	71	\N	57.741973000000002	57.889035999999997	58.59901	58.498963000000003	0103000020E61000000100000005000000ECC1A4F8F8DE4C4000750305DE3F4D40ECC1A4F8F8DE4C400DFD135CAC4C4D40BB7B80EECBF14C400DFD135CAC4C4D40BB7B80EECBF14C4000750305DE3F4D40ECC1A4F8F8DE4C4000750305DE3F4D40
56238	Горнозаводск	7	71	\N	58.295470000000002	58.344706000000002	58.397803000000003	58.366931999999998	0103000020E610000001000000050000007D7901F6D1254D408DEDB5A0F72E4D407D7901F6D1254D4017A06D35EB324D40145E82531F2C4D4017A06D35EB324D40145E82531F2C4D408DEDB5A0F72E4D407D7901F6D1254D408DEDB5A0F72E4D40
56230	Гамово	7	71	\N	56.089872	56.112670999999999	57.872371000000001	57.860923999999997	0103000020E61000000100000005000000BE69FAEC800B4C40B62BF4C132EE4C40BE69FAEC800B4C404A7D59DAA9EF4C40931ADA006C0E4C404A7D59DAA9EF4C40931ADA006C0E4C40B62BF4C132EE4C40BE69FAEC800B4C40B62BF4C132EE4C40
58052	Ветляны	7	71	\N	56.757005999999997	56.774082999999997	58.287511000000002	58.269604000000001	0103000020E6100000010000000500000019709692E5604C40766F456282224D4019709692E5604C40C11E1329CD244D40DDB1D82615634C40C11E1329CD244D40DDB1D82615634C40766F456282224D4019709692E5604C40766F456282224D40
56207	Верещагино	7	71	\N	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
58112	Валежная	7	71	\N	56.950853000000002	56.973059999999997	58.092807000000001	58.071199	0103000020E61000000100000005000000D926158DB5794C400341800C1D094D40D926158DB5794C4081EB8A19E10B4D40DB85E63A8D7C4C4081EB8A19E10B4D40DB85E63A8D7C4C400341800C1D094D40D926158DB5794C400341800C1D094D40
58119	Брод	7	71	\N	57.583168999999998	57.601529999999997	57.539850000000001	57.525480000000002	0103000020E6100000010000000500000040852348A5CA4C40DE59BBED42C34C4040852348A5CA4C40705F07CE19C54C400CC85EEFFECC4C40705F07CE19C54C400CC85EEFFECC4C40DE59BBED42C34C4040852348A5CA4C40DE59BBED42C34C40
58223	Бор-Ленва	7	71	\N	56.092081999999998	56.116506999999999	58.609174000000003	58.594081000000003	0103000020E610000001000000050000006F46CD57C90B4C406616A1D80A4C4D406F46CD57C90B4C4069C9E369F94D4D40A6608DB3E90E4C4069C9E369F94D4D40A6608DB3E90E4C406616A1D80A4C4D406F46CD57C90B4C406616A1D80A4C4D40
58107	Богомягково	7	71	\N	55.464717	55.488953000000002	57.343245000000003	57.334238999999997	0103000020E610000001000000050000009772BED87BBB4B401C06F357C8AA4C409772BED87BBB4B40FDC1C073EFAB4C40FB230C0396BE4B40FDC1C073EFAB4C40FB230C0396BE4B401C06F357C8AA4C409772BED87BBB4B401C06F357C8AA4C40
56225	Бершеть	7	71	\N	56.352584	56.38973	57.763928999999997	57.720469000000001	0103000020E61000000100000005000000E38BF678212D4C401364045438DC4C40E38BF678212D4C40A5BBEB6CC8E14C40922232ACE2314C40A5BBEB6CC8E14C40922232ACE2314C401364045438DC4C40E38BF678212D4C401364045438DC4C40
22854	Березники	7	71	\N	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
58148	Ананичи	7	71	\N	55.826746999999997	55.847866000000003	58.256447999999999	58.24953	0103000020E6100000010000000500000076887FD8D2E94B4079AF5A99F01F4D4076887FD8D2E94B40F38FBE49D3204D40F7B182DF86EC4B40F38FBE49D3204D40F7B182DF86EC4B4079AF5A99F01F4D4076887FD8D2E94B4079AF5A99F01F4D40
21403	Александровск	7	71	\N	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
47147	разрушенный Комсомольский	7	71	372	55.393003999999998	55.524805000000001	59.228808000000001	59.161191000000002	0103000020E610000001000000050000003D997FF44DB24B406CB41CE8A1944D403D997FF44DB24B4016889E94499D4D407EE36BCF2CC34B4016889E94499D4D407EE36BCF2CC34B406CB41CE8A1944D403D997FF44DB24B406CB41CE8A1944D40
4808	Юсьва	7	71	372	54.940693000000003	54.978395999999996	58.971071999999999	58.953263999999997	0103000020E61000000100000005000000BF49D3A068784B40213A048E047A4D40BF49D3A068784B40D90759164C7C4D40C34483143C7D4B40D90759164C7C4D40C34483143C7D4B40213A048E047A4D40BF49D3A068784B40213A048E047A4D40
5179	Чинагорт	7	71	372	54.988312999999998	55.013294999999999	59.055340000000001	59.047648000000002	0103000020E61000000100000005000000179B560A817E4B4023DC645419864D40179B560A817E4B409014916115874D40A4198BA6B3814B409014916115874D40A4198BA6B3814B4023DC645419864D40179B560A817E4B4023DC645419864D40
5648	Тукачево	7	71	372	55.555455000000002	55.580635000000001	59.186936000000003	59.173653000000002	0103000020E6100000010000000500000029B3412619C74B4018EDF1423A964D4029B3412619C74B40F838D384ED974D40DCF4673F52CA4B40F838D384ED974D40DCF4673F52CA4B4018EDF1423A964D4029B3412619C74B4018EDF1423A964D40
58336	Тимино	7	71	372	55.407063000000001	55.431829	59.096980000000002	59.090342	0103000020E61000000100000005000000B134F0A31AB44B4045BA9F53908B4D40B134F0A31AB44B40DC2E34D7698C4D40713B342C46B74B40DC2E34D7698C4D40713B342C46B74B4045BA9F53908B4D40B134F0A31AB44B4045BA9F53908B4D40
5907	Пожва	7	71	372	56.057892000000002	56.114046000000002	59.098846999999999	59.067363999999998	0103000020E610000001000000050000009B594B0169074C40C07630629F884D409B594B0169074C406327BC04A78C4D40AC1E300F990E4C406327BC04A78C4D40AC1E300F990E4C40C07630629F884D409B594B0169074C40C07630629F884D40
5399	Пиканово	7	71	372	55.207897000000003	55.236454999999999	59.094715000000001	59.083953000000001	0103000020E61000000100000005000000E0F76F5E9C9A4B4057B3CEF8BE8A4D40E0F76F5E9C9A4B4067B8019F1F8C4D40E3FC4D28449E4B4067B8019F1F8C4D40E3FC4D28449E4B4057B3CEF8BE8A4D40E0F76F5E9C9A4B4057B3CEF8BE8A4D40
5672	Они	7	71	372	55.69341	55.747371000000001	59.016795000000002	59.005614000000001	0103000020E61000000100000005000000145CACA8C1D84B402B33A5F5B7804D40145CACA8C1D84B4040DEAB5626824D404A7D59DAA9DF4B4040DEAB5626824D404A7D59DAA9DF4B402B33A5F5B7804D40145CACA8C1D84B402B33A5F5B7804D40
58290	Нижняя Волпа	7	71	372	54.999192000000001	55.014507999999999	59.097132999999999	59.089201000000003	0103000020E6100000010000000500000061360186E57F4B40A0E238F06A8B4D4061360186E57F4B40622EA9DA6E8C4D40E3C3EC65DB814B40622EA9DA6E8C4D40E3C3EC65DB814B40A0E238F06A8B4D4061360186E57F4B40A0E238F06A8B4D40
5092	Мелюхино	7	71	372	54.830443000000002	54.839731999999998	58.880043999999998	58.870536000000001	0103000020E610000001000000050000009818CBF44B6A4B40CEFE40B96D6F4D409818CBF44B6A4B4040852348A5704D40CCB392567C6B4B4040852348A5704D40CCB392567C6B4B40CEFE40B96D6F4D409818CBF44B6A4B40CEFE40B96D6F4D40
5748	Майкор	7	71	372	55.826630000000002	55.934356000000001	59.017581999999997	58.990915999999999	0103000020E610000001000000050000003DF20703CFE94B40A48AE255D67E4D403DF20703CFE94B40C77F812040824D40236937FA98F74B40C77F812040824D40236937FA98F74B40A48AE255D67E4D403DF20703CFE94B40A48AE255D67E4D40
7097	Купрос	7	71	372	55.504063000000002	55.525281	58.994498999999998	58.980367000000001	0103000020E61000000100000005000000D40FEA2285C04B40F08975AA7C7D4D40D40FEA2285C04B40CD7344BE4B7F4D40E71A66683CC34B40CD7344BE4B7F4D40E71A66683CC34B40F08975AA7C7D4D40D40FEA2285C04B40F08975AA7C7D4D40
5458	Крохалево	7	71	372	55.39949	55.433059999999998	58.965026999999999	58.924098999999998	0103000020E610000001000000050000001E8A027D22B34B4016A243E048764D401E8A027D22B34B40E5603601867B4D40569A94826EB74B40E5603601867B4D40569A94826EB74B4016A243E048764D401E8A027D22B34B4016A243E048764D40
56223	Комсомольский	7	71	372	55.393003999999998	55.524805000000001	59.228808000000001	59.161191000000002	0103000020E610000001000000050000003D997FF44DB24B406CB41CE8A1944D403D997FF44DB24B4016889E94499D4D407EE36BCF2CC34B4016889E94499D4D407EE36BCF2CC34B406CB41CE8A1944D403D997FF44DB24B406CB41CE8A1944D40
56272	Калино	7	71	372	55.417572999999997	55.425640000000001	59.077595000000002	59.072387999999997	0103000020E61000000100000005000000A758350873B54B40B94F8E0244894D40A758350873B54B40A4AA09A2EE894D404AEF1B5F7BB64B40A4AA09A2EE894D404AEF1B5F7BB64B40B94F8E0244894D40A758350873B54B40B94F8E0244894D40
5353	Доег	7	71	372	55.239894999999997	55.252102999999998	59.060231000000002	59.044148999999997	0103000020E61000000100000005000000A9BC1DE1B49E4B405793A7ACA6854D40A9BC1DE1B49E4B404A9A3FA6B5874D409B1C3EE944A04B404A9A3FA6B5874D409B1C3EE944A04B405793A7ACA6854D40A9BC1DE1B49E4B405793A7ACA6854D40
56515	Большая Мочга	7	71	372	55.587201999999998	55.613999	58.996979000000003	58.989984	0103000020E61000000100000005000000A912656F29CB4B4019C8B3CBB77E4D40A912656F29CB4B403FE603029D7F4D406B63EC8497CE4B403FE603029D7F4D406B63EC8497CE4B4019C8B3CBB77E4D40A912656F29CB4B4019C8B3CBB77E4D40
47314	Бажино	7	71	372	55.118461000000003	55.406973000000001	59.129100999999999	58.951453000000001	0103000020E61000000100000005000000FD6CE4BA298F4B402E573F36C9794D40FD6CE4BA298F4B40C170AE6186904D4071ADF6B017B44B40C170AE6186904D4071ADF6B017B44B402E573F36C9794D40FD6CE4BA298F4B402E573F36C9794D40
47368	Архангельское	7	71	372	54.958748999999997	54.985940999999997	59.035445000000003	59.027313999999997	0103000020E610000001000000050000004E098849B87A4B40895C70067F834D404E098849B87A4B4043E7357689844D408C648F50337E4B4043E7357689844D408C648F50337E4B40895C70067F834D404E098849B87A4B40895C70067F834D40
47436	Антипино	7	71	372	55.150719000000002	55.179572999999998	59.025298999999997	59.012971999999998	0103000020E6100000010000000500000063F19BC24A934B40C1E10511A9814D4063F19BC24A934B408DCF64FF3C834D404F1F813FFC964B408DCF64FF3C834D404F1F813FFC964B40C1E10511A9814D4063F19BC24A934B40C1E10511A9814D40
5498	Аксеново	7	71	372	55.356226999999997	55.372819	58.991013000000002	58.98563	0103000020E61000000100000005000000E179A9D898AD4B406EFAB31F297E4D40E179A9D898AD4B4097749483D97E4D40E9297288B8AF4B4097749483D97E4D40E9297288B8AF4B406EFAB31F297E4D40E179A9D898AD4B406EFAB31F297E4D40
56328	Азово	7	71	372	55.541082000000003	55.550164000000002	59.094127999999998	59.088017000000001	0103000020E61000000100000005000000263ACB2C42C54B40FB3E1C24448B4D40263ACB2C42C54B40A6D1E4620C8C4D40E1B721C66BC64B40A6D1E4620C8C4D40E1B721C66BC64B40FB3E1C24448B4D40263ACB2C42C54B40FB3E1C24448B4D40
3504	Юрла	7	71	562	54.284967999999999	54.337735000000002	59.340215999999998	59.313428999999999	0103000020E610000001000000050000000934D8D479244B401A4F04711EA84D400934D8D479244B40B8C9A8328CAB4D4077DB85E63A2B4B40B8C9A8328CAB4D4077DB85E63A2B4B401A4F04711EA84D400934D8D479244B401A4F04711EA84D40
58210	Юм	7	71	562	53.220869	55.242851000000002	59.746963000000001	59.119287	0103000020E61000000100000005000000A1D9756F459C4A4042EBE1CB448F4D40A1D9756F459C4A403929CC7B9CDF4D408466D7BD159F4B403929CC7B9CDF4D408466D7BD159F4B4042EBE1CB448F4D40A1D9756F459C4A4042EBE1CB448F4D40
4413	Чус	7	71	562	53.625478999999999	53.681533999999999	59.204650999999998	59.179403000000001	0103000020E61000000100000005000000DAAA24B20FD04A40F3E670ADF6964D40DAAA24B20FD04A40FE0B0401329A4D40588E90813CD74A40FE0B0401329A4D40588E90813CD74A40F3E670ADF6964D40DAAA24B20FD04A40F3E670ADF6964D40
4159	Чужья	7	71	562	54.240150999999997	54.256680000000003	59.424702000000003	59.418334000000002	0103000020E61000000100000005000000048D9944BD1E4B400667F0F78BB54D40048D9944BD1E4B40DD4598A25CB64D40C6C4E6E3DA204B40DD4598A25CB64D40C6C4E6E3DA204B400667F0F78BB54D40048D9944BD1E4B400667F0F78BB54D40
56396	Чугайнов Хутор	7	71	562	54.787117000000002	54.809987999999997	59.388832000000001	59.377851	0103000020E610000001000000050000001590F63FC0644B4065E1EB6B5DB04D401590F63FC0644B40B3D1393FC5B14D408313D1AFAD674B40B3D1393FC5B14D408313D1AFAD674B4065E1EB6B5DB04D401590F63FC0644B4065E1EB6B5DB04D40
3901	Усть-Зула	7	71	562	54.482785999999997	54.502719999999997	59.448743	59.439168000000002	0103000020E61000000100000005000000BB7B80EECB3D4B4091B932A836B84D40BB7B80EECB3D4B408BA71E6970B94D40C685032159404B408BA71E6970B94D40C685032159404B4091B932A836B84D40BB7B80EECB3D4B4091B932A836B84D40
47149	Усть-Березовка	7	71	562	53.637903000000001	53.683726	59.592616999999997	59.581156	0103000020E61000000100000005000000998235CEA6D14A40E5EFDE5163CA4D40998235CEA6D14A40DD06B5DFDACB4D4063B6645584D74A40DD06B5DFDACB4D4063B6645584D74A40E5EFDE5163CA4D40998235CEA6D14A40E5EFDE5163CA4D40
46800	Титова	7	71	562	54.252583999999999	54.269688000000002	59.259110999999997	59.249234000000001	0103000020E6100000010000000500000016BF29AC54204B40908653E6E69F4D4016BF29AC54204B4055849B8C2AA14D40D40FEA2285224B4055849B8C2AA14D40D40FEA2285224B40908653E6E69F4D4016BF29AC54204B40908653E6E69F4D40
4014	Пож	7	71	562	54.633190999999997	54.653303999999999	59.432757000000002	59.419198999999999	0103000020E610000001000000050000008E8F16670C514B4009C21550A8B54D408E8F16670C514B40BB0ED59464B74D40492C29779F534B40BB0ED59464B74D40492C29779F534B4009C21550A8B54D408E8F16670C514B4009C21550A8B54D40
4433	Петракова	7	71	562	53.913882999999998	53.927708000000003	59.425755000000002	59.416983999999999	0103000020E6100000010000000500000068AF3E1EFAF44A40467A51BB5FB54D4068AF3E1EFAF44A40E38DCC237FB64D40691EC022BFF64A40E38DCC237FB64D40691EC022BFF64A40467A51BB5FB54D4068AF3E1EFAF44A40467A51BB5FB54D40
58208	Остров	7	71	562	54.304884000000001	54.318537999999997	59.243772	59.237668999999997	0103000020E610000001000000050000006E895C7006274B40F22213F06B9E4D406E895C7006274B401BD7BFEB339F4D4041446ADAC5284B401BD7BFEB339F4D4041446ADAC5284B40F22213F06B9E4D406E895C7006274B40F22213F06B9E4D40
3640	Лопва	7	71	562	54.247311000000003	54.263094000000002	59.300773999999997	59.291772999999999	0103000020E61000000100000005000000757808E3A71F4B408B6D52D158A54D40757808E3A71F4B4059BE2EC37FA64D400DE36E10AD214B4059BE2EC37FA64D400DE36E10AD214B408B6D52D158A54D40757808E3A71F4B408B6D52D158A54D40
4168	Келич	7	71	562	54.144857999999999	54.161377999999999	59.447741000000001	59.437140999999997	0103000020E610000001000000050000003048FAB48A124B40D05E7D3CF4B74D403048FAB48A124B40070ABC934FB94D409E25C808A8144B40070ABC934FB94D409E25C808A8144B40D05E7D3CF4B74D403048FAB48A124B40D05E7D3CF4B74D40
3632	Зюздина	7	71	562	54.306195000000002	54.316597999999999	59.279128999999998	59.270691999999997	0103000020E610000001000000050000007099D36531274B40F8A41309A6A24D407099D36531274B40BE2EC37FBAA34D4050FD834886284B40BE2EC37FBAA34D4050FD834886284B40F8A41309A6A24D407099D36531274B40F8A41309A6A24D40
47038	Зарубина	7	71	562	53.990464000000003	54.005986999999998	59.271763	59.267169000000003	0103000020E61000000100000005000000C4EE3B86C7FE4A40A5C0029832A24D40C4EE3B86C7FE4A40A5A14621C9A24D40BF99982EC4004B40A5A14621C9A24D40BF99982EC4004B40A5C0029832A24D40C4EE3B86C7FE4A40A5C0029832A24D40
47053	Елога	7	71	562	53.905053000000002	53.924151000000002	59.339385	59.327759	0103000020E61000000100000005000000C712D6C6D8F34A401EFCC401F4A94D40C712D6C6D8F34A4061E0B9F770AB4D4069C878944AF64A4061E0B9F770AB4D4069C878944AF64A401EFCC401F4A94D40C712D6C6D8F34A401EFCC401F4A94D40
47015	Дубровка	7	71	562	54.039853999999998	54.058143000000001	59.279229999999998	59.269238999999999	0103000020E61000000100000005000000B14E95EF19054B4064E76D6C76A24D40B14E95EF19054B40F20703CFBDA34D40E4BED53A71074B40F20703CFBDA34D40E4BED53A71074B4064E76D6C76A24D40B14E95EF19054B4064E76D6C76A24D40
3817	Вятчина	7	71	562	54.525941000000003	54.536433000000002	59.281086999999999	59.270116999999999	0103000020E610000001000000050000001250E10852434B40FC8BA03193A24D401250E10852434B40562AA8A8FAA34D4062BF27D6A9444B40562AA8A8FAA34D4062BF27D6A9444B40FC8BA03193A24D401250E10852434B40FC8BA03193A24D40
3942	Верхняя Лобанова	7	71	562	54.446897999999997	54.460498999999999	59.409450999999997	59.398302999999999	0103000020E61000000100000005000000EB5223F433394B400873BB97FBB24D40EB5223F433394B404128EFE368B44D409C6B98A1F13A4B404128EFE368B44D409C6B98A1F13A4B400873BB97FBB24D40EB5223F433394B400873BB97FBB24D40
3842	Большая Половина	7	71	562	54.518583999999997	54.542461000000003	59.330444999999997	59.318403000000004	0103000020E610000001000000050000004B1DE4F560424B4062F9F36DC1A84D404B1DE4F560424B40381092054CAA4D40802DAF5C6F454B40381092054CAA4D40802DAF5C6F454B4062F9F36DC1A84D404B1DE4F560424B4062F9F36DC1A84D40
46810	Центральный	7	71	1738	57.308607000000002	57.329664000000001	58.229537999999998	58.212333000000001	0103000020E610000001000000050000008928266F80A74C40486E4DBA2D1B4D408928266F80A74C4039984D80611D4D409355116E32AA4C4039984D80611D4D409355116E32AA4C40486E4DBA2D1B4D408928266F80A74C40486E4DBA2D1B4D40
46913	Утес	7	71	1738	57.731327999999998	57.760711999999998	58.443316000000003	58.421064000000001	0103000020E610000001000000050000001553E9279CDD4C40F0C2D66CE5354D401553E9279CDD4C4093E52494BE384D405ED6C4025FE14C4093E52494BE384D405ED6C4025FE14C40F0C2D66CE5354D401553E9279CDD4C40F0C2D66CE5354D40
24578	Сёла	7	71	1738	57.228056000000002	57.263350000000003	58.167321999999999	58.155819000000001	0103000020E610000001000000050000000BD462F0309D4C40378C82E0F1134D400BD462F0309D4C405EF3AACE6A154D4068B3EA73B5A14C405EF3AACE6A154D4068B3EA73B5A14C40378C82E0F1134D400BD462F0309D4C40378C82E0F1134D40
25029	Скальный	7	71	1738	57.950426999999998	57.988821000000002	58.374662999999998	58.352944000000001	0103000020E61000000100000005000000211E8997A7F94C40E3A8DC442D2D4D40211E8997A7F94C40B8020AF5F42F4D408C4CC0AF91FE4C40B8020AF5F42F4D408C4CC0AF91FE4C40E3A8DC442D2D4D40211E8997A7F94C40E3A8DC442D2D4D40
56305	Никифорово	7	71	1738	57.181128000000001	57.208787000000001	58.214996999999997	58.199866999999998	0103000020E61000000100000005000000E831CA332F974C405A46EA3D95194D40E831CA332F974C407ADE8D05851B4D403C6A4C88B99A4C407ADE8D05851B4D403C6A4C88B99A4C405A46EA3D95194D40E831CA332F974C405A46EA3D95194D40
24249	Мульково	7	71	1738	57.595610000000001	57.629916999999999	58.287165000000002	58.272373000000002	0103000020E61000000100000005000000D595CFF23CCC4C401EA8531EDD224D40D595CFF23CCC4C4026C79DD2C1244D40E318C91EA1D04C4026C79DD2C1244D40E318C91EA1D04C401EA8531EDD224D40D595CFF23CCC4C401EA8531EDD224D40
23986	Лямино	7	71	1738	57.687722999999998	57.752744	58.298682999999997	58.257849999999998	0103000020E610000001000000050000007FDAA84E07D84C4005A3923A01214D407FDAA84E07D84C40826F9A3E3B264D404F2157EA59E04C40826F9A3E3B264D404F2157EA59E04C4005A3923A01214D407FDAA84E07D84C4005A3923A01214D40
24372	Кутамыш	7	71	1738	57.268830000000001	57.292572999999997	58.109214999999999	58.095024000000002	0103000020E6100000010000000500000083177D0569A24C40E52A16BF290C4D4083177D0569A24C40C79DD2C1FA0D4D40A758350873A54C40C79DD2C1FA0D4D40A758350873A54C40E52A16BF290C4D4083177D0569A24C40E52A16BF290C4D40
24812	Копально	7	71	1738	57.497441999999999	57.526781	58.300797000000003	58.288229999999999	0103000020E6100000010000000500000013D4F02DACBF4C40F0DC7BB8E4244D4013D4F02DACBF4C4012DE1E8480264D40BC934F8F6DC34C4012DE1E8480264D40BC934F8F6DC34C40F0DC7BB8E4244D4013D4F02DACBF4C40F0DC7BB8E4244D40
24382	Комарихинский	7	71	1738	57.097935	57.136912000000002	58.107031999999997	58.085638000000003	0103000020E610000001000000050000001F115322898C4C40BEA59C2FF60A4D401F115322898C4C400FD07D39B30D4D400937195586914C400FD07D39B30D4D400937195586914C40BEA59C2FF60A4D401F115322898C4C40BEA59C2FF60A4D40
24131	Калино	7	71	1738	57.586024999999999	57.637777	58.260179000000001	58.239345999999998	0103000020E61000000100000005000000B7D100DE02CB4C40D636C5E3A21E4D40B7D100DE02CB4C40910DA48B4D214D400C923EADA2D14C40910DA48B4D214D400C923EADA2D14C40D636C5E3A21E4D40B7D100DE02CB4C40D636C5E3A21E4D40
25123	Всесвятская	7	71	1738	58.049188000000001	58.078400999999999	58.369925000000002	58.345849999999999	0103000020E6100000010000000500000086ADD9CA4B064D402AA913D0442C4D4086ADD9CA4B064D40857CD0B3592F4D40A27C410B090A4D40857CD0B3592F4D40A27C410B090A4D402AA913D0442C4D4086ADD9CA4B064D402AA913D0442C4D40
24589	Верхнечусовские Городки	7	71	1738	57.064929999999997	57.122197999999997	58.184265000000003	58.154532000000003	0103000020E61000000100000005000000BF4351A04F884C40BE175FB4C7134D40BF4351A04F884C401366DAFE95174D407CD11E2FA48F4C401366DAFE95174D407CD11E2FA48F4C40BE175FB4C7134D40BF4351A04F884C40BE175FB4C7134D40
24841	Верхнее Калино	7	71	1738	57.650300000000001	57.669046999999999	58.315969000000003	58.301771000000002	0103000020E610000001000000050000005E4BC8073DD34C40CCF09F6EA0264D405E4BC8073DD34C4061C614AC71284D40533E0455A3D54C4061C614AC71284D40533E0455A3D54C40CCF09F6EA0264D405E4BC8073DD34C40CCF09F6EA0264D40
24215	Вереино	7	71	1738	57.423259000000002	57.436528000000003	58.227164000000002	58.217827	0103000020E610000001000000050000006C5ED5592DB64C40C89750C1E11B4D406C5ED5592DB64C400E6ABFB5131D4D40E7E44526E0B74C400E6ABFB5131D4D40E7E44526E0B74C40C89750C1E11B4D406C5ED5592DB64C40C89750C1E11B4D40
40395	Брагино	7	71	1738	57.144646999999999	57.163017000000004	58.213068	58.203375999999999	0103000020E61000000100000005000000753BFBCA83924C4049658A39081A4D40753BFBCA83924C407DE9EDCF451B4D4095D8B5BDDD944C407DE9EDCF451B4D4095D8B5BDDD944C4049658A39081A4D40753BFBCA83924C4049658A39081A4D40
46852	Бобровка	7	71	1738	57.295797	57.299596999999999	58.315128000000001	58.312561000000002	0103000020E61000000100000005000000A1A014ADDCA54C40A680B4FF01284D40A1A014ADDCA54C40E606431D56284D40677DCA3159A64C40E606431D56284D40677DCA3159A64C40A680B4FF01284D40A1A014ADDCA54C40A680B4FF01284D40
48506	Березовка	7	71	1738	57.077004000000002	57.089894999999999	58.091461000000002	58.081417000000002	0103000020E61000000100000005000000A2D45E44DB894C40522B4CDF6B0A4D40A2D45E44DB894C4003EE79FEB40B4D407689EAAD818B4C4003EE79FEB40B4D407689EAAD818B4C40522B4CDF6B0A4D40A2D45E44DB894C40522B4CDF6B0A4D40
20947	Чернушка	7	71	1652	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
22695	Тюй	7	71	1652	56.465502999999998	56.524576000000003	56.538148	56.508212	0103000020E610000001000000050000004E98309A953B4C40A6B73F170D414C404E98309A953B4C4033349E08E2444C401D226E4E25434C4033349E08E2444C401D226E4E25434C40A6B73F170D414C404E98309A953B4C40A6B73F170D414C40
56281	Трушники	7	71	1652	56.035901000000003	56.081194000000004	56.379272	56.360053000000001	0103000020E6100000010000000500000065726A6798044C40D1E97937162E4C4065726A6798044C40EE2422FC8B304C40D350A390640A4C40EE2422FC8B304C40D350A390640A4C40D1E97937162E4C4065726A6798044C40D1E97937162E4C40
56278	Трун	7	71	1652	56.294750999999998	56.358297999999998	56.443857000000001	56.423515000000002	0103000020E610000001000000050000004DBB9866BA254C40C72E51BD35364C404DBB9866BA254C40E38C614ED0384C40711C78B5DC2D4C40E38C614ED0384C40711C78B5DC2D4C40C72E51BD35364C404DBB9866BA254C40C72E51BD35364C40
22493	Тауш	7	71	1652	56.059446000000001	56.100597999999998	56.441394000000003	56.414209999999997	0103000020E6100000010000000500000063F030ED9B074C408CD651D504354C4063F030ED9B074C4048533D997F384C4081053065E00C4C4048533D997F384C4081053065E00C4C408CD651D504354C4063F030ED9B074C408CD651D504354C40
22433	Сульмаш	7	71	1652	56.056347000000002	56.089827	56.560575	56.544808000000003	0103000020E61000000100000005000000261DE56036074C40B24CBF44BC454C40261DE56036074C4044FAEDEBC0474C401EA67D737F0B4C4044FAEDEBC0474C401EA67D737F0B4C40B24CBF44BC454C40261DE56036074C40B24CBF44BC454C40
62090	Слудка	7	71	1652	55.948602999999999	56.009687999999997	56.482954999999997	56.458844999999997	0103000020E6100000010000000500000099F1B6D26BF94B407077D66EBB3A4C4099F1B6D26BF94B4047382D78D13D4C40F294D5743D014C4047382D78D13D4C40F294D5743D014C407077D66EBB3A4C4099F1B6D26BF94B407077D66EBB3A4C40
22373	Рябки	7	71	1652	56.196933000000001	56.242854999999999	56.588248999999998	56.568525999999999	0103000020E610000001000000050000006840BD1935194C407D76C075C5484C406840BD1935194C40CD7344BE4B4B4C40C55565DF151F4C40CD7344BE4B4B4C40C55565DF151F4C407D76C075C5484C406840BD1935194C407D76C075C5484C40
56297	Павловка	7	71	1652	56.201407000000003	56.221995999999997	56.500109999999999	56.483373	0103000020E61000000100000005000000BE175FB4C7194C407C629D2ADF3D4C40BE175FB4C7194C408733BF9A03404C40E1EB6B5D6A1C4C408733BF9A03404C40E1EB6B5D6A1C4C407C629D2ADF3D4C40BE175FB4C7194C407C629D2ADF3D4C40
22768	Ореховая Гора	7	71	1652	56.316346000000003	56.334456000000003	56.482334000000002	56.466180999999999	0103000020E61000000100000005000000371C96067E284C401F82AAD1AB3B4C40371C96067E284C40DBDFD91EBD3D4C40BAF94674CF2A4C40DBDFD91EBD3D4C40BAF94674CF2A4C401F82AAD1AB3B4C40371C96067E284C401F82AAD1AB3B4C40
22245	Нижний Козьмяш	7	71	1652	56.306877999999998	56.342945	56.539090999999999	56.514316000000001	0103000020E6100000010000000500000052EE3EC747274C409FE74F1BD5414C4052EE3EC747274C40B24813EF00454C40D2A92B9FE52B4C40B24813EF00454C40D2A92B9FE52B4C409FE74F1BD5414C4052EE3EC747274C409FE74F1BD5414C40
56351	Комарово	7	71	1652	55.829144999999997	55.847254999999997	56.624592999999997	56.606064000000003	0103000020E610000001000000050000002A52616C21EA4B4038A45181934D4C402A52616C21EA4B40BF27D6A9F24F4C40AD2F12DA72EC4B40BF27D6A9F24F4C40AD2F12DA72EC4B4038A45181934D4C402A52616C21EA4B4038A45181934D4C40
58255	Ключи	7	71	1652	56.335965999999999	56.381286000000003	56.647078	56.634892000000001	0103000020E61000000100000005000000B24813EF002B4C40FB3E1C2444514C40B24813EF002B4C4005FBAF73D3524C401A36CAFACD304C4005FBAF73D3524C401A36CAFACD304C40FB3E1C2444514C40B24813EF002B4C40FB3E1C2444514C40
56355	Калиновка	7	71	1652	56.296430999999998	56.332920000000001	56.700667000000003	56.684632000000001	0103000020E61000000100000005000000A2427573F1254C40C5E57805A2574C40A2427573F1254C407731CD74AF594C409817601F9D2A4C407731CD74AF594C409817601F9D2A4C40C5E57805A2574C40A2427573F1254C40C5E57805A2574C40
56484	Зверево	7	71	1652	56.125355999999996	56.151361999999999	56.553758999999999	56.535466999999997	0103000020E61000000100000005000000BE2D58AA0B104C402A8BC22E8A444C40BE2D58AA0B104C40CE6E2D93E1464C40B7ED7BD45F134C40CE6E2D93E1464C40B7ED7BD45F134C402A8BC22E8A444C40BE2D58AA0B104C402A8BC22E8A444C40
22082	Етыш	7	71	1652	56.157317999999997	56.190106	56.409329	56.380737000000003	0103000020E610000001000000050000003B8908FF22144C4047B071FDBB304C403B8908FF22144C40F62686E464344C40FE62B66455184C40F62686E464344C40FE62B66455184C4047B071FDBB304C403B8908FF22144C4047B071FDBB304C40
22586	Есаул	7	71	1652	56.271250999999999	56.301245999999999	56.367981	56.347633999999999	0103000020E61000000100000005000000EF004F5AB8224C40247D5A457F2C4C40EF004F5AB8224C4052465C001A2F4C4081069B3A8F264C4052465C001A2F4C4081069B3A8F264C40247D5A457F2C4C40EF004F5AB8224C40247D5A457F2C4C40
58273	Емаш-Павлово	7	71	1652	56.080727000000003	56.109132000000002	56.330399999999997	56.316419000000003	0103000020E61000000100000005000000BD732843550A4C40A16AF46A80284C40BD732843550A4C40984C158C4A2A4C403A799109F80D4C40984C158C4A2A4C403A799109F80D4C40A16AF46A80284C40BD732843550A4C40A16AF46A80284C40
62091	Брод	7	71	1652	55.983987999999997	56.024698999999998	56.529699000000001	56.509726999999998	0103000020E6100000010000000500000006D49B51F3FD4B40B071FDBB3E414C4006D49B51F3FD4B40A9DC442DCD434C40389F3A5629034C40A9DC442DCD434C40389F3A5629034C40B071FDBB3E414C4006D49B51F3FD4B40B071FDBB3E414C40
21962	Бедряж	7	71	1652	55.865895000000002	55.902087999999999	56.589641	56.560668999999997	0103000020E610000001000000050000008D62B9A5D5EE4B40C5707500C4474C408D62B9A5D5EE4B40BCB0355B794B4C40990E9D9E77F34B40BCB0355B794B4C40990E9D9E77F34B40C5707500C4474C408D62B9A5D5EE4B40C5707500C4474C40
22338	Ашша	7	71	1652	56.112501000000002	56.141364000000003	56.508474999999997	56.497869000000001	0103000020E6100000010000000500000037E2C96E660E4C409B58E02BBA3F4C4037E2C96E660E4C40B3EA73B515414C40776A2E3718124C40B3EA73B515414C40776A2E3718124C409B58E02BBA3F4C4037E2C96E660E4C409B58E02BBA3F4C40
56349	Атняшка	7	71	1652	56.139234999999999	56.218214000000003	56.465305999999998	56.427179000000002	0103000020E61000000100000005000000B2BAD573D2114C40DD442DCDAD364C40B2BAD573D2114C40F850A2258F3B4C40C2C3B46FEE1B4C40F850A2258F3B4C40C2C3B46FEE1B4C40DD442DCDAD364C40B2BAD573D2114C40DD442DCDAD364C40
56380	Ананьино	7	71	1652	56.048108999999997	56.081113999999999	56.616411999999997	56.598621999999999	0103000020E6100000010000000500000056D28A6F28064C4043554CA59F4C4C4056D28A6F28064C40546EA296E64E4C40B69F8CF1610A4C40546EA296E64E4C40B69F8CF1610A4C4043554CA59F4C4C4056D28A6F28064C4043554CA59F4C4C40
56254	Азинский	7	71	1652	55.748629000000001	56.631529	56.771906000000001	56.289935	0103000020E6100000010000000500000029EB3713D3DF4B409E7B0F971C254C4029EB3713D3DF4B4008CBD8D0CD624C40E0BC38F1D5504C4008CBD8D0CD624C40E0BC38F1D5504C409E7B0F971C254C4029EB3713D3DF4B409E7B0F971C254C40
23048	Чусовской	7	71	456	56.662376999999999	56.691338999999999	61.145086999999997	61.118329000000003	0103000020E61000000100000005000000B14F00C5C8544C408E959867258F4E40B14F00C5C8544C409109F83592924E4084B9DDCB7D584C409109F83592924E4084B9DDCB7D584C408E959867258F4E40B14F00C5C8544C408E959867258F4E40
19585	Чердынь	7	71	456	56.446593	56.507032000000002	60.421021000000003	60.376935000000003	0103000020E61000000100000005000000AFCF9CF529394C40E0DBF4673F304E40AFCF9CF529394C40F1F62004E4354E404303B16CE6404C40F1F62004E4354E404303B16CE6404C40E0DBF4673F304E40AFCF9CF529394C40E0DBF4673F304E40
20337	Чепец	7	71	456	55.631703999999999	55.646121999999998	60.430714999999999	60.419865999999999	0103000020E610000001000000050000004E603AADDBD04B40E659492BBE354E404E603AADDBD04B40C5724BAB21374E40F19C2D20B4D24B40C5724BAB21374E40F19C2D20B4D24B40E659492BBE354E404E603AADDBD04B40E659492BBE354E40
56409	Урол	7	71	456	56.316642999999999	56.344921999999997	60.336360999999997	60.328046000000001	0103000020E61000000100000005000000F0C000C287284C40B4CA4C69FD294E40F0C000C287284C402E5393E00D2B4E40E0D57267262C4C402E5393E00D2B4E40E0D57267262C4C40B4CA4C69FD294E40F0C000C287284C40B4CA4C69FD294E40
49198	Сосновка	7	71	456	56.891295	56.898409999999998	61.427788999999997	61.423310000000001	0103000020E610000001000000050000004E0B5EF415724C40EE08A7052FB64E404E0B5EF415724C40554B3ACAC1B64E401E335019FF724C40554B3ACAC1B64E401E335019FF724C40EE08A7052FB64E404E0B5EF415724C40EE08A7052FB64E40
32976	Серегово	7	71	456	56.504066999999999	56.517074999999998	60.374462000000001	60.363126999999999	0103000020E6100000010000000500000015FF774485404C40B5A50EF27A2E4E4015FF774485404C4021CCED5EEE2F4E40234A7B832F424C4021CCED5EEE2F4E40234A7B832F424C40B5A50EF27A2E4E4015FF774485404C40B5A50EF27A2E4E40
48463	Серебрянка	7	71	456	55.763621999999998	55.776575999999999	60.982809000000003	60.978296	0103000020E61000000100000005000000C8409E5DBEE14B4060E7A6CD387D4E40C8409E5DBEE14B40749B70AFCC7D4E40E36DA5D766E34B40749B70AFCC7D4E40E36DA5D766E34B4060E7A6CD387D4E40C8409E5DBEE14B4060E7A6CD387D4E40
20102	Рябинино	7	71	456	56.478771000000002	56.516517999999998	60.337936999999997	60.304192999999998	0103000020E61000000100000005000000F9A23D5E483D4C400856D5CBEF264E40F9A23D5E483D4C40DE8D0585412B4E40CDE506431D424C40DE8D0585412B4E40CDE506431D424C400856D5CBEF264E40F9A23D5E483D4C400856D5CBEF264E40
19982	Редикор	7	71	456	56.446610999999997	56.471054000000002	60.194575999999998	60.179285	0103000020E6100000010000000500000055849B8C2A394C40E9D495CFF2164E4055849B8C2A394C40124BCADDE7184E4033535A7F4B3C4C40124BCADDE7184E4033535A7F4B3C4C40E9D495CFF2164E4055849B8C2A394C40E9D495CFF2164E40
8832	Пянтег	7	71	456	56.243879	56.275832000000001	60.160423000000002	60.147472	0103000020E610000001000000050000003197546D371F4C40B189CC5CE0124E403197546D371F4C405B43A9BD88144E405B9885764E234C405B43A9BD88144E405B9885764E234C40B189CC5CE0124E403197546D371F4C40B189CC5CE0124E40
20683	Покча	7	71	456	56.442568999999999	56.464585999999997	60.464142000000002	60.440663999999998	0103000020E61000000100000005000000999CDA19A6384C4024438EAD67384E40999CDA19A6384C409B594B01693B4E40F816D68D773B4C409B594B01693B4E40F816D68D773B4C4024438EAD67384E40999CDA19A6384C4024438EAD67384E40
13987	Пильва	7	71	456	55.999555000000001	56.033943000000001	60.838464999999999	60.813254000000001	0103000020E61000000100000005000000D2C6116BF1FF4B40ACAB02B518684E40D2C6116BF1FF4B409AEB34D2526B4E40CD76853E58044C409AEB34D2526B4E40CD76853E58044C40ACAB02B518684E40D2C6116BF1FF4B40ACAB02B518684E40
19766	Ныроб	7	71	456	56.681007999999999	56.744070000000001	60.760342999999999	60.705542999999999	0103000020E610000001000000050000003D2828452B574C40FB75A73B4F5A4E403D2828452B574C400B5F5FEB52614E40A5F78DAF3D5F4C400B5F5FEB52614E40A5F78DAF3D5F4C40FB75A73B4F5A4E403D2828452B574C40FB75A73B4F5A4E40
58909	Кушмангорт	7	71	456	54.990586	58.711084	61.525385999999997	59.840206999999999	0103000020E610000001000000050000000FF0A485CB7E4B40656F29E78BEB4D400FF0A485CB7E4B405CE333D93FC34E40BC5AEECC045B4D405CE333D93FC34E40BC5AEECC045B4D40656F29E78BEB4D400FF0A485CB7E4B40656F29E78BEB4D40
56331	Курган	7	71	456	56.121519999999997	56.151308	60.173096000000001	60.157198999999999	0103000020E61000000100000005000000ABE7A4F78D0F4C4061FBC9181F144E40ABE7A4F78D0F4C40C2887D0228164E40C4CF7F0F5E134C40C2887D0228164E40C4CF7F0F5E134C4061FBC9181F144E40ABE7A4F78D0F4C4061FBC9181F144E40
58905	Коэлпы	7	71	456	56.246161000000001	56.266534999999998	60.112597999999998	60.098627999999998	0103000020E610000001000000050000007C462234821F4C40253CA1D79F0C4E407C462234821F4C4029CC7B9C690E4E40A31EA2D11D224C4029CC7B9C690E4E40A31EA2D11D224C40253CA1D79F0C4E407C462234821F4C40253CA1D79F0C4E40
20788	Кольчуг	7	71	456	56.143205000000002	56.199511000000001	60.408160000000002	60.397146999999997	0103000020E61000000100000005000000D5CF9B8A54124C402D5A80B6D5324E40D5CF9B8A54124C4087C43D963E344E409C18929389194C4087C43D963E344E409C18929389194C402D5A80B6D5324E40D5CF9B8A54124C402D5A80B6D5324E40
2657	Керчевский	7	71	456	56.268700000000003	56.313831	59.958638000000001	59.936751000000001	0103000020E61000000100000005000000B537F8C264224C4066BFEE74E7F74D40B537F8C264224C40F75965A6B4FA4D4049BC3C9D2B284C40F75965A6B4FA4D4049BC3C9D2B284C4066BFEE74E7F74D40B537F8C264224C4066BFEE74E7F74D40
13299	Искор	7	71	456	56.680407000000002	56.722448	60.655946	60.641418000000002	0103000020E61000000100000005000000187C9A9317574C406A882AFC19524E40187C9A9317574C4094F8DC09F6534E40C287122D795C4C4094F8DC09F6534E40C287122D795C4C406A882AFC19524E40187C9A9317574C406A882AFC19524E40
56368	Гремячево	7	71	456	56.346476000000003	56.362906000000002	59.928749000000003	59.918700999999999	0103000020E61000000100000005000000A96C5853592C4C40B8E68EFE97F54D40A96C5853592C4C40AB984A3FE1F64D40D7C22CB4732E4C40AB984A3FE1F64D40D7C22CB4732E4C40B8E68EFE97F54D40A96C5853592C4C40B8E68EFE97F54D40
20416	Вильгорт	7	71	456	56.444626	56.48319	60.569830000000003	60.552180999999997	0103000020E61000000100000005000000C4793881E9384C407D3CF4DDAD464E40C4793881E9384C40CD237F30F0484E408BE07F2BD93D4C40CD237F30F0484E408BE07F2BD93D4C407D3CF4DDAD464E40C4793881E9384C407D3CF4DDAD464E40
20884	Верхняя Колва	7	71	456	57.240532999999999	57.263601999999999	61.136961999999997	61.124056000000003	0103000020E61000000100000005000000EC4D0CC9C99E4C40B16F2711E18F4E40EC4D0CC9C99E4C40BA6587F887914E408194D8B5BDA14C40BA6587F887914E408194D8B5BDA14C40B16F2711E18F4E40EC4D0CC9C99E4C40B16F2711E18F4E40
20838	Валай	7	71	456	57.468040000000002	57.518327999999997	60.835431	60.824010999999999	0103000020E61000000100000005000000249C16BCE8BB4C40AA45443179694E40249C16BCE8BB4C4044882B67EF6A4E40F04C689258C24C4044882B67EF6A4E40F04C689258C24C40AA45443179694E40249C16BCE8BB4C40AA45443179694E40
20241	Бондюг	7	71	456	55.908017000000001	55.944164999999998	60.496076000000002	60.478279999999998	0103000020E61000000100000005000000249BABE639F44B405A2A6F47383D4E40249BABE639F44B404E2A1A6B7F3F4E4090831266DAF84B404E2A1A6B7F3F4E4090831266DAF84B405A2A6F47383D4E40249BABE639F44B405A2A6F47383D4E40
20608	Большие Долды	7	71	456	56.111369000000003	56.129370999999999	60.282280999999998	60.269404999999999	0103000020E61000000100000005000000E564E256410E4C407F30F0DC7B224E40E564E256410E4C401EA4A7C821244E4081069B3A8F104C401EA4A7C821244E4081069B3A8F104C407F30F0DC7B224E40E564E256410E4C407F30F0DC7B224E40
56244	Березовка	7	71	456	55.833646000000002	55.845539000000002	59.998804999999997	59.992623000000002	0103000020E610000001000000050000007A3881E9B4EA4B40F3203D450EFF4D407A3881E9B4EA4B40670A9DD7D8FF4D400C3F389F3AEC4B40670A9DD7D8FF4D400C3F389F3AEC4B40F3203D450EFF4D407A3881E9B4EA4B40F3203D450EFF4D40
32877	Шлыки	7	71	1553	54.811228	54.850394999999999	57.421992000000003	57.399298999999999	0103000020E61000000100000005000000BCCCB051D6674B40AA29C93A1CB34C40BCCCB051D6674B403A9677D503B64C4049D74CBED96C4B403A9677D503B64C4049D74CBED96C4B40AA29C93A1CB34C40BCCCB051D6674B40AA29C93A1CB34C40
19324	Шабуры	7	71	1553	54.788581999999998	54.826895	57.383412999999997	57.366928999999999	0103000020E610000001000000050000006D1B4641F0644B401C7A8B87F7AE4C406D1B4641F0644B403DEE5BAD13B14C40EB1C03B2D7694B403DEE5BAD13B14C40EB1C03B2D7694B401C7A8B87F7AE4C406D1B4641F0644B401C7A8B87F7AE4C40
18552	Частые	7	71	1553	54.952713000000003	54.988052000000003	57.307918000000001	57.277068999999997	0103000020E61000000100000005000000AEBCE47FF2794B4022DE3AFF76A34C40AEBCE47FF2794B40C4EC65DB69A74C40AB5FE97C787E4B40C4EC65DB69A74C40AB5FE97C787E4B4022DE3AFF76A34C40AEBCE47FF2794B4022DE3AFF76A34C40
18984	Средняя Головниха	7	71	1553	54.883173999999997	54.901660999999997	57.218761000000001	57.210115000000002	0103000020E61000000100000005000000B8567BD80B714B4014B35E0CE59A4C40B8567BD80B714B40F451465C009C4C40118AADA069734B40F451465C009C4C40118AADA069734B4014B35E0CE59A4C40B8567BD80B714B4014B35E0CE59A4C40
32890	Пихтовка	7	71	1553	54.906188999999998	54.963231999999998	57.568069000000001	57.543467999999997	0103000020E610000001000000050000005A7F4B00FE734B401536035C90C54C405A7F4B00FE734B408B6F287CB6C84C40F73AA92F4B7B4B408B6F287CB6C84C40F73AA92F4B7B4B401536035C90C54C405A7F4B00FE734B401536035C90C54C40
19243	Пермяковка	7	71	1553	54.443843999999999	54.461342999999999	57.130060999999998	57.119033999999999	0103000020E610000001000000050000004E4354E1CF384B40588E90813C8F4C404E4354E1CF384B4016BEBED6A5904C40889E94490D3B4B4016BEBED6A5904C40889E94490D3B4B40588E90813C8F4C404E4354E1CF384B40588E90813C8F4C40
19022	Ножовка	7	71	1553	54.713509000000002	54.780639999999998	57.119487999999997	57.073497000000003	0103000020E610000001000000050000006A334E43545B4B4054AD855968894C406A334E43545B4B40D921FE614B8F4C4087F9F202EC634B40D921FE614B8F4C4087F9F202EC634B4054AD855968894C406A334E43545B4B4054AD855968894C40
32909	Меркуши	7	71	1553	55.041071000000002	55.097206999999997	57.454715	57.436635000000003	0103000020E6100000010000000500000032E884D041854B40FDA4DAA7E3B74C4032E884D041854B401500E31934BA4C409CF86A47718C4B401500E31934BA4C409CF86A47718C4B40FDA4DAA7E3B74C4032E884D041854B40FDA4DAA7E3B74C40
32796	Мельничная	7	71	1553	54.879328999999998	54.914876	57.28425	57.260686999999997	0103000020E6100000010000000500000052B648DA8D704B4005BF0D315EA14C4052B648DA8D704B40AAF1D24D62A44C4099F221A81A754B40AAF1D24D62A44C4099F221A81A754B4005BF0D315EA14C4052B648DA8D704B4005BF0D315EA14C40
32808	Кленовая	7	71	1553	54.718091000000001	54.736649999999997	57.232247999999998	57.223185999999998	0103000020E61000000100000005000000A646E867EA5B4B406876DD5B919C4C40A646E867EA5B4B40DC476E4DBA9D4C40984C158C4A5E4B40DC476E4DBA9D4C40984C158C4A5E4B406876DD5B919C4C40A646E867EA5B4B406876DD5B919C4C40
18918	Змеевка	7	71	1553	54.914363999999999	54.957985999999998	57.171970999999999	57.160145999999997	0103000020E61000000100000005000000E3512AE109754B40E84A04AA7F944C40E3512AE109754B40226E4E2503964C404F0306499F7A4B40226E4E2503964C404F0306499F7A4B40E84A04AA7F944C40E3512AE109754B40E84A04AA7F944C40
58256	Западная	7	71	1553	54.863428999999996	54.890872999999999	57.308239	57.288088000000002	0103000020E6100000010000000500000080B56AD7846E4B405E2F4D11E0A44C4080B56AD7846E4B40062D246074A74C40D8F15F2008724B40062D246074A74C40D8F15F2008724B405E2F4D11E0A44C4080B56AD7846E4B405E2F4D11E0A44C40
19424	Ельшата	7	71	1553	54.715682999999999	54.737656000000001	57.468691	57.460524999999997	0103000020E61000000100000005000000CEA623809B5B4B40C5FEB27BF2BA4C40CEA623809B5B4B40FB761211FEBB4C405ED905836B5E4B40FB761211FEBB4C405ED905836B5E4B40C5FEB27BF2BA4C40CEA623809B5B4B40C5FEB27BF2BA4C40
58286	Верхнее Рождество	7	71	1553	54.718629999999997	54.748669	57.148400000000002	57.136177000000004	0103000020E6100000010000000500000055F65D11FC5B4B40D4BB783F6E914C4055F65D11FC5B4B40FB5C6DC5FE924C40B743C362D45F4B40FB5C6DC5FE924C40B743C362D45F4B40D4BB783F6E914C4055F65D11FC5B4B40D4BB783F6E914C40
32866	Бугры	7	71	1553	54.542569	54.559412000000002	57.142285999999999	57.123069999999998	0103000020E610000001000000050000006669A7E672454B40328FFCC1C08F4C406669A7E672454B40DE567A6D36924C40B77EFACF9A474B40DE567A6D36924C40B77EFACF9A474B40328FFCC1C08F4C406669A7E672454B40328FFCC1C08F4C40
56237	Марково	7	71	7405	54.079236000000002	54.101415000000003	56.645350999999998	56.634590000000003	0103000020E610000001000000050000003B55BE67240A4B40302FC03E3A514C403B55BE67240A4B406FB88FDC9A524C407429AE2AFB0C4B406FB88FDC9A524C407429AE2AFB0C4B40302FC03E3A514C403B55BE67240A4B40302FC03E3A514C40
56235	Альняш	7	71	7405	54.714390000000002	54.752226999999998	56.748133000000003	56.706488	0103000020E61000000100000005000000734BAB21715B4B401B82E3326E5A4C40734BAB21715B4B40790778D2C25F4C4087156EF948604B40790778D2C25F4C4087156EF948604B401B82E3326E5A4C40734BAB21715B4B401B82E3326E5A4C40
18096	Чумна	7	71	716	54.398820999999998	54.435409	56.728568000000003	56.710811	0103000020E61000000100000005000000A0FA07910C334B408B51D7DAFB5A4C40A0FA07910C334B40C1745AB7415D4C4029B16B7BBB374B40C1745AB7415D4C4029B16B7BBB374B408B51D7DAFB5A4C40A0FA07910C334B408B51D7DAFB5A4C40
4995	Фоки	7	71	716	54.332974	54.388759	56.710416000000002	56.674163999999998	0103000020E610000001000000050000008B355CE49E2A4B40FD1186014B564C408B355CE49E2A4B400F4757E9EE5A4C404983DBDAC2314B400F4757E9EE5A4C404983DBDAC2314B40FD1186014B564C408B355CE49E2A4B40FD1186014B564C40
48681	Уральское	7	71	716	54.373578000000002	54.408244000000003	56.458378000000003	56.431649	0103000020E61000000100000005000000A7406667D12F4B40F12C414640374C40A7406667D12F4B405B9A5B21AC3A4C40E564E25641344B405B9A5B21AC3A4C40E564E25641344B40F12C414640374C40A7406667D12F4B40F12C414640374C40
18327	Сосново	7	71	716	54.553573	54.590421999999997	56.694464000000004	56.668070999999998	0103000020E610000001000000050000006C79E57ADB464B40F833BC5983554C406C79E57ADB464B40EB1F4432E4584C40616BB6F2924B4B40EB1F4432E4584C40616BB6F2924B4B40F833BC5983554C406C79E57ADB464B40F833BC5983554C40
18281	Маракуши	7	71	716	54.519984999999998	54.565852999999997	56.744041000000003	56.728776000000003	0103000020E610000001000000050000008DB454DE8E424B400B0E2F88485D4C408DB454DE8E424B400BF148BC3C5F4C40F7AB00DF6D484B400BF148BC3C5F4C40F7AB00DF6D484B400B0E2F88485D4C408DB454DE8E424B400B0E2F88485D4C40
17908	Кемуль	7	71	716	53.928587999999998	53.969560999999999	56.674298	56.659537999999998	0103000020E61000000100000005000000A1BAB9F8DBF64A40103CBEBD6B544C40A1BAB9F8DBF64A400DE198654F564C40103D29931AFC4A400DE198654F564C40103D29931AFC4A40103CBEBD6B544C40A1BAB9F8DBF64A40103CBEBD6B544C40
18442	Зипуново	7	71	716	54.500573000000003	54.533442000000001	56.606028999999999	56.586454000000003	0103000020E610000001000000050000005C21ACC612404B40E04DB7EC104B4C405C21ACC612404B40BBB6B75B924D4C400B28D4D347444B40BBB6B75B924D4C400B28D4D347444B40E04DB7EC104B4C405C21ACC612404B40E04DB7EC104B4C40
17406	Засечный	7	71	716	54.433171999999999	54.462017000000003	56.865299	56.846026999999999	0103000020E610000001000000050000007EC51A2E72374B403944DC9C4A6C4C407EC51A2E72374B4079211D1EC26E4C401899805F233B4B4079211D1EC26E4C401899805F233B4B403944DC9C4A6C4C407EC51A2E72374B403944DC9C4A6C4C40
56434	Завод Михайловский	7	71	716	54.273747999999998	54.292703000000003	56.531188999999998	56.518349000000001	0103000020E6100000010000000500000036ACA92C0A234B400875914259424C4036ACA92C0A234B405A7F4B00FE434C407638BA4A77254B405A7F4B00FE434C407638BA4A77254B400875914259424C4036ACA92C0A234B400875914259424C40
56330	Гаревая	7	71	716	54.285229000000001	54.300283999999998	56.720044000000001	56.704926999999998	0103000020E61000000100000005000000766F456282244B40A088450C3B5A4C40766F456282244B402CD7DB662A5C4C408BC1C3B46F264B402CD7DB662A5C4C408BC1C3B46F264B40A088450C3B5A4C40766F456282244B40A088450C3B5A4C40
17422	Вассята	7	71	716	54.543008999999998	54.592551	56.897919999999999	56.881394	0103000020E610000001000000050000008237A45181454B400072C284D1704C408237A45181454B405036E50AEF724C40261B0FB6D84B4B405036E50AEF724C40261B0FB6D84B4B400072C284D1704C408237A45181454B400072C284D1704C40
56262	Ваньки	7	71	716	54.354210000000002	54.383091	56.854931000000001	56.830911	0103000020E6100000010000000500000045F5D6C0562D4B407E71A94A5B6A4C4045F5D6C0562D4B4015AB06616E6D4C402B323A2009314B4015AB06616E6D4C402B323A2009314B407E71A94A5B6A4C4045F5D6C0562D4B407E71A94A5B6A4C40
18370	Буренка	7	71	716	54.539603999999997	54.555855000000001	56.552697000000002	56.541204999999998	0103000020E6100000010000000500000038656EBE11454B4041B7973446454C4038656EBE11454B4075CC79C6BE464C40B728B34126474B4075CC79C6BE464C40B728B34126474B4041B7973446454C4038656EBE11454B4041B7973446454C40
17916	Большой Букор	7	71	716	54.245289	54.271377000000001	56.675559	56.650101999999997	0103000020E61000000100000005000000C68844A1651F4B403788D68A36534C40C68844A1651F4B405DC2A1B778564C407CF1457BBC224B405DC2A1B778564C407CF1457BBC224B403788D68A36534C40C68844A1651F4B403788D68A36534C40
32528	Щекино	7	71	572	55.815778000000002	55.844155999999998	59.614227	59.600591999999999	0103000020E61000000100000005000000ED65DB696BE84B409F1EDB32E0CC4D40ED65DB696BE84B40FCA886FD9ECE4D40705CC64D0DEC4B40FCA886FD9ECE4D40705CC64D0DEC4B409F1EDB32E0CC4D40ED65DB696BE84B409F1EDB32E0CC4D40
16003	Шемейный	7	71	572	56.052070999999998	56.081653000000003	59.375824999999999	59.363532999999997	0103000020E61000000100000005000000F6083543AA064C402502D53F88AE4D40F6083543AA064C4075029A081BB04D40664F029B730A4C4075029A081BB04D40664F029B730A4C402502D53F88AE4D40F6083543AA064C402502D53F88AE4D40
12489	Турлавы	7	71	572	56.464694000000001	56.478788999999999	59.406781000000002	59.392420000000001	0103000020E61000000100000005000000DF52CE177B3B4C40EE258DD13AB24D40DF52CE177B3B4C402DD1596611B44D409F573CF5483D4C402DD1596611B44D409F573CF5483D4C40EE258DD13AB24D40DF52CE177B3B4C40EE258DD13AB24D40
3553	Сенькино	7	71	572	55.797964999999998	55.805385000000001	59.597076000000001	59.593305000000001	0103000020E61000000100000005000000232D95B723E64B40D2C6116BF1CB4D40232D95B723E64B40FE9C82FC6CCC4D4030D80DDB16E74B40FE9C82FC6CCC4D4030D80DDB16E74B40D2C6116BF1CB4D40232D95B723E64B40D2C6116BF1CB4D40
15846	Пыскор	7	71	572	56.567658999999999	56.606844000000002	59.490775999999997	59.466628	0103000020E61000000100000005000000D923D40CA9484C40EEB25F77BABB4D40D923D40CA9484C40B2D47ABFD1BE4D400DE36E10AD4D4C40B2D47ABFD1BE4D400DE36E10AD4D4C40EEB25F77BABB4D40D923D40CA9484C40EEB25F77BABB4D40
47347	Плеханово	7	71	572	56.563625999999999	56.572248999999999	59.482708000000002	59.480010999999998	0103000020E61000000100000005000000709692E524484C40315C1D0071BD4D40709692E524484C4040C23060C9BD4D4098158A743F494C4040C23060C9BD4D4098158A743F494C40315C1D0071BD4D40709692E524484C40315C1D0071BD4D40
56352	Ощепково	7	71	572	56.340960000000003	56.356150999999997	59.513876000000003	59.507055000000001	0103000020E61000000100000005000000419FC893A42B4C40FB22A12DE7C04D40419FC893A42B4C40831953B0C6C14D4006B8205B962D4C40831953B0C6C14D4006B8205B962D4C40FB22A12DE7C04D40419FC893A42B4C40FB22A12DE7C04D40
32648	Орел	7	71	572	56.554372999999998	56.613446000000003	59.350026	59.334411000000003	0103000020E610000001000000050000008864C8B1F5464C401A36CAFACDAA4D408864C8B1F5464C40F65FE7A6CDAC4D4057EE0566854E4C40F65FE7A6CDAC4D4057EE0566854E4C401A36CAFACDAA4D408864C8B1F5464C401A36CAFACDAA4D40
33047	Вогулка	7	71	572	56.754840999999999	56.788429000000001	59.137	59.114271000000002	0103000020E61000000100000005000000085740A19E604C40CCF09F6EA08E4D40085740A19E604C40A8C64B3789914D40E71BD13DEB644C40A8C64B3789914D40E71BD13DEB644C40CCF09F6EA08E4D40085740A19E604C40CCF09F6EA08E4D40
58298	Верх-Кондас	7	71	572	56.043339000000003	56.068663000000001	59.454172	59.444781999999996	0103000020E6100000010000000500000018D2E1218C054C40BBECD79DEEB84D4018D2E1218C054C402461DF4E22BA4D40FEB8FDF2C9084C402461DF4E22BA4D40FEB8FDF2C9084C40BBECD79DEEB84D4018D2E1218C054C40BBECD79DEEB84D40
14781	Чесноковка	7	71	1329	56.548237	56.558101000000001	56.953865	56.945608	0103000020E6100000010000000500000084BA48A12C464C40016BD5AE09794C4084BA48A12C464C4047E6913F187A4C40B56E83DA6F474C4047E6913F187A4C40B56E83DA6F474C40016BD5AE09794C4084BA48A12C464C40016BD5AE09794C40
14647	Чайка	7	71	1329	56.713689000000002	56.742651000000002	56.916969000000002	56.899954999999999	0103000020E61000000100000005000000EA4141295A5B4C40936FB6B931734C40EA4141295A5B4C4011397D3D5F754C40BDAB1E300F5F4C4011397D3D5F754C40BDAB1E300F5F4C40936FB6B931734C40EA4141295A5B4C40936FB6B931734C40
58305	Усть-Телес	7	71	1329	56.748246999999999	56.773400000000002	56.867739	56.852780000000003	0103000020E61000000100000005000000412AC58EC65F4C40695721E5276D4C40412AC58EC65F4C405C3B5112126F4C40FB5C6DC5FE624C405C3B5112126F4C40FB5C6DC5FE624C40695721E5276D4C40412AC58EC65F4C40695721E5276D4C40
14616	Усановка	7	71	1329	56.689748999999999	56.713104999999999	56.986902999999998	56.973464	0103000020E610000001000000050000006FB9FAB149584C40ABEAE5779A7C4C406FB9FAB149584C4082A966D6527E4C409ACE4E06475B4C4082A966D6527E4C409ACE4E06475B4C40ABEAE5779A7C4C406FB9FAB149584C40ABEAE5779A7C4C40
14171	Уинское	7	71	1329	56.538805000000004	56.612799000000003	56.890118000000001	56.865687999999999	0103000020E61000000100000005000000EDF5EE8FF7444C40134548DDCE6E4C40EDF5EE8FF7444C405CCAF962EF714C40C1029832704E4C405CCAF962EF714C40C1029832704E4C40134548DDCE6E4C40EDF5EE8FF7444C40134548DDCE6E4C40
14571	Суда	7	71	1329	56.790638999999999	56.830030000000001	56.969289000000003	56.948244000000003	0103000020E6100000010000000500000098F8A3A833654C406A50340F60794C4098F8A3A833654C40B0AF75A9117C4C4075594C6C3E6A4C40B0AF75A9117C4C4075594C6C3E6A4C406A50340F60794C4098F8A3A833654C406A50340F60794C40
14767	Средний Сып	7	71	1329	56.468789999999998	56.488086000000003	56.983671000000001	56.973792000000003	0103000020E610000001000000050000008E588B4F013C4C40A08D5C37A57C4C408E588B4F013C4C4006836BEEE87D4C4057D11F9A793E4C4006836BEEE87D4C4057D11F9A793E4C40A08D5C37A57C4C408E588B4F013C4C40A08D5C37A57C4C40
56508	Сосновка	7	71	1329	56.111215999999999	56.136440999999998	56.795972999999996	56.782677	0103000020E610000001000000050000005E656D533C0E4C406B2A8BC22E644C405E656D533C0E4C40DFBF7971E2654C40B16A10E676114C40DFBF7971E2654C40B16A10E676114C406B2A8BC22E644C405E656D533C0E4C406B2A8BC22E644C40
58722	Соловаты	7	71	1329	56.698596999999999	56.719240999999997	56.845917999999998	56.838036000000002	0103000020E61000000100000005000000B70A62A06B594C40726F7EC3446B4C40B70A62A06B594C40828C800A476C4C409E78CE16105C4C40828C800A476C4C409E78CE16105C4C40726F7EC3446B4C40B70A62A06B594C40726F7EC3446B4C40
14702	Нижний Сып	7	71	1329	56.557130999999998	56.592354	56.981507999999998	56.960867999999998	0103000020E610000001000000050000003C4B901150474C40EFE2FDB8FD7A4C403C4B901150474C409561DC0DA27D4C40D0D38041D24B4C409561DC0DA27D4C40D0D38041D24B4C40EFE2FDB8FD7A4C403C4B901150474C40EFE2FDB8FD7A4C40
15269	Митрохи	7	71	1329	56.094965999999999	56.147615999999999	56.877740000000003	56.868285	0103000020E61000000100000005000000B01D8CD8270C4C40BE4D7FF6236F4C40B01D8CD8270C4C400E32C9C859704C40E42EC214E5124C400E32C9C859704C40E42EC214E5124C40BE4D7FF6236F4C40B01D8CD8270C4C40BE4D7FF6236F4C40
15117	Ломь	7	71	1329	56.200985000000003	56.227646999999997	56.986364000000002	56.977040000000002	0103000020E6100000010000000500000048FE60E0B9194C4022718FA50F7D4C4048FE60E0B9194C40D3F9F02C417E4C4029047289231D4C40D3F9F02C417E4C4029047289231D4C4022718FA50F7D4C4048FE60E0B9194C4022718FA50F7D4C40
15220	Курмакаш	7	71	1329	56.146152000000001	56.182695000000002	56.940280000000001	56.932757000000002	0103000020E610000001000000050000005C1FD61BB5124C40BB0ED59464774C405C1FD61BB5124C409C8A54185B784C404512BD8C62174C409C8A54185B784C404512BD8C62174C40BB0ED59464774C405C1FD61BB5124C40BB0ED59464774C40
15002	Красногорка	7	71	1329	56.162474000000003	56.191211000000003	56.821098999999997	56.805087	0103000020E61000000100000005000000A439B2F2CB144C40A6B73F170D674C40A439B2F2CB144C409FE3A3C519694C4057D11F9A79184C409FE3A3C519694C4057D11F9A79184C40A6B73F170D674C40A439B2F2CB144C40A6B73F170D674C40
14857	Кочешовка	7	71	1329	56.536236000000002	56.560805000000002	56.798718999999998	56.777000000000001	0103000020E610000001000000050000000C789961A3444C40FA7E6ABC74634C400C789961A3444C40CFD8976C3C664C4076374F75C8474C40CFD8976C3C664C4076374F75C8474C40FA7E6ABC74634C400C789961A3444C40FA7E6ABC74634C40
14378	Иштеряки	7	71	1329	56.937226000000003	56.976787999999999	56.833081999999997	56.818975999999999	0103000020E61000000100000005000000FF7A8505F7774C40BD1AA034D4684C40FF7A8505F7774C407171546EA26A4C400890A163077D4C407171546EA26A4C400890A163077D4C40BD1AA034D4684C40FF7A8505F7774C40BD1AA034D4684C40
14421	Воскресенское	7	71	1329	56.869205999999998	56.908102999999997	56.856637999999997	56.836967999999999	0103000020E6100000010000000500000055BE6724426F4C4036E675C4216B4C4055BE6724426F4C4063416150A66D4C40223317B83C744C4063416150A66D4C40223317B83C744C4036E675C4216B4C4055BE6724426F4C4036E675C4216B4C40
15356	Верхний Сып	7	71	1329	56.334285999999999	56.360202000000001	56.982112000000001	56.968445000000003	0103000020E610000001000000050000005DC136E2C92A4C40C47C7901F67B4C405DC136E2C92A4C402C8194D8B57D4C4016FA60191B2E4C402C8194D8B57D4C4016FA60191B2E4C40C47C7901F67B4C405DC136E2C92A4C40C47C7901F67B4C40
14941	Большой Ась	7	71	1329	56.317433000000001	56.332614999999997	56.924967000000002	56.900373000000002	0103000020E61000000100000005000000E9D500A5A1284C40C899266C3F734C40E9D500A5A1284C408B70935165764C405B94D920932A4C408B70935165764C405B94D920932A4C40C899266C3F734C40E9D500A5A1284C40C899266C3F734C40
14460	Барсаи	7	71	1329	56.846387999999997	56.870291999999999	56.884517000000002	56.873539000000001	0103000020E6100000010000000500000009DD2571566C4C40E9633E20D06F4C4009DD2571566C4C40C6E061DA37714C4037FC6EBA656F4C40C6E061DA37714C4037FC6EBA656F4C40E9633E20D06F4C4009DD2571566C4C40E9633E20D06F4C40
14906	Аспа	7	71	1329	56.290222999999997	56.350842	56.866985999999997	56.850766999999998	0103000020E6100000010000000500000004C6FA0626254C400DC2DCEEE56C4C4004C6FA0626254C40800BB265F96E4C4018080264E82C4C40800BB265F96E4C4018080264E82C4C400DC2DCEEE56C4C4004C6FA0626254C400DC2DCEEE56C4C40
13622	Шахарово	7	71	1264	57.391854000000002	57.437021999999999	57.068441999999997	57.048673000000001	0103000020E610000001000000050000004567994528B24C405F99B7EA3A864C404567994528B24C401FD61BB5C2884C40F6D03E56F0B74C401FD61BB5C2884C40F6D03E56F0B74C405F99B7EA3A864C404567994528B24C405F99B7EA3A864C40
47429	Филипповка	7	71	1264	57.553389000000003	57.578758000000001	57.056946000000003	57.051017999999999	0103000020E61000000100000005000000AB7B6473D5C64C40F0C000C287864C40AB7B6473D5C64C40ABD1AB014A874C403126FDBD14CA4C40ABD1AB014A874C403126FDBD14CA4C40F0C000C287864C40AB7B6473D5C64C40F0C000C287864C40
14144	Торговище	7	71	1264	57.503281000000001	57.551054000000001	57.040970999999999	57.030743999999999	0103000020E610000001000000050000005ED905836BC04C402C465D6BEF834C405ED905836BC04C40CE8AA8893E854C403D2AFEEF88C64C40CE8AA8893E854C403D2AFEEF88C64C402C465D6BEF834C405ED905836BC04C402C465D6BEF834C40
14095	Тис	7	71	1264	57.583599999999997	57.632629999999999	57.015085999999997	57.003582999999999	0103000020E6100000010000000500000009F9A067B3CA4C4029E9616875804C4009F9A067B3CA4C4050508A56EE814C40F73B1405FAD04C4050508A56EE814C40F73B1405FAD04C4029E9616875804C4009F9A067B3CA4C4029E9616875804C40
14012	Сыра	7	71	1264	57.551924999999997	57.570681999999998	56.974331999999997	56.955120999999998	0103000020E61000000100000005000000226C787AA5C64C40855CA967417A4C40226C787AA5C64C401FB935E9B67C4C403B35971B0CC94C401FB935E9B67C4C403B35971B0CC94C40855CA967417A4C40226C787AA5C64C40855CA967417A4C40
13918	Сызганка	7	71	1264	57.768653	57.794694999999997	57.115017000000002	57.097776000000003	0103000020E61000000100000005000000747CB43863E24C40B72A89EC838C4C40747CB43863E24C40F5BD86E0B88E4C40B9A5D590B8E54C40F5BD86E0B88E4C40B9A5D590B8E54C40B72A89EC838C4C40747CB43863E24C40B72A89EC838C4C40
13141	Суксун	7	71	1264	57.369180999999998	57.436213000000002	57.163581999999998	57.129660000000001	0103000020E61000000100000005000000FCA6B05241AF4C40B8CCE9B298904C40FCA6B05241AF4C406D1B4641F0944C40878BDCD3D5B74C406D1B4641F0944C40878BDCD3D5B74C40B8CCE9B298904C40FCA6B05241AF4C40B8CCE9B298904C40
13426	Советная	7	71	1264	57.298924	57.348933000000002	57.185051000000001	57.163006000000003	0103000020E61000000100000005000000A8FE412443A64C40A1866F61DD944C40A8FE412443A64C40CA8B4CC0AF974C4062BF27D6A9AC4C40CA8B4CC0AF974C4062BF27D6A9AC4C40A1866F61DD944C40A8FE412443A64C40A1866F61DD944C40
13358	Сабарка	7	71	1264	57.201061000000003	57.229888000000003	57.184874999999998	57.168526	0103000020E6100000010000000500000023C0E95DBC994C404A438D4292954C4023C0E95DBC994C408B6CE7FBA9974C4016DF50F86C9D4C408B6CE7FBA9974C4016DF50F86C9D4C404A438D4292954C4023C0E95DBC994C404A438D4292954C40
13909	Поедуги	7	71	1264	57.521453999999999	57.541262000000003	57.128258000000002	57.116404000000003	0103000020E61000000100000005000000272F3201BFC24C40D28F8653E68E4C40272F3201BFC24C40A6B915C26A904C40A648BE1248C54C40A6B915C26A904C40A648BE1248C54C40D28F8653E68E4C40272F3201BFC24C40D28F8653E68E4C40
13836	Пепелыши	7	71	1264	57.502319999999997	57.524805000000001	57.192377	57.181596999999996	0103000020E61000000100000005000000381092054CC04C409E060C923E974C40381092054CC04C4055C03DCF9F984C407EE36BCF2CC34C4055C03DCF9F984C407EE36BCF2CC34C409E060C923E974C40381092054CC04C409E060C923E974C40
56264	Осинцево	7	71	1264	57.423366999999999	57.447685	56.983671000000001	56.969661000000002	0103000020E61000000100000005000000529ACDE330B64C40749A05DA1D7C4C40529ACDE330B64C4006836BEEE87D4C4073F4F8BD4DB94C4006836BEEE87D4C4073F4F8BD4DB94C40749A05DA1D7C4C40529ACDE330B64C40749A05DA1D7C4C40
13758	Нижняя Истекаевка	7	71	1264	57.475523000000003	57.498682000000002	57.199739999999998	57.189323999999999	0103000020E6100000010000000500000077BF0AF0DDBC4C40882CD2C43B984C4077BF0AF0DDBC4C40FDD98F1491994C404C8DD0CFD4BF4C40FDD98F1491994C404C8DD0CFD4BF4C40882CD2C43B984C4077BF0AF0DDBC4C40882CD2C43B984C40
27182	Бырма	7	71	1264	57.690634000000003	57.710549999999998	57.224536000000001	57.205328000000002	0103000020E61000000100000005000000BAC0E5B166D84C40FF791A30489A4C40BAC0E5B166D84C4028637C98BD9C4C401E166A4DF3DA4C4028637C98BD9C4C401E166A4DF3DA4C40FF791A30489A4C40BAC0E5B166D84C40FF791A30489A4C40
32747	Брехово	7	71	1264	57.421346	57.446364000000003	57.001092999999997	56.984392	0103000020E6100000010000000500000074266DAAEEB54C40D6389B8E007E4C4074266DAAEEB54C4094A0BFD023804C404E0E9F7422B94C4094A0BFD023804C404E0E9F7422B94C40D6389B8E007E4C4074266DAAEEB54C40D6389B8E007E4C40
32839	Агафонково	7	71	1264	57.747722000000003	57.764888999999997	57.055790999999999	57.036754000000002	0103000020E61000000100000005000000F73FC05AB5DF4C40A4FFE55AB4844C40F73FC05AB5DF4C40A034D42824874C40FA08FCE1E7E14C40A034D42824874C40FA08FCE1E7E14C40A4FFE55AB4844C40F73FC05AB5DF4C40A4FFE55AB4844C40
48401	Черное	7	71	1832	56.925763000000003	56.959567	59.686669999999999	59.672069999999998	0103000020E61000000100000005000000666CE8667F764C40B54FC76306D64D40666CE8667F764C40799274CDE4D74D4011A96917D37A4C40799274CDE4D74D4011A96917D37A4C40B54FC76306D64D40666CE8667F764C40B54FC76306D64D40
28692	Усовский	7	71	1832	56.826841000000002	56.853017999999999	59.537393000000002	59.525551999999998	0103000020E61000000100000005000000F8FE06EDD5694C40772CB64945C34D40F8FE06EDD5694C40B70C384BC9C44D401D739EB12F6D4C40B70C384BC9C44D401D739EB12F6D4C40772CB64945C34D40F8FE06EDD5694C40772CB64945C34D40
28047	Тюлькино	7	71	1832	56.513086000000001	56.539757000000002	59.845713000000003	59.833686999999998	0103000020E610000001000000050000008A0453CDAC414C40D80C7041B6EA4D408A0453CDAC414C40AA66D65240EC4D40BF64E3C116454C40AA66D65240EC4D40BF64E3C116454C40D80C7041B6EA4D408A0453CDAC414C40D80C7041B6EA4D40
28250	Тохтуева	7	71	1832	56.718181000000001	56.738796999999998	59.729019000000001	59.719501000000001	0103000020E61000000100000005000000E6CDE15AED5B4C403B38D89B18DC4D40E6CDE15AED5B4C40D1949D7E50DD4D4003B16CE6905E4C40D1949D7E50DD4D4003B16CE6905E4C403B38D89B18DC4D40E6CDE15AED5B4C403B38D89B18DC4D40
56261	Соколово	7	71	1832	56.546117000000002	56.551443999999996	59.732433999999998	59.730184999999999	0103000020E6100000010000000500000013656F29E7454C40CF83BBB376DD4D4013656F29E7454C403E3DB665C0DD4D40A7C98CB795464C403E3DB665C0DD4D40A7C98CB795464C40CF83BBB376DD4D4013656F29E7454C40CF83BBB376DD4D40
48511	Сим	7	71	1832	57.327480999999999	57.521751000000002	59.879587999999998	59.858759999999997	0103000020E61000000100000005000000DB87BCE5EAA94C40758E01D9EBED4D40DB87BCE5EAA94C401EFAEE5696F04D40E1D39CBCC8C24C401EFAEE5696F04D40E1D39CBCC8C24C40758E01D9EBED4D40DB87BCE5EAA94C40758E01D9EBED4D40
58257	Селянка	7	71	1832	56.903539000000002	56.921208999999998	59.591078000000003	59.582782999999999	0103000020E610000001000000050000008DD47B2AA7734C4017D522A298CA4D408DD47B2AA7734C404BB1A371A8CB4D40F3E32F2DEA754C404BB1A371A8CB4D40F3E32F2DEA754C4017D522A298CA4D408DD47B2AA7734C4017D522A298CA4D40
28391	Половодово	7	71	1832	57.058382000000002	57.091287000000001	59.662143999999998	59.645032	0103000020E610000001000000050000006956B60F79874C40CE6F986890D24D406956B60F79874C400E9F7422C1D44D4065C6DB4AAF8B4C400E9F7422C1D44D4065C6DB4AAF8B4C40CE6F986890D24D406956B60F79874C40CE6F986890D24D40
56270	Пальники	7	71	1832	55.595089000000002	55.606470999999999	59.742955000000002	59.735771999999997	0103000020E61000000100000005000000CC9A58E02BCC4B4000A8E2C62DDE4D40CC9A58E02BCC4B4029B3412619DF4D40787C7BD7A0CD4B4029B3412619DF4D40787C7BD7A0CD4B4000A8E2C62DDE4D40CC9A58E02BCC4B4000A8E2C62DDE4D40
48422	Осокино	7	71	1832	57.044494	57.067428	59.811042999999998	59.794569000000003	0103000020E61000000100000005000000226FB9FAB1854C402DB5DE6FB4E54D40226FB9FAB1854C402A53CC41D0E74D40D76A0F7BA1884C402A53CC41D0E74D40D76A0F7BA1884C402DB5DE6FB4E54D40226FB9FAB1854C402DB5DE6FB4E54D40
28132	Нижнее Мошево	7	71	1832	56.593243000000001	56.614955000000002	59.810319	59.790027000000002	0103000020E610000001000000050000005CCAF962EF4B4C407FFACF9A1FE54D405CCAF962EF4B4C40E9297288B8E74D407FC16ED8B64E4C40E9297288B8E74D407FC16ED8B64E4C407FFACF9A1FE54D405CCAF962EF4B4C407FFACF9A1FE54D40
47912	Красный Берег	7	71	1832	57.674545000000002	57.706479999999999	60.009453000000001	59.997824000000001	0103000020E610000001000000050000001557957D57D64C40FB9463B2B8FF4D401557957D57D64C40AFEC82C135014E4098A3C7EF6DDA4C40AFEC82C135014E4098A3C7EF6DDA4C40FB9463B2B8FF4D401557957D57D64C40FB9463B2B8FF4D40
58960	Кокорино	7	71	1832	56.787064000000001	56.800232999999999	59.802335999999997	59.795808999999998	0103000020E61000000100000005000000F2ED5D83BE644C40656EBE11DDE54D40F2ED5D83BE644C40A43330F2B2E64D400917F2086E664C40A43330F2B2E64D400917F2086E664C40656EBE11DDE54D40F2ED5D83BE644C40656EBE11DDE54D40
28184	Касиб	7	71	1832	56.331913999999998	56.368529000000002	59.697519	59.681350999999999	0103000020E61000000100000005000000D28A6F287C2A4C40670C738236D74D40D28A6F287C2A4C4058AB764D48D94D40555051F52B2F4C4058AB764D48D94D40555051F52B2F4C40670C738236D74D40D28A6F287C2A4C40670C738236D74D40
56316	Затон	7	71	1832	56.571916999999999	56.584753999999997	59.831150000000001	59.824154	0103000020E610000001000000050000006283859334494C400D6FD6E07DE94D406283859334494C4003098A1F63EA4D40431A1538D94A4C4003098A1F63EA4D40431A1538D94A4C400D6FD6E07DE94D406283859334494C400D6FD6E07DE94D40
28368	Жуланово	7	71	1832	56.669339000000001	56.699945	59.953637000000001	59.939487	0103000020E61000000100000005000000FB777DE6AC554C4032022A1C41F84D40FB777DE6AC554C40B6A0F7C610FA4D40D6FF39CC97594C40B6A0F7C610FA4D40D6FF39CC97594C4032022A1C41F84D40FB777DE6AC554C4032022A1C41F84D40
28008	Басим	7	71	1832	55.685198999999997	55.706139	59.766370999999999	59.754719000000001	0103000020E610000001000000050000003E20D099B4D74B40BD55D7A19AE04D403E20D099B4D74B4029CDE67118E24D400FB743C362DA4B4029CDE67118E24D400FB743C362DA4B40BD55D7A19AE04D403E20D099B4D74B40BD55D7A19AE04D40
56322	Юбилейный	7	71	927	54.019219	54.029128	58.520417999999999	58.514491	0103000020E610000001000000050000001D3BA8C475024B400D8B51D7DA414D401D3BA8C475024B40F71F990E9D424D40EEB25F77BA034B40F71F990E9D424D40EEB25F77BA034B400D8B51D7DA414D401D3BA8C475024B400D8B51D7DA414D40
11704	Шулынды	7	71	927	54.155144	54.173271999999997	58.406159000000002	58.396464000000002	0103000020E61000000100000005000000D71533C2DB134B404B051555BF324D40D71533C2DB134B40F0FCA204FD334D4000A8E2C62D164B40F0FCA204FD334D4000A8E2C62D164B404B051555BF324D40D71533C2DB134B404B051555BF324D40
56523	Усть-Буб	7	71	927	54.557211000000002	54.569949999999999	58.323295000000002	58.313699999999997	0103000020E6100000010000000500000059FCA6B052474B40AA60545227284D4059FCA6B052474B40ECFA05BB61294D40772D211FF4484B40ECFA05BB61294D40772D211FF4484B40AA60545227284D4059FCA6B052474B40AA60545227284D40
11601	Сива	7	71	927	54.341939000000004	54.402549	58.397817000000003	58.358911999999997	0103000020E610000001000000050000000D1D3BA8C42B4B402B1213D4F02D4D400D1D3BA8C42B4B407C65DEAAEB324D40CD04C3B986334B407C65DEAAEB324D40CD04C3B986334B402B1213D4F02D4D400D1D3BA8C42B4B402B1213D4F02D4D40
33065	Серьгино	7	71	927	54.258611000000002	54.283639000000001	58.516865000000003	58.507778999999999	0103000020E6100000010000000500000064B14D2A1A214B403C4CFBE6FE404D4064B14D2A1A214B4039B9DFA128424D40616F62484E244B4039B9DFA128424D40616F62484E244B403C4CFBE6FE404D4064B14D2A1A214B403C4CFBE6FE404D40
11248	Серафимовское	7	71	927	53.956094999999998	53.974079000000003	58.357269000000002	58.346657999999998	0103000020E610000001000000050000003F6F2A5261FA4A40C972124A5F2C4D403F6F2A5261FA4A40F46F97FDBA2D4D40365CE49EAEFC4A40F46F97FDBA2D4D40365CE49EAEFC4A40C972124A5F2C4D403F6F2A5261FA4A40C972124A5F2C4D40
11168	Северный Коммунар	7	71	927	53.988622999999997	54.041947	58.388793999999997	58.369509999999998	0103000020E610000001000000050000006589CE328BFE4A40C1C58A1A4C2F4D406589CE328BFE4A40C5707500C4314D402995F0845E054B40C5707500C4314D402995F0845E054B40C1C58A1A4C2F4D406589CE328BFE4A40C1C58A1A4C2F4D40
10950	Сатино	7	71	927	53.894264	53.906840000000003	58.549337000000001	58.543739000000002	0103000020E61000000100000005000000BDFE243E77F24A40A647533D99454D40BDFE243E77F24A40CBBDC0AC50464D40325A475513F44A40CBBDC0AC50464D40325A475513F44A40A647533D99454D40BDFE243E77F24A40A647533D99454D40
11428	Савичи	7	71	927	54.384141999999997	54.417245000000001	58.358468000000002	58.341821000000003	0103000020E610000001000000050000009082A7902B314B40030B60CAC02B4D409082A7902B314B40CE548847E22D4D40B3B5BE4868354B40CE548847E22D4D40B3B5BE4868354B40030B60CAC02B4D409082A7902B314B40030B60CAC02B4D40
58217	Кривчана	7	71	927	54.512520000000002	54.531286000000001	58.317264000000002	58.310552000000001	0103000020E61000000100000005000000E1455F419A414B408CDAFD2AC0274D40E1455F419A414B405D19541B9C284D404D69FD2D01444B405D19541B9C284D404D69FD2D01444B408CDAFD2AC0274D40E1455F419A414B408CDAFD2AC0274D40
58264	Краснояр	7	71	927	54.519123	54.528753000000002	58.575837999999997	58.572510999999999	0103000020E61000000100000005000000FBCC599F72424B40D5CC5A0A48494D40FBCC599F72424B40A3E5400FB5494D40B954A52DAE434B40A3E5400FB5494D40B954A52DAE434B40D5CC5A0A48494D40FBCC599F72424B40D5CC5A0A48494D40
58277	Кичаново	7	71	927	54.392091999999998	54.406618000000002	58.323669000000002	58.317197999999998	0103000020E61000000100000005000000F982161230324B40A52DAEF199284D40F982161230324B4051DD5CFC6D294D4083FB010F0C344B4051DD5CFC6D294D4083FB010F0C344B40A52DAEF199284D40F982161230324B40A52DAEF199284D40
11361	Кизьва	7	71	927	54.532463	54.561253999999998	58.496381	58.474915000000003	0103000020E610000001000000050000003FAA61BF27444B409FB0C403CA3C4D403FAA61BF27444B408AADA069893F4D40E55FCB2BD7474B408AADA069893F4D40E55FCB2BD7474B409FB0C403CA3C4D403FAA61BF27444B409FB0C403CA3C4D40
46331	Кекур	7	71	927	54.525914	54.536864999999999	58.431925999999997	58.428482000000002	0103000020E610000001000000050000001841632651434B405C76887FD8364D401841632651434B406325E65949374D40FBAE08FEB7444B406325E65949374D40FBAE08FEB7444B405C76887FD8364D401841632651434B405C76887FD8364D40
48082	Калиновка	7	71	927	54.025517000000001	54.034823000000003	58.507157999999997	58.501206000000003	0103000020E61000000100000005000000FB3E1C2444034B408D47A98427404D40FB3E1C2444034B40CFF3A78DEA404D4006137F1475044B40CFF3A78DEA404D4006137F1475044B408D47A98427404D40FB3E1C2444034B408D47A98427404D40
49592	Зыряново	7	71	927	54.203418999999997	54.218339999999998	58.413432999999998	58.408149000000002	0103000020E61000000100000005000000483140A2091A4B409372F7393E344D40483140A2091A4B40280B5F5FEB344D404EB4AB90F21B4B40280B5F5FEB344D404EB4AB90F21B4B409372F7393E344D40483140A2091A4B409372F7393E344D40
56292	Екатерининское	7	71	927	54.052745000000002	54.094813000000002	58.479249000000003	58.469192999999997	0103000020E6100000010000000500000086032159C0064B408D4127840E3C4D4086032159C0064B4003D2FE07583D4D402A1E17D5220C4B4003D2FE07583D4D402A1E17D5220C4B408D4127840E3C4D4086032159C0064B408D4127840E3C4D40
58254	Дмитриево	7	71	927	54.462609999999998	54.485328000000003	58.423293000000001	58.412519000000003	0103000020E61000000100000005000000BA66F2CD363B4B4044FD2E6CCD344D40BA66F2CD363B4B4018D00B772E364D40A3EA573A1F3E4B4018D00B772E364D40A3EA573A1F3E4B4044FD2E6CCD344D40BA66F2CD363B4B4044FD2E6CCD344D40
10734	Буб	7	71	927	54.360470999999997	54.397948999999997	58.301009999999998	58.288116000000002	0103000020E610000001000000050000000514EAE9232E4B4028BA2EFCE0244D400514EAE9232E4B406DE2E47E87264D40EA3C2AFEEF324B406DE2E47E87264D40EA3C2AFEEF324B4028BA2EFCE0244D400514EAE9232E4B4028BA2EFCE0244D40
10754	Бровилята	7	71	927	54.426929000000001	54.456932999999999	58.299747000000004	58.296531000000002	0103000020E61000000100000005000000645B069CA5364B4006A051BAF4254D40645B069CA5364B407D09151C5E264D4049BBD1C77C3A4B407D09151C5E264D4049BBD1C77C3A4B4006A051BAF4254D40645B069CA5364B4006A051BAF4254D40
10663	Большое Самылово	7	71	927	54.241103000000003	54.258926000000002	58.290018000000003	58.277876999999997	0103000020E61000000100000005000000D7FB8D76DC1E4B40C1A7397991234D40D7FB8D76DC1E4B402CA0504F1F254D40C40AB77C24214B402CA0504F1F254D40C40AB77C24214B40C1A7397991234D40D7FB8D76DC1E4B40C1A7397991234D40
45904	Антипина	7	71	927	54.292873	54.319436000000003	58.211976999999997	58.199620000000003	0103000020E61000000100000005000000D270CADC7C254B4053D0ED258D194D40D270CADC7C254B408940F50F221B4D4021956247E3284B408940F50F221B4D4021956247E3284B4053D0ED258D194D40D270CADC7C254B4053D0ED258D194D40
56279	Андреево	7	71	927	54.267271000000001	54.287509999999997	58.508150000000001	58.498088000000003	0103000020E61000000100000005000000A915A6EF35224B40D943FB58C13F4D40A915A6EF35224B4030BB270F0B414D40F0A2AF20CD244B4030BB270F0B414D40F0A2AF20CD244B40D943FB58C13F4D40A915A6EF35224B40D943FB58C13F4D40
26928	Янычи	7	71	849	56.408783	56.446333000000003	57.694113999999999	57.674363	0103000020E610000001000000050000009414580053344C40F450DB8651D64C409414580053344C400ED940BAD8D84C401310937021394C400ED940BAD8D84C401310937021394C40F450DB8651D64C409414580053344C40F450DB8651D64C40
6309	Юго-Камский	7	71	849	55.549562000000002	55.623672999999997	57.719743000000001	57.676831999999997	0103000020E61000000100000005000000EB8F300C58C64B407171546EA2D64C40EB8F300C58C64B403143E38920DC4C40F8325184D4CF4B403143E38920DC4C40F8325184D4CF4B407171546EA2D64C40EB8F300C58C64B407171546EA2D64C40
56247	Юг	7	71	849	55.425863999999997	56.831521000000002	58.166168999999996	57.392600999999999	0103000020E61000000100000005000000994528B682B64B403EB0E3BF40B24C40994528B682B64B40F44D9A0645154D40F777B6476F6A4C40F44D9A0645154D40F777B6476F6A4C403EB0E3BF40B24C40994528B682B64B403EB0E3BF40B24C40
28049	Чуваки	7	71	849	55.959985000000003	55.986539	57.869306999999999	57.853976000000003	0103000020E6100000010000000500000046D3D9C9E0FA4B40D2C8E7154FED4C4046D3D9C9E0FA4B408997A77345EF4C40419DF2E846FE4B408997A77345EF4C40419DF2E846FE4B40D2C8E7154FED4C4046D3D9C9E0FA4B40D2C8E7154FED4C40
28545	Усть-Качка	7	71	849	55.670413000000003	55.679566999999999	58.011532000000003	58.004533000000002	0103000020E6100000010000000500000019E8DA17D0D54B405B608F8994004D4019E8DA17D0D54B40C26D6DE179014D406D382C0DFCD64B40C26D6DE179014D406D382C0DFCD64B405B608F8994004D4019E8DA17D0D54B405B608F8994004D40
58154	Троица	7	71	849	56.766384000000002	56.804329000000003	57.992584999999998	57.985128000000003	0103000020E61000000100000005000000BE16F4DE18624C40DC2F9FAC18FE4C40BE16F4DE18624C4005C078060DFF4C40B91CAF40F4664C4005C078060DFF4C40B91CAF40F4664C40DC2F9FAC18FE4C40BE16F4DE18624C40DC2F9FAC18FE4C40
29322	Сылва	7	71	849	56.745058	56.784036	58.041218999999998	58.028111000000003	0103000020E61000000100000005000000C4CF7F0F5E5F4C4035D4282499034D40C4CF7F0F5E5F4C40A67C08AA46054D407E71A94A5B644C40A67C08AA46054D407E71A94A5B644C4035D4282499034D40C4CF7F0F5E5F4C4035D4282499034D40
27319	Суздалы	7	71	849	55.704000999999998	55.720880000000001	57.923184999999997	57.918401000000003	0103000020E61000000100000005000000F7AC6BB41CDA4B408ECEF9298EF54C40F7AC6BB41CDA4B40319413ED2AF64C40952BBCCB45DC4B40319413ED2AF64C40952BBCCB45DC4B408ECEF9298EF54C40F7AC6BB41CDA4B408ECEF9298EF54C40
61184	Сокол	7	71	849	55.425863999999997	56.831521000000002	58.166168999999996	57.392600999999999	0103000020E61000000100000005000000994528B682B64B403EB0E3BF40B24C40994528B682B64B40F44D9A0645154D40F777B6476F6A4C40F44D9A0645154D40F777B6476F6A4C403EB0E3BF40B24C40994528B682B64B403EB0E3BF40B24C40
58153	Рождественское	7	71	849	55.693660999999999	55.713388000000002	57.560513999999998	57.552261999999999	0103000020E610000001000000050000005DC136E2C9D84B406A696E85B0C64C405DC136E2C9D84B409E7939ECBEC74C40EFAD484C50DB4B409E7939ECBEC74C40EFAD484C50DB4B406A696E85B0C64C405DC136E2C9D84B406A696E85B0C64C40
56267	Октябрьский	7	71	849	56.015284999999999	56.045648	57.482444000000001	57.468037000000002	0103000020E61000000100000005000000478FDFDBF4014C40B328ECA2E8BB4C40478FDFDBF4014C40621399B9C0BD4C405C902DCBD7054C40621399B9C0BD4C405C902DCBD7054C40B328ECA2E8BB4C40478FDFDBF4014C40B328ECA2E8BB4C40
56310	Новый	7	71	849	55.679405000000003	55.693688000000002	57.564492000000001	57.546269000000002	0103000020E6100000010000000500000094DE37BEF6D64B40C9E88024ECC54C4094DE37BEF6D64B40446D1B4641C84C4057D0B4C4CAD84B40446D1B4641C84C4057D0B4C4CAD84B40C9E88024ECC54C4094DE37BEF6D64B40C9E88024ECC54C40
28402	Нижний Пальник	7	71	849	56.305540000000001	56.328330000000001	57.629536999999999	57.605826	0103000020E6100000010000000500000057CF49EF1B274C408388D4B48BCD4C4057CF49EF1B274C409C4F1DAB94D04C40D925AAB7062A4C409C4F1DAB94D04C40D925AAB7062A4C408388D4B48BCD4C4057CF49EF1B274C408388D4B48BCD4C40
27131	Нестюково	7	71	849	56.246412999999997	56.284500999999999	57.893639999999998	57.867013999999998	0103000020E61000000100000005000000952710768A1F4C404A969350FAEE4C40952710768A1F4C40DF32A7CB62F24C40F3565D876A244C40DF32A7CB62F24C40F3565D876A244C404A969350FAEE4C40952710768A1F4C404A969350FAEE4C40
6640	Мулянка	7	71	849	56.358711	56.399422999999999	57.819412999999997	57.789791000000001	0103000020E6100000010000000500000094DBF63DEA2D4C406BD619DF17E54C4094DBF63DEA2D4C4068757286E2E84C409622F94A20334C4068757286E2E84C409622F94A20334C406BD619DF17E54C4094DBF63DEA2D4C406BD619DF17E54C40
58535	Мостовая	7	71	849	56.661506000000003	56.737341999999998	57.993614999999998	57.824029000000003	0103000020E61000000100000005000000CC0D863AAC544C4051FA42C879E94C40CC0D863AAC544C4053E8BCC62EFF4C40CEFBFF38615E4C4053E8BCC62EFF4C40CEFBFF38615E4C4051FA42C879E94C40CC0D863AAC544C4051FA42C879E94C40
28128	Лобаново	7	71	849	56.279947	56.311990000000002	57.870474999999999	57.853771000000002	0103000020E6100000010000000500000081CEA44DD5234C40F9A23D5E48ED4C4081CEA44DD5234C40287E8CB96BEF4C40EB56CF49EF274C40287E8CB96BEF4C40EB56CF49EF274C40F9A23D5E48ED4C4081CEA44DD5234C40F9A23D5E48ED4C40
28086	Курашим	7	71	849	56.591087000000002	56.63223	57.667873999999998	57.641654000000003	0103000020E610000001000000050000009E0B23BDA84B4C407EACE0B721D24C409E0B23BDA84B4C40A2EC2DE57CD54C4069C6A2E9EC504C40A2EC2DE57CD54C4069C6A2E9EC504C407EACE0B721D24C409E0B23BDA84B4C407EACE0B721D24C40
27824	Култаево	7	71	849	55.921841999999998	55.964207000000002	57.905458000000003	57.888033	0103000020E61000000100000005000000240A2DEBFEF54B406762BA10ABF14C40240A2DEBFEF54B4067F3380CE6F34C4082C98D226BFB4B4067F3380CE6F34C4082C98D226BFB4B406762BA10ABF14C40240A2DEBFEF54B406762BA10ABF14C40
10345	Кукуштан	7	71	849	56.448695000000001	56.529463	57.663421	57.631638000000002	0103000020E610000001000000050000007A7077D66E394C4097749483D9D04C407A7077D66E394C40643DB5FAEAD44C4095B88E71C5434C40643DB5FAEAD44C4095B88E71C5434C4097749483D9D04C407A7077D66E394C4097749483D9D04C40
49152	Красный Восход	7	71	849	55.690866999999997	55.722074999999997	57.999004999999997	57.982765999999998	0103000020E610000001000000050000005C7171546ED84B4074CFBA46CBFD4C405C7171546ED84B402EC55565DFFF4C402D211FF46CDC4B402EC55565DFFF4C402D211FF46CDC4B4074CFBA46CBFD4C405C7171546ED84B4074CFBA46CBFD4C40
33032	Кояново	7	71	849	56.293790000000001	56.341265999999997	57.809978000000001	57.785066	0103000020E6100000010000000500000028F224E99A254C40CC99ED0A7DE44C4028F224E99A254C40603DEE5BADE74C404D9EB29AAE2B4C40603DEE5BADE74C404D9EB29AAE2B4C40CC99ED0A7DE44C4028F224E99A254C40CC99ED0A7DE44C40
27960	Косотуриха	7	71	849	55.870503999999997	55.892781999999997	57.875222999999998	57.867182	0103000020E61000000100000005000000C284D1AC6CEF4B4006D7DCD1FFEE4C40C284D1AC6CEF4B407FDAA84E07F04C408E3A3AAE46F24B407FDAA84E07F04C408E3A3AAE46F24B4006D7DCD1FFEE4C40C284D1AC6CEF4B4006D7DCD1FFEE4C40
33090	Касимово	7	71	849	56.211621000000001	56.251263000000002	57.823473	57.808266000000003	0103000020E61000000100000005000000CB129D65161B4C40003CA24275E74C40CB129D65161B4C40CB11329067E94C40F1D8CF6229204C40CB11329067E94C40F1D8CF6229204C40003CA24275E74C40CB129D65161B4C40003CA24275E74C40
56246	Звездный	7	71	849	55.425863999999997	56.831521000000002	58.166168999999996	57.392600999999999	0103000020E61000000100000005000000994528B682B64B403EB0E3BF40B24C40994528B682B64B40F44D9A0645154D40F777B6476F6A4C40F44D9A0645154D40F777B6476F6A4C403EB0E3BF40B24C40994528B682B64B403EB0E3BF40B24C40
32996	Горшки	7	71	849	55.734768000000003	55.753048999999997	57.944009000000001	57.924532999999997	0103000020E61000000100000005000000DC12B9E00CDE4B405089EB1857F64C40DC12B9E00CDE4B4099107349D5F84C408BA4DDE863E04B4099107349D5F84C408BA4DDE863E04B405089EB1857F64C40DC12B9E00CDE4B405089EB1857F64C40
32986	Горный	7	71	849	56.316023000000001	56.641195000000003	57.900861999999996	57.827661999999997	0103000020E6100000010000000500000054E4107173284C402B1213D4F0E94C4054E4107173284C40C51A2E724FF34C40EBAD81AD12524C40C51A2E724FF34C40EBAD81AD12524C402B1213D4F0E94C4054E4107173284C402B1213D4F0E94C40
56311	Голый Мыс	7	71	849	55.535935000000002	55.544612999999998	57.908839	57.905425000000001	0103000020E6100000010000000500000011E4A08499C44B408BFD65F7E4F34C4011E4A08499C44B40282A1BD654F44C40FCFCF7E0B5C54B40282A1BD654F44C40FCFCF7E0B5C54B408BFD65F7E4F34C4011E4A08499C44B408BFD65F7E4F34C40
8468	Бырма	7	71	849	56.196807999999997	56.226407000000002	57.630448000000001	57.619999	0103000020E61000000100000005000000ABCB290131194C40BF4692205CCF4C40ABCB290131194C4010EA2285B2D04C40F14A92E7FA1C4C4010EA2285B2D04C40F14A92E7FA1C4C40BF4692205CCF4C40ABCB290131194C40BF4692205CCF4C40
58251	Большое Савино	7	71	849	55.999205000000003	56.023809999999997	57.935246999999997	57.914389999999997	0103000020E61000000100000005000000F67F0EF3E5FF4B400CE544BB0AF54C40F67F0EF3E5FF4B404F57772CB6F74C40ACA8C1340C034C404F57772CB6F74C40ACA8C1340C034C400CE544BB0AF54C40F67F0EF3E5FF4B400CE544BB0AF54C40
27251	Большакино	7	71	849	55.771158999999997	55.787489999999998	57.903593000000001	57.897202999999998	0103000020E610000001000000050000000E828E56B5E24B40C16F438CD7F24C400E828E56B5E24B4080F277EFA8F34C40A9F6E978CCE44B4080F277EFA8F34C40A9F6E978CCE44B40C16F438CD7F24C400E828E56B5E24B40C16F438CD7F24C40
58164	Бершетские Дачи	7	71	849	56.292200000000001	56.329281999999999	57.742913999999999	57.728465999999997	0103000020E6100000010000000500000013F241CF66254C40BC1FB75F3EDD4C4013F241CF66254C40CADE52CE17DF4C40AB949EE9252A4C40CADE52CE17DF4C40AB949EE9252A4C40BC1FB75F3EDD4C4013F241CF66254C40BC1FB75F3EDD4C40
24625	Ныр	7	67	592	47.946562999999998	47.965184999999998	57.499578	57.481375	0103000020E61000000100000005000000444DF4F928F94740560E2DB29DBD4C40444DF4F928F947408AE6012CF2BF4C407DCB9C2E8BFB47408AE6012CF2BF4C407DCB9C2E8BFB4740560E2DB29DBD4C40444DF4F928F94740560E2DB29DBD4C40
27873	Башкултаево	7	71	849	55.891748999999997	55.919471000000001	57.851649000000002	57.835653999999998	0103000020E61000000100000005000000CF9ECBD424F24B40C362D4B5F6EA4C40CF9ECBD424F24B40E7559DD502ED4C406A4FC939B1F54B40E7559DD502ED4C406A4FC939B1F54B40C362D4B5F6EA4C40CF9ECBD424F24B40C362D4B5F6EA4C40
27755	Байболовка	7	71	849	56.477925999999997	56.510364000000003	57.593508	57.577587000000001	0103000020E610000001000000050000003CF4DDAD2C3D4C4021CCED5EEEC94C403CF4DDAD2C3D4C400AF5F411F8CB4C402387889B53414C400AF5F411F8CB4C402387889B53414C4021CCED5EEEC94C403CF4DDAD2C3D4C4021CCED5EEEC94C40
32950	Токари	7	71	1781	54.263364000000003	54.28575	57.939360999999998	57.929499	0103000020E61000000100000005000000CD785BE9B5214B401555BFD2F9F64C40CD785BE9B5214B40A51133FB3CF84C407F6ABC7493244B40A51133FB3CF84C407F6ABC7493244B401555BFD2F9F64C40CD785BE9B5214B401555BFD2F9F64C40
26458	Спешково	7	71	1781	54.546565999999999	54.563769000000001	57.941037999999999	57.926459000000001	0103000020E61000000100000005000000828DEBDFF5454B40DD0A613596F64C40828DEBDFF5454B408925E5EE73F84C40D3BF249529484B408925E5EE73F84C40D3BF249529484B40DD0A613596F64C40828DEBDFF5454B40DD0A613596F64C40
32565	Семеново	7	71	1781	54.702289	54.716079000000001	57.835476999999997	57.825994000000001	0103000020E6100000010000000500000097AB1F9BE4594B409B58E02BBAE94C4097AB1F9BE4594B40B4C70BE9F0EA4C401B2D077AA85B4B40B4C70BE9F0EA4C401B2D077AA85B4B409B58E02BBAE94C4097AB1F9BE4594B409B58E02BBAE94C40
48044	Павловский	7	71	1781	54.814300000000003	54.867731999999997	57.857481999999997	57.830666000000001	0103000020E6100000010000000500000000917EFB3A684B4017F3734353EA4C4000917EFB3A684B404F745DF8C1ED4C40A9D898D7116F4B404F745DF8C1ED4C40A9D898D7116F4B4017F3734353EA4C4000917EFB3A684B4017F3734353EA4C40
25794	Очер	7	71	1781	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
26626	Нововознесенск	7	71	1781	54.488275000000002	54.512816999999998	57.804065999999999	57.793835000000001	0103000020E610000001000000050000002A3A92CB7F3E4B40C8B5A1629CE54C402A3A92CB7F3E4B40ABE97AA2EBE64C409AEAC9FCA3414B40ABE97AA2EBE64C409AEAC9FCA3414B40C8B5A1629CE54C402A3A92CB7F3E4B40C8B5A1629CE54C40
26206	Нижняя Талица	7	71	1781	54.954788000000001	54.977389000000002	57.873902000000001	57.853718000000001	0103000020E610000001000000050000007F4E417E367A4B40D600A5A146ED4C407F4E417E367A4B405AF44E05DCEF4C402E3C2F151B7D4B405AF44E05DCEF4C402E3C2F151B7D4B40D600A5A146ED4C407F4E417E367A4B40D600A5A146ED4C40
32922	Морозово	7	71	1781	54.801886000000003	54.823777999999997	57.958494000000002	57.934596999999997	0103000020E61000000100000005000000658F5033A4664B4048F8DEDFA0F74C40658F5033A4664B40C4B46FEEAFFA4C400795B88E71694B40C4B46FEEAFFA4C400795B88E71694B4048F8DEDFA0F74C40658F5033A4664B4048F8DEDFA0F74C40
32911	Лужково	7	71	1781	54.708047999999998	54.732804999999999	57.924911000000002	57.912157000000001	0103000020E61000000100000005000000C5FF1D51A15A4B40A3E8818FC1F44C40C5FF1D51A15A4B40F75AD07B63F64C4032ACE28DCC5D4B40F75AD07B63F64C4032ACE28DCC5D4B40A3E8818FC1F44C40C5FF1D51A15A4B40A3E8818FC1F44C40
26833	Кулики	7	71	1781	54.337600000000002	54.364899999999999	57.882373000000001	57.870494000000001	0103000020E6100000010000000500000097900F7A362B4B409FAEEE586CEF4C4097900F7A362B4B40CCEF3499F1F04C40BB270F0BB52E4B40CCEF3499F1F04C40BB270F0BB52E4B409FAEEE586CEF4C4097900F7A362B4B409FAEEE586CEF4C40
32939	Киприно	7	71	1781	54.470999999999997	54.505234999999999	57.902087000000002	57.895524000000002	0103000020E610000001000000050000003F355EBA493C4B403D64CA87A0F24C403F355EBA493C4B40C992399677F34C40B4E55C8AAB404B40C992399677F34C40B4E55C8AAB404B403D64CA87A0F24C403F355EBA493C4B403D64CA87A0F24C40
56503	Дворец	7	71	1781	54.923526000000003	54.963205000000002	58.021414999999998	58.009157999999999	0103000020E61000000100000005000000BB80971936764B40963FDF162C014D40BB80971936764B4069520ABABD024D40FE2B2B4D4A7B4B4069520ABABD024D40FE2B2B4D4A7B4B40963FDF162C014D40BB80971936764B40963FDF162C014D40
25446	Тулумбаиха	7	71	1092	55.312677000000001	55.338180000000001	57.716757999999999	57.705992999999999	0103000020E610000001000000050000000F9BC8CC05A84B403B1A87FA5DDA4C400F9BC8CC05A84B40BC92E4B9BEDB4C40A514747B49AB4B40BC92E4B9BEDB4C40A514747B49AB4B403B1A87FA5DDA4C400F9BC8CC05A84B403B1A87FA5DDA4C40
32744	Таборы	7	71	1092	55.136085999999999	55.161552999999998	57.836545999999998	57.821944000000002	0103000020E61000000100000005000000C3B81B446B914B405C92037635E94C40C3B81B446B914B40C0CC77F013EB4C400CC9C9C4AD944B40C0CC77F013EB4C400CC9C9C4AD944B405C92037635E94C40C3B81B446B914B405C92037635E94C40
32780	Пономари	7	71	1092	54.943441999999997	54.978988000000001	57.759338999999997	57.741151000000002	0103000020E610000001000000050000001FD61BB5C2784B40E8323509DEDE4C401FD61BB5C2784B40E6C9350532E14C409696917A4F7D4B40E6C9350532E14C409696917A4F7D4B40E8323509DEDE4C401FD61BB5C2784B40E8323509DEDE4C40
25119	Оханск	7	71	1092	55.351205	55.421731999999999	57.730277999999998	57.699438000000001	0103000020E6100000010000000500000089981249F4AC4B4032CA332F87D94C4089981249F4AC4B40807EDFBF79DD4C409DD66D50FBB54B40807EDFBF79DD4C409DD66D50FBB54B4032CA332F87D94C4089981249F4AC4B4032CA332F87D94C40
9658	Острожка	7	71	1092	55.164760000000001	55.211643000000002	57.676836000000002	57.659469000000001	0103000020E6100000010000000500000030D80DDB16954B40E8DCED7A69D44C4030D80DDB16954B40B360E28FA2D64C40B3B6291E179B4B40B360E28FA2D64C40B3B6291E179B4B40E8DCED7A69D44C4030D80DDB16954B40E8DCED7A69D44C40
32770	Мерзляки	7	71	1092	55.087243999999998	55.110205000000001	57.772602999999997	57.762228999999998	0103000020E61000000100000005000000D862B7CF2A8B4B40098849B890E14C40D862B7CF2A8B4B404FE5B4A7E4E24C40876D8B321B8E4B404FE5B4A7E4E24C40876D8B321B8E4B40098849B890E14C40D862B7CF2A8B4B40098849B890E14C40
56260	Ключи	7	71	1092	55.473547000000003	55.493237999999998	57.514707000000001	57.510393999999998	0103000020E61000000100000005000000390F27309DBC4B408D09319754C14C40390F27309DBC4B40DA0242EBE1C14C407D923B6C22BF4B40DA0242EBE1C14C407D923B6C22BF4B408D09319754C14C40390F27309DBC4B408D09319754C14C40
56280	Казанка	7	71	1092	55.346398999999998	55.371184	57.598115	57.583218000000002	0103000020E61000000100000005000000FD2E6CCD56AC4B4022382EE3A6CA4C40FD2E6CCD56AC4B409F1F46088FCC4C40346612F582AF4B409F1F46088FCC4C40346612F582AF4B4022382EE3A6CA4C40FD2E6CCD56AC4B4022382EE3A6CA4C40
58218	Заполье	7	71	1092	55.321308999999999	55.335332000000001	57.603110999999998	57.596454999999999	0103000020E610000001000000050000008A743FA720A94B4091442FA358CC4C408A743FA720A94B40CE6DC2BD32CD4C40B1A6B228ECAA4B40CE6DC2BD32CD4C40B1A6B228ECAA4B4091442FA358CC4C408A743FA720A94B4091442FA358CC4C40
56227	Березовка	7	71	1092	55.223151000000001	55.244036000000001	57.700256000000003	57.690005999999997	0103000020E61000000100000005000000EC884336909C4B409A05DA1D52D84C40EC884336909C4B40F56915FDA1D94C40F98557923C9F4B40F56915FDA1D94C40F98557923C9F4B409A05DA1D52D84C40EC884336909C4B409A05DA1D52D84C40
32711	Беляевка	7	71	1092	55.458590000000001	55.499248000000001	57.480949000000003	57.459933999999997	0103000020E61000000100000005000000E622BE13B3BA4B40C328081EDFBA4C40E622BE13B3BA4B409F05A1BC8FBD4C40F54BC45BE7BF4B409F05A1BC8FBD4C40F54BC45BE7BF4B40C328081EDFBA4C40E622BE13B3BA4B40C328081EDFBA4C40
56277	Андреевка	7	71	1092	55.233947999999998	55.263286999999998	57.524155999999998	57.517113999999999	0103000020E61000000100000005000000787B1002F29D4B40E126A3CA30C24C40787B1002F29D4B404700378B17C34C40213B6F63B3A14B404700378B17C34C40213B6F63B3A14B40E126A3CA30C24C40787B1002F29D4B40E126A3CA30C24C40
58228	Устиново	7	71	1406	55.353333999999997	55.381793000000002	57.264609999999998	57.251300999999998	0103000020E610000001000000050000004D486B0C3AAD4B40DE3994A12AA04C404D486B0C3AAD4B40E71890BDDEA14C40BE6BD097DEB04B40E71890BDDEA14C40BE6BD097DEB04B40DE3994A12AA04C404D486B0C3AAD4B40DE3994A12AA04C40
32557	Пермякова	7	71	1406	55.292904999999998	55.314132000000001	57.281573999999999	57.268095000000002	0103000020E61000000100000005000000DDEA39E97DA54B404E9CDCEF50A24C40DDEA39E97DA54B40B3B3E89D0AA44C404450357A35A84B40B3B3E89D0AA44C404450357A35A84B404E9CDCEF50A24C40DDEA39E97DA54B404E9CDCEF50A24C40
24903	Паль	7	71	1406	55.636825000000002	55.674536000000003	57.469527999999997	57.449053999999997	0103000020E610000001000000050000003A234A7B83D14B40A911FA997AB94C403A234A7B83D14B403447567E19BC4C40C2FC153257D64B403447567E19BC4C40C2FC153257D64B40A911FA997AB94C403A234A7B83D14B40A911FA997AB94C40
23645	Оса	7	71	1406	55.409264	55.483517999999997	57.294829	57.263398000000002	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
56241	Ольховка	7	71	1406	55.226438000000002	55.241647	57.126275	57.115696	0103000020E610000001000000050000002C499EEBFB9C4B4096236420CF8E4C402C499EEBFB9C4B40B5A679C729904C409816F549EE9E4B40B5A679C729904C409816F549EE9E4B4096236420CF8E4C402C499EEBFB9C4B4096236420CF8E4C40
56323	Новозалесново	7	71	1406	54.977379999999997	55.926099999999998	57.515706999999999	57.053705000000001	0103000020E61000000100000005000000DAE1AFC91A7D4B40DB5031CEDF864C40DAE1AFC91A7D4B40BDA8DDAF02C24C40AD69DE718AF64B40BDA8DDAF02C24C40AD69DE718AF64B40DB5031CEDF864C40DAE1AFC91A7D4B40DB5031CEDF864C40
32603	Нижняя Чермода	7	71	1406	55.630958999999997	55.645583000000002	57.084498000000004	57.068148999999998	0103000020E61000000100000005000000F50EB743C3D04B40A7203F1BB9884C40F50EB743C3D04B40E94999D4D08A4C4042EDB776A2D24B40E94999D4D08A4C4042EDB776A2D24B40A7203F1BB9884C40F50EB743C3D04B40A7203F1BB9884C40
15486	Нефтяников	7	71	1406	55.408023999999997	55.423906000000002	57.260151999999998	57.242730000000002	0103000020E61000000100000005000000D6FD63213AB44B4009E1D1C6119F4C40D6FD63213AB44B4097FE25A94CA14C40024A438D42B64B4097FE25A94CA14C40024A438D42B64B4009E1D1C6119F4C40D6FD63213AB44B4009E1D1C6119F4C40
58178	Мостовая	7	71	1406	55.583176999999999	55.602356	57.205931999999997	57.196233999999997	0103000020E61000000100000005000000C3633F8BA5CA4B407F2E1A321E994C40C3633F8BA5CA4B409599D2FA5B9A4C4052465C001ACD4B409599D2FA5B9A4C4052465C001ACD4B407F2E1A321E994C40C3633F8BA5CA4B407F2E1A321E994C40
32611	Лесной	7	71	1406	55.818804999999998	55.843373999999997	57.257255000000001	57.247225	0103000020E6100000010000000500000090662C9ACEE84B4076E09C11A59F4C4090662C9ACEE84B40C2DD59BBEDA04C40FA25E2ADF3EB4B40C2DD59BBEDA04C40FA25E2ADF3EB4B4076E09C11A59F4C4090662C9ACEE84B4076E09C11A59F4C40
32633	Кузнечиха	7	71	1406	55.601610999999998	55.617905999999998	57.372616999999998	57.363832000000002	0103000020E61000000100000005000000F9F4D89601CD4B40809E060C92AE4C40F9F4D89601CD4B408177F2E9B1AF4C404700378B17CF4B408177F2E9B1AF4C404700378B17CF4B40809E060C92AE4C40F9F4D89601CD4B40809E060C92AE4C40
56309	Крылово	7	71	1406	55.531523999999997	55.562956	57.179552999999999	57.152794	0103000020E6100000010000000500000001857AFA08C44B403483F8C08E934C4001857AFA08C44B400873BB97FB964C40228B34F10EC84B400873BB97FB964C40228B34F10EC84B403483F8C08E934C4001857AFA08C44B403483F8C08E934C40
24773	Горы	7	71	1406	55.558140999999999	55.586680999999999	57.301476000000001	57.289810000000003	0103000020E6100000010000000500000043C70E2A71C74B40E2067C7E18A54C4043C70E2A71C74B40B343FCC396A64C40A017EE5C18CB4B40B343FCC396A64C40A017EE5C18CB4B40E2067C7E18A54C4043C70E2A71C74B40E2067C7E18A54C40
56326	Горки	7	71	1406	55.745916000000001	55.751728	57.275945	57.271988999999998	0103000020E6100000010000000500000015C8EC2C7ADF4B4095EF1989D0A24C4015C8EC2C7ADF4B40533F6F2A52A34C4066BE839F38E04B40533F6F2A52A34C4066BE839F38E04B4095EF1989D0A24C4015C8EC2C7ADF4B4095EF1989D0A24C40
56320	Галицы	7	71	1406	55.510710000000003	55.532224999999997	57.215924999999999	57.205058999999999	0103000020E61000000100000005000000BEDEFDF15EC14B400F60915F3F9A4C40BEDEFDF15EC14B40C4B12E6EA39B4C408A8EE4F21FC44B40C4B12E6EA39B4C408A8EE4F21FC44B400F60915F3F9A4C40BEDEFDF15EC14B400F60915F3F9A4C40
24988	Верхняя Давыдовка	7	71	1406	55.312595999999999	55.335484999999998	57.356569999999998	57.339461	0103000020E61000000100000005000000226E4E2503A84B403CA2427573AB4C40226E4E2503A84B400B5EF415A4AD4C4037A6272CF1AA4B400B5EF415A4AD4C4037A6272CF1AA4B403CA2427573AB4C40226E4E2503A84B403CA2427573AB4C40
33084	Щелканка	7	71	1057	56.548157000000003	56.567982000000001	57.140602000000001	57.134495999999999	0103000020E61000000100000005000000680932022A464C40AEB8382A37914C40680932022A464C4048E00F3FFF914C40BC5B59A2B3484C4048E00F3FFF914C40BC5B59A2B3484C40AEB8382A37914C40680932022A464C40AEB8382A37914C40
22832	Шляпники	7	71	1057	56.973193999999999	56.996371000000003	57.095520999999998	57.078315000000003	0103000020E61000000100000005000000EB54F99E917C4C40A4E4D539068A4C40EB54F99E917C4C40658A39083A8C4C4067D7BD15897F4C40658A39083A8C4C4067D7BD15897F4C40A4E4D539068A4C40EB54F99E917C4C40A4E4D539068A4C40
56287	Терехино	7	71	1057	56.915244000000001	56.928134999999997	57.066454999999998	57.057665	0103000020E610000001000000050000001CEE23B726754C40DA8F149161874C401CEE23B726754C40EDD3F19881884C40F0A2AF20CD764C40EDD3F19881884C40F0A2AF20CD764C40DA8F149161874C401CEE23B726754C40DA8F149161874C40
9878	Орда	7	71	1057	56.882213	56.946531999999998	57.221173	57.181587999999998	0103000020E61000000100000005000000938D075BEC704C404BAC8C463E974C40938D075BEC704C400DE198654F9C4C40094FE8F527794C400DE198654F9C4C40094FE8F527794C404BAC8C463E974C40938D075BEC704C404BAC8C463E974C40
9280	Опачевка	7	71	1057	56.781754999999997	56.805551000000001	57.108848000000002	57.093927000000001	0103000020E61000000100000005000000033E3F8C10644C400F9BC8CC058C4C40033E3F8C10644C40151E34BBEE8D4C404B21904B1C674C40151E34BBEE8D4C404B21904B1C674C400F9BC8CC058C4C40033E3F8C10644C400F9BC8CC058C4C40
9965	Михино	7	71	1057	56.978476999999998	57.029474	56.929226	56.911451	0103000020E61000000100000005000000B071FDBB3E7D4C400874266DAA744C40B071FDBB3E7D4C40E44BA8E0F0764C40890AD5CDC5834C40E44BA8E0F0764C40890AD5CDC5834C400874266DAA744C40B071FDBB3E7D4C400874266DAA744C40
33079	Михайловка	7	71	1057	56.310822000000002	56.332920000000001	57.121808999999999	57.114797000000003	0103000020E610000001000000050000004C70EA03C9274C40E75608ABB18E4C404C70EA03C9274C40E2ADF36F978F4C409817601F9D2A4C40E2ADF36F978F4C409817601F9D2A4C40E75608ABB18E4C404C70EA03C9274C40E75608ABB18E4C40
22970	Мерекай	7	71	1057	56.879356000000001	56.908892999999999	56.937575000000002	56.924627999999998	0103000020E610000001000000050000004CC5C6BC8E704C40A27BD6355A764C404CC5C6BC8E704C400B46257502784C401B48179B56744C400B46257502784C401B48179B56744C40A27BD6355A764C404CC5C6BC8E704C40A27BD6355A764C40
33052	Медянка	7	71	1057	56.943064999999997	56.985833999999997	56.991208999999998	56.958832000000001	0103000020E6100000010000000500000049809A5AB6784C40DC2DC901BB7A4C4049809A5AB6784C401C40BFEFDF7E4C4076A4FACE2F7E4C401C40BFEFDF7E4C4076A4FACE2F7E4C40DC2DC901BB7A4C4049809A5AB6784C40DC2DC901BB7A4C40
23120	Малый Ашап	7	71	1057	56.555990000000001	56.590153000000001	57.089604000000001	57.068775000000002	0103000020E61000000100000005000000977329AE2A474C4026E4839ECD884C40977329AE2A474C409FCBD424788B4C4072512D228A4B4C409FCBD424788B4C4072512D228A4B4C4026E4839ECD884C40977329AE2A474C4026E4839ECD884C40
23384	Красный Ясыл	7	71	1057	56.63355	56.669815	57.098092999999999	57.079695000000001	0103000020E61000000100000005000000BE30992A18514C40CE531D72338A4C40BE30992A18514C40B77BB94F8E8C4C4064AF777FBC554C40B77BB94F8E8C4C4064AF777FBC554C40CE531D72338A4C40BE30992A18514C40CE531D72338A4C40
23354	Карьево	7	71	1057	56.558459999999997	56.580261999999998	57.186197	57.165548999999999	0103000020E61000000100000005000000E40F069E7B474C405871AAB530954C40E40F069E7B474C4081CEA44DD5974C40478E7406464A4C4081CEA44DD5974C40478E7406464A4C405871AAB530954C40E40F069E7B474C405871AAB530954C40
22873	Грызаны	7	71	1057	56.842229000000003	56.865656999999999	57.050102000000003	57.032890000000002	0103000020E61000000100000005000000145FED28CE6B4C40C72E51BD35844C40145FED28CE6B4C406BBB09BE69864C40D8463CD9CD6E4C406BBB09BE69864C40D8463CD9CD6E4C40C72E51BD35844C40145FED28CE6B4C40C72E51BD35844C40
23052	Вторые Ключики	7	71	1057	56.675573999999997	56.706566000000002	57.051071999999998	57.037415000000003	0103000020E610000001000000050000009203763579564C409FB0C403CA844C409203763579564C40E3DEFC8689864C40973B33C1705A4C40E3DEFC8689864C40973B33C1705A4C409FB0C403CA844C409203763579564C409FB0C403CA844C40
23533	Верхний Кунгур	7	71	1057	56.838735	56.863573000000002	57.171014999999997	57.162185999999998	0103000020E610000001000000050000005A8121AB5B6B4C403DEFC682C2944C405A8121AB5B6B4C400E10CCD1E3954C40B45A608F896E4C400E10CCD1E3954C40B45A608F896E4C403DEFC682C2944C405A8121AB5B6B4C403DEFC682C2944C40
23229	Ашап	7	71	1057	56.493979000000003	56.547483	57.127671999999997	57.103437	0103000020E6100000010000000500000095F430B43A3F4C402219726C3D8D4C4095F430B43A3F4C40B54E5C8E57904C40D80E46EC13464C40B54E5C8E57904C40D80E46EC13464C402219726C3D8D4C4095F430B43A3F4C402219726C3D8D4C40
56243	Щучье Озеро	7	71	1510	56.618009999999998	56.679229999999997	56.487040999999998	56.449693000000003	0103000020E61000000100000005000000EC4CA1F31A4F4C40BD1E4C8A8F394C40EC4CA1F31A4F4C40D367075C573E4C40253B3602F1564C40D367075C573E4C40253B3602F1564C40BD1E4C8A8F394C40EC4CA1F31A4F4C40BD1E4C8A8F394C40
56359	Шараповка	7	71	1510	57.036938999999997	57.058489999999999	56.236460999999998	56.225892999999999	0103000020E610000001000000050000003579CA6ABA844C409AB2D30FEA1C4C403579CA6ABA844C40C5E3A25A441E4C404F92AE997C874C40C5E3A25A441E4C404F92AE997C874C409AB2D30FEA1C4C403579CA6ABA844C409AB2D30FEA1C4C40
58111	Усть-Саварово	7	71	1510	57.100836000000001	57.126311999999999	56.228661000000002	56.220723999999997	0103000020E610000001000000050000003621AD31E88C4C409DB81CAF401C4C403621AD31E88C4C40726F7EC3441D4C40D28BDAFD2A904C40726F7EC3441D4C40D28BDAFD2A904C409DB81CAF401C4C403621AD31E88C4C409DB81CAF401C4C40
56366	Уразметьево	7	71	1510	56.694735000000001	56.721451000000002	56.726494000000002	56.703665999999998	0103000020E610000001000000050000007B319413ED584C4050A73CBA115A4C407B319413ED584C40C05E61C1FD5C4C405055A181585C4C40C05E61C1FD5C4C405055A181585C4C4050A73CBA115A4C407B319413ED584C4050A73CBA115A4C40
46049	Тюш	7	71	1510	56.971784	57.021909999999998	56.651245000000003	56.629154	0103000020E610000001000000050000005663096B637C4C40E412471E88504C405663096B637C4C407E5704FF5B534C4049BA66F2CD824C407E5704FF5B534C4049BA66F2CD824C40E412471E88504C405663096B637C4C40E412471E88504C40
22523	Тюинск	7	71	1510	56.572681000000003	56.602451000000002	56.336253999999997	56.317188000000002	0103000020E6100000010000000500000032056B9C4D494C408257CB9D99284C4032056B9C4D494C401893FE5E0A2B4C40A438471D1D4D4C401893FE5E0A2B4C40A438471D1D4D4C408257CB9D99284C4032056B9C4D494C408257CB9D99284C40
21569	Тляково	7	71	1510	57.127426	57.142257000000001	56.246301000000003	56.239272999999997	0103000020E610000001000000050000007E54C37E4F904C406CE8667FA01E4C407E54C37E4F904C406EFC89CA861F4C404450357A35924C406EFC89CA861F4C404450357A35924C406CE8667FA01E4C407E54C37E4F904C406CE8667FA01E4C40
58212	Сосновка	7	71	1510	57.030290999999998	57.046613999999998	56.538936999999997	56.526888999999997	0103000020E610000001000000050000007B2E5393E0834C40A2CF471971434C407B2E5393E0834C405BCD3AE3FB444C4093C49272F7854C405BCD3AE3FB444C4093C49272F7854C40A2CF471971434C407B2E5393E0834C40A2CF471971434C40
21208	Снежное	7	71	1510	57.166763000000003	57.178153999999999	56.505941999999997	56.499464000000003	0103000020E6100000010000000500000068976F7D58954C40C2C3B46FEE3F4C4068976F7D58954C401FD61BB5C2404C4067D311C0CD964C401FD61BB5C2404C4067D311C0CD964C40C2C3B46FEE3F4C4068976F7D58954C40C2C3B46FEE3F4C40
56466	Седяш	7	71	1510	57.068263000000002	57.088430000000002	56.376705000000001	56.358038000000001	0103000020E6100000010000000500000070438CD7BC884C40D55C6E30D42D4C4070438CD7BC884C40AE9E93DE37304C401EFE9AAC518B4C40AE9E93DE37304C401EFE9AAC518B4C40D55C6E30D42D4C4070438CD7BC884C40D55C6E30D42D4C40
21407	Сарс	7	71	1510	57.081099999999999	57.100206999999997	56.473744000000003	56.464381000000003	0103000020E6100000010000000500000051DA1B7C618A4C4020F12BD6703B4C4051DA1B7C618A4C408F56B5A4A33C4C4046EA3D95D38C4C408F56B5A4A33C4C4046EA3D95D38C4C4020F12BD6703B4C4051DA1B7C618A4C4020F12BD6703B4C40
56336	Самарова	7	71	1510	56.725842999999998	56.746046	56.681699999999999	56.668599999999998	0103000020E61000000100000005000000E883656CE85C4C40840D4FAF94554C40E883656CE85C4C4073D712F241574C40E3A7716F7E5F4C4073D712F241574C40E3A7716F7E5F4C40840D4FAF94554C40E883656CE85C4C40840D4FAF94554C40
22594	Русский Сарс	7	71	1510	57.080516000000003	57.108454000000002	56.213850999999998	56.189960999999997	0103000020E61000000100000005000000026729594E8A4C40FA415DA450184C40026729594E8A4C40C39B35785F1B4C40698F17D2E18D4C40C39B35785F1B4C40698F17D2E18D4C40FA415DA450184C40026729594E8A4C40FA415DA450184C40
56428	Редькино	7	71	1510	56.949775000000002	56.968702999999998	56.594785999999999	56.581471999999998	0103000020E610000001000000050000007AC7293A92794C4015C5ABAC6D4A4C407AC7293A92794C40300F99F2214C4C40BF44BC75FE7B4C40300F99F2214C4C40BF44BC75FE7B4C4015C5ABAC6D4A4C407AC7293A92794C4015C5ABAC6D4A4C40
56346	Петропавловск	7	71	1510	57.113565000000001	57.129438	56.343063999999998	56.334792	0103000020E61000000100000005000000317C444C898E4C40317BD976DA2A4C40317C444C898E4C40AC376A85E92B4C40096EA46C91904C40AC376A85E92B4C40096EA46C91904C40317BD976DA2A4C40317C444C898E4C40317BD976DA2A4C40
45764	Октябрьский	7	71	1510	57.177138999999997	57.235916000000003	56.530254999999997	56.490386000000001	0103000020E610000001000000050000004EECA17DAC964C404835ECF7C43E4C404EECA17DAC964C402EC55565DF434C40344DD87E329E4C402EC55565DF434C40344DD87E329E4C404835ECF7C43E4C404EECA17DAC964C404835ECF7C43E4C40
56467	Новопетровка	7	71	1510	56.710168000000003	56.725411999999999	56.350436999999999	56.338194999999999	0103000020E610000001000000050000003755F7C8E65A4C40DA5548F9492B4C403755F7C8E65A4C4078279F1EDB2C4C401F10E84CDA5C4C4078279F1EDB2C4C401F10E84CDA5C4C40DA5548F9492B4C403755F7C8E65A4C40DA5548F9492B4C40
21140	Ненастье	7	71	1510	57.292068999999998	57.325505	56.528517999999998	56.515011999999999	0103000020E610000001000000050000007496598462A54C401686C8E9EB414C407496598462A54C4075AC527AA6434C409DD7D825AAA94C4075AC527AA6434C409DD7D825AAA94C401686C8E9EB414C407496598462A54C401686C8E9EB414C40
21290	Малый Сарс	7	71	1510	57.147117000000001	57.162909999999997	56.429723000000003	56.416629999999998	0103000020E61000000100000005000000C3D7D7BAD4924C402844C02154354C40C3D7D7BAD4924C4065ABCB2901374C407E18213CDA944C4065ABCB2901374C407E18213CDA944C402844C02154354C40C3D7D7BAD4924C402844C02154354C40
21742	Леун	7	71	1510	56.785617000000002	56.811380999999997	56.236215999999999	56.220784000000002	0103000020E6100000010000000500000040170D198F644C4073BD6DA6421C4C4040170D198F644C405E656D533C1E4C4042CC2555DB674C405E656D533C1E4C4042CC2555DB674C4073BD6DA6421C4C4040170D198F644C4073BD6DA6421C4C40
46041	Колтаева	7	71	1510	56.833452999999999	56.861848000000002	56.634822999999997	56.617938000000002	0103000020E6100000010000000500000065E08096AE6A4C40537AA697184F4C4065E08096AE6A4C40D2DF4BE141514C40BF0F0709516E4C40D2DF4BE141514C40BF0F0709516E4C40537AA697184F4C4065E08096AE6A4C40537AA697184F4C40
32660	Ишимово	7	71	1510	56.775995999999999	56.821469	56.67727	56.656495	0103000020E61000000100000005000000D5E940D653634C40677E350708544C40D5E940D653634C40ED478AC8B0564C40C3D66CE525694C40ED478AC8B0564C40C3D66CE525694C40677E350708544C40D5E940D653634C40677E350708544C40
58220	Зуевский	7	71	1510	56.861227999999997	56.877802000000003	56.749471	56.737012	0103000020E61000000100000005000000223317B83C6E4C403961C268565E4C40223317B83C6E4C4074266DAAEE5F4C40842EE1D05B704C4074266DAAEE5F4C40842EE1D05B704C403961C268565E4C40223317B83C6E4C403961C268565E4C40
17649	Енапаево	7	71	1510	56.875008999999999	56.905327	56.596435999999997	56.566428000000002	0103000020E61000000100000005000000535A7F4B00704C40F4C473B680484C40535A7F4B00704C401A14CD03584C4C40C89750C1E1734C401A14CD03584C4C40C89750C1E1734C40F4C473B680484C40535A7F4B00704C40F4C473B680484C40
45915	Верх-Шуртан	7	71	1510	57.282350000000001	57.312012000000003	56.635882000000002	56.618828999999998	0103000020E610000001000000050000004703780B24A44C407F68E6C9354F4C404703780B24A44C40BB0ED59464514C40D3FA5B02F0A74C40BB0ED59464514C40D3FA5B02F0A74C407F68E6C9354F4C404703780B24A44C407F68E6C9354F4C40
22256	Верх-Тюш	7	71	1510	57.091835000000003	57.125700999999999	56.681922999999998	56.672136000000002	0103000020E6100000010000000500000068D0D03FC18B4C406D3B6D8D08564C4068D0D03FC18B4C40F2B1BB4049574C4089096AF816904C40F2B1BB4049574C4089096AF816904C406D3B6D8D08564C4068D0D03FC18B4C406D3B6D8D08564C40
56342	Верх-Ирень	7	71	1510	56.937539999999998	56.96228	56.494216999999999	56.482399000000001	0103000020E610000001000000050000008E588B4F01784C40C24F1C40BF3D4C408E588B4F01784C404910AE80423F4C4025CCB4FD2B7B4C404910AE80423F4C4025CCB4FD2B7B4C40C24F1C40BF3D4C408E588B4F01784C40C24F1C40BF3D4C40
21322	Большой Сарс	7	71	1510	57.105390999999997	57.130947999999997	56.481907	56.466090999999999	0103000020E610000001000000050000007825C9737D8D4C40DFFAB0DEA83B4C407825C9737D8D4C40535BEA20AF3D4C4001BD70E7C2904C40535BEA20AF3D4C4001BD70E7C2904C40DFFAB0DEA83B4C407825C9737D8D4C40DFFAB0DEA83B4C40
21702	Бияваш	7	71	1510	56.947232999999997	56.979661999999998	56.160235	56.134430000000002	0103000020E61000000100000005000000925852EE3E794C40F7CC920035114C40925852EE3E794C4058569A9482144C4025917D90657D4C4058569A9482144C4025917D90657D4C40F7CC920035114C40925852EE3E794C40F7CC920035114C40
21868	Бикбай	7	71	1510	56.710284999999999	56.733856000000003	56.767741999999998	56.758423000000001	0103000020E6100000010000000500000070EB6E9EEA5A4C4061C43E0114614C4070EB6E9EEA5A4C4000E2AE5E45624C4098FC4FFEEE5D4C4000E2AE5E45624C4098FC4FFEEE5D4C4061C43E0114614C4070EB6E9EEA5A4C4061C43E0114614C40
21802	Басино	7	71	1510	56.808658999999999	56.823417999999997	56.763593	56.751035000000002	0103000020E61000000100000005000000DB4E5B2382674C40609335EA21604C40DB4E5B2382674C402E3A596ABD614C400778D2C265694C402E3A596ABD614C400778D2C265694C40609335EA21604C40DB4E5B2382674C40609335EA21604C40
21992	Атнягузи	7	71	1510	56.958705000000002	56.982644999999998	56.556497999999998	56.538505000000001	0103000020E610000001000000050000007FC16ED8B67A4C40C2DD59BBED444C407FC16ED8B67A4C400B2593533B474C40F949B54FC77D4C400B2593533B474C40F949B54FC77D4C40C2DD59BBED444C407FC16ED8B67A4C40C2DD59BBED444C40
22362	Алтынное	7	71	1510	57.105364000000002	57.158228999999999	56.836849000000001	56.811024000000003	0103000020E610000001000000050000007F164B917C8D4C40B4226AA2CF674C407F164B917C8D4C405C5837DE1D6B4C40AF230ED940944C405C5837DE1D6B4C40AF230ED940944C40B4226AA2CF674C407F164B917C8D4C40B4226AA2CF674C40
56429	Алмаз	7	71	1510	56.634107	56.658416000000003	56.432046999999997	56.412700999999998	0103000020E6100000010000000500000014950D6B2A514C406403E962D3344C4014950D6B2A514C40DEAAEB504D374C40E294B9F946544C40DEAAEB504D374C40E294B9F946544C406403E962D3344C4014950D6B2A514C406403E962D3344C40
22248	Адилева	7	71	1510	57.112541	57.141295999999997	56.320287999999998	56.307526000000003	0103000020E61000000100000005000000C53A55BE678E4C40B95510035D274C40C53A55BE678E4C408FA67A32FF284C401E87C1FC15924C408FA67A32FF284C401E87C1FC15924C40B95510035D274C40C53A55BE678E4C40B95510035D274C40
19667	Шерья	7	71	1009	55.186185000000002	55.209352000000003	58.026556999999997	58.010053999999997	0103000020E61000000100000005000000BD00FBE8D4974B40D498107349014D40BD00FBE8D4974B406C3D433866034D4015ADDC0BCC9A4B406C3D433866034D4015ADDC0BCC9A4B40D498107349014D40BD00FBE8D4974B40D498107349014D40
19848	Чекмени	7	71	1009	55.131199000000002	55.148411000000003	57.940444999999997	57.932786	0103000020E610000001000000050000004B22FB20CB904B4055151A8865F74C404B22FB20CB904B40E657738060F84C40EFAEB321FF924B40E657738060F84C40EFAEB321FF924B4055151A8865F74C404B22FB20CB904B4055151A8865F74C40
56215	Чайковская	7	71	1009	55.473852000000001	55.566532000000002	58.140881999999998	58.114663	0103000020E610000001000000050000007592AD2EA7BC4B40D787F546AD0E4D407592AD2EA7BC4B402B4CDF6B08124D409911DE1E84C84B402B4CDF6B08124D409911DE1E84C84B40D787F546AD0E4D407592AD2EA7BC4B40D787F546AD0E4D40
47999	Фролы	7	71	1009	55.170347999999997	55.176743999999999	58.049334999999999	58.042219000000003	0103000020E61000000100000005000000317898F6CD954B408A22A46E67054D40317898F6CD954B402AC6F99B50064D40D2E1218C9F964B402AC6F99B50064D40D2E1218C9F964B408A22A46E67054D40317898F6CD954B408A22A46E67054D40
19422	Уральский	7	71	1009	55.502867999999999	55.574131000000001	57.959105000000001	57.927334000000002	0103000020E610000001000000050000003B1A87FA5DC04B40043C69E1B2F64C403B1A87FA5DC04B400D37E0F3C3FA4C40554FE61F7DC94B400D37E0F3C3FA4C40554FE61F7DC94B40043C69E1B2F64C403B1A87FA5DC04B40043C69E1B2F64C40
56350	Сюзьва	7	71	1009	55.377391000000003	55.395394000000003	58.184303	58.173014000000002	0103000020E61000000100000005000000026729594EB04B4005E09F5225164D40026729594EB04B4000C79E3D97174D406F8445459CB24B4000C79E3D97174D406F8445459CB24B4005E09F5225164D40026729594EB04B4005E09F5225164D40
20419	Постаноги	7	71	1009	55.264527000000001	55.278827999999997	58.306831000000003	58.298569999999998	0103000020E610000001000000050000005AF44E05DCA14B408AC8B08A37264D405AF44E05DCA14B401233FB3C46274D40C39ACAA2B0A34B401233FB3C46274D40C39ACAA2B0A34B408AC8B08A37264D405AF44E05DCA14B408AC8B08A37264D40
56298	Половинка	7	71	1009	55.266494000000002	55.284371	57.897486000000001	57.893003999999998	0103000020E61000000100000005000000454AB3791CA24B403D997FF44DF24C40454AB3791CA24B40164F3DD2E0F24C402577D84466A44B40164F3DD2E0F24C402577D84466A44B403D997FF44DF24C40454AB3791CA24B403D997FF44DF24C40
32683	Покровское	7	71	1009	55.426591999999999	55.444935999999998	58.204984000000003	58.195807000000002	0103000020E610000001000000050000001C5E10919AB64B40F8A92A3410194D401C5E10919AB64B40051A6CEA3C1A4D401268B0A9F3B84B40051A6CEA3C1A4D401268B0A9F3B84B40F8A92A3410194D401C5E10919AB64B40F8A92A3410194D40
8751	Нытва	7	71	1009	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
19308	Новоильинский	7	71	1009	55.459550999999998	55.496301000000003	57.929566000000001	57.885314999999999	0103000020E610000001000000050000000BEC3191D2BA4B4041D47D0052F14C400BEC3191D2BA4B409DBCC804FCF64C406EFC89CA86BF4B409DBCC804FCF64C406EFC89CA86BF4B4041D47D0052F14C400BEC3191D2BA4B4041D47D0052F14C40
19905	Нижняя Гаревая	7	71	1009	55.261913	55.301295000000003	57.943297000000001	57.92351	0103000020E61000000100000005000000D9B27C5D86A14B40B5C35F9335F64C40D9B27C5D86A14B401CB5C2F4BDF84C4063B9A5D590A64B401CB5C2F4BDF84C4063B9A5D590A64B40B5C35F9335F64C40D9B27C5D86A14B40B5C35F9335F64C40
32689	Мокино	7	71	1009	55.193407000000001	55.359972999999997	58.245206000000003	58.107416999999998	0103000020E61000000100000005000000A3E8818FC1984B4068041BD7BF0D4D40A3E8818FC1984B40396403E9621F4D40B438639813AE4B40396403E9621F4D40B438639813AE4B4068041BD7BF0D4D40A3E8818FC1984B4068041BD7BF0D4D40
47047	Майский	7	71	1009	55.563063999999997	55.579692000000001	58.108007000000001	58.096516999999999	0103000020E6100000010000000500000008C72C7B12C84B40074147AB5A0C4D4008C72C7B12C84B409A5E622CD30D4D405DE0F25833CA4B409A5E622CD30D4D405DE0F25833CA4B40074147AB5A0C4D4008C72C7B12C84B40074147AB5A0C4D40
58246	Заполье	7	71	1009	55.394657000000002	55.420617999999997	57.959071999999999	57.949553999999999	0103000020E610000001000000050000009911DE1E84B24B409BE447FC8AF94C409911DE1E84B24B4031410DDFC2FA4C40F10D85CFD6B54B4031410DDFC2FA4C40F10D85CFD6B54B409BE447FC8AF94C409911DE1E84B24B409BE447FC8AF94C40
22033	Деменево	7	71	1009	55.241692	55.252614999999999	58.257651000000003	58.249118000000003	0103000020E6100000010000000500000038DA71C3EF9E4B40276C3F19E31F4D4038DA71C3EF9E4B400F643DB5FA204D4051BD35B055A04B400F643DB5FA204D4051BD35B055A04B40276C3F19E31F4D4038DA71C3EF9E4B40276C3F19E31F4D40
20694	Груни	7	71	1009	55.054645000000001	55.075189000000002	57.881334000000003	57.874949999999998	0103000020E61000000100000005000000E9F17B9BFE864B404ED1915CFEEF4C40E9F17B9BFE864B402B6D718DCFF04C406D020CCB9F894B402B6D718DCFF04C406D020CCB9F894B404ED1915CFEEF4C40E9F17B9BFE864B404ED1915CFEEF4C40
45480	Григорьевское	7	71	1009	55.362290999999999	55.400424000000001	58.231149000000002	58.208730000000003	0103000020E610000001000000050000004C512E8D5FAE4B40D8D825AAB71A4D404C512E8D5FAE4B4066C0594A961D4D404A44F81741B34B4066C0594A961D4D404A44F81741B34B40D8D825AAB71A4D404C512E8D5FAE4B40D8D825AAB71A4D40
56303	Григорьевская	7	71	1009	55.288879999999999	55.347019000000003	58.226055000000002	58.208531000000001	0103000020E61000000100000005000000F73B1405FAA44B40E199D024B11A4D40F73B1405FAA44B40740CC85EEF1C4D409A0B5C1E6BAC4B40740CC85EEF1C4D409A0B5C1E6BAC4B40E199D024B11A4D40F73B1405FAA44B40E199D024B11A4D40
20604	Воробьи	7	71	1009	55.407286999999997	55.445132999999998	58.022734999999997	58.004598999999999	0103000020E61000000100000005000000008BFCFA21B44B40124C35B396004D40008BFCFA21B44B40BEBC00FBE8024D4068AF3E1EFAB84B40BEBC00FBE8024D4068AF3E1EFAB84B40124C35B396004D40008BFCFA21B44B40124C35B396004D40
32632	Белобородово	7	71	1009	55.311608	55.333598000000002	57.972977999999998	57.962198999999998	0103000020E6100000010000000500000003965CC5E2A74B40389F3A5629FB4C4003965CC5E2A74B401EDD088B8AFC4C406901DA56B3AA4B401EDD088B8AFC4C406901DA56B3AA4B40389F3A5629FB4C4003965CC5E2A74B40389F3A5629FB4C40
28365	Шаква	7	71	1530	57.524678999999999	57.546939000000002	57.901899999999998	57.891846000000001	0103000020E61000000100000005000000F1F274AE28C34C40C2887D0228F24C40F1F274AE28C34C4096218E7571F34C4017F4DE1802C64C4096218E7571F34C4017F4DE1802C64C40C2887D0228F24C40F1F274AE28C34C40C2887D0228F24C40
18058	Сова	7	71	1530	57.370258999999997	57.384416000000002	57.891435000000001	57.885148000000001	0103000020E610000001000000050000005B069CA564AF4C40560F98874CF14C405B069CA564AF4C4040C1C58A1AF24C409207228B34B14C4040C1C58A1AF24C409207228B34B14C40560F98874CF14C405B069CA564AF4C40560F98874CF14C40
18635	Рассоленки	7	71	1530	58.617407999999998	58.642228000000003	57.693517	57.681480000000001	0103000020E61000000100000005000000F624B039074F4D40657094BC3AD74C40F624B039074F4D402A1C412AC5D84C40AA49F08634524D402A1C412AC5D84C40AA49F08634524D40657094BC3AD74C40F624B039074F4D40657094BC3AD74C40
56333	Олени	7	71	1530	57.576709999999999	57.590265000000002	58.058179000000003	58.048307000000001	0103000020E6100000010000000500000059A31EA2D1C94C407D957CEC2E064D4059A31EA2D1C94C403128D36872074D409A7CB3CD8DCB4C403128D36872074D409A7CB3CD8DCB4C407D957CEC2E064D4059A31EA2D1C94C407D957CEC2E064D40
56509	Обманка 2-я	7	71	1530	57.946123999999998	57.973000999999996	58.185161999999998	58.172818999999997	0103000020E61000000100000005000000F8FA5A971AF94C404F90D8EE1E164D40F8FA5A971AF94C40213B6F63B3174D40D6FCF84B8BFC4C40213B6F63B3174D40D6FCF84B8BFC4C404F90D8EE1E164D40F8FA5A971AF94C404F90D8EE1E164D40
56332	Новорождественское	7	71	1530	57.46707	57.504098999999997	57.844987000000003	57.822538000000002	0103000020E61000000100000005000000AB7823F3C8BB4C40CFDBD8EC48E94C40AB7823F3C8BB4C40C845B58828EC4C402079E75086C04C40C845B58828EC4C402079E75086C04C40CFDBD8EC48E94C40AB7823F3C8BB4C40CFDBD8EC48E94C40
18241	Невидимка	7	71	1530	57.884903999999999	57.917513	58.009306000000002	57.996834999999997	0103000020E61000000100000005000000BF0CC68844F14C400B410E4A98FF4C40BF0CC68844F14C400BD462F030014D40D253E41071F54C400BD462F030014D40D253E41071F54C400B410E4A98FF4C40BF0CC68844F14C400B410E4A98FF4C40
56315	Липовая 1-я	7	71	1530	57.735180999999997	57.751755000000003	58.098030000000001	58.087421999999997	0103000020E61000000100000005000000FED137691ADE4C40B779E3A4300B4D40FED137691ADE4C4071033E3F8C0C4D4060CD018239E04C4071033E3F8C0C4D4060CD018239E04C40B779E3A4300B4D40FED137691ADE4C40B779E3A4300B4D40
18494	Кын	7	71	1530	58.492344000000003	58.532705999999997	57.805264999999999	57.789287999999999	0103000020E61000000100000005000000E030D120053F4D400890A16307E54C40E030D120053F4D4085CE6BEC12E74C400531D0B52F444D4085CE6BEC12E74C400531D0B52F444D400890A16307E54C40E030D120053F4D400890A16307E54C40
18626	Кын	7	71	1530	58.601795000000003	58.681449000000001	57.886654999999998	57.845422999999997	0103000020E61000000100000005000000BBF2599E074D4D40A22424D236EC4C40BBF2599E074D4D40DDEA39E97DF14C402A7288B839574D40DDEA39E97DF14C402A7288B839574D40A22424D236EC4C40BBF2599E074D4D40A22424D236EC4C40
56376	Кумыш	7	71	1530	58.341768999999999	58.375114000000004	57.869843000000003	57.853865999999996	0103000020E61000000100000005000000B0E42A16BF2B4D404A95287B4BED4C40B0E42A16BF2B4D40C8D3F20357EF4C40C9224DBC03304D40C8D3F20357EF4C40C9224DBC03304D404A95287B4BED4C40B0E42A16BF2B4D404A95287B4BED4C40
18202	Кормовище	7	71	1530	58.007488000000002	58.043869999999998	57.873586000000003	57.847889000000002	0103000020E61000000100000005000000658EE55DF5004D40AFD172A087EC4C40658EE55DF5004D402A1F82AAD1EF4C4044A33B889D054D402A1F82AAD1EF4C4044A33B889D054D40AFD172A087EC4C40658EE55DF5004D40AFD172A087EC4C40
18086	Канабеки	7	71	1530	57.269522000000002	57.283715000000001	57.821091000000003	57.805653	0103000020E61000000100000005000000B9C667B27FA24C404F7633A31FE74C40B9C667B27FA24C401D05888219E94C403C31EBC550A44C401D05888219E94C403C31EBC550A44C404F7633A31FE74C40B9C667B27FA24C404F7633A31FE74C40
56283	Заимка	7	71	1530	57.786403	57.805385000000001	58.144334999999998	58.135266000000001	0103000020E61000000100000005000000F73C7FDAA8E44C406021736550114D40F73C7FDAA8E44C408655BC9179124D4030D80DDB16E74C408655BC9179124D4030D80DDB16E74C406021736550114D40F73C7FDAA8E44C406021736550114D40
46177	Верх-Лысьва	7	71	1530	57.895603000000001	57.916452	57.986201999999999	57.975245000000001	0103000020E6100000010000000500000089997D1EA3F24C40344B02D4D4FC4C4089997D1EA3F24C40F99FFCDD3BFE4C40492D944C4EF54C40F99FFCDD3BFE4C40492D944C4EF54C40344B02D4D4FC4C4089997D1EA3F24C40344B02D4D4FC4C40
56534	Верх-Култым	7	71	1530	57.418382000000001	57.440229000000002	57.786428000000001	57.769368	0103000020E61000000100000005000000179E978A8DB54C40624B8FA67AE24C40179E978A8DB54C40505436ACA9E44C401AE0826C59B84C40505436ACA9E44C401AE0826C59B84C40624B8FA67AE24C40179E978A8DB54C40624B8FA67AE24C40
56282	д.Крохово	7	71	2763	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
27133	Юговское	7	71	1372	56.399782000000002	56.429991999999999	57.296779000000001	57.277754999999999	0103000020E61000000100000005000000C6C37B0E2C334C4076A6D0798DA34C40C6C37B0E2C334C40DE91B1DAFCA54C4054C554FA09374C40DE91B1DAFCA54C4054C554FA09374C4076A6D0798DA34C40C6C37B0E2C334C4076A6D0798DA34C40
58261	Шубино	7	71	1372	56.900503	56.913609000000001	57.367874999999998	57.356423999999997	0103000020E610000001000000050000009679ABAE43734C4037C1374D9FAD4C409679ABAE43734C400C022B8716AF4C40672AC423F1744C400C022B8716AF4C40672AC423F1744C4037C1374D9FAD4C409679ABAE43734C4037C1374D9FAD4C40
26400	Шадейка	7	71	1372	56.773696999999999	56.800583000000003	57.438834	57.428015000000002	0103000020E61000000100000005000000B401D88008634C4046990D32C9B64C40B401D88008634C40BA2F67B62BB84C40E65DF58079664C40BA2F67B62BB84C40E65DF58079664C4046990D32C9B64C40B401D88008634C4046990D32C9B64C40
26644	Чувирята	7	71	1372	56.804662	56.824522999999999	57.576858000000001	57.567669000000002	0103000020E61000000100000005000000BF2A172AFF664C40FDF9B660A9C84C40BF2A172AFF664C40CE37A27BD6C94C4060E63BF889694C40CE37A27BD6C94C4060E63BF889694C40FDF9B660A9C84C40BF2A172AFF664C40FDF9B660A9C84C40
56268	Филипповка	7	71	1372	57.001778999999999	57.062029000000003	57.442506000000002	57.414473999999998	0103000020E61000000100000005000000E868554B3A804C406A85E97B0DB54C40E868554B3A804C4053245F09A4B84C40A933F790F0874C4053245F09A4B84C40A933F790F0874C406A85E97B0DB54C40E868554B3A804C406A85E97B0DB54C40
47671	Уфа	7	71	1372	56.776032000000001	56.791725999999997	57.527341	57.519579	0103000020E6100000010000000500000022533E0455634C401D588E9081C24C4022533E0455634C40836BEEE87FC34C404AB20E4757654C40836BEEE87FC34C404AB20E4757654C401D588E9081C24C4022533E0455634C401D588E9081C24C40
27376	Усть-Турка	7	71	1372	56.576067000000002	56.603205000000003	57.219594000000001	57.210791999999998	0103000020E6100000010000000500000005A73E90BC494C401421753BFB9A4C4005A73E90BC494C40EC32FCA71B9C4C4050E449D2354D4C40EC32FCA71B9C4C4050E449D2354D4C401421753BFB9A4C4005A73E90BC494C401421753BFB9A4C40
26868	Троельга	7	71	1372	56.539326000000003	56.552325000000003	57.469262000000001	57.461207000000002	0103000020E61000000100000005000000F6F065A208454C40D8D7BAD408BB4C40F6F065A208454C40B6A0F7C610BC4C40B1E1E995B2464C40B6A0F7C610BC4C40B1E1E995B2464C40D8D7BAD408BB4C40F6F065A208454C40D8D7BAD408BB4C40
56300	Теплая	7	71	1372	56.789290999999999	56.806080999999999	57.339829999999999	57.328307000000002	0103000020E610000001000000050000007903CC7C07654C402106BAF605AA4C407903CC7C07654C408F19A88C7FAB4C40A77686A92D674C408F19A88C7FAB4C40A77686A92D674C402106BAF605AA4C407903CC7C07654C402106BAF605AA4C40
25605	Серга	7	71	1372	56.873742	56.911211000000002	57.793393999999999	57.766064999999998	0103000020E61000000100000005000000219221C7D66F4C401CCEFC6A0EE24C40219221C7D66F4C40DB6B41EF8DE54C40B360E28FA2744C40DB6B41EF8DE54C40B360E28FA2744C401CCEFC6A0EE24C40219221C7D66F4C401CCEFC6A0EE24C40
27917	Семсовхоз	7	71	1372	56.990586	57.009602999999998	57.307062999999999	57.298276999999999	0103000020E610000001000000050000000FF0A485CB7E4C401213D4F02DA64C400FF0A485CB7E4C40E46723D74DA74C40C478CDAB3A814C40E46723D74DA74C40C478CDAB3A814C401213D4F02DA64C400FF0A485CB7E4C401213D4F02DA64C40
58693	Садоягодное	7	71	1372	56.948185000000002	56.971280999999998	57.354671000000003	57.33934	0103000020E6100000010000000500000065C746205E794C40C11C3D7E6FAB4C4065C746205E794C4079EBFCDB65AD4C40F31C91EF527C4C4079EBFCDB65AD4C40F31C91EF527C4C40C11C3D7E6FAB4C4065C746205E794C40C11C3D7E6FAB4C40
52933	Пустынники	7	71	1372	56.957169	56.969332000000001	57.777182000000003	57.771580999999998	0103000020E610000001000000050000005DDF8783847A4C40849B8C2AC3E24C405DDF8783847A4C401B8524B37AE34C40AF7B2B12137C4C401B8524B37AE34C40AF7B2B12137C4C40849B8C2AC3E24C405DDF8783847A4C40849B8C2AC3E24C40
47535	Поповка	7	71	1372	56.876652999999997	56.888986000000003	57.432259999999999	57.424748999999998	0103000020E610000001000000050000005B785E2A36704C401D01DC2C5EB64C405B785E2A36704C403AAFB14B54B74C400A4D124BCA714C403AAFB14B54B74C400A4D124BCA714C401D01DC2C5EB64C405B785E2A36704C401D01DC2C5EB64C40
51951	Подъельничная	7	71	1372	56.163085000000002	56.184275999999997	57.207746	57.203431000000002	0103000020E61000000100000005000000EDBB22F8DF144C400DFFE9060A9A4C40EDBB22F8DF144C40FAEFC16B979A4C4006B8205B96174C40FAEFC16B979A4C4006B8205B96174C400DFFE9060A9A4C40EDBB22F8DF144C400DFFE9060A9A4C40
26709	Подъельник	7	71	1372	56.754913000000002	56.781745999999998	57.607716000000003	57.600270000000002	0103000020E61000000100000005000000A2293BFDA0604C408D62B9A5D5CC4C40A2293BFDA0604C40C3A04CA3C9CD4C40B0E3BF4010644C40C3A04CA3C9CD4C40B0E3BF4010644C408D62B9A5D5CC4C40A2293BFDA0604C408D62B9A5D5CC4C40
25601	Насадка	7	71	1372	56.768935999999997	56.798679	57.877516	57.867277000000001	0103000020E61000000100000005000000C85BAE7E6C624C4058C9C7EE02EF4C40C85BAE7E6C624C40BEDBBC7152F04C4041800C1D3B664C40BEDBBC7152F04C4041800C1D3B664C4058C9C7EE02EF4C40C85BAE7E6C624C4058C9C7EE02EF4C40
47497	Моховое	7	71	1372	56.840684000000003	56.857123000000001	57.61824	57.612893999999997	0103000020E610000001000000050000009F2287889B6B4C4012F5824F73CE4C409F2287889B6B4C401E8A027D22CF4C4020D3DA34B66D4C401E8A027D22CF4C4020D3DA34B66D4C4012F5824F73CE4C409F2287889B6B4C4012F5824F73CE4C40
48101	Мериново	7	71	1372	56.924883000000001	56.936138999999997	57.423858000000003	57.415342000000003	0103000020E610000001000000050000002DD0EE9062764C40DF5339ED29B54C402DD0EE9062764C40F1129CFA40B64C404CC11A67D3774C40F1129CFA40B64C404CC11A67D3774C40DF5339ED29B54C402DD0EE9062764C40DF5339ED29B54C40
27104	Мазунино	7	71	1372	56.494607999999999	56.528466000000002	57.324278999999997	57.302916000000003	0103000020E61000000100000005000000842BA0504F3F4C40B3B794F3C5A64C40842BA0504F3F4C40C9E369F981A94C4023861DC6A4434C40C9E369F981A94C4023861DC6A4434C40B3B794F3C5A64C40842BA0504F3F4C40B3B794F3C5A64C40
56321	Липово	7	71	1372	56.849271999999999	56.869222999999998	57.463265	57.454991	0103000020E610000001000000050000004AB4E4F1B46C4C40B77C24253DBA4C404AB4E4F1B46C4C40D3307C444CBB4C402BF702B3426F4C40D3307C444CBB4C402BF702B3426F4C40B77C24253DBA4C404AB4E4F1B46C4C40B77C24253DBA4C40
27463	Ленск	7	71	1372	56.645865999999998	56.682042000000003	57.312026000000003	57.290841	0103000020E6100000010000000500000096CCB1BCAB524C4000AB23473AA54C4096CCB1BCAB524C4038C0CC77F0A74C40CD3FFA264D574C4038C0CC77F0A74C40CD3FFA264D574C4000AB23473AA54C4096CCB1BCAB524C4000AB23473AA54C40
47730	Кужлево	7	71	1372	56.526355000000002	56.543044999999999	57.51634	57.508262000000002	0103000020E61000000100000005000000058BC3995F434C4058E6ADBA0EC14C40058BC3995F434C40EECEDA6D17C24C40CFA0A17F82454C40EECEDA6D17C24C40CFA0A17F82454C4058E6ADBA0EC14C40058BC3995F434C4058E6ADBA0EC14C40
25837	Кинделино	7	71	1372	56.816816000000003	56.850681999999999	57.654735000000002	57.635531	0103000020E61000000100000005000000BE6C3B6D8D684C400E4C6E1459D14C40BE6C3B6D8D684C40F645425BCED34C40DFA5D425E36C4C40F645425BCED34C40DFA5D425E36C4C400E4C6E1459D14C40BE6C3B6D8D684C400E4C6E1459D14C40
25901	Каширино	7	71	1372	56.841771000000001	56.859350999999997	57.553600000000003	57.539845	0103000020E6100000010000000500000051DCF126BF6B4C405EF415A419C54C4051DCF126BF6B4C406688635DDCC64C407764AC36FF6D4C406688635DDCC64C407764AC36FF6D4C405EF415A419C54C4051DCF126BF6B4C405EF415A419C54C40
32722	Калинино	7	71	1372	56.310543000000003	56.356788999999999	57.344216000000003	57.316871999999996	0103000020E6100000010000000500000039807EDFBF274C405182FE428FA84C4039807EDFBF274C40466117450FAC4C4049490F43AB2D4C40466117450FAC4C4049490F43AB2D4C405182FE428FA84C4039807EDFBF274C405182FE428FA84C40
26517	Казаево	7	71	1372	56.668432000000003	56.704787000000003	57.502571000000003	57.491495999999998	0103000020E61000000100000005000000C9CC052E8F554C40B20E4757E9BE4C40C9CC052E8F554C4082751C3F54C04C40AFD2DD75365A4C4082751C3F54C04C40AFD2DD75365A4C40B20E4757E9BE4C40C9CC052E8F554C40B20E4757E9BE4C40
47135	Ильича	7	71	1372	56.796945000000001	56.833011999999997	57.959921999999999	57.941009000000001	0103000020E61000000100000005000000F9DA334B02664C40EF1EA0FB72F84C40F9DA334B02664C40FF5A5EB9DEFA4C4078962023A06A4C40FF5A5EB9DEFA4C4078962023A06A4C40EF1EA0FB72F84C40F9DA334B02664C40EF1EA0FB72F84C40
25853	Зарубино	7	71	1372	56.943379	56.970787000000001	57.581311999999997	57.573180999999998	0103000020E61000000100000005000000D95DA0A4C0784C4023D8B8FE5DC94C40D95DA0A4C0784C40DC627E6E68CA4C40E43098BF427C4C40DC627E6E68CA4C40E43098BF427C4C4023D8B8FE5DC94C40D95DA0A4C0784C4023D8B8FE5DC94C40
47563	Жилино	7	71	1372	56.767004	56.813043	57.476730000000003	57.465743000000003	0103000020E610000001000000050000005AF3E32F2D624C40A4AB74779DBB4C405AF3E32F2D624C40D482177D05BD4C40F19E03CB11684C40D482177D05BD4C40F19E03CB11684C40A4AB74779DBB4C405AF3E32F2D624C40A4AB74779DBB4C40
56276	Ерзовка	7	71	1372	57.128289000000002	57.134971999999998	57.514744999999998	57.511158000000002	0103000020E61000000100000005000000E1B721C66B904C405D8B16A06DC14C40E1B721C66B904C40C763062AE3C14C4017F032C346914C40C763062AE3C14C4017F032C346914C405D8B16A06DC14C40E1B721C66B904C405D8B16A06DC14C40
56334	Ергач	7	71	1372	56.604104	56.625106000000002	57.510548999999997	57.503000999999998	0103000020E61000000100000005000000FFB0A547534D4C407A6D365662C04C40FFB0A547534D4C40B4006DAB59C14C404644317903504C40B4006DAB59C14C404644317903504C407A6D365662C04C40FFB0A547534D4C407A6D365662C04C40
26483	Ергач	7	71	1372	56.699226000000003	56.735427999999999	57.496594000000002	57.480072999999997	0103000020E61000000100000005000000A741D13C80594C40A758350873BD4C40A741D13C80594C40E6B1666490BF4C4006483481225E4C40E6B1666490BF4C4006483481225E4C40A758350873BD4C40A741D13C80594C40A758350873BD4C40
58199	Дейково	7	71	1372	56.866151000000002	56.884853999999997	57.486682000000002	57.473100000000002	0103000020E61000000100000005000000E8323509DE6E4C406ADE718A8EBC4C40E8323509DE6E4C40A4C684984BBE4C400DDE57E542714C40A4C684984BBE4C400DDE57E542714C406ADE718A8EBC4C40E8323509DE6E4C406ADE718A8EBC4C40
23675	Гробово	7	71	1372	57.107295000000001	57.120949000000003	57.515756000000003	57.507890000000003	0103000020E610000001000000050000001D03B2D7BB8D4C4094FB1D8A02C14C401D03B2D7BB8D4C409F5BE84A04C24C40F1BDBF417B8F4C409F5BE84A04C24C40F1BDBF417B8F4C4094FB1D8A02C14C401D03B2D7BB8D4C4094FB1D8A02C14C40
58268	Голубята	7	71	1372	56.747807000000002	56.757123	57.493299999999998	57.489870000000003	0103000020E61000000100000005000000255CC823B85F4C4051A5660FB4BE4C40255CC823B85F4C40F38E537424BF4C4053060E68E9604C40F38E537424BF4C4053060E68E9604C4051A5660FB4BE4C40255CC823B85F4C4051A5660FB4BE4C40
27966	Голдыревский	7	71	1372	57.028027999999999	57.055183999999997	57.269502000000003	57.256754000000001	0103000020E61000000100000005000000A7AFE76B96834C40008FA850DDA04C40A7AFE76B96834C40721AA20A7FA24C4098A1F14410874C40721AA20A7FA24C4098A1F14410874C40008FA850DDA04C40A7AFE76B96834C40008FA850DDA04C40
27526	Веслянка	7	71	1372	56.681637000000002	56.69858	57.299594999999997	57.285947	0103000020E610000001000000050000002D5F97E13F574C40D5B14AE999A44C402D5F97E13F574C40C685032159A64C40E1D1C6116B594C40C685032159A64C40E1D1C6116B594C40D5B14AE999A44C402D5F97E13F574C40D5B14AE999A44C40
27618	Бымок	7	71	1372	56.605235999999998	56.628691000000003	57.399037	57.381613000000002	0103000020E61000000100000005000000512E8D5F784D4C403E5DDDB1D8B04C40512E8D5F784D4C406D72F8A413B34C4010255AF278504C406D72F8A413B34C4010255AF278504C403E5DDDB1D8B04C40512E8D5F784D4C403E5DDDB1D8B04C40
26976	Бым	7	71	1372	56.294877	56.359456999999999	57.447417000000002	57.420110999999999	0103000020E61000000100000005000000DAAB8F87BE254C404DD87E32C6B54C40DAAB8F87BE254C405456D3F544B94C40BDA8DDAF022E4C405456D3F544B94C40BDA8DDAF022E4C404DD87E32C6B54C40DAAB8F87BE254C404DD87E32C6B54C40
56490	Ботово	7	71	1372	56.631977999999997	56.650725999999999	57.585954000000001	57.565294000000002	0103000020E610000001000000050000004FE5B4A7E4504C400150C58D5BC84C404FE5B4A7E4504C40EE7A698A00CB4C40155454FD4A534C40EE7A698A00CB4C40155454FD4A534C400150C58D5BC84C404FE5B4A7E4504C400150C58D5BC84C40
56289	Богородск	7	71	1372	56.293331999999999	56.324736999999999	57.531979999999997	57.514243	0103000020E61000000100000005000000656F29E78B254C403599F1B6D2C14C40656F29E78B254C402310AFEB17C44C408C6665FB90294C402310AFEB17C44C408C6665FB90294C403599F1B6D2C14C40656F29E78B254C403599F1B6D2C14C40
56382	Блины	7	71	1372	56.465736	56.494114000000003	57.397281	57.380040999999999	0103000020E61000000100000005000000F148BC3C9D3B4C40CF11F92EA5B04C40F148BC3C9D3B4C403D29931ADAB24C40753FA7203F3F4C403D29931ADAB24C40753FA7203F3F4C40CF11F92EA5B04C40F148BC3C9D3B4C40CF11F92EA5B04C40
47467	Беркутово	7	71	1372	57.005884000000002	57.036005000000003	57.428175000000003	57.418681999999997	0103000020E61000000100000005000000EBC891CEC0804C4041B62C5F97B54C40EBC891CEC0804C407FFB3A70CEB64C400ABFD4CF9B844C407FFB3A70CEB64C400ABFD4CF9B844C4041B62C5F97B54C40EBC891CEC0804C4041B62C5F97B54C40
48933	Березовка	7	71	1372	56.048980999999998	56.062688999999999	57.196984999999998	57.186373000000003	0103000020E610000001000000050000000C90680245064C40C0ED0912DB974C400C90680245064C40BA66F2CD36994C40D368723106084C40BA66F2CD36994C40D368723106084C40C0ED0912DB974C400C90680245064C40C0ED0912DB974C40
27409	Бажуки	7	71	1372	56.484375999999997	56.514479000000001	57.196804999999998	57.184230999999997	0103000020E61000000100000005000000D07B6308003E4C4066F4A3E194974C40D07B6308003E4C403A58FFE730994C4049BDA772DA414C403A58FFE730994C4049BDA772DA414C4066F4A3E194974C40D07B6308003E4C4066F4A3E194974C40
56274	Бабка	7	71	1372	55.977043999999999	55.980708999999997	57.292718000000001	57.290914000000001	0103000020E6100000010000000500000063601DC70FFD4B406AF981AB3CA54C4063601DC70FFD4B40AB798EC877A54C4049F25CDF87FD4B40AB798EC877A54C4049F25CDF87FD4B406AF981AB3CA54C4063601DC70FFD4B406AF981AB3CA54C40
56240	Кунгур	7	71	7404	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
13907	Федоровск	7	71	1074	55.571652	55.592475	56.559255999999998	56.546331000000002	0103000020E61000000100000005000000B4588AE42BC94B403FE5982CEE454C40B4588AE42BC94B40BF0B5BB395474C404B598638D6CB4B40BF0B5BB395474C404B598638D6CB4B403FE5982CEE454C40B4588AE42BC94B403FE5982CEE454C40
13571	Урталга	7	71	1074	55.483302999999999	55.512138999999998	56.423316	56.412547000000004	0103000020E61000000100000005000000838769DFDCBD4B400E881057CE344C40838769DFDCBD4B40D0EFFB372F364C40C90050C58DC14B40D0EFFB372F364C40C90050C58DC14B400E881057CE344C40838769DFDCBD4B400E881057CE344C40
14649	Урада	7	71	1074	54.860751999999998	54.878340999999999	56.425412000000001	56.403855999999998	0103000020E61000000100000005000000B9FB1C1F2D6E4B408D25AC8DB1334C40B9FB1C1F2D6E4B40B9A981E673364C4033DE567A6D704B40B9A981E673364C4033DE567A6D704B408D25AC8DB1334C40B9FB1C1F2D6E4B408D25AC8DB1334C40
14617	Узяр	7	71	1074	54.756475999999999	54.801023000000001	56.506126000000002	56.480902	0103000020E61000000100000005000000BD1AA034D4604B405E4A5D328E3D4C40BD1AA034D4604B40E1D39CBCC8404C40022CF2EB87664B40E1D39CBCC8404C40022CF2EB87664B405E4A5D328E3D4C40BD1AA034D4604B405E4A5D328E3D4C40
13522	Трегубовка	7	71	1074	55.593221	55.608806000000001	56.459212999999998	56.451124999999998	0103000020E6100000010000000500000074266DAAEECB4B4039B4C876BE394C4074266DAAEECB4B40F372D87DC73A4C40E6CDE15AEDCD4B40F372D87DC73A4C40E6CDE15AEDCD4B4039B4C876BE394C4074266DAAEECB4B4039B4C876BE394C40
14225	Старый Шагирт	7	71	1074	55.179834	55.218946000000003	56.466410000000003	56.438173999999997	0103000020E61000000100000005000000BC5AEECC04974B408FFAEB1516384C40BC5AEECC04974B408143A852B33B4C4086CB2A6C069C4B408143A852B33B4C4086CB2A6C069C4B408FFAEB1516384C40BC5AEECC04974B408FFAEB1516384C40
13833	Русские Чикаши	7	71	1074	55.794640999999999	55.825426	56.458362999999999	56.443593	0103000020E61000000100000005000000C687D9CBB6E54B4005DEC9A7C7384C40C687D9CBB6E54B40255987A3AB3A4C4051A2258FA7E94B40255987A3AB3A4C4051A2258FA7E94B4005DEC9A7C7384C40C687D9CBB6E54B4005DEC9A7C7384C40
14147	Рабак	7	71	1074	55.245303	55.264068999999999	56.350172999999998	56.346736	0103000020E610000001000000050000002B4EB516669F4B40452C62D8612C4C402B4EB516669F4B409A780778D22C4C4097715303CDA14B409A780778D22C4C4097715303CDA14B40452C62D8612C4C402B4EB516669F4B40452C62D8612C4C40
56337	Покровка	7	71	1074	55.623548	55.631013000000003	56.512171000000002	56.500855000000001	0103000020E610000001000000050000003CBEBD6BD0CF4B40E08442041C404C403CBEBD6BD0CF4B40D57ABFD18E414C40E92CB308C5D04B40D57ABFD18E414C40E92CB308C5D04B40E08442041C404C403CBEBD6BD0CF4B40E08442041C404C40
14768	Пантелеевка	7	71	1074	54.861308999999999	54.883541999999998	56.614817000000002	56.598151000000001	0103000020E610000001000000050000000F60915F3F6E4B40EC884336904C4C400F60915F3F6E4B402E03CE52B24E4C403B527DE717714B402E03CE52B24E4C403B527DE717714B40EC884336904C4C400F60915F3F6E4B40EC884336904C4C40
14567	Ошья	7	71	1074	54.860787999999999	54.891123999999998	56.519748999999997	56.488754999999998	0103000020E6100000010000000500000006651A4D2E6E4B40D4601A868F3E4C4006651A4D2E6E4B4079909E2287424C402157EA5910724B4079909E2287424C402157EA5910724B40D4601A868F3E4C4006651A4D2E6E4B40D4601A868F3E4C40
13226	Куеда	7	71	1074	55.540004000000003	55.614249999999998	56.447533	56.4129	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
32579	Кирга	7	71	1074	55.155929999999998	55.179662999999998	56.362845	56.344391000000002	0103000020E610000001000000050000008E3BA583F5934B40B4041901152C4C408E3BA583F5934B40314278B4712E4C408FA67A32FF964B40314278B4712E4C408FA67A32FF964B40B4041901152C4C408E3BA583F5934B40B4041901152C4C40
32564	Кипчак	7	71	1074	55.407888999999997	55.434102000000003	56.393847999999998	56.383597999999999	0103000020E61000000100000005000000F6B2EDB435B44B40CF6740BD19314C40F6B2EDB435B44B4029CC7B9C69324C40699082A790B74B4029CC7B9C69324C40699082A790B74B40CF6740BD19314C40F6B2EDB435B44B40CF6740BD19314C40
47663	Кама	7	71	1074	55.000197999999997	55.017059000000003	56.470835000000001	56.464858	0103000020E6100000010000000500000026C3F17C06804B4059A48977803B4C4026C3F17C06804B40F5673F52443C4C401E8D43FD2E824B40F5673F52443C4C401E8D43FD2E824B4059A48977803B4C4026C3F17C06804B4059A48977803B4C40
13757	Искильда	7	71	1074	55.647030000000001	55.663936	56.538356	56.533135000000001	0103000020E61000000100000005000000F4C308E1D1D24B402EAD86C43D444C40F4C308E1D1D24B407DCD72D9E8444C408B51D7DAFBD44B407DCD72D9E8444C408B51D7DAFBD44B402EAD86C43D444C40F4C308E1D1D24B402EAD86C43D444C40
56353	Змеевка	7	71	1074	54.778835000000001	54.803151999999997	56.453817000000001	56.446787	0103000020E6100000010000000500000076FD82DDB0634B4094A3005130394C4076FD82DDB0634B4036AFEAAC163A4C40C6DB4AAFCD664B4036AFEAAC163A4C40C6DB4AAFCD664B4094A3005130394C4076FD82DDB0634B4094A3005130394C40
13924	Земплягаш	7	71	1074	55.334766000000002	55.374265000000001	56.675404999999998	56.659370000000003	0103000020E6100000010000000500000008E8BE9CD9AA4B4055FB743C66544C4008E8BE9CD9AA4B400647C9AB73564C40CB845FEAE7AF4B400647C9AB73564C40CB845FEAE7AF4B4055FB743C66544C4008E8BE9CD9AA4B4055FB743C66544C40
14515	Дойная	7	71	1074	54.999515000000002	55.044286999999997	56.689185000000002	56.659365000000001	0103000020E61000000100000005000000446E861BF07F4B404390831266544C40446E861BF07F4B4067F2CD3637584C40A8514832AB854B4067F2CD3637584C40A8514832AB854B404390831266544C40446E861BF07F4B404390831266544C40
56318	Госконезавод 3	7	71	1074	55.072781999999997	55.106648	56.372337999999999	56.353819000000001	0103000020E6100000010000000500000065DEAAEB50894B400ADAE4F0492D4C4065DEAAEB50894B406E8786C5A82F4C40871744A4A68D4B406E8786C5A82F4C40871744A4A68D4B400ADAE4F0492D4C4065DEAAEB50894B400ADAE4F0492D4C40
14292	Гожан	7	71	1074	55.183633999999998	55.211615999999999	56.532483999999997	56.518652000000003	0103000020E610000001000000050000008237A45181974B40A400513063424C408237A45181974B4056D28A6F28444C40B9A7AB3B169B4B4056D28A6F28444C40B9A7AB3B169B4B40A400513063424C408237A45181974B40A400513063424C40
58293	Верхняя Уса	7	71	1074	55.178477000000001	55.196542000000001	56.691054000000001	56.672586000000003	0103000020E610000001000000050000004A0B9755D8964B40ADDF4C4C17564C404A0B9755D8964B408FE21C7574584C402D25CB4928994B408FE21C7574584C402D25CB4928994B40ADDF4C4C17564C404A0B9755D8964B40ADDF4C4C17564C40
14376	Верхняя Сава	7	71	1074	55.076546	55.111866999999997	56.463405999999999	56.444935999999998	0103000020E61000000100000005000000DF516342CC894B401268B0A9F3384C40DF516342CC894B40956247E3503B4C40354069A8518E4B40956247E3503B4C40354069A8518E4B401268B0A9F3384C40DF516342CC894B401268B0A9F3384C40
13624	Большой Талмаз	7	71	1074	55.341090000000001	55.377471999999997	56.572136	56.550375000000003	0103000020E610000001000000050000000F7F4DD6A8AB4B409CC420B072464C400F7F4DD6A8AB4B40A06EA0C03B494C40EE93A30051B04B40A06EA0C03B494C40EE93A30051B04B409CC420B072464C400F7F4DD6A8AB4B409CC420B072464C40
33136	Большой Каскасал	7	71	1074	55.439706999999999	55.474454000000001	56.532152000000004	56.515081000000002	0103000020E610000001000000050000004069A85148B84B403FE5982CEE414C404069A85148B84B402140868E1D444C406BBA9EE8BABC4B402140868E1D444C406BBA9EE8BABC4B403FE5982CEE414C404069A85148B84B403FE5982CEE414C40
14017	Большой Гондыр	7	71	1074	55.310467000000003	55.339303000000001	56.382221999999999	56.368209999999998	0103000020E610000001000000050000005EBEF561BDA74B40B3075A81212F4C405EBEF561BDA74B40E6E786A6EC304C40A437DC476EAB4B40E6E786A6EC304C40A437DC476EAB4B40B3075A81212F4C405EBEF561BDA74B40B3075A81212F4C40
14700	Большие Кусты	7	71	1074	54.999631999999998	55.039382000000003	56.614485000000002	56.575617000000001	0103000020E610000001000000050000007D04FEF0F37F4B40C5025FD1AD494C407D04FEF0F37F4B40F870C971A74E4C408A0629780A854B40F870C971A74E4C408A0629780A854B40C5025FD1AD494C407D04FEF0F37F4B40C5025FD1AD494C40
14430	Большая Уса	7	71	1074	55.068227	55.138286999999998	56.759168000000003	56.720731000000001	0103000020E6100000010000000500000023DA8EA9BB884B40501BD5E9405C4C4023DA8EA9BB884B40BA15C26A2C614C40213B6F63B3914B40BA15C26A2C614C40213B6F63B3914B40501BD5E9405C4C4023DA8EA9BB884B40501BD5E9405C4C40
13785	Бикбарда	7	71	1074	55.706856999999999	55.739663999999998	56.485956999999999	56.471088999999999	0103000020E610000001000000050000006EF9484A7ADA4B40AF40F4A44C3C4C406EF9484A7ADA4B409221C7D6333E4C40A703594FADDE4B409221C7D6333E4C40A703594FADDE4B40AF40F4A44C3C4C406EF9484A7ADA4B40AF40F4A44C3C4C40
13699	Аряж	7	71	1074	55.572865	55.618023000000001	56.504814000000003	56.493650000000002	0103000020E61000000100000005000000F302ECA353C94B40D0D556EC2F3F4C40F302ECA353C94B400F48C2BE9D404C408196AE601BCF4B400F48C2BE9D404C408196AE601BCF4B40D0D556EC2F3F4C40F302ECA353C94B40D0D556EC2F3F4C40
2264	Эрна	7	71	96	55.361086999999998	55.3782	59.357512	59.345309	0103000020E6100000010000000500000060014C1938AE4B40DA01D71533AC4D4060014C1938AE4B40BAF605F4C2AD4D4071AC8BDB68B04B40BAF605F4C2AD4D4071AC8BDB68B04B40DA01D71533AC4D4060014C1938AE4B40DA01D71533AC4D40
45549	Шадрина	7	71	96	54.362430000000003	54.399476	59.138496000000004	59.129899000000002	0103000020E610000001000000050000006E8B321B642E4B403D64CA87A0904D406E8B321B642E4B403C50A73CBA914D40B9C4910722334B403C50A73CBA914D40B9C4910722334B403D64CA87A0904D406E8B321B642E4B403D64CA87A0904D40
473	Тебенькова	7	71	96	54.224440000000001	54.241840000000003	59.108472999999996	59.097876999999997	0103000020E6100000010000000500000006F52D73BA1C4B40EA03C93B878C4D4006F52D73BA1C4B40DFBF7971E28D4D40AD6EF59CF41E4B40DFBF7971E28D4D40AD6EF59CF41E4B40EA03C93B878C4D4006F52D73BA1C4B40EA03C93B878C4D40
56532	Сюзь-Позья	7	71	96	54.846792000000001	54.874667000000002	59.196812999999999	59.181727000000002	0103000020E61000000100000005000000D94125AE636C4B406DE690D442974D40D94125AE636C4B40BD361B2B31994D40FAF19716F56F4B40BD361B2B31994D40FAF19716F56F4B406DE690D442974D40D94125AE636C4B406DE690D442974D40
1668	Сылвож	7	71	96	54.743386999999998	54.762405000000001	58.768819000000001	58.763621000000001	0103000020E61000000100000005000000C2A2224E275F4B40F8C43A55BE614D40C2A2224E275F4B408FC536A968624D4048A7AE7C96614B408FC536A968624D4048A7AE7C96614B40F8C43A55BE614D40C2A2224E275F4B40F8C43A55BE614D40
46297	Степанова	7	71	96	54.678474999999999	54.728520000000003	58.990735000000001	58.974165999999997	0103000020E61000000100000005000000A913D044D8564B400470B378B17C4D40A913D044D8564B4054008C67D07E4D40B03DB324405D4B4054008C67D07E4D40B03DB324405D4B400470B378B17C4D40A913D044D8564B400470B378B17C4D40
58307	Старая Кузьва	7	71	96	54.285497999999997	54.297669999999997	59.049712	59.045231999999999	0103000020E610000001000000050000006589CE328B244B40C85D8429CA854D406589CE328B244B40001C7BF65C864D400A80F10C1A264B40001C7BF65C864D400A80F10C1A264B40C85D8429CA854D406589CE328B244B40C85D8429CA854D40
903	Самково	7	71	96	54.062930999999999	54.094794999999998	58.943859000000003	58.930579000000002	0103000020E61000000100000005000000C9737D1F0E084B4015AC71361D774D40C9737D1F0E084B408484285FD0784D408369183E220C4B408484285FD0784D408369183E220C4B4015AC71361D774D40C9737D1F0E084B4015AC71361D774D40
1778	Ракшина	7	71	96	54.686703999999999	54.707121999999998	58.672634000000002	58.659875999999997	0103000020E610000001000000050000002504ABEAE5574B4028B517D176544D402504ABEAE5574B40BE16F4DE18564D401C2444F9825A4B40BE16F4DE18564D401C2444F9825A4B4028B517D176544D402504ABEAE5574B4028B517D176544D40
58342	Разина	7	71	96	54.455368999999997	54.476004000000003	58.898578999999998	58.890321999999998	0103000020E610000001000000050000005D4E0988493A4B4064744012F6714D405D4E0988493A4B40AAEFFCA204734D40F261F6B2ED3C4B40AAEFFCA204734D40F261F6B2ED3C4B4064744012F6714D405D4E0988493A4B4064744012F6714D40
46055	Пятина	7	71	96	54.798104000000002	54.810994999999998	58.737051999999998	58.732875999999997	0103000020E610000001000000050000004567994528664B40FB027AE1CE5D4D404567994528664B40C7B94DB8575E4D40191C25AFCE674B40C7B94DB8575E4D40191C25AFCE674B40FB027AE1CE5D4D404567994528664B40FB027AE1CE5D4D40
1316	Поносова	7	71	96	54.905254999999997	54.920921	59.078164000000001	59.074745999999998	0103000020E610000001000000050000002EC55565DF734B40DFC0E44691894D402EC55565DF734B40BEDC2747018A4D408D9944BDE0754B40BEDC2747018A4D408D9944BDE0754B40DFC0E44691894D402EC55565DF734B40DFC0E44691894D40
1811	Полва	7	71	96	54.440161000000003	54.469455000000004	58.677433999999998	58.656880000000001	0103000020E61000000100000005000000C2FC153257384B40C0B2D2A414544D40C2FC153257384B4067994528B6564D40CBF8F719173C4B4067994528B6564D40CBF8F719173C4B40C0B2D2A414544D40C2FC153257384B40C0B2D2A414544D40
2381	Пешнигорт	7	71	96	54.557794999999999	54.586649000000001	58.9754	58.957087999999999	0103000020E61000000100000005000000A86F99D365474B4070B20DDC817A4D40A86F99D365474B405B423EE8D97C4D40959D7E50174B4B405B423EE8D97C4D40959D7E50174B4B4070B20DDC817A4D40A86F99D365474B4070B20DDC817A4D40
58279	Петухово	7	71	96	54.789434999999997	54.798436000000002	58.859102999999998	58.857432000000003	0103000020E61000000100000005000000ACA8C1340C654B409E45EF54C06D4D40ACA8C1340C654B409F724C16F76D4D407BF99D2633664B409F724C16F76D4D407BF99D2633664B409E45EF54C06D4D40ACA8C1340C654B409E45EF54C06D4D40
56506	Перкова	7	71	96	54.38955	54.412267999999997	59.181598000000001	59.171905000000002	0103000020E6100000010000000500000012143FC6DC314B406B82A8FB00964D4012143FC6DC314B406F826F9A3E974D40FA97A432C5344B406F826F9A3E974D40FA97A432C5344B406B82A8FB00964D4012143FC6DC314B406B82A8FB00964D40
56286	Ошиб	7	71	96	54.866196000000002	54.891466000000001	59.222836000000001	59.216304999999998	0103000020E6100000010000000500000088F6B182DF6E4B400B7BDAE1AF9B4D4088F6B182DF6E4B408C2FDAE3859C4D407BBFD18E1B724B408C2FDAE3859C4D407BBFD18E1B724B400B7BDAE1AF9B4D4088F6B182DF6E4B400B7BDAE1AF9B4D40
121	Отево	7	71	96	54.561433999999998	54.574648000000003	59.073580999999997	59.064219000000001	0103000020E61000000100000005000000656EBE11DD474B401364045438884D40656EBE11DD474B40B14D2A1A6B894D401D5BCF108E494B40B14D2A1A6B894D401D5BCF108E494B401364045438884D40656EBE11DD474B401364045438884D40
45748	Москвина	7	71	96	54.169822000000003	54.190725999999998	59.015743000000001	59.007666999999998	0103000020E61000000100000005000000171230BABC154B401421753BFB804D40171230BABC154B400A12DBDD03824D409A3FA6B569184B400A12DBDD03824D409A3FA6B569184B401421753BFB804D40171230BABC154B401421753BFB804D40
1369	Мижуева	7	71	96	54.700600999999999	54.712206999999999	59.167763999999998	59.159959000000001	0103000020E61000000100000005000000BF45274BAD594B40B6D9588979944D40BF45274BAD594B401BB96E4A79954D40BB7D5699295B4B401BB96E4A79954D40BB7D5699295B4B40B6D9588979944D40BF45274BAD594B40B6D9588979944D40
2039	Мелехина	7	71	96	55.081774000000003	55.107743999999997	59.274982000000001	59.264727000000001	0103000020E61000000100000005000000E1D40792778A4B4021AF0793E2A14D40E1D40792778A4B408D7E349C32A34D408C2B2E8ECA8D4B408D7E349C32A34D408C2B2E8ECA8D4B4021AF0793E2A14D40E1D40792778A4B4021AF0793E2A14D40
45665	Мальцева	7	71	96	54.314343000000001	54.330962	59.117891999999998	59.110256	0103000020E61000000100000005000000FF5C34643C284B4009185DDE1C8E4D40FF5C34643C284B40E23AC615178F4D40001C7BF65C2A4B40E23AC615178F4D40001C7BF65C2A4B4009185DDE1C8E4D40FF5C34643C284B4009185DDE1C8E4D40
2470	Малая Серва	7	71	96	54.711739999999999	54.738869000000001	59.025706999999997	59.015774999999998	0103000020E61000000100000005000000A5A0DB4B1A5B4B40158C4AEA04824D40A5A0DB4B1A5B4B409E23F25D4A834D409D836742935E4B409E23F25D4A834D409D836742935E4B40158C4AEA04824D40A5A0DB4B1A5B4B40158C4AEA04824D40
45983	Ленинск	7	71	96	54.682732999999999	54.709601999999997	58.729588	58.713915999999998	0103000020E61000000100000005000000327381CB63574B40AA0B7899615B4D40327381CB63574B40EBC6BB23635D4D408D96033DD45A4B40EBC6BB23635D4D408D96033DD45A4B40AA0B7899615B4D40327381CB63574B40AA0B7899615B4D40
418	Кува	7	71	96	54.149143000000002	54.190348	59.134003999999997	59.120322000000002	0103000020E61000000100000005000000B3B6291E17134B40A27E17B6668F4D40B3B6291E17134B403FC4060B27914D40F46DC1525D184B403FC4060B27914D40F46DC1525D184B40A27E17B6668F4D40B3B6291E17134B40A27E17B6668F4D40
1270	Корчевня	7	71	96	54.873157999999997	54.906323999999998	59.116413999999999	59.106107000000002	0103000020E61000000100000005000000D11E2FA4C36F4B40377007EA948D4D40D11E2FA4C36F4B40F56569A7E68E4D403ACAC16C02744B40F56569A7E68E4D403ACAC16C02744B40377007EA948D4D40D11E2FA4C36F4B40377007EA948D4D40
56520	Конанова	7	71	96	54.755110000000002	54.776823	59.202762	59.195394	0103000020E61000000100000005000000F870C971A7604B40D5EAABAB02994D40F870C971A7604B408F6FEF1AF4994D40EBE3A1EF6E634B408F6FEF1AF4994D40EBE3A1EF6E634B40D5EAABAB02994D40F870C971A7604B40D5EAABAB02994D40
365	Карбас	7	71	96	54.501632999999998	54.526615	59.200315000000003	59.180574	0103000020E6100000010000000500000014CC988235404B400341800C1D974D4014CC988235404B40FAF202ECA3994D40A14ACD1E68434B40FAF202ECA3994D40A14ACD1E68434B400341800C1D974D4014CC988235404B400341800C1D974D40
40406	Егорова	7	71	96	54.355620999999999	54.379713000000002	59.101134999999999	59.088414999999998	0103000020E61000000100000005000000AA622AFD842D4B40E8BCC62E518B4D40AA622AFD842D4B4090BDDEFDF18C4D40DB6E826F9A304B4090BDDEFDF18C4D40DB6E826F9A304B40E8BCC62E518B4D40AA622AFD842D4B40E8BCC62E518B4D40
1216	Егва	7	71	96	54.766043000000003	54.791097000000001	59.113346999999997	59.100940999999999	0103000020E61000000100000005000000352A70B20D624B40ABE97AA2EB8C4D40352A70B20D624B40C30C8D27828E4D405B7B9FAA42654B40C30C8D27828E4D405B7B9FAA42654B40ABE97AA2EB8C4D40352A70B20D624B40ABE97AA2EB8C4D40
45723	Демина	7	71	96	54.609413000000004	54.622985999999997	59.031365999999998	59.026341000000002	0103000020E61000000100000005000000EE60C43E014E4B40A0C552245F834D40EE60C43E014E4B40691A14CD03844D40D4EE5701BE4F4B40691A14CD03844D40D4EE5701BE4F4B40A0C552245F834D40EE60C43E014E4B40A0C552245F834D40
45949	Гурина	7	71	96	54.674567000000003	54.695515999999998	59.190328999999998	59.164115000000002	0103000020E61000000100000005000000FDFA213658564B403BE466B801954D40FDFA213658564B407D3D5FB35C984D4020EC14AB06594B407D3D5FB35C984D4020EC14AB06594B403BE466B801954D40FDFA213658564B403BE466B801954D40
56547	Веселый Мыс	7	71	96	53.934579999999997	53.954684	58.935130000000001	58.926862999999997	0103000020E6100000010000000500000072BF4351A0F74A40AC6F6072A3764D4072BF4351A0F74A4016C1FF56B2774D40DA01D71533FA4A4016C1FF56B2774D40DA01D71533FA4A40AC6F6072A3764D4072BF4351A0F74A40AC6F6072A3764D40
56307	Верх-Юсьва	7	71	96	54.634790000000002	54.680855999999999	58.841780999999997	58.827055000000001	0103000020E61000000100000005000000F7E978CC40514B40247F30F0DC694D40F7E978CC40514B4074B2D47ABF6B4D4087A4164A26574B4074B2D47ABF6B4D4087A4164A26574B40247F30F0DC694D40F7E978CC40514B40247F30F0DC694D40
56248	Верх-Иньва	7	71	96	54.315492999999996	54.346997000000002	58.936318999999997	58.913665000000002	0103000020E61000000100000005000000F78E1A1362284B40FB3F87F9F2744D40F78E1A1362284B40CCCF0D4DD9774D40B267CF656A2C4B40CCCF0D4DD9774D40B267CF656A2C4B40FB3F87F9F2744D40F78E1A1362284B40FB3F87F9F2744D40
56517	Велва-База	7	71	96	55.056145000000001	55.073886000000002	59.242004999999999	59.227660999999998	0103000020E61000000100000005000000BE6A65C22F874B408EC9E2FE239D4D40BE6A65C22F874B40F73B1405FA9E4D40EED0B01875894B40F73B1405FA9E4D40EED0B01875894B408EC9E2FE239D4D40BE6A65C22F874B408EC9E2FE239D4D40
1107	Буждом	7	71	96	54.084994000000002	54.095154000000001	59.008648999999998	59.004362999999998	0103000020E61000000100000005000000992D5915E10A4B40FE277FF78E804D40992D5915E10A4B40511212691B814D40B30A9B012E0C4B40511212691B814D40B30A9B012E0C4B40FE277FF78E804D40992D5915E10A4B40FE277FF78E804D40
527	Большая Сидорова	7	71	96	54.103248000000001	54.118582000000004	59.114913000000001	59.107807000000001	0103000020E610000001000000050000004FB0FF3A370D4B40D3A3A99ECC8D4D404FB0FF3A370D4B4050711C78B58E4D4078F2E9B12D0F4B4050711C78B58E4D4078F2E9B12D0F4B40D3A3A99ECC8D4D404FB0FF3A370D4B40D3A3A99ECC8D4D40
32491	Белоево	7	71	96	54.467910000000003	54.511927	59.148262000000003	59.135337999999997	0103000020E6100000010000000500000056BC9179E43B4B40F9F36DC152914D4056BC9179E43B4B40AA9ECC3FFA924D403E78EDD286414B40AA9ECC3FFA924D403E78EDD286414B40F9F36DC152914D4056BC9179E43B4B40F9F36DC152914D40
1499	Алекова	7	71	96	54.678860999999998	54.694591000000003	59.136297999999996	59.128939000000003	0103000020E61000000100000005000000D2C3D0EAE4564B40E816BA1281904D40D2C3D0EAE4564B404E417E3672914D40488C9E5BE8584B404E417E3672914D40488C9E5BE8584B40E816BA1281904D40D2C3D0EAE4564B40E816BA1281904D40
58125	Шабуничи	7	71	4039	55.654018000000001	55.699545000000001	58.144392000000003	58.131478999999999	0103000020E61000000100000005000000677FA0DCB6D34B402E8ECA4DD4104D40677FA0DCB6D34B40EBE6E26F7B124D40488AC8B08AD94B40EBE6E26F7B124D40488AC8B08AD94B402E8ECA4DD4104D40677FA0DCB6D34B402E8ECA4DD4104D40
56304	Черная	7	71	1228	55.706919999999997	55.74756	58.147554999999997	58.135646000000001	0103000020E61000000100000005000000B471C45A7CDA4B40A7EA1ED95C114D40B471C45A7CDA4B403EAE0D15E3124D401DE6CB0BB0DF4B403EAE0D15E3124D401DE6CB0BB0DF4B40A7EA1ED95C114D40B471C45A7CDA4B40A7EA1ED95C114D40
47074	Усть-Сыны	7	71	1228	55.560215999999997	55.589367000000003	58.051836000000002	58.037802999999997	0103000020E6100000010000000500000014596B28B5C74B4068588CBAD6044D4014596B28B5C74B40B360E28FA2064D40BB2BBB6070CB4B40B360E28FA2064D40BB2BBB6070CB4B4068588CBAD6044D4014596B28B5C74B4068588CBAD6044D40
13002	Стряпунята	7	71	1228	55.930779999999999	55.987167999999997	58.190441999999997	58.165940999999997	0103000020E61000000100000005000000ACE28DCC23F74B406308008E3D154D40ACE28DCC23F74B4075E4486760184D4030D461855BFE4B4075E4486760184D4030D461855BFE4B406308008E3D154D40ACE28DCC23F74B406308008E3D154D40
25707	Осташата	7	71	1228	56.108224999999997	56.113892999999997	58.177878	58.173763000000001	0103000020E6100000010000000500000007CE1951DA0D4C409F20B1DD3D164D4007CE1951DA0D4C40C556D0B4C4164D40251FBB0B940E4C40C556D0B4C4164D40251FBB0B940E4C409F20B1DD3D164D4007CE1951DA0D4C409F20B1DD3D164D40
12477	Оверята	7	71	1228	55.841883000000003	55.874257999999998	58.105477	58.077961999999999	0103000020E61000000100000005000000790778D2C2EB4B40562AA8A8FA094D40790778D2C2EB4B4077BD3445800D4D401822A7AFE7EF4B4077BD3445800D4D401822A7AFE7EF4B40562AA8A8FA094D40790778D2C2EB4B40562AA8A8FA094D40
62086	Мысы	7	71	1228	55.897129999999997	55.933025999999998	58.067067999999999	58.054855000000003	0103000020E610000001000000050000005721E527D5F24B40D482177D05074D405721E527D5F24B40D74D29AF95084D40AA285E656DF74B40D74D29AF95084D40AA285E656DF74B40D482177D05074D405721E527D5F24B40D482177D05074D40
56313	Конец Бор	7	71	1228	55.635486	55.670088999999997	58.080052000000002	58.060578999999997	0103000020E610000001000000050000006E88F19A57D14B4085E97B0DC1074D406E88F19A57D14B405DFDD8243F0A4D406534F279C5D54B405DFDD8243F0A4D406534F279C5D54B4085E97B0DC1074D406E88F19A57D14B4085E97B0DC1074D40
56341	Залесная	7	71	1228	55.790832000000002	55.798673999999998	58.238914999999999	58.235242999999997	0103000020E61000000100000005000000AD50A4FB39E54B4074CE4F711C1E4D40AD50A4FB39E54B400DC347C4941E4D402F151BF33AE64B400DC347C4941E4D402F151BF33AE64B4074CE4F711C1E4D40AD50A4FB39E54B4074CE4F711C1E4D40
9759	Цепел	7	71	1028	57.340704000000002	57.362273000000002	60.132424	60.123370999999999	0103000020E61000000100000005000000E6CE4C309CAB4C402D23F59ECA0F4E40E6CE4C309CAB4C404E9A0645F3104E40A69C2FF65EAE4C404E9A0645F3104E40A69C2FF65EAE4C402D23F59ECA0F4E40E6CE4C309CAB4C402D23F59ECA0F4E40
10260	Федорцова	7	71	1028	56.771144999999997	56.802208999999998	60.340012000000002	60.325747	0103000020E61000000100000005000000A9BC1DE1B4624C4093E2E313B2294E40A9BC1DE1B4624C40B01F6283852B4E4047C7D5C8AE664C40B01F6283852B4E4047C7D5C8AE664C4093E2E313B2294E40A9BC1DE1B4624C4093E2E313B2294E40
10349	Усть-Язьва	7	71	1028	56.782482000000002	56.81006	60.377530999999998	60.359054999999998	0103000020E61000000100000005000000B6DAC35E28644C408E3BA583F52D4E40B6DAC35E28644C40F31C91EF52304E401DE6CB0BB0674C40F31C91EF52304E401DE6CB0BB0674C408E3BA583F52D4E40B6DAC35E28644C408E3BA583F52D4E40
11239	Сыпучи	7	71	1028	57.801594000000001	57.815750999999999	60.558709	60.549557	0103000020E61000000100000005000000BD55D7A19AE64C40D9243FE257464E40BD55D7A19AE64C408D7DC9C683474E40F3565D876AE84C408D7DC9C683474E40F3565D876AE84C40D9243FE257464E40BD55D7A19AE64C40D9243FE257464E40
10180	Северный Колчим	7	71	1028	57.764395	57.792036000000003	60.125661000000001	60.116858000000001	0103000020E61000000100000005000000EB1C03B2D7E14C405323F433F50E4E40EB1C03B2D7E14C40FBB0DEA815104E4099A0866F61E54C40FBB0DEA815104E4099A0866F61E54C405323F433F50E4E40EB1C03B2D7E14C405323F433F50E4E40
56294	Светлый	7	71	1028	57.601394999999997	57.611519000000001	60.259993000000001	60.255792	0103000020E610000001000000050000002C7DE882FACC4C400A4AD1CABD204E402C7DE882FACC4C402F185C7347214E40FAF02C4146CE4C402F185C7347214E40FAF02C4146CE4C400A4AD1CABD204E402C7DE882FACC4C400A4AD1CABD204E40
46315	Набережный	7	71	1028	57.076348000000003	57.086409000000003	60.447246999999997	60.441201	0103000020E61000000100000005000000B98E71C5C5894C4033FB3C4679384E40B98E71C5C5894C40F71DC3633F394E40408A3A730F8B4C40F71DC3633F394E40408A3A730F8B4C4033FB3C4679384E40B98E71C5C5894C4033FB3C4679384E40
10518	Мутиха	7	71	1028	57.961665000000004	57.997776999999999	60.454267000000002	60.437282000000003	0103000020E610000001000000050000009B5AB6D617FB4C40939048DBF8374E409B5AB6D617FB4C407653CA6B253A4E40BAD91F28B7FF4C407653CA6B253A4E40BAD91F28B7FF4C40939048DBF8374E409B5AB6D617FB4C40939048DBF8374E40
9164	Красновишерск	7	71	1028	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
11405	Золотанка	7	71	1028	58.570461999999999	58.601795000000003	60.483462000000003	60.469428999999998	0103000020E610000001000000050000002DCE18E604494D40A165DD3F163C4E402DCE18E604494D40EC6D3315E23D4E40BBF2599E074D4D40EC6D3315E23D4E40BBF2599E074D4D40A165DD3F163C4E402DCE18E604494D40A165DD3F163C4E40
10987	Заговоруха	7	71	1028	57.280957000000001	57.293695	60.503267000000001	60.492348999999997	0103000020E61000000100000005000000884A2366F6A34C40F19BC24A053F4E40884A2366F6A34C40F913950D6B404E40D6FF39CC97A54C40F913950D6B404E40D6FF39CC97A54C40F19BC24A053F4E40884A2366F6A34C40F19BC24A053F4E40
10424	Данилов Луг	7	71	1028	56.751669999999997	56.779221	60.366446000000003	60.360430000000001	0103000020E6100000010000000500000031B1F9B836604C40A73FFB91222E4E4031B1F9B836604C4001E0D8B3E72E4E409FAD8383BD634C4001E0D8B3E72E4E409FAD8383BD634C40A73FFB91222E4E4031B1F9B836604C40A73FFB91222E4E40
10521	Губдор	7	71	1028	56.626409000000002	56.649118000000001	60.200026999999999	60.192630000000001	0103000020E61000000100000005000000C5758C2B2E504C403F1D8F19A8184E40C5758C2B2E504C4093A8177C9A194E405A9F724C16534C4093A8177C9A194E405A9F724C16534C403F1D8F19A8184E40C5758C2B2E504C403F1D8F19A8184E40
46490	Волынка	7	71	1028	57.699832999999998	57.721662000000002	60.378830000000001	60.364576999999997	0103000020E61000000100000005000000AED4B32094D94C40D8EF8975AA2E4E40AED4B32094D94C40315F5E807D304E400B62A06B5FDC4C40315F5E807D304E400B62A06B5FDC4C40D8EF8975AA2E4E40AED4B32094D94C40D8EF8975AA2E4E40
11084	Вишерогорск	7	71	1028	57.345967999999999	57.372478000000001	60.462851000000001	60.456187999999997	0103000020E6100000010000000500000034BBEEAD48AC4C40F0694E5E643A4E4034BBEEAD48AC4C40E0F599B33E3B4E40603DEE5BADAF4C40E0F599B33E3B4E40603DEE5BADAF4C40F0694E5E643A4E4034BBEEAD48AC4C40F0694E5E643A4E40
10907	Верхняя Бычина	7	71	1028	57.272387000000002	57.283994	60.147247999999998	60.143574999999998	0103000020E61000000100000005000000836DC493DDA24C40F8C264AA60124E40836DC493DDA24C406133C005D9124E404F2157EA59A44C406133C005D9124E404F2157EA59A44C40F8C264AA60124E40836DC493DDA24C40F8C264AA60124E40
8968	Верх-Язьва	7	71	1028	57.440327000000003	57.448511000000003	60.106059999999999	60.093119000000002	0103000020E61000000100000005000000DD4598A25CB84C4070D1C952EB0B4E40DD4598A25CB84C40F6B4C35F930D4E40B972F6CE68B94C40F6B4C35F930D4E40B972F6CE68B94C4070D1C952EB0B4E40DD4598A25CB84C4070D1C952EB0B4E40
11510	Велс	7	71	1028	58.772412000000003	58.802874000000003	60.741864999999997	60.729844999999997	0103000020E61000000100000005000000DC847B65DE624D4016139B8F6B5D4E40DC847B65DE624D400586AC6EF55E4E4084674293C4664D400586AC6EF55E4E4084674293C4664D4016139B8F6B5D4E40DC847B65DE624D4016139B8F6B5D4E40
10591	Вая	7	71	1028	58.361882000000001	58.400149999999996	60.605753999999997	60.587558999999999	0103000020E610000001000000050000006B813D26522E4D4038BC2022354B4E406B813D26522E4D40E9B5D958894D4E4048BF7D1D38334D40E9B5D958894D4E4048BF7D1D38334D4038BC2022354B4E406B813D26522E4D4038BC2022354B4E40
10067	Ванькова	7	71	1028	57.631326999999999	57.649526999999999	60.031300999999999	60.023947	0103000020E61000000100000005000000780AB952CFD04C402DEBFEB110034E40780AB952CFD04C4082AAD1AB01044E403B6F63B323D34C4082AAD1AB01044E403B6F63B323D34C402DEBFEB110034E40780AB952CFD04C402DEBFEB110034E40
56500	Березовая Старица	7	71	1028	56.585607000000003	56.604652000000002	60.238653999999997	60.226976999999998	0103000020E6100000010000000500000083A7902BF54A4C40DBF813950D1D4E4083A7902BF54A4C40A087DA368C1E4E4002BB9A3C654D4C40A087DA368C1E4E4002BB9A3C654D4C40DBF813950D1D4E4083A7902BF54A4C40DBF813950D1D4E40
45379	Юксеево	7	71	934	54.311909	54.335265	59.872900000000001	59.861046999999999	0103000020E61000000100000005000000FE2955A2EC274B40D2A8C0C936EE4D40FE2955A2EC274B40D656EC2FBBEF4D40293FA9F6E92A4B40D656EC2FBBEF4D40293FA9F6E92A4B40D2A8C0C936EE4D40FE2955A2EC274B40D2A8C0C936EE4D40
31406	Хазово	7	71	934	54.242370000000001	54.249251000000001	59.545786	59.541091999999999	0103000020E6100000010000000500000009C4EBFA051F4B404910AE8042C54D4009C4EBFA051F4B40AD4ECE50DCC54D4066BFEE74E71F4B40AD4ECE50DCC54D4066BFEE74E71F4B404910AE8042C54D4009C4EBFA051F4B404910AE8042C54D40
7524	Усть-Янчер	7	71	934	54.059193999999998	54.076405999999999	59.527861000000001	59.521777	0103000020E61000000100000005000000490F43AB93074B400A67B796C9C24D40490F43AB93074B40BCEA01F390C34D40ED9BFBABC7094B40BCEA01F390C34D40ED9BFBABC7094B400A67B796C9C24D40490F43AB93074B400A67B796C9C24D40
58232	Усть-Силайка	7	71	934	53.963433999999999	53.983322999999999	59.833461	59.815980000000003	0103000020E610000001000000050000005FED28CE51FB4A4055185B0872E84D405FED28CE51FB4A40E8BE9CD9AEEA4D40CA332F87DDFD4A40E8BE9CD9AEEA4D40CA332F87DDFD4A4055185B0872E84D405FED28CE51FB4A4055185B0872E84D40
58115	Усть-Онолва	7	71	934	54.803179	54.825152000000003	59.620344000000003	59.603624000000003	0103000020E61000000100000005000000C0EAC891CE664B40558A1D8D43CD4D40C0EAC891CE664B408A22A46E67CF4D40501DAB949E694B408A22A46E67CF4D40501DAB949E694B40558A1D8D43CD4D40C0EAC891CE664B40558A1D8D43CD4D40
32207	Серва	7	71	934	54.179937000000002	54.198926999999998	59.893087000000001	59.883408000000003	0103000020E61000000100000005000000912BF52C08174B402C836A8313F14D40912BF52C08174B40CBBDC0AC50F24D404CA59F7076194B40CBBDC0AC50F24D404CA59F7076194B402C836A8313F14D40912BF52C08174B402C836A8313F14D40
31487	Сеполь	7	71	934	54.473182999999999	54.495803000000002	59.543747000000003	59.536850000000001	0103000020E61000000100000005000000F702B342913C4B40C66D3480B7C44D40F702B342913C4B4029266F8099C54D401D210379763F4B4029266F8099C54D401D210379763F4B40C66D3480B7C44D40F702B342913C4B40C66D3480B7C44D40
31686	Пыстогово	7	71	934	54.427773000000002	54.446440000000003	59.681691999999998	59.674818999999999	0103000020E61000000100000005000000508E0244C1364B4016DC0F7860D64D40508E0244C1364B40F0F8F6AE41D74D4029D027F224394B40F0F8F6AE41D74D4029D027F224394B4016DC0F7860D64D40508E0244C1364B4016DC0F7860D64D40
31897	Пелым	7	71	934	54.355324000000003	54.380935000000001	59.737994	59.723171000000001	0103000020E61000000100000005000000F1BDBF417B2D4B40333509DE90DC4D40F1BDBF417B2D4B4076525F9676DE4D406D73637AC2304B4076525F9676DE4D406D73637AC2304B40333509DE90DC4D40F1BDBF417B2D4B40333509DE90DC4D40
31983	Отопково	7	71	934	54.398963999999999	54.41075	59.766742000000001	59.753464000000001	0103000020E6100000010000000500000003249A4011334B404F5B238271E04D4003249A4011334B401D3C139A24E24D407F6ABC7493344B401D3C139A24E24D407F6ABC7493344B404F5B238271E04D4003249A4011334B404F5B238271E04D40
45356	Москвино	7	71	934	54.376291000000002	54.390906000000001	59.827866999999998	59.820920000000001	0103000020E61000000100000005000000BB63B14D2A304B40F05014E813E94D40BB63B14D2A304B400438BD8BF7E94D40B4E7323509324B400438BD8BF7E94D40B4E7323509324B40F05014E813E94D40BB63B14D2A304B40F05014E813E94D40
32331	Мараты	7	71	934	54.896648999999996	54.936157000000001	59.705635999999998	59.688245999999999	0103000020E61000000100000005000000DC7EF964C5724B4029CDE67118D84D40DC7EF964C5724B40AC70CB4752DA4D40F37519FED3774B40AC70CB4752DA4D40F37519FED3774B4029CDE67118D84D40DC7EF964C5724B4029CDE67118D84D40
31889	Мара-Пальник	7	71	934	54.738312000000001	54.759619999999998	59.659613	59.648091999999998	0103000020E61000000100000005000000471FF301815E4B404D66BCADF4D24D40471FF301815E4B401B82E3326ED44D409AB1683A3B614B401B82E3326ED44D409AB1683A3B614B404D66BCADF4D24D40471FF301815E4B404D66BCADF4D24D40
31359	Лягаево	7	71	934	54.195971999999998	54.226398000000003	59.596474999999998	59.589106000000001	0103000020E610000001000000050000004277499C15194B404EF04DD367CB4D404277499C15194B40D8F0F44A59CC4D409EF0129CFA1C4B40D8F0F44A59CC4D409EF0129CFA1C4B404EF04DD367CB4D404277499C15194B404EF04DD367CB4D40
31258	Кышка	7	71	934	54.407274000000001	54.434187000000001	59.602718000000003	59.594279999999998	0103000020E610000001000000050000006C41EF8D21344B405C55F65D11CC4D406C41EF8D21344B40F35A09DD25CD4D4097AC8A7093374B40F35A09DD25CD4D4097AC8A7093374B405C55F65D11CC4D406C41EF8D21344B405C55F65D11CC4D40
48272	Кукушка	7	71	934	54.392612999999997	54.409644999999998	59.540239	59.532798	0103000020E61000000100000005000000027E8D2441324B40E6AF90B932C44D40027E8D2441324B400A83328D26C54D4026FC523F6F344B400A83328D26C54D4026FC523F6F344B40E6AF90B932C44D40027E8D2441324B40E6AF90B932C44D40
16095	Красная Курья	7	71	934	54.595444000000001	54.616294000000003	59.531635000000001	59.523955000000001	0103000020E61000000100000005000000BA4C4D82374C4B40B0C91AF510C34D40BA4C4D82374C4B4059349D9D0CC44D404B5CC7B8E24E4B4059349D9D0CC44D404B5CC7B8E24E4B40B0C91AF510C34D40BA4C4D82374C4B40B0C91AF510C34D40
31095	Кочево	7	71	934	54.294670000000004	54.327961000000002	59.612124000000001	59.590012000000002	0103000020E61000000100000005000000618E1EBFB7254B40B01F628385CB4D40618E1EBFB7254B40618C48145ACE4D4086AE44A0FA294B40618C48145ACE4D4086AE44A0FA294B40B01F628385CB4D40618E1EBFB7254B40B01F628385CB4D40
56271	Васькино	7	71	934	54.212699000000001	54.230404	59.581966999999999	59.577666000000001	0103000020E610000001000000050000002A7288B8391B4B406D01A1F5F0C94D402A7288B8391B4B40F52C08E57DCA4D400D6FD6E07D1D4B40F52C08E57DCA4D400D6FD6E07D1D4B406D01A1F5F0C94D402A7288B8391B4B406D01A1F5F0C94D40
32400	Буждым	7	71	934	54.869627999999999	54.906934999999997	59.667271	59.65889	0103000020E61000000100000005000000CBD765F84F6F4B40AAD4EC8156D44D40CBD765F84F6F4B40DC48D92269D54D40834C327216744B40DC48D92269D54D40834C327216744B40AAD4EC8156D44D40CBD765F84F6F4B40AAD4EC8156D44D40
31738	Борино	7	71	934	54.501435000000001	54.520614000000002	59.718865000000001	59.710546999999998	0103000020E61000000100000005000000EE08A7052F404B40ADA23F34F3DA4D40EE08A7052F404B40999EB0C403DC4D407DEBC37AA3424B40999EB0C403DC4D407DEBC37AA3424B40ADA23F34F3DA4D40EE08A7052F404B40ADA23F34F3DA4D40
31661	Большая Коча	7	71	934	54.572240000000001	54.596144000000002	59.658963	59.650815999999999	0103000020E6100000010000000500000045BB0A293F494B4055DB4DF04DD34D4045BB0A293F494B4014234BE658D44D4073DA53724E4C4B4014234BE658D44D4073DA53724E4C4B4055DB4DF04DD34D4045BB0A293F494B4055DB4DF04DD34D40
32319	Акилово	7	71	934	53.950713999999998	53.972048999999998	59.627547	59.619661000000001	0103000020E61000000100000005000000B7EC10FFB0F94A40A7CD380D51CF4D40B7EC10FFB0F94A40F9D9C87553D04D40048E041A6CFC4A40F9D9C87553D04D40048E041A6CFC4A40A7CD380D51CF4D40B7EC10FFB0F94A40A7CD380D51CF4D40
48181	Чураки	7	71	913	55.247342000000003	55.264400999999999	59.646005000000002	59.638092	0103000020E61000000100000005000000B07614E7A89F4B406CEBA7FFACD14D40B07614E7A89F4B40B806B64AB0D24D40CD0358E4D7A14B40B806B64AB0D24D40CD0358E4D7A14B406CEBA7FFACD14D40B07614E7A89F4B406CEBA7FFACD14D40
49063	Чирково	7	71	913	54.979886999999998	54.998463999999998	59.869371999999998	59.858336000000001	0103000020E610000001000000050000004563EDEF6C7D4B405F7D3CF4DDED4D404563EDEF6C7D4B407007EA9447EF4D40DE1D19ABCD7F4B407007EA9447EF4D40DE1D19ABCD7F4B405F7D3CF4DDED4D404563EDEF6C7D4B405F7D3CF4DDED4D40
30561	Чазево	7	71	913	54.527441000000003	54.545659000000001	59.890081000000002	59.881286000000003	0103000020E61000000100000005000000E7C8CA2F83434B401A36CAFACDF04D40E7C8CA2F83434B403FE5982CEEF14D4050E27327D8454B403FE5982CEEF14D4050E27327D8454B401A36CAFACDF04D40E7C8CA2F83434B401A36CAFACDF04D40
30951	Усть-Коса	7	71	913	55.167670999999999	55.184989999999999	60.208602999999997	60.190902999999999	0103000020E610000001000000050000006ABE4A3E76954B40A9DA6E826F184E406ABE4A3E76954B407A6CCB80B31A4E40240B98C0AD974B407A6CCB80B31A4E40240B98C0AD974B40A9DA6E826F184E406ABE4A3E76954B40A9DA6E826F184E40
58300	Трифаново	7	71	913	54.822941999999998	54.840549000000003	60.219014000000001	60.211196000000001	0103000020E610000001000000050000009E40D82956694B40E4857478081B4E409E40D82956694B40DEAE97A6081C4E40BFD7101C976B4B40DEAE97A6081C4E40BFD7101C976B4B40E4857478081B4E409E40D82956694B40E4857478081B4E40
31004	Солым	7	71	913	55.138627999999997	55.153998000000001	60.131644000000001	60.117015000000002	0103000020E61000000100000005000000AA27F38FBE914B401B12F758FA0E4E40AA27F38FBE914B40795BE9B5D9104E4020D3DA34B6934B40795BE9B5D9104E4020D3DA34B6934B401B12F758FA0E4E40AA27F38FBE914B401B12F758FA0E4E40
30398	Пятигоры	7	71	913	54.770912000000003	54.788276000000003	60.221798	60.210856	0103000020E61000000100000005000000070C923EAD624B402B155454FD1A4E40070C923EAD624B40BB287AE0631C4E40611C5C3AE6644B40BB287AE0631C4E40611C5C3AE6644B402B155454FD1A4E40070C923EAD624B402B155454FD1A4E40
7245	Пуксиб	7	71	913	54.999676999999998	55.023527000000001	59.782805000000003	59.762504999999997	0103000020E610000001000000050000001DC87A6AF57F4B40AB048BC399E14D401DC87A6AF57F4B40991249F432E44D4058C9C7EE02834B40991249F432E44D4058C9C7EE02834B40AB048BC399E14D401DC87A6AF57F4B40AB048BC399E14D40
9119	Порошево	7	71	913	54.876615999999999	54.894618999999999	60.126002	60.118569999999998	0103000020E610000001000000050000003E93FDF334704B40B324404D2D0F4E403E93FDF334704B40849D62D520104E40ABB019E082724B40849D62D520104E40ABB019E082724B40B324404D2D0F4E403E93FDF334704B40B324404D2D0F4E40
30854	Новая Светлица	7	71	913	55.255346000000003	55.275576000000001	60.213306000000003	60.200375999999999	0103000020E610000001000000050000000C957F2DAFA04B409F73B7EBA5194E400C957F2DAFA04B4032056B9C4D1B4E4000C8091346A34B4032056B9C4D1B4E4000C8091346A34B409F73B7EBA5194E400C957F2DAFA04B409F73B7EBA5194E40
30180	Нижняя Коса	7	71	913	54.974677	54.993558999999998	60.015948000000002	60.006695999999998	0103000020E61000000100000005000000EA944737C27C4B40CB811E6ADB004E40EA944737C27C4B40E33785950A024E40BFD2F9F02C7F4B40E33785950A024E40BFD2F9F02C7F4B40CB811E6ADB004E40EA944737C27C4B40CB811E6ADB004E40
7306	Левичи	7	71	913	55.190173000000001	55.204430000000002	59.843316999999999	59.838005000000003	0103000020E6100000010000000500000086CABF9657984B40377172BF43EB4D4086CABF9657984B409694BBCFF1EB4D40202922C32A9A4B409694BBCFF1EB4D40202922C32A9A4B40377172BF43EB4D4086CABF9657984B40377172BF43EB4D40
56242	Коса	7	71	913	54.974245000000003	55.009289000000003	59.951912	59.937319000000002	0103000020E6100000010000000500000051A5660FB47C4B40B075A911FAF74D4051A5660FB47C4B40C1559E40D8F94D40359BC76130814B40C1559E40D8F94D40359BC76130814B40B075A911FAF74D4051A5660FB47C4B40B075A911FAF74D40
58141	Верх-Лель	7	71	913	54.805218000000004	54.825071000000001	59.983049000000001	59.976612000000003	0103000020E610000001000000050000004513286211674B40CA703C9F01FD4D404513286211674B40C9AEB48CD4FD4D4063F030ED9B694B40C9AEB48CD4FD4D4063F030ED9B694B40CA703C9F01FD4D404513286211674B40CA703C9F01FD4D40
49159	Бачманово	7	71	913	54.626094000000002	54.645524999999999	59.859338999999999	59.849645000000002	0103000020E61000000100000005000000651C23D923504B40DF1AD82AC1EC4D40651C23D923504B40B39602D2FEED4D400DE02D90A0524B40B39602D2FEED4D400DE02D90A0524B40DF1AD82AC1EC4D40651C23D923504B40DF1AD82AC1EC4D40
58216	дом Отдыха Красный Яр	7	71	984	57.465552000000002	57.492384999999999	57.258107000000003	57.248407999999998	0103000020E61000000100000005000000304B3B3597BB4C404A0856D5CB9F4C40304B3B3597BB4C4031EF71A609A14C403E05C07806BF4C4031EF71A609A14C403E05C07806BF4C404A0856D5CB9F4C40304B3B3597BB4C404A0856D5CB9F4C40
8666	Черный Яр	7	71	984	57.400872999999997	57.433024000000003	57.284488000000003	57.273156	0103000020E61000000100000005000000B96C74CE4FB34C40645A9BC6F6A24C40B96C74CE4FB34C405F0D501A6AA44C400A3197546DB74C405F0D501A6AA44C400A3197546DB74C40645A9BC6F6A24C40B96C74CE4FB34C40645A9BC6F6A24C40
56257	Усть-Кишерть	7	71	984	57.221516000000001	57.273015999999998	57.381948000000001	57.339227999999999	0103000020E6100000010000000500000037C5E3A25A9C4C4099F1B6D26BAB4C4037C5E3A25A9C4C40E5620CACE3B04C4072A43330F2A24C40E5620CACE3B04C4072A43330F2A24C4099F1B6D26BAB4C4037C5E3A25A9C4C4099F1B6D26BAB4C40
32569	Сухой Лог	7	71	984	57.311213000000002	57.334515000000003	57.442419000000001	57.432017999999999	0103000020E61000000100000005000000878BDCD3D5A74C4044A4A65D4CB74C40878BDCD3D5A74C408410902FA1B84C40BF823463D1AA4C408410902FA1B84C40BF823463D1AA4C4044A4A65D4CB74C40878BDCD3D5A74C4044A4A65D4CB74C40
56526	Спасо-Барда	7	71	984	57.344163000000002	57.374040999999998	57.378528000000003	57.358069999999998	0103000020E6100000010000000500000023BF7E880DAC4C40E0D6DD3CD5AD4C4023BF7E880DAC4C40664F029B73B04C407B2E5393E0AF4C40664F029B73B04C407B2E5393E0AF4C40E0D6DD3CD5AD4C4023BF7E880DAC4C40E0D6DD3CD5AD4C40
8845	Седа	7	71	984	57.258293000000002	57.295034000000001	57.332422000000001	57.285406999999999	0103000020E6100000010000000500000093E4B9BE0FA14C405586713788A44C4093E4B9BE0FA14C40473CD9CD8CAA4C40A29A92ACC3A54C40473CD9CD8CAA4C40A29A92ACC3A54C405586713788A44C4093E4B9BE0FA14C405586713788A44C40
32523	Посад	7	71	984	57.246434999999998	57.275342999999999	57.426363000000002	57.410910999999999	0103000020E610000001000000050000007DCB9C2E8B9F4C4088484DBB98B44C407DCB9C2E8B9F4C40BB9C121093B64C405D177E703EA34C40BB9C121093B64C405D177E703EA34C4088484DBB98B44C407DCB9C2E8B9F4C4088484DBB98B44C40
58224	Никулино	7	71	984	57.842297000000002	57.846294	57.292290000000001	57.290661	0103000020E610000001000000050000006C425A63D0EB4C40809C306134A54C406C425A63D0EB4C4053793BC269A54C4088669E5C53EC4C4053793BC269A54C4088669E5C53EC4C40809C306134A54C406C425A63D0EB4C40809C306134A54C40
33105	Молебка	7	71	984	57.915275999999999	57.962032999999998	57.244706999999998	57.231546999999999	0103000020E61000000100000005000000276893C327F54C40533E0455A39D4C40276893C327F54C40170D198F529F4C401D56B8E523FB4C40170D198F529F4C401D56B8E523FB4C40533E0455A39D4C40276893C327F54C40533E0455A39D4C40
8628	Меча	7	71	984	57.487741	57.518237999999997	57.270319000000001	57.261519999999997	0103000020E610000001000000050000008CF50D4C6EBE4C40FD9FC37C79A14C408CF50D4C6EBE4C40643E20D099A24C40B0C56E9F55C24C40643E20D099A24C40B0C56E9F55C24C40FD9FC37C79A14C408CF50D4C6EBE4C40FD9FC37C79A14C40
33111	Медведево	7	71	984	57.479107999999997	57.498708999999998	57.359758999999997	57.352758000000001	0103000020E6100000010000000500000040A0336953BD4C4081B3942C27AD4C4040A0336953BD4C4088B839950CAE4C40459C4EB2D5BF4C4088B839950CAE4C40459C4EB2D5BF4C4081B3942C27AD4C4040A0336953BD4C4081B3942C27AD4C40
8715	Мазуевка	7	71	984	57.305571	57.378703000000002	57.265774	57.240188000000003	0103000020E6100000010000000500000092CD55F31CA74C402272FA7ABE9E4C4092CD55F31CA74C404510E7E104A24C40D4F2035779B04C404510E7E104A24C40D4F2035779B04C402272FA7ABE9E4C4092CD55F31CA74C402272FA7ABE9E4C40
8345	Лек	7	71	984	57.369943999999997	57.780825	57.406902000000002	57.304558999999998	0103000020E61000000100000005000000FBAC32535AAF4C40EA5910CAFBA64C40FBAC32535AAF4C40A8565F5D15B44C401973D712F2E34C40A8565F5D15B44C401973D712F2E34C40EA5910CAFBA64C40FBAC32535AAF4C40EA5910CAFBA64C40
29252	Красный Яр	7	71	984	57.468210999999997	57.491728999999999	57.247867999999997	57.227750999999998	0103000020E6100000010000000500000050508A56EEBB4C40CE50DCF1269D4C4050508A56EEBB4C40CADC7C23BA9F4C4055BFD2F9F0BE4C40CADC7C23BA9F4C4055BFD2F9F0BE4C40CE50DCF1269D4C4050508A56EEBB4C40CE50DCF1269D4C40
30166	Кордон	7	71	984	57.898145	57.935631999999998	57.424953000000002	57.395676000000002	0103000020E610000001000000050000007008556AF6F24C40F3E7DB82A5B24C407008556AF6F24C4026AB22DC64B64C40A88B14CAC2F74C4026AB22DC64B64C40A88B14CAC2F74C40F3E7DB82A5B24C407008556AF6F24C40F3E7DB82A5B24C40
56263	Киселево	7	71	984	57.405059999999999	57.436258000000002	57.344113999999998	57.334944	0103000020E6100000010000000500000079758E01D9B34C40E7FEEA71DFAA4C4079758E01D9B34C40410C74ED0BAC4C40274F594DD7B74C40410C74ED0BAC4C40274F594DD7B74C40E7FEEA71DFAA4C4079758E01D9B34C40E7FEEA71DFAA4C40
25779	Зуята	7	71	984	57.315524000000003	57.326842999999997	57.446201000000002	57.440089	0103000020E61000000100000005000000338D261763A84C40282A1BD654B84C40338D261763A84C40A438471D1DB94C4098F6CDFDD5A94C40A438471D1DB94C4098F6CDFDD5A94C40282A1BD654B84C40338D261763A84C40282A1BD654B84C40
58200	Заборье	7	71	984	57.327409000000003	57.349364000000001	57.400424000000001	57.391252999999999	0103000020E6100000010000000500000042B5C189E8A94C401FBB0B9414B24C4042B5C189E8A94C404A44F81741B34C402B33A5F5B7AC4C404A44F81741B34C402B33A5F5B7AC4C401FBB0B9414B24C4042B5C189E8A94C401FBB0B9414B24C40
8277	Верхняя Солянка	7	71	984	57.539617999999997	57.565553000000001	57.397644999999997	57.382199999999997	0103000020E610000001000000050000009D2ADF3312C54C40FE43FAEDEBB04C409D2ADF3312C54C407E350708E6B24C40CD936B0A64C84C407E350708E6B24C40CD936B0A64C84C40FE43FAEDEBB04C409D2ADF3312C54C40FE43FAEDEBB04C40
56284	Березовка	7	71	984	57.689205999999999	57.700803000000001	57.255429999999997	57.251491000000001	0103000020E610000001000000050000007E1AF7E637D84C40821E6ADB30A04C407E1AF7E637D84C40693524EEB1A04C4027F8A6E9B3D94C40693524EEB1A04C4027F8A6E9B3D94C40821E6ADB30A04C407E1AF7E637D84C40821E6ADB30A04C40
7956	Шахта	7	71	958	57.625632000000003	57.683509999999998	59.107613000000001	59.076286000000003	0103000020E6100000010000000500000061AA99B514D04C40439259BDC3894D4061AA99B514D04C40EECF4543C68D4D40963E74417DD74C40EECF4543C68D4D40963E74417DD74C40439259BDC3894D4061AA99B514D04C40439259BDC3894D40
8060	Центральный Коспашский	7	71	958	57.729953000000002	57.798431999999998	59.073632000000003	59.012726999999998	0103000020E61000000100000005000000FD4E93196FDD4C405A63D009A1814D40FD4E93196FDD4C4034F8FBC56C894D40390A100533E64C4034F8FBC56C894D40390A100533E64C405A63D009A1814D40FD4E93196FDD4C405A63D009A1814D40
58219	Ярино	7	71	523	55.063349000000002	55.084082000000002	58.340744000000001	58.320118999999998	0103000020E61000000100000005000000FE9DEDD11B884B4003EACDA8F9284D40FE9DEDD11B884B407427D87F9D2B4D405517F032C38A4B407427D87F9D2B4D405517F032C38A4B4003EACDA8F9284D40FE9DEDD11B884B4003EACDA8F9284D40
7523	Юрич	7	71	523	55.177705000000003	55.193910000000002	58.709752000000002	58.700958999999997	0103000020E61000000100000005000000F8AA9509BF964B401E6B4606B9594D40F8AA9509BF964B40A3224E27D95A4D40062FFA0AD2984B40A3224E27D95A4D40062FFA0AD2984B401E6B4606B9594D40F8AA9509BF964B401E6B4606B9594D40
56354	Шумиха	7	71	523	54.938735000000001	54.958669	58.612501999999999	58.606642999999998	0103000020E61000000100000005000000274EEE7728784B4075AC527AA64D4D40274EEE7728784B40075E2D77664E4D40325871AAB57A4B40075E2D77664E4D40325871AAB57A4B4075AC527AA64D4D40274EEE7728784B4075AC527AA64D4D40
3177	Челва	7	71	523	55.085340000000002	55.103341999999998	58.726709999999997	58.717154999999998	0103000020E610000001000000050000003485CE6BEC8A4B40D9942BBCCB5B4D403485CE6BEC8A4B408CD651D5045D4D40D026874F3A8D4B408CD651D5045D4D40D026874F3A8D4B40D9942BBCCB5B4D403485CE6BEC8A4B40D9942BBCCB5B4D40
58334	Харино	7	71	523	54.872700000000002	54.877155000000002	58.509470999999998	58.507313000000003	0103000020E610000001000000050000000F9C33A2B46F4B40F7EAE3A1EF404D400F9C33A2B46F4B4055A1815836414D40EE42739D46704B4055A1815836414D40EE42739D46704B40F7EAE3A1EF404D400F9C33A2B46F4B40F7EAE3A1EF404D40
33008	Фролово	7	71	523	55.144996999999996	55.182141999999999	58.484701999999999	58.464919000000002	0103000020E610000001000000050000005182FE428F924B40FF243E77823B4D405182FE428F924B40242713B70A3E4D40309DD66D50974B40242713B70A3E4D40309DD66D50974B40FF243E77823B4D405182FE428F924B40FF243E77823B4D40
6544	Сюзьвяки	7	71	523	55.173904999999998	55.206361000000001	58.414634999999997	58.398091000000001	0103000020E6100000010000000500000031CEDF8442964B407DEA58A5F4324D4031CEDF8442964B4073637AC212354D40BE1589096A9A4B4073637AC212354D40BE1589096A9A4B407DEA58A5F4324D4031CEDF8442964B407DEA58A5F4324D40
33001	Старая Пашня	7	71	523	54.951725000000003	54.975825999999998	58.731876999999997	58.719692000000002	0103000020E610000001000000050000008FE4F21FD2794B40AF9811DE1E5C4D408FE4F21FD2794B40E8D84125AE5D4D40124BCADDE77C4B40E8D84125AE5D4D40124BCADDE77C4B40AF9811DE1E5C4D408FE4F21FD2794B40AF9811DE1E5C4D40
58226	Сосновка	7	71	523	54.803691000000001	54.816070000000003	58.506740000000001	58.498840000000001	0103000020E61000000100000005000000768BC058DF664B40E4F736FDD93F4D40768BC058DF664B409BC937DBDC404D40959F54FB74684B409BC937DBDC404D40959F54FB74684B40E4F736FDD93F4D40768BC058DF664B40E4F736FDD93F4D40
26529	Хор	4	37	661	134.914963	135.000698	47.897385	47.869884999999996	0103000020E610000001000000050000009A417C6047DD6040F623456458EF47409A417C6047DD6040E275FD82DDF2474086E5CFB705E06040E275FD82DDF2474086E5CFB705E06040F623456458EF47409A417C6047DD6040F623456458EF4740
58271	Сергино	7	71	523	54.882572000000003	54.890307	58.486804999999997	58.483497	0103000020E61000000100000005000000C32E8A1EF8704B40685BCD3AE33D4D40C32E8A1EF8704B40BF4351A04F3E4D402F336C94F5714B40BF4351A04F3E4D402F336C94F5714B40685BCD3AE33D4D40C32E8A1EF8704B40685BCD3AE33D4D40
56245	Савино	7	71	523	54.958947000000002	54.994672999999999	58.195118999999998	58.176150999999997	0103000020E6100000010000000500000075CC79C6BE7A4B402F14B01D8C164D4075CC79C6BE7A4B4003EACDA8F9184D406B9BE271517F4B4003EACDA8F9184D406B9BE271517F4B402F14B01D8C164D4075CC79C6BE7A4B402F14B01D8C164D40
33000	Рождественск	7	71	523	55.207475000000002	55.256092000000002	58.534748999999998	58.505912000000002	0103000020E610000001000000050000006ADE718A8E9A4B40B55373B9C1404D406ADE718A8E9A4B40CB48BDA772444D403562669FC7A04B40CB48BDA772444D403562669FC7A04B40B55373B9C1404D406ADE718A8E9A4B40B55373B9C1404D40
7313	Обвинск	7	71	523	54.821064999999997	54.861263999999998	58.501657000000002	58.488323999999999	0103000020E61000000100000005000000F3716DA818694B400BED9C66813E4D40F3716DA818694B409D67EC4B36404D406F9C14E63D6E4B409D67EC4B36404D406F9C14E63D6E4B400BED9C66813E4D40F3716DA818694B400BED9C66813E4D40
56324	Новоселы	7	71	523	54.846198999999999	54.851697000000001	58.574862000000003	58.572535000000002	0103000020E610000001000000050000003674B33F506C4B405E68AED348494D403674B33F506C4B4049DBF81395494D40F88C4468046D4B4049DBF81395494D40F88C4468046D4B405E68AED348494D403674B33F506C4B405E68AED348494D40
7137	Нердва	7	71	523	55.035330999999999	55.065775000000002	58.704825	58.682065000000001	0103000020E610000001000000050000007AC4E8B985844B40855FEAE74D574D407AC4E8B985844B409C33A2B4375A4D407CF2B0506B884B409C33A2B4375A4D407CF2B0506B884B40855FEAE74D574D407AC4E8B985844B40855FEAE74D574D40
49150	Менделеево	7	71	523	54.971074000000002	55.019278	58.179112000000003	58.154964	0103000020E610000001000000050000007AFF1F274C7C4B40570740DCD5134D407AFF1F274C7C4B401C295B24ED164D4022C495B377824B401C295B24ED164D4022C495B377824B40570740DCD5134D407AFF1F274C7C4B40570740DCD5134D40
6970	Козьмодемьянск	7	71	523	55.040621999999999	55.077623000000003	58.399963	58.382199	0103000020E61000000100000005000000C2BF081A33854B402EC896E5EB304D40C2BF081A33854B40164ED2FC31334D406E35EB8CEF894B40164ED2FC31334D406E35EB8CEF894B402EC896E5EB304D40C2BF081A33854B402EC896E5EB304D40
32955	Карагай	7	71	523	54.908856999999998	54.954357000000002	58.279874	58.258091	0103000020E61000000100000005000000CEDE196D55744B402B323A2009214D40CEDE196D55744B40178046E9D2234D40B6DAC35E287A4B40178046E9D2234D40B6DAC35E287A4B402B323A2009214D40CEDE196D55744B402B323A2009214D40
6625	Канюсята	7	71	523	54.841250000000002	54.865495000000003	58.439680000000003	58.431224	0103000020E6100000010000000500000048E17A14AE6B4B400AA0185932374D4048E17A14AE6B4B40475A2A6F47384D40FFEC478AC86E4B40475A2A6F47384D40FFEC478AC86E4B400AA0185932374D4048E17A14AE6B4B400AA0185932374D40
32966	Кадилово	7	71	523	55.087837	55.107205	58.190213999999997	58.175846999999997	0103000020E610000001000000050000007B30293E3E8B4B40C30C8D2782164D407B30293E3E8B4B40E49EAEEE58184D40DD7BB8E4B88D4B40E49EAEEE58184D40DD7BB8E4B88D4B40C30C8D2782164D407B30293E3E8B4B40C30C8D2782164D40
7332	Воскресенск	7	71	523	55.209586000000002	55.242967	58.591849000000003	58.572947999999997	0103000020E6100000010000000500000088D9CBB6D39A4B4080272D5C56494D4088D9CBB6D39A4B40CD9541B5C14B4D40ED80EB8A199F4B40CD9541B5C14B4D40ED80EB8A199F4B4080272D5C56494D4088D9CBB6D39A4B4080272D5C56494D40
56338	Ванькино	7	71	523	54.868665999999997	54.872152	58.781573999999999	58.779069	0103000020E61000000100000005000000D5928E72306F4B40E9297288B8634D40D5928E72306F4B40B3B3E89D0A644D400C923EADA26F4B40B3B3E89D0A644D400C923EADA26F4B40E9297288B8634D40D5928E72306F4B40E9297288B8634D40
6380	Антонята	7	71	523	54.757562999999998	54.766078999999998	58.570366999999997	58.564627000000002	0103000020E610000001000000050000006FD40AD3F7604B4024B891B245484D406FD40AD3F7604B40DBDB2DC901494D4081936DE00E624B40DBDB2DC901494D4081936DE00E624B4024B891B245484D406FD40AD3F7604B4024B891B245484D40
6093	Чермоз	7	71	717	56.118124000000002	56.179506000000003	58.80301	58.771614	0103000020E61000000100000005000000B56FEEAF1E0F4C4060915F3FC4624D40B56FEEAF1E0F4C40342E1C08C9664D40C8B7770DFA164C40342E1C08C9664D40C8B7770DFA164C4060915F3FC4624D40B56FEEAF1E0F4C4060915F3FC4624D40
48689	Сретенское	7	71	717	55.527805000000001	55.581820999999998	58.612751000000003	58.594076999999999	0103000020E6100000010000000500000028D53E1D8FC34B40242713B70A4C4D4028D53E1D8FC34B40B0CBF09F6E4E4D4021904B1C79CA4B40B0CBF09F6E4E4D4021904B1C79CA4B40242713B70A4C4D4028D53E1D8FC34B40242713B70A4C4D40
5104	Слудка	7	71	717	55.999186999999999	56.024160000000002	58.639349000000003	58.626088000000003	0103000020E610000001000000050000004FCB0F5CE5FF4B408335CEA623504D404FCB0F5CE5FF4B407BDD2230D6514D4089EFC4AC17034C407BDD2230D6514D4089EFC4AC17034C408335CEA623504D404FCB0F5CE5FF4B408335CEA623504D40
11108	Сенино	7	71	717	55.612569999999998	55.621912999999999	58.769140999999998	58.764651999999998	0103000020E610000001000000050000005F419AB168CE4B401669E21DE0614D405F419AB168CE4B40A181583673624D4087FA5DD89ACF4B40A181583673624D4087FA5DD89ACF4B401669E21DE0614D405F419AB168CE4B401669E21DE0614D40
32732	Садки	7	71	717	55.495547000000002	55.528092999999998	58.449711999999998	58.433014	0103000020E61000000100000005000000C25087156EBF4B40E65AB4006D374D40C25087156EBF4B40334FAE2990394D408E1F2A8D98C34B40334FAE2990394D408E1F2A8D98C34B40E65AB4006D374D40C25087156EBF4B40E65AB4006D374D40
6064	Романово	7	71	717	56.059752000000003	56.073954000000001	58.844420999999997	58.837054999999999	0103000020E6100000010000000500000070EF1AF4A5074C4005FA449E246B4D4070EF1AF4A5074C401E87C1FC156C4D4046B41D5377094C401E87C1FC156C4D4046B41D5377094C4005FA449E246B4D4070EF1AF4A5074C4005FA449E246B4D40
5465	Посер	7	71	717	55.514052	55.541198999999999	58.563730999999997	58.545414999999998	0103000020E61000000100000005000000C138B874CCC14B40B9DFA128D0454D40C138B874CCC14B40E55E605628484D405FD0420246C54B40E55E605628484D405FD0420246C54B40B9DFA128D0454D40C138B874CCC14B40B9DFA128D0454D40
4996	Пепеляева	7	71	717	55.649104999999999	55.665930000000003	58.554684999999999	58.540849999999999	0103000020E61000000100000005000000C55565DF15D34B405305A3923A454D40C55565DF15D34B40774A07EBFF464D4070B6B9313DD54B40774A07EBFF464D4070B6B9313DD54B405305A3923A454D40C55565DF15D34B405305A3923A454D40
32662	Новая Каменка	7	71	717	55.828327999999999	55.848233999999998	58.578747	58.570014999999998	0103000020E61000000100000005000000382EE3A606EA4B405E9D6340F6484D40382EE3A606EA4B403DD4B661144A4D4079AD84EE92EC4B403DD4B661144A4D4079AD84EE92EC4B405E9D6340F6484D40382EE3A606EA4B405E9D6340F6484D40
56345	Мосино	7	71	717	55.361293000000003	55.371659999999999	58.77684	58.770195999999999	0103000020E610000001000000050000000AA359D93EAE4B4048C153C895624D400AA359D93EAE4B40C11C3D7E6F634D409D9D0C8E92AF4B40C11C3D7E6F634D409D9D0C8E92AF4B4048C153C895624D400AA359D93EAE4B4048C153C895624D40
5293	Мартыновцы	7	71	717	55.892071999999999	55.912401000000003	58.376277000000002	58.369546999999997	0103000020E61000000100000005000000B2D6506A2FF24B40DEAAEB504D2F4D40B2D6506A2FF24B40569E40D829304D403AEB538EC9F44B40569E40D829304D403AEB538EC9F44B40DEAAEB504D2F4D40B2D6506A2FF24B40DEAAEB504D2F4D40
5997	Кыласово	7	71	717	56.088920000000002	56.121969	58.893389999999997	58.880071999999998	0103000020E61000000100000005000000ECFA05BB610B4C400A100533A6704D40ECFA05BB610B4C406649809A5A724D401B1021AE9C0F4C406649809A5A724D401B1021AE9C0F4C400A100533A6704D40ECFA05BB610B4C400A100533A6704D40
56273	Кривец	7	71	717	55.370114999999998	55.407215000000001	58.589640000000003	58.571047	0103000020E610000001000000050000002861A6ED5FAF4B404DBD6E1118494D402861A6ED5FAF4B40EC34D252794B4D4067B8019F1FB44B40EC34D252794B4D4067B8019F1FB44B404DBD6E1118494D402861A6ED5FAF4B404DBD6E1118494D40
56325	Комариха	7	71	717	56.038659000000003	56.055124999999997	58.407767	58.397987000000001	0103000020E61000000100000005000000195932C7F2044C40D89DEE3CF1324D40195932C7F2044C40ABB184B531344D40931804560E074C40ABB184B531344D40931804560E074C40D89DEE3CF1324D40195932C7F2044C40D89DEE3CF1324D40
56327	Каргино	7	71	717	55.359245000000001	55.392752000000002	58.776415	58.761941	0103000020E6100000010000000500000032207BBDFBAD4B40A33D5E4887614D4032207BBDFBAD4B40DA8F149161634D4024B891B245B24B40DA8F149161634D4024B891B245B24B40A33D5E4887614D4032207BBDFBAD4B40A33D5E4887614D40
58241	Ильята	7	71	717	55.350109000000003	55.367384000000001	58.666390999999997	58.65916	0103000020E610000001000000050000008484285FD0AC4B406A6AD95A5F544D408484285FD0AC4B40A3ACDF4C4C554D406E895C7006AF4B40A3ACDF4C4C554D406E895C7006AF4B406A6AD95A5F544D408484285FD0AC4B406A6AD95A5F544D40
32643	Ильинский	7	71	717	55.639887999999999	55.733313000000003	58.586013999999999	58.544424999999997	0103000020E610000001000000050000002A8D98D9E7D14B40F90FE9B7AF454D402A8D98D9E7D14B40C37FBA81024B4D40A75D4C33DDDD4B40C37FBA81024B4D40A75D4C33DDDD4B40F90FE9B7AF454D402A8D98D9E7D14B40F90FE9B7AF454D40
32791	Ивановское	7	71	717	55.618149000000003	55.647163999999997	58.787880000000001	58.771624000000003	0103000020E610000001000000050000000E87A5811FCF4B4084674293C4624D400E87A5811FCF4B4014967840D9644D4003931B45D6D24B4014967840D9644D4003931B45D6D24B4084674293C4624D400E87A5811FCF4B4084674293C4624D40
47761	Ерши	7	71	717	55.511293999999999	55.533096	58.596051000000003	58.586694000000001	0103000020E610000001000000050000000D52F01472C14B403561FBC9184B4D400D52F01472C14B40C2DF2F664B4C4D4070D05E7D3CC44B40C2DF2F664B4C4D4070D05E7D3CC44B403561FBC9184B4D400D52F01472C14B403561FBC9184B4D40
5942	Ерема	7	71	717	55.783043999999997	55.800237000000003	58.783042999999999	58.776093000000003	0103000020E610000001000000050000001DAA29C93AE44B40C8D3F20357634D401DAA29C93AE44B404D2EC6C03A644D404B06802A6EE64B404D2EC6C03A644D404B06802A6EE64B40C8D3F20357634D401DAA29C93AE44B40C8D3F20357634D40
32763	Дмитриевское	7	71	717	55.721383000000003	55.764780999999999	58.631213000000002	58.616908000000002	0103000020E61000000100000005000000F871344756DC4B40055262D7F64E4D40F871344756DC4B40B0E76B96CB504D4014CD0358E4E14B40B0E76B96CB504D4014CD0358E4E14B40055262D7F64E4D40F871344756DC4B40055262D7F64E4D40
58225	Гари	7	71	717	55.97831	55.990032999999997	58.571122000000003	58.560726000000003	0103000020E61000000100000005000000C5AC174339FD4B402A029CDEC5474D40C5AC174339FD4B40580394861A494D40FA7ABE66B9FE4B40580394861A494D40FA7ABE66B9FE4B402A029CDEC5474D40C5AC174339FD4B402A029CDEC5474D40
32725	Васильевское	7	71	717	55.795161999999998	55.847586999999997	58.440109	58.423698999999999	0103000020E61000000100000005000000CF8250DEC7E54B40882CD2C43B364D40CF8250DEC7E54B406FD6E07D55384D40E3C116BB7DEC4B406FD6E07D55384D40E3C116BB7DEC4B40882CD2C43B364D40CF8250DEC7E54B40882CD2C43B364D40
58262	Бор	7	71	717	55.907352000000003	55.921429000000003	58.588827999999999	58.581280999999997	0103000020E61000000100000005000000E8FA3E1C24F44B40A164726A674A4D40E8FA3E1C24F44B400B7C45B75E4B4D40024BAE62F1F54B400B7C45B75E4B4D40024BAE62F1F54B40A164726A674A4D40E8FA3E1C24F44B40A164726A674A4D40
56296	Березовка	7	71	717	55.846015000000001	55.855915000000003	58.599975999999998	58.593682999999999	0103000020E61000000100000005000000757632384AEC4B407898F6CDFD4B4D40757632384AEC4B4044317903CC4C4D40F3936A9F8EED4B4044317903CC4C4D40F3936A9F8EED4B407898F6CDFD4B4D40757632384AEC4B407898F6CDFD4B4D40
4812	Ятыш	7	71	582	55.254815999999998	55.280031999999999	56.834175999999999	56.820177999999999	0103000020E61000000100000005000000AF3F89CF9DA04B400873BB97FB684C40AF3F89CF9DA04B40D68D7747C66A4C40AFEAAC16D8A34B40D68D7747C66A4C40AFEAAC16D8A34B400873BB97FB684C40AF3F89CF9DA04B400873BB97FB684C40
48374	Шумово	7	71	582	54.893334000000003	54.935141999999999	56.770164000000001	56.748617000000003	0103000020E61000000100000005000000D333BDC458724B40651D8EAED25F4C40D333BDC458724B403D47E4BB94624C40DA8EA9BBB2774B403D47E4BB94624C40DA8EA9BBB2774B40651D8EAED25F4C40D333BDC458724B40651D8EAED25F4C40
4427	Шульдиха	7	71	582	54.608199999999997	54.630011000000003	57.035592999999999	57.011533	0103000020E61000000100000005000000AEB6627FD94D4B4092E9D0E979814C40AEB6627FD94D4B40B77BB94F8E844C40658F5033A4504B40B77BB94F8E844C40658F5033A4504B4092E9D0E979814C40AEB6627FD94D4B4092E9D0E979814C40
4145	Суганка	7	71	582	55.161490000000001	55.210673	56.831428000000002	56.812649999999998	0103000020E61000000100000005000000C6504EB4AB944B40158C4AEA04684C40C6504EB4AB944B40467D923B6C6A4C403A933655F79A4B40467D923B6C6A4C403A933655F79A4B40158C4AEA04684C40C6504EB4AB944B40158C4AEA04684C40
4751	Плишкино	7	71	582	54.412942000000001	54.434403000000003	56.964818999999999	56.952843999999999	0103000020E610000001000000050000008A929048DB344B404C18CDCAF6794C408A929048DB344B409BC761307F7B4C4064247B849A374B409BC761307F7B4C4064247B849A374B404C18CDCAF6794C408A929048DB344B404C18CDCAF6794C40
4411	Плишкари	7	71	582	55.051977000000001	55.084629999999997	57.013033	56.990105999999997	0103000020E610000001000000050000007592AD2EA7864B4064C91CCBBB7E4C407592AD2EA7864B406762BA10AB814C405721E527D58A4B406762BA10AB814C405721E527D58A4B4064C91CCBBB7E4C407592AD2EA7864B4064C91CCBBB7E4C40
32593	Осиновик	7	71	582	54.714174	54.739462000000003	56.944253000000003	56.927374	0103000020E61000000100000005000000A6D3BA0D6A5B4B409294F430B4764C40A6D3BA0D6A5B4B4030134548DD784C404051D9B0A65E4B4030134548DD784C404051D9B0A65E4B409294F430B4764C40A6D3BA0D6A5B4B409294F430B4764C40
4256	Нижняя Барда	7	71	582	55.046182000000002	55.070976000000002	56.892881000000003	56.864353999999999	0103000020E61000000100000005000000FAD4B14AE9854B405915E126A36E4C40FAD4B14AE9854B40221CB3EC49724C408466D7BD15894B40221CB3EC49724C408466D7BD15894B405915E126A36E4C40FAD4B14AE9854B405915E126A36E4C40
27748	Неволино	7	71	582	54.946747999999999	54.957636000000001	57.055320999999999	57.045642000000001	0103000020E61000000100000005000000D6C6D8092F794B407AA9D898D7854C40D6C6D8092F794B4019E42EC214874C4073BC02D1937A4B4019E42EC214874C4073BC02D1937A4B407AA9D898D7854C40D6C6D8092F794B407AA9D898D7854C40
4247	Мичура	7	71	582	54.949334999999998	54.972043999999997	56.912905000000002	56.883076000000003	0103000020E610000001000000050000005DF92CCF83794B40F6F065A208714C405DF92CCF83794B406DAD2F12DA744C40F22213F06B7C4B406DAD2F12DA744C40F22213F06B7C4B40F6F065A208714C405DF92CCF83794B40F6F065A208714C40
4165	Малая Уса	7	71	582	54.888464999999997	54.92456	56.812157999999997	56.789402000000003	0103000020E6100000010000000500000000529B38B9714B40D1B2EE1F0B654C4000529B38B9714B40A69718CBF4674C404A9869FB57764B40A69718CBF4674C404A9869FB57764B40D1B2EE1F0B654C4000529B38B9714B40D1B2EE1F0B654C40
4535	Куштомак	7	71	582	55.21096	55.248626999999999	56.831786999999998	56.818080000000002	0103000020E61000000100000005000000D061BEBC009B4B407FC16ED8B6684C40D061BEBC009B4B40751E15FF776A4C4088F37002D39F4B40751E15FF776A4C4088F37002D39F4B407FC16ED8B6684C40D061BEBC009B4B407FC16ED8B6684C40
32562	Крюково	7	71	582	55.042831999999997	55.072853000000002	57.131262999999997	57.100943999999998	0103000020E61000000100000005000000739CDB847B854B401C5DA5BBEB8C4C40739CDB847B854B406116DA39CD904C402F35423F53894B406116DA39CD904C402F35423F53894B401C5DA5BBEB8C4C40739CDB847B854B401C5DA5BBEB8C4C40
32606	Кресты	7	71	582	54.977604999999997	54.997188000000001	57.020021	57.001494999999998	0103000020E61000000100000005000000FAB31F29227D4B40C30DF8FC30804C40FAB31F29227D4B40DA1D520C90824C4059FB3BDBA37F4B40DA1D520C90824C4059FB3BDBA37F4B40C30DF8FC30804C40FAB31F29227D4B40C30DF8FC30804C40
48037	Елово	7	71	582	54.892147999999999	54.950933999999997	57.063563000000002	57.033135000000001	0103000020E610000001000000050000008D98D9E731724B402EAD86C43D844C408D98D9E731724B402A1E17D522884C40C5538F34B8794B402A1E17D522884C40C5538F34B8794B402EAD86C43D844C408D98D9E731724B402EAD86C43D844C40
56295	Дуброво	7	71	582	54.531609000000003	54.564892	57.015237999999997	56.982121999999997	0103000020E6100000010000000500000030A182C30B444B404F57772CB67D4C4030A182C30B444B4006D49B51F3814C40D2E28C614E484B4006D49B51F3814C40D2E28C614E484B404F57772CB67D4C4030A182C30B444B404F57772CB67D4C40
56288	Городище	7	71	582	54.768881999999998	54.794241	56.821513000000003	56.80791	0103000020E61000000100000005000000D53DB2B96A624B40410E4A9869674C40D53DB2B96A624B40931E865627694C40381268B0A9654B40931E865627694C40381268B0A9654B40410E4A9869674C40D53DB2B96A624B40410E4A9869674C40
3647	Брюхово	7	71	582	54.825242000000003	54.870409000000002	56.870911999999997	56.852567999999998	0103000020E6100000010000000500000090A4A487A1694B40DDCEBEF2206D4C4090A4A487A1694B40D3D85E0B7A6F4C407192E68F696F4B40D3D85E0B7A6F4C407192E68F696F4B40DDCEBEF2206D4C4090A4A487A1694B40DDCEBEF2206D4C40
56275	Ярино	7	71	404	56.561892	56.569420000000001	58.469748000000003	58.463459999999998	0103000020E6100000010000000500000028F1B913EC474C40888043A8523B4D4028F1B913EC474C4043AED4B3203C4D401BD82AC1E2484C4043AED4B3203C4D401BD82AC1E2484C40888043A8523B4D4028F1B913EC474C40888043A8523B4D40
3496	Усть-Гаревая	7	71	404	56.111305999999999	56.134670999999997	58.526029000000001	58.510468000000003	0103000020E610000001000000050000009EEC66463F0E4C40C8D3F20357414D409EEC66463F0E4C40B1DF13EB54434D401C5C3AE63C114C40B1DF13EB54434D401C5C3AE63C114C40C8D3F20357414D409EEC66463F0E4C40C8D3F20357414D40
3122	Таборы	7	71	404	56.958838999999998	56.979950000000002	58.691339999999997	58.681452999999998	0103000020E610000001000000050000008E90813CBB7A4C406B6116DA39574D408E90813CBB7A4C40543541D47D584D408CDB68006F7D4C40543541D47D584D408CDB68006F7D4C406B6116DA39574D408E90813CBB7A4C406B6116DA39574D40
56234	Родники	7	71	404	56.752712000000002	56.763052000000002	58.489204000000001	58.482387000000003	0103000020E6100000010000000500000044A7E7DD58604C40FE8172DBBE3D4D4044A7E7DD58604C404489963C9E3E4D40DE921CB0AB614C404489963C9E3E4D40DE921CB0AB614C40FE8172DBBE3D4D4044A7E7DD58604C40FE8172DBBE3D4D40
2132	Полазна	7	71	404	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
2962	Перемское	7	71	404	56.811326999999999	56.845148999999999	58.727513000000002	58.715496000000002	0103000020E610000001000000050000004FAE2990D9674C409C35785F955B4D404FAE2990D9674C401A355F251F5D4D40A19FA9D72D6C4C401A355F251F5D4D40A19FA9D72D6C4C409C35785F955B4D404FAE2990D9674C409C35785F955B4D40
2871	Кыж	7	71	404	56.798490000000001	56.815072999999998	58.590178999999999	58.579597	0103000020E610000001000000050000006E179AEB34664C400BEE073C304A4D406E179AEB34664C409BE447FC8A4B4D40226DE34F54684C409BE447FC8A4B4D40226DE34F54684C400BEE073C304A4D406E179AEB34664C400BEE073C304A4D40
2478	Дивья	7	71	404	56.583019999999998	56.618099000000001	58.293542000000002	58.274673	0103000020E61000000100000005000000FB743C66A04A4C400F0C207C28234D40FB743C66A04A4C405000C5C892254D405C5837DE1D4F4C405000C5C892254D405C5837DE1D4F4C400F0C207C28234D40FB743C66A04A4C400F0C207C28234D40
3318	Висим	7	71	404	56.215797999999999	56.244086000000003	58.670546999999999	58.653851000000003	0103000020E610000001000000050000006745D4449F1B4C407CBABA63B1534D406745D4449F1B4C4028B7ED7BD4554D40ABB4C5353E1F4C4028B7ED7BD4554D40ABB4C5353E1F4C407CBABA63B1534D406745D4449F1B4C407CBABA63B1534D40
2810	Вильва	7	71	404	56.958381000000003	56.991089000000002	58.634815000000003	58.619818000000002	0103000020E61000000100000005000000CC0D863AAC7A4C406FBC3B32564F4D40CC0D863AAC7A4C405001309E41514D4072361D01DC7E4C405001309E41514D4072361D01DC7E4C406FBC3B32564F4D40CC0D863AAC7A4C406FBC3B32564F4D40
10959	Березниковский	7	71	404	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
56285	Широковский	7	71	222	57.769174	57.794074999999999	58.864612999999999	58.835169	0103000020E610000001000000050000007D772B4B74E24C4007D15AD1E66A4D407D772B4B74E24C40255987A3AB6E4D401DC9E53FA4E54C40255987A3AB6E4D401DC9E53FA4E54C4007D15AD1E66A4D407D772B4B74E24C4007D15AD1E66A4D40
56456	Шестаки	7	71	222	57.337893000000001	57.383581	58.858041999999998	58.822108	0103000020E610000001000000050000000F46EC1340AB4C40D6E3BED53A694D400F46EC1340AB4C40164CFC51D46D4D40F92EA52E19B14C40164CFC51D46D4D40F92EA52E19B14C40D6E3BED53A694D400F46EC1340AB4C40D6E3BED53A694D40
842	Углеуральский	7	71	222	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
58231	20-й километр	7	71	222	57.772452999999999	57.790320000000001	58.876235000000001	58.863909999999997	0103000020E610000001000000050000003A596ABDDFE24C40FB57569A946E4D403A596ABDDFE24C40274EEE7728704D40F7AFAC3429E54C40274EEE7728704D40F7AFAC3429E54C40FB57569A946E4D403A596ABDDFE24C40FB57569A946E4D40
56239	Шумихинский	7	71	7406	57.644748	57.714179000000001	58.763896000000003	58.731568000000003	0103000020E61000000100000005000000A9143B1A87D24C406B662D05A45D4D40A9143B1A87D24C40CAC51858C7614D40B83EAC376ADB4C40CAC51858C7614D40B83EAC376ADB4C406B662D05A45D4D40A9143B1A87D24C406B662D05A45D4D40
31675	Теплая Гора	7	71	1842	59.050117	59.092626000000003	58.546204000000003	58.509211999999998	0103000020E61000000100000005000000A0FCDD3B6A864D40895DDBDB2D414D40A0FCDD3B6A864D40E2783E03EA454D403161342BDB8B4D40E2783E03EA454D403161342BDB8B4D40895DDBDB2D414D40A0FCDD3B6A864D40895DDBDB2D414D40
31827	Старый Бисер	7	71	1842	58.866627999999999	58.903934999999997	58.426220000000001	58.404674	0103000020E6100000010000000500000021E692AAED6E4D4050C58D5BCC334D4021E692AAED6E4D40587380608E364D40D95A5F24B4734D40587380608E364D40D95A5F24B4734D4050C58D5BCC334D4021E692AAED6E4D4050C58D5BCC334D40
31755	Сараны	7	71	1842	58.750179000000003	58.773966000000001	58.554732000000001	58.531761000000003	0103000020E61000000100000005000000B0928FDD05604D40E62494BE10444D40B0928FDD05604D40B8054B7501474D40A41B615111634D40B8054B7501474D40A41B615111634D40E62494BE10444D40B0928FDD05604D40E62494BE10444D40
31891	Промысла	7	71	1842	59.134369999999997	59.174892999999997	58.570084999999999	58.555055000000003	0103000020E6100000010000000500000021C8410933914D409B3DD00A0C474D4021C8410933914D405778978BF8484D4050A6D1E462964D405778978BF8484D4050A6D1E462964D409B3DD00A0C474D4021C8410933914D409B3DD00A0C474D40
31444	Пашия	7	71	1842	58.235892999999997	58.307875000000003	58.446722000000001	58.416983000000002	0103000020E610000001000000050000007B2DE8BD311E4D4076FEEDB25F354D407B2DE8BD311E4D40AD33BE2F2E394D40C520B07268274D40AD33BE2F2E394D40C520B07268274D4076FEEDB25F354D407B2DE8BD311E4D4076FEEDB25F354D40
32691	Медведка	7	71	1842	59.093874	59.114337999999996	58.747269000000003	58.732880999999999	0103000020E61000000100000005000000ECF82F10048C4D400D6E6B0BCF5D4D40ECF82F10048C4D404628B682A65F4D405358A9A0A28E4D404628B682A65F4D405358A9A0A28E4D400D6E6B0BCF5D4D40ECF82F10048C4D400D6E6B0BCF5D4D40
56256	Кусье-Александровский	7	71	1842	58.354956000000001	58.410516999999999	58.298754000000002	58.263758000000003	0103000020E610000001000000050000006EC2BD326F2D4D40790778D2C2214D406EC2BD326F2D4D404CC631923D264D40DCB930D28B344D404CC631923D264D40DCB930D28B344D40790778D2C2214D406EC2BD326F2D4D40790778D2C2214D40
31256	Горнозаводск	7	71	1842	58.295470000000002	58.344706000000002	58.397803000000003	58.366931999999998	0103000020E610000001000000050000007D7901F6D1254D408DEDB5A0F72E4D407D7901F6D1254D4017A06D35EB324D40145E82531F2C4D4017A06D35EB324D40145E82531F2C4D408DEDB5A0F72E4D407D7901F6D1254D408DEDB5A0F72E4D40
28242	Вильва	7	71	1842	58.237186999999999	58.270577000000003	58.644734999999997	58.634515999999998	0103000020E61000000100000005000000A704C4245C1E4D40F564FED137514D40A704C4245C1E4D4014CB2DAD86524D4060066344A2224D4014CB2DAD86524D4060066344A2224D40F564FED137514D40A704C4245C1E4D40F564FED137514D40
56308	Бисер	7	71	1842	58.850870999999998	58.890324999999997	58.520370999999997	58.506118999999998	0103000020E61000000100000005000000B20E4757E96C4D402E71E481C8404D40B20E4757E96C4D40B66455849B424D40D5E76A2BF6714D40B66455849B424D40D5E76A2BF6714D402E71E481C8404D40B20E4757E96C4D402E71E481C8404D40
56356	разрушенный Камский	7	71	951	53.981005000000003	54.112805999999999	60.412492	60.347242000000001	0103000020E61000000100000005000000331B649291FD4A4019E6046D722C4E40331B649291FD4A404AEEB089CC344E407365506D700E4B404AEEB089CC344E407365506D700E4B4019E6046D722C4E40331B649291FD4A4019E6046D722C4E40
29637	Шордын	7	71	951	54.266947999999999	54.282156000000001	60.399813999999999	60.393284999999999	0103000020E61000000100000005000000C6DD205A2B224B40F180B22957324E40C6DD205A2B224B40D13DEB1A2D334E40622F14B01D244B40D13DEB1A2D334E40622F14B01D244B40F180B22957324E40C6DD205A2B224B40F180B22957324E40
48442	Чуртан	7	71	951	53.870243000000002	53.883178999999998	60.185977999999999	60.175046999999999	0103000020E610000001000000050000005649641F64EF4A40A721AAF067164E405649641F64EF4A4043E38920CE174E40CAC16C020CF14A4043E38920CE174E40CAC16C020CF14A40A721AAF067164E405649641F64EF4A40A721AAF067164E40
29104	Чажегово	7	71	951	54.386234999999999	54.402799999999999	60.172496000000002	60.161698999999999	0103000020E6100000010000000500000008C9022670314B40E065868DB2144E4008C9022670314B406D58535914164E40166A4DF38E334B406D58535914164E40166A4DF38E334B40E065868DB2144E4008C9022670314B40E065868DB2144E40
48698	Усть-Черная	7	71	951	52.639847000000003	52.677306999999999	60.488098999999998	60.469549000000001	0103000020E61000000100000005000000CCB8A981E6514A404C6F7F2E1A3C4E40CCB8A981E6514A40EB1A2D077A3E4E400A2DEBFEB1564A40EB1A2D077A3E4E400A2DEBFEB1564A404C6F7F2E1A3C4E40CCB8A981E6514A404C6F7F2E1A3C4E40
8889	Усть-Весляна	7	71	951	53.98997	54.007002	60.323025000000001	60.314787000000003	0103000020E61000000100000005000000B4024356B7FE4A405D1ABFF04A284E40B4024356B7FE4A402C6519E258294E40D8800871E5004B402C6519E258294E40D8800871E5004B405D1ABFF04A284E40B4024356B7FE4A405D1ABFF04A284E40
7772	Сосновая	7	71	951	53.832495999999999	53.847417	60.356701000000001	60.348292999999998	0103000020E6100000010000000500000081069B3A8FEA4A407E3672DD942C4E4081069B3A8FEA4A40AAB9DC60A82D4E408789062978EC4A40AAB9DC60A82D4E408789062978EC4A407E3672DD942C4E4081069B3A8FEA4A407E3672DD942C4E40
48727	Сергеевский	7	71	951	54.313533999999997	54.352440999999999	60.029463	60.014890999999999	0103000020E610000001000000050000008F17D2E121284B409B00C3F2E7014E408F17D2E121284B4095B88E71C5034E40806264C91C2D4B4095B88E71C5034E40806264C91C2D4B409B00C3F2E7014E408F17D2E121284B409B00C3F2E7014E40
29785	Сейва	7	71	951	53.740507999999998	53.772021000000002	60.189714000000002	60.176931000000003	0103000020E61000000100000005000000933655F7C8DE4A400553CDACA5164E40933655F7C8DE4A40F3CB608C48184E40A1698995D1E24A40F3CB608C48184E40A1698995D1E24A400553CDACA5164E40933655F7C8DE4A400553CDACA5164E40
26717	Пурга	7	71	951	53.951756000000003	53.957658000000002	60.676993000000003	60.671965	0103000020E61000000100000005000000CAE2FE23D3F94A404087F9F202564E40CAE2FE23D3F94A407B4FE5B4A7564E405B608F8994FA4A407B4FE5B4A7564E405B608F8994FA4A404087F9F202564E40CAE2FE23D3F94A404087F9F202564E40
8032	Оныл	7	71	951	53.636887000000002	53.661681000000002	60.412011999999997	60.403978000000002	0103000020E61000000100000005000000B01F628385D14A40D926158DB5334E40B01F628385D14A409FC728CFBC344E403AB187F6B1D44A409FC728CFBC344E403AB187F6B1D44A40D926158DB5334E40B01F628385D14A40D926158DB5334E40
29509	Луным	7	71	951	54.672024999999998	54.694474	60.408546000000001	60.396307	0103000020E61000000100000005000000158C4AEA04564B4083161230BA324E40158C4AEA04564B40B0743E3C4B344E400EF62686E4584B40B0743E3C4B344E400EF62686E4584B4083161230BA324E40158C4AEA04564B4083161230BA324E40
48800	Лель	7	71	951	54.565987999999997	54.581125	60.654392999999999	60.646856999999997	0103000020E61000000100000005000000D7F6764B72484B402618CE35CC524E40D7F6764B72484B409CDD5A26C3534E40AAF1D24D624A4B409CDD5A26C3534E40AAF1D24D624A4B402618CE35CC524E40D7F6764B72484B402618CE35CC524E40
58347	Керосс	7	71	951	52.838061000000003	52.870094999999999	60.783154000000003	60.759464000000001	0103000020E61000000100000005000000CB863595456B4A40A33EC91D36614E40CB863595456B4A40A5DDE8633E644E40E1B4E0455F6F4A40A5DDE8633E644E40E1B4E0455F6F4A40A33EC91D36614E40CB863595456B4A40A33EC91D36614E40
7946	Кебраты	7	71	951	54.198639999999997	54.231231000000001	60.379866	60.356599000000003	0103000020E61000000100000005000000B6D617096D194B40A6643909A52D4E40B6D617096D194B40616EF7729F304E40236937FA981D4B40616EF7729F304E40236937FA981D4B40A6643909A52D4E40B6D617096D194B40A6643909A52D4E40
48760	Касимовка	7	71	951	54.642910999999998	54.681519999999999	60.217475999999998	60.208486999999998	0103000020E610000001000000050000008C9E5BE84A524B401152B7B3AF1A4E408C9E5BE84A524B401BD5E940D61B4E40F3C81F0C3C574B401BD5E940D61B4E40F3C81F0C3C574B401152B7B3AF1A4E408C9E5BE84A524B401152B7B3AF1A4E40
56389	Имасы	7	71	951	54.439900000000002	54.45722	60.054611999999999	60.048171000000004	0103000020E6100000010000000500000055C1A8A44E384B40CDCEA2772A064E4055C1A8A44E384B400DFCA886FD064E40DF89592F863A4B400DFCA886FD064E40DF89592F863A4B40CDCEA2772A064E4055C1A8A44E384B40CDCEA2772A064E40
48396	Иванчино	7	71	951	54.233324000000003	54.262034	60.073076999999998	60.062831000000003	0103000020E610000001000000050000009BAF928FDD1D4B406616A1D80A084E409BAF928FDD1D4B407E8B4E965A094E40543882548A214B407E8B4E965A094E40543882548A214B406616A1D80A084E409BAF928FDD1D4B406616A1D80A084E40
48864	Жемчужный	7	71	951	53.936467	53.961089000000001	60.577278999999997	60.555059999999997	0103000020E6100000010000000500000041649126DEF74A40ACA8C1340C474E4041649126DEF74A4073D53C47E4494E40CEC5DFF604FB4A4073D53C47E4494E40CEC5DFF604FB4A40ACA8C1340C474E4041649126DEF74A40ACA8C1340C474E40
48358	Данилово	7	71	951	54.329911000000003	54.359411000000001	60.271940000000001	60.257314999999998	0103000020E610000001000000050000009BCB0D863A2A4B4097E2AAB2EF204E409BCB0D863A2A4B40B43C0FEECE224E404D69FD2D012E4B40B43C0FEECE224E404D69FD2D012E4B4097E2AAB2EF204E409BCB0D863A2A4B4097E2AAB2EF204E40
56253	Гаины	7	71	951	54.262905000000003	54.382317999999998	60.339545000000001	60.277566	0103000020E610000001000000050000003A7AFCDEA6214B40A33D5E4887234E403A7AFCDEA6214B409A42E735762B4E400856D5CBEF304B409A42E735762B4E400856D5CBEF304B40A33D5E4887234E403A7AFCDEA6214B40A33D5E4887234E40
56550	Верхняя Старица	7	71	951	54.651535000000003	54.707940000000001	60.243910999999997	60.227339000000001	0103000020E610000001000000050000008599B67F65534B407C0DC171191D4E408599B67F65534B403C11C479381F4E40DFC325C79D5A4B403C11C479381F4E40DFC325C79D5A4B407C0DC171191D4E408599B67F65534B407C0DC171191D4E40
29669	Верхний Будым	7	71	951	54.159742999999999	54.182209999999998	60.562927999999999	60.549990999999999	0103000020E61000000100000005000000E961687572144B40130CE71A66464E40E961687572144B40580053060E484E40888043A852174B40580053060E484E40888043A852174B40130CE71A66464E40E961687572144B40130CE71A66464E40
48999	Базуево	7	71	951	54.184078	54.210273000000001	60.215031000000003	60.202178000000004	0103000020E61000000100000005000000E0F42EDE8F174B4040FCFCF7E0194E40E0F42EDE8F174B402750C422861B4E40AC1DC539EA1A4B402750C422861B4E40AC1DC539EA1A4B4040FCFCF7E0194E40E0F42EDE8F174B4040FCFCF7E0194E40
56339	Федяшино	7	71	1129	54.167566999999998	54.206643999999997	58.007823000000002	58.002654	0103000020E61000000100000005000000C571E0D572154B400F9A5DF756004D40C571E0D572154B400C94145800014D4012F5824F731A4B400C94145800014D4012F5824F731A4B400F9A5DF756004D40C571E0D572154B400F9A5DF756004D40
33099	Субботники	7	71	1129	54.594608000000001	54.623462000000004	58.036349999999999	58.023598	0103000020E6100000010000000500000051F86C1D1C4C4B4021205F4205034D4051F86C1D1C4C4B40D49AE61DA7044D403E26529ACD4F4B40D49AE61DA7044D403E26529ACD4F4B4021205F4205034D4051F86C1D1C4C4B4021205F4205034D40
30749	Соболята	7	71	1129	54.820571000000001	54.846693999999999	58.11985	58.109029	0103000020E61000000100000005000000E485747808694B4065A88AA9F40D4D40E485747808694B407A36AB3E570F4D4016DC0F78606C4B407A36AB3E570F4D4016DC0F78606C4B4065A88AA9F40D4D40E485747808694B4065A88AA9F40D4D40
30997	Сепыч	7	71	1129	54.110551000000001	54.159384000000003	58.193967000000001	58.171788999999997	0103000020E6100000010000000500000022C50089260E4B400168942EFD154D4022C50089260E4B406AC020E9D3184D40BAC0E5B166144B406AC020E9D3184D40BAC0E5B166144B400168942EFD154D4022C50089260E4B400168942EFD154D40
33096	Рябины	7	71	1129	54.648974000000003	54.667012999999997	58.064343999999998	58.054284000000003	0103000020E6100000010000000500000027FA7C9411534B40195932C7F2064D4027FA7C9411534B40CFD8976C3C084D40E08096AE60554B40CFD8976C3C084D40E08096AE60554B40195932C7F2064D4027FA7C9411534B40195932C7F2064D40
30848	Путино	7	71	1129	54.278131999999999	54.457543000000001	58.077129999999997	58.033476999999998	0103000020E610000001000000050000004CFC51D499234B4087156EF948044D404CFC51D499234B402EC55565DF094D40C2C1DEC4903A4B402EC55565DF094D40C2C1DEC4903A4B4087156EF948044D404CFC51D499234B4087156EF948044D40
56266	Посад	7	71	1129	54.385812999999999	54.398308	58.053725999999997	58.048791999999999	0103000020E6100000010000000500000092AF045262314B403927F6D03E064D4092AF045262314B40F2785A7EE0064D401ADEACC1FB324B40F2785A7EE0064D401ADEACC1FB324B403927F6D03E064D4092AF045262314B403927F6D03E064D40
10495	Нижнее Галино	7	71	1129	54.378760999999997	54.408225999999999	58.144002	58.134872000000001	0103000020E6100000010000000500000008008E3D7B304B40B492567C43114D4008008E3D7B304B40804754A86E124D403EB0E3BF40344B40804754A86E124D403EB0E3BF40344B40B492567C43114D4008008E3D7B304B40B492567C43114D40
56475	Мартелы	7	71	1129	54.111700999999996	54.131365000000002	58.013272999999998	58.005687000000002	0103000020E610000001000000050000001AF7E6374C0E4B409581035ABA004D401AF7E6374C0E4B40BC75FEEDB2014D40666B7D91D0104B40BC75FEEDB2014D40666B7D91D0104B409581035ABA004D401AF7E6374C0E4B409581035ABA004D40
33126	Ленино	7	71	1129	54.555971999999997	54.580460000000002	58.199587000000001	58.185214000000002	0103000020E61000000100000005000000F0BE2A172A474B407461A417B5174D40F0BE2A172A474B4077DA1A118C194D406E5166834C4A4B4077DA1A118C194D406E5166834C4A4B407461A417B5174D40F0BE2A172A474B407461A417B5174D40
30818	Кукеты	7	71	1129	54.903843999999999	54.915135999999997	58.110830999999997	58.100332000000002	0103000020E61000000100000005000000C9570229B1734B40035FD1ADD70C4D40C9570229B1734B400531D0B52F0E4D4035B22B2D23754B400531D0B52F0E4D4035B22B2D23754B40035FD1ADD70C4D40C9570229B1734B40035FD1ADD70C4D40
30660	Кукетский	7	71	1129	54.826428	54.853116999999997	58.156796999999997	58.141551	0103000020E61000000100000005000000D53F8864C8694B40A9DBD9571E124D40D53F8864C8694B40328E91EC11144D40B05417F0326D4B40328E91EC11144D40B05417F0326D4B40A9DBD9571E124D40D53F8864C8694B40A9DBD9571E124D40
56258	Комары	7	71	1129	54.494706999999998	54.511235999999997	58.093288000000001	58.077739000000001	0103000020E61000000100000005000000170D198F523F4B40D74FFF59F3094D40170D198F523F4B40FC8D76DCF00B4D40D844662E70414B40FC8D76DCF00B4D40D844662E70414B40D74FFF59F3094D40170D198F523F4B40D74FFF59F3094D40
30494	Зюкайка	7	71	1129	54.676391000000002	54.733846999999997	58.217401000000002	58.188008000000004	0103000020E610000001000000050000008527F4FA93564B4075B169A510184D408527F4FA93564B40118FC4CBD31B4D4044A2D0B2EE5D4B40118FC4CBD31B4D4044A2D0B2EE5D4B4075B169A510184D408527F4FA93564B4075B169A510184D40
58240	Зюкай	7	71	1129	54.720542999999999	54.736469999999997	58.130681000000003	58.125244000000002	0103000020E610000001000000050000004D2EC6C03A5C4B409702D2FE07104D404D2EC6C03A5C4B40B39AAE27BA104D40183E22A6445E4B40B39AAE27BA104D40183E22A6445E4B409702D2FE07104D404D2EC6C03A5C4B409702D2FE07104D40
30305	Вознесенское	7	71	1129	54.609960999999998	54.648668999999998	58.167611999999998	58.137413000000002	0103000020E61000000100000005000000F06AB933134E4B40CB85CABF96114D40F06AB933134E4B4065355D4F74154D40EA76F69507534B4065355D4F74154D40EA76F69507534B40CB85CABF96114D40F06AB933134E4B40CB85CABF96114D40
10421	Верещагино	7	71	1129	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
56259	Бородулино	7	71	1129	54.353572	54.400554	58.006526000000001	57.989078999999997	0103000020E610000001000000050000000264E8D8412D4B40871403249AFE4C400264E8D8412D4B406F490ED8D5004D4018247D5A45334B406F490ED8D5004D4018247D5A45334B40871403249AFE4C400264E8D8412D4B40871403249AFE4C40
32535	Бородули	7	71	1129	54.750349	54.771765000000002	58.083078	58.071666	0103000020E610000001000000050000000CCB9F6F0B604B40191EFB592C094D400CCB9F6F0B604B403082C64CA20A4D4046990D32C9624B403082C64CA20A4D4046990D32C9624B40191EFB592C094D400CCB9F6F0B604B40191EFB592C094D40
58243	Аникино	7	71	1129	54.771172	54.787117000000002	58.135925999999998	58.124820999999997	0103000020E61000000100000005000000A3CB9BC3B5624B40506D7022FA0F4D40A3CB9BC3B5624B408A56EE0566114D401590F63FC0644B408A56EE0566114D401590F63FC0644B40506D7022FA0F4D40A3CB9BC3B5624B40506D7022FA0F4D40
29334	Юрково	7	71	1599	54.592722000000002	54.617578000000002	57.757351	57.733445000000003	0103000020E6100000010000000500000053CF8250DE4B4B4016359886E1DD4C4053CF8250DE4B4B40E44BA8E0F0E04C40535DC0CB0C4F4B40E44BA8E0F0E04C40535DC0CB0C4F4B4016359886E1DD4C4053CF8250DE4B4B4016359886E1DD4C40
29326	Черновское	7	71	1599	54.523784999999997	54.576138999999998	57.503166	57.486832	0103000020E6100000010000000500000053910A630B434B40B952CF8250BE4C4053910A630B434B40C53A55BE67C04C409E7939ECBE494B40C53A55BE67C04C409E7939ECBE494B40B952CF8250BE4C4053910A630B434B40B952CF8250BE4C40
29251	Тойкино	7	71	1599	54.349305000000001	54.394868000000002	57.529853000000003	57.512236000000001	0103000020E6100000010000000500000026AAB706B62C4B40BCEA01F390C14C4026AAB706B62C4B4000581D39D2C34C40541EDD088B324B4000581D39D2C34C40541EDD088B324B40BCEA01F390C14C4026AAB706B62C4B40BCEA01F390C14C40
28553	Солоды	7	71	1599	54.124628000000001	54.154029999999999	57.600766999999998	57.590257000000001	0103000020E610000001000000050000003C1570CFF30F4B40179E978A8DCB4C403C1570CFF30F4B400DC2DCEEE5CC4C402B4D4A41B7134B400DC2DCEEE5CC4C402B4D4A41B7134B40179E978A8DCB4C403C1570CFF30F4B40179E978A8DCB4C40
29170	Полозово	7	71	1599	54.405782000000002	54.435336999999997	57.364190999999998	57.351559000000002	0103000020E610000001000000050000001AA721AAF0334B40A7CEA3E2FFAC4C401AA721AAF0334B40AF3F89CF9DAE4C408FDE701FB9374B40AF3F89CF9DAE4C408FDE701FB9374B40A7CEA3E2FFAC4C401AA721AAF0334B40A7CEA3E2FFAC4C40
29154	Петропавловск	7	71	1599	54.271025999999999	54.318933000000001	57.664017999999999	57.644477000000002	0103000020E61000000100000005000000CF2EDFFAB0224B401903EB387ED24C40CF2EDFFAB0224B4048FAB48AFED44C40BE4EEACBD2284B4048FAB48AFED44C40BE4EEACBD2284B401903EB387ED24C40CF2EDFFAB0224B401903EB387ED24C40
29105	Пермяки	7	71	1599	54.134293999999997	54.161737000000002	57.671610000000001	57.655794999999998	0103000020E610000001000000050000004606B98B30114B40AEF02E17F1D34C404606B98B30114B4052D50451F7D54C40CEC64ACCB3144B4052D50451F7D54C40CEC64ACCB3144B40AEF02E17F1D34C404606B98B30114B40AEF02E17F1D34C40
29039	Нижний Лып	7	71	1599	54.206904000000002	54.231752	57.353079000000001	57.326343999999999	0103000020E61000000100000005000000AFB48CD47B1A4B40779FE3A3C5A94C40AFB48CD47B1A4B40C3F352B131AD4C402C64AE0CAA1D4B40C3F352B131AD4C402C64AE0CAA1D4B40779FE3A3C5A94C40AFB48CD47B1A4B40779FE3A3C5A94C40
29016	Малая Соснова	7	71	1599	54.630918000000001	54.666392999999999	57.630023999999999	57.610087999999998	0103000020E61000000100000005000000973AC8EBC1504B404DD7135D17CE4C40973AC8EBC1504B40F9D85DA0A4D04C4044A4A65D4C554B40F9D85DA0A4D04C4044A4A65D4C554B404DD7135D17CE4C40973AC8EBC1504B404DD7135D17CE4C40
58272	Луговая	7	71	1599	54.16966	54.181382999999997	57.541352000000003	57.530757000000001	0103000020E610000001000000050000003DB83B6BB7154B40C18F6AD8EFC34C403DB83B6BB7154B40E6CFB7054BC54C407286E28E37174B40E6CFB7054BC54C407286E28E37174B40C18F6AD8EFC34C403DB83B6BB7154B40C18F6AD8EFC34C40
28959	Лисья	7	71	1599	54.351201000000003	54.374063	57.255678000000003	57.242375000000003	0103000020E6100000010000000500000048A98427F42C4B401B2FDD24069F4C4048A98427F42C4B404227840EBAA04C4063D2DF4BE12F4B404227840EBAA04C4063D2DF4BE12F4B401B2FDD24069F4C4048A98427F42C4B401B2FDD24069F4C40
28934	Левино	7	71	1599	54.813124000000002	54.837477	57.642646999999997	57.623263000000001	0103000020E61000000100000005000000DECB7D7214684B4047E7FC14C7CF4C40DECB7D7214684B40AEEFC34142D24C407B134372326B4B40AEEFC34142D24C407B134372326B4B4047E7FC14C7CF4C40DECB7D7214684B4047E7FC14C7CF4C40
29414	Красный Яр	7	71	1599	54.436945000000001	54.455899000000002	57.399211000000001	57.375329999999998	0103000020E610000001000000050000004B9352D0ED374B40959A3DD00AB04C404B9352D0ED374B400B9A965819B34C40BAA3FFE55A3A4B400B9A965819B34C40BAA3FFE55A3A4B40959A3DD00AB04C404B9352D0ED374B40959A3DD00AB04C40
28886	Кленовка	7	71	1599	54.298065000000001	54.341912000000001	57.751520999999997	57.740184999999997	0103000020E61000000100000005000000878A71FE26264B40B0FECF61BEDE4C40878A71FE26264B40ECA012D731E04C40130EBDC5C32B4B40ECA012D731E04C40130EBDC5C32B4B40B0FECF61BEDE4C40878A71FE26264B40B0FECF61BEDE4C40
28808	Заболотово	7	71	1599	54.439019999999999	54.466410000000003	57.723621999999999	57.710917000000002	0103000020E610000001000000050000001C25AFCE31384B40D1950854FFDA4C401C25AFCE31384B4043554CA59FDC4C408143A852B33B4B4043554CA59FDC4C408143A852B33B4B40D1950854FFDA4C401C25AFCE31384B40D1950854FFDA4C40
56531	Верх-Потка	7	71	1599	54.285497999999997	54.312241	57.535845000000002	57.518442999999998	0103000020E610000001000000050000006589CE328B244B4089EB18575CC24C406589CE328B244B40D15CA79196C44C4034BC5983F7274B40D15CA79196C44C4034BC5983F7274B4089EB18575CC24C406589CE328B244B4089EB18575CC24C40
28580	Большая Соснова	7	71	1599	54.575816000000003	54.627738000000001	57.689149	57.657716000000001	0103000020E61000000100000005000000BC41B456B4494B402907B30930D44C40BC41B456B4494B401A89D00836D84C406D3A02B859504B401A89D00836D84C406D3A02B859504B402907B30930D44C40BC41B456B4494B402907B30930D44C40
28705	Бердышево	7	71	1599	54.443458	54.471665000000002	57.340145999999997	57.324151999999998	0103000020E610000001000000050000002593533BC3384B406C770FD07DA94C402593533BC3384B40BFEE74E789AB4C407CD5CA845F3C4B40BFEE74E789AB4C407CD5CA845F3C4B406C770FD07DA94C402593533BC3384B406C770FD07DA94C40
28690	Баклуши	7	71	1599	54.441499	54.473632000000002	57.646616000000002	57.632066999999999	0103000020E61000000100000005000000BD1B0B0A83384B40BFF04A92E7D04C40BD1B0B0A83384B4001892650C4D24C40672B2FF99F3C4B4001892650C4D24C40672B2FF99F3C4B40BFF04A92E7D04C40BD1B0B0A83384B40BFF04A92E7D04C40
32904	Шаква	7	71	997	57.305723999999998	57.331873999999999	57.659156000000003	57.653806000000003	0103000020E6100000010000000500000018CDCAF621A74C40DCF63DEAAFD34C4018CDCAF621A74C40297B4B395FD44C404432E4D87AAA4C40297B4B395FD44C404432E4D87AAA4C40DCF63DEAAFD34C4018CDCAF621A74C40DCF63DEAAFD34C40
48584	Харино	7	71	997	57.767825999999999	57.784202999999998	57.541182999999997	57.532041999999997	0103000020E610000001000000050000005E82531F48E24C40990CC7F319C44C405E82531F48E24C4059130B7C45C54C4069368FC360E44C4059130B7C45C54C4069368FC360E44C40990CC7F319C44C405E82531F48E24C40990CC7F319C44C40
56301	Филатово	7	71	997	57.312057000000003	57.323115000000001	57.600811	57.592013000000001	0103000020E6100000010000000500000073BED87BF1A74C4047E7FC14C7CB4C4073BED87BF1A74C40DD09F65FE7CC4C406CEC12D55BA94C40DD09F65FE7CC4C406CEC12D55BA94C4047E7FC14C7CB4C4073BED87BF1A74C4047E7FC14C7CB4C40
27324	Туясы	7	71	997	57.471238	57.488323999999999	57.649963	57.637034	0103000020E61000000100000005000000F450DB8651BC4C40543882548AD14C40F450DB8651BC4C40164ED2FC31D34C400BED9C6681BE4C40164ED2FC31D34C400BED9C6681BE4C40543882548AD14C40F450DB8651BC4C40543882548AD14C40
28175	Тулумбасы	7	71	997	57.615912000000002	57.635891000000001	57.437812000000001	57.427399999999999	0103000020E61000000100000005000000639B5434D6CE4C40BB270F0BB5B64C40639B5434D6CE4C40EFE53E390AB84C400E6954E064D14C40EFE53E390AB84C400E6954E064D14C40BB270F0BB5B64C40639B5434D6CE4C40BB270F0BB5B64C40
28120	Таз-Русский	7	71	997	57.367196	57.389546000000003	57.530124000000001	57.520609	0103000020E610000001000000050000006B9C4D4700AF4C406B80D250A3C24C406B9C4D4700AF4C4090696D1ADBC34C40D124B1A4DCB14C4090696D1ADBC34C40D124B1A4DCB14C406B80D250A3C24C406B9C4D4700AF4C406B80D250A3C24C40
32771	Сая	7	71	997	57.652814999999997	57.685388000000003	57.738725000000002	57.731008000000003	0103000020E610000001000000050000004BAB21718FD34C40A48E8EAB91DD4C404BAB21718FD34C406ADE718A8EDE4C40128942CBBAD74C406ADE718A8EDE4C40128942CBBAD74C40A48E8EAB91DD4C404BAB21718FD34C40A48E8EAB91DD4C40
56399	Рыжково	7	71	997	57.191243	57.212927999999998	57.573484999999998	57.564506999999999	0103000020E61000000100000005000000624B8FA67A984C4079AEEFC341C84C40624B8FA67A984C408FDFDBF467C94C408B338639419B4C408FDFDBF467C94C408B338639419B4C4079AEEFC341C84C40624B8FA67A984C4079AEEFC341C84C40
27246	Пуздрино	7	71	997	57.439419999999998	57.468552000000003	57.659657000000003	57.641514999999998	0103000020E61000000100000005000000AA9A20EA3EB84C405C72DC291DD24C40AA9A20EA3EB84C40EBC9FCA36FD44C40DA3C0E83F9BB4C40EBC9FCA36FD44C40DA3C0E83F9BB4C405C72DC291DD24C40AA9A20EA3EB84C405C72DC291DD24C40
28501	Проносное	7	71	997	57.569056000000003	57.583410999999998	57.491011999999998	57.47898	0103000020E61000000100000005000000DACBB6D3D6C84C4013B875374FBD4C40DACBB6D3D6C84C40C6F8307BD9BE4C4036902E36ADCA4C40C6F8307BD9BE4C4036902E36ADCA4C4013B875374FBD4C40DACBB6D3D6C84C4013B875374FBD4C40
32918	Полушкино	7	71	997	57.735424000000002	57.777205000000002	57.540666000000002	57.527959000000003	0103000020E61000000100000005000000C558A65F22DE4C407F50172994C34C40C558A65F22DE4C409207228B34C54C40D3A414747BE34C409207228B34C54C40D3A414747BE34C407F50172994C34C40C558A65F22DE4C407F50172994C34C40
58214	Подволошино	7	71	997	57.764924999999998	57.787697000000001	57.556628000000003	57.546959999999999	0103000020E610000001000000050000004772F90FE9E14C402E1C08C902C64C404772F90FE9E14C40DA0418963FC74C4023145B41D3E44C40DA0418963FC74C4023145B41D3E44C402E1C08C902C64C404772F90FE9E14C402E1C08C902C64C40
28641	Песьянка	7	71	997	57.785730000000001	57.816425000000002	57.561089000000003	57.549568000000001	0103000020E6100000010000000500000038BEF6CC92E44C40CD76853E58C64C4038BEF6CC92E44C409B92ACC3D1C74C408351499D80E84C409B92ACC3D1C74C408351499D80E84C40CD76853E58C64C4038BEF6CC92E44C40CD76853E58C64C40
32878	Перебор	7	71	997	57.320843000000004	57.331982000000004	57.719349000000001	57.704084000000002	0103000020E610000001000000050000004513286211A94C4085D1AC6C1FDA4C404513286211A94C4085B4C6A013DC4C402B6EDC627EAA4C4085B4C6A013DC4C402B6EDC627EAA4C4085D1AC6C1FDA4C404513286211A94C4085D1AC6C1FDA4C40
27183	Пентюрино	7	71	997	57.271785999999999	57.292186000000001	57.626264999999997	57.618876	0103000020E610000001000000050000005DC136E2C9A24C40C0232A5437CF4C405DC136E2C9A24C4091D0967329D04C40AE2CD15966A54C4091D0967329D04C40AE2CD15966A54C40C0232A5437CF4C405DC136E2C9A24C40C0232A5437CF4C40
27524	Метальниково	7	71	997	57.177039999999998	57.196156000000002	57.624963999999999	57.613852999999999	0103000020E61000000100000005000000BB0A293FA9964C4097C62FBC92CE4C40BB0A293FA9964C40B39602D2FECF4C400475CAA31B994C40B39602D2FECF4C400475CAA31B994C4097C62FBC92CE4C40BB0A293FA9964C4097C62FBC92CE4C40
56340	Мачино	7	71	997	57.372909	57.675102000000003	57.694921999999998	57.599986000000001	0103000020E6100000010000000500000029B16B7BBBAF4C4068075C57CCCC4C4029B16B7BBBAF4C40ADA23F34F3D84C406BBB09BE69D64C40ADA23F34F3D84C406BBB09BE69D64C4068075C57CCCC4C4029B16B7BBBAF4C4068075C57CCCC4C40
58266	Марково	7	71	997	57.448565000000002	57.468283	57.578668	57.570227000000003	0103000020E61000000100000005000000AC90F2936AB94C40EA25C632FDC84C40AC90F2936AB94C40F19E03CB11CA4C40EA2285B2F0BB4C40F19E03CB11CA4C40EA2285B2F0BB4C40EA25C632FDC84C40AC90F2936AB94C40EA25C632FDC84C40
27965	Малыши	7	71	997	57.659973999999998	57.672362	57.614114000000001	57.607475000000001	0103000020E61000000100000005000000EB1A2D077AD44C409D11A5BDC1CD4C40EB1A2D077AD44C4004029D499BCE4C405D8940F50FD64C4004029D499BCE4C405D8940F50FD64C409D11A5BDC1CD4C40EB1A2D077AD44C409D11A5BDC1CD4C40
32687	Копчиково	7	71	997	57.357053999999998	57.373448000000003	57.655462999999997	57.639476999999999	0103000020E61000000100000005000000F7730AF2B3AD4C40A8C5E061DAD14C40F7730AF2B3AD4C40785E2A36E6D34C40D960E124CDAF4C40785E2A36E6D34C40D960E124CDAF4C40A8C5E061DAD14C40F7730AF2B3AD4C40A8C5E061DAD14C40
32848	Кляпово	7	71	997	57.36168	57.386068999999999	57.575921999999998	57.563701000000002	0103000020E6100000010000000500000003CFBD874BAE4C407BDCB75A27C84C4003CFBD874BAE4C400186E5CFB7C94C40ED7F80B56AB14C400186E5CFB7C94C40ED7F80B56AB14C407BDCB75A27C84C4003CFBD874BAE4C407BDCB75A27C84C40
27773	Клычи	7	71	997	57.244287999999997	57.267643999999997	57.588684000000001	57.576264999999999	0103000020E61000000100000005000000126745D4449F4C402B6A300DC3C94C40126745D4449F4C40D8D64FFF59CB4C403D7C992842A24C40D8D64FFF59CB4C403D7C992842A24C402B6A300DC3C94C40126745D4449F4C402B6A300DC3C94C40
27698	Карнаухово	7	71	997	57.174515999999997	57.293236999999998	57.617474000000001	57.527634999999997	0103000020E610000001000000050000007A50508A56964C40CB9C2E8B89C34C407A50508A56964C40AE10566309CF4C40137D3ECA88A54C40AE10566309CF4C40137D3ECA88A54C40CB9C2E8B89C34C407A50508A56964C40CB9C2E8B89C34C40
27910	Зернино	7	71	997	57.647632000000002	57.66337	57.623835999999997	57.614490000000004	0103000020E61000000100000005000000EAEBF99AE5D24C400ADCBA9BA7CE4C40EAEBF99AE5D24C40A208A9DBD9CF4C40E292E34EE9D44C40A208A9DBD9CF4C40E292E34EE9D44C400ADCBA9BA7CE4C40EAEBF99AE5D24C400ADCBA9BA7CE4C40
27827	Зарека	7	71	997	57.233445000000003	57.252201999999997	57.749014000000003	57.738047000000002	0103000020E6100000010000000500000016359886E19D4C4099F4F75278DE4C4016359886E19D4C40821FD5B0DFDF4C402EFEB62748A04C40821FD5B0DFDF4C402EFEB62748A04C4099F4F75278DE4C4016359886E19D4C4099F4F75278DE4C40
32745	Дубовое	7	71	997	57.165011999999997	57.189149	57.666618	57.655149999999999	0103000020E6100000010000000500000049B9FB1C1F954C40B9FC87F4DBD34C4049B9FB1C1F954C40647616BD53D54C401A89D00836984C40647616BD53D54C401A89D00836984C40B9FC87F4DBD34C4049B9FB1C1F954C40B9FC87F4DBD34C40
27866	Батерики	7	71	997	57.234262999999999	57.265487999999998	57.769699000000003	57.758172000000002	0103000020E61000000100000005000000D8D47954FC9D4C40185FB4C70BE14C40D8D47954FC9D4C40C861307F85E24C407FBDC282FBA14C40C861307F85E24C407FBDC282FBA14C40185FB4C70BE14C40D8D47954FC9D4C40185FB4C70BE14C40
56344	Бартым	7	71	997	57.354304999999997	57.36468	57.664437	57.658327999999997	0103000020E6100000010000000500000096E7C1DD59AD4C404205871744D44C4096E7C1DD59AD4C404DA088450CD54C40ADC090D5ADAE4C404DA088450CD54C40ADC090D5ADAE4C404205871744D44C4096E7C1DD59AD4C404205871744D44C40
26862	Асово	7	71	997	57.658897000000003	57.686610000000002	57.525388	57.506912999999997	0103000020E610000001000000050000005D37A5BC56D44C4068757286E2C04C405D37A5BC56D44C40FDDAFAE93FC34C40A48D23D6E2D74C40FDDAFAE93FC34C40A48D23D6E2D74C4068757286E2C04C405D37A5BC56D44C4068757286E2C04C40
32743	Антонково	7	71	997	57.208022999999997	57.223106000000001	57.686297000000003	57.681975999999999	0103000020E610000001000000050000006CE8667FA09A4C40155454FD4AD74C406CE8667FA09A4C40E52B8194D8D74C404CC5C6BC8E9C4C40E52B8194D8D74C404CC5C6BC8E9C4C40155454FD4AD74C406CE8667FA09A4C40155454FD4AD74C40
32620	Яйвинский Рейд	7	71	982	56.718333000000001	56.740414000000001	59.307817	59.298284000000002	0103000020E610000001000000050000009C51F355F25B4C40C5758C2B2EA64D409C51F355F25B4C409013268C66A74D4012C0CDE2C55E4C409013268C66A74D4012C0CDE2C55E4C40C5758C2B2EA64D409C51F355F25B4C40C5758C2B2EA64D40
8239	Усолье	7	71	982	56.624999000000003	56.713437999999996	59.450980000000001	59.397725999999999	0103000020E6100000010000000500000030849CF7FF4F4C406B6281AFE8B24D4030849CF7FF4F4C4036936FB6B9B94D40A0DCB6EF515B4C4036936FB6B9B94D40A0DCB6EF515B4C406B6281AFE8B24D4030849CF7FF4F4C406B6281AFE8B24D40
47935	Железнодорожный	7	71	982	57.009746999999997	57.037083000000003	59.343245000000003	59.334781999999997	0103000020E61000000100000005000000F71DC3633F814C400DA5F622DAAA4D40F71DC3633F814C40FDC1C073EFAB4D40691EC022BF844C40FDC1C073EFAB4D40691EC022BF844C400DA5F622DAAA4D40F71DC3633F814C400DA5F622DAAA4D40
24341	Шермейка	7	71	391	55.819093000000002	55.863802	57.011180000000003	56.991821999999999	0103000020E61000000100000005000000F7B0170AD8E84B4006BAF605F47E4C40F7B0170AD8E84B40452FA3586E814C40151C5E1091EE4B40452FA3586E814C40151C5E1091EE4B4006BAF605F47E4C40F7B0170AD8E84B4006BAF605F47E4C40
24305	Шабарка	7	71	391	55.793427999999999	55.816029999999998	57.061557000000001	57.047767	0103000020E6100000010000000500000087DD770C8FE54B40FD69A33A1D864C4087DD770C8FE54B4081EB8A19E1874C400647C9AB73E84B4081EB8A19E1874C400647C9AB73E84B40FD69A33A1D864C4087DD770C8FE54B40FD69A33A1D864C40
22773	Чалково	7	71	391	55.601807999999998	55.617618999999998	56.999583000000001	56.985756000000002	0103000020E610000001000000050000004F3C670B08CD4B40FBEAAA402D7E4C404F3C670B08CD4B409C51F355F27F4C40B131AF230ECF4B409C51F355F27F4C40B131AF230ECF4B40FBEAAA402D7E4C404F3C670B08CD4B40FBEAAA402D7E4C40
24253	Федорки	7	71	391	55.266530000000003	55.301160000000003	57.057611999999999	57.042243999999997	0103000020E6100000010000000500000092B3B0A71DA24B40E2395B4068854C4092B3B0A71DA24B40B7ED7BD45F874C40836E2F698CA64B40B7ED7BD45F874C40836E2F698CA64B40E2395B4068854C4092B3B0A71DA24B40E2395B4068854C40
23069	Учкул	7	71	391	55.431154999999997	55.457970000000003	56.788829999999997	56.781408999999996	0103000020E61000000100000005000000E140481630B74B4068E6C93505644C40E140481630B74B40450DA661F8644C404A46CEC29EBA4B40450DA661F8644C404A46CEC29EBA4B4068E6C93505644C40E140481630B74B4068E6C93505644C40
58018	Усть-Тунтор	7	71	391	55.582549	55.605249000000001	57.063513999999998	57.049768999999998	0103000020E61000000100000005000000A4A833F790CA4B4064ADA1D45E864C40A4A833F790CA4B40486B0C3A21884C40E6779ACC78CD4B40486B0C3A21884C40E6779ACC78CD4B4064ADA1D45E864C40A4A833F790CA4B4064ADA1D45E864C40
56530	Усть-Ашап	7	71	391	55.671768999999998	55.685854999999997	56.819912000000002	56.809348999999997	0103000020E61000000100000005000000BABBCE86FCD54B4070067FBF98674C40BABBCE86FCD54B408ACC5CE0F2684C402766BD18CAD74B408ACC5CE0F2684C402766BD18CAD74B4070067FBF98674C40BABBCE86FCD54B4070067FBF98674C40
24222	Уймуж	7	71	391	55.297970999999997	55.333643000000002	57.087466999999997	57.070433999999999	0103000020E610000001000000050000000514EAE923A64B40634337FB03894C400514EAE923A64B40573D601E328B4C4009C556D0B4AA4B40573D601E328B4C4009C556D0B4AA4B40634337FB03894C400514EAE923A64B40634337FB03894C40
22415	Тюндюк	7	71	391	55.606586999999998	55.636114999999997	56.832915	56.806342999999998	0103000020E61000000100000005000000E1968FA4A4CD4B40E42D573F36674C40E1968FA4A4CD4B4086AC6EF59C6A4C405DBF60376CD14B4086AC6EF59C6A4C405DBF60376CD14B40E42D573F36674C40E1968FA4A4CD4B40E42D573F36674C40
24095	Танып	7	71	391	55.819110999999999	55.849347999999999	56.781173000000003	56.763005999999997	0103000020E610000001000000050000009D6516A1D8E84B406D533C2EAA614C409D6516A1D8E84B4055C2137AFD634C4025766D6FB7EC4B4055C2137AFD634C4025766D6FB7EC4B406D533C2EAA614C409D6516A1D8E84B406D533C2EAA614C40
2044	Сюзянь	7	71	391	55.758114999999997	55.787292999999998	56.852995999999997	56.841605999999999	0103000020E61000000100000005000000B3CD8DE909E14B40060FD3BEB96B4C40B3CD8DE909E14B4035CF11F92E6D4C4053AF5B04C6E44B4035CF11F92E6D4C4053AF5B04C6E44B40060FD3BEB96B4C40B3CD8DE909E14B40060FD3BEB96B4C40
24043	Султанай	7	71	391	55.685198999999997	55.724401999999998	56.820231999999997	56.801882999999997	0103000020E610000001000000050000003E20D099B4D74B40F31B261AA4664C403E20D099B4D74B40FB90B75CFD684C4018946934B9DC4B40FB90B75CFD684C4018946934B9DC4B40F31B261AA4664C403E20D099B4D74B40F31B261AA4664C40
22784	Старый Чад	7	71	391	55.414779000000003	55.439734000000001	56.932437999999998	56.922249999999998	0103000020E61000000100000005000000A708707A17B54B40355EBA490C764C40A708707A17B54B4019C6DD205A774C403A78263449B84B4019C6DD205A774C403A78263449B84B40355EBA490C764C40A708707A17B54B40355EBA490C764C40
22541	Старый Ашап	7	71	391	55.655051999999998	55.673368000000004	56.814720000000001	56.806294000000001	0103000020E61000000100000005000000F69672BED8D34B40037B4CA434674C40F69672BED8D34B40D5B2B5BE48684C40231631EC30D64B40D5B2B5BE48684C40231631EC30D64B40037B4CA434674C40F69672BED8D34B40037B4CA434674C40
24005	Сараши	7	71	391	55.733457000000001	55.782764999999998	56.788198999999999	56.766257000000003	0103000020E61000000100000005000000DA0242EBE1DD4B4061AA99B514624C40DA0242EBE1DD4B40B5DE6FB4E3644C400ABABDA431E44B40B5DE6FB4E3644C400ABABDA431E44B4061AA99B514624C40DA0242EBE1DD4B4061AA99B514624C40
23862	Печмень	7	71	391	56.013928999999997	56.035201000000001	56.834204999999997	56.817084999999999	0103000020E61000000100000005000000A5BBEB6CC8014C40AD86C43D96684C40A5BBEB6CC8014C407094BC3AC76A4C40ACE4637781044C407094BC3AC76A4C40ACE4637781044C40AD86C43D96684C40A5BBEB6CC8014C40AD86C43D96684C40
32519	Новый Чад	7	71	391	55.509658999999999	55.534362999999999	56.770293000000002	56.761629999999997	0103000020E61000000100000005000000588E90813CC14B4084D382177D614C40588E90813CC14B403BAB05F698624C40A298BC0166C44B403BAB05F698624C40A298BC0166C44B4084D382177D614C40588E90813CC14B4084D382177D614C40
23597	Новый Ашап	7	71	391	55.683824999999999	55.697730999999997	56.686278000000001	56.657806000000001	0103000020E61000000100000005000000F697DD9387D74B40698EACFC32544C40F697DD9387D74B406EFB1EF5D7574C40E333D93F4FD94B406EFB1EF5D7574C40E333D93F4FD94B40698EACFC32544C40F697DD9387D74B40698EACFC32544C40
32931	Новая Казанка	7	71	391	55.483195000000002	55.515211000000001	56.733659000000003	56.714441999999998	0103000020E610000001000000050000009D4B7155D9BD4B40C571E0D5725B4C409D4B7155D9BD4B4042B5C189E85D4C400DC51D6FF2C14B4042B5C189E85D4C400DC51D6FF2C14B40C571E0D5725B4C409D4B7155D9BD4B40C571E0D5725B4C40
32921	Никольск	7	71	391	55.654746000000003	55.671391999999997	56.738230999999999	56.726371	0103000020E61000000100000005000000EA9788B7CED34B40A4E194B9F95C4C40EA9788B7CED34B405AF2785A7E5E4C40E4654D2CF0D54B405AF2785A7E5E4C40E4654D2CF0D54B40A4E194B9F95C4C40EA9788B7CED34B40A4E194B9F95C4C40
23941	Нижняя Искильда	7	71	391	56.003751000000001	56.028508000000002	56.923262000000001	56.906973999999998	0103000020E61000000100000005000000E529ABE97A004C4041295AB917744C40E529ABE97A004C40DDD1FF722D764C4052D66F26A6034C40DDD1FF722D764C4052D66F26A6034C4041295AB917744C40E529ABE97A004C4041295AB917744C40
32783	Мостовая	7	71	391	55.557035999999997	55.578415999999997	56.969794	56.957948000000002	0103000020E61000000100000005000000EA58A5F44CC74B4062A2410A9E7A4C40EA58A5F44CC74B40B3EDB435227C4C40D7BD158909CA4B40B3EDB435227C4C40D7BD158909CA4B4062A2410A9E7A4C40EA58A5F44CC74B4062A2410A9E7A4C40
23503	Куземьярово	7	71	391	55.507728	55.540238000000002	57.026736999999997	57.013989000000002	0103000020E61000000100000005000000BAA1293BFDC04B407BC03C64CA814C40BAA1293BFDC04B40EC4B361E6C834C403A07CF8426C54B40EC4B361E6C834C403A07CF8426C54B407BC03C64CA814C40BAA1293BFDC04B407BC03C64CA814C40
23517	Кудаш	7	71	391	55.398825000000002	55.440893000000003	56.995640999999999	56.987363999999999	0103000020E61000000100000005000000E2E995B20CB34B40B69F8CF1617E4C40E2E995B20CB34B4043C70E2A717F4C4086048C2E6FB84B4043C70E2A717F4C4086048C2E6FB84B40B69F8CF1617E4C40E2E995B20CB34B40B69F8CF1617E4C40
23439	Краснояр 2-й	7	71	391	55.609766999999998	55.636024999999997	56.906540999999997	56.882289	0103000020E610000001000000050000000B9755D80CCE4B406E4F90D8EE704C400B9755D80CCE4B40D7BD158909744C401D38674469D14B40D7BD158909744C401D38674469D14B406E4F90D8EE704C400B9755D80CCE4B406E4F90D8EE704C40
23400	Краснояр 1-й	7	71	391	55.592080000000003	55.612363999999999	56.913922999999997	56.879624	0103000020E61000000100000005000000CF4E0647C9CB4B406B63EC8497704C40CF4E0647C9CB4B40F607CA6DFB744C40B69F8CF161CE4B40F607CA6DFB744C40B69F8CF161CE4B406B63EC8497704C40CF4E0647C9CB4B406B63EC8497704C40
32840	Конюково	7	71	391	55.546301999999997	55.572989999999997	57.066949999999999	57.055996	0103000020E61000000100000005000000A4DE5339EDC54B40795A7EE02A874C40A4DE5339EDC54B40CD3B4ED191884C40AF777FBC57C94B40CD3B4ED191884C40AF777FBC57C94B40795A7EE02A874C40A4DE5339EDC54B40795A7EE02A874C40
56343	Константиновка	7	71	391	55.897731	55.940913000000002	56.793951999999997	56.780245000000001	0103000020E610000001000000050000007DCD72D9E8F24B400BEF7211DF634C407DCD72D9E8F24B40014C1938A0654C40CDB051D66FF84B40014C1938A0654C40CDB051D66FF84B400BEF7211DF634C407DCD72D9E8F24B400BEF7211DF634C40
56371	Кармановка	7	71	391	56.018042999999999	56.035469999999997	56.783780999999998	56.771565000000002	0103000020E61000000100000005000000FB75A73B4F024C407FDE54A4C2624C40FB75A73B4F024C40F31C91EF52644C409BFEEC478A044C40F31C91EF52644C409BFEEC478A044C407FDE54A4C2624C40FB75A73B4F024C407FDE54A4C2624C40
32797	Ишимово	7	71	391	55.575873999999999	55.598250999999998	57.016302000000003	57.004088000000003	0103000020E61000000100000005000000F04E3E3DB6C94B402D27A1F485804C40F04E3E3DB6C94B40016E162F16824C404FE61F7D93CC4B40016E162F16824C404FE61F7D93CC4B402D27A1F485804C40F04E3E3DB6C94B402D27A1F485804C40
23254	Искирь	7	71	391	55.675047999999997	55.701062999999998	57.039907999999997	57.026423999999999	0103000020E61000000100000005000000779D0DF967D64B402DEA93DC61834C40779D0DF967D64B40A46C91B41B854C40C3B7B06EBCD94B40A46C91B41B854C40C3B7B06EBCD94B402DEA93DC61834C40779D0DF967D64B402DEA93DC61834C40
23913	Зязелга	7	71	391	55.916587	55.95234	56.865319	56.852001999999999	0103000020E6100000010000000500000029780AB952F54B403410CB660E6D4C4029780AB952F54B40C0CDE2C5C26E4C401956F146E6F94B40C0CDE2C5C26E4C401956F146E6F94B403410CB660E6D4C4029780AB952F54B403410CB660E6D4C40
56348	Ермия	7	71	391	55.857469000000002	55.869911000000002	57.124633000000003	57.120894999999997	0103000020E61000000100000005000000BB2A508BC1ED4B40FD9FC37C798F4C40BB2A508BC1ED4B404E8061F9F38F4C4020B75F3E59EF4B404E8061F9F38F4C4020B75F3E59EF4B40FD9FC37C798F4C40BB2A508BC1ED4B40FD9FC37C798F4C40
23130	Елпачиха	7	71	391	55.497504999999997	55.541370000000001	57.097135000000002	57.076838000000002	0103000020E61000000100000005000000594C6C3EAEBF4B40878BDCD3D5894C40594C6C3EAEBF4B40032670EB6E8C4C408C84B69C4BC54B40032670EB6E8C4C408C84B69C4BC54B40878BDCD3D5894C40594C6C3EAEBF4B40878BDCD3D5894C40
23617	Верхний Ашап	7	71	391	55.722909999999999	55.743679	56.608629999999998	56.598056999999997	0103000020E61000000100000005000000C6F99B5088DC4B406A12BC218D4C4C40C6F99B5088DC4B40A7AE7C96E74D4C406ADC9BDF30DF4B40A7AE7C96E74D4C406ADC9BDF30DF4B406A12BC218D4C4C40C6F99B5088DC4B406A12BC218D4C4C40
58283	Верхне-Шлык	7	71	391	55.517493000000002	55.550469999999997	56.717134999999999	56.707614999999997	0103000020E610000001000000050000005874EB353DC24B405B94D920935A4C405874EB353DC24B4092E86514CB5B4C40EDB60BCD75C64B4092E86514CB5B4C40EDB60BCD75C64B405B94D920935A4C405874EB353DC24B405B94D920935A4C40
22945	Брюзли	7	71	391	55.840958000000001	55.863576999999999	56.879009000000003	56.865716999999997	0103000020E61000000100000005000000A0A70183A4EB4B40AD4B8DD0CF6E4C40A0A70183A4EB4B40E1F1ED5D83704C40F549EEB089EE4B40E1F1ED5D83704C40F549EEB089EE4B40AD4B8DD0CF6E4C40A0A70183A4EB4B40AD4B8DD0CF6E4C40
45514	Бичурино	7	71	391	55.406128000000002	55.447082999999999	56.857736000000003	56.834707000000002	0103000020E61000000100000005000000B5FE9600FCB34B40035FD1ADD76A4C40B5FE9600FCB34B400A4D124BCA6D4C407DCC07043AB94B400A4D124BCA6D4C407DCC07043AB94B40035FD1ADD76A4C40B5FE9600FCB34B40035FD1ADD76A4C40
62075	Березники	7	71	391	55.537660000000002	55.568255999999998	56.990409999999997	56.975372	0103000020E61000000100000005000000062FFA0AD2C44B4091B75CFDD87C4C40062FFA0AD2C44B40D0D03FC1C57E4C40BDE0D39CBCC84B40D0D03FC1C57E4C40BDE0D39CBCC84B4091B75CFDD87C4C40062FFA0AD2C44B4091B75CFDD87C4C40
22949	Батырбай	7	71	391	55.799114000000003	55.816217999999999	56.899424000000003	56.887546	0103000020E610000001000000050000004CE3175E49E64B400AD9791B9B714C404CE3175E49E64B40679E5C5320734C400934D8D479E84B40679E5C5320734C400934D8D479E84B400AD9791B9B714C404CE3175E49E64B400AD9791B9B714C40
32820	Бардабашка 1-я	7	71	391	55.333410000000001	55.354717999999998	56.841757999999999	56.824424	0103000020E610000001000000050000006614CB2DADAA4B40CD04C3B986694C406614CB2DADAA4B40BC92E4B9BE6B4C40B9A6406667AD4B40BC92E4B9BE6B4C40B9A6406667AD4B40CD04C3B986694C406614CB2DADAA4B40CD04C3B986694C40
22601	Барда	7	71	391	55.562238000000001	55.615192999999998	56.941768000000003	56.908900000000003	0103000020E61000000100000005000000C3482F6AF7C74B40CEAACFD556744C40C3482F6AF7C74B40AD3594DA8B784C4033DDEBA4BECE4B40AD3594DA8B784C4033DDEBA4BECE4B40CEAACFD556744C40C3482F6AF7C74B40CEAACFD556744C40
33006	Антуфьево	7	71	391	55.936214999999997	55.963219000000002	57.006920999999998	56.996440999999997	0103000020E610000001000000050000002783A3E4D5F74B405FB2F1608B7F4C402783A3E4D5F74B40EB538EC9E2804C4063F19BC24AFB4B40EB538EC9E2804C4063F19BC24AFB4B405FB2F1608B7F4C402783A3E4D5F74B405FB2F1608B7F4C40
22505	Аклуши	7	71	391	55.602742999999997	55.625020999999997	56.853935999999997	56.836154999999998	0103000020E610000001000000050000004B72C0AE26CD4B4085B18520076B4C404B72C0AE26CD4B4043705CC64D6D4C40172829B000D04B4043705CC64D6D4C40172829B000D04B4085B18520076B4C404B72C0AE26CD4B4085B18520076B4C40
58143	Акбаш	7	71	391	55.219754999999999	55.258203000000002	56.968646	56.951208999999999	0103000020E61000000100000005000000F5108DEE209C4B4097546D37C1794C40F5108DEE209C4B405BB39597FC7B4C40535DC0CB0CA14B405BB39597FC7B4C40535DC0CB0CA14B4097546D37C1794C40F5108DEE209C4B4097546D37C1794C40
58080	Лытвенский	7	71	7456	57.553137999999997	57.572020000000002	59.146236000000002	59.132599999999996	0103000020E610000001000000050000006116DA39CDC64C408CB96B09F9904D406116DA39CDC64C40BABF7ADCB7924D4037548CF337C94C40BABF7ADCB7924D4037548CF337C94C408CB96B09F9904D406116DA39CDC64C408CB96B09F9904D40
9589	Яйва	7	71	1088	57.227552000000003	57.302256	59.354016999999999	59.316096999999999	0103000020E61000000100000005000000D811876C209D4C408EAED2DD75A84D40D811876C209D4C40309DD66D50AD4D4088821953B0A64C40309DD66D50AD4D4088821953B0A64C408EAED2DD75A84D40D811876C209D4C408EAED2DD75A84D40
56314	Усть-Игум	7	71	1088	57.131189999999997	57.152552	59.166601999999997	59.154223999999999	0103000020E61000000100000005000000F7C77BD5CA904C401021AE9CBD934D40F7C77BD5CA904C405EB9DE3653954D403E78EDD286934C405EB9DE3653954D403E78EDD286934C401021AE9CBD934D40F7C77BD5CA904C401021AE9CBD934D40
22358	Скопкортная	7	71	1088	57.819173999999997	57.839593000000001	59.397758000000003	59.385891000000001	0103000020E61000000100000005000000E3DD91B1DAE84C400E6954E064B14D40E3DD91B1DAE84C4077DCF0BBE9B24D40AB798EC877EB4C4077DCF0BBE9B24D40AB798EC877EB4C400E6954E064B14D40E3DD91B1DAE84C400E6954E064B14D40
58276	Мыс	7	71	1088	57.027264000000002	57.034891000000002	59.095880000000001	59.092044000000001	0103000020E61000000100000005000000D82D02637D834C4082E50819C88B4D40D82D02637D834C40952BBCCB458C4D405EF6EB4E77844C40952BBCCB458C4D405EF6EB4E77844C4082E50819C88B4D40D82D02637D834C4082E50819C88B4D40
22249	Луньевка	7	71	1088	57.667816999999999	57.695574999999998	59.161014999999999	59.141824	0103000020E610000001000000050000003E5B07077BD54C40DAE4F04927924D403E5B07077BD54C402D95B7239C944D402575029A08D94C402D95B7239C944D402575029A08D94C40DAE4F04927924D403E5B07077BD54C40DAE4F04927924D40
56252	Карьер Известняка	7	71	1088	57.449643000000002	57.490597000000001	59.198495000000001	59.179468	0103000020E610000001000000050000000BF0DDE68DB94C40DA56B3CEF8964D400BF0DDE68DB94C40B3B5BE4868994D400342EBE1CBBE4C40B3B5BE4868994D400342EBE1CBBE4C40DA56B3CEF8964D400BF0DDE68DB94C40DA56B3CEF8964D40
56290	Гремяча	7	71	1088	57.031109000000001	57.045786999999997	59.095177	59.089024999999999	0103000020E610000001000000050000003ECE3461FB834C4061C3D32B658B4D403ECE3461FB834C406B2A8BC22E8C4D407DCA3159DC854C406B2A8BC22E8C4D407DCA3159DC854C4061C3D32B658B4D403ECE3461FB834C4061C3D32B658B4D40
47654	Гари	7	71	1088	57.649797	57.660387999999998	59.453741999999998	59.449964000000001	0103000020E61000000100000005000000FB04508C2CD34C404D309C6B98B94D40FB04508C2CD34C402B69C53714BA4D40DE550F9887D44C402B69C53714BA4D40DE550F9887D44C404D309C6B98B94D40FB04508C2CD34C404D309C6B98B94D40
22075	Всеволодо-Вильва	7	71	1088	57.424373000000003	57.458374999999997	59.234929999999999	59.204056999999999	0103000020E610000001000000050000001827BEDA51B64C408BC22E8A1E9A4D401827BEDA51B64C40B56CAD2F129E4D40E9263108ACBA4C40B56CAD2F129E4D40E9263108ACBA4C408BC22E8A1E9A4D401827BEDA51B64C408BC22E8A1E9A4D40
46220	Булатово	7	71	1088	57.1387	57.149200999999998	59.151528999999996	59.144713000000003	0103000020E6100000010000000500000044FAEDEBC0914C402D27A1F485924D4044FAEDEBC0914C40A2B2614D65934D40E7C3B30419934C40A2B2614D65934D40E7C3B30419934C402D27A1F485924D4044FAEDEBC0914C402D27A1F485924D40
58936	станция Кривозеровка	7	70	\N	42.082307	46.981171000000003	54.029561000000001	52.291775000000001	0103000020E61000000100000005000000AE9D2809890A45402C6519E258254A40AE9D2809890A4540581EA4A7C8034B404E64E602977D4740581EA4A7C8034B404E64E602977D47402C6519E258254A40AE9D2809890A45402C6519E258254A40
12202	Ухтинка	7	70	\N	44.979014999999997	45.059548999999997	53.291013999999997	53.249192000000001	0103000020E610000001000000050000008FA50F5D507D464061360186E59F4A408FA50F5D507D4640CD565EF23FA54A4037C1374D9F874640CD565EF23FA54A4037C1374D9F87464061360186E59F4A408FA50F5D507D464061360186E59F4A40
56420	Сердобск	7	70	\N	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
78	Пенза	7	70	\N	44.849755999999999	45.144995999999999	53.273927	53.092261000000001	0103000020E6100000010000000500000036CAFACDC46C46401FD95C35CF8B4A4036CAFACDC46C4640E63E390A10A34A4081069B3A8F924640E63E390A10A34A4081069B3A8F9246401FD95C35CF8B4A4036CAFACDC46C46401FD95C35CF8B4A40
7144	Кузнецк	7	70	\N	46.543574	46.664748000000003	53.139834	53.089671000000003	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
56419	Каменка	7	70	\N	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
60460	Заречный городской округ	7	70	\N	45.170158000000001	45.213177999999999	53.208385999999997	53.189976000000001	0103000020E610000001000000050000008E93C2BCC79546403083312251984A408E93C2BCC7954640DD787764AC9A4A40041DAD6A499B4640DD787764AC9A4A40041DAD6A499B46403083312251984A408E93C2BCC79546403083312251984A40
58927	Заречный	7	70	\N	46.088487999999998	46.100085	53.897106000000001	53.890096999999997	0103000020E61000000100000005000000520B2593530B474044A2D0B2EEF14A40520B2593530B4740CF85915ED4F24A40FBE8D495CF0C4740CF85915ED4F24A40FBE8D495CF0C474044A2D0B2EEF14A40520B2593530B474044A2D0B2EEF14A40
56427	Белинский	7	70	\N	43.380381999999997	43.434531999999997	52.975012999999997	52.954689999999999	0103000020E6100000010000000500000058FE7C5BB0B04540BCE82B48337A4A4058FE7C5BB0B045406116DA39CD7C4A4061889CBE9EB745406116DA39CD7C4A4061889CBE9EB74540BCE82B48337A4A4058FE7C5BB0B04540BCE82B48337A4A40
17853	Шемышейка	7	70	1077	45.356099999999998	45.417850999999999	52.908377999999999	52.871164999999998	0103000020E61000000100000005000000840D4FAF94AD4640BD35B055826F4A40840D4FAF94AD4640F433F5BA45744A40EACC3D247CB54640F433F5BA45744A40EACC3D247CB54640BD35B055826F4A40840D4FAF94AD4640BD35B055826F4A40
17755	Усть-Уза	7	70	1077	45.283794999999998	45.323051	52.978738	52.954456	0103000020E6100000010000000500000058E2016553A4464049BC3C9D2B7A4A4058E2016553A446401DAD6A49477D4A4055F833BC59A946401DAD6A49477D4A4055F833BC59A9464049BC3C9D2B7A4A4058E2016553A4464049BC3C9D2B7A4A40
9522	Урлейка	7	70	1077	45.112468	45.148850000000003	52.867659000000003	52.854267999999998	0103000020E610000001000000050000005BECF659658E4640790261A7586D4A405BECF659658E4640408A3A730F6F4A403B014D840D934640408A3A730F6F4A403B014D840D934640790261A7586D4A405BECF659658E4640790261A7586D4A40
17589	Старое Назимкино	7	70	1077	45.262881999999998	45.295760999999999	52.887953000000003	52.863821000000002	0103000020E61000000100000005000000815A0C1EA6A146408C4CC0AF916E4A40815A0C1EA6A146404BB1A371A8714A405437177FDBA546404BB1A371A8714A405437177FDBA546408C4CC0AF916E4A40815A0C1EA6A146408C4CC0AF916E4A40
17562	Старое Захаркино	7	70	1077	45.210448	45.269170000000003	52.915041000000002	52.891033	0103000020E610000001000000050000001AC1C6F5EF9A464011548D5E0D724A401AC1C6F5EF9A4640E4BF401020754A403C889D2974A24640E4BF401020754A403C889D2974A2464011548D5E0D724A401AC1C6F5EF9A464011548D5E0D724A40
17493	Старое Демкино	7	70	1077	45.145113000000002	45.187783000000003	52.947864000000003	52.901355000000002	0103000020E61000000100000005000000BB9C121093924640058BC3995F734A40BB9C1210939246402387889B53794A4055DFF945099846402387889B53794A4055DFF94509984640058BC3995F734A40BB9C121093924640058BC3995F734A40
17654	Старая Яксарка	7	70	1077	45.402714000000003	45.442644000000001	53.032967999999997	53.014411000000003	0103000020E6100000010000000500000018D2E1218CB34640F1D93A38D8814A4018D2E1218CB3464042E8A04B38844A40A4E2FF8EA8B8464042E8A04B38844A40A4E2FF8EA8B84640F1D93A38D8814A4018D2E1218CB34640F1D93A38D8814A40
9649	Спасско-Александровка	7	70	1077	45.191223999999998	45.209639000000003	52.796812000000003	52.785680999999997	0103000020E61000000100000005000000EB1A2D077A984640560BEC3191644A40EB1A2D077A984640BA8784EFFD654A40AB7B6473D59A4640BA8784EFFD654A40AB7B6473D59A4640560BEC3191644A40EB1A2D077A984640560BEC3191644A40
17415	Синодское	7	70	1077	45.372107999999997	45.421498	52.694172999999999	52.671866000000001	0103000020E610000001000000050000003C4A253CA1AF4640ADA580B4FF554A403C4A253CA1AF464013622EA9DA584A402AAA7EA5F3B5464013622EA9DA584A402AAA7EA5F3B54640ADA580B4FF554A403C4A253CA1AF4640ADA580B4FF554A40
17407	Русская Норка	7	70	1077	45.364382999999997	45.395186000000002	52.817613000000001	52.795326000000003	0103000020E61000000100000005000000F31B261AA4AE46404AD40B3ECD654A40F31B261AA4AE464069E4F38AA7684A4025EB707495B2464069E4F38AA7684A4025EB707495B246404AD40B3ECD654A40F31B261AA4AE46404AD40B3ECD654A40
17340	Песчанка	7	70	1077	45.569629999999997	45.586329999999997	53.037083000000003	53.025944000000003	0103000020E610000001000000050000000569C6A2E9C8464083C30B2252834A400569C6A2E9C84640691EC022BF844A40F35487DC0CCB4640691EC022BF844A40F35487DC0CCB464083C30B2252834A400569C6A2E9C8464083C30B2252834A40
17276	Новый Мачим	7	70	1077	45.727392000000002	45.754997000000003	52.946106	52.921284999999997	0103000020E610000001000000050000009FAF592E1BDD4640CEA5B8AAEC754A409FAF592E1BDD464052465C001A794A4000CADFBDA3E0464052465C001A794A4000CADFBDA3E04640CEA5B8AAEC754A409FAF592E1BDD4640CEA5B8AAEC754A40
17257	Наумкино	7	70	1077	45.267705999999997	45.310628000000001	52.882758000000003	52.852500999999997	0103000020E61000000100000005000000B378B13044A246405567B5C01E6D4A40B378B13044A246402524D236FE704A40679C86A8C2A746402524D236FE704A40679C86A8C2A746405567B5C01E6D4A40B378B13044A246405567B5C01E6D4A40
17209	Наскафтым	7	70	1077	45.614725	45.648969000000001	52.960661999999999	52.941243999999998	0103000020E610000001000000050000004D840D4FAFCE464032C7F2AE7A784A404D840D4FAFCE46404641F0F8F67A4A40158F8B6A11D346404641F0F8F67A4A40158F8B6A11D3464032C7F2AE7A784A404D840D4FAFCE464032C7F2AE7A784A40
17150	Мордовская Норка	7	70	1077	45.440201000000002	45.477310000000003	52.854692	52.845170000000003	0103000020E610000001000000050000005055A18158B84640B9C7D2872E6C4A405055A18158B846409013268C666D4A40E2067C7E18BD46409013268C666D4A40E2067C7E18BD4640B9C7D2872E6C4A405055A18158B84640B9C7D2872E6C4A40
32699	Мачкасы	7	70	1077	45.553209000000003	45.604241999999999	52.778655000000001	52.762113999999997	0103000020E610000001000000050000002B6D718DCFC6464070E998F38C614A402B6D718DCFC64640F6EE8FF7AA634A40506F46CD57CD4640F6EE8FF7AA634A40506F46CD57CD464070E998F38C614A402B6D718DCFC6464070E998F38C614A40
17059	Колдаис	7	70	1077	45.530320000000003	45.558967000000003	53.083289000000001	53.070169999999997	0103000020E6100000010000000500000016359886E1C3464085949F54FB884A4016359886E1C34640EB8EC536A98A4A4089450C3B8CC74640EB8EC536A98A4A4089450C3B8CC7464085949F54FB884A4016359886E1C3464085949F54FB884A40
16924	Каржимант	7	70	1077	45.519728999999998	45.542537000000003	52.784962999999998	52.763035000000002	0103000020E6100000010000000500000032E4D87A86C24640085A8121AB614A4032E4D87A86C24640F7C8E6AA79644A405BEF37DA71C54640F7C8E6AA79644A405BEF37DA71C54640085A8121AB614A4032E4D87A86C24640085A8121AB614A40
16995	Каргалейка	7	70	1077	45.506371000000001	45.531208999999997	52.688097999999997	52.673357000000003	0103000020E610000001000000050000004852D2C3D0C046402FC4EA8F30564A404852D2C3D0C04640B438639813584A40A12B11A8FEC34640B438639813584A40A12B11A8FEC346402FC4EA8F30564A404852D2C3D0C046402FC4EA8F30564A40
16913	Воробьевка	7	70	1077	45.235277000000004	45.254564000000002	52.821187999999999	52.809677000000001	0103000020E610000001000000050000002140868E1D9E464065A9F57EA3674A402140868E1D9E46400FEF39B01C694A40965E9B8D95A046400FEF39B01C694A40965E9B8D95A0464065A9F57EA3674A402140868E1D9E464065A9F57EA3674A40
16855	Армиево	7	70	1077	45.548870000000001	45.585099	52.875709000000001	52.852880999999996	0103000020E61000000100000005000000B5E0455F41C646409C3061342B6D4A40B5E0455F41C646400CE8853B17704A400EF62686E4CA46400CE8853B17704A400EF62686E4CA46409C3061342B6D4A40B5E0455F41C646409C3061342B6D4A40
16767	Ульяновка	7	70	244	43.254950000000001	43.278557999999997	52.694674999999997	52.677064000000001	0103000020E61000000100000005000000BF0E9C33A2A0454044A67C08AA564A40BF0E9C33A2A04540A52C431CEB584A400305DEC9A7A34540A52C431CEB584A400305DEC9A7A3454044A67C08AA564A40BF0E9C33A2A0454044A67C08AA564A40
15631	Тамала	7	70	244	43.198554000000001	43.282798	52.556612999999999	52.525213000000001	0103000020E61000000100000005000000B83EAC376A9945408F37F92D3A434A40B83EAC376A994540A4C343183F474A40E6AF90B932A44540A4C343183F474A40E6AF90B932A445408F37F92D3A434A40B83EAC376A9945408F37F92D3A434A40
16614	Степной	7	70	244	43.462119000000001	43.481369999999998	52.774123000000003	52.762877000000003	0103000020E610000001000000050000001CEE23B726BB454070EF1AF4A5614A401CEE23B726BB45406C0A647616634A4044A33B889DBD45406C0A647616634A4044A33B889DBD454070EF1AF4A5614A401CEE23B726BB454070EF1AF4A5614A40
56468	Павловка	7	70	244	43.177245999999997	43.185313000000001	52.826183999999998	52.819440999999998	0103000020E6100000010000000500000064AC36FFAF96454032005471E3684A4064AC36FFAF9645403E3DB665C0694A4007431D56B89745403E3DB665C0694A4007431D56B897454032005471E3684A4064AC36FFAF96454032005471E3684A40
56476	Озерки	7	70	244	43.306638999999997	43.323779000000002	52.631067000000002	52.621313999999998	0103000020E61000000100000005000000CD565EF23FA7454002469737874F4A40CD565EF23FA74540DC4AAFCDC6504A40D8101C9771A94540DC4AAFCDC6504A40D8101C9771A9454002469737874F4A40CD565EF23FA7454002469737874F4A40
19385	Обвал	7	70	244	43.234971000000002	43.253107999999997	52.755181999999998	52.738664999999997	0103000020E6100000010000000500000014419C87139E454094D920938C5E4A4014419C87139E45409143C4CDA9604A40902DCBD765A045409143C4CDA9604A40902DCBD765A0454094D920938C5E4A4014419C87139E454094D920938C5E4A40
16141	Никольское	7	70	244	43.398859999999999	43.417752	52.597340000000003	52.581710000000001	0103000020E610000001000000050000005ED72FD80DB34540CAE02879754A4A405ED72FD80DB34540DC4B1AA3754C4A4057EBC4E578B54540DC4B1AA3754C4A4057EBC4E578B54540CAE02879754A4A405ED72FD80DB34540CAE02879754A4A40
963	Наровчат	7	70	244	43.389338000000002	43.398285000000001	52.833936999999999	52.82226	0103000020E61000000100000005000000878BDCD3D5B145408C67D0D03F694A40878BDCD3D5B1454051F69672BE6A4A4062BEBC00FBB2454051F69672BE6A4A4062BEBC00FBB245408C67D0D03F694A40878BDCD3D5B145408C67D0D03F694A40
56510	Мача	7	70	244	43.500926999999997	43.522226000000003	52.714308000000003	52.706581999999997	0103000020E6100000010000000500000079573D601EC045409CF86A47715A4A4079573D601EC04540B6A2CD716E5B4A407A8F334DD8C24540B6A2CD716E5B4A407A8F334DD8C245409CF86A47715A4A4079573D601EC045409CF86A47715A4A40
19685	Малая Сергиевка	7	70	244	43.170239000000002	43.202407000000001	52.509588999999998	52.493454999999997	0103000020E610000001000000050000007BC03C64CA9545401A868F88293F4A407BC03C64CA9545405FB35C363A414A40A1BDFA78E89945405FB35C363A414A40A1BDFA78E89945401A868F88293F4A407BC03C64CA9545401A868F88293F4A40
56448	Липовка	7	70	244	43.278863000000001	43.296353000000003	52.742153999999999	52.734777000000001	0103000020E61000000100000005000000408864C8B1A345402F6D382C0D5E4A40408864C8B1A345403C4CFBE6FE5E4A40278925E5EEA545403C4CFBE6FE5E4A40278925E5EEA545402F6D382C0D5E4A40408864C8B1A345402F6D382C0D5E4A40
19333	Куликовка	7	70	244	43.391807999999997	43.414076999999999	52.814352999999997	52.786934000000002	0103000020E61000000100000005000000D427B9C326B24540240ED940BA644A40D427B9C326B24540223317B83C684A404D83A27900B54540223317B83C684A404D83A27900B54540240ED940BA644A40D427B9C326B24540240ED940BA644A40
16628	Каменка	7	70	244	43.184199	43.200656000000002	52.812170000000002	52.789749999999998	0103000020E610000001000000050000005B7A34D5939745400C022B8716654A405B7A34D5939745406B65C22FF5674A4083DF8618AF9945406B65C22FF5674A4083DF8618AF9945400C022B8716654A405B7A34D5939745400C022B8716654A40
16008	Калиновка	7	70	244	43.073877000000003	43.101301999999997	52.490571000000003	52.472636999999999	0103000020E610000001000000050000009B7631CD7489454095F0845E7F3C4A409B7631CD74894540DAAED007CB3E4A407B82C476F78C4540DAAED007CB3E4A407B82C476F78C454095F0845E7F3C4A409B7631CD7489454095F0845E7F3C4A40
19772	Зубрилово	7	70	244	43.375585000000001	43.401133000000002	52.389049	52.378076999999998	0103000020E6100000010000000500000020EF552B13B04540552FBFD364304A4020EF552B13B0454050C58D5BCC314A40562C7E5358B3454050C58D5BCC314A40562C7E5358B34540552FBFD364304A4020EF552B13B04540552FBFD364304A40
16182	Дуровка	7	70	244	43.375450000000001	43.435583000000001	52.531004000000003	52.506070000000001	0103000020E6100000010000000500000040A4DFBE0EB045404DBED9E6C6404A4040A4DFBE0EB04540C90567F0F7434A40C7D8092FC1B74540C90567F0F7434A40C7D8092FC1B745404DBED9E6C6404A4040A4DFBE0EB045404DBED9E6C6404A40
16318	Григорьевка	7	70	244	43.592177	43.610844	52.781297000000002	52.762784000000003	0103000020E61000000100000005000000C138B874CCCB4540BFF4F6E7A2614A40C138B874CCCB454041BB438A01644A409A7ADD2230CE454041BB438A01644A409A7ADD2230CE4540BFF4F6E7A2614A40C138B874CCCB4540BFF4F6E7A2614A40
18722	Волчий Враг	7	70	244	43.386868	43.426780000000001	52.77178	52.755432999999996	0103000020E6100000010000000500000039EFFFE384B14540DAA84E07B2604A4039EFFFE384B145407BDAE1AFC9624A401F4B1FBAA0B645407BDAE1AFC9624A401F4B1FBAA0B64540DAA84E07B2604A4039EFFFE384B14540DAA84E07B2604A40
19812	Вишневое	7	70	244	43.427695999999997	43.471992	52.652000999999998	52.626333000000002	0103000020E61000000100000005000000A45016BEBEB64540EAB303AE2B504A40A45016BEBEB64540CAFACDC474534A40A0FCDD3B6ABC4540CAFACDC474534A40A0FCDD3B6ABC4540EAB303AE2B504A40A45016BEBEB64540EAB303AE2B504A40
16019	Варварино	7	70	244	43.282105999999999	43.302300000000002	52.469586999999997	52.454315999999999	0103000020E61000000100000005000000B000A60C1CA445405706D506273A4A40B000A60C1CA4454039D0436D1B3C4A4058CA32C4B1A6454039D0436D1B3C4A4058CA32C4B1A645405706D506273A4A40B000A60C1CA445405706D506273A4A40
16306	Большая Сергеевка	7	70	244	43.381827999999999	43.407249999999998	52.664361999999997	52.646576000000003	0103000020E610000001000000050000003A596ABDDFB0454073309B00C3524A403A596ABDDFB04540425A63D009554A40E3A59BC420B44540425A63D009554A40E3A59BC420B4454073309B00C3524A403A596ABDDFB0454073309B00C3524A40
16809	Березовка	7	70	244	43.202893000000003	43.240989999999996	52.605277000000001	52.582656	0103000020E610000001000000050000002ECBD765F8994540BA68C878944A4A402ECBD765F8994540B0027CB7794D4A40DE54A4C2D89E4540B0027CB7794D4A40DE54A4C2D89E4540BA68C878944A4A402ECBD765F8994540BA68C878944A4A40
56473	Алексеевка	7	70	244	43.253773000000002	43.286382000000003	52.676501999999999	52.655208000000002	0103000020E61000000100000005000000CDCD37A27BA04540EE0912DBDD534A40CDCD37A27BA04540DCD6169E97564A40E014562AA8A44540DCD6169E97564A40E014562AA8A44540EE0912DBDD534A40CDCD37A27BA04540EE0912DBDD534A40
33029	Щукино	7	70	1096	46.368825000000001	46.399790000000003	53.449012000000003	53.441616000000003	0103000020E610000001000000050000003E7958A8352F4740F7B182DF86B84A403E7958A8352F47407BC1A73979B94A4049A297512C3347407BC1A73979B94A4049A297512C334740F7B182DF86B84A403E7958A8352F4740F7B182DF86B84A40
33024	Шугурово	7	70	1096	46.463605999999999	46.484968000000002	53.422888	53.400253999999997	0103000020E610000001000000050000005C1D0071573B4740ED0BE8853BB34A405C1D0071573B474078EFA83121B64A40A3CD716E133E474078EFA83121B64A40A3CD716E133E4740ED0BE8853BB34A405C1D0071573B4740ED0BE8853BB34A40
14298	Шкудим	7	70	1096	46.435076000000002	46.464225999999996	53.389820999999998	53.368248999999999	0103000020E6100000010000000500000023A30392B037474071E481C822AF4A4023A30392B0374740A2258FA7E5B14A40F8F9EFC16B3B4740A2258FA7E5B14A40F8F9EFC16B3B474071E481C822AF4A4023A30392B037474071E481C822AF4A40
33016	Топоровка	7	70	1096	46.202646000000001	46.221555000000002	53.366970999999999	53.359571000000003	0103000020E610000001000000050000002655DB4DF019474086CB2A6C06AE4A402655DB4DF01947404BCADDE7F8AE4A40F5A10BEA5B1C47404BCADDE7F8AE4A40F5A10BEA5B1C474086CB2A6C06AE4A402655DB4DF019474086CB2A6C06AE4A40
14236	Тешнярь	7	70	1096	46.233144000000003	46.256284000000001	53.339343999999997	53.317435000000003	0103000020E610000001000000050000001BA19FA9D71D47408ACDC7B5A1A84A401BA19FA9D71D4740020CCB9F6FAB4A40793E03EACD204740020CCB9F6FAB4A40793E03EACD2047408ACDC7B5A1A84A401BA19FA9D71D47408ACDC7B5A1A84A40
14170	Татарский Сыромяс	7	70	1096	45.995035999999999	46.020009000000002	53.427990999999999	53.418810000000001	0103000020E61000000100000005000000DC2BF3565DFF46406F9EEA909BB54A40DC2BF3565DFF4640BDFDB968C8B64A401650A8A78F024740BDFDB968C8B64A401650A8A78F0247406F9EEA909BB54A40DC2BF3565DFF46406F9EEA909BB54A40
32975	Сосновоборск	7	70	1096	46.231329000000002	46.275984000000001	53.317435000000003	53.277534000000003	0103000020E61000000100000005000000E6CE4C309C1D474098C3EE3B86A34A40E6CE4C309C1D47408ACDC7B5A1A84A40111C9771532347408ACDC7B5A1A84A40111C97715323474098C3EE3B86A34A40E6CE4C309C1D474098C3EE3B86A34A40
13842	Русский Качим	7	70	1096	46.666015000000002	46.684393999999998	53.428629000000001	53.413356999999998	0103000020E610000001000000050000009ED2C1FA3F5547404D49D6E1E8B44A409ED2C1FA3F554740008FA850DDB64A4010CAFB389A574740008FA850DDB64A4010CAFB389A5747404D49D6E1E8B44A409ED2C1FA3F5547404D49D6E1E8B44A40
13791	Пичилейка	7	70	1096	46.046796999999998	46.075606000000001	53.368898999999999	53.359490999999998	0103000020E610000001000000050000008446B071FD054740691A14CD03AE4A408446B071FD05474078431A1538AF4A40D1B01875AD09474078431A1538AF4A40D1B01875AD094740691A14CD03AE4A408446B071FD054740691A14CD03AE4A40
13701	Новополянское	7	70	1096	46.549961000000003	46.571340999999997	53.448383999999997	53.434916999999999	0103000020E61000000100000005000000A9893E1F65464740BABC395CABB74A40A9893E1F654647405B069CA564B94A4095EEAEB3214947405B069CA564B94A4095EEAEB321494740BABC395CABB74A40A9893E1F65464740BABC395CABB74A40
13630	Николо-Барнуки	7	70	1096	46.309797000000003	46.331806	53.462743000000003	53.446587999999998	0103000020E6100000010000000500000010B3976DA72747409D64ABCB29B94A4010B3976DA7274740FAB9A1293BBB4A40EC4E779E782A4740FAB9A1293BBB4A40EC4E779E782A47409D64ABCB29B94A4010B3976DA72747409D64ABCB29B94A40
13560	Нижний Мывал	7	70	1096	46.152366999999998	46.177044000000002	53.424900000000001	53.411783999999997	0103000020E61000000100000005000000ACFE08C3801347400E828E56B5B44A40ACFE08C38013474003098A1F63B64A40FDF9B660A916474003098A1F63B64A40FDF9B660A91647400E828E56B5B44A40ACFE08C3801347400E828E56B5B44A40
13508	Нижний Катмис	7	70	1096	45.989781000000001	46.031750000000002	53.259492999999999	53.238776000000001	0103000020E61000000100000005000000E199D024B1FE4640EC884336909E4A40E199D024B1FE46403D450E1137A14A40F2D24D62100447403D450E1137A14A40F2D24D6210044740EC884336909E4A40E199D024B1FE4640EC884336909E4A40
56498	Нижная Липовка	7	70	1096	46.124986	46.156480999999999	53.232891000000002	53.220654000000003	0103000020E610000001000000050000009B3A8F8AFF0F4740A5DDE8633E9C4A409B3A8F8AFF0F474031444E5FCF9D4A4002B9C4910714474031444E5FCF9D4A4002B9C49107144740A5DDE8633E9C4A409B3A8F8AFF0F4740A5DDE8633E9C4A40
13477	Мордовский Качим	7	70	1096	46.641193999999999	46.653922999999999	53.405676	53.374605000000003	0103000020E610000001000000050000001A321EA51252474084F57F0EF3AF4A401A321EA512524740D462F030EDB34A40158DB5BFB3534740D462F030EDB34A40158DB5BFB353474084F57F0EF3AF4A401A321EA51252474084F57F0EF3AF4A40
13351	Малая Садовка	7	70	1096	46.273513999999999	46.300894999999997	53.433785	53.422635999999997	0103000020E61000000100000005000000C37FBA81022347405E0EBBEF18B64A40C37FBA8102234740683F524486B74A40D44334BA83264740683F524486B74A40D44334BA832647405E0EBBEF18B64A40C37FBA81022347405E0EBBEF18B64A40
56514	Кряжим	7	70	1096	46.164934000000002	46.180520000000001	53.471111000000001	53.460839999999997	0103000020E61000000100000005000000CEFFAB8E1C15474025581CCEFCBA4A40CEFFAB8E1C15474097E4805D4DBC4A40102384471B17474097E4805D4DBC4A40102384471B17474025581CCEFCBA4A40CEFFAB8E1C15474025581CCEFCBA4A40
9726	Краснополье	7	70	1096	45.892152000000003	45.905428999999998	53.397736000000002	53.388049000000002	0103000020E61000000100000005000000CF87670932F246406D1FF296ABB14A40CF87670932F246408F386403E9B24A40CCECF318E5F346408F386403E9B24A40CCECF318E5F346406D1FF296ABB14A40CF87670932F246406D1FF296ABB14A40
47732	Козловка	7	70	1096	46.350211999999999	46.370640000000002	53.439636999999998	53.432245000000002	0103000020E6100000010000000500000058552FBFD32C4740056EDDCD53B74A4058552FBFD32C4740478E740646B84A40734BAB21712F4740478E740646B84A40734BAB21712F4740056EDDCD53B74A4058552FBFD32C4740056EDDCD53B74A40
13285	Кардафлей	7	70	1096	46.012984000000003	46.037239	53.337457000000001	53.324680000000001	0103000020E6100000010000000500000086AFAF75A901474028D53E1D8FA94A4086AFAF75A901474034677DCA31AB4A4060915F3FC404474034677DCA31AB4A4060915F3FC404474028D53E1D8FA94A4086AFAF75A901474028D53E1D8FA94A40
56477	Карауловка	7	70	1096	46.218958999999998	46.231544999999997	53.403469999999999	53.395544999999998	0103000020E610000001000000050000001A1538D9061C4740548CF337A1B24A401A1538D9061C47406475ABE7A4B34A40B2463D44A31D47406475ABE7A4B34A40B2463D44A31D4740548CF337A1B24A401A1538D9061C4740548CF337A1B24A40
13193	Индерка	7	70	1096	46.241191999999998	46.282514999999997	53.259422999999998	53.224384999999998	0103000020E6100000010000000500000046072461DF1E4740425BCEA5B89C4A4046072461DF1E4740446ADAC534A14A4091D0967329244740446ADAC534A14A4091D0967329244740425BCEA5B89C4A4046072461DF1E4740425BCEA5B89C4A40
25005	Елюзань	7	70	1096	46.105870000000003	46.142691999999997	53.154685999999998	53.145299999999999	0103000020E6100000010000000500000053D0ED258D0D4740ED0DBE3099924A4053D0ED258D0D4740149337C0CC934A404EB340BB43124740149337C0CC934A404EB340BB43124740ED0DBE3099924A4053D0ED258D0D4740ED0DBE3099924A40
32859	Ега	7	70	1096	46.09872	46.126882000000002	53.323061000000003	53.309209000000003	0103000020E6100000010000000500000006BB61DBA20C47407F50172994A74A4006BB61DBA20C474079CE16105AA94A40BD395CAB3D10474079CE16105AA94A40BD395CAB3D1047407F50172994A74A4006BB61DBA20C47407F50172994A74A40
56472	Дмитриевка	7	70	1096	45.945287	45.972380999999999	53.322712000000003	53.313723000000003	0103000020E61000000100000005000000BF2A172AFFF846406380441328A84A40BF2A172AFFF846406D0377A04EA94A403A2009FB76FC46406D0377A04EA94A403A2009FB76FC46406380441328A84A40BF2A172AFFF846406380441328A84A40
32844	Водолей	7	70	1096	45.981605999999999	46.005043000000001	53.292096000000001	53.265186	0103000020E6100000010000000500000058C7F143A5FD4640B4AD669DF1A14A4058C7F143A5FD46406EA5D76663A54A407009C03FA50047406EA5D76663A54A407009C03FA5004740B4AD669DF1A14A4058C7F143A5FD4640B4AD669DF1A14A40
13000	Верхний Катмис	7	70	1096	46.061124999999997	46.087904000000002	53.404141000000003	53.390331000000003	0103000020E61000000100000005000000E7FBA9F1D2074740B8CEBF5DF6B14A40E7FBA9F1D207474083FC6CE4BAB34A4003983270400B474083FC6CE4BAB34A4003983270400B4740B8CEBF5DF6B14A40E7FBA9F1D2074740B8CEBF5DF6B14A40
12945	Вачелай	7	70	1096	46.168052000000003	46.203462999999999	53.379111999999999	53.365600000000001	0103000020E6100000010000000500000082035ABA8215474074B515FBCBAE4A4082035ABA82154740B5C2F4BD86B04A40187959130B1A4740B5C2F4BD86B04A40187959130B1A474074B515FBCBAE4A4082035ABA8215474074B515FBCBAE4A40
12866	Альмяшевка	7	70	1096	46.046384000000003	46.077312999999997	53.232965999999998	53.221165999999997	0103000020E61000000100000005000000628731E9EF0547405A7EE02A4F9C4A40628731E9EF0547403B8A73D4D19D4A401F477364E50947403B8A73D4D19D4A401F477364E50947405A7EE02A4F9C4A40628731E9EF0547405A7EE02A4F9C4A40
11034	Софьино	7	70	1007	43.931353999999999	43.951467999999998	52.557094999999997	52.538027	0103000020E61000000100000005000000D87F9D9B36F74540B8AE9811DE444A40D87F9D9B36F74540EFE192E34E474A40639813B4C9F94540EFE192E34E474A40639813B4C9F94540B8AE9811DE444A40D87F9D9B36F74540B8AE9811DE444A40
9330	Сердобск	7	70	1007	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
11696	Секретарка	7	70	1007	44.138596	44.212581	52.612150999999997	52.590167999999998	0103000020E610000001000000050000009FAD8383BD114640A79201A08A4B4A409FAD8383BD1146405A9BC6F65A4E4A402060ADDA351B46405A9BC6F65A4E4A402060ADDA351B4640A79201A08A4B4A409FAD8383BD114640A79201A08A4B4A40
11519	Салтыково	7	70	1007	44.325104000000003	44.342801000000001	52.402692999999999	52.378264000000001	0103000020E610000001000000050000003FE603029D29464088A06AF46A304A403FE603029D29464000AAB8718B334A409F0436E7E02B464000AAB8718B334A409F0436E7E02B464088A06AF46A304A403FE603029D29464088A06AF46A304A40
40345	Куракино	7	70	1007	44.025956000000001	44.069803	52.557538000000001	52.535719999999998	0103000020E610000001000000050000004791B5865203464014E8137992444A404791B586520346407D23BA675D474A40D314014EEF0846407D23BA675D474A40D314014EEF08464014E8137992444A404791B5865203464014E8137992444A40
11115	Карповка	7	70	1007	44.046923	44.087859000000002	52.485022000000001	52.464258999999998	0103000020E610000001000000050000001137A79201064640D4EFC2D66C3B4A401137A7920106464096EB6D33153E4A4063D4B5F63E0B464096EB6D33153E4A4063D4B5F63E0B4640D4EFC2D66C3B4A401137A79201064640D4EFC2D66C3B4A40
11166	Камзолка	7	70	1007	43.899545000000003	43.934885000000001	52.487287000000002	52.473047999999999	0103000020E61000000100000005000000E223624A24F3454017B83CD68C3C4A40E223624A24F345400B62A06B5F3E4A40AF42CA4FAAF745400B62A06B5F3E4A40AF42CA4FAAF7454017B83CD68C3C4A40E223624A24F3454017B83CD68C3C4A40
8739	Зеленый Дол	7	70	1007	44.265895999999998	44.285604999999997	52.485652000000002	52.479872	0103000020E61000000100000005000000901150E108224640102219726C3D4A40901150E108224640569E40D8293E4A407B4963B48E244640569E40D8293E4A407B4963B48E244640102219726C3D4A40901150E108224640102219726C3D4A40
33061	Зеленовка	7	70	1007	44.430539000000003	44.500185999999999	52.454754999999999	52.429288999999997	0103000020E610000001000000050000008753E6E61B3746402AC423F1F2364A408753E6E61B374640A3586E69353A4A4062F5471806404640A3586E69353A4A4062F54718064046402AC423F1F2364A408753E6E61B3746402AC423F1F2364A40
10831	Гуленовка	7	70	1007	44.087733	44.103175	52.739341000000003	52.721922999999997	0103000020E61000000100000005000000D6E3BED53A0B4640779D0DF9675C4A40D6E3BED53A0B4640C5CBD3B9A25E4A40E561A1D6340D4640C5CBD3B9A25E4A40E561A1D6340D4640779D0DF9675C4A40D6E3BED53A0B4640779D0DF9675C4A40
56446	Варваровка	7	70	1007	44.397067999999997	44.406626000000003	52.411681000000002	52.407094000000001	0103000020E61000000100000005000000E124CD1FD3324640EC32FCA71B344A40E124CD1FD33246403AB187F6B1344A4006DA1D520C3446403AB187F6B1344A4006DA1D520C344640EC32FCA71B344A40E124CD1FD3324640EC32FCA71B344A40
10798	Байка	7	70	1007	44.198154000000002	44.229855999999998	52.368696999999997	52.349975000000001	0103000020E610000001000000050000002AC93A1C5D19464074B515FBCB2C4A402AC93A1C5D19464010919A76312F4A400A65E1EB6B1D464010919A76312F4A400A65E1EB6B1D464074B515FBCB2C4A402AC93A1C5D19464074B515FBCB2C4A40
32539	Александрово-Ростовка	7	70	1007	44.038389000000002	44.063549999999999	52.533579000000003	52.503284999999998	0103000020E6100000010000000500000059C345EEE90446409FC893A46B404A4059C345EEE90446408C6A11514C444A4095D40968220846408C6A11514C444A4095D40968220846409FC893A46B404A4059C345EEE90446409FC893A46B404A40
9037	совхоз Серп и Молот	7	70	976	44.422293000000003	44.457614	53.207804000000003	53.192354999999999	0103000020E61000000100000005000000352A70B20D3646406D1CB1169F984A40352A70B20D3646402FFD4B52999A4A408B187618933A46402FFD4B52999A4A408B187618933A46406D1CB1169F984A40352A70B20D3646406D1CB1169F984A40
9092	Черенцовка	7	70	976	44.394866999999998	44.434645000000003	53.166094999999999	53.147174	0103000020E6100000010000000500000083A279008B3246402769FE98D6924A4083A279008B324640BA83D89942954A405A2F8672A2374640BA83D89942954A405A2F8672A23746402769FE98D6924A4083A279008B3246402769FE98D6924A40
17695	Усть-Мурза	7	70	976	45.240343000000003	45.267750999999997	52.961388999999997	52.953122	0103000020E610000001000000050000004969368FC39E46408F8CD5E6FF794A404969368FC39E4640F8DD74CB0E7B4A40533C2EAA45A24640F8DD74CB0E7B4A40533C2EAA45A246408F8CD5E6FF794A404969368FC39E46408F8CD5E6FF794A40
10758	Старая Каменка	7	70	976	44.939857000000003	44.975349000000001	52.988280000000003	52.966828999999997	0103000020E6100000010000000500000056F5F23B4D78464085E97B0DC17B4A4056F5F23B4D7846403CA583F57F7E4A40D9976C3CD87C46403CA583F57F7E4A40D9976C3CD87C464085E97B0DC17B4A4056F5F23B4D78464085E97B0DC17B4A40
47018	Софьевка	7	70	976	44.49803	44.501604999999998	53.095326999999997	53.092807999999998	0103000020E61000000100000005000000A4367172BF3F46405167EE21E18B4A40A4367172BF3F464080B6D5AC338C4A404A41B7973440464080B6D5AC338C4A404A41B797344046405167EE21E18B4A40A4367172BF3F46405167EE21E18B4A40
10337	Соловцовка	7	70	976	44.885508999999999	44.906331999999999	52.971401	52.949258999999998	0103000020E6100000010000000500000026A8E15B587146408237A45181794A4026A8E15B587146409E2633DE567C4A40BDA8DDAF027446409E2633DE567C4A40BDA8DDAF027446408237A45181794A4026A8E15B587146408237A45181794A40
10509	Саловка	7	70	976	44.780819000000001	44.815485000000002	53.111643999999998	53.093845999999999	0103000020E61000000100000005000000378C82E0F1634640226E4E25038C4A40378C82E0F1634640B665C0594A8E4A4075B0FECF61684640B665C0594A8E4A4075B0FECF61684640226E4E25038C4A40378C82E0F1634640226E4E25038C4A40
9896	Поперечное	7	70	976	44.341543000000001	44.375822999999997	53.032696999999999	53.017071000000001	0103000020E61000000100000005000000C09657AEB72B4640E25AED612F824A40C09657AEB72B4640B2D6506A2F844A40D40AD3F71A304640B2D6506A2F844A40D40AD3F71A304640E25AED612F824A40C09657AEB72B4640E25AED612F824A40
8977	Пановка	7	70	976	44.625042000000001	44.643861999999999	53.143604000000003	53.136220000000002	0103000020E610000001000000050000002F50526001504640D3872EA86F914A402F5052600150464093C9A99D61924A408E91EC116A52464093C9A99D61924A408E91EC116A524640D3872EA86F914A402F50526001504640D3872EA86F914A40
10266	Оленевка	7	70	976	44.871962000000003	44.892569999999999	52.989190000000001	52.966949	0103000020E6100000010000000500000069AD68739C6F464030F31DFCC47B4A4069AD68739C6F4640DFC325C79D7E4A4003B2D7BB3F724640DFC325C79D7E4A4003B2D7BB3F72464030F31DFCC47B4A4069AD68739C6F464030F31DFCC47B4A40
56488	Никифоровка	7	70	976	45.100906999999999	45.132815000000001	52.949534999999997	52.932820999999997	0103000020E61000000100000005000000FF774485EA8C4640D102B4AD66774A40FF774485EA8C464024B4E55C8A794A4089B5F8140091464024B4E55C8A794A4089B5F81400914640D102B4AD66774A40FF774485EA8C4640D102B4AD66774A40
8624	Надеждино	7	70	976	44.707113	44.731546999999999	52.999147000000001	52.985151999999999	0103000020E61000000100000005000000C9C9C4AD825A464064CBF275197E4A40C9C9C4AD825A4640C172840CE47F4A40533E0455A35D4640C172840CE47F4A40533E0455A35D464064CBF275197E4A40C9C9C4AD825A464064CBF275197E4A40
10031	Ленино	7	70	976	44.884503000000002	44.906539000000002	53.053238	53.009816999999998	0103000020E61000000100000005000000611BF16437714640F0F8F6AE41814A40611BF16437714640C573B680D0864A4037C64E7809744640C573B680D0864A4037C64E7809744640F0F8F6AE41814A40611BF16437714640F0F8F6AE41814A40
8272	Лемзяйка	7	70	976	45.087603000000001	45.099271999999999	52.999386000000001	52.991131000000003	0103000020E6100000010000000500000008043A93368B4640A1866F61DD7E4A4008043A93368B4640460A65E1EB7F4A404AB4E4F1B48C4640460A65E1EB7F4A404AB4E4F1B48C4640A1866F61DD7E4A4008043A93368B4640A1866F61DD7E4A40
9876	Кучки	7	70	976	44.447634000000001	44.543008	53.028818999999999	52.983178000000002	0103000020E61000000100000005000000F14927124C394640C712D6C6D87D4A40F14927124C39464070404B57B0834A40B2BB40498145464070404B57B0834A40B2BB404981454640C712D6C6D87D4A40F14927124C394640C712D6C6D87D4A40
10735	Константиновка	7	70	976	44.721871999999998	44.773254999999999	53.143059000000001	53.131686999999999	0103000020E61000000100000005000000F5F23B4D665C464078279F1EDB904A40F5F23B4D665C46400133DFC14F924A40F73B1405FA6246400133DFC14F924A40F73B1405FA62464078279F1EDB904A40F5F23B4D665C464078279F1EDB904A40
56439	Калинино	7	70	976	44.904715000000003	44.919663	53.079681000000001	53.065128000000001	0103000020E61000000100000005000000AF997CB3CD734640E606431D56884A40AF997CB3CD734640698EACFC328A4A40AE2B6684B7754640698EACFC328A4A40AE2B6684B7754640E606431D56884A40AF997CB3CD734640E606431D56884A40
8836	Ивановка	7	70	976	44.391292	44.414962000000003	53.043163	53.034813999999997	0103000020E61000000100000005000000DD9733DB15324640B2B8FFC874844A40DD9733DB15324640D9B27C5D86854A40988A8D791D354640D9B27C5D86854A40988A8D791D354640B2B8FFC874844A40DD9733DB15324640B2B8FFC874844A40
8947	Загоскино	7	70	976	44.562007999999999	44.598461	53.162244999999999	53.141475999999997	0103000020E61000000100000005000000910BCEE0EF4746409E95B4E21B924A40910BCEE0EF4746404278B471C4944A403A77BB5E9A4C46404278B471C4944A403A77BB5E9A4C46409E95B4E21B924A40910BCEE0EF4746409E95B4E21B924A40
8892	Ермоловка	7	70	976	44.490240999999997	44.531204000000002	53.177450999999998	53.152833999999999	0103000020E6100000010000000500000044149337C03E4640C2DB831090934A4044149337C03E46403DD2E0B6B6964A4090C01F7EFE4346403DD2E0B6B6964A4090C01F7EFE434640C2DB831090934A4044149337C03E4640C2DB831090934A40
56465	Вязовка	7	70	976	44.624071999999998	44.670918999999998	53.272267999999997	53.251752000000003	0103000020E61000000100000005000000B62C5F97E14F4640EF59D76839A04A40B62C5F97E14F4640A8DF85ADD9A24A40ECA17DACE0554640A8DF85ADD9A24A40ECA17DACE0554640EF59D76839A04A40B62C5F97E14F4640EF59D76839A04A40
8802	Воскресеновка	7	70	976	44.939489000000002	44.980308000000001	53.063223000000001	53.044640999999999	0103000020E61000000100000005000000D3F9F02C41784640C687D9CBB6854A40D3F9F02C4178464071ADF6B017884A40EB0088BB7A7D464071ADF6B017884A40EB0088BB7A7D4640C687D9CBB6854A40D3F9F02C41784640C687D9CBB6854A40
9252	Возрождение	7	70	976	45.133308999999997	45.153655999999998	53.123539000000001	53.114730000000002	0103000020E6100000010000000500000098A1F144109146405FEFFE78AF8E4A4098A1F14410914640E9633E20D08F4A40C66AF3FFAA934640E9633E20D08F4A40C66AF3FFAA9346405FEFFE78AF8E4A4098A1F144109146405FEFFE78AF8E4A40
8553	Васильевка	7	70	976	44.680405999999998	44.709781	53.240749000000001	53.217908999999999	0103000020E610000001000000050000004700378B1757464085402E71E49B4A404700378B17574640B9C5FCDCD09E4A403D29931ADA5A4640B9C5FCDCD09E4A403D29931ADA5A464085402E71E49B4A404700378B1757464085402E71E49B4A40
8565	Большая Елань	7	70	976	44.660867000000003	44.711505000000002	53.067112999999999	53.045777999999999	0103000020E61000000100000005000000B900344A975446402A70B20DDC854A40B900344A975446407711A62897884A4062F88898125B46407711A62897884A4062F88898125B46402A70B20DDC854A40B900344A975446402A70B20DDC854A40
56527	Большая Валяевка	7	70	976	45.015019000000002	45.030039000000002	53.074092999999998	53.058827999999998	0103000020E61000000100000005000000C9E88024EC814640670B08AD87874A40C9E88024EC81464067EE21E17B894A40624D6551D883464067EE21E17B894A40624D6551D8834640670B08AD87874A40C9E88024EC814640670B08AD87874A40
8337	Богословка	7	70	976	44.787754	44.821333000000003	53.224190999999998	53.197032	0103000020E6100000010000000500000087A5811FD5644640FB21365838994A4087A5811FD56446405D876A4AB29C4A4013109370216946405D876A4AB29C4A401310937021694640FB21365838994A4087A5811FD5644640FB21365838994A40
56469	Березовая роща	7	70	976	44.341543000000001	45.267750999999997	53.272267999999997	52.909365999999999	0103000020E61000000100000005000000C09657AEB72B4640130CE71A66744A40C09657AEB72B4640A8DF85ADD9A24A40533C2EAA45A24640A8DF85ADD9A24A40533C2EAA45A24640130CE71A66744A40C09657AEB72B4640130CE71A66744A40
10669	Ардымский	7	70	976	44.856943000000001	44.875456999999997	53.078789	53.063276999999999	0103000020E61000000100000005000000A0C4E74EB06D464064CBF27519884A40A0C4E74EB06D46406C2409C2158A4A40F20698F90E7046406C2409C2158A4A40F20698F90E70464064CBF27519884A40A0C4E74EB06D464064CBF27519884A40
8162	Алферьевка	7	70	976	45.139220000000002	45.166313000000002	53.035870000000003	53.018847999999998	0103000020E610000001000000050000007D7901F6D191464029CC7B9C69824A407D7901F6D19146402A745E6397844A4028F38FBE499546402A745E6397844A4028F38FBE4995464029CC7B9C69824A407D7901F6D191464029CC7B9C69824A40
27918	лесничество Засурское	7	70	1831	45.132716000000002	45.144393999999998	53.163626999999998	53.155723000000002	0103000020E61000000100000005000000F6D37FD6FC904640151E34BBEE934A40F6D37FD6FC9046400DDFC2BAF1944A408BDEA9807B9246400DDFC2BAF1944A408BDEA9807B924640151E34BBEE934A40F6D37FD6FC904640151E34BBEE934A40
7830	Шейно	7	70	899	43.181243000000002	43.223114000000002	53.389955	53.351536000000003	0103000020E6100000010000000500000081D07AF832974540EFAEB321FFAC4A4081D07AF832974540B2F4A10BEAB14A40CFA3E2FF8E9C4540B2F4A10BEAB14A40CFA3E2FF8E9C4540EFAEB321FFAC4A4081D07AF832974540EFAEB321FFAC4A40
7858	Черкасское	7	70	899	43.073929999999997	43.127155999999999	53.413099000000003	53.400866000000001	0103000020E61000000100000005000000BD18CA8976894540070ABC934FB34A40BD18CA89768945405281936DE0B44A40BEBED6A5469045405281936DE0B44A40BEBED6A546904540070ABC934FB34A40BD18CA8976894540070ABC934FB34A40
56501	Троицкое	7	70	899	43.309469	43.338977999999997	53.450904999999999	53.440485000000002	0103000020E610000001000000050000001B1021AE9CA7454075B0FECF61B84A401B1021AE9CA745402B4D4A41B7B94A40200890A163AB45402B4D4A41B7B94A40200890A163AB454075B0FECF61B84A401B1021AE9CA7454075B0FECF61B84A40
47986	Топориха	7	70	899	43.228664999999999	43.253351000000002	53.169155000000003	53.155901	0103000020E61000000100000005000000B35E0CE5449D4540F4346090F4934A40B35E0CE5449D45403A7AFCDEA6954A4057B439CE6DA045403A7AFCDEA6954A4057B439CE6DA04540F4346090F4934A40B35E0CE5449D4540F4346090F4934A40
7513	Титово	7	70	899	43.618453000000002	43.690919999999998	53.322862000000001	53.268740999999999	0103000020E610000001000000050000007A8EC87729CF4540130CE71A66A24A407A8EC87729CF4540828FC18A53A94A407F130A1170D84540828FC18A53A94A407F130A1170D84540130CE71A66A24A407A8EC87729CF4540130CE71A66A24A40
7957	Татаро-Никольское	7	70	899	43.012664999999998	43.034188999999998	53.456004	53.438440999999997	0103000020E61000000100000005000000E466B8019F814540DE1CAED51EB84A40E466B8019F8145402F6CCD565EBA4A4004711E4E608445402F6CCD565EBA4A4004711E4E60844540DE1CAED51EB84A40E466B8019F814540DE1CAED51EB84A40
32709	Старая Толковка	7	70	899	43.428674999999998	43.480741000000002	53.450690000000002	53.427866999999999	0103000020E6100000010000000500000070CE88D2DEB64540D1048A58C4B64A4070CE88D2DEB645402F51BD35B0B94A40556CCCEB88BD45402F51BD35B0B94A40556CCCEB88BD4540D1048A58C4B64A4070CE88D2DEB64540D1048A58C4B64A40
56512	РусскоНикольское	7	70	899	43.030029999999996	43.067436000000001	53.438312000000003	53.422168999999997	0103000020E610000001000000050000000EF3E505D8834540483140A209B64A400EF3E505D8834540E1B88C9B1AB84A405A492BBEA1884540E1B88C9B1AB84A405A492BBEA1884540483140A209B64A400EF3E505D8834540483140A209B64A40
32742	Решетино	7	70	899	43.610467	43.634721999999996	53.231608000000001	53.212193999999997	0103000020E61000000100000005000000C4245CC823CE45402634492C299B4A40C4245CC823CE4540F9BEB854A59D4A409E060C923ED14540F9BEB854A59D4A409E060C923ED145402634492C299B4A40C4245CC823CE45402634492C299B4A40
56492	Пустынь	7	70	899	43.520024999999997	43.5456	53.236598999999998	53.208914999999998	0103000020E610000001000000050000001B0DE02D90C2454069520ABABD9A4A401B0DE02D90C2454016A243E0489E4A404B598638D6C5454016A243E0489E4A404B598638D6C5454069520ABABD9A4A401B0DE02D90C2454069520ABABD9A4A40
6966	Пачелма	7	70	899	43.293173000000003	43.342069000000002	53.347236000000002	53.318660999999999	0103000020E61000000100000005000000FD885FB186A545405DC136E2C9A84A40FD885FB186A5454037FFAF3A72AC4A40DBFCBFEAC8AB454037FFAF3A72AC4A40DBFCBFEAC8AB45405DC136E2C9A84A40FD885FB186A545405DC136E2C9A84A40
7752	Пачелма	7	70	899	43.326833000000001	43.386733	53.255629999999996	53.231543000000002	0103000020E610000001000000050000007520EBA9D5A94540124F7633A39D4A407520EBA9D5A9454030F0DC7BB8A04A4059A4897780B1454030F0DC7BB8A04A4059A4897780B14540124F7633A39D4A407520EBA9D5A94540124F7633A39D4A40
7773	Новый Валовай	7	70	899	43.223401000000003	43.252803	53.212311999999997	53.192188000000002	0103000020E6100000010000000500000065726A67989C45408257CB9D99984A4065726A67989C45403046240A2D9B4A4054AA44D95BA045403046240A2D9B4A4054AA44D95BA045408257CB9D99984A4065726A67989C45408257CB9D99984A40
7312	Новая Толковка	7	70	899	43.393901	43.449516000000003	53.395147999999999	53.379499000000003	0103000020E610000001000000050000004C6E14596BB24540AFEE586C93B04A404C6E14596BB24540378AAC3594B24A40AE8383BD89B94540378AAC3594B24A40AE8383BD89B94540AFEE586C93B04A404C6E14596BB24540AFEE586C93B04A40
7426	Мокрый Мичкас	7	70	899	43.584659000000002	43.630355999999999	53.360425999999997	53.334403000000002	0103000020E61000000100000005000000F2272A1BD6CA45409757AEB7CDAA4A40F2272A1BD6CA454065506D7022AE4A402F6B6281AFD0454065506D7022AE4A402F6B6281AFD045409757AEB7CDAA4A40F2272A1BD6CA45409757AEB7CDAA4A40
47307	Кобылкино	7	70	899	43.750416000000001	43.769827999999997	53.206941	53.178552000000003	0103000020E610000001000000050000009432A9A10DE045405551BCCADA964A409432A9A10DE04540CC99ED0A7D9A4A40C5C551B989E24540CC99ED0A7D9A4A40C5C551B989E245405551BCCADA964A409432A9A10DE045405551BCCADA964A40
56507	Калиновка	7	70	899	43.349246000000001	43.381360999999998	53.372810999999999	53.350886000000003	0103000020E610000001000000050000002121CA17B4AC4540E84F1BD5E9AC4A402121CA17B4AC4540664B5645B8AF4A40247CEF6FD0B04540664B5645B8AF4A40247CEF6FD0B04540E84F1BD5E9AC4A402121CA17B4AC4540E84F1BD5E9AC4A40
7674	Ворона	7	70	899	43.415461000000001	43.440021000000002	53.267206000000002	53.236114000000001	0103000020E61000000100000005000000B9E177D32DB545405A10CAFB389E4A40B9E177D32DB54540C2A563CE33A24A40D046AE9B52B84540C2A563CE33A24A40D046AE9B52B845405A10CAFB389E4A40B9E177D32DB545405A10CAFB389E4A40
7594	Белынь	7	70	899	43.470025	43.503864	53.245130000000003	53.226076999999997	0103000020E61000000100000005000000B5A679C729BC45405BB05417F09C4A40B5A679C729BC45405EA27A6B609F4A40DDD0949D7EC045405EA27A6B609F4A40DDD0949D7EC045405BB05417F09C4A40B5A679C729BC45405BB05417F09C4A40
61547	с.Столыпино	7	70	739	45.392895000000003	46.478321000000001	54.029561000000001	53.478597999999998	0103000020E6100000010000000500000087E123624AB246402BF702B342BD4A4087E123624AB24640581EA4A7C8034B40B9FE5D9F393D4740581EA4A7C8034B40B9FE5D9F393D47402BF702B342BD4A4087E123624AB246402BF702B342BD4A40
56511	отдел Совхоза Зеленодольский	7	70	739	46.137391999999998	46.150686999999998	53.695644000000001	53.686307999999997	0103000020E61000000100000005000000B35DA10F96114740D87DC7F0D8D74A40B35DA10F961147404ED4D2DC0AD94A4057772CB6491347404ED4D2DC0AD94A4057772CB649134740D87DC7F0D8D74A40B35DA10F96114740D87DC7F0D8D74A40
5996	Усть-Инза	7	70	739	45.797576999999997	45.825271999999998	53.891986000000003	53.876891999999998	0103000020E610000001000000050000005985CD0017E64640E00F3FFF3DF04A405985CD0017E64640B43EE5982CF24A40FA264D83A2E94640B43EE5982CF24A40FA264D83A2E94640E00F3FFF3DF04A405985CD0017E64640E00F3FFF3DF04A40
6687	Тюнярь	7	70	739	45.818148999999998	45.85136	53.555897999999999	53.534709999999997	0103000020E61000000100000005000000A7203F1BB9E846400D6C956071C44A40A7203F1BB9E84640B6F468AA27C74A40B08F4E5DF9EC4640B6F468AA27C74A40B08F4E5DF9EC46400D6C956071C44A40A7203F1BB9E846400D6C956071C44A40
56447	Сура	7	70	739	45.724032000000001	45.801026999999998	53.896532999999998	53.879556999999998	0103000020E61000000100000005000000F5A0A014ADDC4640E3FBE25295F04A40F5A0A014ADDC46407364E597C1F24A40431B800D88E646407364E597C1F24A40431B800D88E64640E3FBE25295F04A40F5A0A014ADDC4640E3FBE25295F04A40
56483	Субботино	7	70	739	46.061880000000002	46.077995999999999	53.885883	53.869895	0103000020E61000000100000005000000642310AFEB0747401AFA27B858EF4A40642310AFEB0747408B8A389D64F14A40029CDEC5FB0947408B8A389D64F14A40029CDEC5FB0947401AFA27B858EF4A40642310AFEB0747401AFA27B858EF4A40
6174	Старая Селя	7	70	739	46.273001999999998	46.290519000000003	53.702057000000003	53.676707999999998	0103000020E610000001000000050000000DDFC2BAF12247408578245E9ED64A400DDFC2BAF1224740C576F700DDD94A40EEEE01BA2F254740C576F700DDD94A40EEEE01BA2F2547408578245E9ED64A400DDFC2BAF12247408578245E9ED64A40
6319	Серман	7	70	739	46.352798999999997	46.379900999999997	53.577432999999999	53.554971999999999	0103000020E61000000100000005000000DF878384282D47400D198F5209C74A40DF878384282D4740CA501553E9C94A40DD5B9198A0304740CA501553E9C94A40DD5B9198A03047400D198F5209C74A40DF878384282D47400D198F5209C74A40
45721	Родники	7	70	739	45.989843999999998	45.997408	53.812151	53.808396999999999	0103000020E6100000010000000500000027124C35B3FE46409E978A8D79E74A4027124C35B3FE4640F4346090F4E74A406762BA10ABFF4640F4346090F4E74A406762BA10ABFF46409E978A8D79E74A4027124C35B3FE46409E978A8D79E74A40
56451	Ночка	7	70	739	46.090778999999998	46.121178	53.884757999999998	53.877375000000001	0103000020E61000000100000005000000F01472A59E0B4740FCA9F1D24DF04A40F01472A59E0B4740EB6F09C03FF14A40527FBDC2820F4740EB6F09C03FF14A40527FBDC2820F4740FCA9F1D24DF04A40F01472A59E0B4740FCA9F1D24DF04A40
5175	Никольск	7	70	739	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
6580	Нижний Шкафт	7	70	739	45.656632000000002	45.692321999999997	53.610145000000003	53.557856000000001	0103000020E61000000100000005000000E8C072840CD446404EF04DD367C74A40E8C072840CD44640B2683A3B19CE4A409126DE019ED84640B2683A3B19CE4A409126DE019ED846404EF04DD367C74A40E8C072840CD446404EF04DD367C74A40
56458	Междуречье	7	70	739	45.941558999999998	45.997928999999999	53.806063000000002	53.770141000000002	0103000020E6100000010000000500000092205C0185F846408527F4FA93E24A4092205C0185F8464001C287122DE74A40705D3123BCFF464001C287122DE74A40705D3123BCFF46408527F4FA93E24A4092205C0185F846408527F4FA93E24A40
6714	Маис	7	70	739	46.020583999999999	46.051855000000003	53.882598000000002	53.864888000000001	0103000020E6100000010000000500000012691B7FA2024740F75965A6B4EE4A4012691B7FA2024740ECC1A4F8F8F04A402A91442FA3064740ECC1A4F8F8F04A402A91442FA3064740F75965A6B4EE4A4012691B7FA2024740F75965A6B4EE4A40
6921	Кравково	7	70	739	46.136611000000002	46.154854999999998	53.890239999999999	53.882899999999999	0103000020E610000001000000050000000EA320787C114740B7D100DE02F14A400EA320787C114740A7CB6262F3F14A40A04FE449D2134740A7CB6262F3F14A40A04FE449D2134740B7D100DE02F14A400EA320787C114740B7D100DE02F14A40
56493	Кочетовка	7	70	739	45.946150000000003	45.961322000000003	53.870505999999999	53.867500999999997	0103000020E61000000100000005000000228E75711BF94640A71FD4450AEF4A40228E75711BF94640637C98BD6CEF4A4071766B990CFB4640637C98BD6CEF4A4071766B990CFB4640A71FD4450AEF4A40228E75711BF94640A71FD4450AEF4A40
32551	Карамалы	7	70	739	46.113066000000003	46.146717000000002	53.638779999999997	53.616554999999998	0103000020E6100000010000000500000010255AF2780E4740B7973446EBCE4A4010255AF2780E474060AB048BC3D14A403562669FC712474060AB048BC3D14A403562669FC7124740B7973446EBCE4A4010255AF2780E4740B7973446EBCE4A40
6637	Казарка	7	70	739	45.775677000000002	45.843544000000001	53.628838000000002	53.592122000000003	0103000020E6100000010000000500000034A1496249E34640FE9E58A7CACB4A4034A1496249E34640B43D7AC37DD04A40575EF23FF9EB4640B43D7AC37DD04A40575EF23FF9EB4640FE9E58A7CACB4A4034A1496249E34640FE9E58A7CACB4A40
6070	Ильмино	7	70	739	45.639491999999997	45.676825999999998	53.801175999999998	53.771358999999997	0103000020E61000000100000005000000DD06B5DFDAD14640D53C47E4BBE24A40DD06B5DFDAD14640882B67EF8CE64A408F8AFF3BA2D64640882B67EF8CE64A408F8AFF3BA2D64640D53C47E4BBE24A40DD06B5DFDAD14640D53C47E4BBE24A40
56416	Заречный	7	70	739	46.088487999999998	46.100085	53.897106000000001	53.890096999999997	0103000020E61000000100000005000000520B2593530B474044A2D0B2EEF14A40520B2593530B4740CF85915ED4F24A40FBE8D495CF0C4740CF85915ED4F24A40FBE8D495CF0C474044A2D0B2EEF14A40520B2593530B474044A2D0B2EEF14A40
5637	Большое Пермиево	7	70	739	45.988694000000002	46.020026999999999	53.587189000000002	53.575893000000001	0103000020E610000001000000050000002FE065868DFE4640677FA0DCB6C94A402FE065868DFE464015C9570229CB4A40BC04A73E9002474015C9570229CB4A40BC04A73E90024740677FA0DCB6C94A402FE065868DFE4640677FA0DCB6C94A40
6385	Базарная Кеньша	7	70	739	46.236018000000001	46.274394000000001	53.605710999999999	53.589892999999996	0103000020E6100000010000000500000038A27BD6351E4740D591239D81CB4A4038A27BD6351E4740EAE923F087CD4A40FC1BB4571F234740EAE923F087CD4A40FC1BB4571F234740D591239D81CB4A4038A27BD6351E4740D591239D81CB4A40
6538	Аришка	7	70	739	45.539239999999999	45.571587999999998	53.643177999999999	53.619295000000001	0103000020E61000000100000005000000F758FAD005C54640C5C9FD0E45CF4A40F758FAD005C54640DBC01DA853D24A409D64ABCB29C94640DBC01DA853D24A409D64ABCB29C94640C5C9FD0E45CF4A40F758FAD005C54640C5C9FD0E45CF4A40
56453	Усть-Каремша	7	70	463	43.282097	44.199294999999999	53.750599999999999	53.319693999999998	0103000020E610000001000000050000005DA626C11BA445401C5DA5BBEBA84A405DA626C11BA4454055302AA913E04A40CFA0A17F8219464055302AA913E04A40CFA0A17F821946401C5DA5BBEBA84A405DA626C11BA445401C5DA5BBEBA84A40
3766	Старая Мурава	7	70	463	43.579520000000002	43.604826000000003	53.483350999999999	53.477435	0103000020E6100000010000000500000060B01BB62DCA45409E7B0F971CBD4A4060B01BB62DCA454094BE1072DEBD4A40A0E238F06ACD454094BE1072DEBD4A40A0E238F06ACD45409E7B0F971CBD4A4060B01BB62DCA45409E7B0F971CBD4A40
56482	Сорокино	7	70	463	43.366681999999997	43.389077	53.629942999999997	53.610715999999996	0103000020E6100000010000000500000014048F6FEFAE45406C921FF12BCE4A4014048F6FEFAE45400CACE3F8A1D04A401A506F46CDB145400CACE3F8A1D04A401A506F46CDB145406C921FF12BCE4A4014048F6FEFAE45406C921FF12BCE4A40
3856	Серый Ключ	7	70	463	43.521740999999999	43.559190999999998	53.607548000000001	53.579518	0103000020E61000000100000005000000BDFDB968C8C24540BFB854A52DCA4A40BDFDB968C8C2454007600322C4CD4A40D89B189293C7454007600322C4CD4A40D89B189293C74540BFB854A52DCA4A40BDFDB968C8C24540BFB854A52DCA4A40
4002	Прянзерки	7	70	463	43.789788999999999	43.813648000000001	53.623204000000001	53.607201000000003	0103000020E61000000100000005000000CADE52CE17E545409C8C2AC3B8CD4A40CADE52CE17E54540425E0F26C5CF4A40583A1F9E25E84540425E0F26C5CF4A40583A1F9E25E845409C8C2AC3B8CD4A40CADE52CE17E545409C8C2AC3B8CD4A40
3417	Пешая Слобода	7	70	463	43.709631999999999	43.735567000000003	53.543213000000002	53.532060999999999	0103000020E61000000100000005000000F818AC38D5DA4540103D29931AC44A40F818AC38D5DA45408BE1EA0088C54A402882380F27DE45408BE1EA0088C54A402882380F27DE4540103D29931AC44A40F818AC38D5DA4540103D29931AC44A40
2959	Овчарное	7	70	463	43.740282999999998	43.760854000000002	53.530022000000002	53.505955999999998	0103000020E610000001000000050000007364E597C1DE4540849B8C2AC3C04A407364E597C1DE45408C14CAC2D7C34A40F183F3A963E145408C14CAC2D7C34A40F183F3A963E14540849B8C2AC3C04A407364E597C1DE4540849B8C2AC3C04A40
56435	Норовка	7	70	463	43.633895000000003	43.652912999999998	53.541885999999998	53.517817000000001	0103000020E61000000100000005000000890CAB7823D145400B28D4D347C24A40890CAB7823D1454083143C855CC54A400E1137A792D3454083143C855CC54A400E1137A792D345400B28D4D347C24A40890CAB7823D145400B28D4D347C24A40
3630	Новый Шуструй	7	70	463	43.352615	43.379725999999998	53.514583000000002	53.504516000000002	0103000020E610000001000000050000001E8A027D22AD45408527F4FA93C04A401E8A027D22AD4540EE0912DBDDC14A406FB88FDC9AB04540EE0912DBDDC14A406FB88FDC9AB045408527F4FA93C04A401E8A027D22AD45408527F4FA93C04A40
2809	Новая Пятина	7	70	463	43.887633000000001	43.911160000000002	53.580869999999997	53.564669000000002	0103000020E61000000100000005000000D9EC48F59DF145405308E41247C84A40D9EC48F59DF145401F9DBAF259CA4A4031B610E4A0F445401F9DBAF259CA4A4031B610E4A0F445405308E41247C84A40D9EC48F59DF145405308E41247C84A40
4425	Нижний Ломов	7	70	463	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
3221	Мичкасские Выселки	7	70	463	43.766514000000001	43.794155000000003	53.390884	53.361258999999997	0103000020E610000001000000050000008CF678211DE245405D3123BC3DAE4A408CF678211DE24540CC43A67C08B24A403A7AFCDEA6E54540CC43A67C08B24A403A7AFCDEA6E545405D3123BC3DAE4A408CF678211DE245405D3123BC3DAE4A40
32130	Ляча	7	70	463	43.682512000000003	43.710369	53.694727	53.672787999999997	0103000020E6100000010000000500000054909F8D5CD745401492CCEA1DD64A4054909F8D5CD74540F85278D0ECD84A40CE8B135FEDDA4540F85278D0ECD84A40CE8B135FEDDA45401492CCEA1DD64A4054909F8D5CD745401492CCEA1DD64A40
3066	Лещиново	7	70	463	43.924948999999998	43.944623	53.412202999999998	53.374605000000003	0103000020E61000000100000005000000E4BB94BA64F6454084F57F0EF3AF4A40E4BB94BA64F6454013286211C3B44A4053060E68E9F8454013286211C3B44A4053060E68E9F8454084F57F0EF3AF4A40E4BB94BA64F6454084F57F0EF3AF4A40
3805	Кувак-Никольское	7	70	463	43.475199000000003	43.519019	53.638272000000001	53.608910999999999	0103000020E61000000100000005000000C40B2252D3BC45405B96AFCBF0CD4A40C40B2252D3BC4540ECF99AE5B2D14A405680EF366FC24540ECF99AE5B2D14A405680EF366FC245405B96AFCBF0CD4A40C40B2252D3BC45405B96AFCBF0CD4A40
3118	Кривошеевка	7	70	463	43.666063999999999	43.728191000000002	53.537129	53.499412	0103000020E610000001000000050000007F85CC9541D545406F9D7FBBECBF4A407F85CC9541D54540D95DA0A4C0C44A40EB1ED95C35DD4540D95DA0A4C0C44A40EB1ED95C35DD45406F9D7FBBECBF4A407F85CC9541D545406F9D7FBBECBF4A40
4414	Кривозерье	7	70	463	43.837471000000001	43.872847	53.612991999999998	53.603434999999998	0103000020E61000000100000005000000992CEE3F32EB45408121AB5B3DCD4A40992CEE3F32EB4540D55A988576CE4A40B3B45373B9EF4540D55A988576CE4A40B3B45373B9EF45408121AB5B3DCD4A40992CEE3F32EB45408121AB5B3DCD4A40
3556	Козлятское	7	70	463	43.603369999999998	43.619971	53.512452000000003	53.496825000000001	0103000020E610000001000000050000009AB1683A3BCD4540E86A2BF697BF4A409AB1683A3BCD45408962F20698C14A40F5BBB0355BCF45408962F20698C14A40F5BBB0355BCF4540E86A2BF697BF4A409AB1683A3BCD4540E86A2BF697BF4A40
32992	Кера	7	70	463	44.023494999999997	44.063937000000003	53.627968000000003	53.615540000000003	0103000020E610000001000000050000004C4F58E2010346409FB0C403CACE4A404C4F58E2010346409F77634161D04A408F006E162F0846409F77634161D04A408F006E162F0846409FB0C403CACE4A404C4F58E2010346409FB0C403CACE4A40
56417	Заречный	7	70	463	43.526187	43.533706000000002	53.450867000000002	53.447274	0103000020E61000000100000005000000494A7A185AC34540F12C414640B94A40494A7A185AC345403EEC8502B6B94A40E9D66B7A50C445403EEC8502B6B94A40E9D66B7A50C44540F12C414640B94A40494A7A185AC34540F12C414640B94A40
33004	Голицыно	7	70	463	44.095441000000001	44.167270000000002	53.643819000000001	53.610508000000003	0103000020E6100000010000000500000049D92269370C464023F94A2025CE4A4049D92269370C46408FC536A968D24A400CCD751A691546408FC536A968D24A400CCD751A6915464023F94A2025CE4A4049D92269370C464023F94A2025CE4A40
5024	Волженка	7	70	463	43.635018000000002	43.685296999999998	53.510593999999998	53.489758999999999	0103000020E61000000100000005000000882F134548D14540F9F5436CB0BE4A40882F134548D1454054C4E9245BC14A400186E5CFB7D7454054C4E9245BC14A400186E5CFB7D74540F9F5436CB0BE4A40882F134548D14540F9F5436CB0BE4A40
2765	Вирга	7	70	463	43.971662000000002	44.073917000000002	53.471319999999999	53.449806000000002	0103000020E610000001000000050000000B62A06B5FFC4540B5C5353E93B94A400B62A06B5FFC4540B1F9B83654BC4A4029CFBC1C76094640B1F9B83654BC4A4029CFBC1C76094640B5C5353E93B94A400B62A06B5FFC4540B5C5353E93B94A40
3465	Верхний Ломов	7	70	463	43.521974	43.580688000000002	53.493257	53.450496999999999	0103000020E6100000010000000500000060AE450BD0C245401AF9BCE2A9B94A4060AE450BD0C24540F4C29D0B23BF4A40FF9600FC53CA4540F4C29D0B23BF4A40FF9600FC53CA45401AF9BCE2A9B94A4060AE450BD0C245401AF9BCE2A9B94A40
2969	Большой Мичкас	7	70	463	43.907800999999999	43.939224000000003	53.456583000000002	53.432749000000001	0103000020E610000001000000050000005723BBD232F445403830B95164B74A405723BBD232F445406D74CE4F71BA4A4025CFF57D38F845406D74CE4F71BA4A4025CFF57D38F845403830B95164B74A405723BBD232F445403830B95164B74A40
32841	Большая Хутора	7	70	463	43.761769999999999	43.789439000000002	53.565894	53.530365000000003	0103000020E610000001000000050000007689EAAD81E14540B6F81400E3C34A407689EAAD81E145405680EF366FC84A40EE974F560CE545405680EF366FC84A40EE974F560CE54540B6F81400E3C34A407689EAAD81E14540B6F81400E3C34A40
2711	Атмис	7	70	463	43.910027999999997	43.968077999999998	53.50835	53.466436999999999	0103000020E61000000100000005000000DE3829CC7BF445407A522635B4BB4A40DE3829CC7BF44540F775E09C11C14A4011FDDAFAE9FB4540F775E09C11C14A4011FDDAFAE9FB45407A522635B4BB4A40DE3829CC7BF445407A522635B4BB4A40
4155	Аршиновка	7	70	463	43.966217999999998	44.001486	53.613275000000002	53.595286000000002	0103000020E610000001000000050000003C670B08ADFB454022E2E65432CC4A403C670B08ADFB45402A3A92CB7FCE4A4070B378B1300046402A3A92CB7FCE4A4070B378B13000464022E2E65432CC4A403C670B08ADFB454022E2E65432CC4A40
2622	Черталей	7	70	262	46.746028000000003	46.756394	52.701791	52.697108999999998	0103000020E610000001000000050000003DF372D87D5F4740A65F22DE3A594A403DF372D87D5F474046D09849D4594A400072C284D160474046D09849D4594A400072C284D1604740A65F22DE3A594A403DF372D87D5F4740A65F22DE3A594A40
2615	Сулеймановка	7	70	262	46.502350999999997	46.524270000000001	52.772772000000003	52.763421999999998	0103000020E61000000100000005000000730E9E094D4047400186E5CFB7614A40730E9E094D404740DCA16131EA624A40102384471B434740DCA16131EA624A40102384471B4347400186E5CFB7614A40730E9E094D4047400186E5CFB7614A40
2468	Старая Андреевка	7	70	262	46.631106000000003	46.654822000000003	52.844853999999998	52.826357999999999	0103000020E610000001000000050000009A27D714C8504740DC645419C6694A409A27D714C850474088F2052D246C4A40C5591135D153474088F2052D246C4A40C5591135D1534740DC645419C6694A409A27D714C8504740DC645419C6694A40
2391	План	7	70	262	46.663409999999999	46.694167999999998	52.760348	52.730164000000002	0103000020E6100000010000000500000070EB6E9EEA544740B85B9203765D4A4070EB6E9EEA5447401DCA501553614A4001F73C7FDA5847401DCA501553614A4001F73C7FDA584740B85B9203765D4A4070EB6E9EEA544740B85B9203765D4A40
2284	Октябрьское	7	70	262	46.469076999999999	46.513032000000003	52.876818	52.862614000000001	0103000020E61000000100000005000000242713B70A3C47402F89B3226A6E4A40242713B70A3C4740A6457D923B704A4097E65608AB414740A6457D923B704A4097E65608AB4147402F89B3226A6E4A40242713B70A3C47402F89B3226A6E4A40
2266	Новое Чирково	7	70	262	46.861370999999998	46.891061000000001	52.883316999999998	52.870784999999998	0103000020E61000000100000005000000855CA967416E4740766C04E2756F4A40855CA967416E47401B800D8810714A40DBDE6E490E7247401B800D8810714A40DBDE6E490E724740766C04E2756F4A40855CA967416E4740766C04E2756F4A40
1925	Неверкино	7	70	262	46.707445	46.756233000000002	52.800334999999997	52.775637000000003	0103000020E61000000100000005000000FF5BC98E8D5A4740A648BE1248634A40FF5BC98E8D5A47400D6C956071664A40F793313ECC6047400D6C956071664A40F793313ECC604740A648BE1248634A40FF5BC98E8D5A4740A648BE1248634A40
1914	Мансуровка	7	70	262	46.706654999999998	46.715862000000001	52.698822999999997	52.689838999999999	0103000020E610000001000000050000000647C9AB735A4740AF40F4A44C584A400647C9AB735A4740A758350873594A407E39B35DA15B4740A758350873594A407E39B35DA15B4740AF40F4A44C584A400647C9AB735A4740AF40F4A44C584A40
1833	Криволучье	7	70	262	46.646161999999997	46.660400000000003	52.821492999999997	52.812328000000001	0103000020E610000001000000050000007FF5B86FB552474003D0285DFA674A407FF5B86FB55247404B72C0AE26694A40A323B9FC875447404B72C0AE26694A40A323B9FC8754474003D0285DFA674A407FF5B86FB552474003D0285DFA674A40
1783	Карновар	7	70	262	46.743243	46.766851000000003	52.678778999999999	52.666755000000002	0103000020E610000001000000050000008FFD2C96225F4740E5B8533A58554A408FFD2C96225F4740151BF33AE2564A40D4F36E2C28624740151BF33AE2564A40D4F36E2C28624740E5B8533A58554A408FFD2C96225F4740E5B8533A58554A40
1723	Каменный Овраг	7	70	262	46.785356	46.805523000000001	52.757050999999997	52.742851999999999	0103000020E61000000100000005000000D3DB9F8B8664474054E23AC6155F4A40D3DB9F8B86644740B933130CE7604A408196AE601B674740B933130CE7604A408196AE601B67474054E23AC6155F4A40D3DB9F8B8664474054E23AC6155F4A40
1665	Исикеево	7	70	262	46.582076000000001	46.596898000000003	52.799295000000001	52.793196999999999	0103000020E61000000100000005000000ACE46377814A47408524B37A87654A40ACE46377814A47409C6D6E4C4F664A401F865627674C47409C6D6E4C4F664A401F865627674C47408524B37A87654A40ACE46377814A47408524B37A87654A40
1605	Илим-Гора	7	70	262	46.917560999999999	46.950161000000001	52.800319000000002	52.789548000000003	0103000020E61000000100000005000000E38A8BA372754740A54FABE80F654A40E38A8BA37275474008AF5DDA70664A40A3772AE09E79474008AF5DDA70664A40A3772AE09E794740A54FABE80F654A40E38A8BA372754740A54FABE80F654A40
1554	Елшанка	7	70	262	46.609096999999998	46.626561000000002	52.701490999999997	52.692349999999998	0103000020E61000000100000005000000BD8BF7E3F64D47405BB1BFEC9E584A40BD8BF7E3F64D47401BB80375CA594A407BF99D26335047401BB80375CA594A407BF99D26335047405BB1BFEC9E584A40BD8BF7E3F64D47405BB1BFEC9E584A40
1502	Джалилово	7	70	262	46.639622000000003	46.661262999999998	52.811968999999998	52.802622	0103000020E61000000100000005000000ACE63922DF5147406A865451BC664A40ACE63922DF514740D32EA699EE674A4005871744A4544740D32EA699EE674A4005871744A45447406A865451BC664A40ACE63922DF5147406A865451BC664A40
1446	Демино	7	70	262	46.387743999999998	46.438758999999997	52.899742000000003	52.876437000000003	0103000020E61000000100000005000000309C6B98A13147408F006E162F704A40309C6B98A1314740386BF0BE2A734A40AFE9414129384740386BF0BE2A734A40AFE94141293847408F006E162F704A40309C6B98A13147408F006E162F704A40
1376	Бикмурзино	7	70	262	46.795380999999999	46.828277	52.786667000000001	52.775871000000002	0103000020E610000001000000050000000D6E6B0BCF6547401975ADBD4F634A400D6E6B0BCF654740D5EB1681B1644A40B68311FB046A4740D5EB1681B1644A40B68311FB046A47401975ADBD4F634A400D6E6B0BCF6547401975ADBD4F634A40
1317	Бикмосеевка	7	70	262	46.812719000000001	46.837332000000004	52.818255000000001	52.801364	0103000020E610000001000000050000003EEB1A2D076847408B18761893664A403EEB1A2D07684740ED647094BC684A4078F2E9B12D6B4740ED647094BC684A4078F2E9B12D6B47408B18761893664A403EEB1A2D076847408B18761893664A40
1282	Бигеево	7	70	262	46.843845000000002	46.864398999999999	52.855905	52.835084999999999	0103000020E6100000010000000500000052F2EA1C036C4740A930B610E46A4A4052F2EA1C036C4740CFBD874B8E6D4A40F9D85DA0A46E4740CFBD874B8E6D4A40F9D85DA0A46E4740A930B610E46A4A4052F2EA1C036C4740A930B610E46A4A40
1222	Березовка	7	70	262	46.771720000000002	46.807895000000002	52.890946	52.873654999999999	0103000020E61000000100000005000000A6D590B8C7624740527E52EDD36F4A40A6D590B8C76247404240BE840A724A400CCD751A696747404240BE840A724A400CCD751A69674740527E52EDD36F4A40A6D590B8C7624740527E52EDD36F4A40
1109	Алешкино	7	70	262	46.676380999999999	46.692371000000001	52.812458999999997	52.803291000000002	0103000020E61000000100000005000000615111A793564740E8154F3DD2664A40615111A793564740A12B11A8FE674A4073D9E89C9F584740A12B11A8FE674A4073D9E89C9F584740E8154F3DD2664A40615111A793564740E8154F3DD2664A40
1106	Алеево	7	70	262	46.863581000000003	46.889308999999997	52.793337999999999	52.776797000000002	0103000020E6100000010000000500000037397CD2896E4740C25087156E634A4037397CD2896E474047567E198C654A40EC8497E0D471474047567E198C654A40EC8497E0D4714740C25087156E634A4037397CD2896E4740C25087156E634A40
620	Шиловка	7	70	74	43.655715000000001	43.678829	53.910924999999999	53.901021	0103000020E61000000100000005000000923F1878EED345402E01F8A754F34A40923F1878EED34540ED0DBE3099F44A40C74961DEE3D64540ED0DBE3099F44A40C74961DEE3D645402E01F8A754F34A40923F1878EED345402E01F8A754F34A40
484	Телешовка	7	70	74	43.516674000000002	43.545321000000001	53.988273	53.974621999999997	0103000020E61000000100000005000000C558A65F22C2454026FBE769C0FC4A40C558A65F22C245408942CBBA7FFE4A4038691A14CDC545408942CBBA7FFE4A4038691A14CDC5454026FBE769C0FC4A40C558A65F22C2454026FBE769C0FC4A40
537	Суркино	7	70	74	43.542572999999997	43.571202	53.972282	53.957540000000002	0103000020E61000000100000005000000A758350873C54540514EB4AB90FA4A40A758350873C54540A73E90BC73FC4A4074B4AA251DC94540A73E90BC73FC4A4074B4AA251DC94540514EB4AB90FA4A40A758350873C54540514EB4AB90FA4A40
31354	Студенец	7	70	74	43.479610000000001	43.499040000000001	53.819204999999997	53.803213	0103000020E61000000100000005000000D36A48DC63BD45406C5CFFAECFE64A40D36A48DC63BD45401EDC9DB5DBE84A40ABB2EF8AE0BF45401EDC9DB5DBE84A40ABB2EF8AE0BF45406C5CFFAECFE64A40D36A48DC63BD45406C5CFFAECFE64A40
56491	Сосновка	7	70	74	43.777625999999998	43.790965999999997	53.748294000000001	53.740541	0103000020E610000001000000050000007842AF3F89E345406F2C280CCADE4A407842AF3F89E3454082E50819C8DF4A40BC1FB75F3EE5454082E50819C8DF4A40BC1FB75F3EE545406F2C280CCADE4A407842AF3F89E345406F2C280CCADE4A40
56522	Сканово	7	70	74	43.408318999999999	43.973844999999997	54.014549000000002	53.664396000000004	0103000020E61000000100000005000000EFAA07CC43B44540EFCB99ED0AD54A40EFAA07CC43B445404298DBBDDC014B40C22FF5F3A6FC45404298DBBDDC014B40C22FF5F3A6FC4540EFCB99ED0AD54A40EFAA07CC43B44540EFCB99ED0AD54A40
32482	Садовое	7	70	74	43.559479000000003	43.581955000000001	53.834288000000001	53.826917000000002	0103000020E610000001000000050000003FE603029DC74540D3C08F6AD8E94A403FE603029DC74540FEB8FDF2C9EA4A40315F5E807DCA4540FEB8FDF2C9EA4A40315F5E807DCA4540D3C08F6AD8E94A403FE603029DC74540D3C08F6AD8E94A40
368	Савинки	7	70	74	43.437308000000002	43.464365000000001	53.883685999999997	53.872905000000003	0103000020E61000000100000005000000BC2363B5F9B74540E8C1DD59BBEF4A40BC2363B5F9B745406EF7729F1CF14A401A34F44F70BB45406EF7729F1CF14A401A34F44F70BB4540E8C1DD59BBEF4A40BC2363B5F9B74540E8C1DD59BBEF4A40
56513	Рождественно-Тезиково	7	70	74	43.673960000000001	43.697631000000001	53.757095	53.742719000000001	0103000020E61000000100000005000000F5673F5244D64540158F8B6A11DF4A40F5673F5244D64540897B2C7DE8E04A4080D6FCF84BD94540897B2C7DE8E04A4080D6FCF84BD94540158F8B6A11DF4A40F5673F5244D64540158F8B6A11DF4A40
32326	Потодеево	7	70	74	43.664177000000002	43.690902000000001	53.817467000000001	53.797342	0103000020E61000000100000005000000B1E07EC003D5454016DD7A4D0FE64A40B1E07EC003D54540954737C2A2E84A40D95E0B7A6FD84540954737C2A2E84A40D95E0B7A6FD8454016DD7A4D0FE64A40B1E07EC003D5454016DD7A4D0FE64A40
90	Плесковка	7	70	74	43.482016999999999	43.497818000000002	53.840589000000001	53.831961	0103000020E61000000100000005000000DA8EA9BBB2BD45401346B3B27DEA4A40DA8EA9BBB2BD45404D309C6B98EB4A4019AE0E80B8BF45404D309C6B98EB4A4019AE0E80B8BF45401346B3B27DEA4A40DA8EA9BBB2BD45401346B3B27DEA4A40
423	Паны	7	70	74	43.487434	43.514536	53.935633000000003	53.918560999999997	0103000020E61000000100000005000000AF7AC03C64BE4540C630276893F54A40AF7AC03C64BE4540790778D2C2F74A40AD4ECE50DCC14540790778D2C2F74A40AD4ECE50DCC14540C630276893F54A40AF7AC03C64BE4540C630276893F54A40
743	Орловка	7	70	74	43.659821000000001	43.701242000000001	53.949497000000001	53.940190999999999	0103000020E61000000100000005000000651BB80375D445402C7FBE2D58F84A40651BB80375D445403753211E89F94A40734A404CC2D945403753211E89F94A40734A404CC2D945402C7FBE2D58F84A40651BB80375D445402C7FBE2D58F84A40
32062	Новый Пичуры	7	70	74	43.768625	43.810440999999997	53.812443000000002	53.794049999999999	0103000020E61000000100000005000000AAF1D24D62E24540C4B12E6EA3E54A40AAF1D24D62E245409C6ED921FEE74A40342BDB87BCE745409C6ED921FEE74A40342BDB87BCE74540C4B12E6EA3E54A40AAF1D24D62E24540C4B12E6EA3E54A40
850	Наровчат	7	70	74	43.676834999999997	43.713754999999999	53.899180000000001	53.861314999999998	0103000020E61000000100000005000000E2E47E87A2D64540F146E6913FEE4A40E2E47E87A2D64540D09B8A5418F34A40A12DE7525CDB4540D09B8A5418F34A40A12DE7525CDB4540F146E6913FEE4A40E2E47E87A2D64540F146E6913FEE4A40
1031	Мелюковка	7	70	74	43.622495999999998	43.666603000000002	53.893869000000002	53.882752000000004	0103000020E6100000010000000500000006F2ECF2ADCF4540433D7D04FEF04A4006F2ECF2ADCF454041F4A44C6AF24A402F35423F53D5454041F4A44C6AF24A402F35423F53D54540433D7D04FEF04A4006F2ECF2ADCF4540433D7D04FEF04A40
32417	Масловка	7	70	74	43.590074999999999	43.618318000000002	53.801735000000001	53.791145999999998	0103000020E61000000100000005000000F697DD9387CB45403C2EAA4544E54A40F697DD9387CB45407F87A2409FE64A409A43520B25CF45407F87A2409FE64A409A43520B25CF45403C2EAA4544E54A40F697DD9387CB45403C2EAA4544E54A40
633	Кадыковка	7	70	74	43.602283999999997	43.634874000000003	53.961830999999997	53.953195999999998	0103000020E61000000100000005000000B87361A417CD4540C956975302FA4A40B87361A417CD4540B5A338471DFB4A40558A1D8D43D14540B5A338471DFB4A40558A1D8D43D14540C956975302FA4A40B87361A417CD4540C956975302FA4A40
239	Вьюнки	7	70	74	43.523339999999997	43.545824000000003	53.859631	53.846874	0103000020E6100000010000000500000025581CCEFCC2454096EA025E66EC4A4025581CCEFCC245405BD07B6308EE4A409BAF928FDDC545405BD07B6308EE4A409BAF928FDDC5454096EA025E66EC4A4025581CCEFCC2454096EA025E66EC4A40
32270	Виляйки	7	70	74	43.681362	43.712308999999998	53.785640000000001	53.769821	0103000020E610000001000000050000005B5EB9DE36D745401363997E89E24A405B5EB9DE36D74540F836FDD98FE44A40BFD2F9F02CDB4540F836FDD98FE44A40BFD2F9F02CDB45401363997E89E24A405B5EB9DE36D745401363997E89E24A40
252	Большой Чердак	7	70	74	43.591099999999997	43.612074999999997	53.854022999999998	53.846842000000002	0103000020E610000001000000050000003255302AA9CB45408B70935165EC4A403255302AA9CB454012842BA050ED4A407FD93D7958CE454012842BA050ED4A407FD93D7958CE45408B70935165EC4A403255302AA9CB45408B70935165EC4A40
32182	Большой Колояр	7	70	74	43.687793999999997	43.713521999999998	53.723292999999998	53.703704000000002	0103000020E61000000100000005000000483140A209D845403E0801F912DA4A40483140A209D845407E3672DD94DC4A40FE7C5BB054DB45407E3672DD94DC4A40FE7C5BB054DB45403E0801F912DA4A40483140A209D845403E0801F912DA4A40
32106	Большое Кирдяшево	7	70	74	43.761645000000001	43.777400999999998	53.714709999999997	53.702499000000003	0103000020E61000000100000005000000BA1457957DE14540823CBB7CEBD94A40BA1457957DE14540E40F069E7BDB4A4058703FE081E34540E40F069E7BDB4A4058703FE081E34540823CBB7CEBD94A40BA1457957DE14540823CBB7CEBD94A40
56450	Большая Кавенда	7	70	74	43.679485	43.717789000000003	53.849795	53.829458000000002	0103000020E61000000100000005000000B08F4E5DF9D64540EAB303AE2BEA4A40B08F4E5DF9D64540F4A62215C6EC4A40DB368C82E0DB4540F4A62215C6EC4A40DB368C82E0DB4540EAB303AE2BEA4A40B08F4E5DF9D64540EAB303AE2BEA4A40
32587	Азарапино	7	70	74	43.765993000000002	43.788001000000001	53.940541000000003	53.921345000000002	0103000020E6100000010000000500000083FB010F0CE24540A4AA09A2EEF54A4083FB010F0CE2454009C6C1A563F84A408F1B7E37DDE4454009C6C1A563F84A408F1B7E37DDE44540A4AA09A2EEF54A4083FB010F0CE24540A4AA09A2EEF54A40
30328	Юлово	7	70	635	44.592576999999999	44.616419	53.629643999999999	53.610556000000003	0103000020E610000001000000050000004FAE2990D94B46403430F2B226CE4A404FAE2990D94B4640B20FB22C98D04A4007D15AD1E64E4640B20FB22C98D04A4007D15AD1E64E46403430F2B226CE4A404FAE2990D94B46403430F2B226CE4A40
31207	Широкоис	7	70	635	44.153903	44.201666000000003	53.46969	53.443970999999998	0103000020E61000000100000005000000CEE0EF17B3134640ABAFAE0AD4B84A40CEE0EF17B31346400EA14ACD1EBC4A408A5B0531D01946400EA14ACD1EBC4A408A5B0531D0194640ABAFAE0AD4B84A40CEE0EF17B3134640ABAFAE0AD4B84A40
30990	Чернозерье	7	70	635	44.322786000000001	44.350507999999998	53.600639999999999	53.568615999999999	0103000020E61000000100000005000000A7CD380D51294640BDFDB968C8C84A40A7CD380D51294640B05582C5E1CC4A40417E3672DD2C4640B05582C5E1CC4A40417E3672DD2C4640BDFDB968C8C84A40A7CD380D51294640BDFDB968C8C84A40
30251	Царевщино	7	70	635	44.730117999999997	44.772967999999999	53.616101	53.598427999999998	0103000020E61000000100000005000000471CB281745D46405E81E84999CC4A40471CB281745D46403604C765DCCE4A40616D8C9DF06246403604C765DCCE4A40616D8C9DF06246405E81E84999CC4A40471CB281745D46405E81E84999CC4A40
56480	Хованщина	7	70	635	44.357821000000001	44.365070000000003	53.662939999999999	53.657631000000002	0103000020E6100000010000000500000038691A14CD2D4640FBEAAA402DD44A4038691A14CD2D4640E99AC937DBD44A4018601F9DBA2E4640E99AC937DBD44A4018601F9DBA2E4640FBEAAA402DD44A4038691A14CD2D4640FBEAAA402DD44A40
30493	Успенское	7	70	635	44.381867999999997	44.407640999999998	53.328741000000001	53.308579999999999	0103000020E61000000100000005000000C8B1F50CE13046408F19A88C7FA74A40C8B1F50CE13046405BED612F14AA4A401EC18D942D3446405BED612F14AA4A401EC18D942D3446408F19A88C7FA74A40C8B1F50CE13046408F19A88C7FA74A40
31544	Сумароково	7	70	635	44.761667000000003	44.785418999999997	53.532654999999998	53.516092999999998	0103000020E61000000100000005000000A2B8E34D7E614640E658DE550FC24A40A2B8E34D7E6146408386FE092EC44A4019541B9C886446408386FE092EC44A4019541B9C88644640E658DE550FC24A40A2B8E34D7E614640E658DE550FC24A40
31438	Скачки	7	70	635	44.375706000000001	44.399780999999997	53.546809000000003	53.531874000000002	0103000020E610000001000000050000009B745B2217304640DECB7D7214C44A409B745B221730464049145AD6FDC54A40F54718062C33464049145AD6FDC54A40F54718062C334640DECB7D7214C44A409B745B2217304640DECB7D7214C44A40
30427	Симбухово	7	70	635	44.519849999999998	44.541848999999999	53.466903000000002	53.454239999999999	0103000020E61000000100000005000000AD69DE718A4246407C444C8924BA4A40AD69DE718A424640C0B33D7AC3BB4A40662FDB4E5B454640C0B33D7AC3BB4A40662FDB4E5B4546407C444C8924BA4A40AD69DE718A4246407C444C8924BA4A40
30944	Рамзай	7	70	635	44.685777999999999	44.767102000000001	53.316881000000002	53.272333000000003	0103000020E610000001000000050000007C28D192C7574640904FC8CEDBA24A407C28D192C7574640A5DC7D8E8FA84A401D59F96530624640A5DC7D8E8FA84A401D59F96530624640904FC8CEDBA24A407C28D192C7574640904FC8CEDBA24A40
30737	Пяша	7	70	635	44.730333999999999	44.750456	53.283963	53.270668999999998	0103000020E610000001000000050000001494A2957B5D464040852348A5A24A401494A2957B5D464014234BE658A44A40228B34F10E60464014234BE658A44A40228B34F10E60464040852348A5A24A401494A2957B5D464040852348A5A24A40
31163	Потьма	7	70	635	44.058017	44.118113999999998	53.526649999999997	53.506802999999998	0103000020E6100000010000000500000057CEDE196D074640E141B3EBDEC04A4057CEDE196D0746401D38674469C34A4091990B5C1E0F46401D38674469C34A4091990B5C1E0F4640E141B3EBDEC04A4057CEDE196D074640E141B3EBDEC04A40
31091	Подгорное	7	70	635	44.329298999999999	44.361530999999999	53.464083000000002	53.445762000000002	0103000020E6100000010000000500000081CD3978262A464058E6ADBA0EB94A4081CD3978262A464096D05D1267BB4A40BEBED6A5462E464096D05D1267BB4A40BEBED6A5462E464058E6ADBA0EB94A4081CD3978262A464058E6ADBA0EB94A40
31261	Плес	7	70	635	44.442442	44.462015999999998	53.484149000000002	53.469234999999998	0103000020E610000001000000050000003C3080F0A1384640BC9179E40FBC4A403C3080F0A138464010B22C98F8BD4A40471D1D57233B464010B22C98F8BD4A40471D1D57233B4640BC9179E40FBC4A403C3080F0A1384640BC9179E40FBC4A40
31689	Парижская Коммуна	7	70	635	44.575769999999999	44.587510999999999	53.393541999999997	53.38458	0103000020E610000001000000050000004B02D4D4B24946400C59DDEA39B14A404B02D4D4B24946401CCD91955FB24A402785798F334B46401CCD91955FB24A402785798F334B46400C59DDEA39B14A404B02D4D4B24946400C59DDEA39B14A40
30856	Отрадный	7	70	635	44.284337999999998	44.302323000000001	53.262261000000002	53.253270999999998	0103000020E6100000010000000500000049810530652446403A03232F6BA04A4049810530652446401502B9C491A14A4010EA2285B22646401502B9C491A14A4010EA2285B22646403A03232F6BA04A4049810530652446403A03232F6BA04A40
30564	Нечаевка	7	70	635	44.446727000000003	44.481814999999997	53.286175	53.262095000000002	0103000020E61000000100000005000000BF9EAF592E394640FAB836548CA14A40BF9EAF592E39464066F7E461A1A44A4072DC291DAC3D464066F7E461A1A44A4072DC291DAC3D4640FAB836548CA14A40BF9EAF592E394640FAB836548CA14A40
30303	Муратовка	7	70	635	44.694553999999997	44.722034000000001	53.642031000000003	53.623514	0103000020E610000001000000050000002AA73D25E7584640904C874ECFCF4A402AA73D25E7584640540262122ED24A40CF4C309C6B5C4640540262122ED24A40CF4C309C6B5C4640904C874ECFCF4A402AA73D25E7584640904C874ECFCF4A40
31739	Мокшан	7	70	635	44.582211000000001	44.643304999999998	53.465927999999998	53.413426999999999	0103000020E610000001000000050000008C2FDAE3854A464046240A2DEBB44A408C2FDAE3854A464035255987A3BB4A40382D78D15752464035255987A3BB4A40382D78D15752464046240A2DEBB44A408C2FDAE3854A464046240A2DEBB44A40
31260	Михайловка	7	70	635	44.469239000000002	44.504480000000001	53.480929000000003	53.460090000000001	0103000020E61000000100000005000000FE800706103C4640BB9BA73AE4BA4A40FE800706103C46405859DB148FBD4A4038BEF6CC924046405859DB148FBD4A4038BEF6CC92404640BB9BA73AE4BA4A40FE800706103C4640BB9BA73AE4BA4A40
31590	Мирный	7	70	635	44.705036999999997	44.716455000000003	53.368174000000003	53.358829999999998	0103000020E6100000010000000500000027BC04A73E5A46406E693524EEAD4A4027BC04A73E5A4640679E5C5320AF4A40210725CCB45B4640679E5C5320AF4A40210725CCB45B46406E693524EEAD4A4027BC04A73E5A46406E693524EEAD4A40
48787	Лопатино	7	70	635	44.854678999999997	44.868279000000001	53.660207999999997	53.649962000000002	0103000020E61000000100000005000000FBC9181F666D464046D26EF431D34A40FBC9181F666D46405E471CB281D44A40DC662AC4236F46405E471CB281D44A40DC662AC4236F464046D26EF431D34A40FBC9181F666D464046D26EF431D34A40
56495	Ивановка	7	70	635	44.220835999999998	44.238677000000003	53.409922000000002	53.406588999999997	0103000020E61000000100000005000000C5E3A25A441C4640E8F4BC1B0BB44A40C5E3A25A441C464099F4F75278B44A4059A7CAF78C1E464099F4F75278B44A4059A7CAF78C1E4640E8F4BC1B0BB44A40C5E3A25A441C4640E8F4BC1B0BB44A40
31403	Знаменское	7	70	635	44.469507999999998	44.491813	53.538440000000001	53.519204000000002	0103000020E61000000100000005000000ED9A90D6183C4640E8F9D34675C24A40ED9A90D6183C4640DB6D179AEBC44A40B35F77BAF33E4640DB6D179AEBC44A40B35F77BAF33E4640E8F9D34675C24A40ED9A90D6183C4640E8F9D34675C24A40
31488	Засечное	7	70	635	44.653708000000002	44.681466	53.556074000000002	53.541496000000002	0103000020E61000000100000005000000199128B4AC5346401975ADBD4FC54A40199128B4AC534640F513CE6E2DC74A4000AB23473A574640F513CE6E2DC74A4000AB23473A5746401975ADBD4FC54A40199128B4AC5346401975ADBD4FC54A40
58421	Заречный	7	70	635	44.389702	44.405593000000003	53.312550000000002	53.301402000000003	0103000020E61000000100000005000000C89750C1E131464079793A5794A64A40C89750C1E1314640B22E6EA301A84A40473EAF78EA334640B22E6EA301A84A40473EAF78EA33464079793A5794A64A40C89750C1E131464079793A5794A64A40
31657	Заречная	7	70	635	44.596277999999998	44.609555	53.419753999999998	53.407409999999999	0103000020E6100000010000000500000082A966D6524C46401C08C90226B44A4082A966D6524C4640BE2EC37FBAB54A40800EF3E5054E4640BE2EC37FBAB54A40800EF3E5054E46401C08C90226B44A4082A966D6524C46401C08C90226B44A40
30809	Елизаветино	7	70	635	44.524296	44.552548000000002	53.354401000000003	53.337339	0103000020E6100000010000000500000039B69E211C4346402A55A2EC2DAB4A4039B69E211C434640B95510035DAD4A4030BC92E4B9464640B95510035DAD4A4030BC92E4B94646402A55A2EC2DAB4A4039B69E211C4346402A55A2EC2DAB4A40
31079	Долгоруково	7	70	635	44.192396000000002	44.289064000000003	53.627187999999997	53.605907999999999	0103000020E61000000100000005000000CCF09F6EA01846404031B2648ECD4A40CCF09F6EA0184640C93846B247D04A40B939950C00254640C93846B247D04A40B939950C002546404031B2648ECD4A40CCF09F6EA01846404031B2648ECD4A40
30895	Дмитриевка	7	70	635	44.231085999999998	44.246735000000001	53.362301000000002	53.352137999999997	0103000020E610000001000000050000001F48DE39941D4640E4D6A4DB12AD4A401F48DE39941D4640702711E15FAE4A40A8E33103951F4640702711E15FAE4A40A8E33103951F4640E4D6A4DB12AD4A401F48DE39941D4640E4D6A4DB12AD4A40
30384	Богородское	7	70	635	44.518932999999997	44.539720000000003	53.451816000000001	53.435228000000002	0103000020E6100000010000000500000057E883656C424640D926158DB5B74A4057E883656C4246409FE74F1BD5B94A40A27F828B154546409FE74F1BD5B94A40A27F828B15454640D926158DB5B74A4057E883656C424640D926158DB5B74A40
48009	Березовка	7	70	635	44.855531999999997	44.861524000000003	53.649973000000003	53.642606999999998	0103000020E610000001000000050000003A579412826D4640209738F240D24A403A579412826D46403A24B55032D34A400C5C1E6B466E46403A24B55032D34A400C5C1E6B466E4640209738F240D24A403A579412826D4640209738F240D24A40
30174	Алексеевка	7	70	635	44.338507	44.350625000000001	53.648254000000001	53.640006999999997	0103000020E61000000100000005000000C93B8732542B4640041BD7BFEBD14A40C93B8732542B464027C0B0FCF9D24A407B14AE47E12C464027C0B0FCF9D24A407B14AE47E12C4640041BD7BFEBD14A40C93B8732542B4640041BD7BFEBD14A40
30161	Шингал	7	70	1603	44.797187000000001	44.827837000000002	52.480936	52.467140000000001	0103000020E61000000100000005000000EFE53E390A664640A453573ECB3B4A40EFE53E390A6646400ABC934F8F3D4A409AB51490F66946400ABC934F8F3D4A409AB51490F6694640A453573ECB3B4A40EFE53E390A664640A453573ECB3B4A40
29523	Чунаки	7	70	1603	45.253216000000002	45.280974000000001	52.510860999999998	52.483097000000001	0103000020E610000001000000050000007769C36169A04640DAE55B1FD63D4A407769C36169A04640A3E6ABE463414A405E83BEF4F6A34640A3E6ABE463414A405E83BEF4F6A34640DAE55B1FD63D4A407769C36169A04640DAE55B1FD63D4A40
29246	Топлое	7	70	1603	45.013195000000003	45.045490000000001	52.371160000000003	52.354683999999999	0103000020E6100000010000000500000041BCAE5FB08146400D350A49662D4A4041BCAE5FB0814640ACCABE2B822F4A40C425C79DD2854640ACCABE2B822F4A40C425C79DD28546400D350A49662D4A4041BCAE5FB08146400D350A49662D4A40
29598	Старое Славкино	7	70	1603	45.105722	45.156046000000003	52.581856999999999	52.548065999999999	0103000020E61000000100000005000000DE3B6A4C888D46405706D50627464A40DE3B6A4C888D46406EF9484A7A4A4A40F855B950F99346406EF9484A7A4A4A40F855B950F99346405706D50627464A40DE3B6A4C888D46405706D50627464A40
29325	Саполга	7	70	1603	45.065370000000001	45.109242999999999	52.465553999999997	52.449584999999999	0103000020E61000000100000005000000DC114E0B5E884640D6E253008C394A40DC114E0B5E884640D0420246973B4A409128B4ACFB8D4640D0420246973B4A409128B4ACFB8D4640D6E253008C394A40DC114E0B5E884640D6E253008C394A40
29666	Новое Славкино	7	70	1603	45.120750999999998	45.146613000000002	52.537764000000003	52.518352	0103000020E61000000100000005000000CAFACDC4748F464079E8BB5B59424A40CAFACDC4748F4640AB7B6473D5444A409015FC36C4924640AB7B6473D5444A409015FC36C492464079E8BB5B59424A40CAFACDC4748F464079E8BB5B59424A40
29791	Новое Назимкино	7	70	1603	44.951526000000001	44.992373000000001	52.664603	52.651018000000001	0103000020E6100000010000000500000098A59D9ACB794640BD8DCD8E54534A4098A59D9ACB79464068E90AB611554A407A371614067F464068E90AB611554A407A371614067F4640BD8DCD8E54534A4098A59D9ACB794640BD8DCD8E54534A40
29789	Новое Демкино	7	70	1603	45.027963999999997	45.052900999999999	52.644592000000003	52.619219999999999	0103000020E6100000010000000500000090BB085394834640BA83D899424F4A4090BB085394834640B2A19BFD81524A407D76C075C5864640B2A19BFD81524A407D76C075C5864640BA83D899424F4A4090BB085394834640BA83D899424F4A40
30089	Николаевка	7	70	1603	44.821243000000003	44.843629	52.508411000000002	52.492775999999999	0103000020E61000000100000005000000D388997D1E6946407920B248133F4A40D388997D1E6946409DF6949C13414A40857AFA08FC6B46409DF6949C13414A40857AFA08FC6B46407920B248133F4A40D388997D1E6946407920B248133F4A40
30005	Марьевка	7	70	1603	44.845471000000003	44.881717999999999	52.559317999999998	52.546641999999999	0103000020E61000000100000005000000B45BCB64386C46405D4F745DF8454A40B45BCB64386C4640350873BB97474A40B325AB22DC704640350873BB97474A40B325AB22DC7046405D4F745DF8454A40B45BCB64386C46405D4F745DF8454A40
19673	Малая Сердоба	7	70	1603	44.912557	44.997134000000003	52.486902999999998	52.445577999999998	0103000020E61000000100000005000000315EF3AACE74464096E82CB308394A40315EF3AACE74464082A966D6523E4A4066DD3F16A27F464082A966D6523E4A4066DD3F16A27F464096E82CB308394A40315EF3AACE74464096E82CB308394A40
29412	Майское	7	70	1603	45.303324000000003	45.335089000000004	52.438952999999998	52.421376000000002	0103000020E61000000100000005000000C40B2252D3A64640DFA815A6EF354A40C40B2252D3A6464094BDA59C2F384A40EB1F4432E4AA464094BDA59C2F384A40EB1F4432E4AA4640DFA815A6EF354A40C40B2252D3A64640DFA815A6EF354A40
29922	Липовка	7	70	1603	44.948354999999999	44.984521000000001	52.592942000000001	52.572335000000002	0103000020E61000000100000005000000C1FF56B26379464097ADF54542494A40C1FF56B26379464061360186E54B4A40D49CBCC8047E464061360186E54B4A40D49CBCC8047E464097ADF54542494A40C1FF56B26379464097ADF54542494A40
29954	Колемас	7	70	1603	44.862898000000001	44.888285000000003	52.605747000000001	52.586289000000001	0103000020E6100000010000000500000054E41071736E4640958098840B4B4A4054E41071736E46403753211E894D4A408143A852B37146403753211E894D4A408143A852B3714640958098840B4B4A4054E41071736E4640958098840B4B4A40
29705	Ключи	7	70	1603	45.184325000000001	45.203547999999998	52.626890000000003	52.609651999999997	0103000020E61000000100000005000000E86A2BF69797464072F8A413094E4A40E86A2BF697974640401878EE3D504A40469561DC0D9A4640401878EE3D504A40469561DC0D9A464072F8A413094E4A40E86A2BF69797464072F8A413094E4A40
29878	Дружаевка	7	70	1603	45.024262999999998	45.045282999999998	52.617607999999997	52.602350999999999	0103000020E610000001000000050000005DC0CB0C1B83464040DB6AD6194D4A405DC0CB0C1B834640BDDF68C70D4F4A404A0856D5CB854640BDDF68C70D4F4A404A0856D5CB85464040DB6AD6194D4A405DC0CB0C1B83464040DB6AD6194D4A40
29510	Бадровка	7	70	1603	45.247107999999997	45.275854000000002	52.403979	52.393011000000001	0103000020E610000001000000050000003C4A253CA19F4640F0FB372F4E324A403C4A253CA19F4640A9A27895B5334A40433C122F4FA34640A9A27895B5334A40433C122F4FA34640F0FB372F4E324A403C4A253CA19F4640F0FB372F4E324A40
32661	Чирково	7	70	1582	45.132446999999999	45.169736	53.693452999999998	53.681615000000001	0103000020E6100000010000000500000006BAF605F490464045BB0A293FD74A4006BAF605F490464013286211C3D84A40187AC4E8B995464013286211C3D84A40187AC4E8B995464045BB0A293FD74A4006BAF605F490464045BB0A293FD74A40
32549	Сытинка	7	70	1582	44.931251000000003	44.953879999999998	53.663179999999997	53.649529999999999	0103000020E6100000010000000500000004AF963B33774640ACE28DCC23D34A4004AF963B337746403EAE0D15E3D44A407C2766BD187A46403EAE0D15E3D44A407C2766BD187A4640ACE28DCC23D34A4004AF963B33774640ACE28DCC23D34A40
28693	Старая Степановка	7	70	1582	45.153934999999997	45.179805999999999	53.770049999999998	53.759134000000003	0103000020E61000000100000005000000D95A5F24B49346400EA48B4D2BE14A40D95A5F24B4934640742497FF90E24A40F2CF0CE203974640742497FF90E24A40F2CF0CE2039746400EA48B4D2BE14A40D95A5F24B49346400EA48B4D2BE14A40
28370	Старая Кутля	7	70	1582	45.318973	45.353163000000002	53.652768999999999	53.638347000000003	0103000020E610000001000000050000004CA7751BD4A84640F73FC05AB5D14A404CA7751BD4A84640DB6B41EF8DD34A402194F77134AD4640DB6B41EF8DD34A402194F77134AD4640F73FC05AB5D14A404CA7751BD4A84640F73FC05AB5D14A40
27695	Синорово	7	70	1582	45.203980000000001	45.229599999999998	53.564439	53.552956000000002	0103000020E61000000100000005000000E08442041C9A464041102043C7C64A40E08442041C9A464021CB82893FC84A40AF946588639D464021CB82893FC84A40AF946588639D464041102043C7C64A40E08442041C9A464041102043C7C64A40
56444	Родники	7	70	1582	45.086480000000002	45.269862000000003	53.829419999999999	53.624625000000002	0103000020E6100000010000000500000009E1D1C6118B4640CBA145B6F3CF4A4009E1D1C6118B4640FC523F6F2AEA4A40723788D68AA24640FC523F6F2AEA4A40723788D68AA24640CBA145B6F3CF4A4009E1D1C6118B4640CBA145B6F3CF4A40
27777	Напольный Вьяс	7	70	1582	45.434621999999997	45.480822000000003	53.821443000000002	53.805117000000003	0103000020E61000000100000005000000A10F96B1A1B74640113AE8120EE74A40A10F96B1A1B746409A43520B25E94A40429946938BBD46409A43520B25E94A40429946938BBD4640113AE8120EE74A40A10F96B1A1B74640113AE8120EE74A40
19285	Маровка	7	70	1582	45.121352999999999	45.141682000000003	53.784683000000001	53.776031000000003	0103000020E61000000100000005000000C022BF7E888F464052D7DAFB54E34A40C022BF7E888F4640145D177E70E44A404837C2A222924640145D177E70E44A404837C2A22292464052D7DAFB54E34A40C022BF7E888F464052D7DAFB54E34A40
28235	Манторово	7	70	1582	45.239643000000001	45.269511999999999	53.611998	53.593981999999997	0103000020E6100000010000000500000090DB2F9FAC9E4640D234289A07CC4A4090DB2F9FAC9E4640D49B51F355CE4A4095F0845E7FA24640D49B51F355CE4A4095F0845E7FA24640D234289A07CC4A4090DB2F9FAC9E4640D234289A07CC4A40
45614	Лунино	7	70	1582	45.182726000000002	45.247826000000003	53.606859	53.557550999999997	0103000020E610000001000000050000008010C99063974640116DC7D45DC74A408010C990639746404224438EADCD4A409C8C2AC3B89F46404224438EADCD4A409C8C2AC3B89F4640116DC7D45DC74A408010C99063974640116DC7D45DC74A40
56440	Ломовка	7	70	1582	45.356343000000003	45.397224999999999	53.709775	53.686931999999999	0103000020E610000001000000050000004B94BDA59CAD4640B6494563EDD74A404B94BDA59CAD46405B423EE8D9DA4A40A913D044D8B246405B423EE8D9DA4A40A913D044D8B24640B6494563EDD74A404B94BDA59CAD4640B6494563EDD74A40
32668	Липяги	7	70	1582	45.043514000000002	45.073086000000004	53.671967000000002	53.653266000000002	0103000020E610000001000000050000008675E3DD918546405CCB64389ED34A408675E3DD91854640E17EC00303D64A40D2E5CDE15A894640E17EC00303D64A40D2E5CDE15A8946405CCB64389ED34A408675E3DD918546405CCB64389ED34A40
27831	Лесной Вьяс	7	70	1582	45.457152000000001	45.500872999999999	53.783188000000003	53.765754999999999	0103000020E6100000010000000500000087A6ECF483BA4640CEDF844204E24A4087A6ECF483BA4640514F1F813FE44A408639419B1CC04640514F1F813FE44A408639419B1CC04640CEDF844204E24A4087A6ECF483BA4640CEDF844204E24A40
56481	Краснооктябрьский	7	70	1582	44.879095	45.677697000000002	53.926175999999998	53.384799999999998	0103000020E61000000100000005000000DF89592F867046401AC05B2041B14A40DF89592F86704640882B67EF8CF64A4075CC79C6BED64640882B67EF8CF64A4075CC79C6BED646401AC05B2041B14A40DF89592F867046401AC05B2041B14A40
19083	Казачья Пелетьма	7	70	1582	45.403171999999998	45.445338999999997	53.757829999999998	53.737164999999997	0103000020E61000000100000005000000DA54DD239BB34640BF60376C5BDE4A40DA54DD239BB34640BEF6CC9200E14A4011514CDE00B94640BEF6CC9200E14A4011514CDE00B94640BF60376C5BDE4A40DA54DD239BB34640BF60376C5BDE4A40
33050	Иванырсенский Лесозавод	7	70	1582	45.312182	45.335098000000002	53.542197000000002	53.528908999999999	0103000020E610000001000000050000002F336C94F5A74640B0C7444AB3C34A402F336C94F5A74640A27E17B666C54A403E7AC37DE4AA4640A27E17B666C54A403E7AC37DE4AA4640B0C7444AB3C34A402F336C94F5A74640B0C7444AB3C34A40
28050	Иванырс	7	70	1582	45.289095000000003	45.312047	53.572893999999998	53.550452	0103000020E61000000100000005000000F437A11001A5464047020D3675C64A40F437A11001A546408D09319754C94A404FE8F527F1A746408D09319754C94A404FE8F527F1A7464047020D3675C64A40F437A11001A5464047020D3675C64A40
32556	Екатериновка	7	70	1582	45.196424999999998	45.229841999999998	53.531381000000003	53.509276999999997	0103000020E61000000100000005000000F38E53742499464070CD1DFD2FC14A40F38E5374249946409F5BE84A04C44A40A59F70766B9D46409F5BE84A04C44A40A59F70766B9D464070CD1DFD2FC14A40F38E53742499464070CD1DFD2FC14A40
27868	Дарьевка	7	70	1582	45.310079999999999	45.350872000000003	53.8705	53.860990999999999	0103000020E61000000100000005000000649291B3B0A746403E93FDF334EE4A40649291B3B0A746408195438B6CEF4A40838AAA5FE9AC46408195438B6CEF4A40838AAA5FE9AC46403E93FDF334EE4A40649291B3B0A746403E93FDF334EE4A40
27763	Большой Вьяс	7	70	1582	45.466529999999999	45.524543000000001	53.833337	53.788412000000001	0103000020E610000001000000050000002B4D4A41B7BB464011E335AFEAE44A402B4D4A41B7BB4640FCC56CC9AAEA4A40412C9B3924C34640FCC56CC9AAEA4A40412C9B3924C3464011E335AFEAE44A402B4D4A41B7BB464011E335AFEAE44A40
33130	Болотниково	7	70	1582	44.946837000000002	44.973776999999998	53.596423999999999	53.589097000000002	0103000020E6100000010000000500000046D26EF431794640FB95CE8767CB4A4046D26EF4317946405646239F57CC4A406A4C88B9A47C46405646239F57CC4A406A4C88B9A47C4640FB95CE8767CB4A4046D26EF431794640FB95CE8767CB4A40
27539	Чардым	7	70	1798	45.751009000000003	45.776466999999997	52.655377000000001	52.638871000000002	0103000020E6100000010000000500000037001B1021E0464071AE6186C6514A4037001B1021E046407AC6BE64E3534A402CB6494563E346407AC6BE64E3534A402CB6494563E3464071AE6186C6514A4037001B1021E0464071AE6186C6514A40
33120	Точка	7	70	1798	45.907361000000002	45.923305999999997	52.508119999999998	52.496619000000003	0103000020E610000001000000050000003B55BE6724F446403FC91D36913F4A403B55BE6724F44640C5387F130A414A40AC1919E42EF64640C5387F130A414A40AC1919E42EF646403FC91D36913F4A403B55BE6724F446403FC91D36913F4A40
27364	Суляевка	7	70	1798	45.902428999999998	45.928829999999998	52.655869000000003	52.635953000000001	0103000020E6100000010000000500000022FB20CB82F3464084656CE866514A4022FB20CB82F34640E9BAF083F3534A4097C5C4E6E3F64640E9BAF083F3534A4097C5C4E6E3F6464084656CE866514A4022FB20CB82F3464084656CE866514A40
27464	Старый Карлыган	7	70	1798	45.808033999999999	45.832512999999999	52.478023	52.462387999999997	0103000020E610000001000000050000002D077AA86DE746400B08AD872F3B4A402D077AA86DE746402FDE8FDB2F3D4A40573F36C98FEA46402FDE8FDB2F3D4A40573F36C98FEA46400B08AD872F3B4A402D077AA86DE746400B08AD872F3B4A40
27393	Старый Вершаут	7	70	1798	45.761015999999998	45.794676000000003	52.541932000000003	52.526510999999999	0103000020E61000000100000005000000CADDE7F868E14640FCFD62B664434A40CADDE7F868E14640F4531C075E454A40437573F1B7E54640F4531C075E454A40437573F1B7E54640FCFD62B664434A40CADDE7F868E14640FCFD62B664434A40
56459	Сорокино	7	70	1798	45.480561999999999	45.501725999999998	52.437745	52.421562999999999	0103000020E61000000100000005000000A5D93C0E83BD4640111AC1C6F5354A40A5D93C0E83BD4640677E350708384A40C5C6BC8E38C04640677E350708384A40C5C6BC8E38C04640111AC1C6F5354A40A5D93C0E83BD4640111AC1C6F5354A40
27244	Пылково	7	70	1798	45.854081000000001	45.887067999999999	52.706189000000002	52.670096999999998	0103000020E610000001000000050000004791B58652ED4640E8120EBDC5554A404791B58652ED4640C1E5B166645A4A4000AAB8718BF14640C1E5B166645A4A4000AAB8718BF14640E8120EBDC5554A404791B58652ED4640E8120EBDC5554A40
56552	Пасечное	7	70	1798	45.273761	46.182496999999998	52.770297999999997	52.385739999999998	0103000020E61000000100000005000000CBF5B6990AA346402861A6ED5F314A40CBF5B6990AA346404C16F71F99624A401E4FCB0F5C1747404C16F71F99624A401E4FCB0F5C1747402861A6ED5F314A40CBF5B6990AA346402861A6ED5F314A40
33087	Огаревка	7	70	1798	45.414931000000003	45.440821	52.495384999999999	52.479756999999999	0103000020E610000001000000050000005D8C81751CB54640778368AD683D4A405D8C81751CB54640E8F692C6683F4A40EC3191D26CB84640E8F692C6683F4A40EC3191D26CB84640778368AD683D4A405D8C81751CB54640778368AD683D4A40
56471	Николаевка	7	70	1798	45.833779999999997	45.857657000000003	52.606496	52.592258000000001	0103000020E610000001000000050000008907944DB9EA4640AE65321CCF4B4A408907944DB9EA4640D19332A9A14D4A40BE175FB4C7ED4640D19332A9A14D4A40BE175FB4C7ED4640AE65321CCF4B4A408907944DB9EA4640AE65321CCF4B4A40
27103	Луначарское	7	70	1798	45.677976000000001	45.705751999999997	52.706893000000001	52.691526000000003	0103000020E6100000010000000500000088BCE5EAC7D64640B72A89EC83584A4088BCE5EAC7D64640BB6246787B5A4A40158BDF1456DA4640BB6246787B5A4A40158BDF1456DA4640B72A89EC83584A4088BCE5EAC7D64640B72A89EC83584A40
33059	Колбинка	7	70	1798	45.481676	45.503801000000003	52.593938000000001	52.584297999999997	0103000020E6100000010000000500000051A2258FA7BD4640218FE046CA4A4A4051A2258FA7BD464003ED0E29064C4A409758198D7CC0464003ED0E29064C4A409758198D7CC04640218FE046CA4A4A4051A2258FA7BD4640218FE046CA4A4A40
26973	Китунькино	7	70	1798	45.998494999999998	46.031525999999999	52.583362000000001	52.572231000000002	0103000020E61000000100000005000000191C25AFCEFF4640F2608BDD3E494A40191C25AFCEFF464055DD239BAB4A4A40A27C410B0904474055DD239BAB4A4A40A27C410B09044740F2608BDD3E494A40191C25AFCEFF4640F2608BDD3E494A40
26831	Камаевка	7	70	1798	45.579422000000001	45.608626000000001	52.624425000000002	52.612577000000002	0103000020E610000001000000050000009D4A06802ACA464012A452EC684E4A409D4A06802ACA464004E78C28ED4F4A4066BFEE74E7CD464004E78C28ED4F4A4066BFEE74E7CD464012A452EC684E4A409D4A06802ACA464012A452EC684E4A40
33046	Дубровское	7	70	1798	45.960433000000002	45.983438999999997	52.488515	52.475259000000001	0103000020E61000000100000005000000E57FF277EFFA464099107349D53C4A40E57FF277EFFA46407F4DD6A8873E4A40334E4354E1FD46407F4DD6A8873E4A40334E4354E1FD464099107349D53C4A40E57FF277EFFA464099107349D53C4A40
56433	Даниловка	7	70	1798	45.345526999999997	45.399687	52.561497000000003	52.518006999999997	0103000020E6100000010000000500000047718E3A3AAC4640AE0CAA0D4E424A4047718E3A3AAC4640ACE63922DF474A4074D190F128B34640ACE63922DF474A4074D190F128B34640AE0CAA0D4E424A4047718E3A3AAC4640AE0CAA0D4E424A40
26641	Генеральщино	7	70	1798	45.874724999999998	45.908878999999999	52.553870000000003	52.52919	0103000020E610000001000000050000002EFF21FDF6EF464064AF777FBC434A402EFF21FDF6EF4640261E5036E5464A40B682A62556F44640261E5036E5464A40B682A62556F4464064AF777FBC434A402EFF21FDF6EF464064AF777FBC434A40
33030	Владимирский	7	70	1798	45.675299000000003	45.692743999999998	52.627862999999998	52.618543000000003	0103000020E61000000100000005000000C102983270D64640BA15C26A2C4F4A40C102983270D6464029AF95D05D504A400740DCD5ABD8464029AF95D05D504A400740DCD5ABD84640BA15C26A2C4F4A40C102983270D64640BA15C26A2C4F4A40
56519	Вехово	7	70	1798	45.273761	46.182496999999998	52.770297999999997	52.385739999999998	0103000020E61000000100000005000000CBF5B6990AA346402861A6ED5F314A40CBF5B6990AA346404C16F71F99624A401E4FCB0F5C1747404C16F71F99624A401E4FCB0F5C1747402861A6ED5F314A40CBF5B6990AA346402861A6ED5F314A40
26560	Верешим	7	70	1798	45.535350000000001	45.565128999999999	52.558512999999998	52.535500999999996	0103000020E61000000100000005000000F1F44A5986C44640D6FCF84B8B444A40F1F44A5986C4464007B29E5A7D474A40B682A62556C8464007B29E5A7D474A40B682A62556C84640D6FCF84B8B444A40F1F44A5986C44640D6FCF84B8B444A40
26447	Бузовлево	7	70	1798	45.656820000000003	45.671903	52.745316000000003	52.727519000000001	0103000020E61000000100000005000000EBAD81AD12D44640FC1BB4571F5D4A40EBAD81AD12D44640C097C283665F4A40CA8AE1EA00D64640C097C283665F4A40CA8AE1EA00D64640FC1BB4571F5D4A40EBAD81AD12D44640FC1BB4571F5D4A40
33025	Буденновка	7	70	1798	45.597405999999999	45.625433000000001	52.624228000000002	52.611843999999998	0103000020E610000001000000050000009337C0CC77CC46407D2079E7504E4A409337C0CC77CC4640AE9FFEB3E64F4A406A6B44300ED04640AE9FFEB3E64F4A406A6B44300ED046407D2079E7504E4A409337C0CC77CC46407D2079E7504E4A40
26351	Берлик	7	70	1798	45.708571999999997	45.724491	52.472692000000002	52.462822000000003	0103000020E610000001000000050000003F6EBF7CB2DA464046EF54C03D3B4A403F6EBF7CB2DA4640598AE42B813C4A40889FFF1EBCDC4640598AE42B813C4A40889FFF1EBCDC464046EF54C03D3B4A403F6EBF7CB2DA464046EF54C03D3B4A40
33007	Белогорье	7	70	1798	45.868786999999998	45.890248	52.443492999999997	52.428382999999997	0103000020E610000001000000050000005018946934EF4640C8940F41D5364A405018946934EF4640A180ED60C4384A402AAA7EA5F3F14640A180ED60C4384A402AAA7EA5F3F14640C8940F41D5364A405018946934EF4640C8940F41D5364A40
56563	с.Татарская Пенделка	7	70	1367	46.124294999999996	46.973579999999998	53.408644000000002	52.848199000000001	0103000020E61000000100000005000000350708E6E80F4740FDBFEAC8916C4A40350708E6E80F474073DA53724EB44A401405FA449E7C474073DA53724EB44A401405FA449E7C4740FDBFEAC8916C4A40350708E6E80F4740FDBFEAC8916C4A40
25884	Ясная Поляна	7	70	1367	46.646602000000001	46.66986	53.045561999999997	53.033368000000003	0103000020E610000001000000050000009CC3B5DAC3524740D15D126745844A409CC3B5DAC35247405DF8C1F9D4854A400473F4F8BD5547405DF8C1F9D4854A400473F4F8BD554740D15D126745844A409CC3B5DAC3524740D15D126745844A40
24603	Явлейка	7	70	1367	46.799100000000003	46.814712999999998	53.282637999999999	53.259466000000003	0103000020E61000000100000005000000E71DA7E8486647404436902E36A14A40E71DA7E848664740AD4D637B2DA44A402250FD8348684740AD4D637B2DA44A402250FD83486847404436902E36A14A40E71DA7E8486647404436902E36A14A40
24399	Шелемис	7	70	1367	46.642865	46.653061000000001	53.267685	53.243966	0103000020E610000001000000050000001C5F7B664952474000AB23473A9F4A401C5F7B66495247409C50888043A24A4083A5BA80975347409C50888043A24A4083A5BA809753474000AB23473A9F4A401C5F7B664952474000AB23473A9F4A40
25471	Чибирлей	7	70	1367	46.607391	46.642541999999999	52.992789999999999	52.968012000000002	0103000020E610000001000000050000003F7100FDBE4D47405A1135D1E77B4A403F7100FDBE4D4740DEE522BE137F4A403927F6D03E524740DEE522BE137F4A403927F6D03E5247405A1135D1E77B4A403F7100FDBE4D47405A1135D1E77B4A40
19980	Часы	7	70	1367	46.721952999999999	46.772339000000002	53.364390999999998	53.349564000000001	0103000020E61000000100000005000000E21FB6F4685C4740F2ED5D83BEAC4A40E21FB6F4685C474076FA415DA4AE4A4072361D01DC62474076FA415DA4AE4A4072361D01DC624740F2ED5D83BEAC4A40E21FB6F4685C4740F2ED5D83BEAC4A40
25402	Тютнярь	7	70	1367	46.351640000000003	46.374547	52.992134	52.977187000000001	0103000020E6100000010000000500000094FB1D8A022D4740C689AF76147D4A4094FB1D8A022D4740F59F353FFE7E4A404FE8F527F12F4740F59F353FFE7E4A404FE8F527F12F4740C689AF76147D4A4094FB1D8A022D4740C689AF76147D4A40
20128	Тихменево	7	70	1367	46.737924999999997	46.749316	53.276113000000002	53.267679999999999	0103000020E610000001000000050000004DF38E53745E47408AE5965643A24A404DF38E53745E47400F80B8AB57A34A404D2F3196E95F47400F80B8AB57A34A404D2F3196E95F47408AE5965643A24A404DF38E53745E47408AE5965643A24A40
26123	Татарский Канадей	7	70	1367	46.910077999999999	46.941392999999998	53.101162000000002	53.090741999999999	0103000020E610000001000000050000009067976F7D744740D32F116F9D8B4A409067976F7D7447408ACC5CE0F28C4A4077D7D9907F7847408ACC5CE0F28C4A4077D7D9907F784740D32F116F9D8B4A409067976F7D744740D32F116F9D8B4A40
25573	Тарлаково 2-е	7	70	1367	46.367666	46.388255999999998	53.238290999999997	53.212958999999998	0103000020E61000000100000005000000F2ECF2AD0F2F4740C631923D429B4A40F2ECF2AD0F2F47402FF7C951809E4A40E63C635FB23147402FF7C951809E4A40E63C635FB2314740C631923D429B4A40F2ECF2AD0F2F4740C631923D429B4A40
24979	Тарлаково 1-е	7	70	1367	46.367666	46.388255999999998	53.238290999999997	53.212958999999998	0103000020E61000000100000005000000F2ECF2AD0F2F4740C631923D429B4A40F2ECF2AD0F2F47402FF7C951809E4A40E63C635FB23147402FF7C951809E4A40E63C635FB2314740C631923D429B4A40F2ECF2AD0F2F4740C631923D429B4A40
25067	Сюзюм	7	70	1367	46.177700000000002	46.242925999999997	53.153401000000002	53.138429000000002	0103000020E61000000100000005000000E63FA4DFBE164740B4E89D0AB8914A40E63FA4DFBE1647403C16DBA4A2934A408EACFC32181F47403C16DBA4A2934A408EACFC32181F4740B4E89D0AB8914A40E63FA4DFBE164740B4E89D0AB8914A40
25803	Сухановка	7	70	1367	46.622599000000001	46.642569000000002	53.084960000000002	53.074001000000003	0103000020E61000000100000005000000DBC2F352B14F4740876F61DD78894A40DBC2F352B14F4740EDBB22F8DF8A4A40333674B33F524740EDBB22F8DF8A4A40333674B33F524740876F61DD78894A40DBC2F352B14F4740876F61DD78894A40
19989	Старый Кряжим	7	70	1367	46.162697999999999	46.215519	53.086080000000003	53.065885000000002	0103000020E61000000100000005000000F38FBE49D3144740032670EB6E884A40F38FBE49D31447407B6B60AB048B4A4054556820961B47407B6B60AB048B4A4054556820961B4740032670EB6E884A40F38FBE49D3144740032670EB6E884A40
25985	Сосновка	7	70	1367	46.800007000000001	46.812798999999998	52.989201000000001	52.977333000000002	0103000020E6100000010000000500000019C91EA1666647409A266C3F197D4A4019C91EA166664740D3156C239E7E4A405A9C31CC09684740D3156C239E7E4A405A9C31CC096847409A266C3F197D4A4019C91EA1666647409A266C3F197D4A40
25448	Радищево	7	70	1367	46.405728000000003	46.460884	53.060625000000002	53.031689999999998	0103000020E61000000100000005000000278925E5EE3347401CCEFC6A0E844A40278925E5EE334740F6285C8FC2874A40F59F353FFE3A4740F6285C8FC2874A40F59F353FFE3A47401CCEFC6A0E844A40278925E5EE3347401CCEFC6A0E844A40
24780	Поселки	7	70	1367	46.461109	46.529246000000001	53.143664000000001	53.126764999999999	0103000020E610000001000000050000001572A59E053B474083A3E4D539904A401572A59E053B474068CEFA9463924A40F8C43A55BE43474068CEFA9463924A40F8C43A55BE43474083A3E4D539904A401572A59E053B474083A3E4D539904A40
25621	Пионер	7	70	1367	46.579524999999997	46.617711999999997	53.044733000000001	53.020679000000001	0103000020E61000000100000005000000711B0DE02D4A4740645B069CA5824A40711B0DE02D4A4740A7069ACFB9854A40622CD32F114F4740A7069ACFB9854A40622CD32F114F4740645B069CA5824A40711B0DE02D4A4740645B069CA5824A40
24858	Никольское	7	70	1367	46.376434000000003	46.461692999999997	53.182616000000003	53.145457	0103000020E610000001000000050000001E8D43FD2E304740B5FCC0559E924A401E8D43FD2E304740F9DC09F65F974A4064E597C1183B4740F9DC09F65F974A4064E597C1183B4740B5FCC0559E924A401E8D43FD2E304740B5FCC0559E924A40
25321	Нижние Аблязово	7	70	1367	46.311476999999996	46.337392999999999	52.968445000000003	52.957337000000003	0103000020E61000000100000005000000643A747ADE2747401920D1048A7A4A40643A747ADE274740C47C7901F67B4A401D739EB12F2B4740C47C7901F67B4A401D739EB12F2B47401920D1048A7A4A40643A747ADE2747401920D1048A7A4A40
14770	Монастырское	7	70	1367	46.733801999999997	46.777234999999997	53.284225999999997	53.274481000000002	0103000020E61000000100000005000000A4DE5339ED5D4740CB2F833122A34A40A4DE5339ED5D474021567F8461A44A403D27BD6F7C63474021567F8461A44A403D27BD6F7C634740CB2F833122A34A40A4DE5339ED5D4740CB2F833122A34A40
25122	Махалино	7	70	1367	46.209499999999998	46.247121	53.090969000000001	53.078578	0103000020E61000000100000005000000894160E5D01A4740B1170AD80E8A4A40894160E5D01A474094F947DFA48B4A40D19332A9A11F474094F947DFA48B4A40D19332A9A11F4740B1170AD80E8A4A40894160E5D01A4740B1170AD80E8A4A40
26086	Малый Труев	7	70	1367	46.856251	46.876759999999997	53.088437999999996	53.073524999999997	0103000020E610000001000000050000006A15FDA1996D47401D38674469894A406A15FDA1996D4740A0DCB6EF518B4A407138F3AB39704740A0DCB6EF518B4A407138F3AB397047401D38674469894A406A15FDA1996D47401D38674469894A40
25891	Комаровка	7	70	1367	46.70449	46.731546999999999	52.994436999999998	52.976612000000003	0103000020E61000000100000005000000F52D73BA2C5A4740CA703C9F017D4A40F52D73BA2C5A474057772CB6497F4A40533E0455A35D474057772CB6497F4A40533E0455A35D4740CA703C9F017D4A40F52D73BA2C5A4740CA703C9F017D4A40
24556	Козляковка	7	70	1367	46.711362000000001	46.734636999999999	53.172491000000001	53.160431000000003	0103000020E61000000100000005000000FFCEF6E80D5B4740DE21C50089944A40FFCEF6E80D5B47405BED612F14964A403DB7D095085E47405BED612F14964A403DB7D095085E4740DE21C50089944A40FFCEF6E80D5B4740DE21C50089944A40
25726	Каменка	7	70	1367	46.501156000000002	46.519660999999999	53.095506	53.07808	0103000020E61000000100000005000000DB183BE125404740603C8386FE894A40DB183BE1254047403049658A398C4A40DA006C40844247403049658A398C4A40DA006C4084424740603C8386FE894A40DB183BE125404740603C8386FE894A40
24494	Казаковка	7	70	1367	46.774774000000001	46.789802999999999	53.231118000000002	53.214232000000003	0103000020E6100000010000000500000043E55FCB2B634740DBE044F46B9B4A4043E55FCB2B6347402BC24D46959D4A402FA4C343186547402BC24D46959D4A402FA4C34318654740DBE044F46B9B4A4043E55FCB2B634740DBE044F46B9B4A40
25790	Злобинка	7	70	1367	46.663094999999998	46.672617000000002	53.062806000000002	53.055439999999997	0103000020E610000001000000050000001092054CE0544740F3716DA818874A401092054CE05447400DFFE9060A884A40E8DD5850185647400DFFE9060A884A40E8DD585018564740F3716DA818874A401092054CE0544740F3716DA818874A40
20101	Евлашево	7	70	1367	46.813158999999999	46.850178	53.123522999999999	53.099853000000003	0103000020E610000001000000050000005AB917981568474029B4ACFBC78C4A405AB9179815684740E3A6069ACF8F4A40ACE3F8A1D26C4740E3A6069ACF8F4A40ACE3F8A1D26C474029B4ACFBC78C4A405AB917981568474029B4ACFBC78C4A40
25972	Дворики	7	70	1367	46.623775999999999	46.631276999999997	53.282454999999999	53.278143	0103000020E61000000100000005000000CD0358E4D74F4740404E98309AA34A40CD0358E4D74F4740BCCB457C27A44A40C6DB4AAFCD504740BCCB457C27A44A40C6DB4AAFCD504740404E98309AA34A40CD0358E4D74F4740404E98309AA34A40
25210	Верхозим	7	70	1367	46.353912999999999	46.376846999999998	52.920959000000003	52.905330999999997	0103000020E610000001000000050000008B506C054D2D47400987DEE2E1734A408B506C054D2D47407BFA08FCE1754A40404CC2853C3047407BFA08FCE1754A40404CC2853C3047400987DEE2E1734A408B506C054D2D47400987DEE2E1734A40
26050	Большой Труев	7	70	1367	46.875312999999998	46.910896000000001	53.097679999999997	53.082082999999997	0103000020E61000000100000005000000BF61A2410A7047405E471CB2818A4A40BF61A2410A70474094BC3AC7808C4A405307793D9874474094BC3AC7808C4A405307793D987447405E471CB2818A4A40BF61A2410A7047405E471CB2818A4A40
24695	Благодатка	7	70	1367	46.406491000000003	46.433666000000002	53.104832999999999	53.094765000000002	0103000020E61000000100000005000000268FA7E50734474019E76F42218C4A40268FA7E5073447405245F12A6B8D4A408EB1135E823747405245F12A6B8D4A408EB1135E8237474019E76F42218C4A40268FA7E50734474019E76F42218C4A40
24906	Бестянка	7	70	1367	46.298954000000002	46.332749	53.194356999999997	53.183933000000003	0103000020E610000001000000050000001381EA1F44264740DDD3D51D8B974A401381EA1F44264740D45FAFB0E0984A406B63EC84972A4740D45FAFB0E0984A406B63EC84972A4740DDD3D51D8B974A401381EA1F44264740DDD3D51D8B974A40
25296	Анненково	7	70	1367	46.360191999999998	46.408414	53.037083000000003	52.997895	0103000020E61000000100000005000000F2237EC51A2E4740C4EBFA05BB7F4A40F2237EC51A2E4740691EC022BF844A40419DF2E846344740691EC022BF844A40419DF2E846344740C4EBFA05BB7F4A40F2237EC51A2E4740C4EBFA05BB7F4A40
25666	Алексеевка	7	70	1367	46.546503000000001	46.562313000000003	53.078046999999998	53.066009999999999	0103000020E610000001000000050000003C1570CFF3454740BF9A030473884A403C1570CFF34547408446B071FD894A40CE8E54DFF94747408446B071FD894A40CE8E54DFF9474740BF9A030473884A403C1570CFF3454740BF9A030473884A40
9760	Улановка	7	70	1003	44.744850999999997	44.764712000000003	52.923445999999998	52.914622999999999	0103000020E610000001000000050000004AB20E47575F4640AF95D05D12754A404AB20E47575F46409ECF807A33764A40EC6D3315E26146409ECF807A33764A40EC6D3315E2614640AF95D05D12754A404AB20E47575F4640AF95D05D12754A40
56505	Танеевка	7	70	1003	44.880352999999999	44.89584	52.888914	52.877524000000001	0103000020E61000000100000005000000BEF73768AF70464041BAD8B452704A40BEF73768AF704640707A17EFC7714A406D3997E2AA724640707A17EFC7714A406D3997E2AA72464041BAD8B452704A40BEF73768AF70464041BAD8B452704A40
10432	Покрово-Березовка	7	70	1003	44.822456000000003	44.852262000000003	52.772444999999998	52.753945000000002	0103000020E610000001000000050000001233FB3C46694640CAFD0E4581604A401233FB3C46694640B77A4E7ADF624A40D1CFD4EB166D4640B77A4E7ADF624A40D1CFD4EB166D4640CAFD0E4581604A401233FB3C46694640CAFD0E4581604A40
10493	Новопавловка	7	70	1003	44.7074	44.919699000000001	52.889012000000001	52.734819999999999	0103000020E610000001000000050000005F984C158C5A46402E39EE940E5E4A405F984C158C5A464033E02C25CB714A40FB9463B2B875464033E02C25CB714A40FB9463B2B87546402E39EE940E5E4A405F984C158C5A46402E39EE940E5E4A40
9370	Кондоль	7	70	1003	45.019376000000001	45.070642999999997	52.842972000000003	52.805720000000001	0103000020E61000000100000005000000E529ABE97A824640D7DD3CD521674A40E529ABE97A824640CCB8A981E66B4A407D586FD40A894640CCB8A981E66B4A407D586FD40A894640D7DD3CD521674A40E529ABE97A824640D7DD3CD521674A40
9566	Колышлейка	7	70	1003	44.998480999999998	45.051931000000003	52.762614999999997	52.752571000000003	0103000020E61000000100000005000000B456B439CE7F464082751C3F54604A40B456B439CE7F464032384A5E9D614A400553CDACA586464032384A5E9D614A400553CDACA586464082751C3F54604A40B456B439CE7F464082751C3F54604A40
56442	Князевка	7	70	1003	44.925358000000003	44.960985000000001	52.911380999999999	52.886589000000001	0103000020E61000000100000005000000C68B85217276464026FF93BF7B714A40C68B8521727646400F99F221A8744A402979758E017B46400F99F221A8744A402979758E017B464026FF93BF7B714A40C68B85217276464026FF93BF7B714A40
10592	Ермолаевка	7	70	1003	44.812772000000002	44.829121999999998	52.821362000000001	52.803749000000003	0103000020E61000000100000005000000618DB3E908684640AB984A3FE1664A40618DB3E908684640AD16D86322694A40723271AB206A4640AD16D86322694A40723271AB206A4640AB984A3FE1664A40618DB3E908684640AB984A3FE1664A40
9588	Волхонщино	7	70	1003	45.188681000000003	45.224093000000003	52.768968999999998	52.732638999999999	0103000020E610000001000000050000003430F2B2269846401763601DC75D4A403430F2B226984640A45181936D624A409B215514AF9C4640A45181936D624A409B215514AF9C46401763601DC75D4A403430F2B2269846401763601DC75D4A40
8721	Волхон-Умет	7	70	1003	45.116906	45.131746	52.716625999999998	52.701169	0103000020E61000000100000005000000645A9BC6F68E464009FCE1E7BF594A40645A9BC6F68E46404DBB9866BA5B4A407DB08C0DDD9046404DBB9866BA5B4A407DB08C0DDD90464009FCE1E7BF594A40645A9BC6F68E464009FCE1E7BF594A40
8674	Варыпаево	7	70	1003	45.178925999999997	45.221865000000001	52.711815000000001	52.670124000000001	0103000020E61000000100000005000000B933130CE7964640E2218C9FC6554A40B933130CE7964640B0E600C11C5B4A4043908312669C4640B0E600C11C5B4A4043908312669C4640E2218C9FC6554A40B933130CE7964640E2218C9FC6554A40
46905	Андреевка	7	70	1003	44.828403000000002	44.859476000000001	52.733767999999998	52.718480999999997	0103000020E610000001000000050000004374081C096A464010E6762FF75B4A404374081C096A4640F86C1D1CEC5D4A4034D93F4F036E4640F86C1D1CEC5D4A4034D93F4F036E464010E6762FF75B4A404374081C096A464010E6762FF75B4A40
32646	совхоз Хопер	7	70	1379	44.487060999999997	44.505763999999999	52.866191000000001	52.851989000000003	0103000020E610000001000000050000001A14CD03583E4640A0C6BDF90D6D4A401A14CD03583E4640768BC058DF6E4A4040BFEFDFBC404640768BC058DF6E4A4040BFEFDFBC404640A0C6BDF90D6D4A401A14CD03583E4640A0C6BDF90D6D4A40
56457	совхоз Пограничный	7	70	1379	44.678483	44.702782999999997	52.771698000000001	52.759095000000002	0103000020E610000001000000050000002CF2EB87D856464050C763062A614A402CF2EB87D8564640BE310400C7624A40A69718CBF4594640BE310400C7624A40A69718CBF459464050C763062A614A402CF2EB87D856464050C763062A614A40
56502	Чубаровка	7	70	1379	44.653762	44.692973000000002	52.534356000000002	52.519875999999996	0103000020E610000001000000050000000CAF2479AE534640D6FCF84B8B424A400CAF2479AE534640F03504C765444A406901DA56B3584640F03504C765444A406901DA56B3584640D6FCF84B8B424A400CAF2479AE534640D6FCF84B8B424A40
32741	Халтурино	7	70	1379	44.323855000000002	44.347625000000001	52.911734000000003	52.900948	0103000020E61000000100000005000000B3D2A41474294640C4B2994352734A40B3D2A414742946405D5320B3B3744A40D122DBF97E2C46405D5320B3B3744A40D122DBF97E2C4640C4B2994352734A40B3D2A41474294640C4B2994352734A40
32636	Телегино	7	70	1379	44.541741999999999	44.570298999999999	52.924939000000002	52.901224999999997	0103000020E61000000100000005000000506F46CD5745464036AB3E575B734A40506F46CD57454640C1E5B16664764A4083F8C08EFF484640C1E5B16664764A4083F8C08EFF48464036AB3E575B734A40506F46CD5745464036AB3E575B734A40
23795	Сумы	7	70	1379	44.707875999999999	44.751983000000003	52.707112000000002	52.691110999999999	0103000020E61000000100000005000000C8CF46AE9B5A4640F373435376584A40C8CF46AE9B5A4640F94D61A5825A4A40F1129CFA40604640F94D61A5825A4A40F1129CFA40604640F373435376584A40C8CF46AE9B5A4640F373435376584A40
23714	Старая Потловка	7	70	1379	44.398280999999997	44.412196000000002	52.738909999999997	52.730168999999997	0103000020E6100000010000000500000020CF2EDFFA324640C9C6832D765D4A4020CF2EDFFA324640FB57569A945E4A4061C5A9D6C2344640FB57569A945E4A4061C5A9D6C2344640C9C6832D765D4A4020CF2EDFFA324640C9C6832D765D4A40
23613	Плещеевка	7	70	1379	44.398218	44.421869999999998	52.674028	52.656556999999999	0103000020E61000000100000005000000DA56B3CEF8324640DD7A4D0F0A544A40DA56B3CEF83246404D4BAC8C46564A40EE940ED6FF3546404D4BAC8C46564A40EE940ED6FF354640DD7A4D0F0A544A40DA56B3CEF8324640DD7A4D0F0A544A40
23513	Названовка	7	70	1379	44.493330999999998	44.530476999999998	52.680635000000002	52.653180999999996	0103000020E610000001000000050000002E8D5F78253F46402DAF5C6F9B534A402E8D5F78253F4640A9C1340C1F574A40DD239BABE6434640A9C1340C1F574A40DD239BABE64346402DAF5C6F9B534A402E8D5F78253F46402DAF5C6F9B534A40
15062	Липяги	7	70	1379	44.209060000000001	44.225408999999999	52.831705999999997	52.819664000000003	0103000020E610000001000000050000006D73637AC21A4640B2DAFCBFEA684A406D73637AC21A464088F19A57756A4A40AE9CBD33DA1C464088F19A57756A4A40AE9CBD33DA1C4640B2DAFCBFEA684A406D73637AC21A4640B2DAFCBFEA684A40
48241	Красная Горка	7	70	1379	44.489891	44.540627999999998	52.576079	52.553618	0103000020E6100000010000000500000068CD8FBFB43E46400C3D62F4DC464A4068CD8FBFB43E4640C974E8F4BC494A40A4A65D4C33454640C974E8F4BC494A40A4A65D4C334546400C3D62F4DC464A4068CD8FBFB43E46400C3D62F4DC464A40
24055	Колышлей	7	70	1379	44.514622000000003	44.569355999999999	52.712622000000003	52.685924999999997	0103000020E61000000100000005000000ACE63922DF4146402041F163CC574A40ACE63922DF4146407F349C32375B4A4004E44BA8E04846407F349C32375B4A4004E44BA8E04846402041F163CC574A40ACE63922DF4146402041F163CC574A40
23421	Колтовское	7	70	1379	44.244219999999999	44.284868000000003	52.809367000000002	52.783284999999999	0103000020E61000000100000005000000BA83D899421F46404339D1AE42644A40BA83D899421F464017BB7D5699674A40A6D6FB8D7624464017BB7D5699674A40A6D6FB8D762446404339D1AE42644A40BA83D899421F46404339D1AE42644A40
20591	Катковка	7	70	1379	44.752828000000001	44.756968999999998	52.643030000000003	52.637106000000003	0103000020E61000000100000005000000ADC1FBAA5C604640EE0A7DB08C514A40ADC1FBAA5C604640672C9ACE4E524A40FC8A355CE4604640672C9ACE4E524A40FC8A355CE4604640EE0A7DB08C514A40ADC1FBAA5C604640EE0A7DB08C514A40
56462	Голицыно	7	70	1379	44.384149999999998	44.391551999999997	52.712693000000002	52.697557000000003	0103000020E610000001000000050000001361C3D32B314640460C3B8C49594A401361C3D32B314640488B3386395B4A4079573D601E324640488B3386395B4A4079573D601E324640460C3B8C49594A401361C3D32B314640460C3B8C49594A40
56499	Бекетовка	7	70	1379	44.533988999999998	44.541409000000002	52.873193000000001	52.863131000000003	0103000020E610000001000000050000003DB665C059444640F7949C137B6E4A403DB665C0594446404E0CC9C9C46F4A404A61DEE34C4546404E0CC9C9C46F4A404A61DEE34C454640F7949C137B6E4A403DB665C059444640F7949C137B6E4A40
33095	Апраксино	7	70	1379	44.455835999999998	44.484788000000002	52.669927999999999	52.664073000000002	0103000020E61000000100000005000000732B84D5583A46400C94145800554A40732B84D5583A46405C566133C0554A4023BF7E880D3E46405C566133C0554A4023BF7E880D3E46400C94145800554A40732B84D5583A46400C94145800554A40
20580	Чумаево	7	70	1369	45.892178999999999	45.924275999999999	52.765737999999999	52.733756999999997	0103000020E61000000100000005000000C896E5EB32F24640041BD7BFEB5D4A40C896E5EB32F24640F8A6E9B303624A40253D0CAD4EF64640F8A6E9B303624A40253D0CAD4EF64640041BD7BFEB5D4A40C896E5EB32F24640041BD7BFEB5D4A40
22718	Старый Чирчим	7	70	1369	46.341903000000002	46.383180000000003	52.774819999999998	52.756332	0103000020E61000000100000005000000C0B33D7AC32B47408A75AA7CCF604A40C0B33D7AC32B4740B324404D2D634A409B3DD00A0C314740B324404D2D634A409B3DD00A0C3147408A75AA7CCF604A40C0B33D7AC32B47408A75AA7CCF604A40
23034	Русский Камешкир	7	70	1369	46.071931999999997	46.114736999999998	52.89564	52.835769999999997	0103000020E6100000010000000500000097C45911350947402C7DE882FA6A4A4097C4591135094740A67EDE54A4724A401152B7B3AF0E4740A67EDE54A4724A401152B7B3AF0E47402C7DE882FA6A4A4097C45911350947402C7DE882FA6A4A40
20515	Порзово	7	70	1369	46.041443000000001	46.074869	52.665886	52.648536999999997	0103000020E61000000100000005000000F6D214014E0547407B9FAA4203534A40F6D214014E054740A06EA0C03B554A40FB3DB14E95094740A06EA0C03B554A40FB3DB14E950947407B9FAA4203534A40F6D214014E0547407B9FAA4203534A40
33135	Пестровка	7	70	1369	46.130986999999998	46.159148999999999	52.764926000000003	52.752217000000002	0103000020E61000000100000005000000BF99982EC4104740643F8BA548604A40BF99982EC410474018EE5C18E9614A40761893FE5E14474018EE5C18E9614A40761893FE5E144740643F8BA548604A40BF99982EC4104740643F8BA548604A40
22691	Новое Шаткино	7	70	1369	46.207011999999999	46.257578000000002	52.921154999999999	52.903717999999998	0103000020E6100000010000000500000095F0845E7F1A47403C670B08AD734A4095F0845E7F1A474000C63368E8754A40A515DF50F820474000C63368E8754A40A515DF50F82047403C670B08AD734A4095F0845E7F1A47403C670B08AD734A40
22413	Мордовский Камешкир	7	70	1369	46.133943000000002	46.157100999999997	52.959529000000003	52.939034999999997	0103000020E610000001000000050000009A43520B251147405166834C32784A409A43520B251147402448A5D8D17A4A409E95B4E21B1447402448A5D8D17A4A409E95B4E21B1447405166834C32784A409A43520B251147405166834C32784A40
56470	Мамадыш	7	70	1369	45.823493999999997	45.845771999999997	52.864103999999998	52.838217999999998	0103000020E61000000100000005000000E2395B4068E94640927538BA4A6B4A40E2395B4068E94640E02BBAF59A6E4A40AEEFC34142EC4640E02BBAF59A6E4A40AEEFC34142EC4640927538BA4A6B4A40E2395B4068E94640927538BA4A6B4A40
20786	Лапшово	7	70	1369	45.970773000000001	46.013109999999998	52.852615	52.835047000000003	0103000020E610000001000000050000007F6B274A42FC4640BCCFF1D1E26A4A407F6B274A42FC46401E8A027D226D4A4012A0A696AD0147401E8A027D226D4A4012A0A696AD014740BCCFF1D1E26A4A407F6B274A42FC4640BCCFF1D1E26A4A40
18556	Кулясово	7	70	1369	45.804512000000003	45.858294999999998	52.840155000000003	52.815795000000001	0103000020E61000000100000005000000AA9ECC3FFAE64640C39E76F86B684A40AA9ECC3FFAE646401349F4328A6B4A4000A94D9CDCED46401349F4328A6B4A4000A94D9CDCED4640C39E76F86B684A40AA9ECC3FFAE64640C39E76F86B684A40
33127	Камышинка	7	70	1369	46.345621999999999	46.366695999999997	52.726650999999997	52.715862000000001	0103000020E61000000100000005000000996379573D2C47407E39B35DA15B4A40996379573D2C4740874D64E6025D4A4079C9FFE4EF2E4740874D64E6025D4A4079C9FFE4EF2E47407E39B35DA15B4A40996379573D2C47407E39B35DA15B4A40
20336	Дьячевка	7	70	1369	46.073549	46.096465000000002	52.720433999999997	52.699936000000001	0103000020E61000000100000005000000A6D3BA0D6A09474083A5BA8097594A40A6D3BA0D6A09474096766A2E375C4A40B51A12F7580C474096766A2E375C4A40B51A12F7580C474083A5BA8097594A40A6D3BA0D6A09474083A5BA8097594A40
14786	Дубровки	7	70	1369	45.834831000000001	45.867466	52.958247999999998	52.927636999999997	0103000020E61000000100000005000000EF5701BEDBEA46409FC728CFBC764A40EF5701BEDBEA46408CBAD6DEA77A4A402B323A2009EF46408CBAD6DEA77A4A402B323A2009EF46409FC728CFBC764A40EF5701BEDBEA46409FC728CFBC764A40
20684	Большой Умыс	7	70	1369	46.069730999999997	46.098278999999998	52.937829999999998	52.928294000000001	0103000020E61000000100000005000000394206F2EC08474059897956D2764A40394206F2EC084740959A3DD00A784A4019710168940C4740959A3DD00A784A4019710168940C474059897956D2764A40394206F2EC08474059897956D2764A40
20451	Бегуч	7	70	1369	46.176468999999997	46.210388999999999	52.630498000000003	52.609268999999998	0103000020E6100000010000000500000000E1438996164740BABBCE86FC4D4A4000E1438996164740C2189128B4504A401538D906EE1A4740C2189128B4504A401538D906EE1A4740BABBCE86FC4D4A4000E1438996164740BABBCE86FC4D4A40
56486	Алексеевка	7	70	1369	45.887121999999998	45.909723	52.877177000000003	52.865685999999997	0103000020E61000000100000005000000F3C7B4368DF14640724D81CCCE6E4A40F3C7B4368DF14640D6E6FF5547704A40A2B5A2CD71F44640D6E6FF5547704A40A2B5A2CD71F44640724D81CCCE6E4A40F3C7B4368DF14640724D81CCCE6E4A40
56443	Федоровка	7	70	1202	44.218311999999997	44.284823000000003	53.187007999999999	53.150593000000001	0103000020E610000001000000050000008429CAA5F11B4640D600A5A146934A408429CAA5F11B4640910BCEE0EF974A4006137F1475244640910BCEE0EF974A4006137F1475244640D600A5A146934A408429CAA5F11B4640D600A5A146934A40
21678	Усть-Атмис	7	70	1202	44.141272999999998	44.173279999999998	53.063623	53.048853000000001	0103000020E610000001000000050000006667D13B15124640DFA7AAD040864A406667D13B15124640FF2268CC24884A408386FE092E164640FF2268CC24884A408386FE092E164640DFA7AAD040864A406667D13B15124640DFA7AAD040864A40
21967	Телятино	7	70	1202	43.662137999999999	43.676628000000001	53.192976000000002	53.183199000000002	0103000020E610000001000000050000002CB81FF0C0D4454078D4981073974A402CB81FF0C0D44540DA740470B3984A4069C70DBF9BD64540DA740470B3984A4069C70DBF9BD6454078D4981073974A402CB81FF0C0D4454078D4981073974A40
32951	Соболевка	7	70	1202	44.064915999999997	44.092934	52.976509	52.963189999999997	0103000020E610000001000000050000005A7EE02A4F084640C8EA56CF497B4A405A7EE02A4F084640F59F353FFE7C4A40DE57E542E50B4640F59F353FFE7C4A40DE57E542E50B4640C8EA56CF497B4A405A7EE02A4F084640C8EA56CF497B4A40
21113	Скворечное	7	70	1202	43.936771	43.959822000000003	53.361296000000003	53.328068000000002	0103000020E61000000100000005000000AD6BB41CE8F745409C6ED921FEA94A40AD6BB41CE8F745407B1684F23EAE4A409CFD8172DBFA45407B1684F23EAE4A409CFD8172DBFA45409C6ED921FEA94A40AD6BB41CE8F745409C6ED921FEA94A40
21982	Покровская Арчада	7	70	1202	44.200327999999999	44.233566000000003	52.942791	52.913086	0103000020E610000001000000050000008E3C1059A4194640BD378600E0744A408E3C1059A419464048FB1F60AD784A4091BA9D7DE51D464048FB1F60AD784A4091BA9D7DE51D4640BD378600E0744A408E3C1059A4194640BD378600E0744A40
56489	Низовка	7	70	1202	44.050148	44.084921000000001	53.339359999999999	53.321097999999999	0103000020E61000000100000005000000DBFAE93F6B064640CF6740BD19A94A40DBFAE93F6B06464008C9022670AB4A402FDFFAB0DE0A464008C9022670AB4A402FDFFAB0DE0A4640CF6740BD19A94A40DBFAE93F6B064640CF6740BD19A94A40
21766	Надеждинка	7	70	1202	44.182865	44.191209999999998	53.124381999999997	53.116297000000003	0103000020E61000000100000005000000A14ACD1E68174640BCCFF1D1E28E4A40A14ACD1E68174640041BD7BFEB8F4A408655BC9179184640041BD7BFEB8F4A408655BC9179184640BCCFF1D1E28E4A40A14ACD1E68174640BCCFF1D1E28E4A40
33067	Максимовка	7	70	1202	43.954054999999997	43.976297000000002	53.096020000000003	53.082141999999997	0103000020E61000000100000005000000EACA67791EFA454063D009A1838A4A40EACA67791EFA454087E123624A8C4A406A17D34CF7FC454087E123624A8C4A406A17D34CF7FC454063D009A1838A4A40EACA67791EFA454063D009A1838A4A40
33078	Кургановка	7	70	1202	44.238568999999998	44.254083000000001	53.107438000000002	53.099376999999997	0103000020E61000000100000005000000726BD26D891E4640BF7CB262B88C4A40726BD26D891E4640802C4487C08D4A401BBCAFCA85204640802C4487C08D4A401BBCAFCA85204640BF7CB262B88C4A40726BD26D891E4640BF7CB262B88C4A40
21307	Кувака	7	70	1202	44.118572	44.148063999999998	53.176194000000002	53.156419	0103000020E61000000100000005000000541C075E2D0F46408CBCAC8905944A40541C075E2D0F46402FE065868D964A4083DBDAC2F31246402FE065868D964A4083DBDAC2F31246408CBCAC8905944A40541C075E2D0F46408CBCAC8905944A40
33041	Крыловка	7	70	1202	43.82414	43.877923000000003	52.853794999999998	52.836765999999997	0103000020E61000000100000005000000A8A9656B7DE94540CE33F6251B6B4A40A8A9656B7DE94540813E9127496D4A40FFB3E6C75FF04540813E9127496D4A40FFB3E6C75FF04540CE33F6251B6B4A40A8A9656B7DE94540CE33F6251B6B4A40
56452	Кочелейка	7	70	1202	43.953552000000002	43.968643	53.259013000000003	53.236975999999999	0103000020E610000001000000050000008884EFFD0DFA4540ECF7C43A559E4A408884EFFD0DFA4540931E865627A14A40EA3F6B7EFCFB4540931E865627A14A40EA3F6B7EFCFB4540ECF7C43A559E4A408884EFFD0DFA4540ECF7C43A559E4A40
21253	Клейменовка	7	70	1202	44.116864999999997	44.153993	52.890391999999999	52.872458999999999	0103000020E610000001000000050000000586AC6EF50E4640E90C8CBCAC6F4A400586AC6EF50E46405D4F745DF8714A400E68E90AB61346405D4F745DF8714A400E68E90AB6134640E90C8CBCAC6F4A400586AC6EF50E4640E90C8CBCAC6F4A40
21479	Кикино	7	70	1202	43.747092000000002	43.810172000000001	53.150517000000001	53.126257000000003	0103000020E61000000100000005000000378DEDB5A0DF45400FF27A3029904A40378DEDB5A0DF4540FB3E1C2444934A40451152B7B3E74540FB3E1C2444934A40451152B7B3E745400FF27A3029904A40378DEDB5A0DF45400FF27A3029904A40
21391	Кевдо-Мельситово	7	70	1202	43.865246999999997	43.913541000000002	53.174936000000002	53.146504999999998	0103000020E6100000010000000500000026FBE769C0EE4540A9D903ADC0924A4026FBE769C0EE45405072874D64964A400F4757E9EEF445405072874D64964A400F4757E9EEF44540A9D903ADC0924A4026FBE769C0EE4540A9D903ADC0924A40
19569	Каменка	7	70	1202	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
21666	Казанская Арчада	7	70	1202	44.211350000000003	44.248351999999997	53.024557000000001	53.003591	0103000020E610000001000000050000003B014D840D1B4640ACC77DAB75804A403B014D840D1B4640A6F10BAF24834A40B6F292FFC91F4640A6F10BAF24834A40B6F292FFC91F4640ACC77DAB75804A403B014D840D1B4640ACC77DAB75804A40
56474	Знаменка	7	70	1202	44.02769	44.042135000000002	53.133572999999998	53.117778000000001	0103000020E610000001000000050000008F368E588B0346401A187959138F4A408F368E588B034640765089EB18914A402C82FFAD64054640765089EB18914A402C82FFAD640546401A187959138F4A408F368E588B0346401A187959138F4A40
21205	Завиваловка	7	70	1202	43.981444000000003	44.029522	52.912689999999998	52.890462999999997	0103000020E610000001000000050000007F6DFDF49FFD454026A60BB1FA714A407F6DFDF49FFD454070B1A206D3744A409A417C60C703464070B1A206D3744A409A417C60C703464026A60BB1FA714A407F6DFDF49FFD454026A60BB1FA714A40
21027	Головинщино	7	70	1202	43.983663	44.017305	53.319619000000003	53.304200000000002	0103000020E6100000010000000500000083A44FABE8FD4540BBB88D06F0A64A4083A44FABE8FD454012178046E9A84A405587DC0C3702464012178046E9A84A405587DC0C37024640BBB88D06F0A64A4083A44FABE8FD4540BBB88D06F0A64A40
32940	Владыкино	7	70	1202	44.009704999999997	44.047128999999998	53.087145	53.062913999999999	0103000020E61000000100000005000000C8CD70033E014640F33AE2900D884A40C8CD70033E01464045813E91278B4A40BAD8B4520806464045813E91278B4A40BAD8B45208064640F33AE2900D884A40C8CD70033E014640F33AE2900D884A40
18446	Большие Верхи	7	70	1202	44.177456999999997	44.200436000000003	53.327525000000001	53.296385999999998	0103000020E610000001000000050000001FB935E9B6164640027FF8F9EFA54A401FB935E9B6164640ABCFD556ECA94A40757808E3A7194640ABCFD556ECA94A40757808E3A7194640027FF8F9EFA54A401FB935E9B6164640027FF8F9EFA54A40
20739	Блиновка	7	70	1202	44.126494999999998	44.168114000000003	53.258555999999999	53.245334	0103000020E61000000100000005000000C30DF8FC30104640664CC11A679F4A40C30DF8FC30104640A017EE5C18A14A40F8FF71C284154640A017EE5C18A14A40F8FF71C284154640664CC11A679F4A40C30DF8FC30104640664CC11A679F4A40
21402	Безруково	7	70	1202	43.872317000000002	43.883617999999998	53.102870000000003	53.090741999999999	0103000020E61000000100000005000000575F5D15A8EF4540D32F116F9D8B4A40575F5D15A8EF4540A9DE1AD82A8D4A40161406651AF14540A9DE1AD82A8D4A40161406651AF14540D32F116F9D8B4A40575F5D15A8EF4540D32F116F9D8B4A40
33066	Батрак	7	70	1202	43.943840999999999	43.963011000000002	53.181558000000003	53.173506000000003	0103000020E61000000100000005000000DDCF29C8CFF8454074D4D17135964A40DDCF29C8CFF84540E129E44A3D974A401958C7F143FB4540E129E44A3D974A401958C7F143FB454074D4D17135964A40DDCF29C8CFF8454074D4D17135964A40
56463	Ахматовка	7	70	1202	44.178902999999998	44.205592000000003	52.903722999999999	52.887692000000001	0103000020E610000001000000050000000114234BE6164640DE7536E49F714A400114234BE61646404ED2FC31AD734A40DD28B2D6501A46404ED2FC31AD734A40DD28B2D6501A4640DE7536E49F714A400114234BE6164640DE7536E49F714A40
47856	Аргамаково	7	70	1202	43.694307000000002	43.731065999999998	53.102654000000001	53.085214999999998	0103000020E610000001000000050000002331410DDFD8454077103B53E88A4A402331410DDFD84540DC662AC4238D4A40D89B189293DD4540DC662AC4238D4A40D89B189293DD454077103B53E88A4A402331410DDFD8454077103B53E88A4A40
19036	Украинцево	7	70	1451	44.769545000000001	44.792622999999999	53.869045999999997	53.861494999999998	0103000020E6100000010000000500000071E65773806246407155D97745EE4A4071E65773806246401C5C3AE63CEF4A405987A3AB746546401C5C3AE63CEF4A405987A3AB746546407155D97745EE4A4071E65773806246407155D97745EE4A40
56521	Уваровский	7	70	1451	44.734896999999997	44.748570000000001	53.779266999999997	53.760565999999997	0103000020E61000000100000005000000D976DA1A115E46408A39083A5AE14A40D976DA1A115E46400FED6305BFE34A4024624A24D15F46400FED6305BFE34A4024624A24D15F46408A39083A5AE14A40D976DA1A115E46408A39083A5AE14A40
46505	Уварово	7	70	1451	44.758451000000001	44.781779999999998	53.753703999999999	53.736781000000001	0103000020E610000001000000050000002B4F20EC1461464037A8FDD64EDE4A402B4F20EC14614640A46E675F79E04A405C55F65D11644640A46E675F79E04A405C55F65D1164464037A8FDD64EDE4A402B4F20EC1461464037A8FDD64EDE4A40
46458	Соловцово	7	70	1451	45.079248999999997	45.102488000000001	53.798389999999998	53.781139000000003	0103000020E61000000100000005000000CF9ECBD4248A4640A950DD5CFCE34A40CF9ECBD4248A46400ABABDA431E64A40C11DA8531E8D46400ABABDA431E64A40C11DA8531E8D4640A950DD5CFCE34A40CF9ECBD4248A4640A950DD5CFCE34A40
46195	Приволье	7	70	1451	45.099865000000001	45.127837999999997	53.871949999999998	53.858643999999998	0103000020E61000000100000005000000ED815660C88C46400C74ED0BE8ED4A40ED815660C88C4640A4DFBE0E9CEF4A40D097DEFE5C904640A4DFBE0E9CEF4A40D097DEFE5C9046400C74ED0BE8ED4A40ED815660C88C46400C74ED0BE8ED4A40
18569	Пестровка Знаменская	7	70	1451	45.128360000000001	45.16572	53.900660000000002	53.875622999999997	0103000020E61000000100000005000000AA0EB9196E9046400D501A6A14F04A40AA0EB9196E9046405E68AED348F34A4085251E50369546405E68AED348F34A4085251E50369546400D501A6A14F04A40AA0EB9196E9046400D501A6A14F04A40
19120	Новотрехсвятское	7	70	1451	44.618566000000001	44.640484000000001	53.852429999999998	53.844541999999997	0103000020E610000001000000050000007235B22B2D4F4640990CC7F319EC4A407235B22B2D4F46408C101E6D1CED4A403ECE3461FB5146408C101E6D1CED4A403ECE3461FB514640990CC7F319EC4A407235B22B2D4F4640990CC7F319EC4A40
18680	Никольская Пестровка	7	70	1451	45.166851999999999	45.206980000000001	53.918922000000002	53.896951999999999	0103000020E61000000100000005000000D7A205685B954640780AB952CFF24A40D7A205685B95464097C9703C9FF54A408A7615527E9A464097C9703C9FF54A408A7615527E9A4640780AB952CFF24A40D7A205685B954640780AB952CFF24A40
56504	Николаевка	7	70	1451	44.829031999999998	44.848229000000003	53.793411999999996	53.779054000000002	0103000020E6100000010000000500000032AB77B81D6A4640B4E89D0AB8E34A4032AB77B81D6A4640812040868EE54A40684293C4926C4640812040868EE54A40684293C4926C4640B4E89D0AB8E34A4032AB77B81D6A4640B4E89D0AB8E34A40
46075	Кисловка	7	70	1451	45.024236000000002	45.045831	53.889316000000001	53.877862999999998	0103000020E6100000010000000500000064B14D2A1A83464029AF95D05DF04A4064B14D2A1A8346409FE74F1BD5F14A404D124BCADD8546409FE74F1BD5F14A404D124BCADD85464029AF95D05DF04A4064B14D2A1A83464029AF95D05DF04A40
19098	Кильмаевка	7	70	1451	44.727297999999998	44.735247999999999	53.826540000000001	53.815308999999999	0103000020E610000001000000050000001D39D219185D46403691990B5CE84A401D39D219185D4640FD6A0E10CCE94A408639419B1C5E4640FD6A0E10CCE94A408639419B1C5E46403691990B5CE84A401D39D219185D46403691990B5CE84A40
46298	Каменный Брод	7	70	1451	44.6922	44.717308000000003	53.854118999999997	53.844728000000003	0103000020E61000000100000005000000462575029A584640FC010F0C20EC4A40462575029A58464034F279C553ED4A406094A0BFD05B464034F279C553ED4A406094A0BFD05B4640FC010F0C20EC4A40462575029A584640FC010F0C20EC4A40
18745	Исса	7	70	1451	44.812089999999998	44.885939999999998	53.882407000000001	53.860194	0103000020E610000001000000050000004EB4AB90F2674640931B45D61AEE4A404EB4AB90F267464078616BB6F2F04A40EF1B5F7B6671464078616BB6F2F04A40EF1B5F7B66714640931B45D61AEE4A404EB4AB90F2674640931B45D61AEE4A40
18993	Верхняя Салмовка	7	70	1451	44.672896000000001	44.693629000000001	53.901387	53.885404999999999	0103000020E61000000100000005000000FBCDC47421564640815B77F354F14A40FBCDC47421564640100533A660F34A405247C7D5C8584640100533A660F34A405247C7D5C8584640815B77F354F14A40FBCDC47421564640815B77F354F14A40
16455	Бутурлино	7	70	1451	45.063913999999997	45.088807000000003	53.907116000000002	53.885899000000002	0103000020E61000000100000005000000D6E07D552E8846409147702365F14A40D6E07D552E884640D4D688601CF44A40F4531C075E8B4640D4D688601CF44A40F4531C075E8B46409147702365F14A40D6E07D552E8846409147702365F14A40
46029	Булычево	7	70	1451	44.988168000000002	45.004212000000003	53.887979000000001	53.871434999999998	0103000020E61000000100000005000000147AFD497C7E46407DCB9C2E8BEF4A40147AFD497C7E46407444BE4BA9F14A401920D1048A8046407444BE4BA9F14A401920D1048A8046407DCB9C2E8BEF4A40147AFD497C7E46407DCB9C2E8BEF4A40
19191	Архаровка	7	70	1451	44.990648	45.010896000000002	53.831254000000001	53.822586000000001	0103000020E6100000010000000500000085ECBC8DCD7E4640E012807F4AE94A4085ECBC8DCD7E4640A855F48766EA4A4020D4450A65814640A855F48766EA4A4020D4450A65814640E012807F4AE94A4085ECBC8DCD7E4640E012807F4AE94A40
56438	Анучино	7	70	1451	44.939120000000003	44.958298999999997	53.761294999999997	53.747432000000003	0103000020E6100000010000000500000080828B1535784640F0FD0DDAABDF4A4080828B1535784640DDCD531D72E14A400E65A88AA97A4640DDCD531D72E14A400E65A88AA97A4640F0FD0DDAABDF4A4080828B1535784640F0FD0DDAABDF4A40
56479	Александровка	7	70	1451	44.921306999999999	44.933110999999997	53.818497999999998	53.813113000000001	0103000020E61000000100000005000000B6494563ED754640EA79371614E84A40B6494563ED754640B3EBDE8AC4E84A40D844662E70774640B3EBDE8AC4E84A40D844662E70774640EA79371614E84A40B6494563ED754640EA79371614E84A40
56436	Чернышево	7	70	1468	42.664774999999999	42.683190000000003	53.711714999999998	53.687806000000002	0103000020E610000001000000050000006519E258175545400DFFE9060AD84A406519E258175545404C89247A19DB4A40257A19C5725745404C89247A19DB4A40257A19C5725745400DFFE9060AD84A406519E258175545400DFFE9060AD84A40
17698	Чернояр	7	70	1468	42.211081	42.288192000000002	53.812603000000003	53.795422000000002	0103000020E610000001000000050000004BE7C3B3041B45406C425A63D0E54A404BE7C3B3041B4540D5D0066003E84A40037CB779E3244540D5D0066003E84A40037CB779E32445406C425A63D0E54A404BE7C3B3041B45406C425A63D0E54A40
18250	Ушинка	7	70	1468	42.785660999999998	42.838679999999997	53.488151000000002	53.457751999999999	0103000020E610000001000000050000000F5F268A90644540DCD6169E97BA4A400F5F268A906445403E4162BB7BBE4A4096E7C1DD596B45403E4162BB7BBE4A4096E7C1DD596B4540DCD6169E97BA4A400F5F268A90644540DCD6169E97BA4A40
17207	Усердино	7	70	1468	42.509518999999997	42.555207000000003	53.408982999999999	53.384746	0103000020E6100000010000000500000066D828EB3741454027A25F5B3FB14A4066D828EB374145405BCF108E59B44A4051C1E105114745405BCF108E59B44A4051C1E1051147454027A25F5B3FB14A4066D828EB3741454027A25F5B3FB14A40
18006	Сядемка	7	70	1468	42.580835999999998	42.624071999999998	53.649861000000001	53.610871000000003	0103000020E61000000100000005000000732B84D5584A454094895B0531CE4A40732B84D5584A454012F92EA52ED34A40B62C5F97E14F454012F92EA52ED34A40B62C5F97E14F454094895B0531CE4A40732B84D5584A454094895B0531CE4A40
18093	Старополянское	7	70	1468	42.606546000000002	42.618915999999999	53.523358000000002	53.507010999999999	0103000020E6100000010000000500000083C2A04CA34D45402BDB87BCE5C04A4083C2A04CA34D4540CC0C1B65FDC24A404E7CB5A3384F4540CC0C1B65FDC24A404E7CB5A3384F45402BDB87BCE5C04A4083C2A04CA34D45402BDB87BCE5C04A40
17418	Салтыково	7	70	1468	42.432766999999998	42.479596000000001	53.612164	53.589706	0103000020E61000000100000005000000DEE4B7E864374540A320787C7BCB4A40DEE4B7E864374540EFE4D3635BCE4A406EA5D766633D4540EFE4D3635BCE4A406EA5D766633D4540A320787C7BCB4A40DEE4B7E864374540A320787C7BCB4A40
17344	Рянза	7	70	1468	42.415852000000001	42.508009999999999	53.490369000000001	53.472965000000002	0103000020E61000000100000005000000F4FC69A33A3545408A93FB1D8ABC4A40F4FC69A33A35454072FC5069C4BE4A403E05C0780641454072FC5069C4BE4A403E05C078064145408A93FB1D8ABC4A40F4FC69A33A3545408A93FB1D8ABC4A40
56496	Пролетарский	7	70	1468	42.082307	42.906098	53.853619999999999	53.325498000000003	0103000020E61000000100000005000000AE9D2809890A4540EB7420EBA9A94A40AE9D2809890A4540139B8F6B43ED4A404A7CEE04FB734540139B8F6B43ED4A404A7CEE04FB734540EB7420EBA9A94A40AE9D2809890A4540EB7420EBA9A94A40
21331	Пашково	7	70	1468	42.397589000000004	42.430574999999997	53.660997999999999	53.636029999999998	0103000020E61000000100000005000000EB1F4432E43245402FA3586E69D14A40EB1F4432E4324540575C1C959BD44A40D3BCE3141D374540575C1C959BD44A40D3BCE3141D3745402FA3586E69D14A40EB1F4432E43245402FA3586E69D14A40
17408	Оторма	7	70	1468	42.464280000000002	42.547203000000003	53.547504000000004	53.527388999999999	0103000020E61000000100000005000000EC17EC866D3B454094A2957B81C34A40EC17EC866D3B4540F0366F9C14C64A40F5A276BF0A464540F0366F9C14C64A40F5A276BF0A46454094A2957B81C34A40EC17EC866D3B454094A2957B81C34A40
17659	Морсово	7	70	1468	42.307361999999998	42.336790999999998	53.748171999999997	53.729841	0103000020E610000001000000050000003E0455A357274540D5230D6E6BDD4A403E0455A35727454036E49F19C4DF4A40274BADF71B2B454036E49F19C4DF4A40274BADF71B2B4540D5230D6E6BDD4A403E0455A357274540D5230D6E6BDD4A40
17147	Матчерка	7	70	1468	42.684959999999997	42.738985	53.451897000000002	53.419834999999999	0103000020E61000000100000005000000B988EFC4AC574540AB5B3D27BDB54A40B988EFC4AC5745408C14CAC2D7B94A40069E7B0F975E45408C14CAC2D7B94A40069E7B0F975E4540AB5B3D27BDB54A40B988EFC4AC574540AB5B3D27BDB54A40
18201	Малая Ижмора	7	70	1468	42.779364000000001	42.836928	53.541612999999998	53.507835999999998	0103000020E6100000010000000500000002D71533C2634540A0DD21C500C14A4002D71533C2634540520B259353C54A40A88DEA74206B4540520B259353C54A40A88DEA74206B4540A0DD21C500C14A4002D71533C2634540A0DD21C500C14A40
17491	Лебедянка	7	70	1468	42.537878999999997	42.559024999999998	53.603001999999996	53.585943	0103000020E61000000100000005000000431A1538D9444540FA28232E00CB4A40431A1538D944454017B6662B2FCD4A40BD5296218E47454017B6662B2FCD4A40BD5296218E474540FA28232E00CB4A40431A1538D9444540FA28232E00CB4A40
17911	Красная Дубрава	7	70	1468	42.671664999999997	42.702117999999999	53.684041999999998	53.650416	0103000020E61000000100000005000000156F641EF9554540C765DCD440D34A40156F641EF9554540938B31B08ED74A406AF7AB00DF594540938B31B08ED74A406AF7AB00DF594540C765DCD440D34A40156F641EF9554540C765DCD440D34A40
17752	Кириллово	7	70	1468	42.642226999999998	42.707813000000002	53.782069999999997	53.742452999999998	0103000020E61000000100000005000000D9CD8C7E3452454096E82CB308DF4A40D9CD8C7E345245406397A8DE1AE44A408257CB9D995A45406397A8DE1AE44A408257CB9D995A454096E82CB308DF4A40D9CD8C7E3452454096E82CB308DF4A40
16772	Земетчино	7	70	1468	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
17253	Долгово	7	70	1468	42.302717999999999	42.370396999999997	53.404677999999997	53.374175000000001	0103000020E610000001000000050000008CF4A276BF2645408BFD65F7E4AF4A408CF4A276BF26454091B41B7DCCB34A40ACC43C2B692F454091B41B7DCCB34A40ACC43C2B692F45408BFD65F7E4AF4A408CF4A276BF2645408BFD65F7E4AF4A40
17850	Гоголев Бор	7	70	1468	42.580351	42.609115000000003	53.738059	53.718296000000002	0103000020E61000000100000005000000B7990AF1484A45407F6C921FF1DB4A40B7990AF1484A45405DC2A1B778DE4A406440F67AF74D45405DC2A1B778DE4A406440F67AF74D45407F6C921FF1DB4A40B7990AF1484A45407F6C921FF1DB4A40
18063	Вяземка	7	70	1468	42.652971000000001	42.698596000000002	53.616325000000003	53.574646999999999	0103000020E61000000100000005000000431EC18D945345404CDF6B088EC94A40431EC18D94534540865AD3BCE3CE4A40E78EFE976B594540865AD3BCE3CE4A40E78EFE976B5945404CDF6B088EC94A40431EC18D945345404CDF6B088EC94A40
18159	Большая Ижмора	7	70	1468	42.803626999999999	42.865225000000002	53.574289	53.541448000000003	0103000020E610000001000000050000005F97E13FDD664540083E062B4EC54A405F97E13FDD664540EDB94C4D82C94A403F575BB1BF6E4540EDB94C4D82C94A403F575BB1BF6E4540083E062B4EC54A405F97E13FDD664540083E062B4EC54A40
56487	Александровка	7	70	1468	42.201756000000003	42.238722000000003	53.682867999999999	53.671272999999999	0103000020E61000000100000005000000CAE2FE23D31945400AD80E46ECD54A40CAE2FE23D319454012BEF73768D74A40F96A47718E1E454012BEF73768D74A40F96A47718E1E45400AD80E46ECD54A40CAE2FE23D31945400AD80E46ECD54A40
62102	Заречный	7	70	7508	46.088487999999998	46.100085	53.897106000000001	53.890096999999997	0103000020E61000000100000005000000520B2593530B474044A2D0B2EEF14A40520B2593530B4740CF85915ED4F24A40FBE8D495CF0C4740CF85915ED4F24A40FBE8D495CF0C474044A2D0B2EEF14A40520B2593530B474044A2D0B2EEF14A40
15481	Юлово	7	70	1375	45.624274	45.66778	53.352702999999998	53.328499000000001	0103000020E610000001000000050000001EDFDE35E8CF464065E256410CAA4A401EDFDE35E8CF4640BD19355F25AD4A402176A6D079D54640BD19355F25AD4A402176A6D079D5464065E256410CAA4A401EDFDE35E8CF464065E256410CAA4A40
16090	Чаадаевка	7	70	1375	45.941299000000001	45.998468000000003	53.127014000000003	53.106498000000002	0103000020E61000000100000005000000F660527C7CF84640728BF9B9A18D4A40F660527C7CF846402C11A8FE41904A40200DA7CCCDFF46402C11A8FE41904A40200DA7CCCDFF4640728BF9B9A18D4A40F660527C7CF84640728BF9B9A18D4A40
16174	Чаадаевка	7	70	1375	45.868940000000002	45.947595999999997	53.148750999999997	53.133372999999999	0103000020E61000000100000005000000D717096D39EF4640AF95D05D12914A40D717096D39EF4640A71FD4450A934A4003E962D34AF94640A71FD4450A934A4003E962D34AF94640AF95D05D12914A40D717096D39EF4640AF95D05D12914A40
16015	Уранка	7	70	1375	45.912821999999998	45.935972	53.195931999999999	53.173440999999997	0103000020E61000000100000005000000DF88EE59D7F446408C648F5033964A40DF88EE59D7F44640B41EBE4C14994A4061FC34EECDF74640B41EBE4C14994A4061FC34EECDF746408C648F5033964A40DF88EE59D7F446408C648F5033964A40
15271	Трескино	7	70	1375	45.722532000000001	45.748727000000002	53.086491000000002	53.053393999999997	0103000020E610000001000000050000002028B7ED7BDC4640BCE6559DD5864A402028B7ED7BDC4640FD321823128B4A40EC504D49D6DF4640FD321823128B4A40EC504D49D6DF4640BCE6559DD5864A402028B7ED7BDC4640BCE6559DD5864A40
15049	Сурск	7	70	1375	45.675612999999998	45.716557999999999	53.090141000000003	53.065159999999999	0103000020E6100000010000000500000050E09D7C7AD64640F180B22957884A4050E09D7C7AD64640AE8383BD898B4A40F5D72B2CB8DB4640AE8383BD898B4A40F5D72B2CB8DB4640F180B22957884A4050E09D7C7AD64640F180B22957884A40
15629	Стеклозавод	7	70	1375	45.611652999999997	45.623116000000003	53.478523000000003	53.463419000000002	0103000020E6100000010000000500000009C03FA54ACE46402AAC545051BB4A4009C03FA54ACE464021B1DD3D40BD4A40A3CEDC43C2CF464021B1DD3D40BD4A40A3CEDC43C2CF46402AAC545051BB4A4009C03FA54ACE46402AAC545051BB4A40
56461	Старый Турдаки	7	70	1375	45.673340000000003	45.712076000000003	53.036952999999997	53.017353	0103000020E61000000100000005000000598B4F0130D6464066BE839F38824A40598B4F0130D646409A3E3BE0BA844A401D226E4E25DB46409A3E3BE0BA844A401D226E4E25DB464066BE839F38824A40598B4F0130D6464066BE839F38824A40
16320	Саловка	7	70	1375	45.884138999999998	45.909463000000002	53.111730000000001	53.085825999999997	0103000020E610000001000000050000001F0F7D772BF14640C092AB58FC8A4A401F0F7D772BF14640B5FD2B2B4D8E4A4006F6984869F44640B5FD2B2B4D8E4A4006F6984869F44640C092AB58FC8A4A401F0F7D772BF14640C092AB58FC8A4A40
15433	Русский Ишим	7	70	1375	45.505293000000002	45.531658	53.269477999999999	53.257074000000003	0103000020E61000000100000005000000E9F2E670ADC04640725303CDE7A04A40E9F2E670ADC04640E97E4E417EA24A4011548D5E0DC44640E97E4E417EA24A4011548D5E0DC44640725303CDE7A04A40E9F2E670ADC04640725303CDE7A04A40
56524	Новая Забалка	7	70	1375	45.420105	45.450890999999999	53.133415999999997	53.120297000000001	0103000020E610000001000000050000006BF12900C6B54640496760E4658F4A406BF12900C6B54640AE6186C613914A40C687D9CBB6B94640AE6186C613914A40C687D9CBB6B94640496760E4658F4A406BF12900C6B54640496760E4658F4A40
16398	Нижняя Елюзань	7	70	1375	46.002482999999998	46.032890999999999	53.106498000000002	53.085538999999997	0103000020E61000000100000005000000E2E5E95C510047402AC423F1F28A4A40E2E5E95C51004740728BF9B9A18D4A4097AAB4C535044740728BF9B9A18D4A4097AAB4C5350447402AC423F1F28A4A40E2E5E95C510047402AC423F1F28A4A40
15339	Мордовский Ишим	7	70	1375	45.621659999999999	45.648834000000001	53.197329000000003	53.167687000000001	0103000020E610000001000000050000009D9D0C8E92CF4640707B82C476954A409D9D0C8E92CF4640B5C6A01342994A40354415FE0CD34640B5C6A01342994A40354415FE0CD34640707B82C476954A409D9D0C8E92CF4640707B82C476954A40
15349	Можарка	7	70	1375	45.627428000000002	45.646597999999997	53.229247000000001	53.213143000000002	0103000020E610000001000000050000001F4C8A8F4FD04640882F1345489B4A401F4C8A8F4FD0464062DA37F7579D4A405AD427B9C3D2464062DA37F7579D4A405AD427B9C3D24640882F1345489B4A401F4C8A8F4FD04640882F1345489B4A40
15520	Кардаво	7	70	1375	45.800604999999997	45.821373999999999	53.463928000000003	53.447386999999999	0103000020E61000000100000005000000CD0182397AE64640E9D32AFA43B94A40CD0182397AE646406FD921FE61BB4A4071E481C822E946406FD921FE61BB4A4071E481C822E94640E9D32AFA43B94A40CD0182397AE64640E9D32AFA43B94A40
14940	Канаевка	7	70	1375	45.525568	45.608598999999998	53.114908	53.103054	0103000020E610000001000000050000007DE9EDCF45C346406ADC9BDF308D4A407DE9EDCF45C346403E062B4EB58E4A406CB07092E6CD46403E062B4EB58E4A406CB07092E6CD46406ADC9BDF308D4A407DE9EDCF45C346406ADC9BDF308D4A40
16490	Иванисовка	7	70	1375	46.073109000000002	46.095342000000002	53.029843	53.008429999999997	0103000020E610000001000000050000008A05BEA25B0947401327F73B14814A408A05BEA25B094740DC813AE5D1834A40B6F7A92A340C4740DC813AE5D1834A40B6F7A92A340C47401327F73B14814A408A05BEA25B0947401327F73B14814A40
56525	Затон	7	70	1375	45.611204000000001	45.638646999999999	53.087372000000002	53.073698	0103000020E610000001000000050000009A97C3EE3BCE4640EBE3A1EF6E894A409A97C3EE3BCE4640064B75012F8B4A402158552FBFD14640064B75012F8B4A402158552FBFD14640EBE3A1EF6E894A409A97C3EE3BCE4640EBE3A1EF6E894A40
15710	Городище	7	70	1375	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
15646	Вышелей	7	70	1375	45.458095	45.499364	53.438885999999997	53.405825999999998	0103000020E6100000010000000500000006BB61DBA2BA4640E9EE3A1BF2B34A4006BB61DBA2BA46400C569C6A2DB84A405E66D828EBBF46400C569C6A2DB84A405E66D828EBBF4640E9EE3A1BF2B34A4006BB61DBA2BA4640E9EE3A1BF2B34A40
15574	Верхний Шкафт	7	70	1375	45.571382	45.626547000000002	53.521290999999998	53.496509000000003	0103000020E61000000100000005000000F4C29D0B23C94640B8955E9B8DBF4A40F4C29D0B23C946407D59DAA9B9C24A4016342DB132D046407D59DAA9B9C24A4016342DB132D04640B8955E9B8DBF4A40F4C29D0B23C94640B8955E9B8DBF4A40
56464	Веденяпино	7	70	1375	46.041837999999998	46.048206999999998	53.061523999999999	53.040320999999999	0103000020E6100000010000000500000072DD94F25A054740C72B103D29854A4072DD94F25A054740A5F5B704E0874A401938A0A52B064740A5F5B704E0874A401938A0A52B064740C72B103D29854A4072DD94F25A054740C72B103D29854A40
16002	Архангельское	7	70	1375	45.842691000000002	45.881793999999999	53.189323000000002	53.161776000000003	0103000020E6100000010000000500000018D1764CDDEB46408CA37213B5944A4018D1764CDDEB4640B8B06EBC3B984A408EE733A0DEF04640B8B06EBC3B984A408EE733A0DEF046408CA37213B5944A4018D1764CDDEB46408CA37213B5944A40
14766	Ягановка	7	70	553	43.152740000000001	43.175952000000002	53.669981999999997	53.650740999999996	0103000020E610000001000000050000004165FCFB8C9345404A95287B4BD34A404165FCFB8C9345404F745DF8C1D54A4039D55A98859645404F745DF8C1D54A4039D55A98859645404A95287B4BD34A404165FCFB8C9345404A95287B4BD34A40
14653	Татарская Лака	7	70	553	42.886443	42.905603999999997	53.786076000000001	53.77319	0103000020E610000001000000050000005262D7F67671454010CCD1E3F7E24A405262D7F676714540D3156C239EE44A403A90F5D4EA734540D3156C239EE44A403A90F5D4EA73454010CCD1E3F7E24A405262D7F67671454010CCD1E3F7E24A40
14614	Серго-Поливаново	7	70	553	42.782822000000003	42.816445999999999	53.753453999999998	53.740025000000003	0103000020E610000001000000050000006F4BE48233644540789CA223B9DE4A406F4BE482336445402B85402E71E04A409A79724D816845402B85402E71E04A409A79724D81684540789CA223B9DE4A406F4BE48233644540789CA223B9DE4A40
14000	Ртищево	7	70	553	42.793089999999999	42.824252999999999	53.699392000000003	53.683396000000002	0103000020E610000001000000050000006F641EF983654540CE1B278579D74A406F641EF983654540C28A53AD85D94A40A0504F1F81694540C28A53AD85D94A40A0504F1F81694540CE1B278579D74A406F641EF983654540CE1B278579D74A40
48955	Рахмановка	7	70	553	42.974333999999999	43.017867000000003	53.597706000000002	53.569124000000002	0103000020E61000000100000005000000C0B0FCF9B67C454032AF230ED9C84A40C0B0FCF9B67C4540BE4F55A181CC4A40BD56427749824540BE4F55A181CC4A40BD5642774982454032AF230ED9C84A40C0B0FCF9B67C454032AF230ED9C84A40
56441	Мочалейка	7	70	553	42.930765999999998	42.951481000000001	53.793841999999998	53.782027999999997	0103000020E61000000100000005000000471D1D57237745403447567E19E44A40471D1D57237745407A185A9D9CE54A40F8E12021CA7945407A185A9D9CE54A40F8E12021CA7945403447567E19E44A40471D1D57237745403447567E19E44A40
13420	Маркино	7	70	553	43.307250000000003	43.320725000000003	53.636809999999997	53.631027000000003	0103000020E6100000010000000500000017D9CEF753A745404EF2237EC5D04A4017D9CEF753A7454004E275FD82D14A403B014D840DA9454004E275FD82D14A403B014D840DA945404EF2237EC5D04A4017D9CEF753A745404EF2237EC5D04A40
14883	Котел	7	70	553	43.226517999999999	43.273364999999998	53.573701	53.555025999999998	0103000020E6100000010000000500000048FAB48AFE9C454000378B170BC74A4048FAB48AFE9C45405C57CC086FC94A407E6FD39FFDA245405C57CC086FC94A407E6FD39FFDA2454000378B170BC74A4048FAB48AFE9C454000378B170BC74A40
14573	Коповка	7	70	553	43.112853999999999	43.167661000000003	53.576507999999997	53.534784999999999	0103000020E61000000100000005000000849CF7FF718E454018B2BAD573C44A40849CF7FF718E4540F1F09E03CBC94A4047E867EA75954540F1F09E03CBC94A4047E867EA7595454018B2BAD573C44A40849CF7FF718E454018B2BAD573C44A40
13513	Каргалей	7	70	553	43.231028000000002	43.25159	53.675716000000001	53.661686000000003	0103000020E61000000100000005000000EB3A5453929D45404C1C7920B2D44A40EB3A5453929D454025B1A4DC7DD64A401500E31934A0454025B1A4DC7DD64A401500E31934A045404C1C7920B2D44A40EB3A5453929D45404C1C7920B2D44A40
14709	Выборное	7	70	553	42.999091999999997	43.015251999999997	53.804876999999998	53.777898999999998	0103000020E61000000100000005000000FDD8243FE27F4540A94BC63192E34A40FDD8243FE27F4540BB26A43506E74A406B990CC7F3814540BB26A43506E74A406B990CC7F3814540A94BC63192E34A40FDD8243FE27F4540A94BC63192E34A40
3418	Вадинск	7	70	553	43.018675000000002	43.088222999999999	53.710616999999999	53.662416999999998	0103000020E610000001000000050000005C2041F1638245403FA88B14CAD44A405C2041F163824540A67D737FF5DA4A40A4E029E44A8B4540A67D737FF5DA4A40A4E029E44A8B45403FA88B14CAD44A405C2041F1638245403FA88B14CAD44A40
13905	Большая Лука	7	70	553	42.879257000000003	42.917335999999999	53.722372	53.694077	0103000020E61000000100000005000000B9E34D7E8B704540F1F3DF83D7D84A40B9E34D7E8B704540E7C589AF76DC4A40C3B81B446B754540E7C589AF76DC4A40C3B81B446B754540F1F3DF83D7D84A40B9E34D7E8B704540F1F3DF83D7D84A40
58938	пос.Полевой	7	70	1055	44.724333000000001	45.472306000000003	53.606757999999999	53.035533999999998	0103000020E61000000100000005000000F03499F1B65C4640B2F2CB608C844A40F03499F1B65C46400E4B033FAACD4A4030DAE38574BC46400E4B033FAACD4A4030DAE38574BC4640B2F2CB608C844A40F03499F1B65C4640B2F2CB608C844A40
13005	Чертково	7	70	1055	44.937601999999998	44.980927999999999	53.413888	53.395609999999998	0103000020E610000001000000050000000455A357037846403BFC3559A3B24A400455A357037846407A1A3048FAB44A4087DD770C8F7D46407A1A3048FAB44A4087DD770C8F7D46403BFC3559A3B24A400455A357037846403BFC3559A3B24A40
13763	Чемодановка	7	70	1055	45.220886	45.277408000000001	53.256836999999997	53.208440000000003	0103000020E61000000100000005000000771211FE459C4640D1967329AE9A4A40771211FE459C46408DB3E908E0A04A400BD3F71A82A346408DB3E908E0A04A400BD3F71A82A34640D1967329AE9A4A40771211FE459C4640D1967329AE9A4A40
13696	Трофимовка	7	70	1055	45.373491999999999	45.398986000000001	53.241207000000003	53.219295000000002	0103000020E61000000100000005000000A8A8FA95CEAF46409296CADB119C4A40A8A8FA95CEAF46407C48F8DEDF9E4A40EBC726F911B346407C48F8DEDF9E4A40EBC726F911B346409296CADB119C4A40A8A8FA95CEAF46409296CADB119C4A40
13230	Степное Полеологово	7	70	1055	44.941428999999999	44.967813	53.337882	53.324857999999999	0103000020E61000000100000005000000C440D7BE8078464007EC6AF294A94A40C440D7BE807846401BF4A5B73FAB4A4063D2DF4BE17B46401BF4A5B73FAB4A4063D2DF4BE17B464007EC6AF294A94A40C440D7BE8078464007EC6AF294A94A40
13629	Степановка	7	70	1055	45.393830000000001	45.449849	53.262250999999999	53.243023000000001	0103000020E6100000010000000500000083177D0569B246408196AE601B9F4A4083177D0569B24640F12BD67091A14A40B491EBA694B94640F12BD67091A14A40B491EBA694B946408196AE601B9F4A4083177D0569B246408196AE601B9F4A40
13419	Сосновка	7	70	1055	45.284927000000003	45.326554999999999	53.295406	53.263919999999999	0103000020E61000000100000005000000AB5FE97C78A4464052616C21C8A14A40AB5FE97C78A44640668522DDCFA54A4032ACE28DCCA94640668522DDCFA54A4032ACE28DCCA9464052616C21C8A14A40AB5FE97C78A4464052616C21C8A14A40
13296	Пыркино	7	70	1055	45.064174999999999	45.145724000000001	53.499491999999996	53.446733000000002	0103000020E61000000100000005000000431CEBE236884640A185048C2EB94A40431CEBE2368846408B4E965AEFBF4A40041F8315A79246408B4E965AEFBF4A40041F8315A7924640A185048C2EB94A40431CEBE236884640A185048C2EB94A40
13348	Проказна	7	70	1055	45.131072000000003	45.169089	53.539676	53.501483999999998	0103000020E61000000100000005000000EEB5A0F7C6904640CFBBB1A030C04A40EEB5A0F7C6904640D237691A14C54A40828E56B5A4954640D237691A14C54A40828E56B5A4954640CFBBB1A030C04A40EEB5A0F7C6904640CFBBB1A030C04A40
13631	Пазелки	7	70	1055	45.36741	45.401986000000001	53.361006000000003	53.337629	0103000020E61000000100000005000000971C774A07AF46403197546D37AB4A40971C774A07AF464074D4D17135AE4A4095B9F94674B3464074D4D17135AE4A4095B9F94674B346403197546D37AB4A40971C774A07AF46403197546D37AB4A40
13570	Лопуховка	7	70	1055	45.31776	45.343533000000001	53.328848000000001	53.300626999999999	0103000020E610000001000000050000000DFD135CACA84640B5A50EF27AA64A400DFD135CACA8464071ADF6B017AA4A40630CACE3F8AB464071ADF6B017AA4A40630CACE3F8AB4640B5A50EF27AA64A400DFD135CACA84640B5A50EF27AA64A40
13844	Лопатки	7	70	1055	45.227587	45.243442999999999	53.203418999999997	53.191001	0103000020E6100000010000000500000054FF2092219D46406C4084B872984A4054FF2092219D4640483140A2099A4A4056B8E523299F4640483140A2099A4A4056B8E523299F46406C4084B872984A4054FF2092219D46406C4084B872984A40
56426	Леонидовка	7	70	1055	45.219341	45.259369999999997	53.160685000000001	53.121279999999999	0103000020E6100000010000000500000002D6AA5D139C464056D4601A868F4A4002D6AA5D139C464098FA795391944A4021C8410933A1464098FA795391944A4021C8410933A1464056D4601A868F4A4002D6AA5D139C464056D4601A868F4A40
13061	Кижеватово	7	70	1055	45.273833000000003	45.306773999999997	53.230476000000003	53.197960000000002	0103000020E6100000010000000500000065C8B1F50CA3464045F5D6C056994A4065C8B1F50CA34640A741D13C809D4A40ADA1D45E44A74640A741D13C809D4A40ADA1D45E44A7464045F5D6C056994A4065C8B1F50CA3464045F5D6C056994A40
9271	Золотаревка	7	70	1055	45.308858000000001	45.340560000000004	53.097014999999999	53.051543000000002	0103000020E61000000100000005000000D28DB0A888A746403BAB05F698864A40D28DB0A888A74640581CCEFC6A8C4A40B329577897AB4640581CCEFC6A8C4A40B329577897AB46403BAB05F698864A40D28DB0A888A746403BAB05F698864A40
12688	Грабово	7	70	1055	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
12622	Вазерки	7	70	1055	45.055677000000003	45.102424999999997	53.450363000000003	53.410409999999999	0103000020E61000000100000005000000D811876C20874640C6F99B5088B44A40D811876C208746400B2AAA7EA5B94A407AA52C431C8D46400B2AAA7EA5B94A407AA52C431C8D4640C6F99B5088B44A40D811876C20874640C6F99B5088B44A40
13201	Блохино	7	70	1055	44.882868000000002	44.913195000000002	53.338016000000003	53.322760000000002	0103000020E61000000100000005000000AC5791D1017146407E3A1E3350A94A40AC5791D1017146402BC3B81B44AB4A4074EFE192E37446402BC3B81B44AB4A4074EFE192E37446407E3A1E3350A94A40AC5791D1017146407E3A1E3350A94A40
12290	Бессоновка	7	70	1055	45.033856999999998	45.049793000000001	53.338591999999998	53.334107000000003	0103000020E61000000100000005000000CEDE196D55844640AE2EA704C4AA4A40CEDE196D55844640F7578FFB56AB4A40ED48F59D5F864640F7578FFB56AB4A40ED48F59D5F864640AE2EA704C4AA4A40CEDE196D55844640AE2EA704C4AA4A40
47894	Языково	7	70	925	43.538117	43.558633999999998	52.961925999999998	52.948087000000001	0103000020E61000000100000005000000F8359204E1C44540A26131EA5A794A40F8359204E1C4454007962364207B4A408237A45181C7454007962364207B4A408237A45181C74540A26131EA5A794A40F8359204E1C44540A26131EA5A794A40
48070	Ширяево	7	70	925	42.975788999999999	43.014228000000003	52.980223000000002	52.968764999999998	0103000020E61000000100000005000000F56569A7E67C45403541D47D007C4A40F56569A7E67C4540BDE47FF2777D4A4000581D39D2814540BDE47FF2777D4A4000581D39D28145403541D47D007C4A40F56569A7E67C45403541D47D007C4A40
56454	Шарова	7	70	925	43.117668999999999	43.146101000000002	53.087978	53.073042999999998	0103000020E6100000010000000500000063601DC70F8F4540D219187959894A4063601DC70F8F45403D62F4DC428B4A40DA740470B39245403D62F4DC428B4A40DA740470B3924540D219187959894A4063601DC70F8F4540D219187959894A40
56425	Ульяновка	7	70	925	43.30292	43.307977000000001	52.919004999999999	52.916665000000002	0103000020E61000000100000005000000F4A62215C6A64540A5315A4755754A40F4A62215C6A6454024EEB1F4A1754A40C97553CA6BA7454024EEB1F4A1754A40C97553CA6BA74540A5315A4755754A40F4A62215C6A64540A5315A4755754A40
11037	Сяськино	7	70	925	43.350315000000002	43.373832999999998	52.974243000000001	52.961844999999997	0103000020E610000001000000050000002D26361FD7AC45401A69A9BC1D7B4A402D26361FD7AC4540B0AD9FFEB37C4A4031957EC2D9AF4540B0AD9FFEB37C4A4031957EC2D9AF45401A69A9BC1D7B4A402D26361FD7AC45401A69A9BC1D7B4A40
11105	Сулак	7	70	925	43.526573999999997	43.541691999999998	53.100475000000003	53.072443	0103000020E610000001000000050000004276DEC666C345407DE9EDCF45894A404276DEC666C345406688635DDC8C4A409E40D82956C545406688635DDC8C4A409E40D82956C545407DE9EDCF45894A404276DEC666C345407DE9EDCF45894A40
7395	Студенка	7	70	925	43.096487000000003	43.134180000000001	53.010055000000001	52.985179000000002	0103000020E610000001000000050000009DBE9EAF598C45405EDA70581A7E4A409DBE9EAF598C4540A514747B49814A407EE36BCF2C914540A514747B49814A407EE36BCF2C9145405EDA70581A7E4A409DBE9EAF598C45405EDA70581A7E4A40
10894	Среднеречье	7	70	925	43.656129	43.671731999999999	52.883116000000001	52.865864999999999	0103000020E61000000100000005000000857AFA08FCD3454022E010AAD46E4A40857AFA08FCD345408449F1F109714A409DD66D50FBD545408449F1F109714A409DD66D50FBD5454022E010AAD46E4A40857AFA08FCD3454022E010AAD46E4A40
12073	Сентяпино	7	70	925	43.044187000000001	43.100521000000001	52.990670000000001	52.973987999999999	0103000020E6100000010000000500000045F46BEBA7854540255987A3AB7C4A4045F46BEBA78545406D904946CE7E4A40D6C743DFDD8C45406D904946CE7E4A40D6C743DFDD8C4540255987A3AB7C4A4045F46BEBA7854540255987A3AB7C4A40
47606	Свищевка	7	70	925	43.731048000000001	43.776485000000001	52.854235000000003	52.836433999999997	0103000020E6100000010000000500000032E719FB92DD454098A1F144106B4A4032E719FB92DD45409E0C8E92576D4A40D36A48DC63E345409E0C8E92576D4A40D36A48DC63E3454098A1F144106B4A4032E719FB92DD454098A1F144106B4A40
11349	Пяркино	7	70	925	43.26202	43.284001000000004	52.956333000000001	52.944271999999998	0103000020E61000000100000005000000EF7211DF89A14540A643A7E7DD784A40EF7211DF89A14540F48AA71E697A4A4002840F255AA44540F48AA71E697A4A4002840F255AA44540A643A7E7DD784A40EF7211DF89A14540A643A7E7DD784A40
11907	Пушанино	7	70	925	43.349111000000001	43.412298999999997	52.937071000000003	52.925753	0103000020E6100000010000000500000041D653ABAFAC4540429605137F764A4041D653ABAFAC4540D88349F1F1774A403596B036C6B44540D88349F1F1774A403596B036C6B44540429605137F764A4041D653ABAFAC4540429605137F764A40
11788	Поим	7	70	925	43.161687000000001	43.208848000000003	53.039881999999999	53.014843999999997	0103000020E610000001000000050000001C98DC28B29445405A457F68E6814A401C98DC28B29445407BD976DA1A854A40E2EA0088BB9A45407BD976DA1A854A40E2EA0088BB9A45405A457F68E6814A401C98DC28B29445405A457F68E6814A40
56449	Невежкино	7	70	925	43.285663	43.380274	53.125824999999999	53.089070999999997	0103000020E61000000100000005000000B056ED9A90A44540D102B4AD668B4A40B056ED9A90A4454075029A081B904A4072C284D1ACB0454075029A081B904A4072C284D1ACB04540D102B4AD668B4A40B056ED9A90A44540D102B4AD668B4A40
56422	Лопатино	7	70	925	43.136920000000003	43.158219000000003	52.907156000000001	52.894444999999997	0103000020E610000001000000050000008C153598869145400D897B2C7D724A408C15359886914540622F14B01D744A408C4D2B8540944540622F14B01D744A408C4D2B85409445400D897B2C7D724A408C153598869145400D897B2C7D724A40
47825	Лермонтово	7	70	925	43.644756000000001	43.678119000000002	52.997407000000003	52.985275999999999	0103000020E610000001000000050000002CF3565D87D2454050C422861D7E4A402CF3565D87D2454097E65608AB7F4A40EBE5779ACCD6454097E65608AB7F4A40EBE5779ACCD6454050C422861D7E4A402CF3565D87D2454050C422861D7E4A40
58918	Кутеевка	7	70	925	42.827046000000003	43.875200999999997	53.188195	52.723095000000001	0103000020E61000000100000005000000D124B1A4DC694540587380608E5C4A40D124B1A4DC694540A72215C616984A4097361C9606F04540A72215C616984A4097361C9606F04540587380608E5C4A40D124B1A4DC694540587380608E5C4A40
11945	Кукарки	7	70	925	43.296990999999998	43.336562000000001	52.915393999999999	52.903950999999999	0103000020E61000000100000005000000691A14CD03A64540DF1797AAB4734A40691A14CD03A64540317A6EA12B754A40C689AF7614AB4540317A6EA12B754A40C689AF7614AB4540DF1797AAB4734A40691A14CD03A64540DF1797AAB4734A40
47893	Крюково	7	70	925	43.581892000000003	43.610773000000002	52.983454999999999	52.969807000000003	0103000020E61000000100000005000000EBE6E26F7BCA45404837C2A2227C4A40EBE6E26F7BCA4540390B7BDAE17D4A40D12346CF2DCE4540390B7BDAE17D4A40D12346CF2DCE45404837C2A2227C4A40EBE6E26F7BCA45404837C2A2227C4A40
11315	Корсаевка	7	70	925	43.198687999999997	43.233812999999998	53.004370999999999	52.978634999999997	0103000020E61000000100000005000000C70DBF9B6E99454048DC63E9437D4A40C70DBF9B6E99454081069B3A8F804A4098309A95ED9D454081069B3A8F804A4098309A95ED9D454048DC63E9437D4A40C70DBF9B6E99454048DC63E9437D4A40
56432	Козловка	7	70	925	43.200215999999998	43.2258	52.940707000000003	52.927604000000002	0103000020E6100000010000000500000066118AADA0994540C4D155BABB764A4066118AADA0994540240F441669784A40E9B7AF03E79C4540240F441669784A40E9B7AF03E79C4540C4D155BABB764A4066118AADA0994540C4D155BABB764A40
56460	Ключи	7	70	925	43.482430000000001	43.497332999999998	53.020516000000001	53.005059000000003	0103000020E61000000100000005000000FD4D2844C0BD454076C6F7C5A5804A40FD4D2844C0BD4540BA85AE44A0824A405C1C959BA8BF4540BA85AE44A0824A405C1C959BA8BF454076C6F7C5A5804A40FD4D2844C0BD454076C6F7C5A5804A40
11081	Кевдо-Вершина	7	70	925	43.444971000000002	43.500180999999998	53.136771000000003	53.114130000000003	0103000020E610000001000000050000008F554ACFF4B845400ABFD4CF9B8E4A408F554ACFF4B8454047054EB681914A40508A56EE05C0454047054EB681914A40508A56EE05C045400ABFD4CF9B8E4A408F554ACFF4B845400ABFD4CF9B8E4A40
47699	Камынино	7	70	925	43.419134999999997	43.459055999999997	52.933689000000001	52.913037000000003	0103000020E61000000100000005000000F2CD3637A6B54540DC847B65DE744A40F2CD3637A6B5454046D1031F83774A402B84D558C2BA454046D1031F83774A402B84D558C2BA4540DC847B65DE744A40F2CD3637A6B54540DC847B65DE744A40
11531	Калдуссы	7	70	925	43.760396	43.782504000000003	53.069099000000001	53.056328000000001	0103000020E610000001000000050000002E01F8A754E14540AFEC82C135874A402E01F8A754E14540D9976C3CD8884A409E7E501729E44540D9976C3CD8884A409E7E501729E44540AFEC82C135874A402E01F8A754E14540AFEC82C135874A40
47633	Волчково	7	70	925	43.428882000000002	43.469062999999998	52.979356000000003	52.957059999999998	0103000020E61000000100000005000000EAEBF99AE5B64540A6272CF1807A4A40EAEBF99AE5B64540199293895B7D4A40BF61A2410ABC4540199293895B7D4A40BF61A2410ABC4540A6272CF1807A4A40EAEBF99AE5B64540A6272CF1807A4A40
11218	Верхние Поляны	7	70	925	43.526474999999998	43.567473999999997	52.902811	52.887169999999998	0103000020E61000000100000005000000AF94658863C3454004FF5BC98E714A40AF94658863C345400ABC934F8F734A4047AAEFFCA2C845400ABC934F8F734A4047AAEFFCA2C8454004FF5BC98E714A40AF94658863C3454004FF5BC98E714A40
10730	Белинский	7	70	925	43.380381999999997	43.434531999999997	52.975012999999997	52.954689999999999	0103000020E6100000010000000500000058FE7C5BB0B04540BCE82B48337A4A4058FE7C5BB0B045406116DA39CD7C4A4061889CBE9EB745406116DA39CD7C4A4061889CBE9EB74540BCE82B48337A4A4058FE7C5BB0B04540BCE82B48337A4A40
10834	Балкашино	7	70	925	43.592410999999998	43.644064	52.881388000000001	52.867001000000002	0103000020E610000001000000050000003465A71FD4CB4540B64C86E3F96E4A403465A71FD4CB45401E8B6D52D1704A40F6436CB070D245401E8B6D52D1704A40F6436CB070D24540B64C86E3F96E4A403465A71FD4CB4540B64C86E3F96E4A40
58495	н.п. Первое отделение	7	70	1086	43.341799000000002	43.947093000000002	52.767901000000002	52.377026999999998	0103000020E610000001000000050000001B67D311C0AB4540C05AB56B42304A401B67D311C0AB454069C878944A624A40A1A2EA573AF9454069C878944A624A40A1A2EA573AF94540C05AB56B42304A401B67D311C0AB4540C05AB56B42304A40
10175	Яковлевка	7	70	1086	43.739465000000003	43.772362000000001	52.728397000000001	52.708263000000002	0103000020E61000000100000005000000B1C403CAA6DE4540C2FBAA5CA85A4A40B1C403CAA6DE454094C0E61C3C5D4A402A560DC2DCE2454094C0E61C3C5D4A402A560DC2DCE24540C2FBAA5CA85A4A40B1C403CAA6DE4540C2FBAA5CA85A4A40
10489	Сосновка	7	70	1086	43.472467999999999	43.536256999999999	52.434032999999999	52.410671000000001	0103000020E610000001000000050000000934D8D479BC4540333509DE90344A400934D8D479BC45404031B2648E374A4023A0C211A4C445404031B2648E374A4023A0C211A4C44540333509DE90344A400934D8D479BC4540333509DE90344A40
10666	Сахзавод	7	70	1086	43.584783999999999	43.626232999999999	52.442076	52.420689000000003	0103000020E61000000100000005000000AE9CBD33DACA4540BB641C23D9354A40AE9CBD33DACA45405A2C45F295384A408656276728D045405A2C45F295384A408656276728D04540BB641C23D9354A40AE9CBD33DACA4540BB641C23D9354A40
16392	Санниковка	7	70	1086	43.577176000000001	43.584578	52.673127999999998	52.667017000000001	0103000020E610000001000000050000009F0436E7E0C94540227024D060554A409F0436E7E0C94540CD02ED0E29564A4005FBAF73D3CA4540CD02ED0E29564A4005FBAF73D3CA4540227024D060554A409F0436E7E0C94540227024D060554A40
10118	Покровка	7	70	1086	43.867438999999997	43.893040999999997	52.625785999999998	52.604182999999999	0103000020E610000001000000050000003123BC3D08EF45404BE658DE554D4A403123BC3D08EF4540B72572C119504A405A7EE02A4FF24540B72572C119504A405A7EE02A4FF245404BE658DE554D4A403123BC3D08EF45404BE658DE554D4A40
56431	Плодосовхоз	7	70	1086	43.719144999999997	43.743921	52.502282000000001	52.490813000000003	0103000020E610000001000000050000007C0A80F10CDC4540D0B9DBF5D23E4A407C0A80F10CDC45404BAFCDC64A404A4060E7A6CD38DF45404BAFCDC64A404A4060E7A6CD38DF4540D0B9DBF5D23E4A407C0A80F10CDC4540D0B9DBF5D23E4A40
10073	Никольское	7	70	1086	43.789178	43.846356	52.627743000000002	52.605232999999998	0103000020E61000000100000005000000815CE2C803E54540E0BA6246784D4A40815CE2C803E545407FA5F3E159504A40FE62B66455EC45407FA5F3E159504A40FE62B66455EC4540E0BA6246784D4A40815CE2C803E54540E0BA6246784D4A40
9897	Мошки	7	70	1086	43.807189000000001	43.837947999999997	52.554904999999998	52.534838999999998	0103000020E6100000010000000500000071581AF851E745400BD0B69A75444A4071581AF851E7454085B1852007474A40D2DF4BE141EB454085B1852007474A40D2DF4BE141EB45400BD0B69A75444A4071581AF851E745400BD0B69A75444A40
10329	Миткирей	7	70	1086	43.557844000000003	43.597665999999997	52.553514	52.521399000000002	0103000020E610000001000000050000008A22A46E67C745406495D233BD424A408A22A46E67C7454067F0F78BD9464A402FF7C95180CC454067F0F78BD9464A402FF7C95180CC45406495D233BD424A408A22A46E67C745406495D233BD424A40
10207	Мача-Родники	7	70	1086	43.641423000000003	43.674804999999999	52.695532	52.681852999999997	0103000020E610000001000000050000007CF31B261AD24540F9D687F546574A407CF31B261AD2454026A94C3107594A40B1169F0260D6454026A94C3107594A40B1169F0260D64540F9D687F546574A407CF31B261AD24540F9D687F546574A40
56437	Крутец	7	70	1086	43.476393999999999	43.488269000000003	52.579411	52.575640999999997	0103000020E610000001000000050000005C01857AFABC45404D9EB29AAE494A405C01857AFABC4540A9F8BF232A4A4A4048533D997FBE4540A9F8BF232A4A4A4048533D997FBE45404D9EB29AAE494A405C01857AFABC45404D9EB29AAE494A40
10030	Ивановка	7	70	1086	43.781362999999999	43.807907999999998	52.652067000000002	52.631749999999997	0103000020E61000000100000005000000F8A6E9B303E44540BE9F1A2FDD504A40F8A6E9B303E4454082E673EE76534A40A016838769E7454082E673EE76534A40A016838769E74540BE9F1A2FDD504A40F8A6E9B303E44540BE9F1A2FDD504A40
10348	Затолокино	7	70	1086	43.601267999999997	43.621040000000001	52.589123999999998	52.581353999999997	0103000020E61000000100000005000000CF108E59F6CC45400BB3D0CE694A4A40CF108E59F6CC4540F4A44C6A684B4A4001C11C3D7ECF4540F4A44C6A684B4A4001C11C3D7ECF45400BB3D0CE694A4A40CF108E59F6CC45400BB3D0CE694A4A40
9870	Волынщино	7	70	1086	43.770879000000001	43.794927000000001	52.528976999999998	52.502665999999998	0103000020E610000001000000050000002B16BF29ACE24540D367075C57404A402B16BF29ACE2454008ABB184B5434A408CDAFD2AC0E5454008ABB184B5434A408CDAFD2AC0E54540D367075C57404A402B16BF29ACE24540D367075C57404A40
10602	Вертуновка	7	70	1086	43.542149999999999	43.613629000000003	52.455024000000002	52.432935000000001	0103000020E6100000010000000500000061C3D32B65C545409A25016A6A374A4061C3D32B65C545409372F7393E3A4A40487023658BCE45409372F7393E3A4A40487023658BCE45409A25016A6A374A4061C3D32B65C545409A25016A6A374A40
9568	Беково	7	70	1086	43.640112000000002	43.724392000000002	52.482717999999998	52.434632000000001	0103000020E610000001000000050000007AE3A430EFD14540C5E57805A2374A407AE3A430EFD14540639813B4C93D4A40F5BD86E0B8DC4540639813B4C93D4A40F5BD86E0B8DC4540C5E57805A2374A407AE3A430EFD14540C5E57805A2374A40
10258	Александровка	7	70	1086	43.585780999999997	43.604413000000001	52.684435000000001	52.676344	0103000020E6100000010000000500000020CF2EDFFACA4540446CB07092564A4020CF2EDFFACA45406F9EEA909B574A407D23BA675DCD45406F9EEA909B574A407D23BA675DCD4540446CB07092564A4020CF2EDFFACA4540446CB07092564A40
14905	Цепаево	7	70	945	43.259199000000002	43.279833000000004	53.820056000000001	53.810864000000002	0103000020E61000000100000005000000F513CE6E2DA145407BC03C64CAE74A40F513CE6E2DA14540BD715298F7E84A40B9AB5791D1A34540BD715298F7E84A40B9AB5791D1A345407BC03C64CAE74A40F513CE6E2DA145407BC03C64CAE74A40
15332	Устье	7	70	945	43.240729999999999	43.265127999999997	53.996640999999997	53.988151000000002	0103000020E6100000010000000500000042959A3DD09E45403E4162BB7BFE4A4042959A3DD09E4540266DAAEE91FF4A407FA0DCB6EFA14540266DAAEE91FF4A407FA0DCB6EFA145403E4162BB7BFE4A4042959A3DD09E45403E4162BB7BFE4A40
15351	Спасск	7	70	945	43.166573999999997	43.205793999999997	53.943117000000001	53.909885000000003	0103000020E61000000100000005000000942EFD4B529545407C0F971C77F44A40942EFD4B529545409CA6CF0EB8F84A4044DB3175579A45409CA6CF0EB8F84A4044DB3175579A45407C0F971C77F44A40942EFD4B529545407C0F971C77F44A40
15212	Русский Шелдаис	7	70	945	43.137081999999999	43.154086999999997	53.789352999999998	53.780197999999999	0103000020E61000000100000005000000656F29E78B914540CA332F87DDE34A40656F29E78B914540EFFFE38409E54A408FDE701FB9934540EFFFE38409E54A408FDE701FB9934540CA332F87DDE34A40656F29E78B914540CA332F87DDE34A40
56529	Русский Пимбур	7	70	945	43.045571000000002	43.604394999999997	54.025922000000001	53.677599000000001	0103000020E61000000100000005000000B1524145D5854540B2666490BBD64A40B1524145D58545409B1F7F6951034B40D66EBBD05CCD45409B1F7F6951034B40D66EBBD05CCD4540B2666490BBD64A40B1524145D5854540B2666490BBD64A40
15132	Рузаново	7	70	945	43.302408	43.325800000000001	53.737468	53.71593	0103000020E610000001000000050000003E062B4EB5A64540D61C2098A3DB4A403E062B4EB5A645405BECF65965DE4A40B6847CD0B3A945405BECF65965DE4A40B6847CD0B3A94540D61C2098A3DB4A403E062B4EB5A64540D61C2098A3DB4A40
14513	Липлейка	7	70	945	43.148589000000001	43.168595000000003	53.956147000000001	53.930422	0103000020E61000000100000005000000CEC5DFF6049345404DBD6E1118F74A40CEC5DFF60493454092955F0663FA4A4073A25D859495454092955F0663FA4A4073A25D85949545404DBD6E1118F74A40CEC5DFF6049345404DBD6E1118F74A40
14850	Красный Восток	7	70	945	43.343569000000002	43.366627999999999	53.825929000000002	53.821261999999997	0103000020E61000000100000005000000B075A911FAAB454049B9FB1C1FE94A40B075A911FAAB4540B4E89D0AB8E94A4021E692AAEDAE4540B4E89D0AB8E94A4021E692AAEDAE454049B9FB1C1FE94A40B075A911FAAB454049B9FB1C1FE94A40
15046	Кошелевка	7	70	945	43.254078999999997	43.268622000000001	53.926388000000003	53.906086999999999	0103000020E61000000100000005000000D9CC21A985A04540562AA8A8FAF34A40D9CC21A985A0454014B4C9E193F64A40397EA83462A2454014B4C9E193F64A40397EA83462A24540562AA8A8FAF34A40D9CC21A985A04540562AA8A8FAF34A40
14989	Зубово	7	70	945	43.374578999999997	43.394261	53.721764	53.710436000000001	0103000020E610000001000000050000005A626534F2AF454056F31C91EFDA4A405A626534F2AF45400FB743C362DC4A404C8BFA2477B245400FB743C362DC4A404C8BFA2477B2454056F31C91EFDA4A405A626534F2AF454056F31C91EFDA4A40
22609	Дубровки	7	70	945	43.282555000000002	43.339903999999997	53.832673	53.808971999999997	0103000020E61000000100000005000000202922C32AA445409AB0FD648CE74A40202922C32AA4454090A1630795EA4A40C9E369F981AB454090A1630795EA4A40C9E369F981AB45409AB0FD648CE74A40202922C32AA445409AB0FD648CE74A40
14612	Дерябкино	7	70	945	43.178629000000001	43.196055999999999	53.870860999999998	53.848785999999997	0103000020E61000000100000005000000008FA850DD964540BDA60705A5EC4A40008FA850DD964540512E8D5F78EF4A40A017EE5C18994540512E8D5F78EF4A40A017EE5C18994540BDA60705A5EC4A40008FA850DD964540BDA60705A5EC4A40
7677	Веденяпино	7	70	945	43.340083	43.360726999999997	53.784773000000001	53.767719	0103000020E610000001000000050000007976F9D687AB454048C2BE9D44E24A407976F9D687AB454054E4107173E44A4060E4654D2CAE454054E4107173E44A4060E4654D2CAE454048C2BE9D44E24A407976F9D687AB454048C2BE9D44E24A40
15187	Баранчеевка	7	70	945	43.234271	43.255479999999999	53.733569000000003	53.715412999999998	0103000020E610000001000000050000005BB39597FC9D45400E1137A792DB4A405BB39597FC9D4540022EC896E5DD4A401B649291B3A04540022EC896E5DD4A401B649291B3A045400E1137A792DB4A405BB39597FC9D45400E1137A792DB4A40
14701	Ахлебинино	7	70	945	43.332447999999999	43.359146000000003	53.800601999999998	53.793751999999998	0103000020E6100000010000000500000070CFF3A78DAA45403A9160AA99E54A4070CFF3A78DAA45405C8E57207AE64A409F3E027FF8AD45405C8E57207AE64A409F3E027FF8AD45403A9160AA99E54A4070CFF3A78DAA45403A9160AA99E54A40
14461	Абашево	7	70	945	43.332788999999998	43.363188000000001	53.943626000000002	53.924919000000003	0103000020E61000000100000005000000F9BB77D498AA45407A39ECBE63F64A40F9BB77D498AA4540E1D39CBCC8F84A405B26C3F17CAE4540E1D39CBCC8F84A405B26C3F17CAE45407A39ECBE63F64A40F9BB77D498AA45407A39ECBE63F64A40
56518	Шереметьево	7	70	999	43.055945999999999	43.083129	53.185912999999999	53.16075	0103000020E61000000100000005000000C72B103D298745407F6ABC7493944A40C72B103D298745405C7347FFCB974A40B22C98F8A38A45405C7347FFCB974A40B22C98F8A38A45407F6ABC7493944A40C72B103D298745407F6ABC7493944A40
46225	Чудная	7	70	999	42.561100000000003	42.587770999999996	53.305157999999999	53.284495999999997	0103000020E610000001000000050000008FE4F21FD2474540E1EB6B5D6AA44A408FE4F21FD24745406F0ED76A0FA74A40C34483143C4B45406F0ED76A0FA74A40C34483143C4B4540E1EB6B5D6AA44A408FE4F21FD2474540E1EB6B5D6AA44A40
56485	Троицкое	7	70	999	42.778942000000001	42.817605	53.280662	53.258383000000002	0103000020E610000001000000050000008CBD175FB4634540D36BB3B112A14A408CBD175FB46345406F9D7FBBECA34A40E605D847A76845406F9D7FBBECA34A40E605D847A7684540D36BB3B112A14A408CBD175FB4634540D36BB3B112A14A40
46936	Тимирязево	7	70	999	42.847051999999998	42.876472	53.293059999999997	53.275078999999998	0103000020E6100000010000000500000075012F336C6C45407F68E6C935A34A4075012F336C6C454004E275FD82A54A400BEE073C3070454004E275FD82A54A400BEE073C307045407F68E6C935A34A4075012F336C6C45407F68E6C935A34A40
56494	Спиртозавод	7	70	999	42.890126000000002	42.900905999999999	53.306072	53.298834999999997	0103000020E61000000100000005000000DFA815A6EF71454038F3AB3940A64A40DFA815A6EF714540541C075E2DA74A40956247E350734540541C075E2DA74A40956247E35073454038F3AB3940A64A40DFA815A6EF71454038F3AB3940A64A40
9190	Соседка	7	70	999	42.649377999999999	42.680585000000001	53.250841000000001	53.224254999999999	0103000020E61000000100000005000000F65E7CD11E534540747B4963B49C4A40F65E7CD11E5345407BBFD18E1BA04A40F792C6681D5745407BBFD18E1BA04A40F792C6681D574540747B4963B49C4A40F65E7CD11E534540747B4963B49C4A40
9165	Соломинка	7	70	999	42.629471000000002	42.653950000000002	53.173079999999999	53.155819999999999	0103000020E61000000100000005000000E5637781925045400708E6E8F1934A40E563778192504540BCCB457C27964A400F9C33A2B4534540BCCB457C27964A400F9C33A2B45345400708E6E8F1934A40E5637781925045400708E6E8F1934A40
46822	Подгорное	7	70	999	42.781303999999999	42.799737999999998	53.219380999999998	53.182535000000001	0103000020E61000000100000005000000F31DFCC4016445400CB08F4E5D974A40F31DFCC401644540902E36AD149C4A4029AF95D05D664540902E36AD149C4A4029AF95D05D6645400CB08F4E5D974A40F31DFCC4016445400CB08F4E5D974A40
46880	Петровское	7	70	999	42.736477999999998	42.776049	53.104443000000003	53.080329999999996	0103000020E610000001000000050000009B1C3EE9445E45409F71E140488A4A409B1C3EE9445E4540E8A562635E8D4A40F88BD99255634540E8A562635E8D4A40F88BD992556345409F71E140488A4A409B1C3EE9445E45409F71E140488A4A40
46960	Новознаменский	7	70	999	42.891483000000001	42.911470000000001	53.294722999999998	53.275300000000001	0103000020E6100000010000000500000051F86C1D1C7245405E4BC8073DA34A4051F86C1D1C7245408330B77BB9A54A407FA4880CAB7445408330B77BB9A54A407FA4880CAB7445405E4BC8073DA34A4051F86C1D1C7245405E4BC8073DA34A40
56445	Никульевка	7	70	999	42.829337000000002	42.856098000000003	53.067433000000001	53.048338999999999	0103000020E610000001000000050000006F2EFEB6276A4540880FECF82F864A406F2EFEB6276A4540E9D500A5A1884A40E415889E946D4540E9D500A5A1884A40E415889E946D4540880FECF82F864A406F2EFEB6276A4540880FECF82F864A40
47005	Митрофаново	7	70	999	43.066276999999999	43.112540000000003	53.132195000000003	53.093873000000002	0103000020E610000001000000050000000EBDC5C37B8845401C7DCC07048C4A400EBDC5C37B884540EDD808C4EB904A40F5BEF1B5678E4540EDD808C4EB904A40F5BEF1B5678E45401C7DCC07048C4A400EBDC5C37B8845401C7DCC07048C4A40
46851	Марат	7	70	999	42.937548	42.964137999999998	53.095824999999998	53.084299999999999	0103000020E610000001000000050000001137A79201784540C286A757CA8A4A401137A79201784540D1915CFE438C4A40596ABDDF687B4540D1915CFE438C4A40596ABDDF687B4540C286A757CA8A4A401137A79201784540C286A757CA8A4A40
40464	Липовка	7	70	999	42.696871999999999	42.748102000000003	53.289786999999997	53.264066	0103000020E61000000100000005000000C2BF081A3359454026FE28EACCA14A40C2BF081A3359454029E78BBD17A54A403E096CCEC15F454029E78BBD17A54A403E096CCEC15F454026FE28EACCA14A40C2BF081A3359454026FE28EACCA14A40
56478	Кирилловка	7	70	999	42.683055000000003	42.712341000000002	53.351128000000003	53.333407999999999	0103000020E61000000100000005000000452FA3586E574540C51C041DADAA4A40452FA3586E574540DE5A26C3F1AC4A40CB4C69FD2D5B4540DE5A26C3F1AC4A40CB4C69FD2D5B4540C51C041DADAA4A40452FA3586E574540C51C041DADAA4A40
8952	Кандиевка	7	70	999	42.871566999999999	42.921773999999999	53.204071999999996	53.186706000000001	0103000020E61000000100000005000000ECA2E8818F6F4540C6FB71FBE5974A40ECA2E8818F6F4540C00303081F9A4A40CC26C0B0FC754540C00303081F9A4A40CC26C0B0FC754540C6FB71FBE5974A40ECA2E8818F6F4540C6FB71FBE5974A40
46737	Знаменское	7	70	999	42.912027000000002	42.965997999999999	53.340677999999997	53.301186000000001	0103000020E61000000100000005000000D508FD4CBD744540AC014A438DA64A40D508FD4CBD744540BC3B32569BAB4A402E008DD2A57B4540BC3B32569BAB4A402E008DD2A57B4540AC014A438DA64A40D508FD4CBD744540AC014A438DA64A40
46599	Дружный	7	70	999	42.735759999999999	42.748308999999999	53.142010999999997	53.134841999999999	0103000020E610000001000000050000003CDA38622D5E45404910AE8042914A403CDA38622D5E45400C569C6A2D924A40B726DD96C85F45400C569C6A2D924A40B726DD96C85F45404910AE8042914A403CDA38622D5E45404910AE8042914A40
47037	Глебовка	7	70	999	43.163978	43.183371999999999	53.243561999999997	53.228810000000003	0103000020E61000000100000005000000BAA1293BFD944540B77F65A5499D4A40BAA1293BFD9445403046240A2D9F4A404580D3BB789745403046240A2D9F4A404580D3BB78974540B77F65A5499D4A40BAA1293BFD944540B77F65A5499D4A40
48064	Высокое	7	70	999	42.805917999999998	42.838265999999997	53.149383	53.121740000000003	0103000020E61000000100000005000000FDA02E5228674540BA4E232D958F4A40FDA02E522867454008CA6DFB1E934A40A3ACDF4C4C6B454008CA6DFB1E934A40A3ACDF4C4C6B4540BA4E232D958F4A40FDA02E5228674540BA4E232D958F4A40
8564	Башмаково	7	70	999	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
56544	Октябрьский	7	70	7415	43.057293999999999	43.076256999999998	53.069628999999999	53.061042	0103000020E61000000100000005000000E620E868558745405AD76839D0874A40E620E8685587454035ED629AE9884A40A88B14CAC289454035ED629AE9884A40A88B14CAC28945405AD76839D0874A40E620E868558745405AD76839D0874A40
56044	пос. им Куйбышева	7	69	\N	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
19350	Ясный	7	69	\N	59.791218999999998	59.928769000000003	51.045537000000003	51.002949999999998	0103000020E61000000100000005000000A67C08AA46E54D40F8C264AA60804940A67C08AA46E54D4005E10A28D4854940F24410E7E1F64D4005E10A28D4854940F24410E7E1F64D40F8C264AA60804940A67C08AA46E54D40F8C264AA60804940
22512	Южный Урал	7	69	\N	55.023204	55.052174000000001	51.731254	51.725642000000001	0103000020E6100000010000000500000075914259F8824B40514D49D6E1DC494075914259F8824B40DB8827BB99DD4940CBD93BA3AD864B40DB8827BB99DD4940CBD93BA3AD864B40514D49D6E1DC494075914259F8824B40514D49D6E1DC4940
56057	Черноречье	7	69	\N	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
45531	Чапаево	7	69	\N	53.098303000000001	53.115856000000001	53.622520999999999	53.616062999999997	0103000020E61000000100000005000000A20C5531958C4A4048A30227DBCE4A40A20C5531958C4A405F09A4C4AECF4A40CF85915ED48E4A405F09A4C4AECF4A40CF85915ED48E4A4048A30227DBCE4A40A20C5531958C4A4048A30227DBCE4A40
56181	Чапаевкое	7	69	\N	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
56137	Тукай	7	69	\N	58.765953000000003	58.791348999999997	51.161517000000003	51.148812	0103000020E61000000100000005000000F5A276BF0A624D404DA088450C934940F5A276BF0A624D40C05FCC96AC944940745C8DEC4A654D40C05FCC96AC944940745C8DEC4A654D404DA088450C934940F5A276BF0A624D404DA088450C934940
56056	Тере	7	69	\N	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
56058	Степановский	7	69	\N	54.994871000000003	55.015459999999997	51.858699999999999	51.842309999999998	0103000020E61000000100000005000000925ED4EE577F4B40008C67D0D0EB4940925ED4EE577F4B40A089B0E1E9ED4940B532E197FA814B40A089B0E1E9ED4940B532E197FA814B40008C67D0D0EB4940925ED4EE577F4B40008C67D0D0EB4940
56048	Сорочинск	7	69	\N	53.125152999999997	53.187344000000003	52.452894999999998	52.399681999999999	0103000020E6100000010000000500000086FF740305904A4062669FC728334A4086FF740305904A40CEC29E76F8394A40098D60E3FA974A40CEC29E76F8394A40098D60E3FA974A4062669FC728334A4086FF740305904A4062669FC728334A40
56040	Соль-Илецк	7	69	\N	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49250	Соловьевка	7	69	\N	54.943010999999998	54.957734000000002	51.816778999999997	51.804847000000002	0103000020E6100000010000000500000056629E95B4784B4051A4FB3905E7494056629E95B4784B40A087DA368CE8494036221807977A4B40A087DA368CE8494036221807977A4B4051A4FB3905E7494056629E95B4784B4051A4FB3905E74940
56119	Пруды	7	69	\N	55.013294999999999	55.021783999999997	51.666708	51.658987000000003	0103000020E61000000100000005000000A4198BA6B3814B409DBE9EAF59D44940A4198BA6B3814B40A4FD0FB056D54940BCC96FD1C9824B40A4FD0FB056D54940BCC96FD1C9824B409DBE9EAF59D44940A4198BA6B3814B409DBE9EAF59D44940
49163	Приютово	7	69	\N	54.922251000000003	54.937873000000003	51.879286999999998	51.870874000000001	0103000020E6100000010000000500000006DA1D520C764B40E6779ACC78EF494006DA1D520C764B402366F6798CF049409566F3380C784B402366F6798CF049409566F3380C784B40E6779ACC78EF494006DA1D520C764B40E6779ACC78EF4940
49507	Пригородный	7	69	\N	55.259065	55.284630999999997	51.769576000000001	51.754953999999998	0103000020E61000000100000005000000E544BB0A29A14B4000FE2955A2E04940E544BB0A29A14B40ACE4637781E24940C136E2C96EA44B40ACE4637781E24940C136E2C96EA44B4000FE2955A2E04940E544BB0A29A14B4000FE2955A2E04940
19872	Подгородняя Покровка	7	69	\N	54.951948999999999	54.992832	51.851796	51.823928000000002	0103000020E61000000100000005000000DE3AFF76D9794B401D21037976E94940DE3AFF76D9794B408B6EBDA607ED49400D36751E157F4B408B6EBDA607ED49400D36751E157F4B401D21037976E94940DE3AFF76D9794B401D21037976E94940
49245	Плодопитомник	7	69	\N	55.146631999999997	55.171712999999997	51.724169000000003	51.717390000000002	0103000020E6100000010000000500000006465ED6C4924B401D3D7E6FD3DB494006465ED6C4924B4076E3DD91B1DC494026A60BB1FA954B4076E3DD91B1DC494026A60BB1FA954B401D3D7E6FD3DB494006465ED6C4924B401D3D7E6FD3DB4940
24158	Орск	7	69	\N	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
1555	Оренбург	7	69	\N	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
9385	Новотроицк	7	69	\N	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
56164	Нижнее Челяево	7	69	\N	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
4803	Медногорск	7	69	\N	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
49307	Ленина	7	69	\N	55.049092999999999	55.068362	51.878191000000001	51.864255999999997	0103000020E6100000010000000500000034BBEEAD48864B4096AFCBF09FEE494034BBEEAD48864B401E520C9068F0494003250516C0884B401E520C9068F0494003250516C0884B4096AFCBF09FEE494034BBEEAD48864B4096AFCBF09FEE4940
622	Кувандык	7	69	\N	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49471	Девятого Января	7	69	\N	54.962909000000003	54.997036000000001	51.740879999999997	51.728202000000003	0103000020E610000001000000050000001503249A407B4B40DF701FB935DD49401503249A407B4B405721E527D5DE4940A3772AE09E7F4B405721E527D5DE4940A3772AE09E7F4B40DF701FB935DD49401503249A407B4B40DF701FB935DD4940
19668	Гай	7	69	\N	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
19770	Бузулук	7	69	\N	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
16051	Бугуруслан	7	69	\N	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
56183	Бикмурзино	7	69	\N	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
3235	Абдулино	7	69	\N	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
58203	Ясный	7	69	7393	59.791218999999998	59.928769000000003	51.045537000000003	51.002949999999998	0103000020E61000000100000005000000A67C08AA46E54D40F8C264AA60804940A67C08AA46E54D4005E10A28D4854940F24410E7E1F64D4005E10A28D4854940F24410E7E1F64D40F8C264AA60804940A67C08AA46E54D40F8C264AA60804940
58901	Ясный	7	69	1545	59.256343999999999	60.535876999999999	51.351573000000002	50.812868999999999	0103000020E610000001000000050000004E4354E1CFA04D40537765170C6849404E4354E1CFA04D400C94145800AD4940DCD6169E97444E400C94145800AD4940DCD6169E97444E40537765170C6849404E4354E1CFA04D40537765170C684940
19027	Тыкаша	7	69	1545	60.107362999999999	60.134770000000003	51.234037000000001	51.213002000000003	0103000020E6100000010000000500000075E61E12BE0D4E40C6FD47A6439B494075E61E12BE0D4E40E886A6ECF49D4940B03DB32440114E40E886A6ECF49D4940B03DB32440114E40C6FD47A6439B494075E61E12BE0D4E40C6FD47A6439B4940
19090	Ореховка	7	69	1545	60.301048000000002	60.324520999999997	51.265101000000001	51.247051999999996	0103000020E610000001000000050000005B43A9BD88264E40A83462669F9F49405B43A9BD88264E4086915ED4EEA14940BFEE74E789294E4086915ED4EEA14940BFEE74E789294E40A83462669F9F49405B43A9BD88264E40A83462669F9F4940
19136	Новосельский	7	69	1545	60.054721000000001	60.083511999999999	51.077067999999997	51.060341999999999	0103000020E61000000100000005000000C4B3041901074E40A1496249B9874940C4B3041901074E40B8C83D5DDD8949406A696E85B00A4E40B8C83D5DDD8949406A696E85B00A4E40A1496249B9874940C4B3041901074E40A1496249B9874940
18381	Кумак	7	69	1545	60.116740999999998	60.151964	51.175714999999997	51.158760000000001	0103000020E61000000100000005000000198D7C5EF10E4E40DCF4673F52944940198D7C5EF10E4E40543541D47D964940AD156D8E73134E40543541D47D964940AD156D8E73134E40DCF4673F52944940198D7C5EF10E4E40DCF4673F52944940
18846	Котансу	7	69	1545	60.121896999999997	60.142118000000004	50.976410000000001	50.959449999999997	0103000020E61000000100000005000000813D26529A0F4E40D712F241CF7A4940813D26529A0F4E4062BEBC00FB7C4940231631EC30124E4062BEBC00FB7C4940231631EC30124E40D712F241CF7A4940813D26529A0F4E40D712F241CF7A4940
18992	Комарово	7	69	1545	60.067988999999997	60.108485999999999	51.199216999999997	51.180034999999997	0103000020E610000001000000050000006EBE11DDB3084E4053910A630B9749406EBE11DDB3084E4053E751F17F994940740987DEE20D4E4053E751F17F994940740987DEE20D4E4053910A630B9749406EBE11DDB3084E4053910A630B974940
18921	Керуембай	7	69	1545	60.146034999999998	60.164000999999999	50.947177000000003	50.927788	0103000020E6100000010000000500000022895E46B1124E4085CFD6C1C176494022895E46B1124E40FF428F183D79494072C119FCFD144E40FF428F183D79494072C119FCFD144E4085CFD6C1C176494022895E46B1124E4085CFD6C1C1764940
18748	Еленовка	7	69	1545	59.769326999999997	59.802349	50.905771999999999	50.888216999999997	0103000020E610000001000000050000000377A04E79E24D4028603B18B17149400377A04E79E24D40F6D03E56F0734940397D3D5FB3E64D40F6D03E56F0734940397D3D5FB3E64D4028603B18B17149400377A04E79E24D4028603B18B1714940
18670	Веселовский	7	69	1545	60.376641999999997	60.402828	50.970874999999999	50.961385	0103000020E61000000100000005000000672618CE35304E40B7EEE6A90E7B4940672618CE35304E4083C0CAA1457C4940E0F42EDE8F334E4083C0CAA1457C4940E0F42EDE8F334E40B7EEE6A90E7B4940672618CE35304E40B7EEE6A90E7B4940
18815	Верхний Киембай	7	69	1545	59.864072	59.901819000000003	50.909032000000003	50.899887	0103000020E61000000100000005000000D5B14AE999EE4D403B8C497F2F734940D5B14AE999EE4D403D821B295B744940AAF413CE6EF34D403D821B295B744940AAF413CE6EF34D403B8C497F2F734940D5B14AE999EE4D403B8C497F2F734940
18445	Акжарское	7	69	1545	59.381587000000003	59.430391999999998	51.110714000000002	51.092377999999997	0103000020E6100000010000000500000015CAC2D7D7B04D40586FD40AD38B494015CAC2D7D7B04D40CC9A58E02B8E4940E23AC61517B74D40CC9A58E02B8E4940E23AC61517B74D40586FD40AD38B494015CAC2D7D7B04D40586FD40AD38B4940
16686	Ялчкаево	7	69	1324	54.915827999999998	54.934899000000001	52.983367999999999	52.972951999999999	0103000020E610000001000000050000006B6116DA39754B40F549EEB0897C4A406B6116DA39754B406AF7AB00DF7D4A4014083BC5AA774B406AF7AB00DF7D4A4014083BC5AA774B40F549EEB0897C4A406B6116DA39754B40F549EEB0897C4A40
16904	Юзеево	7	69	1324	55.034180999999997	55.048734000000003	52.585430000000002	52.578097999999997	0103000020E610000001000000050000008192020B60844B4006F1811DFF494A408192020B60844B40740CC85EEF4A4A40051A6CEA3C864B40740CC85EEF4A4A40051A6CEA3C864B4006F1811DFF494A408192020B60844B4006F1811DFF494A40
18115	Шарлык	7	69	1324	54.716805999999998	54.779859000000002	52.940148000000001	52.904386000000002	0103000020E61000000100000005000000CDC98B4CC05B4B40EA7AA2EBC2734A40CDC98B4CC05B4B402DB308C556784A40E23E726BD2634B402DB308C556784A40E23E726BD2634B40EA7AA2EBC2734A40CDC98B4CC05B4B40EA7AA2EBC2734A40
46827	Урняк	7	69	1324	54.452558000000003	54.470981999999999	52.902887	52.895695000000003	0103000020E6100000010000000500000087C5A86BED394B406A183E22A6724A4087C5A86BED394B40E57D1CCD91734A4099805F23493C4B40E57D1CCD91734A4099805F23493C4B406A183E22A6724A4087C5A86BED394B406A183E22A6724A40
47179	Титовка	7	69	1324	54.695695999999998	54.711461	52.798653000000002	52.782837999999998	0103000020E61000000100000005000000A0FA07910C594B4074081C0934644A40A0FA07910C594B4018EDF1423A664A4092B06F27115B4B4018EDF1423A664A4092B06F27115B4B4074081C0934644A40A0FA07910C594B4074081C0934644A40
17852	Слоновка	7	69	1324	55.288556999999997	55.323663000000003	52.809714999999997	52.792467000000002	0103000020E6100000010000000500000014048F6FEFA44B406214048F6F654A4014048F6FEFA44B40520ABABDA4674A406FF607CA6DA94B40520ABABDA4674A406FF607CA6DA94B406214048F6F654A4014048F6FEFA44B406214048F6F654A40
17708	Сарманай	7	69	1324	54.605046999999999	54.652208000000002	53.096668000000001	53.085186999999998	0103000020E610000001000000050000007EC51A2E724D4B40AD855968E78A4A407EC51A2E724D4B40ED48F59D5F8C4A4044183F8D7B534B40ED48F59D5F8C4A4044183F8D7B534B40AD855968E78A4A407EC51A2E724D4B40AD855968E78A4A40
56150	Романовка	7	69	1324	55.180418000000003	55.220581000000003	52.687933999999998	52.671495	0103000020E610000001000000050000000CCEE0EF17974B40B936548CF3554A400CCEE0EF17974B403AE7A7380E584A403B8F8AFF3B9C4B403AE7A7380E584A403B8F8AFF3B9C4B40B936548CF3554A400CCEE0EF17974B40B936548CF3554A40
46312	Рождественка	7	69	1324	54.582023	54.612592999999997	52.858111999999998	52.837466999999997	0103000020E610000001000000050000008942CBBA7F4A4B40573D601E326B4A408942CBBA7F4A4B400F27309DD66D4A4017618A72694E4B400F27309DD66D4A4017618A72694E4B40573D601E326B4A408942CBBA7F4A4B40573D601E326B4A40
17611	Ратчино	7	69	1324	54.440969000000003	54.489586000000003	53.076230000000002	53.033839999999998	0103000020E6100000010000000500000061C614AC71384B40F8A57EDE54844A4061C614AC71384B40AF7C96E7C1894A402C4A09C1AA3E4B40AF7C96E7C1894A402C4A09C1AA3E4B40F8A57EDE54844A4061C614AC71384B40F8A57EDE54844A40
46949	Путятино	7	69	1324	54.761676999999999	54.800277999999999	53.148541000000002	53.130617999999998	0103000020E61000000100000005000000C58EC6A17E614B406C223317B8904A40C58EC6A17E614B40BD8E386403934A40A9DA6E826F664B40BD8E386403934A40A9DA6E826F664B406C223317B8904A40C58EC6A17E614B406C223317B8904A40
32504	Приветливый	7	69	1324	54.732688000000003	54.751139999999999	52.897953999999999	52.889690999999999	0103000020E61000000100000005000000F9156BB8C85D4B40D4450A65E1714A40F9156BB8C85D4B40FCA71B28F0724A40D55B035B25604B40FCA71B28F0724A40D55B035B25604B40D4450A65E1714A40F9156BB8C85D4B40D4450A65E1714A40
14080	Преображенка	7	69	1324	54.977936999999997	55.030174000000002	52.897460000000002	52.876432000000001	0103000020E610000001000000050000003046240A2D7D4B407D957CEC2E704A403046240A2D7D4B40EDBB22F8DF724A404298DBBDDC834B40EDBB22F8DF724A404298DBBDDC834B407D957CEC2E704A403046240A2D7D4B407D957CEC2E704A40
58162	Покровка	7	69	1324	55.266171	55.292788000000002	52.785752000000002	52.764915000000002	0103000020E6100000010000000500000062122EE411A24B40249C16BCE8614A4062122EE411A24B402062838593644A40A454C2137AA54B402062838593644A40A454C2137AA54B40249C16BCE8614A4062122EE411A24B40249C16BCE8614A40
47094	Перовка	7	69	1324	54.677737999999998	54.702055999999999	53.022775000000003	53.015932999999997	0103000020E61000000100000005000000D3A0681EC0564B40ADF6B0170A824A40D3A0681EC0564B404D158C4AEA824A40F4FA93F8DC594B404D158C4AEA824A40F4FA93F8DC594B40ADF6B0170A824A40D3A0681EC0564B40ADF6B0170A824A40
46863	Парадеево	7	69	1324	55.107897000000001	55.151716999999998	52.797781999999998	52.779156	0103000020E61000000100000005000000132BA391CF8D4B40B83D4162BB634A40132BA391CF8D4B4032AB77B81D664A40A59F70766B934B4032AB77B81D664A40A59F70766B934B40B83D4162BB634A40132BA391CF8D4B40B83D4162BB634A40
16963	Новоникольское	7	69	1324	54.806843999999998	54.832903999999999	52.756348000000003	52.741287	0103000020E61000000100000005000000A67C08AA46674B4098F90E7EE25E4A40A67C08AA46674B409032E202D0604A40925A28999C6A4B409032E202D0604A40925A28999C6A4B4098F90E7EE25E4A40A67C08AA46674B4098F90E7EE25E4A40
16983	Новомусино	7	69	1324	54.405540000000002	54.434403000000003	52.934275999999997	52.911658000000003	0103000020E61000000100000005000000249C16BCE8334B4082919735B1744A40249C16BCE8334B4006B8205B96774A4064247B849A374B4006B8205B96774A4064247B849A374B4082919735B1744A40249C16BCE8334B4082919735B1744A40
56205	Новоархангеловка	7	69	1324	54.851365000000001	54.885626999999999	52.926746999999999	52.904522	0103000020E61000000100000005000000C2FA3F87F96C4B409A417C60C7734A40C2FA3F87F96C4B4043554CA59F764A4030BABC395C714B4043554CA59F764A4030BABC395C714B409A417C60C7734A40C2FA3F87F96C4B409A417C60C7734A40
47216	Мустафино	7	69	1324	54.775402999999997	54.787278999999998	52.841259000000001	52.828153	0103000020E61000000100000005000000321CCF6740634B40CA8AE1EA006A4A40321CCF6740634B409B3BFA5FAE6B4A40EEE9EA8EC5644B409B3BFA5FAE6B4A40EEE9EA8EC5644B40CA8AE1EA006A4A40321CCF6740634B40CA8AE1EA006A4A40
56200	Малослободка	7	69	1324	54.759359000000003	54.773345999999997	53.044901000000003	53.033580000000001	0103000020E610000001000000050000002E76FBAC32614B405CE674594C844A402E76FBAC32614B406347E350BF854A40073F7100FD624B406347E350BF854A40073F7100FD624B405CE674594C844A402E76FBAC32614B405CE674594C844A40
46645	Константиновка	7	69	1324	54.955452999999999	54.995769000000003	52.964176999999999	52.945715999999997	0103000020E61000000100000005000000BBEEAD484C7A4B40E7A6CD380D794A40BBEEAD484C7A4B401747E5266A7B4A4071AFCC5B757F4B401747E5266A7B4A4071AFCC5B757F4B40E7A6CD380D794A40BBEEAD484C7A4B40E7A6CD380D794A40
16596	Колычево	7	69	1324	54.857545000000002	54.881996999999998	52.718508	52.695483000000003	0103000020E6100000010000000500000096ECD808C46D4B4045F6419605594A4096ECD808C46D4B400AF5F411F85B4A40C6151747E5704B400AF5F411F85B4A40C6151747E5704B4045F6419605594A4096ECD808C46D4B4045F6419605594A40
18348	Кармалка	7	69	1324	54.665844999999997	54.723804000000001	52.978949	52.953902999999997	0103000020E61000000100000005000000419AB1683A554B403447567E197A4A40419AB1683A554B40D8B969334E7D4A40645B069CA55C4B40D8B969334E7D4A40645B069CA55C4B403447567E197A4A40419AB1683A554B403447567E197A4A40
16761	Илькульган	7	69	1324	54.543152999999997	54.573174999999999	52.896769999999997	52.865164	0103000020E61000000100000005000000B5DC990986454B4099D6A6B1BD6E4A40B5DC990986454B405704FF5BC9724A4041F163CC5D494B405704FF5BC9724A4041F163CC5D494B4099D6A6B1BD6E4A40B5DC990986454B4099D6A6B1BD6E4A40
56120	Изяк-Никитино	7	69	1324	54.879662000000003	54.896163999999999	53.213341999999997	53.202739000000001	0103000020E6100000010000000500000059C4B0C398704B40D74FFF59F3994A4059C4B0C398704B407E6E68CA4E9B4A4020ED7F80B5724B407E6E68CA4E9B4A4020ED7F80B5724B40D74FFF59F3994A4059C4B0C398704B40D74FFF59F3994A40
47019	Зобово	7	69	1324	54.652568000000002	54.688222000000003	53.222217000000001	53.203921000000001	0103000020E610000001000000050000004435255987534B40DBFB54151A9A4A404435255987534B40C0CE4D9B719C4A40A13193A817584B40C0CE4D9B719C4A40A13193A817584B40DBFB54151A9A4A404435255987534B40DBFB54151A9A4A40
16521	Зеркло	7	69	1324	54.903216	54.937027999999998	52.681852999999997	52.661943000000001	0103000020E61000000100000005000000AA9CF6949C734B407768588CBA544A40AA9CF6949C734B40F9D687F546574A40D8B79388F0774B40F9D687F546574A40D8B79388F0774B407768588CBA544A40AA9CF6949C734B407768588CBA544A40
46582	Дубровка	7	69	1324	54.542102	54.548965000000003	53.113444000000001	53.104999999999997	0103000020E61000000100000005000000508C2C9963454B403D0AD7A3708D4A40508C2C9963454B40B6F63E55858E4A4007D3307C44464B40B6F63E55858E4A4007D3307C44464B403D0AD7A3708D4A40508C2C9963454B403D0AD7A3708D4A40
46945	Вишневка	7	69	1324	54.956494999999997	54.967212000000004	52.850634999999997	52.842911999999998	0103000020E61000000100000005000000CDE49B6D6E7A4B40F6B3588AE46B4A40CDE49B6D6E7A4B409EEA909BE16C4A403E26529ACD7B4B409EEA909BE16C4A403E26529ACD7B4B40F6B3588AE46B4A40CDE49B6D6E7A4B40F6B3588AE46B4A40
46547	Богородское	7	69	1324	55.049506000000001	55.064140000000002	52.733223000000002	52.684713000000002	0103000020E61000000100000005000000577A6D3656864B40B212F3ACA4574A40577A6D3656864B4067D65240DA5D4A40C72E51BD35884B4067D65240DA5D4A40C72E51BD35884B40B212F3ACA4574A40577A6D3656864B40B212F3ACA4574A40
17996	Бараково	7	69	1324	54.649890999999997	54.672187000000001	52.841123000000003	52.822814999999999	0103000020E610000001000000050000007C7BD7A02F534B4041D47D0052694A407C7BD7A02F534B40EB7420EBA96B4A40EFE53E390A564B40EB7420EBA96B4A40EFE53E390A564B4041D47D0052694A407C7BD7A02F534B4041D47D0052694A40
14996	Тюльган	7	69	748	56.135649999999998	56.178823000000001	52.357092999999999	52.333661999999997	0103000020E61000000100000005000000E8D9ACFA5C114C407FF5B86FB52A4A40E8D9ACFA5C114C40B5503239B52D4A40E5620CACE3164C40B5503239B52D4A40E5620CACE3164C407FF5B86FB52A4A40E8D9ACFA5C114C407FF5B86FB52A4A40
15525	Тугустемир	7	69	748	56.072831000000001	56.105601999999998	52.562207999999998	52.549028999999997	0103000020E610000001000000050000004791B58652094C401DC70F9546464A404791B58652094C4058C6866EF6474A403332C85D840D4C4058C6866EF6474A403332C85D840D4C401DC70F9546464A404791B58652094C401DC70F9546464A40
45989	Троицкое	7	69	748	56.368817	56.404299999999999	52.337997999999999	52.310707999999998	0103000020E61000000100000005000000BB9A3C65352F4C40834D9D47C5274A40BB9A3C65352F4C40840EBA84432B4A40EBE2361AC0334C40840EBA84432B4A40EBE2361AC0334C40834D9D47C5274A40BB9A3C65352F4C40834D9D47C5274A40
12374	Ташла	7	69	748	56.210380999999998	56.260103000000001	52.423743000000002	52.394770000000001	0103000020E610000001000000050000009259BDC3ED1A4C4091B8C7D287324A409259BDC3ED1A4C405874EB353D364A40B64B1B0E4B214C405874EB353D364A40B64B1B0E4B214C4091B8C7D287324A409259BDC3ED1A4C4091B8C7D287324A40
46347	Стретинка	7	69	748	55.990824000000003	56.002240999999998	52.322814000000001	52.313450000000003	0103000020E61000000100000005000000C40B2252D3FE4B4032772D211F284A40C40B2252D3FE4B4071581AF851294A40ECDADE6E49004C4071581AF851294A40ECDADE6E49004C4032772D211F284A40C40B2252D3FE4B4032772D211F284A40
15313	Рудное	7	69	748	56.343367999999998	56.361514	52.373376	52.355597000000003	0103000020E61000000100000005000000183F8D7BF32B4C4022C7D633842D4A40183F8D7BF32B4C403F8EE6C8CA2F4A40E8853B17462E4C403F8EE6C8CA2F4A40E8853B17462E4C4022C7D633842D4A40183F8D7BF32B4C4022C7D633842D4A40
15928	Репьевка	7	69	748	56.223550000000003	56.246116000000001	52.288342999999998	52.275478	0103000020E61000000100000005000000AA8251499D1C4C403D62F4DC42234A40AA8251499D1C4C40E883656CE8244A40DC82A5BA801F4C40E883656CE8244A40DC82A5BA801F4C403D62F4DC42234A40AA8251499D1C4C403D62F4DC42234A40
46187	Разномойка	7	69	748	55.858601	55.891308000000002	52.490170999999997	52.477227999999997	0103000020E610000001000000050000000DA837A3E6ED4B40245E9ECE153D4A400DA837A3E6ED4B404B395FECBD3E4A40E3546B6116F24B404B395FECBD3E4A40E3546B6116F24B40245E9ECE153D4A400DA837A3E6ED4B40245E9ECE153D4A40
46124	Подлесный	7	69	748	56.175382999999997	56.184069000000001	52.376818	52.367646999999998	0103000020E610000001000000050000001EA33CF372164C407BBC900E0F2F4A401EA33CF372164C40A6457D923B304A408D9AAF928F174C40A6457D923B304A408D9AAF928F174C407BBC900E0F2F4A401EA33CF372164C407BBC900E0F2F4A40
15479	Новосергиевка	7	69	748	56.060451999999998	56.07443	52.454453000000001	52.442625	0103000020E61000000100000005000000287D21E4BC074C402DB29DEFA7384A40287D21E4BC074C40D84812842B3A4A40AFEB17EC86094C40D84812842B3A4A40AFEB17EC86094C402DB29DEFA7384A40287D21E4BC074C402DB29DEFA7384A40
14415	Нововасильевка	7	69	748	56.094301000000002	56.130889000000003	52.361466	52.350327999999998	0103000020E61000000100000005000000747D1F0E120C4C40C16F438CD72C4A40747D1F0E120C4C40D74E9484442E4A40FD3383F8C0104C40D74E9484442E4A40FD3383F8C0104C40C16F438CD72C4A40747D1F0E120C4C40C16F438CD72C4A40
62031	Николаевка	7	69	748	56.409968999999997	56.427000999999997	52.421441999999999	52.393988999999998	0103000020E61000000100000005000000D9AF3BDD79344C40EBFD463B6E324A40D9AF3BDD79344C409694BBCFF1354A40FD2D01F8A7364C409694BBCFF1354A40FD2D01F8A7364C40EBFD463B6E324A40D9AF3BDD79344C40EBFD463B6E324A40
62041	Козловка	7	69	748	56.188085000000001	56.202646999999999	52.297415000000001	52.283555	0103000020E6100000010000000500000020EF552B13184C4003CFBD874B244A4020EF552B13184C40802BD9B111264A40F6D03E56F0194C40802BD9B111264A40F6D03E56F0194C4003CFBD874B244A4020EF552B13184C4003CFBD874B244A40
46391	Ключи	7	69	748	56.087887000000002	56.120477999999999	52.184767000000001	52.162354000000001	0103000020E610000001000000050000002D5F97E13F0B4C40F92F1004C8144A402D5F97E13F0B4C40A530EF71A6174A4099F1B6D26B0F4C40A530EF71A6174A4099F1B6D26B0F4C40F92F1004C8144A402D5F97E13F0B4C40F92F1004C8144A40
62036	Калининский	7	69	748	56.012490999999997	56.027520000000003	52.507227	52.492902000000001	0103000020E61000000100000005000000463F1A4E99014C400611A969173F4A40463F1A4E99014C40F85278D0EC404A4033FE7DC685034C40F85278D0EC404A4033FE7DC685034C400611A969173F4A40463F1A4E99014C400611A969173F4A40
62033	Ивановка	7	69	748	56.283738	56.327423000000003	52.329292000000002	52.316665	0103000020E61000000100000005000000F450DB8651244C40D8648D7A88284A40F450DB8651244C40CF6A813D262A4A40A77A32FFE8294C40CF6A813D262A4A40A77A32FFE8294C40D8648D7A88284A40F450DB8651244C40D8648D7A88284A40
46290	Екатеринославка	7	69	748	56.029226999999999	56.058638000000002	52.290508000000003	52.274149999999999	0103000020E610000001000000050000008194D8B5BD034C406519E25817234A408194D8B5BD034C40FA9CBB5D2F254A40C426327381074C40FA9CBB5D2F254A40C426327381074C406519E25817234A408194D8B5BD034C406519E25817234A40
46435	Екатериновка	7	69	748	55.752851	55.778345000000002	52.222541	52.207284000000001	0103000020E6100000010000000500000065E1EB6B5DE04B40F67D3848881A4A4065E1EB6B5DE04B40738236397C1C4A40A80018CFA0E34B40738236397C1C4A40A80018CFA0E34B40F67D3848881A4A4065E1EB6B5DE04B40F67D3848881A4A40
15703	Давлеткулово	7	69	748	56.027188000000002	56.046438999999999	52.383144999999999	52.365941999999997	0103000020E61000000100000005000000FD6B79E57A034C40CD1DFD2FD72E4A40FD6B79E57A034C401E5036E50A314A40252191B6F1054C401E5036E50A314A40252191B6F1054C40CD1DFD2FD72E4A40FD6B79E57A034C40CD1DFD2FD72E4A40
15425	Городки	7	69	748	56.123441999999997	56.150525999999999	52.473574999999997	52.458672999999997	0103000020E61000000100000005000000F6798CF2CC0F4C407347FFCBB53A4A40F6798CF2CC0F4C40029A081B9E3C4A404E999B6F44134C40029A081B9E3C4A404E999B6F44134C407347FFCBB53A4A40F6798CF2CC0F4C407347FFCBB53A4A40
46206	Владимировка	7	69	748	55.994928999999999	56.027295000000002	52.357593999999999	52.348517999999999	0103000020E61000000100000005000000C66B5ED559FF4B409E08E23C9C2C4A40C66B5ED559FF4B40779FE3A3C52D4A40132C0E677E034C40779FE3A3C52D4A40132C0E677E034C409E08E23C9C2C4A40C66B5ED559FF4B409E08E23C9C2C4A40
16076	Благодарное	7	69	748	55.807099999999998	55.837356	52.213254999999997	52.201372999999997	0103000020E61000000100000005000000014D840D4FE74B4011A62897C6194A40014D840D4FE74B40AF5A99F04B1B4A40008E3D7B2EEB4B40AF5A99F04B1B4A40008E3D7B2EEB4B4011A62897C6194A40014D840D4FE74B4011A62897C6194A40
46485	Благовещенка	7	69	748	55.951090999999998	55.973064000000001	52.198762000000002	52.185662000000001	0103000020E610000001000000050000008D429259BDF94B40130EBDC5C3174A408D429259BDF94B4002D8800871194A401D75745C8DFC4B4002D8800871194A401D75745C8DFC4B40130EBDC5C3174A408D429259BDF94B40130EBDC5C3174A40
15836	Аустяново	7	69	748	56.099116000000002	56.117046000000002	52.303440000000002	52.294198000000002	0103000020E61000000100000005000000534145D5AF0C4C403946B247A8254A40534145D5AF0C4C402D26361FD7264A405610035DFB0E4C402D26361FD7264A405610035DFB0E4C403946B247A8254A40534145D5AF0C4C403946B247A8254A40
16198	Астрахановка	7	69	748	55.689312999999999	55.721795999999998	52.202356000000002	52.192661999999999	0103000020E6100000010000000500000094DA8B683BD84B404A97FE25A9184A4094DA8B683BD84B401F1329CDE6194A401A31B3CF63DC4B401F1329CDE6194A401A31B3CF63DC4B404A97FE25A9184A4094DA8B683BD84B404A97FE25A9184A40
15134	Алмала	7	69	748	56.344805000000001	56.374583999999999	52.555599999999998	52.544490000000003	0103000020E61000000100000005000000A73FFB91222C4C40E17F2BD9B1454A40A73FFB91222C4C402CD49AE61D474A406CCD565EF22F4C402CD49AE61D474A406CCD565EF22F4C40E17F2BD9B1454A40A73FFB91222C4C40E17F2BD9B1454A40
46250	Алабердино	7	69	748	55.937635	55.956004999999998	52.365611999999999	52.354788999999997	0103000020E61000000100000005000000E04A766C04F84B4082FDD7B9692D4A40E04A766C04F84B403883BF5FCC2E4A40FFE7305F5EFA4B403883BF5FCC2E4A40FFE7305F5EFA4B4082FDD7B9692D4A40E04A766C04F84B4082FDD7B9692D4A40
46763	Аксаково	7	69	748	55.966712999999999	55.990428999999999	52.205131999999999	52.199959999999997	0103000020E610000001000000050000001CCF6740BDFB4B400B410E4A98194A401CCF6740BDFB4B4079AEEFC3411A4A404701A260C6FE4B4079AEEFC3411A4A404701A260C6FE4B400B410E4A98194A401CCF6740BDFB4B400B410E4A98194A40
13158	Тоцкое Второе	7	69	1258	52.797888	52.865611999999999	52.558601000000003	52.534317999999999	0103000020E6100000010000000500000078EFA83121664A4002D53F8864444A4078EFA83121664A40A741D13C80474A403883BF5FCC6E4A40A741D13C80474A403883BF5FCC6E4A4002D53F8864444A4078EFA83121664A4002D53F8864444A40
13014	Тоцкое	7	69	1258	52.709242000000003	52.795183999999999	52.537084	52.509248999999997	0103000020E610000001000000050000008E791D71C85A4A40A6423C122F414A408E791D71C85A4A40399A232BBF444A40B726DD96C8654A40399A232BBF444A40B726DD96C8654A40A6423C122F414A408E791D71C85A4A40A6423C122F414A40
14497	Суворовский	7	69	1258	52.385435000000001	52.409528000000002	52.434835	52.425488999999999	0103000020E61000000100000005000000ECDD1FEF55314A4064E76D6C76364A40ECDD1FEF55314A40FD135CACA8374A40ED65DB696B344A40FD135CACA8374A40ED65DB696B344A4064E76D6C76364A40ECDD1FEF55314A4064E76D6C76364A40
45617	Свердлово	7	69	1258	52.288687000000003	52.301569000000001	52.165967000000002	52.158244000000003	0103000020E61000000100000005000000E3E313B2F3244A40E564E25641144A40E3E313B2F3244A408D9B1A683E154A40643E20D099264A408D9B1A683E154A40643E20D099264A40E564E25641144A40E3E313B2F3244A40E564E25641144A40
13714	Сайфутдиново	7	69	1258	52.580559000000001	52.589334999999998	52.242161000000003	52.230474000000001	0103000020E610000001000000050000000133DFC14F4A4A40064A0A2C801D4A400133DFC14F4A4A40EFAEB321FF1E4A40AFB14B546F4B4A40EFAEB321FF1E4A40AFB14B546F4B4A40064A0A2C801D4A400133DFC14F4A4A40064A0A2C801D4A40
14193	Саиновка	7	69	1258	52.443708999999998	52.458602999999997	52.158088999999997	52.149464000000002	0103000020E610000001000000050000006EF8DD74CB384A40F5F6E7A221134A406EF8DD74CB384A40BD6DA6423C144A407A6CCB80B33A4A40BD6DA6423C144A407A6CCB80B33A4A40F5F6E7A221134A406EF8DD74CB384A40F5F6E7A221134A40
13893	Рябинный	7	69	1258	52.750034999999997	52.769582	52.092525000000002	52.082071999999997	0103000020E610000001000000050000007CED992501604A406AF5D555810A4A407CED992501604A40FD87F4DBD70B4A408ECBB8A981624A40FD87F4DBD70B4A408ECBB8A981624A406AF5D555810A4A407CED992501604A406AF5D555810A4A40
56189	Приютное	7	69	1258	52.628743999999998	52.641616999999997	52.315955000000002	52.296368000000001	0103000020E6100000010000000500000032C7F2AE7A504A405CCAF962EF254A4032C7F2AE7A504A40FC00A43671284A4060C77F8120524A40FC00A43671284A4060C77F8120524A405CCAF962EF254A4032C7F2AE7A504A405CCAF962EF254A40
49542	Пристанционный	7	69	1258	52.777450999999999	52.830865000000003	52.511178999999998	52.501201999999999	0103000020E610000001000000050000000A9FAD8383634A404B581B6327404A400A9FAD8383634A4074B33F506E414A400E32C9C8596A4A4074B33F506E414A400E32C9C8596A4A404B581B6327404A400A9FAD8383634A404B581B6327404A40
14813	Погромное	7	69	1258	52.483764999999998	52.530486000000003	52.620817000000002	52.589188999999998	0103000020E6100000010000000500000087F9F202EC3D4A40DB148F8B6A4B4A4087F9F202EC3D4A4082E673EE764F4A40317E1AF7E6434A4082E673EE764F4A40317E1AF7E6434A40DB148F8B6A4B4A4087F9F202EC3D4A40DB148F8B6A4B4A40
49454	Первое Мая	7	69	1258	52.615090000000002	52.627181	52.573337000000002	52.567031	0103000020E610000001000000050000005F0CE544BB4E4A40BA68C87894484A405F0CE544BB4E4A401B4B581B63494A4017D68D7747504A401B4B581B63494A4017D68D7747504A40BA68C87894484A405F0CE544BB4E4A40BA68C87894484A40
56185	Павло-Антоновка	7	69	1258	52.697187	52.716670999999998	52.424588999999997	52.397001000000003	0103000020E610000001000000050000002219726C3D594A405ABDC3EDD0324A402219726C3D594A40E49EAEEE58364A40ED7E15E0BB5B4A40E49EAEEE58364A40ED7E15E0BB5B4A405ABDC3EDD0324A402219726C3D594A405ABDC3EDD0324A40
45684	Нововасильевка	7	69	1258	52.178077000000002	52.190635999999998	52.106959000000003	52.094185000000003	0103000020E61000000100000005000000BC95253ACB164A400B630B410E0C4A40BC95253ACB164A40A6811FD5B00D4A405AB8ACC266184A40A6811FD5B00D4A405AB8ACC266184A400B630B410E0C4A40BC95253ACB164A400B630B410E0C4A40
46022	Николаевка	7	69	1258	52.543889	52.554687000000001	52.138852999999997	52.130611000000002	0103000020E61000000100000005000000BBD39D279E454A40BABF7ADCB7104A40BBD39D279E454A40CAF962EFC5114A401842CEFBFF464A40CAF962EFC5114A401842CEFBFF464A40BABF7ADCB7104A40BBD39D279E454A40BABF7ADCB7104A40
13524	Невежкино	7	69	1258	52.776274000000001	52.790683000000001	52.330249999999999	52.315503	0103000020E61000000100000005000000185E49F25C634A401B65FD6662284A40185E49F25C634A4083C0CAA1452A4A406840BD1935654A4083C0CAA1452A4A406840BD1935654A401B65FD6662284A40185E49F25C634A401B65FD6662284A40
45639	Набережный	7	69	1258	52.255395	52.275868000000003	52.161929000000001	52.154398999999998	0103000020E61000000100000005000000ED478AC8B0204A407EC4AF58C3134A40ED478AC8B0204A4012A3E716BA144A40A80183A44F234A4012A3E716BA144A40A80183A44F234A407EC4AF58C3134A40ED478AC8B0204A407EC4AF58C3134A40
13977	Мулюково	7	69	1258	52.725878999999999	52.738725000000002	52.104436999999997	52.095435999999999	0103000020E6100000010000000500000035ED629AE95C4A40376E313F370C4A4035ED629AE95C4A4005BF0D315E0D4A406ADE718A8E5E4A4005BF0D315E0D4A406ADE718A8E5E4A40376E313F370C4A4035ED629AE95C4A40376E313F370C4A40
45361	Марковка	7	69	1258	52.654975	52.674100000000003	52.357258000000002	52.345222	0103000020E610000001000000050000004B598638D6534A400BEE073C302C4A404B598638D6534A40001E51A1BA2D4A40E71DA7E848564A40001E51A1BA2D4A40E71DA7E848564A400BEE073C302C4A404B598638D6534A400BEE073C302C4A40
14205	Мананниково	7	69	1258	52.437987	52.452064	52.265244000000003	52.249561	0103000020E610000001000000050000005D8940F50F384A40B4AD669DF11F4A405D8940F50F384A40E9BAF083F3214A4077D9AF3BDD394A40E9BAF083F3214A4077D9AF3BDD394A40B4AD669DF11F4A405D8940F50F384A40B4AD669DF11F4A40
13951	Малая Ремизенка	7	69	1258	52.751921000000003	52.770301000000003	52.168182000000002	52.154508999999997	0103000020E610000001000000050000007B1684F23E604A4005F86EF3C6134A407B1684F23E604A4050E3DEFC86154A40BE89213999624A4050E3DEFC86154A40BE89213999624A4005F86EF3C6134A407B1684F23E604A4005F86EF3C6134A40
14356	Любимовка	7	69	1258	52.35624	52.384627000000002	52.165922999999999	52.156255000000002	0103000020E6100000010000000500000076C3B645992D4A40126BF12900144A4076C3B645992D4A40BD5301F73C154A404D1421753B314A40BD5301F73C154A404D1421753B314A40126BF12900144A4076C3B645992D4A40126BF12900144A40
14656	Логачевка	7	69	1258	52.317729	52.347957999999998	52.383195000000001	52.363428999999996	0103000020E61000000100000005000000D2FE0758AB284A4080B56AD7842E4A40D2FE0758AB284A40D07EA4880C314A40D73043E3892C4A40D07EA4880C314A40D73043E3892C4A4080B56AD7842E4A40D2FE0758AB284A4080B56AD7842E4A40
14474	Кызыл-Мечеть	7	69	1258	52.300356000000001	52.312932000000004	52.177069000000003	52.167259999999999	0103000020E610000001000000050000002594BE1072264A40E8F692C668154A402594BE1072264A4056116E32AA164A409AEFE0270E284A4056116E32AA164A409AEFE0270E284A40E8F692C668154A402594BE1072264A40E8F692C668154A40
13808	Ковыляевка	7	69	1258	52.713580999999998	52.733524000000003	52.225416000000003	52.210501999999998	0103000020E610000001000000050000000306499F565B4A400DDFC2BAF11A4A400306499F565B4A4061FF756EDA1C4A40626A4B1DE45D4A4061FF756EDA1C4A40626A4B1DE45D4A400DDFC2BAF11A4A400306499F565B4A400DDFC2BAF11A4A40
56117	Казанка	7	69	1258	52.447535999999999	52.466211999999999	52.405006	52.386206999999999	0103000020E610000001000000050000002EE411DC48394A403E3E213B6F314A402EE411DC48394A408657923CD7334A405A80B6D5AC3B4A408657923CD7334A405A80B6D5AC3B4A403E3E213B6F314A402EE411DC48394A403E3E213B6F314A40
14715	Злобинка	7	69	1258	52.390214	52.405064000000003	52.456938999999998	52.444695000000003	0103000020E610000001000000050000007E384888F2314A40EDD808C4EB384A407E384888F2314A402BA226FA7C3A4A40BB641C23D9334A402BA226FA7C3A4A40BB641C23D9334A40EDD808C4EB384A407E384888F2314A40EDD808C4EB384A40
14132	Задорожный	7	69	1258	52.450186000000002	52.472949	52.114697	52.103606999999997	0103000020E61000000100000005000000FC8EE1B19F394A407E5182FE420D4A40FC8EE1B19F394A4083F92B64AE0E4A4084D6C397893C4A4083F92B64AE0E4A4084D6C397893C4A407E5182FE420D4A40FC8EE1B19F394A407E5182FE420D4A40
14869	Жидиловка	7	69	1258	52.454714000000003	52.472689000000003	52.532412000000001	52.521628999999997	0103000020E6100000010000000500000045847F11343A4A4095D233BDC4424A4045847F11343A4A40BDFF8F1326444A40E816BA12813C4A40BDFF8F1326444A40E816BA12813C4A4095D233BDC4424A4045847F11343A4A4095D233BDC4424A40
45717	Дружный	7	69	1258	52.363517000000002	52.378456	52.284860999999999	52.276674	0103000020E6100000010000000500000020459DB9872E4A40A6D3BA0D6A234A4020459DB9872E4A40F373435376244A40CC7C073F71304A40F373435376244A40CC7C073F71304A40A6D3BA0D6A234A4020459DB9872E4A40A6D3BA0D6A234A40
13853	Верхнебузулукский	7	69	1258	52.646261000000003	52.661155000000001	52.115088999999998	52.107435000000002	0103000020E6100000010000000500000013D731AEB8524A400FB9196EC00D4A4013D731AEB8524A408E90813CBB0E4A401F4B1FBAA0544A408E90813CBB0E4A401F4B1FBAA0544A400FB9196EC00D4A4013D731AEB8524A400FB9196EC00D4A40
14045	Большая Ремизенка	7	69	1258	52.667254999999997	52.686506000000001	52.108269999999997	52.102361999999999	0103000020E61000000100000005000000D68BA19C68554A40342DB1321A0D4A40D68BA19C68554A40A79196CADB0D4A40FF40B96DDF574A40A79196CADB0D4A40FF40B96DDF574A40342DB1321A0D4A40D68BA19C68554A40342DB1321A0D4A40
45368	Богдановка	7	69	1258	52.605854999999998	52.638024000000001	52.200947999999997	52.167541999999997	0103000020E610000001000000050000001D8F19A88C4D4A406C5A290472154A401D8F19A88C4D4A402A1900AAB8194A4014083BC5AA514A402A1900AAB8194A4014083BC5AA514A406C5A290472154A401D8F19A88C4D4A406C5A290472154A40
13724	Амерханово	7	69	1258	52.596719	52.609278000000003	52.137366	52.129272999999998	0103000020E610000001000000050000006FF3C649614C4A40BEA085048C104A406FF3C649614C4A408ACA863595114A400E164ED2FC4D4A408ACA863595114A400E164ED2FC4D4A40BEA085048C104A406FF3C649614C4A40BEA085048C104A40
49363	Ясная Поляна	7	69	1156	53.068389000000003	53.089103999999999	51.726858	51.709392999999999	0103000020E61000000100000005000000FD3383F8C0884A407381CB63CDDA4940FD3383F8C0884A40016BD5AE09DD4940ADF886C2678B4A40016BD5AE09DD4940ADF886C2678B4A407381CB63CDDA4940FD3383F8C0884A407381CB63CDDA4940
11227	Шумаево	7	69	1156	52.866698999999997	52.882896000000002	51.766320999999998	51.759324999999997	0103000020E61000000100000005000000EA3C2AFEEF6E4A408104C58F31E14940EA3C2AFEEF6E4A40779E78CE16E2494076E272BC02714A40779E78CE16E2494076E272BC02714A408104C58F31E14940EA3C2AFEEF6E4A408104C58F31E14940
49035	Широкое	7	69	1156	52.649962000000002	52.672105999999999	51.993121000000002	51.983243999999999	0103000020E6100000010000000500000046D26EF431534A407EFE7BF0DAFD494046D26EF431534A4044FCC3961EFF494002B9C49107564A4044FCC3961EFF494002B9C49107564A407EFE7BF0DAFD494046D26EF431534A407EFE7BF0DAFD4940
12764	Шестаковка	7	69	1156	52.845759000000001	52.879536000000002	52.088303000000003	52.073210000000003	0103000020E610000001000000050000001AA6B6D4416C4A40BEDEFDF15E094A401AA6B6D4416C4A40C19140834D0B4A40CCD3B9A294704A40C19140834D0B4A40CCD3B9A294704A40BEDEFDF15E094A401AA6B6D4416C4A40BEDEFDF15E094A40
25520	Чернышовка	7	69	1156	52.930757999999997	52.947242000000003	51.803527000000003	51.792698999999999	0103000020E61000000100000005000000C43E011423774A4034492C2977E54940C43E011423774A40FC3905F9D9E64940E6B2D1393F794A40FC3905F9D9E64940E6B2D1393F794A4034492C2977E54940C43E011423774A4034492C2977E54940
12602	Черноярово	7	69	1156	52.666499999999999	52.687719000000001	51.905754000000002	51.893355999999997	0103000020E610000001000000050000005A643BDF4F554A40BAD7497D59F249405A643BDF4F554A40501C40BFEFF349403EEB1A2D07584A40501C40BFEFF349403EEB1A2D07584A40BAD7497D59F249405A643BDF4F554A40BAD7497D59F24940
12705	Чеботаревка	7	69	1156	52.680594999999997	52.692255000000003	51.879136000000003	51.859555999999998	0103000020E610000001000000050000001A69A9BC1D574A40508A56EE05EE49401A69A9BC1D574A403E5E488787F049400ABFD4CF9B584A403E5E488787F049400ABFD4CF9B584A40508A56EE05EE49401A69A9BC1D574A40508A56EE05EE4940
49229	Ташла	7	69	1156	52.727666999999997	52.766824	51.776598	51.751748999999997	0103000020E6100000010000000500000070B03731245D4A407DE6AC4F39E0494070B03731245D4A40CB11329067E34940DAE4F04927624A40CB11329067E34940DAE4F04927624A407DE6AC4F39E0494070B03731245D4A407DE6AC4F39E04940
46279	Степной	7	69	1156	52.502028000000003	52.531295	51.774346000000001	51.757798000000001	0103000020E6100000010000000500000091D6187442404A40B37C5D86FFE0494091D6187442404A40EBE40CC51DE34940A0C37C7901444A40EBE40CC51DE34940A0C37C7901444A40B37C5D86FFE0494091D6187442404A40B37C5D86FFE04940
56143	Степановка	7	69	1156	53.030856999999997	53.052785	52.073244000000003	52.059103	0103000020E6100000010000000500000024ED461FF3834A40390CE6AF90074A4024ED461FF3834A406A50340F60094A40145CACA8C1864A406A50340F60094A40145CACA8C1864A40390CE6AF90074A4024ED461FF3834A40390CE6AF90074A40
49405	Солнечный	7	69	1156	53.001652999999997	53.026114	51.807665	51.797139000000001	0103000020E610000001000000050000005B785E2A36804A40DEAE97A608E649405B785E2A36804A40DA8F149161E74940DFFB1BB457834A40DA8F149161E74940DFFB1BB457834A40DEAE97A608E649405B785E2A36804A40DEAE97A608E64940
11890	Раннее	7	69	1156	52.595847999999997	52.616580999999996	51.503056999999998	51.485813999999998	0103000020E6100000010000000500000089B14CBF444C4A402FF834272FBE494089B14CBF444C4A400E83F92B64C04940E02A4F20EC4E4A400E83F92B64C04940E02A4F20EC4E4A402FF834272FBE494089B14CBF444C4A402FF834272FBE4940
11985	Пустобаево	7	69	1156	52.403131999999999	52.416435999999997	51.688392999999998	51.677610999999999	0103000020E610000001000000050000004CFC51D499334A4076340EF5BBD649404CFC51D499334A40CDE506431DD8494043705CC64D354A40CDE506431DD8494043705CC64D354A4076340EF5BBD649404CFC51D499334A4076340EF5BBD64940
56201	Прокуронка	7	69	1156	52.855550999999998	52.869816	51.862526000000003	51.852826	0103000020E61000000100000005000000B187F6B1826D4A40D996016729ED4940B187F6B1826D4A4090F9804067EE4940CEC47421566F4A4090F9804067EE4940CEC47421566F4A40D996016729ED4940B187F6B1826D4A40D996016729ED4940
49061	Придолинный	7	69	1156	53.187567999999999	53.220644	51.894201000000002	51.872948000000001	0103000020E6100000010000000500000058E36C3A02984A40E78D93C2BCEF494058E36C3A02984A407786A92D75F24940810706103E9C4A407786A92D75F24940810706103E9C4A40E78D93C2BCEF494058E36C3A02984A40E78D93C2BCEF4940
11613	Новосельное	7	69	1156	52.746361	52.760913000000002	51.948374000000001	51.941611999999999	0103000020E610000001000000050000004301DBC1885F4A40B5C2F4BD86F849404301DBC1885F4A403830B95164F94940F60CE19865614A403830B95164F94940F60CE19865614A40B5C2F4BD86F849404301DBC1885F4A40B5C2F4BD86F84940
11604	Новокаменка	7	69	1156	52.693989000000002	52.718333000000001	51.939329999999998	51.916677	0103000020E610000001000000050000005264ADA1D4584A4069FF03AC55F549405264ADA1D4584A406A1327F73BF849409C51F355F25B4A406A1327F73BF849409C51F355F25B4A4069FF03AC55F549405264ADA1D4584A4069FF03AC55F54940
11915	Мирошкино	7	69	1156	52.472824000000003	52.481205000000003	51.658226999999997	51.643312999999999	0103000020E61000000100000005000000C861307F853C4A40BB0B941458D24940C861307F853C4A400E2C47C840D44940FAD51C20983D4A400E2C47C840D44940FAD51C20983D4A40BB0B941458D24940C861307F853C4A40BB0B941458D24940
48756	Майское	7	69	1156	52.912567000000003	52.932679999999998	51.939768999999998	51.929329000000003	0103000020E610000001000000050000005534D6FECE744A40B91CAF40F4F649405534D6FECE744A40B665C0594AF849400FD1E80E62774A40B665C0594AF849400FD1E80E62774A40B91CAF40F4F649405534D6FECE744A40B91CAF40F4F64940
12105	Курташка	7	69	1156	52.975718000000001	53.004401999999999	52.093626	52.085873999999997	0103000020E610000001000000050000002C0FD253E47C4A40D1C952EBFD0A4A402C0FD253E47C4A401407D0EFFB0B4A40BC04A73E90804A401407D0EFFB0B4A40BC04A73E90804A40D1C952EBFD0A4A402C0FD253E47C4A40D1C952EBFD0A4A40
49283	Кузьминка	7	69	1156	52.640970000000003	52.658568000000002	51.649141999999998	51.641038000000002	0103000020E61000000100000005000000CBDB114E0B524A4023BF7E880DD24940CBDB114E0B524A40E23AC61517D349409818CBF44B544A40E23AC61517D349409818CBF44B544A4023BF7E880DD24940CBDB114E0B524A4023BF7E880DD24940
56154	Криница	7	69	1156	53.061641999999999	53.071739000000001	51.879914999999997	51.869472999999999	0103000020E61000000100000005000000AF0793E2E3874A40A4E029E44AEF4940AF0793E2E3874A404221020EA1F04940836C59BE2E894A404221020EA1F04940836C59BE2E894A40A4E029E44AEF4940AF0793E2E3874A40A4E029E44AEF4940
48912	Коммуна	7	69	1156	52.711174	52.731178999999997	51.833067	51.823360000000001	0103000020E61000000100000005000000FCE1E7BF075B4A40D36A48DC63E94940FCE1E7BF075B4A403C3080F0A1EA4940D0420246975D4A403C3080F0A1EA4940D0420246975D4A40D36A48DC63E94940FCE1E7BF075B4A40D36A48DC63E94940
11513	Кинделя	7	69	1156	52.967264999999998	53.012189999999997	51.630954000000003	51.598253999999997	0103000020E6100000010000000500000060C8EA56CF7B4A40C0594A9693CC494060C8EA56CF7B4A40E4A3C519C3D049404BAB21718F814A40E4A3C519C3D049404BAB21718F814A40C0594A9693CC494060C8EA56CF7B4A40C0594A9693CC4940
11411	Кандалинцево	7	69	1156	52.606430000000003	52.623570000000001	51.828180000000003	51.815972000000002	0103000020E610000001000000050000001AA88C7F9F4D4A40D2393FC571E849401AA88C7F9F4D4A40C4995FCD01EA494024624A24D14F4A40C4995FCD01EA494024624A24D14F4A40D2393FC571E849401AA88C7F9F4D4A40D2393FC571E84940
12104	Каменноимангулово	7	69	1156	52.910285000000002	52.930712999999997	52.094926999999998	52.083117999999999	0103000020E610000001000000050000000A85083884744A40BEDA519CA30A4A400A85083884744A40F2406491260C4A40247B849A21774A40F2406491260C4A40247B849A21774A40BEDA519CA30A4A400A85083884744A40BEDA519CA30A4A40
48901	Калинин	7	69	1156	52.704875999999999	52.721738000000002	51.854644999999998	51.841887	0103000020E610000001000000050000001EDE7360395A4A40BAF605F4C2EB49401EDE7360395A4A404F58E20165ED4940E62329E9615C4A404F58E20165ED4940E62329E9615C4A40BAF605F4C2EB49401EDE7360395A4A40BAF605F4C2EB4940
11093	Иртек	7	69	1156	52.657580000000003	52.684925	51.52852	51.515726000000001	0103000020E610000001000000050000007940D9942B544A4034D93F4F03C249407940D9942B544A4016A4198BA6C349403D9B559FAB574A4016A4198BA6C349403D9B559FAB574A4034D93F4F03C249407940D9942B544A4034D93F4F03C24940
49386	Зерновой	7	69	1156	52.945858000000001	52.958606000000003	51.696672999999997	51.685183000000002	0103000020E610000001000000050000007A54FCDF11794A4039639813B4D749407A54FCDF11794A40CB80B3942CD94940ECDFF599B37A4A40CB80B3942CD94940ECDFF599B37A4A4039639813B4D749407A54FCDF11794A4039639813B4D74940
11243	Заречное	7	69	1156	53.154877999999997	53.180543	51.950200000000002	51.927140999999999	0103000020E61000000100000005000000586FD40AD3934A40EFE3688EACF64940586FD40AD3934A4061545227A0F94940C84274081C974A4061545227A0F94940C84274081C974A40EFE3688EACF64940586FD40AD3934A40EFE3688EACF64940
21395	Западный	7	69	1156	52.374215	52.384672000000002	51.800347000000002	51.788843999999997	0103000020E610000001000000050000001956F146E62F4A40AAD216D7F8E449401956F146E62F4A40D2393FC571E64940EDD79DEE3C314A40D2393FC571E64940EDD79DEE3C314A40AAD216D7F8E449401956F146E62F4A40AAD216D7F8E44940
12243	Жирнов	7	69	1156	52.599432	52.617659000000003	51.683273	51.675069000000001	0103000020E6100000010000000500000083161230BA4C4A408FC536A968D6494083161230BA4C4A40B29E5A7D75D74940408A3A730F4F4A40B29E5A7D75D74940408A3A730F4F4A408FC536A968D6494083161230BA4C4A408FC536A968D64940
12663	Жигалино	7	69	1156	52.568888999999999	52.592713000000003	51.906410000000001	51.897919000000002	0103000020E61000000100000005000000EE06D15AD1484A4080BA8102EFF24940EE06D15AD1484A4039622D3E05F4494000750305DE4B4A4039622D3E05F4494000750305DE4B4A4080BA8102EFF24940EE06D15AD1484A4080BA8102EFF24940
48825	Вязовое	7	69	1156	52.999847000000003	53.022691000000002	51.827556999999999	51.811022000000001	0103000020E610000001000000050000007A008BFCFA7F4A40132BA391CFE749407A008BFCFA7F4A40B6494563EDE94940EF74E789E7824A40B6494563EDE94940EF74E789E7824A40132BA391CFE749407A008BFCFA7F4A40132BA391CFE74940
49377	Восходящий	7	69	1156	53.108148	53.127282000000001	51.731605000000002	51.721536	0103000020E610000001000000050000005C902DCBD78D4A407E71A94A5BDC49405C902DCBD78D4A40884B8E3BA5DD49404BAFCDC64A904A40884B8E3BA5DD49404BAFCDC64A904A407E71A94A5BDC49405C902DCBD78D4A407E71A94A5BDC4940
11764	Буренино	7	69	1156	52.82367	52.849863999999997	51.985517999999999	51.971189000000003	0103000020E610000001000000050000002159C0046E694A40139ED0EB4FFC49402159C0046E694A4046CF2D7425FE49401C06F357C86C4A4046CF2D7425FE49401C06F357C86C4A40139ED0EB4FFC49402159C0046E694A40139ED0EB4FFC4940
11526	Бородинск	7	69	1156	52.813437999999998	52.843783000000002	51.577218999999999	51.564287999999998	0103000020E610000001000000050000006DA983BC1E684A403BC3D4963AC849406DA983BC1E684A409ED0EB4FE2C94940DCF5D214016C4A409ED0EB4FE2C94940DCF5D214016C4A403BC3D4963AC849406DA983BC1E684A403BC3D4963AC84940
48767	Болдырево	7	69	1156	52.719932	52.736991000000003	51.674728999999999	51.661954000000001	0103000020E6100000010000000500000004AC55BB265C4A406BBA9EE8BAD4494004AC55BB265C4A40D65416855DD64940223999B8555E4A40D65416855DD64940223999B8555E4A406BBA9EE8BAD4494004AC55BB265C4A406BBA9EE8BAD44940
10908	Благодарное	7	69	1156	53.037325000000003	53.063349000000002	52.011102000000001	51.995244999999997	0103000020E610000001000000050000005F29CB10C7844A40F6402B3064FF49405F29CB10C7844A40C97553CA6B014A40FE9DEDD11B884A40C97553CA6B014A40FE9DEDD11B884A40F6402B3064FF49405F29CB10C7844A40F6402B3064FF4940
12781	Баширово	7	69	1156	52.813068999999999	52.839030999999999	52.084651000000001	52.075994999999999	0103000020E610000001000000050000001A321EA512684A406BD44334BA094A401A321EA512684A406F490ED8D50A4A4043AA285E656B4A406F490ED8D50A4A4043AA285E656B4A406BD44334BA094A401A321EA512684A406BD44334BA094A40
56141	п.Новый	7	69	520	52.782769000000002	53.819344000000001	52.786596000000003	52.087302000000001	0103000020E610000001000000050000004CA94BC631644A400D7041B62C0B4A404CA94BC631644A400C957F2DAF644A404016A243E0E84A400C957F2DAF644A404016A243E0E84A400D7041B62C0B4A404CA94BC631644A400D7041B62C0B4A40
7107	Янтарное	7	69	520	53.019395000000003	53.046587000000002	52.579695999999998	52.567436000000001	0103000020E610000001000000050000005C5A0D897B824A405A492BBEA1484A405C5A0D897B824A409ECF807A334A4A409AB51490F6854A409ECF807A334A4A409AB51490F6854A405A492BBEA1484A405C5A0D897B824A405A492BBEA1484A40
10520	Федоровка	7	69	520	52.914560999999999	52.934781999999998	52.362549000000001	52.336832000000001	0103000020E610000001000000050000003999B85510754A40861F9C4F1D2B4A403999B85510754A4048197101682E4A40DA71C3EFA6774A4048197101682E4A40DA71C3EFA6774A40861F9C4F1D2B4A403999B85510754A40861F9C4F1D2B4A40
9880	Уран	7	69	520	53.073805	53.093532000000003	52.531101999999997	52.519964000000002	0103000020E6100000010000000500000001A4367172894A40768C2B2E8E424A4001A4367172894A408B6B7C26FB434A40939048DBF88B4A408B6B7C26FB434A40939048DBF88B4A40768C2B2E8E424A4001A4367172894A40768C2B2E8E424A40
10492	Троицкое	7	69	520	52.974164000000002	52.991250000000001	52.314490999999997	52.294578000000001	0103000020E610000001000000050000006478EC67B17C4A40800F5EBBB4254A406478EC67B17C4A4073F1B73D41284A407B14AE47E17E4A4073F1B73D41284A407B14AE47E17E4A40800F5EBBB4254A406478EC67B17C4A40800F5EBBB4254A40
10425	Толкаевка	7	69	520	53.266942999999998	53.293731000000001	52.575597000000002	52.543356000000003	0103000020E61000000100000005000000B4722F302BA24A40EE0A7DB08C454A40B4722F302BA24A407E569929AD494A40236937FA98A54A407E569929AD494A40236937FA98A54A40EE0A7DB08C454A40B4722F302BA24A40EE0A7DB08C454A40
3171	Спасское	7	69	520	53.202255999999998	53.226922999999999	52.336832000000001	52.320838000000002	0103000020E61000000100000005000000BBB54C86E3994A4033A8363811294A40BBB54C86E3994A40861F9C4F1D2B4A40E8DA17D00B9D4A40861F9C4F1D2B4A40E8DA17D00B9D4A4033A8363811294A40BBB54C86E3994A4033A8363811294A40
9364	Сборовский	7	69	520	53.101249000000003	53.112684999999999	52.355063999999999	52.347880000000004	0103000020E6100000010000000500000059E02BBAF58C4A405C77F354872C4A4059E02BBAF58C4A4054FEB5BC722D4A40F8DF4A766C8E4A4054FEB5BC722D4A40F8DF4A766C8E4A405C77F354872C4A4059E02BBAF58C4A405C77F354872C4A40
9657	Романовка	7	69	520	52.917633000000002	52.953000000000003	52.214998999999999	52.204011000000001	0103000020E610000001000000050000007D5D86FF74754A401B834E081D1A4A407D5D86FF74754A401BD65416851B4A40448B6CE7FB794A401BD65416851B4A40448B6CE7FB794A401B834E081D1A4A407D5D86FF74754A401B834E081D1A4A40
10211	Родинский	7	69	520	53.322530999999998	53.347225999999999	52.436278999999999	52.424232000000003	0103000020E610000001000000050000001C7920B248A94A4056F5F23B4D364A401C7920B248A94A403E7782FDD7374A401329CDE671AC4A403E7782FDD7374A401329CDE671AC4A4056F5F23B4D364A401C7920B248A94A4056F5F23B4D364A40
10111	Пронькино	7	69	520	52.886201	52.932724999999998	52.722943000000001	52.691710999999998	0103000020E610000001000000050000005C57CC086F714A4048A46DFC89584A405C57CC086F714A40A2EF6E65895C4A40AF94658863774A40A2EF6E65895C4A40AF94658863774A4048A46DFC89584A405C57CC086F714A4048A46DFC89584A40
10029	Покровка	7	69	520	53.10398	53.128926	52.199469000000001	52.190322000000002	0103000020E6100000010000000500000013B875374F8D4A40CBDAA6785C184A4013B875374F8D4A406DC83F3388194A4053CDACA580904A406DC83F3388194A4053CDACA580904A40CBDAA6785C184A4013B875374F8D4A40CBDAA6785C184A40
10061	Первокрасное	7	69	520	53.512470999999998	53.55603	52.518895000000001	52.501548	0103000020E61000000100000005000000FF9254A698C14A40E6AF90B932404A40FF9254A698C14A406A87BF266B424A4025CCB4FD2BC74A406A87BF266B424A4025CCB4FD2BC74A40E6AF90B932404A40FF9254A698C14A40E6AF90B932404A40
56178	Новая Белогорка	7	69	520	53.099767	53.118721000000001	52.124384999999997	52.116804000000002	0103000020E610000001000000050000002A1C412AC58C4A406005F86EF30E4A402A1C412AC58C4A40758E01D9EB0F4A40992CEE3F328F4A40758E01D9EB0F4A40992CEE3F328F4A406005F86EF30E4A402A1C412AC58C4A406005F86EF30E4A40
9903	Никольское	7	69	520	53.124372000000001	53.146110999999998	52.590567999999998	52.575077	0103000020E61000000100000005000000E144F46BEB8F4A4045D7851F9C494A40E144F46BEB8F4A40350873BB974B4A40FD4AE7C3B3924A40350873BB974B4A40FD4AE7C3B3924A4045D7851F9C494A40E144F46BEB8F4A4045D7851F9C494A40
9825	Николаевка	7	69	520	52.976410000000001	53.022843999999999	52.506394	52.497419999999998	0103000020E6100000010000000500000062BEBC00FB7C4A402B306475AB3F4A4062BEBC00FB7C4A400072C284D1404A4075745C8DEC824A400072C284D1404A4075745C8DEC824A402B306475AB3F4A4062BEBC00FB7C4A402B306475AB3F4A40
9259	Надеждинка	7	69	520	53.394503999999998	53.417672000000003	52.326337000000002	52.316335000000002	0103000020E610000001000000050000001212691B7FB24A4043CA4FAA7D284A401212691B7FB24A40C53C2B69C5294A403B3AAE4676B54A40C53C2B69C5294A403B3AAE4676B54A4043CA4FAA7D284A401212691B7FB24A4043CA4FAA7D284A40
9721	Михайловка 2-я	7	69	520	53.379736000000001	53.405310999999998	52.485388999999998	52.471550999999998	0103000020E61000000100000005000000938E72309BB04A40B3B27DC85B3C4A40938E72309BB04A40486B0C3A213E4A40C2DA183BE1B34A40486B0C3A213E4A40C2DA183BE1B34A40B3B27DC85B3C4A40938E72309BB04A40B3B27DC85B3C4A40
9590	Михайловка 1-я	7	69	520	53.002299999999998	53.023930999999997	52.241168000000002	52.223953999999999	0103000020E61000000100000005000000F163CC5D4B804A4079E75086AA1C4A40F163CC5D4B804A40BE6BD097DE1E4A40272EC72B10834A40BE6BD097DE1E4A40272EC72B10834A4079E75086AA1C4A40F163CC5D4B804A4079E75086AA1C4A40
9569	Матвеевка	7	69	520	53.275621000000001	53.298338999999999	52.169525	52.145960000000002	0103000020E61000000100000005000000A08B868C47A34A40184339D1AE124A40A08B868C47A34A405D6DC5FEB2154A40880FECF82FA64A405D6DC5FEB2154A40880FECF82FA64A40184339D1AE124A40A08B868C47A34A40184339D1AE124A40
9750	Ивановка 2-я	7	69	520	53.367438	53.403585999999997	52.466343999999999	52.450524000000001	0103000020E6100000010000000500000061A7583508AF4A4014083BC5AA394A4061A7583508AF4A40C9570229B13B4A40CD8FBFB4A8B34A40C9570229B13B4A40CD8FBFB4A8B34A4014083BC5AA394A4061A7583508AF4A4014083BC5AA394A40
56041	Ивановка	7	69	520	53.050871000000001	53.071102000000003	52.646006999999997	52.627268000000001	0103000020E610000001000000050000004CA8E0F082864A40E6E95C514A504A404CA8E0F082864A4058FE7C5BB0524A401157CEDE19894A4058FE7C5BB0524A401157CEDE19894A40E6E95C514A504A404CA8E0F082864A40E6E95C514A504A40
9441	Гамалеевка	7	69	520	53.439725000000003	53.462605000000003	52.287241000000002	52.252560000000003	0103000020E61000000100000005000000E71DA7E848B84A408E23D6E253204A40E71DA7E848B84A4001892650C4244A40A9FB00A436BB4A4001892650C4244A40A9FB00A436BB4A408E23D6E253204A40E71DA7E848B84A408E23D6E253204A40
9276	Войковский	7	69	520	53.145724999999999	53.165326	52.258723000000003	52.246104000000003	0103000020E61000000100000005000000D49AE61DA7924A4018B5FB55801F4A40D49AE61DA7924A408CDCD3D51D214A40D996016729954A408CDCD3D51D214A40D996016729954A4018B5FB55801F4A40D49AE61DA7924A4018B5FB55801F4A40
9184	Бурдыгино	7	69	520	53.314078000000002	53.361274999999999	52.342801999999999	52.311314000000003	0103000020E61000000100000005000000513239B533A84A40BB641C23D9274A40513239B533A84A406F8099EFE02B4A4063EE5A423EAE4A406F8099EFE02B4A4063EE5A423EAE4A40BB641C23D9274A40513239B533A84A40BB641C23D9274A40
24767	Березовка	7	69	520	52.952038999999999	52.973077000000004	52.631202999999999	52.620631000000003	0103000020E610000001000000050000001EC2F869DC794A4020F12BD6704F4A401EC2F869DC794A408C118942CB504A40B2BE81C98D7C4A408C118942CB504A40B2BE81C98D7C4A4020F12BD6704F4A401EC2F869DC794A4020F12BD6704F4A40
9114	Баклановка	7	69	520	52.989544000000002	53.023705999999997	52.648891999999996	52.637357000000002	0103000020E61000000100000005000000FDF9B660A97E4A40377007EA94514A40FDF9B660A97E4A4069519FE40E534A40075C57CC08834A4069519FE40E534A40075C57CC08834A40377007EA94514A40FDF9B660A97E4A40377007EA94514A40
9519	Алексеевка	7	69	520	53.304600999999998	53.336193999999999	52.220616	52.203366000000003	0103000020E6100000010000000500000019AA622AFDA64A40268FA7E5071A4A4019AA622AFDA64A40B77C24253D1C4A40438EAD6708AB4A40B77C24253D1C4A40438EAD6708AB4A40268FA7E5071A4A4019AA622AFDA64A40268FA7E5071A4A40
56093	кирпичный Завод	7	69	884	54.911714000000003	54.923400999999998	51.182552999999999	51.175941000000002	0103000020E6100000010000000500000016A75A0BB3744B404583143C8596494016A75A0BB3744B40B2648EE55D974940FE0B040132764B40B2648EE55D974940FE0B040132764B404583143C8596494016A75A0BB3744B404583143C85964940
7874	Шахтный	7	69	884	55.091636999999999	55.114490000000004	51.208229000000003	51.188282999999998	0103000020E61000000100000005000000410DDFC2BA8B4B4046B247A819984940410DDFC2BA8B4B40168A743FA79A49400ADCBA9BA78E4B40168A743FA79A49400ADCBA9BA78E4B4046B247A819984940410DDFC2BA8B4B4046B247A819984940
7048	Чашкан	7	69	884	55.321461999999997	55.336858999999997	51.108673000000003	51.102038999999998	0103000020E610000001000000050000001074B4AA25A94B4051F52B9D0F8D49401074B4AA25A94B40A77A32FFE88D49407F2E1A321EAB4B40A77A32FFE88D49407F2E1A321EAB4B4051F52B9D0F8D49401074B4AA25A94B4051F52B9D0F8D4940
7239	Цвиллинга	7	69	884	54.601641999999998	54.618476999999999	51.120598000000001	51.110996999999998	0103000020E6100000010000000500000034F3E49A024D4B40207A5226358E494034F3E49A024D4B4044FB58C16F8F4940022A1C412A4F4B4044FB58C16F8F4940022A1C412A4F4B40207A5226358E494034F3E49A024D4B40207A5226358E4940
8160	Угольное	7	69	884	55.166699999999999	55.190398000000002	51.118969999999997	51.102032999999999	0103000020E61000000100000005000000211FF46C56954B406F0ED76A0F8D4940211FF46C56954B40419AB1683A8F4940A69C2FF65E984B40419AB1683A8F4940A69C2FF65E984B406F0ED76A0F8D4940211FF46C56954B406F0ED76A0F8D4940
8027	Трудовое	7	69	884	54.862189999999998	54.892327999999999	51.099567	51.076847000000001	0103000020E610000001000000050000001878EE3D5C6E4B40DAE55B1FD68949401878EE3D5C6E4B406361889CBE8C49400DA7CCCD37724B406361889CBE8C49400DA7CCCD37724B40DAE55B1FD68949401878EE3D5C6E4B40DAE55B1FD6894940
8136	Троицк	7	69	884	54.605307000000003	54.63364	50.709485000000001	50.684797000000003	0103000020E610000001000000050000001B8524B37A4D4B4010B3976DA75749401B8524B37A4D4B4054008C67D05A4940FEB7921D1B514B4054008C67D05A4940FEB7921D1B514B4010B3976DA75749401B8524B37A4D4B4010B3976DA7574940
8066	Тамар-Уткуль	7	69	884	55.003045	55.028754999999997	51.090341000000002	51.076847000000001	0103000020E610000001000000050000004AB54FC763804B40DAE55B1FD68949404AB54FC763804B40753E3C4B908B4940594C6C3EAE834B40753E3C4B908B4940594C6C3EAE834B40DAE55B1FD68949404AB54FC763804B40DAE55B1FD6894940
21017	Сухоречка	7	69	884	55.230345999999997	55.247853999999997	51.209532000000003	51.190660000000001	0103000020E61000000100000005000000D8614CFA7B9D4B40E353008C67984940D8614CFA7B9D4B4095BBCFF1D19A494065170CAEB99F4B4095BBCFF1D19A494065170CAEB99F4B40E353008C67984940D8614CFA7B9D4B40E353008C67984940
8389	Соль-Илецк	7	69	884	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
22504	Смирновка	7	69	884	55.356946000000001	55.381729999999997	51.465501000000003	51.452392000000003	0103000020E6100000010000000500000011381268B0AD4B406C7C26FBE7B9494011381268B0AD4B40AEA0698995BB494077F35487DCB04B40AEA0698995BB494077F35487DCB04B406C7C26FBE7B9494011381268B0AD4B406C7C26FBE7B94940
7949	Саратовка	7	69	884	54.898535000000003	54.924900999999998	51.212533999999998	51.183072000000003	0103000020E61000000100000005000000DBA7E33103734B401B683EE76E974940DBA7E33103734B40DFA46950349B4940D384ED2763764B40DFA46950349B4940D384ED2763764B401B683EE76E974940DBA7E33103734B401B683EE76E974940
52595	Садовый	7	69	884	54.412537999999998	54.428877999999997	51.257508999999999	51.248804999999997	0103000020E61000000100000005000000BA2D910BCE344B40670A9DD7D89F4940BA2D910BCE344B407CB60E0EF6A04940A8FC6B79E5364B407CB60E0EF6A04940A8FC6B79E5364B40670A9DD7D89F4940BA2D910BCE344B40670A9DD7D89F4940
7843	Покровка	7	69	884	54.523910999999998	54.553491999999999	50.925136000000002	50.906163999999997	0103000020E61000000100000005000000E08101840F434B400168942EFD734940E08101840F434B40172D40DB6A7649407F4C6BD3D8464B40172D40DB6A7649407F4C6BD3D8464B400168942EFD734940E08101840F434B400168942EFD734940
7676	Перовка	7	69	884	55.290362999999999	55.313637999999997	51.367984	51.351999999999997	0103000020E61000000100000005000000F67B629D2AA54B40931804560EAD4940F67B629D2AA54B40C3B986191AAF494034643C4A25A84B40C3B986191AAF494034643C4A25A84B40931804560EAD4940F67B629D2AA54B40931804560EAD4940
7747	Первомайское	7	69	884	54.987063999999997	55.020158000000002	50.981560000000002	50.966642999999998	0103000020E610000001000000050000008B87F71C587E4B4023F433F5BA7B49408B87F71C587E4B40E88711C2A37D49405B608F8994824B40E88711C2A37D49405B608F8994824B4023F433F5BA7B49408B87F71C587E4B4023F433F5BA7B4940
7600	Новоилецк	7	69	884	54.214692999999997	54.241148000000003	51.002332000000003	50.990642999999999	0103000020E610000001000000050000000ED76A0F7B1B4B407381CB63CD7E49400ED76A0F7B1B4B40FDDD3B6A4C80494077BF0AF0DD1E4B40FDDD3B6A4C80494077BF0AF0DD1E4B407381CB63CD7E49400ED76A0F7B1B4B407381CB63CD7E4940
7578	Михайловка	7	69	884	55.384065999999997	55.407646999999997	51.443247999999997	51.429234000000001	0103000020E61000000100000005000000B5C01E1329B14B40672AC423F1B64940B5C01E1329B14B403A02B859BCB8494000A8E2C62DB44B403A02B859BCB8494000A8E2C62DB44B40672AC423F1B64940B5C01E1329B14B40672AC423F1B64940
56155	Мирный	7	69	884	54.003804000000002	55.629665000000003	51.500000999999997	50.527413000000003	0103000020E6100000010000000500000008CC43A67C004B401D3EE9448243494008CC43A67C004B40D07B630800C04940CA37DBDC98D04B40D07B630800C04940CA37DBDC98D04B401D3EE9448243494008CC43A67C004B401D3EE94482434940
7682	Мещеряковка	7	69	884	55.258651999999998	55.283723999999999	51.395259000000003	51.380898000000002	0103000020E61000000100000005000000C2853C821BA14B40508E0244C1B04940C2853C821BA14B408F39CFD897B249408F8B6A1151A44B408F39CFD897B249408F8B6A1151A44B40508E0244C1B04940C2853C821BA14B40508E0244C1B04940
56139	Маячная	7	69	884	54.95044	54.967202999999998	51.332178999999996	51.321215000000002	0103000020E61000000100000005000000B6679604A8794B4009FEB7921DA94940B6679604A8794B4080B56AD784AA4940EACBD24ECD7B4B4080B56AD784AA4940EACBD24ECD7B4B4009FEB7921DA94940B6679604A8794B4009FEB7921DA94940
56078	Маякский	7	69	884	55.131729	55.152327	51.363114000000003	51.340107000000003	0103000020E61000000100000005000000A777F17EDC904B4002124DA088AB4940A777F17EDC904B40215C01857AAE49401EA67D737F934B40215C01857AAE49401EA67D737F934B4002124DA088AB4940A777F17EDC904B4002124DA088AB4940
56118	Малопрудный	7	69	884	55.151285000000001	55.159396999999998	51.372774	51.364744999999999	0103000020E610000001000000050000000CB08F4E5D934B409430D3F6AFAE49400CB08F4E5D934B404966F50EB7AF49404E0AF31E67944B404966F50EB7AF49404E0AF31E67944B409430D3F6AFAE49400CB08F4E5D934B409430D3F6AFAE4940
7521	Линевка	7	69	884	54.099393999999997	54.133448999999999	51.155676	51.130614999999999	0103000020E6100000010000000500000095B54DF1B80C4B40FBAE08FEB790494095B54DF1B80C4B40D462F030ED9349408A5759DB14114B40D462F030ED9349408A5759DB14114B40FBAE08FEB790494095B54DF1B80C4B40FBAE08FEB7904940
56088	Кумакский	7	69	884	55.120230999999997	55.138142999999999	51.078884000000002	51.063110999999999	0103000020E61000000100000005000000917BBABA638F4B404982700514884940917BBABA638F4B40BE16F4DE188A4940EE9579ABAE914B40BE16F4DE188A4940EE9579ABAE914B404982700514884940917BBABA638F4B404982700514884940
6996	Казанка	7	69	884	55.377372999999999	55.401384999999998	51.107852999999999	51.098685000000003	0103000020E610000001000000050000005BB22AC24DB04B408ACDC7B5A18C49405BB22AC24DB04B4043E38920CE8D49406F0D6C9560B34B4043E38920CE8D49406F0D6C9560B34B408ACDC7B5A18C49405BB22AC24DB04B408ACDC7B5A18C4940
7217	Изобильное	7	69	884	54.554156999999996	54.586064999999998	51.047043000000002	51.020992999999997	0103000020E61000000100000005000000BBECD79DEE464B40F3380CE6AF824940BBECD79DEE464B40BC40498105864940452A8C2D044B4B40BC40498105864940452A8C2D044B4B40F3380CE6AF824940BBECD79DEE464B40F3380CE6AF824940
56124	Зеленый Клин	7	69	884	54.927928000000001	54.957886999999999	51.173163000000002	51.153196000000001	0103000020E6100000010000000500000077853E58C6764B4063F030ED9B93494077853E58C6764B404AF086342A964940BC218D0A9C7A4B404AF086342A964940BC218D0A9C7A4B4063F030ED9B93494077853E58C6764B4063F030ED9B934940
7496	Елшанка	7	69	884	55.001815000000001	55.017014000000003	51.326275000000003	51.313564999999997	0103000020E6100000010000000500000035D252793B804B40CA15DEE522A8494035D252793B804B404F401361C3A949407EC9C6832D824B404F401361C3A949407EC9C6832D824B40CA15DEE522A8494035D252793B804B40CA15DEE522A84940
56148	Егенсай	7	69	884	55.102542999999997	55.125081000000002	50.965792	50.955914999999997	0103000020E6100000010000000500000084B70721208D4B40BF60376C5B7A494084B70721208D4B40855E7F129F7B4940ED2C7AA702904B40855E7F129F7B4940ED2C7AA702904B40BF60376C5B7A494084B70721208D4B40BF60376C5B7A4940
7147	Дружба	7	69	884	55.040936000000002	55.059503999999997	51.428604999999997	51.411306000000003	0103000020E61000000100000005000000529D0E643D854B400553CDACA5B44940529D0E643D854B4077F35487DCB6494097FDBAD39D874B4077F35487DCB6494097FDBAD39D874B400553CDACA5B44940529D0E643D854B400553CDACA5B44940
8250	Дивнополье	7	69	884	54.493915999999999	54.529130000000002	51.196399999999997	51.183641999999999	0103000020E610000001000000050000004E7CB5A3383F4B400516C094819749404E7CB5A3383F4B409A779CA2239949408FAA2688BA434B409A779CA2239949408FAA2688BA434B400516C094819749404E7CB5A3383F4B400516C09481974940
6917	Григорьевка	7	69	884	55.286904	55.324039999999997	51.110973999999999	51.095726999999997	0103000020E61000000100000005000000B98B3045B9A44B400E2C47C8408C4940B98B3045B9A44B40685A6265348E4940444C89247AA94B40685A6265348E4940444C89247AA94B400E2C47C8408C4940B98B3045B9A44B400E2C47C8408C4940
6963	Возрождение	7	69	884	55.222926000000001	55.246606	51.114440999999999	51.105998	0103000020E61000000100000005000000CCB6D3D6889C4B4080B8AB57918D4940CCB6D3D6889C4B402829B000A68E4940AA7F10C9909F4B402829B000A68E4940AA7F10C9909F4B4080B8AB57918D4940CCB6D3D6889C4B4080B8AB57918D4940
6841	Ветлянка	7	69	884	54.768180999999998	54.806440000000002	51.089509999999997	51.071945999999997	0103000020E610000001000000050000004C3448C153624B40FC89CA86358949404C3448C153624B401D554D10758B4940D717096D39674B401D554D10758B4940D717096D39674B40FC89CA86358949404C3448C153624B40FC89CA8635894940
6837	Буранное	7	69	884	54.453060999999998	54.484079999999999	50.985585999999998	50.966717000000003	0103000020E61000000100000005000000E90B21E7FD394B405EBEF561BD7B4940E90B21E7FD394B409EB29AAE277E4940E7525C55F63D4B409EB29AAE277E4940E7525C55F63D4B405EBEF561BD7B4940E90B21E7FD394B405EBEF561BD7B4940
6707	Боевая Гора	7	69	884	54.884540000000001	54.909764000000003	51.284545999999999	51.273864000000003	0103000020E610000001000000050000007E00529B38714B40A0C6BDF90DA349407E00529B38714B40931ADA006CA44940018A912573744B40931ADA006CA44940018A912573744B40A0C6BDF90DA349407E00529B38714B40A0C6BDF90DA34940
56162	Ащибутак	7	69	884	55.155543000000002	55.176501000000002	51.395162999999997	51.381875999999998	0103000020E61000000100000005000000950F41D5E8934B404B901150E1B04940950F41D5E8934B406CCB80B394B249400C5BB39597964B406CCB80B394B249400C5BB39597964B404B901150E1B04940950F41D5E8934B404B901150E1B04940
46300	Яковлево	7	69	473	53.015172	53.042760000000001	54.261713999999998	54.246771000000003	0103000020E610000001000000050000004FE8F527F1814A40F54C2F31961F4B404FE8F527F1814A40E27327D87F214B40DAC9E02879854A40E27327D87F214B40DAC9E02879854A40F54C2F31961F4B404FE8F527F1814A40F54C2F31961F4B40
6172	Шабрино	7	69	473	52.983694999999997	53.015667000000001	54.031491000000003	54.021420999999997	0103000020E610000001000000050000008E1EBFB7E97D4A404B395FECBD024B408E1EBFB7E97D4A40268FA7E507044B402F50526001824A40268FA7E507044B402F50526001824A404B395FECBD024B408E1EBFB7E97D4A404B395FECBD024B40
5023	Тургай	7	69	473	52.439306999999999	52.454901999999997	54.105051000000003	54.092849999999999	0103000020E61000000100000005000000B2F336363B384A4080B74082E20B4B40B2F336363B384A40C0B4A84F720D4B4047718E3A3A3A4A40C0B4A84F720D4B4047718E3A3A3A4A4080B74082E20B4B40B2F336363B384A4080B74082E20B4B40
46744	Трифоновка	7	69	473	52.616213000000002	52.640647000000001	54.037641000000001	54.017479999999999	0103000020E610000001000000050000005E2F4D11E04E4A40C32ADEC83C024B405E2F4D11E04E4A408FFE976BD1044B40E8A38CB800524A408FFE976BD1044B40E8A38CB800524A40C32ADEC83C024B405E2F4D11E04E4A40C32ADEC83C024B40
6633	Стародомосейкино	7	69	473	52.559142999999999	52.593521000000003	54.259216000000002	54.243588000000003	0103000020E61000000100000005000000C76471FF91474A405AD93EE42D1F4B40C76471FF91474A40CB4C69FD2D214B409F3E027FF84B4A40CB4C69FD2D214B409F3E027FF84B4A405AD93EE42D1F4B40C76471FF91474A405AD93EE42D1F4B40
6570	Староборискино	7	69	473	52.436081999999999	52.486721000000003	54.250579999999999	54.216293999999998	0103000020E61000000100000005000000E82FF488D1374A4017299485AF1B4B40E82FF488D1374A400E84640113204B4062A3ACDF4C3E4A400E84640113204B4062A3ACDF4C3E4A4017299485AF1B4B40E82FF488D1374A4017299485AF1B4B40
6377	Соковка	7	69	473	52.467739000000002	52.507274000000002	54.13588	54.112631	0103000020E6100000010000000500000029081EDFDE3B4A4005C24EB16A0E4B4029081EDFDE3B4A401A170E8464114B40390EBC5AEE404A401A170E8464114B40390EBC5AEE404A4005C24EB16A0E4B4029081EDFDE3B4A4005C24EB16A0E4B40
46500	Сергушкино	7	69	473	53.213476	53.240254	54.060482999999998	54.019208999999996	0103000020E610000001000000050000008E3D7B2E539B4A40F964C57075024B408E3D7B2E539B4A40637B2DE8BD074B40D95DA0A4C09E4A40637B2DE8BD074B40D95DA0A4C09E4A40F964C57075024B408E3D7B2E539B4A40F964C57075024B40
6388	Секретарка	7	69	473	52.875224000000003	52.920813000000003	54.163258999999996	54.144820000000003	0103000020E6100000010000000500000050560C5707704A4043E7357689124B4050560C5707704A408AE3C0ABE5144B40A75D4C33DD754A408AE3C0ABE5144B40A75D4C33DD754A4043E7357689124B4050560C5707704A4043E7357689124B40
46889	Северное	7	69	473	52.516347000000003	52.558244000000002	54.103102999999997	54.083342999999999	0103000020E61000000100000005000000A13193A817424A40DEACC1FBAA0A4B40A13193A817424A404B8FA67A320D4B401898158A74474A404B8FA67A320D4B401898158A74474A40DEACC1FBAA0A4B40A13193A817424A40DEACC1FBAA0A4B40
46788	Рычково	7	69	473	52.515349999999998	52.536980999999997	53.996758	53.976460000000003	0103000020E610000001000000050000002EFF21FDF6414A4014ED2AA4FCFC4A402EFF21FDF6414A40600322C495FF4A4064C91CCBBB444A40600322C495FF4A4064C91CCBBB444A4014ED2AA4FCFC4A402EFF21FDF6414A4014ED2AA4FCFC4A40
6094	Русский Кандыз	7	69	473	52.908929000000001	52.959584999999997	54.037916000000003	54.018695999999998	0103000020E6100000010000000500000068B114C957744A4073486AA164024B4068B114C957744A4061FF756EDA044B40B75D68AED37A4A4061FF756EDA044B40B75D68AED37A4A4073486AA164024B4068B114C957744A4073486AA164024B40
5488	Ремчугово	7	69	473	52.590305000000001	52.626579	54.324615999999999	54.314895	0103000020E6100000010000000500000028D53E1D8F4B4A404356B77A4E284B4028D53E1D8F4B4A4011E15F048D294B4021AE9CBD33504A4011E15F048D294B4021AE9CBD33504A404356B77A4E284B4028D53E1D8F4B4A404356B77A4E284B40
5387	Пашкино	7	69	473	52.712440000000001	52.999595999999997	54.169431000000003	54.023060000000001	0103000020E610000001000000050000005E2EE23B315B4A4042EC4CA1F3024B405E2EE23B315B4A40DCF63DEAAF154B40309B00C3F27F4A40DCF63DEAAF154B40309B00C3F27F4A4042EC4CA1F3024B405E2EE23B315B4A4042EC4CA1F3024B40
49269	Павловка	7	69	473	52.875205999999999	52.890810000000002	54.225701000000001	54.213487999999998	0103000020E61000000100000005000000A9A10DC006704A40520B2593531B4B40A9A10DC006704A4056D636C5E31C4B409279E40F06724A4056D636C5E31C4B409279E40F06724A40520B2593531B4B40A9A10DC006704A40520B2593531B4B40
45370	Октябрьское	7	69	473	52.445262999999997	52.465673000000002	53.956698000000003	53.937775000000002	0103000020E61000000100000005000000368FC360FE384A40D200DE0209F84A40368FC360FE384A4006137F1475FA4A40ABD0402C9B3B4A4006137F1475FA4A40ABD0402C9B3B4A40D200DE0209F84A40368FC360FE384A40D200DE0209F84A40
5741	Новодомосейкино	7	69	473	52.871648999999998	52.891609000000003	54.304546999999999	54.291806000000001	0103000020E61000000100000005000000A94BC631926F4A40676325E659254B40A94BC631926F4A40268C6665FB264B40DEE8633E20724A40268C6665FB264B40DEE8633E20724A40676325E659254B40A94BC631926F4A40676325E659254B40
5673	Новоборискино	7	69	473	52.929257999999997	52.964750000000002	54.140985999999998	54.125391999999998	0103000020E61000000100000005000000EFC517EDF1764A400B9755D80C104B40EFC517EDF1764A40D09849D40B124B40736891ED7C7B4A40D09849D40B124B40736891ED7C7B4A400B9755D80C104B40EFC517EDF1764A400B9755D80C104B40
5632	Мордово-Добрино	7	69	473	53.005318000000003	53.026707000000002	54.140917000000002	54.126542000000001	0103000020E61000000100000005000000420A9E42AE804A4004C93B8732104B40420A9E42AE804A40A839799109124B4082C98D226B834A40A839799109124B4082C98D226B834A4004C93B8732104B40420A9E42AE804A4004C93B8732104B40
45872	Медведка	7	69	473	52.697339999999997	52.704391000000001	54.328895000000003	54.323146000000001	0103000020E61000000100000005000000A818E76F42594A40A7EA1ED95C294B40A818E76F42594A40B2683A3B192A4B40624CFA7B295A4A40B2683A3B192A4B40624CFA7B295A4A40A7EA1ED95C294B40A818E76F42594A40A7EA1ED95C294B40
56202	Кызыляр	7	69	473	53.196488000000002	53.209415	54.082904999999997	54.068541000000003	0103000020E610000001000000050000003A07CF8426994A40B3B794F3C5084B403A07CF8426994A4062D68BA19C0A4B405B25581CCE9A4A4062D68BA19C0A4B405B25581CCE9A4A40B3B794F3C5084B403A07CF8426994A40B3B794F3C5084B40
5467	Курская Васильевка	7	69	473	52.690458	52.716492000000002	54.235636999999997	54.222679999999997	0103000020E610000001000000050000007BA180ED60584A4094BC3AC7801C4B407BA180ED60584A40205D6C5A291E4B403EEC8502B65B4A40205D6C5A291E4B403EEC8502B65B4A4094BC3AC7801C4B407BA180ED60584A4094BC3AC7801C4B40
5162	Кряжлы	7	69	473	53.135277000000002	53.17015	54.062311000000001	54.049748000000001	0103000020E610000001000000050000005473B9C150914A404D8578245E064B405473B9C150914A402D978DCEF9074B400BB5A679C7954A402D978DCEF9074B400BB5A679C7954A404D8578245E064B405473B9C150914A404D8578245E064B40
46534	Красноярка	7	69	473	52.702486999999998	52.720847999999997	53.999701000000002	53.98516	0103000020E61000000100000005000000BD6E1118EB594A40E7A90EB919FE4A40BD6E1118EB594A40A663CE33F6FF4A4089B14CBF445C4A40A663CE33F6FF4A4089B14CBF445C4A40E7A90EB919FE4A40BD6E1118EB594A40E7A90EB919FE4A40
49554	Кирсановка	7	69	473	52.923274999999997	52.946829000000001	54.238352999999996	54.225901	0103000020E61000000100000005000000711B0DE02D764A401D91EF52EA1C4B40711B0DE02D764A40A5F3E159821E4B40C3F352B131794A40A5F3E159821E4B40C3F352B131794A401D91EF52EA1C4B40711B0DE02D764A401D91EF52EA1C4B40
46996	Камышлинка	7	69	473	52.472608000000001	52.488239	54.201739000000003	54.186109999999999	0103000020E61000000100000005000000FBE93F6B7E3C4A40B2BAD573D2174B40FBE93F6B7E3C4A40F4A96395D2194B40DDD0949D7E3E4A40F4A96395D2194B40DDD0949D7E3E4A40B2BAD573D2174B40FBE93F6B7E3C4A40B2BAD573D2174B40
5095	Каменногорское	7	69	473	52.774056000000002	52.816913999999997	54.172536000000001	54.161962000000003	0103000020E61000000100000005000000E4A25A4414634A40EE98BA2BBB144B40E4A25A4414634A40FBB0DEA815164B4080D250A390684A40FBB0DEA815164B4080D250A390684A40EE98BA2BBB144B40E4A25A4414634A40EE98BA2BBB144B40
4920	Кабаевка	7	69	473	53.172908	53.204025000000001	53.974532000000004	53.959130000000002	0103000020E61000000100000005000000BF9B6ED921964A40664E97C5C4FA4A40BF9B6ED921964A40E773EE76BDFC4A408048BF7D1D9A4A40E773EE76BDFC4A408048BF7D1D9A4A40664E97C5C4FA4A40BF9B6ED921964A40664E97C5C4FA4A40
46384	Жмакино	7	69	473	52.81315	52.823219999999999	54.284247999999998	54.274186999999998	0103000020E61000000100000005000000075F984C15684A4082FE428F18234B40075F984C15684A4009FA0B3D62244B40E1B4E0455F694A4009FA0B3D62244B40E1B4E0455F694A4082FE428F18234B40075F984C15684A4082FE428F18234B40
46987	Дымка	7	69	473	52.485795000000003	52.506385000000002	54.301631999999998	54.294265000000003	0103000020E61000000100000005000000B9C7D2872E3E4A40C1ADBB79AA254B40B9C7D2872E3E4A40AAB69BE09B264B40AD174339D1404A40AAB69BE09B264B40AD174339D1404A40C1ADBB79AA254B40B9C7D2872E3E4A40C1ADBB79AA254B40
56142	Большедорожный	7	69	473	52.558199000000002	52.571890000000003	53.939439	53.916265000000003	0103000020E6100000010000000500000078D4981073474A4017BCE82B48F54A4078D4981073474A4021CB82893FF84A40697407B133494A4021CB82893FF84A40697407B133494A4017BCE82B48F54A4078D4981073474A4017BCE82B48F54A40
46854	Богдановка	7	69	473	52.614325999999998	52.636702999999997	54.134492000000002	54.122805999999997	0103000020E610000001000000050000008F8AFF3BA24E4A4054E0641BB80F4B408F8AFF3BA24E4A406DC9AA0837114B40EE21E17B7F514A406DC9AA0837114B40EE21E17B7F514A4054E0641BB80F4B408F8AFF3BA24E4A4054E0641BB80F4B40
4994	Бакаево	7	69	473	52.395524000000002	52.413589000000002	54.137878999999998	54.115428000000001	0103000020E610000001000000050000003D64CA87A0324A4077853E58C60E4B403D64CA87A0324A4010E7E104A6114B40207EFE7BF0344A4010E7E104A6114B40207EFE7BF0344A4077853E58C60E4B403D64CA87A0324A4077853E58C60E4B40
4884	Аксенкино	7	69	473	53.077812000000002	53.132429999999999	54.008792	53.976672000000001	0103000020E61000000100000005000000419E5DBEF5894A409F758D9603FD4A40419E5DBEF5894A40B43BA41820014B4030815B77F3904A40B43BA41820014B4030815B77F3904A409F758D9603FD4A40419E5DBEF5894A409F758D9603FD4A40
46352	Целинный	7	69	662	60.703088999999999	60.749946000000001	50.847630000000002	50.826793000000002	0103000020E61000000100000005000000B39602D2FE594E40E7C75F5AD4694940B39602D2FE594E40E38DCC237F6C49400DE2033BFE5F4E40E38DCC237F6C49400DE2033BFE5F4E40E7C75F5AD4694940B39602D2FE594E40E7C75F5AD4694940
4809	Тобольский	7	69	662	61.145195000000001	61.169369000000003	51.448591999999998	51.433019000000002	0103000020E610000001000000050000007845F0BF95924E40F8C5A52A6DB749407845F0BF95924E40A59F70766BB9494066FA25E2AD954E40A59F70766BB9494066FA25E2AD954E40F8C5A52A6DB749407845F0BF95924E40F8C5A52A6DB74940
46060	Светлый	7	69	662	60.807805999999999	60.914256000000002	50.840133000000002	50.809874999999998	0103000020E610000001000000050000009CC1DF2F66674E408B6CE7FBA96749409CC1DF2F66674E402BA5677A896B4940FD15325706754E402BA5677A896B4940FD15325706754E408B6CE7FBA96749409CC1DF2F66674E408B6CE7FBA9674940
46660	Полевой	7	69	662	61.337254999999999	61.352859000000002	50.883006999999999	50.868889000000003	0103000020E61000000100000005000000CCB4FD2B2BAB4E40556D37C1376F4940CCB4FD2B2BAB4E40CD91955F06714940B58CD47B2AAD4E40CD91955F06714940B58CD47B2AAD4E40556D37C1376F4940CCB4FD2B2BAB4E40556D37C1376F4940
46231	Озерный	7	69	662	60.885312999999996	60.930166	51.119562999999999	51.098379999999999	0103000020E61000000100000005000000A0DCB6EF51714E404D4A41B7978C4940A0DCB6EF51714E40E46723D74D8F4940F2ECF2AD0F774E40E46723D74D8F4940F2ECF2AD0F774E404D4A41B7978C4940A0DCB6EF51714E404D4A41B7978C4940
46212	Коскуль	7	69	662	61.125396000000002	61.143030000000003	51.148421999999997	51.139375000000001	0103000020E610000001000000050000004D86E3F90C904E40A4703D0AD79149404D86E3F90C904E40E200FA7DFF924940672C9ACE4E924E40E200FA7DFF924940672C9ACE4E924E40A4703D0AD79149404D86E3F90C904E40A4703D0AD7914940
46180	Восточный	7	69	662	61.290776000000001	61.325757000000003	51.439205999999999	51.420574000000002	0103000020E61000000100000005000000193BE12538A54E4022C66B5ED5B54940193BE12538A54E407E1AF7E637B84940B7B8C667B2A94E407E1AF7E637B84940B7B8C667B2A94E4022C66B5ED5B54940193BE12538A54E4022C66B5ED5B54940
46149	Актюбинский	7	69	662	61.441611999999999	61.474795999999998	51.206389000000001	51.196592000000003	0103000020E61000000100000005000000B5C2F4BD86B84E40DF5339ED29994940B5C2F4BD86B84E4088A06AF46A9A4940C422861DC6BC4E4088A06AF46A9A4940C422861DC6BC4E40DF5339ED29994940B5C2F4BD86B84E40DF5339ED29994940
3641	Шишма	7	69	337	56.454039999999999	56.473435000000002	51.752851999999997	51.743870000000001	0103000020E61000000100000005000000B58993FB1D3A4C40DE3CD52137DF4940B58993FB1D3A4C40355D4F745DE0494011E4A084993C4C40355D4F745DE0494011E4A084993C4C40DE3CD52137DF4940B58993FB1D3A4C40DE3CD52137DF4940
1907	Черный Отрог	7	69	337	55.977134	56.048755999999997	51.894184000000003	51.871163000000003	0103000020E61000000100000005000000A3E716BA12FD4B401D3EE94482EF4940A3E716BA12FD4B40A14D0E9F74F24940ECBDF8A23D064C40A14D0E9F74F24940ECBDF8A23D064C401D3EE94482EF4940A3E716BA12FD4B401D3EE94482EF4940
45506	Черкассы	7	69	337	56.314469000000003	56.353653000000001	51.817815000000003	51.801828	0103000020E610000001000000050000008C4D2B8540284C403082C64CA2E649408C4D2B8540284C40D1967329AEE84940EF906280442D4C40D1967329AEE84940EF906280442D4C403082C64CA2E649408C4D2B8540284C403082C64CA2E64940
2775	Федоровка 1-я	7	69	337	56.164862999999997	56.186926	51.851951999999997	51.843550999999998	0103000020E6100000010000000500000004A9143B1A154C4009C1AA7AF9EB494004A9143B1A154C4082E15CC30CED4940D462F030ED174C4082E15CC30CED4940D462F030ED174C4009C1AA7AF9EB494004A9143B1A154C4009C1AA7AF9EB4940
2876	Татарский Саракташ	7	69	337	56.361936	56.370955000000002	51.844830999999999	51.834397000000003	0103000020E610000001000000050000005E9F39EB532E4C40B5705985CDEA49405E9F39EB532E4C40D0D2156C23EC4940D3A414747B2F4C40D0D2156C23EC4940D3A414747B2F4C40B5705985CDEA49405E9F39EB532E4C40B5705985CDEA4940
49570	Студенцы	7	69	337	55.850704999999998	55.868921999999998	51.871969	51.856352000000001	0103000020E6100000010000000500000097C5C4E6E3EC4B409EEE3CF19CED494097C5C4E6E3EC4B401B1021AE9CEF494030630AD638EF4B401B1021AE9CEF494030630AD638EF4B409EEE3CF19CED494097C5C4E6E3EC4B409EEE3CF19CED4940
3120	Старый Сокулак	7	69	337	56.393503000000003	56.415636999999997	52.064076	52.047744999999999	0103000020E610000001000000050000005FF0694E5E324C4015C616821C064A405FF0694E5E324C40B03A72A433084A40F700DD9733354C40B03A72A433084A40F700DD9733354C4015C616821C064A405FF0694E5E324C4015C616821C064A40
48749	Спасское	7	69	337	56.527710999999996	56.556393999999997	52.016894000000001	51.996431999999999	0103000020E61000000100000005000000A65EB7088C434C400C5872158BFF4940A65EB7088C434C40D3BF249529024A4066D828EB37474C40D3BF249529024A4066D828EB37474C400C5872158BFF4940A65EB7088C434C400C5872158BFF4940
1607	Саракташ	7	69	337	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
21774	Пречистинка	7	69	337	55.798279000000001	55.820988	51.951687999999997	51.935026999999998	0103000020E61000000100000005000000B30A9B012EE64B4041F0F8F6AEF74940B30A9B012EE64B4071FF91E9D0F949404834812216E94B4071FF91E9D0F949404834812216E94B4041F0F8F6AEF74940B30A9B012EE64B4041F0F8F6AEF74940
3064	Покурлей	7	69	337	56.485543999999997	56.497447000000001	51.903497999999999	51.892000000000003	0103000020E610000001000000050000006F62484E263E4C401904560E2DF249406F62484E263E4C402E008DD2A5F34940253FE257AC3F4C402E008DD2A5F34940253FE257AC3F4C401904560E2DF249406F62484E263E4C401904560E2DF24940
45743	Петровское	7	69	337	56.556682000000002	56.593234000000002	51.878864	51.854038000000003	0103000020E61000000100000005000000CD22145B41474C4048C5FF1D51ED4940CD22145B41474C40DDD0949D7EF0494009707A17EF4B4C40DDD0949D7EF0494009707A17EF4B4C4048C5FF1D51ED4940CD22145B41474C4048C5FF1D51ED4940
46034	Островное	7	69	337	55.915230999999999	55.943562999999997	51.666165999999997	51.649991	0103000020E6100000010000000500000087A4164A26F54B40E0D8B3E732D3494087A4164A26F54B4083DA6FED44D549409A5B21ACC6F84B4083DA6FED44D549409A5B21ACC6F84B40E0D8B3E732D3494087A4164A26F54B40E0D8B3E732D34940
56191	Новый Сокулак	7	69	337	56.297122000000002	56.338228999999998	52.101742999999999	52.086627	0103000020E610000001000000050000000876FC1708264C40ADF9F197160B4A400876FC1708264C4068CC24EA050D4A4086C77E164B2B4C4068CC24EA050D4A4086C77E164B2B4C40ADF9F197160B4A400876FC1708264C40ADF9F197160B4A40
62049	Новочеркасск	7	69	337	56.221043999999999	56.246465999999998	51.544021000000001	51.532541999999999	0103000020E610000001000000050000000F7D772B4B1C4C408BDF14562AC449400F7D772B4B1C4C402AABE97AA2C54940B8C9A8328C1F4C402AABE97AA2C54940B8C9A8328C1F4C408BDF14562AC449400F7D772B4B1C4C408BDF14562AC44940
62056	Новотафарово	7	69	337	56.638697999999998	56.654859000000002	51.623344000000003	51.612026	0103000020E61000000100000005000000A30227DBC0514C409E2633DE56CE4940A30227DBC0514C40341477BCC9CF4940E23E726BD2534C40341477BCC9CF4940E23E726BD2534C409E2633DE56CE4940A30227DBC0514C409E2633DE56CE4940
45591	Новоселки	7	69	337	56.420892000000002	56.463678999999999	51.970883999999998	51.958852999999998	0103000020E61000000100000005000000F392FFC9DF354C40F355F2B1BBFA4940F392FFC9DF354C40D61A4AED45FC4940C66B5ED5593B4C40D61A4AED45FC4940C66B5ED5593B4C40F355F2B1BBFA4940F392FFC9DF354C40F355F2B1BBFA4940
62057	Новомихайловка	7	69	337	56.471556999999997	56.508091999999998	52.162824000000001	52.152531000000003	0103000020E610000001000000050000009599D2FA5B3C4C402750C42286134A409599D2FA5B3C4C408080B56AD7144A40FBAD9D2809414C408080B56AD7144A40FBAD9D2809414C402750C42286134A409599D2FA5B3C4C402750C42286134A40
45367	Николаевка	7	69	337	55.992835999999997	56.026980999999999	51.997340999999999	51.981247000000003	0103000020E610000001000000050000004E25034015FF4B4029266F8099FD49404E25034015FF4B40DFFAB0DEA8FF4940834E081D74034C40DFFAB0DEA8FF4940834E081D74034C4029266F8099FD49404E25034015FF4B4029266F8099FD4940
45355	Никитино	7	69	337	56.140698999999998	56.158962000000002	51.865046	51.852108000000001	0103000020E610000001000000050000003ACAC16C02124C407A54FCDF11ED49403ACAC16C02124C408FC4CBD3B9EE494044A7E7DD58144C408FC4CBD3B9EE494044A7E7DD58144C407A54FCDF11ED49403ACAC16C02124C407A54FCDF11ED4940
47665	Назаровка	7	69	337	56.498040000000003	56.509357999999999	51.793495999999998	51.787736000000002	0103000020E61000000100000005000000C80C54C6BF3F4C40E1F08288D4E44940C80C54C6BF3F4C40DFC0E44691E549405DFA97A432414C40DFC0E44691E549405DFA97A432414C40E1F08288D4E44940C80C54C6BF3F4C40E1F08288D4E44940
21972	Надеждинка	7	69	337	56.144686999999998	56.163668999999999	52.117030999999997	52.089432000000002	0103000020E610000001000000050000000394861A85124C40A29BFD81720B4A400394861A85124C4020CF2EDFFA0E4A403C2F151BF3144C4020CF2EDFFA0E4A403C2F151BF3144C40A29BFD81720B4A400394861A85124C40A29BFD81720B4A40
2975	Кульчумово	7	69	337	56.273991000000002	56.291373	51.880471	51.870401000000001	0103000020E61000000100000005000000FD32182312234C40EEB3CA4C69EF4940FD32182312234C40C8091346B3F04940FDF7E0B54B254C40C8091346B3F04940FDF7E0B54B254C40EEB3CA4C69EF4940FD32182312234C40EEB3CA4C69EF4940
45986	Красногор	7	69	337	56.111314999999998	56.132658999999997	51.570535	51.561140999999999	0103000020E61000000100000005000000F146E6913F0E4C40EDB8E177D3C74940F146E6913F0E4C40971C774A07C94940914259F8FA104C40971C774A07C94940914259F8FA104C40EDB8E177D3C74940F146E6913F0E4C40EDB8E177D3C74940
3762	Кондуровка	7	69	337	56.684584000000001	56.697806999999997	51.535029999999999	51.520355000000002	0103000020E61000000100000005000000B4AED172A0574C40B1A71DFE9AC24940B4AED172A0574C407F30F0DC7BC44940BEF561BD51594C407F30F0DC7BC44940BEF561BD51594C40B1A71DFE9AC24940B4AED172A0574C40B1A71DFE9AC24940
2611	Карагузино	7	69	337	56.243231999999999	56.260229000000002	52.006728000000003	51.991484999999997	0103000020E610000001000000050000009BABE639221F4C40BEBC00FBE8FE49409BABE639221F4C40D7FB8D76DC004A40433C122F4F214C40D7FB8D76DC004A40433C122F4F214C40BEBC00FBE8FE49409BABE639221F4C40BEBC00FBE8FE4940
4066	Камышино	7	69	337	56.236513000000002	56.252915999999999	51.619396999999999	51.606068999999998	0103000020E61000000100000005000000180AD80E461E4C40490F43AB93CD4940180AD80E461E4C40C91EA16648CF49404C512E8D5F204C40C91EA16648CF49404C512E8D5F204C40490F43AB93CD4940180AD80E461E4C40490F43AB93CD4940
3499	Каировка	7	69	337	56.521512999999999	56.555486999999999	51.789357000000003	51.782705	0103000020E610000001000000050000002CB81FF0C0424C4035B56CAD2FE449402CB81FF0C0424C4031EF71A609E54940342DB1321A474C4031EF71A609E54940342DB1321A474C4035B56CAD2FE449402CB81FF0C0424C4035B56CAD2FE44940
2275	Кабанкино	7	69	337	56.000562000000002	56.018348000000003	51.933715999999997	51.919542999999997	0103000020E6100000010000000500000068CF656A12004C400322C495B3F5494068CF656A12004C403FE0810184F7494038F92D3A59024C403FE0810184F7494038F92D3A59024C400322C495B3F5494068CF656A12004C400322C495B3F54940
58180	Ильинка	7	69	337	56.035308000000001	56.046681	51.943555000000003	51.937286999999998	0103000020E61000000100000005000000C2A4F8F884044C40A4FB3905F9F74940C2A4F8F884044C40187D0569C6F849401B2C9CA4F9054C40187D0569C6F849401B2C9CA4F9054C40A4FB3905F9F74940C2A4F8F884044C40A4FB3905F9F74940
2129	Изяк-Никитино	7	69	337	56.094427000000003	56.113875	51.881031999999998	51.869050000000001	0103000020E61000000100000005000000016E162F160C4C405E4BC8073DEF4940016E162F160C4C405F5D15A8C5F049407F6ABC74930E4C405F5D15A8C5F049407F6ABC74930E4C405E4BC8073DEF4940016E162F160C4C405E4BC8073DEF4940
3730	Желтое	7	69	337	56.580640000000002	56.596854	51.640300000000003	51.624222000000003	0103000020E61000000100000005000000EE5F5969524A4C40CCB8A981E6CF4940EE5F5969524A4C407DD0B359F5D149404F3E3DB6654C4C407DD0B359F5D149404F3E3DB6654C4C40CCB8A981E6CF4940EE5F5969524A4C40CCB8A981E6CF4940
45380	Гавриловка	7	69	337	56.142468000000001	56.162177	51.952970000000001	51.923459000000001	0103000020E61000000100000005000000FF5C34643C124C4033198EE733F64940FF5C34643C124C40D908C4EBFAF94940EA944737C2144C40D908C4EBFAF94940EA944737C2144C4033198EE733F64940FF5C34643C124C4033198EE733F64940
2430	Вторая Александровка	7	69	337	55.965176999999997	55.983071000000002	52.100022000000003	52.077925999999998	0103000020E61000000100000005000000FAEC80EB8AFB4B4009C1AA7AF9094A40FAEC80EB8AFB4B40B5705985CD0C4A40B1524145D5FD4B40B5705985CD0C4A40B1524145D5FD4B4009C1AA7AF9094A40FAEC80EB8AFB4B4009C1AA7AF9094A40
48857	Воздвиженка	7	69	337	56.416634000000002	56.438670000000002	51.765602000000001	51.749239000000003	0103000020E610000001000000050000006A334E4354354C40A2F14410E7DF49406A334E4354354C4048E00F3FFFE1494040DEAB5626384C4048E00F3FFFE1494040DEAB5626384C40A2F14410E7DF49406A334E4354354C40A2F14410E7DF4940
45554	Васильевка	7	69	337	56.404552000000002	56.437358000000003	51.864829	51.85351	0103000020E6100000010000000500000005C4245CC8334C408C67D0D03FED494005C4245CC8334C40F2D077B7B2EE49406E52D158FB374C40F2D077B7B2EE49406E52D158FB374C408C67D0D03FED494005C4245CC8334C408C67D0D03FED4940
3308	Бурунча	7	69	337	56.508082999999999	56.527054999999997	52.114834999999999	52.099556999999997	0103000020E61000000100000005000000A8531EDD08414C403F8BA548BE0C4A40A8531EDD08414C40D4B7CCE9B20E4A40BD18CA8976434C40D4B7CCE9B20E4A40BD18CA8976434C403F8BA548BE0C4A40A8531EDD08414C403F8BA548BE0C4A40
2385	Биктимирово	7	69	337	56.044407999999997	56.057155000000002	51.911805000000001	51.903036999999998	0103000020E6100000010000000500000023D74D29AF054C40FA0967B796F3494023D74D29AF054C4026AAB706B6F44940C5E6E3DA50074C4026AAB706B6F44940C5E6E3DA50074C40FA0967B796F3494023D74D29AF054C40FA0967B796F34940
62051	Андреевка	7	69	337	56.633515000000003	56.649549	51.947812999999996	51.930923	0103000020E610000001000000050000004243FF0417514C400F0C207C28F749404243FF0417514C40A0DCB6EF51F949402313F06B24534C40A0DCB6EF51F949402313F06B24534C400F0C207C28F749404243FF0417514C400F0C207C28F74940
45840	Александровка	7	69	337	56.280557000000002	56.305171000000001	51.818299000000003	51.806255999999998	0103000020E61000000100000005000000FAD4B14AE9234C40151A886533E74940FAD4B14AE9234C40BDAC8905BEE849400458E4D70F274C40BDAC8905BEE849400458E4D70F274C40151A886533E74940FAD4B14AE9234C40151A886533E74940
49320	Украинка	7	69	121	55.572721000000001	55.598115999999997	52.102975999999998	52.053859000000003	0103000020E61000000100000005000000C05DF6EB4EC94B4032CC09DAE4064A40C05DF6EB4EC94B40EE224C512E0D4A406F9BA9108FCC4B40EE224C512E0D4A406F9BA9108FCC4B4032CC09DAE4064A40C05DF6EB4EC94B4032CC09DAE4064A40
49295	Тимашево	7	69	121	55.841461000000002	55.874968000000003	52.093986000000001	52.074655	0103000020E6100000010000000500000003EE79FEB4EB4B40CFBD874B8E094A4003EE79FEB4EB4B401424B6BB070C4A40F58590F3FEEF4B401424B6BB070C4A40F58590F3FEEF4B40CFBD874B8E094A4003EE79FEB4EB4B40CFBD874B8E094A40
539	Татарская Каргала	7	69	121	55.150899000000003	55.196218999999999	51.961750000000002	51.938969	0103000020E61000000100000005000000E3FF8EA850934B409A7ADD2230F84940E3FF8EA850934B40C976BE9F1AFB49404AED45B41D994B40C976BE9F1AFB49404AED45B41D994B409A7ADD2230F84940E3FF8EA850934B409A7ADD2230F84940
58187	Северный	7	69	121	55.202696000000003	55.209128	52.151277	52.147331000000001	0103000020E61000000100000005000000D88349F1F1994B40EF5701BEDB124A40D88349F1F1994B4089D1730B5D134A40C556D0B4C49A4B4089D1730B5D134A40C556D0B4C49A4B40EF5701BEDB124A40D88349F1F1994B40EF5701BEDB124A40
56102	Сакмарская	7	69	121	55.353262999999998	55.379097999999999	51.971637999999999	51.950887999999999	0103000020E6100000010000000500000084F1D3B837AD4B405514AFB2B6F9494084F1D3B837AD4B4082C64CA25EFC494050FD834886B04B4082C64CA25EFC494050FD834886B04B405514AFB2B6F9494084F1D3B837AD4B405514AFB2B6F94940
241	Сакмара	7	69	121	55.308247999999999	55.346210999999997	51.999065999999999	51.974640000000001	0103000020E610000001000000050000005987A3AB74A74B40CDAFE600C1FC49405987A3AB74A74B40D4450A65E1FF4940FA415DA450AC4B40D4450A65E1FF4940FA415DA450AC4B40CDAFE600C1FC49405987A3AB74A74B40CDAFE600C1FC4940
49380	Никольское	7	69	121	55.680177	55.714277000000003	52.035763000000003	52.022553000000002	0103000020E61000000100000005000000E63E390A10D74B409EB64604E3024A40E63E390A10D74B4014B4C9E193044A407BA4C16D6DDB4B4014B4C9E193044A407BA4C16D6DDB4B409EB64604E3024A40E63E390A10D74B409EB64604E3024A40
643	Нижние Чебеньки	7	69	121	55.526600999999999	55.540292000000001	52.007055000000001	52.003740000000001	0103000020E610000001000000050000003C855CA967C34B40F1D7648D7A004A403C855CA967C34B40FB22A12DE7004A402D25CB4928C54B40FB22A12DE7004A402D25CB4928C54B40F1D7648D7A004A403C855CA967C34B40F1D7648D7A004A40
49349	Марьевка	7	69	121	55.279752999999999	55.290596000000001	52.107605999999997	52.093234000000002	0103000020E610000001000000050000009CFA40F2CEA34B4009707A17EF0B4A409CFA40F2CEA34B403B6D8D08C60D4A40992CEE3F32A54B403B6D8D08C60D4A40992CEE3F32A54B4009707A17EF0B4A409CFA40F2CEA34B4009707A17EF0B4A40
56053	Красный Коммунар	7	69	121	54.641706999999997	55.935406999999998	53.089627999999998	51.938969	0103000020E61000000100000005000000A04E797423524B409A7ADD2230F84940A04E797423524B40276728EE788B4A4088B9A46ABBF74B40276728EE788B4A4088B9A46ABBF74B409A7ADD2230F84940A04E797423524B409A7ADD2230F84940
56113	Жилгородок	7	69	121	54.641706999999997	55.935406999999998	53.089627999999998	51.938969	0103000020E61000000100000005000000A04E797423524B409A7ADD2230F84940A04E797423524B40276728EE788B4A4088B9A46ABBF74B40276728EE788B4A4088B9A46ABBF74B409A7ADD2230F84940A04E797423524B409A7ADD2230F84940
49368	Жданово	7	69	121	55.377372999999999	55.396346000000001	52.051848999999997	52.040537999999998	0103000020E610000001000000050000005BB22AC24DB04B40641F645930054A405BB22AC24DB04B4047AAEFFCA2064A4041F33977BBB24B4047AAEFFCA2064A4041F33977BBB24B40641F645930054A405BB22AC24DB04B40641F645930054A40
56069	Егорьевка	7	69	121	55.023536	55.037585999999997	52.130018999999997	52.120890000000003	0103000020E61000000100000005000000AB23473A03834B40EC34D252790F4A40AB23473A03834B40E76D6C76A4104A40CB64389ECF844B40E76D6C76A4104A40CB64389ECF844B40EC34D252790F4A40AB23473A03834B40EC34D252790F4A40
49556	Дмитриевка	7	69	121	55.497864	55.531478999999997	52.009672000000002	51.978544999999997	0103000020E6100000010000000500000089EDEE01BABF4B4008556AF640FD494089EDEE01BABF4B40EDD79DEE3C014A4061C1FD8007C44B40EDD79DEE3C014A4061C1FD8007C44B4008556AF640FD494089EDEE01BABF4B4008556AF640FD4940
1020	Григорьевка 1-я	7	69	121	55.58766	55.602285000000002	52.122864	52.105615	0103000020E610000001000000050000006C95607138CB4B40C87BD5CA840D4A406C95607138CB4B4089EDEE01BA0F4A4089EFC4AC17CD4B4089EDEE01BA0F4A4089EFC4AC17CD4B40C87BD5CA840D4A406C95607138CB4B40C87BD5CA840D4A40
628	Верхние Чебеньки	7	69	121	55.615183999999999	55.630859999999998	52.011761999999997	52.000629000000004	0103000020E61000000100000005000000E0826C59BECE4B40F0366F9C14004A40E0826C59BECE4B40F3AACE6A81014A40622D3E05C0D04B40F3AACE6A81014A40622D3E05C0D04B40F0366F9C14004A40E0826C59BECE4B40F0366F9C14004A40
49442	Белоусовка	7	69	121	54.826203	54.854751	52.175341000000003	52.157349000000004	0103000020E61000000100000005000000B56D1805C1694B407787140324144A40B56D1805C1694B40F052EA9271164A40959C137B686D4B40F052EA9271164A40959C137B686D4B407787140324144A40B56D1805C1694B407787140324144A40
474	Беловка	7	69	121	55.424228999999997	55.458851000000003	51.983198999999999	51.968286999999997	0103000020E61000000100000005000000E481C8224DB64B402B1213D4F0FB4940E481C8224DB64B40DE3AFF76D9FD4940535E2BA1BBBA4B40DE3AFF76D9FD4940535E2BA1BBBA4B402B1213D4F0FB4940E481C8224DB64B402B1213D4F0FB4940
49339	Архиповка	7	69	121	55.421686999999999	55.431604999999998	52.059075999999997	52.040388999999998	0103000020E61000000100000005000000FD12F1D6F9B54B401F0F7D772B054A40FD12F1D6F9B54B403FFD67CD8F074A4021E527D53EB74B403FFD67CD8F074A4021E527D53EB74B401F0F7D772B054A40FD12F1D6F9B54B401F0F7D772B054A40
31490	Чистополье	7	69	334	53.815984999999998	53.830249999999999	53.139930999999997	53.122815000000003	0103000020E6100000010000000500000066834C3272E84A40A83AE466B88F4A4066834C3272E84A4029594E42E9914A4083C0CAA145EA4A4029594E42E9914A4083C0CAA145EA4A40A83AE466B88F4A4066834C3272E84A40A83AE466B88F4A40
31449	Фадеевский	7	69	334	53.959446	53.995243000000002	53.284517000000001	53.257257000000003	0103000020E6100000010000000500000096236420CFFA4A4063D520CCEDA04A4096236420CFFA4A40F913950D6BA44A405649641F64FF4A40F913950D6BA44A405649641F64FF4A4063D520CCEDA04A4096236420CFFA4A4063D520CCEDA04A40
48773	Софиевка	7	69	334	54.422517999999997	54.468268999999999	53.202513000000003	53.145381	0103000020E6100000010000000500000054FCDF1115364B40DA3A38D89B924A4054FCDF1115364B40E7012CF2EB994A40855D143DF03B4B40E7012CF2EB994A40855D143DF03B4B40DA3A38D89B924A4054FCDF1115364B40DA3A38D89B924A40
48700	Сорокино	7	69	334	53.784705000000002	53.815634000000003	53.403309	53.390158999999997	0103000020E61000000100000005000000FC00A43671E44A40BA9EE8BAF0B14A40FC00A43671E44A405B971AA19FB34A40BAC0E5B166E84A405B971AA19FB34A40BAC0E5B166E84A40BA9EE8BAF0B14A40FC00A43671E44A40BA9EE8BAF0B14A40
48695	Семеновка	7	69	334	53.999834	54.028965999999997	53.369802	53.355153999999999	0103000020E61000000100000005000000E5B67D8FFAFF4A409485AFAF75AD4A40E5B67D8FFAFF4A4069FF03AC55AF4A4014596B28B5034B4069FF03AC55AF4A4014596B28B5034B409485AFAF75AD4A40E5B67D8FFAFF4A409485AFAF75AD4A40
49103	Романовка	7	69	334	54.050454000000002	54.092666000000001	53.045535000000001	53.014367999999997	0103000020E61000000100000005000000E8F9D34675064B40F10D85CFD6814A40E8F9D34675064B4064E94317D4854A40BFB9BF7ADC0B4B4064E94317D4854A40BFB9BF7ADC0B4B40F10D85CFD6814A40E8F9D34675064B40F10D85CFD6814A40
22619	Река Дема	7	69	334	54.422671000000001	54.432848999999997	53.113757	53.099572000000002	0103000020E61000000100000005000000DBFB54151A364B4075CC79C6BE8C4A40DBFB54151A364B407558E1968F8E4A409B8D959867374B407558E1968F8E4A409B8D959867374B4075CC79C6BE8C4A40DBFB54151A364B4075CC79C6BE8C4A40
23222	Равнинный	7	69	334	54.061475999999999	54.084985000000003	53.221193	53.204276999999998	0103000020E6100000010000000500000094BE1072DE074B409929ADBF259A4A4094BE1072DE074B40548D5E0D509C4A4046D3D9C9E00A4B40548D5E0D509C4A4046D3D9C9E00A4B409929ADBF259A4A4094BE1072DE074B409929ADBF259A4A40
22961	Пономаревка	7	69	334	54.107101999999998	54.144300999999999	53.343989000000001	53.299684999999997	0103000020E6100000010000000500000008ABB184B50D4B40060DFD135CA64A4008ABB184B50D4B408597E0D407AC4A40DAE3857478124B408597E0D407AC4A40DAE3857478124B40060DFD135CA64A4008ABB184B50D4B40060DFD135CA64A40
22942	Новобогородское	7	69	334	53.921509999999998	53.937472999999997	53.183230999999999	53.156716000000003	0103000020E61000000100000005000000EE77280AF4F54A40466117450F944A40EE77280AF4F54A40834E081D74974A4006F1811DFFF74A40834E081D74974A4006F1811DFFF74A40466117450F944A40EE77280AF4F54A40466117450F944A40
22848	Нижние Кузлы	7	69	334	54.516993999999997	54.536459999999998	53.253756000000003	53.226987999999999	0103000020E61000000100000005000000361D01DC2C424B40CF4A5AF10D9D4A40361D01DC2C424B40F7949C137BA04A405BCEA5B8AA444B40F7949C137BA04A405BCEA5B8AA444B40CF4A5AF10D9D4A40361D01DC2C424B40CF4A5AF10D9D4A40
22881	Наурузово	7	69	334	54.139584999999997	54.161225000000002	53.298619000000002	53.278691999999999	0103000020E610000001000000050000008E01D9EBDD114B4013D4F02DACA34A408E01D9EBDD114B406C7BBB2539A64A4018265305A3144B406C7BBB2539A64A4018265305A3144B4013D4F02DACA34A408E01D9EBDD114B4013D4F02DACA34A40
47842	Михайловка	7	69	334	54.450384	54.458486999999998	53.312469	53.305104	0103000020E610000001000000050000002252D32EA6394B407CF0DAA50DA74A402252D32EA6394B40C501F4FBFEA74A401152B7B3AF3A4B40C501F4FBFEA74A401152B7B3AF3A4B407CF0DAA50DA74A402252D32EA6394B407CF0DAA50DA74A40
48962	Максимовка	7	69	334	54.344068	54.378976999999999	53.231721	53.198807000000002	0103000020E61000000100000005000000D1CC936B0A2C4B40A29BFD8172994A40D1CC936B0A2C4B40F165A208A99D4A40D5777E5182304B40F165A208A99D4A40D5777E5182304B40A29BFD8172994A40D1CC936B0A2C4B40A29BFD8172994A40
48633	Ключевка	7	69	334	54.388741000000003	54.428690000000003	53.368319	53.350875000000002	0103000020E61000000100000005000000A3CEDC43C2314B40F4FDD478E9AC4A40A3CEDC43C2314B406ABFB51325AF4A40A60F5D50DF364B406ABFB51325AF4A40A60F5D50DF364B40F4FDD478E9AC4A40A3CEDC43C2314B40F4FDD478E9AC4A40
22726	Кирсаново	7	69	334	54.194130000000001	54.217343	53.210721999999997	53.181460999999999	0103000020E6100000010000000500000014967840D9184B40EE3F321D3A974A4014967840D9184B401B4641F0F89A4A40DC813AE5D11B4B401B4641F0F89A4A40DC813AE5D11B4B40EE3F321D3A974A4014967840D9184B40EE3F321D3A974A40
48948	Жатва	7	69	334	54.189476999999997	54.207641000000002	53.085706999999999	53.072935000000001	0103000020E610000001000000050000000E2C47C840184B40ECDD1FEF55894A400E2C47C840184B40E6046D72F88A4A408527F4FA931A4B40E6046D72F88A4A408527F4FA931A4B40ECDD1FEF55894A400E2C47C840184B40ECDD1FEF55894A40
22688	Ефремово-Зыково	7	69	334	53.852015999999999	53.892879999999998	53.395620000000001	53.368721999999998	0103000020E6100000010000000500000099D53BDC0EED4A4069A8514832AF4A4099D53BDC0EED4A405FD218ADA3B24A4051A04FE449F24A405FD218ADA3B24A4051A04FE449F24A4069A8514832AF4A4099D53BDC0EED4A4069A8514832AF4A40
31899	Дюсметьево	7	69	334	54.320191000000001	54.343781	53.133389000000001	53.124592999999997	0103000020E610000001000000050000009DBCC804FC284B40BF27D6A9F28F4A409DBCC804FC284B40B55208E412914A403BFE0B04012C4B40B55208E412914A403BFE0B04012C4B40BF27D6A9F28F4A409DBCC804FC284B40BF27D6A9F28F4A40
23314	Грачевка	7	69	334	54.337294999999997	54.345936999999999	53.183349999999997	53.175082000000003	0103000020E610000001000000050000005A0D897B2C2B4B40240F441669964A405A0D897B2C2B4B405DDC460378974A40F9BCE2A9472C4B405DDC460378974A40F9BCE2A9472C4B40240F441669964A405A0D897B2C2B4B40240F441669964A40
45672	Воздвиженка	7	69	334	54.203733	54.260838999999997	53.178238999999998	53.149555999999997	0103000020E61000000100000005000000D80E46EC131A4B40D575A8A624934A40D80E46EC131A4B4095EF1989D0964A40BB421F2C63214B4095EF1989D0964A40BB421F2C63214B40D575A8A624934A40D80E46EC131A4B40D575A8A624934A40
20129	Верхние Кузлы	7	69	334	54.498703999999996	54.522384000000002	53.290401000000003	53.253577999999997	0103000020E6100000010000000500000033315D88D53F4B40177E703E75A04A4033315D88D53F4B40E4DC26DC2BA54A4012FA997ADD424B40E4DC26DC2BA54A4012FA997ADD424B40177E703E75A04A4033315D88D53F4B40177E703E75A04A40
48819	Борисовка	7	69	334	54.003463000000004	54.019902000000002	53.438113999999999	53.414043999999997	0103000020E610000001000000050000007FDFBF7971004B40718DCF64FFB44A407FDFBF7971004B40BAF59A1E14B84A40009013268C024B40BAF59A1E14B84A40009013268C024B40718DCF64FFB44A407FDFBF7971004B40718DCF64FFB44A40
16024	Беседино	7	69	334	53.862859	53.899977	53.232593999999999	53.213411999999998	0103000020E610000001000000050000009607E92972EE4A4077499C15519B4A409607E92972EE4A40779FE3A3C59D4A407B13437232F34A40779FE3A3C59D4A407B13437232F34A4077499C15519B4A409607E92972EE4A4077499C15519B4A40
1596	Алябьево	7	69	334	54.002052999999997	54.026316000000001	53.176921999999998	53.161316999999997	0103000020E61000000100000005000000E9EDCF4543004B40F8A41309A6944A40E9EDCF4543004B40B1F84D61A5964A4047AE9B525E034B40B1F84D61A5964A4047AE9B525E034B40F8A41309A6944A40E9EDCF4543004B40F8A41309A6944A40
56125	Алексеевка	7	69	334	54.269257000000003	54.295262999999998	53.057459000000001	53.028753999999999	0103000020E610000001000000050000000B9C6C0377224B4089D00836AE834A400B9C6C0377224B4031EE06D15A874A40035C902DCB254B4031EE06D15A874A40035C902DCB254B4089D00836AE834A400B9C6C0377224B4089D00836AE834A40
29153	Япрынцево	7	69	1861	54.306122999999999	54.328266999999997	52.058323000000001	52.044676000000003	0103000020E61000000100000005000000D6C6D8092F274B40437573F1B7054A40D6C6D8092F274B4064CDC82077074A4092AD2EA7042A4B4064CDC82077074A4092AD2EA7042A4B40437573F1B7054A40D6C6D8092F274B40437573F1B7054A40
49278	Южный	7	69	1861	54.214325000000002	54.228265999999998	51.838476	51.826366	0103000020E610000001000000050000008CDB68006F1B4B405F43705CC6E949408CDB68006F1B4B408E3D7B2E53EB4940F564FED1371D4B408E3D7B2E53EB4940F564FED1371D4B405F43705CC6E949408CDB68006F1B4B405F43705CC6E94940
56116	Шуваловский	7	69	1861	54.657831999999999	54.677540999999998	51.757998000000001	51.749367999999997	0103000020E610000001000000050000009221C7D633544B409F55664AEBDF49409221C7D633544B407A37161406E149407D59DAA9B9564B407A37161406E149407D59DAA9B9564B409F55664AEBDF49409221C7D633544B409F55664AEBDF4940
56049	Чесноковка	7	69	1861	54.068196	54.103374000000002	51.667512000000002	51.647666000000001	0103000020E61000000100000005000000E8DB82A5BA084B40965D30B8E6D24940E8DB82A5BA084B4002D8800871D54940DCA0F65B3B0D4B4002D8800871D54940DCA0F65B3B0D4B40965D30B8E6D24940E8DB82A5BA084B40965D30B8E6D24940
31254	Филипповка	7	69	1861	54.266651000000003	54.295802000000002	51.973275000000001	51.954796000000002	0103000020E610000001000000050000000D39B69E21224B40022D5DC136FA49400D39B69E21224B40D881734694FC4940B30B06D7DC254B40D881734694FC4940B30B06D7DC254B40022D5DC136FA49400D39B69E21224B40022D5DC136FA4940
48465	Татищево	7	69	1861	54.297103999999997	54.323999999999998	51.698604000000003	51.686221000000003	0103000020E6100000010000000500000061C1FD8007264B400A6AF816D6D7494061C1FD8007264B406A6D1ADB6BD94940B6F3FDD478294B406A6D1ADB6BD94940B6F3FDD478294B400A6AF816D6D7494061C1FD8007264B400A6AF816D6D74940
56084	Сырт	7	69	1861	54.514218	54.544249000000001	51.885317999999998	51.866447000000001	0103000020E61000000100000005000000DC813AE5D1414B40D15B3CBCE7EE4940DC813AE5D1414B40B247A81952F14940BBF083F3A9454B40B247A81952F14940BBF083F3A9454B40D15B3CBCE7EE4940DC813AE5D1414B40D15B3CBCE7EE4940
29639	Судаковка	7	69	1861	54.420972999999996	54.430880999999999	52.008752000000001	52.005308999999997	0103000020E61000000100000005000000DFBF7971E2354B40EEAF1EF7AD004A40DFBF7971E2354B4026E318C91E014A40E0BBCD1B27374B4026E318C91E014A40E0BBCD1B27374B40EEAF1EF7AD004A40DFBF7971E2354B40EEAF1EF7AD004A40
48288	Суворовка	7	69	1861	54.310111999999997	54.323900999999999	52.282933	52.273251999999999	0103000020E610000001000000050000006F0C01C0B1274B4086C8E9EBF9224A406F0C01C0B1274B40C6FA062637244A402312859675294B40C6FA062637244A402312859675294B4086C8E9EBF9224A406F0C01C0B1274B4086C8E9EBF9224A40
48344	Степановка	7	69	1861	54.493467000000003	54.524827000000002	52.296770000000002	52.278801000000001	0103000020E61000000100000005000000DF5339ED293F4B40CA8B4CC0AF234A40DF5339ED293F4B408B37328FFC254A406687F8872D434B408B37328FFC254A406687F8872D434B40CA8B4CC0AF234A40DF5339ED293F4B40CA8B4CC0AF234A40
48146	Сенное	7	69	1861	54.378411	54.403500999999999	52.162149999999997	52.149540999999999	0103000020E610000001000000050000002CB98AC56F304B40A034D42824134A402CB98AC56F304B40F085C954C1144A409F73B7EBA5334B40F085C954C1144A409F73B7EBA5334B40A034D42824134A402CB98AC56F304B40A034D42824134A40
47871	Садовый	7	69	1861	54.078544000000001	54.098171999999998	51.801115000000003	51.780859999999997	0103000020E6100000010000000500000005A6D3BA0D0A4B4095607138F3E3494005A6D3BA0D0A4B40E3AAB2EF8AE6494003B16CE6900C4B40E3AAB2EF8AE6494003B16CE6900C4B4095607138F3E3494005A6D3BA0D0A4B4095607138F3E34940
30659	Рычковка	7	69	1861	54.491095000000001	54.513948999999997	51.724487000000003	51.712451999999999	0103000020E61000000100000005000000541D7233DC3E4B4022FC8BA031DB4940541D7233DC3E4B4047B071FDBBDC4940EC67B114C9414B4047B071FDBBDC4940EC67B114C9414B4022FC8BA031DB4940541D7233DC3E4B4022FC8BA031DB4940
30012	Рыжковка	7	69	1861	54.469796000000002	54.490546999999999	52.206578	52.189692000000001	0103000020E6100000010000000500000054E57B46223C4B400B28D4D347184A4054E57B46223C4B405B09DD25711A4A4051137D3ECA3E4B405B09DD25711A4A4051137D3ECA3E4B400B28D4D347184A4054E57B46223C4B400B28D4D347184A40
29939	Родничное	7	69	1861	54.476156000000003	54.491697000000002	52.345629000000002	52.332517000000003	0103000020E61000000100000005000000A8E507AEF23C4B40992EC4EA8F2A4A40A8E507AEF23C4B404CC631923D2C4A404A4563EDEF3E4B404CC631923D2C4A404A4563EDEF3E4B40992EC4EA8F2A4A40A8E507AEF23C4B40992EC4EA8F2A4A40
56101	Родничий Дол	7	69	1861	54.536847000000002	54.568162000000001	51.814512999999998	51.790432000000003	0103000020E6100000010000000500000055FA0967B7444B401FDB32E02CE5494055FA0967B7444B405B9544F641E849403C6A4C88B9484B405B9544F641E849403C6A4C88B9484B401FDB32E02CE5494055FA0967B7444B401FDB32E02CE54940
29236	Радовка	7	69	1861	54.188327000000001	54.202852999999998	52.024842	52.013696000000003	0103000020E6100000010000000500000016FA60191B184B40030B60CAC0014A4016FA60191B184B409BC8CC052E034A409F724C16F7194B409BC8CC052E034A409F724C16F7194B40030B60CAC0014A4016FA60191B184B40030B60CAC0014A40
56174	Пустошь-Адамовка	7	69	1861	54.351928000000001	54.370576999999997	52.033968000000002	52.024647999999999	0103000020E61000000100000005000000FA4509FA0B2D4B40B6F468AA27034A40FA4509FA0B2D4B40268E3C1059044A402CD32F116F2F4B40268E3C1059044A402CD32F116F2F4B40B6F468AA27034A40FA4509FA0B2D4B40B6F468AA27034A40
30165	Претория	7	69	1861	54.306438	54.339523	52.254550000000002	52.233193	0103000020E610000001000000050000003620425C39274B40FC53AA44D91D4A403620425C39274B4031992A1895204A40B29E5A7D752B4B4031992A1895204A40B29E5A7D752B4B40FC53AA44D91D4A403620425C39274B40FC53AA44D91D4A40
30843	Переволоцкий	7	69	1861	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
30039	Мамалаевка	7	69	1861	54.041739999999997	54.064926	51.930017999999997	51.918698999999997	0103000020E61000000100000005000000AF777FBC57054B4017EFC7ED97F54940AF777FBC57054B407D586FD40AF749407E54C37E4F084B407D586FD40AF749407E54C37E4F084B4017EFC7ED97F54940AF777FBC57054B4017EFC7ED97F54940
30394	Кутлумбетово	7	69	1861	54.567883000000002	54.585462999999997	52.278078999999998	52.270353	0103000020E61000000100000005000000297AE063B0484B4010B056ED9A224A40297AE063B0484B40295AB91798234A404F029B73F04A4B40295AB91798234A404F029B73F04A4B4010B056ED9A224A40297AE063B0484B4010B056ED9A224A40
56167	Кунакбай	7	69	1861	54.255369000000002	54.265340000000002	52.329931000000002	52.325251999999999	0103000020E61000000100000005000000C4B46FEEAF204B40B37A87DBA1294A40C4B46FEEAF204B40E277D32D3B2A4A400B293FA9F6214B40E277D32D3B2A4A400B293FA9F6214B40B37A87DBA1294A40C4B46FEEAF204B40B37A87DBA1294A40
48170	Кубанка	7	69	1861	54.438372999999999	54.475591000000001	52.306452	52.291367000000001	0103000020E610000001000000050000008639419B1C384B401B118C834B254A408639419B1C384B409BE5B2D139274A40CFA2772AE03C4B409BE5B2D139274A40CFA2772AE03C4B401B118C834B254A408639419B1C384B401B118C834B254A40
48426	Краснополье	7	69	1861	54.434331	54.458936000000001	51.763043000000003	51.752690999999999	0103000020E61000000100000005000000CA51802898374B402C7FBE2D58E04940CA51802898374B408B389D64ABE14940817A336ABE3A4B408B389D64ABE14940817A336ABE3A4B402C7FBE2D58E04940CA51802898374B402C7FBE2D58E04940
56087	Кичкас	7	69	1861	54.386451000000001	54.422230999999996	52.324728999999998	52.310741	0103000020E61000000100000005000000D540F33977314B405F43705CC6274A40D540F33977314B40098849B890294A40BE2D58AA0B364B40098849B890294A40BE2D58AA0B364B405F43705CC6274A40D540F33977314B405F43705CC6274A40
29599	Кариновка	7	69	1861	54.523173999999997	54.542982000000002	52.027451999999997	52.011102000000001	0103000020E610000001000000050000000A0F9A5DF7424B40C97553CA6B014A400A0F9A5DF7424B40DA1A118C83034A408928266F80454B40DA1A118C83034A408928266F80454B40C97553CA6B014A400A0F9A5DF7424B40C97553CA6B014A40
48230	Капитоновка	7	69	1861	54.100929999999998	54.125427000000002	51.966866000000003	51.951444000000002	0103000020E61000000100000005000000B7973446EB0C4B40DBFCBFEAC8F94940B7973446EB0C4B40A3CEDC43C2FB49408884EFFD0D104B40A3CEDC43C2FB49408884EFFD0D104B40DBFCBFEAC8F94940B7973446EB0C4B40DBFCBFEAC8F94940
56172	Камышевка	7	69	1861	54.368564999999997	54.386999000000003	52.227682999999999	52.221950999999997	0103000020E61000000100000005000000A1B94E232D2F4B404128EFE3681C4A40A1B94E232D2F4B40766D6FB7241D4A40D84AE82E89314B40766D6FB7241D4A40D84AE82E89314B404128EFE3681C4A40A1B94E232D2F4B404128EFE3681C4A40
29505	Зубочистка Первая	7	69	1861	54.211224999999999	54.240141999999999	51.703443999999998	51.682994000000001	0103000020E610000001000000050000007E8CB96B091B4B409FAEEE586CD749407E8CB96B091B4B40A148F7730ADA4940B1321AF9BC1E4B40A148F7730ADA4940B1321AF9BC1E4B409FAEEE586CD749407E8CB96B091B4B409FAEEE586CD74940
29521	Зубочистка Вторая	7	69	1861	54.180807999999999	54.208224999999999	51.676442999999999	51.661740999999999	0103000020E61000000100000005000000766D6FB724174B400FB6D8EDB3D44940766D6FB724174B40D74D29AF95D64940D49AE61DA71A4B40D74D29AF95D64940D49AE61DA71A4B400FB6D8EDB3D44940766D6FB724174B400FB6D8EDB3D44940
29407	Донецкое	7	69	1861	54.397463999999999	54.423327	51.908627000000003	51.88832	0103000020E610000001000000050000002EABB019E0324B40FD304278B4F149402EABB019E0324B409DA1B8E34DF44940C44142942F364B409DA1B8E34DF44940C44142942F364B40FD304278B4F149402EABB019E0324B40FD304278B4F14940
48107	Долиновка	7	69	1861	54.446548	54.461782999999997	52.340232	52.328190999999997	0103000020E610000001000000050000000F0C207C28394B40B7EBA529022A4A400F0C207C28394B40BE86E0B88C2B4A40A46C91B41B3B4B40BE86E0B88C2B4A40A46C91B41B3B4B40B7EBA529022A4A400F0C207C28394B40B7EBA529022A4A40
29786	Габдрафиково	7	69	1861	54.370901000000003	54.388776999999997	52.335852000000003	52.326149999999998	0103000020E61000000100000005000000E08618AF792F4B4092CB7F48BF294A40E08618AF792F4B40EA25C632FD2A4A40EF37DA71C3314B40EA25C632FD2A4A40EF37DA71C3314B4092CB7F48BF294A40E08618AF792F4B4092CB7F48BF294A40
48366	Алмала	7	69	1861	54.604210999999999	54.616239999999998	52.273218999999997	52.266571999999996	0103000020E6100000010000000500000015713AC9564D4B40C00303081F224A4015713AC9564D4B40AAD216D7F8224A40573ECBF3E04E4B40AAD216D7F8224A40573ECBF3E04E4B40C00303081F224A4015713AC9564D4B40C00303081F224A40
30497	Алисово	7	69	1861	54.545282	54.557004999999997	52.245562999999997	52.232272000000002	0103000020E610000001000000050000007A8CF2CCCB454B4065E3C116BB1D4A407A8CF2CCCB454B40C70DBF9B6E1F4A40AF5A99F04B474B40C70DBF9B6E1F4A40AF5A99F04B474B4065E3C116BB1D4A407A8CF2CCCB454B4065E3C116BB1D4A40
47837	Адамовка	7	69	1861	54.192855000000002	54.217683999999998	52.082160999999999	52.066915999999999	0103000020E610000001000000050000005FEFFE78AF184B4021CA17B490084A405FEFFE78AF184B40DA006C40840A4A40656EBE11DD1B4B40DA006C40840A4A40656EBE11DD1B4B4021CA17B490084A405FEFFE78AF184B4021CA17B490084A40
29108	Абрамовка	7	69	1861	54.262752999999996	54.292253000000002	52.099961	52.086499000000003	0103000020E6100000010000000500000083F6EAE3A1214B4080113466120B4A4083F6EAE3A1214B400FF0A485CB0C4A403694DA8B68254B400FF0A485CB0C4A403694DA8B68254B4080113466120B4A4083F6EAE3A1214B4080113466120B4A40
47087	Шапошниково	7	69	1655	51.279905999999997	51.308239	51.707155	51.68683	0103000020E6100000010000000500000022FAB5F5D3A34940B2F4A10BEAD7494022FAB5F5D3A34940F819170E84DA4940062D246074A74940F819170E84DA4940062D246074A74940B2F4A10BEAD7494022FAB5F5D3A34940B2F4A10BEAD74940
47697	Фурманов	7	69	1655	51.612884000000001	51.627006000000002	52.070841000000001	52.060780999999999	0103000020E61000000100000005000000EF1EA0FB72CE4940ED9BFBABC7074A40EF1EA0FB72CE4940A41B615111094A40A9328CBB41D04940A41B615111094A40A9328CBB41D04940ED9BFBABC7074A40EF1EA0FB72CE4940ED9BFBABC7074A40
47245	Уральский	7	69	1655	51.636896	51.672407	51.631551999999999	51.613954999999997	0103000020E61000000100000005000000037AE1CE85D149409B1BD31396CE4940037AE1CE85D1494098DC28B2D6D04940FD4CBD6E11D6494098DC28B2D6D04940FD4CBD6E11D649409B1BD31396CE4940037AE1CE85D149409B1BD31396CE4940
47277	Ударный	7	69	1655	52.234428999999999	52.246628000000001	51.761845000000001	51.751430999999997	0103000020E61000000100000005000000F31DFCC4011E4A40AC1919E42EE04940F31DFCC4011E4A4081CF0F2384E1494092239D81911F4A4081CF0F2384E1494092239D81911F4A40AC1919E42EE04940F31DFCC4011E4A40AC1919E42EE04940
47712	Тюльпан	7	69	1655	51.557125999999997	51.591073000000002	52.203387999999997	52.190984	0103000020E610000001000000050000002AE09EE74FC749409607E92972184A402AE09EE74FC749400D33349E081A4A403946B247A8CB49400D33349E081A4A403946B247A8CB49409607E92972184A402AE09EE74FC749409607E92972184A40
27239	Теплое	7	69	1655	51.509515	51.533132000000002	51.524698000000001	51.515165000000003	0103000020E6100000010000000500000025E99AC937C149409D853DEDF0C1494025E99AC937C149406823D74D29C34940BD395CAB3DC449406823D74D29C34940BD395CAB3DC449409D853DEDF0C1494025E99AC937C149409D853DEDF0C14940
28232	Степнянка	7	69	1655	51.689017	51.701503000000002	51.930428999999997	51.92557	0103000020E61000000100000005000000ABB184B531D849405114E81379F64940ABB184B531D84940FF1F274C18F74940E085ADD9CAD94940FF1F274C18F74940E085ADD9CAD949405114E81379F64940ABB184B531D849405114E81379F64940
47615	Советское	7	69	1655	51.751520999999997	51.769100999999999	52.054395999999997	52.030127999999998	0103000020E61000000100000005000000ECA012D731E04940D158FB3BDB034A40ECA012D731E049404084B872F6064A401329CDE671E249404084B872F6064A401329CDE671E24940D158FB3BDB034A40ECA012D731E04940D158FB3BDB034A40
47455	Соболево	7	69	1655	51.708303000000001	51.740516999999997	51.953674999999997	51.930534999999999	0103000020E61000000100000005000000505436ACA9DA4940456458C51BF74940505436ACA9DA4940A301BC0512FA4940E690D442C9DE4940A301BC0512FA4940E690D442C9DE4940456458C51BF74940505436ACA9DA4940456458C51BF74940
21961	Сергиевка	7	69	1655	51.879190000000001	51.917592999999997	51.942661000000001	51.923580999999999	0103000020E61000000100000005000000317C444C89F049407E1AF7E637F64940317C444C89F049407A1B9B1DA9F84940EE04FBAF73F549407A1B9B1DA9F84940EE04FBAF73F549407E1AF7E637F64940317C444C89F049407E1AF7E637F64940
47784	Революционный	7	69	1655	52.169130000000003	52.202933999999999	52.010980000000004	51.989632999999998	0103000020E61000000100000005000000E162450DA6154A406C054D4BACFE4940E162450DA6154A407E74EACA67014A408C9FC6BDF9194A407E74EACA67014A408C9FC6BDF9194A406C054D4BACFE4940E162450DA6154A406C054D4BACFE4940
56145	Пономарев	7	69	1655	51.594127	51.614870000000003	51.890098999999999	51.878897000000002	0103000020E61000000100000005000000D655815A0CCC4940B9C667B27FF04940D655815A0CCC4940E59997C3EEF1494051A5660FB4CE4940E59997C3EEF1494051A5660FB4CE4940B9C667B27FF04940D655815A0CCC4940B9C667B27FF04940
47508	Первомайский	7	69	1655	51.628191999999999	51.666243999999999	51.913437999999999	51.89564	0103000020E61000000100000005000000EECD6F9868D04940A67EDE54A4F24940EECD6F9868D049403A765089EBF44940FF93BF7B47D549403A765089EBF44940FF93BF7B47D54940A67EDE54A4F24940EECD6F9868D04940A67EDE54A4F24940
27455	Озерное	7	69	1655	51.454835000000003	51.472189999999998	51.797027	51.784443000000003	0103000020E61000000100000005000000C009850838BA4940BF49D3A068E44940C009850838BA4940B68311FB04E64940C6BFCFB870BC4940B68311FB04E64940C6BFCFB870BC4940BF49D3A068E44940C009850838BA4940BF49D3A068E44940
56190	Новая Стройка	7	69	1655	51.920261000000004	51.946384000000002	51.941712000000003	51.933138999999997	0103000020E610000001000000050000006364C91CCBF54940A2CF471971F749406364C91CCBF549401920D1048AF8494095BA641C23F949401920D1048AF8494095BA641C23F94940A2CF471971F749406364C91CCBF54940A2CF471971F74940
49115	Мирошкино	7	69	1655	52.036413000000003	52.068339000000002	51.998966000000003	51.980159	0103000020E610000001000000050000001B13622EA9044A40A6F0A0D975FD49401B13622EA9044A4071E82D1EDEFF49404B051555BF084A4071E82D1EDEFF49404B051555BF084A40A6F0A0D975FD49401B13622EA9044A40A6F0A0D975FD4940
27535	Малый Зайкин	7	69	1655	51.223590000000002	51.249471	51.772629999999999	51.755423	0103000020E6100000010000000500000038DBDC989E9C4940B7D26BB3B1E0494038DBDC989E9C494049F4328AE5E2494074266DAAEE9F494049F4328AE5E2494074266DAAEE9F4940B7D26BB3B1E0494038DBDC989E9C4940B7D26BB3B1E04940
47594	Маевка	7	69	1655	51.529907000000001	51.545008000000003	51.857419999999998	51.848069000000002	0103000020E61000000100000005000000F37519FED3C349402FE065868DEC4940F37519FED3C34940D97745F0BFED4940790778D2C2C54940D97745F0BFED4940790778D2C2C549402FE065868DEC4940F37519FED3C349402FE065868DEC4940
56186	Лящев	7	69	1655	51.469253000000002	51.489275999999997	51.852586000000002	51.844658000000003	0103000020E610000001000000050000006346787B10BC49400327DBC01DEC49406346787B10BC49408483BD8921ED4940DD5B9198A0BE49408483BD8921ED4940DD5B9198A0BE49400327DBC01DEC49406346787B10BC49400327DBC01DEC4940
47409	Лесопитомник	7	69	1655	51.654063000000001	51.667833999999999	51.944687999999999	51.937426000000002	0103000020E6100000010000000500000007431D56B8D34940C6353E93FDF7494007431D56B8D349403A765089EBF849401494A2957BD549403A765089EBF849401494A2957BD54940C6353E93FDF7494007431D56B8D34940C6353E93FDF74940
47339	Ленинский	7	69	1655	51.369745999999999	51.408994	51.944381999999997	51.932473000000002	0103000020E61000000100000005000000D5E940D653AF494096B377465BF74940D5E940D653AF49402D776682E1F849404F2157EA59B449402D776682E1F849404F2157EA59B4494096B377465BF74940D5E940D653AF494096B377465BF74940
21779	Курлин	7	69	1655	50.966662999999997	50.984872000000003	51.808309999999999	51.797851999999999	0103000020E610000001000000050000006AA0F99CBB7B49402B86AB0320E649406AA0F99CBB7B4940CF83BBB376E74940815F2349107E4940CF83BBB376E74940815F2349107E49402B86AB0320E649406AA0F99CBB7B49402B86AB0320E64940
40384	Красное	7	69	1655	51.473177999999997	51.497118	51.586329999999997	51.571072999999998	0103000020E61000000100000005000000E597C11891BC4940765089EB18C94940E597C11891BC4940F35487DC0CCB494060200890A1BF4940F35487DC0CCB494060200890A1BF4940765089EB18C94940E597C11891BC4940765089EB18C94940
47054	Каменное	7	69	1655	51.443973999999997	51.464194999999997	51.633268000000001	51.62482	0103000020E610000001000000050000001C23D923D4B8494080F10C1AFACF49401C23D923D4B849403ACD02ED0ED14940BDFBE3BD6ABB49403ACD02ED0ED14940BDFBE3BD6ABB494080F10C1AFACF49401C23D923D4B8494080F10C1AFACF4940
47374	Зори	7	69	1655	51.410665000000002	51.419395999999999	51.983266	51.976686999999998	0103000020E61000000100000005000000514EB4AB90B44940D4B6611404FD4940514EB4AB90B4494066A208A9DBFD49405F09A4C4AEB5494066A208A9DBFD49405F09A4C4AEB54940D4B6611404FD4940514EB4AB90B44940D4B6611404FD4940
47301	Дружный	7	69	1655	52.220953999999999	52.234032999999997	51.885295999999997	51.873621	0103000020E61000000100000005000000CFF57D38481C4A40A60C1CD0D2EF4940CFF57D38481C4A40CAA31B6151F14940A69718CBF41D4A40CAA31B6151F14940A69718CBF41D4A40A60C1CD0D2EF4940CFF57D38481C4A40A60C1CD0D2EF4940
48174	Ветелки	7	69	1655	51.622559000000003	51.636096999999999	51.556638999999997	51.550517999999997	0103000020E610000001000000050000004D6A6803B0CF4940FEEDB25F77C649404D6A6803B0CF4940CD565EF23FC74940B70A62A06BD14940CD565EF23FC74940B70A62A06BD14940FEEDB25F77C649404D6A6803B0CF4940FEEDB25F77C64940
27394	Вербовый Сырт	7	69	1655	51.264786999999998	51.276671999999998	51.713579000000003	51.700636000000003	0103000020E61000000100000005000000F6B3588AE4A149403C33C170AED94940F6B3588AE4A14940630E828E56DB494005DCF3FC69A34940630E828E56DB494005DCF3FC69A349403C33C170AED94940F6B3588AE4A149403C33C170AED94940
27623	Большой Зайкин	7	69	1655	51.139606999999998	51.161095000000003	51.842526999999997	51.830880000000001	0103000020E6100000010000000500000076A565A4DE91494043739D465AEA494076A565A4DE9149409D7FBBECD7EB49404A46CEC29E9449409D7FBBECD7EB49404A46CEC29E94494043739D465AEA494076A565A4DE91494043739D465AEA4940
27783	Большепрудный	7	69	1655	52.04898	52.069228000000003	51.715850000000003	51.706468999999998	0103000020E610000001000000050000003C1405FA44064A40A45181936DDA49403C1405FA44064A40BA6B09F9A0DB4940D7FB8D76DC084A40BA6B09F9A0DB4940D7FB8D76DC084A40A45181936DDA49403C1405FA44064A40A45181936DDA4940
47643	Башкировка	7	69	1655	51.612929000000001	51.623727000000002	52.044732000000003	52.031668000000003	0103000020E610000001000000050000008FE21C7574CE4940352A70B20D044A408FE21C7574CE4940D78A36C7B9054A40EC504D49D6CF4940D78A36C7B9054A40EC504D49D6CF4940352A70B20D044A408FE21C7574CE4940352A70B20D044A40
25574	Ора	7	69	1754	58.706358999999999	58.725844000000002	51.196536000000002	51.188808000000002	0103000020E610000001000000050000001D1EC2F8695A4D40919C4CDC2A9849401D1EC2F8695A4D404B3E761728994940B9FFC874E85C4D404B3E761728994940B9FFC874E85C4D40919C4CDC2A9849401D1EC2F8695A4D40919C4CDC2A984940
24508	Джанаталап	7	69	1754	58.491256999999997	58.517560000000003	51.169865000000001	51.155760999999998	0103000020E610000001000000050000002D776682E13E4D40027FF8F9EF9349402D776682E13E4D4016DEE522BE954940E0DBF4673F424D4016DEE522BE954940E0DBF4673F424D40027FF8F9EF9349402D776682E13E4D40027FF8F9EF934940
46004	Яровой	7	69	1244	55.668149	55.688414999999999	51.746395999999997	51.736497	0103000020E6100000010000000500000074ED0BE885D54B40124DA08845DE494074ED0BE885D54B40BFEE74E789DF4940B58993FB1DD84B40BFEE74E789DF4940B58993FB1DD84B40124DA08845DE494074ED0BE885D54B40124DA08845DE4940
22071	Юный	7	69	1244	54.847008000000002	54.890585000000002	51.891615999999999	51.874321000000002	0103000020E61000000100000005000000A6B915C26A6C4B405F9A22C0E9EF4940A6B915C26A6C4B40904B1C7920F2494072A774B0FE714B40904B1C7920F2494072A774B0FE714B405F9A22C0E9EF4940A6B915C26A6C4B405F9A22C0E9EF4940
49436	Экспериментальный	7	69	1244	55.023077999999998	55.035725999999997	51.540134000000002	51.527517000000003	0103000020E61000000100000005000000E8A04B38F4824B40C28A53AD85C34940E8A04B38F4824B4095BA641C23C54940F6CE68AB92844B4095BA641C23C54940F6CE68AB92844B40C28A53AD85C34940E8A04B38F4824B40C28A53AD85C34940
26981	Чулошников	7	69	1244	55.650165000000001	55.673358999999998	51.824952000000003	51.809691000000001	0103000020E610000001000000050000007E00529B38D34B40CA6E66F4A3E749407E00529B38D34B408962F20698E94940CFBBB1A030D64B408962F20698E94940CFBBB1A030D64B40CA6E66F4A3E749407E00529B38D34B40CA6E66F4A3E74940
20738	Чкалов	7	69	1244	55.357295999999998	55.376071000000003	51.732045999999997	51.712283999999997	0103000020E61000000100000005000000ED7E15E0BBAD4B4066BB421F2CDB4940ED7E15E0BBAD4B407495EEAEB3DD4940ADFC321823B04B407495EEAEB3DD4940ADFC321823B04B4066BB421F2CDB4940ED7E15E0BBAD4B4066BB421F2CDB4940
49050	Чебеньки	7	69	1244	55.680464999999998	55.728489000000003	51.947485999999998	51.927957999999997	0103000020E610000001000000050000004C89247A19D74B40E107E753C7F649404C89247A19D74B407CB5A33847F94940753FA7203FDD4B407CB5A33847F94940753FA7203FDD4B40E107E753C7F649404C89247A19D74B40E107E753C7F64940
21867	Струково	7	69	1244	54.800618999999998	54.821002	51.999043999999998	51.983981	0103000020E6100000010000000500000032C7F2AE7A664B405471E316F3FD494032C7F2AE7A664B40ECA17DACE0FF4940ADF9F19716694B40ECA17DACE0FF4940ADF9F19716694B405471E316F3FD494032C7F2AE7A664B405471E316F3FD4940
40364	Старица	7	69	1244	54.887594	54.908614	51.746161000000001	51.730885999999998	0103000020E610000001000000050000001B1021AE9C714B40588D25AC8DDD49401B1021AE9C714B407C46223482DF49400858AB764D744B407C46223482DF49400858AB764D744B40588D25AC8DDD49401B1021AE9C714B40588D25AC8DDD4940
22959	Светлогорка	7	69	1244	55.080174999999997	55.100306000000003	51.502760000000002	51.491961000000003	0103000020E61000000100000005000000787AA52C438A4B4028F4FA93F8BE4940787AA52C438A4B4055DE8E705AC04940DACBB6D3D68C4B4055DE8E705AC04940DACBB6D3D68C4B4028F4FA93F8BE4940787AA52C438A4B4028F4FA93F8BE4940
15513	Самородово	7	69	1244	55.478245000000001	55.534092999999999	51.729551999999998	51.717044000000001	0103000020E61000000100000005000000DE3CD52137BD4B4082E50819C8DB4940DE3CD52137BD4B409E5DBEF561DD4940E202D0285DC44B409E5DBEF561DD4940E202D0285DC44B4082E50819C8DB4940DE3CD52137BD4B4082E50819C8DB4940
48764	Пугачевский	7	69	1244	55.353414999999998	55.382511999999998	51.489572000000003	51.472700000000003	0103000020E610000001000000050000003A75E5B33CAD4B40DC68006F81BC49403A75E5B33CAD4B40C784984BAABE4940ED293927F6B04B40C784984BAABE4940ED293927F6B04B40DC68006F81BC49403A75E5B33CAD4B40DC68006F81BC4940
21311	Приуральский	7	69	1244	55.634911000000002	55.662678	51.762251999999997	51.747689000000001	0103000020E61000000100000005000000726F7EC344D14B401B4AED45B4DF4940726F7EC344D14B40C1A7397991E14940ACE3F8A1D2D44B40C1A7397991E14940ACE3F8A1D2D44B401B4AED45B4DF4940726F7EC344D14B401B4AED45B4DF4940
47531	Первомайский	7	69	1244	54.966214000000001	55.030434999999997	51.548659000000001	51.515439999999998	0103000020E61000000100000005000000FB777DE6AC7B4B406E861BF0F9C14940FB777DE6AC7B4B40FAD346753AC64940AED3484BE5834B40FAD346753AC64940AED3484BE5834B406E861BF0F9C14940FB777DE6AC7B4B406E861BF0F9C14940
56092	Паника	7	69	1244	55.251969000000003	55.277624000000003	51.571370000000002	51.558425	0103000020E610000001000000050000008C4D2B8540A04B4068226C787AC749408C4D2B8540A04B4030F5F3A622C94940D84AE82E89A34B4030F5F3A622C94940D84AE82E89A34B4068226C787AC749408C4D2B8540A04B4068226C787AC74940
48324	Никольское	7	69	1244	54.492846999999998	54.530135999999999	51.684958999999999	51.668607000000002	0103000020E610000001000000050000004277499C153F4B40377007EA94D549404277499C153F4B40E90C8CBCACD749405437177FDB434B40E90C8CBCACD749405437177FDB434B40377007EA94D549404277499C153F4B40377007EA94D54940
22547	Нижняя Павловка	7	69	1244	54.776319999999998	54.827533000000003	51.740679999999998	51.703482999999999	0103000020E61000000100000005000000889D29745E634B405F251FBB0BDA4940889D29745E634B4090662C9ACEDE49402EAEF199EC694B4090662C9ACEDE49402EAEF199EC694B405F251FBB0BDA4940889D29745E634B405F251FBB0BDA4940
21125	Нежинка	7	69	1244	55.351815999999999	55.386383000000002	51.774535999999998	51.757742	0103000020E61000000100000005000000D21A834E08AD4B401F679AB0FDE04940D21A834E08AD4B408EC9E2FE23E349407D5D86FF74B14B408EC9E2FE23E349407D5D86FF74B14B401F679AB0FDE04940D21A834E08AD4B401F679AB0FDE04940
21475	Мирный Путь	7	69	1244	55.873100000000001	55.887112999999999	51.785936	51.769486000000001	0103000020E610000001000000050000009D11A5BDC1EF4B406C5D6A847EE249409D11A5BDC1EF4B40E15F048D99E44940A06D35EB8CF14B40E15F048D99E44940A06D35EB8CF14B406C5D6A847EE249409D11A5BDC1EF4B406C5D6A847EE24940
20635	Караванный	7	69	1244	55.620016999999997	55.658735	51.708880000000001	51.689453999999998	0103000020E6100000010000000500000065FB90B75CCF4B40560C570740D8494065FB90B75CCF4B40ED647094BCDA494083DDB06D51D44B40ED647094BCDA494083DDB06D51D44B40560C570740D8494065FB90B75CCF4B40560C570740D84940
21247	Каменноозерное	7	69	1244	55.553829	55.575263	51.781734999999998	51.767892000000003	0103000020E61000000100000005000000C74961DEE3C64B40166EF9484AE24940C74961DEE3C64B40BC9179E40FE44940A7CCCD37A2C94B40BC9179E40FE44940A7CCCD37A2C94B40166EF9484AE24940C74961DEE3C64B40166EF9484AE24940
22146	Зубаревка	7	69	1244	54.646647999999999	54.683317000000002	51.999299000000001	51.987631	0103000020E610000001000000050000000C03965CC5524B4005C24EB16AFE49400C03965CC5524B4077F69507E9FF494082E673EE76574B4077F69507E9FF494082E673EE76574B4005C24EB16AFE49400C03965CC5524B4005C24EB16AFE4940
20960	Джеланды	7	69	1244	55.474328	55.489303	51.515366999999998	51.502972999999997	0103000020E61000000100000005000000DEC9A7C7B6BC4B40B0E2546B61C04940DEC9A7C7B6BC4B400438BD8BF7C14940D76A0F7BA1BE4B400438BD8BF7C14940D76A0F7BA1BE4B40B0E2546B61C04940DEC9A7C7B6BC4B40B0E2546B61C04940
22687	Дедуровка	7	69	1244	54.599639000000003	54.643737000000002	51.695076	51.673645	0103000020E61000000100000005000000FD3383F8C04C4B40950ED6FF39D64940FD3383F8C04C4B40041E1840F8D84940D21C59F965524B40041E1840F8D84940D21C59F965524B40950ED6FF39D64940FD3383F8C04C4B40950ED6FF39D64940
56047	Городище	7	69	1244	54.361207999999998	54.409412000000003	51.649124999999998	51.626677000000001	0103000020E61000000100000005000000DB8651103C2E4B40E413B2F336D04940DB8651103C2E4B400C022B8716D34940844BC79C67344B400C022B8716D34940844BC79C67344B40E413B2F336D04940DB8651103C2E4B40E413B2F336D04940
48321	Горный	7	69	1244	54.904105000000001	54.922367999999999	51.916609999999999	51.899203	0103000020E6100000010000000500000036936FB6B9734B4088BB7A1519F3494036936FB6B9734B40E197FA7953F549403F70952710764B40E197FA7953F549403F70952710764B4088BB7A1519F3494036936FB6B9734B4088BB7A1519F34940
48981	Вязовка	7	69	1244	55.779997999999999	55.803623999999999	51.711905000000002	51.701400999999997	0103000020E61000000100000005000000037976F9D6E34B40DB300A82C7D94940037976F9D6E34B40F06DFAB31FDB4940EE23B726DDE64B40F06DFAB31FDB4940EE23B726DDE64B40DB300A82C7D94940037976F9D6E34B40DB300A82C7D94940
21661	Былинный	7	69	1244	55.553946000000003	55.573709000000001	51.899813999999999	51.885980000000004	0103000020E6100000010000000500000001E0D8B3E7C64B407E74EACA67F1494001E0D8B3E7C64B40D13DEB1A2DF34940DF35E84B6FC94B40D13DEB1A2DF34940DF35E84B6FC94B407E74EACA67F1494001E0D8B3E7C64B407E74EACA67F14940
22162	Бродецкое	7	69	1244	54.643619999999999	54.681727000000002	51.958736999999999	51.946308999999999	0103000020E610000001000000050000009886E12362524B408A743FA720F949409886E12362524B408A3BDEE4B7FA49406DE690D442574B408A3BDEE4B7FA49406DE690D442574B408A743FA720F949409886E12362524B408A743FA720F94940
20778	Благословенка	7	69	1244	55.311599000000001	55.336472999999998	51.720844	51.709705999999997	0103000020E61000000100000005000000B03BDD79E2A74B4032E36DA5D7DA4940B03BDD79E2A74B4048C2BE9D44DC4940567E198C11AB4B4048C2BE9D44DC4940567E198C11AB4B4032E36DA5D7DA4940B03BDD79E2A74B4032E36DA5D7DA4940
48719	Береговой	7	69	1244	55.719658000000003	55.758339999999997	51.676085999999998	51.663747000000001	0103000020E610000001000000050000000327DBC01DDC4B40B8E864A9F5D449400327DBC01DDC4B4048A46DFC89D64940D39FFD4811E14B4048A46DFC89D64940D39FFD4811E14B40B8E864A9F5D449400327DBC01DDC4B40B8E864A9F5D44940
21683	Бакалка	7	69	1244	55.759121	55.773170999999998	51.855885000000001	51.846527999999999	0103000020E61000000100000005000000795A7EE02AE14B40FB928D075BEC4940795A7EE02AE14B408811C2A38DED4940999B6F44F7E24B408811C2A38DED4940999B6F44F7E24B40FB928D075BEC4940795A7EE02AE14B40FB928D075BEC4940
48852	Аэропорт	7	69	1244	55.311957999999997	55.317878	51.763739999999999	51.759163000000001	0103000020E61000000100000005000000DFDC5F3DEEA74B40A8AAD0402CE14940DFDC5F3DEEA74B40D252793BC2E14940170FEF39B0A84B40D252793BC2E14940170FEF39B0A84B40A8AAD0402CE14940DFDC5F3DEEA74B40A8AAD0402CE14940
58173	Орск	7	69	7402	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
12520	Шестимирский	7	69	1056	55.129365999999997	55.140883000000002	52.358275999999996	52.348588999999997	0103000020E610000001000000050000006F9BA9108F904B40675F79909E2C4A406F9BA9108F904B408978EBFCDB2D4A40FCC7427408924B408978EBFCDB2D4A40FCC7427408924B40675F79909E2C4A406F9BA9108F904B40675F79909E2C4A40
45447	Успенка	7	69	1056	54.954473	54.974784	52.536504000000001	52.519058999999999	0103000020E610000001000000050000001FF5D72B2C7A4B40E4D87A8670424A401FF5D72B2C7A4B402B16BF29AC444A400055DCB8C57C4B402B16BF29AC444A400055DCB8C57C4B40E4D87A8670424A401FF5D72B2C7A4B40E4D87A8670424A40
12698	Уранбаш	7	69	1056	54.907321000000003	54.951310999999997	52.230986999999999	52.208443000000003	0103000020E61000000100000005000000ADFC321823744B40420A9E42AE1A4A40ADFC321823744B408C6665FB901D4A409BA9108FC4794B408C6665FB901D4A409BA9108FC4794B40420A9E42AE1A4A40ADFC321823744B40420A9E42AE1A4A40
11759	Салмыш	7	69	1056	55.290937	55.296947000000003	52.207178999999996	52.202565	0103000020E610000001000000050000002219726C3DA54B40392861A6ED194A402219726C3DA54B4080B56AD7841A4A409AD2FA5B02A64B4080B56AD7841A4A409AD2FA5B02A64B40392861A6ED194A402219726C3DA54B40392861A6ED194A40
45457	Российский	7	69	1056	54.972754000000002	54.995823000000001	52.416262000000003	52.398611000000002	0103000020E61000000100000005000000CF86FC33837C4B40B6696CAF05334A40CF86FC33837C4B40A648BE1248354A4064CDC820777F4B40A648BE1248354A4064CDC820777F4B40B6696CAF05334A40CF86FC33837C4B40B6696CAF05334A40
12656	Портнов	7	69	1056	54.89911	54.917803999999997	52.263556999999999	52.248381000000002	0103000020E61000000100000005000000D7C0560916734B4051F9D7F2CA1F4A40D7C0560916734B40E1D05B3CBC214A40A911FA997A754B40E1D05B3CBC214A40A911FA997A754B4051F9D7F2CA1F4A40D7C0560916734B4051F9D7F2CA1F4A40
40277	Орск	7	69	1056	54.657913000000001	55.892431000000002	52.675196999999997	52.103900000000003	0103000020E610000001000000050000007F4E417E36544B40F7065F984C0D4A407F4E417E36544B40BCADF4DA6C564A40E277D32D3BF24B40BCADF4DA6C564A40E277D32D3BF24B40F7065F984C0D4A407F4E417E36544B40F7065F984C0D4A40
46406	Октябрьское	7	69	1056	55.468677999999997	55.522379000000001	52.363720000000001	52.336765999999997	0103000020E61000000100000005000000662D05A4FDBB4B40CE33F6251B2B4A40662D05A4FDBB4B40587380608E2E4A40008FA850DDC24B40587380608E2E4A40008FA850DDC24B40CE33F6251B2B4A40662D05A4FDBB4B40CE33F6251B2B4A40
49546	Новотроицкое	7	69	1056	55.296255000000002	55.322719999999997	52.382947000000001	52.356020999999998	0103000020E61000000100000005000000642310AFEBA54B4038D89B18922D4A40642310AFEBA54B40F88C446804314A40EFE192E34EA94B40F88C446804314A40EFE192E34EA94B4038D89B18922D4A40642310AFEBA54B4038D89B18922D4A40
9273	Новоникитино	7	69	1056	55.560540000000003	55.583751999999997	52.374250000000004	52.355443000000001	0103000020E61000000100000005000000C80C54C6BFC74B40CB4BFE277F2D4A40C80C54C6BFC74B4096438B6CE72F4A40BF7CB262B8CA4B4096438B6CE72F4A40BF7CB262B8CA4B40CB4BFE277F2D4A40C80C54C6BFC74B40CB4BFE277F2D4A40
11286	Новобиккулово	7	69	1056	55.337209999999999	55.352696999999999	52.283473000000001	52.271768999999999	0103000020E610000001000000050000002CF180B229AB4B4087889B53C9224A402CF180B229AB4B404626E0D748244A40DB32E02C25AD4B404626E0D748244A40DB32E02C25AD4B4087889B53C9224A402CF180B229AB4B4087889B53C9224A40
11976	Нижний Гумбет	7	69	1056	55.418525000000002	55.439438000000003	52.487056000000003	52.449052999999999	0103000020E610000001000000050000007AC7293A92B54B40D99596917A394A407AC7293A92B54B4009A9DBD9573E4A40514F1F813FB84B4009A9DBD9573E4A40514F1F813FB84B40D99596917A394A407AC7293A92B54B40D99596917A394A40
9640	Междугорный	7	69	1056	55.372521999999996	55.381639999999997	52.416482000000002	52.402825	0103000020E610000001000000050000002F8507CDAEAF4B406F8104C58F334A402F8507CDAEAF4B40B4AF3C484F354A40376C5B94D9B04B40B4AF3C484F354A40376C5B94D9B04B406F8104C58F334A402F8507CDAEAF4B406F8104C58F334A40
56065	Марьевка	7	69	1056	55.264454999999998	55.290999999999997	52.255597999999999	52.232118	0103000020E61000000100000005000000C02154A9D9A14B400E68E90AB61D4A40C02154A9D9A14B4025766D6FB7204A406891ED7C3FA54B4025766D6FB7204A406891ED7C3FA54B400E68E90AB61D4A40C02154A9D9A14B400E68E90AB61D4A40
56133	Кузьминовка	7	69	1056	55.403962999999997	55.436033000000002	52.661811999999998	52.644581000000002	0103000020E61000000100000005000000A3E5400FB5B34B40BE4F55A181524A40A3E5400FB5B34B40D80C7041B6544A40077DE9EDCFB74B40D80C7041B6544A40077DE9EDCFB74B40BE4F55A181524A40A3E5400FB5B34B40BE4F55A181524A40
49388	Краснооктябрьский	7	69	1056	55.526772000000001	55.540560999999997	52.338917000000002	52.326594999999998	0103000020E610000001000000050000006939D0436DC34B40C0046EDDCD294A406939D0436DC34B407B87DBA1612B4A401C3F541A31C54B407B87DBA1612B4A401C3F541A31C54B40C0046EDDCD294A406939D0436DC34B40C0046EDDCD294A40
45509	Комиссарово	7	69	1056	54.803556	54.831108	52.293846000000002	52.281075999999999	0103000020E6100000010000000500000096404AECDA664B4062D8614CFA234A4096404AECDA664B40BC07E8BE9C254A40D4B837BF616A4B40BC07E8BE9C254A40D4B837BF616A4B4062D8614CFA234A4096404AECDA664B4062D8614CFA234A40
49521	Каменка	7	69	1056	55.200270000000003	55.235672999999998	52.308053999999998	52.297376	0103000020E610000001000000050000005A2F8672A2994B40C24EB16A10264A405A2F8672A2994B4074B33F506E274A406DC669882A9E4B4074B33F506E274A406DC669882A9E4B40C24EB16A10264A405A2F8672A2994B40C24EB16A10264A40
11630	Имангулово 2-е	7	69	1056	55.308157999999999	55.325657	52.217471000000003	52.204695999999998	0103000020E610000001000000050000001900AAB871A74B409ECF807A331A4A401900AAB871A74B400A6AF816D61B4A40535BEA20AFA94B400A6AF816D61B4A40535BEA20AFA94B409ECF807A331A4A401900AAB871A74B409ECF807A331A4A40
11699	Имангулово 1-е	7	69	1056	55.308157999999999	55.325657	52.217471000000003	52.204695999999998	0103000020E610000001000000050000001900AAB871A74B409ECF807A331A4A401900AAB871A74B400A6AF816D61B4A40535BEA20AFA94B400A6AF816D61B4A40535BEA20AFA94B409ECF807A331A4A401900AAB871A74B409ECF807A331A4A40
49409	Зеленый Дол	7	69	1056	55.6798	55.703344999999999	52.263821999999998	52.258243999999998	0103000020E6100000010000000500000010E9B7AF03D74B40B131AF230E214A4010E9B7AF03D74B408FFB56EBC4214A400E677E3507DA4B408FFB56EBC4214A400E677E3507DA4B40B131AF230E214A4010E9B7AF03D74B40B131AF230E214A40
23946	Взгорье	7	69	1056	55.549543999999997	55.577939999999998	52.226033000000001	52.216344999999997	0103000020E6100000010000000500000044DB317557C64B4099D36531B11B4A4044DB317557C64B408C683BA6EE1C4A406E861BF0F9C94B408C683BA6EE1C4A406E861BF0F9C94B4099D36531B11B4A4044DB317557C64B4099D36531B11B4A40
12098	Верхний Гумбет	7	69	1056	55.362309000000003	55.381478999999999	52.567250000000001	52.555796999999998	0103000020E61000000100000005000000F3052D2460AE4B40821B295B24474A40F3052D2460AE4B40F853E3A59B484A402E8ECA4DD4B04B40F853E3A59B484A402E8ECA4DD4B04B40821B295B24474A40F3052D2460AE4B40821B295B24474A40
45492	Васильевка	7	69	1056	54.972368000000003	54.998167000000002	52.335543999999999	52.306573	0103000020E61000000100000005000000A6D6FB8D767C4B40166BB8C83D274A40A6D6FB8D767C4B403C2F151BF32A4A402579AEEFC37F4B403C2F151BF32A4A402579AEEFC37F4B40166BB8C83D274A40A6D6FB8D767C4B40166BB8C83D274A40
45420	Буланово	7	69	1056	55.142257000000001	55.179797999999998	52.465998999999996	52.441724999999998	0103000020E610000001000000050000004450357A35924B40AD69DE718A384A404450357A35924B40FE7BF0DAA53B4A406FF1F09E03974B40FE7BF0DAA53B4A406FF1F09E03974B40AD69DE718A384A404450357A35924B40AD69DE718A384A40
49440	Броды	7	69	1056	55.405050000000003	55.433706999999998	52.196207000000001	52.182535999999999	0103000020E61000000100000005000000569FABADD8B34B40DC2BF3565D174A40569FABADD8B34B40861F9C4F1D194A40EC8502B683B74B40861F9C4F1D194A40EC8502B683B74B40DC2BF3565D174A40569FABADD8B34B40DC2BF3565D174A40
49525	Биккулово	7	69	1056	55.299211	55.321165999999998	52.324751999999997	52.311340999999999	0103000020E610000001000000050000003ECDC98B4CA64B40B4739A05DA274A403ECDC98B4CA64B40C1A7397991294A40274BADF71BA94B40C1A7397991294A40274BADF71BA94B40B4739A05DA274A403ECDC98B4CA64B40B4739A05DA274A40
45424	Белозерка	7	69	1056	55.069943000000002	55.099237000000002	52.533639000000001	52.504792999999999	0103000020E61000000100000005000000C5CA68E4F3884B40F71F990E9D404A40C5CA68E4F3884B40616F62484E444A40CEC64ACCB38C4B40616F62484E444A40CEC64ACCB38C4B40F71F990E9D404A40C5CA68E4F3884B40F71F990E9D404A40
12779	Анатольевка	7	69	1056	55.334451999999999	55.346452999999997	52.153343	52.138244999999998	0103000020E61000000100000005000000780AB952CFAA4B40F2EA1C03B2114A40780AB952CFAA4B40070951BEA0134A40F04C689258AC4B40070951BEA0134A40F04C689258AC4B40F2EA1C03B2114A40780AB952CFAA4B40F2EA1C03B2114A40
10788	Хабарное	7	69	1148	58.221826	58.247723999999998	51.157184000000001	51.142867000000003	0103000020E6100000010000000500000085B35BCB641C4D40BD5642774992494085B35BCB641C4D402CBAF59A1E9449409737876BB51F4D402CBAF59A1E9449409737876BB51F4D40BD5642774992494085B35BCB641C4D40BD56427749924940
59502	Пригорное	7	69	1148	58.099682000000001	58.430576000000002	51.337530000000001	51.068007000000001	0103000020E61000000100000005000000FCFF3861C20C4D4015731074B4884940FCFF3861C20C4D409EB5DB2E34AB4940A438471D1D374D409EB5DB2E34AB4940A438471D1D374D4015731074B4884940FCFF3861C20C4D4015731074B4884940
49249	Новоникольск	7	69	1148	58.253985	58.267378999999998	51.305103000000003	51.288376	0103000020E6100000010000000500000058569A9482204D40C4793881E9A4494058569A9482204D40AC74779D0DA749408F519E7939224D40AC74779D0DA749408F519E7939224D40C4793881E9A4494058569A9482204D40C4793881E9A44940
10865	Аккермановка	7	69	1148	58.200383000000002	58.238058000000002	51.205216	51.176991000000001	0103000020E6100000010000000500000052D66F26A6194D40DA571EA4A796494052D66F26A6194D40D74E9484449A49408D463EAF781E4D40D74E9484449A49408D463EAF781E4D40DA571EA4A796494052D66F26A6194D40DA571EA4A7964940
48493	Ясногорский	7	69	891	54.011277999999997	54.053804999999997	52.584659000000002	52.562131999999998	0103000020E610000001000000050000000795B88E71014B407D04FEF0F3474A400795B88E71014B40F2272A1BD64A4A403EAE0D15E3064B40F2272A1BD64A4A403EAE0D15E3064B407D04FEF0F3474A400795B88E71014B407D04FEF0F3474A40
47849	Черепаново	7	69	891	53.596004999999998	53.615777000000001	51.961939000000001	51.946508999999999	0103000020E6100000010000000500000051A04FE449CC4A40512FF83427F9494051A04FE449CC4A409CDF30D120FB49408350DEC7D1CE4A409CDF30D120FB49408350DEC7D1CE4A40512FF83427F9494051A04FE449CC4A40512FF83427F94940
9265	Хуторка	7	69	891	53.793014999999997	53.811869999999999	52.214215000000003	52.192501999999998	0103000020E61000000100000005000000641EF98381E54A401135D1E7A3184A40641EF98381E54A4005A8A9656B1B4A40404D2D5BEBE74A4005A8A9656B1B4A40404D2D5BEBE74A401135D1E7A3184A40641EF98381E54A401135D1E7A3184A40
8859	Хлебовка	7	69	891	53.963586999999997	53.980933	52.461060000000003	52.453498000000003	0103000020E61000000100000005000000E5EC9DD156FB4A409566F3380C3A4A40E5EC9DD156FB4A4034BF9A03043B4A40994869368FFD4A4034BF9A03043B4A40994869368FFD4A409566F3380C3A4A40E5EC9DD156FB4A409566F3380C3A4A40
9327	Сузаново	7	69	891	53.797578000000001	53.81682	52.132474000000002	52.122200999999997	0103000020E610000001000000050000002A01310917E64A40ED444948A40F4A402A01310917E64A4000C974E8F4104A40FF5BC98E8DE84A4000C974E8F4104A40FF5BC98E8DE84A40ED444948A40F4A402A01310917E64A40ED444948A40F4A40
8552	Судьбодаровка	7	69	891	54.062581000000002	54.098756000000002	52.342840000000002	52.328395	0103000020E61000000100000005000000ED2C7AA702084B40C095ECD8082A4A40ED2C7AA702084B405DE15D2EE22B4A4053245F09A40C4B405DE15D2EE22B4A4053245F09A40C4B40C095ECD8082A4A40ED2C7AA702084B40C095ECD8082A4A40
47900	Старая Белогорка	7	69	891	53.227497999999997	53.253945000000002	52.100039000000002	52.078502	0103000020E61000000100000005000000E4F38AA71E9D4A40D655815A0C0A4A40E4F38AA71E9D4A408BA9F413CE0C4A40CAFD0E4581A04A408BA9F413CE0C4A40CAFD0E4581A04A40D655815A0C0A4A40E4F38AA71E9D4A40D655815A0C0A4A40
8921	Среднеуранский	7	69	891	53.949789000000003	53.973522000000003	52.404555999999999	52.39228	0103000020E61000000100000005000000DF8C9AAF92F94A40FC6F253B36324A40DF8C9AAF92F94A4046B3B27DC8334A40E0F76F5E9CFC4A4046B3B27DC8334A40E0F76F5E9CFC4A40FC6F253B36324A40DF8C9AAF92F94A40FC6F253B36324A40
7872	Рыбкино	7	69	891	53.950876000000001	53.977223000000002	51.865290999999999	51.843668000000001	0103000020E610000001000000050000009146054EB6F94A4043572250FDEB49409146054EB6F94A40F64201DBC1EE494013F3ACA415FD4A40F64201DBC1EE494013F3ACA415FD4A4043572250FDEB49409146054EB6F94A4043572250FDEB4940
56165	Родниковое Озеро	7	69	891	53.524652000000003	53.532539	52.178356000000001	52.170994	0103000020E61000000100000005000000F8E3F6CB27C34A40F7E7A221E3154A40F8E3F6CB27C34A40CF85915ED4164A401A6CEA3C2AC44A40CF85915ED4164A401A6CEA3C2AC44A40F7E7A221E3154A40F8E3F6CB27C34A40F7E7A221E3154A40
48047	Ржавка	7	69	891	53.484309000000003	53.509830000000001	51.839827999999997	51.827807	0103000020E6100000010000000500000049145AD6FDBD4A402F336C94F5E9494049145AD6FDBD4A40EE21E17B7FEB49408542041C42C14A40EE21E17B7FEB49408542041C42C14A402F336C94F5E9494049145AD6FDBD4A402F336C94F5E94940
56198	Приуранный	7	69	891	54.206904000000002	54.217306999999998	52.321190000000001	52.314374999999998	0103000020E61000000100000005000000AFB48CD47B1A4B400AD7A3703D284A40AFB48CD47B1A4B40B0E600C11C294A408F183DB7D01B4B40B0E600C11C294A408F183DB7D01B4B400AD7A3703D284A40AFB48CD47B1A4B400AD7A3703D284A40
48507	Привольный	7	69	891	53.829009999999997	53.841973000000003	52.627595999999997	52.620171999999997	0103000020E610000001000000050000004A07EBFF1CEA4A408CF2CCCB614F4A404A07EBFF1CEA4A40DA8CD31055504A40B98E71C5C5EB4A40DA8CD31055504A40B98E71C5C5EB4A408CF2CCCB614F4A404A07EBFF1CEA4A408CF2CCCB614F4A40
56075	Покровка	7	69	891	53.849321000000003	53.894038999999999	51.999482	51.977829999999997	0103000020E610000001000000050000002C67EF8CB6EC4A401A868F8829FD49402C67EF8CB6EC4A406878B306EFFF49409D2CB5DE6FF24A406878B306EFFF49409D2CB5DE6FF24A401A868F8829FD49402C67EF8CB6EC4A401A868F8829FD4940
8131	Платовка	7	69	891	53.889448999999999	53.920377999999999	51.980575000000002	51.965257000000001	0103000020E61000000100000005000000DE3AFF76D9F14A40179E978A8DFB4940DE3AFF76D9F14A403A234A7B83FD49409CFA40F2CEF54A403A234A7B83FD49409CFA40F2CEF54A40179E978A8DFB4940DE3AFF76D9F14A40179E978A8DFB4940
6849	Новосергиевка	7	69	891	53.62838	53.678218999999999	52.113396999999999	52.059607	0103000020E61000000100000005000000F1BA7EC16ED04A406CCEC133A1074A40F1BA7EC16ED04A40753BFBCA830E4A404E4354E1CFD64A40753BFBCA830E4A404E4354E1CFD64A406CCEC133A1074A40F1BA7EC16ED04A406CCEC133A1074A40
7387	Новородниковка	7	69	891	53.276690000000002	53.298195999999997	51.955061999999998	51.945343000000001	0103000020E61000000100000005000000AC90F2936AA34A405340DAFF00F94940AC90F2936AA34A4080D3BB783FFA494025E659492BA64A4080D3BB783FFA494025E659492BA64A405340DAFF00F94940AC90F2936AA34A405340DAFF00F94940
7429	Новокинделька	7	69	891	53.386814000000001	53.400109999999998	52.006179000000003	51.988241000000002	0103000020E6100000010000000500000046D1031F83B14A407EC85BAE7EFE494046D1031F83B14A4004763579CA004A40BA66F2CD36B34A4004763579CA004A40BA66F2CD36B34A407EC85BAE7EFE494046D1031F83B14A407EC85BAE7EFE4940
8465	Нижний Кунакбай	7	69	891	54.140582000000002	54.150868000000003	52.345613	52.340418999999997	0103000020E6100000010000000500000001344A97FE114B40F0F78BD9922B4A4001344A97FE114B404609FA0B3D2C4A40A80183A44F134B404609FA0B3D2C4A40A80183A44F134B40F0F78BD9922B4A4001344A97FE114B40F0F78BD9922B4A40
48614	Нестеровка	7	69	891	53.687615000000001	53.727510000000002	52.438535000000002	52.421743999999997	0103000020E61000000100000005000000999EB0C403D84A4061A417B5FB354A40999EB0C403D84A40609335EA21384A40A9C1340C1FDD4A40609335EA21384A40A9C1340C1FDD4A4061A417B5FB354A40999EB0C403D84A4061A417B5FB354A40
7603	Мустаево	7	69	891	53.370680999999998	53.419674999999998	51.81664	51.800831000000002	0103000020E61000000100000005000000D11F9A7972AF4A40BE4F55A181E64940D11F9A7972AF4A407F4DD6A887E8494072F90FE9B7B54A407F4DD6A887E8494072F90FE9B7B54A40BE4F55A181E64940D11F9A7972AF4A40BE4F55A181E64940
48351	Мрясово	7	69	891	54.035578000000001	54.053679000000002	52.153740999999997	52.145645000000002	0103000020E61000000100000005000000823AE5D18D044B40B8E9CF7EA4124A40823AE5D18D044B40F486FBC8AD134A40B2BD16F4DE064B40F486FBC8AD134A40B2BD16F4DE064B40B8E9CF7EA4124A40823AE5D18D044B40B8E9CF7EA4124A40
48710	Малахово	7	69	891	53.793678999999997	53.807108999999997	52.161580999999998	52.157465000000002	0103000020E61000000100000005000000D042024697E54A40E0A128D027144A40D042024697E54A40D653ABAFAE144A4054A703594FE74A40D653ABAFAE144A4054A703594FE74A40E0A128D027144A40D042024697E54A40E0A128D027144A40
7105	Лебяжка	7	69	891	53.578766000000002	53.590705	52.030997999999997	52.024005000000002	0103000020E61000000100000005000000B404190115CA4A4062F8889812034A40B404190115CA4A40E61E12BEF7034A40B64AB0389CCB4A40E61E12BEF7034A40B64AB0389CCB4A4062F8889812034A40B404190115CA4A4062F8889812034A40
7497	Лапаз	7	69	891	53.476457000000003	53.502203000000002	51.975194000000002	51.961312	0103000020E61000000100000005000000A379008BFCBC4A404DA088450CFB4940A379008BFCBC4A40B2A03028D3FC4940FF791A3048C04A40B2A03028D3FC4940FF791A3048C04A404DA088450CFB4940A379008BFCBC4A404DA088450CFB4940
56204	Кутушево	7	69	891	53.958950999999999	53.976298	52.601776000000001	52.591334000000003	0103000020E61000000100000005000000B6BB07E8BEFA4A40A6811FD5B04B4A40B6BB07E8BEFA4A4044C2F7FE064D4A403A933655F7FC4A4044C2F7FE064D4A403A933655F7FC4A40A6811FD5B04B4A40B6BB07E8BEFA4A40A6811FD5B04B4A40
7744	Кулагино	7	69	891	53.620736000000001	53.662292000000001	51.897140999999998	51.862560000000002	0103000020E6100000010000000500000095B9F94674CF4A403C6BB75D68EE494095B9F94674CF4A404B732B84D5F249408333F8FBC5D44A404B732B84D5F249408333F8FBC5D44A403C6BB75D68EE494095B9F94674CF4A403C6BB75D68EE4940
48331	Кувай	7	69	891	53.889754000000003	53.913066000000001	52.163851999999999	52.149065999999998	0103000020E610000001000000050000001BBE8575E3F14A4007793D9814134A401BBE8575E3F14A402DB1321AF9144A40768BC058DFF44A402DB1321AF9144A40768BC058DFF44A4007793D9814134A401BBE8575E3F14A4007793D9814134A40
56152	Красная Поляна	7	69	891	53.604782	53.630077999999997	52.219948000000002	52.207923999999998	0103000020E61000000100000005000000D09A1F7F69CD4A40D906EE409D1A4A40D09A1F7F69CD4A400A698D41271C4A40ECF65965A6D04A400A698D41271C4A40ECF65965A6D04A40D906EE409D1A4A40D09A1F7F69CD4A40D906EE409D1A4A40
47033	Козловка	7	69	891	53.800561000000002	53.820943	52.017504000000002	52.006323000000002	0103000020E61000000100000005000000FEB968C878E64A40371B2B31CF004A40FEB968C878E64A404CC631923D024A40A87004A914E94A404CC631923D024A40A87004A914E94A40371B2B31CF004A40FEB968C878E64A40371B2B31CF004A40
48940	Ключевка	7	69	891	53.656309	53.671598000000003	52.474699000000001	52.463918999999997	0103000020E610000001000000050000000589EDEE01D44A401B7FA2B2613B4A400589EDEE01D44A40D238D4EFC23C4A408E075BECF6D54A40D238D4EFC23C4A408E075BECF6D54A401B7FA2B2613B4A400589EDEE01D44A401B7FA2B2613B4A40
8638	Камышка	7	69	891	54.032245000000003	54.050767999999998	52.354761000000003	52.345272000000001	0103000020E61000000100000005000000D23AAA9A20044B40BD1C76DF312C4A40D23AAA9A20044B40B972F6CE682D4A4077D7D9907F064B40B972F6CE682D4A4077D7D9907F064B40BD1C76DF312C4A40D23AAA9A20044B40BD1C76DF312C4A40
56149	Измайловка	7	69	891	53.309272	53.336472999999998	51.811540000000001	51.791027999999997	0103000020E61000000100000005000000C5C8923996A74A40321CCF6740E54940C5C8923996A74A40ABB2EF8AE0E74940567E198C11AB4A40ABB2EF8AE0E74940567E198C11AB4A40321CCF6740E54940C5C8923996A74A40321CCF6740E54940
7043	Землянка	7	69	891	53.713935999999997	53.736941999999999	52.044227999999997	52.033906999999999	0103000020E61000000100000005000000F1B73D4162DB4A40800D881057044A40F1B73D4162DB4A40A3C85A43A9054A4040868E1D54DE4A40A3C85A43A9054A4040868E1D54DE4A40800D881057044A40F1B73D4162DB4A40800D881057044A40
48077	Дедово	7	69	891	53.676377000000002	53.695825999999997	51.913876999999999	51.902375999999997	0103000020E610000001000000050000002062838593D64A40FF58880E81F349402062838593D64A4086C8E9EBF9F449406EDA8CD310D94A4086C8E9EBF9F449406EDA8CD310D94A40FF58880E81F349402062838593D64A40FF58880E81F34940
9047	Губовский	7	69	891	53.913173	53.925632999999998	52.388345000000001	52.379885000000002	0103000020E610000001000000050000008C4B55DAE2F44A40D89E5912A0304A408C4B55DAE2F44A405648F949B5314A40978C63247BF64A405648F949B5314A40978C63247BF64A40D89E5912A0304A408C4B55DAE2F44A40D89E5912A0304A40
62082	Горный	7	69	891	54.056058999999998	54.069175000000001	52.149000000000001	52.143031000000001	0103000020E61000000100000005000000BFD2F9F02C074B4037A8FDD64E124A40BFD2F9F02C074B40508D976E12134A40B459F5B9DA084B40508D976E12134A40B459F5B9DA084B4037A8FDD64E124A40BFD2F9F02C074B4037A8FDD64E124A40
47993	Герасимовка	7	69	891	53.262478999999999	53.295034000000001	51.787736000000002	51.776831999999999	0103000020E61000000100000005000000827170E998A14A403E3E213B6FE34940827170E998A14A40E1F08288D4E44940A29A92ACC3A54A40E1F08288D4E44940A29A92ACC3A54A403E3E213B6FE34940827170E998A14A403E3E213B6FE34940
7833	Волостновка	7	69	891	53.794147000000002	53.826082	51.802568999999998	51.790660000000003	0103000020E61000000100000005000000B79BE09BA6E54A40B020CD5834E54940B79BE09BA6E54A4047E4BB94BAE649403AE8120EBDE94A4047E4BB94BAE649403AE8120EBDE94A40B020CD5834E54940B79BE09BA6E54A40B020CD5834E54940
8169	Верхняя Платовка	7	69	891	53.967899000000003	53.993113999999998	51.954690999999997	51.940035000000002	0103000020E61000000100000005000000626A4B1DE4FB4A40350C1F1153F84940626A4B1DE4FB4A408C648F5033FA494091990B5C1EFF4A408C648F5033FA494091990B5C1EFF4A40350C1F1153F84940626A4B1DE4FB4A40350C1F1153F84940
47933	Варшавка	7	69	891	53.264940000000003	53.277732	52.016013000000001	52.006838999999999	0103000020E610000001000000050000007DB3CD8DE9A14A402EABB019E0004A407DB3CD8DE9A14A40CAA7C7B60C024A40BE86E0B88CA34A40CAA7C7B60C024A40BE86E0B88CA34A402EABB019E0004A407DB3CD8DE9A14A402EABB019E0004A40
8907	Берестовка	7	69	891	54.091731000000003	54.104937	52.457569999999997	52.452005999999997	0103000020E61000000100000005000000C38366D7BD0B4B4042CC2555DB394A40C38366D7BD0B4B40BBD05CA7913A4A40F7915B936E0D4B40BBD05CA7913A4A40F7915B936E0D4B4042CC2555DB394A40C38366D7BD0B4B4042CC2555DB394A40
47860	Барабановка	7	69	891	53.479331999999999	53.498637000000002	52.211241000000001	52.190581000000002	0103000020E6100000010000000500000090F63FC05ABD4A40971E4DF564184A4090F63FC05ABD4A408449F1F1091B4A40ACC95356D3BF4A408449F1F1091B4A40ACC95356D3BF4A40971E4DF564184A4090F63FC05ABD4A40971E4DF564184A40
9002	Балейка	7	69	891	53.844560000000001	53.862777999999999	52.394869	52.385652	0103000020E6100000010000000500000040C1C58A1AEC4A4089D1730B5D314A4040C1C58A1AEC4A40249A40118B324A40A9DA6E826FEE4A40249A40118B324A40A9DA6E826FEE4A4089D1730B5D314A4040C1C58A1AEC4A4089D1730B5D314A40
48400	Ахмерово	7	69	891	54.115096999999999	54.125687999999997	52.342663999999999	52.333683999999998	0103000020E61000000100000005000000116F9D7FBB0E4B4067994528B62A4A40116F9D7FBB0E4B401EC2F869DC2B4A40F4BF5C8B16104B401EC2F869DC2B4A40F4BF5C8B16104B4067994528B62A4A40116F9D7FBB0E4B4067994528B62A4A40
62083	Александровка	7	69	891	53.912365000000001	53.926971000000002	52.055598000000003	52.043219000000001	0103000020E61000000100000005000000ED815660C8F44A406DC83F3388054A40ED815660C8F44A408CDCD3D51D074A4093AB58FCA6F64A408CDCD3D51D074A4093AB58FCA6F64A406DC83F3388054A40ED815660C8F44A406DC83F3388054A40
56063	ст. Новоорск	7	69	790	59.030569999999997	59.030813000000002	51.364142999999999	51.364024999999998	0103000020E610000001000000050000008E1EBFB7E9834D4094F6065F98AE49408E1EBFB7E9834D409E08E23C9CAE494055A52DAEF1834D409E08E23C9CAE494055A52DAEF1834D4094F6065F98AE49408E1EBFB7E9834D4094F6065F98AE4940
5939	Энергетик	7	69	790	58.766663000000001	58.845534999999998	51.760702000000002	51.723376999999999	0103000020E61000000100000005000000D106600322624D40DCD6169E97DC4940D106600322624D403B00E2AE5EE14940CA4FAA7D3A6C4D403B00E2AE5EE14940CA4FAA7D3A6C4D40DCD6169E97DC4940D106600322624D40DCD6169E97DC4940
58904	Чилекта	7	69	790	59.279708999999997	59.302875999999998	51.766064	51.753984000000003	0103000020E61000000100000005000000CCB22781CDA34D4088DA368C82E04940CCB22781CDA34D404C5299620EE24940245F09A4C4A64D404C5299620EE24940245F09A4C4A64D4088DA368C82E04940CCB22781CDA34D4088DA368C82E04940
6403	Чапаевка	7	69	790	59.167527	59.203163000000004	51.376232000000002	51.356253000000002	0103000020E610000001000000050000003719558671954D400B0DC4B299AD49403719558671954D40B6DAC35E28B04940EE60C43E019A4D40B6DAC35E28B04940EE60C43E019A4D400B0DC4B299AD49403719558671954D400B0DC4B299AD4940
5581	Центральные Усадьбы Совхоза Новоорский	7	69	790	58.936993000000001	58.967534999999998	51.386941	51.377333999999998	0103000020E610000001000000050000005CCAF962EF774D409DD5027B4CB049405CCAF962EF774D40A33D5E4887B14940205ED72FD87B4D40A33D5E4887B14940205ED72FD87B4D409DD5027B4CB049405CCAF962EF774D409DD5027B4CB04940
56076	Ударник	7	69	790	58.765341999999997	58.794725999999997	51.286606999999997	51.269446000000002	0103000020E61000000100000005000000AB2006BAF6614D40DE04DF347DA24940AB2006BAF6614D40FFE6C589AFA44940F4A3E194B9654D40FFE6C589AFA44940F4A3E194B9654D40DE04DF347DA24940AB2006BAF6614D40DE04DF347DA24940
6383	Тасбулак	7	69	790	59.140253999999999	59.158445	51.523667000000003	51.512188999999999	0103000020E610000001000000050000000C91D3D7F3914D407B2FBE688FC149400C91D3D7F3914D404A7F2F8507C349407C9BFEEC47944D404A7F2F8507C349407C9BFEEC47944D407B2FBE688FC149400C91D3D7F3914D407B2FBE688FC14940
6089	Скалистое	7	69	790	58.707858999999999	58.723399999999998	51.532274000000001	51.526148999999997	0103000020E61000000100000005000000F296AB1F9B5A4D405BE9B5D958C34940F296AB1F9B5A4D406C41EF8D21C4494094F6065F985C4D406C41EF8D21C4494094F6065F985C4D405BE9B5D958C34940F296AB1F9B5A4D405BE9B5D958C34940
56038	Новоорск	7	69	790	58.952227999999998	59.062936000000001	51.399017999999998	51.355960000000003	0103000020E61000000100000005000000F12A6B9BE2794D409357E71890AD4940F12A6B9BE2794D40F641960513B34940DBDE6E490E884D40F641960513B34940DBDE6E490E884D409357E71890AD4940F12A6B9BE2794D409357E71890AD4940
45800	Молодежный	7	69	790	59.280256999999999	59.296768	51.301076999999999	51.294420000000002	0103000020E61000000100000005000000CFBC1C76DFA34D40E8A4F78DAFA54940CFBC1C76DFA34D40F549EEB089A64940EA3F6B7EFCA54D40F549EEB089A64940EA3F6B7EFCA54D40E8A4F78DAFA54940CFBC1C76DFA34D40E8A4F78DAFA54940
6568	Можаровка	7	69	790	59.054546000000002	59.071469999999998	51.154637000000001	51.141781999999999	0103000020E610000001000000050000005610035DFB864D40AB949EE9259249405610035DFB864D4033E02C25CB9349409352D0ED25894D4033E02C25CB9349409352D0ED25894D40AB949EE9259249405610035DFB864D40AB949EE925924940
6542	Лужки	7	69	790	59.094323000000003	59.114356000000001	51.257666999999998	51.244706000000001	0103000020E610000001000000050000005C21ACC6128C4D404791B586529F49405C21ACC6128C4D401421753BFBA04940FA0CA837A38E4D401421753BFBA04940FA0CA837A38E4D404791B586529F49405C21ACC6128C4D404791B586529F4940
6631	Кумак	7	69	790	58.827506	58.870381999999999	51.331166000000003	51.310879999999997	0103000020E61000000100000005000000349F73B7EB694D40807D74EACAA74940349F73B7EB694D4009C6C1A563AA4940778368AD686F4D4009C6C1A563AA4940778368AD686F4D40807D74EACAA74940349F73B7EB694D40807D74EACAA74940
56059	Крыловка	7	69	790	58.927075000000002	58.956719999999997	51.184766000000003	51.168740999999997	0103000020E6100000010000000500000038F8C264AA764D40463F1A4E9995494038F8C264AA764D40D5B48B69A6974940EDB60BCD757A4D40D5B48B69A6974940EDB60BCD757A4D40463F1A4E9995494038F8C264AA764D40463F1A4E99954940
6704	Красноуральск	7	69	790	58.797601	58.811973999999999	51.429071	51.408603999999997	0103000020E61000000100000005000000E22021CA17664D40E481C8224DB44940E22021CA17664D40BD546CCCEBB64940E59997C3EE674D40BD546CCCEBB64940E59997C3EE674D40E481C8224DB44940E22021CA17664D40E481C8224DB44940
6322	Караганка	7	69	790	59.383940000000003	59.400953999999999	51.381708000000003	51.362945000000003	0103000020E6100000010000000500000029D027F224B14D40959F54FB74AE494029D027F224B14D40904FC8CEDBB04940A699EE7552B34D40904FC8CEDBB04940A699EE7552B34D40959F54FB74AE494029D027F224B14D40959F54FB74AE4940
6176	Заморское	7	69	790	58.939552999999997	58.959440999999998	51.709024999999997	51.695321999999997	0103000020E61000000100000005000000E9EDCF4543784D403B18B14F00D94940E9EDCF4543784D40F085C954C1DA494084B872F6CE7A4D40F085C954C1DA494084B872F6CE7A4D403B18B14F00D94940E9EDCF4543784D403B18B14F00D94940
6220	Добровольское	7	69	790	59.252049999999997	59.279753999999997	51.694322999999997	51.67474	0103000020E61000000100000005000000787AA52C43A04D40CAA65CE15DD64940787AA52C43A04D4028EE7893DFD849406C76A4FACEA34D4028EE7893DFD849406C76A4FACEA34D40CAA65CE15DD64940787AA52C43A04D40CAA65CE15DD64940
5850	Гранитный	7	69	790	59.102578999999999	59.129277000000002	51.419562999999997	51.409643000000003	0103000020E61000000100000005000000D120054F218D4D4086048C2E6FB44940D120054F218D4D404ACE893DB4B54940009013268C904D404ACE893DB4B54940009013268C904D4086048C2E6FB44940D120054F218D4D4086048C2E6FB44940
6465	Горьковское	7	69	790	59.024020999999998	59.049622999999997	51.301487999999999	51.279380000000003	0103000020E6100000010000000500000067B5C01E13834D4008944DB9C2A3494067B5C01E13834D407711A62897A649409010E50B5A864D407711A62897A649409010E50B5A864D4008944DB9C2A3494067B5C01E13834D4008944DB9C2A34940
6065	Будамша	7	69	790	58.956305999999998	58.995463999999998	51.634945000000002	51.611125000000001	0103000020E61000000100000005000000FA7B293C687A4D404E62105839CE4940FA7B293C687A4D401EE1B4E045D14940342C465D6B7F4D401EE1B4E045D14940342C465D6B7F4D404E62105839CE4940FA7B293C687A4D404E62105839CE4940
62047	Ракитянка	7	69	7543	57.616971999999997	57.677123000000002	51.479196000000002	51.458840000000002	0103000020E610000001000000050000001B4641F0F8CE4C405F0CE544BBBA49401B4641F0F8CE4C40E02F664B56BD4940492F6AF7ABD64C40E02F664B56BD4940492F6AF7ABD64C405F0CE544BBBA49401B4641F0F8CE4C405F0CE544BBBA4940
46861	Тимошкино	7	69	552	53.42201	53.446066999999999	53.399034999999998	53.381255000000003	0103000020E61000000100000005000000E04A766C04B64A40DF37BEF6CCB04A40E04A766C04B64A40CC7A319413B34A40946934B918B94A40CC7A319413B34A40946934B918B94A40DF37BEF6CCB04A40E04A766C04B64A40DF37BEF6CCB04A40
46142	Староякупово	7	69	552	53.458571999999997	53.480894999999997	53.558593999999999	53.546926999999997	0103000020E610000001000000050000003F6EBF7CB2BA4A40522635B401C64A403F6EBF7CB2BA4A40F4DE180280C74A40ABE7A4F78DBD4A40F4DE180280C74A40ABE7A4F78DBD4A40522635B401C64A403F6EBF7CB2BA4A40522635B401C64A40
56104	Старокутлумбетово	7	69	552	53.735666000000002	53.763019999999997	53.428001000000002	53.415418000000003	0103000020E61000000100000005000000BB63B14D2ADE4A40BA15C26A2CB54A40BB63B14D2ADE4A40E1D39CBCC8B64A40D218ADA3AAE14A40E1D39CBCC8B64A40D218ADA3AAE14A40BA15C26A2CB54A40BB63B14D2ADE4A40BA15C26A2CB54A40
3850	Староаширово	7	69	552	53.508006000000002	53.533904999999997	53.487825000000001	53.469673999999998	0103000020E61000000100000005000000FD15325706C14A4008E412471EBC4A40FD15325706C14A40EA95B20C71BE4A40DF15C1FF56C44A40EA95B20C71BE4A40DF15C1FF56C44A4008E412471EBC4A40FD15325706C14A4008E412471EBC4A40
4157	Сарай-Гир	7	69	552	53.361006000000003	53.429538000000001	53.618734000000003	53.596936999999997	0103000020E6100000010000000500000074D4D17135AE4A40DC627E6E68CC4A4074D4D17135AE4A402E76FBAC32CF4A40D331E719FBB64A402E76FBAC32CF4A40D331E719FBB64A40DC627E6E68CC4A4074D4D17135AE4A40DC627E6E68CC4A40
4422	Садак	7	69	552	53.566792	53.583832999999998	53.456164999999999	53.448787000000003	0103000020E6100000010000000500000035D1E7A38CC84A405BEF37DA71B94A4035D1E7A38CC84A40384A5E9D63BA4A40ACA92C0ABBCA4A40384A5E9D63BA4A40ACA92C0ABBCA4A405BEF37DA71B94A4035D1E7A38CC84A405BEF37DA71B94A40
46767	Пролетаровка	7	69	552	53.338206999999997	53.354520000000001	53.558995000000003	53.544995	0103000020E610000001000000050000009E23F25D4AAB4A40E4BD6A65C2C54A409E23F25D4AAB4A4053D0ED258DC74A4093E34EE960AD4A4053D0ED258DC74A4093E34EE960AD4A40E4BD6A65C2C54A409E23F25D4AAB4A40E4BD6A65C2C54A40
58172	Покровка	7	69	552	53.767538000000002	53.796796999999998	53.241115000000001	53.230480999999997	0103000020E61000000100000005000000F83768AF3EE24A40B8ACC266809D4A40F83768AF3EE24A409BC937DBDC9E4A408446B071FDE54A409BC937DBDC9E4A408446B071FDE54A40B8ACC266809D4A40F83768AF3EE24A40B8ACC266809D4A40
26852	Новоузели	7	69	552	53.603470000000002	53.643751000000002	53.374507999999999	53.362833000000002	0103000020E61000000100000005000000FE0E45813ECD4A406D74CE4F71AE4A40FE0E45813ECD4A40910BCEE0EFAF4A4037E2C96E66D24A40910BCEE0EFAF4A4037E2C96E66D24A406D74CE4F71AE4A40FE0E45813ECD4A406D74CE4F71AE4A40
4007	Новожедрино	7	69	552	53.417447000000003	53.441997999999998	53.239896999999999	53.223193000000002	0103000020E610000001000000050000001B683EE76EB54A401BD99596919C4A401B683EE76EB54A404AB4E4F1B49E4A40DE72F56393B84A404AB4E4F1B49E4A40DE72F56393B84A401BD99596919C4A401B683EE76EB54A401BD99596919C4A40
3944	Новоаширово	7	69	552	53.307008000000003	53.328432999999997	53.341371000000002	53.323377999999998	0103000020E6100000010000000500000021CEC3094CA74A40791F477364A94A4021CEC3094CA74A40C366800BB2AB4A40ADF6B0170AAA4A40C366800BB2AB4A40ADF6B0170AAA4A40791F477364A94A4021CEC3094CA74A40791F477364A94A40
3506	Нижненовокутлумбетьево	7	69	552	53.657674	53.677436999999998	53.262003	53.252651	0103000020E61000000100000005000000FAB660A92ED44A409E2633DE56A04A40FAB660A92ED44A40193A765089A14A40D80C7041B6D64A40193A765089A14A40D80C7041B6D64A409E2633DE56A04A40FAB660A92ED44A409E2633DE56A04A40
46680	Натальино	7	69	552	53.456370999999997	53.476125000000003	53.226832000000002	53.203802000000003	0103000020E61000000100000005000000E1EB6B5D6ABA4A40016E162F169A4A40E1EB6B5D6ABA4A40D8D7BAD4089D4A406DE7FBA9F1BC4A40D8D7BAD4089D4A406DE7FBA9F1BC4A40016E162F169A4A40E1EB6B5D6ABA4A40016E162F169A4A40
46119	Матвеевка	7	69	552	53.460107999999998	53.497478000000001	53.526446	53.492319000000002	0103000020E610000001000000050000006150A6D1E4BA4A4087191A4F04BF4A406150A6D1E4BA4A40158E209562C34A40603DEE5BADBF4A40158E209562C34A40603DEE5BADBF4A4087191A4F04BF4A406150A6D1E4BA4A4087191A4F04BF4A40
3463	Кульчум	7	69	552	53.794460999999998	53.824464999999996	53.293123999999999	53.265455000000003	0103000020E610000001000000050000004679E6E5B0E54A40A4C7EF6DFAA14A404679E6E5B0E54A401BD6541685A54A402BD9B11188E94A401BD6541685A54A402BD9B11188E94A40A4C7EF6DFAA14A404679E6E5B0E54A40A4C7EF6DFAA14A40
3733	Кузькино	7	69	552	53.322485999999998	53.359065000000001	53.498821999999997	53.481892999999999	0103000020E610000001000000050000007CB5A33847A94A40EE9579ABAEBD4A407CB5A33847A94A403D433866D9BF4A40B21188D7F5AD4A403D433866D9BF4A40B21188D7F5AD4A40EE9579ABAEBD4A407CB5A33847A94A40EE9579ABAEBD4A40
26639	Кинельский	7	69	552	53.480328999999998	53.517187	53.289496	53.271163999999999	0103000020E610000001000000050000000229B16B7BBD4A4020ED7F80B5A24A400229B16B7BBD4A40522976340EA54A404B75012F33C24A40522976340EA54A404B75012F33C24A4020ED7F80B5A24A400229B16B7BBD4A4020ED7F80B5A24A40
46054	Емельяновка	7	69	552	53.717771999999997	53.746769	53.239601	53.224508999999998	0103000020E6100000010000000500000004FEF0F3DFDB4A402E54FEB5BC9C4A4004FEF0F3DFDB4A40618BDD3EAB9E4A405455682096DF4A40618BDD3EAB9E4A405455682096DF4A402E54FEB5BC9C4A4004FEF0F3DFDB4A402E54FEB5BC9C4A40
46495	Высотный	7	69	552	53.602293000000003	53.619073999999998	53.185918000000001	53.168497000000002	0103000020E610000001000000050000000CCEE0EF17CD4A40B03C484F91954A400CCEE0EF17CD4A406EDE3829CC974A40E6E61BD13DCF4A406EDE3829CC974A40E6E61BD13DCF4A40B03C484F91954A400CCEE0EF17CD4A40B03C484F91954A40
3415	Верхненовокутлумбетьево	7	69	552	53.756157000000002	53.781049000000003	53.254250999999996	53.244025000000001	0103000020E610000001000000050000001CD2A8C0C9E04A40053411363C9F4A401CD2A8C0C9E04A40D6FCF84B8BA04A4069C9E369F9E34A40D6FCF84B8BA04A4069C9E369F9E34A40053411363C9F4A401CD2A8C0C9E04A40053411363C9F4A40
46899	Борискино	7	69	552	53.498547000000002	53.534992000000003	53.410350999999999	53.394615999999999	0103000020E610000001000000050000006C425A63D0BF4A403A3DEFC682B24A406C425A63D0BF4A40C170AE6186B44A4092CF2B9E7AC44A40C170AE6186B44A4092CF2B9E7AC44A403A3DEFC682B24A406C425A63D0BF4A403A3DEFC682B24A40
3637	Африка	7	69	552	53.541252999999998	53.564653999999997	53.333300999999999	53.322868	0103000020E6100000010000000500000052EE3EC747C54A40647616BD53A94A4052EE3EC747C54A40AF5C6F9BA9AA4A401DC70F9546C84A40AF5C6F9BA9AA4A401DC70F9546C84A40647616BD53A94A4052EE3EC747C54A40647616BD53A94A40
45889	Азаматово	7	69	552	53.464438000000001	53.479726999999997	53.302967000000002	53.296498999999997	0103000020E61000000100000005000000848252B472BB4A40FA25E2ADF3A54A40848252B472BB4A403562669FC7A64A400C01C0B167BD4A403562669FC7A64A400C01C0B167BD4A40FA25E2ADF3A54A40848252B472BB4A40FA25E2ADF3A54A40
56045	Оренбург	7	69	2799	55.020463999999997	55.274084999999999	51.836356000000002	51.682088999999998	0103000020E61000000100000005000000675F79909E824B400DFB3DB14ED74940675F79909E824B401DE8A1B60DEB49407EA99F3715A34B401DE8A1B60DEB49407EA99F3715A34B400DFB3DB14ED74940675F79909E824B400DFB3DB14ED74940
2387	Ферапонтовка	7	69	325	51.896158999999997	51.913766000000003	52.236049999999999	52.225817999999997	0103000020E610000001000000050000000E828E56B5F249408F6CAE9AE71C4A400E828E56B5F24940431CEBE2361E4A402F19C748F6F44940431CEBE2361E4A402F19C748F6F449408F6CAE9AE71C4A400E828E56B5F249408F6CAE9AE71C4A40
2484	Федоровка	7	69	325	51.960504999999998	51.989386000000003	52.256005999999999	52.239966000000003	0103000020E610000001000000050000007E52EDD3F1FA49407313B534B71E4A407E52EDD3F1FA494036CAFACDC4204A40658F5033A4FE494036CAFACDC4204A40658F5033A4FE49407313B534B71E4A407E52EDD3F1FA49407313B534B71E4A40
2041	Суриково	7	69	325	52.027942000000003	52.055044000000002	52.641264999999997	52.626311000000001	0103000020E61000000100000005000000A9177C9A93034A40021077F52A504A40A9177C9A93034A40E388B5F814524A40A7EB89AE0B074A40E388B5F814524A40A7EB89AE0B074A40021077F52A504A40A9177C9A93034A40021077F52A504A40
1927	Скворцовка	7	69	325	52.128895	52.153894999999999	52.573478999999999	52.559229999999999	0103000020E6100000010000000500000018CFA0A17F104A40967840D994474A4018CFA0A17F104A40ADF886C267494A404B02D4D4B2134A40ADF886C267494A404B02D4D4B2134A40967840D994474A4018CFA0A17F104A40967840D994474A40
2960	Сергеевка	7	69	325	51.526152000000003	51.545780000000001	52.255361000000001	52.241163	0103000020E61000000100000005000000CD5CE0F258C34940AC00DF6DDE1E4A40CD5CE0F258C3494041D653ABAF204A40CB67791EDCC5494041D653ABAF204A40CB67791EDCC54940AC00DF6DDE1E4A40CD5CE0F258C34940AC00DF6DDE1E4A40
56132	Семеновка	7	69	325	51.690111999999999	51.716289000000003	52.531782	52.519153000000003	0103000020E61000000100000005000000E0490B9755D84940664F029B73424A40E0490B9755D84940FD4CBD6E11444A4006BEA25BAFDB4940FD4CBD6E11444A4006BEA25BAFDB4940664F029B73424A40E0490B9755D84940664F029B73424A40
2268	Ромашкино	7	69	325	51.779215999999998	51.831417000000002	52.496065000000002	52.477974000000003	0103000020E610000001000000050000008D429259BDE349404E2B85402E3D4A408D429259BDE349405AD8D30E7F3F4A40522B4CDF6BEA49405AD8D30E7F3F4A40522B4CDF6BEA49404E2B85402E3D4A408D429259BDE349404E2B85402E3D4A40
1767	Родионовка	7	69	325	51.919981999999997	51.947650000000003	52.455770000000001	52.449914999999997	0103000020E610000001000000050000004F745DF8C1F549406B7D91D096394A404F745DF8C1F54940BC3FDEAB563A4A40F7065F984CF94940BC3FDEAB563A4A40F7065F984CF949406B7D91D096394A404F745DF8C1F549406B7D91D096394A40
2866	Покровка	7	69	325	51.487183000000002	51.508302	52.326374999999999	52.308219000000001	0103000020E61000000100000005000000661536035CBE4940BF805EB873274A40661536035CBE4940B29DEFA7C6294A40E63E390A10C14940B29DEFA7C6294A40E63E390A10C14940BF805EB873274A40661536035CBE4940BF805EB873274A40
1614	Петровка	7	69	325	52.115366000000002	52.129775000000002	52.527766	52.520741999999998	0103000020E6100000010000000500000001892650C40E4A40AAD381ACA7424A4001892650C40E4A406AF816D68D434A40516B9A779C104A406AF816D68D434A40516B9A779C104A40AAD381ACA7424A4001892650C40E4A40AAD381ACA7424A40
1911	Озерки	7	69	325	52.219884999999998	52.231589999999997	52.632793999999997	52.617094000000002	0103000020E61000000100000005000000C3F01131251C4A406747AAEFFC4E4A40C3F01131251C4A40718DCF64FF504A40520ABABDA41D4A40718DCF64FF504A40520ABABDA41D4A406747AAEFFC4E4A40C3F01131251C4A406747AAEFFC4E4A40
2623	Михайловка	7	69	325	51.929361	51.960847000000001	52.408890999999997	52.384084999999999	0103000020E61000000100000005000000C4961E4DF5F649402CF180B229314A40C4961E4DF5F649407A50508A56344A40D8BAD408FDFA49407A50508A56344A40D8BAD408FDFA49402CF180B229314A40C4961E4DF5F649402CF180B229314A40
2754	Лаврентьевка	7	69	325	51.660862999999999	51.698332000000001	52.425033999999997	52.411060999999997	0103000020E610000001000000050000007711A62897D449409DD497A59D344A407711A62897D4494012D89C8367364A4009E066F162D9494012D89C8367364A4009E066F162D949409DD497A59D344A407711A62897D449409DD497A59D344A40
1819	Лабазы	7	69	325	52.156886	52.194445000000002	52.620041000000001	52.595999999999997	0103000020E61000000100000005000000A29927D714144A403F355EBA494C4A40A29927D714144A40EE96E4805D4F4A4074EFE192E3184A40EE96E4805D4F4A4074EFE192E3184A403F355EBA494C4A40A29927D714144A403F355EBA494C4A40
1724	Кутуши	7	69	325	51.975982999999999	51.998081999999997	52.446461999999997	52.436273	0103000020E61000000100000005000000DA39CD02EDFC49405C902DCBD7374A40DA39CD02EDFC49401074B4AA25394A40F65CA626C1FF49401074B4AA25394A40F65CA626C1FF49405C902DCBD7374A40DA39CD02EDFC49405C902DCBD7374A40
56050	Курманаевка	7	69	325	52.048208000000002	52.093384	52.526161000000002	52.492479000000003	0103000020E61000000100000005000000EAB303AE2B064A40C07B478D093F4A40EAB303AE2B064A4020B75F3E59434A401EFCC401F40B4A4020B75F3E59434A401EFCC401F40B4A40C07B478D093F4A40EAB303AE2B064A40C07B478D093F4A40
2712	Кретовка	7	69	325	51.906480999999999	51.915644	52.378489000000002	52.364027999999998	0103000020E6100000010000000500000002B9C49107F44940056A3178982E4A4002B9C49107F44940A872DA5372304A40AA6395D233F54940A872DA5372304A40AA6395D233F54940056A3178982E4A4002B9C49107F44940056A3178982E4A40
2538	Краснояровка	7	69	325	51.937624999999997	51.953166000000003	52.337712000000003	52.329622000000001	0103000020E61000000100000005000000BC74931804F849406405BF0D312A4A40BC74931804F84940BFBB95253A2B4A405FD4EE5701FA4940BFBB95253A2B4A405FD4EE5701FA49406405BF0D312A4A40BC74931804F849406405BF0D312A4A40
2814	Костино	7	69	325	51.581443	51.631974	52.389592999999998	52.366942999999999	0103000020E610000001000000050000007BBE66B96CCA4940813FFCFCF72E4A407BBE66B96CCA494011E0F42EDE314A400EF62686E4D0494011E0F42EDE314A400EF62686E4D04940813FFCFCF72E4A407BBE66B96CCA4940813FFCFCF72E4A40
1667	Кандауровка	7	69	325	52.031616	52.062437000000003	52.485487999999997	52.466920000000002	0103000020E61000000100000005000000E2033BFE0B044A4096ECD808C43B4A40E2033BFE0B044A40DB4C8578243E4A40BA8784EFFD074A40DB4C8578243E4A40BA8784EFFD074A4096ECD808C43B4A40E2033BFE0B044A4096ECD808C43B4A40
3112	Ефимовка	7	69	325	52.017018	52.079765999999999	52.220990999999998	52.197966999999998	0103000020E61000000100000005000000BFB854A52D024A40F7578FFB56194A40BFB854A52D024A40ECDADE6E491C4A4097AAB4C5350A4A40ECDADE6E491C4A4097AAB4C5350A4A40F7578FFB56194A40BFB854A52D024A40F7578FFB56194A40
3311	Егорьевка	7	69	325	52.204658000000002	52.215510000000002	52.291125000000001	52.279963000000002	0103000020E61000000100000005000000B16EBC3B321A4A40878BDCD3D5234A40B16EBC3B321A4A402506819543254A4001FBE8D4951B4A402506819543254A4001FBE8D4951B4A40878BDCD3D5234A40B16EBC3B321A4A40878BDCD3D5234A40
2976	Грачевка	7	69	325	51.696013999999998	51.735557999999997	52.249169000000002	52.235906999999997	0103000020E6100000010000000500000071C79BFC16D94940E0F25833321E4A4071C79BFC16D94940A91611C5E41F4A40D427B9C326DE4940A91611C5E41F4A40D427B9C326DE4940E0F25833321E4A4071C79BFC16D94940E0F25833321E4A40
21682	Гаршино	7	69	325	51.839861999999997	51.864161000000003	52.179029999999997	52.162011999999997	0103000020E610000001000000050000009A93179980EB49409FC728CFBC144A409A93179980EB49405E807D74EA164A4045BDE0D39CEE49405E807D74EA164A4045BDE0D39CEE49409FC728CFBC144A409A93179980EB49409FC728CFBC144A40
2082	Волжский	7	69	325	51.618561999999997	51.648952000000001	52.532105000000001	52.519694999999999	0103000020E610000001000000050000003046240A2DCF49408672A25D85424A403046240A2DCF4940E08442041C444A403F56F0DB10D34940E08442041C444A403F56F0DB10D349408672A25D85424A403046240A2DCF49408672A25D85424A40
3228	Васильевка	7	69	325	52.126981000000001	52.161772999999997	52.184269999999998	52.175699999999999	0103000020E61000000100000005000000501BD5E940104A401FF46C567D164A40501BD5E940104A4024D1CB2896174A401A3048FAB4144A4024D1CB2896174A401A3048FAB4144A401FF46C567D164A40501BD5E940104A401FF46C567D164A40
46916	Бобровка	7	69	325	51.561760999999997	51.598250999999998	52.554971000000002	52.537878999999997	0103000020E610000001000000050000008995D1C8E7C74940431A1538D9444A408995D1C8E7C749403D9D2B4A09474A404FE61F7D93CC49403D9D2B4A09474A404FE61F7D93CC4940431A1538D9444A408995D1C8E7C74940431A1538D9444A40
2621	Байгоровка	7	69	325	51.938110000000002	51.959203000000002	52.303185999999997	52.290407999999999	0103000020E6100000010000000500000079060DFD13F84940963FDF162C254A4079060DFD13F84940724D81CCCE264A40D09CF529C7FA4940724D81CCCE264A40D09CF529C7FA4940963FDF162C254A4079060DFD13F84940963FDF162C254A40
2279	Андреевка	7	69	325	51.895493999999999	51.929864000000002	52.326281999999999	52.305790999999999	0103000020E61000000100000005000000D2E1218C9FF24940A034D42824274A40D2E1218C9FF2494001A3CB9BC3294A4027DD96C805F7494001A3CB9BC3294A4027DD96C805F74940A034D42824274A40D2E1218C9FF24940A034D42824274A40
56061	ст. Дубиновка	7	69	63	56.841807000000003	56.843953999999997	51.527504999999998	51.527090999999999	0103000020E610000001000000050000009E45EF54C06B4C400A82C7B777C349409E45EF54C06B4C40FDBCA94885C3494008AA46AF066C4C40FDBCA94885C3494008AA46AF066C4C400A82C7B777C349409E45EF54C06B4C400A82C7B777C34940
491	Ялнайр	7	69	63	57.815302000000003	57.829891000000003	51.309246999999999	51.286776000000003	0103000020E61000000100000005000000842EE1D05BE84C408CA37213B5A44940842EE1D05BE84C406CB1DB6795A74940541F48DE39EA4C406CB1DB6795A74940541F48DE39EA4C408CA37213B5A44940842EE1D05BE84C408CA37213B5A44940
30812	Юлгутла	7	69	63	56.801642999999999	56.818100000000001	51.553296000000003	51.542149999999999	0103000020E610000001000000050000009E08E23C9C664C4061C3D32B65C549409E08E23C9C664C40FA804067D2C64940C66D3480B7684C40FA804067D2C64940C66D3480B7684C4061C3D32B65C549409E08E23C9C664C4061C3D32B65C54940
56159	Чураево	7	69	63	57.523251000000002	57.547514	51.642318000000003	51.629198000000002	0103000020E61000000100000005000000B64C86E3F9C24C40B45A608F89D04940B64C86E3F9C24C40EAD0E97937D24940130D52F014C64C40EAD0E97937D24940130D52F014C64C40B45A608F89D04940B64C86E3F9C24C40B45A608F89D04940
31088	Чеботарево	7	69	63	56.983777000000003	57.003028	51.683881999999997	51.668970000000002	0103000020E610000001000000050000004CC79C67EC7D4C40A80018CFA0D549404CC79C67EC7D4C405A29047289D74940747CB43863804C405A29047289D74940747CB43863804C40A80018CFA0D549404CC79C67EC7D4C40A80018CFA0D54940
31450	Урал	7	69	63	57.405310999999998	57.434902000000001	51.176997	51.162911999999999	0103000020E61000000100000005000000C2DA183BE1B34C401F10E84CDA944940C2DA183BE1B34C40BC3E73D6A7964940857B65DEAAB74C40BC3E73D6A7964940857B65DEAAB74C401F10E84CDA944940C2DA183BE1B34C401F10E84CDA944940
32489	Сарбай	7	69	63	57.984796000000003	58.013568999999997	51.739246000000001	51.728487000000001	0103000020E61000000100000005000000A69D9ACB0DFE4C40D447E00F3FDD4940A69D9ACB0DFE4C4073D9E89C9FDE4940A59E05A1BC014D4073D9E89C9FDE4940A59E05A1BC014D40D447E00F3FDD4940A69D9ACB0DFE4C40D447E00F3FDD4940
431	Сара	7	69	63	57.813236000000003	57.930089000000002	51.476587000000002	51.356752999999998	0103000020E6100000010000000500000006F7031E18E84C40FCDF1115AAAD494006F7031E18E84C40715985CD00BD494047AF06280DF74C40715985CD00BD494047AF06280DF74C40FCDF1115AAAD494006F7031E18E84C40FCDF1115AAAD4940
20157	Рысаево	7	69	63	57.499561999999997	57.534309	51.386704999999999	51.370345	0103000020E610000001000000050000008429CAA5F1BF4C405A9E077767AF49408429CAA5F1BF4C408F19A88C7FB14940AF7AC03C64C44C408F19A88C7FB14940AF7AC03C64C44C405A9E077767AF49408429CAA5F1BF4C405A9E077767AF4940
30896	Русское Канчерово	7	69	63	57.045760000000001	57.073087000000001	51.526783000000002	51.517798999999997	0103000020E6100000010000000500000084BBB376DB854C406473D53C47C2494084BBB376DB854C405D8B16A06DC34940A26131EA5A894C405D8B16A06DC34940A26131EA5A894C406473D53C47C2494084BBB376DB854C406473D53C47C24940
31493	Ровный	7	69	63	57.270555000000002	57.285404	51.104567000000003	51.095008	0103000020E610000001000000050000007862D68BA1A24C40DF6DDE38298C49407862D68BA1A24C40D49E9273628D4940E412471E88A44C40D49E9273628D4940E412471E88A44C40DF6DDE38298C49407862D68BA1A24C40DF6DDE38298C4940
17201	Рамазаново	7	69	63	57.437013	57.446966000000003	51.531047000000001	51.523671999999998	0103000020E61000000100000005000000A376BF0AF0B74C405BEA20AF07C34940A376BF0AF0B74C40C8D11C59F9C349404436902E36B94C40C8D11C59F9C349404436902E36B94C405BEA20AF07C34940A376BF0AF0B74C405BEA20AF07C34940
56114	Подлесная	7	69	63	58.023010999999997	58.045540000000003	51.690967000000001	51.678241999999997	0103000020E6100000010000000500000060394206F2024D40066344A2D0D6494060394206F2024D40C0CE4D9B71D8494076543541D4054D40C0CE4D9B71D8494076543541D4054D40066344A2D0D6494060394206F2024D40066344A2D0D64940
31404	Подгорное	7	69	63	57.595143	57.622352999999997	51.192183999999997	51.184804999999997	0103000020E61000000100000005000000BFB854A52DCC4C409291B3B0A7974940BFB854A52DCC4C4040683D7C99984940A3C85A43A9CF4C4040683D7C99984940A3C85A43A9CF4C409291B3B0A7974940BFB854A52DCC4C409291B3B0A7974940
31685	Пехотное	7	69	63	57.004787999999998	57.022584000000002	51.337130999999999	51.333517999999998	0103000020E61000000100000005000000E5B4A7E49C804C404C50C3B7B0AA4940E5B4A7E49C804C40E0BBCD1B27AB4940D9B45208E4824C40E0BBCD1B27AB4940D9B45208E4824C404C50C3B7B0AA4940E5B4A7E49C804C404C50C3B7B0AA4940
32120	Первомайск	7	69	63	57.422828000000003	57.446122000000003	51.393331000000003	51.379852999999997	0103000020E61000000100000005000000A3EA573A1FB64C40CC24EA059FB04940A3EA573A1FB64C4062C092AB58B24940580394861AB94C4062C092AB58B24940580394861AB94C40CC24EA059FB04940A3EA573A1FB64C40CC24EA059FB04940
32321	Оноприеновка	7	69	63	57.754019	57.776305999999998	51.638221000000001	51.627654999999997	0103000020E6100000010000000500000004C8D0B183E04C40DF15C1FF56D0494004C8D0B183E04C406A4FC939B1D1494023D8B8FE5DE34C406A4FC939B1D1494023D8B8FE5DE34C40DF15C1FF56D0494004C8D0B183E04C40DF15C1FF56D04940
31586	Новоуральск	7	69	63	57.222898999999998	57.254007999999999	51.255462999999999	51.235340000000001	0103000020E61000000100000005000000D2A755F4879C4C4067B8019F1F9E4940D2A755F4879C4C40452BF702B3A0494010768A5583A04C40452BF702B3A0494010768A5583A04C4067B8019F1F9E4940D2A755F4879C4C4067B8019F1F9E4940
32412	Новосимбирка	7	69	63	57.859445000000001	57.902887999999997	51.780704	51.763004000000002	0103000020E61000000100000005000000F9DA334B02EE4C40CD5B751DAAE14940F9DA334B02EE4C409EEDD11BEEE34940B5F97FD591F34C409EEDD11BEEE34940B5F97FD591F34C40CD5B751DAAE14940F9DA334B02EE4C40CD5B751DAAE14940
115	Новосаринский	7	69	63	57.887113999999997	57.916694999999997	51.489207	51.477865999999999	0103000020E6100000010000000500000070E998F38CF14C4067EF8CB62ABD494070E998F38CF14C40B5FCC0559EBE49400FB4024356F54C40B5FCC0559EBE49400FB4024356F54C4067EF8CB62ABD494070E998F38CF14C4067EF8CB62ABD4940
31006	Новосакмарск	7	69	63	57.238430999999999	57.258580000000002	51.543729999999996	51.530413000000003	0103000020E6100000010000000500000021AD31E8849E4C40C72FBC92E4C3494021AD31E8849E4C4052EDD3F198C5494029B3412619A14C4052EDD3F198C5494029B3412619A14C40C72FBC92E4C3494021AD31E8849E4C40C72FBC92E4C34940
32176	Новопокровка	7	69	63	57.876171999999997	57.912554	51.538615	51.521889999999999	0103000020E61000000100000005000000E0D5726726F04C40020EA14ACDC24940E0D5726726F04C4049111956F1C44940C0EAC891CEF44C4049111956F1C44940C0EAC891CEF44C40020EA14ACDC24940E0D5726726F04C40020EA14ACDC24940
32401	Новоказанка	7	69	63	57.677788	57.707557999999999	51.642161000000002	51.629243000000002	0103000020E6100000010000000500000085CFD6C1C1D64C40541EDD088BD0494085CFD6C1C1D64C4022E2E65432D24940F702B34291DA4C4022E2E65432D24940F702B34291DA4C40541EDD088BD0494085CFD6C1C1D64C40541EDD088BD04940
31979	Новая Ракитянка	7	69	63	57.637301000000001	57.665247999999998	51.527360000000002	51.518740999999999	0103000020E61000000100000005000000A35A441493D14C40130CE71A66C24940A35A441493D14C40FA9B508880C349405DDDB1D826D54C40FA9B508880C349405DDDB1D826D54C40130CE71A66C24940A35A441493D14C40130CE71A66C24940
56100	Никольск	7	69	63	57.094728000000003	57.119278999999999	51.359250000000003	51.348866999999998	0103000020E61000000100000005000000FC010F0C208C4C40AAD381ACA7AC4940FC010F0C208C4C40448B6CE7FBAD4940BF0CC688448F4C40448B6CE7FBAD4940BF0CC688448F4C40AAD381ACA7AC4940FC010F0C208C4C40AAD381ACA7AC4940
31078	Мухамедьярово	7	69	63	56.953360000000004	56.965487000000003	51.528536000000003	51.522075000000001	0103000020E6100000010000000500000044A852B3077A4C409487855AD3C2494044A852B3077A4C401C615111A7C3494049DBF813957B4C401C615111A7C3494049DBF813957B4C409487855AD3C2494044A852B3077A4C409487855AD3C24940
31742	Маячный	7	69	63	57.498251000000003	57.524858999999999	51.103538	51.086579	0103000020E61000000100000005000000831953B0C6BF4C409CC24A05158B4940831953B0C6BF4C4056F2B1BB408D4940710168942EC34C4056F2B1BB408D4940710168942EC34C409CC24A05158B4940831953B0C6BF4C409CC24A05158B4940
238	Мазово	7	69	63	58.005341000000001	58.032766000000002	51.503819	51.490558999999998	0103000020E61000000100000005000000FA298E03AF004D4015E126A3CABE4940FA298E03AF004D403D0D18247DC04940DB3521AD31044D403D0D18247DC04940DB3521AD31044D4015E126A3CABE4940FA298E03AF004D4015E126A3CABE4940
372	Лесной	7	69	63	57.821778999999999	57.840229999999998	51.461196999999999	51.446829000000001	0103000020E6100000010000000500000011C5E40D30E94C40C3F352B131B9494011C5E40D30E94C40B401D88008BB49401D8F19A88CEB4C40B401D88008BB49401D8F19A88CEB4C40C3F352B131B9494011C5E40D30E94C40C3F352B131B94940
31198	Куруил	7	69	63	57.123868999999999	57.165703000000001	51.558795000000003	51.542974000000001	0103000020E610000001000000050000007EFE7BF0DA8F4C40064A0A2C80C549407EFE7BF0DA8F4C408C15359886C74940AFEC82C135954C408C15359886C74940AFEC82C135954C40064A0A2C80C549407EFE7BF0DA8F4C40064A0A2C80C54940
31352	Краснощеково	7	69	63	57.247055000000003	57.271039999999999	51.308678	51.286912000000001	0103000020E610000001000000050000001AA88C7F9F9F4C403C6A4C88B9A449401AA88C7F9F9F4C40527FBDC282A7494034F44F70B1A24C40527FBDC282A7494034F44F70B1A24C403C6A4C88B9A449401AA88C7F9F9F4C403C6A4C88B9A44940
31758	Краснознаменка	7	69	63	57.205750000000002	57.247881	51.384979000000001	51.369304999999997	0103000020E6100000010000000500000075931804569A4C40E89FE06245AF494075931804569A4C40CA52EBFD46B149405F268A90BA9F4C40CA52EBFD46B149405F268A90BA9F4C40E89FE06245AF494075931804569A4C40E89FE06245AF4940
20274	Кидрясово	7	69	63	57.523062000000003	57.543776999999999	51.299641000000001	51.286855000000003	0103000020E61000000100000005000000E3E313B2F3C24C40D8D825AAB7A44940E3E313B2F3C24C4037C5E3A25AA6494093A8177C9AC54C4037C5E3A25AA6494093A8177C9AC54C40D8D825AAB7A44940E3E313B2F3C24C40D8D825AAB7A44940
32205	Карагай-Покровка	7	69	63	57.886654999999998	57.914924999999997	51.646644000000002	51.625982999999998	0103000020E61000000100000005000000DDEA39E97DF14C400D6D003620D04940DDEA39E97DF14C40CB13083BC5D249407AA52C431CF54C40CB13083BC5D249407AA52C431CF54C400D6D003620D04940DDEA39E97DF14C400D6D003620D04940
31269	Кайракла	7	69	63	57.035277000000001	57.062621999999998	51.624608000000002	51.609436000000002	0103000020E6100000010000000500000087A6ECF483844C40A680B4FF01CE494087A6ECF483844C40F568AA27F3CF49404B0169FF03884C40F568AA27F3CF49404B0169FF03884C40A680B4FF01CE494087A6ECF483844C40A680B4FF01CE4940
31264	Ильинка	7	69	63	57.341728000000003	57.368265000000001	51.24474	51.225740999999999	0103000020E6100000010000000500000052103CBEBDAB4C40E42EC214E59C494052103CBEBDAB4C40F302ECA3539F494077A1B94E23AF4C40F302ECA3539F494077A1B94E23AF4C40E42EC214E59C494052103CBEBDAB4C40E42EC214E59C4940
20191	Идельбаево	7	69	63	57.511913999999997	57.526287000000004	51.424987999999999	51.407738000000002	0103000020E61000000100000005000000A92EE06586C14C4011AB3FC230B44940A92EE06586C14C40A298BC0166B64940ADA7565F5DC34C40A298BC0166B64940ADA7565F5DC34C4011AB3FC230B44940A92EE06586C14C4011AB3FC230B44940
31895	Ибрагимово	7	69	63	57.430140999999999	57.458644	51.515047000000003	51.497971999999997	0103000020E6100000010000000500000099D53BDC0EB74C406F29E78BBDBF494099D53BDC0EB74C409373620FEDC14940D940BAD8B4BA4C409373620FEDC14940D940BAD8B4BA4C406F29E78BBDBF494099D53BDC0EB74C406F29E78BBDBF4940
30743	Зиянчурино	7	69	63	56.891177999999996	56.926867999999999	51.570954999999998	51.552937	0103000020E610000001000000050000001475E61E12724C40CADFBDA3C6C649401475E61E12724C406C3EAE0D15C94940BEDA519CA3764C406C3EAE0D15C94940BEDA519CA3764C40CADFBDA3C6C649401475E61E12724C40CADFBDA3C6C64940
31656	Залужье	7	69	63	57.129626999999999	57.156728999999999	51.301093000000002	51.289593000000004	0103000020E61000000100000005000000DCD6169E97904C404513286211A54940DCD6169E97904C40FB0626378AA64940DAAA24B20F944C40FB0626378AA64940DAAA24B20F944C404513286211A54940DCD6169E97904C404513286211A54940
266	Вьюжный	7	69	63	57.940733999999999	57.962373999999997	51.425049999999999	51.414732000000001	0103000020E610000001000000050000001D1EC2F869F84C40664D2CF015B549401D1EC2F869F84C401895D40968B64940A6423C122FFB4C401895D40968B64940A6423C122FFB4C40664D2CF015B549401D1EC2F869F84C40664D2CF015B54940
32328	Верхненазаргулово	7	69	63	57.713208999999999	57.738154999999999	51.748336000000002	51.728403	0103000020E610000001000000050000003F1BB96E4ADB4C4076A73B4F3CDD49403F1BB96E4ADB4C40B1355B79C9DF49407F30F0DC7BDE4C40B1355B79C9DF49407F30F0DC7BDE4C4076A73B4F3CDD49403F1BB96E4ADB4C4076A73B4F3CDD4940
32057	Васильевка	7	69	63	57.144629000000002	57.15849	51.517961999999997	51.505007999999997	0103000020E61000000100000005000000CF86FC3383924C40F31B261AA4C04940CF86FC3383924C400E492D944CC249401C5F7B6649944C400E492D944CC249401C5F7B6649944C40F31B261AA4C04940CF86FC3383924C40F31B261AA4C04940
56066	Блявтамак	7	69	63	57.547649	57.582495000000002	51.500830999999998	51.485920999999998	0103000020E61000000100000005000000F357C85C19C64C4045B8C9A832BE4940F357C85C19C64C4057E9EE3A1BC04940B18A37328FCA4C4057E9EE3A1BC04940B18A37328FCA4C4045B8C9A832BE4940F357C85C19C64C4045B8C9A832BE4940
20323	Блява	7	69	63	57.714224000000002	57.745871000000001	51.405687999999998	51.392792	0103000020E61000000100000005000000580229B16BDB4C40B2101D0247B24940580229B16BDB4C4098309A95EDB34940750470B378DF4C4098309A95EDB34940750470B378DF4C40B2101D0247B24940580229B16BDB4C40B2101D0247B24940
30855	Башкирское Канчерово	7	69	63	56.991636999999997	57.003152999999998	51.548166000000002	51.537730000000003	0103000020E61000000100000005000000744012F6ED7E4C40FF092E56D4C44940744012F6ED7E4C40BB63B14D2AC6494030F1475167804C40BB63B14D2AC6494030F1475167804C40FF092E56D4C44940744012F6ED7E4C40FF092E56D4C44940
31154	Барангулово	7	69	63	56.938797999999998	56.953251999999999	51.65963	51.647063000000003	0103000020E610000001000000050000006DC669882A784C40D0B9DBF5D2D249406DC669882A784C40F1BA7EC16ED449405D6C5A29047A4C40F1BA7EC16ED449405D6C5A29047A4C40D0B9DBF5D2D249406DC669882A784C40D0B9DBF5D2D24940
31880	Адаево	7	69	63	57.317680000000003	57.329951000000001	51.340732000000003	51.334316999999999	0103000020E61000000100000005000000F14BFDBCA9A84C4098BF42E6CAAA4940F14BFDBCA9A84C40B0592E1B9DAB4940292499D53BAA4C40B0592E1B9DAB4940292499D53BAA4C4098BF42E6CAAA4940F14BFDBCA9A84C4098BF42E6CAAA4940
30298	Яшкино	7	69	791	53.425649	53.459353	52.694997000000001	52.672733999999998	0103000020E610000001000000050000009D499BAA7BB64A402174D0251C564A409D499BAA7BB64A40B8E864A9F5584A40E5284014CCBA4A40B8E864A9F5584A40E5284014CCBA4A402174D0251C564A409D499BAA7BB64A402174D0251C564A40
59069	Яиково	7	69	791	53.068964000000001	54.045630000000003	53.140298000000001	52.526598999999997	0103000020E61000000100000005000000F94CF6CFD3884A409B8D959867434A40F94CF6CFD3884A40DCD8EC48F5914A40B6DB2E34D7054B40DCD8EC48F5914A40B6DB2E34D7054B409B8D959867434A40F94CF6CFD3884A409B8D959867434A40
30091	Юринский	7	69	791	53.762219999999999	53.776116999999999	52.716920999999999	52.704880000000003	0103000020E61000000100000005000000B62DCA6C90E14A4060CD0182395A4A40B62DCA6C90E14A4066683C11C45B4A40506F46CD57E34A4066683C11C45B4A40506F46CD57E34A4060CD0182395A4A40B62DCA6C90E14A4060CD0182395A4A40
30038	Юлты	7	69	791	53.722695000000002	53.749087000000003	52.786847000000002	52.774292000000003	0103000020E61000000100000005000000CAFD0E4581DC4A40F8C610001C634A40CAFD0E4581DC4A4055FA0967B7644A40EC6D3315E2DF4A4055FA0967B7644A40EC6D3315E2DF4A40F8C610001C634A40CAFD0E4581DC4A40F8C610001C634A40
28806	Утеево	7	69	791	53.934068000000003	53.950192999999999	52.972262999999998	52.960428999999998	0103000020E61000000100000005000000BD1E4C8A8FF74A40A3906456EF7A4A40BD1E4C8A8FF74A40300E2E1D737C4A40AEF199EC9FF94A40300E2E1D737C4A40AEF199EC9FF94A40A3906456EF7A4A40BD1E4C8A8FF74A40A3906456EF7A4A40
28958	Токское	7	69	791	53.379950999999998	53.411132000000002	52.875534999999999	52.864196	0103000020E610000001000000050000008F8AFF3BA2B04A40C1AA7AF99D6E4A408F8AFF3BA2B04A406EC0E78711704A40672B2FF99FB44A406EC0E78711704A40672B2FF99FB44A40C1AA7AF99D6E4A408F8AFF3BA2B04A40C1AA7AF99D6E4A40
48903	Степной	7	69	791	53.345258000000001	53.472963	52.778432000000002	52.605572000000002	0103000020E610000001000000050000005857056A31AC4A40C9AF1F62834D4A405857056A31AC4A407714E7A8A3634A40E99B340D8ABC4A407714E7A8A3634A40E99B340D8ABC4A40C9AF1F62834D4A405857056A31AC4A40C9AF1F62834D4A40
29918	Староюлдашево	7	69	791	53.629179999999998	53.651511999999997	52.848329	52.840578999999998	0103000020E610000001000000050000000DA661F888D04A40295AB917986B4A400DA661F888D04A40CB9F6F0B966C4A40CC79C6BE64D34A40CB9F6F0B966C4A40CC79C6BE64D34A40295AB917986B4A400DA661F888D04A40295AB917986B4A40
48198	Староникольское	7	69	791	53.591414999999998	53.612256000000002	53.119281000000001	53.101691000000002	0103000020E6100000010000000500000092AE997CB3CB4A4016A6EF35048D4A4092AE997CB3CB4A4060048D99448F4A40D06394675ECE4A4060048D99448F4A40D06394675ECE4A4016A6EF35048D4A4092AE997CB3CB4A4016A6EF35048D4A40
30019	Старобогдановка	7	69	791	53.886035	53.911088999999997	52.761628999999999	52.742797000000003	0103000020E61000000100000005000000410E4A9869F14A409148DBF8135F4A40410E4A9869F14A40B4571F0F7D614A40675F79909EF44A40B4571F0F7D614A40675F79909EF44A409148DBF8135F4A40410E4A9869F14A409148DBF8135F4A40
29112	Среднеильясово	7	69	791	53.406317000000001	53.421911999999999	52.909323000000001	52.897106999999998	0103000020E610000001000000050000008867093202B44A409F01F566D4724A408867093202B44A40144031B264744A401DE5603601B64A40144031B264744A401DE5603601B64A409F01F566D4724A408867093202B44A409F01F566D4724A40
48951	Свердловский	7	69	791	53.66001	53.684201999999999	52.674356000000003	52.654372000000002	0103000020E6100000010000000500000038842A357BD44A4085B53176C2534A4038842A357BD44A4042EE224C51564A40CCED5EEE93D74A4042EE224C51564A40CCED5EEE93D74A4085B53176C2534A4038842A357BD44A4085B53176C2534A40
48743	Пушкинский	7	69	791	53.862634	53.878903000000001	52.765900999999999	52.746699999999997	0103000020E61000000100000005000000763579CA6AEE4A402BF697DD935F4A40763579CA6AEE4A40A27C410B09624A409BADBCE47FF04A40A27C410B09624A409BADBCE47FF04A402BF697DD935F4A40763579CA6AEE4A402BF697DD935F4A40
48432	Пролетарка	7	69	791	53.258445000000002	53.280130999999997	52.888973999999997	52.880546000000002	0103000020E610000001000000050000004968CBB914A14A40D34F38BBB5704A404968CBB914A14A40457F68E6C9714A4042CC2555DBA34A40457F68E6C9714A4042CC2555DBA34A40D34F38BBB5704A404968CBB914A14A40D34F38BBB5704A40
48258	Преображенка	7	69	791	53.877609	53.901108999999998	52.97569	52.954217999999997	0103000020E610000001000000050000006FD6E07D55F04A4094A0BFD0237A4A406FD6E07D55F04A406284F068E37C4A40CD902A8A57F34A406284F068E37C4A40CD902A8A57F34A4094A0BFD0237A4A406FD6E07D55F04A4094A0BFD0237A4A40
58175	Покровка	7	69	791	53.807352000000002	53.827033999999998	52.978043999999997	52.969507999999998	0103000020E610000001000000050000001B2E724F57E74A40ED9A90D6187C4A401B2E724F57E74A404606B98B307D4A400C570740DCE94A404606B98B307D4A400C570740DCE94A40ED9A90D6187C4A401B2E724F57E74A40ED9A90D6187C4A40
48671	Подольск	7	69	791	53.555957999999997	53.612606	52.840513999999999	52.824660000000002	0103000020E610000001000000050000008BF9B9A129C74A40E12879758E694A408BF9B9A129C74A4042EA76F6956B4A40ACAA97DF69CE4A4042EA76F6956B4A40ACAA97DF69CE4A40E12879758E694A408BF9B9A129C74A40E12879758E694A40
29494	Плешаново	7	69	791	53.478226999999997	53.499004999999997	52.869295000000001	52.829231	0103000020E610000001000000050000003788D68A36BD4A4029EACC3D246A4A403788D68A36BD4A40C5C9FD0E456F4A402EC55565DFBF4A40C5C9FD0E456F4A402EC55565DFBF4A4029EACC3D246A4A403788D68A36BD4A4029EACC3D246A4A40
18570	Новоюласка	7	69	791	53.630958999999997	53.667664000000002	53.020932999999999	52.971010999999997	0103000020E61000000100000005000000F50EB743C3D04A403387A4164A7C4A40F50EB743C3D04A401E34BBEEAD824A40B85B920376D54A401E34BBEEAD824A40B85B920376D54A403387A4164A7C4A40F50EB743C3D04A403387A4164A7C4A40
48884	Новопетровка	7	69	791	53.588225999999999	53.618327999999998	52.670408000000002	52.653334000000001	0103000020E61000000100000005000000155454FD4ACB4A40B4AED172A0534A40155454FD4ACB4A40077DE9EDCF554A40BD19355F25CF4A40077DE9EDCF554A40BD19355F25CF4A40B4AED172A0534A40155454FD4ACB4A40B4AED172A0534A40
29151	Нижнекристалка	7	69	791	53.388942999999998	53.417492000000003	52.986491000000001	52.962045000000003	0103000020E610000001000000050000000A815CE2C8B14A40E223624A247B4A400A815CE2C8B14A4030664B56457E4A40BB2BBB6070B54A4030664B56457E4A40BB2BBB6070B54A40E223624A247B4A400A815CE2C8B14A40E223624A247B4A40
29045	Нижнеильясово	7	69	791	53.382997000000003	53.399363999999998	52.917212999999997	52.910735000000003	0103000020E61000000100000005000000AABBB20B06B14A404A29E8F692744A40AABBB20B06B14A40A73B4F3C67754A4091990B5C1EB34A40A73B4F3C67754A4091990B5C1EB34A404A29E8F692744A40AABBB20B06B14A404A29E8F692744A40
56209	Нижнебахтиярово	7	69	791	53.288961	53.310107000000002	52.892310000000002	52.882019	0103000020E61000000100000005000000E4688EACFCA44A40AEB9A3FFE5704A40E4688EACFCA44A4067F2CD3637724A405EA10F96B1A74A4067F2CD3637724A405EA10F96B1A74A40AEB9A3FFE5704A40E4688EACFCA44A40AEB9A3FFE5704A40
29635	Малоюлдашево	7	69	791	53.528488000000003	53.536267000000002	52.867305999999999	52.862091999999997	0103000020E610000001000000050000000B2AAA7EA5C34A405512D907596E4A400B2AAA7EA5C34A40F2CF0CE2036F4A404776A565A4C44A40F2CF0CE2036F4A404776A565A4C44A405512D907596E4A400B2AAA7EA5C34A405512D907596E4A40
29796	Луговск	7	69	791	53.536375	53.56071	52.84196	52.833703	0103000020E610000001000000050000002DB29DEFA7C44A40DEC9A7C7B66A4A402DB29DEFA7C44A4024456458C56B4A4024456458C5C74A4024456458C56B4A4024456458C5C74A40DEC9A7C7B66A4A402DB29DEFA7C44A40DEC9A7C7B66A4A40
29662	Кутерля	7	69	791	53.599266	53.621023000000001	52.781182999999999	52.763236999999997	0103000020E6100000010000000500000068CD8FBFB4CC4A406F0C01C0B1614A4068CD8FBFB4CC4A407898F6CDFD634A402B8881AE7DCF4A407898F6CDFD634A402B8881AE7DCF4A406F0C01C0B1614A4068CD8FBFB4CC4A406F0C01C0B1614A40
28627	Кристалка	7	69	791	53.463324	53.490633000000003	53.020381	53.002772999999998	0103000020E61000000100000005000000D8B969334EBB4A40E9279CDD5A804A40D8B969334EBB4A40DA3A38D89B824A4050ABE80FCDBE4A40DA3A38D89B824A4050ABE80FCDBE4A40E9279CDD5A804A40D8B969334EBB4A40E9279CDD5A804A40
29876	Красиково	7	69	791	53.630671	53.663271000000002	52.825150000000001	52.811114000000003	0103000020E610000001000000050000008FC4CBD3B9D04A40F4A96395D2674A408FC4CBD3B9D04A40AF25E4839E694A404FB16A10E6D44A40AF25E4839E694A404FB16A10E6D44A40F4A96395D2674A408FC4CBD3B9D04A40F4A96395D2674A40
48591	Клинок	7	69	791	53.466073000000002	53.476754	52.798974000000001	52.786470999999999	0103000020E610000001000000050000003946B247A8BB4A404F20EC14AB644A403946B247A8BB4A405A2DB0C744664A405C1E6B4606BD4A405A2DB0C744664A405C1E6B4606BD4A404F20EC14AB644A403946B247A8BB4A404F20EC14AB644A40
30162	Кинзелька	7	69	791	53.236077000000002	53.279609999999998	52.697535000000002	52.678910000000002	0103000020E610000001000000050000003D2B69C5379E4A40B476DB85E6564A403D2B69C5379E4A405E68AED348594A4039D1AE42CAA34A405E68AED348594A4039D1AE42CAA34A40B476DB85E6564A403D2B69C5379E4A40B476DB85E6564A40
29702	Калтан	7	69	791	53.524481000000002	53.536904999999997	52.799577999999997	52.775925999999998	0103000020E61000000100000005000000CB2F833122C34A40DC0E0D8B51634A40CB2F833122C34A40F04C689258664A408907944DB9C44A40F04C689258664A408907944DB9C44A40DC0E0D8B51634A40CB2F833122C34A40DC0E0D8B51634A40
29245	Ишалка	7	69	791	53.188358999999998	53.205382	52.883251999999999	52.864913999999999	0103000020E610000001000000050000002174D0251C984A4020ED7F80B56E4A402174D0251C984A403410CB660E714A40F29716F5499A4A403410CB660E714A40F29716F5499A4A4020ED7F80B56E4A402174D0251C984A4020ED7F80B56E4A40
45648	Ивановка	7	69	791	53.780932	53.805241000000002	52.862701000000001	52.835977	0103000020E610000001000000050000002F336C94F5E34A40A69A594B016B4A402F336C94F5E34A40FE9C82FC6C6E4A40FD32182312E74A40FE9C82FC6C6E4A40FD32182312E74A40A69A594B016B4A402F336C94F5E34A40A69A594B016B4A40
5582	Ибряево	7	69	791	53.830052000000002	53.853534000000003	53.023788000000003	53.008060999999998	0103000020E610000001000000050000005DFDD8243FEA4A40C0AF912408814A405DFDD8243FEA4A40C504357C0B834A401503249A40ED4A40C504357C0B834A401503249A40ED4A40C0AF912408814A405DFDD8243FEA4A40C0AF912408814A40
28695	Залесово	7	69	791	53.737974999999999	53.795834999999997	52.921366999999996	52.895645999999999	0103000020E61000000100000005000000FF21FDF675DE4A4088653387A4724A40FF21FDF675DE4A408B4E965AEF754A408E01D9EBDDE54A408B4E965AEF754A408E01D9EBDDE54A4088653387A4724A40FF21FDF675DE4A4088653387A4724A40
48937	Ермаково	7	69	791	53.759436000000001	53.770000000000003	52.631847999999998	52.625807999999999	0103000020E61000000100000005000000D9B3E73235E14A409FC9FE791A504A40D9B3E73235E14A4081053065E0504A40C3F5285C8FE24A4081053065E0504A40C3F5285C8FE24A409FC9FE791A504A40D9B3E73235E14A409FC9FE791A504A40
22602	Долинск	7	69	791	53.411293999999998	53.445169	52.866745999999999	52.855083999999998	0103000020E6100000010000000500000040852348A5B44A409BAA7B64736D4A4040852348A5B44A402BF86D88F16E4A40B5183C4CFBB84A402BF86D88F16E4A40B5183C4CFBB84A409BAA7B64736D4A4040852348A5B44A409BAA7B64736D4A40
48838	Вознесенка	7	69	791	53.264373999999997	53.306631000000003	52.664389999999997	52.653973000000001	0103000020E61000000100000005000000D3F4D901D7A14A40C7BB2363B5534A40D3F4D901D7A14A400CE544BB0A554A404B7842AF3FA74A400CE544BB0A554A404B7842AF3FA74A40C7BB2363B5534A40D3F4D901D7A14A40C7BB2363B5534A40
29512	Верхнеильясово	7	69	791	53.444693000000001	53.468722999999997	52.892820999999998	52.886522999999997	0103000020E610000001000000050000004CE141B3EBB84A406E13EE9579714A404CE141B3EBB84A404C1762F547724A4006F1811DFFBB4A404C1762F547724A4006F1811DFFBB4A406E13EE9579714A404CE141B3EBB84A406E13EE9579714A40
46849	Александровка	7	69	791	53.241503000000002	53.258741999999998	52.616864	52.598916000000003	0103000020E610000001000000050000006571FF91E99E4A408C868C47A94C4A406571FF91E99E4A40350A4966F54E4A40020D36751EA14A40350A4966F54E4A40020D36751EA14A408C868C47A94C4A406571FF91E99E4A408C868C47A94C4A40
47545	разрушенный Майский	7	69	1733	59.759112999999999	59.890914000000002	52.069412999999997	51.988112999999998	0103000020E61000000100000005000000F67B629D2AE14D4050E09D7C7AFE4940F67B629D2AE14D4068757286E2084A4037C64E7809F24D4068757286E2084A4037C64E7809F24D4050E09D7C7AFE4940F67B629D2AE14D4050E09D7C7AFE4940
56158	Чапаевка	7	69	1733	58.824657999999999	58.834575999999998	52.057884999999999	52.048713999999997	0103000020E610000001000000050000004031B2648E694D40BD6DA6423C064A404031B2648E694D40E8F692C668074A406403E962D36A4D40E8F692C668074A406403E962D36A4D40BD6DA6423C064A404031B2648E694D40BD6DA6423C064A40
28236	Уртазым	7	69	1733	58.833632000000001	58.850394999999999	52.213690999999997	52.196781000000001	0103000020E6100000010000000500000015731074B46A4D40B2BCAB1E30194A4015731074B46A4D408A39083A5A1B4A4049D74CBED96C4D408A39083A5A1B4A4049D74CBED96C4D40B2BCAB1E30194A4015731074B46A4D40B2BCAB1E30194A40
47943	Уральское	7	69	1733	58.907609000000001	58.926357000000003	52.199623000000003	52.189725000000003	0103000020E6100000010000000500000013471E882C744D40E71DA7E848184A4013471E882C744D40C443183F8D194A40D9B5BDDD92764D40C443183F8D194A40D9B5BDDD92764D40E71DA7E848184A4013471E882C744D40E71DA7E848184A40
28359	Таналык	7	69	1733	58.927165000000002	58.947907000000001	52.042648999999997	52.029013999999997	0103000020E61000000100000005000000787FBC57AD764D40259012BBB6034A40787FBC57AD764D40821ABE8575054A4022533E0455794D40821ABE8575054A4022533E0455794D40259012BBB6034A40787FBC57AD764D40259012BBB6034A40
56212	Свободное	7	69	1733	59.714708999999999	59.738819999999997	52.419837999999999	52.405517000000003	0103000020E610000001000000050000001494A2957BDB4D406C7C26FBE7334A401494A2957BDB4D401CCF6740BD354A40BBD05CA791DE4D401CCF6740BD354A40BBD05CA791DE4D406C7C26FBE7334A401494A2957BDB4D406C7C26FBE7334A40
47882	Просторы	7	69	1733	59.311464000000001	59.345680999999999	52.217294000000003	52.197504000000002	0103000020E61000000100000005000000D0F0660DDEA74D40236AA2CF47194A40D0F0660DDEA74D40FBCE2F4AD01B4A409EEC66463FAC4D40FBCE2F4AD01B4A409EEC66463FAC4D40236AA2CF47194A40D0F0660DDEA74D40236AA2CF47194A40
48150	Приморск	7	69	1733	58.872781000000003	58.911434999999997	51.890020999999997	51.876539999999999	0103000020E61000000100000005000000FCC8AD49B76F4D4063D1747632F04940FCC8AD49B76F4D4069E04735ECF1494002B7EEE6A9744D4069E04735ECF1494002B7EEE6A9744D4063D1747632F04940FCC8AD49B76F4D4063D1747632F04940
47156	Покровка	7	69	1733	58.824936999999998	58.834575999999998	52.135171	52.127265999999999	0103000020E6100000010000000500000053211E8997694D4045F295404A104A4053211E8997694D400E2F88484D114A406403E962D36A4D400E2F88484D114A406403E962D36A4D4045F295404A104A4053211E8997694D4045F295404A104A40
46271	Первомайский	7	69	1733	59.653874999999999	59.677751999999998	52.000262999999997	51.988163	0103000020E6100000010000000500000004560E2DB2D34D40020F0C207CFE494004560E2DB2D34D400D33349E08004A403866D993C0D64D400D33349E08004A403866D993C0D64D40020F0C207CFE494004560E2DB2D34D40020F0C207CFE4940
56196	Новопотоцкое	7	69	1733	59.414428999999998	59.434992000000001	52.413049000000001	52.401401999999997	0103000020E61000000100000005000000CAC16C020CB54D404546072461334A40CAC16C020CB54D40A05225CADE344A40C5025FD1ADB74D40A05225CADE344A40C5025FD1ADB74D404546072461334A40CAC16C020CB54D404546072461334A40
27630	Новооренбург	7	69	1733	59.565750000000001	59.585127	52.416614000000003	52.403858	0103000020E6100000010000000500000023DBF97E6AC84D402E1D739EB1334A4023DBF97E6AC84D402387889B53354A40D8800871E5CA4D402387889B53354A40D8800871E5CA4D402E1D739EB1334A4023DBF97E6AC84D402E1D739EB1334A40
47974	Максим Горький	7	69	1733	58.978495000000002	58.997261000000002	52.229536000000003	52.222734000000003	0103000020E610000001000000050000005726FC523F7D4D4088DA368C821C4A405726FC523F7D4D4099A0866F611D4A40C3499A3FA67F4D4099A0866F611D4A40C3499A3FA67F4D4088DA368C821C4A405726FC523F7D4D4088DA368C821C4A40
47655	Лесная Поляна	7	69	1733	59.674095999999999	59.689754000000001	52.179620999999997	52.17069	0103000020E61000000100000005000000A52E19C748D64D408BE07F2BD9154A40A52E19C748D64D40605628D2FD164A408124ECDB49D84D40605628D2FD164A408124ECDB49D84D408BE07F2BD9154A40A52E19C748D64D408BE07F2BD9154A40
47841	Кульма	7	69	1733	59.330058999999999	59.353271999999997	52.426099000000001	52.411192	0103000020E610000001000000050000000F60915F3FAA4D403C3080F0A1344A400F60915F3FAA4D40DDED7A698A364A40D74B530438AD4D40DDED7A698A364A40D74B530438AD4D403C3080F0A1344A400F60915F3FAA4D403C3080F0A1344A40
27523	Красный Огородник	7	69	1733	59.848261999999998	59.859095000000003	52.180360999999998	52.171937999999997	0103000020E61000000100000005000000433866D993EC4D4046787B1002164A40433866D993EC4D40A73CBA1116174A401D9430D3F6ED4D40A73CBA1116174A401D9430D3F6ED4D4046787B1002164A40433866D993EC4D4046787B1002164A40
27176	Красноярский	7	69	1733	59.879029000000003	59.926001999999997	51.978394999999999	51.949067999999997	0103000020E61000000100000005000000289EB30584F04D400ED76A0F7BF94940289EB30584F04D40F3C81F0C3CFD4940EA03C93B87F64D40F3C81F0C3CFD4940EA03C93B87F64D400ED76A0F7BF94940289EB30584F04D400ED76A0F7BF94940
47831	Коминтерн	7	69	1733	59.360773000000002	59.388710000000003	52.382320999999997	52.365958999999997	0103000020E61000000100000005000000D12346CF2DAE4D40A35698BED72E4A40D12346CF2DAE4D4079C9FFE4EF304A4068D0D03FC1B14D4079C9FFE4EF304A4068D0D03FC1B14D40A35698BED72E4A40D12346CF2DAE4D40A35698BED72E4A40
47647	Кировск	7	69	1733	59.608870000000003	59.635738000000003	52.159652999999999	52.142207999999997	0103000020E61000000100000005000000FDC1C073EFCD4D40629D2ADF33124A40FDC1C073EFCD4D40A9DA6E826F144A408869DFDC5FD14D40A9DA6E826F144A408869DFDC5FD14D40629D2ADF33124A40FDC1C073EFCD4D40629D2ADF33124A40
26924	Кваркено	7	69	1733	59.708537999999997	59.744191999999998	52.096038999999998	52.071416999999997	0103000020E6100000010000000500000093FC885FB1DA4D4070B0373124094A4093FC885FB1DA4D40FD1186014B0C4A40F0F8F6AE41DF4D40FD1186014B0C4A40F0F8F6AE41DF4D4070B0373124094A4093FC885FB1DA4D4070B0373124094A40
27528	Зеленодольск	7	69	1733	59.878382000000002	59.909103999999999	52.384514000000003	52.367724000000003	0103000020E6100000010000000500000092B245D26EF04D4027FA7C94112F4A4092B245D26EF04D40556D37C137314A40D65416855DF44D40556D37C137314A40D65416855DF44D4027FA7C94112F4A4092B245D26EF04D4027FA7C94112F4A40
56131	Екатериновка	7	69	1733	59.956454999999998	59.981473000000001	51.937514999999998	51.925657999999999	0103000020E610000001000000050000003F8C101E6DFA4D40F0A31AF67BF649403F8C101E6DFA4D403541D47D00F84940197442E8A0FD4D403541D47D00F84940197442E8A0FD4D40F0A31AF67BF649403F8C101E6DFA4D40F0A31AF67BF64940
28551	Горный Ерик	7	69	1733	58.82349	58.833416999999997	51.786136999999997	51.778604000000001	0103000020E61000000100000005000000A14ACD1E68694D407444BE4BA9E34940A14ACD1E68694D4078962023A0E4494018778368AD6A4D4078962023A0E4494018778368AD6A4D407444BE4BA9E34940A14ACD1E68694D407444BE4BA9E34940
48158	Гоголевка	7	69	1733	58.980237000000002	58.988672999999999	51.944999000000003	51.935654	0103000020E6100000010000000500000022AAF067787D4D40902FA182C3F7494022AAF067787D4D4059E02BBAF5F8494017B83CD68C7E4D4059E02BBAF5F8494017B83CD68C7E4D40902FA182C3F7494022AAF067787D4D40902FA182C3F74940
27903	Бриент	7	69	1733	59.295160000000003	59.318786000000003	52.137974	52.116964000000003	0103000020E610000001000000050000002F8B89CDC7A54D40996725ADF80E4A402F8B89CDC7A54D4062D9CC21A9114A401A36CAFACDA84D4062D9CC21A9114A401A36CAFACDA84D40996725ADF80E4A402F8B89CDC7A54D40996725ADF80E4A40
47959	Большевик	7	69	1733	58.881062999999997	58.898634000000001	52.172933	52.166277000000001	0103000020E610000001000000050000009A5B21ACC6704D40DB89929048154A409A5B21ACC6704D4018B325AB22164A406E895C7006734D4018B325AB22164A406E895C7006734D40DB89929048154A409A5B21ACC6704D40DB89929048154A40
27369	Болотовск	7	69	1733	59.955241999999998	59.966031000000001	52.236700999999996	52.225647000000002	0103000020E6100000010000000500000000E2AE5E45FA4D4063B83A00E21C4A4000E2AE5E45FA4D401AF7E6374C1E4A400AF65FE7A6FB4D401AF7E6374C1E4A400AF65FE7A6FB4D4063B83A00E21C4A4000E2AE5E45FA4D4063B83A00E21C4A40
56112	Березовка	7	69	1733	58.950646999999996	58.974182999999996	52.370153999999999	52.356729999999999	0103000020E610000001000000050000002F8507CDAE794D4044C02154A92D4A402F8507CDAE794D40E63DCE34612F4A40DAA84E07B27C4D40E63DCE34612F4A40DAA84E07B27C4D4044C02154A92D4A402F8507CDAE794D4044C02154A92D4A40
47720	Белоозерный	7	69	1733	59.596563000000003	59.614941999999999	52.271461000000002	52.259379000000003	0103000020E610000001000000050000007880272D5CCC4D407522C15433214A407880272D5CCC4D40DA91EA3BBF224A40EA77616BB6CE4D40DA91EA3BBF224A40EA77616BB6CE4D407522C15433214A407880272D5CCC4D407522C15433214A40
45624	Алексеевка	7	69	1733	58.685383000000002	58.700861000000003	52.155979000000002	52.150204000000002	0103000020E61000000100000005000000001E51A1BA574D403CDD79E239134A40001E51A1BA574D4070EEAF1EF7134A405C0531D0B5594D4070EEAF1EF7134A405C0531D0B5594D403CDD79E239134A40001E51A1BA574D403CDD79E239134A40
27402	Аландское	7	69	1733	59.771456000000001	59.809454000000002	52.237346000000002	52.216892000000001	0103000020E61000000100000005000000C826F911BFE24D40CC61F71DC31B4A40C826F911BFE24D4010EB8D5A611E4A40E6CE4C309CE74D4010EB8D5A611E4A40E6CE4C309CE74D40CC61F71DC31B4A40C826F911BFE24D40CC61F71DC31B4A40
23600	Айдырлинский	7	69	1733	59.757271000000003	59.774428999999998	52.059108999999999	52.044566000000003	0103000020E61000000100000005000000C89A9141EEE04D40BC41B456B4054A40C89A9141EEE04D401BF33AE290074A4078094E7D20E34D401BF33AE290074A4078094E7D20E34D40BC41B456B4054A40C89A9141EEE04D40BC41B456B4054A40
26860	Яман	7	69	1351	53.293506000000001	53.329025999999999	51.622281999999998	51.607747000000003	0103000020E610000001000000050000000397C79A91A54A40FE9E58A7CACD49400397C79A91A54A40DA71C3EFA6CF494050C422861DAA4A40DA71C3EFA6CF494050C422861DAA4A40FE9E58A7CACD49400397C79A91A54A40FE9E58A7CACD4940
47017	Шутово	7	69	1351	53.536473999999998	53.561563999999997	51.544015000000002	51.533579000000003	0103000020E61000000100000005000000C093162EABC44A408C6A11514CC44940C093162EABC44A4048C49448A2C54940334E4354E1C74A4048C49448A2C54940334E4354E1C74A408C6A11514CC44940C093162EABC44A408C6A11514CC44940
26555	Студеное	7	69	1351	53.142491	53.184863999999997	51.600938999999997	51.584763000000002	0103000020E61000000100000005000000B77C24253D924A4097749483D9CA4940B77C24253D924A400AF2B391EBCC4940971AA19FA9974A400AF2B391EBCC4940971AA19FA9974A4097749483D9CA4940B77C24253D924A4097749483D9CA4940
47260	Степное	7	69	1351	53.876449999999998	53.891990999999997	51.366352999999997	51.359789999999997	0103000020E61000000100000005000000234A7B832FF04A40C3B645990DAE4940234A7B832FF04A404FE5B4A7E4AE4940C5A9D6C22CF24A404FE5B4A7E4AE4940C5A9D6C22CF24A40C3B645990DAE4940234A7B832FF04A40C3B645990DAE4940
56071	Сладков(Сладково)	7	69	1351	53.461230999999998	53.498762999999997	51.637504999999997	51.620778000000001	0103000020E6100000010000000500000060730E9E09BB4A40C4094CA775CF494060730E9E09BB4A40AB048BC399D1494038BA4A77D7BF4A40AB048BC399D1494038BA4A77D7BF4A40C4094CA775CF494060730E9E09BB4A40C4094CA775CF4940
56085	Рассыпная	7	69	1351	53.604179999999999	53.64667	51.609906000000002	51.591059000000001	0103000020E61000000100000005000000DA722EC555CD4A40D48041D2A7CB4940DA722EC555CD4A402DD1596611CE4940F4A62215C6D24A402DD1596611CE4940F4A62215C6D24A40D48041D2A7CB4940DA722EC555CD4A40D48041D2A7CB4940
47413	Раздольное	7	69	1351	53.267266999999997	53.284576999999999	51.617780000000003	51.604978000000003	0103000020E61000000100000005000000672618CE35A24A4056664AEB6FCD4940672618CE35A24A40BB0F406A13CF4940CE18E6046DA44A40BB0F406A13CF4940CE18E6046DA44A4056664AEB6FCD4940672618CE35A24A4056664AEB6FCD4940
47214	Привольное	7	69	1351	53.671688000000003	53.706766999999999	51.367713999999999	51.348011999999997	0103000020E61000000100000005000000CE8E54DFF9D54A40CA4E3FA88BAC4940CE8E54DFF9D54A4003249A4011AF49402E724F5777DA4A4003249A4011AF49402E724F5777DA4A40CA4E3FA88BAC4940CE8E54DFF9D54A40CA4E3FA88BAC4940
47050	Подстепки	7	69	1351	53.738782999999998	53.765517000000003	51.543762999999998	51.531495	0103000020E610000001000000050000009EEBFB7090DE4A40677E350708C449409EEBFB7090DE4A402EE3A6069AC549401AC40776FCE14A402EE3A6069AC549401AC40776FCE14A40677E350708C449409EEBFB7090DE4A40677E350708C44940
47090	Нижнеозерное	7	69	1351	53.890006	53.933439	51.623769000000003	51.598880999999999	0103000020E61000000100000005000000349F73B7EBF14A400F99F221A8CC4940349F73B7EBF14A401BA19FA9D7CF4940CDE7DCED7AF74A401BA19FA9D7CF4940CDE7DCED7AF74A400F99F221A8CC4940349F73B7EBF14A400F99F221A8CC4940
26711	Мухраново	7	69	1351	53.376421000000001	53.407853000000003	51.617758000000002	51.605319000000001	0103000020E61000000100000005000000894336902EB04A40DF52CE177BCD4940894336902EB04A40D36BB3B112CF4940AA49F08634B44A40D36BB3B112CF4940AA49F08634B44A40DF52CE177BCD4940894336902EB04A40DF52CE177BCD4940
47399	Крестовка	7	69	1351	53.052812000000003	53.101851000000003	51.585451999999997	51.572997999999998	0103000020E610000001000000050000000E6B2A8BC2864A4032569BFF57C949400E6B2A8BC2864A405BB05417F0CA49404F081D74098D4A405BB05417F0CA49404F081D74098D4A4032569BFF57C949400E6B2A8BC2864A4032569BFF57C94940
47039	Красный Яр	7	69	1351	53.639358000000001	53.675623000000002	51.544676000000003	51.526155000000003	0103000020E61000000100000005000000CE37A27BD6D14A403ED00A0C59C34940CE37A27BD6D14A40437573F1B7C5494074B680D07AD64A40437573F1B7C5494074B680D07AD64A403ED00A0C59C34940CE37A27BD6D14A403ED00A0C59C34940
14488	Краснохолм	7	69	1351	54.125337000000002	54.181572000000003	51.610247000000001	51.576138999999998	0103000020E6100000010000000500000048FDF50A0B104B409E7939ECBEC9494048FDF50A0B104B40B6BDDD921CCE494046EF54C03D174B40B6BDDD921CCE494046EF54C03D174B409E7939ECBEC9494048FDF50A0B104B409E7939ECBEC94940
25979	Кардаилово	7	69	1351	53.874752000000001	53.953651000000001	51.550938000000002	51.522249000000002	0103000020E61000000100000005000000280EA0DFF7EF4A4032AF230ED9C24940280EA0DFF7EF4A40D40FEA2285C649401B66683C11FA4A40D40FEA2285C649401B66683C11FA4A4032AF230ED9C24940280EA0DFF7EF4A4032AF230ED9C24940
25675	Илек	7	69	1351	53.363027000000002	53.421534000000001	51.542839000000001	51.513826000000002	0103000020E61000000100000005000000524832AB77AE4A40D1EAE40CC5C14940524832AB77AE4A4026FF93BF7BC5494077137CD3F4B54A4026FF93BF7BC5494077137CD3F4B54A40D1EAE40CC5C14940524832AB77AE4A40D1EAE40CC5C14940
26507	Затонное	7	69	1351	53.575479000000001	53.603631999999998	51.421669000000001	51.410868000000001	0103000020E610000001000000050000007444BE4BA9C94A40897C975297B449407444BE4BA9C94A40575EF23FF9B54940D76839D043CD4A40575EF23FF9B54940D76839D043CD4A40897C975297B449407444BE4BA9C94A40897C975297B44940
26572	Заживный	7	69	1351	53.222019000000003	53.234119	51.604508000000003	51.597693999999997	0103000020E610000001000000050000009A0B5C1E6B9C4A40F981AB3C81CC49409A0B5C1E6B9C4A40CF15A58460CD4940A52F849CF79D4A40CF15A58460CD4940A52F849CF79D4A40F981AB3C81CC49409A0B5C1E6B9C4A40F981AB3C81CC4940
47123	Димитровский	7	69	1351	54.225301999999999	54.244264999999999	51.43956	51.423724999999997	0103000020E6100000010000000500000098DC28B2D61C4B40B1BFEC9E3CB6494098DC28B2D61C4B409C50888043B849405A475513441F4B409C50888043B849405A475513441F4B40B1BFEC9E3CB6494098DC28B2D61C4B40B1BFEC9E3CB64940
25302	Ушкатты	7	69	1612	59.946986000000003	59.965536999999998	50.759601000000004	50.745463000000001	0103000020E610000001000000050000008BE255D636F94D4064B0E2546B5F49408BE255D636F94D402481069B3A614940FA0967B796FB4D402481069B3A614940FA0967B796FB4D4064B0E2546B5F49408BE255D636F94D4064B0E2546B5F4940
19978	Тюльпанный	7	69	1612	58.742840000000001	58.762953000000003	51.014482999999998	51.006759000000002	0103000020E6100000010000000500000090149161155F4D4012FA997ADD80494090149161155F4D408AAC3594DA8149404BB1A371A8614D408AAC3594DA8149404BB1A371A8614D4012FA997ADD80494090149161155F4D4012FA997ADD804940
46679	Соколовка	7	69	1612	58.984378999999997	58.998823999999999	50.798951000000002	50.774186	0103000020E6100000010000000500000041EF8D21007E4D40B282DF861863494041EF8D21007E4D40A20DC00644664940DE3AFF76D97F4D40A20DC00644664940DE3AFF76D97F4D40B282DF861863494041EF8D21007E4D40B282DF8618634940
46740	Прибрежный	7	69	1612	59.510638999999998	59.534489000000001	50.709969999999998	50.695776000000002	0103000020E61000000100000005000000F487669E5CC14D40BDAB1E300F594940F487669E5CC14D401092054CE05A49402F89B3226AC44D401092054CE05A49402F89B3226AC44D40BDAB1E300F594940F487669E5CC14D40BDAB1E300F594940
25129	Курмансай	7	69	1612	59.520412	59.556182999999997	50.861203000000003	50.840805000000003	0103000020E61000000100000005000000153944DC9CC24D401AA88C7F9F6B4940153944DC9CC24D40CA1B60E63B6E4940ABCB290131C74D40CA1B60E63B6E4940ABCB290131C74D401AA88C7F9F6B4940153944DC9CC24D401AA88C7F9F6B4940
24684	Кужанберля	7	69	1612	59.055399000000001	59.071758000000003	50.714367000000003	50.703467000000003	0103000020E61000000100000005000000959D7E5017874D405A68E7340B5A4940959D7E5017874D40BB2BBB60705B4940FA9CBB5D2F894D40BB2BBB60705B4940FA9CBB5D2F894D405A68E7340B5A4940959D7E5017874D405A68E7340B5A4940
24910	Красночабанский	7	69	1612	58.786417	58.806099000000003	51.017502999999998	51.004576999999998	0103000020E610000001000000050000005C02F04FA9644D402AA8A8FA958049405C02F04FA9644D407B4ACE893D8249404E2B85402E674D407B4ACE893D8249404E2B85402E674D402AA8A8FA958049405C02F04FA9644D402AA8A8FA95804940
56188	Корсуньский	7	69	1612	59.244000999999997	59.25797	50.946956	50.925834999999999	0103000020E610000001000000050000007C98BD6C3B9F4D40FF3EE3C2817649407C98BD6C3B9F4D402060ADDA35794940B0AC342905A14D402060ADDA35794940B0AC342905A14D40FF3EE3C2817649407C98BD6C3B9F4D40FF3EE3C281764940
24935	Кинжебулак	7	69	1612	58.769035000000002	58.799639999999997	50.941349000000002	50.925902999999998	0103000020E610000001000000050000005C3D27BD6F624D40572250FD837649405C3D27BD6F624D40A88FC01F7E7849406649809A5A664D40A88FC01F7E7849406649809A5A664D40572250FD837649405C3D27BD6F624D40572250FD83764940
25206	Караганда	7	69	1612	59.708798000000002	59.725200999999998	50.705817000000003	50.693401999999999	0103000020E6100000010000000500000030BC92E4B9DA4D40917D9065C158494030BC92E4B9DA4D40FDFA2136585A49406403E962D3DC4D40FDFA2136585A49406403E962D3DC4D40917D9065C158494030BC92E4B9DA4D40917D9065C1584940
24594	Камсак	7	69	1612	59.227023000000003	59.262030000000003	50.864443000000001	50.845996999999997	0103000020E610000001000000050000004C38F4160F9D4D40CEC133A1496C49404C38F4160F9D4D40C9207711A66E49401349F4328AA14D40C9207711A66E49401349F4328AA14D40CEC133A1496C49404C38F4160F9D4D40CEC133A1496C4940
56168	Истемис	7	69	1612	59.083238000000001	59.097171000000003	50.918669000000001	50.905016000000003	0103000020E6100000010000000500000069E4F38AA78A4D40AA2D7590D773494069E4F38AA78A4D40AD6C1FF296754940508F6D19708C4D40AD6C1FF296754940508F6D19708C4D40AA2D7590D773494069E4F38AA78A4D40AA2D7590D7734940
56134	Зарево	7	69	1612	59.595529999999997	59.621428000000002	50.937603000000003	50.919469999999997	0103000020E61000000100000005000000B8E4B8533ACC4D4099D36531B1754940B8E4B8533ACC4D40D5D0066003784940CB68E4F38ACF4D40D5D0066003784940CB68E4F38ACF4D4099D36531B1754940B8E4B8533ACC4D4099D36531B1754940
46709	Екатеринославка	7	69	1612	58.680011999999998	58.696773999999998	50.903221000000002	50.895347999999998	0103000020E610000001000000050000009B711AA20A574D40FE4465C39A7249409B711AA20A574D40BC07E8BE9C734940FF59F3E32F594D40BC07E8BE9C734940FF59F3E32F594D40FE4465C39A7249409B711AA20A574D40FE4465C39A724940
25307	Домбаровский	7	69	1612	59.515166000000001	59.571643000000002	50.793446000000003	50.727699999999999	0103000020E610000001000000050000006D01A1F5F0C14D404CA60A46255D49406D01A1F5F0C14D402E9276A38F65494061FE0A992BC94D402E9276A38F65494061FE0A992BC94D404CA60A46255D49406D01A1F5F0C14D404CA60A46255D4940
24504	Домбаровка	7	69	1612	59.313718999999999	59.344647999999999	50.873958999999999	50.846269999999997	0103000020E610000001000000050000002191B6F127A84D40FFCA4A93526C49402191B6F127A84D40BE8575E3DD6F4940DF50F86C1DAC4D40BE8575E3DD6F4940DF50F86C1DAC4D40FFCA4A93526C49402191B6F127A84D40FFCA4A93526C4940
24775	Голубой Факел	7	69	1612	59.330392000000003	59.341746000000001	50.882221999999999	50.876806000000002	0103000020E61000000100000005000000166EF9484AAA4D40E277D32D3B704940166EF9484AAA4D40E6E786A6EC704940F8C43A55BEAB4D40E6E786A6EC704940F8C43A55BEAB4D40E277D32D3B704940166EF9484AAA4D40E277D32D3B704940
24691	Бояровка	7	69	1612	59.283410000000003	59.312128999999999	50.761208000000003	50.742699000000002	0103000020E6100000010000000500000000AE64C746A44D40CEE2C5C2105F494000AE64C746A44D400FBA84436F6149400C91D3D7F3A74D400FBA84436F6149400C91D3D7F3A74D40CEE2C5C2105F494000AE64C746A44D40CEE2C5C2105F4940
24795	Богоявленка	7	69	1612	59.706040000000002	59.744264000000001	50.834302999999998	50.824545999999998	0103000020E610000001000000050000007CD5CA845FDA4D4018062CB98A6949407CD5CA845FDA4D4033FAD170CA6A49408ACBF10A44DF4D4033FAD170CA6A49408ACBF10A44DF4D4018062CB98A6949407CD5CA845FDA4D4018062CB98A694940
56052	Ащибутак	7	69	1612	59.097036000000003	59.126510000000003	51.065928999999997	51.038978999999998	0103000020E610000001000000050000007044F7AC6B8C4D408A1D8D43FD8449407044F7AC6B8C4D40D26D895C70884940F94ECC7A31904D40D26D895C70884940F94ECC7A31904D408A1D8D43FD8449407044F7AC6B8C4D408A1D8D43FD844940
46457	Архангельское	7	69	1612	59.249623999999997	59.268965000000001	50.799185000000001	50.785411000000003	0103000020E61000000100000005000000FA25E2ADF39F4D409775FF5888644940FA25E2ADF39F4D40153AAFB14B6649406362F3716DA24D40153AAFB14B6649406362F3716DA24D409775FF5888644940FA25E2ADF39F4D409775FF5888644940
24983	Аккудук	7	69	1612	59.041682000000002	59.052812000000003	51.002637999999997	50.995978000000001	0103000020E610000001000000050000007B6AF5D555854D408BC404357C7F49407B6AF5D555854D4009DD2571568049400E6B2A8BC2864D4009DD2571568049400E6B2A8BC2864D408BC404357C7F49407B6AF5D555854D408BC404357C7F4940
56046	п. Каргала	7	69	2990	55.150899000000003	55.196218999999999	51.961750000000002	51.938969	0103000020E61000000100000005000000E3FF8EA850934B409A7ADD2230F84940E3FF8EA850934B40C976BE9F1AFB49404AED45B41D994B40C976BE9F1AFB49404AED45B41D994B409A7ADD2230F84940E3FF8EA850934B409A7ADD2230F84940
48178	Якутино	7	69	1521	52.823884999999997	52.844493	53.021566999999997	53.011307000000002	0103000020E610000001000000050000001D554D1075694A40A29BFD8172814A401D554D1075694A401FD61BB5C2824A40B859BC58186C4A401FD61BB5C2824A40B859BC58186C4A40A29BFD8172814A401D554D1075694A40A29BFD8172814A40
46299	Ягодное	7	69	1521	52.922421	52.943702000000002	53.047088000000002	53.029528999999997	0103000020E6100000010000000500000062122EE411764A404CA4349BC7834A4062122EE411764A405C04C6FA06864A40BC95253ACB784A405C04C6FA06864A40BC95253ACB784A404CA4349BC7834A4062122EE411764A404CA4349BC7834A40
46338	Урицкое	7	69	1521	53.075108	53.095759999999999	53.069667000000003	53.049919000000003	0103000020E6100000010000000500000080D591239D894A407A39ECBE63864A4080D591239D894A40234E27D9EA884A40EA211ADD418C4A40234E27D9EA884A40EA211ADD418C4A407A39ECBE63864A4080D591239D894A407A39ECBE63864A40
24054	Таллы	7	69	1521	53.047727000000002	53.079949999999997	53.147007000000002	53.130541999999998	0103000020E610000001000000050000006F1118EB1B864A409160AA99B5904A406F1118EB1B864A403CA41820D1924A4058A835CD3B8A4A403CA41820D1924A4058A835CD3B8A4A409160AA99B5904A406F1118EB1B864A409160AA99B5904A40
23954	Старояшкино	7	69	1521	52.914012999999997	52.965018999999998	52.823849000000003	52.804538000000001	0103000020E61000000100000005000000368FC360FE744A40D331E719FB664A40368FC360FE744A40D1EB4FE273694A4062821ABE857B4A40D1EB4FE273694A4062821ABE857B4A40D331E719FB664A40368FC360FE744A40D331E719FB664A40
46304	Саблино	7	69	1521	53.282528999999997	53.305813000000001	53.012141	52.993445000000001	0103000020E61000000100000005000000F69507E929A44A40F7AFAC34297F4A40F69507E929A44A406AF816D68D814A4088D860E124A74A406AF816D68D814A4088D860E124A74A40F7AFAC34297F4A40F69507E929A44A40F7AFAC34297F4A40
56099	Русское Игнашкино	7	69	1521	53.022269000000001	53.051976000000003	52.952188999999997	52.938118000000003	0103000020E61000000100000005000000795BE9B5D9824A40FCE4284014784A40795BE9B5D9824A40334E4354E1794A40A5164A26A7864A40334E4354E1794A40A5164A26A7864A40FCE4284014784A40795BE9B5D9824A40FCE4284014784A40
24098	Революционер	7	69	1521	52.924621999999999	52.938851999999997	53.109309000000003	53.094078000000003	0103000020E61000000100000005000000C09481035A764A40F5A276BF0A8C4A40C09481035A764A4049145AD6FD8D4A4060E4654D2C784A4049145AD6FD8D4A4060E4654D2C784A40F5A276BF0A8C4A40C09481035A764A40F5A276BF0A8C4A40
17882	Покровка	7	69	1521	53.054285	53.089390999999999	52.802076999999997	52.784162000000002	0103000020E61000000100000005000000E9D495CFF2864A400B62A06B5F644A40E9D495CFF2864A40D8EF8975AA664A4043C70E2A718B4A40D8EF8975AA664A4043C70E2A718B4A400B62A06B5F644A40E9D495CFF2864A400B62A06B5F644A40
46096	Победа	7	69	1521	52.776795	52.792552000000001	53.108308999999998	53.090319999999998	0103000020E610000001000000050000002159C0046E634A405D16139B8F8B4A402159C0046E634A40656EBE11DD8D4A4090300C5872654A40656EBE11DD8D4A4090300C5872654A405D16139B8F8B4A402159C0046E634A405D16139B8F8B4A40
56090	Петро-Херсонец	7	69	1521	53.020302000000001	53.064086000000003	53.023674	53.013609000000002	0103000020E610000001000000050000008E05854199824A4034F790F0BD814A408E05854199824A40FCE1E7BF07834A40D41055F833884A40FCE1E7BF07834A40D41055F833884A4034F790F0BD814A408E05854199824A4034F790F0BD814A40
49499	Новоникольское	7	69	1521	53.113959999999999	53.136507999999999	52.874084000000003	52.856465	0103000020E61000000100000005000000AD86C43D968E4A40969526A5A06D4A40AD86C43D968E4A407BFA08FCE16F4A4039D2191879914A407BFA08FCE16F4A4039D2191879914A40969526A5A06D4A40AD86C43D968E4A40969526A5A06D4A40
24011	Малояшкино	7	69	1521	52.815629999999999	52.830235999999999	52.790512	52.779020000000003	0103000020E6100000010000000500000078D1579066684A40087767EDB6634A4078D1579066684A403B8C497F2F654A401EFB592C456A4A403B8C497F2F654A401EFB592C456A4A40087767EDB6634A4078D1579066684A40087767EDB6634A40
47232	Луговое	7	69	1521	52.937702000000002	52.942005000000002	53.102080999999998	53.092553000000002	0103000020E6100000010000000500000068B27F9E06784A40C712D6C6D88B4A4068B27F9E06784A4080457EFD108D4A4091D5AD9E93784A4080457EFD108D4A4091D5AD9E93784A40C712D6C6D88B4A4068B27F9E06784A40C712D6C6D88B4A40
56074	Ключи	7	69	1521	52.72401	52.744850999999997	52.959642000000002	52.942286000000003	0103000020E610000001000000050000000DFD135CAC5C4A4045BDE0D39C784A400DFD135CAC5C4A401CEF8E8CD57A4A404AB20E47575F4A401CEF8E8CD57A4A404AB20E47575F4A4045BDE0D39C784A400DFD135CAC5C4A4045BDE0D39C784A40
46010	Каликино	7	69	1521	53.147421999999999	53.165244999999999	52.917050000000003	52.912070999999997	0103000020E61000000100000005000000FF5A5EB9DE924A40A45016BEBE744A40FF5A5EB9DE924A40FE65F7E461754A40EC6987BF26954A40FE65F7E461754A40EC6987BF26954A40A45016BEBE744A40FF5A5EB9DE924A40A45016BEBE744A40
23712	Ждамировка	7	69	1521	52.963177999999999	52.995885999999999	53.021712999999998	53.012650000000001	0103000020E61000000100000005000000041DAD6A497B4A40AF25E4839E814A40041DAD6A497B4A40F372D87DC7824A40AA454431797F4A40F372D87DC7824A40AA454431797F4A40AF25E4839E814A40041DAD6A497B4A40AF25E4839E814A40
23434	Ероховка	7	69	1521	52.636496999999999	52.683298999999998	52.906281	52.891472999999998	0103000020E610000001000000050000004580D3BB78514A402D228AC91B724A404580D3BB78514A403BFE0B0401744A40DB31755776574A403BFE0B0401744A40DB31755776574A402D228AC91B724A404580D3BB78514A402D228AC91B724A40
48869	Грачевка	7	69	1521	52.827910000000003	52.894815999999999	52.929080999999996	52.910936	0103000020E61000000100000005000000040473F4F8694A40E15F048D99744A40040473F4F8694A40E02A4F20EC764A4001F8A75489724A40E02A4F20EC764A4001F8A75489724A40E15F048D99744A40040473F4F8694A40E15F048D99744A40
47571	Володарский	7	69	1521	52.799999	52.805649000000003	53.053102000000003	53.047359	0103000020E6100000010000000500000096EA025E66664A40EC1516DC0F864A4096EA025E66664A4015ADDC0BCC864A400E87A5811F674A4015ADDC0BCC864A400E87A5811F674A40EC1516DC0F864A4096EA025E66664A40EC1516DC0F864A40
56098	Верхигнашкино	7	69	1521	53.056980000000003	53.089112999999998	52.960559000000003	52.947972999999998	0103000020E610000001000000050000005743E21E4B874A40D93EE42D57794A405743E21E4B874A407270E998F37A4A400053060E688B4A407270E998F37A4A400053060E688B4A40D93EE42D57794A405743E21E4B874A40D93EE42D57794A40
40525	Александровка	7	69	1521	53.303576999999997	53.340972999999998	53.088172999999998	53.069310000000002	0103000020E61000000100000005000000AD68739CDBA64A4094A46B26DF884A40AD68739CDBA64A40F2B1BB40498B4A40D5E8D500A5AB4A40F2B1BB40498B4A40D5E8D500A5AB4A4094A46B26DF884A40AD68739CDBA64A4094A46B26DF884A40
23916	Абрышкино	7	69	1521	52.959854	52.988734999999998	52.946334	52.939323000000002	0103000020E61000000100000005000000A777F17EDC7A4A40B8B06EBC3B784A40A777F17EDC7A4A40E38BF67821794A408DB454DE8E7E4A40E38BF67821794A408DB454DE8E7E4A40B8B06EBC3B784A40A777F17EDC7A4A40B8B06EBC3B784A40
45552	Хмелевка	7	69	618	57.859706000000003	57.874654	51.247722000000003	51.238515	0103000020E610000001000000050000006616A1D80AEE4C407F4DD6A8879E49406616A1D80AEE4C40F73FC05AB59F494065A88AA9F4EF4C40F73FC05AB59F494065A88AA9F4EF4C407F4DD6A8879E49406616A1D80AEE4C407F4DD6A8879E4940
45372	Халилово	7	69	618	58.115079000000001	58.138596999999997	51.405171000000003	51.394022	0103000020E610000001000000050000006BBA9EE8BA0E4D40C7F319506FB249406BBA9EE8BA0E4D40D124B1A4DCB349406F29E78BBD114D40D124B1A4DCB349406F29E78BBD114D40C7F319506FB249406BBA9EE8BA0E4D40C7F319506FB24940
49455	Уральск	7	69	618	58.628430000000002	58.661416000000003	51.596206000000002	51.586286000000001	0103000020E61000000100000005000000A3E9EC6470504D40240D6E6B0BCB4940A3E9EC6470504D40E9D66B7A50CC49408C868C47A9544D40E9D66B7A50CC49408C868C47A9544D40240D6E6B0BCB4940A3E9EC6470504D40240D6E6B0BCB4940
22328	Узембаево	7	69	618	58.167369999999998	58.191274	51.316785000000003	51.301487999999999	0103000020E610000001000000050000006F2A52616C154D407711A62897A649406F2A52616C154D40836E2F698CA849409D499BAA7B184D40836E2F698CA849409D499BAA7B184D407711A62897A649406F2A52616C154D407711A62897A64940
49429	Терекла	7	69	618	58.604095000000001	58.619222999999998	51.644565	51.633436000000003	0103000020E61000000100000005000000AC5626FC524D4D40F60D4C6E14D14940AC5626FC524D4D40B8921D1B81D249402BF702B3424F4D40B8921D1B81D249402BF702B3424F4D40F60D4C6E14D14940AC5626FC524D4D40F60D4C6E14D14940
22158	Старохалилово	7	69	618	58.101101	58.120406000000003	51.450927	51.441063999999997	0103000020E61000000100000005000000E44BA8E0F00C4D40B2B8FFC874B84940E44BA8E0F00C4D4013F1D6F9B7B94940001FBC76690F4D4013F1D6F9B7B94940001FBC76690F4D40B2B8FFC874B84940E44BA8E0F00C4D40B2B8FFC874B84940
58937	Северовка	7	69	618	58.444643999999997	58.461019999999998	51.404294	51.387773000000003	0103000020E610000001000000050000006A2E3718EA384D40CBA2B08BA2B149406A2E3718EA384D4009FCE1E7BFB34940A5660FB4023B4D4009FCE1E7BFB34940A5660FB4023B4D40CBA2B08BA2B149406A2E3718EA384D40CBA2B08BA2B14940
21880	Репино	7	69	618	58.397069000000002	58.412376000000002	51.347658000000003	51.330191999999997	0103000020E61000000100000005000000B2A03028D3324D404EB340BB43AA4940B2A03028D3324D40AD18AE0E80AC4940E1D39CBCC8344D40AD18AE0E80AC4940E1D39CBCC8344D404EB340BB43AA4940B2A03028D3324D404EB340BB43AA4940
49548	Поповка	7	69	618	58.416238999999997	58.441885999999997	51.538201000000001	51.525258000000001	0103000020E61000000100000005000000ED28CE5147354D402FFB75A73BC34940ED28CE5147354D4056D636C5E3C44940B6476FB88F384D4056D636C5E3C44940B6476FB88F384D402FFB75A73BC34940ED28CE5147354D402FFB75A73BC34940
56187	Пласковский	7	69	618	58.682679	58.698041000000003	51.434899999999999	51.426088999999997	0103000020E610000001000000050000003F55850662574D40B91798158AB649403F55850662574D40E4839ECDAAB749403222516859594D40E4839ECDAAB749403222516859594D40B91798158AB649403F55850662574D40B91798158AB64940
46871	Писаревка	7	69	618	58.390160999999999	58.400841999999997	51.604866000000001	51.579518999999998	0103000020E610000001000000050000005B96AFCBF0314D408F34B8AD2DCA49405B96AFCBF0314D402E3BC43F6CCD49407E6E68CA4E334D402E3BC43F6CCD49407E6E68CA4E334D408F34B8AD2DCA49405B96AFCBF0314D408F34B8AD2DCA4940
10888	Новорудный	7	69	618	58.172041	58.203454999999998	51.511561	51.497708000000003	0103000020E610000001000000050000001B49827005164D40927A4FE5B4BF49401B49827005164D405C74B2D47AC14940959A3DD00A1A4D405C74B2D47AC14940959A3DD00A1A4D40927A4FE5B4BF49401B49827005164D40927A4FE5B4BF4940
22422	Новопетропавловка	7	69	618	58.157794000000003	58.180306000000002	51.652130999999997	51.629075	0103000020E61000000100000005000000A5C0029832144D4098DD938785D04940A5C0029832144D4098DA520779D34940E4A25A4414174D4098DA520779D34940E4A25A4414174D4098DD938785D04940A5C0029832144D4098DD938785D04940
49595	Новониколаевка	7	69	618	58.330603000000004	58.370173999999999	51.653874999999999	51.623176999999998	0103000020E61000000100000005000000D17AF832512A4D40484F9143C4CF4940D17AF832512A4D4004560E2DB2D349402DEA93DC612F4D4004560E2DB2D349402DEA93DC612F4D40484F9143C4CF4940D17AF832512A4D40484F9143C4CF4940
45537	Новокиевка	7	69	618	58.146044000000003	58.177906999999998	51.537785999999997	51.518465999999997	0103000020E6100000010000000500000076E3DD91B1124D40410B09185DC2494076E3DD91B1124D40921FF12BD6C449405F5D15A8C5164D40921FF12BD6C449405F5D15A8C5164D40410B09185DC2494076E3DD91B1124D40410B09185DC24940
56121	Новоказачий	7	69	618	58.668342000000003	58.682760000000002	51.292532999999999	51.282760000000003	0103000020E6100000010000000500000089450C3B8C554D40F94ECC7A31A4494089450C3B8C554D401900AAB871A549402C82FFAD64574D401900AAB871A549402C82FFAD64574D40F94ECC7A31A4494089450C3B8C554D40F94ECC7A31A44940
22153	Нововоронежский	7	69	618	58.144337	58.167656999999998	51.412272000000002	51.395927	0103000020E61000000100000005000000274D83A279124D403C4D66BCADB24940274D83A279124D403C873254C5B4494005F9D9C875154D403C873254C5B4494005F9D9C875154D403C4D66BCADB24940274D83A279124D403C4D66BCADB24940
21494	Новоактюбинск	7	69	618	58.660716000000001	58.674855000000001	51.565871999999999	51.558951999999998	0103000020E61000000100000005000000D3F8855792544D40530438BD8BC74940D3F8855792544D406EDC627E6EC8494063450DA661564D406EDC627E6EC8494063450DA661564D40530438BD8BC74940D3F8855792544D40530438BD8BC74940
22246	Нарбулатово	7	69	618	58.190114999999999	58.203608000000003	51.39405	51.385243000000003	0103000020E6100000010000000500000051BD35B055184D40A80183A44FB1494051BD35B055184D40917EFB3A70B249401C9AB2D30F1A4D40917EFB3A70B249401C9AB2D30F1A4D40A80183A44FB1494051BD35B055184D40A80183A44FB14940
56180	Лылов	7	69	618	58.036701000000001	58.059994000000003	51.391274000000003	51.375191999999998	0103000020E61000000100000005000000815D4D9EB2044D4044DC9C4A06B04940815D4D9EB2044D4037E3344415B2494066FA25E2AD074D4037E3344415B2494066FA25E2AD074D4044DC9C4A06B04940815D4D9EB2044D4044DC9C4A06B04940
21578	Колпакское	7	69	618	58.711066000000002	58.736973999999996	51.496665	51.472642999999998	0103000020E6100000010000000500000016A6EF35045B4D4077D7D9907FBC494016A6EF35045B4D40AF08FEB792BF49404B00FE29555E4D40AF08FEB792BF49404B00FE29555E4D4077D7D9907FBC494016A6EF35045B4D4077D7D9907FBC4940
21905	Камейкино	7	69	618	58.419742999999997	58.445945999999999	51.518785999999999	51.503684999999997	0103000020E61000000100000005000000CADC7C23BA354D402D3E05C078C04940CADC7C23BA354D40B3CF639467C2494019E42EC214394D40B3CF639467C2494019E42EC214394D402D3E05C078C04940CADC7C23BA354D402D3E05C078C04940
49591	Ишкинино	7	69	618	58.277970000000003	58.292406	51.465601999999997	51.450679999999998	0103000020E6100000010000000500000073A25D8594234D400B7BDAE1AFB9494073A25D8594234D40E179A9D898BB4940BC934F8F6D254D40E179A9D898BB4940BC934F8F6D254D400B7BDAE1AFB9494073A25D8594234D400B7BDAE1AFB94940
21389	Ириклинский	7	69	618	58.629911999999997	58.649514000000003	51.680118	51.666998	0103000020E61000000100000005000000D1ADD7F4A0504D40AB3FC23060D54940D1ADD7F4A0504D40E1B54B1B0ED74940A725564623534D40E1B54B1B0ED74940A725564623534D40AB3FC23060D54940D1ADD7F4A0504D40AB3FC23060D54940
22412	Ижберда	7	69	618	58.002744999999997	58.043573000000002	51.295434	51.280540000000002	0103000020E610000001000000050000001F9DBAF259004D40249C16BCE8A349401F9DBAF259004D40301004C8D0A549408BFED0CC93054D40301004C8D0A549408BFED0CC93054D40249C16BCE8A349401F9DBAF259004D40249C16BCE8A34940
10984	Губерля	7	69	618	57.937275	57.955547000000003	51.139741999999998	51.132728999999998	0103000020E61000000100000005000000E02D90A0F8F74C408A1D8D43FD904940E02D90A0F8F74C4056F0DB10E39149403D65355D4FFA4C4056F0DB10E39149403D65355D4FFA4C408A1D8D43FD904940E02D90A0F8F74C408A1D8D43FD904940
22287	Гайнулино	7	69	618	58.292819999999999	58.307713999999997	51.364063999999999	51.355966000000002	0103000020E61000000100000005000000AFCE31207B254D40753E3C4B90AD4940AFCE31207B254D4052D32EA699AE4940BB421F2C63274D4052D32EA699AE4940BB421F2C63274D40753E3C4B90AD4940AFCE31207B254D40753E3C4B90AD4940
49424	Вишневое	7	69	618	58.529625000000003	58.551597000000001	51.710225000000001	51.688834	0103000020E610000001000000050000006F1283C0CA434D40BA2F67B62BD849406F1283C0CA434D409BE61DA7E8DA49402EC901BB9A464D409BE61DA7E8DA49402EC901BB9A464D40BA2F67B62BD849406F1283C0CA434D40BA2F67B62BD84940
22618	Белошапка	7	69	618	58.080530000000003	58.096851999999998	51.224629	51.21443	0103000020E61000000100000005000000672C9ACE4E0A4D4001A43671729B4940672C9ACE4E0A4D40D95DA0A4C09C4940AE4676A5650C4D40D95DA0A4C09C4940AE4676A5650C4D4001A43671729B4940672C9ACE4E0A4D4001A43671729B4940
21665	Банное	7	69	618	58.720804000000001	58.742390999999998	51.359661000000003	51.341897000000003	0103000020E61000000100000005000000BA69334E435C4D40DECCE847C3AB4940BA69334E435C4D40C652245F09AE494020EC14AB065F4D40C652245F09AE494020EC14AB065F4D40DECCE847C3AB4940BA69334E435C4D40DECCE847C3AB4940
18455	Шахматовка	7	69	1489	52.495524000000003	52.524037	52.867213	52.850085999999997	0103000020E610000001000000050000000A3197546D3F4A40CB64389ECF6C4A400A3197546D3F4A4041D5E8D5006F4A406D72F8A413434A4041D5E8D5006F4A406D72F8A413434A40CB64389ECF6C4A400A3197546D3F4A40CB64389ECF6C4A40
19187	Тупиковка	7	69	1489	51.985073999999997	52.053714999999997	52.808228999999997	52.774858000000002	0103000020E61000000100000005000000E811A3E716FE4940A185048C2E634A40E811A3E716FE4940E256410C74674A40FE261422E0064A40E256410C74674A40FE261422E0064A40A185048C2E634A40E811A3E716FE4940A185048C2E634A40
56062	Троицкое	7	69	1489	52.497391999999998	52.547455999999997	53.113157000000001	53.099156000000001	0103000020E6100000010000000500000061A5828AAA3F4A40E199D024B18C4A4061A5828AAA3F4A402028B7ED7B8E4A40DEFFC70913464A402028B7ED7B8E4A40DEFFC70913464A40E199D024B18C4A4061A5828AAA3F4A40E199D024B18C4A40
48845	Твердилово	7	69	1489	52.398713000000001	52.420146000000003	53.017353	52.99615	0103000020E61000000100000005000000BABE0F0709334A4088F4DBD7817F4A40BABE0F0709334A4066BE839F38824A40CAC51858C7354A4066BE839F38824A40CAC51858C7354A4088F4DBD7817F4A40BABE0F0709334A4088F4DBD7817F4A40
19274	Сухоречка	7	69	1489	52.360768	52.456977000000002	52.833866	52.796512999999997	0103000020E61000000100000005000000BFB854A52D2E4A405FEB5223F4654A40BFB854A52D2E4A40889FFF1EBC6A4A401903EB387E3A4A40889FFF1EBC6A4A401903EB387E3A4A405FEB5223F4654A40BFB854A52D2E4A405FEB5223F4654A40
18736	Старая Тепловка	7	69	1489	52.560130999999998	52.583540999999997	52.786112000000003	52.766320999999998	0103000020E61000000100000005000000E63C635FB2474A40779E78CE16624A40E63C635FB2474A40207F69519F644A400470B378B14A4A40207F69519F644A400470B378B14A4A40779E78CE16624A40E63C635FB2474A40779E78CE16624A40
19577	Проскурино	7	69	1489	51.910586000000002	51.964852999999998	52.666437999999999	52.647433999999997	0103000020E61000000100000005000000051901158EF44940C328081EDF524A40051901158EF44940E46723D74D554A404739984D80FB4940E46723D74D554A404739984D80FB4940C328081EDF524A40051901158EF44940C328081EDF524A40
18926	Подколки	7	69	1489	52.505952999999998	52.523471000000001	53.000132999999998	52.977311999999998	0103000020E6100000010000000500000013286211C3404A4082FE428F187D4A4013286211C3404A403F53AF5B04804A40C4B3041901434A403F53AF5B04804A40C4B3041901434A4082FE428F187D4A4013286211C3404A4082FE428F187D4A40
18598	Перевозинка	7	69	1489	52.225419000000002	52.262393000000003	52.678648000000003	52.664603	0103000020E61000000100000005000000D272A087DA1C4A4068E90AB611554A40D272A087DA1C4A4077BF0AF0DD564A4084D9041896214A4077BF0AF0DD564A4084D9041896214A4068E90AB611554A40D272A087DA1C4A4068E90AB611554A40
48127	Партизанский	7	69	1489	52.129109999999997	52.142530999999998	53.005878000000003	52.996177000000003	0103000020E6100000010000000500000014CB2DAD86104A4082035ABA827F4A4014CB2DAD86104A4009E23C9CC0804A4045D5AF743E124A4009E23C9CC0804A4045D5AF743E124A4082035ABA827F4A4014CB2DAD86104A4082035ABA827F4A40
18822	Палимовка	7	69	1489	52.174906	52.243295000000003	52.847878000000001	52.831200000000003	0103000020E61000000100000005000000E5EFDE5163164A40B537F8C2646A4A40E5EFDE5163164A40BB7F2C44876C4A40E223624A241F4A40BB7F2C44876C4A40E223624A241F4A40B537F8C2646A4A40E5EFDE5163164A40B537F8C2646A4A40
48636	Новая Тепловка	7	69	1489	52.584781	52.628151000000003	52.841427000000003	52.818232999999999	0103000020E610000001000000050000003D29931ADA4A4A4005C1E3DBBB684A403D29931ADA4A4A40577C43E1B36B4A4090F9804067504A40577C43E1B36B4A4090F9804067504A4005C1E3DBBB684A403D29931ADA4A4A4005C1E3DBBB684A40
48722	Новая Казанка	7	69	1489	52.542110999999998	52.561577	52.965620000000001	52.948684	0103000020E61000000100000005000000A3E6ABE463454A40861E317A6E794A40A3E6ABE463454A40882EA86F997B4A40C89750C1E1474A40882EA86F997B4A40C89750C1E1474A40861E317A6E794A40A3E6ABE463454A40861E317A6E794A40
18854	Новая Елшанка	7	69	1489	52.123038000000001	52.160147000000002	52.844597999999998	52.833615999999999	0103000020E6100000010000000500000027158DB5BF0F4A400FB6D8EDB36A4A4027158DB5BF0F4A402D228AC91B6C4A40B9C667B27F144A402D228AC91B6C4A40B9C667B27F144A400FB6D8EDB36A4A4027158DB5BF0F4A400FB6D8EDB36A4A40
17951	Никифоровка	7	69	1489	52.502639000000002	52.517136999999998	52.732742999999999	52.720520999999998	0103000020E61000000100000005000000DA58897956404A40658A39083A5C4A40DA58897956404A40BCAFCA85CA5D4A409946938B31424A40BCAFCA85CA5D4A409946938B31424A40658A39083A5C4A40DA58897956404A40658A39083A5C4A40
17449	Нижняя Вязовка	7	69	1489	52.629517	52.654463	52.723483000000002	52.692605999999998	0103000020E6100000010000000500000055A3570394504A40B6813B50A7584A4055A3570394504A40221B48179B5C4A4095B88E71C5534A40221B48179B5C4A4095B88E71C5534A40B6813B50A7584A4055A3570394504A40B6813B50A7584A40
18508	Могутово	7	69	1489	52.129370999999999	52.176245000000002	53.162958000000003	53.144278999999997	0103000020E6100000010000000500000081069B3A8F104A40F23FF9BB77924A4081069B3A8F104A40904FC8CEDB944A40B18A37328F164A40904FC8CEDB944A40B18A37328F164A40F23FF9BB77924A4081069B3A8F104A40F23FF9BB77924A40
48512	Лисья Поляна	7	69	1489	52.381402000000001	52.401829999999997	52.945824000000002	52.933841000000001	0103000020E610000001000000050000008350DEC7D1304A40FC54151A88774A408350DEC7D1304A40CEE2C5C210794A409D465A2A6F334A40CEE2C5C210794A409D465A2A6F334A40FC54151A88774A408350DEC7D1304A40FC54151A88774A40
48487	Липовка	7	69	1489	52.028930000000003	52.061449000000003	52.714477000000002	52.691214000000002	0103000020E61000000100000005000000C8EF6DFAB3034A40C8444AB379584A40C8EF6DFAB3034A40425F7AFB735B4A409BAF928FDD074A40425F7AFB735B4A409BAF928FDD074A40C8444AB379584A40C8EF6DFAB3034A40C8444AB379584A40
48384	Красногвардеец	7	69	1489	52.340879000000001	52.381168000000002	52.690085000000003	52.669207	0103000020E6100000010000000500000054724EECA12B4A408CA03193A8554A4054724EECA12B4A40E73A8DB454584A401024EF1CCA304A40E73A8DB454584A401024EF1CCA304A408CA03193A8554A4054724EECA12B4A408CA03193A8554A40
56193	Красная Слободка	7	69	1489	52.503338999999997	52.530890999999997	53.239299000000003	53.219171000000003	0103000020E6100000010000000500000092E68F696D404A40A69D9ACB0D9C4A4092E68F696D404A40967B8159A19E4A40D05E7D3CF4434A40967B8159A19E4A40D05E7D3CF4434A40A69D9ACB0D9C4A4092E68F696D404A40A69D9ACB0D9C4A40
19505	Колтубановский	7	69	1489	52.006535	52.055456999999997	52.952947999999999	52.930757999999997	0103000020E61000000100000005000000C2A38D23D6004A40C43E011423774A40C2A38D23D6004A40F1643733FA794A40C9AA083719074A40F1643733FA794A40C9AA083719074A40C43E011423774A40C2A38D23D6004A40C43E011423774A40
48414	Кировский	7	69	1489	52.305242999999997	52.320594999999997	52.642128	52.632055999999999	0103000020E610000001000000050000009D2ADF3312274A40CB9E0436E7504A409D2ADF3312274A4046EC134031524A406C21C84109294A4046EC134031524A406C21C84109294A40CB9E0436E7504A409D2ADF3312274A40CB9E0436E7504A40
17885	Каменная Сарма	7	69	1489	52.498291000000002	52.520201	52.672898000000004	52.654671999999998	0103000020E610000001000000050000001172DEFFC73F4A40AFCDC64ACC534A401172DEFFC73F4A409CC58B8521564A405A2C45F295424A409CC58B8521564A405A2C45F295424A40AFCDC64ACC534A401172DEFFC73F4A40AFCDC64ACC534A40
56060	Искра	7	69	1489	52.150418000000002	52.179380000000002	52.765351000000003	52.743848999999997	0103000020E61000000100000005000000685DA3E540134A40C614AC71365F4A40685DA3E540134A40FF7A8505F7614A403BC780ECF5164A40FF7A8505F7614A403BC780ECF5164A40C614AC71365F4A40685DA3E540134A40C614AC71365F4A40
17791	Жилинка	7	69	1489	52.694510000000001	52.716303000000003	53.079183	53.063206999999998	0103000020E610000001000000050000005B5F24B4E5584A406BF0BE2A17884A405B5F24B4E5584A4018B325AB228A4A406B8313D1AF5B4A4018B325AB228A4A406B8313D1AF5B4A406BF0BE2A17884A405B5F24B4E5584A406BF0BE2A17884A40
17760	Елшанка 1-я	7	69	1489	52.000813000000001	52.049177999999998	52.883991000000002	52.857748000000001	0103000020E61000000100000005000000B134F0A31A004A40CE1ABCAFCA6D4A40B134F0A31A004A40AB7AF99D26714A4062D7F6764B064A40AB7AF99D26714A4062D7F6764B064A40CE1ABCAFCA6D4A40B134F0A31A004A40CE1ABCAFCA6D4A40
48267	Елховка	7	69	1489	52.282138000000003	52.303105000000002	52.911195999999997	52.89752	0103000020E61000000100000005000000BC7A15191D244A40C2C073EFE1724A40BC7A15191D244A407D1F0E12A2744A4086200725CC264A407D1F0E12A2744A4086200725CC264A40C2C073EFE1724A40BC7A15191D244A40C2C073EFE1724A40
46964	Дмитриевка	7	69	1489	52.301065999999999	52.329577999999998	52.706882	52.687148000000001	0103000020E6100000010000000500000001F8A75489264A4083C13577F4574A4001F8A75489264A40C710001C7B5A4A4094BDA59C2F2A4A40C710001C7B5A4A4094BDA59C2F2A4A4083C13577F4574A4001F8A75489264A4083C13577F4574A40
48191	Державино	7	69	1489	52.312348999999998	52.381203999999997	53.218739999999997	53.204552	0103000020E610000001000000050000001AF8510DFB274A406B2A8BC22E9A4A401AF8510DFB274A40DC291DACFF9B4A405C8DEC4ACB304A40DC291DACFF9B4A405C8DEC4ACB304A406B2A8BC22E9A4A401AF8510DFB274A406B2A8BC22E9A4A40
48273	Воронцовка	7	69	1489	52.235013000000002	52.267153999999998	52.932875000000003	52.919206000000003	0103000020E610000001000000050000004391EEE7141E4A40BC24CE8AA8754A404391EEE7141E4A40C520B07268774A406F7F2E1A32224A40C520B07268774A406F7F2E1A32224A40BC24CE8AA8754A404391EEE7141E4A40BC24CE8AA8754A40
17355	Верхняя Вязовка	7	69	1489	52.666716000000001	52.700502	52.766179000000001	52.743746000000002	0103000020E6100000010000000500000027DC2BF356554A40F243A511335F4A4027DC2BF356554A40E5F0492712624A402C64AE0CAA594A40E5F0492712624A402C64AE0CAA594A40F243A511335F4A4027DC2BF356554A40F243A511335F4A40
48476	Булгаково	7	69	1489	52.458666000000001	52.480575999999999	53.259428	53.237730999999997	0103000020E61000000100000005000000C1E44691B53A4A40681F2BF86D9E4A40C1E44691B53A4A4056D5CBEF34A14A400A9FAD83833D4A4056D5CBEF34A14A400A9FAD83833D4A40681F2BF86D9E4A40C1E44691B53A4A40681F2BF86D9E4A40
56170	Бузулукское Лесничество	7	69	1489	52.312645000000003	52.323011999999999	52.791373	52.785850000000003	0103000020E61000000100000005000000042159C004284A40E3C798BB96644A40042159C004284A40FDF7E0B54B654A40971B0C7558294A40FDF7E0B54B654A40971B0C7558294A40E3C798BB96644A40042159C004284A40E3C798BB96644A40
48847	Березовка	7	69	1489	52.412582999999998	52.426586999999998	53.092916000000002	53.075581	0103000020E610000001000000050000005AF10D85CF344A40789961A3AC894A405AF10D85CF344A4038A3E6ABE48B4A400AF31E679A364A4038A3E6ABE48B4A400AF31E679A364A40789961A3AC894A405AF10D85CF344A40789961A3AC894A40
17218	Алдаркино	7	69	1489	51.839350000000003	51.862805000000002	52.826771000000001	52.809448000000003	0103000020E61000000100000005000000E5F21FD26FEB494004E8F7FD9B674A40E5F21FD26FEB4940FF23D3A1D3694A40A3E9EC6470EE4940FF23D3A1D3694A40A3E9EC6470EE494004E8F7FD9B674A40E5F21FD26FEB494004E8F7FD9B674A40
56042	Бузулук	7	69	7394	52.203499999999998	52.294319000000002	52.817318999999998	52.735588999999997	0103000020E61000000100000005000000355EBA490C1A4A400F26C5C7275E4A40355EBA490C1A4A4020B3B3E89D684A40B4CBB73EAC254A4020B3B3E89D684A40B4CBB73EAC254A400F26C5C7275E4A40355EBA490C1A4A400F26C5C7275E4A40
19688	Шестайкино	7	69	1214	52.568565999999997	52.595551	53.793922000000002	53.784230000000001	0103000020E610000001000000050000000BCF4BC5C6484A4063450DA661E44A400BCF4BC5C6484A4097C9703C9FE54A40D00CE2033B4C4A4097C9703C9FE54A40D00CE2033B4C4A4063450DA661E44A400BCF4BC5C6484A4063450DA661E44A40
15082	Турхановка	7	69	1214	52.455404999999999	52.469661000000002	53.771652000000003	53.750993999999999	0103000020E61000000100000005000000AAB706B64A3A4A4001BF469220E04A40AAB706B64A3A4A404EF2237EC5E24A40749A05DA1D3C4A404EF2237EC5E24A40749A05DA1D3C4A4001BF469220E04A40AAB706B64A3A4A4001BF469220E04A40
56175	Старые Узелки	7	69	1214	52.926921999999998	52.961651000000003	53.884067999999999	53.856991999999998	0103000020E61000000100000005000000B1F84D61A5764A408177F2E9B1ED4A40B1F84D61A5764A4056B8E52329F14A4036954561177B4A4056B8E52329F14A4036954561177B4A408177F2E9B1ED4A40B1F84D61A5764A408177F2E9B1ED4A40
15322	Старое Тюрино	7	69	1214	52.715369000000003	52.743296999999998	53.742336000000002	53.730697999999997	0103000020E610000001000000050000003FC91D36915B4A4055A0168387DD4A403FC91D36915B4A405D52B5DD04DF4A40821B295B245F4A405D52B5DD04DF4A40821B295B245F4A4055A0168387DD4A403FC91D36915B4A4055A0168387DD4A40
15851	Сапожкино	7	69	1214	52.903241999999999	52.934297000000001	53.951324999999997	53.932447000000003	0103000020E61000000100000005000000D32F116F9D734A406D205D6C5AF74A40D32F116F9D734A40006F8104C5F94A401EE0490B97774A40006F8104C5F94A401EE0490B97774A406D205D6C5AF74A40D32F116F9D734A406D205D6C5AF74A40
14281	Саловка	7	69	1214	52.309815	52.331339	53.751409000000002	53.744039999999998	0103000020E61000000100000005000000B6679604A8274A403A75E5B33CDF4A40B6679604A8274A40C5758C2B2EE04A40D671FC50692A4A40C5758C2B2EE04A40D671FC50692A4A403A75E5B33CDF4A40B6679604A8274A403A75E5B33CDF4A40
14411	Савруша	7	69	1214	52.384509999999999	52.406410999999999	53.853524	53.842019000000001	0103000020E61000000100000005000000137EA99F37314A4029CE5147C7EB4A40137EA99F37314A40F12C414640ED4A4009DE904605344A40F12C414640ED4A4009DE904605344A4029CE5147C7EB4A40137EA99F37314A4029CE5147C7EB4A40
15794	Русская Бокла	7	69	1214	52.815449999999998	52.832895000000001	53.933332999999998	53.897556999999999	0103000020E61000000100000005000000F8C264AA60684A40DFA5D425E3F24A40F8C264AA60684A4087A3AB7477F74A403F00A94D9C6A4A4087A3AB7477F74A403F00A94D9C6A4A40DFA5D425E3F24A40F8C264AA60684A40DFA5D425E3F24A40
15005	Резвый	7	69	1214	52.541015000000002	52.554839999999999	53.396538999999997	53.390788000000001	0103000020E610000001000000050000009ED2C1FA3F454A40AAD5575705B24A409ED2C1FA3F454A40554B3ACAC1B24A409E4143FF04474A40554B3ACAC1B24A409E4143FF04474A40AAD5575705B24A409ED2C1FA3F454A40AAD5575705B24A40
47410	Рабочий	7	69	1214	52.465277999999998	52.486306999999996	53.362951000000002	53.350552999999998	0103000020E610000001000000050000002EC6C03A8E3B4A40E141B3EBDEAC4A402EC6C03A8E3B4A407786A92D75AE4A406E68CA4E3F3E4A407786A92D75AE4A406E68CA4E3F3E4A40E141B3EBDEAC4A402EC6C03A8E3B4A40E141B3EBDEAC4A40
47523	Пронькино	7	69	1214	52.591858999999999	52.609161	53.785645000000002	53.757978999999999	0103000020E61000000100000005000000F06B2409C24B4A400307B47405E14A40F06B2409C24B4A400AA2EE0390E44A40D47FD6FCF84D4A400AA2EE0390E44A40D47FD6FCF84D4A400307B47405E14A40F06B2409C24B4A400307B47405E14A40
15665	Поникла	7	69	1214	52.469715000000001	52.506231999999997	53.556978000000001	53.535592999999999	0103000020E6100000010000000500000067B8019F1F3C4A40B77BB94F8EC44A4067B8019F1F3C4A40B64B1B0E4BC74A402618CE35CC404A40B64B1B0E4BC74A402618CE35CC404A40B77BB94F8EC44A4067B8019F1F3C4A40B77BB94F8EC44A40
58962	Полибино	7	69	1214	52.078265999999999	53.146254999999996	54.026699000000001	53.254396999999997	0103000020E61000000100000005000000C231CB9E040A4A40AA99B51490A04A40C231CB9E040A4A40FFEA71DF6A034B4030F0DC7BB8924A40FFEA71DF6A034B4030F0DC7BB8924A40AA99B51490A04A40C231CB9E040A4A40AA99B51490A04A40
47398	Пилюгино	7	69	1214	52.388283000000001	52.432758999999997	53.410491	53.395223000000001	0103000020E61000000100000005000000E04BE141B3314A4042D0D1AA96B24A40E04BE141B3314A40B32616F88AB44A405B069CA564374A40B32616F88AB44A405B069CA564374A4042D0D1AA96B24A40E04BE141B3314A4042D0D1AA96B24A40
33163	Передовка	7	69	1214	52.273802000000003	52.30686	53.678030999999997	53.663862999999999	0103000020E610000001000000050000002ACAA5F10B234A4021037976F9D44A402ACAA5F10B234A404B5645B8C9D64A40AC39403047274A404B5645B8C9D64A40AC39403047274A4021037976F9D44A402ACAA5F10B234A4021037976F9D44A40
47552	Октябрьский	7	69	1214	52.621073000000003	52.635615999999999	53.713937000000001	53.705137999999998	0103000020E61000000100000005000000DDB6EF517F4F4A405B9544F641DA4A40DDB6EF517F4F4A40C233A14962DB4A403C6876DD5B514A40C233A14962DB4A403C6876DD5B514A405B9544F641DA4A40DDB6EF517F4F4A405B9544F641DA4A40
14750	Нуштайкино	7	69	1214	52.216849000000003	52.240608999999999	53.621339999999996	53.594383000000001	0103000020E61000000100000005000000CD9541B5C11B4A403126FDBD14CC4A40CD9541B5C11B4A402BD9B11188CF4A40C70F9546CC1E4A402BD9B11188CF4A40C70F9546CC1E4A403126FDBD14CC4A40CD9541B5C11B4A403126FDBD14CC4A40
15280	Нойкино	7	69	1214	52.702342999999999	52.737197999999999	53.803665000000002	53.782273000000004	0103000020E610000001000000050000008AC91B60E6594A409CC58B8521E44A408AC91B60E6594A404DF8A57EDEE64A409B560A815C5E4A404DF8A57EDEE64A409B560A815C5E4A409CC58B8521E44A408AC91B60E6594A409CC58B8521E44A40
15161	Нижнепавлушкино	7	69	1214	52.978234	53.003818000000003	53.895806	53.872172999999997	0103000020E61000000100000005000000EAEA8EC5367D4A4023BA675DA3EF4A40EAEA8EC5367D4A40C1C760C5A9F24A406D91B41B7D804A40C1C760C5A9F24A406D91B41B7D804A4023BA675DA3EF4A40EAEA8EC5367D4A4023BA675DA3EF4A40
15759	Мордовский Бугуруслан	7	69	1214	52.509726000000001	52.540655000000001	53.806877	53.785502000000001	0103000020E61000000100000005000000E0F599B33E414A40A7785C548BE44A40E0F599B33E414A408272DBBE47E74A409EB5DB2E34454A408272DBBE47E74A409EB5DB2E34454A40A7785C548BE44A40E0F599B33E414A40A7785C548BE44A40
46875	Михайловка	7	69	1214	52.450302999999998	52.475734000000003	53.683987999999999	53.668179000000002	0103000020E6100000010000000500000035255987A3394A40DF6FB4E386D54A4035255987A3394A40A06D35EB8CD74A4032CC09DAE43C4A40A06D35EB8CD74A4032CC09DAE43C4A40DF6FB4E386D54A4035255987A3394A40DF6FB4E386D54A40
56129	Красноярка	7	69	1214	52.479973999999999	52.520766999999999	53.626147000000003	53.604412000000004	0103000020E610000001000000050000001477BCC96F3D4A40ADA7565F5DCD4A401477BCC96F3D4A4088BEBB9525D04A4003EB387EA8424A4088BEBB9525D04A4003EB387EA8424A40ADA7565F5DCD4A401477BCC96F3D4A40ADA7565F5DCD4A40
47177	Коровино	7	69	1214	53.012253000000001	53.079904999999997	53.840297	53.815314000000001	0103000020E6100000010000000500000092239D8191814A4048FC8A355CE84A4092239D8191814A40A5F622DA8EEB4A40B8E4B8533A8A4A40A5F622DA8EEB4A40B8E4B8533A8A4A4048FC8A355CE84A4092239D8191814A4048FC8A355CE84A40
14864	Коптяжево	7	69	1214	52.217396999999998	52.248218000000001	53.460529000000001	53.444502	0103000020E61000000100000005000000CF9F36AAD31B4A40D8800871E5B84A40CF9F36AAD31B4A4007EE409DF2BA4A40A723809BC51F4A4007EE409DF2BA4A40A723809BC51F4A40D8800871E5B84A40CF9F36AAD31B4A40D8800871E5B84A40
14810	Кокошеевка	7	69	1214	52.352314999999997	52.371538999999999	53.486769000000002	53.468617999999999	0103000020E61000000100000005000000F3716DA8182D4A409128B4ACFBBB4A40F3716DA8182D4A4073DA53724EBE4A40221807978E2F4A4073DA53724EBE4A40221807978E2F4A409128B4ACFBBB4A40F3716DA8182D4A409128B4ACFBBB4A40
46373	Козловка	7	69	1214	52.617291000000002	52.633299000000001	53.577930000000002	53.568230999999997	0103000020E61000000100000005000000BD8E3864034F4A4064C91CCBBBC84A40BD8E3864034F4A404BB0389CF9C94A4075CB0EF10F514A404BB0389CF9C94A4075CB0EF10F514A4064C91CCBBBC84A40BD8E3864034F4A4064C91CCBBBC84A40
47099	Кирюшкино	7	69	1214	52.282884000000003	52.339550000000003	53.58914	53.559086000000001	0103000020E61000000100000005000000E547FC8A35244A4063D34A2190C74A40E547FC8A35244A40FA6184F068CB4A40ACADD85F762B4A40FA6184F068CB4A40ACADD85F762B4A4063D34A2190C74A40E547FC8A35244A4063D34A2190C74A40
56127	Ивановка	7	69	1214	52.519795999999999	52.537861999999997	53.312426000000002	53.295003000000001	0103000020E61000000100000005000000BA4BE2AC88424A40679C86A8C2A54A40BA4BE2AC88424A40C6353E93FDA74A406DE179A9D8444A40C6353E93FDA74A406DE179A9D8444A40679C86A8C2A54A40BA4BE2AC88424A40679C86A8C2A54A40
15911	Земсков	7	69	1214	52.811371999999999	52.830632000000001	53.996392999999998	53.987425000000002	0103000020E61000000100000005000000EF71A609DB674A405C2041F163FE4A40EF71A609DB674A404E7B4ACE89FF4A406B813D26526A4A404E7B4ACE89FF4A406B813D26526A4A405C2041F163FE4A40EF71A609DB674A405C2041F163FE4A40
15522	Затоновский	7	69	1214	52.419193999999997	52.435462999999999	53.422915000000003	53.408552999999998	0103000020E61000000100000005000000F7562426A8354A4062D7F6764BB44A40F7562426A8354A4072FE261422B64A401CCF6740BD374A4072FE261422B64A401CCF6740BD374A4062D7F6764BB44A40F7562426A8354A4062D7F6764BB44A40
47913	Затон	7	69	1214	52.268186999999998	52.281222	53.654482000000002	53.645868	0103000020E610000001000000050000002E1B9DF353224A4037C478CDABD24A402E1B9DF353224A400CE9F010C6D34A4036751E15FF234A400CE9F010C6D34A4036751E15FF234A4037C478CDABD24A402E1B9DF353224A4037C478CDABD24A40
14493	Завьяловка	7	69	1214	52.545811999999998	52.58717	53.605480999999997	53.585751000000002	0103000020E61000000100000005000000D6E1E82ADD454A40B64C86E3F9CA4A40D6E1E82ADD454A40B8ACC26680CD4A409E98F562284B4A40B8ACC26680CD4A409E98F562284B4A40B64C86E3F9CA4A40D6E1E82ADD454A40B64C86E3F9CA4A40
47427	Жуково	7	69	1214	52.321187999999999	52.340690000000002	53.328853000000002	53.317295000000001	0103000020E610000001000000050000000FEF39B01C294A409817601F9DA84A400FEF39B01C294A408318E8DA17AA4A408109DCBA9B2B4A408318E8DA17AA4A408109DCBA9B2B4A409817601F9DA84A400FEF39B01C294A409817601F9DA84A40
14477	Елатомка	7	69	1214	52.602873000000002	52.642237000000002	53.705506	53.688611000000002	0103000020E610000001000000050000001A5245F12A4D4A403B55BE6724D84A401A5245F12A4D4A40DE9046054EDA4A40FDA36FD234524A40DE9046054EDA4A40FDA36FD234524A403B55BE6724D84A401A5245F12A4D4A403B55BE6724D84A40
46838	Григорьевка	7	69	1214	53.035806999999998	53.065550000000002	53.724460000000001	53.713845999999997	0103000020E61000000100000005000000E3FBE25295844A40B130444E5FDB4A40E3FBE25295844A404DA1F31ABBDC4A405C2041F163884A404DA1F31ABBDC4A405C2041F163884A40B130444E5FDB4A40E3FBE25295844A40B130444E5FDB4A40
47626	Вишневка	7	69	1214	52.800637000000002	52.8249	53.749524000000001	53.742910999999999	0103000020E61000000100000005000000D97BF1457B664A40596B28B517DF4A40D97BF1457B664A4097C80567F0DF4A40363CBD5296694A4097C80567F0DF4A40363CBD5296694A40596B28B517DF4A40D97BF1457B664A40596B28B517DF4A40
15140	Верхнепавлушкино	7	69	1214	53.016717999999997	53.046227000000002	53.946418999999999	53.905233000000003	0103000020E6100000010000000500000094A0BFD023824A404721C9ACDEF34A4094A0BFD023824A4011A8FE4124F94A409A982EC4EA854A4011A8FE4124F94A409A982EC4EA854A404721C9ACDEF34A4094A0BFD023824A404721C9ACDEF34A40
46893	Благодаровка	7	69	1214	52.391598000000002	52.405234	53.677610000000001	53.654797000000002	0103000020E61000000100000005000000EA961DE21F324A406C425A63D0D34A40EA961DE21F324A40A6B8AAECBBD64A40179D2CB5DE334A40A6B8AAECBBD64A40179D2CB5DE334A406C425A63D0D34A40EA961DE21F324A406C425A63D0D34A40
46826	Бестужевка	7	69	1214	53.002460999999997	53.033847999999999	53.728929999999998	53.717469999999999	0103000020E61000000100000005000000FA415DA450804A4039EE940ED6DB4A40FA415DA450804A40618907944DDD4A407B849A2155844A40618907944DDD4A407B849A2155844A4039EE940ED6DB4A40FA415DA450804A4039EE940ED6DB4A40
14052	Баймаково	7	69	1214	52.378500000000003	52.400221999999999	53.594425000000001	53.582200999999998	0103000020E610000001000000050000009CC420B072304A406859F78F85CA4A409CC420B072304A4060764F1E16CC4A40E29178793A334A4060764F1E16CC4A40E29178793A334A406859F78F85CA4A409CC420B072304A406859F78F85CA4A40
56147	Алексеевка	7	69	1214	52.523749000000002	52.547114000000001	53.864724000000002	53.8446	0103000020E6100000010000000500000007280D350A434A40CE1951DA1BEC4A4007280D350A434A407D08AA46AFEE4A408597E0D407464A407D08AA46AFEE4A408597E0D407464A40CE1951DA1BEC4A4007280D350A434A40CE1951DA1BEC4A40
46450	Цветочное	7	69	1237	55.960118999999999	55.976514000000002	51.408901	51.399940000000001	0103000020E6100000010000000500000055A2EC2DE5FA4B405E2EE23B31B3494055A2EC2DE5FA4B409E2633DE56B44940070B2769FEFC4B409E2633DE56B44940070B2769FEFC4B405E2EE23B31B3494055A2EC2DE5FA4B405E2EE23B31B34940
46228	Херсоновка	7	69	1237	56.204264000000002	56.220272000000001	51.489705999999998	51.481254	0103000020E6100000010000000500000005E09F52251A4C40DB8827BB99BD494005E09F52251A4C40D653ABAFAEBE4940BD1C76DF311C4C40D653ABAFAEBE4940BD1C76DF311C4C40DB8827BB99BD494005E09F52251A4C40DB8827BB99BD4940
13011	Старицкое	7	69	1237	55.687795000000001	55.719766	51.458374999999997	51.440986000000002	0103000020E6100000010000000500000019ADA3AA09D84B4037FFAF3A72B8494019ADA3AA09D84B40E9263108ACBA4940E962D34A21DC4B40E9263108ACBA4940E962D34A21DC4B4037FFAF3A72B8494019ADA3AA09D84B4037FFAF3A72B84940
13149	Сазан	7	69	1237	56.074294999999999	56.103005000000003	51.228048000000001	51.215868999999998	0103000020E61000000100000005000000CFA0A17F82094C40309C6B98A19B4940CFA0A17F82094C4088F546AD309D4940892991442F0D4C4088F546AD309D4940892991442F0D4C40309C6B98A19B4940CFA0A17F82094C40309C6B98A19B4940
46571	Новоорловка	7	69	1237	56.550069999999998	56.565018000000002	51.393320000000003	51.384388999999999	0103000020E610000001000000050000005F419AB168464C4098F8A3A833B149405F419AB168464C406E6E4C4F58B249405FD3838252484C406E6E4C4F58B249405FD3838252484C4098F8A3A833B149405F419AB168464C4098F8A3A833B14940
56157	Междуречье	7	69	1237	56.570165000000003	56.597259000000001	51.045377999999999	51.020873999999999	0103000020E610000001000000050000007429AE2AFB484C4019ABCDFFAB8249407429AE2AFB484C409CFA40F2CE854940EF1EA0FB724C4C409CFA40F2CE854940EF1EA0FB724C4C4019ABCDFFAB8249407429AE2AFB484C4019ABCDFFAB824940
46538	Листвянка	7	69	1237	56.743046	56.760824	51.355319000000001	51.345267	0103000020E6100000010000000500000039B69E211C5F4C40ABB184B531AC494039B69E211C5F4C40DF52CE177BAD494086014BAE62614C40DF52CE177BAD494086014BAE62614C40ABB184B531AC494039B69E211C5F4C40ABB184B531AC4940
12865	Крючковка	7	69	1237	55.922775999999999	55.961655999999998	51.575735999999999	51.556179999999998	0103000020E6100000010000000500000050C422861DF64B403A58FFE730C7494050C422861DF64B409F909DB7B1C949404700378B17FB4B409F909DB7B1C949404700378B17FB4B403A58FFE730C7494050C422861DF64B403A58FFE730C74940
13527	Красноуральск	7	69	1237	56.872107	56.892156999999997	51.355336000000001	51.342728999999999	0103000020E610000001000000050000006CCEC133A16F4C4005323B8BDEAB49406CCEC133A16F4C40B58B69A67BAD4940E0F2583332724C40B58B69A67BAD4940E0F2583332724C4005323B8BDEAB49406CCEC133A16F4C4005323B8BDEAB4940
46344	Ключевка	7	69	1237	55.786034999999998	55.813082999999999	51.374443999999997	51.359127000000001	0103000020E6100000010000000500000074417DCB9CE44B40280EA0DFF7AD494074417DCB9CE44B407A17EFC7EDAF49407FF78E1A13E84B407A17EFC7EDAF49407FF78E1A13E84B40280EA0DFF7AD494074417DCB9CE44B40280EA0DFF7AD4940
62065	Карагач	7	69	1237	56.404076000000003	56.428977000000003	51.255361000000001	51.244221000000003	0103000020E610000001000000050000009C8C2AC3B8334C408BFF3BA2429F49409C8C2AC3B8334C4041D653ABAFA049403CDEE4B7E8364C4041D653ABAFA049403CDEE4B7E8364C408BFF3BA2429F49409C8C2AC3B8334C408BFF3BA2429F4940
12709	Жанаталап	7	69	1237	56.473965	56.490313999999998	51.389026000000001	51.372121999999997	0103000020E610000001000000050000006D3997E2AA3C4C40A10F96B1A1AF49406D3997E2AA3C4C4098A59D9ACBB14940AE62F19BC23E4C4098A59D9ACBB14940AE62F19BC23E4C40A10F96B1A1AF49406D3997E2AA3C4C40A10F96B1A1AF4940
13804	Дубенский	7	69	1237	56.622374999999998	56.643118000000001	51.459783000000002	51.442518	0103000020E610000001000000050000008B6CE7FBA94F4C4017F2086EA4B849408B6CE7FBA94F4C40DE205A2BDABA494006BCCCB051524C40DE205A2BDABA494006BCCCB051524C4017F2086EA4B849408B6CE7FBA94F4C4017F2086EA4B84940
46608	Донское	7	69	1237	56.852946000000003	56.871909000000002	51.396737000000002	51.386828000000001	0103000020E6100000010000000500000084A0A3552D6D4C40AB96749483B1494084A0A3552D6D4C407C0E2C47C8B24940460BD0B69A6F4C407C0E2C47C8B24940460BD0B69A6F4C40AB96749483B1494084A0A3552D6D4C40AB96749483B14940
12769	Днепровка	7	69	1237	56.322679000000001	56.354300000000002	51.435308999999997	51.415529999999997	0103000020E61000000100000005000000910DA48B4D294C40E140481630B54940910DA48B4D294C40C5538F34B8B74940857CD0B3592D4C40C5538F34B8B74940857CD0B3592D4C40E140481630B54940910DA48B4D294C40E140481630B54940
13719	Гирьял	7	69	1237	56.389854999999997	56.416049999999998	51.479044000000002	51.466875999999999	0103000020E610000001000000050000004E97C5C4E6314C40C6A4BF97C2BB49404E97C5C4E6314C402AAC545051BD49401AC05B2041354C402AAC545051BD49401AC05B2041354C40C6A4BF97C2BB49404E97C5C4E6314C40C6A4BF97C2BB4940
13609	Верхнеозерное	7	69	1237	56.695228999999998	56.717030999999999	51.407907000000002	51.393881999999998	0103000020E610000001000000050000008A1D8D43FD584C40D53DB2B96AB249408A1D8D43FD584C409D67EC4B36B44940ED9BFBABC75B4C409D67EC4B36B44940ED9BFBABC75B4C40D53DB2B96AB249408A1D8D43FD584C40D53DB2B96AB24940
56146	Васильевка	7	69	1237	56.298254	56.323200999999997	51.278607999999998	51.267992	0103000020E610000001000000050000005AF3E32F2D264C4079CBD58F4DA249405AF3E32F2D264C40B5334C6DA9A349406A847EA65E294C40B5334C6DA9A349406A847EA65E294C4079CBD58F4DA249405AF3E32F2D264C4079CBD58F4DA24940
13100	Буртинский	7	69	1237	55.982990999999998	55.998351999999997	51.374512000000003	51.355808000000003	0103000020E6100000010000000500000094A12AA6D2FD4B40DDD3D51D8BAD494094A12AA6D2FD4B40D3FA5B02F0AF4940B6F292FFC9FF4B40D3FA5B02F0AF4940B6F292FFC9FF4B40DDD3D51D8BAD494094A12AA6D2FD4B40DDD3D51D8BAD4940
13375	Бурлыкский	7	69	1237	56.678933000000001	56.722861000000002	51.360111000000003	51.344647999999999	0103000020E610000001000000050000006C96CB46E7564C40DF50F86C1DAC49406C96CB46E7564C4006F7031E18AE4940E54691B5865C4C4006F7031E18AE4940E54691B5865C4C40DF50F86C1DAC49406C96CB46E7564C40DF50F86C1DAC4940
12846	Буранчи	7	69	1237	56.036879999999996	56.052402999999998	51.516672999999997	51.504806000000002	0103000020E6100000010000000500000030F0DC7BB8044C408C69A67B9DC0494030F0DC7BB8044C40F4DC425722C249402C9B3924B5064C40F4DC425722C249402C9B3924B5064C408C69A67B9DC0494030F0DC7BB8044C408C69A67B9DC04940
13040	Блюменталь	7	69	1237	55.706623999999998	55.729585	51.35069	51.337412	0103000020E61000000100000005000000CB48BDA772DA4B4094A3005130AB4940CB48BDA772DA4B406284F068E3AC49407A53910A63DD4B406284F068E3AC49407A53910A63DD4B4094A3005130AB4940CB48BDA772DA4B4094A3005130AB4940
13886	Беляевка	7	69	1237	56.388866999999998	56.437474999999999	51.406973999999998	51.389699999999998	0103000020E610000001000000050000002FBFD364C6314C4027A089B0E1B149402FBFD364C6314C4041295AB917B44940A7E8482EFF374C4041295AB917B44940A7E8482EFF374C4027A089B0E1B149402FBFD364C6314C4027A089B0E1B14940
46648	Белогорский	7	69	1237	56.516832000000001	56.547401999999998	51.577952000000003	51.561056999999998	0103000020E610000001000000050000005DC30C8D27424C408F183DB7D0C749405DC30C8D27424C403354C554FAC94940EBE1CB4411464C403354C554FAC94940EBE1CB4411464C408F183DB7D0C749405DC30C8D27424C408F183DB7D0C74940
13712	Алабайтал	7	69	1237	56.504120999999998	56.519661999999997	51.448351000000002	51.437021999999999	0103000020E61000000100000005000000081D740987404C40F6D03E56F0B74940081D740987404C408010C99063B94940AA7CCF4884424C408010C99063B94940AA7CCF4884424C40F6D03E56F0B74940081D740987404C40F6D03E56F0B74940
58189	Яковлевка	7	69	1172	53.004562999999997	53.049227999999999	53.602612000000001	53.58117	0103000020E61000000100000005000000C5E2378595804A404AB54FC763CA4A40C5E2378595804A40AD16D86322CD4A401406651A4D864A40AD16D86322CD4A401406651A4D864A404AB54FC763CA4A40C5E2378595804A404AB54FC763CA4A40
46139	Юдинка	7	69	1172	52.811425999999997	52.866501	53.424067999999998	53.412326999999998	0103000020E61000000100000005000000E28FA2CEDC674A40FF209221C7B44A40E28FA2CEDC674A40DBA337DC47B64A40C4793881E96E4A40DBA337DC47B64A40C4793881E96E4A40FF209221C7B44A40E28FA2CEDC674A40FF209221C7B44A40
12469	Шамассовка	7	69	1172	53.102227999999997	53.121200999999999	53.560941999999997	53.549778000000003	0103000020E61000000100000005000000245E9ECE158D4A40B80721205FC64A40245E9ECE158D4A40F6798CF2CCC74A400A9FAD83838F4A40F6798CF2CCC74A400A9FAD83838F4A40B80721205FC64A40245E9ECE158D4A40B80721205FC64A40
46134	Чкаловский	7	69	1172	52.905802999999999	52.967184000000003	53.506321	53.478104999999999	0103000020E6100000010000000500000031CF4A5AF1734A40EC866D8B32BD4A4031CF4A5AF1734A4096236420CFC04A40749B70AFCC7B4A4096236420CFC04A40749B70AFCC7B4A40EC866D8B32BD4A4031CF4A5AF1734A40EC866D8B32BD4A40
26176	Филипповка	7	69	1172	53.132897	53.160080000000001	53.610663000000002	53.601804999999999	0103000020E61000000100000005000000465ED6C402914A40DEC83CF207CD4A40465ED6C402914A404AF086342ACE4A40315F5E807D944A404AF086342ACE4A40315F5E807D944A40DEC83CF207CD4A40465ED6C402914A40DEC83CF207CD4A40
46097	Троицкое	7	69	1172	52.801974999999999	52.825727000000001	53.368217000000001	53.357630999999998	0103000020E61000000100000005000000D49AE61DA7664A40948444DAC6AD4A40D49AE61DA7664A40666A12BC21AF4A404C361E6CB1694A40666A12BC21AF4A404C361E6CB1694A40948444DAC6AD4A40D49AE61DA7664A40948444DAC6AD4A40
12110	Старосултангулово	7	69	1172	52.811191999999998	52.844977999999998	53.547387000000001	53.539436000000002	0103000020E610000001000000050000006F63B323D5674A407D24253D0CC54A406F63B323D5674A40B6A0F7C610C64A4074EB353D286C4A40B6A0F7C610C64A4074EB353D286C4A407D24253D0CC54A406F63B323D5674A407D24253D0CC54A40
12420	Старомукменево	7	69	1172	53.06617	53.085439000000001	53.489699999999999	53.471668000000001	0103000020E61000000100000005000000F8FC304278884A40ED48F59D5FBC4A40F8FC304278884A40F46C567DAEBE4A40C76647AAEF8A4A40F46C567DAEBE4A40C76647AAEF8A4A40ED48F59D5FBC4A40F8FC304278884A40ED48F59D5FBC4A40
12295	Старокульшарипово	7	69	1172	52.991906	53.048096000000001	53.484990000000003	53.464646000000002	0103000020E61000000100000005000000645A9BC6F67E4A40CE1B278579BB4A40645A9BC6F67E4A408B71FE2614BE4A40C2887D0228864A408B71FE2614BE4A40C2887D0228864A40CE1B278579BB4A40645A9BC6F67E4A40CE1B278579BB4A40
56153	Ст.Асекевео	7	69	1172	52.869520000000001	52.873624999999997	53.584313000000002	53.583399	0103000020E61000000100000005000000E59B6D6E4C6F4A4072C284D1ACCA4A40E59B6D6E4C6F4A4057D0B4C4CACA4A40E7FBA9F1D26F4A4057D0B4C4CACA4A40E7FBA9F1D26F4A4072C284D1ACCA4A40E59B6D6E4C6F4A4072C284D1ACCA4A40
48066	Сосновка	7	69	1172	52.964812999999999	52.986004000000001	53.470317000000001	53.451666000000003	0103000020E61000000100000005000000B9E00CFE7E7B4A408A5B0531D0B94A40B9E00CFE7E7B4A405DE0F25833BC4A40D3DC0A61357E4A405DE0F25833BC4A40D3DC0A61357E4A408A5B0531D0B94A40B9E00CFE7E7B4A408A5B0531D0B94A40
12035	Самаркино	7	69	1172	53.172395999999999	53.196317999999998	53.751766000000003	53.731769	0103000020E6100000010000000500000009FB761211964A40029D499BAADD4A4009FB761211964A40541F48DE39E04A40DDCEBEF220994A40541F48DE39E04A40DDCEBEF220994A40029D499BAADD4A4009FB761211964A40029D499BAADD4A40
45967	Рязановка	7	69	1172	53.162244999999999	53.202354	53.404752999999999	53.384757	0103000020E610000001000000050000004278B471C4944A401BF4A5B73FB14A404278B471C4944A409CFA40F2CEB34A407E1B62BCE6994A409CFA40F2CEB34A407E1B62BCE6994A401BF4A5B73FB14A404278B471C4944A401BF4A5B73FB14A40
58190	Петровка	7	69	1172	52.633262999999999	52.648031000000003	53.483206000000003	53.470633999999997	0103000020E61000000100000005000000286211C30E514A405D3123BC3DBC4A40286211C30E514A40919DB7B1D9BD4A40A8E507AEF2524A40919DB7B1D9BD4A40A8E507AEF2524A405D3123BC3DBC4A40286211C30E514A405D3123BC3DBC4A40
45894	Новосултангулово	7	69	1172	52.849173	52.891950999999999	53.541061999999997	53.523485999999998	0103000020E61000000100000005000000B7D26BB3B16C4A40F9F4D89601C34A40B7D26BB3B16C4A40DE8D058541C54A4037514B732B724A40DE8D058541C54A4037514B732B724A40F9F4D89601C34A40B7D26BB3B16C4A40F9F4D89601C34A40
12322	Новокульшарипово	7	69	1172	52.935150999999998	52.963572999999997	53.452589000000003	53.438671999999997	0103000020E610000001000000050000002DE92807B3774A40E0D5726726B84A402DE92807B3774A40C2C3B46FEEB94A4080272D5C567B4A40C2C3B46FEEB94A4080272D5C567B4A40E0D5726726B84A402DE92807B3774A40E0D5726726B84A40
12370	Мулланур	7	69	1172	52.947870999999999	52.971910000000001	53.512430999999999	53.497467	0103000020E61000000100000005000000D5E940D653794A406CEBA7FFACBF4A40D5E940D653794A40713AC95697C14A40E353008C677C4A40713AC95697C14A40E353008C677C4A406CEBA7FFACBF4A40D5E940D653794A406CEBA7FFACBF4A40
45854	Мочегай	7	69	1172	53.136741000000001	53.176177000000003	53.694082000000002	53.682516	0103000020E61000000100000005000000DC82A5BA80914A40957F2DAF5CD74A40DC82A5BA80914A40035FD1ADD7D84A4059A7CAF78C964A40035FD1ADD7D84A4059A7CAF78C964A40957F2DAF5CD74A40DC82A5BA80914A40957F2DAF5CD74A40
45816	Мартыновка	7	69	1172	53.167554000000003	53.230030999999997	53.657432999999997	53.628084999999999	0103000020E610000001000000050000003128D36872954A40D80DDB1665D04A403128D36872954A40D427B9C326D44A407808E3A7719D4A40D427B9C326D44A407808E3A7719D4A40D80DDB1665D04A403128D36872954A40D80DDB1665D04A40
11803	Лекаревка	7	69	1172	52.726894000000001	52.746746999999999	53.484112000000003	53.464168999999998	0103000020E610000001000000050000004ED4D2DC0A5D4A409468C9E369BB4A404ED4D2DC0A5D4A40F3CCCB61F7BD4A406CB1DB67955F4A40F3CCCB61F7BD4A406CB1DB67955F4A409468C9E369BB4A404ED4D2DC0A5D4A409468C9E369BB4A40
11762	Кутлуево	7	69	1172	53.219898000000001	53.252400000000002	53.528731999999998	53.506647000000001	0103000020E61000000100000005000000583A1F9E259C4A40EACE13CFD9C04A40583A1F9E259C4A40A12C7C7DADC34A4055C1A8A44EA04A40A12C7C7DADC34A4055C1A8A44EA04A40EACE13CFD9C04A40583A1F9E259C4A40EACE13CFD9C04A40
12195	Курбанай	7	69	1172	52.805802	52.811892999999998	53.479294000000003	53.464737	0103000020E6100000010000000500000094861A8524674A40DE1E84807CBB4A4094861A8524674A40A3957B8159BD4A40F86C1D1CEC674A40A3957B8159BD4A40F86C1D1CEC674A40DE1E84807CBB4A4094861A8524674A40DE1E84807CBB4A40
45739	Красногорский	7	69	1172	52.902479	52.923445000000001	53.233165999999997	53.214641999999998	0103000020E61000000100000005000000D4298F6E84734A408C2C9963799B4A40D4298F6E84734A4002452C62D89D4A40CE531D7233764A4002452C62D89D4A40CE531D7233764A408C2C9963799B4A40D4298F6E84734A408C2C9963799B4A40
11621	Кисла	7	69	1172	52.842328000000002	52.866843000000003	53.660203000000003	53.647598000000002	0103000020E61000000100000005000000A7406667D16B4A403E7AC37DE4D24A40A7406667D16B4A404DDC2A8881D44A401EE21FB6F46E4A404DDC2A8881D44A401EE21FB6F46E4A403E7AC37DE4D24A40A7406667D16B4A403E7AC37DE4D24A40
46712	Казанка	7	69	1172	52.568888999999999	52.585993000000002	53.361843999999998	53.349091000000001	0103000020E61000000100000005000000EE06D15AD1484A40FA298E03AFAC4A40EE06D15AD1484A407D2079E750AE4A40AC5791D1014B4A407D2079E750AE4A40AC5791D1014B4A40FA298E03AFAC4A40EE06D15AD1484A40FA298E03AFAC4A40
11822	Золотой Родник	7	69	1172	52.658648999999997	52.672168999999997	53.430013000000002	53.411022000000003	0103000020E610000001000000050000008445459C4E544A40E0F76F5E9CB44A408445459C4E544A406CED7DAA0AB74A40483140A209564A406CED7DAA0AB74A40483140A209564A40E0F76F5E9CB44A408445459C4E544A40E0F76F5E9CB44A40
56037	Заглядино	7	69	1172	52.707742000000003	52.767471	53.561033000000002	53.544305000000001	0103000020E61000000100000005000000B900344A975A4A404F0647C9ABC54A40B900344A975A4A40077DE9EDCFC74A4070D05E7D3C624A40077DE9EDCFC74A4070D05E7D3C624A404F0647C9ABC54A40B900344A975A4A404F0647C9ABC54A40
45697	Думино	7	69	1172	53.089579999999998	53.109253000000002	53.215192000000002	53.204579000000003	0103000020E610000001000000050000001630815B778B4A40653909A52F9A4A401630815B778B4A40302E55698B9B4A40B5FE9600FC8D4A40302E55698B9B4A40B5FE9600FC8D4A40653909A52F9A4A401630815B778B4A40653909A52F9A4A40
49563	Воскресеновка	7	69	1172	53.121676999999998	53.165163999999997	53.481256000000002	53.472006	0103000020E6100000010000000500000073D6A71C938F4A4005C24EB16ABC4A4073D6A71C938F4A407C80EECB99BD4A40FF3C0D1824954A407C80EECB99BD4A40FF3C0D1824954A4005C24EB16ABC4A4073D6A71C938F4A4005C24EB16ABC4A40
58174	Воздвиженка	7	69	1172	53.009756000000003	53.053592999999999	53.287995000000002	53.267211000000003	0103000020E610000001000000050000004B7842AF3F814A40D41055F833A24A404B7842AF3F814A40AD342905DDA44A40B325AB22DC864A40AD342905DDA44A40B325AB22DC864A40D41055F833A24A404B7842AF3F814A40D41055F833A24A40
11135	Брянчаниново	7	69	1172	52.879545	52.906655999999998	53.359361999999997	53.352567999999998	0103000020E610000001000000050000001F2E39EE94704A40DDCEBEF220AD4A401F2E39EE94704A406BB6F292FFAD4A40705CC64D0D744A406BB6F292FFAD4A40705CC64D0D744A40DDCEBEF220AD4A401F2E39EE94704A40DDCEBEF220AD4A40
45662	Баландино	7	69	1172	52.635041000000001	52.668441000000001	53.325783000000001	53.293807999999999	0103000020E61000000100000005000000404F030649514A40CEA623809BA54A40404F030649514A40E04BE141B3A94A401C2785798F554A40E04BE141B3A94A401C2785798F554A40CEA623809BA54A40404F030649514A40CEA623809BA54A40
11193	Асекеево	7	69	1172	52.778771999999996	52.885877999999998	53.592624000000001	53.567413000000002	0103000020E610000001000000050000002F8507CDAE634A40A2293BFDA0C84A402F8507CDAE634A4090696D1ADBCB4A40791F477364714A4090696D1ADBCB4A40791F477364714A40A2293BFDA0C84A402F8507CDAE634A40A2293BFDA0C84A40
11417	Аксютино	7	69	1172	53.104528000000002	53.153432000000002	53.269176999999999	53.258592999999998	0103000020E6100000010000000500000016C26A2C618D4A40BDFC4E9319A14A4016C26A2C618D4A40EEEA556474A24A407714E7A8A3934A40EEEA556474A24A407714E7A8A3934A40BDFC4E9319A14A4016C26A2C618D4A40BDFC4E9319A14A40
9152	Яфарово	7	69	224	54.200220999999999	54.223595000000003	52.975608999999999	52.956355000000002	0103000020E61000000100000005000000787C7BD7A0194B40DC2E34D7697A4A40787C7BD7A0194B40755776C1E07C4A404A46CEC29E1C4B40755776C1E07C4A404A46CEC29E1C4B40DC2E34D7697A4A40787C7BD7A0194B40DC2E34D7697A4A40
9718	Якут	7	69	224	54.236314999999998	54.241382000000002	52.708323	52.698075000000003	0103000020E61000000100000005000000F146E6913F1E4B40DE9387855A594A40F146E6913F1E4B409700FC53AA5A4A40EAEBF99AE51E4B409700FC53AA5A4A40EAEBF99AE51E4B40DE9387855A594A40F146E6913F1E4B40DE9387855A594A40
9067	Юртаево	7	69	224	54.351129	54.370164000000003	52.853175	52.836123999999998	0103000020E61000000100000005000000AED689CBF12C4B404AB3791C066B4A40AED689CBF12C4B40E561A1D6346D4A400A14B188612F4B40E561A1D6346D4A400A14B188612F4B404AB3791C066B4A40AED689CBF12C4B404AB3791C066B4A40
61390	Южный	7	69	224	54.262374999999999	54.274512000000001	52.808805999999997	52.802159000000003	0103000020E61000000100000005000000DD24068195214B4096986725AD664A40DD24068195214B407F677BF486674A40062E8F3523234B407F677BF486674A40062E8F3523234B4096986725AD664A40DD24068195214B4096986725AD664A40
10151	Шар	7	69	224	54.340538000000002	54.359662999999998	52.539056000000002	52.525032000000003	0103000020E61000000100000005000000CB85CABF962B4B403FADA23F34434A40CB85CABF962B4B40365B79C9FF444A40664AEB6F092E4B40365B79C9FF444A40664AEB6F092E4B403FADA23F34434A40CB85CABF962B4B403FADA23F34434A40
9401	Чебоксарово	7	69	224	54.162519000000003	54.174771999999997	52.842390000000002	52.819757000000003	0103000020E6100000010000000500000044FD2E6CCD144B4063D520CCED684A4044FD2E6CCD144B401D3D7E6FD36B4A40D520CCED5E164B401D3D7E6FD36B4A40D520CCED5E164B4063D520CCED684A4044FD2E6CCD144B4063D520CCED684A40
10032	Хортица	7	69	224	54.231347999999997	54.257227999999998	52.475807000000003	52.458015000000003	0103000020E610000001000000050000005CFFAECF9C1D4B40EA094B3CA03A4A405CFFAECF9C1D4B409C1A683EE73C4A40C8CEDBD8EC204B409C1A683EE73C4A40C8CEDBD8EC204B40EA094B3CA03A4A405CFFAECF9C1D4B40EA094B3CA03A4A40
56108	Федоровка	7	69	224	54.353949999999998	54.380091	52.401775999999998	52.391905999999999	0103000020E61000000100000005000000A835CD3B4E2D4B40978DCEF929324A40A835CD3B4E2D4B40AA285E656D334A40814067D2A6304B40AA285E656D334A40814067D2A6304B40978DCEF929324A40A835CD3B4E2D4B40978DCEF929324A40
49241	Успенка	7	69	224	54.058152	54.086179999999999	52.789068999999998	52.769464999999997	0103000020E610000001000000050000003719558671074B40543541D47D624A403719558671074B40CAA4863600654A40DEC83CF2070B4B40CAA4863600654A40DEC83CF2070B4B40543541D47D624A403719558671074B40543541D47D624A40
61386	Тукай	7	69	224	54.223289999999999	54.244292000000002	52.768320000000003	52.748548	0103000020E610000001000000050000000DC347C4941C4B403CBEBD6BD05F4A400DC347C4941C4B406E6E4C4F58624A405456D3F5441F4B406E6E4C4F58624A405456D3F5441F4B403CBEBD6BD05F4A400DC347C4941C4B403CBEBD6BD05F4A40
9052	Султакай	7	69	224	54.366742000000002	54.388095	52.801996000000003	52.789428000000001	0103000020E61000000100000005000000EA08E066F12E4B40FA4509FA0B654A40EA08E066F12E4B40ECC20FCEA7664A40DD5ED218AD314B40ECC20FCEA7664A40DD5ED218AD314B40FA4509FA0B654A40EA08E066F12E4B40FA4509FA0B654A40
45360	Романовский	7	69	224	54.685482	54.698462999999997	52.679172000000001	52.669114	0103000020E6100000010000000500000093FFC9DFBD574B40DBA50D87A5554A4093FFC9DFBD574B40F12DAC1BEF564A40A73B4F3C67594B40F12DAC1BEF564A40A73B4F3C67594B40DBA50D87A5554A4093FFC9DFBD574B40DBA50D87A5554A40
61399	Петровка	7	69	224	54.271996000000001	54.305827000000001	52.462761	52.447702999999997	0103000020E610000001000000050000004852D2C3D0224B4019A9F7544E394A404852D2C3D0224B40A06EA0C03B3B4A40ED9DD15625274B40A06EA0C03B3B4A40ED9DD15625274B4019A9F7544E394A404852D2C3D0224B4019A9F7544E394A40
10336	Октябрьский	7	69	224	54.035766000000002	54.051541	52.934004000000002	52.925710000000002	0103000020E610000001000000050000008527F4FA93044B4043CA4FAA7D764A408527F4FA93044B40A62A6D718D774A409AB33EE598064B40A62A6D718D774A409AB33EE598064B4043CA4FAA7D764A408527F4FA93044B4043CA4FAA7D764A40
9953	Озерка	7	69	224	54.127026000000001	54.148944999999998	52.556142000000001	52.540934999999998	0103000020E61000000100000005000000F0DE516342104B408121AB5B3D454A40F0DE516342104B404DF73AA92F474A408CF337A110134B404DF73AA92F474A408CF337A110134B408121AB5B3D454A40F0DE516342104B408121AB5B3D454A40
857	Новоспасское	7	69	224	54.556331	54.592739999999999	52.403122000000003	52.384793999999999	0103000020E610000001000000050000002060ADDA35474B4038D906EE40314A402060ADDA35474B4029266F8099334A40F98381E7DE4B4B4029266F8099334A40F98381E7DE4B4B4038D906EE40314A402060ADDA35474B4038D906EE40314A40
45994	Новоникольское	7	69	224	54.491678999999998	54.524602999999999	52.433121999999997	52.417493	0103000020E61000000100000005000000A3906456EF3E4B408BA71E6970354A40A3906456EF3E4B40CC96AC8A70374A401631EC3026434B40CC96AC8A70374A401631EC3026434B408BA71E6970354A40A3906456EF3E4B408BA71E6970354A40
49366	Новоникитино	7	69	224	53.980718000000003	54.018537000000002	52.884062	52.867719000000001	0103000020E610000001000000050000009D4CDC2A88FD4A40158F8B6A116F4A409D4CDC2A88FD4A4074D190F128714A400B62A06B5F024B4074D190F128714A400B62A06B5F024B40158F8B6A116F4A409D4CDC2A88FD4A40158F8B6A116F4A40
45414	Новомихайловка	7	69	224	54.528789000000003	54.544725	52.562285000000003	52.551690999999998	0103000020E6100000010000000500000006BEA25BAF434B40AF3F89CF9D464A4006BEA25BAF434B40040473F4F8474A4024287E8CB9454B40040473F4F8474A4024287E8CB9454B40AF3F89CF9D464A4006BEA25BAF434B40AF3F89CF9D464A40
61422	Михайловка	7	69	224	54.720489000000001	54.740549000000001	52.577227999999998	52.570753000000003	0103000020E610000001000000050000005A10CAFB385C4B40058C2E6F0E494A405A10CAFB385C4B40F12A6B9BE2494A40F20A444FCA5E4B40F12A6B9BE2494A40F20A444FCA5E4B40058C2E6F0E494A405A10CAFB385C4B40058C2E6F0E494A40
56109	Мирный	7	69	224	54.057281000000003	54.067594	52.574201000000002	52.570101999999999	0103000020E6100000010000000500000052D7DAFB54074B402DB1321AF9484A4052D7DAFB54074B404E2A1A6B7F494A40F2B391EBA6084B404E2A1A6B7F494A40F2B391EBA6084B402DB1321AF9484A4052D7DAFB54074B402DB1321AF9484A40
10463	Марксовский	7	69	224	54.720004000000003	54.738222	52.468691999999997	52.456637999999998	0103000020E610000001000000050000009E7E5017295C4B40300E2E1D733A4A409E7E5017295C4B40CBF27519FE3B4A400798F90E7E5E4B40CBF27519FE3B4A400798F90E7E5E4B40300E2E1D733A4A409E7E5017295C4B40300E2E1D733A4A40
61374	Майский	7	69	224	54.390008000000002	54.403931999999998	52.752451000000001	52.743113000000001	0103000020E61000000100000005000000D5963AC8EB314B40C11DA8531E5F4A40D5963AC8EB314B40D76B7A5050604A4068E7340BB4334B40D76B7A5050604A4068E7340BB4334B40C11DA8531E5F4A40D5963AC8EB314B40C11DA8531E5F4A40
9647	Кутучево	7	69	224	54.325132000000004	54.344355999999998	52.617733000000001	52.607322000000003	0103000020E610000001000000050000000971E5EC9D294B40171230BABC4D4A400971E5EC9D294B407A54FCDF114F4A4037177FDB132C4B407A54FCDF114F4A4037177FDB132C4B40171230BABC4D4A400971E5EC9D294B40171230BABC4D4A40
9856	Курпячево	7	69	224	54.049132999999998	54.064486000000002	52.673859	52.668644	0103000020E61000000100000005000000C2137AFD49064B405455682096554A40C2137AFD49064B40C18EFF0241564A406286C61341084B40C18EFF0241564A406286C61341084B405455682096554A40C2137AFD49064B405455682096554A40
9824	Каяпкулово	7	69	224	54.143672000000002	54.154846999999997	52.652186999999998	52.642826999999997	0103000020E61000000100000005000000EBAC16D863124B402EFEB62748524A40EBAC16D863124B402CF015DD7A534A401D71C806D2134B402CF015DD7A534A401D71C806D2134B402EFEB62748524A40EBAC16D863124B402EFEB62748524A40
56195	Канчерово	7	69	224	54.266058999999998	54.280548000000003	52.625185000000002	52.618017999999999	0103000020E610000001000000050000003AE7A7380E224B406F2BBD361B4F4A403AE7A7380E224B409279E40F06504A40A77A32FFE8234B409279E40F06504A40A77A32FFE8234B406F2BBD361B4F4A403AE7A7380E224B406F2BBD361B4F4A40
10114	Канцеровка	7	69	224	54.291300999999997	54.308377999999998	52.426850999999999	52.406550000000003	0103000020E610000001000000050000006325E65949254B402B1895D409344A406325E65949254B40E8A1B60DA3364A40276728EE78274B40E8A1B60DA3364A40276728EE78274B402B1895D409344A406325E65949254B402B1895D409344A40
61418	Каменка	7	69	224	54.361738000000003	54.384672000000002	52.449761000000002	52.440589000000003	0103000020E6100000010000000500000038DC476E4D2E4B401AFD683865384A4038DC476E4D2E4B401502B9C491394A40EDD79DEE3C314B401502B9C491394A40EDD79DEE3C314B401AFD683865384A4038DC476E4D2E4B401AFD683865384A40
49184	Каликино	7	69	224	54.062598999999999	54.117100000000001	52.916426000000001	52.889197000000003	0103000020E6100000010000000500000093E1783E03084B40C5591135D1714A4093E1783E03084B40209A79724D754A40492EFF21FD0E4B40209A79724D754A40492EFF21FD0E4B40C5591135D1714A4093E1783E03084B40C5591135D1714A40
45436	Исянгильдино	7	69	224	54.564155	54.5839	52.539648	52.531201000000003	0103000020E61000000100000005000000FC6F253B36484B401F4DF564FE434A40FC6F253B36484B4008AD872F13454A403411363CBD4A4B4008AD872F13454A403411363CBD4A4B401F4DF564FE434A40FC6F253B36484B401F4DF564FE434A40
56192	Зеленая Роща	7	69	224	54.310578999999997	54.332776000000003	52.636040000000001	52.622413000000002	0103000020E6100000010000000500000085E97B0DC1274B4079CDAB3AAB4F4A4085E97B0DC1274B4053793BC269514A4065726A67982A4B4053793BC269514A4065726A67982A4B4079CDAB3AAB4F4A4085E97B0DC1274B4079CDAB3AAB4F4A40
49571	Загорский	7	69	224	54.886730999999997	54.908596000000003	52.605013999999997	52.596235	0103000020E61000000100000005000000B8ACC26680714B4083DDB06D514C4A40B8ACC26680714B40A2CF4719714D4A4062A3ACDF4C744B40A2CF4719714D4A4062A3ACDF4C744B4083DDB06D514C4A40B8ACC26680714B4083DDB06D514C4A40
10251	Ждановка	7	69	224	54.382714	54.420307999999999	52.411510999999997	52.389603999999999	0103000020E6100000010000000500000055DCB8C5FC304B4005323B8BDE314A4055DCB8C5FC304B40DD787764AC344A40A31F0DA7CC354B40DD787764AC344A40A31F0DA7CC354B4005323B8BDE314A4055DCB8C5FC304B4005323B8BDE314A40
49597	Добринка	7	69	224	54.630721000000001	54.679355000000001	52.651181999999999	52.624741999999998	0103000020E6100000010000000500000041F33977BB504B400438BD8BF74F4A4041F33977BB504B4037DF88EE59534A40E2AFC91AF5564B4037DF88EE59534A40E2AFC91AF5564B400438BD8BF74F4A4041F33977BB504B400438BD8BF74F4A40
56128	Дмитриевка	7	69	224	54.765808999999997	54.797258999999997	52.5047	52.492621999999997	0103000020E61000000100000005000000C1FD800706624B4022A5D93C0E3F4A40C1FD800706624B40462575029A404A4088B839950C664B40462575029A404A4088B839950C664B4022A5D93C0E3F4A40C1FD800706624B4022A5D93C0E3F4A40
49218	Дальний	7	69	224	53.870054000000003	53.885451000000003	52.93421	52.926496999999998	0103000020E6100000010000000500000083E0F1ED5DEF4A40CA6B257497764A4083E0F1ED5DEF4A404FCC7A3194774A40F29A577556F14A404FCC7A3194774A40F29A577556F14A40CA6B257497764A4083E0F1ED5DEF4A40CA6B257497764A40
48459	Георгиевка	7	69	224	54.105027	54.132308000000002	52.669381000000001	52.655862999999997	0103000020E6100000010000000500000037195586710D4B4006D49B51F3534A4037195586710D4B402AC8CF46AE554A40E57FF277EF104B402AC8CF46AE554A40E57FF277EF104B4006D49B51F3534A4037195586710D4B4006D49B51F3534A40
56107	Гавриловка	7	69	224	54.607787000000002	54.623741000000003	52.701599999999999	52.680399999999999	0103000020E610000001000000050000008CF7E3F6CB4D4B406519E25817574A408CF7E3F6CB4D4B40D26F5F07CE594A405116BEBED64F4B40D26F5F07CE594A405116BEBED64F4B406519E25817574A408CF7E3F6CB4D4B406519E25817574A40
49108	Буранный	7	69	224	54.417504999999998	54.436990000000002	52.642198999999998	52.631241000000003	0103000020E610000001000000050000004F75C8CD70354B407A724D81CC504A404F75C8CD70354B400F43AB9333524A40EB56CF49EF374B400F43AB9333524A40EB56CF49EF374B407A724D81CC504A404F75C8CD70354B407A724D81CC504A40
49105	Архангеловка	7	69	224	54.777127999999998	54.787809000000003	52.588428999999998	52.575969000000001	0103000020E61000000100000005000000276728EE78634B404241295AB9494A40276728EE78634B404D8237A4514B4A404B3FE1ECD6644B404D8237A4514B4A404B3FE1ECD6644B404241295AB9494A40276728EE78634B404241295AB9494A40
56095	Александровка	7	69	224	54.402036000000003	54.430377999999997	52.69068	52.669338000000003	0103000020E6100000010000000500000047E867EA75334B402BFC19DEAC554A4047E867EA75334B402A00C63368584A407D7555A016374B402A00C63368584A407D7555A016374B402BFC19DEAC554A4047E867EA75334B402BFC19DEAC554A40
10953	Актыново	7	69	224	54.419347000000002	54.430557999999998	52.601239999999997	52.591006	0103000020E610000001000000050000007E569929AD354B40B1DEA815A64B4A407E569929AD354B400586AC6EF54C4A40FD8348861C374B400586AC6EF54C4A40FD8348861C374B40B1DEA815A64B4A407E569929AD354B40B1DEA815A64B4A40
7575	Шулаксу	7	69	919	55.683861	55.727077999999999	50.977288999999999	50.963937999999999	0103000020E610000001000000050000004301DBC188D74B4092AF0452627B49404301DBC188D74B40CADE52CE177D49400FD253E410DD4B40CADE52CE177D49400FD253E410DD4B4092AF0452627B49404301DBC188D74B4092AF0452627B4940
8811	Шкуновка	7	69	919	55.352525999999997	55.394513000000003	50.781584000000002	50.759321999999997	0103000020E61000000100000005000000AE7E6C921FAD4B4010919A7631614940AE7E6C921FAD4B40D789CBF10A644940666CE8667FB24B40D789CBF10A644940666CE8667FB24B4010919A7631614940AE7E6C921FAD4B4010919A7631614940
56086	Шаповаловка	7	69	919	55.561708000000003	55.584919999999997	50.742641999999996	50.723041000000002	0103000020E6100000010000000500000067F3380CE6C74B406555849B8C5C494067F3380CE6C74B4069519FE40E5F49405E6397A8DECA4B4069519FE40E5F49405E6397A8DECA4B406555849B8C5C494067F3380CE6C74B406555849B8C5C4940
56220	Ушкуль	7	69	919	55.977860999999997	55.991191999999998	50.826355	50.816806999999997	0103000020E6100000010000000500000055849B8C2AFD4B406A12BC218D68494055849B8C2AFD4B406BF12900C669494046072461DFFE4B406BF12900C669494046072461DFFE4B406A12BC218D68494055849B8C2AFD4B406A12BC218D684940
8723	Тамдысай	7	69	919	55.991875	56.009957999999997	50.766773999999998	50.749907999999998	0103000020E61000000100000005000000295C8FC2F5FE4B401F813FFCFC5F4940295C8FC2F5FE4B4028B682A625624940B22AC24D46014C4028B682A625624940B22AC24D46014C401F813FFCFC5F4940295C8FC2F5FE4B401F813FFCFC5F4940
47487	Советское	7	69	919	56.270927999999998	56.312106	51.122497000000003	51.095771999999997	0103000020E610000001000000050000000CC9C9C4AD224C40AEEFC341428C49400CC9C9C4AD224C40D76D50FBAD8F49405471E316F3274C40D76D50FBAD8F49405471E316F3274C40AEEFC341428C49400CC9C9C4AD224C40AEEFC341428C4940
8547	Сагарчин	7	69	919	55.891452000000001	55.920377999999999	50.909542999999999	50.894205999999997	0103000020E6100000010000000500000016FA60191BF24B4088F19A577572494016FA60191BF24B4022A7AFE76B7449409CFA40F2CEF54B4022A7AFE76B7449409CFA40F2CEF54B4088F19A577572494016FA60191BF24B4088F19A5775724940
49384	Орловка	7	69	919	56.282784999999997	56.301084000000003	51.153799999999997	51.143189	0103000020E610000001000000050000005166834C32244C40CF126404549249405166834C32244C40F90FE9B7AF934940A8ACA6EB89264C40F90FE9B7AF934940A8ACA6EB89264C40CF126404549249405166834C32244C40CF12640454924940
8495	Новоуспеновка	7	69	919	55.46698	55.489133000000002	50.879097000000002	50.862112000000003	0103000020E610000001000000050000006BF12900C6BB4B409DBE9EAF596E49406BF12900C6BB4B4080812040867049407B32FFE89BBE4B4080812040867049407B32FFE89BBE4B409DBE9EAF596E49406BF12900C6BB4B409DBE9EAF596E4940
48893	Новопавловка	7	69	919	55.588459	55.623322999999999	51.149467000000001	51.130704999999999	0103000020E61000000100000005000000B804E09F52CB4B403B3602F1BA904940B804E09F52CB4B40666A12BC219349401CEC4D0CC9CF4B40666A12BC219349401CEC4D0CC9CF4B403B3602F1BA904940B804E09F52CB4B403B3602F1BA904940
7966	Новоодесский	7	69	919	55.408158999999998	55.430931000000001	51.036876999999997	51.026103999999997	0103000020E61000000100000005000000B648DA8D3EB44B40BB25396057834940B648DA8D3EB44B40BF7CB262B884494092EA3BBF28B74B40BF7CB262B884494092EA3BBF28B74B40BB25396057834940B648DA8D3EB44B40BB25396057834940
8291	Новогригорьевка	7	69	919	55.892916	55.906661	51.230590999999997	51.212139000000001	0103000020E610000001000000050000009E094D124BF24B40639AE95E279B49409E094D124BF24B403FE08101849D494082C7B7770DF44B403FE08101849D494082C7B7770DF44B40639AE95E279B49409E094D124BF24B40639AE95E279B4940
48571	Новоалександровка	7	69	919	55.795529999999999	55.805833999999997	51.220990999999998	51.208222999999997	0103000020E61000000100000005000000527E52EDD3E54B4033A31F0DA79A4940527E52EDD3E54B40ECDADE6E499C49409F008A9125E74B40ECDADE6E499C49409F008A9125E74B4033A31F0DA79A4940527E52EDD3E54B4033A31F0DA79A4940
8034	Нагумановка	7	69	919	55.491943999999997	55.504187999999999	50.978129000000003	50.963937999999999	0103000020E6100000010000000500000051BB5F05F8BE4B4092AF0452627B494051BB5F05F8BE4B407522C154337D494090847D3B89C04B407522C154337D494090847D3B89C04B4092AF0452627B494051BB5F05F8BE4B4092AF0452627B4940
7652	Меловой Завод	7	69	919	55.655347999999996	55.665112999999998	51.081102000000001	51.072409999999998	0103000020E61000000100000005000000DFBF7971E2D34B40A1F31ABB44894940DFBF7971E2D34B40F2D1E28C618A49407D923B6C22D54B40F2D1E28C618A49407D923B6C22D54B40A1F31ABB44894940DFBF7971E2D34B40A1F31ABB44894940
48910	Межгорный	7	69	919	55.579799999999999	55.598987999999999	51.277582000000002	51.265889999999999	0103000020E61000000100000005000000431CEBE236CA4B40AE2AFBAE08A24940431CEBE236CA4B40A9FA95CE87A34940255987A3ABCC4B40A9FA95CE87A34940255987A3ABCC4B40AE2AFBAE08A24940431CEBE236CA4B40AE2AFBAE08A24940
48704	Майдан	7	69	919	55.665498999999997	55.685406	50.940452000000001	50.930188999999999	0103000020E61000000100000005000000A6423C122FD54B40AA0CE36E10774940A6423C122FD54B4099BA2BBB60784940B83D4162BBD74B4099BA2BBB60784940B83D4162BBD74B40AA0CE36E10774940A6423C122FD54B40AA0CE36E10774940
48741	Кызылбулак	7	69	919	55.367007000000001	55.388970999999998	51.056617000000003	51.048724999999997	0103000020E610000001000000050000009833DB15FAAE4B40B1BFEC9E3C8649409833DB15FAAE4B40E6B2D1393F874940D40B3ECDC9B14B40E6B2D1393F874940D40B3ECDC9B14B40B1BFEC9E3C8649409833DB15FAAE4B40B1BFEC9E3C864940
7516	Кулаксай	7	69	919	55.791801999999997	55.817683000000002	50.938749000000001	50.922559	0103000020E61000000100000005000000257497C459E54B40B3D0CE6916764940257497C459E54B408C135FED2878494062BF27D6A9E84B408C135FED2878494062BF27D6A9E84B40B3D0CE6916764940257497C459E54B40B3D0CE6916764940
7696	Кужунтай	7	69	919	55.544370000000001	55.571157999999997	51.030262	51.016590999999998	0103000020E61000000100000005000000367689EAADC54B40373465A71F824940367689EAADC54B40E1270EA0DF834940A46C91B41BC94B40E1270EA0DF834940A46C91B41BC94B40373465A71F824940367689EAADC54B40373465A71F824940
48956	Корниловка	7	69	919	55.949680999999998	55.975579000000003	50.882285000000003	50.870280999999999	0103000020E61000000100000005000000F850A2258FF94B4043AA285E656F4940F850A2258FF94B402D6002B7EE7049400BD5CDC5DFFC4B402D6002B7EE7049400BD5CDC5DFFC4B4043AA285E656F4940F850A2258FF94B4043AA285E656F4940
48871	Карповка	7	69	919	56.049565000000001	56.073836999999997	51.123311000000001	51.108198000000002	0103000020E610000001000000050000005C035B2558064C400EBF9B6ED98D49405C035B2558064C40581EA4A7C88F49400C1EA67D73094C40581EA4A7C88F49400C1EA67D73094C400EBF9B6ED98D49405C035B2558064C400EBF9B6ED98D4940
8216	Карасай	7	69	919	55.929288999999997	55.959625000000003	51.173225000000002	51.158410000000003	0103000020E610000001000000050000002AC423F1F2F64B4000AE64C7469449402AC423F1F2F64B40C0EC9E3C2C96494046B6F3FDD4FA4B40C0EC9E3C2C96494046B6F3FDD4FA4B4000AE64C7469449402AC423F1F2F64B4000AE64C746944940
8070	Каракудук	7	69	919	56.157012000000002	56.182965000000003	51.000149999999998	50.988500000000002	0103000020E610000001000000050000002F8A1EF818144C404A0C022B877E49402F8A1EF818144C40158C4AEA0480494005A8A9656B174C40158C4AEA0480494005A8A9656B174C404A0C022B877E49402F8A1EF818144C404A0C022B877E4940
48670	Кайракты	7	69	919	55.909005000000001	55.935056000000003	50.980074000000002	50.960720999999999	0103000020E6100000010000000500000043739D465AF44B404BCADDE7F87A494043739D465AF44B4078D49810737D4940DCF63DEAAFF74B4078D49810737D4940DCF63DEAAFF74B404BCADDE7F87A494043739D465AF44B404BCADDE7F87A4940
48723	Веселый Первый	7	69	919	55.550595000000001	55.583339000000002	50.981893999999997	50.968055999999997	0103000020E61000000100000005000000AA2B9FE579C64B4029594E42E97B4940AA2B9FE579C64B40BE11DDB3AE7D49409DBD33DAAACA4B40BE11DDB3AE7D49409DBD33DAAACA4B4029594E42E97B4940AA2B9FE579C64B4029594E42E97B4940
8132	Веселый Второй	7	69	919	56.255898999999999	56.284995000000002	50.958371999999997	50.937341000000004	0103000020E61000000100000005000000200A664CC1204C40981936CAFA774940200A664CC1204C4078B306EFAB7A4940034356B77A244C4078B306EFAB7A4940034356B77A244C40981936CAFA774940200A664CC1204C40981936CAFA774940
8632	Акоба	7	69	919	55.877887999999999	55.896617999999997	50.853389999999997	50.8461	0103000020E6100000010000000500000082C64CA25EF04B40A3923A014D6C494082C64CA25EF04B40E15D2EE23B6D4940A180ED60C4F24B40E15D2EE23B6D4940A180ED60C4F24B40A3923A014D6C494082C64CA25EF04B40A3923A014D6C4940
7311	Акбулак	7	69	919	55.587085000000002	55.644362000000001	51.023741000000001	50.987423	0103000020E61000000100000005000000707CED9925CB4B40BB287AE0637E4940707CED9925CB4B408449F1F10983494080643A747AD24B408449F1F10983494080643A747AD24B40BB287AE0637E4940707CED9925CB4B40BB287AE0637E4940
56097	с.Бело	7	69	666	59.126761999999999	61.008606	52.056756	51.177289999999999	0103000020E610000001000000050000001230BABC39904D4034F44F70B19649401230BABC39904D4007EDD5C743074A4052465C001A814E4007EDD5C743074A4052465C001A814E4034F44F70B19649401230BABC39904D4034F44F70B1964940
56094	п.Новоада	7	69	666	59.126761999999999	61.008606	52.056756	51.177289999999999	0103000020E610000001000000050000001230BABC39904D4034F44F70B19649401230BABC39904D4007EDD5C743074A4052465C001A814E4007EDD5C743074A4052465C001A814E4034F44F70B19649401230BABC39904D4034F44F70B1964940
56043	п.Ком	7	69	666	59.126761999999999	61.008606	52.056756	51.177289999999999	0103000020E610000001000000050000001230BABC39904D4034F44F70B19649401230BABC39904D4007EDD5C743074A4052465C001A814E4007EDD5C743074A4052465C001A814E4034F44F70B19649401230BABC39904D4034F44F70B1964940
56091	Юбилейный	7	69	666	59.334003000000003	59.361105000000002	51.655467000000002	51.631720000000001	0103000020E6100000010000000500000009E23C9CC0AA4D40541D7233DCD0494009E23C9CC0AA4D40BA4DB857E6D3494007B64AB038AE4D40BA4DB857E6D3494007B64AB038AE4D40541D7233DCD0494009E23C9CC0AA4D40541D7233DCD04940
56126	Энбекши	7	69	666	59.580519000000002	59.600524	51.867738000000003	51.847056000000002	0103000020E6100000010000000500000073DA53724ECA4D40B7F0BC546CEC494073DA53724ECA4D408CBFED0912EF4940473B6EF8DDCC4D408CBFED0912EF4940473B6EF8DDCC4D40B7F0BC546CEC494073DA53724ECA4D40B7F0BC546CEC4940
7121	Шильда	7	69	666	59.749141000000002	59.789431	51.828414000000002	51.798057999999997	0103000020E61000000100000005000000DF8B2FDAE3DF4D40D427B9C326E64940DF8B2FDAE3DF4D4037C64E7809EA49406BB933130CE54D4037C64E7809EA49406BB933130CE54D40D427B9C326E64940DF8B2FDAE3DF4D40D427B9C326E64940
56089	Совхозный	7	69	666	59.989558000000002	60.012104999999998	51.677622	51.663969999999999	0103000020E6100000010000000500000062BF27D6A9FE4D4037C30DF8FCD4494062BF27D6A9FE4D406A865451BCD649401D8F19A88C014E406A865451BCD649401D8F19A88C014E4037C30DF8FCD4494062BF27D6A9FE4D4037C30DF8FCD44940
56122	Слюдяной	7	69	666	59.331451999999999	59.348869999999998	51.593995999999997	51.579037999999997	0103000020E61000000100000005000000CE18E6046DAA4D401492CCEA1DCA4940CE18E6046DAA4D4037FA980F08CC49401B47ACC5A7AC4D4037FA980F08CC49401B47ACC5A7AC4D401492CCEA1DCA4940CE18E6046DAA4D401492CCEA1DCA4940
56105	Обильный	7	69	666	60.830101999999997	60.851626000000003	51.321052000000002	51.307839000000001	0103000020E610000001000000050000000E2C47C8406A4E4078B7B24467A749400E2C47C8406A4E405F28603B18A949402F36AD14026D4E405F28603B18A949402F36AD14026D4E4078B7B24467A749400E2C47C8406A4E4078B7B24467A74940
56151	Нововинницкий	7	69	666	60.020297999999997	60.046897000000001	51.577745	51.555714999999999	0103000020E610000001000000050000004C16F71F99024E40C5724BAB21C749404C16F71F99024E40B936548CF3C94940E8A38CB800064E40B936548CF3C94940E8A38CB800064E40C5724BAB21C749404C16F71F99024E40C5724BAB21C74940
56203	Нижняя Кийма	7	69	666	59.787176000000002	59.802464999999998	51.399276999999998	51.383657999999997	0103000020E610000001000000050000001A19E42EC2E44D40A46C91B41BB149401A19E42EC2E44D40C2853C821BB34940A297512CB7E64D40C2853C821BB34940A297512CB7E64D40A46C91B41BB149401A19E42EC2E44D40A46C91B41BB14940
56199	Мещеряковский	7	69	666	59.872785999999998	59.909886	51.773598999999997	51.765278000000002	0103000020E610000001000000050000000D349F73B7EF4D40952C27A1F4E149400D349F73B7EF4D40F19BC24A05E349404C8BFA2477F44D40F19BC24A05E349404C8BFA2477F44D40952C27A1F4E149400D349F73B7EF4D40952C27A1F4E14940
6435	Майский	7	69	666	59.386536	59.410018000000001	51.912937999999997	51.903309	0103000020E61000000100000005000000035DFB027AB14D405B971AA19FF34940035DFB027AB14D4048A30227DBF44940BB6246787BB44D4048A30227DBF44940BB6246787BB44D405B971AA19FF34940035DFB027AB14D405B971AA19FF34940
56197	Красноярск	7	69	666	60.134841999999999	60.156123000000001	51.437555000000003	51.421905000000002	0103000020E610000001000000050000004910AE8042114E406B82A8FB00B649404910AE8042114E40C4995FCD01B84940A393A5D6FB134E40C4995FCD01B84940A393A5D6FB134E406B82A8FB00B649404910AE8042114E406B82A8FB00B64940
58185	Комсомольский	7	69	666	60.614902000000001	60.658344	51.577840000000002	51.557181999999997	0103000020E610000001000000050000005C1FD61BB54E4E40BEF561BD51C749405C1FD61BB54E4E400B293FA9F6C9494048C2BE9D44544E400B293FA9F6C9494048C2BE9D44544E40BEF561BD51C749405C1FD61BB54E4E40BEF561BD51C74940
56106	Каменецк	7	69	666	60.400365999999998	60.430737999999998	51.724319999999999	51.712457000000001	0103000020E6100000010000000500000015376E313F334E4034677DCA31DB494015376E313F334E405BEB8B84B6DC49407D923B6C22374E405BEB8B84B6DC49407D923B6C22374E4034677DCA31DB494015376E313F334E4034677DCA31DB4940
56179	Каинсай	7	69	666	60.191301000000003	60.220443000000003	51.631636	51.617030999999997	0103000020E610000001000000050000009758198D7C184E4020CF2EDFFACE49409758198D7C184E40F67CCD72D9D04940EAD0E979371C4E40F67CCD72D9D04940EAD0E979371C4E4020CF2EDFFACE49409758198D7C184E4020CF2EDFFACE4940
6367	Заполье	7	69	666	60.414577000000001	60.433369999999996	51.542833999999999	51.530794	0103000020E610000001000000050000003F56F0DB10354E40DE74CB0EF1C349403F56F0DB10354E401494A2957BC54940A4880CAB78374E401494A2957BC54940A4880CAB78374E40DE74CB0EF1C349403F56F0DB10354E40DE74CB0EF1C34940
61196	Елизаветинка	7	69	666	59.727474000000001	59.755339999999997	51.775834000000003	51.754302000000003	0103000020E610000001000000050000005C5837DE1DDD4D4059A7CAF78CE049405C5837DE1DDD4D40FC8F4C874EE3494029AE2AFBAEE04D40FC8F4C874EE3494029AE2AFBAEE04D4059A7CAF78CE049405C5837DE1DDD4D4059A7CAF78CE04940
56110	Джусинск	7	69	666	59.722408000000001	59.740597999999999	51.642178000000001	51.632832000000001	0103000020E61000000100000005000000342F87DD77DC4D405FEE93A300D14940342F87DD77DC4D40F81A82E332D24940D3BD4EEACBDE4D40F81A82E332D24940D3BD4EEACBDE4D405FEE93A300D14940342F87DD77DC4D405FEE93A300D14940
5578	Джасай	7	69	666	60.391418999999999	60.421809000000003	51.404985000000003	51.382348	0103000020E610000001000000050000003A048E041A324E4073D87DC7F0B049403A048E041A324E406F2F698CD6B3494049145AD6FD354E406F2F698CD6B3494049145AD6FD354E4073D87DC7F0B049403A048E041A324E4073D87DC7F0B04940
56182	Джарлинский	7	69	666	59.889592999999998	59.916038999999998	51.473669999999998	51.458216999999998	0103000020E6100000010000000500000011E0F42EDEF14D4051BCCADAA6BA494011E0F42EDEF14D40548CF337A1BC4940266E15C440F54D40548CF337A1BC4940266E15C440F54D4051BCCADAA6BA494011E0F42EDEF14D4051BCCADAA6BA4940
56068	Брацлавка	7	69	666	60.240330999999998	60.282884000000003	51.676319999999997	51.655768999999999	0103000020E61000000100000005000000849B8C2AC31E4E40855D143DF0D34940849B8C2AC31E4E40BBD05CA791D64940E547FC8A35244E40BBD05CA791D64940E547FC8A35244E40855D143DF0D34940849B8C2AC31E4E40855D143DF0D34940
56140	Баймурат	7	69	666	59.629980000000003	59.648189000000002	51.634967000000003	51.625256999999998	0103000020E610000001000000050000002A91442FA3D04D402B4CDF6B08D049402A91442FA3D04D400685419946D1494040506EDBF7D24D400685419946D1494040506EDBF7D24D402B4CDF6B08D049402A91442FA3D04D402B4CDF6B08D04940
56080	Аниховка	7	69	666	60.216140000000003	60.265619000000001	51.501094999999999	51.485573000000002	0103000020E61000000100000005000000C1ADBB79AA1B4E400A698D4127BE4940C1ADBB79AA1B4E40359886E123C049401E19ABCDFF214E40359886E123C049401E19ABCDFF214E400A698D4127BE4940C1ADBB79AA1B4E400A698D4127BE4940
5751	Аневка	7	69	666	60.220883000000001	60.240709000000003	51.718812999999997	51.702997000000003	0103000020E61000000100000005000000069FE6E4451C4E40D31742CEFBD94940069FE6E4451C4E4046787B1002DC49402B6D718DCF1E4E4046787B1002DC49402B6D718DCF1E4E40D31742CEFBD94940069FE6E4451C4E40D31742CEFBD94940
56136	Андреевка	7	69	666	59.525137999999998	59.552204000000003	51.648342	51.633251000000001	0103000020E6100000010000000500000084F1D3B837C34D406494675E0ED1494084F1D3B837C34D40C64FE3DEFCD24940365CE49EAEC64D40C64FE3DEFCD24940365CE49EAEC64D406494675E0ED1494084F1D3B837C34D406494675E0ED14940
5098	Адамовка	7	69	666	59.919767	59.956518000000003	51.539164	51.504094000000002	0103000020E610000001000000050000005378D0ECBAF54D400F0EF62686C049405378D0ECBAF54D401C97715303C5494086048C2E6FFA4D401C97715303C5494086048C2E6FFA4D400F0EF62686C049405378D0ECBAF54D400F0EF62686C04940
47778	Черемушки	7	69	604	53.616056	53.623781000000001	53.792236000000003	53.787075999999999	0103000020E6100000010000000500000096404AECDACE4A40B6BB07E8BEE44A4096404AECDACE4A40605B3FFD67E54A40DF6E490ED8CF4A40605B3FFD67E54A40DF6E490ED8CF4A40B6BB07E8BEE44A4096404AECDACE4A40B6BB07E8BEE44A40
4990	Чеганлы	7	69	604	53.559021000000001	53.577590000000001	53.913550000000001	53.894601999999999	0103000020E610000001000000050000007C6308008EC74A40D5777E5182F24A407C6308008EC74A4062A1D634EFF44A40923F1878EEC94A4062A1D634EFF44A40923F1878EEC94A40D5777E5182F24A407C6308008EC74A40D5777E5182F24A40
4931	Тирис-Усманово	7	69	604	53.325271000000001	53.347630000000002	53.737009999999998	53.716692000000002	0103000020E610000001000000050000002AABE97AA2A94A4005A73E90BCDB4A402AABE97AA2A94A409869FB5756DE4A40E38DCC237FAC4A409869FB5756DE4A40E38DCC237FAC4A4005A73E90BCDB4A402AABE97AA2A94A4005A73E90BCDB4A40
5015	Степановка 2-я	7	69	604	53.381433999999999	53.428874	53.921233999999998	53.893211000000001	0103000020E610000001000000050000008ECA4DD4D2B04A40B7B6F0BC54F24A408ECA4DD4D2B04A404CFBE6FEEAF54A40670DDE57E5B64A404CFBE6FEEAF54A40670DDE57E5B64A40B7B6F0BC54F24A408ECA4DD4D2B04A40B7B6F0BC54F24A40
4878	Старые Шалты	7	69	604	53.223474000000003	53.257815999999998	53.933512999999998	53.912928999999998	0103000020E61000000100000005000000CFC0C8CB9A9C4A40F54883DBDAF44A40CFC0C8CB9A9C4A4007B29E5A7DF74A4059315C1D00A14A4007B29E5A7DF74A4059315C1D00A14A40F54883DBDAF44A40CFC0C8CB9A9C4A40F54883DBDAF44A40
4347	Радовка	7	69	604	53.598070999999997	53.613422999999997	53.599497	53.580956	0103000020E61000000100000005000000CFD72C978DCC4A401E3526C45CCA4A40CFD72C978DCC4A406A865451BCCC4A409ECE15A584CE4A406A865451BCCC4A409ECE15A584CE4A401E3526C45CCA4A40CFD72C978DCC4A401E3526C45CCA4A40
46032	Покровка	7	69	604	53.304358000000001	53.359316999999997	53.800581000000001	53.757621999999998	0103000020E610000001000000050000005323F433F5A64A40745DF8C1F9E04A405323F433F5A64A4045662E7079E64A40CBF27519FEAD4A4045662E7079E64A40CBF27519FEAD4A40745DF8C1F9E04A405323F433F5A64A40745DF8C1F9E04A40
4148	Новый Тирис	7	69	604	53.483015000000002	53.502068000000001	53.680591	53.664428000000001	0103000020E610000001000000050000001D3D7E6FD3BD4A40FA4509FA0BD54A401D3D7E6FD3BD4A40D9791B9B1DD74A401F2FA4C343C04A40D9791B9B1DD74A401F2FA4C343C04A40FA4509FA0BD54A401D3D7E6FD3BD4A40FA4509FA0BD54A40
47511	Новоякупово	7	69	604	53.556812000000001	53.594315999999999	53.674084000000001	53.650196999999999	0103000020E610000001000000050000009B02999D45C74A40897AC1A739D34A409B02999D45C74A40E1606F6248D64A40A9BEF38B12CC4A40E1606F6248D64A40A9BEF38B12CC4A40897AC1A739D34A409B02999D45C74A40897AC1A739D34A40
3810	Николькино	7	69	604	53.502895000000002	53.521785999999999	54.012394999999998	53.991152	0103000020E61000000100000005000000352905DD5EC04A40B8AE9811DEFE4A40352905DD5EC04A4024D1CB2896014B405DC136E2C9C24A4024D1CB2896014B405DC136E2C9C24A40B8AE9811DEFE4A40352905DD5EC04A40B8AE9811DEFE4A40
4510	Нижний Курмей	7	69	604	53.918787999999999	53.946266999999999	53.520268999999999	53.499540000000003	0103000020E6100000010000000500000087FA5DD89AF54A409D853DEDF0BF4A4087FA5DD89AF54A40B20FB22C98C24A405B24ED461FF94A40B20FB22C98C24A405B24ED461FF94A409D853DEDF0BF4A4087FA5DD89AF54A409D853DEDF0BF4A40
4412	Малый Сурмет	7	69	604	53.350990000000003	53.382871000000002	53.821309999999997	53.802441999999999	0103000020E610000001000000050000008D9C853DEDAC4A40EA77616BB6E64A408D9C853DEDAC4A405AF0A2AF20E94A401DCBBBEA01B14A405AF0A2AF20E94A401DCBBBEA01B14A40EA77616BB6E64A408D9C853DEDAC4A40EA77616BB6E64A40
4261	Камыш-Садак	7	69	604	53.676358999999998	53.706102999999999	53.548167999999997	53.523876999999999	0103000020E6100000010000000500000079AD84EE92D64A403410CB660EC34A4079AD84EE92D64A405B5B785E2AC64A40C24D469561DA4A405B5B785E2AC64A40C24D469561DA4A403410CB660EC34A4079AD84EE92D64A403410CB660EC34A40
47366	Искра	7	69	604	53.618993000000003	53.635494999999999	53.768065	53.757899000000002	0103000020E61000000100000005000000FAB9A1293BCF4A40E7559DD502E14A40FAB9A1293BCF4A40E31934F44FE24A40C1E270E657D14A40E31934F44FE24A40C1E270E657D14A40E7559DD502E14A40FAB9A1293BCF4A40E7559DD502E14A40
4823	Исайкино	7	69	604	53.170904	53.196731	53.824328999999999	53.814830000000001	0103000020E61000000100000005000000B760A92EE0954A405CE674594CE84A40B760A92EE0954A407B12D89C83E94A40008E3D7B2E994A407B12D89C83E94A40008E3D7B2E994A405CE674594CE84A40B760A92EE0954A405CE674594CE84A40
56138	Зерикла	7	69	604	53.378658000000001	53.40558	53.669006000000003	53.650863999999999	0103000020E61000000100000005000000342F87DD77B04A406612F5824FD34A40342F87DD77B04A40F56915FDA1D54A40B2F4A10BEAB34A40F56915FDA1D54A40B2F4A10BEAB34A406612F5824FD34A40342F87DD77B04A406612F5824FD34A40
3945	Емантаево	7	69	604	53.810352000000002	53.836933000000002	53.560744	53.529904000000002	0103000020E61000000100000005000000C51F459DB9E74A408202EFE4D3C34A40C51F459DB9E74A40D0B69A75C6C74A40BAF8DB9E20EB4A40D0B69A75C6C74A40BAF8DB9E20EB4A408202EFE4D3C34A40C51F459DB9E74A408202EFE4D3C34A40
3995	Егорьевка	7	69	604	53.879756	53.931355000000003	53.476239999999997	53.452969000000003	0103000020E61000000100000005000000DA3A38D89BF04A40098D60E3FAB94A40DA3A38D89BF04A400586AC6EF5BC4A40A9FB00A436F74A400586AC6EF5BC4A40A9FB00A436F74A40098D60E3FAB94A40DA3A38D89BF04A40098D60E3FAB94A40
47384	Венера	7	69	604	53.633195000000001	53.654736999999997	53.716372	53.702728999999998	0103000020E61000000100000005000000D07EA4880CD14A40B3791C06F3D94A40D07EA4880CD14A4093E2E313B2DB4A40963D096CCED34A4093E2E313B2DB4A40963D096CCED34A40B3791C06F3D94A40D07EA4880CD14A40B3791C06F3D94A40
47584	Васькино	7	69	604	53.133794999999999	53.145553999999997	53.847830000000002	53.829452000000003	0103000020E6100000010000000500000025AFCE3120914A4008CDAE7B2BEA4A4025AFCE3120914A40AA4885B185EC4A40A7E67283A1924A40AA4885B185EC4A40A7E67283A1924A4008CDAE7B2BEA4A4025AFCE3120914A4008CDAE7B2BEA4A40
56161	Васильевка	7	69	604	53.757100000000001	53.779594000000003	53.651094000000001	53.631512999999998	0103000020E610000001000000050000009BE61DA7E8E04A40DAFF006BD5D04A409BE61DA7E8E04A40984F560C57D34A40341477BCC9E34A40984F560C57D34A40341477BCC9E34A40DAFF006BD5D04A409BE61DA7E8E04A40DAFF006BD5D04A40
3897	Булатовка	7	69	604	53.403846999999999	53.426673000000001	53.763823000000002	53.750520000000002	0103000020E610000001000000050000003ACB2C42B1B34A40397F130A11E04A403ACB2C42B1B34A406077BAF3C4E14A40098B8A389DB64A406077BAF3C4E14A40098B8A389DB64A40397F130A11E04A403ACB2C42B1B34A40397F130A11E04A40
4428	Большой Сурмет	7	69	604	53.411113999999998	53.460270000000001	53.809550999999999	53.785310000000003	0103000020E61000000100000005000000C07630629FB44A40639CBF0985E44A40C07630629FB44A40D8B8FE5D9FE74A403BAA9A20EABA4A40D8B8FE5D9FE74A403BAA9A20EABA4A40639CBF0985E44A40C07630629FB44A40639CBF0985E44A40
3849	Артемьевка	7	69	604	53.494225999999998	53.530383	53.728568000000003	53.708329999999997	0103000020E610000001000000050000009C6A2DCC42BF4A404963B48EAADA4A409C6A2DCC42BF4A40C1745AB741DD4A405CAD1397E3C34A40C1745AB741DD4A405CAD1397E3C34A404963B48EAADA4A409C6A2DCC42BF4A404963B48EAADA4A40
45620	Алексеевка	7	69	604	53.125602000000001	53.139589000000001	53.821857999999999	53.819327000000001	0103000020E61000000100000005000000F627F1B913904A406ADD06B5DFE84A40F627F1B913904A405DFA97A432E94A40D0F0660DDE914A405DFA97A432E94A40D0F0660DDE914A406ADD06B5DFE84A40F627F1B913904A406ADD06B5DFE84A40
47435	Авдеевка	7	69	604	53.763415000000002	53.790401000000003	53.490524999999998	53.470730000000003	0103000020E610000001000000050000004F232D95B7E14A40809F71E140BC4A404F232D95B7E14A40696FF085C9BE4A40E4DC26DC2BE54A40696FF085C9BE4A40E4DC26DC2BE54A40809F71E140BC4A404F232D95B7E14A40809F71E140BC4A40
47192	Абдрахманово	7	69	604	53.490687000000001	53.508392000000001	54.051909999999999	54.033411000000001	0103000020E6100000010000000500000043C9E4D4CEBE4A40D029C8CF46044B4043C9E4D4CEBE4A40ED2AA4FCA4064B4026C632FD12C14A40ED2AA4FCA4064B4026C632FD12C14A40D029C8CF46044B4043C9E4D4CEBE4A40D029C8CF46044B40
50037	д.Ближнее Константиново	7	68	\N	41.776566000000003	47.770995999999997	58.091237	54.461975000000002	0103000020E61000000100000005000000C097C28366E34440E9482EFF213B4B40C097C28366E34440B3976DA7AD0B4D4064AC36FFAFE24740B3976DA7AD0B4D4064AC36FFAFE24740E9482EFF213B4B40C097C28366E34440E9482EFF213B4B40
8797	Селекционной Станции	7	68	\N	44.020125999999998	44.03096	56.212479999999999	56.204940000000001	0103000020E610000001000000050000004FE61F7D9302464035D252793B1A4C404FE61F7D93024640EC866D8B321B4C40F9BD4D7FF6034640EC866D8B321B4C40F9BD4D7FF603464035D252793B1A4C404FE61F7D9302464035D252793B1A4C40
49771	Саров	7	68	\N	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
629	Саров	7	68	\N	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
12248	Павлово	7	68	\N	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
42	Нижний Новгород	7	68	\N	43.607072000000002	44.170639000000001	56.421180999999997	56.155709000000002	0103000020E610000001000000050000009E280989B4CD4540B058C345EE134C409E280989B4CD454029594E42E9354C400936AE7FD715464029594E42E9354C400936AE7FD7154640B058C345EE134C409E280989B4CD4540B058C345EE134C40
49760	Неклюдово	7	68	\N	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
13322	Кулебаки	7	68	\N	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
49702	Кстово	7	68	\N	41.776566000000003	47.770995999999997	58.091237	54.461975000000002	0103000020E61000000100000005000000C097C28366E34440E9482EFF213B4B40C097C28366E34440B3976DA7AD0B4D4064AC36FFAFE24740B3976DA7AD0B4D4064AC36FFAFE24740E9482EFF213B4B40C097C28366E34440E9482EFF213B4B40
49699	Желнино	7	68	\N	43.355867000000003	43.382959999999997	56.209390999999997	56.192154000000002	0103000020E61000000100000005000000E25CC30C8DAD4540D6E5948098184C40E25CC30C8DAD4540D2890453CD1A4C408CD651D504B14540D2890453CD1A4C408CD651D504B14540D6E5948098184C40E25CC30C8DAD4540D6E5948098184C40
9699	Дзержинск	7	68	\N	43.369970000000002	43.508660999999996	56.264617000000001	56.212358999999999	0103000020E6100000010000000500000025404D2D5BAF4540710168942E1B4C4025404D2D5BAF45409A7B48F8DE214C4015E0BBCD1BC145409A7B48F8DE214C4015E0BBCD1BC14540710168942E1B4C4025404D2D5BAF4540710168942E1B4C40
5618	Городец	7	68	\N	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
138	Выкса	7	68	\N	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
50053	Бор	7	68	\N	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
40353	Бор	7	68	\N	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
14518	Богородск	7	68	\N	43.476447999999998	43.560988000000002	56.117361000000002	56.086072999999999	0103000020E610000001000000050000004F1F813FFCBC4540C808A870040B4C404F1F813FFCBC4540B6696CAF050F4C4067B96C74CEC74540B6696CAF050F4C4067B96C74CEC74540C808A870040B4C404F1F813FFCBC4540C808A870040B4C40
49824	Балахна	7	68	\N	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
6490	Арзамас	7	68	\N	43.757432000000001	43.917816999999999	55.430314000000003	55.346246000000001	0103000020E61000000100000005000000D1782288F3E04540772FF7C951AC4B40D1782288F3E045406781768714B74B403E5B07077BF545406781768714B74B403E5B07077BF54540772FF7C951AC4B40D1782288F3E04540772FF7C951AC4B40
8387	Щербаж	7	68	933	46.784449000000002	46.813392	57.639198	57.627706000000003	0103000020E61000000100000005000000A13028D36864474062C092AB58D04C40A13028D36864474095D5743DD1D14C40FD69A33A1D68474095D5743DD1D14C40FD69A33A1D68474062C092AB58D04C40A13028D36864474062C092AB58D04C40
7520	Шахунья	7	68	933	46.571198000000003	46.668574999999997	57.692487999999997	57.646365000000003	0103000020E6100000010000000500000033C51C041D494740B8239C16BCD24C4033C51C041D494740AC6F6072A3D84C402BF697DD93554740AC6F6072A3D84C402BF697DD93554740B8239C16BCD24C4033C51C041D494740B8239C16BCD24C40
8916	Черное	7	68	933	46.385497999999998	46.422669999999997	57.542051999999998	57.526659000000002	0103000020E6100000010000000500000032569BFF573147407192E68F69C34C4032569BFF573147409E5DBEF561C54C400A80F10C1A3647409E5DBEF561C54C400A80F10C1A3647407192E68F69C34C4032569BFF573147407192E68F69C34C40
8635	Хмелевицы	7	68	933	46.357605	46.389909000000003	57.754584999999999	57.737417999999998	0103000020E610000001000000050000006BF12900C62D4740A9BD88B663DE4C406BF12900C62D4740AD86C43D96E04C4042B5C189E8314740AD86C43D96E04C4042B5C189E8314740A9BD88B663DE4C406BF12900C62D4740A9BD88B663DE4C40
49638	Туманино	7	68	933	46.601992000000003	46.628509999999999	57.720982999999997	57.710296999999997	0103000020E61000000100000005000000113AE8120E4D474034B91803EBDA4C40113AE8120E4D474069FCC22B49DC4C40BF9A03047350474069FCC22B49DC4C40BF9A03047350474034B91803EBDA4C40113AE8120E4D474034B91803EBDA4C40
8135	Сява	7	68	933	46.276595	46.381104999999998	58.033647999999999	58.006788	0103000020E610000001000000050000005A9E077767234740AC00DF6DDE004D405A9E077767234740B4C9E1934E044D40C9AB730CC8304740B4C9E1934E044D40C9AB730CC8304740AC00DF6DDE004D405A9E077767234740AC00DF6DDE004D40
8893	Никитиха	7	68	933	46.114620000000002	46.137768999999999	57.699285000000003	57.683328000000003	0103000020E61000000100000005000000D8BB3FDEAB0E47407638BA4A77D74C40D8BB3FDEAB0E4740ACCABE2B82D94C4089B3226AA2114740ACCABE2B82D94C4089B3226AA21147407638BA4A77D74C40D8BB3FDEAB0E47407638BA4A77D74C40
8298	Мелешиха	7	68	933	46.616858999999998	46.634619000000001	57.650627999999998	57.632317	0103000020E61000000100000005000000239F573CF54E474038DA71C3EFD04C40239F573CF54E474052EE3EC747D34C40CA3505323B51474052EE3EC747D34C40CA3505323B51474038DA71C3EFD04C40239F573CF54E474038DA71C3EFD04C40
8350	Мартяхино	7	68	933	46.745533999999999	46.768206999999997	57.598939000000001	57.587401	0103000020E610000001000000050000002D077AA86D5F4740A051BAF42FCB4C402D077AA86D5F474044A67C08AACC4C4075C7629B5462474044A67C08AACC4C4075C7629B54624740A051BAF42FCB4C402D077AA86D5F4740A051BAF42FCB4C40
8692	Малиновка	7	68	933	46.387303000000003	46.397948	57.625411999999997	57.619667	0103000020E6100000010000000500000044520B259331474089B48D3F51CF4C4044520B259331474052431B800DD04C401AC1C6F5EF32474052431B800DD04C401AC1C6F5EF32474089B48D3F51CF4C4044520B259331474089B48D3F51CF4C40
8860	Лужайки	7	68	933	46.530962000000002	46.545020999999998	57.667802000000002	57.66151	0103000020E610000001000000050000009AB51490F64347400DFD135CACD44C409AB51490F6434740091A33897AD54C400D51853FC3454740091A33897AD54C400D51853FC34547400DFD135CACD44C409AB51490F64347400DFD135CACD44C40
8726	Красногор	7	68	933	46.289512999999999	46.315007000000001	57.764375000000001	57.750368000000002	0103000020E61000000100000005000000286211C30E25474083FB010F0CE04C40286211C30E254740A4703D0AD7E14C406B813D2652284740A4703D0AD7E14C406B813D265228474083FB010F0CE04C40286211C30E25474083FB010F0CE04C40
16037	Комсомольский	7	68	933	46.364413999999996	46.384670999999997	57.648913	57.635097999999999	0103000020E610000001000000050000002E1A321EA52E4740A4E029E44AD14C402E1A321EA52E47408179C8940FD34C401C5C3AE63C3147408179C8940FD34C401C5C3AE63C314740A4E029E44AD14C402E1A321EA52E4740A4E029E44AD14C40
8563	Верховское	7	68	933	46.372481000000001	46.412627000000001	57.909632999999999	57.893090000000001	0103000020E61000000100000005000000D1B01875AD2F47403C31EBC550F24C40D1B01875AD2F4740622EA9DA6EF44C402A3927F6D0344740622EA9DA6EF44C402A3927F6D03447403C31EBC550F24C40D1B01875AD2F47403C31EBC550F24C40
7914	Вахтан	7	68	933	46.650384000000003	46.716734000000002	57.982590000000002	57.946216	0103000020E61000000100000005000000BCEB6CC83F534740D9791B9B1DF94C40BCEB6CC83F53474036B05582C5FD4C4034F790F0BD5B474036B05582C5FD4C4034F790F0BD5B4740D9791B9B1DF94C40BCEB6CC83F534740D9791B9B1DF94C40
8814	Большое Широкое	7	68	933	46.193438	46.220557999999997	57.640912999999998	57.625551999999999	0103000020E61000000100000005000000DEE68D93C218474044F9821612D04C40DEE68D93C2184740664AEB6F09D24C40826F9A3E3B1C4740664AEB6F09D24C40826F9A3E3B1C474044F9821612D04C40DEE68D93C218474044F9821612D04C40
8492	Большая Свеча	7	68	933	46.279415999999998	46.298496	57.708646999999999	57.694715000000002	0103000020E6100000010000000500000054FD4AE7C32347403485CE6BECD84C4054FD4AE7C32347404AB4E4F1B4DA4C4050FEEE1D352647404AB4E4F1B4DA4C4050FEEE1D352647403485CE6BECD84C4054FD4AE7C32347403485CE6BECD84C40
8445	Большая Музя	7	68	933	46.436180999999998	46.459626999999998	57.761816000000003	57.752831999999998	0103000020E610000001000000050000007B116DC7D4374740EEB089CC5CE04C407B116DC7D4374740E7C8CA2F83E14C40E6ADBA0ED53A4740E7C8CA2F83E14C40E6ADBA0ED53A4740EEB089CC5CE04C407B116DC7D4374740EEB089CC5CE04C40
8742	Андрианово	7	68	933	46.184069000000001	46.198225999999998	57.747611999999997	57.735568000000001	0103000020E610000001000000050000008D9AAF928F174740F8FD9B1727DE4C408D9AAF928F1747406F0C01C0B1DF4C40C39B35785F1947406F0C01C0B1DF4C40C39B35785F194740F8FD9B1727DE4C408D9AAF928F174740F8FD9B1727DE4C40
8221	Акаты	7	68	933	46.532085000000002	46.554102999999998	57.606606999999997	57.598861999999997	0103000020E6100000010000000500000099D87C5C1B44474098689082A7CC4C4099D87C5C1B4447402843554CA5CD4C40C8CEDBD8EC4647402843554CA5CD4C40C8CEDBD8EC46474098689082A7CC4C4099D87C5C1B44474098689082A7CC4C40
50059	п. Светлогорск	7	68	828	43.781300000000002	44.838698000000001	55.386097999999997	55.028925000000001	0103000020E61000000100000005000000B22E6EA301E44540B6847CD0B3834B40B22E6EA301E445408786C5A86BB14B403D9CC0745A6B46408786C5A86BB14B403D9CC0745A6B4640B6847CD0B3834B40B22E6EA301E44540B6847CD0B3834B40
7305	Языково	7	68	828	44.596736999999997	44.620002999999997	55.253943	55.243895000000002	0103000020E6100000010000000500000015A8C5E0614C464037548CF3379F4B4015A8C5E0614C46402906483481A04B40003620425C4F46402906483481A04B40003620425C4F464037548CF3379F4B4015A8C5E0614C464037548CF3379F4B40
5962	Шатки	7	68	828	44.092700999999998	44.158709000000002	55.204777	55.165770000000002	0103000020E610000001000000050000003BA759A0DD0B464037548CF337954B403BA759A0DD0B46408BFCFA21369A4B405A4A9693501446408BFCFA21369A4B405A4A96935014464037548CF337954B403BA759A0DD0B464037548CF337954B40
7238	Шарапово	7	68	828	44.699539999999999	44.736046999999999	55.280163999999999	55.261659000000002	0103000020E61000000100000005000000361FD7868A5946401FDAC70A7EA14B40361FD7868A5946401EC2F869DCA34B40D2A8C0C9365E46401EC2F869DCA34B40D2A8C0C9365E46401FDAC70A7EA14B40361FD7868A5946401FDAC70A7EA14B40
7330	Чапары	7	68	828	44.651192000000002	44.669984999999997	55.292499999999997	55.276862000000001	0103000020E610000001000000050000005BB56B425A534640A9C0C93670A34B405BB56B425A5346403D0AD7A370A54B40C0E78711C25546403D0AD7A370A54B40C0E78711C2554640A9C0C93670A34B405BB56B425A534640A9C0C93670A34B40
7135	Старое Иванцево	7	68	828	44.562376	44.585382000000003	55.235128000000003	55.221116000000002	0103000020E610000001000000050000001407D0EFFB474640A94F72874D9C4B401407D0EFFB474640DC2F9FAC189E4B4063D520CCED4A4640DC2F9FAC189E4B4063D520CCED4A4640A94F72874D9C4B401407D0EFFB474640A94F72874D9C4B40
6674	Спасское	7	68	828	44.328634000000001	44.360156000000003	55.230159	55.205922999999999	0103000020E61000000100000005000000452DCDAD102A4640423F53AF5B9A4B40452DCDAD102A4640A6F0A0D9759D4B40A6BA8097192E4640A6F0A0D9759D4B40A6BA8097192E4640423F53AF5B9A4B40452DCDAD102A4640423F53AF5B9A4B40
7124	Смирново	7	68	828	44.386521999999999	44.410443999999998	55.322572999999998	55.302104999999997	0103000020E610000001000000050000009E978A8D79314640A27A6B60ABA64B409E978A8D793146404BC972124AA94B40726BD26D893446404BC972124AA94B40726BD26D89344640A27A6B60ABA64B409E978A8D79314640A27A6B60ABA64B40
6938	Силино	7	68	828	44.328814000000001	44.368330999999998	55.109440999999997	55.090974000000003	0103000020E61000000100000005000000C53BC093162A4640A6643909A58B4B40C53BC093162A4640B7EBA529028E4B402E8D5F78252F4640B7EBA529028E4B402E8D5F78252F4640A6643909A58B4B40C53BC093162A4640A6643909A58B4B40
49777	Понетаевка	7	68	828	43.877428999999999	43.893453999999998	55.126282000000003	55.109394000000002	0103000020E61000000100000005000000EFC7ED974FF045407730629F008E4B40EFC7ED974FF04540680932022A904B407D3D5FB35CF24540680932022A904B407D3D5FB35CF245407730629F008E4B40EFC7ED974FF045407730629F008E4B40
6923	Пасьяново	7	68	828	44.044479000000003	44.062975999999999	55.250639	55.236795999999998	0103000020E61000000100000005000000ED2DE57CB10546406CE9D1544F9E4B40ED2DE57CB1054640130D52F014A04B406937FA980F084640130D52F014A04B406937FA980F0846406CE9D1544F9E4B40ED2DE57CB10546406CE9D1544F9E4B40
6588	Паново	7	68	828	43.889726000000003	43.916218000000001	55.222538999999998	55.207084000000002	0103000020E610000001000000050000005133A48AE2F145402FC37FBA819A4B405133A48AE2F14540D28A6F287C9C4B40D600A5A146F54540D28A6F287C9C4B40D600A5A146F545402FC37FBA819A4B405133A48AE2F145402FC37FBA819A4B40
7011	Новое	7	68	828	44.271042999999999	44.292118000000002	55.120263999999999	55.102688999999998	0103000020E61000000100000005000000A5677A89B12246405854C4E9248D4B40A5677A89B12246406D718DCF648F4B405649641F642546406D718DCF648F4B405649641F642546405854C4E9248D4B40A5677A89B12246405854C4E9248D4B40
6261	Лесогорск	7	68	828	43.928030999999997	43.937454000000002	55.099387	55.093102000000002	0103000020E610000001000000050000004B5645B8C9F645409A982EC4EA8B4B404B5645B8C9F64540E35295B6B88C4B4090C01F7EFEF74540E35295B6B88C4B4090C01F7EFEF745409A982EC4EA8B4B404B5645B8C9F645409A982EC4EA8B4B40
50044	Красный Бор	7	68	828	43.967672999999998	44.001944000000002	55.279944	55.254733000000002	0103000020E61000000100000005000000711C78B5DCFB4540221B48179BA04B40711C78B5DCFB4540105B7A34D5A34B40333674B33F004640105B7A34D5A34B40333674B33F004640221B48179BA04B40711C78B5DCFB4540221B48179BA04B40
6742	Костянка	7	68	828	44.464666000000001	44.495100999999998	55.310437	55.299655000000001	0103000020E6100000010000000500000015C8EC2C7A3B46409C8A54185BA64B4015C8EC2C7A3B4640F33B4D66BCA74B40C39B35785F3F4640F33B4D66BCA74B40C39B35785F3F46409C8A54185BA64B4015C8EC2C7A3B46409C8A54185BA64B40
49832	Ключищи	7	68	828	43.982081999999998	44.004036999999997	55.117153999999999	55.104950000000002	0103000020E61000000100000005000000C1FEEBDCB4FD45408CDB68006F8D4B40C1FEEBDCB4FD45403C4CFBE6FE8E4B40AA7CCF48840046403C4CFBE6FE8E4B40AA7CCF48840046408CDB68006F8D4B40C1FEEBDCB4FD45408CDB68006F8D4B40
6649	Кержемок	7	68	828	44.206364999999998	44.234400999999998	55.221983999999999	55.200611000000002	0103000020E61000000100000005000000FF04172B6A1A4640E31B0A9FAD994B40FF04172B6A1A46401D1EC2F8699C4B4029931ADA001E46401D1EC2F8699C4B4029931ADA001E4640E31B0A9FAD994B40FF04172B6A1A4640E31B0A9FAD994B40
7066	Калапино	7	68	828	44.183323000000001	44.220253	55.073782999999999	55.057589999999998	0103000020E6100000010000000500000064CDC82077174640CF49EF1B5F874B4064CDC820771746401900AAB871894B4046EC1340311C46401900AAB871894B4046EC1340311C4640CF49EF1B5F874B4064CDC82077174640CF49EF1B5F874B40
6514	Елховка	7	68	828	43.936788999999997	43.958689999999997	55.157747000000001	55.142468000000001	0103000020E610000001000000050000005320B3B3E8F74540FF5C34643C924B405320B3B3E8F745406405BF0D31944B4049809A5AB6FA45406405BF0D31944B4049809A5AB6FA4540FF5C34643C924B405320B3B3E8F74540FF5C34643C924B40
7418	Выползово	7	68	828	44.770631999999999	44.794294000000001	55.323469000000003	55.309848000000002	0103000020E6100000010000000500000023A0C211A4624640925D6919A9A74B4023A0C211A46246408A22A46E67A94B405BB4006DAB6546408A22A46E67A94B405BB4006DAB654640925D6919A9A74B4023A0C211A4624640925D6919A9A74B40
7205	Великий Враг	7	68	828	44.498379999999997	44.539234999999998	55.270733	55.241083000000003	0103000020E61000000100000005000000807D74EACA3F4640904FC8CEDB9E4B40807D74EACA3F464057790261A7A24B40E5ED08A70545464057790261A7A24B40E5ED08A705454640904FC8CEDB9E4B40807D74EACA3F4640904FC8CEDB9E4B40
6790	Большие Печерки	7	68	828	44.597876999999997	44.624000000000002	55.340712000000003	55.326326999999999	0103000020E61000000100000005000000EA03C93B874C4640A1664815C5A94B40EA03C93B874C464069AD68739CAB4B401D5A643BDF4F464069AD68739CAB4B401D5A643BDF4F4640A1664815C5A94B40EA03C93B874C4640A1664815C5A94B40
6427	Архангельское	7	68	828	44.078436000000004	44.118707000000001	55.236232000000001	55.204968000000001	0103000020E610000001000000050000001F6ADB300A0A4640FF5C34643C9A4B401F6ADB300A0A46406422A5D93C9E4B4034677DCA310F46406422A5D93C9E4B4034677DCA310F4640FF5C34643C9A4B401F6ADB300A0A4640FF5C34643C9A4B40
5067	Щенники	7	68	689	46.636541000000001	46.663598	57.328229	57.318334999999998	0103000020E6100000010000000500000015C8EC2C7A51474009168733BFA84C4015C8EC2C7A514740A54C6A6803AA4C4073D87DC7F0544740A54C6A6803AA4C4073D87DC7F054474009168733BFA84C4015C8EC2C7A51474009168733BFA84C40
5746	Щекотово	7	68	689	46.553643999999998	46.587995999999997	56.991115999999998	56.975603	0103000020E6100000010000000500000035D07CCEDD4647409370218FE07C4C4035D07CCEDD4647406B459BE3DC7E4C40E316F373434B47406B459BE3DC7E4C40E316F373434B47409370218FE07C4C4035D07CCEDD4647409370218FE07C4C40
4903	Шаранга	7	68	689	46.500033000000002	46.578169000000003	57.194352000000002	57.153146	0103000020E61000000100000005000000DCF5D21401404740B1C1C2499A934C40DCF5D21401404740C3F4BD86E0984C40D0471971014A4740C3F4BD86E0984C40D0471971014A4740B1C1C2499A934C40DCF5D21401404740B1C1C2499A934C40
5795	Черномуж	7	68	689	46.468682000000001	46.494436999999998	57.127735999999999	57.116061999999999	0103000020E61000000100000005000000A81C93C5FD3B474078279F1EDB8E4C40A81C93C5FD3B4740CC423BA759904C4057772CB6493F4740CC423BA759904C4057772CB6493F474078279F1EDB8E4C40A81C93C5FD3B474078279F1EDB8E4C40
5816	Туманка	7	68	689	46.471628000000003	46.493924	57.180529	57.166989000000001	0103000020E610000001000000050000005FF0694E5E3C474058E542E55F954C405FF0694E5E3C4740637D03931B974C40D15AD1E6383F4740637D03931B974C40D15AD1E6383F474058E542E55F954C405FF0694E5E3C474058E542E55F954C40
5691	Старая Рудка	7	68	689	46.470109999999998	46.502324000000002	56.971325	56.958213000000001	0103000020E61000000100000005000000E3C281902C3C474010CD3CB9A67A4C40E3C281902C3C4740C364AA60547C4C407AFF1F274C404740C364AA60547C4C407AFF1F274C40474010CD3CB9A67A4C40E3C281902C3C474010CD3CB9A67A4C40
5523	Роженцово	7	68	689	46.529031000000003	46.558692999999998	57.058942999999999	57.041528999999997	0103000020E61000000100000005000000FCC8AD49B7434740F46A80D250854C40FCC8AD49B743474000AAB8718B874C4087C091408347474000AAB8718B874C4087C0914083474740F46A80D250854C40FCC8AD49B7434740F46A80D250854C40
5441	Преображенка	7	68	689	46.749341999999999	46.765602000000001	56.983980000000003	56.973007000000003	0103000020E6100000010000000500000076C24B70EA5F4740B9E34D7E8B7C4C4076C24B70EA5F474084F57F0EF37D4C4048E00F3FFF61474084F57F0EF37D4C4048E00F3FFF614740B9E34D7E8B7C4C4076C24B70EA5F4740B9E34D7E8B7C4C40
5548	Поздеево	7	68	689	46.497239	46.504182999999998	57.027565000000003	57.020921999999999	0103000020E61000000100000005000000DBA50D87A53F47402AE27492AD824C40DBA50D87A53F4740D3C1FA3F87834C407E198C1189404740D3C1FA3F87834C407E198C11894047402AE27492AD824C40DBA50D87A53F47402AE27492AD824C40
5222	Пестово	7	68	689	46.665376999999999	46.698965000000001	57.181826999999998	57.170862999999997	0103000020E610000001000000050000005B41D3122B554740588CBAD6DE954C405B41D3122B554740D0436D1B46974C403A0664AF77594740D0436D1B46974C403A0664AF77594740588CBAD6DE954C405B41D3122B554740588CBAD6DE954C40
5903	Мосуново	7	68	689	46.557876	46.571683	57.139122	57.132024999999999	0103000020E61000000100000005000000959C137B6847474090A0F831E6904C40959C137B68474740BA13ECBFCE914C40EF5696E82C494740BA13ECBFCE914C40EF5696E82C49474090A0F831E6904C40959C137B6847474090A0F831E6904C40
5412	Кушнур	7	68	689	46.701624000000002	46.719869000000003	57.013165000000001	57.001319000000002	0103000020E610000001000000050000005B0BB3D0CE59474085EE92382B804C405B0BB3D0CE594740D6390664AF814C40BE33DAAA245C4740D6390664AF814C40BE33DAAA245C474085EE92382B804C405B0BB3D0CE59474085EE92382B804C40
5205	Кугланур	7	68	689	46.622959000000002	46.654722999999997	57.243124999999999	57.229647	0103000020E61000000100000005000000DBDFD91EBD4F4740F04FA912659D4C40DBDFD91EBD4F474085EB51B81E9F4C40317898F6CD53474085EB51B81E9F4C40317898F6CD534740F04FA912659D4C40DBDFD91EBD4F4740F04FA912659D4C40
5619	Красная Горка	7	68	689	46.384715999999997	46.399889000000002	57.049402000000001	57.040163	0103000020E61000000100000005000000BC1FB75F3E3147402FC1A90F24854C40BC1FB75F3E314740B22D03CE52864C40DC8310902F334740B22D03CE52864C40DC8310902F3347402FC1A90F24854C40BC1FB75F3E3147402FC1A90F24854C40
4810	Козлянур	7	68	689	46.703591000000003	46.725985999999999	57.047713000000002	57.034329999999997	0103000020E61000000100000005000000466117450F5A4740C6A2E9EC64844C40466117450F5A47400A4CA7751B864C404BADF71BED5C47400A4CA7751B864C404BADF71BED5C4740C6A2E9EC64844C40466117450F5A4740C6A2E9EC64844C40
5051	Большое Устинское	7	68	689	46.437241	46.470253999999997	57.280906999999999	57.264747	0103000020E6100000010000000500000034BC5983F7374740685BCD3AE3A14C4034BC5983F7374740D61BB5C2F4A34C4016687748313C4740D61BB5C2F4A34C4016687748313C4740685BCD3AE3A14C4034BC5983F7374740685BCD3AE3A14C40
5335	Большая Рудка	7	68	689	46.693216	46.747599999999998	57.133645999999999	57.115631999999998	0103000020E610000001000000050000002F88484DBB5847407F2F8507CD8E4C402F88484DBB584740E09EE74F1B914C40AB3E575BB15F4740E09EE74F1B914C40AB3E575BB15F47407F2F8507CD8E4C402F88484DBB5847407F2F8507CD8E4C40
5159	Астанчурга	7	68	689	46.625411	46.644123	57.281179999999999	57.267719999999997	0103000020E6100000010000000500000082C7B7770D504740183E22A644A24C4082C7B7770D5047400725CCB4FDA34C40FBCC599F725247400725CCB4FDA34C40FBCC599F72524740183E22A644A24C4082C7B7770D504740183E22A644A24C40
3827	Чкаловск	7	68	305	43.196488000000002	43.269385999999997	56.780127	56.750245999999997	0103000020E610000001000000050000003A07CF842699454037FA980F08604C403A07CF842699454001DD9733DB634C4008008E3D7BA2454001DD9733DB634C4008008E3D7BA2454037FA980F08604C403A07CF842699454037FA980F08604C40
4149	Чистое	7	68	305	42.985607999999999	43.023390999999997	56.546649000000002	56.527439999999999	0103000020E6100000010000000500000086562767287E4540164D672783434C4086562767287E454010B22C98F8454C40A702EE79FE82454010B22C98F8454C40A702EE79FE824540164D672783434C4086562767287E4540164D672783434C40
4718	Соломаты	7	68	305	42.890557000000001	42.923822000000001	56.753591999999998	56.738582000000001	0103000020E61000000100000005000000A81C93C5FD71454007B5DFDA895E4C40A81C93C5FD7145407C43E1B375604C40A4A99ECC3F7645407C43E1B375604C40A4A99ECC3F76454007B5DFDA895E4C40A81C93C5FD71454007B5DFDA895E4C40
4635	Сицкое	7	68	305	43.147053	43.162072999999999	56.771284000000001	56.760322000000002	0103000020E61000000100000005000000ACE3F8A1D2924540F436363B52614C40ACE3F8A1D2924540CBF6216FB9624C404548DDCEBE944540CBF6216FB9624C404548DDCEBE944540F436363B52614C40ACE3F8A1D2924540F436363B52614C40
4690	Пурех	7	68	305	43.041285999999999	43.089075999999999	56.654193999999997	56.633184	0103000020E610000001000000050000002EE411DC48854540DC2C5E2C0C514C402EE411DC48854540A59E05A1BC534C40E36DA5D7668B4540A59E05A1BC534C40E36DA5D7668B4540DC2C5E2C0C514C402EE411DC48854540DC2C5E2C0C514C40
4552	Новинки	7	68	305	43.041932000000003	43.062109	56.755358000000001	56.746011000000003	0103000020E61000000100000005000000F4531C075E85454067BAD7497D5F4C40F4531C075E854540D0622992AF604C40C5E40D30F3874540D0622992AF604C40C5E40D30F387454067BAD7497D5F4C40F4531C075E85454067BAD7497D5F4C40
4446	Кузнецово	7	68	305	43.105857	43.208928999999998	56.722360000000002	56.629787999999998	0103000020E61000000100000005000000BE86E0B88C8D4540E5B4A7E49C504C40BE86E0B88C8D454023F8DF4A765C4C40CE177B2FBE9A454023F8DF4A765C4C40CE177B2FBE9A4540E5B4A7E49C504C40BE86E0B88C8D4540E5B4A7E49C504C40
4316	Котельницы	7	68	305	43.210645	43.218020000000003	56.810768000000003	56.804997999999998	0103000020E610000001000000050000007008556AF69A454036ACA92C0A674C407008556AF69A45405952EE3EC7674C40DDEF5014E89B45405952EE3EC7674C40DDEF5014E89B454036ACA92C0A674C407008556AF69A454036ACA92C0A674C40
1368	Кодочиги	7	68	305	42.924469000000002	42.933577999999997	56.749890000000001	56.744213999999999	0103000020E610000001000000050000003A950C0055764540D89C8367425F4C403A950C005576454079CC4065FC5F4C40EE21E17B7F77454079CC4065FC5F4C40EE21E17B7F774540D89C8367425F4C403A950C0055764540D89C8367425F4C40
4139	Катунки	7	68	305	43.211004000000003	43.23516	56.840242000000003	56.824607	0103000020E61000000100000005000000A0A9D72D029B4540BE86E0B88C694C40A0A9D72D029B4540E25CC30C8D6B4C40E7A90EB9199E4540E25CC30C8D6B4C40E7A90EB9199E4540BE86E0B88C694C40A0A9D72D029B4540BE86E0B88C694C40
4854	Железово	7	68	305	42.974998999999997	42.996189999999999	56.720216999999998	56.716566999999998	0103000020E61000000100000005000000FC5069C4CC7C45404832AB77B85B4C40FC5069C4CC7C4540F9821612305C4C40164D6727837F4540F9821612305C4C40164D6727837F45404832AB77B85B4C40FC5069C4CC7C45404832AB77B85B4C40
49734	Высокая	7	68	305	43.183416999999999	43.217534999999998	56.689718999999997	56.677097000000003	0103000020E61000000100000005000000E54350357A974540209C4F1DAB564C40E54350357A974540043752B648584C40205ED72FD89B4540043752B648584C40205ED72FD89B4540209C4F1DAB564C40E54350357A974540209C4F1DAB564C40
50047	Вершилово	7	68	305	43.200135000000003	43.225898000000001	56.627985000000002	56.614643999999998	0103000020E610000001000000050000007AE40F069E994540605793A7AC4E4C407AE40F069E99454075B0FECF61504C40AC1DC539EA9C454075B0FECF61504C40AC1DC539EA9C4540605793A7AC4E4C407AE40F069E994540605793A7AC4E4C40
4243	Белое	7	68	305	42.985860000000002	42.997402999999998	56.795786	56.787641999999998	0103000020E61000000100000005000000A03715A9307E45405F7AFB73D1644C40A03715A9307E4540AD4ECE50DC654C4055F7C8E6AA7F4540AD4ECE50DC654C4055F7C8E6AA7F45405F7AFB73D1644C40A03715A9307E45405F7AFB73D1644C40
3709	Уста	7	68	338	45.636132000000003	45.697181999999998	57.444834999999998	57.42221	0103000020E6100000010000000500000034F8FBC56CD14640A7052FFA0AB64C4034F8FBC56CD14640DE8E705AF0B84C4010AE80423DD94640DE8E705AF0B84C4010AE80423DD94640A7052FFA0AB64C4034F8FBC56CD14640A7052FFA0AB64C40
1616	Урень	7	68	338	45.735754999999997	45.848108000000003	57.484065000000001	57.445155	0103000020E610000001000000050000002A6F47382DDE46405053CBD6FAB84C402A6F47382DDE4640B21188D7F5BD4C40EDBC8DCD8EEC4640B21188D7F5BD4C40EDBC8DCD8EEC46405053CBD6FAB84C402A6F47382DDE46405053CBD6FAB84C40
2992	Тулага	7	68	338	45.791271000000002	45.811726	57.594149999999999	57.573335	0103000020E61000000100000005000000F9A23D5E48E546407A53910A63C94C40F9A23D5E48E546408E75711B0DCC4C400DA837A3E6E746408E75711B0DCC4C400DA837A3E6E746407A53910A63C94C40F9A23D5E48E546407A53910A63C94C40
3639	Темта	7	68	338	45.867564999999999	45.890355	57.501154	57.482337999999999	0103000020E61000000100000005000000BE13B35E0CEF46401CCF6740BDBD4C40BE13B35E0CEF46403A2174D025C04C40406A1327F7F146403A2174D025C04C40406A1327F7F146401CCF6740BDBD4C40BE13B35E0CEF46401CCF6740BDBD4C40
3451	Семеново	7	68	338	45.705401000000002	45.727553999999998	57.350461000000003	57.321877999999998	0103000020E6100000010000000500000069C878944ADA4640A4A65D4C33A94C4069C878944ADA464001C3F2E7DBAC4C4078094E7D20DD464001C3F2E7DBAC4C4078094E7D20DD4640A4A65D4C33A94C4069C878944ADA4640A4A65D4C33A94C40
3345	Обход	7	68	338	46.188972999999997	46.237769999999998	57.575299999999999	57.560051000000001	0103000020E61000000100000005000000DB696B4430184740CA8B4CC0AFC74C40DB696B4430184740C4B12E6EA3C94C4026FC523F6F1E4740C4B12E6EA3C94C4026FC523F6F1E4740CA8B4CC0AFC74C40DB696B4430184740CA8B4CC0AFC74C40
3302	Минеево	7	68	338	45.526654999999998	45.542617999999997	57.368371000000003	57.357643000000003	0103000020E610000001000000050000002FA3586E69C346405952EE3EC7AD4C402FA3586E69C34640BDE5EAC726AF4C40471CB28174C54640BDE5EAC726AF4C40471CB28174C546405952EE3EC7AD4C402FA3586E69C346405952EE3EC7AD4C40
3676	Ломы	7	68	338	45.584910000000001	45.594405000000002	57.466082	57.458544000000003	0103000020E610000001000000050000003B8DB454DECA464076E3DD91B1BA4C403B8DB454DECA46408CA03193A8BB4C4019CA897615CC46408CA03193A8BB4C4019CA897615CC464076E3DD91B1BA4C403B8DB454DECA464076E3DD91B1BA4C40
3536	Красный Яр	7	68	338	45.682198	45.697676000000001	57.404724999999999	57.398454999999998	0103000020E61000000100000005000000C4B2994352D74640BEF6CC9200B34C40C4B2994352D74640D26F5F07CEB34C40209A79724DD94640D26F5F07CEB34C40209A79724DD94640BEF6CC9200B34C40C4B2994352D74640BEF6CC9200B34C40
2863	Копылиха	7	68	338	45.620600000000003	45.644019	57.637183999999998	57.626756999999998	0103000020E61000000100000005000000E5F21FD26FCF464000C5C89239D04C40E5F21FD26FCF464069C4CC3E8FD14C405680EF366FD2464069C4CC3E8FD14C405680EF366FD2464000C5C89239D04C40E5F21FD26FCF464000C5C89239D04C40
3100	Карпуниха	7	68	338	45.791352000000003	45.814556000000003	57.686258000000002	57.666699999999999	0103000020E61000000100000005000000E6CFB7054BE54640211FF46C56D54C40E6CFB7054BE54640274F594DD7D74C405B61FA5E43E84640274F594DD7D74C405B61FA5E43E84640211FF46C56D54C40E6CFB7054BE54640211FF46C56D54C40
2844	Вязовая	7	68	338	45.711123999999998	45.741612000000003	57.663257999999999	57.650328999999999	0103000020E610000001000000050000004AB3791C06DB4640F8510DFB3DD34C404AB3791C06DB4640BA675DA3E5D44C401C295B24EDDE4640BA675DA3E5D44C401C295B24EDDE4640F8510DFB3DD34C404AB3791C06DB4640F8510DFB3DD34C40
2650	Большой Терсень	7	68	338	45.704017999999998	45.725344	57.466106000000003	57.461967000000001	0103000020E61000000100000005000000CDE506431DDA4640666A12BC21BB4C40CDE506431DDA4640153C855CA9BB4C40C72C7B12D8DC4640153C855CA9BB4C40C72C7B12D8DC4640666A12BC21BB4C40CDE506431DDA4640666A12BC21BB4C40
3219	Большой Красногор	7	68	338	45.990184999999997	46.010784000000001	57.655472000000003	57.640922000000003	0103000020E61000000100000005000000B0FECF61BEFE4640BAA46ABB09D24C40B0FECF61BEFE4640CCB8A981E6D34C40F8A8BF5E61014740CCB8A981E6D34C40F8A8BF5E61014740BAA46ABB09D24C40B0FECF61BEFE4640BAA46ABB09D24C40
2497	Большое Песочное	7	68	338	46.068230999999997	46.089916000000002	57.491456999999997	57.482236	0103000020E6100000010000000500000064C91CCBBB084740187AC4E8B9BD4C4064C91CCBBB084740F4311F10E8BE4C408EB1135E820B4740F4311F10E8BE4C408EB1135E820B4740187AC4E8B9BD4C4064C91CCBBB084740187AC4E8B9BD4C40
2748	Большое Никитино	7	68	338	45.753003	45.771687999999997	57.514141000000002	57.504626000000002	0103000020E610000001000000050000001B65FD6662E046400C5BB39597C04C401B65FD6662E0464031444E5FCFC14C409A5B21ACC6E2464031444E5FCFC14C409A5B21ACC6E246400C5BB39597C04C401B65FD6662E046400C5BB39597C04C40
2609	Большое Непряхино	7	68	338	45.659478999999997	45.683535999999997	57.498311000000001	57.490958999999997	0103000020E610000001000000050000000BB3D0CE69D44640A35698BED7BE4C400BB3D0CE69D44640581EA4A7C8BF4C40BFD18E1B7ED74640581EA4A7C8BF4C40BFD18E1B7ED74640A35698BED7BE4C400BB3D0CE69D44640A35698BED7BE4C40
3523	Большое Лопатино	7	68	338	45.610117000000002	45.627364999999998	57.305813000000001	57.298811999999998	0103000020E61000000100000005000000E8DD585018CE464080D3BB783FA64C40E8DD585018CE464088D860E124A74C40D8D30E7F4DD0464088D860E124A74C40D8D30E7F4DD0464080D3BB783FA64C40E8DD585018CE464080D3BB783FA64C40
3050	Большое Карпово	7	68	338	46.069237000000001	46.096814999999999	57.410280999999998	57.392004	0103000020E610000001000000050000002A560DC2DC0847405AF3E32F2DB24C402A560DC2DC084740C8957A1684B44C409161156F640C4740C8957A1684B44C409161156F640C47405AF3E32F2DB24C402A560DC2DC0847405AF3E32F2DB24C40
2952	Большое Горево	7	68	338	45.845618999999999	45.873807999999997	57.575879	57.560093999999999	0103000020E6100000010000000500000028F04E3E3DEC4640C9570229B1C74C4028F04E3E3DEC464002BA2F67B6C94C40D87DC7F0D8EF464002BA2F67B6C94C40D87DC7F0D8EF4640C9570229B1C74C4028F04E3E3DEC4640C9570229B1C74C40
3196	Большая Козляна	7	68	338	45.851764000000003	45.878480000000003	57.674636999999997	57.663151999999997	0103000020E6100000010000000500000080F44D9A06ED464074232C2AE2D44C4080F44D9A06ED4640F5D555815AD64C4055185B0872F04640F5D555815AD64C4055185B0872F0464074232C2AE2D44C4080F44D9A06ED464074232C2AE2D44C40
2509	Большая Елховка	7	68	338	46.129773999999998	46.147731999999998	57.523198999999998	57.506675999999999	0103000020E6100000010000000500000080EF366F9C10474084D558C2DAC04C4080EF366F9C1047406326512FF8C24C404D49D6E1E81247406326512FF8C24C404D49D6E1E812474084D558C2DAC04C4080EF366F9C10474084D558C2DAC04C40
2423	Большая Арья	7	68	338	45.94182	45.969676999999997	57.514826999999997	57.496923000000002	0103000020E61000000100000005000000FF5BC98E8DF84640ABD0402C9BBF4C40FF5BC98E8DF84640840CE4D9E5C14C4079573D601EFC4640840CE4D9E5C14C4079573D601EFC4640ABD0402C9BBF4C40FF5BC98E8DF84640ABD0402C9BBF4C40
2166	Арья	7	68	338	45.949159000000002	45.991703000000001	57.501154	57.477122000000001	0103000020E610000001000000050000001FDAC70A7EF94640DF196D5512BD4C401FDAC70A7EF946403A2174D025C04C402C2CB81FF0FE46403A2174D025C04C402C2CB81FF0FE4640DF196D5512BD4C401FDAC70A7EF94640DF196D5512BD4C40
1435	Южный	7	68	126	47.438153	47.451529000000001	57.613497000000002	57.604514000000002	0103000020E6100000010000000500000078D2C26515B84740B1FCF9B660CD4C4078D2C26515B84740D998D71187CE4C400919C8B3CBB94740D998D71187CE4C400919C8B3CBB94740B1FCF9B660CD4C4078D2C26515B84740B1FCF9B660CD4C40
635	Ширта	7	68	126	47.048786999999997	47.072960999999999	57.809210999999998	57.797711	0103000020E6100000010000000500000027BC04A73E8647406954E0641BE64C4027BC04A73E8647401F48DE3994E74C4015713AC9568947401F48DE3994E74C4015713AC9568947406954E0641BE64C4027BC04A73E8647406954E0641BE64C40
1271	Шерстки	7	68	126	47.432232999999997	47.458598000000002	57.979014999999997	57.965010999999997	0103000020E6100000010000000500000040A0336953B74740DFA3FE7A85FB4C4040A0336953B747408FA50F5D50FD4C406901DA56B3BA47408FA50F5D50FD4C406901DA56B3BA4740DFA3FE7A85FB4C4040A0336953B74740DFA3FE7A85FB4C40
920	Шайгино	7	68	126	46.845202	46.875402999999999	57.779423000000001	57.759256999999998	0103000020E61000000100000005000000C44142942F6C4740292158552FE14C40C44142942F6C474007600322C4E34C40FFE89B340D70474007600322C4E34C40FFE89B340D704740292158552FE14C40C44142942F6C4740292158552FE14C40
261	Тоншаево	7	68	126	46.989587999999998	47.061579000000002	57.748590999999998	57.723055000000002	0103000020E61000000100000005000000CC41D0D1AA7E4740CA1AF5108DDC4C40CC41D0D1AA7E47403B8A73D4D1DF4C40698F17D2E18747403B8A73D4D1DF4C40698F17D2E1874740CA1AF5108DDC4C40CC41D0D1AA7E4740CA1AF5108DDC4C40
1079	Сухой Овраг	7	68	126	47.057006000000001	47.073104000000001	57.682822999999999	57.668784000000002	0103000020E6100000010000000500000080D6FCF84B874740460BD0B69AD54C4080D6FCF84B87474072FA7ABE66D74C40789ACC785B89474072FA7ABE66D74C40789ACC785B894740460BD0B69AD54C4080D6FCF84B874740460BD0B69AD54C40
9065	Ромачи	7	68	126	47.234487000000001	47.251958999999999	57.751502000000002	57.742173999999999	0103000020E61000000100000005000000282B86AB039E474083F8C08EFFDE4C40282B86AB039E47407670B03731E04C406877483140A047407670B03731E04C406877483140A0474083F8C08EFFDE4C40282B86AB039E474083F8C08EFFDE4C40
741	Пижма	7	68	126	47.073751000000001	47.152776000000003	57.875686999999999	57.845585	0103000020E610000001000000050000000E863AAC708947407C7E18213CEC4C400E863AAC708947402444F98216F04C408ECEF9298E9347402444F98216F04C408ECEF9298E9347407C7E18213CEC4C400E863AAC708947407C7E18213CEC4C40
1487	Ошминское	7	68	126	47.321390000000001	47.362631	57.687721000000003	57.675542	0103000020E6100000010000000500000077A1B94E23A947408789062978D64C4077A1B94E23A94740DFE2E13D07D84C4005C24EB16AAE4740DFE2E13D07D84C4005C24EB16AAE47408789062978D64C4077A1B94E23A947408789062978D64C40
1022	Гагаринское	7	68	126	46.871746999999999	46.881484999999998	57.679732999999999	57.675094000000001	0103000020E610000001000000050000006CB1DB67956F4740E8DCED7A69D64C406CB1DB67956F47408881AE7D01D74C4010751F80D47047408881AE7D01D74C4010751F80D4704740E8DCED7A69D64C406CB1DB67956F4740E8DCED7A69D64C40
1149	Вякшенер	7	68	126	47.094242000000001	47.114310000000003	57.591028999999999	57.575009999999999	0103000020E610000001000000050000006FF4311F108C4740BD6F7CED99C94C406FF4311F108C474069FE98D6A6CB4C408ACDC7B5A18E474069FE98D6A6CB4C408ACDC7B5A18E4740BD6F7CED99C94C406FF4311F108C4740BD6F7CED99C94C40
1214	Буреполом	7	68	126	47.341467000000002	47.382618999999998	57.960877000000004	57.940378000000003	0103000020E61000000100000005000000E5D4CE30B5AB47405FF0694E5EF84C40E5D4CE30B5AB4740433D7D04FEFA4C4003EACDA8F9B04740433D7D04FEFA4C4003EACDA8F9B047405FF0694E5EF84C40E5D4CE30B5AB47405FF0694E5EF84C40
1570	Большие Селки	7	68	126	47.163663	47.185744	57.716723999999999	57.706651999999998	0103000020E610000001000000050000005A48C0E8F294474095D39E9273DA4C405A48C0E8F29447401021AE9CBDDB4C40D0B69A75C69747401021AE9CBDDB4C40D0B69A75C697474095D39E9273DA4C405A48C0E8F294474095D39E9273DA4C40
624	Большая Куверба	7	68	126	47.132752000000004	47.149515000000001	57.8369	57.829017999999998	0103000020E61000000100000005000000433D7D04FE904740CDE506431DEA4C40433D7D04FE904740DE02098A1FEB4C4077A1B94E23934740DE02098A1FEB4C4077A1B94E23934740CDE506431DEA4C40433D7D04FE904740CDE506431DEA4C40
964	Березята	7	68	126	46.969411999999998	46.985734000000001	57.697909000000003	57.690784999999998	0103000020E61000000100000005000000CB2C42B1157C47409FC893A46BD84C40CB2C42B1157C4740C34A051555D94C4013471E882C7E4740C34A051555D94C4013471E882C7E47409FC893A46BD84C40CB2C42B1157C47409FC893A46BD84C40
50	Трошково	7	68	42	46.058224000000003	46.082118999999999	57.332121000000001	57.319181	0103000020E61000000100000005000000D1EB4FE27307474096404AECDAA84C40D1EB4FE2730747404CA8E0F082AA4C40ABB019E0820A47404CA8E0F082AA4C40ABB019E0820A474096404AECDAA84C40D1EB4FE27307474096404AECDAA84C40
32150	Тонкино	7	68	42	46.419266	46.480198000000001	57.389211000000003	57.355899999999998	0103000020E6100000010000000500000091291F82AA354740BD5296218EAD4C4091291F82AA3547402A1F82AAD1B14C4064CDC820773D47402A1F82AAD1B14C4064CDC820773D4740BD5296218EAD4C4091291F82AA354740BD5296218EAD4C40
130	Степановское	7	68	42	45.953910999999998	45.977052	57.274222000000002	57.265720000000002	0103000020E61000000100000005000000B72572C119FA464052F2EA1C03A24C40B72572C119FA4640FFEBDCB419A34C40E63E390A10FD4640FFEBDCB419A34C40E63E390A10FD464052F2EA1C03A24C40B72572C119FA464052F2EA1C03A24C40
7495	Старые Краи	7	68	42	46.739685999999999	46.761622000000003	57.398339	57.389685999999998	0103000020E610000001000000050000008FA7E507AE5E4740C2DA183BE1B14C408FA7E507AE5E474055DCB8C5FCB24C4002F566D47C61474055DCB8C5FCB24C4002F566D47C614740C2DA183BE1B14C408FA7E507AE5E4740C2DA183BE1B14C40
250	Полянское	7	68	42	45.951225000000001	45.975757999999999	57.227488000000001	57.215310000000002	0103000020E610000001000000050000009D11A5BDC1F946403A4030478F9B4C409D11A5BDC1F94640C11DA8531E9D4C40BA675DA3E5FC4640C11DA8531E9D4C40BA675DA3E5FC46403A4030478F9B4C409D11A5BDC1F946403A4030478F9B4C40
14876	Пахутино	7	68	42	46.179819999999999	46.201981000000004	57.286501999999999	57.27122	0103000020E6100000010000000500000057957D5704174740B4024356B7A24C4057957D57041747408A1EF818ACA44C40EAB46E83DA1947408A1EF818ACA44C40EAB46E83DA194740B4024356B7A24C4057957D5704174740B4024356B7A24C40
14952	Пакали	7	68	42	46.049878	46.088371000000002	57.276581999999998	57.264541999999999	0103000020E610000001000000050000001B65FD66620647408F352383DCA14C401B65FD6662064740C554FA0967A34C401975ADBD4F0B4740C554FA0967A34C401975ADBD4F0B47408F352383DCA14C401B65FD66620647408F352383DCA14C40
32345	Кодочиги	7	68	42	46.657876000000002	46.681133000000003	57.384830000000001	57.372520000000002	0103000020E610000001000000050000006269E047355447408F8D40BCAEAF4C406269E047355447408542041C42B14C40FA9CBB5D2F5747408542041C42B14C40FA9CBB5D2F5747408F8D40BCAEAF4C406269E047355447408F8D40BCAEAF4C40
32301	Вязовка	7	68	42	46.637044000000003	46.668394999999997	57.437477999999999	57.417552000000001	0103000020E61000000100000005000000780E65A88A51474090300C5872B54C40780E65A88A514740185C7347FFB74C40ABE7A4F78D554740185C7347FFB74C40ABE7A4F78D55474090300C5872B54C40780E65A88A51474090300C5872B54C40
9141	Вая	7	68	42	46.435121000000002	46.473163999999997	57.426121000000002	57.415351999999999	0103000020E61000000100000005000000C366800BB2374740022A1C412AB54C40C366800BB2374740C59107228BB64C4080D250A3903C4740C59107228BB64C4080D250A3903C4740022A1C412AB54C40C366800BB2374740022A1C412AB54C40
32391	Большое Содомово	7	68	42	46.229964000000002	46.266866	57.316575999999998	57.302264000000001	0103000020E61000000100000005000000F1A0D9756F1D47400B613596B0A64C40F1A0D9756F1D47406859F78F85A84C40093543AA282247406859F78F85A84C40093543AA282247400B613596B0A64C40F1A0D9756F1D47400B613596B0A64C40
32444	Большое Сидорово	7	68	42	46.163460999999998	46.185389000000001	57.332787000000003	57.323588999999998	0103000020E61000000100000005000000F295404AEC144740342C465D6BA94C40F295404AEC14474059C4B0C398AA4C40E204A6D3BA17474059C4B0C398AA4C40E204A6D3BA174740342C465D6BA94C40F295404AEC144740342C465D6BA94C40
32222	Большое Ларионово	7	68	42	46.300113000000003	46.331249	57.394506999999997	57.384587000000003	0103000020E610000001000000050000005F0D501A6A264740BFBB95253AB14C405F0D501A6A264740838593347FB24C4096EA025E662A4740838593347FB24C4096EA025E662A4740BFBB95253AB14C405F0D501A6A264740BFBB95253AB14C40
32250	Бердники	7	68	42	46.506644999999999	46.543925000000002	57.431708	57.412477000000003	0103000020E6100000010000000500000049D74CBED940474015ADDC0BCCB44C4049D74CBED9404740F6B52E3542B74C40083D9B559F454740F6B52E3542B74C40083D9B559F45474015ADDC0BCCB44C4049D74CBED940474015ADDC0BCCB44C40
32043	Турбанка	7	68	1101	45.739798	45.764015999999998	55.866312999999998	55.848866999999998	0103000020E61000000100000005000000B7D26BB3B1DE4640AAD381ACA7EC4B40B7D26BB3B1DE4640C18C2958E3EE4B4074CFBA46CBE14640C18C2958E3EE4B4074CFBA46CBE14640AAD381ACA7EC4B40B7D26BB3B1DE4640AAD381ACA7EC4B40
10350	Тукай	7	68	1101	45.61795	45.635818	55.747936000000003	55.731419000000002	0103000020E61000000100000005000000174850FC18CF4640265646239FDD4B40174850FC18CF464023C0E95DBCDF4B40A41AF67B62D1464023C0E95DBCDF4B40A41AF67B62D14640265646239FDD4B40174850FC18CF4640265646239FDD4B40
31457	Тубанаевка	7	68	1101	45.683204000000003	45.698600999999996	55.937184999999999	55.915266000000003	0103000020E610000001000000050000008A3F8A3A73D746400492B06F27F54B408A3F8A3A73D74640A0A696ADF5F74B40F8F9EFC16BD94640A0A696ADF5F74B40F8F9EFC16BD946400492B06F27F54B408A3F8A3A73D746400492B06F27F54B40
31961	Татарское Маклаково	7	68	1101	45.545492000000003	45.600369999999998	55.818361000000003	55.796819999999997	0103000020E61000000100000005000000651D8EAED2C546403C66A032FEE54B40651D8EAED2C5464033A9A10DC0E84B40F0BF95ECD8CC464033A9A10DC0E84B40F0BF95ECD8CC46403C66A032FEE54B40651D8EAED2C546403C66A032FEE54B40
21589	Спасское	7	68	1101	45.671697000000002	45.707529999999998	55.869444999999999	55.847174000000003	0103000020E6100000010000000500000021E9D32AFAD54640C102983270EC4B4021E9D32AFAD54640DA5548F949EF4B402D78D15790DA4640DA5548F949EF4B402D78D15790DA4640C102983270EC4B4021E9D32AFAD54640C102983270EC4B40
31711	Сосновка	7	68	1101	45.421210000000002	45.445222000000001	55.952872999999997	55.939222000000001	0103000020E61000000100000005000000C45F9335EAB5464084D72E6D38F84B40C45F9335EAB54640E61E12BEF7F94B40D8BAD408FDB84640E61E12BEF7F94B40D8BAD408FDB8464084D72E6D38F84B40C45F9335EAB5464084D72E6D38F84B40
31643	Русское Маклаково	7	68	1101	45.487110999999999	45.517716	55.791263000000001	55.776532000000003	0103000020E61000000100000005000000CC423BA759BE464014268C6665E34B40CC423BA759BE464076C4211B48E54B40D74E948444C2464076C4211B48E54B40D74E948444C2464014268C6665E34B40CC423BA759BE464014268C6665E34B40
31549	Новый Усад	7	68	1101	45.659947000000003	45.692627000000002	55.949939000000001	55.937220000000003	0103000020E61000000100000005000000F20BAF2479D446401D9430D3F6F74B40F20BAF2479D44640F418E59997F94B40CEA96400A8D84640F418E59997F94B40CEA96400A8D846401D9430D3F6F74B40F20BAF2479D446401D9430D3F6F74B40
31749	Масловка	7	68	1101	45.713341999999997	45.741441999999999	55.825361000000001	55.815337	0103000020E610000001000000050000007E6E68CA4EDB4640001C7BF65CE84B407E6E68CA4EDB46406A32E36DA5E94B40BFF04A92E7DE46406A32E36DA5E94B40BFF04A92E7DE4640001C7BF65CE84B407E6E68CA4EDB4640001C7BF65CE84B40
31395	Красный Ватрас	7	68	1101	45.729728000000001	45.760055000000001	55.943038000000001	55.919840999999998	0103000020E61000000100000005000000DD7C23BA67DD46408D429259BDF54B40DD7C23BA67DD464050711C78B5F84B40A514747B49E1464050711C78B5F84B40A514747B49E146408D429259BDF54B40DD7C23BA67DD46408D429259BDF54B40
9805	Кирилловка	7	68	1101	45.568165999999998	45.579053000000002	55.960245999999998	55.954853	0103000020E610000001000000050000007D59DAA9B9C8464066BE839F38FA4B407D59DAA9B9C84640B20E4757E9FA4B404AD3A0681ECA4640B20E4757E9FA4B404AD3A0681ECA464066BE839F38FA4B407D59DAA9B9C8464066BE839F38FA4B40
31118	Ишеево	7	68	1101	45.697101000000004	45.726125000000003	55.775646000000002	55.761290000000002	0103000020E610000001000000050000002481069B3AD94640CC6262F371E14B402481069B3AD94640F9A23D5E48E34B406DE7FBA9F1DC4640F9A23D5E48E34B406DE7FBA9F1DC4640CC6262F371E14B402481069B3AD94640CC6262F371E14B40
31587	Ивановское	7	68	1101	45.634830000000001	45.656891999999999	55.983035999999998	55.972256999999999	0103000020E610000001000000050000008542041C42D146404E27D9EA72FC4B408542041C42D146403465A71FD4FD4B4084807C0915D446403465A71FD4FD4B4084807C0915D446404E27D9EA72FC4B408542041C42D146404E27D9EA72FC4B40
31905	Елховка	7	68	1101	45.623753000000001	45.650550000000003	55.849589999999999	55.831271000000001	0103000020E6100000010000000500000015E46723D7CF46407E8E8F1667EA4B4015E46723D7CF46401B81785DBFEC4B40D734EF3845D346401B81785DBFEC4B40D734EF3845D346407E8E8F1667EA4B4015E46723D7CF46407E8E8F1667EA4B40
31178	Горки	7	68	1101	45.456190999999997	45.488098999999998	55.911763999999998	55.901172000000003	0103000020E6100000010000000500000061DD787764BA46401409A69A59F34B4061DD787764BA4640C7D5C8AEB4F44B40EB1A2D077ABE4640C7D5C8AEB4F44B40EB1A2D077ABE46401409A69A59F34B4061DD787764BA46401409A69A59F34B40
31350	Высокий Оселок	7	68	1101	45.556891999999998	45.579906999999999	55.929177000000003	55.913550000000001	0103000020E61000000100000005000000B7B3AF3C48C7464062A1D634EFF44B40B7B3AF3C48C7464003999D45EFF64B4059DC7F643ACA464003999D45EFF64B4059DC7F643ACA464062A1D634EFF44B40B7B3AF3C48C7464062A1D634EFF44B40
10321	Вазьянка	7	68	1101	45.442321	45.467967999999999	56.009396000000002	55.991318999999997	0103000020E61000000100000005000000C1AA7AF99DB84640A3737E8AE3FE4B40C1AA7AF99DB846404B5B5CE333014C408AC91B60E6BB46404B5B5CE333014C408AC91B60E6BB4640A3737E8AE3FE4B40C1AA7AF99DB84640A3737E8AE3FE4B40
31141	Бронский Ватрас	7	68	1101	45.447217000000002	45.481056000000002	55.864156000000001	55.844757999999999	0103000020E610000001000000050000008D9B1A683EB946406684B70721EC4B408D9B1A683EB946403352EFA99CEE4B40B5C5353E93BD46403352EFA99CEE4B40B5C5353E93BD46406684B70721EC4B408D9B1A683EB946406684B70721EC4B40
31068	Базлово	7	68	1101	45.668965999999998	45.691971000000002	55.764014000000003	55.746617999999998	0103000020E6100000010000000500000066118AADA0D546406E4DBA2D91DF4B4066118AADA0D54640D4D7F335CBE14B40E563778192D84640D4D7F335CBE14B40E563778192D846406E4DBA2D91DF4B4066118AADA0D546406E4DBA2D91DF4B40
32100	Антоново	7	68	1101	45.801170999999997	45.830230999999998	55.878191999999999	55.865595999999996	0103000020E6100000010000000500000076C075C58CE6464032C687D9CBEE4B4076C075C58CE64640EECD6F9868F04B400C90680245EA4640EECD6F9868F04B400C90680245EA464032C687D9CBEE4B4076C075C58CE6464032C687D9CBEE4B40
30970	Яковское	7	68	1050	43.375073	43.394863000000001	55.878934999999998	55.866883999999999	0103000020E610000001000000050000006A4E5E6402B045407CB60E0EF6EE4B406A4E5E6402B04540A6272CF180F04B4042B3EBDE8AB24540A6272CF180F04B4042B3EBDE8AB245407CB60E0EF6EE4B406A4E5E6402B045407CB60E0EF6EE4B40
49625	Сурудово	7	68	1050	43.233677999999998	43.250908000000003	55.814027000000003	55.805771	0103000020E61000000100000005000000B8E52329E99D454059880E8123E74B40B8E52329E99D4540CF87670932E84B400327DBC01DA04540CF87670932E84B400327DBC01DA0454059880E8123E74B40B8E52329E99D454059880E8123E74B40
30463	Стечкино	7	68	1050	43.080111000000002	43.096136999999999	55.797296000000003	55.787993999999998	0103000020E610000001000000050000006286C613418A4540DCB8C5FCDCE44B406286C613418A4540A69D9ACB0DE64B40C0779B374E8C4540A69D9ACB0DE64B40C0779B374E8C4540DCB8C5FCDCE44B406286C613418A4540DCB8C5FCDCE44B40
9266	Сосновское	7	68	1050	43.137189999999997	43.195400999999997	55.816374000000003	55.785260000000001	0103000020E610000001000000050000004BAB21718F914540B16D516683E44B404BAB21718F91454001A777F17EE84B40874D64E60299454001A777F17EE84B40874D64E602994540B16D516683E44B404BAB21718F914540B16D516683E44B40
29870	Созоново	7	68	1050	43.248159000000001	43.281081999999998	55.794649	55.777287000000001	0103000020E61000000100000005000000A29A92ACC39F4540904DF2237EE34B40A29A92ACC39F45404966F50EB7E54B4044BFB67EFAA345404966F50EB7E54B4044BFB67EFAA34540904DF2237EE34B40A29A92ACC39F4540904DF2237EE34B40
30376	Сиуха	7	68	1050	43.138689999999997	43.152686000000003	55.777003000000001	55.768562000000003	0103000020E6100000010000000500000020240B98C09145406479573D60E24B4020240B98C09145406BF294D574E34B404E4700378B9345406BF294D574E34B404E4700378B9345406479573D60E24B4020240B98C09145406479573D60E24B40
14359	Селитьба	7	68	1050	43.463638000000003	43.503145000000004	55.793211999999997	55.774340000000002	0103000020E6100000010000000500000068976F7D58BB454009FEB7921DE34B4068976F7D58BB4540BA6587F887E54B40AE122C0E67C04540BA6587F887E54B40AE122C0E67C0454009FEB7921DE34B4068976F7D58BB454009FEB7921DE34B40
30259	Рыльково	7	68	1050	43.098579999999998	43.116411999999997	55.739721000000003	55.729852999999999	0103000020E610000001000000050000001405FA449E8C454099F1B6D26BDD4B401405FA449E8C45400C957F2DAFDE4B40546EA296E68E45400C957F2DAFDE4B40546EA296E68E454099F1B6D26BDD4B401405FA449E8C454099F1B6D26BDD4B40
30756	Рожок	7	68	1050	43.187136000000002	43.215989999999998	55.664501999999999	55.646914000000002	0103000020E61000000100000005000000BFF38B12F49745408BA9F413CED24B40BFF38B12F49745403410CB660ED54B40AB21718FA59B45403410CB660ED54B40AB21718FA59B45408BA9F413CED24B40BFF38B12F49745408BA9F413CED24B40
30563	Рагозино	7	68	1050	42.937072000000001	42.949559000000001	55.739874	55.730553	0103000020E61000000100000005000000A8FFACF9F1774540527FBDC282DD4B40A8FFACF9F17745409294F430B4DE4B40AD4F39268B7945409294F430B4DE4B40AD4F39268B794540527FBDC282DD4B40A8FFACF9F1774540527FBDC282DD4B40
30478	Панино	7	68	1050	42.915368999999998	42.941113999999999	55.763199	55.742271000000002	0103000020E61000000100000005000000D862B7CF2A75454076E272BC02DF4B40D862B7CF2A75454082AB3C81B0E14B4064E76D6C7678454082AB3C81B0E14B4064E76D6C7678454076E272BC02DF4B40D862B7CF2A75454076E272BC02DF4B40
30673	Николаевка	7	68	1050	43.294575000000002	43.315522999999999	55.651257000000001	55.636707000000001	0103000020E610000001000000050000000F9C33A2B4A5454030116F9D7FD14B400F9C33A2B4A545404225AE635CD34B406211C30E63A845404225AE635CD34B406211C30E63A8454030116F9D7FD14B400F9C33A2B4A5454030116F9D7FD14B40
30354	Матюшево	7	68	1050	43.076912999999998	43.091222999999999	55.829861000000001	55.819569999999999	0103000020E6100000010000000500000091D10149D8894540306475ABE7E84B4091D10149D8894540E99C9FE238EA4B404ED2FC31AD8B4540E99C9FE238EA4B404ED2FC31AD8B4540306475ABE7E84B4091D10149D8894540306475ABE7E84B40
30177	Малахово	7	68	1050	42.998364000000002	43.026868	55.767068000000002	55.759450999999999	0103000020E610000001000000050000007BC03C64CA7F45400EF5BBB035E14B407BC03C64CA7F454071E7C2482FE24B408BA71E697083454071E7C2482FE24B408BA71E69708345400EF5BBB035E14B407BC03C64CA7F45400EF5BBB035E14B40
30805	Макасово	7	68	1050	43.189740999999998	43.203449999999997	55.803691000000001	55.790959999999998	0103000020E61000000100000005000000ECDADE6E49984540DA38622D3EE54B40ECDADE6E49984540768BC058DFE64B40832F4CA60A9A4540768BC058DFE64B40832F4CA60A9A4540DA38622D3EE54B40ECDADE6E49984540DA38622D3EE54B40
30571	Лесуново	7	68	1050	43.115189999999998	43.143414999999997	55.673869000000003	55.656269999999999	0103000020E61000000100000005000000C269C18BBE8E454047ACC5A700D44B40C269C18BBE8E4540E564E25641D64B40BF60376C5B924540E564E25641D64B40BF60376C5B92454047ACC5A700D44B40C269C18BBE8E454047ACC5A700D44B40
30249	Крутые	7	68	1050	43.114417000000003	43.133569999999999	55.779260999999998	55.766404999999999	0103000020E61000000100000005000000A08D5C37A58E4540D53E1D8F19E24B40A08D5C37A58E45402D060FD3BEE34B4005DD5ED2189145402D060FD3BEE34B4005DD5ED218914540D53E1D8F19E24B40A08D5C37A58E4540D53E1D8F19E24B40
30159	Клещариха	7	68	1050	43.049011	43.065289	55.758584999999997	55.747647000000001	0103000020E61000000100000005000000771211FE45864540ECF99AE5B2DF4B40771211FE458645403A1E335019E14B40EFE4D3635B8845403A1E335019E14B40EFE4D3635B884540ECF99AE5B2DF4B40771211FE45864540ECF99AE5B2DF4B40
30070	Елизарово	7	68	1050	43.024182000000003	43.049720999999998	55.820095999999999	55.798211999999999	0103000020E6100000010000000500000071935165188345402BA391CF2BE64B4071935165188345404BCADDE7F8E84B405376FA415D8645404BCADDE7F8E84B405376FA415D8645402BA391CF2BE64B4071935165188345402BA391CF2BE64B40
29687	Давыдково	7	68	1050	43.212217000000003	43.231808999999998	55.893909000000001	55.882413999999997	0103000020E61000000100000005000000DF5339ED299B45402AC423F1F2F04B40DF5339ED299B4540CF4C309C6BF24B4090F5D4EAAB9D4540CF4C309C6BF24B4090F5D4EAAB9D45402AC423F1F2F04B40DF5339ED299B45402AC423F1F2F04B40
29964	Глядково	7	68	1050	43.171802	43.183300000000003	55.846390999999997	55.837246999999998	0103000020E6100000010000000500000096B1A19BFD95454049D6E1E82AEB4B4096B1A19BFD9545407A50508A56EC4B40ACADD85F769745407A50508A56EC4B40ACADD85F7697454049D6E1E82AEB4B4096B1A19BFD95454049D6E1E82AEB4B40
29885	Волчиха	7	68	1050	43.204393000000003	43.224758000000001	55.768897000000003	55.755611000000002	0103000020E610000001000000050000000344C18C299A4540BABF7ADCB7E04B400344C18C299A45400B7F86376BE24B40D7C1C1DEC49C45400B7F86376BE24B40D7C1C1DEC49C4540BABF7ADCB7E04B400344C18C299A4540BABF7ADCB7E04B40
29798	Виткулово	7	68	1050	43.196064999999997	43.215909000000003	55.810718999999999	55.796365000000002	0103000020E61000000100000005000000F3716DA818994540EB56CF49EFE54B40F3716DA818994540779FE3A3C5E74B40BFF4F6E7A29B4540779FE3A3C5E74B40BFF4F6E7A29B4540EB56CF49EFE54B40F3716DA818994540EB56CF49EFE54B40
29692	Венец	7	68	1050	43.034880999999999	43.060923000000003	55.611103999999997	55.593522	0103000020E610000001000000050000003A2009FB768445406FBA6587F8CB4B403A2009FB76844540363AE7A738CE4B4080492A53CC874540363AE7A738CE4B4080492A53CC8745406FBA6587F8CB4B403A2009FB768445406FBA6587F8CB4B40
30080	Богданово	7	68	1050	42.966096999999998	42.979194	55.824010000000001	55.813606999999998	0103000020E61000000100000005000000C1E10511A97B4540F965304624E84B40C1E10511A97B4540DAC9E02879E94B403F389F3A567D4540DAC9E02879E94B403F389F3A567D4540F965304624E84B40C1E10511A97B4540F965304624E84B40
9199	Бараново	7	68	1050	43.309460000000001	43.334038	55.835194999999999	55.825133000000001	0103000020E61000000100000005000000C8B5A1629CA74540D9EC48F59DE94B40C8B5A1629CA74540306475ABE7EA4B4085CFD6C1C1AA4540306475ABE7EA4B4085CFD6C1C1AA4540D9EC48F59DE94B40C8B5A1629CA74540D9EC48F59DE94B40
28718	Фатеево	7	68	1117	43.613377999999997	43.6267	57.044021000000001	57.036965000000002	0103000020E61000000100000005000000FE0A992B83CE45405F0CE544BB844C40FE0A992B83CE45402AABE97AA2854C409C33A2B437D045402AABE97AA2854C409C33A2B437D045405F0CE544BB844C40FE0A992B83CE45405F0CE544BB844C40
27983	Сокольское	7	68	1117	43.179779000000003	43.193010999999998	57.142355000000002	57.13879	0103000020E61000000100000005000000F9C08EFF029745408481E7DEC3914C40F9C08EFF0297454007B64AB038924C4056629E95B498454007B64AB038924C4056629E95B49845408481E7DEC3914C40F9C08EFF029745408481E7DEC3914C40
21394	Сокольское	7	68	1117	43.146577000000001	43.181736999999998	57.165123999999999	57.120894999999997	0103000020E6100000010000000500000043ACFE08C3924540FD9FC37C798F4C4043ACFE08C392454071E481C822954C4090BC73284397454071E481C822954C4090BC732843974540FD9FC37C798F4C4043ACFE08C3924540FD9FC37C798F4C40
15740	Селянцево	7	68	1117	43.258408000000003	43.270454999999998	57.318131000000001	57.313650000000003	0103000020E610000001000000050000002C836A8313A14540F931E6AE25A84C402C836A8313A14540016C4084B8A84C401405FA449EA24540016C4084B8A84C401405FA449EA24540F931E6AE25A84C402C836A8313A14540F931E6AE25A84C40
15717	Пушкарево	7	68	1117	43.249918999999998	43.260879000000003	57.272840000000002	57.265521	0103000020E6100000010000000500000013D38558FD9F45405BB39597FCA14C4013D38558FD9F45403485CE6BECA24C404A9BAA7B64A145403485CE6BECA24C404A9BAA7B64A145405BB39597FCA14C4013D38558FD9F45405BB39597FCA14C40
28190	Пудово	7	68	1117	43.174596000000001	43.188124000000002	57.130817999999998	57.122419999999998	0103000020E6100000010000000500000097016729599645402B306475AB8F4C40970167295996454033DDEBA4BE904C40DECB7D721498454033DDEBA4BE904C40DECB7D72149845402B306475AB8F4C4097016729599645402B306475AB8F4C40
10240	Пелегово	7	68	1117	43.392850000000003	43.410798999999997	57.399590000000003	57.390428	0103000020E61000000100000005000000E71DA7E848B24540AAB8718BF9B14C40E71DA7E848B2454082E7DEC325B34C40601DC70F95B4454082E7DEC325B34C40601DC70F95B44540AAB8718BF9B14C40E71DA7E848B24540AAB8718BF9B14C40
28643	Никольское	7	68	1117	43.408580000000001	43.432555999999998	56.933062	56.926893	0103000020E610000001000000050000005CE674594CB4454017F2086EA4764C405CE674594CB44540F7915B936E774C4023D8B8FE5DB74540F7915B936E774C4023D8B8FE5DB7454017F2086EA4764C405CE674594CB4454017F2086EA4764C40
28319	Мурзино	7	68	1117	43.443415999999999	43.460906999999999	57.115476000000001	57.106853999999998	0103000020E61000000100000005000000F64201DBC1B8454030B95164AD8D4C40F64201DBC1B8454088BCE5EAC78E4C40ADBF2500FFBA454088BCE5EAC78E4C40ADBF2500FFBA454030B95164AD8D4C40F64201DBC1B8454030B95164AD8D4C40
23156	Молчаново	7	68	1117	43.269260000000003	43.283211000000001	57.035181999999999	57.027712000000001	0103000020E610000001000000050000007C0F971C77A2454077DA1A118C834C407C0F971C77A2454035B401D880844C40096F0F4240A4454035B401D880844C40096F0F4240A4454077DA1A118C834C407C0F971C77A2454077DA1A118C834C40
28441	Мамонтово	7	68	1117	43.608553999999998	43.625917999999999	57.279774000000003	57.266995000000001	0103000020E61000000100000005000000CCECF318E5CD4540079964E42CA24C40CCECF318E5CD4540B4226AA2CFA34C4026FDBD141ED04540B4226AA2CFA34C4026FDBD141ED04540079964E42CA24C40CCECF318E5CD4540079964E42CA24C40
10252	Летняя База	7	68	1117	43.463278000000003	43.487927999999997	57.457082	57.445053000000001	0103000020E61000000100000005000000687A89B14CBB45404CFE277FF7B84C40687A89B14CBB45408ECBB8A981BA4C40BE66B96C74BE45408ECBB8A981BA4C40BE66B96C74BE45404CFE277FF7B84C40687A89B14CBB45404CFE277FF7B84C40
28498	Лесной	7	68	1117	43.573466000000003	43.586858999999997	57.311205000000001	57.303839000000004	0103000020E6100000010000000500000019AF795567C94540EB1F4432E4A64C4019AF795567C9454004ADC090D5A74C407F2E1A321ECB454004ADC090D5A74C407F2E1A321ECB4540EB1F4432E4A64C4019AF795567C94540EB1F4432E4A64C40
10120	Куртюга	7	68	1117	43.315928	43.325566000000002	57.352268000000002	57.345275000000001	0103000020E6100000010000000500000002F2255470A845402E90A0F831AC4C4002F2255470A84540B3B6291E17AD4C4043588D25ACA94540B3B6291E17AD4C4043588D25ACA945402E90A0F831AC4C4002F2255470A845402E90A0F831AC4C40
28412	Кузнецово	7	68	1117	43.521695999999999	43.539285	57.295237	57.278177999999997	0103000020E610000001000000050000001D3A3DEFC6C24540BC3B32569BA34C401D3A3DEFC6C24540DAC87553CAA54C40971C774A07C54540DAC87553CAA54C40971C774A07C54540BC3B32569BA34C401D3A3DEFC6C24540BC3B32569BA34C40
28972	Кудрино	7	68	1117	43.206117999999996	43.225602000000002	57.200096000000002	57.190353000000002	0103000020E61000000100000005000000F78E1A13629A454006D9B27C5D984C40F78E1A13629A4540BC07E8BE9C994C40C3F4BD86E09C4540BC07E8BE9C994C40C3F4BD86E09C454006D9B27C5D984C40F78E1A13629A454006D9B27C5D984C40
28209	Коренево	7	68	1117	43.315595000000002	43.337155000000003	57.182744	57.176416000000003	0103000020E61000000100000005000000FCE3BD6A65A84540DE3EABCC94964C40FCE3BD6A65A8454026C5C72764974C40695721E527AB454026C5C72764974C40695721E527AB4540DE3EABCC94964C40FCE3BD6A65A84540DE3EABCC94964C40
29180	Ковригино	7	68	1117	43.349784999999997	43.365271999999997	57.262663000000003	57.255079000000002	0103000020E61000000100000005000000D0D03FC1C5AC4540BD72BD6DA6A04C40D0D03FC1C5AC4540446FF1F09EA14C407F129F3BC1AE4540446FF1F09EA14C407F129F3BC1AE4540BD72BD6DA6A04C40D0D03FC1C5AC4540BD72BD6DA6A04C40
15228	Запашка	7	68	1117	43.487560000000002	43.509101000000001	57.271223999999997	57.262059999999998	0103000020E610000001000000050000003C6BB75D68BE45407DCB9C2E8BA14C403C6BB75D68BE4540F5F1D077B7A24C4032AEB8382AC14540F5F1D077B7A24C4032AEB8382AC145407DCB9C2E8BA14C403C6BB75D68BE45407DCB9C2E8BA14C40
28792	Заболотное	7	68	1117	43.240855000000003	43.261462999999999	57.008023999999999	56.991022999999998	0103000020E61000000100000005000000FF092E56D49E4540BA4A77D7D97E4C40FF092E56D49E4540A3CA30EE06814C40990E9D9E77A14540A3CA30EE06814C40990E9D9E77A14540BA4A77D7D97E4C40FF092E56D49E4540BA4A77D7D97E4C40
28603	Дресвищи	7	68	1117	43.327049000000002	43.346443000000001	56.950890000000001	56.942081999999999	0103000020E610000001000000050000004298DBBDDCA945403C139A2496784C404298DBBDDCA94540F60B76C3B6794C40CD76853E58AC4540F60B76C3B6794C40CD76853E58AC45403C139A2496784C404298DBBDDCA945403C139A2496784C40
28262	Дорофеево	7	68	1117	43.277093000000001	43.314247999999999	57.142598999999997	57.130955	0103000020E61000000100000005000000AB798EC877A34540B41F2922C3904C40AB798EC877A345409DB81CAF40924C40AD6A494739A845409DB81CAF40924C40AD6A494739A84540B41F2922C3904C40AB798EC877A34540B41F2922C3904C40
28879	Георгиевское	7	68	1117	43.312280000000001	43.332070000000002	57.072777000000002	57.064526999999998	0103000020E61000000100000005000000F29881CAF8A74540C05AB56B42884C40F29881CAF8A745405473B9C150894C40CAFD0E4581AA45405473B9C150894C40CAFD0E4581AA4540C05AB56B42884C40F29881CAF8A74540C05AB56B42884C40
15467	Гари	7	68	1117	43.520591000000003	43.553567999999999	57.049039999999998	57.038214000000004	0103000020E61000000100000005000000C5CBD3B9A2C24540EB1F4432E4844C40C5CBD3B9A2C24540111956F146864C405A0EF450DBC64540111956F146864C405A0EF450DBC64540EB1F4432E4844C40C5CBD3B9A2C24540EB1F4432E4844C40
10154	Вилеж	7	68	1117	43.495275999999997	43.512551000000002	57.362284000000002	57.350971000000001	0103000020E61000000100000005000000313F373465BF4540166C239EECAC4C40313F373465BF45409AEE75525FAE4C401C446B459BC145409AEE75525FAE4C401C446B459BC14540166C239EECAC4C40313F373465BF4540166C239EECAC4C40
28900	Боталово	7	68	1117	43.264597999999999	43.290441999999999	57.103594000000001	57.094327999999997	0103000020E61000000100000005000000234BE658DEA145406D8C9DF0128C4C40234BE658DEA14540EA077591428D4C4042B115342DA54540EA077591428D4C4042B115342DA545406D8C9DF0128C4C40234BE658DEA145406D8C9DF0128C4C40
28535	Березово	7	68	1117	43.475225999999999	43.495429000000001	56.968229000000001	56.957633999999999	0103000020E61000000100000005000000BD1AA034D4BC4540D2C43BC0937A4C40BD1AA034D4BC4540F70489EDEE7B4C40B83EAC376ABF4540F70489EDEE7B4C40B83EAC376ABF4540D2C43BC0937A4C40BD1AA034D4BC4540D2C43BC0937A4C40
50071	Деревня Кузнечиха	7	68	5773	43.962435999999997	44.080222999999997	56.320442999999997	56.243634999999998	0103000020E610000001000000050000001C3F541A31FB45409A94826E2F1F4C401C3F541A31FB4540B69DB64604294C4089B14CBF440A4640B69DB64604294C4089B14CBF440A46409A94826E2F1F4C401C3F541A31FB45409A94826E2F1F4C40
50050	совхоз Теплостанский	7	68	1805	45.961815999999999	45.978399000000003	55.221507000000003	55.212159	0103000020E61000000100000005000000806264C91CFB4640AA46AF06289B4B40806264C91CFB4640E46A64575A9C4B4035B8AD2D3CFD4640E46A64575A9C4B4035B8AD2D3CFD4640AA46AF06289B4B40806264C91CFB4640AA46AF06289B4B40
50070	совхоз Талызинский	7	68	1805	45.867403000000003	45.881480000000003	55.132205999999996	55.124186999999999	0103000020E61000000100000005000000E5B9BE0F07EF46404FCB0F5CE58F4B40E5B9BE0F07EF4640E02A4F20EC904B40FF092E56D4F04640E02A4F20EC904B40FF092E56D4F046404FCB0F5CE58F4B40E5B9BE0F07EF46404FCB0F5CE58F4B40
27707	Ясное	7	68	1805	45.906982999999997	45.940499000000003	55.263669999999998	55.245517	0103000020E610000001000000050000009483D90418F4464057CEDE196D9F4B409483D90418F44640D97745F0BFA14B40DA756F4562F84640D97745F0BFA14B40DA756F4562F8464057CEDE196D9F4B409483D90418F4464057CEDE196D9F4B40
27886	Шемарино	7	68	1805	45.896661999999999	45.937876000000003	55.050142999999998	55.035497999999997	0103000020E6100000010000000500000071C806D2C5F246406589CE328B844B4071C806D2C5F24640C98FF8156B864B4006DA1D520CF84640C98FF8156B864B4006DA1D520CF846406589CE328B844B4071C806D2C5F246406589CE328B844B40
27795	Торговое Талызино	7	68	1805	45.800156000000001	45.808878	55.064070999999998	55.053856000000003	0103000020E610000001000000050000005ED905836BE64640C158DFC0E4864B405ED905836BE646409ECF807A33884B40193A765089E746409ECF807A33884B40193A765089E74640C158DFC0E4864B405ED905836BE64640C158DFC0E4864B40
27804	Скрипино	7	68	1805	45.904890000000002	45.924554000000001	55.029651999999999	55.017803000000001	0103000020E610000001000000050000001D3D7E6FD3F34640A662635E47824B401D3D7E6FD3F34640682101A3CB834B4068B114C957F64640682101A3CB834B4068B114C957F64640A662635E47824B401D3D7E6FD3F34640A662635E47824B40
27546	Сеченово	7	68	1805	45.870457999999999	45.911735	55.240938999999997	55.213900000000002	0103000020E610000001000000050000005245F12A6BEF4640A54E4013619B4B405245F12A6BEF46405CAAD216D79E4B402DCF83BBB3F446405CAAD216D79E4B402DCF83BBB3F44640A54E4013619B4B405245F12A6BEF4640A54E4013619B4B40
27073	Рогожка	7	68	1805	46.023944	46.054783	55.227268000000002	55.214368	0103000020E61000000100000005000000BC77D498100347408BA71E69709B4B40BC77D49810034740B3B6291E179D4B403AB01C2103074740B3B6291E179D4B403AB01C21030747408BA71E69709B4B40BC77D498100347408BA71E69709B4B40
27452	Ратово	7	68	1805	46.144390000000001	46.197803999999998	55.344417999999997	55.318787999999998	0103000020E610000001000000050000004AEF1B5F7B124740BA2D910BCEA84B404AEF1B5F7B124740AD1397E315AC4B404D8237A451194740AD1397E315AC4B404D8237A451194740BA2D910BCEA84B404AEF1B5F7B124740BA2D910BCEA84B40
27140	Николаевка	7	68	1805	45.982433	46.007486999999998	55.184392000000003	55.175961000000001	0103000020E610000001000000050000006EC1525DC0FD46408C2FDAE385964B406EC1525DC0FD464070D234289A974B4094128255F500474070D234289A974B4094128255F50047408C2FDAE385964B406EC1525DC0FD46408C2FDAE385964B40
27396	Мурзицы	7	68	1805	46.194794000000002	46.222903000000002	55.303750000000001	55.284675999999997	0103000020E6100000010000000500000080BA8102EF18474061FA5E4370A44B4080BA8102EF1847407B14AE47E1A64B401497E315881C47407B14AE47E1A64B401497E315881C474061FA5E4370A44B4080BA8102EF18474061FA5E4370A44B40
27366	Митрополье	7	68	1805	45.940634000000003	45.979010000000002	55.107587000000002	55.080967000000001	0103000020E61000000100000005000000BAC0E5B166F8464012876C205D8A4B40BAC0E5B166F84640C53C2B69C58D4B407E3A1E3350FD4640C53C2B69C58D4B407E3A1E3350FD464012876C205D8A4B40BAC0E5B166F8464012876C205D8A4B40
27495	Мамлейка	7	68	1805	45.910981	45.938845999999998	55.199547000000003	55.182684999999999	0103000020E61000000100000005000000812381069BF44640213CDA3862974B40812381069BF44640E9818FC18A994B407EFD101B2CF84640E9818FC18A994B407EFD101B2CF84640213CDA3862974B40812381069BF44640213CDA3862974B40
27303	Липовка	7	68	1805	46.000757999999998	46.032252999999997	55.052349999999997	55.034022999999998	0103000020E61000000100000005000000ED9A90D618004740E9279CDD5A844B40ED9A90D61800474009F9A067B3864B405419C6DD2004474009F9A067B3864B405419C6DD20044740E9279CDD5A844B40ED9A90D618004740E9279CDD5A844B40
27275	Левашовка	7	68	1805	45.627516999999997	45.956471000000001	55.372824999999999	55.224961999999998	0103000020E610000001000000050000008E57207A52D04640DF6B088ECB9C4B408E57207A52D04640CB10C7BAB8AF4B40454948A46DFA4640CB10C7BAB8AF4B40454948A46DFA4640DF6B088ECB9C4B408E57207A52D04640DF6B088ECB9C4B40
50073	Красный Остров	7	68	1805	46.009185000000002	46.059525999999998	55.337080999999998	55.313045000000002	0103000020E61000000100000005000000904E5DF92C0147409296CADB11A84B40904E5DF92C0147402E8D5F7825AB4B407FA1478C9E0747402E8D5F7825AB4B407FA1478C9E0747409296CADB11A84B40904E5DF92C0147409296CADB11A84B40
27171	Красное	7	68	1805	45.961753999999999	45.992215000000002	55.296723	55.283549000000001	0103000020E610000001000000050000000A664CC11AFB464021E868554BA44B400A664CC11AFB46404A7CEE04FBA54B40E2CCAFE600FF46404A7CEE04FBA54B40E2CCAFE600FF464021E868554BA44B400A664CC11AFB464021E868554BA44B40
27048	Кочетовка	7	68	1805	46.088425000000001	46.147741000000003	55.253203999999997	55.234112000000003	0103000020E610000001000000050000000C93A982510B4740F3CCCB61F79D4B400C93A982510B4740B29B19FD68A04B40A1A3552DE9124740B29B19FD68A04B40A1A3552DE9124740F3CCCB61F79D4B400C93A982510B4740F3CCCB61F79D4B40
26766	Ильинка	7	68	1805	45.793166999999997	45.815219999999997	55.262931999999999	55.246943999999999	0103000020E610000001000000050000001AA20A7F86E54640C2F869DC9B9F4B401AA20A7F86E5464033897AC1A7A14B40C685032159E8464033897AC1A7A14B40C685032159E84640C2F869DC9B9F4B401AA20A7F86E54640C2F869DC9B9F4B40
26959	Верхнее Талызино	7	68	1805	45.811385000000001	45.862102999999998	55.117370000000001	55.081812999999997	0103000020E6100000010000000500000084BBB376DBE746409EB12FD9788A4B4084BBB376DBE7464009C4EBFA058F4B4049641F6459EE464009C4EBFA058F4B4049641F6459EE46409EB12FD9788A4B4084BBB376DBE746409EB12FD9788A4B40
26855	Васильевка	7	68	1805	45.680895	45.703892000000003	55.260618000000001	55.242626999999999	0103000020E6100000010000000500000045813E9127D746403410CB660E9F4B4045813E9127D74640DD5F3DEE5BA14B4041F50F2219DA4640DD5F3DEE5BA14B4041F50F2219DA46403410CB660E9F4B4045813E9127D746403410CB660E9F4B40
27741	Булдаково	7	68	1805	45.741019999999999	45.762380999999998	55.035054000000002	55.016022	0103000020E6100000010000000500000049D74CBED9DE46401D0247020D824B4049D74CBED9DE464008CC43A67C844B40BF0B5BB395E1464008CC43A67C844B40BF0B5BB395E146401D0247020D824B4049D74CBED9DE46401D0247020D824B40
26817	Болховское	7	68	1805	45.645420999999999	45.661797	55.208773999999998	55.191346000000003	0103000020E610000001000000050000006893C3279DD24640371C96067E984B406893C3279DD24640A7203F1BB99A4B40A3CB9BC3B5D44640A7203F1BB99A4B40A3CB9BC3B5D44640371C96067E984B406893C3279DD24640371C96067E984B40
26748	Болтинка	7	68	1805	45.817780999999997	45.842547000000003	55.336134000000001	55.318542000000001	0103000020E6100000010000000500000024253D0CADE846408333F8FBC5A84B4024253D0CADE846406E895C7006AB4B40E52B8194D8EB46406E895C7006AB4B40E52B8194D8EB46408333F8FBC5A84B4024253D0CADE846408333F8FBC5A84B40
26905	Богатиловка	7	68	1805	45.912903	45.945304999999998	55.152448999999997	55.131666000000003	0103000020E61000000100000005000000CCB56801DAF4464061FF756EDA904B40CCB56801DAF4464069A7E67283934B4065DF15C1FFF8464069A7E67283934B4065DF15C1FFF8464061FF756EDA904B40CCB56801DAF4464061FF756EDA904B40
26707	Бахметьевка	7	68	1805	45.818795999999999	45.837355000000002	55.276344000000002	55.263782999999997	0103000020E610000001000000050000003D0CAD4ECEE84640D11E2FA4C3A14B403D0CAD4ECEE8464011397D3D5FA34B403012DA722EEB464011397D3D5FA34B403012DA722EEB4640D11E2FA4C3A14B403D0CAD4ECEE84640D11E2FA4C3A14B40
26602	Алферьево	7	68	1805	45.791001999999999	45.839035000000003	55.188004999999997	55.16901	0103000020E610000001000000050000000989B48D3FE546403659A31EA2954B400989B48D3FE54640033E3F8C10984B408599B67F65EB4640033E3F8C10984B408599B67F65EB46403659A31EA2954B400989B48D3FE546403659A31EA2954B40
26613	Александровка	7	68	1805	45.809883999999997	45.831004	55.352521000000003	55.334941000000001	0103000020E61000000100000005000000DEC66647AAE74640768BC058DFAA4B40DEC66647AAE746409D137B681FAD4B402F6CCD565EEA46409D137B681FAD4B402F6CCD565EEA4640768BC058DFAA4B40DEC66647AAE74640768BC058DFAA4B40
26307	Яново	7	68	1201	45.292859	45.324649999999998	55.481760000000001	55.463180999999999	0103000020E610000001000000050000006DAB59677CA546407590D78349BB4B406DAB59677CA54640AF42CA4FAABD4B40BD5296218EA94640AF42CA4FAABD4B40BD5296218EA946407590D78349BB4B406DAB59677CA546407590D78349BB4B40
26236	Шубино	7	68	1201	45.378010000000003	45.410466	55.481143000000003	55.473739999999999	0103000020E61000000100000005000000CEC7B5A162B046404D672783A3BC4B40CEC7B5A162B0464084D9041896BD4B405A0F5F268AB4464084D9041896BD4B405A0F5F268AB446404D672783A3BC4B40CEC7B5A162B046404D672783A3BC4B40
25375	Толба	7	68	1201	45.272216	45.308363999999997	55.635330000000003	55.609807000000004	0103000020E6100000010000000500000056B950F9D7A246409AEFE0270ECE4B4056B950F9D7A246407715527E52D14B40C2A1B77878A746407715527E52D14B40C2A1B77878A746409AEFE0270ECE4B4056B950F9D7A246409AEFE0270ECE4B40
26037	Старая Березовка	7	68	1201	45.714295	45.743471999999997	55.499310999999999	55.484040999999998	0103000020E610000001000000050000002159C0046EDB46402976340EF5BD4B402159C0046EDB46403BC43F6CE9BF4B40F0BE2A172ADF46403BC43F6CE9BF4B40F0BE2A172ADF46402976340EF5BD4B402159C0046EDB46402976340EF5BD4B40
25690	Сосновка	7	68	1201	45.539589999999997	45.566324000000002	55.716538999999997	55.698041000000003	0103000020E61000000100000005000000D39FFD4811C546403222516859D94B40D39FFD4811C546407EA7C98CB7DB4B404F78094E7DC846407EA7C98CB7DB4B404F78094E7DC846403222516859D94B40D39FFD4811C546403222516859D94B40
11618	Сергач	7	68	1201	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
25493	Пожарки	7	68	1201	45.497199000000002	45.526637000000001	55.505873000000001	55.492762999999997	0103000020E610000001000000050000004D4D8237A4BF4640E4D6A4DB12BF4B404D4D8237A4BF4640F7764B72C0C04B4089EE59D768C34640F7764B72C0C04B4089EE59D768C34640E4D6A4DB12BF4B404D4D8237A4BF4640E4D6A4DB12BF4B40
15135	Пица	7	68	1201	45.273643999999997	45.319412999999997	55.385269999999998	55.373387999999998	0103000020E61000000100000005000000915F3FC406A34640035C902DCBAF4B40915F3FC406A34640A110018750B14B4068757286E2A84640A110018750B14B4068757286E2A84640035C902DCBAF4B40915F3FC406A34640035C902DCBAF4B40
25768	Мокрый Майдан	7	68	1201	45.375486000000002	45.398302999999999	55.584187	55.570003	0103000020E610000001000000050000008D0DDDEC0FB046409ACFB9DBF5C84B408D0DDDEC0FB04640CADFBDA3C6CA4B400873BB97FBB24640CADFBDA3C6CA4B400873BB97FBB246409ACFB9DBF5C84B408D0DDDEC0FB046409ACFB9DBF5C84B40
26549	Луговое	7	68	1201	45.181880999999997	45.207923000000001	55.562911999999997	55.553075	0103000020E61000000100000005000000C36169E0479746401B9E5E29CBC64B40C36169E04797464052431B800DC84B40098B8A389D9A464052431B800DC84B40098B8A389D9A46401B9E5E29CBC64B40C36169E0479746401B9E5E29CBC64B40
25525	Лопатино	7	68	1201	45.210942000000003	45.240046999999997	55.414082000000001	55.399898	0103000020E610000001000000050000002AADBF25009B46402FDE8FDB2FB34B402AADBF25009B46405FEE93A300B54B405F402FDCB99E46405FEE93A300B54B405F402FDCB99E46402FDE8FDB2FB34B402AADBF25009B46402FDE8FDB2FB34B40
50072	Кошкарево	7	68	1201	45.176338999999999	45.202191999999997	55.400885000000002	55.389003000000002	0103000020E610000001000000050000003201BF4692964640E085ADD9CAB14B403201BF46929646407E3A1E3350B34B40A4C16D6DE19946407E3A1E3350B34B40A4C16D6DE1994640E085ADD9CAB14B403201BF4692964640E085ADD9CAB14B40
26224	Кочко-Пожарки	7	68	1201	45.459218	45.496246999999997	55.498683	55.479806000000004	0103000020E6100000010000000500000005DEC9A7C7BA4640593673486ABD4B4005DEC9A7C7BA46401C0934D8D4BF4B407ADE8D0585BF46401C0934D8D4BF4B407ADE8D0585BF4640593673486ABD4B4005DEC9A7C7BA4640593673486ABD4B40
25435	Камкино	7	68	1201	45.180120000000002	45.222718999999998	55.543872999999998	55.524003	0103000020E6100000010000000500000082AD122C0E974640C100C28712C34B4082AD122C0E974640B51666A19DC54B405299620E829C4640B51666A19DC54B405299620E829C4640C100C28712C34B4082AD122C0E974640C100C28712C34B40
26112	Каменка	7	68	1201	45.761726000000003	45.788728999999996	55.487025000000003	55.479812000000003	0103000020E61000000100000005000000A741D13C80E146403B1DC87A6ABD4B40A741D13C80E14640CEAACFD556BE4B4011346612F5E44640CEAACFD556BE4B4011346612F5E446403B1DC87A6ABD4B40A741D13C80E146403B1DC87A6ABD4B40
26486	Грибаново	7	68	1201	45.201023999999997	45.232968	55.473730000000003	55.462890000000002	0103000020E6100000010000000500000005DB8827BB9946409ED2C1FA3FBB4B4005DB8827BB9946402A91442FA3BC4B40DC813AE5D19D46402A91442FA3BC4B40DC813AE5D19D46409ED2C1FA3FBB4B4005DB8827BB9946409ED2C1FA3FBB4B40
26165	Вязовка	7	68	1201	45.654350000000001	45.684075	55.461691000000002	55.452365	0103000020E610000001000000050000009D11A5BDC1D34640726DA818E7B94B409D11A5BDC1D34640C4EDD0B018BB4B406F8104C58FD74640C4EDD0B018BB4B406F8104C58FD74640726DA818E7B94B409D11A5BDC1D34640726DA818E7B94B40
25623	Воскресенское	7	68	1201	45.710917000000002	45.744954	55.683990000000001	55.667085999999998	0103000020E61000000100000005000000D1950854FFDA46404ACFF41263D54B40D1950854FFDA46404165FCFB8CD74B401F8315A75ADF46404165FCFB8CD74B401F8315A75ADF46404ACFF41263D54B40D1950854FFDA46404ACFF41263D54B40
25838	Вершинино	7	68	1201	45.496974000000002	45.525621000000001	55.734329000000002	55.722116999999997	0103000020E610000001000000050000002D7B12D89CBF46405C7171546EDC4B402D7B12D89CBF464090C01F7EFEDD4B40A08B868C47C3464090C01F7EFEDD4B40A08B868C47C346405C7171546EDC4B402D7B12D89CBF46405C7171546EDC4B40
25885	Борисовка	7	68	1201	45.615803	45.634945999999999	55.765179000000003	55.749380000000002	0103000020E61000000100000005000000ACE3F8A1D2CE4640642310AFEBDF4B40ACE3F8A1D2CE4640024BAE62F1E14B40EE5C18E945D14640024BAE62F1E14B40EE5C18E945D14640642310AFEBDF4B40ACE3F8A1D2CE4640642310AFEBDF4B40
25721	Богородское	7	68	1201	45.513736999999999	45.548951000000002	55.603938999999997	55.588669000000003	0103000020E6100000010000000500000061DF4E22C2C14640A3957B8159CB4B4061DF4E22C2C14640B4E386DF4DCD4B40A20DC00644C64640B4E386DF4DCD4B40A20DC00644C64640A3957B8159CB4B4061DF4E22C2C14640A3957B8159CB4B40
26023	Ачка	7	68	1201	45.562848000000002	45.600577000000001	55.570323999999999	55.556094999999999	0103000020E610000001000000050000003C4F3C670BC846400C3CF71E2EC74B403C4F3C670BC84640DC0F786000C94B406ADD06B5DFCC4640DC0F786000C94B406ADD06B5DFCC46400C3CF71E2EC74B403C4F3C670BC846400C3CF71E2EC74B40
25888	Андреевка	7	68	1201	45.572927	45.602553	55.699106	55.67127	0103000020E6100000010000000500000069FF03AC55C946409964E42CECD54B4069FF03AC55C94640FC372F4E7CD94B40A88DEA7420CD4640FC372F4E7CD94B40A88DEA7420CD46409964E42CECD54B4069FF03AC55C946409964E42CECD54B40
25963	Анда	7	68	1201	45.573079	45.616225999999997	55.612355000000001	55.595815999999999	0103000020E610000001000000050000001F8315A75AC946407E37DDB243CC4B401F8315A75AC9464063450DA661CE4B40F2785A7EE0CE464063450DA661CE4B40F2785A7EE0CE46407E37DDB243CC4B401F8315A75AC946407E37DDB243CC4B40
25591	Акузово	7	68	1201	45.605347000000002	45.648699999999998	55.472735	55.462491999999997	0103000020E61000000100000005000000A9DDAF027CCD4640B05417F032BB4B40A9DDAF027CCD464058569A9482BC4B402575029A08D3464058569A9482BC4B402575029A08D34640B05417F032BB4B40A9DDAF027CCD4640B05417F032BB4B40
26376	Абаимово	7	68	1201	45.264705999999997	45.291440000000001	55.363886999999998	55.345007000000003	0103000020E610000001000000050000000987DEE2E1A146400FF27A3029AC4B400987DEE2E1A14640433866D993AE4B40855FEAE74DA54640433866D993AE4B40855FEAE74DA546400FF27A3029AC4B400987DEE2E1A146400FF27A3029AC4B40
49810	Шалдежка	7	68	1084	44.827855	44.868459000000001	56.862352000000001	56.853538	0103000020E61000000100000005000000406A1327F769464056F2B1BB406D4C40406A1327F7694640F2D1E28C616E4C405C751DAA296F4640F2D1E28C616E4C405C751DAA296F464056F2B1BB406D4C40406A1327F769464056F2B1BB406D4C40
49816	Шалдеж	7	68	1084	44.725743999999999	44.778609000000003	56.851647999999997	56.838552999999997	0103000020E6100000010000000500000055A2EC2DE55C4640397B67B4556B4C4055A2EC2DE55C464016DA39CD026D4C4086AFAF75A963464016DA39CD026D4C4086AFAF75A9634640397B67B4556B4C4055A2EC2DE55C4640397B67B4556B4C40
49721	Хахалы	7	68	1084	44.660139999999998	44.691696999999998	56.662762999999998	56.645108999999998	0103000020E610000001000000050000000664AF777F54464079AD84EE92524C400664AF777F544640DAFF006BD5544C40E3DEFC8689584640DAFF006BD5544C40E3DEFC868958464079AD84EE92524C400664AF777F54464079AD84EE92524C40
49781	Фундриково	7	68	1084	44.262599000000002	44.275733000000002	56.983299000000002	56.973630999999997	0103000020E610000001000000050000002D7B12D89C21464096AFCBF09F7C4C402D7B12D89C2146404298DBBDDC7D4C40C8B60C384B2346404298DBBDDC7D4C40C8B60C384B23464096AFCBF09F7C4C402D7B12D89C21464096AFCBF09F7C4C40
49634	Успенье	7	68	1084	44.202852	44.214889999999997	56.670513999999997	56.658538	0103000020E61000000100000005000000CFF6E80DF71946402D9622F94A544C40CFF6E80DF71946404CC11A67D3554C40641EF983811B46404CC11A67D3554C40641EF983811B46402D9622F94A544C40CFF6E80DF71946402D9622F94A544C40
49737	Успенское	7	68	1084	44.492351999999997	44.511459000000002	57.191099000000001	57.183373000000003	0103000020E61000000100000005000000620FED63053F464016FC36C478974C40620FED63053F46402FA699EE75984C40581F0F7D774146402FA699EE75984C40581F0F7D7741464016FC36C478974C40620FED63053F464016FC36C478974C40
10423	Семенов	7	68	1084	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
49788	Светлое	7	68	1084	44.483648000000002	44.499952	56.680078000000002	56.669307000000003	0103000020E610000001000000050000004E637B2DE83D4640F0FD0DDAAB554C404E637B2DE83D4640535DC0CB0C574C40EFC8586DFE3F4640535DC0CB0C574C40EFC8586DFE3F4640F0FD0DDAAB554C404E637B2DE83D4640F0FD0DDAAB554C40
49772	Полом	7	68	1084	44.355736	44.376415999999999	56.964033000000001	56.948577999999998	0103000020E610000001000000050000004301DBC1882D464040DAFF006B794C404301DBC1882D4640E4A1EF6E657B4C4077D844662E304640E4A1EF6E657B4C4077D844662E30464040DAFF006B794C404301DBC1882D464040DAFF006B794C40
49758	Пафнутово	7	68	1084	44.273055999999997	44.293016000000001	56.781444	56.771214999999998	0103000020E6100000010000000500000000FDBE7FF3224640A297512CB7624C4000FDBE7FF3224640E5D3635B06644C40359A5C8C81254640E5D3635B06644C40359A5C8C81254640A297512CB7624C4000FDBE7FF3224640A297512CB7624C40
49645	Осинки	7	68	1084	44.290995000000002	44.361170999999999	56.741360999999998	56.726607999999999	0103000020E610000001000000050000005726FC523F2546408881AE7D015D4C405726FC523F254640D2C3D0EAE45E4C40BEA1F0D93A2E4640D2C3D0EAE45E4C40BEA1F0D93A2E46408881AE7D015D4C405726FC523F2546408881AE7D015D4C40
49636	Огибное	7	68	1084	44.563625000000002	44.593637000000001	57.086592000000003	57.068261	0103000020E61000000100000005000000A01A2FDD24484640CF4BC5C6BC884C40A01A2FDD24484640310C5872158B4C400859164CFC4B4640310C5872158B4C400859164CFC4B4640CF4BC5C6BC884C40A01A2FDD24484640CF4BC5C6BC884C40
23787	Никитино	7	68	1084	44.621915999999999	44.641688000000002	57.057675000000003	57.04833	0103000020E61000000100000005000000F86D88F19A4F464035B56CAD2F864C40F86D88F19A4F4640FE65F7E461874C402A1E17D522524640FE65F7E461874C402A1E17D52252464035B56CAD2F864C40F86D88F19A4F464035B56CAD2F864C40
49712	Медведево	7	68	1084	44.460093999999998	44.492441999999997	56.752521000000002	56.737712999999999	0103000020E61000000100000005000000FC8A355CE43A4640C26A2C616D5E4C40FC8A355CE43A4640D046AE9B52604C40A296E656083F4640D046AE9B52604C40A296E656083F4640C26A2C616D5E4C40FC8A355CE43A4640C26A2C616D5E4C40
49782	Кулагино	7	68	1084	44.252330999999998	44.276487000000003	56.758614999999999	56.744945000000001	0103000020E610000001000000050000002C62D8614C204640CC28965B5A5F4C402C62D8614C204640A5A0DB4B1A614C4074620FED63234640A5A0DB4B1A614C4074620FED63234640CC28965B5A5F4C402C62D8614C204640CC28965B5A5F4C40
49784	Кондратьево	7	68	1084	44.531447	44.557353999999997	56.877021999999997	56.867714999999997	0103000020E6100000010000000500000056478E7406444640D39FFD48116F4C4056478E7406444640AEEFC34142704C40BB25396057474640AEEFC34142704C40BB25396057474640D39FFD48116F4C4056478E7406444640D39FFD48116F4C40
49711	Керженец	7	68	1084	44.617837999999999	44.638885000000002	56.913809999999998	56.899988999999998	0103000020E61000000100000005000000EF1CCA50154F46403FE1ECD632734C40EF1CCA50154F4640FE60E0B9F7744C40D673D2FBC6514640FE60E0B9F7744C40D673D2FBC65146403FE1ECD632734C40EF1CCA50154F46403FE1ECD632734C40
49654	Ильино-Заборское	7	68	1084	44.366489000000001	44.417189999999998	57.254612000000002	57.237552999999998	0103000020E6100000010000000500000000AC8E1CE92E46408908FF22689E4C4000AC8E1CE92E4640A795422097A04C40EF1B5F7B66354640A795422097A04C40EF1B5F7B663546408908FF22689E4C4000AC8E1CE92E46408908FF22689E4C40
49786	Зубово	7	68	1084	44.105637000000002	44.134194000000001	56.859437999999997	56.848291000000003	0103000020E61000000100000005000000B01F6283850D4640DE3EABCC946C4C40B01F6283850D464046787B10026E4C40E3A8DC442D11464046787B10026E4C40E3A8DC442D114640DE3EABCC946C4C40B01F6283850D4640DE3EABCC946C4C40
49719	Зименки	7	68	1084	44.593197000000004	44.621144000000001	56.838504	56.825794000000002	0103000020E61000000100000005000000EC8A19E1ED4B4640D49D279EB3694C40EC8A19E1ED4B464058C85C19546B4C40A60D87A5814F464058C85C19546B4C40A60D87A5814F4640D49D279EB3694C40EC8A19E1ED4B4640D49D279EB3694C40
49644	Елфимово	7	68	1084	44.232793000000001	44.248550000000002	56.879308999999999	56.868648999999998	0103000020E610000001000000050000006EDE3829CC1D4640FF59F3E32F6F4C406EDE3829CC1D46400B0A83328D704C40DDB5847CD01F46400B0A83328D704C40DDB5847CD01F4640FF59F3E32F6F4C406EDE3829CC1D4640FF59F3E32F6F4C40
49819	Дъяково	7	68	1084	44.508468000000001	44.529739999999997	56.788533999999999	56.778480000000002	0103000020E610000001000000050000000188BB7A15414640884B8E3BA5634C400188BB7A154146405CE49EAEEE644C4007B13385CE4346405CE49EAEEE644C4007B13385CE434640884B8E3BA5634C400188BB7A15414640884B8E3BA5634C40
49655	Боковая	7	68	1084	44.999523000000003	45.027496999999997	56.903542999999999	56.886114999999997	0103000020E61000000100000005000000C74CA25EF07F46405DBF60376C714C40C74CA25EF07F4640CEC3094CA7734C407ADE8D0585834640CEC3094CA7734C407ADE8D05858346405DBF60376C714C40C74CA25EF07F46405DBF60376C714C40
49755	Богоявление	7	68	1084	44.609951000000002	44.639389000000001	56.972192999999997	56.962128999999997	0103000020E61000000100000005000000CD94D6DF124E46403FC4060B277B4C40CD94D6DF124E46403733FAD1707C4C400936AE7FD75146403733FAD1707C4C400936AE7FD75146403FC4060B277B4C40CD94D6DF124E46403FC4060B277B4C40
49735	Беласовка	7	68	1084	44.575958	44.641112999999997	56.924942000000001	56.910429000000001	0103000020E610000001000000050000004EEFE2FDB84946403D2AFEEF88744C404EEFE2FDB84946403259DC7F64764C402D05A4FD0F5246403259DC7F64764C402D05A4FD0F5246403D2AFEEF88744C404EEFE2FDB84946403D2AFEEF88744C40
20994	Шишадеево	7	68	1211	44.744670999999997	44.772545999999998	54.666576999999997	54.658296999999997	0103000020E61000000100000005000000CAA31B61515F464007077B1343544B40CAA31B61515F464005A2276552554B40EB538EC9E262464005A2276552554B40EB538EC9E262464007077B1343544B40CAA31B61515F464007077B1343544B40
21670	Шагаево	7	68	1211	44.653618000000002	44.696297000000001	54.533524	54.513604999999998	0103000020E61000000100000005000000D9092FC1A9534640F20703CFBD414B40D9092FC1A9534640C8D0B1834A444B40C6A6954220594640C8D0B1834A444B40C6A6954220594640F20703CFBD414B40D9092FC1A9534640F20703CFBD414B40
21593	Учуево-Майдан	7	68	1211	44.474654999999998	44.511450000000004	54.566876999999998	54.547302999999999	0103000020E6100000010000000500000002F1BA7EC13C4640580053060E464B4002F1BA7EC13C464063EDEF6C8F484B4005C58F317741464063EDEF6C8F484B4005C58F3177414640580053060E464B4002F1BA7EC13C4640580053060E464B40
21554	Ужово	7	68	1211	44.885553999999999	44.924379000000002	54.889474999999997	54.865622000000002	0103000020E61000000100000005000000C66B5ED5597146405C59A2B3CC6E4B40C66B5ED55971464007CE1951DA714B40FA0D130D5276464007CE1951DA714B40FA0D130D527646405C59A2B3CC6E4B40C66B5ED5597146405C59A2B3CC6E4B40
20284	Ужовка	7	68	1211	44.875734999999999	44.938698000000002	54.803175000000003	54.788507000000003	0103000020E61000000100000005000000357BA0151870464063D520CCED644B40357BA015187046407FFB3A70CE664B400A698D41277846407FFB3A70CE664B400A698D412778464063D520CCED644B40357BA0151870464063D520CCED644B40
21516	Тагаево	7	68	1211	44.747096999999997	44.788096000000003	54.717557999999997	54.696361000000003	0103000020E6100000010000000500000048F8DEDFA05F4640DD9A745B22594B4048F8DEDFA05F4640D87DC7F0D85B4B40E10D6954E0644640D87DC7F0D85B4B40E10D6954E0644640DD9A745B22594B4048F8DEDFA05F4640DD9A745B22594B40
21207	Сырятино	7	68	1211	44.745893000000002	44.773938000000001	54.777583	54.759087999999998	0103000020E610000001000000050000005DA8FC6B795F46409D64ABCB29614B405DA8FC6B795F46407976F9D687634B40DA907F66106346407976F9D687634B40DA907F66106346409D64ABCB29614B405DA8FC6B795F46409D64ABCB29614B40
21387	Симбухово	7	68	1211	44.942013000000003	44.987405000000003	54.543464	54.518543999999999	0103000020E6100000010000000500000014B4C9E193784640BDC458A65F424B4014B4C9E193784640D446753A90454B4015747B49637E4640D446753A90454B4015747B49637E4640BDC458A65F424B4014B4C9E193784640BDC458A65F424B40
21300	Саитовка	7	68	1211	44.983758000000002	45.017632999999996	54.724297	54.708274000000003	0103000020E61000000100000005000000D5963AC8EB7D4640B64DF1B8A85A4B40D5963AC8EB7D4640A3CB9BC3B55C4B40492A53CC41824640A3CB9BC3B55C4B40492A53CC41824640B64DF1B8A85A4B40D5963AC8EB7D4640B64DF1B8A85A4B40
21213	Ризоватово	7	68	1211	44.597445999999998	44.660643	54.801535000000001	54.757404999999999	0103000020E6100000010000000500000021904B1C794C4640D769A4A5F2604B4021904B1C794C4640B8CCE9B298664B4069AA27F38F544640B8CCE9B298664B4069AA27F38F544640D769A4A5F2604B4021904B1C794C4640D769A4A5F2604B40
50058	Пузская Слобода	7	68	1211	44.741069000000003	44.78302	54.795015999999997	54.779353999999998	0103000020E610000001000000050000002B8A5759DB5E4640DE0033DFC1634B402B8A5759DB5E4640FBE59315C3654B40950ED6FF39644640FBE59315C3654B40950ED6FF39644640DE0033DFC1634B402B8A5759DB5E4640DE0033DFC1634B40
11881	Починки	7	68	1211	44.823228999999998	44.884467000000001	54.723283000000002	54.678364000000002	0103000020E61000000100000005000000340F60915F6946405264ADA1D4564B40340F60915F6946405B608F89945C4B4014B2F336367146405B608F89945C4B4014B2F336367146405264ADA1D4564B40340F60915F6946405264ADA1D4564B40
21119	Пеля-Хованская	7	68	1211	44.916815	44.956133999999999	54.609530999999997	54.583424999999998	0103000020E61000000100000005000000BABDA4315A7546409B559FABAD4A4B40BABDA4315A754640F7729F1C054E4B40FD4B5299627A4640F7729F1C054E4B40FD4B5299627A46409B559FABAD4A4B40BABDA4315A7546409B559FABAD4A4B40
21037	Панкратово	7	68	1211	45.022691000000002	45.041843	54.521093999999998	54.499040999999998	0103000020E61000000100000005000000EF74E789E78246407B2E5393E03F4B40EF74E789E782464027124C35B3424B408448861C5B85464027124C35B3424B408448861C5B8546407B2E5393E03F4B40EF74E789E78246407B2E5393E03F4B40
19915	Новоспасское	7	68	1211	44.809807999999997	44.831287000000003	54.654386000000002	54.631399000000002	0103000020E610000001000000050000000305DEC9A767464012DDB3AED1504B400305DEC9A7674640EA7AA2EBC2534B40844BC79C676A4640EA7AA2EBC2534B40844BC79C676A464012DDB3AED1504B400305DEC9A767464012DDB3AED1504B40
20669	Новое Урюпино	7	68	1211	44.540700000000001	44.580233999999997	54.853371000000003	54.831119999999999	0103000020E610000001000000050000003E7958A8354546409886E123626A4B403E7958A8354546406B2DCC423B6D4B407D03931B454A46406B2DCC423B6D4B407D03931B454A46409886E123626A4B403E7958A8354546409886E123626A4B40
26121	Новая Березовка	7	68	1211	44.773076000000003	44.781537999999998	54.848903	54.831986000000001	0103000020E6100000010000000500000048A98427F46246406C5D6A847E6A4B4048A98427F4624640F73C7FDAA86C4B40664AEB6F09644640F73C7FDAA86C4B40664AEB6F096446406C5D6A847E6A4B4048A98427F46246406C5D6A847E6A4B40
20961	Никитино	7	68	1211	44.720883999999998	44.756475000000002	54.632817000000003	54.608545999999997	0103000020E61000000100000005000000D61A4AED455C4640490ED8D5E44D4B40D61A4AED455C46402AADBF2500514B40ED9E3C2CD46046402AADBF2500514B40ED9E3C2CD4604640490ED8D5E44D4B40D61A4AED455C4640490ED8D5E44D4B40
20897	Наруксово	7	68	1211	44.528149999999997	44.570864999999998	54.647713000000003	54.609797	0103000020E61000000100000005000000F2B0506B9A4346407619FED30D4E4B40F2B0506B9A434640D7187442E8524B402CB7B41A12494640D7187442E8524B402CB7B41A124946407619FED30D4E4B40F2B0506B9A4346407619FED30D4E4B40
18187	Маресево	7	68	1211	44.810985000000002	44.848785999999997	54.544252999999998	54.517592999999998	0103000020E61000000100000005000000F645425BCE674640BBD1C77C40424B40F645425BCE674640FCDF1115AA454B40BDA60705A56C4640FCDF1115AA454B40BDA60705A56C4640BBD1C77C40424B40F645425BCE674640BBD1C77C40424B40
20623	Мадаево	7	68	1211	44.470784000000002	44.520155000000003	54.811912999999997	54.775266999999999	0103000020E6100000010000000500000073BD6DA6423C46408255F5F23B634B4073BD6DA6423C46403F19E3C3EC674B40EAEC6470944246403F19E3C3EC674B40EAEC6470944246408255F5F23B634B4073BD6DA6423C46408255F5F23B634B40
20558	Криуша	7	68	1211	44.620066000000001	44.644868000000002	54.588914000000003	54.571303	0103000020E6100000010000000500000047AE9B525E4F4640A88DEA7420494B4047AE9B525E4F46400A14B188614B4B40541EDD088B5246400A14B188614B4B40541EDD088B524640A88DEA7420494B4047AE9B525E4F4640A88DEA7420494B40
20518	Кочкурово	7	68	1211	44.965620999999999	45.022959999999998	54.771163999999999	54.741368999999999	0103000020E6100000010000000500000058AA0B78997B464055A2EC2DE55E4B4058AA0B78997B464020ED7F80B5624B40DE8E705AF082464020ED7F80B5624B40DE8E705AF082464055A2EC2DE55E4B4058AA0B78997B464055A2EC2DE55E4B40
20444	Коммунар	7	68	1211	44.328400999999999	44.351002000000001	54.668362999999999	54.653063000000003	0103000020E61000000100000005000000A27C410B092A4640249D819197534B40A27C410B092A4640A06D35EB8C554B40516A2FA2ED2C4640A06D35EB8C554B40516A2FA2ED2C4640249D819197534B40A27C410B092A4640249D819197534B40
21480	Каменка	7	68	1211	44.852953999999997	44.868144999999998	54.509998000000003	54.498142000000001	0103000020E61000000100000005000000067FBF982D6D4640CC61F71DC33F4B40067FBF982D6D464041834D9D47414B40CC9717601F6F464041834D9D47414B40CC9717601F6F4640CC61F71DC33F4B40067FBF982D6D4640CC61F71DC33F4B40
20396	Ильинское	7	68	1211	44.869258000000002	44.912629000000003	54.775252000000002	54.757024999999999	0103000020E61000000100000005000000A8E49CD8436F464090A0F831E6604B40A8E49CD8436F46404D1421753B634B40CB30EE06D17446404D1421753B634B40CB30EE06D174464090A0F831E6604B40A8E49CD8436F464090A0F831E6604B40
21401	Журавлиха	7	68	1211	44.920848999999997	44.944268000000001	54.505487000000002	54.491259999999997	0103000020E61000000100000005000000F3C64961DE7546409EEA909BE13E4B40F3C64961DE754640CEC64ACCB3404B40655419C6DD784640CEC64ACCB3404B40655419C6DD7846409EEA909BE13E4B40F3C64961DE7546409EEA909BE13E4B40
20205	Дуброво	7	68	1211	44.658118000000002	44.698183	54.666806999999999	54.644795999999999	0103000020E610000001000000050000005874EB353D544640BA4BE2AC88524B405874EB353D54464037DF88EE59554B40C4CF7F0F5E59464037DF88EE59554B40C4CF7F0F5E594640BA4BE2AC88524B405874EB353D544640BA4BE2AC88524B40
20803	Дивеев Усад	7	68	1211	44.793387000000003	44.819733999999997	54.597270999999999	54.577863000000001	0103000020E61000000100000005000000290989B48D654640C3482F6AF7494B40290989B48D654640B3EC4960734C4B40AAB5300BED684640B3EC4960734C4B40AAB5300BED684640C3482F6AF7494B40290989B48D654640C3482F6AF7494B40
20119	Василевка	7	68	1211	44.708145999999999	44.748651000000002	54.564166999999998	54.54101	0103000020E6100000010000000500000088653387A45A46408C67D0D03F454B4088653387A45A4640C03DCF9F36484B40118FC4CBD35F4640C03DCF9F36484B40118FC4CBD35F46408C67D0D03F454B4088653387A45A46408C67D0D03F454B40
20011	Василев Майдан	7	68	1211	44.740116999999998	44.774962000000002	54.898519999999998	54.878210000000003	0103000020E61000000100000005000000581B6327BC5E464095826E2F69704B40581B6327BC5E4640A5660FB402734B4046D26EF431634640A5660FB402734B4046D26EF43163464095826E2F69704B40581B6327BC5E464095826E2F69704B40
20317	Байково	7	68	1211	44.839649999999999	44.867587999999998	54.789628	54.763736999999999	0103000020E610000001000000050000000F0BB5A6796B464061DF4E22C2614B400F0BB5A6796B4640C100C28712654B407633A31F0D6F4640C100C28712654B407633A31F0D6F464061DF4E22C2614B400F0BB5A6796B464061DF4E22C2614B40
20108	Арзинка	7	68	1211	44.683315999999998	44.717488000000003	54.870424999999997	54.850836999999999	0103000020E61000000100000005000000B16A10E676574640069D103AE86C4B40B16A10E676574640764F1E166A6F4B40E0A293A5D65B4640764F1E166A6F4B40E0A293A5D65B4640069D103AE86C4B40B16A10E676574640069D103AE86C4B40
19959	Азрапино	7	68	1211	44.537123999999999	44.574665000000003	54.718451999999999	54.675896999999999	0103000020E61000000100000005000000C7F2AE7AC0444640753BFBCA83564B40C7F2AE7AC044464076DF313CF65B4B40F3936A9F8E49464076DF313CF65B4B40F3936A9F8E494640753BFBCA83564B40C7F2AE7AC0444640753BFBCA83564B40
12108	Языково	7	68	1209	46.267828000000002	46.316085000000001	55.421588	55.406982999999997	0103000020E61000000100000005000000FF791A30482247409483D90418B44B40FF791A30482247406A317898F6B54B40CAE02879752847406A317898F6B54B40CAE02879752847409483D90418B44B40FF791A30482247409483D90418B44B40
18541	Юморга	7	68	1209	45.794370000000001	45.825668	55.498240000000003	55.480122999999999	0103000020E61000000100000005000000367689EAADE546405987A3AB74BD4B40367689EAADE546408FC70C54C6BF4B4047AD307DAFE946408FC70C54C6BF4B4047AD307DAFE946405987A3AB74BD4B40367689EAADE546405987A3AB74BD4B40
11990	Тенекаево	7	68	1209	45.991793000000001	46.037329	55.54128	55.524090000000001	0103000020E610000001000000050000006CB3B112F3FE46409014916115C34B406CB3B112F3FE46404CFDBCA948C54B40A0185932C70447404CFDBCA948C54B40A0185932C70447409014916115C34B406CB3B112F3FE46409014916115C34B40
18314	Столбищи	7	68	1209	45.741602999999998	45.773296000000002	55.610813999999998	55.592489999999998	0103000020E61000000100000005000000C8CEDBD8ECDE4640809A5AB6D6CB4B40C8CEDBD8ECDE46402FF834272FCE4B405610035DFBE246402FF834272FCE4B405610035DFBE24640809A5AB6D6CB4B40C8CEDBD8ECDE4640809A5AB6D6CB4B40
19588	Старомочалей	7	68	1209	45.8889	45.926045999999999	55.435594999999999	55.411234999999998	0103000020E610000001000000050000000BB5A679C7F146403BFC3559A3B44B400BB5A679C7F146408BA6B393C1B74B40BA4BE2AC88F646408BA6B393C1B74B40BA4BE2AC88F646403BFC3559A3B44B400BB5A679C7F146403BFC3559A3B44B40
11816	Пильна	7	68	1209	45.906705000000002	45.940930999999999	55.577897	55.543790999999999	0103000020E61000000100000005000000520FD1E80EF44640F86D88F19AC54B40520FD1E80EF446406FBA6587F8C94B407365506D70F846406FBA6587F8C94B407365506D70F84640F86D88F19AC54B40520FD1E80EF44640F86D88F19AC54B40
19392	Петряксы	7	68	1209	46.011619000000003	46.067225000000001	55.425097999999998	55.397351999999998	0103000020E6100000010000000500000091813CBB7C01474006802A6EDCB24B4091813CBB7C01474029CC7B9C69B64B409F3C2CD49A08474029CC7B9C69B64B409F3C2CD49A08474006802A6EDCB24B4091813CBB7C01474006802A6EDCB24B40
12101	Озерки	7	68	1209	46.213155999999998	46.252735999999999	55.462758000000001	55.447177000000003	0103000020E610000001000000050000001C7920B2481B4740FF428F183DB94B401C7920B2481B47402FFB75A73BBB4B40CC423BA7592047402FFB75A73BBB4B40CC423BA759204740FF428F183DB94B401C7920B2481B4740FF428F183DB94B40
18400	Ожгибовка	7	68	1209	45.797711999999997	45.826242999999998	55.597963	55.587189000000002	0103000020E6100000010000000500000039D0436D1BE6464015C9570229CB4B4039D0436D1BE64640E99B340D8ACC4B4043C6A354C2E94640E99B340D8ACC4B4043C6A354C2E9464015C9570229CB4B4039D0436D1BE6464015C9570229CB4B40
19552	Новомочалей	7	68	1209	45.889367	45.92071	55.414434	55.400491000000002	0103000020E61000000100000005000000219221C7D6F14640D2AB014A43B34B40219221C7D6F14640DC2C5E2C0CB54B40D28C45D3D9F54640DC2C5E2C0CB54B40D28C45D3D9F54640D2AB014A43B34B40219221C7D6F14640D2AB014A43B34B40
19144	Наваты	7	68	1209	46.257452000000001	46.289709999999999	55.456755000000001	55.43629	0103000020E610000001000000050000001825E82FF420474032C9C859D8B74B401825E82FF42047406AA4A5F276BA4B407EA99F37152547406AA4A5F276BA4B407EA99F371525474032C9C859D8B74B401825E82FF420474032C9C859D8B74B40
17896	Можаров Майдан	7	68	1209	45.859794999999998	45.910442000000003	55.633805000000002	55.606791999999999	0103000020E61000000100000005000000D52137C30DEE4640BABC395CABCD4B40D52137C30DEE46404985B18520D14B40D2730B5D89F446404985B18520D14B40D2730B5D89F44640BABC395CABCD4B40D52137C30DEE4640BABC395CABCD4B40
19046	Медяна	7	68	1209	46.120809000000001	46.198846000000003	55.498128000000001	55.462665999999999	0103000020E61000000100000005000000FF0758AB760F47404E7CB5A338BB4B40FF0758AB760F4740679C86A8C2BF4B40607825C973194740679C86A8C2BF4B40607825C9731947404E7CB5A338BB4B40FF0758AB760F47404E7CB5A338BB4B40
18684	Мамешево	7	68	1209	45.893220999999997	45.936295000000001	55.506718999999997	55.49597	0103000020E61000000100000005000000DA8CD31055F2464008E6E8F17BBF4B40DA8CD31055F2464083A10E2BDCC04B404434BA83D8F7464083A10E2BDCC04B404434BA83D8F7464008E6E8F17BBF4B40DA8CD31055F2464008E6E8F17BBF4B40
18083	Мальцево	7	68	1209	45.831246	45.853273000000002	55.774664000000001	55.762079999999997	0103000020E610000001000000050000002577D84466EA4640C47762D68BE14B402577D84466EA4640BCB1A03028E34B40A8C7B60C38ED4640BCB1A03028E34B40A8C7B60C38ED4640C47762D68BE14B402577D84466EA4640C47762D68BE14B40
18504	Малое Андосово	7	68	1209	45.651646	45.678964000000001	55.57864	55.564647999999998	0103000020E61000000100000005000000DC48D92269D346403BE0BA6246C84B40DC48D92269D34640271422E010CA4B40A794D74AE8D64640271422E010CA4B40A794D74AE8D646403BE0BA6246C84B40DC48D92269D346403BE0BA6246C84B40
18237	Курмыш	7	68	1209	46.042924999999997	46.099789000000001	55.841251	55.819358000000001	0103000020E610000001000000050000002497FF907E054740A5DB12B9E0E84B402497FF907E054740185DDE1CAEEB4B4012C0CDE2C50C4740185DDE1CAEEB4B4012C0CDE2C50C4740A5DB12B9E0E84B402497FF907E054740A5DB12B9E0E84B40
19289	Красная Горка	7	68	1209	46.092584000000002	46.128678000000001	55.399248999999998	55.367075	0103000020E610000001000000050000000211E2CAD90B4740F0164850FCAE4B400211E2CAD90B4740F8FA5A971AB34B407BDB4C8578104740F8FA5A971AB34B407BDB4C8578104740F0164850FCAE4B400211E2CAD90B4740F0164850FCAE4B40
18767	Кисленка	7	68	1209	45.940823000000002	45.965544000000001	55.518310999999997	55.504873000000003	0103000020E610000001000000050000008D2958E36CF8464014D1AFAD9FC04B408D2958E36CF846401A14CD0358C24B40AD6C1FF296FB46401A14CD0358C24B40AD6C1FF296FB464014D1AFAD9FC04B408D2958E36CF8464014D1AFAD9FC04B40
12037	Каменка	7	68	1209	46.059607	46.081724000000001	55.511949999999999	55.495944999999999	0103000020E610000001000000050000006CCEC133A1074740AFCE31207BBF4B406CCEC133A1074740F697DD9387C14B402FA699EE750A4740F697DD9387C14B402FA699EE750A4740AFCE31207BBF4B406CCEC133A1074740AFCE31207BBF4B40
19454	Калиновка	7	68	1209	46.023350999999998	46.039538999999998	55.438507000000001	55.423678000000002	0103000020E6100000010000000500000019AA622AFD0247407104A9143BB64B4019AA622AFD024740960854FF20B84B4051F52B9D0F054740960854FF20B84B4051F52B9D0F0547407104A9143BB64B4019AA622AFD0247407104A9143BB64B40
18634	Жданово	7	68	1209	45.854531000000001	45.881714000000002	55.499158000000001	55.485709	0103000020E610000001000000050000008735954561ED4640BA2F67B62BBE4B408735954561ED4640B5C4CA68E4BF4B4072361D01DCF04640B5C4CA68E4BF4B4072361D01DCF04640BA2F67B62BBE4B408735954561ED4640BA2F67B62BBE4B40
18153	Деяново	7	68	1209	45.915598000000003	45.939636999999998	55.800888	55.788063999999999	0103000020E610000001000000050000003A24B55032F54640D593F947DFE44B403A24B55032F5464022E17B7F83E64B40478E740646F8464022E17B7F83E64B40478E740646F84640D593F947DFE44B403A24B55032F54640D593F947DFE44B40
18052	Бортсурманы	7	68	1209	45.851306000000001	45.884058000000003	55.736331	55.715108999999998	0103000020E61000000100000005000000BD715298F7EC4640A20914B188DB4B40BD715298F7EC4640F7031E1840DE4B4033E202D028F14640F7031E1840DE4B4033E202D028F14640A20914B188DB4B40BD715298F7EC4640A20914B188DB4B40
18427	Большое Андосово	7	68	1209	45.754053999999996	45.784174999999998	55.570217	55.558171999999999	0103000020E6100000010000000500000080B56AD784E046407EC51A2E72C74B4080B56AD784E04640C64FE3DEFCC84B409FABADD85FE44640C64FE3DEFCC84B409FABADD85FE446407EC51A2E72C74B4080B56AD784E046407EC51A2E72C74B40
18185	Беловка	7	68	1209	45.924275999999999	45.950083999999997	55.824520999999997	55.810809999999996	0103000020E61000000100000005000000253D0CAD4EF6464087A2409FC8E74B40253D0CAD4EF64640BFEE74E789E94B40F7393E5A9CF94640BFEE74E789E94B40F7393E5A9CF9464087A2409FC8E74B40253D0CAD4EF6464087A2409FC8E74B40
19234	Барятино	7	68	1209	46.192036999999999	46.219678000000002	55.388727000000003	55.368026999999998	0103000020E610000001000000050000009C4F1DAB94184740C2853C821BAF4B409C4F1DAB941847403E096CCEC1B14B404AD3A0681E1C47403E096CCEC1B14B404AD3A0681E1C4740C2853C821BAF4B409C4F1DAB94184740C2853C821BAF4B40
18714	Балеевка	7	68	1209	45.942691000000003	45.967629000000002	55.484907999999997	55.471597000000003	0103000020E61000000100000005000000E59D4319AAF8464024F25D4A5DBC4B40E59D4319AAF84640CDC8207711BE4B40A2D45E44DBFB4640CDC8207711BE4B40A2D45E44DBFB464024F25D4A5DBC4B40E59D4319AAF8464024F25D4A5DBC4B40
18976	Бакшандино	7	68	1209	46.098126999999998	46.122238000000003	55.516714999999998	55.503093999999997	0103000020E6100000010000000500000063EDEF6C8F0C47402B685A6265C04B4063EDEF6C8F0C4740232D95B723C24B400B2AAA7EA50F4740232D95B723C24B400B2AAA7EA50F47402B685A6265C04B4063EDEF6C8F0C47402B685A6265C04B40
17968	Арьевка	7	68	1209	45.858770999999997	45.887138999999998	55.652405000000002	55.639704999999999	0103000020E6100000010000000500000069E04735ECED4640390B7BDAE1D14B4069E04735ECED46409A5FCD0182D34B40C90050C58DF146409A5FCD0182D34B40C90050C58DF14640390B7BDAE1D14B4069E04735ECED4640390B7BDAE1D14B40
16958	имени Дзержинского	7	68	1465	44.474027	44.491418000000003	55.495981	55.483224	0103000020E61000000100000005000000E335AFEAAC3C46403752B648DABD4B40E335AFEAAC3C4640FC372F4E7CBF4B403755F7C8E63E4640FC372F4E7CBF4B403755F7C8E63E46403752B648DABD4B40E335AFEAAC3C46403752B648DABD4B40
17486	Ягодное	7	68	1465	44.420954000000002	44.450149000000003	55.632443000000002	55.618434999999998	0103000020E61000000100000005000000698F17D2E1354640D3D9C9E028CF4B40698F17D2E1354640C5CA68E4F3D04B40DFA9807B9E394640C5CA68E4F3D04B40DFA9807B9E394640D3D9C9E028CF4B40698F17D2E1354640D3D9C9E028CF4B40
29440	Шпилево	7	68	1465	44.553716000000001	44.575330000000001	55.693717999999997	55.682397000000002	0103000020E61000000100000005000000CFA2772AE0464640BBF1EEC858D74B40CFA2772AE0464640C1525DC0CBD84B402F34D769A4494640C1525DC0CBD84B402F34D769A4494640BBF1EEC858D74B40CFA2772AE0464640BBF1EEC858D74B40
49766	Центральный	7	68	1465	44.595469999999999	44.615772	55.601909999999997	55.596696000000001	0103000020E61000000100000005000000E3DF675C384C4640B7D3D68860CC4B40E3DF675C384C464053910A630BCD4B4071E5EC9DD14E464053910A630BCD4B4071E5EC9DD14E4640B7D3D68860CC4B40E3DF675C384C4640B7D3D68860CC4B40
17443	Тилинино	7	68	1465	44.367010000000001	44.409329999999997	55.57976	55.563203000000001	0103000020E6100000010000000500000009A7052FFA2E46402A01310917C84B4009A7052FFA2E4640B5C35F9335CA4B40C6A2E9EC64344640B5C35F9335CA4B40C6A2E9EC643446402A01310917C84B4009A7052FFA2E46402A01310917C84B40
17375	Танайково	7	68	1465	44.503455000000002	44.520280999999997	55.635818	55.625836	0103000020E61000000100000005000000FC00A436714046406954E0641BD04B40FC00A43671404640A41AF67B62D14B4076DD5B9198424640A41AF67B62D14B4076DD5B91984246406954E0641BD04B40FC00A436714046406954E0641BD04B40
17182	Сунеево	7	68	1465	44.46649	44.488273999999997	55.429884999999999	55.413181999999999	0103000020E610000001000000050000009DF4BEF1B53B4640DFA5D425E3B44B409DF4BEF1B53B46403E05C07806B74B4059BE2EC37F3E46403E05C07806B74B4059BE2EC37F3E4640DFA5D425E3B44B409DF4BEF1B53B4640DFA5D425E3B44B40
17009	Ревезень	7	68	1465	44.401136999999999	44.463003999999998	55.571942999999997	55.553564000000001	0103000020E61000000100000005000000971B0C7558334640191F662FDBC64B40971B0C75583346408B16A06D35C94B4066F50EB7433B46408B16A06D35C94B4066F50EB7433B4640191F662FDBC64B40971B0C7558334640191F662FDBC64B40
16731	Перевоз	7	68	1465	44.519382999999998	44.580567000000002	55.605521000000003	55.583081999999997	0103000020E61000000100000005000000978C63247B4246407171546EA2CA4B40978C63247B42464047054EB681CD4B408411FB04504A464047054EB681CD4B408411FB04504A46407171546EA2CA4B40978C63247B4246407171546EA2CA4B40
17279	Палец	7	68	1465	44.472580000000001	44.497410000000002	55.761071999999999	55.745269999999998	0103000020E61000000100000005000000315F5E807D3C46404F58E20165DF4B40315F5E807D3C46405EF3AACE6AE14B40085A8121AB3F46405EF3AACE6AE14B40085A8121AB3F46404F58E20165DF4B40315F5E807D3C46404F58E20165DF4B40
17346	Каменка	7	68	1465	44.349772000000002	44.375230000000002	55.733310000000003	55.724145	0103000020E610000001000000050000003C873254C52C4640ED478AC8B0DC4B403C873254C52C464036EA211ADDDD4B40323D61890730464036EA211ADDDD4B40323D618907304640ED478AC8B0DC4B403C873254C52C4640ED478AC8B0DC4B40
17152	Ичалки	7	68	1465	44.477530000000002	44.516705999999999	55.456648000000001	55.435814999999998	0103000020E61000000100000005000000F06DFAB31F3D4640990D32C9C8B74B40F06DFAB31F3D464054E4107173BA4B40D0D2156C2342464054E4107173BA4B40D0D2156C23424640990D32C9C8B74B40F06DFAB31F3D4640990D32C9C8B74B40
17030	Дубское	7	68	1465	44.634484	44.687483999999998	55.598771999999997	55.588042999999999	0103000020E61000000100000005000000EAEA8EC53651464024D236FE44CB4B40EAEA8EC53651464058E1968FA4CC4B40FA42C879FF57464058E1968FA4CC4B40FA42C879FF57464024D236FE44CB4B40EAEA8EC53651464024D236FE44CB4B40
17556	Вельдеманово	7	68	1465	44.632471000000002	44.669328999999998	55.664558	55.646588999999999	0103000020E610000001000000050000008F554ACFF4504640077AA86DC3D24B408F554ACFF4504640C8258E3C10D54B40D7A19A92AC554640C8258E3C10D54B40D7A19A92AC554640077AA86DC3D24B408F554ACFF4504640077AA86DC3D24B40
17093	Большие Кемары	7	68	1465	44.632651000000003	44.662286999999999	55.52646	55.513987999999998	0103000020E610000001000000050000000F643DB5FA504640AA44D95BCAC14B400F643DB5FA5046407A53910A63C34B4071C806D2C55446407A53910A63C34B4071C806D2C5544640AA44D95BCAC14B400F643DB5FA504640AA44D95BCAC14B40
16338	Шутилово	7	68	1230	44.094299999999997	44.135137	54.877682	54.857367000000004	0103000020E61000000100000005000000A301BC05120C4640B7D5AC33BE6D4B40A301BC05120C4640D9243FE257704B4062BD512B4C114640D9243FE257704B4062BD512B4C114640B7D5AC33BE6D4B40A301BC05120C4640B7D5AC33BE6D4B40
16645	Успенское	7	68	1230	43.744649000000003	43.778865000000003	55.143317000000003	55.125165000000003	0103000020E61000000100000005000000E3FF8EA850DF45404BCD1E6805904B40E3FF8EA850DF4540FDFA213658924B40E17F2BD9B1E34540FDFA213658924B40E17F2BD9B1E345404BCD1E6805904B40E3FF8EA850DF45404BCD1E6805904B40
16187	Сатис	7	68	1230	43.801223999999998	43.836914	55.033414	55.012388000000001	0103000020E6100000010000000500000099620E828EE64540726E13EE95814B4099620E828EE64540419DF2E846844B4043C879FF1FEB4540419DF2E846844B4043C879FF1FEB4540726E13EE95814B4099620E828EE64540726E13EE95814B40
16283	Петровка	7	68	1230	43.948951999999998	43.980789000000001	54.878639999999997	54.867227999999997	0103000020E61000000100000005000000A5BC564277F945407616BD53016F4B40A5BC564277F945408D7A884677704B4066A3737E8AFD45408D7A884677704B4066A3737E8AFD45407616BD53016F4B40A5BC564277F945407616BD53016F4B40
12521	Первомайск	7	68	1230	43.772720999999997	43.84075	54.888708000000001	54.845311000000002	0103000020E6100000010000000500000059F78F85E8E245407BF99D26336C4B4059F78F85E8E24540C7D8092FC1714B40560E2DB29DEB4540C7D8092FC1714B40560E2DB29DEB45407BF99D26336C4B4059F78F85E8E245407BF99D26336C4B40
16409	Обухово	7	68	1230	44.038702999999998	44.073019000000002	54.883566000000002	54.871217000000001	0103000020E61000000100000005000000E8A04B38F4044640105CE509846F4B40E8A04B38F4044640C4EDD0B018714B404A7EC4AF58094640C4EDD0B018714B404A7EC4AF58094640105CE509846F4B40E8A04B38F4044640105CE509846F4B40
16504	Николаевка	7	68	1230	43.862822000000001	43.907738000000002	54.840266999999997	54.824300000000001	0103000020E61000000100000005000000792288F370EE4540E10B93A982694B40792288F370EE45403A747ADE8D6B4B4011AB3FC230F445403A747ADE8D6B4B4011AB3FC230F44540E10B93A982694B40792288F370EE4540E10B93A982694B40
16416	Нелей	7	68	1230	43.976612000000003	44.002312000000003	54.819336	54.808374000000001	0103000020E61000000100000005000000CA703C9F01FD4540E6779ACC78674B40CA703C9F01FD4540BD378600E0684B40B63176C24B004640BD378600E0684B40B63176C24B004640E6779ACC78674B40CA703C9F01FD4540E6779ACC78674B40
16595	Малый Макателем	7	68	1230	43.704368000000002	43.729134999999999	55.112160000000003	55.092947000000002	0103000020E61000000100000005000000AA2C0ABB28DA454073A1F2AFE58B4B40AA2C0ABB28DA4540AEF545425B8E4B403AAFB14B54DD4540AEF545425B8E4B403AAFB14B54DD454073A1F2AFE58B4B40AA2C0ABB28DA454073A1F2AFE58B4B40
16717	Кошелиха	7	68	1230	43.521363000000001	43.554188000000003	55.033842	55.006368000000002	0103000020E61000000100000005000000172CD505BCC24540D7DEA7AAD0804B40172CD505BCC24540999D45EF54844B40F7EAE3A1EFC64540999D45EF54844B40F7EAE3A1EFC64540D7DEA7AAD0804B40172CD505BCC24540D7DEA7AAD0804B40
16556	Большой Макателем	7	68	1230	43.663575999999999	43.700082999999999	55.072153999999998	55.056516999999999	0103000020E610000001000000050000008B34F10EF0D445408255F5F23B874B408B34F10EF0D4454046239F573C894B4027BEDA519CD9454046239F573C894B4027BEDA519CD945408255F5F23B874B408B34F10EF0D445408255F5F23B874B40
16242	Берещино	7	68	1230	43.683922000000003	43.734489000000004	54.952837000000002	54.940809999999999	0103000020E61000000100000005000000E9818FC18AD74540F8DF4A766C784B40E9818FC18AD745409AB51490F6794B40C9224DBC03DE45409AB51490F6794B40C9224DBC03DE4540F8DF4A766C784B40E9818FC18AD74540F8DF4A766C784B40
12474	Ясенцы	7	68	981	43.203116999999999	43.216636999999999	55.965364999999998	55.952796999999997	0103000020E610000001000000050000007D21E4BCFF9945400B5D8940F5F94B407D21E4BCFF994540FDD98F1491FB4B40410DDFC2BA9B4540FDD98F1491FB4B40410DDFC2BA9B45400B5D8940F5F94B407D21E4BCFF9945400B5D8940F5F94B40
15372	Ярымово	7	68	981	43.128197999999998	43.143864000000001	55.901980000000002	55.892086999999997	0103000020E61000000100000005000000D0B4C4CA68904540E71725E82FF24B40D0B4C4CA68904540B3D2A41474F34B402F89B3226A924540B3D2A41474F34B402F89B3226A924540E71725E82FF24B40D0B4C4CA68904540E71725E82FF24B40
15821	Щепачиха	7	68	981	42.842883999999998	42.875250000000001	56.005813000000003	55.992325999999998	0103000020E610000001000000050000002C29779FE36B4540397CD28904FF4B402C29779FE36B45402272FA7ABE004C4079E92631087045402272FA7ABE004C4079E9263108704540397CD28904FF4B402C29779FE36B4540397CD28904FF4B40
15727	Чмутово	7	68	981	43.136955999999998	43.15945	56.123804	56.115765000000003	0103000020E61000000100000005000000D87E32C687914540BF823463D10E4C40D87E32C687914540978E39CFD80F4C4071AC8BDB68944540978E39CFD80F4C4071AC8BDB68944540BF823463D10E4C40D87E32C687914540BF823463D10E4C40
15306	Чернеево	7	68	981	43.075251000000002	43.096020000000003	55.864635999999997	55.854571999999997	0103000020E61000000100000005000000E3FE23D3A1894540E509849D62ED4B40E3FE23D3A1894540DD787764ACEE4B4087E123624A8C4540DD787764ACEE4B4087E123624A8C4540E509849D62ED4B40E3FE23D3A1894540E509849D62ED4B40
14707	Тумботино	7	68	981	42.994411999999997	43.054257	56.005620999999998	55.981434	0103000020E61000000100000005000000FE5F75E4487F45405B971AA19FFD4B40FE5F75E4487F4540DD955D30B8004C401F4AB4E4F1864540DD955D30B8004C401F4AB4E4F18645405B971AA19FFD4B40FE5F75E4487F45405B971AA19FFD4B40
15613	Таремское	7	68	981	43.027191000000002	43.048552999999998	55.934719000000001	55.920133999999997	0103000020E610000001000000050000006EDFA3FE7A83454005F86EF3C6F54B406EDFA3FE7A83454094F947DFA4F74B40B48F15FC3686454094F947DFA4F74B40B48F15FC3686454005F86EF3C6F54B406EDFA3FE7A83454005F86EF3C6F54B40
14838	Старое Щербинино	7	68	981	42.925106999999997	42.940387000000001	55.986521000000003	55.974468000000002	0103000020E610000001000000050000007C26FBE769764540D07F0F5EBBFC4B407C26FBE7697645409BE8F35146FE4B40B24AE9995E7845409BE8F35146FE4B40B24AE9995E784540D07F0F5EBBFC4B407C26FBE769764540D07F0F5EBBFC4B40
12363	Пурка	7	68	981	42.872151000000002	42.890664999999998	55.943739000000001	55.935118000000003	0103000020E610000001000000050000003C16DBA4A26F454052F355F2B1F74B403C16DBA4A26F4540D97A8670CCF84B408E588B4F01724540D97A8670CCF84B408E588B4F0172454052F355F2B1F74B403C16DBA4A26F454052F355F2B1F74B40
15799	Попадьино	7	68	981	43.084907999999999	43.100619000000002	56.125785999999998	56.114666	0103000020E610000001000000050000009A95ED43DE8A454048FB1F60AD0E4C409A95ED43DE8A4540B72572C119104C40992D5915E18C4540B72572C119104C40992D5915E18C454048FB1F60AD0E4C409A95ED43DE8A454048FB1F60AD0E4C40
40284	Павлово	7	68	981	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
40286	Павлово	7	68	981	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
15661	Молявино	7	68	981	43.005344000000001	43.018405999999999	55.909816999999997	55.903892999999997	0103000020E610000001000000050000006B9DB81CAF804540AA0A0DC4B2F34B406B9DB81CAF804540232C2AE274F44B406C06B8205B824540232C2AE274F44B406C06B8205B824540AA0A0DC4B2F34B406B9DB81CAF804540AA0A0DC4B2F34B40
15112	Малое Иголкино	7	68	981	42.880191000000003	42.899701999999998	55.915336000000003	55.907646999999997	0103000020E61000000100000005000000E59D4319AA70454000A8E2C62DF44B40E59D4319AA704540FD6CE4BA29F54B40A912656F29734540FD6CE4BA29F54B40A912656F2973454000A8E2C62DF44B40E59D4319AA70454000A8E2C62DF44B40
15266	Лаптево	7	68	981	43.071809999999999	43.095804000000001	55.923366999999999	55.902197000000001	0103000020E610000001000000050000004CC3F0113189454050C6F8307BF34B404CC3F01131894540529ACDE330F64B40BA69334E438C4540529ACDE330F64B40BA69334E438C454050C6F8307BF34B404CC3F0113189454050C6F8307BF34B40
15080	Кряжи	7	68	981	42.832742000000003	42.847762000000003	55.935763000000001	55.931114000000001	0103000020E61000000100000005000000B900344A976A4540836C59BE2EF74B40B900344A976A454047E7FC14C7F74B4052651877836C454047E7FC14C7F74B4052651877836C4540836C59BE2EF74B40B900344A976A4540836C59BE2EF74B40
14937	Комарово	7	68	981	43.249173999999996	43.274388999999999	56.038764999999998	56.028354	0103000020E61000000100000005000000BA8102EFE49F4540FB5A971AA1034C40BA8102EFE49F45405E9D6340F6044C40EAB0C22D1FA345405E9D6340F6044C40EAB0C22D1FA34540FB5A971AA1034C40BA8102EFE49F4540FB5A971AA1034C40
15211	Кишкино	7	68	981	43.262405999999999	43.276482999999999	55.956501000000003	55.949148000000001	0103000020E610000001000000050000001823128596A145402B8881AE7DF94B401823128596A14540B0CBF09F6EFA4B40327381CB63A34540B0CBF09F6EFA4B40327381CB63A345402B8881AE7DF94B401823128596A145402B8881AE7DF94B40
49635	Грудцино	7	68	981	43.314858999999998	43.345939999999999	55.965057999999999	55.944586000000001	0103000020E61000000100000005000000F6ECB94C4DA845403621AD31E8F84B40F6ECB94C4DA84540205F420587FB4B406A300DC347AC4540205F420587FB4B406A300DC347AC45403621AD31E8F84B40F6ECB94C4DA845403621AD31E8F84B40
14544	Горбатов	7	68	981	43.034171000000001	43.099558999999999	56.1389	56.117927999999999	0103000020E610000001000000050000005EBC1FB75F8445402FA4C343180F4C405EBC1FB75F8445400BB5A679C7114C40E0826C59BE8C45400BB5A679C7114C40E0826C59BE8C45402FA4C343180F4C405EBC1FB75F8445402FA4C343180F4C40
14262	Ворсма	7	68	981	43.249057000000001	43.293937	56.012244000000003	55.968882000000001	0103000020E6100000010000000500000081EB8A19E19F45406FD74B5304FC4B4081EB8A19E19F45403FC91D3691014C40CC0A45BA9FA545403FC91D3691014C40CC0A45BA9FA545406FD74B5304FC4B4081EB8A19E19F45406FD74B5304FC4B40
14990	Вареж	7	68	981	42.908963999999997	42.924675000000001	55.950266999999997	55.934854999999999	0103000020E61000000100000005000000E49EAEEE5874454044C02154A9F74B40E49EAEEE58744540E8BB5B59A2F94B40E3361AC05B764540E8BB5B59A2F94B40E3361AC05B76454044C02154A9F74B40E49EAEEE5874454044C02154A9F74B40
15714	Борок	7	68	981	43.166592000000001	43.18233	56.078783999999999	56.070368999999999	0103000020E610000001000000050000003BE3FBE2529545407CD3F4D901094C403BE3FBE2529545405AB91798150A4C40338AE596569745405AB91798150A4C40338AE596569745407CD3F4D901094C403BE3FBE2529545407CD3F4D901094C40
8215	Большое Окское	7	68	981	43.048194000000002	43.058757999999997	55.990076000000002	55.983232000000001	0103000020E6100000010000000500000085EE92382B864540BA30D28BDAFD4B4085EE92382B864540FA4674CFBAFE4B406E30D46185874540FA4674CFBAFE4B406E30D46185874540BA30D28BDAFD4B4085EE92382B864540BA30D28BDAFD4B40
15439	Большое Давыдово	7	68	981	43.104509	43.140864000000001	55.953664000000003	55.938208000000003	0103000020E610000001000000050000009F91088D608D45403C6C223317F84B409F91088D608D4540B0AF75A911FA4B408597E0D407924540B0AF75A911FA4B408597E0D4079245403C6C223317F84B409F91088D608D45403C6C223317F84B40
32512	Абабково	7	68	981	43.139381999999998	43.181728	56.035063999999998	56.016894000000001	0103000020E6100000010000000500000056D3F544D7914540D3BF249529024C4056D3F544D79145402BA226FA7C044C403D62F4DC429745402BA226FA7C044C403D62F4DC42974540D3BF249529024C4056D3F544D7914540D3BF249529024C40
29064	Теша	7	68	1042	42.799899000000003	42.834367999999998	55.523345999999997	55.504981000000001	0103000020E61000000100000005000000338D261763664540FA0CA837A3C04B40338D261763664540073F7100FDC24B401A6A1492CC6A4540073F7100FDC24B401A6A1492CC6A4540FA0CA837A3C04B40338D261763664540FA0CA837A3C04B40
28807	Степурино	7	68	1042	42.658064000000003	42.685938999999998	55.521985000000001	55.508696999999998	0103000020E610000001000000050000006556EF703B5445406249B9FB1CC14B406556EF703B54454054008C67D0C24B40850662D9CC57454054008C67D0C24B40850662D9CC5745406249B9FB1CC14B406556EF703B5445406249B9FB1CC14B40
28668	Сонино	7	68	1042	42.424968999999997	42.444634000000001	55.611688999999998	55.591579000000003	0103000020E610000001000000050000002B685A62653645400D0055DCB8CB4B402B685A626536454056293DD34BCE4B40475854C4E938454056293DD34BCE4B40475854C4E93845400D0055DCB8CB4B402B685A62653645400D0055DCB8CB4B40
29001	Салавирь	7	68	1042	42.833019999999998	42.858083000000001	55.621845999999998	55.609425999999999	0103000020E61000000100000005000000FB743C66A06A454082AAD1AB01CE4B40FB743C66A06A4540FF9254A698CF4B407520EBA9D56D4540FF9254A698CF4B407520EBA9D56D454082AAD1AB01CE4B40FB743C66A06A454082AAD1AB01CE4B40
28968	Рогово	7	68	1042	42.690618999999998	42.706716999999998	55.584629	55.566313000000001	0103000020E61000000100000005000000847F1134665845405B26C3F17CC84B40847F11346658454087A5811FD5CA4B407C43E1B3755A454087A5811FD5CA4B407C43E1B3755A45405B26C3F17CC84B40847F1134665845405B26C3F17CC84B40
10060	Поздняково	7	68	1042	42.228346000000002	42.251244	55.642305999999998	55.626120999999998	0103000020E61000000100000005000000121615713A1D45405E2BA1BB24D04B40121615713A1D45402503401537D24B407AA86DC3282045402503401537D24B407AA86DC3282045405E2BA1BB24D04B40121615713A1D45405E2BA1BB24D04B40
28415	Новошино	7	68	1042	42.232182000000002	42.250939000000002	55.596151999999996	55.582155999999998	0103000020E61000000100000005000000255CC823B81D4540C8957A1684CA4B40255CC823B81D4540F5B86FB54ECC4B403E25E7C41E204540F5B86FB54ECC4B403E25E7C41E204540C8957A1684CA4B40255CC823B81D4540C8957A1684CA4B40
28795	Натальино	7	68	1042	42.502673999999999	42.536557999999999	55.538803999999999	55.521562000000003	0103000020E610000001000000050000005646239F574045400E6B2A8BC2C24B405646239F574045401C7A8B87F7C44B401E34BBEEAD4445401C7A8B87F7C44B401E34BBEEAD4445400E6B2A8BC2C24B405646239F574045400E6B2A8BC2C24B40
9126	Навашино	7	68	1042	42.167862999999997	42.224393999999997	55.556716000000002	55.499988999999999	0103000020E61000000100000005000000AE9AE7887C1545400CAEB9A3FFBF4B40AE9AE7887C15454079944A7842C74B4095B54DF1B81C454079944A7842C74B4095B54DF1B81C45400CAEB9A3FFBF4B40AE9AE7887C1545400CAEB9A3FFBF4B40
28646	Монаково	7	68	1042	42.349187999999998	42.383915999999999	55.750418000000003	55.733193	0103000020E61000000100000005000000EC134031B22C4540FC53AA44D9DD4B40EC134031B22C4540352A70B20DE04B40A034D42824314540352A70B20DE04B40A034D42824314540FC53AA44D9DD4B40EC134031B22C4540FC53AA44D9DD4B40
28330	Малое Окулово	7	68	1042	42.122892999999998	42.134320000000002	55.584533	55.575017000000003	0103000020E6100000010000000500000023F433F5BA0F454070D234289AC94B4023F433F5BA0F4540653733FAD1CA4B407099D36531114540653733FAD1CA4B407099D3653111454070D234289AC94B4023F433F5BA0F454070D234289AC94B40
28602	Коробково	7	68	1042	42.267854	42.283439999999999	55.675240000000002	55.665162000000002	0103000020E61000000100000005000000280D350A492245405F45460724D54B40280D350A49224540BC79AA436ED64B406A300DC347244540BC79AA436ED64B406A300DC3472445405F45460724D54B40280D350A492245405F45460724D54B40
28525	Ефаново	7	68	1042	42.267594000000003	42.290095999999998	55.728408000000002	55.709358000000002	0103000020E610000001000000050000008C4D2B8540224540F793313ECCDA4B408C4D2B854022454088122D793CDD4B40A759A0DD2125454088122D793CDD4B40A759A0DD21254540F793313ECCDA4B408C4D2B8540224540F793313ECCDA4B40
28716	Горицы	7	68	1042	42.422364000000002	42.454110999999997	55.631076	55.619599000000001	0103000020E61000000100000005000000FE8007061036454031D120054FCF4B40FE800706103645402FA52E19C7D04B407EE02A4F203A45402FA52E19C7D04B407EE02A4F203A454031D120054FCF4B40FE8007061036454031D120054FCF4B40
49718	Валтово	7	68	1042	42.572310999999999	42.581178000000001	55.521363999999998	55.519565	0103000020E610000001000000050000000E12A27C41494540B8921D1B81C24B400E12A27C41494540E7A7380EBCC24B40CD936B0A644A4540E7A7380EBCC24B40CD936B0A644A4540B8921D1B81C24B400E12A27C41494540B8921D1B81C24B40
28322	Большое Окулово	7	68	1042	42.205492999999997	42.232137000000002	55.567900999999999	55.550499000000002	0103000020E61000000100000005000000494739984D1A454088BD50C076C64B40494739984D1A4540CF2EDFFAB0C84B4085984BAAB61D4540CF2EDFFAB0C84B4085984BAAB61D454088BD50C076C64B40494739984D1A454088BD50C076C64B40
24273	Чернуха	7	68	390	45.136057999999998	45.163268000000002	56.022916000000002	56.00853	0103000020E61000000100000005000000F92D3A596A9146407784D38217014C40F92D3A596A9146400F4757E9EE024C40DE3D40F7E59446400F4757E9EE024C40DE3D40F7E59446407784D38217014C40F92D3A596A9146407784D38217014C40
49632	Черная Маза	7	68	390	45.122672999999999	45.155524999999997	56.147379999999998	56.129142999999999	0103000020E61000000100000005000000158DB5BFB38F4640F0C000C287104C40158DB5BFB38F4640D00A0C59DD124C40EE5A423EE8934640D00A0C59DD124C40EE5A423EE8934640F0C000C287104C40158DB5BFB38F4640F0C000C287104C40
49752	Ушаковка	7	68	390	45.138933000000002	45.153171	56.087921000000001	56.073779999999999	0103000020E61000000100000005000000E7AA798EC8914640A88C7F9F71094C40E7AA798EC8914640D9D0CDFE400B4C400AD9791B9B934640D9D0CDFE400B4C400AD9791B9B934640A88C7F9F71094C40E7AA798EC8914640A88C7F9F71094C40
3389	Трофимово	7	68	390	45.064911000000002	45.112073000000002	56.047539999999998	56.033565000000003	0103000020E610000001000000050000004913EF004F88464027A5A0DB4B044C404913EF004F8846403CA06CCA15064C40DFE17668588E46403CA06CCA15064C40DFE17668588E464027A5A0DB4B044C404913EF004F88464027A5A0DB4B044C40
49799	Просек	7	68	390	45.157456000000003	45.200665000000001	56.115178	56.095357999999997	0103000020E610000001000000050000008D47A98427944640BBB4E1B0340C4C408D47A98427944640FE9B1727BE0E4C40D6390664AF994640FE9B1727BE0E4C40D6390664AF994640BBB4E1B0340C4C408D47A98427944640BBB4E1B0340C4C40
27223	Петровка	7	68	390	45.340398	45.384962999999999	56.009340999999999	55.990749999999998	0103000020E61000000100000005000000D9CF622992AB4640894160E5D0FE4B40D9CF622992AB464087C1FC1532014C40C495B37746B1464087C1FC1532014C40C495B37746B14640894160E5D0FE4B40D9CF622992AB4640894160E5D0FE4B40
27794	Окинино	7	68	390	44.838258000000003	44.863939999999999	56.056649	56.044367000000001	0103000020E6100000010000000500000021CEC3094C6B4640C5025FD1AD054C4021CEC3094C6B4640F12C414640074C4066DAFE95956E4640F12C414640074C4066DAFE95956E4640C5025FD1AD054C4021CEC3094C6B4640C5025FD1AD054C40
27358	Никольское	7	68	390	45.193874000000001	45.215972000000001	55.967168999999998	55.956194000000004	0103000020E61000000100000005000000B9C5FCDCD0984640D350A39064FA4B40B9C5FCDCD09846403E5A9C31CCFB4B40056D72F8A49B46403E5A9C31CCFB4B40056D72F8A49B4640D350A39064FA4B40B9C5FCDCD0984640D350A39064FA4B40
27807	Нива	7	68	390	44.779876000000002	44.808604000000003	55.999817999999998	55.992325999999998	0103000020E61000000100000005000000B8770DFAD2634640397CD28904FF4B40B8770DFAD2634640DFF94509FAFF4B4018B5FB5580674640DFF94509FAFF4B4018B5FB5580674640397CD28904FF4B40B8770DFAD2634640397CD28904FF4B40
27491	Неверово	7	68	390	45.055155999999997	45.084980000000002	56.030692999999999	56.016044000000001	0103000020E61000000100000005000000CE16105A0F87464005A6D3BA0D024C40CE16105A0F874640AA9B8BBFED034C403468E89FE08A4640AA9B8BBFED034C403468E89FE08A464005A6D3BA0D024C40CE16105A0F87464005A6D3BA0D024C40
27456	Малиновка	7	68	390	45.003160999999999	45.026850000000003	55.956516999999998	55.948846000000003	0103000020E61000000100000005000000B3CF639467804640607825C973F94B40B3CF639467804640B58828266FFA4B40E5F21FD26F834640B58828266FFA4B40E5F21FD26F834640607825C973F94B40B3CF639467804640607825C973F94B40
12415	Макарьево	7	68	390	45.039237999999997	45.085895999999998	56.095705000000002	56.081974000000002	0103000020E61000000100000005000000566133C005854640A88FC01F7E0A4C40566133C0058546402788BA0F400C4C40B96DDFA3FE8A46402788BA0F400C4C40B96DDFA3FE8A4640A88FC01F7E0A4C40566133C005854640A88FC01F7E0A4C40
9379	Ляпуны	7	68	390	44.975790000000003	44.994411999999997	55.995483	55.985064999999999	0103000020E61000000100000005000000C6E1CCAFE67C464095B7239C16FE4B40C6E1CCAFE67C4640AB5CA8FC6BFF4B40FE5F75E4487F4640AB5CA8FC6BFF4B40FE5F75E4487F464095B7239C16FE4B40C6E1CCAFE67C464095B7239C16FE4B40
16552	Лысково	7	68	390	45.011074999999998	45.064911000000002	56.05406	56.001508999999999	0103000020E61000000100000005000000CF66D5E76A81464028D3687231004C40CF66D5E76A814640C9022670EB064C404913EF004F884640C9022670EB064C404913EF004F88464028D3687231004C40CF66D5E76A81464028D3687231004C40
27733	Летнево	7	68	390	44.897357999999997	44.926301000000002	56.008918000000001	55.994903999999998	0103000020E61000000100000005000000E8667FA0DC7246406D54A70359FF4B40E8667FA0DC724640412C9B3924014C4045A0FA0791764640412C9B3924014C4045A0FA07917646406D54A70359FF4B40E8667FA0DC7246406D54A70359FF4B40
15531	Леньково	7	68	390	45.175521000000003	45.194772	55.975918999999998	55.959932999999999	0103000020E610000001000000050000007061DD7877964640F3ACA415DFFA4B407061DD7877964640C345EEE9EAFC4B409816F549EE984640C345EEE9EAFC4B409816F549EE984640F3ACA415DFFA4B407061DD7877964640F3ACA415DFFA4B40
49773	Кременки	7	68	390	45.419440999999999	45.469782000000002	56.07676	56.060223000000001	0103000020E61000000100000005000000FFCC203EB0B54640C7BB2363B5074C40FFCC203EB0B546400BD28C45D3094C40EF1F0BD121BC46400BD28C45D3094C40EF1F0BD121BC4640C7BB2363B5074C40FFCC203EB0B54640C7BB2363B5074C40
27137	Красный Оселок	7	68	390	45.262954000000001	45.300710000000002	56.089120999999999	56.073855999999999	0103000020E610000001000000050000001B2D077AA8A14640834E081D74094C401B2D077AA8A1464083312251680B4C4043CA4FAA7DA6464083312251680B4C4043CA4FAA7DA64640834E081D74094C401B2D077AA8A14640834E081D74094C40
24388	Кириково	7	68	390	44.968063999999998	44.996800999999998	56.029862999999999	56.016547000000003	0103000020E61000000100000005000000AC376A85E97B464068EC4B361E024C40AC376A85E97B4640232E008DD2034C405FCFD72C977F4640232E008DD2034C405FCFD72C977F464068EC4B361E024C40AC376A85E97B464068EC4B361E024C40
3341	Елховка	7	68	390	45.361561999999999	45.381154000000002	55.934679000000003	55.915089000000002	0103000020E61000000100000005000000F9BCE2A947AE4640F5F6E7A221F54B40F9BCE2A947AE464006A1BC8FA3F74B40AB5E7EA7C9B0464006A1BC8FA3F74B40AB5E7EA7C9B04640F5F6E7A221F54B40F9BCE2A947AE4640F5F6E7A221F54B40
7948	Великовское	7	68	390	45.34957	45.381360999999998	56.127893	56.107768999999998	0103000020E61000000100000005000000D4D4B2B5BEAC4640E542E55FCB0D4C40D4D4B2B5BEAC464094313ECC5E104C40247CEF6FD0B0464094313ECC5E104C40247CEF6FD0B04640E542E55FCB0D4C40D4D4B2B5BEAC4640E542E55FCB0D4C40
20277	Варганы	7	68	390	45.415667999999997	45.454152000000001	56.042259999999999	56.023671	0103000020E6100000010000000500000032FFE89B34B546408B6EBDA607034C4032FFE89B34B54640E8F692C668054C40DDB419A721BA4640E8F692C668054C40DDB419A721BA46408B6EBDA607034C4032FFE89B34B546408B6EBDA607034C40
16587	Валки	7	68	390	44.969473999999998	45.004275	56.134751000000001	56.112577999999999	0103000020E6100000010000000500000041295AB9177C4640E21FB6F4680E4C4041295AB9177C4640390D51853F114C405F984C158C804640390D51853F114C405F984C158C804640E21FB6F4680E4C4041295AB9177C4640E21FB6F4680E4C40
27403	Валава	7	68	390	44.952343999999997	44.974200000000003	55.939176000000003	55.926448999999998	0103000020E610000001000000050000005A457F68E6794640B9347EE195F64B405A457F68E679464014984EEB36F84B40B1E1E995B27C464014984EEB36F84B40B1E1E995B27C4640B9347EE195F64B405A457F68E6794640B9347EE195F64B40
2021	Берендеевка	7	68	390	45.267660999999997	45.285609999999998	55.993352999999999	55.986178000000002	0103000020E6100000010000000500000013B534B742A246407104A9143BFE4B4013B534B742A246401631EC3026FF4B408DB454DE8EA446401631EC3026FF4B408DB454DE8EA446407104A9143BFE4B4013B534B742A246407104A9143BFE4B40
22701	Белозериха	7	68	390	45.324173999999999	45.365766000000001	56.045211999999999	56.031649000000002	0103000020E61000000100000005000000541B9C887EA94640BEF90D130D044C40541B9C887EA9464081B1BE81C9054C408FFE976BD1AE464081B1BE81C9054C408FFE976BD1AE4640BEF90D130D044C40541B9C887EA94640BEF90D130D044C40
13044	Бармино	7	68	390	45.489105000000002	45.526761999999998	56.121490999999999	56.093767	0103000020E61000000100000005000000B1A71DFE9ABE4640D6389B8E000C4C40B1A71DFE9ABE464011E15F048D0F4C404563EDEF6CC3464011E15F048D0F4C404563EDEF6CC34640D6389B8E000C4C40B1A71DFE9ABE4640D6389B8E000C4C40
27072	Асташиха	7	68	390	45.269018000000003	45.304015999999997	56.041711999999997	56.030034000000001	0103000020E6100000010000000500000086048C2E6FA2464050E27327D8034C4086048C2E6FA24640E5EC9DD156054C40F9BA0CFFE9A64640E5EC9DD156054C40F9BA0CFFE9A6464050E27327D8034C4086048C2E6FA2464050E27327D8034C40
24970	Шандрово	7	68	1502	44.294156999999998	44.329172999999997	55.023491	55.002485	0103000020E61000000100000005000000DA71C3EFA625464083DDB06D51804B40DA71C3EFA62546400B60CAC001834B40F4DC4257222A46400B60CAC001834B40F4DC4257222A464083DDB06D51804B40DA71C3EFA625464083DDB06D51804B40
23647	Чуфарово	7	68	1502	44.629013	44.656267999999997	55.132289	55.119553000000003	0103000020E6100000010000000500000022E17B7F83504640C19140834D8F4B4022E17B7F835046406E4F90D8EE904B40A6B4FE96005446406E4F90D8EE904B40A6B4FE9600544640C19140834D8F4B4022E17B7F83504640C19140834D8F4B40
25722	Чиргуши	7	68	1502	44.704687	44.738446000000003	55.046253999999998	55.031700999999998	0103000020E610000001000000050000004B75012F335A4640102043C70E844B404B75012F335A464093A7ACA6EB854B4057EE0566855E464093A7ACA6EB854B4057EE0566855E4640102043C70E844B404B75012F335A4640102043C70E844B40
49776	Ульяново	7	68	1502	44.383493999999999	44.433602	55.050967999999997	55.036436999999999	0103000020E610000001000000050000002A1BD65416314640A3AEB5F7A9844B402A1BD654163146403E92921E86864B4077BD3445803746403E92921E86864B4077BD344580374640A3AEB5F7A9844B402A1BD65416314640A3AEB5F7A9844B40
24476	Тольский Майдан	7	68	1502	44.635005	44.670892000000002	54.964312999999997	54.934102000000003	0103000020E61000000100000005000000F3E505D847514640699082A790774B40F3E505D847514640C70DBF9B6E7B4B40F392FFC9DF554640C70DBF9B6E7B4B40F392FFC9DF554640699082A790774B40F3E505D847514640699082A790774B40
25209	Сонино	7	68	1502	44.513534999999997	44.531573000000002	55.092525000000002	55.077798000000001	0103000020E61000000100000005000000F92CCF83BB414640DCD8EC48F5894B40F92CCF83BB414640FD87F4DBD78B4B40E33785950A444640FD87F4DBD78B4B40E33785950A444640DCD8EC48F5894B40F92CCF83BB414640DCD8EC48F5894B40
49831	Санки	7	68	1502	44.210982000000001	44.228929999999998	54.849639000000003	54.829103000000003	0103000020E61000000100000005000000B8054B75011B4640FC010F0C206A4B40B8054B75011B4640FD3383F8C06C4B40618907944D1D4640FD3383F8C06C4B40618907944D1D4640FC010F0C206A4B40B8054B75011B4640FC010F0C206A4B40
25035	Салдаманово	7	68	1502	44.264009999999999	44.287222	55.026659000000002	55.015000000000001	0103000020E6100000010000000500000092E86514CB21464052B81E85EB814B4092E86514CB2146407192E68F69834B408A58C4B0C32446407192E68F69834B408A58C4B0C324464052B81E85EB814B4092E86514CB21464052B81E85EB814B40
24941	Салдаманов Майдан	7	68	1502	44.242666	44.268591000000001	55.011902999999997	54.988509999999998	0103000020E61000000100000005000000F2ECF2AD0F1F46406DE2E47E877E4B40F2ECF2AD0F1F4640B5DC990986814B40FE7F9C3061224640B5DC990986814B40FE7F9C30612246406DE2E47E877E4B40F2ECF2AD0F1F46406DE2E47E877E4B40
25518	Саврасово	7	68	1502	44.671278999999998	44.718556999999997	55.130029	55.112551000000003	0103000020E61000000100000005000000ECBE6378EC554640E9103812688E4B40ECBE6378EC5546400B444FCAA4904B40EBA7FFACF95B46400B444FCAA4904B40EBA7FFACF95B4640E9103812688E4B40ECBE6378EC554640E9103812688E4B40
25104	Поя	7	68	1502	44.306373999999998	44.331041999999997	55.081792	55.067354999999999	0103000020E610000001000000050000001F2C6343372746406D1CB1169F884B401F2C63433727464087890629788A4B401CCD91955F2A464087890629788A4B401CCD91955F2A46406D1CB1169F884B401F2C6343372746406D1CB1169F884B40
49657	Покровка	7	68	1502	44.306365	44.341085	54.763789000000003	54.736972000000002	0103000020E61000000100000005000000CCD1E3F736274640AB083719555E4B40CCD1E3F736274640B40584D6C3614B40FD135CACA82B4640B40584D6C3614B40FD135CACA82B4640AB083719555E4B40CCD1E3F736274640AB083719555E4B40
25713	Пичингуши	7	68	1502	44.814084000000001	44.841411000000001	55.077824	55.060245000000002	0103000020E6100000010000000500000033198EE733684640AF5FB01BB6874B4033198EE733684640056C0723F6894B4051BF0B5BB36B4640056C0723F6894B4051BF0B5BB36B4640AF5FB01BB6874B4033198EE733684640AF5FB01BB6874B40
49746	Печи	7	68	1502	44.302681999999997	44.337141000000003	54.816949999999999	54.786538999999998	0103000020E610000001000000050000003F8BA548BE264640A703594FAD644B403F8BA548BE264640CD3B4ED191684B400492B06F272B4640CD3B4ED191684B400492B06F272B4640A703594FAD644B403F8BA548BE264640A703594FAD644B40
25422	Перемчалки	7	68	1502	44.575563000000002	44.594706000000002	55.187686999999997	55.175837999999999	0103000020E61000000100000005000000D2E4620CAC49464070B20DDC81964B40D2E4620CAC4946403271AB2006984B40145E82531F4C46403271AB2006984B40145E82531F4C464070B20DDC81964B40D2E4620CAC49464070B20DDC81964B40
25695	Новоселки	7	68	1502	44.763365	44.797213999999997	55.072550999999997	55.060167999999997	0103000020E610000001000000050000009DF4BEF1B56146400322C495B3874B409DF4BEF1B56146406325E65949894B40E8F4BC1B0B6646406325E65949894B40E8F4BC1B0B6646400322C495B3874B409DF4BEF1B56146400322C495B3874B40
50030	Новомихайловка	7	68	1502	44.392234999999999	44.420890999999997	54.831431000000002	54.812581999999999	0103000020E610000001000000050000005CACA8C134324640BDA8DDAF02684B405CACA8C134324640B7F0BC546C6A4B4022179CC1DF354640B7F0BC546C6A4B4022179CC1DF354640BDA8DDAF02684B405CACA8C134324640BDA8DDAF02684B40
25769	Никулино	7	68	1502	44.717945999999998	44.749217000000002	55.009048	54.996268000000001	0103000020E61000000100000005000000A2258FA7E55B46409206B7B5857F4B40A2258FA7E55B46400F0C207C28814B40BA4DB857E65F46400F0C207C28814B40BA4DB857E65F46409206B7B5857F4B40A2258FA7E55B46409206B7B5857F4B40
25968	Нехорошево	7	68	1502	44.860849999999999	44.895353999999998	55.046965999999998	55.031922999999999	0103000020E610000001000000050000007C613255306E4640BF7E880D16844B407C613255306E464010035DFB02864B40E02BBAF59A72464010035DFB02864B40E02BBAF59A724640BF7E880D16844B407C613255306E4640BF7E880D16844B40
25152	Неверово	7	68	1502	44.387940999999998	44.432443999999997	55.138274000000003	55.118879	0103000020E6100000010000000500000086E3F90CA83146403197546D378F4B4086E3F90CA83146408DF161F6B2914B40FBAC32535A3746408DF161F6B2914B40FBAC32535A3746403197546D378F4B4086E3F90CA83146403197546D378F4B40
24376	Мерлиновка	7	68	1502	44.553662000000003	44.570515	54.993338999999999	54.985607000000002	0103000020E61000000100000005000000DC847B65DE464640B6DAC35E287E4B40DC847B65DE464640B16B7BBB257F4B405070B1A206494640B16B7BBB257F4B405070B1A206494640B6DAC35E287E4B40DC847B65DE464640B6DAC35E287E4B40
50031	Малое Мамлево	7	68	1502	44.527377999999999	44.555737000000001	54.915373000000002	54.903168999999998	0103000020E61000000100000005000000A0504F1F8143464069E1B20A9B734B40A0504F1F814346401A5245F12A754B40AD16D863224746401A5245F12A754B40AD16D8632247464069E1B20A9B734B40A0504F1F8143464069E1B20A9B734B40
25886	Малая Поляна	7	68	1502	44.914866000000004	44.943046000000002	55.005867000000002	54.995838999999997	0103000020E61000000100000005000000761C3F541A754640698A00A7777F4B40761C3F541A7546401590F63FC0804B40D34F38BBB57846401590F63FC0804B40D34F38BBB5784640698A00A7777F4B40761C3F541A754640698A00A7777F4B40
23883	Лукоянов	7	68	1502	44.436422999999998	44.515276999999998	55.047445000000003	55.021571000000002	0103000020E61000000100000005000000711C78B5DC37464061C5A9D6C2824B40711C78B5DC374640EBAD81AD12864B40C4B0C398F4414640EBAD81AD12864B40C4B0C398F441464061C5A9D6C2824B40711C78B5DC37464061C5A9D6C2824B40
25420	Лопатино	7	68	1502	44.551622999999999	44.606124000000001	55.118091	55.102925999999997	0103000020E61000000100000005000000575C1C959B4646403CF4DDAD2C8D4B40575C1C959B464640D9791B9B1D8F4B400DA9A278954D4640D9791B9B1D8F4B400DA9A278954D46403CF4DDAD2C8D4B40575C1C959B4646403CF4DDAD2C8D4B40
24277	Кудеярово	7	68	1502	44.439585000000001	44.477440000000001	55.030890999999997	55.011308999999997	0103000020E61000000100000005000000F5673F52443846404293C49272814B40F5673F5244384640D05E7D3CF4834B40B0E600C11C3D4640D05E7D3CF4834B40B0E600C11C3D46404293C49272814B40F5673F52443846404293C49272814B40
25207	Крюковка	7	68	1502	44.48115	44.501524000000003	55.112473999999999	55.100613000000003	0103000020E61000000100000005000000363CBD52963D4640B74604E3E08C4B40363CBD52963D46403DD34B8C658E4B405E143DF0314046403DD34B8C658E4B405E143DF031404640B74604E3E08C4B40363CBD52963D4640B74604E3E08C4B40
25900	Красная Поляна	7	68	1502	44.846082000000003	44.873902999999999	54.964204000000002	54.954931000000002	0103000020E61000000100000005000000FDDD3B6A4C6C4640E277D32D3B7A4B40FDDD3B6A4C6C4640115663096B7B4B402A70B20DDC6F4640115663096B7B4B402A70B20DDC6F4640E277D32D3B7A4B40FDDD3B6A4C6C4640E277D32D3B7A4B40
17483	Имени Степана Разина	7	68	1502	44.261701000000002	44.320602999999998	54.906559000000001	54.876852999999997	0103000020E610000001000000050000004E2A1A6B7F214640223317B83C704B404E2A1A6B7F2146407E7214200A744B40EFFFE384092946407E7214200A744B40EFFFE38409294640223317B83C704B404E2A1A6B7F214640223317B83C704B40
24368	Иванцево	7	68	1502	44.362392999999997	44.400849999999998	55.008924	54.981375999999997	0103000020E6100000010000000500000050A6D1E4622E4640268A90BA9D7D4B4050A6D1E4622E46402313F06B24814B40014D840D4F3346402313F06B24814B40014D840D4F334640268A90BA9D7D4B4050A6D1E4622E4640268A90BA9D7D4B40
25830	Елфимово	7	68	1502	44.811335	44.852074000000002	55.004483999999998	54.987121000000002	0103000020E61000000100000005000000D28C45D3D9674640F0181EFB597E4B40D28C45D3D967464079AD84EE92804B40CEE2C5C2106D464079AD84EE92804B40CEE2C5C2106D4640F0181EFB597E4B40D28C45D3D9674640F0181EFB597E4B40
25587	Докучаево	7	68	1502	44.708945	44.727027999999997	55.074117999999999	55.060085000000001	0103000020E61000000100000005000000D4D4B2B5BE5A464076FD82DDB0874B40D4D4B2B5BE5A4640C005D9B27C894B405DA3E5400F5D4640C005D9B27C894B405DA3E5400F5D464076FD82DDB0874B40D4D4B2B5BE5A464076FD82DDB0874B40
24574	Гари	7	68	1502	44.460067000000002	44.503069000000004	54.880727999999998	54.866342000000003	0103000020E61000000100000005000000037CB779E33A46405C936E4BE46E4B40037CB779E33A4640F355F2B1BB704B40D350A39064404640F355F2B1BB704B40D350A390644046405C936E4BE46E4B40037CB779E33A46405C936E4BE46E4B40
25376	Владимировка	7	68	1502	44.535705	44.568547000000002	55.164721	55.148915000000002	0103000020E61000000100000005000000DFA63FFB9144464022718FA50F934B40DFA63FFB9144464072FBE59315954B40959EE925C648464072FBE59315954B40959EE925C648464022718FA50F934B40DFA63FFB9144464022718FA50F934B40
26021	Большое Маресьево	7	68	1502	44.909331999999999	44.951875999999999	55.044454000000002	55.022385999999997	0103000020E61000000100000005000000679AB0FD64744640B2F1608BDD824B40679AB0FD6474464094162EABB0854B4074ECA012D779464094162EABB0854B4074ECA012D7794640B2F1608BDD824B40679AB0FD64744640B2F1608BDD824B40
50045	Большое Мамлево	7	68	1502	44.483072999999997	44.515574000000001	55.0169	54.995519000000002	0103000020E61000000100000005000000514A0856D53D4640F8C5A52A6D7F4B40514A0856D53D4640B5A679C729824B407E552E54FE414640B5A679C729824B407E552E54FE414640F8C5A52A6D7F4B40514A0856D53D4640F8C5A52A6D7F4B40
25483	Большая Аря	7	68	1502	44.615358999999998	44.681024999999998	55.074437000000003	55.051644000000003	0103000020E610000001000000050000004E266E15C44E46406F8445459C864B404E266E15C44E4640624ED02687894B401361C3D32B574640624ED02687894B401361C3D32B5746406F8445459C864B404E266E15C44E46406F8445459C864B40
25073	Атингеево	7	68	1502	44.215499999999999	44.256787000000003	55.045288999999997	55.030689000000002	0103000020E61000000100000005000000DD240681951B464069ACFD9DED834B40DD240681951B46402CEFAA07CC854B40DC847B65DE2046402CEFAA07CC854B40DC847B65DE20464069ACFD9DED834B40DD240681951B464069ACFD9DED834B40
25295	Александровка	7	68	1502	44.474539	44.496197000000002	55.146430000000002	55.138336000000002	0103000020E6100000010000000500000099D6A6B1BD3C464003EE79FEB4914B4099D6A6B1BD3C46409F93DE37BE924B40C9AF1F62833F46409F93DE37BE924B40C9AF1F62833F464003EE79FEB4914B4099D6A6B1BD3C464003EE79FEB4914B40
23303	Шилокша	7	68	1292	42.694284000000003	42.721431000000003	55.412911999999999	55.402858000000002	0103000020E610000001000000050000006B11514CDE5845404B77D7D990B34B406B11514CDE5845401F10E84CDAB44B4009A9DBD9575C45401F10E84CDAB44B4009A9DBD9575C45404B77D7D990B34B406B11514CDE5845404B77D7D990B34B40
13578	Серебрянка	7	68	1292	42.711315999999997	42.737403999999998	55.241205999999998	55.228906000000002	0103000020E610000001000000050000008E8F16670C5B4540D9EDB3CA4C9D4B408E8F16670C5B4540ABCC94D6DF9E4B4044F81741635E4540ABCC94D6DF9E4B4044F81741635E4540D9EDB3CA4C9D4B408E8F16670C5B4540D9EDB3CA4C9D4B40
17593	Саваслейка	7	68	1292	42.289827000000002	42.341202000000003	55.471530999999999	55.442546	0103000020E61000000100000005000000B83F170D19254540E17CEA58A5B84B40B83F170D192545406C06B8205BBC4B4037AAD381AC2B45406C06B8205BBC4B4037AAD381AC2B4540E17CEA58A5B84B40B83F170D19254540E17CEA58A5B84B40
23782	Первомайский	7	68	1292	42.415816	42.435721999999998	55.440548999999997	55.428521000000003	0103000020E61000000100000005000000A7936C75393545401A53B0C6D9B64B40A7936C75393545408BA4DDE863B84B40E8120EBDC53745408BA4DDE863B84B40E8120EBDC53745401A53B0C6D9B64B40A7936C75393545401A53B0C6D9B64B40
16820	Мурзицы	7	68	1292	42.471718000000003	42.496043999999998	55.460216000000003	55.441110999999999	0103000020E610000001000000050000009F776341613C4540F373435376B84B409F776341613C4540488C9E5BE8BA4B4042B0AA5E7E3F4540488C9E5BE8BA4B4042B0AA5E7E3F4540F373435376B84B409F776341613C4540F373435376B84B40
17555	Молочной Фермы	7	68	1292	42.564594999999997	42.577243000000003	55.448816000000001	55.438042000000003	0103000020E61000000100000005000000183E22A6444845402123A0C211B84B40183E22A644484540F5F57CCD72B94B40276C3F19E3494540F5F57CCD72B94B40276C3F19E34945402123A0C211B84B40183E22A6444845402123A0C211B84B40
13529	Михайловка	7	68	1292	42.765160999999999	42.795425999999999	55.307997999999998	55.297195000000002	0103000020E610000001000000050000005B96AFCBF061454072C45A7C0AA64B405B96AFCBF0614540E09D7C7A6CA74B40AD31E884D0654540E09D7C7A6CA74B40AD31E884D065454072C45A7C0AA64B405B96AFCBF061454072C45A7C0AA64B40
17715	Ломовка	7	68	1292	42.772609000000003	42.810886000000004	55.428525999999998	55.411158999999998	0103000020E6100000010000000500000032CC09DAE4624540603AADDBA0B44B4032CC09DAE46245402BBEA1F0D9B64B406364C91CCB6745402BBEA1F0D9B64B406364C91CCB674540603AADDBA0B44B4032CC09DAE4624540603AADDBA0B44B40
49765	Кулебаки	7	68	1292	42.219794	43.078898000000002	55.508293999999999	55.157598	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
49731	Кулебаки	7	68	1292	42.219794	43.078898000000002	55.508293999999999	55.157598	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
16722	Гремячево	7	68	1292	43.005811000000001	43.055722000000003	55.402622999999998	55.385986000000003	0103000020E61000000100000005000000817A336ABE804540605B3FFD67B14B40817A336ABE80454007CF842689B34B4078D503E62187454007CF842689B34B4078D503E621874540605B3FFD67B14B40817A336ABE804540605B3FFD67B14B40
23574	Велетьма	7	68	1292	42.406258000000001	42.432775999999997	55.345002000000001	55.327356999999999	0103000020E6100000010000000500000083DE1B4300344540EF8E8CD5E6A94B4083DE1B4300344540FD86890629AC4B40313F373465374540FD86890629AC4B40313F373465374540EF8E8CD5E6A94B4083DE1B4300344540EF8E8CD5E6A94B40
50018	Кулебаки	7	68	7005	42.219794	43.078898000000002	55.508293999999999	55.157598	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
9627	Шелокша	7	68	926	44.133889000000003	44.164979000000002	56.091366000000001	56.065334	0103000020E61000000100000005000000A7255646231146408FA850DD5C084C40A725564623114640B1FB8EE1B10B4C406EC328081E154640B1FB8EE1B10B4C406EC328081E1546408FA850DD5C084C40A7255646231146408FA850DD5C084C40
21673	Шава	7	68	926	44.376362	44.421646000000003	56.075282999999999	56.059660000000001	0103000020E6100000010000000500000084BA48A12C3046408F705AF0A2074C4084BA48A12C304640EE7893DFA2094C409F3E027FF8354640EE7893DFA2094C409F3E027FF83546408F705AF0A2074C4084BA48A12C3046408F705AF0A2074C40
22253	Чернышиха	7	68	926	44.647554	44.677055000000003	55.984088	55.958768999999997	0103000020E610000001000000050000006E32AA0CE352464095B54DF1B8FA4B406E32AA0CE35246406A317898F6FD4B40F14BFDBCA95646406A317898F6FD4B40F14BFDBCA956464095B54DF1B8FA4B406E32AA0CE352464095B54DF1B8FA4B40
21520	Чернуха	7	68	926	44.151594000000003	44.185057	56.035702999999998	56.016325000000002	0103000020E610000001000000050000008A22A46E67134640B98D06F016024C408A22A46E671346403EAF78EA91044C40AC72A1F2AF1746403EAF78EA91044C40AC72A1F2AF174640B98D06F016024C408A22A46E67134640B98D06F016024C40
49749	Фроловское	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
50016	Федяково	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
50039	Утечино	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
7407	Слободское	7	68	926	44.375588999999998	44.398055999999997	56.019222999999997	56.001398000000002	0103000020E6100000010000000500000061DEE34C13304640D12346CF2D004C4061DEE34C133046405E2A36E675024C4000FDBE7FF33246405E2A36E675024C4000FDBE7FF3324640D12346CF2D004C4061DEE34C13304640D12346CF2D004C40
49706	Ржавка	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
9391	Работки	7	68	926	44.589469000000001	44.631250000000001	56.049757	56.028565999999998	0103000020E61000000100000005000000BF805EB8734B464086E3F90CA8034C40BF805EB8734B4640A0DFF76F5E064C40CDCCCCCCCC504640A0DFF76F5E064C40CDCCCCCCCC50464086E3F90CA8034C40BF805EB8734B464086E3F90CA8034C40
22101	Прокошево	7	68	926	44.450023999999999	44.472751000000002	55.969577000000001	55.959344000000002	0103000020E610000001000000050000002235ED629A39464092CEC0C8CBFA4B402235ED629A39464016FA60191BFC4B405E13D21A833C464016FA60191BFC4B405E13D21A833C464092CEC0C8CBFA4B402235ED629A39464092CEC0C8CBFA4B40
49764	Прокошево	7	68	926	44.450023999999999	44.472751000000002	55.969577000000001	55.959344000000002	0103000020E610000001000000050000002235ED629A39464092CEC0C8CBFA4B402235ED629A39464016FA60191BFC4B405E13D21A833C464016FA60191BFC4B405E13D21A833C464092CEC0C8CBFA4B402235ED629A39464092CEC0C8CBFA4B40
49620	Подлесово	7	68	926	44.310147000000001	44.331930999999997	56.032248000000003	56.014287000000003	0103000020E61000000100000005000000ECF99AE5B227464005E10A28D4014C40ECF99AE5B227464043AED4B320044C40A8C30AB77C2A464043AED4B320044C40A8C30AB77C2A464005E10A28D4014C40ECF99AE5B227464005E10A28D4014C40
12842	Новые Ключищи	7	68	926	44.001323999999997	44.023116999999999	56.129483999999998	56.113311000000003	0103000020E61000000100000005000000965984622B00464077A38FF9800E4C40965984622B00464079AD84EE92104C40A67D737FF502464079AD84EE92104C40A67D737FF502464077A38FF9800E4C40965984622B00464077A38FF9800E4C40
9450	Новоликеево	7	68	926	44.217027999999999	44.262383999999997	56.127637999999997	56.114213999999997	0103000020E610000001000000050000007C28D192C71B4640675F79909E0E4C407C28D192C71B464009DD257156104C40307F85CC9521464009DD257156104C40307F85CC95214640675F79909E0E4C407C28D192C71B4640675F79909E0E4C40
13037	Михальчиково	7	68	926	44.326352999999997	44.348863999999999	56.125691000000003	56.115434	0103000020E61000000100000005000000CAF962EFC5294640596C938AC60E4C40CAF962EFC5294640663387A416104C4039605793A72C4640663387A416104C4039605793A72C4640596C938AC60E4C40CAF962EFC5294640596C938AC60E4C40
22057	Малиновка	7	68	926	44.636567999999997	44.660921000000002	56.008575999999998	55.997929999999997	0103000020E610000001000000050000000ED76A0F7B51464040D9942BBCFF4B400ED76A0F7B514640E7C3B30419014C40AC1E300F99544640E7C3B30419014C40AC1E300F9954464040D9942BBCFF4B400ED76A0F7B51464040D9942BBCFF4B40
21296	Лавровка	7	68	926	44.563156999999997	44.577934999999997	56.029133999999999	56.019253999999997	0103000020E61000000100000005000000B9C1508715484640992842EA76024C40B9C1508715484640D099B4A9BA034C405C1B2AC6F9494640D099B4A9BA034C405C1B2AC6F9494640992842EA76024C40B9C1508715484640992842EA76024C40
50036	Кузьминка	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
49700	Кстово	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
22174	Игумново	7	68	926	44.700024999999997	44.735553000000003	55.953834999999998	55.941777999999999	0103000020E61000000100000005000000F2B0506B9A594640D00B772E8CF84B40F2B0506B9A594640DC63E94317FA4B40C3BCC799265E4640DC63E94317FA4B40C3BCC799265E4640D00B772E8CF84B40F2B0506B9A594640D00B772E8CF84B40
21219	Зименки	7	68	926	44.249294999999996	44.274034999999998	56.162726999999997	56.152118999999999	0103000020E61000000100000005000000350708E6E81F4640D40CA9A278134C40350708E6E81F46408D96033DD4144C40CC7A3194132346408D96033DD4144C40CC7A319413234640D40CA9A278134C40350708E6E81F4640D40CA9A278134C40
21587	Запрудное	7	68	926	44.422984	44.462349000000003	56.048459999999999	56.031840000000003	0103000020E610000001000000050000009A5DF75624364640325A475513044C409A5DF756243646400395F1EF33064C404E2B85402E3B46400395F1EF33064C404E2B85402E3B4640325A475513044C409A5DF75624364640325A475513044C40
20407	Ждановский	7	68	926	44.094830000000002	44.116219000000001	56.220168000000001	56.200432999999997	0103000020E610000001000000050000000057B263230C46400305DEC9A7194C400057B263230C464018D00B772E1C4C404016A243E00E464018D00B772E1C4C404016A243E00E46400305DEC9A7194C400057B263230C46400305DEC9A7194C40
49791	Дружный	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
49715	Вязовка	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
21980	Волжский	7	68	926	44.560336999999997	44.584403000000002	56.053019999999997	56.043728999999999	0103000020E610000001000000050000008FDE701FB9474640827170E998054C408FDE701FB94746405704FF5BC9064C409757AEB7CD4A46405704FF5BC9064C409757AEB7CD4A4640827170E998054C408FDE701FB9474640827170E998054C40
21393	Ветчак	7	68	926	44.288119999999999	44.311971	56.110897000000001	56.097667999999999	0103000020E6100000010000000500000069A9BC1DE1244640D0EE9062800C4C4069A9BC1DE1244640BD1C76DF310E4C4074266DAAEE274640BD1C76DF310E4C4074266DAAEE274640D0EE9062800C4C4069A9BC1DE1244640D0EE9062800C4C40
12964	Великий Враг	7	68	926	44.225138999999999	44.247346	56.161233000000003	56.145806	0103000020E61000000100000005000000EE06D15AD11C4640C1C760C5A9124C40EE06D15AD11C46409B046F48A3144C40F165A208A91F46409B046F48A3144C40F165A208A91F4640C1C760C5A9124C40EE06D15AD11C4640C1C760C5A9124C40
12768	Большое Мокрое	7	68	926	44.062994000000003	44.096634999999999	56.139822000000002	56.118248999999999	0103000020E6100000010000000500000010ECF82F1008464071E481C8220F4C4010ECF82F1008464073A1F2AFE5114C40115322895E0C464073A1F2AFE5114C40115322895E0C464071E481C8220F4C4010ECF82F1008464071E481C8220F4C40
49807	Большая Ельня	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
50042	Ближнее Борисово	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
21118	Безводное	7	68	926	44.32461	44.365178	56.154946000000002	56.135899999999999	0103000020E610000001000000050000002FFA0AD28C29464061C3D32B65114C402FFA0AD28C294640B1524145D5134C40FE9B1727BE2E4640B1524145D5134C40FE9B1727BE2E464061C3D32B65114C402FFA0AD28C29464061C3D32B65114C40
49649	Афонино	7	68	926	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
17822	Чернуха	7	68	1499	45.367060000000002	45.385905999999999	55.359726999999999	55.344295000000002	0103000020E61000000100000005000000BBD573D2FBAE46409296CADB11AC4B40BBD573D2FBAE46407D3ECA880BAE4B4043AA285E65B146407D3ECA880BAE4B4043AA285E65B146409296CADB11AC4B40BBD573D2FBAE46409296CADB11AC4B40
18890	Чембилей	7	68	1499	45.707962000000002	45.749319999999997	55.340142999999998	55.320574999999998	0103000020E61000000100000005000000C767B27F9EDA46402575029A08A94B40C767B27F9EDA46404E7B4ACE89AB4B408E1EBFB7E9DF46404E7B4ACE89AB4B408E1EBFB7E9DF46402575029A08A94B40C767B27F9EDA46402575029A08A94B40
17474	Федоровка	7	68	1499	45.307420999999998	45.323483000000003	55.258515000000003	55.244675000000001	0103000020E61000000100000005000000438D429259A746400C93A982519F4B40438D429259A746404243FF0417A14B40EFE714E467A946404243FF0417A14B40EFE714E467A946400C93A982519F4B40438D429259A746400C93A982519F4B40
18518	Уразовка	7	68	1499	45.60134	45.635773	55.410238999999997	55.391553999999999	0103000020E6100000010000000500000069E388B5F8CC46401A4F04711EB24B4069E388B5F8CC4640994528B682B44B400457790261D14640994528B682B44B400457790261D146401A4F04711EB24B4069E388B5F8CC46401A4F04711EB24B40
50048	Трехозерье	7	68	1499	45.497163	45.524633000000001	55.414991000000001	55.408700000000003	0103000020E6100000010000000500000000E48409A3BF464007F0164850B44B4000E48409A3BF46403291D26C1EB54B4081B3942C27C346403291D26C1EB54B4081B3942C27C3464007F0164850B44B4000E48409A3BF464007F0164850B44B40
18405	Семеновка	7	68	1499	45.581578	45.608463999999998	55.457887999999997	55.444941	0103000020E610000001000000050000005B09DD2571CA464024D3A1D3F3B84B405B09DD2571CA46408C9DF0129CBA4B408C65FA25E2CD46408C9DF0129CBA4B408C65FA25E2CD464024D3A1D3F3B84B405B09DD2571CA464024D3A1D3F3B84B40
18243	Сарга	7	68	1499	45.497145000000003	45.520645000000002	55.119311000000003	55.106278000000003	0103000020E610000001000000050000005A2F8672A2BF464064247B849A8D4B405A2F8672A2BF4640CB863595458F4B40B8E9CF7EA4C24640CB863595458F4B40B8E9CF7EA4C2464064247B849A8D4B405A2F8672A2BF464064247B849A8D4B40
50076	Салган	7	68	1499	45.461903999999997	45.510350000000003	55.267342999999997	55.239485999999999	0103000020E610000001000000050000001FF296AB1FBB4640C8EC2C7AA79E4B401FF296AB1FBB464042E8A04B38A24B40BEC1172653C1464042E8A04B38A24B40BEC1172653C14640C8EC2C7AA79E4B401FF296AB1FBB4640C8EC2C7AA79E4B40
18432	Пошатово	7	68	1499	45.557268999999998	45.585709999999999	55.474775999999999	55.456632999999997	0103000020E610000001000000050000008D09319754C746401EA33CF372BA4B408D09319754C746407D76C075C5BC4B405778978BF8CA46407D76C075C5BC4B405778978BF8CA46401EA33CF372BA4B408D09319754C746401EA33CF372BA4B40
18771	Овечий Овраг	7	68	1499	45.680545000000002	45.702337999999997	55.454110999999997	55.442464000000001	0103000020E61000000100000005000000693A3B191CD7464024D40CA9A2B84B40693A3B191CD746407EE02A4F20BA4B40785E2A36E6D946407EE02A4F20BA4B40785E2A36E6D9464024D40CA9A2B84B40693A3B191CD7464024D40CA9A2B84B40
18302	Михайловка	7	68	1499	45.482070999999998	45.499336999999997	55.157217000000003	55.145544999999998	0103000020E61000000100000005000000CDACA580B4BD4640548CF337A1924B40CDACA580B4BD464008B0C8AF1F944B4064575A46EABF464008B0C8AF1F944B4064575A46EABF4640548CF337A1924B40CDACA580B4BD4640548CF337A1924B40
49729	Медяны	7	68	1499	45.650540999999997	45.70382	55.308818000000002	55.286568000000003	0103000020E6100000010000000500000083DA6FED44D34640420A9E42AEA44B4083DA6FED44D346404435255987A74B40A72215C616DA46404435255987A74B40A72215C616DA4640420A9E42AEA44B4083DA6FED44D34640420A9E42AEA44B40
49759	Маресево	7	68	1499	45.214499000000004	45.849491	55.479995000000002	55.086233999999997	0103000020E610000001000000050000002A0307B4749B4640D1E638B7098B4B402A0307B4749B46402C9FE57970BD4B40889FFF1EBCEC46402C9FE57970BD4B40889FFF1EBCEC4640D1E638B7098B4B402A0307B4749B4640D1E638B7098B4B40
17962	Малая Мажарка	7	68	1499	45.413494	45.428280000000001	55.226517999999999	55.216448	0103000020E61000000100000005000000CE8B135FEDB446406EA46C91B49B4B40CE8B135FEDB4464048FAB48AFE9C4B40F4C308E1D1B6464048FAB48AFE9C4B40F4C308E1D1B646406EA46C91B49B4B40CE8B135FEDB446406EA46C91B49B4B40
50041	Кузьминка	7	68	1499	45.603631	45.619126999999999	55.426059000000002	55.418078000000001	0103000020E6100000010000000500000007EDD5C743CD4640AB96749483B54B4007EDD5C743CD46404F95EF1989B64B400989B48D3FCF46404F95EF1989B64B400989B48D3FCF4640AB96749483B54B4007EDD5C743CD4640AB96749483B54B40
18702	Красный Яр	7	68	1499	45.566270000000003	45.586796999999997	55.396458000000003	55.388384000000002	0103000020E610000001000000050000005C5A0D897BC8464014252191B6B14B405C5A0D897BC84640691EC022BFB24B400932022A1CCB4640691EC022BFB24B400932022A1CCB464014252191B6B14B405C5A0D897BC8464014252191B6B14B40
18091	Ключищи	7	68	1499	45.530841000000002	45.568013000000001	55.351205999999998	55.319054000000001	0103000020E610000001000000050000001F300F99F2C3464039D4EFC2D6A84B401F300F99F2C3464059147651F4AC4B40F75965A6B4C8464059147651F4AC4B40F75965A6B4C8464039D4EFC2D6A84B401F300F99F2C3464039D4EFC2D6A84B40
17899	Китово	7	68	1499	45.473717000000001	45.500594	55.222965000000002	55.206600999999999	0103000020E61000000100000005000000954737C2A2BC46401329CDE6719A4B40954737C2A2BC46408A93FB1D8A9C4B407349D57613C046408A93FB1D8A9C4B407349D57613C046401329CDE6719A4B40954737C2A2BC46401329CDE6719A4B40
17804	Кечасово	7	68	1499	45.375486000000002	45.39188	55.324724000000003	55.306224999999998	0103000020E610000001000000050000008D0DDDEC0FB04640DA1B7C6132A74B408D0DDDEC0FB04640F81C588E90A94B406EFAB31F29B24640F81C588E90A94B406EFAB31F29B24640DA1B7C6132A74B408D0DDDEC0FB04640DA1B7C6132A74B40
17717	Карга	7	68	1499	45.401789000000001	45.423248999999998	55.420729999999999	55.407555000000002	0103000020E610000001000000050000003F726BD26DB34640202922C32AB44B403F726BD26DB3464019390B7BDAB54B404888F2052DB6464019390B7BDAB54B404888F2052DB64640202922C32AB44B403F726BD26DB34640202922C32AB44B40
18310	Ерпелево	7	68	1499	45.555796000000001	45.579313999999997	55.156441000000001	55.13937	0103000020E61000000100000005000000B29FC55224C7464092054CE0D6914B40B29FC55224C746407460394206944B40B60E0EF626CA46407460394206944B40B60E0EF626CA464092054CE0D6914B40B29FC55224C7464092054CE0D6914B40
17652	Ендовищи	7	68	1499	45.440334999999997	45.476951	55.38552	55.372042999999998	0103000020E610000001000000050000005F24B4E55CB8464055DAE21A9FAF4B405F24B4E55CB846401AFA27B858B14B40B265F9BA0CBD46401AFA27B858B14B40B265F9BA0CBD464055DAE21A9FAF4B405F24B4E55CB8464055DAE21A9FAF4B40
17559	Большое Рыбушкино	7	68	1499	45.752670999999999	45.803497	55.418706	55.402945000000003	0103000020E61000000100000005000000E5D2F88557E046401A8BA6B393B34B40E5D2F88557E04640CA51802898B54B4091B75CFDD8E64640CA51802898B54B4091B75CFDD8E646401A8BA6B393B34B40E5D2F88557E046401A8BA6B393B34B40
18677	Антяровка	7	68	1499	45.586526999999997	45.613728000000002	55.418700999999999	55.408290999999998	0103000020E61000000100000005000000499C155113CB4640252026E142B44B40499C155113CB4640B8E68EFE97B54B40DB519CA38ECE4640B8E68EFE97B54B40DB519CA38ECE4640252026E142B44B40499C155113CB4640252026E142B44B40
17438	Александрово	7	68	1499	45.269241999999998	45.295023999999998	55.220720999999998	55.207433000000002	0103000020E61000000100000005000000D55A988576A246403B8E1F2A8D9A4B40D55A988576A246402C45F295409C4B407EC4AF58C3A546402C45F295409C4B407EC4AF58C3A546403B8E1F2A8D9A4B40D55A988576A246403B8E1F2A8D9A4B40
50035	Акулино	7	68	1499	45.371174000000003	45.391593	55.194347	55.183117000000003	0103000020E6100000010000000500000011902FA182AF4640BB2BBB6070974B4011902FA182AF4640B189CC5CE0984B40D82B2CB81FB24640B189CC5CE0984B40D82B2CB81FB24640BB2BBB6070974B4011902FA182AF4640BB2BBB6070974B40
18546	Актуково	7	68	1499	45.624004999999997	45.648637000000001	55.381807000000002	55.369233999999999	0103000020E610000001000000050000002EC55565DFCF46401F49490F43AF4B402EC55565DFCF46402331410DDFB04B40DFFC868906D346402331410DDFB04B40DFFC868906D346401F49490F43AF4B402EC55565DFCF46401F49490F43AF4B40
17281	Шеманиха	7	68	1450	45.357968999999997	45.402453000000001	57.310558	57.289099	0103000020E61000000100000005000000ACFD9DEDD1AD464035272F3201A54C40ACFD9DEDD1AD46406EC1525DC0A74C40AB96749483B346406EC1525DC0A74C40AB96749483B3464035272F3201A54C40ACFD9DEDD1AD464035272F3201A54C40
17014	Чибирь	7	68	1450	44.854292000000001	44.869473999999997	57.145865999999998	57.134995000000004	0103000020E61000000100000005000000029EB470596D4640D00F238447914C40029EB470596D464096CCB1BCAB924C40745C8DEC4A6F464096CCB1BCAB924C40745C8DEC4A6F4640D00F238447914C40029EB470596D4640D00F238447914C40
17028	Чемашиха	7	68	1450	44.989336000000002	45.011910999999998	57.237454999999997	57.225543999999999	0103000020E61000000100000005000000B360E28FA27E46408EE733A0DE9C4C40B360E28FA27E4640C6A2E9EC649E4C4038BBB54C86814640C6A2E9EC649E4C4038BBB54C868146408EE733A0DE9C4C40B360E28FA27E46408EE733A0DE9C4C40
17096	Чащиха	7	68	1450	45.146568000000002	45.171028999999997	57.108984999999997	57.098401000000003	0103000020E61000000100000005000000F0517FBDC292464065726A67988C4C40F0517FBDC292464095607138F38D4C4073D53C47E495464095607138F38D4C4073D53C47E495464065726A67988C4C40F0517FBDC292464065726A67988C4C40
50067	Пруды	7	68	1450	44.778412000000003	44.790961000000003	57.200935000000001	57.192894000000003	0103000020E6100000010000000500000030682101A36346401DCC26C0B0984C4030682101A363464096CFF23CB8994C40ABB4C5353E65464096CFF23CB8994C40ABB4C5353E6546401DCC26C0B0984C4030682101A36346401DCC26C0B0984C40
17247	Носовая	7	68	1450	45.560934000000003	45.597352000000001	57.248618	57.232224000000002	0103000020E61000000100000005000000749B70AFCCC7464054AC1A84B99D4C40749B70AFCCC746403599F1B6D29F4C40A019C40776CC46403599F1B6D29F4C40A019C40776CC464054AC1A84B99D4C40749B70AFCCC7464054AC1A84B99D4C40
16425	Красные Баки	7	68	1450	45.119340000000001	45.175764000000001	57.143478000000002	57.112034999999999	0103000020E61000000100000005000000658D7A88468F4640F180B229578E4C40658D7A88468F464006D9B27C5D924C4036E84B6F7F96464006D9B27C5D924C4036E84B6F7F964640F180B229578E4C40658D7A88468F4640F180B229578E4C40
16896	Козлово	7	68	1450	45.131252000000003	45.145040999999999	56.961500999999998	56.954256999999998	0103000020E610000001000000050000006EC493DDCC904640527DE717257A4C406EC493DDCC9046402009FB76127B4C4021CA17B4909246402009FB76127B4C4021CA17B490924640527DE717257A4C406EC493DDCC904640527DE717257A4C40
17187	Кириллово	7	68	1450	45.415469999999999	45.447845000000001	57.128571000000001	57.106693	0103000020E610000001000000050000000C3CF71E2EB5464027DBC01DA88D4C400C3CF71E2EB54640651BB80375904C40AC5626FC52B94640651BB80375904C40AC5626FC52B9464027DBC01DA88D4C400C3CF71E2EB5464027DBC01DA88D4C40
20893	Зубилиха	7	68	1450	45.131844999999998	45.150260000000003	57.071607999999998	57.056696000000002	0103000020E610000001000000050000001092054CE090464032E884D041874C401092054CE0904640E41071732A894C40D0F23CB83B934640E41071732A894C40D0F23CB83B93464032E884D041874C401092054CE090464032E884D041874C40
50060	Затон	7	68	1450	44.689497000000003	45.912697000000001	57.380299000000001	56.904299999999999	0103000020E6100000010000000500000056D80C7041584640EBE2361AC0734C4056D80C7041584640CBD93BA3ADB04C4023145B41D3F44640CBD93BA3ADB04C4023145B41D3F44640EBE2361AC0734C4056D80C7041584640EBE2361AC0734C40
16862	Дмитриевское	7	68	1450	45.099837999999998	45.111722999999998	57.196663000000001	57.188786999999998	0103000020E61000000100000005000000F372D87DC78C46407974232C2A984C40F372D87DC78C4640A8AAD0402C994C40029B73F04C8E4640A8AAD0402C994C40029B73F04C8E46407974232C2A984C40F372D87DC78C46407974232C2A984C40
16723	Ветлужский	7	68	1450	45.097079999999998	45.160600000000002	57.183197	57.156177	0103000020E610000001000000050000003F8C101E6D8C464096B1A19BFD934C403F8C101E6D8C4640D7DCD1FF72974C406ADE718A8E944640D7DCD1FF72974C406ADE718A8E94464096B1A19BFD934C403F8C101E6D8C464096B1A19BFD934C40
17151	Быструха	7	68	1450	45.241565000000001	45.413556999999997	57.251038000000001	57.223205	0103000020E61000000100000005000000DB6D179AEB9E4640DFA63FFB919C4C40DB6D179AEB9E4640D106600322A04C4014048F6FEFB44640D106600322A04C4014048F6FEFB44640DFA63FFB919C4C40DB6D179AEB9E4640DFA63FFB919C4C40
15826	Шадрино	7	68	1274	43.557834999999997	43.579188000000002	57.174551999999998	57.162162000000002	0103000020E6100000010000000500000036C8242367C74540B55373B9C1944C4036C8242367C74540C7B94DB857964C402A1E17D522CA4540C7B94DB857964C402A1E17D522CA4540B55373B9C1944C4036C8242367C74540B55373B9C1944C40
16107	Хохлома	7	68	1274	43.881309000000002	43.911304000000001	56.980007999999998	56.961137999999998	0103000020E61000000100000005000000D255BABBCEF04540AF78EA91067B4C40D255BABBCEF04540C0E8F2E6707D4C40645B069CA5F44540C0E8F2E6707D4C40645B069CA5F44540AF78EA91067B4C40D255BABBCEF04540AF78EA91067B4C40
16120	Тарасово	7	68	1274	43.914870000000001	43.939807999999999	57.004544000000003	56.986918000000003	0103000020E61000000100000005000000B70BCD751AF54540B8EA3A54537E4C40B70BCD751AF545404FB2D5E594804C407442E8A04BF845404FB2D5E594804C407442E8A04BF84540B8EA3A54537E4C40B70BCD751AF54540B8EA3A54537E4C40
15980	Сухоноска	7	68	1274	43.769190999999999	43.792295000000003	57.030234999999998	57.009763999999997	0103000020E6100000010000000500000053B0C6D974E24540CD565EF23F814C4053B0C6D974E24540E71890BDDE834C4065E42CEC69E54540E71890BDDE834C4065E42CEC69E54540CD565EF23F814C4053B0C6D974E24540CD565EF23F814C40
16036	Семино	7	68	1274	43.774940000000001	43.799903999999998	56.954988999999998	56.941012000000001	0103000020E610000001000000050000005E2EE23B31E345406092CA1473784C405E2EE23B31E3454016855D143D7A4C4044F8174163E6454016855D143D7A4C4044F8174163E645406092CA1473784C405E2EE23B31E345406092CA1473784C40
16334	Рамешки	7	68	1274	44.295980999999998	44.315573000000001	57.295845	57.284720999999998	0103000020E61000000100000005000000629E95B4E225464001BEDBBC71A44C40629E95B4E2254640B2D7BB3FDEA54C40144031B264284640B2D7BB3FDEA54C40144031B26428464001BEDBBC71A44C40629E95B4E225464001BEDBBC71A44C40
16250	Понурово	7	68	1274	44.004899000000002	44.030987000000003	57.193859000000003	57.180523999999998	0103000020E610000001000000050000003D64CA87A0004640511212691B974C403D64CA87A00046408484285FD0984C40F3CCCB61F70346408484285FD0984C40F3CCCB61F7034640511212691B974C403D64CA87A0004640511212691B974C40
49745	Октябрьский	7	68	1274	43.901144000000002	43.908852000000003	57.284410000000001	57.277137000000003	0103000020E610000001000000050000004A7EC4AF58F345407BC1A73979A34C404A7EC4AF58F34540E353008C67A44C40BD73284355F44540E353008C67A44C40BD73284355F445407BC1A73979A34C404A7EC4AF58F345407BC1A73979A34C40
15529	Ковернино	7	68	1274	43.793228999999997	43.869514000000002	57.142462000000002	57.110657000000003	0103000020E61000000100000005000000909E228788E54540680932022A8E4C40909E228788E545401D76DF313C924C4003B5183C4CEF45401D76DF313C924C4003B5183C4CEF4540680932022A8E4C40909E228788E54540680932022A8E4C40
15726	Каменное	7	68	1274	43.867772000000002	43.888325000000002	57.240451	57.228346000000002	0103000020E610000001000000050000003831242713EF4540121615713A9D4C403831242713EF45402FA52E19C79E4C400F9C33A2B4F145402FA52E19C79E4C400F9C33A2B4F14540121615713A9D4C403831242713EF4540121615713A9D4C40
15956	Демино	7	68	1274	43.907513000000002	43.920098000000003	57.055061000000002	57.045858000000003	0103000020E61000000100000005000000F1D8CF6229F445404721C9ACDE854C40F1D8CF6229F445407D24253D0C874C40B98E71C5C5F545407D24253D0C874C40B98E71C5C5F545404721C9ACDE854C40F1D8CF6229F445404721C9ACDE854C40
16274	Горево	7	68	1274	44.192053999999999	44.226433	57.238760999999997	57.221314999999997	0103000020E610000001000000050000007288B839951846409F8EC70C549C4C407288B83995184640B6476FB88F9E4C401ADEACC1FB1C4640B6476FB88F9E4C401ADEACC1FB1C46409F8EC70C549C4C407288B839951846409F8EC70C549C4C40
49806	Гавриловка	7	68	1274	43.767699	43.791460000000001	57.096269999999997	57.081592999999998	0103000020E610000001000000050000000116F9F543E24540904AB1A3718A4C400116F9F543E24540FFCA4A93528C4C40CC0BB08F4EE54540FFCA4A93528C4C40CC0BB08F4EE54540904AB1A3718A4C400116F9F543E24540904AB1A3718A4C40
15655	Большие Мосты	7	68	1274	43.830922999999999	43.839177999999997	57.154331999999997	57.143785999999999	0103000020E61000000100000005000000423F53AF5BEA4540B3CF639467924C40423F53AF5BEA4540F65CA626C1934C40E7C2482F6AEB4540F65CA626C1934C40E7C2482F6AEB4540B3CF639467924C40423F53AF5BEA4540B3CF639467924C40
15804	Большие Круты	7	68	1274	43.731928000000003	43.760710000000003	57.229368999999998	57.216261000000003	0103000020E610000001000000050000006B8313D1AFDD45403C33C170AE9B4C406B8313D1AFDD4540ADDBA0F65B9D4C40BEDEFDF15EE14540ADDBA0F65B9D4C40BEDEFDF15EE145403C33C170AE9B4C406B8313D1AFDD45403C33C170AE9B4C40
15719	Бетино	7	68	1274	43.960765000000002	43.976467999999997	57.099497	57.094006	0103000020E610000001000000050000001B12F758FAFA45405BD07B63088C4C401B12F758FAFA45406A865451BC8C4C4096CB46E7FCFC45406A865451BC8C4C4096CB46E7FCFC45405BD07B63088C4C401B12F758FAFA45405BD07B63088C4C40
16406	Белбаж	7	68	1274	44.168078000000001	44.199779999999997	57.320751000000001	57.311962999999999	0103000020E61000000100000005000000AB96749483154640F1475167EEA74C40AB967494831546406494675E0EA94C408B321B64921946406494675E0EA94C408B321B6492194640F1475167EEA74C40AB96749483154640F1475167EEA74C40
16193	Анисимово	7	68	1274	44.094686000000003	44.107810000000001	57.060704999999999	57.051898999999999	0103000020E61000000100000005000000CDB1BCAB1E0C4640F9D85DA0A4864C40CDB1BCAB1E0C464012DA722EC5874C404417D4B7CC0D464012DA722EC5874C404417D4B7CC0D4640F9D85DA0A4864C40CDB1BCAB1E0C4640F9D85DA0A4864C40
15221	совхоз Возрождение	7	68	168	45.270527000000001	45.283920999999999	55.795737000000003	55.781717	0103000020E61000000100000005000000AED7F4A0A0A2464016DD7A4D0FE44B40AED7F4A0A0A24640CC9BC3B5DAE54B40E5D2F88557A44640CC9BC3B5DAE54B40E5D2F88557A4464016DD7A4D0FE44B40AED7F4A0A0A2464016DD7A4D0FE44B40
15373	Урга	7	68	168	45.220041999999999	45.257178000000003	55.731743999999999	55.709955999999998	0103000020E610000001000000050000008BDF14562A9C4640ABCC94D6DFDA4B408BDF14562A9C4640A98592C9A9DD4B4017A06D35EBA04640A98592C9A9DD4B4017A06D35EBA04640ABCC94D6DFDA4B408BDF14562A9C4640ABCC94D6DFDA4B40
15079	Троицкое	7	68	168	45.307806999999997	45.328476999999999	55.813566000000002	55.799917000000001	0103000020E610000001000000050000006C3D433866A74640D94125AE63E64B406C3D433866A746409B9141EE22E84B407D3ECA880BAA46409B9141EE22E84B407D3ECA880BAA4640D94125AE63E64B406C3D433866A74640D94125AE63E64B40
15447	Соловьево	7	68	168	45.018270999999999	45.035474000000001	55.877177000000003	55.864258	0103000020E610000001000000050000008CBB41B45682464037A79201A0EE4B408CBB41B456824640D6E6FF5547F04B40DDED7A698A844640D6E6FF5547F04B40DDED7A698A84464037A79201A0EE4B408CBB41B45682464037A79201A0EE4B40
15275	Покров	7	68	168	45.23198	45.248860000000001	55.693809999999999	55.686025999999998	0103000020E61000000100000005000000BDA94885B19D4640541A31B3CFD74B40BDA94885B19D4640A2D11DC4CED84B402BA4FCA4DA9F4640A2D11DC4CED84B402BA4FCA4DA9F4640541A31B3CFD74B40BDA94885B19D4640541A31B3CFD74B40
15314	Островское	7	68	168	45.138924000000003	45.162882000000003	55.884216000000002	55.876308999999999	0103000020E610000001000000050000009450FA42C89146406118B0E42AF04B409450FA42C8914640CB4C69FD2DF14B40B58D3F51D9944640CB4C69FD2DF14B40B58D3F51D99446406118B0E42AF04B409450FA42C89146406118B0E42AF04B40
521	Княгинино	7	68	168	45.003548000000002	45.060392999999998	55.830123999999998	55.805861999999998	0103000020E61000000100000005000000ADFBC74274804640698B6B7C26E74B40ADFBC74274804640F6CFD38041EA4B4023F433F5BA874640F6CFD38041EA4B4023F433F5BA874640698B6B7C26E74B40ADFBC74274804640698B6B7C26E74B40
13162	Бубенки	7	68	168	44.909771999999997	44.927351999999999	55.837833000000003	55.831575000000001	0103000020E610000001000000050000008368AD6873744640EA95B20C71EA4B408368AD68737446403A419B1C3EEB4B40AAF06778B37646403A419B1C3EEB4B40AAF06778B3764640EA95B20C71EA4B408368AD6873744640EA95B20C71EA4B40
15105	Большая Андреевка	7	68	168	44.951642999999997	44.976868000000003	55.737242999999999	55.720939999999999	0103000020E61000000100000005000000D13B1570CF7946406A300DC347DC4B40D13B1570CF7946403B1A87FA5DDE4B402541B8020A7D46403B1A87FA5DDE4B402541B8020A7D46406A300DC347DC4B40D13B1570CF7946406A300DC347DC4B40
13152	Белка	7	68	168	45.140127	45.162765	55.756127999999997	55.745372000000003	0103000020E61000000100000005000000AF2479AEEF91464054AD855968DF4B40AF2479AEEF91464081CB63CDC8E04B407BF7C77BD594464081CB63CDC8E04B407BF7C77BD594464054AD855968DF4B40AF2479AEEF91464054AD855968DF4B40
15033	Ананье	7	68	168	45.255516	45.293128000000003	55.851256999999997	55.832721999999997	0103000020E6100000010000000500000068CD8FBFB4A0464071546EA296EA4B4068CD8FBFB4A04640DBBE47FDF5EC4B405DC5E23785A54640DBBE47FDF5EC4B405DC5E23785A5464071546EA296EA4B4068CD8FBFB4A0464071546EA296EA4B40
50078	Яколевка	7	68	1300	43.245446000000001	43.268272000000003	55.003255000000003	54.991768999999998	0103000020E610000001000000050000008E7747C66A9F4540E3175E49F27E4B408E7747C66A9F45403546EBA86A804B405D37A5BC56A245403546EBA86A804B405D37A5BC56A24540E3175E49F27E4B408E7747C66A9F4540E3175E49F27E4B40
14540	Суворово	7	68	1300	43.437865000000002	43.483787	55.096367999999998	55.075535000000002	0103000020E610000001000000050000001288D7F50BB84540085A8121AB894B401288D7F50BB84540C23060C9558C4B406F9D7FBBECBD4540C23060C9558C4B406F9D7FBBECBD4540085A8121AB894B401288D7F50BB84540085A8121AB894B40
14525	Стуклово	7	68	1300	43.495733999999999	43.522306999999998	55.178789000000002	55.166943000000003	0103000020E61000000100000005000000F4C1323674BF4540E8A562635E954B40F4C1323674BF454039F1D58EE2964B4066BCADF4DAC2454039F1D58EE2964B4066BCADF4DAC24540E8A562635E954B40F4C1323674BF4540E8A562635E954B40
14471	Смирново	7	68	1300	43.332644999999999	43.366799	55.151846999999997	55.139282999999999	0103000020E61000000100000005000000C616821C94AA4540C3F17C06D4914B40C616821C94AA4540737FF5B86F934B404E9A0645F3AE4540737FF5B86F934B404E9A0645F3AE4540C3F17C06D4914B40C616821C94AA4540C3F17C06D4914B40
14390	Сатис	7	68	1300	43.206260999999998	43.255263999999997	54.934438	54.904736999999997	0103000020E610000001000000050000005AB8ACC2669A4540963D096CCE734B405AB8ACC2669A4540E01115AA9B774B404EECA17DACA04540E01115AA9B774B404EECA17DACA04540963D096CCE734B405AB8ACC2669A4540963D096CCE734B40
14385	Осиновка	7	68	1300	43.249065999999999	43.266278	55.023918999999999	55.012073000000001	0103000020E61000000100000005000000D4450A65E19F45401215AA9B8B814B40D4450A65E19F454063601DC70F834B4078D2C26515A2454063601DC70F834B4078D2C26515A245401215AA9B8B814B40D4450A65E19F45401215AA9B8B814B40
14326	Ореховец	7	68	1300	43.614742999999997	43.638027000000001	55.235666999999999	55.225599000000003	0103000020E61000000100000005000000F3380CE6AFCE45405281936DE09C4B40F3380CE6AFCE45408BDF14562A9E4B40857B65DEAAD145408BDF14562A9E4B40857B65DEAAD145405281936DE09C4B40F3380CE6AFCE45405281936DE09C4B40
14266	Онучино	7	68	1300	43.528270999999997	43.552463000000003	55.222856999999998	55.206626999999997	0103000020E610000001000000050000006D3656629EC345403CBCE7C0729A4B406D3656629EC34540A3570394869C4B4002A08A1BB7C64540A3570394869C4B4002A08A1BB7C645403CBCE7C0729A4B406D3656629EC345403CBCE7C0729A4B40
14238	Лихачи	7	68	1300	43.465991000000002	43.488512	55.057929999999999	55.041766000000003	0103000020E610000001000000050000007C9DD497A5BB4540D90A9A9658854B407C9DD497A5BB454088BA0F406A874B400EDAAB8F87BE454088BA0F406A874B400EDAAB8F87BE4540D90A9A9658854B407C9DD497A5BB4540D90A9A9658854B40
14190	Круглые Паны	7	68	1300	43.343460999999998	43.368183000000002	55.118080999999997	55.102832999999997	0103000020E61000000100000005000000C939B187F6AB45408BF9B9A1298D4B40C939B187F6AB4540B5A338471D8F4B40BAF8DB9E20AF4540B5A338471D8F4B40BAF8DB9E20AF45408BF9B9A1298D4B40C939B187F6AB45408BF9B9A1298D4B40
14108	Кременки	7	68	1300	43.358525999999998	43.402624000000003	55.013399999999997	54.992203000000003	0103000020E610000001000000050000000262122EE4AD45401EFF0582007F4B400262122EE4AD454019E25817B7814B40D84AE82E89B3454019E25817B7814B40D84AE82E89B345401EFF0582007F4B400262122EE4AD45401EFF0582007F4B40
14103	Конново	7	68	1300	43.455095	43.490595999999996	55.207351000000003	55.189933000000003	0103000020E610000001000000050000005CC98E8D40BA454031B77BB94F984B405CC98E8D40BA45407EE5417A8A9A4B4032C687D9CBBE45407EE5417A8A9A4B4032C687D9CBBE454031B77BB94F984B405CC98E8D40BA454031B77BB94F984B40
14053	Ичалово	7	68	1300	43.680446000000003	43.701943	55.184772000000002	55.170403	0103000020E61000000100000005000000D658C2DA18D74540F511F8C3CF954B40D658C2DA18D74540B79BE09BA6974B40FC53AA44D9D94540B79BE09BA6974B40FC53AA44D9D94540F511F8C3CF954B40D658C2DA18D74540F511F8C3CF954B40
13984	Ивановское	7	68	1300	43.422863	43.451402000000002	55.164253000000002	55.14432	0103000020E610000001000000050000001FD8F15F20B645405114E81379924B401FD8F15F20B645408CA2073E06954B40ACAC6D8AC7B945408CA2073E06954B40ACAC6D8AC7B945405114E81379924B401FD8F15F20B645405114E81379924B40
13953	Елизарьево	7	68	1300	43.317633999999998	43.351132999999997	55.077623000000003	55.054639999999999	0103000020E61000000100000005000000800C1D3BA8A84540D7868A71FE864B40800C1D3BA8A845406E35EB8CEF894B40EFC517EDF1AC45406E35EB8CEF894B40EFC517EDF1AC4540D7868A71FE864B40800C1D3BA8A84540D7868A71FE864B40
13789	Дивеево	7	68	1300	43.216358	43.273949000000002	55.057088999999998	55.022447999999997	0103000020E610000001000000050000002E1D739EB19B454028EE7893DF824B402E1D739EB19B45400DFB3DB14E874B40CEE2C5C210A345400DFB3DB14E874B40CEE2C5C210A3454028EE7893DF824B402E1D739EB19B454028EE7893DF824B40
13744	Глухово	7	68	1300	43.516665000000003	43.550505000000001	55.121488999999997	55.098145000000002	0103000020E6100000010000000500000072FE261422C245400AA2EE03908C4B4072FE261422C2454070E998F38C8F4B406AA4A5F276C6454070E998F38C8F4B406AA4A5F276C645400AA2EE03908C4B4072FE261422C245400AA2EE03908C4B40
13692	Верякуши	7	68	1300	43.595410999999999	43.619917000000001	55.173878999999999	55.157710999999999	0103000020E61000000100000005000000DE567A6D36CC4540179CC1DF2F944B40DE567A6D36CC4540083BC5AA41964B40029EB47059CF4540083BC5AA41964B40029EB47059CF4540179CC1DF2F944B40DE567A6D36CC4540179CC1DF2F944B40
13657	Большое Череватово	7	68	1300	43.210079	43.252039000000003	55.099133999999999	55.084204	0103000020E61000000100000005000000C74961DEE39A4540A0185932C78A4B40C74961DEE39A4540F9F5436CB08C4B4085285FD042A04540F9F5436CB08C4B4085285FD042A04540A0185932C78A4B40C74961DEE39A4540A0185932C78A4B40
50051	Горбатовка	7	68	7009	43.726655000000001	43.765543000000001	56.273535000000003	56.249651999999998	0103000020E61000000100000005000000C93CF20703DD4540C4B0C398F41F4C40C93CF20703DD4540DBA7E33103234C4043572250FDE14540DBA7E33103234C4043572250FDE14540C4B0C398F41F4C40C93CF20703DD4540C4B0C398F41F4C40
49789	Пыра	7	68	6977	43.328136000000001	43.373868999999999	56.321097000000002	56.288896000000001	0103000020E61000000100000005000000F451465C00AA4540FDF84B8BFA244C40F451465C00AA4540FFEBDCB419294C407EFE7BF0DAAF4540FFEBDCB419294C407EFE7BF0DAAF4540FDF84B8BFA244C40F451465C00AA4540FDF84B8BFA244C40
49815	Дзержинск	7	68	6977	43.369970000000002	43.508660999999996	56.264617000000001	56.212358999999999	0103000020E6100000010000000500000025404D2D5BAF4540710168942E1B4C4025404D2D5BAF45409A7B48F8DE214C4015E0BBCD1BC145409A7B48F8DE214C4015E0BBCD1BC14540710168942E1B4C4025404D2D5BAF4540710168942E1B4C40
49643	Бабино	7	68	6977	43.555822999999997	43.669297999999998	56.234720000000003	56.206901999999999	0103000020E61000000100000005000000ABAE433525C745400EBDC5C37B1A4C40ABAE433525C74540CBDB114E0B1E4C409CA38E8EABD54540CBDB114E0B1E4C409CA38E8EABD545400EBDC5C37B1A4C40ABAE433525C745400EBDC5C37B1A4C40
9075	Тепелево	7	68	985	44.093688999999998	44.134535	55.874434999999998	55.861994000000003	0103000020E610000001000000050000005A7F4B00FE0B464093ACC3D155EE4B405A7F4B00FE0B464027BD6F7CEDEF4B406C9560713811464027BD6F7CEDEF4B406C9560713811464093ACC3D155EE4B405A7F4B00FE0B464093ACC3D155EE4B40
9285	Татарское	7	68	985	44.087059000000004	44.105150999999999	55.783670999999998	55.770547000000001	0103000020E6100000010000000500000047E9D2BF240B4640F583BA48A1E24B4047E9D2BF240B46406CE9D1544FE44B4023128596750D46406CE9D1544FE44B4023128596750D4640F583BA48A1E24B4047E9D2BF240B4640F583BA48A1E24B40
49642	Суроватиха	7	68	985	43.885503999999997	43.939152	55.777504999999998	55.741855000000001	0103000020E61000000100000005000000143DF03158F14540E2AFC91AF5DE4B40143DF03158F14540FDBCA94885E34B408BFCFA2136F84540FDBCA94885E34B408BFCFA2136F84540E2AFC91AF5DE4B40143DF03158F14540E2AFC91AF5DE4B40
8587	Сарлей	7	68	985	44.008547	44.030698999999998	55.786445000000001	55.775621000000001	0103000020E610000001000000050000004DBD6E1118014640A08B868C47E34B404DBD6E1118014640268DD13AAAE44B408C82E0F1ED034640268DD13AAAE44B408C82E0F1ED034640A08B868C47E34B404DBD6E1118014640A08B868C47E34B40
8928	Румянцево	7	68	985	44.127249999999997	44.154181000000001	55.933422999999998	55.918343	0103000020E610000001000000050000003F355EBA4910464059C16F438CF54B403F355EBA49104640C72AA5677AF74B401155F833BC134640C72AA5677AF74B401155F833BC13464059C16F438CF54B403F355EBA4910464059C16F438CF54B40
8532	Румстиха	7	68	985	43.976754999999997	43.990876999999998	55.717055999999999	55.702494999999999	0103000020E610000001000000050000002C9ACE4E06FD4540404D2D5BEBD94B402C9ACE4E06FD454046B3B27DC8DB4B40E6ADBA0ED5FE454046B3B27DC8DB4B40E6ADBA0ED5FE4540404D2D5BEBD94B402C9ACE4E06FD4540404D2D5BEBD94B40
8609	Помра	7	68	985	44.303705999999998	44.323146000000001	55.781959999999998	55.768116999999997	0103000020E61000000100000005000000ABCC94D6DF264640354069A851E24B40ABCC94D6DF264640DC63E94317E44B40A7EA1ED95C294640DC63E94317E44B40A7EA1ED95C294640354069A851E24B40ABCC94D6DF264640354069A851E24B40
9198	Нижегородец	7	68	985	43.972515000000001	44.006596999999999	56.010896000000002	56.000407000000003	0103000020E610000001000000050000004AEF1B5F7BFC454041D829560D004C404AEF1B5F7BFC454020D4450A65014C4038A0A52BD800464020D4450A65014C4038A0A52BD800464041D829560D004C404AEF1B5F7BFC454041D829560D004C40
49710	Нижегородец	7	68	985	43.972515000000001	44.006596999999999	56.010896000000002	56.000407000000003	0103000020E610000001000000050000004AEF1B5F7BFC454041D829560D004C404AEF1B5F7BFC454020D4450A65014C4038A0A52BD800464020D4450A65014C4038A0A52BD800464041D829560D004C404AEF1B5F7BFC454041D829560D004C40
8879	Муравьиха	7	68	985	43.861950999999998	43.885854999999999	55.777200999999998	55.766035000000002	0103000020E6100000010000000500000093E00D6954EE4540B24B546F0DE24B4093E00D6954EE454091B586527BE34B40C1FF56B263F1454091B586527BE34B40C1FF56B263F14540B24B546F0DE24B4093E00D6954EE4540B24B546F0DE24B40
8708	Маргуша	7	68	985	44.195791	44.215276000000003	55.687984	55.670752	0103000020E61000000100000005000000F2ECF2AD0F19464001DD9733DBD54B40F2ECF2AD0F194640EC1516DC0FD84B408ECEF9298E1B4640EC1516DC0FD84B408ECEF9298E1B464001DD9733DBD54B40F2ECF2AD0F19464001DD9733DBD54B40
8686	Малая Пица	7	68	985	44.177619	44.198307	55.770603000000001	55.755139999999997	0103000020E61000000100000005000000F9122A38BC16464062F3716DA8E04B40F9122A38BC16464089997D1EA3E24B40B0C8AF1F6219464089997D1EA3E24B40B0C8AF1F6219464062F3716DA8E04B40F9122A38BC16464062F3716DA8E04B40
9134	Лазазей	7	68	985	44.170234000000001	44.188138000000002	55.848179999999999	55.837024999999997	0103000020E6100000010000000500000069554B3ACA1546409A779CA223EB4B4069554B3ACA154640868F882991EC4B404391EEE714184640868F882991EC4B404391EEE7141846409A779CA223EB4B4069554B3ACA1546409A779CA223EB4B40
9160	Кужутки	7	68	985	44.043751999999998	44.068761000000002	55.936388000000001	55.920375999999997	0103000020E610000001000000050000003A9160AA99054640FB027AE1CEF54B403A9160AA99054640F52EDE8FDBF74B40C11E1329CD084640F52EDE8FDBF74B40C11E1329CD084640FB027AE1CEF54B403A9160AA99054640FB027AE1CEF54B40
9406	Дубрава	7	68	985	44.245181000000002	44.262805999999998	55.948577999999998	55.937244999999997	0103000020E61000000100000005000000E04C4C17621F464075ABE7A4F7F74B40E04C4C17621F464040DAFF006BF94B40A69883A0A321464040DAFF006BF94B40A69883A0A321464075ABE7A4F7F74B40E04C4C17621F464075ABE7A4F7F74B40
8753	Дубки	7	68	985	43.890597999999997	43.908797999999997	55.743704999999999	55.734385000000003	0103000020E6100000010000000500000006F1811DFFF1454024D6E25300DE4B4006F1811DFFF14540936FB6B931DF4B40C9552C7E53F44540936FB6B931DF4B40C9552C7E53F4454024D6E25300DE4B4006F1811DFFF1454024D6E25300DE4B40
8308	Дальнее Константиново	7	68	985	44.072623	44.112059000000002	55.821036999999997	55.797544000000002	0103000020E61000000100000005000000FDF7E0B54B0946407E8FFAEB15E64B40FDF7E0B54B09464029E78BBD17E94B407A1C06F3570E464029E78BBD17E94B407A1C06F3570E46407E8FFAEB15E64B40FDF7E0B54B0946407E8FFAEB15E64B40
9033	Богоявление	7	68	985	43.975065999999998	44.001916999999999	55.831256000000003	55.820137000000003	0103000020E6100000010000000500000084B872F6CEFC4540AA9ECC3FFAE84B4084B872F6CEFC4540494DBB9866EA4B403927F6D03E004640494DBB9866EA4B403927F6D03E004640AA9ECC3FFAE84B4084B872F6CEFC4540AA9ECC3FFAE84B40
9377	Берсеменово	7	68	985	44.337608000000003	44.359006000000001	55.817365000000002	55.807485999999997	0103000020E610000001000000050000001A6F2BBD362B46402AFD84B35BE74B401A6F2BBD362B464091F2936A9FE84B40AD889AE8F32D464091F2936A9FE84B40AD889AE8F32D46402AFD84B35BE74B401A6F2BBD362B46402AFD84B35BE74B40
9324	Белозерово	7	68	985	44.253301999999998	44.280079999999998	55.838282999999997	55.825178000000001	0103000020E6100000010000000500000075012F336C20464079B0C56E9FE94B4075012F336C20464079E57ADB4CEB4B40C02154A9D923464079E57ADB4CEB4B40C02154A9D923464079B0C56E9FE94B4075012F336C20464079B0C56E9FE94B40
8979	Арманиха	7	68	985	43.883465000000001	43.917977999999998	55.856129000000003	55.848467999999997	0103000020E610000001000000050000009014916115F14540ECD973999AEC4B409014916115F145401F1494A295ED4B404739984D80F545401F1494A295ED4B404739984D80F54540ECD973999AEC4B409014916115F14540ECD973999AEC4B40
7583	имени Тимирязева	7	68	837	43.390819999999998	43.424138999999997	56.725575999999997	56.709358999999999	0103000020E61000000100000005000000B54FC76306B24540C70F9546CC5A4C40B54FC76306B245409961A3ACDF5C4C40A4FACE2F4AB645409961A3ACDF5C4C40A4FACE2F4AB64540C70F9546CC5A4C40B54FC76306B24540C70F9546CC5A4C40
7419	Шадрино	7	68	837	43.678083000000001	43.694163000000003	56.903455000000001	56.890338999999997	0103000020E610000001000000050000009E7C7A6CCBD645403AADDBA0F6714C409E7C7A6CCBD645402F34D769A4734C40F08B4B55DAD845402F34D769A4734C40F08B4B55DAD845403AADDBA0F6714C409E7C7A6CCBD645403AADDBA0F6714C40
7554	Федурино	7	68	837	43.368937000000003	43.387549999999997	56.816065000000002	56.804130000000001	0103000020E6100000010000000500000066A4DE5339AF4540C2DD59BBED664C4066A4DE5339AF4540833463D174684C404BC8073D9BB14540833463D174684C404BC8073D9BB14540C2DD59BBED664C4066A4DE5339AF4540C2DD59BBED664C40
7723	Строчково	7	68	837	43.508715000000002	43.531227000000001	56.689762999999999	56.681646000000001	0103000020E6100000010000000500000009FEB7921DC1454080B9162D40574C4009FEB7921DC14540D47E6B274A584C4048E00F3FFFC34540D47E6B274A584C4048E00F3FFFC3454080B9162D40574C4009FEB7921DC1454080B9162D40574C40
7866	Смольки	7	68	837	43.624507999999999	43.661887	56.673555999999998	56.659616999999997	0103000020E61000000100000005000000910BCEE0EFCF45405C7171546E544C40910BCEE0EFCF45402503401537564C40E35295B6B8D445402503401537564C40E35295B6B8D445405C7171546E544C40910BCEE0EFCF45405C7171546E544C40
7341	Смиркино	7	68	837	43.557699999999997	43.601376000000002	56.934033999999997	56.915942000000001	0103000020E61000000100000005000000567DAEB662C74540348463963D754C40567DAEB662C7454010AD156D8E774C40B64C86E3F9CC454010AD156D8E774C40B64C86E3F9CC4540348463963D754C40567DAEB662C74540348463963D754C40
7844	Серково	7	68	837	43.568263999999999	43.574992999999999	56.706226000000001	56.703142999999997	0103000020E6100000010000000500000040BFEFDFBCC84540A6B4FE96005A4C4040BFEFDFBCC84540DECA129D655A4C40E736E15E99C94540DECA129D655A4C40E736E15E99C94540A6B4FE96005A4C4040BFEFDFBCC84540A6B4FE96005A4C40
7700	Мошкино	7	68	837	43.553837000000001	43.568237000000003	56.762799000000001	56.751815000000001	0103000020E610000001000000050000004A287D21E4C6454035D252793B604C404A287D21E4C64540F435CB65A3614C4047B071FDBBC84540F435CB65A3614C4047B071FDBBC8454035D252793B604C404A287D21E4C6454035D252793B604C40
50021	Кудашиха	7	68	837	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
7667	Ковригино	7	68	837	43.508068000000002	43.527993000000002	56.727052	56.717326999999997	0103000020E6100000010000000500000073124A5F08C14540D6C4025FD15B4C4073124A5F08C14540E63E390A105D4C402BC24D4695C34540E63E390A105D4C402BC24D4695C34540D6C4025FD15B4C4073124A5F08C14540D6C4025FD15B4C40
8010	Ильинский	7	68	837	43.608131999999998	43.627850000000002	56.555137999999999	56.545622000000002	0103000020E6100000010000000500000056D3F544D7CD454033FD12F1D6454C4056D3F544D7CD4540286211C30E474C40956588635DD04540286211C30E474C40956588635DD0454033FD12F1D6454C4056D3F544D7CD454033FD12F1D6454C40
8091	Зиняки	7	68	837	43.820537999999999	43.848951999999997	56.545268999999998	56.534122000000004	0103000020E610000001000000050000000890A16307E945407D09151C5E444C400890A16307E94540E542E55FCB454C40D8EF8975AAEC4540E542E55FCB454C40D8EF8975AAEC45407D09151C5E444C400890A16307E945407D09151C5E444C40
8167	Зарубино	7	68	837	43.864483999999997	43.887858000000001	56.478729999999999	56.469313999999997	0103000020E6100000010000000500000027F56569A7EE454008C72C7B123C4C4027F56569A7EE45409ACE4E06473D4C40F9BEB854A5F145409ACE4E06473D4C40F9BEB854A5F1454008C72C7B123C4C4027F56569A7EE454008C72C7B123C4C40
6492	Заволжье	7	68	837	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
7484	Дроздово	7	68	837	43.623609999999999	43.640956000000003	56.797998999999997	56.79307	0103000020E61000000100000005000000B2BAD573D2CF454028B8585183654C40B2BAD573D2CF4540CF9ECBD424664C406616A1D80AD24540CF9ECBD424664C406616A1D80AD2454028B8585183654C40B2BAD573D2CF454028B8585183654C40
49802	Городец	7	68	837	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
8147	Воронино	7	68	837	43.717241000000001	43.745268000000003	56.588174000000002	56.572170999999997	0103000020E61000000100000005000000D82C978DCEDB45401C5C3AE63C494C40D82C978DCEDB4540C32D1F49494B4C40AF601BF164DF4540C32D1F49494B4C40AF601BF164DF45401C5C3AE63C494C40D82C978DCEDB45401C5C3AE63C494C40
9720	Варварское	7	68	837	43.562389000000003	43.571202	56.641936000000001	56.636882	0103000020E61000000100000005000000A950DD5CFCC745409EB4705985514C40A950DD5CFCC74540021077F52A524C4074B4AA251DC94540021077F52A524C4074B4AA251DC945409EB4705985514C40A950DD5CFCC745409EB4705985514C40
7602	Буревестник	7	68	837	43.359963	43.375943999999997	56.760924000000003	56.752293999999999	0103000020E610000001000000050000009162804413AE45400F7D772B4B604C409162804413AE4540EA5E27F565614C404F90D8EE1EB04540EA5E27F565614C404F90D8EE1EB045400F7D772B4B604C409162804413AE45400F7D772B4B604C40
7414	Бриляково	7	68	837	43.609793000000003	43.647756000000001	56.865805999999999	56.852336999999999	0103000020E61000000100000005000000352A70B20DCE4540DB15FA60196D4C40352A70B20DCE45401D5723BBD26E4C40D6E429ABE9D245401D5723BBD26E4C40D6E429ABE9D24540DB15FA60196D4C40352A70B20DCE4540DB15FA60196D4C40
49778	Аксентис	7	68	837	43.618335999999999	43.635575000000003	56.601103999999999	56.583683000000001	0103000020E6100000010000000500000040F850A225CF4540971DE21FB64A4C4040F850A225CF454055BFD2F9F04C4C40DE9387855AD1454055BFD2F9F04C4C40DE9387855AD14540971DE21FB64A4C4040F850A225CF4540971DE21FB64A4C40
4541	Юрьево	7	68	590	44.945534000000002	44.965404999999997	55.330010000000001	55.314233000000002	0103000020E61000000100000005000000C7A0134207794640782975C938A84B40C7A01342077946402EAD86C43DAA4B408B321B64927B46402EAD86C43DAA4B408B321B64927B4640782975C938A84B40C7A0134207794640782975C938A84B40
3837	Шерстино	7	68	590	45.019573999999999	45.048068000000001	55.258833000000003	55.243730999999997	0103000020E610000001000000050000000BED9C6681824640BC02D193329F4B400BED9C66818246401310937021A14B40F8FD9B17278646401310937021A14B40F8FD9B1727864640BC02D193329F4B400BED9C6681824640BC02D193329F4B40
5451	Ушаково	7	68	590	44.877217000000002	44.915064000000001	55.125751999999999	55.114522999999998	0103000020E61000000100000005000000643F8BA548704640E5D18DB0A88E4B40643F8BA5487046400BB43BA418904B409CDF30D1207546400BB43BA418904B409CDF30D120754640E5D18DB0A88E4B40643F8BA548704640E5D18DB0A88E4B40
3922	Тяпино	7	68	590	45.028503000000001	45.049478000000001	55.275379999999998	55.261879999999998	0103000020E61000000100000005000000406B7EFCA5834640FDBCA94885A14B40406B7EFCA58346407AFCDEA63FA34B408DEF8B4B558646407AFCDEA63FA34B408DEF8B4B55864640FDBCA94885A14B40406B7EFCA5834640FDBCA94885A14B40
4322	Тарханово	7	68	590	45.201841999999999	45.230784999999997	55.290084999999998	55.276442000000003	0103000020E61000000100000005000000C87A6AF5D5994640D49E927362A34B40C87A6AF5D5994640B3075A8121A54B4024B4E55C8A9D4640B3075A8121A54B4024B4E55C8A9D4640D49E927362A34B40C87A6AF5D5994640D49E927362A34B40
5077	Сыченки	7	68	590	44.753169	44.775151000000001	55.195461999999999	55.183179000000003	0103000020E6100000010000000500000036AE7FD7676046403128D36872974B4036AE7FD7676046402DCE18E604994B40193BE125386346402DCE18E604994B40193BE125386346403128D36872974B4036AE7FD7676046403128D36872974B40
4024	Субботино	7	68	590	45.008083999999997	45.033785000000002	55.188555000000001	55.174928000000001	0103000020E6100000010000000500000078CF81E508814640CD936B0A64964B4078CF81E508814640A73FFB9122984B40350C1F1153844640A73FFB9122984B40350C1F1153844640CD936B0A64964B4078CF81E508814640CD936B0A64964B40
4305	Соболево	7	68	590	45.188124000000002	45.205407999999998	55.227905	55.220340999999998	0103000020E61000000100000005000000DECB7D7214984640E57B4622349C4B40DECB7D721498464025CCB4FD2B9D4B401B2B31CF4A9A464025CCB4FD2B9D4B401B2B31CF4A9A4640E57B4622349C4B40DECB7D7214984640E57B4622349C4B40
4143	Покров	7	68	590	45.139229	45.173437	55.190637000000002	55.174109999999999	0103000020E61000000100000005000000D0D38041D29146400AF4893C49964B40D0D38041D29146402B3410CB66984B404B75012F339646402B3410CB66984B404B75012F339646400AF4893C49964B40D0D38041D29146400AF4893C49964B40
3926	Паново-Осаново	7	68	590	45.057248999999999	45.080047999999998	55.201664000000001	55.188715000000002	0103000020E61000000100000005000000465D6BEF53874640E0A128D027984B40465D6BEF53874640E9633E20D0994B401B0E4B033F8A4640E9633E20D0994B401B0E4B033F8A4640E0A128D027984B40465D6BEF53874640E0A128D027984B40
4722	Паново-Леонтьево	7	68	590	44.923544	44.952531999999998	55.353617	55.341223999999997	0103000020E61000000100000005000000613596B0367646401E4E603AADAB4B40613596B036764640A227655243AD4B405D328E91EC794640A227655243AD4B405D328E91EC7946401E4E603AADAB4B40613596B0367646401E4E603AADAB4B40
50019	Новоеделево	7	68	590	44.820901999999997	44.844501000000001	55.381597999999997	55.361794000000003	0103000020E61000000100000005000000499C155113694640CCF10A444FAE4B40499C155113694640081C0934D8B04B403B38D89B186C4640081C0934D8B04B403B38D89B186C4640CCF10A444FAE4B40499C155113694640CCF10A444FAE4B40
5528	Новое Молчаново	7	68	590	44.793512	44.825493000000002	55.126719000000001	55.115563000000002	0103000020E61000000100000005000000E57D1CCD9165464057D0B4C4CA8E4B40E57D1CCD916546401364045438904B40D9092FC1A96946401364045438904B40D9092FC1A969464057D0B4C4CA8E4B40E57D1CCD9165464057D0B4C4CA8E4B40
4526	Новоблаговещенское	7	68	590	45.070194000000001	45.090684000000003	55.377214000000002	55.359051999999998	0103000020E610000001000000050000000E30F31DFC8846401DC87A6AF5AD4B400E30F31DFC884640F3CB608C48B04B409F2287889B8B4640F3CB608C48B04B409F2287889B8B46401DC87A6AF5AD4B400E30F31DFC8846401DC87A6AF5AD4B40
4901	Никольское	7	68	590	44.896864000000001	44.921000999999997	55.364500999999997	55.352634000000002	0103000020E61000000100000005000000D97A8670CC72464095BA641C23AD4B40D97A8670CC724640FD2D01F8A7AE4B40A94A5B5CE3754640FD2D01F8A7AE4B40A94A5B5CE375464095BA641C23AD4B40D97A8670CC72464095BA641C23AD4B40
4400	Муратовка	7	68	590	45.213726000000001	45.241287	55.315078999999997	55.300356999999998	0103000020E610000001000000050000000727A25F5B9B4640F50F221972A64B400727A25F5B9B46400454388254A84B4098F90E7EE29E46400454388254A84B4098F90E7EE29E4640F50F221972A64B400727A25F5B9B4640F50F221972A64B40
4924	Моисеевка	7	68	590	44.858353000000001	44.877478000000004	55.257899000000002	55.247652000000002	0103000020E6100000010000000500000035B6D782DE6D4640FE648C0FB39F4B4035B6D782DE6D4640E7559DD502A14B40D17AF83251704640E7559DD502A14B40D17AF83251704640FE648C0FB39F4B4035B6D782DE6D4640FE648C0FB39F4B40
4636	Мишуково	7	68	590	44.986649999999997	45.008299999999998	55.362791999999999	55.346071999999999	0103000020E61000000100000005000000984C158C4A7E4640D90759164CAC4B40984C158C4A7E46400EA0DFF76FAE4B40454772F90F8146400EA0DFF76FAE4B40454772F90F814640D90759164CAC4B40984C158C4A7E4640D90759164CAC4B40
5302	Ляпня	7	68	590	44.984206999999998	45.02084	55.140230000000003	55.119532999999997	0103000020E6100000010000000500000044BFB67EFA7D464079E57ADB4C8F4B4044BFB67EFA7D464084F57F0EF3914B406D3997E2AA82464084F57F0EF3914B406D3997E2AA82464079E57ADB4C8F4B4044BFB67EFA7D464079E57ADB4C8F4B40
4250	Ломакино	7	68	590	45.114642000000003	45.136704999999999	55.231098000000003	55.214613999999997	0103000020E61000000100000005000000C05FCC96AC8E4640C2A1B778789B4B40C05FCC96AC8E4640E415889E949D4B408F19A88C7F914640E415889E949D4B408F19A88C7F914640C2A1B778789B4B40C05FCC96AC8E4640C2A1B778789B4B40
4699	Курбатово	7	68	590	44.985230999999999	45.017336999999998	55.316231000000002	55.300576999999997	0103000020E61000000100000005000000B000A60C1C7E46400377A04E79A64B40B000A60C1C7E46409E7DE5417AA84B4060014C19388246409E7DE5417AA84B4060014C19388246400377A04E79A64B40B000A60C1C7E46400377A04E79A64B40
5000	Карауловка	7	68	590	44.882913000000002	44.907409999999999	55.225321999999998	55.215246	0103000020E610000001000000050000004C1B0E4B03714640234C512E8D9B4B404C1B0E4B03714640DF88EE59D79C4B401C08C90226744640DF88EE59D79C4B401C08C90226744640234C512E8D9B4B404C1B0E4B03714640234C512E8D9B4B40
5165	Какино	7	68	590	44.853645999999998	44.900762	55.195914000000002	55.174846000000002	0103000020E610000001000000050000003C2EAA45446D464010EB8D5A61964B403C2EAA45446D46400E6ABFB513994B4062BD512B4C7346400E6ABFB513994B4062BD512B4C73464010EB8D5A61964B403C2EAA45446D464010EB8D5A61964B40
5546	Итманово	7	68	590	44.724648000000002	44.762027000000003	55.157418	55.135511000000001	0103000020E61000000100000005000000508E0244C15C4640C79FA86C58914B40508E0244C15C46409FE6E44526944B40A2D5C9198A6146409FE6E44526944B40A2D5C9198A614640C79FA86C58914B40508E0244C15C4640C79FA86C58914B40
4154	Исупово	7	68	590	45.186093999999997	45.217103999999999	55.173127999999998	55.153250999999997	0103000020E61000000100000005000000ACFD9DEDD1974640268A90BA9D934B40ACFD9DEDD1974640CD02ED0E29964B4057EA5910CA9B4640CD02ED0E29964B4057EA5910CA9B4640268A90BA9D934B40ACFD9DEDD1974640268A90BA9D934B40
5411	Ивково	7	68	590	45.006207000000003	45.028089999999999	55.089005999999998	55.068534999999997	0103000020E61000000100000005000000CE001764CB804640D0D03FC1C5884B40CE001764CB804640EA92718C648B4B401DACFF7398834640EA92718C648B4B401DACFF7398834640D0D03FC1C5884B40CE001764CB804640D0D03FC1C5884B40
5215	Зверево	7	68	590	44.941806	44.965665999999999	55.152355999999997	55.142504000000002	0103000020E610000001000000050000009A9658198D7846404CC631923D924B409A9658198D784640B8ACC26680934B40F86D88F19A7B4640B8ACC26680934B40F86D88F19A7B46404CC631923D924B409A9658198D7846404CC631923D924B40
3711	Гагино	7	68	590	45.009377999999998	45.060096999999999	55.241852000000002	55.225050000000003	0103000020E61000000100000005000000A4A65D4C338146407FFB3A70CE9C4B40A4A65D4C33814640713C9F01F59E4B403ACB2C42B1874640713C9F01F59E4B403ACB2C42B18746407FFB3A70CE9C4B40A4A65D4C338146407FFB3A70CE9C4B40
4454	Ветошкино	7	68	590	45.043289000000001	45.075592	55.301341000000001	55.283543000000002	0103000020E6100000010000000500000066A3737E8A8546403F0114234BA44B4066A3737E8A854640D3F8855792A64B406CEBA7FFAC894640D3F8855792A64B406CEBA7FFAC8946403F0114234BA44B4066A3737E8A8546403F0114234BA44B40
5330	Большая Уда	7	68	590	44.943621	44.966267000000002	55.092967999999999	55.078147999999999	0103000020E61000000100000005000000CF68AB92C8784640B81FF0C0008A4B40CF68AB92C87846408AC91B60E68B4B401E1A16A3AE7B46408AC91B60E68B4B401E1A16A3AE7B4640B81FF0C0008A4B40CF68AB92C8784640B81FF0C0008A4B40
4797	Березники	7	68	590	44.861792999999999	44.877594999999999	55.372154999999999	55.356872000000003	0103000020E61000000100000005000000FB75A73B4F6E4640D76D50FBADAD4B40FB75A73B4F6E46407D0569C6A2AF4B400A117008557046407D0569C6A2AF4B400A11700855704640D76D50FBADAD4B40FB75A73B4F6E4640D76D50FBADAD4B40
49795	Шиморское	7	68	6955	42.005366000000002	42.053201999999999	55.333441000000001	55.316513	0103000020E61000000100000005000000534145D5AF00454022E17B7F83A84B40534145D5AF004540A112D731AEAA4B40780AB952CF064540A112D731AEAA4B40780AB952CF06454022E17B7F83A84B40534145D5AF00454022E17B7F83A84B40
49722	Тамбалес	7	68	6955	42.031300999999999	42.055518999999997	55.297286999999997	55.286726999999999	0103000020E6100000010000000500000082AAD1AB01044540AAF06778B3A44B4082AAD1AB0104454052431B800DA64B403FA7203F1B07454052431B800DA64B403FA7203F1B074540AAF06778B3A44B4082AAD1AB01044540AAF06778B3A44B40
49821	Полдеревка	7	68	6955	42.536611999999998	42.562412000000002	55.216669000000003	55.199429000000002	0103000020E610000001000000050000001152B7B3AF444540DF6FB4E386994B401152B7B3AF4445404D874ECFBB9B4B406170CD1DFD4745404D874ECFBB9B4B406170CD1DFD474540DF6FB4E386994B401152B7B3AF444540DF6FB4E386994B40
49727	Новодмитриевка	7	68	6955	42.364953	42.392288999999998	55.177365000000002	55.166434000000002	0103000020E61000000100000005000000DEC9A7C7B62E4540A37895B54D954B40DEC9A7C7B62E45403F3A75E5B3964B404FCAA486363245403F3A75E5B3964B404FCAA48636324540A37895B54D954B40DEC9A7C7B62E4540A37895B54D954B40
49726	Дружба	7	68	6955	42.160874	42.186	55.423605999999999	55.415895999999996	0103000020E610000001000000050000006B63EC8497144540C34483143CB54B406B63EC8497144540D731AEB838B64B402B8716D9CE174540D731AEB838B64B402B8716D9CE174540C34483143CB54B406B63EC8497144540C34483143CB54B40
49714	Досчатое	7	68	6955	42.090786999999999	42.138685000000002	55.418660000000003	55.367944999999999	0103000020E6100000010000000500000073F38DE89E0B454005DD5ED218AF4B4073F38DE89E0B45405A12A0A696B54B400FB9196EC01145405A12A0A696B54B400FB9196EC011454005DD5ED218AF4B4073F38DE89E0B454005DD5ED218AF4B40
49869	Димара	7	68	6955	42.526228000000003	42.544383000000003	55.084688	55.073535	0103000020E61000000100000005000000A81E69705B434540410E4A9869894B40A81E69705B4345408C2E6F0ED78A4B40CBBF9657AE4545408C2E6F0ED78A4B40CBBF9657AE454540410E4A9869894B40A81E69705B434540410E4A9869894B40
49798	Грязная	7	68	6955	42.054468	42.095719000000003	55.331018999999998	55.316620999999998	0103000020E61000000100000005000000DA56B3CEF8064540081D740987A84B40DA56B3CEF806454064ADA1D45EAA4B408C4D2B85400C454064ADA1D45EAA4B408C4D2B85400C4540081D740987A84B40DA56B3CEF8064540081D740987A84B40
50017	Виля	7	68	6955	42.169029999999999	42.226064999999998	55.266101999999997	55.229173000000003	0103000020E610000001000000050000007D0569C6A21545402810768A559D4B407D0569C6A215454039B35DA10FA24B4097E2AAB2EF1C454039B35DA10FA24B4097E2AAB2EF1C45402810768A559D4B407D0569C6A21545402810768A559D4B40
49720	Верхняя Верея	7	68	6955	42.094982000000002	42.118364999999997	55.241652000000002	55.215964999999997	0103000020E61000000100000005000000B6DAC35E280C4540520ABABDA49B4B40B6DAC35E280C4540AA81E673EE9E4B40DAFE9595260F4540AA81E673EE9E4B40DAFE9595260F4540520ABABDA49B4B40B6DAC35E280C4540520ABABDA49B4B40
49650	Борковка	7	68	6955	42.089359000000002	42.128894000000003	55.311399999999999	55.298209999999997	0103000020E61000000100000005000000384D9F1D700B45408AABCABE2BA64B40384D9F1D700B4540B9FC87F4DBA74B4048533D997F104540B9FC87F4DBA74B4048533D997F1045408AABCABE2BA64B40384D9F1D700B45408AABCABE2BA64B40
49762	Ближне-Песочное	7	68	6955	42.044469999999997	42.129280000000001	55.367612000000001	55.338540999999999	0103000020E6100000010000000500000099D36531B105454075ADBD4F55AB4B4099D36531B1054540FFCEF6E80DAF4B4071033E3F8C104540FFCEF6E80DAF4B4071033E3F8C10454075ADBD4F55AB4B4099D36531B105454075ADBD4F55AB4B40
49724	Выкса	7	68	6980	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
32226	Шадрино	7	68	47	45.010033	45.035617000000002	56.824449000000001	56.813468	0103000020E61000000100000005000000BD70E7C248814640D82B2CB81F684C40BD70E7C248814640261C7A8B87694C4040170D198F844640261C7A8B87694C4040170D198F844640D82B2CB81F684C40BD70E7C248814640D82B2CB81F684C40
32299	Староустье	7	68	47	45.435493000000001	45.461500000000001	57.005363000000003	56.982269000000002	0103000020E610000001000000050000008751103CBEB74640F46F97FDBA7D4C408751103CBEB74640E2CD1ABCAF804C40508D976E12BB4640E2CD1ABCAF804C40508D976E12BB4640F46F97FDBA7D4C408751103CBEB74640F46F97FDBA7D4C40
872	Северный	7	68	47	45.821212000000003	45.835324999999997	56.963512999999999	56.955043000000003	0103000020E61000000100000005000000988A8D791DE946400AA359D93E7A4C40988A8D791DE94640AB22DC64547B4C40FE43FAEDEBEA4640AB22DC64547B4C40FE43FAEDEBEA46400AA359D93E7A4C40988A8D791DE946400AA359D93E7A4C40
32394	Русениха	7	68	47	45.351905000000002	45.373339000000001	56.909972000000003	56.897773000000001	0103000020E61000000100000005000000422619390BAD4640AC1DC539EA724C40422619390BAD46404B2366F679744C4022A98592C9AF46404B2366F679744C4022A98592C9AF4640AC1DC539EA724C40422619390BAD4640AC1DC539EA724C40
32343	Раскаты	7	68	47	45.368245999999999	45.394063000000003	56.952843999999999	56.940024999999999	0103000020E61000000100000005000000007157AF22AF464011363CBD52784C40007157AF22AF46404C18CDCAF6794C4026C808A870B246404C18CDCAF6794C4026C808A870B2464011363CBD52784C40007157AF22AF464011363CBD52784C40
32149	Погатиха	7	68	47	45.157249	45.175611000000004	56.924933000000003	56.916285999999999	0103000020E61000000100000005000000132A38BC209446402EE411DC48754C40132A38BC20944640DFFE5C3464764C40B0E8D66B7A964640DFFE5C3464764C40B0E8D66B7A9646402EE411DC48754C40132A38BC209446402EE411DC48754C40
49785	Осиновка	7	68	47	45.532305000000001	45.574992999999999	56.625287	56.617041	0103000020E61000000100000005000000A73FFB9122C4464044A51133FB4E4C40A73FFB9122C4464096CE876709504C40E736E15E99C9464096CE876709504C40E736E15E99C9464044A51133FB4E4C40A73FFB9122C4464044A51133FB4E4C40
366	Нестиары	7	68	47	45.324703999999997	45.345545000000001	56.56682	56.552514000000002	0103000020E61000000100000005000000B07092E68FA94640844A5CC7B8464C40B07092E68FA94640FF5BC98E8D484C40EE258DD13AAC4640FF5BC98E8D484C40EE258DD13AAC4640844A5CC7B8464C40B07092E68FA94640844A5CC7B8464C40
55	Марфино	7	68	47	45.394359999999999	45.410376999999997	56.788105000000002	56.773178000000001	0103000020E61000000100000005000000DF6C73637AB246404CFE277FF7624C40DF6C73637AB246403468E89FE0644C40EA03C93B87B446403468E89FE0644C40EA03C93B87B446404CFE277FF7624C40DF6C73637AB246404CFE277FF7624C40
1013	Малое Содомово	7	68	47	45.592959	45.611339000000001	57.042600999999998	57.030484999999999	0103000020E61000000100000005000000376F9C14E6CB46406002B7EEE6834C40376F9C14E6CB464071E316F373854C407AE2395B40CE464071E316F373854C407AE2395B40CE46406002B7EEE6834C40376F9C14E6CB46406002B7EEE6834C40
49757	Кучиново	7	68	47	45.363934	45.381047000000002	56.753819	56.746040999999998	0103000020E6100000010000000500000084F3A96395AE4640D13C80457E5F4C4084F3A96395AE46403D0D18247D604C40959EE925C6B046403D0D18247D604C40959EE925C6B04640D13C80457E5F4C4084F3A96395AE4640D13C80457E5F4C40
255	Красный Яр	7	68	47	45.719800999999997	45.746293000000001	56.775998999999999	56.752865999999997	0103000020E6100000010000000500000065506D7022DC46409A22C0E95D604C4065506D7022DC4640465D6BEF53634C40EB1D6E8786DF4640465D6BEF53634C40EB1D6E8786DF46409A22C0E95D604C4065506D7022DC46409A22C0E95D604C40
32499	Капустиха	7	68	47	45.355696000000002	45.378171999999999	56.837096000000003	56.826129000000002	0103000020E61000000100000005000000B5A84F7287AD46407BA35698BE694C40B5A84F7287AD464064CE33F6256B4C40A721AAF067B0464064CE33F6256B4C40A721AAF067B046407BA35698BE694C40B5A84F7287AD46407BA35698BE694C40
49811	Калиниха	7	68	47	45.420760999999999	45.456119000000001	56.821719999999999	56.799472999999999	0103000020E610000001000000050000005437177FDBB546407B849A2155664C405437177FDBB546400C3CF71E2E694C40C80A7E1B62BA46400C3CF71E2E694C40C80A7E1B62BA46407B849A2155664C405437177FDBB546407B849A2155664C40
31911	Задворка	7	68	47	45.461678999999997	45.484082999999998	56.807747999999997	56.793750000000003	0103000020E61000000100000005000000FF1F274C18BB46409A99999999654C40FF1F274C18BB464067B4554964674C4058C6866EF6BD464067B4554964674C4058C6866EF6BD46409A99999999654C40FF1F274C18BB46409A99999999654C40
619	Елкино	7	68	47	45.466529999999999	45.485143000000001	56.896548000000003	56.885505000000002	0103000020E610000001000000050000002B4D4A41B7BB4640E5B8533A58714C402B4D4A41B7BB4640A9A5B915C2724C401171732A19BE4640A9A5B915C2724C401171732A19BE4640E5B8533A58714C402B4D4A41B7BB4640E5B8533A58714C40
32466	Елдеж	7	68	47	45.235618000000002	45.254249000000002	56.647519000000003	56.636178999999998	0103000020E61000000100000005000000AA2C0ABB289E464074B33F506E514C40AA2C0ABB289E4640F24410E7E1524C403605323B8BA04640F24410E7E1524C403605323B8BA0464074B33F506E514C40AA2C0ABB289E464074B33F506E514C40
374	Егорово	7	68	47	45.612667999999999	45.636096000000002	56.597264000000003	56.583995999999999	0103000020E6100000010000000500000022A7AFE76BCE4640567F8461C04A4C4022A7AFE76BCE4640018A9125734C4C40E78EFE976BD14640018A9125734C4C40E78EFE976BD14640567F8461C04A4C4022A7AFE76BCE4640567F8461C04A4C40
32005	Докукино	7	68	47	45.684336000000002	45.701034999999997	56.731575999999997	56.722276000000001	0103000020E61000000100000005000000DCBC715298D74640C5573B8A735C4C40DCBC715298D74640ED444948A45D4C40F92CCF83BBD94640ED444948A45D4C40F92CCF83BBD94640C5573B8A735C4C40DCBC715298D74640C5573B8A735C4C40
511	Глухово	7	68	47	45.481613000000003	45.500163000000001	56.875329999999998	56.863782999999998	0103000020E610000001000000050000000B2AAA7EA5BD46409EEBFB70906E4C400B2AAA7EA5BD4640959A3DD00A704C40AAD5575705C04640959A3DD00A704C40AAD5575705C046409EEBFB70906E4C400B2AAA7EA5BD46409EEBFB70906E4C40
31963	Галибиха	7	68	47	45.600209	45.638646999999999	56.759408999999998	56.746775999999997	0103000020E61000000100000005000000E7E104A6D3CC464006B8205B965F4C40E7E104A6D3CC4640DFA4695034614C402158552FBFD14640DFA4695034614C402158552FBFD1464006B8205B965F4C40E7E104A6D3CC464006B8205B965F4C40
31639	Воскресенское	7	68	47	45.420670999999999	45.446606000000003	56.855541000000002	56.821375000000003	0103000020E6100000010000000500000014B01D8CD8B546404260E5D022694C4014B01D8CD8B546408EB1135E826D4C404419AA622AB946408EB1135E826D4C404419AA622AB946404260E5D022694C4014B01D8CD8B546404260E5D022694C40
634	Воздвиженское	7	68	47	45.596623999999998	45.629142999999999	56.966996999999999	56.952829000000001	0103000020E610000001000000050000001D01DC2C5ECC464017D7F84CF6794C401D01DC2C5ECC4640412AC58EC67B4C40F0C000C287D04640412AC58EC67B4C40F0C000C287D0464017D7F84CF6794C401D01DC2C5ECC464017D7F84CF6794C40
32154	Владимирское	7	68	47	45.101509	45.132114000000001	56.830359000000001	56.813419000000003	0103000020E61000000100000005000000F59F353FFE8C4640F778211D1E684C40F59F353FFE8C46403A782634496A4C4000AC8E1CE99046403A782634496A4C4000AC8E1CE9904640F778211D1E684C40F59F353FFE8C4640F778211D1E684C40
916	Большое Поле	7	68	47	45.920726999999999	45.945233999999999	56.923502999999997	56.913254000000002	0103000020E61000000100000005000000A8C5E061DAF546407978CF81E5744C40A8C5E061DAF546400261A75835764C409C887E6DFDF846400261A75835764C409C887E6DFDF846407978CF81E5744C40A8C5E061DAF546407978CF81E5744C40
771	Большое Иевлево	7	68	47	45.677894999999999	45.709291	56.940634000000003	56.930075000000002	0103000020E610000001000000050000009B8F6B43C5D64640E2E995B20C774C409B8F6B43C5D64640BAC0E5B166784C406F2C280CCADA4640BAC0E5B166784C406F2C280CCADA4640E2E995B20C774C409B8F6B43C5D64640E2E995B20C774C40
744	Большие Отары	7	68	47	45.495365999999997	45.528495999999997	56.970441999999998	56.955897	0103000020E6100000010000000500000071C6302768BF464019AC38D55A7A4C4071C6302768BF464019558671377C4C408D08C6C1A5C3464019558671377C4C408D08C6C1A5C3464019AC38D55A7A4C4071C6302768BF464019AC38D55A7A4C40
31847	Богородское	7	68	47	45.509172999999997	45.565165	56.786937000000002	56.767702999999997	0103000020E61000000100000005000000CB80B3942CC146404205871744624C40CB80B3942CC146409581035ABA644C4003ECA35357C846409581035ABA644C4003ECA35357C846404205871744624C40CB80B3942CC146404205871744624C40
32091	Благовещенское	7	68	47	45.304582000000003	45.317841000000001	56.946202	56.937398000000002	0103000020E61000000100000005000000A379008BFCA64640FCAA5CA8FC774C40A379008BFCA6464074B4AA251D794C40FA298E03AFA8464074B4AA251D794C40FA298E03AFA84640FCAA5CA8FC774C40A379008BFCA64640FCAA5CA8FC774C40
32263	Бараново	7	68	47	45.235888000000003	45.255192999999998	56.815345000000001	56.806165999999997	0103000020E610000001000000050000006AC2F693319E4640D5928E7230674C406AC2F693319E464083FA96395D684C4085950A2AAAA0464083FA96395D684C4085950A2AAAA04640D5928E7230674C406AC2F693319E4640D5928E7230674C40
32037	Асташиха	7	68	47	45.316431000000001	45.336517000000001	56.931494999999998	56.917012999999997	0103000020E6100000010000000500000065389ECF80A84640E08096AE60754C4065389ECF80A846409AB1683A3B774C4026C632FD12AB46409AB1683A3B774C4026C632FD12AB4640E08096AE60754C4065389ECF80A84640E08096AE60754C40
50080	Шереметьево	7	68	1540	45.959553	45.974555000000002	56.091025000000002	56.080151000000001	0103000020E61000000100000005000000ACE3F8A1D2FA4640F0DE5163420A4C40ACE3F8A1D2FA4640280F0BB5A60B4C409F93DE37BEFC4640280F0BB5A60B4C409F93DE37BEFC4640F0DE5163420A4C40ACE3F8A1D2FA4640F0DE5163420A4C40
31557	Чугуны	7	68	1540	45.671022999999998	45.723188	56.071041999999998	56.057765000000003	0103000020E6100000010000000500000091EEE714E4D546403EEDF0D764074C4091EEE714E4D546403B527DE717094C40096EA46C91DC46403B527DE717094C40096EA46C91DC46403EEDF0D764074C4091EEE714E4D546403EEDF0D764074C40
31483	Фокино	7	68	1540	45.786169000000001	45.840606999999999	56.172811000000003	56.148980000000002	0103000020E610000001000000050000008410902FA1E4464009E1D1C611134C408410902FA1E44640CDB1BCAB1E164C40F3E49A0299EB4640CDB1BCAB1E164C40F3E49A0299EB464009E1D1C611134C408410902FA1E4464009E1D1C611134C40
31464	Тришкино	7	68	1540	45.953668999999998	45.976100000000002	55.889048000000003	55.877420000000001	0103000020E61000000100000005000000C11A67D311FA46409C6D6E4C4FF04B40C11A67D311FA464080492A53CCF14B4014D044D8F0FC464080492A53CCF14B4014D044D8F0FC46409C6D6E4C4FF04B40C11A67D311FA46409C6D6E4C4FF04B40
31390	Сомовка	7	68	1540	45.69782	45.744469000000002	56.137785999999998	56.124747999999997	0103000020E61000000100000005000000533F6F2A52D94640E61E12BEF70F4C40533F6F2A52D946405FECBDF8A2114C4063F19BC24ADF46405FECBDF8A2114C4063F19BC24ADF4640E61E12BEF70F4C40533F6F2A52D94640E61E12BEF70F4C40
31340	Семьяны	7	68	1540	45.964951999999997	46.003813000000001	56.032131999999997	56.011584999999997	0103000020E61000000100000005000000DA1A118C83FB4640E40F069E7B014C40DA1A118C83FB4640D993C0E61C044C405B26C3F17C004740D993C0E61C044C405B26C3F17C004740E40F069E7B014C40DA1A118C83FB4640E40F069E7B014C40
31280	Разнежье	7	68	1540	45.668948	45.690426000000002	56.200097	56.173983	0103000020E61000000100000005000000C05C8B16A0D54640AD872F1345164C40C05C8B16A0D546408C834BC79C194C40702711E15FD846408C834BC79C194C40702711E15FD84640AD872F1345164C40C05C8B16A0D54640AD872F1345164C40
31223	Покров-Майдан	7	68	1540	45.779457999999998	45.819622000000003	55.973370000000003	55.958517000000001	0103000020E61000000100000005000000834D9D47C5E346407CD45FAFB0FA4B40834D9D47C5E346402A745E6397FC4B40838AAA5FE9E846402A745E6397FC4B40838AAA5FE9E846407CD45FAFB0FA4B40834D9D47C5E346407CD45FAFB0FA4B40
31147	Отары	7	68	1540	45.880428999999999	45.908321999999998	56.126964999999998	56.117224999999998	0103000020E6100000010000000500000099B9C0E5B1F0464005A3923A010F4C4099B9C0E5B1F046404A5E9D6340104C40601E32E543F446404A5E9D6340104C40601E32E543F4464005A3923A010F4C4099B9C0E5B1F0464005A3923A010F4C40
31122	Осинки	7	68	1540	45.826538999999997	45.860900000000001	56.102347999999999	56.094470000000001	0103000020E610000001000000050000002CEFAA07CCE94640003ACC97170C4C402CEFAA07CCE94640CF6740BD190D4C402E90A0F831EE4640CF6740BD190D4C402E90A0F831EE4640003ACC97170C4C402CEFAA07CCE94640003ACC97170C4C40
31180	Огнев-Майдан	7	68	1540	45.879100000000001	45.924869000000001	56.039188000000003	56.009320000000002	0103000020E61000000100000005000000F1F44A5986F046407099D36531014C40F1F44A5986F04640A532C51C04054C40C80A7E1B62F64640A532C51C04054C40C80A7E1B62F646407099D36531014C40F1F44A5986F046407099D36531014C40
31067	Михайловское	7	68	1540	45.753138	45.802509000000001	56.197398	56.174725000000002	0103000020E61000000100000005000000FBAF73D366E04640956588635D164C40FBAF73D366E04640DD25715644194C4072DF6A9DB8E64640DD25715644194C4072DF6A9DB8E64640956588635D164C40FBAF73D366E04640956588635D164C40
30966	Львово	7	68	1540	45.529232999999998	45.563090000000003	56.053019999999997	56.044820000000001	0103000020E61000000100000005000000637B2DE8BDC34640761A69A9BC054C40637B2DE8BDC346405704FF5BC9064C40325A475513C846405704FF5BC9064C40325A475513C84640761A69A9BC054C40637B2DE8BDC34640761A69A9BC054C40
30988	Лысая Гора	7	68	1540	45.950209999999998	45.966774999999998	56.110756000000002	56.103422000000002	0103000020E61000000100000005000000842A357BA0F94640EDD79DEE3C0D4C40842A357BA0F94640FBEAAA402D0E4C4092CB7F48BFFB4640FBEAAA402D0E4C4092CB7F48BFFB4640EDD79DEE3C0D4C40842A357BA0F94640EDD79DEE3C0D4C40
30885	Липовка	7	68	1540	45.605885999999998	45.637920000000001	56.030954999999999	56.015977999999997	0103000020E61000000100000005000000588D25AC8DCD46404DBA2D910B024C40588D25AC8DCD4640E7525C55F6034C406FBBD05CA7D14640E7525C55F6034C406FBBD05CA7D146404DBA2D910B024C40588D25AC8DCD46404DBA2D910B024C40
30758	Кузьмияр	7	68	1540	45.473241000000002	45.495178000000003	56.387664000000001	56.373854000000001	0103000020E610000001000000050000002C103D2993BC464049BDA772DA2F4C402C103D2993BC464014EB54F99E314C406FD921FE61BF464014EB54F99E314C406FD921FE61BF464049BDA772DA2F4C402C103D2993BC464049BDA772DA2F4C40
30644	Криуши	7	68	1540	45.762058000000003	45.785549000000003	56.081682999999998	56.063906000000003	0103000020E61000000100000005000000DDD3D51D8BE14640540262122E084C40DDD3D51D8BE14640D0D1AA96740A4C40E833A0DE8CE44640D0D1AA96740A4C40E833A0DE8CE44640540262122E084C40DDD3D51D8BE14640540262122E084C40
30797	Красная Горка	7	68	1540	45.598123999999999	45.620879000000002	56.010080000000002	56.000714000000002	0103000020E61000000100000005000000F279C5538FCC46401E53776517004C40F279C5538FCC4640FE2B2B4D4A014C40F8E28BF678CF4640FE2B2B4D4A014C40F8E28BF678CF46401E53776517004C40F279C5538FCC46401E53776517004C40
30882	Кекино	7	68	1540	46.000838999999999	46.031553000000002	55.910589000000002	55.896186	0103000020E61000000100000005000000DAC70A7E1B00474008910C39B6F24B40DAC70A7E1B004740768C2B2E8EF44B409C8BBFED09044740768C2B2E8EF44B409C8BBFED0904474008910C39B6F24B40DAC70A7E1B00474008910C39B6F24B40
30674	Каменка	7	68	1540	45.562165	45.606684999999999	56.210811999999997	56.174819999999997	0103000020E6100000010000000500000059FAD005F5C74640E657738060164C4059FAD005F5C746405BCD3AE3FB1A4C40A4FCA4DAA7CD46405BCD3AE3FB1A4C40A4FCA4DAA7CD4640E657738060164C4059FAD005F5C74640E657738060164C40
26612	Ивановка	7	68	1540	45.955429000000002	45.970809000000003	55.985709999999997	55.972422999999999	0103000020E6100000010000000500000033535A7F4BFA464069705B5B78FC4B4033535A7F4BFA46408AABCABE2BFE4B40CCD4247843FC46408AABCABE2BFE4B40CCD4247843FC464069705B5B78FC4B4033535A7F4BFA464069705B5B78FC4B40
30562	Елвашка	7	68	1540	45.816864000000002	45.839942000000001	56.034385	56.015269000000004	0103000020E61000000100000005000000CFA3E2FF8EE8464042D2A755F4014C40CFA3E2FF8EE846408A3C49BA66044C40B7442E3883EB46408A3C49BA66044C40B7442E3883EB464042D2A755F4014C40CFA3E2FF8EE8464042D2A755F4014C40
26604	Воротынец	7	68	1540	45.826171000000002	45.883994999999999	56.070771000000001	56.049821999999999	0103000020E61000000100000005000000AAF3A8F8BFE94640874F3A9160064C40AAF3A8F8BFE94640AB402D060F094C40EC6987BF26F14640AB402D060F094C40EC6987BF26F14640874F3A9160064C40AAF3A8F8BFE94640874F3A9160064C40
30239	Васильсурск	7	68	1540	45.993563000000002	46.043958000000003	56.140569999999997	56.115679999999998	0103000020E6100000010000000500000001C287122DFF464090662C9ACE0E4C4001C287122DFF46403C66A032FE114C40E4326E6AA00547403C66A032FE114C40E4326E6AA005474090662C9ACE0E4C4001C287122DFF464090662C9ACE0E4C40
30355	Быковка	7	68	1540	45.662712999999997	45.700513999999998	55.994159000000003	55.978149999999999	0103000020E6100000010000000500000028D192C7D3D446408C4AEA0434FD4B4028D192C7D3D446401503249A40FF4B40F0315871AAD946401503249A40FF4B40F0315871AAD946408C4AEA0434FD4B4028D192C7D3D446408C4AEA0434FD4B40
30462	Березов Майдан	7	68	1540	46.007801000000001	46.029584999999997	55.972009999999997	55.954566	0103000020E6100000010000000500000024F0879FFF004740D0EFFB372FFA4B4024F0879FFF00474046B1DCD26AFC4B40E0B9F770C903474046B1DCD26AFC4B40E0B9F770C9034740D0EFFB372FFA4B4024F0879FFF004740D0EFFB372FFA4B40
30467	Белогорка	7	68	1540	45.654009000000002	45.677185000000001	56.120984	56.108628000000003	0103000020E6100000010000000500000014252191B6D3464007B7B585E70D4C4014252191B6D346406DAB59677C0F4C40BF2B82FFADD646406DAB59677C0F4C40BF2B82FFADD6464007B7B585E70D4C4014252191B6D3464007B7B585E70D4C40
30380	Белавка	7	68	1540	46.065463999999999	46.110289999999999	55.998499000000002	55.988529999999997	0103000020E610000001000000050000005D88D51F61084740B48EAA2688FE4B405D88D51F610847405B0BB3D0CEFF4B40B58993FB1D0E47405B0BB3D0CEFF4B40B58993FB1D0E4740B48EAA2688FE4B405D88D51F61084740B48EAA2688FE4B40
30267	Ахпаевка	7	68	1540	45.748269000000001	45.776090000000003	56.022216999999998	56.004826000000001	0103000020E6100000010000000500000029CE5147C7DF4640D3156C239E004C4029CE5147C7DF46402635B401D8024C405760C8EA56E346402635B401D8024C405760C8EA56E34640D3156C239E004C4029CE5147C7DF4640D3156C239E004C40
29115	Юганец	7	68	888	43.212108999999998	43.245958000000002	56.258927999999997	56.240403000000001	0103000020E61000000100000005000000F8174163269B45401E6E8786C51E4C40F8174163269B454064027E8D24214C4044183F8D7B9F454064027E8D24214C4044183F8D7B9F45401E6E8786C51E4C40F8174163269B45401E6E8786C51E4C40
29792	Центральный	7	68	888	42.774009999999997	42.811362000000003	56.310203000000001	56.279302000000001	0103000020E6100000010000000500000073637AC2126345408CDAFD2AC0234C4073637AC212634540800F5EBBB4274C40CC9BC3B5DA674540800F5EBBB4274C40CC9BC3B5DA6745408CDAFD2AC0234C4073637AC2126345408CDAFD2AC0234C40
29872	Фролищи	7	68	888	42.627988999999999	42.666930999999998	56.433231999999997	56.406635000000001	0103000020E61000000100000005000000B69F8CF16150454059349D9D0C344C40B69F8CF16150454053CA6B2574374C4023D8B8FE5D55454053CA6B2574374C4023D8B8FE5D55454059349D9D0C344C40B69F8CF16150454059349D9D0C344C40
29634	Смолино	7	68	888	43.058228	43.106062999999999	56.292757999999999	56.267152000000003	0103000020E6100000010000000500000012DBDD0374874540CF87670932224C4012DBDD037487454039D2191879254C406728EE78938D454039D2191879254C406728EE78938D4540CF87670932224C4012DBDD0374874540CF87670932224C40
28797	Решетиха	7	68	888	43.273319999999998	43.313817	56.226714000000001	56.209440999999998	0103000020E61000000100000005000000DEAB5626FCA2454084B872F6CE1A4C40DEAB5626FCA24540CEC5DFF6041D4C40E4F6CB272BA84540CEC5DFF6041D4C40E4F6CB272BA8454084B872F6CE1A4C40DEAB5626FCA2454084B872F6CE1A4C40
29430	Новосмолинский	7	68	888	43.014642000000002	43.057006000000001	56.292268	56.279131999999997	0103000020E61000000100000005000000F392FFC9DF8145402FA2ED98BA234C40F392FFC9DF8145406BD5AE0969254C4080D6FCF84B8745406BD5AE0969254C4080D6FCF84B8745402FA2ED98BA234C40F392FFC9DF8145402FA2ED98BA234C40
29537	Мячково	7	68	888	42.775770999999999	42.814695	56.238731999999999	56.223751999999998	0103000020E61000000100000005000000B517D1764C6345401135D1E7A31C4C40B517D1764C6345401C412AC58E1E4C407C9BFEEC476845401C412AC58E1E4C407C9BFEEC476845401135D1E7A31C4C40B517D1764C6345401135D1E7A31C4C40
6817	Мулино	7	68	888	42.930459999999997	42.993675000000003	56.331268999999999	56.301383999999999	0103000020E610000001000000050000003A1E335019774540D2C43BC093264C403A1E335019774540DD96C805672A4C4029ED0DBE307F4540DD96C805672A4C4029ED0DBE307F4540D2C43BC093264C403A1E335019774540D2C43BC093264C40
29186	Красная Горка	7	68	888	43.046514000000002	43.083264	56.220137999999999	56.200228000000003	0103000020E610000001000000050000003067B62BF48545402BDF3312A1194C403067B62BF4854540AD4D637B2D1C4C4092770E65A88A4540AD4D637B2D1C4C4092770E65A88A45402BDF3312A1194C403067B62BF48545402BDF3312A1194C40
29240	Ильиногорск	7	68	888	42.938087000000003	42.997753000000003	56.235399999999998	56.218136000000001	0103000020E61000000100000005000000C1E61C3C13784540460A65E1EB1B4C40C1E61C3C137845403CBD5296211E4C40323ECC5EB67F45403CBD5296211E4C40323ECC5EB67F4540460A65E1EB1B4C40C1E61C3C13784540460A65E1EB1B4C40
19877	Ильино	7	68	888	42.886856000000002	42.938797000000001	56.238802	56.223601000000002	0103000020E610000001000000050000007521567F847145402C2D23F59E1C4C407521567F84714540151C5E10911E4C409D4A06802A784540151C5E10911E4C409D4A06802A7845402C2D23F59E1C4C407521567F847145402C2D23F59E1C4C40
29392	Золино	7	68	888	42.964821000000001	42.997627999999999	56.289234999999998	56.267741999999998	0103000020E610000001000000050000003CBF28417F7B454000E2AE5E45224C403CBF28417F7B4540E5ED08A705254C4075C93846B27F4540E5ED08A705254C4075C93846B27F454000E2AE5E45224C403CBF28417F7B454000E2AE5E45224C40
9050	Володарск	7	68	888	43.127640999999997	43.229050999999998	56.247830999999998	56.2089	0103000020E610000001000000050000007A50508A569045403411363CBD1A4C407A50508A56904540ADF71BEDB81F4C40DC0E0D8B519D4540ADF71BEDB81F4C40DC0E0D8B519D45403411363CBD1A4C407A50508A569045403411363CBD1A4C40
28722	Суморьево	7	68	1818	42.884439999999998	42.915917	54.796579000000001	54.780107000000001	0103000020E610000001000000050000001AA3755435714540BA30D28BDA634B401AA375543571454017D7F84CF6654B40DB6CACC43C75454017D7F84CF6654B40DB6CACC43C754540BA30D28BDA634B401AA3755435714540BA30D28BDA634B40
28596	Сарминский Майдан	7	68	1818	42.965612	42.991726	54.869425	54.853422999999999	0103000020E6100000010000000500000005508C2C997B4540BD5301F73C6D4B4005508C2C997B454093A98251496F4B40E44BA8E0F07E454093A98251496F4B40E44BA8E0F07E4540BD5301F73C6D4B4005508C2C997B4540BD5301F73C6D4B40
28316	Починки	7	68	1818	42.681977000000003	42.707759000000003	54.852231000000003	54.837865999999998	0103000020E61000000100000005000000E6CFB7054B57454015376E313F6B4B40E6CFB7054B57454096D1C8E7156D4B408F39CFD8975A454096D1C8E7156D4B408F39CFD8975A454015376E313F6B4B40E6CFB7054B57454015376E313F6B4B40
28647	Полховский Майдан	7	68	1818	42.627495000000003	42.659295	54.864907000000002	54.840319000000001	0103000020E61000000100000005000000A7B393C1515045408D9AAF928F6B4B40A7B393C1515045406E8AC745B56E4B404AB54FC7635445406E8AC745B56E4B404AB54FC7635445408D9AAF928F6B4B40A7B393C1515045408D9AAF928F6B4B40
28220	Новоселки	7	68	1818	42.746035999999997	42.775303000000001	54.848888000000002	54.830207999999999	0103000020E61000000100000005000000BFD18E1B7E5F454054707841446A4B40BFD18E1B7E5F4540C2FBAA5CA86C4B40CFBEF2203D634540C2FBAA5CA86C4B40CFBEF2203D63454054707841446A4B40BFD18E1B7E5F454054707841446A4B40
28439	Нарышкино	7	68	1818	43.028897999999998	43.071640000000002	54.896320000000003	54.869543999999998	0103000020E61000000100000005000000BC75FEEDB28345406D37C1374D6F4B40BC75FEEDB283454018601F9DBA724B40F08AE07F2B89454018601F9DBA724B40F08AE07F2B8945406D37C1374D6F4B40BC75FEEDB28345406D37C1374D6F4B40
28411	Мотызлей	7	68	1818	42.884988	42.923391000000002	54.924841999999998	54.897179000000001	0103000020E610000001000000050000001DAD6A494771454039D4EFC2D6724B401DAD6A4947714540CEFBFF3861764B40DB3521AD31764540CEFBFF3861764B40DB3521AD3176454039D4EFC2D6724B401DAD6A494771454039D4EFC2D6724B40
28333	Линейка	7	68	1818	42.518915	42.543170000000003	54.843279000000003	54.828552999999999	0103000020E61000000100000005000000B13385CE6B424540580053060E6A4B40B13385CE6B424540A933F790F06B4B408C15359886454540A933F790F06B4B408C15359886454540580053060E6A4B40B13385CE6B424540580053060E6A4B40
28666	Куриха	7	68	1818	42.849935000000002	42.86553	55.008541999999998	55.000988	0103000020E61000000100000005000000E65C8AABCA6C45401FD8F15F20804B40E65C8AABCA6C45403B527DE717814B407BDAE1AFC96E45403B527DE717814B407BDAE1AFC96E45401FD8F15F20804B40E65C8AABCA6C45401FD8F15F20804B40
28267	Криуша	7	68	1818	42.640799000000001	42.668449000000003	54.831384999999997	54.808675000000001	0103000020E610000001000000050000009E279EB305524540E10B93A982674B409E279EB30552454046B1DCD26A6A4B409F05A1BC8F55454046B1DCD26A6A4B409F05A1BC8F554540E10B93A982674B409E279EB305524540E10B93A982674B40
28530	Илев	7	68	1818	42.971783000000002	43.016832999999998	54.967941000000003	54.941782000000003	0103000020E6100000010000000500000086E7A562637C454012FB04508C784B4086E7A562637C454091BA9D7DE57B4B402D3F70952782454091BA9D7DE57B4B402D3F70952782454012FB04508C784B4086E7A562637C454012FB04508C784B40
28494	Заря	7	68	1818	43.097124999999998	43.117668999999999	54.833423000000003	54.822479999999999	0103000020E61000000100000005000000DF4F8D976E8C45409ACE4E0647694B40DF4F8D976E8C4540FB5DD89AAD6A4B4063601DC70F8F4540FB5DD89AAD6A4B4063601DC70F8F45409ACE4E0647694B40DF4F8D976E8C45409ACE4E0647694B40
27729	Вознесенское	7	68	1818	42.710822	42.801220000000001	54.906689	54.881059	0103000020E610000001000000050000007FA31D37FC5A4540596C938AC6704B407FA31D37FC5A45404C5299620E744B40587380608E6645404C5299620E744B40587380608E664540596C938AC6704B407FA31D37FC5A4540596C938AC6704B40
28069	Варнаево	7	68	1818	42.721117	42.752837	54.939869000000002	54.922772000000002	0103000020E6100000010000000500000079CBD58F4D5C45400FD594641D764B4079CBD58F4D5C45401AC39CA04D784B40001C7BF65C6045401AC39CA04D784B40001C7BF65C6045400FD594641D764B4079CBD58F4D5C45400FD594641D764B40
28144	Бутаково	7	68	1818	42.767515000000003	42.791876999999999	54.810906000000003	54.790869000000001	0103000020E61000000100000005000000401878EE3D624540CA3505323B654B40401878EE3D624540AA108FC4CB674B4030BABC395C654540AA108FC4CB674B4030BABC395C654540CA3505323B654B40401878EE3D624540CA3505323B654B40
28056	Букалей	7	68	1818	42.677145000000003	42.700519	54.960223999999997	54.948179000000003	0103000020E6100000010000000500000031D3F6AFAC56454083E0F1ED5D794B4031D3F6AFAC564540CA6ABA9EE87A4B40029D499BAA594540CA6ABA9EE87A4B40029D499BAA59454083E0F1ED5D794B4031D3F6AFAC56454083E0F1ED5D794B40
28183	Борки	7	68	1818	42.834933999999997	42.855809999999998	54.829087000000001	54.817245999999997	0103000020E61000000100000005000000C328081EDF6A4540B66455849B684B40C328081EDF6A4540F644D7851F6A4B407DCB9C2E8B6D4540F644D7851F6A4B407DCB9C2E8B6D4540B66455849B684B40C328081EDF6A4540B66455849B684B40
27998	Благодатовка	7	68	1818	42.703617999999999	42.724539999999998	55.016604999999998	55.003641999999999	0103000020E610000001000000050000003F709527105A45402E724F5777804B403F709527105A45409CF9D51C20824B4069520ABABD5C45409CF9D51C20824B4069520ABABD5C45402E724F5777804B403F709527105A45402E724F5777804B40
27398	Бахтызино	7	68	1818	42.859636999999999	42.900044000000001	54.869616000000001	54.854854000000003	0103000020E610000001000000050000003DB7D095086E45406A6D1ADB6B6D4B403DB7D095086E4540070ABC934F6F4B40037B4CA434734540070ABC934F6F4B40037B4CA4347345406A6D1ADB6B6D4B403DB7D095086E45406A6D1ADB6B6D4B40
27925	Аламасово	7	68	1818	43.131323999999999	43.163680999999997	54.912976999999998	54.894258999999998	0103000020E6100000010000000500000007978E39CF904540AB93331477724B4007978E39CF90454006802A6EDC744B4000FDBE7FF394454006802A6EDC744B4000FDBE7FF3944540AB93331477724B4007978E39CF904540AB93331477724B40
21964	имени М. И.Калинина	7	68	1446	45.084530999999998	45.134369	58.012238000000004	57.980041	0103000020E61000000100000005000000C43F6CE9D18A46409CDEC5FB71FD4C40C43F6CE9D18A46405DE2C80391014D40514CDE00339146405DE2C80391014D40514CDE00339146409CDEC5FB71FD4C40C43F6CE9D18A46409CDEC5FB71FD4C40
16411	Турань	7	68	1446	45.340415999999998	45.365048000000002	57.942270000000001	57.931677999999998	0103000020E610000001000000050000007F8461C092AB46408B33863941F74C407F8461C092AB46403F00A94D9CF84C4030BC92E4B9AE46403F00A94D9CF84C4030BC92E4B9AE46408B33863941F74C407F8461C092AB46408B33863941F74C40
27270	Стрелица	7	68	1446	45.289248000000001	45.309361000000003	57.743082000000001	57.729937	0103000020E610000001000000050000007A37161406A54640F7915B936EDD4C407A37161406A54640861F9C4F1DDF4C4035D4282499A74640861F9C4F1DDF4C4035D4282499A74640F7915B936EDD4C407A37161406A54640F7915B936EDD4C40
27296	Скулябиха	7	68	1446	45.229320999999999	45.246102	57.715470000000003	57.704498000000001	0103000020E610000001000000050000009CA4F9635A9D4640780C8FFD2CDA4C409CA4F9635A9D464073A25D8594DB4C4077BD3445809F464073A25D8594DB4C4077BD3445809F4640780C8FFD2CDA4C409CA4F9635A9D4640780C8FFD2CDA4C40
27548	Скрябино	7	68	1446	45.873745999999997	45.896346999999999	58.007728	58.000779000000001	0103000020E610000001000000050000006281AFE8D6EF464005C3B98619004D406281AFE8D6EF4640BAA1293BFD004D40116F9D7FBBF24640BAA1293BFD004D40116F9D7FBBF2464005C3B98619004D406281AFE8D6EF464005C3B98619004D40
27608	Пустошь	7	68	1446	45.809578999999999	45.825533	57.969790000000003	57.957377000000001	0103000020E61000000100000005000000A243E048A0E74640A7785C548BFA4C40A243E048A0E7464072FE261422FC4C406762BA10ABE9464072FE261422FC4C406762BA10ABE94640A7785C548BFA4C40A243E048A0E74640A7785C548BFA4C40
27699	Новоуспенское	7	68	1446	46.018895000000001	46.047426000000002	57.757519000000002	57.738911999999999	0103000020E610000001000000050000006A87BF266B0247409C4F1DAB94DE4C406A87BF266B024740A08CF161F6E04C40747D1F0E12064740A08CF161F6E04C40747D1F0E120647409C4F1DAB94DE4C406A87BF266B0247409C4F1DAB94DE4C40
16344	Новопокровское	7	68	1446	45.168936000000002	45.198841000000002	57.942484999999998	57.923442999999999	0103000020E61000000100000005000000FC8EE1B19F9546402D5C566133F64C40FC8EE1B19F9546403BFC3559A3F84C404E0D349F739946403BFC3559A3F84C404E0D349F739946402D5C566133F64C40FC8EE1B19F9546402D5C566133F64C40
27169	Махони	7	68	1446	45.416601999999997	45.431083000000001	57.836919000000002	57.828122	0103000020E610000001000000050000005EB9DE3653B546408F8CD5E6FFE94C405EB9DE3653B5464055336B2920EB4C40486E4DBA2DB7464055336B2920EB4C40486E4DBA2DB746408F8CD5E6FFE94C405EB9DE3653B546408F8CD5E6FFE94C40
27641	Маркуша	7	68	1446	45.847605000000001	45.870511999999998	57.879899000000002	57.867148	0103000020E610000001000000050000008A7615527EEC46405A65A6B4FEEE4C408A7615527EEC46403D64CA87A0F04C404563EDEF6CEF46403D64CA87A0F04C404563EDEF6CEF46405A65A6B4FEEE4C408A7615527EEC46405A65A6B4FEEE4C40
26999	Крутцы	7	68	1446	45.723466000000002	45.744019999999999	57.864179999999998	57.857731000000001	0103000020E610000001000000050000004CE2AC889ADC4640F8E12021CAED4C404CE2AC889ADC4640BBED42739DEE4C40F3C81F0C3CDF4640BBED42739DEE4C40F3C81F0C3CDF4640F8E12021CAED4C404CE2AC889ADC4640F8E12021CAED4C40
27375	Галкино	7	68	1446	45.219780999999998	45.237288999999997	57.824815000000001	57.812783000000003	0103000020E610000001000000050000001EA4A7C8219C464055DFF94509E84C401EA4A7C8219C46400820B58993E94C40AB59677C5F9E46400820B58993E94C40AB59677C5F9E464055DFF94509E84C401EA4A7C8219C464055DFF94509E84C40
27233	Волынцы	7	68	1446	45.469664999999999	45.486967	57.813952999999998	57.805874000000003	0103000020E61000000100000005000000B58993FB1DBC46402E5915E126E74C40B58993FB1DBC464094BDA59C2FE84C40999D45EF54BE464094BDA59C2FE84C40999D45EF54BE46402E5915E126E74C40B58993FB1DBC46402E5915E126E74C40
26608	Ветлуга	7	68	1446	45.734228000000002	45.816164000000001	57.874965000000003	57.841835000000003	0103000020E610000001000000050000005CE7DF2EFBDD464068D0D03FC1EB4C405CE7DF2EFBDD4640841266DAFEEF4C401616DC0F78E84640841266DAFEEF4C401616DC0F78E8464068D0D03FC1EB4C405CE7DF2EFBDD464068D0D03FC1EB4C40
49767	Ветлуга	7	68	1446	45.734228000000002	45.816164000000001	57.874965000000003	57.841835000000003	0103000020E610000001000000050000005CE7DF2EFBDD464068D0D03FC1EB4C405CE7DF2EFBDD4640841266DAFEEF4C401616DC0F78E84640841266DAFEEF4C401616DC0F78E8464068D0D03FC1EB4C405CE7DF2EFBDD464068D0D03FC1EB4C40
27075	Белышево	7	68	1446	45.497593999999999	45.556029000000002	57.878960999999997	57.85707	0103000020E61000000100000005000000C9570229B1BF4640FD304278B4ED4C40C9570229B1BF4640CFBA46CB81F04C40555051F52BC74640CFBA46CB81F04C40555051F52BC74640FD304278B4ED4C40C9570229B1BF4640FD304278B4ED4C40
26022	Яковцево	7	68	1675	42.628438000000003	42.654713999999998	55.902918999999997	55.888542999999999	0103000020E6100000010000000500000026C808A8705045407C0BEBC6BBF14B4026C808A870504540F0F78BD992F34B40DE1D19ABCD534540F0F78BD992F34B40DE1D19ABCD5345407C0BEBC6BBF14B4026C808A8705045407C0BEBC6BBF14B40
26328	Чулково	7	68	1675	42.742640999999999	42.770479999999999	55.962181000000001	55.947463999999997	0103000020E6100000010000000500000099D53BDC0E5F45409411178046F94B4099D53BDC0E5F454092EA3BBF28FB4B406D1CB1169F62454092EA3BBF28FB4B406D1CB1169F6245409411178046F94B4099D53BDC0E5F45409411178046F94B40
26036	Филинское	7	68	1675	42.461899000000003	42.524296	55.770097	55.737228000000002	0103000020E610000001000000050000000E87A5811F3B454006D9B27C5DDE4B400E87A5811F3B4540B5DFDA8992E24B4039B69E211C434540B5DFDA8992E24B4039B69E211C43454006D9B27C5DDE4B400E87A5811F3B454006D9B27C5DDE4B40
25887	Федурино	7	68	1675	42.722203999999998	42.752153999999997	55.847295000000003	55.833637000000003	0103000020E610000001000000050000002B85402E715C454027DE019EB4EA4B402B85402E715C45403C889D2974EC4B401DC70F95466045403C889D2974EC4B401DC70F954660454027DE019EB4EA4B402B85402E715C454027DE019EB4EA4B40
25719	Сколково	7	68	1675	42.566769000000001	42.581761	55.841735999999997	55.834007	0103000020E610000001000000050000007DB1F7E28B4845404AD1CABDC0EA4B407DB1F7E28B484540D4EE5701BEEB4B404C8BFA24774A4540D4EE5701BEEB4B404C8BFA24774A45404AD1CABDC0EA4B407DB1F7E28B4845404AD1CABDC0EA4B40
25419	Сергеево	7	68	1675	42.921863999999999	42.940368999999997	55.835290999999998	55.823788	0103000020E610000001000000050000000CAEB9A3FF7545402B6B9BE271E94B400CAEB9A3FF75454052D2C3D0EAEA4B400B96EA025E78454052D2C3D0EAEA4B400B96EA025E7845402B6B9BE271E94B400CAEB9A3FF7545402B6B9BE271E94B40
25481	Польцо	7	68	1675	42.791742999999997	42.816662000000001	55.843904000000002	55.823090000000001	0103000020E6100000010000000500000020EBA9D55765454013D55B035BE94B4020EBA9D557654540577BD80B05EC4B4067F1626188684540577BD80B05EC4B4067F162618868454013D55B035BE94B4020EBA9D55765454013D55B035BE94B40
25835	Новоселки	7	68	1675	42.665826000000003	42.707363999999998	55.819372999999999	55.784540999999997	0103000020E61000000100000005000000CB694FC93955454081AFE8D66BE44B40CB694FC939554540DA1CE736E1E84B40122F4FE78A5A4540DA1CE736E1E84B40122F4FE78A5A454081AFE8D66BE44B40CB694FC93955454081AFE8D66BE44B40
25344	Медоварцево	7	68	1675	42.849432	42.863517999999999	55.836064	55.819893999999998	0103000020E6100000010000000500000083161230BA6C4540E3175E49F2E84B4083161230BA6C454075AE282504EB4B40F0C000C2876E454075AE282504EB4B40F0C000C2876E4540E3175E49F2E84B4083161230BA6C4540E3175E49F2E84B40
25956	Лесниково	7	68	1675	42.632139000000002	42.650995000000002	55.844025000000002	55.828747999999997	0103000020E6100000010000000500000059C345EEE95045400D501A6A14EA4B4059C345EEE9504540D200DE0209EC4B40056EDDCD53534540D200DE0209EC4B40056EDDCD535345400D501A6A14EA4B4059C345EEE95045400D501A6A14EA4B40
26311	Клин	7	68	1675	42.467540999999997	42.497841000000001	55.830067999999997	55.814264000000001	0103000020E6100000010000000500000002452C62D83B4540B32781CD39E84B4002452C62D83B454062BA10AB3FEA4B40D1CDFE40B93F454062BA10AB3FEA4B40D1CDFE40B93F4540B32781CD39E84B4002452C62D83B4540B32781CD39E84B40
25528	Казаково	7	68	1675	42.752961999999997	42.782947999999998	55.773034000000003	55.754573000000001	0103000020E61000000100000005000000BC900E0F61604540E9B81AD995E04B40BC900E0F61604540195932C7F2E24B40FB3BDBA337644540195932C7F2E24B40FB3BDBA337644540E9B81AD995E04B40BC900E0F61604540E9B81AD995E04B40
25590	Звягино	7	68	1675	42.754390999999998	42.775708000000002	55.736797000000003	55.728515000000002	0103000020E61000000100000005000000C8B260E28F6045409ED2C1FA3FDD4B40C8B260E28F6045403D65355D4FDE4B406F9F55664A6345403D65355D4FDE4B406F9F55664A6345409ED2C1FA3FDD4B40C8B260E28F6045409ED2C1FA3FDD4B40
25374	Епифаново	7	68	1675	42.883434000000001	42.900412000000003	55.827888999999999	55.814244000000002	0103000020E610000001000000050000005516855D147145406C7BBB2539E84B405516855D14714540ECDB4944F8E94B4086764EB340734540ECDB4944F8E94B4086764EB3407345406C7BBB2539E84B405516855D147145406C7BBB2539E84B40
26164	Давыдово	7	68	1675	42.620623000000002	42.645093000000003	55.701627999999999	55.687080999999999	0103000020E610000001000000050000009D121093704F4540FB592C45F2D74B409D121093704F45409CFA40F2CED94B4074F04C68925245409CFA40F2CED94B4074F04C6892524540FB592C45F2D74B409D121093704F4540FB592C45F2D74B40
25299	Верхополье	7	68	1675	42.897419999999997	42.920147999999998	55.881515	55.871481000000003	0103000020E610000001000000050000005E6397A8DE724540EE0A7DB08CEF4B405E6397A8DE7245407BF7C77BD5F04B406ABDDF68C77545407BF7C77BD5F04B406ABDDF68C7754540EE0A7DB08CEF4B405E6397A8DE724540EE0A7DB08CEF4B40
21807	Вача	7	68	1675	42.706671999999998	42.797618	55.814886999999999	55.789805999999999	0103000020E61000000100000005000000DC7F643A745A4540A017EE5C18E54B40DC7F643A745A4540C0779B374EE84B40B859BC5818664540C0779B374EE84B40B859BC5818664540A017EE5C18E54B40DC7F643A745A4540A017EE5C18E54B40
26110	Болотниково	7	68	1675	42.447167	42.46949	55.799345000000002	55.788763000000003	0103000020E61000000100000005000000DB6CACC43C394540BEA59C2FF6E44B40DB6CACC43C3945404E9CDCEF50E64B4047E6913F183C45404E9CDCEF50E64B4047E6913F183C4540BEA59C2FF6E44B40DB6CACC43C394540BEA59C2FF6E44B40
26220	Березовка	7	68	1675	42.595227000000001	42.626730999999999	55.722644000000003	55.710261000000003	0103000020E610000001000000050000001D59F965304C4540E84F1BD5E9DA4B401D59F965304C454048533D997FDC4B40D731AEB83850454048533D997FDC4B40D731AEB838504540E84F1BD5E9DA4B401D59F965304C4540E84F1BD5E9DA4B40
25898	Беляйково	7	68	1675	42.596969999999999	42.651201	55.803423000000002	55.777059000000001	0103000020E61000000100000005000000B8585183694C4540FF0758AB76E34B40B8585183694C454057ED9A90D6E64B40AE0FEB8D5A53454057ED9A90D6E64B40AE0FEB8D5A534540FF0758AB76E34B40B8585183694C4540FF0758AB76E34B40
25770	Белогузово	7	68	1675	42.784923999999997	42.799925999999999	55.783437999999997	55.77355	0103000020E6100000010000000500000039ECBE637864454010E9B7AF03E34B4039ECBE6378644540C93846B247E44B402C9CA4F963664540C93846B247E44B402C9CA4F96366454010E9B7AF03E34B4039ECBE637864454010E9B7AF03E34B40
25205	Арефино	7	68	1675	42.856853000000001	42.882418999999999	55.878737999999998	55.869799	0103000020E61000000100000005000000603DEE5BAD6D4540F88BD99255EF4B40603DEE5BAD6D454050E09D7C7AF04B403C2F151BF370454050E09D7C7AF04B403C2F151BF3704540F88BD99255EF4B40603DEE5BAD6D4540F88BD99255EF4B40
25688	Алтунино	7	68	1675	42.810220999999999	42.836675999999997	55.802199000000002	55.789841000000003	0103000020E6100000010000000500000026C45C52B56745401D05888219E54B4026C45C52B567454024F1F274AEE64B408EACFC32186B454024F1F274AEE64B408EACFC32186B45401D05888219E54B4026C45C52B56745401D05888219E54B40
24800	Черемушки	7	68	1010	44.635300999999998	44.649242999999998	57.367249000000001	57.355758999999999	0103000020E61000000100000005000000DC0E0D8B51514640FB20CB8289AD4C40DC0E0D8B515146408E3EE60302AF4C40161406651A5346408E3EE60302AF4C40161406651A534640FB20CB8289AD4C40DC0E0D8B51514640FB20CB8289AD4C40
25105	Северный	7	68	1010	44.560400000000001	44.601712999999997	57.495533999999999	57.468767999999997	0103000020E61000000100000005000000D656EC2FBB474640A6B4FE9600BC4C40D656EC2FBB4746402D077AA86DBF4C40FD497CEE044D46402D077AA86DBF4C40FD497CEE044D4640A6B4FE9600BC4C40D656EC2FBB474640A6B4FE9600BC4C40
25072	Новоникольское	7	68	1010	44.805613000000001	44.820588000000001	57.343409999999999	57.335881000000001	0103000020E61000000100000005000000C11DA8531E674640842C0B26FEAA4C40C11DA8531E674640478FDFDBF4AB4C40BABE0F0709694640478FDFDBF4AB4C40BABE0F0709694640842C0B26FEAA4C40C11DA8531E674640842C0B26FEAA4C40
24962	Михаленино	7	68	1010	45.039003999999998	45.068486999999998	57.433345000000003	57.422727999999999	0103000020E61000000100000005000000E3344415FE8446403F8D7BF31BB64C40E3344415FE8446404C7155D977B74C40BF99982EC48846404C7155D977B74C40BF99982EC48846403F8D7BF31BB64C40E3344415FE8446403F8D7BF31BB64C40
24757	Мирный	7	68	1010	44.739452	44.755701999999999	57.305813000000001	57.293798000000002	0103000020E610000001000000050000001C7BF65CA65E4640ABD0402C9BA54C401C7BF65CA65E464088D860E124A74C40CAC2D7D7BA60464088D860E124A74C40CAC2D7D7BA604640ABD0402C9BA54C401C7BF65CA65E4640ABD0402C9BA54C40
24878	Макарий	7	68	1010	45.010086999999999	45.024667000000001	57.300348	57.292406999999997	0103000020E61000000100000005000000B08EE3874A8146408C0FB3976DA54C40B08EE3874A814640A2B5A2CD71A64C402D25CB4928834640A2B5A2CD71A64C402D25CB49288346408C0FB3976DA54C40B08EE3874A8146408C0FB3976DA54C40
24652	Красный Луч	7	68	1010	44.999091999999997	45.023077000000001	57.720742999999999	57.710489000000003	0103000020E61000000100000005000000FDD8243FE27F46407995B54DF1DA4C40FDD8243FE27F464014E97E4E41DC4C401825E82FF482464014E97E4E41DC4C401825E82FF48246407995B54DF1DA4C40FDD8243FE27F46407995B54DF1DA4C40
24651	Зверниха	7	68	1010	44.981799000000002	44.987450000000003	57.446308000000002	57.442912999999997	0103000020E610000001000000050000006D1FF296AB7D464093FC885FB1B84C406D1FF296AB7D4640BAF8DB9E20B94C40B537F8C2647E4640BAF8DB9E20B94C40B537F8C2647E464093FC885FB1B84C406D1FF296AB7D464093FC885FB1B84C40
24851	Горки	7	68	1010	45.062944000000002	45.087207999999997	57.640334000000003	57.617961000000001	0103000020E610000001000000050000005EBD8A8C0E8846400B9A965819CF4C405EBD8A8C0E8846402942EA76F6D14C408BF9B9A1298B46402942EA76F6D14C408BF9B9A1298B46400B9A965819CF4C405EBD8A8C0E8846400B9A965819CF4C40
24703	Восход	7	68	1010	44.710239000000001	44.730423999999999	57.239978000000001	57.228467999999999	0103000020E6100000010000000500000000AC8E1CE95A46405D177E703E9D4C4000AC8E1CE95A464037E15E99B79E4C40541B9C887E5D464037E15E99B79E4C40541B9C887E5D46405D177E703E9D4C4000AC8E1CE95A46405D177E703E9D4C40
24490	Варнавино	7	68	1010	45.050699999999999	45.109360000000002	57.410291000000001	57.39085	0103000020E610000001000000050000001FF46C567D86464020D26F5F07B24C401FF46C567D864640EC6B5D6A84B44C40CBBE2B82FF8D4640EC6B5D6A84B44C40CBBE2B82FF8D464020D26F5F07B24C401FF46C567D86464020D26F5F07B24C40
24934	Богородское	7	68	1010	44.998894	45.022179000000001	57.366948000000001	57.353442999999999	0103000020E61000000100000005000000D71533C2DB7F46400400C79E3DAD4C40D71533C2DB7F464093AAED26F8AE4C4039D4EFC2D682464093AAED26F8AE4C4039D4EFC2D68246400400C79E3DAD4C40D71533C2DB7F46400400C79E3DAD4C40
24614	Антониха	7	68	1010	45.056691999999998	45.093648999999999	57.671249000000003	57.658684000000001	0103000020E61000000100000005000000F0F8F6AE418746400133DFC14FD44C40F0F8F6AE41874640823CBB7CEBD54C40CC26C0B0FC8B4640823CBB7CEBD54C40CC26C0B0FC8B46400133DFC14FD44C40F0F8F6AE418746400133DFC14FD44C40
24280	совхоз Новый Мир	7	68	1703	44.429264000000003	44.454487999999998	55.430222000000001	55.42239	0103000020E61000000100000005000000D2AC6C1FF2364640271422E010B64B40D2AC6C1FF23646408602B68311B74B405436ACA92C3A46408602B68311B74B405436ACA92C3A4640271422E010B64B40D2AC6C1FF2364640271422E010B64B40
23879	Щедровка	7	68	1703	44.047569000000003	44.065283999999998	55.498235000000001	55.484923000000002	0103000020E61000000100000005000000D7A6B1BD16064640030AF5F411BE4B40D7A6B1BD160646407D5C1B2AC6BF4B40DD79E2395B0846407D5C1B2AC6BF4B40DD79E2395B084640030AF5F411BE4B40D7A6B1BD16064640030AF5F411BE4B40
24479	Холостой Майдан	7	68	1703	44.116838999999999	44.137033000000002	55.411679999999997	55.402479999999997	0103000020E61000000100000005000000DCF29194F40E4640A4A5F27684B34B40DCF29194F40E4640693524EEB1B44B4084BC1E4C8A114640693524EEB1B44B4084BC1E4C8A114640A4A5F27684B34B40DCF29194F40E4640A4A5F27684B34B40
23064	Умай	7	68	1703	44.322426999999998	44.345531999999999	55.466703000000003	55.450006000000002	0103000020E61000000100000005000000772CB649452946407C80EECB99B94B40772CB64945294640F9F884ECBCBB4B4059DC7F643A2C4640F9F884ECBCBB4B4059DC7F643A2C46407C80EECB99B94B40772CB649452946407C80EECB99B94B40
22803	Стрелка	7	68	1703	44.143571999999999	44.174276999999996	55.5289	55.513987999999998	0103000020E61000000100000005000000874F3A9160124640AA44D95BCAC14B40874F3A91601246405D6DC5FEB2C34B40F5B86FB54E1646405D6DC5FEB2C34B40F5B86FB54E164640AA44D95BCAC14B40874F3A9160124640AA44D95BCAC14B40
22935	Свобода	7	68	1703	44.298963000000001	44.324376000000001	55.653334999999998	55.643073000000001	0103000020E6100000010000000500000066DB696B4426464066F84F3750D24B4066DB696B44264640842A357BA0D34B40BCCD1B2785294640842A357BA0D34B40BCCD1B278529464066F84F3750D24B4066DB696B4426464066F84F3750D24B40
25423	Петлино	7	68	1703	44.162087	44.192953000000003	55.449368	55.431789999999999	0103000020E61000000100000005000000AA0D4E44BF144640B35E0CE544B74B40AA0D4E44BF14464039EFFFE384B94B40225514AFB218464039EFFFE384B94B40225514AFB2184640B35E0CE544B74B40AA0D4E44BF144640B35E0CE544B74B40
24150	Лопатино	7	68	1703	44.307614000000001	44.334544999999999	55.525609000000003	55.506036000000002	0103000020E6100000010000000500000058E542E55F274640A14CA3C9C5C04B4058E542E55F274640DCBDDC2747C34B402905DD5ED22A4640DCBDDC2747C34B402905DD5ED22A4640A14CA3C9C5C04B4058E542E55F274640A14CA3C9C5C04B40
22857	Крутой Майдан	7	68	1703	44.051485999999997	44.088757000000001	55.597428999999998	55.577007000000002	0103000020E61000000100000005000000D619DF17970646401348895DDBC94B40D619DF17970646404B57B08D78CC4B404225AE635C0B46404B57B08D78CC4B404225AE635C0B46401348895DDBC94B40D619DF17970646401348895DDBC94B40
22864	Зеленые Горы	7	68	1703	44.192521999999997	44.234122999999997	55.622369999999997	55.610793999999999	0103000020E6100000010000000500000058E1968FA4184640E84B6F7F2ECE4B4058E1968FA41846407901F6D1A9CF4B40E61E12BEF71D46407901F6D1A9CF4B40E61E12BEF71D4640E84B6F7F2ECE4B4058E1968FA4184640E84B6F7F2ECE4B40
22764	Елховка	7	68	1703	44.276155000000003	44.301549999999999	55.596513000000002	55.574075000000001	0103000020E610000001000000050000003ED00A0C59234640C139234A7BC94B403ED00A0C59234640C651B9895ACC4B40ED0DBE3099264640C651B9895ACC4B40ED0DBE3099264640C139234A7BC94B403ED00A0C59234640C139234A7BC94B40
23112	Дубенское	7	68	1703	44.252294999999997	44.302053000000001	55.374478000000003	55.356625999999999	0103000020E61000000100000005000000DFF8DA334B2046409F73B7EBA5AD4B40DFF8DA334B204640278925E5EEAF4B40505436ACA9264640278925E5EEAF4B40505436ACA92646409F73B7EBA5AD4B40DFF8DA334B2046409F73B7EBA5AD4B40
22706	Вад	7	68	1703	44.173127000000001	44.224896999999999	55.548909999999999	55.516663999999999	0103000020E61000000100000005000000FD86890629164640A182C30B22C24B40FD868906291646404339D1AE42C64B40F8FBC56CC91C46404339D1AE42C64B40F8FBC56CC91C4640A182C30B22C24B40FD86890629164640A182C30B22C24B40
49733	Анненковского Карьера	7	68	1703	44.359932000000001	44.384329999999999	55.482545999999999	55.458868000000002	0103000020E6100000010000000500000056647440122E46402997C62FBCBA4B4056647440122E464066683C11C4BD4B40936FB6B93131464066683C11C4BD4B40936FB6B9313146402997C62FBCBA4B4056647440122E46402997C62FBCBA4B40
22581	Ягубовка	7	68	1536	44.674233999999998	44.735751	55.389453000000003	55.376308999999999	0103000020E61000000100000005000000F6ECB94C4D5646406118B0E42AB04B40F6ECB94C4D564640202A8D98D9B14B40E97FB9162D5E4640202A8D98D9B14B40E97FB9162D5E46406118B0E42AB04B40F6ECB94C4D5646406118B0E42AB04B40
22482	Уварово	7	68	1536	44.993343000000003	45.014749999999999	55.543118999999997	55.534891999999999	0103000020E61000000100000005000000F35A09DD257F46402E724F5777C44B40F35A09DD257F4640096B63EC84C54B40D9CEF753E3814640096B63EC84C54B40D9CEF753E38146402E724F5777C44B40F35A09DD257F46402E724F5777C44B40
22535	Тарталей	7	68	1536	45.09187	45.115900000000003	55.471055999999997	55.460481000000001	0103000020E61000000100000005000000E4BD6A65C28B4640F6B6990AF1BA4B40E4BD6A65C28B4640D34A21904BBC4B409FCDAACFD58E4640D34A21904BBC4B409FCDAACFD58E4640F6B6990AF1BA4B40E4BD6A65C28B4640F6B6990AF1BA4B40
21970	Смагино	7	68	1536	44.779165999999996	44.800043000000002	55.594962000000002	55.582940000000001	0103000020E61000000100000005000000DB1324B6BB634640DFC325C79DCA4B40DB1324B6BB6346406F2EFEB627CC4B4066321CCF676646406F2EFEB627CC4B4066321CCF67664640DFC325C79DCA4B40DB1324B6BB634640DFC325C79DCA4B40
23109	Пергалей	7	68	1536	44.752414999999999	44.774872000000002	55.526353	55.515053999999999	0103000020E610000001000000050000008A027D224F60464045D61A4AEDC14B408A027D224F6046406493FC885FC34B40064B75012F6346406493FC885FC34B40064B75012F63464045D61A4AEDC14B408A027D224F60464045D61A4AEDC14B40
22450	Лукьяново	7	68	1536	44.797806000000001	44.831305	55.461956000000001	55.450251000000002	0103000020E61000000100000005000000BB46CB811E664640E3FE23D3A1B94B40BB46CB811E6646407218CC5F21BB4B402A00C633686A46407218CC5F21BB4B402A00C633686A4640E3FE23D3A1B94B40BB46CB811E664640E3FE23D3A1B94B40
22983	Крутец	7	68	1536	45.125027000000003	45.149811	55.646360000000001	55.628728000000002	0103000020E61000000100000005000000FA0E7EE2009046402D0ABB287AD04B40FA0E7EE200904640A6B8AAECBBD24B4060CAC0012D934640A6B8AAECBBD24B4060CAC0012D9346402D0ABB287AD04B40FA0E7EE2009046402D0ABB287AD04B40
23019	Кремницкое	7	68	1536	44.960141	44.985599000000001	55.643118999999999	55.629286999999998	0103000020E610000001000000050000003D4679E6E57A46402366F6798CD04B403D4679E6E57A4640D63730B951D24B4033FCA71B287E4640D63730B951D24B4033FCA71B287E46402366F6798CD04B403D4679E6E57A46402366F6798CD04B40
23144	Кочуново	7	68	1536	44.973489999999998	45.006475999999999	55.453130999999999	55.436253999999998	0103000020E61000000100000005000000D47D00529B7C4640E55FCB2BD7B74B40D47D00529B7C4640E2E6543200BA4B40BD1AA034D4804640E2E6543200BA4B40BD1AA034D4804640E55FCB2BD7B74B40D47D00529B7C4640E55FCB2BD7B74B40
23062	Кетрось	7	68	1536	44.695461000000002	44.730620999999999	55.483866999999996	55.467911999999998	0103000020E610000001000000050000005D52B5DD04594640F6B3588AE4BB4B405D52B5DD045946408B4E965AEFBD4B40AA622AFD845D46408B4E965AEFBD4B40AA622AFD845D4640F6B3588AE4BB4B405D52B5DD04594640F6B3588AE4BB4B40
22342	Кеньшево	7	68	1536	44.972915	44.994430000000001	55.478306000000003	55.467336000000003	0103000020E61000000100000005000000D8648D7A887C46402A1F82AAD1BB4B40D8648D7A887C464084BD892139BD4B40A514747B497F464084BD892139BD4B40A514747B497F46402A1F82AAD1BB4B40D8648D7A887C46402A1F82AAD1BB4B40
22938	Каменищи	7	68	1536	45.004167000000002	45.024577000000001	55.599947	55.580528000000001	0103000020E61000000100000005000000795C548B88804640C634D3BD4ECA4B40795C548B88804640AA2A3410CBCC4B40ED9DD15625834640AA2A3410CBCC4B40ED9DD15625834640C634D3BD4ECA4B40795C548B88804640C634D3BD4ECA4B40
22410	Инкино	7	68	1536	44.861469999999997	44.891751999999997	55.431994000000003	55.418114000000003	0103000020E61000000100000005000000183E22A6446E4640F8FF71C284B54B40183E22A6446E4640BC0853944BB74B404012F6ED24724640BC0853944BB74B404012F6ED24724640F8FF71C284B54B40183E22A6446E4640F8FF71C284B54B40
22860	Валгусы	7	68	1536	44.850645	44.880414999999999	55.605378000000002	55.592601999999999	0103000020E61000000100000005000000C2C073EFE16C4640A8C5E061DACB4B40C2C073EFE16C4640E4DBBB067DCD4B4034F44F70B1704640E4DBBB067DCD4B4034F44F70B1704640A8C5E061DACB4B40C2C073EFE16C4640A8C5E061DACB4B40
18239	Бутурлино	7	68	1536	44.861784	44.935662000000001	55.586663999999999	55.561548000000002	0103000020E61000000100000005000000A81B28F04E6E46402E910BCEE0C74B40A81B28F04E6E4640CADE52CE17CB4B40130EBDC5C3774640CADE52CE17CB4B40130EBDC5C37746402E910BCEE0C74B40A81B28F04E6E46402E910BCEE0C74B40
22626	Борнуково	7	68	1536	44.760967000000001	44.794015999999999	55.384031999999998	55.365155999999999	0103000020E61000000100000005000000E92ADD5D6761464016F88A6EBDAE4B40E92ADD5D67614640094FE8F527B14B401840F850A2654640094FE8F527B14B401840F850A265464016F88A6EBDAE4B40E92ADD5D6761464016F88A6EBDAE4B40
22679	Большой Якшень	7	68	1536	44.552647	44.574413	55.388731999999997	55.376154999999997	0103000020E61000000100000005000000C39D0B23BD4646400A9DD7D825B04B40C39D0B23BD4646404F745DF8C1B14B40D9B27C5D864946404F745DF8C1B14B40D9B27C5D864946400A9DD7D825B04B40C39D0B23BD4646400A9DD7D825B04B40
22862	Большие Бакалды	7	68	1536	44.723390000000002	44.758989999999997	55.669432	55.648209000000001	0103000020E610000001000000050000007120240B985C464087FC3383F8D24B407120240B985C4640AC72A1F2AFD54B40DAFE959526614640AC72A1F2AFD54B40DAFE95952661464087FC3383F8D24B407120240B985C464087FC3383F8D24B40
49713	Ямново	7	68	983	44.526254999999999	44.567253999999998	56.260067999999997	56.236550999999999	0103000020E61000000100000005000000A12DE7525C434640056B9C4D471E4C40A12DE7525C434640395E81E849214C40394371C79B484640395E81E849214C40394371C79B484640056B9C4D471E4C40A12DE7525C434640056B9C4D471E4C40
49818	Шпалозавода	7	68	983	44.035541000000002	44.054388000000003	56.534990999999998	56.523707000000002	0103000020E610000001000000050000006555849B8C044640D8D7BAD408434C406555849B8C044640C153C8957A444C40BEA59C2FF6064640C153C8957A444C40BEA59C2FF6064640D8D7BAD408434C406555849B8C044640D8D7BAD408434C40
49707	Чистое-Борское	7	68	983	44.405773000000003	44.42991	56.257958000000002	56.246636000000002	0103000020E61000000100000005000000C74CA25EF03346401502B9C4911F4C40C74CA25EF0334640ECDE8AC404214C40971C774A07374640ECDE8AC404214C40971C774A073746401502B9C4911F4C40C74CA25EF03346401502B9C4911F4C40
49628	Чистое Поле	7	68	983	44.022829999999999	44.051594000000001	56.766953000000001	56.757652999999998	0103000020E6100000010000000500000010AFEB17EC024640AF5B04C6FA604C4010AFEB17EC024640D84812842B624C40BD55D7A19A064640D84812842B624C40BD55D7A19A064640AF5B04C6FA604C4010AFEB17EC024640AF5B04C6FA604C40
49708	Тайново	7	68	983	43.965850000000003	43.978157000000003	56.421962000000001	56.415793000000001	0103000020E61000000100000005000000BA6B09F9A0FB4540EF737CB438354C40BA6B09F9A0FB4540CF13CFD902364C403FADA23F34FD4540CF13CFD902364C403FADA23F34FD4540EF737CB438354C40BA6B09F9A0FB4540EF737CB438354C40
21041	Ситники	7	68	983	44.017296000000002	44.071455999999998	56.451697000000003	56.439478000000001	0103000020E61000000100000005000000022D5DC136024640DFA7AAD040384C40022D5DC136024640C5591135D1394C402E8D5F7825094640C5591135D1394C402E8D5F7825094640DFA7AAD040384C40022D5DC136024640DFA7AAD040384C40
49805	Рустай	7	68	983	44.793953000000002	44.825097	56.514609	56.496929999999999	0103000020E61000000100000005000000D2C77C40A06546405D33F9669B3F4C40D2C77C40A0654640179D2CB5DE414C408C834BC79C694640179D2CB5DE414C408C834BC79C6946405D33F9669B3F4C40D2C77C40A06546405D33F9669B3F4C40
50027	Рожново	7	68	983	44.316094	44.332110999999998	56.277982999999999	56.271506000000002	0103000020E610000001000000050000001D3BA8C4752846407A5567B5C0224C401D3BA8C47528464007EC6AF294234C4028D2FD9C822A464007EC6AF294234C4028D2FD9C822A46407A5567B5C0224C401D3BA8C4752846407A5567B5C0224C40
21206	Рекшино	7	68	983	44.002456000000002	44.026395999999998	56.455905999999999	56.444502999999997	0103000020E61000000100000005000000E9D66B7A50004640A8FC6B79E5384C40E9D66B7A500046406C06B8205B3A4C40635FB2F1600346406C06B8205B3A4C40635FB2F160034640A8FC6B79E5384C40E9D66B7A50004640A8FC6B79E5384C40
49748	Редькино	7	68	983	44.186062999999997	44.221088000000002	56.329447000000002	56.310228000000002	0103000020E6100000010000000500000071FF91E9D0174640D926158DB5274C4071FF91E9D0174640F661BD512B2A4C40DFC4909C4C1C4640F661BD512B2A4C40DFC4909C4C1C4640D926158DB5274C4071FF91E9D0174640D926158DB5274C40
50026	Попово	7	68	983	44.085658000000002	44.097633000000002	56.498708999999998	56.494197	0103000020E61000000100000005000000055262D7F60A46400264E8D8413F4C40055262D7F60A4640459C4EB2D53F4C405401F73C7F0C4640459C4EB2D53F4C405401F73C7F0C46400264E8D8413F4C40055262D7F60A46400264E8D8413F4C40
50024	Плотинка	7	68	983	44.764747999999997	44.788257000000002	56.196055999999999	56.178448000000003	0103000020E6100000010000000500000038D73043E3614640B0045262D7164C4038D73043E3614640A017EE5C18194C40EAEBF99AE5644640A017EE5C18194C40EAEBF99AE5644640B0045262D7164C4038D73043E3614640B0045262D7164C40
49742	Память Парижской Коммуны	7	68	983	44.475554000000002	44.510919999999999	56.116447999999998	56.097943999999998	0103000020E61000000100000005000000B2BD16F4DE3C4640726BD26D890C4C40B2BD16F4DE3C4640A1D79FC4E70E4C40A86F99D365414640A1D79FC4E70E4C40A86F99D365414640726BD26D890C4C40B2BD16F4DE3C4640726BD26D890C4C40
49629	Останкино	7	68	983	44.331913	44.443179000000001	56.393847999999998	56.259763	0103000020E61000000100000005000000020F0C207C2A4640FDDAFAE93F214C40020F0C207C2A464029CC7B9C69324C4012A3E716BA38464029CC7B9C69324C4012A3E716BA384640FDDAFAE93F214C40020F0C207C2A4640FDDAFAE93F214C40
21675	Оманово	7	68	983	44.107827999999998	44.132432999999999	56.396766999999997	56.387475000000002	0103000020E61000000100000005000000EACBD24ECD0D46404182E2C798314C40EACBD24ECD0D4640E690D442C9324C40A1F48590F3104640E690D442C9324C40A1F48590F31046404182E2C798314C40EACBD24ECD0D46404182E2C798314C40
49756	Октябрьский	7	68	983	43.790453999999997	45.221066	56.896185000000003	56.052326000000001	0103000020E61000000100000005000000067FBF982DE54540815D4D9EB2064C40067FBF982DE545403815A930B6724C40F72004E44B9C46403815A930B6724C40F72004E44B9C4640815D4D9EB2064C40067FBF982DE54540815D4D9EB2064C40
20794	Неклюдово	7	68	983	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
8243	Линда	7	68	983	44.080044000000001	44.126379	56.630808000000002	56.604582000000001	0103000020E61000000100000005000000DA1EBDE13E0A464009E066F1624D4C40DA1EBDE13E0A464010070951BE504C405AF3E32F2D10464010070951BE504C405AF3E32F2D10464009E066F1624D4C40DA1EBDE13E0A464009E066F1624D4C40
49703	Красная Слобода	7	68	983	44.179900000000004	44.194597000000002	56.437905000000001	56.428950999999998	0103000020E61000000100000005000000744694F606174640124BCADDE7364C40744694F606174640A0E062450D384C402A73F38DE8184640A0E062450D384C402A73F38DE8184640124BCADDE7364C40744694F606174640124BCADDE7364C40
50038	Коврово	7	68	983	43.790453999999997	45.221066	56.896185000000003	56.052326000000001	0103000020E61000000100000005000000067FBF982DE54540815D4D9EB2064C40067FBF982DE545403815A930B6724C40F72004E44B9C46403815A930B6724C40F72004E44B9C4640815D4D9EB2064C40067FBF982DE54540815D4D9EB2064C40
50023	Керженец	7	68	983	44.411791000000001	44.437356999999999	56.483383000000003	56.463977999999997	0103000020E61000000100000005000000C1E44691B5344640200890A1633B4C40C1E44691B5344640A038807EDF3D4C409DD66D50FB374640A038807EDF3D4C409DD66D50FB374640200890A1633B4C40C1E44691B5344640200890A1633B4C40
49801	Кантаурово	7	68	983	44.025281999999997	44.053857999999998	56.498896999999999	56.490107000000002	0103000020E61000000100000005000000B796C9703C034640354580D3BB3E4C40B796C9703C03464048895DDBDB3F4C406150A6D1E406464048895DDBDB3F4C406150A6D1E4064640354580D3BB3E4C40B796C9703C034640354580D3BB3E4C40
49704	Каликино	7	68	983	44.044119999999999	44.071024000000001	56.559131999999998	56.537526999999997	0103000020E61000000100000005000000BD8C62B9A5054640C6DB4AAFCD444C40BD8C62B9A5054640D3122BA391474C40959D7E5017094640D3122BA391474C40959D7E5017094640C6DB4AAFCD444C40BD8C62B9A5054640C6DB4AAFCD444C40
49631	Ивонькино	7	68	983	44.039448999999998	44.067	56.396932	56.393275000000003	0103000020E61000000100000005000000116E32AA0C054640CEAACFD556324C40116E32AA0C054640315EF3AACE324C407F6ABC7493084640315EF3AACE324C407F6ABC7493084640CEAACFD556324C40116E32AA0C054640CEAACFD556324C40
49775	Ивановское	7	68	983	44.204047000000003	44.212662000000002	56.409235000000002	56.402411000000001	0103000020E6100000010000000500000068EC4B361E1A46407C46223482334C4068EC4B361E1A464075B0FECF61344C400D8D2782381B464075B0FECF61344C400D8D2782381B46407C46223482334C4068EC4B361E1A46407C46223482334C40
49830	Завражное	7	68	983	44.49644	44.523847000000004	56.225838000000003	56.210566999999998	0103000020E610000001000000050000008F368E588B3F4640F44E05DCF31A4C408F368E588B3F4640D7187442E81C4C40CA8D226B0D434640D7187442E81C4C40CA8D226B0D434640F44E05DCF31A4C408F368E588B3F4640F44E05DCF31A4C40
14639	Железнодорожный	7	68	983	44.033107000000001	44.077178000000004	56.488328000000003	56.463495999999999	0103000020E610000001000000050000006422A5D93C044640D5E940D6533B4C406422A5D93C0446404DDC2A88813E4C4040FCFCF7E00946404DDC2A88813E4C4040FCFCF7E0094640D5E940D6533B4C406422A5D93C044640D5E940D6533B4C40
21888	Городищи	7	68	983	44.368906000000003	44.387994999999997	56.377014000000003	56.363294000000003	0103000020E610000001000000050000002BA6D24F382F4640A16AF46A802E4C402BA6D24F382F46402C11A8FE41304C407901F6D1A93146402C11A8FE41304C407901F6D1A9314640A16AF46A802E4C402BA6D24F382F4640A16AF46A802E4C40
49827	Владимирово	7	68	983	44.139870999999999	44.152906000000002	56.353031000000001	56.346935999999999	0103000020E610000001000000050000005454FD4AE71146400CE71A66682C4C405454FD4AE7114640B2BCAB1E302D4C405CAE7E6C92134640B2BCAB1E302D4C405CAE7E6C921346400CE71A66682C4C405454FD4AE71146400CE71A66682C4C40
50081	Боталово	7	68	983	44.021329999999999	44.052231999999997	56.395556999999997	56.379964999999999	0103000020E610000001000000050000003B3602F1BA024640F44F70B1A2304C403B3602F1BA024640185A9D9CA1324C40FFE6C589AF064640185A9D9CA1324C40FFE6C589AF064640F44F70B1A2304C403B3602F1BA024640F44F70B1A2304C40
49787	Большое Пикино	7	68	983	44.182344000000001	44.201127	56.357106000000002	56.341667000000001	0103000020E61000000100000005000000984F560C57174640AC8F87BEBB2B4C40984F560C571746404A9A3FA6B52D4C40DAAB8F87BE1946404A9A3FA6B52D4C40DAAB8F87BE194640AC8F87BEBB2B4C40984F560C57174640AC8F87BEBB2B4C40
49812	Большеорловское	7	68	983	44.593646	44.614064999999997	56.426945000000003	56.416365999999996	0103000020E610000001000000050000005BB39597FC4B46404A95287B4B354C405BB39597FC4B46406A183E22A6364C40224F92AE994E46406A183E22A6364C40224F92AE994E46404A95287B4B354C405BB39597FC4B46404A95287B4B354C40
18775	Холязино	7	68	1526	44.754120999999998	44.784951999999997	55.834800000000001	55.820687999999997	0103000020E61000000100000005000000081D7409876046401D1CEC4D0CE94B40081D740987604640B459F5B9DAEA4B400377A04E79644640B459F5B9DAEA4B400377A04E796446401D1CEC4D0CE94B40081D7409876046401D1CEC4D0CE94B40
49769	Советский	7	68	1526	44.675429000000001	44.696511999999998	55.827782999999997	55.815027999999998	0103000020E610000001000000050000008FE21C757456464082A966D652E84B408FE21C7574564640A69718CBF4E94B40C2A2224E27594640A69718CBF4E94B40C2A2224E2759464082A966D652E84B408FE21C757456464082A966D652E84B40
18316	Рождествено	7	68	1526	44.782831999999999	44.815897999999997	55.717081999999998	55.700710000000001	0103000020E610000001000000050000009221C7D63364464076FD82DDB0D94B409221C7D6336446406F46CD57C9DB4B40976F7D586F6846406F46CD57C9DB4B40976F7D586F68464076FD82DDB0D94B409221C7D63364464076FD82DDB0D94B40
18542	Курлаково	7	68	1526	44.612304000000002	44.638787000000001	55.837544999999999	55.828389000000001	0103000020E61000000100000005000000E19A3BFA5F4E4640DEAE97A608EA4B40E19A3BFA5F4E4640D3F6AFAC34EB4B40130EBDC5C3514640D3F6AFAC34EB4B40130EBDC5C3514640DEAE97A608EA4B40E19A3BFA5F4E4640DEAE97A608EA4B40
18674	Кишкино	7	68	1526	44.688822999999999	44.708334000000001	55.890805	55.878238000000003	0103000020E61000000100000005000000C6DD205A2B5846405F0D501A6AF04B40C6DD205A2B584640800EF3E505F24B408B5242B0AA5A4640800EF3E505F24B408B5242B0AA5A46405F0D501A6AF04B40C6DD205A2B5846405F0D501A6AF04B40
18625	Карабатово	7	68	1526	44.516238000000001	44.533154000000003	55.833587000000001	55.826447999999999	0103000020E61000000100000005000000EA793716144246401CEC4D0CC9E94B40EA7937161442464075AF93FAB2EA4B40A5DDE8633E44464075AF93FAB2EA4B40A5DDE8633E4446401CEC4D0CC9E94B40EA793716144246401CEC4D0CC9E94B40
18703	Ивановское	7	68	1526	44.874648000000001	44.885472999999998	55.900289000000001	55.891855	0103000020E6100000010000000500000083C13577F46F464015E3FC4D28F24B4083C13577F46F46406AF981AB3CF34B40D93EE42D577146406AF981AB3CF34B40D93EE42D5771464015E3FC4D28F24B4083C13577F46F464015E3FC4D28F24B40
18498	Григорово	7	68	1526	44.612475000000003	44.643090000000001	55.786363999999999	55.775767999999999	0103000020E610000001000000050000000E4FAF94654E464044A4A65D4CE34B400E4FAF94654E464039605793A7E44B403C31EBC55052464039605793A7E44B403C31EBC55052464044A4A65D4CE34B400E4FAF94654E464044A4A65D4CE34B40
18428	Вершинино	7	68	1526	44.727989000000001	44.751885000000001	55.749718999999999	55.735864999999997	0103000020E61000000100000005000000836C59BE2E5D4640B1A206D330DE4B40836C59BE2E5D46404C18CDCAF6DF4B402EAD86C43D6046404C18CDCAF6DF4B402EAD86C43D604640B1A206D330DE4B40836C59BE2E5D4640B1A206D330DE4B40
18050	Большое Мурашкино	7	68	1526	44.745480000000001	44.795408000000002	55.796394999999997	55.762064000000002	0103000020E610000001000000050000003AE97DE36B5F4640BFBA2A508BE14B403AE97DE36B5F464055D97745F0E54B40077DE9EDCF65464055D97745F0E54B40077DE9EDCF654640BFBA2A508BE14B403AE97DE36B5F4640BFBA2A508BE14B40
18000	Чиреси	7	68	1428	45.099775000000001	45.127218999999997	54.988742000000002	54.971336000000001	0103000020E61000000100000005000000ADFA5C6DC58C4640B7B6F0BC547C4B40ADFA5C6DC58C464040170D198F7E4B40043752B64890464040170D198F7E4B40043752B648904640B7B6F0BC547C4B40ADFA5C6DC58C4640B7B6F0BC547C4B40
17964	Черновское	7	68	1428	45.350971000000001	45.384864	55.134821000000002	55.115785000000002	0103000020E61000000100000005000000166C239EECAC4640062FFA0AD28E4B40166C239EECAC464032E884D041914B4031B43A3943B1464032E884D041914B4031B43A3943B14640062FFA0AD28E4B40166C239EECAC4640062FFA0AD28E4B40
17901	Усад	7	68	1428	45.348877999999999	45.368282000000001	55.112901000000001	55.096549000000003	0103000020E610000001000000050000009E25C808A8AC464013BBB6B75B8C4B409E25C808A8AC4640C5573B8A738E4B404DDA54DD23AF4640C5573B8A738E4B404DDA54DD23AF464013BBB6B75B8C4B409E25C808A8AC464013BBB6B75B8C4B40
17797	Сумароково	7	68	1428	45.07508	45.083272999999998	55.044499999999999	55.034821999999998	0103000020E61000000100000005000000B64AB0389C89464035971B0C75844B40B64AB0389C89464004560E2DB2854B40E5D18DB0A88A464004560E2DB2854B40E5D18DB0A88A464035971B0C75844B40B64AB0389C89464035971B0C75844B40
17721	Старое Ахматово	7	68	1428	45.232357	45.265639999999998	55.139952000000001	55.120958999999999	0103000020E6100000010000000500000093FFC9DFBD9D46401494A2957B8F4B4093FFC9DFBD9D4640418177F2E9914B403541D47D00A24640418177F2E9914B403541D47D00A246401494A2957B8F4B4093FFC9DFBD9D46401494A2957B8F4B40
17817	Сергеевка	7	68	1428	45.169862000000002	45.207644999999999	55.007468000000003	54.990189000000001	0103000020E61000000100000005000000A56ABB09BE954640F2ED5D83BE7E4B40A56ABB09BE9546401EE21FB6F4804B40C616821C949A46401EE21FB6F4804B40C616821C949A4640F2ED5D83BE7E4B40A56ABB09BE954640F2ED5D83BE7E4B40
17646	Пикшень	7	68	1428	45.359980999999998	45.387172999999997	54.990772	54.969113999999998	0103000020E6100000010000000500000037177FDB13AE4640410C74ED0B7C4B4037177FDB13AE464071E5EC9DD17E4B40757286E28EB1464071E5EC9DD17E4B40757286E28EB14640410C74ED0B7C4B4037177FDB13AE4640410C74ED0B7C4B40
17714	Пермеево	7	68	1428	45.192230000000002	45.224344000000002	54.979835999999999	54.968525	0103000020E61000000100000005000000B1A71DFE9A984640E02D90A0F87B4B40B1A71DFE9A984640C3B81B446B7D4B40E486DF4DB79C4640C3B81B446B7D4B40E486DF4DB79C4640E02D90A0F87B4B40B1A71DFE9A984640E02D90A0F87B4B40
50055	Новая Слобода	7	68	1428	45.114696000000002	45.154842000000002	54.932234000000001	54.911352000000001	0103000020E61000000100000005000000B37DC85BAE8E46407592AD2EA7744B40B37DC85BAE8E4640111C977153774B400C06D7DCD1934640111C977153774B400C06D7DCD19346407592AD2EA7744B40B37DC85BAE8E46407592AD2EA7744B40
17560	Молчаново	7	68	1428	45.198777999999997	45.221595999999998	55.114033999999997	55.099649999999997	0103000020E610000001000000050000000795B88E71994640F085C954C18C4B400795B88E71994640E75086AA988E4B405376FA415D9C4640E75086AA988E4B405376FA415D9C4640F085C954C18C4B400795B88E71994640F085C954C18C4B40
17487	Кондрыкино	7	68	1428	45.026553	45.055532999999997	54.924149	54.906745999999998	0103000020E610000001000000050000002B4EB51666834640B0E3BF4010744B402B4EB51666834640C8D0B1834A764B40A46C91B41B874640C8D0B1834A764B40A46C91B41B874640B0E3BF4010744B402B4EB51666834640B0E3BF4010744B40
17447	Илларионово	7	68	1428	45.136049	45.167552999999998	55.054639999999999	55.040078999999999	0103000020E61000000100000005000000A6D3BA0D6A914640D120054F21854B40A6D3BA0D6A914640D7868A71FE864B4060AC6F6072954640D7868A71FE864B4060AC6F6072954640D120054F21854B40A6D3BA0D6A914640D120054F21854B40
17278	Большое Казариново	7	68	1428	45.302183999999997	45.308103000000003	55.038603999999999	55.032856000000002	0103000020E61000000100000005000000EEAF1EF7ADA646401BBD1AA034844B40EEAF1EF7ADA6464055BFD2F9F0844B4056664AEB6FA7464055BFD2F9F0844B4056664AEB6FA746401BBD1AA034844B40EEAF1EF7ADA646401BBD1AA034844B40
15909	Большое Болдино	7	68	1428	45.283929999999998	45.335529000000001	55.013641999999997	54.987094999999997	0103000020E61000000100000005000000382D78D157A44640C6850321597E4B40382D78D157A446400FED6305BF814B4007EE409DF2AA46400FED6305BF814B4007EE409DF2AA4640C6850321597E4B40382D78D157A44640C6850321597E4B40
17337	Большие Поляны	7	68	1428	44.921055000000003	44.954607000000003	54.947248000000002	54.925711	0103000020E610000001000000050000009D685721E57546401346B3B27D764B409D685721E5754640C899266C3F794B402FC4EA8F307A4640C899266C3F794B402FC4EA8F307A46401346B3B27D764B409D685721E57546401346B3B27D764B40
17380	Большевик	7	68	1428	44.937601999999998	44.949477999999999	54.901584999999997	54.891365	0103000020E610000001000000050000000455A3570378464047E6913F18724B400455A3570378464036C8242367734B40C022BF7E8879464036C8242367734B40C022BF7E8879464047E6913F18724B400455A3570378464047E6913F18724B40
17099	Апраксино	7	68	1428	45.405363999999999	45.427911999999999	55.095728999999999	55.071654000000002	0103000020E61000000100000005000000E57CB1F7E2B34640555051F52B894B40E57CB1F7E2B34640AF230ED9408C4B4071C806D2C5B64640AF230ED9408C4B4071C806D2C5B64640555051F52B894B40E57CB1F7E2B34640555051F52B894B40
17036	Аносово	7	68	1428	45.28013	45.314185000000002	55.078313000000001	55.056877999999998	0103000020E610000001000000050000007250C24CDBA3464052EE3EC747874B407250C24CDBA3464003ED0E29068A4B4067F2CD3637A8464003ED0E29068A4B4067F2CD3637A8464052EE3EC747874B407250C24CDBA3464052EE3EC747874B40
49656	Швариха	7	68	1389	43.397899000000002	43.409801999999999	56.156796	56.147635999999999	0103000020E61000000100000005000000390EBC5AEEB245402BDB87BCE5124C40390EBC5AEEB2454062122EE411144C40EEEA556474B4454062122EE411144C40EEEA556474B445402BDB87BCE5124C40390EBC5AEEB245402BDB87BCE5124C40
16545	Шапкино	7	68	1389	43.538449	43.563080999999997	56.022503999999998	56.010443000000002	0103000020E610000001000000050000002EC896E5EBC445406FBC3B3256014C402EC896E5EBC44540BC033C69E1024C40DEFFC70913C84540BC033C69E1024C40DEFFC70913C845406FBC3B3256014C402EC896E5EBC445406FBC3B3256014C40
16653	Центральный	7	68	1389	43.491880999999999	43.511149000000003	56.079965000000001	56.069398999999997	0103000020E610000001000000050000000B43E4F4F5BE454003B00111E2084C400B43E4F4F5BE45408EE9094B3C0A4C400A3197546DC145408EE9094B3C0A4C400A3197546DC1454003B00111E2084C400B43E4F4F5BE454003B00111E2084C40
16407	Хвощевка	7	68	1389	43.535772000000001	43.559415999999999	55.911562000000004	55.886417999999999	0103000020E61000000100000005000000670E492D94C44540F94A202576F14B40670E492D94C4454060234910AEF44B40F86D88F19AC7454060234910AEF44B40F86D88F19AC74540F94A202576F14B40670E492D94C44540F94A202576F14B40
15440	Ушаково	7	68	1389	43.341816999999999	43.357087999999997	56.144351	56.131414999999997	0103000020E61000000100000005000000C11BD2A8C0AB4540179AEB34D2104C40C11BD2A8C0AB45408C12F4177A124C40A3E5400FB5AD45408C12F4177A124C40A3E5400FB5AD4540179AEB34D2104C40C11BD2A8C0AB4540179AEB34D2104C40
49740	Теряево	7	68	1389	43.360205999999998	43.384748000000002	56.042355999999998	56.03098	0103000020E6100000010000000500000057E9EE3A1BAE4540406A1327F7034C4057E9EE3A1BAE45400A65E1EB6B054C40C899266C3FB145400A65E1EB6B054C40C899266C3FB14540406A1327F7034C4057E9EE3A1BAE4540406A1327F7034C40
49630	Сысоевка	7	68	1389	43.588917000000002	43.612614000000001	56.184465000000003	56.175116000000003	0103000020E610000001000000050000007B87DBA161CB4540D0807A336A164C407B87DBA161CB4540DA20938C9C174C402F89B3226ACE4540DA20938C9C174C402F89B3226ACE4540D0807A336A164C407B87DBA161CB4540D0807A336A164C40
16737	Солонское	7	68	1389	43.417625999999998	43.437164000000003	55.993228000000002	55.985855999999998	0103000020E61000000100000005000000CAFACDC474B545405E48878730FE4B40CAFACDC474B545405ABC581822FF4B40897E6DFDF4B745405ABC581822FF4B40897E6DFDF4B745405E48878730FE4B40CAFACDC474B545405E48878730FE4B40
16330	Оранки	7	68	1389	43.701655000000002	43.727221	55.903519000000003	55.887357000000002	0103000020E610000001000000050000009609BFD4CFD94540377007EA94F14B409609BFD4CFD945404628B682A6F34B4072FBE59315DD45404628B682A6F34B4072FBE59315DD4540377007EA94F14B409609BFD4CFD94540377007EA94F14B40
49829	Окский	7	68	1389	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
49793	Новинки	7	68	1389	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
16585	Лукино	7	68	1389	43.588360000000002	43.610773000000002	55.985539000000003	55.973683000000001	0103000020E61000000100000005000000252367614FCB4540E9D500A5A1FC4B40252367614FCB45405EF7562426FE4B40D12346CF2DCE45405EF7562426FE4B40D12346CF2DCE4540E9D500A5A1FC4B40252367614FCB4540E9D500A5A1FC4B40
16414	Лакша	7	68	1389	43.617787999999997	43.641432000000002	56.049354999999998	56.031044999999999	0103000020E610000001000000050000003DEE5BAD13CF454027DA5548F9034C403DEE5BAD13CF45407172BF4351064C40CF4D9B711AD245407172BF4351064C40CF4D9B711AD2454027DA5548F9034C403DEE5BAD13CF454027DA5548F9034C40
49639	Кусаковка	7	68	1389	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
49736	Кудьма	7	68	1389	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
16278	Ключищи	7	68	1389	43.547207999999998	43.567959000000002	55.848882000000003	55.841512999999999	0103000020E61000000100000005000000060E68E90AC645405514AFB2B6EB4B40060E68E90AC64540E014562AA8EC4B40043C69E1B2C84540E014562AA8EC4B40043C69E1B2C845405514AFB2B6EB4B40060E68E90AC645405514AFB2B6EB4B40
15986	Каменки	7	68	1389	43.845457000000003	43.875255000000003	56.075327999999999	56.058061000000002	0103000020E610000001000000050000004F965AEF37EC45402716F88A6E074C404F965AEF37EC45408E3C1059A4094C408B54185B08F045408E3C1059A4094C408B54185B08F045402716F88A6E074C404F965AEF37EC45402716F88A6E074C40
49754	Инютино	7	68	1389	43.869838000000001	43.897686	55.939787000000003	55.926630000000003	0103000020E61000000100000005000000B66801DA56EF45400ABFD4CF9BF64B40B66801DA56EF45405D1ABFF04AF84B40DD09F65FE7F245405D1ABFF04AF84B40DD09F65FE7F245400ABFD4CF9BF64B40B66801DA56EF45400ABFD4CF9BF64B40
15732	Дуденево	7	68	1389	43.491	43.528917999999997	56.189520000000002	56.171087	0103000020E61000000100000005000000022B8716D9BE4540A8E2C62DE6154C40022B8716D9BE45400EF8FC3042184C400322C495B3C345400EF8FC3042184C400322C495B3C34540A8E2C62DE6154C40022B8716D9BE4540A8E2C62DE6154C40
49741	Доскино	7	68	1389	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
49641	Демидово	7	68	1389	43.458454000000003	43.478064000000003	56.109416000000003	56.094147999999997	0103000020E61000000100000005000000365CE49EAEBA4540ED7DAA0A0D0C4C40365CE49EAEBA45405FD4EE57010E4C408EB27E3331BD45405FD4EE57010E4C408EB27E3331BD4540ED7DAA0A0D0C4C40365CE49EAEBA4540ED7DAA0A0D0C4C40
49858	Высоково	7	68	1389	43.512757000000001	43.52731	56.086067999999997	56.073855999999999	0103000020E61000000100000005000000C5E57805A2C14540834E081D74094C40C5E57805A2C14540B69DB646040B4C40486DE2E47EC34540B69DB646040B4C40486DE2E47EC34540834E081D74094C40C5E57805A2C14540834E081D74094C40
49739	Буревестник	7	68	1389	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
49723	Богородск	7	68	1389	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
15801	Березовка	7	68	1389	43.551672000000003	43.594774000000001	56.130226	56.117361000000002	0103000020E61000000100000005000000390F27309DC64540B6696CAF050F4C40390F27309DC64540618BDD3EAB104C406C41EF8D21CC4540618BDD3EAB104C406C41EF8D21CC4540B6696CAF050F4C40390F27309DC64540B6696CAF050F4C40
16499	Афанасьево	7	68	1389	43.705967000000001	43.733787999999997	56.041913000000001	56.027504	0103000020E6100000010000000500000012876C205DDA45402D41464085034C4012876C205DDA45407D23BA675D054C403F19E3C3ECDD45407D23BA675D054C403F19E3C3ECDD45402D41464085034C4012876C205DDA45402D41464085034C40
15376	Арапово	7	68	1389	43.244053000000001	43.261409	56.117798000000001	56.107900000000001	0103000020E61000000100000005000000CFBEF2203D9F4540849ECDAACF0D4C40CFBEF2203D9F454061C43E01140F4C40A6F0A0D975A1454061C43E01140F4C40A6F0A0D975A14540849ECDAACF0D4C40CFBEF2203D9F4540849ECDAACF0D4C40
15223	Алешково	7	68	1389	43.404240999999999	43.430022999999998	56.074010999999999	56.059258	0103000020E61000000100000005000000E659492BBEB34540600322C495074C40E659492BBEB34540AA45443179094C408FC360FE0AB74540AA45443179094C408FC360FE0AB74540600322C495074C40E659492BBEB34540600322C495074C40
14118	Шеляухово	7	68	916	43.422314999999998	43.452606000000003	56.612825999999998	56.603686000000003	0103000020E610000001000000050000001CCEFC6A0EB64540CB863595454D4C401CCEFC6A0EB64540BA111615714E4C4098FC4FFEEEB94540BA111615714E4C4098FC4FFEEEB94540CB863595454D4C401CCEFC6A0EB64540CB863595454D4C40
14241	Совхозный	7	68	916	43.473815000000002	43.489437000000002	56.566764999999997	56.556795000000001	0103000020E6100000010000000500000058AD4CF8A5BC4540C5C9FD0E45474C4058AD4CF8A5BC45403BC269C18B484C40E73922DFA5BE45403BC269C18B484C40E73922DFA5BE4540C5C9FD0E45474C4058AD4CF8A5BC4540C5C9FD0E45474C40
49817	Поселок Большое Козино	7	68	916	43.104849999999999	43.717312999999997	56.644509999999997	56.371102	0103000020E61000000100000005000000287E8CB96B8D454077BD3445802F4C40287E8CB96B8D4540F4F8BD4D7F524C4071FF91E9D0DB4540F4F8BD4D7F524C4071FF91E9D0DB454077BD3445802F4C40287E8CB96B8D454077BD3445802F4C40
7288	Первомайский	7	68	916	43.346415999999998	43.378666000000003	56.625127999999997	56.605741999999999	0103000020E61000000100000005000000D367075C57AC454025E82FF4884D4C40D367075C57AC45402DE8BD3104504C40B70DA32078B045402DE8BD3104504C40B70DA32078B0454025E82FF4884D4C40D367075C57AC454025E82FF4884D4C40
13950	Малое Козино	7	68	916	43.661679999999997	43.694864000000003	56.450915999999999	56.428742	0103000020E61000000100000005000000693524EEB1D44540F8359204E1364C40693524EEB1D445401F9F909DB7394C407995B54DF1D845401F9F909DB7394C407995B54DF1D84540F8359204E1364C40693524EEB1D44540F8359204E1364C40
13792	Лукино	7	68	916	43.611230999999997	43.655805000000001	56.455984999999998	56.424903999999998	0103000020E6100000010000000500000093A641D13CCE454044F8174163364C4093A641D13CCE4540B83B6BB75D3A4C40D2C6116BF1D34540B83B6BB75D3A4C40D2C6116BF1D3454044F8174163364C4093A641D13CCE454044F8174163364C40
14384	Конево	7	68	916	43.186560999999998	43.220140000000001	56.463411000000001	56.446717999999997	0103000020E61000000100000005000000C2DA183BE19745406B44300E2E394C40C2DA183BE1974540A7CD380D513B4C404E452A8C2D9C4540A7CD380D513B4C404E452A8C2D9C45406B44300E2E394C40C2DA183BE19745406B44300E2E394C40
14272	Истомино	7	68	916	43.445571999999999	43.470922999999999	56.537066000000003	56.523741999999999	0103000020E61000000100000005000000B401D88008B9454054C554FA09434C40B401D88008B9454093E52494BE444C4094F7713447BC454093E52494BE444C4094F7713447BC454054C554FA09434C40B401D88008B9454054C554FA09434C40
14328	Замятино	7	68	916	43.399588000000001	43.414580999999998	56.480823000000001	56.470193999999999	0103000020E61000000100000005000000E1EF17B325B34540416326512F3C4C40E1EF17B325B345401215AA9B8B3D4C4080457EFD10B545401215AA9B8B3D4C4080457EFD10B54540416326512F3C4C40E1EF17B325B34540416326512F3C4C40
13602	Гидроторф	7	68	916	43.515433999999999	43.569952999999998	56.493580999999999	56.451557999999999	0103000020E610000001000000050000008C9FC6BDF9C14540A31F0DA7CC394C408C9FC6BDF9C14540A77686A92D3F4C40E8A04B38F4C84540A77686A92D3F4C40E8A04B38F4C84540A31F0DA7CC394C408C9FC6BDF9C14540A31F0DA7CC394C40
14183	Большие Могильцы	7	68	916	43.519917	43.528450999999997	56.540277000000003	56.534232000000003	0103000020E6100000010000000500000035D1E7A38CC24540043DD4B661444C4035D1E7A38CC24540F8E3F6CB27454C40ED444948A4C34540F8E3F6CB27454C40ED444948A4C34540043DD4B661444C4035D1E7A38CC24540043DD4B661444C40
40312	Балахна	7	68	916	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
12841	Балахна	7	68	916	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
13890	1-е Мая	7	68	916	43.629215000000002	43.665103000000002	56.427064999999999	56.40802	0103000020E610000001000000050000008A93FB1D8AD04540950ED6FF39344C408A93FB1D8AD045401422E010AA364C405ABC581822D545401422E010AA364C405ABC581822D54540950ED6FF39344C408A93FB1D8AD04540950ED6FF39344C40
8877	Шерстино	7	68	992	43.404375999999999	43.432429999999997	55.395502	55.380415999999997	0103000020E61000000100000005000000C6A4BF97C2B345400470B378B1B04B40C6A4BF97C2B3454055C03DCF9FB24B4096E7C1DD59B7454055C03DCF9FB24B4096E7C1DD59B745400470B378B1B04B40C6A4BF97C2B345400470B378B1B04B40
49732	Шатовка	7	68	992	43.699058999999998	43.718786000000001	55.283009999999997	55.268476999999997	0103000020E61000000100000005000000BB7CEBC37AD94540355D4F745DA24B40BB7CEBC37AD945407138F3AB39A44B404D69FD2D01DC45407138F3AB39A44B404D69FD2D01DC4540355D4F745DA24B40BB7CEBC37AD94540355D4F745DA24B40
10680	Чернуха	7	68	992	43.722999000000002	43.800505999999999	55.612003999999999	55.587809	0103000020E610000001000000050000003605323B8BDC4540B1A547533DCB4B403605323B8BDC4540B682A62556CE4B403A2009FB76E64540B682A62556CE4B403A2009FB76E64540B1A547533DCB4B403605323B8BDC4540B1A547533DCB4B40
10623	Хватовка	7	68	992	43.725648999999997	43.769486999999998	55.445911000000002	55.425925999999997	0103000020E6100000010000000500000003B00111E2DC45400F4240BE84B64B4003B00111E2DC45409DF6949C13B94B403CD9CD8C7EE245409DF6949C13B94B403CD9CD8C7EE245400F4240BE84B64B4003B00111E2DC45400F4240BE84B64B40
10161	Успенское 1-е	7	68	992	44.137096	44.156122000000003	55.368405000000003	55.356031999999999	0103000020E61000000100000005000000CA349A5C8C1146402C2AE27492AD4B40CA349A5C8C114640695721E527AF4B40D31742CEFB134640695721E527AF4B40D31742CEFB1346402C2AE27492AD4B40CA349A5C8C1146402C2AE27492AD4B40
10589	Степаново	7	68	992	43.501196	43.521247000000002	55.339528999999999	55.324083999999999	0103000020E610000001000000050000006971C63027C045401494A2957BA94B406971C63027C045409485AFAF75AB4B40AE11C138B8C245409485AFAF75AB4B40AE11C138B8C245401494A2957BA94B406971C63027C045401494A2957BA94B40
10362	Слизнево	7	68	992	43.52749	43.569540000000003	55.333461	55.314556000000003	0103000020E61000000100000005000000C87BD5CA84C345405B61FA5E43A84B40C87BD5CA84C34540E8BE9CD9AEAA4B40C6E1CCAFE6C84540E8BE9CD9AEAA4B40C6E1CCAFE6C845405B61FA5E43A84B40C87BD5CA84C345405B61FA5E43A84B40
10512	Семеново	7	68	992	43.533365000000003	43.555149	55.376154999999997	55.355325999999998	0103000020E6100000010000000500000060EAE74D45C4454091B586527BAD4B4060EAE74D45C445400A9DD7D825B04B401CB4571F0FC745400A9DD7D825B04B401CB4571F0FC7454091B586527BAD4B4060EAE74D45C4454091B586527BAD4B40
10262	Селема	7	68	992	43.626995999999998	43.648277	55.549770000000002	55.532350000000001	0103000020E61000000100000005000000855CA96741D045404703780B24C44B40855CA96741D04540352905DD5EC64B40DFDFA0BDFAD24540352905DD5EC64B40DFDFA0BDFAD245404703780B24C44B40855CA96741D045404703780B24C44B40
10010	Пустынь	7	68	992	43.589581000000003	43.619774	55.666203000000003	55.654884000000003	0103000020E61000000100000005000000E7ABE46377CB45403B56293DD3D34B40E7ABE46377CB4540A1BFD02346D54B409F7422C154CF4540A1BFD02346D54B409F7422C154CF45403B56293DD3D34B40E7ABE46377CB45403B56293DD3D34B40
9767	Протопоповка	7	68	992	43.890858000000001	43.923135000000002	55.490386000000001	55.478178999999997	0103000020E61000000100000005000000A3B08BA207F2454026512FF834BD4B40A3B08BA207F245404835ECF7C4BE4B408065A54929F645404835ECF7C4BE4B408065A54929F6454026512FF834BD4B40A3B08BA207F2454026512FF834BD4B40
10868	Пошатово	7	68	992	43.703145999999997	43.722496	55.630826999999996	55.613574999999997	0103000020E61000000100000005000000172829B000DA4540545227A089CE4B40172829B000DA454086376BF0BED04B40D3BEB9BF7ADC454086376BF0BED04B40D3BEB9BF7ADC4540545227A089CE4B40172829B000DA4540545227A089CE4B40
10225	Пешелань	7	68	992	43.901755000000001	43.941828999999998	55.317214999999997	55.291967	0103000020E61000000100000005000000930035B56CF345407041B62C5FA54B40930035B56CF345407B6649809AA84B4052B648DA8DF845407B6649809AA84B4052B648DA8DF845407041B62C5FA54B40930035B56CF345407041B62C5FA54B40
9968	Новый Усад	7	68	992	43.776277999999998	43.827482000000003	55.318424	55.288992999999998	0103000020E61000000100000005000000594DD7135DE34540EFE2FDB8FDA44B40594DD7135DE3454079211D1EC2A84B40AC0320EEEAE9454079211D1EC2A84B40AC0320EEEAE94540EFE2FDB8FDA44B40594DD7135DE34540EFE2FDB8FDA44B40
10308	Никольское	7	68	992	43.568371999999997	43.611778999999999	55.541193	55.528269000000002	0103000020E6100000010000000500000026FBE769C0C84540CD3E8F519EC34B4026FBE769C0C845407DE9EDCF45C54B4096B036C64ECE45407DE9EDCF45C54B4096B036C64ECE4540CD3E8F519EC34B4026FBE769C0C84540CD3E8F519EC34B40
10077	Наумовка	7	68	992	43.480589000000002	43.513620000000003	55.649352	55.635345000000001	0103000020E610000001000000050000009FE8BAF083BD4540AC5626FC52D14B409FE8BAF083BD4540CDCB61F71DD34B402849D74CBEC14540CDCB61F71DD34B402849D74CBEC14540AC5626FC52D14B409FE8BAF083BD4540AC5626FC52D14B40
9865	Мотовилово	7	68	992	43.822882999999997	43.856380999999999	55.597285999999997	55.575332000000003	0103000020E6100000010000000500000099B7EA3A54E94540D02B9E7AA4C94B4099B7EA3A54E94540E82D1EDE73CC4B4038F581E49DED4540E82D1EDE73CC4B4038F581E49DED4540D02B9E7AA4C94B4099B7EA3A54E94540D02B9E7AA4C94B40
9691	Морозовка	7	68	992	43.929997999999998	43.957774000000001	55.449863000000001	55.437117000000001	0103000020E6100000010000000500000036ACA92C0AF7454048C32973F3B74B4036ACA92C0AF7454019575C1C95B94B40C47AA35698FA454019575C1C95B94B40C47AA35698FA454048C32973F3B74B4036ACA92C0AF7454048C32973F3B74B40
8525	Мерлино	7	68	992	43.615839000000001	43.646830999999999	55.412140000000001	55.401952999999999	0103000020E61000000100000005000000F94CF6CFD3CE4540B9C3263273B34B40F94CF6CFD3CE4540CDAFE600C1B44B40FD84B35BCBD24540CDAFE600C1B44B40FD84B35BCBD24540B9C3263273B34B40F94CF6CFD3CE4540B9C3263273B34B40
9650	Ломовка	7	68	992	43.810386999999999	43.854171000000001	55.55527	55.524191999999999	0103000020E61000000100000005000000410DDFC2BAE74540946934B918C34B40410DDFC2BAE7454097395D1613C74B408718AF7955ED454097395D1613C74B408718AF7955ED4540946934B918C34B40410DDFC2BAE74540946934B918C34B40
9506	Лидовка	7	68	992	43.521138999999998	43.527157000000003	55.484831	55.477465000000002	0103000020E61000000100000005000000C7D5C8AEB4C2454009FEB7921DBD4B40C7D5C8AEB4C24540228B34F10EBE4B40C26D6DE179C34540228B34F10EBE4B40C26D6DE179C3454009FEB7921DBD4B40C7D5C8AEB4C2454009FEB7921DBD4B40
9077	Криуша	7	68	992	43.974240000000002	43.995871000000001	55.609817	55.602804999999996	0103000020E610000001000000050000003F3A75E5B3FC4540C16ED8B628CD4B403F3A75E5B3FC4540BDC5C37B0ECE4B40750470B378FF4540BDC5C37B0ECE4B40750470B378FF4540C16ED8B628CD4B403F3A75E5B3FC4540C16ED8B628CD4B40
9548	Красное	7	68	992	43.723098	43.762929	55.407468999999999	55.388041000000001	0103000020E61000000100000005000000C9E6AA798EDC4540EA40D653ABB14B40C9E6AA798EDC45402191B6F127B44B40C21550A8A7E145402191B6F127B44B40C21550A8A7E14540EA40D653ABB14B40C9E6AA798EDC4540EA40D653ABB14B40
8683	Котиха	7	68	992	43.480983999999999	43.505642999999999	55.468668000000001	55.451058000000003	0103000020E610000001000000050000001BF33AE290BD4540B24CBF44BCB94B401BF33AE290BD454043572250FDBB4B40C539EAE8B8C0454043572250FDBB4B40C539EAE8B8C04540B24CBF44BCB94B401BF33AE290BD4540B24CBF44BCB94B40
9456	Костылиха	7	68	992	43.527147999999997	43.601861	55.497720000000001	55.476923999999997	0103000020E610000001000000050000006E13EE9579C34540B8567BD80BBD4B406E13EE9579C345405648F949B5BF4B4072DEFFC709CD45405648F949B5BF4B4072DEFFC709CD4540B8567BD80BBD4B406E13EE9579C34540B8567BD80BBD4B40
8793	Кожино	7	68	992	43.868741999999997	43.887830999999998	55.333492	55.323760999999998	0103000020E61000000100000005000000B05417F032EF4540315C1D0071A94B40B05417F032EF454023BDA8DDAFAA4B40FFAF3A72A4F1454023BDA8DDAFAA4B40FFAF3A72A4F14540315C1D0071A94B40B05417F032EF4540315C1D0071A94B40
9413	Ковакса	7	68	992	43.481594999999999	43.526870000000002	55.525602999999997	55.509976999999999	0103000020E610000001000000050000006475ABE7A4BD4540295B24ED46C14B406475ABE7A4BD4540F9D687F546C34B402C9FE57970C34540F9D687F546C34B402C9FE57970C34540295B24ED46C14B406475ABE7A4BD4540295B24ED46C14B40
9602	Кичанзино	7	68	992	43.703991000000002	43.738118	55.416483999999997	55.400675	0103000020E61000000100000005000000D4D688601CDA454093A9825149B34B40D4D688601CDA454054A703594FB54B40624B8FA67ADE454054A703594FB54B40624B8FA67ADE454093A9825149B34B40D4D688601CDA454093A9825149B34B40
8590	Каменка	7	68	992	43.701915999999997	43.718975	55.442560999999998	55.434128999999999	0103000020E6100000010000000500000002452C62D8D94540629F008A91B74B4002452C62D8D9454016BEBED6A5B84B4020D26F5F07DC454016BEBED6A5B84B4020D26F5F07DC4540629F008A91B74B4002452C62D8D94540629F008A91B74B40
9382	Казаково	7	68	992	43.790939000000002	43.812973999999997	55.215308	55.202706999999997	0103000020E61000000100000005000000C310397D3DE54540CBD58F4DF2994B40C310397D3DE54540994869368F9B4B40C83F33880FE84540994869368F9B4B40C83F33880FE84540CBD58F4DF2994B40C310397D3DE54540CBD58F4DF2994B40
8453	Забелино	7	68	992	43.690426000000002	43.704340999999999	55.416181999999999	55.401432	0103000020E61000000100000005000000702711E15FD84540B0C8AF1F62B34B40702711E15FD845408997A77345B54B40B01D8CD827DA45408997A77345B54B40B01D8CD827DA4540B0C8AF1F62B34B40702711E15FD84540B0C8AF1F62B34B40
9027	Выездное	7	68	992	43.760700999999997	43.800666999999997	55.393864999999998	55.365310000000001	0103000020E610000001000000050000006A847EA65EE145406D73637AC2AE4B406A847EA65EE14540FF04172B6AB24B4043FE99417CE64540FF04172B6AB24B4043FE99417CE645406D73637AC2AE4B406A847EA65EE145406D73637AC2AE4B40
9906	Вторусское	7	68	992	43.852463999999998	43.885136000000003	55.609059999999999	55.598446000000003	0103000020E610000001000000050000003882548A1DED45400536E7E099CC4B403882548A1DED4540A0A696ADF5CD4B409241EE224CF14540A0A696ADF5CD4B409241EE224CF145400536E7E099CC4B403882548A1DED45400536E7E099CC4B40
8984	Волчиха	7	68	992	43.899455000000003	43.922713000000002	55.595520999999998	55.576075000000003	0103000020E61000000100000005000000A29C685721F3454088855AD3BCC94B40A29C685721F34540658A39083ACC4B400A4CA7751BF64540658A39083ACC4B400A4CA7751BF6454088855AD3BCC94B40A29C685721F3454088855AD3BCC94B40
8930	Водоватово	7	68	992	43.550764999999998	43.597199000000003	55.409196000000001	55.393022000000002	0103000020E610000001000000050000000664AF777FC64540E44D7E8B4EB24B400664AF777FC64540B7D3D68860B44B401A1A4F0471CC4540B7D3D68860B44B401A1A4F0471CC4540E44D7E8B4EB24B400664AF777FC64540E44D7E8B4EB24B40
10411	Ветошкино	7	68	992	43.474732000000003	43.495213	55.330553000000002	55.317081999999999	0103000020E61000000100000005000000AE2EA704C4BC45403C139A2496A84B40AE2EA704C4BC45401F4C8A8F4FAA4B40EBC6BB2363BF45401F4C8A8F4FAA4B40EBC6BB2363BF45403C139A2496A84B40AE2EA704C4BC45403C139A2496A84B40
8460	Веригино	7	68	992	43.649839999999998	43.668804000000002	55.381740999999998	55.370072999999998	0103000020E61000000100000005000000FAD005F52DD34540F910548D5EAF4B40FAD005F52DD345406B459BE3DCB04B408DB7955E9BD545406B459BE3DCB04B408DB7955E9BD54540F910548D5EAF4B40FAD005F52DD34540F910548D5EAF4B40
9319	Васильев Враг	7	68	992	43.692627000000002	43.714699000000003	55.350233000000003	55.338740000000001	0103000020E61000000100000005000000CEA96400A8D845406CEC12D55BAB4B40CEA96400A8D84540707D586FD4AC4B40F1BDBF417BDB4540707D586FD4AC4B40F1BDBF417BDB45406CEC12D55BAB4B40CEA96400A8D845406CEC12D55BAB4B40
10485	Булдаково	7	68	992	43.481658000000003	43.498356999999999	55.350126000000003	55.335754999999999	0103000020E61000000100000005000000ABED26F8A6BD4540F73B1405FAAA4B40ABED26F8A6BD45405ABDC3EDD0AC4B40C85D8429CABF45405ABDC3EDD0AC4B40C85D8429CABF4540F73B1405FAAA4B40ABED26F8A6BD4540F73B1405FAAA4B40
8850	Большое Туманово	7	68	992	43.474066999999998	43.502462999999999	55.396825999999997	55.374375000000001	0103000020E61000000100000005000000718E3A3AAEBC454052B81E85EBAF4B40718E3A3AAEBC4540EB19C231CBB24B409B3924B550C04540EB19C231CBB24B409B3924B550C0454052B81E85EBAF4B40718E3A3AAEBC454052B81E85EBAF4B40
49709	Березовка	7	68	992	42.484293999999998	44.395738000000001	55.719186000000001	55.202706999999997	0103000020E6100000010000000500000013D38558FD3D4540CBD58F4DF2994B4013D38558FD3D4540DBDE6E490EDC4B4069E4F38AA7324640DBDE6E490EDC4B4069E4F38AA7324640CBD58F4DF2994B4013D38558FD3D4540CBD58F4DF2994B40
49803	Беговатово	7	68	992	43.587415999999997	43.615443999999997	55.272328999999999	55.256703000000002	0103000020E61000000100000005000000D5928E7230CB45407EE4D6A4DBA04B40D5928E7230CB45404E603AADDBA24B407C4276DEC6CE45404E603AADDBA24B407C4276DEC6CE45407EE4D6A4DBA04B40D5928E7230CB45407EE4D6A4DBA04B40
8713	Бебяево	7	68	992	43.929701000000001	43.946356000000002	55.314781000000004	55.303657999999999	0103000020E610000001000000050000007D073F7100F745409A95ED43DEA64B407D073F7100F745407B336ABE4AA84B40CB2F833122F945407B336ABE4AA84B40CB2F833122F945409A95ED43DEA64B407D073F7100F745409A95ED43DEA64B40
8612	Балахониха	7	68	992	43.346649999999997	43.380147999999998	55.487549999999999	55.451281999999999	0103000020E610000001000000050000004694F6065FAC454001A3CB9BC3B94B404694F6065FAC45401895D40968BE4B40E5D18DB0A8B045401895D40968BE4B40E5D18DB0A8B0454001A3CB9BC3B94B404694F6065FAC454001A3CB9BC3B94B40
8401	Абрамово	7	68	992	43.64649	43.679332000000002	55.416953999999997	55.40043	0103000020E6100000010000000500000074982F2FC0D245402C2B4D4A41B34B4074982F2FC0D24540DBF7A8BF5EB54B402A90D959F4D64540DBF7A8BF5EB54B402A90D959F4D645402C2B4D4A41B34B4074982F2FC0D245402C2B4D4A41B34B40
8318	Чуварлей-Майдан	7	68	907	42.881439	42.907221	55.144325000000002	55.129818	0103000020E61000000100000005000000A0353FFED2704540503750E09D904B40A0353FFED2704540637FD93D79924B40499F56D11F744540637FD93D79924B40499F56D11F744540503750E09D904B40A0353FFED2704540503750E09D904B40
8307	Хрипуново	7	68	907	43.181252000000001	43.210645	55.189424000000002	55.167858000000003	0103000020E61000000100000005000000D42AFA43339745409D2FF65E7C954B40D42AFA4333974540EC89AE0B3F984B407008556AF69A4540EC89AE0B3F984B407008556AF69A45409D2FF65E7C954B40D42AFA43339745409D2FF65E7C954B40
7978	Туркуши	7	68	907	43.001705999999999	43.026130999999999	55.368834999999997	55.349670000000003	0103000020E610000001000000050000007E1AF7E63780454038328FFCC1AC4B407E1AF7E637804540614F3BFC35AF4B40B534B74258834540614F3BFC35AF4B40B534B7425883454038328FFCC1AC4B407E1AF7E63780454038328FFCC1AC4B40
8171	Стексово	7	68	907	43.392006000000002	43.439481999999998	55.304493000000001	55.290126000000001	0103000020E61000000100000005000000FBEAAA402DB2454012DC48D922A54B40FBEAAA402DB24540336E6AA0F9A64B40209738F240B84540336E6AA0F9A64B40209738F240B8454012DC48D922A54B40FBEAAA402DB2454012DC48D922A54B40
7422	Саконы	7	68	907	43.089759000000001	43.171388999999998	55.487687999999999	55.370753000000001	0103000020E61000000100000005000000C6C210397D8B45406BF294D574AF4B40C6C210397D8B45406953758F6CBE4B4073F22213F09545406953758F6CBE4B4073F22213F09545406BF294D574AF4B40C6C210397D8B45406BF294D574AF4B40
7870	Размазлей	7	68	907	43.107886999999998	43.129050999999997	55.325032	55.311016000000002	0103000020E61000000100000005000000EF54C03DCF8D454031444E5FCFA74B40EF54C03DCF8D4540A51309A69AA94B400F4240BE84904540A51309A69AA94B400F4240BE8490454031444E5FCFA74B40EF54C03DCF8D454031444E5FCFA74B40
7123	Поляна	7	68	907	43.104716000000003	43.132041999999998	55.268245999999998	55.253332	0103000020E6100000010000000500000019AF7955678D4540E083D72E6DA04B4019AF7955678D454033A48AE255A24B4066D993C0E690454033A48AE255A24B4066D993C0E6904540E083D72E6DA04B4019AF7955678D4540E083D72E6DA04B40
7853	Надежино	7	68	907	43.270985000000003	43.298293999999999	55.186920999999998	55.175781000000001	0103000020E61000000100000005000000715AF0A2AFA245400C21E7FD7F964B40715AF0A2AFA24540C2F7FE06ED974B40E84B6F7F2EA64540C2F7FE06ED974B40E84B6F7F2EA645400C21E7FD7F964B40715AF0A2AFA245400C21E7FD7F964B40
7270	Мухтолово	7	68	907	43.160491999999998	43.221235999999998	55.478617999999997	55.452706999999997	0103000020E6100000010000000500000083A279008B944540CBD58F4DF2B94B4083A279008B94454072A3C85A43BD4B4053591476519C454072A3C85A43BD4B4053591476519C4540CBD58F4DF2B94B4083A279008B944540CBD58F4DF2B94B40
7798	Михеевка	7	68	907	43.124110000000002	43.149307999999998	55.141789000000003	55.126188999999997	0103000020E61000000100000005000000A48D23D6E28F4540B60E0EF626904B40A48D23D6E28F45405EF7562426924B40FD8348861C9345405EF7562426924B40FD8348861C934540B60E0EF626904B40A48D23D6E28F4540B60E0EF626904B40
7727	Личадеево	7	68	907	43.299767000000003	43.330983000000003	55.385674000000002	55.372902000000003	0103000020E61000000100000005000000C4B5DAC35EA64540774EB340BBAF4B40C4B5DAC35EA64540717500C45DB14B401844A4A65DAA4540717500C45DB14B401844A4A65DAA4540774EB340BBAF4B40C4B5DAC35EA64540774EB340BBAF4B40
7704	Липовка	7	68	907	43.199820000000003	43.245868000000002	55.378089000000003	55.369484999999997	0103000020E610000001000000050000001A8BA6B39399454068AED3484BAF4B401A8BA6B3939945401AFD683865B04B400491459A789F45401AFD683865B04B400491459A789F454068AED3484BAF4B401A8BA6B39399454068AED3484BAF4B40
7115	Леметь	7	68	907	43.074074000000003	43.095607000000001	55.302269000000003	55.280538999999997	0103000020E61000000100000005000000F1BDBF417B8945405320B3B3E8A34B40F1BDBF417B8945401DCC26C0B0A64B406422A5D93C8C45401DCC26C0B0A64B406422A5D93C8C45405320B3B3E8A34B40F1BDBF417B8945405320B3B3E8A34B40
8143	Кузятово	7	68	907	43.277462	43.298878000000002	55.258955999999998	55.242063000000002	0103000020E61000000100000005000000FEF0F3DF83A345402C499EEBFB9E4B40FEF0F3DF83A345402E8D5F7825A14B4038BF61A241A645402E8D5F7825A14B4038BF61A241A645402C499EEBFB9E4B40FEF0F3DF83A345402C499EEBFB9E4B40
7596	Кужендеево	7	68	907	43.073813999999999	43.099784	55.220711000000001	55.200051000000002	0103000020E6100000010000000500000054FEB5BC728945401C446B459B994B4054FEB5BC72894540096F0F42409C4B400055DCB8C58C4540096F0F42409C4B400055DCB8C58C45401C446B459B994B4054FEB5BC728945401C446B459B994B40
8083	Круглово	7	68	907	43.201590000000003	43.222349999999999	55.274769999999997	55.260396999999998	0103000020E61000000100000005000000AF997CB3CD994540FE7C5BB054A14B40AF997CB3CD99454001F6D1A92BA34B40FF21FDF6759C454001F6D1A92BA34B40FF21FDF6759C4540FE7C5BB054A14B40AF997CB3CD994540FE7C5BB054A14B40
7579	Котовка	7	68	907	42.988258000000002	43.016374999999996	55.287635000000002	55.272534	0103000020E610000001000000050000005401F73C7F7E45402786E464E2A24B405401F73C7F7E4540AD174339D1A44B406ABC749318824540AD174339D1A44B406ABC7493188245402786E464E2A24B405401F73C7F7E45402786E464E2A24B40
7542	Каркалей	7	68	907	42.796754999999997	42.813374000000003	55.139457999999998	55.132545999999998	0103000020E6100000010000000500000055F65D11FC654540999B6F44F7904B4055F65D11FC65454031957EC2D9914B4057B5A4A31C68454031957EC2D9914B4057B5A4A31C684540999B6F44F7904B4055F65D11FC654540999B6F44F7904B40
8003	Идеал	7	68	907	43.480176	43.500611999999997	55.246142999999996	55.230517999999996	0103000020E610000001000000050000007C293C6876BD4540D591239D819D4B407C293C6876BD4540D591239D819F4B4019FED30D14C04540D591239D819F4B4019FED30D14C04540D591239D819D4B407C293C6876BD4540D591239D819D4B40
7483	Журелейка	7	68	907	43.010869	43.033901	55.191566999999999	55.177221000000003	0103000020E6100000010000000500000026C5C727648145400C957F2DAF964B4026C5C7276481454015FF774485984B409E2633DE5684454015FF774485984B409E2633DE568445400C957F2DAF964B4026C5C727648145400C957F2DAF964B40
7662	Голяткино	7	68	907	43.269286999999998	43.286005000000003	55.365099999999998	55.356293000000001	0103000020E61000000100000005000000751E15FF77A2454099654F029BAD4B40751E15FF77A2454082E2C798BBAE4B400ABFD4CF9BA4454082E2C798BBAE4B400ABFD4CF9BA4454099654F029BAD4B40751E15FF77A2454099654F029BAD4B40
7413	Венец	7	68	907	42.970283000000002	42.994366999999997	55.505037000000002	55.494216000000002	0103000020E61000000100000005000000B16EBC3B327C454079944A7842BF4B40B16EBC3B327C45408E226B0DA5C04B405E9CF86A477F45408E226B0DA5C04B405E9CF86A477F454079944A7842BF4B40B16EBC3B327C454079944A7842BF4B40
8244	Атемасово	7	68	907	43.238501999999997	43.265469000000003	55.161116	55.148584999999997	0103000020E61000000100000005000000EA03C93B879E45408CD651D504934B40EA03C93B879E4540616EF7729F944B40098D60E3FAA14540616EF7729F944B40098D60E3FAA145408CD651D504934B40EA03C93B879E45408CD651D504934B40
36370	Ардатов	7	68	907	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
49761	Ардатов	7	68	907	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
49751	Павлово	7	68	6974	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
49743	Городец	7	68	6982	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
55970	Яранск	7	67	\N	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
6838	Слободской	7	67	\N	50.143824000000002	50.251514	58.758141999999999	58.687725	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
31734	Порошино	7	67	\N	49.776215999999998	49.812112999999997	58.615046999999997	58.601475999999998	0103000020E61000000100000005000000E350BF0B5BE3484019AA622AFD4C4D40E350BF0B5BE348405F402FDCB94E4D4006D49B51F3E748405F402FDCB94E4D4006D49B51F3E7484019AA622AFD4C4D40E350BF0B5BE3484019AA622AFD4C4D40
55978	Орлов	7	67	\N	48.860427999999999	48.920993000000003	58.555990000000001	58.524299999999997	0103000020E6100000010000000500000006483481226E48407AA52C431C434D4006483481226E4840977329AE2A474D40276C3F19E3754840977329AE2A474D40276C3F19E37548407AA52C431C434D4006483481226E48407AA52C431C434D40
55977	Омутнинск	7	67	\N	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
55983	Мураши	7	67	\N	48.942166	49.026266	59.413870000000003	59.377640999999997	0103000020E610000001000000050000009AB33EE5987848407A50508A56B04D409AB33EE598784840D46531B1F9B44D40957F2DAF5C834840D46531B1F9B44D40957F2DAF5C8348407A50508A56B04D409AB33EE5987848407A50508A56B04D40
55976	Малмыж	7	67	\N	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
55975	Луза	7	67	\N	47.200395999999998	47.313448999999999	60.63908	60.604889	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
1207	Котельнич	7	67	\N	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
55981	Кирово-Чепецк	7	67	\N	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
369	Киров	7	67	\N	49.530445999999998	49.794128000000001	58.681148999999998	58.481724	0103000020E61000000100000005000000A2258FA7E5C3484062D9CC21A93D4D40A2258FA7E5C34840FF59F3E32F574D40406B7EFCA5E54840FF59F3E32F574D40406B7EFCA5E5484062D9CC21A93D4D40A2258FA7E5C3484062D9CC21A93D4D40
11679	Вятские Поляны	7	67	\N	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
55980	Белая Холуница	7	67	\N	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
6761	Яранск	7	67	87	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
57427	Энгенер	7	67	87	47.396191999999999	48.555711000000002	57.462997999999999	56.957776000000003	0103000020E61000000100000005000000EA77616BB6B2474065726A67987A4C40EA77616BB6B24740840EBA8443BB4C408483BD8921474840840EBA8443BB4C408483BD892147484065726A67987A4C40EA77616BB6B2474065726A67987A4C40
104	Шкаланка	7	67	87	47.938980999999998	47.960729999999998	57.129206000000003	57.118056000000003	0103000020E610000001000000050000005E48878730F847405D8C81751C8F4C405E48878730F8474037397CD289904C409E245D33F9FA474037397CD289904C409E245D33F9FA47405D8C81751C8F4C405E48878730F847405D8C81751C8F4C40
31873	Уртма	7	67	87	47.459218	47.486742999999997	57.282176999999997	57.269317000000001	0103000020E6100000010000000500000005DEC9A7C7BA4740E0A0BDFA78A24C4005DEC9A7C7BA474079573D601EA44C40494739984DBE474079573D601EA44C40494739984DBE4740E0A0BDFA78A24C4005DEC9A7C7BA4740E0A0BDFA78A24C40
32416	Сердеж	7	67	87	48.278823000000003	48.299996	57.285310000000003	57.274334000000003	0103000020E61000000100000005000000B22FD978B0234840271763601DA34C40B22FD978B0234840639CBF0985A44C402577D84466264840639CBF0985A44C402577D84466264840271763601DA34C40B22FD978B0234840271763601DA34C40
32310	Салобеляк	7	67	87	48.040320000000001	48.074204999999999	57.111761999999999	57.095585	0103000020E61000000100000005000000F7AFAC34290548407C7E18213C8C4C40F7AFAC3429054840C0779B374E8E4C408F19A88C7F094840C0779B374E8E4C408F19A88C7F0948407C7E18213C8C4C40F7AFAC34290548407C7E18213C8C4C40
32068	Савичи	7	67	87	48.099348999999997	48.128813000000001	57.428601999999998	57.412981000000002	0103000020E61000000100000005000000F5F1D077B70C4840486FB88FDCB44C40F5F1D077B70C484006802A6EDCB64C405B26C3F17C10484006802A6EDCB64C405B26C3F17C104840486FB88FDCB44C40F5F1D077B70C4840486FB88FDCB44C40
56009	Рождественск	7	67	87	47.832521999999997	47.866083000000003	57.395240000000001	57.385553000000002	0103000020E61000000100000005000000AA99B51490EA4740F6EFFACC59B14C40AA99B51490EA474018096D3997B24C40904FC8CEDBEE474018096D3997B24C40904FC8CEDBEE4740F6EFFACC59B14C40AA99B51490EA4740F6EFFACC59B14C40
32251	Пушкино	7	67	87	48.212617000000002	48.219453000000001	57.334229000000001	57.329307999999997	0103000020E610000001000000050000006DC9AA08371B4840D427B9C326AA4C406DC9AA08371B4840F92F1004C8AA4C402A013109171C4840F92F1004C8AA4C402A013109171C4840D427B9C326AA4C406DC9AA08371B4840D427B9C326AA4C40
6826	Пиштань	7	67	87	47.935864000000002	47.957424000000003	57.357939000000002	57.340373999999997	0103000020E610000001000000050000007BC03C64CAF7474050340F6091AB4C407BC03C64CAF74740427BF5F1D0AD4C40E833A0DE8CFA4740427BF5F1D0AD4C40E833A0DE8CFA474050340F6091AB4C407BC03C64CAF7474050340F6091AB4C40
31967	Первомайское	7	67	87	47.554133999999998	47.571300999999998	57.147520999999998	57.13711	0103000020E6100000010000000500000003CDE7DCEDC647402FFA0AD28C914C4003CDE7DCEDC64740923CD7F7E1924C400796236420C94740923CD7F7E1924C400796236420C947402FFA0AD28C914C4003CDE7DCEDC647402FFA0AD28C914C40
32157	Опытное Поле	7	67	87	47.900686	47.934255999999998	57.392363000000003	57.376693000000003	0103000020E6100000010000000500000087FBC8AD49F34740EAD0E97937B04C4087FBC8AD49F347408A9466F338B24C40BF0B5BB395F747408A9466F338B24C40BF0B5BB395F74740EAD0E97937B04C4087FBC8AD49F34740EAD0E97937B04C40
32135	Никулята	7	67	87	48.257767000000001	48.447885999999997	57.369754	57.181874999999998	0103000020E61000000100000005000000787E5182FE204840E17A14AE47974C40787E5182FE20484058C85C1954AF4C400A2B15545439484058C85C1954AF4C400A2B155454394840E17A14AE47974C40787E5182FE204840E17A14AE47974C40
31988	Никола	7	67	87	48.055213999999999	48.095818000000001	57.389772999999998	57.374723000000003	0103000020E6100000010000000500000003249A40110748408E075BECF6AF4C4003249A401107484091EEE714E4B14C401F2FA4C3430C484091EEE714E4B14C401F2FA4C3430C48408E075BECF6AF4C4003249A40110748408E075BECF6AF4C40
32467	Мари-Ушем	7	67	87	48.185865	48.210352999999998	57.240713999999997	57.233018000000001	0103000020E610000001000000050000004B3CA06CCA1748408EB0A888D39D4C404B3CA06CCA1748403CD862B7CF9E4C40C8CEDBD8EC1A48403CD862B7CF9E4C40C8CEDBD8EC1A48408EB0A888D39D4C404B3CA06CCA1748408EB0A888D39D4C40
30232	Лум	7	67	87	47.897084	47.916541000000002	57.186587000000003	57.172224999999997	0103000020E61000000100000005000000E7E104A6D3F24740DC4603780B964C40E7E104A6D3F24740EC6D3315E2974C40B9382A3751F54740EC6D3315E2974C40B9382A3751F54740DC4603780B964C40E7E104A6D3F24740DC4603780B964C40
31804	Лом	7	67	87	47.6646	47.690219999999997	57.402436000000002	57.388953000000001	0103000020E61000000100000005000000F775E09C11D547402E573F36C9B14C40F775E09C11D54740D55DD90583B34C40C685032159D84740D55DD90583B34C40C685032159D847402E573F36C9B14C40F775E09C11D547402E573F36C9B14C40
32518	Кугушерга	7	67	87	47.628352999999997	47.650199999999998	57.210845999999997	57.201870999999997	0103000020E61000000100000005000000F7AB00DF6DD047406281AFE8D6994C40F7AB00DF6DD04740073F7100FD9A4C40FAEDEBC039D34740073F7100FD9A4C40FAEDEBC039D347406281AFE8D6994C40F7AB00DF6DD047406281AFE8D6994C40
31786	Кугалки	7	67	87	47.631407000000003	47.680517999999999	57.316575999999998	57.305638000000002	0103000020E6100000010000000500000095BBCFF1D1D047401A355F251FA74C4095BBCFF1D1D047406859F78F85A84C406F2BBD361BD747406859F78F85A84C406F2BBD361BD747401A355F251FA74C4095BBCFF1D1D047401A355F251FA74C40
119	Каракша	7	67	87	47.907890999999999	47.937562	57.038952999999999	57.024400999999997	0103000020E6100000010000000500000097AAB4C535F44740AE7E6C921F834C4097AAB4C535F44740618A7269FC844C4076FC170802F84740618A7269FC844C4076FC170802F84740AE7E6C921F834C4097AAB4C535F44740AE7E6C921F834C40
31637	Иваново	7	67	87	47.867573999999998	47.896948999999999	57.351855	57.334676000000002	0103000020E61000000100000005000000116E32AA0CEF4740C860C5A9D6AA4C40116E32AA0CEF474090F7AA9509AD4C4007978E39CFF2474090F7AA9509AD4C4007978E39CFF24740C860C5A9D6AA4C40116E32AA0CEF4740C860C5A9D6AA4C40
30923	Знаменка	7	67	87	47.822918999999999	47.849086999999997	57.252893	57.238342000000003	0103000020E61000000100000005000000E620E86855E94740B2A19BFD819E4C40E620E86855E9474094313ECC5EA04C40B83A00E2AEEC474094313ECC5EA04C40B83A00E2AEEC4740B2A19BFD819E4C40E620E86855E94740B2A19BFD819E4C40
31694	Демино	7	67	87	47.912624999999998	47.945323999999999	57.298971999999999	57.283442000000001	0103000020E61000000100000005000000894160E5D0F447400B28D4D347A44C40894160E5D0F44740B935E9B644A64C40DC0F786000F94740B935E9B644A64C40DC0F786000F947400B28D4D347A44C40894160E5D0F447400B28D4D347A44C40
31609	Высоково	7	67	87	47.852986000000001	48.061314000000003	57.229861	57.068930999999999	0103000020E6100000010000000500000012F92EA52EED47401D5723BBD2884C4012F92EA52EED47401CD0D2156C9D4C40BB641C23D90748401CD0D2156C9D4C40BB641C23D90748401D5723BBD2884C4012F92EA52EED47401D5723BBD2884C40
32330	Верхоуслино	7	67	87	48.154451000000002	48.175947999999998	57.143169999999998	57.129558000000003	0103000020E61000000100000005000000D1EAE40CC5134840B477465B95904C40D1EAE40CC513484058E2016553924C40F7E5CC768516484058E2016553924C40F7E5CC7685164840B477465B95904C40D1EAE40CC5134840B477465B95904C40
30617	Юрья	7	67	1882	49.242643999999999	49.314337999999999	59.054067000000003	59.027614999999997	0103000020E610000001000000050000000A4966F50E9F484084F068E388834D400A4966F50E9F48407C65DEAAEB864D40EDF1423A3CA848407C65DEAAEB864D40EDF1423A3CA8484084F068E388834D400A4966F50E9F484084F068E388834D40
30011	Северный	7	67	1882	49.279591000000003	49.313448999999999	59.086367000000003	59.068913999999999	0103000020E61000000100000005000000C3A04CA3C9A34840471E882CD2884D40C3A04CA3C9A34840113AE8120E8B4D4061FBC9181FA84840113AE8120E8B4D4061FBC9181FA84840471E882CD2884D40C3A04CA3C9A34840471E882CD2884D40
30551	Подгорцы	7	67	1882	49.470007000000003	49.503326000000001	58.810648999999998	58.798305999999997	0103000020E610000001000000050000000FF27A3029BC4840AC1919E42E664D400FF27A3029BC48407EC4AF58C3674D40FE9C82FC6CC048407EC4AF58C3674D40FE9C82FC6CC04840AC1919E42E664D400FF27A3029BC4840AC1919E42E664D40
56035	Первомайский	7	67	1882	49.270544999999998	49.299965	59.071629000000001	59.053327000000003	0103000020E61000000100000005000000548CF337A1A24840357F4C6BD3864D40548CF337A1A24840FC389A232B894D40EA78CC4065A64840FC389A232B894D40EA78CC4065A64840357F4C6BD3864D40548CF337A1A24840357F4C6BD3864D40
30788	Мурыгино	7	67	1882	49.433607000000002	49.495600000000003	58.751975000000002	58.726215000000003	0103000020E610000001000000050000008928266F80B74840AD6EF59CF45C4D408928266F80B748406E3480B740604D40E5F21FD26FBF48406E3480B740604D40E5F21FD26FBF4840AD6EF59CF45C4D408928266F80B74840AD6EF59CF45C4D40
30296	Монастырское	7	67	1882	49.401223000000002	49.424804000000002	58.902841000000002	58.890089000000003	0103000020E6100000010000000500000096B377465BB34840C2C3B46FEE714D4096B377465BB34840753E3C4B90734D40E19A3BFA5FB64840753E3C4B90734D40E19A3BFA5FB64840C2C3B46FEE714D4096B377465BB34840C2C3B46FEE714D40
56001	Медяна	7	67	1882	49.339671000000003	49.369486000000002	58.783752	58.769570999999999	0103000020E610000001000000050000002733DE567AAB48409A79724D81624D402733DE567AAB484059164CFC51644D40392A37514BAF484059164CFC51644D40392A37514BAF48409A79724D81624D402733DE567AAB48409A79724D81624D40
30318	Ложкари	7	67	1882	49.580894999999998	49.602024	58.893869000000002	58.878123000000002	0103000020E6100000010000000500000078B471C45ACA4840C66E9F5566704D4078B471C45ACA484041F4A44C6A724D401CB4571F0FCD484041F4A44C6A724D401CB4571F0FCD4840C66E9F5566704D4078B471C45ACA4840C66E9F5566704D40
56010	Комарово	7	67	1882	49.419215999999999	49.427095000000001	58.917907	58.912233999999998	0103000020E61000000100000005000000DFFAB0DEA8B548404E266E15C4744D40DFFAB0DEA8B548407EE200FA7D754D407FA4880CABB648407EE200FA7D754D407FA4880CABB648404E266E15C4744D40DFFAB0DEA8B548404E266E15C4744D40
30111	Кокино	7	67	1882	49.537973999999998	49.563189000000001	58.993929000000001	58.980246000000001	0103000020E61000000100000005000000950C0055DCC44840750470B3787D4D40950C0055DCC44840E3C5C210397F4D40C53BC09316C84840E3C5C210397F4D40C53BC09316C84840750470B3787D4D40950C0055DCC44840750470B3787D4D40
30032	Ивановщина	7	67	1882	49.313377000000003	49.342382999999998	59.03895	59.029111	0103000020E61000000100000005000000C828CFBC1CA84840187AC4E8B9834D40C828CFBC1CA84840F0164850FC844D406ADAC534D3AB4840F0164850FC844D406ADAC534D3AB4840187AC4E8B9834D40C828CFBC1CA84840187AC4E8B9834D40
30402	Загарье	7	67	1882	49.594845999999997	49.631264000000002	58.821846999999998	58.806781000000001	0103000020E610000001000000050000000514EAE923CC484060048D9944674D400514EAE923CC484069A8514832694D4032923D42CDD0484069A8514832694D4032923D42CDD0484060048D9944674D400514EAE923CC484060048D9944674D40
30447	Гирсово	7	67	1882	49.534964000000002	49.571921000000003	58.737864000000002	58.722617	0103000020E61000000100000005000000C8444AB379C448404E44BFB67E5C4D40C8444AB379C44840A872DA53725E4D40A47213B534C94840A872DA53725E4D40A47213B534C948404E44BFB67E5C4D40C8444AB379C448404E44BFB67E5C4D40
30149	Высоково	7	67	1882	49.289535999999998	49.317213000000002	58.994132999999998	58.983691999999998	0103000020E61000000100000005000000E08101840FA548401DAB949EE97D4D40E08101840FA54840EB6F09C03F7F4D40DB6E826F9AA84840EB6F09C03F7F4D40DB6E826F9AA848401DAB949EE97D4D40E08101840FA548401DAB949EE97D4D40
29930	Верходворье	7	67	1882	49.131351000000002	49.165649000000002	59.157800000000002	59.146217999999998	0103000020E6100000010000000500000001A60C1CD0904840130B7C45B7924D4001A60C1CD090484087A757CA32944D40BCCE86FC3395484087A757CA32944D40BCCE86FC33954840130B7C45B7924D4001A60C1CD0904840130B7C45B7924D40
30172	Верховино	7	67	1882	49.169269	49.187325000000001	59.038598	59.019925999999998	0103000020E61000000100000005000000029D499BAA954840882B67EF8C824D40029D499BAA95484073D87DC7F0844D40925CFE43FA97484073D87DC7F0844D40925CFE43FA974840882B67EF8C824D40029D499BAA954840882B67EF8C824D40
30597	Великорецкое	7	67	1882	49.032563000000003	49.066619000000003	58.900917	58.888629000000002	0103000020E61000000100000005000000A3073E062B8448407BA35698BE714D40A3073E062B84484089B48D3F51734D406825ADF88688484089B48D3F51734D406825ADF8868848407BA35698BE714D40A3073E062B8448407BA35698BE714D40
56011	Великая	7	67	1882	49.020893999999998	49.049720999999998	59.233387999999998	59.217098	0103000020E61000000100000005000000605793A7AC824840750305DEC99B4D40605793A7AC824840B1A371A8DF9D4D405376FA415D864840B1A371A8DF9D4D405376FA415D864840750305DEC99B4D40605793A7AC824840750305DEC99B4D40
29838	Черновское	7	67	1862	47.375908000000003	47.428989999999999	58.695810999999999	58.676586999999998	0103000020E610000001000000050000000327DBC01DB047400AF31E679A564D400327DBC01DB047403999B85510594D40D027F224E9B647403999B85510594D40D027F224E9B647400AF31E679A564D400327DBC01DB047400AF31E679A564D40
55999	Чащино	7	67	1862	47.389733	47.394899000000002	58.657442000000003	58.654801999999997	0103000020E6100000010000000500000003965CC5E2B147407DAD4B8DD0534D4003965CC5E2B147402882380F27544D408F1CE90C8CB247402882380F27544D408F1CE90C8CB247407DAD4B8DD0534D4003965CC5E2B147407DAD4B8DD0534D40
29823	Соловецкое	7	67	1862	47.120499000000002	47.141646000000001	58.559885999999999	58.542076000000002	0103000020E61000000100000005000000B119E0826C8F474027F911BF62454D40B119E0826C8F47407FBE2D58AA474D40FBCDC474219247407FBE2D58AA474D40FBCDC4742192474027F911BF62454D40B119E0826C8F474027F911BF62454D40
29677	Содом	7	67	1862	47.106772999999997	47.124209	58.198098000000002	58.186039999999998	0103000020E61000000100000005000000438CD7BCAA8D4740B9DFA128D0174D40438CD7BCAA8D474096B377465B194D40376F9C14E68F474096B377465B194D40376F9C14E68F4740B9DFA128D0174D40438CD7BCAA8D4740B9DFA128D0174D40
29356	Семеновское	7	67	1862	47.339913000000003	47.355291999999999	58.301076000000002	58.288134999999997	0103000020E610000001000000050000001D3EE94482AB47409EEA909BE1244D401D3EE94482AB474025CE8AA889264D40E54350357AAD474025CE8AA889264D40E54350357AAD47409EEA909BE1244D401D3EE94482AB47409EEA909BE1244D40
29547	Прокопьевское	7	67	1862	46.796090999999997	46.829884999999997	58.373714999999997	58.360626000000003	0103000020E61000000100000005000000E9D1544FE66547402D0B26FE282E4D40E9D1544FE66547402783A3E4D52F4D407138F3AB396A47402783A3E4D52F4D407138F3AB396A47402D0B26FE282E4D40E9D1544FE66547402D0B26FE282E4D40
29700	Новотроицкое	7	67	1862	47.046990000000001	47.101500000000001	58.463290000000001	58.433993999999998	0103000020E61000000100000005000000999EB0C40386474082548A1D8D374D40999EB0C4038647402C4833164D3B4D40A245B6F3FD8C47402C4833164D3B4D40A245B6F3FD8C474082548A1D8D374D40999EB0C40386474082548A1D8D374D40
29421	Николаевское	7	67	1862	46.666696999999999	46.699612000000002	58.528322000000003	58.512906999999998	0103000020E61000000100000005000000B0ABC95356554740DA71C3EFA6414D40B0ABC95356554740F0E0270EA0434D40D0F1D1E28C594740F0E0270EA0434D40D0F1D1E28C594740DA71C3EFA6414D40B0ABC95356554740DA71C3EFA6414D40
29296	Луни	7	67	1862	47.309469	47.329627000000002	58.388345999999999	58.377693000000001	0103000020E610000001000000050000001B1021AE9CA74740CD76853E58304D401B1021AE9CA7474026C45C52B5314D407670B03731AA474026C45C52B5314D407670B03731AA4740CD76853E58304D401B1021AE9CA74740CD76853E58304D40
55969	Ленинское	7	67	1862	47.076113999999997	47.137369999999997	58.326366999999998	58.291437000000002	0103000020E610000001000000050000004562821ABE89474014ECBFCE4D254D404562821ABE8947402FBFD364C6294D40CBB91457959147402FBFD364C6294D40CBB914579591474014ECBFCE4D254D404562821ABE89474014ECBFCE4D254D40
29495	Колосово	7	67	1862	46.855801999999997	46.883020999999999	58.458464999999997	58.447865999999998	0103000020E61000000100000005000000FAEC80EB8A6D4740C37E4FAC53394D40FAEC80EB8A6D474029AE2AFBAE3A4D40325706D50671474029AE2AFBAE3A4D40325706D506714740C37E4FAC53394D40FAEC80EB8A6D4740C37E4FAC53394D40
29404	Гостовский	7	67	1862	46.662700000000001	46.702513000000003	58.340721000000002	58.322941	0103000020E610000001000000050000009487855AD3544740CEC4742156294D409487855AD3544740BC07E8BE9C2B4D40E7012CF2EB594740BC07E8BE9C2B4D40E7012CF2EB594740CEC4742156294D409487855AD3544740CEC4742156294D40
29564	Высокораменское	7	67	1862	47.069664000000003	47.104725000000002	58.152422999999999	58.130495000000003	0103000020E61000000100000005000000B2DAFCBFEA88474051A5660FB4104D40B2DAFCBFEA8847404014CC9882134D406C09F9A0678D47404014CC9882134D406C09F9A0678D474051A5660FB4104D40B2DAFCBFEA88474051A5660FB4104D40
29629	Высокогорье	7	67	1862	47.172637999999999	47.214202999999998	58.249600999999998	58.236541000000003	0103000020E61000000100000005000000FF05820019964740E294B9F9461E4D40FF058200199647404206F2ECF21F4D4040DAFF006B9B47404206F2ECF21F4D4040DAFF006B9B4740E294B9F9461E4D40FF05820019964740E294B9F9461E4D40
29776	Архангельское	7	67	1862	46.881027000000003	46.914434999999997	58.551558	58.533597999999998	0103000020E610000001000000050000004EF2237EC5704740029B73F04C444D404EF2237EC570474070ECD97399464D40ACA8C1340C75474070ECD97399464D40ACA8C1340C754740029B73F04C444D404EF2237EC5704740029B73F04C444D40
28904	Юсово	7	67	1841	51.684696000000002	51.707998000000003	58.333010999999999	58.321976999999997	0103000020E61000000100000005000000DCD9571EA4D749403788D68A36294D40DCD9571EA4D74940A81ABD1AA02A4D4014D1AFAD9FDA4940A81ABD1AA02A4D4014D1AFAD9FDA49403788D68A36294D40DCD9571EA4D749403788D68A36294D40
55998	Чуваши	7	67	1841	51.671669999999999	51.686861	57.890228999999998	57.882491999999999	0103000020E6100000010000000500000027DA5548F9D54940A67D737FF5F04C4027DA5548F9D54940B3791C06F3F14C40EDF2AD0FEBD74940B3791C06F3F14C40EDF2AD0FEBD74940A67D737FF5F04C4027DA5548F9D54940A67D737FF5F04C40
28857	Филейка	7	67	1841	51.362217999999999	51.397846000000001	57.988686999999999	57.959124000000003	0103000020E61000000100000005000000E202D0285DAE494084674293C4FA4C40E202D0285DAE49407C7DAD4B8DFE4C40166C239EECB249407C7DAD4B8DFE4C40166C239EECB2494084674293C4FA4C40E202D0285DAE494084674293C4FA4C40
28963	Фаленки	7	67	1841	51.554422000000002	51.654494	58.376885999999999	58.330941000000003	0103000020E610000001000000050000006A17D34CF7C64940E9F351465C2A4D406A17D34CF7C64940FE28EACC3D304D40D0B69A75C6D34940FE28EACC3D304D40D0B69A75C6D34940E9F351465C2A4D406A17D34CF7C64940E9F351465C2A4D40
28800	Талица	7	67	1841	51.480238999999997	51.533850999999999	58.028691999999999	58.001170000000002	0103000020E61000000100000005000000C2A1B77878BD494040DEAB5626004D40C2A1B77878BD494013D4F02DAC034D40ECF7C43A55C4494013D4F02DAC034D40ECF7C43A55C4494040DEAB5626004D40C2A1B77878BD494040DEAB5626004D40
28774	Святица	7	67	1841	51.570098000000002	51.595537999999998	58.212190999999997	58.194445999999999	0103000020E61000000100000005000000ECC1A4F8F8C84940446B459BE3184D40ECC1A4F8F8C84940B5C01E13291B4D403BC3D4963ACC4940B5C01E13291B4D403BC3D4963ACC4940446B459BE3184D40ECC1A4F8F8C84940446B459BE3184D40
28701	Полом	7	67	1841	51.197215999999997	51.215145999999997	57.920614	57.902656	0103000020E61000000100000005000000BC1FB75F3E994940E3C4573B8AF34C40BC1FB75F3E994940B01EF7ADD6F54C40BFEE74E7899B4940B01EF7ADD6F54C40BFEE74E7899B4940E3C4573B8AF34C40BC1FB75F3E994940E3C4573B8AF34C40
28676	Подоплеки	7	67	1841	51.388331999999998	51.417177000000002	58.137836	58.123818	0103000020E61000000100000005000000C1FEEBDCB4B14940FC53AA44D90F4D40C1FEEBDCB4B14940111B2C9CA4114D405BD2510E66B54940111B2C9CA4114D405BD2510E66B54940FC53AA44D90F4D40C1FEEBDCB4B14940FC53AA44D90F4D40
28612	Петруненки	7	67	1841	51.498744000000002	51.522415000000002	58.147745	58.135854999999999	0103000020E61000000100000005000000C289E8D7D6BF4940C1FF56B263114D40C289E8D7D6BF4940E292E34EE9124D404DF8A57EDEC24940E292E34EE9124D404DF8A57EDEC24940C1FF56B263114D40C289E8D7D6BF4940C1FF56B263114D40
28586	Паньшонки	7	67	1841	51.518138999999998	51.538459000000003	57.934162000000001	57.921053999999998	0103000020E610000001000000050000001DE4F56052C24940CCECF318E5F54C401DE4F56052C249403E95D39E92F74C40529E7939ECC449403E95D39E92F74C40529E7939ECC44940CCECF318E5F54C401DE4F56052C24940CCECF318E5F54C40
28395	Октябрьский	7	67	1841	51.509874000000003	51.547288999999999	58.214717999999998	58.194251000000001	0103000020E61000000100000005000000558A1D8D43C149408F1B7E37DD184D40558A1D8D43C1494067EE21E17B1B4D40F33AE2900DC6494067EE21E17B1B4D40F33AE2900DC649408F1B7E37DD184D40558A1D8D43C149408F1B7E37DD184D40
28526	Николаево	7	67	1841	51.741092000000002	51.781416999999998	58.409534999999998	58.391308000000002	0103000020E61000000100000005000000E3A9471ADCDE4940E3546B6116324D40E3A9471ADCDE49409FC893A46B344D40EBC4E57805E449409FC893A46B344D40EBC4E57805E44940E3546B6116324D40E3A9471ADCDE4940E3546B6116324D40
28496	Низево	7	67	1841	51.558616999999998	51.593544000000001	58.470393000000001	58.446857999999999	0103000020E61000000100000005000000ACFE08C380C749405DFA97A432394D40ACFE08C380C7494038A27BD6353C4D40575EF23FF9CB494038A27BD6353C4D40575EF23FF9CB49405DFA97A432394D40ACFE08C380C749405DFA97A432394D40
28442	Малахи	7	67	1841	51.542608999999999	51.565111999999999	58.278455000000001	58.264524999999999	0103000020E61000000100000005000000F4C1323674C54940B9FC87F4DB214D40F4C1323674C549402F34D769A4234D40E0490B9755C849402F34D769A4234D40E0490B9755C84940B9FC87F4DB214D40F4C1323674C54940B9FC87F4DB214D40
28341	Леваны	7	67	1841	51.490443999999997	51.511986	58.406134999999999	58.389436000000003	0103000020E610000001000000050000007C4276DEC6BE49404AF1F109D9314D407C4276DEC6BE494067614F3BFC334D404301DBC188C1494067614F3BFC334D404301DBC188C149404AF1F109D9314D407C4276DEC6BE49404AF1F109D9314D40
28300	Вогульцы	7	67	1841	51.616126999999999	51.654179999999997	58.068519000000002	58.040280000000003	0103000020E610000001000000050000005F97E13FDDCE4940695721E527054D405F97E13FDDCE4940CB13083BC5084D4040D9942BBCD34940CB13083BC5084D4040D9942BBCD34940695721E527054D405F97E13FDDCE4940695721E527054D40
28246	Верхосунье	7	67	1841	51.311131000000003	51.347082	58.034863000000001	58.015250999999999	0103000020E61000000100000005000000CAE2FE23D3A749409B1DA9BEF3014D40CAE2FE23D3A74940946B0A6476044D40E083D72E6DAC4940946B0A6476044D40E083D72E6DAC49409B1DA9BEF3014D40CAE2FE23D3A749409B1DA9BEF3014D40
28222	Белая	7	67	1841	51.658518999999998	51.699356000000002	57.989699000000002	57.973174	0103000020E61000000100000005000000B665C0594AD44940A4A833F790FC4C40B665C0594AD4494024F1F274AEFE4C407521567F84D9494024F1F274AEFE4C407521567F84D94940A4A833F790FC4C40B665C0594AD44940A4A833F790FC4C40
1836	Шурма	7	67	359	50.32161	50.372292999999999	56.985300000000002	56.950355000000002	0103000020E61000000100000005000000850838842A294940884B8E3BA5794C40850838842A294940D95F764F1E7E4C40CEC3094CA72F4940D95F764F1E7E4C40CEC3094CA72F4940884B8E3BA5794C40850838842A294940884B8E3BA5794C40
27997	Шевнино	7	67	359	50.048639000000001	50.074807	57.050367000000001	57.034216999999998	0103000020E61000000100000005000000B32781CD39064940CEFBFF3861844C40B32781CD3906494019E6046D72864C40854199469309494019E6046D72864C408541994693094940CEFBFF3861844C40B32781CD39064940CEFBFF3861844C40
27802	Цепочкино	7	67	359	50.080762999999997	50.106274999999997	57.188046	57.172840000000001	0103000020E6100000010000000500000009DD2571560A494067B8019F1F964C4009DD2571560A494062122EE411984C40F2B0506B9A0D494062122EE411984C40F2B0506B9A0D494067B8019F1F964C4009DD2571560A494067B8019F1F964C40
25893	Уржум	7	67	359	49.983474999999999	50.016272999999998	57.134047000000002	57.085495999999999	0103000020E6100000010000000500000080B74082E2FD48402BF86D88F18A4C4080B74082E2FD48403F90BC7328914C406667D13B150249403F90BC7328914C406667D13B150249402BF86D88F18A4C4080B74082E2FD48402BF86D88F18A4C40
26903	Тюм-Тюм	7	67	359	50.405009999999997	50.445532999999998	56.95917	56.943973	0103000020E61000000100000005000000C746205ED73349404CA7751BD4784C40C746205ED7334940F4A62215C67A4C40F624B03907394940F4A62215C67A4C40F624B039073949404CA7751BD4784C40C746205ED73349404CA7751BD4784C40
27787	Толгозино	7	67	359	49.97813	49.992942999999997	56.922657999999998	56.912256999999997	0103000020E61000000100000005000000459E245D33FD484006465ED6C4744C40459E245D33FD484046B247A819764C4064E597C118FF484046B247A819764C4064E597C118FF484006465ED6C4744C40459E245D33FD484006465ED6C4744C40
27884	Теребиловка	7	67	359	49.979298	49.992755000000002	57.136611000000002	57.122371000000001	0103000020E61000000100000005000000E48409A359FD48404A7D59DAA98F4C40E48409A359FD48400EA320787C914C4062F8889812FF48400EA320787C914C4062F8889812FF48404A7D59DAA98F4C40E48409A359FD48404A7D59DAA98F4C40
26590	Танабаево	7	67	359	50.312950000000001	50.352099000000003	56.847113999999998	56.834603999999999	0103000020E6100000010000000500000040A4DFBE0E2849402E8ECA4DD46A4C4040A4DFBE0E284940EBFD463B6E6C4C4027FA7C94112D4940EBFD463B6E6C4C4027FA7C94112D49402E8ECA4DD46A4C4040A4DFBE0E2849402E8ECA4DD46A4C40
26430	Старая Берсениха	7	67	359	49.940401000000001	49.960245	57.095908000000001	57.085887	0103000020E6100000010000000500000017105A0F5FF8484066136058FE8A4C4017105A0F5FF848405FB69DB6468C4C40E292E34EE9FA48405FB69DB6468C4C40E292E34EE9FA484066136058FE8A4C4017105A0F5FF8484066136058FE8A4C40
6669	Собакино	7	67	359	50.008502	50.027250000000002	57.028995999999999	57.019913000000003	0103000020E61000000100000005000000ADF9F19716014940F4E159828C824C40ADF9F197160149407FDB1324B6834C40736891ED7C0349407FDB1324B6834C40736891ED7C034940F4E159828C824C40ADF9F19716014940F4E159828C824C40
27688	Савиново	7	67	359	50.105511	50.130564999999997	56.966633999999999	56.950733	0103000020E61000000100000005000000232F6B62810D49402E1D739EB1794C40232F6B62810D4940D099B4A9BA7B4C4049809A5AB6104940D099B4A9BA7B4C4049809A5AB61049402E1D739EB1794C40232F6B62810D49402E1D739EB1794C40
27543	Русское Тимкино	7	67	359	50.079424000000003	50.098863999999999	57.129503999999997	57.117978000000001	0103000020E610000001000000050000003E42CD902A0A4940E1D231E7198F4C403E42CD902A0A4940C0594A9693904C4039605793A70C4940C0594A9693904C4039605793A70C4940E1D231E7198F4C403E42CD902A0A4940E1D231E7198F4C40
27609	Русский Турек	7	67	359	50.199232000000002	50.246071000000001	57.069000000000003	57.048335000000002	0103000020E610000001000000050000008928266F8019494047205ED72F864C408928266F8019494046B6F3FDD4884C403CBF28417F1F494046B6F3FDD4884C403CBF28417F1F494047205ED72F864C408928266F8019494047205ED72F864C40
26488	Русская Биляморь	7	67	359	49.892898000000002	49.965446	57.037058000000002	57.023347000000001	0103000020E61000000100000005000000F8544E7B4AF24840D8BAD408FD824C40F8544E7B4AF2484010070951BE844C40EA060ABC93FB484010070951BE844C40EA060ABC93FB4840D8BAD408FD824C40F8544E7B4AF24840D8BAD408FD824C40
27437	Рождественское	7	67	359	49.970827	49.987040999999998	57.285299999999999	57.277209999999997	0103000020E610000001000000050000007289230F44FC4840E40F069E7BA34C407289230F44FC48403FC6DCB584A44C40D367075C57FE48403FC6DCB584A44C40D367075C57FE4840E40F069E7BA34C407289230F44FC4840E40F069E7BA34C40
27318	Поповка	7	67	359	49.896850999999998	49.927878	57.129592000000002	57.121198	0103000020E6100000010000000500000044317903CCF24840992B836A838F4C4044317903CCF2484060E97C7896904C40C556D0B4C4F6484060E97C7896904C40C556D0B4C4F64840992B836A838F4C4044317903CCF24840992B836A838F4C40
27337	Пиляндыш	7	67	359	50.444194000000003	50.472400999999998	57.001759999999997	56.975876999999997	0103000020E610000001000000050000002B8A5759DB38494094F59B89E97C4C402B8A5759DB3849407138F3AB39804C4081CCCEA2773C49407138F3AB39804C4081CCCEA2773C494094F59B89E97C4C402B8A5759DB38494094F59B89E97C4C40
27161	Петровское	7	67	359	49.963272000000003	49.983583000000003	57.342078999999998	57.318869999999997	0103000020E610000001000000050000008693347F4CFB484077D66EBBD0A84C408693347F4CFB4840FED2A23EC9AB4C4067F3380CE6FD4840FED2A23EC9AB4C4067F3380CE6FD484077D66EBBD0A84C408693347F4CFB484077D66EBBD0A84C40
27254	Орешник	7	67	359	49.960980999999997	49.976880999999999	57.367418999999998	57.360968	0103000020E61000000100000005000000E789E76C01FB484086730D3334AE4C40E789E76C01FB4840EA76F69507AF4C40B98AC56F0AFD4840EA76F69507AF4C40B98AC56F0AFD484086730D3334AE4C40E789E76C01FB484086730D3334AE4C40
55988	Опарино	7	67	359	50.018078000000003	50.044237000000003	56.87621	56.864384000000001	0103000020E610000001000000050000007863416150024940C4978922A46E4C407863416150024940CE3637A627704C40F722DA8EA9054940CE3637A627704C40F722DA8EA9054940C4978922A46E4C407863416150024940C4978922A46E4C40
27138	Овсянниково	7	67	359	49.765875999999999	49.806786000000002	57.010871999999999	56.993107000000002	0103000020E6100000010000000500000049658A3908E24840DF3653211E7F4C4049658A3908E248409738F24064814C40726F7EC344E748409738F24064814C40726F7EC344E74840DF3653211E7F4C4049658A3908E24840DF3653211E7F4C40
6645	Нижний Унур	7	67	359	49.876036999999997	49.891227000000001	56.933979999999998	56.927869999999999	0103000020E61000000100000005000000008BFCFA21F048404278B471C4764C40008BFCFA21F048401D8F19A88C774C40F627F1B913F248401D8F19A88C774C40F627F1B913F248404278B471C4764C40008BFCFA21F048404278B471C4764C40
26298	Мари-Шуэть	7	67	359	49.859462999999998	49.879036999999997	57.227566000000003	57.213098000000002	0103000020E610000001000000050000009F8F32E202EE4840E86B96CB469B4C409F8F32E202EE48403DD7F7E1209D4C40AA7CCF4884F048403DD7F7E1209D4C40AA7CCF4884F04840E86B96CB469B4C409F8F32E202EE4840E86B96CB469B4C40
26607	Манкинерь	7	67	359	50.388508000000002	50.409151000000001	56.799813	56.789786999999997	0103000020E61000000100000005000000001E51A1BA31494029E78BBD17654C40001E51A1BA31494034F5BA4560664C4017105A0F5F34494034F5BA4560664C4017105A0F5F34494029E78BBD17654C40001E51A1BA31494029E78BBD17654C40
56029	Максинерь	7	67	359	50.275212000000003	50.303894999999997	57.007843000000001	56.99494	0103000020E61000000100000005000000BFBB95253A234940BABDA4315A7F4C40BFBB95253A2349405340DAFF00814C407E350708E62649405340DAFF00814C407E350708E6264940BABDA4315A7F4C40BFBB95253A234940BABDA4315A7F4C40
56032	Лопъял	7	67	359	49.947650000000003	49.988639999999997	56.963842	56.941149000000003	0103000020E61000000100000005000000F7065F984CF94840E1D4079277784C40F7065F984CF948407041B62C5F7B4C403BC269C18BFE48407041B62C5F7B4C403BC269C18BFE4840E1D4079277784C40F7065F984CF94840E1D4079277784C40
56022	Лебедевский	7	67	359	49.573250000000002	49.613199000000002	57.118949999999998	57.102967999999997	0103000020E610000001000000050000004C37894160C948406B44300E2E8D4C404C37894160C94840FAEDEBC0398F4C404F78094E7DCE4840FAEDEBC0398F4C404F78094E7DCE48406B44300E2E8D4C404C37894160C948406B44300E2E8D4C40
26792	Лазарево	7	67	359	50.183692000000001	50.219085	56.832959000000002	56.817473999999997	0103000020E61000000100000005000000B7442E388317494047AAEFFCA2684C40B7442E388317494056F487669E6A4C40A7052FFA0A1C494056F487669E6A4C40A7052FFA0A1C494047AAEFFCA2684C40B7442E388317494047AAEFFCA2684C40
56025	Кизерь	7	67	359	50.209032999999998	50.256059999999998	57.037968999999997	57.013649999999998	0103000020E610000001000000050000007364E597C11A494092CB7F48BF814C407364E597C11A494083A10E2BDC844C4029E8F692C620494083A10E2BDC844C4029E8F692C620494092CB7F48BF814C407364E597C11A494092CB7F48BF814C40
26234	Зоткино	7	67	359	49.844352999999998	49.858896999999999	57.197350999999998	57.175727999999999	0103000020E61000000100000005000000C6A354C213EC4840E97E4E417E964C40C6A354C213EC48409C6A2DCC42994C40F6D03E56F0ED48409C6A2DCC42994C40F6D03E56F0ED4840E97E4E417E964C40C6A354C213EC4840E97E4E417E964C40
26778	Ешпаево	7	67	359	50.113605	50.148665999999999	56.895220999999999	56.881929999999997	0103000020E61000000100000005000000BFD4CF9B8A0E49403EAE0D15E3704C40BFD4CF9B8A0E4940A1D80A9A96724C407903CC7C07134940A1D80A9A96724C407903CC7C071349403EAE0D15E3704C40BFD4CF9B8A0E49403EAE0D15E3704C40
27963	Дюково	7	67	359	50.065581000000002	50.077933000000002	57.170887999999998	57.163908999999997	0103000020E61000000100000005000000971E4DF564084940914259F8FA944C40971E4DF564084940B1A371A8DF954C40BC2363B5F9094940B1A371A8DF954C40BC2363B5F9094940914259F8FA944C40971E4DF564084940914259F8FA944C40
26725	Донаурово	7	67	359	50.509627000000002	50.542461000000003	56.907814000000002	56.884709000000001	0103000020E610000001000000050000004D1421753B4149400ABDFE243E714C404D1421753B414940EC6CC83F33744C40802DAF5C6F454940EC6CC83F33744C40802DAF5C6F4549400ABDFE243E714C404D1421753B4149400ABDFE243E714C40
26982	Витля	7	67	359	49.894855999999997	49.923763999999998	56.904299999999999	56.896518999999998	0103000020E610000001000000050000008F5033A48AF248400E9F7422C1724C408F5033A48AF24840EBE2361AC0734C406F9C14E63DF64840EBE2361AC0734C406F9C14E63DF648400E9F7422C1724C408F5033A48AF248400E9F7422C1724C40
27219	Вершинята	7	67	359	49.882702000000002	49.918858999999998	57.267034000000002	57.257576	0103000020E61000000100000005000000910E0F61FCF04840041E1840F8A04C40910E0F61FCF04840C5758C2B2EA24C405051F52B9DF54840C5758C2B2EA24C405051F52B9DF54840041E1840F8A04C40910E0F61FCF04840041E1840F8A04C40
28129	Верхняя Шурма	7	67	359	50.318376000000001	50.328626	56.956009000000002	56.945945999999999	0103000020E6100000010000000500000068EA758BC028494019E42EC214794C4068EA758BC028494041D7BE805E7A4C40C24EB16A102A494041D7BE805E7A4C40C24EB16A102A494019E42EC214794C4068EA758BC028494019E42EC214794C40
26697	Буйское	7	67	359	49.696238999999998	49.741514000000002	57.098650999999997	57.071334	0103000020E6100000010000000500000091990B5C1ED94840E38BF67821894C4091990B5C1ED94840DD5B9198A08C4C4059C345EEE9DE4840DD5B9198A08C4C4059C345EEE9DE4840E38BF67821894C4091990B5C1ED94840E38BF67821894C40
26516	Большой Рой	7	67	359	50.386352000000002	50.415520000000001	56.869402000000001	56.851731000000001	0103000020E61000000100000005000000425F7AFB73314940A4FE7A85056D4C40425F7AFB73314940DB899290486F4C40BE6A65C22F354940DB899290486F4C40BE6A65C22F354940A4FE7A85056D4C40425F7AFB73314940A4FE7A85056D4C40
26408	Богданово	7	67	359	50.015903999999999	50.031176000000002	57.081837999999998	57.055574999999997	0103000020E6100000010000000500000013F06B2409024940D3BCE3141D874C4013F06B2409024940F7C8E6AA798A4C40C6353E93FD034940F7C8E6AA798A4C40C6353E93FD034940D3BCE3141D874C4013F06B2409024940D3BCE3141D874C40
26326	Байса	7	67	359	49.505139999999997	49.549607000000002	57.217913000000003	57.184874999999998	0103000020E6100000010000000500000062F3716DA8C048408B6CE7FBA9974C4062F3716DA8C04840C72FBC92E49B4C408B53AD8559C64840C72FBC92E49B4C408B53AD8559C648408B6CE7FBA9974C4062F3716DA8C048408B6CE7FBA9974C40
26964	Ашлань	7	67	359	49.937624999999997	49.959598	56.993827000000003	56.981096000000001	0103000020E61000000100000005000000BC74931804F84840431EC18D947D4C40BC74931804F84840DF701FB9357F4C404CA7751BD4FA4840DF701FB9357F4C404CA7751BD4FA4840431EC18D947D4C40BC74931804F84840431EC18D947D4C40
27904	Антонково	7	67	359	50.018949999999997	50.059913000000002	57.161971999999999	57.147004000000003	0103000020E610000001000000050000002D211FF46C024940CB30EE06D1924C402D211FF46C024940116F9D7FBB944C4079CDAB3AAB074940116F9D7FBB944C4079CDAB3AAB074940CB30EE06D1924C402D211FF46C024940CB30EE06D1924C40
26205	Андреевский	7	67	359	50.530828	50.540906999999997	57.073403999999996	57.066401999999997	0103000020E610000001000000050000008AE6012CF2434940CA3159DC7F884C408AE6012CF2434940A2B2614D65894C40B796C9703C454940A2B2614D65894C40B796C9703C454940CA3159DC7F884C408AE6012CF2434940CA3159DC7F884C40
27724	Актыгашево	7	67	359	50.175193999999998	50.209150000000001	56.938876	56.926572999999998	0103000020E610000001000000050000004B3ACAC16C164940A52DAEF199764C404B3ACAC16C164940E97FB9162D784C40ADFA5C6DC51A4940E97FB9162D784C40ADFA5C6DC51A4940A52DAEF199764C404B3ACAC16C164940A52DAEF199764C40
27498	Адово	7	67	359	49.650900999999998	49.665174999999998	57.234893	57.221597000000003	0103000020E6100000010000000500000083F755B950D3484024F25D4A5D9C4C4083F755B950D3484098874CF9109E4C40F38E537424D5484098874CF9109E4C40F38E537424D5484024F25D4A5D9C4C4083F755B950D3484024F25D4A5D9C4C40
25877	Чуваши	7	67	1759	51.183795000000003	51.196182999999998	57.529361000000002	57.519497000000001	0103000020E610000001000000050000008C1535988697494060AFB0E07EC24C408C153598869749409163EB19C2C34C40FD8348861C9949409163EB19C2C34C40FD8348861C99494060AFB0E07EC24C408C1535988697494060AFB0E07EC24C40
25805	Уть	7	67	1759	51.749077999999997	51.765543999999998	57.704219000000002	57.694358999999999	0103000020E610000001000000050000009813B4C9E1DF4940755776C1E0D84C409813B4C9E1DF4940651C23D923DA4C4013D38558FDE14940651C23D923DA4C4013D38558FDE14940755776C1E0D84C409813B4C9E1DF4940755776C1E0D84C40
25612	Уни	7	67	1759	51.469334000000003	51.517699	57.768033000000003	57.736812999999998	0103000020E610000001000000050000005073F22213BC494042226DE34FDE4C405073F22213BC4940D89FC4E74EE24C400116F9F543C24940D89FC4E74EE24C400116F9F543C2494042226DE34FDE4C405073F22213BC494042226DE34FDE4C40
25580	Удмуртский Сурвай	7	67	1759	51.576314000000004	51.600864999999999	57.831879000000001	57.817408999999998	0103000020E610000001000000050000000D1D3BA8C4C94940603AADDBA0E84C400D1D3BA8C4C94940569DD5027BEA4C40D027F224E9CC4940569DD5027BEA4C40D027F224E9CC4940603AADDBA0E84C400D1D3BA8C4C94940603AADDBA0E84C40
25509	Сосновка	7	67	1759	51.667456999999999	51.705742999999998	57.803638999999997	57.790030999999999	0103000020E610000001000000050000003E3E213B6FD54940C0E95DBC1FE54C403E3E213B6FD5494023658BA4DDE64C40C23060C955DA494023658BA4DDE64C40C23060C955DA4940C0E95DBC1FE54C403E3E213B6FD54940C0E95DBC1FE54C40
25380	Сардык	7	67	1759	51.407494	51.544091000000002	57.649509999999999	57.631219000000002	0103000020E610000001000000050000007AA86DC328B4494092CEC0C8CBD04C407AA86DC328B449406536C82423D34C4023861DC6A4C549406536C82423D34C4023861DC6A4C5494092CEC0C8CBD04C407AA86DC328B4494092CEC0C8CBD04C40
25284	Малый Полом	7	67	1759	51.262802000000001	51.288331999999997	57.694243999999998	57.679198999999997	0103000020E6100000010000000500000065A9F57EA3A14940EA3C2AFEEFD64C4065A9F57EA3A14940DCB8C5FCDCD84C40F4311F10E8A44940DCB8C5FCDCD84C40F4311F10E8A44940EA3C2AFEEFD64C4065A9F57EA3A14940EA3C2AFEEFD64C40
25165	Князево	7	67	1759	51.241404000000003	51.269674000000002	57.616957999999997	57.605333999999999	0103000020E61000000100000005000000D28F8653E69E49401494A2957BCD4C40D28F8653E69E4940B680D07AF8CE4C406F4A79AD84A24940B680D07AF8CE4C406F4A79AD84A249401494A2957BCD4C40D28F8653E69E49401494A2957BCD4C40
25146	Канахинцы	7	67	1759	51.588701999999998	51.614843	57.677875999999998	57.665174	0103000020E610000001000000050000007E8B4E965ACB49402313F06B24D54C407E8B4E965ACB4940245F09A4C4D64C405796E82CB3CE4940245F09A4C4D64C405796E82CB3CE49402313F06B24D54C407E8B4E965ACB49402313F06B24D54C40
25085	Елгань	7	67	1759	51.194915999999999	51.222827000000002	57.829492000000002	57.816954000000003	0103000020E61000000100000005000000CBBBEA01F39849400F2BDCF291E84C40CBBBEA01F398494096253ACB2CEA4C4039D55A98859C494096253ACB2CEA4C4039D55A98859C49400F2BDCF291E84C40CBBBEA01F39849400F2BDCF291E84C40
25068	Верхолемье	7	67	1759	51.847605000000001	51.877105999999998	57.799970000000002	57.788241999999997	0103000020E610000001000000050000008A7615527EEC4940B4AA251DE5E44C408A7615527EEC4940FCE3BD6A65E64C400C90680245F04940FCE3BD6A65E64C400C90680245F04940B4AA251DE5E44C408A7615527EEC4940B4AA251DE5E44C40
25008	Булатовцы	7	67	1759	51.628667999999998	51.649706000000002	57.603675000000003	57.591631999999997	0103000020E6100000010000000500000057056A3178D049402FA2ED98BACB4C4057056A3178D04940D734EF3845CD4C40EB01F39029D34940D734EF3845CD4C40EB01F39029D349402FA2ED98BACB4C4057056A3178D049402FA2ED98BACB4C40
24964	Барашки	7	67	1759	51.041573999999997	51.079348000000003	57.732464	57.711499000000003	0103000020E61000000100000005000000942EFD4B528549408011346612DB4C40942EFD4B52854940A9BF5E61C1DD4C4063804413288A4940A9BF5E61C1DD4C4063804413288A49408011346612DB4C40942EFD4B528549408011346612DB4C40
24938	Астрахань	7	67	1759	51.237326000000003	51.286633999999999	57.829861000000001	57.813482999999998	0103000020E61000000100000005000000C93EC8B2609E49400D6D003620E84C40C93EC8B2609E4940E99C9FE238EA4C40F9F5436CB0A44940E99C9FE238EA4C40F9F5436CB0A449400D6D003620E84C40C93EC8B2609E49400D6D003620E84C40
24092	Шешурга	7	67	592	47.557322999999997	47.590004	57.480266999999998	57.462131999999997	0103000020E6100000010000000500000080272D5C56C74740B037312427BB4C4080272D5C56C747408C2C996379BD4C402D41464085CB47408C2C996379BD4C402D41464085CB4740B037312427BB4C4080272D5C56C74740B037312427BB4C40
3719	Тужа	7	67	592	47.892825999999999	47.965572000000002	57.671878999999997	57.582644000000002	0103000020E610000001000000050000005E82531F48F24740F69A1E1494CA4C405E82531F48F2474041EF8D2100D64C4077F700DD97FB474041EF8D2100D64C4077F700DD97FB4740F69A1E1494CA4C405E82531F48F24740F69A1E1494CA4C40
24799	Полушнур	7	67	592	48.160587	48.189565999999999	57.492114999999998	57.481467000000002	0103000020E61000000100000005000000D594641D8E144840378DEDB5A0BD4C40D594641D8E1448407E6FD39FFDBE4C407E37DDB2431848407E6FD39FFDBE4C407E37DDB243184840378DEDB5A0BD4C40D594641D8E144840378DEDB5A0BD4C40
24733	Покста	7	67	592	48.092153000000003	48.137635000000003	57.618886000000003	57.607132	0103000020E61000000100000005000000399D64ABCB0B4840732D5A80B6CD4C40399D64ABCB0B4840E4F90CA837CF4C407AE40F069E114840E4F90CA837CF4C407AE40F069E114840732D5A80B6CD4C40399D64ABCB0B4840732D5A80B6CD4C40
24719	Пиштенур	7	67	592	47.829709999999999	47.853155999999998	57.500805999999997	57.474435999999997	0103000020E610000001000000050000000395F1EF33EA4740C405A051BABC4C400395F1EF33EA4740FED137691AC04C406E313F3734ED4740FED137691AC04C406E313F3734ED4740C405A051BABC4C400395F1EF33EA4740C405A051BABC4C40
24642	Пачи	7	67	592	48.155493	48.174833999999997	57.577148000000001	57.558376000000003	0103000020E61000000100000005000000E3E0D231E7134840876F61DD78C74C40E3E0D231E7134840D57954FCDFC94C404B1DE4F560164840D57954FCDFC94C404B1DE4F560164840876F61DD78C74C40E3E0D231E7134840876F61DD78C74C40
24550	Михайловское	7	67	592	47.702652999999998	47.745224	57.520865000000001	57.504665000000003	0103000020E61000000100000005000000D8B79388F0D94740CA37DBDC98C04C40D8B79388F0D94740C6504EB4ABC24C40DF18028063DF4740C6504EB4ABC24C40DF18028063DF4740CA37DBDC98C04C40D8B79388F0D94740CA37DBDC98C04C40
24459	Коврижата	7	67	592	47.773466999999997	47.823780999999997	57.723025999999997	57.704338999999997	0103000020E6100000010000000500000082C476F700E347400F26C5C727DA4C4082C476F700E347402F14B01D8CDC4C407808E3A771E947402F14B01D8CDC4C407808E3A771E947400F26C5C727DA4C4082C476F700E347400F26C5C727DA4C40
24495	Караванное	7	67	592	47.665750000000003	47.698008000000002	57.787680000000002	57.774915999999997	0103000020E61000000100000005000000F0A7C64B37D54740D5928E7230E34C40F0A7C64B37D547404DDBBFB2D2E44C40562C7E5358D947404DDBBFB2D2E44C40562C7E5358D94740D5928E7230E34C40F0A7C64B37D54740D5928E7230E34C40
24387	Греково	7	67	592	48.077178000000004	48.099178000000002	57.528678999999997	57.510641	0103000020E6100000010000000500000040FCFCF7E0094840957F2DAF5CC14C4040FCFCF7E00948407E8AE3C0ABC34C40C93D5DDDB10C48407E8AE3C0ABC34C40C93D5DDDB10C4840957F2DAF5CC14C4040FCFCF7E0094840957F2DAF5CC14C40
24346	Вынур	7	67	592	48.283628999999998	48.307389000000001	57.59648	57.582779000000002	0103000020E610000001000000050000003D997FF44D244840D6E5948098CA4C403D997FF44D244840EA5BE67459CC4C403813D38558274840EA5BE67459CC4C403813D38558274840D6E5948098CA4C403D997FF44D244840D6E5948098CA4C40
24287	Васькино	7	67	592	47.670600999999998	47.69923	57.467244000000001	57.450167999999998	0103000020E610000001000000050000001BD5E940D6D5474055DAE21A9FB94C401BD5E940D6D5474049A0C1A6CEBB4C40E8305F5E80D9474049A0C1A6CEBB4C40E8305F5E80D9474055DAE21A9FB94C401BD5E940D6D5474055DAE21A9FB94C40
23408	Суна	7	67	869	50.043069000000003	50.087293000000003	57.845858	57.793729999999996	0103000020E61000000100000005000000583CF5488305494052EDD3F198E54C40583CF54883054940AD872F1345EC4C40BA15C26A2C0B4940AD872F1345EC4C40BA15C26A2C0B494052EDD3F198E54C40583CF5488305494052EDD3F198E54C40
52566	Смыки	7	67	869	49.949151000000001	49.974680999999997	57.786769	57.774656999999998	0103000020E610000001000000050000009CFBABC77DF94840094FE8F527E34C409CFBABC77DF94840D940BAD8B4E44C402B84D558C2FC4840D940BAD8B4E44C402B84D558C2FC4840094FE8F527E34C409CFBABC77DF94840094FE8F527E34C40
24014	Плелое	7	67	869	50.235965	50.256149999999998	57.827983000000003	57.817548000000002	0103000020E610000001000000050000001500E319341E49408274B169A5E84C401500E319341E49406E52D158FBE94C40696FF085C92049406E52D158FBE94C40696FF085C92049408274B169A5E84C401500E319341E49408274B169A5E84C40
56015	Новый	7	67	869	49.812319000000002	49.838352	57.910809	57.892702	0103000020E61000000100000005000000B075A911FAE748407289230F44F24C40B075A911FAE7484084F3A96395F44C40A2444B1E4FEB484084F3A96395F44C40A2444B1E4FEB48407289230F44F24C40B075A911FAE748407289230F44F24C40
23856	Нестино	7	67	869	50.156714999999998	50.195936000000003	57.774954999999999	57.763404999999999	0103000020E6100000010000000500000075E5B33C0F1449402B4D4A41B7E14C4075E5B33C0F144940936FB6B931E34C40F60D4C6E14194940936FB6B931E34C40F60D4C6E141949402B4D4A41B7E14C4075E5B33C0F1449402B4D4A41B7E14C40
52550	Мурино	7	67	869	50.290878999999997	50.321286999999998	57.890253000000001	57.875582000000001	0103000020E61000000100000005000000ED0BE8853B254940AF7B2B1213F04C40ED0BE8853B2549403C1570CFF3F14C40A2D0B2EE1F2949403C1570CFF3F14C40A2D0B2EE1F294940AF7B2B1213F04C40ED0BE8853B254940AF7B2B1213F04C40
23679	Курчум	7	67	869	50.280358999999997	50.309159000000001	57.938630000000003	57.927697000000002	0103000020E61000000100000005000000D311C0CDE223494075CC79C6BEF64C40D311C0CDE2234940B285200725F84C40CD21A98592274940B285200725F84C40CD21A9859227494075CC79C6BEF64C40D311C0CDE223494075CC79C6BEF64C40
52536	Краснополье	7	67	869	49.904342999999997	49.933788999999997	57.873845000000003	57.86103	0103000020E61000000100000005000000EAAEEC82C1F34840FC6F253B36EE4C40EAAEEC82C1F34840F6622827DAEF4C40A92EE06586F74840F6622827DAEF4C40A92EE06586F74840FC6F253B36EE4C40EAAEEC82C1F34840FC6F253B36EE4C40
23576	Кокуй	7	67	869	50.263641999999997	50.274386	57.814968999999998	57.810822000000002	0103000020E610000001000000050000000FED6305BF2149404C70EA03C9E74C400FED6305BF2149407D2079E750E84C40793D98141F2349407D2079E750E84C40793D98141F2349404C70EA03C9E74C400FED6305BF2149404C70EA03C9E74C40
56034	Дворища	7	67	869	49.553891999999998	50.477592999999999	58.043796	57.713999000000001	0103000020E610000001000000050000000DC2DCEEE5C648403830B95164DB4C400DC2DCEEE5C648400AD9791B9B054D4036E675C4213D49400AD9791B9B054D4036E675C4213D49403830B95164DB4C400DC2DCEEE5C648403830B95164DB4C40
52555	Гребенки	7	67	869	50.104154999999999	50.122183999999997	57.760697999999998	57.748432999999999	0103000020E61000000100000005000000815B77F3540D4940A31F0DA7CCDF4C40815B77F3540D4940F910548D5EE14C40170CAEB9A30F4940F910548D5EE14C40170CAEB9A30F4940A31F0DA7CCDF4C40815B77F3540D4940A31F0DA7CCDF4C40
23525	Верхосунье	7	67	869	49.838056000000002	49.862580000000001	57.921235000000003	57.904133000000002	0103000020E61000000100000005000000B91B446B45EB4840001E51A1BAF34C40B91B446B45EB48401D774A07EBF54C4083177D0569EE48401D774A07EBF54C4083177D0569EE4840001E51A1BAF34C40B91B446B45EB4840001E51A1BAF34C40
52572	Большие Туры	7	67	869	49.813657999999997	49.832943999999998	57.80782	57.800445000000003	0103000020E610000001000000050000007B1002F225E84840959F54FB74E64C407B1002F225E84840018750A566E74C4020B3B3E89DEA4840018750A566E74C4020B3B3E89DEA4840959F54FB74E64C407B1002F225E84840959F54FB74E64C40
23480	Большевик	7	67	869	50.058214999999997	50.095925999999999	57.858218999999998	57.844814	0103000020E610000001000000050000007D91D09673074940FA997ADD22EC4C407D91D0967307494025E7C41EDAED4C40056B9C4D470C494025E7C41EDAED4C40056B9C4D470C4940FA997ADD22EC4C407D91D09673074940FA997ADD22EC4C40
56026	Шаваржаково	7	67	1676	48.873175000000003	48.908020999999998	57.142184	57.122356000000003	0103000020E61000000100000005000000A857CA32C46F4840153C855CA98F4C40A857CA32C46F4840DA01D71533924C40658A39083A744840DA01D71533924C40658A39083A744840153C855CA98F4C40A857CA32C46F4840153C855CA98F4C40
23293	Фокино	7	67	1676	49.042921	49.056224999999998	57.414696999999997	57.404108999999998	0103000020E61000000100000005000000E3A7716F7E8548407782FDD7B9B34C40E3A7716F7E854840E95F92CA14B54C40DA1B7C6132874840E95F92CA14B54C40DA1B7C61328748407782FDD7B9B34C40E3A7716F7E8548407782FDD7B9B34C40
23240	Суводь	7	67	1676	49.132753000000001	49.152138000000001	57.748975999999999	57.738216000000001	0103000020E6100000010000000500000013B9E00CFE90484025B1A4DC7DDE4C4013B9E00CFE90484094BE1072DEDF4C404B3D0B427993484094BE1072DEDF4C404B3D0B427993484025B1A4DC7DDE4C4013B9E00CFE90484025B1A4DC7DDE4C40
22835	Советск	7	67	1676	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
22782	Ситемка	7	67	1676	49.232653999999997	49.263627999999997	57.632313000000003	57.62133	0103000020E610000001000000050000004CA4349BC79D48400803CFBD87CF4C404CA4349BC79D4840F7EAE3A1EFD04C40AA27F38FBEA14840F7EAE3A1EFD04C40AA27F38FBEA148400803CFBD87CF4C404CA4349BC79D48400803CFBD87CF4C40
22757	Родыгино	7	67	1676	48.920102999999997	48.941060999999998	57.579566	57.563986	0103000020E61000000100000005000000CAF962EFC575484070B378B130C84C40CAF962EFC5754840D0EFFB372FCA4C404145D5AF74784840D0EFFB372FCA4C404145D5AF7478484070B378B130C84C40CAF962EFC575484070B378B130C84C40
22696	Прозорово	7	67	1676	49.288088999999999	49.305472000000002	57.735788999999997	57.717868000000003	0103000020E610000001000000050000002EABB019E0A44840276C3F19E3DB4C402EABB019E0A44840D6E07D552EDE4C40FFEBDCB419A74840D6E07D552EDE4C40FFEBDCB419A74840276C3F19E3DB4C402EABB019E0A44840276C3F19E3DB4C40
56028	Новый	7	67	1676	48.944842999999999	48.959791000000003	57.551417000000001	57.539299	0103000020E61000000100000005000000616D8C9DF0784840FCE1E7BF07C54C40616D8C9DF0784840AEBA0ED594C64C4061FF756EDA7A4840AEBA0ED594C64C4061FF756EDA7A4840FCE1E7BF07C54C40616D8C9DF0784840FCE1E7BF07C54C40
22612	Муша	7	67	1676	48.955767000000002	48.982140999999999	57.363604000000002	57.344614999999997	0103000020E610000001000000050000004BCCB392567A4840035B25581CAC4C404BCCB392567A4840EF586C938AAE4C40C687D9CBB67D4840EF586C938AAE4C40C687D9CBB67D4840035B25581CAC4C404BCCB392567A4840035B25581CAC4C40
22590	Мокино	7	67	1676	49.167471999999997	49.198680000000003	57.443387000000001	57.431519000000002	0103000020E61000000100000005000000737FF5B86F954840234DBC033CB74C40737FF5B86F9548405C3CBCE7C0B84C40452FA3586E9948405C3CBCE7C0B84C40452FA3586E994840234DBC033CB74C40737FF5B86F954840234DBC033CB74C40
22520	Лошкари	7	67	1676	48.892408000000003	48.929149000000002	57.230513999999999	57.215691	0103000020E610000001000000050000002A58E36C3A72484051853FC39B9B4C402A58E36C3A72484094A2957B819D4C40390EBC5AEE76484094A2957B819D4C40390EBC5AEE76484051853FC39B9B4C402A58E36C3A72484051853FC39B9B4C40
22490	Лесниково	7	67	1676	48.761659000000002	48.784593000000001	57.567118999999998	57.560273000000002	0103000020E610000001000000050000001FDAC70A7E61484079EA9106B7C74C401FDAC70A7E61484059F8FA5A97C84C40D4D51D8B6D64484059F8FA5A97C84C40D4D51D8B6D64484079EA9106B7C74C401FDAC70A7E61484079EA9106B7C74C40
22420	Колянур	7	67	1676	48.768082	48.817901999999997	57.432279000000001	57.402582000000002	0103000020E61000000100000005000000B952CF8250624840A9FA95CE87B34C40B952CF8250624840B1DF13EB54B74C409FAA4203B1684840B1DF13EB54B74C409FAA4203B1684840A9FA95CE87B34C40B952CF8250624840A9FA95CE87B34C40
22401	Кожа	7	67	1676	48.904347000000001	48.928952000000002	57.80245	57.788150999999999	0103000020E610000001000000050000002C9E7AA4C1734840A4A7C821E2E44C402C9E7AA4C17348406D567DAEB6E64C40E3C62DE6E77648406D567DAEB6E64C40E3C62DE6E7764840A4A7C821E2E44C402C9E7AA4C1734840A4A7C821E2E44C40
22365	Кичма	7	67	1676	48.909979	48.941806999999997	57.205522999999999	57.182172999999999	0103000020E61000000100000005000000FD851E317A7448406B9BE27151974C40FD851E317A744840B4C9E1934E9A4C406A12BC218D784840B4C9E1934E9A4C406A12BC218D7848406B9BE27151974C40FD851E317A7448406B9BE27151974C40
22234	Зашижемье	7	67	1676	48.821719999999999	48.852290000000004	57.771085999999997	57.756535	0103000020E610000001000000050000000C3CF71E2E694840C2A38D23D6E04C400C3CF71E2E694840A43330F2B2E24C409B5AB6D6176D4840A43330F2B2E24C409B5AB6D6176D4840C2A38D23D6E04C400C3CF71E2E694840C2A38D23D6E04C40
22164	Дуброва	7	67	1676	48.976346999999997	48.996684999999999	57.486362999999997	57.477184000000001	0103000020E610000001000000050000001B4641F0F87C48405516855D14BD4C401B4641F0F87C4840027E8D2441BE4C40F6B4C35F937F4840027E8D2441BE4C40F6B4C35F937F48405516855D14BD4C401B4641F0F87C48405516855D14BD4C40
24482	Дороничи	7	67	1676	48.923121999999999	48.930407000000002	57.309964999999998	57.306196999999997	0103000020E61000000100000005000000EB1B98DC2876484010919A7631A74C40EB1B98DC28764840CBF3E0EEACA74C40187C9A9317774840CBF3E0EEACA74C40187C9A931777484010919A7631A74C40EB1B98DC2876484010919A7631A74C40
22142	Грехово	7	67	1676	49.001283999999998	49.035150999999999	57.601688000000003	57.585341	0103000020E610000001000000050000000801F9122A80484004013274ECCA4C400801F9122A804840A532C51C04CD4C40FAB5F5D37F844840A532C51C04CD4C40FAB5F5D37F84484004013274ECCA4C400801F9122A80484004013274ECCA4C40
22079	Воробьева Гора	7	67	1676	49.129491999999999	49.153576000000001	57.374679999999998	57.361842000000003	0103000020E61000000100000005000000FC8BA03193904840DD28B2D650AE4C40FC8BA031939048408E3BA583F5AF4C40AAB9DC60A89348408E3BA583F5AF4C40AAB9DC60A8934840DD28B2D650AE4C40FC8BA03193904840DD28B2D650AE4C40
22036	Верхопижемье	7	67	1676	48.874541000000001	48.896656999999998	57.576501	57.565674999999999	0103000020E610000001000000050000006D01A1F5F06F48401895D40968C84C406D01A1F5F06F48403F8EE6C8CAC94C405F5D15A8C57248403F8EE6C8CAC94C405F5D15A8C57248401895D40968C84C406D01A1F5F06F48401895D40968C84C40
21988	Васичи	7	67	1676	48.870013	48.889623999999998	57.312128000000001	57.303440999999999	0103000020E61000000100000005000000240C03965C6F4840FDA19927D7A64C40240C03965C6F48403C1570CFF3A74C404CDE0033DF7148403C1570CFF3A74C404CDE0033DF714840FDA19927D7A64C40240C03965C6F4840FDA19927D7A64C40
21904	Васильково	7	67	1676	48.705675999999997	48.727432999999998	57.737777999999999	57.723751999999998	0103000020E610000001000000050000003AC95697535A48401135D1E7A3DC4C403AC95697535A4840A9DA6E826FDE4C40FD8348861C5D4840A9DA6E826FDE4C40FD8348861C5D48401135D1E7A3DC4C403AC95697535A48401135D1E7A3DC4C40
21832	Борок	7	67	1676	48.664191000000002	48.697141999999999	57.613053000000001	57.599575999999999	0103000020E6100000010000000500000016A6EF3504554840B6BB07E8BECC4C4016A6EF35045548407BDB4C8578CE4C408255F5F23B5948407BDB4C8578CE4C408255F5F23B594840B6BB07E8BECC4C4016A6EF3504554840B6BB07E8BECC4C40
23321	Большая Челка	7	67	1676	48.791896000000001	48.818980000000003	57.499858000000003	57.482666999999999	0103000020E61000000100000005000000A7EA1ED95C654840E1ED4108C8BD4C40A7EA1ED95C6548406E52D158FBBF4C40FF092E56D46848406E52D158FBBF4C40FF092E56D4684840E1ED4108C8BD4C40A7EA1ED95C654840E1ED4108C8BD4C40
19429	Шихово	7	67	30	49.804917000000003	49.846823000000001	58.637045000000001	58.625065999999997	0103000020E610000001000000050000004A7F2F8507E74840B7EBA52902504D404A7F2F8507E74840488AC8B08A514D40144031B264EC4840488AC8B08A514D40144031B264EC4840B7EBA52902504D404A7F2F8507E74840B7EBA52902504D40
20712	Шестаково	7	67	30	50.156122000000003	50.184176999999998	58.946458999999997	58.917943999999999	0103000020E61000000100000005000000D31742CEFB1349409BC761307F754D40D31742CEFB1349409F008A9125794D4073D6A71C931749409F008A9125794D4073D6A71C931749409BC761307F754D40D31742CEFB1349409BC761307F754D40
20866	Центральный	7	67	30	50.262186	50.293511000000002	59.063755999999998	59.042195	0103000020E610000001000000050000000ABC934F8F214940018750A566854D400ABC934F8F2149403E76172829884D401502B9C4912549403E76172829884D401502B9C491254940018750A566854D400ABC934F8F214940018750A566854D40
20972	Сухоборка	7	67	30	49.951639	49.983339999999998	59.125599999999999	59.099023000000003	0103000020E61000000100000005000000904C874ECFF94840A24621C9AC8C4D40904C874ECFF9484055302AA913904D40A06CCA15DEFD484055302AA913904D40A06CCA15DEFD4840A24621C9AC8C4D40904C874ECFF94840A24621C9AC8C4D40
19396	Сунцовы	7	67	30	49.846392000000002	49.865589	58.550472999999997	58.541682000000002	0103000020E610000001000000050000004BCCB39256EC48407B6AF5D555454D404BCCB39256EC48405E2A36E675464D408063CF9ECBEE48405E2A36E675464D408063CF9ECBEE48407B6AF5D555454D404BCCB39256EC48407B6AF5D555454D40
19943	Стулово	7	67	30	50.129496000000003	50.170045999999999	58.727536999999998	58.711668000000003	0103000020E610000001000000050000003E7B2E53931049400CCEE0EF175B4D403E7B2E5393104940A2D0B2EE1F5D4D4066683C11C4154940A2D0B2EE1F5D4D4066683C11C41549400CCEE0EF175B4D403E7B2E53931049400CCEE0EF175B4D40
20602	Стеклофилины	7	67	30	50.200426999999998	50.213552	58.778337000000001	58.768949999999997	0103000020E61000000100000005000000211E8997A71949402D211FF46C624D40211E8997A71949402522FC8BA0634D4069FF03AC551B49402522FC8BA0634D4069FF03AC551B49402D211FF46C624D40211E8997A71949402D211FF46C624D40
6534	Совье	7	67	30	49.916289999999996	49.935290000000002	58.858874999999998	58.848812000000002	0103000020E610000001000000050000006FD39FFD48F54840E73922DFA56C4D406FD39FFD48F548400E2DB29DEF6D4D404F232D95B7F748400E2DB29DEF6D4D404F232D95B7F74840E73922DFA56C4D406FD39FFD48F54840E73922DFA56C4D40
20434	Светозарево	7	67	30	50.351129	50.368268	58.647970999999998	58.640183	0103000020E61000000100000005000000AED689CBF12C4940433A3C84F1514D40AED689CBF12C4940D2E0B6B6F0524D40E814E467232F4940D2E0B6B6F0524D40E814E467232F4940433A3C84F1514D40AED689CBF12C4940433A3C84F1514D40
20148	Салтыки	7	67	30	50.296340000000001	50.314306999999999	58.753548000000002	58.746082999999999	0103000020E61000000100000005000000923F1878EE254940008DD2A57F5F4D40923F1878EE254940ADFBC74274604D40B2F336363B284940ADFBC74274604D40B2F336363B284940008DD2A57F5F4D40923F1878EE254940008DD2A57F5F4D40
6452	Роговое	7	67	30	50.718755000000002	50.743135000000002	58.554777999999999	58.547753999999998	0103000020E61000000100000005000000126BF129005C4940682096CD1C464D40126BF129005C494028452BF702474D40A9C1340C1F5F494028452BF702474D40A9C1340C1F5F4940682096CD1C464D40126BF129005C4940682096CD1C464D40
6342	Октябрьский	7	67	30	50.425311999999998	50.446458	58.862848999999997	58.846837999999998	0103000020E61000000100000005000000554CA59F7036494049810530656C4D40554CA59F70364940723106D6716E4D40CF84268925394940723106D6716E4D40CF8426892539494049810530656C4D40554CA59F7036494049810530656C4D40
19322	Митино	7	67	30	49.809677999999998	49.818994000000004	58.683819999999997	58.678969000000002	0103000020E6100000010000000500000035255987A3E74840B9FFC874E8564D4035255987A3E74840E42CEC6987574D4064CF9ECBD4E84840E42CEC6987574D4064CF9ECBD4E84840B9FFC874E8564D4035255987A3E74840B9FFC874E8564D40
20845	Лекма	7	67	30	49.943553999999999	49.969282	59.044666999999997	59.025872999999997	0103000020E610000001000000050000004701A260C6F84840B96C74CE4F834D404701A260C6F84840EF1AF4A5B7854D40FD4CBD6E11FC4840EF1AF4A5B7854D40FD4CBD6E11FC4840B96C74CE4F834D404701A260C6F84840B96C74CE4F834D40
61182	Кирово-Чепецк	7	67	30	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
20507	Карино	7	67	30	50.319589000000001	50.348506	58.630969	58.609426999999997	0103000020E61000000100000005000000A794D74AE8284940522635B4014E4D40A794D74AE828494019E59997C3504D40DA3A38D89B2C494019E59997C3504D40DA3A38D89B2C4940522635B4014E4D40A794D74AE8284940522635B4014E4D40
20169	Ильинское	7	67	30	50.418745000000001	50.453842000000002	58.785459000000003	58.773429	0103000020E61000000100000005000000882EA86F993549409563B2B8FF624D40882EA86F99354940A8ACA6EB89644D408FC6A17E173A4940A8ACA6EB89644D408FC6A17E173A49409563B2B8FF624D40882EA86F993549409563B2B8FF624D40
19495	Зониха	7	67	30	49.857702000000003	49.910739	58.659182999999999	58.643171000000002	0103000020E610000001000000050000005EDBDB2DC9ED4840295E656D53524D405EDBDB2DC9ED4840228AC91B60544D408B18761893F44840228AC91B60544D408B18761893F44840295E656D53524D405EDBDB2DC9ED4840295E656D53524D40
6447	Закаринье	7	67	30	50.567039000000001	50.589073999999997	58.623899000000002	58.607205	0103000020E610000001000000050000003D47E4BB94484940DD7BB8E4B84D4D403D47E4BB94484940E98024ECDB4F4D404276DEC6664B4940E98024ECDB4F4D404276DEC6664B4940DD7BB8E4B84D4D403D47E4BB94484940DD7BB8E4B84D4D40
20564	Денисовы	7	67	30	50.129019999999997	50.140456	58.765225999999998	58.75732	0103000020E61000000100000005000000D44334BA83104940A94D9CDCEF604D40D44334BA831049404206F2ECF2614D4074435376FA1149404206F2ECF2614D4074435376FA114940A94D9CDCEF604D40D44334BA83104940A94D9CDCEF604D40
1746	Волково	7	67	30	49.957478000000002	49.988847	58.645873000000002	58.632862000000003	0103000020E61000000100000005000000DB519CA38EFA4840CA703C9F01514D40DB519CA38EFA4840492F6AF7AB524D40B5DFDA8992FE4840492F6AF7AB524D40B5DFDA8992FE4840CA703C9F01514D40DB519CA38EFA4840CA703C9F01514D40
19524	Вахруши	7	67	30	49.998781999999999	50.054020000000001	58.698073999999998	58.670214000000001	0103000020E61000000100000005000000AFEAAC16D8FF484022A98592C9554D40AFEAAC16D8FF48400D18247D5A594D403BAA9A20EA0649400D18247D5A594D403BAA9A20EA06494022A98592C9554D40AFEAAC16D8FF484022A98592C9554D40
19626	Боровица	7	67	30	49.935612999999996	49.970081	58.609994	58.597284000000002	0103000020E61000000100000005000000315BB22AC2F74840483657CD734C4D40315BB22AC2F74840CC608C48144E4D4049BC3C9D2BFC4840CC608C48144E4D4049BC3C9D2BFC4840483657CD734C4D40315BB22AC2F74840483657CD734C4D40
19227	Бобино	7	67	30	49.752195	49.775075000000001	58.709415	58.692739000000003	0103000020E610000001000000050000007C9BFEEC47E04840F6D4EAABAB584D407C9BFEEC47E048405B25581CCE5A4D403E7958A835E348405B25581CCE5A4D403E7958A835E34840F6D4EAABAB584D407C9BFEEC47E04840F6D4EAABAB584D40
6305	Юма	7	67	132	47.565058000000001	47.606793000000003	58.277816000000001	58.255771000000003	0103000020E61000000100000005000000ED2B0FD253C84740F321A81ABD204D40ED2B0FD253C847401C2785798F234D408B389D64ABCD47401C2785798F234D408B389D64ABCD4740F321A81ABD204D40ED2B0FD253C84740F321A81ABD204D40
1740	Шмелево	7	67	132	47.783267000000002	47.820672999999999	58.268686000000002	58.251291000000002	0103000020E610000001000000050000009D84D21742E44740BB63B14D2A204D409D84D21742E447405072874D64224D40E8DA17D00BE947405072874D64224D40E8DA17D00BE94740BB63B14D2A204D409D84D21742E44740BB63B14D2A204D40
5914	Успенское	7	67	132	47.544539999999998	47.562381000000002	58.549439999999997	58.525564000000003	0103000020E6100000010000000500000092AE997CB3C547403CFA5FAE45434D4092AE997CB3C547409F8EC70C54464D402672C119FCC747409F8EC70C54464D402672C119FCC747403CFA5FAE45434D4092AE997CB3C547403CFA5FAE45434D40
294	Свеча	7	67	132	47.476312999999998	47.540371999999998	58.306154999999997	58.267933999999997	0103000020E610000001000000050000006FD40AD3F7BC474044BE4BA94B224D406FD40AD3F7BC4740E140481630274D4049D6E1E82AC54740E140481630274D4049D6E1E82AC5474044BE4BA94B224D406FD40AD3F7BC474044BE4BA94B224D40
6138	Самоулки	7	67	132	47.474274000000001	47.493012999999998	58.278345999999999	58.270271999999999	0103000020E61000000100000005000000EBABAB02B5BC47402383DC4598224D40EBABAB02B5BC4740787C7BD7A0234D405DC0CB0C1BBF4740787C7BD7A0234D405DC0CB0C1BBF47402383DC4598224D40EBABAB02B5BC47402383DC4598224D40
6020	Рыбаковщина	7	67	132	47.503819999999997	47.527481000000002	58.332920999999999	58.323225000000001	0103000020E610000001000000050000000D897B2C7DC04740F31FD26F5F294D400D897B2C7DC047406893C3279D2A4D407521567F84C347406893C3279D2A4D407521567F84C34740F31FD26F5F294D400D897B2C7DC04740F31FD26F5F294D40
6012	Рига	7	67	132	47.761510000000001	47.778506	58.442162000000003	58.430630000000001	0103000020E61000000100000005000000DAC9E02879E14740975643E21E374D40DAC9E02879E1474059C4B0C398384D40B1DEA815A6E3474059C4B0C398384D40B1DEA815A6E34740975643E21E374D40DAC9E02879E14740975643E21E374D40
5187	Октябрьское	7	67	132	47.590820999999998	47.614429000000001	58.413286999999997	58.398572000000001	0103000020E610000001000000050000001F65C405A0CB4740F88C446804334D401F65C405A0CB4740546EA296E6344D40645B069CA5CE4740546EA296E6344D40645B069CA5CE4740F88C446804334D401F65C405A0CB4740F88C446804334D40
5930	Круглыжи	7	67	132	47.651431000000002	47.686860000000003	58.518777999999998	58.488446000000003	0103000020E61000000100000005000000E04C4C1762D3474057EE0566853E4D40E04C4C1762D3474030F1475167424D401D774A07EBD7474030F1475167424D401D774A07EBD7474057EE0566853E4D40E04C4C1762D3474057EE0566853E4D40
6109	Ивановское	7	67	132	47.401716999999998	47.437002999999997	58.40399	58.392507000000002	0103000020E61000000100000005000000A59F70766BB34740BD395CAB3D324D40A59F70766BB347409DF4BEF1B5334D407FA0DCB6EFB747409DF4BEF1B5334D407FA0DCB6EFB74740BD395CAB3D324D40A59F70766BB34740BD395CAB3D324D40
4868	Ганино	7	67	132	47.576456999999998	47.580832000000001	58.666344000000002	58.663003000000003	0103000020E610000001000000050000006F46CD57C9C9474030134548DD544D406F46CD57C9C9474063F19BC24A554D40323CF6B358CA474063F19BC24A554D40323CF6B358CA474030134548DD544D406F46CD57C9C9474030134548DD544D40
5834	Благовещенское	7	67	132	47.487209999999997	47.502481000000003	58.473658999999998	58.462890000000002	0103000020E610000001000000050000005F24B4E55CBE47409ED2C1FA3F3B4D405F24B4E55CBE4740603AADDBA03C4D4042EE224C51C04740603AADDBA03C4D4042EE224C51C047409ED2C1FA3F3B4D405F24B4E55CBE47409ED2C1FA3F3B4D40
6236	Ацвеж	7	67	132	47.740822000000001	47.767816000000003	58.345765	58.336241999999999	0103000020E6100000010000000500000023145B41D3DE474054C554FA092B4D4023145B41D3DE4740FC8C0B07422C4D403BAC70CB47E24740FC8C0B07422C4D403BAC70CB47E2474054C554FA092B4D4023145B41D3DE474054C554FA092B4D40
18217	Сметанино	7	67	1500	47.168883000000001	47.211022999999997	56.967227999999999	56.949908000000001	0103000020E61000000100000005000000D9EC48F59D954740B91AD99596794C40D9EC48F59D95474043E38920CE7B4C4016DA39CD029B474043E38920CE7B4C4016DA39CD029B4740B91AD99596794C40D9EC48F59D954740B91AD99596794C40
17458	Санчурск	7	67	1500	47.224533000000001	47.265649000000003	56.949416999999997	56.930075000000002	0103000020E61000000100000005000000B7EF517FBD9C4740E2E995B20C774C40B7EF517FBD9C47401AA20A7F86794C40899B53C900A247401AA20A7F86794C40899B53C900A24740E2E995B20C774C40B7EF517FBD9C4740E2E995B20C774C40
18317	Мельниково	7	67	1500	47.103135000000002	47.116160999999998	56.949074000000003	56.940300000000001	0103000020E6100000010000000500000057091687338D4740E3361AC05B784C4057091687338D4740F1BDBF417B794C400B09185DDE8E4740F1BDBF417B794C400B09185DDE8E4740E3361AC05B784C4057091687338D4740E3361AC05B784C40
18152	Матвинур	7	67	1500	47.429420999999998	47.445582000000002	57.070540999999999	57.059412999999999	0103000020E61000000100000005000000999B6F44F7B6474087FA5DD89A874C40999B6F44F7B647407903CC7C07894C40D8D7BAD408B947407903CC7C07894C40D8D7BAD408B9474087FA5DD89A874C40999B6F44F7B6474087FA5DD89A874C40
17854	Марийская Лиса	7	67	1500	47.238771999999997	47.264525999999996	57.078721000000002	57.070497000000003	0103000020E61000000100000005000000AA99B514909E4740AABBB20B06894C40AA99B514909E474014419C87138A4C408978EBFCDBA1474014419C87138A4C408978EBFCDBA14740AABBB20B06894C40AA99B514909E4740AABBB20B06894C40
18057	Люмпанур	7	67	1500	46.830855999999997	46.863895999999997	56.977868999999998	56.956612999999997	0103000020E61000000100000005000000BAD7497D596A4740D7F6764B727A4C40BAD7497D596A4740D862B7CF2A7D4C409692E524946E4740D862B7CF2A7D4C409692E524946E4740D7F6764B727A4C40BAD7497D596A4740D7F6764B727A4C40
18193	Люй	7	67	1500	47.552320000000002	47.567798000000003	57.037312999999997	57.028511000000002	0103000020E610000001000000050000009F76F86BB2C64740C3499A3FA6834C409F76F86BB2C647409A5B21ACC6844C40FB5DD89AADC847409A5B21ACC6844C40FB5DD89AADC84740C3499A3FA6834C409F76F86BB2C64740C3499A3FA6834C40
18283	Кувшинское	7	67	1500	47.144340999999997	47.161183999999999	57.024267999999999	57.016204000000002	0103000020E61000000100000005000000683C11C4799247403E0801F912824C40683C11C4799247406F2BBD361B834C40B95164ADA19447406F2BBD361B834C40B95164ADA19447403E0801F912824C40683C11C4799247403E0801F912824C40
17894	Корляки	7	67	1500	46.909297000000002	46.943280000000001	57.115276000000001	57.097003000000001	0103000020E61000000100000005000000EBAC16D863744740944E24986A8C4C40EBAC16D863744740C1012D5DC18E4C40467C2766BD784740C1012D5DC18E4C40467C2766BD784740944E24986A8C4C40EBAC16D863744740944E24986A8C4C40
17689	Городище	7	67	1500	47.277417	47.298105	56.956378000000001	56.947561999999998	0103000020E610000001000000050000005E2D776682A3474057772CB649794C405E2D776682A34740944E24986A7A4C4015E3FC4D28A64740944E24986A7A4C4015E3FC4D28A6474057772CB649794C405E2D776682A3474057772CB649794C40
17776	Галицкое	7	67	1500	47.314310999999996	47.326151000000003	57.008867000000002	56.995562999999997	0103000020E61000000100000005000000F3E2C4573BA84740C70DBF9B6E7F4C40F3E2C4573BA84740BF81C98D22814C406347E350BFA94740BF81C98D22814C406347E350BFA94740C70DBF9B6E7F4C40F3E2C4573BA84740C70DBF9B6E7F4C40
18067	Вотчина	7	67	1500	46.939570000000003	46.967768	57.000715999999997	56.987437999999997	0103000020E61000000100000005000000C0266BD443784740F0694E5E647E4C40C0266BD443784740BE4A3E7617804C40C30E63D2DF7B4740BE4A3E7617804C40C30E63D2DF7B4740F0694E5E647E4C40C0266BD443784740F0694E5E647E4C40
56012	Большой Ихтаил	7	67	1500	47.443604999999998	47.461813999999997	56.985280000000003	56.974867000000003	0103000020E61000000100000005000000C9AB730CC8B847408E791D71C87C4C40C9AB730CC8B8474092B3B0A71D7E4C40DF6A9DB81CBB474092B3B0A71D7E4C40DF6A9DB81CBB47408E791D71C87C4C40C9AB730CC8B847408E791D71C87C4C40
18379	Большая Шишовка	7	67	1500	47.262954000000001	47.285609999999998	56.900205999999997	56.886311999999997	0103000020E610000001000000050000001B2D077AA8A14740B306EFAB72714C401B2D077AA8A14740DCD440F339734C408DB454DE8EA44740DCD440F339734C408DB454DE8EA44740B306EFAB72714C401B2D077AA8A14740B306EFAB72714C40
17935	Большая Поломка	7	67	1500	46.931789999999999	46.947062000000003	57.062280999999999	57.051428999999999	0103000020E61000000100000005000000B35E0CE5447747407288B83995864C40B35E0CE544774740C214E5D2F8874C4066A4DE5339794740C214E5D2F8874C4066A4DE53397947407288B83995864C40B35E0CE5447747407288B83995864C40
18452	Алексеиха	7	67	1500	47.364814000000003	47.392958	56.915937	56.898539	0103000020E61000000100000005000000BD8FA339B2AE47401C97715303734C40BD8FA339B2AE47402219726C3D754C40CD599F724CB247402219726C3D754C40CD599F724CB247401C97715303734C40BD8FA339B2AE47401C97715303734C40
2100	Яхреньга	7	67	122	46.881269000000003	46.942238000000003	60.234803999999997	60.210624000000003	0103000020E6100000010000000500000044FD2E6CCD70474059E02BBAF51A4E4044FD2E6CCD704740287CB60E0E1E4E40348639419B784740287CB60E0E1E4E40348639419B78474059E02BBAF51A4E4044FD2E6CCD70474059E02BBAF51A4E40
61192	Щеткино	7	67	122	47.404834000000001	47.447018999999997	60.224564000000001	60.213909000000001	0103000020E610000001000000050000008927BB99D1B34740F8A8BF5E611B4E408927BB99D1B34740F2ED5D83BE1C4E4066D828EB37B94740F2ED5D83BE1C4E4066D828EB37B94740F8A8BF5E611B4E408927BB99D1B34740F8A8BF5E611B4E40
61188	Шолга	7	67	122	46.989443999999999	47.006520999999999	60.452758000000003	60.440731	0103000020E61000000100000005000000999CDA19A67E4740ACAA97DF69384E40999CDA19A67E47404E8061F9F3394E405DDE1CAED58047404E8061F9F3394E405DDE1CAED5804740ACAA97DF69384E40999CDA19A67E4740ACAA97DF69384E40
16662	Ровдино	7	67	122	46.802092000000002	46.832338	60.176264000000003	60.163297	0103000020E610000001000000050000000E315EF3AA664740784485EAE6144E400E315EF3AA66474028BB99D18F164E40E99B340D8A6A474028BB99D18F164E40E99B340D8A6A4740784485EAE6144E400E315EF3AA664740784485EAE6144E40
55991	Подосиновец	7	67	122	47.046630999999998	47.088861000000001	60.292605999999999	60.260429999999999	0103000020E6100000010000000500000069FD2D01F8854740DA722EC555214E4069FD2D01F8854740834E081D74254E40E77118CC5F8B4740834E081D74254E40E77118CC5F8B4740DA722EC555214E4069FD2D01F8854740DA722EC555214E40
55989	Пинюг	7	67	122	47.754044999999998	47.806058	60.262768999999999	60.239615000000001	0103000020E610000001000000050000002D5BEB8B84E04740C6504EB4AB1E4E402D5BEB8B84E0474089B3226AA2214E40EF5696E82CE7474089B3226AA2214E40EF5696E82CE74740C6504EB4AB1E4E402D5BEB8B84E04740C6504EB4AB1E4E40
246	Лунданка	7	67	122	47.461599	47.499535000000002	60.473126999999998	60.460132000000002	0103000020E61000000100000005000000E36E10AD15BB4740EAEBF99AE53A4E40E36E10AD15BB474063EDEF6C8F3C4E408B1A4CC3F0BF474063EDEF6C8F3C4E408B1A4CC3F0BF4740EAEBF99AE53A4E40E36E10AD15BB4740EAEBF99AE53A4E40
61198	Заречье	7	67	122	47.033794	47.045068000000001	60.473376000000002	60.462784999999997	0103000020E6100000010000000500000088669E5C53844740280AF4893C3B4E4088669E5C538447400C5BB395973C4E404E0CC9C9C48547400C5BB395973C4E404E0CC9C9C4854740280AF4893C3B4E4088669E5C53844740280AF4893C3B4E40
55995	Демьяново	7	67	122	47.026814000000002	47.034782	60.377704000000001	60.373398999999999	0103000020E61000000100000005000000988922A46E834740F7ADD689CB2F4E40988922A46E834740C1C8CB9A58304E40A73E90BC73844740C1C8CB9A58304E40A73E90BC73844740F7ADD689CB2F4E40988922A46E834740F7ADD689CB2F4E40
61187	Верхнемалье	7	67	122	47.516979999999997	47.541018999999999	60.412692	60.398493999999999	0103000020E61000000100000005000000D15790662CC247407CD3F4D901334E40D15790662CC2474011A96917D3344E40DFC14F1C40C5474011A96917D3344E40DFC14F1C40C547407CD3F4D901334E40D15790662CC247407CD3F4D901334E40
16146	Сретенское	7	67	1426	48.629821999999997	48.653770999999999	57.354588999999997	57.338746999999998	0103000020E610000001000000050000009126DE019E5048401E4FCB0F5CAB4C409126DE019E504840BB421F2C63AD4C405F09A4C4AE534840BB421F2C63AD4C405F09A4C4AE5348401E4FCB0F5CAB4C409126DE019E5048401E4FCB0F5CAB4C40
16431	Русская Шуйма	7	67	1426	48.334086999999997	48.349673000000003	57.333258000000001	57.327306	0103000020E610000001000000050000006682E15CC32A48406DE4BA29E5A94C406682E15CC32A4840B090B932A8AA4C40A9A5B915C22C4840B090B932A8AA4C40A9A5B915C22C48406DE4BA29E5A94C406682E15CC32A48406DE4BA29E5A94C40
15893	Пижанка	7	67	1426	48.495972999999999	48.563023000000001	57.469527999999997	57.450845999999999	0103000020E610000001000000050000007959130B7C3F484026C45C52B5B94C407959130B7C3F48403447567E19BC4C40AAF23D23114848403447567E19BC4C40AAF23D231148484026C45C52B5B94C407959130B7C3F484026C45C52B5B94C40
16524	Павлово	7	67	1426	48.404173999999998	48.443224000000001	57.537908000000002	57.521638000000003	0103000020E610000001000000050000005EF23FF9BB334840E92CB308C5C24C405EF23FF9BB334840DE205A2BDAC44C40B2666490BB384840DE205A2BDAC44C40B2666490BB384840E92CB308C5C24C405EF23FF9BB334840E92CB308C5C24C40
16494	Обухово	7	67	1426	48.595847999999997	48.631286000000003	57.583666999999998	57.565356999999999	0103000020E6100000010000000500000089B14CBF444C484047C8409E5DC84C4089B14CBF444C48409160AA99B5CA4C401A36CAFACD5048409160AA99B5CA4C401A36CAFACD50484047C8409E5DC84C4089B14CBF444C484047C8409E5DC84C40
16020	Мари-Ошаево	7	67	1426	48.477682999999999	48.503959000000002	57.419795999999998	57.408667000000001	0103000020E61000000100000005000000766D6FB7243D48402BFA43334FB44C40766D6FB7243D4840ED7E15E0BBB54C402FC37FBA81404840ED7E15E0BBB54C402FC37FBA814048402BFA43334FB44C40766D6FB7243D48402BFA43334FB44C40
15994	Малый Кашнур	7	67	1426	48.637943	48.643844999999999	57.393149000000001	57.386237000000001	0103000020E6100000010000000500000027DBC01DA8514840A9C0C93670B14C4027DBC01DA851484041BAD8B452B24C40B85851836952484041BAD8B452B24C40B858518369524840A9C0C93670B14C4027DBC01DA8514840A9C0C93670B14C40
16235	Ластик 2-й	7	67	1426	48.439737999999998	48.453617000000001	57.320847999999998	57.307802000000002	0103000020E610000001000000050000007B67B455493848405BD2510E66A74C407B67B45549384840567E198C11A94C406FF4311F103A4840567E198C11A94C406FF4311F103A48405BD2510E66A74C407B67B455493848405BD2510E66A74C40
16317	Казаково	7	67	1426	48.651094000000001	48.658703000000003	57.236398000000001	57.231200999999999	0103000020E61000000100000005000000984F560C57534840B8E68EFE979D4C40984F560C575348407F6B274A429E4C4078634161505448407F6B274A429E4C407863416150544840B8E68EFE979D4C40984F560C57534840B8E68EFE979D4C40
16285	Воя	7	67	1426	48.530898999999998	48.566392	57.289833999999999	57.275253999999997	0103000020E61000000100000005000000533D997FF4434840ED0BE8853BA34C40533D997FF44348406AA2CF4719A54C40A75B76887F4848406AA2CF4719A54C40A75B76887F484840ED0BE8853BA34C40533D997FF4434840ED0BE8853BA34C40
56005	Борок	7	67	1426	48.431851000000002	48.440869999999997	57.540246000000003	57.535936999999997	0103000020E6100000010000000500000059DFC0E446374840B1DB679599C44C4059DFC0E446374840BDE5EAC726C54C40CDE49B6D6E384840BDE5EAC726C54C40CDE49B6D6E384840B1DB679599C44C4059DFC0E446374840B1DB679599C44C40
16405	Безводное	7	67	1426	48.323262999999997	48.355376999999997	57.428300999999998	57.415103999999999	0103000020E61000000100000005000000E08096AE602948402A38BC2022B54C40E08096AE602948400BEC3191D2B64C40136058FE7C2D48400BEC3191D2B64C40136058FE7C2D48402A38BC2022B54C40E08096AE602948402A38BC2022B54C40
16100	Ахманово	7	67	1426	48.492657999999999	48.510939	57.374552999999999	57.356957999999999	0103000020E610000001000000050000006F0ED76A0F3F4840D505BCCCB0AD4C406F0ED76A0F3F484031CF4A5AF1AF4C401FA0FB726641484031CF4A5AF1AF4C401FA0FB7266414840D505BCCCB0AD4C406F0ED76A0F3F4840D505BCCCB0AD4C40
15429	Шадричи	7	67	789	48.605451000000002	48.623040000000003	58.687739000000001	58.676062999999999	0103000020E610000001000000050000004E2A1A6B7F4D484090847D3B89564D404E2A1A6B7F4D48408597E0D407584D40C80C54C6BF4F48408597E0D407584D40C80C54C6BF4F484090847D3B89564D404E2A1A6B7F4D484090847D3B89564D40
15791	Чудиново	7	67	789	49.053189000000003	49.073428	58.839849000000001	58.819530999999998	0103000020E61000000100000005000000E4C0ABE5CE86484072874D64E6684D40E4C0ABE5CE864840064A0A2C806B4D402B4EB51666894840064A0A2C806B4D402B4EB5166689484072874D64E6684D40E4C0ABE5CE86484072874D64E6684D40
15741	Цепели	7	67	789	49.175198000000002	49.205624	58.739279000000003	58.714860000000002	0103000020E610000001000000050000008D2958E36C964840FA9B5088805B4D408D2958E36C9648404FCFBBB1A05E4D40E8A221E3519A48404FCFBBB1A05E4D40E8A221E3519A4840FA9B5088805B4D408D2958E36C964840FA9B5088805B4D40
5604	Тохтино	7	67	789	48.499960999999999	48.536217000000001	58.638280999999999	58.625563	0103000020E610000001000000050000004223D8B8FE3F4840384BC97212504D404223D8B8FE3F48403F541A31B3514D40954737C2A24448403F541A31B3514D40954737C2A2444840384BC97212504D404223D8B8FE3F4840384BC97212504D40
15596	Степановщина	7	67	789	48.802756000000002	48.827953999999998	58.712215	58.702997000000003	0103000020E610000001000000050000007A5567B5C0664840D31742CEFB594D407A5567B5C06648403E5C72DC295B4D40D34B8C65FA6948403E5C72DC295B4D40D34B8C65FA694840D31742CEFB594D407A5567B5C0664840D31742CEFB594D40
15458	Солоницыны	7	67	789	48.549944000000004	48.574252000000001	58.729937999999997	58.722706000000002	0103000020E61000000100000005000000D350A39064464840BE4F55A1815C4D40D350A39064464840C70DBF9B6E5D4D40D0D4EB1681494840C70DBF9B6E5D4D40D0D4EB1681494840BE4F55A1815C4D40D350A39064464840BE4F55A1815C4D40
14848	Соловецкое	7	67	789	48.800708	48.816564	58.784759999999999	58.775641	0103000020E61000000100000005000000A2D288997D664840E7374C3448634D40A2D288997D664840BF9A030473644D40A48B4D2B85684840BF9A030473644D40A48B4D2B85684840E7374C3448634D40A2D288997D664840E7374C3448634D40
15382	Русаново	7	67	789	48.704183999999998	48.724594000000003	58.623730999999999	58.609572	0103000020E61000000100000005000000E82E89B3225A484056478E74064E4D40E82E89B3225A48402D40DB6AD64F4D405D70067FBF5C48402D40DB6AD64F4D405D70067FBF5C484056478E74064E4D40E82E89B3225A484056478E74064E4D40
15274	Поляки	7	67	789	48.662350000000004	48.692776000000002	58.563144000000001	58.556050999999997	0103000020E61000000100000005000000B84082E2C75448403CF4DDAD2C474D40B84082E2C75448402578431A15484D4013BA4BE2AC5848402578431A15484D4013BA4BE2AC5848403CF4DDAD2C474D40B84082E2C75448403CF4DDAD2C474D40
14931	Орлов	7	67	789	48.860427999999999	48.920993000000003	58.555990000000001	58.524299999999997	0103000020E6100000010000000500000006483481226E48407AA52C431C434D4006483481226E4840977329AE2A474D40276C3F19E3754840977329AE2A474D40276C3F19E37548407AA52C431C434D4006483481226E48407AA52C431C434D40
15156	Моржи	7	67	789	48.844276999999998	48.849074000000002	58.528688000000002	58.526485000000001	0103000020E61000000100000005000000EBE1CB44116C4840D36A48DC63434D40EBE1CB44116C4840D2E4620CAC434D4024F1F274AE6C4840D2E4620CAC434D4024F1F274AE6C4840D36A48DC63434D40EBE1CB44116C4840D36A48DC63434D40
15702	Кузнецы	7	67	789	49.019151999999998	49.036723000000002	58.665880999999999	58.656332999999997	0103000020E6100000010000000500000095D39E92738248408D2441B802544D4095D39E92738248408E03AF963B554D406901DA56B38448408E03AF963B554D406901DA56B38448408D2441B802544D4095D39E92738248408D2441B802544D40
15654	Коробовщина	7	67	789	48.901634000000001	48.920526000000002	58.847456999999999	58.839337	0103000020E61000000100000005000000187B2FBE6873484050A912656F6B4D40187B2FBE6873484015E29178796C4D40118FC4CBD375484015E29178796C4D40118FC4CBD375484050A912656F6B4D40187B2FBE6873484050A912656F6B4D40
15577	Колково	7	67	789	48.892588000000003	48.931655999999997	58.650883	58.633166000000003	0103000020E61000000100000005000000AA66D6524072484036785F950B514D40AA66D65240724840DD42572250534D40A38FF98040774840DD42572250534D40A38FF9804077484036785F950B514D40AA66D6524072484036785F950B514D40
13644	Юбилейный	7	67	1245	49.198526999999999	49.213313999999997	58.483271999999999	58.468919999999997	0103000020E61000000100000005000000BE2F2E55699948405C381092053C4D40BE2F2E556999484048895DDBDB3D4D40B4E386DF4D9B484048895DDBDB3D4D40B4E386DF4D9B48405C381092053C4D40BE2F2E55699948405C381092053C4D40
14081	Шалегово	7	67	1245	48.880560000000003	48.918298	58.358071000000002	58.317991999999997	0103000020E610000001000000050000003815A930B6704840DF313CF6B3284D403815A930B6704840B1524145D52D4D40B9FDF2C98A754840B1524145D52D4D40B9FDF2C98A754840DF313CF6B3284D403815A930B6704840DF313CF6B3284D40
14019	Усовы	7	67	1245	49.235923999999997	49.262909000000001	58.344777999999998	58.333658	0103000020E61000000100000005000000B62BF4C1329E48403E062B4EB52A4D40B62BF4C1329E4840AD307DAF212C4D407B698A00A7A14840AD307DAF212C4D407B698A00A7A148403E062B4EB52A4D40B62BF4C1329E48403E062B4EB52A4D40
13986	Торфяной	7	67	1245	49.186086000000003	49.221739999999997	58.500109999999999	58.483088000000002	0103000020E610000001000000050000002A1F82AAD1974840878BDCD3D53D4D402A1F82AAD19748408733BF9A03404D40861BF0F9619C48408733BF9A03404D40861BF0F9619C4840878BDCD3D53D4D402A1F82AAD1974840878BDCD3D53D4D40
13930	Суводи	7	67	1245	48.519446000000002	48.546852999999999	58.081069999999997	58.057187999999996	0103000020E61000000100000005000000DE04DF347D424840A0DCB6EF51074D40DE04DF347D424840E6577380600A4D40185C7347FF454840E6577380600A4D40185C7347FF454840A0DCB6EF51074D40DE04DF347D424840A0DCB6EF51074D40
14733	Стрижи	7	67	1245	49.242669999999997	49.284649000000002	58.473339000000003	58.453955000000001	0103000020E6100000010000000500000033DC80CF0F9F4840876D8B321B3A4D4033DC80CF0F9F4840EF75525F963C4D4068EBE0606FA44840EF75525F963C4D4068EBE0606FA44840876D8B321B3A4D4033DC80CF0F9F4840876D8B321B3A4D40
13894	Спас-Талица	7	67	1245	48.976545000000002	49.019125000000003	58.414088999999997	58.394520999999997	0103000020E610000001000000050000004209336DFF7C4840E84A04AA7F324D404209336DFF7C484011514CDE00354D409CC420B07282484011514CDE00354D409CC420B072824840E84A04AA7F324D404209336DFF7C4840E84A04AA7F324D40
13795	Пустоши	7	67	1245	49.018990000000002	49.039157000000003	58.329788000000001	58.317028000000001	0103000020E61000000100000005000000BC79AA436E82484049F59D5F94284D40BC79AA436E8248407F4E417E362A4D406A34B918038548407F4E417E362A4D406A34B9180385484049F59D5F94284D40BC79AA436E82484049F59D5F94284D40
13728	Пищалье	7	67	1245	48.695632000000003	48.719302999999996	58.242111999999999	58.226444000000001	0103000020E610000001000000050000008A0629780A5948400E30F31DFC1C4D408A0629780A5948400DFCA886FD1E4D401475E61E125C48400DFCA886FD1E4D401475E61E125C48400E30F31DFC1C4D408A0629780A5948400E30F31DFC1C4D40
13688	Оричи	7	67	1245	49.021388000000002	49.099048000000003	58.413980000000002	58.385572000000003	0103000020E6100000010000000500000070438CD7BC8248406D205D6C5A314D4070438CD7BC8248405B99F04BFD344D40FB5DD89AAD8C48405B99F04BFD344D40FB5DD89AAD8C48406D205D6C5A314D4070438CD7BC8248406D205D6C5A314D40
13824	Монастырщина	7	67	1245	48.843018999999998	48.866052000000003	58.239663	58.226396999999999	0103000020E610000001000000050000000C74ED0BE86B4840CD74AF93FA1C4D400C74ED0BE86B4840D787F546AD1E4D405551BCCADA6E4840D787F546AD1E4D405551BCCADA6E4840CD74AF93FA1C4D400C74ED0BE86B4840CD74AF93FA1C4D40
55979	Мирный	7	67	1245	48.621234000000001	48.653905999999999	58.320827999999999	58.291767999999998	0103000020E61000000100000005000000E6948098844F4840790261A758254D40E6948098844F48400FD253E410294D403F541A31B35348400FD253E410294D403F541A31B3534840790261A758254D40E6948098844F4840790261A758254D40
13611	Кучелапы	7	67	1245	49.442734000000002	49.468919999999997	58.213599000000002	58.204433999999999	0103000020E61000000100000005000000E469F981ABB848406118B0E42A1A4D40E469F981ABB84840AABA4736571B4D405C38109205BC4840AABA4736571B4D405C38109205BC48406118B0E42A1A4D40E469F981ABB848406118B0E42A1A4D40
13555	Коршик	7	67	1245	49.263925	49.302247000000001	58.224719	58.195314000000003	0103000020E6100000010000000500000064CC5D4BC8A14840B939950C00194D4064CC5D4BC8A1484019E59997C31C4D4035289A07B0A6484019E59997C31C4D4035289A07B0A64840B939950C00194D4064CC5D4BC8A14840B939950C00194D40
13357	Колос	7	67	1245	49.517591000000003	49.534623000000003	58.266745	58.257769000000003	0103000020E610000001000000050000001BDA006C40C2484019761893FE204D401BDA006C40C248408EAF3DB324224D403F58C6866EC448408EAF3DB324224D403F58C6866EC4484019761893FE204D401BDA006C40C2484019761893FE204D40
13519	Истобенск	7	67	1245	48.777800999999997	48.800879000000002	58.420234999999998	58.411076000000001	0103000020E61000000100000005000000E6E5B0FB8E634840D3156C239E344D40E6E5B0FB8E63484039D1AE42CA354D40CF86FC338366484039D1AE42CA354D40CF86FC3383664840D3156C239E344D40E6E5B0FB8E634840D3156C239E344D40
13457	Зенгино	7	67	1245	49.010841999999997	49.040585	58.504717999999997	58.490633000000003	0103000020E610000001000000050000002CB649456381484050ABE80FCD3E4D402CB6494563814840ECD973999A404D40A5DAA7E331854840ECD973999A404D40A5DAA7E33185484050ABE80FCD3E4D402CB649456381484050ABE80FCD3E4D40
14122	Зеленый	7	67	1245	48.825169000000002	48.843961999999998	58.352991000000003	58.347087999999999	0103000020E61000000100000005000000265646239F694840C26A2C616D2C4D40265646239F694840246420CF2E2D4D408B8862F2066C4840246420CF2E2D4D408B8862F2066C4840C26A2C616D2C4D40265646239F694840C26A2C616D2C4D40
14211	Быстряги	7	67	1245	48.727316000000002	48.749549000000002	58.333086000000002	58.325204999999997	0103000020E61000000100000005000000C4EDD0B0185D484072BF4351A0294D40C4EDD0B0185D4840B360E28FA22A4D40F0DFBC38F15F4840B360E28FA22A4D40F0DFBC38F15F484072BF4351A0294D40C4EDD0B0185D484072BF4351A0294D40
13412	Быстрица	7	67	1245	49.201563999999998	49.234101000000003	58.538530000000002	58.523172000000002	0103000020E61000000100000005000000850662D9CC9948406A17D34CF7424D40850662D9CC9948401BF5108DEE444D40FF7A8505F79D48401BF5108DEE444D40FF7A8505F79D48406A17D34CF7424D40850662D9CC9948406A17D34CF7424D40
12784	Адышево	7	67	1245	49.468794000000003	49.500891000000003	58.352929000000003	58.333691000000002	0103000020E61000000100000005000000D047197101BC48401AFCFD62B62A4D40D047197101BC4840AE6708C72C2D4D402DEE3F321DC04840AE6708C72C2D4D402DEE3F321DC048401AFCFD62B62A4D40D047197101BC48401AFCFD62B62A4D40
13326	Стрельская	7	67	1240	47.769047	47.786313	59.475268	59.464680000000001	0103000020E61000000100000005000000200BD12170E247407A8D5DA27ABB4D40200BD12170E24740EC6AF294D5BC4D40B7B585E7A5E44740EC6AF294D5BC4D40B7B585E7A5E447407A8D5DA27ABB4D40200BD12170E247407A8D5DA27ABB4D40
13268	Северный	7	67	1240	47.786096999999998	47.814726	59.881005999999999	59.871259999999999	0103000020E61000000100000005000000EA3D95D39EE447400F289B7285EF4D40EA3D95D39EE4474036CAFACDC4F04D40B7990AF148E8474036CAFACDC4F04D40B7990AF148E847400F289B7285EF4D40EA3D95D39EE447400F289B7285EF4D40
12737	Опарино	7	67	1240	48.250211999999998	48.308827000000001	59.861584000000001	59.837589000000001	0103000020E610000001000000050000008B8862F206204840A33EC91D36EB4D408B8862F206204840E1606F6248EE4D40978FA4A487274840E1606F6248EE4D40978FA4A487274840A33EC91D36EB4D408B8862F206204840A33EC91D36EB4D40
13175	Нижняя Паломица	7	67	1240	47.312424	47.339185000000001	59.852257999999999	59.844371000000002	0103000020E61000000100000005000000253E7782FDA747406D58535914EC4D40253E7782FDA747408FE046CA16ED4D409A25016A6AAB47408FE046CA16ED4D409A25016A6AAB47406D58535914EC4D40253E7782FDA747406D58535914EC4D40
13128	Молома	7	67	1240	47.589554999999997	47.609093000000001	59.720281	59.711469000000001	0103000020E61000000100000005000000BD18CA8976CB4740158F8B6A11DB4D40BD18CA8976CB47401077F52A32DC4D407C9C69C2F6CD47401077F52A32DC4D407C9C69C2F6CD4740158F8B6A11DB4D40BD18CA8976CB4740158F8B6A11DB4D40
13073	Латышский	7	67	1240	48.167898999999998	48.192853999999997	59.952173000000002	59.942394	0103000020E61000000100000005000000FB03E5B67D1548402BF9D85DA0F84D40FB03E5B67D1548402E910BCEE0F94D408E739B70AF1848402E910BCEE0F94D408E739B70AF1848402BF9D85DA0F84D40FB03E5B67D1548402BF9D85DA0F84D40
12987	Верхняя Волманга	7	67	1240	47.403792000000003	47.422854000000001	59.435882999999997	59.426006999999998	0103000020E610000001000000050000007731CD74AFB34740FC6EBA6587B64D407731CD74AFB34740F1F09E03CBB74D40CC7D721420B64740F1F09E03CBB74D40CC7D721420B64740FC6EBA6587B64D407731CD74AFB34740FC6EBA6587B64D40
12621	Шахровка	7	67	769	52.192154000000002	52.214925999999998	58.568795000000001	58.554844000000003	0103000020E61000000100000005000000D6E5948098184A40E030D12005474D40D6E5948098184A406D904946CE484D40B187F6B1821B4A406D904946CE484D40B187F6B1821B4A40E030D12005474D40D6E5948098184A40E030D12005474D40
12381	Черная Холуница	7	67	769	51.683824000000001	51.734057999999997	58.860363999999997	58.841864999999999	0103000020E61000000100000005000000261C7A8B87D74940D252793BC26B4D40261C7A8B87D74940EF535568206E4D40FFAECF9CF5DD4940EF535568206E4D40FFAECF9CF5DD4940D252793BC26B4D40261C7A8B87D74940D252793BC26B4D40
12445	Плетневская	7	67	769	52.204227000000003	52.222867000000001	58.647979999999997	58.635095999999997	0103000020E61000000100000005000000E8FA3E1C241A4A4003E962D34A514D40E8FA3E1C241A4A40253B3602F1524D40C72DE6E7861C4A40253B3602F1524D40C72DE6E7861C4A4003E962D34A514D40E8FA3E1C241A4A4003E962D34A514D40
55992	Песковка	7	67	769	52.315213999999997	52.389279999999999	59.059475999999997	59.022210000000001	0103000020E61000000100000005000000E49EAEEE58284A4074D2FBC6D7824D40E49EAEEE58284A40CD72D9E89C874D40527E52EDD3314A40CD72D9E89C874D40527E52EDD3314A4074D2FBC6D7824D40E49EAEEE58284A4074D2FBC6D7824D40
5413	Омутнинск	7	67	769	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
11909	Метрострой	7	67	769	52.319651999999998	52.342531999999999	58.866343999999998	58.858669999999996	0103000020E61000000100000005000000ED0C535BEA284A40350708E6E86D4D40ED0C535BEA284A40FC8A355CE46E4D40AFEAAC16D82B4A40FC8A355CE46E4D40AFEAAC16D82B4A40350708E6E86D4D40ED0C535BEA284A40350708E6E86D4D40
12234	Лесные Поляны	7	67	769	52.402773000000003	52.433413999999999	59.010415000000002	58.989001000000002	0103000020E610000001000000050000001D5BCF108E334A400C5BB395977E4D401D5BCF108E334A40A5315A4755814D4074D0251C7A374A40A5315A4755814D4074D0251C7A374A400C5BB395977E4D401D5BCF108E334A400C5BB395977E4D40
12085	Котчиха	7	67	769	52.330342000000002	52.353957999999999	59.132793999999997	59.119836999999997	0103000020E61000000100000005000000643F8BA5482A4A40E5EC9DD1568F4D40643F8BA5482A4A40718DCF64FF904D402B14E97E4E2D4A40718DCF64FF904D402B14E97E4E2D4A40E5EC9DD1568F4D40643F8BA5482A4A40E5EC9DD1568F4D40
12289	Зимино	7	67	769	52.380170999999997	52.395173	58.876973999999997	58.868028000000002	0103000020E610000001000000050000009DF17D71A9304A409301A08A1B6F4D409DF17D71A9304A409DB81CAF40704D4090A1630795324A409DB81CAF40704D4090A1630795324A409301A08A1B6F4D409DF17D71A9304A409301A08A1B6F4D40
12535	Залазна	7	67	769	52.494689000000001	52.519050999999997	58.679763999999999	58.653154000000001	0103000020E6100000010000000500000071581AF8513F4A4034A0DE8C9A534D4071581AF8513F4A40C37FBA8102574D4061FA5E4370424A40C37FBA8102574D4061FA5E4370424A4034A0DE8C9A534D4071581AF8513F4A4034A0DE8C9A534D40
12307	Ежово	7	67	769	52.320433000000001	52.340124000000003	58.719481999999999	58.700659000000002	0103000020E6100000010000000500000093C7D3F203294A40F452B131AF594D4093C7D3F203294A40C40776FC175C4D40D84AE82E892B4A40C40776FC175C4D40D84AE82E892B4A40F452B131AF594D4093C7D3F203294A40F452B131AF594D40
11741	Восточный	7	67	769	52.237034000000001	52.257956	58.790809000000003	58.776283999999997	0103000020E6100000010000000500000021054F21571E4A403B342C465D634D4021054F21571E4A40F530B43A39654D404BE7C3B304214A40F530B43A39654D404BE7C3B304214A403B342C465D634D4021054F21571E4A403B342C465D634D40
11878	Белореченск	7	67	769	52.273657999999998	52.312843000000001	58.781374	58.766482000000003	0103000020E61000000100000005000000F624B03907234A40817C09151C624D40F624B03907234A40ECF82F1004644D402AE44A3D0B284A40ECF82F1004644D402AE44A3D0B284A40817C09151C624D40F624B03907234A40817C09151C624D40
12564	Белорецк	7	67	769	52.467452000000002	52.501390000000001	58.678387999999998	58.667181999999997	0103000020E6100000010000000500000093399677D53B4A406C3D433866554D4093399677D53B4A40DAFF006BD5564D404E452A8C2D404A40DAFF006BD5564D404E452A8C2D404A406C3D433866554D4093399677D53B4A406C3D433866554D40
10635	Юртик	7	67	736	50.137509000000001	50.162491000000003	57.477639000000003	57.465167000000001	0103000020E61000000100000005000000EDF318E599114940D7169E978ABB4C40EDF318E599114940A725564623BD4C407A724D81CC144940A725564623BD4C407A724D81CC144940D7169E978ABB4C40EDF318E599114940D7169E978ABB4C40
11058	Швариха	7	67	736	49.606155999999999	49.631219000000002	57.545482	57.527330999999997	0103000020E610000001000000050000001823128596CD48405F950B957FC34C401823128596CD48404147AB5AD2C54C4092CEC0C8CBD048404147AB5AD2C54C4092CEC0C8CBD048405F950B957FC34C401823128596CD48405F950B957FC34C40
11119	Хмелевка	7	67	736	49.448106000000003	49.474041	57.537719000000003	57.526465999999999	0103000020E61000000100000005000000199293895BB948405C3AE63C63C34C40199293895BB948400BB8E7F9D3C44C4048FB1F60ADBC48400BB8E7F9D3C44C4048FB1F60ADBC48405C3AE63C63C34C40199293895BB948405C3AE63C63C34C40
10942	Татаурово	7	67	736	49.542428999999998	49.584273000000003	57.826161999999997	57.803134999999997	0103000020E6100000010000000500000074B33F506EC54840F0A2AF20CDE64C4074B33F506EC54840569929ADBFE94C40C9772975C9CA4840569929ADBFE94C40C9772975C9CA4840F0A2AF20CDE64C4074B33F506EC54840F0A2AF20CDE64C40
10752	Рябиновщина	7	67	736	49.894810999999997	49.915446000000003	57.553860999999998	57.539076999999999	0103000020E61000000100000005000000EF8CB62A89F248404D83A27900C54C40EF8CB62A89F24840D2C3D0EAE4C64C4084A0A3552DF54840D2C3D0EAE4C64C4084A0A3552DF548404D83A27900C54C40EF8CB62A89F248404D83A27900C54C40
56002	Птицефабрика	7	67	736	49.844928000000003	49.871015	57.537323000000001	57.527881999999998	0103000020E61000000100000005000000C3BCC79926EC4840D3122BA391C34C40C3BCC79926EC4840BE310400C7C44C40A8A9656B7DEF4840BE310400C7C44C40A8A9656B7DEF4840D3122BA391C34C40C3BCC79926EC4840D3122BA391C34C40
10698	Перевоз	7	67	736	49.987805000000002	50.020116999999999	57.562286	57.550437000000002	0103000020E61000000100000005000000A3E9EC6470FE484012C138B874C64C40A3E9EC6470FE4840D47FD6FCF8C74C40FC8BA03193024940D47FD6FCF8C74C40FC8BA0319302494012C138B874C64C40A3E9EC6470FE484012C138B874C64C40
10116	Нолинск	7	67	736	49.909652000000001	49.963227000000003	57.571902000000001	57.545158000000001	0103000020E61000000100000005000000D95E0B7A6FF448408E93C2BCC7C54C40D95E0B7A6FF448402D42B11534C94C40E6CFB7054BFB48402D42B11534C94C40E6CFB7054BFB48408E93C2BCC7C54C40D95E0B7A6FF448408E93C2BCC7C54C40
10553	Медведок	7	67	736	50.006867	50.061709	57.400951999999997	57.373024999999998	0103000020E61000000100000005000000F8359204E100494092CB7F48BFAF4C40F8359204E100494005A2276552B34C40376F9C14E607494005A2276552B34C40376F9C14E607494092CB7F48BFAF4C40F8359204E100494092CB7F48BFAF4C40
10477	Лудяна	7	67	736	49.690579	49.724238999999997	57.740675000000003	57.721113000000003	0103000020E61000000100000005000000F62686E464D8484038DC476E4DDC4C40F62686E464D848407FFB3A70CEDE4C406EBE11DDB3DC48407FFB3A70CEDE4C406EBE11DDB3DC484038DC476E4DDC4C40F62686E464D8484038DC476E4DDC4C40
10383	Кырчаны	7	67	736	50.145882	50.166516000000001	57.654398	57.630101000000003	0103000020E610000001000000050000009C89E942AC124940A5164A26A7D04C409C89E942AC124940AE484C50C3D34C406021736550154940AE484C50C3D34C406021736550154940A5164A26A7D04C409C89E942AC124940A5164A26A7D04C40
5126	Карачи	7	67	736	49.550730000000001	49.567070000000001	57.861001000000002	57.851663000000002	0103000020E610000001000000050000008A7615527EC648404C1B0E4B03ED4C408A7615527EC648406269E04735EE4C407845F0BF95C848406269E04735EE4C407845F0BF95C848404C1B0E4B03ED4C408A7615527EC648404C1B0E4B03ED4C40
5266	Верхоишеть	7	67	736	49.460171000000003	49.497045999999997	57.704132000000001	57.681981	0103000020E61000000100000005000000A8C821E2E6BA484027BF45274BD74C40A8C821E2E6BA4840960854FF20DA4C40C64D0D349FBF4840960854FF20DA4C40C64D0D349FBF484027BF45274BD74C40A8C821E2E6BA484027BF45274BD74C40
10847	Варнаки	7	67	736	49.774141	49.813504999999999	57.495384999999999	57.478040999999997	0103000020E6100000010000000500000012BF620D17E34840D5928E7230BD4C4012BF620D17E34840E8F692C668BF4C40F5108DEE20E84840E8F692C668BF4C40F5108DEE20E84840D5928E7230BD4C4012BF620D17E34840D5928E7230BD4C40
5275	Ботыли	7	67	736	49.856292000000003	49.890507999999997	57.492308000000001	57.475631	0103000020E61000000100000005000000C9E9EBF99AED48405DFB027AE1BC4C40C9E9EBF99AED484093C7D3F203BF4C40C669882AFCF1484093C7D3F203BF4C40C669882AFCF148405DFB027AE1BC4C40C9E9EBF99AED48405DFB027AE1BC4C40
10264	Аркуль	7	67	736	50.029243999999998	50.068131999999999	57.294775000000001	57.271355999999997	0103000020E6100000010000000500000057CD7344BE03494064C91CCBBBA24C4057CD7344BE034940D656EC2FBBA54C40D1E7A38CB8084940D656EC2FBBA54C40D1E7A38CB808494064C91CCBBBA24C4057CD7344BE03494064C91CCBBBA24C40
55993	мкр. Радужный	7	67	7390	49.638890000000004	49.770564999999998	58.563124999999999	58.481727999999997	0103000020E61000000100000005000000E8DEC325C7D14840A3C85A43A93D4D40E8DEC325C7D14840AE47E17A14484D409B38B9DFA1E24840AE47E17A14484D409B38B9DFA1E24840A3C85A43A93D4D40E8DEC325C7D14840A3C85A43A93D4D40
10076	Соколово	7	67	733	50.392254000000001	50.413066999999998	57.662573999999999	57.652380999999998	0103000020E61000000100000005000000D3DC0A613532494011C4793881D34C40D3DC0A613532494007978E39CFD44C4046072461DF34494007978E39CFD44C4046072461DF34494011C4793881D34C40D3DC0A613532494011C4793881D34C40
10045	Слудка	7	67	733	50.636747999999997	50.674135999999997	57.560972999999997	57.544809999999998	0103000020E610000001000000050000008EE55DF58051494052448655BCC54C408EE55DF580514940317898F6CDC74C403387A4164A564940317898F6CDC74C403387A4164A56494052448655BCC54C408EE55DF58051494052448655BCC54C40
5108	Нема	7	67	733	50.459474	50.548389999999998	57.518118999999999	57.492652	0103000020E6100000010000000500000060AE450BD03A49408D2782380FBF4C4060AE450BD03A4940D63730B951C24C400ABABDA431464940D63730B951C24C400ABABDA4314649408D2782380FBF4C4060AE450BD03A49408D2782380FBF4C40
9813	Марково	7	67	733	50.815170999999999	50.846674999999998	57.566963999999999	57.554710999999998	0103000020E61000000100000005000000E5D2F88557684940A0DD21C500C74C40E5D2F885576849403201BF4692C84C409FABADD85F6C49403201BF4692C84C409FABADD85F6C4940A0DD21C500C74C40E5D2F88557684940A0DD21C500C74C40
9774	Колобово	7	67	733	50.619222000000001	50.645426	57.625388000000001	57.609943000000001	0103000020E610000001000000050000005B7B9FAA424F49404AB6BA9C12CE4C405B7B9FAA424F4940CAA7C7B60CD04C407AFEB4519D524940CAA7C7B60CD04C407AFEB4519D5249404AB6BA9C12CE4C405B7B9FAA424F49404AB6BA9C12CE4C40
61367	Ильинское	7	67	733	50.378276	50.408799999999999	57.755454	57.731686000000003	0103000020E610000001000000050000004C6E14596B304940757808E3A7DD4C404C6E14596B304940F2D077B7B2E04C406A4DF38E53344940F2D077B7B2E04C406A4DF38E53344940757808E3A7DD4C404C6E14596B304940757808E3A7DD4C40
9676	Городище	7	67	733	50.268115000000002	50.295397000000001	57.700530000000001	57.686138	0103000020E610000001000000050000009548A297512249407C45B75ED3D74C409548A29751224940F6EE8FF7AAD94C40132BA391CF254940F6EE8FF7AAD94C40132BA391CF2549407C45B75ED3D74C409548A297512249407C45B75ED3D74C40
9600	Васильевское	7	67	733	50.288947	50.315457000000002	57.569642999999999	57.556694999999998	0103000020E610000001000000050000007FA31D37FC244940616C21C841C74C407FA31D37FC2449409AB2D30FEAC84C40AB251DE5602849409AB2D30FEAC84C40AB251DE560284940616C21C841C74C407FA31D37FC244940616C21C841C74C40
61365	Архангельское	7	67	733	50.179037999999998	50.229236	57.646428	57.626145000000001	0103000020E61000000100000005000000E15E99B7EA164940E7C6F48425D04C40E15E99B7EA164940FE9B1727BED24C406E88F19A571D4940FE9B1727BED24C406E88F19A571D4940E7C6F48425D04C40E15E99B7EA164940E7C6F48425D04C40
52092	Шевырталово	7	67	449	50.695371999999999	50.717021000000003	59.187038000000001	59.171729999999997	0103000020E61000000100000005000000ED461FF301594940FCDEA63FFB954D40ED461FF301594940FC8D76DCF0974D40CAC51858C75B4940FC8D76DCF0974D40CAC51858C75B4940FCDEA63FFB954D40ED461FF301594940FCDEA63FFB954D40
9445	Синегорье	7	67	449	50.674486000000002	50.723956000000001	59.724133000000002	59.698326999999999	0103000020E6100000010000000500000010CEA78E55564940F77475C762D94D4010CEA78E55564940297AE063B0DC4D401ADF1797AA5C4940297AE063B0DC4D401ADF1797AA5C4940F77475C762D94D4010CEA78E55564940F77475C762D94D40
9433	Первомайск	7	67	449	50.563302	50.585194000000001	59.613325000000003	59.598961000000003	0103000020E61000000100000005000000BDE2A9471A4849402C4A09C1AACC4D40BDE2A9471A484940DC68006F81CE4D4060E811A3E74A4940DC68006F81CE4D4060E811A3E74A49402C4A09C1AACC4D40BDE2A9471A4849402C4A09C1AACC4D40
9302	Орлецы	7	67	449	51.053117	51.073635000000003	59.755372000000001	59.747461999999999	0103000020E610000001000000050000004AEEB089CC8649405A80B6D5ACDF4D404AEEB089CC86494035289A07B0E04D40A56B26DF6C89494035289A07B0E04D40A56B26DF6C8949405A80B6D5ACDF4D404AEEB089CC8649405A80B6D5ACDF4D40
52099	Назаровцы	7	67	449	50.980784999999997	50.995759999999997	59.433562999999999	59.420288999999997	0103000020E6100000010000000500000024B4E55C8A7D49402CEFAA07CCB54D4024B4E55C8A7D4940B9E00CFE7EB74D401D554D10757F4940B9E00CFE7EB74D401D554D10757F49402CEFAA07CCB54D4024B4E55C8A7D49402CEFAA07CCB54D40
8569	Нагорск	7	67	449	50.777450999999999	50.823714000000002	59.348222999999997	59.293506000000001	0103000020E610000001000000050000000A9FAD83836349400397C79A91A54D400A9FAD8383634940855B3E9292AC4D40F1A0D9756F694940855B3E9292AC4D40F1A0D9756F6949400397C79A91A54D400A9FAD83836349400397C79A91A54D40
9115	Мулино	7	67	449	50.893225999999999	50.922125000000001	59.342028999999997	59.326855000000002	0103000020E61000000100000005000000ECF7C43A557249405DC47762D6A94D40ECF7C43A557249404CA4349BC7AB4D4079E92631087649404CA4349BC7AB4D4079E92631087649405DC47762D6A94D40ECF7C43A557249405DC47762D6A94D40
2546	Липовое	7	67	449	51.003162000000003	51.031063000000003	59.281823000000003	59.272365999999998	0103000020E61000000100000005000000844BC79C678049406B459BE3DCA24D40844BC79C678049405C21ACC612A44D40CE8E54DFF98349405C21ACC612A44D40CE8E54DFF98349406B459BE3DCA24D40844BC79C678049406B459BE3DCA24D40
52106	Липовка	7	67	449	50.638508999999999	50.805182000000002	59.526853000000003	59.494275999999999	0103000020E61000000100000005000000D099B4A9BA5149404E999B6F44BF4D40D099B4A9BA51494056664AEB6FC34D40F8A92A341067494056664AEB6FC34D40F8A92A34106749404E999B6F44BF4D40D099B4A9BA5149404E999B6F44BF4D40
9365	Крутой Лог	7	67	449	50.773201999999998	50.793081999999998	59.598233	59.58522	0103000020E61000000100000005000000D4997B48F8624940897B2C7DE8CA4D40D4997B48F8624940A93121E692CC4D40EC8502B683654940A93121E692CC4D40EC8502B683654940897B2C7DE8CA4D40D4997B48F8624940897B2C7DE8CA4D40
52095	Качонки	7	67	449	51.340694999999997	51.357125000000003	59.550803000000002	59.540832000000002	0103000020E610000001000000050000009274CDE49BAB4940AD50A4FB39C54D409274CDE49BAB4940F4C473B680C64D40C1CAA145B6AD4940F4C473B680C64D40C1CAA145B6AD4940AD50A4FB39C54D409274CDE49BAB4940AD50A4FB39C54D40
8944	Заево	7	67	449	50.550141000000004	50.573524999999997	59.170046999999997	59.150292999999998	0103000020E61000000100000005000000299831056B464940ABE80FCD3C934D40299831056B46494036E49F19C4954D401D3867446949494036E49F19C4954D401D38674469494940ABE80FCD3C934D40299831056B464940ABE80FCD3C934D40
9200	Бажелка	7	67	449	50.053767999999998	50.078705999999997	59.485878999999997	59.473508000000002	0103000020E6100000010000000500000021C9ACDEE10649407B32FFE89BBC4D4021C9ACDEE10649401668774831BE4D40DEFFC709130A49401668774831BE4D40DEFFC709130A49407B32FFE89BBC4D4021C9ACDEE10649407B32FFE89BBC4D40
8035	Тылай	7	67	942	48.867345	48.881224000000003	59.609743000000002	59.599699000000001	0103000020E61000000100000005000000B0AC3429056F4840D238D4EFC2CC4D40B0AC3429056F484083FB010F0CCE4D40A439B2F2CB70484083FB010F0CCE4D40A439B2F2CB704840D238D4EFC2CC4D40B0AC3429056F4840D238D4EFC2CC4D40
56023	Староверческая	7	67	942	48.604407999999999	48.638607	59.634557999999998	59.616802999999997	0103000020E610000001000000050000006BB8C83D5D4D48408F899466F3CE4D406BB8C83D5D4D484024B5503239D14D4093FFC9DFBD51484024B5503239D14D4093FFC9DFBD5148408F899466F3CE4D406BB8C83D5D4D48408F899466F3CE4D40
8278	Пермята	7	67	942	48.391686999999997	48.426882999999997	59.196832000000001	59.187688000000001	0103000020E6100000010000000500000059A2B3CC2232484003ED0E2906984D4059A2B3CC2232484034677DCA31994D40F31B261AA436484034677DCA31994D40F31B261AA436484003ED0E2906984D4059A2B3CC2232484003ED0E2906984D40
8353	Паломохино	7	67	942	48.318223000000003	48.347938999999997	59.258094999999997	59.249101000000003	0103000020E61000000100000005000000E2EA0088BB2848405133A48AE29F4D40E2EA0088BB2848406C21C84109A14D406000E143892C48406C21C84109A14D406000E143892C48405133A48AE29F4D40E2EA0088BB2848405133A48AE29F4D40
7854	Октябрьский	7	67	942	48.869554999999998	48.918900000000001	59.451999999999998	59.433484999999997	0103000020E61000000100000005000000618907944D6F48403D27BD6F7CB74D40618907944D6F484060E5D022DBB94D40AF25E4839E75484060E5D022DBB94D40AF25E4839E7548403D27BD6F7CB74D40618907944D6F48403D27BD6F7CB74D40
7625	Мураши	7	67	942	48.942166	49.026266	59.413870000000003	59.377640999999997	0103000020E610000001000000050000009AB33EE5987848407A50508A56B04D409AB33EE598784840D46531B1F9B44D40957F2DAF5C834840D46531B1F9B44D40957F2DAF5C8348407A50508A56B04D409AB33EE5987848407A50508A56B04D40
8145	Казаковщина	7	67	942	48.449018000000002	48.473075000000001	59.090957000000003	59.084637999999998	0103000020E610000001000000050000005DA8FC6B79394840DAFF006BD58A4D405DA8FC6B79394840D02B9E7AA48B4D4011C7BAB88D3C4840D02B9E7AA48B4D4011C7BAB88D3C4840DAFF006BD58A4D405DA8FC6B79394840DAFF006BD58A4D40
8494	Даниловка	7	67	942	49.087648000000002	49.119044000000002	59.413246999999998	59.402146000000002	0103000020E61000000100000005000000A8C7B60C388B4840CE1B278579B34D40A8C7B60C388B4840C6151747E5B44D407C6473D53C8F4840C6151747E5B44D407C6473D53C8F4840CE1B278579B34D40A8C7B60C388B4840CE1B278579B34D40
8376	Верхораменье	7	67	942	48.486108999999999	48.510696000000003	59.329118000000001	59.320858999999999	0103000020E6100000010000000500000048A5D8D1383E48404AD05FE811A94D4048A5D8D1383E48403143E38920AA4D4059198D7C5E4148403143E38920AA4D4059198D7C5E4148404AD05FE811A94D4048A5D8D1383E48404AD05FE811A94D40
8242	Боровица	7	67	942	48.380296999999999	48.404218999999998	59.130375000000001	59.118349000000002	0103000020E610000001000000050000002AE27492AD304840D5415E0F268F4D402AE27492AD304840A69BC420B0904D40FEB5BC72BD334840A69BC420B0904D40FEB5BC72BD334840D5415E0F268F4D402AE27492AD304840D5415E0F268F4D40
7915	Безбожник	7	67	942	48.783146000000002	48.830711999999998	59.517957000000003	59.501432999999999	0103000020E6100000010000000500000022FFCC203E6448404D11E0F42EC04D4022FFCC203E644840FDDD3B6A4CC24D40873254C5546A4840FDDD3B6A4CC24D40873254C5546A48404D11E0F42EC04D4022FFCC203E6448404D11E0F42EC04D40
7143	Тат-Верх-Гоньба	7	67	808	50.448900999999999	50.475321000000001	56.661817999999997	56.643143999999999	0103000020E6100000010000000500000023128596753949402F4FE78A52524C402312859675394940BAF3C473B6544C400F0D8B51D73C4940BAF3C473B6544C400F0D8B51D73C49402F4FE78A52524C4023128596753949402F4FE78A52524C40
7103	Старый Ирюк	7	67	808	50.54954	50.577835999999998	56.567881	56.550460000000001	0103000020E6100000010000000500000003ECA35357464940CAE0287975464C4003ECA3535746494088821953B0484C40C939B187F649494088821953B0484C40C939B187F6494940CAE0287975464C4003ECA35357464940CAE0287975464C40
6441	Старый Буртек	7	67	808	50.792865999999997	50.815423000000003	56.424734999999998	56.415025999999997	0103000020E610000001000000050000001F0E12A27C654940AE7E6C921F354C401F0E12A27C654940B83B6BB75D364C40FFB3E6C75F684940B83B6BB75D364C40FFB3E6C75F684940AE7E6C921F354C401F0E12A27C654940AE7E6C921F354C40
6116	Старый Бурец	7	67	808	50.881295999999999	50.907131999999997	56.392820999999998	56.378504	0103000020E610000001000000050000003D0CAD4ECE704940DDB3AED172304C403D0CAD4ECE7049404C1762F547324C40D993C0E61C7449404C1762F547324C40D993C0E61C744940DDB3AED172304C403D0CAD4ECE704940DDB3AED172304C40
7200	Старая Тушка	7	67	808	50.485408999999997	50.522015000000003	56.75067	56.740729000000002	0103000020E610000001000000050000008F17D2E1213E494072193735D05E4C408F17D2E1213E49404E0B5EF415604C40BF823463D14249404E0B5EF415604C40BF823463D142494072193735D05E4C408F17D2E1213E494072193735D05E4C40
7008	Савали	7	67	808	50.620685999999999	50.650950000000002	56.541958999999999	56.529038999999997	0103000020E61000000100000005000000E38A8BA3724F49407EA7C98CB7434C40E38A8BA3724F4940ED629AE95E454C4065AA605452534940ED629AE95E454C4065AA6054525349407EA7C98CB7434C40E38A8BA3724F49407EA7C98CB7434C40
6913	Рожки	7	67	808	50.490654999999997	50.541876999999999	56.694637	56.668585	0103000020E61000000100000005000000374F75C8CD3E49404FCC7A3194554C40374F75C8CD3E4940B8CB7EDDE9584C4030BABC395C454940B8CB7EDDE9584C4030BABC395C4549404FCC7A3194554C40374F75C8CD3E49404FCC7A3194554C40
6827	Ральники	7	67	808	50.107038000000003	50.132981999999998	56.657673000000003	56.645564	0103000020E61000000100000005000000F2B6D26BB30D4940CBBC55D7A1524C40F2B6D26BB30D49402A3BFDA02E544C40747ADE8D051149402A3BFDA02E544C40747ADE8D05114940CBBC55D7A1524C40F2B6D26BB30D4940CBBC55D7A1524C40
6646	Преображенка	7	67	808	50.993110000000001	51.015163000000001	56.464376000000001	56.452469000000001	0103000020E6100000010000000500000050AA7D3A1E7F494017BA1281EA394C4050AA7D3A1E7F49400E863AAC703B4C40FC8D76DCF08149400E863AAC703B4C40FC8D76DCF081494017BA1281EA394C4050AA7D3A1E7F494017BA1281EA394C40
6765	Порез	7	67	808	50.244875999999998	50.263139000000002	56.6464	56.636263	0103000020E61000000100000005000000A3C9C518581F4940D253E41071514C40A3C9C518581F49403411363CBD524C40ADA6EB89AE2149403411363CBD524C40ADA6EB89AE214940D253E41071514C40A3C9C518581F4940D253E41071514C40
6737	Плотбище	7	67	808	50.547266999999998	50.571863	56.832737999999999	56.81335	0103000020E610000001000000050000000B9755D80C464940CE1951DA1B684C400B9755D80C4649407711A628976A4C406F6589CE324949407711A628976A4C406F6589CE32494940CE1951DA1B684C400B9755D80C464940CE1951DA1B684C40
6334	Пахотная	7	67	808	50.693413999999997	50.699261999999997	56.514575000000001	56.509552999999997	0103000020E61000000100000005000000554B3ACAC1584940124A5F0839414C40554B3ACAC15849406B2BF697DD414C40F3AACE6A815949406B2BF697DD414C40F3AACE6A81594940124A5F0839414C40554B3ACAC1584940124A5F0839414C40
6666	Новый Смаиль	7	67	808	50.649351000000003	50.680495999999998	56.409025999999997	56.391928999999998	0103000020E61000000100000005000000FD4FFEEE1D5349404FADBEBA2A324C40FD4FFEEE1D5349405A9BC6F65A344C408787307E1A5749405A9BC6F65A344C408787307E1A5749404FADBEBA2A324C40FD4FFEEE1D5349404FADBEBA2A324C40
6131	Новый Кокуй	7	67	808	51.039121000000002	51.054608000000002	56.605271000000002	56.593676000000002	0103000020E610000001000000050000001DCBBBEA01854940C6353E93FD4B4C401DCBBBEA01854940CE1B2785794D4C40CC0C1B65FD864940CE1B2785794D4C40CC0C1B65FD864940C6353E93FD4B4C401DCBBBEA01854940C6353E93FD4B4C40
7032	Новый Ирюк	7	67	808	50.554813000000003	50.575904999999999	56.608956999999997	56.599300999999997	0103000020E61000000100000005000000A532C51C04474940E4BA29E5B54C4C40A532C51C04474940CBD58F4DF24D4C402B4D4A41B7494940CBD58F4DF24D4C402B4D4A41B7494940E4BA29E5B54C4C40A532C51C04474940E4BA29E5B54C4C40
6531	Мелеть	7	67	808	50.788634999999999	50.822870000000002	56.661284000000002	56.643692999999999	0103000020E6100000010000000500000090BDDEFDF164494002D53F8864524C4090BDDEFDF16449401DAF40F4A4544C40056EDDCD536949401DAF40F4A4544C40056EDDCD5369494002D53F8864524C4090BDDEFDF164494002D53F8864524C40
6556	Мари-Малмыж	7	67	808	50.851418000000002	50.882418999999999	56.512200999999997	56.488497000000002	0103000020E61000000100000005000000E59CD843FB6C4940D998D711873E4C40E59CD843FB6C49403FFD67CD8F414C403C2F151BF37049403FFD67CD8F414C403C2F151BF3704940D998D711873E4C40E59CD843FB6C4940D998D711873E4C40
6011	Малый Китяк	7	67	808	50.757491000000002	50.777549999999998	56.360711000000002	56.349195000000002	0103000020E61000000100000005000000D6011077F56049409F76F86BB22C4C40D6011077F56049405B272EC72B2E4C409D8026C2866349405B272EC72B2E4C409D8026C2866349409F76F86BB22C4C40D6011077F56049409F76F86BB22C4C40
7316	Малмыж	7	67	808	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
6451	Константиновка	7	67	808	50.860320999999999	50.893180999999998	56.695996999999998	56.677908000000002	0103000020E61000000100000005000000F0879FFF1E6E494030D978B0C5564C40F0879FFF1E6E49409B8E006E16594C404C3448C1537249409B8E006E16594C404C3448C15372494030D978B0C5564C40F0879FFF1E6E494030D978B0C5564C40
7250	Кинерь	7	67	808	50.447220999999999	50.468116000000002	56.797181000000002	56.781551999999998	0103000020E61000000100000005000000CE8AA8893E394940CB0F5CE509644C40CE8AA8893E3949400DFFE9060A664C40FF5D9F39EB3B49400DFFE9060A664C40FF5D9F39EB3B4940CB0F5CE509644C40CE8AA8893E394940CB0F5CE509644C40
6243	Калинино	7	67	808	50.621907999999998	50.654058999999997	56.514679000000001	56.495429000000001	0103000020E61000000100000005000000758F6CAE9A4F4940B83EAC376A3F4C40758F6CAE9A4F494010786000E1414C40C5538F34B853494010786000E1414C40C5538F34B8534940B83EAC376A3F4C40758F6CAE9A4F4940B83EAC376A3F4C40
6225	Каксинвай	7	67	808	51.105542999999997	51.123806000000002	56.534379999999999	56.527267000000002	0103000020E610000001000000050000002EA9DA6E828D494049A12C7C7D434C402EA9DA6E828D494078D1579066444C40388600E0D88F494078D1579066444C40388600E0D88F494049A12C7C7D434C402EA9DA6E828D494049A12C7C7D434C40
6962	Гоньба	7	67	808	50.681781000000001	50.707805	56.601506000000001	56.588075000000003	0103000020E6100000010000000500000060048D9944574940304CA60A464B4C4060048D9944574940842C0B26FE4C4C40FF78AF5A995A4940842C0B26FE4C4C40FF78AF5A995A4940304CA60A464B4C4060048D9944574940304CA60A464B4C40
5916	Большой Сатнур	7	67	808	50.933020999999997	50.946863999999998	56.535001000000001	56.517007999999997	0103000020E6100000010000000500000098BD6C3B6D7749409BE271512D424C4098BD6C3B6D774940E529ABE97A444C403FE1ECD632794940E529ABE97A444C403FE1ECD6327949409BE271512D424C4098BD6C3B6D7749409BE271512D424C40
5932	Большой Китяк	7	67	808	50.733325999999998	50.769796999999997	56.346575999999999	56.334867000000003	0103000020E610000001000000050000003BA759A0DD5D49403CC1FEEBDC2A4C403BA759A0DD5D49400CCA349A5C2C4C408AC745B5886249400CCA349A5C2C4C408AC745B5886249403CC1FEEBDC2A4C403BA759A0DD5D49403CC1FEEBDC2A4C40
5839	Арык	7	67	808	50.809655999999997	50.839623000000003	56.594785999999999	56.585090999999998	0103000020E610000001000000050000004D81CCCEA26749408B170B43E44A4C404D81CCCEA2674940300F99F2214C4C4016FC36C4786B4940300F99F2214C4C4016FC36C4786B49408B170B43E44A4C404D81CCCEA26749408B170B43E44A4C40
5762	Аджим	7	67	808	50.246195999999998	50.286701000000001	56.746395999999997	56.731827000000003	0103000020E61000000100000005000000F833BC59831F494037AAD381AC5D4C40F833BC59831F4940BFEE74E7895F4C40815D4D9EB2244940BFEE74E7895F4C40815D4D9EB224494037AAD381AC5D4C40F833BC59831F494037AAD381AC5D4C40
47793	Христофорово	7	67	412	47.242589000000002	47.261372999999999	60.907127000000003	60.893970000000003	0103000020E6100000010000000500000047AF06280D9F474075CDE49B6D724E4047AF06280D9F4740C828CFBC1C744E405987A3AB74A14740C828CFBC1C744E405987A3AB74A1474075CDE49B6D724E4047AF06280D9F474075CDE49B6D724E40
5422	Учка	7	67	412	47.720125000000003	47.736555000000003	60.660393999999997	60.647813999999997	0103000020E610000001000000050000001904560E2DDC47400AF2B391EB524E401904560E2DDC4740C03C64CA87544E40475A2A6F47DE4740C03C64CA87544E40475A2A6F47DE47400AF2B391EB524E401904560E2DDC47400AF2B391EB524E40
5192	Уга	7	67	412	48.343107000000003	48.375535999999997	60.390146000000001	60.378157999999999	0103000020E61000000100000005000000AC0320EEEA2B4840425C397B67304E40AC0320EEEA2B48402655DB4DF0314E403E3C4B90113048402655DB4DF0314E403E3C4B9011304840425C397B67304E40AC0320EEEA2B4840425C397B67304E40
4624	Сирино	7	67	412	47.791981	47.797829	60.957183999999998	60.953611000000002	0103000020E61000000100000005000000D50627A25FE547408D0DDDEC0F7A4E40D50627A25FE5474092205C01857A4E407366BB421FE6474092205C01857A4E407366BB421FE647408D0DDDEC0F7A4E40D50627A25FE547408D0DDDEC0F7A4E40
5285	Папулово	7	67	412	47.999941	48.049016000000002	60.595688000000003	60.580050999999997	0103000020E61000000100000005000000FB761211FEFF47408C81751C3F4A4E40FB761211FEFF4740514F1F813F4C4E40897D022846064840514F1F813F4C4E40897D0228460648408C81751C3F4A4E40FB761211FEFF47408C81751C3F4A4E40
4840	Озерская	7	67	412	47.180408	47.190640000000002	60.654279000000002	60.644050999999997	0103000020E61000000100000005000000E8F7FD9B1797474061FA5E4370524E40E8F7FD9B17974740D4BA0D6ABF534E409CA73AE466984740D4BA0D6ABF534E409CA73AE46698474061FA5E4370524E40E8F7FD9B1797474061FA5E4370524E40
4539	Луза	7	67	412	47.200395999999998	47.313448999999999	60.63908	60.604889	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
4943	Лальск	7	67	412	47.567573000000003	47.607126000000001	60.748035000000002	60.719399000000003	0103000020E61000000100000005000000DB8B683BA6C8474037E33444155C4E40DB8B683BA6C84740B6A1629CBF5F4E409146054EB6CD4740B6A1629CBF5F4E409146054EB6CD474037E33444155C4E40DB8B683BA6C8474037E33444155C4E40
4874	Каравайково	7	67	412	47.151392000000001	47.166393999999997	60.625965999999998	60.622014999999998	0103000020E61000000100000005000000227024D0609347408B4F01309E4F4E40227024D060934740373465A71F504E4014200A664C954740373465A71F504E4014200A664C9547408B4F01309E4F4E40227024D0609347408B4F01309E4F4E40
4686	Животово	7	67	412	47.673690999999998	47.691378999999998	60.850524	60.837777000000003	0103000020E61000000100000005000000054EB6813BD64740A62BD8463C6B4E40054EB6813BD64740473B6EF8DD6C4E401212691B7FD84740473B6EF8DD6C4E401212691B7FD84740A62BD8463C6B4E40054EB6813BD64740A62BD8463C6B4E40
4779	Ефаново	7	67	412	47.317301999999998	47.334899999999998	60.666716000000001	60.659908999999999	0103000020E610000001000000050000004A7A185A9DA8474004ABEAE577544E404A7A185A9DA8474027DC2BF356554E4017B7D100DEAA474027DC2BF356554E4017B7D100DEAA474004ABEAE577544E404A7A185A9DA8474004ABEAE577544E40
5100	Аксеновская	7	67	412	47.945988	47.956085000000002	60.709223000000001	60.702570999999999	0103000020E610000001000000050000004834812216F947401B0FB6D8ED594E404834812216F947401749BBD1C75A4E401C9947FE60FA47401749BBD1C75A4E401C9947FE60FA47401B0FB6D8ED594E404834812216F947401B0FB6D8ED594E40
56036	Адреева Гора	7	67	412	48.188381	48.198981000000003	60.474457999999998	60.465676999999999	0103000020E6100000010000000500000009185DDE1C184840ECBFCE4D9B3B4E4009185DDE1C184840ACA92C0ABB3C4E4040C39B3578194840ACA92C0ABB3C4E4040C39B3578194840ECBFCE4D9B3B4E4009185DDE1C184840ECBFCE4D9B3B4E40
4448	Синцово	7	67	575	49.235321999999996	49.256981000000003	57.334918999999999	57.326464999999999	0103000020E61000000100000005000000C00303081F9E4840F224E99AC9A94C40C00303081F9E48408EE733A0DEAA4C40C158DFC0E4A048408EE733A0DEAA4C40C158DFC0E4A04840F224E99AC9A94C40C00303081F9E4840F224E99AC9A94C40
4088	Редькино	7	67	575	49.489438	49.520797999999999	57.434551999999996	57.40457	0103000020E61000000100000005000000B7B585E7A5BE4840AB7823F3C8B34C40B7B585E7A5BE4840A83462669FB74C403EE94482A9C24840A83462669FB74C403EE94482A9C24840AB7823F3C8B34C40B7B585E7A5BE4840AB7823F3C8B34C40
4399	Окунево	7	67	575	49.353378999999997	49.382260000000002	57.345954999999996	57.328113000000002	0103000020E61000000100000005000000ED0BE8853BAD48403C32569BFFA94C40ED0BE8853BAD48409F71E14048AC4C40D4484BE5EDB048409F71E14048AC4C40D4484BE5EDB048403C32569BFFA94C40ED0BE8853BAD48403C32569BFFA94C40
4341	Михеевщина	7	67	575	49.502625000000002	49.517536999999997	57.379299000000003	57.366312999999998	0103000020E610000001000000050000007593180456C04840C18C2958E3AE4C407593180456C04840E833A0DE8CB04C4027BC04A73EC24840E833A0DE8CB04C4027BC04A73EC24840C18C2958E3AE4C407593180456C04840C18C2958E3AE4C40
4262	Мелянда	7	67	575	49.657369000000003	49.674320000000002	57.387096	57.377882	0103000020E61000000100000005000000BE33DAAA24D44840A0DFF76F5EB04C40BE33DAAA24D44840CA349A5C8CB14C40F584251E50D64840CA349A5C8CB14C40F584251E50D64840A0DFF76F5EB04C40BE33DAAA24D44840A0DFF76F5EB04C40
3589	Мари-Байса	7	67	575	49.6661	49.682369000000001	57.295208000000002	57.287314000000002	0103000020E61000000100000005000000CCEEC9C342D548406BD784B4C6A44C40CCEEC9C342D5484040C23060C9A54C40F1660DDE57D7484040C23060C9A54C40F1660DDE57D748406BD784B4C6A44C40CCEEC9C342D548406BD784B4C6A44C40
3967	Малое Рын-Дудорово	7	67	575	49.480750999999998	49.495932000000003	57.246470000000002	57.243057	0103000020E610000001000000050000007842AF3F89BD48402D08E57D1C9F4C407842AF3F89BD4840FAB836548C9F4C401B8524B37ABF4840FAB836548C9F4C401B8524B37ABF48402D08E57D1C9F4C407842AF3F89BD48402D08E57D1C9F4C40
56030	Лебяжье	7	67	575	49.478802000000002	49.564025000000001	57.437947999999999	57.39378	0103000020E6100000010000000500000034A1496249BD4840D1E80E6267B24C4034A1496249BD48409FAC18AE0EB84C402E90A0F831C848409FAC18AE0EB84C402E90A0F831C84840D1E80E6267B24C4034A1496249BD4840D1E80E6267B24C40
4226	Лаж	7	67	575	49.209513999999999	49.260312999999996	57.202485000000003	57.181485000000002	0103000020E61000000100000005000000EE06D15AD19A484077DB85E63A974C40EE06D15AD19A48401D774A07EB994C40A0DCB6EF51A148401D774A07EB994C40A0DCB6EF51A1484077DB85E63A974C40EE06D15AD19A484077DB85E63A974C40
4093	Кузнецово	7	67	575	49.251455999999997	49.268982000000001	57.057132000000003	57.045099	0103000020E610000001000000050000000531D0B52FA04840890AD5CDC5854C400531D0B52FA048400DC7F31950874C40399B8E006EA248400DC7F31950874C40399B8E006EA24840890AD5CDC5854C400531D0B52FA04840890AD5CDC5854C40
3977	Красное	7	67	575	49.470762000000001	49.493264000000003	57.471445000000003	57.459358000000002	0103000020E610000001000000050000008B19E1ED41BC4840F793313ECCBA4C408B19E1ED41BC48406E6E4C4F58BC4C40A725564623BF48406E6E4C4F58BC4C40A725564623BF4840F793313ECCBA4C408B19E1ED41BC4840F793313ECCBA4C40
3877	Кокорево	7	67	575	49.548986999999997	49.573179000000003	57.255794999999999	57.245564999999999	0103000020E61000000100000005000000EE76BD3445C64840680586AC6E9F4C40EE76BD3445C648407BBDFBE3BDA04C4083E0F1ED5DC948407BBDFBE3BDA04C4083E0F1ED5DC94840680586AC6E9F4C40EE76BD3445C64840680586AC6E9F4C40
3874	Индыгойка	7	67	575	49.403908999999999	49.426690000000001	57.130789	57.116424000000002	0103000020E61000000100000005000000B0C7444AB3B34840193C4CFBE68E4C40B0C7444AB3B3484099D6A6B1BD904C40DFC325C79DB6484099D6A6B1BD904C40DFC325C79DB64840193C4CFBE68E4C40B0C7444AB3B34840193C4CFBE68E4C40
3799	Изиморка	7	67	575	49.387641000000002	49.421362999999999	57.165450999999997	57.150342999999999	0103000020E610000001000000050000005CCB64389EB148405D177E703E934C405CCB64389EB14840950B957F2D954C404A5F0839EFB54840950B957F2D954C404A5F0839EFB548405D177E703E934C405CCB64389EB148405D177E703E934C40
56004	Зыково	7	67	575	49.298968000000002	49.322763999999999	57.083627999999997	57.07741	0103000020E6100000010000000500000078465B9544A6484012312592E8894C4078465B9544A64840D3838252B48A4C40BF29AC5450A94840D3838252B48A4C40BF29AC5450A9484012312592E8894C4078465B9544A6484012312592E8894C40
3759	Елькино	7	67	575	49.334423999999999	49.364984999999997	57.460451999999997	57.447034000000002	0103000020E61000000100000005000000AE7FD767CEAA48409C19FD6838B94C40AE7FD767CEAA48405BB05417F0BA4C40E94317D4B7AE48405BB05417F0BA4C40E94317D4B7AE48409C19FD6838B94C40AE7FD767CEAA48409C19FD6838B94C40
3710	Елизарово	7	67	575	49.520519	49.542428999999998	57.332787000000003	57.318120999999998	0103000020E610000001000000050000002BF9D85DA0C24840DD955D30B8A84C402BF9D85DA0C2484059C4B0C398AA4C4074B33F506EC5484059C4B0C398AA4C4074B33F506EC54840DD955D30B8A84C402BF9D85DA0C24840DD955D30B8A84C40
3679	Вотское	7	67	575	49.799976000000001	49.829953000000003	57.350889000000002	57.336463999999999	0103000020E61000000100000005000000DECA129D65E6484003249A4011AB4C40DECA129D65E6484059C345EEE9AC4C40CA1B60E63BEA484059C345EEE9AC4C40CA1B60E63BEA484003249A4011AB4C40DECA129D65E6484003249A4011AB4C40
3582	Ветошкино	7	67	575	49.705176999999999	49.737704999999998	57.298583000000001	57.283116	0103000020E6100000010000000500000019726C3D43DA4840B77C24253DA44C4019726C3D43DA48401F12BEF737A64C403F8C101E6DDE48401F12BEF737A64C403F8C101E6DDE4840B77C24253DA44C4019726C3D43DA4840B77C24253DA44C40
4198	Васичи	7	67	575	49.315900999999997	49.326852000000002	57.218862999999999	57.207189999999997	0103000020E6100000010000000500000008E3A7716FA848407407B133859A4C4008E3A7716FA84840F8A6E9B3039C4C40EC504D49D6A94840F8A6E9B3039C4C40EC504D49D6A948407407B133859A4C4008E3A7716FA848407407B133859A4C40
3006	Рябиново	7	67	414	49.750075000000002	49.776350999999998	58.048563999999999	58.033810000000003	0103000020E610000001000000050000000B46257502E048408E23D6E253044D400B46257502E04840A8E15B5837064D40C39B35785FE34840A8E15B5837064D40C39B35785FE348408E23D6E253044D400B46257502E048408E23D6E253044D40
3047	Речной	7	67	414	49.799239999999998	49.833959999999998	58.294578000000001	58.281587000000002	0103000020E61000000100000005000000D8D30E7F4DE6484048FDF50A0B244D40D8D30E7F4DE64840800F5EBBB4254D4009168733BFEA4840800F5EBBB4254D4009168733BFEA484048FDF50A0B244D40D8D30E7F4DE6484048FDF50A0B244D40
2560	Плотники	7	67	414	49.899788000000001	49.920521000000001	58.171300000000002	58.160328999999997	0103000020E61000000100000005000000A8AAD0402CF34840D9CC21A985144D40A8AAD0402CF3484004E78C28ED154D40FF23D3A1D3F5484004E78C28ED154D40FF23D3A1D3F54840D9CC21A985144D40A8AAD0402CF34840D9CC21A985144D40
2340	Парфеновщина	7	67	414	49.957495999999999	49.984104000000002	58.141280999999999	58.129525999999998	0103000020E6100000010000000500000081069B3A8FFA4840A8FDD64E94104D4081069B3A8FFA4840E945ED7E15124D4070EEAF1EF7FD4840E945ED7E15124D4070EEAF1EF7FD4840A8FDD64E94104D4081069B3A8FFA4840A8FDD64E94104D40
3097	Олимпийский	7	67	414	49.816011000000003	49.839188	58.273519	58.257272	0103000020E610000001000000050000009016670C73E848409816F549EE204D409016670C73E84840D5EAABAB02234D400B992B836AEB4840D5EAABAB02234D400B992B836AEB48409816F549EE204D409016670C73E848409816F549EE204D40
3396	Нижнеивкино	7	67	414	49.502265999999999	49.538890000000002	58.208578000000003	58.182361999999998	0103000020E6100000010000000500000045F295404AC048403E0455A357174D4045F295404AC04840225514AFB21A4D401B12F758FAC44840225514AFB21A4D401B12F758FAC448403E0455A357174D4045F295404AC048403E0455A357174D40
3357	Моряны	7	67	414	49.890985000000001	49.913128	58.060698000000002	58.043824999999998	0103000020E61000000100000005000000001DE6CB0BF24840A4DFBE0E9C054D40001DE6CB0BF248406077BAF3C4074D40EC87D860E1F448406077BAF3C4074D40EC87D860E1F44840A4DFBE0E9C054D40001DE6CB0BF24840A4DFBE0E9C054D40
3164	Кумены	7	67	414	49.890400999999997	49.959139999999998	58.120714999999997	58.089081999999998	0103000020E61000000100000005000000B0A9F3A8F8F14840C554FA09670B4D40B0A9F3A8F8F148407D91D096730F4D4089247A19C5FA48407D91D096730F4D4089247A19C5FA4840C554FA09670B4D40B0A9F3A8F8F14840C554FA09670B4D40
2776	Краснооктябрьский	7	67	414	50.162348000000001	50.183709999999998	58.164673999999998	58.149484000000001	0103000020E610000001000000050000001749BBD1C71449403CA3AD4A22134D401749BBD1C71449403140A20914154D405DF92CCF831749403140A20914154D405DF92CCF831749403CA3AD4A22134D401749BBD1C71449403CA3AD4A22134D40
2448	Желны	7	67	414	50.464073999999997	50.484051999999998	58.048611999999999	58.038556	0103000020E610000001000000050000004276DEC6663B494044882B67EF044D404276DEC6663B4940B91803EB38064D401DC87A6AF53D4940B91803EB38064D401DC87A6AF53D494044882B67EF044D404276DEC6663B494044882B67EF044D40
2663	Вожгалы	7	67	414	50.189808999999997	50.208584000000002	58.163629	58.152769999999997	0103000020E6100000010000000500000044BE4BA94B184940ABE7A4F78D134D4044BE4BA94B184940AED689CBF1144D40043C69E1B21A4940AED689CBF1144D40043C69E1B21A4940ABE7A4F78D134D4044BE4BA94B184940ABE7A4F78D134D40
2541	Вичевщина	7	67	414	50.069794000000002	50.101370000000003	58.202148000000001	58.187069000000001	0103000020E6100000010000000500000080BA8102EF084940378C82E0F1174D4080BA8102EF084940D57954FCDF194D40D46531B1F90C4940D57954FCDF194D40D46531B1F90C4940378C82E0F1174D4080BA8102EF084940378C82E0F1174D40
2436	Верхобыстрица	7	67	414	50.348784000000002	50.378419000000001	58.090204999999997	58.075648999999999	0103000020E610000001000000050000001DAF40F4A42C4940D07CCEDDAE094D401DAF40F4A42C4940C47762D68B0B4D40AF97A60870304940C47762D68B0B4D40AF97A60870304940D07CCEDDAE094D401DAF40F4A42C4940D07CCEDDAE094D40
2911	Быково	7	67	414	49.677024000000003	49.704143999999999	58.128898999999997	58.113079999999997	0103000020E61000000100000005000000B64DF1B8A8D6484074EACA67790E4D40B64DF1B8A8D6484059BE2EC37F104D405AD6FD6321DA484059BE2EC37F104D405AD6FD6321DA484074EACA67790E4D40B64DF1B8A8D6484074EACA67790E4D40
2326	Большой Перелаз	7	67	414	50.004379	50.03246	58.089210999999999	58.078437999999998	0103000020E6100000010000000500000004E5B67D8F004940BF61A2410A0A4D4004E5B67D8F004940C3B81B446B0B4D40CE3637A627044940C3B81B446B0B4D40CE3637A627044940BF61A2410A0A4D4004E5B67D8F004940BF61A2410A0A4D40
2214	Березник	7	67	414	50.593916	50.629013	58.059707000000003	58.046135	0103000020E610000001000000050000001B498270054C4940B9196EC0E7054D401B498270054C4940D02B9E7AA4074D4022E17B7F83504940D02B9E7AA4074D4022E17B7F83504940B9196EC0E7054D401B498270054C4940B9196EC0E7054D40
2791	Бельтюги	7	67	414	50.238138999999997	50.254190999999999	58.084648000000001	58.069732999999999	0103000020E610000001000000050000007973B8567B1E4940DA39CD02ED084D407973B8567B1E4940FED5E3BED50A4D4001F8A75489204940FED5E3BED50A4D4001F8A75489204940DA39CD02ED084D407973B8567B1E4940DA39CD02ED084D40
3486	Барановщина	7	67	414	49.549543999999997	49.578792999999997	58.210143000000002	58.196713000000003	0103000020E6100000010000000500000044DB317557C648405AD93EE42D194D4044DB317557C64840DE3D40F7E51A4D40AD1397E315CA4840DE3D40F7E51A4D40AD1397E315CA48405AD93EE42D194D4044DB317557C648405AD93EE42D194D40
2678	Ардашиха	7	67	414	50.212977000000002	50.234357000000003	58.151910000000001	58.141333000000003	0103000020E610000001000000050000006DE690D4421B49403C6C223317124D406DE690D4421B4940BAF770C971134D405A4B0169FF1D4940BAF770C971134D405A4B0169FF1D49403C6C223317124D406DE690D4421B49403C6C223317124D40
1509	Юрьево	7	67	110	48.520380000000003	48.566814000000001	58.453972999999998	58.439506000000002	0103000020E610000001000000050000000ABFD4CF9B424840A9328CBB41384D400ABFD4CF9B4248402D228AC91B3A4D401D75745C8D4848402D228AC91B3A4D401D75745C8D484840A9328CBB41384D400ABFD4CF9B424840A9328CBB41384D40
1408	Юбилейный	7	67	110	48.213003999999998	48.241838999999999	58.509255000000003	58.494917999999998	0103000020E6100000010000000500000066F50EB7431B4840D2191879593F4D4066F50EB7431B4840892991442F414D40DCF29194F41E4840892991442F414D40DCF29194F41E4840D2191879593F4D4066F50EB7431B4840D2191879593F4D40
1392	Шалеевщина	7	67	110	48.072723000000003	48.094650000000001	58.452311000000002	58.441620999999998	0103000020E610000001000000050000006155BDFC4E094840081D740987384D406155BDFC4E0948407F4FAC53E5394D408048BF7D1D0C48407F4FAC53E5394D408048BF7D1D0C4840081D740987384D406155BDFC4E094840081D740987384D40
1309	Чистополье	7	67	110	47.875731000000002	47.909337000000001	57.875878999999998	57.857351999999999	0103000020E61000000100000005000000F48B12F417F047408194D8B5BDED4C40F48B12F417F04740682096CD1CF04C407905A22765F44740682096CD1CF04C407905A22765F447408194D8B5BDED4C40F48B12F417F047408194D8B5BDED4C40
1260	Сретенье	7	67	110	48.045062999999999	48.056068000000003	58.634023999999997	58.623314000000001	0103000020E610000001000000050000003CA1D79FC4054840C991CEC0C84F4D403CA1D79FC40548408670CCB227514D40132D793C2D0748408670CCB227514D40132D793C2D074840C991CEC0C84F4D403CA1D79FC4054840C991CEC0C84F4D40
1162	Спасское	7	67	110	48.311728000000002	48.324826000000002	58.693936000000001	58.679895000000002	0103000020E61000000100000005000000AE9FFEB3E627484062DBA2CC06574D40AE9FFEB3E62748402FC214E5D2584D40FC71FBE5932948402FC214E5D2584D40FC71FBE59329484062DBA2CC06574D40AE9FFEB3E627484062DBA2CC06574D40
1062	Светлый	7	67	110	47.579439999999998	47.603164	58.089463000000002	58.072951000000003	0103000020E6100000010000000500000043FF04172BCA4740F29A577556094D4043FF04172BCA4740DD990986730B4D40F10F5B7A34CD4740DD990986730B4D40F10F5B7A34CD4740F29A577556094D4043FF04172BCA4740F29A577556094D40
52760	Роминская	7	67	110	48.178598000000001	48.203778	58.299156000000004	58.291767999999998	0103000020E61000000100000005000000C5909C4CDC164840790261A758254D40C5909C4CDC1648407B336ABE4A264D4078D2C265151A48407B336ABE4A264D4078D2C265151A4840790261A758254D40C5909C4CDC164840790261A758254D40
1033	Родичи	7	67	110	48.178984	48.190230999999997	58.253858000000001	58.247743999999997	0103000020E61000000100000005000000EE409DF2E8164840DEE34C13B61F4D40EE409DF2E8164840FBE93F6B7E204D40BAD7497D59184840FBE93F6B7E204D40BAD7497D59184840DEE34C13B61F4D40EE409DF2E8164840DEE34C13B61F4D40
945	Покровское	7	67	110	48.186252000000003	48.204568000000002	58.207971000000001	58.195945000000002	0103000020E610000001000000050000004568041BD71748404968CBB914194D404568041BD71748401AC231CB9E1A4D4071E7C2482F1A48401AC231CB9E1A4D4071E7C2482F1A48404968CBB914194D404568041BD71748404968CBB914194D40
819	Молотниково	7	67	110	48.270063999999998	48.288893000000002	58.429828999999998	58.419603000000002	0103000020E61000000100000005000000D9E9077591224840D926158DB5354D40D9E9077591224840AAEFFCA204374D408C852172FA244840AAEFFCA204374D408C852172FA244840D926158DB5354D40D9E9077591224840D926158DB5354D40
808	Макарье	7	67	110	48.151873000000002	48.196061	58.585287000000001	58.566654999999997	0103000020E610000001000000050000009D12109370134840B48EAA2688484D409D1210937013484011E335AFEA4A4D40B282DF861819484011E335AFEA4A4D40B282DF8618194840B48EAA2688484D409D12109370134840B48EAA2688484D40
185	Ленинская Искра	7	67	110	48.408853999999998	48.442379000000003	58.338279	58.323748999999999	0103000020E610000001000000050000005D6BEF53553448406D8E739B70294D405D6BEF535534484038F6ECB94C2B4D40F6B704E09F38484038F6ECB94C2B4D40F6B704E09F3848406D8E739B70294D405D6BEF53553448406D8E739B70294D40
1636	Курино	7	67	110	48.378957999999997	48.398254000000001	58.591422000000001	58.577368	0103000020E610000001000000050000005E471CB281304840E3E0D231E7494D405E471CB281304840451152B7B34B4D4027C0B0FCF9324840451152B7B34B4D4027C0B0FCF9324840E3E0D231E7494D405E471CB281304840E3E0D231E7494D40
703	Красногорье	7	67	110	48.384096999999997	48.408701000000001	58.478402000000003	58.471102999999999	0103000020E61000000100000005000000F0BE2A172A3148401406651A4D3C4D40F0BE2A172A314840A62BD8463C3D4D40D76B7A5050344840A62BD8463C3D4D40D76B7A50503448401406651A4D3C4D40F0BE2A172A3148401406651A4D3C4D40
558	Комсомольский	7	67	110	47.998908	48.019686	58.187956	58.172007000000001	0103000020E610000001000000050000003CDBA337DCFF47406FD74B5304164D403CDBA337DCFF4740228B34F10E184D403318231285024840228B34F10E184D4033182312850248406FD74B5304164D403CDBA337DCFF47406FD74B5304164D40
1627	Козловаж	7	67	110	47.929118000000003	47.943688999999999	58.099342999999998	58.092032000000003	0103000020E61000000100000005000000FE0FB056EDF64740BE175FB4C70B4D40FE0FB056EDF64740130B7C45B70C4D40274C18CDCAF84740130B7C45B70C4D40274C18CDCAF84740BE175FB4C70B4D40FE0FB056EDF64740BE175FB4C70B4D40
442	Карпушино	7	67	110	48.09404	48.116577999999997	58.333185999999998	58.320965000000001	0103000020E610000001000000050000000742B280090C48409014916115294D400742B280090C484016BEBED6A52A4D406FB72407EC0E484016BEBED6A52A4D406FB72407EC0E48409014916115294D400742B280090C48409014916115294D40
581	Караул	7	67	110	48.265976999999999	48.322158000000002	58.292741999999997	58.270313999999999	0103000020E610000001000000050000007D3ECA880B22484052D32EA699224D407D3ECA880B2248403315E29178254D4088122D793C2948403315E29178254D4088122D793C29484052D32EA699224D407D3ECA880B22484052D32EA699224D40
435	Зайцевы	7	67	110	48.252358999999998	48.269247	58.351730000000003	58.335920999999999	0103000020E61000000100000005000000F6ECB94C4D20484012859675FF2A4D40F6ECB94C4D204840D482177D052D4D40E7C589AF76224840D482177D052D4D40E7C589AF7622484012859675FF2A4D40F6ECB94C4D20484012859675FF2A4D40
1525	Екатерина	7	67	110	48.056849	48.072524999999999	58.387242000000001	58.375244000000002	0103000020E61000000100000005000000B8E7F9D3460748409702D2FE07304D40B8E7F9D3460748409ED1562591314D403A92CB7F480948409ED1562591314D403A92CB7F480948409702D2FE07304D40B8E7F9D3460748409702D2FE07304D40
321	Ежиха	7	67	110	47.685144000000001	47.727939999999997	58.095632999999999	58.065643999999999	0103000020E610000001000000050000007B8670CCB2D74740DD96C80567084D407B8670CCB2D747408DB5BFB33D0C4D40A1B94E232DDD47408DB5BFB33D0C4D40A1B94E232DDD4740DD96C80567084D407B8670CCB2D74740DD96C80567084D40
301	Вишкиль	7	67	110	48.307299999999998	48.327250999999997	58.089016000000001	58.074826000000002	0103000020E61000000100000005000000C8073D9B55274840FC71FBE593094D40C8073D9B552748400E6954E0640B4D40A94A5B5CE32948400E6954E0640B4D40A94A5B5CE3294840FC71FBE593094D40C8073D9B55274840FC71FBE593094D40
926	Боровка	7	67	110	48.325913	48.349618999999997	57.956277999999998	57.938085000000001	0103000020E61000000100000005000000AE2B6684B729484020EF552B13F84C40AE2B6684B729484030F1475167FA4C40B587BD50C02C484030F1475167FA4C40B587BD50C02C484020EF552B13F84C40AE2B6684B729484020EF552B13F84C40
161	Александровское	7	67	110	47.939205999999999	47.983322000000001	58.272666999999998	58.255828000000001	0103000020E610000001000000050000007E1AF7E637F8474057B3CEF8BE204D407E1AF7E637F8474066D993C0E6224D40FAB7CB7EDDFD474066D993C0E6224D40FAB7CB7EDDFD474057B3CEF8BE204D407E1AF7E637F8474057B3CEF8BE204D40
55972	Чистые Пруды	7	67	7389	49.618974999999999	49.649813999999999	58.556168	58.538153999999999	0103000020E610000001000000050000005305A3923ACF4840151BF33AE2444D405305A3923ACF4840768A558330474D40D13DEB1A2DD34840768A558330474D40D13DEB1A2DD34840151BF33AE2444D405305A3923ACF4840151BF33AE2444D40
31044	Шутовщина	7	67	1887	49.703012000000001	49.729107999999997	58.470528999999999	58.460315000000001	0103000020E610000001000000050000000859164CFCD94840DB6D179AEB3A4D400859164CFCD94840E868554B3A3C4D4040A0336953DD4840E868554B3A3C4D4040A0336953DD4840DB6D179AEB3A4D400859164CFCD94840DB6D179AEB3A4D40
30948	Филиппово	7	67	1887	50.479191999999998	50.504282000000003	58.306106999999997	58.296593000000001	0103000020E610000001000000050000009E40D829563D49407C9C69C2F6254D409E40D829563D4940D009A1832E274D4012FB04508C404940D009A1832E274D4012FB04508C4049407C9C69C2F6254D409E40D829563D49407C9C69C2F6254D40
30888	Фатеево	7	67	1887	49.945225000000001	49.983924000000002	58.420169000000001	58.401122999999998	0103000020E61000000100000005000000492EFF21FDF8484032569BFF57334D40492EFF21FDF8484082E50819C8354D40F0DFBC38F1FD484082E50819C8354D40F0DFBC38F1FD484032569BFF57334D40492EFF21FDF8484032569BFF57334D40
56013	Сибирь	7	67	1887	49.357278000000001	49.372342000000003	58.475593000000003	58.467399	0103000020E6100000010000000500000047CA1649BBAD48407097FDBAD33B4D4047CA1649BBAD4840709A3E3BE03C4D40B07614E7A8AF4840709A3E3BE03C4D40B07614E7A8AF48407097FDBAD33B4D4047CA1649BBAD48407097FDBAD33B4D40
30784	Селезениха	7	67	1887	50.662781000000003	50.724271000000002	58.328086999999996	58.278809000000003	0103000020E6100000010000000500000081B4FF01D65449404D6A6803B0234D4081B4FF01D6544940129F3BC1FE294D407A3881E9B45C4940129F3BC1FE294D407A3881E9B45C49404D6A6803B0234D4081B4FF01D65449404D6A6803B0234D40
30740	Просница	7	67	1887	50.200966000000001	50.250984000000003	58.450916999999997	58.433517999999999	0103000020E61000000100000005000000D1CDFE40B9194940191D90847D374D40D1CDFE40B9194940EF1AF4A5B7394D40DEE8633E20204940EF1AF4A5B7394D40DEE8633E20204940191D90847D374D40D1CDFE40B9194940191D90847D374D40
30678	Пригородный	7	67	1887	49.976495	49.991245999999997	58.522053	58.512568999999999	0103000020E6100000010000000500000090DAC4C9FDFC4840C2F869DC9B414D4090DAC4C9FDFC4840ACE3F8A1D2424D4039252026E1FE4840ACE3F8A1D2424D4039252026E1FE4840C2F869DC9B414D4090DAC4C9FDFC4840C2F869DC9B414D40
30569	Полом	7	67	1887	50.329093	50.352350000000001	58.378542000000003	58.361660000000001	0103000020E61000000100000005000000D82B2CB81F2A4940BC22F8DF4A2E4D40D82B2CB81F2A4940CB14731074304D40705F07CE192D4940CB14731074304D40705F07CE192D4940BC22F8DF4A2E4D40D82B2CB81F2A4940BC22F8DF4A2E4D40
30529	Пасегово	7	67	1887	49.495367000000002	49.52899	58.516672	58.494945999999999	0103000020E610000001000000050000004242942F68BF48409CA4F9635A3F4D404242942F68BF48402461DF4E22424D409DF4BEF1B5C348402461DF4E22424D409DF4BEF1B5C348409CA4F9635A3F4D404242942F68BF48409CA4F9635A3F4D40
30472	Марковцы	7	67	1887	50.443097999999999	50.479191999999998	58.247019999999999	58.234997	0103000020E6100000010000000500000025766D6FB73849403DD4B661141E4D4025766D6FB73849409DBAF2599E1F4D409E40D829563D49409DBAF2599E1F4D409E40D829563D49403DD4B661141E4D4025766D6FB73849403DD4B661141E4D40
30375	Малый Конып	7	67	1887	50.348604000000002	50.382173999999999	58.447870999999999	58.430480000000003	0103000020E610000001000000050000009DA04D0E9F2C494082CAF8F719374D409DA04D0E9F2C4940D5E940D653394D40D5B0DF13EB304940D5E940D653394D40D5B0DF13EB30494082CAF8F719374D409DA04D0E9F2C494082CAF8F719374D40
30434	Кстинино	7	67	1887	49.762354999999999	49.788891	58.452556000000001	58.436939000000002	0103000020E61000000100000005000000967840D994E1484069ACFD9DED374D40967840D994E14840E6CDE15AED394D40EB8D5A61FAE44840E6CDE15AED394D40EB8D5A61FAE4484069ACFD9DED374D40967840D994E1484069ACFD9DED374D40
30344	Ключи	7	67	1887	50.250687999999997	50.257497000000001	58.343763000000003	58.341414999999998	0103000020E61000000100000005000000F4BF5C8B1620494092AE997CB32B4D40F4BF5C8B1620494095490D6D002C4D40B8E864A9F520494095490D6D002C4D40B8E864A9F520494092AE997CB32B4D40F4BF5C8B1620494092AE997CB32B4D40
32285	Каринторф	7	67	1887	50.170476999999998	50.217235000000002	58.567537000000002	58.545453000000002	0103000020E610000001000000050000002FDCB930D2154940A7406667D1454D402FDCB930D21549408E226B0DA5484D40F645425BCE1B49408E226B0DA5484D40F645425BCE1B4940A7406667D1454D402FDCB930D2154940A7406667D1454D40
30278	Каринка	7	67	1887	50.568350000000002	50.596423000000001	58.212361000000001	58.198700000000002	0103000020E610000001000000050000003F575BB1BF4849408CDB68006F194D403F575BB1BF48494012F92EA52E1B4D4086CABF96574C494012F92EA52E1B4D4086CABF96574C49408CDB68006F194D403F575BB1BF4849408CDB68006F194D40
30243	Дресвяново	7	67	1887	49.770969999999998	49.802652999999999	58.400933999999999	58.381548000000002	0103000020E610000001000000050000003B191C25AFE2484057ED9A90D6304D403B191C25AFE248405FED28CE51334D40A5846055BDE648405FED28CE51334D40A5846055BDE6484057ED9A90D6304D403B191C25AFE2484057ED9A90D6304D40
30193	Быстрицкий Туберкулезный Санаторий	7	67	1887	49.508419000000004	49.527742000000003	58.391680999999998	58.371783999999998	0103000020E6100000010000000500000020D5B0DF13C1484089963C9E962F4D4020D5B0DF13C1484077BB5E9A22324D40E25CC30C8DC3484077BB5E9A22324D40E25CC30C8DC3484089963C9E962F4D4020D5B0DF13C1484089963C9E962F4D40
30106	Бурмакино	7	67	1887	49.77026	49.816657999999997	58.354771	58.314627000000002	0103000020E610000001000000050000005FB532E197E2484024B891B245284D405FB532E197E24840DC48D922692D4D402502D53F88E84840DC48D922692D4D402502D53F88E8484024B891B245284D405FB532E197E2484024B891B245284D40
56016	Бумкомбинат	7	67	1887	50.06109	50.079504999999997	58.469296	58.460334000000003	0103000020E610000001000000050000006B0E10CCD1074940529E7939EC3A4D406B0E10CCD107494062122EE4113C4D402A6F47382D0A494062122EE4113C4D402A6F47382D0A4940529E7939EC3A4D406B0E10CCD1074940529E7939EC3A4D40
60509	Кирово-Чепецк	7	67	7391	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
55968	Садаковский	7	67	1752	49.519413999999998	49.575468999999998	58.605944000000001	58.588486000000003	0103000020E61000000100000005000000D28A6F287CC24840B2135E82534B4D40D28A6F287CC248408D9AAF928F4D4D40506EDBF7A8C948408D9AAF928F4D4D40506EDBF7A8C94840B2135E82534B4D40D28A6F287CC24840B2135E82534B4D40
28131	Русское	7	67	1752	49.274084999999999	49.323483000000003	58.579023999999997	58.551125999999996	0103000020E610000001000000050000007EA99F3715A34840D6FCF84B8B464D407EA99F3715A34840AFCC5B751D4A4D40EFE714E467A94840AFCC5B751D4A4D40EFE714E467A94840D6FCF84B8B464D407EA99F3715A34840D6FCF84B8B464D40
55990	Малая Субботиха	7	67	1752	49.752868999999997	49.773646999999997	58.585953000000003	58.576025999999999	0103000020E610000001000000050000000B96EA025EE04840A6D24F38BB494D400B96EA025EE048401EFF0582004B4D4002D369DD06E348401EFF0582004B4D4002D369DD06E34840A6D24F38BB494D400B96EA025EE04840A6D24F38BB494D40
55987	Лянгасово	7	67	1752	49.422235000000001	49.492842000000003	58.534443000000003	58.508366000000002	0103000020E61000000100000005000000001DE6CB0BB64840FD32182312414D40001DE6CB0BB64840BF49D3A068444D40310C587215BF4840BF49D3A068444D40310C587215BF4840FD32182312414D40001DE6CB0BB64840FD32182312414D40
27972	Костино	7	67	1752	49.469341999999997	49.502212	58.617189000000003	58.607875999999997	0103000020E61000000100000005000000D2510E6613BC4840FB027AE1CE4D4D40D2510E6613BC4840B939950C004F4D4052D4997B48C04840B939950C004F4D4052D4997B48C04840FB027AE1CE4D4D40D2510E6613BC4840FB027AE1CE4D4D40
24454	Захарищевы	7	67	1752	49.393462	49.422657000000001	58.515656999999997	58.499747999999997	0103000020E61000000100000005000000001C7BF65CB24840E61E12BEF73F4D40001C7BF65CB248400B7A6F0C01424D407636E49F19B648400B7A6F0C01424D407636E49F19B64840E61E12BEF73F4D40001C7BF65CB24840E61E12BEF73F4D40
28030	Большая Гора	7	67	1752	49.589699000000003	49.600136999999997	58.669984999999997	58.662427000000001	0103000020E61000000100000005000000F1BDBF417BCB4840637E6E68CA544D40F1BDBF417BCB4840C0E78711C2554D404D0F0A4AD1CC4840C0E78711C2554D404D0F0A4AD1CC4840637E6E68CA544D40F1BDBF417BCB4840637E6E68CA544D40
28078	Бахта	7	67	1752	49.386051000000002	49.433751000000001	58.622925000000002	58.605573999999997	0103000020E6100000010000000500000047CB811E6AB1484069A7E672834D4D4047CB811E6AB148402F6EA301BC4F4D40BCCD1B2785B748402F6EA301BC4F4D40BCCD1B2785B7484069A7E672834D4D4047CB811E6AB1484069A7E672834D4D40
20567	Четай	7	67	655	50.961004000000003	50.981484999999999	57.126055000000001	57.118335000000002	0103000020E61000000100000005000000A0A9D72D027B4940707CED99258F4C40A0A9D72D027B4940A73FFB9122904C40DD41EC4CA17D4940A73FFB9122904C40DD41EC4CA17D4940707CED99258F4C40A0A9D72D027B4940707CED99258F4C40
19823	Чернушка	7	67	655	50.784638000000001	50.804023000000001	56.989561000000002	56.978247000000003	0103000020E6100000010000000500000074999A046F6449407F349C32377D4C4074999A046F644940D33252EFA97E4C40AC1DC539EA664940D33252EFA97E4C40AC1DC539EA6649407F349C32377D4C4074999A046F6449407F349C32377D4C40
20014	Тат-Кильмезь	7	67	655	50.970086000000002	50.994447999999998	56.960774999999998	56.948194999999998	0103000020E610000001000000050000005B272EC72B7C4940889D29745E794C405B272EC72B7C49403EE8D9ACFA7A4C404BC972124A7F49403EE8D9ACFA7A4C404BC972124A7F4940889D29745E794C405B272EC72B7C4940889D29745E794C40
20839	Тат-Бояры	7	67	655	50.915855000000001	50.933200999999997	57.312978999999999	57.303387000000001	0103000020E61000000100000005000000657094BC3A7549400A849D62D5A64C40657094BC3A754940DAAA24B20FA84C4018CC5F2173774940DAAA24B20FA84C4018CC5F21737749400A849D62D5A64C40657094BC3A7549400A849D62D5A64C40
20049	Селино	7	67	655	50.722518999999998	50.747096999999997	56.936135999999998	56.928887000000003	0103000020E610000001000000050000008BDEA9807B5C4940FC56EBC4E5764C408BDEA9807B5C4940DB4DF04DD3774C4048F8DEDFA05F4940DB4DF04DD3774C4048F8DEDFA05F4940FC56EBC4E5764C408BDEA9807B5C4940FC56EBC4E5764C40
19924	Саринка	7	67	655	50.824244	50.843262000000003	57.089213000000001	57.080350000000003	0103000020E610000001000000050000004DF6CFD380694940E71DA7E8488A4C404DF6CFD38069494064B0E2546B8B4C40D3FA5B02F06B494064B0E2546B8B4C40D3FA5B02F06B4940E71DA7E8488A4C404DF6CFD380694940E71DA7E8488A4C40
20716	Рыбная Ватага	7	67	655	50.973526	50.993558999999998	57.222572	57.203923000000003	0103000020E6100000010000000500000021E7FD7F9C7C49407CF31B261A9A4C4021E7FD7F9C7C4940AE80423D7D9C4C40BFD2F9F02C7F4940AE80423D7D9C4C40BFD2F9F02C7F49407CF31B261A9A4C4021E7FD7F9C7C49407CF31B261A9A4C40
20503	Паска	7	67	655	51.121460999999996	51.139589000000001	57.092205999999997	57.078285999999999	0103000020E61000000100000005000000A65EB7088C8F494009DE9046058A4C40A65EB7088C8F49405B3FFD67CD8B4C40D0F0660DDE9149405B3FFD67CD8B4C40D0F0660DDE91494009DE9046058A4C40A65EB7088C8F494009DE9046058A4C40
20428	Осиновка	7	67	655	50.837279000000002	50.855747999999998	57.421716000000004	57.410280999999998	0103000020E61000000100000005000000555051F52B6B4940C8957A1684B44C40555051F52B6B4940981936CAFAB54C4007CF8426896D4940981936CAFAB54C4007CF8426896D4940C8957A1684B44C40555051F52B6B4940C8957A1684B44C40
20271	Надежда	7	67	655	51.483105000000002	51.501170000000002	56.861677	56.851978000000003	0103000020E610000001000000050000005DC47762D6BD4940AC74779D0D6D4C405DC47762D6BD4940925B936E4B6E4C4040DEAB5626C04940925B936E4B6E4C4040DEAB5626C04940AC74779D0D6D4C405DC47762D6BD4940AC74779D0D6D4C40
20403	Моторки	7	67	655	51.460126000000002	51.491405	56.890132000000001	56.872241000000002	0103000020E610000001000000050000000805A568E5BA49407C9DD497A56F4C400805A568E5BA4940C18F6AD8EF714C40A20BEA5BE6BE4940C18F6AD8EF714C40A20BEA5BE6BE49407C9DD497A56F4C400805A568E5BA49407C9DD497A56F4C40
19811	Малыши	7	67	655	51.198051	51.227829999999997	56.849319999999999	56.835298000000002	0103000020E6100000010000000500000055F833BC5999494005357C0BEB6A4C4055F833BC599949405BEB8B84B66C4C401A868F88299D49405BEB8B84B66C4C401A868F88299D494005357C0BEB6A4C4055F833BC5999494005357C0BEB6A4C40
20156	Малая Кильмезь	7	67	655	51.020598	51.051509000000003	56.935668999999997	56.919204000000001	0103000020E61000000100000005000000772E8CF4A28249401B2D077AA8754C40772E8CF4A2824940C5707500C4774C408F39CFD897864940C5707500C4774C408F39CFD8978649401B2D077AA8754C40772E8CF4A28249401B2D077AA8754C40
20878	Кульма	7	67	655	50.795265000000001	50.809629000000001	57.247118	57.239803000000002	0103000020E61000000100000005000000A453573ECB654940C93D5DDDB19E4C40A453573ECB65494060200890A19F4C4054724EECA167494060200890A19F4C4054724EECA1674940C93D5DDDB19E4C40A453573ECB654940C93D5DDDB19E4C40
19528	Кильмезь	7	67	655	51.042706000000003	51.311500000000002	57.007494999999999	56.932977999999999	0103000020E61000000100000005000000E7ABE4637785494099F1B6D26B774C40E7ABE4637785494017F19D98F5804C401D5A643BDFA7494017F19D98F5804C401D5A643BDFA7494099F1B6D26B774C40E7ABE4637785494099F1B6D26B774C40
19716	Карманкино	7	67	655	51.290649999999999	51.308418000000003	56.981670000000001	56.968705	0103000020E610000001000000050000008C4AEA0434A54940603C8386FE7B4C408C4AEA0434A549406FBBD05CA77D4C40B6BFB33D7AA749406FBBD05CA77D4C40B6BFB33D7AA74940603C8386FE7B4C408C4AEA0434A54940603C8386FE7B4C40
56019	Каменный Перебор	7	67	655	50.948517000000002	50.972439000000001	57.249499	57.236150000000002	0103000020E610000001000000050000009B594B0169794940A779C7293A9E4C409B594B01697949403EB14E95EF9F4C406F2D93E1787C49403EB14E95EF9F4C406F2D93E1787C4940A779C7293A9E4C409B594B0169794940A779C7293A9E4C40
19939	Зимник	7	67	655	51.194170999999997	51.215515000000003	56.930301	56.922446999999998	0103000020E61000000100000005000000726A6798DA9849408BA548BE12764C40726A6798DA984940D237691A14774C401366DAFE959B4940D237691A14774C401366DAFE959B49408BA548BE12764C40726A6798DA9849408BA548BE12764C40
56007	Еремино	7	67	655	51.416880999999997	51.437891999999998	56.844056999999999	56.836686999999998	0103000020E6100000010000000500000071A94A5B5CB5494082FE428F186B4C4071A94A5B5CB54940DD7A4D0F0A6C4C400B9755D80CB84940DD7A4D0F0A6C4C400B9755D80CB8494082FE428F186B4C4071A94A5B5CB5494082FE428F186B4C40
4444	Дамаскино	7	67	655	51.234442000000001	51.276294999999998	56.804125999999997	56.788707000000002	0103000020E6100000010000000500000088670932029E49402A90D959F4644C4088670932029E494080EECB99ED664C402F8672A25DA3494080EECB99ED664C402F8672A25DA349402A90D959F4644C4088670932029E49402A90D959F4644C40
4391	Вихарево	7	67	655	51.327409000000003	51.355463	56.924382000000001	56.909514999999999	0103000020E6100000010000000500000042B5C189E8A94940581CCEFC6A744C4042B5C189E8A949406B813D2652764C4012F8C3CF7FAD49406B813D2652764C4012F8C3CF7FAD4940581CCEFC6A744C4042B5C189E8A94940581CCEFC6A744C40
19601	Бураши	7	67	655	51.036605999999999	51.066285999999998	56.782952999999999	56.766938000000003	0103000020E610000001000000050000002F6B6281AF844940A3073E062B624C402F6B6281AF8449400DA7CCCD37644C406117450F7C8849400DA7CCCD37644C406117450F7C884940A3073E062B624C402F6B6281AF844940A3073E062B624C40
20678	Большой Порек	7	67	655	50.800708	50.857069000000003	56.779747	56.765794	0103000020E61000000100000005000000A2D288997D6649408CBCAC8905624C40A2D288997D664940BA13ECBFCE634C402DB5DE6FB46D4940BA13ECBFCE634C402DB5DE6FB46D49408CBCAC8905624C40A2D288997D6649408CBCAC8905624C40
20302	Азиково	7	67	655	51.410449	51.425863999999997	56.792498000000002	56.779752000000002	0103000020E6100000010000000500000084D6C39789B44940CC7EDDE9CE634C4084D6C39789B449409D12109370654C40994528B682B649409D12109370654C40994528B682B64940CC7EDDE9CE634C4084D6C39789B44940CC7EDDE9CE634C40
19026	Шапта	7	67	1556	47.046415000000003	47.074703	57.228482	57.206254000000001	0103000020E610000001000000050000009D853DEDF0854740A855F487669A4C409D853DEDF0854740C2DCEEE53E9D4C40E0F42EDE8F894740C2DCEEE53E9D4C40E0F42EDE8F894740A855F487669A4C409D853DEDF0854740A855F487669A4C40
18853	Цекеево	7	67	1556	47.163124000000003	47.186138999999997	57.214647999999997	57.178030999999997	0103000020E61000000100000005000000AB984A3FE19447404B5645B8C9964C40AB984A3FE19447406E13EE95799B4C404CC11A67D39747406E13EE95799B4C404CC11A67D39747404B5645B8C9964C40AB984A3FE19447404B5645B8C9964C40
18905	Улеш	7	67	1556	47.125870999999997	47.142679000000001	57.135722000000001	57.125107	0103000020E61000000100000005000000E5417A8A1C90474016C0948103904C40E5417A8A1C90474082ACA7565F914C40BA69334E4392474082ACA7565F914C40BA69334E4392474016C0948103904C40E5417A8A1C90474016C0948103904C40
19291	Тырышкино	7	67	1556	46.943171999999997	46.964784999999999	57.445270999999998	57.430801000000002	0103000020E610000001000000050000005F402FDCB9784740C40AB77C24B74C405F402FDCB9784740B96DDFA3FEB84C40EF552B137E7B4740B96DDFA3FEB84C40EF552B137E7B4740C40AB77C24B74C405F402FDCB9784740C40AB77C24B74C40
19497	Турусиново	7	67	1556	47.268039000000002	47.287666999999999	57.375194	57.363590000000002	0103000020E61000000100000005000000BA86191A4FA247408A93FB1D8AAE4C40BA86191A4FA24740E5D3635B06B04C40B891B245D2A44740E5D3635B06B04C40B891B245D2A447408A93FB1D8AAE4C40BA86191A4FA247408A93FB1D8AAE4C40
19225	Русские Краи	7	67	1556	46.788274999999999	46.838303000000003	57.391854000000002	57.372461999999999	0103000020E6100000010000000500000090A0F831E66447405A80B6D5ACAF4C4090A0F831E66447404567994528B24C40C19140834D6B47404567994528B24C40C19140834D6B47405A80B6D5ACAF4C4090A0F831E66447405A80B6D5ACAF4C40
18798	Потняк	7	67	1556	47.323061000000003	47.349597000000003	57.267223999999999	57.251252000000001	0103000020E6100000010000000500000079CE16105AA94740FD86890629A04C4079CE16105AA94740685A626534A24C40CEE33098BFAC4740685A626534A24C40CEE33098BFAC4740FD86890629A04C4079CE16105AA94740FD86890629A04C40
19109	Падерино	7	67	1556	46.867103	46.894635999999998	57.226100000000002	57.211517999999998	0103000020E61000000100000005000000BAA1293BFD6E4740F6419605139B4C40BAA1293BFD6E474014D044D8F09C4C4081E9B46E8372474014D044D8F09C4C4081E9B46E83724740F6419605139B4C40BAA1293BFD6E4740F6419605139B4C40
19389	Макарье	7	67	1556	47.095489999999998	47.135088000000003	57.444195999999998	57.433016000000002	0103000020E610000001000000050000002A8C2D04398C474087527B116DB74C402A8C2D04398C4740CB811E6ADBB84C40810A47904A914740CB811E6ADBB84C40810A47904A91474087527B116DB74C402A8C2D04398C474087527B116DB74C40
19421	Кокшага	7	67	1556	47.357053000000001	47.379834000000002	57.477159999999998	57.462494999999997	0103000020E6100000010000000500000027F8A6E9B3AD474021C8410933BB4C4027F8A6E9B3AD4740CC7A319413BD4C4056F487669EB04740CC7A319413BD4C4056F487669EB0474021C8410933BB4C4027F8A6E9B3AD474021C8410933BB4C40
18607	Кикнур	7	67	1556	47.177605	47.254699000000002	57.319108	57.291580000000003	0103000020E61000000100000005000000944DB9C2BB9647407715527E52A54C40944DB9C2BB9647402CF2EB87D8A84C4076A911FA99A047402CF2EB87D8A84C4076A911FA99A047407715527E52A54C40944DB9C2BB9647407715527E52A54C40
19317	Ваштранга	7	67	1556	47.112566999999999	47.133597000000002	57.340922999999997	57.323690999999997	0103000020E61000000100000005000000EECD6F98688E47403881E9B46EA94C40EECD6F98688E474023BA675DA3AB4C40FFEBDCB41991474023BA675DA3AB4C40FFEBDCB4199147403881E9B46EA94C40EECD6F98688E47403881E9B46EA94C40
19087	Березовка	7	67	1556	46.977424999999997	46.993899999999996	57.216076000000001	57.206498000000003	0103000020E610000001000000050000007AA52C431C7D47403F58C6866E9A4C407AA52C431C7D4740AAB9DC60A89B4C4048BF7D1D387F4740AAB9DC60A89B4C4048BF7D1D387F47403F58C6866E9A4C407AA52C431C7D47403F58C6866E9A4C40
18742	Беляево	7	67	1556	47.405642999999998	47.458148999999999	57.374879	57.35389	0103000020E61000000100000005000000F86C1D1CECB34740D3307C444CAD4C40F86C1D1CECB34740857AFA08FCAF4C40F9D85DA0A4BA4740857AFA08FCAF4C40F9D85DA0A4BA4740D3307C444CAD4C40F86C1D1CECB34740D3307C444CAD4C40
18953	Абрамово	7	67	1556	47.004105000000003	47.078332000000003	57.160493000000002	57.146169	0103000020E6100000010000000500000003603C8386804740325871AAB5924C4003603C8386804740541EDD088B944C407A1D71C8068A4740541EDD088B944C407A1D71C8068A4740325871AAB5924C4003603C8386804740325871AAB5924C40
18557	Чепецкий	7	67	1328	51.166286999999997	51.214652000000001	58.513306999999998	58.462862000000001	0103000020E61000000100000005000000FE5F75E448954940D447E00F3F3B4D40FE5F75E44895494068E7340BB4414D40B0027CB7799B494068E7340BB4414D40B0027CB7799B4940D447E00F3F3B4D40FE5F75E448954940D447E00F3F3B4D40
18474	Суна	7	67	1328	51.263421999999998	51.292293999999998	58.186352999999997	58.169919	0103000020E610000001000000050000000186E5CFB7A1494009FCE1E7BF154D400186E5CFB7A149407841446ADA174D409468C9E369A549407841446ADA174D409468C9E369A5494009FCE1E7BF154D400186E5CFB7A1494009FCE1E7BF154D40
18385	Старки	7	67	1328	51.103090000000002	51.121837999999997	58.304476000000001	58.290140999999998	0103000020E61000000100000005000000B745990D328D4940471D1D5723254D40B745990D328D49405D35CF11F9264D407CB43863988F49405D35CF11F9264D407CB43863988F4940471D1D5723254D40B745990D328D4940471D1D5723254D40
18293	Соколовка	7	67	1328	51.212766000000002	51.247844999999998	58.279093000000003	58.260126999999997	0103000020E61000000100000005000000B2D991EA3B9B49403EE76ED74B214D40B2D991EA3B9B494072C5C551B9234D4012BD8C62B99F494072C5C551B9234D4012BD8C62B99F49403EE76ED74B214D40B2D991EA3B9B49403EE76ED74B214D40
18224	Семушино	7	67	1328	50.781844	50.812691999999998	58.453921999999999	58.440593999999997	0103000020E610000001000000050000007349D576136449402B685A6265384D407349D57613644940AB77B81D1A3A4D4044DC9C4A06684940AB77B81D1A3A4D4044DC9C4A066849402B685A6265384D407349D576136449402B685A6265384D40
18156	Сезенево	7	67	1328	51.019115999999997	51.047350000000002	58.474553	58.457599000000002	0103000020E61000000100000005000000486AA1647282494056D7A19A923A4D40486AA16472824940FE9B1727BE3C4D4099BB96900F864940FE9B1727BE3C4D4099BB96900F86494056D7A19A923A4D40486AA1647282494056D7A19A923A4D40
17931	Рябово	7	67	1328	50.794815999999997	50.831431000000002	58.202651000000003	58.189512000000001	0103000020E61000000100000005000000342BDB87BC6549408B19E1ED41184D40342BDB87BC65494038C0CC77F0194D40B7F0BC546C6A494038C0CC77F0194D40B7F0BC546C6A49408B19E1ED41184D40342BDB87BC6549408B19E1ED41184D40
17987	Октябрьский	7	67	1328	51.120885999999999	51.177911000000002	58.134529999999998	58.113874000000003	0103000020E61000000100000005000000AA454431798F4940AFEE586C930E4D40AA454431798F49405A2A6F4738114D40A14CA3C9C59649405A2A6F4738114D40A14CA3C9C5964940AFEE586C930E4D40AA454431798F4940AFEE586C930E4D40
18451	Мусихи	7	67	1328	51.171137999999999	51.188268999999998	58.205267999999997	58.197015999999998	0103000020E610000001000000050000002A8D98D9E7954940F564FED137194D402A8D98D9E79549402975C938461A4D40E1ECD632199849402975C938461A4D40E1ECD63219984940F564FED137194D402A8D98D9E7954940F564FED137194D40
17773	Лема	7	67	1328	50.838734000000002	50.889263999999997	58.072104000000003	58.058331000000003	0103000020E610000001000000050000008A05BEA25B6B4940E7ABE46377074D408A05BEA25B6B494095F430B43A094D404CC11A67D371494095F430B43A094D404CC11A67D3714940E7ABE46377074D408A05BEA25B6B4940E7ABE46377074D40
14165	Левинцы	7	67	1328	50.962620999999999	50.967768	58.446764000000002	58.444060999999998	0103000020E61000000100000005000000AEB8382A377B4940EB36A8FDD6384D40AEB8382A377B4940DC8310902F394D40C30E63D2DF7B4940DC8310902F394D40C30E63D2DF7B4940EB36A8FDD6384D40AEB8382A377B4940EB36A8FDD6384D40
17549	Косино	7	67	1328	51.256360999999998	51.300153999999999	58.420994	58.391779999999997	0103000020E61000000100000005000000247CEF6FD0A049400A9DD7D825324D40247CEF6FD0A04940F7E7A221E3354D40BDE13E726BA64940F7E7A221E3354D40BDE13E726BA649400A9DD7D825324D40247CEF6FD0A049400A9DD7D825324D40
18324	Коса	7	67	1328	51.237181999999997	51.265478999999999	58.339331999999999	58.322029000000001	0103000020E610000001000000050000009599D2FA5B9E49408AAE0B3F38294D409599D2FA5B9E49403E3E213B6F2B4D402C634337FBA149403E3E213B6F2B4D402C634337FBA149408AAE0B3F38294D409599D2FA5B9E49408AAE0B3F38294D40
17765	Кордяга	7	67	1328	50.996972	51.054366000000002	58.435667000000002	58.420782000000003	0103000020E610000001000000050000008C834BC79C7F49406C5F402FDC354D408C834BC79C7F49402579AEEFC3374D40D6011077F58649402579AEEFC3374D40D6011077F58649406C5F402FDC354D408C834BC79C7F49406C5F402FDC354D40
56020	Зуи	7	67	1328	51.113492999999998	51.139014000000003	58.389623999999998	58.372771	0103000020E6100000010000000500000097A949F0868E4940D8F2CAF5B62F4D4097A949F0868E49404CDE0033DF314D40D4D7F335CB9149404CDE0033DF314D40D4D7F335CB914940D8F2CAF5B62F4D4097A949F0868E4940D8F2CAF5B62F4D40
17066	Зуевка	7	67	1328	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
18060	Городище	7	67	1328	51.064121	51.079528000000003	58.114882000000001	58.103023999999998	0103000020E6100000010000000500000050FEEE1D35884940FF59F3E32F0D4D4050FEEE1D3588494015731074B40E4D40E38E37F92D8A494015731074B40E4D40E38E37F92D8A4940FF59F3E32F0D4D4050FEEE1D35884940FF59F3E32F0D4D40
18079	Большие Пасынки	7	67	1328	50.990388000000003	51.017391000000003	58.328691999999997	58.319840999999997	0103000020E61000000100000005000000E92CB308C57E4940C075C58CF0284D40E92CB308C57E4940793A5794122A4D40541F48DE39824940793A5794122A4D40541F48DE39824940C075C58CF0284D40E92CB308C57E4940C075C58CF0284D40
52226	Ардаши	7	67	1328	50.617137999999997	50.645550999999998	58.467277000000003	58.454345000000004	0103000020E61000000100000005000000368FC360FE4E4940F20C1AFA273A4D40368FC360FE4E4940259694BBCF3B4D403673486AA1524940259694BBCF3B4D403673486AA1524940F20C1AFA273A4D40368FC360FE4E4940F20C1AFA273A4D40
16683	Хохловщина	7	67	1053	47.792520000000003	47.809013	58.788131999999997	58.775714999999998	0103000020E6100000010000000500000085B69C4B71E5474021020EA14A634D4085B69C4B71E547402D776682E1644D40F984ECBC8DE747402D776682E1644D40F984ECBC8DE7474021020EA14A634D4085B69C4B71E5474021020EA14A634D40
56024	Субарь	7	67	1053	47.907989999999998	47.930070000000001	59.222651999999997	59.215504000000003	0103000020E610000001000000050000002A8C2D0439F447401F1494A2959B4D402A8C2D0439F44740CA3159DC7F9C4D40D07EA4880CF74740CA3159DC7F9C4D40D07EA4880CF747401F1494A2959B4D402A8C2D0439F447401F1494A2959B4D40
16663	Пиксур	7	67	1053	47.987229999999997	48.023871999999997	58.918711000000002	58.905946	0103000020E61000000100000005000000A6D0798D5DFE474094F8DC09F6734D40A6D0798D5DFE4740DCBC715298754D4022A5D93C0E034840DCBC715298754D4022A5D93C0E03484094F8DC09F6734D40A6D0798D5DFE474094F8DC09F6734D40
16589	Окатьево	7	67	1053	48.423892000000002	48.449404000000001	58.794609000000001	58.782100999999997	0103000020E610000001000000050000009D84D217423648409E95B4E21B644D409D84D21742364840BB0D6ABFB5654D408658FD1186394840BB0D6ABFB5654D408658FD11863948409E95B4E21B644D409D84D217423648409E95B4E21B644D40
16523	Кривецкая	7	67	1053	47.906804000000001	47.926988999999999	59.267018	59.251327000000003	0103000020E61000000100000005000000E5F0492712F4474008CDAE7B2BA04D40E5F0492712F44740BFB854A52DA24D4039605793A7F64740BFB854A52DA24D4039605793A7F6474008CDAE7B2BA04D40E5F0492712F4474008CDAE7B2BA04D40
16502	Красное	7	67	1053	47.864403000000003	47.898674	59.214900999999998	59.196375000000003	0103000020E610000001000000050000003BC8EBC1A4EE47404260E5D022994D403BC8EBC1A4EE474058703FE0819B4D40FCE1E7BF07F3474058703FE0819B4D40FCE1E7BF07F347404260E5D022994D403BC8EBC1A4EE47404260E5D022994D40
9235	Кобра	7	67	1053	48.292710999999997	48.324314000000001	58.889921999999999	58.876584000000001	0103000020E61000000100000005000000F816D68D7725484033198EE733704D40F816D68D77254840D6FECEF6E8714D4046D1031F83294840D6FECEF6E8714D4046D1031F8329484033198EE733704D40F816D68D7725484033198EE733704D40
16321	Ивановка	7	67	1053	48.237465	48.266452999999998	59.067318	59.054622999999999	0103000020E61000000100000005000000EA78CC40651E4840014EEFE2FD864D40EA78CC40651E4840503750E09D884D40E675C4211B224840503750E09D884D40E675C4211B224840014EEFE2FD864D40EA78CC40651E4840014EEFE2FD864D40
16143	Даровской	7	67	1053	47.925488999999999	47.997875000000001	58.779335000000003	58.753323999999999	0103000020E6100000010000000500000064E76D6C76F647405DA5BBEB6C604D4064E76D6C76F6474068D0D03FC1634D407D3F355EBAFF474068D0D03FC1634D407D3F355EBAFF47405DA5BBEB6C604D4064E76D6C76F647405DA5BBEB6C604D40
16023	Вонданка	7	67	1053	47.823062999999998	47.842250999999997	59.095325000000003	59.083573999999999	0103000020E6100000010000000500000019C6DD205AE94740E065868DB28A4D4019C6DD205AE94740E0BE0E9C338C4D40FB027AE1CEEB4740E0BE0E9C338C4D40FB027AE1CEEB4740E065868DB28A4D4019C6DD205AE94740E065868DB28A4D40
15984	Верховонданка	7	67	1053	47.646247000000002	47.677419	58.863760999999997	58.855486999999997	0103000020E61000000100000005000000AE11C138B8D247409A931799806D4D40AE11C138B8D24740B6476FB88F6E4D40325871AAB5D64740B6476FB88F6E4D40325871AAB5D647409A931799806D4D40AE11C138B8D247409A931799806D4D40
16104	Бобровы	7	67	1053	47.881920000000001	48.075184	58.846107000000003	58.817270999999998	0103000020E610000001000000050000001BD82AC1E2F047400F7C0C569C684D401BD82AC1E2F0474056F5F23B4D6C4D405B971AA19F09484056F5F23B4D6C4D405B971AA19F0948400F7C0C569C684D401BD82AC1E2F047400F7C0C569C684D40
15897	Бечева	7	67	1053	48.387528000000003	48.400723999999997	58.918585	58.901879000000001	0103000020E6100000010000000500000064247B849A3148407FF964C570734D4064247B849A3148404FCC7A3194754D40745C8DEC4A3348404FCC7A3194754D40745C8DEC4A3348407FF964C570734D4064247B849A3148407FF964C570734D40
14934	Ямышка	7	67	1290	51.363826000000003	51.392321000000003	56.167518999999999	56.160662000000002	0103000020E610000001000000050000009EB7B1D991AE4940E0DA899290144C409EB7B1D991AE4940B43A394371154C405B44149337B24940B43A394371154C405B44149337B24940E0DA899290144C409EB7B1D991AE4940E0DA899290144C40
15003	Чекашево	7	67	1290	51.142175999999999	51.170186000000001	56.177436	56.161343000000002	0103000020E610000001000000050000005723BBD23292494022382EE3A6144C405723BBD23292494008910C39B6164C40581EA4A7C895494008910C39B6164C40581EA4A7C895494022382EE3A6144C405723BBD23292494022382EE3A6144C40
14889	Усть-Люга	7	67	1290	51.328774000000003	51.349910999999999	56.200477999999997	56.187922	0103000020E6100000010000000500000037E3344415AA49407619FED30D184C4037E3344415AA4940A3C85A43A9194C405DC136E2C9AC4940A3C85A43A9194C405DC136E2C9AC49407619FED30D184C4037E3344415AA49407619FED30D184C40
48794	Старая Пинигерь	7	67	1290	50.916097000000001	50.959251999999999	56.208474000000002	56.198484999999998	0103000020E610000001000000050000005B7B9FAA427549408FDFDBF467194C405B7B9FAA427549407D08AA46AF1A4C40B14F00C5C87A49407D08AA46AF1A4C40B14F00C5C87A49408FDFDBF467194C405B7B9FAA427549408FDFDBF467194C40
14597	Средняя Тойма	7	67	1290	50.940792000000002	50.967390999999999	56.254502000000002	56.243609999999997	0103000020E61000000100000005000000522B4CDF6B784940417DCB9C2E1F4C40522B4CDF6B7849402062838593204C40EDB8E177D37B49402062838593204C40EDB8E177D37B4940417DCB9C2E1F4C40522B4CDF6B784940417DCB9C2E1F4C40
14721	Средние Шуни	7	67	1290	51.224874999999997	51.251016	56.129544000000003	56.117184999999999	0103000020E61000000100000005000000105839B4C89C4940774A07EBFF0E4C40105839B4C89C49404FB2D5E594104C40E962D34A21A049404FB2D5E594104C40E962D34A21A04940774A07EBFF0E4C40105839B4C89C4940774A07EBFF0E4C40
13515	Сосновка	7	67	1290	51.234541	51.313124999999999	56.264946999999999	56.238332	0103000020E610000001000000050000001B498270059E49408ECBB8A9811E4C401B498270059E49402F1686C8E9214C40AE47E17A14A849402F1686C8E9214C40AE47E17A14A849408ECBB8A9811E4C401B498270059E49408ECBB8A9811E4C40
14858	Сосмак	7	67	1290	51.189715	51.215155000000003	56.142735999999999	56.130367	0103000020E61000000100000005000000C347C4944898494023BDA8DDAF104C40C347C494489849401EFB592C45124C401349F4328A9B49401EFB592C45124C401349F4328A9B494023BDA8DDAF104C40C347C4944898494023BDA8DDAF104C40
14468	Слудка	7	67	1290	51.005640999999997	51.052424999999999	56.327070999999997	56.315246000000002	0103000020E61000000100000005000000244223D8B8804940F0181EFB59284C40244223D8B8804940293C6876DD294C40143FC6DCB5864940293C6876DD294C40143FC6DCB5864940F0181EFB59284C40244223D8B8804940F0181EFB59284C40
14538	Новый Бурец	7	67	1290	50.880316999999998	50.901940000000003	56.370562999999997	56.359538999999998	0103000020E61000000100000005000000718E3A3AAE7049407A51BB5F052E4C40718E3A3AAE704940C70DBF9B6E2F4C40257A19C572734940C70DBF9B6E2F4C40257A19C5727349407A51BB5F052E4C40718E3A3AAE7049407A51BB5F052E4C40
14628	Нижняя Тойма	7	67	1290	50.974226999999999	51.044556	56.251302000000003	56.233924999999999	0103000020E61000000100000005000000AAF06778B37C4940C05B2041F11D4C40AAF06778B37C4940AFB5F7A92A204C40986BD102B4854940AFB5F7A92A204C40986BD102B4854940C05B2041F11D4C40AAF06778B37C4940C05B2041F11D4C40
14804	Нижние Шуни	7	67	1290	51.265999999999998	51.312685000000002	56.123905000000001	56.114534999999997	0103000020E61000000100000005000000355EBA490CA24940A99F3715A90E4C40355EBA490CA24940CB67791EDC0F4C409279E40F06A84940CB67791EDC0F4C409279E40F06A84940A99F3715A90E4C40355EBA490CA24940A99F3715A90E4C40
14523	Нижние Изиверки	7	67	1290	51.039292000000003	51.052487999999997	56.295515000000002	56.283988999999998	0103000020E610000001000000050000004A7F2F85078549403DB665C059244C404A7F2F85078549401D3D7E6FD3254C405AB741EDB78649401D3D7E6FD3254C405AB741EDB78649403DB665C059244C404A7F2F85078549403DB665C059244C40
55985	Мухино	7	67	1290	51.055084000000001	51.064875999999998	56.265191999999999	56.254427	0103000020E61000000100000005000000354415FE0C874940151C5E1091204C40354415FE0C8749409694BBCFF1214C40CC2555DB4D8849409694BBCFF1214C40CC2555DB4D884940151C5E1091204C40354415FE0C874940151C5E1091204C40
14180	Куршино	7	67	1290	51.234667000000002	51.256397	56.190466000000001	56.179845999999998	0103000020E61000000100000005000000A8397991099E49408028983105174C40A8397991099E4940FE7F9C3061184C4071E5EC9DD1A04940FE7F9C3061184C4071E5EC9DD1A049408028983105174C40A8397991099E49408028983105174C40
14274	Кулыги	7	67	1290	51.225459000000001	51.255526000000003	56.220989000000003	56.202131000000001	0103000020E6100000010000000500000060CB2BD7DB9C4940FF40B96DDF194C4060CB2BD7DB9C49404CE3175E491C4C408CA37213B5A049404CE3175E491C4C408CA37213B5A04940FF40B96DDF194C4060CB2BD7DB9C4940FF40B96DDF194C40
13822	Красная Поляна	7	67	1290	51.123015000000002	51.211364000000003	56.262791999999997	56.236530999999999	0103000020E610000001000000050000006FF59CF4BE8F4940BEBED6A5461E4C406FF59CF4BE8F494041D3122BA3214C40A0C6BDF90D9B494041D3122BA3214C40A0C6BDF90D9B4940BEBED6A5461E4C406FF59CF4BE8F4940BEBED6A5461E4C40
14307	Казанка	7	67	1290	51.178781999999998	51.195922000000003	56.416839000000003	56.407646	0103000020E61000000100000005000000868E1D54E2964940302C7FBE2D344C40868E1D54E29649404359F8FA5A354C409148DBF8139949404359F8FA5A354C409148DBF813994940302C7FBE2D344C40868E1D54E2964940302C7FBE2D344C40
15013	Ершовка	7	67	1290	51.017220000000002	51.036903000000002	56.179034000000001	56.157859000000002	0103000020E61000000100000005000000276BD443348249408C3045B934144C40276BD44334824940A06F0B96EA164C40E90FCD3CB9844940A06F0B96EA164C40E90FCD3CB98449408C3045B934144C40276BD443348249408C3045B934144C40
14370	Дым-Дым-Омга	7	67	1290	51.171047999999999	51.195301999999998	56.379646000000001	56.368738999999998	0103000020E61000000100000005000000EA059FE6E49549403FE1ECD6322F4C40EA059FE6E49549405307793D98304C40F46BEBA7FF9849405307793D98304C40F46BEBA7FF9849403FE1ECD6322F4C40EA059FE6E49549403FE1ECD6322F4C40
14125	Гремячка	7	67	1290	51.321390000000001	51.335053000000002	56.290764000000003	56.281120999999999	0103000020E6100000010000000500000077A1B94E23A94940029CDEC5FB234C4077A1B94E23A94940556D37C137254C409EB64604E3AA4940556D37C137254C409EB64604E3AA4940029CDEC5FB234C4077A1B94E23A94940029CDEC5FB234C40
14399	Виноградово	7	67	1290	51.150511999999999	51.177371999999998	56.427742000000002	56.416206000000003	0103000020E61000000100000005000000E9D32AFA439349401233FB3C46354C40E9D32AFA439349401590F63FC0364C40F19C2D20B49649401590F63FC0364C40F19C2D20B49649401233FB3C46354C40E9D32AFA439349401233FB3C46354C40
1986	Угор	7	67	185	49.447702	49.481254	58.083067999999997	58.068348	0103000020E61000000100000005000000492D944C4EB948409E5F94A0BF084D40492D944C4EB948400CACE3F8A10A4D40DB8827BB99BD48400CACE3F8A10A4D40DB8827BB99BD48409E5F94A0BF084D40492D944C4EB948409E5F94A0BF084D40
1403	Сырда	7	67	185	49.437793999999997	49.458508999999999	58.131835000000002	58.114839000000003	0103000020E61000000100000005000000483140A209B8484016A75A0BB30E4D40483140A209B84840EDBB22F8DF104D40F9F5436CB0BA4840EDBB22F8DF104D40F9F5436CB0BA484016A75A0BB30E4D40483140A209B8484016A75A0BB30E4D40
2208	Среднеивкино	7	67	185	49.420743000000002	49.457610000000003	58.008184999999997	57.992694999999998	0103000020E61000000100000005000000AE8218E8DAB548408CF337A110FF4C40AE8218E8DAB54840ACA8C1340C014D404A29E8F692BA4840ACA8C1340C014D404A29E8F692BA48408CF337A110FF4C40AE8218E8DAB548408CF337A110FF4C40
1383	Пунгино	7	67	185	49.107410999999999	49.113743999999997	58.140825	58.137588999999998	0103000020E61000000100000005000000861DC6A4BF8D484009A52F849C114D40861DC6A4BF8D4840C7BAB88D06124D40E00ED4298F8E4840C7BAB88D06124D40E00ED4298F8E484009A52F849C114D40861DC6A4BF8D484009A52F849C114D40
1335	Мякиши	7	67	185	49.029249	49.072592	57.882573999999998	57.863706000000001	0103000020E610000001000000050000006938656EBE834840F3AD0FEB8DEE4C406938656EBE8348406326512FF8F04C40C2F9D4B14A8948406326512FF8F04C40C2F9D4B14A894840F3AD0FEB8DEE4C406938656EBE834840F3AD0FEB8DEE4C40
1237	Косино	7	67	185	48.933722000000003	48.963231999999998	58.035758999999999	58.023049999999998	0103000020E6100000010000000500000022C7D633847748401E166A4DF3024D4022C7D63384774840D2C43BC093044D40F73AA92F4B7B4840D2C43BC093044D40F73AA92F4B7B48401E166A4DF3024D4022C7D633847748401E166A4DF3024D40
1226	Калачиги	7	67	185	49.596023000000002	49.633589999999998	58.043514999999999	58.027177000000002	0103000020E61000000100000005000000F8544E7B4ACC4840091A33897A034D40F8544E7B4ACC484056F146E691054D404C89247A19D1484056F146E691054D404C89247A19D14840091A33897A034D40F8544E7B4ACC4840091A33897A034D40
1158	Зониха	7	67	185	49.254016	49.280031000000001	57.877386000000001	57.862217000000001	0103000020E610000001000000050000009354A69883A0484012876C205DEE4C409354A69883A04840F0FB372F4EF04C40DF6E490ED8A34840F0FB372F4EF04C40DF6E490ED8A3484012876C205DEE4C409354A69883A0484012876C205DEE4C40
2319	Воронье	7	67	185	49.470914	49.501772000000003	57.943803000000003	57.930138999999997	0103000020E61000000100000005000000419DF2E846BC4840F8DD74CB0EF74C40419DF2E846BC4840F06E6589CEF84C4036069D103AC04840F06E6589CEF84C4036069D103AC04840F8DD74CB0EF74C40419DF2E846BC4840F8DD74CB0EF74C40
664	Верхошижемье	7	67	185	49.066268000000001	49.138655	58.028778000000003	57.978127999999998	0103000020E61000000100000005000000BB6246787B884840A4A65D4C33FD4C40BB6246787B884840126C5CFFAE034D40A4367172BF914840126C5CFFAE034D40A4367172BF914840A4A65D4C33FD4C40BB6246787B884840A4A65D4C33FD4C40
2665	Верхолипово	7	67	185	48.888410999999998	48.914434999999997	57.902264000000002	57.882075999999998	0103000020E610000001000000050000000D349F73B7714840124BCADDE7F04C400D349F73B7714840D82D02637DF34C40ACA8C1340C754840D82D02637DF34C40ACA8C1340C754840124BCADDE7F04C400D349F73B7714840124BCADDE7F04C40
12732	Чус	7	67	172	52.820929999999997	52.84169	59.723624999999998	59.712367	0103000020E610000001000000050000001327F73B14694A40F4DF83D72EDB4D401327F73B14694A40B4C876BE9FDC4D4064AF777FBC6B4A40B4C876BE9FDC4D4064AF777FBC6B4A40F4DF83D72EDB4D401327F73B14694A40F4DF83D72EDB4D40
12881	Тупрунка	7	67	172	53.443786000000003	53.464294000000002	60.061788999999997	60.053030999999997	0103000020E610000001000000050000001A36CAFACDB84A404B5645B8C9064E401A36CAFACDB84A405320B3B3E8074E4051DD5CFC6DBB4A405320B3B3E8074E4051DD5CFC6DBB4A404B5645B8C9064E401A36CAFACDB84A404B5645B8C9064E40
12305	Созимский	7	67	172	52.226784000000002	52.269229000000003	59.758544999999998	59.720802999999997	0103000020E61000000100000005000000C7A01342071D4A40E9EDCF4543DC4D40C7A01342071D4A40ACC5A70018E14D4041118B1876224A40ACC5A70018E14D4041118B1876224A40E9EDCF4543DC4D40C7A01342071D4A40E9EDCF4543DC4D40
12075	Светлополянск	7	67	172	52.338884999999998	52.388454000000003	59.428230999999997	59.410587	0103000020E610000001000000050000006F0D6C95602B4A40D594641D8EB44D406F0D6C95602B4A401211FE45D0B64D400D0055DCB8314A401211FE45D0B64D400D0055DCB8314A40D594641D8EB44D406F0D6C95602B4A40D594641D8EB44D40
12151	Рудничный	7	67	172	52.434978000000001	52.504049000000002	59.624516999999997	59.592157	0103000020E61000000100000005000000603DEE5BAD374A407A8CF2CCCBCB4D40603DEE5BAD374A40E4654D2CF0CF4D406F4A79AD84404A40E4654D2CF0CF4D406F4A79AD84404A407A8CF2CCCBCB4D40603DEE5BAD374A407A8CF2CCCBCB4D40
12662	Пушья	7	67	172	52.896289000000003	52.918092000000001	59.901187999999998	59.886293000000002	0103000020E61000000100000005000000DD611399B9724A403DD68C0C72F14D40DD611399B9724A4019C6DD205AF34D40105CE50984754A4019C6DD205AF34D40105CE50984754A403DD68C0C72F14D40DD611399B9724A403DD68C0C72F14D40
12016	Пещера	7	67	172	52.315879000000002	52.338273999999998	59.196292999999997	59.182040000000001	0103000020E61000000100000005000000213F1BB96E284A402C4833164D974D40213F1BB96E284A4084B7072120994D40268BFB8F4C2B4A4084B7072120994D40268BFB8F4C2B4A402C4833164D974D40213F1BB96E284A402C4833164D974D40
12782	Ожмегово	7	67	172	52.771343000000002	52.800960000000003	59.542834999999997	59.531717	0103000020E61000000100000005000000D07F0F5EBB624A4016DD7A4D0FC44D40D07F0F5EBB624A40E40F069E7BC54D40BCB376DB85664A40E40F069E7BC54D40BCB376DB85664A4016DD7A4D0FC44D40D07F0F5EBB624A4016DD7A4D0FC44D40
12569	Лойно	7	67	172	52.612107000000002	52.677936000000003	59.739472999999997	59.717399999999998	0103000020E610000001000000050000008B53AD85594E4A40401361C3D3DB4D408B53AD85594E4A4033A31F0DA7DE4D40FA635A9BC6564A4033A31F0DA7DE4D40FA635A9BC6564A40401361C3D3DB4D408B53AD85594E4A40401361C3D3DB4D40
12424	Лесной	7	67	172	52.111324000000003	52.146942000000003	59.806182999999997	59.772958000000003	0103000020E6100000010000000500000045A165DD3F0E4A403E97A949F0E24D4045A165DD3F0E4A40ABCB290131E74D405534D6FECE124A40ABCB290131E74D405534D6FECE124A403E97A949F0E24D4045A165DD3F0E4A403E97A949F0E24D40
56003	Куликово	7	67	172	52.757373999999999	52.771334000000003	59.794409999999999	59.789538	0103000020E610000001000000050000009C6B98A1F1604A408179C8940FE54D409C6B98A1F1604A40C4CE143AAFE54D407D259012BB624A40C4CE143AAFE54D407D259012BB624A408179C8940FE54D409C6B98A1F1604A408179C8940FE54D40
11958	Кочкино	7	67	172	52.246276999999999	52.257559999999998	59.235888000000003	59.222417	0103000020E61000000100000005000000E5603601861F4A4087890629789C4D40E5603601861F4A406AC2F693319E4D40FE60E0B9F7204A406AC2F693319E4D40FE60E0B9F7204A4087890629789C4D40E5603601861F4A4087890629789C4D40
544	Кирс	7	67	172	52.188893	52.282938000000001	59.369613000000001	59.324064	0103000020E61000000100000005000000BFB854A52D184A40CDE7DCED7AA94D40BFB854A52D184A409696917A4FAF4D40D865F84F37244A409696917A4FAF4D40D865F84F37244A40CDE7DCED7AA94D40BFB854A52D184A40CDE7DCED7AA94D40
12719	Кай	7	67	172	52.957554000000002	52.989229000000002	59.965449	59.952606000000003	0103000020E61000000100000005000000B6132521917A4A4098FC4FFEEEF94D40B6132521917A4A405B7A34D593FB4D409DA04D0E9F7E4A405B7A34D593FB4D409DA04D0E9F7E4A4098FC4FFEEEF94D40B6132521917A4A4098FC4FFEEEF94D40
11910	Барановка	7	67	172	51.919192000000002	51.936359000000003	59.382334	59.372084999999998	0103000020E61000000100000005000000575F5D15A8F54940842A357BA0AF4D40575F5D15A8F549400E130D52F0B04D405B28999CDAF749400E130D52F0B04D405B28999CDAF74940842A357BA0AF4D40575F5D15A8F54940842A357BA0AF4D40
11559	Хороши	7	67	198	50.585912	50.641266999999999	57.781246000000003	57.761149000000003	0103000020E61000000100000005000000BF2A172AFF4A49400A3197546DE14C40BF2A172AFF4A4940BF1072DEFFE34C4084807C0915524940BF1072DEFFE34C4084807C09155249400A3197546DE14C40BF2A172AFF4A49400A3197546DE14C40
11495	Ухтым	7	67	198	50.974083	51.028961000000002	57.940617000000003	57.906801999999999	0103000020E61000000100000005000000774B72C0AE7C494044F9821612F44C40774B72C0AE7C4940E4874A2366F84C4003EE79FEB4834940E4874A2366F84C4003EE79FEB483494044F9821612F44C40774B72C0AE7C494044F9821612F44C40
11441	Таранки	7	67	198	50.548479999999998	50.594312000000002	57.979210999999999	57.964824999999998	0103000020E610000001000000050000004A41B797344649407DAEB6627FFB4C404A41B7973446494015713AC956FD4C4068CF656A124C494015713AC956FD4C4068CF656A124C49407DAEB6627FFB4C404A41B797344649407DAEB6627FFB4C40
11424	Спасское	7	67	198	50.892614999999999	50.949154999999998	57.805791999999997	57.787934999999997	0103000020E61000000100000005000000A375543541724940D72FD80DDBE44C40A37554354172494070B0373124E74C40DDEA39E97D79494070B0373124E74C40DDEA39E97D794940D72FD80DDBE44C40A375543541724940D72FD80DDBE44C40
750	Рождественское	7	67	198	50.454982999999999	50.495550999999999	57.897567000000002	57.879224000000001	0103000020E61000000100000005000000349E08E23C3A4940DDED7A698AF04C40349E08E23C3A4940037CB779E3F24C40034015376E3F4940037CB779E3F24C40034015376E3F4940DDED7A698AF04C40349E08E23C3A4940DDED7A698AF04C40
11288	Ошлань	7	67	198	50.480584999999998	50.530873	57.970067	57.936317000000003	0103000020E610000001000000050000005DF92CCF833D49402CD8463CD9F74C405DF92CCF833D4940E4F6CB272BFC4C402AAA7EA5F3434940E4F6CB272BFC4C402AAA7EA5F34349402CD8463CD9F74C405DF92CCF833D49402CD8463CD9F74C40
11271	Караул	7	67	198	51.094188000000003	51.117373999999998	57.981158000000001	57.966439000000001	0103000020E610000001000000050000007CD6355A0E8C49401B4AED45B4FB4C407CD6355A0E8C4940B91AD99596FD4C404AB3791C068F4940B91AD99596FD4C404AB3791C068F49401B4AED45B4FB4C407CD6355A0E8C49401B4AED45B4FB4C40
1647	Верховойское	7	67	198	50.735768999999998	50.763168	57.940913000000002	57.932552000000001	0103000020E610000001000000050000008F34B8AD2D5E4940E2E82ADD5DF74C408F34B8AD2D5E4940CDB051D66FF84C4047AD307DAF614940CDB051D66FF84C4047AD307DAF614940E2E82ADD5DF74C408F34B8AD2D5E4940E2E82ADD5DF74C40
55997	Богородское	7	67	198	50.712466999999997	50.787835999999999	57.846960000000003	57.813651	0103000020E61000000100000005000000573D601E325B4940C9AD49B725E84C40573D601E325B494095826E2F69EC4C40444E5FCFD764494095826E2F69EC4C40444E5FCFD7644940C9AD49B725E84C40573D601E325B4940C9AD49B725E84C40
10763	Юдино	7	67	486	51.002209999999998	51.015225999999998	59.011698000000003	59.002809999999997	0103000020E61000000100000005000000B1DCD26A48804940060DFD135C804D40B1DCD26A48804940DDB6EF517F814D404206F2ECF2814940DDB6EF517F814D404206F2ECF2814940060DFD135C804D40B1DCD26A48804940060DFD135C804D40
10902	Троица	7	67	486	51.347199000000003	51.365057	59.224341000000003	59.209252999999997	0103000020E610000001000000050000001A1A4F0471AC494081CB63CDC89A4D401A1A4F0471AC49407313B534B79C4D4083161230BAAE49407313B534B79C4D4083161230BAAE494081CB63CDC89A4D401A1A4F0471AC494081CB63CDC89A4D40
10539	Сырьяны	7	67	486	50.690027000000001	50.718620000000001	59.045653000000001	59.029671	0103000020E61000000100000005000000B22D03CE52584940DF516342CC834D40B22D03CE525849406EFB1EF5D7854D4032207BBDFB5B49406EFB1EF5D7854D4032207BBDFB5B4940DF516342CC834D40B22D03CE52584940DF516342CC834D40
10638	Ракалово	7	67	486	50.912567000000003	50.934531	58.961074000000004	58.950321000000002	0103000020E610000001000000050000005534D6FECE744940DCD9571EA4794D405534D6FECE74494099840B79047B4D40910C39B69E77494099840B79047B4D40910C39B69E774940DCD9571EA4794D405534D6FECE744940DCD9571EA4794D40
10470	Прокопье	7	67	486	50.578591000000003	50.608640000000001	58.915291000000003	58.900931	0103000020E61000000100000005000000466117450F4A4940EE79FEB451734D40466117450F4A49405DA9674128754D40CB845FEAE74D49405DA9674128754D40CB845FEAE74D4940EE79FEB451734D40466117450F4A4940EE79FEB451734D40
10755	Полом	7	67	486	50.808982	50.845129999999997	59.198388999999999	59.175916999999998	0103000020E61000000100000005000000BE86E0B88C674940BCE7C07284964D40BE86E0B88C6749406D718DCF64994D402A6F47382D6C49406D718DCF64994D402A6F47382D6C4940BCE7C07284964D40BE86E0B88C674940BCE7C07284964D40
3046	Подрезчиха	7	67	486	51.436490999999997	51.492393	59.359144000000001	59.339257000000003	0103000020E61000000100000005000000C9FFE4EFDEB7494034F8FBC56CAB4D40C9FFE4EFDEB74940FE463B6EF8AD4D40C1E3DBBB06BF4940FE463B6EF8AD4D40C1E3DBBB06BF494034F8FBC56CAB4D40C9FFE4EFDEB7494034F8FBC56CAB4D40
10843	Климковка	7	67	486	51.219261000000003	51.257393999999998	58.896895999999998	58.878211999999998	0103000020E61000000100000005000000E62494BE109C4940357A354069704D40E62494BE109C4940E4F4F57CCD724D40E3175E49F2A04940E4F4F57CCD724D40E3175E49F2A04940357A354069704D40E62494BE109C4940357A354069704D40
3009	Каменное	7	67	486	51.498438999999998	51.518048999999998	59.157499999999999	59.148705	0103000020E61000000100000005000000850662D9CCBF494037E0F3C308934D40850662D9CCBF49405C8FC2F528944D40DD5CFC6D4FC249405C8FC2F528944D40DD5CFC6D4FC2494037E0F3C308934D40850662D9CCBF494037E0F3C308934D40
10693	Иванцево	7	67	486	50.979436999999997	51.016061999999998	59.136848000000001	59.124630000000003	0103000020E6100000010000000500000005BF0D315E7D4940DD0C37E0F38F4D4005BF0D315E7D4940F2423A3C84914D40AB5AD2510E824940F2423A3C84914D40AB5AD2510E824940DD0C37E0F38F4D4005BF0D315E7D4940DD0C37E0F38F4D40
10815	Дубровка	7	67	486	51.140532	51.172063000000001	59.234166000000002	59.219335999999998	0103000020E610000001000000050000004F05DCF3FC914940F06AB933139C4D404F05DCF3FC914940E6EAC726F99D4D4003ED0E2906964940E6EAC726F99D4D4003ED0E2906964940F06AB933139C4D404F05DCF3FC914940F06AB933139C4D40
10412	Гуренки	7	67	486	50.666876999999999	50.688338000000002	58.795941999999997	58.785170000000001	0103000020E6100000010000000500000030BABC395C55494071E6577380644D4030BABC395C554940A4C16D6DE1654D400A4CA7751B584940A4C16D6DE1654D400A4CA7751B58494071E6577380644D4030BABC395C55494071E6577380644D40
10554	Всехсвятское	7	67	486	50.842813	50.872402999999998	59.063816000000003	59.052081999999999	0103000020E6100000010000000500000063D2DF4BE16B4940EA5A7B9FAA864D4063D2DF4BE16B4940147B681F2B884D4055F7C8E6AA6F4940147B681F2B884D4055F7C8E6AA6F4940EA5A7B9FAA864D4063D2DF4BE16B4940EA5A7B9FAA864D40
10384	Быданово	7	67	486	50.782401	50.813806	58.7562	58.742930999999999	0103000020E61000000100000005000000C9AD49B725644940A017EE5C185F4D40C9AD49B7256449401B9E5E29CB604D40F0A485CB2A6849401B9E5E29CB604D40F0A485CB2A684940A017EE5C185F4D40C9AD49B725644940A017EE5C185F4D40
2909	Белая Холуница	7	67	486	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
9299	Шердынята	7	67	246	53.504556999999998	53.530859	58.602075999999997	58.587173	0103000020E61000000100000005000000E3FBE25295C04A400F0C207C284B4D40E3FBE25295C04A406EDA8CD3104D4D40C5E40D30F3C34A406EDA8CD3104D4D40C5E40D30F3C34A400F0C207C284B4D40E3FBE25295C04A400F0C207C284B4D40
9437	Фроловская	7	67	246	53.141134000000001	53.155346000000002	58.732422999999997	58.724710000000002	0103000020E61000000100000005000000452DCDAD10924A40C68A1A4CC35C4D40452DCDAD10924A404AEB6F09C05D4D403FC8B260E2934A404AEB6F09C05D4D403FC8B260E2934A40C68A1A4CC35C4D40452DCDAD10924A40C68A1A4CC35C4D40
1035	Томызь	7	67	246	52.937494999999998	52.954445999999997	58.705548999999998	58.696699000000002	0103000020E61000000100000005000000EE940ED6FF774A40F513CE6E2D594D40EE940ED6FF774A40DD5CFC6D4F5A4D4025E659492B7A4A40DD5CFC6D4F5A4D4025E659492B7A4A40F513CE6E2D594D40EE940ED6FF774A40F513CE6E2D594D40
8810	Сюзьва	7	67	246	53.054895999999999	53.066834999999998	59.306778999999999	59.299607999999999	0103000020E61000000100000005000000325706D506874A405BCF108E59A64D40325706D506874A40BF0CC68844A74D40349D9D0C8E884A40BF0CC68844A74D40349D9D0C8E884A405BCF108E59A64D40325706D506874A405BCF108E59A64D40
56017	Слобода	7	67	246	53.664205000000003	53.681173999999999	58.678978000000001	58.668112999999998	0103000020E610000001000000050000007B6B60AB04D54A4027840EBA84554D407B6B60AB04D54A400C5A48C0E8564D405871AAB530D74A400C5A48C0E8564D405871AAB530D74A4027840EBA84554D407B6B60AB04D54A4027840EBA84554D40
1633	Савинцы	7	67	246	53.397576000000001	53.427841000000001	59.000149999999998	58.988120000000002	0103000020E6100000010000000500000056D636C5E3B24A40034356B77A7E4D4056D636C5E3B24A40158C4AEA04804D40A8716F7EC3B64A40158C4AEA04804D40A8716F7EC3B64A40034356B77A7E4D4056D636C5E3B24A40034356B77A7E4D40
9594	Ромаши	7	67	246	53.400126999999998	53.42051	58.705933000000002	58.687874999999998	0103000020E61000000100000005000000909F8D5C37B34A40355EBA490C584D40909F8D5C37B34A40661536035C5A4D400BD28C45D3B54A40661536035C5A4D400BD28C45D3B54A40355EBA490C584D40909F8D5C37B34A40355EBA490C584D40
1519	Пура	7	67	246	53.172279000000003	53.195590000000003	59.024942000000003	59.014690999999999	0103000020E61000000100000005000000D064FF3C0D964A40D4450A65E1814D40D064FF3C0D964A40FF25A94C31834D405BB6D61709994A40FF25A94C31834D405BB6D61709994A40D4450A65E1814D40D064FF3C0D964A40D4450A65E1814D40
2893	Пашино	7	67	246	53.323160000000001	53.339446000000002	58.787717000000001	58.772505000000002	0103000020E610000001000000050000000CB08F4E5DA94A408D7F9F71E1624D400CB08F4E5DA94A406AC020E9D3644D4007616EF772AB4A406AC020E9D3644D4007616EF772AB4A408D7F9F71E1624D400CB08F4E5DA94A408D7F9F71E1624D40
6312	Ожегино	7	67	246	53.291924999999999	53.300657000000001	59.000205999999999	58.995260000000002	0103000020E6100000010000000500000041F163CC5DA54A402C82FFAD647F4D4041F163CC5DA54A40A9A10DC006804D402028B7ED7BA64A40A9A10DC006804D402028B7ED7BA64A402C82FFAD647F4D4041F163CC5DA54A402C82FFAD647F4D40
1081	Московская	7	67	246	53.109665999999997	53.138691000000001	58.830399	58.820314000000003	0103000020E61000000100000005000000D7BD1589098E4A40B939950C00694D40D7BD1589098E4A40C8D0B1834A6A4D40F19F6EA0C0914A40C8D0B1834A6A4D40F19F6EA0C0914A40B939950C00694D40D7BD1589098E4A40B939950C00694D40
9233	Лытка	7	67	246	52.994242	53.011524999999999	58.565434000000003	58.554679999999998	0103000020E61000000100000005000000A2276552437F4A4065DF15C1FF464D40A2276552437F4A40F3052D2460484D400F0BB5A679814A40F3052D2460484D400F0BB5A679814A4065DF15C1FF464D40A2276552437F4A4065DF15C1FF464D40
9122	Кувакуш	7	67	246	53.640363999999998	53.656866000000001	58.88682	58.876398000000002	0103000020E6100000010000000500000093C49272F7D14A40D12346CF2D704D4093C49272F7D14A4028B8585183714D405BED612F14D44A4028B8585183714D405BED612F14D44A40D12346CF2D704D4093C49272F7D14A40D12346CF2D704D40
1506	Камский	7	67	246	53.311166999999998	53.33146	58.773713999999998	58.760947000000002	0103000020E61000000100000005000000164CFC51D4A74A40A27E17B666614D40164CFC51D4A74A408A3A730F09634D4051F701486DAA4A408A3A730F09634D4051F701486DAA4A40A27E17B666614D40164CFC51D4A74A40A27E17B666614D40
977	Илюши	7	67	246	53.284253999999997	53.300091000000002	58.959626	58.947963000000001	0103000020E61000000100000005000000EBE0606F62A44A40B66801DA56794D40EBE0606F62A44A4016325706D57A4D407769C36169A64A4016325706D57A4D407769C36169A64A40B66801DA56794D40EBE0606F62A44A40B66801DA56794D40
31170	Жарковы	7	67	246	53.314464000000001	53.330472	59.066831999999998	59.057319999999997	0103000020E610000001000000050000007AE2395B40A84A400FB4024356874D407AE2395B40A84A40C32973F38D884D40321F10E84CAA4A40C32973F38D884D40321F10E84CAA4A400FB4024356874D407AE2395B40A84A400FB4024356874D40
9072	Ефремята	7	67	246	53.466512999999999	53.476385000000001	58.487552000000001	58.475292000000003	0103000020E610000001000000050000005514AFB2B6BB4A407506465ED63C4D405514AFB2B6BB4A40B98C9B1A683E4D4009A7052FFABC4A40B98C9B1A683E4D4009A7052FFABC4A407506465ED63C4D405514AFB2B6BB4A407506465ED63C4D40
9197	Езжа	7	67	246	53.630544999999998	53.642995999999997	58.801751000000003	58.795825999999998	0103000020E6100000010000000500000002D4D4B2B5D04A403BA759A0DD654D4002D4D4B2B5D04A408544DAC69F664D40BABA63B14DD24A408544DAC69F664D40BABA63B14DD24A403BA759A0DD654D4002D4D4B2B5D04A403BA759A0DD654D40
2784	Гордино	7	67	246	53.538881000000003	53.563971000000002	58.571728	58.551209999999998	0103000020E61000000100000005000000C8B7770DFAC44A40349D9D0C8E464D40C8B7770DFAC44A408F1A13622E494D403B72A43330C84A408F1A13622E494D403B72A43330C84A40349D9D0C8E464D40C8B7770DFAC44A40349D9D0C8E464D40
2559	Георгиево	7	67	246	53.165173000000003	53.191045000000003	59.150024999999999	59.139650000000003	0103000020E6100000010000000500000053978C6324954A4076711B0DE0914D4053978C6324954A408C4AEA0434934D403C889D2974984A408C4AEA0434934D403C889D2974984A4076711B0DE0914D4053978C6324954A4076711B0DE0914D40
8567	Верхняя Тимофеевская	7	67	246	53.103540000000002	53.134045999999998	58.885899000000002	58.878318999999998	0103000020E61000000100000005000000F7E978CC408D4A404B3ACAC16C704D40F7E978CC408D4A409147702365714D406E14596B28914A409147702365714D406E14596B28914A404B3ACAC16C704D40F7E978CC408D4A404B3ACAC16C704D40
1851	Верхнее Камье	7	67	246	53.430185000000002	53.436734000000001	58.659328000000002	58.655203999999998	0103000020E61000000100000005000000691D554D10B74A40AC1A84B9DD534D40691D554D10B74A4026AB22DC64544D40908653E6E6B74A4026AB22DC64544D40908653E6E6B74A40AC1A84B9DD534D40691D554D10B74A40AC1A84B9DD534D40
2457	Васенки	7	67	246	53.605428000000003	53.621841000000003	58.516793999999997	58.509391000000001	0103000020E61000000100000005000000960A2AAA7ECD4A4039F06AB933414D40960A2AAA7ECD4A406F62484E26424D40EE27637C98CF4A406F62484E26424D40EE27637C98CF4A4039F06AB933414D40960A2AAA7ECD4A4039F06AB933414D40
8679	Ванино	7	67	246	52.914974000000001	52.918433	59.315289	59.310136	0103000020E610000001000000050000005C5837DE1D754A40F8A75489B2A74D405C5837DE1D754A40EFE4D3635BA84D40994869368F754A40EFE4D3635BA84D40994869368F754A40F8A75489B2A74D405C5837DE1D754A40F8A75489B2A74D40
56000	Бор	7	67	246	53.072009000000001	53.096235999999998	59.198233000000002	59.182653999999999	0103000020E610000001000000050000004302469737894A40E63DCE3461974D404302469737894A4076FEEDB25F994D4053591476518C4A4076FEEDB25F994D4053591476518C4A40E63DCE3461974D404302469737894A40E63DCE3461974D40
2782	Бисерово	7	67	246	53.245339000000001	53.275100000000002	59.080351	59.055084999999998	0103000020E6100000010000000500000078B7B244679F4A4005C078060D874D4078B7B244679F4A40B7990AF1488A4D4097900F7A36A34A40B7990AF1488A4D4097900F7A36A34A4005C078060D874D4078B7B244679F4A4005C078060D874D40
8613	Афонята	7	67	246	52.944682	52.956018	59.342767000000002	59.336136000000003	0103000020E61000000100000005000000588FFB56EB784A400F81238106AB4D40588FFB56EB784A40F392FFC9DFAB4D4094313ECC5E7A4A40F392FFC9DFAB4D4094313ECC5E7A4A400F81238106AB4D40588FFB56EB784A400F81238106AB4D40
2668	Афанасьево	7	67	246	53.224983000000002	53.301825000000001	58.887256999999998	58.832486000000003	0103000020E61000000100000005000000F793313ECC9C4A405E30B8E68E6A4D40F793313ECC9C4A40D3122BA391714D40BF0E9C33A2A64A40D3122BA391714D40BF0E9C33A2A64A405E30B8E68E6A4D40F793313ECC9C4A405E30B8E68E6A4D40
9678	Архипята	7	67	246	53.522083000000002	53.542932999999998	58.965881000000003	58.957982999999999	0103000020E610000001000000050000001766A19DD3C24A40DE8FDB2F9F7A4D401766A19DD3C24A40F56915FDA17B4D40A7751BD47EC54A40F56915FDA17B4D40A7751BD47EC54A40DE8FDB2F9F7A4D401766A19DD3C24A40DE8FDB2F9F7A4D40
7009	Шембеть	7	67	429	48.245882000000002	48.286135000000002	57.836004000000003	57.813282000000001	0103000020E610000001000000050000006956B60F791F48407636E49F19E84C406956B60F791F4840A0A9D72D02EB4C40D89E5912A0244840A0A9D72D02EB4C40D89E5912A02448407636E49F19E84C406956B60F791F48407636E49F19E84C40
8369	Шараница	7	67	429	48.619599000000001	48.644472999999998	57.811124	57.790107999999996	0103000020E6100000010000000500000031D120054F4F48406B274A4222E54C4031D120054F4F4840178046E9D2E74C40D7135D177E524840178046E9D2E74C40D7135D177E5248406B274A4222E54C4031D120054F4F48406B274A4222E54C40
8348	Сорвижи	7	67	429	48.492119000000002	48.545686000000003	57.870058999999998	57.851931999999998	0103000020E61000000100000005000000C05E61C1FD3E48403B35971B0CED4C40C05E61C1FD3E4840944BE3175EEF4C404AF1F109D9454840944BE3175EEF4C404AF1F109D94548403B35971B0CED4C40C05E61C1FD3E48403B35971B0CED4C40
8273	Пишнур	7	67	429	47.936169999999997	47.954225999999998	57.802210000000002	57.780901	0103000020E6100000010000000500000087BF266BD4F74740F4346090F4E34C4087BF266BD4F74740184339D1AEE64C40177FDB1324FA4740184339D1AEE64C40177FDB1324FA4740F4346090F4E34C4087BF266BD4F74740F4346090F4E34C40
8236	Мосуны	7	67	429	48.270352000000003	48.289234999999998	57.770937000000004	57.755713	0103000020E610000001000000050000004034F3E49A224840BE141E34BBE04C404034F3E49A22484060234910AEE24C40E5ED08A70525484060234910AEE24C40E5ED08A705254840BE141E34BBE04C404034F3E49A224840BE141E34BBE04C40
8173	Криуша	7	67	429	48.401325999999997	48.422257000000002	57.922654999999999	57.912185999999998	0103000020E610000001000000050000006A847EA65E3348403DEFC682C2F44C406A847EA65E334840D53E1D8F19F64C40E8C072840C364840D53E1D8F19F64C40E8C072840C3648403DEFC682C2F44C406A847EA65E3348403DEFC682C2F44C40
2337	Кормино	7	67	429	48.378526999999998	48.400778000000003	57.884894000000003	57.874485999999997	0103000020E6100000010000000500000095D39E9273304840A9674128EFEF4C4095D39E92733048409C36E33444F14C40687A89B14C3348409C36E33444F14C40687A89B14C334840A9674128EFEF4C4095D39E9273304840A9674128EFEF4C40
8053	Гулины	7	67	429	48.386450000000004	48.405557000000002	57.746502	57.738047000000002	0103000020E6100000010000000500000005C58F317731484099F4F75278DE4C4005C58F31773148400533A6608DDF4C40FAD4B14AE93348400533A6608DDF4C40FAD4B14AE933484099F4F75278DE4C4005C58F317731484099F4F75278DE4C40
6954	Верхотулье	7	67	429	48.053758999999999	48.069910999999998	57.772502000000003	57.764975	0103000020E61000000100000005000000CE6E2D93E1064840F9A067B3EAE14C40CE6E2D93E10648401C0C7558E1E24C40B950F9D7F20848401C0C7558E1E24C40B950F9D7F2084840F9A067B3EAE14C40CE6E2D93E1064840F9A067B3EAE14C40
7982	Большой Кугунур	7	67	429	48.132389000000003	48.172930000000001	57.676243999999997	57.667369000000001	0103000020E61000000100000005000000D2AC6C1FF21048409FAEEE586CD54C40D2AC6C1FF2104840E00ED4298FD64C40A73FFB9122164840E00ED4298FD64C40A73FFB91221648409FAEEE586CD54C40D2AC6C1FF21048409FAEEE586CD54C40
7924	Басманы	7	67	429	48.462752999999999	48.489550000000001	57.660369000000003	57.652472000000003	0103000020E610000001000000050000001D90847D3B3B484022C7D63384D34C401D90847D3B3B48406825ADF886D44C40DFE00B93A93E48406825ADF886D44C40DFE00B93A93E484022C7D63384D34C401D90847D3B3B484022C7D63384D34C40
6910	Арбаж	7	67	429	48.280673999999998	48.337069999999997	57.692137000000002	57.665630999999998	0103000020E61000000100000005000000336B2920ED234840151A886533D54C40336B2920ED23484000ADF9F197D84C403A3B191C252B484000ADF9F197D84C403A3B191C252B4840151A886533D54C40336B2920ED234840151A886533D54C40
61558	городское поселение Эгвекинот	4	42	\N	157.72459900000001	190.343693	71.612297999999996	61.808397999999997	0103000020E61000000100000005000000DCF63DEA2FB763406E13EE9579E74E40DCF63DEA2FB76340FF59F3E32FE75140A75B7688FFCA6740FF59F3E32FE75140A75B7688FFCA67406E13EE9579E74E40DCF63DEA2FB763406E13EE9579E74E40
55649	Угольные Копи	4	42	\N	177.15205	178.20670799999999	64.962370000000007	64.511729000000003	0103000020E610000001000000050000006B2BF697DD2466408CDAFD2AC02050406B2BF697DD246640B3295778973D50404A7A185A9D466640B3295778973D50404A7A185A9D4666408CDAFD2AC02050406B2BF697DD2466408CDAFD2AC0205040
55648	Певек	4	42	\N	169.84854899999999	170.90320700000001	69.879572999999993	69.513324999999995	0103000020E61000000100000005000000B6813B50273B654007CE1951DA605140B6813B50273B6540745C8DEC4A78514096D05D12E75C6540745C8DEC4A78514096D05D12E75C654007CE1951DA605140B6813B50273B654007CE1951DA605140
55646	Билибино	4	42	\N	165.91016400000001	166.964822	68.252239000000003	67.857735000000005	0103000020E61000000100000005000000E4BF401020BD64409D685721E5F65040E4BF401020BD6440A6F10BAF24105140C30E63D2DFDE6440A6F10BAF24105140C30E63D2DFDE64409D685721E5F65040E4BF401020BD64409D685721E5F65040
21786	Анадырь	4	42	\N	176.95003700000001	178.004695	64.961044999999999	64.510382000000007	0103000020E61000000100000005000000AE9FFEB3661E6640E59D4319AA205040AE9FFEB3661E6640FF3EE3C2813D50408DEE207626406640FF3EE3C2813D50408DEE207626406640E59D4319AA205040AE9FFEB3661E6640E59D4319AA205040
13399	Лорино	4	42	1281	184.06794600000001	192.50544400000001	67.200055000000006	63.695833	0103000020E610000001000000050000009CFC169D2C026740213D450E11D94F409CFC169D2C026740AF997CB3CDCC5040B43EE5982C106840AF997CB3CDCC5040B43EE5982C106840213D450E11D94F409CFC169D2C026740213D450E11D94F40
23419	Лаврентия	4	42	1281	184.76483200000001	193.20232999999999	67.274854000000005	63.781399	0103000020E61000000100000005000000E65DF580791867404510E7E104E44F40E65DF58079186740304B3B3597D15040FD9FC37C79266840304B3B3597D15040FD9FC37C792668404510E7E104E44F40E65DF580791867404510E7E104E44F40
24099	Янранай	4	42	1524	170.01742300000001	171.072081	70.100233000000003	69.737840000000006	0103000020E6100000010000000500000058E6ADBA8E406540906B43C5386F514058E6ADBA8E406540B83EAC376A8651403735D07C4E626540B83EAC376A8651403735D07C4E626540906B43C5386F514058E6ADBA8E406540906B43C5386F5140
23934	Певек	4	42	1524	169.84854899999999	170.90320700000001	69.879572999999993	69.513324999999995	0103000020E61000000100000005000000B6813B50273B654007CE1951DA605140B6813B50273B6540745C8DEC4A78514096D05D12E75C6540745C8DEC4A78514096D05D12E75C654007CE1951DA605140B6813B50273B654007CE1951DA605140
61551	Провидения	4	42	1735	182.54790700000001	190.98540499999999	66.199275	62.551695000000002	0103000020E61000000100000005000000FCC7427488D16640F12E17F19D464F40FCC7427488D1664044FAEDEBC08C5040130A117088DF674044FAEDEBC08C5040130A117088DF6740F12E17F19D464F40FCC7427488D16640F12E17F19D464F40
61552	Нов. Чаплино	4	42	1735	182.903819	191.341317	66.262438000000003	62.623866999999997	0103000020E610000001000000050000001CD0D215ECDC6640DD06B5DFDA4F4F401CD0D215ECDC664092CEC0C8CB9050403412A111ECEA674092CEC0C8CB9050403412A111ECEA6740DD06B5DFDA4F4F401CD0D215ECDC6640DD06B5DFDA4F4F40
55367	городское поселение Эгвекинот	4	42	1719	176.06889699999999	185.40589700000001	68.312197999999995	64.948198000000005	0103000020E610000001000000050000005C397B67340266407D08AA46AF3C50405C397B67340266401AF8510DFB1351406D91B41BFD2C67401AF8510DFB1351406D91B41BFD2C67407D08AA46AF3C50405C397B67340266407D08AA46AF3C5040
52771	Амгуэма	4	42	1719	176.89049700000001	185.32799499999999	68.638737000000006	65.342815000000002	0103000020E61000000100000005000000F58590F37E1C6640026553AEF0555040F58590F37E1C6640B16F2711E12851400CC85EEF7E2A6740B16F2711E12851400CC85EEF7E2A6740026553AEF0555040F58590F37E1C6640026553AEF0555040
23159	Кепервеем	4	42	1705	165.62069099999999	166.67534900000001	68.041569999999993	67.643431000000007	0103000020E610000001000000050000007D3D5FB3DCB36440E38E37F92DE950407D3D5FB3DCB36440A99F3715A90251405D8C81759CD56440A99F3715A90251405D8C81759CD56440E38E37F92DE950407D3D5FB3DCB36440E38E37F92DE95040
22792	Билибино	4	42	1705	165.91016400000001	166.964822	68.252239000000003	67.857735000000005	0103000020E61000000100000005000000E4BF401020BD64409D685721E5F65040E4BF401020BD6440A6F10BAF24105140C30E63D2DFDE6440A6F10BAF24105140C30E63D2DFDE64409D685721E5F65040E4BF401020BD64409D685721E5F65040
52731	Алькатваам	4	42	7218	178.49858	179.55323799999999	63.365082000000001	62.887706999999999	0103000020E61000000100000005000000124E0B5EF44F664013B70A62A0714F40124E0B5EF44F6640DC2DC901BBAE4F40F19C2D20B4716640DC2DC901BBAE4F40F19C2D20B471664013B70A62A0714F40124E0B5EF44F664013B70A62A0714F40
55373	городское поселение Беринговский	4	42	1682	165.305194	179.75699399999999	68.272299000000004	62.253399000000002	0103000020E61000000100000005000000EF1D3526C4A9644068EBE0606F204F40EF1D3526C4A96440F2EEC8586D11514095287B4B39786640F2EEC8586D11514095287B4B3978664068EBE0606F204F40EF1D3526C4A9644068EBE0606F204F40
55647	Угольные Копи	4	42	1682	177.15205	178.20670799999999	64.962370000000007	64.511729000000003	0103000020E610000001000000050000006B2BF697DD2466408CDAFD2AC02050406B2BF697DD246640B3295778973D50404A7A185A9D466640B3295778973D50404A7A185A9D4666408CDAFD2AC02050406B2BF697DD2466408CDAFD2AC0205040
52702	Марково	4	42	1682	169.88493099999999	170.93958900000001	64.899139000000005	64.447434000000001	0103000020E61000000100000005000000EE06D15A513C6540954737C2A21C5040EE06D15A513C6540B9E34D7E8B395040CE55F31C115E6540B9E34D7E8B395040CE55F31C115E6540954737C2A21C5040EE06D15A513C6540954737C2A21C5040
55651	Канчалан	4	42	1682	165.305194	179.75699399999999	68.272299000000004	62.253399000000002	0103000020E61000000100000005000000EF1D3526C4A9644068EBE0606F204F40EF1D3526C4A96440F2EEC8586D11514095287B4B39786640F2EEC8586D11514095287B4B3978664068EBE0606F204F40EF1D3526C4A9644068EBE0606F204F40
50556	п. Третий Сплавной	4	37	\N	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
718	Хабаровск	4	37	\N	134.89181400000001	135.22114500000001	48.599291000000001	48.321784999999998	0103000020E61000000100000005000000AE8383BD89DC6040F3AB394030294840AE8383BD89DC6040C1E44691B54C484091D5AD9E13E76040C1E44691B54C484091D5AD9E13E76040F3AB394030294840AE8383BD89DC6040F3AB394030294840
61564	Охотск	4	37	\N	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
49990	Комсомольск-на-Амуре	4	37	\N	136.86117200000001	137.15650199999999	50.699987	50.516188	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
50483	.Комсомольск-на-Амуре	4	37	\N	136.86117200000001	137.15650199999999	50.699987	50.516188	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
61571	с. Второй Сплавной Участок	4	37	7534	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
49969	Бичевая	4	37	7003	135.61096000000001	135.645464	47.798434	47.758094999999997	0103000020E610000001000000050000004165FCFB8CF360406C21C84109E147404165FCFB8CF36040DA01D71533E64740DA571EA4A7F46040DA01D71533E64740DA571EA4A7F460406C21C84109E147404165FCFB8CF360406C21C84109E14740
50509	Хабаровск	4	37	7082	134.89181400000001	135.11669800000001	48.506638000000002	48.434173000000001	0103000020E61000000100000005000000AE8383BD89DC604032E719FB92374840AE8383BD89DC604097749483D940484047B071FDBBE3604097749483D940484047B071FDBBE3604032E719FB92374840AE8383BD89DC604032E719FB92374840
3570	Чистополье	4	37	249	135.25022300000001	135.258668	48.516939999999998	48.509341999999997	0103000020E61000000100000005000000A036AAD301E86040573D601E32414840A036AAD301E8604043FF04172B424840B2101D0247E8604043FF04172B424840B2101D0247E86040573D601E32414840A036AAD301E86040573D601E32414840
50956	Черная Речка	4	37	249	135.30088799999999	135.326661	48.475768000000002	48.461418999999999	0103000020E6100000010000000500000048F8DEDFA0E9604063601DC70F3B484048F8DEDFA0E96040DE3D40F7E53C48401EFCC40174EA6040DE3D40F7E53C48401EFCC40174EA604063601DC70F3B484048F8DEDFA0E9604063601DC70F3B4840
2564	Челны	4	37	249	136.003218	136.043903	48.884793000000002	48.87238	0103000020E610000001000000050000004698A25C1A0061409DD7D825AA6F48404698A25C1A006140685DA3E54071484048A643A767016140685DA3E54071484048A643A7670161409DD7D825AA6F48404698A25C1A0061409DD7D825AA6F4840
2073	Федоровка	4	37	249	135.16967099999999	135.178978	48.602967	48.590657	0103000020E610000001000000050000008C82E0F16DE56040A51309A69A4B48408C82E0F16DE560409BC8CC052E4D484083161230BAE560409BC8CC052E4D484083161230BAE56040A51309A69A4B48408C82E0F16DE56040A51309A69A4B4840
2548	Улика-Национальное	4	37	249	134.22504799999999	134.23687000000001	48.762174999999999	48.757133000000003	0103000020E61000000100000005000000F700DD9733C7604077DCF0BBE9604840F700DD9733C76040166A4DF38E614840EAEC647094C76040166A4DF38E614840EAEC647094C7604077DCF0BBE9604840F700DD9733C7604077DCF0BBE9604840
50488	Тополево	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
2914	Таежное	4	37	249	135.58428900000001	135.617616	48.607118999999997	48.597396000000003	0103000020E61000000100000005000000344DD87EB2F260407061DD78774C4840344DD87EB2F26040DEE34C13B64D4840902FA182C3F36040DEE34C13B64D4840902FA182C3F360407061DD78774C4840344DD87EB2F260407061DD78774C4840
50445	Сосновка	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
1372	Смирновка	4	37	249	135.30306200000001	135.32139699999999	48.561864999999997	48.556409000000002	0103000020E61000000100000005000000225514AFB2E960409C19FD6838474840225514AFB2E960402EE23B31EB4748400A815CE248EA60402EE23B31EB4748400A815CE248EA60409C19FD6838474840225514AFB2E960409C19FD6838474840
2749	Сикачи-Алян	4	37	249	135.63094699999999	135.647908	48.753158999999997	48.747633999999998	0103000020E610000001000000050000004C50C3B730F4604057B08D78B25F48404C50C3B730F4604012D89C836760484023DA8EA9BBF4604012D89C836760484023DA8EA9BBF4604057B08D78B25F48404C50C3B730F4604057B08D78B25F4840
3462	Сергеевка	4	37	249	135.36960099999999	135.39810399999999	48.478000999999999	48.467058000000002	0103000020E6100000010000000500000034F279C5D3EB6040E7AA798EC83B484034F279C5D3EB6040473A03232F3D4840048D9944BDEC6040473A03232F3D4840048D9944BDEC6040E7AA798EC83B484034F279C5D3EB6040E7AA798EC83B4840
50449	Ракитное	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
2364	Победа	4	37	249	134.316892	134.33811900000001	49.067233999999999	49.037393999999999	0103000020E61000000100000005000000A60BB1FA23CA604087889B53C9844840A60BB1FA23CA6040F296AB1F9B88484000E5EFDED1CA6040F296AB1F9B88484000E5EFDED1CA604087889B53C9844840A60BB1FA23CA604087889B53C9844840
2902	Петропавловка	4	37	249	135.514229	135.551851	48.691659999999999	48.673856999999998	0103000020E61000000100000005000000F434609074F06040209738F240564840F434609074F06040C6F99B50885848407AA86DC3A8F16040C6F99B50885848407AA86DC3A8F16040209738F240564840F434609074F06040209738F240564840
2415	Пасека	4	37	249	134.334014	134.36148399999999	49.069454	49.056578999999999	0103000020E61000000100000005000000FFCC203EB0CA6040F8510DFB3D874840FFCC203EB0CA6040C74961DEE3884840DFC0E44691CB6040C74961DEE3884840DFC0E44691CB6040F8510DFB3D874840FFCC203EB0CA6040F8510DFB3D874840
2469	Новокуровка	4	37	249	134.304495	134.32118600000001	48.860035000000003	48.840246	0103000020E6100000010000000500000075594C6CBEC96040234C512E8D6B484075594C6CBEC960402B357BA0156E4840DCBDDC2747CA60402B357BA0156E4840DCBDDC2747CA6040234C512E8D6B484075594C6CBEC96040234C512E8D6B4840
1021	Некрасовка	4	37	249	135.22432499999999	135.249864	48.354486000000001	48.342731000000001	0103000020E610000001000000050000009B559FAB2DE76040A629029CDE2B48409B559FAB2DE76040E77118CC5F2D4840548EC9E2FEE76040E77118CC5F2D4840548EC9E2FEE76040A629029CDE2B48409B559FAB2DE76040A629029CDE2B4840
2320	Наумовка	4	37	249	133.422493	133.43119799999999	48.999740000000003	48.987910999999997	0103000020E610000001000000050000003F390A1085AD6040E82D1EDE737E48403F390A1085AD60406440F67AF77F48403883BF5FCCAD60406440F67AF77F48403883BF5FCCAD6040E82D1EDE737E48403F390A1085AD6040E82D1EDE737E4840
50467	Нагорное	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
50493	Мичуринское	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
3678	Мирное	4	37	249	135.218504	135.22675899999999	48.490673999999999	48.481172999999998	0103000020E6100000010000000500000072C119FCFDE66040EE5BAD13973D484072C119FCFDE66040AE7FD767CE3E48405B22179C41E76040AE7FD767CE3E48405B22179C41E76040EE5BAD13973D484072C119FCFDE66040EE5BAD13973D4840
50447	Матвеевка	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
2805	Малышево	4	37	249	135.59921	135.62263799999999	48.740850000000002	48.720329999999997	0103000020E61000000100000005000000F52D73BA2CF36040F12900C6335C4840F52D73BA2CF36040ED9E3C2CD45E4840E6E786A6ECF36040ED9E3C2CD45E4840E6E786A6ECF36040F12900C6335C4840F52D73BA2CF36040F12900C6335C4840
2216	Кукан	4	37	249	133.46163300000001	133.48387500000001	49.210217	49.183089000000002	0103000020E6100000010000000500000024B891B2C5AE6040F1A0D9756F97484024B891B2C5AE604018080264E89A4840448B6CE77BAF604018080264E89A4840448B6CE77BAF6040F1A0D9756F97484024B891B2C5AE6040F1A0D9756F974840
1761	Краснореченское	4	37	249	134.982022	135.00561200000001	48.357562999999999	48.342570000000002	0103000020E610000001000000050000007BBE66B96CDF60409D4B7155D92B48407BBE66B96CDF60403CA1D79FC42D4840E38E37F92DE060403CA1D79FC42D4840E38E37F92DE060409D4B7155D92B48407BBE66B96CDF60409D4B7155D92B4840
1848	Корфовский	4	37	249	135.03270499999999	135.085454	48.240186000000001	48.204816999999998	0103000020E610000001000000050000004D2D5BEB0BE1604019558671371A48404D2D5BEB0BE16040817A336ABE1E4840FFE9060ABCE26040817A336ABE1E4840FFE9060ABCE2604019558671371A48404D2D5BEB0BE1604019558671371A4840
1714	Корсаково-1	4	37	249	134.94758100000001	134.97416200000001	48.354246000000003	48.343677999999997	0103000020E61000000100000005000000F4A9639552DE6040662D05A4FD2B4840F4A9639552DE6040925ED4EE572D48403160C9552CDF6040925ED4EE572D48403160C9552CDF6040662D05A4FD2B4840F4A9639552DE6040662D05A4FD2B4840
1514	Константиновка	4	37	249	135.43286900000001	135.45529999999999	48.590096000000003	48.582039000000002	0103000020E6100000010000000500000079CE1610DAED60408FFF0241804A484079CE1610DAED60400EC00644884B4840CD3B4ED191EE60400EC00644884B4840CD3B4ED191EE60408FFF0241804A484079CE1610DAED60408FFF0241804A4840
3138	Князе-Волконское	4	37	249	135.44840099999999	135.47366099999999	48.497700999999999	48.456339999999997	0103000020E61000000100000005000000CCCF0D4D59EE6040A6ED5F59693A4840CCCF0D4D59EE6040DF1797AAB43F4840800C1D3B28EF6040DF1797AAB43F4840800C1D3B28EF6040A6ED5F59693A4840CCCF0D4D59EE6040A6ED5F59693A4840
3374	Калинка	4	37	249	135.417957	135.430533	48.438077	48.427818000000002	0103000020E610000001000000050000004CC45BE75FED6040F0517FBDC23648404CC45BE75FED60409D103AE812384840295B24EDC6ED60409D103AE812384840295B24EDC6ED6040F0517FBDC23648404CC45BE75FED6040F0517FBDC2364840
1521	Казакевичево	4	37	249	134.71367799999999	134.74773300000001	48.275098999999997	48.261015999999998	0103000020E61000000100000005000000FDBB3E73D6D66040CADDE7F868214840FDBB3E73D6D66040C614AC71362348407BA4C16DEDD76040C614AC71362348407BA4C16DEDD76040CADDE7F868214840FDBB3E73D6D66040CADDE7F868214840
50505	Ильинка	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
1318	Заозерное	4	37	249	135.22217800000001	135.24033299999999	48.605809000000001	48.592753999999999	0103000020E61000000100000005000000817C09151CE760405E49F25CDF4B4840817C09151CE76040AD4F39268B4D4840C9E4D4CEB0E76040AD4F39268B4D4840C9E4D4CEB0E760405E49F25CDF4B4840817C09151CE760405E49F25CDF4B4840
2659	Елабуга	4	37	249	135.84096500000001	135.876295	48.813223999999998	48.787041000000002	0103000020E6100000010000000500000095826E2FE9FA60403ACE6DC2BD64484095826E2FE9FA604041295AB917684840BFD4CF9B0AFC604041295AB917684840BFD4CF9B0AFC60403ACE6DC2BD64484095826E2FE9FA60403ACE6DC2BD644840
3693	Дружба	4	37	249	135.30387999999999	135.32558299999999	48.393118999999999	48.377291999999997	0103000020E6100000010000000500000012BD8C62B9E960406E85B01A4B30484012BD8C62B9E96040D63730B95132484046240A2D6BEA6040D63730B95132484046240A2D6BEA60406E85B01A4B30484012BD8C62B9E960406E85B01A4B304840
50451	Гаровка 2-я	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
50491	Гаровка 1-я	4	37	249	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
1418	Галкино	4	37	249	135.358183	135.38048800000001	48.566592999999997	48.559766000000003	0103000020E6100000010000000500000076DF313C76EB6040D5B48B69A647484076DF313C76EB60403E92921E86484840A8902BF52CEC60403E92921E86484840A8902BF52CEC6040D5B48B69A647484076DF313C76EB6040D5B48B69A6474840
2703	Вятское	4	37	249	135.70427699999999	135.74295799999999	48.748341000000003	48.730486999999997	0103000020E61000000100000005000000664AEB6F89F660409A931799805D4840664AEB6F89F66040C3A04CA3C95F4840A609DB4FC6F76040C3A04CA3C95F4840A609DB4FC6F760409A931799805D4840664AEB6F89F660409A931799805D4840
3583	Восточное	4	37	249	135.25652099999999	135.274801	48.488232000000004	48.477122999999999	0103000020E610000001000000050000009737876B35E86040AF95D05D123D48409737876B35E860402B6EDC627E3E48400F7D772BCBE860402B6EDC627E3E48400F7D772BCBE86040AF95D05D123D48409737876B35E86040AF95D05D123D4840
1619	Бычиха	4	37	249	134.82088300000001	134.834034	48.304000000000002	48.296334000000002	0103000020E61000000100000005000000F5DA6CAC44DA6040B058C345EE254840F5DA6CAC44DA6040F4FDD478E926484011381268B0DA6040F4FDD478E926484011381268B0DA6040B058C345EE254840F5DA6CAC44DA6040B058C345EE254840
3359	Благодатное	4	37	249	135.47912299999999	135.49073799999999	48.429779000000003	48.416702999999998	0103000020E610000001000000050000005DF8C1F954EF604092921E86563548405DF8C1F954EF6040F9C08EFF02374840F19C2D20B4EF6040F9C08EFF02374840F19C2D20B4EF604092921E86563548405DF8C1F954EF604092921E8656354840
2999	Анастасьевка	4	37	249	135.55301	135.57950099999999	48.581842000000002	48.567999999999998	0103000020E610000001000000050000008D0B0742B2F1604062105839B44848408D0B0742B2F1604039B874CC794A4840FA5FAE458BF2604039B874CC794A4840FA5FAE458BF2604062105839B44848408D0B0742B2F1604062105839B4484840
50522	с.Булава (Новая)	4	37	65	140.39860300000001	140.42361199999999	51.956266999999997	51.916432	0103000020E61000000100000005000000CD22145BC18C61400281CEA44DF54940CD22145BC18C61403C9F01F566FA49402EC6C03A8E8D61403C9F01F566FA49402EC6C03A8E8D61400281CEA44DF54940CD22145BC18C61400281CEA44DF54940
823	Циммермановка	4	37	65	139.22343599999999	139.26288099999999	51.348506999999998	51.333579999999998	0103000020E61000000100000005000000F817416326676140C24CDBBFB2AA4940F817416326676140AAB69BE09BAC4940AC376A8569686140AAB69BE09BAC4940AC376A8569686140C24CDBBFB2AA4940F817416326676140C24CDBBFB2AA4940
32152	Ухта	4	37	65	140.393168	140.399879	52.378928999999999	52.373700999999997	0103000020E61000000100000005000000AEBA0ED5948C6140C2BD326FD52F4A40AEBA0ED5948C6140C440D7BE80304A406E6B0BCFCB8C6140C440D7BE80304A406E6B0BCFCB8C6140C2BD326FD52F4A40AEBA0ED5948C6140C2BD326FD52F4A40
32067	Тыр	4	37	65	139.74989400000001	139.77669	52.935479999999998	52.925873000000003	0103000020E61000000100000005000000EFAEB321FF776140ED9FA70183764A40EFAEB321FF776140F20703CFBD774A402BA4FCA4DA786140F20703CFBD774A402BA4FCA4DA786140ED9FA70183764A40EFAEB321FF776140ED9FA70183764A40
4028	Тахта	4	37	65	139.835476	139.855491	53.137462999999997	53.122329000000001	0103000020E61000000100000005000000F9122A38BC7A61401B2D077AA88F4A40F9122A38BC7A61407CB4386398914A40B760A92E607B61407CB4386398914A40B760A92E607B61401B2D077AA88F4A40F9122A38BC7A61401B2D077AA88F4A40
32079	Сусанино	4	37	65	140.06734	140.09330199999999	52.798777999999999	52.772897	0103000020E61000000100000005000000CE3637A6278261409816F549EE624A40CE3637A627826140D461855B3E664A40D8D47954FC826140D461855B3E664A40D8D47954FC8261409816F549EE624A40CE3637A6278261409816F549EE624A40
532	Софийск	4	37	65	139.83011300000001	139.86822900000001	51.578422000000003	51.558211999999997	0103000020E61000000100000005000000815F2349907A61400C1EA67D73C74940815F2349907A6140BAA46ABB09CA49400B0E2F88C87B6140BAA46ABB09CA49400B0E2F88C87B61400C1EA67D73C74940815F2349907A61400C1EA67D73C74940
32409	Солонцы	4	37	65	140.23095900000001	140.270207	52.265574999999998	52.248254000000003	0103000020E61000000100000005000000F1F6200464876140F48C7DC9C61F4A40F1F62004648761404ED1915CFE214A40CF842689A58861404ED1915CFE214A40CF842689A5886140F48C7DC9C61F4A40F1F6200464876140F48C7DC9C61F4A40
32495	Савинское	4	37	65	140.364575	140.37713299999999	52.173225000000002	52.148077000000001	0103000020E610000001000000050000000EBE3099AA8B61401825E82FF4124A400EBE3099AA8B6140C0EC9E3C2C164A40C1A73979118C6140C0EC9E3C2C164A40C1A73979118C61401825E82FF4124A400EBE3099AA8B61401825E82FF4124A40
813	Решающий	4	37	65	139.524102	139.54412600000001	51.421737	51.411631999999997	0103000020E6100000010000000500000095B88E71C570614058FE7C5BB0B4494095B88E71C5706140AF415F7AFBB54940E8DCED7A69716140AF415F7AFBB54940E8DCED7A6971614058FE7C5BB0B4494095B88E71C570614058FE7C5BB0B44940
32134	Нижняя Гавань	4	37	65	140.41851	140.433009	52.444761	52.432989999999997	0103000020E610000001000000050000009161156F648D61405DBF60376C374A409161156F648D6140A4C4AEEDED384A40F5BBB035DB8D6140A4C4AEEDED384A40F5BBB035DB8D61405DBF60376C374A409161156F648D61405DBF60376C374A40
208	Мариинское	4	37	65	140.17047600000001	140.22700699999999	51.731689000000003	51.722518000000001	0103000020E610000001000000050000001898158A74856140BB6246787BDC49401898158A74856140E6EB32FCA7DD4940D11E2FA443876140E6EB32FCA7DD4940D11E2FA443876140BB6246787BDC49401898158A74856140BB6246787BDC4940
318	Мариинский Рейд	4	37	65	140.18556799999999	140.22010800000001	51.720486999999999	51.698642999999997	0103000020E61000000100000005000000E4654D2CF0856140274A42226DD94940E4654D2CF0856140B91803EB38DC4940D1B2EE1F0B876140B91803EB38DC4940D1B2EE1F0B876140274A42226DD94940E4654D2CF0856140274A42226DD94940
32405	Кольчем	4	37	65	140.174419	140.18280100000001	52.233159999999998	52.224947	0103000020E61000000100000005000000A29927D794856140AA2A3410CB1C4A40A29927D794856140205ED72FD81D4A40A3957B81D9856140205ED72FD81D4A40A3957B81D9856140AA2A3410CB1C4A40A29927D794856140AA2A3410CB1C4A40
971	Ключевой	4	37	65	138.97479999999999	138.99614399999999	51.467587999999999	51.461815000000001	0103000020E610000001000000050000008104C58F315F6140B0E600C11CBB49408104C58F315F6140430070ECD9BB494069C36169E05F6140430070ECD9BB494069C36169E05F6140B0E600C11CBB49408104C58F315F6140B0E600C11CBB4940
30490	Кальма	4	37	65	139.730715	139.740407	52.977670000000003	52.967219999999998	0103000020E610000001000000050000004B766C0462776140C0046EDDCD7B4A404B766C0462776140E223624A247D4A405857056AB1776140E223624A247D4A405857056AB1776140C0046EDDCD7B4A404B766C0462776140C0046EDDCD7B4A40
663	Калиновка	4	37	65	139.70511300000001	139.71534399999999	51.550562999999997	51.541870000000003	0103000020E61000000100000005000000815F2349907661407E5704FF5BC54940815F2349907661409EB12FD978C6494079AC1919E47661409EB12FD978C6494079AC1919E47661407E5704FF5BC54940815F2349907661407E5704FF5BC54940
32415	Дуди	4	37	65	140.185801	140.207415	52.097715000000001	52.085740999999999	0103000020E610000001000000050000000D52F014F28561409276A38FF90A4A400D52F014F285614011AAD4EC810C4A406536C824A386614011AAD4EC810C4A406536C824A38661409276A38FF90A4A400D52F014F28561409276A38FF90A4A40
482	Де-Кастри	4	37	65	140.75187500000001	140.78603699999999	51.486570999999998	51.464799999999997	0103000020E61000000100000005000000C3F5285C0F9861402497FF907EBB4940C3F5285C0F9861404C1762F547BE4940450E1137279961404C1762F547BE4940450E1137279961402497FF907EBB4940C3F5285C0F9861402497FF907EBB4940
713	Быстринск	4	37	65	139.462029	139.47973400000001	51.439267999999998	51.424909999999997	0103000020E61000000100000005000000B7990AF1C86E614026DF6C7363B64940B7990AF1C86E6140F4160FEF39B84940F0181EFB596F6140F4160FEF39B84940F0181EFB596F614026DF6C7363B64940B7990AF1C86E614026DF6C7363B64940
50527	Булава	4	37	65	140.39860300000001	140.42361199999999	51.956266999999997	51.916432	0103000020E61000000100000005000000CD22145BC18C61400281CEA44DF54940CD22145BC18C61403C9F01F566FA49402EC6C03A8E8D61403C9F01F566FA49402EC6C03A8E8D61400281CEA44DF54940CD22145BC18C61400281CEA44DF54940
434	Большие Санники	4	37	65	140.45486500000001	140.46910299999999	51.650706	51.640478999999999	0103000020E610000001000000050000000B630B418E8E61402C634337FBD149400B630B418E8E6140CEA78E554AD34940936E4BE4028F6140CEA78E554AD34940936E4BE4028F61402C634337FBD149400B630B418E8E61402C634337FBD14940
32220	Богородское	4	37	65	140.427457	140.480323	52.385326999999997	52.356076000000002	0103000020E61000000100000005000000486E4DBAAD8D6140FC71FBE5932D4A40486E4DBAAD8D614005A2276552314A40881057CE5E8F614005A2276552314A40881057CE5E8F6140FC71FBE5932D4A40486E4DBAAD8D6140FC71FBE5932D4A40
32059	Аннинские Минеральные Воды	4	37	65	140.16386399999999	140.17759100000001	52.771861999999999	52.761350999999998	0103000020E61000000100000005000000BC1FB75F3E85614071E316F373614A40BC1FB75F3E8561403883BF5FCC624A400C2252D3AE8561403883BF5FCC624A400C2252D3AE85614071E316F373614A40BC1FB75F3E85614071E316F373614A40
31714	Чумикан	4	37	1919	135.298607	135.328	54.723247000000001	54.708055999999999	0103000020E610000001000000050000006A6B44308EE9604048DE3994A15A4B406A6B44308EE960400EF7915B935C4B40D122DBF97EEA60400EF7915B935C4B40D122DBF97EEA604048DE3994A15A4B406A6B44308EE9604048DE3994A15A4B40
31845	Удское	4	37	1919	134.39827	134.420998	54.519939000000001	54.503839999999997	0103000020E610000001000000050000004B1FBAA0BECC6040543541D47D404B404B1FBAA0BECC60401D75745C8D424B40CE35CCD078CD60401D75745C8D424B40CE35CCD078CD6040543541D47D404B404B1FBAA0BECC6040543541D47D404B40
31629	Тугур	4	37	1919	136.80541400000001	136.83752899999999	53.777563999999998	53.769151000000001	0103000020E61000000100000005000000B3B794F3C5196140C5573B8A73E24A40B3B794F3C51961400246973787E34A40730E9E09CD1A61400246973787E34A40730E9E09CD1A6140C5573B8A73E24A40B3B794F3C5196140C5573B8A73E24A40
31709	Тором	4	37	1919	135.80735000000001	135.81618900000001	54.539009	54.528399	0103000020E610000001000000050000009FCDAACFD5F960409B1E1494A2434B409FCDAACFD5F96040F59F353FFE444B405CCB64381EFA6040F59F353FFE444B405CCB64381EFA60409B1E1494A2434B409FCDAACFD5F960409B1E1494A2434B40
31774	Неран	4	37	1919	135.26677000000001	135.27798999999999	54.694023999999999	54.688920000000003	0103000020E61000000100000005000000BA313D6189E86040B9C7D2872E584B40BA313D6189E86040CE5147C7D5584B40AED3484BE5E86040CE5147C7D5584B40AED3484BE5E86040B9C7D2872E584B40BA313D6189E86040B9C7D2872E584B40
31834	Алгазея	4	37	1919	135.18959599999999	135.19812099999999	54.701376000000003	54.696663000000001	0103000020E610000001000000050000007A6EA12B11E66040A8AAD0402C594B407A6EA12B11E66040831953B0C6594B40D3F4D90157E66040831953B0C6594B40D3F4D90157E66040A8AAD0402C594B407A6EA12B11E66040A8AAD0402C594B40
50959	п. Новое Устье	4	37	673	134.21499600000001	138.11319900000001	52.368796000000003	50.373199	0103000020E61000000100000005000000AB984A3FE1C6604030F31DFCC42F4940AB984A3FE1C66040A47213B5342F4A40145E82539F436140A47213B5342F4A40145E82539F43614030F31DFCC42F4940AB984A3FE1C6604030F31DFCC42F4940
31327	Эворон	4	37	673	136.316676	136.36165500000001	51.403682000000003	51.387441000000003	0103000020E61000000100000005000000B3EDB435220A61409510ACAA97B14940B3EDB435220A6140F0FD0DDAABB34940EBAD81AD920B6140F0FD0DDAABB34940EBAD81AD920B61409510ACAA97B14940B3EDB435220A61409510ACAA97B14940
30954	Хурмули	4	37	673	136.87608399999999	136.91430800000001	51.028568	50.996822000000002	0103000020E61000000100000005000000901150E1081C614077F700DD977F4940901150E1081C614027DBC01DA883494014CFD902421D614027DBC01DA883494014CFD902421D614077F700DD977F4940901150E1081C614077F700DD977F4940
31283	Харпичан	4	37	673	136.51684800000001	136.532622	51.302636	51.283351000000003	0103000020E610000001000000050000001920D1048A106140FB2477D844A449401920D1048A106140CF4BC5C6BCA649402AE44A3D0B116140CF4BC5C6BCA649402AE44A3D0B116140FB2477D844A449401920D1048A106140FB2477D844A44940
4616	Хальгасо	4	37	673	136.885031	136.900195	50.701537999999999	50.691975999999997	0103000020E61000000100000005000000471E882C521C6140F6CE68AB92584940471E882C521C61405C7347FFCB594940BAA0BE65CE1C61405C7347FFCB594940BAA0BE65CE1C6140F6CE68AB92584940471E882C521C6140F6CE68AB92584940
30438	Солнечный	4	37	673	136.60209800000001	136.65409299999999	50.736108999999999	50.699325000000002	0103000020E61000000100000005000000965F0663441361403A234A7B83594940965F06634413614048A5D8D1385E49405C717154EE14614048A5D8D1385E49405C717154EE1461403A234A7B83594940965F0663441361403A234A7B83594940
31055	Лиан	4	37	673	136.93220199999999	136.93607399999999	50.823669000000002	50.821331000000001	0103000020E6100000010000000500000081E84999D41D61407218CC5F2169494081E84999D41D614051DD5CFC6D69494059147651F41D614051DD5CFC6D69494059147651F41D61407218CC5F2169494081E84999D41D61407218CC5F21694940
31186	Кондон	4	37	673	136.57341500000001	136.59050999999999	51.267901999999999	51.255687999999999	0103000020E6100000010000000500000026016A6A5912614065FD6662BAA0494026016A6A591261403944DC9C4AA24940C03E3A75E51261403944DC9C4AA24940C03E3A75E512614065FD6662BAA0494026016A6A5912614065FD6662BAA04940
31407	Дуки	4	37	673	135.78227799999999	135.835781	51.576490999999997	51.555273	0103000020E610000001000000050000002B4CDF6B08F9604008AD872F13C749402B4CDF6B08F960401BB80375CAC94940C8B3CBB7BEFA60401BB80375CAC94940C8B3CBB7BEFA604008AD872F13C749402B4CDF6B08F9604008AD872F13C74940
4678	Джамку	4	37	673	134.634401	134.65492800000001	51.125539000000003	51.115254999999998	0103000020E61000000100000005000000977153034DD46040A9D903ADC08E4940977153034DD46040B0AF75A91190494083A7902BF5D46040B0AF75A91190494083A7902BF5D46040A9D903ADC08E4940977153034DD46040A9D903ADC08E4940
30907	Горный	4	37	673	136.41617400000001	136.46598499999999	50.769548999999998	50.758826999999997	0103000020E6100000010000000500000042EE224C510D614030293E3E2161494042EE224C510D6140B2D5E59480624940A6ED5F59E90E6140B2D5E59480624940A6ED5F59E90E614030293E3E2161494042EE224C510D614030293E3E21614940
31113	Горин	4	37	673	136.633306	136.67885899999999	51.211055999999999	51.185336	0103000020E610000001000000050000008ACBF10A44146140BF620D17B99749408ACBF10A44146140F2CF0CE2039B49400C738236B9156140F2CF0CE2039B49400C738236B9156140BF620D17B99749408ACBF10A44146140BF620D17B9974940
31451	Березовый	4	37	673	135.640254	135.71128400000001	51.695579000000002	51.654595	0103000020E6100000010000000500000043E4F4F57CF460400490DAC4C9D3494043E4F4F57CF46040676490BB08D9494061C5A9D6C2F66040676490BB08D9494061C5A9D6C2F660400490DAC4C9D3494043E4F4F57CF460400490DAC4C9D34940
31550	Амгунь	4	37	673	135.06253799999999	135.111964	51.421140999999999	51.409351000000001	0103000020E610000001000000050000003B18B14F00E26040DECA129D65B449403B18B14F00E260409B00C3F2E7B549408ACA863595E360409B00C3F2E7B549408ACA863595E36040DECA129D65B449403B18B14F00E26040DECA129D65B44940
4353	Советская Гавань	4	37	652	140.218176	140.320504	48.998918000000003	48.924950000000003	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
15043	Майский	4	37	652	140.19774899999999	140.258385	49.012399000000002	48.986286	0103000020E6100000010000000500000022FAB5F5538661405740A19E3E7E484022FAB5F55386614066C0594A96814840DD989EB04488614066C0594A96814840DD989EB0448861405740A19E3E7E484022FAB5F5538661405740A19E3E7E4840
15248	Лососина	4	37	652	140.30569	140.32902000000001	49.006388999999999	48.991506000000001	0103000020E61000000100000005000000DB166536C8896140D6E429ABE97E4840DB166536C8896140EE06D15AD18048405C77F354878A6140EE06D15AD18048405C77F354878A6140D6E429ABE97E4840DB166536C8896140D6E429ABE97E4840
15144	Заветы Ильича	4	37	652	140.21072899999999	140.33070799999999	49.057394000000002	49.009633000000001	0103000020E61000000100000005000000336ABE4ABE8661402FFB75A73B814840336ABE4ABE8661404A7EC4AF58874840D190F128958A61404A7EC4AF58874840D190F128958A61402FFB75A73B814840336ABE4ABE8661402FFB75A73B814840
5623	Гатка	4	37	652	140.12432899999999	140.13952	48.902172	48.889118000000003	0103000020E61000000100000005000000389ECF80FA83614079245E9ECE714840389ECF80FA836140F7AE415F7A7348406AA4A5F276846140F7AE415F7A7348406AA4A5F27684614079245E9ECE714840389ECF80FA83614079245E9ECE714840
50557	п. Морской	4	37	7076	132.982552	133.06769499999999	51.137645999999997	51.11703	0103000020E61000000100000005000000D253E410719F60405053CBD6FA8E4940D253E410719F60406D3656629E9149404963B48E2AA260406D3656629E9149404963B48E2AA260405053CBD6FA8E4940D253E410719F60405053CBD6FA8E4940
50411	Охотск	4	37	7076	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
61617	Аэропорт	4	37	7076	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
61579	Арка	4	37	7076	134.130833	134.209597	52.065277000000002	52.023677999999997	0103000020E610000001000000050000009A07B0C82FC460403DD175E107034A409A07B0C82FC460402B172AFF5A084A40DF8AC404B5C660402B172AFF5A084A40DF8AC404B5C660403DD175E107034A409A07B0C82FC460403DD175E107034A40
16616	Чныррах	4	37	911	140.87322800000001	140.88675699999999	53.088161999999997	53.079849000000003	0103000020E6100000010000000500000073BED87BF19B614025CFF57D388A4A4073BED87BF19B6140FE5F75E4488B4A40F84F3750609C6140FE5F75E4488B4A40F84F3750609C614025CFF57D388A4A4073BED87BF19B614025CFF57D388A4A40
16931	Чля	4	37	911	140.18423799999999	140.21232800000001	53.545675000000003	53.538905999999997	0103000020E61000000100000005000000C6151747E585614020CF2EDFFAC44A40C6151747E5856140569FABADD8C54A40CE001764CB866140569FABADD8C54A40CE001764CB86614020CF2EDFFAC44A40C6151747E585614020CF2EDFFAC44A40
50439	Пуир	4	37	911	138.73109600000001	141.54502400000001	54.358401999999998	51.755795999999997	0103000020E6100000010000000500000091477023655761404B395FECBDE0494091477023655761401669E21DE02D4B4020F12BD670B161401669E21DE02D4B4020F12BD670B161404B395FECBDE0494091477023655761404B395FECBDE04940
16520	Оремиф	4	37	911	141.093863	141.10122899999999	53.012661000000001	53.005813000000003	0103000020E61000000100000005000000BE69FAEC00A361402272FA7ABE804A40BE69FAEC00A36140A3772AE09E814A40048D99443DA36140A3772AE09E814A40048D99443DA361402272FA7ABE804A40BE69FAEC00A361402272FA7ABE804A40
7277	Озерпах	4	37	911	141.239543	141.25673699999999	53.049633	53.033617999999997	0103000020E610000001000000050000008BDF1456AAA76140494739984D844A408BDF1456AAA76140B4E6C75F5A864A408A55833037A86140B4E6C75F5A864A408A55833037A86140494739984D844A408BDF1456AAA76140494739984D844A40
7166	Николаевск-на-Амуре	4	37	911	140.633072	140.81411	53.162585	53.127408000000003	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
17109	Нижнее Пронге	4	37	911	141.195256	141.221496	52.863858999999998	52.851374999999997	0103000020E6100000010000000500000021CB82893FA66140E5D022DBF96C4A4021CB82893FA6614079AD84EE926E4A403C86C77E16A7614079AD84EE926E4A403C86C77E16A76140E5D022DBF96C4A4021CB82893FA66140E5D022DBF96C4A40
17212	Нигирь	4	37	911	141.27849399999999	141.31485799999999	52.124529000000003	52.112496	0103000020E610000001000000050000003BC43F6CE9A861402577D844660E4A403BC43F6CE9A86140A933F790F00F4A40499C155113AA6140A933F790F00F4A40499C155113AA61402577D844660E4A403BC43F6CE9A861402577D844660E4A40
17006	Многовершинный	4	37	911	139.89010300000001	139.94605899999999	53.943679000000003	53.925978999999998	0103000020E610000001000000050000004A6249B97B7C614032E4D87A86F64A404A6249B97B7C614004763579CAF84A40C422861D467E614004763579CAF84A40C422861D467E614032E4D87A86F64A404A6249B97B7C614032E4D87A86F64A40
16748	Маго	4	37	911	140.13344699999999	140.21090899999999	53.27496	53.246692000000003	0103000020E61000000100000005000000FA97A43245846140A9177C9A939F4A40FA97A43245846140A5DAA7E331A34A40D32D3BC4BF866140A5DAA7E331A34A40D32D3BC4BF866140A9177C9A939F4A40FA97A43245846140A9177C9A939F4A40
17133	Лазарев	4	37	911	141.50176999999999	141.531361	52.228532000000001	52.204684999999998	0103000020E61000000100000005000000A583F57F0EB06140AA7D3A1E331A4A40A583F57F0EB06140740B5D89401D4A40D6ABC8E800B16140740B5D89401D4A40D6ABC8E800B16140AA7D3A1E331A4A40A583F57F0EB06140AA7D3A1E331A4A40
16615	Красное	4	37	911	140.838616	140.878681	53.129148000000001	53.098274000000004	0103000020E61000000100000005000000E0BC38F1D59A61400806103E948C4A40E0BC38F1D59A6140022CF2EB87904A40BBD39D271E9C6140022CF2EB87904A40BBD39D271E9C61400806103E948C4A40E0BC38F1D59A61400806103E948C4A40
17041	Константиновка	4	37	911	140.77229299999999	140.789963	53.086717999999998	53.074764000000002	0103000020E61000000100000005000000C03DCF9FB69861408675E3DD91894A40C03DCF9FB6986140BDFC4E93198B4A409A417C6047996140BDFC4E93198B4A409A417C60479961408675E3DD91894A40C03DCF9FB69861408675E3DD91894A40
16706	Иннокентьевка	4	37	911	140.311035	140.33372700000001	53.237402000000003	53.226227999999999	0103000020E610000001000000050000002A1DACFFF389614041B8020AF59C4A402A1DACFFF3896140A4005130639E4A405AD93EE4AD8A6140A4005130639E4A405AD93EE4AD8A614041B8020AF59C4A402A1DACFFF389614041B8020AF59C4A40
28833	Троицкое	4	37	1843	136.51595900000001	136.582075	49.449967000000001	49.429465	0103000020E6100000010000000500000076E272BC8210614069E388B5F8B6484076E272BC82106140BEA3C68498B94840371AC05BA0126140BEA3C68498B94840371AC05BA012614069E388B5F8B6484076E272BC8210614069E388B5F8B64840
29048	Славянка	4	37	1843	136.76552899999999	136.790663	49.472141999999998	49.465755000000001	0103000020E610000001000000050000007764AC367F18614068791EDC9DBB48407764AC367F186140B58828266FBC484008E57D1C4D196140B58828266FBC484008E57D1C4D19614068791EDC9DBB48407764AC367F18614068791EDC9DBB4840
28410	Синда	4	37	1843	136.27248800000001	136.31499700000001	48.974820000000001	48.946089999999998	0103000020E61000000100000005000000AE11C138B80861404C89247A19794840AE11C138B80861404DBED9E6C67C4840D2AA9674140A61404DBED9E6C67C4840D2AA9674140A61404C89247A19794840AE11C138B80861404C89247A19794840
28672	Нижняя Манома	4	37	1843	136.62284	136.63702499999999	49.330925999999998	49.323498000000001	0103000020E6100000010000000500000080D4264EEE1361402429E96168A9484080D4264EEE136140B3B27DC85BAA484080B7408262146140B3B27DC85BAA484080B74082621461402429E96168A9484080D4264EEE1361402429E96168A94840
28593	Найхин	4	37	1843	136.459464	136.473837	49.296385999999998	49.272486000000001	0103000020E610000001000000050000000FB6D8EDB30E6140164F3DD2E0A248400FB6D8EDB30E6140027FF8F9EFA54840505436AC290F6140027FF8F9EFA54840505436AC290F6140164F3DD2E0A248400FB6D8EDB30E6140164F3DD2E0A24840
28327	Маяк	4	37	1843	136.23101299999999	136.25613899999999	48.925708	48.906146	0103000020E610000001000000050000006DFE5F75640761405BB39597FC7348406DFE5F7564076140A2D288997D7648405D876A4A32086140A2D288997D7648405D876A4A320861405BB39597FC7348406DFE5F75640761405BB39597FC734840
29087	Лидога	4	37	1843	136.883397	136.914254	49.514074000000001	49.501795000000001	0103000020E610000001000000050000004E0CC9C9441C6140EE258DD13AC048404E0CC9C9441C6140A9DC442DCDC1484097C79A91411D6140A9DC442DCDC1484097C79A91411D6140EE258DD13AC048404E0CC9C9441C6140EE258DD13AC04840
29190	Иннокентьевка	4	37	1843	136.88599300000001	136.916077	49.694873999999999	49.666347000000002	0103000020E6100000010000000500000085EFFD0D5A1C6140D464C6DB4AD5484085EFFD0D5A1C61409C6B98A1F1D84840C573B680501D61409C6B98A1F1D84840C573B680501D6140D464C6DB4AD5484085EFFD0D5A1C6140D464C6DB4AD54840
61764	Дубовый Мыс	4	37	1843	136.49204499999999	136.50666100000001	49.114297000000001	49.095275000000001	0103000020E6100000010000000500000021E527D5BE0F61402E90A0F8318C484021E527D5BE0F6140F583BA48A18E48401425219136106140F583BA48A18E484014252191361061402E90A0F8318C484021E527D5BE0F61402E90A0F8318C4840
29148	Джонка	4	37	1843	136.92701	136.96492799999999	49.681294000000001	49.659407999999999	0103000020E610000001000000050000001422E010AA1D6140425C397B67D448401422E010AA1D6140037B4CA434D74840D45FAFB0E01E6140037B4CA434D74840D45FAFB0E01E6140425C397B67D448401422E010AA1D6140425C397B67D44840
28606	Джари	4	37	1843	136.509221	136.516929	49.441040999999998	49.435791999999999	0103000020E61000000100000005000000F7ADD6894B106140E1ED4108C8B74840F7ADD6894B106140FA980F0874B8484054ABAFAE8A106140FA980F0874B8484054ABAFAE8A106140E1ED4108C8B74840F7ADD6894B106140E1ED4108C8B74840
28533	Даерга	4	37	1843	136.465294	136.48074500000001	49.270564	49.257053999999997	0103000020E61000000100000005000000CD203EB0E30E61402AA73D25E7A04840CD203EB0E30E6140CBBC55D7A1A24840E6965643620F6140CBBC55D7A1A24840E6965643620F61402AA73D25E7A04840CD203EB0E30E61402AA73D25E7A04840
28507	Дада	4	37	1843	136.46512300000001	136.47975700000001	49.175333000000002	49.162073999999997	0103000020E61000000100000005000000C233A149E20E614015C440D7BE944840C233A149E20E61406D74CE4F71964840DE205A2B5A0F61406D74CE4F71964840DE205A2B5A0F614015C440D7BE944840C233A149E20E614015C440D7BE944840
28734	Верхняя Манома	4	37	1843	137.06726399999999	137.08543700000001	49.327626000000002	49.318348999999998	0103000020E610000001000000050000005706D506272261406EDBF7A8BFA848405706D50627226140DFA815A6EFA94840CA1B60E6BB226140DFA815A6EFA94840CA1B60E6BB2261406EDBF7A8BFA848405706D506272261406EDBF7A8BFA84840
29225	Верхний Нерген	4	37	1843	136.77652399999999	136.81365099999999	49.851058000000002	49.837057999999999	0103000020E61000000100000005000000E411DC48D9186140766D6FB724EB4840E411DC48D9186140E57FF277EFEC4840726BD26D091A6140E57FF277EFEC4840726BD26D091A6140766D6FB724EB4840E411DC48D9186140766D6FB724EB4840
28768	Арсеньево	4	37	1843	137.060733	137.09156300000001	49.221057000000002	49.208450999999997	0103000020E6100000010000000500000037195586F1216140C4E8B985AE9A484037195586F1216140A4C684984B9C4840C2508715EE226140A4C684984B9C4840C2508715EE226140C4E8B985AE9A484037195586F1216140C4E8B985AE9A4840
50489	Хабаровск	4	37	7080	134.97636299999999	135.18267	48.599291000000001	48.516928	0103000020E61000000100000005000000C8409E5D3EDF60407F315BB22A424840C8409E5D3EDF6040C1E44691B54C4840BB7EC16ED8E56040C1E44691B54C4840BB7EC16ED8E560407F315BB22A424840C8409E5D3EDF60407F315BB22A424840
25108	Ягодный	4	37	620	138.42271400000001	138.440303	51.074815000000001	51.061616000000001	0103000020E61000000100000005000000F7B182DF864D614086747808E3874940F7B182DF864D61400820B58993894940952A51F6164E61400820B58993894940952A51F6164E614086747808E3874940F7B182DF864D614086747808E3874940
25430	Хурба	4	37	620	136.840125	136.90018599999999	50.419280999999998	50.394508999999999	0103000020E61000000100000005000000AAF1D24DE21A6140247D5A457F324940AAF1D24DE21A6140C66AF3FFAA35494025CADE52CE1C6140C66AF3FFAA35494025CADE52CE1C6140247D5A457F324940AAF1D24DE21A6140247D5A457F324940
24943	Уктур	4	37	620	138.476011	138.49540500000001	50.345362000000002	50.335065999999998	0103000020E6100000010000000500000029B16B7B3B4F614032005471E32A494029B16B7B3B4F6140FDA36FD2342C4940CC28965BDA4F6140FDA36FD2342C4940CC28965BDA4F614032005471E32A494029B16B7B3B4F614032005471E32A4940
24867	Снежный	4	37	620	137.911923	137.961411	50.277264000000002	50.257075999999998	0103000020E610000001000000050000000CAF24792E3D6140124BCADDE72049400CAF24792E3D6140D82D02637D234940786000E1C33E6140D82D02637D234940786000E1C33E6140124BCADDE72049400CAF24792E3D6140124BCADDE7204940
25827	Селихино	4	37	620	137.472691	137.53684000000001	50.375342000000003	50.351950000000002	0103000020E61000000100000005000000A243E048202F6140E2E995B20C2D4940A243E048202F61405A68E7340B304940E96514CB2D3161405A68E7340B304940E96514CB2D316140E2E995B20C2D4940A243E048202F6140E2E995B20C2D4940
50477	Поселок Бельго	4	37	620	137.24467200000001	137.276544	50.655465	50.644705000000002	0103000020E61000000100000005000000E7C75F5AD4276140AA4885B185524940E7C75F5AD42761401956F146E6534940F67CCD72D92861401956F146E6534940F67CCD72D9286140AA4885B185524940E7C75F5AD4276140AA4885B185524940
25686	Пивань-Пристань	4	37	620	137.05960099999999	137.114497	50.513427999999998	50.470781000000002	0103000020E61000000100000005000000E2395B40E8216140024A438D423C4940E2395B40E8216140E36C3A02B8414940AFCF9CF5A9236140E36C3A02B8414940AFCF9CF5A9236140024A438D423C4940E2395B40E8216140024A438D423C4940
25586	Новый Мир	4	37	620	136.956726	136.983271	50.463206999999997	50.441733999999997	0103000020E610000001000000050000007427D87F9D1E614000C45DBD8A3849407427D87F9D1E61409E23F25D4A3B49405E83BEF4761F61409E23F25D4A3B49405E83BEF4761F614000C45DBD8A3849407427D87F9D1E614000C45DBD8A384940
25018	Новоильиновка	4	37	620	138.620397	138.630539	51.182727999999997	51.176414999999999	0103000020E610000001000000050000002B31CF4ADA5361400DC347C4949649402B31CF4ADA536140200890A16397494048FB1F602D546140200890A16397494048FB1F602D5461400DC347C4949649402B31CF4ADA5361400DC347C494964940
25191	Нижние Халбы	4	37	620	137.91999799999999	137.93190100000001	50.799947000000003	50.793411999999996	0103000020E61000000100000005000000554CA59F703D6140812040868E654940554CA59F703D614044C4CDA96466494083C30B22D23D614044C4CDA96466494083C30B22D23D6140812040868E654940554CA59F703D6140812040868E654940
25145	Нижнетамбовское	4	37	620	138.176602	138.19946400000001	50.931641999999997	50.906464999999997	0103000020E6100000010000000500000010CD3CB9A6456140FCFB8C0B0774494010CD3CB9A64561403ECA880B4077494057975302624661403ECA880B407749405797530262466140FCFB8C0B0774494010CD3CB9A6456140FCFB8C0B07744940
25527	Молодежный	4	37	620	136.93246300000001	136.95949300000001	50.386296000000002	50.370728999999997	0103000020E610000001000000050000005D37A5BCD61D6140E256410C742F49405D37A5BCD61D6140AE49B72572314940B6F7A92AB41E6140AE49B72572314940B6F7A92AB41E6140E256410C742F49405D37A5BCD61D6140E256410C742F4940
5366	Комсомольск-на-Амуре	4	37	620	136.86117200000001	137.15650199999999	50.699987	50.516188	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
24952	Кенай	4	37	620	138.578508	138.60357999999999	50.199005999999997	50.184859000000003	0103000020E610000001000000050000002E8F35238352614086AFAF75A91749402E8F35238352614098DA520779194940A11001875053614098DA520779194940A11001875053614086AFAF75A91749402E8F35238352614086AFAF75A9174940
24785	Даппы	4	37	620	137.378162	137.397727	50.195010000000003	50.181992999999999	0103000020E61000000100000005000000E1D231E7192C6140EB8CEF8B4B174940E1D231E7192C61404D327216F61849408F37F92DBA2C61404D327216F61849408F37F92DBA2C6140EB8CEF8B4B174940E1D231E7192C6140EB8CEF8B4B174940
24883	Гурское	4	37	620	138.080195	138.12707800000001	50.326469000000003	50.304456000000002	0103000020E61000000100000005000000B0C91AF5904261401689096AF8264940B0C91AF590426140341477BCC929494051C1E10511446140341477BCC929494051C1E105114461401689096AF8264940B0C91AF5904261401689096AF8264940
25336	Галичный	4	37	620	137.192273	137.21296100000001	50.728178999999997	50.709553	0103000020E61000000100000005000000ECDCB41927266140ACE3F8A1D25A4940ECDCB4192726614026512FF8345D49405A4A9693D026614026512FF8345D49405A4A9693D0266140ACE3F8A1D25A4940ECDCB41927266140ACE3F8A1D25A4940
7927	Гайтер	4	37	620	137.223175	137.26113799999999	50.379449999999999	50.352983999999999	0103000020E610000001000000050000001DC9E53F24276140710168942E2D49401DC9E53F24276140CD3B4ED191304940C537143E5B286140CD3B4ED191304940C537143E5B286140710168942E2D49401DC9E53F24276140710168942E2D4940
25629	Верхняя Эконь	4	37	620	137.07649799999999	137.08873299999999	50.430236000000001	50.417869000000003	0103000020E61000000100000005000000B306EFAB7222614091813CBB7C354940B306EFAB72226140EBC726F9113749406EA296E6D6226140EBC726F9113749406EA296E6D622614091813CBB7C354940B306EFAB7222614091813CBB7C354940
25230	Верхнетамбовское	4	37	620	137.39103399999999	137.408354	50.671863000000002	50.663237000000002	0103000020E61000000100000005000000F833BC59832C6140A33F34F3E4544940F833BC59832C61403C32569BFF5549401B66683C112D61403C32569BFF5549401B66683C112D6140A33F34F3E4544940F833BC59832C6140A33F34F3E4544940
5849	Большая Картель	4	37	620	137.365846	137.40232599999999	50.395772000000001	50.376714999999997	0103000020E61000000100000005000000EBABAB02B52B6140D174763238304940EBABAB02B52B614015562AA8A8324940938AC6DADF2C614015562AA8A8324940938AC6DADF2C6140D174763238304940EBABAB02B52B6140D174763238304940
25393	Боктор	4	37	620	137.40196700000001	137.41730100000001	51.100093000000001	51.09205	0103000020E6100000010000000500000048E2E5E9DC2C614064CC5D4BC88B494048E2E5E9DC2C61407EC7F0D8CF8C4940D272A0875A2D61407EC7F0D8CF8C4940D272A0875A2D614064CC5D4BC88B494048E2E5E9DC2C614064CC5D4BC88B4940
50482	Хабаровск	4	37	7079	134.943296	135.071405	48.524191000000002	48.469448	0103000020E6100000010000000500000053CE177B2FDE604018963FDF163C484053CE177B2FDE6040C4EDD0B018434840AB7823F348E26040C4EDD0B018434840AB7823F348E2604018963FDF163C484053CE177B2FDE604018963FDF163C4840
30036	имени Полины Осипенко	4	37	1885	136.467602	136.515366	52.435225000000003	52.408302999999997	0103000020E610000001000000050000006A317898F60E6140E9EDCF4543344A406A317898F60E614068B3EA73B5374A400D6FD6E07D10614068B3EA73B5374A400D6FD6E07D106140E9EDCF4543344A406A317898F60E6140E9EDCF4543344A40
50481	Удинск	4	37	1885	138.84538000000001	138.86873600000001	52.907943000000003	52.902935999999997	0103000020E6100000010000000500000029965B5A0D5B6140C630276893734A4029965B5A0D5B6140EAD0E97937744A40749B70AFCC5B6140EAD0E97937744A40749B70AFCC5B6140C630276893734A4029965B5A0D5B6140C630276893734A40
50479	Бриакан	4	37	1885	135.81780599999999	135.85297499999999	52.327717999999997	52.303097999999999	0103000020E610000001000000050000001F0F7D772BFA6040D3BD4EEACB264A401F0F7D772BFA6040BF27D6A9F2294A40C7293A924BFB6040BF27D6A9F2294A40C7293A924BFB6040D3BD4EEACB264A401F0F7D772BFA6040D3BD4EEACB264A40
27791	Южный	4	37	661	135.59532899999999	135.60513	47.116630000000001	47.107559999999999	0103000020E61000000100000005000000882B67EF0CF36040CB2DAD86C48D4740882B67EF0CF36040C2DD59BBED8E474083FA96395DF36040C2DD59BBED8E474083FA96395DF36040CB2DAD86C48D4740882B67EF0CF36040CB2DAD86C48D4740
26440	Черняево	4	37	661	134.67576	134.705772	48.011736999999997	48.000354999999999	0103000020E610000001000000050000003D7E6FD39FD56040EEB1F4A10B0048403D7E6FD39FD560409A93179980014840D74D29AF95D660409A93179980014840D74D29AF95D66040EEB1F4A10B0048403D7E6FD39FD56040EEB1F4A10B004840
50454	Хака	4	37	661	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
25851	Сукпай	4	37	661	136.77251699999999	136.837277	48.005443	47.9666	0103000020E6100000010000000500000054539275B818614024287E8CB9FB474054539275B8186140FE7E315BB20048402D9622F9CA1A6140FE7E315BB20048402D9622F9CA1A614024287E8CB9FB474054539275B818614024287E8CB9FB4740
27935	Среднехорский	4	37	661	136.21442099999999	136.24623	47.682146000000003	47.673184999999997	0103000020E610000001000000050000006BD26D89DC066140319413ED2AD647406BD26D89DC066140728C648F50D7474069A9BC1DE1076140728C648F50D7474069A9BC1DE1076140319413ED2AD647406BD26D89DC066140319413ED2AD64740
27877	Солонцовый	4	37	661	136.08731	136.09985900000001	47.157865000000001	47.146185000000003	0103000020E61000000100000005000000A453573ECB0261403815A930B6924740A453573ECB0261406E179AEB34944740C366800B320361406E179AEB34944740C366800B320361403815A930B6924740A453573ECB0261403815A930B6924740
27185	Соколовка	4	37	661	135.373436	135.40778800000001	48.013309999999997	47.995308999999999	0103000020E61000000100000005000000C5E40D30F3EB60400D350A4966FF4740C5E40D30F3EB6040D95A5F24B401484071766B990CED6040D95A5F24B401484071766B990CED60400D350A4966FF4740C5E40D30F3EB60400D350A4966FF4740
28081	Сита	4	37	661	135.38634500000001	135.450952	48.146939000000003	48.116962000000001	0103000020E61000000100000005000000247F30F05CEC6040F86F5E9CF80E4840247F30F05CEC6040E4C0ABE5CE1248401B82E3326EEE6040E4C0ABE5CE1248401B82E3326EEE6040F86F5E9CF80E4840247F30F05CEC6040F86F5E9CF80E4840
28314	Сидима	4	37	661	136.02249599999999	136.05930000000001	48.132966000000003	48.106054999999998	0103000020E610000001000000050000004E098849B8006140E449D235930D48404E098849B80061406FBDA60705114840E4141DC9E50161406FBDA60705114840E4141DC9E5016140E449D235930D48404E098849B8006140E449D235930D4840
27460	Святогорье	4	37	661	135.398966	135.44282200000001	47.863242	47.843215999999998	0103000020E61000000100000005000000E9465854C4EC604062BB7B80EEEB4740E9465854C4EC60404E44BFB67EEE474061FE0A992BEE60404E44BFB67EEE474061FE0A992BEE604062BB7B80EEEB4740E9465854C4EC604062BB7B80EEEB4740
4496	Прудки	4	37	661	135.61492999999999	135.63110900000001	47.873578000000002	47.864342000000001	0103000020E6100000010000000500000089EAAD81ADF36040954737C2A2EE474089EAAD81ADF36040A7406667D1EF4740C366800B32F46040A7406667D1EF4740C366800B32F46040954737C2A2EE474089EAAD81ADF36040954737C2A2EE4740
27330	Полетное	4	37	661	135.583687	135.61483200000001	47.909109999999998	47.887132000000001	0103000020E6100000010000000500000036035C90ADF26040179E978A8DF1474036035C90ADF26040B83B6BB75DF44740199128B4ACF36040B83B6BB75DF44740199128B4ACF36040179E978A8DF1474036035C90ADF26040179E978A8DF14740
27327	Петровичи	4	37	661	135.53063299999999	135.55086299999999	47.947603999999998	47.923301000000002	0103000020E61000000100000005000000B5A50EF2FAF060409BAE27BA2EF64740B5A50EF2FAF0604086C77E164BF94740723271ABA0F1604086C77E164BF94740723271ABA0F160409BAE27BA2EF64740B5A50EF2FAF060409BAE27BA2EF64740
50412	Переяславка-2	4	37	661	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
26090	Переяславка	4	37	661	135.03562500000001	135.121486	47.983488999999999	47.948703000000002	0103000020E61000000100000005000000713D0AD723E16040FD4E93196FF94740713D0AD723E16040E57CB1F7E2FD4740809D9B36E3E36040E57CB1F7E2FD4740809D9B36E3E36040FD4E93196FF94740713D0AD723E16040FD4E93196FF94740
28164	Обор	4	37	661	135.66415799999999	135.710781	48.113419	48.080002999999998	0103000020E610000001000000050000000E2C47C840F560407B4ACE893D0A48400E2C47C840F560405DDF8783840E4840C8B3CBB7BEF660405DDF8783840E4840C8B3CBB7BEF660407B4ACE893D0A48400E2C47C840F560407B4ACE893D0A4840
26918	Новостройка	4	37	661	134.93325300000001	134.97825800000001	47.858145	47.841540999999999	0103000020E610000001000000050000009B3C6535DDDD60401F9F909DB7EB47409B3C6535DDDD6040EB1C03B2D7ED47409DA1B8E34DDF6040EB1C03B2D7ED47409DA1B8E34DDF60401F9F909DB7EB47409B3C6535DDDD60401F9F909DB7EB4740
26505	Невельское	4	37	661	134.669085	134.677233	48.120517	48.107444999999998	0103000020E61000000100000005000000D027F22469D56040328FFCC1C00D4840D027F22469D5604057CEDE196D0F4840B4588AE4ABD5604057CEDE196D0F4840B4588AE4ABD56040328FFCC1C00D4840D027F22469D56040328FFCC1C00D4840
25982	Мухен	4	37	661	136.09305900000001	136.15683899999999	48.211446000000002	48.184618999999998	0103000020E610000001000000050000002733DE56FA026140309C6B98A11748402733DE56FA0261405D6F9BA9101B484098F738D3040561405D6F9BA9101B484098F738D304056140309C6B98A11748402733DE56FA026140309C6B98A1174840
26325	Могилевка	4	37	661	134.92489900000001	134.966329	47.976481	47.960203999999997	0103000020E610000001000000050000004DA3C9C598DD604083BEF4F6E7FA47404DA3C9C598DD60402B155454FDFC4740A585CB2AECDE60402B155454FDFC4740A585CB2AECDE604083BEF4F6E7FA47404DA3C9C598DD604083BEF4F6E7FA4740
27249	Марусино	4	37	661	135.44915499999999	135.47534099999999	47.981270000000002	47.961773000000001	0103000020E61000000100000005000000B77A4E7A5FEE60408196AE601BFB4740B77A4E7A5FEE6040E1455F419AFD4740552E54FE35EF6040E1455F419AFD4740552E54FE35EF60408196AE601BFB4740B77A4E7A5FEE60408196AE601BFB4740
27708	Кутузовка	4	37	661	135.70026999999999	135.73579000000001	47.700184	47.680925999999999	0103000020E61000000100000005000000D68BA19C68F66040807F4A9528D74740D68BA19C68F660405B971AA19FD947402A5778978BF760405B971AA19FD947402A5778978BF76040807F4A9528D74740D68BA19C68F66040807F4A9528D74740
28005	Кругликово	4	37	661	135.11190099999999	135.13599400000001	48.113461000000001	48.093978	0103000020E6100000010000000500000078EC67B194E3604091459A78070C484078EC67B194E360408C2FDAE3850E484079CE16105AE460408C2FDAE3850E484079CE16105AE4604091459A78070C484078EC67B194E3604091459A78070C4840
26881	Кондратьевка	4	37	661	134.97951599999999	135.010751	47.858942999999996	47.849831999999999	0103000020E61000000100000005000000143DF03158DF6040118C834BC7EC4740143DF03158DF604066101FD8F1ED4740C72C7B1258E0604066101FD8F1ED4740C72C7B1258E06040118C834BC7EC4740143DF03158DF6040118C834BC7EC4740
27508	Кия	4	37	661	135.62841399999999	135.64784499999999	47.835583999999997	47.821658999999997	0103000020E61000000100000005000000274BADF71BF4604066BB421F2CE94740274BADF71BF46040CA87A06AF4EA474011FC6F25BBF46040CA87A06AF4EA474011FC6F25BBF4604066BB421F2CE94740274BADF71BF4604066BB421F2CE94740
26377	Киинск	4	37	661	134.82231100000001	134.835983	47.994433999999998	47.977240999999999	0103000020E610000001000000050000008484285F50DA6040B9A7AB3B16FD47408484285F50DA6040E603029D49FF474062A06B5FC0DA6040E603029D49FF474062A06B5FC0DA6040B9A7AB3B16FD47408484285F50DA6040B9A7AB3B16FD4740
27832	Катэн	4	37	661	136.09145100000001	136.10061400000001	47.397092000000001	47.389394000000003	0103000020E61000000100000005000000F8C5A52AED0261401BA19FA9D7B14740F8C5A52AED0261406AC020E9D3B24740A2F0D93A380361406AC020E9D3B24740A2F0D93A380361401BA19FA9D7B14740F8C5A52AED0261401BA19FA9D7B14740
28142	Золотой	4	37	661	136.379639	136.41363200000001	48.068756999999998	48.054665999999997	0103000020E610000001000000050000002829B000260C6140001AA54BFF0648402829B000260C61407F2F8507CD08484088122D793C0D61407F2F8507CD08484088122D793C0D6140001AA54BFF0648402829B000260C6140001AA54BFF064840
28048	Зоевка	4	37	661	135.11648199999999	135.13585900000001	48.067883999999999	48.061518999999997	0103000020E6100000010000000500000053927538BAE36040938AC6DADF07484053927538BAE36040F9F5436CB0084840C13BF9F458E46040F9F5436CB0084840C13BF9F458E46040938AC6DADF07484053927538BAE36040938AC6DADF074840
50963	Екатеринославка	4	37	661	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
28248	Дурмин	4	37	661	135.822091	135.86810299999999	48.094448	48.077998000000001	0103000020E61000000100000005000000C0EAC8914EFA6040A393A5D6FB094840C0EAC8914EFA604018963FDF160C4840E751F17FC7FB604018963FDF160C4840E751F17FC7FB6040A393A5D6FB094840C0EAC8914EFA6040A393A5D6FB094840
26808	Дрофа	4	37	661	135.00130899999999	135.02665999999999	47.887397999999997	47.88364	0103000020E6100000010000000500000018062CB90AE06040FEB7921D1BF1474018062CB90AE060409544F64196F1474090831266DAE060409544F64196F1474090831266DAE06040FEB7921D1BF1474018062CB90AE06040FEB7921D1BF14740
27718	Долми	4	37	661	135.615362	135.629986	47.380426	47.369349999999997	0103000020E610000001000000050000007026A60BB1F3604088635DDC46AF47407026A60BB1F36040284696CCB1B04740035E66D828F46040284696CCB1B04740035E66D828F4604088635DDC46AF47407026A60BB1F3604088635DDC46AF4740
26314	Гродеково	4	37	661	134.99685400000001	135.02567199999999	47.971462000000002	47.941110000000002	0103000020E61000000100000005000000611C5C3AE6DF604023F8DF4A76F84740611C5C3AE6DF604044A7E7DD58FC4740880D164ED2E0604044A7E7DD58FC4740880D164ED2E0604023F8DF4A76F84740611C5C3AE6DF604023F8DF4A76F84740
27002	Георгиевка	4	37	661	135.230874	135.28949800000001	47.967576999999999	47.949572000000003	0103000020E61000000100000005000000E5EFDE5163E76040429946938BF94740E5EFDE5163E760404FAE2990D9FB47403D484F9143E960404FAE2990D9FB47403D484F9143E96040429946938BF94740E5EFDE5163E76040429946938BF94740
27957	Гвасюги	4	37	661	136.17590999999999	136.18817200000001	47.673105999999997	47.660842000000002	0103000020E610000001000000050000004221020EA105614060E97C7896D447404221020EA1056140E55E605628D64740BC40498105066140E55E605628D64740BC4049810506614060E97C7896D447404221020EA105614060E97C7896D44740
27222	Васильевка	4	37	661	135.448185	135.46302499999999	47.904429	47.890546000000001	0103000020E61000000100000005000000D9B1118857EE6040B4CA4C69FDF14740D9B1118857EE6040E9465854C4F347405F07CE19D1EE6040E9465854C4F347405F07CE19D1EE6040B4CA4C69FDF14740D9B1118857EE6040B4CA4C69FDF14740
27553	Бичевая	4	37	661	135.61096000000001	135.645464	47.798434	47.758094999999997	0103000020E610000001000000050000004165FCFB8CF360406C21C84109E147404165FCFB8CF36040DA01D71533E64740DA571EA4A7F46040DA01D71533E64740DA571EA4A7F460406C21C84109E147404165FCFB8CF360406C21C84109E14740
55348	База-Дрофа	4	37	661	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
24185	Шумный	4	37	658	134.97542000000001	134.99387100000001	47.285044999999997	47.273325999999997	0103000020E61000000100000005000000A9FB00A436DF6040C092AB58FCA24740A9FB00A436DF6040B471C45A7CA447402C2E8ECACDDF6040B471C45A7CA447402C2E8ECACDDF6040C092AB58FCA24740A9FB00A436DF6040C092AB58FCA24740
50951	Шереметьево	4	37	658	134.25298599999999	134.26691	47.369131000000003	47.358851999999999	0103000020E61000000100000005000000118B187618C86040560DC2DCEEAD4740118B187618C860404B7842AF3FAF4740361FD7868AC860404B7842AF3FAF4740361FD7868AC86040560DC2DCEEAD4740118B187618C86040560DC2DCEEAD4740
23791	Отрадное	4	37	658	134.68708799999999	134.714944	47.507134999999998	47.480682000000002	0103000020E610000001000000050000002B2FF99FFCD5604050E3DEFC86BD47402B2FF99FFCD5604017D4B7CCE9C04740164F3DD2E0D6604017D4B7CCE9C04740164F3DD2E0D6604050E3DEFC86BD47402B2FF99FFCD5604050E3DEFC86BD4740
24170	Медвежий	4	37	658	135.20166900000001	135.212422	47.35754	47.349854000000001	0103000020E61000000100000005000000BFF38B1274E66040F92F1004C8AC4740BFF38B1274E660408481E7DEC3AD47406EDE3829CCE660408481E7DEC3AD47406EDE3829CCE66040F92F1004C8AC4740BFF38B1274E66040F92F1004C8AC4740
4463	Кукелево	4	37	658	134.76066900000001	134.77549099999999	47.766731999999998	47.752879	0103000020E6100000010000000500000098C2836657D860402F6CCD565EE0474098C2836657D86040F965304624E24740F46A80D2D0D86040F965304624E24740F46A80D2D0D860402F6CCD565EE0474098C2836657D860402F6CCD565EE04740
23899	Красицкое	4	37	658	134.84383500000001	134.89376300000001	47.649510999999997	47.633696	0103000020E610000001000000050000000C0742B200DB604092CD55F31CD147400C0742B200DB604035B22B2D23D34740FFEBDCB499DC604035B22B2D23D34740FFEBDCB499DC604092CD55F31CD147400C0742B200DB604092CD55F31CD14740
23691	Котиково	4	37	658	134.50746000000001	134.584464	47.425764999999998	47.405503000000003	0103000020E61000000100000005000000E700C11C3DD0604007B7B585E7B34740E700C11C3DD060400664AF777FB647400FB6D8EDB3D260400664AF777FB647400FB6D8EDB3D2604007B7B585E7B34740E700C11C3DD0604007B7B585E7B34740
23604	Кедрово	4	37	658	134.35361499999999	134.377205	47.433396999999999	47.424002999999999	0103000020E61000000100000005000000008C67D050CB6040F433F5BA45B64740008C67D050CB60409E978A8D79B74740685C381012CC60409E978A8D79B74740685C381012CC6040F433F5BA45B64740008C67D050CB6040F433F5BA45B64740
24103	Капитоновка	4	37	658	135.05227099999999	135.07824099999999	47.678463000000001	47.664472000000004	0103000020E61000000100000005000000EF703B34ACE16040CA8D226B0DD54740EF703B34ACE16040E54526E0D7D647409A0645F380E26040E54526E0D7D647409A0645F380E26040CA8D226B0DD54740EF703B34ACE16040CA8D226B0DD54740
7890	Забайкальское	4	37	658	134.67947899999999	134.69522599999999	47.621009999999998	47.605459000000003	0103000020E61000000100000005000000336ABE4ABED56040D10836AE7FCD4740336ABE4ABED56040963E74417DCF474086AA984A3FD66040963E74417DCF474086AA984A3FD66040D10836AE7FCD4740336ABE4ABED56040D10836AE7FCD4740
24058	Дормидонтовка	4	37	658	134.88279399999999	134.927378	47.778868000000003	47.760415000000002	0103000020E610000001000000050000005CE333D93FDC6040A5315A4755E147405CE333D93FDC604052F355F2B1E34740F5A0A014ADDD604052F355F2B1E34740F5A0A014ADDD6040A5315A4755E147405CE333D93FDC6040A5315A4755E14740
23955	Дормидонтовка	4	37	658	134.90928600000001	134.922572	47.718755000000002	47.704161999999997	0103000020E61000000100000005000000BE16F4DE18DD6040008BFCFA21DA4740BE16F4DE18DD6040126BF12900DC47409206B7B585DD6040126BF12900DC47409206B7B585DD6040008BFCFA21DA4740BE16F4DE18DD6040008BFCFA21DA4740
23481	Глебово	4	37	658	134.35604000000001	134.37185099999999	47.259611	47.252332000000003	0103000020E610000001000000050000002C82FFAD64CB6040FDDD3B6A4CA047402C82FFAD64CB60404757E9EE3AA14740847F1134E6CB60404757E9EE3AA14740847F1134E6CB6040FDDD3B6A4CA047402C82FFAD64CB6040FDDD3B6A4CA04740
24302	Вяземский	4	37	658	134.721394	134.793745	47.564903000000001	47.512205000000002	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
23629	Виноградовка	4	37	658	134.49169499999999	134.502565	47.440229000000002	47.424936000000002	0103000020E610000001000000050000006A1327F7BBCF60405072874D64B647406A1327F7BBCF60401AE0826C59B84740A8E3310315D060401AE0826C59B84740A8E3310315D060405072874D64B647406A1327F7BBCF60405072874D64B64740
23422	Видное	4	37	658	134.16141099999999	134.17180500000001	47.243285	47.236648000000002	0103000020E61000000100000005000000DEC666472AC56040F8544E7B4A9E4740DEC666472AC56040BE4D7FF6239F47404209336D7FC56040BE4D7FF6239F47404209336D7FC56040F8544E7B4A9E4740DEC666472AC56040F8544E7B4A9E4740
23725	Венюково	4	37	658	134.56799799999999	134.58487700000001	47.488177999999998	47.472490000000001	0103000020E610000001000000050000003046240A2DD26040F1D7648D7ABC47403046240A2DD260403750E09D7CBE4740D865F84FB7D260403750E09D7CBE4740D865F84FB7D26040F1D7648D7ABC47403046240A2DD26040F1D7648D7ABC4740
23768	Аван	4	37	658	134.64536100000001	134.669669	47.486387000000001	47.475816000000002	0103000020E61000000100000005000000A5A31CCCA6D46040EF74E789E7BC4740A5A31CCCA6D460408B19E1ED41BE4740A4C4AEED6DD560408B19E1ED41BE4740A4C4AEED6DD56040EF74E789E7BC4740A5A31CCCA6D46040EF74E789E7BC4740
22922	Этыркэн	4	37	948	131.52346399999999	131.53256400000001	51.525145999999999	51.519889999999997	0103000020E6100000010000000500000044149337C07060403BC269C18BC2494044149337C070604007D0EFFB37C34940DD60A8C30A71604007D0EFFB37C34940DD60A8C30A7160403BC269C18BC2494044149337C07060403BC269C18BC24940
23022	Эльга	4	37	948	132.29985099999999	132.31717900000001	50.849927000000001	50.835520000000002	0103000020E6100000010000000500000088D51F6198896040B493C151F26A494088D51F6198896040637E6E68CA6C49404CFF9254268A6040637E6E68CA6C49404CFF9254268A6040B493C151F26A494088D51F6198896040B493C151F26A4940
22040	Шахтинский	4	37	948	133.256449	133.26242199999999	51.635973999999997	51.631010000000003	0103000020E61000000100000005000000F18288D434A8604078B988EFC4D04940F18288D434A860409B8D959867D149400778D2C265A860409B8D959867D149400778D2C265A8604078B988EFC4D04940F18288D434A8604078B988EFC4D04940
7707	Чекунда	4	37	948	132.25061400000001	132.261942	50.873463999999998	50.860174000000001	0103000020E610000001000000050000006FBDA607058860404C6F7F2E1A6E49406FBDA60705886040DE1D19ABCD6F49405D6E30D461886040DE1D19ABCD6F49405D6E30D4618860404C6F7F2E1A6E49406FBDA607058860404C6F7F2E1A6E4940
7825	Чегдомын	4	37	948	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
23066	Ушман	4	37	948	132.24915899999999	132.28280100000001	50.420819000000002	50.406433999999997	0103000020E6100000010000000500000021904B1CF9876040C1FD80070634494021904B1CF98760408944A165DD354940D6C8AEB40C8960408944A165DD354940D6C8AEB40C896040C1FD80070634494021904B1CF9876040C1FD800706344940
22839	Усть-Ургал	4	37	948	132.51341600000001	132.524124	51.137154000000002	51.126607	0103000020E61000000100000005000000C82764E76D906040EB387EA834904940C82764E76D906040FF4124438E9149408FE1B19FC5906040FF4124438E9149408FE1B19FC5906040EB387EA834904940C82764E76D906040EB387EA834904940
7796	Тырма	4	37	948	132.122263	132.188433	50.063462999999999	50.025455999999998	0103000020E6100000010000000500000059501894E983604055BE67244203494059501894E9836040C6C03A8E1F084940978FA4A407866040C6C03A8E1F084940978FA4A40786604055BE67244203494059501894E983604055BE672442034940
22763	Сулук	4	37	948	133.56682499999999	133.59784400000001	50.659193999999999	50.644950999999999	0103000020E61000000100000005000000C4B12E6E23B26040E1421EC18D524940C4B12E6E23B2604016DC0F78605449408483BD8921B3604016DC0F78605449408483BD8921B36040E1421EC18D524940C4B12E6E23B26040E1421EC18D524940
22096	Средний Ургал	4	37	948	132.92858100000001	132.95385099999999	51.165317999999999	51.150754999999997	0103000020E61000000100000005000000FC5580EFB69D6040AF5A99F04B934940FC5580EFB69D604056B8E52329954940384888F2859E604056B8E52329954940384888F2859E6040AF5A99F04B934940FC5580EFB69D6040AF5A99F04B934940
21999	Софийск	4	37	948	133.974706	134.001924	52.260190000000001	52.251947999999999	0103000020E61000000100000005000000E126A3CA30BF6040742502D53F204A40E126A3CA30BF6040855FEAE74D214A407BA2EBC20FC06040855FEAE74D214A407BA2EBC20FC06040742502D53F204A40E126A3CA30BF6040742502D53F204A40
22731	Солони	4	37	948	133.21942000000001	133.23344299999999	50.822491999999997	50.813893	0103000020E61000000100000005000000D482177D05A76040BFB854A52D684940D482177D05A760405E9CF86A476949405D4F745D78A760405E9CF86A476949405D4F745D78A76040BFB854A52D684940D482177D05A76040BFB854A52D684940
7720	Согда	4	37	948	132.26792399999999	132.294209	50.345052000000003	50.333824	0103000020E61000000100000005000000083A5AD592886040594FADBEBA2A4940083A5AD592886040AFB5F7A92A2C49400B26FE286A896040AFB5F7A92A2C49400B26FE286A896040594FADBEBA2A4940083A5AD592886040594FADBEBA2A4940
22643	Новый Ургал	4	37	948	132.54962699999999	132.61161100000001	51.083812000000002	51.061061000000002	0103000020E61000000100000005000000F4BF5C8B96916040D107CBD8D0874940F4BF5C8B969160409581035ABA8A4940F75B3B51929360409581035ABA8A4940F75B3B5192936040D107CBD8D0874940F4BF5C8B96916040D107CBD8D0874940
22796	Герби	4	37	948	134.11337800000001	134.12313399999999	50.807268000000001	50.801364999999997	0103000020E61000000100000005000000C042E6CAA0C360405B94D92093664940C042E6CAA0C36040BD8DCD8E54674940D2E0B6B6F0C36040BD8DCD8E54674940D2E0B6B6F0C360405B94D92093664940C042E6CAA0C360405B94D92093664940
22887	Алонка	4	37	948	132.434957	132.45253700000001	51.372577999999997	51.336342999999999	0103000020E610000001000000050000005245F12AEB8D6040889E94490DAB49405245F12AEB8D6040C39ACAA2B0AF49405CE7DF2E7B8E6040C39ACAA2B0AF49405CE7DF2E7B8E6040889E94490DAB49405245F12AEB8D6040889E94490DAB4940
23299	Аланап	4	37	948	131.98125400000001	131.99896000000001	50.018042000000001	50.008420999999998	0103000020E6100000010000000500000037E2C96E667F6040C0CC77F01301494037E2C96E667F60402BFA43334F0249406440F67AF77F60402BFA43334F0249406440F67AF77F6040C0CC77F01301494037E2C96E667F6040C0CC77F013014940
21704	Уська-Орочская	4	37	654	140.027671	140.0548	49.353558999999997	49.344268999999997	0103000020E6100000010000000500000086014BAEE28061406803B00111AC484086014BAEE28061406D1ADB6B41AD484044FAEDEBC08161406D1ADB6B41AD484044FAEDEBC08161406803B00111AC484086014BAEE28061406803B00111AC4840
7656	Тумнин	4	37	654	140.06239099999999	140.11667600000001	49.677937	49.646658000000002	0103000020E610000001000000050000001212691BFF81614030D978B0C5D248401212691BFF816140CADFBDA3C6D648404D874ECFBB836140CADFBDA3C6D648404D874ECFBB83614030D978B0C5D248401212691BFF81614030D978B0C5D24840
21819	Тулучи	4	37	654	139.945897	139.96571399999999	49.893324	49.874924	0103000020E610000001000000050000004E0CC9C9447E6140253E7782FDEF48404E0CC9C9447E6140AF5DDA7058F2484042E90B21E77E6140AF5DDA7058F2484042E90B21E77E6140253E7782FDEF48404E0CC9C9447E6140253E7782FDEF4840
21452	Токи	4	37	654	140.30781899999999	140.32849899999999	49.137348000000003	49.107537999999998	0103000020E61000000100000005000000CC423BA7D9896140E38920CEC38D4840CC423BA7D9896140E415889E9491484099B85510838A6140E415889E9491484099B85510838A6140E38920CEC38D4840CC423BA7D9896140E38920CEC38D4840
20909	Октябрьский	4	37	654	140.22118599999999	140.29294300000001	49.084637999999998	49.040973000000001	0103000020E61000000100000005000000A88AA9F4138761406F826F9A3E854840A88AA9F413876140DAFF006BD58A4840F392FFC95F896140DAFF006BD58A4840F392FFC95F8961406F826F9A3E854840A88AA9F4138761406F826F9A3E854840
4386	Монгохто	4	37	654	140.209768	140.25115400000001	49.245834000000002	49.230400000000003	0103000020E61000000100000005000000EA77616BB6866140CC7F48BF7D9D4840EA77616BB6866140581F0F7D779F48404F081D7409886140581F0F7D779F48404F081D7409886140CC7F48BF7D9D4840EA77616BB6866140CC7F48BF7D9D4840
21859	Кенада	4	37	654	139.55477099999999	139.59724299999999	50.141713000000003	50.124262999999999	0103000020E610000001000000050000009DB81CAFC07161402A8D98D9E70F49409DB81CAFC07161408335CEA6231249407A185A9D1C7361408335CEA6231249407A185A9D1C7361402A8D98D9E70F49409DB81CAFC07161402A8D98D9E70F4940
21617	Датта	4	37	654	140.35836800000001	140.37716	49.293225	49.272509999999997	0103000020E61000000100000005000000DBFD2AC0778B61409EEA909BE1A24840DBFD2AC0778B61404FAF946588A54840802BD9B1118C61404FAF946588A54840802BD9B1118C61409EEA909BE1A24840DBFD2AC0778B61409EEA909BE1A24840
21914	Высокогорный	4	37	654	139.108182	139.15546900000001	50.116638999999999	50.089858999999997	0103000020E610000001000000050000008200193A766361402920ED7F800B49408200193A766361401538D906EE0E494057D11F9AF96461401538D906EE0E494057D11F9AF96461402920ED7F800B49408200193A766361402920ED7F800B4940
21080	Ванино	4	37	654	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
20253	Пушкино	4	37	1283	134.36957799999999	134.389341	47.139969999999998	47.127893999999998	0103000020E6100000010000000500000046EA3D95D3CB604064ADA1D45E90474046EA3D95D3CB6040E7357689EA914740BEBF417B75CC6040E7357689EA914740BEBF417B75CC604064ADA1D45E90474046EA3D95D3CB604064ADA1D45E904740
20087	Покровка	4	37	1283	134.019972	134.03120999999999	46.722386	46.709850000000003	0103000020E61000000100000005000000BEDA519CA3C060406688635DDC5A4740BEDA519CA3C060404C8BFA24775C4740DC291DACFFC060404C8BFA24775C4740DC291DACFFC060406688635DDC5A4740BEDA519CA3C060406688635DDC5A4740
19212	Оренбургское	4	37	1283	134.23083299999999	134.24882600000001	46.808225	46.789872000000003	0103000020E61000000100000005000000CD3AE3FB62C76040580394861A654740CD3AE3FB62C76040A167B3EA73674740A08CF161F6C76040A167B3EA73674740A08CF161F6C76040580394861A654740CD3AE3FB62C76040580394861A654740
20358	Лончаково	4	37	1283	134.208223	134.23260300000001	47.104156000000003	47.086807	0103000020E61000000100000005000000CDE847C3A9C660402D08E57D1C8B4740CDE847C3A9C6604052D7DAFB548D474073BED87B71C7604052D7DAFB548D474073BED87B71C760402D08E57D1C8B4740CDE847C3A9C660402D08E57D1C8B4740
20141	Лесопильное	4	37	1283	134.32532699999999	134.36117899999999	46.746738999999998	46.720131000000002	0103000020E610000001000000050000002F302B1469CA6040FBEAAA402D5C47402F302B1469CA6040E9D2BF24955F4740102043C78ECB6040E9D2BF24955F4740102043C78ECB6040FBEAAA402D5C47402F302B1469CA6040FBEAAA402D5C4740
20460	Лермонтовка	4	37	1283	134.27361999999999	134.35245599999999	47.167575999999997	47.134073000000001	0103000020E6100000010000000500000002F1BA7EC1C860406823D74D2991474002F1BA7EC1C8604018CC5F2173954740ED28CE5147CB604018CC5F2173954740ED28CE5147CB60406823D74D2991474002F1BA7EC1C860406823D74D29914740
20377	Добролюбово	4	37	1283	134.318365	134.32750100000001	47.213577000000001	47.199938000000003	0103000020E610000001000000050000001DE6CB0B30CA6040249D8191979947401DE6CB0B30CA6040C216BB7D569B4740098D60E37ACA6040C216BB7D569B4740098D60E37ACA6040249D8191979947401DE6CB0B30CA6040249D819197994740
20225	Бойцово	4	37	1283	134.319605	134.33502899999999	46.990476000000001	46.973809000000003	0103000020E610000001000000050000006BD443343ACA604076C6F7C5A57C47406BD443343ACA604088BCE5EAC77E4740C5C6BC8EB8CA604088BCE5EAC77E4740C5C6BC8EB8CA604076C6F7C5A57C47406BD443343ACA604076C6F7C5A57C4740
13440	Бикин	4	37	1283	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
50562	с.Нелькан	4	37	7081	134.63354799999999	134.94936000000001	54.484769999999997	54.309449000000001	0103000020E61000000100000005000000478E740646D46040D4635B069C274B40478E740646D460407C0A80F10C3E4B402E04392861DE60407C0A80F10C3E4B402E04392861DE6040D4635B069C274B40478E740646D46040D4635B069C274B40
50495	Джигда	4	37	7081	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
61809	Аян	4	37	7081	138.39611500000001	138.57760099999999	53.211368999999998	53.162494000000002	0103000020E61000000100000005000000904E5DF9AC4C6140EBE5779ACC944A40904E5DF9AC4C6140B131AF230E9B4A4061A417B57B526140B131AF230E9B4A4061A417B57B526140EBE5779ACC944A40904E5DF9AC4C6140EBE5779ACC944A40
61574	Аим	4	37	7081	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
50470	станция Мылки	4	37	864	136.70577299999999	136.83757299999999	50.369103000000003	50.284728999999999	0103000020E61000000100000005000000CB2C42B195166140849CF7FF71244940CB2C42B19516614081ED60C43E2F49406760E465CD1A614081ED60C43E2F49406760E465CD1A6140849CF7FF71244940CB2C42B195166140849CF7FF71244940
7360	Эльбан	4	37	864	136.474277	136.52242699999999	50.120001000000002	50.068939	0103000020E61000000100000005000000D787F5462D0F6140A0353FFED2084940D787F5462D0F6140603E59315C0F494084F1D3B8B7106140603E59315C0F494084F1D3B8B7106140A0353FFED2084940D787F5462D0F6140A0353FFED2084940
19399	Форель	4	37	864	135.14618100000001	135.171199	49.090218999999998	49.08128	0103000020E610000001000000050000007EC9C683ADE46040D1E80E62678A48407EC9C683ADE46040293DD34B8C8B4840744353767AE56040293DD34B8C8B4840744353767AE56040D1E80E62678A48407EC9C683ADE46040D1E80E62678A4840
18642	Тейсин	4	37	864	136.412509	136.444614	50.027863000000004	50.014139999999998	0103000020E61000000100000005000000C8091346330D614060C8EA56CF014940C8091346330D61405DE2C8039103494000AB23473A0E61405DE2C8039103494000AB23473A0E614060C8EA56CF014940C8091346330D614060C8EA56CF014940
19184	Сельгон	4	37	864	135.41130000000001	135.420571	49.588543999999999	49.583708000000001	0103000020E61000000100000005000000091B9E5E29ED6040F03499F1B6CA4840091B9E5E29ED6040E620E86855CB4840AC54505175ED6040E620E86855CB4840AC54505175ED6040F03499F1B6CA4840091B9E5E29ED6040F03499F1B6CA4840
19145	Санболи	4	37	864	135.165144	135.19451000000001	49.376921000000003	49.358611000000003	0103000020E610000001000000050000002EE411DC48E56040317E1AF7E6AD48402EE411DC48E560407B1684F23EB04840D717096D39E660407B1684F23EB04840D717096D39E66040317E1AF7E6AD48402EE411DC48E56040317E1AF7E6AD4840
18825	Падали	4	37	864	136.63856100000001	136.65489199999999	50.226733000000003	50.204886999999999	0103000020E6100000010000000500000009707A176F1461401230BABC391A494009707A176F14614045F64196051D49402F4D11E0F414614045F64196051D49402F4D11E0F41461401230BABC391A494009707A176F1461401230BABC391A4940
7437	Омми	4	37	864	136.782534	136.794939	50.096297	50.084494999999997	0103000020E610000001000000050000004240BE840A19614077D66EBBD00A49404240BE840A196140F9D9C875530C494014EAE92370196140F9D9C875530C494014EAE9237019614077D66EBBD00A49404240BE840A19614077D66EBBD00A4940
18852	Малмыж	4	37	864	136.668654	136.69263000000001	50.312919000000001	50.296745999999999	0103000020E61000000100000005000000DECA129D65156140029CDEC5FB254940DECA129D6515614005A6D3BA0D28494050C763062A16614005A6D3BA0D28494050C763062A166140029CDEC5FB254940DECA129D65156140029CDEC5FB254940
19295	Литовко	4	37	864	135.15165099999999	135.19158100000001	49.258206999999999	49.220838999999998	0103000020E61000000100000005000000FBAC3253DAE460403657CD73449C4840FBAC3253DAE46040944C4EED0CA148401F317A6E21E66040944C4EED0CA148401F317A6E21E660403657CD73449C4840FBAC3253DAE460403657CD73449C4840
19323	Лесной	4	37	864	135.15925999999999	135.18162799999999	49.188352999999999	49.170043999999997	0103000020E61000000100000005000000F3716DA818E56040C5707500C4954840F3716DA818E560403F8D7BF31B984840360186E5CFE560403F8D7BF31B984840360186E5CFE56040C5707500C4954840F3716DA818E56040C5707500C4954840
7461	Известковый	4	37	864	136.62958699999999	136.66021000000001	50.263365	50.249651999999998	0103000020E6100000010000000500000093DFA29325146140C4B0C398F41F494093DFA293251461409DF4BEF1B5214940C0CFB870201561409DF4BEF1B5214940C0CFB87020156140C4B0C398F41F494093DFA29325146140C4B0C398F41F4940
7558	Джуен	4	37	864	136.24746099999999	136.26421500000001	49.853380999999999	49.847427000000003	0103000020E6100000010000000500000022C15433EB076140AB5FE97C78EC484022C15433EB0761408E03AF963BED48409B030473740861408E03AF963BED48409B03047374086140AB5FE97C78EC484022C15433EB076140AB5FE97C78EC4840
17300	Голубичное	4	37	864	134.90808200000001	134.92138600000001	48.829411999999998	48.824559999999998	0103000020E61000000100000005000000C382FB010FDD60407DCB9C2E8B694840C382FB010FDD60407974232C2A6A4840C11F7EFE7BDD60407974232C2A6A4840C11F7EFE7BDD60407DCB9C2E8B694840C382FB010FDD60407DCB9C2E8B694840
18933	Вознесенское	4	37	864	136.91168400000001	136.952809	50.139645999999999	50.123305000000002	0103000020E610000001000000050000002B89EC832C1D614076374F75C80F49402B89EC832C1D614034828DEBDF114940B4CA4C697D1E614034828DEBDF114940B4CA4C697D1E614076374F75C80F49402B89EC832C1D614076374F75C80F4940
19052	Болонь	4	37	864	136.121329	136.16707099999999	49.919466	49.877287000000003	0103000020E61000000100000005000000CEE15AEDE10361405D1ABFF04AF04840CEE15AEDE103614058E4D70FB1F54840852348A55805614058E4D70FB1F54840852348A5580561405D1ABFF04AF04840CEE15AEDE10361405D1ABFF04AF04840
7548	Ачан	4	37	864	136.60242099999999	136.64057299999999	49.893748000000002	49.882111000000002	0103000020E610000001000000050000008EAD6708471361408F386403E9F048408EAD670847136140C66E9F5566F248406BB6F2927F146140C66E9F5566F248406BB6F2927F1461408F386403E9F048408EAD6708471361408F386403E9F04840
6510	Амурск	4	37	864	136.754749	136.927468	50.337826	50.212122000000001	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
61554	с. Головнино	4	40	\N	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
61541	пгт.Южно-Курильск	4	40	\N	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
23754	Южно-Сахалинск	4	40	\N	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
55616	Углегорск	4	40	\N	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
61562	Северо-Курильск	4	40	\N	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
55614	Поронайск	4	40	\N	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
55642	Петропавловское	4	40	\N	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
55615	Оха	4	40	\N	142.90475000000001	142.973848	53.609161999999998	53.562835	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
55613	Макаров	4	40	\N	142.76570899999999	142.791436	48.636825999999999	48.606327	0103000020E61000000100000005000000172829B080D8614045D7851F9C4D4840172829B080D861400A9FAD8383514840111C977153D961400A9FAD8383514840111C977153D9614045D7851F9C4D4840172829B080D8614045D7851F9C4D4840
61555	Курильск	4	40	\N	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
55620	Корсаков	4	40	\N	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
61543	Горячий Пляж	4	40	\N	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
55618	Анива	4	40	\N	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
55628	Александровск-Сахалинский	4	40	\N	142.12698900000001	142.19465	50.936836	50.868848999999997	0103000020E61000000100000005000000753E3C4B10C46140C614AC71366F4940753E3C4B10C4614094DBF63DEA7749405305A3923AC6614094DBF63DEA7749405305A3923AC66140C614AC71366F4940753E3C4B10C46140C614AC71366F4940
55625	Дальнее	4	40	7375	142.65743499999999	142.69002599999999	47.014142	46.985514999999999	0103000020E61000000100000005000000DD0720B509D56140D55B035B257E4740DD0720B509D5614001C0B167CF81474078EC67B114D6614001C0B167CF81474078EC67B114D66140D55B035B257E4740DD0720B509D56140D55B035B257E4740
61560	с.Малокурильское	4	40	7532	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
61567	с. Крабозаводское	4	40	7532	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
55629	Яблочный	4	40	1749	142.044613	142.07168799999999	47.207033000000003	47.114311999999998	0103000020E610000001000000050000003FFF3D786DC161402AC58EC6A18E47403FFF3D786DC16140AD18AE0E809A474080F0A1444BC26140AD18AE0E809A474080F0A1444BC261402AC58EC6A18E47403FFF3D786DC161402AC58EC6A18E4740
24431	Чехов	4	40	1749	141.96551600000001	142.01910100000001	47.452922999999998	47.433287	0103000020E610000001000000050000007978CF81E5BE61401764CBF275B747407978CF81E5BE6140984D8061F9B94740454AB3799CC06140984D8061F9B94740454AB3799CC061401764CBF275B747407978CF81E5BE61401764CBF275B74740
25404	Чапланово	4	40	1749	142.21859000000001	142.24353600000001	46.974153000000001	46.955506999999997	0103000020E6100000010000000500000072A774B0FEC66140AE0CAA0D4E7A474072A774B0FEC661407026A60BB17C4740C26C020CCBC761407026A60BB17C4740C26C020CCBC76140AE0CAA0D4E7A474072A774B0FEC66140AE0CAA0D4E7A4740
24822	Холмск	4	40	1749	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
55623	Правда	4	40	1749	141.94359800000001	142.519193	47.632323	46.818998999999998	0103000020E6100000010000000500000046D26EF431BE6140753A90F5D468474046D26EF431BE61401AC1C6F5EFD04740FD69A33A9DD061401AC1C6F5EFD04740FD69A33A9DD06140753A90F5D468474046D26EF431BE6140753A90F5D4684740
24582	Пионеры	4	40	1749	142.01892100000001	142.03880100000001	47.272702000000002	47.252325999999996	0103000020E61000000100000005000000A58636009BC061401AF7E6374CA04740A58636009BC06140E3C62DE6E7A24740AB4198DB3DC16140E3C62DE6E7A24740AB4198DB3DC161401AF7E6374CA04740A58636009BC061401AF7E6374CA04740
24427	Новосибирское	4	40	1749	141.96500399999999	141.96840900000001	47.471496999999999	47.459356999999997	0103000020E610000001000000050000004B901150E1BE61402618CE35CCBA47404B901150E1BE6140C09481035ABC4740DE04DF34FDBE6140C09481035ABC4740DE04DF34FDBE61402618CE35CCBA47404B901150E1BE61402618CE35CCBA4740
24540	Костромское	4	40	1749	142.00475499999999	142.034651	47.328176999999997	47.281781000000002	0103000020E61000000100000005000000C22FF5F326C061402DD1596611A44740C22FF5F326C06140522635B401AA4740C2F869DC1BC16140522635B401AA4740C2F869DC1BC161402DD1596611A44740C22FF5F326C061402DD1596611A44740
55641	с.Поречье	4	40	1715	141.847702	142.57529299999999	49.816695000000003	48.573645999999997	0103000020E610000001000000050000001FD8F15F20BB614098BD6C3B6D4948401FD8F15F20BB614043E7357689E84840C493DDCC68D2614043E7357689E84840C493DDCC68D2614098BD6C3B6D4948401FD8F15F20BB614098BD6C3B6D494840
23403	Шахтерск	4	40	1715	142.05405400000001	142.160586	49.187275999999997	49.153413	0103000020E61000000100000005000000FA4674CFBAC1614000E48409A3934840FA4674CFBAC16140B0A9F3A8F89748404146408523C56140B0A9F3A8F89748404146408523C5614000E48409A3934840FA4674CFBAC1614000E48409A3934840
23827	Углегорск	4	40	1715	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
23371	Тельновский	4	40	1715	142.095305	142.161798	49.407353000000001	49.363382000000001	0103000020E61000000100000005000000A64412BD0CC3614040FA264D83AE4840A64412BD0CC36140B876A22424B44840DDD1FF722DC56140B876A22424B44840DDD1FF722DC5614040FA264D83AE4840A64412BD0CC3614040FA264D83AE4840
23132	Ольшанка	4	40	1715	141.945798	141.955015	48.846282000000002	48.840394000000003	0103000020E61000000100000005000000E9D32AFA43BE614098E0D407926B4840E9D32AFA43BE6140C498F4F7526C484010069E7B8FBE6140C498F4F7526C484010069E7B8FBE614098E0D407926B4840E9D32AFA43BE614098E0D407926B4840
24276	Ольховка	4	40	1715	142.09328400000001	142.11201399999999	49.065823999999999	49.056372000000003	0103000020E61000000100000005000000AF27BA2EFCC261407F349C3237874840AF27BA2EFCC261405DA5BBEB6C8848403656629E95C361405DA5BBEB6C8848403656629E95C361407F349C3237874840AF27BA2EFCC261407F349C3237874840
24231	Никольское	4	40	1715	142.12752800000001	142.147335	48.992137999999997	48.982430999999998	0103000020E6100000010000000500000061AA99B514C46140CDC98B4CC07D484061AA99B514C46140368FC360FE7E4840CCD1E3F7B6C46140368FC360FE7E4840CCD1E3F7B6C46140CDC98B4CC07D484061AA99B514C46140CDC98B4CC07D4840
24125	Медвежье	4	40	1715	142.261269	142.275983	48.900514000000001	48.889704000000002	0103000020E61000000100000005000000AD4ECE505CC86140698F17D2E1714840AD4ECE505CC861408ACBF10A4473484010E84CDAD4C861408ACBF10A4473484010E84CDAD4C86140698F17D2E1714840AD4ECE505CC86140698F17D2E1714840
23357	Лесогорское	4	40	1715	142.11546300000001	142.150228	49.450536	49.435335000000002	0103000020E61000000100000005000000BD1C76DFB1C36140EFE6A90EB9B74840BD1C76DFB1C36140D8D5E429ABB94840315EF3AACEC46140D8D5E429ABB94840315EF3AACEC46140EFE6A90EB9B74840BD1C76DFB1C36140EFE6A90EB9B74840
24224	Краснополье	4	40	1715	142.18342999999999	142.223432	48.949711000000001	48.935077	0103000020E610000001000000050000005E6397A8DEC56140F31E679AB07748405E6397A8DEC5614063D34A2190794840289CDD5A26C7614063D34A2190794840289CDD5A26C76140F31E679AB07748405E6397A8DEC56140F31E679AB0774840
23264	Бошняково	4	40	1715	142.15630100000001	142.1935	49.66384	49.638117999999999	0103000020E61000000100000005000000A16AF46A00C56140957EC2D9ADD14840A16AF46A00C5614069E388B5F8D44840D578E92631C6614069E388B5F8D44840D578E92631C66140957EC2D9ADD14840A16AF46A00C56140957EC2D9ADD14840
23098	Ясное	4	40	1694	142.703159	142.72249099999999	50.648909000000003	50.633046	0103000020E610000001000000050000006B9C4D4780D661408B6EBDA6075149406B9C4D4780D66140408A3A730F534940F01472A51ED76140408A3A730F534940F01472A51ED761408B6EBDA6075149406B9C4D4780D661408B6EBDA607514940
22458	Чир-Унвд	4	40	1694	142.68213800000001	142.690529	51.207923999999998	51.198459999999997	0103000020E610000001000000050000007C2B1213D4D5614036C82423679949407C2B1213D4D56140D906EE409D9A494011FE45D018D66140D906EE409D9A494011FE45D018D6614036C82423679949407C2B1213D4D5614036C8242367994940
22735	Тымовское	4	40	1694	142.63856999999999	142.68678299999999	50.870229999999999	50.827322000000002	0103000020E610000001000000050000009D465A2A6FD4614073A1F2AFE56949409D465A2A6FD46140C1FF56B2636F49405C8E5720FAD56140C1FF56B2636F49405C8E5720FAD5614073A1F2AFE56949409D465A2A6FD4614073A1F2AFE5694940
22604	Молодежное	4	40	1694	142.646152	142.65813499999999	51.021706999999999	51.013134000000001	0103000020E61000000100000005000000D787F546ADD461409B3BFA5FAE814940D787F546ADD46140118C834BC78249404BAB21710FD56140118C834BC78249404BAB21710FD561409B3BFA5FAE814940D787F546ADD461409B3BFA5FAE814940
61545	Малокурильское	4	40	1694	142.23749900000001	143.317993	51.527493999999997	50.295797	0103000020E61000000100000005000000A6BA809799C76140A1A014ADDC254940A6BA809799C76140096B63EC84C349406CEBA7FF2CEA6140096B63EC84C349406CEBA7FF2CEA6140A1A014ADDC254940A6BA809799C76140A1A014ADDC254940
22993	Красная Тымь	4	40	1694	142.66181900000001	142.68469899999999	50.796315	50.776617999999999	0103000020E61000000100000005000000E31B0A9F2DD5614012BEF73768634940E31B0A9F2DD56140392861A6ED6549405393E00DE9D56140392861A6ED6549405393E00DE9D5614012BEF73768634940E31B0A9F2DD5614012BEF73768634940
23000	Кировское	4	40	1694	142.710408	142.736019	50.724398000000001	50.693584999999999	0103000020E6100000010000000500000023DA8EA9BBD6614082FFAD64C758494023DA8EA9BBD66140D7A4DB12B95C494082C7B7778DD76140D7A4DB12B95C494082C7B7778DD7614082FFAD64C758494023DA8EA9BBD6614082FFAD64C7584940
55640	Зональное	4	40	1694	142.23749900000001	143.317993	51.527493999999997	50.295797	0103000020E61000000100000005000000A6BA809799C76140A1A014ADDC254940A6BA809799C76140096B63EC84C349406CEBA7FF2CEA6140096B63EC84C349406CEBA7FF2CEA6140A1A014ADDC254940A6BA809799C76140A1A014ADDC254940
22907	Восход	4	40	1694	142.58826500000001	142.61743300000001	50.841816999999999	50.828375000000001	0103000020E61000000100000005000000350C1F11D3D2614079E92631086A4940350C1F11D3D26140C11BD2A8C06B494014CFD902C2D36140C11BD2A8C06B494014CFD902C2D3614079E92631086A4940350C1F11D3D2614079E92631086A4940
22658	Воскресеновка	4	40	1694	142.662699	142.68433899999999	50.908071999999997	50.891154999999998	0103000020E61000000100000005000000F18288D434D561405C55F65D11724940F18288D434D56140E7340BB43B744940130CE71AE6D56140E7340BB43B744940130CE71AE6D561405C55F65D11724940F18288D434D561405C55F65D11724940
23184	Белоречье	4	40	1694	142.857606	142.867659	50.699342000000001	50.686064000000002	0103000020E610000001000000050000004F5B238271DB6140427BF5F1D05749404F5B238271DB6140105CE5098459494090A2CEDCC3DB6140105CE5098459494090A2CEDCC3DB6140427BF5F1D05749404F5B238271DB6140427BF5F1D0574940
22452	Арги-Паги	4	40	1694	142.71958900000001	142.74131	51.357855999999998	51.339387000000002	0103000020E61000000100000005000000F7B182DF06D7614002D8800871AB4940F7B182DF06D76140B456B439CEAD494054C6BFCFB8D76140B456B439CEAD494054C6BFCFB8D7614002D8800871AB4940F7B182DF06D7614002D8800871AB4940
22564	Адо-Тымово	4	40	1694	142.659402	142.683953	51.140132000000001	51.124482	0103000020E61000000100000005000000581D39D219D561406878B306EF8F4940581D39D219D56140C18F6AD8EF91494009E066F1E2D56140C18F6AD8EF91494009E066F1E2D561406878B306EF8F4940581D39D219D561406878B306EF8F4940
22295	Черемшанка	4	40	1679	142.18034	142.20004	47.908022000000003	47.900176000000002	0103000020E6100000010000000500000024456458C5C56140725298F738F3474024456458C5C5614036069D103AF447408A3C49BA66C6614036069D103AF447408A3C49BA66C66140725298F738F3474024456458C5C56140725298F738F34740
22305	Томари	4	40	1679	142.04894300000001	142.098997	47.774138999999998	47.756005000000002	0103000020E61000000100000005000000C80BE9F090C16140664E97C5C4E04740C80BE9F090C1614071C79BFC16E34740DEACC1FB2AC3614071C79BFC16E34740DEACC1FB2AC36140664E97C5C4E04740C80BE9F090C16140664E97C5C4E04740
22208	Пензенское	4	40	1679	142.136394	142.16578699999999	47.904477	47.890993000000002	0103000020E61000000100000005000000DC2BF3565DC4614083FB010F0CF24740DC2BF3565DC46140FA7DFFE6C5F3474043E389204EC56140FA7DFFE6C5F3474043E389204EC5614083FB010F0CF24740DC2BF3565DC4614083FB010F0CF24740
22069	Парусное	4	40	1679	142.14571799999999	142.16319100000001	48.326098000000002	48.315727000000003	0103000020E61000000100000005000000088ECBB8A9C461406BBB09BE69284840088ECBB8A9C4614040A54A94BD2948400D0055DC38C5614040A54A94BD2948400D0055DC38C561406BBB09BE69284840088ECBB8A9C461406BBB09BE69284840
21922	Красногорск	4	40	1679	142.06959499999999	142.11361299999999	48.437162000000001	48.385669999999998	0103000020E61000000100000005000000E21E4B1F3AC261402F8672A25D314840E21E4B1F3AC26140E886A6ECF4374840D0ECBAB7A2C36140E886A6ECF4374840D0ECBAB7A2C361402F8672A25D314840E21E4B1F3AC261402F8672A25D314840
55637	Ильинский	4	40	1679	142.19209000000001	142.22664800000001	48.000771	47.976866999999999	0103000020E61000000100000005000000707CED9925C6614054C554FA09FD4740707CED9925C6614082E49D431900484086764EB340C7614082E49D431900484086764EB340C7614054C554FA09FD4740707CED9925C6614054C554FA09FD4740
21544	Смирных	4	40	1662	142.80573799999999	142.85561200000001	49.767164000000001	49.729277000000003	0103000020E610000001000000050000009FE40E9BC8D96140CD5CE0F258DD48409FE40E9BC8D961409355116E32E2484016C26A2C61DB61409355116E32E2484016C26A2C61DB6140CD5CE0F258DD48409FE40E9BC8D96140CD5CE0F258DD4840
21343	Рощино	4	40	1662	142.75406699999999	142.77832100000001	49.964627999999998	49.954236999999999	0103000020E61000000100000005000000C5FF1D5121D861400BD1217024FA4840C5FF1D5121D86140276728EE78FB484048197101E8D86140276728EE78FB484048197101E8D861400BD1217024FA4840C5FF1D5121D861400BD1217024FA4840
21442	Победино	4	40	1662	142.80189300000001	142.84940499999999	49.851522000000003	49.821705000000001	0103000020E61000000100000005000000863C821BA9D96140D7FA22A12DE94840863C821BA9D961408AE942ACFEEC4840E20165532EDB61408AE942ACFEEC4840E20165532EDB6140D7FA22A12DE94840863C821BA9D96140D7FA22A12DE94840
21436	Первомайск	4	40	1662	143.24833799999999	143.276949	49.987864000000002	49.951078000000003	0103000020E61000000100000005000000548B8862F2E76140F9F884ECBCF94840548B8862F2E76140A872DA5372FE48401E3526C4DCE86140A872DA5372FE48401E3526C4DCE86140F9F884ECBCF94840548B8862F2E76140F9F884ECBCF94840
21266	Онор	4	40	1662	142.66142300000001	142.72402700000001	50.200482000000001	50.182170999999997	0103000020E61000000100000005000000503A91602AD56140CAA31B6151174940503A91602AD56140E5B7E864A919494079CDAB3A2BD76140E5B7E864A919494079CDAB3A2BD76140CAA31B6151174940503A91602AD56140CAA31B6151174940
21728	Буюклы	4	40	1662	142.84867700000001	142.884197	49.559089999999998	49.529570999999997	0103000020E61000000100000005000000C2FBAA5C28DB61407BF486FBC8C34840C2FBAA5C28DB6140A4C2D84290C7484015C781574BDC6140A4C2D84290C7484015C781574BDC61407BF486FBC8C34840C2FBAA5C28DB61407BF486FBC8C34840
20917	Тихменево	4	40	1617	142.884152	142.914649	49.210510999999997	49.197555999999999	0103000020E610000001000000050000002D9622F94ADC61407590D783499948402D9622F94ADC614060394206F29A484036CAFACD44DD614060394206F29A484036CAFACD44DD61407590D783499948402D9622F94ADC61407590D78349994840
20174	Поронайск	4	40	1617	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
21163	Малиновка	4	40	1617	142.89545200000001	142.91706600000001	49.470824999999998	49.460133999999996	0103000020E6100000010000000500000069E4F38AA7DC61408AE3C0ABE5BA484069E4F38AA7DC6140D1915CFE43BC4840C1C8CB9A58DD6140D1915CFE43BC4840C1C8CB9A58DD61408AE3C0ABE5BA484069E4F38AA7DC61408AE3C0ABE5BA4840
21062	Майское	4	40	1617	142.86946399999999	142.90890899999999	49.298501000000002	49.287109000000001	0103000020E6100000010000000500000094A12AA6D2DB614092B1DAFCBFA4484094A12AA6D2DB61406269E04735A6484048C153C815DD61406269E04735A6484048C153C815DD614092B1DAFCBFA4484094A12AA6D2DB614092B1DAFCBFA44840
20983	Леонидово	4	40	1617	142.85062600000001	142.888823	49.288513000000002	49.272669	0103000020E610000001000000050000001364045438DB614007D15AD1E6A248401364045438DB614045BC75FEEDA44840D89DEE3C71DC614045BC75FEEDA44840D89DEE3C71DC614007D15AD1E6A248401364045438DB614007D15AD1E6A24840
21068	Забайкалец	4	40	1617	142.85744500000001	142.87323699999999	49.363387000000003	49.355905999999997	0103000020E61000000100000005000000CD237F3070DB61409F39EB538EAD4840CD237F3070DB61405265187783AE48400795B88EF1DB61405265187783AE48400795B88EF1DB61409F39EB538EAD4840CD237F3070DB61409F39EB538EAD4840
20863	Гастелло	4	40	1617	142.923327	142.96531400000001	49.108364000000002	49.094743999999999	0103000020E61000000100000005000000719010E58BDD614001BF4692208C4840719010E58BDD614029081EDFDE8D4840DF8B2FDAE3DE614029081EDFDE8D4840DF8B2FDAE3DE614001BF4692208C4840719010E58BDD614001BF4692208C4840
20851	Восток	4	40	1617	142.90613300000001	142.92580599999999	48.988207000000003	48.973756000000002	0103000020E61000000100000005000000721AA20AFFDC614053245F09A47C4840721AA20AFFDC6140D25625917D7E4840198EE733A0DD6140D25625917D7E4840198EE733A0DD614053245F09A47C4840721AA20AFFDC614053245F09A47C4840
20755	Вахрушев	4	40	1617	142.841554	142.90716599999999	48.998646000000001	48.979610000000001	0103000020E610000001000000050000002D7AA702EEDA6140D36A48DC637D48402D7AA702EEDA6140FF23D3A1D37F484061C1FD8007DD6140FF23D3A1D37F484061C1FD8007DD6140D36A48DC637D48402D7AA702EEDA6140D36A48DC637D4840
19837	Тунгор	4	40	1431	142.946495	142.96482	53.397129	53.380921999999998	0103000020E610000001000000050000007BDAE1AF49DE6140D829560DC2B04A407BDAE1AF49DE614087A5811FD5B24A40DB5031CEDFDE614087A5811FD5B24A40DB5031CEDFDE6140D829560DC2B04A407BDAE1AF49DE6140D829560DC2B04A40
15958	Оха	4	40	1431	142.90475000000001	142.973848	53.609161999999998	53.562835	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
19884	Некрасовка	4	40	1431	142.61603099999999	142.634276	53.687869999999997	53.671197999999997	0103000020E610000001000000050000004FCAA486B6D36140FF91E9D0E9D54A404FCAA486B6D3614023F3C81F0CD84A4068942EFD4BD4614023F3C81F0CD84A4068942EFD4BD46140FF91E9D0E9D54A404FCAA486B6D36140FF91E9D0E9D54A40
20042	Москальво	4	40	1431	142.49665400000001	142.51622900000001	53.596632	53.571759999999998	0103000020E61000000100000005000000AFEDED96E4CF61409A94826E2FC94A40AFEDED96E4CF6140A0DFF76F5ECC4A40E607AEF284D06140A0DFF76F5ECC4A40E607AEF284D061409A94826E2FC94A40AFEDED96E4CF61409A94826E2FC94A40
55636	Лагури	4	40	1431	141.628828	143.32529600000001	54.424470999999997	51.893394999999998	0103000020E61000000100000005000000E4D9E55B1FB4614078B471C45AF24940E4D9E55B1FB46140DA8CD31055364B40A13028D368EA6140DA8CD31055364B40A13028D368EA614078B471C45AF24940E4D9E55B1FB4614078B471C45AF24940
55626	Восточный	4	40	1431	143.02812499999999	143.075861	53.498710000000003	53.450138000000003	0103000020E6100000010000000500000066666666E6E06140EB573A1F9EB94A4066666666E6E061401618B2BAD5BF4A4057410C746DE261401618B2BAD5BF4A4057410C746DE26140EB573A1F9EB94A4066666666E6E06140EB573A1F9EB94A40
19216	Ныш	4	40	1511	142.747311	142.78050400000001	51.544043000000002	51.531785999999997	0103000020E610000001000000050000001D1EC2F8E9D761403E3C4B9011C449401D1EC2F8E9D76140124F7633A3C54940B64C86E3F9D86140124F7633A3C54940B64C86E3F9D861403E3C4B9011C449401D1EC2F8E9D761403E3C4B9011C44940
18843	Ноглики	4	40	1511	143.10432	143.18010200000001	51.822636000000003	51.768867999999998	0103000020E61000000100000005000000338AE59656E36140707841446AE24940338AE59656E361409241EE224CE9494037FE4465C3E561409241EE224CE9494037FE4465C3E56140707841446AE24940338AE59656E36140707841446AE24940
19158	Катангли	4	40	1511	143.21501900000001	143.25100599999999	51.718445000000003	51.698481999999998	0103000020E6100000010000000500000099A0866FE1E661401E6CB1DB67D9494099A0866FE1E66140C47C7901F6DB49403123BC3D08E86140C47C7901F6DB49403123BC3D08E861401E6CB1DB67D9494099A0866FE1E661401E6CB1DB67D94940
17691	Горячие Ключи	4	40	1511	143.08215799999999	143.08779999999999	52.046886000000001	52.039613000000003	0103000020E610000001000000050000005A63D009A1E261408CBFED0912054A405A63D009A1E26140F451465C00064A40D712F241CFE26140F451465C00064A40D712F241CFE261408CBFED0912054A405A63D009A1E261408CBFED0912054A40
55624	Вал	4	40	1511	143.00032200000001	143.13212300000001	52.383260999999997	52.302536000000003	0103000020E61000000100000005000000056F48A302E061406CEEE87FB9264A40056F48A302E06140876A4AB20E314A409581035A3AE46140876A4AB20E314A409581035A3AE461406CEEE87FB9264A40056F48A302E061406CEEE87FB9264A40
55634	Ясноморский	4	40	1534	141.89299500000001	141.91377299999999	46.752358000000001	46.746473999999999	0103000020E61000000100000005000000BB0F406A93BC61403BA8C4758C5F4740BB0F406A93BC6140267156444D604740F8DEDFA03DBD6140267156444D604740F8DEDFA03DBD61403BA8C4758C5F4740BB0F406A93BC61403BA8C4758C5F4740
18692	Шебунино	4	40	1534	141.847352	141.872613	46.437610999999997	46.417448	0103000020E610000001000000050000006806F1811DBB6140EBE3A1EF6E3547406806F1811DBB614057AF22A30338474010221972ECBB614057AF22A30338474010221972ECBB6140EBE3A1EF6E3547406806F1811DBB6140EBE3A1EF6E354740
18212	Невельск	4	40	1534	141.84986699999999	141.889411	46.720081	46.641136000000003	0103000020E61000000100000005000000635E471C32BB6140E62494BE10524740635E471C32BB614049BC3C9D2B5C47407CB60E0E76BC614049BC3C9D2B5C47407CB60E0E76BC6140E62494BE10524740635E471C32BB6140E62494BE10524740
18463	Колхозное	4	40	1534	141.89089300000001	141.92207400000001	46.659112999999998	46.643622999999998	0103000020E610000001000000050000008867093282BC614009FA0B3D625247408867093282BC614029AF95D05D544740BE4F55A181BD614029AF95D05D544740BE4F55A181BD614009FA0B3D625247408867093282BC614009FA0B3D62524740
55621	Горнозаводск	4	40	1534	141.82046500000001	141.87423000000001	46.582158999999997	46.542155999999999	0103000020E6100000010000000500000068D0D03F41BA614043AA285E6545474068D0D03F41BA61403909A52F844A4740D46531B1F9BB61403909A52F844A4740D46531B1F9BB614043AA285E6545474068D0D03F41BA614043AA285E65454740
17857	Поречье	4	40	1516	142.741454	142.759986	48.57544	48.565043000000003	0103000020E61000000100000005000000A12FBDFDB9D76140B8EA3A5453484840A12FBDFDB9D76140B6679604A84948405FED28CE51D86140B6679604A84948405FED28CE51D86140B8EA3A5453484840A12FBDFDB9D76140B8EA3A5453484840
55631	Новое	4	40	1516	142.928843	142.973983	48.904215000000001	48.878484	0103000020E61000000100000005000000CB83F414B9DD61409607E92972704840CB83F414B9DD6140BDC62E51BD734840857B65DE2ADF6140BDC62E51BD734840857B65DE2ADF61409607E92972704840CB83F414B9DD61409607E92972704840
17867	Макаров	4	40	1516	142.76570899999999	142.791436	48.636825999999999	48.606327	0103000020E61000000100000005000000172829B080D8614045D7851F9C4D4840172829B080D861400A9FAD8383514840111C977153D961400A9FAD8383514840111C977153D9614045D7851F9C4D4840172829B080D8614045D7851F9C4D4840
18070	Горное	4	40	1516	142.78089	142.82707300000001	48.758665000000001	48.742620000000002	0103000020E61000000100000005000000C078060DFDD8614082AD122C0E5F4840C078060DFDD8614057CF49EF1B614840F3CCCB6177DA614057CF49EF1B614840F3CCCB6177DA614082AD122C0E5F4840C078060DFDD8614082AD122C0E5F4840
55633	Восточный	4	40	1516	142.617774	142.63452799999999	48.282989000000001	48.261592	0103000020E6100000010000000500000036CAFACDC4D361409772BED87B21484036CAFACDC4D361405A10CAFB38244840AE0CAA0D4ED461405A10CAFB38244840AE0CAA0D4ED461409772BED87B21484036CAFACDC4D361409772BED87B214840
61550	Рейдово	4	40	7533	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
16479	Чапаево	4	40	1440	142.92597699999999	142.96667099999999	46.787503000000001	46.775117999999999	0103000020E61000000100000005000000247B849AA1DD61403D450E1137634740247B849AA1DD61403E40F7E5CC644740BB5F05F8EEDE61403E40F7E5CC644740BB5F05F8EEDE61403D450E1137634740247B849AA1DD61403D450E1137634740
16671	Третья Падь	4	40	1440	142.73478	142.75650099999999	46.705437000000003	46.691803	0103000020E6100000010000000500000028B8585183D7614029232E008D58474028B8585183D76140B63176C24B5A474085CC954135D86140B63176C24B5A474085CC954135D8614029232E008D58474028B8585183D7614029232E008D584740
16669	Соловьевка	4	40	1440	142.73614499999999	142.76309499999999	46.742885999999999	46.715817999999999	0103000020E61000000100000005000000A583F57F8ED76140AEF199EC9F5B4740A583F57F8ED76140005471E3165F4740B79734466BD86140005471E3165F4740B79734466BD86140AEF199EC9F5B4740A583F57F8ED76140AEF199EC9F5B4740
16560	Раздольное	4	40	1440	142.80901700000001	142.81973300000001	46.654170999999998	46.643908000000003	0103000020E610000001000000050000000F9D9E77E3D96140FFD0CC936B5247400F9D9E77E3D96140ED7E15E0BB534740774EB3403BDA6140ED7E15E0BB534740774EB3403BDA6140FFD0CC936B5247400F9D9E77E3D96140FFD0CC936B524740
55644	Пихтовый	4	40	1440	143.32846699999999	143.338663	46.611615	46.601678999999997	0103000020E6100000010000000500000016DA39CD82EA614051D845D1034D474016DA39CD82EA61401C5F7B66494E4740B0ABC953D6EA61401C5F7B66494E4740B0ABC953D6EA614051D845D1034D474016DA39CD82EA614051D845D1034D4740
16361	Охотское	4	40	1440	143.14946900000001	143.16206299999999	46.866706999999998	46.851714999999999	0103000020E6100000010000000500000082583673C8E461409E4143FF046D474082583673C8E461406D1B4641F06E4740889CBE9E2FE561406D1B4641F06E4740889CBE9E2FE561409E4143FF046D474082583673C8E461409E4143FF046D4740
55619	Озерский	4	40	1440	143.111785	143.154706	46.614846999999997	46.599988000000003	0103000020E61000000100000005000000DEE522BE93E3614009FF2268CC4C4740DEE522BE93E361409885764EB34E4740D74FFF59F3E461409885764EB34E4740D74FFF59F3E4614009FF2268CC4C4740DEE522BE93E3614009FF2268CC4C4740
16254	Новиково	4	40	1440	143.34894	143.377138	46.378877000000003	46.359183999999999	0103000020E61000000100000005000000850838842AEB61408C9FC6BDF92D4740850838842AEB6140721AA20A7F3047408602B68311EC6140721AA20A7F3047408602B68311EC61408C9FC6BDF92D4740850838842AEB61408C9FC6BDF92D4740
16418	Лесное	4	40	1440	143.06965400000001	143.09295599999999	46.909841999999998	46.904381000000001	0103000020E610000001000000050000002481069B3AE26140D80FB1C1C27347402481069B3AE261407C43E1B375744740F17EDC7EF9E261407C43E1B375744740F17EDC7EF9E26140D80FB1C1C27347402481069B3AE26140D80FB1C1C2734740
16799	Корсаков	4	40	1440	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
16568	Дачное	4	40	1440	142.73443800000001	142.75147000000001	46.770581	46.753512999999998	0103000020E6100000010000000500000012DE1E8480D76140300E2E1D7360474012DE1E8480D76140A1F5F065A26247409B3DD00A0CD86140A1F5F065A26247409B3DD00A0CD86140300E2E1D7360474012DE1E8480D76140300E2E1D73604740
55639	Вторая Падь	4	40	1440	142.744122	142.756393	46.685053000000003	46.679141999999999	0103000020E610000001000000050000007EC7F0D8CFD7614086AB0320EE5647407EC7F0D8CFD761406B8313D1AF5747408CBD175F34D861406B8313D1AF5747408CBD175F34D8614086AB0320EE5647407EC7F0D8CFD7614086AB0320EE564740
16061	Углезаводск	4	40	1394	142.59061800000001	142.647661	47.327669999999998	47.304485999999997	0103000020E61000000100000005000000BA4DB857E6D26140800BB265F9A64740BA4DB857E6D26140AEF02E17F1A94740A1BC8FA3B9D46140AEF02E17F1A94740A1BC8FA3B9D46140800BB265F9A64740BA4DB857E6D26140800BB265F9A64740
15493	Стародубское	4	40	1394	142.79485	142.84313499999999	47.416187000000001	47.404052	0103000020E61000000100000005000000386744696FD9614013F1D6F9B7B34740386744696FD961409B02999D45B547409D6340F6FADA61409B02999D45B547409D6340F6FADA614013F1D6F9B7B34740386744696FD9614013F1D6F9B7B34740
15819	Сокол	4	40	1394	142.73407900000001	142.77646200000001	47.299670999999996	47.208123000000001	0103000020E61000000100000005000000C6353E937DD76140D04543C6A39A4740C6353E937DD76140A1478C9E5BA64740C712D6C6D8D86140A1478C9E5BA64740C712D6C6D8D86140D04543C6A39A4740C6353E937DD76140D04543C6A39A4740
15393	Советское	4	40	1394	142.63981899999999	142.685633	47.507379	47.482526999999997	0103000020E61000000100000005000000800BB26579D46140EF37DA71C3BD4740800BB26579D46140AED689CBF1C04740DE019EB4F0D56140AED689CBF1C04740DE019EB4F0D56140EF37DA71C3BD4740800BB26579D46140EF37DA71C3BD4740
16053	Покровка	4	40	1394	142.700311	142.70847699999999	47.330778000000002	47.322270000000003	0103000020E61000000100000005000000EE409DF268D66140B03DB32440A94740EE409DF268D661403F1EFAEE56AA4740FB1EF5D7ABD661403F1EFAEE56AA4740FB1EF5D7ABD66140B03DB32440A94740EE409DF268D66140B03DB32440A94740
15503	Долинск	4	40	1394	142.77762000000001	142.808145	47.343034000000003	47.310198999999997	0103000020E61000000100000005000000E6965643E2D861403E20D099B4A74740E6965643E2D8614042B5C189E8AB4740A12DE752DCD9614042B5C189E8AB4740A12DE752DCD961403E20D099B4A74740E6965643E2D861403E20D099B4A74740
15297	Взморье	4	40	1394	142.502206	142.53053	47.860086000000003	47.840822000000003	0103000020E610000001000000050000005C3B511212D06140F0E0270EA0EB47405C3B511212D06140ADDF4C4C17EE474080F10C1AFAD06140ADDF4C4C17EE474080F10C1AFAD06140F0E0270EA0EB47405C3B511212D06140F0E0270EA0EB4740
55622	Быков	4	40	1394	142.49592699999999	142.62772799999999	47.362704000000001	47.273074999999999	0103000020E6100000010000000500000082C64CA2DECF6140772D211FF4A2474082C64CA2DECF61406F10AD156DAE474012D9075916D461406F10AD156DAE474012D9075916D46140772D211FF4A2474082C64CA2DECF6140772D211FF4A24740
14739	Успенское	4	40	1356	142.57368500000001	142.59304399999999	46.858204000000001	46.846594000000003	0103000020E610000001000000050000009626A5A05BD26140B37E33315D6C47409626A5A05BD26140F0A5F0A0D96D4740D9226937FAD26140F0A5F0A0D96D4740D9226937FAD26140B37E33315D6C47409626A5A05BD26140B37E33315D6C4740
14624	Троицкое	4	40	1356	142.62735900000001	142.663319	46.934165999999998	46.908850999999999	0103000020E610000001000000050000003E7B2E5313D46140ECF7C43A557447403E7B2E5313D461407F8461C092774740187AC4E839D561407F8461C092774740187AC4E839D56140ECF7C43A557447403E7B2E5313D46140ECF7C43A55744740
14968	Таранай	4	40	1356	142.41501500000001	142.443106	46.638488000000002	46.611305999999999	0103000020E610000001000000050000002F8B89CD47CD61409EEC66463F4E47402F8B89CD47CD6140B9718BF9B95147402A55A2EC2DCE6140B9718BF9B95147402A55A2EC2DCE61409EEC66463F4E47402F8B89CD47CD61409EEC66463F4E4740
14912	Рыбацкое	4	40	1356	142.51648	142.53980899999999	46.706476000000002	46.696736000000001	0103000020E6100000010000000500000038A1100187D0614012F92EA52E59474038A1100187D0614057B439CE6D5A4740C422861D46D1614057B439CE6D5A4740C422861D46D1614012F92EA52E59474038A1100187D0614012F92EA52E594740
15023	Огоньки	4	40	1356	142.37849900000001	142.4034	46.78219	46.774327999999997	0103000020E610000001000000050000003352EFA91CCC614044300E2E1D6347403352EFA91CCC61400EA14ACD1E6447409BE61DA7E8CC61400EA14ACD1E6447409BE61DA7E8CC614044300E2E1D6347403352EFA91CCC614044300E2E1D634740
14635	Новотроицкое	4	40	1356	142.680216	142.69379900000001	46.895803999999998	46.887287999999998	0103000020E61000000100000005000000E9465854C4D561400E1137A792714740E9465854C4D5614020D099B4A9724740ECDFF59933D6614020D099B4A9724740ECDFF59933D661400E1137A792714740E9465854C4D561400E1137A792714740
14677	Мицулевка	4	40	1356	142.72177199999999	142.74061900000001	46.811093	46.799719000000003	0103000020E6100000010000000500000064E597C118D76140B37E33315D66474064E597C118D76140DC813AE5D16747407BF99D26B3D76140DC813AE5D16747407BF99D26B3D76140B37E33315D66474064E597C118D76140B37E33315D664740
55645	Ключи	4	40	1356	142.65781200000001	142.67464699999999	47.083419999999997	47.072440999999998	0103000020E61000000100000005000000535DC0CB0CD56140DCF126BF45894740535DC0CB0CD5614089EAAD81AD8A4740062B4EB596D5614089EAAD81AD8A4740062B4EB596D56140DCF126BF45894740535DC0CB0CD56140DCF126BF45894740
15093	Высокое	4	40	1356	142.30848399999999	142.32420500000001	46.817075000000003	46.810457999999997	0103000020E61000000100000005000000DB6AD619DFC961400A647616BD674740DB6AD619DFC961408AB0E1E99568474064062AE35FCA61408AB0E1E99568474064062AE35FCA61400A647616BD674740DB6AD619DFC961400A647616BD674740
14820	Воскресенское	4	40	1356	142.521062	142.540941	46.762421000000003	46.738352999999996	0103000020E610000001000000050000000726378AACD06140A5F3E159825E47400726378AACD061404E64E60297614740190280634FD161404E64E60297614740190280634FD16140A5F3E159825E47400726378AACD06140A5F3E159825E4740
15097	Анива	4	40	1356	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
29759	Михайловка	4	40	1314	142.17029600000001	142.18561299999999	50.837232	50.823846000000003	0103000020E6100000010000000500000078D4981073C56140607825C97369494078D4981073C5614014950D6B2A6B4940CC96AC8AF0C5614014950D6B2A6B4940CC96AC8AF0C56140607825C97369494078D4981073C56140607825C973694940
14068	Мгачи	4	40	1314	142.25115400000001	142.301953	51.055021000000004	51.040666000000002	0103000020E610000001000000050000004F081D7409C861409207228B348549404F081D7409C86140EFCB99ED0A874940BB7D5699A9C96140EFCB99ED0A874940BB7D5699A9C961409207228B348549404F081D7409C861409207228B34854940
14057	Мангидай	4	40	1314	142.25654399999999	142.266704	51.099725999999997	51.095211999999997	0103000020E61000000100000005000000853FC39B35C86140E71725E82F8C4940853FC39B35C86140CB4752D2C38C4940CCB6D3D688C86140CB4752D2C38C4940CCB6D3D688C86140E71725E82F8C4940853FC39B35C86140E71725E82F8C4940
14245	Дуэ	4	40	1314	142.10036299999999	142.12202099999999	50.832869000000002	50.816612999999997	0103000020E610000001000000050000004F57772C36C36140853E58C6866849404F57772C36C36140166D8E739B6A49409B8D9598E7C36140166D8E739B6A49409B8D9598E7C36140853E58C6866849404F57772C36C36140853E58C686684940
14113	Арково	4	40	1314	142.25216	142.28477799999999	50.949305000000003	50.941631999999998	0103000020E61000000100000005000000802BD9B111C86140FC6EBA6587784940802BD9B111C86140F37684D382794940D993C0E61CC96140F37684D382794940D993C0E61CC96140FC6EBA6587784940802BD9B111C86140FC6EBA6587784940
14250	Александровск-Сахалинский	4	40	1314	142.12698900000001	142.19465	50.936836	50.868848999999997	0103000020E61000000100000005000000753E3C4B10C46140C614AC71366F4940753E3C4B10C4614094DBF63DEA7749405305A3923AC6614094DBF63DEA7749405305A3923AC66140C614AC71366F4940753E3C4B10C46140C614AC71366F4940
61702	с.Черюмча	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55508	с.Тулуна	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61646	с.Развилка	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61795	с.Нычалах	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61699	с.Нахара	4	34	\N	124.531184	124.537616	56.257872999999996	56.224077000000001	0103000020E61000000100000005000000240A2DEBFE215F4095641D8EAE1C4C40240A2DEBFE215F40BDC282FB01214C409B73F04C68225F40BDC282FB01214C409B73F04C68225F4095641D8EAE1C4C40240A2DEBFE215F4095641D8EAE1C4C40
61719	с.Ботулу	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61763	с. Чукар	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61706	с. Хара-Алдан	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61643	с. Хампа	4	34	\N	125.210086	125.219509	62.626300000000001	62.624070000000003	0103000020E610000001000000050000003DD68C0C724D5F4016359886E14F4F403DD68C0C724D5F400EBE30992A504F405F0B7A6F0C4E5F400EBE30992A504F405F0B7A6F0C4E5F4016359886E14F4F403DD68C0C724D5F4016359886E14F4F40
61605	с. Толон	4	34	\N	130.816283	130.933019	61.481555999999998	61.453932000000002	0103000020E61000000100000005000000FCA886FD1E5A6040CF4D9B711ABA4E40FCA886FD1E5A6040A69883A0A3BD4E407E71A94ADB5D6040A69883A0A3BD4E407E71A94ADB5D6040CF4D9B711ABA4E40FCA886FD1E5A6040CF4D9B711ABA4E40
61655	с. Окоемовка	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61348	с. Норгана	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61693	с. Маягас	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61704	с. Кобяй	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61739	с. Кальвица	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61742	с. Елечей	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55424	пос. Накын	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55443	п. Тикси	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
639	Якутск	4	34	\N	129.593334	129.81023300000001	62.10642	61.949759999999998	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
55602	Юрях-Кюере	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55496	Юрюнг-Хая	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54265	Эмисск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61866	Эйик	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55346	Ытык-Кюель	4	34	\N	129.97073499999999	130.025756	61.681325999999999	61.672682000000002	0103000020E61000000100000005000000A4C2D842103F6040CF4D9B711AD64E40A4C2D842103F60400EF5BBB035D74E40A0353FFED24060400EF5BBB035D74E40A0353FFED2406040CF4D9B711AD64E40A4C2D842103F6040CF4D9B711AD64E40
55503	Шея	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61737	Чычымах	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55597	Чымнай	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55476	Черский	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55560	Хоро	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55403	Хонуу	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55573	Хонгор-Бие	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61682	Хара-Улах	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55351	Хандыга	4	34	\N	130.91417200000001	130.985499	61.608524000000003	61.602384999999998	0103000020E61000000100000005000000685DA3E5405D6040EC4CA1F31ACD4E40685DA3E5405D6040626A4B1DE4CD4E40B4E73235895F6040626A4B1DE4CD4E40B4E73235895F6040EC4CA1F31ACD4E40685DA3E5405D6040EC4CA1F31ACD4E40
55582	Халарчинский наслег	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55548	Уорга	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55376	Удачный	4	34	\N	129.18697299999999	129.28692799999999	56.905033000000003	56.823050000000002	0103000020E610000001000000050000008507CDAEFB256040857CD0B359694C408507CDAEFB2560408066101FD8734C40D009A1832E2960408066101FD8734C40D009A1832E296040857CD0B359694C408507CDAEFB256040857CD0B359694C40
55598	Тымпы	4	34	\N	130.950931	130.956447	62.176264000000003	62.173870999999998	0103000020E610000001000000050000001538D9066E5E6040855CA96741164F401538D9066E5E604028BB99D18F164F406F2BBD369B5E604028BB99D18F164F406F2BBD369B5E6040855CA96741164F401538D9066E5E6040855CA96741164F40
61762	Тыайа	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55574	Туобуя	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55497	Тополиное	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55448	Томмот	4	34	\N	126.201494	126.301108	58.990118000000002	58.908116	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
55458	Тойбохой	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55523	Тинная	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55444	Тикси	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55522	Терют	4	34	\N	124.336187	124.384426	59.380414000000002	59.243799000000003	0103000020E61000000100000005000000C8957A1684155F4015E63DCE349F4D40C8957A1684155F406478EC67B1B04D40DB6E826F9A185F406478EC67B1B04D40DB6E826F9A185F4015E63DCE349F4D40C8957A1684155F4015E63DCE349F4D40
61800	Тасагар	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55357	Сунтар	4	34	\N	130.50110900000001	130.524259	58.687725	58.656739999999999	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
55557	Сулгаччы	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55531	Столбы	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55428	Столбы	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55085	Среднеколымск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55401	Село Чурапча	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55409	Село Черкех	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61741	Село Белькачи	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
39557	Светлый	4	34	\N	124.28842299999999	124.30423399999999	56.525270999999996	56.460903999999999	0103000020E61000000100000005000000821ABE8575125F403C4CFBE6FE3A4C40821ABE8575125F40C34483143C434C403315E29178135F40C34483143C434C403315E29178135F403C4CFBE6FE3A4C40821ABE8575125F403C4CFBE6FE3A4C40
61760	Сатагай	4	34	\N	128.64537799999999	128.66276999999999	62.178863	62.171241999999999	0103000020E61000000100000005000000DA71C3EFA6146040CFD90242EB154F40DA71C3EFA614604073BB97FBE4164F40A3586E693515604073BB97FBE4164F40A3586E6935156040CFD90242EB154F40DA71C3EFA6146040CFD90242EB154F40
55477	Саскылах	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55561	Сайылык	4	34	\N	128.667216	128.676074	61.821333000000003	61.818987999999997	0103000020E61000000100000005000000C66B5ED55915604081E84999D4E84E40C66B5ED5591560401310937021E94E40A1F5F065A21560401310937021E94E40A1F5F065A215604081E84999D4E84E40C66B5ED55915604081E84999D4E84E40
55391	Поселок Эльдикан	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55381	Поселок Чокурдах	4	34	\N	127.783705	127.842608	59.756433000000001	59.663812999999998	0103000020E610000001000000050000008C2D043928F25F406FD40AD3F7D44D408C2D043928F25F40BE4EEACBD2E04D4045D61A4AEDF55F40BE4EEACBD2E04D4045D61A4AEDF55F406FD40AD3F7D44D408C2D043928F25F406FD40AD3F7D44D40
55378	Поселок Чернышевский	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55377	Поселок Хандыга	4	34	\N	130.91417200000001	130.985499	61.608524000000003	61.602384999999998	0103000020E61000000100000005000000685DA3E5405D6040EC4CA1F31ACD4E40685DA3E5405D6040626A4B1DE4CD4E40B4E73235895F6040626A4B1DE4CD4E40B4E73235895F6040EC4CA1F31ACD4E40685DA3E5405D6040EC4CA1F31ACD4E40
55369	Поселок Усть-Нера	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55474	Поселок Усть-Мая	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55365	Поселок Талакан	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55534	Поселок Сангар	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55335	Поселок Пеледуй	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55408	Поселок Зырянка	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55386	Поселок Джебарики-Хая	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55420	Поселок Витим	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55412	Поселок Батагай	4	34	\N	128.070088	128.09794500000001	61.591523000000002	61.562134	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
55389	Поселок Алмазный	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55359	Поселок Айхал	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55432	Олёринский наслег	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55342	Олёкминск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55338	Олекминск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61767	Ойусардах	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61752	Нюрбачан	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55411	Нюрба	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55609	Нефтебаза	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
26979	Нерюнгри	4	34	\N	124.687545	124.746914	56.673901999999998	56.648072999999997	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
55482	Нерюктяйинск 1-й	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55334	Намцы	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55345	Намцы	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
33793	Мирный	4	34	\N	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
55491	Мегино-алдан	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55583	Мача	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61776	Мастах	4	34	\N	129.769386	129.77163200000001	61.890825999999997	61.888834000000003	0103000020E61000000100000005000000028063CF9E38604054C90050C5F14E40028063CF9E38604097361C9606F24E4082919735B138604097361C9606F24E4082919735B138604054C90050C5F14E40028063CF9E38604054C90050C5F14E40
61773	Мар-Кель	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55463	Мар	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55406	Малыкай	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61818	Линдинское	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55333	Ленск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61811	Лекечен	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55473	Кюндяде	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55464	Кутана	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55579	Куду	4	34	\N	124.19354300000001	124.232557	57.267248000000002	57.219926000000001	0103000020E61000000100000005000000AAD72D02630C5F4022C50089269C4C40AAD72D02630C5F40F1F5B52E35A24C402D5DC136E20E5F40F1F5B52E35A24C402D5DC136E20E5F4022C50089269C4C40AAD72D02630C5F4022C50089269C4C40
55563	Кирово	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61352	Кентик (Харыялах)	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55394	Жиганск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55581	Жархан	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55470	Едей	4	34	\N	126.362669	126.383914	61.107719000000003	61.102449999999997	0103000020E61000000100000005000000799109F835975F40D3BCE3141D8D4E40799109F835975F40341477BCC98D4E40809E060C92985F40341477BCC98D4E40809E060C92985F40D3BCE3141D8D4E40799109F835975F40D3BCE3141D8D4E40
55472	Дирин	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55436	Дебдирге	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61624	Витим	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54266	Вилюйск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55421	Верхоянск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61879	Верхневилюск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54711	Верхневилюйск	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61793	Бясь-Кюэль	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61588	Бютяй-Юрдя	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55460	Бютейдях	4	34	\N	128.92620099999999	128.962322	56.443404000000001	56.344092000000003	0103000020E61000000100000005000000B8904770A31D60405A68E7340B2C4C40B8904770A31D604032755776C1384C4015C78157CB1E604032755776C1384C4015C78157CB1E60405A68E7340B2C4C40B8904770A31D60405A68E7340B2C4C40
55559	Быковский	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61731	Борогон	4	34	\N	130.088899	130.13783000000001	62.385922000000001	62.335152000000001	0103000020E61000000100000005000000B534B742D84260403198BF42E62A4F40B534B742D8426040496760E465314F400CCD751A69446040496760E465314F400CCD751A694460403198BF42E62A4F40B534B742D84260403198BF42E62A4F40
55440	Бетюнг	4	34	\N	129.541708	129.71032199999999	60.015269000000004	59.792558	0103000020E6100000010000000500000069FF03AC553160407217618A72E54D4069FF03AC5531604042D2A755F4014E4023F433F5BA36604042D2A755F4014E4023F433F5BA3660407217618A72E54D4069FF03AC553160407217618A72E54D40
61582	Березовка	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55571	Берег-Юрдя	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55388	Батагай-Алыта	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55540	Багадя	4	34	\N	129.06565499999999	129.07191599999999	61.288846999999997	61.285822000000003	0103000020E6100000010000000500000034BA83D819226040193DB7D095A44E4034BA83D8192260401B4641F0F8A44E40E481C8224D2260401B4641F0F8A44E40E481C8224D226040193DB7D095A44E4034BA83D819226040193DB7D095A44E40
61770	Ары-Толон	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55366	Амга	4	34	\N	127.111891	127.11817000000001	59.653989000000003	59.644809000000002	0103000020E61000000100000005000000DF6DDE3829C75F404F95EF1989D24D40DF6DDE3829C75F40CD785BE9B5D34D409357E71890C75F40CD785BE9B5D34D409357E71890C75F404F95EF1989D24D40DF6DDE3829C75F404F95EF1989D24D40
62066	Абый	4	34	\N	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55422	Абага	4	34	\N	130.12072599999999	130.129099	62.235957999999997	62.233258999999997	0103000020E61000000100000005000000DCB8C5FCDC436040B33F506EDB1D4F40DCB8C5FCDC436040629D2ADF331E4F4048DE399421446040629D2ADF331E4F4048DE399421446040B33F506EDB1D4F40DCB8C5FCDC436040B33F506EDB1D4F40
55354	Хатассы	4	34	567	129.607348	129.653719	61.915723	61.894140999999998	0103000020E6100000010000000500000050A912656F336040A181583673F24E4050A912656F336040F698486936F54E40C3B81B44EB346040F698486936F54E40C3B81B44EB346040A181583673F24E4050A912656F336040A181583673F24E40
55374	Тулагино	4	34	567	129.86085299999999	129.89397399999999	62.264173	62.240282000000001	0103000020E610000001000000050000003B35971B8C3B6040A3E8818FC11E4F403B35971B8C3B60403CBEBD6BD0214F402DAF5C6F9B3C60403CBEBD6BD0214F402DAF5C6F9B3C6040A3E8818FC11E4F403B35971B8C3B6040A3E8818FC11E4F40
55426	Пригородный	4	34	567	129.65176099999999	129.71181300000001	61.994204000000003	61.957112000000002	0103000020E61000000100000005000000DD79E239DB346040F94D61A582FA4E40DD79E239DB346040B5C6A01342FF4E40C47B0E2CC7366040B5C6A01342FF4E40C47B0E2CC7366040F94D61A582FA4E40DD79E239DB346040F94D61A582FA4E40
29293	Марха	4	34	567	129.687622	129.79934499999999	62.141185999999998	62.070025999999999	0103000020E610000001000000050000005340DAFF0036604052EFA99CF6084F405340DAFF003660409753026212124F401327F73B943960409753026212124F401327F73B9439604052EFA99CF6084F405340DAFF0036604052EFA99CF6084F40
55363	Маган	4	34	567	129.50870399999999	129.54111499999999	62.115442000000002	62.096764	0103000020E61000000100000005000000056B9C4D473060400FB743C3620C4F40056B9C4D47306040DC4AAFCDC60E4F40008C67D050316040DC4AAFCDC60E4F40008C67D0503160400FB743C3620C4F40056B9C4D473060400FB743C3620C4F40
55402	Капитоновка	4	34	567	129.911688	129.94914800000001	62.331133999999999	62.320934999999999	0103000020E61000000100000005000000FB04508C2C3D60402592E86514294F40FB04508C2C3D6040FD4B5299622A4F400B62A06B5F3E6040FD4B5299622A4F400B62A06B5F3E60402592E86514294F40FB04508C2C3D60402592E86514294F40
55337	Жатай	4	34	567	129.79662300000001	129.850585	62.176431999999998	62.135316000000003	0103000020E61000000100000005000000BA8784EF7D3960401250E10852114F40BA8784EF7D396040E3FBE25295164F40FBAE08FE373B6040E3FBE25295164F40FBAE08FE373B60401250E10852114F40BA8784EF7D3960401250E10852114F40
27669	Чульман	4	34	117	124.871646	124.929722	56.897934999999997	56.823878000000001	0103000020E610000001000000050000001CEC4D0CC9375F406BF294D574694C401CEC4D0CC9375F408577B988EF724C40CA17B490803B5F408577B988EF724C40CA17B490803B5F406BF294D574694C401CEC4D0CC9375F406BF294D574694C40
55358	Чульман	4	34	117	124.871646	124.929722	56.897934999999997	56.823878000000001	0103000020E610000001000000050000001CEC4D0CC9375F406BF294D574694C401CEC4D0CC9375F408577B988EF724C40CA17B490803B5F408577B988EF724C40CA17B490803B5F406BF294D574694C401CEC4D0CC9375F406BF294D574694C40
55371	Удачный	4	34	117	129.18697299999999	129.28692799999999	56.905033000000003	56.823050000000002	0103000020E610000001000000050000008507CDAEFB256040857CD0B359694C408507CDAEFB2560408066101FD8734C40D009A1832E2960408066101FD8734C40D009A1832E296040857CD0B359694C408507CDAEFB256040857CD0B359694C40
23267	Серебряный Бор	4	34	117	124.827646	124.860722	56.683005000000001	56.656238000000002	0103000020E6100000010000000500000093AAED26F8345F403C32569BFF534C4093AAED26F8345F40930035B56C574C40A73CBA1116375F40930035B56C574C40A73CBA1116375F403C32569BFF534C4093AAED26F8345F403C32569BFF534C40
28028	Иенгра	4	34	117	124.82907400000001	124.863884	56.226703999999998	56.220047999999998	0103000020E61000000100000005000000B1FD648C0F355F406DC669882A1C4C40B1FD648C0F355F40AAEFFCA2041D4C4069E21DE049375F40AAEFFCA2041D4C4069E21DE049375F406DC669882A1C4C40B1FD648C0F355F406DC669882A1C4C40
27941	Беркакит	4	34	117	124.762518	124.79236	56.588535999999998	56.564230999999999	0103000020E6100000010000000500000020274C18CD305F40D731AEB838484C4020274C18CD305F406342CC25554B4C4026AAB706B6325F406342CC25554B4C4026AAB706B6325F40D731AEB838484C4020274C18CD305F40D731AEB838484C40
55604	Табага	4	34	7374	129.57959	129.65125800000001	61.865523000000003	61.810952	0103000020E61000000100000005000000D6E253008C3260401A506F46CDE74E40D6E253008C326040C9772975C9EE4E404568041BD7346040C9772975C9EE4E404568041BD73460401A506F46CDE74E40D6E253008C3260401A506F46CDE74E40
55605	Кильдемцы	4	34	7374	129.80495999999999	129.84421599999999	62.285254999999999	62.271144	0103000020E61000000100000005000000D252793BC2396040D940BAD8B4224F40D252793BC23960409F02603C83244F4051D845D1033B60409F02603C83244F4051D845D1033B6040D940BAD8B4224F40D252793BC2396040D940BAD8B4224F40
61749	Кустур	4	34	7538	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61717	Джаргалах	4	34	7538	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61886	уч. Кындал	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61608	с.Тея	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61827	с. Харбала-1	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61829	с. Туора-Кюель	4	34	7314	130.27191300000001	130.30632700000001	62.649144	62.633139999999997	0103000020E610000001000000050000006F4BE482B34860400CE544BB0A514F406F4BE482B348604083328D2617534F4038DC476ECD49604083328D2617534F4038DC476ECD4960400CE544BB0A514F406F4BE482B34860400CE544BB0A514F40
61794	с. Толон	4	34	7314	130.816283	130.933019	61.481555999999998	61.453932000000002	0103000020E61000000100000005000000FCA886FD1E5A6040CF4D9B711ABA4E40FCA886FD1E5A6040A69883A0A3BD4E407E71A94ADB5D6040A69883A0A3BD4E407E71A94ADB5D6040CF4D9B711ABA4E40FCA886FD1E5A6040CF4D9B711ABA4E40
61841	с. Килянки	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54732	Юрюнг-Кюель	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55584	Чыаппара	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55398	Чурапча	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55569	Чакыр	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54722	Хахыйах	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61626	Харбала-2	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55486	Усун-Кюель	4	34	7314	130.78766300000001	130.80640099999999	61.908704	61.905116	0103000020E610000001000000050000009E280989345960400D8B51D7DAF34E409E2809893459604048DFA46950F44E40C64E7809CE59604048DFA46950F44E40C64E7809CE5960400D8B51D7DAF34E409E280989345960400D8B51D7DAF34E40
61703	Усун-Кюель	4	34	7314	130.78766300000001	130.80640099999999	61.908704	61.905116	0103000020E610000001000000050000009E280989345960400D8B51D7DAF34E409E2809893459604048DFA46950F44E40C64E7809CE59604048DFA46950F44E40C64E7809CE5960400D8B51D7DAF34E409E280989345960400D8B51D7DAF34E40
55547	Телей	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55405	Село Чурапча	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54261	Мырыла	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54712	Мельжехси	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55469	Маралайы	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55471	Дябыла	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55511	Беря	4	34	7314	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
8207	Чкалов	4	34	255	127.730013	127.759073	61.200130000000001	61.189796000000001	0103000020E61000000100000005000000E9297288B8EE5F40B0743E3C4B984E40E9297288B8EE5F4068791EDC9D994E40B491EBA694F05F4068791EDC9D994E40B491EBA694F05F40B0743E3C4B984E40E9297288B8EE5F40B0743E3C4B984E40
32622	Чаранг	4	34	255	128.77081899999999	128.78727599999999	61.427832000000002	61.420921	0103000020E6100000010000000500000055849B8CAA1860408D9944BDE0B54E4055849B8CAA1860405517F032C3B64E409F1D705D311960405517F032C3B64E409F1D705D311960408D9944BDE0B54E4055849B8CAA1860408D9944BDE0B54E40
8957	Чапаево	4	34	255	129.37662499999999	129.42210700000001	61.666846	61.650632999999999	0103000020E61000000100000005000000643BDF4F0D2C6040645930F147D34E40643BDF4F0D2C6040F5BBB0355BD54E40350D8AE6812D6040F5BBB0355BD54E40350D8AE6812D6040645930F147D34E40643BDF4F0D2C6040645930F147D34E40
33145	Хоточчу	4	34	255	129.39662100000001	129.42567299999999	61.540992000000003	61.530593000000003	0103000020E6100000010000000500000005FD851EB12C6040473EAF78EAC34E4005FD851EB12C6040E6B2D1393FC54E4049B9FB1C9F2D6040E6B2D1393FC54E4049B9FB1C9F2D6040473EAF78EAC34E4005FD851EB12C6040473EAF78EAC34E40
32628	Харыялах	4	34	255	127.90673	127.920096	61.219620999999997	61.215423000000001	0103000020E61000000100000005000000551344DD07FA5F4032E719FB929B4E40551344DD07FA5F40E5417A8A1C9C4E408C4B55DAE2FA5F40E5417A8A1C9C4E408C4B55DAE2FA5F4032E719FB929B4E40551344DD07FA5F4032E719FB929B4E40
20054	Улахан-Сайылык	4	34	255	128.667216	128.676074	61.821333000000003	61.818987999999997	0103000020E61000000100000005000000C66B5ED55915604081E84999D4E84E40C66B5ED5591560401310937021E94E40A1F5F065A21560401310937021E94E40A1F5F065A215604081E84999D4E84E40C66B5ED55915604081E84999D4E84E40
8871	Улахан-Ан	4	34	255	128.24842200000001	128.2775	61.304909000000002	61.294244999999997	0103000020E610000001000000050000006CB3B112F30760407901F6D1A9A54E406CB3B112F3076040C7A0134207A74E407B14AE47E1086040C7A0134207A74E407B14AE47E10860407901F6D1A9A54E406CB3B112F30760407901F6D1A9A54E40
9020	Тёхтюр	4	34	255	129.44345100000001	129.48191600000001	61.719793000000003	61.705446999999999	0103000020E610000001000000050000001DCC26C0302E6040D90759164CDA4E401DCC26C0302E6040E371512D22DC4E406A6D1ADB6B2F6040E371512D22DC4E406A6D1ADB6B2F6040D90759164CDA4E401DCC26C0302E6040D90759164CDA4E40
8059	Тумул	4	34	255	127.50830000000001	127.54468199999999	61.182237000000001	61.173948000000003	0103000020E61000000100000005000000A323B9FC87E05F40319A95ED43964E40A323B9FC87E05F40828FC18A53974E40122EE411DCE25F40828FC18A53974E40122EE411DCE25F40319A95ED43964E40A323B9FC87E05F40319A95ED43964E40
32527	Тит-Эбя	4	34	255	129.29582099999999	129.33371199999999	61.494118	61.471915000000003	0103000020E610000001000000050000000A0F9A5D77296040F5BEF1B567BC4E400A0F9A5D77296040B62E35423FBF4E400CC9C9C4AD2A6040B62E35423FBF4E400CC9C9C4AD2A6040F5BEF1B567BC4E400A0F9A5D77296040F5BEF1B567BC4E40
32663	Тит-Ары	4	34	255	127.70256000000001	127.74992899999999	61.228253000000002	61.218564000000001	0103000020E6100000010000000500000094DE37BEF6EC5F409E0AB8E7F99B4E4094DE37BEF6EC5F40611BF164379D4E409B5434D6FEEF5F40611BF164379D4E409B5434D6FEEF5F409E0AB8E7F99B4E4094DE37BEF6EC5F409E0AB8E7F99B4E40
55543	Техтюр	4	34	255	129.44345100000001	129.48191600000001	61.719793000000003	61.705446999999999	0103000020E610000001000000050000001DCC26C0302E6040D90759164CDA4E401DCC26C0302E6040E371512D22DC4E406A6D1ADB6B2F6040E371512D22DC4E406A6D1ADB6B2F6040D90759164CDA4E401DCC26C0302E6040D90759164CDA4E40
8043	Синск	4	34	255	126.812186	126.85305099999999	61.137900000000002	61.127752999999998	0103000020E610000001000000050000003811FDDAFAB35F40A27BD6355A904E403811FDDAFAB35F40280F0BB5A6914E407CB4386398B65F40280F0BB5A6914E407CB4386398B65F40A27BD6355A904E403811FDDAFAB35F40A27BD6355A904E40
8642	Покровск	4	34	255	129.11896999999999	129.18293	61.503086000000003	61.470089000000002	0103000020E6100000010000000500000090662C9ACE236040CC9A58E02BBC4E4090662C9ACE236040A9893E1F65C04E40A2EE0390DA256040A9893E1F65C04E40A2EE0390DA256040CC9A58E02BBC4E4090662C9ACE236040CC9A58E02BBC4E40
55350	Покровск	4	34	255	129.11896999999999	129.18293	61.503086000000003	61.470089000000002	0103000020E6100000010000000500000090662C9ACE236040CC9A58E02BBC4E4090662C9ACE236040A9893E1F65C04E40A2EE0390DA256040A9893E1F65C04E40A2EE0390DA256040CC9A58E02BBC4E4090662C9ACE236040CC9A58E02BBC4E40
9009	Октёмцы	4	34	255	129.405676	129.44616300000001	61.683152	61.667276999999999	0103000020E61000000100000005000000B5183C4CFB2C6040BE2F2E5569D54E40B5183C4CFB2C60403719558671D74E40EEB5A0F7462E60403719558671D74E40EEB5A0F7462E6040BE2F2E5569D54E40B5183C4CFB2C6040BE2F2E5569D54E40
55361	Ой	4	34	255	124.434498	130.3169	62.006096999999997	60.552097000000003	0103000020E610000001000000050000005B0BB3D0CE1B5F40209C4F1DAB464E405B0BB3D0CE1B5F4046CD57C9C7004F404703780B244A604046CD57C9C7004F404703780B244A6040209C4F1DAB464E405B0BB3D0CE1B5F40209C4F1DAB464E40
8545	Мохсоголлох	4	34	255	128.911486	128.97080199999999	61.405099999999997	61.389145999999997	0103000020E610000001000000050000006118B0E42A1D604042AF3F89CFB14E406118B0E42A1D604007CE1951DAB34E40861C5BCF101F604007CE1951DAB34E40861C5BCF101F604042AF3F89CFB14E406118B0E42A1D604042AF3F89CFB14E40
32537	Кёрдём	4	34	255	129.17983100000001	129.20927800000001	61.435757000000002	61.425460999999999	0103000020E61000000100000005000000D3F9F02CC12560409A5C8C8175B64E40D3F9F02CC12560406500A8E2C6B74E40B7B8C667B22660406500A8E2C6B74E40B7B8C667B22660409A5C8C8175B64E40D3F9F02CC12560409A5C8C8175B64E40
33037	Кытыл-Дюра	4	34	255	125.889302	125.93849400000001	60.975031000000001	60.954234999999997	0103000020E610000001000000050000001D91EF52EA785F406AD95A5F247A4E401D91EF52EA785F4008CBD8D0CD7C4E40815F2349107C5F4008CBD8D0CD7C4E40815F2349107C5F406AD95A5F247A4E401D91EF52EA785F406AD95A5F247A4E40
61683	Кытанах-Кырдал (Тойон-Ары)	4	34	255	128.37294600000001	128.39443399999999	61.242201999999999	61.235514000000002	0103000020E610000001000000050000009225732CEF0B604005E09F52259E4E409225732CEF0B60404D83A279009F4E40C64D0D349F0C60404D83A279009F4E40C64D0D349F0C604005E09F52259E4E409225732CEF0B604005E09F52259E4E40
9223	Кысыл-Юрюйя	4	34	255	129.01370499999999	129.035112	61.363066000000003	61.356019000000003	0103000020E6100000010000000500000055D977457020604098E0D40792AD4E4055D977457020604010255AF278AE4E404F7633A31F21604010255AF278AE4E404F7633A31F21604098E0D40792AD4E4055D977457020604098E0D40792AD4E40
9227	Качикатцы	4	34	255	128.918421	128.964361	61.328330999999999	61.310304000000002	0103000020E61000000100000005000000B5DE6FB4631D6040B4E89D0AB8A74E40B5DE6FB4631D6040A9A10DC006AA4E403691990BDC1E6040A9A10DC006AA4E403691990BDC1E6040B4E89D0AB8A74E40B5DE6FB4631D6040B4E89D0AB8A74E40
7895	Исит	4	34	255	125.299244	125.34963	60.815188999999997	60.807971000000002	0103000020E610000001000000050000008D614ED026535F40E78EFE976B674E408D614ED026535F408B87F71C58684E40D5EC815660565F408B87F71C58684E40D5EC815660565F40E78EFE976B674E408D614ED026535F40E78EFE976B674E40
29555	Едей	4	34	255	126.362669	126.383914	61.107719000000003	61.102449999999997	0103000020E61000000100000005000000799109F835975F40D3BCE3141D8D4E40799109F835975F40341477BCC98D4E40809E060C92985F40341477BCC98D4E40809E060C92985F40D3BCE3141D8D4E40799109F835975F40D3BCE3141D8D4E40
14110	Булгунняхтах	4	34	255	128.62236300000001	128.70619400000001	61.308162000000003	61.292637999999997	0103000020E61000000100000005000000B267CF65EA1360408EC8772975A54E40B267CF65EA1360405BEF37DA71A74E4035D42824991660405BEF37DA71A74E4035D42824991660408EC8772975A54E40B267CF65EA1360408EC8772975A54E40
55349	Бестях	4	34	255	128.83053000000001	128.90285299999999	61.37771	61.348604999999999	0103000020E610000001000000050000001A8BA6B3931A60406D1CB1169FAC4E401A8BA6B3931A6040A3AF20CD58B04E400E83F92BE41C6040A3AF20CD58B04E400E83F92BE41C60406D1CB1169FAC4E401A8BA6B3931A60406D1CB1169FAC4E40
20228	Батамай	4	34	255	127.33996399999999	127.35001699999999	61.136141000000002	61.132745	0103000020E610000001000000050000004F745DF8C1D55F4090DAC4C9FD904E404F745DF8C1D55F4087527B116D914E40D102B4AD66D65F4087527B116D914E40D102B4AD66D65F4090DAC4C9FD904E404F745DF8C1D55F4090DAC4C9FD904E40
61853	с. Хайыр	4	34	7540	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61854	с. Сайылык	4	34	7540	128.667216	128.676074	61.821333000000003	61.818987999999997	0103000020E61000000100000005000000C66B5ED55915604081E84999D4E84E40C66B5ED5591560401310937021E94E40A1F5F065A21560401310937021E94E40A1F5F065A215604081E84999D4E84E40C66B5ED55915604081E84999D4E84E40
61852	с. Казачье	4	34	7540	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61857	Уянди	4	34	7540	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61858	Усть-Янск	4	34	7540	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61856	Тумат	4	34	7540	130.07580200000001	130.174823	59.687361000000003	59.625031	0103000020E6100000010000000500000016DF50F86C4260403BFE0B0401D04D4016DF50F86C426040DFC5FB71FBD74D40D672672698456040DFC5FB71FBD74D40D6726726984560403BFE0B0401D04D4016DF50F86C4260403BFE0B0401D04D40
61859	Поселок Усть-Куйга	4	34	7540	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61860	Поселок Нижнеянск	4	34	7540	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61855	Поселок Депутатский	4	34	7540	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54723	Эжанцы	4	34	7334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55588	Троицк	4	34	7334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61753	Село Усть-Миль	4	34	7334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61692	Поселок Югоренок	4	34	7334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61849	Поселок Эльдикан	4	34	7334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55504	Поселок Солнечный	4	34	7334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61613	Поселок Звездочка	4	34	7334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55135	с.Чериктей	4	34	240	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
32751	Элясин	4	34	240	130.52319	130.53984399999999	62.623643999999999	62.620471000000002	0103000020E610000001000000050000000473F4F8BD506040E78EFE976B4F4F400473F4F8BD5060405E2C0C91D34F4F40239EEC66465160405E2C0C91D34F4F40239EEC6646516040E78EFE976B4F4F400473F4F8BD506040E78EFE976B4F4F40
61628	Чаран	4	34	240	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
5597	Хоногор	4	34	240	130.10444899999999	130.13588999999999	62.482996	62.458393000000001	0103000020E6100000010000000500000032E36DA55743604090DB2F9FAC3A4F4032E36DA557436040A60C1CD0D23D4F404F3BFC3559446040A60C1CD0D23D4F404F3BFC355944604090DB2F9FAC3A4F4032E36DA55743604090DB2F9FAC3A4F40
55586	Хомустах	4	34	240	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
55429	Усун-Кюель	4	34	240	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
5721	Тумул	4	34	240	130.26932600000001	130.29499999999999	62.561981000000003	62.549666999999999	0103000020E61000000100000005000000CD3E8F519E4860406058FE7C5B464F40CD3E8F519E48604098FC4FFEEE474F403D0AD7A37049604098FC4FFEEE474F403D0AD7A3704960406058FE7C5B464F40CD3E8F519E4860406058FE7C5B464F40
61632	Танда	4	34	240	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
5119	Сырдах	4	34	240	130.862672	130.90413799999999	62.567042000000001	62.556480000000001	0103000020E6100000010000000500000099654F029B5B6040657094BC3A474F4099654F029B5B6040AEBA0ED594484F4044A2D0B2EE5C6040AEBA0ED594484F4044A2D0B2EE5C6040657094BC3A474F4099654F029B5B6040657094BC3A474F40
5668	Сасылыкан	4	34	240	130.64024900000001	130.665582	62.478926999999999	62.473506	0103000020E610000001000000050000007F8978EB7C546040DA3A38D89B3C4F407F8978EB7C546040F015DD7A4D3D4F40CD599F724C556040F015DD7A4D3D4F40CD599F724C556040DA3A38D89B3C4F407F8978EB7C546040DA3A38D89B3C4F40
5589	Огородтах	4	34	240	130.124841	130.157656	62.462027999999997	62.435318000000002	0103000020E6100000010000000500000066868DB2FE43604019AE0E80B8374F4066868DB2FE4360400BEBC6BB233B4F40958098840B4560400BEBC6BB233B4F40958098840B45604019AE0E80B8374F4066868DB2FE43604019AE0E80B8374F40
55524	Бээди	4	34	240	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
55553	Балаганнах	4	34	240	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
5493	Арылах	4	34	240	130.91839400000001	130.97061299999999	62.454013000000003	62.448616000000001	0103000020E61000000100000005000000F75AD07B635D60402E3BC43F6C394F40F75AD07B635D6040BC7A15191D3A4F405182FE420F5F6040BC7A15191D3A4F405182FE420F5F60402E3BC43F6C394F40F75AD07B635D60402E3BC43F6C394F40
5230	Ары-Тит	4	34	240	130.038872	130.059991	62.513807	62.505173999999997	0103000020E610000001000000050000005D177E703E4160400E65A88AA9404F405D177E703E4160405ABA826DC4414F40BDE13E72EB4160405ABA826DC4414F40BDE13E72EB4160400E65A88AA9404F405D177E703E4160400E65A88AA9404F40
61671	с.Теплый Ключ	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61840	с.Охотский Перевоз	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61833	с.Кескиль	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61685	п.Аэропорт	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55596	Ударник	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61667	Сайды	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61748	Новый	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55483	Крест-Хальджайы	4	34	7371	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61665	с. Уолба	4	34	7366	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55590	с. Туора-Кюель	4	34	7366	130.27191300000001	130.30632700000001	62.649144	62.633139999999997	0103000020E610000001000000050000006F4BE482B34860400CE544BB0A514F406F4BE482B348604083328D2617534F4038DC476ECD49604083328D2617534F4038DC476ECD4960400CE544BB0A514F406F4BE482B34860400CE544BB0A514F40
55449	Усть-Татта	4	34	7366	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55456	Кыйы	4	34	7366	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61577	Дайа-Амга	4	34	7366	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55413	Боробул	4	34	7366	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61697	с.Кемпендяй	4	34	7367	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55414	Сунтар	4	34	7367	130.50110900000001	130.524259	58.687725	58.656739999999999	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
55427	с.Сунтар	4	34	7316	130.50110900000001	130.524259	58.687725	58.656739999999999	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
61839	с.Кюндяе	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61686	с.Куокуну	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61846	с.Аллага	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55417	Эльгяй	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61659	Хордогой	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55546	Хадан	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61781	Усун-Кюель	4	34	7316	130.78766300000001	130.80640099999999	61.908704	61.905116	0103000020E610000001000000050000009E280989345960400D8B51D7DAF34E409E2809893459604048DFA46950F44E40C64E7809CE59604048DFA46950F44E40C64E7809CE5960400D8B51D7DAF34E409E280989345960400D8B51D7DAF34E40
61616	Устье	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55555	Тюбяй	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61727	Туойдах	4	34	7316	128.70544000000001	128.711872	62.352764999999998	62.350923999999999	0103000020E610000001000000050000004A29E8F692166040D5B0DF13EB2C4F404A29E8F69216604033164D67272D4F4005DEC9A7C716604033164D67272D4F4005DEC9A7C7166040D5B0DF13EB2C4F404A29E8F692166040D5B0DF13EB2C4F40
61666	Толон	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54267	Тенькя	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55591	Кюкей	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61751	Крестях	4	34	7316	129.52371500000001	129.52887999999999	60.701197999999998	60.697957000000002	0103000020E6100000010000000500000097ADF545C2306040D481ACA756594E4097ADF545C2306040A30227DBC0594E4045F0BF95EC306040A30227DBC0594E4045F0BF95EC306040D481ACA756594E4097ADF545C2306040D481ACA756594E40
54707	Илимнир	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55407	Бордон	4	34	7316	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61718	с.Эбях	4	34	7537	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61745	с.Аргахтах	4	34	7537	126.33634000000001	126.39474800000001	59.553789999999999	59.531913000000003	0103000020E610000001000000050000008C15359886955F409CA8A5B915C44D408C15359886955F40096D3997E2C64D40558A1D8D43995F40096D3997E2C64D40558A1D8D43995F409CA8A5B915C44D408C15359886955F409CA8A5B915C44D40
61691	Сылгы-Ытар	4	34	7537	127.848016	127.90814899999999	61.011884000000002	60.971848000000001	0103000020E61000000100000005000000069FE6E445F65F406D57E883657C4E40069FE6E445F65F403FAC376A85814E4049B9FB1C1FFA5F403FAC376A85814E4049B9FB1C1FFA5F406D57E883657C4E40069FE6E445F65F406D57E883657C4E40
61714	Алеко-Кюель	4	34	7537	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55385	Оленек	4	34	7362	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55501	Жилинда	4	34	7362	126.117079	126.21625299999999	57.462567999999997	57.371248999999999	0103000020E610000001000000050000001903EB387E875F401BD6541685AF4C401903EB387E875F408B16A06D35BB4C405CAAD216D78D5F408B16A06D35BB4C405CAAD216D78D5F401BD6541685AF4C401903EB387E875F401BD6541685AF4C40
55499	Юнкюр	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
54262	Центральная Абага	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61789	Хоринцы	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
55526	Урицкое	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61622	Уолбут	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61784	Улахан-Мунку	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61836	Тяня	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61681	Троицк	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
54724	Токко	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61678	Солянка	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61668	Селиваново	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
31751	Саныяхтах	4	34	200	124.04082099999999	124.08444299999999	60.590223000000002	60.580964999999999	0103000020E610000001000000050000005CFFAECF9C025F40718FA50F5D4A4E405CFFAECF9C025F406B2C616D8C4B4E4012D89C8367055F406B2C616D8C4B4E4012D89C8367055F40718FA50F5D4A4E405CFFAECF9C025F40718FA50F5D4A4E40
54730	Олекминск	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61757	Нерюктяйинск-2	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
55565	Марха	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
31756	Малыкан	4	34	200	124.723226	124.738479	60.685955	60.682563000000002	0103000020E610000001000000050000007B67B455492E5F40D63A71395E574E407B67B455492E5F408BC3995FCD574E4019726C3D432F5F408BC3995FCD574E4019726C3D432F5F40D63A71395E574E407B67B455492E5F40D63A71395E574E40
61801	Кяччи	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
55084	Кыллах	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61803	Куду-Кюэль	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
55533	Иннях	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61798	Дельгей	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61779	Даппарай	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
61609	Дабан	4	34	200	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
54716	Ючюгей	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54725	Хара-Тумул	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55433	Поселок Усть-Нера	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55580	Поселок Усть-Нера	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61648	Поселок Артык	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55520	Орто-Балаган	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55507	Оймякон	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54263	Куйдусун	4	34	7315	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61847	с. Акана	4	34	7368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55606	Энгольжа	4	34	7368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55461	Чаппанда	4	34	7368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61848	Сюля	4	34	7368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55425	Село Антоновка	4	34	7368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61631	Поселок Бысыттах	4	34	7368	130.55717300000001	130.560667	61.967955000000003	61.966597	0103000020E61000000100000005000000DBA6785CD4516040B3B45373B9FB4E40DBA6785CD4516040F67F0EF3E5FB4E40499EEBFBF0516040F67F0EF3E5FB4E40499EEBFBF0516040B3B45373B9FB4E40DBA6785CD4516040B3B45373B9FB4E40
61850	Нефтебаза	4	34	7368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61663	Киров	4	34	7368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55558	Арангастах	4	34	7368	127.494259	127.498769	61.731065999999998	61.729272000000002	0103000020E610000001000000050000003C3080F0A1DF5F40BBF1EEC858DD4E403C3080F0A1DF5F40D89B189293DD4E408DD0CFD4EBDF5F40D89B189293DD4E408DD0CFD4EBDF5F40BBF1EEC858DD4E403C3080F0A1DF5F40BBF1EEC858DD4E40
62081	Походский наслег	4	34	7361	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55380	Поселок Черский	4	34	7361	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
40346	Нерюнгри	4	34	6894	124.000989	131.00103899999999	58.566597999999999	55.489896000000002	0103000020E61000000100000005000000F8A92A3410005F407A3881E9B4BE4B40F8A92A3410005F4050FD834886484D40A8E0F0820860604050FD834886484D40A8E0F082086060407A3881E9B4BE4B40F8A92A3410005F407A3881E9B4BE4B40
55556	с.Фрунзе	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
57575	с.Красная Деревня	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
55612	с.Аппаны	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
55465	Ымыяхтах	4	34	1301	129.84232	129.90908300000001	62.466611999999998	62.450763000000002	0103000020E6100000010000000500000089981249F43A6040999F1B9AB2394F4089981249F43A6040E8F527F1B93B4F40304B3B35173D6040E8F527F1B93B4F40304B3B35173D6040999F1B9AB2394F4089981249F43A6040999F1B9AB2394F40
61649	Хатас	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
54260	Сыгыннах	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
61602	Село Маймага	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
25839	Партизан	4	34	1301	129.76008899999999	129.77769599999999	62.592838999999998	62.577451000000003	0103000020E6100000010000000500000094A12AA652386040710514EAE9494F4094A12AA6523860408C65FA25E24B4F405CC7B8E2E23860408C65FA25E24B4F405CC7B8E2E2386040710514EAE9494F4094A12AA652386040710514EAE9494F40
55567	Никольский	4	34	1301	129.70910000000001	129.720698	62.632561000000003	62.618729000000002	0103000020E61000000100000005000000FFB27BF2B03660401C0B0A83324F4F40FFB27BF2B0366040CFDC43C2F7504F405D8940F50F376040CFDC43C2F7504F405D8940F50F3760401C0B0A83324F4F40FFB27BF2B03660401C0B0A83324F4F40
54203	Намцы	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
55487	Намцы	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
55521	Кюренг-Ат	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
16869	Кысыл-Сыр	4	34	1301	129.74370300000001	129.781576	62.543301	62.521554000000002	0103000020E61000000100000005000000FDDD3B6ACC3760408B8C0E48C2424F40FDDD3B6ACC3760402A711DE38A454F40D5EAABAB023960402A711DE38A454F40D5EAABAB023960408B8C0E48C2424F40FDDD3B6ACC3760408B8C0E48C2424F40
26078	Крест-Кытыл	4	34	1301	129.69434999999999	129.713673	62.667352000000001	62.649754999999999	0103000020E6100000010000000500000048BF7D1D38366040CCB4FD2B2B534F4048BF7D1D38366040C97553CA6B554F403961C268D6366040C97553CA6B554F403961C268D6366040CCB4FD2B2B534F4048BF7D1D38366040CCB4FD2B2B534F40
25937	Ергёлёх (Тастах)	4	34	1301	128.85945599999999	128.872409	62.586801000000001	62.580285000000003	0103000020E610000001000000050000003B8BDEA9801B604000AE64C7464A4F403B8BDEA9801B60404B21904B1C4B4F408E7747C6EA1B60404B21904B1C4B4F408E7747C6EA1B604000AE64C7464A4F403B8BDEA9801B604000AE64C7464A4F40
55489	Графский Берег	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
61768	Булус	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
55570	Аппаны	4	34	1301	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
61835	с. Чумпу-Кытыл	4	34	7336	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61581	Суон-Тиит	4	34	7336	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55519	Соболох	4	34	7336	129.37947299999999	129.389884	62.335203	62.330699000000003	0103000020E61000000100000005000000E1968FA4242C6040F3E84658542A4F40E1968FA4242C6040B34291EEE72A4F407AA702EE792C6040B34291EEE72A4F407AA702EE792C6040F3E84658542A4F40E1968FA4242C6040F3E84658542A4F40
55516	Сасыр	4	34	7336	126.555942	126.57952299999999	59.217692	59.187263000000002	0103000020E61000000100000005000000431EC18D94A35F401C60E63BF8974D40431EC18D94A35F40E84CDA54DD9B4D40E811A3E716A55F40E84CDA54DD9B4D40E811A3E716A55F401C60E63BF8974D40431EC18D94A35F401C60E63BF8974D40
55517	Кулун-Елбют	4	34	7336	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54731	Буор-Сысы	4	34	7336	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61799	п. Сюльдюкар	4	34	7352	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61661	п. Заря	4	34	7352	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55437	Чернышевский	4	34	7352	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55490	Удачный	4	34	7352	129.18697299999999	129.28692799999999	56.905033000000003	56.823050000000002	0103000020E610000001000000050000008507CDAEFB256040857CD0B359694C408507CDAEFB2560408066101FD8734C40D009A1832E2960408066101FD8734C40D009A1832E296040857CD0B359694C408507CDAEFB256040857CD0B359694C40
55352	Мирный	4	34	7352	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
55136	Айхал	4	34	7352	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61744	с. Хапчагай	4	34	496	129.57499999999999	130.999045	62.456595999999998	60.834598	0103000020E6100000010000000500000066666666663260404CA7751BD46A4E40666666666632604001BEDBBC713A4F406F47382DF85F604001BEDBBC713A4F406F47382DF85F60404CA7751BD46A4E4066666666663260404CA7751BD46A4E40
55379	Ытык-Кюель	4	34	496	129.97073499999999	130.025756	61.681325999999999	61.672682000000002	0103000020E61000000100000005000000A4C2D842103F6040CF4D9B711AD64E40A4C2D842103F60400EF5BBB035D74E40A0353FFED24060400EF5BBB035D74E40A0353FFED2406040CF4D9B711AD64E40A4C2D842103F6040CF4D9B711AD64E40
55512	Чюйя	4	34	496	130.353453	130.381058	61.735267	61.724204999999998	0103000020E610000001000000050000008A75AA7C4F4B6040C24CDBBFB2DC4E408A75AA7C4F4B6040FD69A33A1DDE4E4022FC8BA0314C6040FD69A33A1DDE4E4022FC8BA0314C6040C24CDBBFB2DC4E408A75AA7C4F4B6040C24CDBBFB2DC4E40
32761	Хочо	4	34	496	130.72016300000001	130.75614999999999	61.576037999999997	61.559396	0103000020E61000000100000005000000429946930B576040B1C1C2499AC74E40429946930B5760406AA0F99CBBC94E40DA1B7C61325860406AA0F99CBBC94E40DA1B7C6132586040B1C1C2499AC74E40429946930B576040B1C1C2499AC74E40
23557	Хоробут	4	34	496	130.73342199999999	130.769993	61.842368	61.824790999999998	0103000020E6100000010000000500000057056A31785760407F8461C092E94E4057056A31785760403599F1B6D2EB4E40C4245CC8A35860403599F1B6D2EB4E40C4245CC8A35860407F8461C092E94E4057056A31785760407F8461C092E94E40
5873	Хомустах	4	34	496	129.851034	129.86443700000001	61.843328	61.837344999999999	0103000020E6100000010000000500000017B9A7AB3B3B60400C3CF71E2EEB4E4017B9A7AB3B3B60408AE6012CF2EB4E407A8EC877A93B60408AE6012CF2EB4E407A8EC877A93B60400C3CF71E2EEB4E4017B9A7AB3B3B60400C3CF71E2EEB4E40
32666	Хатылыма	4	34	496	129.87848700000001	129.89446799999999	61.546140000000001	61.538834999999999	0103000020E61000000100000005000000C2DEC4901C3C60405778978BF8C44E40C2DEC4901C3C6040CB845FEAE7C54E4031EA5A7B9F3C6040CB845FEAE7C54E4031EA5A7B9F3C60405778978BF8C44E40C2DEC4901C3C60405778978BF8C44E40
23463	Хаптагай	4	34	496	129.760188	129.81833499999999	61.799194999999997	61.769666999999998	0103000020E61000000100000005000000F9D9C87553386040BCE7C07284E24E40F9D9C87553386040381092054CE64E4082C5E1CC2F3A6040381092054CE64E4082C5E1CC2F3A6040BCE7C07284E24E40F9D9C87553386040BCE7C07284E24E40
55446	Улухан-Кюель	4	34	496	129.57499999999999	130.999045	62.456595999999998	60.834598	0103000020E6100000010000000500000066666666663260404CA7751BD46A4E40666666666632604001BEDBBC713A4F406F47382DF85F604001BEDBBC713A4F406F47382DF85F60404CA7751BD46A4E4066666666663260404CA7751BD46A4E40
23662	Тюнгюлю	4	34	496	130.693366	130.73576700000001	62.201749999999997	62.183926999999997	0103000020E6100000010000000500000011C5E40D30566040FAEC80EB8A174F4011C5E40D30566040E7FBA9F1D2194F403C4F3C678B576040E7FBA9F1D2194F403C4F3C678B576040FAEC80EB8A174F4011C5E40D30566040FAEC80EB8A174F40
2972	Томтор	4	34	496	130.01630599999999	130.06029699999999	62.159984000000001	62.145667000000003	0103000020E610000001000000050000005017299485406040A08D5C37A5124F4050172994854060400FF10F5B7A144F408061F9F3ED4160400FF10F5B7A144F408061F9F3ED416040A08D5C37A5124F405017299485406040A08D5C37A5124F40
32752	Телиги	4	34	496	130.68195800000001	130.703113	61.387656	61.376640999999999	0103000020E61000000100000005000000DC679599D255604097AAB4C535B04E40DC679599D2556040910C39B69EB14E408F8CD5E67F566040910C39B69EB14E408F8CD5E67F56604097AAB4C535B04E40DC679599D255604097AAB4C535B04E40
22565	Тарат	4	34	496	130.670783	130.69489400000001	62.226534999999998	62.217554999999997	0103000020E61000000100000005000000CFF6E80D77556040670A9DD7D81B4F40CFF6E80D775560401E335019FF1C4F40F98557923C5660401E335019FF1C4F40F98557923C566040670A9DD7D81B4F40CFF6E80D77556040670A9DD7D81B4F40
23407	Табага	4	34	496	130.90844100000001	130.97844699999999	61.674292000000001	61.654246999999998	0103000020E610000001000000050000000F2BDCF2115D6040C8409E5DBED34E400F2BDCF2115D60402BFA43334FD64E40D13B15704F5F60402BFA43334FD64E40D13B15704F5F6040C8409E5DBED34E400F2BDCF2115D6040C8409E5DBED34E40
22997	Сымах	4	34	496	130.93938800000001	130.97850099999999	61.929544	61.916744000000001	0103000020E6100000010000000500000028486C770F5E6040F1660DDE57F54E4028486C770F5E6040B5183C4CFBF64E404E4354E14F5F6040B5183C4CFBF64E404E4354E14F5F6040F1660DDE57F54E4028486C770F5E6040F1660DDE57F54E40
22808	Суола	4	34	496	130.55766700000001	130.57662999999999	61.912796	61.899023	0103000020E61000000100000005000000DFE17668D851604008AD872F13F34E40DFE17668D8516040B6F5D37FD6F44E408FFCC1C073526040B6F5D37FD6F44E408FFCC1C07352604008AD872F13F34E40DFE17668D851604008AD872F13F34E40
32801	Рассолода	4	34	496	129.64036999999999	129.667427	61.684517999999997	61.667541999999997	0103000020E61000000100000005000000DDEA39E97D3460406C5A290472D54E40DDEA39E97D346040FCC22B499ED74E40F52EDE8F5B356040FCC22B499ED74E40F52EDE8F5B3560406C5A290472D54E40DDEA39E97D3460406C5A290472D54E40
23563	Петровка	4	34	496	130.24700300000001	130.26623499999999	61.730060000000002	61.722321000000001	0103000020E6100000010000000500000072E0D572E7476040651BB80375DC4E4072E0D572E7476040130F289B72DD4E409E4143FF84486040130F289B72DD4E409E4143FF84486040651BB80375DC4E4072E0D572E7476040651BB80375DC4E40
22306	Павловск	4	34	496	129.81975499999999	129.87845100000001	61.893946	61.856884000000001	0103000020E610000001000000050000007077D66E3B3A60409B3BFA5FAEED4E407077D66E3B3A6040EC3191D26CF24E406F8445451C3C6040EC3191D26CF24E406F8445451C3C60409B3BFA5FAEED4E407077D66E3B3A60409B3BFA5FAEED4E40
55375	Нижний Бестях	4	34	496	129.88257400000001	129.94662400000001	61.986345	61.932842000000001	0103000020E610000001000000050000009949D40B3E3C6040E92ADD5D67F74E409949D40B3E3C60405CC98E8D40FE4E407B336ABE4A3E60405CC98E8D40FE4E407B336ABE4A3E6040E92ADD5D67F74E409949D40B3E3C6040E92ADD5D67F74E40
18838	Нижний Бестях	4	34	496	129.88257400000001	129.94662400000001	61.986345	61.932842000000001	0103000020E610000001000000050000009949D40B3E3C6040E92ADD5D67F74E409949D40B3E3C60405CC98E8D40FE4E407B336ABE4A3E60405CC98E8D40FE4E407B336ABE4A3E6040E92ADD5D67F74E409949D40B3E3C6040E92ADD5D67F74E40
22998	Матта	4	34	496	130.61081999999999	130.672687	62.360912999999996	62.350206	0103000020E61000000100000005000000C47762D68B536040766EDA8CD32C4F40C47762D68B536040C2D9AD65322E4F40382EE3A686556040C2D9AD65322E4F40382EE3A686556040766EDA8CD32C4F40C47762D68B536040766EDA8CD32C4F40
22074	Майя	4	34	496	130.24759499999999	130.32193100000001	61.749476000000001	61.720446000000003	0103000020E61000000100000005000000E674594CEC4760405B44149337DC4E40E674594CEC47604086915ED4EEDF4E4032923D424D4A604086915ED4EEDF4E4032923D424D4A60405B44149337DC4E40E674594CEC4760405B44149337DC4E40
32831	Ломтука	4	34	496	130.07096899999999	130.10709900000001	61.641672999999997	61.632201999999999	0103000020E61000000100000005000000F4C0C760454260409F3BC1FEEBD04E40F4C0C76045426040F4DC425722D24E40E6CDE15A6D436040F4DC425722D24E40E6CDE15A6D4360409F3BC1FEEBD04E40F4C0C760454260409F3BC1FEEBD04E40
22665	Даркылах	4	34	496	130.36280400000001	130.38419300000001	60.981678000000002	60.966036000000003	0103000020E61000000100000005000000755B22179C4B60401C615111A77B4E40755B22179C4B6040F299EC9FA77D4E40454B1E4F4B4C6040F299EC9FA77D4E40454B1E4F4B4C60401C615111A77B4E40755B22179C4B60401C615111A77B4E40
22559	Бёкё	4	34	496	130.36749399999999	130.39058900000001	61.790273999999997	61.782817999999999	0103000020E610000001000000050000003DEFC682C24B60402D5C566133E44E403DEFC682C24B60408670CCB227E54E40ADA580B47F4C60408670CCB227E54E40ADA580B47F4C60402D5C566133E44E403DEFC682C24B60402D5C566133E44E40
22466	Бырама	4	34	496	130.927638	130.959214	61.483983000000002	61.476039999999998	0103000020E61000000100000005000000DC10E335AF5D60403ECBF3E0EEBC4E40DC10E335AF5D6040F568AA27F3BD4E40B1FB8EE1B15E6040F568AA27F3BD4E40B1FB8EE1B15E60403ECBF3E0EEBC4E40DC10E335AF5D60403ECBF3E0EEBC4E40
5485	Бейдинга	4	34	496	130.84695099999999	130.876497	62.402309000000002	62.387096999999997	0103000020E6100000010000000500000010CAFB381A5B60409AB0FD648C314F4010CAFB381A5B604078F17EDC7E334F4059C16F430C5C604078F17EDC7E334F4059C16F430C5C60409AB0FD648C314F4010CAFB381A5B60409AB0FD648C314F40
6203	Балыктах	4	34	496	130.68780599999999	130.74738199999999	62.260387999999999	62.247736000000003	0103000020E61000000100000005000000C37FBA81025660405C0531D0B51F4F40C37FBA8102566040AB22DC6454214F40CFF3A78DEA576040AB22DC6454214F40CFF3A78DEA5760405C0531D0B51F4F40C37FBA81025660405C0531D0B51F4F40
61708	с. Натора	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55611	с. Батамай	4	34	7329	127.33996399999999	127.35001699999999	61.136141000000002	61.132745	0103000020E610000001000000050000004F745DF8C1D55F4090DAC4C9FD904E404F745DF8C1D55F4087527B116D914E40D102B4AD66D65F4087527B116D914E40D102B4AD66D65F4090DAC4C9FD904E404F745DF8C1D55F4090DAC4C9FD904E40
61657	Ярославский	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61820	Чамча	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55601	Хамра	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61790	Турукта	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55390	Поселок Пеледуй	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55368	Поселок Витим	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61707	Орто-Нахара	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61821	Нюя Северная	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55439	Нюя	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54709	Мурья	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55341	Ленск	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55514	Дорожный	4	34	7329	128.19301400000001	128.374123	57.621406999999998	57.590179999999997	0103000020E610000001000000050000007235B22B2D0660406B60AB048BCB4C407235B22B2D066040B340BB438ACF4C40CE35CCD0F80B6040B340BB438ACF4C40CE35CCD0F80B60406B60AB048BCB4C407235B22B2D0660406B60AB048BCB4C40
61712	Беченча	4	34	7329	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
37846	Покровск	4	34	5322	43.581513999999999	43.651322999999998	54.078014000000003	54.054960000000001	0103000020E610000001000000050000004415FE0C6FCA4540494BE5ED08074B404415FE0C6FCA4540A950DD5CFC094B40F910548D5ED34540A950DD5CFC094B40F910548D5ED34540494BE5ED08074B404415FE0C6FCA4540494BE5ED08074B40
61689	с. Ситте	4	34	7326	127.50627	127.63908499999999	62.667233000000003	62.344907999999997	0103000020E610000001000000050000008A3C49BA66E05F407B1002F2252C4F408A3C49BA66E05F40EFE714E467554F404E97C5C4E6E85F40EFE714E467554F404E97C5C4E6E85F407B1002F2252C4F408A3C49BA66E05F407B1002F2252C4F40
61771	с. Арыктах	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54726	Сеген-Кюель	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54704	Себян-Кюель	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55441	Поселок Сангар	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55541	Люксюгюн	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55505	Кобяй	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55423	Кобяй	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55536	Аргас	4	34	7326	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54268	Кыстатыам	4	34	7317	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61778	Жиганск	4	34	7317	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
17311	Эбя	4	34	1114	126.647256	126.656724	61.86965	61.866100000000003	0103000020E61000000100000005000000F2086EA46CA95F406688635DDCEE4E40F2086EA46CA95F40B37BF2B050EF4E40E49F19C407AA5F40B37BF2B050EF4E40E49F19C407AA5F406688635DDCEE4E40F2086EA46CA95F406688635DDCEE4E40
18486	Орто-Сурт	4	34	1114	125.107849	125.154822	62.573528000000003	62.560605000000002	0103000020E6100000010000000500000001FA7DFFE6465F40AF7C96E7C1474F4001FA7DFFE6465F408FAB915D69494F40E2AC889AE8495F408FAB915D69494F40E2AC889AE8495F40AF7C96E7C1474F4001FA7DFFE6465F40AF7C96E7C1474F40
18163	Магарас	4	34	1114	128.04916600000001	128.07037600000001	62.153753000000002	62.143742000000003	0103000020E61000000100000005000000684293C492016040E4874A2366124F40684293C492016040B954A52DAE134F408C4D2B8540026040B954A52DAE134F408C4D2B8540026040E4874A2366124F40684293C492016040E4874A2366124F40
18526	Кюёрелях	4	34	1114	126.82892200000001	126.85102000000001	62.577289999999998	62.566113999999999	0103000020E61000000100000005000000D63BDC0E0DB55F4064E76D6C76484F40D63BDC0E0DB55F40672783A3E4494F407C0F971C77B65F40672783A3E4494F407C0F971C77B65F4064E76D6C76484F40D63BDC0E0DB55F4064E76D6C76484F40
18479	Кептин	4	34	1114	124.42398799999999	124.46343299999999	62.346749000000003	62.335340000000002	0103000020E610000001000000050000005F79909E221B5F403485CE6BEC2A4F405F79909E221B5F40DA756F45622C4F40C7B8E2E2A81D5F40DA756F45622C4F40C7B8E2E2A81D5F403485CE6BEC2A4F405F79909E221B5F403485CE6BEC2A4F40
18354	Ерт	4	34	1114	125.782124	125.804914	62.023904000000002	62.012942000000002	0103000020E61000000100000005000000AB5AD2510E725F40575F5D15A8014F40AB5AD2510E725F402E1F49490F034F40EC8502B683735F402E1F49490F034F40EC8502B683735F40575F5D15A8014F40AB5AD2510E725F40575F5D15A8014F40
18273	Дикимдя (Мытах)	4	34	1114	126.51997299999999	126.544605	61.891084999999997	61.879201000000002	0103000020E610000001000000050000006473D53C47A15F4025CE8AA889F04E406473D53C47A15F40637AC2120FF24E403D0FEECEDAA25F40637AC2120FF24E403D0FEECEDAA25F4025CE8AA889F04E406473D53C47A15F4025CE8AA889F04E40
61675	Бяс-Кюель	4	34	1114	124.001034	128.640896	62.667183000000001	61.194400000000002	0103000020E61000000100000005000000C80BE9F010005F40D42B6519E2984E40C80BE9F010005F403DB9A64066554F4064045438821460403DB9A64066554F406404543882146040D42B6519E2984E40C80BE9F010005F40D42B6519E2984E40
18066	Бердигестях	4	34	1114	126.67786099999999	126.72544499999999	62.115614999999998	62.079703000000002	0103000020E61000000100000005000000F78E1A1362AB5F40513239B5330A4F40F78E1A1362AB5F40A9F6E978CC0E4F40FD82DDB06DAE5F40A9F6E978CC0E4F40FD82DDB06DAE5F40513239B5330A4F40F78E1A1362AB5F40513239B5330A4F40
18357	Асыма	4	34	1114	126.625444	126.65511600000001	62.366667	62.357332	0103000020E61000000100000005000000AF5E454607A85F403AE8120EBD2D4F40AF5E454607A85F40DFC2BAF1EE2E4F4087C5A86BEDA95F40DFC2BAF1EE2E4F4087C5A86BEDA95F403AE8120EBD2D4F40AF5E454607A85F403AE8120EBD2D4F40
61664	с.Хампа	4	34	7332	125.210086	125.219509	62.626300000000001	62.624070000000003	0103000020E610000001000000050000003DD68C0C724D5F4016359886E14F4F403DD68C0C724D5F400EBE30992A504F405F0B7A6F0C4E5F400EBE30992A504F405F0B7A6F0C4E5F4016359886E14F4F403DD68C0C724D5F4016359886E14F4F40
61837	с. Кюбяинде	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55478	Чинекя	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61733	Чай	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55459	Усун	4	34	7332	130.54242300000001	130.70477500000001	56.628554999999999	56.624133	0103000020E6100000010000000500000025B37A875B5160405CAD1397E34F4C4025B37A875B5160405F5E807D74504C403B014D848D5660405F5E807D74504C403B014D848D5660405CAD1397E34F4C4025B37A875B5160405CAD1397E34F4C40
55493	Тосу	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61654	Тербяс	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55538	Сыдыбыл	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
62076	Кеданда	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54727	Илбенге	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61638	Екюндю	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55009	Балагачча	4	34	7332	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61715	с.Юттях	4	34	7327	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61826	с.Юнкюр	4	34	7327	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61887	с.Бетенкес	4	34	7327	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55593	Томтор	4	34	7327	130.01630599999999	130.06029699999999	62.159984000000001	62.145667000000003	0103000020E610000001000000050000005017299485406040A08D5C37A5124F4050172994854060400FF10F5B7A144F408061F9F3ED4160400FF10F5B7A144F408061F9F3ED416040A08D5C37A5124F405017299485406040A08D5C37A5124F40
54705	Томтор	4	34	7327	130.01630599999999	130.06029699999999	62.159984000000001	62.145667000000003	0103000020E610000001000000050000005017299485406040A08D5C37A5124F4050172994854060400FF10F5B7A144F408061F9F3ED4160400FF10F5B7A144F408061F9F3ED416040A08D5C37A5124F405017299485406040A08D5C37A5124F40
54720	Токума	4	34	7327	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61755	Суордах	4	34	7327	127.624641	127.698671	62.042859999999997	61.98471	0103000020E6100000010000000500000068AF3E1EFAE75F40A7052FFA0AFE4E4068AF3E1EFAE75F403D27BD6F7C054F4079EA9106B7EC5F403D27BD6F7C054F4079EA9106B7EC5F40A7052FFA0AFE4E4068AF3E1EFAE75F40A7052FFA0AFE4E40
61746	Сайды	4	34	7327	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55550	Поселок Эсэ-Хайя	4	34	7327	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55475	Поселок Батагай	4	34	7327	128.070088	128.09794500000001	61.591523000000002	61.562134	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
61728	Боронук	4	34	7327	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61645	Батагай	4	34	7327	128.070088	128.09794500000001	61.591523000000002	61.562134	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
61698	Барылас	4	34	7327	125.269599	125.296791	57.101042	57.019354	0103000020E6100000010000000500000032022A1C41515F40FD851E317A824C4032022A1C41515F40DFC2BAF1EE8C4C40D1AFAD9FFE525F40DFC2BAF1EE8C4C40D1AFAD9FFE525F40FD851E317A824C4032022A1C41515F40FD851E317A824C40
61644	Угольное	4	34	7328	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61633	Село Улус-Кюель	4	34	7328	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55595	Поселок Зырянка	4	34	7328	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54708	Нелемное	4	34	7328	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61831	с.Сургулук	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61735	с.Нам	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61637	с.Май	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
57576	с.Магасс	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61807	с.Кырыкый	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61690	с.Кетердях	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61353	с.Едюгей	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61842	с.Дюллюкю	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61700	с.Далыр	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61680	Хоро	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55607	Тамалакан	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61660	Оросу	4	34	7330	129.52892499999999	129.571416	61.803918000000003	61.754356000000001	0103000020E610000001000000050000002D211FF4EC3060404CC5C6BC8EE04E402D211FF4EC3060403755F7C8E6E64E40280D350A493260403755F7C8E6E64E40280D350A493260404CC5C6BC8EE04E402D211FF4EC3060404CC5C6BC8EE04E40
62073	Оргет	4	34	7330	128.42406	128.43574699999999	62.470998999999999	62.466433000000002	0103000020E6100000010000000500000056F146E6910D604039639813B43B4F4056F146E6910D60406FB9FAB1493C4F40904AB1A3F10D60406FB9FAB1493C4F40904AB1A3F10D604039639813B43B4F4056F146E6910D604039639813B43B4F40
61851	Онхой	4	34	7330	126.698325	126.759743	59.975351000000003	59.907722	0103000020E61000000100000005000000AB3E575BB1AC5F400BEE073C30F44D40AB3E575BB1AC5F407A8F334DD8FC4D405B971AA19FB05F407A8F334DD8FC4D405B971AA19FB05F400BEE073C30F44D40AB3E575BB1AC5F400BEE073C30F44D40
61603	Намцы	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55506	Кюль	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61782	Кюлекян	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61845	Дюллюкю	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55462	Верхневилюйск	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61597	Быракан	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61709	Ботулу	4	34	7330	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61629	Балаганнах	4	34	7330	129.89029099999999	129.92540600000001	56.665266000000003	56.529420999999999	0103000020E610000001000000050000008A1D8D437D3C604066683C11C4434C408A1D8D437D3C60400492B06F27554C40B6300BED9C3D60400492B06F27554C40B6300BED9C3D604066683C11C4434C408A1D8D437D3C604066683C11C4434C40
62077	с. Тюметинский	4	34	7363	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55387	п. Тикси	4	34	7363	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55578	Сиктях	4	34	7363	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55485	Кюсюр	4	34	7363	127.50100500000001	127.508686	58.336838	58.302115999999998	0103000020E610000001000000050000007B88467710E05F4096CCB1BCAB264D407B88467710E05F406806F1811D2B4D40B77BB94F8EE05F406806F1811D2B4D40B77BB94F8EE05F4096CCB1BCAB264D407B88467710E05F4096CCB1BCAB264D40
61834	Саскылах	4	34	7539	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55419	Чапчылганский наслег	4	34	299	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
61832	Чакыр	4	34	299	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
3441	Харбалах	4	34	299	130.024283	130.029188	60.501742999999998	60.498961000000001	0103000020E61000000100000005000000295B24EDC64060405F7D3CF4DD3F4E40295B24EDC64060409BFF571D39404E40F12DAC1BEF4060409BFF571D39404E40F12DAC1BEF4060405F7D3CF4DD3F4E40295B24EDC64060405F7D3CF4DD3F4E40
61614	Покровка	4	34	299	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
32707	Олом (Олом-Кюель)	4	34	299	130.87642500000001	130.882983	61.282653000000003	61.276510000000002	0103000020E61000000100000005000000B30C71AC0B5C60402C82FFAD64A34E40B30C71AC0B5C6040E38E37F92DA44E40917D9065415C6040E38E37F92DA44E40917D9065415C60402C82FFAD64A34E40B30C71AC0B5C60402C82FFAD64A34E40
61716	Мяндиги	4	34	299	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
55494	Болугур	4	34	299	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
55451	Бетюнский наслег	4	34	299	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
55447	Алтанцы	4	34	299	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
61621	с. Оленегорск	4	34	7536	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61786	Русское Устье	4	34	7536	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61797	с.Сватай	4	34	159	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
61796	с. Куберганя	4	34	159	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
11395	Якокут	4	34	159	125.70159	125.721542	58.535128999999998	58.525346999999996	0103000020E61000000100000005000000D74CBED9E66C5F409E060C923E434D40D74CBED9E66C5F401212691B7F444D40302C7FBE2D6E5F401212691B7F444D40302C7FBE2D6E5F409E060C923E434D40D74CBED9E66C5F409E060C923E434D40
61738	Якоит	4	34	159	125.830157	125.84365	58.900131000000002	58.89273	0103000020E61000000100000005000000E962D34A21755F403C1405FA44724D40E962D34A21755F40D28E1B7E37734D404ED1915CFE755F40D28E1B7E37734D404ED1915CFE755F403C1405FA44724D40E962D34A21755F403C1405FA44724D40
55577	Ыллымах	4	34	159	126.677187	126.701415	58.584935000000002	58.574820000000003	0103000020E61000000100000005000000B091240857AB5F401A8BA6B393494D40B091240857AB5F4094A46B26DF4A4D40207BBDFBE3AC5F4094A46B26DF4A4D40207BBDFBE3AC5F401A8BA6B393494D40B091240857AB5F401A8BA6B393494D40
55576	Чагда	4	34	159	130.59747999999999	130.61462900000001	58.765936000000004	58.735039	0103000020E610000001000000050000007380608E1E5360406C2409C2155E4D407380608E1E5360401F6ADB300A624D408BC56F0AAB5360401F6ADB300A624D408BC56F0AAB5360406C2409C2155E4D407380608E1E5360406C2409C2155E4D40
11467	Хатыстыр	4	34	159	125.138257	125.169257	58.93141	58.910960000000003	0103000020E610000001000000050000005B5CE333D9485F406AFB57569A744D405B5CE333D9485F406C95607138774D409FE74F1BD54A5F406C95607138774D409FE74F1BD54A5F406AFB57569A744D405B5CE333D9485F406AFB57569A744D40
32561	Хайысардах	4	34	159	128.364295	128.36779899999999	60.662818999999999	60.660058999999997	0103000020E6100000010000000500000015E3FC4DA80B6040193735D07C544E4015E3FC4DA80B60406E15C440D7544E400C906802C50B60406E15C440D7544E400C906802C50B6040193735D07C544E4015E3FC4DA80B6040193735D07C544E40
55600	Улу	4	34	159	127.42307700000001	127.435914	60.318770000000001	60.310904999999998	0103000020E6100000010000000500000026AC8DB113DB5F40D9942BBCCB274E4026AC8DB113DB5F4014799274CD284E409677D503E6DB5F4014799274CD284E409677D503E6DB5F40D9942BBCCB274E4026AC8DB113DB5F40D9942BBCCB274E40
11481	Угоян	4	34	159	125.288158	125.295677	59.258586999999999	59.249389999999998	0103000020E610000001000000050000002B85402E71525F4087F9F202EC9F4D402B85402E71525F40DB15FA6019A14D407B4B395FEC525F40DB15FA6019A14D407B4B395FEC525F4087F9F202EC9F4D402B85402E71525F4087F9F202EC9F4D40
10962	Томмот	4	34	159	126.201494	126.301108	58.990118000000002	58.908116	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
55404	Таас-Юрях	4	34	159	128.45330000000001	128.491164	58.576917999999999	58.518965999999999	0103000020E61000000100000005000000DC68006F810E604033DE567A6D424D40DC68006F810E6040A33CF372D8494D401F9F909DB70F6040A33CF372D8494D401F9F909DB70F604033DE567A6D424D40DC68006F810E604033DE567A6D424D40
61350	Сангар	4	34	159	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
55364	Нижний Куранах	4	34	159	125.501356	125.543379	58.842632999999999	58.799830999999998	0103000020E61000000100000005000000D1E9793716605F40DAA9B9DC60664D40D1E9793716605F40E3C3EC65DB6B4D405395B6B8C6625F40E3C3EC65DB6B4D405395B6B8C6625F40DAA9B9DC60664D40D1E9793716605F40DAA9B9DC60664D40
61650	Налимск	4	34	159	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
11327	Ленинский	4	34	159	125.42565500000001	125.45608900000001	58.581341999999999	58.560913999999997	0103000020E61000000100000005000000401878EE3D5B5F402CEFAA07CC474D40401878EE3D5B5F4047E5266A694A4D402FC4EA8F305D5F4047E5266A694A4D402FC4EA8F305D5F402CEFAA07CC474D40401878EE3D5B5F402CEFAA07CC474D40
11335	Лебединый	4	34	159	125.483847	125.518666	58.498953	58.485647	0103000020E6100000010000000500000022516859F75E5F4044334FAE293E4D4022516859F75E5F40DC9E20B1DD3F4D4004E3E0D231615F40DC9E20B1DD3F4D4004E3E0D231615F4044334FAE293E4D4022516859F75E5F4044334FAE293E4D40
61758	Кутана	4	34	159	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
10605	Верхний Куранах	4	34	159	125.475628	125.49019	58.762701999999997	58.747833999999997	0103000020E61000000100000005000000F6436CB0705E5F401E6B4606B95F4D40F6436CB0705E5F40014C1938A0614D40E1B4E0455F5F5F40014C1938A0614D40E1B4E0455F5F5F401E6B4606B95F4D40F6436CB0705E5F401E6B4606B95F4D40
61815	Верхнеколымский	4	34	159	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
11281	Большой Нимныр	4	34	159	125.476634	125.48713499999999	58.043295999999998	58.040671000000003	0103000020E61000000100000005000000598AE42B815E5F40A47213B534054D40598AE42B815E5F4018062CB98A054D402A6F47382D5F5F4018062CB98A054D402A6F47382D5F5F40A47213B534054D40598AE42B815E5F40A47213B534054D40
10186	Алдан	4	34	159	125.313554	125.425798	58.636688999999997	58.578310999999999	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
61695	с. Кенг-Кюель	4	34	7333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
54721	Сутуруоха	4	34	7333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55594	Деску	4	34	7333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55343	Белая Гора	4	34	7333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55481	Мындагай	4	34	7364	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
61726	с. Мастах	4	34	7331	129.769386	129.77163200000001	61.890825999999997	61.888834000000003	0103000020E61000000100000005000000028063CF9E38604054C90050C5F14E40028063CF9E38604097361C9606F24E4082919735B138604097361C9606F24E4082919735B138604054C90050C5F14E40028063CF9E38604054C90050C5F14E40
55529	Сатагай	4	34	7372	129.41587200000001	129.51896300000001	60.701597999999997	60.696455	0103000020E610000001000000050000004FEACBD24E2D60405E11FC6F25594E404FEACBD24E2D6040317898F6CD594E40B11A4B589B306040317898F6CD594E40B11A4B589B3060405E11FC6F25594E404FEACBD24E2D60405E11FC6F25594E40
54728	Сыаганнах	4	34	7335	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
55256	Фокино	4	36	\N	132.322326	132.46548200000001	43.008889000000003	42.884895	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
8394	Уссурийск	4	36	\N	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
55268	Уссурийск	4	36	\N	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
55285	Тавричанка	4	36	\N	46.017313999999999	139.01091299999999	51.530569999999997	42.293455999999999	0103000020E61000000100000005000000A8E15B5837024740516859F78F254540A8E15B58370247408E1EBFB7E9C349403D433866596061408E1EBFB7E9C349403D43386659606140516859F78F254540A8E15B5837024740516859F78F254540
55288	Тавричанка	4	36	\N	46.017313999999999	139.01091299999999	51.530569999999997	42.293455999999999	0103000020E61000000100000005000000A8E15B5837024740516859F78F254540A8E15B58370247408E1EBFB7E9C349403D433866596061408E1EBFB7E9C349403D43386659606140516859F78F254540A8E15B5837024740516859F78F254540
55290	Спасск-Дальний	4	36	\N	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
4638	Спасск-Дальний	4	36	\N	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
55259	Спасск-Дальний	4	36	\N	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
55286	Партизанск	4	36	\N	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
9761	Партизанск	4	36	\N	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
1410	Находка	4	36	\N	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
55271	Находка	4	36	\N	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
55276	Ливадия	4	36	\N	132.66364100000001	132.72727800000001	42.893244000000003	42.855100999999998	0103000020E610000001000000050000001DE90C8C3C95604071E316F3736D45401DE90C8C3C95604093ACC3D155724540362383DC4597604093ACC3D155724540362383DC4597604071E316F3736D45401DE90C8C3C95604071E316F3736D4540
55280	Лесозаводск	4	36	\N	133.325987	133.462118	45.510340999999997	45.438733999999997	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
88	Лесозаводск	4	36	\N	133.325987	133.462118	45.510340999999997	45.438733999999997	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
55306	Козьмино	4	36	\N	46.017313999999999	139.01091299999999	51.530569999999997	42.293455999999999	0103000020E61000000100000005000000A8E15B5837024740516859F78F254540A8E15B58370247408E1EBFB7E9C349403D433866596061408E1EBFB7E9C349403D43386659606140516859F78F254540A8E15B5837024740516859F78F254540
55332	Дальнереченск	4	36	\N	133.676357	133.838584	45.963492000000002	45.905858000000002	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
32880	Дальнереченск	4	36	\N	133.676357	133.838584	45.963492000000002	45.905858000000002	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
55263	Дальнегорск	4	36	\N	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
4988	Дальнегорск	4	36	\N	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
1538	Владивосток	4	36	\N	131.598051	132.258905	43.319028000000003	42.948588999999998	0103000020E61000000100000005000000E2CAD93B23736040342C465D6B794540E2CAD93B237360401041D5E8D5A84540AB7823F3488860401041D5E8D5A84540AB7823F348886040342C465D6B794540E2CAD93B23736040342C465D6B794540
55124	Большой Камень	4	36	\N	132.31584100000001	132.383196	43.139045000000003	43.067574	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
1306	Артем	4	36	\N	132.047541	132.33355499999999	43.479103000000002	43.309058	0103000020E610000001000000050000000307B47485816040994869368FA745400307B474858160402F35423F53BD45405A0D897BAC8A60402F35423F53BD45405A0D897BAC8A6040994869368FA745400307B47485816040994869368FA74540
55291	Артем	4	36	\N	132.047541	132.33355499999999	43.479103000000002	43.309058	0103000020E610000001000000050000000307B47485816040994869368FA745400307B474858160402F35423F53BD45405A0D897BAC8A60402F35423F53BD45405A0D897BAC8A6040994869368FA745400307B47485816040994869368FA74540
11414	Арсеньев	4	36	\N	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
55260	Арсеньев	4	36	\N	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
55284	Подножье	4	36	7358	131.74581499999999	131.93778499999999	43.062857999999999	42.944636000000003	0103000020E61000000100000005000000B83B6BB7DD776040E84F1BD5E9784540B83B6BB7DD7760405F251FBB0B884540BD35B055027E60405F251FBB0B884540BD35B055027E6040E84F1BD5E9784540B83B6BB7DD776040E84F1BD5E9784540
55294	Углекаменск	4	36	1203	133.22132400000001	133.24415099999999	43.249122	43.196520999999997	0103000020E610000001000000050000003DBA111615A7604015FDA199279945403DBA111615A76040685BCD3AE39F45402409C215D0A76040685BCD3AE39F45402409C215D0A7604015FDA199279945403DBA111615A7604015FDA19927994540
11702	Тигровое	4	36	1203	132.87313700000001	132.91761299999999	43.205976999999997	43.168483000000002	0103000020E61000000100000005000000AF7D01BDF09B60404B77D7D990954540AF7D01BDF09B6040355D4F745D9A45404D2CF0155D9D6040355D4F745D9A45404D2CF0155D9D60404B77D7D990954540AF7D01BDF09B60404B77D7D990954540
55297	Казанка	4	36	1203	133.21164999999999	133.23218499999999	43.209158000000002	43.191650000000003	0103000020E61000000100000005000000598638D6C5A66040A323B9FC87984540598638D6C5A6604030D978B0C59A4540E5B33C0F6EA7604030D978B0C59A4540E5B33C0F6EA76040A323B9FC87984540598638D6C5A66040A323B9FC87984540
55309	Бровничи	4	36	1203	133.00887299999999	133.04164299999999	43.299098999999998	43.281768999999997	0103000020E61000000100000005000000289A07B048A060406803B00111A44540289A07B048A0604016A243E048A645406F63B32355A1604016A243E048A645406F63B32355A160406803B00111A44540289A07B048A060406803B00111A44540
55296	Авангард	4	36	1203	133.21084999999999	133.248786	43.286375999999997	43.254828000000003	0103000020E6100000010000000500000092CB7F48BFA66040740D33349EA0454092CB7F48BFA66040FD2D01F8A7A445407CB60E0EF6A76040FD2D01F8A7A445407CB60E0EF6A76040740D33349EA0454092CB7F48BFA66040740D33349EA04540
55311	Средний	4	36	7357	132.53489500000001	133.00569300000001	42.998998999999998	42.737496999999998	0103000020E6100000010000000500000068791EDC1D916040F5F23B4D665E454068791EDC1D9160404CDE0033DF7F45401E1A16A32EA060404CDE0033DF7F45401E1A16A32EA06040F5F23B4D665E454068791EDC1D916040F5F23B4D665E4540
55281	Ливадия	4	36	7357	132.66364100000001	132.72727800000001	42.893244000000003	42.855100999999998	0103000020E610000001000000050000001DE90C8C3C95604071E316F3736D45401DE90C8C3C95604093ACC3D155724540362383DC4597604093ACC3D155724540362383DC4597604071E316F3736D45401DE90C8C3C95604071E316F3736D4540
55307	Душкино	4	36	7357	132.67684700000001	132.706221	42.933442999999997	42.922102000000002	0103000020E61000000100000005000000AA2C0ABBA8956040C1C9367007764540AA2C0ABBA89560400ED76A0F7B774540F357C85C999660400ED76A0F7B774540F357C85C99966040C1C9367007764540AA2C0ABBA8956040C1C9367007764540
55248	Лесозаводск	4	36	7354	133.37516099999999	133.46794800000001	45.513890000000004	45.455592000000003	0103000020E610000001000000050000008237A45101AC6040DD28B2D650BA46408237A45101AC6040E8DEC325C7C146405187156EF9AE6040E8DEC325C7C146405187156EF9AE6040DD28B2D650BA46408237A45101AC6040DD28B2D650BA4640
55255	Шкотово	4	36	140	132.335936	132.38544200000001	43.356907999999997	43.307149000000003	0103000020E6100000010000000500000092B1DAFCBF8A6040E3FF8EA850A7454092B1DAFCBF8A604023D74D29AFAD45402810768A558C604023D74D29AFAD45402810768A558C6040E3FF8EA850A7454092B1DAFCBF8A6040E3FF8EA850A74540
460	Центральное	4	36	140	132.678967	132.70105599999999	43.348785999999997	43.332289000000003	0103000020E6100000010000000500000006820019BA95604008E9297288AA454006820019BA956040BDA60705A5AC45404415FE0C6F966040BDA60705A5AC45404415FE0C6F96604008E9297288AA454006820019BA95604008E9297288AA4540
28253	Фокино	4	36	140	132.322326	132.46548200000001	43.008889000000003	42.884895	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
591	Стеклянуха	4	36	140	132.47149200000001	132.48052000000001	43.350647000000002	43.34198	0103000020E610000001000000050000006C0A6476168F60406BF12900C6AB45406C0A6476168F604063B83A00E2AC45405EA27A6B608F604063B83A00E2AC45405EA27A6B608F60406BF12900C6AB45406C0A6476168F60406BF12900C6AB4540
55275	Смоляниново	4	36	140	132.44353599999999	132.480322	43.315342000000001	43.245707000000003	0103000020E6100000010000000500000028D36872318E6040FBB2B453739F454028D36872318E604012876C205DA8454094313ECC5E8F604012876C205DA8454094313ECC5E8F6040FBB2B453739F454028D36872318E6040FBB2B453739F4540
1068	Романовка	4	36	140	132.436125	132.47599199999999	43.242213999999997	43.228794999999998	0103000020E61000000100000005000000FA7E6ABCF48D6040813E9127499D4540FA7E6ABCF48D604011514CDE009F45400B2593533B8F604011514CDE009F45400B2593533B8F6040813E9127499D4540FA7E6ABCF48D6040813E9127499D4540
28675	Путятин	4	36	140	132.40388400000001	132.42208400000001	42.86627	42.854824000000001	0103000020E61000000100000005000000166C239EEC8C6040FFEA71DF6A6D4540166C239EEC8C6040C2C073EFE16E454047054EB6818D6040C2C073EFE16E454047054EB6818D6040FFEA71DF6A6D4540166C239EEC8C6040FFEA71DF6A6D4540
55282	Петровка	4	36	140	132.375956	132.40553700000001	43.162098999999998	43.134315000000001	0103000020E610000001000000050000008597E0D4078C60405E2EE23B319145408597E0D4078C60406EDBF7A8BF9445402D0ABB28FA8C60406EDBF7A8BF9445402D0ABB28FA8C60405E2EE23B319145408597E0D4078C60405E2EE23B31914540
859	Новонежино	4	36	140	132.56529399999999	132.62847199999999	43.230725999999997	43.204374000000001	0103000020E61000000100000005000000005471E3169260408C135FED289A4540005471E3169260401F2BF86D889D454074CE4F711C9460401F2BF86D889D454074CE4F711C9460408C135FED289A4540005471E3169260408C135FED289A4540
331	Многоудобное	4	36	140	132.42733899999999	132.48105000000001	43.477258999999997	43.424287	0103000020E61000000100000005000000C5A9D6C2AC8D6040198F52094FB64540C5A9D6C2AC8D60405F5CAAD216BD4540B537F8C2648F60405F5CAAD216BD4540B537F8C2648F6040198F52094FB64540C5A9D6C2AC8D6040198F52094FB64540
28704	Дунай	4	36	140	132.320494	132.369731	42.894010000000002	42.866481	0103000020E610000001000000050000000E12A27C418A60407DCD72D9E86E45400E12A27C418A6040032670EB6E724540282A1BD6D48B6040032670EB6E724540282A1BD6D48B60407DCD72D9E86E45400E12A27C418A60407DCD72D9E86E4540
55273	Дунай	4	36	140	132.320494	132.369731	42.894010000000002	42.866481	0103000020E610000001000000050000000E12A27C418A60407DCD72D9E86E45400E12A27C418A6040032670EB6E724540282A1BD6D48B6040032670EB6E724540282A1BD6D48B60407DCD72D9E86E45400E12A27C418A60407DCD72D9E86E4540
15899	Большой Камень	4	36	140	132.31584100000001	132.383196	43.139045000000003	43.067574	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
57572	Большой Камень	4	36	140	132.31584100000001	132.383196	43.139045000000003	43.067574	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
759	Анисимовка	4	36	140	132.75582600000001	132.82332600000001	43.193812999999999	43.161276000000001	0103000020E61000000100000005000000EEEE01BA2F9860409AD024B1A4944540EEEE01BA2F986040134548DDCE9845404A7EC4AF589A6040134548DDCE9845404A7EC4AF589A60409AD024B1A4944540EEEE01BA2F9860409AD024B1A4944540
3734	Черниговка	4	36	594	132.51849200000001	132.60686799999999	44.355773999999997	44.322023000000002	0103000020E610000001000000050000009BE7887C97906040A8C7B60C382946409BE7887C9790604030629F008A2D4640A59F70766B93604030629F008A2D4640A59F70766B936040A8C7B60C382946409BE7887C97906040A8C7B60C38294640
26889	Халкидон	4	36	594	132.40233000000001	132.43120200000001	44.282136000000001	44.249008000000003	0103000020E6100000010000000500000064062AE3DF8C6040A038807EDF1F464064062AE3DF8C60401B834E081D24464009FF2268CC8D60401B834E081D24464009FF2268CC8D6040A038807EDF1F464064062AE3DF8C6040A038807EDF1F4640
26352	Снегуровка	4	36	594	132.571223	132.59688800000001	44.092422999999997	44.074556999999999	0103000020E6100000010000000500000023F77475479260400C5872158B09464023F7747547926040F8325184D40B4640FFEBDCB419936040F8325184D40B4640FFEBDCB4199360400C5872158B09464023F77475479260400C5872158B094640
26048	Синий Гай	4	36	594	132.58245199999999	132.59792100000001	44.464846000000001	44.450955999999998	0103000020E61000000100000005000000AC6F6072A3926040ADF71BEDB8394640AC6F6072A392604095D6DF12803B4640EF92382B2293604095D6DF12803B4640EF92382B22936040ADF71BEDB8394640AC6F6072A3926040ADF71BEDB8394640
55310	Сибирцево	4	36	594	132.416955	132.48074399999999	44.218167000000001	44.183813999999998	0103000020E61000000100000005000000EB1C03B2578D60400246973787174640EB1C03B2578D6040810871E5EC1B4640F1B73D41628F6040810871E5EC1B4640F1B73D41628F60400246973787174640EB1C03B2578D60400246973787174640
26487	Сибирцево	4	36	594	132.416955	132.48074399999999	44.218167000000001	44.183813999999998	0103000020E61000000100000005000000EB1C03B2578D60400246973787174640EB1C03B2578D6040810871E5EC1B4640F1B73D41628F6040810871E5EC1B4640F1B73D41628F60400246973787174640EB1C03B2578D60400246973787174640
26427	Орехово	4	36	594	132.37531799999999	132.39608699999999	44.157950999999997	44.136017000000002	0103000020E6100000010000000500000034F3E49A028C60409B594B016911464034F3E49A028C60406CAF05BD37144640DDEBA4BEAC8C60406CAF05BD37144640DDEBA4BEAC8C60409B594B016911464034F3E49A028C60409B594B0169114640
26769	Монастырище	4	36	594	132.44851299999999	132.52437599999999	44.205005999999997	44.183270999999998	0103000020E61000000100000005000000965AEF375A8E604011A7936C75174640965AEF375A8E6040ECBDF8A23D1A4640D5592DB0C7906040ECBDF8A23D1A4640D5592DB0C790604011A7936C75174640965AEF375A8E604011A7936C75174640
26122	Меркушевка	4	36	594	132.777242	132.80165	44.385685000000002	44.373095999999997	0103000020E610000001000000050000007C629D2ADF9860405B22179CC12F46407C629D2ADF98604065C746205E314640D49AE61DA799604065C746205E314640D49AE61DA79960405B22179CC12F46407C629D2ADF9860405B22179CC12F4640
26287	Вассиановка	4	36	594	132.62832900000001	132.65670600000001	44.150590999999999	44.127425000000002	0103000020E610000001000000050000001C446B451B946040AED85F764F1046401C446B451B9460403509DE9046134640C9224DBC039560403509DE9046134640C9224DBC03956040AED85F764F1046401C446B451B946040AED85F764F104640
26125	Алтыновка	4	36	594	132.522794	132.53984500000001	44.412882000000003	44.389690999999999	0103000020E6100000010000000500000071917BBABA906040D4450A65E131464071917BBABA906040B58D3F51D9344640187D056946916040B58D3F51D9344640187D056946916040D4450A65E131464071917BBABA906040D4450A65E1314640
26404	Абражеевка	4	36	594	132.46042399999999	132.48572999999999	44.082808	44.068359000000001	0103000020E6100000010000000500000064C91CCBBB8E604092B1DAFCBF08464064C91CCBBB8E604070ECD973990A4640F415A4198B8F604070ECD973990A4640F415A4198B8F604092B1DAFCBF08464064C91CCBBB8E604092B1DAFCBF084640
24474	Ярославский	4	36	1753	132.20559	132.24407400000001	44.197716999999997	44.143399000000002	0103000020E610000001000000050000004FCC7A3194866040BAA3FFE55A1246404FCC7A31948660407E6E68CA4E194640BAF94674CF8760407E6E68CA4E194640BAF94674CF876040BAA3FFE55A1246404FCC7A3194866040BAA3FFE55A124640
55270	Ярославский	4	36	1753	132.20559	132.24407400000001	44.197716999999997	44.143399000000002	0103000020E610000001000000050000004FCC7A3194866040BAA3FFE55A1246404FCC7A31948660407E6E68CA4E194640BAF94674CF8760407E6E68CA4E194640BAF94674CF876040BAA3FFE55A1246404FCC7A3194866040BAA3FFE55A124640
55304	Хорольск	4	36	1753	132.090067	132.11259699999999	44.458632000000001	44.442982999999998	0103000020E610000001000000050000005D6E30D4E18260408CD7BCAAB33846405D6E30D4E182604015731074B43A4640161406659A83604015731074B43A4640161406659A8360408CD7BCAAB33846405D6E30D4E18260408CD7BCAAB3384640
24819	Хороль	4	36	1753	132.04640000000001	132.10177200000001	44.446199999999997	44.402836999999998	0103000020E610000001000000050000001A51DA1B7C816040334FAE29903346401A51DA1B7C816040D3BCE3141D394640C1745AB741836040D3BCE3141D394640C1745AB741836040334FAE29903346401A51DA1B7C816040334FAE2990334640
25501	Усачевка	4	36	1753	131.833382	131.843785	44.245502000000002	44.238166	0103000020E610000001000000050000006762BA10AB7A6040738236397C1E46406762BA10AB7A6040228D0A9C6C1F46405F7B6649007B6040228D0A9C6C1F46405F7B6649007B6040738236397C1E46406762BA10AB7A6040738236397C1E4640
25618	Сиваковка	4	36	1753	132.345934	132.38431	44.492277000000001	44.467137000000001	0103000020E6100000010000000500000062122EE4118B604033E02C25CB3B464062122EE4118B604058C9C7EE023F4640D3307C444C8C604058C9C7EE023F4640D3307C444C8C604033E02C25CB3B464062122EE4118B604033E02C25CB3B4640
25405	Приозерное	4	36	1753	131.95863499999999	131.973232	44.315702999999999	44.307110999999999	0103000020E61000000100000005000000A1B94E23AD7E6040F59ECA694F274640A1B94E23AD7E6040E21FB6F468284640766D6FB7247F6040E21FB6F468284640766D6FB7247F6040F59ECA694F274640A1B94E23AD7E6040F59ECA694F274640
25417	Прилуки	4	36	1753	131.81939600000001	131.841072	44.348450999999997	44.330651000000003	0103000020E6100000010000000500000025CFF57D387A6040E2B19FC5522A464025CFF57D387A604016A1D80A9A2C46409AB2D30FEA7A604016A1D80A9A2C46409AB2D30FEA7A6040E2B19FC5522A464025CFF57D387A6040E2B19FC5522A4640
25127	Поповка	4	36	1753	131.95452	132.00319099999999	44.457498999999999	44.424734999999998	0103000020E6100000010000000500000018EC866D8B7E6040B83B6BB75D36464018EC866D8B7E6040F279C5538F3A4640871403241A806040F279C5538F3A4640871403241A806040B83B6BB75D36464018EC866D8B7E6040B83B6BB75D364640
25708	Петровичи	4	36	1753	132.26146600000001	132.28720200000001	44.388995999999999	44.374428999999999	0103000020E6100000010000000500000083E0F1ED5D88604045D61A4AED2F464083E0F1ED5D8860402D23F59ECA31464011AB3FC2308960402D23F59ECA31464011AB3FC23089604045D61A4AED2F464083E0F1ED5D88604045D61A4AED2F4640
25609	Новодевица	4	36	1753	132.16189600000001	132.21257	44.501857000000001	44.484940000000002	0103000020E610000001000000050000004E2B85402E856040D9429083123E46404E2B85402E8560406422A5D93C4046408BC3995FCD8660406422A5D93C4046408BC3995FCD866040D9429083123E46404E2B85402E856040D9429083123E4640
25333	Новобельмановка	4	36	1753	132.15896799999999	132.18711200000001	44.364879999999999	44.351700000000001	0103000020E6100000010000000500000089230F441685604069006F81042D464089230F4416856040747B4963B42E46400E164ED2FC856040747B4963B42E46400E164ED2FC85604069006F81042D464089230F441685604069006F81042D4640
25540	Лучки	4	36	1753	132.24451400000001	132.27334099999999	44.301685999999997	44.273868999999998	0103000020E61000000100000005000000412D060FD3876040B131AF230E234640412D060FD38760409DD497A59D264640FDF49F35BF8860409DD497A59D264640FDF49F35BF886040B131AF230E234640412D060FD3876040B131AF230E234640
55313	Луговой	4	36	1753	132.07731100000001	132.09786399999999	44.542929999999998	44.533171000000003	0103000020E61000000100000005000000E013EB54798260407B1684F23E444640E013EB54798260403602F1BA7E45464095EEAEB3218360403602F1BA7E45464095EEAEB3218360407B1684F23E444640E013EB54798260407B1684F23E444640
25197	Ленинское	4	36	1753	132.152635	132.19946400000001	44.447642000000002	44.412714999999999	0103000020E6100000010000000500000033A7CB62E2846040C9C859D8D334464033A7CB62E2846040742843554C3946405797530262866040742843554C3946405797530262866040C9C859D8D334464033A7CB62E2846040C9C859D8D3344640
24764	Дальзаводское	4	36	1753	132.089528	132.12598199999999	44.155830000000002	44.143250000000002	0103000020E610000001000000050000007102D369DD82604075931804561246407102D369DD8260402BDEC83CF21346404F3C670B088460402BDEC83CF21346404F3C670B0884604075931804561246407102D369DD8260407593180456124640
24683	Вознесенка	4	36	1753	132.17564999999999	132.21414200000001	44.202117999999999	44.177090999999997	0103000020E610000001000000050000005BB1BFEC9E8560403DB5FAEAAA1646405BB1BFEC9E8560406AF7AB00DF19464067D65240DA8660406AF7AB00DF19464067D65240DA8660403DB5FAEAAA1646405BB1BFEC9E8560403DB5FAEAAA164640
25280	Благодатное	4	36	1753	132.077293	132.10830300000001	44.327117999999999	44.315663999999998	0103000020E61000000100000005000000B6662B2F7982604024438EAD67284640B6662B2F798260406AF7AB00DF294640E161DA37778360406AF7AB00DF294640E161DA377783604024438EAD67284640B6662B2F7982604024438EAD67284640
23377	Цуканово	4	36	1724	130.77668499999999	130.78822	42.763899000000002	42.751739000000001	0103000020E610000001000000050000006649809ADA5860405A10CAFB386045406649809ADA5860403B394371C7614540B3412619395960403B394371C7614540B3412619395960405A10CAFB386045406649809ADA5860405A10CAFB38604540
55292	Хасан	4	36	1724	130.639081	130.65660700000001	42.434108000000002	42.414361999999997	0103000020E61000000100000005000000D74FFF5973546040425A63D009354540D74FFF59735460404B77D7D99037454064EAAEEC025560404B77D7D99037454064EAAEEC02556040425A63D009354540D74FFF5973546040425A63D009354540
24289	Филипповка	4	36	1724	131.53042600000001	131.54652300000001	43.243125999999997	43.233274999999999	0103000020E61000000100000005000000575EF23FF9706040B9FC87F4DB9D4540575EF23FF97060405567B5C01E9F45406170CD1D7D7160405567B5C01E9F45406170CD1D7D716040B9FC87F4DB9D4540575EF23FF9706040B9FC87F4DB9D4540
23713	Славянка	4	36	1724	131.368064	131.435788	42.909933000000002	42.851995000000002	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
55254	Славянка	4	36	1724	131.368064	131.435788	42.909933000000002	42.851995000000002	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
55269	Приморский	4	36	1724	131.55654000000001	131.60701599999999	43.111311000000001	43.055717999999999	0103000020E610000001000000050000004F5DF92CCF71604036E675C4218745404F5DF92CCF716040B05758703F8E4540C284D1AC6C736040B05758703F8E4540C284D1AC6C73604036E675C4218745404F5DF92CCF71604036E675C421874540
55278	Посьет	4	36	1724	130.788884	130.82382000000001	42.666715000000003	42.643123000000003	0103000020E61000000100000005000000CE8AA8893E5960401827BEDA51524540CE8AA8893E5960405760C8EA565545404EB9C2BB5C5A60405760C8EA565545404EB9C2BB5C5A60401827BEDA51524540CE8AA8893E5960401827BEDA51524540
55330	Перевозная	4	36	1724	131.54768200000001	131.562253	43.028927000000003	43.018664999999999	0103000020E6100000010000000500000074D3669C86716040384A5E9D6382454074D3669C86716040577C43E1B38345407EE200FAFD716040577C43E1B38345407EE200FAFD716040384A5E9D6382454074D3669C86716040384A5E9D63824540
55253	Краскино	4	36	1724	130.76770200000001	130.80082300000001	42.727880999999996	42.700046	0103000020E610000001000000050000005DE2C803915860400AD9791B9B5945405DE2C803915860409C3061342B5D45404F5C8E57A05960409C3061342B5D45404F5C8E57A05960400AD9791B9B5945405DE2C803915860400AD9791B9B594540
55279	Зарубино	4	36	1724	131.05132699999999	131.094797	42.664918999999998	42.6267	0103000020E61000000100000005000000DB4C8578A46160409C33A2B437504540DB4C8578A461604098BED7101C55454049D8B7930863604098BED7101C55454049D8B793086360409C33A2B437504540DB4C8578A46160409C33A2B437504540
23591	Зарубино	4	36	1724	131.05132699999999	131.094797	42.664918999999998	42.6267	0103000020E61000000100000005000000DB4C8578A46160409C33A2B437504540DB4C8578A461604098BED7101C55454049D8B7930863604098BED7101C55454049D8B793086360409C33A2B437504540DB4C8578A46160409C33A2B437504540
24373	Занадворовка	4	36	1724	131.58428000000001	131.62054499999999	43.310310999999999	43.293049000000003	0103000020E610000001000000050000009F76F86BB272604011902FA182A545409F76F86BB2726040664B5645B8A7454048163081DB736040664B5645B8A7454048163081DB73604011902FA182A545409F76F86BB272604011902FA182A54540
23520	Гвоздево	4	36	1724	130.89386099999999	130.93846300000001	42.696559999999998	42.685222000000003	0103000020E610000001000000050000006F4562829A5C6040F73FC05AB55745406F4562829A5C6040D3D9C9E02859454032B08EE3075E6040D3D9C9E02859454032B08EE3075E6040F73FC05AB55745406F4562829A5C6040F73FC05AB5574540
24064	Безверхово	4	36	1724	131.47974300000001	131.49565200000001	42.981912000000001	42.957504	0103000020E6100000010000000500000085EFFD0D5A6F604004E5B67D8F7A454085EFFD0D5A6F604065C6DB4AAF7D45404E469561DC6F604065C6DB4AAF7D45404E469561DC6F604004E5B67D8F7A454085EFFD0D5A6F604004E5B67D8F7A4540
24201	Барабаш	4	36	1724	131.46964600000001	131.515343	43.202238000000001	43.177793000000001	0103000020E6100000010000000500000050560C57076F6040973AC8EBC196454050560C57076F604015014EEFE29945401F679AB07D70604015014EEFE29945401F679AB07D706040973AC8EBC196454050560C57076F6040973AC8EBC1964540
23677	Андреевка	4	36	1724	131.12469300000001	131.15528900000001	42.659514999999999	42.638267999999997	0103000020E6100000010000000500000049A12C7CFD636040AA0A0DC4B251454049A12C7CFD636040581CCEFC6A544540B70DA320F8646040581CCEFC6A544540B70DA320F8646040AA0A0DC4B251454049A12C7CFD636040AA0A0DC4B2514540
23230	Турий Рог	4	36	750	131.973645	131.98896199999999	45.245871000000001	45.226315999999997	0103000020E610000001000000050000003F1D8F19287F6040E04735ECF79C46403F1D8F19287F6040750470B3789F464093DFA293A57F6040750470B3789F464093DFA293A57F6040E04735ECF79C46403F1D8F19287F6040E04735ECF79C4640
23308	Рассказово	4	36	750	131.77901600000001	131.80111500000001	45.187674999999999	45.178654000000002	0103000020E61000000100000005000000F261F6B2ED78604059A65F22DE964640F261F6B2ED7860406EA301BC05984640B9AAECBBA27960406EA301BC05984640B9AAECBBA279604059A65F22DE964640F261F6B2ED78604059A65F22DE964640
23122	Платоно-Александровское	4	36	750	131.971732	132.00478100000001	45.061236000000001	45.031278999999998	0103000020E61000000100000005000000410FB56D187F60409A0645F300844640410FB56D187F60403FABCC94D68746408DD47B2A278060403FABCC94D68746408DD47B2A278060409A0645F300844640410FB56D187F60409A0645F300844640
23236	Первомайское	4	36	750	131.840677	131.86947699999999	45.143540000000002	45.127943999999999	0103000020E61000000100000005000000FBAF73D3E67A604016DC0F7860904640FBAF73D3E67A60407CD5CA845F924640F9F36DC1D27B60407CD5CA845F924640F9F36DC1D27B604016DC0F7860904640FBAF73D3E67A604016DC0F7860904640
22437	Пархоменко	4	36	750	131.958742	131.97353799999999	44.769024999999999	44.756954999999998	0103000020E61000000100000005000000A7E9B303AE7E604097C5C4E6E3604640A7E9B303AE7E6040386744696F62464039ED2939277F6040386744696F62464039ED2939277F604097C5C4E6E3604640A7E9B303AE7E604097C5C4E6E3604640
22966	Октябрьское	4	36	750	132.00487100000001	132.02122900000001	44.921444999999999	44.914717000000003	0103000020E610000001000000050000005D363AE727806040310C5872157546405D363AE7278060400708E6E8F1754640429770E8AD8060400708E6E8F1754640429770E8AD806040310C5872157546405D363AE727806040310C587215754640
22528	Новоселище	4	36	750	131.84275199999999	131.86963800000001	44.663705	44.646552999999997	0103000020E610000001000000050000006FD40AD3F77A6040BA10AB3FC25246406FD40AD3F77A604089981249F45446407C2B1213D47B604089981249F45446407C2B1213D47B6040BA10AB3FC25246406FD40AD3F77A6040BA10AB3FC2524640
22869	Новониколаевка	4	36	750	132.09039000000001	132.10612	44.895923000000003	44.883904999999999	0103000020E6100000010000000500000056BC9179E4826040ACE28DCC2371464056BC9179E4826040FB5DD89AAD724640732EC55565836040FB5DD89AAD724640732EC55565836040ACE28DCC2371464056BC9179E4826040ACE28DCC23714640
23163	Новокачалинск	4	36	750	131.98775800000001	132.02364600000001	45.108741999999999	45.089934999999997	0103000020E61000000100000005000000994BAAB69B7F604004E275FD828B4640994BAAB69B7F6040CFD90242EB8D4640CD9541B5C1806040CFD90242EB8D4640CD9541B5C180604004E275FD828B4640994BAAB69B7F604004E275FD828B4640
22694	Мельгуновка	4	36	750	131.92793	131.96060199999999	44.584809	44.560369999999999	0103000020E61000000100000005000000465F419AB17D60406BD44334BA474640465F419AB17D604007B47405DB4A46401CCF6740BD7E604007B47405DB4A46401CCF6740BD7E60406BD44334BA474640465F419AB17D60406BD44334BA474640
22911	Майское	4	36	750	131.98535000000001	132.004997	44.949781000000002	44.932637999999997	0103000020E61000000100000005000000A323B9FC877F6040E08096AE60774640A323B9FC877F60405CAE7E6C9279464080F277EF288060405CAE7E6C9279464080F277EF28806040E08096AE60774640A323B9FC877F6040E08096AE60774640
22838	Люблино	4	36	750	132.031407	132.045511	44.902473000000001	44.887991999999997	0103000020E61000000100000005000000B2BB404901816040088ECBB8A9714640B2BB404901816040F2423A3C8473464077137CD374816040F2423A3C8473464077137CD374816040088ECBB8A9714640B2BB404901816040088ECBB8A9714640
23023	Комиссарово	4	36	750	131.77221599999999	131.79497900000001	45.001964000000001	44.978811	0103000020E61000000100000005000000552E54FEB578604087FBC8AD497D4640552E54FEB57860407AE2395B4080464038C0CC77707960407AE2395B4080464038C0CC777079604087FBC8AD497D4640552E54FEB578604087FBC8AD497D4640
22154	Камень-Рыболов	4	36	750	132.018103	132.06115	44.762689000000002	44.707585000000002	0103000020E61000000100000005000000B41EBE4C94806040F1113125925A4640B41EBE4C948060406D020CCB9F614640D044D8F0F48160406D020CCB9F614640D044D8F0F4816040F1113125925A4640B41EBE4C94806040F1113125925A4640
22805	Ильинка	4	36	750	131.94363300000001	131.99852899999999	44.910670000000003	44.878374000000001	0103000020E61000000100000005000000A54DD53D327E60400FD4298F6E704640A54DD53D327E604063B9A5D59074464071E316F3F37F604063B9A5D59074464071E316F3F37F60400FD4298F6E704640A54DD53D327E60400FD4298F6E704640
23060	Дворянка	4	36	750	131.57638299999999	131.59103500000001	44.886477999999997	44.869706000000001	0103000020E610000001000000050000000DDFC2BA717260404791B586526F46400DDFC2BA71726040CE4F711C7871464053793BC2E9726040CE4F711C7871464053793BC2E97260404791B586526F46400DDFC2BA717260404791B586526F4640
22500	Владимиро-Петровка	4	36	750	132.08004199999999	132.09634600000001	44.665956000000001	44.653202999999998	0103000020E61000000100000005000000CE893DB48F8260401553E9279C534640CE893DB48F8260409949D40B3E55464037E33444158360409949D40B3E55464037E33444158360401553E9279C534640CE893DB48F8260401553E9279C534640
22392	Астраханка	4	36	750	132.04054300000001	132.07990699999999	44.734324000000001	44.707706999999999	0103000020E610000001000000050000009E62D5204C8160403C139A24965A46409E62D5204C8160407E552E54FE5D464016F71F998E8260407E552E54FE5D464016F71F998E8260403C139A24965A46409E62D5204C8160403C139A24965A4640
22647	Алексеевка	4	36	750	131.87774099999999	131.89108999999999	44.728848999999997	44.715584999999997	0103000020E61000000100000005000000772B4B74167C60400B410E4A985B4640772B4B74167C6040745C8DEC4A5D46405DF92CCF837C6040745C8DEC4A5D46405DF92CCF837C60400B410E4A985B4640772B4B74167C60400B410E4A985B4640
55301	Поселок Аякс	4	36	7359	131.84038899999999	131.90227400000001	43.140827999999999	43.072816000000003	0103000020E6100000010000000500000061DD7877E47A60401250E1085289454061DD7877E47A6040382EE3A606924540FF40B96DDF7C6040382EE3A606924540FF40B96DDF7C60401250E1085289454061DD7877E47A60401250E10852894540
21042	Яконовка	4	36	1637	131.686804	131.703531	43.744453999999998	43.721238	0103000020E6100000010000000500000062D8614CFA756040F450DB8651DC454062D8614CFA7560402DB0C7444ADF45401C977153837660402DB0C7444ADF45401C97715383766040F450DB8651DC454062D8614CFA756040F450DB8651DC4540
21459	Утесное	4	36	1637	131.93550300000001	131.948466	43.755113999999999	43.745502000000002	0103000020E61000000100000005000000EBC9FCA3EF7D6040228D0A9C6CDF4540EBC9FCA3EF7D604039605793A7E04540C66B5ED5597E604039605793A7E04540C66B5ED5597E6040228D0A9C6CDF4540EBC9FCA3EF7D6040228D0A9C6CDF4540
20848	Улитовка	4	36	1637	131.65459999999999	131.67234099999999	43.862395999999997	43.856870999999998	0103000020E61000000100000005000000C5FEB27BF274604006F2ECF2ADED4540C5FEB27BF2746040C119FCFD62EE454051D845D183756040C119FCFD62EE454051D845D18375604006F2ECF2ADED4540C5FEB27BF274604006F2ECF2ADED4540
21217	Тимирязевский	4	36	1637	131.95045999999999	131.96262300000001	43.868245000000002	43.851208999999997	0103000020E61000000100000005000000FF04172B6A7E6040CA87A06AF4EC4540FF04172B6A7E604030F5F3A622EF454014ECBFCECD7E604030F5F3A622EF454014ECBFCECD7E6040CA87A06AF4EC4540FF04172B6A7E6040CA87A06AF4EC4540
21209	Степное	4	36	1637	131.79996499999999	131.82281800000001	43.975990000000003	43.968159999999997	0103000020E610000001000000050000003A1E335099796040CEA5B8AAECFB45403A1E3350997960408D9C853DEDFC4540ED116A86547A60408D9C853DEDFC4540ED116A86547A6040CEA5B8AAECFB45403A1E335099796040CEA5B8AAECFB4540
21330	Раковка	4	36	1637	132.156408	132.17848799999999	43.818525999999999	43.795555	0103000020E61000000100000005000000A69A594B01856040AB9509BFD4E54540A69A594B018560407D76C075C5E845404F57772CB68560407D76C075C5E845404F57772CB6856040AB9509BFD4E54540A69A594B01856040AB9509BFD4E54540
21575	Партизан	4	36	1637	131.951134	131.96940499999999	43.706511999999996	43.676346000000002	0103000020E61000000100000005000000A30392B06F7E6040E563778192D64540A30392B06F7E6040A31D37FC6EDA45408672A25D057F6040A31D37FC6EDA45408672A25D057F6040E563778192D64540A30392B06F7E6040E563778192D64540
21147	Новоникольск	4	36	1637	131.841306	131.88082199999999	43.872878	43.839643000000002	0103000020E61000000100000005000000B77D8FFAEB7A60405DA8FC6B79EB4540B77D8FFAEB7A6040EEB25F77BAEF45401D739EB12F7C6040EEB25F77BAEF45401D739EB12F7C60405DA8FC6B79EB4540B77D8FFAEB7A60405DA8FC6B79EB4540
20609	Николо-Львовское	4	36	1637	131.35484099999999	131.38009299999999	43.882983000000003	43.872923999999998	0103000020E61000000100000005000000F54883DB5A6B60405EF23FF9BBEF4540F54883DB5A6B604045F6419605F14540088ECBB8296C604045F6419605F14540088ECBB8296C60405EF23FF9BBEF4540F54883DB5A6B60405EF23FF9BBEF4540
20881	Монакино	4	36	1637	131.452012	131.462234	43.749084000000003	43.740324000000001	0103000020E61000000100000005000000C9ACDEE1766E6040D238D4EFC2DE4540C9ACDEE1766E60407BFA08FCE1DF45402D23F59ECA6E60407BFA08FCE1DF45402D23F59ECA6E6040D238D4EFC2DE4540C9ACDEE1766E6040D238D4EFC2DE4540
21572	Линевичи	4	36	1637	131.83163099999999	131.84775500000001	43.740982000000002	43.728501999999999	0103000020E61000000100000005000000DF6A9DB89C7A60400989B48D3FDD4540DF6A9DB89C7A60405C76887FD8DE4540A80018CF207B60405C76887FD8DE4540A80018CF207B60400989B48D3FDD4540DF6A9DB89C7A60400989B48D3FDD4540
20989	Кроуновка	4	36	1637	131.64423300000001	131.67705799999999	43.754429999999999	43.748725999999998	0103000020E610000001000000050000002140868E9D7460401BD5E940D6DF45402140868E9D746040868F882991E04540D8EF8975AA756040868F882991E04540D8EF8975AA7560401BD5E940D6DF45402140868E9D7460401BD5E940D6DF4540
21510	Красный Яр	4	36	1637	131.911742	131.91923399999999	43.704771999999998	43.684365	0103000020E61000000100000005000000780C8FFD2C7D604076C3B64599D74540780C8FFD2C7D6040799109F835DA4540E1EB6B5D6A7D6040799109F835DA4540E1EB6B5D6A7D604076C3B64599D74540780C8FFD2C7D604076C3B64599D74540
20952	Корсаковка	4	36	1637	131.686508	131.70549800000001	43.787973999999998	43.770693000000001	0103000020E61000000100000005000000280EA0DFF7756040C9207711A6E24540280EA0DFF7756040950C0055DCE4454097AC8A7093766040950C0055DCE4454097AC8A7093766040C9207711A6E24540280EA0DFF7756040C9207711A6E24540
21696	Кондратеновка	4	36	1637	132.159255	132.16661199999999	43.634473	43.616194	0103000020E610000001000000050000002F17F19D18856040E7FEEA71DFCE45402F17F19D18856040F698486936D14540E063B0E254856040F698486936D14540E063B0E254856040E7FEEA71DFCE45402F17F19D18856040E7FEEA71DFCE4540
21791	Каменушка	4	36	1637	132.22621599999999	132.23643899999999	43.625455000000002	43.613871000000003	0103000020E610000001000000050000009F3A56293D8760403E7B2E5393CE45409F3A56293D876040520FD1E80ED04540F78F85E890876040520FD1E80ED04540F78F85E8908760403E7B2E5393CE45409F3A56293D8760403E7B2E5393CE4540
21869	Заречное	4	36	1637	132.10137700000001	132.11119500000001	43.702419999999996	43.693804	0103000020E610000001000000050000002272FA7A3E836040C0EAC891CED845402272FA7A3E836040350708E6E8D94540520FD1E88E836040350708E6E8D94540520FD1E88E836040C0EAC891CED845402272FA7A3E836040C0EAC891CED84540
21664	Дубовый Ключ	4	36	1637	132.126485	132.13315	43.666322999999998	43.65401	0103000020E61000000100000005000000E84D452A0C846040E4A08499B6D34540E84D452A0C8460404BC972124AD54540CCEEC9C3428460404BC972124AD54540CCEEC9C342846040E4A08499B6D34540E84D452A0C846040E4A08499B6D34540
55321	Горнотаежное	4	36	1637	132.146275	132.16745700000001	43.701585999999999	43.694468000000001	0103000020E610000001000000050000001EA7E848AE8460402C0FD253E4D845401EA7E848AE8460406DAAEE91CDD94540904FC8CE5B8560406DAAEE91CDD94540904FC8CE5B8560402C0FD253E4D845401EA7E848AE8460402C0FD253E4D84540
21361	Глуховка	4	36	1637	132.08758800000001	132.11098899999999	43.768290999999998	43.756500000000003	0103000020E61000000100000005000000B5705985CD82604046B6F3FDD4E04540B5705985CD826040D367075C57E24540E7A6CD388D836040D367075C57E24540E7A6CD388D83604046B6F3FDD4E04540B5705985CD82604046B6F3FDD4E04540
21289	Воздвиженка	4	36	1637	131.89197100000001	131.96609100000001	43.921902000000003	43.869472999999999	0103000020E61000000100000005000000603FC4068B7C6040A4E029E44AEF4540603FC4068B7C6040FA0E7EE200F64540B83EAC37EA7E6040FA0E7EE200F64540B83EAC37EA7E6040A4E029E44AEF4540603FC4068B7C6040A4E029E44AEF4540
21092	Борисовка	4	36	1637	131.79978500000001	131.82713000000001	43.820244000000002	43.792431999999998	0103000020E610000001000000050000009B5AB6D697796040E5266A696EE545409B5AB6D697796040C05E61C1FDE845404C7155D9777A6040C05E61C1FDE845404C7155D9777A6040E5266A696EE545409B5AB6D697796040E5266A696EE54540
21418	Боголюбовка	4	36	1637	132.26022599999999	132.27719500000001	43.823925000000003	43.814442	0103000020E6100000010000000500000034F279C553886040923EADA23FE8454034F279C553886040ACADD85F76E94540AC730CC8DE886040ACADD85F76E94540AC730CC8DE886040923EADA23FE8454034F279C553886040923EADA23FE84540
20787	Богатырка	4	36	1637	131.60136600000001	131.62401199999999	43.812300999999998	43.800643000000001	0103000020E61000000100000005000000A5DDE8633E736040BB6246787BE64540A5DDE8633E73604009C1AA7AF9E74540F88903E8F773604009C1AA7AF9E74540F88903E8F7736040BB6246787BE64540A5DDE8633E736040BB6246787BE64540
21876	Баневурово	4	36	1637	132.03502700000001	132.049993	43.723075999999999	43.714956999999998	0103000020E61000000100000005000000446FF1F01E816040EC8502B683DB4540446FF1F01E816040E1421EC18DDC4540ED80EB8A99816040E1421EC18DDC4540ED80EB8A99816040EC8502B683DB4540446FF1F01E816040EC8502B683DB4540
17063	Усть-Соболевка	4	36	1455	137.995385	138.01343199999999	46.175984999999997	46.166860999999997	0103000020E61000000100000005000000BABDA431DA3F61402AFD84B35B154740BABDA431DA3F614014CB2DAD861647400917F2086E40614014CB2DAD861647400917F2086E4061402AFD84B35B154740BABDA431DA3F61402AFD84B35B154740
16771	Терней	4	36	1455	136.53975500000001	136.633386	45.109703000000003	45.036113999999998	0103000020E61000000100000005000000481B47AC45116140C07630629F844640481B47AC45116140F5A276BF0A8E4640D177B7B244146140F5A276BF0A8E4640D177B7B244146140C07630629F844640481B47AC45116140C07630629F844640
55267	Терней	4	36	1455	136.53975500000001	136.633386	45.109703000000003	45.036113999999998	0103000020E61000000100000005000000481B47AC45116140C07630629F844640481B47AC45116140F5A276BF0A8E4640D177B7B244146140F5A276BF0A8E4640D177B7B244146140C07630629F844640481B47AC45116140C07630629F844640
17091	Светлая	4	36	1455	138.31090900000001	138.33873	46.545273999999999	46.536993000000002	0103000020E6100000010000000500000007616EF7F24961402997C62FBC44474007616EF7F2496140F7ADD689CB45474092054CE0D64A6140F7ADD689CB45474092054CE0D64A61402997C62FBC44474007616EF7F24961402997C62FBC444740
17203	Самарга	4	36	1455	138.79512800000001	138.81429800000001	47.254027000000001	47.241669999999999	0103000020E61000000100000005000000498446B0715961405036E50AEF9E4740498446B07159614087A6ECF483A0474058E6ADBA0E5A614087A6ECF483A0474058E6ADBA0E5A61405036E50AEF9E4740498446B0715961405036E50AEF9E4740
16633	Пластун	4	36	1455	136.25904	136.31914699999999	44.772052000000002	44.747647000000001	0103000020E61000000100000005000000630B410E4A086140ECF99AE5B25F4640630B410E4A086140DC679599D2624640BAF3C473360A6140DC679599D2624640BAF3C473360A6140ECF99AE5B25F4640630B410E4A086140ECF99AE5B25F4640
17160	Перетычиха	4	36	1455	138.62097199999999	138.64395099999999	47.186974999999997	47.181694999999998	0103000020E610000001000000050000006AF7AB00DF536140616C21C8419747406AF7AB00DF536140B515FBCBEE9747403FA7203F9B546140B515FBCBEE9747403FA7203F9B546140616C21C8419747406AF7AB00DF536140616C21C841974740
16866	Малая Кема	4	36	1455	137.13732300000001	137.16214400000001	45.4191	45.403700000000001	0103000020E61000000100000005000000A33F34F36424614096B20C71ACB34640A33F34F36424614076E09C11A5B54640C4279D483025614076E09C11A5B54640C4279D483025614096B20C71ACB34640A33F34F36424614096B20C71ACB34640
16912	Амгу	4	36	1455	137.66731100000001	137.68888899999999	45.856819999999999	45.836962999999997	0103000020E610000001000000050000005B28999C5A356140247B849A21EB46405B28999C5A35614084471B47ACED46405FB2F1600B36614084471B47ACED46405FB2F1600B366140247B849A21EB46405B28999C5A356140247B849A21EB4640
17256	Агзу	4	36	1455	138.389431	138.39777599999999	47.594577000000001	47.590293000000003	0103000020E610000001000000050000008E210038764C6140640795B88ECB47408E210038764C614016FA60191BCC474047E4BB94BA4C614016FA60191BCC474047E4BB94BA4C6140640795B88ECB47408E210038764C6140640795B88ECB4740
4015	Чкаловское	4	36	616	133.026704	133.06321199999999	44.857503000000001	44.812618999999998	0103000020E6100000010000000500000084D558C2DAA06040DA8D3EE60368464084D558C2DAA06040679C86A8C26D4640DF162CD505A26040679C86A8C26D4640DF162CD505A26040DA8D3EE60368464084D558C2DAA06040DA8D3EE603684640
31650	Хвалынка	4	36	616	132.874054	132.90650099999999	44.648310000000002	44.593995	0103000020E61000000100000005000000041E1840F89B6040677E3507084C4640041E1840F89B6040BBD573D2FB5246405299620E029D6040BBD573D2FB5246405299620E029D6040677E3507084C4640041E1840F89B6040677E3507084C4640
31573	Татьяновка	4	36	616	133.05146199999999	133.077181	44.620319000000002	44.609462000000001	0103000020E6100000010000000500000093DFA293A5A16040CF13CFD9024E464093DFA293A5A16040310BED9C664F4640ECDB494478A26040310BED9C664F4640ECDB494478A26040CF13CFD9024E464093DFA293A5A16040CF13CFD9024E4640
31562	Степное	4	36	616	132.73879400000001	132.751047	44.709077000000001	44.685459999999999	0103000020E61000000100000005000000658F5033A4976040AB5B3D27BD574640658F5033A497604043ACFE08C35A464049D8B7930898604043ACFE08C35A464049D8B79308986040AB5B3D27BD574640658F5033A4976040AB5B3D27BD574640
30579	Спасское	4	36	616	132.77627200000001	132.811567	44.637498000000001	44.591106000000003	0103000020E610000001000000050000009E996038D7986040153C855CA94B46409E996038D7986040F9A1D2889951464069705B5BF8996040F9A1D2889951464069705B5BF8996040153C855CA94B46409E996038D7986040153C855CA94B4640
31363	Сосновка	4	36	616	132.79651100000001	132.81239299999999	44.814723000000001	44.790841999999998	0103000020E61000000100000005000000F0FCA2047D996040D026874F3A654640F0FCA2047D9960404626E0D748684640FACF9A1FFF9960404626E0D748684640FACF9A1FFF996040D026874F3A654640F0FCA2047D996040D026874F3A654640
31303	Славинка	4	36	616	132.89174199999999	132.928258	44.583081999999997	44.565623000000002	0103000020E6100000010000000500000007CF8426899C6040C66E9F556648464007CF8426899C60407171546EA24A464003081F4AB49D60407171546EA24A464003081F4AB49D6040C66E9F556648464007CF8426899C6040C66E9F5566484640
31233	Свиягино	4	36	616	133.06605999999999	133.08684700000001	44.829549	44.795645999999998	0103000020E610000001000000050000005C72DC291DA26040BB9866BAD76546405C72DC291DA26040FAB660A92E6A46402F185C73C7A26040FAB660A92E6A46402F185C73C7A26040BB9866BAD76546405C72DC291DA26040BB9866BAD7654640
31155	Прохоры	4	36	616	132.677044	132.73985400000001	44.537129	44.505096999999999	0103000020E610000001000000050000007FBE2D58AA9560406327BC04A74046407FBE2D58AA956040D95DA0A4C044464013BA4BE2AC976040D95DA0A4C044464013BA4BE2AC9760406327BC04A74046407FBE2D58AA9560406327BC04A7404640
31109	Новосельское	4	36	616	132.685767	132.712456	44.780490999999998	44.765627000000002	0103000020E61000000100000005000000A2B5A2CDF1956040A1F7C61000624640A2B5A2CDF195604042E90B21E7634640D97A8670CC96604042E90B21E7634640D97A8670CC966040A1F7C61000624640A2B5A2CDF1956040A1F7C61000624640
31013	Нововладимировка	4	36	616	133.09845300000001	133.140916	44.617674999999998	44.584654999999998	0103000020E610000001000000050000002EE6E78626A36040B0389CF9D54A46402EE6E78626A36040454772F90F4F4640766F456282A46040454772F90F4F4640766F456282A46040B0389CF9D54A46402EE6E78626A36040B0389CF9D54A4640
30968	Новинка	4	36	616	132.794679	132.807399	44.568776	44.559573999999998	0103000020E610000001000000050000002D7AA7026E99604090D8EE1EA04746402D7AA7026E996040F65FE7A6CD484640577A6D36D6996040F65FE7A6CD484640577A6D36D699604090D8EE1EA04746402D7AA7026E99604090D8EE1EA0474640
30887	Нахимовка	4	36	616	133.10665399999999	133.12993	44.640749	44.631211999999998	0103000020E610000001000000050000009A3FA6B569A36040DF6B088ECB5046409A3FA6B569A36040ECF82F10045246409E98F56228A46040ECF82F10045246409E98F56228A46040DF6B088ECB5046409A3FA6B569A36040DF6B088ECB504640
30880	Малые Ключи	4	36	616	132.68802199999999	132.69722899999999	44.473421000000002	44.465226000000001	0103000020E61000000100000005000000B69DB64604966040DC9F8B868C3B4640B69DB64604966040AC1E300F993C4640541A31B34F966040AC1E300F993C4640541A31B34F966040DC9F8B868C3B4640B69DB64604966040DC9F8B868C3B4640
55319	Кронштадка	4	36	616	133.085014	133.107283	44.728433000000003	44.710621000000003	0103000020E6100000010000000500000078B6476FB8A26040E86C01A1F55A464078B6476FB8A26040E129E44A3D5D4640560DC2DC6EA36040E129E44A3D5D4640560DC2DC6EA36040E86C01A1F55A464078B6476FB8A26040E86C01A1F55A4640
30295	Красный Кут	4	36	616	132.81386699999999	132.845371	44.535297999999997	44.502795999999996	0103000020E610000001000000050000006589CE320B9A6040A1478C9E5B4046406589CE320B9A60409ECE15A58444464094BF7B470D9B60409ECE15A58444464094BF7B470D9B6040A1478C9E5B4046406589CE320B9A6040A1478C9E5B404640
30685	Константиновка	4	36	616	132.98547199999999	133.002486	44.679845999999998	44.665031999999997	0103000020E61000000100000005000000F56393FC889F60409065C1C41F554640F56393FC889F604080289831055746405516855D14A0604080289831055746405516855D14A060409065C1C41F554640F56393FC889F60409065C1C41F554640
55300	Кнорринг	4	36	616	132.62866099999999	132.64092299999999	44.535952999999999	44.514907000000001	0103000020E61000000100000005000000A968ACFD1D946040A1BDFA78E8414640A968ACFD1D946040B7989F1B9A4446402288F37082946040B7989F1B9A4446402288F37082946040A1BDFA78E8414640A968ACFD1D946040A1BDFA78E8414640
30532	Зеленодольское	4	36	616	133.06485599999999	133.087008	44.922139999999999	44.913913000000001	0103000020E6100000010000000500000061DEE34C13A26040D331E719FB74464061DEE34C13A26040AE2AFBAE08764640B14F00C5C8A26040AE2AFBAE08764640B14F00C5C8A26040D331E719FB74464061DEE34C13A26040D331E719FB744640
30499	Зеленовка	4	36	616	133.01154099999999	133.03123199999999	44.530099	44.518191000000002	0103000020E6100000010000000500000005323B8B5EA06040700A2B155442464005323B8B5EA060403752B648DA434640D65240DAFFA060403752B648DA434640D65240DAFFA06040700A2B155442464005323B8B5EA06040700A2B1554424640
30460	Евсеевка	4	36	616	132.88036	132.904596	44.420324999999998	44.40455	0103000020E610000001000000050000009C16BCE82B9C604064CC5D4BC83346409C16BCE82B9C60407958A835CD354640F5824F73F29C60407958A835CD354640F5824F73F29C604064CC5D4BC83346409C16BCE82B9C604064CC5D4BC8334640
30366	Духовское	4	36	616	133.132203	133.15911600000001	44.887327999999997	44.868907	0103000020E61000000100000005000000DC2DC9013BA46040FB213658386F4640DC2DC9013BA460409C69C2F693714640A708707A17A560409C69C2F693714640A708707A17A56040FB213658386F4640DC2DC9013BA46040FB213658386F4640
30360	Дубовское	4	36	616	132.83981900000001	132.865645	44.564537999999999	44.53434	0103000020E61000000100000005000000E77118CCDF9A6040EA78CC4065444640E77118CCDF9A6040B4ACFBC742484640459E245DB39B6040B4ACFBC742484640459E245DB39B6040EA78CC4065444640E77118CCDF9A6040EA78CC4065444640
30222	Гайворон	4	36	616	132.76574400000001	132.78699800000001	44.762791999999997	44.733888999999998	0103000020E6100000010000000500000077A38FF98098604073F22213F05D464077A38FF98098604041D3122BA36146408F006E162F99604041D3122BA36146408F006E162F99604073F22213F05D464077A38FF98098604073F22213F05D4640
30194	Воскресенка	4	36	616	132.72478100000001	132.74977200000001	44.584732000000002	44.562451000000003	0103000020E610000001000000050000006478EC67319760401F4DF564FE4746406478EC67319760405C76887FD84A46409C6ED921FE9760405C76887FD84A46409C6ED921FE9760401F4DF564FE4746406478EC67319760401F4DF564FE474640
30147	Вишневка	4	36	616	132.850123	132.869248	44.465310000000002	44.444507999999999	0103000020E610000001000000050000007A522635349B6040BA675DA3E53846407A522635349B60403A4030478F3B4640A1832EE1D09B60403A4030478F3B4640A1832EE1D09B6040BA675DA3E53846407A522635349B6040BA675DA3E5384640
30054	Буссевка	4	36	616	132.971341	132.99453600000001	44.642122000000001	44.627541999999998	0103000020E610000001000000050000007288B839159F6040E76ED74B535046407288B839159F60406405BF0D315246403B56293DD39F60406405BF0D315246403B56293DD39F6040E76ED74B535046407288B839159F6040E76ED74B53504640
29943	Анненка	4	36	616	132.94175999999999	132.95505499999999	44.712735000000002	44.698718	0103000020E61000000100000005000000CA15DEE5229E6040329067976F594640CA15DEE5229E604077DB85E63A5B464033DC80CF8F9E604077DB85E63A5B464033DC80CF8F9E6040329067976F594640CA15DEE5229E6040329067976F594640
29915	Александровка	4	36	616	132.94254100000001	132.96464900000001	44.788079000000003	44.754356000000001	0103000020E610000001000000050000007444BE4B299E60404CC5C6BC8E6046407444BE4B299E60400BD5CDC5DF644640D0639467DE9E60400BD5CDC5DF644640D0639467DE9E60404CC5C6BC8E6046407444BE4B299E60404CC5C6BC8E604640
55323	Ясеневый	4	36	668	135.40334100000001	135.415469	46.607349999999997	46.598632000000002	0103000020E610000001000000050000005A84622BE8EC6040672B2FF99F4C47405A84622BE8EC6040E09C11A5BD4D47400FF0A4854BED6040E09C11A5BD4D47400FF0A4854BED6040672B2FF99F4C47405A84622BE8EC6040672B2FF99F4C4740
14943	Федосьевка	4	36	668	134.26192399999999	134.28085999999999	46.542614999999998	46.527723999999999	0103000020E6100000010000000500000033C170AE61C860403BA8C4758C43474033C170AE61C86040D6A887687445474025581CCEFCC86040D6A887687445474025581CCEFCC860403BA8C4758C43474033C170AE61C860403BA8C4758C434740
55315	Соболиный	4	36	668	135.42721800000001	135.44460100000001	46.679816000000002	46.672224	0103000020E61000000100000005000000674815C5ABED60400CCB9F6F0B564740674815C5ABED604016A6EF35045747409B58E02B3AEE604016A6EF35045747409B58E02B3AEE60400CCB9F6F0B564740674815C5ABED60400CCB9F6F0B564740
14998	Светлогорье	4	36	668	134.43489400000001	134.451639	46.864871000000001	46.856971999999999	0103000020E610000001000000050000004167D2A6EACD60403ACB2C42B16D47404167D2A6EACD60402121CA17B46E474024D3A1D373CE60402121CA17B46E474024D3A1D373CE60403ACB2C42B16D47404167D2A6EACD60403ACB2C42B16D4740
14228	Пожарское	4	36	668	134.05082899999999	134.07665499999999	46.264341000000002	46.245572000000003	0103000020E6100000010000000500000007962364A0C160401B683EE76E1F474007962364A0C16040F8FE06EDD521474065C22FF573C26040F8FE06EDD521474065C22FF573C260401B683EE76E1F474007962364A0C160401B683EE76E1F4740
14179	Пожарский	4	36	668	134.00275099999999	134.020771	46.228411000000001	46.219400999999998	0103000020E6100000010000000500000000E1438916C06040D7DAFB54151C474000E1438916C06040F98557923C1D474091B6F127AAC06040F98557923C1D474091B6F127AAC06040D7DAFB54151C474000E1438916C06040D7DAFB54151C4740
14099	Новостройка	4	36	668	133.921516	133.94568100000001	46.192613000000001	46.174325000000003	0103000020E61000000100000005000000B4571F0F7DBD604007F0164850164740B4571F0F7DBD604069E4F38AA71847405BEECC0443BE604069E4F38AA71847405BEECC0443BE604007F0164850164740B4571F0F7DBD604007F0164850164740
14289	Никитовка	4	36	668	134.10737800000001	134.12904499999999	46.282020000000003	46.271655000000003	0103000020E61000000100000005000000EBC9FCA36FC36040BF654E97C5224740EBC9FCA36FC36040B2683A3B19244740CBD6FA2221C46040B2683A3B19244740CBD6FA2221C46040BF654E97C5224740EBC9FCA36FC36040BF654E97C5224740
14514	Нагорное	4	36	668	134.373558	134.400803	46.346003000000003	46.330204999999999	0103000020E610000001000000050000001825E82FF4CB6040E3FC4D28442A47401825E82FF4CB6040B1A888D3492C47407024D060D3CC6040B1A888D3492C47407024D060D3CC6040E3FC4D28442A47401825E82FF4CB6040E3FC4D28442A4740
14565	Лучегорск	4	36	668	134.27604500000001	134.31674799999999	46.451582000000002	46.431778999999999	0103000020E610000001000000050000002EE7525CD5C86040BF0CC688443747402EE7525CD5C860402CBB6070CD39474059A2B3CC22CA60402CBB6070CD39474059A2B3CC22CA6040BF0CC688443747402EE7525CD5C86040BF0CC68844374740
55266	Лучегорск	4	36	668	134.27604500000001	134.31674799999999	46.451582000000002	46.431778999999999	0103000020E610000001000000050000002EE7525CD5C86040BF0CC688443747402EE7525CD5C860402CBB6070CD39474059A2B3CC22CA60402CBB6070CD39474059A2B3CC22CA6040BF0CC688443747402EE7525CD5C86040BF0CC68844374740
14377	Ласточка	4	36	668	134.11302800000001	134.15886900000001	46.400086000000002	46.361105000000002	0103000020E610000001000000050000000971E5EC9DC3604007B64AB0382E47400971E5EC9DC3604032CB9E043633474025EB707415C5604032CB9E043633474025EB707415C5604007B64AB0382E47400971E5EC9DC3604007B64AB0382E4740
4555	Красный Яр	4	36	668	135.351428	135.37030100000001	46.547511999999998	46.534990000000001	0103000020E61000000100000005000000C2DCEEE53EEB6040F1D7648D7A444740C2DCEEE53EEB604072158BDF14464740A3957B81D9EB604072158BDF14464740A3957B81D9EB6040F1D7648D7A444740C2DCEEE53EEB6040F1D7648D7A444740
14463	Игнатьевка	4	36	668	134.12615299999999	134.142448	46.411999000000002	46.400632999999999	0103000020E610000001000000050000005A29047209C46040645930F1473347405A29047209C460400B7E1B62BC3447402EAC1BEF8EC460400B7E1B62BC3447402EAC1BEF8EC46040645930F1473347405A29047209C46040645930F147334740
14029	Знаменка	4	36	668	133.95557099999999	133.98731799999999	46.173813000000003	46.149768999999999	0103000020E610000001000000050000003140A20994BE6040317A6EA12B1347403140A20994BE6040514F1F813F1647401118EB1B98BF6040514F1F813F1647401118EB1B98BF6040317A6EA12B1347403140A20994BE6040317A6EA12B134740
14301	Емельяновка	4	36	668	134.033931	134.04897800000001	46.369456999999997	46.356223	0103000020E6100000010000000500000042EA76F615C16040A08A1BB7982D474042EA76F615C160409E23F25D4A2F474027874F3A91C160409E23F25D4A2F474027874F3A91C16040A08A1BB7982D474042EA76F615C16040A08A1BB7982D4740
14150	Губерово	4	36	668	133.93954500000001	133.966037	46.210839	46.193356000000001	0103000020E61000000100000005000000DA03ADC010BE6040213EB0E3BF184740DA03ADC010BE604055DCB8C5FC1A47403B376DC6E9BE604055DCB8C5FC1A47403B376DC6E9BE6040213EB0E3BF184740DA03ADC010BE6040213EB0E3BF184740
55265	Верхний Перевал	4	36	668	134.65544	134.69240600000001	46.575215	46.555016999999999	0103000020E61000000100000005000000B08F4E5DF9D46040ADDC0BCC0A474740B08F4E5DF9D46040969526A5A0494740BCB1A03028D66040969526A5A0494740BCB1A03028D66040ADDC0BCC0A474740B08F4E5DF9D46040ADDC0BCC0A474740
13423	Таловый	4	36	1251	131.55781500000001	131.565136	44.386284000000003	44.379010000000001	0103000020E61000000100000005000000FCC6D79ED9716040B16D516683304640FCC6D79ED9716040EA7B0DC1713146405AB9179815726040EA7B0DC1713146405AB9179815726040B16D516683304640FCC6D79ED9716040B16D516683304640
13343	Софье-Алексеевское	4	36	1251	131.343513	131.35491300000001	44.305086000000003	44.295195999999997	0103000020E610000001000000050000000798F90EFE6A60407BF486FBC82546400798F90EFE6A6040D63BDC0E0D2746409CFD81725B6B6040D63BDC0E0D2746409CFD81725B6B60407BF486FBC82546400798F90EFE6A60407BF486FBC8254640
13567	Сергеевка	4	36	1251	131.64525699999999	131.678585	44.346832999999997	44.318269999999998	0103000020E610000001000000050000007B1002F2A574604022A64412BD2846407B1002F2A574604037161406652C4640CCD1E3F7B675604037161406652C4640CCD1E3F7B675604022A64412BD2846407B1002F2A574604022A64412BD284640
55328	Садовый	4	36	1251	131.59719699999999	131.604555	44.408071999999997	44.398155000000003	0103000020E610000001000000050000009E08E23C1C73604094DE37BEF63246409E08E23C1C736040E7340BB43B3446404434BA8358736040E7340BB43B3446404434BA835873604094DE37BEF63246409E08E23C1C73604094DE37BEF6324640
13920	Рубиновка	4	36	1251	131.68790000000001	131.70409699999999	44.695591	44.686478999999999	0103000020E61000000100000005000000645DDC460376604005323B8BDE574640645DDC46037660402B323A2009594640C6866EF6877660402B323A2009594640C6866EF68776604005323B8BDE574640645DDC460376604005323B8BDE574640
55258	Пограничный	4	36	1251	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
12859	Пограничный	4	36	1251	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
13703	Нестеровка	4	36	1251	131.752184	131.768317	44.462704000000002	44.441786	0103000020E6100000010000000500000062122EE41178604053EA92718C38464062122EE4117860403CDD79E2393B4640BF7E880D967860403CDD79E2393B4640BF7E880D9678604053EA92718C38464062122EE41178604053EA92718C384640
13750	Жариково	4	36	1251	131.69384700000001	131.75915499999999	44.607871000000003	44.575055999999996	0103000020E61000000100000005000000B0AD9FFE337660402DAF5C6F9B494640B0AD9FFE33766040EA9788B7CE4D464009336DFF4A786040EA9788B7CE4D464009336DFF4A7860402DAF5C6F9B494640B0AD9FFE337660402DAF5C6F9B494640
13906	Духовское	4	36	1251	131.52314899999999	131.54610099999999	44.604436999999997	44.585894000000003	0103000020E61000000100000005000000ECBDF8A2BD70604019761893FE4A4640ECBDF8A2BD70604005BF0D315E4D464003EACDA87971604005BF0D315E4D464003EACDA87971604019761893FE4A4640ECBDF8A2BD70604019761893FE4A4640
13200	Бойкое	4	36	1251	131.46128200000001	131.47734399999999	44.470919000000002	44.458618999999999	0103000020E61000000100000005000000790778D2C26E604080290307B43A4640790778D2C26E60405308E412473C4640239EEC66466F60405308E412473C4640239EEC66466F604080290307B43A4640790778D2C26E604080290307B43A4640
13793	Богуславка	4	36	1251	131.56424699999999	131.58850200000001	44.500404000000003	44.475467000000002	0103000020E61000000100000005000000B77BB94F0E726040E3A9471ADC3C4640B77BB94F0E726040D064FF3C0D4046402E742502D5726040D064FF3C0D4046402E742502D5726040E3A9471ADC3C4640B77BB94F0E726040E3A9471ADC3C4640
13225	Барано-Оренбургское	4	36	1251	131.43445	131.47034600000001	44.381239000000001	44.357649000000002	0103000020E61000000100000005000000E9B7AF03E76D60403B394371C72D4640E9B7AF03E76D6040D97A8670CC304640BEF90D130D6F6040D97A8670CC304640BEF90D130D6F60403B394371C72D4640E9B7AF03E76D60403B394371C72D4640
12498	Хмыловка	4	36	738	133.11532299999999	133.131574	42.789496	42.777335000000001	0103000020E61000000100000005000000402FDCB9B0A36040A18499B67F634540402FDCB9B0A36040522976340E6545402060ADDA35A46040522976340E6545402060ADDA35A46040A18499B67F634540402FDCB9B0A36040A18499B67F634540
11975	Фроловка	4	36	738	133.25264899999999	133.282185	43.219065999999998	43.203144999999999	0103000020E61000000100000005000000BF0B5BB315A8604047ACC5A7009A4540BF0B5BB315A8604030D5CC5A0A9C45407F4DD6A807A9604030D5CC5A0A9C45407F4DD6A807A9604047ACC5A7009A4540BF0B5BB315A8604047ACC5A7009A4540
11834	Сергеевка	4	36	738	133.13889499999999	133.37734399999999	43.360624000000001	42.998584000000001	0103000020E610000001000000050000007E52EDD371A460408927BB99D17F45407E52EDD371A460408C135FED28AE4540F06AB93313AC60408C135FED28AE4540F06AB93313AC60408927BB99D17F45407E52EDD371A460408927BB99D17F4540
55326	Село Перетино	4	36	738	132.50149500000001	133.75279499999999	43.821798000000001	42.679794000000001	0103000020E6100000010000000500000071033E3F0C9060402E02637D0357454071033E3F0C90604088F546AD30E94540F4328AE516B8604088F546AD30E94540F4328AE516B860402E02637D0357454071033E3F0C9060402E02637D03574540
12793	Новолитовск	4	36	738	132.78312600000001	132.80918600000001	42.928418999999998	42.898158000000002	0103000020E61000000100000005000000B7D4415E0F996040055262D7F6724540B7D4415E0F99604015FE0C6FD676454032CC09DAE499604015FE0C6FD676454032CC09DAE4996040055262D7F6724540B7D4415E0F996040055262D7F6724540
12197	Новицкое	4	36	738	133.157984	133.185338	43.059828000000003	43.049188999999998	0103000020E61000000100000005000000522976340EA5604056293DD34B864540522976340EA560404BB1A371A88745409816F549EEA560404BB1A371A88745409816F549EEA5604056293DD34B864540522976340EA5604056293DD34B864540
12573	Новая Сила	4	36	738	133.09703400000001	133.11278999999999	43.025322000000003	43.003943999999997	0103000020E6100000010000000500000034130CE71AA36040F981AB3C8180454034130CE71AA3604046EF54C03D8345401B2AC6F99BA3604046EF54C03D8345401B2AC6F99BA36040F981AB3C8180454034130CE71AA36040F981AB3C81804540
12005	Николаевка	4	36	738	133.185059	133.22960699999999	43.107953999999999	43.075437000000001	0103000020E61000000100000005000000931ADA00ECA5604045F46BEBA7894540931ADA00ECA5604077BCC96FD18D4540D87DC7F058A7604077BCC96FD18D4540D87DC7F058A7604045F46BEBA7894540931ADA00ECA5604045F46BEBA7894540
11796	Молчановка	4	36	738	133.357743	133.37413699999999	43.484585000000003	43.468373999999997	0103000020E61000000100000005000000EFAB72A172AB6040FA25E2ADF3BB4540EFAB72A172AB6040EB909BE106BE4540276728EEF8AB6040EB909BE106BE4540276728EEF8AB6040FA25E2ADF3BB4540EFAB72A172AB6040FA25E2ADF3BB4540
12340	Золотая Долина	4	36	738	133.096396	133.14505700000001	42.966338	42.922866999999997	0103000020E61000000100000005000000E36E10AD15A3604060C77F8120764540E36E10AD15A36040E770ADF6B07B4540CAE1934EA4A46040E770ADF6B07B4540CAE1934EA4A4604060C77F8120764540E36E10AD15A3604060C77F8120764540
12686	Екатериновка	4	36	738	133.02268000000001	133.06990400000001	42.934829000000001	42.910316000000002	0103000020E61000000100000005000000BF4868CBB9A060404583143C85744540BF4868CBB9A060401B2D077AA8774540823B50A73CA260401B2D077AA8774540823B50A73CA260404583143C85744540BF4868CBB9A060404583143C85744540
12762	Голубовка	4	36	738	132.97862699999999	133.007229	42.884571000000001	42.865966	0103000020E6100000010000000500000071FF91E9509F604056B950F9D76E454071FF91E9509F6040B9FE5D9F39714540A6D24F383BA06040B9FE5D9F39714540A6D24F383BA0604056B950F9D76E454071FF91E9509F604056B950F9D76E4540
55252	Врангель	4	36	738	133.02174600000001	133.12417199999999	42.744278000000001	42.714216999999998	0103000020E6100000010000000500000034DAAA24B2A06040A59F70766B5B454034DAAA24B2A06040EF906280445F454086E28E37F9A36040EF906280445F454086E28E37F9A36040A59F70766B5B454034DAAA24B2A06040A59F70766B5B4540
5168	Волчанец	4	36	738	132.73781500000001	132.77363099999999	42.919545999999997	42.910204	0103000020E61000000100000005000000F2EF332E9C9760401D588E9081744540F2EF332E9C9760407495EEAEB37545407F85CC95C19860407495EEAEB37545407F85CC95C19860401D588E9081744540F2EF332E9C9760401D588E9081744540
12433	Владимиро-Александровское	4	36	738	133.05974399999999	133.098264	42.904459000000003	42.87735	0103000020E610000001000000050000003BC43F6CE9A16040A3923A014D7045403BC43F6CE9A1604054C90050C5734540F94B8BFA24A3604054C90050C5734540F94B8BFA24A36040A3923A014D7045403BC43F6CE9A16040A3923A014D704540
12620	Боец Кузнецов	4	36	738	133.057355	133.07481799999999	42.962966999999999	42.942214	0103000020E61000000100000005000000632827DAD5A16040ABEAE5779A784540632827DAD5A160404910AE80427B4540DEE4B7E864A260404910AE80427B4540DEE4B7E864A26040ABEAE5779A784540632827DAD5A16040ABEAE5779A784540
9408	Щербаковка	4	36	1029	134.624304	134.633602	43.577283000000001	43.561802999999998	0103000020E6100000010000000500000062D8614CFAD36040B8E52329E9C7454062D8614CFAD36040B5C4CA68E4C94540C495B37746D46040B5C4CA68E4C94540C495B37746D46040B8E52329E9C7454062D8614CFAD36040B8E52329E9C74540
9369	Фурманово	4	36	1029	134.673146	134.69833399999999	43.978552999999998	43.972701000000001	0103000020E61000000100000005000000DDED7A698AD56040ACE4637781FC4540DDED7A698AD560408B33863941FD4540EA758BC058D660408B33863941FD4540EA758BC058D66040ACE4637781FC4540DDED7A698AD56040ACE4637781FC4540
9651	Тимофеевка	4	36	1029	135.42975200000001	135.47320300000001	43.878967000000003	43.857118	0103000020E61000000100000005000000802C4487C0ED60400E68E90AB6ED4540802C4487C0ED6040B2A19BFD81F04540D02B9E7A24EF6040B2A19BFD81F04540D02B9E7A24EF60400E68E90AB6ED4540802C4487C0ED60400E68E90AB6ED4540
9733	Ракушка	4	36	1029	135.44020800000001	135.45840799999999	43.945239999999998	43.932347999999998	0103000020E61000000100000005000000016E162F16EE6040D93EE42D57F74540016E162F16EE60407E6FD39FFDF8454031074147ABEE60407E6FD39FFDF8454031074147ABEE6040D93EE42D57F74540016E162F16EE6040D93EE42D57F74540
9196	Пермское	4	36	1029	135.16664399999999	135.182311	43.772483000000001	43.761651000000001	0103000020E610000001000000050000006342CC2555E560409CFBABC77DE145406342CC2555E56040A5DB12B9E0E245406FD6E07DD5E56040A5DB12B9E0E245406FD6E07DD5E560409CFBABC77DE145406342CC2555E560409CFBABC77DE14540
9089	Ольга	4	36	1029	135.27192700000001	135.32840400000001	43.788442000000003	43.738363999999997	0103000020E61000000100000005000000C87C40A0B3E86040994528B682DE4540C87C40A0B3E860407C65DEAAEBE4454005FC1A4982EA60407C65DEAAEBE4454005FC1A4982EA6040994528B682DE4540C87C40A0B3E86040994528B682DE4540
9281	Новониколаевка	4	36	1029	135.01989499999999	135.03157300000001	43.828926000000003	43.81597	0103000020E6100000010000000500000053CBD6FAA2E06040314278B471E8454053CBD6FAA2E06040ED66463F1AEA4540F94D61A502E16040ED66463F1AEA4540F94D61A502E16040314278B471E8454053CBD6FAA2E06040314278B471E84540
9523	Моряк-Рыболов	4	36	1029	134.77183500000001	134.79855000000001	43.360492999999998	43.340702	0103000020E61000000100000005000000105D50DFB2D8604045D7851F9CAB4540105D50DFB2D86040EDB776A224AE454011C7BAB88DD96040EDB776A224AE454011C7BAB88DD9604045D7851F9CAB4540105D50DFB2D8604045D7851F9CAB4540
9447	Маргаритово	4	36	1029	134.74025	134.766391	43.419879999999999	43.401857	0103000020E61000000100000005000000A69BC420B0D760409755D80C70B34540A69BC420B0D760404B1FBAA0BEB545405C1E6B4686D860404B1FBAA0BEB545405C1E6B4686D860409755D80C70B34540A69BC420B0D760409755D80C70B34540
9593	Лиственное	4	36	1029	134.526433	134.54281800000001	43.332898999999998	43.323940999999998	0103000020E6100000010000000500000020D1048AD8D06040B16A10E676A9454020D1048AD8D0604080EF366F9CAA4540C4B5DAC35ED1604080EF366F9CAA4540C4B5DAC35ED16040B16A10E676A9454020D1048AD8D06040B16A10E676A94540
9257	Ветка	4	36	1029	135.11637400000001	135.12820500000001	43.778607999999998	43.768649000000003	0103000020E610000001000000050000005A83F755B9E36040338D261763E245405A83F755B9E36040B5334C6DA9E34540E1455F411AE46040B5334C6DA9E34540E1455F411AE46040338D261763E245405A83F755B9E36040338D261763E24540
9039	Веселый Яр	4	36	1029	135.44724199999999	135.51880199999999	43.970936999999999	43.921843000000003	0103000020E61000000100000005000000B96C74CE4FEE6040F58590F3FEF54540B96C74CE4FEE6040F9BCE2A947FC45402EE3A6069AF06040F9BCE2A947FC45402EE3A6069AF06040F58590F3FEF54540B96C74CE4FEE6040F58590F3FEF54540
7952	Покровка	4	36	454	131.60318899999999	131.67637500000001	43.961204000000002	43.930504999999997	0103000020E61000000100000005000000D28904534D736040DAE1AFC91AF74540D28904534D736040676490BB08FB4540A01A2FDDA4756040676490BB08FB4540A01A2FDDA4756040DAE1AFC91AF74540D28904534D736040DAE1AFC91AF74540
55329	п. Тавричанка	4	36	579	131.384063	132.06049400000001	43.662703999999998	43.274470000000001	0103000020E6100000010000000500000051137D3E4A6C6040D7DD3CD521A3454051137D3E4A6C6040D576137CD3D4454056F31C91EF816040D576137CD3D4454056F31C91EF816040D7DD3CD521A3454051137D3E4A6C6040D7DD3CD521A34540
55327	Тихое	4	36	579	131.79383000000001	131.80855299999999	43.519137000000001	43.506898999999997	0103000020E61000000100000005000000AE122C0E6779604003B00111E2C04540AE122C0E677960406092CA1473C24540A5828AAADF7960406092CA1473C24540A5828AAADF79604003B00111E2C04540AE122C0E6779604003B00111E2C04540
4267	Тимофеевка	4	36	579	131.93805399999999	131.94961499999999	43.517567999999997	43.506506000000002	0103000020E61000000100000005000000397CD289047E6040289D4830D5C04540397CD289047E604062BA10AB3FC245405019FF3E637E604062BA10AB3FC245405019FF3E637E6040289D4830D5C04540397CD289047E6040289D4830D5C04540
3629	Тереховка	4	36	579	131.91056599999999	131.926637	43.647781000000002	43.635365999999998	0103000020E610000001000000050000002FDB4E5B237D6040C37E4FAC53D145402FDB4E5B237D60402FFCE07CEAD245406F48A302A77D60402FFCE07CEAD245406F48A302A77D6040C37E4FAC53D145402FDB4E5B237D6040C37E4FAC53D14540
4432	Таежный	4	36	579	131.953101	131.960296	43.478991999999998	43.473287999999997	0103000020E610000001000000050000001E19ABCD7F7E60406CCB80B394BC45401E19ABCD7F7E6040D7851F9C4FBD4540594FADBEBA7E6040D7851F9C4FBD4540594FADBEBA7E60406CCB80B394BC45401E19ABCD7F7E60406CCB80B394BC4540
55289	Тавричанка	4	36	579	131.384063	132.06049400000001	43.662703999999998	43.274470000000001	0103000020E6100000010000000500000051137D3E4A6C6040D7DD3CD521A3454051137D3E4A6C6040D576137CD3D4454056F31C91EF816040D576137CD3D4454056F31C91EF816040D7DD3CD521A3454051137D3E4A6C6040D7DD3CD521A34540
4997	Соловей-Ключ	4	36	579	132.04609400000001	132.05803299999999	43.400782999999997	43.389870000000002	0103000020E6100000010000000500000057D11F9A7981604084D89942E7B1454057D11F9A7981604079E57ADB4CB34540D7A20568DB81604079E57ADB4CB34540D7A20568DB81604084D89942E7B1454057D11F9A7981604084D89942E7B14540
3907	Раздольное	4	36	579	131.87057300000001	131.945537	43.575847000000003	43.493310000000001	0103000020E61000000100000005000000FB78E8BBDB7B6040176536C824BF4540FB78E8BBDB7B6040F73FC05AB5C945400E85CFD6417E6040F73FC05AB5C945400E85CFD6417E6040176536C824BF4540FB78E8BBDB7B6040176536C824BF4540
4922	Прохладное	4	36	579	131.95933500000001	132.09113600000001	43.384261000000002	43.288055999999997	0103000020E61000000100000005000000105D50DFB27E604052B5DD04DFA44540105D50DFB27E60406B10E6762FB14540A06F0B96EA8260406B10E6762FB14540A06F0B96EA82604052B5DD04DFA44540105D50DFB27E604052B5DD04DFA44540
4169	Оленевод	4	36	579	131.85057599999999	131.866297	43.604883000000001	43.580652999999998	0103000020E6100000010000000500000066D828EB377B604082A966D652CA454066D828EB377B604004745FCE6CCD4540EF737CB4B87B604004745FCE6CCD4540EF737CB4B87B604082A966D652CA454066D828EB377B604082A966D652CA4540
55287	Новый	4	36	579	132.00474500000001	132.02856800000001	43.372500000000002	43.358756	0103000020E610000001000000050000003A7AFCDE26806040349F73B7EBAD45403A7AFCDE2680604048E17A14AEAF4540CA367007EA80604048E17A14AEAF4540CA367007EA806040349F73B7EBAD45403A7AFCDE26806040349F73B7EBAD4540
3776	Нежино	4	36	579	131.76400599999999	131.77704900000001	43.460541999999997	43.450260999999998	0103000020E6100000010000000500000054FEB5BC7278604006D50627A2B9454054FEB5BC727860409B374E0AF3BA4540774CDD95DD7860409B374E0AF3BA4540774CDD95DD78604006D50627A2B9454054FEB5BC7278604006D50627A2B94540
4415	Кипарисово-2	4	36	579	131.91980899999999	131.943579	43.457552	43.436418000000003	0103000020E6100000010000000500000020B248136F7D604060B1868BDCB7454020B248136F7D6040151C5E1091BA4540284696CC317E6040151C5E1091BA4540284696CC317E604060B1868BDCB7454020B248136F7D604060B1868BDCB74540
4345	Кипарисово-1	4	36	579	131.91598300000001	131.931164	43.484042000000002	43.470768999999997	0103000020E61000000100000005000000259694BB4F7D60403D7C992842BC4540259694BB4F7D6040FAF19716F5BD4540CDE67118CC7D6040FAF19716F5BD4540CDE67118CC7D60403D7C992842BC4540259694BB4F7D60403D7C992842BC4540
4551	Западный	4	36	579	131.96137400000001	131.97192999999999	43.363658999999998	43.354568	0103000020E6100000010000000500000031276893C37E6040A41AF67B62AD454031276893C37E6040B2F2CB608CAE45400A80F10C1A7F6040B2F2CB608CAE45400A80F10C1A7F6040A41AF67B62AD454031276893C37E6040A41AF67B62AD4540
55295	Девятый Вал	4	36	579	131.384063	132.06049400000001	43.662703999999998	43.274470000000001	0103000020E6100000010000000500000051137D3E4A6C6040D7DD3CD521A3454051137D3E4A6C6040D576137CD3D4454056F31C91EF816040D576137CD3D4454056F31C91EF816040D7DD3CD521A3454051137D3E4A6C6040D7DD3CD521A34540
55324	Городечное	4	36	579	131.945088	131.96247	43.644877999999999	43.633434999999999	0103000020E61000000100000005000000F27A30293E7E60402592E86514D14540F27A30293E7E604077F4BF5C8BD2454032ACE28DCC7E604077F4BF5C8BD2454032ACE28DCC7E60402592E86514D14540F27A30293E7E60402592E86514D14540
4640	Вольно-Надеждинское	4	36	579	131.96900099999999	132.010683	43.385643999999999	43.356225999999999	0103000020E610000001000000050000005299620E027F604011FE45D098AD45405299620E027F604006F357C85CB14540F1F3DF835780604006F357C85CB14540F1F3DF835780604011FE45D098AD45405299620E027F604011FE45D098AD4540
55303	Барановский	4	36	579	131.922909	131.93760499999999	43.656475999999998	43.643835000000003	0103000020E61000000100000005000000E4857478887D604095826E2F69D24540E4857478887D6040F04DD36707D445401D7233DC007E6040F04DD36707D445401D7233DC007E604095826E2F69D24540E4857478887D604095826E2F69D24540
4251	Алексеевка	4	36	579	131.96075500000001	132.000191	43.562842000000003	43.554518999999999	0103000020E61000000100000005000000FE0E4581BE7E60405C01857AFAC64540FE0E4581BE7E60405A68E7340BC845401D588E90018060405A68E7340BC845401D588E90018060405C01857AFAC64540FE0E4581BE7E60405C01857AFAC64540
3455	Ширяевка	4	36	410	132.554361	132.58528999999999	43.990059000000002	43.968944999999998	0103000020E61000000100000005000000B1A54753BD916040B54FC76306FC4540B1A54753BD916040240ED940BAFE4540A01518B2BA926040240ED940BAFE4540A01518B2BA926040B54FC76306FC4540B1A54753BD916040B54FC76306FC4540
3502	Тарасовка	4	36	410	132.64852300000001	132.66476399999999	43.999229	43.984883000000004	0103000020E6100000010000000500000086764EB3C094604075B169A510FE454086764EB3C09460407E1B62BCE6FF4540DCF126BF459560407E1B62BCE6FF4540DCF126BF4595604075B169A510FE454086764EB3C094604075B169A510FE4540
2480	Степное	4	36	410	131.84188	131.862865	44.088273000000001	44.072724999999998	0103000020E61000000100000005000000026553AEF07A6040014D840D4F094640026553AEF07A6040560F98874C0B46409E7B0F979C7B6040560F98874C0B46409E7B0F979C7B6040014D840D4F094640026553AEF07A6040014D840D4F094640
2390	Песчаное	4	36	410	132.10296700000001	132.11532800000001	43.910674	43.901127000000002	0103000020E61000000100000005000000273273814B8360407445292158F34540273273814B836040A4A833F790F44540058A58C4B0836040A4A833F790F44540058A58C4B08360407445292158F34540273273814B8360407445292158F34540
2521	Первомайское	4	36	410	131.9691	131.993336	44.009188999999999	43.995117999999998	0103000020E61000000100000005000000B7D100DE027F604099D4D00660FF4540B7D100DE027F6040D13DEB1A2D014640103E9468C97F6040D13DEB1A2D014640103E9468C97F604099D4D00660FF4540B7D100DE027F604099D4D00660FF4540
3419	Отрадное	4	36	410	132.525409	132.53742800000001	43.815702999999999	43.810186999999999	0103000020E61000000100000005000000C5008926D09060407A522635B4E74540C5008926D0906040E21FB6F468E845408D7E349C32916040E21FB6F468E845408D7E349C329160407A522635B4E74540C5008926D09060407A522635B4E74540
3076	Осиновка	4	36	410	132.22599099999999	132.25827699999999	43.981355000000001	43.939293999999997	0103000020E6100000010000000500000017467A513B8760401DAA29C93AF8454017467A513B8760400F62670A9DFD4540E38920CE438860400F62670A9DFD4540E38920CE438860401DAA29C93AF8454017467A513B8760401DAA29C93AF84540
2822	Новошахтинский	4	36	410	132.14984100000001	132.184031	44.034267999999997	44.012462999999997	0103000020E6100000010000000500000033535A7FCB8460407CB438639801464033535A7FCB84604050A6D1E46204464068CEFA94E385604050A6D1E46204464068CEFA94E38560407CB438639801464033535A7FCB8460407CB4386398014640
55250	Новошахтинский	4	36	410	132.14984100000001	132.184031	44.034267999999997	44.012462999999997	0103000020E6100000010000000500000033535A7FCB8460407CB438639801464033535A7FCB84604050A6D1E46204464068CEFA94E385604050A6D1E46204464068CEFA94E38560407CB438639801464033535A7FCB8460407CB4386398014640
2752	Новожатково	4	36	410	131.91612599999999	131.93546699999999	44.242699000000002	44.227088999999999	0103000020E610000001000000050000007D2079E7507D604003249A40111D46407D2079E7507D6040CEE2C5C2101F4640976F7D58EF7D6040CEE2C5C2101F4640976F7D58EF7D604003249A40111D46407D2079E7507D604003249A40111D4640
3319	Николаевка	4	36	410	132.43507399999999	132.45945399999999	43.899535999999998	43.877738999999998	0103000020E61000000100000005000000E02A4F20EC8D60403DB665C059F04540E02A4F20EC8D60408EC9E2FE23F345408600E0D8B38E60408EC9E2FE23F345408600E0D8B38E60403DB665C059F04540E02A4F20EC8D60403DB665C059F04540
2435	Некруглово	4	36	410	132.058482	132.071157	43.985610000000001	43.975737000000002	0103000020E61000000100000005000000F3ACA415DF816040A33F34F3E4FC4540F3ACA415DF816040274EEE7728FE4540357C0BEB46826040274EEE7728FE4540357C0BEB46826040A33F34F3E4FC4540F3ACA415DF816040A33F34F3E4FC4540
2182	Михайловка	4	36	410	131.985063	132.03508099999999	43.954085999999997	43.911771999999999	0103000020E61000000100000005000000FD2FD7A2857F60404AB4E4F1B4F44540FD2FD7A2857F604025C9737D1FFA4540C07630621F81604025C9737D1FFA4540C07630621F8160404AB4E4F1B4F44540FD2FD7A2857F60404AB4E4F1B4F44540
2965	Ляличи	4	36	410	132.35391999999999	132.39866499999999	44.089016999999998	44.060203999999999	0103000020E61000000100000005000000CF2C0950538B6040508BC1C3B4074640CF2C0950538B6040DEE4B7E8640B4640EA211ADDC18C6040DEE4B7E8640B4640EA211ADDC18C6040508BC1C3B4074640CF2C0950538B6040508BC1C3B4074640
3547	Лубянка	4	36	410	132.618133	132.62944200000001	43.96696	43.953443	0103000020E610000001000000050000008272DBBEC7936040D1CC936B0AFA45408272DBBEC793604024456458C5FB454053978C632494604024456458C5FB454053978C6324946040D1CC936B0AFA45408272DBBEC7936040D1CC936B0AFA4540
2964	Кремово	4	36	410	132.22073599999999	132.296446	44.062905000000001	44.007516000000003	0103000020E6100000010000000500000098A1F144108760402F19C748F600464098A1F14410876040A0E062450D084640F660527C7C896040A0E062450D084640F660527C7C8960402F19C748F600464098A1F144108760402F19C748F6004640
3312	Ивановка	4	36	410	132.45491799999999	132.50448700000001	43.983722	43.950581	0103000020E61000000100000005000000938B31B08E8E6040789961A3ACF94540938B31B08E8E6040882D3D9AEAFD45403BC8EBC124906040882D3D9AEAFD45403BC8EBC124906040789961A3ACF94540938B31B08E8E6040789961A3ACF94540
2610	Дубки	4	36	410	131.94710000000001	131.96383599999999	44.064933000000003	44.052112999999999	0103000020E6100000010000000500000055C1A8A44E7E6040255987A3AB06464055C1A8A44E7E604031B77BB94F084640A35698BED77E604031B77BB94F084640A35698BED77E6040255987A3AB06464055C1A8A44E7E6040255987A3AB064640
3115	Даниловка	4	36	410	132.25987599999999	132.29843099999999	43.913648999999999	43.890610000000002	0103000020E610000001000000050000007D2079E750886040CBBE2B82FFF145407D2079E750886040F5824F73F2F445409A232BBF8C896040F5824F73F2F445409A232BBF8C896040CBBE2B82FFF145407D2079E750886040CBBE2B82FFF14540
2714	Григорьевка	4	36	410	131.98543100000001	132.01611800000001	44.168801999999999	44.149628	0103000020E61000000100000005000000DEAE97A6887F60406F48A30227134640DEAE97A6887F6040ECBFCE4D9B154640105CE50984806040ECBFCE4D9B154640105CE509848060406F48A30227134640DEAE97A6887F60406F48A30227134640
55314	Горное	4	36	410	132.33367200000001	132.34609599999999	43.989753999999998	43.982911999999999	0103000020E61000000100000005000000E9F2E670AD8A6040486C770FD0FD4540E9F2E670AD8A6040E78A5242B0FE4540D828EB37138B6040E78A5242B0FE4540D828EB37138B6040486C770FD0FD4540E9F2E670AD8A6040486C770FD0FD4540
3216	Горбатка	4	36	410	132.37046699999999	132.40362400000001	43.957479999999997	43.946019	0103000020E61000000100000005000000E9279CDDDA8B604083328D2617F94540E9279CDDDA8B60407B4963B48EFA45402FFCE07CEA8C60407B4963B48EFA45402FFCE07CEA8C604083328D2617F94540E9279CDDDA8B604083328D2617F94540
2628	Абрамовка	4	36	410	132.01061100000001	132.047235	44.094940999999999	44.085385000000002	0103000020E610000001000000050000004B3FE1EC56806040D4484BE5ED0A46404B3FE1EC568060405706D506270C46404087F9F2828160405706D506270C46404087F9F282816040D4484BE5ED0A46404B3FE1EC56806040D4484BE5ED0A4640
1557	Филаретовка	4	36	147	133.501383	133.52644599999999	45.57197	45.543281999999998	0103000020E61000000100000005000000A7785C540BB06040B340BB438AC54640A7785C540BB0604085251E5036C94640852348A5D8B0604085251E5036C94640852348A5D8B06040B340BB438AC54640A7785C540BB06040B340BB438AC54640
1322	Урожайное	4	36	147	133.45661100000001	133.46590900000001	45.503898	45.498565999999997	0103000020E61000000100000005000000CEFFAB8E9CAE6040E272BC02D1BF4640CEFFAB8E9CAE60408942CBBA7FC0464030BDFDB9E8AE60408942CBBA7FC0464030BDFDB9E8AE6040E272BC02D1BF4640CEFFAB8E9CAE6040E272BC02D1BF4640
1378	Тургенево	4	36	147	133.64294000000001	133.65282999999999	45.473582	45.456204999999997	0103000020E610000001000000050000004A29E8F692B46040C6A2E9EC64BA46404A29E8F692B46040B5FCC0559EBC4640207BBDFBE3B46040B5FCC0559EBC4640207BBDFBE3B46040C6A2E9EC64BA46404A29E8F692B46040C6A2E9EC64BA4640
1829	Тихменево	4	36	147	133.45804799999999	133.48271600000001	45.289000000000001	45.255997999999998	0103000020E61000000100000005000000F17F4754A8AE6040B3EBDE8AC4A04640F17F4754A8AE6040A245B6F3FDA446403128D36872AF6040A245B6F3FDA446403128D36872AF6040B3EBDE8AC4A04640F17F4754A8AE6040B3EBDE8AC4A04640
1102	Тамга	4	36	147	133.60247100000001	133.63164800000001	45.579073999999999	45.571548	0103000020E610000001000000050000003B39437147B360400F0C207C28C946403B39437147B3604061FBC9181FCA4640AFD2DD7536B4604061FBC9181FCA4640AFD2DD7536B460400F0C207C28C946403B39437147B360400F0C207C28C94640
1450	Ружино	4	36	147	133.56564900000001	133.59104400000001	45.527605999999999	45.512627000000002	0103000020E610000001000000050000007C80EECB19B26040F705F4C29DC146407C80EECB19B260403196E99788C34640E84F1BD5E9B260403196E99788C34640E84F1BD5E9B26040F705F4C29DC146407C80EECB19B26040F705F4C29DC14640
1912	Полевое	4	36	147	133.37472099999999	133.395274	45.438557000000003	45.425319000000002	0103000020E61000000100000005000000FB03E5B6FDAB604008AF5DDA70B64640FB03E5B6FDAB60404837C2A222B84640B1DEA815A6AC60404837C2A222B84640B1DEA815A6AC604008AF5DDA70B64640FB03E5B6FDAB604008AF5DDA70B64640
1224	Пантелеймоновка	4	36	147	133.57925800000001	133.60593800000001	45.646790000000003	45.630746000000002	0103000020E6100000010000000500000049BE124889B260409A0AF148BCD0464049BE124889B260409FB0C403CAD24640EBAC16D863B360409FB0C403CAD24640EBAC16D863B360409A0AF148BCD0464049BE124889B260409A0AF148BCD04640
1280	Невское	4	36	147	133.66037600000001	133.68158500000001	45.728234999999998	45.707985999999998	0103000020E610000001000000050000000762D9CC21B560404F0306499FDA46400762D9CC21B56040BA66F2CD36DD4640378E588BCFB56040BA66F2CD36DD4640378E588BCFB560404F0306499FDA46400762D9CC21B560404F0306499FDA4640
2040	Марково	4	36	147	133.33570700000001	133.36224300000001	45.556454000000002	45.540301999999997	0103000020E610000001000000050000003A419B1CBEAA604050FBAD9D28C546403A419B1CBEAA60403CDD79E239C746408FC6A17E97AB60403CDD79E239C746408FC6A17E97AB604050FBAD9D28C546403A419B1CBEAA604050FBAD9D28C54640
1779	Лесное	4	36	147	133.54212200000001	133.558166	45.473258999999999	45.463436999999999	0103000020E61000000100000005000000268E3C1059B16040D06053E751BB4640268E3C1059B16040D2C43BC093BC4640A777F17EDCB16040D2C43BC093BC4640A777F17EDCB16040D06053E751BB4640268E3C1059B16040D06053E751BB4640
1611	Курское	4	36	147	133.48218600000001	133.509863	45.415303999999999	45.392902999999997	0103000020E61000000100000005000000DA9255116EAF604009C03FA54AB24640DA9255116EAF6040F1F274AE28B5464018CE35CC50B06040F1F274AE28B5464018CE35CC50B0604009C03FA54AB24640DA9255116EAF604009C03FA54AB24640
1718	Иннокентьевка	4	36	147	133.58682200000001	133.609576	45.264665000000001	45.245237000000003	0103000020E610000001000000050000005952EE3EC7B2604074620FED639F46405952EE3EC7B26040ABB2EF8AE0A14640A60D87A581B36040ABB2EF8AE0A14640A60D87A581B3604074620FED639F46405952EE3EC7B2604074620FED639F4640
1121	Ильмовка	4	36	147	133.763071	133.781181	45.651224999999997	45.639695000000003	0103000020E61000000100000005000000D5B0DF136BB8604016359886E1D14640D5B0DF136BB8604036AB3E575BD3464036E84B6FFFB8604036AB3E575BD3464036E84B6FFFB8604016359886E1D14640D5B0DF136BB8604016359886E1D14640
1497	Елизаветовка	4	36	147	133.70403400000001	133.72144399999999	45.560158000000001	45.551437	0103000020E61000000100000005000000B5A84F7287B66040F566D47C95C64640B5A84F7287B66040E04BE141B3C74640A73CBA1116B76040E04BE141B3C74640A73CBA1116B76040F566D47C95C64640B5A84F7287B66040F566D47C95C64640
1919	Донское	4	36	147	133.35230799999999	133.36322200000001	45.398890000000002	45.395308	0103000020E61000000100000005000000D0436D1B46AB604070ECD97399B24640D0436D1B46AB6040C959D8D30EB346400266BE839FAB6040C959D8D30EB346400266BE839FAB604070ECD97399B24640D0436D1B46AB604070ECD97399B24640
1663	Глазовка	4	36	147	133.501608	133.521353	45.313104000000003	45.300533000000001	0103000020E610000001000000050000002F6D382C0DB06040342F87DD77A646402F6D382C0DB06040971FB8CA13A846407D957CECAEB06040971FB8CA13A846407D957CECAEB06040342F87DD77A646402F6D382C0DB06040342F87DD77A64640
31679	Чистоводное	4	36	651	133.550737	133.56033099999999	43.063094999999997	43.040551000000001	0103000020E610000001000000050000004F7633A39FB16040F96871C6308545404F7633A39FB1604043C5387F13884540EBFD463BEEB1604043C5387F13884540EBFD463BEEB16040F96871C6308545404F7633A39FB16040F96871C630854540
32105	Черноручье	4	36	651	134.27001799999999	134.28450799999999	43.230837999999999	43.216194999999999	0103000020E610000001000000050000009AEAC9FCA3C8604084471B47AC9B45409AEAC9FCA3C8604047567E198C9D4540696E85B01AC9604047567E198C9D4540696E85B01AC9604084471B47AC9B45409AEAC9FCA3C8604084471B47AC9B4540
31986	Старая Каменка	4	36	651	134.04564500000001	134.06553400000001	43.360073999999997	43.353865999999996	0103000020E610000001000000050000003BC780EC75C160404A95287B4BAD45403BC780EC75C16040E811A3E716AE4540D658C2DA18C26040E811A3E716AE4540D658C2DA18C260404A95287B4BAD45403BC780EC75C160404A95287B4BAD4540
32061	Сокольчи	4	36	651	134.214708	134.24688599999999	43.299498999999997	43.289603999999997	0103000020E6100000010000000500000011C64FE3DEC6604038656EBE11A5454011C64FE3DEC66040A417B5FB55A64540E3FA777DE6C76040A417B5FB55A64540E3FA777DE6C7604038656EBE11A5454011C64FE3DEC6604038656EBE11A54540
55331	Преображение	4	36	651	133.891063	133.924858	42.907516000000001	42.893687	0103000020E610000001000000050000009F758D9683BC604020EEEA55647245409F758D9683BC6040624CFA7B2974454035EECD6F98BD6040624CFA7B2974454035EECD6F98BD604020EEEA55647245409F758D9683BC604020EEEA5564724540
4416	Преображение	4	36	651	133.891063	133.924858	42.907516000000001	42.893687	0103000020E610000001000000050000009F758D9683BC604020EEEA55647245409F758D9683BC6040624CFA7B2974454035EECD6F98BD6040624CFA7B2974454035EECD6F98BD604020EEEA55647245409F758D9683BC604020EEEA5564724540
55298	Лазо	4	36	651	133.89232100000001	133.92265699999999	43.400337999999998	43.364386000000003	0103000020E610000001000000050000001711C5E48DBC6040658F5033A4AE45401711C5E48DBC60404BAC8C463EB345409D0DF96786BD60404BAC8C463EB345409D0DF96786BD6040658F5033A4AE45401711C5E48DBC6040658F5033A4AE4540
31759	Кишиневка	4	36	651	133.851448	133.863045	43.270276000000003	43.262779000000002	0103000020E61000000100000005000000D447E00F3FBB6040AD8905BEA2A14540D447E00F3FBB604065726A6798A245403E3F8C109EBB604065726A6798A245403E3F8C109EBB6040AD8905BEA2A14540D447E00F3FBB6040AD8905BEA2A14540
31659	Киевка	4	36	651	133.68790899999999	133.72037499999999	42.914278000000003	42.900660999999999	0103000020E61000000100000005000000F833BC5903B660402EE411DC48734540F833BC5903B66040E5B9BE0F07754540643BDF4F0DB76040E5B9BE0F07754540643BDF4F0DB760402EE411DC48734540F833BC5903B660402EE411DC48734540
32137	Данильченково	4	36	651	134.379154	134.38993400000001	43.231140000000003	43.21837	0103000020E61000000100000005000000B9C4910722CC6040B936548CF39B4540B9C4910722CC60401366DAFE959D45402733DE567ACC60401366DAFE959D45402733DE567ACC6040B936548CF39B4540B9C4910722CC6040B936548CF39B4540
32217	Глазковка	4	36	651	134.16399000000001	134.183986	43.075543000000003	43.066237000000001	0103000020E61000000100000005000000E0DBF4673FC5604080643A747A884540E0DBF4673FC560408B389D64AB894540809D9B36E3C560408B389D64AB894540809D9B36E3C5604080643A747A884540E0DBF4673FC5604080643A747A884540
32185	Валентин	4	36	651	134.282792	134.314278	43.13015	43.106177000000002	0103000020E6100000010000000500000041F2CEA10CC96040304B3B35978D454041F2CEA10CC9604086C954C1A8904540467BBC900ECA604086C954C1A8904540467BBC900ECA6040304B3B35978D454041F2CEA10CC96040304B3B35978D4540
31744	Беневское	4	36	651	133.74741399999999	133.76869500000001	43.177872000000001	43.157178999999999	0103000020E6100000010000000500000052D2C3D0EAB760401A4F04711E94454052D2C3D0EAB76040E36F7B82C496454029B3412699B86040E36F7B82C496454029B3412699B860401A4F04711E94454052D2C3D0EAB760401A4F04711E944540
31351	Восток	4	36	646	135.817339	135.83264600000001	46.460298999999999	46.439784000000003	0103000020E61000000100000005000000DA571EA427FA6040ECA694D74A384740DA571EA427FA6040D5B0DF13EB3A4740A6643909A5FA6040D5B0DF13EB3A4740A6643909A5FA6040ECA694D74A384740DA571EA427FA6040ECA694D74A384740
29679	Шмаковка	4	36	517	133.36456100000001	133.37768500000001	45.124738999999998	45.110981000000002	0103000020E61000000100000005000000B58CD47BAAAB60401BBD1AA0348E4640B58CD47BAAAB604093C49272F78F46401366DAFE15AC604093C49272F78F46401366DAFE15AC60401BBD1AA0348E4640B58CD47BAAAB60401BBD1AA0348E4640
30170	Хвищанка	4	36	517	133.94610299999999	133.979026	45.047131999999998	45.037272999999999	0103000020E61000000100000005000000B874CC7946BE60400C03965CC5844640B874CC7946BE60402B4CDF6B08864640E17D552E54BF60402B4CDF6B08864640E17D552E54BF60400C03965CC5844640B874CC7946BE60400C03965CC5844640
30345	Уссурка	4	36	517	133.50175200000001	133.52386799999999	45.203693999999999	45.188971000000002	0103000020E610000001000000050000007CD6355A0EB060403B72A433309846407CD6355A0EB060401A321EA5129A464078EDD286C3B060401A321EA5129A464078EDD286C3B060403B72A433309846407CD6355A0EB060403B72A43330984640
29270	Увальное	4	36	517	133.463313	133.49169000000001	45.054715999999999	45.037329999999997	0103000020E61000000100000005000000F9D9C875D3AE60407094BC3AC7844640F9D9C875D3AE6040B24813EF00874640A6B8AAECBBAF6040B24813EF00874640A6B8AAECBBAF60407094BC3AC7844640F9D9C875D3AE60407094BC3AC7844640
29177	Степановка	4	36	517	133.48063200000001	133.49536499999999	44.960847999999999	44.946176999999999	0103000020E61000000100000005000000282D5C5661AF60401B9DF3531C794640282D5C5661AF6040A8363811FD7A4640A852B307DAAF6040A8363811FD7A4640A852B307DAAF60401B9DF3531C794640282D5C5661AF60401B9DF3531C794640
29078	Руновка	4	36	517	133.32907700000001	133.36047300000001	44.972625999999998	44.95711	0103000020E61000000100000005000000B51B7DCC87AA604058569A94827A4640B51B7DCC87AA6040A19E3E027F7C4640EA42ACFE88AB6040A19E3E027F7C4640EA42ACFE88AB604058569A94827A4640B51B7DCC87AA604058569A94827A4640
55308	Родниковый	4	36	517	133.385096	133.40132	45.181728999999997	45.160404	0103000020E6100000010000000500000041BAD8B452AC6040E412471E8894464041BAD8B452AC60400DDE57E54297464062670A9DD7AC60400DDE57E54297464062670A9DD7AC6040E412471E8894464041BAD8B452AC6040E412471E88944640
29860	Преображенка	4	36	517	133.62092200000001	133.63675000000001	45.082833000000001	45.06841	0103000020E61000000100000005000000BE6BD097DEB36040145CACA8C1884640BE6BD097DEB36040C90391459A8A46404C37894160B46040C90391459A8A46404C37894160B46040145CACA8C1884640BE6BD097DEB36040145CACA8C1884640
29831	Павло-Федоровка	4	36	517	133.25166999999999	133.27661599999999	45.138886999999997	45.120998999999998	0103000020E610000001000000050000004C6C3EAE0DA86040A2EC2DE57C8F46404C6C3EAE0DA86040766B990CC79146409C31CC09DAA86040766B990CC79146409C31CC09DAA86040A2EC2DE57C8F46404C6C3EAE0DA86040A2EC2DE57C8F4640
29996	Межгорье	4	36	517	133.63504399999999	133.648967	44.937640000000002	44.925414000000004	0103000020E61000000100000005000000AC70CB4752B460405AA148F773764640AC70CB4752B46040F2B5679604784640DD257156C4B46040F2B5679604784640DD257156C4B460405AA148F773764640AC70CB4752B460405AA148F773764640
30253	Марьяновка	4	36	517	133.71721199999999	133.74683899999999	44.801006000000001	44.785359999999997	0103000020E610000001000000050000008F899466F3B6604014CB2DAD866446408F899466F3B660402CF3565D87664640130CE71AE6B760402CF3565D87664640130CE71AE6B7604014CB2DAD866446408F899466F3B6604014CB2DAD86644640
29331	Луговое	4	36	517	133.431342	133.441834	45.113405	45.107387000000003	0103000020E6100000010000000500000085ECBC8DCDAD6040FE8172DBBE8D464085ECBC8DCDAD6040F819170E848E464059880E8123AE6040F819170E848E464059880E8123AE6040FE8172DBBE8D464085ECBC8DCDAD6040FE8172DBBE8D4640
29005	Комаровка	4	36	517	133.28282300000001	133.30193	45.015416000000002	44.988641999999999	0103000020E61000000100000005000000D0F1D1E20CA96040DCB930D28B7E4640D0F1D1E20CA96040E6EAC726F9814640CD751A69A9A96040E6EAC726F9814640CD751A69A9A96040DCB930D28B7E4640D0F1D1E20CA96040DCB930D28B7E4640
3421	Кировский	4	36	517	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
55293	Кировский	4	36	517	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
55312	Горный	4	36	517	133.940471	133.96450999999999	44.850569999999998	44.836772000000003	0103000020E61000000100000005000000C47AA35618BE6040B11A4B581B6B4640C47AA35618BE6040B77A4E7ADF6C464047551344DDBE6040B77A4E7ADF6C464047551344DDBE6040B11A4B581B6B4640C47AA35618BE6040B11A4B581B6B4640
3635	Горные Ключи	4	36	517	133.4879	133.51319599999999	45.249907	45.216088999999997	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
55302	Горные Ключи	4	36	517	133.4879	133.51319599999999	45.249907	45.216088999999997	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
30182	Владимировка	4	36	517	133.670635	133.67946499999999	44.863126000000001	44.852302000000002	0103000020E61000000100000005000000B21188D775B560405F28603B186D4640B21188D775B56040E529ABE97A6E4640DA38622DBEB56040E529ABE97A6E4640DA38622DBEB560405F28603B186D4640B21188D775B560405F28603B186D4640
30102	Большие Ключи	4	36	517	133.84914800000001	133.861581	44.933371999999999	44.911710999999997	0103000020E61000000100000005000000D82E6D382CBB6040A43330F2B2744640D82E6D382CBB60404580D3BB787746405C3B511292BB60404580D3BB787746405C3B511292BB6040A43330F2B2744640D82E6D382CBB6040A43330F2B2744640
29144	Афанасьевка	4	36	517	133.39433099999999	133.409198	44.934277999999999	44.918163999999997	0103000020E6100000010000000500000091990B5C9EAC6040A92EE0658675464091990B5C9EAC6040A7AFE76B96774640D672672618AD6040A7AFE76B96774640D672672618AD6040A92EE0658675464091990B5C9EAC6040A92EE06586754640
29952	Архангеловка	4	36	517	133.544781	133.56468699999999	45.065418000000001	45.045355000000001	0103000020E610000001000000050000006E4F90D86EB16040E4DA5031CE8546406E4F90D86EB16040ED48F59D5F8846403EAF78EA11B26040ED48F59D5F8846403EAF78EA11B26040E4DA5031CE8546406E4F90D86EB16040E4DA5031CE854640
29071	Антоновка	4	36	517	133.319807	133.34727699999999	44.917876999999997	44.900531999999998	0103000020E6100000010000000500000005C1E3DB3BAA60403080F0A14473464005C1E3DB3BAA6040136058FE7C754640E5B4A7E41CAB6040136058FE7C754640E5B4A7E41CAB60403080F0A14473464005C1E3DB3BAA60403080F0A144734640
29781	Авдеевка	4	36	517	133.30112199999999	133.32475600000001	45.140095000000002	45.11759	0103000020E6100000010000000500000065C39ACAA2A96040172B6A300D8F464065C39ACAA2A96040A4AA09A2EE914640C1E5B16664AA6040A4AA09A2EE914640C1E5B16664AA6040172B6A300D8F464065C39ACAA2A96040172B6A300D8F4640
28681	Хрустальный	4	36	1829	135.08054999999999	135.109511	44.364705999999998	44.334029999999998	0103000020E610000001000000050000002BF697DD93E2604002F1BA7EC12A46402BF697DD93E26040D653ABAFAE2E4640AC71361D81E36040D653ABAFAE2E4640AC71361D81E3604002F1BA7EC12A46402BF697DD93E2604002F1BA7EC12A4640
28015	Устиновка	4	36	1829	135.218962	135.23719800000001	44.256517000000002	44.247781000000003	0103000020E6100000010000000500000023A298BC01E76040FCC8AD49B71F464023A298BC01E760401CEF8E8CD5204640A795422097E760401CEF8E8CD5204640A795422097E76040FCC8AD49B71F464023A298BC01E76040FCC8AD49B71F4640
27970	Суворово	4	36	1829	135.345732	135.348814	44.255212999999998	44.243138000000002	0103000020E61000000100000005000000C8258E3C10EB60401A355F251F1F4640C8258E3C10EB6040CC41D0D1AA204640624CFA7B29EB6040CC41D0D1AA204640624CFA7B29EB60401A355F251F1F4640C8258E3C10EB60401A355F251F1F4640
28062	Синегорье	4	36	1829	135.11264600000001	135.13234600000001	44.241311000000003	44.230079000000003	0103000020E61000000100000005000000CFC0C8CB9AE360408A3F8A3A731D4640CFC0C8CB9AE3604021956247E31E464035B8AD2D3CE4604021956247E31E464035B8AD2D3CE460408A3F8A3A731D4640CFC0C8CB9AE360408A3F8A3A731D4640
28837	Рудный	4	36	1829	134.936172	134.98049499999999	44.348689999999998	44.271416000000002	0103000020E61000000100000005000000CA6DFB1EF5DD60403ACE6DC2BD224640CA6DFB1EF5DD60409B38B9DFA12C464087DC0C3760DF60409B38B9DFA12C464087DC0C3760DF60403ACE6DC2BD224640CA6DFB1EF5DD60403ACE6DC2BD224640
55249	Кавалерово	4	36	1829	135.027738	135.086658	44.344293999999998	44.247897000000002	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
55277	Кавалерово	4	36	1829	135.027738	135.086658	44.344293999999998	44.247897000000002	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
28261	Кавалерово	4	36	1829	135.027738	135.086658	44.344293999999998	44.247897000000002	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
27885	Зеркальное	4	36	1829	135.54452900000001	135.561049	44.222346999999999	44.211984999999999	0103000020E6100000010000000500000028D714C86CF160400C1F1153221B464028D714C86CF160408EAED2DD751C4640834E081DF4F160408EAED2DD751C4640834E081DF4F160400C1F1153221B464028D714C86CF160400C1F1153221B4640
55257	Горнореченский	4	36	1829	135.08529300000001	135.126364	44.287517999999999	44.243377000000002	0103000020E610000001000000050000007DB262B8BAE260409FCC3FFA261F46407DB262B8BAE260407381CB63CD24464089EC832C0BE460407381CB63CD24464089EC832C0BE460409FCC3FFA261F46407DB262B8BAE260409FCC3FFA261F4640
28066	Высокогорск	4	36	1829	135.38435100000001	135.41299799999999	44.411388000000002	44.402689000000002	0103000020E61000000100000005000000EBE5779A4CEC6040BFBA2A508B334640EBE5779A4CEC6040C2FBAA5CA834464007EA944737ED6040C2FBAA5CA834464007EA944737ED6040BFBA2A508B334640EBE5779A4CEC6040BFBA2A508B334640
27919	Богополь	4	36	1829	135.442553	135.46831599999999	44.257589000000003	44.240555000000001	0103000020E61000000100000005000000E5B7E86429EE6040D4F19881CA1E4640E5B7E86429EE6040996725ADF82046403106D671FCEE6040996725ADF82046403106D671FCEE6040D4F19881CA1E4640E5B7E86429EE6040D4F19881CA1E4640
32238	Ясная Поляна	4	36	71	134.306579	134.321563	45.583236999999997	45.571250999999997	0103000020E610000001000000050000007E54C37ECFC960405567B5C01EC946407E54C37ECFC9604098689082A7CA464051137D3E4ACA604098689082A7CA464051137D3E4ACA60405567B5C01EC946407E54C37ECFC960405567B5C01EC94640
31896	Стретенка	4	36	71	134.04037199999999	134.06163599999999	45.836787000000001	45.825622000000003	0103000020E61000000100000005000000927538BA4AC16040D76D50FBADE94640927538BA4AC16040E65B1FD61BEB464033880FECF8C16040E65B1FD61BEB464033880FECF8C16040D76D50FBADE94640927538BA4AC16040D76D50FBADE94640
31878	Соловьевка	4	36	71	133.951987	133.969235	45.890535	45.876902999999999	0103000020E61000000100000005000000F3E670AD76BE6040D461855B3EF04640F3E670AD76BE6040C078060DFDF146406F641EF903BF6040C078060DFDF146406F641EF903BF6040D461855B3EF04640F3E670AD76BE6040D461855B3EF04640
32045	Сальское	4	36	71	133.74727899999999	133.77301600000001	45.979219999999998	45.965271000000001	0103000020E610000001000000050000009A3FA6B5E9B760407C6308008EFB46409A3FA6B5E9B7604068CBB91457FD46401DE90C8CBCB8604068CBB91457FD46401DE90C8CBCB860407C6308008EFB46409A3FA6B5E9B760407C6308008EFB4640
32421	Пожига	4	36	71	134.376441	134.39032900000001	45.124859000000001	45.108258999999997	0103000020E61000000100000005000000F4FBFECD0BCC6040B33F506EDB8D4640F4FBFECD0BCC60403ECE3461FB8F4640C6353E937DCC60403ECE3461FB8F4640C6353E937DCC6040B33F506EDB8D4640F4FBFECD0BCC6040B33F506EDB8D4640
31973	Новотроицкое	4	36	71	134.100739	134.11962199999999	45.799363999999997	45.780762000000003	0103000020E61000000100000005000000D1CDFE4039C36040D3FA5B02F0E34640D1CDFE4039C36040C4CC3E8F51E646403A3C84F1D3C36040C4CC3E8F51E646403A3C84F1D3C36040D3FA5B02F0E34640D1CDFE4039C36040D3FA5B02F0E34640
32020	Междуречье	4	36	71	134.09283400000001	134.12106800000001	45.713492000000002	45.690852	0103000020E610000001000000050000009F3E027FF8C2604027309DD66DD846409F3E027FF8C2604094FAB2B453DB4640F392FFC9DFC3604094FAB2B453DB4640F392FFC9DFC3604027309DD66DD846409F3E027FF8C2604027309DD66DD84640
32245	Малиново	4	36	71	134.28841499999999	134.31602899999999	45.414571000000002	45.396802000000001	0103000020E61000000100000005000000A01518B23AC96040637E6E68CAB24640A01518B23AC960405D6F9BA910B54640CD72D9E81CCA60405D6F9BA910B54640CD72D9E81CCA6040637E6E68CAB24640A01518B23AC96040637E6E68CAB24640
31176	Лобановка	4	36	71	134.239125	134.25969599999999	45.678063999999999	45.673020000000001	0103000020E61000000100000005000000FED478E9A6C76040E7C6F48425D64640FED478E9A6C76040274C18CDCAD64640DD5CFC6D4FC86040274C18CDCAD64640DD5CFC6D4FC86040E7C6F48425D64640FED478E9A6C76040E7C6F48425D64640
27782	Лазо	4	36	71	133.62723700000001	133.69152099999999	45.887129000000002	45.853926999999999	0103000020E61000000100000005000000EB3A545312B46040F015DD7A4DED4640EB3A545312B46040A62A6D718DF14640E9EFA5F020B66040A62A6D718DF14640E9EFA5F020B66040F015DD7A4DED4640EB3A545312B46040F015DD7A4DED4640
32324	Зимники	4	36	71	134.24740700000001	134.26413400000001	45.480589999999999	45.466723999999999	0103000020E61000000100000005000000A6B915C2EAC760401021AE9CBDBB4640A6B915C2EAC760406F641EF983BD4640607825C973C860406F641EF983BD4640607825C973C860401021AE9CBDBB4640A6B915C2EAC760401021AE9CBDBB4640
1239	Грушевое	4	36	71	133.60812100000001	133.61992499999999	45.824396999999998	45.817450999999998	0103000020E6100000010000000500000059E02BBA75B360408F8AFF3BA2E8464059E02BBA75B36040D3F544D785E94640211FF46CD6B36040D3F544D785E94640211FF46CD6B360408F8AFF3BA2E8464059E02BBA75B360408F8AFF3BA2E84640
31824	Веденка	4	36	71	133.88699399999999	133.92910699999999	45.884186999999997	45.868268	0103000020E61000000100000005000000F1B73D4162BC6040E814E46723EF4640F1B73D4162BC60403046240A2DF14640826F9A3EBBBD60403046240A2DF14640826F9A3EBBBD6040E814E46723EF4640F1B73D4162BC6040E814E46723EF4640
26692	Сержантово	4	36	701	135.73957200000001	135.75741199999999	44.454520000000002	44.434545	0103000020E610000001000000050000003221E692AAF76040F6D1A92B9F3746403221E692AAF7604060B01BB62D3A4640223317B83CF8604060B01BB62D3A4640223317B83CF86040F6D1A92B9F3746403221E692AAF76040F6D1A92B9F374640
55283	Рудная Пристань	4	36	701	135.79778300000001	135.84286	44.384614999999997	44.344718999999998	0103000020E61000000100000005000000C1C9367087F96040A8A78FC01F2C4640C1C9367087F96040884677103B31464069E388B5F8FA6040884677103B31464069E388B5F8FA6040A8A78FC01F2C4640C1C9367087F96040A8A78FC01F2C4640
55262	Подъяпольское	4	36	701	135.41949299999999	135.50874099999999	44.620241999999998	44.545102	0103000020E61000000100000005000000D47C957C6CED6040FA7DFFE6C5454640D47C957C6CED604085CD0017644F46404CA4349B47F0604085CD0017644F46404CA4349B47F06040FA7DFFE6C5454640D47C957C6CED6040FA7DFFE6C5454640
26738	Мономахово	4	36	701	135.76141000000001	135.78601499999999	44.399963999999997	44.373108999999999	0103000020E610000001000000050000001E1B81785DF86040F06B2409C22F46401E1B81785DF86040E6C93505323346404BE5ED0827F96040E6C93505323346404BE5ED0827F96040F06B2409C22F46401E1B81785DF86040F06B2409C22F4640
25907	Краснореченский	4	36	701	135.31290799999999	135.38204200000001	44.64799	44.611477000000001	0103000020E610000001000000050000000455A35703EA6040CBA0DAE0444E46400455A35703EA604049111956F15246405AF624B039EC604049111956F15246405AF624B039EC6040CBA0DAE0444E46400455A35703EA6040CBA0DAE0444E4640
15709	Ясное	4	36	125	132.15443099999999	132.169254	43.459947	43.447080999999997	0103000020E61000000100000005000000A2CF4719F1846040DCD440F339B94540A2CF4719F18460405872158BDFBA4540F3565D876A8560405872158BDFBA4540F3565D876A856040DCD440F339B94540A2CF4719F1846040DCD440F339B94540
259	Штыково	4	36	125	132.35720800000001	132.38187600000001	43.395299999999999	43.381909	0103000020E61000000100000005000000D4BB783F6E8B60402786E464E2B04540D4BB783F6E8B6040ED0DBE3099B2454013640454388C6040ED0DBE3099B2454013640454388C60402786E464E2B04540D4BB783F6E8B60402786E464E2B04540
15214	Суражевка	4	36	125	132.30834899999999	132.33569299999999	43.426459999999999	43.411366999999998	0103000020E6100000010000000500000023D8B8FEDD896040AAD381ACA7B4454023D8B8FEDD896040AD86C43D96B64540E00F3FFFBD8A6040AD86C43D96B64540E00F3FFFBD8A6040AAD381ACA7B4454023D8B8FEDD896040AAD381ACA7B44540
15571	Кневичи	4	36	125	132.180509	132.22131099999999	43.417706000000003	43.377853000000002	0103000020E610000001000000050000004774CFBAC685604006D9B27C5DB045404774CFBAC6856040E7ABE46377B54540D767CEFA14876040E7ABE46377B54540D767CEFA1487604006D9B27C5DB045404774CFBAC685604006D9B27C5DB04540
12199	Чернышевка	4	36	1169	133.097375	133.16551200000001	44.212992	44.178699999999999	0103000020E61000000100000005000000560E2DB21DA36040C9E53FA4DF164640560E2DB21DA36040A2276552431B46400F63D2DF4BA56040A2276552431B46400F63D2DF4BA56040C9E53FA4DF164640560E2DB21DA36040C9E53FA4DF164640
12007	Тихоречное	4	36	1169	133.01063400000001	133.04511099999999	44.192177999999998	44.168833999999997	0103000020E6100000010000000500000039471D1D57A06040F7393E5A9C15464039471D1D57A060405E81E8499918464013B69F8C71A160405E81E8499918464013B69F8C71A16040F7393E5A9C15464039471D1D57A06040F7393E5A9C154640
11504	Таежка	4	36	1169	133.211263	133.23873399999999	44.108626000000001	44.093173999999998	0103000020E610000001000000050000005B7B9FAAC2A66040336B2920ED0B46405B7B9FAAC2A6604066BFEE74E70D46402F4E7CB5A3A7604066BFEE74E70D46402F4E7CB5A3A76040336B2920ED0B46405B7B9FAAC2A66040336B2920ED0B4640
11351	Старогордеевка	4	36	1169	133.11608699999999	133.124145	44.008209999999998	43.996026000000001	0103000020E61000000100000005000000B48F15FCB6A360409CFBABC77DFF4540B48F15FCB6A3604005C078060D014640C85EEFFEF8A3604005C078060D014640C85EEFFEF8A360409CFBABC77DFF4540B48F15FCB6A360409CFBABC77DFF4540
11840	Староварваровка	4	36	1169	132.920119	132.937825	43.891195000000003	43.882015000000003	0103000020E61000000100000005000000B4AD669D719D60406DCA15DEE5F04540B4AD669D719D6040EBAD81AD12F24540E10B93A9029E6040EBAD81AD12F24540E10B93A9029E60406DCA15DEE5F04540B4AD669D719D60406DCA15DEE5F04540
11695	Смольное	4	36	1169	132.899135	132.91330099999999	43.854672999999998	43.847060999999997	0103000020E610000001000000050000000C76C3B6C59C6040C85BAE7E6CEC45400C76C3B6C59C604019E3C3EC65ED4540EECC04C3399D604019E3C3EC65ED4540EECC04C3399D6040C85BAE7E6CEC45400C76C3B6C59C6040C85BAE7E6CEC4540
11898	Рисовое	4	36	1169	133.102441	133.12773799999999	44.228400000000001	44.215052999999997	0103000020E61000000100000005000000A018593247A360400EF450DB861B4640A018593247A36040053411363C1D46409B8E006E16A46040053411363C1D46409B8E006E16A460400EF450DB861B4640A018593247A360400EF450DB861B4640
11913	Пухово	4	36	1169	133.24526499999999	133.28149400000001	44.213154000000003	44.183019000000002	0103000020E610000001000000050000004F3BFC35D9A76040F8C5A52A6D1746404F3BFC35D9A760407C8159A1481B4640A680B4FF01A960407C8159A1481B4640A680B4FF01A96040F8C5A52A6D1746404F3BFC35D9A76040F8C5A52A6D174640
12091	Новотроицкое	4	36	1169	133.037556	133.057121	44.161405000000002	44.146355	0103000020E6100000010000000500000098F8A3A833A16040944DB9C2BB12464098F8A3A833A16040983446EBA8144640465D6BEFD3A16040983446EBA8144640465D6BEFD3A16040944DB9C2BB12464098F8A3A833A16040944DB9C2BB124640
11433	Новогордеевка	4	36	1169	133.12924699999999	133.15497500000001	44.040677000000002	44.024428999999998	0103000020E6100000010000000500000065C39ACA22A4604078094E7D2003464065C39ACA22A46040865968E7340546405396218EF5A46040865968E7340546405396218EF5A4604078094E7D2003464065C39ACA22A4604078094E7D20034640
11250	Нововарваровка	4	36	1169	132.97720699999999	132.99014299999999	43.975543000000002	43.968496999999999	0103000020E61000000100000005000000834D9D47459F604016A3AEB5F7FB4540834D9D47459F6040BE6BD097DEFC4540A06B5F40AF9F6040BE6BD097DEFC4540A06B5F40AF9F604016A3AEB5F7FB4540834D9D47459F604016A3AEB5F7FB4540
11615	Муравейка	4	36	1169	133.257769	133.279526	43.890642999999997	43.876134	0103000020E61000000100000005000000861DC6A43FA86040F374AE2825F04540861DC6A43FA86040A6B4FE9600F24540378C82E0F1A86040A6B4FE9600F24540378C82E0F1A86040F374AE2825F04540861DC6A43FA86040F374AE2825F04540
12112	Корниловка	4	36	1169	133.16205400000001	133.177774	44.149614999999997	44.131507999999997	0103000020E61000000100000005000000F4C5DE8B2FA56040C8940F41D5104640F4C5DE8B2FA56040DAFE95952613464088821953B0A56040DAFE95952613464088821953B0A56040C8940F41D5104640F4C5DE8B2FA56040C8940F41D5104640
11791	Ильмаковка	4	36	1169	132.96221399999999	132.966589	43.747430000000001	43.734690000000001	0103000020E610000001000000050000001BB80375CA9E6040605969520ADE45401BB80375CA9E60404F0647C9ABDF45408CF50D4CEE9E60404F0647C9ABDF45408CF50D4CEE9E6040605969520ADE45401BB80375CA9E6040605969520ADE4540
11600	Еловка	4	36	1169	133.22269	133.23441299999999	43.840584999999997	43.830806000000003	0103000020E61000000100000005000000AE64C74620A7604009A9DBD957EA4540AE64C74620A760400B410E4A98EB45403B18B14F80A760400B410E4A98EB45403B18B14F80A7604009A9DBD957EA4540AE64C74620A7604009A9DBD957EA4540
11310	Гродеково	4	36	1169	133.13857200000001	133.154427	43.863928999999999	43.855434000000002	0103000020E6100000010000000500000086048C2E6FA4604078F17EDC7EED454086048C2E6FA460407288B83995EE4540D253E410F1A460407288B83995EE4540D253E410F1A4604078F17EDC7EED454086048C2E6FA4604078F17EDC7EED4540
11972	Гражданка	4	36	1169	133.16420099999999	133.18599399999999	44.231389999999998	44.205768999999997	0103000020E610000001000000050000000E9F742241A56040EBC37AA3561A46400E9F742241A560408B4F01309E1D46401268B0A9F3A560408B4F01309E1D46401268B0A9F3A56040EBC37AA3561A46400E9F742241A56040EBC37AA3561A4640
11737	Виноградовка	4	36	1169	132.942092	132.96127100000001	43.765017	43.757933000000001	0103000020E61000000100000005000000583A1F9E259E604093C7D3F203E14540583A1F9E259E604028F1B913ECE14540FC7266BBC29E604028F1B913ECE14540FC7266BBC29E604093C7D3F203E14540583A1F9E259E604093C7D3F203E14540
11101	Анучино	4	36	1169	133.03010900000001	133.07240200000001	43.972461000000003	43.953885	0103000020E61000000100000005000000174A26A7F6A060408E9257E718FA4540174A26A7F6A0604057D11F9A79FC454048C5FF1D51A2604057D11F9A79FC454048C5FF1D51A260408E9257E718FA4540174A26A7F6A060408E9257E718FA4540
55653	п.Сокол	4	39	\N	150.233071	151.28772900000001	60.175257000000002	59.645619000000003	0103000020E61000000100000005000000AC54505175C762408F56B5A4A3D24D40AC54505175C7624092B245D26E164E408CA3721335E9624092B245D26E164E408CA3721335E962408F56B5A4A3D24D40AC54505175C762408F56B5A4A3D24D40
55652	Сусуман	4	39	\N	147.62070800000001	148.675366	63.017885	62.534747000000003	0103000020E61000000100000005000000B30B06D7DC7362402B51F69672444F40B30B06D7DC736240630B410E4A824F40925A28999C956240630B410E4A824F40925A28999C9562402B51F69672444F40B30B06D7DC7362402B51F69672444F40
55654	Сокол	4	39	\N	150.233071	151.28772900000001	60.175257000000002	59.645619000000003	0103000020E61000000100000005000000AC54505175C762408F56B5A4A3D24D40AC54505175C7624092B245D26E164E408CA3721335E9624092B245D26E164E408CA3721335E962408F56B5A4A3D24D40AC54505175C762408F56B5A4A3D24D40
231	Магадан	4	39	\N	150.28574900000001	151.340407	59.82291	59.287596000000001	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
31995	Ягодное	4	39	1922	149.09912800000001	150.153786	62.769500999999998	62.282251000000002	0103000020E61000000100000005000000C6C37B0E2CA36240B421FFCC20244F40C6C37B0E2CA36240A19E3E027F624F40A5129ED0EBC46240A19E3E027F624F40A5129ED0EBC46240B421FFCC20244F40C6C37B0E2CA36240B421FFCC20244F40
32187	Синегорье	4	39	1922	149.952887	151.00754499999999	62.329037	61.834516999999998	0103000020E6100000010000000500000013B9E00C7EBE62405F7AFB73D1EA4E4013B9E00C7EBE6240441669E21D2A4F40F20703CF3DE06240441669E21D2A4F40F20703CF3DE062405F7AFB73D1EA4E4013B9E00C7EBE62405F7AFB73D1EA4E40
32081	Сенокосный	4	39	1922	149.15223599999999	150.20689400000001	62.789022000000003	62.302095000000001	0103000020E61000000100000005000000C328081EDFA462407FA4880CAB264F40C328081EDFA462408AE942ACFE644F40A3772AE09EC662408AE942ACFE644F40A3772AE09EC662407FA4880CAB264F40C328081EDFA462407FA4880CAB264F40
32214	Оротукан	4	39	1922	151.14549	152.20014800000001	62.498088000000003	62.006354999999999	0103000020E61000000100000005000000A4FCA4DAA7E4624042959A3DD0004F40A4FCA4DAA7E46240D943FB58C13F4F40844BC79C67066340D943FB58C13F4F40844BC79C6706634042959A3DD0004F40A4FCA4DAA7E4624042959A3DD0004F40
32142	Дебин	4	39	1922	150.22042300000001	151.275081	62.587404999999997	62.097147	0103000020E61000000100000005000000290989B40DC76240C7F319506F0C4F40290989B40DC76240E1404816304B4F400858AB76CDE86240E1404816304B4F400858AB76CDE86240C7F319506F0C4F40290989B40DC76240C7F319506F0C4F40
31953	Бурхала	4	39	1922	148.573847	149.62850499999999	62.892856000000002	62.407646999999997	0103000020E610000001000000050000000C3D62F45C92624000A8E2C62D344F400C3D62F45C926240C904FC1A49724F40EB8B84B61CB46240C904FC1A49724F40EB8B84B61CB4624000A8E2C62D344F400C3D62F45C92624000A8E2C62D344F40
31926	Талая	4	39	101	151.86837299999999	152.92303200000001	61.396185000000003	60.886367	0103000020E6100000010000000500000057772CB6C9FB624077A04E7974714E4057772CB6C9FB62403815A930B6B24E402BA5677A891D63403815A930B6B24E402BA5677A891D634077A04E7974714E4057772CB6C9FB624077A04E7974714E40
31617	Стекольный	4	39	101	150.213919	151.26857699999999	60.317723000000001	59.790385000000001	0103000020E61000000100000005000000C79FA86CD8C66240DE1FEF552BE54D40C79FA86CD8C66240F017B325AB284E40A6EECA2E98E86240F017B325AB284E40A6EECA2E98E86240DE1FEF552BE54D40C79FA86CD8C66240DE1FEF552BE54D40
140	Палатка	4	39	101	150.410551	151.46521000000001	60.365841000000003	59.839280000000002	0103000020E61000000100000005000000E2CAD93B23CD6240EC17EC866DEB4D40E2CAD93B23CD62409A44BDE0D32E4E40B6F81400E3EE62409A44BDE0D32E4E40B6F81400E3EE6240EC17EC866DEB4D40E2CAD93B23CD6240EC17EC866DEB4D40
31861	Атка	4	39	101	151.256495	152.31115299999999	61.097658000000003	60.582971999999998	0103000020E61000000100000005000000CD92003535E86240EA3D95D39E4A4E40CD92003535E86240AD18AE0E808C4E40ACE122F7F4096340AD18AE0E808C4E40ACE122F7F4096340EA3D95D39E4A4E40CD92003535E86240EA3D95D39E4A4E40
55655	им.Гастелло	4	39	1914	146.09569200000001	151.218999	62.501299000000003	60.403796	0103000020E61000000100000005000000A54FABE80F436240B8205B96AF334E40A54FABE80F4362403E42CD902A404F406ADB300A02E762403E42CD902A404F406ADB300A02E76240B8205B96AF334E40A54FABE80F436240B8205B96AF334E40
31358	Усть-Омчуг	4	39	1914	149.100853	150.15551099999999	61.373939	60.863757	0103000020E61000000100000005000000831612303AA362407558E1968F6E4E40831612303AA3624077D9AF3BDDAF4E40626534F2F9C4624077D9AF3BDDAF4E40626534F2F9C462407558E1968F6E4E40831612303AA362407558E1968F6E4E40
31467	Транспортный	4	39	1914	147.66072800000001	148.715386	61.749374000000003	61.245331999999998	0103000020E61000000100000005000000A6F10BAF24756240C554FA09679F4E40A6F10BAF24756240823CBB7CEBDF4E4085402E71E4966240823CBB7CEBDF4E4085402E71E4966240C554FA09679F4E40A6F10BAF24756240C554FA09679F4E40
31563	Омчак	4	39	1914	147.34008299999999	148.39474100000001	61.892347999999998	61.390650000000001	0103000020E610000001000000050000009E5DBEF5E16A62405917B7D100B24E409E5DBEF5E16A62405453927538F24E407EACE0B7A18C62405453927538F24E407EACE0B7A18C62405917B7D100B24E409E5DBEF5E16A62405917B7D100B24E40
31268	Мадаун	4	39	1914	150.178921	151.23357899999999	60.870752000000003	60.352375000000002	0103000020E610000001000000050000002A7288B8B9C56240C976BE9F1A2D4E402A7288B8B9C562409B7631CD746F4E4009C1AA7A79E762409B7631CD746F4E4009C1AA7A79E76240C976BE9F1A2D4E402A7288B8B9C56240C976BE9F1A2D4E40
31071	Широкий	4	39	1905	147.51244299999999	148.56710100000001	63.313248000000002	62.835011999999999	0103000020E610000001000000050000000DC2DCEE657062403FE257ACE16A4F400DC2DCEE65706240CAC4AD8218A84F40ED10FFB025926240CAC4AD8218A84F40ED10FFB0259262403FE257ACE16A4F400DC2DCEE657062403FE257ACE16A4F40
31085	Холодный	4	39	1905	147.38267200000001	148.43733	62.957286000000003	62.473143999999998	0103000020E610000001000000050000000AA359D93E6C624039268BFB8F3C4F400AA359D93E6C62409775FF58887A4F40E9F17B9BFE8D62409775FF58887A4F40E9F17B9BFE8D624039268BFB8F3C4F400AA359D93E6C624039268BFB8F3C4F40
30873	Сусуман	4	39	1905	147.62070800000001	148.675366	63.017885	62.534747000000003	0103000020E61000000100000005000000B30B06D7DC7362402B51F69672444F40B30B06D7DC736240630B410E4A824F40925A28999C956240630B410E4A824F40925A28999C9562402B51F69672444F40B30B06D7DC7362402B51F69672444F40
31253	Мяунджа	4	39	1905	146.66383099999999	147.71848900000001	63.283200000000001	62.804464000000003	0103000020E610000001000000050000004562821A3E556240996725ADF8664F404562821A3E556240151DC9E53FA44F4025B1A4DCFD766240151DC9E53FA44F4025B1A4DCFD766240996725ADF8664F404562821A3E556240996725ADF8664F40
31166	Кедровый	4	39	1905	146.53304499999999	147.587703	63.252476000000001	62.773229999999998	0103000020E610000001000000050000007B4963B40E5162409E245D33F9624F407B4963B40E5162403083312251A04F405B988576CE7262403083312251A04F405B988576CE7262409E245D33F9624F407B4963B40E5162409E245D33F9624F40
31156	Большевик	4	39	1905	147.04834600000001	148.103004	62.933005999999999	62.448461999999999	0103000020E610000001000000050000008F1CE90C8C616240D7BFEB3367394F408F1CE90C8C616240637C98BD6C774F406E6B0BCF4B836240637C98BD6C774F406E6B0BCF4B836240D7BFEB3367394F408F1CE90C8C616240D7BFEB3367394F40
30704	Сеймчан	4	39	1900	151.85754	152.91219799999999	63.170126000000003	62.689512999999998	0103000020E6100000010000000500000061E0B9F770FB62405B9544F641584F4061E0B9F770FB6240831953B0C6954F40402FDCB9301D6340831953B0C6954F40402FDCB9301D63405B9544F641584F4061E0B9F770FB62405B9544F641584F40
30776	Верх. Сеймчан	4	39	1900	151.94049000000001	152.995148	62.962153000000001	62.478090999999999	0103000020E61000000100000005000000E2067C7E18FE624087C1FC15323D4F40E2067C7E18FE6240C85F5AD4277B4F40C1559E40D81F6340C85F5AD4277B4F40C1559E40D81F634087C1FC15323D4F40E2067C7E18FE624087C1FC15323D4F40
30480	Эвенск	4	39	1893	158.70060000000001	159.755258	62.169426999999999	61.672280999999998	0103000020E610000001000000050000007CF2B0506BD66340705CC64D0DD64E407CF2B0506BD663409A07B0C8AF154F405B41D3122BF863409A07B0C8AF154F405B41D3122BF86340705CC64D0DD64E407CF2B0506BD66340705CC64D0DD64E40
30626	Чайбуха	4	39	1893	159.879998	160.93465599999999	62.058183	61.559207000000001	0103000020E6100000010000000500000074D190F128FC6340DE58501894C74E4074D190F128FC63407217618A72074F405320B3B3E81D64407217618A72074F405320B3B3E81D6440DE58501894C74E4074D190F128FC6340DE58501894C74E40
30596	Гижига	4	39	1893	159.84321199999999	160.89787000000001	62.200664000000003	61.704031000000001	0103000020E610000001000000050000000873BB97FBFA6340622F14B01DDA4E400873BB97FBFA634006BEA25BAF194F40E8C1DD59BB1C644006BEA25BAF194F40E8C1DD59BB1C6440622F14B01DDA4E400873BB97FBFA6340622F14B01DDA4E40
30555	Гарманда	4	39	1893	158.568341	159.62299899999999	62.422165	61.929180000000002	0103000020E610000001000000050000003BFF76D92FD26340740CC85EEFF64E403BFF76D92FD263400742B28009364F401A4E999BEFF363400742B28009364F401A4E999BEFF36340740CC85EEFF64E403BFF76D92FD26340740CC85EEFF64E40
30327	Омсукчан	4	39	1891	155.23810700000001	156.292765	62.759310999999997	62.271892999999999	0103000020E610000001000000050000005C3E92929E6763407381CB63CD224F405C3E92929E6763401C3F541A31614F403B8DB4545E8963401C3F541A31614F403B8DB4545E8963407381CB63CD224F405C3E92929E6763407381CB63CD224F40
30458	Дукат	4	39	1891	154.82330099999999	155.877959	62.817104	62.330641	0103000020E6100000010000000500000073B8567B585A6340BEDBBC71522A4F4073B8567B585A634024B726DD96684F405307793D187C634024B726DD96684F405307793D187C6340BEDBBC71522A4F4073B8567B585A6340BEDBBC71522A4F40
30160	Яна	4	39	62	147.673025	148.72768400000001	60.777228000000001	60.257333000000003	0103000020E610000001000000050000007E8CB96B897562403E97A949F0204E407E8CB96B897562408BC404357C634E4052BAF42F499762408BC404357C634E4052BAF42F499762403E97A949F0204E407E8CB96B897562403E97A949F0204E40
29749	Ямск	4	39	62	153.609308	154.66396700000001	59.848208	59.313301000000003	0103000020E610000001000000050000001EA67D737F336340ED66463F1AA84D401EA67D737F336340501A6A1492EC4D40F2D3B8373F556340501A6A1492EC4D40F2D3B8373F556340ED66463F1AA84D401EA67D737F336340ED66463F1AA84D40
29727	Тахтоямск	4	39	62	154.137168	155.19182599999999	60.462226000000001	59.937224000000001	0103000020E61000000100000005000000D94125AE634463405E83BEF4F6F74D40D94125AE6344634032AEB8382A3B4E40B89047702366634032AEB8382A3B4E40B8904770236663405E83BEF4F6F74D40D94125AE634463405E83BEF4F6F74D40
30207	Тауйск	4	39	62	148.79586599999999	149.85052400000001	59.985579000000001	59.452883	0103000020E61000000100000005000000F23FF9BB779962400AF5F411F8B94D40F23FF9BB77996240EC4FE27327FE4D40D28E1B7E37BB6240EC4FE27327FE4D40D28E1B7E37BB62400AF5F411F8B94D40F23FF9BB779962400AF5F411F8B94D40
30291	Талон	4	39	62	148.125103	149.17976100000001	60.030470000000001	59.498496000000003	0103000020E6100000010000000500000035B401D800846240EA9788B7CEBF4D4035B401D8008462402BC1E270E6034E401503249AC0A562402BC1E270E6034E401503249AC0A56240EA9788B7CEBF4D4035B401D800846240EA9788B7CEBF4D40
75	Ола	4	39	62	150.77232100000001	151.82697899999999	59.838959000000003	59.303902999999998	0103000020E6100000010000000500000073A087DAB6D862400114234BE6A64D4073A087DAB6D86240AAD72D0263EB4D4052EFA99C76FA6240AAD72D0263EB4D4052EFA99C76FA62400114234BE6A64D4073A087DAB6D862400114234BE6A64D40
29804	Клепка	4	39	62	150.952451	152.00710900000001	60.019927000000003	59.487783999999998	0103000020E610000001000000050000005C01857A7ADE62408BC1C3B46FBE4D405C01857A7ADE624059A7CAF78C024E403C50A73C3A00634059A7CAF78C024E403C50A73C3A0063408BC1C3B46FBE4D405C01857A7ADE62408BC1C3B46FBE4D40
29868	Гадля	4	39	62	150.79047600000001	151.845134	59.930312999999998	59.396726999999998	0103000020E61000000100000005000000BC0853944BD96240583849F3C7B24D40BC0853944BD962409605137F14F74D409B5775560BFB62409605137F14F74D409B5775560BFB6240583849F3C7B24D40BC0853944BD96240583849F3C7B24D40
30230	Балаганное	4	39	62	148.57231100000001	149.626969	59.925294999999998	59.391627999999997	0103000020E610000001000000050000008484285F509262405419C6DD20B24D408484285F509262407F130A1170F64D4063D34A2110B462407F130A1170F64D4063D34A2110B462405419C6DD20B24D408484285F509262405419C6DD20B24D40
30075	Армань	4	39	62	149.61142799999999	150.66608600000001	59.939968999999998	59.406537999999998	0103000020E610000001000000050000007AFB73D190B36240664AEB6F09B44D407AFB73D190B362407D2079E750F84D405A4A969350D562407D2079E750F84D405A4A969350D56240664AEB6F09B44D407AFB73D190B36240664AEB6F09B44D40
23070	Петропавловск-Камчатский	4	35	\N	158.095145	159.14980299999999	53.378059	52.742710000000002	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
55668	Елизово	4	35	\N	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
55660	Вилючинск	4	35	\N	157.88167799999999	158.93633600000001	53.257224999999998	52.620072999999998	0103000020E6100000010000000500000049F3C7B436BC6340F910548D5E4F4A4049F3C7B436BC6340575BB1BFECA04A402942EA76F6DD6340575BB1BFECA04A402942EA76F6DD6340F910548D5E4F4A4049F3C7B436BC6340F910548D5E4F4A40
30428	Усть-Камчатск	4	35	1889	161.950525	163.00518299999999	56.517578999999998	55.930034999999997	0103000020E61000000100000005000000F9A067B36A3E644053910A630BF74B40F9A067B36A3E6440560C570740424C40D8EF89752A606440560C570740424C40D8EF89752A60644053910A630BF74B40F9A067B36A3E644053910A630BF74B40
30247	Майское	4	35	1889	159.53535099999999	160.59000900000001	56.545085999999998	55.957968000000001	0103000020E61000000100000005000000309C6B9821F16340A94E07B29EFA4B40309C6B9821F16340F4C0C760C5454C4010EB8D5AE1126440F4C0C760C5454C4010EB8D5AE1126440A94E07B29EFA4B40309C6B9821F16340A94E07B29EFA4B40
30537	Крутоберегово	4	35	1889	162.18317999999999	163.23783800000001	56.541978999999998	55.954813000000001	0103000020E6100000010000000500000000A94D9CDC456440D865F84F37FA4B4000A94D9CDC456440340F60915F454C40E0F76F5E9C676440340F60915F454C40E0F76F5E9C676440D865F84F37FA4B4000A94D9CDC456440D865F84F37FA4B40
30204	Козыревск	4	35	1889	159.33936499999999	160.394023	56.335430000000002	55.745063000000002	0103000020E61000000100000005000000060DFD13DCEA6340D63A71395EDF4B40060DFD13DCEA6340740CC85EEF2A4C40E65B1FD69B0C6440740CC85EEF2A4C40E65B1FD69B0C6440D63A71395EDF4B40060DFD13DCEA6340D63A71395EDF4B40
55662	Ключи-1	4	35	1889	159.09459200000001	163.36289199999999	57.595799999999997	54.980797000000003	0103000020E61000000100000005000000D34ECDE506E36340E9818FC18A7D4B40D34ECDE506E36340787AA52C43CC4C405CFFAECF9C6B6440787AA52C43CC4C405CFFAECF9C6B6440E9818FC18A7D4B40D34ECDE506E36340E9818FC18A7D4B40
55666	Ключи	4	35	1889	159.09459200000001	163.36289199999999	57.595799999999997	54.980797000000003	0103000020E61000000100000005000000D34ECDE506E36340E9818FC18A7D4B40D34ECDE506E36340787AA52C43CC4C405CFFAECF9C6B6440787AA52C43CC4C405CFFAECF9C6B6440E9818FC18A7D4B40D34ECDE506E36340E9818FC18A7D4B40
55674	с. Кавалерское	4	35	1873	156.00669600000001	158.09539599999999	53.631497000000003	51.081696000000001	0103000020E6100000010000000500000073A087DA36806340651BB803758A494073A087DA36806340D542C9E4D4D04A406A85E97B0DC36340D542C9E4D4D04A406A85E97B0DC36340651BB803758A494073A087DA36806340651BB803758A4940
29738	Усть-Большерецк	4	35	1873	155.74825100000001	156.802909	53.139601999999996	52.500698	0103000020E6100000010000000500000061C614ACF177634018963FDF16404A4061C614ACF1776340643A747ADE914A404015376EB1996340643A747ADE914A404015376EB199634018963FDF16404A4061C614ACF177634018963FDF16404A40
29578	Паужетка	4	35	1873	156.28557799999999	157.340236	51.796191999999998	51.137470999999998	0103000020E61000000100000005000000A04E797423896340FF9254A698914940A04E7974238963401DAB949EE9E54940809D9B36E3AA63401DAB949EE9E54940809D9B36E3AA6340FF9254A698914940A04E797423896340FF9254A698914940
48905	Октябрьский	4	35	1873	155.715813	156.77047099999999	52.975110000000001	52.333761000000003	0103000020E61000000100000005000000A721AAF0E776634013D731AEB82A4A40A721AAF0E776634054008C67D07C4A408670CCB2A798634054008C67D07C4A408670CCB2A798634013D731AEB82A4A40A721AAF0E776634013D731AEB82A4A40
29640	Озерновский	4	35	1873	155.97389899999999	157.02855700000001	51.816696	51.158275000000003	0103000020E610000001000000050000006D533C2E2A7F63402063EE5A429449406D533C2E2A7F63401363997E89E849404DA25EF0E9A063401363997E89E849404DA25EF0E9A063402063EE5A429449406D533C2E2A7F63402063EE5A42944940
29630	Запорожье	4	35	1873	155.99447000000001	157.049128	51.832611	51.174422	0103000020E610000001000000050000004DDBBFB2D27F6340F9D9C875539649404DDBBFB2D27F63401AA54BFF92EA49402C2AE27492A163401AA54BFF92EA49402C2AE27492A16340F9D9C875539649404DDBBFB2D27F6340F9D9C87553964940
29867	Апача	4	35	1873	156.60625899999999	157.66091700000001	53.242964000000001	52.605598999999998	0103000020E61000000100000005000000FB3C467966936340C2BE9D44844D4A40FB3C4679669363407C0DC171199F4A40DB8B683B26B563407C0DC171199F4A40DB8B683B26B56340C2BE9D44844D4A40FB3C467966936340C2BE9D44844D4A40
52608	Хайрюзово	4	35	1898	156.49097800000001	157.545636	57.135351	56.557425000000002	0103000020E61000000100000005000000C7A17E17B68F6340857CD0B359474C40C7A17E17B68F63408E3D7B2E53914C40A6F0A0D975B163408E3D7B2E53914C40A6F0A0D975B16340857CD0B359474C40C7A17E17B68F6340857CD0B359474C40
52611	Усть-Хайрюзово	4	35	1898	156.20993999999999	157.26459800000001	57.385159999999999	56.811143000000001	0103000020E61000000100000005000000E94317D4B78663408EB0A888D3674C40E94317D4B78663401ADD41EC4CB14C40C992399677A863401ADD41EC4CB14C40C992399677A863408EB0A888D3674C40E94317D4B78663408EB0A888D3674C40
52624	Тигиль	4	35	1898	158.1481	159.20275799999999	58.042195	57.47851	0103000020E610000001000000050000003411363CBDC463408C67D0D03FBD4C403411363CBDC46340018750A566054D40136058FE7CE66340018750A566054D40136058FE7CE663408C67D0D03FBD4C403411363CBDC463408C67D0D03FBD4C40
52622	Седанка	4	35	1898	157.761852	158.81650999999999	58.007736999999999	57.443508000000001	0103000020E610000001000000050000008D0C721761B86340D7C1C1DEC4B84C408D0C721761B863400DFCA886FD004D406C5B94D920DA63400DFCA886FD004D406C5B94D920DA6340D7C1C1DEC4B84C408D0C721761B86340D7C1C1DEC4B84C40
55656	Палана	4	35	1898	159.42327700000001	160.477935	59.353254999999997	58.810406999999998	0103000020E61000000100000005000000C504357C8BED634088B9A46ABB674D40C504357C8BED63400113B87537AD4D40A453573E4B0F64400113B87537AD4D40A453573E4B0F644088B9A46ABB674D40C504357C8BED634088B9A46ABB674D40
52631	Лесная	4	35	1898	160.02884900000001	161.083507	59.730856000000003	59.194062000000002	0103000020E61000000100000005000000B7F0BC54EC006440BCB20B06D7984D40B7F0BC54EC006440EE0A7DB08CDD4D40963FDF16AC226440EE0A7DB08CDD4D40963FDF16AC226440BCB20B06D7984D40B7F0BC54EC006440BCB20B06D7984D40
52614	Ковран	4	35	1898	156.35291599999999	157.40757400000001	57.483899999999998	56.911431	0103000020E6100000010000000500000086C77E164B8B6340C1C760C5A9744C4086C77E164B8B63406744696FF0BD4C406616A1D80AAD63406744696FF0BD4C406616A1D80AAD6340C1C760C5A9744C4086C77E164B8B6340C1C760C5A9744C40
52628	Воямполка	4	35	1898	158.860366	159.91502399999999	58.584057999999999	58.028950000000002	0103000020E61000000100000005000000E412471E88DB63400F9C33A2B4034D40E412471E88DB6340CC7B9C69C24A4D40C36169E047FD6340CC7B9C69C24A4D40C36169E047FD63400F9C33A2B4034D40E412471E88DB63400F9C33A2B4034D40
55665	Соболево	4	35	1884	155.41593700000001	156.470595	54.605578999999999	53.988700999999999	0103000020E6100000010000000500000049861C5B4F6D6340E1421EC18DFE4A4049861C5B4F6D63407B12D89C834D4B4028D53E1D0F8F63407B12D89C834D4B4028D53E1D0F8F6340E1421EC18DFE4A4049861C5B4F6D6340E1421EC18DFE4A40
55680	Ичинский	4	35	1884	155.07975200000001	156.13441	55.901470000000003	55.304400999999999	0103000020E610000001000000050000004DF910548D62634052EFA99CF6A64B404DF910548D6263409E29745E63F34B402C4833164D8463409E29745E63F34B402C4833164D84634052EFA99CF6A64B404DF910548D62634052EFA99CF6A64B40
55678	Таловка	4	35	1920	166.17098100000001	167.225639	62.300514	61.805525000000003	0103000020E61000000100000005000000996725AD78C56440228E75711BE74E40996725AD78C56440BDFE243E77264F4078B6476F38E76440BDFE243E77264F4078B6476F38E76440228E75711BE74E40996725AD78C56440228E75711BE74E40
55679	Слаутное	4	35	1920	167.44143199999999	168.49609100000001	63.403579999999998	62.926845	0103000020E610000001000000050000000D6D003620EE644006BB61DBA2764F400D6D003620EE6440EBA86A82A8B34F40E19A3BFADF0F6540EBA86A82A8B34F40E19A3BFADF0F654006BB61DBA2764F400D6D003620EE644006BB61DBA2764F40
31768	Парень	4	35	1920	162.56266400000001	163.617322	62.666167000000002	62.177208999999998	0103000020E610000001000000050000005FD4EE570152644047C7D5C8AE164F405FD4EE57015264405456D3F544554F403E23111AC17364405456D3F544554F403E23111AC173644047C7D5C8AE164F405FD4EE570152644047C7D5C8AE164F40
31872	Оклан	4	35	1920	166.050185	167.10484299999999	62.950094999999997	62.465834000000001	0103000020E61000000100000005000000FEB7921D9BC16440B4AED172A03B4F40FEB7921D9BC16440EB8B84B69C794F40DD06B5DF5AE36440EB8B84B69C794F40DD06B5DF5AE36440B4AED172A03B4F40FEB7921D9BC16440B4AED172A03B4F40
55671	Манилы	4	35	1920	164.79425000000001	165.84890799999999	62.733758999999999	62.245918000000003	0103000020E6100000010000000500000023DBF97E6A996440B6BFB33D7A1F4F4023DBF97E6A996440A5129ED0EB5D4F40022A1C412ABB6440A5129ED0EB5D4F40022A1C412ABB6440B6BFB33D7A1F4F4023DBF97E6A996440B6BFB33D7A1F4F40
55676	Каменское	4	35	1920	165.68137200000001	166.73603	62.714348999999999	62.226188	0103000020E61000000100000005000000200DA7CCCDB56440B35F77BAF31C4F40200DA7CCCDB564401477BCC96F5B4F40FF5BC98E8DD764401477BCC96F5B4F40FF5BC98E8DD76440B35F77BAF31C4F40200DA7CCCDB56440B35F77BAF31C4F40
55677	Аянка	4	35	1920	167.05389	168.10854800000001	63.955694999999999	63.488163	0103000020E610000001000000050000009B728577B9E16440020F0C207CBE4F409B728577B9E16440B1F9B83654FA4F407BC1A73979036540B1F9B83654FA4F407BC1A73979036540020F0C207CBE4F409B728577B9E16440020F0C207CBE4F40
52666	Хаилино	4	35	1918	166.31554700000001	167.370205	61.211238000000002	60.698400999999997	0103000020E610000001000000050000003BAB05F618CA6440313F373465594E403BAB05F618CA644013D6C6D8099B4E401AFA27B8D8EB644013D6C6D8099B4E401AFA27B8D8EB6440313F373465594E403BAB05F618CA6440313F373465594E40
52662	Тиличики	4	35	1918	165.52123900000001	166.575897	60.692998000000003	60.171734999999998	0103000020E61000000100000005000000CB4C69FDADB064400E4A9869FB154E40CB4C69FDADB06440C2189128B4584E40AA9B8BBF6DD26440C2189128B4584E40AA9B8BBF6DD264400E4A9869FB154E40CB4C69FDADB064400E4A9869FB154E40
55675	Средние Пахачи	4	35	1918	164.08439200000001	174.49339599999999	62.548397999999999	59.590699999999998	0103000020E610000001000000050000006901DA56B3826440A4DFBE0E9CCB4D406901DA56B38264408D98D9E731464F40457F68E6C9CF65408D98D9E731464F40457F68E6C9CF6540A4DFBE0E9CCB4D406901DA56B3826440A4DFBE0E9CCB4D40
52669	Пахачи	4	35	1918	168.61536899999999	169.670027	60.819695000000003	60.300488999999999	0103000020E610000001000000050000001C3F541AB113654064E76D6C76264E401C3F541AB1136540EDD808C4EB684E40FC8D76DC70356540EDD808C4EB684E40FC8D76DC7035654064E76D6C76264E401C3F541AB113654064E76D6C76264E40
52661	Корф	4	35	1918	165.487776	166.54243399999999	60.631698	60.109442000000001	0103000020E61000000100000005000000C2F869DC9BAF644088670932020E4E40C2F869DC9BAF64406C79E57ADB504E40A1478C9E5BD164406C79E57ADB504E40A1478C9E5BD1644088670932020E4E40C2F869DC9BAF644088670932020E4E40
52658	Вывенка	4	35	1918	164.92821599999999	165.98287400000001	60.449993999999997	59.924793999999999	0103000020E61000000100000005000000F7730AF2B39D6440BDC458A65FF64D40F7730AF2B39D6440B7B2446799394E40D7C22CB473BF6440B7B2446799394E40D7C22CB473BF6440BDC458A65FF64D40F7730AF2B39D6440BDC458A65FF64D40
52678	Ачайваям	4	35	1918	169.97252599999999	171.02718400000001	61.262047000000003	60.750039000000001	0103000020E610000001000000050000004F90D8EE1E3F6540BEDC274701604E404F90D8EE1E3F6540E9818FC18AA14E402FDFFAB0DE606540E9818FC18AA14E402FDFFAB0DE606540BEDC274701604E404F90D8EE1E3F6540BEDC274701604E40
52673	Апука	4	35	1918	169.05177900000001	170.106437	60.717115	60.196244	0103000020E61000000100000005000000D4F36E2CA8216540A304FD851E194E40D4F36E2CA82165404B3CA06CCA5B4E40B34291EE674365404B3CA06CCA5B4E40B34291EE67436540A304FD851E194E40D4F36E2CA8216540A304FD851E194E40
29162	Шаромы	4	35	1863	157.68627599999999	158.74093500000001	54.704315999999999	54.088935999999997	0103000020E61000000100000005000000F30016F9F5B56340F1B73D41620B4B40F30016F9F5B563405706D506275A4B40C72E51BDB5D763405706D506275A4B40C72E51BDB5D76340F1B73D41620B4B40F30016F9F5B56340F1B73D41620B4B40
45451	Таежный	4	35	1863	158.84442000000001	159.899079	55.572487000000002	54.970359999999999	0103000020E61000000100000005000000D482177D05DB63405CACA8C1347C4B40D482177D05DB63404D31074147C94B40A7B05241C5FC63404D31074147C94B40A7B05241C5FC63405CACA8C1347C4B40D482177D05DB63405CACA8C1347C4B40
48693	Пущино	4	35	1863	157.48738900000001	158.54204799999999	54.476573000000002	53.857740999999997	0103000020E61000000100000005000000C4EDD0B098AF63401BB80375CAED4A40C4EDD0B098AF63400C941458003D4B40971B0C7558D163400C941458003D4B40971B0C7558D163401BB80375CAED4A40C4EDD0B098AF63401BB80375CAED4A40
29250	Мильково	4	35	1863	158.09467799999999	159.14933600000001	54.999816000000003	54.388930999999999	0103000020E61000000100000005000000D234289A07C3634046B3B27DC8314B40D234289A07C363403F027FF8F97F4B40B2834A5CC7E463403F027FF8F97F4B40B2834A5CC7E4634046B3B27DC8314B40D234289A07C3634046B3B27DC8314B40
48840	Лазо	4	35	1863	159.234217	160.28887499999999	55.837116000000002	55.239055	0103000020E610000001000000050000005A65A6B47EE76340FF78AF5A999E4B405A65A6B47EE76340AB7AF99D26EB4B4039B4C8763E096440AB7AF99D26EB4B4039B4C8763E096440FF78AF5A999E4B405A65A6B47EE76340FF78AF5A999E4B40
45404	Долиновка	4	35	1863	158.53715199999999	159.59181000000001	55.422221999999998	54.817791	0103000020E61000000100000005000000641F645930D1634048FB1F60AD684B40641F645930D163406BD3D85E0BB64B40446E861BF0F263406BD3D85E0BB64B40446E861BF0F2634048FB1F60AD684B40641F645930D1634048FB1F60AD684B40
29501	Атласово	4	35	1863	159.11202900000001	160.166687	55.903277000000003	55.306235000000001	0103000020E610000001000000050000008466D7BD95E36340FEF15EB532A74B408466D7BD95E36340501DAB949EF34B4063B5F97F55056440501DAB949EF34B4063B5F97F55056440FEF15EB532A74B408466D7BD95E36340FEF15EB532A74B40
52655	Тымлат	4	35	1909	162.651579	163.70623800000001	59.757719999999999	59.221358000000002	0103000020E6100000010000000500000055F833BCD95464409F5A7D75559C4D4055F833BCD954644037C30DF8FCE04D4029266F809976644037C30DF8FCE04D4029266F80997664409F5A7D75559C4D4055F833BCD95464409F5A7D75559C4D40
55667	Оссора	4	35	1909	162.53523899999999	163.58989700000001	59.515926	58.975682999999997	0103000020E6100000010000000500000066118AAD20516440AF21382EE37C4D4066118AAD20516440FB93F8DC09C24D404660AC6FE0726440FB93F8DC09C24D404660AC6FE0726440AF21382EE37C4D4066118AAD20516440AF21382EE37C4D40
52643	Кострома	4	35	1909	162.64778899999999	163.70244700000001	59.305419000000001	58.761805000000003	0103000020E61000000100000005000000AC36FFAFBA546440F37684D382614D40AC36FFAFBA546440DC4944F817A74D408C8521727A766440DC4944F817A74D408C8521727A766440F37684D382614D40AC36FFAFBA546440F37684D382614D40
52650	Карага	4	35	1909	162.59601900000001	163.650677	59.377847000000003	58.835391999999999	0103000020E610000001000000050000006E1970961253644086AB0320EE6A4D406E1970961253644024F25D4A5DB04D404D689258D274644024F25D4A5DB04D404D689258D274644086AB0320EE6A4D406E1970961253644086AB0320EE6A4D40
52653	Ильпырское	4	35	1909	163.65144000000001	164.706098	60.221297	59.692402000000001	0103000020E61000000100000005000000CDE9B298D8746440AED7F4A0A0D84D40CDE9B298D8746440F9D9C875531C4E40AC38D55A98966440F9D9C875531C4E40AC38D55A98966440AED7F4A0A0D84D40CDE9B298D8746440AED7F4A0A0D84D40
52640	Ивашка	4	35	1909	161.77157199999999	162.82623000000001	58.839047999999998	58.287993	0103000020E610000001000000050000004C50C3B7B03864400C3D62F4DC244D404C50C3B7B038644019E3C3EC656B4D402C9FE579705A644019E3C3EC656B4D402C9FE579705A64400C3D62F4DC244D404C50C3B7B03864400C3D62F4DC244D40
55670	п.Новый	4	35	1821	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
55664	п.Вулканный	4	35	1821	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
28618	Термальный	4	35	1821	157.69248400000001	158.747142	53.250556000000003	52.613303999999999	0103000020E610000001000000050000001BA034D428B66340C440D7BE804E4A401BA034D428B6634086E8103812A04A40FAEE5696E8D7634086E8103812A04A40FAEE5696E8D76340C440D7BE804E4A401BA034D428B66340C440D7BE804E4A40
28472	Сосновка	4	35	1821	157.76879600000001	158.823454	53.390808999999997	52.755651	0103000020E6100000010000000500000076A911FA99B863404818062CB9604A4076A911FA99B86340C1FD800706B24A4055F833BC59DA6340C1FD800706B24A4055F833BC59DA63404818062CB9604A4076A911FA99B863404818062CB9604A40
29086	Сокоч	4	35	1821	157.166089	158.22074699999999	53.461961000000002	52.827865000000003	0103000020E6100000010000000500000036E7E09950A563406440F67AF7694A4036E7E09950A563408483BD8921BB4A401536035C10C763408483BD8921BB4A401536035C10C763406440F67AF7694A4036E7E09950A563406440F67AF7694A40
55673	Северные Коряки	4	35	1821	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
28698	Раздольный	4	35	1821	157.76091700000001	158.81557599999999	53.583415000000002	52.951135999999998	0103000020E610000001000000050000000EBF9B6E59B863402D060FD3BE794A400EBF9B6E59B86340787FBC57ADCA4A40E1ECD63219DA6340787FBC57ADCA4A40E1ECD63219DA63402D060FD3BE794A400EBF9B6E59B863402D060FD3BE794A40
27493	Пионерский	4	35	1821	158.004864	159.05952199999999	53.410963000000002	52.776105999999999	0103000020E61000000100000005000000B01D8CD827C063405C1D007157634A40B01D8CD827C06340DB6E826F9AB44A408F6CAE9AE7E16340DB6E826F9AB44A408F6CAE9AE7E163405C1D007157634A40B01D8CD827C063405C1D007157634A40
28540	Паратунка	4	35	1821	157.72131099999999	158.775969	53.277662999999997	52.640816000000001	0103000020E61000000100000005000000D767CEFA14B763407460394206524A40D767CEFA14B76340952710768AA34A40B7B6F0BCD4D86340952710768AA34A40B7B6F0BCD4D863407460394206524A40D767CEFA14B763407460394206524A40
28456	Николаевка	4	35	1821	157.807962	158.86261999999999	53.360881999999997	52.725276999999998	0103000020E6100000010000000500000025CD1FD3DAB963403FC571E0D55C4A4025CD1FD3DAB9634087DBA16131AE4A40041C42959ADB634087DBA16131AE4A40041C42959ADB63403FC571E0D55C4A4025CD1FD3DAB963403FC571E0D55C4A40
55659	Нагорный	4	35	1821	157.991039	159.04569699999999	53.435786	52.801299	0103000020E61000000100000005000000F0C16B97B6BF6340A4A833F790664A40F0C16B97B6BF6340FF06EDD5C7B74A40CF108E5976E16340FF06EDD5C7B74A40CF108E5976E16340A4A833F790664A40F0C16B97B6BF6340A4A833F790664A40
29006	Лесной	4	35	1821	157.49830399999999	158.55296200000001	53.566231000000002	52.933695	0103000020E61000000100000005000000E9EE3A1BF2AF634028B8585183774A40E9EE3A1BF2AF63409E7DE5417AC84A40C93D5DDDB1D163409E7DE5417AC84A40C93D5DDDB1D1634028B8585183774A40E9EE3A1BF2AF634028B8585183774A40
28769	Коряки	4	35	1821	157.68032099999999	158.73497900000001	53.595669999999998	52.963574999999999	0103000020E6100000010000000500000006B98B30C5B56340211FF46C567B4A4006B98B30C5B56340AA9A20EA3ECC4A40E607AEF284D76340AA9A20EA3ECC4A40E607AEF284D76340211FF46C567B4A4006B98B30C5B56340211FF46C567B4A40
28926	Зеленый	4	35	1821	157.64958899999999	158.70424700000001	53.587043999999999	52.954819999999998	0103000020E61000000100000005000000ECDADE6EC9B463408AC8B08A377A4A40ECDADE6EC9B4634011A8FE4124CB4A40CC29013189D6634011A8FE4124CB4A40CC29013189D663408AC8B08A377A4A40ECDADE6EC9B463408AC8B08A377A4A40
27738	Елизово	4	35	1821	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
27674	Двуречье	4	35	1821	157.972677	159.02733499999999	53.453226999999998	52.819001	0103000020E610000001000000050000004912842B20BF634016325706D5684A404912842B20BF63400455A35703BA4A402861A6EDDFE063400455A35703BA4A402861A6EDDFE0634016325706D5684A404912842B20BF634016325706D5684A40
55669	Вилючинский городской округ	4	35	1821	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
55658	Вилючинск	4	35	1821	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
28947	Березняки	4	35	1821	157.55922799999999	158.61388600000001	53.579234999999997	52.946893000000003	0103000020E610000001000000050000003D601E32E5B16340DAE731CA33794A403D601E32E5B163406AD95A5F24CA4A401DAF40F4A4D363406AD95A5F24CA4A401DAF40F4A4D36340DAE731CA33794A403D601E32E5B16340DAE731CA33794A40
29890	Эссо	4	35	1879	158.16732400000001	159.221982	56.225417999999998	55.633347999999998	0103000020E61000000100000005000000C07ADCB75AC56340567E198C11D14B40C07ADCB75AC5634001F73C7FDA1C4C409FC9FE791AE7634001F73C7FDA1C4C409FC9FE791AE76340567E198C11D14B40C07ADCB75AC56340567E198C11D14B40
29940	Анавгай	4	35	1879	158.44434699999999	159.49900500000001	56.350861000000002	55.760731999999997	0103000020E610000001000000050000006C22331738CE6340A5828AAA5FE14B406C22331738CE63408F386403E92C4C404C7155D9F7EF63408F386403E92C4C404C7155D9F7EF6340A5828AAA5FE14B406C22331738CE6340A5828AAA5FE14B40
55672	Никольское	4	35	1896	165.486752	166.54141000000001	55.502589	54.899389999999997	0103000020E610000001000000050000006728EE7893AF6440BA2C26361F734B406728EE7893AF6440282A1BD654C04B404777103B53D16440282A1BD654C04B404777103B53D16440BA2C26361F734B406728EE7893AF6440BA2C26361F734B40
55681	Хинганск	4	41	\N	131.17627400000001	131.21327500000001	49.134630999999999	49.115777000000001	0103000020E6100000010000000500000053245F09A46560408350DEC7D18E484053245F09A46560408E03AF963B914840BEC11726D36660408E03AF963B914840BEC11726D36660408350DEC7D18E484053245F09A46560408350DEC7D18E4840
55686	Облучье	4	41	\N	131.03078300000001	131.083505	49.049754	48.973348000000001	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
55691	Волочаевка-2	4	41	\N	134.564809	134.58585600000001	48.581353	48.551124999999999	0103000020E6100000010000000500000091EF52EA12D26040068195438B46484091EF52EA12D260403B376DC6694A48404B051555BFD260403B376DC6694A48404B051555BFD26040068195438B46484091EF52EA12D26040068195438B464840
55684	Биробиджан	4	41	\N	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
16582	Биробиджан	4	41	\N	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
45455	им. Тельмана	4	41	1601	134.96798200000001	134.98416900000001	48.559151999999997	48.532699000000001	0103000020E61000000100000005000000BC2363B5F9DE604053CE177B2F444840BC2363B5F9DE60401ABFF04A924748409697FC4F7EDF60401ABFF04A924748409697FC4F7EDF604053CE177B2F444840BC2363B5F9DE604053CE177B2F444840
55682	Смидович	4	41	1601	133.78368800000001	133.85586699999999	48.611044999999997	48.586132999999997	0103000020E610000001000000050000009148DBF813B960409D0DF967064B48409148DBF813B9604031B1F9B8364E484038D7304363BB604031B1F9B8364E484038D7304363BB60409D0DF967064B48409148DBF813B960409D0DF967064B4840
19715	Смидович	4	41	1601	133.78368800000001	133.85586699999999	48.611044999999997	48.586132999999997	0103000020E610000001000000050000009148DBF813B960409D0DF967064B48409148DBF813B9604031B1F9B8364E484038D7304363BB604031B1F9B8364E484038D7304363BB60409D0DF967064B48409148DBF813B960409D0DF967064B4840
55683	Приамурский	4	41	1601	134.889568	134.92329100000001	48.543365000000001	48.497802999999998	0103000020E610000001000000050000002E724F5777DC6040E36C3A02B83F48402E724F5777DC60404165FCFB8C4548401E3691998BDD60404165FCFB8C4548401E3691998BDD6040E36C3A02B83F48402E724F5777DC6040E36C3A02B83F4840
49474	Песчаное	4	41	1601	133.85235499999999	133.86783299999999	48.621183000000002	48.606476000000001	0103000020E61000000100000005000000A032FE7D46BB60408AE76C01A14D4840A032FE7D46BB604064EAAEEC824F4840772CB649C5BB604064EAAEEC824F4840772CB649C5BB60408AE76C01A14D4840A032FE7D46BB60408AE76C01A14D4840
49485	Партизанское	4	41	1601	134.44448	134.46842000000001	48.575201999999997	48.563529000000003	0103000020E610000001000000050000003CF71E2E39CE60407EACE0B7214848403CF71E2E39CE6040014C1938A04948405B99F04BFDCE6040014C1938A04948405B99F04BFDCE60407EACE0B7214848403CF71E2E39CE60407EACE0B721484840
55685	Николаевка	4	41	1601	134.74839800000001	134.80835999999999	48.576256999999998	48.527239999999999	0103000020E610000001000000050000008ACC5CE0F2D760404F92AE997C4348408ACC5CE0F2D76040A88B14CAC2494840A06CCA15DED96040A88B14CAC2494840A06CCA15DED960404F92AE997C4348408ACC5CE0F2D760404F92AE997C434840
45354	Николаевка	4	41	1601	134.74839800000001	134.80835999999999	48.576256999999998	48.527239999999999	0103000020E610000001000000050000008ACC5CE0F2D760404F92AE997C4348408ACC5CE0F2D76040A88B14CAC2494840A06CCA15DED96040A88B14CAC2494840A06CCA15DED960404F92AE997C4348408ACC5CE0F2D760404F92AE997C434840
20264	Ключевое	4	41	1601	134.719481	134.73462599999999	48.538592999999999	48.531672999999998	0103000020E61000000100000005000000FDA204FD05D76040469561DC0D444840FDA204FD05D76040616D8C9DF04448405299620E82D76040616D8C9DF04448405299620E82D76040469561DC0D444840FDA204FD05D76040469561DC0D444840
49577	Камышовка	4	41	1601	134.59482199999999	134.61089200000001	48.557201999999997	48.544730999999999	0103000020E610000001000000050000001F9E25C808D36040060FD3BEB94548401F9E25C808D3604005A22765524748406B2C616D8CD3604005A22765524748406B2C616D8CD36040060FD3BEB94548401F9E25C808D36040060FD3BEB9454840
46672	Даниловка	4	41	1601	134.59681599999999	134.61695599999999	48.599023000000003	48.585304999999998	0103000020E610000001000000050000005837DE1D19D36040B7973446EB4A48405837DE1D19D36040A24621C9AC4C48404562821ABED36040A24621C9AC4C48404562821ABED36040B7973446EB4A48405837DE1D19D36040B7973446EB4A4840
19999	Волочаевка-2	4	41	1601	134.564809	134.58585600000001	48.581353	48.551124999999999	0103000020E6100000010000000500000091EF52EA12D26040068195438B46484091EF52EA12D260403B376DC6694A48404B051555BFD260403B376DC6694A48404B051555BFD26040068195438B46484091EF52EA12D26040068195438B464840
19957	Волочаевка-1	4	41	1601	134.46802400000001	134.50973300000001	48.568005999999997	48.557308999999997	0103000020E61000000100000005000000C8B7770DFACE60401B62BCE655474840C8B7770DFACE604044F7AC6BB4484840259694BB4FD0604044F7AC6BB4484840259694BB4FD060401B62BCE655474840C8B7770DFACE60401B62BCE655474840
19650	Белгородское	4	41	1601	133.71685299999999	133.73601400000001	48.601120000000002	48.588678000000002	0103000020E6100000010000000500000043E1B375F0B66040F6EFFACC594B484043E1B375F0B660405B7C0A80F14C4840BE6C3B6D8DB760405B7C0A80F14C4840BE6C3B6D8DB76040F6EFFACC594B484043E1B375F0B66040F6EFFACC594B4840
19583	Аур	4	41	1601	133.41334800000001	133.45194900000001	48.631847999999998	48.622422	0103000020E61000000100000005000000BFBB95253AAD6040CC272B86AB4F4840BFBB95253AAD604081053065E0504840B8CEBF5D76AE604081053065E0504840B8CEBF5D76AE6040CC272B86AB4F4840BFBB95253AAD6040CC272B86AB4F4840
21065	Столбовое	4	41	1645	131.044805	131.06407400000001	47.925710000000002	47.909332999999997	0103000020E610000001000000050000005036E50A6F6160403716140665F447405036E50A6F61604043CA4FAA7DF64740C4D0EAE40C62604043CA4FAA7DF64740C4D0EAE40C6260403716140665F447405036E50A6F6160403716140665F44740
21055	Самара	4	41	1645	131.210059	131.239407	47.842574999999997	47.820411999999997	0103000020E6100000010000000500000060E7A6CDB86660407B9FAA4203E9474060E7A6CDB8666040AEB6627FD9EB4740DF6DDE38A9676040AEB6627FD9EB4740DF6DDE38A96760407B9FAA4203E9474060E7A6CDB86660407B9FAA4203E94740
45668	Садовое	4	41	1645	131.43562600000001	131.457213	47.768222000000002	47.756920000000001	0103000020E6100000010000000500000032E9EFA5F06D60401BD82AC1E2E0474032E9EFA5F06D6040AB08371955E24740CB49287DA16E6040AB08371955E24740CB49287DA16E60401BD82AC1E2E0474032E9EFA5F06D60401BD82AC1E2E04740
45735	Ручейки	4	41	1645	131.63588799999999	131.646659	47.825029000000001	47.817653999999997	0103000020E61000000100000005000000677DCA3159746040C7B8E2E2A8E84740677DCA315974604034A0DE8C9AE947404015376EB174604034A0DE8C9AE947404015376EB1746040C7B8E2E2A8E84740677DCA3159746040C7B8E2E2A8E84740
20991	Пузино	4	41	1645	131.19644099999999	131.235185	47.742494999999998	47.728701999999998	0103000020E61000000100000005000000FED2A23E49666040D0436D1B46DD4740FED2A23E49666040C5387F130ADF47405070B1A286676040C5387F130ADF47405070B1A286676040D0436D1B46DD4740FED2A23E49666040D0436D1B46DD4740
45626	Полевое	4	41	1645	131.239093	131.26260199999999	47.850423999999997	47.833195000000003	0103000020E610000001000000050000007BF65CA6A66760406A183E22A6EA47407BF65CA6A6676040E3DD91B1DAEC4740A73B4F3C67686040E3DD91B1DAEC4740A73B4F3C676860406A183E22A6EA47407BF65CA6A66760406A183E22A6EA4740
45532	Озерное	4	41	1645	131.12904900000001	131.141482	47.757404000000001	47.743319	0103000020E610000001000000050000009C525E2B216460406ABFB51325DF47409C525E2B2164604007EE409DF2E04740205F42058764604007EE409DF2E04740205F4205876460406ABFB51325DF47409C525E2B216460406ABFB51325DF4740
21299	Нагибово	4	41	1645	131.52248399999999	131.54493299999999	47.750450000000001	47.73695	0103000020E61000000100000005000000DD955D30B8706040C364AA6054DE4740DD955D30B870604040A4DFBE0EE047405BB054177071604040A4DFBE0EE047405BB0541770716040C364AA6054DE4740DD955D30B8706040C364AA6054DE4740
45635	Луговое	4	41	1645	131.321451	131.33855399999999	47.849226999999999	47.832324	0103000020E6100000010000000500000087889B53496A604084D6C39789EA474087889B53496A6040AAF06778B3EC4740C2BD326FD56A6040AAF06778B3EC4740C2BD326FD56A604084D6C39789EA474087889B53496A604084D6C39789EA4740
20883	Екатерино-Никольское	4	41	1645	130.95768699999999	130.97644399999999	47.768155	47.731059999999999	0103000020E61000000100000005000000BD19355FA55E6040F6B4C35F93DD4740BD19355FA55E604023A12DE752E2474003CC7C073F5F604023A12DE752E2474003CC7C073F5F6040F6B4C35F93DD4740BD19355FA55E6040F6B4C35F93DD4740
21366	Доброе	4	41	1645	131.668982	131.68695700000001	47.770626	47.759869999999999	0103000020E610000001000000050000009B73F04C68756040139B8F6B43E147409B73F04C6875604041B96DDFA3E2474044183F8DFB75604041B96DDFA3E2474044183F8DFB756040139B8F6B43E147409B73F04C68756040139B8F6B43E14740
55695	Благославенное	4	41	1645	131.36466799999999	131.396478	47.774175	47.761431999999999	0103000020E61000000100000005000000BABC395CAB6B60405E10919A76E14740BABC395CAB6B6040BE30992A18E34740AC72A1F2AF6C6040BE30992A18E34740AC72A1F2AF6C60405E10919A76E14740BABC395CAB6B60405E10919A76E14740
20785	Амурзет	4	41	1645	131.06270000000001	131.127657	47.702354999999997	47.688054000000001	0103000020E61000000100000005000000B22E6EA301626040E5F0492712D84740B22E6EA3016260404E97C5C4E6D94740600322C4156460404E97C5C4E6D94740600322C415646040E5F0492712D84740B22E6EA301626040E5F0492712D84740
55687	Теплоозерск	4	41	1543	131.850289	131.92113900000001	49.019683999999998	48.998097000000001	0103000020E61000000100000005000000C1E44691357B60402C9E7AA4C17F4840C1E44691357B604092205C01858248403F027FF8797D604092205C01858248403F027FF8797D60402C9E7AA4C17F4840C1E44691357B60402C9E7AA4C17F4840
55697	Семисточный	4	41	1543	132.59939399999999	132.608305	48.964422999999996	48.957572999999996	0103000020E61000000100000005000000656D533C2E9360402C4487C0917A4840656D533C2E9360404E417E36727B4840C91F0C3C779360404E417E36727B4840C91F0C3C779360402C4487C0917A4840656D533C2E9360402C4487C0917A4840
18919	Радде	4	41	1543	130.590509	130.606706	48.605040000000002	48.589888000000002	0103000020E61000000100000005000000CC5F2173E5526040C4263273814B4840CC5F2173E5526040CC6262F3714D48402F89B3226A536040CC6262F3714D48402F89B3226A536040C4263273814B4840CC5F2173E5526040C4263273814B4840
49205	Пашково	4	41	1543	130.641336	130.66311099999999	48.894384000000002	48.882446999999999	0103000020E61000000100000005000000EB3713D38554604006BAF605F4704840EB3713D3855460406808C72C7B724840C5538F34385560406808C72C7B724840C5538F343855604006BAF605F4704840EB3713D38554604006BAF605F4704840
55688	Облучье	4	41	1543	131.03078300000001	131.083505	49.049754	48.973348000000001	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
18371	Облучье	4	41	1543	131.03078300000001	131.083505	49.049754	48.973348000000001	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
55693	Лондоко	4	41	1543	131.920815	132.01342299999999	49.029798	49.001767000000001	0103000020E6100000010000000500000052D50451777D6040249BABE63980484052D50451777D60403CBEBD6BD0834840744012F66D8060403CBEBD6BD0834840744012F66D806040249BABE63980484052D50451777D6040249BABE639804840
19325	Кульдур	4	41	1543	131.61451700000001	131.653998	49.215860999999997	49.191561999999998	0103000020E61000000100000005000000C13A8E1FAA7360400394861A85984840C13A8E1FAA736040ADBD4F55A19B4840C8B4368DED746040ADBD4F55A19B4840C8B4368DED7460400394861A85984840C13A8E1FAA7360400394861A85984840
55689	Известковый	4	41	1543	131.522323	131.58410900000001	49.006537000000002	48.972934000000002	0103000020E610000001000000050000005B5EB9DEB67060404F95EF19897C48405B5EB9DEB6706040639B5434D680484094895B05B1726040639B5434D680484094895B05B17260404F95EF19897C48405B5EB9DEB67060404F95EF19897C4840
19079	Двуречье	4	41	1543	131.569942	131.595742	48.977310000000003	48.966197999999999	0103000020E61000000100000005000000BD5301F73C726040F5BA4560AC7B4840BD5301F73C726040E2067C7E187D484051DB865110736040E2067C7E187D484051DB865110736040F5BA4560AC7B4840BD5301F73C726040F5BA4560AC7B4840
19471	Будукан	4	41	1543	132.22074499999999	132.25653399999999	49.020937000000004	49.006590000000003	0103000020E610000001000000050000002D78D15710876040863DEDF0D78048402D78D1571087604060234910AE824840FC89CA863588604060234910AE824840FC89CA8635886040863DEDF0D78048402D78D15710876040863DEDF0D7804840
19140	Биракан	4	41	1543	131.69599400000001	131.765964	49.012889000000001	48.987208000000003	0103000020E61000000100000005000000CB86359545766040BF2CEDD45C7E4840CB8635954576604034BDC458A68148403A3DEFC68278604034BDC458A68148403A3DEFC682786040BF2CEDD45C7E4840CB86359545766040BF2CEDD45C7E4840
19386	Бира	4	41	1543	132.44315	132.48958400000001	49.013781999999999	48.988272000000002	0103000020E610000001000000050000001EA7E8482E8E6040B9C667B27F7E48401EA7E8482E8E604001A3CB9BC3814840A39410ACAA8F604001A3CB9BC3814840A39410ACAA8F6040B9C667B27F7E48401EA7E8482E8E6040B9C667B27F7E4840
55690	Бира	4	41	1543	132.44315	132.48958400000001	49.013781999999999	48.988272000000002	0103000020E610000001000000050000001EA7E8482E8E6040B9C667B27F7E48401EA7E8482E8E604001A3CB9BC3814840A39410ACAA8F604001A3CB9BC3814840A39410ACAA8F6040B9C667B27F7E48401EA7E8482E8E6040B9C667B27F7E4840
18981	Башурово	4	41	1543	130.58836199999999	130.60432499999999	48.703631000000001	48.68824	0103000020E61000000100000005000000B1868BDCD352604047E6913F18584840B1868BDCD3526040D4B9A294105A4840F7E461A156536040D4B9A294105A4840F7E461A15653604047E6913F18584840B1868BDCD352604047E6913F18584840
22622	Чурки	4	41	1696	132.65636499999999	132.672337	48.081893000000001	48.072923000000003	0103000020E61000000100000005000000A6272CF1009560402810768A55094840A6272CF100956040BB6246787B0A4840815CE2C883956040BB6246787B0A4840815CE2C8839560402810768A55094840A6272CF1009560402810768A55094840
22836	Унгун	4	41	1696	132.39657199999999	132.428777	48.219971999999999	48.201124	0103000020E610000001000000050000004C50C3B7B08C60406938656EBE1948404C50C3B7B08C60409204E10A281C4840DD088B8AB88D60409204E10A281C4840DD088B8AB88D60406938656EBE1948404C50C3B7B08C60406938656EBE194840
46489	Степное	4	41	1696	131.89182700000001	131.90975700000001	47.900249000000002	47.880473000000002	0103000020E6100000010000000500000013D6C6D8897C60406901DA56B3F0474013D6C6D8897C6040DCA0F65B3BF34740D449B6BA1C7D6040DCA0F65B3BF34740D449B6BA1C7D60406901DA56B3F0474013D6C6D8897C60406901DA56B3F04740
23583	Преображеновка	4	41	1696	131.88637399999999	131.90785299999999	48.104027000000002	48.074975999999999	0103000020E61000000100000005000000CAC0012D5D7C604011FE45D098094840CAC0012D5D7C60405473B9C1500D48406A12BC210D7D60405473B9C1500D48406A12BC210D7D604011FE45D098094840CAC0012D5D7C604011FE45D098094840
46326	Октябрьское	4	41	1696	132.51107999999999	132.52329800000001	48.096908999999997	48.088025999999999	0103000020E6100000010000000500000078B471C45A9060404E999B6F440B484078B471C45A90604012D89C83670C4840FE8172DBBE90604012D89C83670C4840FE8172DBBE9060404E999B6F440B484078B471C45A9060404E999B6F440B4840
46443	Новотроицкое	4	41	1696	131.95170899999999	131.97268399999999	48.263517999999998	48.242904000000003	0103000020E61000000100000005000000E2C96E66747E6040A708707A171F4840E2C96E66747E604023F433F5BA214840F52A323A207F604023F433F5BA214840F52A323A207F6040A708707A171F4840E2C96E66747E6040A708707A171F4840
55694	Новое	4	41	1696	132.32149999999999	132.36151100000001	47.815202999999997	47.799486999999999	0103000020E610000001000000050000003F355EBA498A6040E0490B9755E647403F355EBA498A6040F04C689258E847409E44847F918B6040F04C689258E847409E44847F918B6040E0490B9755E647403F355EBA498A6040E0490B9755E64740
46221	Нижнеленинское	4	41	1696	132.65772999999999	132.680485	47.966912999999998	47.955613	0103000020E6100000010000000500000023F3C81F0C956040F450DB8651FA474023F3C81F0C956040E38920CEC3FB4740658D7A88C6956040E38920CEC3FB4740658D7A88C6956040F450DB8651FA474023F3C81F0C956040F450DB8651FA4740
45545	Ленинское	4	41	1696	132.60779299999999	132.64625000000001	47.963287999999999	47.925795000000001	0103000020E610000001000000050000009B374E0A7393604071E6577380F647409B374E0A739360408B506C054DFB474048E17A14AE9460408B506C054DFB474048E17A14AE94604071E6577380F647409B374E0A7393604071E6577380F64740
22542	Ленинск	4	41	1696	132.600202	132.62829300000001	47.989876000000002	47.971631000000002	0103000020E61000000100000005000000CD1FD3DA34936040D06394675EFC4740CD1FD3DA34936040338CBB41B4FE4740C9E9EBF91A946040338CBB41B4FE4740C9E9EBF91A946040D06394675EFC4740CD1FD3DA34936040D06394675EFC4740
22868	Лазарево	4	41	1696	132.42988199999999	132.45782800000001	48.248598999999999	48.231436000000002	0103000020E610000001000000050000007364E597C18D6040FC8EE1B19F1D48407364E597C18D6040BE688F17D21F48402EE6E786A68E6040BE688F17D21F48402EE6E786A68E6040FC8EE1B19F1D48407364E597C18D6040FC8EE1B19F1D4840
46606	Кукелево	4	41	1696	132.512248	132.530565	47.895952999999999	47.883415999999997	0103000020E6100000010000000500000020EEEA5564906040AE6186C613F1474020EEEA556490604065E08096AEF24740DF6C7363FA90604065E08096AEF24740DF6C7363FA906040AE6186C613F1474020EEEA5564906040AE6186C613F14740
46518	Кирово	4	41	1696	132.04924800000001	132.06846300000001	47.860328000000003	47.849687000000003	0103000020E6100000010000000500000097AC8A70938160400E6B2A8BC2EC474097AC8A7093816040A3EA573A1FEE47408E3F51D930826040A3EA573A1FEE47408E3F51D9308260400E6B2A8BC2EC474097AC8A70938160400E6B2A8BC2EC4740
46549	Квашнино	4	41	1696	132.12094200000001	132.13887199999999	47.784765	47.774605000000001	0103000020E61000000100000005000000D0D6C1C1DE836040B728B34126E34740D0D6C1C1DE836040D105F52D73E44740904AB1A371846040D105F52D73E44740904AB1A371846040B728B34126E34740D0D6C1C1DE836040B728B34126E34740
46246	Калинино	4	41	1696	132.590599	132.602125	48.014448999999999	48.003248999999997	0103000020E610000001000000050000009CC1DF2FE6926040525F96766A0048409CC1DF2FE6926040DE3AFF76D901484054E3A59B44936040DE3AFF76D901484054E3A59B44936040525F96766A0048409CC1DF2FE6926040525F96766A004840
23200	Дежнево	4	41	1696	132.17929699999999	132.210531	47.805084999999998	47.789723000000002	0103000020E61000000100000005000000ABE80FCDBC85604013F3ACA415E54740ABE80FCDBC85604005C078060DE747406AF981ABBC86604005C078060DE747406AF981ABBC86604013F3ACA415E54740ABE80FCDBC85604013F3ACA415E54740
46383	Горное	4	41	1696	132.424995	132.445953	48.144029000000003	48.124270000000003	0103000020E61000000100000005000000D53E1D8F998D6040DDEF5014E80F4840D53E1D8F998D60407A56D28A6F124840B3D1393F458E60407A56D28A6F124840B3D1393F458E6040DDEF5014E80F4840D53E1D8F998D6040DDEF5014E80F4840
46309	Воскресеновка	4	41	1696	132.876497	132.89527200000001	48.048830000000002	48.036932	0103000020E6100000010000000500000059C16F430C9C604083161230BA04484059C16F430C9C60402788BA0F40064840C9207711A69C60402788BA0F40064840C9207711A69C604083161230BA04484059C16F430C9C604083161230BA044840
23078	Венцелево	4	41	1696	131.92742699999999	131.94637299999999	47.791539	47.772539999999999	0103000020E61000000100000005000000AD4D637BAD7D6040096D3997E2E24740AD4D637BAD7D60401841632651E54740289A07B0487E60401841632651E54740289A07B0487E6040096D3997E2E24740AD4D637BAD7D6040096D3997E2E24740
22975	Биджан	4	41	1696	131.92391499999999	131.951583	47.991793000000001	47.95767	0103000020E6100000010000000500000015A930B6907D60401F2E39EE94FA474015A930B6907D60406CB3B112F3FE4740BF0D315E737E60406CB3B112F3FE4740BF0D315E737E60401F2E39EE94FA474015A930B6907D60401F2E39EE94FA4740
23638	Башмак	4	41	1696	132.02110300000001	132.041935	47.949300000000001	47.931482000000003	0103000020E610000001000000050000001FDB32E0AC80604006685BCD3AF747401FDB32E0AC806040E10B93A982F94740D9B1118857816040E10B93A982F94740D9B111885781604006685BCD3AF747401FDB32E0AC80604006685BCD3AF74740
22742	Бабстово	4	41	1696	132.459158	132.505439	48.142730999999998	48.106247000000003	0103000020E610000001000000050000004C361E6CB18E604029266F80990D48404C361E6CB18E60400C90680245124840EFE3688E2C9060400C90680245124840EFE3688E2C90604029266F80990D48404C361E6CB18E604029266F80990D4840
45900	Русская Поляна	4	41	1668	133.226966	133.23943399999999	48.324499000000003	48.316068999999999	0103000020E61000000100000005000000BA69334E43A76040C423F1F274284840BA69334E43A76040D84AE82E892948409DF17D71A9A76040D84AE82E892948409DF17D71A9A76040C423F1F274284840BA69334E43A76040C423F1F274284840
55696	Раздольное	4	41	1668	132.82701800000001	132.843807	48.865138000000002	48.832560999999998	0103000020E6100000010000000500000082E673EE769A60406876DD5B916A484082E673EE769A604070438CD7BC6E484059A48977009B604070438CD7BC6E484059A48977009B60406876DD5B916A484082E673EE769A60406876DD5B916A4840
21451	Птичник	4	41	1668	132.940924	132.96256500000001	48.761059000000003	48.72137	0103000020E61000000100000005000000B000A60C1C9E6040632827DA555C4840B000A60C1C9E6040CAA99D616A614840C7681D55CD9E6040CAA99D616A614840C7681D55CD9E6040632827DA555C4840B000A60C1C9E6040632827DA555C4840
45819	Пронькино	4	41	1668	132.97364099999999	132.99178699999999	48.621366999999999	48.609431000000001	0103000020E610000001000000050000006EA12B11289F60409415C3D5014E48406EA12B11289F604025E82FF4884F4840223317B8BC9F604025E82FF4884F4840223317B8BC9F60409415C3D5014E48406EA12B11289F60409415C3D5014E4840
45876	Петровка	4	41	1668	133.173687	133.18803299999999	48.406332999999997	48.397168999999998	0103000020E61000000100000005000000B1170AD88EA5604015FE0C6FD6324840B1170AD88EA560408D2441B8023448403332C85D04A660408D2441B8023448403332C85D04A6604015FE0C6FD6324840B1170AD88EA5604015FE0C6FD6324840
22178	Опытное Поле	4	41	1668	132.685677	132.70797300000001	48.412840000000003	48.401536	0103000020E61000000100000005000000D253E410F195604055151A8865334840D253E410F1956040863DEDF0D73448406F2EFEB6A7966040863DEDF0D73448406F2EFEB6A796604055151A8865334840D253E410F195604055151A8865334840
21755	Найфельд	4	41	1668	133.091814	133.11539500000001	48.498286	48.482396999999999	0103000020E6100000010000000500000014EAE923F0A260402158552FBF3D484014EAE923F0A26040FF06EDD5C73F4840E7E3DA50B1A36040FF06EDD5C73F4840E7E3DA50B1A360402158552FBF3D484014EAE923F0A260402158552FBF3D4840
22005	Надеждинское	4	41	1668	133.18078299999999	133.19606400000001	48.305881999999997	48.286802999999999	0103000020E6100000010000000500000087156EF9C8A5604085B2F0F5B524484087156EF9C8A56040B037312427274840897D022846A66040B037312427274840897D022846A6604085B2F0F5B524484087156EF9C8A5604085B2F0F5B5244840
46080	Красивое	4	41	1668	132.52837299999999	132.54251300000001	48.286425000000001	48.276375999999999	0103000020E61000000100000005000000DC627E6EE89060401CB3EC4960234840DC627E6EE8906040DFE00B93A9244840F51439445C916040DFE00B93A9244840F51439445C9160401CB3EC4960234840DC627E6EE89060401CB3EC4960234840
46112	Кирга	4	41	1668	132.84868499999999	132.87197900000001	48.888430999999997	48.871065000000002	0103000020E6100000010000000500000062F3716D289B60405AD8D30E7F6F484062F3716D289B604054E0641BB871484090F98040E79B604054E0641BB871484090F98040E79B60405AD8D30E7F6F484062F3716D289B60405AD8D30E7F6F4840
45939	Казанка	4	41	1668	133.04959400000001	133.066554	48.470368000000001	48.456871999999997	0103000020E610000001000000050000007E02284696A16040A33A1DC87A3A48407E02284696A16040DF8AC404353C484060ADDA3521A26040DF8AC404353C484060ADDA3521A26040A33A1DC87A3A48407E02284696A16040A33A1DC87A3A4840
62080	Заречное	4	41	1668	132.299994	133.34759199999999	48.960963	48.099556999999997	0103000020E61000000100000005000000E15F048D998960403F8BA548BE0C4840E15F048D9989604041D5E8D5007B48403D0B42791FAB604041D5E8D5007B48403D0B42791FAB60403F8BA548BE0C4840E15F048D998960403F8BA548BE0C4840
21685	Желтый Яр	4	41	1668	133.04265899999999	133.064694	48.577019999999997	48.562770999999998	0103000020E61000000100000005000000293C68765DA16040901150E108484840293C68765DA16040A79196CADB494840EBC726F911A26040A79196CADB494840EBC726F911A26040901150E108484840293C68765DA16040901150E108484840
45941	Дубовое	4	41	1668	133.10345599999999	133.12195299999999	48.408347999999997	48.381791999999997	0103000020E610000001000000050000006612F5824FA36040EDEF6C8FDE3048406612F5824FA3604089B14CBF44344840C554FA09E7A3604089B14CBF44344840C554FA09E7A36040EDEF6C8FDE3048406612F5824FA36040EDEF6C8FDE304840
45985	Головино	4	41	1668	133.18966800000001	133.20261300000001	48.209302999999998	48.200422000000003	0103000020E610000001000000050000002123A0C211A6604010B3976DA71948402123A0C211A6604033FAD170CA1A4840D31742CE7BA6604033FAD170CA1A4840D31742CE7BA6604010B3976DA71948402123A0C211A6604010B3976DA7194840
21530	Валдгейм	4	41	1668	132.96048099999999	132.988122	48.702471000000003	48.672606999999999	0103000020E61000000100000005000000BD6DA642BC9E6040C40776FC17564840BD6DA642BC9E6040B8B1D991EA594840A94E07B29E9F6040B8B1D991EA594840A94E07B29E9F6040C40776FC17564840BD6DA642BC9E6040C40776FC17564840
22120	Бирофельд	4	41	1668	132.783477	132.80994999999999	48.429575999999997	48.410812	0103000020E6100000010000000500000062855B3E12996040F566D47C9534484062855B3E12996040C092AB58FC364840A52C431CEB996040C092AB58FC364840A52C431CEB996040F566D47C9534484062855B3E12996040F566D47C95344840
46018	Алексеевка	4	41	1668	132.81772900000001	132.84086099999999	48.390982999999999	48.381402999999999	0103000020E61000000100000005000000B5FF01D62A9A604053CC41D0D1304840B5FF01D62A9A60405F251FBB0B3248406BEF5355E89A60405F251FBB0B3248406BEF5355E89A604053CC41D0D1304840B5FF01D62A9A604053CC41D0D1304840
3781	Ядрино	4	38	\N	131.01082199999999	131.04402400000001	48.986539999999998	48.969185000000003	0103000020E61000000100000005000000790261A7586060400B630B410E7C4840790261A758606040111956F1467E4840A70705A568616040111956F1467E4840A70705A5686160400B630B410E7C4840790261A7586060400B630B410E7C4840
6039	Шимановск	4	38	\N	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
55748	Чергали	4	38	\N	129.387674	129.409153	50.859059000000002	50.846730999999998	0103000020E610000001000000050000004EF04DD3672C604033C170AE616C49404EF04DD3672C6040D02A33A5F56D4940EE4108C8172D6040D02A33A5F56D4940EE4108C8172D604033C170AE616C49404EF04DD3672C604033C170AE616C4940
55733	Ушумун	4	38	\N	126.517224	126.556669	52.797134	52.768363999999998	0103000020E61000000100000005000000342DB1321AA15F403DB665C059624A40342DB1321AA15F40CC43A67C08664A409C6C0377A0A35F40CC43A67C08664A409C6C0377A0A35F403DB665C059624A40342DB1321AA15F403DB665C059624A40
3466	Тында	4	38	\N	124.68052	124.79870200000001	55.177864	55.102131999999997	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
55729	Сиваки	4	38	\N	126.729523	126.77889500000001	52.647165999999999	52.621451	0103000020E6100000010000000500000082AB3C81B0AE5F408388D4B48B4F4A4082AB3C81B0AE5F40A48AE255D6524A4026016A6AD9B15F40A48AE255D6524A4026016A6AD9B15F408388D4B48B4F4A4082AB3C81B0AE5F408388D4B48B4F4A40
7235	Свободный	4	38	\N	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
8466	Райчихинск	4	38	\N	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
55717	Прогресс	4	38	\N	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
55737	Новорайчихинск	4	38	\N	129.57268199999999	129.61483999999999	49.7958	49.769520999999997	0103000020E6100000010000000500000040A0336953326040E84A04AA7FE2484040A033695332604012143FC6DCE54840B988EFC4AC33604012143FC6DCE54840B988EFC4AC336040E84A04AA7FE2484040A0336953326040E84A04AA7FE24840
55701	Магдагачи	4	38	\N	125.785169	125.835313	53.470981999999999	53.434648000000003	0103000020E6100000010000000500000050357A3540725F40CBA2B08BA2B74A4050357A3540725F4099805F2349BC4A401D3BA8C475755F4099805F2349BC4A401D3BA8C475755F40CBA2B08BA2B74A4050357A3540725F40CBA2B08BA2B74A40
16732	Зея	4	38	\N	127.143557	127.314273	53.772472	53.707222000000002	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
55722	Ерофей Павлович	4	38	\N	121.93104599999999	121.97144400000001	53.971577000000003	53.945120000000003	0103000020E610000001000000050000009544F641967B5E40D46531B1F9F84A409544F641967B5E40DD4598A25CFC4A404F7974232C7E5E40DD4598A25CFC4A404F7974232C7E5E40D46531B1F9F84A409544F641967B5E40D46531B1F9F84A40
55725	Бурея	4	38	\N	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
55698	Благовещенск	4	38	\N	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
55699	Белогорск	4	38	\N	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
55741	Архара	4	38	\N	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
6663	Прогресс	4	38	881	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
55704	Прогресс	4	38	881	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
55735	Новорайчихинск	4	38	881	129.57268199999999	129.61483999999999	49.7958	49.769520999999997	0103000020E6100000010000000500000040A0336953326040E84A04AA7FE2484040A033695332604012143FC6DCE54840B988EFC4AC33604012143FC6DCE54840B988EFC4AC336040E84A04AA7FE2484040A0336953326040E84A04AA7FE24840
40273	Белогорск	4	38	6892	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
5998	Чагоян	4	38	709	128.20017300000001	128.241918	52.144948999999997	52.119259	0103000020E610000001000000050000005A1135D167066040786000E1430F4A405A1135D167066040404B57B08D124A400A4AD1CABD076040404B57B08D124A400A4AD1CABD076040786000E1430F4A405A1135D167066040786000E1430F4A40
5943	Ушаково	4	38	709	126.54921299999999	126.571905	51.887787000000003	51.864629000000001	0103000020E610000001000000050000006F62484E26A35F402B16BF29ACEE49406F62484E26A35F4030682101A3F14940CFDA6D179AA45F4030682101A3F14940CFDA6D179AA45F402B16BF29ACEE49406F62484E26A35F402B16BF29ACEE4940
5889	Ураловка	4	38	709	128.12040300000001	128.13894400000001	52.457653000000001	52.434230999999997	0103000020E61000000100000005000000E46A6457DA03604066F4A3E194374A40E46A6457DA03604049F59D5F943A4A4037FFAF3A7204604049F59D5F943A4A4037FFAF3A7204604066F4A3E194374A40E46A6457DA03604066F4A3E194374A40
5851	Симоново	4	38	709	126.982327	127.011639	51.475594000000001	51.463048999999998	0103000020E6100000010000000500000094BE1072DEBE5F4006B98B3045BB494094BE1072DEBE5F404016A243E0BC4940EC1681B1BEC05F404016A243E0BC4940EC1681B1BEC05F4006B98B3045BB494094BE1072DEBE5F4006B98B3045BB4940
5775	Селеткан	4	38	709	127.89382999999999	127.914177	51.925269999999998	51.911538	0103000020E61000000100000005000000C18BBE8234F95F40D787F546ADF44940C18BBE8234F95F4026FC523F6FF6494058703FE081FA5F4026FC523F6FF6494058703FE081FA5F40D787F546ADF44940C18BBE8234F95F40D787F546ADF44940
5743	Свободный Труд	4	38	709	127.278493	127.296109	51.970151000000001	51.958981000000001	0103000020E610000001000000050000008ECA4DD4D2D15F40213EB0E3BFFA49408ECA4DD4D2D15F40429770E82DFC494048C32973F3D25F40429770E82DFC494048C32973F3D25F40213EB0E3BFFA49408ECA4DD4D2D15F40213EB0E3BFFA4940
5679	Светильное	4	38	709	127.83010299999999	127.843273	51.954391000000001	51.950266999999997	0103000020E61000000100000005000000EF53556820F55F40E8BB5B59A2F94940EF53556820F55F40624CFA7B29FA49406326512FF8F55F40624CFA7B29FA49406326512FF8F55F40E8BB5B59A2F94940EF53556820F55F40E8BB5B59A2F94940
5630	Саскаль	4	38	709	126.90861099999999	126.930333	51.656652000000001	51.638807999999997	0103000020E610000001000000050000004B72C0AE26BA5F402A36E675C4D149404B72C0AE26BA5F402F6D382C0DD44940EF586C938ABB5F402F6D382C0DD44940EF586C938ABB5F402A36E675C4D149404B72C0AE26BA5F402A36E675C4D14940
5543	Петруши	4	38	709	127.647763	127.662271	52.062381000000002	52.043818000000002	0103000020E61000000100000005000000C423F1F274E95F40F27C06D49B054A40C423F1F274E95F402672C119FC074A40B685E7A562EA5F402672C119FC074A40B685E7A562EA5F40F27C06D49B054A40C423F1F274E95F40F27C06D49B054A40
5544	Новогеоргиевка	4	38	709	127.10023099999999	127.118278	51.860674000000003	51.837864000000003	0103000020E61000000100000005000000E7C2482F6AC65F40753FA7203FEB4940E7C2482F6AC65F403E42CD902AEE49408675E3DD91C75F403E42CD902AEE49408675E3DD91C75F40753FA7203FEB4940E7C2482F6AC65F40753FA7203FEB4940
5461	Нововоскресеновка	4	38	709	126.552789	126.58394199999999	52.114597000000003	52.095286000000002	0103000020E61000000100000005000000AB251DE560A35F4022E2E654320C4A40AB251DE560A35F40209C4F1DAB0E4A40B130444E5FA55F40209C4F1DAB0E4A40B130444E5FA55F4022E2E654320C4A40AB251DE560A35F4022E2E654320C4A40
5382	Мухино	4	38	709	127.194464	127.232607	52.282294	52.260393999999998	0103000020E61000000100000005000000F50F221972CC5F408D09319754214A40F50F221972CC5F40B3EDB43522244A4086747808E3CE5F40B3EDB43522244A4086747808E3CE5F408D09319754214A40F50F221972CC5F408D09319754214A40
5373	Малиновка	4	38	709	127.765326	127.779771	52.025086000000002	52.017726000000003	0103000020E61000000100000005000000D331E719FBF05F40FB2477D844024A40D331E719FBF05F4032CB9E0436034A40A1D79FC4E7F15F4032CB9E0436034A40A1D79FC4E7F15F40FB2477D844024A40D331E719FBF05F40FB2477D844024A40
5294	Кухтерин Луг	4	38	709	128.096283	128.11074600000001	52.425153999999999	52.413901000000003	0103000020E61000000100000005000000250516C0140360400F643DB5FA344A40250516C014036040BDE13E726B364A403605323B8B036040BDE13E726B364A403605323B8B0360400F643DB5FA344A40250516C0140360400F643DB5FA344A40
5232	Ключевое	4	38	709	127.216617	127.22743199999999	52.310670000000002	52.303229999999999	0103000020E610000001000000050000007DB08C0DDDCD5F4042959A3DD0264A407DB08C0DDDCD5F4096ECD808C4274A401684F23E8ECE5F4096ECD808C4274A401684F23E8ECE5F4042959A3DD0264A407DB08C0DDDCD5F4042959A3DD0264A40
5147	Берея	4	38	709	127.463842	127.484728	52.167127000000001	52.158194000000002	0103000020E61000000100000005000000B8205B96AFDD5F40333674B33F144A40B8205B96AFDD5F40A9A3E36A64154A4027DD96C805DF5F40A9A3E36A64154A4027DD96C805DF5F40333674B33F144A40B8205B96AFDD5F40333674B33F144A40
5069	Базисное	4	38	709	127.669628	127.681657	52.142721999999999	52.136381999999998	0103000020E61000000100000005000000191F662FDBEA5F40ACE122F774114A40191F662FDBEA5F40B935E9B644124A40BA85AE44A0EB5F40B935E9B644124A40BA85AE44A0EB5F40ACE122F774114A40191F662FDBEA5F40ACE122F774114A40
4984	Аносово	4	38	709	126.57991800000001	126.597911	52.169933	52.158161	0103000020E61000000100000005000000271763601DA55F405740A19E3E144A40271763601DA55F406EC1525DC0154A40CBBA7F2C44A65F406EC1525DC0154A40CBBA7F2C44A65F405740A19E3E144A40271763601DA55F405740A19E3E144A40
4949	Актай	4	38	709	127.23806	127.260535	51.741343000000001	51.735616	0103000020E61000000100000005000000179F02603CCF5F40093543AA28DE4940179F02603CCF5F402C0FD253E4DE4940A81DFE9AACD05F402C0FD253E4DE4940A81DFE9AACD05F40093543AA28DE4940179F02603CCF5F40093543AA28DE4940
61339	Усть-Уркима	4	38	419	123.156519	123.175797	55.318351999999997	55.307982000000003	0103000020E61000000100000005000000F88C446804CA5E40DBE044F46BA74B40F88C446804CA5E40DF4E22C2BFA84B40096F0F4240CB5E40DF4E22C2BFA84B40096F0F4240CB5E40DBE044F46BA74B40F88C446804CA5E40DBE044F46BA74B40
55720	Тында	4	38	419	119.656153	128.14549299999999	57.053058999999998	53.859296999999998	0103000020E61000000100000005000000070B2769FEE95D408446B071FDED4A40070B2769FEE95D4015E126A3CA864C408099EFE0A704604015E126A3CA864C408099EFE0A70460408446B071FDED4A40070B2769FEE95D408446B071FDED4A40
61333	Тутаул	4	38	419	127.44693599999999	127.46969900000001	55.030689000000002	55.015892999999998	0103000020E61000000100000005000000ECD973999ADC5F401F9E25C808824B40ECD973999ADC5F4069ACFD9DED834B40B1FD648C0FDE5F4069ACFD9DED834B40B1FD648C0FDE5F401F9E25C808824B40ECD973999ADC5F401F9E25C808824B40
55759	Первомайское	4	38	419	124.819948	124.85669799999999	55.117221000000001	55.106042000000002	0103000020E61000000100000005000000EB1A2D077A345F405000C5C8928D4B40EB1A2D077A345F40C4B30419018F4B401C23D923D4365F40C4B30419018F4B401C23D923D4365F405000C5C8928D4B40EB1A2D077A345F405000C5C8928D4B40
61297	Муртыгит	4	38	419	123.856217	123.87128199999999	54.437240000000003	54.421008999999998	0103000020E61000000100000005000000DF516342CCF65E402C29779FE3354B40DF516342CCF65E406440F67AF7374B40FBE59315C3F75E406440F67AF7374B40FBE59315C3F75E402C29779FE3354B40DF516342CCF65E402C29779FE3354B40
61557	Маревский сельсовет	4	38	419	119.656153	128.14549299999999	57.053058999999998	53.859296999999998	0103000020E61000000100000005000000070B2769FEE95D408446B071FDED4A40070B2769FEE95D4015E126A3CA864C408099EFE0A704604015E126A3CA864C408099EFE0A70460408446B071FDED4A40070B2769FEE95D408446B071FDED4A40
61563	Ларбинский сельсовет	4	38	419	119.656153	128.14549299999999	57.053058999999998	53.859296999999998	0103000020E61000000100000005000000070B2769FEE95D408446B071FDED4A40070B2769FEE95D4015E126A3CA864C408099EFE0A704604015E126A3CA864C408099EFE0A70460408446B071FDED4A40070B2769FEE95D408446B071FDED4A40
61303	Кувыкта	4	38	419	124.20170899999999	124.21955	55.214928	55.180089000000002	0103000020E61000000100000005000000C493DDCCE80C5F4047AF06280D974B40C493DDCCE80C5F40527FBDC2829B4B408E75711B0D0E5F40527FBDC2829B4B408E75711B0D0E5F4047AF06280D974B40C493DDCCE80C5F4047AF06280D974B40
61354	Аносовский	4	38	419	123.964051	123.976124	54.627412	54.622810000000001	0103000020E61000000100000005000000452BF702B3FD5E4096CFF23CB84F4B40452BF702B3FD5E40198F52094F504B40CE35CCD078FE5E40198F52094F504B40CE35CCD078FE5E4096CFF23CB84F4B40452BF702B3FD5E4096CFF23CB84F4B40
1301	Чуевка	4	38	243	128.18623099999999	128.22815600000001	50.160530000000001	50.147826000000002	0103000020E610000001000000050000000BD0B69AF5056040CFBF5DF6EB1249400BD0B69AF505604071033E3F8C1449405CCCCF0D4D07604071033E3F8C1449405CCCCF0D4D076040CFBF5DF6EB1249400BD0B69AF5056040CFBF5DF6EB124940
47548	Толстовка	4	38	243	127.919414	127.95672999999999	50.211239999999997	50.196209000000003	0103000020E61000000100000005000000035FD1ADD7FA5F40271763601D194940035FD1ADD7FA5F40B3CD8DE9091B4940884677103BFD5F40B3CD8DE9091B4940884677103BFD5F40271763601D194940035FD1ADD7FA5F40271763601D194940
47199	Тамбовка	4	38	243	128.03628499999999	128.083868	50.113138999999997	50.084519	0103000020E61000000100000005000000BB0A293F290160400072C284D10A4940BB0A293F290160407973B8567B0E4940CAA5F10BAF0260407973B8567B0E4940CAA5F10BAF0260400072C284D10A4940BB0A293F290160400072C284D10A4940
962	Свободка	4	38	243	127.96086200000001	127.98292499999999	49.974193999999997	49.959150999999999	0103000020E61000000100000005000000077E54C37EFD5F407D76C075C5FA4840077E54C37EFD5F40CEFA9463B2FC4840EE5A423EE8FE5F40CEFA9463B2FC4840EE5A423EE8FE5F407D76C075C5FA4840077E54C37EFD5F407D76C075C5FA4840
47493	Садовое	4	38	243	127.864158	127.881604	50.163144000000003	50.149766	0103000020E61000000100000005000000EA245B5D4EF75F40C00644882B134940EA245B5D4EF75F40F24410E7E114494075012F336CF85F40F24410E7E114494075012F336CF85F40C00644882B134940EA245B5D4EF75F40C00644882B134940
47598	Рощино	4	38	243	127.88751499999999	127.90467200000001	50.009960999999997	50.000385000000001	0103000020E6100000010000000500000067EDB60BCDF85F4059349D9D0C00494067EDB60BCDF85F40239EEC6646014940D8666325E6F95F40239EEC6646014940D8666325E6F95F4059349D9D0C00494067EDB60BCDF85F4059349D9D0C004940
1865	Резуновка	4	38	243	127.741062	127.761337	49.820717000000002	49.812823999999999	0103000020E61000000100000005000000BC934F8F6DEF5F40B3B3E89D0AE84840BC934F8F6DEF5F40B82231410DE94840060FD3BEB9F05F40B82231410DE94840060FD3BEB9F05F40B3B3E89D0AE84840BC934F8F6DEF5F40B3B3E89D0AE84840
55716	Раздольное	4	38	243	127.80744799999999	127.843093	50.032429	50.007651000000003	0103000020E610000001000000050000001E4E603AADF35F400F643DB5FA0049401E4E603AADF35F4093382BA226044940239F573CF5F55F4093382BA226044940239F573CF5F55F400F643DB5FA0049401E4E603AADF35F400F643DB5FA004940
47269	Придорожное	4	38	243	128.15566200000001	128.176377	50.070396000000002	50.057026	0103000020E610000001000000050000005CE7DF2EFB046040C782C2A04C0749405CE7DF2EFB04604076E272BC0209494088D860E1A405604076E272BC0209494088D860E1A4056040C782C2A04C0749405CE7DF2EFB046040C782C2A04C074940
55746	Привольное	4	38	243	128.136402	128.154269	49.974187999999998	49.965896999999998	0103000020E610000001000000050000007D23BA675D046040FA264D83A2FB48407D23BA675D046040EC134031B2FC48402CB98AC5EF046040EC134031B2FC48402CB98AC5EF046040FA264D83A2FB48407D23BA675D046040FA264D83A2FB4840
1478	Орлецкое	4	38	243	128.074274	128.090192	50.2089	50.198839	0103000020E610000001000000050000002E1EDE7360026040AD156D8E731949402E1EDE73600260403411363CBD1A49408C4B55DAE20260403411363CBD1A49408C4B55DAE2026040AD156D8E731949402E1EDE7360026040AD156D8E73194940
40510	Новоалександровка	4	38	243	128.26400699999999	128.291945	50.009689000000002	49.992114999999998	0103000020E6100000010000000500000048DDCEBE720860407E6FD39FFDFE484048DDCEBE72086040C310397D3D01494062670A9D57096040C310397D3D01494062670A9D570960407E6FD39FFDFE484048DDCEBE720860407E6FD39FFDFE4840
55740	Николаевка	4	38	243	127.655767	127.68083	50.073656999999997	50.049114000000003	0103000020E61000000100000005000000F2B22616F8E95F404CE3175E49064940F2B22616F8E95F408C0FB3976D094940AF08FEB792EB5F408C0FB3976D094940AF08FEB792EB5F404CE3175E49064940F2B22616F8E95F404CE3175E49064940
46089	Липовка	4	38	243	128.16309100000001	128.18214399999999	50.217269999999999	50.206167000000001	0103000020E61000000100000005000000B4E89D0A38056040D94125AE631A4940B4E89D0A380560407233DC80CF1B49403465A71FD40560407233DC80CF1B49403465A71FD4056040D94125AE631A4940B4E89D0A38056040D94125AE631A4940
1058	Лиманное	4	38	243	128.29916800000001	128.31083699999999	50.059201000000002	50.052070000000001	0103000020E610000001000000050000005000C5C892096040268DD13AAA0649405000C5C892096040FC71FBE59307494060AC6F60F2096040FC71FBE59307494060AC6F60F2096040268DD13AAA0649405000C5C892096040268DD13AAA064940
47558	Лермонтовка	4	38	243	127.848977	127.87310600000001	50.091495000000002	50.075778	0103000020E610000001000000050000009983A0A355F65F40CEE0EF17B30949409983A0A355F65F40AF5FB01BB60B494040FCFCF7E0F75F40AF5FB01BB60B494040FCFCF7E0F75F40CEE0EF17B30949409983A0A355F65F40CEE0EF17B3094940
47418	Лазаревка	4	38	243	128.325839	128.357585	50.230738000000002	50.218693000000002	0103000020E610000001000000050000005D18E9456D0A60409C6ED921FE1B49405D18E9456D0A6040E4F8A1D2881D494049111956710B6040E4F8A1D2881D494049111956710B60409C6ED921FE1B49405D18E9456D0A60409C6ED921FE1B4940
2090	Куропатино	4	38	243	127.65542600000001	127.680004	50.006348000000003	49.9863	0103000020E61000000100000005000000AEBCE47FF2E95F40BC0512143FFE4840AEBCE47FF2E95F409032E202D00049408C497F2F85EB5F409032E202D00049408C497F2F85EB5F40BC0512143FFE4840AEBCE47FF2E95F40BC0512143FFE4840
40404	Красное	4	38	243	127.505308	127.524694	49.996423999999998	49.971963000000002	0103000020E610000001000000050000000F9A5DF756E05F4006F6984869FC48400F9A5DF756E05F40897956D28AFF4840139A249694E15F40897956D28AFF4840139A249694E15F4006F6984869FC48400F9A5DF756E05F4006F6984869FC4840
55739	Косицыно	4	38	243	128.01502099999999	128.037803	50.070413000000002	50.052723	0103000020E610000001000000050000001AF8510D7B0060409E5F94A0BF0649401AF8510D7B0060404C1B0E4B030949401A16A3AE350160404C1B0E4B030949401A16A3AE350160409E5F94A0BF0649401AF8510D7B0060409E5F94A0BF064940
1983	Корфово	4	38	243	127.53895	127.55261400000001	49.904336999999998	49.887259	0103000020E61000000100000005000000780B24287EE25F40740AF2B391F14840780B24287EE25F4008C89750C1F34840F4531C075EE35F4008C89750C1F34840F4531C075EE35F40740AF2B391F14840780B24287EE25F40740AF2B391F14840
1183	Козьмодемьяновка	4	38	243	128.224006	128.26858899999999	50.147896000000003	50.131199000000002	0103000020E610000001000000050000007383A10E2B0760404B22FB20CB1049407383A10E2B076040C89A9141EE1249401762F54798086040C89A9141EE1249401762F547980860404B22FB20CB1049407383A10E2B0760404B22FB20CB104940
47311	Жариково	4	38	243	127.997648	128.03030200000001	50.031561000000004	50.004756	0103000020E61000000100000005000000DE3AFF76D9FF5F40DA3A38D89B004940DE3AFF76D9FF5F401F6ADB300A0449401C60E63BF80060401F6ADB300A0449401C60E63BF8006040DA3A38D89B004940DE3AFF76D9FF5F40DA3A38D89B004940
47726	Духовское	4	38	243	127.70501299999999	127.71484	49.957430000000002	49.945431999999997	0103000020E610000001000000050000004F90D8EE1EED5F40C24B70EA03F948404F90D8EE1EED5F40CA1AF5108DFA4840D97745F0BFED5F40CA1AF5108DFA4840D97745F0BFED5F40C24B70EA03F948404F90D8EE1EED5F40C24B70EA03F94840
1770	Гильчин	4	38	243	127.853657	127.881783	49.915139000000003	49.893439999999998	0103000020E610000001000000050000001840F850A2F65F401878EE3D5CF248401840F850A2F65F40A725564623F54840CDCAF6216FF85F40A725564623F54840CDCAF6216FF85F401878EE3D5CF248401840F850A2F65F401878EE3D5CF24840
55757	ж.д.ст.Мадалан	4	38	37	123.34451900000001	123.476319	54.101488000000003	54.023954000000003	0103000020E6100000010000000500000071766B990CD65E40E04DB7EC10034B4071766B990CD65E40DE770C8FFD0C4B40A9DDAF027CDE5E40DE770C8FFD0C4B40A9DDAF027CDE5E40E04DB7EC10034B4071766B990CD65E40E04DB7EC10034B40
55712	Уруша	4	38	37	122.86241099999999	122.91728000000001	54.060287000000002	54.029496999999999	0103000020E610000001000000050000007B2DE8BD31B75E40412AC58EC6034B407B2DE8BD31B75E40DEAF027CB7074B4098512CB7B4BA5E40DEAF027CB7074B4098512CB7B4BA5E40412AC58EC6034B407B2DE8BD31B75E40412AC58EC6034B40
32076	Уруша	4	38	37	122.86241099999999	122.91728000000001	54.060287000000002	54.029496999999999	0103000020E610000001000000050000007B2DE8BD31B75E40412AC58EC6034B407B2DE8BD31B75E40DEAF027CB7074B4098512CB7B4BA5E40DEAF027CB7074B4098512CB7B4BA5E40412AC58EC6034B407B2DE8BD31B75E40412AC58EC6034B40
32259	Тахтамыгда	4	38	37	123.582437	123.626311	54.119993000000001	54.102120999999997	0103000020E61000000100000005000000BEBED6A546E55E400E9E094D120D4B40BEBED6A546E55E40DD5F3DEE5B0F4B400188BB7A15E85E40DD5F3DEE5B0F4B400188BB7A15E85E400E9E094D120D4B40BEBED6A546E55E400E9E094D120D4B40
32462	Талдан	4	38	37	124.79263	124.832838	53.703805000000003	53.677743	0103000020E6100000010000000500000006F52D73BA325F40E50B5A48C0D64A4006F52D73BA325F4072E1404816DA4A406D37C1374D355F4072E1404816DA4A406D37C1374D355F40E50B5A48C0D64A4006F52D73BA325F40E50B5A48C0D64A40
175	Среднерейновский	4	38	37	123.83403800000001	123.842877	53.688478000000003	53.683459999999997	0103000020E61000000100000005000000C367EBE060F55E40E40F069E7BD74A40C367EBE060F55E40FC010F0C20D84A403D635FB2F1F55E40FC010F0C20D84A403D635FB2F1F55E40E40F069E7BD74A40C367EBE060F55E40E40F069E7BD74A40
32304	Солнечный	4	38	37	123.663151	123.678135	54.138131999999999	54.124152000000002	0103000020E61000000100000005000000D253E41071EA5E40D3DD7536E40F4B40D253E41071EA5E40FA43334FAE114B4078D1579066EB5E40FA43334FAE114B4078D1579066EB5E40D3DD7536E40F4B40D253E41071EA5E40D3DD7536E40F4B40
45	Сковородино	4	38	37	123.904349	123.987137	53.996434999999998	53.970412000000003	0103000020E61000000100000005000000E6CAA0DAE0F95E40AFD2DD7536FC4A40E6CAA0DAE0F95E407DCB9C2E8BFF4A40FBEAAA402DFF5E407DCB9C2E8BFF4A40FBEAAA402DFF5E40AFD2DD7536FC4A40E6CAA0DAE0F95E40AFD2DD7536FC4A40
18893	Орловка	4	38	37	123.689678	123.69696399999999	53.500627999999999	53.497616999999998	0103000020E6100000010000000500000053B131AF23EC5E408177F2E9B1BF4A4053B131AF23EC5E401FBB0B9414C04A40519FE40E9BEC5E401FBB0B9414C04A40519FE40E9BEC5E408177F2E9B1BF4A4053B131AF23EC5E408177F2E9B1BF4A40
32378	Невер	4	38	37	124.10272399999999	124.18000600000001	54.006855000000002	53.970688000000003	0103000020E61000000100000005000000EA20AF0793065F40514F1F813FFC4A40EA20AF0793065F403468E89FE0004B405DC5E237850B5F403468E89FE0004B405DC5E237850B5F40514F1F813FFC4A40EA20AF0793065F40514F1F813FFC4A40
2323	Лесной	4	38	37	123.815945	123.827758	53.885952000000003	53.875304999999997	0103000020E610000001000000050000006C95607138F45E403C8386FE09F04A406C95607138F45E40B4E908E066F14A4027C0B0FCF9F45E40B4E908E066F14A4027C0B0FCF9F45E403C8386FE09F04A406C95607138F45E403C8386FE09F04A40
55710	Ерофей Павлович	4	38	37	121.93104599999999	121.97144400000001	53.971577000000003	53.945120000000003	0103000020E610000001000000050000009544F641967B5E40D46531B1F9F84A409544F641967B5E40DD4598A25CFC4A404F7974232C7E5E40DD4598A25CFC4A404F7974232C7E5E40D46531B1F9F84A409544F641967B5E40D46531B1F9F84A40
462	Ерофей Павлович	4	38	37	121.93104599999999	121.97144400000001	53.971577000000003	53.945120000000003	0103000020E610000001000000050000009544F641967B5E40D46531B1F9F84A409544F641967B5E40DD4598A25CFC4A404F7974232C7E5E40DD4598A25CFC4A404F7974232C7E5E40D46531B1F9F84A409544F641967B5E40D46531B1F9F84A40
229	Джалинда	4	38	37	123.884101	123.915317	53.494816	53.466146999999999	0103000020E6100000010000000500000019575C1C95F85E40731074B4AABB4A4019575C1C95F85E40CEC4742156BF4A40431EC18D94FA5E40CEC4742156BF4A40431EC18D94FA5E40731074B4AABB4A4019575C1C95F85E40731074B4AABB4A40
32334	Бам	4	38	37	123.682528	123.709396	54.122394	54.112594000000001	0103000020E61000000100000005000000ADA6EB89AEEB5E40E8DCED7A690E4B40ADA6EB89AEEB5E40029D499BAA0F4B4072FA7ABE66ED5E40029D499BAA0F4B4072FA7ABE66ED5E40E8DCED7A690E4B40ADA6EB89AEEB5E40E8DCED7A690E4B40
404	Албазино	4	38	37	124.065219	124.096903	53.399534000000003	53.371558999999998	0103000020E61000000100000005000000FB04508C2C045F4069C4CC3E8FAF4A40FB04508C2C045F40EED11BEE23B34A4098F8A3A833065F40EED11BEE23B34A4098F8A3A833065F4069C4CC3E8FAF4A40FB04508C2C045F4069C4CC3E8FAF4A40
46504	Широкий Лог	4	38	1808	129.05554000000001	129.08473499999999	50.940372000000004	50.926329000000003	0103000020E61000000100000005000000D673D2FBC62160400F2BDCF291764940D673D2FBC62160407D09151C5E78494073BA2C26B62260407D09151C5E78494073BA2C26B62260400F2BDCF291764940D673D2FBC62160400F2BDCF291764940
46454	Фроловка	4	38	1808	128.743537	128.76076699999999	51.067571000000001	51.047088000000002	0103000020E61000000100000005000000B64B1B0ECB1760405C04C6FA06864940B64B1B0ECB1760403A94A12AA6884940081C0934581860403A94A12AA6884940081C0934581860405C04C6FA06864940B64B1B0ECB1760405C04C6FA06864940
55752	Украинка	4	38	1808	128.48978099999999	128.536089	51.153145000000002	51.141052999999999	0103000020E6100000010000000500000078263449AC0F6040580053060E92494078263449AC0F6040E1455F419A934940DA571EA427116040E1455F419A934940DA571EA427116040580053060E92494078263449AC0F6040580053060E924940
30986	Ударное	4	38	1808	128.31305499999999	128.32971900000001	51.097366999999998	51.089238000000002	0103000020E610000001000000050000002D5BEB8B040A6040BDC799266C8B49402D5BEB8B040A6040D55A9885768C4940D63BDC0E8D0A6040D55A9885768C4940D63BDC0E8D0A6040BDC799266C8B49402D5BEB8B040A6040BDC799266C8B4940
45877	Томское	4	38	1808	128.388182	128.424824	50.963807000000003	50.952204999999999	0103000020E61000000100000005000000AB5CA8FC6B0C6040390B7BDAE1794940AB5CA8FC6B0C6040F4531C075E7B4940CA518028980D6040F4531C075E7B4940CA518028980D6040390B7BDAE1794940AB5CA8FC6B0C6040390B7BDAE1794940
46143	Тавричанка	4	38	1808	128.31523799999999	128.352384	50.963030000000003	50.954242000000001	0103000020E610000001000000050000009B8E006E160A60401D3C139A247A49409B8E006E160A604090882991447B49404774CFBA460B604090882991447B49404774CFBA460B60401D3C139A247A49409B8E006E160A60401D3C139A247A4940
46390	Сосновка	4	38	1808	128.74751699999999	128.77900299999999	51.169401999999998	51.160184000000001	0103000020E610000001000000050000008786C5A8EB176040D6ABC8E8809449408786C5A8EB17604041F0F8F6AE9549408C0FB397ED18604041F0F8F6AE9549408C0FB397ED186040D6ABC8E8809449408786C5A8EB176040D6ABC8E880944940
46552	Соколовка	4	38	1808	129.194096	129.21346399999999	51.014114999999997	51.006169	0103000020E610000001000000050000001A89D00836266040E09F5225CA8049401A89D0083626604007B13385CE814940F25B74B2D426604007B13385CE814940F25B74B2D4266040E09F5225CA8049401A89D00836266040E09F5225CA804940
55703	Серышево	4	38	1808	128.358384	128.40905799999999	51.104861	51.078221999999997	0103000020E610000001000000050000001CEDB8E1770B6040F2E9B12D038A49401CEDB8E1770B60401CD0D2156C8D49405985CD00170D60401CD0D2156C8D49405985CD00170D6040F2E9B12D038A49401CEDB8E1770B6040F2E9B12D038A4940
55718	Серышево	4	38	1808	128.358384	128.40905799999999	51.104861	51.078221999999997	0103000020E610000001000000050000001CEDB8E1770B6040F2E9B12D038A49401CEDB8E1770B60401CD0D2156C8D49405985CD00170D60401CD0D2156C8D49405985CD00170D6040F2E9B12D038A49401CEDB8E1770B6040F2E9B12D038A4940
46208	Рождественка	4	38	1808	128.85809900000001	128.882237	50.913910000000001	50.901812999999997	0103000020E610000001000000050000005FB7088C751B6040C70DBF9B6E7349405FB7088C751B604062BEBC00FB74494047CA16493B1C604062BEBC00FB74494047CA16493B1C6040C70DBF9B6E7349405FB7088C751B6040C70DBF9B6E734940
46357	Поляна	4	38	1808	128.39352700000001	128.42533599999999	51.070802999999998	51.058309999999999	0103000020E61000000100000005000000FA62EFC5970C6040CF83BBB376874940FA62EFC5970C6040B6BA9C1210894940F7393E5A9C0D6040B6BA9C1210894940F7393E5A9C0D6040CF83BBB376874940FA62EFC5970C6040CF83BBB376874940
30677	Паруновка	4	38	1808	128.696133	128.732946	50.916772999999999	50.906044000000001	0103000020E610000001000000050000005395B6B846166040575EF23FF97349405395B6B8461660408B6D52D1587549407D772B4B741760408B6D52D1587549407D772B4B74176040575EF23FF97349405395B6B846166040575EF23FF9734940
46258	Озерное	4	38	1808	128.25815	128.27777	51.255755999999998	51.243172000000001	0103000020E61000000100000005000000CCEEC9C342086040C6A69542209F4940CCEEC9C342086040BDE0D39CBCA04940EB39E97DE3086040BDE0D39CBCA04940EB39E97DE3086040C6A69542209F4940CCEEC9C342086040C6A69542209F4940
55773	Новоохочье	4	38	1808	128.552448	128.57599200000001	51.221283999999997	51.217464999999997	0103000020E61000000100000005000000B3976DA7AD1160402783A3E4D59B4940B3976DA7AD1160406490BB08539C49403F58C6866E1260406490BB08539C49403F58C6866E1260402783A3E4D59B4940B3976DA7AD1160402783A3E4D59B4940
30292	Милехино	4	38	1808	128.940628	128.95939300000001	51.032544000000001	51.027894000000003	0103000020E610000001000000050000007636E49F191E604098E0D407928349407636E49F191E60402CD7DB662A8449405DE0F258B31E60402CD7DB662A8449405DE0F258B31E604098E0D407928349407636E49F191E604098E0D40792834940
55772	Липовка	4	38	1808	128.22855100000001	128.24560099999999	51.060456000000002	51.049715999999997	0103000020E61000000100000005000000FBCE2F4A50076040410B09185D864940FBCE2F4A500760406A6CAF05BD874940ADDBA0F6DB0760406A6CAF05BD874940ADDBA0F6DB076040410B09185D864940FBCE2F4A50076040410B09185D864940
55758	Лиманное	4	38	1808	128.81825900000001	128.85098500000001	51.270184	51.257919999999999	0103000020E610000001000000050000000C957F2D2F1A6040FE7DC68503A149400C957F2D2F1A604084F3A96395A249405F0CE5443B1B604084F3A96395A249405F0CE5443B1B6040FE7DC68503A149400C957F2D2F1A6040FE7DC68503A14940
46151	Лермонтово	4	38	1808	128.67565099999999	128.693196	51.350059999999999	51.338982000000001	0103000020E610000001000000050000004F90D8EE9E15604062F71DC363AB49404F90D8EE9E156040A2D11DC4CEAC4940FAB660A92E166040A2D11DC4CEAC4940FAB660A92E16604062F71DC363AB49404F90D8EE9E15604062F71DC363AB4940
46157	Лебяжье	4	38	1808	128.124122	128.17413999999999	50.992429000000001	50.976371	0103000020E61000000100000005000000DA56B3CEF8036040A4E194B9F97C4940DA56B3CEF80360400E4DD9E9077F49409D9D0C8E920560400E4DD9E9077F49409D9D0C8E92056040A4E194B9F97C4940DA56B3CEF8036040A4E194B9F97C4940
46016	Ключики	4	38	1808	128.21124	128.22073599999999	51.235514999999999	51.221617000000002	0103000020E610000001000000050000006D73637AC20660406B9E23F25D9C49406D73637AC2066040D55B035B259E494098A1F14410076040D55B035B259E494098A1F144100760406B9E23F25D9C49406D73637AC20660406B9E23F25D9C4940
46082	Казанка	4	38	1808	128.04499799999999	128.071732	51.075251000000002	51.062358000000003	0103000020E61000000100000005000000554CA59F700160406E52D158FB874940554CA59F70016040E3FE23D3A18949407442E8A04B026040E3FE23D3A18949407442E8A04B0260406E52D158FB874940554CA59F700160406E52D158FB874940
46320	Добрянка	4	38	1808	128.38900799999999	128.40493499999999	51.224443000000001	51.202404999999999	0103000020E610000001000000050000003CBCE7C0720C604000C63368E89949403CBCE7C0720C60407768588CBA9C49402FC03E3AF50C60407768588CBA9C49402FC03E3AF50C604000C63368E89949403CBCE7C0720C604000C63368E8994940
31133	Державинка	4	38	1808	128.83430300000001	128.86486400000001	51.165663000000002	51.156682000000004	0103000020E610000001000000050000008D7E349CB21A60409AEFE0270E9449408D7E349CB21A60402194F771349549409C6F44F7AC1B60402194F771349549409C6F44F7AC1B60409AEFE0270E9449408D7E349CB21A60409AEFE0270E944940
30213	Водораздельное	4	38	1808	128.91924800000001	128.934968	51.089022999999997	51.073785000000001	0103000020E610000001000000050000003B1DC87A6A1D6040BAF770C9718949403B1DC87A6A1D6040C0CB0C1B658B4940CFD90242EB1D6040C0CB0C1B658B4940CFD90242EB1D6040BAF770C9718949403B1DC87A6A1D6040BAF770C971894940
26814	Верное	4	38	1808	128.68324200000001	128.709608	51.198658000000002	51.181919999999998	0103000020E610000001000000050000001EA8531EDD156040813E9127499749401EA8531EDD1560405D8B16A06D9949405C1FD61BB51660405D8B16A06D9949405C1FD61BB5166040813E9127499749401EA8531EDD156040813E912749974940
55777	Введеновка	4	38	1808	128.20095499999999	128.21952300000001	51.318288000000003	51.304782000000003	0103000020E61000000100000005000000F71E2E396E0660406A34B91803A74940F71E2E396E066040C95A43A9BDA849400937195506076040C95A43A9BDA8494009371955060760406A34B91803A74940F71E2E396E0660406A34B91803A74940
49413	Бочкаревка	4	38	1808	128.42476099999999	128.47061099999999	50.965021	50.946035999999999	0103000020E61000000100000005000000B87361A4970D6040596B28B517794940B87361A4970D6040037AE1CE857B494069C4CC3E0F0F6040037AE1CE857B494069C4CC3E0F0F6040596B28B517794940B87361A4970D6040596B28B517794940
31240	Борисполь	4	38	1808	128.555125	128.582379	51.050621999999997	51.042744999999996	0103000020E6100000010000000500000025068195C3116040A4880CAB7885494025068195C3116040A33A1DC87A86494012DC48D9A2126040A33A1DC87A86494012DC48D9A2126040A4880CAB7885494025068195C3116040A4880CAB78854940
30125	Большая Сазанка	4	38	1808	128.139501	128.16238100000001	51.19679	51.166786999999999	0103000020E610000001000000050000004C18CDCA76046040F032C346599549404C18CDCA7604604005172B6A30994940BD8FA3393205604005172B6A30994940BD8FA33932056040F032C346599549404C18CDCA76046040F032C34659954940
46286	Белоногово	4	38	1808	128.342502	128.36152000000001	51.143076000000001	51.119247000000001	0103000020E61000000100000005000000111AC1C6F50A6040B492567C438F4940111AC1C6F50A6040D76B7A5050924940331B6492910B6040D76B7A5050924940331B6492910B6040B492567C438F4940111AC1C6F50A6040B492567C438F4940
48724	Белогорка	4	38	1808	128.586862	128.61502400000001	50.931449000000001	50.923546999999999	0103000020E610000001000000050000007C28D192C7126040D2A8C0C9367649407C28D192C71260402A7288B8397749402AC8CF46AE1360402A7288B8397749402AC8CF46AE136040D2A8C0C9367649407C28D192C7126040D2A8C0C936764940
55726	Арга	4	38	1808	128.17212799999999	128.25038000000001	51.289862999999997	51.256714000000002	0103000020E610000001000000050000003A5794128205604072361D01DCA049403A5794128205604004A9143B1AA5494052F2EA1C0308604004A9143B1AA5494052F2EA1C0308604072361D01DCA049403A5794128205604072361D01DCA04940
31114	Автономовка	4	38	1808	128.999629	129.032929	51.185923000000003	51.169604999999997	0103000020E6100000010000000500000043E4F4F5FC1F6040791EDC9DB595494043E4F4F5FC1F604080492A53CC974940E1421EC10D21604080492A53CC974940E1421EC10D216040791EDC9DB595494043E4F4F5FC1F6040791EDC9DB5954940
55724	Экимчан	4	38	1025	132.92833899999999	132.95901599999999	53.075536999999997	53.064776000000002	0103000020E610000001000000050000003E93FDF3B49D604069C878944A884A403E93FDF3B49D6040A8514832AB894A40E78A5242B09E6040A8514832AB894A40E78A5242B09E604069C878944A884A403E93FDF3B49D604069C878944A884A40
29490	Экимчан	4	38	1025	132.92833899999999	132.95901599999999	53.075536999999997	53.064776000000002	0103000020E610000001000000050000003E93FDF3B49D604069C878944A884A403E93FDF3B49D6040A8514832AB894A40E78A5242B09E6040A8514832AB894A40E78A5242B09E604069C878944A884A403E93FDF3B49D604069C878944A884A40
29755	Февральск	4	38	1025	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
55751	Февральск	4	38	1025	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
55702	Февральск	4	38	1025	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
55734	Токур	4	38	1025	132.86998399999999	132.89764299999999	53.148141000000003	53.121836999999999	0103000020E610000001000000050000006281AFE8D69B6040AC38D55A988F4A406281AFE8D69B60402F19C748F6924A40770FD07DB99C60402F19C748F6924A40770FD07DB99C6040AC38D55A988F4A406281AFE8D69B6040AC38D55A988F4A40
29693	Стойба	4	38	1025	131.68225000000001	131.72739000000001	52.798358999999998	52.782429999999998	0103000020E6100000010000000500000046B6F3FDD475604063B48EAA26644A4046B6F3FDD4756040CFBBB1A030664A4000AE64C746776040CFBBB1A030664A4000AE64C74677604063B48EAA26644A4046B6F3FDD475604063B48EAA26644A40
55731	Селемджинск	4	38	1025	131.115467	131.127522	52.575279000000002	52.570151000000003	0103000020E610000001000000050000008D98D9E7B16360400F643DB5FA484A408D98D9E7B1636040AD8905BEA2494A40A87004A914646040AD8905BEA2494A40A87004A9146460400F643DB5FA484A408D98D9E7B16360400F643DB5FA484A40
29316	Ольгинск	4	38	1025	133.41136299999999	133.42111	52.887093999999998	52.881110999999997	0103000020E610000001000000050000001AF9BCE229AD6040AB92C83EC8704A401AF9BCE229AD6040293DD34B8C714A4098C0ADBB79AD6040293DD34B8C714A4098C0ADBB79AD6040AB92C83EC8704A401AF9BCE229AD6040AB92C83EC8704A40
29582	Огоджа	4	38	1025	132.536134	132.555691	52.771464000000002	52.758343000000004	0103000020E61000000100000005000000C2887D02289160404513286211614A40C2887D02289160404B051555BF624A40CFF57D38C89160404B051555BF624A40CFF57D38C89160404513286211614A40C2887D02289160404513286211614A40
30031	Норск	4	38	1025	129.88555600000001	129.91095200000001	52.339984000000001	52.328808000000002	0103000020E61000000100000005000000DA588979563C6040E3546B61162A4A40DA588979563C6040E6948098842B4A403A07CF84263D6040E6948098842B4A403A07CF84263D6040E3546B61162A4A40DA588979563C6040E3546B61162A4A40
8932	Коболдо	4	38	1025	132.718897	132.735893	52.967730000000003	52.950305999999998	0103000020E610000001000000050000002906483401976040A69883A0A3794A402906483401976040D6AD9E93DE7B4A405F0B7A6F8C976040D6AD9E93DE7B4A405F0B7A6F8C976040A69883A0A3794A402906483401976040A69883A0A3794A40
30025	Иса	4	38	1025	131.02300299999999	131.033514	51.764330999999999	51.753120000000003	0103000020E61000000100000005000000B796C970BC60604055FB743C66E04940B796C970BC606040D4282499D5E14940A9BEF38B12616040D4282499D5E14940A9BEF38B1261604055FB743C66E04940B796C970BC60604055FB743C66E04940
29391	Ивановское	4	38	1025	133.401679	133.412576	52.867897999999997	52.859281000000003	0103000020E61000000100000005000000AE0FEB8DDAAC60407F8978EBFC6D4A40AE0FEB8DDAAC6040C4211B48176F4A40AA6395D233AD6040C4211B48176F4A40AA6395D233AD60407F8978EBFC6D4A40AE0FEB8DDAAC60407F8978EBFC6D4A40
55728	Златоустовск	4	38	1025	133.580839	133.60557	52.976275999999999	52.958936999999999	0103000020E61000000100000005000000B9A7AB3B96B2604051F69672BE7A4A40B9A7AB3B96B2604052EFA99CF67C4A400A2E56D460B3604052EFA99CF67C4A400A2E56D460B3604051F69672BE7A4A40B9A7AB3B96B2604051F69672BE7A4A40
55761	п.Орлиный	4	38	700	126.892792	128.69869299999999	51.947696999999998	50.887262999999997	0103000020E6100000010000000500000059880E8123B95F40B5F97FD59171494059880E8123B95F4037C2A2224EF94940361E6CB15B16604037C2A2224EF94940361E6CB15B166040B5F97FD59171494059880E8123B95F40B5F97FD591714940
27042	Юхта-3	4	38	700	128.15301199999999	128.16554300000001	51.478667999999999	51.467426000000003	0103000020E61000000100000005000000A8FC6B79E50460406AA67B9DD4BB4940A8FC6B79E504604024D236FE44BD49409E62D5204C05604024D236FE44BD49409E62D5204C0560406AA67B9DD4BB4940A8FC6B79E50460406AA67B9DD4BB4940
27175	Черновка	4	38	700	128.13774900000001	128.15629000000001	51.662444999999998	51.628923999999998	0103000020E61000000100000005000000D141977068046040B2D5E59480D04940D14197706804604009336DFFCAD4494024D6E2530005604009336DFFCAD4494024D6E25300056040B2D5E59480D04940D141977068046040B2D5E59480D04940
26337	Черниговка	4	38	700	128.243481	128.27321499999999	51.473652999999999	51.457746	0103000020E610000001000000050000005186AA98CA076040FAEFC16B97BA49405186AA98CA0760407E5358A9A0BC4940DA38622DBE0860407E5358A9A0BC4940DA38622DBE086040FAEFC16B97BA49405186AA98CA076040FAEFC16B97BA4940
26950	Усть-Пера	4	38	700	128.12938600000001	128.15946199999999	51.459204999999997	51.437072000000001	0103000020E61000000100000005000000EED11BEE23046040A8FFACF9F1B74940EED11BEE230460407094BC3AC7BA49408D5E0D501A0560407094BC3AC7BA49408D5E0D501A056040A8FFACF9F1B74940EED11BEE23046040A8FFACF9F1B74940
55714	Углегорск	4	38	700	128.104682	128.13192799999999	51.771163999999999	51.752473000000002	0103000020E610000001000000050000005BCF108E59036040BF0F070951E049405BCF108E5903604020ED7F80B5E24940A7AD11C13804604020ED7F80B5E24940A7AD11C138046040BF0F070951E049405BCF108E59036040BF0F070951E04940
28121	Талали	4	38	700	127.23677499999999	127.27759399999999	51.545347999999997	51.535674	0103000020E61000000100000005000000AA60545227CF5F40A4A833F790C44940AA60545227CF5F40317898F6CDC5494036E49F19C4D15F40317898F6CDC5494036E49F19C4D15F40A4A833F790C44940AA60545227CF5F40A4A833F790C44940
27680	Сычевка	4	38	700	127.44549000000001	127.48046100000001	51.156104999999997	51.140025000000001	0103000020E610000001000000050000007C2C7DE882DC5F40ABCFD556EC9149407C2C7DE882DC5F40FCDEA63FFB93494039807EDFBFDE5F40FCDEA63FFB93494039807EDFBFDE5F40ABCFD556EC9149407C2C7DE882DC5F40ABCFD556EC914940
27958	Сукромли	4	38	700	127.839742	127.86632299999999	51.529791000000003	51.521324	0103000020E61000000100000005000000F8C43A55BEF55F40594FADBEBAC24940F8C43A55BEF55F408A5B0531D0C34940723106D671F75F408A5B0531D0C34940723106D671F75F40594FADBEBAC24940F8C43A55BEF55F40594FADBEBAC24940
27547	Серебрянка	4	38	700	127.77220699999999	127.78850199999999	51.371536999999996	51.353197999999999	0103000020E6100000010000000500000081AFE8D66BF15F409D81919735AD494081AFE8D66BF15F40812040868EAF494028B517D176F25F40812040868EAF494028B517D176F25F409D81919735AD494081AFE8D66BF15F409D81919735AD4940
27916	Семеновка	4	38	700	127.74678400000001	127.76610700000001	51.540346	51.526710000000001	0103000020E61000000100000005000000454B1E4FCBEF5F40F33CB83B6BC34940454B1E4FCBEF5F402043C70E2AC54940268FA7E507F15F402043C70E2AC54940268FA7E507F15F40F33CB83B6BC34940454B1E4FCBEF5F40F33CB83B6BC34940
27449	Рогачевка	4	38	700	127.82227899999999	127.847872	51.281323	51.259419999999999	0103000020E61000000100000005000000014C1938A0F45F40D3F6AFAC34A14940014C1938A0F45F406A4E5E6402A449406CCCEB8843F65F406A4E5E6402A449406CCCEB8843F65F40D3F6AFAC34A14940014C1938A0F45F40D3F6AFAC34A14940
7438	Разливная	4	38	700	128.13526999999999	128.14664300000001	51.697738999999999	51.688070000000003	0103000020E610000001000000050000002844C02154046040EBAD81AD12D849402844C021540460406612F5824FD94940FF25A94CB10460406612F5824FD94940FF25A94CB1046040EBAD81AD12D849402844C02154046040EBAD81AD12D84940
26617	Подгорный	4	38	700	128.09120799999999	128.104467	51.321722000000001	51.303401999999998	0103000020E6100000010000000500000046240A2DEB0260403FC571E0D5A6494046240A2DEB026040AD33BE2F2EA949405C902DCB57036040AD33BE2F2EA949405C902DCB570360403FC571E0D5A6494046240A2DEB0260403FC571E0D5A64940
27878	Петропавловка	4	38	700	126.917523	126.933854	51.116804000000002	51.100088	0103000020E61000000100000005000000FB9463B2B8BA5F406C5CFFAECF8C4940FB9463B2B8BA5F406005F86EF38E4940484F9143C4BB5F406005F86EF38E4940484F9143C4BB5F406C5CFFAECF8C4940FB9463B2B8BA5F406C5CFFAECF8C4940
28085	Новостепановка	4	38	700	127.267309	127.293504	51.409855999999998	51.395494999999997	0103000020E610000001000000050000004B3B35971BD15F40A25D85949FB249404B3B35971BD15F40E108522976B44940B14F00C5C8D25F40E108522976B44940B14F00C5C8D25F40A25D85949FB249404B3B35971BD15F40A25D85949FB24940
27123	Новоострополь	4	38	700	128.27897300000001	128.29478399999999	51.671740999999997	51.664808000000001	0103000020E61000000100000005000000F2EEC858ED086040410FB56D18D54940F2EEC858ED086040F030ED9BFBD549404AECDADE6E096040F030ED9BFBD549404AECDADE6E096040410FB56D18D54940F2EEC858ED086040410FB56D18D54940
26532	Новоникольск	4	38	700	128.622624	128.64568399999999	51.621510000000001	51.614179	0103000020E610000001000000050000008DB62A89EC136040EB71DF6A9DCE49408DB62A89EC1360408811C2A38DCF49409DF17D71A91460408811C2A38DCF49409DF17D71A9146040EB71DF6A9DCE49408DB62A89EC136040EB71DF6A9DCE4940
27395	Новоивановка	4	38	700	127.971435	127.999948	51.406866999999998	51.393594999999998	0103000020E6100000010000000500000025CCB4FD2BFE5F403F6F2A5261B2494025CCB4FD2BFE5F402B69C53714B44940D76CE525FFFF5F402B69C53714B44940D76CE525FFFF5F403F6F2A5261B2494025CCB4FD2BFE5F403F6F2A5261B24940
26584	Новгородка	4	38	700	128.10137599999999	128.116603	51.239654000000002	51.226439999999997	0103000020E610000001000000050000002D93E1783E036040CC4065FCFB9C49402D93E1783E036040842D76FBAC9E4940B2F33636BB036040842D76FBAC9E4940B2F33636BB036040CC4065FCFB9C49402D93E1783E036040CC4065FCFB9C4940
27082	Нижние Бузули	4	38	700	128.17069900000001	128.22464299999999	51.633766000000001	51.616097000000003	0103000020E61000000100000005000000B8CEBF5D76056040F5143944DCCE4940B8CEBF5D760560408BA8893E1FD14940CF488446300760408BA8893E1FD14940CF48844630076040F5143944DCCE4940B8CEBF5D76056040F5143944DCCE4940
26851	Москвитино	4	38	700	127.958967	127.986051	51.151229999999998	51.137346000000001	0103000020E610000001000000050000005EBC1FB75FFD5F40431EC18D949149405EBC1FB75FFD5F40481630815B9349400A4CA7751BFF5F40481630815B9349400A4CA7751BFF5F40431EC18D949149405EBC1FB75FFD5F40431EC18D94914940
28002	Маркучи	4	38	700	127.694422	127.710537	51.581237999999999	51.568593	0103000020E61000000100000005000000DEE7F86871EC5F4005DEC9A7C7C84940DEE7F86871EC5F40A298BC0166CA494045662E7079ED5F40A298BC0166CA494045662E7079ED5F4005DEC9A7C7C84940DEE7F86871EC5F4005DEC9A7C7C84940
27636	Малый Эргель	4	38	700	127.679644	127.688924	51.273936999999997	51.266661999999997	0103000020E610000001000000050000000C3B8C497FEB5F40008BFCFA21A249400C3B8C497FEB5F4009151C5E10A349407D5BB05417EC5F4009151C5E10A349407D5BB05417EC5F40008BFCFA21A249400C3B8C497FEB5F40008BFCFA21A24940
26736	Малая Сазанка	4	38	700	128.06219200000001	128.08336499999999	51.239004999999999	51.217301999999997	0103000020E6100000010000000500000055C2137AFD0160407DAD4B8DD09B494055C2137AFD0160404D4A41B7979E4940319413EDAA0260404D4A41B7979E4940319413EDAA0260407DAD4B8DD09B494055C2137AFD0160407DAD4B8DD09B4940
27494	Костюковка	4	38	700	127.668092	127.690406	51.327046000000003	51.309235999999999	0103000020E6100000010000000500000008AEF204C2EA5F40785F950B95A7494008AEF204C2EA5F40D124B1A4DCA9494094BDA59C2FEC5F40D124B1A4DCA9494094BDA59C2FEC5F40785F950B95A7494008AEF204C2EA5F40785F950B95A74940
28036	Климоуцы	4	38	700	127.585887	127.62238600000001	51.482908999999999	51.448306000000002	0103000020E61000000100000005000000B309302C7FE55F40E04C4C1762B94940B309302C7FE55F40D7F84CF6CFBD494040DF162CD5E75F40D7F84CF6CFBD494040DF162CD5E75F40E04C4C1762B94940B309302C7FE55F40E04C4C1762B94940
55774	Источный	4	38	700	127.948241	127.96547	51.112082999999998	51.104663000000002	0103000020E610000001000000050000007CEE04FBAFFC5F40F60CE198658D49407CEE04FBAFFC5F4002B859BC588E494039D1AE42CAFD5F4002B859BC588E494039D1AE42CAFD5F40F60CE198658D49407CEE04FBAFFC5F40F60CE198658D4940
27596	Зиговка	4	38	700	127.615675	127.65468	51.352545999999997	51.345728000000001	0103000020E61000000100000005000000BF7D1D3867E75F40DFA7AAD040AC4940BF7D1D3867E75F40F52A323A20AD49401956F146E6E95F40F52A323A20AD49401956F146E6E95F40DFA7AAD040AC4940BF7D1D3867E75F40DFA7AAD040AC4940
27775	Загорная Селитьба	4	38	700	127.23808699999999	127.259907	51.151439000000003	51.127612999999997	0103000020E6100000010000000500000093A641D13CCF5F40B0C56E9F5590494093A641D13CCF5F40632B685A629349401840F850A2D05F40632B685A629349401840F850A2D05F40B0C56E9F5590494093A641D13CCF5F40B0C56E9F55904940
26480	Заган	4	38	700	128.49311399999999	128.502825	51.552869999999999	51.542144999999998	0103000020E6100000010000000500000064E60297C70F60404F58E20165C5494064E60297C70F60404278B471C4C649408F537424171060404278B471C4C649408F537424171060404F58E20165C5494064E60297C70F60404F58E20165C54940
26398	Желтоярово	4	38	700	128.430196	128.463874	51.536200999999998	51.520758000000001	0103000020E61000000100000005000000D7DB662AC40D6040B090B932A8C24940D7DB662AC40D60408F8AFF3BA2C44940DF6E490ED80E60408F8AFF3BA2C44940DF6E490ED80E6040B090B932A8C24940D7DB662AC40D6040B090B932A8C24940
26998	Дмитриевка	4	38	700	128.12488500000001	128.14664300000001	51.505147999999998	51.485202999999998	0103000020E610000001000000050000005AD8D30EFF036040E675C4211BBE49405AD8D30EFF036040E5D18DB0A8C04940FF25A94CB1046040E5D18DB0A8C04940FF25A94CB1046040E675C4211BBE49405AD8D30EFF036040E675C4211BBE4940
27734	Гуран	4	38	700	127.287997	127.301912	51.015757999999998	51.001793999999997	0103000020E610000001000000050000002716F88A6ED25F401DAA29C93A8049402716F88A6ED25F403F53AF5B048249404791B58652D35F403F53AF5B048249404791B58652D35F401DAA29C93A8049402716F88A6ED25F401DAA29C93A804940
27346	Голубое	4	38	700	127.95752899999999	127.976816	51.792197999999999	51.775511000000002	0103000020E610000001000000050000002EFEB62748FD5F401958C7F143E349402EFEB62748FD5F4072FA7ABE66E54940698D412784FE5F4072FA7ABE66E54940698D412784FE5F401958C7F143E349402EFEB62748FD5F401958C7F143E34940
27301	Глухари	4	38	700	128.06098800000001	128.07509200000001	51.752350999999997	51.738638000000002	0103000020E610000001000000050000005A2E1B9DF30160409BCAA2B08BDE49405A2E1B9DF3016040730E9E094DE049401F86562767026040730E9E094DE049401F865627670260409BCAA2B08BDE49405A2E1B9DF30160409BCAA2B08BDE4940
26434	Гащенка	4	38	700	128.35595900000001	128.38727399999999	51.515653	51.501537999999996	0103000020E61000000100000005000000F1F62004640B6040C2D9AD6532C04940F1F62004640B6040CA8AE1EA00C24940EA92718C640C6040CA8AE1EA00C24940EA92718C640C6040C2D9AD6532C04940F1F62004640B6040C2D9AD6532C04940
8841	Буссе	4	38	700	126.90214400000001	126.92611100000001	51.229768	51.208967999999999	0103000020E61000000100000005000000171230BABCB95F408CF4A276BF9A4940171230BABCB95F406BD5AE09699D4940D15D126745BB5F406BD5AE09699D4940D15D126745BB5F408CF4A276BF9A4940171230BABCB95F408CF4A276BF9A4940
26681	Бардагон	4	38	700	128.128128	128.14148599999999	51.289231999999998	51.274206999999997	0103000020E610000001000000050000007636E49F19046040C9AA083719A349407636E49F19046040747ADE8D05A54940F0DAA50D87046040747ADE8D05A54940F0DAA50D87046040C9AA083719A349407636E49F19046040C9AA083719A34940
25363	Смоляное	4	38	1030	129.46617800000001	129.47484700000001	50.862107000000002	50.853935999999997	0103000020E61000000100000005000000AC0320EEEA2E604043705CC64D6D4940AC0320EEEA2E60408B53AD85596E494052F355F2312F60408B53AD85596E494052F355F2312F604043705CC64D6D4940AC0320EEEA2E604043705CC64D6D4940
55763	Святоруссовка	4	38	1030	129.135445	129.17348000000001	50.638666999999998	50.623184000000002	0103000020E6100000010000000500000004ADC09055246040FBB1497EC44F494004ADC0905524604068041BD7BF51494053D0ED258D25604068041BD7BF51494053D0ED258D256040FBB1497EC44F494004ADC09055246040FBB1497EC44F4940
25789	Ромны	4	38	1030	129.277074	129.313267	50.738007000000003	50.705931	0103000020E610000001000000050000004D124BCADD286040C51D6FF25B5A49404D124BCADD2860400B9C6C03775E494050FD8348062A60400B9C6C03775E494050FD8348062A6040C51D6FF25B5A49404D124BCADD286040C51D6FF25B5A4940
26250	Рогозовка	4	38	1030	128.62108799999999	128.66542899999999	50.516731999999998	50.503632000000003	0103000020E6100000010000000500000004FEF0F3DF1360400B9C6C037740494004FEF0F3DF136040F965304624424940EB19C2314B156040F965304624424940EB19C2314B1560400B9C6C037740494004FEF0F3DF1360400B9C6C0377404940
9034	Поздеевка	4	38	1030	128.86490900000001	128.903806	50.600023	50.578417000000002	0103000020E6100000010000000500000084A0A355AD1B6040A8397991094A494084A0A355AD1B604085ECBC8DCD4C4940B77D8FFAEB1C604085ECBC8DCD4C4940B77D8FFAEB1C6040A8397991094A494084A0A355AD1B6040A8397991094A4940
25624	Новый Быт	4	38	1030	129.11136099999999	129.12386599999999	50.920383999999999	50.911309000000003	0103000020E6100000010000000500000098A1F1449023604076C6F7C5A574494098A1F144902360407EE19524CF754940C362D4B5F62360407EE19524CF754940C362D4B5F623604076C6F7C5A574494098A1F1449023604076C6F7C5A5744940
26042	Новороссийка	4	38	1030	128.83680899999999	128.859869	50.622304	50.612782000000003	0103000020E61000000100000005000000F3FFAA23C71A6040EBC9FCA36F4E4940F3FFAA23C71A6040C21550A8A74F4940043BFE0B841B6040C21550A8A74F4940043BFE0B841B6040EBC9FCA36F4E4940F3FFAA23C71A6040EBC9FCA36F4E4940
25567	Новониколаевка	4	38	1030	129.5318	129.53821400000001	50.750678000000001	50.738081000000001	0103000020E6100000010000000500000069006F810431604045662E70795E494069006F8104316040D1E9793716604940FB07910C39316040D1E9793716604940FB07910C3931604045662E70795E494069006F810431604045662E70795E4940
25855	Любимое	4	38	1030	129.192398	129.230433	50.630051999999999	50.613633999999998	0103000020E610000001000000050000001BBAD91F2826604059DB148F8B4E49401BBAD91F28266040C3633F8BA55049406ADD06B55F276040C3633F8BA55049406ADD06B55F27604059DB148F8B4E49401BBAD91F2826604059DB148F8B4E4940
8975	Каховка	4	38	1030	129.19948600000001	129.23281399999999	50.802663000000003	50.782541000000002	0103000020E6100000010000000500000051C0763062266040BB63B14D2A64494051C0763062266040C95A43A9BD664940A181583673276040C95A43A9BD664940A181583673276040BB63B14D2A64494051C0763062266040BB63B14D2A644940
25736	Калиновка	4	38	1030	129.36892599999999	129.394924	50.686618000000003	50.672817000000002	0103000020E610000001000000050000009C14E63DCE2B6040AF9811DE1E5649409C14E63DCE2B6040276C3F19E3574940FA0CA837A32C6040276C3F19E3574940FA0CA837A32C6040AF9811DE1E5649409C14E63DCE2B6040AF9811DE1E564940
25965	Знаменка	4	38	1030	129.01685900000001	129.09277499999999	50.627885999999997	50.616297000000003	0103000020E6100000010000000500000096B4E21B8A206040BCCFF1D1E24E494096B4E21B8A206040E1CE85915E5049405DDC4603F8226040E1CE85915E5049405DDC4603F8226040BCCFF1D1E24E494096B4E21B8A206040BCCFF1D1E24E4940
26162	Дальневосточное	4	38	1030	128.862672	128.89531700000001	50.524715999999998	50.509779000000002	0103000020E6100000010000000500000099654F029B1B6040039832704041494099654F029B1B60400ED8D5E429434940B151D66FA61C60400ED8D5E429434940B151D66FA61C6040039832704041494099654F029B1B60400398327040414940
26198	Григорьевка	4	38	1030	128.77402599999999	128.806231	50.528472000000001	50.510638	0103000020E610000001000000050000001E882CD2C4186040240C03965C4149401E882CD2C4186040056D72F8A4434940AF40F4A4CC196040056D72F8A4434940AF40F4A4CC196040240C03965C4149401E882CD2C4186040240C03965C414940
26280	Вознесеновка	4	38	1030	128.68107699999999	128.71100000000001	50.611626999999999	50.602612000000001	0103000020E61000000100000005000000D921FE61CB156040AD16D863224D4940D921FE61CB156040E02C25CB494E4940986E1283C0166040E02C25CB494E4940986E1283C0166040AD16D863224D4940D921FE61CB156040AD16D863224D4940
26001	Верхнебелое	4	38	1030	128.90306000000001	128.94572099999999	50.612651	50.606014000000002	0103000020E610000001000000050000006DCA15DEE51C60408675E3DD914D49406DCA15DEE51C60404C6E14596B4E49407EC4AF58431E60404C6E14596B4E49407EC4AF58431E60408675E3DD914D49406DCA15DEE51C60408675E3DD914D4940
25470	Братолюбовка	4	38	1030	129.41712100000001	129.42921200000001	50.795358999999998	50.775803000000003	0103000020E6100000010000000500000032AF230E592D6040C19140834D63494032AF230E592D604025CADE52CE654940A0E1CD1ABC2D604025CADE52CE654940A0E1CD1ABC2D6040C19140834D63494032AF230E592D6040C19140834D634940
25526	Амаранка	4	38	1030	129.581423	129.60691700000001	50.690942999999997	50.681731999999997	0103000020E610000001000000050000008D4468049B3260407E5182FE425749408D4468049B3260403733FAD1705849405E4C33DD6B3360403733FAD1705849405E4C33DD6B3360407E5182FE425749408D4468049B3260407E5182FE42574940
24240	Южный	4	38	978	128.99391600000001	129.010795	50.305705000000003	50.297269999999997	0103000020E61000000100000005000000145FED28CE1F60407C0A80F10C264940145FED28CE1F6040A29C685721274940BB7EC16E58206040A29C685721274940BB7EC16E582060407C0A80F10C264940145FED28CE1F60407C0A80F10C264940
49182	Черемушки	4	38	978	128.78050300000001	128.790762	50.295917000000003	50.291383000000003	0103000020E61000000100000005000000C26D6DE1F918604021CEC3094C254940C26D6DE1F91860404CAAB69BE02549406D1D1CEC4D1960404CAAB69BE02549406D1D1CEC4D19604021CEC3094C254940C26D6DE1F918604021CEC3094C254940
55776	Увальный	4	38	978	128.832156	128.84577400000001	50.090488999999998	50.077975000000002	0103000020E6100000010000000500000072A59E05A11A6040EB73B515FB09494072A59E05A11A6040E9D2BF24950B4940D4B9A294101B6040E9D2BF24950B4940D4B9A294101B6040EB73B515FB09494072A59E05A11A6040EB73B515FB094940
55771	Трудовой	4	38	978	128.714495	128.744696	50.026097999999998	50.014423999999998	0103000020E61000000100000005000000FA449E24DD166040852348A5D8014940FA449E24DD166040D93EE42D57034940C9AEB48CD4176040D93EE42D57034940C9AEB48CD4176040852348A5D8014940FA449E24DD166040852348A5D8014940
47107	Смелое	4	38	978	129.19891999999999	129.22078500000001	50.554771000000002	50.518816999999999	0103000020E61000000100000005000000A6D0798D5D266040EECD6F9868424940A6D0798D5D26604076E272BC02474940514EB4AB1027604076E272BC02474940514EB4AB10276040EECD6F9868424940A6D0798D5D266040EECD6F9868424940
24124	Сергее-Федоровка	4	38	978	129.172528	129.19376399999999	50.233457999999999	50.216346999999999	0103000020E610000001000000050000009EB47059852560403ACB2C42B11B49409EB4705985256040AA7EA5F3E11D49408C648F5033266040AA7EA5F3E11D49408C648F50332660403ACB2C42B11B49409EB47059852560403ACB2C42B11B4940
23959	Романовка	4	38	978	129.282544	129.31456	50.364075	50.335979999999999	0103000020E61000000100000005000000CBF5B6990A296040170E8464012B4940CBF5B6990A296040462575029A2E4940271422E0102A6040462575029A2E4940271422E0102A6040170E8464012B4940CBF5B6990A296040170E8464012B4940
55787	Прибрежный	4	38	978	129.169419	129.19264100000001	50.422913999999999	50.413294	0103000020E61000000100000005000000460A65E16B25604007D15AD1E6344940460A65E16B256040A182C30B22364940CD5B751D2A266040A182C30B22364940CD5B751D2A26604007D15AD1E6344940460A65E16B25604007D15AD1E6344940
23893	Преображеновка	4	38	978	128.631688	128.65329199999999	50.434379	50.425168999999997	0103000020E61000000100000005000000D2A8C0C936146040F22213F06B364940D2A8C0C936146040DB8827BB99374940A1D79FC4E7146040DB8827BB99374940A1D79FC4E7146040F22213F06B364940D2A8C0C936146040F22213F06B364940
23460	Покровка	4	38	978	128.62765400000001	128.662204	50.167130999999998	50.156385999999998	0103000020E610000001000000050000008466D7BD15146040B0C6D974041449408466D7BD15146040EA92718C64154940F96871C630156040EA92718C64154940F96871C630156040B0C6D974041449408466D7BD15146040B0C6D97404144940
23748	Песчаноозерка	4	38	978	128.64442600000001	128.71749500000001	50.339343	50.31897	0103000020E61000000100000005000000265646239F146040DB334B02D4284940265646239F146040329067976F2B4940650113B8F5166040329067976F2B4940650113B8F5166040DB334B02D4284940265646239F146040DB334B02D4284940
23836	Переясловка	4	38	978	128.776748	128.81229400000001	50.424101999999998	50.405171000000003	0103000020E6100000010000000500000078279F1EDB186040D124B1A4DC33494078279F1EDB18604087156EF9483649409697FC4FFE19604087156EF9483649409697FC4FFE196040D124B1A4DC33494078279F1EDB186040D124B1A4DC334940
24221	Панино	4	38	978	128.879865	128.897041	50.252336	50.237768000000003	0103000020E61000000100000005000000A4FCA4DA271C604086048C2E6F1E4940A4FCA4DA271C60403ECDC98B4C2049407AC5538FB41C60403ECDC98B4C2049407AC5538FB41C604086048C2E6F1E4940A4FCA4DA271C604086048C2E6F1E4940
24110	Новомихайловка	4	38	978	129.23791600000001	129.26585399999999	50.242187000000001	50.221787999999997	0103000020E610000001000000050000003FE603029D2760409752978C631C49403FE603029D2760401842CEFBFF1E494058703FE0812860401842CEFBFF1E494058703FE0812860409752978C631C49403FE603029D2760409752978C631C4940
23427	Николо-Александровка	4	38	978	128.475785	128.521537	50.174332	50.156184000000003	0103000020E61000000100000005000000ADDD76A1390F604049145AD6FD134940ADDD76A1390F6040B952CF8250164940EDD45C6EB0106040B952CF8250164940EDD45C6EB010604049145AD6FD134940ADDD76A1390F604049145AD6FD134940
55743	Нагорный	4	38	978	128.974952	128.99063699999999	50.405493	50.397430999999997	0103000020E610000001000000050000006F6589CE321F604052B5DD04DF3249406F6589CE321F6040E3E0D231E7334940A4A65D4CB31F6040E3E0D231E7334940A4A65D4CB31F604052B5DD04DF3249406F6589CE321F604052B5DD04DF324940
55738	Мухинский	4	38	978	128.668429	128.69633999999999	50.264062000000003	50.249687000000002	0103000020E6100000010000000500000056D636C563156040419E5DBEF51F494056D636C563156040E50E9BC8CC214940B1DCD26A48166040E50E9BC8CC214940B1DCD26A48166040419E5DBEF51F494056D636C563156040419E5DBEF51F4940
23989	Марьяновка	4	38	978	129.443433	129.45977300000001	50.320712	50.307937000000003	0103000020E61000000100000005000000F31E679A302E60403B1DC87A6A274940F31E679A302E6040A6B73F170D294940AFD2DD75B62E6040A6B73F170D294940AFD2DD75B62E60403B1DC87A6A274940F31E679A302E60403B1DC87A6A274940
23621	Максимовка	4	38	978	128.79315099999999	128.817127	50.170442999999999	50.153933000000002	0103000020E6100000010000000500000045B9347E6119604039639813B413494045B9347E61196040836A8313D1154940B7B585E7251A6040836A8313D1154940B7B585E7251A604039639813B413494045B9347E6119604039639813B4134940
20443	Короли	4	38	978	129.00885500000001	129.03383700000001	50.485346999999997	50.467415000000003	0103000020E61000000100000005000000FFEC478A4820604076543541D43B4940FFEC478A48206040191BBAD91F3E4940A20C553115216040191BBAD91F3E4940A20C55311521604076543541D43B4940FFEC478A4820604076543541D43B4940
23595	Ильиновка	4	38	978	128.538443	128.55976899999999	49.983955000000002	49.966000999999999	0103000020E610000001000000050000005378D0EC3A1160409F73B7EBA5FB48405378D0EC3A1160402BDEC83CF2FD4840118AADA0E91160402BDEC83CF2FD4840118AADA0E91160409F73B7EBA5FB48405378D0EC3A1160409F73B7EBA5FB4840
24419	Екатеринославка	4	38	978	129.071135	129.13511299999999	50.387163000000001	50.352789000000001	0103000020E610000001000000050000003B53E8BC46226040BCB1A030282D49403B53E8BC46226040529CA38E8E31494076887FD852246040529CA38E8E31494076887FD852246040BCB1A030282D49403B53E8BC46226040BCB1A030282D4940
45454	Георгиевка	4	38	978	129.08193299999999	129.10205500000001	50.531421000000002	50.516961999999999	0103000020E61000000100000005000000D26EF4319F2260402BA391CF2B424940D26EF4319F2260402DB4739A0544494096ECD808442360402DB4739A0544494096ECD808442360402BA391CF2B424940D26EF4319F2260402BA391CF2B424940
55715	Восточный	4	38	978	129.08632499999999	129.142236	50.364162	50.328505	0103000020E61000000100000005000000787AA52CC322604047C9AB730C2A4940787AA52CC3226040153944DC9C2E49400B0A83328D246040153944DC9C2E49400B0A83328D24604047C9AB730C2A4940787AA52CC322604047C9AB730C2A4940
23808	Варваровка	4	38	978	128.54348200000001	128.584913	50.357174000000001	50.333742999999998	0103000020E61000000100000005000000DFFE5C34641160406C223317B82A4940DFFE5C3464116040A27DACE0B72D49402BC0779BB7126040A27DACE0B72D49402BC0779BB71260406C223317B82A4940DFFE5C34641160406C223317B82A4940
23540	Борисоглебка	4	38	978	128.59515300000001	128.633026	50.046123000000001	50.026885	0103000020E61000000100000005000000B9E34D7E0B13604061E0B9F770034940B9E34D7E0B136040F54BC45BE705494091F0BDBF41146040F54BC45BE705494091F0BDBF4114604061E0B9F770034940B9E34D7E0B13604061E0B9F770034940
8194	Албазинка	4	38	978	129.02741399999999	129.044194	50.095793999999998	50.074778000000002	0103000020E610000001000000050000007B2E5393E0206040EB3A5453920949407B2E5393E0206040969350FA420C4940BE1589096A216040969350FA420C4940BE1589096A216040EB3A5453920949407B2E5393E0206040EB3A545392094940
55767	станция Воскресеновка	4	38	988	128.84857700000001	128.980378	49.871754000000003	49.786495000000002	0103000020E6100000010000000500000069E4F38A271B6040D8BB3FDEABE4484069E4F38A271B60401F1494A295EF4840F9F6AE415F1F60401F1494A295EF4840F9F6AE415F1F6040D8BB3FDEABE4484069E4F38A271B6040D8BB3FDEABE44840
55769	Ярославка	4	38	988	128.498369	128.51492500000001	49.920011000000002	49.903171	0103000020E61000000100000005000000E38A8BA3F20F60400AD9791B9BF34840E38A8BA3F20F6040EA7AA2EBC2F54840925CFE437A106040EA7AA2EBC2F54840925CFE437A1060400AD9791B9BF34840E38A8BA3F20F60400AD9791B9BF34840
22690	Шурино	4	38	988	128.836037	128.848299	49.783318999999999	49.773674999999997	0103000020E61000000100000005000000DFA7AAD0C01A6040CC5D4BC807E34840DFA7AAD0C01A6040EFAA07CC43E4484058C7F143251B6040EFAA07CC43E4484058C7F143251B6040CC5D4BC807E34840DFA7AAD0C01A6040CC5D4BC807E34840
22471	Шумиловка	4	38	988	129.04185000000001	129.05358200000001	49.900821000000001	49.889789999999998	0103000020E61000000100000005000000CEAACFD556216040672783A3E4F14840CEAACFD55621604067463F1A4EF34840F03499F1B621604067463F1A4EF34840F03499F1B6216040672783A3E4F14840CEAACFD556216040672783A3E4F14840
23291	Шадрино	4	38	988	128.826604	128.83971099999999	49.588585000000002	49.580443000000002	0103000020E61000000100000005000000C5573B8A731A60409818CBF44BCA4840C5573B8A731A604045F5D6C056CB4840ED629AE9DE1A604045F5D6C056CB4840ED629AE9DE1A60409818CBF44BCA4840C5573B8A731A60409818CBF44BCA4840
23239	Чесноково	4	38	988	128.80553900000001	128.82430500000001	49.571722000000001	49.545448999999998	0103000020E61000000100000005000000E294B9F9C61960406551D845D1C54840E294B9F9C6196040AD33BE2F2EC94840BD1DE1B4601A6040AD33BE2F2EC94840BD1DE1B4601A60406551D845D1C54840E294B9F9C61960406551D845D1C54840
22955	Черемисино	4	38	988	128.64069799999999	128.655844	49.745969000000002	49.731558999999997	0103000020E610000001000000050000009A93179980146040170CAEB9A3DD48409A93179980146040386A85E97BDF4840E4688EACFC146040386A85E97BDF4840E4688EACFC146040170CAEB9A3DD48409A93179980146040170CAEB9A3DD4840
22707	Привольное	4	38	988	128.86380399999999	128.87548200000001	49.672835999999997	49.667898000000001	0103000020E61000000100000005000000ED444948A41B60402B8881AE7DD54840ED444948A41B604025C9737D1FD6484093C7D3F2031C604025C9737D1FD6484093C7D3F2031C60402B8881AE7DD54840ED444948A41B60402B8881AE7DD54840
8362	Поярково	4	38	988	128.61974000000001	128.69544999999999	49.638457000000002	49.612791999999999	0103000020E61000000100000005000000BD00FBE8D41360400EA0DFF76FCE4840BD00FBE8D41360407E737FF5B8D148401AC05B20411660407E737FF5B8D148401AC05B20411660400EA0DFF76FCE4840BD00FBE8D41360400EA0DFF76FCE4840
22279	Петропавловка	4	38	988	128.879839	128.907174	49.984540000000003	49.971870000000003	0103000020E61000000100000005000000DA571EA4271C604055FB743C66FC4840DA571EA4271C60404BCD1E6805FE484002B9C491071D60404BCD1E6805FE484002B9C491071D604055FB743C66FC4840DA571EA4271C604055FB743C66FC4840
23176	Новочесноково	4	38	988	129.001138	129.018574	49.576161999999997	49.555736000000003	0103000020E610000001000000050000000D198F5209206040DD9A745B22C748400D198F5209206040569929ADBFC94840CA51802898206040569929ADBFC94840CA51802898206040DD9A745B22C748400D198F5209206040DD9A745B22C74840
55768	Нижняя Ильиновка	4	38	988	128.53089700000001	128.547121	49.920203000000001	49.906396999999998	0103000020E610000001000000050000006D91B41BFD106040A41820D104F448406D91B41BFD1060402E573F36C9F548408E3EE603821160402E573F36C9F548408E3EE60382116040A41820D104F448406D91B41BFD106040A41820D104F44840
22798	Нижнезавитинка	4	38	988	128.69228799999999	128.706616	49.838766	49.824598999999999	0103000020E6100000010000000500000039ED2939271660403BA8C4758CE9484039ED293927166040957F2DAF5CEB4840925A28999C166040957F2DAF5CEB4840925A28999C1660403BA8C4758CE9484039ED2939271660403BA8C4758CE94840
22223	Михайловка	4	38	988	128.82512199999999	128.86054300000001	49.931244999999997	49.901674	0103000020E61000000100000005000000B9A64066671A6040A6D3BA0D6AF34840B9A64066671A604021C8410933F74840A8397991891B604021C8410933F74840A8397991891B6040A6D3BA0D6AF34840B9A64066671A6040A6D3BA0D6AF34840
23096	Куприяново	4	38	988	128.998299	129.021377	49.470649000000002	49.461252000000002	0103000020E610000001000000050000002594BE10F21F6040789B374E0ABB48402594BE10F21F60409372F7393EBC48405F7CD11EAF2060409372F7393EBC48405F7CD11EAF206040789B374E0ABB48402594BE10F21F6040789B374E0ABB4840
22928	Красный Яр	4	38	988	128.729083	128.752475	49.847358	49.833483999999999	0103000020E610000001000000050000003A22DFA554176040A0DE8C9AAFEA48403A22DFA5541760408200193A76EC4840D8817346141860408200193A76EC4840D881734614186040A0DE8C9AAFEA48403A22DFA554176040A0DE8C9AAFEA4840
22813	Красный Восток	4	38	988	128.58626000000001	128.60921200000001	49.726818999999999	49.710039000000002	0103000020E610000001000000050000007FDE54A4C212604039F1D58EE2DA48407FDE54A4C2126040438EAD6708DD4840960A2AAA7E136040438EAD6708DD4840960A2AAA7E13604039F1D58EE2DA48407FDE54A4C212604039F1D58EE2DA4840
23342	Красная Орловка	4	38	988	128.754524	128.784976	49.607590999999999	49.597070000000002	0103000020E610000001000000050000008201840F251860401CB62DCA6CCC48408201840F25186040062CB98AC5CD4840A304FD851E196040062CB98AC5CD4840A304FD851E1960401CB62DCA6CCC48408201840F251860401CB62DCA6CCC4840
22747	Коршуновка	4	38	988	128.629873	128.65484599999999	49.783603999999997	49.760711000000001	0103000020E6100000010000000500000045F46BEB271460408E5A61FA5EE1484045F46BEB27146040E481C8224DE44840533D997FF4146040E481C8224DE44840533D997FF41460408E5A61FA5EE1484045F46BEB271460408E5A61FA5EE14840
23083	Калинино	4	38	988	129.27551	129.29203899999999	49.398342999999997	49.380000000000003	0103000020E6100000010000000500000012F758FAD0286040713D0AD7A3B0484012F758FAD028604096CB46E7FCB2484002452C625829604096CB46E7FCB2484002452C6258296040713D0AD7A3B0484012F758FAD0286040713D0AD7A3B04840
22546	Кавказ	4	38	988	128.95759699999999	128.97026299999999	49.751108000000002	49.731583000000001	0103000020E61000000100000005000000EDB776A2A41E6040A0A70183A4DD4840EDB776A2A41E6040CAE1934E24E048409AB0FD640C1F6040CAE1934E24E048409AB0FD640C1F6040A0A70183A4DD4840EDB776A2A41E6040A0A70183A4DD4840
55730	Зеленый Бор	4	38	988	128.62313599999999	128.64165	49.692863000000003	49.677126000000001	0103000020E61000000100000005000000BA9EE8BAF0136040BAA29410ACD64840BA9EE8BAF0136040E2CD1ABCAFD848404FAF946588146040E2CD1ABCAFD848404FAF946588146040BAA29410ACD64840BA9EE8BAF0136040BAA29410ACD64840
22650	Дубовое	4	38	988	128.762878	128.79405800000001	49.720185999999998	49.707931000000002	0103000020E61000000100000005000000D09A1F7F691860408C69A67B9DDA4840D09A1F7F69186040BE840A0E2FDC484012A452EC68196040BE840A0E2FDC484012A452EC681960408C69A67B9DDA4840D09A1F7F691860408C69A67B9DDA4840
23372	Дим	4	38	988	128.42487800000001	128.444299	49.663232999999998	49.641508000000002	0103000020E610000001000000050000004759BF99980D6040AA0F24EF1CD248404759BF99980D60406150A6D1E4D44840A85489B2370E60406150A6D1E4D44840A85489B2370E6040AA0F24EF1CD248404759BF99980D6040AA0F24EF1CD24840
46528	Воскресеновка	4	38	988	128.965349	128.98979199999999	49.845528000000002	49.821193999999998	0103000020E610000001000000050000003E079623E41E6040F1D58EE21CE948403E079623E41E604018EDF1423AEC4840F5BA4560AC1F604018EDF1423AEC4840F5BA4560AC1F6040F1D58EE21CE948403E079623E41E6040F1D58EE21CE94840
23008	Винниково	4	38	988	129.28719799999999	129.30240599999999	49.546162000000002	49.529798999999997	0103000020E61000000100000005000000402FDCB9302960400C3A2174D0C34840402FDCB930296040B328ECA2E8C54840A703594FAD296040B328ECA2E8C54840A703594FAD2960400C3A2174D0C34840402FDCB9302960400C3A2174D0C34840
22317	Арсентьевка	4	38	988	128.850967	128.88900100000001	49.991050000000001	49.967803000000004	0103000020E61000000100000005000000355F251F3B1B604040FCFCF7E0FB4840355F251F3B1B6040B459F5B9DAFE484090A339B2721C6040B459F5B9DAFE484090A339B2721C604040FCFCF7E0FB4840355F251F3B1B604040FCFCF7E0FB4840
20946	Юбилейное	4	38	1611	128.84014199999999	128.847948	51.549391999999997	51.538581999999998	0103000020E61000000100000005000000DFBF7971E21A60406D1B4641F0C44940DFBF7971E21A60408E57207A52C64940AD16D863221B60408E57207A52C64940AD16D863221B60406D1B4641F0C44940DFBF7971E21A60406D1B4641F0C44940
21145	Христиновка	4	38	1611	128.79438200000001	128.80688599999999	51.495241	51.486128000000001	0103000020E61000000100000005000000FFD0CC936B196040BFD53A7139BE4940FFD0CC936B196040B5519D0E64BF494035B39602D2196040B5519D0E64BF494035B39602D2196040BFD53A7139BE4940FFD0CC936B196040BFD53A7139BE4940
20615	Ульма	4	38	1611	129.568218	129.596622	51.943959999999997	51.929862999999997	0103000020E61000000100000005000000F4DF83D72E326040566133C005F74940F4DF83D72E326040B75D68AED3F849405F42058717336040B75D68AED3F849405F42058717336040566133C005F74940F4DF83D72E326040566133C005F74940
20555	Угловое	4	38	1611	129.35295400000001	129.374729	51.956471999999998	51.929729000000002	0103000020E61000000100000005000000C2DF2F664B2B60404792205C01F74940C2DF2F664B2B604015C5ABAC6DFA49409CFBABC7FD2B604015C5ABAC6DFA49409CFBABC7FD2B60404792205C01F74940C2DF2F664B2B60404792205C01F74940
20305	Таскино	4	38	1611	129.066104	129.09088	51.772730000000003	51.755299999999998	0103000020E6100000010000000500000050C422861D2260409B559FABADE0494050C422861D226040AD510FD1E8E24940897B2C7DE8226040AD510FD1E8E24940897B2C7DE82260409B559FABADE0494050C422861D2260409B559FABADE04940
21511	Сохатино	4	38	1611	128.84338500000001	128.85335599999999	51.687299000000003	51.671869000000001	0103000020E61000000100000005000000FC1D8A02FD1A60401E19ABCDFFD54940FC1D8A02FD1A604069C9E369F9D749400DFB3DB14E1B604069C9E369F9D749400DFB3DB14E1B60401E19ABCDFFD54940FC1D8A02FD1A60401E19ABCDFFD54940
21225	Сапроново	4	38	1611	128.84766099999999	128.87638000000001	51.418416999999998	51.404046999999998	0103000020E610000001000000050000000723F609201B60400186E5CFB7B349400723F609201B6040938B31B08EB54940CBDB114E0B1C6040938B31B08EB54940CBDB114E0B1C60400186E5CFB7B349400723F609201B60400186E5CFB7B34940
21033	Романкауцы	4	38	1611	129.048147	129.06243000000001	51.537702000000003	51.528182999999999	0103000020E61000000100000005000000D1CC936B8A216040CEA623809BC34940D1CC936B8A216040357F4C6BD3C449404209336DFF216040357F4C6BD3C449404209336DFF216040CEA623809BC34940D1CC936B8A216040CEA623809BC34940
20988	Раздольное	4	38	1611	129.018835	129.042991	51.553083000000001	51.543438000000002	0103000020E61000000100000005000000A5A0DB4B9A206040ABB35A608FC54940A5A0DB4B9A2060409E7C7A6CCBC64940B760A92E602160409E7C7A6CCBC64940B760A92E60216040ABB35A608FC54940A5A0DB4B9A206040ABB35A608FC54940
20254	Путятино	4	38	1611	129.044634	129.068602	51.762262999999997	51.750695	0103000020E61000000100000005000000454948A46D216040A72215C616E04940454948A46D216040B5F97FD591E14940164ED2FC31226040B5F97FD591E14940164ED2FC31226040A72215C616E04940454948A46D216040A72215C616E04940
21455	Практичи	4	38	1611	128.70756	128.74127300000001	51.651465999999999	51.630265999999999	0103000020E61000000100000005000000A67EDE54A4166040EFE3688EACD04940A67EDE54A41660405C3AE63C63D349400D8D2782B81760405C3AE63C63D349400D8D2782B8176040EFE3688EACD04940A67EDE54A4166040EFE3688EACD04940
21797	Поповка	4	38	1611	128.34360699999999	128.366083	51.400215000000003	51.378352	0103000020E61000000100000005000000A7751BD4FE0A604027309DD66DB04940A7751BD4FE0A6040302FC03E3AB34940E413B2F3B60B6040302FC03E3AB34940E413B2F3B60B604027309DD66DB04940A7751BD4FE0A604027309DD66DB04940
20202	Пионерский	4	38	1611	128.94765200000001	128.963067	51.717820000000003	51.711503	0103000020E61000000100000005000000A67F492A531E6040C100C28712DB4940A67F492A531E604016359886E1DB49406B9BE271D11E604016359886E1DB49406B9BE271D11E6040C100C28712DB4940A67F492A531E6040C100C28712DB4940
21540	Петровка	4	38	1611	128.58292700000001	128.598872	51.493653999999999	51.484793000000003	0103000020E61000000100000005000000931E8656A7126040352A70B20DBE4940931E8656A712604011C5E40D30BF4940AFCF9CF52913604011C5E40D30BF4940AFCF9CF529136040352A70B20DBE4940931E8656A7126040352A70B20DBE4940
21353	Паутовка	4	38	1611	129.080738	129.099063	51.333326999999997	51.321412000000002	0103000020E610000001000000050000006CB1DB67952260405F45460724A949406CB1DB6795226040D8EF8975AAAA4940CC272B862B236040D8EF8975AAAA4940CC272B862B2360405F45460724A949406CB1DB67952260405F45460724A94940
20668	Новороссийка	4	38	1611	129.45674600000001	129.47190900000001	52.156061999999999	52.141533000000003	0103000020E610000001000000050000008692C9A99D2E60400327DBC01D124A408692C9A99D2E6040FD12F1D6F9134A400536E7E0192F6040FD12F1D6F9134A400536E7E0192F60400327DBC01D124A408692C9A99D2E60400327DBC01D124A40
20022	Новокиевский Увал	4	38	1611	128.89639399999999	128.93175199999999	51.672629000000001	51.643161999999997	0103000020E61000000100000005000000944A7842AF1C6040D503E62153D24940944A7842AF1C6040ACAB02B518D6494071FF91E9D01D6040ACAB02B518D6494071FF91E9D01D6040D503E62153D24940944A7842AF1C6040D503E62153D24940
19950	Новокиевка	4	38	1611	128.907408	128.92475400000001	51.680950000000003	51.670791000000001	0103000020E610000001000000050000001F84807C091D6040BFB9BF7ADCD549401F84807C091D6040091B9E5E29D749400C5BB395971D6040091B9E5E29D749400C5BB395971D6040BFB9BF7ADCD549401F84807C091D6040BFB9BF7ADCD54940
21844	Молчаново	4	38	1611	128.31883199999999	128.36819399999999	51.378464000000001	51.361409999999999	0103000020E61000000100000005000000629D2ADF330A60404339D1AE42AE4940629D2ADF330A60404F5B238271B04940AB92C83EC80B60404F5B238271B04940AB92C83EC80B60404339D1AE42AE4940629D2ADF330A60404339D1AE42AE4940
21633	Михайловка	4	38	1611	128.65700200000001	128.67790600000001	51.455945	51.447687999999999	0103000020E6100000010000000500000003ED0E2906156040E46723D74DB9494003ED0E29061560402AE3DF675CBA49406478EC67B11560402AE3DF675CBA49406478EC67B1156040E46723D74DB9494003ED0E2906156040E46723D74DB94940
21421	Маргаритовка	4	38	1611	129.202226	129.22307599999999	51.341845999999997	51.325161000000001	0103000020E61000000100000005000000D40CA9A278266040A3772AE09EA94940D40CA9A2782660405B22179CC1AB4940B8904770232760405B22179CC1AB4940B890477023276040A3772AE09EA94940D40CA9A278266040A3772AE09EA94940
20733	Майский	4	38	1611	129.56875700000001	129.592544	52.292661000000003	52.279991000000003	0103000020E61000000100000005000000E04BE141333260405116BEBED6234A40E04BE1413332604047E867EA75254A401DAED51EF632604047E867EA75254A401DAED51EF63260405116BEBED6234A40E04BE141333260405116BEBED6234A40
20822	Мазаново	4	38	1611	128.80604199999999	128.842963	51.634168000000003	51.622981000000003	0103000020E610000001000000050000007AA69718CB196040C38366D7BDCF49407AA69718CB196040BA15C26A2CD149409E978A8DF91A6040BA15C26A2CD149409E978A8DF91A6040C38366D7BDCF49407AA69718CB196040C38366D7BDCF4940
21695	Леонтьевка	4	38	1611	128.517764	128.53458000000001	51.481887999999998	51.470959999999998	0103000020E610000001000000050000007AE1CE8591106040B1DCD26A48BC49407AE1CE8591106040DC2A8881AEBD4940102384471B116040DC2A8881AEBD4940102384471B116040B1DCD26A48BC49407AE1CE8591106040B1DCD26A48BC4940
21739	Красноярово	4	38	1611	128.386259	128.45155800000001	51.467055000000002	51.440688000000002	0103000020E610000001000000050000002499D53B5C0C6040ADDEE17668B849402499D53B5C0C604076374F75C8BB4940E947C329730E604076374F75C8BB4940E947C329730E6040ADDEE17668B849402499D53B5C0C6040ADDEE17668B84940
20386	Козловка	4	38	1611	129.19	129.20701399999999	51.835638000000003	51.821840000000002	0103000020E61000000100000005000000AE47E17A14266040B745990D32E94940AE47E17A14266040BEA59C2FF6EA49400DFAD2DB9F266040BEA59C2FF6EA49400DFAD2DB9F266040B745990D32E94940AE47E17A14266040B745990D32E94940
20768	Ивановский	4	38	1611	129.53496200000001	129.56045599999999	52.290253999999997	52.276122999999998	0103000020E610000001000000050000004AD3A0681E31604032569BFF57234A404AD3A0681E3160403FC4060B27254A401ADB6B41EF3160403FC4060B27254A401ADB6B41EF31604032569BFF57234A404AD3A0681E31604032569BFF57234A40
21084	Дружное	4	38	1611	129.001183	129.00792000000001	51.492415000000001	51.487031000000002	0103000020E61000000100000005000000F549EEB009206040B091240857BE4940F549EEB009206040A987687407BF4940809F71E140206040A987687407BF4940809F71E140206040B091240857BE4940F549EEB009206040B091240857BE4940
21313	Дмитриевка	4	38	1611	128.92356000000001	128.93868699999999	51.350425000000001	51.337114	0103000020E610000001000000050000009A7CB3CD8D1D60400A83328D26AB49409A7CB3CD8D1D6040B459F5B9DAAC4940C5C551B9091E6040B459F5B9DAAC4940C5C551B9091E60400A83328D26AB49409A7CB3CD8D1D60400A83328D26AB4940
20504	Богословка	4	38	1611	129.22150400000001	129.24926199999999	51.871847000000002	51.860035000000003	0103000020E61000000100000005000000DD7D8E8F162760402B357BA015EE4940DD7D8E8F16276040D00EB8AE98EF494056444DF4F9276040D00EB8AE98EF494056444DF4F92760402B357BA015EE4940DD7D8E8F162760402B357BA015EE4940
21265	Бичура	4	38	1611	128.839585	128.86388400000001	51.388356999999999	51.375202999999999	0103000020E61000000100000005000000CAA65CE1DD1A6040382EE3A606B04940CAA65CE1DD1A60401A16A3AEB5B1494035F10EF0A41B60401A16A3AEB5B1494035F10EF0A41B6040382EE3A606B04940CAA65CE1DD1A6040382EE3A606B04940
20868	Белоярово	4	38	1611	128.754784	128.79406700000001	51.602488999999998	51.583359000000002	0103000020E610000001000000050000006971C63027186040E469F981ABCA49406971C6302718604091990B5C1ECD4940A77A32FF6819604091990B5C1ECD4940A77A32FF68196040E469F981ABCA49406971C63027186040E469F981ABCA4940
21596	Антоновка	4	38	1611	128.565428	128.57465400000001	51.479162000000002	51.473221000000002	0103000020E61000000100000005000000C40776FC17126040E563778192BC4940C40776FC1712604034BE2F2E55BD49408010C9906312604034BE2F2E55BD49408010C99063126040E563778192BC4940C40776FC17126040E563778192BC4940
21174	Алексеевка	4	38	1611	128.775544	128.78722200000001	51.438684000000002	51.43139	0103000020E610000001000000050000007D93A641D118604025E99AC937B749407D93A641D1186040A5A31CCC26B84940231631EC30196040A5A31CCC26B84940231631EC3019604025E99AC937B749407D93A641D118604025E99AC937B74940
19196	Черняево	4	38	1578	125.986751	126.014482	52.804380000000002	52.777358999999997	0103000020E61000000100000005000000E692AAED267F5F402920ED7F80634A40E692AAED267F5F403BC780ECF5664A405D18E945ED805F403BC780ECF5664A405D18E945ED805F402920ED7F80634A40E692AAED267F5F402920ED7F80634A40
19630	Чалганы	4	38	1578	126.42698900000001	126.44257399999999	52.957667999999998	52.942768999999998	0103000020E610000001000000050000001DB0ABC9539B5F40605793A7AC784A401DB0ABC9539B5F407E3672DD947A4A40D503E621539C5F407E3672DD947A4A40D503E621539C5F40605793A7AC784A401DB0ABC9539B5F40605793A7AC784A40
19465	Ушумун	4	38	1578	126.517224	126.556669	52.797134	52.768363999999998	0103000020E61000000100000005000000342DB1321AA15F403DB665C059624A40342DB1321AA15F40CC43A67C08664A409C6C0377A0A35F40CC43A67C08664A409C6C0377A0A35F403DB665C059624A40342DB1321AA15F403DB665C059624A40
19713	Тыгда	4	38	1578	126.30533	126.34843100000001	53.125965000000001	53.096159999999998	0103000020E61000000100000005000000361FD7868A935F4078978BF84E8C4A40361FD7868A935F4067B8019F1F904A40687A89B14C965F4067B8019F1F904A40687A89B14C965F4078978BF84E8C4A40361FD7868A935F4078978BF84E8C4A40
19284	Толбузино	4	38	1578	125.42144999999999	125.46216200000001	53.140152999999998	53.129964000000001	0103000020E610000001000000050000008CB96B09F95A5F4024D40CA9A2904A408CB96B09F95A5F40D8B79388F0914A400EDDEC0F945D5F40D8B79388F0914A400EDDEC0F945D5F4024D40CA9A2904A408CB96B09F95A5F4024D40CA9A2904A40
19362	Сиваки	4	38	1578	126.729523	126.77889500000001	52.647165999999999	52.621451	0103000020E6100000010000000500000082AB3C81B0AE5F408388D4B48B4F4A4082AB3C81B0AE5F40A48AE255D6524A4026016A6AD9B15F40A48AE255D6524A4026016A6AD9B15F408388D4B48B4F4A4082AB3C81B0AE5F408388D4B48B4F4A40
55708	Магдагачи	4	38	1578	125.785169	125.835313	53.470981999999999	53.434648000000003	0103000020E6100000010000000500000050357A3540725F40CBA2B08BA2B74A4050357A3540725F4099805F2349BC4A401D3BA8C475755F4099805F2349BC4A401D3BA8C475755F40CBA2B08BA2B74A4050357A3540725F40CBA2B08BA2B74A40
18969	Магдагачи	4	38	1578	125.785169	125.835313	53.470981999999999	53.434648000000003	0103000020E6100000010000000500000050357A3540725F40CBA2B08BA2B74A4050357A3540725F4099805F2349BC4A401D3BA8C475755F4099805F2349BC4A401D3BA8C475755F40CBA2B08BA2B74A4050357A3540725F40CBA2B08BA2B74A40
19232	Кузнецово	4	38	1578	126.15107999999999	126.175676	52.567951000000001	52.560544	0103000020E6100000010000000500000019C5724BAB895F4009FCE1E7BF474A4019C5724BAB895F40815D4D9EB2484A404BAC8C463E8B5F40815D4D9EB2484A404BAC8C463E8B5F4009FCE1E7BF474A4019C5724BAB895F4009FCE1E7BF474A40
19793	Дактуй	4	38	1578	126.161519	126.18574599999999	53.344704	53.329535999999997	0103000020E61000000100000005000000B0ABC953568A5F40656D533C2EAA4A40B0ABC953568A5F407366BB421FAC4A4038D73043E38B5F407366BB421FAC4A4038D73043E38B5F40656D533C2EAA4A40B0ABC953568A5F40656D533C2EAA4A40
19900	Гудачи	4	38	1578	125.22629999999999	125.249109	53.691949000000001	53.680666000000002	0103000020E610000001000000050000006DC5FEB27B4E5F40E4BF401020D74A406DC5FEB27B4E5F40FDBFEAC891D84A40EA08E066F14F5F40FDBFEAC891D84A40EA08E066F14F5F40E4BF401020D74A406DC5FEB27B4E5F40E4BF401020D74A40
19856	Гонжа	4	38	1578	125.36606	125.387665	53.590640999999998	53.573621000000003	0103000020E61000000100000005000000EC17EC866D575F4040A6B5696CC94A40EC17EC866D575F409F56D11F9ACB4A407233DC80CF585F409F56D11F9ACB4A407233DC80CF585F4040A6B5696CC94A40EC17EC866D575F4040A6B5696CC94A40
23569	Средняя Полтавка	4	38	810	128.183671	128.19893400000001	49.825512000000003	49.807772	0103000020E61000000100000005000000284701A2E0056040F04FA91265E74840284701A2E0056040503A9160AAE948400002D6AA5D066040503A9160AAE948400002D6AA5D066040F04FA91265E74840284701A2E0056040F04FA91265E74840
8734	Семидомка	4	38	810	127.765011	127.79761999999999	49.750461999999999	49.736001999999999	0103000020E610000001000000050000002385B2F0F5F05F4032E5435035DE48402385B2F0F5F05F40047289230FE04840ACA8C1340CF35F40047289230FE04840ACA8C1340CF35F4032E5435035DE48402385B2F0F5F05F4032E5435035DE4840
45855	Октябрьское	4	38	810	127.864383	127.875055	49.693026000000003	49.680267999999998	0103000020E61000000100000005000000FA0D130D52F75F40F641960513D74840FA0D130D52F75F408CA37213B5D84840E2CCAFE600F85F408CA37213B5D84840E2CCAFE600F85F40F641960513D74840FA0D130D52F75F40F641960513D74840
55742	Новотроицкое	4	38	810	128.06676400000001	128.089743	49.822930999999997	49.800573999999997	0103000020E610000001000000050000009B9141EE220260409203763579E648409B9141EE22026040AAEE91CD55E948407041B62CDF026040AAEE91CD55E948407041B62CDF0260409203763579E648409B9141EE220260409203763579E64840
55756	Новопетровка	4	38	810	128.256866	128.28351900000001	49.581991000000002	49.565652	0103000020E610000001000000050000008AAE0B3F380860406075E44867C848408AAE0B3F380860407EC85BAE7ECA48406E197096120960407EC85BAE7ECA48406E197096120960406075E44867C848408AAE0B3F380860406075E44867C84840
5772	Нижняя Полтавка	4	38	810	128.22655700000001	128.250182	49.727395999999999	49.699086000000001	0103000020E61000000100000005000000C23577F43F076040B58B69A67BD94840C23577F43F076040E09EE74F1BDD48408881AE7D01086040E09EE74F1BDD48408881AE7D01086040B58B69A67BD94840C23577F43F076040B58B69A67BD94840
19589	Крестовоздвиженка	4	38	810	127.95187	127.990183	49.786273999999999	49.762211999999998	0103000020E61000000100000005000000C9022670EBFC5F40334FAE2990E14840C9022670EBFC5F40F9D85DA0A4E44840888384285FFF5F40F9D85DA0A4E44840888384285FFF5F40334FAE2990E14840C9022670EBFC5F40334FAE2990E14840
45804	Константиновка	4	38	810	127.963548	128.02076199999999	49.633217000000002	49.59843	0103000020E6100000010000000500000014083BC5AAFD5F40FF78AF5A99CC484014083BC5AAFD5F40B82231410DD14840FCDF1115AA006040B82231410DD14840FCDF1115AA006040FF78AF5A99CC484014083BC5AAFD5F40FF78AF5A99CC4840
31788	Коврижка	4	38	810	127.826429	127.854457	49.721933	49.708758000000003	0103000020E61000000100000005000000D3DD7536E4F45F40A2630795B8DA4840D3DD7536E4F45F409B73F04C68DC4840A6B5696CAFF65F409B73F04C68DC4840A6B5696CAFF65F40A2630795B8DA4840D3DD7536E4F45F40A2630795B8DA4840
45674	Ключи	4	38	810	128.060225	128.097092	49.739862000000002	49.723232000000003	0103000020E61000000100000005000000DAACFA5CED016040D9B5BDDD92DC4840DAACFA5CED016040CEC64ACCB3DE48408196AE601B036040CEC64ACCB3DE48408196AE601B036040D9B5BDDD92DC4840DAACFA5CED016040D9B5BDDD92DC4840
30128	Золотоножка	4	38	810	128.365409	128.37820099999999	49.846694999999997	49.828201999999997	0103000020E610000001000000050000004015376EB10B6040AB3DEC8502EA48404015376EB10B6040E657738060EC484010CAFB381A0C6040E657738060EC484010CAFB381A0C6040AB3DEC8502EA48404015376EB10B6040AB3DEC8502EA4840
29340	Зеньковка	4	38	810	128.36842799999999	128.38143500000001	49.921084	49.900286999999999	0103000020E61000000100000005000000C85D8429CA0B6040C901BB9A3CF34840C85D8429CA0B6040376F9C14E6F5484098512CB7340C6040376F9C14E6F5484098512CB7340C6040C901BB9A3CF34840C85D8429CA0B6040C901BB9A3CF34840
47101	Войково	4	38	810	128.17670000000001	128.19181	49.618161999999998	49.607194	0103000020E610000001000000050000008126C286A7056040E9297288B8CD48408126C286A7056040A2D0B2EE1FCF484077A1B94E23066040A2D0B2EE1FCF484077A1B94E23066040E9297288B8CD48408126C286A7056040E9297288B8CD4840
18743	Верхняя Полтавка	4	38	810	128.19017500000001	128.22336799999999	49.910190999999998	49.884253000000001	0103000020E610000001000000050000008AB0E1E915066040E831CA332FF148408AB0E1E915066040880E812381F4484022DFA5D425076040880E812381F4484022DFA5D425076040E831CA332FF148408AB0E1E915066040E831CA332FF14840
29483	Верхний Уртуй	4	38	810	127.986221	128.00493299999999	49.862400000000001	49.847793000000003	0103000020E610000001000000050000003868AF3E1EFF5F408D63247B84EC48403868AF3E1EFF5F4003098A1F63EE48407A3540692800604003098A1F63EE48407A354069280060408D63247B84EC48403868AF3E1EFF5F408D63247B84EC4840
18706	Черемхово	4	38	1397	127.78378600000001	127.806055	50.431595999999999	50.383792	0103000020E610000001000000050000000344C18C29F25F40B43BA418203149400344C18C29F25F40CE8AA8893E374940BFF1B56796F35F40CE8AA8893E374940BFF1B56796F35F40B43BA418203149400344C18C29F25F40B43BA41820314940
17590	Успеновка	4	38	1397	128.05976699999999	128.08155099999999	50.292856	50.277828	0103000020E6100000010000000500000029CC7B9CE9016040E0F42EDE8F23494029CC7B9CE9016040FC372F4E7C25494098BED7109C026040FC372F4E7C25494098BED7109C026040E0F42EDE8F23494029CC7B9CE9016040E0F42EDE8F234940
18340	Троицкое	4	38	1397	127.927543	127.95178900000001	50.771628	50.751857000000001	0103000020E610000001000000050000008FA850DD5CFB5F406422A5D93C6049408FA850DD5CFB5F40C556D0B4C462494053EC681CEAFC5F40C556D0B4C462494053EC681CEAFC5F406422A5D93C6049408FA850DD5CFB5F406422A5D93C604940
55744	Среднебелое-2	4	38	1397	127.659998	128.610793	50.812998999999998	50.205694000000001	0103000020E610000001000000050000003A5B40683DEA5F40E17D552E541A49403A5B40683DEA5F402157EA591068494006F4C29D8B1360402157EA591068494006F4C29D8B136040E17D552E541A49403A5B40683DEA5F40E17D552E541A4940
18264	Среднебелое	4	38	1397	128.02245099999999	128.075065	50.699798000000001	50.660656000000003	0103000020E6100000010000000500000066D828EBB7006040FEF334609054494066D828EBB700604032E719FB925949406002B7EE6602604032E719FB925949406002B7EE66026040FEF334609054494066D828EBB7006040FEF3346090544940
18100	Среднебелая	4	38	1397	127.98185599999999	128.024193	50.669682000000002	50.646225000000001	0103000020E6100000010000000500000068588CBAD6FE5F40C66D3480B752494068588CBAD6FE5F40255CC823B855494059F96530C6006040255CC823B855494059F96530C6006040C66D3480B752494068588CBAD6FE5F40C66D3480B7524940
18384	Солнечное	4	38	1397	127.972944	127.996202	50.608083000000001	50.597593000000003	0103000020E61000000100000005000000B935E9B644FE5F40C6A86BED7D4C4940B935E9B644FE5F407520EBA9D54D49406D8D08C6C1FF5F407520EBA9D54D49406D8D08C6C1FF5F40C6A86BED7D4C4940B935E9B644FE5F40C6A86BED7D4C4940
18429	Семиозерка	4	38	1397	127.809873	127.841081	50.655625000000001	50.634490999999997	0103000020E61000000100000005000000753A90F5D4F35F409C4D470037514940753A90F5D4F35F4052B81E85EB5349405E126745D4F55F4052B81E85EB5349405E126745D4F55F409C4D470037514940753A90F5D4F35F409C4D470037514940
17648	Правовосточное	4	38	1397	128.17728399999999	128.20134100000001	50.33222	50.320931000000002	0103000020E6100000010000000500000054C37E4FAC056040E4A25A441429494054C37E4FAC056040DF89592F862A4940024BAE6271066040DF89592F862A4940024BAE6271066040E4A25A441429494054C37E4FAC056040E4A25A4414294940
18578	Петропавловка	4	38	1397	127.79037099999999	127.809658	50.519665000000003	50.491553000000003	0103000020E610000001000000050000003C2D3F7095F25F4017A06D35EB3E49403C2D3F7095F25F401CF0F9618442494077BCC96FD1F35F401CF0F9618442494077BCC96FD1F35F4017A06D35EB3E49403C2D3F7095F25F4017A06D35EB3E4940
17975	Новопокровка	4	38	1397	128.20081999999999	128.230366	50.619782999999998	50.603549999999998	0103000020E610000001000000050000003F8C101E6D0660401AC05B20414D49403F8C101E6D066040F2CEA10C554F4940888384285F076040F2CEA10C554F4940888384285F0760401AC05B20414D49403F8C101E6D0660401AC05B20414D4940
18039	Новоалексеевка	4	38	1397	128.065507	128.10038800000001	50.565196999999998	50.546489000000001	0103000020E6100000010000000500000017D522A218026040D74FFF59F345494017D522A2180260400E66136058484940261DE560360360400E66136058484940261DE56036036040D74FFF59F345494017D522A218026040D74FFF59F3454940
17953	Николаевка	4	38	1397	128.324195	128.361996	50.605397000000004	50.592405999999997	0103000020E61000000100000005000000DB5031CE5F0A604022FAB5F5D34B4940DB5031CE5F0A60405B0C1EA67D4D49400DA9A278950B60405B0C1EA67D4D49400DA9A278950B604022FAB5F5D34B4940DB5031CE5F0A604022FAB5F5D34B4940
17476	Луговое	4	38	1397	128.108473	128.13860299999999	50.428806999999999	50.423051000000001	0103000020E61000000100000005000000F86F5E9C7803604022C5008926364940F86F5E9C78036040DFA5D425E336494014048F6F6F046040DFA5D425E336494014048F6F6F04604022C5008926364940F86F5E9C7803604022C5008926364940
15350	Крещеновка	4	38	1397	127.950424	127.96713200000001	50.276895000000003	50.268408999999998	0103000020E6100000010000000500000058552FBFD3FC5F40DD79E2395B22494058552FBFD3FC5F4085B69C4B7123494091BA9D7DE5FD5F4085B69C4B7123494091BA9D7DE5FD5F40DD79E2395B22494058552FBFD3FC5F40DD79E2395B224940
17839	Константиноградовка	4	38	1397	128.25980300000001	128.31797800000001	50.467823000000003	50.448112000000002	0103000020E61000000100000005000000E38C614E50086040FB78E8BB5B394940E38C614E5008604087A8C29FE13B49401FDB32E02C0A604087A8C29FE13B49401FDB32E02C0A6040FB78E8BB5B394940E38C614E50086040FB78E8BB5B394940
17342	Ивановка	4	38	1397	127.96568600000001	128.023888	50.372923999999998	50.348846000000002	0103000020E61000000100000005000000200DA7CCCDFD5F4093AB58FCA62C4940200DA7CCCDFD5F405EF23FF9BB2F49408A58C4B0C30060405EF23FF9BB2F49408A58C4B0C300604093AB58FCA62C4940200DA7CCCDFD5F4093AB58FCA62C4940
17891	Ерковцы	4	38	1397	128.386484	128.457999	50.485576000000002	50.460465999999997	0103000020E61000000100000005000000AC8DB1135E0C6040C075C58CF03A4940AC8DB1135E0C60407BDCB75A273E494039D384EDA70E60407BDCB75A273E494039D384EDA70E6040C075C58CF03A4940AC8DB1135E0C6040C075C58CF03A4940
17534	Дмитриевка	4	38	1397	127.914931	127.953649	50.415435000000002	50.400554999999997	0103000020E610000001000000050000002EC6C03A8EFA5F40E89FE062453349402EC6C03A8EFA5F40904E5DF92C3549403DB7D09508FD5F40904E5DF92C3549403DB7D09508FD5F40E89FE062453349402EC6C03A8EFA5F40E89FE06245334940
17742	Большеозерка	4	38	1397	128.142807	128.167969	50.392676999999999	50.388191999999997	0103000020E610000001000000050000007A54FCDF91046040CF488446B03149407A54FCDF9104604019726C3D43324940BD3786006005604019726C3D43324940BD37860060056040CF488446B03149407A54FCDF91046040CF488446B0314940
18665	Богородское	4	38	1397	127.804411	127.829474	50.455883999999998	50.439461999999999	0103000020E61000000100000005000000BB6246787BF35F40D9EA724A40384940BB6246787BF35F4084622B685A3A494078B81D1A16F55F4084622B685A3A494078B81D1A16F55F40D9EA724A40384940BB6246787BF35F40D9EA724A40384940
18493	Березовка	4	38	1397	127.842141	127.89286	50.588735	50.553054000000003	0103000020E61000000100000005000000BA675DA3E5F55F4004763579CA464940BA675DA3E5F55F405A8121AB5B4B494005FA449E24F95F405A8121AB5B4B494005FA449E24F95F4004763579CA464940BA675DA3E5F55F4004763579CA464940
17800	Анновка	4	38	1397	128.33061799999999	128.375542	50.388306	50.373112999999996	0103000020E61000000100000005000000012F336C940A6040315BB22AC22F4940012F336C940A6040986BD102B4314940C808A870040C6040986BD102B4314940C808A870040C6040315BB22AC22F4940012F336C940A6040315BB22AC22F4940
17686	Андреевка	4	38	1397	128.23034799999999	128.259929	50.293914999999998	50.281264	0103000020E610000001000000050000005ED6C4025F07604065C57075002449405ED6C4025F076040E466B8019F25494006499F5651086040E466B8019F25494006499F565108604065C57075002449405ED6C4025F07604065C5707500244940
15998	Юбилейный	4	38	1386	127.343118	127.370696	53.139175000000002	53.118043	0103000020E61000000100000005000000D02A33A5F5D55F40C84274081C8F4A40D02A33A5F5D55F40DDB5847CD0914A408330B77BB9D75F40DDB5847CD0914A408330B77BB9D75F40C84274081C8F4A40D02A33A5F5D55F40C84274081C8F4A40
15788	Чалбачи	4	38	1386	127.021871	127.056771	53.344194000000002	53.330354	0103000020E61000000100000005000000C66E9F5566C15F40280D350A49AA4A40C66E9F5566C15F405EBD8A8C0EAC4A401E17D522A2C35F405EBD8A8C0EAC4A401E17D522A2C35F40280D350A49AA4A40C66E9F5566C15F40280D350A49AA4A40
16328	Хвойный	4	38	1386	127.824929	127.84056	54.605673000000003	54.589852999999998	0103000020E61000000100000005000000682101A3CBF45F404739984D804B4B40682101A3CBF45F40FD885FB1864D4B40D9942BBCCBF55F40FD885FB1864D4B40D9942BBCCBF55F404739984D804B4B40682101A3CBF45F404739984D804B4B40
15886	Умлекан	4	38	1386	127.116535	127.146297	53.273307000000003	53.258398999999997	0103000020E61000000100000005000000B875374F75C75F40D828EB3713A14A40B875374F75C75F404A6249B9FBA24A4030A017EE5CC95F404A6249B9FBA24A4030A017EE5CC95F40D828EB3713A14A40B875374F75C75F40D828EB3713A14A40
16573	Тунгала	4	38	1386	129.420705	129.45190400000001	53.552537999999998	53.545380000000002	0103000020E610000001000000050000007008556A762D60403DF20703CFC54A407008556A762D60400CE6AF90B9C64A40D09D60FF752E60400CE6AF90B9C64A40D09D60FF752E60403DF20703CFC54A407008556A762D60403DF20703CFC54A40
55732	Сосновый Бор	4	38	1386	127.15942099999999	127.18461000000001	53.706662000000001	53.694146000000003	0103000020E61000000100000005000000EB5223F433CA5F401A53B0C6D9D84A40EB5223F433CA5F40B9A981E673DA4A40EF2076A6D0CB5F40B9A981E673DA4A40EF2076A6D0CB5F401A53B0C6D9D84A40EB5223F433CA5F401A53B0C6D9D84A40
16237	Снежногорский	4	38	1386	127.94738700000001	127.97745399999999	54.203598	54.184277000000002	0103000020E61000000100000005000000F56915FDA1FC5F40D733846396174B40F56915FDA1FC5F40F8C3CF7F0F1A4B400AD6389B8EFE5F40F8C3CF7F0F1A4B400AD6389B8EFE5F40D733846396174B40F56915FDA1FC5F40D733846396174B40
15855	Сиан	4	38	1386	126.939019	126.96682199999999	53.304575999999997	53.294432	0103000020E61000000100000005000000A6D425E318BC5F40AC72A1F2AFA54A40A6D425E318BC5F40C092AB58FCA64A4069C36169E0BD5F40C092AB58FCA64A4069C36169E0BD5F40AC72A1F2AFA54A40A6D425E318BC5F40AC72A1F2AFA54A40
15940	Рублевка	4	38	1386	127.168054	127.17735999999999	53.243141000000001	53.228940000000001	0103000020E61000000100000005000000917D9065C1CA5F40855FEAE74D9D4A40917D9065C1CA5F408BA8893E1F9F4A4096E7C1DD59CB5F408BA8893E1F9F4A4096E7C1DD59CB5F40855FEAE74D9D4A40917D9065C1CA5F40855FEAE74D9D4A40
16042	Поляковский	4	38	1386	127.527389	127.55241599999999	53.004192000000003	52.981301999999999	0103000020E610000001000000050000004AD1CABDC0E15F40ECBFCE4D9B7D4A404AD1CABDC0E15F40D2730B5D89804A406072A3C85AE35F40D2730B5D89804A406072A3C85AE35F40ECBFCE4D9B7D4A404AD1CABDC0E15F40ECBFCE4D9B7D4A40
16124	Октябрьский	4	38	1386	128.61055999999999	128.67034200000001	53.057026	53.000480000000003	0103000020E61000000100000005000000DD0720B589136040AB2688BA0F804A40DD0720B589136040C782C2A04C874A4054E4107173156040C782C2A04C874A4054E4107173156040AB2688BA0F804A40DD0720B589136040AB2688BA0F804A40
16548	Огорон	4	38	1386	129.130325	129.152432	53.966943000000001	53.955086999999999	0103000020E610000001000000050000003D9B559F2B246040D9EA724A40FA4A403D9B559F2B2460404E0CC9C9C4FB4A40A5DB12B9E02460404E0CC9C9C4FB4A40A5DB12B9E0246040D9EA724A40FA4A403D9B559F2B246040D9EA724A40FA4A40
15421	Овсянка	4	38	1386	126.875967	126.92308300000001	53.596606000000001	53.551949999999998	0103000020E610000001000000050000000458E4D70FB85F407B832F4CA6C64A400458E4D70FB85F40774CDD955DCC4A40971FB8CA13BB5F40774CDD955DCC4A40971FB8CA13BB5F407B832F4CA6C64A400458E4D70FB85F407B832F4CA6C64A40
15601	Николаевка 2-я	4	38	1386	127.02569800000001	127.038436	53.600116	53.592122000000003	0103000020E61000000100000005000000A6643909A5C15F40FE9E58A7CACB4A40A6643909A5C15F4036E7E099D0CC4A404DBF44BC75C25F4036E7E099D0CC4A404DBF44BC75C25F40FE9E58A7CACB4A40A6643909A5C15F40FE9E58A7CACB4A40
15507	Ивановка	4	38	1386	126.719067	126.738264	53.641880999999998	53.619722000000003	0103000020E610000001000000050000008028983105AE5F404D4EED0C53CF4A408028983105AE5F403E76172829D24A401BF4A5B73FAF5F403E76172829D24A401BF4A5B73FAF5F404D4EED0C53CF4A408028983105AE5F404D4EED0C53CF4A40
16080	Золотая Гора	4	38	1386	126.62282999999999	126.636602	54.285057999999999	54.276074000000001	0103000020E61000000100000005000000EE3D5C72DCA75F4051A3906456234B40EE3D5C72DCA75F4049BBD1C77C244B405DA45016BEA85F4049BBD1C77C244B405DA45016BEA85F4051A3906456234B40EE3D5C72DCA75F4051A3906456234B40
55727	Заречная Слобода	4	38	1386	127.246405	127.294878	53.735619999999997	53.707839999999997	0103000020E6100000010000000500000089247A19C5CF5F407B6649809ADA4A4089247A19C5CF5F404A24D1CB28DE4A40D593F947DFD25F404A24D1CB28DE4A40D593F947DFD25F407B6649809ADA4A4089247A19C5CF5F407B6649809ADA4A40
16640	Дугда	4	38	1386	129.99468400000001	130.00990100000001	53.357985999999997	53.343795999999998	0103000020E61000000100000005000000583B8A73D43F6040703FE08101AC4A40583B8A73D43F60408236397CD2AD4A4054E6E61B514060408236397CD2AD4A4054E6E61B51406040703FE08101AC4A40583B8A73D43F6040703FE08101AC4A40
15258	Гулик	4	38	1386	127.08662200000001	127.110328	53.753017	53.736865999999999	0103000020E610000001000000050000004E4700378BC55F4065C405A051DE4A404E4700378BC55F40802A6EDC62E04A4051F52B9D0FC75F40802A6EDC62E04A4051F52B9D0FC75F4065C405A051DE4A404E4700378BC55F4065C405A051DE4A40
16401	Горный	4	38	1386	128.40733399999999	128.42901900000001	54.654885999999998	54.639878000000003	0103000020E61000000100000005000000901150E1080D604007B7B585E7514B40901150E1080D6040DB4DF04DD3534B409BCB0D86BA0D6040DB4DF04DD3534B409BCB0D86BA0D604007B7B585E7514B40901150E1080D604007B7B585E7514B40
16483	Верхнезейск	4	38	1386	128.50932800000001	128.57168899999999	54.637157999999999	54.603789999999996	0103000020E61000000100000005000000FDDD3B6A4C1060406FD39FFD484D4B40FDDD3B6A4C1060404031B2648E514B4074CFBA464B1260404031B2648E514B4074CFBA464B1260406FD39FFD484D4B40FDDD3B6A4C1060406FD39FFD484D4B40
16429	Бомнак	4	38	1386	128.837447	128.858261	54.714193000000002	54.703187	0103000020E6100000010000000500000044A4A65DCC1A604076FC1708025A4B4044A4A65DCC1A60401D041DAD6A5B4B40D5CDC5DF761B60401D041DAD6A5B4B40D5CDC5DF761B604076FC1708025A4B4044A4A65DCC1A604076FC1708025A4B40
15698	Березовка	4	38	1386	126.959321	126.970613	53.471753999999997	53.455747000000002	0103000020E610000001000000050000006D57E88365BD5F400420EEEA55BA4A406D57E88365BD5F40EBE0606F62BC4A40A304FD851EBE5F40EBE0606F62BC4A40A304FD851EBE5F400420EEEA55BA4A406D57E88365BD5F400420EEEA55BA4A40
16264	Береговой	4	38	1386	127.465504	127.499838	54.367750999999998	54.349099000000002	0103000020E610000001000000050000000F0A4AD1CADD5F407D08AA46AF2C4B400F0A4AD1CADD5F402009FB76122F4B4013D38558FDDF5F402009FB76122F4B4013D38558FDDF5F407D08AA46AF2C4B400F0A4AD1CADD5F407D08AA46AF2C4B40
15558	Амуро-Балтийск	4	38	1386	126.787339	126.798828	53.514550999999997	53.500884999999997	0103000020E6100000010000000500000062F71DC363B25F404A07EBFF1CC04A4062F71DC363B25F40E28FA2CEDCC14A4043C879FF1FB35F40E28FA2CEDCC14A4043C879FF1FB35F404A07EBFF1CC04A4062F71DC363B25F404A07EBFF1CC04A40
15641	Александровка	4	38	1386	126.946844	126.965852	53.598908999999999	53.591625000000001	0103000020E610000001000000050000007C9A931799BC5F407D3F355EBACB4A407C9A931799BC5F40D923D40CA9CC4A40AD31E884D0BD5F40D923D40CA9CC4A40AD31E884D0BD5F407D3F355EBACB4A407C9A931799BC5F407D3F355EBACB4A40
15743	Алгач	4	38	1386	126.975024	126.99523600000001	53.398536	53.383124000000002	0103000020E610000001000000050000002B3410CB66BE5F4007280D350AB14A402B3410CB66BE5F40AB23473A03B34A4052F355F2B1BF5F40AB23473A03B34A4052F355F2B1BF5F4007280D350AB14A402B3410CB66BE5F4007280D350AB14A40
55760	Червоная Армия	4	38	966	129.439246	129.49319	50.153812000000002	50.129744000000002	0103000020E61000000100000005000000C39CA04D0E2E6040166D8E739B104940C39CA04D0E2E6040BEDD921CB0134940DB166536C82F6040BEDD921CB0134940DB166536C82F6040166D8E739B104940C39CA04D0E2E6040166D8E739B104940
14124	Федоровка	4	38	966	129.263958	129.28149300000001	49.924106000000002	49.914275000000004	0103000020E6100000010000000500000090300C5872286040744694F606F5484090300C5872286040C904FC1A49F64840B2A19BFD01296040C904FC1A49F64840B2A19BFD01296040744694F606F5484090300C5872286040744694F606F54840
14459	Успеновка	4	38	966	129.24365599999999	129.255334	50.118389000000001	50.091656	0103000020E610000001000000050000002CEFAA07CC276040B83D4162BB0B49402CEFAA07CC276040639AE95E270F4940D27135B22B286040639AE95E270F4940D27135B22B286040B83D4162BB0B49402CEFAA07CC276040B83D4162BB0B4940
14232	Преображеновка	4	38	966	129.42839499999999	129.44419600000001	50.047026000000002	50.034771999999997	0103000020E61000000100000005000000A3586E69B52D60408368AD6873044940A3586E69B52D6040E607AEF20406494073A087DA362E6040E607AEF20406494073A087DA362E60408368AD6873044940A3586E69B52D60408368AD6873044940
14172	Подоловка	4	38	966	129.18337	129.202451	49.894699000000003	49.883800000000001	0103000020E610000001000000050000002922C32ADE256040371AC05B20F148402922C32ADE256040C861307F85F248405C01857A7A266040C861307F85F248405C01857A7A266040371AC05B20F148402922C32ADE256040371AC05B20F14840
55753	Новоалексеевка	4	38	966	129.320336	129.35785899999999	50.211787999999999	50.206679999999999	0103000020E6100000010000000500000068774831402A60405F5E807D741A494068774831402A6040B6D782DE1B1B494089B2B794732B6040B6D782DE1B1B494089B2B794732B60405F5E807D741A494068774831402A60405F5E807D741A4940
13976	Ленино	4	38	966	129.30951200000001	129.32432499999999	49.815671999999999	49.809981000000001	0103000020E6100000010000000500000007B7B585E7296040D1B01875ADE7484007B7B585E7296040A721AAF067E84840CE88D2DE602A6040A721AAF067E84840CE88D2DE602A6040D1B01875ADE7484007B7B585E7296040D1B01875ADE74840
8062	Куприяновка	4	38	966	129.324828	129.34141099999999	49.965839000000003	49.951061000000003	0103000020E61000000100000005000000679AB0FD642A604023C0E95DBCF94840679AB0FD642A6040C619C39CA0FB4840D4EFC2D6EC2A6040C619C39CA0FB4840D4EFC2D6EC2A604023C0E95DBCF94840679AB0FD642A604023C0E95DBCF94840
8142	Камышенка	4	38	966	129.321774	129.34397999999999	50.097146000000002	50.089801000000001	0103000020E6100000010000000500000080D6FCF84B2A6040F51263997E0B494080D6FCF84B2A6040F777B6476F0C49404C4F58E2012B6040F777B6476F0C49404C4F58E2012B6040F51263997E0B494080D6FCF84B2A6040F51263997E0B4940
14320	Иннокентьевка	4	38	966	129.169545	129.18717000000001	49.977170999999998	49.966023999999997	0103000020E6100000010000000500000069C6A2E96C2560405793A7ACA6FB484069C6A2E96C256040C0CC77F013FD48405B99F04BFD256040C0CC77F013FD48405B99F04BFD2560405793A7ACA6FB484069C6A2E96C2560405793A7ACA6FB4840
14592	Завитинск	4	38	966	129.41032100000001	129.468154	50.135038999999999	50.077067	0103000020E61000000100000005000000967B8159212D6040E84CDA54DD094940967B8159212D60409F573CF548114940BBEF181EFB2E60409F573CF548114940BBEF181EFB2E6040E84CDA54DD094940967B8159212D6040E84CDA54DD094940
14363	Демьяновка	4	38	966	129.21965299999999	129.22663299999999	49.997767000000003	49.986421999999997	0103000020E61000000100000005000000FC6EBA650727604007077B1343FE4840FC6EBA650727604097033DD4B6FF48403866D9934027604097033DD4B6FF48403866D9934027604007077B1343FE4840FC6EBA650727604007077B1343FE4840
8294	Верхнеильиновка	4	38	966	129.68455800000001	129.70902799999999	50.226000999999997	50.209446999999997	0103000020E61000000100000005000000E3C62DE6E7356040669FC728CF1A4940E3C62DE6E735604080EECB99ED1C494058FE7C5BB036604080EECB99ED1C494058FE7C5BB0366040669FC728CF1A4940E3C62DE6E7356040669FC728CF1A4940
14259	Валуево	4	38	966	129.554913	129.57109199999999	50.064641999999999	50.050646999999998	0103000020E610000001000000050000000264E8D8C1316040FC51D4997B0649400264E8D8C131604059F96530460849403BE0BA624632604059F96530460849403BE0BA6246326040FC51D4997B0649400264E8D8C1316040FC51D4997B064940
15064	Болдыревка	4	38	966	129.47890699999999	129.510501	50.228641000000003	50.220336000000003	0103000020E610000001000000050000006ADAC534532F6040D41055F8331C49406ADAC534532F60402BC3B81B441D494069723106563060402BC3B81B441D49406972310656306040D41055F8331C49406ADAC534532F6040D41055F8331C4940
8231	Белый Яр	4	38	966	129.17560900000001	129.21835100000001	50.189773000000002	50.176605000000002	0103000020E6100000010000000500000044FCC3969E256040B1A71DFE9A16494044FCC3969E256040F8544E7B4A18494091813CBBFC266040F8544E7B4A18494091813CBBFC266040B1A71DFE9A16494044FCC3969E256040B1A71DFE9A164940
14039	Антоновка	4	38	966	129.35910799999999	129.37932000000001	49.871214000000002	49.857615000000003	0103000020E610000001000000050000006C770FD07D2B60408FC70C54C6ED48406C770FD07D2B60409FE8BAF083EF48400057B263232C60409FE8BAF083EF48400057B263232C60408FC70C54C6ED48406C770FD07D2B60408FC70C54C6ED4840
15114	Аврамовка	4	38	966	129.418172	129.43428800000001	50.273325999999997	50.252037000000001	0103000020E610000001000000050000004B033FAA612D6040E43098BF422049404B033FAA612D6040C092AB58FC22494073A1F2AFE52D6040C092AB58FC22494073A1F2AFE52D6040E43098BF422049404B033FAA612D6040E43098BF42204940
13743	Усть-Кивда	4	38	40	129.68332799999999	129.71341200000001	49.680157999999999	49.669775000000001	0103000020E610000001000000050000001D8EAED2DD356040D656EC2FBBD548401D8EAED2DD3560406F0ED76A0FD748405E126745D43660406F0ED76A0FD748405E126745D4366040D656EC2FBBD548401D8EAED2DD356040D656EC2FBBD54840
13276	Талакан	4	38	40	130.25051500000001	130.28245000000001	50.271489000000003	50.254145000000001	0103000020E610000001000000050000000A8508380448604091B8C7D2872049400A85083804486040A41CCC26C02249402B1895D409496040A41CCC26C02249402B1895D40949604091B8C7D2872049400A8508380448604091B8C7D287204940
48	Старая Райчиха	4	38	40	129.221441	129.24502200000001	49.760956	49.740856999999998	0103000020E61000000100000005000000CB9F6F0B162760409F01F566D4DE4840CB9F6F0B16276040F5D8960167E148409E996038D7276040F5D8960167E148409E996038D72760409F01F566D4DE4840CB9F6F0B162760409F01F566D4DE4840
48415	Семеновка	4	38	40	129.811643	129.83248399999999	50.072927999999997	50.065353999999999	0103000020E61000000100000005000000E0A0BDFAF8396040D65416855D084940E0A0BDFAF8396040397B67B4550949402F4E7CB5A33A6040397B67B4550949402F4E7CB5A33A6040D65416855D084940E0A0BDFAF8396040D65416855D084940
48402	Родионовка	4	38	40	129.751645	129.78381300000001	50.022863000000001	50.013243000000003	0103000020E6100000010000000500000076A6D0790D38604052F355F2B101494076A6D0790D386040ECA4BE2CED024940C02500FF14396040ECA4BE2CED024940C02500FF1439604052F355F2B101494076A6D0790D38604052F355F2B1014940
12980	Новобурейский	4	38	40	129.84680299999999	129.89233899999999	49.815370000000001	49.785437000000002	0103000020E61000000100000005000000F3E49A02193B6040C0081A3389E44840F3E49A02193B6040DC114E0B5EE8484040BE840A8E3C6040DC114E0B5EE8484040BE840A8E3C6040C0081A3389E44840F3E49A02193B6040C0081A3389E44840
55700	Новобурейский	4	38	40	129.84680299999999	129.89233899999999	49.815370000000001	49.785437000000002	0103000020E61000000100000005000000F3E49A02193B6040C0081A3389E44840F3E49A02193B6040DC114E0B5EE8484040BE840A8E3C6040DC114E0B5EE8484040BE840A8E3C6040C0081A3389E44840F3E49A02193B6040C0081A3389E44840
55723	Николаевка	4	38	40	129.889689	129.94521399999999	49.801184999999997	49.781191	0103000020E610000001000000050000008DD31055783C6040FB761211FEE348408DD31055783C6040DB85E63A8DE6484015376E313F3E6040DB85E63A8DE6484015376E313F3E6040FB761211FEE348408DD31055783C6040FB761211FEE34840
48348	Муравка	4	38	40	129.590101	129.60834500000001	49.801318000000002	49.790241000000002	0103000020E61000000100000005000000C80A7E1BE2326040AB7AF99D26E54840C80A7E1BE23260401BD9959691E64840EDF5EE8F773360401BD9959691E64840EDF5EE8F77336040AB7AF99D26E54840C80A7E1BE2326040AB7AF99D26E54840
48373	Малиновка	4	38	40	129.813107	129.860727	49.792323000000003	49.771382000000003	0103000020E61000000100000005000000C2A4F8F8043A60408E5C37A5BCE24840C2A4F8F8043A60402F6F0ED76AE54840187959138B3B60402F6F0ED76AE54840187959138B3B60408E5C37A5BCE24840C2A4F8F8043A60408E5C37A5BCE24840
13600	Кивдо-Тюкан	4	38	40	129.67696799999999	129.690415	49.853839999999998	49.845568999999998	0103000020E61000000100000005000000088ECBB8A935604076C1E09A3BEC4840088ECBB8A935604021020EA14AED48405FB532E11736604021020EA14AED48405FB532E11736604076C1E09A3BEC4840088ECBB8A935604076C1E09A3BEC4840
13887	Долдыкан	4	38	40	129.874166	129.884658	49.905759000000003	49.887183999999998	0103000020E61000000100000005000000CEA8F92AF93B604069C4CC3E8FF14840CEA8F92AF93B6040628731E9EFF34840A2444B1E4F3C6040628731E9EFF34840A2444B1E4F3C604069C4CC3E8FF14840CEA8F92AF93B604069C4CC3E8FF14840
49255	Виноградовка	4	38	40	129.402164	129.41974400000001	49.670963999999998	49.654865000000001	0103000020E610000001000000050000001D740987DE2C6040C425C79DD2D348401D740987DE2C60408C65FA25E2D548402716F88A6E2D60408C65FA25E2D548402716F88A6E2D6040C425C79DD2D348401D740987DE2C6040C425C79DD2D34840
13380	Бурея	4	38	40	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
55707	Бурея	4	38	40	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
30127	Безозерное	4	38	40	129.011594	129.03446600000001	49.820118000000001	49.805486999999999	0103000020E610000001000000050000008E5A61FA5E206040342DB1321AE748408E5A61FA5E206040336E6AA0F9E848405EDA70581A216040336E6AA0F9E848405EDA70581A216040342DB1321AE748408E5A61FA5E206040342DB1321AE74840
48446	Алексеевка	4	38	40	129.44772699999999	129.470472	49.572212999999998	49.553216999999997	0103000020E6100000010000000500000028D192C7532E6040AD4B8DD0CFC6484028D192C7532E60404BAC8C463EC94840E1B54B1B0E2F60404BAC8C463EC94840E1B54B1B0E2F6040AD4B8DD0CFC6484028D192C7532E6040AD4B8DD0CFC64840
7764	Чигири	4	38	912	127.49753800000001	127.524658	50.344223999999997	50.329103000000003	0103000020E610000001000000050000001BA19FA9D7DF5F40FC010F0C202A49401BA19FA9D7DF5F40C83F33880F2C49406DE525FF93E15F40C83F33880F2C49406DE525FF93E15F40FC010F0C202A49401BA19FA9D7DF5F40FC010F0C202A4940
7361	Усть-Ивановка	4	38	912	127.725441	127.771973	50.337589999999999	50.314374000000001	0103000020E610000001000000050000005D8B16A06DEE5F403A5B40683D2849405D8B16A06DEE5F4073BA2C26362B49404819710168F15F4073BA2C26362B49404819710168F15F403A5B40683D2849405D8B16A06DEE5F403A5B40683D284940
7695	Удобное	4	38	912	127.79410799999999	127.81020599999999	50.142873000000002	50.134236000000001	0103000020E610000001000000050000007C5F5CAAD2F25F4012F92EA52E1149407C5F5CAAD2F25F409F3D97A9491249407841446ADAF35F409F3D97A9491249407841446ADAF35F4012F92EA52E1149407C5F5CAAD2F25F4012F92EA52E114940
8057	Сергеевка	4	38	912	127.277666	127.31368000000001	50.764023000000002	50.718006000000003	0103000020E61000000100000005000000834D9D47C5D15F40782AE09EE75B4940834D9D47C5D15F4027327381CB614940325A475513D45F4027327381CB614940325A475513D45F40782AE09EE75B4940834D9D47C5D15F40782AE09EE75B4940
7247	Ровное	4	38	912	127.76408600000001	127.781648	50.298990000000003	50.282553999999998	0103000020E610000001000000050000003755F7C8E6F05F404FADBEBA2A2449403755F7C8E6F05F4060EAE74D45264940F73E558506F25F4060EAE74D45264940F73E558506F25F404FADBEBA2A2449403755F7C8E6F05F404FADBEBA2A244940
8289	Прядчино	4	38	912	127.779124	127.789643	50.877636000000003	50.855584999999998	0103000020E61000000100000005000000D6E1E82ADDF15F405DF92CCF836D4940D6E1E82ADDF15F4069E55E6056704940FB20CB8289F25F4069E55E6056704940FB20CB8289F25F405DF92CCF836D4940D6E1E82ADDF15F405DF92CCF836D4940
55706	Плодопитомник	4	38	912	127.48012900000001	127.498966	50.316186000000002	50.301389999999998	0103000020E610000001000000050000001E37FC6EBADE5F40B4AB90F2932649401E37FC6EBADE5F40FEB968C87828494038F4160FEFDF5F40FEB968C87828494038F4160FEFDF5F40B4AB90F2932649401E37FC6EBADE5F40B4AB90F293264940
7742	Передовое	4	38	912	127.706118	127.73409100000001	50.134270999999998	50.124090000000002	0103000020E610000001000000050000007C478D0931ED5F405DE15D2EE20F49407C478D0931ED5F408EE6C8CA2F1149406E52D158FBEE5F408EE6C8CA2F1149406E52D158FBEE5F405DE15D2EE20F49407C478D0931ED5F405DE15D2EE20F4940
47342	Новотроицкое	4	38	912	127.544673	127.568505	50.508232	50.488028999999997	0103000020E61000000100000005000000E98024ECDBE25F40F23FF9BB773E4940E98024ECDBE25F40ED6305BF0D41494033A7CB6262E45F40ED6305BF0D41494033A7CB6262E45F40F23FF9BB773E4940E98024ECDBE25F40F23FF9BB773E4940
8224	Новопетровка	4	38	912	127.748707	127.765703	50.792814	50.773935000000002	0103000020E6100000010000000500000052D2C3D0EAEF5F40691D554D1063494052D2C3D0EAEF5F40CDE7DCED7A654940BEDC274701F15F40CDE7DCED7A654940BEDC274701F15F40691D554D1063494052D2C3D0EAEF5F40691D554D10634940
8377	Новинка	4	38	912	127.65600999999999	127.675907	50.647497999999999	50.638924000000003	0103000020E6100000010000000500000055F65D11FCE95F409450FA42C851494055F65D11FCE95F40DA1CE736E1524940CC086F0F42EB5F40DA1CE736E1524940CC086F0F42EB5F409450FA42C851494055F65D11FCE95F409450FA42C8514940
8452	Натальино	4	38	912	127.82485699999999	127.83772999999999	50.977924999999999	50.963523000000002	0103000020E610000001000000050000001BB80375CAF45F40CFF8BEB8547B49401BB80375CAF45F406C787AA52C7D494032384A5E9DF55F406C787AA52C7D494032384A5E9DF55F40CFF8BEB8547B49401BB80375CAF45F40CFF8BEB8547B4940
7975	Михайловка	4	38	912	127.359027	127.392633	50.643380000000001	50.619703000000001	0103000020E6100000010000000500000062D8614CFAD65F40D61D8B6D524F494062D8614CFAD65F4043739D465A524940259529E620D95F4043739D465A524940259529E620D95F40D61D8B6D524F494062D8614CFAD65F40D61D8B6D524F4940
7928	Марково	4	38	912	127.359143	127.382015	50.550198000000002	50.536883000000003	0103000020E6100000010000000500000097E5EB32FCD65F40A2630795B844494097E5EB32FCD65F408D2958E36C46494036E50AEF72D85F408D2958E36C46494036E50AEF72D85F40A2630795B844494097E5EB32FCD65F40A2630795B8444940
55750	Каникурган	4	38	912	127.62853	127.641942	50.209228000000003	50.200015	0103000020E6100000010000000500000083A3E4D539E85F40CFDA6D179A19494083A3E4D539E85F4029B4ACFBC71A494072FBE59315E95F4029B4ACFBC71A494072FBE59315E95F40CFDA6D179A19494083A3E4D539E85F40CFDA6D179A194940
7868	Игнатьево	4	38	912	127.38598500000001	127.399388	50.449109999999997	50.441648000000001	0103000020E61000000100000005000000C8EF6DFAB3D85F40022CF2EB87384940C8EF6DFAB3D85F403D27BD6F7C3949408D9AAF928FD95F403D27BD6F7C3949408D9AAF928FD95F40022CF2EB87384940C8EF6DFAB3D85F40022CF2EB87384940
55745	Заречный	4	38	912	127.66885600000001	127.676141	50.250545000000002	50.247065999999997	0103000020E61000000100000005000000F06E6589CEEA5F400DFAD2DB9F1F4940F06E6589CEEA5F409296CADB11204940069FE6E445EB5F409296CADB11204940069FE6E445EB5F400DFAD2DB9F1F4940F06E6589CEEA5F400DFAD2DB9F1F4940
8359	Егорьевка	4	38	912	127.69380200000001	127.705794	50.692461000000002	50.679226999999997	0103000020E6100000010000000500000090F9804067EC5F40B4C70BE9F056494090F9804067EC5F40B360E28FA2584940A2ED98BA2BED5F40B360E28FA2584940A2ED98BA2BED5F40B4C70BE9F056494090F9804067EC5F40B4C70BE9F0564940
7654	Дроново	4	38	912	127.828343	127.838134	50.177787000000002	50.170270000000002	0103000020E61000000100000005000000B7B75B9203F55F40B6BE4868CB154940B7B75B9203F55F40B55373B9C11649409AEAC9FCA3F55F40B55373B9C11649409AEAC9FCA3F55F40B6BE4868CB154940B7B75B9203F55F40B6BE4868CB154940
8022	Грязнушка	4	38	912	127.478494	127.50071800000001	50.660296000000002	50.648401	0103000020E6100000010000000500000043554CA59FDE5F40CBD8D0CDFE52494043554CA59FDE5F40FED64E948454494030A182C30BE05F40FED64E948454494030A182C30BE05F40CBD8D0CDFE52494043554CA59FDE5F40CBD8D0CDFE524940
7486	Гродеково	4	38	912	127.565073	127.586112	50.129432000000001	50.114508000000001	0103000020E6100000010000000500000091B6F1272AE45F40B090B932A80E494091B6F1272AE45F4027874F3A91104940C3F2E7DB82E55F4027874F3A91104940C3F2E7DB82E55F40B090B932A80E494091B6F1272AE45F40B090B932A80E4940
55736	Грибское	4	38	912	127.745311	127.75728599999999	50.210715999999998	50.196088000000003	0103000020E610000001000000050000005796E82CB3EF5F40AC915D69191949405796E82CB3EF5F40395FECBDF81A4940FEEDB25F77F05F40395FECBDF81A4940FEEDB25F77F05F40AC915D69191949405796E82CB3EF5F40AC915D6919194940
7302	Владимировка	4	38	912	127.631162	127.63878	50.304254999999998	50.296602	0103000020E61000000100000005000000971E4DF564E85F40CFF6E80DF7254940971E4DF564E85F407E52EDD3F1264940B05582C5E1E85F407E52EDD3F1264940B05582C5E1E85F40CFF6E80DF7254940971E4DF564E85F40CFF6E80DF7254940
7847	Верхнеблаговещенское	4	38	912	127.389039	127.45218199999999	50.291918000000003	50.274603999999997	0103000020E610000001000000050000009677D503E6D85F40E6AC4F39262349409677D503E6D85F408F8EAB915D254940C075C58CF0DC5F408F8EAB915D254940C075C58CF0DC5F40E6AC4F39262349409677D503E6D85F40E6AC4F3926234940
7446	Благовещенск	4	38	912	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
8141	Бибиково	4	38	912	127.210823	127.22781000000001	50.811827000000001	50.800904000000003	0103000020E61000000100000005000000A88FC01F7ECD5F40289EB30584664940A88FC01F7ECD5F40418177F2E9674940EAEC647094CE5F40418177F2E9674940EAEC647094CE5F40289EB30584664940A88FC01F7ECD5F40289EB30584664940
4514	Чернетчено	4	38	600	128.50684899999999	128.54668899999999	50.616388999999998	50.605156000000001	0103000020E6100000010000000500000054E0641B38106040357D76C0754D494054E0641B381060409C4EB2D5E54E4940A702EE797E1160409C4EB2D5E54E4940A702EE797E116040357D76C0754D494054E0641B38106040357D76C0754D4940
5308	Успеновка	4	38	600	128.04744199999999	128.080994	50.741616	50.721004999999998	0103000020E610000001000000050000009ECE15A58401604051A04FE4495C49409ECE15A5840160405D18E945ED5E494083A5BA80970260405D18E945ED5E494083A5BA809702604051A04FE4495C49409ECE15A58401604051A04FE4495C4940
4992	Томичи	4	38	600	128.21610000000001	128.274338	50.794032000000001	50.766843000000001	0103000020E610000001000000050000004D158C4AEA066040511553E9276249404D158C4AEA0660401EFD2FD7A26549409A417C60C70860401EFD2FD7A26549409A417C60C7086040511553E9276249404D158C4AEA066040511553E927624940
5536	Светиловка	4	38	600	127.95248100000001	127.980903	50.991238000000003	50.978026999999997	0103000020E61000000100000005000000EE43DE72F5FC5F4070CD1DFD2F7D4940EE43DE72F5FC5F40B74604E3E07E49401763601DC7FE5F40B74604E3E07E49401763601DC7FE5F4070CD1DFD2F7D4940EE43DE72F5FC5F4070CD1DFD2F7D4940
4947	Савельевка	4	38	600	128.20952500000001	128.218526	50.696615000000001	50.687559	0103000020E6100000010000000500000039D6C56DB40660400589EDEE0158494039D6C56DB4066040977329AE2A5949406CEA3C2AFE066040977329AE2A5949406CEA3C2AFE0660400589EDEE0158494039D6C56DB40660400589EDEE01584940
4603	Пригородное	4	38	600	128.511574	128.53144499999999	50.832436999999999	50.819902999999996	0103000020E610000001000000050000007CEF6FD05E1060403672DD94F26849407CEF6FD05E1060407C7DAD4B8D6A4940EDD3F198011160407C7DAD4B8D6A4940EDD3F198011160403672DD94F26849407CEF6FD05E1060403672DD94F2684940
5072	Поляное	4	38	600	128.318005	128.334903	50.740862999999997	50.719476999999998	0103000020E61000000100000005000000DD5ED2182D0A6040B29C84D2175C4940DD5ED2182D0A604081E84999D45E4940A20A7F86B70A604081E84999D45E4940A20A7F86B70A6040B29C84D2175C4940DD5ED2182D0A6040B29C84D2175C4940
3899	Павловка	4	38	600	128.709338	128.74067199999999	50.876556000000001	50.867694999999998	0103000020E61000000100000005000000ECF99AE5B21660408CF337A1106F4940ECF99AE5B2166040698EACFC327049400322C495B3176040698EACFC327049400322C495B31760408CF337A1106F4940ECF99AE5B21660408CF337A1106F4940
4470	Озеряне	4	38	600	128.718762	128.77330699999999	50.648080999999998	50.637884999999997	0103000020E6100000010000000500000071732A1900176040F2CD3637A651494071732A190017604059147651F4524940925852EEBE18604059147651F4524940925852EEBE186040F2CD3637A651494071732A1900176040F2CD3637A6514940
4786	Новоселитьба	4	38	600	128.41888599999999	128.44738100000001	50.620851999999999	50.616314000000003	0103000020E6100000010000000500000012D89C83670D604092088D60E34E494012D89C83670D6040FED30D14784F4940427BF5F1500E6040FED30D14784F4940427BF5F1500E604092088D60E34E494012D89C83670D604092088D60E34E4940
4817	Новоназаровка	4	38	600	128.44974300000001	128.46929	50.695627999999999	50.687525000000001	0103000020E610000001000000050000005C936E4B640E60405917B7D1005849405C936E4B640E604048179B560A594940E04A766C040F604048179B560A594940E04A766C040F60405917B7D1005849405C936E4B640E60405917B7D100584940
3996	Новое	4	38	600	128.976282	128.995362	50.876567999999999	50.862890999999998	0103000020E610000001000000050000008DB5BFB33D1F6040A1815836736E49408DB5BFB33D1F60402D5C566133704940CCB56801DA1F60402D5C566133704940CCB56801DA1F6040A1815836736E49408DB5BFB33D1F6040A1815836736E4940
5393	Новоандреевка	4	38	600	127.870572	127.889635	50.888109	50.868882999999997	0103000020E610000001000000050000000D349F73B7F75F407286E28E376F49400D349F73B7F75F404224438EAD7149402098A3C7EFF85F404224438EAD7149402098A3C7EFF85F407286E28E376F49400D349F73B7F75F407286E28E376F4940
5687	Никольское	4	38	600	128.277725	128.30211399999999	50.932647000000003	50.914422000000002	0103000020E6100000010000000500000003098A1FE3086040185FB4C70B75494003098A1FE308604034DB15FA607749403DB5FAEAAA09604034DB15FA607749403DB5FAEAAA096040185FB4C70B75494003098A1FE3086040185FB4C70B754940
55747	Низинное	4	38	600	128.398045	128.416146	50.861964	50.850535999999998	0103000020E61000000100000005000000C32ADEC8BC0C60400B09185DDE6C4940C32ADEC8BC0C6040282A1BD6546E49408F8B6A11510D6040282A1BD6546E49408F8B6A11510D60400B09185DDE6C4940C32ADEC8BC0C60400B09185DDE6C4940
4734	Некрасовка	4	38	600	128.34262799999999	128.36267799999999	50.684866	50.67051	0103000020E6100000010000000500000034D6FECEF60A60400BD28C45D355494034D6FECEF60A6040381268B0A9574940519FE40E9B0B6040381268B0A9574940519FE40E9B0B60400BD28C45D355494034D6FECEF60A60400BD28C45D3554940
4553	Мирное	4	38	600	128.599636	128.610973	50.746141000000001	50.736165999999997	0103000020E610000001000000050000002330D63730136040AC36FFAF3A5E49402330D63730136040359A5C8C815F4940A6B73F178D136040359A5C8C815F4940A6B73F178D136040AC36FFAF3A5E49402330D63730136040AC36FFAF3A5E4940
3786	Междугранка	4	38	600	128.57759999999999	128.58983499999999	50.907480999999997	50.901215999999998	0103000020E610000001000000050000006DC5FEB27B126040E350BF0B5B7349406DC5FEB27B126040E55E6056287449402861A6EDDF126040E55E6056287449402861A6EDDF126040E350BF0B5B7349406DC5FEB27B126040E350BF0B5B734940
5208	Лукьяновка	4	38	600	128.19192699999999	128.21805000000001	50.841355999999998	50.828153	0103000020E610000001000000050000000587174424066040CA8AE1EA006A494005871744240660408D25AC8DB16B4940925CFE43FA0660408D25AC8DB16B4940925CFE43FA066040CA8AE1EA006A49400587174424066040CA8AE1EA006A4940
4087	Луговое	4	38	600	129.04726700000001	129.05986100000001	50.765635000000003	50.756450000000001	0103000020E61000000100000005000000C3651536832160409487855AD3604940C36515368321604024D6E25300624940CAA99D61EA21604024D6E25300624940CAA99D61EA2160409487855AD3604940C3651536832160409487855AD3604940
4877	Лохвицы	4	38	600	128.193184	128.23198300000001	50.741781000000003	50.723896000000003	0103000020E61000000100000005000000894336902E06604045DAC69FA85C4940894336902E066040A8E507AEF25E49404CC79C676C076040A8E507AEF25E49404CC79C676C07604045DAC69FA85C4940894336902E06604045DAC69FA85C4940
47510	Лозовое	4	38	600	128.314583	128.320458	50.781402	50.776823	0103000020E61000000100000005000000151C5E10110A6040EBE3A1EF6E634940151C5E10110A6040B68311FB04644940BBB72231410A6040B68311FB04644940BBB72231410A6040EBE3A1EF6E634940151C5E10110A6040EBE3A1EF6E634940
5133	Кустанаевка	4	38	600	128.25230199999999	128.273898	50.807166000000002	50.793224000000002	0103000020E61000000100000005000000E4D6A4DB120860407F33315D88654940E4D6A4DB12086040B9382A3751674940130EBDC5C3086040B9382A3751674940130EBDC5C30860407F33315D88654940E4D6A4DB120860407F33315D88654940
3949	Круглое	4	38	600	128.84449000000001	128.85933	50.879761999999999	50.866847999999997	0103000020E610000001000000050000009279E40F061B60402F4D11E0F46E49409279E40F061B6040BC218D0A9C70494018CFA0A17F1B6040BC218D0A9C70494018CFA0A17F1B60402F4D11E0F46E49409279E40F061B60402F4D11E0F46E4940
5383	Комиссаровка	4	38	600	127.980733	128.004457	50.869588	50.853327999999998	0103000020E61000000100000005000000E9465854C4FE5F406B6116DA396D4940E9465854C4FE5F403D7FDAA84E6F4940A0A70183240060403D7FDAA84E6F4940A0A70183240060406B6116DA396D4940E9465854C4FE5F406B6116DA396D4940
5638	Ключи	4	38	600	128.159021	128.17909	50.944918000000001	50.933902000000003	0103000020E61000000100000005000000124C35B316056040A2D5C9198A774940124C35B3160560406CB3B112F37849404DA1F31ABB0560406CB3B112F37849404DA1F31ABB056040A2D5C9198A774940124C35B316056040A2D5C9198A774940
5547	Киселеозерка	4	38	600	128.11596499999999	128.13077799999999	50.943714999999997	50.932096000000001	0103000020E61000000100000005000000614F3BFCB5036040C05DF6EB4E774940614F3BFCB503604050DF32A7CB784940292158552F04604050DF32A7CB784940292158552F046040C05DF6EB4E774940614F3BFCB5036040C05DF6EB4E774940
55749	Камышевка	4	38	600	128.226099	128.240184	50.883149000000003	50.878909	0103000020E610000001000000050000001155F8333C0760407D941117807049401155F8333C076040603FC4060B714940B8205B96AF076040603FC4060B714940B8205B96AF0760407D941117807049401155F8333C0760407D94111780704940
4377	Заречное	4	38	600	128.612931	128.64221599999999	50.633902999999997	50.612147999999998	0103000020E610000001000000050000008CF678219D136040E9279CDD5A4E49408CF678219D1360400BEBC6BB23514940F99E91088D1460400BEBC6BB23514940F99E91088D146040E9279CDD5A4E49408CF678219D136040E9279CDD5A4E4940
4132	Дубровка	4	38	600	128.85081400000001	128.86482799999999	50.686937	50.680664999999998	0103000020E61000000100000005000000541F48DE391B60401344DD0720574940541F48DE391B6040C8B4368DED5749404815C5ABAC1B6040C8B4368DED5749404815C5ABAC1B60401344DD0720574940541F48DE391B60401344DD0720574940
4220	Возжаевка	4	38	600	128.68810199999999	128.74230600000001	50.745674000000001	50.714407000000001	0103000020E61000000100000005000000FD497CEE04166040498446B0715B4940FD497CEE041660401FBDE13E725F4940FD3383F8C01760401FBDE13E725F4940FD3383F8C0176040498446B0715B4940FD497CEE04166040498446B0715B4940
5455	Великокнязевка	4	38	600	127.895132	127.925118	50.932640999999997	50.900767000000002	0103000020E610000001000000050000009966BAD749F95F40742843554C7349409966BAD749F95F4051F4C0C76077494038BC202235FB5F4051F4C0C76077494038BC202235FB5F40742843554C7349409966BAD749F95F40742843554C734940
3865	Васильевка	4	38	600	128.59866600000001	128.62678299999999	50.896051999999997	50.879016999999997	0103000020E61000000100000005000000456799452813604063D009A1837049404567994528136040F8C1F9D4B17249400AD6389B0E146040F8C1F9D4B17249400AD6389B0E14604063D009A183704940456799452813604063D009A183704940
4642	Белоцерковка	4	38	600	128.48870299999999	128.499402	50.775832000000001	50.762883000000002	0103000020E61000000100000005000000A04E7974A30F604052D66F26A6614940A04E7974A30F60405B9885764E634940D331E719FB0F60405B9885764E634940D331E719FB0F604052D66F26A6614940A04E7974A30F604052D66F26A6614940
5033	Белогорск	4	38	600	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
4175	Амурское	4	38	600	128.727026	128.74871999999999	50.748398000000002	50.733783000000003	0103000020E61000000100000005000000EFAA07CC431760402EAEF199EC5D4940EFAA07CC4317604027327381CB5F49408E3BA583F517604027327381CB5F49408E3BA583F51760402EAEF199EC5D4940EFAA07CC431760402EAEF199EC5D4940
2672	Черноберезовка	4	38	428	130.25470999999999	130.27755400000001	49.437806999999999	49.430917999999998	0103000020E61000000100000005000000DAFE959526486040FDA02E5228B74840DAFE959526486040DD7A4D0F0AB84840F81BEDB8E1486040DD7A4D0F0AB84840F81BEDB8E1486040FDA02E5228B74840DAFE959526486040FDA02E5228B74840
3704	Черниговка	4	38	428	129.93078700000001	129.94702799999999	49.623251000000003	49.614660000000001	0103000020E610000001000000050000005891D101C93D60406614CB2DADCE48405891D101C93D6040831953B0C6CF4840AE0CAA0D4E3E6040831953B0C6CF4840AE0CAA0D4E3E60406614CB2DADCE48405891D101C93D60406614CB2DADCE4840
3671	Урил	4	38	428	130.46976699999999	130.49058099999999	49.234217999999998	49.223998999999999	0103000020E61000000100000005000000AEB7CD54084F604019ABCDFFAB9C4840AEB7CD54084F60403811FDDAFA9D48403FE1ECD6B24F60403811FDDAFA9D48403FE1ECD6B24F604019ABCDFFAB9C4840AEB7CD54084F604019ABCDFFAB9C4840
3620	Северное	4	38	428	129.54682	129.56637599999999	49.456567999999997	49.443238000000001	0103000020E610000001000000050000008F19A88C7F316040172CD505BCB848408F19A88C7F3160403733FAD170BA4840A8A78FC01F3260403733FAD170BA4840A8A78FC01F326040172CD505BCB848408F19A88C7F316040172CD505BCB84840
3479	Отважное	4	38	428	130.088764	130.13015899999999	49.366919000000003	49.345578000000003	0103000020E61000000100000005000000FDA19927D7426040CA1B60E63BAC4840FDA19927D7426040F9A3A833F7AE4840F60835432A446040F9A3A833F7AE4840F60835432A446040CA1B60E63BAC4840FDA19927D7426040CA1B60E63BAC4840
3338	Новоспасск	4	38	428	129.77282700000001	129.79552699999999	49.657629	49.647306	0103000020E61000000100000005000000E84EB0FFBA38604096404AECDAD24840E84EB0FFBA3860405AF3E32F2DD44840B8020AF5743960405AF3E32F2DD44840B8020AF57439604096404AECDAD24840E84EB0FFBA38604096404AECDAD24840
3477	Новосергеевка	4	38	428	130.288702	130.302572	49.243723000000003	49.228552000000001	0103000020E610000001000000050000004609FA0B3D496040BBB72231419D48404609FA0B3D4960403A24B550329F4840EE9579ABAE4960403A24B550329F4840EE9579ABAE496040BBB72231419D48404609FA0B3D496040BBB72231419D4840
3134	Новопокровка	4	38	428	130.198296	130.21348599999999	48.912208999999997	48.900111000000003	0103000020E61000000100000005000000AF5DDA70584660408BE255D636734840AF5DDA7058466040F50EB743C3744840EC8497E0D4466040F50EB743C3744840EC8497E0D44660408BE255D636734840AF5DDA70584660408BE255D636734840
3250	Ленинское	4	38	428	129.92855	129.969064	49.268935999999997	49.246398999999997	0103000020E610000001000000050000006D567DAEB63D604030629F008A9F48406D567DAEB63D6040C85BAE7E6CA2484064778192023F6040C85BAE7E6CA2484064778192023F604030629F008A9F48406D567DAEB63D604030629F008A9F4840
3142	Кундур	4	38	428	130.742064	130.76969600000001	49.119225999999998	49.089688000000002	0103000020E610000001000000050000003F7100FDBE576040FD6B79E57A8B48403F7100FDBE5760409C6A2DCC428F4840967B8159A15860409C6A2DCC428F4840967B8159A1586040FD6B79E57A8B48403F7100FDBE576040FD6B79E57A8B4840
3284	Красный Исток	4	38	428	130.02705	130.051053	49.293942000000001	49.276947999999997	0103000020E610000001000000050000006B2BF697DD406040A758350873A348406B2BF697DD406040DE7536E49FA548409BABE639A2416040DE7536E49FA548409BABE639A2416040A758350873A348406B2BF697DD406040A758350873A34840
2991	Касаткино	4	38	428	130.05869799999999	130.087605	48.980207	48.966174000000002	0103000020E61000000100000005000000E6CAA0DAE04160406D1FF296AB7B4840E6CAA0DAE0416040B727486C777D4840EA3E00A9CD426040B727486C777D4840EA3E00A9CD4260406D1FF296AB7B4840E6CAA0DAE04160406D1FF296AB7B4840
3578	Каменный Карьер	4	38	428	130.17449099999999	130.189897	49.318835999999997	49.304405000000003	0103000020E61000000100000005000000484E266E9545604094DE37BEF6A64840484E266E95456040CB64389ECFA848407993DFA213466040CB64389ECFA848407993DFA21346604094DE37BEF6A64840484E266E9545604094DE37BEF6A64840
2924	Иннокентьевка	4	38	428	129.674183	129.721147	49.307771000000002	49.290422999999997	0103000020E610000001000000050000009D103AE892356040CB80B3942CA548409D103AE89235604020D4450A65A748407993DFA21337604020D4450A65A748407993DFA213376040CB80B3942CA548409D103AE892356040CB80B3942CA54840
3032	Журавлевка	4	38	428	129.99064100000001	130.004853	49.086674000000002	49.074263999999999	0103000020E610000001000000050000007522C154B33F604094A2957B818948407522C154B33F6040EEB43522188B484033897AC127406040EEB43522188B484033897AC12740604094A2957B818948407522C154B33F604094A2957B81894840
3382	Домикан	4	38	428	129.85555299999999	129.884613	49.690713000000002	49.679755	0103000020E61000000100000005000000D45FAFB0603B604070253B3602D74840D45FAFB0603B604006F6984869D84840BA13ECBF4E3C604006F6984869D84840BA13ECBF4E3C604070253B3602D74840D45FAFB0603B604070253B3602D74840
2879	Грибовка	4	38	428	130.37007199999999	130.37667400000001	49.482075000000002	49.463366000000001	0103000020E610000001000000050000004A253CA1D74B6040070ABC934FBB48404A253CA1D74B60400F9C33A2B4BD48401DE8A1B60D4C60400F9C33A2B4BD48401DE8A1B60D4C6040070ABC934FBB48404A253CA1D74B6040070ABC934FBB4840
2818	Вольное	4	38	428	129.90726000000001	129.92402200000001	49.280127	49.270988000000003	0103000020E61000000100000005000000029F1F46083D6040E2CD1ABCAFA24840029F1F46083D604001DD9733DBA348401BD99596913D604001DD9733DBA348401BD99596913D6040E2CD1ABCAFA24840029F1F46083D6040E2CD1ABCAFA24840
55705	Архара	4	38	428	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
2322	Архара	4	38	428	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
2669	Аркадьевка	4	38	428	130.12449899999999	130.16335100000001	49.409849999999999	49.397762	0103000020E610000001000000050000004FAC53E5FB436040B8CB7EDDE9B248404FAC53E5FB436040FF21FDF675B448409B58E02B3A456040FF21FDF675B448409B58E02B3A456040B8CB7EDDE9B248404FAC53E5FB436040B8CB7EDDE9B24840
2769	Антоновка	4	38	428	129.93104700000001	129.95115100000001	49.436799999999998	49.425539000000001	0103000020E610000001000000050000003F011423CB3D60401616DC0F78B648403F011423CB3D60404772F90FE9B74840D9D138D46F3E60404772F90FE9B74840D9D138D46F3E60401616DC0F78B648403F011423CB3D60401616DC0F78B64840
\.


--
-- Data for Name: location; Type: TABLE DATA; Schema: public; Owner: -
--

COPY location (id, district_id, area_id, sub_area_id, locality_id, street_id, lon, lat, raw_address, address, point) FROM stdin;
38011	2	19	\N	57158	\N	\N	46.170611999999998	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Гашунское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, поселок городского типа Яшкуль	0101000020E61000000420EEEA55AC46400F27309DD6154740
37803	2	19	\N	11360	\N	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ДОД ""Дворец детского творчества"", Парк культуры и отдыха ""Дружба"""		0101000020E6100000A0A70183A421464003ECA353572A4740
37781	2	19	\N	11360	\N	\N	46.33079	Республика Калмыкия, город Элиста, МОУ Начальная общеобразовательная школа №24, СМП-334		0101000020E6100000A0A70183A421464003ECA353572A4740
37810	2	19	\N	11360	57312	\N	46.33079	Республика Калмыкия, город Элиста, МОУ СОШ № 17, 2 мкр, д.10		0101000020E6100000A0A70183A421464003ECA353572A4740
37783	2	19	\N	11360	57312	\N	46.33079	Республика Калмыкия, город Элиста, МОУ Начальная общеобразовательная школа №25, 1мкр, д.1А		0101000020E6100000A0A70183A421464003ECA353572A4740
37814	2	19	\N	11360	57332	\N	46.33079	"Республика Калмыкия, город Элиста, МУП ""Октябрь"", Хрущева д. 19"		0101000020E6100000A0A70183A421464003ECA353572A4740
37788	2	19	\N	11360	57355	\N	46.318421707341301	"Республика Калмыкия, город Элиста, МОУ ""Этнокультурная гимназия №8 имени Н.Очирова"", Хомутникова, д. 109 А"	Россия, республика Калмыкия, Элиста	0101000020E61000000B96EA025E244640D829560DC2284740
37784	2	19	\N	11360	57428	\N	46.33079	"Республика Калмыкия, город Элиста, жилой квартал ""Северный"", отделение почтовой связи №15"		0101000020E6100000A0A70183A421464003ECA353572A4740
37823	2	19	\N	11360	57359	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ""Средняя общеобразовательная школа №3"", С.Стальского д.6"		0101000020E6100000A0A70183A421464003ECA353572A4740
37780	2	19	\N	11360	57318	\N	46.33079	Республика Калмыкия, город Элиста, МОУ СОШ №21,  Г.Рокчинского, 7		0101000020E6100000A0A70183A421464003ECA353572A4740
37822	2	19	\N	11360	57322	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ "" Элистинский технический лицей"", Пушкина д.3"		0101000020E6100000A0A70183A421464003ECA353572A4740
37812	2	19	\N	11360	57322	\N	46.33079	"Республика Калмыкия, город Элиста, ГГКУ ""Калмконцерт"", Пушкина д. 5"	Россия, республика Калмыкия, Элиста	0101000020E6100000A0A70183A421464003ECA353572A4740
37806	2	19	\N	11360	57328	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ""РНГ"", Николаева д. 55"		0101000020E6100000A0A70183A421464003ECA353572A4740
37825	2	19	\N	11360	57313	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ""Начальная общеобразовательная школа №22"", поселок Аршан, ул.Мира д. 25"		0101000020E6100000A0A70183A421464003ECA353572A4740
37820	2	19	\N	11360	57348	\N	46.33079	"Республика Калмыкия, город Элиста, РГУ ""Элистинское лесничество"", Лесная д.11"		0101000020E6100000A0A70183A421464003ECA353572A4740
37819	2	19	\N	11360	57326	\N	46.308727310770699	"Республика Калмыкия, город Элиста, МОУ ""Средняя общеобразовательная школа №2"", Ленина д. 52"	Россия, республика Калмыкия, Элиста	0101000020E610000033C34659BF1F46403332C85D84274740
37805	2	19	\N	11360	57315	\N	46.310154815086399	"Республика Калмыкия, город Элиста, КРО ""Всероссийское добровольное пожарное общество"", Ленина, д.276"	Россия, республика Калмыкия, Элиста	0101000020E6100000E3FE23D3A11F46406FD8B628B3274740
37802	2	19	\N	11360	57315	\N	46.308705005718501	"Республика Калмыкия, город Элиста, МОУ ""Калмыцкая национальная гимназия"", Ленина, д.209"	Россия, республика Калмыкия, Элиста	0101000020E6100000132A38BC202046404C8E3BA583274740
37799	2	19	\N	11360	57315	\N	46.310199423992501	"Республика Калмыкия, город Элиста, МОУ ""Калмыцкая национальная гимназия"", Ленина, д.291"	Россия, республика Калмыкия, Элиста	0101000020E6100000B726DD96C82346403E20D099B4274740
37795	2	19	\N	11360	57315	\N	46.309560026174999	"Республика Калмыкия, город Элиста, ГОУ ""Калмыцкий медицинский колледж им.Т.Хахлыновой"", Ленина, д. 237 А"	Россия, республика Калмыкия, Элиста	0101000020E610000059A31EA2D11F46402B137EA99F274740
37789	2	19	\N	11360	57315	\N	46.33079	"Республика Калмыкия, город Элиста, ""Калмыцкое дорожное управление"", Ленина, д.10"	Россия, республика Калмыкия, Элиста	0101000020E6100000A0A70183A421464003ECA353572A4740
37811	2	19	\N	11360	57324	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ДОД ""Детская школа искусств №1"", Леваневского д. 18"		0101000020E6100000A0A70183A421464003ECA353572A4740
37794	2	19	\N	11360	57358	\N	46.33079	Республика Калмыкия, город Элиста, МОУ СОШ №4, Илишкина, д.16		0101000020E6100000A0A70183A421464003ECA353572A4740
37793	2	19	\N	11360	57445	\N	46.33079	"Республика Калмыкия, город Элиста, ГСУ СО ""Элистинский дом-интернат для престарелых и инвалидов, Добровольского, д.2"		0101000020E6100000A0A70183A421464003ECA353572A4740
37798	2	19	\N	11360	57364	\N	46.307540949726402	"Республика Калмыкия, город Элиста, МОУ ЦООД РК ""Элистинский лицей"", Губаревича, д.14"	Россия, республика Калмыкия, Элиста	0101000020E6100000639B5434D6224640EE96E4805D274740
37824	2	19	\N	11360	57365	\N	46.275024661354003	Республика Калмыкия, город Элиста, поселок Аршан, Гагарина д.34	Россия, республика Калмыкия, Целинный район, село Солнечный	0101000020E610000073D87DC7F01C46408C4AEA0434234740
37791	2	19	\N	11360	57327	\N	46.33079	Республика Калмыкия, город Элиста, МОУ СОШ №23, Волгоградская, д.59А		0101000020E6100000A0A70183A421464003ECA353572A4740
37790	2	19	\N	11360	57327	\N	46.33079	Республика Калмыкия, город Элиста, МОУ СОШ №23, Волгоградская, д.59 А		0101000020E6100000A0A70183A421464003ECA353572A4740
38003	2	19	417	22377	57390	\N	46.202238999999999	село Эсто-Алтай, имени Карла Маркса, администрация СМО		0101000020E6100000FC010F0C201E4540E57CB1F7E2194740
37817	2	19	\N	11360	57317	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ""Элистинская многопрофильная гимназия"", 8микрорайон д.21а"		0101000020E6100000A0A70183A421464003ECA353572A4740
37816	2	19	\N	11360	57323	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ""Элистинская многопрофильная гимназия"", 8 микрорайон д. 21а"		0101000020E6100000A0A70183A421464003ECA353572A4740
37815	2	19	\N	11360	57323	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ""Средняя общеобразовательная школа №18"", 8 микрорайон д.19"	Россия, республика Калмыкия, Элиста	0101000020E6100000A0A70183A421464003ECA353572A4740
37792	2	19	\N	11360	57323	\N	46.324992692632598	"Республика Калмыкия, город Элиста, МУ ""ЦГБ им. А.С. Пушкина"", 8 микрорайон д.67а"	Россия, республика Калмыкия, Элиста	0101000020E6100000865AD3BCE3224640E736E15E99294740
37787	2	19	\N	11360	57357	\N	46.315686040410299	"Республика Калмыкия, город Элиста, ФГОУ СПО ""КГТЭК"", 8 Марта, д.26"	Россия, республика Калмыкия, Элиста	0101000020E6100000018750A5662146400CE71A6668284740
37813	2	19	\N	11360	57344	\N	46.300696900848997	"Республика Калмыкия, город Элиста, МОУ ""Средняя общеобразовательная школа №20"", 6 микрорайон д. 18"	Россия, республика Калмыкия, Элиста	0101000020E6100000A5164A26A7244640AE80423D7D264740
37807	2	19	\N	11360	57339	\N	46.33079	"Республика Калмыкия, город Элиста, здание ""Калмыцкого государственного университета"", 5 мкр. 3 корпус"		0101000020E6100000A0A70183A421464003ECA353572A4740
37809	2	19	\N	11360	57330	\N	46.33079	"Республика Калмыкия, город Элиста, МОУ ""Элистинская классическая гимназия"", 4 мкр, д.51"		0101000020E6100000A0A70183A421464003ECA353572A4740
37808	2	19	\N	11360	57360	\N	46.33079	Республика Калмыкия, город Элиста, Вечерняя (сменная) общеобразовательная школа №25, 3 мкр, д.8		0101000020E6100000A0A70183A421464003ECA353572A4740
94423	2	19	\N	11360	57351	\N	46.33079	"Республика Калмыкия, город Элиста, МБОУ ""СОШ №12"" , 3мкр, д.26"		0101000020E6100000A0A70183A421464003ECA353572A4740
37786	2	19	\N	11360	57346	\N	46.33079	"Республика Калмыкия, город Элиста, ГУ ""Государствен. калмыцкий ансамбль песни и танца ""Тюльпан"", 28 Армии. д. 25"	Россия, республика Калмыкия, Элиста	0101000020E6100000A0A70183A421464003ECA353572A4740
37804	2	19	\N	11360	57342	\N	46.306898266108902	"Республика Калмыкия, город Элиста, здание базовой НОШ ""Алтн Гасн"", 2мкр"	Россия, республика Калмыкия, Элиста	0101000020E6100000394371C79B264640999A046F48274740
94422	2	19	\N	11360	57349	\N	46.33079	"Республика Калмыкия, город Элиста, МБОУ ""СОШ №10"" им.Бембетова В.А., 1мкр, д.8"		0101000020E6100000A0A70183A421464003ECA353572A4740
37796	2	19	\N	11360	57349	\N	46.33079	Республика Калмыкия, город Элиста, МОУ СОШ №10, 1мкр, д.8	Россия, республика Калмыкия, Элиста	0101000020E6100000A0A70183A421464003ECA353572A4740
37782	2	19	\N	11360	57356	\N	46.33079	Республика Калмыкия, город Элиста, МОУ Начальная общеобразовательная школа №25, 1 мкр,  д.1А		0101000020E6100000A0A70183A421464003ECA353572A4740
37821	2	19	\N	11360	57363	\N	46.33079	"Республика Калмыкия, город Элиста, МУ ""Городская поликлиника"", Маяковского д. 57"	Россия, республика Калмыкия, Элиста	0101000020E6100000A0A70183A421464003ECA353572A4740
37884	2	19	\N	57159	57458	\N	45.392891707699398	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, микрорайон, 60	Россия, республика Калмыкия, Лаганский район, Лагань	0101000020E610000063D34A2190AF4740166EF9484AB24640
37886	2	19	\N	57159	57373	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Свердлова, 124	Россия, республика Калмыкия, Лаганский район, Лагань	0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37893	2	19	\N	57159	57415	\N	45.3933082984992	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Пришкольная, 3 а	Россия, республика Калмыкия, Лаганский район, Лагань	0101000020E6100000B88FDC9A74AF4740A9A0A2EA57B24640
37896	2	19	\N	57159	57456	\N	45.397661884270299	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Колхозная, 44	Россия, республика Калмыкия, Лаганский район, Лагань	0101000020E61000004DA1F31ABBAE4740546EA296E6B24640
37894	2	19	\N	57159	57387	\N	45.390042621834901	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Дружбы, 9	Россия, республика Калмыкия, Лаганский район, Лагань	0101000020E610000094A5D6FB8DAE47405184D4EDECB14640
37833	2	19	\N	57156	\N	\N	46.084142	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Городовиковское городское муниципальное образование Республики Калмыкия, Здание МОУ ""Городовиковская средняя школа № 2"""	Россия, республика Калмыкия, Городовиковский район, Городовиковск	0101000020E6100000E4D87A8670F644402A1C412AC50A4740
38005	2	19	417	57155	57345	\N	46.340900139572298	село Яшалта, переулок Школьный, 2	Россия, республика Калмыкия, Яшалтинский район, поселок городского типа Яшалта	0101000020E610000010C99063EB2345406B9A779CA22B4740
38004	2	19	417	22386	57325	\N	46.339948999999997	село Яшалта, Ленина, 10		0101000020E6100000389F3A562923454069A7E672832B4740
37826	2	19	\N	57156	\N	\N	46.087841936783697	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Городовиковское городское муниципальное образование Республики Калмыкия, Здание учебного корпуса БАК КГУ	Россия, республика Калмыкия, Городовиковский район, Городовиковск	0101000020E610000010E7E104A6F544408D9B1A683E0B4740
38017	2	19	1925	32542	\N	\N	46.170611999999998	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Уттинское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, поселок Яшкуль	0101000020E61000000420EEEA55AC46400F27309DD6154740
38014	2	19	1925	32542	57388	\N	46.170611999999998	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Привольненское сельское муниципальное образование Республики Калмыкия, Ленина, 6		0101000020E61000000420EEEA55AC46400F27309DD6154740
38007	2	19	1925	32542	57336	\N	46.170611999999998	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Яшкульское сельское муниципальное образование Республики Калмыкия, Клыкова, 86		0101000020E61000000420EEEA55AC46400F27309DD6154740
38006	2	19	1925	32542	57427	\N	46.170611999999998	"Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Яшкульское сельское муниципальное образование Республики Калмыкия, Кирова, 16""б"""		0101000020E61000000420EEEA55AC46400F27309DD6154740
38010	2	19	1925	57153	57353	\N	46.171443713019499	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Яшкульское сельское муниципальное образование Республики Калмыкия, Лиджиева, 2	Россия, республика Калмыкия, Яшкульский район, поселок городского типа Яшкуль	0101000020E61000001EDFDE35E8AB4640378C82E0F1154740
38008	2	19	1925	57153	57335	\N	46.170611999999998	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Яшкульское сельское муниципальное образование Республики Калмыкия, Леджинова, 1	Россия, республика Калмыкия, Яшкульский район, поселок городского типа Яшкуль	0101000020E61000000420EEEA55AC46400F27309DD6154740
38022	2	19	1925	57184	\N	\N	46.345517999999998	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Элвгинское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, село Элвг	0101000020E610000062BD512B4C734640F4160FEF392C4740
38021	2	19	1925	57163	\N	\N	46.482283000000002	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Чилгирское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, село Чилгир	0101000020E6100000C5CBD3B9A286464059350873BB3D4740
38020	2	19	1925	57190	\N	\N	46.047905999999998	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Цаган-Уснское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, село Цаган Усн	0101000020E6100000BA6A9E23F2A546401EA4A7C821064740
38019	2	19	1925	57182	\N	\N	46.317366	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Хулхутинское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, село Хулхута	0101000020E61000005ABA826DC42F4740616EF7729F284740
38018	2	19	1925	57204	57471	\N	46.097411666105202	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Хартолгинское сельское муниципальное образование Республики Калмыкия, Советская, 26	Россия, республика Калмыкия, Яшкульский район, село Хар Толга	0101000020E6100000E333D93F4F8D4640751E15FF770C4740
38016	2	19	1925	57168	\N	\N	46.309156000000002	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Уланэргинское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, село Улан Эрге	0101000020E610000098FC4FFEEE6D46405CAE7E6C92274740
38015	2	19	1925	57196	\N	\N	46.019186959750201	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Тавнгашунское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, село Тавн Гашун	0101000020E6100000E2E7BF07AFF5464012C138B874024740
38013	2	19	1925	57189	\N	\N	46.591485170050397	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Молодежненское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Яшкульский район, село Молодежный	0101000020E6100000B58828266F1C47408B89CDC7B54B4740
38012	2	19	1925	57195	57461	\N	46.211392795374898	Республика Калмыкия, Яшкульское районное муниципальное образование Республики Калмыкия, Гашунское сельское муниципальное образование Республики Калмыкия, 60 лет Октября, 27	Россия, республика Калмыкия, Яшкульский район, село Гашун	0101000020E6100000E31A9FC9FE8B46403ACD02ED0E1B4740
14062	1	17	\N	3130	22688	\N	58.045848999999997	г. Рыбинск, Щепкина, 19		0101000020E6100000B3614D65516C4340F3C64961DE054D40
38002	2	19	417	46412	57338	\N	46.281939000000001	село Ульяновское, Школьная, 6		0101000020E61000004CFDBCA948214540C53BC09316244740
38001	2	19	417	22275	57366	\N	46.228012	село Соленое, Ленина, 38		0101000020E6100000B8ACC266804545403B8C497F2F1D4740
37997	2	19	417	46313	\N	\N	46.149287999999999	село Матросово, здание Матросовской начальной школы	Россия, республика Калмыкия, Яшалтинский район, село Матросово	0101000020E61000002B3410CB66484540B6D782DE1B134740
37999	2	19	417	57169	57409	\N	46.414507821133398	село Манычское, Школьная, 2	Россия, республика Калмыкия, Яшалтинский район, село Манычский	0101000020E6100000E126A3CA302E454016F71F990E354740
37998	2	19	417	46346	\N	\N	46.096736	"село Красный Партизан, Центральная, столовая СПК ""Яшалтинский"""		0101000020E6100000BEDEFDF15E594540452C62D8610C4740
36352	2	19	417	45563	57443	\N	46.542262000000001	село Красный Маныч, Центральная, 60		0101000020E6100000EA3C2AFEEF16454089EE59D768454740
37994	2	19	417	57199	57467	\N	46.215342468659401	село Краснополье, переулок Спортивный, 11	Россия, республика Калмыкия, Яшалтинский район, село Краснополье	0101000020E610000027BD6F7CED2D454045BA9F53901B4740
37996	2	19	417	22025	57404	\N	46.166485999999999	село Красномихайловское, Школьная, 3		0101000020E6100000342E1C08C9444540F59ECA694F154740
37993	2	19	417	21882	57403	\N	46.258815265552798	село Березовское, Кооперативная, сельский Дом культуры	Россия, республика Калмыкия, Яшалтинский район, село Березовское	0101000020E6100000DA756F45623245406C5B94D920214740
36281	2	19	417	2227	57453	\N	46.454307999999997	село Бага-Тугтун, Пионерская, 10		0101000020E6100000062E8F35231D4540D427B9C3263A4740
37986	2	19	1559	21545	\N	\N	47.122644999999999	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Юстинское сельское муниципальное образование Республики Калмыкия, поселок Юста, сельский Дом культуры		0101000020E6100000855D143DF02547404B02D4D4B28F4740
37992	2	19	1559	21848	\N	\N	46.866079415675202	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Эрдниевское сельское муниципальное образование Республики Калмыкия, поселок Эрдниевский, сельский Дом культуры	Россия, республика Калмыкия, Юстинский район, село Эрдниевский	0101000020E6100000CDAB3AAB052447404E603AADDB6E4740
37985	2	19	1559	21498	\N	\N	47.353535000000001	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Татальское сельское муниципальное образование Республики Калмыкия, поселок Чомпот, здание ФАП	Россия, республика Калмыкия, Юстинский район, село Чомпот	0101000020E6100000CDE847C329374740E57E87A240AD4740
37980	2	19	1559	33019	57389	\N	47.557046999999997	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Цаганаманское сельское муниципальное образование Республики Калмыкия, поселок Цаган Аман, пер.Мацакова, 5		0101000020E6100000E606431D565C4740DEAAEB504DC74740
37979	2	19	1559	33019	57432	\N	47.557046999999997	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Цаганаманское сельское муниципальное образование Республики Калмыкия, поселок Цаган Аман, Хомутникова, 5		0101000020E6100000E606431D565C4740DEAAEB504DC74740
37982	2	19	1559	33019	57376	\N	47.557046999999997	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Цаганаманское сельское муниципальное образование Республики Калмыкия, поселок Цаган Аман, Советская, 154		0101000020E6100000E606431D565C4740DEAAEB504DC74740
37977	2	19	1559	33019	57400	\N	47.557046999999997	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Цаганаманское сельское муниципальное образование Республики Калмыкия, поселок Цаган Аман, Кирова, 2		0101000020E6100000E606431D565C4740DEAAEB504DC74740
37981	2	19	1559	33019	57402	\N	47.557046999999997	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Цаганаманское сельское муниципальное образование Республики Калмыкия, поселок Цаган Аман, Городовикова, 114		0101000020E6100000E606431D565C4740DEAAEB504DC74740
37978	2	19	1559	57165	57383	\N	47.557046999999997	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Цаганаманское сельское муниципальное образование Республики Калмыкия, поселок Цаган Аман, пер. Школьный, 6	Россия, республика Калмыкия, Юстинский район, поселок городского типа Цаган Аман	0101000020E6100000E606431D565C4740DEAAEB504DC74740
37989	2	19	1559	21712	\N	\N	47.014128999999997	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Харбинское сельское муниципальное образование Республики Калмыкия, поселок Харба, сельский Дом культуры		0101000020E6100000ADA3AA09A24C47406C76A4FACE814740
37984	2	19	1559	21463	\N	\N	47.285375000000002	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Татальское сельское муниципальное образование Республики Калмыкия, поселок Татал, сельский Дом культуры	Россия, республика Калмыкия, Юстинский район, село Татал	0101000020E610000017618A72692247404A0C022B87A44740
38000	2	19	1559	57175	57429	\N	47.025690129514501	село Октябрьское, Центральная, 15	Россия, республика Калмыкия, Юстинский район, село Октябрьский	0101000020E6100000D6A8876874154740C8EA56CF49834740
14879	2	18	\N	57030	56643	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Привокзальная, 130"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
37991	2	19	1559	57192	\N	\N	47.110923409863098	"Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Бергинское сельское муниципальное образование Республики Калмыкия, поселок Бергин, здание молодежного центра ""Бергин"""	Россия, республика Калмыкия, Юстинский район	0101000020E6100000D0B9DBF5D2204740E6AF90B9328E4740
37987	2	19	1559	21609	\N	\N	47.110657000000003	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Юстинское сельское муниципальное образование Республики Калмыкия, поселок Белоозерный, сельский Дом культуры		0101000020E610000023A30392B0FB4640680932022A8E4740
37990	2	19	1559	21730	\N	\N	47.559649999999998	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Барунское сельское муниципальное образование Республики Калмыкия, поселок Барун, здание Барунской средней школы	Россия, республика Калмыкия, Юстинский район, село Барун	0101000020E6100000FAD4B14AE9E746406B9A779CA2C74740
37785	2	19	7420	57185	57442	\N	46.361932000000003	Республика Калмыкия, город Элиста пос. Салын, Школьная, 2	Россия, республика Калмыкия, Элиста городской округ, село Салын	0101000020E610000004C93B87321A46401DB0ABC9532E4740
37976	2	19	1928	57187	57450	\N	45.820774	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Сарульское сельское муниципальное образование Республики Калмыкия, Интернациональная, 2	Россия, республика Калмыкия, Черноземельский район, село Сарул	0101000020E6100000C5E2378595BC46401CB4571F0FE94640
37975	2	19	1928	32999	57405	\N	45.252133999999998	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Прикумское сельское муниципальное образование Республики Калмыкия, Комсомольская, 12		0101000020E6100000FE614B8FA6E84640D61A4AED45A04640
37974	2	19	1928	57203	57470	\N	45.435237000000001	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Нарынхудукское сельское муниципальное образование Республики Калмыкия, Советская, 5/1	Россия, республика Калмыкия, Черноземельский район, село Нарын Худук	0101000020E6100000EC51B81E854547402C8194D8B5B74640
37856	2	19	1928	52910	\N	\N	45.170158999999998	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Манычское сельское муниципальное образование Республики Калмыкия, село Маныч, Здание дома культуры	Россия, республика Калмыкия, Черноземельский район, село Маныч	0101000020E610000036E50AEF72C146405E0F26C5C7954640
37973	2	19	1928	57198	57465	\N	44.978302598390798	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Кумское сельское муниципальное образование Республики Калмыкия, Ленина, 4	Россия, республика Калмыкия, Черноземельский район, село Кумской	0101000020E61000006DA818E76F084740124A5F08397D4640
37971	2	19	1928	57170	57420	\N	45.329264000000002	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Комсомольское сельское муниципальное образование Республики Калмыкия, Ленина, 54		0101000020E6100000A759A0DD2105474005E09F5225AA4640
37970	2	19	1928	32984	57397	\N	45.329264000000002	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Комсомольское сельское муниципальное образование Республики Калмыкия, Некрасова, 60		0101000020E6100000A759A0DD2105474005E09F5225AA4640
37972	2	19	1928	32984	57399	\N	45.329264000000002	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Комсомольское сельское муниципальное образование Республики Калмыкия, Ленина, 38		0101000020E6100000A759A0DD2105474005E09F5225AA4640
37969	2	19	1928	32984	57347	\N	45.3295027643616	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Комсомольское сельское муниципальное образование Республики Калмыкия, Аллея Памяти, 43	Россия, республика Калмыкия, Черноземельский район, поселок городского типа Комсомольский	0101000020E6100000E7C41EDAC70447408A7780272DAA4640
37968	2	19	1928	57161	57375	\N	45.406659240499401	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Ачинеровское сельское муниципальное образование Республики Калмыкия, Ленина, 12	Россия, республика Калмыкия, Черноземельский район, село Ачинеры	0101000020E61000005FCE6C57E8AD4640E1CFF0660DB44640
37965	2	19	1928	32962	57398	\N	44.946801999999998	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Артезианское сельское муниципальное образование Республики Калмыкия, переулок Кооперативный, 10		0101000020E610000043E7357689544740C9E4D4CE30794640
37966	2	19	1928	32962	57422	\N	44.943998102433	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Артезианское сельское муниципальное образование Республики Калмыкия, Советская, 8	Россия, республика Калмыкия, Черноземельский район, село Артезиан	0101000020E61000002828452BF7544740A5BE2CEDD4784640
46811	2	20	251	1488	20631	\N	44.861246999999999	село Коноково, Калинина, 22, телефон: 67321		0101000020E6100000E415889E94A94440996379573D6E4640
37967	2	19	1928	32962	57437	\N	44.943770350851601	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Артезианское сельское муниципальное образование Республики Калмыкия, Д. Адьянова, 20	Россия, республика Калмыкия, Черноземельский район, село Артезиан	0101000020E6100000CF4BC5C6BC54474014799274CD784640
37964	2	19	1928	57172	57423	\N	45.803032999999999	Республика Калмыкия, Черноземельское районное муниципальное образование Республики Калмыкия, Адыковское сельское муниципальное образование Республики Калмыкия, Мира, 2	Россия, республика Калмыкия, Черноземельский район, село Адык	0101000020E6100000A8AB3B16DBD04640EC4D0CC9C9E64640
37962	2	19	1607	20295	\N	\N	46.537978000000003	село Ялмта, здание администрации Ялмтинского СМО	Россия, республика Калмыкия, Целинный район, село Ялмта	0101000020E6100000C47AA35698724640D7FB8D76DC444740
37961	2	19	1607	20272	\N	\N	46.726475000000001	село Чагорта, здание администрации Чагортинского СМО	Россия, республика Калмыкия, Целинный район, село Чагорта	0101000020E6100000C289E8D7D6FB4540492EFF21FD5C4740
37959	2	19	1607	20115	\N	\N	46.310681000000002	село Хар-Булук	Россия, республика Калмыкия, Целинный район, село Хар-Булук	0101000020E61000002B137EA99FFD45408A3E1F65C4274740
35330	2	19	1607	32888	\N	\N	46.419330000000002	село Троицкое, СУ-959, дом 45		0101000020E61000001D93C5FD47204640A81DFE9AAC354740
35596	2	19	1607	32888	57378	\N	46.418139359452098	село Троицкое, Чапаева, дом 43	Россия, республика Калмыкия, Целинный район, село Троицкое	0101000020E61000001A69A9BC1D2146405017299485354740
35468	2	19	1607	32888	57331	\N	46.416777532119603	село Троицкое, Физкультурная, дом 5	Россия, республика Калмыкия, Целинный район, село Троицкое	0101000020E61000009607E929722046409DD843FB58354740
35134	2	19	1607	32888	57352	\N	46.419330000000002	"село Троицкое, Пушкина, дом 1 ""а"""		0101000020E61000001D93C5FD47204640A81DFE9AAC354740
37881	2	19	1607	32888	57361	\N	46.419330000000002	село Троицкое, Октябрьская, дом 1 кв.2		0101000020E61000001D93C5FD47204640A81DFE9AAC354740
35571	2	19	1607	32888	57426	\N	46.418614240280498	село Троицкое, Ленина, дом 4	Россия, республика Калмыкия, Целинный район, село Троицкое	0101000020E6100000ABCC94D6DF204640E9D2BF2495354740
37921	2	19	1607	32888	57370	\N	46.456933999999997	"село Троицкое, Колхозная, дом 25 ""а"""		0101000020E6100000471CB28174734640193735D07C3A4740
37963	2	19	1607	32888	57354	\N	46.419330000000002	"село Троицкое, Геологическа, 37  ""а"""		0101000020E61000001D93C5FD47204640A81DFE9AAC354740
37958	2	19	1607	20069	\N	\N	46.8504997028041	"село Овата, здание МОУ ""Оватинская средняя школа"""	Россия, республика Калмыкия, Целинный район, село Овата	0101000020E61000005264ADA1D4304640BE9F1A2FDD6C4740
37957	2	19	1607	19995	\N	\N	46.624144000000001	село Найнтахн, здание администрации Найнтахинского СМО	Россия, республика Калмыкия, Целинный район, село Найнтахн	0101000020E6100000278925E5EE07464050FF59F3E34F4740
37956	2	19	1607	57174	\N	\N	46.417964176533097	Республика Калмыкия, Целинное районное муниципальное образование Республики Калмыкия, Ики-Чоносовское сельское муниципальное образование Республики Калмыкия, здание администрации Ики-Чоносовского СМО	Россия, республика Калмыкия, Целинный район, село Ики-Чонос	0101000020E6100000211D1EC2F83D4640E27327D87F354740
37955	2	19	1607	19898	\N	\N	46.268166000000001	село Вознесеновка, здание сельского Дома культуры	Россия, республика Калмыкия, Целинный район, село Вознесеновка	0101000020E6100000D4B5F63E552D464017F3734353224740
37954	2	19	1607	19830	\N	\N	46.493848	"село Верхний Яшкуль, здание МОУ ""Верхнеяшкульская средняя школа"""	Россия, республика Калмыкия, Целинный район, село Верхняя Яшкуль	0101000020E61000002A8C2D0439144640F6984869363F4740
37953	2	19	1607	19809	\N	\N	46.721637999999999	село Бага-Чонос, здание администрации Бага-Чоносовского СМО	Россия, республика Калмыкия, Целинный район, село Бага-Чонос	0101000020E6100000BBB6B75B9235464082C64CA25E5C4740
37960	2	19	1607	20186	\N	\N	46.666632999999997	село Аршан-Булг, здание администрации Целинного СМО	Россия, республика Калмыкия, Целинный район, село Аршан-Булг	0101000020E6100000B96E4A79AD42464099B7EA3A54554740
37942	2	19	1927	32778	\N	\N	47.667782409267602	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Шарнутовское сельское муниципальное образование Республики Калмыкия	Россия, республика Калмыкия, Сарпинский район, село Шарнут	0101000020E61000000053060E68E34540C26D6DE179D54740
37941	2	19	1927	32778	57394	\N	47.667724	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Шарнутовское сельское муниципальное образование Республики Калмыкия, Хомутникова, 11		0101000020E6100000054D4BAC8CE245408D60E3FA77D54740
37951	2	19	1927	57186	57449	\N	47.7328660960832	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Уманцевское сельское муниципальное образование Республики Калмыкия, Ленина, 1	Россия, республика Калмыкия, Сарпинский район, село Уманцево	0101000020E6100000FFCEF6E80D234640D82C978DCEDD4740
37949	2	19	1927	57183	57441	\N	47.507031809222802	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Салынтугтунское сельское муниципальное образование Республики Калмыкия, Школьная, 11	Россия, республика Калмыкия, Сарпинский район, село Салын Тугтун	0101000020E61000001F1329CDE6EF45404303B16CE6C04740
14878	2	18	\N	57030	56643	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Привокзальная, 288-А"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
37948	2	19	1927	57183	57454	\N	47.5061925029406	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Салынтугтунское сельское муниципальное образование Республики Калмыкия, Бадмаева, 15	Россия, республика Калмыкия, Сарпинский район, село Салын Тугтун	0101000020E61000004485EAE6E2EF4540693BA6EECAC04740
37940	2	19	1927	57154	57337	\N	47.773485000000001	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Садовское сельское муниципальное образование Республики Калмыкия, Ленина, 120	Россия, республика Калмыкия, Сарпинский район, село Садовое	0101000020E610000063416150A64146402979758E01E34740
37938	2	19	1927	57154	57337	\N	47.778033530612099	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Садовское сельское муниципальное образование Республики Калмыкия, Ленина, 95	Россия, республика Калмыкия, Сарпинский район, село Садовое	0101000020E610000094BF7B478D41464089963C9E96E34740
37939	2	19	1927	57154	57372	\N	47.773485000000001	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Садовское сельское муниципальное образование Республики Калмыкия, Дорожная, 10	Россия, республика Калмыкия, Сарпинский район, село Садовое	0101000020E610000063416150A64146402979758E01E34740
37947	2	19	1927	32825	57419	\N	47.512017	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Обильненское сельское муниципальное образование Республики Калмыкия, Колхозная, 1		0101000020E610000065A88AA9F43546407EFFE6C589C14740
37946	2	19	1927	57205	57472	\N	47.817533717939803	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Коробкинское сельское муниципальное образование Республики Калмыкия, Школьная, 12	Россия, республика Калмыкия, Сарпинский район, село Коробкин	0101000020E61000007D91D096733146401DAF40F4A4E84740
37945	2	19	1927	57191	57464	\N	47.6430185332378	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Кировское сельское муниципальное образование Республики Калмыкия, Центральная, 49	Россия, республика Калмыкия, Сарпинский район, село Кировский	0101000020E6100000E82D1EDE7340464073DA53724ED24740
37944	2	19	1927	57191	57455	\N	47.645222682058801	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Кировское сельское муниципальное образование Республики Калмыкия, Зеленая, 42	Россия, республика Калмыкия, Сарпинский район, село Кировский	0101000020E610000086E63A8DB440464042D0D1AA96D24740
37943	2	19	1927	57160	57374	\N	47.598995000000002	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Кануковское сельское муниципальное образование Республики Калмыкия, Лесная, 2	Россия, республика Калмыкия, Сарпинский район, село Кануково	0101000020E6100000AC1919E42E064640D8BB3FDEABCC4740
37952	2	19	1927	57164	57380	\N	47.6111766378475	Республика Калмыкия, Сарпинское районное муниципальное образование Республики Калмыкия, Аршаньзельменское сельское муниципальное образование Республики Калмыкия, Дорожная, 1	Россия, республика Калмыкия, Сарпинский район, село Аршань-Зельмень	0101000020E610000004560E2DB24D4640A088450C3BCE4740
37937	2	19	1542	18955	57425	\N	46.127755999999998	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Ульдючинское сельское муниципальное образование Республики Калмыкия, село Ульдючины, улица Дружбы, 28		0101000020E610000008E412471EE2454013EF004F5A104740
37934	2	19	1542	18763	57362	\N	46.100380000000001	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Приютненское сельское муниципальное образование Республики Калмыкия, село Приютное, улица Московская, 85, здание Приютненского СМО		0101000020E61000001DAED51EF6C0454014967840D90C4740
37936	2	19	1542	18763	57343	\N	46.100380000000001	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Приютненское сельское муниципальное образование Республики Калмыкия, село Приютнок, улица Канукова, 1, здание ПСШ №2	Россия, республика Калмыкия, Приютненский район, село Приютное	0101000020E61000001DAED51EF6C0454014967840D90C4740
37935	2	19	1542	18763	57385	\N	46.100380000000001	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Приютненское сельское муниципальное образование Республики Калмыкия, село Приютное, улица Ильина, 4, здание Дорожного участка		0101000020E61000001DAED51EF6C0454014967840D90C4740
37933	2	19	1542	18763	57333	\N	46.0979916277931	"Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Приютненское сельское муниципальное образование Республики Калмыкия, село Приютное, улица Гагарина, 75, здание МОУ ""ПСШ №1"""	Россия, республика Калмыкия, Приютненский район, село Приютное	0101000020E6100000FAD170CADCC0454083A279008B0C4740
14917	2	18	\N	57030	56615	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Первомайская, 208"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
37932	2	19	1542	18686	57466	\N	46.234352000000001	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Песчаное сельское муниципальное образование Республики Калмыкия, поселок Песчаный, ул.Гагарина, 1 а		0101000020E61000006E6DE179A914464048E00F3FFF1D4740
37931	2	19	1542	32706	57371	\N	45.881495000000001	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Первомайское сельское муниципальное образование Республики Калмыкия, поселок Первомайский, ул.Советская, 13		0101000020E6100000DD408177F2174640344B02D4D4F04640
37988	2	19	1542	52054	\N	\N	46.305002999999999	Республика Калмыкия, Юстинское районное муниципальное образование Республики Калмыкия, Юстинское сельское муниципальное образование Республики Калмыкия, поселок Октябрьский, здание бывшей Октябрьской начальной школы	Россия, республика Калмыкия, Приютненский район, село Октябрьский	0101000020E6100000035B25581C8E454048179B560A274740
37930	2	19	1542	52054	\N	\N	46.305002999999999	"Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Октябрьское сельское муниципальное образование Республики Калмыкия, поселок Октябрьский, МОУ ""Октябрьская  средняя общеобразовательная школа"""		0101000020E6100000035B25581C8E454048179B560A274740
37927	2	19	1542	18440	57452	\N	46.258657999999997	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Булуктинское сельское муниципальное образование Республики Калмыкия, поселок Нарын, ул. Степная, 10		0101000020E6100000F88DAF3DB31E4640A46C91B41B214740
37929	2	19	1542	18549	57459	\N	46.118555000000001	Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Нартинское сельское муниципальное образование Республики Калмыкия, поселок Нарта, ул.Школьная, 16		0101000020E6100000EA2285B2F0F145407EE36BCF2C0F4740
37928	2	19	1542	18471	\N	\N	46.203279999999999	"Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Воробьевское сельское муниципальное образование Республики Калмыкия, село Воробьевка, МОУ ""Воробьевская средняя общеобразовательная школа"""		0101000020E610000005FD851E31E2454027F73B14051A4740
37926	2	19	1542	18358	\N	\N	46.224938000000002	"Республика Калмыкия, Приютненское районное муниципальное образование Республики Калмыкия, Булуктинское сельское муниципальное образование Республики Калмыкия, поселок Бурата, здание МОУ ""Булуктинская средняя общеобразовательная школа"""	Россия, республика Калмыкия, Приютненский район, село Бурата	0101000020E610000006F357C85C1F464057D0B4C4CA1C4740
37924	2	19	1926	32637	\N	\N	47.369295000000001	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Цаган-Нурское сельское муниципальное образование Республики Калмыкия, Санджирова, 60	Россия, республика Калмыкия, Октябрьский район, село Цаган Нур	0101000020E6100000F25EB532E19D4640C5C9FD0E45AF4740
37925	2	19	1926	57179	57438	\N	47.230404660890201	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Хошеутовское сельское муниципальное образование Республики Калмыкия, Октябрьская, 18	Россия, республика Калмыкия, Октябрьский район, село Хошеут	0101000020E6100000C3F17C06D4B34640DDEA39E97D9D4740
37920	2	19	1926	57188	57451	\N	47.793905392158401	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Мирненское сельское муниципальное образование Республики Калмыкия, Советская, 13	Россия, республика Калмыкия, Октябрьский район, село Мирный	0101000020E6100000B68311FB04C24640C190D5AD9EE54740
37923	2	19	1926	57180	57439	\N	47.432957999999999	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Иджилское сельское муниципальное образование Республики Калмыкия, Северная, 3	Россия, республика Калмыкия, Октябрьский район, село Иджил	0101000020E6100000132BA391CFC346405245F12A6BB74740
37922	2	19	1926	57177	57436	\N	47.659452999999999	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Джангарское сельское муниципальное образование Республики Калмыкия, Квартал, 1	Россия, республика Калмыкия, Октябрьский район, село Джангар	0101000020E6100000E95F92CA14E14640E21FB6F468D44740
37919	2	19	1926	57157	57368	\N	47.880806	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Восходовское сельское муниципальное образование Республики Калмыкия, Советская, 15	Россия, республика Калмыкия, Октябрьский район, село Восход	0101000020E610000097AB1F9BE4A546406F0F4240BEF04740
37916	2	19	1926	32600	57386	\N	47.850937999999999	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Большецарынское сельское муниципальное образование Республики Калмыкия, Советская, 1	Россия, республика Калмыкия, Октябрьский район, село Большой Царын	0101000020E61000004EB51666A1B746403A765089EBEC4740
14906	2	18	\N	57030	56615	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Первомайская, 268"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
37915	2	19	1926	32600	57334	\N	47.850937999999999	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Большецарынское сельское муниципальное образование Республики Калмыкия, Матросова, 4	Россия, республика Калмыкия, Октябрьский район, село Большой Царын	0101000020E61000004EB51666A1B746403A765089EBEC4740
37918	2	19	1926	32600	57396	\N	47.850937999999999	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Большецарынское сельское муниципальное образование Республики Калмыкия, Ломоносова, 1	Россия, республика Калмыкия, Октябрьский район, село Большой Царын	0101000020E61000004EB51666A1B746403A765089EBEC4740
37917	2	19	1926	32600	57392	\N	47.850937999999999	Республика Калмыкия, Октябрьское районное муниципальное образование Республики Калмыкия, Большецарынское сельское муниципальное образование Республики Калмыкия, Горького, 15		0101000020E61000004EB51666A1B746403A765089EBEC4740
37914	2	19	1491	17778	\N	\N	48.188583999999999	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Хончнурское сельское муниципальное образование Республики Калмыкия, п.Хонч-Нур, Номто Очирова, 7	Россия, республика Калмыкия, Малодербетовский район, село Хонч-Нур	0101000020E6100000D76A0F7BA18246404146408523184840
37913	2	19	1491	17762	57463	\N	47.701154000000002	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Ханатинское сельское муниципальное образование Республики Калмыкия, п.Ханата, Г.Даваева, 4		0101000020E61000002385B2F0F56F4640D4BA0D6ABFD94740
37912	2	19	1491	17682	57457	\N	47.818630401199599	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Ханатинское сельское муниципальное образование Республики Калмыкия, п.Унгун Терячи, пер.Школьный, 1	Россия, республика Калмыкия, Малодербетовский район, село Унгун-Терячи	0101000020E6100000AC730CC85E5B464022C32ADEC8E84740
37910	2	19	1491	17573	57321	\N	47.940102000000003	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Тундутовское сельское муниципальное образование Республики Калмыкия, с.Тундутово, Ленина, 154		0101000020E610000079CC4065FC4F4640BD73284355F84740
37909	2	19	1491	17539	57382	\N	48.135852	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Плодовитенское сельское муниципальное образование Республики Калмыкия, с. Плодовитое, А.Хадыкина, 31		0101000020E6100000E50CC51D6F364640508C2C9963114840
37908	2	19	1491	17366	57319	\N	47.949933999999999	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Малодербетовское сельское муниципальное образование Республики Калмыкия, с.Малые Дербеты, Советская, 8		0101000020E610000032005471E3564640E2ADF36F97F94740
37907	2	19	1491	17366	57319	\N	47.949933999999999	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Малодербетовское сельское муниципальное образование Республики Калмыкия, с. Малые Дербеты, Советская, 9		0101000020E610000032005471E3564640E2ADF36F97F94740
37906	2	19	1491	17366	57316	\N	47.949053254291996	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Малодербетовское сельское муниципальное образование Республики Калмыкия, с. Малые Дербеты, 40 лет Победы, 7	Россия, республика Калмыкия, Малодербетовский район, село Малые Дербеты	0101000020E61000009E077767ED564640D99596917AF94740
37905	2	19	1491	17345	57435	\N	48.022343999999997	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Ики-Бухусовское сельское муниципальное образование Республики Калмыкия, п.Ики-Манлан, Китидова, 2		0101000020E610000095D5743DD1D5464083A10E2BDC024840
37904	2	19	1491	17268	57447	\N	48.041752000000002	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Ики-Бухусовское сельское муниципальное образование Республики Калмыкия, п.Ики-Бухус, Э.Овла, 1		0101000020E610000036AE7FD7679C46407445292158054840
37911	2	19	1491	17644	\N	\N	47.637072000000003	Республика Калмыкия, Малодербетовское районное муниципальное образование Республики Калмыкия, Ханатинское сельское муниципальное образование Республики Калмыкия, п.Зурган, Городовикова, 10	Россия, республика Калмыкия, Малодербетовский район, село Зурган	0101000020E61000002A38BC20227D4640429946938BD14740
37901	2	19	1930	57173	57424	\N	45.442870141490097	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Уланхольское сельское муниципальное образование Республики Калмыкия, улица Советская, 24	Россия, республика Калмыкия, Лаганский район, поселок городского типа Улан Хол	0101000020E61000001FA16648156D47409430D3F6AFB84640
37900	2	19	1930	57173	57431	\N	45.444077999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Уланхольское сельское муниципальное образование Республики Калмыкия, улица Орджоникидзе, 26		0101000020E6100000D600A5A1466D4740C16F438CD7B84640
37883	2	19	1930	57171	64946	\N	45.438252044503102	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Пушкина, 61	Россия, республика Калмыкия, Лаганский район, поселок городского типа Улан Хол	0101000020E61000004A7EC4AF586D47400BB43BA418B84640
37903	2	19	1930	33143	57418	\N	45.371101000000003	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Северное сельское муниципальное образование Республики Калмыкия, улица Школьная, 30		0101000020E61000002E3883BF5FAA4740A741D13C80AF4640
37887	2	19	1930	33051	57381	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, переулок Почтовый, 12	Россия, республика Калмыкия, Лаганский район, Лагань	0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37880	2	19	1930	33051	57410	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, микрорайон, 70		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37889	2	19	1930	33051	57350	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Советская, 59	Россия, республика Калмыкия, Лаганский район, Лагань	0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37888	2	19	1930	33051	57414	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Свердлова, 16 а		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37897	2	19	1930	33051	57444	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Садовая, 58		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37891	2	19	1930	33051	57413	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Рабочая, 44		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37890	2	19	1930	33051	57393	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Колхозная, 1		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37885	2	19	1930	33051	57401	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Кирова, 7		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37882	2	19	1930	33051	57412	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Канукова, 44 а		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37895	2	19	1930	33051	57395	\N	45.388953999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Лаганское городское муниципальное образование Республики Калмыкия, улица Ермолинская, 33		0101000020E6100000494DBB9866AE4740FED2A23EC9B14640
37902	2	19	1930	33140	57416	\N	45.445208999999998	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Красинское сельское муниципальное образование Республики Калмыкия, улица Советская, 25		0101000020E6100000274D83A279AA47404371C79BFCB84640
37898	2	19	1930	57166	57391	\N	45.6073378359877	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Джалыковское сельское муниципальное образование Республики Калмыкия, улица Ленина, 25	Россия, республика Калмыкия, Лаганский район, село Джалыково	0101000020E610000036B05582C5B747401CCF6740BDCD4640
37899	2	19	1930	57166	57448	\N	45.608027999999997	Республика Калмыкия, Лаганское районное муниципальное образование Республики Калмыкия, Джалыковское сельское муниципальное образование Республики Калмыкия, улица Кирова, 14	Россия, республика Калмыкия, Лаганский район, село Джалыково	0101000020E6100000A182C30B22B84740B1868BDCD3CD4640
37877	2	19	1371	57201	57468	\N	47.341880000000003	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Чкаловское сельское муниципальное образование Республики Калмыкия, пос. Эвдык, Школьная, 1	Россия, республика Калмыкия, Кетченеровский район, село Эвдик	0101000020E6100000D7169E978A99464008944DB9C2AB4740
37870	2	19	1371	15604	57434	\N	47.397708000000002	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Кетченеровское сельское муниципальное образование Республики Калмыкия, пос. Шин-Мер, Октябрьская, 8		0101000020E61000007F880D164E424640C5AD8218E8B24740
14936	2	18	\N	57030	56755	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", поселок Родниковый, Мичурина, 34"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
37879	2	19	1371	16032	57417	\N	46.852085000000002	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Шаттинское сельское муниципальное образование Республики Калмыкия, пос. Шатта, Октябрьская, 16		0101000020E6100000EA04341136664640C2340C1F116D4740
37876	2	19	1371	15880	57446	\N	47.242001000000002	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Чкаловское сельское муниципальное образование Республики Калмыкия, пос. Чкаловский, Кошевого, 1		0101000020E61000002C9D0FCF12704640B64C86E3F99E4740
37878	2	19	1371	15974	57433	\N	47.405101000000002	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Тугтунское сельское муниципальное образование Республики Калмыкия, пос. Тугтун, Бадмаева, 15		0101000020E6100000B89388F02F864640D8497D59DAB34740
37875	2	19	1371	15845	57462	\N	47.081960000000002	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Сарпинское сельское муниципальное образование Республики Калмыкия, пос. Сарпа, Центральная, 11		0101000020E61000000F26C5C727C0464043CA4FAA7D8A4740
37868	2	19	1371	15375	57408	\N	47.307094999999997	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Кетченеровское сельское муниципальное образование Республики Калмыкия, пос. Кетченеры, Номто Очирова, 23		0101000020E610000098158A743F434640EFE192E34EA74740
37869	2	19	1371	15375	57407	\N	47.307094999999997	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Кетченеровское сельское муниципальное образование Республики Калмыкия, пос. Кетченеры, Ленина, 79		0101000020E610000098158A743F434640EFE192E34EA74740
37867	2	19	1371	15375	57407	\N	47.307094999999997	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Кетченеровское сельское муниципальное образование Республики Калмыкия, пос. Кетченеры, Ленина, 76		0101000020E610000098158A743F434640EFE192E34EA74740
37866	2	19	1371	15375	57379	\N	47.307094999999997	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Кетченеровское сельское муниципальное образование Республики Калмыкия, пос. Кетченеры, Заречная, 93		0101000020E610000098158A743F434640EFE192E34EA74740
37865	2	19	1371	15375	57384	\N	47.307094999999997	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Кетченеровское сельское муниципальное образование Республики Калмыкия, пос. Кетченеры, А. Мучкаева, 5		0101000020E610000098158A743F434640EFE192E34EA74740
37874	2	19	1371	15785	57411	\N	46.9334400356014	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Кегультинское сельское муниципальное образование Республики Калмыкия, пос. Кегульта, Центральная, 1	Россия, республика Калмыкия, Кетченеровский район, село Кегульта	0101000020E61000000B96EA025E3046409D6340F67A774740
37854	2	19	1371	14839	57406	\N	47.103076000000001	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Ергенинское сельское муниципальное образование Республики Калмыкия,пос. Ергенинский, Школьная, 10		0101000020E610000091813CBB7C3D464052802898318D4740
37873	2	19	1371	15744	57460	\N	47.017809871146298	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Ергенинское сельское муниципальное образование Республики Калмыкия, пос. Годжур, Мира, 7	Россия, республика Калмыкия, Кетченеровский район, село Годжур	0101000020E6100000A3737E8AE338464058C51B9947824740
37872	2	19	1371	57202	57469	\N	47.236995999999998	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Гашун-Бургустинское сельское муниципальное образование Республики Калмыкия, пос. Гашун-Бургуста, Манджиева, 18	Россия, республика Калмыкия, Кетченеровский район, село Гаршун-Бургуста	0101000020E6100000F436363B523F464033A48AE2559E4740
37871	2	19	1371	15647	57367	\N	47.038632	Республика Калмыкия, Кетченеровский районное муниципальное образование Республики Калмыкия, Алцынхутинское сельское муниципальное образование Республики Калмыкия, пос. Алцынхута, Чапчаева, 2	Россия, республика Калмыкия, Кетченеровский район, село Алцынхута	0101000020E6100000AD4ECE50DC7546401F4AB4E4F1844740
37863	2	19	1357	52927	\N	\N	45.524487000000001	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Чограйское сельское муниципальное образование Республики Калмыкия, село Южный, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Южный	0101000020E610000004E44BA8E0584640AD16D86322C34640
37858	2	19	1357	57178	\N	\N	46.122858194950197	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Оргакинское сельское муниципальное образование Республики Калмыкия, село Шеернг, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Шееринг	0101000020E6100000274BADF71B4D4640A7069ACFB90F4740
77350	2	23	\N	54820	40028	\N	47.739519999999999	Ростовская область, город Шахты, Энтузиастов, 103		0101000020E61000001553E9279C1D4440745E6397A8DE4740
37864	2	19	1357	15302	\N	\N	45.502065999999999	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Чолунхамурское сельское муниципальное образование Республики Калмыкия, село Чолун Хамур, Здание детского сада	Россия, республика Калмыкия, Ики-Бурульский район, село Чолун Хамур	0101000020E610000070B03731246D46407E37DDB243C04640
37862	2	19	1357	15206	\N	\N	45.605151999999997	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Хомутниковское сельское муниципальное образование Республики Калмыкия, село Хомутников, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Хомутников	0101000020E6100000BAD8B45208684640F38DE89E75CD4640
37861	2	19	1357	52921	\N	\N	45.876811479056002	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Утсалинское сельское муниципальное образование Республики Калмыкия, село Ут Сала, Здание дома культуры	Россия, республика Калмыкия, Ики-Бурульский район, село Ут-Сала	0101000020E61000005C3D27BD6F744640F3E2C4573BF04640
37860	2	19	1357	52920	\N	\N	45.588932999999997	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Светловское сельское муниципальное образование Республики Калмыкия, Светлый, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Светлый	0101000020E6100000F6402B3064A146408044132862CB4640
37859	2	19	1357	15075	\N	\N	45.972155000000001	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Приманычское сельское муниципальное образование Республики Калмыкия, село Приманыч, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Приманыч	0101000020E6100000E25AED612F4446404AD235936FFC4640
37857	2	19	1357	14987	\N	\N	46.096829999999997	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Оргакинское сельское муниципальное образование Республики Калмыкия, село Оргакин, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Оргакин	0101000020E6100000AA9A20EA3E3A4640C6A2E9EC640C4740
37855	2	19	1357	14897	\N	\N	45.498939	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Манцинкецовское сельское муниципальное образование Республики Калмыкия, село Манцин Кец, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Манцин Кец	0101000020E6100000D80C7041B65E464077D9AF3BDDBF4640
37800	2	19	1357	57197	\N	\N	46.1506105546787	"Республика Калмыкия, город Элиста пос. Лола, санаторий ""Лола"""	Россия, республика Калмыкия, Ики-Бурульский район, село Лола	0101000020E610000054008C67D02046407CB5A33847134740
37853	2	19	1357	14791	\N	\N	45.837629	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Кевюдовское сельское муниципальное образование Республики Калмыкия, село Кевюды, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Кевюды	0101000020E61000003ACFD8976C1E46403197546D37EB4640
37852	2	19	1357	14699	\N	\N	45.8183325936781	"Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Ики-Бурульское сельское муниципальное образование Республики Калмыкия, село Ики-Бурул, Здание ГУП ""Чограй"""	Россия, республика Калмыкия, Ики-Бурульский район, село Ики-Бурул	0101000020E61000008C4CC0AF91524640691EC022BFE84640
37851	2	19	1357	14699	\N	\N	45.823374000000001	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Ики-Бурульское сельское муниципальное образование Республики Калмыкия, село Ики-Бурул, Молодежный центр		0101000020E610000077871403245246403830B95164E94640
37850	2	19	1357	14638	\N	\N	45.612226999999997	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Зундатолгинское сельское муниципальное образование Республики Калмыкия, село Зунда Толга, Здание школы	Россия, республика Калмыкия, Ики-Бурульский район, село Зунда Толга	0101000020E6100000E0BBCD1B27214640355D4F745DCE4640
37847	2	19	1289	15263	\N	\N	46.102673000000003	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Южненское сельское муниципальное образование Республики Калмыкия, Здание начальной школы п. Шин-Бядл	Россия, республика Калмыкия, Городовиковский район, село Южный	0101000020E6100000973B33C17002454053978C63240D4740
37846	2	19	1289	15263	\N	\N	46.098784648115299	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Южненское сельское муниципальное образование Республики Калмыкия, Здание начальной школы	Россия, республика Калмыкия, Городовиковский район, село Южный	0101000020E6100000CB9F6F0B96024540ED2AA4FCA40C4740
14922	2	18	\N	57030	56745	\N	44.610397227885301	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Пржевальского, 2"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000287D21E4BC0D4440CB49287D214E4640
37845	2	19	1289	15263	\N	\N	46.102673000000003	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Южненское сельское муниципальное образование Республики Калмыкия, Здание конторы СПК ""Южный"""	Россия, республика Калмыкия, Городовиковский район, село Южный	0101000020E6100000973B33C17002454053978C63240D4740
37841	2	19	1289	32798	\N	\N	46.111851999999999	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Пушкинское сельское муниципальное образование Республики Калмыкия, Здание Пушкинского сельского Дома культуры	Россия, республика Калмыкия, Городовиковский район, село Пушкинское	0101000020E61000008C4D2B8540E6444000FF942A510E4740
37840	2	19	1289	32798	\N	\N	46.111851999999999	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Пушкинское сельское муниципальное образование Республики Калмыкия, Здание Администрации Пушкинского СМО	Россия, республика Калмыкия, Городовиковский район, село Пушкинское	0101000020E61000008C4D2B8540E6444000FF942A510E4740
37839	2	19	1289	32739	\N	\N	46.070710806693697	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Лазаревское сельское муниципальное образование Республики Калмыкия, Балковский сельский клуб	Россия, республика Калмыкия, Городовиковский район, село Лазаревский	0101000020E6100000F0A2AF20CDF44440D63BDC0E0D094740
37838	2	19	1289	32739	\N	\N	46.069938	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Лазаревское сельское муниципальное образование Республики Калмыкия, начальная школа СПК ""Бага-Бурул"""	Россия, республика Калмыкия, Городовиковский район, село Лазаревский	0101000020E610000053CF8250DEF34440B35F77BAF3084740
37837	2	19	1289	32739	\N	\N	46.070057980794999	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Лазаревское сельское муниципальное образование Республики Калмыкия, Контора отделения № 3	Россия, республика Калмыкия, Городовиковский район, село Лазаревский	0101000020E61000006C26DF6C73F344405E6919A9F7084740
37836	2	19	1289	32739	\N	\N	46.068563394439899	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Лазаревское сельское муниципальное образование Республики Калмыкия, Контора отделения № 2	Россия, республика Калмыкия, Городовиковский район, село Лазаревский	0101000020E6100000A0C4E74EB0F344409A5B21ACC6084740
37835	2	19	1289	32739	\N	\N	46.071730693048103	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Лазаревское сельское муниципальное образование Республики Калмыкия, Здание конторы отделения № 1	Россия, республика Калмыкия, Городовиковский район, село Лазаревский	0101000020E6100000EB8D5A61FAF44440008E3D7B2E094740
37834	2	19	1289	32739	\N	\N	46.069938	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Лазаревское сельское муниципальное образование Республики Калмыкия, Здание МОУ ""Кировская средняя школа"""	Россия, республика Калмыкия, Городовиковский район, село Лазаревский	0101000020E610000053CF8250DEF34440B35F77BAF3084740
37844	2	19	1289	57167	\N	\N	46.293040186024797	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Дружненское сельское муниципальное образование Республики Калмыкия, Здание Веселовской средней школы	Россия, республика Калмыкия, Городовиковский район, село Дружное	0101000020E6100000957EC2D9AD074540BD35B05582254740
37832	2	19	1289	32704	\N	\N	46.0841988189432	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Городовиковское городское муниципальное образование Республики Калмыкия, Здание МОУ ""Городовиковская средняя школа № 4"""	Россия, республика Калмыкия, Городовиковский район, Городовиковск	0101000020E6100000ADDD76A1B9F644408EAD6708C70A4740
37831	2	19	1289	32704	\N	\N	46.084142	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Городовиковское городское муниципальное образование Республики Калмыкия, Здание клуба МУП ""Башантинское"""	Россия, республика Калмыкия, Городовиковский район, Городовиковск	0101000020E6100000E4D87A8670F644402A1C412AC50A4740
37829	2	19	1289	32704	\N	\N	46.084142	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Городовиковское городское муниципальное образование Республики Калмыкия, Здание МОУ ДОД ""Дом школьника"""	Россия, республика Калмыкия, Городовиковский район, Городовиковск	0101000020E6100000E4D87A8670F644402A1C412AC50A4740
14923	2	18	\N	57030	56770	\N	44.615056829592397	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Пионерская, 532"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000F3AB3940300D444083161230BA4E4640
14050	1	17	\N	3130	22449	\N	58.045848999999997	г. Рыбинск, Чкалова, 89		0101000020E6100000B3614D65516C4340F3C64961DE054D40
37828	2	19	1289	32704	\N	\N	46.084351398024602	"Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Городовиковское городское муниципальное образование Республики Калмыкия, Здание МОУ ""Городовиковская средняя школа № 3"""	Россия, республика Калмыкия, Городовиковский район, Городовиковск	0101000020E61000000EBDC5C37BF6444044317903CC0A4740
37827	2	19	1289	32704	\N	\N	46.086886388319002	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Городовиковское городское муниципальное образование Республики Калмыкия, Здание Городовиковского городского Дома культуры	Россия, республика Калмыкия, Городовиковский район, Городовиковск	0101000020E61000004CFE277FF7F64440793D98141F0B4740
37843	2	19	1289	57152	\N	\N	46.219088569493302	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Виноградненское сельское муниципальное образование Республики Калмыкия, Здание Пролетарской начальной школы	Россия, республика Калмыкия, Городовиковский район, село Виноградное	0101000020E610000078EE3D5C72FC4440E8F4BC1B0B1C4740
37842	2	19	1289	57152	\N	\N	46.219207725537501	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Виноградненское сельское муниципальное образование Республики Калмыкия, Здание Виноградненского Дома культуры	Россия, республика Калмыкия, Городовиковский район, село Виноградное	0101000020E610000035B39602D2FC4440C382FB010F1C4740
37995	2	19	1289	46265	57440	\N	46.258040999999999	село Веселое, Школьная, сельский Дом культуры		0101000020E6100000A1DB4B1AA3FF44407903CC7C07214740
37849	2	19	1289	14598	\N	\N	45.985314000000002	Республика Калмыкия, Ики-Бурульское районное муниципальное образование Республики Калмыкия, Багабурульское сельское муниципальное образование Республики Калмыкия, село Бага-Бурул, Здание школы	Россия, республика Калмыкия, Городовиковский район, село Бага-Бурул	0101000020E61000003A3DEFC682E044403E25E7C41EFE4640
37848	2	19	7419	57194	\N	\N	46.070650600019199	Республика Калмыкия, Городовиковское районное муниципальное образование Республики Калмыкия, Розентальское сельское муниципальное образование Республики Калмыкия, Здание сельского Дома культуры		0101000020E6100000A9A0A2EA5706454000378B170B094740
14927	2	18	\N	57030	56682	\N	44.609538999999998	Республика Адыгея (Адыгея), муниципальное образование "Город Майкоп", квартал 407-е		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
95160	2	18	\N	57030	56616	\N	44.609784110132601	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", ул. Шоссейная, 10"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000AE4676A5650E4440E1CFF0660D4E4640
14928	2	18	\N	57030	56616	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Шоссейная, 10"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14924	2	18	\N	57030	56616	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Шоссейная, 96"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14896	2	18	\N	57030	56594	\N	44.615029462618701	Республика Адыгея (Адыгея), муниципальное образование "Город Майкоп", Чкалова, 77	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000CC9717601F0D4440B98B3045B94E4640
14942	2	18	\N	57030	56731	\N	44.611746064003803	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Хакурате, 640"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000287D21E4BC0D4440BABA63B14D4E4640
14919	2	18	\N	57030	56714	\N	44.611010339121698	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Тульская, 3"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E610000049DA8D3EE60F4440B5C35F93354E4640
14909	2	18	\N	57030	56630	\N	44.611255581791703	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Советская, 108"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000A359D93EE40D4440ECBDF8A23D4E4640
14908	2	18	\N	57030	56630	\N	44.610274604856102	Республика Адыгея (Адыгея), муниципальное образование "Город Майкоп", Советская, 168	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000005801BEDBBC0D44408048BF7D1D4E4640
14907	2	18	\N	57030	56630	\N	44.610151981566197	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Советская, 241"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000A629029CDE0D444064CBF275194E4640
14918	2	18	\N	57030	56652	\N	44.599007501988801	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Пушкина, 173"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000728A8EE4F20F44406C054D4BAC4C4640
14905	2	18	\N	57030	56589	\N	44.608101382480399	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Пролетарская, 353"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000005323F433F50C44401BD5E940D64D4640
14882	2	18	\N	57030	56643	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Привокзальная, 106"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
77308	2	23	\N	54820	40303	\N	47.739519999999999	Ростовская область, город Шахты, Шевченко, 94		0101000020E61000001553E9279C1D4440745E6397A8DE4740
14914	2	18	\N	57030	56591	\N	44.609538999999998	Республика Адыгея (Адыгея), муниципальное образование "Город Майкоп", Мопра, 65, столовая		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14913	2	18	\N	57030	56591	\N	44.616378190421898	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", МОПРа, 65"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000A583F57F0E0D4440A8FC6B79E54E4640
14932	2	18	\N	57030	56721	\N	44.683422	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", станица Ханская, Ленина, 40"		0101000020E6100000E8667FA0DCFA4340F7AE415F7A574640
14880	2	18	\N	57030	56679	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Ленина, 139"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14893	2	18	\N	57030	56637	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Курганная, 1"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14892	2	18	\N	57030	56637	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Курганная, 172"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14887	2	18	\N	57030	56637	\N	44.6122671967847	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Курганная, 331"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000C4995FCD010E4440C4B5DAC35E4E4640
14883	2	18	\N	57030	56637	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Курганная, 710"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14839	2	18	\N	57030	56637	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Курганная, 644"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14889	2	18	\N	57030	56611	\N	44.6070590636077	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Крестьянская, 238"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000B9E00CFE7E0D444009DFFB1BB44D4640
14890	2	18	\N	57030	56625	\N	44.614780829956601	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Краснооктябрьская, 48"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000029D499BAA0D4440E199D024B14E4640
14884	2	18	\N	57030	56657	\N	44.617340331660202	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Красногвардейская, 3"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000D027F224E90844409E4143FF044F4640
14916	2	18	\N	57030	56648	\N	44.609538999999998	Республика Адыгея (Адыгея), муниципальное образование "Город Майкоп", Комсомольская, 201		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14915	2	18	\N	57030	56648	\N	44.610765215157201	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Комсомольская, 276"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000007F15E0BBCD0D44404E452A8C2D4E4640
14910	2	18	\N	57030	56649	\N	44.614688869697801	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Заводская, 116"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000A583F57F0E0D4440001B1021AE4E4640
14921	2	18	\N	57030	56712	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Железнодорожная, 162"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14897	2	18	\N	57030	56596	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Димитрова, 21"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14895	2	18	\N	57030	56596	\N	44.615397300601899	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Димитрова, 23"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000007E6FD39FFD0C44403C873254C54E4640
14898	2	18	\N	57030	56618	\N	44.616010358694297	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Депутатская, 10"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000575BB1BFEC0C444026016A6AD94E4640
14891	2	18	\N	57030	56707	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Гоголя, 112"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14877	2	18	\N	57030	56678	\N	44.624221302961097	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Герцена, 96"		0101000020E6100000D158FB3BDB0B4440FB3C4679E64F4640
14920	2	18	\N	57030	56713	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Апшеронская, 4"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14886	2	18	\N	57030	56610	\N	44.612086620977301	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 8 Марта, 21"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000005531957EC20D444044A7E7DD584E4640
14926	2	18	\N	57030	56672	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 7-й переулок, 22"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14911	2	18	\N	57030	56710	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 2-я Ветеранов, 1"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14894	2	18	\N	57030	56716	\N	44.6176315252564	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 2 Ветеранов, 1"		0101000020E61000007AC7293A92094440467BBC900E4F4640
14903	2	18	\N	57030	56614	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 12 Марта, 65"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14902	2	18	\N	57030	56614	\N	44.6080366887875	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 12 Марта, 126"		0101000020E61000002592E8651409444005E10A28D44D4640
14901	2	18	\N	57030	56614	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 12 Марта, 144-А"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14900	2	18	\N	57030	56614	\N	44.609538999999998	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 12 Марта 144, А"		0101000020E6100000CF6740BD190D44407A51BB5F054E4640
14899	2	18	\N	57030	56614	\N	44.6096461577404	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 12 Марта, 163"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000001B2E724F57074440901150E1084E4640
14805	2	18	\N	58944	67075	\N	44.475859904724601	Республика Адыгея, Кошехабльский район, хутор Игнатьевский, Ленина, 92	Россия, республика Адыгея, Майкопский район	0101000020E6100000C44142942FF24340BEBC00FBE83C4640
14812	2	18	\N	58881	66891	\N	44.492573	Республика Адыгея, Кошехабльский район, хутор Дмитриевский, Комсомольская, 20А		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14767	2	18	\N	57050	56702	\N	44.884932999999997	Республика Адыгея, г.Адыгейск, Пушкина, 15		0101000020E61000003049658A3998434059130B7C45714640
14766	2	18	\N	57050	56696	\N	44.8832273986838	Республика Адыгея, г.Адыгейск, Ленина, 28	Россия, республика Адыгея, Теучежский район, город Адыгейск	0101000020E6100000CA3159DC7F984340DBF813950D714640
15006	2	18	1763	40357	9922	\N	45.022207683982799	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Хакуринохабльское сельское поселение, аул Хакуринохабль, Шовгенова, 12"	Россия, республика Адыгея, Шовгеновский район, поселок Хакуринохабль	0101000020E610000023DBF97E6A1E4440D3DA34B6D7824640
14999	2	18	1763	57055	56732	\N	45.051417413150801	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Заревское сельское поселение, хутор Чернышев, Школьная, 5"	Россия, республика Адыгея, Шовгеновский район, поселок Чернышев	0101000020E610000039252026E1044440AEBA0ED594864640
15009	2	18	1763	57056	56733	\N	45.0699765704748	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Хатажукайское сельское поселение, аул Хатажукай, Мурата Шовгенова, 9"	Россия, республика Адыгея, Шовгеновский район, поселок Хатажукай	0101000020E6100000FB761211FE174440713C9F01F5884640
15005	2	18	1763	57053	56724	\N	45.0205934774729	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Хакуринохабльское сельское поселение, аул Хакуринохабль, Краснооктябрьская, 90"	Россия, республика Адыгея, Шовгеновский район, поселок Хакуринохабль	0101000020E610000070ECD973991E444065C39ACAA2824640
14997	2	18	1763	25097	56752	\N	44.9640201367598	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Дукмасовское сельское поселение, хутор Тихонов, Советская, 206"	Россия, республика Адыгея, Шовгеновский район, поселок Тихонов	0101000020E6100000FAB5F5D37FFA43404F58E201657B4640
15004	2	18	1763	57091	56808	\N	44.918821000000001	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Джерокайское сельское поселение, хутор Семено-Макаренский, Кочубея, 6"	Россия, республика Адыгея, Шовгеновский район, поселок Семено-Макаровский	0101000020E6100000DB15FA60191F444063F030ED9B754640
15003	2	18	1763	25372	56775	\N	44.9826478030811	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Джерокайское сельское поселение, хутор Свободный Труд, Карла Маркса, 1А"	Россия, республика Адыгея, Шовгеновский район, поселок Свободный Труд	0101000020E6100000F27B9BFEEC2544406ABDDF68C77D4640
15010	2	18	1763	57080	56783	\N	45.064788368395803	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Хатажукайское сельское поселение, аул Пшичо, Ленина, 51"	Россия, республика Адыгея, Шовгеновский район, поселок Пшичо	0101000020E6100000280EA0DFF71544402D9622F94A884640
15012	2	18	1763	57057	56734	\N	45.094364970020997	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Хатажукайское сельское поселение, аул Пшизов, Школьная, 22"	Россия, республика Адыгея, Шовгеновский район, поселок Пшизов	0101000020E6100000D6390664AF0D44408B71FE26148C4640
15001	2	18	1763	57096	56815	\N	44.976081999999998	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Заревское сельское поселение, хутор Михайлов, Красноармейская, 16"	Россия, республика Адыгея, Шовгеновский район, поселок Михайлов	0101000020E6100000B6B9313D611344406D1B4641F07C4640
15008	2	18	1763	57049	56693	\N	45.0129462693696	Республика Адыгея (Адыгея), Муниципальное образование "Шовгеновский район", Мамхегское сельское поселение, аул Мамхег, 50 лет ВЛКСМ, 35	Россия, республика Адыгея, Шовгеновский район, поселок Мамхег	0101000020E6100000B665C0594A1C4440984EEB36A8814640
14998	2	18	1763	25136	56824	\N	44.942700000000002	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Дукмасовское сельское поселение, хутор Мамацев, Школьная, 2"		0101000020E6100000A609DB4FC6FE434038F8C264AA784640
15007	2	18	1763	57101	56826	\N	45.091914000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Хакуринохабльское сельское поселение, хутор Киров, Краснооктябрьская, 18"	Россия, республика Адыгея, Шовгеновский район, поселок Киров	0101000020E610000008E57D1CCD214440B40584D6C38B4640
46810	2	20	251	1488	20631	\N	44.861246999999999	село Коноково, Калинина, 51, телефон: 67253		0101000020E6100000E415889E94A94440996379573D6E4640
15011	2	18	1763	57081	56784	\N	45.044139000000001	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Хатажукайское сельское поселение, аул Кабехабль, Ленина, 35"	Россия, республика Адыгея, Шовгеновский район, поселок Кабехабль	0101000020E6100000C5C9FD0E4517444034BDC458A6854640
15000	2	18	1763	25226	56747	\N	44.999413370418999	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Заревское сельское поселение, поселок Зарево, Пролетарская, 5"	Россия, республика Адыгея, Шовгеновский район, поселок Зарево	0101000020E6100000B6300BED9C0A44403F19E3C3EC7F4640
14996	2	18	1763	25053	56816	\N	45.005378999999998	"Республика Адыгея (Адыгея), Муниципальное образование ""Шовгеновский район"", Дукмасовское сельское поселение, хутор Дукмасов, Ушанева, 19"		0101000020E6100000EDBAB72231F54340E78A5242B0804640
15002	2	18	1763	57079	56781	\N	44.989133000000002	Республика Адыгея (Адыгея), Муниципальное образование "Шовгеновский район", Джерокайское сельское поселение, аул Джерокай, Краснооктябрьская, 26	Россия, республика Адыгея, Шовгеновский район, поселок Джерокай	0101000020E6100000266DAAEE912744407B32FFE89B7E4640
14994	2	18	1298	57069	56760	\N	44.897812999999999	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Габукайское сельское поселение, х. Шевченко, Красная, 1	Россия, республика Адыгея, Теучежский район, поселок Шевченко	0101000020E61000009203763579C243403A765089EB724640
14978	2	18	1298	24202	56774	\N	44.871206825640002	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Пчегатлукайское сельское поселение, п. Четук, Ленина, 4/1	Россия, республика Адыгея, Теучежский район, поселок Четук	0101000020E6100000AB97DF6932934340EC8502B6836F4640
14976	2	18	1298	57102	56827	\N	44.953040402820598	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Тлюстенхабльское городское поселение, а. Тугургой, Школьная, 5	Россия, республика Адыгея, Теучежский район, поселок Тугургой	0101000020E610000099D711876C8E4340D2E3F736FD794640
14974	2	18	1298	23996	56690	\N	44.984619000000002	Республика Адыгея (Адыгея), Теучежский район, п. Тлюстенхабль, Школьная, 1		0101000020E61000004450357A358C43409702D2FE077E4640
14975	2	18	1298	23996	56723	\N	44.984619000000002	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Тлюстенхабльское городское поселение, п. Тлюстенхабль, Ленина, 23		0101000020E61000004450357A358C43409702D2FE077E4640
14990	2	18	1298	57082	56793	\N	44.965209999999999	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Джиджихабльское сельское поселение, а. Тауйхабль, Пролетарская, 23	Россия, республика Адыгея, Теучежский район, поселок Тауйхабль	0101000020E6100000849F38807EAF4340D6E253008C7B4640
14984	2	18	1298	57099	56820	\N	44.942298000000001	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Понежукайское сельское поселение,  а. Пшикуйхабль, Красная, 28	Россия, республика Адыгея, Теучежский район, поселок Пшикуйхабль	0101000020E6100000E09EE74F1BAF4340098B8A389D784640
14980	2	18	1298	57067	56750	\N	44.8855428049323	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Пчегатлукайское сельское поселение, а. Пчегатлукай, Ленина, 45	Россия, республика Адыгея, Теучежский район, поселок Пчегатлукай	0101000020E6100000E90AB6114FA24340D219187959714640
14982	2	18	1298	57039	56659	\N	44.887389532773703	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Понежукайское сельское поселение,  а. Понежукай, Октябрьская, 34	Россия, республика Адыгея, Теучежский район, поселок Понежукай	0101000020E61000008B18761893B043401366DAFE95714640
14995	2	18	1298	57074	56772	\N	44.936143778885501	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Габукайское сельское поселение, х. Петров, Первомайская, 37А	Россия, республика Адыгея, Теучежский район, поселок Петров	0101000020E610000014AE47E17AC043405E2C0C91D3774640
14985	2	18	1298	57059	56736	\N	44.908620111254102	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Понежукайское сельское поселение, а. Нешукай, Октябрьская, 43	Россия, республика Адыгея, Теучежский район, поселок Нешукай	0101000020E6100000E542E55FCBB54340EA3E00A94D744640
14983	2	18	1298	57086	56801	\N	44.924143999999998	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Понежукайское сельское поселение, а. Нечерезий, Хакурате, 4А	Россия, республика Адыгея, Теучежский район, поселок Начерезий	0101000020E6100000BB7D569929B14340B665C0594A764640
14987	2	18	1298	24649	56825	\N	44.874957000000002	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Ассоколайское сельское поселение, с. Красное, Шоссейная, 1		0101000020E610000045F295404ABA434001344A97FE6F4640
14979	2	18	1298	57103	56845	\N	44.879806794683603	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Пчегатлукайское сельское поселение, п. Красненский, Школьная, 1	Россия, республика Адыгея, Теучежский район	0101000020E6100000F566D47C95A043405CE509849D704640
14992	2	18	1298	57088	56805	\N	44.983286999999997	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Джиджихабльское сельское поселение, а. Кунчукохабль, Хакурате, 3	Россия, республика Адыгея, Теучежский район, поселок Кончукохабль	0101000020E61000009C6B98A1F1BC43407DCA3159DC7D4640
14977	2	18	1298	57095	56814	\N	44.903233	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Пчегатлукайское сельское поселение, х. Казазово, Красная, 13	Россия, республика Адыгея, Теучежский район, поселок Казазов	0101000020E6100000862172FA7A96434080D591239D734640
14988	2	18	1298	57075	56773	\N	44.945081844620198	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Джиджихабльское сельское поселение, а. Джиджихабль, Школьная, 36	Россия, республика Адыгея, Теучежский район, поселок Джиджихабль	0101000020E6100000902DCBD765B44340E6046D72F8784640
14991	2	18	1298	57087	56802	\N	44.992314	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Джиджихабльское сельское поселение, х. Городской, Советов, 16	Россия, республика Адыгея, Теучежский район, поселок Городской	0101000020E6100000C992399677B7434075AE2825047F4640
14993	2	18	1298	57040	56660	\N	44.929673817610997	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Габукайское сельское поселение, а. габукай, Хакурате, 26	Россия, республика Адыгея, Теучежский район, поселок Габукай	0101000020E6100000D73043E389C8434083F8C08EFF764640
14981	2	18	1298	57048	56691	\N	44.873987006782599	Республика Адыгея (Адыгея), Муниципальное образование "Теучежский район", Вочепшийское сельское поселение, а. Вочепший, Школьная, 1		0101000020E6100000B5DE6FB4E3A44340881057CEDE6F4640
14986	2	18	1298	57052	56719	\N	44.843434430233202	"Республика Адыгея (Адыгея), Муниципальное образование ""Теучежский район"", Ассоколайское сельское поселение, а. Ассоколай, Ленина, 47"	Россия, республика Адыгея, Теучежский район, поселок Ассоколай	0101000020E6100000231631EC30BC4340D02A33A5F56B4640
14768	2	18	1298	13653	56743	\N	44.835346791508798	Республика Адыгея, г.Адыгейск, х. Псекупс, Ленина, 13		0101000020E6100000543541D47D9A4340E6E786A6EC6A4640
14765	2	18	1298	13653	56585	\N	44.884932999999997	Республика Адыгея, г.Адыгейск, Ленина, 16		0101000020E61000003049658A3998434059130B7C45714640
14764	2	18	1298	13653	56585	\N	44.884932999999997	Республика Адыгея , г.Адыгейск, Ленина, 21		0101000020E61000003049658A3998434059130B7C45714640
14769	2	18	1298	13653	56663	\N	44.884932999999997	Республика Адыгея, г.Адыгейск, а. Гатлукай, ул. А.И. Хуаде, 76		0101000020E61000003049658A3998434059130B7C45714640
14967	2	18	1196	57083	56796	\N	45.000624866925598	Республика Адыгея, Тахтамукайский район, аул Новая Адыгея, Братьев Пченушай, 39	Россия, республика Адыгея, Тахтамукайский район	0101000020E61000004206F2ECF2754340AE47E17A14804640
14961	2	18	1196	23063	56656	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Школьная, 2/1		0101000020E6100000C6A6954220794340E388B5F8147E4640
14960	2	18	1196	23063	56639	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Пушкина, 26		0101000020E6100000C6A6954220794340E388B5F8147E4640
14962	2	18	1196	23063	56626	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Ленина, 17		0101000020E6100000C6A6954220794340E388B5F8147E4640
14959	2	18	1196	23063	56654	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Лаухина, 11		0101000020E6100000C6A6954220794340E388B5F8147E4640
95199	2	18	1196	23063	56674	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, ул. Космическая, 35		0101000020E6100000C6A6954220794340E388B5F8147E4640
14956	2	18	1196	23063	56674	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Космическая, 35		0101000020E6100000C6A6954220794340E388B5F8147E4640
14954	2	18	1196	23063	56686	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Заводская, 7	Россия, республика Адыгея, Тахтамукайский район, поселок Яблоновский	0101000020E6100000C6A6954220794340E388B5F8147E4640
14965	2	18	1196	23063	56623	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, п. Яблоновский, Гагарина, 41/1		0101000020E6100000C6A6954220794340E388B5F8147E4640
14958	2	18	1196	23063	56623	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Гагарина, 41		0101000020E6100000C6A6954220794340E388B5F8147E4640
14955	2	18	1196	23063	56622	\N	44.985014999999997	Республика Адыгея, Тахтамукайский район, поселок Яблоновский, Андрухаева, 61		0101000020E6100000C6A6954220794340E388B5F8147E4640
14951	2	18	1196	11525	56653	\N	44.924258999999999	Республика Адыгея, Тахтамукайский район, поселокЭнем, Чкалова, 13		0101000020E610000033A5F5B7047443404F04711E4E764640
14950	2	18	1196	11525	56620	\N	44.924258999999999	Республика Адыгея, Тахтамукайский район, поселок Энем, Седина, 42		0101000020E610000033A5F5B7047443404F04711E4E764640
14885	2	18	1196	11525	56620	\N	44.924258999999999	Республика Адыгея, Тахтамукайский район, поселок Энем, Седина, 36		0101000020E610000033A5F5B7047443404F04711E4E764640
14719	2	18	1196	11525	56620	\N	44.924258999999999	Республика Адыгея, Тахтамукайский район, поселок Энем, Седина, 9		0101000020E610000033A5F5B7047443404F04711E4E764640
14726	2	18	1196	11525	56627	\N	44.924258999999999	Республика Адыгея, Тахтамукайский район, поселок Энем, Маяковского, 1		0101000020E610000033A5F5B7047443404F04711E4E764640
14731	2	18	1196	11525	56694	\N	44.924258999999999	Республика Адыгея, Тахтамукайский район, поселок Энем, Ленина, 60		0101000020E610000033A5F5B7047443404F04711E4E764640
14949	2	18	1196	11525	56662	\N	44.917792132104303	Республика Адыгея, Тахтамукайский район, поселок Энем, Красная, 16А	Россия, республика Адыгея, Тахтамукайский район, поселок Энем	0101000020E6100000F88DAF3DB3744340E54350357A754640
14720	2	18	1196	11525	56662	\N	44.924258999999999	Республика Адыгея, Тахтамукайский район, поселок Энем, Красная, 23		0101000020E610000033A5F5B7047443404F04711E4E764640
77204	2	23	\N	54820	40303	\N	47.739519999999999	Ростовская область, город Шахты, Шевченко, 145		0101000020E61000001553E9279C1D4440745E6397A8DE4740
14943	2	18	1196	57037	56651	\N	44.8852356864924	Республика Адыгея, Тахтамукайский район, аул Шенджий, Пушкина, 22	Россия, республика Адыгея, Тахтамукайский район, поселок Шенджий	0101000020E61000005C001AA54B874340F59ECA694F714640
14968	2	18	1196	23710	56821	\N	44.997598000000004	Республика Адыгея, Тахтамукайский район, хутор Хомуты, Заречная, 10		0101000020E6100000A83462669F6F43400B47904AB17F4640
14972	2	18	1196	57085	56799	\N	45.042259999999999	Республика Адыгея, Тахтамукайский район, аул Хаштук, Хакурате, 18/1	Россия, республика Адыгея, Тахтамукайский район, поселок Хаштук	0101000020E6100000FB40F2CEA1604340E8F692C668854640
14944	2	18	1196	57034	56619	\N	44.923296256969401	Республика Адыгея, Тахтамукайский район, аул Тахтамукай, Совмена, 3	Россия, республика Адыгея, Тахтамукайский район, поселок Тахтамукай	0101000020E61000007E3B8908FF7E4340894336902E764640
14945	2	18	1196	57034	56718	\N	44.922624999999996	Республика Адыгея, Тахтамукайский район, аул Тахтамукай, Натухаевская, 6	Россия, республика Адыгея, Тахтамукайский район, поселок Тахтамукай	0101000020E6100000F54718062C7F43406ABC749318764640
14735	2	18	1196	12310	56762	\N	44.900883999999998	Республика Адыгея, Тахтамукайский район, хутор Суповский, Ленина, 86/а		0101000020E61000004582A966D6784340ADBEBA2A50734640
14966	2	18	1196	57041	56664	\N	45.035910008166098	Республика Адыгея, Тахтамукайский район, аул Старобжегокай, Ленина, 35/1	Россия, республика Адыгея, Тахтамукайский район, поселок Старобжегокай	0101000020E6100000D788601C5C724340B8CCE9B298844640
14971	2	18	1196	57097	56817	\N	45.051602000000003	Республика Адыгея, Тахтамукайский район, аул Псейтук, Школьная, 2	Россия, республика Адыгея, Тахтамукайский район, поселок Псейтук	0101000020E610000017F37343535A43404034F3E49A864640
14946	2	18	1196	22713	56728	\N	44.956682999999998	Республика Адыгея, Тахтамукайский район, п. Прикубанский, Ленина, 10		0101000020E610000016C1FF56B2834340D0D1AA96747A4640
14964	2	18	1196	57105	\N	\N	44.983433975942198	"Республика Адыгея, Тахтамукайский район, поселок Перекатный, кафе ""На берегу"""	Россия, республика Адыгея, Тахтамукайский район	0101000020E6100000058882195376434022E3512AE17D4640
14970	2	18	1196	57047	56689	\N	44.985814914190598	Республика Адыгея, Тахтамукайский район, аул Панахес, Схакумидова, 2		0101000020E6100000DD7A4D0F0A5C43400074982F2F7E4640
14947	2	18	1196	22743	56746	\N	44.872228999999997	Республика Адыгея, Тахтамукайский район, поселок Отрадный, Павлова, 10		0101000020E61000000FF27A30297A4340B7CF2A33A56F4640
14963	2	18	1196	57066	56789	\N	44.904815999999997	Республика Адыгея, Тахтамукайский район, поселок Новый, Ленина, 1	Россия, республика Адыгея, Тахтамукайский район, поселок Новый Сад	0101000020E6100000E3A430EF71744340E272BC02D1734640
14759	2	18	1196	57066	56749	\N	44.9033797755527	Республика Адыгея, Тахтамукайский район, хутор Новый Сад, Дружбы, 29А	Россия, республика Адыгея, Тахтамукайский район, поселок Новый Сад	0101000020E6100000DE718A8EE474434024EEB1F4A1734640
14952	2	18	1196	57094	56813	\N	44.932153	Республика Адыгея, Тахтамукайский район, аул Новобжегокай, Хатита, 17	Россия, республика Адыгея, Тахтамукайский район, поселок Новобжегокай	0101000020E61000003F8F519E796B434024EF1CCA50774640
14948	2	18	1196	57073	56771	\N	44.866747051007501	Республика Адыгея, Тахтамукайский район, аул Натухай, Ленина, 33	Россия, республика Адыгея, Тахтамукайский район, поселок Натухай	0101000020E6100000A913D044D87E4340FB73D190F16E4640
14973	2	18	1196	57089	56806	\N	44.941966000000001	Республика Адыгея, Тахтамукайский район, поселок Кубаньстрой, Заводская, 1		0101000020E61000008522DDCF29744340D3F8855792784640
14953	2	18	1196	57045	56685	\N	44.993885902607197	Республика Адыгея, Тахтамукайский район, аул Козет, Площадь Памяти, 1	Россия, республика Адыгея, Тахтамукайский район, поселок Козет	0101000020E61000002F6D382C0D804340E4F90CA8377F4640
14733	2	18	1196	12216	56761	\N	44.957664999999999	Республика Адыгея, Тахтамукайский район, поселок Дружный, Рабочая, 14		0101000020E61000008386FE092E7243400DC347C4947A4640
14969	2	18	1196	57038	56658	\N	44.993679404631301	Республика Адыгея, Тахтамукайский район, аул Афипсип, Жане, 5	Россия, республика Адыгея, Тахтамукайский район, поселок Афипсип	0101000020E6100000431CEBE2366443406ADC9BDF307F4640
14876	2	18	1243	57110	56905	\N	44.667327684548198	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Кужорское сельское поселение, пос. Трехречный, Школьная, 2"	Россия, республика Адыгея, Майкопский район	0101000020E610000011C64FE3DE2E444040DAFF006B554640
14806	2	18	1243	60675	75535	\N	44.488430999999999	Республика Адыгея, Кошехабльский район, аул Кошехабль, Промышленная, 35	Россия, республика Адыгея, Майкопский район	0101000020E610000000581D39D2F1434021AD31E8843E4640
14836	2	18	1243	57077	56777	\N	44.450993559260297	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Тимирязевское сельское поселение, хут. Шунтук, пер. Школьный, 1"	Россия, республика Адыгея, Майкопский район, поселок Шунтук	0101000020E61000004FB16A10E61444409B58E02BBA394640
14865	2	18	1243	57063	56742	\N	44.492947553767401	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Побединское сельское поселение, хут. Шаумян, Комсомольская, 9"	Россия, республика Адыгея, Майкопский район, поселок Шаумян	0101000020E610000026E0D74812124440765089EB183F4640
14838	2	18	1243	17220	56692	\N	44.497601000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Тимирязевское сельское поселение, пос. Цветочный, Клубная, 6"		0101000020E6100000AC1DC539EA1444407CBABA63B13F4640
77158	2	23	\N	54820	40303	\N	47.739519999999999	Ростовская область, город Шахты, Шевченко, 147		0101000020E61000001553E9279C1D4440745E6397A8DE4740
14934	2	18	1243	22098	56684	\N	44.683422	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", станица Ханская, Краснооктябрьская, 25"		0101000020E6100000E8667FA0DCFA4340F7AE415F7A574640
14933	2	18	1243	22098	56650	\N	44.683422	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", станица Ханская, Интернациональная, 112"		0101000020E6100000E8667FA0DCFA4340F7AE415F7A574640
14854	2	18	1243	57090	56807	\N	44.207565000000002	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Даховское сельское поселение, пос. Усть-Сахрай, Советская, 17"	Россия, республика Адыгея, Майкопский район, поселок Усть-Сахрайский	0101000020E6100000E50D30F31D244440AA656B7D911A4640
14863	2	18	1243	18483	56609	\N	44.552154999999999	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Побединское сельское поселение, пос. Удобный, Ленина, 20 б"		0101000020E610000078D2C2651514444054A9D903AD464640
14832	2	18	1243	16951	56667	\N	44.511969000000001	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Тульское городское поселение, п. Тульский, Советская, 38"		0101000020E61000006F826F9A3E1744406DC83F3388414640
14835	2	18	1243	16951	56720	\N	44.511969000000001	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Тульское городское поселение, пос. Тульский, Первомайская, 222"		0101000020E61000006F826F9A3E1744406DC83F3388414640
14834	2	18	1243	16951	56668	\N	44.511969000000001	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Тульское городское поселение, пос. Тульский, Комсомольская, 22"		0101000020E61000006F826F9A3E1744406DC83F3388414640
14833	2	18	1243	16951	56668	\N	44.511969000000001	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Тульское городское поселение, пос. Тульский, Комсомольская, 22 б"		0101000020E61000006F826F9A3E1744406DC83F3388414640
14837	2	18	1243	57078	56778	\N	44.468223999999999	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Тимирязевское сельское поселение, пос. Тимирязево, Садовая, 4"	Россия, республика Адыгея, Майкопский район, поселок Тимирязева	0101000020E6100000D07CCEDDAE154440E59997C3EE3B4640
14860	2	18	1243	18322	56673	\N	44.554422000000002	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Краснооктябрьское сельское поселение, пос. Табачный, Шоссейная, 29"		0101000020E61000005184D4EDEC0B44406A17D34CF7464640
14864	2	18	1243	18544	56676	\N	44.543149	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Побединское сельское поселение, пос. Совхозный, Советская, 49"		0101000020E6100000221807978E13444074ED0BE885454640
14807	2	18	1243	12776	\N	\N	44.670610000000003	Республика Адыгея, Кошехабльский район, аул Кошехабль, Советская, 55	Россия, республика Адыгея, Майкопский район, поселок Советский	0101000020E6100000695721E5270D44406F2F698CD6554640
14855	2	18	1243	12776	56709	\N	44.670521256848801	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Даховское сельское поселение. с. Хамышки, Советская, 11"	Россия, республика Адыгея, Майкопский район, поселок Советский	0101000020E61000005FD218ADA30C4440FF23D3A1D3554640
14808	2	18	1243	12776	56709	\N	44.670610000000003	Республика Адыгея, Кошехабльский район, аул Кошехабль, Советская, 26		0101000020E6100000695721E5270D44406F2F698CD6554640
14869	2	18	1243	12776	56819	\N	44.670610000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Кировское сельское поселение, хут. Советский, Западная, 4"	Россия, республика Адыгея, Майкопский район, поселок Советский	0101000020E6100000695721E5270D44406F2F698CD6554640
14867	2	18	1243	33093	56607	\N	44.6341761379472	Республика Адыгея (Адыгея), Муниципальное образование "Майкопский район", Кировское сельское поселение, хут. Северо-Восточные Сады, Нагорная, 48А	Россия, республика Адыгея, Майкопский район, поселок Северо-Восточные Сады	0101000020E6100000925A28999C1044403CF4DDAD2C514640
14868	2	18	1243	33093	56641	\N	44.634114253244597	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Кировское сельское поселение, хут. Северо-Восточные Сады, Маяковского, 268"	Россия, республика Адыгея, Майкопский район, поселок Северо-Восточные Сады	0101000020E61000006090F46915114440C6F7C5A52A514640
14937	2	18	1243	22324	56617	\N	44.656672	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", поселокСеверный, Школьная, 12"		0101000020E6100000217711A6280F44407619FED30D544640
14844	2	18	1243	57098	56818	\N	44.353000740672002	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Абадзехское сельское поселение, ст. Севастопольская, Советская, 29"	Россия, республика Адыгея, Майкопский район, поселок Севастопольская	0101000020E610000003B5183C4C274440473A03232F2D4640
14935	2	18	1243	22228	56759	\N	44.681032000000002	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", поселок Родниковый, Ленина, 14"	Россия, республика Адыгея, Майкопский район, поселок Родниковый	0101000020E6100000FEB968C878004440C6C37B0E2C574640
14870	2	18	1243	57064	56744	\N	44.620441491855203	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Кировское сельское поселение, хут. Пролетарский, Комсомольская, 43 а"	Россия, республика Адыгея, Майкопский район, поселок Пролетарский	0101000020E6100000E23E726BD21744407C0C569C6A4F4640
14862	2	18	1243	17878	56729	\N	44.558224317032703	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Побединское сельское поселение, пос. Победа, Шоссейная, 103 ш"	Россия, республика Адыгея, Майкопский район, поселок Победа	0101000020E61000002D3E05C078124440D1EB4FE273474640
14851	2	18	1243	17878	56786	\N	44.557776648742198	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Каменномостское городское поселение, пос. Победа, Дружбы, 42"		0101000020E61000009775FF588812444002BB9A3C65474640
14843	2	18	1243	17481	56701	\N	44.406398000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Абадзехское сельское поселение, пос. Первомайский, Школьная, 39"		0101000020E6100000FF05820019184440759483D904344640
14845	2	18	1243	17580	56741	\N	44.349581984180503	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Абадзехское сельское поселение, ст. Новосвободная, Советская, 20"	Россия, республика Адыгея, Майкопский район, поселок Новосвободная	0101000020E6100000946A9F8EC734444098A25C1ABF2C4640
14853	2	18	1243	17994	56804	\N	44.137658780605797	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Даховское сельское поселение, с. Новопрохладное, Советская, 8"	Россия, республика Адыгея, Майкопский район, поселок Новопрохладное	0101000020E61000004D672783A3244440028063CF9E114640
14888	2	18	1243	32525	56612	\N	44.604756298765899	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Краснооктябрьская, 51"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000002E1D739EB10D4440A70705A5684D4640
14881	2	18	1243	32525	56612	\N	44.612864960941799	Республика Адыгея (Адыгея), муниципальное образование "Город Майкоп", Краснооктябрьская, 61	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E6100000D1764CDD950D444078EE3D5C724E4640
14904	2	18	1243	32525	56655	\N	44.608910406076099	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", Гайдара, 1-А"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E610000084807C09150A44408B1A4CC3F04D4640
14912	2	18	1243	32525	56621	\N	44.609784110132601	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", 12 Марта, 138"	Россия, республика Адыгея, Майкопский район, город Майкоп	0101000020E61000005532005471074440E1CFF0660D4E4640
14856	2	18	1243	18142	56642	\N	44.464415000000002	Республика Адыгея (Адыгея), Муниципальное образование "Майкопский район", Краснооктябрьское сельское поселение, ст. Курджипская, Кооперативная, 12А		0101000020E61000000AF8359204074440CC6262F3713B4640
14874	2	18	1243	19069	56677	\N	44.671737999999998	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Кужорское сельское поселение, ст. Кужорская, Школьная, 25"		0101000020E61000000C3CF71E2E2744407FBDC282FB554640
14875	2	18	1243	19069	56629	\N	44.671737999999998	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Кужорское сельское поселение, ст. Кужорская, Краснооктябрьская, 18"		0101000020E61000000C3CF71E2E2744407FBDC282FB554640
14858	2	18	1243	18236	56671	\N	44.576436999999999	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Краснооктябрьское сельское поселение, пос Краснооктябрьский, Шоссейная, 95"		0101000020E6100000A1BB24CE8A0A4440289A07B0C8494640
14859	2	18	1243	18236	56680	\N	44.576436999999999	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Краснооктябрьское сельское поселение, пос. Краснооктябрьский, Кубанская, 74"		0101000020E6100000A1BB24CE8A0A4440289A07B0C8494640
14801	2	18	1243	15404	\N	\N	44.697712000000003	Республика Адыгея, Кошехабльский район, село Натырбово, Красная, 54	Россия, республика Адыгея, Майкопский район, поселок Красная Улька	0101000020E6100000BF0F0709511644406D0377A04E594640
14873	2	18	1243	15404	56606	\N	44.697712000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Красноульское сельское поселение, хут. Красная Улька, Октябрьская, 27"		0101000020E6100000BF0F0709511644406D0377A04E594640
14802	2	18	1243	15404	56809	\N	44.695217008600103	Республика Адыгея, Кошехабльский район, хутор Красный, Красная, 62	Россия, республика Адыгея, Майкопский район, поселок Красная Улька	0101000020E61000008527F4FA93164440C64FE3DEFC584640
14938	2	18	1243	22357	56812	\N	44.732595000000003	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", хутор Косинов, Гагарина, 17"		0101000020E6100000CFF8BEB8540B4440481B47ACC55D4640
14847	2	18	1243	17658	56669	\N	44.299899000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Каменномостское городское поселение, пос. Каменномоссткий, Мира, 25"		0101000020E6100000A35A441493174440338D261763264640
14848	2	18	1243	17658	56640	\N	44.299899000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Каменномостское городское поселение, пос. Каменномостский, Железнодорожная, 21"		0101000020E6100000A35A441493174440338D261763264640
14849	2	18	1243	17658	56703	\N	44.297529485423702	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Каменномостское городское поселение, пос. Каменномостский, Дальняя, 11"	Россия, республика Адыгея, Майкопский район, поселок Каменномостский	0101000020E61000009485AFAF75154440484E266E15264640
77380	2	23	\N	54820	55211	\N	47.739519999999999	Ростовская область, город Шахты, Индустриальная, 1-Г		0101000020E61000001553E9279C1D4440745E6397A8DE4740
14846	2	18	1243	17658	56638	\N	44.299899000000003	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Каменномостское городское поселение, пос. Каменномостский, Гагарина, 38 а"		0101000020E6100000A35A441493174440338D261763264640
14929	2	18	1243	21928	56681	\N	44.628402000000001	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", поселок Западный, Клубная, 18"		0101000020E61000002F51BD35B0074440D95E0B7A6F504640
14852	2	18	1243	17943	56599	\N	44.230454000000002	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Даховское сельское поселение, ст. Даховская, Советская, 20"		0101000020E6100000E31934F44F1A4440BF9D44847F1D4640
14857	2	18	1243	57072	56769	\N	44.378082465441999	Республика Адыгея (Адыгея), Муниципальное образование "Майкопский район", Краснооктябрьское сельское поселение, ст. Дагестанская, Ленина, 145	Россия, республика Адыгея, Майкопский район, поселок Дагестанская	0101000020E6100000FF092E56D4024440679AB0FD64304640
14866	2	18	1243	57076	56776	\N	44.555179265230201	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Побединское сельское поселение, хут. Грозный, Школьная, 9"	Россия, республика Адыгея, Майкопский район, поселок Грозный	0101000020E61000000E12A27C411144408736001B10474640
14871	2	18	1243	57076	56779	\N	44.556471000000002	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Кировское сельское поселение, хут. Грозный, Пионерская, 47"	Россия, республика Адыгея, Майкопский район, поселок Грозный	0101000020E6100000D2C2651536114440121615713A474640
15014	2	18	1243	21997	56661	\N	44.613934	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", хутор Гавердовский, переулок Клубный, 1"		0101000020E6100000DB32E02C2503444084F3A963954E4640
14930	2	18	1243	21997	56661	\N	44.613934	Республика Адыгея (Адыгея), муниципальное образование "Город Майкоп", хутор Гавердовский, переулок Клубный, 1		0101000020E6100000DB32E02C2503444084F3A963954E4640
14931	2	18	1243	57068	56756	\N	44.388049000000002	"Республика Адыгея (Адыгея), муниципальное образование ""Город Майкоп"", хутор Веселый, Лесная, 4"	Россия, республика Адыгея, Майкопский район, поселок Веселый	0101000020E6100000E7AA798EC81944406D1FF296AB314640
14842	2	18	1243	17350	56782	\N	44.392139015670402	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Абадзехское сельское поселение, ст. Абадзехская, Полевая, 4"	Россия, республика Адыгея, Майкопский район, поселок Абадзехская	0101000020E61000005E9F39EB531C44403A3E5A9C31324640
14841	2	18	1243	17350	56700	\N	44.392139	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Абадзехское сельское поселение, ст. Абадзехская, Клубная, 48"		0101000020E610000013471E882C1C44403A3E5A9C31324640
14840	2	18	1243	17350	56603	\N	44.392139	"Республика Адыгея (Адыгея), Муниципальное образование ""Майкопский район"", Абадзехское сельское поселение, ст. Абадзехская, Винника, 52"		0101000020E610000013471E882C1C44403A3E5A9C31324640
14830	2	18	1167	16868	56758	\N	45.052170790074598	Республика Адыгея, Красногвардейский район, село Штурбино, Красная, 3	Россия, республика Адыгея, Красногвардейский район, поселок Штурбино	0101000020E6100000C24EB16A10F443405A66118AAD864640
14815	2	18	1167	57033	56613	\N	45.187341462803801	Республика Адыгея, Красногвардейский район, аул Хатукай, Школьная, 2	Россия, республика Адыгея, Красногвардейский район, поселок Хатукай	0101000020E61000004D327216F6D44340981936CAFA974640
14816	2	18	1167	57033	56634	\N	45.191650658183597	Республика Адыгея, Красногвардейский район, аул Хатукай, Мира, 35	Россия, республика Адыгея, Красногвардейский район, поселок Хатукай	0101000020E61000009700FC53AAD44340739F1C0588984640
14831	2	18	1167	57042	56666	\N	45.051032046297401	Республика Адыгея, Красногвардейский район, аул Уляп, Братьев Шекультировых, 1	Россия, республика Адыгея, Красногвардейский район, поселок Уляп	0101000020E61000006744696FF0F943405586713788864640
14721	2	18	1167	11623	56757	\N	45.099511	Республика Адыгея, Красногвардейский район, хутор Саратовский, Красная, 28		0101000020E6100000FBB1497EC4E14340CF4BC5C6BC8C4640
14825	2	18	1167	16593	56753	\N	45.002005460995697	Республика Адыгея, Красногвардейский район, село Садовое, Красная, 14	Россия, республика Адыгея, Красногвардейский район, поселок Садовое	0101000020E61000003D27BD6F7CD94340D8B628B341804640
14822	2	18	1167	16446	56727	\N	45.085143000000002	Республика Адыгея, Красногвардейский район, село Преображенское, Школьная, 28		0101000020E61000006E52D158FBCF4340DE3D40F7E58A4640
14824	2	18	1167	16543	56739	\N	45.060935999999998	Республика Адыгея, Красногвардейский район, село Новосевастопольское, Чучваги, 4		0101000020E6100000BB4560AC6FDA4340149337C0CC874640
14817	2	18	1167	16181	56698	\N	45.124914383804096	Республика Адыгея, Красногвардейский район, село Красногвардейское, Первомайская, 12		0101000020E6100000658D7A8846C943400168942EFD8F4640
14820	2	18	1167	16181	56604	\N	45.125323999999999	Республика Адыгея, Красногвардейский район, село Красногвардейское, Мира, 341		0101000020E61000000EC0064488C94340B3B3E89D0A904640
14818	2	18	1167	16181	56665	\N	45.125323999999999	Республика Адыгея, Красногвардейский район, село Красногвардейское, 50 лет Октября, 35		0101000020E61000000EC0064488C94340B3B3E89D0A904640
14709	2	18	1167	11077	56722	\N	45.099276000000003	Республика Адыгея, Красногвардейский район, село Еленовское, Юбилейная, 8		0101000020E61000005778978BF8DA43408CA37213B58C4640
77375	2	23	\N	54820	55212	\N	47.739519999999999	Ростовская область, город Шахты, Есенина, 15		0101000020E61000001553E9279C1D4440745E6397A8DE4740
14762	2	18	1167	11077	56754	\N	45.099276000000003	Республика Адыгея, Красногвардейский район, село Еленовское, Молодежная, 2		0101000020E61000005778978BF8DA43408CA37213B58C4640
14761	2	18	1167	11077	56780	\N	45.099276000000003	Республика Адыгея, Красногвардейский район, село Еленовское, Клубная, 17		0101000020E61000005778978BF8DA43408CA37213B58C4640
14829	2	18	1167	57054	56730	\N	45.087710028710902	Республика Адыгея, Красногвардейский район, аул Джамбечи, Центральная, 38	Россия, республика Адыгея, Красногвардейский район, поселок Джамбечи	0101000020E61000008C31B08EE3ED43401EC4CE143A8B4640
14827	2	18	1167	16716	56823	\N	45.007846000000001	Республика Адыгея, Красногвардейский район, село Верхненазаровское, Почтовая, 40 А		0101000020E6100000548EC9E2FEDF4340C4B3041901814640
14828	2	18	1167	16746	56636	\N	45.034534000000001	Республика Адыгея, Красногвардейский район, село Большесидоровское, Советская, 42		0101000020E6100000501DAB949EEB4340CF4C309C6B844640
14826	2	18	1167	57061	56738	\N	44.972255691058798	Республика Адыгея, Красногвардейский район, аул Бжедугхабль, Клубная, 13	Россия, республика Адыгея, Красногвардейский район, поселок Бжедугхабль	0101000020E6100000394371C79BDA43407EAB75E2727C4640
14823	2	18	1167	57065	56748	\N	45.053912430941402	Республика Адыгея, Красногвардейский район, село Белосельское, Советская, 12	Россия, республика Адыгея, Красногвардейский район, поселок Белое	0101000020E6100000DEC66647AAD34340546EA296E6864640
14821	2	18	1167	57062	56740	\N	45.067795285833498	Республика Адыгея, Красногвардейский район, аул Адамий, Шоссейная, 36	Россия, республика Адыгея, Красногвардейский район, поселок Адамий	0101000020E610000069723106D6BF434089EAAD81AD884640
14795	2	18	7417	57043	56670	\N	44.492573	Республика Адыгея, Кошехабльский район, аул Ходзь, Краснооктябрьская, 104		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14814	2	18	7417	57084	56798	\N	44.492573	Республика Адыгея, Кошехабльский район, аул Хачемзий, Ленина, 37		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14809	2	18	7417	57044	56675	\N	44.492573	Республика Адыгея, Кошехабльский район, аул Егерухай, Школьная, 28А		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14797	2	18	7417	58958	67094	\N	44.492573	Республика Адыгея, Кошехабльский район, хутор Шелковников, Мира, 53		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14811	2	18	7417	61684	79561	\N	44.492573	Республика Адыгея, Кошехабльский район, поселок Дружба, Промышленная, 3		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14803	2	18	7417	57036	56635	\N	44.490151061510701	Республика Адыгея, Кошехабльский район, поселок Майский, Заводская, 5	Россия, республика Адыгея, Майкопский район	0101000020E61000006631B1F9B8F04340048D9944BD3E4640
14810	2	18	7417	61122	79568	\N	44.481549000000001	Республика Адыгея, Кошехабльский район, поселок Комсомольский, Центральная, 1		0101000020E610000014EB54F99EFB4340F435CB65A33D4640
14796	2	18	7417	58894	66955	\N	44.492573	Республика Адыгея, Кошехабльский район, хутор Кармалино-Гидроицкий, Свободного Мира, 75		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14800	2	18	7417	58880	66876	\N	44.492573	Республика Адыгея, Кошехабльский район, хутор Казенно-Кужорский, Ленина, 50		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14799	2	18	7417	57046	56688	\N	44.488640983557197	Республика Адыгея, Кошехабльский район, село Вольное, Гагарина, 18	Россия, республика Адыгея, Майкопский район	0101000020E6100000BFBB95253AF143400C3ECDC98B3E4640
14798	2	18	7417	58953	67089	\N	44.492573	Республика Адыгея, Кошехабльский район, село Вольное, пер. Кооперативный, 6		0101000020E61000005264ADA1D4F0434041F2CEA10C3F4640
14790	2	18	1319	57058	56735	\N	44.755302931446103	"Республика Адыгея, Гиагинский район, муниципальное образование ""Сергиевское сельское поселение"", х.Тамбовский, Прямая, 1"	Россия, республика Адыгея, Гиагинский район, поселок Тамбовский	0101000020E6100000D0F0660DDE2F44400CC9C9C4AD604640
14787	2	18	1319	57092	56810	\N	44.868727999999997	"Республика Адыгея, Гиагинский район, муниципальное образование ""Дондуковское сельское поселение"", х.См.Малиновский, Шоссейная, 10"	Россия, республика Адыгея, Гиагинский район, поселок Смольчев-Малиновский	0101000020E6100000E50CC51D6F3644404B8FA67A326F4640
14788	2	18	1319	14799	56597	\N	44.806089999999998	"Республика Адыгея, Гиагинский район, муниципальное образование ""Сергиевское сельское поселение"", с.Сергиевское, Почтовая, 7"		0101000020E61000007CF1457BBC2C4440FAD005F52D674640
14780	2	18	1319	57100	56822	\N	44.837558999999999	"Республика Адыгея, Гиагинский район, муниципальное образование ""Айрюмовское сельское поселение"", х.Садовый, Луговая, 45"	Россия, республика Адыгея, Гиагинский район, поселок Садовый	0101000020E6100000653909A52F1E444038BC2022356B4640
14779	2	18	1319	57035	56631	\N	44.869671785388803	"Республика Адыгея, Гиагинский район, муниципальное образование ""Айрюмовское сельское поселение"", х.Прогресс, Центральная, 2"	Россия, республика Адыгея, Гиагинский район, поселок Прогресс	0101000020E610000004029D499B1844409B1F7F69516F4640
14777	2	18	1319	14291	56602	\N	44.9311895028736	"Республика Адыгея, Гиагинский район, муниципальное образование ""Айрюмовское сельское поселение"", пос.Новый, пер.Советский, 2"		0101000020E6100000F9122A38BC1644405E2EE23B31774640
14778	2	18	1319	14313	\N	\N	44.906424999999999	"Республика Адыгея, Гиагинский район, муниципальное образование ""Айрюмовское сельское поселение"", с.Нижний Айрюм, Пролетарская, 2"	Россия, республика Адыгея, Гиагинский район, поселок Ниж. Айрюм	0101000020E61000003D0AD7A3701744406EA301BC05744640
77374	2	23	\N	54820	40329	\N	47.739519999999999	Ростовская область, город Шахты, Еременко, 9		0101000020E61000001553E9279C1D4440745E6397A8DE4740
14794	2	18	1319	15073	\N	\N	44.799747627251897	"Республика Адыгея, Гиагинский район, муниципальное образование ""Келермесское сельское поселение"", пос.Лесной, помещение АОЗТ ""Рассвет"""	Россия, республика Адыгея, Гиагинский район, поселок Лесной	0101000020E610000076FC1708021844404D8578245E664640
14793	2	18	1319	14994	56601	\N	44.791853000000003	"Республика Адыгея, Гиагинский район, муниципальное образование ""Келермесское сельское поселение"",  ст.Келермесская, Советская, 89"		0101000020E6100000E816BA1281104440A81E69705B654640
14792	2	18	1319	14994	56601	\N	44.788677793658501	"Республика Адыгея, Гиагинский район, муниципальное образование ""Келермесское сельское поселение"",  ст.Келермесская, Советская, 116"	Россия, республика Адыгея, Гиагинский район, поселок Келермесская	0101000020E61000005EBBB4E1B01044408F899466F3644640
14786	2	18	1319	57029	56587	\N	44.897994006072203	"Республика Адыгея, Гиагинский район, муниципальное образование ""Дондуковское сельское поселение"", ст.Дондуковская, Ленина, 169"	Россия, республика Адыгея, Гиагинский район, поселок Дондуковская	0101000020E61000006A183E22A62E44408A00A777F1724640
14784	2	18	1319	57029	56587	\N	44.890089919178997	"Республика Адыгея, Гиагинский район, муниципальное образование ""Дондуковское сельское поселение"", ст.Дондуковская, Ленина, 145"	Россия, республика Адыгея, Гиагинский район, поселок Дондуковская	0101000020E6100000E44EE960FD2D4440923F1878EE714640
14782	2	18	1319	57027	56633	\N	44.879958000000002	"Республика Адыгея, Гиагинский район, муниципальное образование ""Дондуковское сельское поселение"", ст.Дондуковская, Элеваторная, 30"		0101000020E6100000DEB06D51662D444042EDB776A2704640
14783	2	18	1319	57027	56583	\N	44.8800828342941	"Республика Адыгея, Гиагинский район, муниципальное образование ""Дондуковское сельское поселение"", ст.Дондуковская, Ленина, 73"	Россия, республика Адыгея, Гиагинский район, поселок Дондуковская	0101000020E61000006A183E22A62E4440FE614B8FA6704640
14785	2	18	1319	57027	56726	\N	44.880689854533799	"Республика Адыгея, Гиагинский район, муниципальное образование ""Дондуковское сельское поселение"", ст.Дондуковская, Гагарина, 148"	Россия, республика Адыгея, Гиагинский район, поселок Дондуковская	0101000020E6100000A01518B2BA2D444006F52D73BA704640
14791	2	18	1319	57071	56768	\N	44.755353006626997	Республика Адыгея, Гиагинский район, муниципальное образование "Сергиевское сельское поселение", х.Днепровский, Крестьянская, 48	Россия, республика Адыгея, Гиагинский район, поселок Днепровский	0101000020E61000005A4A969350264440BEF73768AF604640
14776	2	18	1319	14223	56595	\N	44.806711	"Республика Адыгея, Гиагинский район, муниципальное образование ""Гиагинское сельское поселение"", пос.Гончарка, Центральная, 11"		0101000020E610000008CC43A67CFA43406729594E42674640
14773	2	18	1319	57031	56592	\N	44.858116593759902	"Республика Адыгея, Гиагинский район, муниципальное образование ""Гиагинское сельское поселение"", ст.Гиагинская, Центральная, 36А"	Россия, республика Адыгея, Гиагинский район, поселок Гиагинская	0101000020E61000000E4FAF94650A4440219221C7D66D4640
14775	2	18	1319	57031	56697	\N	44.872176083922803	"Республика Адыгея, Гиагинский район, муниципальное образование ""Гиагинское сельское поселение"", ст.Гиагинская, Красноармейская, 220"	Россия, республика Адыгея, Гиагинский район, поселок Гиагинская	0101000020E6100000785E2A36E6074440952D9276A36F4640
14774	2	18	1319	57031	56598	\N	44.853358074346197	"Республика Адыгея, Гиагинский район, муниципальное образование ""Гиагинское сельское поселение"", ст.Гиагинская, Красная, 170"	Россия, республика Адыгея, Гиагинский район, поселок Гиагинская	0101000020E61000006CCB80B3940A4440D6E3BED53A6D4640
14771	2	18	1319	57031	56598	\N	44.8715683772323	"Республика Адыгея, Гиагинский район, муниципальное образование ""Гиагинское сельское поселение"",  ст.Гиагинская, Красная, 310"	Россия, республика Адыгея, Гиагинский район, поселок Гиагинская	0101000020E6100000C6866EF607084440BD1E4C8A8F6F4640
14770	2	18	1319	57031	56628	\N	44.872300771472098	"Республика Адыгея, Гиагинский район, муниципальное образование ""Гиагинское сельское поселение"", ст.Гиагинская, Боевая, 3"	Россия, республика Адыгея, Гиагинский район, поселок Гиагинская	0101000020E6100000A5129ED0EB07444051A2258FA76F4640
14772	2	18	1319	57031	56699	\N	44.849233477639501	"Республика Адыгея, Гиагинский район, муниципальное образование ""Гиагинское сельское поселение"", ст.Гиагинская, Ленина, 152"	Россия, республика Адыгея, Гиагинский район, поселок Гиагинская	0101000020E61000001F49490F430B44408CD7BCAAB36C4640
14789	2	18	1319	14833	56767	\N	44.765627000000002	"Республика Адыгея, Гиагинский район, муниципальное образование ""Сергиевское сельское поселение"", с.Георгиевское, Октябрьская, 4"		0101000020E61000006E8AC745B5344440A1F7C61000624640
14781	2	18	1319	57070	56763	\N	44.909611368987498	"Республика Адыгея, Гиагинский район, муниципальное образование ""Дондуковское сельское поселение"", х.Вольно-Веселый, Центральная, 27"	Россия, республика Адыгея, Гиагинский район, поселок Вольно-Веселый	0101000020E6100000C537143E5B2144407A8A1C226E744640
77312	2	23	\N	54820	55118	\N	47.739519999999999	Ростовская область, город Шахты, пл.Ленина, 1		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77326	2	23	\N	54820	39809	\N	47.739519999999999	Ростовская область, город Шахты, бульвар Аллейный, 8		0101000020E61000001553E9279C1D4440745E6397A8DE4740
76944	2	23	\N	54820	40303	\N	47.7410252662728	Ростовская область, город Шахты, Шевченко, 116	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E6100000EC14AB06611E44405B423EE8D9DE4740
77359	2	23	\N	54820	40030	\N	47.739519999999999	Ростовская область, город Шахты, Фучика, 8-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77337	2	23	\N	54820	39813	\N	47.739519999999999	Ростовская область, город Шахты, Федосеева, 49		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77311	2	23	\N	54820	40830	\N	47.739519999999999	Ростовская область, город Шахты, Тюменский, 97		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77378	2	23	\N	54820	40176	\N	47.739519999999999	Ростовская область, город Шахты, Текстильная, 41-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77377	2	23	\N	54820	40176	\N	47.739519999999999	Ростовская область, город Шахты, Текстильная, 19		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77345	2	23	\N	54820	39816	\N	47.739519999999999	Ростовская область, город Шахты, Стрельникова, 40		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77314	2	23	\N	54820	40324	\N	47.739519999999999	Ростовская область, город Шахты, Спортивный, 2		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77364	2	23	\N	54820	41214	\N	47.739519999999999	Ростовская область, город Шахты, Сокольнический, 17-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77340	2	23	\N	54820	40150	\N	47.742298274830198	Ростовская область, город Шахты, Советская, 155	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E6100000A3E6ABE4631D44406FF1F09E03DF4740
77339	2	23	\N	54820	40150	\N	47.739519999999999	Ростовская область, город Шахты, Советская, 145		0101000020E61000001553E9279C1D4440745E6397A8DE4740
76922	2	23	\N	54820	40150	\N	47.7168185774036	Ростовская область, город Шахты, Советская, 279		0101000020E6100000056EDDCD53194440621399B9C0DB4740
77349	2	23	\N	54820	40174	\N	47.739519999999999	Ростовская область, город Шахты, Сельская, 42		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77354	2	23	\N	54820	39817	\N	47.739519999999999	Ростовская область, город Шахты, Сапрыкина, 5		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77309	2	23	\N	54820	39996	\N	47.739519999999999	Ростовская область, город Шахты, Садовая, 10-Б		0101000020E61000001553E9279C1D4440745E6397A8DE4740
76743	2	23	\N	54820	39996	\N	47.739519999999999	Ростовская область, город Шахты, Садовая, 33-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77356	2	23	\N	54820	39776	\N	47.739519999999999	Ростовская область, город Шахты, Рудничный, 1-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77313	2	23	\N	54820	40020	\N	47.739519999999999	Ростовская область, город Шахты, Пролетарская, 135		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77324	2	23	\N	54820	55168	\N	47.724484717088799	Ростовская область, город Шахты, Пограничная, 47-В		0101000020E6100000423F53AF5B1C4440A6B8AAECBBDC4740
77342	2	23	\N	54820	40024	\N	47.739519999999999	Ростовская область, город Шахты, Победы революции, 105		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77335	2	23	\N	54820	40024	\N	47.704116685743799	Ростовская область, город Шахты, Победы революции, 11		0101000020E61000009C6A2DCC421B444060C77F8120DA4740
77338	2	23	\N	54820	40841	\N	47.739519999999999	Ростовская область, город Шахты, Победа Революции, 79		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77319	2	23	\N	54820	40841	\N	47.739519999999999	Ростовская область, город Шахты, Победа Революции, 4		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77754	2	23	\N	54820	40961	\N	47.739519999999999	Ростовская область, город Шахты, Платова, 220-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77330	2	23	\N	54820	40251	\N	47.739519999999999	Ростовская область, город Шахты, Питерская, 66		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77332	2	23	\N	54820	41384	\N	47.739519999999999	Ростовская область, город Шахты, Паустовского, 2-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77320	2	23	\N	54820	40834	\N	47.739519999999999	Ростовская область, город Шахты, Панфилова, 42		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77369	2	23	\N	54820	39819	\N	47.739519999999999	Ростовская область, город Шахты, Островского, 26		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77373	2	23	\N	54820	55709	\N	47.740445628798803	Ростовская область, город Шахты, Муранова, 1		0101000020E61000008B6D52D1581D44401D3A3DEFC6DE4740
77360	2	23	\N	54820	40850	\N	47.739519999999999	Ростовская область, город Шахты, Монгольский, 25		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77353	2	23	\N	54820	40845	\N	47.739519999999999	Ростовская область, город Шахты, Михайлова, 23		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77323	2	23	\N	54820	40021	\N	47.739519999999999	Ростовская область, город Шахты, Мировая Коммуна, 1-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77317	2	23	\N	54820	40021	\N	47.739519999999999	Ростовская область, город Шахты, Мировая Коммуна, 21		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77361	2	23	\N	54820	40032	\N	47.739519999999999	Ростовская область, город Шахты, Милиционная, 10		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77134	2	23	\N	54820	40008	\N	47.739519999999999	Ростовская область, город Шахты, Маяковского, 88		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77325	2	23	\N	54820	40835	\N	47.739519999999999	Ростовская область, город Шахты, Майская, 27-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
76690	2	23	\N	54820	40130	\N	47.739519999999999	Ростовская область, город Шахты, Лозовая, 33		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77370	2	23	\N	54820	40642	\N	47.739519999999999	Ростовская область, город Шахты, Ленинского Комсомола, 8		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77367	2	23	\N	54820	40642	\N	47.739519999999999	Ростовская область, город Шахты, Ленинского Комсомола, 40		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77371	2	23	\N	54820	55210	\N	47.739519999999999	Ростовская область, город Шахты, Лебедева, 2		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77346	2	23	\N	54820	41390	\N	47.739519999999999	Ростовская область, город Шахты, Красинская, 42-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77328	2	23	\N	54820	55177	\N	47.737608636014201	Ростовская область, город Шахты, Кошевого, 17	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E6100000265646239F1D44401D1EC2F869DE4740
77341	2	23	\N	54820	40844	\N	47.739519999999999	Ростовская область, город Шахты, Короткий, 2		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77363	2	23	\N	54820	40848	\N	47.739519999999999	Ростовская область, город Шахты, Дубинина, 2		0101000020E61000001553E9279C1D4440745E6397A8DE4740
76595	2	23	\N	54820	55096	\N	47.739519999999999	Ростовская область, город Шахты, Достоевского, 69		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77315	2	23	\N	54820	41375	\N	47.739519999999999	Ростовская область, город Шахты, Донской, 37		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77327	2	23	\N	54820	40836	\N	47.739519999999999	Ростовская область, город Шахты, Депутатская, 16-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77307	2	23	\N	54820	40170	\N	47.739519999999999	Ростовская область, город Шахты, Дачная, 223		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77331	2	23	\N	54820	39812	\N	47.739519999999999	Ростовская область, город Шахты, Георгиевская, 27		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77355	2	23	\N	54820	40846	\N	47.739519999999999	Ростовская область, город Шахты, Врубовая, 27/29		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77376	2	23	\N	54820	39821	\N	47.739519999999999	Ростовская область, город Шахты, Ворошилова, 51		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77352	2	23	\N	54820	41210	\N	47.739519999999999	Ростовская область, город Шахты, Волошина, 20		0101000020E61000001553E9279C1D4440745E6397A8DE4740
76825	2	23	\N	54820	41272	\N	47.739519999999999	Ростовская область, город Шахты, Веселый, 36-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77322	2	23	\N	54820	40173	\N	47.739519999999999	Ростовская область, город Шахты, Бугроватый, 28		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77321	2	23	\N	54820	39807	\N	47.743383778795	Ростовская область, город Шахты, Безымянная, 6	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E6100000D63730B9511E4440512FF83427DF4740
77344	2	23	\N	54820	40026	\N	47.739519999999999	Ростовская область, город Шахты, Баррикадная, 16		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77329	2	23	\N	54820	40244	\N	47.739519999999999	Ростовская область, город Шахты, Базарная, 25		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77347	2	23	\N	54820	55199	\N	47.739519999999999	Ростовская область, город Шахты, Азовская, 46		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77358	2	23	\N	54820	40175	\N	47.739519999999999	Ростовская область, город Шахты, 60 лет Победы, 50		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77336	2	23	\N	54820	41386	\N	47.7149650192788	Ростовская область, город Шахты, 50 лет ВЛКСМ, 25		0101000020E610000060048D99441D44406F641EF983DB4740
77306	2	23	\N	54820	41373	\N	47.739519999999999	Ростовская область, город Шахты, 10 лет За индустриализацию, 179		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77316	2	23	\N	54820	41377	\N	47.739519999999999	Ростовская область, город Шахты, 1-й Милиционный, 67-А		0101000020E61000001553E9279C1D4440745E6397A8DE4740
75994	2	23	\N	56619	55178	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Свердлова, 112		0101000020E610000018B2BAD5730A4540AF264F594DD34740
77042	2	23	\N	193	\N	\N	47.211477000000002	Ростовская область, город Таганрог, Здание станции Марцево	Россия, Ростовская область, Таганрог	0101000020E61000009146054EB6754340986DA7AD119B4740
77021	2	23	\N	193	\N	\N	47.211477000000002	"Ростовская область, город Таганрог, Здание базы отдыха ""Таксист"""	Россия, Ростовская область, Таганрог	0101000020E61000009146054EB6754340986DA7AD119B4740
76995	2	23	\N	193	\N	\N	47.211477000000002	Ростовская область, город Таганрог, ул.Большая Бульварная, 2	Россия, Ростовская область, Таганрог	0101000020E61000009146054EB6754340986DA7AD119B4740
77676	2	23	\N	193	6812	\N	47.205741000000003	Ростовская область, город Таганрог, ул.Чехова, 22/Б	Россия, Ростовская область, Таганрог, улица Чехова, 22б	0101000020E61000000074982F2F784340223999B8559A4740
77040	2	23	\N	193	7523	\N	47.258704999999999	Ростовская область, город Таганрог, ул.Сергея Лазо, 7/1	Россия, Ростовская область, Таганрог, улица Сергея Лазо, 7	0101000020E6100000562DE92807754340E527D53E1DA14740
76974	2	23	\N	193	6857	\N	47.210296	Ростовская область, город Таганрог, ул.Розы Люксембург, 153/1	Россия, Ростовская область, Таганрог, улица Розы Люксембург, 153	0101000020E6100000C0081A3389744340643DB5FAEA9A4740
77033	2	23	\N	193	7436	\N	47.250276999999997	Ростовская область, город Таганрог, ул.Пальмиро Тольятти, 32/2	Россия, Ростовская область, Таганрог, улица Пальмиро Тольятти, 32	0101000020E6100000FA5E43705C74434072F8A41309A04740
77032	2	23	\N	193	7436	\N	47.250283000000003	Ростовская область, город Таганрог, ул.Пальмиро Тольятти, 26/4	Россия, Ростовская область, Таганрог, улица Пальмиро Тольятти, 26	0101000020E6100000889FFF1EBC74434055DFF94509A04740
77036	2	23	\N	193	75	\N	47.253177000000001	Ростовская область, город Таганрог, ул.Морозова, 30	Россия, Ростовская область, Таганрог, улица Морозова, 30	0101000020E610000027A5A0DB4B764340B98C9B1A68A04740
77020	2	23	\N	193	4289	\N	47.241340000000001	Ростовская область, город Таганрог, ул.Менделеева, 14	Россия, Ростовская область, Таганрог, улица Менделеева, 14	0101000020E61000001E17D522A2704340BB9BA73AE49E4740
77630	2	23	\N	193	6836	\N	47.274402000000002	Ростовская область, город Таганрог, ул.Маршала Жукова, 2/Ж	Россия, Ростовская область, Таганрог, улица Маршала Жукова, 2	0101000020E610000030F0DC7BB87643407FFACF9A1FA34740
77022	2	23	\N	193	375	\N	47.231067000000003	Ростовская область, город Таганрог, ул.Ленина, 212	Россия, Ростовская область, Таганрог, улица Ленина, 212	0101000020E6100000DD5D6743FE734340A9177C9A939D4740
76983	2	23	\N	193	6933	\N	47.210008000000002	Ростовская область, город Таганрог, ул.Карла Либкнехта, 185	Россия, Ростовская область, Таганрог, улица Карла Либкнехта, 185	0101000020E6100000D13B1570CF734340FEF2C98AE19A4740
77515	2	23	\N	193	5652	\N	47.268801000000003	Ростовская область, город Таганрог, ул.Инициативная, 22	Россия, Ростовская область, Таганрог, улица Инициативная, 22	0101000020E6100000F295404AEC764340E910381268A24740
77024	2	23	\N	193	55373	\N	47.221386000000003	Ростовская область, город Таганрог, ул.Петровская, 109/А		0101000020E610000052B9895A9A75434069E55E60569C4740
77052	2	23	\N	193	5652	\N	47.265535999999997	Ростовская область, город Таганрог, ул.Инициативная, 38	Россия, Ростовская область, Таганрог, улица Инициативная, 38	0101000020E6100000809A5AB6D675434090F46915FDA14740
77047	2	23	\N	193	5652	\N	47.260117999999999	Ростовская область, город Таганрог, ул.Инициативная, 70	Россия, Ростовская область, Таганрог, улица Инициативная, 70	0101000020E6100000BD8BF7E3F6734340EB8CEF8B4BA14740
77038	2	23	\N	193	7334	\N	47.255115000000004	Ростовская область, город Таганрог, ул.Дзержинского, 171/1	Россия, Ростовская область, Таганрог, улица Дзержинского, 171	0101000020E6100000CC96AC8A707543400ADCBA9BA7A04740
77031	2	23	\N	193	7334	\N	47.242826999999998	Ростовская область, город Таганрог, ул.Дзержинского, 144	Россия, Ростовская область, Таганрог, улица Дзержинского, 144	0101000020E6100000064A0A2C80754340FBCA83F4149F4740
77046	2	23	\N	193	7617	\N	47.263627999999997	Ростовская область, город Таганрог, ул.1я Линия, 146/А	Россия, Ростовская область, Таганрог, улица 1-я Линия, 146а	0101000020E61000005A68E7340B744340AA27F38FBEA14740
76985	2	23	\N	193	41281	\N	47.208470613424197	Ростовская область, город Таганрог, пер.Трудовых резервов, 1	Россия, Ростовская область, Таганрог, улица Трудовых Резервов, 1	0101000020E61000008A22A46E677143400C957F2DAF9A4740
76966	2	23	\N	193	55451	\N	47.204510999999997	Ростовская область, город Таганрог, ул.Шевченко, 2		0101000020E6100000A8AB3B16DB7843400C569C6A2D9A4740
77514	2	23	\N	193	55458	\N	47.265872999999999	Ростовская область, город Таганрог, ул.Шаумяна, 12		0101000020E610000016889E9449774340D8F15F2008A24740
77511	2	23	\N	193	55458	\N	47.265909000000001	Ростовская область, город Таганрог, ул.Шаумяна, 14		0101000020E61000000492B06F27774340255B5D4E09A24740
76999	2	23	\N	193	55425	\N	47.216037	Ростовская область, город Таганрог, ул.Чехова, 375		0101000020E6100000EB707495EE6C4340ECDCB419A79B4740
76975	2	23	\N	193	55425	\N	47.212468999999999	Ростовская область, город Таганрог, ул.Чехова, 104		0101000020E610000054E6E61BD1754340F834272F329B4740
76969	2	23	\N	193	55425	\N	47.207749	Ростовская область, город Таганрог, ул.Чехова, 75		0101000020E61000004FEB36A8FD7643406B63EC84979A4740
77037	2	23	\N	193	55426	\N	47.255310999999999	Ростовская область, город Таганрог, ул.Черняховского, 7		0101000020E61000004704E3E0D27543408FA7E507AEA04740
76976	2	23	\N	193	55449	\N	47.215040000000002	Ростовская область, город Таганрог, ул.Фрунзе, 40		0101000020E61000009413ED2AA47643407AAA436E869B4740
77007	2	23	\N	193	55342	\N	47.219594335577803	Ростовская область, город Таганрог, ул.Фадеева, 21		0101000020E61000004E98309A956F4340EC32FCA71B9C4740
76839	2	23	\N	193	5459	\N	47.210785000000001	Ростовская область, город Таганрог, пер.Украинский, 8	Россия, Ростовская область, Таганрог, Украинский переулок, 8	0101000020E610000057AF22A30378434062BEBC00FB9A4740
76896	2	23	\N	193	6086	\N	47.209175999999999	Ростовская область, город Таганрог, пер.Тургеневский, 32	Россия, Ростовская область, Таганрог, Тургеневский переулок, 32	0101000020E61000004A0A2C8029774340D68D7747C69A4740
77008	2	23	\N	193	55371	\N	47.224972999999999	Ростовская область, город Таганрог, ул.Транспортная, 1/5		0101000020E61000006D0377A04E714340D3BD4EEACB9C4740
76989	2	23	\N	193	6838	\N	47.213332000000001	Ростовская область, город Таганрог, пер.Смирновский, 26/А	Россия, Ростовская область, Таганрог, Смирновский переулок, 26а	0101000020E61000000D7217618A7443405B9885764E9B4740
76972	2	23	\N	193	6838	\N	47.208238999999999	Ростовская область, город Таганрог, пер.Смирновский, 101/А	Россия, Ростовская область, Таганрог, Смирновский переулок, 101а	0101000020E6100000AEF545425B74434039605793A79A4740
77012	2	23	\N	193	39745	\N	47.225780500849702	Ростовская область, город Таганрог, ул.Сергея Шило, 162	Россия, Ростовская область, Таганрог, улица имени С. И. Шило, 162	0101000020E61000008AE42B819470434072874D64E69C4740
77010	2	23	\N	193	39745	\N	47.225722031072202	Ростовская область, город Таганрог, ул.Сергея Шило, 182-1	Россия, Ростовская область, Таганрог, улица имени С. И. Шило, 182	0101000020E6100000F12A6B9BE26F43406DFE5F75E49C4740
77006	2	23	\N	193	39745	\N	47.224567239669803	Ростовская область, город Таганрог, ул.Сергея Шило, 190	Россия, Ростовская область, Таганрог, улица имени С. И. Шило, 190	0101000020E6100000B821C66B5E6F43406361889CBE9C4740
77005	2	23	\N	193	39745	\N	47.224026379296397	Ростовская область, город Таганрог, ул.Сергея Шило, 196	Россия, Ростовская область, Таганрог, улица имени С. И. Шило, 194к1	0101000020E61000002FC1A90F246F434013BA4BE2AC9C4740
77003	2	23	\N	193	39745	\N	47.221892119316799	Ростовская область, город Таганрог, ул.Сергея Шило, 245	Россия, Ростовская область, Таганрог, улица имени С. И. Шило, 245	0101000020E6100000973B33C1706E43403C9F01F5669C4740
77039	2	23	\N	193	55359	\N	47.256632000000003	Ростовская область, город Таганрог, ул.Сергея Лазо, 1/1		0101000020E610000089EFC4AC17754340B58D3F51D9A04740
76987	2	23	\N	193	55397	\N	47.210883000000003	Ростовская область, город Таганрог, ул.Свободы, 34		0101000020E6100000E98024ECDB7143402524D236FE9A4740
76986	2	23	\N	193	55397	\N	47.208851000000003	Ростовская область, город Таганрог, ул.Свободы, 21		0101000020E610000038F4160FEF714340535E2BA1BB9A4740
76982	2	23	\N	193	55397	\N	47.206708999999996	Ростовская область, город Таганрог, ул.Свободы, 16		0101000020E610000075C7629B54724340F964C570759A4740
76981	2	23	\N	193	55397	\N	47.204768000000001	Ростовская область, город Таганрог, ул.Свободы, 10		0101000020E6100000FAEFC16B9772434038A27BD6359A4740
77002	2	23	\N	193	55193	\N	47.222915405438101	Ростовская область, город Таганрог, ул.Сергея Шило, 202/А		0101000020E61000007F130A11706E4340D8648D7A889C4740
76992	2	23	\N	193	55361	\N	47.2192955557991	Ростовская область, город Таганрог, ул.Розы Люксембург, 240/2	Россия, Ростовская область, Таганрог, улица Розы Люксембург, 240к2	0101000020E6100000F224E99AC971434062122EE4119C4740
77045	2	23	\N	193	55433	\N	47.269981999999999	Ростовская область, город Таганрог, ул.Поселковая, 58		0101000020E6100000CBF44BC45B7343401C412AC58EA24740
77004	2	23	\N	193	55454	\N	47.218142999999998	Ростовская область, город Таганрог, ул.Пархоменко, 21		0101000020E610000087527B116D6F4340F86C1D1CEC9B4740
77000	2	23	\N	193	55454	\N	47.218595999999998	Ростовская область, город Таганрог, ул.Пархоменко, 5		0101000020E61000007C0DC171196F4340A98427F4FA9B4740
76990	2	23	\N	193	55358	\N	47.221710999999999	Ростовская область, город Таганрог, ул.Октябрьская, 44/1		0101000020E6100000016DAB5967744340EC14AB06619C4740
76977	2	23	\N	193	55358	\N	47.214868000000003	Ростовская область, город Таганрог, ул.Октябрьская, 7		0101000020E6100000384BC972127643407D7A6CCB809B4740
76958	2	23	\N	193	55358	\N	47.228351000000004	Ростовская область, Мясниковский район, Недвиговское сельское поселение, х. Недвиговка, Октябрьская, 72 А		0101000020E61000001FB935E9B67243402481069B3A9D4740
76967	2	23	\N	193	6776	\N	47.202159999999999	Ростовская область, город Таганрог, пер.Некрасовский, 44	Россия, Ростовская область, Таганрог, Некрасовский переулок, 44	0101000020E61000002DD2C43BC07743409947FE60E0994740
76965	2	23	\N	193	6776	\N	47.207357000000002	Ростовская область, город Таганрог, пер.Некрасовский, 19	Россия, Ростовская область, Таганрог, Некрасовский переулок, 17	0101000020E610000013471E882C78434060CC96AC8A9A4740
77034	2	23	\N	193	55446	\N	47.252115563406598	Ростовская область, город Таганрог, ул.Московская, 72		0101000020E61000008C14CAC2D773434030664B5645A04740
77054	2	23	\N	193	55428	\N	47.262717000000002	Ростовская область, город Таганрог, ул.Москатова, 1		0101000020E6100000C287122D79764340378DEDB5A0A14740
77632	2	23	\N	193	55319	\N	47.267499000000001	Ростовская область, город Таганрог, ул.Михайловская, 51/1		0101000020E610000048E2E5E95C7943403A5B40683DA24740
77049	2	23	\N	193	55377	\N	47.265830000000001	Ростовская область, город Таганрог, ул.Маршала Жукова, 146/А		0101000020E61000000FD6FF39CC734340D925AAB706A24740
77043	2	23	\N	193	55377	\N	47.263340999999997	Ростовская область, город Таганрог, ул.Маршала Жукова, 192		0101000020E6100000F14A92E7FA72434014596B28B5A14740
77016	2	23	\N	193	55330	\N	47.229714999999999	Ростовская область, город Таганрог, ул.Ломоносова, 65		0101000020E610000028999CDA197043404833164D679D4740
76968	2	23	\N	193	55424	\N	47.200605000000003	Ростовская область, город Таганрог, ул.Ломакина, 2		0101000020E6100000D481ACA7567543400135B56CAD994740
76978	2	23	\N	193	6895	\N	47.214458	Ростовская область, город Таганрог, пер.Лермонтовский, 2	Россия, Ростовская область, Таганрог, Лермонтовский переулок, 2	0101000020E6100000B66801DA56774340CB2E185C739B4740
76559	2	23	\N	193	55268	\N	47.228712000000002	Ростовская область, Родионово-Несветайский район, сл.Большекрепинская, ул.Ленина, д.19		0101000020E61000005E82531F48744340F419506F469D4740
76206	2	23	\N	193	55268	\N	47.228712000000002	Ростовская область, Каменский район, х. Березовый, Ленина, 19-А		0101000020E61000005E82531F48744340F419506F469D4740
76984	2	23	\N	193	6935	\N	47.204909000000001	Ростовская область, город Таганрог, пер.Красногвардейский, 9	Россия, Ростовская область, Таганрог, Красногвардейский переулок, 9	0101000020E610000060EAE74D45724340FAD346753A9A4740
76996	2	23	\N	193	55393	\N	47.242448021701698	Ростовская область, город Таганрог, ул.Котлостроительная, 21/2	Россия, Ростовская область, Таганрог, улица Котлостроительная, 21к2	0101000020E6100000C710001C7B724340857D3B89089F4740
77025	2	23	\N	193	55311	\N	47.230670000000003	Ростовская область, город Таганрог, ул.Конторская, 84		0101000020E6100000E99AC937DB7643408C153598869D4740
76971	2	23	\N	193	6834	\N	47.203083999999997	Ростовская область, город Таганрог, пер.Комсомольский, 86/А	Россия, Ростовская область, Таганрог, Комсомольский переулок, 86а	0101000020E6100000118C834BC7744340A12B11A8FE994740
77019	2	23	\N	193	55399	\N	47.241536000000004	Ростовская область, город Таганрог, ул.Комарова, 30		0101000020E610000092B3B0A71D7043404167D2A6EA9E4740
77053	2	23	\N	193	55476	\N	47.259236999999999	Ростовская область, город Таганрог, ул.Кирова, 2		0101000020E6100000CC09DAE4F0754340E27492AD2EA14740
77015	2	23	\N	193	55459	\N	47.239559999999997	Ростовская область, город Таганрог, ул.Калинина, 109		0101000020E61000002635B401D870434002B7EEE6A99E4740
76980	2	23	\N	193	55375	\N	47.200275925431498	Ростовская область, город Таганрог, ул.Инструментальная, 25/2	Россия, Ростовская область, Таганрог, улица Инструментальная, 25к2	0101000020E6100000439259BDC37143403C16DBA4A2994740
77048	2	23	\N	193	55455	\N	47.263750999999999	Ростовская область, город Таганрог, ул.Инициативная, 48		0101000020E61000004E7CB5A338754340C6A4BF97C2A14740
77026	2	23	\N	193	55335	\N	47.2389379760046	Ростовская область, город Таганрог, ул.Заводская, 20/3	Россия, Ростовская область, Таганрог, улица Заводская	0101000020E610000033FD12F1D6754340C5E23785959E4740
76970	2	23	\N	193	6825	\N	47.210265005711904	Ростовская область, город Таганрог, пер.Добролюбовский, 9	Россия, Ростовская область, Таганрог, Добролюбовский переулок	0101000020E6100000253D0CAD4E784340293FA9F6E99A4740
77030	2	23	\N	193	55376	\N	47.247450999999998	Ростовская область, город Таганрог, ул.Дзержинского, 149		0101000020E6100000F4531C075E754340662E7079AC9F4740
77027	2	23	\N	193	55376	\N	47.236666	Ростовская область, город Таганрог, ул.Дзержинского, 115		0101000020E6100000AC915D69197543409E094D124B9E4740
77023	2	23	\N	193	55376	\N	47.229177	Ростовская область, город Таганрог, ул.Дзержинского, 67		0101000020E61000006A50340F6075434069FF03AC559D4740
76964	2	23	\N	193	55423	\N	47.208288000000003	Ростовская область, город Таганрог, ул.Греческая, 37		0101000020E61000006AFB57569A7843401B13622EA99A4740
76994	2	23	\N	193	55301	\N	47.234850638523199	Ростовская область, город Таганрог, ул.Восточная, 2	Россия, Ростовская область, Таганрог, улица Восточная	0101000020E6100000AEBB79AA437243406937FA980F9E4740
77017	2	23	\N	193	55398	\N	47.237375999999998	Ростовская область, город Таганрог, ул.Вишневая, 21		0101000020E6100000205ED72FD86F43407A6D3656629E4740
76803	2	23	\N	378	55384	\N	47.207774000000001	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Портовая, 82		0101000020E61000007AA9D898D7D74340C47AA356989A4740
76993	2	23	\N	193	6894	\N	47.229151999999999	Ростовская область, город Таганрог, Большой Проспект, 5	Россия, Ростовская область, Таганрог, Большой проспект, 3	0101000020E6100000809F71E14072434010E84CDA549D4740
76988	2	23	\N	193	6894	\N	47.2166575172471	Ростовская область, город Таганрог, Большой Проспект, 48/1	Россия, Ростовская область, Таганрог, Большой проспект, 48к1	0101000020E6100000787B1002F271434059350873BB9B4740
76979	2	23	\N	193	6900	\N	47.221882000000001	Ростовская область, город Таганрог, пер.Большой Садовый, 11	Россия, Ростовская область, Таганрог, Большой Садовый переулок, 11	0101000020E610000087E123624A76434019C91EA1669C4740
76997	2	23	\N	193	40153	\N	47.243143153098799	Ростовская область, город Таганрог, ул.Большая Бульварная, 12	Россия, Ростовская область, Таганрог, улица Бульварная, 12	0101000020E6100000753C66A0327243402CA0504F1F9F4740
77513	2	23	\N	193	55378	\N	47.260424	Ростовская область, город Таганрог, ул.Бабушкина, 43		0101000020E610000063B48EAA26784340F88BD99255A14740
77512	2	23	\N	193	55378	\N	47.252209999999998	Ростовская область, город Таганрог, ул.Бабушкина, 2/В		0101000020E61000004A7D59DAA9774340B1DCD26A48A04740
77635	2	23	\N	193	56581	\N	47.265022999999999	Ростовская область, город Таганрог, ул.Афоновых, 2		0101000020E61000008600E0D8B37743400AD80E46ECA14740
76973	2	23	\N	193	55443	\N	47.210093999999998	Ростовская область, город Таганрог, ул.Александровская, 47		0101000020E61000001422E010AA764340FC8A355CE49A4740
77050	2	23	\N	193	7651	\N	47.274456999999998	Ростовская область, город Таганрог, пер.7й Новый, 75	Россия, Ростовская область, Таганрог, 7-й Новый переулок, 75	0101000020E61000007D21E4BCFF73434042942F6821A34740
77051	2	23	\N	193	55306	\N	47.273502999999998	Ростовская область, город Таганрог, ул.3я Линия, 51		0101000020E610000058AA0B7899754340CF2D742502A34740
77028	2	23	\N	193	7390	\N	47.237945000000003	Ростовская область, город Таганрог, пер.3й Артиллерийский, 21	Россия, Ростовская область, Таганрог, 3-й Артиллерийский переулок, 21	0101000020E61000007973B8567B744340959F54FB749E4740
77041	2	23	\N	193	7552	\N	47.257739000000001	Ростовская область, город Таганрог, пер.17й Новый, 5/1	Россия, Ростовская область, Таганрог, 17-й Новый переулок, 5	0101000020E6100000E6E95C514A724340AEF36F97FDA04740
77029	2	23	\N	193	7409	\N	47.246051000000001	Ростовская область, город Таганрог, пер.14й Артиллерийский, 21	Россия, Ростовская область, Таганрог, 14-й Артиллерийский переулок, 21	0101000020E610000018778368AD744340F51263997E9F4740
77631	2	23	\N	193	6839	\N	47.273631999999999	Ростовская область, город Таганрог, пер.1й Новый, 8	Россия, Ростовская область, Таганрог, 1-й Новый переулок, 8	0101000020E6100000F5824F73F2764340CD91955F06A34740
77009	2	23	\N	193	55369	\N	47.221598606125497	Ростовская область, город Таганрог, ул.Чехова, 299/1	Россия, Ростовская область, Таганрог, улица Чехова, 299к1	0101000020E610000090DAC4C9FD704340C4E9245B5D9C4740
77001	2	23	\N	193	55369	\N	47.219575947421703	Ростовская область, город Таганрог, ул.Чехова, 339/3	Россия, Ростовская область, Таганрог, улица Чехова, 339	0101000020E6100000853E58C6866E4340467EFD101B9C4740
76998	2	23	\N	193	55369	\N	47.217494000000002	Ростовская область, город Таганрог, ул.Чехова, 357/3		0101000020E6100000C64D0D349F6D4340C289E8D7D69B4740
77018	2	23	\N	193	55267	\N	47.232455999999999	Ростовская область, город Таганрог, ул.Театральная, 1		0101000020E6100000AE6708C72C71434026E1421EC19D4740
77014	2	23	\N	193	55267	\N	47.232995000000003	Ростовская область, город Таганрог, ул.Театральная, 6		0101000020E610000059E02BBAF5704340D690B8C7D29D4740
77013	2	23	\N	193	55267	\N	47.233153999999999	Ростовская область, город Таганрог, ул.Театральная, 20		0101000020E610000036CB65A3737043403E7782FDD79D4740
76991	2	23	\N	193	55271	\N	47.217531000000001	Ростовская область, город Таганрог, Площадь Мира, 6		0101000020E61000005D86FF7403734340DF6E490ED89B4740
76092	2	23	\N	193	55352	\N	47.220303000000001	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Плеханова, 8		0101000020E6100000F1BC546CCC6F4340F81A82E3329C4740
75563	2	23	\N	56609	55097	\N	47.516675308786297	Ростовская область, Семикаракорский район, г. Семикаракорск, пр-кт Атаманский, 250	Россия, Ростовская область, Семикаракорский район, Семикаракорск	0101000020E61000001F662FDB4E67444095D4096822C24740
76461	2	23	\N	56609	55111	\N	47.5251058193559	Ростовская область, Семикаракорский район, г.Семикаракорск, ул. Араканцева, 2	Россия, Ростовская область, Семикаракорский район, Семикаракорск	0101000020E610000003EFE4D363694440797764AC36C34740
75503	2	23	\N	56609	55174	\N	47.519931391663299	Ростовская область, Семикаракорский района, г. Семикаракорск, 16-й переулок, 35	Россия, Ростовская область, Семикаракорский район, Семикаракорск	0101000020E610000044DE72F5636744409A9658198DC24740
75664	2	23	\N	56620	55183	\N	46.475687044188597	Ростовская область, Сальский район, г. Сальск, ул. Кутузова, 1	Россия, Ростовская область, Сальский район, Сальск	0101000020E61000004ED026874FC44440F110C64FE33C4740
75658	2	23	\N	56620	55186	\N	46.477495581162501	Ростовская область, Сальский район, г. Сальск, ул. Коломийцева, 128	Россия, Ростовская область, Сальский район, Сальск	0101000020E61000000CC9C9C4ADC4444044FCC3961E3D4740
76661	2	23	\N	378	\N	\N	47.218406000000002	"Ростовская область, город Ростов-на-Дону, Пролетарский район, парк им. В.Черевичкина, спорткомплекс ""Экспресс"""		0101000020E61000000F80B8AB57E5434006A051BAF49B4740
76646	2	23	\N	378	\N	\N	47.254506661942798	Ростовская область, город Ростов-на-Дону, Первомайский район, Сельмаш, 3		0101000020E6100000707B82C476E3434031CD74AF93A04740
76297	2	23	\N	378	182	\N	47.238641999999999	Ростовская область, Милютинский район, х. Степано-Савченский, ул. Школьная, д. 18	Россия, Ростовская область, Ростов-на-Дону, улица Школьная, 18	0101000020E61000002C499EEBFBE24340DCB930D28B9E4740
76574	2	23	\N	378	1960	\N	47.269675999999997	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Фурмановская, 82	Россия, Ростовская область, Ростов-на-Дону, улица Фурмановская, 82	0101000020E6100000E5F1B4FCC0DB43400F4240BE84A24740
76852	2	23	\N	378	5573	\N	47.214691000000002	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Тургеневская, д. 12	Россия, Ростовская область, Ростов-на-Дону, улица Тургеневская, 12	0101000020E6100000B22D03CE52DA43406EDFA3FE7A9B4740
76850	2	23	\N	378	5573	\N	47.216766	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Тургеневская, д. 48	Россия, Ростовская область, Ростов-на-Дону, улица Тургеневская, 48	0101000020E610000070B54E5C8EDB43403F7100FDBE9B4740
76626	2	23	\N	378	2733	\N	47.280704999999998	Ростовская область, город Ростов-на-Дону, Первомайский район, Туполева, 8/2	Россия, Ростовская область, Ростов-на-Дону, улица Туполева, 8	0101000020E6100000E86B96CB46E743406E693524EEA34740
76902	2	23	\N	378	6139	\N	47.263230999999998	Ростовская область, город Ростов-на-Дону, Октябрьский район, Таганрогская, 137	Россия, Ростовская область, Ростов-на-Дону, улица Таганрогская, 137	0101000020E610000022E010AAD4D443408D25AC8DB1A14740
77465	2	23	\N	378	492	\N	47.230682000000002	Ростовская область, Красносулинский район, х. Божковка, Советская, 1	Россия, Ростовская область, Ростов-на-Дону, улица Советская, 1	0101000020E6100000F08975AA7CE1434050E3DEFC869D4740
76854	2	23	\N	378	5557	\N	47.217689999999997	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Серафимовича, д. 25	Россия, Ростовская область, Ростов-на-Дону, улица Серафимовича, 25	0101000020E6100000C1E61C3C13DA434047551344DD9B4740
76836	2	23	\N	378	1446	\N	47.228687000000001	Ростовская область, город Ростов-на-Дону, Кировский район, Пушкинская, 190	Россия, Ростовская область, Ростов-на-Дону, улица Пушкинская, 190	0101000020E610000093567C43E1DD43409B02999D459D4740
76707	2	23	\N	378	3808	\N	47.204664000000001	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Портовая, 166	Россия, Ростовская область, Ростов-на-Дону, улица Портовая, 166	0101000020E61000000C957F2DAFD643409355116E329A4740
76889	2	23	\N	378	6017	\N	47.252276999999999	Ростовская область, город Ростов-на-Дону, Октябрьский район, Погодина, 5А	Россия, Ростовская область, Ростов-на-Дону, улица Погодина, 5а	0101000020E6100000EE23B726DDDA43403944DC9C4AA04740
76941	2	23	\N	378	6532	\N	47.218161000000002	Ростовская область, город Ростов-на-Дону, Советский район, Пескова, 17/1	Россия, Ростовская область, Ростов-на-Дону, улица Пескова, 17к1	0101000020E610000088F6B182DFCA43409F211CB3EC9B4740
76637	2	23	\N	378	2898	\N	47.2816571650512	Ростовская область, город Ростов-на-Дону, Первомайский район, Орская, 31А	Россия, Ростовская область, Ростов-на-Дону, улица Орская	0101000020E6100000145AD6FD63E3434041D829560DA44740
76294	2	23	\N	378	580	\N	47.266067999999997	Ростовская область, Милютинский район, х. Николаевский, ул. Молодежная, д. 4	Россия, Ростовская область, Ростов-на-Дону, улица Молодежная, 4	0101000020E6100000E63DCE3461E343408D4127840EA24740
76881	2	23	\N	378	5777	\N	47.238684999999997	Ростовская область, город Ростов-на-Дону, Октябрьский район, Мечникова, 61	Россия, Ростовская область, Ростов-на-Дону, улица Мечникова, 61	0101000020E6100000E1EF17B325D94340DB85E63A8D9E4740
76640	2	23	\N	378	2940	\N	47.255702999999997	Ростовская область, город Ростов-на-Дону, Первомайский район, Металлургическая, 100	Россия, Ростовская область, Ростов-на-Дону, улица Металлургическая, 100	0101000020E61000004AEEB089CCE243409A3E3BE0BAA04740
76634	2	23	\N	378	2859	\N	47.264961	Ростовская область, город Ростов-на-Дону, Первомайский район, Мелитопольская, 22	Россия, Ростовская область, Ростов-на-Дону, улица Мелитопольская, 22	0101000020E61000005E30B8E68EE4434094DBF63DEAA14740
76827	2	23	\N	378	5299	\N	47.233759999999997	Ростовская область, город Ростов-на-Дону, Кировский район, Малюгиной, 212	Россия, Ростовская область, Ростов-на-Дону, улица Малюгиной, 212	0101000020E6100000C2887D0228DC4340758E01D9EB9D4740
76094	2	23	\N	378	4410	\N	47.222433000000002	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Максима Горького, 22	Россия, Ростовская область, Ростов-на-Дону, улица Максима Горького, 28	0101000020E6100000A73CBA1116D943408D463EAF789C4740
76792	2	23	\N	378	4867	\N	47.228081000000003	Ростовская область, город Ростов-на-Дону, Железнодорожный район, ЛЕСОПАРКОВАЯ, 23 А	Россия, Ростовская область, Ростов-на-Дону, улица Лесопарковая, 23	0101000020E6100000B6F81400E3D3434064EB19C2319D4740
76819	2	23	\N	378	5206	\N	47.231667000000002	Ростовская область, город Ростов-на-Дону, Кировский район, ул.Лермонтовская, 161	Россия, Ростовская область, Ростов-на-Дону, улица Лермонтовская, 161	0101000020E610000002BA2F67B6DB4340FE47A643A79D4740
76802	2	23	\N	378	4990	\N	47.207351000000003	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Кулагина, 19	Россия, Ростовская область, Ростов-на-Дону, улица Кулагина, 19	0101000020E6100000909E228788D543407EE5417A8A9A4740
76794	2	23	\N	378	4892	\N	47.213355999999997	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Крупской, 43	Россия, Ростовская область, Ростов-на-Дону, улица Крупской, 43	0101000020E6100000124E0B5EF4D34340E333D93F4F9B4740
76832	2	23	\N	378	5360	\N	47.222819000000001	Ростовская область, город Ростов-на-Дону, Кировский район, Красных Зорь, 157	Россия, Ростовская область, Ростов-на-Дону, улица Красных Зорь, 157	0101000020E6100000D4D347E00FDF4340B6F63E55859C4740
76859	2	23	\N	378	929	\N	47.226025	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Красноармейская, д. 11	Россия, Ростовская область, Ростов-на-Дону, улица Красноармейская, 11	0101000020E61000001ADCD6169ED94340098A1F63EE9C4740
76931	2	23	\N	378	6427	\N	47.235210000000002	Ростовская область, город Ростов-на-Дону, Советский район, ул. Калининградская, 1	Россия, Ростовская область, Ростов-на-Дону, улица Калининградская, 1	0101000020E61000002BDA1CE736D1434099D87C5C1B9E4740
76621	2	23	\N	378	2616	\N	47.274219000000002	Ростовская область, город Ростов-на-Дону, Первомайский район, Казахская, 107	Россия, Ростовская область, Ростов-на-Дону, улица Казахская, 107	0101000020E61000000C3D62F4DCDE43408E78B29B19A34740
76885	2	23	\N	378	5978	\N	47.248002	Ростовская область, город Ростов-на-Дону, Октябрьский район, Зоологическая, 3	Россия, Ростовская область, Ростов-на-Дону, улица Зоологическая, 3	0101000020E61000006BB8C83D5DD54340DAAB8F87BE9F4740
76936	2	23	\N	378	6478	\N	47.231605999999999	Ростовская область, город Ростов-на-Дону, Советский район, ул. Еременко, 56/4	Россия, Ростовская область, Ростов-на-Дону, улица Еременко, 56	0101000020E6100000437573F1B7CF434058C7F143A59D4740
76587	2	23	\N	378	2133	\N	47.293540999999998	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Добровольского, 15/4	Россия, Ростовская область, Ростов-на-Дону, улица Добровольского, 15	0101000020E61000002504ABEAE5D943407F8461C092A54740
76642	2	23	\N	378	2714	\N	47.270367	Ростовская область, город Ростов-на-Дону, Первомайский район, Днепропетровская, 12	Россия, Ростовская область, Ростов-на-Дону, улица Днепропетровская, 10	0101000020E6100000E3A8DC442DE543407575C7629BA24740
76630	2	23	\N	378	2714	\N	47.271908000000003	Ростовская область, город Ростов-на-Дону, Первомайский район, Днепропетровская, 14	Россия, Ростовская область, Ростов-на-Дону, улица Днепропетровская, 14	0101000020E6100000058BC3995FE54340A9C29FE1CDA24740
76625	2	23	\N	378	2714	\N	47.283236000000002	Ростовская область, город Ростов-на-Дону, Первомайский район, Днепропетровская, 44	Россия, Ростовская область, Ростов-на-Дону, улица Днепропетровская, 44	0101000020E6100000C22FF5F3A6E643406286C61341A44740
76633	2	23	\N	378	2842	\N	47.269216999999998	Ростовская область, город Ростов-на-Дону, Первомайский район, Глинки, 95	Россия, Ростовская область, Ростов-на-Дону, улица Глинки, 93	0101000020E610000025EA059FE6E443407C43E1B375A24740
76865	2	23	\N	378	55200	\N	47.230923303397098	Ростовская область, город Ростов-на-Дону, Ленинский район, пер. Гайдара, д. 27	Россия, Ростовская область, Ростов-на-Дону, улица Гайдара	0101000020E61000008E05854199D64340757286E28E9D4740
76659	2	23	\N	378	55205	\N	47.231235148733901	Ростовская область, город Ростов-на-Дону, Пролетарский район, ул. В.Нольная, 15	Россия, Ростовская область, Ростов-на-Дону, улица Верхненольная, 13	0101000020E61000001137A79201E043406458C51B999D4740
76898	2	23	\N	378	6076	\N	47.261426999999998	Ростовская область, город Ростов-на-Дону, Октябрьский район, ул. Вавилова, 1	Россия, Ростовская область, Ростов-на-Дону, улица Вавилова, 1	0101000020E6100000B2F50CE198D743404CA59F7076A14740
76795	2	23	\N	378	4901	\N	47.218331999999997	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Балакирева, 32	Россия, Ростовская область, Ростов-на-Дону, улица Балакирева, 32	0101000020E6100000F4C1323674D54340CBD58F4DF29B4740
76702	2	23	\N	378	3754	\N	47.252443	Ростовская область, город Ростов-на-Дону, Пролетарский район, Аксайская, 22	Россия, Ростовская область, Ростов-на-Дону, улица Аксайская, 22	0101000020E6100000155454FD4AEB4340548D5E0D50A04740
76667	2	23	\N	378	3270	\N	47.235357	Ростовская область, город Ростов-на-Дону, Пролетарский район, 14-я линия, 50	Россия, Ростовская область, Ростов-на-Дону, улица 14-я Линия, 50	0101000020E61000005307793D98E043403DF19C2D209E4740
76665	2	23	\N	378	3270	\N	47.236579999999996	Ростовская область, город Ростов-на-Дону, Пролетарский район, 14-я линия, 64/69	Россия, Ростовская область, Ростов-на-Дону, улица 14-я Линия, 64	0101000020E61000000798F90E7EE043409F71E140489E4740
76663	2	23	\N	378	3246	\N	47.223956999999999	Ростовская область, город Ростов-на-Дону, Пролетарский район, 1-я линия, 54	Россия, Ростовская область, Ростов-на-Дону, улица 1-я Линия, 54	0101000020E61000008B70935165E04340EA5A7B9FAA9C4740
76695	2	23	\N	378	55255	\N	47.229394537994203	"Ростовская область, город Ростов-на-Дону, Пролетарский район, станция ""Кизитеринка"", вокзал"		0101000020E6100000FC53AA44D9E94340D66EBBD05C9D4740
76887	2	23	\N	378	78529	\N	47.251208814546601	Ростовская область, город Ростов-на-Дону, Октябрьский район, Ленина, 42А	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 42а	0101000020E61000000C3A2174D0D74340FEBAD39D27A04740
76567	2	23	\N	378	40569	\N	47.248635726875399	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 105/3	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 105к3	0101000020E6100000664B5645B8DB4340DB4DF04DD39F4740
76565	2	23	\N	378	40569	\N	47.248285059461097	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 125/1	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 125к1	0101000020E610000065C746205EDD43402F8B89CDC79F4740
76561	2	23	\N	378	40569	\N	47.249468552622098	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 92	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 92	0101000020E6100000C61858C7F1DD4340D32EA699EE9F4740
14043	1	17	\N	3130	22449	\N	58.045848999999997	г.Рыбинск, Чкалова, 93		0101000020E6100000B3614D65516C4340F3C64961DE054D40
76557	2	23	\N	378	40569	\N	47.248416560015201	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 217/219	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 217-219	0101000020E6100000A69883A0A3DF43409E62D520CC9F4740
76869	2	23	\N	378	55209	\N	47.224186262586201	Ростовская область, город Ростов-на-Дону, Ленинский район, пер. Саратовский, д. 40	Россия, Ростовская область, Ростов-на-Дону, Ленинский район	0101000020E61000004432E4D87AD843404C1C7920B29C4740
76608	2	23	\N	378	55402	\N	47.288065000000003	Ростовская область, город Ростов-на-Дону, Первомайский район, Штахановского, 18		0101000020E6100000BDFC4E9319DF4340A60F5D50DFA44740
76653	2	23	\N	378	3056	\N	47.265267000000001	Ростовская область, город Ростов-на-Дону, Первомайский район, Шолохова, 294/3	Россия, Ростовская область, Ростов-на-Дону, Шолохова проспект, 294	0101000020E61000007044F7AC6BE84340A1DAE044F4A14740
76651	2	23	\N	378	3056	\N	47.254900999999997	Ростовская область, город Ростов-на-Дону, Первомайский район, Шолохова, 262	Россия, Ростовская область, Ростов-на-Дону, Шолохова проспект, 262	0101000020E6100000529ACDE330E64340DD5B9198A0A04740
76649	2	23	\N	378	3056	\N	47.256864999999998	Ростовская область, город Ростов-на-Дону, Первомайский район, Шолохова, 272	Россия, Ростовская область, Ростов-на-Дону, Шолохова проспект, 272	0101000020E610000080F44D9A06E74340573ECBF3E0A04740
76244	2	23	\N	378	3056	\N	47.237864999999999	Ростовская область, Каменский район, х. Старая Станица, Шолохова, 46-А	Россия, Ростовская область, Ростов-на-Дону, Шолохова проспект, 46	0101000020E610000020B6F468AADF434078EE3D5C729E4740
76675	2	23	\N	378	55406	\N	47.237951000000002	Ростовская область, город Ростов-на-Дону, Пролетарский район, Ченцова, 95		0101000020E6100000CCED5EEE93E143407786A92D759E4740
76787	2	23	\N	378	55198	\N	47.217623000000003	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Саши Чебанова, 10	Россия, Ростовская область, Ростов-на-Дону, улица Чебанова, 10	0101000020E61000005AD76839D0D74340C0ED0912DB9B4740
76875	2	23	\N	378	5657	\N	47.234188000000003	Ростовская область, город Ростов-на-Дону, Октябрьский район, Халтуринский, 155	Россия, Ростовская область, Ростов-на-Дону, Халтуринский переулок, 155	0101000020E61000003BFBCA83F4D84340CE8E54DFF99D4740
76857	2	23	\N	378	5657	\N	47.221552000000003	Ростовская область, город Ростов-на-Дону, Ленинский район, пер. Халтуринский, д. 65	Россия, Ростовская область, Ростов-на-Дону, Халтуринский переулок, 65	0101000020E61000008D0E48C2BED94340842EE1D05B9C4740
76882	2	23	\N	378	55328	\N	47.241340861302703	Ростовская область, город Ростов-на-Дону, Октябрьский район, Фрунзе, 12	Россия, Ростовская область, Ростов-на-Дону, улица Фрунзе	0101000020E61000008BC56F0A2BD943408B170B43E49E4740
76654	2	23	\N	378	55285	\N	47.305435128903099	Ростовская область, город Ростов-на-Дону, Первомайский район, Фасадная, 99	Россия, Ростовская область, Ростов-на-Дону, улица Фасадная	0101000020E6100000AEA0698995E54340E2067C7E18A74740
76614	2	23	\N	378	55413	\N	47.281841999999997	Ростовская область, город Ростов-на-Дону, Первомайский район, Украинская, 26		0101000020E6100000F9BB77D498E04340D2510E6613A44740
76627	2	23	\N	378	55354	\N	47.280386999999997	Ростовская область, город Ростов-на-Дону, Первомайский район, Туполева, 4/1		0101000020E610000090300C5872E743409D9CA1B8E3A34740
76904	2	23	\N	378	55452	\N	47.264595	Ростовская область, город Ростов-на-Дону, Октябрьский район, Тимошенко, 30		0101000020E6100000F65CA626C1D34340B2D7BB3FDEA14740
76903	2	23	\N	378	55452	\N	47.266264	Ростовская область, город Ростов-на-Дону, Октябрьский район, Тимошенко, 22		0101000020E61000002E1C08C902D44340130D52F014A24740
76840	2	23	\N	378	55316	\N	47.240752999999998	Ростовская область, город Ростов-на-Дону, Кировский район, Текучева, 201		0101000020E61000001956F146E6DD4340FAB48AFED09E4740
76656	2	23	\N	378	3153	\N	47.230719000000001	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект Театральный, 46	Россия, Ростовская область, Ростов-на-Дону, Театральный проспект, 46	0101000020E610000055A2EC2DE5DE43406DC83F33889D4740
76655	2	23	\N	378	3153	\N	47.231630000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект Театральный, 48	Россия, Ростовская область, Ростов-на-Дону, Театральный проспект, 48	0101000020E61000002CF2EB87D8DE4340E162450DA69D4740
76905	2	23	\N	378	55365	\N	47.258961999999997	Ростовская область, город Ростов-на-Дону, Октябрьский район, Таганрогская, 114		0101000020E610000014B2F33636D343401074B4AA25A14740
76901	2	23	\N	378	55365	\N	47.263280000000002	Ростовская область, город Ростов-на-Дону, Октябрьский район, Таганрогская, 139/6		0101000020E6100000E335AFEAACD443406FD8B628B3A14740
76835	2	23	\N	378	55439	\N	47.228045000000002	Ростовская область, город Ростов-на-Дону, Кировский район, Суворова, 131		0101000020E610000003250516C0DE434017821C94309D4740
76639	2	23	\N	378	55460	\N	47.259371999999999	Ростовская область, город Ростов-на-Дону, Первомайский район, Студенческая, 4		0101000020E6100000137F1475E6E24340C2BF081A33A14740
76921	2	23	\N	378	6312	\N	47.213918999999997	Ростовская область, город Ростов-на-Дону, Советский район, пр. Стачки, 200		0101000020E61000001E520C9068D043401B7FA2B2619B4740
76919	2	23	\N	378	6312	\N	47.211477000000002	Ростовская область, город Ростов-на-Дону, Советский район, пр. Стачки, 195	Россия, Ростовская область, Ростов-на-Дону, Стачки проспект, 195	0101000020E6100000357BA01518D24340986DA7AD119B4740
76918	2	23	\N	378	6312	\N	47.211716000000003	Ростовская область, город Ростов-на-Дону, Советский район, пр. Стачки, 221	Россия, Ростовская область, Ростов-на-Дону, Стачки проспект, 221	0101000020E6100000D5B2B5BE48D043401D058882199B4740
76917	2	23	\N	378	6312	\N	47.211562999999998	Ростовская область, город Ростов-на-Дону, Советский район, пр. Стачки, 227	Россия, Ростовская область, Ростов-на-Дону, Стачки проспект, 227	0101000020E61000000DC68844A1CF43409605137F149B4740
76788	2	23	\N	378	4814	\N	47.216717000000003	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Ставского, 33	Россия, Ростовская область, Ростов-на-Дону, Ставского проспект, 33	0101000020E610000020EBA9D557D743405EBEF561BD9B4740
76841	2	23	\N	378	55409	\N	47.225608999999999	Ростовская область, город Ростов-на-Дону, Кировский район, Социалистическая, 195		0101000020E6100000417FA1478CDE4340755776C1E09C4740
76828	2	23	\N	378	55409	\N	47.222298000000002	Ростовская область, город Ростов-на-Дону, Кировский район, Социалистическая, 126		0101000020E6100000373811FDDADC4340ADFBC742749C4740
76692	2	23	\N	378	55407	\N	47.229140000000001	Ростовская область, город Ростов-на-Дону, Пролетарский район, Солидарности, 184		0101000020E61000005AF44E05DCE743404C1AA375549D4740
76817	2	23	\N	378	5179	\N	47.228161	Ростовская область, город Ростов-на-Дону, Кировский район, проспект Соколова, 58	Россия, Ростовская область, Ростов-на-Дону, Соколова проспект, 58	0101000020E6100000F2237EC51ADC4340809C3061349D4740
76933	2	23	\N	378	55421	\N	47.229323999999998	Ростовская область, город Ростов-на-Дону, Советский район, Содружества, 43		0101000020E610000060394206F2D043400D18247D5A9D4740
77694	2	23	\N	378	55471	\N	47.226680000000002	Ростовская область, город Ростов-на-Дону, Советский район, Совхозная, 18А		0101000020E6100000C364AA6054C843402254A9D9039D4740
76682	2	23	\N	378	55322	\N	47.229737794680403	Ростовская область, город Ростов-на-Дону, Пролетарский район, Советская, 30/1	Россия, Ростовская область, Ростов-на-Дону, улица Советская	0101000020E6100000CE33F6251BE143400053060E689D4740
76394	2	23	\N	378	55322	\N	47.229194999999997	Ростовская область, Тарасовский район, сл. Колушкино, ул. Советская, д. 91		0101000020E61000004F3DD2E0B6E043400FB40243569D4740
76872	2	23	\N	378	5591	\N	47.233178000000002	Ростовская область, город Ростов-на-Дону, Октябрьский район, Соборный, 88	Россия, Ростовская область, Ростов-на-Дону, Соборный переулок, 88	0101000020E61000009278793A57DA4340C712D6C6D89D4740
76851	2	23	\N	378	5591	\N	47.214261999999998	Ростовская область, город Ростов-на-Дону, Ленинский район, пер. Соборный, д. 1	Россия, Ростовская область, Ростов-на-Дону, Соборный переулок, 1	0101000020E61000006283859334DB43404563EDEF6C9B4740
76641	2	23	\N	378	55404	\N	47.254894999999998	Ростовская область, город Ростов-на-Дону, Первомайский район, Сержантова, 10		0101000020E6100000328E91EC11E24340FB743C66A0A04740
76848	2	23	\N	378	55419	\N	47.220236	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Серафимовича, д. 85		0101000020E6100000AC55BB26A4DB434070B378B1309C4740
76877	2	23	\N	378	5556	\N	47.235576999999999	Ростовская область, город Ростов-на-Дону, Октябрьский район, Семашко, 132	Россия, Ростовская область, Ростов-на-Дону, Семашко переулок, 132	0101000020E6100000AD69DE718ADA43404B581B63279E4740
76847	2	23	\N	378	5556	\N	47.223497999999999	Ростовская область, город Ростов-на-Дону, Ленинский район, пер. Семашко, д. 48	Россия, Ростовская область, Ростов-на-Дону, Семашко переулок, 48-50	0101000020E6100000BCEB6CC83FDB4340575C1C959B9C4740
76645	2	23	\N	378	55383	\N	47.250418000000003	Ростовская область, город Ростов-на-Дону, Первомайский район, Селиванова, 64/112		0101000020E61000008411FB0450E24340352A70B20DA04740
76671	2	23	\N	378	3348	\N	47.229396999999999	Ростовская область, город Ростов-на-Дону, Пролетарский район, площадь Свободы, 1	Россия, Ростовская область, Ростов-на-Дону, Свободы площадь, 1	0101000020E6100000E2E7BF07AFE14340776682E15C9D4740
76688	2	23	\N	378	55469	\N	47.231037000000001	Ростовская область, город Ростов-на-Дону, Пролетарский район, Сарьяна, 86	Россия, Ростовская область, Ростов-на-Дону, улица Сарьяна, 86	0101000020E61000009B5775560BE443403E95D39E929D4740
76629	2	23	\N	378	55308	\N	47.285736	Ростовская область, город Ростов-на-Дону, Первомайский район, Ректорская, 11		0101000020E6100000FDBB3E73D6E143401AA54BFF92A44740
76689	2	23	\N	378	3571	\N	47.230742999999997	Ростовская область, город Ростов-на-Дону, Пролетарский район, М.Расковой, 28	Россия, Ростовская область, Ростов-на-Дону, Расковой переулок, 28	0101000020E6100000535DC0CB0CE74340F56393FC889D4740
76796	2	23	\N	378	4914	\N	47.214213000000001	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Рабочая площадь, 23	Россия, Ростовская область, Ростов-на-Дону, Рабочая площадь, 23	0101000020E61000006781768714D5434064B0E2546B9B4740
76822	2	23	\N	378	55466	\N	47.226177999999997	Ростовская область, город Ростов-на-Дону, Кировский район, Пушкинская, 128		0101000020E61000000E32C9C859DC43408F899466F39C4740
76799	2	23	\N	378	55356	\N	47.215131	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Профсоюзная, 45		0101000020E61000005D6E30D461D743408AADA069899B4740
76786	2	23	\N	378	55356	\N	47.213234	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Профсоюзная, 29/22		0101000020E6100000CE3637A627D84340983270404B9B4740
76809	2	23	\N	378	5077	\N	47.196067999999997	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Пржевальского, 30	Россия, Ростовская область, Ростов-на-Дону, Пржевальского переулок, 30	0101000020E6100000C3BCC79926D0434064E597C118994740
76808	2	23	\N	378	55384	\N	47.191696	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Портовая, 541		0101000020E610000044C18C2958D143401363997E89984740
76806	2	23	\N	378	55384	\N	47.202030999999998	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Портовая, 238		0101000020E610000086A92D7590D543409BE3DC26DC994740
76644	2	23	\N	378	55431	\N	47.250638000000002	Ростовская область, город Ростов-на-Дону, Первомайский район, Полторацкого, 10		0101000020E6100000D19332A9A1E343404391EEE714A04740
76929	2	23	\N	378	55374	\N	47.226753000000002	Ростовская область, город Ростов-на-Дону, Советский район, ул. Петрозаводская, 137А		0101000020E610000077499C1551D143408CA2073E069D4740
76928	2	23	\N	378	55374	\N	47.226972836200297	Ростовская область, город Ростов-на-Дону, Советский район, Петрозаводская, 137А	Россия, Ростовская область, Ростов-на-Дону, улица Петрозаводская, 137в	0101000020E610000055DB4DF04DD143409A0986730D9D4740
76892	2	23	\N	378	6041	\N	47.254050999999997	Ростовская область, город Ростов-на-Дону, Октябрьский район, Педагогический, 24	Россия, Ростовская область, Ростов-на-Дону, Педагогический переулок, 24	0101000020E6100000FDA02E5228D943400F4240BE84A04740
76581	2	23	\N	378	55430	\N	47.284128000000003	Ростовская область, город Ростов-на-Дону, Ворошиловский район, ул. Пацаева, 11 (МБОУ №288)		0101000020E61000004BCD1E6805DA43405FF0694E5EA44740
76874	2	23	\N	378	107	\N	47.234298000000003	Ростовская область, город Ростов-на-Дону, Октябрьский район, Островского, 153	Россия, Ростовская область, Ростов-на-Дону, Островского переулок, 153	0101000020E6100000A96917D34CD9434055C2137AFD9D4740
76573	2	23	\N	378	1919	\N	47.262185000000002	"Ростовская область, город Ростов-на-Дону, Ворошиловский район, пер.Оренбургский, 22/1 (МБУЗ ""Городская поликлиника №3 г.Ростова-на-Дону"""		0101000020E6100000FA9B508880DB43403A4030478FA14740
76571	2	23	\N	378	55429	\N	47.263365	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Оренбургский, 26/55		0101000020E6100000F1A0D9756FDB43409DF4BEF1B5A14740
77646	2	23	\N	378	55347	\N	47.302105807890399	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Орбитальная, 86/1	Россия, Ростовская область, Ростов-на-Дону, улица Орбитальная, 86к1	0101000020E6100000C39E76F86BDE434073F6CE68ABA64740
76601	2	23	\N	378	55347	\N	47.301844329178202	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Орбитальная, 78/1	Россия, Ростовская область, Ростов-на-Дону, улица Орбитальная, 78	0101000020E6100000433A3C84F1DD4340363FFED2A2A64740
76599	2	23	\N	378	55347	\N	47.300758374662799	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Орбитальная, 66/2	Россия, Ростовская область, Ростов-на-Дону, улица Орбитальная, 66к2	0101000020E6100000EFFFE38409DD43405401F73C7FA64740
76598	2	23	\N	378	55347	\N	47.300545	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Орбитальная, 50/1		0101000020E6100000642310AFEBDB4340F8FC304278A64740
76590	2	23	\N	378	55347	\N	47.298168094946703	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Орбитальная, 26/1	Россия, Ростовская область, Ростов-на-Дону, улица Орбитальная, 26к1	0101000020E6100000C32973F38DDA43405B5B785E2AA64740
76564	2	23	\N	378	1817	\N	47.245077999999999	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Обуховский, 3	Россия, Ростовская область, Ростов-на-Дону, Обуховский переулок, 3	0101000020E61000001CCEFC6A0EDC43400B7C45B75E9F4740
76616	2	23	\N	378	2461	\N	47.275765	Ростовская область, город Ростов-на-Дону, Первомайский район, Обский, 7/2		0101000020E61000001024EF1CCADE4340D3307C444CA34740
76609	2	23	\N	378	2461	\N	47.284317999999999	Ростовская область, город Ростов-на-Дону, Первомайский район, Обский, 122	Россия, Ростовская область, Ростов-на-Дону, Обский переулок, 122	0101000020E61000008ACA863595DF434002D53F8864A44740
76853	2	23	\N	378	55333	\N	47.215735651709402	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Обороны, д. 24	Россия, Ростовская область, Ростов-на-Дону, улица Обороны	0101000020E610000020D1048A58DA4340F148BC3C9D9B4740
76791	2	23	\N	378	55327	\N	47.222714000000003	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Некрасовская, 22		0101000020E6100000F8A8BF5E61D54340412E71E4819C4740
76890	2	23	\N	378	55385	\N	47.282839000000003	Ростовская область, город Ростов-на-Дону, Октябрьский район, Неклиновская, 4/1Б		0101000020E6100000DC0E0D8B51D9434045847F1134A44740
76893	2	23	\N	378	6059	\N	47.250638000000002	Ростовская область, город Ростов-на-Дону, Октябрьский район, Народного Ополчения, 2	Россия, Ростовская область, Ростов-на-Дону, Народного Ополчения площадь, 2	0101000020E61000007FDC7EF964D943404391EEE714A04740
76684	2	23	\N	378	55331	\N	47.227364999999999	Ростовская область, город Ростов-на-Дону, Пролетарский район, Мясникова, 12		0101000020E6100000268FA7E507E24340A5A0DB4B1A9D4740
76849	2	23	\N	378	55299	\N	47.218038999999997	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Московская, д. 49		0101000020E610000037C30DF8FCDA43405320B3B3E89B4740
76883	2	23	\N	378	1909	\N	47.246447213521002	Ростовская область, город Ростов-на-Дону, Октябрьский район, Нагибина, 17/2	Россия, Ростовская область, Ростов-на-Дону, Михаила Нагибина проспект, 17к2	0101000020E6100000B85CFDD824DB4340429946938B9F4740
76570	2	23	\N	378	1909	\N	47.257849	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Михаила Нагибина, 33	Россия, Ростовская область, Ростов-на-Дону, Михаила Нагибина проспект, 33а	0101000020E6100000E2E7BF07AFDB434035272F3201A14740
76569	2	23	\N	378	1909	\N	47.253892	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Михаила Нагибина, 29	Россия, Ростовская область, Ростов-на-Дону, Михаила Нагибина проспект, 29	0101000020E61000005BD2510E66DB4340A75B76887FA04740
76624	2	23	\N	378	55381	\N	47.297648000000002	Ростовская область, город Ростов-на-Дону, Первомайский район, Миронова, 8		0101000020E6100000E10B93A982DF434023DC645419A64740
76648	2	23	\N	378	197	\N	47.2455	Ростовская область, город Ростов-на-Дону, Первомайский район, Мира, 10	Россия, Ростовская область, Ростов-на-Дону, Мира площадь, 10	0101000020E6100000CE8DE9094BE243408195438B6C9F4740
76647	2	23	\N	378	55462	\N	47.267203721711702	Ростовская область, город Ростов-на-Дону, Первомайский район, Мира, 9	Россия, Ростовская область, Ростов-на-Дону, Оренбургский переулок	0101000020E6100000B728B34126DB434021AE9CBD33A24740
76790	2	23	\N	378	55463	\N	47.222512999999999	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Минераловодская, 128		0101000020E61000003A90F5D4EAD54340A9F7544E7B9C4740
76876	2	23	\N	378	55357	\N	47.237876999999997	Ростовская область, город Ростов-на-Дону, Октябрьский район, Мечникова, 130		0101000020E6100000F3E505D847D943403CBCE7C0729E4740
76868	2	23	\N	378	55357	\N	47.239499000000002	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Мечникова, д. 41		0101000020E6100000DE1CAED51ED843405D363AE7A79E4740
76867	2	23	\N	378	55357	\N	47.241157000000001	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Мечникова, д. 17		0101000020E610000079909E2287D64340CA198A3BDE9E4740
76866	2	23	\N	378	55357	\N	47.241180999999997	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Мечникова, д. 19А		0101000020E6100000BB270F0BB5D6434052B5DD04DF9E4740
76871	2	23	\N	378	55389	\N	47.231189588142598	Ростовская область, город Ростов-на-Дону, Октябрьский район, Малюгиной, 163/72	Россия, Ростовская область, Ростов-на-Дону, Соборный переулок, 72	0101000020E6100000DDD0949D7EDA4340C49448A2979D4740
76831	2	23	\N	378	55389	\N	47.235118	Ростовская область, город Ростов-на-Дону, Кировский район, Малюгиной, 233		0101000020E610000061E28FA2CEDC4340B859BC58189E4740
76920	2	23	\N	378	55392	\N	47.213380999999998	Ростовская область, город Ростов-на-Дону, Советский район, Малиновского, 36		0101000020E61000004776A565A4CE43403C4B9011509B4740
76858	2	23	\N	378	55408	\N	47.222714000000003	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. М.Горького, д. 30		0101000020E610000080B9162D40D94340412E71E4819C4740
76846	2	23	\N	378	55408	\N	47.225591000000001	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. М.Горького, д. 115		0101000020E61000007DCEDDAE97DA4340CFA2772AE09C4740
76826	2	23	\N	378	55408	\N	47.228276999999999	Ростовская область, город Ростов-на-Дону, Кировский район, Максима Горького, 166		0101000020E61000001E51A1BAB9DC4340E9B6442E389D4740
76932	2	23	\N	378	55332	\N	47.236536999999998	Ростовская область, город Ростов-на-Дону, Советский район, ул.Мадояна, 205Б		0101000020E6100000882F134548D14340A0A52BD8469E4740
76793	2	23	\N	378	55332	\N	47.233826999999998	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Мадояна, 126		0101000020E6100000B075A911FAD14340FDF50A0BEE9D4740
76800	2	23	\N	378	55470	\N	47.210363000000001	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Литвинова, 4		0101000020E6100000AF7C96E7C1D54340ECA4BE2CED9A4740
76683	2	23	\N	378	55323	\N	47.223363543682702	Ростовская область, город Ростов-на-Дону, Пролетарский район, Листопадова, 42/79		0101000020E6100000304B3B3597E14340478D0931979C4740
76837	2	23	\N	378	55475	\N	47.234720000000003	Ростовская область, город Ростов-на-Дону, Кировский район, Лермонтовская, 229		0101000020E6100000EE5BAD1397DD4340CBDB114E0B9E4740
76880	2	23	\N	378	55447	\N	47.242643000000001	Ростовская область, город Ростов-на-Дону, Октябрьский район, Лениногорская, 9		0101000020E610000059BF99982EDA43403ACD02ED0E9F4740
76886	2	23	\N	378	55474	\N	47.250009836633097	Ростовская область, город Ростов-на-Дону, Октябрьский район, Ленина, 61	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект	0101000020E610000030815B77F3D8434024D6E25300A04740
76566	2	23	\N	378	40631	\N	47.250345767795302	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 64/2	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 64к2	0101000020E61000002D95B7239CDC43409B5775560BA04740
76563	2	23	\N	378	40631	\N	47.247561001481202	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 113/4	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 113к4	0101000020E6100000EA3E00A94DDC4340ED612F14B09F4740
76560	2	23	\N	378	40631	\N	47.250242922635003	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 92/1	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 92к1	0101000020E610000097C80567F0DD4340C6866EF607A04740
76555	2	23	\N	378	40631	\N	47.248665976396403	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ленина, 245	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 245	0101000020E6100000363FFED2A2E0434046D09849D49F4740
76891	2	23	\N	378	5969	\N	47.250185999999999	Ростовская область, город Ростов-на-Дону, Октябрьский район, Ленина, 44	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 44	0101000020E6100000280EA0DFF7D9434062F5471806A04740
76884	2	23	\N	378	5969	\N	47.249218999999997	Ростовская область, город Ростов-на-Дону, Октябрьский район, Ленина, 83А	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 83а	0101000020E6100000309C6B98A1D943405A457F68E69F4740
76606	2	23	\N	378	55355	\N	47.295735000000001	Ростовская область, город Ростов-на-Дону, Первомайский район, Лелюшенко, 7		0101000020E6100000EA5A7B9FAADE43402BA4FCA4DAA54740
76604	2	23	\N	378	55355	\N	47.295338000000001	Ростовская область, город Ростов-на-Дону, Первомайский район, Лелюшенко, 3/4		0101000020E6100000F3E2C4573BDE43400EA2B5A2CDA54740
76568	2	23	\N	378	55412	\N	47.255274	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Ларина, 24А		0101000020E6100000F14A92E7FADA434072C284D1ACA04740
76636	2	23	\N	378	55461	\N	47.263280000000002	Ростовская область, город Ростов-на-Дону, Первомайский район, Курчатова, 2		0101000020E6100000D95BCAF962E343406FD8B628B3A14740
77680	2	23	\N	378	56146	\N	47.174052571617501	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Кумженский, 62 А		0101000020E61000008D7E349C32C74340A662635E47964740
76888	2	23	\N	378	55396	\N	47.255287000000003	Ростовская область, город Ростов-на-Дону, Октябрьский район, Кропоткина, 31		0101000020E6100000A9A0A2EA57D84340070C923EADA04740
76708	2	23	\N	378	55348	\N	47.262135102605903	Ростовская область, город Ростов-на-Дону, Октябрьский район, Кривоноса, 9/4	Россия, Ростовская область, Ростов-на-Дону, улица Кривоноса	0101000020E61000006A696E85B0D243408811C2A38DA14740
76838	2	23	\N	378	5438	\N	47.234940999999999	Ростовская область, город Ростов-на-Дону, Кировский район, переулок Крепостной, 139	Россия, Ростовская область, Ростов-на-Дону, Крепостной переулок, 139	0101000020E6100000DEAF027CB7DD4340A9BEF38B129E4740
76940	2	23	\N	378	6520	\N	47.196252000000001	Ростовская область, город Ростов-на-Дону, Советский район, Красноярский пер, 24а	Россия, Ростовская область, Ростов-на-Дону, Красноярский переулок, 26	0101000020E6100000D61A4AED45CE434026E318C91E994740
76860	2	23	\N	378	55411	\N	47.224953999999997	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Красноармейская, д. 5		0101000020E610000070CD1DFD2FD943405C8DEC4ACB9C4740
76830	2	23	\N	378	55411	\N	47.231183999999999	Ростовская область, город Ростов-на-Дону, Кировский район, Красноармейская, 232		0101000020E610000036AB3E575BDD4340E2ADF36F979D4740
76703	2	23	\N	378	55417	\N	47.236960000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, Краеведческая, 13		0101000020E61000006BD26D895CEA4340E73A8DB4549E4740
77696	2	23	\N	378	55400	\N	47.292887	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Космонавтов, 24		0101000020E61000006DAB59677CDB434037363B527DA54740
77697	2	23	\N	378	2213	\N	47.285290000000003	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Космонавтов, 6/1	Россия, Ростовская область, Ростов-на-Дону, Космонавтов площадь, 6к1	0101000020E61000002B6A300DC3DB43401CF0F96184A44740
76597	2	23	\N	378	2213	\N	47.298228999999999	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Космонавтов, 36	Россия, Ростовская область, Ростов-на-Дону, Космонавтов площадь, 36	0101000020E61000005EB9DE3653DB434001DC2C5E2CA64740
76594	2	23	\N	378	55351	\N	47.291536000000001	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Космонавтов, 18/2		0101000020E610000083A5BA8097DB4340A7CD380D51A54740
76596	2	23	\N	378	2118	\N	47.2982690217693	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Королева, 25/3	Россия, Ростовская область, Ростов-на-Дону, Королева проспект, 25к3	0101000020E610000060B1868BDCDB43408F34B8AD2DA64740
76589	2	23	\N	378	2118	\N	47.295521000000001	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Королева, 15/4	Россия, Ростовская область, Ростов-на-Дону, Королева проспект, 15	0101000020E610000080D8D2A3A9DA4340FF23D3A1D3A54740
76585	2	23	\N	378	2118	\N	47.293650999999997	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Королева, 12/3	Россия, Ростовская область, Ростов-на-Дону, Королева проспект, 12	0101000020E61000003082C64CA2DA434006B8205B96A54740
76687	2	23	\N	378	55465	\N	47.230736999999998	Ростовская область, город Ростов-на-Дону, Пролетарский район, Комсомольская, 57		0101000020E6100000FAEDEBC039E34340137D3ECA889D4740
76916	2	23	\N	378	6286	\N	47.208129	Ростовская область, город Ростов-на-Дону, Советский район, пр. Коммунистический, 42/4	Россия, Ростовская область, Ростов-на-Дону, Коммунистический проспект, 42	0101000020E61000002C4833164DCF4340B22C98F8A39A4740
76915	2	23	\N	378	6286	\N	47.208238999999999	Ростовская область, город Ростов-на-Дону, Советский район, Коммунистический пр, 11	Россия, Ростовская область, Ростов-на-Дону, Коммунистический проспект, 11	0101000020E6100000E94482A966D2434039605793A79A4740
76678	2	23	\N	378	55416	\N	47.244075000000002	Ростовская область, город Ростов-на-Дону, Пролетарский район, Коммунаров, 34		0101000020E61000002F4D11E0F4E24340B7627FD93D9F4740
76588	2	23	\N	378	2017	\N	47.290638000000001	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Комарова, 6	Россия, Ростовская область, Ростов-на-Дону, Комарова бульвар, 6	0101000020E61000005055A18158D84340C87C40A033A54740
76586	2	23	\N	378	2017	\N	47.289195999999997	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Комарова, 18	Россия, Ростовская область, Ростов-на-Дону, Комарова бульвар, 18	0101000020E61000004E417E3672D943402711E15F04A54740
76584	2	23	\N	378	2017	\N	47.289385000000003	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Комарова, 28/3	Россия, Ростовская область, Ростов-на-Дону, Комарова бульвар, 28	0101000020E6100000DB5031CEDFDA4340FB7953910AA54740
76583	2	23	\N	378	2017	\N	47.286763000000001	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Комарова, 3/2	Россия, Ростовская область, Ростов-на-Дону, Комарова бульвар, 3	0101000020E6100000F1643733FAD94340F75965A6B4A44740
76579	2	23	\N	378	2017	\N	47.287208999999997	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Комарова, 7/3	Россия, Ростовская область, Ростов-на-Дону, Комарова бульвар, 7	0101000020E6100000E2C8039145DA4340F50EB743C3A44740
76578	2	23	\N	378	2017	\N	47.286025240906703	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Комарова, 9/5	Россия, Ростовская область, Ростов-на-Дону, Комарова бульвар, 9к5	0101000020E6100000DCB8C5FCDCDA4340516B9A779CA44740
76618	2	23	\N	378	55435	\N	47.274341	Ростовская область, город Ростов-на-Дону, Первомайский район, Киргизская, 12		0101000020E61000002CB7B41A12E14340D9791B9B1DA34740
76617	2	23	\N	378	55435	\N	47.274872999999999	Ростовская область, город Ростов-на-Дону, Первомайский район, Киргизская, 41		0101000020E6100000172EABB019E04340D6C6D8092FA34740
76909	2	23	\N	378	55420	\N	47.200843999999996	Ростовская область, город Ростов-на-Дону, Советский район, Каширская, 20		0101000020E6100000B70BCD751ACF434085CC9541B5994740
76930	2	23	\N	378	55391	\N	47.235210000000002	Ростовская область, город Ростов-на-Дону, Советский район, Калининградская, 1		0101000020E61000002BDA1CE736D1434099D87C5C1B9E4740
76620	2	23	\N	378	55353	\N	47.272625326624002	Ростовская область, город Ростов-на-Дону, Первомайский район, Казахская, 89/4	Россия, Ростовская область, Ростов-на-Дону, улица Казахская, 89к4	0101000020E6100000DBBFB2D2A4DE434037894160E5A24740
76619	2	23	\N	378	55353	\N	47.275790000000001	Ростовская область, город Ростов-на-Дону, Первомайский район, Казахская, 80/1		0101000020E610000014E8137992DE43402C4833164DA34740
77759	2	23	\N	378	55467	\N	47.216012999999997	Ростовская область, город Ростов-на-Дону, Советский район, ул.Зорге, д.28		0101000020E61000006E4E250340D1434063416150A69B4740
76926	2	23	\N	378	55467	\N	47.216453000000001	Ростовская область, город Ростов-на-Дону, Советский район, ул.Зорге, д.7		0101000020E61000006403E962D3D04340800F5EBBB49B4740
76631	2	23	\N	378	55427	\N	47.269480000000001	Ростовская область, город Ростов-на-Дону, Первомайский район, З. Космодемьянской, 47		0101000020E61000008A7269FCC2E743408A7615527EA24740
76824	2	23	\N	378	5263	\N	47.222617	Ростовская область, город Ростов-на-Дону, Кировский район, переулок Журавлева, 26	Россия, Ростовская область, Ростов-на-Дону, Журавлева переулок, 24	0101000020E6100000B45549641FDE43404E44BFB67E9C4740
76939	2	23	\N	378	55362	\N	47.232995000000003	Ростовская область, город Ростов-на-Дону, Советский район, Еременко, 87		0101000020E6100000537B116DC7CE4340D690B8C7D29D4740
76937	2	23	\N	378	55362	\N	47.230364000000002	Ростовская область, город Ростов-на-Дону, Советский район, Еременко, 60/5		0101000020E610000054C554FA09CF43407F164B917C9D4740
76935	2	23	\N	378	55362	\N	47.228792520200798	Ростовская область, город Ростов-на-Дону, Советский район, Еременко, 56/4	Россия, Ростовская область, Ростов-на-Дону, улица Еременко, 56к4	0101000020E61000008927BB99D1CF4340E146CA16499D4740
76862	2	23	\N	378	5734	\N	47.230944999999998	Ростовская область, город Ростов-на-Дону, Ленинский район, пер. Доломановский, д. 93	Россия, Ростовская область, Ростов-на-Дону, Доломановский переулок, 93	0101000020E6100000FB40F2CEA1D843405D16139B8F9D4740
76615	2	23	\N	378	2488	\N	47.281725999999999	Ростовская область, город Ростов-на-Дону, Первомайский район, Днепровский, 103/18		0101000020E6100000AB984A3FE1E043406937FA980FA44740
76611	2	23	\N	378	2488	\N	47.285558999999999	Ростовская область, город Ростов-на-Дону, Первомайский район, Днепровский, 116	Россия, Ростовская область, Ростов-на-Дону, Днепровский переулок, 116	0101000020E6100000D87F9D9B36E143400B0A83328DA44740
76610	2	23	\N	378	2488	\N	47.286817999999997	Ростовская область, город Ростов-на-Дону, Первомайский район, Днепровский, 131	Россия, Ростовская область, Ростов-на-Дону, Днепровский переулок, 131	0101000020E6100000EBC9FCA36FE04340BAF3C473B6A44740
76680	2	23	\N	378	3463	\N	47.246496999999998	Ростовская область, город Ростов-на-Дону, Пролетарский район, Дзержинского, 3	Россия, Ростовская область, Ростов-на-Дону, Дзержинского переулок, 1	0101000020E61000004BB1A371A8E34340F3C7B4368D9F4740
76805	2	23	\N	378	5033	\N	47.204436999999999	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Деревянко, 14	Россия, Ростовская область, Ростов-на-Дону, Деревянко переулок, 12	0101000020E61000004CA59F7076D74340D28BDAFD2A9A4740
76789	2	23	\N	378	55444	\N	47.219574999999999	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Гусева, 2	Россия, Ростовская область, Ростов-на-Дону, улица Депутатская, 24	0101000020E610000052B9895A9AD7434075029A081B9C4740
76900	2	23	\N	378	6130	\N	47.26191	Ростовская область, город Ростов-на-Дону, Октябрьский район, Госпитальный, 1	Россия, Ростовская область, Ростов-на-Дону, Госпитальный переулок, 3	0101000020E6100000A2F0D93A38D64340683F524486A14740
76681	2	23	\N	378	55437	\N	47.242263999999999	Ростовская область, город Ростов-на-Дону, Пролетарский район, Горсоветская, 49		0101000020E6100000842A357BA0E34340C37FBA81029F4740
76691	2	23	\N	378	55324	\N	47.229543999999997	Ростовская область, город Ростов-на-Дону, Пролетарский район, Герцена, 4		0101000020E6100000821C9430D3E443401B7FA2B2619D4740
76861	2	23	\N	378	5719	\N	47.224893000000002	Ростовская область, город Ростов-на-Дону, Ленинский район, пер.Гвардейский, 2/51	Россия, Ростовская область, Ростов-на-Дону, Гвардейский переулок, 2	0101000020E61000007381CB63CDD84340B70C384BC99C4740
76878	2	23	\N	378	5895	\N	47.237915800315001	Ростовская область, город Ростов-на-Дону, Октябрьский район, Гагарина, 1	Россия, Ростовская область, Ростов-на-Дону, Гагарина площадь, 1	0101000020E61000000F81238106DB4340FA980F08749E4740
76643	2	23	\N	378	55366	\N	47.280675000000002	Ростовская область, город Ростов-на-Дону, Первомайский район, Вятская, 112Б		0101000020E6100000D40B3ECDC9E1434004E78C28EDA34740
76613	2	23	\N	378	55366	\N	47.287300999999999	Ростовская область, город Ростов-на-Дону, Первомайский район, Вятская, 27		0101000020E6100000DB519CA38EDE4340D68D7747C6A44740
76612	2	23	\N	378	55366	\N	47.280949999999997	Ростовская область, город Ростов-на-Дону, Первомайский район, Вятская, 108		0101000020E6100000807EDFBF79E14340D5E76A2BF6A34740
76810	2	23	\N	378	55291	\N	47.189056999999998	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Всесоюзная, 128		0101000020E61000004034F3E49AD04340390A100533984740
14054	1	17	\N	3130	22476	\N	58.045848999999997	г. Рыбинск, Чехова, 48а		0101000020E6100000B3614D65516C4340F3C64961DE054D40
76821	2	23	\N	378	5129	\N	47.219329999999999	Ростовская область, город Ростов-на-Дону, Кировский район, проспект Ворошиловский, 29	Россия, Ростовская область, Ростов-на-Дону, Ворошиловский проспект, 29	0101000020E61000005260014C19DC43400E846401139C4740
76813	2	23	\N	378	5129	\N	47.217328999999999	Ростовская область, город Ростов-на-Дону, Кировский район, проспект Ворошиловский, 2/2	Россия, Ростовская область, Ростов-на-Дону, Ворошиловский проспект, 2	0101000020E6100000971E4DF564DC434077BCC96FD19B4740
76592	2	23	\N	378	55349	\N	47.287007000000003	Ростовская область, город Ростов-на-Дону, Ворошиловский район, ул. Волкова, 41А		0101000020E610000050560C5707DC43408E5C37A5BCA44740
76591	2	23	\N	378	55349	\N	47.283175	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Волкова, 18		0101000020E6100000DD408177F2DB4340BC0512143FA44740
76577	2	23	\N	378	55349	\N	47.283230000000003	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Волкова, 5/6		0101000020E61000001EE21FB6F4DA4340809F71E140A44740
76575	2	23	\N	378	55349	\N	47.280898429832803	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Волкова, 6/2	Россия, Ростовская область, Ростов-на-Дону, улица Волкова, 6к2	0101000020E6100000F4C29D0B23DB434083C13577F4A34740
76807	2	23	\N	378	55450	\N	47.195357999999999	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Войкова, 136		0101000020E6100000145E82531FD443408881AE7D01994740
76798	2	23	\N	378	55438	\N	47.215541999999999	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Верещагина, 10		0101000020E6100000FBAE08FEB7D643400C7558E1969B4740
76864	2	23	\N	378	55390	\N	47.226391999999997	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Варфоломеева, д. 1А		0101000020E6100000A3906456EFD64340BB09BE69FA9C4740
76820	2	23	\N	378	55390	\N	47.233870000000003	Ростовская область, город Ростов-на-Дону, Кировский район, Варфоломеева, 259		0101000020E61000001096B1A19BDB4340FDC1C073EF9D4740
76895	2	23	\N	378	55394	\N	47.269590000000001	Ростовская область, город Ростов-на-Дону, Октябрьский район, Вавилова, 58		0101000020E61000007E9065C1C4D7434011AAD4EC81A24740
76658	2	23	\N	378	55202	\N	47.218406000000002	Ростовская область, город Ростов-на-Дону, Пролетарский район, ул. В.Нольная, 8		0101000020E61000000F80B8AB57E5434006A051BAF49B4740
76664	2	23	\N	378	55197	\N	47.226723431248601	Ростовская область, город Ростов-на-Дону, Пролетарский район, В.Закруткина, 67	Россия, Ростовская область, Ростов-на-Дону, улица Закруткина, 67	0101000020E6100000F20698F90EE0434021205F42059D4740
76925	2	23	\N	378	55453	\N	47.214843999999999	Ростовская область, город Ростов-на-Дону, Советский район, Быковского, 5		0101000020E6100000D925AAB706D24340F4DE1802809B4740
76676	2	23	\N	378	55464	\N	47.239075999999997	Ростовская область, город Ростов-на-Дону, Пролетарский район, Буйнакская, 12		0101000020E6100000D461855B3EE2434016A1D80A9A9E4740
76879	2	23	\N	378	5632	\N	47.238776999999999	Ростовская область, город Ростов-на-Дону, Октябрьский район, Буденновский, 100	Россия, Ростовская область, Ростов-на-Дону, Буденновский проспект, 100	0101000020E6100000C687D9CBB6D94340BC04A73E909E4740
76870	2	23	\N	378	5632	\N	47.227725999999997	Ростовская область, город Ростов-на-Дону, Октябрьский район, Буденновский, 64	Россия, Ростовская область, Ростов-на-Дону, Буденновский проспект, 64	0101000020E610000066BE839F38DA434075392520269D4740
76855	2	23	\N	378	5632	\N	47.222909999999999	Ростовская область, город Ростов-на-Дону, Ленинский район, пр. Буденновский, д. 39	Россия, Ростовская область, Ростов-на-Дону, Буденновский проспект, 39-41	0101000020E610000052F17F4754DA4340C6F99B50889C4740
76635	2	23	\N	378	55387	\N	47.267119999999998	Ростовская область, город Ростов-на-Дону, Первомайский район, Брестская, 1/79		0101000020E6100000C1E3DBBB06E54340C30DF8FC30A24740
76580	2	23	\N	378	55379	\N	47.280817205386803	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Борко, 3/1	Россия, Ростовская область, Ростов-на-Дону, улица Борко, 3к1	0101000020E610000081EA1F4432DA43409694BBCFF1A34740
76856	2	23	\N	378	55422	\N	47.219892999999999	Ростовская область, город Ростов-на-Дону, Ленинский район, ул. Б.Садовая, д. 33		0101000020E6100000AA2C0ABB28DA434046CF2D74259C4740
76833	2	23	\N	378	55422	\N	47.226134999999999	Ростовская область, город Ростов-на-Дону, Кировский район, Большая Садовая, 170		0101000020E6100000E529ABE97ADE434090BDDEFDF19C4740
76815	2	23	\N	378	55422	\N	47.222560999999999	Ростовская область, город Ростов-на-Дону, Кировский район, Большая Садовая, 69		0101000020E61000004A42226DE3DB4340BA2EFCE07C9C4740
76600	2	23	\N	378	55350	\N	47.300018617303998	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Беляева, 24/1		0101000020E6100000B70C384BC9DC4340DD96C80567A64740
76622	2	23	\N	378	2682	\N	47.269877999999999	Ростовская область, город Ростов-на-Дону, Первомайский район, Беломорский, 16	Россия, Ростовская область, Ростов-на-Дону, Беломорский переулок, 16	0101000020E61000007EAB75E272E0434077F4BF5C8BA24740
76923	2	23	\N	378	55395	\N	47.214880000000001	Ростовская область, город Ростов-на-Дону, Советский район, Сладкова, 85		0101000020E6100000E8DEC325C7D1434041481630819B4740
76804	2	23	\N	378	55472	\N	47.203733	Ростовская область, город Ростов-на-Дону, Железнодорожный район, Амбулаторная, 95		0101000020E6100000AA7D3A1E33D84340D80E46EC139A4740
76899	2	23	\N	378	6119	\N	47.268000000000001	Ростовская область, город Ростов-на-Дону, Октябрьский район, Авиамоторный, 13	Россия, Ростовская область, Ростов-на-Дону, Авиамоторный переулок, 13	0101000020E61000009468C9E369D54340FCA9F1D24DA24740
77537	2	23	\N	54821	55232	\N	47.785890999999999	Ростовская область, город Новошахтинск, Рабоче-Крестьянская, 19		0101000020E61000002BD9B11188F34340419C871398E44740
76705	2	23	\N	378	3229	\N	47.238971999999997	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 65/5	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 65к5	0101000020E61000000DE198654FE8434071546EA2969E4740
76704	2	23	\N	378	3229	\N	47.238556000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 312	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 312	0101000020E6100000B77BB94F8EEA4340DE21C500899E4740
76700	2	23	\N	378	3229	\N	47.238202000000001	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 73	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 73	0101000020E61000007B9FAA4203E94340C0EB33677D9E4740
76699	2	23	\N	378	3229	\N	47.241174999999998	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 65/12		0101000020E6100000ED2B0FD253E8434070CE88D2DE9E4740
76698	2	23	\N	378	3229	\N	47.237425000000002	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 63	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 63	0101000020E61000006E179AEB34E843405C2041F1639E4740
76697	2	23	\N	378	3229	\N	47.238556000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 43б	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 43б	0101000020E6100000DD99098673E74340DE21C500899E4740
76696	2	23	\N	378	3229	\N	47.236262000000004	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 27а	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 27а	0101000020E6100000CA5356D3F5E64340CFA44DD53D9E4740
76694	2	23	\N	378	3229	\N	47.240330999999998	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 81	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 81	0101000020E6100000070951BEA0E94340849B8C2AC39E4740
76693	2	23	\N	378	3229	\N	47.241328000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 87/4	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 87к4	0101000020E6100000DEAE97A608EA4340F7CDFDD5E39E4740
76686	2	23	\N	378	3229	\N	47.241328000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект  40-летия Победы, 87/4	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 87к4	0101000020E6100000DEAE97A608EA4340F7CDFDD5E39E4740
76677	2	23	\N	378	3229	\N	47.237454999999997	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 306	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 306	0101000020E6100000689599D2FAE94340C6A2E9EC649E4740
76662	2	23	\N	378	3229	\N	47.241089000000002	Ростовская область, город Ростов-на-Дону, Пролетарский район, проспект 40-летия Победы, 95	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 95	0101000020E6100000E63FA4DFBEEA434072361D01DC9E4740
77695	2	23	\N	378	55315	\N	47.225732000000001	Ростовская область, город Ростов-на-Дону, Советский район, 339 Стрелковой дивизии, 21/3		0101000020E6100000BA6B09F9A0CF434091D442C9E49C4740
76938	2	23	\N	378	55315	\N	47.225701000000001	Ростовская область, город Ростов-на-Дону, Советский район, 339 Стрелковой дивизии, 15		0101000020E6100000E4654D2CF0CF434056D636C5E39C4740
76943	2	23	\N	378	55334	\N	47.224964202069401	Ростовская область, город Ростов-на-Дону, Советский район, 339 Стрелковой Дивизии, 21/3	Россия, Ростовская область, Ростов-на-Дону, улица 339-й Стрелковой Дивизии	0101000020E6100000683F524486CF43408063CF9ECB9C4740
76672	2	23	\N	378	55418	\N	47.231594000000001	Ростовская область, город Ростов-на-Дону, Пролетарский район, 31-я линия, 4		0101000020E6100000E97E4E417EE2434094F947DFA49D4740
76669	2	23	\N	378	55329	\N	47.237340025690301	Ростовская область, город Ростов-на-Дону, Пролетарский район, 28-я линия, 55/56а	Россия, Ростовская область, Ростов-на-Дону, улица 28-я Линия	0101000020E6100000D88349F1F1E143402E043928619E4740
76670	2	23	\N	378	55382	\N	47.233386000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, 24-я линия, 2/5		0101000020E6100000E5D4CE30B5E1434011ACAA97DF9D4740
76685	2	23	\N	378	55445	\N	47.225082999999998	Ростовская область, город Ростов-на-Дону, Пролетарский район, 23-я  линия, 43		0101000020E61000007E1AF7E637E243405AF10D85CF9C4740
76914	2	23	\N	378	55368	\N	47.205422930964801	Ростовская область, город Ростов-на-Дону, Советский район, 2-я Краснодарская, 68А	Россия, Ростовская область, Ростов-на-Дону, улица 2-я Краснодарская	0101000020E6100000F7729F1C05D24340516C054D4B9A4740
76913	2	23	\N	378	55368	\N	47.203831000000001	Ростовская область, город Ростов-на-Дону, Советский район, 2-я Краснодарская, 80/13		0101000020E6100000520DFB3DB1D043409B745B22179A4740
76912	2	23	\N	378	55368	\N	47.204033000000003	Ростовская область, город Ростов-на-Дону, Советский район, 2 Краснодарская, 82		0101000020E61000007E8E8F1667D043400327DBC01D9A4740
76911	2	23	\N	378	55368	\N	47.204675999999999	Ростовская область, город Ростов-на-Дону, Советский район, 2-я Краснодарская, 94		0101000020E61000001A355F251FCF43405723BBD2329A4740
76910	2	23	\N	378	55368	\N	47.202727416428203	Ростовская область, город Ростов-на-Дону, Советский район, 2 Краснодарская, 149/1	Россия, Ростовская область, Ростов-на-Дону, улица 2-я Краснодарская, 149к1	0101000020E61000006552431B80CF4340138255F5F2994740
46809	2	20	251	1488	21630	\N	44.861246999999999	село Коноково, Донская, 10, телефон: 67251		0101000020E6100000E415889E94A94440996379573D6E4640
76706	2	23	\N	378	40655	\N	47.197955489976202	Ростовская область, город Ростов-на-Дону, Железнодорожный район, 2-я Володарская, 78	Россия, Ростовская область, Ростов-на-Дону, улица 2-я Володарского	0101000020E6100000C16ED8B628D34340338AE59656994740
76894	2	23	\N	378	40746	\N	47.260912293748497	Ростовская область, город Ростов-на-Дону, Октябрьский район, 2-ой Пятилетки, 10	Россия, Ростовская область, Ростов-на-Дону, улица 2-й Пятилетки, 10к1	0101000020E610000024F0879FFFD8434025917D9065A14740
76668	2	23	\N	378	55442	\N	47.230645000000003	Ростовская область, город Ростов-на-Дону, Пролетарский район, 1-я майская, 34		0101000020E6100000ECD973999AE0434033FE7DC6859D4740
76801	2	23	\N	378	55473	\N	47.201407000000003	Ростовская область, город Ростов-на-Дону, Железнодорожный район, 1-я Круговая, 91		0101000020E61000006571FF91E9D44340BE175FB4C7994740
76638	2	23	\N	378	55244	\N	47.258132651633602	Ростовская область, город Ростов-на-Дону, Первомайский район, Урожная, 4/82		0101000020E6100000FF3C0D1824E543405A828C800AA14740
76906	2	23	\N	378	55370	\N	47.256465663289198	Ростовская область, город Ростов-на-Дону, Октябрьский район, Таганрогская, 118/2	Россия, Ростовская область, Ростов-на-Дону, улица Таганрогская, 118к2	0101000020E6100000C2340C1F11D343409A44BDE0D3A04740
76823	2	23	\N	378	55441	\N	47.218969000000001	Ростовская область, город Ростов-на-Дону, Кировский район, Седова, 8		0101000020E61000001DCA501553DD43403EEB1A2D079C4740
76607	2	23	\N	378	55367	\N	47.300758000000002	Ростовская область, город Ростов-на-Дону, Первомайский район, Миронова, 12г		0101000020E6100000698EACFC32E043405401F73C7FA64740
76816	2	23	\N	378	55456	\N	47.226349999999996	Ростовская область, город Ростов-на-Дону, Кировский район, Максима Горького, 108		0101000020E6100000B70A62A06BDB43408CB96B09F99C4740
76605	2	23	\N	378	55251	\N	47.288877999999997	Ростовская область, город Ростов-на-Дону, Первомайский район, адрес помещения для голосования: Думенко, 3А, адрес УИК: Лелюшенко, 3/4		0101000020E6100000779E78CE16E4434056444DF4F9A44740
76576	2	23	\N	378	55380	\N	47.280774311527601	Ростовская область, город Ростов-на-Дону, Ворошиловский район, Волкова, 6/3		0101000020E61000008FA67A32FFDA434097C80567F0A34740
76632	2	23	\N	378	55414	\N	47.274524	Ростовская область, город Ростов-на-Дону, Первомайский район, Волжская, 19		0101000020E61000006D7022FAB5E34340CAFB389A23A34740
76829	2	23	\N	378	55410	\N	47.224783000000002	Ростовская область, город Ростов-на-Дону, Кировский район, Большая Садовая, 105		0101000020E61000006729594E42DD434030D978B0C59C4740
76924	2	23	\N	378	55386	\N	47.227637453520202	Ростовская область, город Ростов-на-Дону, Советский район, 339 Стрелковой Дивизии, 25/3	Россия, Ростовская область, Ростов-на-Дону, улица 339-й Стрелковой Дивизии, 25к3	0101000020E61000001DE736E15ECF4340062E8F35239D4740
75922	2	23	\N	56611	55108	\N	46.70561	Ростовская область, Пролетарский район, город Пролетарск, пер.Красный, д.31		0101000020E6100000D4282499D5DB444083DDB06D515A4740
75919	2	23	\N	56611	55110	\N	46.70561	Ростовская область, Пролетарский район, город Пролетарск, ул.Пионерская, д.200		0101000020E6100000D4282499D5DB444083DDB06D515A4740
75921	2	23	\N	56611	55107	\N	46.706200397424801	Ростовская область, Пролетарский район, город Пролетарск, ул.Думенко, д.139	Россия, Ростовская область, Пролетарский район, Пролетарск	0101000020E610000072E1404816DC4440B537F8C2645A4740
75918	2	23	\N	56611	55107	\N	46.701995677532501	Ростовская область, Пролетарский район, город Пролетарск, ул.Думенко, д.162	Россия, Ростовская область, Пролетарский район, Пролетарск	0101000020E61000005BD07B6308DC44401FF64201DB594740
75924	2	23	\N	56611	55119	\N	46.70561	Ростовская область, Пролетарский район, город Пролетарск, ул.Дорожная, д.5		0101000020E6100000D4282499D5DB444083DDB06D515A4740
77530	2	23	\N	54821	40562	\N	47.785890999999999	Ростовская область, город Новошахтинск, Энергетическая, 6		0101000020E61000002BD9B11188F34340419C871398E44740
77550	2	23	\N	54821	40947	\N	47.785890999999999	Ростовская область, город Новошахтинск, Энгельса, 8		0101000020E61000002BD9B11188F34340419C871398E44740
77549	2	23	\N	54821	40947	\N	47.785890999999999	Ростовская область, город Новошахтинск, Энгельса, 2		0101000020E61000002BD9B11188F34340419C871398E44740
77556	2	23	\N	54821	40948	\N	47.785890999999999	Ростовская область, город Новошахтинск, Щербакова, 21		0101000020E61000002BD9B11188F34340419C871398E44740
77520	2	23	\N	54821	55238	\N	47.785890999999999	Ростовская область, город Новошахтинск, Школьная, 7		0101000020E61000002BD9B11188F34340419C871398E44740
77528	2	23	\N	54821	40204	\N	47.772425666925699	Ростовская область, город Новошахтинск, Харьковская, 84	Россия, Ростовская область, М19 главные шоссе	0101000020E6100000CE39782634F74340414AECDADEE24740
77527	2	23	\N	54821	40204	\N	47.787047823267002	Ростовская область, город Новошахтинск, Харьковская, 18	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E6100000DEB06D5166F34340EC3026FDBDE44740
77535	2	23	\N	54821	40335	\N	47.7507089782397	Ростовская область, город Новошахтинск, Союзная, 1		0101000020E61000001763601DC7F743400CE8853B17E04740
77522	2	23	\N	54821	40942	\N	47.785890999999999	Ростовская область, город Новошахтинск, Советской Конституции, 36		0101000020E61000002BD9B11188F34340419C871398E44740
77521	2	23	\N	54821	40942	\N	47.788898800212898	Ростовская область, город Новошахтинск, Советской Конституции, 52	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E6100000F437A11001F343406E6C76A4FAE44740
77518	2	23	\N	54821	39836	\N	47.785890999999999	Ростовская область, город Новошахтинск, Советская, 1/18-б		0101000020E61000002BD9B11188F34340419C871398E44740
77532	2	23	\N	54821	39858	\N	47.788436062193803	Ростовская область, город Новошахтинск, Радио, 24	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E610000066A4DE5339F34340997E8978EBE44740
77507	2	23	\N	54821	39834	\N	47.785890999999999	Ростовская область, город Новошахтинск, Рабочая, 2		0101000020E61000002BD9B11188F34340419C871398E44740
77523	2	23	\N	54821	40186	\N	47.785890999999999	Ростовская область, город Новошахтинск, Просвещения, 28		0101000020E61000002BD9B11188F34340419C871398E44740
77568	2	23	\N	54821	55264	\N	47.770841713233402	Ростовская область, город Новошахтинск, Пирогова, 26	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E6100000603AADDBA0F643400E315EF3AAE24740
77559	2	23	\N	54821	55595	\N	47.785890999999999	Ростовская область, город Новошахтинск, Перова, 1а		0101000020E61000002BD9B11188F34340419C871398E44740
77540	2	23	\N	54821	55794	\N	47.785890999999999	Ростовская область, город Новошахтинск, ул. Назаренко, 1Б/14		0101000020E61000002BD9B11188F34340419C871398E44740
77536	2	23	\N	54821	55231	\N	47.785890999999999	Ростовская область, город Новошахтинск, Молодогвардейцев, 6		0101000020E61000002BD9B11188F34340419C871398E44740
77564	2	23	\N	54821	41173	\N	47.785890999999999	Ростовская область, город Новошахтинск, Молдавская, 3		0101000020E61000002BD9B11188F34340419C871398E44740
77567	2	23	\N	54821	40949	\N	47.7876262606867	Ростовская область, город Новошахтинск, Моисеенко, 2/1а	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E6100000E08096AE60F343405ABDC3EDD0E44740
77524	2	23	\N	54821	40944	\N	47.785890999999999	Ростовская область, город Новошахтинск, Мичурина, 52а/2б		0101000020E61000002BD9B11188F34340419C871398E44740
77542	2	23	\N	54821	55800	\N	47.7608631356808	Ростовская область, город Новошахтинск, Маяковского, 58а	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E61000007A89B14CBFF8434044DE72F563E14740
77526	2	23	\N	54821	40189	\N	47.785890999999999	Ростовская область, город Новошахтинск, Малосадовая, 6		0101000020E61000002BD9B11188F34340419C871398E44740
77558	2	23	\N	54821	39837	\N	47.785890999999999	Ростовская область, город Новошахтинск, Магистральная, 8а		0101000020E61000002BD9B11188F34340419C871398E44740
77534	2	23	\N	54821	40332	\N	47.785890999999999	Ростовская область, город Новошахтинск, Ленинградская, 40		0101000020E61000002BD9B11188F34340419C871398E44740
77533	2	23	\N	54821	40332	\N	47.785890999999999	Ростовская область, город Новошахтинск, Ленинградская, 28		0101000020E61000002BD9B11188F34340419C871398E44740
77516	2	23	\N	54821	40940	\N	47.785890999999999	Ростовская область, город Новошахтинск, Ленина, 54		0101000020E61000002BD9B11188F34340419C871398E44740
77565	2	23	\N	54821	40337	\N	47.785890999999999	Ростовская область, город Новошахтинск, Курская, 21б		0101000020E61000002BD9B11188F34340419C871398E44740
77544	2	23	\N	54821	39861	\N	47.785890999999999	Ростовская область, город Новошахтинск, Краснофлотская, 22/8		0101000020E61000002BD9B11188F34340419C871398E44740
77562	2	23	\N	54821	39934	\N	47.785890999999999	Ростовская область, город Новошахтинск, Котельникова, 7а/20/13		0101000020E61000002BD9B11188F34340419C871398E44740
77566	2	23	\N	54821	39789	\N	47.785890999999999	Ростовская область, город Новошахтинск, Королева, 2б		0101000020E61000002BD9B11188F34340419C871398E44740
77538	2	23	\N	54821	39838	\N	47.785890999999999	Ростовская область, город Новошахтинск, Киевская, 15		0101000020E61000002BD9B11188F34340419C871398E44740
77553	2	23	\N	54821	55814	\N	47.785890999999999	Ростовская область, город Новошахтинск, Казахстанская, 7		0101000020E61000002BD9B11188F34340419C871398E44740
77552	2	23	\N	54821	55813	\N	47.785890999999999	Ростовская область, город Новошахтинск, Грессовская, 21/17/1		0101000020E61000002BD9B11188F34340419C871398E44740
77545	2	23	\N	54821	40191	\N	47.785890999999999	Ростовская область, город Новошахтинск, Грессовсая, 21/17/1		0101000020E61000002BD9B11188F34340419C871398E44740
77529	2	23	\N	54821	41172	\N	47.785890999999999	Ростовская область, город Новошахтинск, Горького, 13		0101000020E61000002BD9B11188F34340419C871398E44740
77519	2	23	\N	54821	55228	\N	47.785890999999999	Ростовская область, город Новошахтинск, Горняцкая, 24		0101000020E61000002BD9B11188F34340419C871398E44740
77561	2	23	\N	54821	55230	\N	47.785890999999999	Ростовская область, город Новошахтинск, Восточная, 8г		0101000020E61000002BD9B11188F34340419C871398E44740
77531	2	23	\N	54821	39862	\N	47.785890999999999	Ростовская область, город Новошахтинск, Вокзальная, 2а		0101000020E61000002BD9B11188F34340419C871398E44740
77554	2	23	\N	54821	55598	\N	47.785890999999999	Ростовская область, город Новошахтинск, Войкова, 66а		0101000020E61000002BD9B11188F34340419C871398E44740
77525	2	23	\N	54821	40643	\N	47.785890999999999	Ростовская область, город Новошахтинск, 60 лет Октября, 20		0101000020E61000002BD9B11188F34340419C871398E44740
77560	2	23	\N	54821	56299	\N	47.785890999999999	Ростовская область, город Новошахтинск, Поленова, 1		0101000020E61000002BD9B11188F34340419C871398E44740
75315	2	23	\N	54826	55100	\N	47.417732249743501	Ростовская область, город Новочеркасск, ул. Театральная, д. 1	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E6100000EE7C3F355E0E4440103FFF3D78B54740
75282	2	23	\N	54826	55093	\N	47.414427688625999	Ростовская область, город Новочеркасск, Платовский пр-т, д. 37		0101000020E6100000F46BEBA7FF0E4440FA4509FA0BB54740
75279	2	23	\N	54826	55106	\N	47.419829437507701	Ростовская область, город Новочеркасск, Платовский пр-т, д. 37 лит. С		0101000020E6100000D47FD6FCF80D4440C974E8F4BCB54740
75269	2	23	\N	54826	55719	\N	47.448163999999998	Ростовская область,город Новочеркасск, ул. Панфилова, д. 10		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75294	2	23	\N	54826	55145	\N	47.448163999999998	Ростовская область, город Новочеркасск, ГОУ СПО НМК (Машиностроительный колледж), ул. Михайловская, 166		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75324	2	23	\N	54826	55151	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Макаренко, д. 14		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75274	2	23	\N	54826	39892	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Крылова, д. 6		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
76078	2	23	\N	54808	40519	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Лиховской, Победы, 7		0101000020E6100000D993C0E61C1C444017F3734353224840
77642	2	23	\N	54826	55697	\N	47.449117334388497	Ростовская область, город Новочеркасск, Интернатный пер, д. 7	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E6100000BE840A0E2F104440F08975AA7CB94740
75277	2	23	\N	54826	55166	\N	47.449466661836901	Ростовская область, город Новочеркасск, ул. Дубовского, д. 3	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E6100000E868554B3A104440CCD0782288B94740
75286	2	23	\N	54826	55143	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Дворцовая, д. 12		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75310	2	23	\N	54826	39898	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Гвардейская, д. 24		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75275	2	23	\N	54826	39895	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Буденновская, д. 21		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
77644	2	23	\N	54826	39868	\N	47.448163999999998	Ростовская область, город Новочеркасск, Баклановский пр-т, д. 79		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75270	2	23	\N	54826	39868	\N	47.448513283500503	Ростовская область, город Новочеркасск, Баклановский пр-т, д. 118	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E610000065C405A051104440596ABDDF68B94740
75266	2	23	\N	54826	55124	\N	47.414988438715	Ростовская область, город Новочеркасск, Баклановский пр-т, д. 150	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E6100000056EDDCD530D4440C11DA8531EB54740
75265	2	23	\N	54826	55124	\N	47.418250865520797	Ростовская область, город Новочеркасск, Баклановский пр-т, д. 166	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E61000007A50508A560E44407842AF3F89B54740
75288	2	23	\N	54826	39896	\N	47.448163999999998	"Ростовская область, город Новочеркасск, НГОО ""СВА"", ул. Б.Хмельницкого, д. 38"		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75283	2	23	\N	54826	55122	\N	47.449764241645603	Ростовская область, город Новочеркасск, ул. Александровская, д. 62	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E6100000C154336B291044408675E3DD91B94740
76315	2	23	\N	56614	55121	\N	48.358542538273397	Ростовская область, Морозовский район, город Морозовск, улица Руднева, 98		0101000020E6100000A52DAEF199EA4440D89AADBCE42D4840
76314	2	23	\N	56614	55121	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, ул. Руднева, д.98 (здание школы №4)		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76318	2	23	\N	56614	55150	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Ленина, 157		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76326	2	23	\N	56614	55184	\N	48.357881565083503	Ростовская область, Морозовский район, город Морозовск, улица Ворошилова, 211	Россия, Ростовская область, Морозовский район, Морозовск	0101000020E61000001B2C9CA4F9E94440DDE9CE13CF2D4840
76097	2	23	\N	56613	55120	\N	48.9249610495919	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Черноморская, 52		0101000020E610000050FD834886324440A9893E1F65764840
75482	2	23	\N	56613	55153	\N	48.9318607520634	Ростовская область, Миллеровский район, Миллеровское городское поселение, III Интернационала, 21		0101000020E61000003D4679E6E53244407CB5A33847774840
77448	2	23	\N	56821	56203	\N	47.885360088930803	Ростовская область, Красносулинский район, город Красный Сулин, Коммунистическая, 1-а	Россия, Ростовская область, Красносулинский район, Красный Сулин	0101000020E610000071E2AB1DC5074440E197FA7953F14740
77652	2	23	\N	56612	55141	\N	47.581155711280502	Ростовская область, Константиновский район, город Константиновск, ул. Коммунистическая, д. 224	Россия, Ростовская область, Константиновский район, Константиновск	0101000020E6100000B45A608F898C4440E5EFDE5163CA4740
75492	2	23	\N	56612	55154	\N	47.579820100414402	Ростовская область, Константиновский район, город Константиновск, ул. Донская, д. 1	Россия, Ростовская область, Константиновский район, Константиновск	0101000020E61000004B732B84D58C44408AC8B08A37CA4740
75487	2	23	\N	56612	55117	\N	47.582041449083697	Ростовская область, Константиновский район, город Константиновск, ул. 25 Октября, д. 57	Россия, Ростовская область, Константиновский район, Константиновск	0101000020E610000061FA5E43708C44402FF7C95180CA4740
76051	2	23	\N	54808	41123	\N	48.268166000000001	"Ростовская область, город Каменск-Шахтинский, пер.Придорожный, 83 (спортзал ""Дружба"")"		0101000020E6100000D993C0E61C1C444017F3734353224840
76081	2	23	\N	54808	55149	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский,  микрорайон Лиховской, Советский, Лесозащитная станция, пер.Советский, 43		0101000020E6100000D993C0E61C1C444017F3734353224840
76066	2	23	\N	54808	40070	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Ученическая, 7		0101000020E6100000D993C0E61C1C444017F3734353224840
76043	2	23	\N	54808	39970	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, ул.Танкистов, 28		0101000020E6100000D993C0E61C1C444017F3734353224840
76073	2	23	\N	54808	41140	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Заводской, Строителей, 2		0101000020E6100000D993C0E61C1C444017F3734353224840
76076	2	23	\N	54808	55148	\N	48.266974200172001	Ростовская область, город Каменск-Шахтинский, микрорайон Лиховской, Советская, 38	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E6100000A148F7730A1C4440EF703B342C224840
76044	2	23	\N	54808	39973	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Просторный, 1		0101000020E6100000D993C0E61C1C444017F3734353224840
76068	2	23	\N	54808	40072	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Пивоварова, 16		0101000020E6100000D993C0E61C1C444017F3734353224840
76396	2	23	\N	54808	40092	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Заводской, Парковая, 14		0101000020E6100000D993C0E61C1C444017F3734353224840
76040	2	23	\N	54808	39759	\N	48.267375334746198	Ростовская область, город Каменск-Шахтинский, ул.Парк Культуры, 8	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E61000007A34D593F91B44404E62105839224840
76042	2	23	\N	54808	40508	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, ул.Островского, 57		0101000020E6100000D993C0E61C1C444017F3734353224840
76063	2	23	\N	54808	41124	\N	48.268107525899602	Ростовская область, город Каменск-Шахтинский, Освобождения, 46-а	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E6100000B325AB22DC1C4440E2E5E95C51224840
76046	2	23	\N	54808	39760	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Мусина, 80		0101000020E6100000D993C0E61C1C444017F3734353224840
76039	2	23	\N	54808	41118	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Мира, 20		0101000020E6100000D993C0E61C1C444017F3734353224840
76069	2	23	\N	54808	40238	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Микрорайон 60-лет Октября, 7		0101000020E6100000D993C0E61C1C444017F3734353224840
76074	2	23	\N	54808	40239	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Заводской, Луначарского, 1		0101000020E6100000D993C0E61C1C444017F3734353224840
76047	2	23	\N	54808	40509	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Ленина, 25		0101000020E6100000D993C0E61C1C444017F3734353224840
76059	2	23	\N	54808	40488	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Крупской, 82		0101000020E6100000D993C0E61C1C444017F3734353224840
76056	2	23	\N	54808	40488	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Крупской, 48		0101000020E6100000D993C0E61C1C444017F3734353224840
76064	2	23	\N	54808	40236	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Красная, 20-а		0101000020E6100000D993C0E61C1C444017F3734353224840
76070	2	23	\N	54808	40074	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Котовского, 15		0101000020E6100000D993C0E61C1C444017F3734353224840
76049	2	23	\N	54808	41120	\N	48.266617614355901	Ростовская область, город Каменск-Шахтинский, Коммунистический, 72	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E61000008733BF9A031C44403143E38920224840
76055	2	23	\N	54808	40066	\N	48.269941203202798	Ростовская область, город Каменск-Шахтинский, Кирова, 98	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E6100000B325AB22DC1C4440BE6C3B6D8D224840
76045	2	23	\N	54808	40066	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Кирова, 4		0101000020E6100000D993C0E61C1C444017F3734353224840
76057	2	23	\N	54808	40068	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, К.Маркса, 58		0101000020E6100000D993C0E61C1C444017F3734353224840
76053	2	23	\N	54808	40068	\N	48.320341394343501	Ростовская область, город Каменск-Шахтинский, К.Маркса, 62		0101000020E6100000E09D7C7A6C234440B24813EF00294840
76392	2	23	\N	54808	39771	\N	48.266789529456297	Ростовская область, город Каменск-Шахтинский, Западная, 2	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E610000050508A56EE1B44402E73BA2C26224840
76061	2	23	\N	54808	40235	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Желябова, 107		0101000020E6100000D993C0E61C1C444017F3734353224840
76071	2	23	\N	54808	55851	\N	48.267419879847303	Ростовская область, город Каменск-Шахтинский, микрорайон Шахта-17/32, ул.Дружбы, 1	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E61000002504ABEAE51B4440EE258DD13A224840
76083	2	23	\N	54808	41129	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Героев Пионеров, 81		0101000020E6100000D993C0E61C1C444017F3734353224840
76077	2	23	\N	54808	40241	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Лиховской, Гагарина, 141		0101000020E6100000D993C0E61C1C444017F3734353224840
76075	2	23	\N	54808	40241	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Лиховской, Гагарина, 16		0101000020E6100000D993C0E61C1C444017F3734353224840
76062	2	23	\N	54808	40241	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Гагарина, 93		0101000020E6100000D993C0E61C1C444017F3734353224840
77626	2	23	\N	54808	40338	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Ворошилова, 143		0101000020E6100000D993C0E61C1C444017F3734353224840
76050	2	23	\N	54808	40067	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Володарского, 74		0101000020E6100000D993C0E61C1C444017F3734353224840
76048	2	23	\N	54808	40067	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Володарского, 43		0101000020E6100000D993C0E61C1C444017F3734353224840
76082	2	23	\N	54808	39981	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Лиховской, Вокзальная, 114		0101000020E6100000D993C0E61C1C444017F3734353224840
76072	2	23	\N	54808	39984	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, микрорайон Заводской, Больничная, 10		0101000020E6100000D993C0E61C1C444017F3734353224840
76060	2	23	\N	54808	39763	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Башкевича, 106-а		0101000020E6100000D993C0E61C1C444017F3734353224840
76058	2	23	\N	54808	39763	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Башкевича, 84		0101000020E6100000D993C0E61C1C444017F3734353224840
76054	2	23	\N	54808	39972	\N	48.268166000000001	Ростовская область, город Каменск-Шахтинский, Астаховский, 96		0101000020E6100000D993C0E61C1C444017F3734353224840
45559	2	20	433	5079	21459	\N	44.951127	село Мерчанское, Мира, 6, телефон: 6-57-67		0101000020E6100000AD86C43D96104340DAAB8F87BE794640
75478	2	23	\N	56615	55173	\N	46.850883604125897	Ростовская область, Зерноградский район, г. Зерноград, Мира, 1	Россия, Ростовская область, Зерноградский район, Зерноград	0101000020E6100000FF06EDD5C7274440475854C4E96C4740
75470	2	23	\N	56615	55175	\N	46.845303997367097	Ростовская область, Зерноградский район, г. Зерноград, Колодина, 5		0101000020E610000014E8137992264440C896E5EB326C4740
75468	2	23	\N	56615	55155	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Калинина, 49		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
77389	2	23	\N	54823	40330	\N	48.025255000000001	Ростовская область, город Зверево, Школьная, 7		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77386	2	23	\N	54823	39824	\N	48.025255000000001	Ростовская область, город Зверево, Строительная, 19		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77384	2	23	\N	54823	40177	\N	48.025255000000001	Ростовская область, город Зверево, Советская, 120,а		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77392	2	23	\N	54823	40179	\N	48.025255000000001	Ростовская область, город Зверево, Рижская, 11		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77390	2	23	\N	54823	40179	\N	48.025255000000001	Ростовская область, город Зверево, Рижская, 7		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77388	2	23	\N	54823	40178	\N	48.025255000000001	Ростовская область, город Зверево, Осташенко, 10		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77636	2	23	\N	54823	55213	\N	48.025255000000001	Ростовская область, город Зверево, Обухова, 7		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77387	2	23	\N	54823	55213	\N	48.025255000000001	Ростовская область, город Зверево, Обухова, 45		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77391	2	23	\N	54823	40853	\N	48.025255000000001	Ростовская область, город Зверево, Ивановская, 11		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77385	2	23	\N	54823	40852	\N	48.025255000000001	Ростовская область, город Зверево, Горького, 65,а		0101000020E61000005D177E703E0F4440BE874B8E3B034840
77748	2	23	\N	54811	40501	\N	48.309759	Ростовская область, город Донецк, проспект Мира, 35		0101000020E61000000612143FC6FA43402252D32EA6274840
76031	2	23	\N	54811	40501	\N	48.309759	Ростовская область, город Донецк, проспект Мира, 21		0101000020E61000000612143FC6FA43402252D32EA6274840
76028	2	23	\N	54811	40501	\N	48.309759	Ростовская область, город Донецк, проспект Мира, 57		0101000020E61000000612143FC6FA43402252D32EA6274840
76013	2	23	\N	54811	40501	\N	48.311365063427999	Ростовская область, город Донецк, проспект Мира, 41	Россия, Ростовская область, городской округ Донецк, Донецк	0101000020E6100000A48CB80034FA43403D0FEECEDA274840
76021	2	23	\N	54811	55613	\N	48.309759	Ростовская область, город Донецк, переулок Октябрьский, 53		0101000020E61000000612143FC6FA43402252D32EA6274840
77750	2	23	\N	54811	39843	\N	48.309759	Ростовская область, город Донецк, переулок Молодежный, 14		0101000020E61000000612143FC6FA43402252D32EA6274840
76030	2	23	\N	54811	40500	\N	48.309759	Ростовская область, город Донецк, переулок Гагарина, 70		0101000020E61000000612143FC6FA43402252D32EA6274840
76029	2	23	\N	54811	40496	\N	48.309759	Ростовская область, город Донецк, улица Экскаваторная, 1		0101000020E61000000612143FC6FA43402252D32EA6274840
76033	2	23	\N	54811	40065	\N	48.309759	Ростовская область, город Донецк, улица Шевченко, 6		0101000020E61000000612143FC6FA43402252D32EA6274840
76036	2	23	\N	54811	39695	\N	48.308957403879198	Ростовская область, город Донецк, улица Цветкова, 20а	Россия, Ростовская область, городской округ Донецк, Донецк	0101000020E6100000A532C51C04FB4340656F29E78B274840
77751	2	23	\N	54811	40039	\N	48.309759	Ростовская область, город Донецк, улица Тимирязева, 44		0101000020E61000000612143FC6FA43402252D32EA6274840
76019	2	23	\N	54811	40492	\N	48.309759	Ростовская область, г. Донецк, ул. Советская, 51		0101000020E61000000612143FC6FA43402252D32EA6274840
76038	2	23	\N	54811	39758	\N	48.309759	Ростовская область, город Донецк, улица Пролетарская, 100		0101000020E61000000612143FC6FA43402252D32EA6274840
76037	2	23	\N	54811	55833	\N	48.309759	Ростовская область, город Донецк, Обогатителей, 25		0101000020E61000000612143FC6FA43402252D32EA6274840
76034	2	23	\N	54811	40506	\N	48.309759	Ростовская область, город Донецк, улица Некрасова, 27 б		0101000020E61000000612143FC6FA43402252D32EA6274840
76025	2	23	\N	54811	39967	\N	48.309759	Ростовская область, город Донецк, улица Мичурина, 75		0101000020E61000000612143FC6FA43402252D32EA6274840
76027	2	23	\N	54811	41115	\N	48.309759	Ростовская область, город Донецк, улица Королева, 12		0101000020E61000000612143FC6FA43402252D32EA6274840
76026	2	23	\N	54811	41115	\N	48.312968168063598	Ростовская область, город Донецк, улица Королева, 19	Россия, Ростовская область, городской округ Донецк, Донецк	0101000020E61000001C9947FE60FA4340E658DE550F284840
76024	2	23	\N	54811	55542	\N	48.309759	Ростовская область, город Донецк, Второй Аварийный, 10		0101000020E61000000612143FC6FA43402252D32EA6274840
76020	2	23	\N	54811	40493	\N	48.309759	Ростовская область, город Донецк, улица Братьев Дорошевых, 23-а		0101000020E61000000612143FC6FA43402252D32EA6274840
77752	2	23	\N	54811	39694	\N	48.309759	Ростовская область, город Донецк, 3 микрорайон, 24		0101000020E61000000612143FC6FA43402252D32EA6274840
76023	2	23	\N	54811	39694	\N	48.308330476655101	Ростовская область, город Донецк, 3 микрорайон, д.25	Россия, Ростовская область, городской округ Донецк, Донецк	0101000020E6100000494BE5ED08FB43401630815B77274840
76022	2	23	\N	54811	39694	\N	48.309759	Ростовская область, город Донецк, 3 микрорайон, 10		0101000020E61000000612143FC6FA43402252D32EA6274840
77749	2	23	320	\N	55253	\N	48.328338224205801	Ростовская область, город Донецк, 12 квартал, 17/1	Россия, Ростовская область, городской округ Донецк	0101000020E61000005D86FF7403F943405C04C6FA062A4840
77423	2	23	\N	54824	55136	\N	48.041666999999997	Ростовская область, город Гуково, пер. Волжский д. 1		0101000020E61000008BC1C3B46FFA43404529215855054840
77426	2	23	\N	54824	39848	\N	48.041666999999997	Ростовская область, город Гуково, Щорса, 40		0101000020E61000008BC1C3B46FFA43404529215855054840
14346	1	17	1488	47121	24052	\N	58.092745000000001	д. Волково, Лапшина, 10		0101000020E6100000E50D30F31D1444400BEF7211DF0B4D40
77431	2	23	\N	54824	40967	\N	48.041666999999997	Ростовская область, город Гуково, микрорайон Алмазный, Школьная, 2-а		0101000020E61000008BC1C3B46FFA43404529215855054840
77409	2	23	\N	54824	40863	\N	48.041666999999997	Ростовская область, город Гуково, Шахтерская, 63-а		0101000020E61000008BC1C3B46FFA43404529215855054840
77429	2	23	\N	54824	40042	\N	48.041666999999997	Ростовская область, город Гуково, Чкалова, 32		0101000020E61000008BC1C3B46FFA43404529215855054840
77422	2	23	\N	54824	40356	\N	48.041666999999997	Ростовская область, город Гуково, ул. Трамвайная д.1-а		0101000020E61000008BC1C3B46FFA43404529215855054840
77415	2	23	\N	54824	40199	\N	48.041666999999997	Ростовская область, город Гуково, ул. Степная д. 12		0101000020E61000008BC1C3B46FFA43404529215855054840
77437	2	23	\N	54824	39829	\N	48.041666999999997	Ростовская область, город Гуково, Российская, 42		0101000020E61000008BC1C3B46FFA43404529215855054840
77427	2	23	\N	54824	55524	\N	48.041666999999997	Ростовская область, город Гуково, Розы Люксембург, 2-а		0101000020E61000008BC1C3B46FFA43404529215855054840
77425	2	23	\N	54824	55809	\N	48.041666999999997	Ростовская область, город Гуково, Пушкина, 79		0101000020E61000008BC1C3B46FFA43404529215855054840
77410	2	23	\N	54824	40864	\N	48.041666999999997	Ростовская область, город Гуково, Молодежная, 17		0101000020E61000008BC1C3B46FFA43404529215855054840
77401	2	23	\N	54824	40034	\N	48.041666999999997	Ростовская область, город Гуково, Мира, 13-а		0101000020E61000008BC1C3B46FFA43404529215855054840
77400	2	23	\N	54824	40034	\N	48.041666999999997	Ростовская область, город Гуково, Мира, 28		0101000020E61000008BC1C3B46FFA43404529215855054840
77406	2	23	\N	54824	40259	\N	48.041666999999997	Ростовская область, город Гуково, Милицейская, 1		0101000020E61000008BC1C3B46FFA43404529215855054840
77394	2	23	\N	54824	40858	\N	48.041666999999997	Ростовская область, город Гуково, Льва Толстого, 28		0101000020E61000008BC1C3B46FFA43404529215855054840
77420	2	23	\N	54824	40354	\N	48.041666999999997	Ростовская область, город Гуково, Ленинградская, 2		0101000020E61000008BC1C3B46FFA43404529215855054840
77419	2	23	\N	54824	40351	\N	48.041666999999997	Ростовская область, город Гуково, Кутузова, 30		0101000020E61000008BC1C3B46FFA43404529215855054840
77428	2	23	\N	54824	40041	\N	48.041666999999997	Ростовская область, город Гуково, Куйбышева, 1-а		0101000020E61000008BC1C3B46FFA43404529215855054840
77395	2	23	\N	54824	55223	\N	48.041494849305501	Ростовская область, город Гуково, Крупской, 51		0101000020E610000061FF756EDAFA434048F949B54F054840
77407	2	23	\N	54824	40263	\N	48.041666999999997	Ростовская область, город Гуково, Криничная, 59		0101000020E61000008BC1C3B46FFA43404529215855054840
77414	2	23	\N	54824	40349	\N	48.041666999999997	Ростовская область, город Гуково, Кооперативная, 2		0101000020E61000008BC1C3B46FFA43404529215855054840
77430	2	23	\N	54824	40866	\N	48.058543188069599	Ростовская область, город Гуково, микрорайон Приовражный, Комсомольская, 46	Россия, Ростовская область, городской округ Гуково, Гуково	0101000020E61000006D72F8A413F94340723447567E074840
77413	2	23	\N	54824	40866	\N	48.0570333171583	Ростовская область, город Гуково, Комсомольская, 31		0101000020E610000089096AF816FA434079E57ADB4C074840
77412	2	23	\N	54824	40866	\N	48.041666999999997	Ростовская область, город Гуково, Комсомольская, 40-а		0101000020E61000008BC1C3B46FFA43404529215855054840
77411	2	23	\N	54824	40866	\N	48.058701983217901	Ростовская область, город Гуково, Комсомольская, 75		0101000020E6100000CD3AE3FBE2F84340DA1A118C83074840
77405	2	23	\N	54824	55131	\N	48.041666999999997	Ростовская область, город Гуково, Колодезная, 61		0101000020E61000008BC1C3B46FFA43404529215855054840
77397	2	23	\N	54824	55594	\N	48.0423576591662	Ростовская область, город Гуково, Карла Маркса, 89	Россия, Ростовская область, городской округ Гуково, Гуково	0101000020E61000003D997FF44DFA4340AB5CA8FC6B054840
77398	2	23	\N	54824	39826	\N	48.041666999999997	Ростовская область, город Гуково, Герцена, 115		0101000020E61000008BC1C3B46FFA43404529215855054840
77396	2	23	\N	54824	39826	\N	48.041666999999997	Ростовская область, город Гуково, Герцена, 124		0101000020E61000008BC1C3B46FFA43404529215855054840
77403	2	23	\N	54824	40036	\N	48.041666999999997	Ростовская область, город Гуково, Бургустинская, 17		0101000020E61000008BC1C3B46FFA43404529215855054840
77402	2	23	\N	54824	40036	\N	48.041666999999997	Ростовская область, город Гуково, Бургустинская, 7		0101000020E61000008BC1C3B46FFA43404529215855054840
77399	2	23	\N	54824	39828	\N	48.041666999999997	Ростовская область, город Гуково, Болгарский, 4		0101000020E61000008BC1C3B46FFA43404529215855054840
77432	2	23	\N	54824	40200	\N	48.041666999999997	Ростовская область, город Гуково, микрорайон Алмазный, Ардинцева, 12-а		0101000020E61000008BC1C3B46FFA43404529215855054840
75293	2	23	\N	56617	55172	\N	47.523117777046401	Ростовская область, город Волгодонск, Мира, 47	Россия, Ростовская область, городской округ Волгодонск	0101000020E6100000770FD07D391D454076F9D687F5C24740
75643	2	23	\N	54830	41098	\N	47.534306000000001	Ростовская область, город Волгодонск, пер. Октябрьский, 13		0101000020E61000006D904946CE1445403E07962364C44740
75640	2	23	\N	54830	40121	\N	47.534306000000001	Ростовская область, город Волгодонск, Бульвар Великой Победы, 14		0101000020E61000006D904946CE1445403E07962364C44740
75639	2	23	\N	54830	40121	\N	47.526460660592498	Ростовская область, город Волгодонск, Бульвар Великой Победы,14	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E6100000F96A47718E1445404ACFF41263C34740
75638	2	23	\N	54830	40121	\N	47.534306000000001	Ростовская область, город Волгодонск, Бульвар Великой Победы, 6		0101000020E61000006D904946CE1445403E07962364C44740
75636	2	23	\N	54830	39914	\N	47.534306000000001	Ростовская область, город Волгодонск, Энтузиастов, 7		0101000020E61000006D904946CE1445403E07962364C44740
75642	2	23	\N	54830	55144	\N	47.534306000000001	Ростовская область, город Волгодонск, Черникова, 6		0101000020E61000006D904946CE1445403E07962364C44740
75644	2	23	\N	54830	40102	\N	47.534306000000001	Ростовская область, город Волгодонск, Строителей, 39		0101000020E61000006D904946CE1445403E07962364C44740
75641	2	23	\N	54830	40102	\N	47.534306000000001	Ростовская область, город Волгодонск, Строителей, 37		0101000020E61000006D904946CE1445403E07962364C44740
45107	2	20	1322	45847	21380	\N	45.280495999999999	поселок Водный, ул.Новая, 3, телефон: 44-1-02		0101000020E61000008F8D40BCAE2D43405454FD4AE7A34640
75633	2	23	\N	54830	39912	\N	47.534306000000001	Ростовская область, город Волгодонск, Степная, 193		0101000020E61000006D904946CE1445403E07962364C44740
75626	2	23	\N	54830	40279	\N	47.534306000000001	Ростовская область, город Волгодонск, Советская, 138		0101000020E61000006D904946CE1445403E07962364C44740
75621	2	23	\N	54830	40279	\N	47.534306000000001	Ростовская область, город Волгодонск, Советская, 1		0101000020E61000006D904946CE1445403E07962364C44740
75646	2	23	\N	54830	41095	\N	47.534306000000001	Ростовская область, город Волгодонск, Молодежная, 13-а		0101000020E61000006D904946CE1445403E07962364C44740
75637	2	23	\N	54830	41095	\N	47.530646229937702	Ростовская область, город Волгодонск, Молодежная, 1	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E610000047938B31B014454069E04735ECC34740
75652	2	23	\N	54830	40595	\N	47.527855887714701	Ростовская область, город Волгодонск, Мира, 16	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E61000001DAF40F4A4144540AA7F10C990C34740
75651	2	23	\N	54830	40595	\N	47.535528969430501	Ростовская область, город Волгодонск, Мира, 75	Россия, Ростовская область, городской округ Волгодонск	0101000020E61000005BB1BFEC9E1A4540A087DA368CC44740
75649	2	23	\N	54830	40595	\N	47.534306000000001	Ростовская область, город Волгодонск, Мира, 69		0101000020E61000006D904946CE1445403E07962364C44740
75648	2	23	\N	54830	41104	\N	47.529483605496303	Ростовская область, город Волгодонск, Маршала Кошевого, 20	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E6100000CF86FC3383144540ACE0B721C6C34740
75632	2	23	\N	54830	40589	\N	47.529018548459099	Ростовская область, город Волгодонск, М. Горького, 163	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E6100000AB4203B16C14454037FB03E5B6C34740
75631	2	23	\N	54830	40119	\N	47.5276233524541	Ростовская область, город Волгодонск, ул.Ленина, 115	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E61000001F680586AC14454007CF842689C34740
75629	2	23	\N	54830	40119	\N	47.534306000000001	Ростовская область, город Волгодонск, Ленина, 94		0101000020E61000006D904946CE1445403E07962364C44740
75628	2	23	\N	54830	40119	\N	47.5291994046637	Ростовская область, город Волгодонск, Ленина, 75	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E6100000224F92AE99144540B709F7CABCC34740
75625	2	23	\N	54830	40119	\N	47.529018548459099	Ростовская область, город Волгодонск, Ленина, 73/94	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E61000006BD784B4C614454037FB03E5B6C34740
75624	2	23	\N	54830	40119	\N	47.5107617824209	Ростовская область, город Волгодонск, Ленина, 56	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E61000002E7079AC19154540100533A660C14740
75623	2	23	\N	54830	40119	\N	47.534306000000001	Ростовская область, город Волгодонск, Ленина, 29		0101000020E61000006D904946CE1445403E07962364C44740
75622	2	23	\N	54830	40119	\N	47.511692218046797	Ростовская область, город Волгодонск, Ленина, 28		0101000020E6100000BE9F1A2FDD144540FACF9A1F7FC14740
75645	2	23	\N	54830	41101	\N	47.534306000000001	Ростовская область, город Волгодонск, Курчатова, 20		0101000020E61000006D904946CE1445403E07962364C44740
75634	2	23	\N	54830	41094	\N	47.534306000000001	Ростовская область, город Волгодонск, Кооперативная, 23		0101000020E61000006D904946CE1445403E07962364C44740
75650	2	23	\N	54830	40596	\N	47.534306000000001	Ростовская область, город Волгодонск, ул. К. Маркса, 38		0101000020E61000006D904946CE1445403E07962364C44740
75489	2	23	\N	54830	40596	\N	47.534306000000001	Ростовская область, город Волгодонск, К. Маркса, 4		0101000020E61000006D904946CE1445403E07962364C44740
75630	2	23	\N	54830	40280	\N	47.5318152967671	Ростовская область, г.Волгодонск, ул. Горького,190	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E6100000F96A47718E144540D942908312C44740
75647	2	23	\N	54830	41102	\N	47.534306000000001	Ростовская область, город Волгодонск, Гагарина, 29		0101000020E61000006D904946CE1445403E07962364C44740
75307	2	23	\N	54830	40267	\N	47.534306000000001	Ростовская область, город Волгодонск, 50 Лет ВЛКСМ, 10		0101000020E61000006D904946CE1445403E07962364C44740
75226	2	23	\N	54829	\N	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Зал ожидания железнодорожного вокзала		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75235	2	23	\N	54829	40988	\N	48.176949206405602	Ростовская область, Белокалитвинский район, г.Белая Калитва, Энтузиастов, 11А		0101000020E61000008352B4722F684440AB07CC43A6164840
75230	2	23	\N	54829	39974	\N	48.177257763797002	Ростовская область, Белокалитвинский район, г.Белая Калитва, Энгельса, 17	Россия, Ростовская область, городской округ Белая Калитва, Белая Калитва	0101000020E610000060ADDA3521654440297AE063B0164840
75221	2	23	\N	54829	55504	\N	48.201039762768602	Ростовская область, Белокалитвинский район, г.Белая Калитва, Щаденко, 12		0101000020E61000006EA12B11A86244400B98C0ADBB194840
75231	2	23	\N	54829	39976	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Театральная, 1		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75229	2	23	\N	54829	40984	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Строительная, 6		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75355	2	23	\N	54829	39904	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Светлая, 6		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75222	2	23	\N	54829	40418	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Пролетарская, 98		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75234	2	23	\N	54829	40206	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Мичурина, 34		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
76711	2	23	\N	54817	41260	\N	47.116163999999998	Ростовская область, город Батайск, 1-й Пятилетки, 9		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76907	2	23	\N	54829	40005	\N	48.175557087041	Ростовская область, Белокалитвинский район, г.Белая Калитва, Машиностроителей, общ. 4\\1		0101000020E6100000E0BDA3C684644440BCCADAA678164840
75220	2	23	\N	54829	40005	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Машиностроителей, МОУ СОШ №17		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75225	2	23	\N	54829	40982	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Копаева, 22		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75233	2	23	\N	54829	40205	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Калинина, 21		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75236	2	23	\N	54829	40419	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Горького, 167		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75237	2	23	\N	54829	40361	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Геологическая, 2		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
76495	2	23	\N	54817	55113	\N	47.117704674372398	Ростовская область, город Батайск, пл. Ленина, 5	Россия, Ростовская область, городской округ Батайск, Батайск	0101000020E6100000446D1B4641DE4340B0C91AF5108F4740
94449	2	23	\N	54817	40246	\N	47.116163999999998	Ростовская область, город Батайск, Южная, 5		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76720	2	23	\N	54817	39994	\N	47.116163999999998	Ростовская область, город Батайск, Эстакадная, 12		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77618	2	23	\N	54817	40146	\N	47.121608061832397	Ростовская область, город Батайск, Энгельса, 347	Россия, Ростовская область, городской округ Батайск, Батайск	0101000020E61000009CC58B8521E043404B77D7D9908F4740
76480	2	23	\N	54817	40146	\N	47.116163999999998	Ростовская область, город Батайск, Энгельса, 199		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76717	2	23	\N	54817	40659	\N	47.116163999999998	Ростовская область, город Батайск, Тельмана, 154		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77629	2	23	\N	54817	40341	\N	47.116163999999998	Ростовская область, город Батайск, Ставропольская, 50		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76725	2	23	\N	54817	40341	\N	47.116163999999998	Ростовская область, город Батайск, Ставропольская, 50б		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77617	2	23	\N	54817	55241	\N	47.116163999999998	Ростовская область, город Батайск, Совхозная, 4/2		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77633	2	23	\N	54817	39867	\N	47.116163999999998	Ростовская область, город Батайск, Северный массив, 6/2		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77728	2	23	\N	54817	40198	\N	47.116163999999998	Ростовская область, город Батайск, Первомайское кольцо, 175		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76679	2	23	\N	54817	41259	\N	47.126594897457998	Ростовская область, город Батайск, Октябрьская, 110		0101000020E61000009F573CF548DF4340276BD44334904740
76722	2	23	\N	54817	40136	\N	47.116163999999998	Ростовская область, город Батайск, Молдавская, 17		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76718	2	23	\N	54817	40660	\N	47.116163999999998	Ростовская область, город Батайск, Матросова, 2а/155		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76724	2	23	\N	54817	39995	\N	47.116163999999998	Ростовская область, город Батайск, М.Горького, 593		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76723	2	23	\N	54817	39995	\N	47.116163999999998	Ростовская область, город Батайск, М.Горького, 582а		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76114	2	23	\N	54817	41145	\N	47.116532869559002	Ростовская область, город Батайск, Луначарского, 180	Россия, Ростовская область, городской округ Батайск, Батайск	0101000020E61000001A89D00836DE4340CFF3A78DEA8E4740
76719	2	23	\N	54817	40483	\N	47.116163999999998	Ростовская область, город Батайск, ул. Ленина, 170		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76652	2	23	\N	54817	40483	\N	47.116163999999998	Ростовская область, город Батайск, ул. Ленина, 95		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
75960	2	23	\N	54817	40483	\N	47.116163999999998	Ростовская область, город Батайск, ул. Ленина, 3		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76715	2	23	\N	54817	40650	\N	47.116163999999998	Ростовская область, город Батайск, Коммунистическая, 180б		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76701	2	23	\N	54817	40650	\N	47.116767232599003	Ростовская область, город Батайск, Коммунистическая, 88	Россия, Ростовская область, городской округ Батайск, Батайск	0101000020E610000092955F0663DE434043209738F28E4740
77747	2	23	\N	54817	55254	\N	47.117470315486997	Ростовская область, город Батайск, Комарова, 175	Россия, Ростовская область, городской округ Батайск, Батайск	0101000020E61000006B813D2652DE43406C21C841098F4740
77745	2	23	\N	54817	40037	\N	47.116163999999998	Ростовская область, город Батайск, Коваливского, 74а		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77693	2	23	\N	54817	55249	\N	47.140491114081598	Ростовская область, город Батайск, Калинина, 136а		0101000020E61000003EEDF0D764DD4340F030ED9BFB914740
76714	2	23	\N	54817	39979	\N	47.116163999999998	Ростовская область, город Батайск, Железнодорожный тупик, 37		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77746	2	23	\N	54817	40347	\N	47.116163999999998	Ростовская область, город Батайск, Гастелло, 2а		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77628	2	23	\N	54817	39839	\N	47.116163999999998	Ростовская область, город Батайск, Воровского, 1а		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76721	2	23	\N	54817	39724	\N	47.1161640431989	Ростовская область, город Батайск, Белорусская, 83	Россия, Ростовская область, городской округ Батайск, Батайск	0101000020E61000008DEF8B4B55DE43407C7C4276DE8E4740
76726	2	23	\N	54817	40134	\N	47.116163999999998	Ростовская область, город Батайск, Авиагородок, 19а		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76716	2	23	\N	54817	40134	\N	47.116163999999998	Ростовская область, город Батайск, Авиагородок, 34а		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76713	2	23	\N	54817	39723	\N	47.116163999999998	Ростовская область, город Батайск, 50 лет Октября, 71		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77744	2	23	\N	54817	55250	\N	47.116163999999998	Ростовская область, город Батайск, Северный массив, 8		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
76728	2	23	\N	11987	55101	\N	47.2660303522294	Ростовская область,Аксайский район,г.Аксай, Шолохова, 4	Россия, Ростовская область, Аксай	0101000020E61000000B62A06B5FF04340A0E062450DA24740
76727	2	23	\N	11987	55099	\N	47.265855076759898	Ростовская область,Аксайский район,г. Аксай, Шевченко, 156	Россия, Ростовская область, Аксай	0101000020E61000002FA699EE75F04340323D618907A24740
76744	2	23	\N	11987	55129	\N	47.274397453516201	Ростовская область,Аксайский район,г.Аксай, Садовая, 30/5	Россия, Ростовская область	0101000020E61000001CEF8E8CD5F043406D8FDE701FA34740
77710	2	23	\N	11987	55245	\N	47.266605673575	Ростовская область,Аксайский район,г.Аксай, Платова, 68	Россия, Ростовская область, Аксай	0101000020E610000046239F573CEF43406D75392520A24740
76739	2	23	\N	11987	55159	\N	47.2640568464995	Ростовская область,Аксайский район,г.Аксай, Крупской, 5	Россия, Ростовская область, Аксай	0101000020E61000008CF337A110F14340D3A3A99ECCA14740
77171	2	23	\N	54819	40262	\N	47.092899000000003	Ростовская область, город Азов, Зои Космодемьянской пр, 90А		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77192	2	23	\N	54819	40313	\N	47.092899000000003	Ростовская область, город Азов, Ст. Разина пер, 3А		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77183	2	23	\N	54819	40312	\N	47.092899000000003	Ростовская область, город Азов, Социалистический пер, 25		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77189	2	23	\N	54819	39755	\N	47.092899000000003	Ростовская область, город Азов, Осипенко пер, 47		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77175	2	23	\N	54819	40311	\N	47.092899000000003	Ростовская область, город Азов, Черноморский пер, 77		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77606	2	23	\N	54819	55237	\N	47.104082213335602	Ростовская область, город Азов, Толстого ул, 99	Россия, Ростовская область, городской округ Азов, Азов	0101000020E61000009BC8CC052EB74340170D198F528D4740
77195	2	23	\N	54819	56208	\N	47.092899000000003	Ростовская область, город Азов, Соловьиный пер, 9		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77193	2	23	\N	54819	40161	\N	47.092899000000003	Ростовская область, город Азов, Пушкина ул, 110		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77187	2	23	\N	54819	40161	\N	47.092899000000003	Ростовская область, город Азов, Пушкина ул, 29		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77194	2	23	\N	54819	40772	\N	47.092899000000003	Ростовская область, город Азов, Победы ул, 6		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77180	2	23	\N	54819	40770	\N	47.092899000000003	Ростовская область, город Азов, Петровский бульвар ул, 8		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77190	2	23	\N	54819	41363	\N	47.092899000000003	Ростовская область, город Азов, Первомайская ул, 94		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77191	2	23	\N	54819	40160	\N	47.092899000000003	Ростовская область, город Азов, Московская ул, 292		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77188	2	23	\N	54819	40160	\N	47.092899000000003	Ростовская область, город Азов, Московская ул, 118 (вход с пер. О. Кошевого)		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77185	2	23	\N	54819	40160	\N	47.092899000000003	Ростовская область, город Азов, Московская ул, 118 (вход с пер. Осипенко)		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
76158	2	23	\N	54819	40160	\N	47.092899000000003	Ростовская область, город Азов, Московская ул, 141		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77678	2	23	\N	54819	55821	\N	47.093078039901698	Ростовская область, город Азов, Мира ул, 19/31	Россия, Ростовская область, городской округ Азов, Азов	0101000020E6100000D9976C3CD8B6434011FDDAFAE98B4740
77181	2	23	\N	54819	40158	\N	47.092899000000003	Ростовская область, город Азов, Мира ул, 2		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77077	2	23	\N	54819	40158	\N	47.092899000000003	Ростовская область, город Азов, Мира ул, 41		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77176	2	23	\N	54819	40151	\N	47.092899000000003	Ростовская область, город Азов, Макаровского ул, 31А		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77174	2	23	\N	54819	40151	\N	47.092899000000003	Ростовская область, город Азов, Макаровского ул, 37		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77196	2	23	\N	54819	40011	\N	47.092899000000003	Ростовская область, город Азов, Ленинградская ул, 39		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77186	2	23	\N	54819	40011	\N	47.092899000000003	Ростовская область, город Азов, Ленинградская ул, 47		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
76842	2	23	\N	54819	41274	\N	47.092899000000003	Ростовская область, город Азов, Куйбышева ул, 63/30		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77607	2	23	\N	54819	39863	\N	47.092899000000003	Ростовская область, город Азов, Красногоровская ул, 16		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
76844	2	23	\N	54819	39863	\N	47.092899000000003	Ростовская область, город Азов, Красногоровская ул, 4		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77184	2	23	\N	54819	40761	\N	47.092899000000003	Ростовская область, город Азов, Красноармейский пер, 63		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77088	2	23	\N	54819	40761	\N	47.092902188994898	Ростовская область, город Азов, Красноармейский пер, 90	Россия, Ростовская область, городской округ Азов, Азов	0101000020E610000016BD5301F7B64340D3DD7536E48B4740
77679	2	23	\N	54819	39757	\N	47.092899000000003	Ростовская область, город Азов, Кондаурова ул, 32		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77197	2	23	\N	54819	39757	\N	47.092899000000003	Ростовская область, город Азов, Кондаурова ул, 23		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77179	2	23	\N	54819	40157	\N	47.092899000000003	Ростовская область, город Азов, Дзержинского, 14		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77177	2	23	\N	54819	40767	\N	47.092899000000003	Ростовская область, город Азов, Григория Мирошниченко ул, 48		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77677	2	23	\N	54819	40955	\N	47.092899000000003	Ростовская область, город Азов, Васильева ул, 85/87		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
76843	2	23	\N	54819	41357	\N	47.092899000000003	Ростовская область, город Азов, Андреевская ул, 102		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77365	2	23	374	1920	\N	\N	47.739519999999999	Ростовская область, город Шахты, Сокольнический, 8-А	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E61000001553E9279C1D4440745E6397A8DE4740
77351	2	23	374	1920	\N	\N	47.739519999999999	Ростовская область, город Шахты, Парковая, 2-Б	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E61000001553E9279C1D4440745E6397A8DE4740
77318	2	23	374	1920	55163	\N	47.705544153739801	Ростовская область, город Шахты, Якутский, 2	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E6100000137F1475E6184440CCF10A444FDA4740
77368	2	23	374	1920	55207	\N	47.7294803696564	Ростовская область, город Шахты, Мичурина, 11	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E6100000A7EB89AE0B254440058BC3995FDD4740
77362	2	23	374	1920	55206	\N	47.739519999999999	Ростовская область, город Шахты, Милиционная, 20		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77366	2	23	374	1920	55203	\N	47.739519999999999	Ростовская область, город Шахты, Ленинского Комсомола, 51		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77372	2	23	374	1920	55214	\N	47.739519999999999	Ростовская область, город Шахты, Калинина, 79		0101000020E61000001553E9279C1D4440745E6397A8DE4740
77379	2	23	374	1920	55216	\N	47.732267140828903	Ростовская область, город Шахты, Ворошилова, 9-А	Россия, Ростовская область, городской округ Шахты, Шахты	0101000020E610000000016BD5AE1F44405378D0ECBADD4740
77547	2	23	1638	20596	41222	\N	47.772787293383097	Ростовская область, город Новошахтинск, Привокзальная, 132	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E6100000BC96900F7AF2434011E335AFEAE24740
77555	2	23	1638	20596	55716	\N	47.763818210573902	Ростовская область, город Новошахтинск, Перспективная, 2	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E610000067EE21E17BF743404E0CC9C9C4E14740
77539	2	23	1638	20596	55235	\N	47.785890999999999	Ростовская область, город Новошахтинск, Молодогвардейцев, 13/5		0101000020E61000002BD9B11188F34340419C871398E44740
77548	2	23	1638	20596	55695	\N	47.753950422168998	Ростовская область, город Новошахтинск, Маркса, 15	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E6100000D36C1E87C1F64340DC68006F81E04740
77557	2	23	1638	20596	55571	\N	47.785890999999999	Ростовская область, город Новошахтинск, Линейная, 32		0101000020E61000002BD9B11188F34340419C871398E44740
77517	2	23	1638	20596	55139	\N	47.7598684274394	Ростовская область, город Новошахтинск, Ленина, 21/16	Россия, Ростовская область, городской округ Новошахтинск, Новошахтинск	0101000020E6100000A0C37C7901F8434072A3C85A43E14740
76032	2	23	1247	12804	40518	\N	48.316377057112597	Ростовская область, город Каменск-Шахтинский, мкр.Лиховской, Советская, 18	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E61000004A42226DE3214440721AA20A7F284840
76079	2	23	1247	12804	32956	\N	48.319160712589998	Ростовская область, город Каменск-Шахтинский, микрорайон Лиховской, Железнодорожников, 12	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E610000082E3326E6A2244404F948444DA284840
76065	2	23	1247	12804	55182	\N	48.315217751926902	Ростовская область, город Каменск-Шахтинский, Ворошилова, 155	Россия, Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский	0101000020E61000005A12A0A696234440268E3C1059284840
76035	2	23	320	1460	55723	\N	48.3314717699892	Ростовская область, город Донецк, Юго-Западное шоссе, 1	Россия, Ростовская область, городской округ Донецк, Донецк	0101000020E610000060014C1938FA434015C5ABAC6D2A4840
77417	2	23	1370	14830	39845	\N	48.041666999999997	Ростовская область, город Гуково, Красная Горка, 80		0101000020E61000008BC1C3B46FFA43404529215855054840
77408	2	23	1370	14830	55218	\N	48.041666999999997	Ростовская область, город Гуково, Комсомольская, 17		0101000020E61000008BC1C3B46FFA43404529215855054840
77404	2	23	1370	14830	55224	\N	48.052717549178197	Ростовская область, город Гуково, Карла Маркса, 54	Россия, Ростовская область, городской округ Гуково, Гуково	0101000020E61000006E13EE9579F743408CF4A276BF064840
77418	2	23	1370	14830	55807	\N	48.041666999999997	Ростовская область, город Гуково, Железнодорожная, 31-а		0101000020E61000008BC1C3B46FFA43404529215855054840
75635	2	23	265	1116	55158	\N	47.516838390317901	Ростовская область, город Волгодонск, Центральная, 46	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E6100000C442AD69DE1745403FAA61BF27C24740
75653	2	23	265	\N	55140	\N	47.523699163494598	Ростовская область, город Волгодонск, Октябрьское шоссе, 32	Россия, Ростовская область, городской округ Волгодонск	0101000020E6100000B0E42A16BF1D454055F99E9108C34740
75627	2	23	265	1116	55162	\N	47.519330543512801	Ростовская область, город Волгодонск, Вокзальный, 21	Россия, Ростовская область, городской округ Волгодонск, Волгодонск	0101000020E6100000A5D8D138D411454045662E7079C24740
75219	2	23	758	5338	39938	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Машиностроителей, 17Б		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75232	2	23	758	5338	55133	\N	48.176116809706798	Ростовская область, Белокалитвинский район, г.Белая Калитва, Калинина, 19	Россия, Ростовская область, городской округ Белая Калитва, Белая Калитва	0101000020E6100000416150A6D166444083A279008B164840
75223	2	23	758	5338	40979	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, Большая, 11		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
76628	2	23	418	2228	40299	\N	47.116163999999998	Ростовская область, город Батайск, пер. Книжный, 2		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
45934	2	20	\N	6023	23372	\N	44.735861	город Новороссийск, ул. Видова, д. 184, телефон: 26-24-22		0101000020E61000004ACE893DB4DD424070B378B1305E4640
76712	2	23	418	2228	55128	\N	47.139012343793098	Ростовская область, город Батайск, Куйбышева, 50	Россия, Ростовская область, городской округ Батайск, Батайск	0101000020E610000056629E95B4DE434033E02C25CB914740
77634	2	23	418	2228	55242	\N	47.116163999999998	Ростовская область, город Батайск, Авиагородок, 29а		0101000020E6100000799274CDE4DD43407C7C4276DE8E4740
77178	2	23	183	589	\N	\N	47.123725785267702	Ростовская область, город Азов, Хутор Задонье ул.	Россия, Ростовская область, городской округ Азов, Азов	0101000020E6100000BA4DB857E6B543401BD5E940D68F4740
77173	2	23	183	589	55165	\N	47.1054154530757	Ростовская область, город Азов, Севастопольская ул, 113	Россия, Ростовская область, городской округ Азов, Азов	0101000020E610000029B3412619B3434001C11C3D7E8D4740
77182	2	23	183	589	55116	\N	47.107997593829502	Ростовская область, город Азов, Макаровского ул, 29В	Россия, Ростовская область, городской округ Азов, Азов	0101000020E61000003FC571E0D5B443404704E3E0D28D4740
76908	2	23	183	589	55116	\N	47.106613142544298	Ростовская область, город Азов, Макаровского ул, 35	Россия, Ростовская область, городской округ Азов, Азов	0101000020E610000003ECA35357B443400B2AAA7EA58D4740
77610	2	23	183	589	55240	\N	47.092899000000003	Ростовская область, город Азов, Литейный проезд, 9/22		0101000020E610000055C03DCF9FB64340626A4B1DE48B4740
77111	2	23	183	589	55204	\N	47.110286620308401	Ростовская область, город Азов, Измайлова ул, 69	Россия, Ростовская область, городской округ Азов, Азов	0101000020E6100000B55373B9C1B64340441669E21D8E4740
76545	2	23	290	5809	55970	\N	49.475665999999997	Ростовская область, Шолоховский район, хутор Чукаринский, пер.Центральный, 5-а		0101000020E6100000BB270F0BB5DC4440D9E89C9FE2BC4840
76543	2	23	290	5655	56353	\N	49.735362000000002	Ростовская область, Шолоховский район, хутор Черновский, пер.Центральный, 10		0101000020E610000002452C62D8D944404F5C8E5720DE4840
76541	2	23	290	5592	56092	\N	49.808812000000003	Ростовская область, Шолоховский район, хутор Ушаковский, ул.Центральная, 22		0101000020E61000007C48F8DEDFE44440624ED02687E74840
76552	2	23	290	6139	55798	\N	49.758119176565003	Ростовская область, Шолоховский район, хутор Терновской, ул.Центральная, 7-в	Россия, Ростовская область, Шолоховский район, хутор Терновской	0101000020E6100000780B24287EFC4440F5BC1B0B0AE14840
76547	2	23	290	5918	56088	\N	49.478827000000003	Ростовская область, Шолоховский район, хутор Сингиновский, ул.Степная, 1		0101000020E610000040F67AF7C7ED44408DB800344ABD4840
77675	2	23	290	28470	55998	\N	49.588731000000003	Ростовская область, Шолоховский район, хутор Рубежинский, ул.Береговая, 22		0101000020E6100000EE3EC7478BF94440199293895BCB4840
76553	2	23	290	6184	56192	\N	49.816009000000001	Ростовская область, Шолоховский район, хутор Поповский, ул.Центральная, 11-а		0101000020E6100000DC8310902FF74440EF1EA0FB72E84840
76539	2	23	290	5436	56167	\N	49.587691999999997	Ростовская область, Шолоховский район, хутор Плешаковский, ул.Лесная, 42		0101000020E6100000C1AA7AF99D044540770FD07D39CB4840
77753	2	23	290	56784	55935	\N	49.635689854792901	Ростовская область, Шолоховский район, х.Пигаревский, ул.Чехова, 25	Россия, Ростовская область, Шолоховский район, хутор Пигаревский	0101000020E6100000F302ECA353D744407632384A5ED14840
76538	2	23	290	5429	56352	\N	49.560012999999998	Ростовская область, Шолоховский район, хутор Нижнекривской, ул.Родниковая, 152		0101000020E6100000E1B88C9B1A004540DC2A8881AEC74840
76548	2	23	290	5985	40629	\N	49.6098527845744	Ростовская область, Шолоховский район, хутор Меркуловский, пер.Победы, 5	Россия, Ростовская область, Шолоховский район, хутор Меркуловский	0101000020E610000026AB22DC64C444400A2FC1A90FCE4840
76546	2	23	290	5819	56188	\N	49.457627000000002	Ростовская область, Шолоховский район, хутор Максаевский, ул.Южная, 43-а		0101000020E6100000817B9E3F6DE644402062838593BA4840
76535	2	23	290	5270	56209	\N	49.910690000000002	Ростовская область, Шолоховский район, хутор Лосевский, ул.Зеленая, 4-а		0101000020E610000027F911BF62D74440AA656B7D91F44840
76528	2	23	290	4917	56061	\N	49.597670999999998	Ростовская область, Шолоховский район, хутор Лебяженский, ул.Плоткина, 25		0101000020E61000004242942F68F544404162BB7B80CC4840
76544	2	23	290	5727	41243	\N	49.434427049497103	Ростовская область, Шолоховский район, хутор Кружилинский, ул.Школьная, 12	Россия, Ростовская область, Шолоховский район, хутор Кружилинский	0101000020E6100000DB6D179AEBE24440ECBFCE4D9BB74840
76540	2	23	290	5497	55803	\N	49.758895000000003	Ростовская область, Шолоховский район, хутор Колундаевский, пер.Больничный, 12		0101000020E6100000A7EB89AE0BEB4440890CAB7823E14840
76550	2	23	290	6068	56098	\N	49.550201000000001	Ростовская область, Шолоховский район, хутор Калиновский, ул.Центральная, 19		0101000020E61000006728EE7893B34440FE9C82FC6CC64840
76536	2	23	290	5277	39717	\N	49.561638000000002	Ростовская область, Шолоховский район, хутор Калининский, ул.Центральная, 15		0101000020E6100000B5C35F9335EC44406E1805C1E3C74840
76532	2	23	290	5110	56317	\N	49.744408999999997	Ростовская область, Шолоховский район, хутор Зубковский, ул.Решетовская, 39		0101000020E6100000AAD72D0263C744408DEC4ACB48DF4840
76549	2	23	290	5969	56067	\N	49.593561000000001	Ростовская область, Шолоховский район, хутор Затонский, ул.Центральная, 68		0101000020E6100000A48E8EAB91B944402D978DCEF9CB4840
76529	2	23	290	56913	56446	\N	49.615360000000003	Ростовская область, Шолоховский район, хутор Еланский, ул.Платова, 13	Россия, Ростовская область, Шолоховский район, станица Еланская	0101000020E610000032569BFF570545401FA2D11DC4CE4840
76533	2	23	290	5113	55623	\N	49.898482999999999	Ростовская область, Шолоховский район, хутор Дударевский, ул.Клубная, 4-б		0101000020E6100000F8FC304278CE44408881AE7D01F34840
76534	2	23	290	5113	56050	\N	49.8981742270688	Ростовская область, Шолоховский район, хутор Дударевский, ул.Западная, 16-а	Россия, Ростовская область, Шолоховский район, хутор Дударевский	0101000020E6100000B1524145D5CD44400A0F9A5DF7F24840
76530	2	23	290	4976	55489	\N	49.699000751980797	Ростовская область, Шолоховский район, хутор Дубровский, пер.Школьный, 13	Россия, Ростовская область, Шолоховский район, хутор Дубровский	0101000020E6100000CBF5B6990AD14440876F61DD78D94840
76521	2	23	290	4530	55488	\N	49.582137000000003	Ростовская область, Шолоховский район, хутор Громковский, ул.Почтовая, 271		0101000020E61000001BF33AE290E344405265187783CA4840
76542	2	23	290	5649	55956	\N	49.713616000000002	Ростовская область, Шолоховский район, хутор Гороховский, ул.Школьная, 1		0101000020E61000009B1F7F6951E1444080F3E2C457DB4840
77733	2	23	290	31179	56133	\N	49.567338389727396	Ростовская область, Шолоховский район, хутор Водянский, ул.Подгорная, 5	Россия, Ростовская область, Шолоховский район, хутор Водянский	0101000020E6100000ADC1FBAA5CC6444097E315889EC84840
76525	2	23	290	4694	55109	\N	49.632802025805901	Ростовская область, Шолоховский район, станица Вешенская, пер.Красный, 12	Россия, Ростовская область, Шолоховский район, станица Вешенская	0101000020E6100000D4EE5701BEDD4440F46BEBA7FFD04840
76554	2	23	290	4694	39929	\N	49.633025000000004	Ростовская область, Шолоховский район, ст.Вешенская, ул.Шолохова, 125		0101000020E6100000C19140834DDD4440744694F606D14840
76526	2	23	290	4694	39929	\N	49.633025000000004	Ростовская область, Шолоховский район, станица Вешенская, ул.Шолохова, 2-г		0101000020E6100000C19140834DDD4440744694F606D14840
76524	2	23	290	4694	41175	\N	49.633025000000004	Ростовская область, Шолоховский район, станица Вешенская, ул.Сосновая, 61		0101000020E6100000C19140834DDD4440744694F606D14840
76523	2	23	290	4601	55955	\N	49.533371000000002	Ростовская область, Шолоховский район, хутор Верхнетокинский, ул.Молодежная, 11-а		0101000020E61000003E78EDD286D9444042D13C8045C44840
76551	2	23	290	1346	32959	\N	49.543801000000002	Ростовская область, Шолоховский район, хутор Варваринский, ул.Горская, 17		0101000020E6100000A758350873AF44401C446B459BC54840
76520	2	23	290	1240	40147	\N	49.593671999999998	Ростовская область, Шолоховский район, ст.Базковская, ул.Ленина, 12		0101000020E610000017F2086EA4DE44408446B071FDCB4840
76531	2	23	290	5056	56066	\N	49.720599999999997	Ростовская область, Шолоховский район, хутор Антиповский, ул.Школьная, 35		0101000020E6100000C636A968ACC54440B1BFEC9E3CDC4840
76527	2	23	290	4858	56312	\N	49.666679000000002	Ростовская область, Шолоховский район, хутор Андроповский, ул.Агеева, 19		0101000020E61000001212691B7FF844400AF7CABC55D54840
76522	2	23	290	4534	56311	\N	49.610514999999999	Ростовская область, Шолоховский район, хутор Альшанский, ул.Городская, 10-а		0101000020E61000009F02603C83D24440D55B035B25CE4840
76494	2	23	355	3030	55778	\N	49.495603120410998	Ростовская область, Чертковский район, с. Щедровка, ул.Южная, д.79	Россия, Ростовская область, Чертковский район, село Щедровка	0101000020E61000008C3045B93426444056664AEB6FBF4840
76502	2	23	355	3485	55635	\N	49.291150999999999	Ростовская область, Чертковский район, с. Шептуховка, ул.Центральная, д.59		0101000020E6100000BFB9BF7ADC2B44404E999B6F44A54840
76484	2	23	355	1803	55626	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, пер.Деповской, д.50		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76477	2	23	355	1803	55732	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Фрунзе, д.23		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76478	2	23	355	1803	40261	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Садовая, д.31		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76476	2	23	355	1803	40145	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Пролетарская, д.102		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76473	2	23	355	1803	40145	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Пролетарская, д.1		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76483	2	23	355	1803	39992	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Петровского, д.152		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76475	2	23	355	1803	39992	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Петровского, д.71		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76482	2	23	355	1803	40566	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Октябрьская, д.21-а		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76474	2	23	355	1803	55730	\N	49.378386999999996	Ростовская область, Чертковский район, п. Чертково, ул.Комсомольская, д.21		0101000020E6100000ACFE08C380134440A31D37FC6EB04840
76507	2	23	355	3739	55780	\N	49.583930000000002	Ростовская область, Чертковский район, с. Тихая Журавка, ул.Широкая, д.29		0101000020E6100000EB1ED95C355544409F93DE37BECA4840
76487	2	23	355	2566	56234	\N	49.465538000000002	Ростовская область, Чертковский район, с. Тарасово- Меловское, ул.Ленина, 1		0101000020E610000058C6866EF6094440CB85CABF96BB4840
76506	2	23	355	3699	39931	\N	49.501801	Ростовская область, Чертковский район, с. Сохрановка, ул.Социалистическая, д.1-а		0101000020E6100000A515DF50F8404440D00CE2033BC04840
76514	2	23	355	56790	55941	\N	49.366790000000002	Ростовская область, Чертковский район, х. Сетраки, ул.Советская, д.23	Россия, Ростовская область, Чертковский район, хутор Сетраки	0101000020E6100000F83768AF3E6A4440FB3F87F9F2AE4840
76513	2	23	355	57026	56582	\N	49.250441026859797	Ростовская область, Чертковский район, сл. Семено-Камышенская, ул.Советская, д.18	Россия, Ростовская область, Чертковский район, слобода Семено-Камышенская	0101000020E610000013640454384A4440ED4960730EA04840
76479	2	23	355	56956	56496	\N	49.388392148673198	"Ростовская область, Чертковский район, х. Полтава, ул.Комарова, здание конторы ЗАО ""Полтавское"""	Россия, Ростовская область, Чертковский район, хутор Полтава	0101000020E6100000960A2AAA7E17444097033DD4B6B14840
76467	2	23	76	1458	56233	\N	48.045462000000001	Ростовская область, Тацинский район, хутор Араканцев, 70 лет Октября, 48		0101000020E6100000994BAAB69BC64440FA9AE5B2D1054840
76516	2	23	355	56806	56060	\N	49.244993000000001	Ростовская область, Чертковский район, х. Павловка, ул.Партизанская, д.13	Россия, Ростовская область, Чертковский район, хутор Павловка	0101000020E610000097A8DE1AD85E4440DD5F3DEE5B9F4840
76485	2	23	355	2502	39993	\N	49.399901999999997	Ростовская область, Чертковский район, с. Осиково, ул.Российская, д.6		0101000020E61000000C2252D32E12444070CD1DFD2FB34840
76515	2	23	355	4160	55564	\N	49.270411000000003	Ростовская область, Чертковский район, с. Ольховчик, ул.Молодежная, д.37		0101000020E6100000048D9944BD64444045BDE0D39CA24840
76492	2	23	355	57011	56559	\N	49.574240000000003	Ростовская область, Чертковский район, х. Новостепановский, ул.Мира, д.27	Россия, Ростовская область, Чертковский район, хутор Новостепановский	0101000020E6100000224F92AE992244400C0742B280C94840
76503	2	23	355	3532	55553	\N	49.260641	Ростовская область, Чертковский район, с. Новоселовка, ул.Школьная, д.1		0101000020E6100000518369183E2E4440957F2DAF5CA14840
76508	2	23	355	56709	55852	\N	49.566731522026302	Ростовская область, Чертковский район, х. Нагибин, ул.Лесная, д.15	Россия, Ростовская область, Чертковский район, хутор Нагибин	0101000020E6100000A8E2C62DE647444060CC96AC8AC84840
77619	2	23	355	3600	55600	\N	49.206325999999997	Ростовская область, Чертковский район, с. Михайлово-Александровка, ул.Ленина, д.22		0101000020E6100000A393A5D6FB1D44404128EFE3689A4840
76504	2	23	355	3600	55600	\N	49.206325999999997	Ростовская область, Чертковский район, с. Михайлово-Александровка, ул.Ленина, д.51-а		0101000020E6100000A393A5D6FB1D44404128EFE3689A4840
76509	2	23	355	56988	56534	\N	49.428151999999997	Ростовская область, Чертковский район, х. Марьяны, ул.Степная, д.2-а	Россия, Ростовская область, Чертковский район, хутор Марьяны	0101000020E6100000CC7A319413334440C6DB4AAFCDB64840
76497	2	23	355	3205	55678	\N	49.392274	Ростовская область, Чертковский район, с. Маньково-Калитвенское, ул.Юбилейная, д.7		0101000020E6100000F20C1AFA272444401A89D00836B24840
76498	2	23	355	3205	55808	\N	49.392274	Ростовская область, Чертковский район, с. Маньково-Калитвенское, ул.Октябрьская, д.17		0101000020E6100000F20C1AFA272444401A89D00836B24840
76500	2	23	355	3205	55483	\N	49.392274	Ростовская область, Чертковский район, с. Маньково-Калитвенское, ул.Кирова, д.106		0101000020E6100000F20C1AFA272444401A89D00836B24840
76499	2	23	355	3205	55483	\N	49.392274	Ростовская область, Чертковский район, с. Маньково-Калитвенское, ул.Кирова, д.35		0101000020E6100000F20C1AFA272444401A89D00836B24840
76511	2	23	355	56785	55936	\N	49.448275177742403	Ростовская область, Чертковский район, х. Малая Лозовска, ул.Победы, д.18	Россия, Ростовская область, Чертковский район, хутор Малая Лозовка	0101000020E610000081E84999D4504440A54E401361B94840
76519	2	23	355	56954	56494	\N	49.4285339829013	Ростовская область, Чертковский район, х. Лозовой, ул.Центральная, д.3	Россия, Ростовская область, Чертковский район, хутор Лозовой	0101000020E6100000997E8978EB264440AE9CBD33DAB64840
76505	2	23	355	3634	55680	\N	49.395351194445297	Ростовская область, Чертковский район, с. Кутейниково, ул.Октябрьская, д.32	Россия, Ростовская область, Чертковский район, село Кутейниково	0101000020E6100000902E36AD143C44406FB88FDC9AB24840
76496	2	23	355	56874	56402	\N	49.525162000000002	Ростовская область, Чертковский район, х. Кадамов, ул.Лесная, д.33	Россия, Ростовская область, Чертковский район, хутор Кадамов	0101000020E610000045D8F0F44A2D44400D8D278238C34840
76501	2	23	355	56928	56463	\N	49.390638000000003	Ростовская область, Чертковский район, х. Гусев, ул.Мира, д.20	Россия, Ростовская область, Чертковский район, хутор Гусев	0101000020E61000007F677BF48633444095490D6D00B24840
76512	2	23	355	3994	55481	\N	49.342630999999997	Ростовская область, Чертковский район, с. Греково-Степановка, пер.Тихий, д.2		0101000020E6100000DB8827BB9955444042CC2555DBAB4840
76488	2	23	355	56812	\N	\N	49.510159999999999	Ростовская область, Чертковский район, х. Галдин, здание дома культуры	Россия, Ростовская область, Чертковский район, хутор Галдин	0101000020E61000003F524486550A44401ADD41EC4CC14840
76518	2	23	355	56927	56461	\N	49.482227282191701	Ростовская область, Чертковский район, х. Богуны, ул.Центральная, д.15	Россия, Ростовская область, Чертковский район, хутор Богуны	0101000020E6100000F299EC9FA76B4440C51F459DB9BD4840
76493	2	23	355	56847	56354	\N	49.531489226337101	Ростовская область, Чертковский район, х. Бакай, ул.Полетаева, д.33	Россия, Ростовская область, Чертковский район, хутор Бакай	0101000020E6100000707D586FD42244408597E0D407C44840
76517	2	23	355	56808	56071	\N	49.373548	Ростовская область, Чертковский район, х. Артамошкин, ул.Центральная, д.19	Россия, Ростовская область, Чертковский район, хутор Артамошкин	0101000020E610000041D5E8D5008344403CBEBD6BD0AF4840
76491	2	23	355	56811	\N	\N	49.6130232343316	Ростовская область, Чертковский район, сл. Анно-Ребриковская, здание СДК	Россия, Ростовская область, Чертковский район, слобода Анно-Ребриковская	0101000020E6100000B32781CD391A44401059A48977CE4840
76510	2	23	355	3881	41174	\N	49.393382000000003	Ростовская область, Чертковский район, с. Алексеево-Лозовское, ул.Лисичкина, д.22		0101000020E6100000CFA10C5531534440E46A64575AB24840
77620	2	23	355	3881	55816	\N	49.393382000000003	Ростовская область, Чертковский район, с. Алексеево-Лозовское, ул.Кирова, д.70-а		0101000020E6100000CFA10C5531534440E46A64575AB24840
76010	2	23	254	56880	56408	\N	48.023645983258803	Ростовская область, Цимлянский район, Маркинское сельское поселение, х.Черкасский, Центральная, 49	Россия, Ростовская область, Цимлянский район, хутор Черкасский	0101000020E610000039605793A7024540325706D506034840
45353	2	20	1322	50257	\N	\N	45.078200000000002	поселок Белозерный, 14/2, телефон: 229-43-99		0101000020E6100000B2A19BFD815643400B462575028A4640
75991	2	23	254	1189	40230	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Советская, 35		0101000020E610000018B2BAD5730A4540AF264F594DD34740
77730	2	23	254	1189	39692	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Победы, 134		0101000020E610000018B2BAD5730A4540AF264F594DD34740
75999	2	23	254	1189	39692	\N	47.638880856680203	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Победы, 112	Россия, Ростовская область, Цимлянский район, Цимлянск	0101000020E61000008369183E220E4540948444DAC6D14740
75990	2	23	254	1189	40060	\N	47.6397945025168	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Набережная, 2	Россия, Ростовская область, Цимлянский район, Цимлянск	0101000020E6100000E44D7E8B4E0E4540799274CDE4D14740
75995	2	23	254	1189	40062	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Московская, 63		0101000020E610000018B2BAD5730A4540AF264F594DD34740
77709	2	23	254	1189	55491	\N	47.648393587488101	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Маяковского, 106	Россия, Ростовская область, Цимлянский район, Цимлянск	0101000020E61000002F4FE78A520C454019761893FED24740
75996	2	23	254	1189	40232	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Ломоносова, 6а		0101000020E610000018B2BAD5730A4540AF264F594DD34740
75992	2	23	254	1189	40486	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, ул.Ленина, 44		0101000020E610000018B2BAD5730A4540AF264F594DD34740
75993	2	23	254	1189	40061	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Донская, 33		0101000020E610000018B2BAD5730A4540AF264F594DD34740
77780	2	23	254	1189	55797	\N	47.650798000000002	Ростовская область, Цимлянский район, Цимлянское городское поселение, г.Цимлянск, Артемова, 2		0101000020E610000018B2BAD5730A4540AF264F594DD34740
76001	2	23	254	11332	56286	\N	47.718321942615503	Ростовская область, Цимлянский район, Саркеловское сельское поселение, ст.Хорошевская, Центральная, 20	Россия, Ростовская область, Цимлянский район, станица Хорошевская	0101000020E6100000A5D8D138D41B4540A8FFACF9F1DB4740
76016	2	23	254	12014	56285	\N	47.774901999999997	Ростовская область, Цимлянский район, Калининское сельское поселение, ст.Терновская, Центральная, 50		0101000020E610000032005471E314454070CD1DFD2FE34740
76004	2	23	254	11473	55535	\N	47.641910000000003	Ростовская область, Цимлянский район, Лозновское сельское поселение, п.Сосенки, Центральная, 32		0101000020E610000043723271AB004540D97C5C1B2AD24740
76008	2	23	254	56916	56473	\N	47.771535603030998	Ростовская область, Цимлянский район, Лозновское сельское поселение, х.Синий Курган, Школьная, 4		0101000020E61000003ACC971760E74440E4D70FB1C1E24740
75997	2	23	254	11104	40233	\N	47.677942000000002	Ростовская область, Цимлянский район, Саркеловское сельское поселение, п.Саркел, Винзаводская, 3		0101000020E6100000C408E1D1C6134540DC4AAFCDC6D64740
76012	2	23	254	56748	55895	\N	47.777837368485699	Ростовская область, Цимлянский район, Маркинское сельское поселение, х.Паршиков, Мира, 4	Россия, Ростовская область, Цимлянский район, хутор Паршиков	0101000020E6100000CEA623809BFB4440334FAE2990E34740
76018	2	23	254	12111	40490	\N	47.976215000000003	Ростовская область, Цимлянский район, Новоцимлянское сельское поселение, ст.Новоцимлянская, Мира, 36		0101000020E61000009BAE27BA2E244540AD6EF59CF4FC4740
76009	2	23	254	11698	55834	\N	47.837440999999998	Ростовская область, Цимлянский район, Маркинское сельское поселение, ст.Маркинская, Ленина, 5		0101000020E6100000A41820D1040045402EAA454431EB4740
76002	2	23	254	56638	55290	\N	47.630923731356297	Ростовская область, Цимлянский район, Лозновское сельское поселение, х.Лозной, Советская, 75		0101000020E6100000A3AF20CD58FC444079211D1EC2D04740
76006	2	23	254	11530	56268	\N	47.621471	Ростовская область, Цимлянский район, Лозновское сельское поселение, ст.Лозновская, Центральная, 32		0101000020E61000000856D5CBEFF44440CA349A5C8CCF4740
76014	2	23	254	11914	56016	\N	47.738925999999999	Ростовская область, Цимлянский район, Маркинское сельское поселение, ст.Кумшацкая, Молодежная, 38		0101000020E6100000DF5339ED29FD444001158E2095DE4740
77778	2	23	254	1066	39966	\N	47.651763000000003	Ростовская область, Цимлянский район, Красноярское сельское поселение, ст.Красноярская, Победы, 93		0101000020E6100000AD69DE718A06454016DF50F86CD34740
75998	2	23	254	1066	39966	\N	47.651763000000003	Ростовская область, Цимлянский район, Красноярское сельское поселение, ст.Красноярская, Победы, 101		0101000020E6100000AD69DE718A06454016DF50F86CD34740
76007	2	23	254	56922	56455	\N	47.601632000000002	Ростовская область, Цимлянский район, Лозновское сельское поселение, х.Карпов, Центральная, 25		0101000020E61000004CA60A4625F14440111D024702CD4740
76005	2	23	254	11517	55538	\N	47.613855000000001	Ростовская область, Цимлянский район, Лозновское сельское поселение, ст.Камышевская, Победы, 11		0101000020E6100000D717096D39E9444038BEF6CC92CE4740
76015	2	23	254	11977	55832	\N	47.842393999999999	Ростовская область, Цимлянский район, Калининское сельское поселение, ст.Калининская, Театральный, 3		0101000020E6100000EEB5A0F7C61E45405E2C0C91D3EB4740
76011	2	23	254	57006	56554	\N	47.934465499461098	Ростовская область, Цимлянский район, Маркинское сельское поселение, х.Железнодорожный, Советская, 29	Россия, Ростовская область, Цимлянский район, хутор Железнодорожный	0101000020E61000003C889D2974FE4440DA20938C9CF74740
76003	2	23	254	11397	55831	\N	47.674156000000004	Ростовская область, Цимлянский район, Красноярское сельское поселение, п.Дубравный, Садовая, 1		0101000020E6100000702711E15FFE44407B336ABE4AD64740
76017	2	23	254	56731	55876	\N	47.871199690735502	Ростовская область, Цимлянский район, Калининское сельское поселение, х.Антонов, Центральная, 17	Россия, Ростовская область, Цимлянский район, хутор Антонов	0101000020E610000091990B5C1E1345403A234A7B83EF4740
75981	2	23	238	56656	55344	\N	46.514498120026303	Ростовская область, Целинский район, поселок Юловский, ул. Транспортная, д.9	Россия, Ростовская область, Целинский район	0101000020E61000004DF564FED17D4440C0ED0912DB414740
77726	2	23	238	9482	40956	\N	46.532411000000003	Ростовская область, Целинский район, поселок Целина, ул. Степная, д.13		0101000020E6100000AAD5575705844440ED832C0B26444740
75965	2	23	238	9482	55343	\N	46.533006952274	Ростовская область, Целинский район, поселок Целина адрес помещения для голосования: ул.Советская, д.10, адрес УИК: ул. Советская, д.17	Россия, Ростовская область, Целинский район, поселок Целина	0101000020E6100000202A8D98D983444000C5C89239444740
75963	2	23	238	9482	40227	\N	46.532411000000003	Ростовская область, Целинский район, поселок Целина, ул. Механизаторов, 38А		0101000020E6100000AAD5575705844440ED832C0B26444740
75966	2	23	238	9482	40058	\N	46.532411000000003	Ростовская область, Целинский район, поселок Целина, ул. Западная, д.61		0101000020E6100000AAD5575705844440ED832C0B26444740
75989	2	23	238	9482	41112	\N	46.532411000000003	Ростовская область, Целинский район, поселок Целина, ул. 3-я линия, д.117		0101000020E6100000AAD5575705844440ED832C0B26444740
75987	2	23	238	56786	55937	\N	46.694299629605801	Ростовская область, Целинский район, село Хлеборобное адрес помещения для голосования: ул.Советская, д.17, адрес УИК: ул. Ленина, д.55	Россия, Ростовская область, Целинский район, село Хлеборобное	0101000020E6100000AB7B6473D572444070CE88D2DE584740
75988	2	23	238	56764	55912	\N	46.681640187044501	Ростовская область, Целинский район, село Хлебодарное адрес помещения для голосования: ул.Центральная, д.2/а, адрес УИК: ул. Центральная, д.1	Россия, Ростовская область, Целинский район, село Хлебодарное	0101000020E61000002E71E481C86A44409ED2C1FA3F574740
75979	2	23	238	10255	39965	\N	46.625647000000001	Ростовская область, Целинский район, село Степное, ул. Центральная, д.50		0101000020E61000007E1CCD919587444096EB6D3315504740
75973	2	23	238	9949	56267	\N	46.487848999999997	Ростовская область, Целинский район, хутор Старченский, ул. Октябрьская, д.9		0101000020E61000006ABC749318724440723106D6713E4740
75961	2	23	238	9270	55715	\N	46.356988000000001	Ростовская область, Целинский район, село Средний Егорлык, ул.Школьная, д.4		0101000020E61000002D05A4FD0F684440408864C8B12D4740
75958	2	23	238	9270	55713	\N	46.356988000000001	Ростовская область, Целинский район, село Средний Егорлык, ул. Молодёжная, д.16		0101000020E61000002D05A4FD0F684440408864C8B12D4740
75976	2	23	238	56728	55872	\N	46.419132477059897	Ростовская область, Целинский район, станица Сладкая Балка адрес помещения для голосования: ул.Центральная, д.62, адрес УИК: ул. Центральная, д.61	Россия, Ростовская область, Целинский район, станица Сладкая Балка	0101000020E6100000A4C343183F874440815A0C1EA6354740
75969	2	23	238	9727	55533	\N	46.539968000000002	Ростовская область, Целинский район, хутор Северный, ул. Мира, д.177-Г		0101000020E61000000F9D9E77637D44407A71E2AB1D454740
75971	2	23	238	9884	56272	\N	46.490125999999997	Ростовская область, Целинский район, хутор Свободный,  ул. Зеленая, д.40А		0101000020E610000000750305DE814440AB75E272BC3E4740
75982	2	23	238	10405	56284	\N	46.742682000000002	Ростовская область, Целинский район, хутор Рассвет, ул. Новая, д.2/б		0101000020E6100000F1811DFF059E4440F8A92A34105F4740
75986	2	23	238	10597	55597	\N	46.744553000000003	Ростовская область, Целинский район, село Плодородное, ул. Гагарина, д.83		0101000020E610000006F2ECF2AD8D4440C19140834D5F4740
75975	2	23	238	56950	56490	\N	46.440983000000003	Ростовская область, Целинский район, хутор Первомайский адрес помещения для голосования: ул.Центральная, д.25, адрес УИК: ул. Центральная, д.18		0101000020E61000009C1551137D6A4440C68B852172384740
75984	2	23	238	10505	40229	\N	46.84104	Ростовская область, Целинский район, село Ольшанка, ул. Торговая, д.4		0101000020E6100000E695EB6D337944405D50DF32A76B4740
77776	2	23	238	948	55799	\N	46.541425447291999	Ростовская область, Целинский район, поселок Новая Целина, ул. Макаренко, д.2	Россия, Ростовская область, Целинский район, поселок Новая Целина	0101000020E6100000FDDD3B6A4C8444404F1E166A4D454740
75967	2	23	238	948	40228	\N	46.542906000000002	Ростовская область, Целинский район, поселок Новая Целина, ул. Ленина, д.5		0101000020E6100000FB75A73B4F844440AE669DF17D454740
75983	2	23	238	10500	55593	\N	46.705047999999998	Ростовская область, Целинский район, село Михайловка, ул. Крупской, д.14		0101000020E610000026AC8DB1138044401B0E4B033F5A4740
75977	2	23	238	10189	55534	\N	46.406436999999997	Ростовская область, Целинский район, село Лопанка, ул. Молодежная, д.2/а		0101000020E6100000A69C2FF65E7C44403271AB2006344740
75978	2	23	238	10189	55724	\N	46.412017823987199	Ростовская область, Целинский район, село Лопанка, ул. Красная, д.1	Россия, Ростовская область, Целинский район, село Лопанка	0101000020E6100000D1E80E62677C444082AE7D01BD344740
77777	2	23	238	996	56365	\N	46.581037999999999	Ростовская область, Целинский район, хутор Красный Юг, ул. Виноградная, д.4		0101000020E61000008A01124DA07C4440DBDD03745F4A4740
75980	2	23	238	10339	55830	\N	46.504067936428498	Ростовская область, Целинский район, поселок Коренной, ул. Абрикосовая, д.5	Россия, Ростовская область, Целинский район, поселок Коренной	0101000020E6100000EEB25F77BA8F4440E57ADB4C85404740
75985	2	23	238	10564	55829	\N	46.834499999999998	Ростовская область, Целинский район, село Журавлевка, ул. Центральная, д.80		0101000020E610000022AB5B3D278B4440894160E5D06A4740
75972	2	23	238	9938	9726	\N	46.482094593275697	Ростовская область, Целинский район, поселок Вороново, ул. Гусева, д.15	Россия, Ростовская область, Целинский район, поселок Вороново	0101000020E61000005743E21E4B7744405648F949B53D4740
75974	2	23	238	9999	56018	\N	46.645226000000001	Ростовская область, Целинский район, хутор Васильевка, пер. Школьный, д.2		0101000020E6100000FC56EBC4E56C4440B343FCC396524740
75615	2	23	221	24678	56334	\N	47.755290000000002	Ростовская область, Усть-Донецкий район, Нижнекундрюченское сельское поселение, хутор Черни, Центральная, 26		0101000020E610000030F5F3A622734440787FBC57ADE04740
75608	2	23	221	2399	55156	\N	47.642864000000003	Ростовская область, Усть-Донецкий район, Усть-Донецкое городское поселение, рабочий поселок Усть-Донецкий, переулок Почтовый,11		0101000020E6100000DA0242EBE16F44404CE3175E49D24740
75609	2	23	221	2399	40118	\N	47.642864000000003	Ростовская область, Усть-Донецкий район, Усть-Донецкое городское поселение, рабочий поселок Усть-Донецкий, Ленина, 10		0101000020E6100000DA0242EBE16F44404CE3175E49D24740
75607	2	23	221	2399	40117	\N	47.642864000000003	Ростовская область, Усть-Донецкий район, Усть-Донецкое городское поселение, рабочий поселок Усть-Донецкий, Донецкая, 3		0101000020E6100000DA0242EBE16F44404CE3175E49D24740
75620	2	23	221	24899	40212	\N	47.822887000000001	Ростовская область, Усть-Донецкий район, Нижнекундрюченское сельское поселение, станица Усть-Быстрянская, Центральная, 29		0101000020E61000005053CBD6FA844440DBA6785C54E94740
75619	2	23	221	24850	56218	\N	47.830691000000002	Ростовская область, Усть-Донецкий район, Верхнекундрюченское сельское поселение, хутор Тереховский, Калинина, 3		0101000020E61000001E19ABCDFF674440700A2B1554EA4740
75602	2	23	221	2345	39910	\N	47.542377999999999	Ростовская область, Усть-Донецкий район, Раздорское сельское поселение, станица Раздорская, ул.Ленина,29А		0101000020E6100000E4A1EF6E65534440F2086EA46CC54740
75601	2	23	221	23972	39709	\N	47.514847000000003	Ростовская область, Усть-Донецкий район, Пухляковское сельское поселение, хутор Пухляковский, Центральная, 31		0101000020E61000006612F5824F4B4440CCB8A981E6C14740
75604	2	23	221	24116	55999	\N	47.640586999999996	Ростовская область, Усть-Донецкий район, Крымское сельское поселение, хутор Ольховский, Центральная, 17		0101000020E6100000EB387EA8345A4440129F3BC1FED14740
75614	2	23	221	24575	39911	\N	47.750250000000001	Ростовская область, Усть-Донецкий район, Нижнекундрюченское сельское поселение, станица Нижнекундрюченская, Советская, 5		0101000020E61000004FB0FF3A3779444079E9263108E04740
75617	2	23	221	24766	56335	\N	47.799177999999998	Ростовская область, Усть-Донецкий район, Верхнекундрюченское сельское поселение, хутор Мостовой, Донская, 1		0101000020E61000009E60FF756E68444062D7F6764BE64740
75600	2	23	221	23858	40578	\N	47.477387	Ростовская область, Усть-Донецкий район, Мелиховское сельское поселение, станица Мелиховская, Мерзлякова, 39а		0101000020E6100000FFCEF6E80D3F44408D4468041BBD4740
75599	2	23	221	23858	40211	\N	47.477387	Ростовская область, Усть-Донецкий район, Мелиховское сельское поселение, станица Мелиховская, Интернациональная, 72а		0101000020E6100000FFCEF6E80D3F44408D4468041BBD4740
75606	2	23	221	24212	55650	\N	47.668646000000003	Ростовская область, Усть-Донецкий район, Крымское сельское поселение, хутор Крымский, Центральная, 60		0101000020E610000021E692AAED624440F54C2F3196D54740
75603	2	23	221	24071	32952	\N	47.590505999999998	Ростовская область, Усть-Донецкий район, Раздорское сельское поселение, хутор Коныгин, Шубина, 10		0101000020E6100000F6CE68AB92584440BF0B5BB395CB4740
75598	2	23	221	23800	55636	\N	47.510007999999999	Ростовская область, Усть-Донецкий район, Мелиховское сельское поселение, поселок Керчикский, Виноградная, 3а		0101000020E610000091B932A8363A4440645930F147C14740
75597	2	23	221	56858	56384	\N	47.536380000000001	Ростовская область, Усть-Донецкий район, Мелиховское сельское поселение, х.Исаевский, Центральная, 37	Россия, Ростовская область, Усть-Донецкий район, хутор Исаевский	0101000020E6100000E1455F419A3B44403F1D8F19A8C44740
75610	2	23	221	24379	56144	\N	47.657285999999999	"Ростовская область, Усть-Донецкий район, Крымское сельское поселение, хутор Ещеулов, Гагарина, МУК ""Культурный центр Крымского """		0101000020E61000001A34F44F70694440300F99F221D44740
75618	2	23	221	24823	56340	\N	47.827654000000003	Ростовская область, Усть-Донецкий район, Верхнекундрюченское сельское поселение, хутор Евсеевский, Школьная, 8		0101000020E6100000083D9B559F654440A933F790F0E94740
75605	2	23	221	24145	56080	\N	47.653534999999998	Ростовская область, Усть-Донецкий район, Крымское сельское поселение, хутор Виноградный, Большая Садовая, 17		0101000020E6100000A81C93C5FD5B44404BE5ED08A7D34740
75616	2	23	221	24693	55655	\N	47.778553000000002	Ростовская область, Усть-Донецкий район, Верхнекундрюченское сельское поселение, станица Верхнекундрюченская, Центральная, 29		0101000020E610000081069B3A8F6C4440F299EC9FA7E34740
75613	2	23	221	2462	56336	\N	47.680774999999997	Ростовская область, Усть-Донецкий район, Апаринское сельское поселение, хутор Бронницкий, ул.Толстого,9		0101000020E6100000B3412619397744409A779CA223D74740
75611	2	23	221	24481	41093	\N	47.661692000000002	Ростовская область, Усть-Донецкий район, Апаринское сельское поселение, хутор Апаринский, Комсомольская, 3		0101000020E6100000FC71FBE5937544402E03CE52B2D44740
76395	2	23	1878	56898	56432	\N	48.587914452665103	Ростовская область, Тарасовский район, сл. Шарпаевка, ул. Ленина, д. 43 а		0101000020E6100000D3F6AFAC347F4440266E15C4404B4840
77774	2	23	221	24481	56577	\N	47.661692000000002	Ростовская область, Усть-Донецкий район, х. Апаринский, ул. Гагарина,111	Россия, Ростовская область, Усть-Донецкий район, хутор Апаринский	0101000020E6100000FC71FBE5937544402E03CE52B2D44740
77721	2	23	76	30583	56137	\N	47.885548999999997	Ростовская область, Тацинский район, хутор Чумаков, Советская, 29		0101000020E61000007730629F00B04440B4006DAB59F14740
76451	2	23	76	515	41171	\N	48.241307999999997	Ростовская область, Тацинский район, поселок Углегорский, Школьный переулок, 2		0101000020E610000098A1F14410A14440AF21382EE31E4840
76442	2	23	76	91	41170	\N	48.195028000000001	Ростовская область, Тацинский район, станица Тацинская, пл.Калинина, д.52А		0101000020E6100000715AF0A2AFA24440F3E670ADF6184840
76445	2	23	76	91	40144	\N	48.195028000000001	Ростовская область, Тацинский район, станица Тацинская, Соревнования переулок, 9		0101000020E6100000715AF0A2AFA24440F3E670ADF6184840
76443	2	23	76	91	39988	\N	48.193826524800102	Ростовская область, Тацинский район, станица Тацинская, Пионерский переулок, 23	Россия, Ростовская область, Тацинский район, станица Тацинская	0101000020E6100000EACE13CFD9A24440780AB952CF184840
77616	2	23	76	91	55239	\N	48.195028000000001	Ростовская область, Тацинский район, станица Тацинская, Октябрьская, 61		0101000020E6100000715AF0A2AFA24440F3E670ADF6184840
76440	2	23	76	91	55239	\N	48.195028000000001	Ростовская область, Тацинский район, станица Тацинская, Октябрьская, 131		0101000020E6100000715AF0A2AFA24440F3E670ADF6184840
76444	2	23	76	91	55567	\N	48.195028000000001	Ростовская область, Тацинский район, станица Тацинская, Ленина, 78		0101000020E6100000715AF0A2AFA24440F3E670ADF6184840
76459	2	23	76	997	55569	\N	48.412725999999999	Ростовская область, Тацинский район, станица Скосырская, Школьная, 5		0101000020E61000004D486B0C3AA74440BD1AA034D4344840
76454	2	23	76	708	56231	\N	48.285207999999997	Ростовская область, Тацинский район, хутор Потапов, Школьный переулок, 7		0101000020E61000005AD5928E729444405E471CB281244840
76466	2	23	76	1413	55740	\N	48.118087000000003	Ростовская область, Тацинский район, поселок Новосуховый, Административная, 8		0101000020E6100000965984622BB44440988A8D791D0F4840
76469	2	23	76	1575	56201	\N	47.912908000000002	Ростовская область, Тацинский район, хутор Новороссошанский, Молодежная, 1		0101000020E61000005FB7088CF5AD4440DE205A2BDAF44740
76458	2	23	76	947	56232	\N	48.401989999999998	Ростовская область, Тацинский район, хутор Надежевка, Заводская, 43		0101000020E61000002B4B7496599E4440D6A8876874334840
76456	2	23	76	762	40564	\N	48.239040000000003	Ростовская область, Тацинский район, хутор Михайлов, Ленина, 126		0101000020E6100000D0D03FC1C5964440CA37DBDC981E4840
76455	2	23	76	762	55574	\N	48.239040000000003	Ростовская область, Тацинский район, хутор Михайлов, Клубная, 11		0101000020E6100000D0D03FC1C5964440CA37DBDC981E4840
76452	2	23	76	588	55958	\N	48.316673999999999	Ростовская область, Тацинский район, хутор Маслов, Школьная, 12		0101000020E6100000AA7F10C9909344402BBF0CC688284840
76463	2	23	76	1246	56350	\N	48.301333	Ростовская область, Тацинский район, хутор Луговой, Молодежная, 1		0101000020E61000005A9C31CC09B44440501A6A1492264840
76457	2	23	76	878	55676	\N	48.358491000000001	Ростовская область, Тацинский район, хутор Крюков, Ленина, 3а		0101000020E610000055BE6724429F444086747808E32D4840
76465	2	23	76	1348	55563	\N	48.141041000000001	Ростовская область, Тацинский район, хутор Крылов, Центральная, 6		0101000020E610000057CC086F0FC444409432A9A10D124840
76464	2	23	76	1307	55737	\N	48.244332999999997	Ростовская область, Тацинский район, хутор Ковылкин, Мира, 33		0101000020E61000003D0CAD4ECEBC4440B22AC24D461F4840
76460	2	23	76	1073	55777	\N	48.462339	Ростовская область, Тацинский район, хутор Качалин, Харченко, 44		0101000020E61000009FE74F1BD5B344402A55A2EC2D3B4840
76453	2	23	76	641	56229	\N	48.282708	Ростовская область, Тацинский район, хутор Карпово-Обрывский, Розы Люксембург, 1а		0101000020E6100000350708E6E8914440A62897C62F244840
76446	2	23	76	194	55734	\N	48.084012000000001	Ростовская область, Тацинский район, хутор Исаев, Южный переулок, 8		0101000020E610000048FC8A355C8E44405C3CBCE7C00A4840
76468	2	23	76	1535	55581	\N	47.987343000000003	Ростовская область, Тацинский район, хутор Зазерский, Центральная, 61		0101000020E61000000936AE7FD7C344409F77634161FE4740
76447	2	23	76	56616	55160	\N	48.1697039617559	Ростовская область, Тацинский район, поселок Жирнов, П. Морозова, 2	Россия, Ростовская область, Тацинский район, ПГТ Жирнов	0101000020E6100000317898F6CD8F44400D0055DCB8154840
76449	2	23	76	56616	55305	\N	48.167117446482898	Ростовская область, Тацинский район, поселок Жирнов, Островского, 5		0101000020E6100000F7AB00DF6D90444085CD001764154840
76448	2	23	76	54931	55432	\N	48.167949543338501	Ростовская область, Тацинский район, поселок Жирнов, Театральная, 9	Россия, Ростовская область, Тацинский район, ПГТ Жирнов	0101000020E6100000DB85E63A8D9044407DAEB6627F154840
76471	2	23	76	1696	55562	\N	48.042980447086599	Ростовская область, Тацинский район, станица Ермаковская, Молодежная, 4	Россия, Ростовская область, Тацинский район, станица Ермаковская	0101000020E6100000776A2E3718A44440E8305F5E80054840
76462	2	23	76	1186	55682	\N	48.392065158593901	Ростовская область, Тацинский район, хутор Верхнеобливский, Советская, 55	Россия, Ростовская область, Тацинский район, хутор Верхнеобливский	0101000020E6100000D0ED258DD1BC44400074982F2F324840
76470	2	23	76	1650	56046	\N	48.041190999999998	Ростовская область, Тацинский район, хутор Верхнекольцов, Мира, 28		0101000020E6100000D7DF12807FAA4440DCF126BF45054840
77670	2	23	76	458	39936	\N	48.199773	Ростовская область, Тацинский район, поселок Быстрогорский, Космонавтов, 1		0101000020E61000007898F6CDFD914440D9CF622992194840
76450	2	23	76	458	41168	\N	48.199773	Ростовская область, Тацинский район, поселок Быстрогорский, Волгодонская, 5а		0101000020E61000007898F6CDFD914440D9CF622992194840
76428	2	23	1878	57016	56567	\N	48.649999999999999	Ростовская область, Тарасовский район, х. Чеботовка, ул. Центральная, д. 30	Россия, Ростовская область, Тарасовский район, хутор Чеботовка	0101000020E61000000890A16307FF43403333333333534840
76436	2	23	1878	56875	56403	\N	48.795081879450599	Ростовская область, Тарасовский район, х. Ушаковка, ул. Заречная, д. 40	Россия, Ростовская область, Тарасовский район, хутор Ушаковка	0101000020E610000006651A4D2EE64340B3D1393FC5654840
76408	2	23	1878	30874	40260	\N	48.738740999999997	Ростовская область, Тарасовский район, п. Тарасовский, ул. Степная, д. 136		0101000020E6100000E564E256412E44406F9BA9108F5E4840
76411	2	23	1878	30874	40093	\N	48.738740999999997	Ростовская область, Тарасовский район, п. Тарасовский, ул. Победы, 32		0101000020E6100000E564E256412E44406F9BA9108F5E4840
76409	2	23	1878	30874	39987	\N	48.737605598353397	Ростовская область, Тарасовский район, п. Тарасовский, ул. Островского, д. 63	Россия, Ростовская область, Тарасовский район, поселок Тарасовский	0101000020E61000005839B4C8762E4440ACAA97DF695E4840
76413	2	23	1878	30874	55779	\N	48.738740999999997	Ростовская область, Тарасовский район, п. Тарасовский, ул. Мира, д. 29		0101000020E6100000E564E256412E44406F9BA9108F5E4840
76415	2	23	1878	30874	55620	\N	48.738740999999997	Ростовская область, Тарасовский район, п. Тарасовский, ул. Ленина, д. 79		0101000020E6100000E564E256412E44406F9BA9108F5E4840
76414	2	23	1878	30874	55620	\N	48.738740999999997	Ростовская область, Тарасовский район, п. Тарасовский, ул. Ленина, д. 100		0101000020E6100000E564E256412E44406F9BA9108F5E4840
76412	2	23	1878	30874	55621	\N	48.738740999999997	Ростовская область, Тарасовский район, п. Тарасовский, ул. Грибоедова, д. 5		0101000020E6100000E564E256412E44406F9BA9108F5E4840
76393	2	23	1878	56912	56445	\N	48.682881000000002	Ростовская область, Тарасовский район, х. Сергеевка, ул. Дорожная, д. 30	Россия, Ростовская область, Тарасовский район, хутор Сергеевка	0101000020E610000055BE672442794440A70705A568574840
76405	2	23	1878	56947	56487	\N	48.755323968032499	Ростовская область, Тарасовский район, х. Россошь, ул. Советская, д. 10	Россия, Ростовская область, Тарасовский район, хутор Россошь	0101000020E610000018096D399740444024F1F274AE604840
76435	2	23	1878	56864	56391	\N	48.763340744863299	Ростовская область, Тарасовский район, х. Прогной, ул. Южная, д. 68	Россия, Ростовская область, Тарасовский район, хутор Прогной	0101000020E61000002DEA93DC61EB434014596B28B5614840
76398	2	23	1878	56826	56224	\N	48.652914514556898	Ростовская область, Тарасовский район, х. Новоалексеевка, ул. Новоалексеевская, д. 27	Россия, Ростовская область, Тарасовский район, хутор Новоалексеевка	0101000020E610000059DB148F8B5A4440AF08FEB792534840
76407	2	23	1878	30769	56204	\N	48.729529999999997	Ростовская область, Тарасовский район, х. Нижняя Тарасовка, ул. Школьная, д. 22	Россия, Ростовская область, Тарасовский район, хутор Нижняя Тарасовка	0101000020E610000038F581E49D294440B6B9313D615D4840
76426	2	23	1878	56807	56070	\N	48.698924919127101	Ростовская область, Тарасовский район, х. Нижнемитякин, ул. Правобережная, д. 122	Россия, Ростовская область, Тарасовский район, хутор Нижнемитякин	0101000020E6100000F20A444FCA064440ACADD85F76594840
76425	2	23	1878	56807	56070	\N	48.695913584609201	Ростовская область, Тарасовский район, х. Нижнемитякин, ул. Правобережная, д. 65	Россия, Ростовская область, Тарасовский район, хутор Нижнемитякин	0101000020E61000002043C70E2A0544400E6ABFB513594840
76427	2	23	1878	56807	56462	\N	48.698808	Ростовская область, Тарасовский район, х. Нижнемитякин, ул. Левобережная, д. 148		0101000020E6100000BBB54C86E30544407217618A72594840
76389	2	23	1878	56920	56453	\N	48.784511999999999	Ростовская область, Тарасовский район, х. Нижнемакеевский, ул. Садовая, д. 40		0101000020E6100000D4BA0D6ABF7B4440E7A8A3E36A644840
76438	2	23	1878	56782	55933	\N	48.753786656043403	Ростовская область, Тарасовский район, х. Можаевка, ул. Центральная, д. 66	Россия, Ростовская область, Тарасовский район, хутор Можаевка	0101000020E61000006E4F90D8EEE043403293A8177C604840
76431	2	23	1878	30231	55776	\N	48.612516999999997	Ростовская область, Тарасовский район, ст. Митякинская, ул. Менжинского, д. 70		0101000020E6100000A0C552245FE343403C9F01F5664E4840
77714	2	23	1878	30231	55603	\N	48.612516999999997	Ростовская область, Тарасовский район, ст. Митякинская, пер. Лесхозный, д. 17		0101000020E6100000A0C552245FE343403C9F01F5664E4840
76400	2	23	1878	56829	56235	\N	48.658825999999998	Ростовская область, Тарасовский район, х. Мартыновка, пер. Советский, д. 14	Россия, Ростовская область, Тарасовский район, хутор Мартыновка	0101000020E6100000831953B0C651444093E00D6954544840
76419	2	23	1878	31381	56351	\N	48.658099999999997	Ростовская область, Тарасовский район, п. Малое Полесье, ул. Центральная, д. 20		0101000020E6100000ADFC3218231C4440B1BFEC9E3C544840
76399	2	23	1878	57001	56549	\N	48.686752958032798	Ростовская область, Тарасовский район, сл. Курно-Липовка, ул. Молодежная, д. 2	Россия, Ростовская область, Тарасовский район, слобода Курно-Липовка	0101000020E6100000643C4A253C53444007B7B585E7574840
76422	2	23	1878	56850	56361	\N	48.816730048099501	Ростовская область, Тарасовский район, х. Красновка, ул. 13 Героев, д. 39	Россия, Ростовская область, Тарасовский район, хутор Красновка	0101000020E6100000C85BAE7E6C0C4440BFD4CF9B8A684840
76417	2	23	1878	56872	56400	\N	48.685200999999999	Ростовская область, Тарасовский район, х. Каюковка, ул. Центральная, д. 47	Россия, Ростовская область, Тарасовский район, хутор Каюковка	0101000020E610000009FB761211284440DF1797AAB4574840
76397	2	23	1878	30284	56097	\N	48.647387000000002	Ростовская область, Тарасовский район, п. Изумрудный, ул. Южная, д. 11		0101000020E6100000B5503239B5634440836DC493DD524840
45933	2	20	\N	6023	23372	\N	44.735227000000002	город Новороссийск, ул.Видова, д. 182, телефон: 26-20-35		0101000020E6100000F98381E7DEDD42406F1118EB1B5E4640
76429	2	23	1878	56738	55885	\N	48.615774976557503	Ростовская область, Тарасовский район, х. Зеленовка, ул. Центральная, д. 55	Россия, Ростовская область, Тарасовский район, хутор Зеленовка	0101000020E610000042EA76F695FD4340E25817B7D14E4840
76391	2	23	1878	56729	55873	\N	48.714723999999997	Ростовская область, Тарасовский район, сл. Ефремово-Степановка, ул. Новая, д. 19		0101000020E61000006D57E883656A444049D576137C5B4840
76402	2	23	1878	57010	56558	\N	48.586181000000003	Ростовская область, Тарасовский район, х. Ерофеевка, ул. Школьная, д. 15	Россия, Ростовская область, Тарасовский район, хутор Ерофеевка	0101000020E6100000698A00A777494440AF44A0FA074B4840
76439	2	23	1878	56889	56418	\N	48.688118740105701	Ростовская область, Тарасовский район, х. Елань, ул. Круглая, д. 44	Россия, Ростовская область, Тарасовский район, хутор Елань	0101000020E6100000C763062AE3E34340CC608C4814584840
76401	2	23	1878	56867	56395	\N	48.632252999999999	Ростовская область, Тарасовский район, х. Егоро-Калитвенский, ул. Ленина, д. 19	Россия, Ростовская область, Тарасовский район, хутор Егоро-Калитвенский	0101000020E6100000988A8D791D4B444021E692AAED504840
76418	2	23	1878	56769	55917	\N	48.627344655641998	Ростовская область, Тарасовский район, сл. Дячкино, ул. Мира, д. 16	Россия, Ростовская область, Тарасовский район, слобода Дячкино	0101000020E6100000CC9BC3B5DA274440912749D74C504840
76432	2	23	1878	56795	56477	\N	48.641916000000002	Ростовская область, Тарасовский район, х. Дубы, ул. Центральная, д. 42	Россия, Ростовская область, Тарасовский район, хутор Дубы	0101000020E6100000B2BE81C98DEE4340BB63B14D2A524840
76433	2	23	1878	56795	55953	\N	48.641641470695703	Ростовская область, Тарасовский район, х. Дубы, ул. Дубовская, д. 26	Россия, Ростовская область, Тарасовский район, хутор Дубы	0101000020E6100000A8565F5D15EE4340E962D34A21524840
76406	2	23	1878	30760	55731	\N	48.735436999999997	Ростовская область, Тарасовский район, п. Донская Нива, ул. Центральная, д. 1 б		0101000020E610000077DCF0BBE938444059A2B3CC225E4840
76437	2	23	1878	32235	55954	\N	48.823990000000002	Ростовская область, Тарасовский район, п. Деркул, ул. Школьная, д. 7 а		0101000020E6100000A0F99CBB5DE74340931D1B8178694840
76404	2	23	1878	56886	56415	\N	48.637871300960903	Ростовская область, Тарасовский район, х. Грачи, ул. Степная, 79	Россия, Ростовская область, Тарасовский район, хутор Грачи	0101000020E6100000AAB69BE09B4444408D08C6C1A5514840
76434	2	23	1878	32088	56314	\N	48.7062351074606	Ростовская область, Тарасовский район, п. Войково, ул. Интернациональная, д. 7	Россия, Ростовская область, Тарасовский район, поселок Войково	0101000020E610000007616EF772ED4340312592E8655A4840
76420	2	23	1878	31470	56107	\N	48.746102	Ростовская область, Тарасовский район, п. Весенний, ул. 13 Героев, д. 22		0101000020E610000051BF0B5BB319444077BD3445805F4840
76424	2	23	1878	31576	56077	\N	48.761764999999997	Ростовская область, Тарасовский район, х. Верхний Митякин, ул. Центральная, д. 136		0101000020E6100000F06C8FDE700D4440641EF98381614840
76423	2	23	1878	31576	56077	\N	48.761764999999997	Ростовская область, Тарасовский район, х. Верхний Митякин, ул. Центральная, д. 39	Россия, Ростовская область, Тарасовский район, хутор Верхний Митякин	0101000020E6100000F06C8FDE700D4440641EF98381614840
76430	2	23	1878	31887	56228	\N	48.554817	Ростовская область, Тарасовский район, х. Верхние Грачики, ул. Лесная, д. 3	Россия, Ростовская область, Тарасовский район, хутор Верхние Грачики	0101000020E61000001A4E999B6FFC4340E621533E04474840
76421	2	23	1878	31501	56226	\N	48.781004000000003	Ростовская область, Тарасовский район, п. Верхнетарасовский, ул. Школьная, д. 10		0101000020E6100000519FE40E9B244440C90567F0F7634840
76416	2	23	1878	56680	55677	\N	48.711858413261098	Ростовская область, Тарасовский район, х. Васильевка, ул. Придорожная, д. 8	Россия, Ростовская область, Тарасовский район, хутор Васильевка	0101000020E61000006D382C0DFC2A4440AFB2B6291E5B4840
76388	2	23	1878	54932	40560	\N	48.656022728586699	Ростовская область, Тарасовский район, сл. Большинка, ул. Башмакова И.В, д. 1 а	Россия, Ростовская область, Тарасовский район, слобода Большинка	0101000020E6100000B131AF230E8B44403F36C98FF8534840
76390	2	23	1878	29953	56063	\N	48.794508	Ростовская область, Тарасовский район, сл. Александровка, ул. Молодежная, д. 4		0101000020E61000007D3ECA880B6E444087342A70B2654840
76386	2	23	1373	29775	56200	\N	49.044991747101001	Ростовская область, Советский район, село Чистяково, улица Гагарина, 6	Россия, Ростовская область, Советский район, село Чистяково	0101000020E610000072FBE59315074540734A404CC2854840
76383	2	23	1373	29615	55556	\N	48.900252999999999	Ростовская область, Советский район, поселок Чирский, улица Дорожная, 19		0101000020E61000008386FE092E1645401D90847D3B734840
76385	2	23	1373	29694	56065	\N	48.833401305384101	Ростовская область, Советский район, хутор Усть-Грязновский, улица Речная, 11	Россия, Ростовская область, Советский район, хутор Усть-Грязновский	0101000020E6100000A0A70183A40D454013BA4BE2AC6A4840
75419	2	23	1373	14946	56210	\N	49.047491999999998	Ростовская область, Советский район, хутор Ставиднянский, улица Центральная, 36		0101000020E6100000095053CBD6FE44402B69C53714864840
76378	2	23	1373	29416	39775	\N	49.007955000000003	Ростовская область, Советский район, станица Советская, улица Горева, 7		0101000020E610000005A3923A010F45407B6B60AB04814840
75418	2	23	1373	14910	56074	\N	49.015146000000001	Ростовская область, Советский район, хутор Русаков, улица Мартыненко, 20		0101000020E6100000EBE1CB44111445402655DB4DF0814840
76387	2	23	1373	29828	56045	\N	49.122321999999997	Ростовская область, Советский район, хутор Пичугин, улица Лесная, 23		0101000020E6100000CA880B40A30A454068CA4E3FA88F4840
76381	2	23	1373	29527	56349	\N	49.007139000000002	Ростовская область, Советский район, слобода Петрово, улица Любимая, 27		0101000020E61000006A882AFC192C454059C345EEE9804840
76379	2	23	1373	29450	56348	\N	48.986669999999997	Ростовская область, Советский район, хутор Парамонов, улица Молодежная, 22		0101000020E6100000CB2BD7DB66004540DFF8DA334B7E4840
76384	2	23	1373	29683	56053	\N	48.872280000000003	Ростовская область, Советский район, хутор Осиновский, улица Школьная, 4		0101000020E61000008461C092AB1E45403A7AFCDEA66F4840
76382	2	23	1373	29597	56062	\N	48.989708999999998	Ростовская область, Советский район, хутор Новорябухин, улица Центральная, 34		0101000020E6100000C4EA8F300C26454047C7D5C8AE7E4840
77735	2	23	1373	31309	56005	\N	48.890338	Ростовская область, Советский район, поселок Малые Озера, улица Озерная, 16		0101000020E610000034492C29772145406A317898F6714840
76380	2	23	1373	29511	55775	\N	48.994233951297602	Ростовская область, Советский район, слобода Калач-Куртлак, улица Школьная, 2	Россия, Ростовская область, Советский район, слобода Калач-Куртлак	0101000020E6100000A0168387693745401F49490F437F4840
75582	2	23	264	56677	55633	\N	47.376497235644898	Ростовская область, Семикаракорский район, х. Шаминка, пер. Школьный, 2/1	Россия, Ростовская область, Семикаракорский район, хутор Шаминка	0101000020E6100000471D1D57238B44406405BF0D31B04740
75573	2	23	264	56643	55298	\N	47.564503212808098	Ростовская область, Семикаракорский район, х. Чебачий, ул. Гагарина, 8/1	Россия, Ростовская область, Семикаракорский район, хутор Чебачий	0101000020E6100000FA6184F06875444038BF61A241C84740
75581	2	23	264	54814	39707	\N	47.372820875179102	Ростовская область, Семикаракорский район, х. Топилин, пер. Советский, 10/1	Россия, Ростовская область, Семикаракорский район, хутор Топилин	0101000020E6100000DC4603780B9244408A213999B8AF4740
75580	2	23	264	56701	55842	\N	47.523104264276498	Ростовская область, Семикаракорский район, х.Титов, ул. Пионерская, 36	Россия, Ростовская область, Семикаракорский район, хутор Титов	0101000020E610000032AD4D637BAF444011346612F5C24740
75593	2	23	264	56658	55346	\N	47.426161	Ростовская область, Семикаракорский район, х.Сусат, ул. Молодежная, 48В	Россия, Ростовская область, Семикаракорский район, хутор Сусат	0101000020E610000033A836381159444053EA92718CB64740
75583	2	23	264	56706	55848	\N	47.390047000000003	Ростовская область, Семикаракорский район, х. Страхов, ул. Гагарина, 60	Россия, Ростовская область, Семикаракорский район, хутор Страхов	0101000020E6100000C8B1F50CE18244409373620FEDB14740
75571	2	23	264	4374	56456	\N	47.561705000000003	Ростовская область, Семикаракорский район, х. Старая Станица, ул. Центральная, 11		0101000020E6100000DC4B1AA375664440F67F0EF3E5C74740
75596	2	23	264	56777	55925	\N	47.430651283288903	Ростовская область, Семикаракорский район, х.Слободской, ул. Мира, 25	Россия, Ростовская область, Семикаракорский район, хутор Слободской	0101000020E6100000FEF33460906A4440AE7E6C921FB74740
75567	2	23	264	1115	9658	\N	47.525629047499599	Ростовская область, Семикаракорский район, г. Семикаракорск, пр-кт Закруткина, 25/1	Россия, Ростовская область, Семикаракорский район, Семикаракорск	0101000020E6100000957CEC2E50684440236AA2CF47C34740
75566	2	23	264	1115	9658	\N	47.517489348565398	Ростовская область, Семикаракорский район, г. Семикаракорск, пр-кт Закруткина, 25	Россия, Ростовская область, Семикаракорский район, Семикаракорск	0101000020E6100000D009A1832E67444016855D143DC24740
75568	2	23	264	1115	55770	\N	47.522046000000003	Ростовская область, Семикаракорский район, г. Семикаракорск, ул. Серегина, 1		0101000020E6100000514B732B84674440FA804067D2C24740
77713	2	23	264	1115	39704	\N	47.517852755078501	Ростовская область, Семикаракорский район, г.Семикаракорск, ул. Ленина, 138	Россия, Ростовская область, Семикаракорский район, Семикаракорск	0101000020E61000009B8D9598676544405891D10149C24740
75564	2	23	264	1115	39704	\N	47.522046000000003	Ростовская область, Семикаракорский район, г. Семикаракорск, ул. Ленина, 129		0101000020E6100000514B732B84674440FA804067D2C24740
75562	2	23	264	1115	56215	\N	47.522046000000003	Ростовская область, Семикаракорский район, г. Семикаракорск, ул. Зеленая, 14		0101000020E6100000514B732B84674440FA804067D2C24740
75565	2	23	264	1115	41054	\N	47.522046000000003	Ростовская область, Семикаракорский район, г. Семикаракорск, ул. Авилова, 18		0101000020E6100000514B732B84674440FA804067D2C24740
75585	2	23	264	56888	56417	\N	47.312557618788802	Ростовская область, Семикаракорский район, х. Павлов, ул. Юрия Гагарина, 25	Россия, Ростовская область, Семикаракорский район, хутор Павлов	0101000020E610000075560BEC31934440350D8AE601A84740
75595	2	23	264	56909	56441	\N	47.439492000000001	Ростовская область, Семикаракорский район, х. Новоромановский, ул. Калинина, 23А	Россия, Ростовская область, Семикаракорский район, хутор Новоромановский	0101000020E61000009641B5C189644440446D1B4641B84740
75572	2	23	264	22637	41090	\N	47.565753999999998	Ростовская область, Семикаракорский район, ст. Новозолотовская, ул. Октябрьская, 50		0101000020E61000004628B682A679444064CA87A06AC84740
75590	2	23	264	2113	55525	\N	47.478726999999999	Ростовская область, Семикаракорский район, п. Нижний Саловск, ул. Тоговая, 14		0101000020E610000068976F7D58794440295B24ED46BD4740
75574	2	23	264	56664	55440	\N	47.5106455526684	Ростовская область, Семикаракорский район, х. Маломечетный, ул. Октябрьская, 18	Россия, Ростовская область, Семикаракорский район, хутор Маломечетный	0101000020E61000008FC70C54C68B4440A7EA1ED95CC14740
75586	2	23	264	56907	56439	\N	47.225259999999999	Ростовская область, Семикаракорский район, х.Лиманский, ул. Степная, 26	Россия, Ростовская область, Семикаракорский район, хутор Лиманский	0101000020E6100000F949B54FC7874440698CD651D59C4740
75662	2	23	461	2683	41055	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Свободы, 58		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75591	2	23	264	56693	55754	\N	47.410950403269503	Ростовская область, Семикаракорский район, ,х. Кузнецовка, ул. Ананченко, 15А	Россия, Ростовская область, Семикаракорский район, хутор Кузнецовка	0101000020E6100000F6285C8FC2794440462575029AB44740
75578	2	23	264	22878	55558	\N	47.485230000000001	Ростовская область, Семикаракорский район, п. Крымский, ул. Ленина, 28		0101000020E61000002E8ECA4DD4A44440E08442041CBE4740
75569	2	23	264	1693	39705	\N	47.579408000000001	Ростовская область, Семикаракорский район, ст. Кочетовская, ул. Студенческая, 28		0101000020E6100000BD395CAB3D6C44403885950A2ACA4740
75594	2	23	264	56890	56419	\N	47.441130999999999	Ростовская область, Семикаракорский район, х. Костылевка, ул. Ленина, 1 В	Россия, Ростовская область, Семикаракорский район, хутор Костылевка	0101000020E610000016359886E15B44403A2009FB76B84740
75587	2	23	264	57025	56579	\N	47.365541999999998	Ростовская область, Семикаракорский район, х.Кирсановка, ул. Школьная, 3		0101000020E6100000AF9811DE1E8044403FA88B14CAAE4740
75584	2	23	264	54909	40415	\N	47.330823481847702	Ростовская область, Семикаракорский район, х. Золотаревка, ул. Степана Здоровцева, 28а	Россия, Ростовская область, Семикаракорский район, хутор Золотаревка	0101000020E61000009087BEBB958B4440DFE1766858AA4740
75576	2	23	264	22800	55657	\N	47.478386	Ростовская область, Семикаракорский район, х. Зеленая Горка, ул. Пушкина, 3		0101000020E6100000B08F4E5DF99A4440A06EA0C03BBD4740
75579	2	23	264	2002	40576	\N	47.522015000000003	Ростовская область, Семикаракорский район, ст. Задоно-Кагальницкая, ул. 30 лет Победы, 63а		0101000020E610000094A12AA6D2A54440BF823463D1C24740
75577	2	23	264	56756	55903	\N	47.5148411742693	Ростовская область, Семикаракорский район,  х.Жуков, ул. Центральная, 7	Россия, Ростовская область, Семикаракорский район, хутор Жуков	0101000020E6100000EFE53E390A9A4440E9D1544FE6C14740
75575	2	23	264	56657	55345	\N	47.493705702220801	Ростовская область, Семикаракорский район, х. Вислый, ул. школьная, 23/1	Россия, Ростовская область, Семикаракорский район, хутор Вислый	0101000020E6100000215A2BDA1C93444064EB19C231BF4740
75589	2	23	264	2043	55634	\N	47.486545999999997	Ростовская область, Семикаракорский район, п.Вершинный, ул. Центральная, 2/1		0101000020E61000001CD0D2156C814440F3FFAA2347BE4740
75570	2	23	264	56902	56433	\N	47.601140000000001	Ростовская область, Семикаракорский район, х. Бугры, ул. Речная, 14	Россия, Ростовская область, Семикаракорский район, хутор Бугры	0101000020E6100000C5C9FD0E45694440A228D027F2CC4740
75592	2	23	264	56938	56475	\N	47.417814058936202	Ростовская область, Семикаракорский район, х.Балабинка, ул. Центральная, 17В	Россия, Ростовская область, Семикаракорский район, хутор Балабинка	0101000020E61000000667F0F78B734440CDE7DCED7AB54740
75588	2	23	264	56793	55944	\N	47.4411963447874	Ростовская область, Семикаракорский район, х.Бакланники, ул. Школьная, 28	Россия, Ростовская область, Семикаракорский район, хутор Бакланники	0101000020E61000004D86E3F90C7E444021904B1C79B84740
75703	2	23	461	2795	\N	\N	46.548670999999999	Ростовская область, Сальский район, п. Ясенево, бывшая контора отделения№10 СПК имени Ангельева		0101000020E61000005280289831AB4440BEA1F0D93A464740
75675	2	23	461	56627	55270	\N	46.679405477762799	Ростовская область, Сальский район, п. Юловский, ул. Ленина, 15	Россия, Ростовская область, Сальский район	0101000020E6100000350D8AE601AC444094DE37BEF6564740
75689	2	23	461	28061	41111	\N	46.544288999999999	Ростовская область, Сальский район, с. Шаблиевка, ул. Димитрова, 44		0101000020E6100000394371C79BD0444049490F43AB454740
77704	2	23	461	29777	56112	\N	46.924098000000001	Ростовская область, Сальский район, п. Тальники, ул. Ленина, 12		0101000020E61000008B19E1ED41A044404626E0D748764740
75695	2	23	461	28304	56139	\N	46.412855999999998	Ростовская область, Сальский район, с. Сысоево-Александровское, ул. Молодежная, 28		0101000020E610000012A1116C5CA344408BFA2477D8344740
75676	2	23	461	27428	55661	\N	46.759402000000001	Ростовская область, Сальский район, п. Супрун, ул. Центральная, 19		0101000020E6100000E3175E49F2B044402D42B11534614740
75678	2	23	461	27531	55513	\N	46.984132000000002	Ростовская область, Сальский район, п. Степной Курган, ул. Победы, 23		0101000020E6100000925D6919A99B44403A799109F87D4740
75698	2	23	461	28466	55639	\N	46.518143999999999	Ростовская область, Сальский район, п. Сеятель Северный, ул. Пришкольная, 11-б		0101000020E6100000522B4CDF6B9844402F4FE78A52424740
75681	2	23	461	27690	55579	\N	46.275852999999998	Ростовская область, Сальский район, с. Сандата, ул. Полевая, 9		0101000020E6100000D0D4EB1681E1444072C0AE264F234740
75682	2	23	461	27690	40611	\N	46.275852999999998	Ростовская область, Сальский район, с. Сандата, ул. Калинина, 51		0101000020E6100000D0D4EB1681E1444072C0AE264F234740
77707	2	23	461	29910	75533	\N	46.654127000000003	Ростовская область, Сальский район, п. Сальский Беслан, ул. Крайняя, 8		0101000020E6100000AF95D05D12C144401E37FC6EBA534740
75655	2	23	461	2683	40284	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, пер. Морской, 5		0101000020E61000009A40118B18C444406EF7729F1C3D4740
77703	2	23	461	2683	56125	\N	46.477435999999997	"Ростовская область, Сальский район, г. Сальск, микрорайон Плодопитомник, адм.зд.ЗАО АФ"" Сальский сад"""		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75666	2	23	461	2683	40286	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Юннатов, 4		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75656	2	23	461	2683	39916	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Школьная площадь, 13		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75673	2	23	461	2683	41108	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Халтурина, 27		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75669	2	23	461	2683	40287	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Фрунзе, 39		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75672	2	23	461	2683	39713	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Прямая, 112		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75667	2	23	461	2683	39921	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Промышленная, 59		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75670	2	23	461	2683	40288	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Островского, 6		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75663	2	23	461	2683	39712	\N	46.476816923635603	Ростовская область, Сальский район, г. Сальск, ул. Новостройка, 1	Россия, Ростовская область, Сальский район, Сальск	0101000020E6100000E6E8F17B9BC44440A296E656083D4740
75665	2	23	461	2683	40285	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Ленина, 8		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75661	2	23	461	2683	40285	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Ленина, 37		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75659	2	23	461	2683	40285	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Ленина, 41		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75654	2	23	461	2683	40281	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Ковпака, 26		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75660	2	23	461	2683	39920	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Кирова, 17		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75668	2	23	461	2683	41107	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Карла Маркса, 21-а		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75671	2	23	461	2683	39923	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Верхняя, 89-а		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75657	2	23	461	2683	39918	\N	46.477435999999997	Ростовская область, Сальский район, г. Сальск, ул. Береговая, 1		0101000020E61000009A40118B18C444406EF7729F1C3D4740
75697	2	23	461	28418	55665	\N	46.445273999999998	Ростовская область, Сальский район, п. Рыбасово, ул. Московская, 1		0101000020E61000004EB7EC10FFCE44402AE109BDFE384740
75683	2	23	461	27779	55659	\N	46.346015000000001	Ростовская область, Сальский район, с. Романовка, ул. Чапаева, 9-г		0101000020E610000095EF1989D0104540757632384A2C4740
75704	2	23	461	28712	55755	\N	46.446348	Ростовская область, Сальский район, п. Приречный, ул. Школьная, 16		0101000020E610000024287E8CB9B14440485167EE21394740
77706	2	23	461	29852	56247	\N	46.610773000000002	Ростовская область, Сальский район, п. Поливной, ул. Советская, 1		0101000020E6100000DCD7817346CA4440D12346CF2D4E4740
75690	2	23	461	28074	56219	\N	46.507947999999999	Ростовская область, Сальский район, с. Новый Маныч, ул. Центральная, 24		0101000020E61000006B2C616D8CEF4440C808A87004414740
75687	2	23	461	27879	39924	\N	46.392187	Ростовская область, Сальский район, с. Новый Егорлык, ул. Советская, 17		0101000020E610000013F1D6F9B7EF44404B75012F33324740
75685	2	23	461	27879	55637	\N	46.392187	Ростовская область, Сальский район, с. Новый Егорлык, ул. Новостройка, 13		0101000020E610000013F1D6F9B7EF44404B75012F33324740
75686	2	23	461	27879	55663	\N	46.392187	Ростовская область, Сальский район, с. Новый Егорлык, ул. Гагарина, 12-а		0101000020E610000013F1D6F9B7EF44404B75012F33324740
77705	2	23	461	29832	56113	\N	46.823222999999999	Ростовская область, Сальский район, п. Новостепной, ул. Школьная, 5		0101000020E6100000439259BDC3A3444052280B5F5F694740
75693	2	23	461	28227	55536	\N	46.420597000000001	Ростовская область, Сальский район, х. Новоселый 1-й, ул. Солнечная, 6		0101000020E61000001E335019FFB84440DAE55B1FD6354740
75696	2	23	461	56787	55938	\N	46.345962707828399	Ростовская область, Сальский район, х. Маяк, ул. Центральная, 1	Россия, Ростовская область, Сальский район, хутор Маяк	0101000020E6100000B492567C43DD44402250FD83482C4740
75692	2	23	461	28159	55997	\N	46.621147999999998	Ростовская область, Сальский район, п. Манычстрой, ул. Нефтяников, 6		0101000020E61000001077F52A32D44440E7FC14C7814F4740
75694	2	23	461	28256	40290	\N	46.419429000000001	Ростовская область, Сальский район, с. Крученая Балка, ул. Ленина, 20-а		0101000020E610000098309A95EDAD44403BFF76D9AF354740
75691	2	23	461	11240	41234	\N	46.548583999999998	Ростовская область, Сальский район, п. Конезавод имени Буденного, ул. Ленина, 3		0101000020E6100000BB287AE063CA4440EF8D210038464740
76000	2	23	461	11240	55606	\N	46.548583999999998	Ростовская область, Цимлянский район, Саркеловское сельское поселение, х.Крутой, Буденного, 2		0101000020E6100000BB287AE063CA4440EF8D210038464740
77708	2	23	461	29941	55692	\N	46.510317999999998	Ростовская область, Сальский район, п. Клены, пер. Школьный, 31-а		0101000020E610000096CD1C925AA24440B247A81952414740
75680	2	23	461	27659	41110	\N	46.200254999999999	Ростовская область, Сальский район, с. Ивановка, ул. Ленина, 63		0101000020E6100000087250C24CD5444024EEB1F4A1194740
75688	2	23	461	28010	40626	\N	46.531984000000001	Ростовская область, Сальский район, с. Екатериновка, ул. Коржова, 14		0101000020E6100000226E4E2503D8444065FF3C0D18444740
75702	2	23	461	2726	39925	\N	46.504356999999999	Ростовская область, Сальский район, п. Гигант, ул. Учебная, 3		0101000020E610000097FE25A94CAB44401C412AC58E404740
75699	2	23	461	2726	39925	\N	46.504356999999999	Ростовская область, Сальский район, п. Гигант, ул. Учебная,23		0101000020E610000097FE25A94CAB44401C412AC58E404740
75701	2	23	461	2726	41238	\N	46.504356999999999	Ростовская область, Сальский район, п. Гигант, ул. Ленина, 83		0101000020E610000097FE25A94CAB44401C412AC58E404740
75700	2	23	461	2726	41236	\N	46.504356999999999	Ростовская область, Сальский район, п. Гигант, ул. Крупской, 6		0101000020E610000097FE25A94CAB44401C412AC58E404740
75679	2	23	461	27613	40289	\N	46.320218540028399	Ростовская область, Сальский район, с. Березовка, ул. Юбилейная, 1	Россия, Ростовская область, Сальский район, село Березовка	0101000020E6100000CAC0012D5DEB44406747AAEFFC284740
75677	2	23	461	27517	41109	\N	46.838414	Ростовская область, Сальский район, п. Белозерный, ул. Центральная, 3		0101000020E6100000B493C151F2AA444018416326516B4740
45929	2	20	\N	6023	23372	\N	44.730175000000003	город Новороссийск, ул. Видова, д. 123, телефон: 21-37-38		0101000020E6100000A7751BD47EDF4240ACADD85F765D4640
75684	2	23	461	27813	55521	\N	46.486303999999997	Ростовская область, Сальский район, с. Бараники, ул. Октябрьская, 2		0101000020E61000008D47A98427F64440FDF49F353F3E4740
77580	2	23	1729	24069	56126	\N	47.520853000000002	Ростовская область, Родионово-Несветайский район, с.Чистополье, ул.Октябрьская, д.28		0101000020E6100000D53DB2B96AB843400283A44FABC24740
77588	2	23	1729	54827	55294	\N	47.610292869825201	Ростовская область, Родионово-Несветайский район, сл.Родионово-Несветайская, ул.Пушкинская, д.24	Россия, Ростовская область, Родионово-Несветайский район, слобода Родионово-Несветайская	0101000020E6100000AE6708C72CDB434026FDBD141ECE4740
77589	2	23	1729	54827	55257	\N	47.6071007051778	Ростовская область, Родионово-Несветайский район, сл.Родионово-Несветайская, ул.Кирова, 14	Россия, Ростовская область, Родионово-Несветайский район, слобода Родионово-Несветайская	0101000020E6100000BFF4F6E7A2DB4340382F4E7CB5CD4740
77681	2	23	1729	54827	39879	\N	47.612184405262603	Ростовская область, Родионово-Несветайский район, сл.Родионово-Несветайская, ул.Гвардейцев-Танкистов, д.6	Россия, Ростовская область, Родионово-Несветайский район, слобода Родионово-Несветайская	0101000020E6100000F609A01859DA43403691990B5CCE4740
77570	2	23	1729	23599	56131	\N	47.687048188825997	Ростовская область, Родионово-Несветайский район, с.Плато-Ивановка, ул.Чапаева, д.3	Россия, Ростовская область, Родионово-Несветайский район, село Плато-Ивановка	0101000020E610000070B54E5C8EB543401F645930F1D74740
77576	2	23	1729	56814	\N	\N	47.824196333235498	Ростовская область, Родионово-Несветайский район, х.Новопрохоровка, Сельский клуб	Россия, Ростовская область, Родионово-Несветайский район, хутор Новопрохоровка	0101000020E6100000D0EFFB372FC443403CBF28417FE94740
77586	2	23	1729	24375	55573	\N	47.551293999999999	Ростовская область, Родионово-Несветайский район, сл.Кутейниково, ул.Булановой, д.30		0101000020E61000009624CFF57DE24340923D42CD90C64740
77587	2	23	1729	24380	55796	\N	47.434066999999999	Ростовская область, Родионово-Несветайский район, х.Каменный Брод, ул.Первомайская, д.4		0101000020E610000052465C001AED4340ECA2E8818FB74740
77578	2	23	1729	56744	55891	\N	47.687056678465403	Ростовская область, Родионово-Несветайский район, х.Дарьевка, ул.Центральная, д.36Б	Россия, Ростовская область, Родионово-Несветайский район, хутор Дарьевка	0101000020E6100000E010AAD4ECD7434073BED87BF1D74740
77581	2	23	1729	24115	55689	\N	47.623457000000002	Ростовская область, Родионово-Несветайский район, с.Греково-Ульяновка, ул.Волошилова, д.32А		0101000020E610000046787B1002A043402CBB6070CDCF4740
77756	2	23	1729	56917	56450	\N	47.525345178715597	Ростовская область, Родионово-Несветайский район, х.Гребцово, ул.Суворова, д.25А	Россия, Ростовская область, Родионово-Несветайский район, хутор Гребцово	0101000020E6100000F08975AA7CE94340FE0E45813EC34740
77583	2	23	1729	24218	55690	\N	47.470553000000002	Ростовская область, Родионово-Несветайский район, с.Генеральское, ул.Клубная, д.6А		0101000020E6100000F3E32F2DEACB43407104A9143BBC4740
77582	2	23	1729	56666	55496	\N	47.624957000000002	Ростовская область, Родионово-Несветайский район, х.Выдел, ул.Первомайская, д.13	Россия, Ростовская область, Родионово-Несветайский район, хутор Выдел	0101000020E6100000857CD0B359C5434001344A97FECF4740
77584	2	23	1729	56707	55849	\N	47.514310342126699	Ростовская область, Родионово-Несветайский район, х.Волошино, ул.Центральная, 14	Россия, Ростовская область, Родионово-Несветайский район, хутор Волошино	0101000020E61000005BD3BCE314D54340BD00FBE8D4C14740
77574	2	23	1729	56732	55877	\N	47.594389	Ростовская область, Родионово-Несветайский район, х.Веселый, ул.Ленина, д.5В	Россия, Ростовская область, Родионово-Несветайский район, хутор Веселый	0101000020E61000005AF44E05DCD14340130D52F014CC4740
77573	2	23	1729	56852	56377	\N	47.8058948841336	Ростовская область, Родионово-Несветайский район, х.Бунако-Соколовец, ул.Первомайская, Сельский клуб	Россия, Ростовская область, Родионово-Несветайский район, хутор Бунако-Соколовец	0101000020E6100000B5C5353E93CD434045813E9127E74740
77579	2	23	1729	56635	55282	\N	47.5982530382649	Ростовская область, Родионово-Несветайский район, сл.Большекрепинская, ул.Ленина, д.8	Россия, Ростовская область, Родионово-Несветайский район, слобода Большекрепинская	0101000020E6100000D61F6118B0B04340F0DDE68D93CC4740
77577	2	23	1729	56725	55869	\N	47.719537000000003	Ростовская область, Родионово-Несветайский район, х.Болдыревка, ул.Октябрьская, д.26	Россия, Ростовская область, Родионово-Несветайский район, хутор Болдыревка	0101000020E6100000A296E65608DD434088A1D5C919DC4740
77571	2	23	1729	56713	55856	\N	47.754577501448601	Ростовская область, Родионово-Несветайский район, сл.Барило-Крепинская, ул.Красноармейская, д.2А	Россия, Ростовская область, Родионово-Несветайский район, слобода Барило-Крепинская	0101000020E6100000C51B9947FEC44340FB230C0396E04740
77572	2	23	1729	56936	56472	\N	47.774883000000003	Ростовская область, Родионово-Несветайский район, х.Атамано-Власовка, ул.Чапаева, д.4/1	Россия, Ростовская область, Родионово-Несветайский район, хутор Атамано-Власовка	0101000020E6100000C7F65AD07BCB4340FA9CBB5D2FE34740
77575	2	23	1729	56766	55914	\N	47.841418478450301	Ростовская область, Родионово-Несветайский район, сл.Алексеево-Тузловка, ул.Садовая, д.24А	Россия, Ростовская область, Родионово-Несветайский район, слобода Алексеево-Тузловка	0101000020E610000018B49080D1B943400322C495B3EB4740
45512	2	20	\N	50444	21927	\N	44.921664119509401	город Крымск, Свердлова, 65, телефон: 4-27-10		0101000020E6100000C537143E5BFF424045F30016F9754640
77569	2	23	1729	56675	55599	\N	47.7306171506414	Ростовская область, Родионово-Несветайский район, сл.Аграфеновка, ул.Просвещения, Дом культуры	Россия, Ростовская область, Родионово-Несветайский район, слобода Аграфеновка	0101000020E6100000EB353D2828BF434069739CDB84DD4740
77682	2	23	1729	56778	55926	\N	47.641658113440201	Ростовская область, Родионово-Несветайский район, х.Авилов, ул.Советская, д.1	Россия, Ростовская область, Родионово-Несветайский район, хутор Авилов	0101000020E6100000A41B615111F14340BF9B6ED921D24740
75949	2	23	989	8826	56289	\N	46.307948000000003	Ростовская область, Ремонтненский район, поселок Тихий Лиман, ул. Школьная, д.6		0101000020E610000066BE839F38B445402F6F0ED76A274740
75940	2	23	989	8379	41086	\N	46.561107999999997	Ростовская область, Ремонтненский район, село Ремонтное, ул. Первомайская, д.20		0101000020E610000081B2295778D5454011C30E63D2474740
75941	2	23	989	8379	40482	\N	46.561107999999997	Ростовская область, Ремонтненский район, село Ремонтное, ул. Октябрьская, д.147		0101000020E610000081B2295778D5454011C30E63D2474740
75939	2	23	989	8379	40226	\N	46.561107999999997	Ростовская область, Ремонтненский район, село Ремонтное, ул. Ленинская, д.90		0101000020E610000081B2295778D5454011C30E63D2474740
75952	2	23	989	8962	56283	\N	46.635939	Ростовская область, Ремонтненский район, хутор Раздольный, ул. Центральная, д.48		0101000020E610000070CE88D2DE7A45401FA0FB7266514740
75956	2	23	989	9146	55554	\N	46.654443000000001	Ростовская область, Ремонтненский район, поселок Привольный, ул. Советская, д.21		0101000020E61000004EB4AB90F2B345404E0CC9C9C4534740
75950	2	23	989	8866	55722	\N	46.533416000000003	Ростовская область, Ремонтненский район, село Подгорное, ул. Ленина, д.54		0101000020E61000002C2D23F59E904540E294B9F946444740
75947	2	23	989	8772	41087	\N	46.360078999999999	Ростовская область, Ремонтненский район, село Первомайское, ул. Богданова, д.78		0101000020E6100000352A70B20DCE4540FA7C9411172E4740
75957	2	23	989	9222	56273	\N	46.598891999999999	Ростовская область, Ремонтненский район, поселок Новопривольный, ул. Садовая, д.9		0101000020E610000067D65240DAC1454003EB387EA84C4740
75954	2	23	989	9061	55548	\N	46.339399598715801	Ростовская область, Ремонтненский район, поселок Краснопартизанский, ул. Южная, д.11	Россия, Ростовская область, Ремонтненский район, поселок Краснопартизанский	0101000020E61000002EAA45443193454096218E75712B4740
75948	2	23	989	8777	55710	\N	46.267947999999997	Ростовская область, Ремонтненский район, село Кормовое, ул. Ленина, д.24		0101000020E6100000D47FD6FCF8BF4540A983BC1E4C224740
75951	2	23	989	8953	55828	\N	46.563085000000001	Ростовская область, Ремонтненский район, село Киевка, ул. Ленинская, д.97		0101000020E610000075E95F92CA84454020EF552B13484740
75955	2	23	989	9108	55531	\N	46.456685999999998	Ростовская область, Ремонтненский район, поселок Денисовский, ул. Ленинская, д.16		0101000020E61000000F09DFFB1BB045404145D5AF743A4740
75944	2	23	989	8594	56290	\N	46.700512000000003	Ростовская область, Ремонтненский район, хутор Вольный, ул. Веревкина, д.60		0101000020E610000051A2258FA7CD4540503A9160AA594740
75942	2	23	989	8505	55591	\N	46.712853000000003	Ростовская область, Ремонтненский район, село Валуевка, ул. 40 лет Победы, д.84		0101000020E610000078D2C26515DE454081ED60C43E5B4740
75945	2	23	989	8653	55539	\N	46.468834000000001	Ростовская область, Ремонтненский район, село Большое Ремонтное, ул. Ленина, д.27		0101000020E6100000249A40118BEA45405EA0A4C0023C4740
75946	2	23	989	8702	55827	\N	46.343874999999997	Ростовская область, Ремонтненский район, с. Богородское, ул. Буденного, д.14		0101000020E6100000F30016F9F5F14540BC749318042C4740
75933	2	23	924	8052	55532	\N	46.656994517215402	Ростовская область, Пролетарский район, хутор Уютный, ул.Ленина, д.31	Россия, Ростовская область, Пролетарский район, хутор Уютный	0101000020E6100000478E740646DE44405951836918544740
75932	2	23	924	8041	56280	\N	47.125956000000002	Ростовская область, Пролетарский район, хутор Татнинов, ул.Лесная, д.21		0101000020E6100000D789CBF10AD04440145E82531F904740
75927	2	23	924	7761	39962	\N	47.102414000000003	Ростовская область, Пролетарский район, хутор Сухой, ул.Пионерская, д.28		0101000020E610000083A3E4D539AE44408753E6E61B8D4740
75917	2	23	924	7364	39690	\N	46.70561	Ростовская область, Пролетарский район, город Пролетарск, пер.Красный, д.101		0101000020E6100000D4282499D5DB444083DDB06D515A4740
75920	2	23	924	7364	39685	\N	46.70561	Ростовская область, Пролетарский район, город Пролетарск, ул.Матвеева, д.8/1		0101000020E6100000D4282499D5DB444083DDB06D515A4740
75923	2	23	924	7364	40225	\N	46.70561	Ростовская область, Пролетарский район, город Пролетарск, ул.Горького, д.9		0101000020E6100000D4282499D5DB444083DDB06D515A4740
75935	2	23	924	8212	56265	\N	46.801779000000003	Ростовская область, Пролетарский район, хутор Привольный, ул.Свободная, д.20/1		0101000020E61000005DC0CB0C1BCF44404FCFBBB1A0664740
75936	2	23	924	8265	40057	\N	46.640332000000001	Ростовская область, Пролетарский район, поселок Опенки, ул.Каштанов, д.21		0101000020E6100000AF963B33C1F04440884A2366F6514740
75926	2	23	924	7755	56269	\N	47.158876202333403	Ростовская область, Пролетарский район, хутор Новомоисеевский, Школьная улица, д.19	Россия, Ростовская область, Пролетарский район, хутор Новомоисеевский	0101000020E6100000FFE9060ABC914440450F7C0C56944740
75937	2	23	924	8269	55825	\N	46.624552000000001	Ростовская область, Пролетарский район, хутор Николаевский 2-й, адрес помещения для голосования, ул.Школьная, д.2-а		0101000020E61000003EEC8502B61945406153E751F14F4740
75929	2	23	924	7903	55528	\N	47.005761	Ростовская область, Пролетарский район, хутор Наумовский, ул.Центральная, д.35-а		0101000020E6100000425C397B67B84440CF4BC5C6BC804740
75934	2	23	924	8106	55826	\N	46.845613999999998	Ростовская область, Пролетарский район, хутор Мокрая Ельмута, ул.Фермерская, д.2		0101000020E61000001155F833BCD7444016855D143D6C4740
75930	2	23	924	7908	55712	\N	47.012721999999997	Ростовская область, Пролетарский район, хутор Коврино, адрес помещения для голосования, ул.Ленина, д.55-а		0101000020E610000082C5E1CCAFE0444048F8DEDFA0814740
75925	2	23	924	7687	55589	\N	47.052289000000002	Ростовская область, Пролетарский район, хутор Дальний, адрес помещения для голосования, ул.Целинная, д.28		0101000020E6100000C07971E2AB9344406478EC67B1864740
75931	2	23	924	7961	56014	\N	47.012833000000001	Ростовская область, Пролетарский район, хутор Ганчуков, адрес помещения для голосования, ул.Огнева, д.10		0101000020E61000000E15E3FC4DCC4440A0A70183A4814740
75928	2	23	924	7813	39691	\N	46.929291999999997	Ростовская область, Пролетарский район, станица Буденновская, ул.Гремучая, д.38		0101000020E6100000F3599E0777C744409B374E0AF3764740
75901	2	23	845	6555	55526	\N	46.101598000000003	Ростовская область, Песчанокопский район, село Рассыпное, улица Ленина, д.55-а		0101000020E6100000815EB873619A444065ABCB29010D4740
75915	2	23	845	7068	\N	\N	46.237144999999998	Ростовская область, Песчанокопский район, село Развильное, усадьба СХТ, д.3		0101000020E61000006B0BCF4BC5A4444078B471C45A1E4740
75913	2	23	845	7068	41085	\N	46.237144999999998	Ростовская область, Песчанокопский район, село Развильное, улица Ростовская, д.23		0101000020E61000006B0BCF4BC5A4444078B471C45A1E4740
75911	2	23	845	7068	39959	\N	46.237144999999998	Ростовская область, Песчанокопский район, село Развильное, улица Комсомольская, д.1-б		0101000020E61000006B0BCF4BC5A4444078B471C45A1E4740
75912	2	23	845	7068	40476	\N	46.237144999999998	Ростовская область, Песчанокопский район, село Развильное, улица Буденного, д.3		0101000020E61000006B0BCF4BC5A4444078B471C45A1E4740
75909	2	23	845	6937	41084	\N	46.253037999999997	Ростовская область, Песчанокопский район, село Поливянка, Центральная площадь, д.4		0101000020E6100000A759A0DD21B344409752978C63204740
75896	2	23	845	6287	41081	\N	46.189413000000002	Ростовская область, Песчанокопский район, село Песчанокопское, площадь им.В.И.Ленина, д.1		0101000020E6100000240F4416698A4440F83768AF3E184740
75897	2	23	845	6287	39956	\N	46.189413000000002	Ростовская область, Песчанокопский район, село Песчанокопское, улица Орджоникидзе, д.14		0101000020E6100000240F4416698A4440F83768AF3E184740
75900	2	23	845	6287	39684	\N	46.192605089393403	Ростовская область, Песчанокопский район, село Песчанокопское, улица Народная, д.104-а	Россия, Ростовская область, Песчанокопский район, село Песчанокопское	0101000020E61000004ED1915CFE894440E605D847A7184740
75899	2	23	845	6287	39684	\N	46.189413000000002	Ростовская область, Песчанокопский район, село Песчанокопское, улица Народная, д.2		0101000020E6100000240F4416698A4440F83768AF3E184740
75898	2	23	845	6287	40466	\N	46.193469358156896	Ростовская область, Песчанокопский район, село Песчанокопское, улица Бабина, д.1	Россия, Ростовская область, Песчанокопский район, село Песчанокопское	0101000020E6100000459F8F32E28A444019E59997C3184740
75910	2	23	845	7024	55711	\N	46.284199000000001	Ростовская область, Песчанокопский район, село Николаевка, улица Дружбы, д.43		0101000020E610000084BBB376DBBB4440284701A260244740
75903	2	23	845	6614	40470	\N	46.016522000000002	Ростовская область, Песчанокопский район, село Летник, улица Ленина, д.50/1		0101000020E61000009483D90418A244400FD594641D024740
75906	2	23	845	6806	55529	\N	46.111839000000003	Ростовская область, Песчанокопский район, село Красная Поляна, площадь Школьная, д.3		0101000020E6100000703FE08101C044406CB587BD500E4740
75907	2	23	845	6806	41082	\N	46.111839000000003	Ростовская область, Песчанокопский район, село Красная Поляна, улица Кирова, д.7		0101000020E6100000703FE08101C044406CB587BD500E4740
75905	2	23	845	6752	56266	\N	46.082123000000003	Ростовская область, Песчанокопский район, село Жуковское, улица Московская, д.122		0101000020E610000084BD892139AD4440ED9FA701830A4740
75904	2	23	845	6752	40473	\N	46.082123000000003	Ростовская область, Песчанокопский район, село Жуковское, улица Ленина, д.98-а		0101000020E610000084BD892139AD4440ED9FA701830A4740
75908	2	23	845	6885	55527	\N	46.096774000000003	Ростовская область, Песчанокопский район, поселок Дальнее Поле, улица Ленина, д.3		0101000020E6100000BBEF181EFBD34440338D2617630C4740
75916	2	23	845	7326	40478	\N	46.328519	Ростовская область, Песчанокопский район, село Богородицкое, переулок Советский, д.65		0101000020E6100000DD5CFC6D4F964440AC8E1CE90C2A4740
75875	2	23	529	56919	56452	\N	46.947535000000002	Ростовская область, Орловский район, х. Широкий, ул. Школьная, 1-а	Россия, Ростовская область, Орловский район, хутор Широкий	0101000020E61000003752B648DA1D45405E68AED348794740
77743	2	23	529	56933	56469	\N	46.733207999999998	Ростовская область, Орловский район, х. Черкесский, ул. Транспортная, 34		0101000020E61000005F268A90BA37454031957EC2D95D4740
75885	2	23	529	56923	56457	\N	47.051496999999998	Ростовская область, Орловский район, х. Успенский, ул. Молодежная, 28	Россия, Ростовская область, Орловский район, хутор Успенский	0101000020E6100000382EE3A606F44440CA6B257497864740
75874	2	23	529	57005	56553	\N	47.000440947057697	Ростовская область, Орловский район, х. Токмацкий, ул. Дорожная, 17	Россия, Ростовская область, Орловский район, хутор Токмацкий	0101000020E6100000963D096CCE1D4540ED4960730E804740
75870	2	23	529	56838	56276	\N	46.715233488773997	Ростовская область, Орловский район, х. Таловый, ул. Микояновская, 12	Россия, Ростовская область, Орловский район, хутор Таловый	0101000020E6100000D82D02637D5745408E0244C18C5B4740
75863	2	23	529	4531	56012	\N	46.584995999999997	Ростовская область, Орловский район, п. Стрепетов, ул. Школьная, 1		0101000020E61000009D4CDC2A8843454039252026E14A4740
75838	2	23	529	3209	56007	\N	46.483269999999997	Ростовская область, Орловский район, п. Рунный, ул. Южная, 2		0101000020E61000004C70EA03C96D4540A79196CADB3D4740
45517	2	20	\N	50444	22269	\N	44.918024000000003	город Крымск, Ленина, 31, телефон: 4-05-11		0101000020E6100000F81C588E90FF4240B87878CF81754640
75865	2	23	529	56871	56399	\N	46.748072999999998	Ростовская область, Орловский район, х. Романовский, ул. Луговая, 45	Россия, Ростовская область, Орловский район, хутор Романовский	0101000020E610000011A96917D3FC4440A30227DBC05F4740
75864	2	23	529	56670	55523	\N	46.825850000000003	Ростовская область, Орловский район, х. Ребричанский, ул. Веселая, 13	Россия, Ростовская область, Орловский район, хутор Ребричанский	0101000020E610000059DDEA39E9F3444068B3EA73B5694740
75873	2	23	529	56984	56526	\N	47.033448999999997	Ростовская область, Орловский район, х. Раздорский, ул Транспортная, 20	Россия, Ростовская область, Орловский район, хутор Раздорский	0101000020E6100000B5A50EF27A1A4540BD8A8C0E48844740
77742	2	23	529	56771	55919	\N	46.663541433796198	Ростовская область, Орловский район, х. Пролетарский, ул. Школьная, 19	Россия, Ростовская область, Орловский район, хутор Пролетарский	0101000020E6100000EC6AF294D53045400F4757E9EE544740
77684	2	23	529	56676	55604	\N	46.760933594506	Ростовская область, Орловский район, х. Островянский, ул. Коммунистическая, 34	Россия, Ростовская область, Орловский район, хутор Островянский	0101000020E610000017299485AF1B45400D350A4966614740
75888	2	23	529	5805	41080	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, пер. Почтовый, 90		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75892	2	23	529	5805	40224	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, пер. П.Ф. Костенко, 52		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75891	2	23	529	5805	40224	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, пер. П.Ф. Костенко, 50		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75893	2	23	529	5805	55147	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, Ростовская область, Орловский район, пер. Чапаевский, 146		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75890	2	23	529	5805	55135	\N	46.871611000000001	п. Орловский, Ростовская область, Орловский район, пер. Октябрьский, 2		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
77683	2	23	529	5805	39882	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, ул. Рябиновая, 5		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75894	2	23	529	5805	39955	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, ул. Пролетарская, 49		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75887	2	23	529	5805	39954	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, ул. Пионерская, 64		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75886	2	23	529	5805	39954	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, ул. Пионерская, 41		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75895	2	23	529	5805	40465	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, ул. Красноармейская, 1		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75889	2	23	529	5805	40054	\N	46.871611000000001	Ростовская область, Орловский район, п. Орловский, ул. Коммунальная, 158		0101000020E6100000A4FB3905F9054540BCEA01F3906F4740
75867	2	23	529	4759	56278	\N	46.998189000000004	Ростовская область, Орловский район, х. Орден Ленина, ул. Степная, 1-а	Россия, Ростовская область, Орловский район, хутор Орден Ленина	0101000020E6100000C005D9B27C0745400D1D3BA8C47F4740
75878	2	23	529	56835	56263	\N	46.606228999999999	Ростовская область, Орловский район, х. Нижнеантоновский, ул. Антоновская, 44/1	Россия, Ростовская область, Орловский район, хутор Нижнеантоновский	0101000020E6100000DACA4BFE27574540827170E9984D4740
75862	2	23	529	4527	56275	\N	46.433225999999998	Ростовская область, Орловский район, п. Маныч, ул. Приозерная, 28		0101000020E6100000677FA0DCB65B454071E316F373374740
75884	2	23	529	56700	55841	\N	47.059958882500098	Ростовская область, Орловский район, х. Майорский, ул. Магистральная, 24	Россия, Ростовская область, Орловский район, хутор Майорский	0101000020E6100000F16778B306014540E90C8CBCAC874740
75881	2	23	529	56723	55866	\N	46.832403999999997	Ростовская область, Орловский район, х. Луганский, пер. Колхозный, 12	Россия, Ростовская область, Орловский район, хутор Луганский	0101000020E6100000F90FE9B7AF054540A087DA368C6A4740
75883	2	23	529	56840	56282	\N	46.833475999999997	Ростовская область, Орловский район, х. Курмоярский, ул. Новоселов, 7	Россия, Ростовская область, Орловский район, хутор Курмоярский	0101000020E6100000F0FACC599F1645401D007157AF6A4740
75877	2	23	529	56684	55714	\N	46.567979000000001	Ростовская область, Орловский район, х. Курганный, пер. Театральный, 1	Россия, Ростовская область, Орловский район, хутор Курганный	0101000020E610000038A11001876645404BE82E89B3484740
75882	2	23	529	56967	56508	\N	46.769247999999997	Ростовская область, Орловский район, х. Кундрюченский, пер. Почтовый, 2-а	Россия, Ростовская область, Орловский район, хутор Кундрюченский	0101000020E610000059C16F438C0D4540B741EDB776624740
75871	2	23	529	4972	41079	\N	47.009245	Ростовская область, Орловский район, п. Красноармейский, пер. Красноармейский, 22		0101000020E61000003A24B550321B45406553AEF02E814740
75872	2	23	529	4972	32951	\N	47.009245	Ростовская область, Орловский район, п. Красноармейский, ул. Кирова, 45		0101000020E61000003A24B550321B45406553AEF02E814740
75869	2	23	529	56624	55261	\N	46.654928927205198	Ростовская область, Орловский район, х. Камышевка, ул. Школьная, 63	Россия, Ростовская область, Орловский район, хутор Камышевка	0101000020E6100000FAEC80EB8A514540DB19A6B6D4534740
75866	2	23	529	4755	55134	\N	46.943364000000003	Ростовская область, Орловский район, х. Каменная Балка, пер. Центральный, 1		0101000020E6100000EF90628044014540A41CCC26C0784740
77660	2	23	898	21414	55246	\N	47.400789000000003	Ростовская область, Октябрьский район, Кривянское сельское поселение, ст. Кривянская, ул. Советская, №100		0101000020E6100000327381CB631544405CCCCF0D4DB34740
75850	2	23	529	56745	55892	\N	46.781611011233601	Ростовская область, Орловский район, х. Гундоровский, ул. Центральная, 17	Россия, Ростовская область, Орловский район, хутор Гундоровский	0101000020E6100000D4F02DAC1BF34440D09849D40B644740
75868	2	23	529	56970	56514	\N	46.9366425746896	Ростовская область, Орловский район, х. Греков, ул. Солнечная, 20		0101000020E6100000ED612F14B0EB44407F83F6EAE3774740
75861	2	23	529	4418	55824	\N	46.543104999999997	Ростовская область, Орловский район, п. Волочаевский, ул. Садовая, 4-а		0101000020E61000006283859334534540A4A5F27684454740
77741	2	23	529	56797	55969	\N	46.707010862881503	Ростовская область, Орловский район, х. Веселый, пер. Кооперативный, 6	Россия, Ростовская область, Орловский район, хутор Веселый	0101000020E61000006D58535914184540C57421567F5A4740
75876	2	23	529	56982	56524	\N	46.938195999999998	Ростовская область, Орловский район, х. Верхнетавричанский, ул. Пушкинская, 1-б	Россия, Ростовская область, Орловский район, хутор Верхнетавричанский	0101000020E6100000032670EB6E244540779E78CE16784740
77685	2	23	529	56816	56138	\N	46.794493000000003	Ростовская область, Орловский район, х. Верхнезундов, ул. Колхозная, 11	Россия, Ростовская область, Орловский район, хутор Верхнезундов	0101000020E6100000210725CCB41F454052F355F2B1654740
75879	2	23	529	56833	56260	\N	46.611986970087102	Ростовская область, Орловский район, х. Верхневодяной, ул. Запрудная, 12	Россия, Ростовская область, Орловский район, хутор Верхневодяной	0101000020E6100000C269C18BBE724540E0490B97554E4740
75880	2	23	529	56734	55879	\N	46.828667000000003	Ростовская область, Орловский район, х. Быстрянский, пер. Садовый, 19	Россия, Ростовская область, Орловский район, хутор Быстрянский	0101000020E610000063B5F97FD50345402123A0C2116A4740
77740	2	23	529	56908	56440	\N	46.706401	Ростовская область, Орловский район, х. Большевик, ул. Победы, 15	Россия, Ростовская область, Орловский район, хутор Большевик	0101000020E61000003DEE5BAD132145404C6E14596B5A4740
75540	2	23	898	21138	40442	\N	47.490583000000001	Ростовская область, Октябрьский район, Красюковское сельское поселение, х. Яново-Грушевский, ул. Восточная, №7		0101000020E610000000016BD5AE0544409E7C7A6CCBBE4740
77641	2	23	898	26890	56359	\N	47.627780999999999	Ростовская область, Октябрьский район, Краснолучское сельское поселение, х. Ягодинка, ул. Центральная, №25-А		0101000020E61000000CB08F4E5D2B44406C06B8205BD04740
75523	2	23	898	20220	56217	\N	47.851560999999997	Ростовская область, Октябрьский район, Артемовское сельское поселение, п. Равнинный, ул. Майская, №27		0101000020E6100000FA62EFC5174D444047C66AF3FFEC4740
75553	2	23	898	21703	39908	\N	47.521334000000003	Ростовская область, Октябрьский район, Персиановское сельское поселение, п. Персиановский, ул. Школьная, №21		0101000020E6100000195932C7F20E44407D259012BBC24740
75552	2	23	898	21703	39908	\N	47.521334000000003	Ростовская область, Октябрьский район, Персиановское сельское поселение, п. Персиановский, адрес помещения для голосования: ул. Школьная, №8, адрес УИК: ул. Кривошлыкова, №29		0101000020E6100000195932C7F20E44407D259012BBC24740
75554	2	23	898	21703	41047	\N	47.521334000000003	Ростовская область, Октябрьский район, Персиановское сельское поселение, п. Персиановский, ул. Московская, №17-В		0101000020E6100000195932C7F20E44407D259012BBC24740
75321	2	23	898	6945	\N	\N	47.448163999999998	"Ростовская область, город Новочеркасск, Алюминиевая площадка, здание медицинской санитарной части Заводоуправления ОАО ""НЭЗ"""		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75280	2	23	898	6945	40094	\N	47.448163999999998	Ростовская область, город Новочеркасск, Ермака пр-т, д. 92		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75291	2	23	898	6945	39641	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Энгельса, д. 20		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75318	2	23	898	6945	41017	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Чехова, д. 7		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75300	2	23	898	6945	39643	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Центральная, д. 1/7		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75298	2	23	898	6945	40265	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Троицкая, д. 51		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75309	2	23	898	6945	40268	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Свободы, д. 19		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75289	2	23	898	6945	40096	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Ростовский выезд, д. 18		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75250	2	23	898	6945	40373	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Пушкинская, д. 111		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75302	2	23	898	6945	56327	\N	47.448884448125902	Ростовская область, город Новочеркасск, Просторный пер, д. 3		0101000020E6100000BBB4E1B0341044404DD9E90775B94740
75290	2	23	898	6945	40097	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Просвещения, д. 132		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75297	2	23	898	6945	39642	\N	47.448163999999998	Ростовская область, город Новочеркасск, Платовский пр-т, д. 116		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75296	2	23	898	6945	39642	\N	47.448163999999998	Ростовская область, город Новочеркасск, Платовский пр-т, д. 102		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75281	2	23	898	6945	39642	\N	47.448163999999998	Ростовская область, город Новочеркасск, Платовский пр-т, д. 94		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75323	2	23	898	6945	40400	\N	47.419882002657701	Ростовская область, город Новочеркасск, ул. Петрова, д. 17	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E61000002618CE35CC0A4440EC1681B1BEB54740
45186	2	20	\N	242	23621	\N	45.064024000000003	город Краснодар, Тургенева, 140, телефон: 259-29-28		0101000020E610000011C5E40D307B43405E143DF031884640
75319	2	23	898	6945	40400	\N	47.419736367480503	Ростовская область, город Новочеркасск, МБОУ СОШ №25, ул. Петрова, д. 17	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E61000000342EBE1CB0A4440187AC4E8B9B54740
75292	2	23	898	6945	40245	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Первомайская, д. 166		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75326	2	23	898	6945	40271	\N	47.448163999999998	Ростовская область, город Новочеркасск, Парковый пр-т, д. 7А		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75325	2	23	898	6945	32958	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Новый городок, д. 6		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75317	2	23	898	6945	40270	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Молодежная, д. 57/8		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75327	2	23	898	6945	39645	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Мелиховская, д. 35		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75316	2	23	898	6945	40398	\N	47.481536615525698	Ростовская область, город Новочеркасск, ул. Мацоты, д. 38	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E6100000F9A1D288990B444030682101A3BD4740
75305	2	23	898	6945	40098	\N	47.491223572468797	Ростовская область, город Новочеркасск, ул. Клещева, д. 37	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E61000008D463EAF780844405281936DE0BE4740
75304	2	23	898	6945	40098	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Клещева, д. 39		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75314	2	23	898	6945	40269	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Калинина, д. 65А		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75313	2	23	898	6945	40269	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Калинина, д. 53		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75312	2	23	898	6945	40269	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Калинина, д. 25		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75303	2	23	898	6945	41006	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Заводская, д. 3		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75276	2	23	898	6945	41003	\N	47.449932428136897	Ростовская область, город Новочеркасск, ул. Ермака, д. 92		0101000020E61000006D8C9DF01210444041B62C5F97B94740
75308	2	23	898	6945	40397	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Гвардейская, д. 19		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75306	2	23	898	6945	40099	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Высоковольтная, д. 1		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75271	2	23	898	6945	40381	\N	47.448163999999998	Ростовская область, город Новочеркасск, адрес помещения для голосования: ул. Буденновская, д. 94, адрес УИК: ул. Буденновская, д. 141		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75268	2	23	898	6945	40381	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Буденновская, д. 188		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75273	2	23	898	6945	39640	\N	47.422386864264901	"Ростовская область, город Новочеркасск, МУП ""Центр технической инвентаризации"", пер. Баклановский, д. 102"	Россия, Ростовская область, Октябрьский район, Новочеркасск	0101000020E61000009B3C65355D094440B6A0F7C610B64740
75267	2	23	898	6945	39640	\N	47.448163999999998	Ростовская область,город Новочеркасск, Баклановский пр-т, д. 136		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75264	2	23	898	6945	39640	\N	47.448163999999998	Ростовская область, город Новочеркасск, Баклановский пр-т, д. 190		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75285	2	23	898	6945	40210	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Александровская, д. 109		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75284	2	23	898	6945	40210	\N	47.448163999999998	Ростовская область, город Новочеркасск, ул. Александровская, д. 72		0101000020E610000004E5B67D8F1044404D9F1D705DB94740
75534	2	23	898	20846	40112	\N	47.642007999999997	Ростовская область, Октябрьский район, Коммунарское сельское поселение, п. Новосветловский, ул. Мокроусова, №251		0101000020E610000014B01D8CD81744409BE271512DD24740
75539	2	23	898	21083	55506	\N	47.538235	Ростовская область, Октябрьский район, Красюковское сельское поселение, п. Новоперсиановка, ул. Советская, №12		0101000020E6100000E048A0C1A6FA434002486DE2E4C44740
75536	2	23	898	20956	56344	\N	47.767992	Ростовская область, Октябрьский район, Краснокутское сельское поселение, х. Новопавловка, ул. Центральная, №18-А		0101000020E6100000718FA50F5DFC434079CBD58F4DE24740
75519	2	23	898	19983	40437	\N	47.768802999999998	Ростовская область, Октябрьский район, Артемовское сельское поселение, п. Новокадамово, ул. Клубная, №7		0101000020E61000005D86FF74032744408908FF2268E24740
75550	2	23	898	21584	55654	\N	47.668816	Ростовская область, Октябрьский район, Мокрологское сельское поселение, п. Новозарянский, ул. Ленина, №33		0101000020E6100000E48574780837444051853FC39BD54740
75544	2	23	898	21324	39905	\N	47.586081999999998	Ростовская область, Октябрьский район, Краснолучское сельское поселение, п. Нижнедонской, ул. Ленина, №9		0101000020E610000010E7E104A63B44401B6327BC04CB4740
75549	2	23	898	21573	56331	\N	47.661650000000002	Ростовская область, Октябрьский район, Мокрологское сельское поселение, п. Мокрый Лог, ул. Рослова, №52-А		0101000020E6100000D5EDEC2B0F464440FFB27BF2B0D44740
75538	2	23	898	21047	56081	\N	47.656002811777697	Ростовская область, Октябрьский район, Краснокутское сельское поселение, х. Марьевка, ул. Вишневая, №6-А	Россия, Ростовская область, Октябрьский район, хутор Марьевка	0101000020E61000006C98A1F1440A4440F88903E8F7D34740
75551	2	23	898	21668	55631	\N	47.686495000000001	Ростовская область, Октябрьский район, Мокрологское сельское поселение, х. Маркин, ул. Клубная, №1		0101000020E610000025E7C41EDA2B44400BEF7211DFD74740
75547	2	23	898	21414	41044	\N	47.400789000000003	Ростовская область, Октябрьский район, Кривянское сельское поселение, ст. Кривянская, ул. Октябрьская, №81		0101000020E6100000327381CB631544405CCCCF0D4DB34740
75548	2	23	898	21414	39682	\N	47.400789000000003	Ростовская область, Октябрьский район, Кривянское сельское поселение, ст. Кривянская, ул. Кооперативная, №119		0101000020E6100000327381CB631544405CCCCF0D4DB34740
75546	2	23	898	21414	40114	\N	47.400789000000003	Ростовская область, Октябрьский район, Кривянское сельское поселение,ст. Кривянская, ул. Кирпичная, №1		0101000020E6100000327381CB631544405CCCCF0D4DB34740
75541	2	23	898	21211	40445	\N	47.531013999999999	Ростовская область, Октябрьский район, Красюковское сельское поселение, сл. Красюковская, ул. Советская, №24		0101000020E610000005F86EF3C60B4440ECDB4944F8C34740
75542	2	23	898	21211	40575	\N	47.531013999999999	Ростовская область, Октябрьский район, Красюковское сельское поселение, сл. Красюковская, ул. Горького, №67		0101000020E610000005F86EF3C60B4440ECDB4944F8C34740
75545	2	23	898	56810	56090	\N	47.661929000000001	Ростовская область, Октябрьский район, Краснолучское сельское поселение, х. Красный Луч, ул. Центральная, №54	Россия, Ростовская область, Октябрьский район, хутор Красный Луч	0101000020E6100000268DD13AAA2C444012A3E716BAD44740
75535	2	23	898	54810	39663	\N	47.684194685659399	Ростовская область, Октябрьский район, Краснокутское сельское поселение, х. Красный Кут, ул. Чистова, №2-В	Россия, Ростовская область, Октябрьский район, хутор Красный Кут	0101000020E6100000DC4603780B0444401A8BA6B393D74740
75530	2	23	898	20598	39660	\N	47.647781000000002	Ростовская область, Октябрьский район, Коммунарское сельское поселение, п. Красногорняцкий, ул. Чапаева, №26-А		0101000020E610000041B62C5F971944402FFCE07CEAD24740
75521	2	23	898	20105	56279	\N	47.685063999999997	Ростовская область, Октябрьский район, Мокрологское сельское поселение, х. Костиков, ул. Центральная, №56-В		0101000020E6100000D653ABAFAE2644405ED5592DB0D74740
75518	2	23	898	19895	55518	\N	47.773429999999998	Ростовская область, Октябрьский район, Артемовское сельское поселение, х. Киреевка, ул. Ленина, №1		0101000020E61000001230BABC3932444065DF15C1FFE24740
75527	2	23	898	20455	55658	\N	47.768422000000001	Ростовская область, Октябрьский район, Керчикское сельское поселение, х. Керчик-Савров, ул. Советская, №36		0101000020E6100000548B8862F24C444072C3EFA65BE24740
77661	2	23	898	22006	40195	\N	47.661175999999998	Ростовская область, Октябрьский район, Каменоломненское городское поселение, р.п. Каменоломни, пер.Шоссейный, 10А		0101000020E6100000EB7420EBA91944403673486AA1D44740
75560	2	23	898	22006	55187	\N	47.661175999999998	Ростовская область, Октябрьский район, Каменоломненское городское поселение, р.п. Каменоломни, ул. Ленина, №15		0101000020E6100000EB7420EBA91944403673486AA1D44740
75558	2	23	898	22006	40116	\N	47.661175999999998	Ростовская область, Октябрьский район, Каменоломненское городское поселение, р.п. Каменоломни, адрес помещения для голосования: ул. Крупской, №39, адрес УИК: ул. Крупской, №28-А		0101000020E6100000EB7420EBA91944403673486AA1D44740
75561	2	23	898	22006	40276	\N	47.661175999999998	Ростовская область, Октябрьский район, Каменоломненское городское поселение, р.п. Каменоломни, 4-й переулок, №1		0101000020E6100000EB7420EBA91944403673486AA1D44740
75559	2	23	898	56618	55176	\N	47.666348126299603	Ростовская область, Октябрьский район, Каменоломненское городское поселение, р.п. Каменоломни, ул. Дзержинского, №78-Б		0101000020E6100000234A7B832F1A4440A4E029E44AD54740
77640	2	23	898	26887	55967	\N	47.773445221030002	Ростовская область, Октябрьский район, Краснокутское сельское поселение, х. Калиновка, ул. Центральная, №32	Россия, Ростовская область, Октябрьский район, хутор Калиновка	0101000020E6100000DB4E5B23820144409B20EA3E00E34740
75526	2	23	898	20415	56328	\N	47.400435000000002	Ростовская область, Октябрьский район, Бессергеневское сельское поселение, х. Калинин, ул. Центральная, №82		0101000020E6100000679E5C53203744403E963E7441B34740
75556	2	23	898	21881	41048	\N	47.558250999999998	Ростовская область, Октябрьский район, Персиановское сельское поселение, п. Казачьи Лагери, ул. Российская, №4		0101000020E6100000931CB0ABC90F4440CAFACDC474C74740
75557	2	23	898	21881	55752	\N	47.558250999999998	Ростовская область, Октябрьский район, Персиановское сельское поселение, п. Казачьи Лагери, ул. им. Петрушко, №1		0101000020E6100000931CB0ABC90F4440CAFACDC474C74740
75555	2	23	898	21870	55629	\N	47.461142543738298	Ростовская область, Октябрьский район, Персиановское сельское поселение, п. Кадамовский, ул. Садовая, №5	Россия, Ростовская область, Октябрьский район, поселок Кадамовский	0101000020E61000007BC1A73979174440C1E3DBBB06BB4740
75537	2	23	898	20987	40113	\N	47.698492000000002	Ростовская область, Октябрьский район, Краснокутское сельское поселение, п. Интернациональный, ул. Железнодорожная, №57		0101000020E6100000FC8F4C874E1144404242942F68D94740
75517	2	23	898	19849	39658	\N	47.743664000000003	Ростовская область, Октябрьский район, Алексеевское сельское поселение, х. Ильичевка, ул. Победы Революции, №26		0101000020E610000040F7E5CC76F14340359BC76130DF4740
75524	2	23	898	20236	40438	\N	47.406936000000002	Ростовская область, Октябрьский район, Бессергеневское сельское поселение, ст. Заплавская, ул. Ленина, №1		0101000020E6100000A2F0D93A3828444054C8957A16B44740
75531	2	23	898	20688	56329	\N	47.589351000000001	Ростовская область, Октябрьский район, Коммунарское сельское поселение, п. Заозерье, адрес помещения для голосования: ул. Центральная, №11, адрес УИК: ул. Центральная, №10		0101000020E6100000DE550F98872A4440B56E83DA6FCB4740
75529	2	23	898	20588	55995	\N	47.748700610076298	Ростовская область, Октябрьский район, Керчикское сельское поселение, п. Залужный, ул. Школьная, №1	Россия, Ростовская область, Октябрьский район, поселок Залужный	0101000020E6100000F3AACE6A81454440C2BD326FD5DF4740
75528	2	23	898	52150	56169	\N	47.735035328243796	Ростовская область, Октябрьский район, Керчикское сельское поселение, х. Веселая Бахмутовка, ул. Логвинова, №2	Россия, Ростовская область, Октябрьский район, хутор Веселая Бахмутовка	0101000020E61000007E569929AD3B44402B357BA015DE4740
75522	2	23	898	20110	56332	\N	47.841329999999999	Ростовская область, Октябрьский район, Артемовское сельское поселение, х. Верхняя Кадамовка, ул. Галенко, №2		0101000020E6100000BFF4F6E7A2394440649291B3B0EB4740
75532	2	23	898	20706	40275	\N	47.598939999999999	Ростовская область, Октябрьский район, Коммунарское сельское поселение, п. Верхнегрушевский, Школьная, 20		0101000020E6100000904FC8CEDB1444401422E010AACC4740
75525	2	23	898	20340	40439	\N	47.400703	Ростовская область, Октябрьский район, Бессергеневское сельское поселение, ст. Бессергеневская, ул. Комарова, №7		0101000020E6100000C76471FF912B44405D34643C4AB34740
75543	2	23	898	21293	56000	\N	47.634473	Ростовская область, Октябрьский район, Красюковское сельское поселение, х. Аюта, ул. Заповедная, №2		0101000020E61000008847E2E5E9044440F698486936D14740
75520	2	23	898	19998	56040	\N	47.761643999999997	Ростовская область, Октябрьский район, Артемовское сельское поселение, п. Атюхта, ул. Центральная, №11-А		0101000020E61000004015376E311B4440E998F38C7DE14740
75516	2	23	898	19806	55576	\N	47.691602000000003	Ростовская область, Октябрьский район, Алексеевское сельское поселение, с. Алексеевка, адрес помещения для голосования: ул. Ленина, д.№2, адрес УИК: ул. Ленина, №13		0101000020E6100000E42EC214E5F6434092EC116A86D84740
76365	2	23	1758	28828	56044	\N	48.858345999999997	Ростовская область, Обливский район, поселок Шаповаловка, Центральная, 7		0101000020E61000007A7077D66E43454082531F48DE6D4840
76361	2	23	1758	28610	55836	\N	48.547516999999999	Ростовская область, Обливский район, поселок Средний Чир, Первомайская, 1а		0101000020E6100000EF3B86C77E3A454084807C0915464840
76376	2	23	1758	29333	56096	\N	48.660594000000003	Ростовская область, Обливский район, поселок Сосновый, Казачья, 1		0101000020E61000004391EEE71418454088F71C588E544840
76367	2	23	1758	28929	55551	\N	48.537166999999997	Ростовская область, Обливский район, хутор Солонецкий, Ленина, 8		0101000020E6100000FEEE1D3526244540C6BE64E3C1444840
76368	2	23	1758	28960	56309	\N	48.475408999999999	Ростовская область, Обливский район, хутор Сиволобов, Школьная, 9		0101000020E610000001FBE8D495154540AE9CBD33DA3C4840
76366	2	23	1758	28868	56059	\N	48.887352999999997	Ростовская область, Обливский район, поселок Пухов, Дорожная, 5		0101000020E6100000FF3F4E9830384540F58079C894714840
76358	2	23	1758	28310	40539	\N	48.538204999999998	Ростовская область, Обливский район, станица Обливская, Лесхозная, 1		0101000020E61000001E37FC6EBA3F454097C5C4E6E3444840
76355	2	23	1758	28310	39773	\N	48.538204999999998	Ростовская область, Обливский район, станица Обливская, Ленина, 47		0101000020E61000001E37FC6EBA3F454097C5C4E6E3444840
76354	2	23	1758	28310	39985	\N	48.538204999999998	Ростовская область, Обливский район, станица Обливская, Коммунистическая, 4		0101000020E61000001E37FC6EBA3F454097C5C4E6E3444840
76357	2	23	1758	28310	39986	\N	48.538204999999998	Ростовская область, Обливский район, станица Обливская, Грызлова, 18 а		0101000020E61000001E37FC6EBA3F454097C5C4E6E3444840
76369	2	23	1758	29012	56184	\N	48.555025000000001	Ростовская область, Обливский район, поселок Новополеевский, переулок Торговый, 9		0101000020E61000004E2B85402E0F454030BB270F0B474840
76363	2	23	1758	28707	55546	\N	48.6684685361096	Ростовская область, Обливский район, хутор Нестеркин, Центральная, 62	Россия, Ростовская область, Обливский район, хутор Нестеркин	0101000020E6100000D6027B4CA4404540E6B1666490554840
76373	2	23	1758	29174	56196	\N	48.7353066122947	Ростовская область, Обливский район, хутор Машинский, Центральная, 5		0101000020E6100000F4C29D0B231F45408BC22E8A1E5E4840
76360	2	23	1758	28605	55772	\N	48.537764000000003	Ростовская область, Обливский район, хутор Лобачев, Чирская, 38		0101000020E6100000B6847CD0B3314540AB7B6473D5444840
76371	2	23	1758	29079	56047	\N	48.707352999999998	Ростовская область, Обливский район, хутор Леонов, Терешковой, 5		0101000020E61000008D60E3FA770745401EDD088B8A5A4840
76279	2	23	1758	24901	56308	\N	48.751817000000003	Ростовская область, Обливский район, хутор Кривов, Центральная, 35		0101000020E610000037AAD381AC514540D6C9198A3B604840
76359	2	23	1758	28549	56043	\N	48.561024000000003	Ростовская область, Обливский район, хутор Ковыленский, Речная, 36		0101000020E61000004359F8FA5A4B4540B4226AA2CF474840
76375	2	23	1758	29281	56198	\N	48.622934000000001	Ростовская область, Обливский район, хутор Киреев, Мира, 38		0101000020E6100000C18F6AD8EF21454082C8224DBC4F4840
76364	2	23	1758	28784	55550	\N	48.751489999999997	Ростовская область, Обливский район, поселок Каштановский, Школьная, 4		0101000020E61000007FFB3A70CE424540B1A206D330604840
76374	2	23	1758	29229	56048	\N	48.623619532386698	Ростовская область, Обливский район, хутор Караичев, Восточная, 15	Россия, Ростовская область, Обливский район, хутор Караичев	0101000020E610000090A4A487A11B4540D690B8C7D24F4840
76362	2	23	1758	28674	56058	\N	48.626781000000001	Ростовская область, Обливский район, хутор Дубовой, Сосновая, 9		0101000020E6100000A45181936D58454089601C5C3A504840
76372	2	23	1758	29145	56064	\N	48.758747999999997	Ростовская область, Обливский район, хутор Алексеевский, Ленина, 11		0101000020E610000057B5A4A31C2C4540E4F38AA71E614840
76370	2	23	1758	29067	56199	\N	48.774532000000001	Ростовская область, Обливский район, хутор Александровский, Школьная, 4		0101000020E6100000EAE8B81AD90D45404DDA54DD23634840
76331	2	23	351	27276	56177	\N	48.441735000000001	Ростовская область, Морозовский район, хутор Гурин, улица Гурина, 17		0101000020E6100000F46A80D250074540D13FC1C58A384840
77139	2	23	73	2233	56358	\N	47.276988000000003	Ростовская область, Неклиновский район, Васильево-Ханжоновское сельское поселение, с. Щербаково, ул. Калинина, д. 30		0101000020E61000001135D1E7A334434036B1C05774A34740
77119	2	23	73	56863	56390	\N	47.359572999999997	Ростовская область, Неклиновский район, Федоровское сельское поселение, х. Чикилев, ул. Солнечная, д. 53	Россия, Ростовская область, Неклиновский район, хутор Чекилев	0101000020E610000025E99AC93733434026C3F17C06AE4740
77103	2	23	73	89	55498	\N	47.159722000000002	"Ростовская область, Неклиновский район, Поляковское сельское поселение, с. Христофоровка, ул. Октябрьская, д. 24""а"""		0101000020E6100000A5BC5642775B4340D2393FC571944740
77085	2	23	73	31740	56248	\N	47.329507999999997	"Ростовская область, Неклиновский район, Синявское сельское поселение, х. Халыбо-Адабашев, ул. Молодежная, д. 18""б"""		0101000020E61000003F90BC73289B43409BE271512DAA4740
77116	2	23	73	882	40762	\N	47.336244000000001	Ростовская область, Неклиновский район, Федоровское сельское поселение, с. Федоровка, ул. им. Ленина, д. 48		0101000020E6100000828FC18A53314340F5BC1B0B0AAB4740
77073	2	23	73	31102	39932	\N	47.362496	Ростовская область, Неклиновский район, Троицкое сельское поселение, с. Троицкое, ул. им. Ленина, д. 74		0101000020E6100000F758FAD0057343402577D84466AE4740
77072	2	23	73	31102	39932	\N	47.362496	"Ростовская область, Неклиновский район, Троицкое сельское поселение, с. Троицкое, ул. им. Ленина, д. 120""а"""		0101000020E6100000F758FAD0057343402577D84466AE4740
77124	2	23	73	1347	56258	\N	47.290308000000003	"Ростовская область, Неклиновский район, Носовское сельское поселение, х. Таврический, ул. Мира, д. 36""а"""		0101000020E6100000C9586DFE5F4B434033E202D028A54740
77067	2	23	73	30883	55783	\N	47.318623000000002	Ростовская область, Неклиновский район, Андреево-Мелентьевское сельское поселение, п. Сухосарматка, ул. Садовая, д. 14		0101000020E6100000C5C8923996654340706072A3C8A84740
77087	2	23	73	31818	55683	\N	47.503537999999999	Ростовская область, Неклиновский район, Советинское сельское поселение, сл. Советка, пр. им. Победы, д. 18		0101000020E6100000F9BA0CFFE9A043408925E5EE73C04740
77083	2	23	73	31651	\N	\N	47.277856	Ростовская область, Неклиновский район, Синявское сельское поселение, с. Синявское, здание железнодорожного вокзала ст. Синявская	Россия, Ростовская область, Неклиновский район, село Синявское	0101000020E610000068CEFA9463A44340AA7F10C990A34740
77084	2	23	73	31651	41294	\N	47.277856	Ростовская область, Неклиновский район, Синявское сельское поселение, с. Синявское, ул. им. Ленина, 351		0101000020E610000068CEFA9463A44340AA7F10C990A34740
77075	2	23	73	31238	41290	\N	47.324000402588197	Ростовская область, Неклиновский район, Самбекское сельское поселение, с. Самбек, ул. Кооперативная, д. 27	Россия, Ростовская область, Неклиновский район, село Самбек	0101000020E610000098512CB7B4824340B6F3FDD478A94740
77106	2	23	73	256	55479	\N	47.190074570560498	"Ростовская область, Неклиновский район, Поляковское сельское поселение, х. Русский Колодец, ул. Дзержинского, д. 14""а"""	Россия, Ростовская область, Неклиновский район, хутор Русский Колодец	0101000020E61000003BE0BA6246564340C364AA6054984740
77132	2	23	73	1807	55684	\N	47.143782000000002	"Ростовская область, Неклиновский район, Натальевское сельское поселение, х. Рожок, ул. им. Приходько П.Е, д. 23""а"""		0101000020E610000004FF5BC98E35434072E0D57267924740
77063	2	23	73	30657	56236	\N	47.378802999999998	Ростовская область, Неклиновский район, Андреево-Мелентьевское сельское поселение, х. Родионовка, ул. им. Ленина, д. 51	Россия, Ростовская область, Неклиновский район, хутор Родионовка	0101000020E6100000A73D25E7C45443403750E09D7CB04740
77140	2	23	73	2276	56116	\N	47.200843999999996	"Ростовская область, Неклиновский район, Васильево-Ханжоновское сельское поселение, х. Пудовой, ул. Гагарина, д. 17""а"""	Россия, Ростовская область, Неклиновский район, хутор Пудовой	0101000020E61000004DF8A57EDE2E434085CC9541B5994740
77093	2	23	73	32094	55963	\N	47.405588000000002	Ростовская область, Неклиновский район, Советинское сельское поселение, х. Приют, ул. Космическая, д. 49		0101000020E610000029266F809995434035D3BD4EEAB34740
77079	2	23	73	31469	41291	\N	47.277403999999997	"Ростовская область, Неклиновский район, Приморское сельское поселение, с. Приморка, ул. им. Ленина, д. 239""б"""		0101000020E6100000BE30992A18874340C9E369F981A34740
77133	2	23	73	1867	55570	\N	47.143445	Ростовская область, Неклиновский район, Платовское сельское поселение, п. Приазовский, ул. Луговая, 1-А		0101000020E61000006B0C3A21743043402AE3DF675C924740
77055	2	23	73	30229	41204	\N	47.430262357238597	Ростовская область, Неклиновский район, Покровское сельское поселение, с. Покровское, пер. им. Маяковского, д. 3	Россия, Ростовская область, Неклиновский район, село Покровское	0101000020E61000001AA20A7F86734340145B41D312B74740
77056	2	23	73	30229	55114	\N	47.413167999999999	Ростовская область, Неклиновский район, Покровское сельское поселение, с. Покровское, пер. Тургеневский, д. 12		0101000020E61000008D63247B847443407AE063B0E2B44740
77058	2	23	73	30229	40007	\N	47.413167999999999	Ростовская область, Неклиновский район, Покровское сельское поселение, с. Покровское, ул. Привокзальная, д. 38		0101000020E61000008D63247B847443407AE063B0E2B44740
77057	2	23	73	30229	40757	\N	47.413167999999999	Ростовская область, Неклиновский район, Покровское сельское поселение, с. Покровское, ул. им. Ленина, д. 438		0101000020E61000008D63247B847443407AE063B0E2B44740
45238	2	20	\N	242	23759	\N	45.029724999999999	город Краснодар, улица Садовая, дом 11, телефон: 2377129		0101000020E6100000B58D3F51D97E4340D26F5F07CE834640
77094	2	23	73	32126	41296	\N	47.183239	Ростовская область, Неклиновский район, Новобессергеневское сельское поселение, с. Петрушино, ул. им. Ворошилова, 102		0101000020E61000002BDA1CE7366F4340062D246074974740
77117	2	23	73	949	55977	\N	47.331965710463699	Ростовская область, Неклиновский район, Федоровское сельское поселение, х. Петровский, ул. Мичурина, д. 18		0101000020E6100000A1BAB9F8DB28434025B1A4DC7DAA4740
77062	2	23	73	30585	55788	\N	47.396763	Ростовская область, Неклиновский район, Большенеклиновское сельское поселение, с. Отрадное, ул. им. Ленина, д. 13		0101000020E6100000787C7BD7A05F4340A5A14621C9B24740
77122	2	23	73	1241	55700	\N	47.274560999999999	"Ростовская область, Неклиновский район, Носовское сельское поселение, с. Носово, ул. Клубная, д. 34""а"""		0101000020E6100000FAB660A92E564340E7E099D024A34740
77118	2	23	73	56830	\N	\N	47.367978604278498	"Ростовская область, Неклиновский район, Федоровское сельское поселение, х. Новофедоровский, помещение административного здания ООО ""Гелиос"""	Россия, Ростовская область, Неклиновский район, хутор Новофедоровский	0101000020E6100000A3755435412C4340B14E95EF19AF4740
77090	2	23	73	31976	56094	\N	47.446153000000002	Ростовская область, Неклиновский район, Советинское сельское поселение, с. Новостроенка, ул. им. Ленина, д. 23		0101000020E610000039454772F99B43409301A08A1BB94740
77080	2	23	73	31511	55505	\N	47.302647	Ростовская область, Неклиновский район, Приморское сельское поселение, п. Новоприморский, ул. Центральная, д. 1		0101000020E61000007B87DBA161894340C39D0B23BDA64740
77773	2	23	73	760	55632	\N	47.178975999999999	Ростовская область, Неклиновский район, Новобессергеневское сельское поселение, х. Новозолотовка, ул. Транспортная, д. 29		0101000020E610000020D3DA34B66743406B6281AFE8964740
77096	2	23	73	32236	39748	\N	47.183686000000002	Ростовская область, Неклиновский район, Новобессергеневское сельское поселение, с. Новобессергеневка, ул. Коминтерна, д. 33		0101000020E6100000666B7D91D06C4340D55DD90583974740
77100	2	23	73	32395	56238	\N	47.239424999999997	Ростовская область, Неклиновский район, Новобессергеневское сельское поселение, с. Никольское, ул. Центральная, д. 2		0101000020E6100000AF7C96E7C15D4340226C787AA59E4740
77127	2	23	73	1539	55966	\N	47.214207000000002	"Ростовская область, Неклиновский район, Натальевское сельское поселение, х. Николаево-Отрадное, ул. им. Ленина, д. 37""а"""		0101000020E610000085984BAAB643434082C98D226B9B4740
77138	2	23	73	2176	56202	\N	47.220132	Ростовская область, Неклиновский район, Васильево-Ханжоновское сельское поселение, х. Николаево-Козловский, ул. Шолохова, д. 16		0101000020E6100000CAA65CE15D2E4340CB660E492D9C4740
77137	2	23	73	2119	56052	\N	47.246423999999998	Ростовская область, Неклиновский район, Васильево-Ханжоновское сельское поселение, х. Николаево-Иловайский, ул. им. Ленина, д. 38		0101000020E6100000E73A8DB454344340897956D28A9F4740
77068	2	23	73	883	41230	\N	47.301107000000002	Ростовская область, Неклиновский район, Николаевское сельское поселение, с. Николаевка, пер. Школьный, д. 1		0101000020E6100000904C874ECF6B434060CC96AC8AA64740
77775	2	23	73	883	40305	\N	47.301107000000002	Ростовская область, Неклиновский район, Николаевское сельское поселение, с. Николаевка, ул. Садовая, д. 103		0101000020E6100000904C874ECF6B434060CC96AC8AA64740
77069	2	23	73	883	40305	\N	47.301107000000002	Ростовская область, Неклиновский район, Николаевское сельское поселение, с. Николаевка, ул.Садовая,39		0101000020E6100000904C874ECF6B434060CC96AC8AA64740
77070	2	23	73	883	41286	\N	47.301107000000002	Ростовская область, Неклиновский район, Николаевское сельское поселение, с. Николаевка, ул. им. Ленина, д. 341		0101000020E6100000904C874ECF6B434060CC96AC8AA64740
77086	2	23	73	31795	56104	\N	47.367178000000003	Ростовская область, Неклиновский район, Самбекское сельское поселение, х. Некрасовка, пер. Молодежный, д. 11		0101000020E6100000344C6DA9838E4340C5E74EB0FFAE4740
77125	2	23	73	1412	40764	\N	47.170664000000002	"Ростовская область, Неклиновский район, Натальевское сельское поселение, с. Натальевка, ул. Чехова, д. 46""а"""		0101000020E610000089D349B6BA3C4340624D6551D8954740
77082	2	23	73	31570	55735	\N	47.284213999999999	"Ростовская область, Неклиновский район, Синявское сельское поселение, х. Морской Чулек, ул. Красногвардейская, д. 21""а"""		0101000020E6100000B2497EC4AF9A43405D88D51F61A44740
77121	2	23	73	1188	55974	\N	47.372225	Ростовская область, Неклиновский район, Федоровское сельское поселение, х. Михайловка, ул. Садовая, здание фельдшерско-акушерского пункта		0101000020E61000000E4C6E14593D434076E09C11A5AF4740
77081	2	23	73	31567	55805	\N	47.290565067988403	Ростовская область, Неклиновский район, Синявское сельское поселение, х. Мержаново, ул. Первомайская, д. 31	Россия, Ростовская область, Неклиновский район, хутор Мержаново	0101000020E61000003CD862B7CF9243405E2EE23B31A54740
77064	2	23	73	30691	56099	\N	47.349066999999998	Ростовская область, Неклиновский район, Андреево-Мелентьевское сельское поселение, с. Марьевка, ул. им. Ленина, д. 100		0101000020E610000084D72E6D38504340718E3A3AAEAC4740
77110	2	23	73	454	55978	\N	47.229109000000001	"""Ростовская область, Неклиновский район, Лакедемоновское сельское поселение, с. Малофедоровка, ул. Клубная, д. 8-А"		0101000020E610000092EBA694D74C4340111C9771539D4740
77130	2	23	73	1690	56244	\N	47.166663	Ростовская область, Неклиновский район, Платовское сельское поселение, х. Максимов, пер. Кольцевой, д. 2-А		0101000020E61000009F94490D6D204340043A933655954740
75435	2	23	1220	56634	55280	\N	46.876536512702003	Ростовская область, Зерноградский район, х. Чернышевка, Центральная, 14		0101000020E61000000ADAE4F0495D4440F25D4A5D32704740
77091	2	23	73	32019	55961	\N	47.472026999999997	Ростовская область, Неклиновский район, Советинское сельское поселение, х. Любовка, ул. Красносельская, д. 24		0101000020E61000006A34B918039543401CEA77616BBC4740
77126	2	23	73	56960	56501	\N	47.198847999999998	Ростовская область, Неклиновский район, Натальевское сельское поселение, х. Ломакино, ул. Набережная, д. 9	Россия, Ростовская область, Неклиновский район, хутор Ломакин	0101000020E610000038C0CC77F04143400070ECD973994740
77112	2	23	73	637	39749	\N	47.197885999999997	"Ростовская область, Неклиновский район, Лакедемоновское сельское поселение, с. Лакедемоновка, ул. им. Ленина, д. 50""б"""		0101000020E6100000668522DDCF4543400A2B155454994740
77074	2	23	73	31177	55704	\N	47.359702694056203	Ростовская область, Неклиновский район, Самбекское сельское поселение, х. Курлацкий, ул. Кооперативная, д. 3	Россия, Ростовская область, Неклиновский район, хутор Курлацкий	0101000020E610000015562AA8A8884340F5A276BF0AAE4740
77102	2	23	73	56697	55802	\N	47.1670916133777	Ростовская область, Неклиновский район, Поляковское сельское поселение, х, Красный Десант, ул, Октябрьская, д. 2	Россия, Ростовская область, Неклиновский район, хутор Красный Десант	0101000020E6100000F01989D0085E43402CB6494563954740
77092	2	23	73	32035	56237	\N	47.452685000000002	Ростовская область, Неклиновский район, Советинское сельское поселение, х. Копани, ул. Металлургическая, д. 32		0101000020E6100000793F6EBF7C864340E4310395F1B94740
77104	2	23	73	114	41299	\N	47.15493	Ростовская область, Неклиновский район, Поляковское сельское поселение, х. Ключникова Балка, ул. Октябрьская, д. 83		0101000020E61000001E335019FF564340AB9509BFD4934740
77123	2	23	73	1311	56251	\N	47.248204000000001	Ростовская область, Неклиновский район, Носовское сельское поселение, с. Ивановка, ул. Миусская, д. 29		0101000020E6100000226DE34F544C4340425E0F26C59F4740
77105	2	23	73	196	55699	\N	47.144849000000001	"Ростовская область, Неклиновский район, Поляковское сельское поселение, п. Золотая Коса, ул. Октябрьская, д. 73""а"""		0101000020E610000012143FC6DC514340DDED7A698A924740
77061	2	23	73	30540	55962	\N	47.437413999999997	"Ростовская область, Неклиновский район, Большенеклиновское сельское поселение, х. Жатва, ул. Полевая, д. 1""а"""		0101000020E61000002028B7ED7B6443400168942EFDB74740
77120	2	23	73	1117	55495	\N	47.318147000000003	Ростовская область, Неклиновский район, Федоровское сельское поселение, с. Ефремовка, ул. Транспортная, д. 1		0101000020E6100000336FD575A83C43400729780AB9A84740
77098	2	23	73	32247	56356	\N	47.180526	"""Ростовская область, Неклиновский район, Новобессергеневское сельское поселение, п. Дмитриадовка, ул. 2-я Степная, д. 1"		0101000020E61000005D52B5DD04694340F209D9791B974740
77099	2	23	73	32336	56109	\N	47.241348738686199	Ростовская область, Неклиновский район, Новобессергеневское сельское поселение, х. Дарагановка, ул. Центральная, д. 160	Россия, Ростовская область, Неклиновский район, хутор Дарагановка	0101000020E6100000511553E9276643400EF62686E49E4740
77089	2	23	73	31898	56083	\N	47.529268000000002	Ростовская область, Неклиновский район, Советинское сельское поселение, с. Горская Порада, ул. Центральная, д. 22		0101000020E6100000D15B3CBCE7A44340E068C70DBFC34740
77071	2	23	73	31042	40307	\N	47.273124000000003	Ростовская область, Неклиновский район, Николаевское сельское поселение, х. Гаевка, пер. Ореховый, д. 12		0101000020E6100000B79C4B71556B434059E02BBAF5A24740
77108	2	23	73	337	56239	\N	47.236696999999999	"""Ростовская область, Неклиновский район, Лакедемоновское сельское поселение, с. Гаевка, ул. им. Ленина, д. 34А"		0101000020E610000010CF126404544340D90759164C9E4740
77101	2	23	73	56623	55260	\N	47.1732289558392	Ростовская область, Неклиновский район, Поляковское сельское поселение, х. Веселое, ул. им. Ленина, д. 11	Россия, Ростовская область, Неклиновский район, хутор Веселый	0101000020E6100000F86F5E9CF860434001DC2C5E2C964740
77129	2	23	73	1652	41339	\N	47.148237999999999	"Ростовская область, Неклиновский район, Платовское сельское поселение, с. Весело-Вознесенка, ул. Октябрьская, д. 93""а"""		0101000020E6100000D26F5F07CE2B434021037976F9924740
77136	2	23	73	2055	55497	\N	47.228172999999998	Ростовская область, Неклиновский район, Васильево-Ханжоновское сельское поселение, с. Васильево-Ханжоновка, ул. Школьная, д. 9		0101000020E6100000F3E8465854304340446ADAC5349D4740
77076	2	23	73	31304	39747	\N	47.287466000000002	Ростовская область, Неклиновский район, Вареновское сельское поселение, с. Вареновка, ул. Советская, д. 124		0101000020E6100000D670917BBA824340215B96AFCBA44740
77059	2	23	73	30459	55478	\N	47.426600000000001	"Ростовская область, Неклиновский район, Большенеклиновское сельское поселение, с. Большая Неклиновка, пер. Памятный, д. 1""а"""		0101000020E61000007CB779E3A46E43409F3C2CD49AB64740
77060	2	23	73	30459	55477	\N	47.426600000000001	"Ростовская область, Неклиновский район, Большенеклиновское сельское поселение, с. Большая Неклиновка, ул. Школьная, д. 76""а"""		0101000020E61000007CB779E3A46E43409F3C2CD49AB64740
77078	2	23	73	31374	40758	\N	47.277360999999999	Ростовская область, Неклиновский район, Вареновское сельское поселение, с. Бессергеновка, ул. Школьная, д. 2		0101000020E610000037397CD2897E4340CA17B49080A34740
77115	2	23	73	705	56373	\N	47.136892144171703	"Ростовская область, Неклиновский район, Лакедемоновское сельское поселение, с. Беглица, 11-й участок, ул. Садовая, д. 81""а"""	Россия, Ростовская область, Неклиновский район, село Беглица	0101000020E6100000EA3F6B7EFC454340C28A53AD85914740
44928	2	20	301	50243	21343	\N	46.698206999999996	город Ейск, Кирпичная, 12, телефон: 75045		0101000020E61000009F1C0588822343404C6BD3D85E594740
77113	2	23	73	705	55975	\N	47.137647000000001	"Ростовская область, Неклиновский район, Лакедемоновское сельское поселение, с. Беглица, 16-й участок, ул. Октябрьская, д. 68""б"""		0101000020E6100000EBA7FFACF94543403EB2B96A9E914740
77114	2	23	73	705	55840	\N	47.137647000000001	"Ростовская область, Неклиновский район, Лакедемоновское сельское поселение, с. Беглица, 13-й участок, ул. им. Ленина, д. 30""а"""		0101000020E6100000EBA7FFACF94543403EB2B96A9E914740
77066	2	23	73	30790	55681	\N	47.304926000000002	Ростовская область, Неклиновский район, Андреево-Мелентьевское сельское поселение, с. Андреево-Мелентьево, ул. им. Победы, д. 16-а		0101000020E610000045292158556743409DD9AED007A74740
77128	2	23	73	1574	56102	\N	47.232799	Ростовская область, Неклиновский район, Носовское сельское поселение, х. Александрово-Марково, ул. Энгельса, д. 18		0101000020E6100000C780ECF5EE47434050C58D5BCC9D4740
77673	2	23	73	28343	55611	\N	47.177236000000001	Ростовская область, Неклиновский район, Новобессергеневское сельское поселение, с. Александрова Коса, ул. Цветочная, д. 1		0101000020E61000002B69C5371466434041D653ABAF964740
76961	2	23	1296	56798	55973	\N	47.4280492117271	Ростовская область, Мясниковский район, Петровское сельское поселение, х. Чкалова, Нижняя	Россия, Ростовская область, Мясниковский район, хутор Чкалова	0101000020E6100000C0B167CF65A04340F20A444FCAB64740
76948	2	23	1296	13597	40640	\N	47.284789000000004	Ростовская область, Мясниковский район, Чалтырское сельское поселение, с. Чалтырь, Туманяна, 2		0101000020E610000011902FA182BF43405AA148F773A44740
76709	2	23	1296	13597	40131	\N	47.284789000000004	Ростовская область, Мясниковский район, Чалтырское сельское поселение, с. Чалтырь, Синявская, 19 Б		0101000020E610000011902FA182BF43405AA148F773A44740
76946	2	23	1296	13597	41275	\N	47.284789000000004	Ростовская область, Мясниковский район, Чалтырское сельское поселение, с. Чалтырь, Октябрьская, 36		0101000020E610000011902FA182BF43405AA148F773A44740
76947	2	23	1296	13597	40148	\N	47.284789000000004	Ростовская область, Мясниковский район, Чалтырское сельское поселение, с. Чалтырь, Мясникяна, 18		0101000020E610000011902FA182BF43405AA148F773A44740
76945	2	23	1296	13597	40148	\N	47.284789000000004	Ростовская область, Мясниковский район, Чалтырское сельское поселение, с. Чалтырь, Мясникяна, 88		0101000020E610000011902FA182BF43405AA148F773A44740
76949	2	23	1296	13597	41276	\N	47.284789000000004	Ростовская область, Мясниковский район, Чалтырское сельское поселение, с. Чалтырь, 6-я линия, 86		0101000020E610000011902FA182BF43405AA148F773A44740
76959	2	23	1296	25864	55584	\N	47.268948000000002	Ростовская область, Мясниковский район, Недвиговское сельское поселение, х. Хапры, пер.Макаренко, 9		0101000020E61000007EC9C6832DB843408D2958E36CA24740
76955	2	23	1296	25697	55801	\N	47.356141999999998	Ростовская область, Мясниковский район, Краснокрымское сельское поселение, с. Султан Салы, Селиверстова, 2		0101000020E610000077BAF3C473CA4340B35DA10F96AD4740
76962	2	23	1296	56662	55403	\N	47.485634314936298	Ростовская область, Мясниковский район, Петровское сельское поселение, сл. Петровка, Школьная, 15	Россия, Ростовская область, Мясниковский район, слобода Петровка	0101000020E61000009B5AB6D617B94340AFE9414129BE4740
76956	2	23	1296	25715	56194	\N	47.452618000000001	Ростовская область, Мясниковский район, Большесальское сельское поселение, с. Несветай, Ворошилова, 1 А		0101000020E6100000A4FE7A8505D543405CCAF962EFB94740
77712	2	23	1296	56893	56422	\N	47.268312000000002	Ростовская область, Мясниковский район, Чалтырское сельское поселение, х. Мокрый Чалтырь, Ленина, 3	Россия, Ростовская область, Мясниковский район, хутор Мокрый Чалтырь	0101000020E6100000EBE40CC51DBD4340EB8F300C58A24740
76953	2	23	1296	57017	56565	\N	47.308128000000004	Ростовская область, Мясниковский район, Краснокрымское сельское поселение, х. Ленинакан, Трудовая, 1	Россия, Ростовская область, Мясниковский район, хутор Ленинакан	0101000020E6100000158F8B6A11D34340AF7D01BD70A74740
76952	2	23	1296	56629	55273	\N	47.282295881339699	Ростовская область, Мясниковский район, Краснокрымское сельское поселение, х. Ленинаван, Ленина, 5	Россия, Ростовская область, Мясниковский район, хутор Ленинаван	0101000020E6100000F5BA4560ACCF434054E57B4622A44740
76942	2	23	1296	25055	40747	\N	47.306866363073397	Ростовская область, Мясниковский район, Крымское сельское поселение, с. Крым, Советская, 3	Россия, Ростовская область, Мясниковский район, село Крым	0101000020E61000001E705D3123C243408E20956247A74740
76950	2	23	1296	25055	40749	\N	47.306807999999997	Ростовская область, Мясниковский район, Крымское сельское поселение, с. Крым, 8-я линия, 14		0101000020E6100000A663CE33F6C1434059130B7C45A74740
76954	2	23	1296	56674	55583	\N	47.336775000000003	Ростовская область, Мясниковский район, Краснокрымское сельское поселение, х. Красный Крым, Туманяна, 51	Россия, Ростовская область, Мясниковский район, хутор Красный Крым	0101000020E61000001A170E8464D14340228E75711BAB4740
77659	2	23	1296	56633	55278	\N	47.244588999999998	Ростовская область, Мясниковский район, Калининское сельское поселение, х. Калинин, Школьная, 136	Россия, Ростовская область, Мясниковский район, хутор Калинин	0101000020E6100000BC77D49810C143400DFB3DB14E9F4740
76951	2	23	1296	56633	55278	\N	47.245407261089497	Ростовская область, Мясниковский район, Калининское сельское поселение, х. Калинин, Школьная, 81	Россия, Ростовская область, Мясниковский район, хутор Калинин	0101000020E610000094FB1D8A02C14340D09A1F7F699F4740
76960	2	23	1296	25912	40304	\N	47.330449000000002	Ростовская область, Мясниковский район, Недвиговское сельское поселение, х. Веселый, ул. Новая, 5		0101000020E6100000B55208E412A743407AFF1F274CAA4740
76957	2	23	1296	25788	40750	\N	47.389997999999999	Ростовская область, Мясниковский район, Большесальское сельское поселение, с. Большие Салы, Советская, 8		0101000020E61000003337DF88EED74340B1C05774EBB14740
77757	2	23	1296	25788	39844	\N	47.389997999999999	Ростовская область, Мясниковский район, Большесальское сельское поселение, с. Большие Салы, Оганяна, 7		0101000020E61000003337DF88EED74340B1C05774EBB14740
76963	2	23	1296	26039	55492	\N	47.453398	Ростовская область, Мясниковский район, Петровское сельское поселение, с. Александровка 2-я, Центральная, 26		0101000020E61000000531D0B52FB04340310917F208BA4740
76335	2	23	351	27439	56093	\N	48.252690000000001	Ростовская область, Морозовский район, хутор Широко-Атамановский, улица Мира, 33		0101000020E6100000C0EC9E3C2CF044405C035B2558204840
76346	2	23	351	27974	55949	\N	47.876497000000001	Ростовская область, Морозовский район, станица Чертковская, улица Степная, 22		0101000020E610000046EA3D95D3FE44406405BF0D31F04740
76339	2	23	351	27660	56346	\N	48.132755000000003	Ростовская область, Морозовский район, хутор Чекалов, улица Центральная, 12б		0101000020E61000004FAF946588034540B4B0A71DFE104840
76353	2	23	351	28259	56185	\N	48.372396000000002	Ростовская область, Морозовский район, хутор Трофименков, улица Садовая, 14		0101000020E6100000D996016729DB4440A39410ACAA2F4840
76341	2	23	351	27745	\N	\N	48.077810999999997	Ростовская область, Морозовский район, поселок Табунный, здание школы, 17		0101000020E610000025E659492BEC44407022FAB5F5094840
76347	2	23	351	28014	55952	\N	47.906599078073299	Ростовская область, Морозовский район, хутор Старопетровский, улица Лютиковая, 1	Россия, Ростовская область, Морозовский район, хутор Старопетровский	0101000020E61000008B8862F206EE44400CCB9F6F0BF44740
76349	2	23	351	28075	56183	\N	48.298954000000002	Ростовская область, Морозовский район, хутор Сибирьки, улица Степная, 21		0101000020E6100000C6DCB5847CDC44401381EA1F44264840
76342	2	23	351	27778	56230	\N	48.007173999999999	Ростовская область, Морозовский район, поселок Разлатный, здание школы, 7		0101000020E6100000BDFBE3BD6AF14440D5B0DF13EB004840
76334	2	23	351	27422	56091	\N	48.306955000000002	Ростовская область, Морозовский район, хутор Покровский, улица Покровская, 52		0101000020E6100000FACF9A1F7F0B4540FE2B2B4D4A274840
76345	2	23	351	27902	55675	\N	47.958714000000001	Ростовская область, Морозовский район, хутор Парамонов, улица Центральная, 41		0101000020E61000000917F2086EF84440D21BEE23B7FA4740
76328	2	23	351	27147	56223	\N	48.448751000000001	Ростовская область, Морозовский район, хутор Общий, улица Энтузиастов, 33		0101000020E6100000029B73F04CEA44400E863AAC70394840
76352	2	23	351	28230	56189	\N	48.375323000000002	Ростовская область, Морозовский район, хутор Новопроциков, улица Школьная, 54		0101000020E6100000C7F319506FD04440E33785950A304840
76343	2	23	351	27816	55674	\N	48.020448692616398	Ростовская область, Морозовский район, хутор Николаев, улица Придорожная, 29б	Россия, Ростовская область, Морозовский район, хутор Николаев	0101000020E6100000221B48179BDE4440321EA5129E024840
76321	2	23	351	1764	40088	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Филонова, 7		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76322	2	23	351	1764	41166	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Ляшенко, 96		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76317	2	23	351	1764	40531	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Луначарского, 122		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76472	2	23	351	1764	40090	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Ленина, 296		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76377	2	23	351	1764	40090	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Ленина, 169		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76325	2	23	351	1764	40258	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Кирова, 152		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76324	2	23	351	1764	40258	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Кирова, 124		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76316	2	23	351	1764	39766	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Карла Маркса, 5		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76319	2	23	351	1764	39982	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Дзержинского, 7		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76323	2	23	351	1764	40257	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Ворошилова, 264		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76320	2	23	351	1764	40257	\N	48.356161999999998	Ростовская область, Морозовский район, город Морозовск, улица Ворошилова, 170		0101000020E61000009F71E14048EA4440FA0967B7962D4840
76332	2	23	351	27295	39768	\N	48.334682000000001	Ростовская область, Морозовский район, хутор Морозов, улица Дорожная, 34		0101000020E6100000B58D3F51D9F04440AA471ADCD62A4840
76336	2	23	351	27522	56095	\N	48.202007000000002	Ростовская область, Морозовский район, хутор Малая Хлоповая, улица Солнечная, 26		0101000020E6100000B98B3045B9EA44401348895DDB194840
76351	2	23	351	28156	55549	\N	48.401786999999999	Ростовская область, Морозовский район, хутор Костино-Быстрянский, улица Котельникова, 74		0101000020E6100000B9895A9A5BD344409E7AA4C16D334840
76337	2	23	351	27537	56345	\N	48.192374000000001	Ростовская область, Морозовский район, поселок Комсомольский, улица Центральная, 51		0101000020E610000017F2086EA4F44440E44C13B69F184840
76340	2	23	351	27689	55672	\N	48.039709000000002	Ростовская область, Морозовский район, поселок Знаменка, улица Дружбы, 18		0101000020E61000007094BC3AC7E84440AE2D3C2F15054840
76333	2	23	351	27354	55951	\N	48.269443000000003	Ростовская область, Морозовский район, хутор Донской, улица Школьная, 17		0101000020E61000000E881057CE0245406D91B41B7D224840
76327	2	23	351	27081	55774	\N	48.406159000000002	Ростовская область, Морозовский район, хутор Грузинов, улица Центральная, 55		0101000020E6100000488AC8B08AE34440F0FCA204FD334840
76348	2	23	351	28065	55547	\N	48.297136999999999	Ростовская область, Морозовский район, станица Вольно-Донская, улица Стадионная, 3		0101000020E6100000B51A12F758D044403DB7D09508264840
76329	2	23	351	27163	55618	\N	48.378763999999997	Ростовская область, Морозовский район, хутор Вознесенский, улица Центральная, 14		0101000020E610000047718E3A3AF844407973B8567B304840
77692	2	23	351	29224	56111	\N	48.158486000000003	Ростовская область, Морозовский район, хутор Владимиров, улица Молодежная, 26		0101000020E61000003FFD67CD8FE74440DB6FED4449144840
76350	2	23	351	28140	56056	\N	48.218218999999998	Ростовская область, Морозовский район, хутор Вишневка, улица Центральная, 40		0101000020E6100000DB1324B6BBDB4440D32EA699EE1B4840
76330	2	23	351	27232	56085	\N	48.451464000000001	Ростовская область, Морозовский район, хутор Вербочки, улица Мира, 37		0101000020E61000005D363AE7A700454022A98592C9394840
77691	2	23	351	29168	56010	\N	48.391455894723002	Ростовская область, Морозовский район, хутор Быстрый, улица Быстрая, 30	Россия, Ростовская область, Морозовский район, хутор Быстрый	0101000020E6100000C79C67EC4B08454057E9EE3A1B324840
76338	2	23	351	27607	55950	\N	48.137566	Ростовская область, Морозовский район, хутор Беляев, улица Молодежная, 2а		0101000020E6100000446D1B4641E8444051853FC39B114840
76344	2	23	351	27882	55565	\N	47.903317000000001	Ростовская область, Морозовский район, хутор Александров, улица Центральная, 13		0101000020E6100000075C57CC08DF4440DE7536E49FF34740
76307	2	23	167	56781	55931	\N	48.625733618227898	Ростовская область, Милютинский район, х. Юдин (правый берег реки Гнилой), ул. Заречная, д. 2/35	Россия, Ростовская область, Милютинский район, хутор Юдин	0101000020E61000001D1EC2F869DA444065FF3C0D18504840
77621	2	23	167	56781	56442	\N	48.625506000000001	Ростовская область, Милютинский район, х. Юдин (левый берег реки Гнилой), пер. Березовый, д. 3	Россия, Ростовская область, Милютинский район, хутор Юдин	0101000020E6100000F2D1E28C61DA4440D4B9A29410504840
76306	2	23	167	56904	56435	\N	48.570398556313798	Ростовская область, Милютинский район, х. Широко-Бахолдинский, ул. Школьная, д. 4	Россия, Ростовская область, Милютинский район, хутор Широко-Бахолдинский	0101000020E6100000C5AEEDED96F84440E7559DD502494840
77719	2	23	167	56972	56513	\N	48.586092000000001	Ростовская область, Милютинский район, х. Терновой, ул. Городская, д. 1	Россия, Ростовская область, Милютинский район, хутор Терновой	0101000020E610000041D3122BA3C744403F390A10054B4840
76311	2	23	167	56752	55899	\N	48.548316488348298	Ростовская область, Милютинский район, х. Сулинский, ул. Центральная, д. 18/2	Россия, Ростовская область, Милютинский район, хутор Сулинский	0101000020E610000072FC5069C4C24440D0EFFB372F464840
76309	2	23	167	56690	55733	\N	48.614443347613403	Ростовская область, Милютинский район, х. Старокузнецов, пер. Культурный, д. 6	Россия, Ростовская область, Милютинский район, хутор Старокузнецов	0101000020E6100000F23FF9BB77D24440C9207711A64E4840
76299	2	23	167	594	55486	\N	48.847948000000002	Ростовская область, Милютинский район, ст. Селивановская, ул.Титова, д. 21		0101000020E6100000A0E238F06ADD4440B45A608F896C4840
77770	2	23	167	594	55971	\N	48.847948000000002	Ростовская область, Милютинский район, ст. Селивановская, ул. Песчаная, д. 48		0101000020E6100000A0E238F06ADD4440B45A608F896C4840
76300	2	23	167	57009	56557	\N	48.811371999999999	Ростовская область, Милютинский район, х. Севостьянов, ул. Школьная, д. 23	Россия, Ростовская область, Милютинский район, хутор Севостьянов	0101000020E6100000535E2BA1BBEA4440EF71A609DB674840
76305	2	23	167	26088	56038	\N	48.551817	Ростовская область, Милютинский район, п. Светоч, ул. Западная, д. 2/2		0101000020E61000001C0C7558E1E444403C3080F0A1464840
76298	2	23	167	56859	56385	\N	48.785242632985302	Ростовская область, Милютинский район, х. Решетняков, ул. Центральная, д. 14	Россия, Ростовская область, Милютинский район, хутор Решетняков	0101000020E610000014AE47E17ACE4440DB34B6D782644840
77768	2	23	167	56975	56517	\N	48.749785000000003	Ростовская область, Милютинский район, х. Павловка, ул. Пионерская, д. 18	Россия, Ростовская область, Милютинский район, хутор Павловка	0101000020E61000008DD13AAA9AC44440040473F4F85F4840
76304	2	23	167	56945	56484	\N	48.651998173830499	Ростовская область, Милютинский район, х. Орлов, ул. Центральная, д. 3	Россия, Ростовская область, Милютинский район, хутор Орлов	0101000020E6100000B61490F63FF044405987A3AB74534840
76310	2	23	167	57002	56550	\N	48.612617999999998	Ростовская область, Милютинский район, х. Образцов, ул. Студенческая, д. 6	Россия, Ростовская область, Милютинский район, хутор Образцов	0101000020E610000096CD1C925AD84440707841446A4E4840
76301	2	23	167	56843	56310	\N	48.920899028771998	Ростовская область, Милютинский район, х. Новодмитриевский, ул. Новодмитриевская, д. 12	Россия, Ростовская область, Милютинский район, хутор Новодмитриевский	0101000020E610000088A1D5C919E44440A5F5B704E0754840
76293	2	23	167	56672	55568	\N	48.677830559796298	Ростовская область, Милютинский район, х. Николовка, пер. Школьный, д. 2		0101000020E610000050340F6091B54440849B8C2AC3564840
76295	2	23	167	56948	56488	\N	48.736738000000003	Ростовская область, Милютинский район, х. Нижнепетровский, ул. Ермака, д. 3	Россия, Ростовская область, Милютинский район, хутор Нижнепетровский	0101000020E610000024F0879FFFC4444038DC476E4D5E4840
77769	2	23	167	519	40040	\N	48.628340999999999	Ростовская область, Милютинский район, ст. Милютинская, ул. Красноармейская, д. 14		0101000020E610000084622B685AD6444033DE567A6D504840
4016	1	16	442	3716	\N	\N	54.187716999999999	с. Машковичи, д. 86		0101000020E610000008043A93362342409DF3531C07184B40
76308	2	23	167	519	40083	\N	48.628340999999999	Ростовская область, Милютинский район, ст. Милютинская, ул. Комсомольская, д. 32		0101000020E610000084622B685AD6444033DE567A6D504840
76296	2	23	167	25701	55617	\N	48.771687999999997	Ростовская область, Милютинский район, сл. Маньково-Березовская, пер. Проходной, д. 18		0101000020E6100000EB8B84B69CC744409A5B21ACC6624840
76302	2	23	167	56901	56431	\N	48.905920999999999	Ростовская область, Милютинский район, х. Кутейников, ул. Центральная, д. 14	Россия, Ростовская область, Милютинский район, хутор Кутейников	0101000020E6100000CEA5B8AAECEF44403BE12538F5734840
76303	2	23	167	26011	56181	\N	48.713487999999998	Ростовская область, Милютинский район, п. Доброполье, ул. Солнечная, д. 2		0101000020E61000002FA699EE75F44440520B2593535B4840
77771	2	23	167	636	56114	\N	48.955787000000001	Ростовская область, Милютинский район, х. Вячеслав, ул. Вячеслав, д. 9		0101000020E6100000E544BB0A29E744409278793A577A4840
77772	2	23	167	56995	56541	\N	48.881264692563299	Ростовская область, Милютинский район, х. Волоцков, ул. Мира, д. 9	Россия, Ростовская область, Милютинский район, хутор Волоцков	0101000020E61000006A4FC939B1EB4440020EA14ACD704840
77767	2	23	167	56964	56505	\N	48.636932999999999	Ростовская область, Милютинский район, х. Антоновка, ул. Сельская, д. 4	Россия, Ростовская область, Милютинский район, хутор Антоновка	0101000020E6100000E78A5242B0AC4440205F420587514840
76312	2	23	167	26405	56180	\N	48.588183999999998	Ростовская область, Милютинский район, п. Аграрный, ул. Строительная, д. 18/27		0101000020E6100000D5E76A2BF6B74440E603029D494B4840
76105	2	23	1388	16236	56271	\N	49.016587999999999	Ростовская область, Миллеровский район, п. Ярский, ул. Молодежная, 11		0101000020E6100000E19BA6CF0E684440C6C03A8E1F824840
76112	2	23	1388	56699	55839	\N	49.122921335486403	Ростовская область, Миллеровский район, х. Хмызов, ул. Ленина, 7	Россия, Ростовская область, Миллеровский район, хутор Хмызов	0101000020E6100000B7B6F0BC54664440ED7E15E0BB8F4840
76102	2	23	1388	56941	56482	\N	49.020316000000001	Ростовская область, Миллеровский район, х. Фоминка, ул. Станиславского, 2	Россия, Ростовская область, Миллеровский район, хутор Фоминка	0101000020E6100000917C2590124B4440F3CAF5B699824840
76099	2	23	1388	56788	55939	\N	48.8525688888666	Ростовская область, Миллеровский район, х. Туроверово, ул. Российская, 48	Россия, Ростовская область, Миллеровский район, хутор Туроверово-Глубокинский	0101000020E6100000A5F44C2F31304440AE4A22FB206D4840
77638	2	23	1388	56800	55985	\N	48.975802000000002	Ростовская область, Миллеровский район, х. Треневка, пер. Школьный, 3	Россия, Ростовская область, Миллеровский район, хутор Треневка	0101000020E6100000BB473657CD2D44408AAF7614E77C4840
76131	2	23	1388	17558	56168	\N	48.990825999999998	Ростовская область, Миллеровский район, слобода Титовка, ул. Ленина, 8		0101000020E61000006E3315E291DE43406403E962D37E4840
76128	2	23	1388	26822	55880	\N	48.929830838626998	Ростовская область, Миллеровский район, х. Терновой, ул.Школьная, 32	Россия, Ростовская область, Миллеровский район, хутор Терновой	0101000020E61000003B55BE67242C44404BE7C3B304774840
76111	2	23	1388	16544	55838	\N	49.101077546861099	Ростовская область, Миллеровский район, слобода Терновая, ул. Школьная, 22	Россия, Ростовская область, Миллеровский район, слобода Терновая	0101000020E6100000D95DA0A4C05444402C2CB81FF08C4840
76138	2	23	1388	56758	55905	\N	48.9098280315918	Ростовская область, Миллеровский район, х. Сулин, ул. Северная, 9	Россия, Ростовская область, Миллеровский район, хутор Сулин	0101000020E61000009B559FABAD104440177E703E75744840
76135	2	23	1388	17759	56026	\N	48.932259999999999	Ростовская область, Миллеровский район, слобода Рогалик, ул. Дружбы, 67		0101000020E610000079B0C56E9F0744403AAFB14B54774840
76120	2	23	1388	17005	56021	\N	49.045768000000002	Ростовская область, Миллеровский район, слобода Поповка, ул. Садовая, 3		0101000020E6100000F4E159828C3C4440079ACFB9DB854840
76108	2	23	1388	16391	55725	\N	48.855702000000001	Ростовская область, Миллеровский район, слобода Позднеевка, ул. Советская, 2-а		0101000020E6100000772CB64945754440978FA4A4876D4840
76110	2	23	1388	16497	55540	\N	49.018030000000003	Ростовская область, Миллеровский район,  село Ольховый-Рог, ул. Вокзальная, 6		0101000020E6100000F965304624584440672C9ACE4E824840
77702	2	23	1388	56718	55861	\N	48.910699207572101	Ростовская область, Миллеровский район, х. Новоспасовка, ул. Центральная, 11	Россия, Ростовская область, Миллеровский район, хутор Новоспасовка	0101000020E61000000BF148BC3C3B4440FDBFEAC891744840
76124	2	23	1388	56841	56298	\N	49.06485	Ростовская область, Миллеровский район, х. Новая Деревня, ул. Милькевича, 8	Россия, Ростовская область, Миллеровский район, хутор Новая Деревня	0101000020E61000002F6CCD565E0A4440A3923A014D884840
76104	2	23	1388	16169	55835	\N	48.960974999999998	Ростовская область, Миллеровский район, слобода Никольская, ул. Школьная, 43		0101000020E610000051888043A856444005A3923A017B4840
76130	2	23	1388	17494	55757	\N	48.995626000000001	Ростовская область, Миллеровский район, слобода Нижненагольная, ул. Российская, 1		0101000020E6100000F7AC6BB41CFA43400E863AAC707F4840
76134	2	23	1388	17699	56022	\N	48.999136999999997	Ростовская область, Миллеровский район, слобода Нижнекамышинка, ул. Центральная, 11		0101000020E610000043041C4295EC43409D9CA1B8E37F4840
76096	2	23	1388	54851	41142	\N	48.934122740851898	Ростовская область, Миллеровский район, Миллеровское городское поселение, квартал имени маршала Ефимова, гимназия №7	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E6100000FDDAFAE93F33444080B8AB5791774840
76087	2	23	1388	54851	55608	\N	48.939169431744801	Ростовская область, Миллеровский район, Миллеровское городское поселение, квартал ДСХТ, 29	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E6100000B5F97FD591334440613596B036784840
76088	2	23	1388	54851	55436	\N	48.921814862860899	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Энгельса, 26	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E610000030D63730B93344402BFBAE08FE754840
76084	2	23	1388	54851	40516	\N	48.930051086813599	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Осоавиахима, 15	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E6100000FDDAFAE93F334440594E42E90B774840
76093	2	23	1388	54851	55320	\N	48.908911644936303	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Нахимова, 45	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E61000006C97361C963044409278793A57744840
76085	2	23	1388	54851	55360	\N	48.9210017709525	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Менделеева, 37	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E6100000A1F5F065A23244407AC6BE64E3754840
76091	2	23	1388	54851	55289	\N	48.923751868122999	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Криничная, 16		0101000020E61000003198BF42E6324440ABCE6A813D764840
76095	2	23	1388	54851	55262	\N	48.924728627448097	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Заводская, 15	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E6100000AD174339D1324440D65416855D764840
76089	2	23	1388	54851	55283	\N	48.924487145874302	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Жуковского, 60	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E6100000081C0934D8324440E0490B9755764840
76086	2	23	1388	54851	41138	\N	48.930167175108402	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Донецкая, 2	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E61000008D25AC8DB1334440C26856B60F774840
76090	2	23	1388	54851	55312	\N	48.922692456904301	Ростовская область, Миллеровский район, Миллеровское городское поселение, ул. Артиллерийская, 16	Россия, Ростовская область, Миллеровский район, Миллерово	0101000020E61000000264E8D841314440F2237EC51A764840
76132	2	23	1388	17598	56020	\N	48.950012999999998	Ростовская область, Миллеровский район, слобода Машлыкино, пер. Школьный, 22		0101000020E61000001B12F758FAE443402EE3A6069A794840
76127	2	23	1388	17349	55560	\N	48.984915984774602	Ростовская область, Миллеровский район, слобода Мальчевско-Полненская, ул. Школьная, 1	Россия, Ростовская область, Миллеровский район, слобода Мальчевско-Полненская	0101000020E6100000DBBE47FDF51A444050A73CBA117E4840
76119	2	23	1388	16936	40078	\N	49.061791999999997	Ростовская область, Миллеровский район, станица Мальчевская, ул. Голдобина, 1-а		0101000020E6100000876F61DD782D4440C493DDCCE8874840
76101	2	23	1388	56783	55934	\N	48.9483365610159	Ростовская область, Миллеровский район, х. Малотокмацкий, ул. Мира, 15	Россия, Ростовская область, Миллеровский район, хутор Малотакмацкий	0101000020E6100000D3687231063E44401B4B581B63794840
76118	2	23	1388	16921	55753	\N	49.208768999999997	Ростовская область, Миллеровский район,  слобода Кудиновка, ул. Победы, 21		0101000020E61000002592E865143F444095B54DF1B89A4840
76109	2	23	1388	56883	56411	\N	48.899749999999997	Ростовская область, Миллеровский район, х. Криничный, ул. Речная, 79	Россия, Ростовская область, Миллеровский район, хутор Криничный	0101000020E6100000056C0723F6714440BA490C022B734840
76106	2	23	1388	16310	40523	\N	48.853687000000001	Ростовская область, Миллеровский район, слюбода Криворожье, ул. Ленина, 33		0101000020E61000002481069B3A6144409B02999D456D4840
76117	2	23	1388	16864	40524	\N	49.155334000000003	Ростовская область, Миллеровский район, слобода Колодези, ул. Советская, 15		0101000020E6100000BFB854A52D3844407BFA08FCE1934840
76103	2	23	1388	56794	55945	\N	48.886629176382101	Ростовская область, Миллеровский район, х. Каменка, ул. Почтовая, 2	Россия, Ростовская область, Миллеровский район, хутор Каменка	0101000020E6100000BF6378EC674D4440B4571F0F7D714840
77701	2	23	1388	56969	56510	\N	48.982737999999998	Ростовская область, Миллеровский район, х. Ивановка, ул. Фабричная, 21	Россия, Ростовская область, Миллеровский район, хутор Ивановка	0101000020E6100000FA0E7EE2003E4440AA44D95BCA7D4840
76121	2	23	1388	56993	56539	\N	49.022507864047597	Ростовская область, Миллеровский район, х. Зеленая Роща, ул. Школьная, 3-а		0101000020E610000061AA99B514324440FEF2C98AE1824840
75481	2	23	1388	56998	56545	\N	48.922072999999997	Ростовская область, Миллеровский район, х. Жеребковский, ул. Свободы, 7	Россия, Ростовская область, Миллеровский район, хутор Жеребковский	0101000020E61000007C48F8DEDF0A444026C3F17C06764840
76113	2	23	1388	56882	56410	\N	49.149277926481801	Ростовская область, Миллеровский район, х. Еритовка, ул. Центральная, 14	Россия, Ростовская область, Миллеровский район, хутор Еритовка	0101000020E6100000124C35B3966C44409301A08A1B934840
76107	2	23	1388	56873	56401	\N	48.825997699446397	Ростовская область, Миллеровский район, х. Екатериновка, ул. Юбилейная, 85	Россия, Ростовская область, Миллеровский район, хутор Екатериновка	0101000020E610000040C39B35785F4440DC476E4DBA694840
76126	2	23	1388	17285	55605	\N	48.929798033271901	Ростовская область, Миллеровский район, п. Долотинка, ул. Советская, 3-в	Россия, Ростовская область, Миллеровский район, поселок Долотинка	0101000020E6100000BAC0E5B1662444406FF1F09E03774840
76115	2	23	1388	16774	41146	\N	49.163139999999999	Ростовская область, Миллеровский район, слобода Дегтево, ул. Российская, 34		0101000020E61000000C01C0B167554440B05582C5E1944840
3760	1	16	1223	23289	25323	\N	54.081986000000001	г. Болохово, Мира, 20		0101000020E61000004EB4AB90F2E942406C5D6A847E0A4B40
76100	2	23	1388	56837	56270	\N	48.842849000000001	Ростовская область, Миллеровский район, х. Греково-Станичный, ул. Станичная, 26	Россия, Ростовская область, Миллеровский район, хутор Греково-Станичный	0101000020E6100000A4A5F276843B4440B03BDD79E26B4840
76125	2	23	1388	17254	55759	\N	48.901176999999997	Ростовская область, Миллеровский район, слобода Греково, ул. Центральная, 3		0101000020E6100000A8380EBC5A1C4440257497C459734840
76116	2	23	1388	56918	56451	\N	49.164790000000004	Ростовская область, Миллеровский район, х. Грай-Воронец, ул. Московская, 77	Россия, Ростовская область, Миллеровский район, хутор Грай-Воронец	0101000020E61000003909A52F844E44409B5AB6D617954840
76122	2	23	1388	56802	56019	\N	49.055431141778797	Ростовская область, Миллеровский район, х. Гетманов, ул. Гетмановская, 41	Россия, Ростовская область, Миллеровский район, хутор Гетманов	0101000020E6100000F4A62215C6224440A017EE5C18874840
77700	2	23	1388	57019	56568	\N	49.104973000000001	Ростовская область, Миллеровский район, х. Гернер, ул. Восточная, 9	Россия, Ростовская область, Миллеровский район, хутор Гернер	0101000020E6100000B39597FC4F14444044FB58C16F8D4840
76133	2	23	1388	17657	41147	\N	48.919668999999999	Ростовская область, Миллеровский район, слобода Волошино, ул. Ленина, 27		0101000020E6100000E3A7716F7EF743409012BBB6B7754840
76098	2	23	1388	56739	55886	\N	48.818201213679899	Ростовская область, Миллеровский район, х. Верхнеталовка, ул. Центральная, 38	Россия, Ростовская область, Миллеровский район, хутор Верхнеталовка	0101000020E6100000759483D9042E4440FA4674CFBA684840
76123	2	23	1388	56773	55921	\N	49.071042153981097	Ростовская область, Миллеровский район, х. Венделеевка, ул. Молодежная, 2	Россия, Ростовская область, Миллеровский район, хутор Венделеевка	0101000020E610000011FE45D0981B44403B527DE717894840
77699	2	23	1388	57008	56556	\N	49.049565000000001	Ростовская область, Миллеровский район, х. Беляевск, ул. Школьная, 3	Россия, Ростовская область, Миллеровский район, хутор Беляевск	0101000020E6100000EC3191D26C1444405C035B2558864840
76136	2	23	1388	56963	56504	\N	48.973285733333	Ростовская область, Миллеровский район, х. Ануфриевка, ул. Калинина, 91	Россия, Ростовская область, Миллеровский район, хутор Ануфриевка	0101000020E61000004DBB9866BA0B4440CCD3B9A2947C4840
77643	2	23	431	56866	56394	\N	47.585181165491001	Ростовская область, Матвеево-Курганский район, х. Шапошниково, ул. Примиусская, д. 88	Россия, Ростовская область, Матвеево-Курганский район, село Шапошниково	0101000020E61000000C1F115322674340CB9E0436E7CA4740
77613	2	23	431	25614	56245	\N	47.534506	Ростовская область, Матвеево-Курганский район, п. Сухореченский, ул. Парковая, д. 1		0101000020E6100000B75D68AED36E434005C24EB16AC44740
77147	2	23	431	56698	55815	\N	47.602482000000002	Ростовская область, Матвеево-Курганский район, х. Староротовка, пр. Дружбы, д. 68		0101000020E610000026C632FD126F4340DF3653211ECD4740
77149	2	23	431	2798	39754	\N	47.483994000000003	Ростовская область, Матвеево-Курганский район, с. Рясное, ул. Таганрогская, д. 2А		0101000020E610000005DD5ED218754340E9BAF083F3BD4740
77148	2	23	431	2724	41347	\N	47.505794029349303	Ростовская область, Матвеево-Курганский район, с. Ряженое, ул. Ленина, д. 4	Россия, Ростовская область, Матвеево-Курганский район, село Ряженое	0101000020E61000003A4030478F6F4340AB4198DBBDC04740
77151	2	23	431	2923	55786	\N	47.523344881899298	Ростовская область, Матвеево-Курганский район, с. Политотдельское, ул. Азарова, д. 12	Россия, Ростовская область, Матвеево-Курганский район, село Политотдельское	0101000020E61000009D2B4A09C188434037C30DF8FCC24740
77161	2	23	431	3483	55588	\N	47.617559999999997	Ростовская область, Матвеево-Курганский район, с. Новониколаевка, ул. Ленина, д. 69А		0101000020E6100000C310397D3D574340ACA8C1340CCF4740
77153	2	23	431	3028	55790	\N	47.573523999999999	Ростовская область, Матвеево-Курганский район, с. Новоандриановка, ул. 50 лет Победы, д. 48		0101000020E6100000DA39CD02ED8443404DBC033C69C94740
77156	2	23	431	3204	55585	\N	47.644669161296498	Ростовская область, Матвеево-Курганский район, п. Надежда, ул. Первомайская, д. 38	Россия, Ростовская область, Матвеево-Курганский район, поселок Надежда	0101000020E61000004223D8B8FE6B43405DDF878384D24740
77145	2	23	431	2342	39753	\N	47.575173495519003	Ростовская область, Матвеево-Курганский район, п. Матвеев Курган, ул. Славы, д. 6	Россия, Ростовская область, Матвеево-Курганский район, поселок Матвеев Курган	0101000020E6100000FA47DFA4696E43406745D4449FC94740
77612	2	23	431	2342	39791	\N	47.574824999999997	Ростовская область, Матвеево-Курганский район, п. Матвеев Курган, ул. Донецкая, д. 1		0101000020E610000046088F368E6E43402BF697DD93C94740
77144	2	23	431	2342	39750	\N	47.574824999999997	Ростовская область, Матвеево-Курганский район, п. Матвеев Курган, ул. 1-я Пятилетка, д. 107		0101000020E610000046088F368E6E43402BF697DD93C94740
77141	2	23	431	2342	39750	\N	47.574824999999997	Ростовская область, Матвеево-Курганский район, п. Матвеев Курган, ул. 1-я Пятилетка, д. 42		0101000020E610000046088F368E6E43402BF697DD93C94740
77142	2	23	431	2342	41345	\N	47.574824999999997	Ростовская область, Матвеево-Курганский район, п. Матвеев Курган, ул. 1-я Мая, д. 18		0101000020E610000046088F368E6E43402BF697DD93C94740
77152	2	23	431	2966	55480	\N	47.591957999999998	Ростовская область, Матвеево-Курганский район, с. Марьевка, ул. Парамонова, д. 39А		0101000020E6100000459DB98784914340834D9D47C5CB4740
77163	2	23	431	3606	41350	\N	47.595846999999999	Ростовская область, Матвеево-Курганский район, с. Марфинка, ул. Центральная, д. 59А		0101000020E61000003FA7203F1B434340B935E9B644CC4740
77169	2	23	431	3885	55812	\N	47.469681999999999	Ростовская область, Матвеево-Курганский район, с. Малокирсановка, ул. Аникиенко, д. 52		0101000020E61000006420CF2EDF4243408BC22E8A1EBC4740
77166	2	23	431	56953	56493	\N	47.501857999999999	Ростовская область, Матвеево-Курганский район, х. Малоекатериновка, ул. Центральная, д. 32	Россия, Ростовская область, Матвеево-Курганский район, хутор Малоекатериновка	0101000020E6100000CFD8976C3C2C4340349E08E23CC04740
77162	2	23	431	3533	55500	\N	47.565548	Ростовская область, Матвеево-Курганский район, п. Ленинский, ул. Центральная, д. 35		0101000020E6100000F437A11001534340BB287AE063C84740
77170	2	23	431	3934	40154	\N	47.476805434714201	Ростовская область, Матвеево-Курганский район, с. Латоново, ул. Ленина, д. 61	Россия, Ростовская область, Матвеево-Курганский район, село Латоново	0101000020E6100000AA0CE36E10514340DEC83CF207BD4740
77155	2	23	431	3158	55575	\N	47.688932999999999	Ростовская область, Матвеево-Курганский район, с. Кульбаково, ул. Таганрогская, д. 56А		0101000020E610000018096D39977643404D11E0F42ED84740
77159	2	23	431	3385	55587	\N	47.612172615970501	Ростовская область, Матвеево-Курганский район, п. Крынка, ул. Светлая, д. 19	Россия, Ростовская область, Матвеево-Курганский район, поселок Крынка	0101000020E6100000AF795567B5664340423F53AF5BCE4740
77146	2	23	431	2629	56115	\N	47.574162000000001	Ростовская область, Матвеево-Курганский район, п. Красный Бумажник, ул. Заречная, д. 4		0101000020E6100000FDFA213658664340904DF2237EC94740
77172	2	23	431	4038	56073	\N	47.428715383495401	Ростовская область, Матвеево-Курганский район, х. Красная Горка, ул. Школьная, д. 2А	Россия, Ростовская область, Матвеево-Курганский район, хутор Красная Горка	0101000020E6100000FF976BD102584340FE261422E0B64740
77614	2	23	431	56780	55930	\N	47.5391709717982	Ростовская область, Матвеево-Курганский район, х. Колесниково, ул. Таганрогская, д. 2		0101000020E6100000E4BED53A71714340CFF9298E03C54740
77150	2	23	431	2856	55572	\N	47.505985000000003	Ростовская область, Матвеево-Курганский район, с. Каменно-Андрианово, ул. Центральная, д. 66		0101000020E61000004C6BD3D85E8143401FA2D11DC4C04740
77165	2	23	431	3695	40155	\N	47.53989	Ростовская область, Матвеево-Курганский район, с. Екатериновка, пер. Школьный, д. 2		0101000020E61000006EFC89CA86314340FEB7921D1BC54740
77167	2	23	431	3801	55502	\N	47.448085940573002	Ростовская область, Матвеево-Курганский район, с. Григорьевка, ул. Кирова, д. 34	Россия, Ростовская область, Матвеево-Курганский район, село Григорьевка	0101000020E6100000882F134548314340D2E5CDE15AB94740
77168	2	23	431	3830	55511	\N	47.429264000000003	Ростовская область, Матвеево-Курганский район, с. Греково-Тимофеевка, ул. Мира, д. 57		0101000020E6100000C91EA16648414340D2AC6C1FF2B64740
77154	2	23	431	3082	55787	\N	47.656084	Ростовская область, Матвеево-Курганский район, х. Большая Кирсановка, ул. Советская, д. 91Б		0101000020E6100000FA0CA837A3724340E5B67D8FFAD34740
77164	2	23	431	3644	40766	\N	47.562958000000002	Ростовская область, Матвеево-Курганский район, с. Анастасиевка, ул. Ленина, д. 49		0101000020E6100000643DB5FAEA424340C382FB010FC84740
77157	2	23	431	3268	55789	\N	47.635420000000003	Ростовская область, Матвеево-Курганский район, с. Алексеевка, ул. Гагарина, д. 34		0101000020E61000005E4C33DDEB684340B79C4B7155D14740
77065	2	23	431	30759	55696	\N	47.634678999999998	Ростовская область, Матвеево-Курганский район, с. Александровка, ул. Московская, д. 39А		0101000020E6100000AEF199EC9F6543409F3A56293DD14740
77690	2	23	431	56997	56544	\N	47.676965000000003	Ростовская область, Матвеево-Курганский район, х. Авило-Федоровка, ул. Победы, д. 1	Россия, Ростовская область, Матвеево-Курганский район, хутор Авило-Федоровка	0101000020E61000008FE046CA165F4340B1C403CAA6D64740
77160	2	23	431	3430	40309	\N	47.689284999999998	Ростовская область, Матвеево-Курганский район, с. Авило-Успенка, ул. Ленина, д. 60		0101000020E6100000B401D88008574340CA4FAA7D3AD84740
75855	2	23	406	4100	40456	\N	47.339455999999998	Ростовская область, Мартыновский район, п. Южный, пер. Клубный, здание Дома культуры, д.1		0101000020E61000002D095053CBEE44402A37514B73AB4740
75856	2	23	406	4100	40052	\N	47.339455999999998	Ростовская область, Мартыновский район, п. Южный, пер. Административный, здание начальной школы №2, д.4		0101000020E61000002D095053CBEE44402A37514B73AB4740
75822	2	23	406	2273	55667	\N	47.437804	Ростовская область, Мартыновский район, п. Черемухи, ул. Ленина,  здание МОУ ООШ №13, д.11		0101000020E6100000E6E61BD13D9D44406C0723F609B84740
75857	2	23	406	4214	55586	\N	47.367147000000003	Ростовская область, Мартыновский район, п. Центральный, ул. Ленина, здание бывшей школы, д.62		0101000020E610000009E1D1C611ED44408AE942ACFEAE4740
75826	2	23	406	2506	56262	\N	47.156205	Ростовская область, Мартыновский район, п. Типчаковый, ул. Краснопартизанская, здание ФАП, д.2А		0101000020E6100000DFE1766858DA4440603C8386FE934740
75828	2	23	406	2630	56274	\N	47.151535000000003	Ростовская область, Мартыновский район, п. Степной Маяк, ул. Широкая, здание бывшей школы, д.23		0101000020E61000009D9CA1B8E3F144408599B67F65934740
75833	2	23	406	2926	55515	\N	47.312545	Ростовская область, Мартыновский район, х. Сальский Кагальник, ул. Центральная, здание МОУ ООШ №20, д.9		0101000020E6100000D3307C444CAD4440A0C37C7901A84740
75854	2	23	406	56884	56414	\N	47.310853000000002	Ростовская область, Мартыновский район, х. Пробуждение, ул. Юбилейная, здание сельского Дома культуры, д.57		0101000020E6100000FA2B64AE0CEC4440876EF607CAA74740
75847	2	23	406	3698	56148	\N	47.285375000000002	"Ростовская область, Мартыновский район, п. Поречье, ул. Северная, здание МБДОУ детский сад ""Колокольчик"", д.1/2"		0101000020E6100000433C122F4FD944404A0C022B87A44740
75843	2	23	406	56669	55520	\N	47.271010713242198	Ростовская область, Мартыновский район, х. Новоселовка, ул. Кировская, здание сельского Дома культуры, д. 3А	Россия, Ростовская область, Мартыновский район, хутор Новоселовка	0101000020E610000038BA4A77D7BD44409AED0A7DB0A24740
75830	2	23	406	56645	55310	\N	47.1950993940806	"Ростовская область, Мартыновский район, х. Новосадковский, ул. Центральная, здание МДОУ детский сад ""Аленький цветочек"", д. 2"	Россия, Ростовская область, Мартыновский район, хутор Новосадковский	0101000020E6100000C6DCB5847CA64440BC3D0801F9984740
75852	2	23	406	57028	56584	\N	47.257824999999997	Ростовская область, Мартыновский район, х.Новониколаевский, ул.школьная,24	Россия, Ростовская область, Мартыновский район, хутор Новониколаевский	0101000020E610000075029A081BE84440AC8BDB6800A14740
75849	2	23	406	3798	56009	\N	47.275624999999998	Ростовская область, Мартыновский район, п. Новомартыновский, ул. Думенко, здание ФАП, д.14		0101000020E610000053B4722F30DB4440E17A14AE47A34740
75842	2	23	406	3428	55516	\N	47.236249999999998	Ростовская область, Мартыновский район, п. Новоберезовка, ул. Центральная, здание сельского Дома культуры, д.16А		0101000020E6100000F78E1A1362D044400AD7A3703D9E4740
75844	2	23	406	56836	56264	\N	47.283841000000002	Ростовская область, Мартыновский район, х. Несмеяновка, ул. Несмеяновская, здание сельского Дома культуры, д.116	Россия, Ростовская область, Мартыновский район, хутор Несмеяновка	0101000020E61000000E1137A792BD4440C921E2E654A44740
75846	2	23	406	56910	56443	\N	47.160888155257602	Ростовская область, Мартыновский район, х. Московский, ул. Московская, здание филиала МОУ СОШ №1, д.79А	Россия, Ростовская область, Мартыновский район, хутор Московский	0101000020E6100000EC4D0CC9C9CC4440D0285DFA97944740
75832	2	23	406	56648	55317	\N	47.291223864114599	Ростовская область, Мартыновский район, х. Малоорловский, ул. Новая, здание сельского Дома культуры, д.25	Россия, Ростовская область, Мартыновский район, хутор Малоорловский	0101000020E6100000320395F1EFB14440B8E7F9D346A54740
75858	2	23	406	56682	55698	\N	47.332249807417703	"Ростовская область, Мартыновский район, х. М-Мартыновка, ул. Административная, здание конторы ОАО ""Южно-Цимлянское"", д.9"	Россия, Ростовская область, Мартыновский район, хутор Малая Мартыновка	0101000020E6100000055262D7F6EA44404A0C022B87AA4740
75823	2	23	406	2348	55670	\N	47.425179999999997	"Ростовская область, Мартыновский район, п. Малая Горка, ул. Садовая,  здание МБДОУ детский сад ""Ивушка"", д.11"		0101000020E61000005B087250C2AA4440E674594C6CB64740
75834	2	23	406	56763	55911	\N	47.338974	Ростовская область, Мартыновский район, х. Лесной, ул. Центральная, здание сельского Дома культуры, д.2	Россия, Ростовская область, Мартыновский район, хутор Лесной	0101000020E610000097AC8A7093B94440DF18028063AB4740
75831	2	23	406	2793	56259	\N	47.368855550966899	Ростовская область, Мартыновский район, п. Крутоярский, ул. Широкая, здание сельского дома культуры, д.1	Россия, Ростовская область, Мартыновский район, поселок Крутоярский	0101000020E6100000BDC62E51BDBF4440797764AC36AF4740
75820	2	23	406	2167	55530	\N	47.344878000000001	Ростовская область, Мартыновский район, п. Крутобережный, ул. Мира, здание МОУ СОШ №8, д. 27		0101000020E61000000B5EF415A49B4440118E59F624AC4740
75851	2	23	406	56751	55898	\N	47.245902011602901	Ростовская область, Мартыновский район, х. Кривой Лиман, ул. Молодежная, здание сельского Дома культуры, д.29	Россия, Ростовская область, Мартыновский район, хутор Кривой Лиман	0101000020E6100000462234828DDF4440B0027CB7799F4740
75845	2	23	406	56943	56481	\N	47.253312438852198	Ростовская область, Мартыновский район, х. Красноармейский, ул. Красноармейская, здание бывшей школы, д.71А	Россия, Ростовская область, Мартыновский район, хутор Красноармейский	0101000020E61000000AA2EE0390B6444099D711876CA04740
75829	2	23	406	54884	40218	\N	47.276956503831599	Ростовская область, Мартыновский район, х. Комаров, улица Никифорова,  здание администрации Комаровского СП, д.37а	Россия, Ростовская область, Мартыновский район, хутор Комаров	0101000020E6100000A774B0FECFA14440FBB2B45373A34740
75825	2	23	406	56721	55864	\N	47.3109623598477	Ростовская область, Мартыновский район, х. Ильинов, пер. Пионерский, здание сельского Дома культуры, д.8	Россия, Ростовская область, Мартыновский район, хутор Ильинов	0101000020E61000006D1CB1169FF844403E26529ACDA74740
75821	2	23	406	2231	41076	\N	47.413668000000001	Ростовская область, Мартыновский район, п. Зеленолугский, пер. Строительный, здание МОУ СОШ №5, д.10		0101000020E61000009A3FA6B5699A44406CB3B112F3B44740
75853	2	23	406	56877	56405	\N	47.302793879539998	Ростовская область, Мартыновский район, х. Засальский, ул. Ленина, здание сельского Дома культуры, д.75	Россия, Ростовская область, Мартыновский район, хутор Засальский	0101000020E610000011C64FE3DEE0444067B62BF4C1A64740
75836	2	23	406	56765	55913	\N	47.2573952617551	Ростовская область, Мартыновский район, х. Долгий, ул. Школьная, здание сельского Дома культуры, д.23	Россия, Ростовская область, Мартыновский район, хутор Долгий	0101000020E610000083A44FABE8AB4440B493C151F2A04740
75835	2	23	406	56768	55916	\N	47.370308744609197	Ростовская область, Мартыновский район, х. Денисов, ул. Школьная, здание МОУ СОШ №9, д.23	Россия, Ростовская область, Мартыновский район, хутор Денисов	0101000020E6100000562AA8A8FAB744400D350A4966AF4740
75841	2	23	406	3380	56011	\N	47.207118999999999	Ростовская область, Мартыновский район, п. Гром-Гора, ул. Центральная,  здание бывшей школы, д.15А		0101000020E61000005EBEF561BDC74440ABB019E0829A4740
75859	2	23	406	4312	55522	\N	47.409632000000002	Ростовская область, Мартыновский район, п. Восход, пер. Экскаваторный, здание МОУ ООШ №15, д.7		0101000020E610000097917A4FE5EC444092B245D26EB44740
75827	2	23	406	56959	56500	\N	47.288719	Ростовская область, Мартыновский район, х. Веселый, ул. Кирова, здание сельского дома культуры, д. 21	Россия, Ростовская область, Мартыновский район, хутор Веселый	0101000020E61000009C1551137D084540EE5D83BEF4A44740
75818	2	23	406	56641	55388	\N	47.329927663472297	Ростовская область, Мартыновский район, сл. Б-Орловка, ул. Советская, здание сельского Дома культуры, д. 25	Россия, Ростовская область, Мартыновский район, слобода Большая Орловка	0101000020E610000089230F4416A344407104A9143BAA4740
75819	2	23	406	56641	55295	\N	47.330627907537497	"Ростовская область, Мартыновский район, сл. Б-Орловка, ул. Октябрьская,  здание МБДОУ детский сад ""Сказка"", д.88"		0101000020E610000065DF15C1FFA244402992AF0452AA4740
75840	2	23	406	3161	40452	\N	47.280461162479398	Ростовская область, Мартыновский район, сл. Б-Мартыновка, пер. Зыгина, здание МОУ СОШ №1, д.12	Россия, Ростовская область, Мартыновский район, слобода Большая Мартыновка	0101000020E61000005628D2FD9CD44440D8666325E6A34740
75837	2	23	406	3161	40220	\N	47.276279000000002	Ростовская область, Мартыновский район, слобода Б-Мартыновка, улица Ленина, здание районного Дома культуры, д.98		0101000020E6100000C11C3D7E6FD544402AC93A1C5DA34740
75839	2	23	406	3161	55307	\N	47.277423805146803	Ростовская область, Мартыновский район, сл. Б-Мартыновка, ул. Ковалева, здание Центра дополнительного образования дете, д.1А	Россия, Ростовская область, Мартыновский район, слобода Большая Мартыновка	0101000020E61000003B014D840DD5444011902FA182A34740
75848	2	23	406	56722	55865	\N	47.239314165458097	Ростовская область, Мартыновский район, х. Арбузов, ул. Школьная, здание МОУ ООШ №16, д.24	Россия, Ростовская область, Мартыновский район, хутор Арбузов	0101000020E6100000B1BFEC9E3CD64440CBBC55D7A19E4740
75824	2	23	406	2398	56257	\N	47.404685999999998	Ростовская область, Мартыновский район, п. Абрикосовый, ул. Школьная, здание филиала МОУ СОШ №3, д.5А		0101000020E61000009CA5643909A14440149337C0CCB34740
77503	2	23	141	20417	56376	\N	47.785733999999998	Ростовская область, Куйбышевский район, Куйбышевское сельское поселение, хутор Свободный, ул. Победы, 29		0101000020E6100000B89388F02F6A434079AD84EE92E44740
77501	2	23	141	20237	55984	\N	47.745202999999997	Ростовская область, Куйбышевский район, Куйбышевское сельское поселение, село Русское, ул. Красноармейская, 8-А		0101000020E610000071C971A774784340C7F0D8CF62DF4740
77508	2	23	141	20698	56379	\N	47.747463000000003	Ростовская область, Куйбышевский район, Кринично-Лугское сельское поселение, село Русско-Лютино, ул. Социалистическая, 18-Б		0101000020E61000002B4CDF6B08A243402BFC19DEACDF4740
77686	2	23	141	28961	56110	\N	47.806114000000001	Ростовская область, Куйбышевский район, Куйбышевское сельское поселение, хутор Ольховский, ул. Центральная, 5-А		0101000020E61000002C11A8FE416E4340836C59BE2EE74740
77688	2	23	141	29068	56242	\N	47.705550000000002	Ростовская область, Куйбышевский район, Лысогорское сельское поселение, село Новоспасовка, ул. Победы, 9-B		0101000020E6100000CC7D7214208A4340AED85F764FDA4740
77766	2	23	141	336	56364	\N	47.778613	Ростовская область, Куйбышевский район, Куйбышевское сельское поселение, хутор Новобахмутский, ул. Широкая, 89-А		0101000020E6100000E44D7E8B4E704340C79E3D97A9E34740
77502	2	23	141	20341	9937	\N	47.742840000000001	Ростовская область, Куйбышевский район, Лысогорское сельское поселение, село Новиковка, ул. Победы, 30		0101000020E61000005C55F65D118A43409014916115DF4740
77504	2	23	141	20453	55227	\N	47.846148999999997	Ростовская область, Куйбышевский район, Кринично-лугское сельское поселение, хутор Новая Надежда, ул. Юбилейная, 15		0101000020E610000086032159C08843408445459C4EEC4740
77505	2	23	141	20527	55706	\N	47.825301000000003	Ростовская область, Куйбышевский район, Кринично-Лугское сельское поселение, село Миллерово, ул. Школьная, 3		0101000020E6100000EC32FCA71BA04340952D9276A3E94740
77509	2	23	141	20714	40184	\N	47.702129999999997	Ростовская область, Куйбышевский район, Кринично-Лугское сельское поселение, село Лысогорка, Кушнарёва, 7		0101000020E610000063635E471C9A43402EC55565DFD94740
77500	2	23	141	20120	40938	\N	47.811844999999998	Ростовская область, Куйбышевский район, Куйбышевское сельское поселение, село Куйбышево, ул. Театральная, 22		0101000020E6100000E5D18DB0A8744340E7357689EAE74740
77499	2	23	141	20120	41220	\N	47.811844999999998	Ростовская область, Куйбышевский район, Куйбышевское сельское поселение, село Куйбышево, ул. Пролетарская, 2-Б		0101000020E6100000E5D18DB0A8744340E7357689EAE74740
77510	2	23	141	56719	55862	\N	47.662098999999998	Ростовская область, Куйбышевский район, Лысогорское сельское поселение, село Крюково, ул. Молодежная, 28	Россия, Ростовская область, Куйбышевский район, хутор Крюково	0101000020E61000005A46EA3D959D43406EDBF7A8BFD44740
77506	2	23	141	56747	55894	\N	47.749687000000002	Ростовская область, Куйбышевский район, Кринично-Лугское сельское поселение, хутор Криничнолугский, ул. Октябрьская, 38-В	Россия, Ростовская область, Куйбышевский район, хутор Кринично-Лугский	0101000020E610000095F0845E7F9C4340419E5DBEF5DF4740
77687	2	23	141	29017	56362	\N	47.761299000000001	Ростовская область, Куйбышевский район, Кринично-Лугское сельское поселение, хутор Карташево, ул. Калинина, 18-А		0101000020E61000003B1BF2CF0C9243401FBDE13E72E14740
75938	2	23	141	8332	56277	\N	47.820152	Ростовская область, Куйбышевский район, Кринично-Лугское сельское поселение, село Каменно-Тузловка, ул. Социалистическая, 18		0101000020E6100000117008556A944340DFDFA0BDFAE84740
44907	2	20	301	50243	20600	\N	46.698206999999996	город Ейск, К. Либкнехта, 1, телефон: 21941		0101000020E61000009F1C0588822343404C6BD3D85E594740
77627	2	23	141	26269	56055	\N	47.722054090849902	Ростовская область, Куйбышевский район, Кринично-Лугское сельское поселение, хутор Зайцево, ул. Советская, 39	Россия, Ростовская область, Куйбышевский район, хутор Зайцево	0101000020E6100000093543AA28AE434016F9F5436CDC4740
77435	2	23	1337	16829	56121	\N	48.116781000000003	Ростовская область, Красносулинский район, станция Замчалово, Пионерская, 1		0101000020E6100000FC010F0C20084440A8E507AEF20E4840
77436	2	23	1337	16887	56156	\N	48.073591	Ростовская область, Красносулинский район, хутор Ясный, Гуковская, 1		0101000020E610000015562AA8A8024440D5230D6E6B094840
77482	2	23	1337	56831	56241	\N	47.776215047518903	Ростовская область, Красносулинский район, х. Шахтёнки, Школьный, 2	Россия, Ростовская область, Красносулинский район, хутор Шахтенки	0101000020E6100000459C4EB2D5E5434013D55B035BE34740
77471	2	23	1337	18632	55487	\N	48.136657999999997	Ростовская область, Красносулинский район, п. Чичерино, Горького, 1		0101000020E61000008104C58F311344404E5E64027E114840
77481	2	23	1337	57014	56562	\N	47.820942923033698	Ростовская область, Красносулинский район, х. Черников, Советская, 4	Россия, Ростовская область, Красносулинский район, хутор Черников	0101000020E6100000910DA48B4DE34340A87004A914E94740
77463	2	23	1337	56974	56516	\N	48.112341999999998	Ростовская область, Красносулинский район, х. Чернецов, Щаденко, 2	Россия, Ростовская область, Красносулинский район, хутор Чернецов	0101000020E61000006E4F90D8EE3C4440CEFBFF38610E4840
77689	2	23	1337	56991	56537	\N	48.117402167034903	Ростовская область, Красносулинский район, х. Чекунов, Мира, 23	Россия, Ростовская область, Красносулинский район, хутор Чекунов	0101000020E610000003ED0E2906464440143E5B07070F4840
77486	2	23	1337	56796	55964	\N	47.968389159280498	Ростовская область, Красносулинский район, х. Украинский, Ворошилова, б/н		0101000020E6100000C009850838EE43403067B62BF4FB4740
77434	2	23	1337	16781	\N	\N	48.145665000000001	Ростовская область, Красносулинский район, поселок Углеродовский, Шахтерская, 79	Россия, Ростовская область, Красносулинский район, ПГТ Углеродовский	0101000020E6100000DEC9A7C7B6084440FF959526A5124840
77433	2	23	1337	16781	40868	\N	48.145665000000001	Ростовская область, Красносулинский район, поселок Углеродовский, Восточная, 73		0101000020E6100000DEC9A7C7B6084440FF959526A5124840
77466	2	23	1337	18368	39833	\N	48.085450000000002	Ростовская область, Красносулинский район, п. Тополевый, Советская, 1-а		0101000020E6100000DACA4BFE27314440BBB88D06F00A4840
77496	2	23	1337	19979	55811	\N	47.802258999999999	Ростовская область, Красносулинский район, с. Табунщиково, Ленина, 82		0101000020E610000080B74082E2234440F9F5436CB0E64740
77490	2	23	1337	56663	55405	\N	47.8983612054517	Ростовская область, Красносулинский район, х. Садки, Советская, 17	Россия, Ростовская область, Красносулинский район, хутор Садки	0101000020E6100000028063CF9E3B44403D80457EFDF24740
77497	2	23	1337	19993	55982	\N	47.794105999999999	Ростовская область, Красносулинский район, п. Рябиновка, ул. Школьная, 5		0101000020E61000007E6FD39FFD1A444058C7F143A5E54740
77469	2	23	1337	57024	56575	\N	47.991219999999998	Ростовская область, Красносулинский район, х. Русско-Прохоровский, Новая, 9	Россия, Ростовская область, Красносулинский район, хутор Русско-Прохоровский	0101000020E61000009DB98784EF1744401092054CE0FE4740
77470	2	23	1337	18585	40183	\N	48.116667	Ростовская область, Красносулинский район, п. Розет, Советская, 8-а		0101000020E61000008463963D09104440DFC2BAF1EE0E4840
77484	2	23	1337	19356	56122	\N	47.885421999999998	Ростовская область, Красносулинский район, с. Прохоровка, Центральная, 27		0101000020E6100000AC58FCA6B02244405794128255F14740
77483	2	23	1337	56655	55341	\N	47.885153509379698	Ростовская область, Красносулинский район, х. Пролетарка, Советская, 27	Россия, Ростовская область, Красносулинский район, хутор Пролетарка	0101000020E6100000BE30992A1819444038F6ECB94CF14740
77494	2	23	1337	19852	39857	\N	47.927225999999997	Ростовская область, Красносулинский район, п. Пригородный, Ленина, 1-а		0101000020E6100000223999B8550644401D007157AFF64740
77480	2	23	1337	56646	55313	\N	48.063131753434298	Ростовская область, Красносулинский район, х. Платово, Советская, 48	Россия, Ростовская область, Красносулинский район, хутор Платово	0101000020E6100000D8614CFA7BF5434061AA99B514084840
77383	2	23	1337	14336	55743	\N	48.033732999999998	Ростовская область, Красносулинский район, п. Первомайский, Карла Маркса, 25		0101000020E610000092E86514CB0B4440E2E5E95C51044840
77487	2	23	1337	19511	56108	\N	47.930551999999999	Ростовская область, Красносулинский район, с. Павловка, Саломатина, 15		0101000020E6100000024BAE62F1E943401B9DF3531CF74740
77464	2	23	1337	18267	\N	\N	47.940995971946101	Ростовская область, Красносулинский район, п. Октябрьский, здание МОУ СОШ	Россия, Ростовская область, Красносулинский район, поселок Октябрьский	0101000020E61000002DCDAD1056F943405AD5928E72F84740
77478	2	23	1337	56673	55577	\N	48.011677330378703	Ростовская область, Красносулинский район, х. Новоровенецкий, Карьерная, 61	Россия, Ростовская область, Красносулинский район, хутор Новоровенецкий	0101000020E6100000AAF23D2311E84340C58EC6A17E014840
77479	2	23	1337	56861	56388	\N	48.122701890321302	Ростовская область, Красносулинский район, х. Нижняя Ковалёвка, Мичурина, 33-а	Россия, Ростовская область, Красносулинский район, хутор Нижняя Ковалевка	0101000020E6100000AF5FB01BB6F94340AF93FAB2B40F4840
77600	2	23	1337	25026	56240	\N	48.047896000000001	Ростовская область, Красносулинский район, п. Молодежный, Степная, 4		0101000020E61000007349D57613224440FBCDC47421064840
77492	2	23	1337	56905	56436	\N	47.8944516998951	Ростовская область, Красносулинский район, х. Дудкино, Набережная, 1-А	Россия, Ростовская область, Красносулинский район, хутор Дудкино	0101000020E61000006C088ECBB8454440C0EB33677DF24740
77474	2	23	1337	56848	56357	\N	48.033871362823398	Ростовская область, Красносулинский район, х. Молаканский, Придорожная, 1/1	Россия, Ростовская область, Красносулинский район, хутор Молаканский	0101000020E6100000D1967329AE0A444033A48AE255044840
77393	2	23	1337	14780	55215	\N	48.030835000000003	Ростовская область, Красносулинский район, хутор Михайловка, Ленина, 18		0101000020E6100000C8B1F50CE11A44403D49BA66F2034840
77477	2	23	1337	56696	55793	\N	48.034665716337102	Ростовская область, Красносулинский район, х. Марс, Первомайская, 37-а	Россия, Ростовская область, Красносулинский район, хутор Марс	0101000020E61000007E350708E6F443403E247CEF6F044840
77485	2	23	1337	56853	\N	\N	47.934581645551702	Ростовская область, Красносулинский район, х. Малая Гнилуша, Здание ЖЭУ, 1	Россия, Ростовская область, Красносулинский район, хутор Малая Гнилуша	0101000020E610000004CB11329015444013B70A62A0F74740
77472	2	23	1337	56632	55277	\N	48.124521999999999	Ростовская область, Красносулинский район, х. Лихой, Ленина, 65	Россия, Ростовская область, Красносулинский район, хутор Лихой	0101000020E61000001900AAB871194440F6D03E56F00F4840
77454	2	23	1337	16973	39788	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, инени Героя Советского Союза Алексеева А.И, 2		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77443	2	23	1337	16973	39851	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Шоссейная, 2а		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77457	2	23	1337	16973	39830	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Чкалова, 19		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77456	2	23	1337	16973	39830	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Чкалова, 13		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77438	2	23	1337	16973	40180	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Центральная, 10		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77440	2	23	1337	16973	39849	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Фондовый, 16		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77439	2	23	1337	16973	40869	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Строителей, 2		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77449	2	23	1337	16973	39856	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Свободы, 1-а		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77453	2	23	1337	16973	55222	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Революционный, 1		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77462	2	23	1337	16973	39831	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Первомайская, 3		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77444	2	23	1337	16973	55219	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Московская, 25		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77460	2	23	1337	16973	55510	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Металлургов, 12-а		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77461	2	23	1337	16973	55225	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Ленина, 8		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77455	2	23	1337	16973	55226	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Культуры, 1		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77446	2	23	1337	16973	41218	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Кронштадтская, 5		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77458	2	23	1337	16973	40937	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Краснопартизанская, 69		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77459	2	23	1337	16973	40182	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Интернациональная, 13		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77452	2	23	1337	16973	40181	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Гагарина, 153		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77451	2	23	1337	16973	40181	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Гагарина, 59		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77445	2	23	1337	16973	40935	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Вокзальная, 68		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77442	2	23	1337	16973	40931	\N	47.883628000000002	Ростовская область, Красносулинский район, город Красный Сулин, Вербенская, 60		0101000020E6100000D097DEFE5C0844403AEAE8B81AF14740
77441	2	23	1337	16973	40931	\N	47.896415057832598	Ростовская область, Красносулинский район, город Красный Сулин, Вербенская, 217-а	Россия, Ростовская область, Красносулинский район, Красный Сулин	0101000020E61000004A287D21E408444069520ABABDF24740
77489	2	23	1337	56813	56123	\N	48.002822226576797	Ростовская область, Красносулинский район, х. Коминтерн, Щербатых, 31	Россия, Ростовская область, Красносулинский район, хутор Коминтерн	0101000020E6100000DEC7D11C59ED4340CBDAA6785C004840
77488	2	23	1337	19518	55687	\N	47.885241000000001	Ростовская область, Красносулинский район, с. Киселево, Мичурина, 3		0101000020E6100000191EFB592CF14340070ABC934FF14740
77493	2	23	1337	56930	56465	\N	47.989621999999997	Ростовская область, Красносулинский район, х. Зайцевка, Советская, 10-а	Россия, Ростовская область, Красносулинский район, хутор Зайцевка	0101000020E61000003EE8D9ACFA40444078B306EFABFE4740
19465	2	21	\N	3394	57059	\N	46.368493000000001	г. Астрахань, ул. 1-я Перевозная, дом 94		0101000020E6100000D3BEB9BF7A08484008E753C72A2F4740
77473	2	23	1337	56952	56492	\N	47.997985999999997	Ростовская область, Красносулинский район, х. Долотинка, Малиновского, 2	Россия, Ростовская область, Красносулинский район, хутор Долотинка	0101000020E6100000D105F52D73064440D4EE5701BEFF4740
77476	2	23	1337	56681	55686	\N	47.981743412569401	Ростовская область, Красносулинский район, х. Гуково, Краснопартизанская, 1	Россия, Ростовская область, Красносулинский район, хутор Гуково	0101000020E6100000DB89929048F94340D9092FC1A9FD4740
77495	2	23	1337	56926	56460	\N	47.842247186196502	Ростовская область, Красносулинский район, х. Гривенный, Победы, 21	Россия, Ростовская область, Красносулинский район, хутор Гривенный	0101000020E61000000D51853FC32B4440BA13ECBFCEEB4740
77447	2	23	1337	17410	39853	\N	47.819952999999998	Ростовская область, Красносулинский район, п. Горный, Соцтруда, 1а		0101000020E61000006956B60F79194440E8A04B38F4E84740
77468	2	23	1337	18482	55592	\N	47.934911	Ростовская область, Красносулинский район, станица Владимировская, Ленина, 20		0101000020E6100000C7F484251E264440D8D5E429ABF74740
77467	2	23	1337	56772	55920	\N	47.974466633091097	Ростовская область, Красносулинский район, х. Большая Федоровка, Октябрьская, 22	Россия, Ростовская область, Красносулинский район, хутор Большая Федоровка	0101000020E610000058569A94822E4440FF03AC55BBFC4740
75496	2	23	182	18782	\N	\N	47.715409000000001	Ростовская область, Константиновский район, хутор  Хрящевский, Сельский дом культуры		0101000020E6100000BCEB6CC83F794440CD21A98592DB4740
77657	2	23	182	27658	56130	\N	47.786586999999997	Ростовская область, Константиновский район, поселок Холмистый, ул. Западная, д. 3		0101000020E61000009BE271512DA64440B83A00E2AEE44740
75504	2	23	182	19164	56324	\N	47.640799000000001	Ростовская область, Константиновский район, хутор Упраздно-Кагальницкий, ул. Спортивная, д. 6		0101000020E610000080B9162D409D44409E279EB305D24740
77653	2	23	182	27441	55987	\N	47.871552999999999	Ростовская область, Константиновский район, хутор Трофимов, ул. Степная, д.26		0101000020E610000073F6CE68ABA4444087DD770C8FEF4740
77656	2	23	182	27616	56375	\N	47.814689000000001	Ростовская область, Константиновский район, хутор Суворов, ул. Центральная, д. 30		0101000020E6100000427C60C77FD944409AB4A9BA47E84740
75512	2	23	182	19593	56326	\N	47.884521999999997	Ростовская область, Константиновский район, поселок Стычновский, ул. Центральная, д. 3		0101000020E6100000C7D5C8AEB4C24440D74B530438F14740
75860	2	23	182	56801	56013	\N	47.597471215614803	Ростовская область, Константиновский район, хутор Старая Станица, ул. Школьная, д. 2	Россия, Ростовская область, Константиновский район, поселок Старая Станица	0101000020E610000067B96C74CEBB44407AA702EE79CC4740
75511	2	23	182	19536	55996	\N	47.705587000000001	Ростовская область, Константиновский район, хутор Савельев, ул. Фестивальная, д. 13		0101000020E6100000E50AEF7211B74440CBBDC0AC50DA4740
77655	2	23	182	27541	55993	\N	47.616824999999999	Ростовская область, Константиновский район, хутор Правда, ул. Центральная, д. 13		0101000020E610000099654F029BE14440772D211FF4CE4740
75498	2	23	182	18881	55986	\N	47.838850000000001	Ростовская область, Константиновский район, хутор Почтовый, ул. Центральная, д. 3		0101000020E61000006E179AEB34864440F31FD26F5FEB4740
75793	2	23	182	584	\N	\N	47.644326999999997	Ростовская область, Константиновский район, хутор Новая Жизнь, Сельский дом культуры		0101000020E61000007104A9143BB244400377A04E79D24740
75506	2	23	182	19247	40109	\N	47.606552999999998	Ростовская область, Константиновский район, станица Николаевская, ул. Центральная, д. 28		0101000020E61000004567994528C2444035255987A3CD4740
75505	2	23	182	19247	40109	\N	47.606552999999998	Ростовская область, Константиновский район, станица Николаевская, ул. Центральная, д. 23		0101000020E61000004567994528C2444035255987A3CD4740
75499	2	23	182	18916	56079	\N	47.902242000000001	Ростовская область, Константиновский район, хутор Нижнекалинов, ул. Набережная, д. 20		0101000020E6100000CAA7C7B60C844440F08975AA7CF34740
75494	2	23	182	18644	56170	\N	47.719145613033398	Ростовская область, Константиновский район, хутор Нижнежуравский, ул. Мира, д. 15	Россия, Ростовская область, Константиновский район, хутор Нижнежуравский	0101000020E610000051C07630628944404D86E3F90CDC4740
75497	2	23	182	18813	55960	\N	47.671430999999998	Ростовская область, Константиновский район, хутор Михайловский, ул. Березовая, д. 22		0101000020E6100000568330B77B7B4440A2427573F1D54740
75507	2	23	182	19321	55750	\N	47.604056	Ростовская область, Константиновский район, станица Мариинская, ул. Зеленая, д. 5		0101000020E6100000505436ACA9DA4440EE79FEB451CD4740
75509	2	23	182	19427	55981	\N	47.753982000000001	Ростовская область, Константиновский район, хутор Лисичкин, ул. Центральная, д. 13		0101000020E610000050A8A78FC0A74440E7E26F7B82E04740
75500	2	23	182	18975	55990	\N	47.836497000000001	Ростовская область, Константиновский район, хутор Крюков, пер. Клубный, д. 2		0101000020E6100000F451465C00A44440DF196D5512EB4740
77654	2	23	182	27518	55988	\N	47.819029076427398	Ростовская область, Константиновский район, хутор Кременской, ул. Московская, д. 8	Россия, Ростовская область, Константиновский район, хутор Кременской	0101000020E6100000FC8A355CE48E4440E0BC38F1D5E84740
75495	2	23	182	18724	56316	\N	47.626292999999997	Ростовская область, Константиновский район, хутор Костино-Горский, ул. Казачья, д. 2		0101000020E610000079211D1EC27244405B5B785E2AD04740
75484	2	23	182	18084	\N	\N	47.581054761847902	Ростовская область, Константиновский район, город Константиновск, пос. КГУ-1, д. 12	Россия, Ростовская область, Константиновский район, Константиновск	0101000020E6100000DBFAE93F6B8C4440B1169F0260CA4740
75491	2	23	182	18084	40433	\N	47.580575000000003	Ростовская область, Константиновский район, город Константиновск, ул. Рылеева, д. 59		0101000020E6100000FD4AE7C3B38C444007F0164850CA4740
75485	2	23	182	18084	40431	\N	47.580575000000003	Ростовская область, Константиновский район, город Константиновск, ул. Комсомольская, д. 61		0101000020E6100000FD4AE7C3B38C444007F0164850CA4740
75488	2	23	182	18084	40432	\N	47.580575000000003	Ростовская область, Константиновский район, город Константиновск, ул. Калинина, д. 93		0101000020E6100000FD4AE7C3B38C444007F0164850CA4740
75486	2	23	182	18084	40043	\N	47.580575000000003	Ростовская область, Константиновский район, город Константиновск, ул. 25 Октября, д. 52		0101000020E6100000FD4AE7C3B38C444007F0164850CA4740
77611	2	23	182	25535	56366	\N	47.630301840144099	Ростовская область, Константиновский район, хутор Кастырский, ул. Центральная, д. 10	Россия, Ростовская область, Константиновский район, хутор Кастырский	0101000020E6100000AE2B6684B7A344403C4D66BCADD04740
75502	2	23	182	19093	56101	\N	47.626365999999997	Ростовская область, Константиновский район, хутор Камышный, ул. Центральная, д. 40		0101000020E61000002594BE1072984440C5A9D6C22CD04740
75513	2	23	182	19677	56325	\N	47.777813999999999	Ростовская область, Константиновский район, хутор Ермилов, ул. Степная, 58		0101000020E61000000D71AC8BDBBC44407B2FBE688FE34740
75508	2	23	182	19379	55628	\N	47.716821000000003	Ростовская область, Константиновский район, хутор Гапкин, ул. Центральная, д. 42		0101000020E6100000C9E6AA798EB64440030B60CAC0DB4740
75515	2	23	182	19768	55992	\N	47.895972	Ростовская область, Константиновский район, хутор Вифлянцев, ул. Октябрьская, д. 13		0101000020E6100000A1A3552DE9C04440DC10E335AFF24740
77650	2	23	182	27293	56253	\N	47.886153999999998	Ростовская область, Константиновский район, хутор Верхнепотапов, ул. Береговая, д. 1		0101000020E6100000C6850321598644401B9C887E6DF14740
75493	2	23	182	18630	39654	\N	47.581176999999997	Ростовская область, Константиновский район, хутор Ведерников, ул. Лесная, д. 37		0101000020E61000000E4DD9E907934440FC17080264CA4740
75501	2	23	182	19017	55630	\N	47.650425896567199	Ростовская область, Константиновский район, станица Богоявленская, ул. Парковая, д. 2	Россия, Ростовская область, Константиновский район, станица Богоявленская	0101000020E6100000E5F1B4FCC0AB4440EB3BBF2841D34740
75510	2	23	182	19478	56213	\N	47.755557000000003	Ростовская область, Константиновский район, хутор Белянский, ул. Широкая, д. 22		0101000020E6100000E6779ACC78C74440C7A17E17B6E04740
77658	2	23	182	27686	55991	\N	47.805338999999996	Ростовская область, Константиновский район, поселок Белоковыльный, ул. Лазоревая, д. 16		0101000020E6100000FED5E3BED5D64440BF982D5915E74740
77651	2	23	182	27365	55989	\N	47.814337999999999	Ростовская область, Константиновский район, хутор Базки, ул. Пушкина, д. 11		0101000020E61000005F0D501A6A884440EDF1423A3CE84740
77649	2	23	182	27273	56128	\N	47.694671	Ростовская область, Константиновский район, хутор Авилов, ул. Молодежная, д 17		0101000020E61000004A0856D5CB854440643DB5FAEAD84740
76268	2	23	1731	24374	56195	\N	49.120351999999997	Ростовская область, Кашарский район, Киевское сельское поселение, с. Шалаевка, ул. Заречная, 1		0101000020E6100000E08442041CAA44400C01C0B1678F4840
76282	2	23	1731	25022	56036	\N	48.792175	Ростовская область, Кашарский район, Первомайское сельское поселение, х. Чернигово-Песчаный, ул. Молодежная, 2		0101000020E610000009C556D0B4A44440BADA8AFD65654840
76272	2	23	1731	24573	56164	\N	48.968150000000001	Ростовская область, Кашарский район, Талловеровское сельское поселение, с. Усть-Мечетка, ул. Центральная, 7		0101000020E61000008693347F4C934440ABCFD556EC7B4840
76292	2	23	1731	25498	56165	\N	49.090986000000001	Ростовская область, Кашарский район, Киевское сельское поселение, х. Третий Интернационал, ул. Заветная, 1		0101000020E6100000EB71DF6A9D9C44406A32E36DA58B4840
76289	2	23	1731	25339	56039	\N	48.977375000000002	Ростовская область, Кашарский район, Верхнесвечниковское сельское поселение, п. Теплые Ключи, ул. Школьная, 22		0101000020E61000003D7D04FEF0DB4440C976BE9F1A7D4840
76273	2	23	1731	24590	55729	\N	49.013066999999999	Ростовская область, Кашарский район, Талловеровское сельское поселение, х. Талловеров, ул. Центральная, 46		0101000020E6100000CA1AF5108DA4444013D4F02DAC814840
76276	2	23	1731	24774	56315	\N	48.847586999999997	Ростовская область, Кашарский район, Фомино-Свечниковское сельское поселение, х. Сергеевка, ул. Сергеевская, 1		0101000020E61000008D47A98427944440E3C116BB7D6C4840
76278	2	23	1731	24848	56306	\N	48.815306	Ростовская область, Кашарский район, Фомино-Свечниковское сельское поселение, с. Сариновка, ул. Школьная, 17		0101000020E610000023111AC1C6914440C51D6FF25B684840
76285	2	23	1731	25118	\N	\N	48.911445999999998	Ростовская область, Кашарский район, Первомайское сельское поселение, с. Россошь, ул. Центральная, 17	Россия, Ростовская область, Кашарский район, село Россошь	0101000020E6100000C2340C1F11AD4440F6083543AA744840
76262	2	23	1731	56819	56187	\N	49.2079159035708	Ростовская область, Кашарский район, Верхнемакеевское сельское поселение, х. Речка, ул. Тихомировская, 29	Россия, Ростовская область, Кашарский район, хутор Речка	0101000020E6100000C09657AEB78544405628D2FD9C9A4840
76266	2	23	1731	24257	32953	\N	49.243194000000003	Ростовская область, Кашарский район, Поповское сельское поселение, сл. Поповка, ул. Большая Садовая, 46		0101000020E6100000F2086EA46C9D4440AE4A22FB209F4840
76290	2	23	1731	25403	55673	\N	49.057518000000002	Ростовская область, Кашарский район, Талловеровское сельское поселение, х. Пономарев, ул. Центральная, 7		0101000020E61000003B71395E81BE44403677F4BF5C874840
76280	2	23	1731	24948	40256	\N	48.826552999999997	Ростовская область, Кашарский район, Первомайское сельское поселение, с. Первомайское, ул. Мира, 9		0101000020E61000005A46EA3D959D444091B41B7DCC694840
76264	2	23	1731	24153	56193	\N	49.305914999999999	Ростовская область, Кашарский район, Вяжинское сельское поселение, х. Ольховый, ул. Лесная, 126 А		0101000020E610000069519FE40E7F44408C2D043928A74840
76261	2	23	1731	23983	56342	\N	49.170070975020799	Ростовская область, Кашарский район, Верхнемакеевское сельское поселение, х. Новочигириновский, ул. Набережная, 54	Россия, Ростовская область, Кашарский район, хутор Новочигириновский	0101000020E61000002E910BCEE0914440BF7FF3E2C4954840
76257	2	23	1731	23809	55609	\N	49.1102666749238	Ростовская область, Кашарский район, Кашарское сельское поселение, с. Новопавловка, ул. Октябрьская, 37	Россия, Ростовская область, Кашарский район, село Новопавловка	0101000020E61000007BD976DA1A854440FD69A33A1D8E4840
76270	2	23	1731	52874	56304	\N	49.163888	Ростовская область, Кашарский район, Киевское сельское поселение, х. Нижний Астахов, пер. Школьный, 2		0101000020E6100000E622BE13B3B444407A1A3048FA944840
76281	2	23	1731	24958	56313	\N	48.963524	Ростовская область, Кашарский район, Индустриальное сельское поселение, х. Михайловка, ул. Юбилейная, 28		0101000020E6100000CBA145B6F3B944409F7422C1547B4840
76258	2	23	1731	23860	56161	\N	48.956059000000003	Ростовская область, Кашарский район, Кашарское сельское поселение, с. Лысогорка, ул. Школьная, 34		0101000020E610000031D28BDAFD784440F3052D24607A4840
76275	2	23	1731	24700	56197	\N	48.932093999999999	Ростовская область, Кашарский район, Фомино-Свечниковское сельское поселение, х. Ленинский, ул. Песчаная, 1 А	Россия, Ростовская область, Кашарский район, хутор Ленинский	0101000020E6100000D7A6B1BD168E44401F662FDB4E774840
76291	2	23	1731	25408	55947	\N	49.048963000000001	Ростовская область, Кашарский район, Киевское сельское поселение, п. Красный Колос, ул. Пушкинская, 12		0101000020E610000073BB97FBE490444066DB696B44864840
76286	2	23	1731	25200	56341	\N	48.867924000000002	Ростовская область, Кашарский район, Первомайское сельское поселение, х. Краснояровка, ул. Центральная, 31		0101000020E61000001A6EC0E7879F4440EEB43522186F4840
76254	2	23	1731	23589	39765	\N	49.044120332854703	Ростовская область, Кашарский район, Кашарское сельское поселение, сл. Кашары, ул. Ленина, 62	Россия, Ростовская область, Кашарский район, слобода Кашары	0101000020E6100000AA4885B185804440BD8C62B9A5854840
76252	2	23	1731	23589	40530	\N	49.04392	Ростовская область, Кашарский район, Кашарское сельское поселение, сл. Кашары, ул. Комсомольская, 43		0101000020E6100000F816D68D77814440F6D1A92B9F854840
76255	2	23	1731	23589	41165	\N	49.04392	Ростовская область, Кашарский район, Кашарское сельское поселение, сл. Кашары, ул. Андреевская, 42		0101000020E6100000F816D68D77814440F6D1A92B9F854840
76256	2	23	1731	23589	55610	\N	49.04392	Ростовская область, Кашарский район, Кашарское сельское поселение, сл. Кашары, ул. Адмиральская, 44		0101000020E6100000F816D68D77814440F6D1A92B9F854840
76267	2	23	1731	24297	55616	\N	49.267789999999998	Ростовская область, Кашарский район, Поповское сельское поселение, с. Каменка, ул. Центральная, 15 В		0101000020E610000030D978B0C5A84440111956F146A24840
76287	2	23	1731	25255	56037	\N	48.964477000000002	Ростовская область, Кашарский район, Верхнесвечниковское сельское поселение, х. Калашников, ул. Подтелковская, 1		0101000020E6100000BFF1B56796B64440425F7AFB737B4840
76283	2	23	1731	25054	55619	\N	48.726463000000003	Ростовская область, Кашарский район, Индустриальное сельское поселение, п. Индустриальный, ул. Советская, 9		0101000020E610000005E09F5225964440856055BDFC5C4840
76265	2	23	1731	24204	55614	\N	49.208691999999999	Ростовская область, Кашарский район, Поповское сельское поселение, п. Дибровый, ул. Центральная, 12		0101000020E610000021EA3E00A9974440EA77616BB69A4840
76263	2	23	1731	24122	55669	\N	49.269565860620098	Ростовская область, Кашарский район, Вяжинское сельское поселение, х. Вяжа, ул. Центральная, 6	Россия, Ростовская область, Кашарский район, хутор Вяжа	0101000020E6100000404B57B08D864440880E812381A24840
76271	2	23	1731	24514	32960	\N	49.055546	Ростовская область, Кашарский район, Киевское сельское поселение, х. Второй Киевский, ул. Победы, 1		0101000020E6100000EBFCDB65BF94444039B69E211C874840
76274	2	23	1731	24679	56034	\N	48.906453999999997	Ростовская область, Кашарский район, Фомино-Свечниковское сельское поселение, х. Вишневка, ул. Молодежная, 8		0101000020E6100000331AF9BCE291444008AA46AF06744840
76288	2	23	1731	25283	55767	\N	48.983755000000002	Ростовская область, Кашарский район, Верхнесвечниковское сельское поселение, с. Верхнесвечниково, ул. Ленина, 18		0101000020E6100000E63C635FB2C94440642310AFEB7D4840
76260	2	23	1731	23967	55615	\N	49.172400000000003	Ростовская область, Кашарский район, Верхнемакеевское сельское поселение, сл. Верхнемакеевка, ул. Октябрьская, 26		0101000020E610000076E09C11A58944404BEA043411964840
76259	2	23	1731	23903	56033	\N	48.995128999999999	Ростовская область, Кашарский район, Кашарское сельское поселение, с. Верхнекалиновка, ул. Центральная, 55		0101000020E610000009C4EBFA057B44408D261763607F4840
76269	2	23	1731	24389	56163	\N	49.145110000000003	Ростовская область, Кашарский район, Киевское сельское поселение, с. Верхнегреково, ул. Береговая, 5		0101000020E61000000B7C45B75EAF44404A29E8F692924840
76171	2	23	1602	19591	56179	\N	48.187117999999998	Ростовская область, Каменский район, ст. Репная, Железнодорожная, 14-А		0101000020E6100000BCE7C072843E4440183F8D7BF3174840
76208	2	23	1602	21571	41157	\N	48.258778999999997	Ростовская область, Каменский район, п. Чистоозерный, Ленина, 23		0101000020E61000000D535BEA203744401FF296AB1F214840
76231	2	23	1602	56965	56506	\N	48.359226999999997	Ростовская область, Каменский район, х. Филиппенков, Набережная, 46	Россия, Ростовская область, Каменский район, хутор Филиппенков	0101000020E6100000EB56CF49EF1B44408B6B7C26FB2D4840
75458	2	23	1220	16854	55748	\N	46.809550999999999	Ростовская область, Зерноградский район, п. Экспериментальный, Шоссейная, 6		0101000020E6100000CAFE791A30264440D8B8FE5D9F674740
76242	2	23	1602	56737	55884	\N	48.558608999999997	Ростовская область, Каменский район, х. Урывский, Российская, 56	Россия, Ростовская область, Каменский район, хутор Урывский	0101000020E6100000287FF78E1A1F44402920ED7F80474840
76249	2	23	1602	56823	56214	\N	48.468303929216397	Ростовская область, Каменский район, х. Уляшкин, Лесная, 35	Россия, Ростовская область, Каменский район, хутор Уляшкин	0101000020E6100000AF5E454607FC4340024BAE62F13B4840
76246	2	23	1602	56630	55304	\N	48.336108000000003	Ростовская область, Каменский район, х. Старая Станица, Садовая, 52		0101000020E610000096CCB1BCAB26444045F64196052B4840
76245	2	23	1602	56630	55274	\N	48.335990097654403	Ростовская область, Каменский район, х. Старая Станица, Театральная, 65	Россия, Ростовская область, Каменский район, хутор Старая Станица	0101000020E610000037177FDB132644403BE466B8012B4840
76241	2	23	1602	56921	56454	\N	48.596706861496301	Ростовская область, Каменский район, х. Сибилев, Степная, 5	Россия, Ростовская область, Каменский район, хутор Сибилев	0101000020E61000008B4E965AEF274440AB251DE5604C4840
76214	2	23	1602	56961	56502	\N	48.162999999999997	Ростовская область, Каменский район, х. Светлый, Центральная, 93	Россия, Ростовская область, Каменский район, хутор Светлый	0101000020E610000060E811A3E7084440BE9F1A2FDD144840
76223	2	23	1602	56671	55545	\N	48.406620106756399	Ростовская область, Каменский район, х. Самбуров, Колхозная, 3	Россия, Ростовская область, Каменский район, хутор Самбуров	0101000020E6100000D619DF17974C444023F3C81F0C344840
76209	2	23	1602	56804	56035	\N	48.2435429204344	Ростовская область, Каменский район, п. Разъезд Северный Донец, Народная, 1	Россия, Ростовская область, Каменский район, поселок Разъезд Северный Донец	0101000020E6100000CEAACFD556244440BA15C26A2C1F4840
76227	2	23	1602	56749	55896	\N	48.547464685542899	Ростовская область, Каменский район, х. Плешаков, Московская, 20	Россия, Ростовская область, Каменский район, хутор Плешаков	0101000020E610000066BB421F2C474440325A475513464840
76238	2	23	1602	56818	56162	\N	48.260699843490301	Ростовская область, Каменский район, х. Нижнеясиновский, Платова, 35	Россия, Ростовская область, Каменский район, хутор Нижнеясиновский	0101000020E610000027F8A6E9B34944409A081B9E5E214840
76226	2	23	1602	57015	56563	\N	48.388302000000003	Ростовская область, Каменский район, х. Нижнеерохин, Молодежная, 3	Россия, Ростовская область, Каменский район, хутор Нижнеерохин	0101000020E6100000BAA0BE654E3F4440577C43E1B3314840
76210	2	23	1602	57007	56555	\N	48.285358000000002	Ростовская область, Каменский район, х. Нижнеговейный, Щаденко, 14	Россия, Ростовская область, Каменский район, хутор Нижнеговейный	0101000020E6100000506EDBF7A82B444074D3669C86244840
76207	2	23	1602	21497	56031	\N	48.453381999999998	Ростовская область, Каменский район, п. Молодежный, Достоевского, 12		0101000020E61000002C0E677E352744402B4CDF6B083A4840
76234	2	23	1602	56976	56518	\N	48.374670620277797	Ростовская область, Каменский район, х. Михайловка, Донская, 16-А	Россия, Ростовская область, Каменский район, хутор Михайловка	0101000020E610000073309B00C30044403BE12538F52F4840
76232	2	23	1602	56640	55293	\N	48.411975461646399	Ростовская область, Каменский район, х. Масаловка, Советская, 62	Россия, Ростовская область, Каменский район, хутор Масаловка	0101000020E61000009772BED87B21444082E2C798BB344840
76233	2	23	1602	56637	55286	\N	48.327549553375398	Ростовская область, Каменский район, х. Малая Каменка, К.Маркса, 23-Б	Россия, Ростовская область, Каменский район, хутор Малая Каменка	0101000020E610000043ACFE08C314444004E78C28ED294840
76247	2	23	1602	23420	55929	\N	48.316603145371701	Ростовская область, Каменский район, х. Лесной, Королева, 10	Россия, Ростовская область, Каменский район, хутор Лесной	0101000020E6100000D5E8D500A52944406268757286284840
76230	2	23	1602	56659	55552	\N	48.373443999999999	Ростовская область, Каменский район, х. Красновка, Профильная, 15	Россия, Ростовская область, Каменский район, хутор Красновка	0101000020E61000004D672783A320444097715303CD2F4840
76229	2	23	1602	56659	55363	\N	48.373443999999999	Ростовская область, Каменский район, х. Красновка, Октябрьская, 146-Б	Россия, Ростовская область, Каменский район, хутор Красновка	0101000020E61000004D672783A320444097715303CD2F4840
76218	2	23	1602	56659	55932	\N	48.373040539050002	Ростовская область, Каменский район, х. Красновка, Матросова, 2	Россия, Ростовская область, Каменский район, хутор Красновка	0101000020E6100000C573B680D02044409888B7CEBF2F4840
76251	2	23	1602	57021	56571	\N	48.484842039626798	Ростовская область, Каменский район, х. Кочетовка, Победы, 1	Россия, Ростовская область, Каменский район, хутор Кочетовка	0101000020E610000009185DDE1C12444016DD7A4D0F3E4840
76221	2	23	1602	22166	55728	\N	48.525969000000003	Ростовская область, Каменский район, п. Каменногорье, Спортивная, 41		0101000020E6100000469737876B2F4440DCDAC2F352434840
76228	2	23	1602	22499	40129	\N	48.289535999999998	Ростовская область, Каменский район, ст. Калитвенская, Калинина, 13		0101000020E6100000F3E32F2DEA434440E08101840F254840
76248	2	23	1602	56885	56413	\N	48.29824	Ростовская область, Каменский район, х. Диченский, Левитана, 48-А	Россия, Ростовская область, Каменский район, хутор Диченский	0101000020E6100000FD6A0E10CC2F4440F52D73BA2C264840
76222	2	23	1602	56846	56347	\N	48.496108290541699	Ростовская область, Каменский район, х. Данилов, Школьный, 2	Россия, Ростовская область, Каменский район, хутор Данилов	0101000020E610000048A5D8D13868444059A48977803F4840
76225	2	23	1602	56775	55923	\N	48.441603644145403	Ростовская область, Каменский район, х. Гусев, Центральная, 21	Россия, Ростовская область, Каменский район, хутор Гусев	0101000020E6100000AEBCE47FF23F444032E4D87A86384840
14027	1	17	\N	3130	22864	\N	58.045848999999997	г.Рыбинск, Черняховского, 29		0101000020E6100000B3614D65516C4340F3C64961DE054D40
76224	2	23	1602	56736	55883	\N	48.472048707404603	Ростовская область, Каменский район, х. Груцинов, Школьная, 1	Россия, Ростовская область, Каменский район, хутор Груцинов	0101000020E6100000C5C72764E7554440048E041A6C3C4840
76219	2	23	1602	21884	40082	\N	48.519857999999999	Ростовская область, Каменский район, р.п. Глубокий, Юбилейная, 8/4		0101000020E610000092239D81912944403048FAB48A424840
76220	2	23	1602	21884	41162	\N	48.519857999999999	Ростовская область, Каменский район, р.п. Глубокий, Фрунзе, 86		0101000020E610000092239D81912944403048FAB48A424840
76216	2	23	1602	21884	40254	\N	48.519857999999999	Ростовская область, Каменский район, р.п. Глубокий, Ленина, 32		0101000020E610000092239D81912944403048FAB48A424840
76215	2	23	1602	21884	41159	\N	48.519857999999999	Ростовская область, Каменский район, р.п. Глубокий, К.Маркса, 50		0101000020E610000092239D81912944403048FAB48A424840
76217	2	23	1602	21884	40081	\N	48.519857999999999	Ростовская область, Каменский район, р.п. Глубокий, Вокзальная, 212		0101000020E610000092239D81912944403048FAB48A424840
76211	2	23	1602	56740	55887	\N	48.243617999999998	Ростовская область, Каменский район, х. Волченский, Молодежная, 48	Россия, Ростовская область, Каменский район, хутор Волченский	0101000020E610000054724EECA10F4440C45BE7DF2E1F4840
76235	2	23	1602	56724	55867	\N	48.386172000000002	Ростовская область, Каменский район, х. Вишневецкий, Набережная, 1		0101000020E6100000B45BCB64380A4440C25087156E314840
76239	2	23	1602	56644	55300	\N	48.561166999999998	Ростовская область, Каменский район, х. Верхний Пиховкин, Центральная, 31	Россия, Ростовская область, Каменский район, хутор Верхний Пиховкин	0101000020E61000006DE179A9D8284440164CFC51D4474840
76250	2	23	1602	56977	56519	\N	48.502005281243001	Ростовская область, Каменский район, х. Верхние грачики, Молодежная, 22	Россия, Ростовская область, Каменский район, хутор Верхние Грачики	0101000020E6100000CE70033E3FFE4340D8B628B341404840
76236	2	23	1602	56992	56542	\N	48.212158767322002	Ростовская область, Каменский район, х. Верхнеясиновский, Центральная, 19		0101000020E6100000FCFECD8B13474440AA46AF06281B4840
76237	2	23	1602	22876	56171	\N	48.181994000000003	Ростовская область, Каменский район, п. Васильевский, Школьная, 8		0101000020E6100000774D486B0C484440BC0853944B174840
76212	2	23	1602	56820	56191	\N	48.208545999999998	Ростовская область, Каменский район, х. Белгородцев, Станичная, 78	Россия, Ростовская область, Каменский район, хутор Белгородцев	0101000020E6100000560E2DB29D11444016DBA4A2B11A4840
77608	2	23	1602	56980	56522	\N	48.461340999999997	Ростовская область, Каменский район, х. Астахов, Советская, 44-А	Россия, Ростовская область, Каменский район, хутор Астахов	0101000020E610000094861A8524254440E7A6CD380D3B4840
76213	2	23	1602	56869	56397	\N	48.168113043313397	Ростовская область, Каменский район, х. Аникин, Мира, 122	Россия, Ростовская область, Каменский район, хутор Аникин	0101000020E61000001BBD1AA034FE434027840EBA84154840
77609	2	23	1602	56981	56523	\N	48.297203000000003	Ростовская область, Каменский район, х. Абрамовка, Набережная, 1	Россия, Ростовская область, Каменский район, хутор Абрамовка	0101000020E61000003D2828452B2B4440F5A276BF0A264840
77298	2	23	1052	10344	55741	\N	47.045214999999999	Ростовская область, Кагальницкий район, ст. Хомутовская, адрес помещения для голосования: ул.Школьная, 13, адрес УИК: ул. Центральная, 11Д		0101000020E610000049BBD1C77C084440F224E99AC9854740
77288	2	23	1052	56854	56380	\N	46.875208999999998	Ростовская область, Кагальницкий район, х. Середин, ул. Солнечная, 60	Россия, Ростовская область, Кагальницкий район, хутор Середин	0101000020E610000012FA997ADD0044401A1538D906704740
77284	2	23	1052	9584	56120	\N	46.805171999999999	Ростовская область, Кагальницкий район, п. Светлый Яр, ул. Парковая, 1Б		0101000020E61000001286014BAE124440D4D347E00F674740
77304	2	23	1052	56962	56503	\N	46.959431000000002	Ростовская область, Кагальницкий район, х. Родники, ул. Школьная, 25	Россия, Ростовская область, Кагальницкий район, хутор Родники	0101000020E6100000826F9A3E3B1C444061E28FA2CE7A4740
77301	2	23	1052	56900	56430	\N	47.001342000000001	Ростовская область, Кагальницкий район, х. Раково-Таврический, ул. Школьная, 20		0101000020E61000002B16BF29AC2E44403D0E83F92B804740
77299	2	23	1052	56931	56468	\N	47.101517999999999	Ростовская область, Кагальницкий район, х. Первомайский, ул. Степная, 59	Россия, Ростовская область, Кагальницкий район, хутор Первомайский	0101000020E61000007F5017299413444048FAB48AFE8C4740
77294	2	23	1052	10104	55983	\N	46.967376999999999	Ростовская область, Кагальницкий район, п. Новоракитный, ул. Климова, 34		0101000020E6100000AF06280D35F6434088F37002D37B4740
77722	2	23	1052	30647	56207	\N	47.118451	Ростовская область, Кагальницкий район, п. Новонатальин, ул. Садовая, 5		0101000020E6100000F644D7851FFC4340D9960167298F4740
77671	2	23	1052	9888	39871	\N	46.896199000000003	Ростовская область, Кагальницкий район, с. Новобатайск, адрес помещения для голосования: ул.Ленина, 20, адрес УИК: ул. Ленина, 68		0101000020E610000009C6C1A563E443409DDA19A6B6724740
77290	2	23	1052	9888	39871	\N	46.896199000000003	Ростовская область, Кагальницкий район, с. Новобатайск, адрес помещения для голосования: ул.Ленина, 64, адрес УИК: ул. Ленина, 68		0101000020E610000009C6C1A563E443409DDA19A6B6724740
77289	2	23	1052	9888	39871	\N	46.896199000000003	Ростовская область, Кагальницкий район, с. Новобатайск, адрес помещения для голосования: ул.Ленина, 55, адрес УИК: ул. Ленина, 68		0101000020E610000009C6C1A563E443409DDA19A6B6724740
77672	2	23	1052	9888	55819	\N	46.896199000000003	Ростовская область, Кагальницкий район, с. Новобатайск, адрес помещения для голосования: ул.Красная, 31, адрес УИК: ул. Ленина, 68		0101000020E610000009C6C1A563E443409DDA19A6B6724740
75460	2	23	1220	16937	56220	\N	46.800058	Ростовская область, Зерноградский район, п. Шоссейный, Пугачева, 12		0101000020E61000008750A5660F2C44409B73F04C68664740
77723	2	23	1052	56703	55845	\N	46.965556999999997	Ростовская область, Кагальницкий район, х. Николаевский, ул. Луговая, 127	Россия, Ростовская область, Кагальницкий район, хутор Николаевский	0101000020E6100000707CED992501444041B62C5F977B4740
77296	2	23	1052	10195	40321	\N	47.043005000000001	Ростовская область, Кагальницкий район, п. Мокрый Батай, ул. 40 Лет Победы, 36		0101000020E6100000FA0E7EE200EC43404148163081854740
77724	2	23	1052	30763	56378	\N	46.993352000000002	Ростовская область, Кагальницкий район, п. Малодубравный, ул. Светлая, 13/2		0101000020E610000079909E2287EC434046B58828267F4740
77280	2	23	1052	9404	56302	\N	46.904425000000003	Ростовская область, Кагальницкий район, п. Малиновка, ул. Юбилейная, 13		0101000020E61000007E6E68CA4E174440A857CA32C4734740
77305	2	23	1052	10677	56243	\N	46.946765999999997	Ростовская область, Кагальницкий район, х. Красный Яр, ул. Пионерская, 7		0101000020E610000080F10C1AFA1744407C7BD7A02F794740
77283	2	23	1052	9579	56371	\N	46.811110999999997	Ростовская область, Кагальницкий район, п. Ключевой, ул. Школьная, 23		0101000020E6100000B9A981E673FE43408236397CD2674740
77623	2	23	1052	52110	55338	\N	46.979323999999998	Ростовская область, Кагальницкий район, ст. Кировская, ул. Школьная, 36	Россия, Ростовская область, Кагальницкий район, станица Кировская	0101000020E6100000ECF65965A60644400D18247D5A7D4740
77295	2	23	1052	52110	55338	\N	46.976854024442602	Ростовская область, Кагальницкий район, ст. Кировская, ул. Школьная, 49	Россия, Ростовская область, Кагальницкий район, станица Кировская	0101000020E6100000A036AAD381064440C07B478D097D4740
77292	2	23	1052	52110	55318	\N	46.977278435851701	Ростовская область, Кагальницкий район, ст. Кировская, ул. Московская, 37	Россия, Ростовская область, Кагальницкий район, станица Кировская	0101000020E6100000833463D174064440D68C0C72177D4740
77622	2	23	1052	52110	55844	\N	46.979676485940601	Ростовская область, Кагальницкий район, ст. Кировская, ул. Ленина, 62	Россия, Ростовская область, Кагальницкий район, станица Кировская	0101000020E61000008577B988EF0644408A56EE05667D4740
77291	2	23	1052	52110	55276	\N	46.979027562536501	Ростовская область, Кагальницкий район, ст. Кировская, ул. Гагарина, 110	Россия, Ростовская область, Кагальницкий район, станица Кировская	0101000020E610000050E449D23507444024EF1CCA507D4740
77303	2	23	1052	56832	56246	\N	47.041759069167199	Ростовская область, Кагальницкий район, х. Камышеваха, ул. Казачья, 30	Россия, Ростовская область, Кагальницкий район, хутор Камышеваха	0101000020E610000009C21550A821444026A8E15B58854740
77281	2	23	1052	57003	56551	\N	46.924472999999999	Ростовская область, Кагальницкий район, х. Кагальничек, ул. Трудовая, 23	Россия, Ростовская область, Кагальницкий район, хутор Кагальничек	0101000020E610000017F2086EA41A44407B849A2155764740
77278	2	23	1052	9217	55791	\N	46.887177000000001	Ростовская область, Кагальницкий район, ст. Кагальницкая, пер. Комсомольский, 1А		0101000020E610000016DC0F7860144440B76114048F714740
77279	2	23	1052	9217	55509	\N	46.887177000000001	Ростовская область, Кагальницкий район, ст. Кагальницкая, ул. Привокзальная, 1		0101000020E610000016DC0F7860144440B76114048F714740
77275	2	23	1052	9217	55508	\N	46.887177000000001	Ростовская область, Кагальницкий район, ст. Кагальницкая, ул. Почтовая, 101		0101000020E610000016DC0F7860144440B76114048F714740
77276	2	23	1052	9217	39804	\N	46.887177000000001	Ростовская область, Кагальницкий район, ст. Кагальницкая, пер. Кольцовский, 57		0101000020E610000016DC0F7860144440B76114048F714740
77274	2	23	1052	9217	40149	\N	46.887177000000001	Ростовская область, Кагальницкий район, ст. Кагальницкая, ул. Калинина, 105		0101000020E610000016DC0F7860144440B76114048F714740
77277	2	23	1052	9217	55485	\N	46.887177000000001	Ростовская область, Кагальницкий район, ст. Кагальницкая, ул. Горького, 34		0101000020E610000016DC0F7860144440B76114048F714740
77286	2	23	1052	9725	56374	\N	46.877020000000002	Ростовская область, Кагальницкий район, с. Иваново-Шамшево, ул. Красноармейская, 36		0101000020E61000000475CAA31BF543400EF8FC3042704740
77300	2	23	1052	57018	56572	\N	47.100066381059897	Ростовская область, Кагальницкий район, п. Зеленая Роща, ул. Школьная, 14		0101000020E610000012DC48D9221D444084B872F6CE8C4740
77302	2	23	1052	56717	55860	\N	47.000291969322802	Ростовская область, Кагальницкий район, х. Жуково-Татарский, адрес помещения для голосования: ул.Ленина, 16А, адрес УИК: ул. Ленина, 11А	Россия, Ростовская область, Кагальницкий район, хутор Жуково-Татарский	0101000020E610000096AFCBF09F284440A839799109804740
77282	2	23	1052	9485	55806	\N	46.849533000000001	Ростовская область, Кагальницкий район, п.Двуречье, адрес помещения для голосования: ул.Советская, 30, адрес УИК: ул. Советская, 23		0101000020E61000009738F24064074440B7EF517FBD6C4740
77285	2	23	1052	9485	55739	\N	46.849533000000001	Ростовская область, Кагальницкий район, п. Двуречье, адрес помещения для голосования: ул.Первомайская, 37, адрес УИК: ул. Советская, 23		0101000020E61000009738F24064074440B7EF517FBD6C4740
77725	2	23	1052	30774	56132	\N	46.967100000000002	Ростовская область, Кагальницкий район, п. Глубокий Яр, ул. Кленовая, 10 В		0101000020E61000000DA5F622DA12444016FBCBEEC97B4740
77297	2	23	1052	10254	55596	\N	46.949055000000001	Ростовская область, Кагальницкий район, п. Воронцовка, ул. Школьная, 1А		0101000020E61000005439ED2939E343407A8D5DA27A794740
77287	2	23	1052	9742	40014	\N	46.868234999999999	Ростовская область, Кагальницкий район, с. Васильево-Шамшево, ул. Жукова, 17		0101000020E61000005F5D15A8C5FA43400C1F1153226F4740
77293	2	23	1052	12209	55980	\N	47.032705588373403	Ростовская область, Кагальницкий район, п. Березовая Роща, ул. Бирюкова, 8	Россия, Ростовская область, Кагальницкий район, поселок Березовая Роща	0101000020E6100000E3A7716F7EFD43400531D0B52F844740
46282	2	20	\N	50262	23900	\N	43.456825000000002	с.Орел-Изумруд, Петрозаводская, 10, телефон: 466958		0101000020E610000036E9B6442EF64340637FD93D79BA4540
75811	2	23	66	56770	55918	\N	46.865632386251797	Ростовская область, Зимовниковский район, х.Хуторской, Стадионная, 7	Россия, Ростовская область, Зимовниковский район, хутор Хуторской	0101000020E6100000601DC70F957E45407F2F8507CD6E4740
75804	2	23	66	56915	56448	\N	47.132344000000003	Ростовская область, Зимовниковский район, х.Харьковский, Клубный, 5		0101000020E610000068942EFD4B0C454032E9EFA5F0904740
75817	2	23	66	1923	55514	\N	46.757513000000003	Ростовская область, Зимовниковский район, п.Савоськин, Кирова, 59		0101000020E6100000D34A21904B664540BEA59C2FF6604740
75814	2	23	66	56996	56543	\N	46.933045999999997	Ростовская область, Зимовниковский район, х.Погорелов, Зелёный, 2	Россия, Ростовская область, Зимовниковский район, хутор Погорелов	0101000020E6100000C6866EF6074E4540F1D4230D6E774740
75809	2	23	66	56741	55888	\N	47.039829105252799	Ростовская область, Зимовниковский район, х.Плотников, Мира, 22	Россия, Ростовская область, Зимовниковский район, хутор Плотников	0101000020E61000006FF1F09E036D45405837DE1D19854740
75795	2	23	66	57020	56576	\N	47.052503999999999	Ростовская область, Зимовниковский район, х.Нариманов, Школьная, 17	Россия, Ростовская область, Зимовниковский район, хутор Нариманов	0101000020E61000003C4B9011503B454060747973B8864740
75815	2	23	66	1860	55582	\N	46.880229	Ростовская область, Зимовниковский район, п.Мокрый Гашун, Центральная, 64		0101000020E61000009C4EB2D5E5604540D2FE0758AB704740
75798	2	23	66	56958	56498	\N	47.070188999999999	Ростовская область, Зимовниковский район, х.Марченков, Победы, 20 Б		0101000020E610000033DC80CF0F4D4540FCC401F4FB884740
75801	2	23	66	56870	56398	\N	47.232658000000001	Ростовская область, Зимовниковский район, х.Майкопский, Центральный, 18	Россия, Ростовская область, Зимовниковский район, хутор Майкопский	0101000020E610000016F6B4C35F3F45408E93C2BCC79D4740
75796	2	23	66	56937	56474	\N	47.097887	Ростовская область, Зимовниковский район, х.Ленинский, Мира, 38	Россия, Ростовская область, Зимовниковский район, хутор Ленинский	0101000020E61000009A44BDE0D33A45400EDAAB8F878C4740
75794	2	23	66	56839	56281	\N	47.130786999999998	Ростовская область, Зимовниковский район, х.Лагунный, Макарчука, 58	Россия, Ростовская область, Зимовниковский район, поселок Лагунный	0101000020E6100000E1CFF0660D304540F8DEDFA0BD904740
75802	2	23	66	1112	40213	\N	47.237406	Ростовская область, Зимовниковский район, ст.Кутейниковская, Школьный, 32		0101000020E61000000A4966F50E114540E5EFDE51639E4740
75812	2	23	66	1692	55823	\N	46.748393999999998	Ростовская область, Зимовниковский район, п.Краснестепной, Школьная, 9 В		0101000020E61000004FCE50DCF18C4540E542E55FCB5F4740
75813	2	23	66	56653	55339	\N	46.888647576603297	Ростовская область, Зимовниковский район, х.Камышев, Мира, 16	Россия, Ростовская область, Зимовниковский район, хутор Камышев	0101000020E610000052499D8026424540F2D3B837BF714740
75799	2	23	66	42353	14469	\N	47.137614405702998	Ростовская область, Зимовниковский район, х.Ильичев, Лодянова, 19 Б	Россия, Ростовская область, Зимовниковский район, хутор Ильичев	0101000020E6100000EF1EA0FB7258454062BCE6559D914740
75790	2	23	66	81	40045	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Сиреневая, 92		0101000020E61000002F698CD6513B4540111C977153934740
75789	2	23	66	81	41064	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Пушкина, 8		0101000020E61000002F698CD6513B4540111C977153934740
75791	2	23	66	81	40047	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Малый, 2		0101000020E61000002F698CD6513B4540111C977153934740
75803	2	23	66	81	55820	\N	47.151393822783703	Ростовская область, Зимовниковский район, п.Зимовники, Магистральная, 23	Россия, Ростовская область, Зимовниковский район, поселок Зимовники	0101000020E6100000CD21A985923B4540C367EBE060934740
75785	2	23	66	81	39927	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Круглякова, 120		0101000020E61000002F698CD6513B4540111C977153934740
75788	2	23	66	81	41058	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Игнатовский, 85		0101000020E61000002F698CD6513B4540111C977153934740
75792	2	23	66	81	40048	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Дружбы, 135		0101000020E61000002F698CD6513B4540111C977153934740
75787	2	23	66	81	40127	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Дзержинского, 206		0101000020E61000002F698CD6513B4540111C977153934740
75786	2	23	66	81	40127	\N	47.150984000000001	Ростовская область, Зимовниковский район, п.Зимовники, Дзержинского, 179		0101000020E61000002F698CD6513B4540111C977153934740
75810	2	23	66	56789	55940	\N	47.008565850894897	Ростовская область, Зимовниковский район, х.Глубокий, Садовая, 23	Россия, Ростовская область, Зимовниковский район, хутор Глубокий	0101000020E61000003160C9552C664540C4EDD0B018814740
75807	2	23	66	54835	39952	\N	47.278486055944903	Ростовская область, Зимовниковский район, х.Гашун ж/д, Деревенского, 2	Россия, Ростовская область, Зимовниковский район, хутор Гашун	0101000020E61000003BE466B8014D45406A32E36DA5A34740
75806	2	23	66	56939	56476	\N	47.367220000000003	Ростовская область, Зимовниковский район, х.Верхоломов, Школьная, 1 В	Россия, Ростовская область, Зимовниковский район, хутор Верхоломов	0101000020E61000001CEA77616B344540F437A11001AF4740
75805	2	23	66	56660	55364	\N	47.327272486531903	Ростовская область, Зимовниковский район, сл.Верхнесеребряковка, Мира, 12 А	Россия, Ростовская область, Зимовниковский район, слобода Верхнесеребряковка	0101000020E610000034130CE71A1E4540C172840CE4A94740
75808	2	23	66	1462	55578	\N	47.128898999999997	Ростовская область, Зимовниковский район, п.Байков, Парковая, 15		0101000020E61000008C0FB3976D7B454059BE2EC37F904740
75448	2	23	1220	56891	56420	\N	46.955274000000003	Ростовская область, Зерноградский район, х. Средние Хороли, Заречная, 9	Россия, Ростовская область, Зерноградский район, хутор Средние Хороли	0101000020E61000007C6473D53C3D44400C5C1E6B467A4740
75451	2	23	1220	16493	40410	\N	47.042777999999998	Ростовская область, Зерноградский район, п. Сорговый, Центральная, 9		0101000020E6100000DD06B5DFDA334440807EDFBF79854740
75438	2	23	1220	15844	55749	\N	46.608285000000002	Ростовская область, Зерноградский район, с. Светлоречное, Специалистов, 23		0101000020E61000003A933655F72C4440DDD26A48DC4D4740
75427	2	23	1220	56865	56392	\N	46.730601	Ростовская область, Зерноградский район, х.Революционный, Магистральная, 96	Россия, Ростовская область, Зерноградский район, хутор Революционный	0101000020E61000007A34D593F921444063B66455845D4740
75477	2	23	1220	56906	56438	\N	46.896415769499299	Ростовская область, Зерноградский район, х. Ракитный, Заречная, 61	Россия, Ростовская область, Зерноградский район, хутор Ракитный	0101000020E610000075931804562844403ACE6DC2BD724740
75452	2	23	1220	56625	55265	\N	46.934116155993998	Ростовская область, Зерноградский район, х. Путь Правды, Ленина, 85/5	Россия, Ростовская область, Зерноградский район, хутор Путь Правды	0101000020E6100000605B3FFD67834440CE55F31C91774740
75459	2	23	1220	56809	56078	\N	46.794882000000001	Ростовская область, Зерноградский район, п. Прудовый, Платова, 1	Россия, Ростовская область, Зерноградский район, поселок Прудовой	0101000020E6100000DC2F9FAC181E4440EC1681B1BE654740
75444	2	23	1220	56985	56531	\N	46.913462000000003	Ростовская область, Зерноградский район, х. Попов, 40 лет Победы, 89 В		0101000020E6100000118DEE2076524440C311A452EC744740
75441	2	23	1220	56990	56536	\N	46.7889785530284	Ростовская область, Зерноградский район, х. Пишванов, Мира, 27А	Россия, Ростовская область, Зерноградский район, хутор Пишванов	0101000020E6100000020F0C207C4E44408A1D8D43FD644740
75446	2	23	1220	16240	56333	\N	47.124870999999999	Ростовская область, Зерноградский район, п. Осокино, Майская, 11		0101000020E61000001AF8510DFB314440029CDEC5FB8F4740
75410	2	23	1220	14519	56323	\N	47.052822999999997	Ростовская область, Зерноградский район, п. Новые Постройки, пер. Казачий, 37		0101000020E61000001A1A4F04712E444001BD70E7C2864740
75439	2	23	1220	15895	56076	\N	46.915486999999999	Ростовская область, Зерноградский район, с. Новокузнецовка, Специалистов, 32		0101000020E6100000645C717154444440E27492AD2E754740
75360	2	23	1220	12193	56072	\N	46.523926665730698	Ростовская область, Зерноградский район, с. Новоивановка, Школьная, 24	Россия, Ростовская область, Зерноградский район, село Новоивановка	0101000020E6100000A8E507AEF2244440E63E390A10434740
75431	2	23	1220	56825	56221	\N	46.580666000000001	Ростовская область, Зерноградский район, х. Новая Поляна, Бородинская, 35	Россия, Ростовская область, Зерноградский район, хутор Новая Поляна	0101000020E61000001898158A741B444017F37343534A4740
75429	2	23	1220	15437	55946	\N	46.539161999999997	Ростовская область, Зерноградский район, п. Нижнекугоейский, Мира, 20		0101000020E6100000CFD90242EB0944407B9FAA4203454740
75420	2	23	1220	54860	40408	\N	46.775831602209401	Ростовская область, Зерноградский район, ст. Мечетинская, Токарева, 93	Россия, Ростовская область, Зерноградский район, станица Мечетинская	0101000020E61000000F0C207C283B44405B9885764E634740
75423	2	23	1220	54860	40107	\N	46.777246799769003	Ростовская область, Зерноградский район, ст.Мечетинская, Победы, 35	Россия, Ростовская область, Зерноградский район, станица Мечетинская	0101000020E6100000FF243E77823B444002F566D47C634740
75422	2	23	1220	54860	40106	\N	46.7777185239716	Ростовская область, Зерноградский район, ст. Мечетинская, Ленина, 23	Россия, Ростовская область, Зерноградский район, станица Мечетинская	0101000020E61000004D4D8237A43B4440293DD34B8C634740
75421	2	23	1220	54860	40106	\N	46.777246799769003	Ростовская область, Зерноградский район, ст.Мечетинская, Ленина, 68	Россия, Ростовская область, Зерноградский район, станица Мечетинская	0101000020E6100000335019FF3E3B444002F566D47C634740
75445	2	23	1220	16180	55948	\N	47.094499999999996	Ростовская область, Зерноградский район, п. Междупольный, Ростовская, 41		0101000020E6100000691D554D102944406ABC7493188C4740
75447	2	23	1220	16301	56075	\N	47.084707999999999	Ростовская область, Зерноградский район, п. Малый Лог, Молодежная, 25		0101000020E6100000B91803EB383C4440D3DA34B6D78A4740
75436	2	23	1220	15767	56320	\N	46.885120000000001	Ростовская область, Зерноградский район, п. Лободин, Майская, 14		0101000020E6100000978DCEF9296C44408C84B69C4B714740
75428	2	23	1220	15343	56211	\N	46.515582999999999	Ростовская область, Зерноградский район, с. Ленинка, Парковая, 3		0101000020E610000058C9C7EE022B4440D1AFAD9FFE414740
75453	2	23	1220	56940	56499	\N	46.882286000000001	Ростовская область, Зерноградский район, х. Краснюков, Молодежная, 42/4	Россия, Ростовская область, Зерноградский район, хутор Краснюков	0101000020E61000006A317898F6734440FDDB65BFEE704740
75442	2	23	1220	56892	56421	\N	46.703616697575001	Ростовская область, Зерноградский район, х. Красноармейский, Заречная, 16А	Россия, Ростовская область, Зерноградский район, хутор Красноармейский	0101000020E610000018D1764CDD4D44406FF4311F105A4740
75455	2	23	1220	16701	55656	\N	46.925131999999998	Ростовская область, Зерноградский район, п. Комсомольский, ул. Тургенева, 16		0101000020E610000040D9942BBC2F4440D53DB2B96A764740
75434	2	23	1220	56776	55924	\N	46.732138999999997	Ростовская область, Зерноградский район, х. Клюев, Садовая, 10 В	Россия, Ростовская область, Зерноградский район, хутор Клюев	0101000020E61000003733FAD170524440259012BBB65D4740
75457	2	23	1220	16804	55652	\N	46.853354000000003	Ростовская область, Зерноградский район, п. Кленовый, Куйбышева, 11А		0101000020E610000058207A52262F444095F430B43A6D4740
75479	2	23	1220	17061	40427	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Шукшина, 14		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
77718	2	23	1220	17061	55602	\N	46.854652085000602	Ростовская область, Зерноградский район, г. Зерноград, Специалистов, 57	Россия, Ростовская область, Зерноградский район, Зерноград	0101000020E61000001094DBF63D28444002BB9A3C656D4740
75462	2	23	1220	17061	9752	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Социалистическая, 35/42		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75471	2	23	1220	17061	40423	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Советская, 28		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75476	2	23	1220	17061	41039	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Научный Городок, 3		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75473	2	23	1220	17061	39649	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Мира, 22		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75467	2	23	1220	17061	39649	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Мира, 8		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75472	2	23	1220	17061	9807	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Ленина, 17		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75466	2	23	1220	17061	9807	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Ленина, 32		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75464	2	23	1220	17061	9807	\N	46.850118098933301	Ростовская область, Зерноградский район, г. Зерноград, Ленина, 14	Россия, Ростовская область, Зерноградский район, Зерноград	0101000020E6100000B07614E7A8274440D7DEA7AAD06C4740
75480	2	23	1220	17061	39651	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Еремина, 17		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75469	2	23	1220	17061	40108	\N	46.848700999999998	Ростовская область, Зерноградский район, г. Зерноград, Гагарина, 1		0101000020E6100000F8FE06EDD52744408F8AFF3BA26C4740
75461	2	23	1220	17008	56212	\N	46.835202000000002	Ростовская область, Зерноградский район, п. Зерновой, Разина, 7		0101000020E61000002A8F6E84451F4440E3C62DE6E76A4740
75437	2	23	1220	56705	55847	\N	46.985534565480101	Ростовская область, Зерноградский район, х. Заполосный, Степная, 20	Россия, Ростовская область, Зерноградский район, хутор Заполосный	0101000020E6100000AFB0E07EC06944401C08C902267E4740
77715	2	23	1220	30288	56254	\N	46.584406999999999	Ростовская область, Зерноградский район, п. Займище, Школьная, 4		0101000020E6100000847F1134660C4440D8463CD9CD4A4740
75440	2	23	1220	15948	40409	\N	46.848953999999999	Ростовская область, Зерноградский район, х. Донской, Цветной Бульвар, 29		0101000020E61000003370404B5746444079E75086AA6C4740
75430	2	23	1220	54831	39944	\N	46.629422767497502	Ростовская область, Зерноградский район, х. Гуляй-Борисовка, 50 лет ВЛКСМ, 8/63	Россия, Ростовская область, Зерноградский район, хутор Гуляй-Борисовка	0101000020E6100000813FFCFCF71A4440D42CD0EE90504740
75454	2	23	1220	56994	56540	\N	46.905304999999998	Ростовская область, Зерноградский район, х. Голубовка, Школьная, 5/3	Россия, Ростовская область, Зерноградский район, хутор Голубовка	0101000020E6100000CB82893F8A664440E0F3C308E1734740
75449	2	23	1220	56934	56470	\N	47.005305999999997	Ростовская область, Зерноградский район, х. Верхние Хороли, Школьная, 24А	Россия, Ростовская область, Зерноградский район, хутор Верхние Хороли	0101000020E610000061E124CD1F3B44407D3CF4DDAD804740
75450	2	23	1220	56944	56483	\N	47.025776999999998	Ростовская область, Зерноградский район, х. Булочкин, Центральная, 65	Россия, Ростовская область, Зерноградский район, хутор Булочкин	0101000020E6100000793D98141F43444097FE25A94C834740
75432	2	23	1220	57000	56548	\N	46.628826975391497	Ростовская область, Зерноградский район, х. Большие Эльбуздовские, Родниковая, 2А	Россия, Ростовская область, Зерноградский район, хутор Большие Эльбуздовские	0101000020E6100000C1E270E657134440C0EB33677D504740
75443	2	23	1220	56712	55855	\N	46.979514999999999	Ростовская область, Зерноградский район, х. Большая Таловая, Ленина, 4А	Россия, Ростовская область, Зерноградский район, хутор Большая Таловая	0101000020E6100000F94A2025764F444081785DBF607D4740
75433	2	23	1220	56887	56416	\N	46.625258000000002	Ростовская область, Зерноградский район, х. Болдиновка, Звездная, 30	Россия, Ростовская область, Зерноградский район, хутор Болдиновка	0101000020E61000003D2B69C537204440FCC7427408504740
75426	2	23	1220	57013	56561	\N	46.694096000000002	Ростовская область, Зерноградский район, х. 2-й Россошинский, Мира, 27	Россия, Ростовская область, Зерноградский район, хутор 2-й Россошинский	0101000020E6100000289CDD5A2619444068244223D8584740
75424	2	23	1220	56715	56580	\N	46.683671869984103	Ростовская область, Зерноградский район, х.1-й Россошинский, Садовая, 5	Россия, Ростовская область, Зерноградский район, хутор 1-й Россошинский	0101000020E610000017670C73822A44407098689082574740
75425	2	23	1220	56715	55858	\N	46.682963000000001	Ростовская область, Зерноградский район, х.1-й Россошинский, Заречная, 92	Россия, Ростовская область, Зерноградский район, хутор 1-й Россошинский	0101000020E6100000DC9BDF30D12A444064B0E2546B574740
75779	2	23	1766	32241	55664	\N	47.363351000000002	Ростовская область, Заветинский район, хутор Шебалин, Гагарина, 1		0101000020E610000028EE7893DFCE454005FC1A4982AE4740
75781	2	23	1766	32329	55646	\N	46.959899	Ростовская область, Заветинский район, хутор Фомин, Центральная, 9		0101000020E6100000B858518369D44540473B6EF8DD7A4740
75784	2	23	1766	32475	55771	\N	46.873041000000001	Ростовская область, Заветинский район, село Федосеевка, Центральная, 11А		0101000020E61000007CB8E4B8530046409888B7CEBF6F4740
14034	1	17	\N	3130	22380	\N	58.045848999999997	г.Рыбинск, Черепанова, 15		0101000020E6100000B3614D65516C4340F3C64961DE054D40
75783	2	23	1766	32418	55768	\N	46.822001999999998	Ростовская область, Заветинский район, село Тюльпаны, Школьная, 16А		0101000020E6100000C503CAA65CD54540909F8D5C37694740
75782	2	23	1766	32387	55648	\N	46.783850000000001	Ростовская область, Заветинский район, хутор Савдя, Центральная, 11		0101000020E6100000D734EF3845BD45401C7C613255644740
77604	2	23	1766	25203	55965	\N	47.254063000000002	Ростовская область, Заветинский район,  хутор Новобеляевский, Зеленая, 16/2		0101000020E6100000EFE53E390AC84540D40FEA2285A04740
77605	2	23	1766	25249	56008	\N	47.242435	Ростовская область, Заветинский район, хутор Никольский, Школьная, 22А		0101000020E61000001822A7AFE7D94540F0332E1C089F4740
75780	2	23	1766	25249	56008	\N	47.242435	Ростовская область, Заветинский район, хутор Никольский, Школьная, 10А		0101000020E61000001822A7AFE7D94540F0332E1C089F4740
75777	2	23	1766	32168	55764	\N	47.074356000000002	Ростовская область, Заветинский район, село Кичкино, Школьная, 15А		0101000020E610000076C4211B480546407521567F84894740
75778	2	23	1766	32234	55766	\N	47.303458999999997	Ростовская область, Заветинский район, село Киселевка, Новый, 6		0101000020E610000079CC4065FC134640A35698BED7A64740
75775	2	23	1766	32093	41241	\N	47.117812999999998	Ростовская область, Заветинский район, село Заветное, Ломоносова, 39		0101000020E610000095BA641C23F345409605137F148F4740
75776	2	23	1766	32093	39683	\N	47.116875602266802	Ростовская область, Заветинский район, село Заветное, Горького, 52	Россия, Ростовская область, Заветинский район, село Заветное	0101000020E6100000581F0F7D77F34540F9D7F2CAF58E4740
77603	2	23	1766	25128	56363	\N	47.054203999999999	Ростовская область, Заветинский район, хутор Андреев, Центральная, 14А		0101000020E6100000E84EB0FF3A134640FCA71B28F0864740
75413	2	23	1286	14644	39940	\N	46.368357000000003	Ростовская область, Егорлыкский район, Шаумяновское сельское поселение, хутор Шаумяновский, Шаумяна, 21		0101000020E610000025E82FF48845444058207A52262F4740
75403	2	23	1286	14185	56206	\N	46.571604000000001	Ростовская область, Егорлыкский район, Войновское сельское поселение, хутор Украинский, пер. Школьный, 6		0101000020E6100000BDA772DA536A4440A321E3512A494740
75404	2	23	1286	14237	55503	\N	46.670077999999997	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, хутор Таганрогский, ул. Специалистов, 23 (здание МБОУ БООШ №13)		0101000020E61000002670EB6E9E58444071E2AB1DC5554740
75392	2	23	1286	13642	56318	\N	46.396394000000001	Ростовская область, Егорлыкский район, Балко-Грузское сельское поселение, хутор Тавричанка, Мира, 30а		0101000020E61000008505F7031E3E4440522AE109BD324740
75417	2	23	1286	14851	55123	\N	46.428542	Ростовская область, Егорлыкский район, Роговское сельское поселение, поселок Роговский, пер. Победы, 10		0101000020E61000007D96E7C1DD4F4440317BD976DA364740
75407	2	23	1286	14381	40402	\N	46.612532000000002	Ростовская область, Егорлыкский район, Объединенное сельское поселение, хутор Объединенный, Зеленая, 25		0101000020E61000002786E464E238444072E0D572674E4740
75415	2	23	1286	14777	40404	\N	46.336615000000002	Ростовская область, Егорлыкский район, Новороговское сельское поселение, станица Новороговская, ул. Школьная, 50 (здание МБОУ НСОШ №2)		0101000020E61000003674B33F50564440E92B4833162B4740
75411	2	23	1286	14572	41032	\N	46.402205000000002	Ростовская область, Егорлыкский район, Балко-Грузское сельское поселение, хутор Мирный, Почтовая, 1г		0101000020E6100000FD304278B4354440D3A414747B334740
75409	2	23	1286	14458	41030	\N	46.461900999999997	Ростовская область, Егорлыкский район, Ильинское сельское поселение, хутор Кугейский, Октябрьская, 31		0101000020E6100000B1FB8EE1B13F4440AE7E6C921F3B4740
75414	2	23	1286	14711	41034	\N	46.345368000000001	Ростовская область, Егорлыкский район, Кавалерское сельское поселение, хутор Кавалерский, Ленина, 33		0101000020E6100000F37519FED3354440DF8AC404352C4740
75408	2	23	1286	14426	56322	\N	46.519868000000002	Ростовская область, Егорлыкский район, Ильинское сельское поселение, хутор Ильинский, Парковая, 3/1		0101000020E6100000637E6E68CA404440541EDD088B424740
75400	2	23	1286	14016	55640	\N	46.662645828824601	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, хутор Изобильный, Ростовская, 12	Россия, Ростовская область, Егорлыкский район, хутор Изобильный	0101000020E61000004835ECF7C4484440A1698995D1544740
75396	2	23	1286	13475	41028	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, пер.Тергенева, 129, (здание МБОУ №7 им.О.Казанского)		0101000020E61000004C38F4160F5544407D08AA46AF484740
75406	2	23	1286	13475	40103	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, пер. Первомайский, 57		0101000020E61000004C38F4160F5544407D08AA46AF484740
75389	2	23	1286	13475	40103	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, пер. Первомайский, 1		0101000020E61000004C38F4160F5544407D08AA46AF484740
75393	2	23	1286	13475	41026	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, Ростовская, 117		0101000020E61000004C38F4160F5544407D08AA46AF484740
75397	2	23	1286	13475	40272	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, Мичурина, 5		0101000020E61000004C38F4160F5544407D08AA46AF484740
75398	2	23	1286	13475	41029	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, ул. Малькова, 5		0101000020E61000004C38F4160F5544407D08AA46AF484740
75391	2	23	1286	13475	40972	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, Ленина, 62		0101000020E61000004C38F4160F5544407D08AA46AF484740
75388	2	23	1286	13475	40972	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, Ленина, 1		0101000020E61000004C38F4160F5544407D08AA46AF484740
75394	2	23	1286	13475	39647	\N	46.567849000000002	Ростовская область, Егорлыкский район, Егорлыкское сельское поселение, станица Егорлыкская, Грицика, 119		0101000020E61000004C38F4160F5544407D08AA46AF484740
75401	2	23	1286	14106	55499	\N	46.504418999999999	Ростовская область, Егорлыкский район, Войновское сельское поселение, хутор Войнов, Садовая, 32 (здание МБОУ ВСОШ №9)		0101000020E610000078B988EFC4644440923D42CD90404740
75412	2	23	1286	14618	55653	\N	46.407269999999997	Ростовская область, Егорлыкский район, Балко-Грузское сельское поселение, хутор Балко-Грузский, Школьная, 8		0101000020E61000008AE3C0ABE52C44402A52616C21344740
75771	2	23	480	31893	56032	\N	47.297702999999998	Ростовская область, Дубовский район, Андреевское сельское поселение, ст. Эркетиновская, ул. Молодежная, 13		0101000020E6100000CD565EF23F814540E675C4211BA64740
75762	2	23	480	31503	55660	\N	47.400191	Ростовская область, Дубовский район, Барабанщиковское сельское поселение, х.Щеглов, ул. Садовая, 37		0101000020E6100000ADC3D155BA514540A7936C7539B34740
75768	2	23	480	31792	55555	\N	47.487130000000001	Ростовская область, Дубовский район, Семичанское сельское поселение, х.Семичный, ул. Ленина, 14		0101000020E61000002CD49AE61D7F454043739D465ABE4740
75760	2	23	480	56735	55881	\N	47.360067000000001	Ростовская область, Дубовский район, Романовское сельское поселение, х.Романов, Молодежная, 24		0101000020E61000007959130B7C5F454036AFEAAC16AE4740
75773	2	23	480	32017	55561	\N	47.056648000000003	Ростовская область, Дубовский район, Присальское сельское поселение, х. Присальский, ул. Центральная, 7		0101000020E610000070EB6E9EEAA0454021B1DD3D40874740
75764	2	23	480	39345	56054	\N	47.564259	Ростовская область, Дубовский район, Жуковское сельское поселение, ст. Подгорненская, пер. Солнечный, 18		0101000020E6100000A2B5A2CD71304540A1BC8FA339C84740
75759	2	23	480	31361	56004	\N	47.238880999999999	Ростовская область, Дубовский район, Веселовское сельское поселение, х.Новогашунский, ул.Центральная, 74		0101000020E6100000378DEDB5A0674540615111A7939E4740
75774	2	23	480	32046	56089	\N	46.908487999999998	Ростовская область, Дубовский район, Мирнинское сельское поселение, х. Мирный, ул. Центральная, 7		0101000020E61000001A4E999B6F9A45407B67B45549744740
75766	2	23	480	31690	56006	\N	47.733491621447001	Ростовская область, Дубовский район, Малолученское сельское поселение, ст.Малая  Лучка, ул. Приморская, 12	Россия, Ростовская область, Дубовский район, станица Малая Лучка	0101000020E61000009488F02F8256454056F0DB10E3DD4740
75772	2	23	480	56730	55875	\N	47.484214000000001	Ростовская область, Дубовский район, Комиссаровское сельское поселение. х. Сиротский, ул. Лесная, 15	Россия, Ростовская область, Дубовский район, хутор Лесной	0101000020E61000002DCE18E6042D4540F7216FB9FABD4740
75765	2	23	480	31648	40126	\N	47.622971	Ростовская область, Дубовский район, Жуковское сельское поселение, ст. Жуковская, Центральная  площадь, 1		0101000020E6100000B682A625564045409FAD8383BDCF4740
75761	2	23	480	31472	55645	\N	47.410266	Ростовская область, Дубовский район, Дубовское сельское поселение, х.Ериковский, пер. Школьный, 18		0101000020E6100000A3EA573A1F5E45409354A69883B44740
75756	2	23	480	25057	55126	\N	47.409827	Ростовская область, Дубовский район, Дубовское сельское поселение, с. Дубовское, пл. Павших  Борцов 2, 2		0101000020E6100000310917F20862454047020D3675B44740
75757	2	23	480	25057	40298	\N	47.409827	Ростовская область, Дубовский район, Дубовское сельское поселение, с. Дубовское, пер. Герцена, 31		0101000020E6100000310917F20862454047020D3675B44740
77601	2	23	480	25057	55234	\N	47.409827	Ростовская область, Дубовский район, Дубовское сельское поселение, с. Дубовское, ул. Первомайская 38, 38		0101000020E6100000310917F20862454047020D3675B44740
77602	2	23	480	25057	40194	\N	47.409827	Ростовская область, Дубовский район, Дубовское сельское поселение, с.Дубовское, ул.Ленина, 73		0101000020E6100000310917F20862454047020D3675B44740
75769	2	23	480	31815	55668	\N	47.340989	Ростовская область, Дубовский район, Гуреевское сельское поселение, х.Гуреев, ул. Школьная, 2		0101000020E6100000F92D3A596AA14540DBA50D87A5AB4740
75758	2	23	480	56760	55907	\N	47.385370955438901	Ростовская область, Дубовский район, Веселовское сельское поселение, х.Веселый, Октябрьская, 45	Россия, Ростовская область, Дубовский район, хутор Веселый	0101000020E6100000850B7904376E4540D5E940D653B14740
75763	2	23	480	31568	55671	\N	47.527405999999999	Ростовская область, Дубовский район, Вербовологовское сельское поселение, х.Вербовый Лог, ул. Административная, 1		0101000020E610000004C8D0B1834C45406ADB300A82C34740
75770	2	23	480	31876	55773	\N	47.363447999999998	Ростовская область, Дубовский район, Андреевское сельское поселение, ст.Андреевская, ул. Центральная, 34		0101000020E6100000AB984A3FE1844540F7E5CC7685AE4740
75767	2	23	480	2860	56087	\N	47.664256081134603	Ростовская область, Дубовский район, Малолученское сельское поселение, х.Алдабульский, ул.Школьная, 1А	Россия, Ростовская область, Дубовский район, хутор Алдабульский	0101000020E61000004298DBBDDC4F4540FD15325706D54740
75735	2	23	82	30150	55761	\N	47.494107999999997	Ростовская область, Волгодонской район, Рябичевское сельское поселение, хутор Ясырев, улица Победы, 24		0101000020E610000048F949B54FEB4440925852EE3EBF4740
75733	2	23	82	30063	56082	\N	47.504761000000002	Ростовская область, Волгодонской район, Рябичевское сельское поселение, хутор Холодный, улица Центральная, 30 - а		0101000020E610000092B06F2711DD4440ECA529029CC04740
75742	2	23	82	30511	56227	\N	47.456676000000002	Ростовская область, Волгодонской район, Добровольское сельское поселение, хутор Сухая Балка, улица Центральная, 17		0101000020E6100000D6FCF84B8B1C45401E6FF25B74BA4740
75736	2	23	82	30199	56002	\N	47.471508999999998	Ростовская область, Волгодонской район, Потаповское сельское поселение, хутор Степной, улица Комсомольская, 14		0101000020E61000006F7EC34483F2444084622B685ABC4740
75741	2	23	82	30461	55760	\N	47.497542000000003	Ростовская область, Волгодонской район, Добровольское сельское поселение, поселок Солнечный, улица Прудовая, 18		0101000020E6100000999B6F44F72845407731CD74AFBF4740
77667	2	23	82	28072	55994	\N	47.426192	Ростовская область, Волгодонской район, Романовское сельское поселение, поселок Сибирьковый, улица Надежды, 23		0101000020E610000069C9E369F90345408EE89E758DB64740
75752	2	23	82	31010	56222	\N	47.343699999999998	Ростовская область, Волгодонской район, Романовское сельское поселение, хутор Семенкин, улица Центральная, 16		0101000020E61000004739984D800B45404ED1915CFEAB4740
75744	2	23	82	30582	56337	\N	47.407508999999997	Ростовская область, Волгодонской район, Добровольское сельское поселение, поселок Саловский, улица Молодежная, 4		0101000020E61000003A94A12AA6204540AFE9414129B44740
75738	2	23	82	30294	56003	\N	47.359077999999997	Ростовская область, Волгодонской район, Потаповское сельское поселение, поселок Савельевский, улица Степная, 4		0101000020E6100000D881734694EE4440465B9544F6AD4740
75734	2	23	82	30093	40628	\N	47.510525000000001	Ростовская область, Волгодонской район, Рябичевское сельское поселение, хутор Рябичев, улица Театральная, 49		0101000020E61000002EC6C03A8EE344402C6519E258C14740
77663	2	23	82	27914	39840	\N	47.540272999999999	Ростовская область, Волгодонской район, Романовское сельское поселение, станица Романовская, переулок Союзный, 44		0101000020E6100000CA32C4B12E044540B6F468AA27C54740
77666	2	23	82	27914	55243	\N	47.540272999999999	Ростовская область, Волгодонской район, Романовское сельское поселение, станица Романовская, улица Юбилейная, 2		0101000020E6100000CA32C4B12E044540B6F468AA27C54740
75755	2	23	82	27914	39715	\N	47.540272999999999	Ростовская область, Волгодонской район, Романовское сельское поселение, станица Романовская, улица Тюхова, 90		0101000020E6100000CA32C4B12E044540B6F468AA27C54740
77665	2	23	82	27914	40343	\N	47.540272999999999	Ростовская область, Волгодонской район, Романовское сельское поселение, станица Романовская, улица Мелиораторов, 8 - а		0101000020E6100000CA32C4B12E044540B6F468AA27C54740
75745	2	23	82	30646	55557	\N	47.424557999999998	Ростовская область, Волгодонской район, Прогрессовское сельское поселение, поселок Прогресс, адрес помещения для голосования: улица Ленина, 11, адрес УИК: переулок Лермонтова, 15		0101000020E6100000CADE52CE17E54440A9A0A2EA57B64740
77762	2	23	82	99	40964	\N	47.471107000000003	Ростовская область, Волгодонской район, Потаповское сельское поселение, хутор Потапов, улица Садовая, 67 - б		0101000020E61000002A1C412AC5F8444056F5F23B4DBC4740
75737	2	23	82	99	55666	\N	47.471107000000003	Ростовская область, Волгодонской район, Потаповское сельское поселение, хутор Потапов, улица Комсомольская, 45		0101000020E61000002A1C412AC5F8444056F5F23B4DBC4740
75754	2	23	82	31100	56086	\N	47.548375	Ростовская область, Волгодонской район, Романовское сельское поселение, хутор Погожев, улица Комсомольская, 1 - а		0101000020E610000016855D143D0A4540D578E92631C64740
75747	2	23	82	30766	55822	\N	47.420704999999998	Ростовская область, Волгодонской район, Победенское сельское поселение, поселок Победа, адрес помещения для голосования: улица Кооперативная, 7, адрес УИК: улица Кооперативная, 3		0101000020E610000037C7B94DB8D34440C02154A9D9B54740
75729	2	23	82	29850	55642	\N	47.522021000000002	Ростовская область, Волгодонской район, Дубенцовское сельское поселение, хутор Пирожок, улица Центральная, 11 - а		0101000020E6100000DDEC0F94DBB64440A1698995D1C24740
75731	2	23	82	29942	55758	\N	47.519806000000003	Ростовская область, Волгодонской район, Дубенцовское сельское поселение, хутор Морозов, улица Школьная, 24		0101000020E6100000B741EDB776CA4440DE21C50089C24740
75740	2	23	82	30367	56084	\N	47.495119000000003	Ростовская область, Волгодонской район, Добровольское сельское поселение, хутор Мокросоленый, улица Центральная, 27		0101000020E610000038691A14CD2745406A50340F60BF4740
75748	2	23	82	30781	55762	\N	47.420496999999997	Ростовская область, Волгодонской район, Победенское сельское поселение, поселок Мичуринский, улица Ленина, 12		0101000020E61000009701672959CC444076887FD8D2B54740
75753	2	23	82	31048	40293	\N	47.523896000000001	Ростовская область, Волгодонской район, Романовское сельское поселение, хутор Лагутники, переулок Юбилейный, 9 - а		0101000020E61000009D0FCF1264084540AB402D060FC34740
75751	2	23	82	30964	55644	\N	47.438052999999996	Ростовская область, Волгодонской район, Победенское сельское поселение, поселок Краснодонский, улица Мира, 18		0101000020E61000001D740987DEB644401475E61E12B84740
75739	2	23	82	30362	56338	\N	47.334533999999998	Ростовская область, Волгодонской район, Потаповское сельское поселение, хутор Калинин, улица Школьная, 7		0101000020E61000005D19541B9CF0444035B39602D2AA4740
75730	2	23	82	29911	55647	\N	47.523876999999999	Ростовская область, Волгодонской район, Дубенцовское сельское поселение, станица Дубенцовская, переулок Совхозный, 21		0101000020E61000007FDFBF7971BE44403410CB660EC34740
75749	2	23	82	30877	55643	\N	47.412284	Ростовская область, Волгодонской район, Победенское сельское поселение, поселок Донской, улица Гайдара, 7		0101000020E61000000CAEB9A3FFC144400055DCB8C5B44740
75746	2	23	82	40369	9964	\N	47.422768453750102	Ростовская область, Волгодонской район, Прогрессовское сельское поселение, поселок Виноградный, улица Дружбы, 19	Россия, Ростовская область, Волгодонской район, хутор Виноградный	0101000020E6100000B2101D0247DC4440CDE506431DB64740
75732	2	23	82	30003	55818	\N	47.515448999999997	Ростовская область, Волгодонской район, Рябичевское сельское поселение, станица Большовская, улица Школьная, 37 - а		0101000020E61000003F027FF8F9D34440C1E09A3BFAC14740
75721	2	23	1846	56779	55927	\N	47.275331000000001	Ростовская область, Веселовский район, х. Чаканиха, ул. Школьная, 15	Россия, Ростовская область, Веселовский район, поселок Чаканиха	0101000020E6100000C2323674B36944409949D40B3EA34740
75717	2	23	1846	29332	55662	\N	47.225242000000001	Ростовская область, Веселовский район, п. Средний Маныч, ул. Ленина, 4		0101000020E6100000959C137B68574440C3D7D7BAD49C4740
75723	2	23	1846	56946	56486	\N	47.131124	Ростовская область, Веселовский район, х. Спорный, ул. Центральная, 27	Россия, Ростовская область, Веселовский район, хутор Спорный	0101000020E6100000FE9AAC510F61444040DCD5ABC8904740
75715	2	23	1846	56868	56396	\N	47.183982845684604	Ростовская область, Веселовский район, х. Свобода, ул. Производственная, 19/2	Россия, Ростовская область, Веселовский район, хутор Свобода	0101000020E61000003F1A4E999B5344408E0244C18C974740
75722	2	23	1846	29518	56001	\N	47.286884999999998	Ростовская область, Веселовский район, п. Садковский, ул. Механическая, 4		0101000020E610000077BAF3C4737E4440425BCEA5B8A44740
75710	2	23	1846	56895	56424	\N	47.013942855669598	Ростовская область, Веселовский район, х. Проциков, ул. Верхняя, 35	Россия, Ростовская область, Веселовский район, хутор Проциков	0101000020E6100000022D5DC1365844400A815CE2C8814740
75712	2	23	1846	56753	55900	\N	47.088843602954	Ростовская область, Веселовский район, х. Позднеевка, ул. Центральная, 22	Россия, Ростовская область, Веселовский район, хутор Позднеевка	0101000020E6100000C1ADBB79AA4F444011397D3D5F8B4740
75718	2	23	1846	56792	55943	\N	47.257568967590998	Ростовская область, Веселовский район, п. Новый, ул. Дружбы, 7	Россия, Ростовская область, Веселовский район, поселок Новый	0101000020E6100000BBEEAD484C5C444051BB5F05F8A04740
75720	2	23	1846	56774	55922	\N	47.234836251959997	Ростовская область, Веселовский район, х. Нижнесоленый, ул. Садовая, 27	Россия, Ростовская область, Веселовский район, хутор Нижнесоленый	0101000020E6100000B1A206D33066444034F6251B0F9E4740
75724	2	23	1846	56894	56425	\N	47.156653200212801	Ростовская область, Веселовский район, х. Маныч-Балабинка, ул. Солнечная, 23а		0101000020E6100000E84B6F7F2E604440FFE89B340D944740
75713	2	23	1846	56727	55871	\N	47.167436076134301	Ростовская область, Веселовский район, х. Малая Западенка, ул. 40 лет Победы, 12/3	Россия, Ростовская область, Веселовский район, хутор Малая Западенка	0101000020E61000008A9125732C4944402716F88A6E954740
75725	2	23	1846	56702	55843	\N	47.174730773267498	Ростовская область, Веселовский район, х. Ленинский, ул. Вишневая, 51а	Россия, Ростовская область, Веселовский район, хутор Ленинский	0101000020E6100000416326512F724440774CDD955D964740
75727	2	23	1846	56679	55641	\N	47.027514004236899	Ростовская область, Веселовский район, х. Красный Октябрь, ул. Школьная, 59	Россия, Ростовская область, Веселовский район, хутор Красный Октябрь	0101000020E61000008A56EE05667F44405017299485834740
75728	2	23	1846	46289	55756	\N	46.981625732595802	Ростовская область, Веселовский район, х. Красный Маныч, ул. Центральная, 128	Россия, Ростовская область, Веселовский район, хутор Красный Маныч	0101000020E6100000D7F7E120219044409F73B7EBA57D4740
75716	2	23	1846	29273	56143	\N	47.101806000000003	Ростовская область, Веселовский район, х. Красный Кут, ул. Школьная, 5а	Россия, Ростовская область, Веселовский район, хутор Красный Кут	0101000020E6100000A9DDAF027C554440AF44A0FA078D4740
77674	2	23	1846	28419	55601	\N	47.103579000000003	Ростовская область, Веселовский район,  х. Красное Знамя, ул. Центральная, 24		0101000020E61000003D29931ADA444440B5C6A013428D4740
75709	2	23	1846	56827	56225	\N	47.065332282602903	Ростовская область, Веселовский район, х. Каракашев, ул. Старая, 37	Россия, Ростовская область, Веселовский район, хутор Каракашев	0101000020E6100000C7D5C8AEB46C4440EEB089CC5C884740
75726	2	23	1846	56935	56471	\N	47.051594999999999	Ростовская область, Веселовский район, х. Казачий, ул. Школьная, 20	Россия, Ростовская область, Веселовский район, хутор Казачий	0101000020E6100000DDB3AED1727444408DD13AAA9A864740
75708	2	23	1846	28782	40125	\N	47.087899	Ростовская область, Веселовский район, п. Веселый, пер. Комсомольский, 50а		0101000020E610000084BD892139614440F12C4146408B4740
75705	2	23	1846	28782	55125	\N	47.087899	Ростовская область, Веселовский район, п. Веселый, пер. Комсомольский, 50		0101000020E610000084BD892139614440F12C4146408B4740
75706	2	23	1846	28782	40291	\N	47.087899	Ростовская область, Веселовский район, п. Веселый, ул. Октябрьская, 190		0101000020E610000084BD892139614440F12C4146408B4740
75707	2	23	1846	28782	40627	\N	47.087899	Ростовская область, Веселовский район, п. Веселый, ул. Думенко, 185		0101000020E610000084BD892139614440F12C4146408B4740
75711	2	23	1846	29069	56343	\N	46.9761904947581	Ростовская область, Веселовский район, х. Верхний Хомутец, пер. Школьный, 6	Россия, Ростовская область, Веселовский район, хутор Верхний Хомутец	0101000020E6100000B05417F03261444054573ECBF37C4740
75719	2	23	1846	56661	55401	\N	47.236494999999998	Ростовская область, Веселовский район, х. Верхнесоленый, ул. Центральная, 61	Россия, Ростовская область, Веселовский район, хутор Верхнесоленый	0101000020E610000043AB9333146944407155D977459E4740
14070	1	17	\N	3130	22896	\N	58.045848999999997	г. Рыбинск, Фроловская, 4		0101000020E6100000B3614D65516C4340F3C64961DE054D40
76203	2	23	1585	21338	55559	\N	49.961295999999997	Ростовская область, Верхнедонской район, Шумилинское сельское поселение, станица Шумилинская, Ленина, 6		0101000020E6100000DF15C1FF56B8444047E350BF0BFB4840
76199	2	23	1585	56842	56300	\N	49.7798105829145	Ростовская область, Верхнедонской район, Тубянское сельское поселение, хутор Тубянской, Тубянская, 21	Россия, Ростовская область, Верхнедонской район, хутор Тубянский	0101000020E6100000069FE6E445924440D107CBD8D0E34840
76180	2	23	1585	20106	55765	\N	49.613585407880798	Ростовская область, Верхнедонской район, Мешковское сельское поселение, хутор Суходольный, Клубная, 6	Россия, Ростовская область, Верхнедонской район, поселок Суходольный	0101000020E61000000F62670A9D81444078280AF489CE4840
76195	2	23	1585	20962	56157	\N	49.801523477564302	Ростовская область, Верхнедонской район, Тубянское сельское поселение, хутор Суровский, Суровская, 26	Россия, Ростовская область, Верхнедонской район, хутор Суровский	0101000020E610000028BA2EFCE08C4440F4FE3F4E98E64840
76202	2	23	1585	21214	56030	\N	49.737538999999998	Ростовская область, Верхнедонской район, Тубянское сельское поселение, хутор Стоговской, Стоговская, 45		0101000020E6100000A8DF85ADD998444024438EAD67DE4840
76197	2	23	1585	21052	56028	\N	49.806749163959303	Ростовская область, Верхнедонской район, Солонцовское сельское поселение, хутор Солонцовский, Солонцовская, 123	Россия, Ростовская область, Верхнедонской район, хутор Солонцовский	0101000020E61000001172DEFFC7A74440558A1D8D43E74840
76204	2	23	1585	21374	56305	\N	49.920087000000002	Ростовская область, Верхнедонской район, Шумилинское сельское поселение, хутор Свидовский, Свидовская, 3-А		0101000020E6100000CF4BC5C6BCB44440C53C2B69C5F54840
76192	2	23	1585	20795	56158	\N	50.069262000000002	Ростовская область, Верхнедонской район, Шумилинское сельское поселение, хутор Раскольный, Раскольная, 33		0101000020E61000000F0EF62686C24440836DC493DD084940
76189	2	23	1585	20603	56042	\N	49.712986999999998	Ростовская область, Верхнедонской район, Тубянское сельское поселение, посёлок Придонский, Придонская, 80		0101000020E61000001A886533878E444090BC732843DB4840
76176	2	23	1585	19846	55607	\N	49.816932999999999	Ростовская область, Верхнедонской район, Казанское сельское поселение, хутор Поповка, Петровского, 52		0101000020E610000054E6E61BD18B4440F702B34291E84840
76168	2	23	1585	19435	56296	\N	49.614851999999999	Ростовская область, Верхнедонской район, Верхняковское сельское поселение, хутор Поздняковский, Лесная, 31		0101000020E6100000C154336B29604440AAF06778B3CE4840
76205	2	23	1585	21423	56041	\N	49.983114999999998	Ростовская область, Верхнедонской район, Шумилинское сельское поселение, хутор Песковатская Лопатина, Песковатсколопатинская, 120-А		0101000020E610000000ADF9F197AA4440809A5AB6D6FD4840
76196	2	23	1585	20996	56159	\N	50.157285999999999	Ростовская область, Верхнедонской район, Шумилинское сельское поселение, хутор Парижский, Парижская, 70		0101000020E610000050A912656FB14440300F99F221144940
76167	2	23	1585	19387	56178	\N	49.590862999999999	Ростовская область, Верхнедонской район, Верхняковское сельское поселение, хутор Павловский, Павловская, 76		0101000020E6100000B6813B50A76244404EB51666A1CB4840
76193	2	23	1585	20849	55763	\N	50.060161000000001	Ростовская область, Верхнедонской район, Шумилинское сельское поселение, хутор Новониколаевский, Центральная, 4		0101000020E6100000A0A86C5853BD444051BF0B5BB3074940
76183	2	23	1585	20249	56152	\N	49.561497000000003	Ростовская область, Верхнедонской район, Мещеряковское сельское поселение, хутор Нижнетиховский, Ермака, 9		0101000020E6100000E2AE5E45469F4440ACE63922DFC74840
76179	2	23	1585	20001	56301	\N	49.550007999999998	Ростовская область, Верхнедонской район, Мешковское сельское поселение, хутор Назаровский, Назаровская, 54, кв.1		0101000020E61000004A0A2C8029774440E94482A966C64840
76181	2	23	1585	20124	56154	\N	49.609738999999998	Ростовская область, Верхнедонской район, Мещеряковское сельское поселение, хутор Мрыховский, Мрыховская, 29-А		0101000020E61000006C7A50508A964440410C74ED0BCE4840
76164	2	23	1585	19241	56160	\N	49.650502000000003	Ростовская область, Верхнедонской район, Верхняковское сельское поселение, хутор Михайловский, Степная, 10		0101000020E61000004DF38E53746E4440C6FD47A643D34840
76186	2	23	1585	20452	41155	\N	49.694256000000003	Ростовская область, Верхнедонской район, Мигулинское сельское поселение, станица Мигулинская, Карла Маркса, 7		0101000020E61000003B8C497F2FA14440A1866F61DDD84840
76182	2	23	1585	20213	55727	\N	49.575566000000002	Ростовская область, Верхнедонской район, Мещеряковское сельское поселение, хутор Мещеряковский, Плешакова, 13-А		0101000020E6100000C45E28603B9C444043588D25ACC94840
76178	2	23	1585	19981	41153	\N	49.535482000000002	Ростовская область, Верхнедонской район, Мешковское сельское поселение, станица Мешковская, Победы, 2		0101000020E6100000C3D32B65197E444060CC96AC8AC44840
76177	2	23	1585	19904	56297	\N	49.515079999999998	Ростовская область, Верхнедонской район, Мешковское сельское поселение, хутор Меловатский, Меловатская, 40, кв.2		0101000020E6100000800D8810578644406E693524EEC14840
76163	2	23	1585	19161	56176	\N	49.675739	Ростовская область, Верхнедонской район, Верхняковское сельское поселение, хутор Макаровский, Макаровская, 5		0101000020E61000007B681F2BF8714440DDD0949D7ED64840
76175	2	23	1585	19814	55544	\N	49.810498063282303	Ростовская область, Верхнедонской район, Казанское сельское поселение, хутор Кукуевский, Школьная, 3	Россия, Ростовская область, Верхнедонской район, хутор Кукуевский	0101000020E6100000346953758F90444099BC0166BEE74840
14056	1	17	\N	3130	22517	\N	58.045848999999997	г. Рыбинск, Федорова, 7		0101000020E6100000B3614D65516C4340F3C64961DE054D40
76188	2	23	1585	20519	56155	\N	49.635964999999999	Ростовская область, Верхнедонской район, Мещеряковское сельское поселение, хутор Коноваловский, Центральная, 28		0101000020E61000009E7939ECBE8F44404833164D67D14840
76174	2	23	1585	19773	56151	\N	49.964894000000001	Ростовская область, Верхнедонской район, Казансколопатинское сельское поселение, хутор Колодезный, Колодезная, 105		0101000020E6100000200C3CF71E944440A60D87A581FB4840
75475	2	23	1585	56817	56140	\N	50.022171951704699	Ростовская область, Зерноградский район, х. Каменный, Семиренко, 4	Россия, Ростовская область, Верхнедонской район, хутор Каменный	0101000020E61000003C4B901150AD444086713788D6024940
76172	2	23	1585	19675	56294	\N	49.932003999999999	Ростовская область, Верхнедонской район, Казансколопатинское сельское поселение, хутор Казанская Лопатина, Лопатинская, 165		0101000020E610000048BF7D1D389F4440DFDE35E84BF74840
76170	2	23	1585	19483	40250	\N	49.791618999999997	Ростовская область, Верхнедонской район, Казанское сельское поселение, станица Казанская, Матросова, 10		0101000020E61000003F389F3A5693444034F279C553E54840
76169	2	23	1585	19483	41150	\N	49.791618999999997	Ростовская область, Верхнедонской район, Казанское сельское поселение, станица Казанская, Коммунальная, 13		0101000020E61000003F389F3A5693444034F279C553E54840
76198	2	23	1585	21096	56182	\N	49.770108	Ростовская область, Верхнедонской район, Солонцовское сельское поселение, хутор Заикинский, Заикинская, 126		0101000020E6100000E19A3BFA5F9A4440A93121E692E24840
76191	2	23	1585	20719	56190	\N	49.755991000000002	Ростовская область, Верхнедонской район, Солонцовское сельское поселение, хутор Дубровский, Дубровская, 80		0101000020E610000042D2A755F4B3444001892650C4E04840
76200	2	23	1585	21212	56029	\N	49.7642394566994	Ростовская область, Верхнедонской район, Тубянское сельское поселение, хутор Гормиловский, Гормиловская, 37	Россия, Ростовская область, Верхнедонской район, хутор Гормиловский	0101000020E6100000F3AFE595EB954440F4A96395D2E14840
76165	2	23	1585	19300	56292	\N	49.579970000000003	Ростовская область, Верхнедонской район, Верхняковское сельское поселение, хутор Верхняковский, Мира, 9		0101000020E6100000E9B5D95889694440A054FB743CCA4840
76166	2	23	1585	19300	55726	\N	49.579970000000003	Ростовская область, Верхнедонской район, Верхняковское сельское поселение, хутор Верхняковский, Административная, 6		0101000020E6100000E9B5D95889694440A054FB743CCA4840
76190	2	23	1585	20682	56100	\N	49.880142999999997	Ростовская область, Верхнедонской район, Нижнебыковское сельское поселение, хутор Быковский, Быковская, 213		0101000020E610000011FE45D098BD4440D3669C86A8F04840
76184	2	23	1585	20354	56153	\N	49.533780999999998	Ростовская область, Верхнедонской район, Мешковское сельское поселение, хутор Бирюковский, Бирюковская, 40		0101000020E6100000F8C5A52A6D934440F31C91EF52C44840
76185	2	23	1585	20424	56025	\N	49.455086000000001	Ростовская область, Верхнедонской район, Мешковское сельское поселение, хутор Алексеевский, Центральная, 4, кв.2		0101000020E61000007097FDBAD3914440096F0F4240BA4840
76151	2	23	1522	18555	56291	\N	49.276130999999999	Ростовская область, Боковский район, поселок Яблоновский, Казачья улица, 3		0101000020E6100000E49F19C407B44440B534B74258A34840
77736	2	23	1522	31367	56255	\N	49.172699999999999	Ростовская область, Боковский район, хутор Свиридов, Луговая улица, 42		0101000020E6100000637E6E68CAF4444075029A081B964840
76156	2	23	1522	18801	56147	\N	49.291027999999997	Ростовская область, Боковский район, хутор Попов, Школьная улица, 26		0101000020E610000016C1FF56B2E54440321CCF6740A54840
76148	2	23	1522	18383	56172	\N	49.191037999999999	Ростовская область, Боковский район, село Пономарёвка, Школьная улица, 28		0101000020E6100000EAAF575870DB44408925E5EE73984840
76147	2	23	1522	18343	56173	\N	49.137531000000003	Ростовская область, Боковский район, хутор Малаховский, Центральная улица, 24А		0101000020E610000028F224E99ADD4440D597A59D9A914840
76159	2	23	1522	18983	56175	\N	49.377043999999998	Ростовская область, Боковский район, хутор Лиховидовский, Школьная улица, 7		0101000020E6100000FCC8AD49B7CB4440969350FA42B04840
76153	2	23	1522	18650	56145	\N	49.338974	Ростовская область, Боковский район, хутор Латышев, Кривошлыкова улица, 36		0101000020E61000000114234BE6DA4440DF18028063AB4840
76139	2	23	1522	17926	56287	\N	49.153365999999998	Ростовская область, Боковский район, станица Краснокутская, Лазоревая улица, 13		0101000020E6100000AA49F08634FA4440BF28417FA1934840
76150	2	23	1522	18484	56174	\N	49.267631000000002	Ростовская область, Боковский район, поселок Краснозоринский, Школьная улица, 1		0101000020E61000006C787AA52CC54440A9328CBB41A24840
76155	2	23	1522	18778	56293	\N	49.263004000000002	Ростовская область, Боковский район, хутор Коньков, Коньковская улица, 34Б		0101000020E61000001B6327BC04E94440CD5B751DAAA14840
76154	2	23	1522	18715	56295	\N	49.337876999999999	Ростовская область, Боковский район, хутор Климовка, Школьная улица, 6		0101000020E6100000FC53AA44D9C344400989B48D3FAB4840
77717	2	23	1522	18627	55543	\N	49.350766	Ростовская область, Боковский район, станица Каргинская, Советская улица, 35		0101000020E6100000179F02603CD344403D4679E6E5AC4840
76152	2	23	1522	18627	55543	\N	49.350766	Ростовская область, Боковский район, станица Каргинская, Советская улица, 37		0101000020E6100000179F02603CD344403D4679E6E5AC4840
76141	2	23	1522	18061	56166	\N	49.177923999999997	Ростовская область, Боковский район, хутор Каменка, Песчаная улица, 77		0101000020E61000000473F4F8BD0345403596B036C6964840
76140	2	23	1522	18011	56142	\N	49.136887999999999	Ростовская область, Боковский район, хутор Илларионов, Магрицкого улица, 25		0101000020E61000004BCD1E6805004540809BC58B85914840
76149	2	23	1522	18449	55541	\N	49.204118999999999	Ростовская область, Боковский район, хутор Земцов, Школьная улица, 42		0101000020E61000000AD6389B8EEA444001BF4692209A4840
76144	2	23	1522	18203	56288	\N	49.230341000000003	Ростовская область, Боковский район, хутор Дулёнков, Песчаная улица, 29В		0101000020E610000072BF4351A0F14440C7F65AD07B9D4840
76157	2	23	1522	18883	56150	\N	49.360559000000002	Ростовская область, Боковский район, хутор Грушинский, Грушинская улица, 69		0101000020E610000091ED7C3F35E24440A5A31CCC26AE4840
76160	2	23	1522	19024	55751	\N	49.411802000000002	Ростовская область, Боковский район, хутор Грачев, Школьная улица, 35		0101000020E6100000AA49F08634C44440B5368DEDB5B44840
77738	2	23	1522	31466	56124	\N	49.34948	Ростовская область, Боковский район, хутор Горбатов, Луговая улица, 15А		0101000020E610000079E6E5B0FB024540944DB9C2BBAC4840
76162	2	23	1522	19156	56027	\N	49.409809000000003	Ростовская область, Боковский район, хутор Верхнечирский, Мира улица, 56		0101000020E6100000E38920CEC3A74440A14D0E9F74B44840
77737	2	23	1522	31383	55968	\N	49.160024	Ростовская огбласть, Боковский район, село Вербовка, Кристальная улица, 47/2		0101000020E6100000A5846055BDE044409D499BAA7B944840
76161	2	23	1522	19077	56149	\N	49.440097999999999	Ростовская область, Боковский район, хутор Большенаполовский, Школьная улица, 73		0101000020E6100000284696CCB1B644407B849A2155B84840
76145	2	23	1522	18253	40080	\N	49.226945999999998	Ростовская область, Боковский район, станица Боковская, Теличенко переулок, 27		0101000020E6100000CE35CCD078EA4440A0FA07910C9D4840
76146	2	23	1522	18253	40243	\N	49.226945999999998	Ростовская область, Боковский район, станица Боковская, Октябрьская улица, 20А		0101000020E6100000CE35CCD078EA4440A0FA07910C9D4840
76142	2	23	1522	18085	56024	\N	49.299900000000001	Ростовская область, Боковский район, хутор Белавин, Центральная улица, 17А		0101000020E6100000A59F70766BFF444003098A1F63A64840
75369	2	23	7337	56746	55893	\N	48.2459132619827	Ростовская область, Белокалитвинский район, х. Поцелуев, Старцева, 57		0101000020E6100000A9A44E40135B4440A454C2137A1F4840
75228	2	23	7337	54809	39635	\N	48.172224	Ростовская область, Белокалитвинский район, г.Белая Калитва, ул.Космонавтов, 3		0101000020E6100000D0B4C4CA686444400CCB9F6F0B164840
75245	2	23	855	6745	55744	\N	48.024532000000001	Ростовская область, Белокалитвинский район, п. Ясногорка, Строителей, 11		0101000020E6100000FA7C9411176244404DDA54DD23034840
75260	2	23	855	7392	40369	\N	48.280759000000003	Ростовская область, Белокалитвинский район, п. Шолоховский, Пушкина, 32		0101000020E6100000D908C4EBFA854440628731E9EF234840
75263	2	23	855	7392	40091	\N	48.280759000000003	Ростовская область, Белокалитвинский район, п. Шолоховский, Октябрьская, 19		0101000020E6100000D908C4EBFA854440628731E9EF234840
75259	2	23	855	7392	40367	\N	48.280759000000003	Ростовская область, Белокалитвинский район, п. Шолоховский, Максима Горького, 1		0101000020E6100000D908C4EBFA854440628731E9EF234840
75261	2	23	855	7392	39888	\N	48.280759000000003	Ростовская область, Белокалитвинский район, п. Шолоховский, Железнодорожная, 4		0101000020E6100000D908C4EBFA854440628731E9EF234840
75381	2	23	855	56914	56447	\N	47.910330000000002	Ростовская область, Белокалитвинский район, х. Чернышев, Центральная, 29А	Россия, Ростовская область, Белокалитвенский район, хутор Чернышев	0101000020E6100000CC2A6C06B85E4440AA4885B185F44740
75386	2	23	855	56694	55769	\N	48.047848000000002	Ростовская область, Белокалитвинский район, х. Чапаев, пер. Школьный, 2	Россия, Ростовская область, Белокалитвенский район, хутор Чапаев	0101000020E61000007BA4C16D6D634440EA961DE21F064840
75255	2	23	855	57023	56574	\N	47.9759030708829	Ростовская область, Белокалитвинский район, х.Усть-Быстрый, Верхняя, 65	Россия, Ростовская область, Белокалитвенский район, хутор Усть-Быстрый	0101000020E61000002096CD1C927C4440BE88B663EAFC4740
75240	2	23	855	6493	55651	\N	47.989404999999998	Ростовская область, Белокалитвинский район, п. Углекаменный, Бурденко, 1		0101000020E610000050357A3540714440DBBFB2D2A4FE4740
75373	2	23	855	12799	41024	\N	48.179254	Ростовская область, Белокалитвинский район, п. Сосны, Пролетарская, 1А		0101000020E61000004AD40B3ECD6B4440AED689CBF1164840
75242	2	23	855	6501	41226	\N	48.009193000000003	Ростовская область, Белокалитвинский район, п. Синегорский, м\\р Юбилейный, 23		0101000020E6100000FD3383F8C06C4440132D793C2D014840
75244	2	23	855	6501	39636	\N	48.009193000000003	Ростовская область, Белокалитвинский район, п. Синегорский, Маяковского, 6		0101000020E6100000FD3383F8C06C4440132D793C2D014840
75243	2	23	855	6501	40387	\N	48.009193000000003	Ростовская область, Белокалитвинский район, п. Синегорский, Горького, 15		0101000020E6100000FD3383F8C06C4440132D793C2D014840
75241	2	23	855	6501	55649	\N	48.009193000000003	Ростовская область, Белокалитвинский район, п. Синегорский, Белинского, 3		0101000020E6100000FD3383F8C06C4440132D793C2D014840
75246	2	23	855	6751	56303	\N	48.230494	Ростовская область, Белокалитвинский район, п. Русичи, Почтовая, 5		0101000020E6100000A208A9DBD94B44404DF6CFD3801D4840
75368	2	23	855	56973	56515	\N	48.281553813661901	Ростовская область, Белокалитвинский район, х. Рудаков, Школьная, 44	Россия, Ростовская область, Белокалитвенский район, хутор Рудаков	0101000020E61000000AF4893C497444406C0723F609244840
77720	2	23	855	56942	56480	\N	48.175474999999999	Ростовская область, Белокалитвинский район, п. разъезд Васильевский, Вокзальная, 16	Россия, Ростовская область, Белокалитвенский район, поселок Разъезд Васильевский	0101000020E610000095D5743DD1474440FF21FDF675164840
75371	2	23	855	56844	56321	\N	48.218215393781399	Ростовская область, Белокалитвинский район, х.Погорелов, Ефремовой, 2	Россия, Ростовская область, Белокалитвенский район, хутор Погорелов	0101000020E6100000AB402D060F714440923F1878EE1B4840
75376	2	23	855	56896	56426	\N	47.975642000000001	Ростовская область, Белокалитвинский район, х. Нижнесеребряковский, Центральная, 25		0101000020E61000005B087250C2844440514D49D6E1FC4740
14060	1	17	\N	3130	22716	\N	58.045848999999997	г. Рыбинск, Труда, 61а		0101000020E6100000B3614D65516C4340F3C64961DE054D40
75372	2	23	855	56755	55908	\N	48.168543326216898	Ростовская область, Белокалитвинский район, х. Нижнепопов, Молодежная, 23		0101000020E6100000DA8CD31055704440207C28D192154840
75375	2	23	855	56899	56429	\N	48.031967999999999	Ростовская область, Белокалитвинский район, х. Насонтов, Центральная, 57		0101000020E610000006B8205B968344405F42058717044840
75387	2	23	855	56845	56330	\N	48.065027091126602	Ростовская область, Белокалитвинский район, х. Мечетный, Шляхтная, 22	Россия, Ростовская область, Белокалитвенский район, хутор Мечетный	0101000020E6100000C190D5AD9E514440B22D03CE52084840
77734	2	23	855	31244	56135	\N	48.009326000000001	Ростовская область, Белокалитвинский район, п. Мельничный, Береговая, 24		0101000020E61000006DAE9AE7887444405280289831014840
75359	2	23	855	56791	55942	\N	48.574374370202499	Ростовская область, Белокалитвинский район, х. Марьевка, ул. Центральная, 2	Россия, Ростовская область, Белокалитвенский район, хутор Марьевка	0101000020E61000002E7590D7839D44401BD6541685494840
75366	2	23	855	12480	41022	\N	48.392287000000003	Ростовская область, Белокалитвинский район, с. Литвиновка, Школьная, 32		0101000020E6100000B29E5A7D75714440AFD2DD7536324840
75367	2	23	855	56652	55336	\N	48.299238825723897	Ростовская область, Белокалитвинский район, х. Ленина, Ленина, 112	Россия, Ростовская область, Белокалитвенский район, хутор Ленина	0101000020E61000000B613596B07044400858AB764D264840
75370	2	23	855	56759	55906	\N	48.247768229941599	Ростовская область, Белокалитвинский район, х.Крутинский, Центральная, 40	Россия, Ростовская область, Белокалитвенский район, хутор Крутинский	0101000020E6100000726A6798DA724440677FA0DCB61F4840
75378	2	23	855	13003	55746	\N	48.025357	Ростовская область, Белокалитвинский район, ст. Краснодонецкая, Центральная, 23		0101000020E6100000AE122C0E67744440C2DCEEE53E034840
75365	2	23	855	56726	55870	\N	48.4203041917824	Ростовская область, Белокалитвинский район, х. Кононов, Центральная, 60	Россия, Ростовская область, Белокалитвенский район, хутор Кононов	0101000020E610000025ADF886C277444062307F85CC354840
75251	2	23	855	6801	9823	\N	48.199109346670703	Ростовская область, Белокалитвинский район, п.Коксовый, Щаденко, 10	Россия, Ростовская область, Белокалитвенский район, поселок Коксовый	0101000020E6100000A1BC8FA3395444406DAB59677C194840
75254	2	23	855	6801	55718	\N	48.203929000000002	Ростовская область, Белокалитвинский район, п.Коксовый, Чехова, 22		0101000020E61000009F9273620F5544405EDA70581A1A4840
75253	2	23	855	6801	55738	\N	48.203929000000002	Ростовская область, Белокалитвинский район, п.Коксовый, Тургенева, 20		0101000020E61000009F9273620F5544405EDA70581A1A4840
75252	2	23	855	6801	55625	\N	48.203929000000002	Ростовская область, Белокалитвинский район, п.Коксовый, отечественная, 16А		0101000020E61000009F9273620F5544405EDA70581A1A4840
75248	2	23	855	6801	40208	\N	48.203929000000002	Ростовская область, Белокалитвинский район, п.Коксовый, к. Маркса, 2		0101000020E61000009F9273620F5544405EDA70581A1A4840
75247	2	23	855	6801	56307	\N	48.203584886334099	Ростовская область, Белокалитвинский район, п.Коксовый, Дзержинского, 26	Россия, Ростовская область, Белокалитвенский район, поселок Коксовый	0101000020E61000004F029B73F0544440637AC2120F1A4840
75249	2	23	855	6801	39638	\N	48.204477347251199	Ростовская область, Белокалитвинский район, п.Коксовый, Горноспасательная, 6		0101000020E6100000543A58FFE754444060E4654D2C1A4840
75385	2	23	855	56968	56509	\N	48.138003851291302	Ростовская область, Белокалитвинский район, х. Какичев, Центральная, 44	Россия, Ростовская область, Белокалитвенский район, хутор Какичев	0101000020E6100000BBF1EEC8585F4440CD5B751DAA114840
75362	2	23	855	56757	55904	\N	48.540626923468103	Ростовская область, Белокалитвинский район, х. Ильинка, Школьная, 1	Россия, Ростовская область, Белокалитвенский район, хутор Ильинка	0101000020E61000002B31CF4A5A8B4440D42AFA4333454840
75379	2	23	855	56924	56458	\N	48.562527000000003	Ростовская область, Белокалитвинский район, х. Западный, Садовая, 48		0101000020E610000057B1F84D61954440FA0E7EE200484840
77639	2	23	855	56815	56127	\N	48.1493681588722	Ростовская область, Белокалитвинский район, х. Дороговский, Терновой, 4	Россия, Ростовская область, Белокалитвенский район, хутор Дороговский	0101000020E610000037C5E3A25A6A4440D388997D1E134840
75364	2	23	855	57012	56560	\N	48.4603028862347	Ростовская область, Белокалитвинский район, х. Гусынка, Центральная, 28	Россия, Ростовская область, Белокалитвенский район, хутор Гусынка	0101000020E6100000ED461FF30185444017A06D35EB3A4840
75380	2	23	855	56767	55915	\N	47.921900000000001	Ростовская область, Белокалитвинский район, х. Грушевка, Центральная, 19А	Россия, Ростовская область, Белокалитвенский район, хутор Грушевка	0101000020E610000012BF620D175544405917B7D100F64740
75258	2	23	855	7246	41000	\N	48.290543	Ростовская область, Белокалитвинский район, п. Горняцкий, Театральная, 1		0101000020E61000001B9B1DA9BE794440768A558330254840
75256	2	23	855	7246	40376	\N	48.290543	Ростовская область, Белокалитвинский район, п. Горняцкий, Майская, 26		0101000020E61000001B9B1DA9BE794440768A558330254840
75257	2	23	855	7246	39891	\N	48.290543	Ростовская область, Белокалитвинский район, п. Горняцкий, Дзержинского, 19А		0101000020E61000001B9B1DA9BE794440768A558330254840
75382	2	23	855	56704	55846	\N	47.867421227419399	Ростовская область, Белокалитвинский район, х. Голубинка, Центральная, 16	Россия, Ростовская область, Белокалитвенский район, хутор Голубинка	0101000020E6100000B6A1629CBF6344408B6EBDA607EF4740
75363	2	23	855	56999	56547	\N	48.489752516198898	Ростовская область, Белокалитвинский район, х. Головка, Школьная, 16	Россия, Ростовская область, Белокалитвенский район, село Головка	0101000020E6100000C2F7FE06ED834440170FEF39B03E4840
75239	2	23	855	6396	55501	\N	47.995863	Ростовская область, Белокалитвинский район, п. Виноградный, Матросова, 26		0101000020E6100000CD3AE3FBE2744440F225547078FF4740
75384	2	23	855	56636	55434	\N	48.149549781448002	Ростовская область, Белокалитвинский район, х. Богураев, Центральная, 66	Россия, Ростовская область, Белокалитвенский район, хутор Богураев	0101000020E61000003B8908FF225A4440F38E537424134840
75383	2	23	855	56636	55284	\N	48.148688218336403	Ростовская область, Белокалитвинский район, х. Богураев, Заречная, 1	Россия, Ростовская область, Белокалитвенский район, хутор Богураев	0101000020E6100000AC014A438D5A444061A7583508134840
75377	2	23	855	56822	56205	\N	48.097113999999998	Ростовская область, Белокалитвинский район, х. Богатов, Станкевского, 21	Россия, Ростовская область, Белокалитвенский район, хутор Богатов	0101000020E61000009604A8A965654440EBFD463B6E0C4840
75374	2	23	855	56750	55897	\N	48.141250012732698	Ростовская область, Белокалитвинский район, х. Апанасовка, Шоссейная, 29	Россия, Ростовская область, Белокалитвенский район, хутор Апанасовка	0101000020E61000000D1CD0D2158C4440AE47E17A14124840
75348	2	23	1141	11522	56069	\N	47.141992999999999	Ростовская область, Багаевский район, п.Ясный, Центральная, 4		0101000020E61000006EA46C91B413444066A19DD32C924740
75335	2	23	1141	56691	\N	\N	47.2575098483236	Ростовская область, Багаевский район, Багаевское сельское поселение, х.Федулов, Федуловская СОШ	Россия, Ростовская область, Багаевский район, хутор Федулов	0101000020E61000008C9FC6BDF93B44404D327216F6A04740
75351	2	23	1141	56667	55512	\N	47.152369	Ростовская область, Багаевский район, х.Усьман, Братская, 50	Россия, Ростовская область, Багаевский район, хутор Усьман	0101000020E61000003EEB1A2D072644404DF6CFD380934740
75357	2	23	1141	56987	56533	\N	47.204957999999998	Ростовская область, Багаевский район, х.Тузлуков, Береговая, 9А	Россия, Ростовская область, Багаевский район, хутор Тузлуков	0101000020E61000005A63D009A13B4440DB8651103C9A4740
75353	2	23	1141	11838	55627	\N	47.146602000000001	Ростовская область, Багаевский район, п.Садовый, ул. Гагарина, 5		0101000020E61000005FB69DB6463244409CC3B5DAC3924740
75346	2	23	1141	56857	56383	\N	47.183956787718799	Ростовская область, Багаевский район, х.Пустошкин, Ленина, 35	Россия, Ростовская область, Багаевский район, хутор Пустошкин	0101000020E61000003BC269C18B204440656F29E78B974740
75341	2	23	1141	11224	55745	\N	47.333392000000003	Ростовская область, Багаевский район, п.Привольный, ул. Школьная, 1		0101000020E6100000A69C2FF65E564440C05FCC96ACAA4740
75350	2	23	1141	11690	55742	\N	47.214703	Ростовская область, Багаевский район, п.Первомайский, Школьная, 42		0101000020E610000035F0A31AF625444032AD4D637B9B4740
75354	2	23	1141	11893	55736	\N	47.126060000000003	Ростовская область, Багаевский район, п.Отрадный, Первомайская, 7А		0101000020E6100000F9D687F5463B4440B9AAECBB22904740
75344	2	23	1141	10808	55624	\N	47.228454999999997	Ростовская область, Багаевский район, ст.Манычская, Почтовая, 14		0101000020E61000005F61C1FD801F4440C8CD70033E9D4740
75331	2	23	1141	10808	56057	\N	47.228454999999997	Ростовская область, Багаевский район, ст.Манычская, Поповкина, 2		0101000020E61000005F61C1FD801F4440C8CD70033E9D4740
75343	2	23	1141	56710	55853	\N	47.329145804405897	Ростовская область, Багаевский район, х.Кудинов, Школьная, 94	Россия, Ростовская область, Багаевский район, хутор Кудинов	0101000020E61000006EDE3829CC454440FBCDC47421AA4740
75349	2	23	1141	56649	55321	\N	47.202233174305903	Ростовская область, Багаевский район, х.Красный, Центральная, 18		0101000020E61000007808E3A7712D444003965CC5E2994740
75339	2	23	1141	56949	56489	\N	47.404716000000001	Ростовская область, Багаевский район, х.Карповка, Зеленая, 13	Россия, Ростовская область, Багаевский район, хутор Карповка	0101000020E6100000E3A9471ADC4A44407F15E0BBCDB34740
75337	2	23	1141	11091	\N	\N	47.318080000000002	Ростовская область, Багаевский район, Багаевское сельское поселение, п.Задонский, Дом культуры		0101000020E61000007F315BB22A2844407FC16ED8B6A84740
75342	2	23	1141	56639	55292	\N	47.312733999999999	Ростовская область, Багаевский район, х.Елкин, Советская, 8	Россия, Ростовская область, Багаевский район, хутор Елкин	0101000020E61000005ABA826DC43F4440732CEFAA07A84740
75336	2	23	1141	11036	56068	\N	47.251506999999997	Ростовская область, Багаевский район, Багаевское сельское поселение, п.Дачный, Центральная, 1		0101000020E61000006840BD193539444087DBA16131A04740
75334	2	23	1141	56754	55901	\N	47.297074000000002	Ростовская область, Багаевский район, Багаевское сельское поселение, х.Белянин, Октябрьская, 24		0101000020E6100000C38366D7BD2B4440F73E558506A64740
75332	2	23	1141	10661	39646	\N	47.316704999999999	Ростовская область, Багаевский район, Багаевское сельское поселение, ст.Багаевская, ул.Фрунзе, 69А		0101000020E6100000CB2E185C7331444066BD18CA89A84740
75333	2	23	1141	10661	39903	\N	47.316704999999999	Ростовская область, Багаевский район, Багаевское сельское поселение, ст.Багаевская, Спартака, 106		0101000020E6100000CB2E185C7331444066BD18CA89A84740
75329	2	23	1141	10661	41019	\N	47.316704999999999	Ростовская область, Багаевский район, Багаевское сельское поселение, ст. Багаевская, Красноармейская, 1		0101000020E6100000CB2E185C7331444066BD18CA89A84740
75330	2	23	1141	10661	41020	\N	47.316704999999999	Ростовская область, Багаевский район, Багаевское сельское поселение, ст.Багаевская, Ермаковский, 83		0101000020E6100000CB2E185C7331444066BD18CA89A84740
75345	2	23	1141	56642	55297	\N	47.228914000000003	Ростовская область, Багаевский район, х.Арпачин, Советская, 42	Россия, Ростовская область, Багаевский район, хутор Арпачин	0101000020E6100000C7A01342071744405CCCCF0D4D9D4740
75338	2	23	1141	56692	55747	\N	47.367732031560799	Ростовская область, Багаевский район, х.Ажинов, Заярного, 6	Россия, Ростовская область, Багаевский район, хутор Ажинов	0101000020E6100000AA0CE36E10494440A9D898D711AF4740
76765	2	23	88	16304	55959	\N	47.440412000000002	Ростовская область,Аксайский район,п.Элитный, Центральная, 13		0101000020E6100000A35698BED7DC43400B62A06B5FB84740
76762	2	23	88	16101	55490	\N	47.380052999999997	Ростовская область,Аксайский район,п.Щепкин, Строителей, 36А		0101000020E61000004C530438BDE5434093DFA293A5B04740
76771	2	23	88	56716	55859	\N	47.1933024287449	Ростовская область,Аксайский район,х.Черюмкин, Центральная, 67/3	Россия, Ростовская область, Аксайский район, хутор Черюмкин	0101000020E6100000DFE00B93A90C44402E20B41EBE984740
77764	2	23	88	56803	56023	\N	47.339210836857703	Ростовская область,Аксайский район,п.Темерницкий, Парковый, 18	Россия, Ростовская область, Аксайский район	0101000020E6100000D6E253008CDD4340C3B81B446BAB4740
77711	2	23	88	30087	55248	\N	47.350469970655503	Ростовская область,Аксайский район,п.Степной, Центральная, 7	Россия, Ростовская область, Аксайский район, поселок Степной	0101000020E610000014CD0358E4EF4340541D7233DCAC4740
76782	2	23	88	17146	40302	\N	47.252302	Ростовская область,Аксайский район,ст.Старочеркасская, Гагарина, 1		0101000020E610000017BB7D5699054440925B936E4BA04740
76773	2	23	88	56805	56049	\N	47.141860380947797	Ростовская область,Аксайский район,х.Слава Труда, Славянская, 19	Россия, Ростовская область, Аксайский район, хутор Слава Труда	0101000020E610000035F10EF0A4094440274EEE7728924740
76784	2	23	88	17255	55972	\N	47.233826999999998	Ростовская область,Аксайский район,п.Рыбацкий, Береговая, 29		0101000020E61000006C04E275FD024440FDF50A0BEE9D4740
76750	2	23	88	15572	55693	\N	47.291016999999997	Ростовская область,Аксайский район,п.Российский, Молодежная, 7а		0101000020E61000009B92ACC3D1F143403ECA880B40A54740
76748	2	23	88	15484	39997	\N	47.304712000000002	Ростовская область,Аксайский район,п.Реконструктор, Гагарина, 1а		0101000020E6100000C7D5C8AEB4F84340715985CD00A74740
76757	2	23	88	15843	40141	\N	47.361153000000002	Ростовская область,Аксайский район,п.Рассвет, Экспериментальная, 66 б		0101000020E6100000EC134031B2F0434018EDF1423AAE4740
76756	2	23	88	15843	40670	\N	47.361153000000002	Ростовская область,Аксайский район,п.Рассвет, Комсомольская, 47		0101000020E6100000EC134031B2F0434018EDF1423AAE4740
76747	2	23	88	56979	56527	\N	47.300149190309298	Ростовская область,Аксайский район,х.Пчеловодный,адрес помещения для голосования:Пионерский,2а, адрес УИК:Подтелкова, 88		0101000020E6100000AE9B525E2BFB4340AB764D486BA64740
76775	2	23	88	56720	55863	\N	47.113692999999998	Ростовская область,Аксайский район,х.Островского, Кирова, 21 б	Россия, Ростовская область, Аксайский район, хутор Островского	0101000020E61000008675E3DD91F743405E64027E8D8E4740
76755	2	23	88	15790	56103	\N	47.318575000000003	Ростовская область,Аксайский район,п.Опытный, Центральная, 33		0101000020E6100000F2B391EBA6FC43405F29CB10C7A84740
76779	2	23	88	16940	41269	\N	47.187305000000002	Ростовская область,Аксайский район,ст.Ольгинская, Ленина, 78		0101000020E610000079E57ADB4CF943404BB0389CF9974740
76778	2	23	88	16940	40143	\N	47.187305000000002	Ростовская область,Аксайский район,ст.Ольгинская, 5-ый, 1		0101000020E610000079E57ADB4CF943404BB0389CF9974740
76760	2	23	88	16018	40301	\N	47.399258000000003	Ростовская область,Аксайский район,п.Октябрьский, Советская, 36		0101000020E6100000BC95253ACBEA43404C55DAE21AB34740
76780	2	23	88	56742	55889	\N	47.193801999999998	Ростовская область,Аксайский район,х.Нижнеподпольный, Центральная, 53		0101000020E61000002827DA55480144401FF30181CE984740
77763	2	23	88	105	39731	\N	47.3628821401431	Ростовская область,Аксайский район,ст.Мишкинская, Просвещения, 30а	Россия, Ростовская область, Аксайский район, станица Мишкинская	0101000020E61000009AD024B1A40644404E27D9EA72AE4740
76751	2	23	88	105	39731	\N	47.361916000000001	Ростовская область,Аксайский район,ст.Мишкинская, Просвещения, 58		0101000020E61000005A65A6B4FE06444017F3734353AE4740
76753	2	23	88	56897	56427	\N	47.382403537818597	Ростовская область,Аксайский район,х.Малый Мишкин, Восточная, 13а	Россия, Ростовская область, Аксайский район, хутор Малый Мишкин	0101000020E610000034D6FECEF608444007EE409DF2B04740
76781	2	23	88	14534	40002	\N	47.115438742034399	Ростовская область,Аксайский район,х.Ленина,адрес помещения для голосования:Онучкина,22, адрес УИК:Онучкина, 37	Россия, Ростовская область, Аксайский район, хутор Ленина	0101000020E6100000357BA01518EE43406BD784B4C68E4740
76758	2	23	88	15954	55694	\N	47.402265	Ростовская область,Аксайский район,п.Красный Колос, Зеленая, 13		0101000020E610000099B7EA3A54F94340A8A9656B7DB34740
76763	2	23	88	16177	55580	\N	47.389839000000002	Ростовская область,Аксайский район,п.Красный, Толстого, 13а		0101000020E610000015CAC2D7D7F0434049DA8D3EE6B14740
76783	2	23	88	56929	56464	\N	47.289703000000003	Ростовская область,Аксайский район,х.Краснодворск, Центральная, 38	Россия, Ростовская область, Аксайский район, хутор Краснодворск	0101000020E610000027F8A6E9B3094440CC46E7FC14A54740
76759	2	23	88	16006	40142	\N	47.339956999999998	Ростовская область,Аксайский район,п.Ковалевка, Центральная, 28		0101000020E610000031D28BDAFDEA4340EC8502B683AB4740
76752	2	23	88	56862	56389	\N	47.387767947808598	Ростовская область,Аксайский район,х.Киров, 50-лет Октября, 92а	Россия, Ростовская область, Аксайский район, хутор Киров	0101000020E6100000C6C1A563CE014440B937BF61A2B14740
76768	2	23	88	56903	56437	\N	47.439053000000001	Ростовская область,Аксайский район,х.Камышеваха, Подтелкова, 30		0101000020E6100000A400513063F24340F81A82E332B84740
76776	2	23	88	56695	55785	\N	47.078642124978202	Ростовская область,Аксайский район,х.Истомино, Истомина, 67		0101000020E610000002F1BA7EC1EE4340C80BE9F0108A4740
76777	2	23	88	16916	55781	\N	47.135005	Ростовская область,Аксайский район,п.Дорожный, Центральная, 25а		0101000020E610000077103B53E8F04340F3E505D847914740
76774	2	23	88	16770	55784	\N	47.134784000000003	Ростовская область,Аксайский район,п.Дивный, Ленина, 14		0101000020E6100000DEAE97A6080044401503249A40914740
14036	1	17	\N	3130	22576	\N	58.045848999999997	г.Рыбинск, Солнечная, 7		0101000020E6100000B3614D65516C4340F3C64961DE054D40
76767	2	23	88	13066	41265	\N	47.438541000000001	Ростовская область,Аксайский район,ст.Грушевская, Школьная, 25		0101000020E610000086AE44A0FAFD4340427A8A1C22B84740
77357	2	23	88	13066	55679	\N	47.438541000000001	Ростовская область,Аксайский район,ст.Грушевская, Советская, 265 а		0101000020E610000086AE44A0FAFD4340427A8A1C22B84740
76769	2	23	88	13066	55679	\N	47.438541000000001	Ростовская область,Аксайский район,ст.Грушевская, Советская, 35		0101000020E610000086AE44A0FAFD4340427A8A1C22B84740
76766	2	23	88	13066	55679	\N	47.439434963562299	Ростовская область,Аксайский район,ст.Грушевская, Советская, 191	Россия, Ростовская область, Аксайский район, станица Грушевская	0101000020E6100000D7BE805EB8FD4340E0DBF4673FB84740
76764	2	23	88	16238	55957	\N	47.428947000000001	Ростовская область,Аксайский район,п.Возрожденный, Школьная, 14		0101000020E6100000344C6DA983E04340D15B3CBCE7B64740
76749	2	23	88	15519	55196	\N	47.305056447373801	Ростовская область,Аксайский район,п.Водопадный, Совхозная, 5	Россия, Ростовская область, Аксайский район, поселок Водопадный	0101000020E610000082E49D4319EA43406BB933130CA74740
76770	2	23	88	56651	55326	\N	47.189461132896803	Ростовская область,Аксайский район,х.Верхнеподпольный, Школьная, 1	Россия, Ростовская область, Аксайский район, хутор Верхнеподпольный	0101000020E6100000D55A988576084440096F0F4240984740
76746	2	23	88	56650	55325	\N	47.305648014911803	Ростовская область,Аксайский район,х.Большой Лог, Советская, 73		0101000020E6100000FDDB65BFEEF443403D0B42791FA74740
76745	2	23	88	56650	55325	\N	47.308041583328801	Ростовская область,Аксайский район,х.Большой Лог, Советская, 36а	Россия, Ростовская область, Аксайский район, хутор Большой Лог	0101000020E610000017B7D100DEF44340B0E595EB6DA74740
77647	2	23	88	56855	56381	\N	47.303604638514102	Ростовская область,Аксайский район,х.Большой Лог, Фадеева, 293	Россия, Ростовская область, Аксайский район, хутор Большой Лог	0101000020E6100000C556D0B4C4F4434077F35487DCA64740
76772	2	23	88	57022	56573	\N	47.229456429418299	Ростовская область,Аксайский район,х.Алитуб, Луговая, 1	Россия, Ростовская область, Аксайский район, хутор Алитуб	0101000020E61000007C6308008E0D44407CEF6FD05E9D4740
76754	2	23	88	56628	55272	\N	47.325948495104399	Ростовская область,Аксайский район,х.Александровка, Студенческая, 43	Россия, Ростовская область, Аксайский район, хутор Александровка	0101000020E6100000E1D40792770044402A1900AAB8A94740
76741	2	23	88	54816	40140	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Чапаева, 299		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76740	2	23	88	54816	40140	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Чапаева, 163		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76735	2	23	88	54816	40665	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Толпинского, 114		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
77698	2	23	88	54816	40300	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Садовая, 14а		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
77648	2	23	88	54816	40300	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Садовая, 20		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76732	2	23	88	54816	39721	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Мира, 1А		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76730	2	23	88	54816	39721	\N	47.264581999999997	Ростовская область,Аксайский район,г. Аксай, Мира, 7		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76734	2	23	88	54816	41199	\N	47.258318338494803	Ростовская область,Аксайский район,г.Аксай, Маяковского, 13	Россия, Ростовская область, Аксай	0101000020E61000002E5393E00DEF4340ECFB709010A14740
76733	2	23	88	54816	40139	\N	47.262700221278699	Ростовская область,Аксайский район,г.Аксай, Ленина, 17	Россия, Ростовская область, Аксай	0101000020E6100000F4A44C6A68EF434061545227A0A14740
76729	2	23	88	54816	40139	\N	47.255220808784699	Ростовская область,Аксайский район,г. Аксай, Ленина, 39	Россия, Ростовская область, Аксай	0101000020E6100000601E32E543EE43404F20EC14ABA04740
77333	2	23	88	54816	40838	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Кирова, 31		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76737	2	23	88	54816	40667	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Гулаева, 129		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76736	2	23	88	54816	40667	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Гулаева, 89		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76143	2	23	88	54816	41148	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Вартанова, 25		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76814	2	23	88	54816	40004	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Буденного, 136		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
76738	2	23	88	54816	41262	\N	47.264581999999997	Ростовская область,Аксайский район,г.Аксай, Бондарчука, 18		0101000020E6100000BC5B59A2B3F043401D8EAED2DDA14740
77215	2	23	779	6344	56387	\N	46.656477867445403	Ростовская область, Азовский район, п.Южный, ул.Гагарина, 40	Россия, Ростовская область, Азовский район, поселок Южный	0101000020E6100000CC96AC8A707D434091459A7807544740
77246	2	23	779	56856	56382	\N	46.952945321314701	Ростовская область, Азовский район, х.Чумбур-Коса, ул.Центральная, 39-Б	Россия, Ростовская область, Азовский район, хутор Чумбур-Коса	0101000020E610000003931B45D674434080F10C1AFA794740
77205	2	23	779	56955	56495	\N	46.751882999999999	Ростовская область, Азовский район, х.Христичево, ул. Школьная, 38	Россия, Ростовская область, Азовский район, хутор Христичево	0101000020E6100000B4722F302B8643408DB5BFB33D604740
77237	2	23	779	56957	56497	\N	46.797547000000002	Ростовская область, Азовский район, х.Харьковский, ул.Центральная, 85	Россия, Ростовская область, Азовский район, хутор Харьковский	0101000020E6100000246420CF2E9D4340EF02250516664740
46848	2	20	\N	50675	23346	\N	45.034534000000001	х. Семёновкский, Буденного, 1-А, телефон: 74-8-03		0101000020E6100000850662D9CC7D4340CF4C309C6B844640
77213	2	23	779	56881	56409	\N	47.139592166685702	Ростовская область, Азовский район, х.Усть-Койсуг, ул.Степная, 83	Россия, Ростовская область, Азовский район, хутор Усть-Койсуг	0101000020E61000002383DC4598C8434041649126DE914740
77260	2	23	779	56799	55979	\N	47.117970958818098	Ростовская область, Азовский район, х.Узяк, ул.Платова, 90	Россия, Ростовская область, Азовский район, хутор Узяк	0101000020E6100000E371512D22AC43402E7079AC198F4740
77242	2	23	779	7635	56355	\N	47.053271000000002	Ростовская область, Азовский район, п.Тимирязевский, ул.Кольцевая, 5		0101000020E61000009770E82D1ECE4340A1698995D1864740
77271	2	23	779	9054	55507	\N	47.003106000000002	Ростовская область, Азовский район, п.Суходольск, ул.Зеленая, 40		0101000020E6100000F48B12F417DA4340F03504C765804740
77232	2	23	779	7223	41367	\N	47.028388	Ростовская область, Азовский район, с.Стефанидинодар, ул.Мира, 45		0101000020E61000002E76FBAC32974340A7CCCD37A2834740
77595	2	23	779	56911	56444	\N	46.814472000000002	Ростовская область, Азовский район, х.Степнянский, ул.Социалистическая, 19-А	Россия, Ростовская область, Азовский район, хутор Степнянский	0101000020E61000006C04E275FDD64340FDC0559E40684740
77596	2	23	779	24839	56134	\N	46.870558000000003	Ростовская область, Азовский район, п.Солнечный, ул.Школьная, 5		0101000020E610000004CB113290B94340B6A2CD716E6F4740
77254	2	23	779	8263	56252	\N	46.623097999999999	Ростовская область, Азовский район, с.Советский Дар, пер.Береговой, 1-1		0101000020E6100000787AA52C43944340FC19DEACC14F4740
77272	2	23	779	9057	40169	\N	47.006056000000001	Ростовская область, Азовский район, с.Семибалки, ул.Ленина, 14		0101000020E61000001553E9279C854340E8F86871C6804740
77265	2	23	779	8656	40320	\N	46.941217000000002	Ростовская область, Азовский район, с.Самарское, пер.Промышленный, 9		0101000020E6100000C8EF6DFAB3D7434039B874CC79784740
77263	2	23	779	8656	39802	\N	46.941217000000002	Ростовская область, Азовский район, с.Самарское, ул.Переездная, 68		0101000020E6100000C8EF6DFAB3D7434039B874CC79784740
77267	2	23	779	8656	40013	\N	46.941217000000002	Ростовская область, Азовский район, с.Самарское, ул.Московская, 51		0101000020E6100000C8EF6DFAB3D7434039B874CC79784740
77268	2	23	779	8656	40167	\N	46.941217000000002	Ростовская область, Азовский район, с.Самарское, ул.Мира, 1		0101000020E6100000C8EF6DFAB3D7434039B874CC79784740
77264	2	23	779	8656	40316	\N	46.941217000000002	Ростовская область, Азовский район, с.Самарское, ул.Ленина, 42		0101000020E6100000C8EF6DFAB3D7434039B874CC79784740
77262	2	23	779	56683	55705	\N	47.174964078107301	Ростовская область, Азовский район, х.Рогожкино, пер.Школьный, 29	Россия, Ростовская область, Азовский район, хутор Рогожкино	0101000020E610000011363CBD52AC43401AFD683865964740
77247	2	23	779	7899	56117	\N	46.859560000000002	Ростовская область, Азовский район, п.Приморский, ул.Центральная, 12		0101000020E610000047B071FDBB7643409279E40F066E4740
77248	2	23	779	7906	39933	\N	46.876854000000002	Ростовская область, Азовский район, с.Порт-Катон, ул.Социалистическая, 39		0101000020E6100000882B67EF8C604340F3AE7AC03C704740
77236	2	23	779	7373	56106	\N	46.811703000000001	Ростовская область, Азовский район, х.Полтава-2я, ул.Молодежная, 8		0101000020E6100000FE9E58A7CA954340558847E2E5674740
77234	2	23	779	7328	56339	\N	46.843936999999997	Ростовская область, Азовский район, х.Полтава-1я, ул.Южная, 5		0101000020E610000013286211C39C43403271AB20066C4740
77219	2	23	779	54868	40165	\N	46.938704430191301	Ростовская область, Азовский район, х.Победа, ул.Филипченко, 2-А	Россия, Ростовская область, Азовский район, хутор Победа	0101000020E6100000E998F38C7DD14340EC4FE27327784740
77251	2	23	779	8056	56370	\N	46.991132999999998	Ростовская область, Азовский район, с.Платоно-Петровка, ул.Калинина, 12-А		0101000020E6100000105839B4C8BC4340417E3672DD7E4740
77256	2	23	779	8323	40822	\N	47.018478999999999	Ростовская область, Азовский район, с.Пешково, пер.Октябрьский, 20		0101000020E6100000DBC2F352B1B14340D65416855D824740
77729	2	23	779	8323	55104	\N	47.018478999999999	Ростовская область, Азовский район, с.Пешково, пер.Октябрьский, 15-А		0101000020E6100000DBC2F352B1B14340D65416855D824740
77218	2	23	779	56761	55909	\N	46.957684971997701	Ростовская область, Азовский район, х.Песчаный, ул.Комсомольская, 4	Россия, Ростовская область, Азовский район, хутор Песчаный	0101000020E6100000209C4F1DABCC4340546F0D6C957A4740
77252	2	23	779	56743	55890	\N	47.021476999999997	Ростовская область, Азовский район, х.Павловка, пер.Ростовский, 8	Россия, Ростовская область, Азовский район, хутор Павловка	0101000020E6100000D4D347E00FB94340DF4E22C2BF824740
77273	2	23	779	56925	56459	\N	47.022557999999997	Ростовская область, Азовский район, х.Павло-Очаково, ул.Победы, 36	Россия, Ростовская область, Азовский район, хутор Павло-Очаково	0101000020E610000089096AF8168A4340AF21382EE3824740
77253	2	23	779	8206	55792	\N	46.663058999999997	Ростовская область, Азовский район, с.Отрадовка, ул.Курышко, 20-А		0101000020E6100000B45549641F8C4340C328081EDF544740
77255	2	23	779	8271	55703	\N	46.730027	Ростовская область, Азовский район, с.Орловка, ул.Победы, 23		0101000020E6100000723106D6719C434037195586715D4740
77243	2	23	779	7686	40820	\N	47.104596999999998	Ростовская область, Азовский район, п.Овощной, пер.Комсомольский, 6-А		0101000020E6100000853E58C686D243403E213B6F638D4740
77209	2	23	779	56622	55263	\N	47.160131999999997	Ростовская область, Азовский район, х.Обуховка, ул.Заводская, 38-В		0101000020E61000002AC93A1C5DB74340838593347F944740
77221	2	23	779	6694	41366	\N	46.903044999999999	Ростовская область, Азовский район, с.Новотроицкое, ул.Школьная, 12		0101000020E610000041F4A44C6AD643407DE882FA96734740
77261	2	23	779	8589	40315	\N	46.876255999999998	Ростовская область, Азовский район, п.Новополтавский, пер.Школьный, 21-А		0101000020E6100000DFC5FB71FB9143403E76172829704740
77269	2	23	779	8956	55702	\N	46.978273000000002	Ростовская область, Азовский район, с.Новониколаевка, пер.Школьный, 13		0101000020E610000006668522DDCD4340A8C7B60C387D4740
77229	2	23	779	7064	40314	\N	46.833846000000001	Ростовская область, Азовский район, п.Новомирский, ул.Московская, 5		0101000020E61000006A4B1DE4F5B4434041F33977BB6A4740
77249	2	23	779	7963	56372	\N	46.899751000000002	Ростовская область, Азовский район, с.Новомаргаритово, ул.Ленина, 14		0101000020E61000009DF2E846586A43408BC56F0A2B734740
77250	2	23	779	56626	55269	\N	47.078012161560103	Ростовская область, Азовский район, х.Новоалександровка, ул.Ленина, 88-А	Россия, Ростовская область, Азовский район, хутор Новоалександровка	0101000020E61000002A37514B73C143400859164CFC894740
77203	2	23	779	5729	55976	\N	46.844059999999999	Ростовская область, Азовский район, х.Нижняя Козинка, ул.Мира, 40-А		0101000020E61000000EBBEF181E7B43404EEE77280A6C4740
77245	2	23	779	7765	55590	\N	46.928854999999999	Ростовская область, Азовский район, с.Маргаритово, ул.Луговая, 8		0101000020E6100000560DC2DCEE6F4340F0DC7BB8E4764740
77207	2	23	779	5961	56105	\N	46.756920999999998	Ростовская область, Азовский район, п.Ленинский Лесхоз, пл.Домошевского, 5		0101000020E61000008C15359886914340EB538EC9E2604740
77593	2	23	779	56932	56467	\N	46.956018	Ростовская область, Азовский район, х.Левобережный, ул.Школьная, 1	Россия, Ростовская область, Азовский район, хутор Левобережный	0101000020E61000007EE4D6A4DBD0434094313ECC5E7A4740
77240	2	23	779	7498	40166	\N	47.078904000000001	Ростовская область, Азовский район, с.Кулешовка, пл.Гагарина, 1		0101000020E610000008E753C72AC7434005C3B986198A4740
77241	2	23	779	7498	41371	\N	47.078904000000001	Ростовская область, Азовский район, с.Кулешовка, ул.Первомайская, 30		0101000020E610000008E753C72AC7434005C3B986198A4740
77669	2	23	779	7498	40196	\N	47.078904000000001	Ростовская область, Азовский район, с.Кулешовка, ул.Матросова, 16		0101000020E610000008E753C72AC7434005C3B986198A4740
77238	2	23	779	7498	39801	\N	47.078904000000001	Ростовская область, Азовский район, с.Кулешовка, ул.Ленина, 299		0101000020E610000008E753C72AC7434005C3B986198A4740
77239	2	23	779	7498	40817	\N	47.078904000000001	Ростовская область, Азовский район, с.Кулешовка, ул.Кулагина, 4-А		0101000020E610000008E753C72AC7434005C3B986198A4740
77233	2	23	779	7225	39795	\N	46.881774999999998	Ростовская область, Азовский район, с.Кугей, ул.Ленина, 50		0101000020E6100000F03499F1B6A8434017B7D100DE704740
77231	2	23	779	7138	40814	\N	47.015296999999997	Ростовская область, Азовский район, с.Круглое, ул.Мира, 79		0101000020E6100000EFC7ED974F9E43400B5D8940F5814740
77244	2	23	779	56631	55275	\N	47.1013689300772	Ростовская область, Азовский район, п.Красный Сад, ул.Заводская, 15	Россия, Ростовская область, Азовский район, поселок Красный Сад	0101000020E6100000D449B6BA9CDC434003EACDA8F98C4740
77270	2	23	779	56711	55854	\N	46.973401353563197	Ростовская область, Азовский район, х.Кочеванчик, ул.Луговая, 71	Россия, Ростовская область, Азовский район, хутор Кочеванчик	0101000020E610000040FA264D83D2434065726A67987C4740
77211	2	23	779	56708	55850	\N	47.154378999999999	Ростовская область, Азовский район, х.Колузаево, ул.Ленина, 68-А	Россия, Ростовская область, Азовский район, хутор Колузаево	0101000020E6100000C382FB010FC643403718EAB0C2934740
77222	2	23	779	6748	55685	\N	46.878892999999998	Ростовская область, Азовский район, п.Каяльский, ул.Ленина, 44		0101000020E61000008CD651D504D7434077D7D9907F704740
77598	2	23	779	57004	56552	\N	46.840731717134297	Ростовская область, Азовский район, х.Калиновка, ул.Октябрьская, 39	Россия, Ростовская область, Азовский район, хутор Калиновка	0101000020E6100000299831056BBC4340B0592E1B9D6B4740
77223	2	23	779	6753	40774	\N	47.077007000000002	Ростовская область, Азовский район, с.Кагальник, ул.Тельмана, 4-Б		0101000020E6100000F8C5A52A6DA943401348895DDB894740
77224	2	23	779	6753	40777	\N	47.077007000000002	Ростовская область, Азовский район, с.Кагальник, ул.Советская, 59		0101000020E6100000F8C5A52A6DA943401348895DDB894740
77225	2	23	779	6753	40778	\N	47.077007000000002	Ростовская область, Азовский район, с.Кагальник, ул.Ленина, 33-А		0101000020E6100000F8C5A52A6DA943401348895DDB894740
77226	2	23	779	6753	39793	\N	47.077007000000002	Ростовская область, Азовский район, с.Кагальник, ул.Волгодонская, 9		0101000020E6100000F8C5A52A6DA943401348895DDB894740
77755	2	23	779	32246	56136	\N	47.050158000000003	Ростовская область, Азовский район, п.Зеленый, ул.Центральная, 17		0101000020E61000002713B70A62B04340FFD0CC936B864740
77258	2	23	779	8435	40826	\N	47.019302000000003	Ростовская область, Азовский район, с.Займо-Обрыв, пер.Октябрьский, 12		0101000020E61000000953944BE3A74340AB5FE97C78824740
77220	2	23	779	56714	55857	\N	46.928986934380902	Ростовская область, Азовский район, х.Задонский, ул.Ленина, 28-А	Россия, Ростовская область, Азовский район, хутор Задонский	0101000020E6100000F0DC7BB8E4D443405FB4C70BE9764740
77217	2	23	779	56851	56369	\N	46.965232738531903	Ростовская область, Азовский район, х.Еремеевка, ул.Ворошиловская, 72-А	Россия, Ростовская область, Азовский район, хутор Еремеевка	0101000020E61000005F79909E22C743408E0244C18C7B4740
77594	2	23	779	56879	56407	\N	46.869277958268299	Ростовская область, Азовский район, х.Ельбузд, ул.Юбилейная, 1-Б	Россия, Ростовская область, Азовский район, хутор Ельбузд	0101000020E610000037001B1021DC4340EF906280446F4740
77214	2	23	779	6286	32957	\N	46.660466999999997	Ростовская область, Азовский район, с.Елизаветовка, ул.Дзержинского, 35		0101000020E610000022365838497343402A8BC22E8A544740
77208	2	23	779	5970	56119	\N	47.135508000000002	Ростовская область, Азовский район, ст.Елизаветинская, пл.Павших Борцов, 1		0101000020E6100000D9E89C9FE2BC4340562C7E5358914740
77210	2	23	779	56986	56529	\N	47.164078000000003	Ростовская область, Азовский район, х.Дугино, ул.Свердлова, 12-Б	Россия, Ростовская область, Азовский район, хутор Дугино	0101000020E61000008D7DC9C683B543401EFF058200954740
77227	2	23	779	56860	56386	\N	47.123954509884598	Ростовская область, Азовский район, х.Донской, ул.Бакланова, 79	Россия, Ростовская область, Азовский район, хутор Донской	0101000020E61000000EF450DB86A943407D96E7C1DD8F4740
77230	2	23	779	7074	55484	\N	46.826559000000003	Ростовская область, Азовский район, х.Гусарева Балка, ул.Кирова, 29		0101000020E61000009BE61DA7E8C44340749B70AFCC694740
77599	2	23	779	56878	56406	\N	46.662396999999999	Ростовская область, Азовский район, х.Григорьевка, ул.Центральная, 14-А	Россия, Ростовская область, Азовский район, хутор Григорьевка	0101000020E61000007D3F355EBA874340F8FBC56CC9544740
77257	2	23	779	8374	41208	\N	47.020144000000002	Ростовская область, Азовский район, с.Головатовка, пер.Октябрьский, 26		0101000020E61000005E81E84999AC4340F69A1E1494824740
77235	2	23	779	7367	55482	\N	47.000309999999999	Ростовская область, Азовский район, с.Высочино, ул.Горького, 33		0101000020E61000002A1900AAB8C743404EEE77280A804740
77216	2	23	779	6390	56368	\N	46.967610999999998	Ростовская область, Азовский район, с.Васильево Петровское, ул.Азовская, 35		0101000020E6100000B403AE2B66C04340FB1F60ADDA7B4740
77591	2	23	779	24585	32955	\N	46.929648999999998	Ростовская область, Азовский район, п.Васильево Петровский, Строителей улица, 2		0101000020E6100000466117450FBC43402AE109BDFE764740
77597	2	23	779	56983	56532	\N	46.815512383228899	Ростовская область, Азовский район, х.Бурхановка, ул.Октябрьская, 18-Б	Россия, Ростовская область, Азовский район, хутор Бурхановка	0101000020E6100000E3DD91B1DAD043406EBF7CB262684740
77259	2	23	779	56876	56404	\N	47.043763906517199	Ростовская область, Азовский район, х.Береговой, ул.Ленина, 30	Россия, Ростовская область, Азовский район, хутор Береговой	0101000020E6100000CC26C0B0FCA94340FF5E0A0F9A854740
77201	2	23	779	5490	56256	\N	46.780794999999998	Ростовская область, Азовский район, с.Александровка, пер.Победы, 45		0101000020E6100000096B63EC847F4340AEF02E17F1634740
77199	2	23	779	5490	40162	\N	46.780794999999998	Ростовская область, Азовский район, с.Александровка, ул.Советская, 35		0101000020E6100000096B63EC847F4340AEF02E17F1634740
77200	2	23	779	5490	55701	\N	46.780794999999998	Ростовская область, Азовский район, с.Александровка, ул.Октябрьская, 22		0101000020E6100000096B63EC847F4340AEF02E17F1634740
77202	2	23	779	5490	55804	\N	46.780794999999998	Ростовская область, Азовский район, с.Александровка, ул.Калинина, 101		0101000020E6100000096B63EC847F4340AEF02E17F1634740
44958	2	20	\N	50720	23456	\N	43.801209	х. Журавлевка, Центральная, 102/А, телефон: 33073		0101000020E6100000B13385CE6BBA434064213A048EE64540
46867	2	20	\N	50389	21563	\N	45.160041999999997	ст. Ладожская, Коншиных, 113, телефон: 70-1-19		0101000020E61000000A9E42AED495434043FE99417C944640
46859	2	20	\N	50296	20882	\N	45.095078118533102	ст. Воронежская, Карпенко, 50, телефон: 37-1-45	Россия, Краснодарский край, Краснодар	0101000020E6100000B58993FB1DA44340D84812842B8C4640
46286	2	20	\N	50625	23059	\N	43.553431638842703	с.Галицино, Батайская, 43, телефон: 431094		0101000020E6100000A33D5E4887FD4340AA471ADCD6C64540
45916	2	20	\N	50475	\N	\N	45.160041999999997	пос.Грушовая балка, 16, телефон: 60-97-88		0101000020E61000000A9E42AED495434043FE99417C944640
46648	2	20	\N	50331	21120	\N	45.074534	п. Пригородный ул. Центральная 27		0101000020E61000001DCC26C0B0984340543882548A894640
44739	2	20	\N	50674	\N	\N	45.099098465039503	"жилой городок ""Лесная сказка"", здание средней школы №17 жилого городка ""Лесная сказка"", телефон: 5-94-39"		0101000020E6100000B1DB6795999C4340AC8C463EAF8C4640
45904	2	20	\N	50277	20689	\N	44.735809094139398	город Новороссийск, Сухумское шоссе, 5, телефон: 60-46-21	Россия, Краснодарский край, поселок Шесхарис, Сухумийское шоссе	0101000020E610000021AD31E884E642401E8D43FD2E5E4640
45903	2	20	\N	50277	20689	\N	44.727335314142202	город Новороссийск, Сухумское шоссе, 92, телефон: 28-12-58	Россия, Краснодарский край, поселок Шесхарис, Сухумийское шоссе	0101000020E61000003C6A4C88B9E842403A1E3350195D4640
45902	2	20	\N	50277	20689	\N	44.727212939932699	город Новороссийск, Сухумское шоссе, 11, телефон: 60-34-63		0101000020E610000002D369DD06E94240EF1CCA50155D4640
44735	2	20	\N	50332	21139	\N	44.700697841581302	станица Черноморская, Ленина, 25, телефон: 5-87-72		0101000020E610000035EECD6F98AE4340B22FD978B0594640
45941	2	20	\N	23618	6275	\N	44.752278434753102	город Новороссийск, с.Цемдолина, ул. Школьная, д. 33, телефон: 67-00-13	Россия, Краснодарский край, поселок Цемдолина, улица Школьная	0101000020E61000007C61325530DC424009C03FA54A604640
44389	2	20	\N	50490	22329	\N	44.425500999999997	г. Хадыженск, Ленина, 57, телефон: 71762		0101000020E61000002B1895D409C4434028B517D176364640
44725	2	20	\N	50327	21111	\N	44.514040916224403	село Фанагорийское, Подгорная, 14, телефон: 5-39-43	Россия, Краснодарский край, Горячий Ключ, поселок Фанагорийское	0101000020E6100000A8E15B58378E4340CDE67118CC414640
46843	2	20	\N	50459	22538	\N	45.218679000000002	г. Усть-Лабинск, Строительная, 11, телефон: 94-1-62		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46837	2	20	\N	50459	22056	\N	45.218679000000002	г. Усть-Лабинск, Площадь Революции, 15, телефон: 2-36-83		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46880	2	20	\N	50459	22337	\N	45.218679000000002	г. Усть-Лабинск, Пионерская, 251/А,		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46841	2	20	\N	50459	22408	\N	45.218679000000002	г. Усть-Лабинск, Коммунистическая, 63, телефон: 5-13-36		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46070	2	20	\N	50702	23424	\N	44.745086999999998	станица Украинская, Школьная, 14, телефон: 4-57-28		0101000020E610000084D4EDEC2BE342405ED6C4025F5F4640
45821	2	20	\N	100	7856	\N	44.098398000000003	х.Северокавказский, ул.Пушкина, 1, телефон: 2-41-09	Россия, Краснодарский край, Туапсе, улица Пушкина, 1	0101000020E6100000F44F70B1A28C4340F4FE3F4E980C4640
46789	2	20	\N	100	18	\N	44.109453738826303	Краснодарский край, Туапсинский район, город Туапсе, Новицкого, 17 А, телефон: 2-68-42	Россия, Краснодарский край, Туапсе, улица Новицкого	0101000020E6100000AF78EA91068B43404C35B396020E4640
46786	2	20	\N	100	8152	\N	44.098755022789298	Краснодарский край, Туапсинский район, город Туапсе, Коммунистическая, 1 (Школа искусств), телефон: 2-16-47	Россия, Краснодарский край, Туапсе, улица Коммунистическая	0101000020E6100000F7E80DF79189434082A8FB00A40C4640
46779	2	20	\N	100	8072	\N	44.098887909539997	Краснодарский край, Туапсинский район, город Туапсе, Горького, 40 (СОШ 4, корпус 2), телефон: 2-73-31	Россия, Краснодарский край, Туапсе, улица Горького	0101000020E6100000EA79371614884340C2FBAA5CA80C4640
46782	2	20	\N	100	21089	\N	44.0958194777714	Краснодарский край, Туапсинский район, город Туапсе, площадь Октябрьской Революции, 2 (ГДК, 2 этаж), телефон: 2-22-10	Россия, Краснодарский край, Туапсе, улица Карла Маркса	0101000020E61000007217618A72894340EFAA07CC430C4640
46781	2	20	\N	100	21089	\N	44.099530999999999	Краснодарский край, Туапсинский район, город Туапсе, площадь Октябрьской Революции, 2 (ГДК, 1 этаж), телефон: 2-22-09		0101000020E61000000E2C47C8408A434016F88A6EBD0C4640
46784	2	20	\N	100	23830	\N	44.101188	Краснодарский край, Туапсинский район, город Туапсе, Шаумяна, 7 (Центр детского творчества), телефон: 6-04-91		0101000020E61000001904560E2D8A4340B35F77BAF30C4640
46751	2	20	\N	100	23830	\N	44.092033999999998	с.Кроянское, Шаумяна, 4, телефон: 60565	Россия, Краснодарский край, Туапсе, Кроянское квартал	0101000020E6100000E7ABE463778F43405E0F26C5C70B4640
46776	2	20	\N	100	22890	\N	44.111032999999999	Краснодарский край, Туапсинский район, город Туапсе, Фрунзе, 67 (СОШ 2, левое крыло), телефон: 5-00-82		0101000020E61000007D224F92AE8743406DE34F54360E4640
46775	2	20	\N	100	22890	\N	44.111032999999999	Краснодарский край, Туапсинский район, город Туапсе, Фрунзе, 67 (СОШ 2, правое крыло), телефон: 5-02-90		0101000020E61000007D224F92AE8743406DE34F54360E4640
46777	2	20	\N	100	23588	\N	44.106078325607299	Краснодарский край, Туапсинский район, город Туапсе, Таманская, 12 (ТЮЗ), телефон: 5-00-83	Россия, Краснодарский край, Туапсе, улица Таманская	0101000020E6100000A530EF71A68743409C69C2F6930D4640
46800	2	20	\N	100	23827	\N	44.101182000000001	Краснодарский край, Туапсинский район, город Туапсе, Сочинская, 45 (СОШ 3), телефон: 2-68-33		0101000020E61000004DF564FED18B4340D1782288F30C4640
46793	2	20	\N	100	23827	\N	44.098326999999998	Краснодарский край, Туапсинский район, город Туапсе, Сочинская, 48 (ДКН, 2 этаж), телефон: 5-91-33		0101000020E610000095F0845E7F8C43402AA8A8FA950C4640
46792	2	20	\N	100	23827	\N	44.098326999999998	Краснодарский край, Туапсинский район, город Туапсе, Сочинская, 48 (ДКН, 1этаж), телефон: 5-91-34		0101000020E610000095F0845E7F8C43402AA8A8FA950C4640
46780	2	20	\N	100	23644	\N	44.097698999999999	Краснодарский край, Туапсинский район, город Туапсе, Полетаева, 10 (СОШ 7), телефон: 2-30-97		0101000020E6100000B9E177D32D8943400BED9C66810C4640
46783	2	20	\N	100	23765	\N	44.098430999999998	Краснодарский край, Туапсинский район, город Туапсе, Ленина, 1 (СОШ 6), телефон: 2-13-41		0101000020E61000008E7747C66A894340CFF41263990C4640
46787	2	20	\N	100	23711	\N	44.102767999999998	Краснодарский край, Туапсинский район, город Туапсе, Кондратьева, 5 (СОШ 5), телефон: 2-22-26		0101000020E61000006937FA980F8A4340A4897780270D4640
46791	2	20	\N	100	23764	\N	44.111609000000001	Краснодарский край, Туапсинский район, город Туапсе, Киевская, 1 (СОШ 10), телефон: 2-16-01		0101000020E6100000876EF607CA8B43403A782634490E4640
46799	2	20	\N	100	23714	\N	44.098987000000001	"Краснодарский край, Туапсинский район, город Туапсе, Карла Маркса, 17 (Кинотеатр ""Россия"", 1 этаж), телефон: 2-27-36"		0101000020E61000006E1805C1E389434055DD239BAB0C4640
46788	2	20	\N	100	23714	\N	44.101362930712	Краснодарский край, Туапсинский район, город Туапсе, Карла Маркса, 39 (Художественная школа), телефон: 2-76-93	Россия, Краснодарский край, Туапсе, улица Карла Маркса	0101000020E6100000D8F0F44A598A434021037976F90C4640
46750	2	20	\N	100	23450	\N	44.095062221312098	с.Кроянское, Камо, 1, телефон: 74743	Россия, Краснодарский край, Туапсе, улица Камо	0101000020E61000002043C70E2A8F4340D28BDAFD2A0C4640
46797	2	20	\N	100	23602	\N	44.128647999999998	Краснодарский край, Туапсинский район, город Туапсе, Калараша, 7а (СОШ 11, правое крыло), телефон: 5-87-63		0101000020E6100000E71890BDDE8943401059A48977104640
46774	2	20	\N	100	23602	\N	44.128647999999998	Краснодарский край, Туапсинский район, город Туапсе, Калараша, 7а (СОШ 11, левое крыло), телефон: 5-16-40		0101000020E6100000E71890BDDE8943401059A48977104640
46801	2	20	\N	100	23650	\N	44.090318000000003	"город Туапсе, Звездная, 49 МОУ СОШ №8"		0101000020E6100000CB4BFE277F8D4340BD1E4C8A8F0B4640
46795	2	20	\N	100	23650	\N	44.090060000000001	Краснодарский край, Туапсинский район, город Туапсе, Звездная, 25 (КубГТУ), телефон: 4-24-01		0101000020E610000037A5BC56428B4340C1560916870B4640
46794	2	20	\N	100	23650	\N	44.090318000000003	Краснодарский край, Туапсинский район, город Туапсе, Звездная, 49 (СОШ 8), телефон: 4-24-00		0101000020E6100000CB4BFE277F8D4340BD1E4C8A8F0B4640
46773	2	20	\N	100	23063	\N	44.118884000000001	"город Туапсе, Судоремонтников, 68 Социальный дом, (фойе 1 этажа) "	Россия, Краснодарский край, Туапсе, Дружбы переулок	0101000020E61000000282397AFC86434043024697370F4640
46778	2	20	\N	100	22870	\N	44.098970057562802	Краснодарский край, Туапсинский район, город Туапсе, Горького, 40 (СОШ 4, корпус 1), телефон: 2-58-94		0101000020E6100000E9D7D64FFF8743407FA4880CAB0C4640
46790	2	20	\N	100	23651	\N	44.110883999999999	Краснодарский край, Туапсинский район, город Туапсе, Б.Хмельницкого, 85 (филиал РГУПС), телефон: 3-67-00		0101000020E6100000452DCDAD108C434028D36872310E4640
46712	2	20	\N	50396	22051	\N	45.855417189124204	город Тихорецк, ул.Федосеева, 43, телефон: 7-08-36	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E61000003BE466B801114440A2B8E34D7EED4640
46706	2	20	\N	50396	22033	\N	45.848519743775903	город Тихорецк, ул.Парковая, 35, телефон: 5-64-01	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E6100000CA897615520E44403F00A94D9CEC4640
46701	2	20	\N	50396	21666	\N	45.849554415465597	город Тихорецк, ул.Красноармейская, 80, телефон: 2-08-62	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E6100000310A82C7B70F4440CE177B2FBEEC4640
46689	2	20	\N	50396	21666	\N	45.850661001909003	город Тихорецк, ул.Красноармейская, 32, телефон: 2-94-56		0101000020E6100000F0E0270EA00F4440C87DAB75E2EC4640
46692	2	20	\N	50396	21887	\N	45.8641727054382	город Тихорецк, ул.Калинина, 128, телефон: 5-11-65		0101000020E6100000BE839F3880124440098B8A389DEE4640
46696	2	20	\N	50512	22494	\N	45.862328765134102	город Тихорецк, ул.Меньшикова, 84, телефон: 2-81-74, 7-29-54	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E61000005AB91798150E44403AB2F2CB60EE4640
46589	2	20	\N	50425	22736	\N	45.616953965666802	город Тимашевск, Степанова, 54, телефон: 4-26-35	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000EB025E66D876434075914259F8CE4640
46610	2	20	\N	50425	22232	\N	45.603143980711103	город Тимашевск, Рабочая, 36, телефон: 5-55-57	Россия, Краснодарский край, Тимашевский район	0101000020E6100000B1C22D1F497F4340AA6395D233CD4640
46600	2	20	\N	50425	21750	\N	45.6147253229434	город Тимашевск, Пионерская, 92, телефон: 4-78-56	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E610000056B8E523297943404D840D4FAFCE4640
46594	2	20	\N	50425	22637	\N	45.6182188313362	город Тимашевск, Ленина, 176, телефон: 5-17-06	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000A5A2B1F6777843400762D9CC21CF4640
46597	2	20	\N	50425	22180	\N	45.611833977909697	город Тимашевск, Колхозная, 74, телефон: 5-91-52	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E61000004301DBC1887943405A4A969350CE4640
44587	2	20	\N	50589	22915	\N	44.902383999999998	хутор Терновый, улица Спортивная, 38, телефон: 67-5-41		0101000020E6100000732B84D558AC42408237A45181734640
46547	2	20	\N	50516	22536	\N	45.265749	г.Темрюк, 27 Сентября, 188/1, здание Дома культуры, телефон: 65-2-48		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
44733	2	20	\N	50259	20552	\N	44.764871999999997	станица Суздальская, Красная, 30, телефон: 3-28-34		0101000020E6100000AE49B72572AF434024D06053E7614640
45278	2	20	\N	50535	22666	\N	45.053595000000001	станица Старокорсунская, улица Шевченко, дом 222, телефон: 2348024		0101000020E61000009B012EC896A74340541D7233DC864640
45277	2	20	\N	50535	22837	\N	45.051965000000003	станица Старокорсунская, улица Красная, дом 60/1, телефон: 2348709		0101000020E6100000E10CFE7E31A74340B1C403CAA6864640
45276	2	20	\N	50535	22837	\N	45.051965000000003	станица Старокорсунская, улица Красная, дом 27/1, телефон: 2348255	Россия, Краснодарский край, Краснодар, деревня Старокорсунская, улица Закрытая	0101000020E6100000E10CFE7E31A74340B1C403CAA6864640
45809	2	20	\N	50727	23468	\N	44.615334890125602	Краснодарский край, Мостовский район, ст-ца Ярославская, Энгельса, 106, телефон: 6-31-53	Россия, Краснодарский край, М-29 шоссе	0101000020E610000026AAB706B63A4440C68A1A4CC34E4640
46311	2	20	\N	50262	\N	\N	43.685088	г. Сочи, Адлерский район, Село  Эсто-Садок,  Роза-Хутор		0101000020E61000007C48F8DEDF204440E770ADF6B0D74540
46309	2	20	\N	50262	\N	\N	43.582794999999997	г. Сочи, Адлерский район, Общество с ограниченной ответственностью «ТрансКомСтрой»		0101000020E6100000B3EC496073DC4340DBA2CC0699CA4540
46304	2	20	\N	50262	\N	\N	43.598792000000003	г. Сочи, Адлерский район, Село Кепша, Пикет № 276	Россия, Краснодарский край, Сочи	0101000020E61000002497FF907EDF4340A08D5C37A5CC4540
46300	2	20	\N	50262	\N	\N	43.598792000000003	г. Сочи, Адлерский район, Левый берег р. Мзымта,  Пикет № 59	Россия, Краснодарский край, Сочи	0101000020E61000002497FF907EDF4340A08D5C37A5CC4540
46432	2	20	\N	50262	21819	\N	43.632209238606599	Краснодарский край, город Сочи, Центральный район, Тимирязевская, 21/7, телефон: 556239, 554986	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Тимирязева, 21	0101000020E610000071C806D2C5DC4340529E7939ECD04540
46459	2	20	\N	50262	4607	\N	43.585839802122699	Краснодарский край, город Сочи, Центральный район, Советская, 26/А, телефон: 648798	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Советская, 26а	0101000020E6100000E42F2DEA93DC434025581CCEFCCA4540
46273	2	20	\N	50262	22195	\N	43.483759093160899	г.Сочи, Ленина, 280а, телефон: 463528		0101000020E6100000DECA129D65F24340A5129ED0EBBD4540
46425	2	20	\N	50262	4174	\N	43.618994000000001	Краснодарский край, город Сочи, Центральный район, Донская, 15, телефон: 550242	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Донская, 15	0101000020E61000001346B3B27DDC4340CA3505323BCF4540
46412	2	20	\N	50262	4078	\N	43.598114751630803	Краснодарский край, город Сочи, Центральный район, Гагарина, 10/А, телефон: 544022	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Гагарина, 10а	0101000020E6100000B01C210379DC43409F1F46088FCC4540
46409	2	20	\N	50262	2638	\N	43.604177999999997	Краснодарский край, город Сочи, Центральный район, Виноградная, 45, телефон: 535302	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Виноградная, 45	0101000020E61000002E742502D5DB4340397B67B455CD4540
46407	2	20	\N	50262	2638	\N	43.613576999999999	Краснодарский край, город Сочи, Центральный район, Виноградная, 101, телефон: 536238	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Виноградная, 101	0101000020E6100000FDF50A0BEEDB4340F549EEB089CE4540
46377	2	20	\N	50262	23597	\N	43.570034	город Сочи, Фабрициуса, 2/28, телефон: 96-43-62		0101000020E6100000A7E8482EFFDF4340D5CDC5DFF6C84540
46392	2	20	\N	50262	22224	\N	43.515148458632197	город Сочи, Шоссейная, 26, телефон: 65-00-13	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, улица Шоссейная, 18	0101000020E6100000F7E461A1D6EE4340C74CA25EF0C14540
46422	2	20	\N	50262	4190	\N	43.620665000000002	Краснодарский край, город Сочи, Центральный район, Чехова переулок, 9, телефон: 554045	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, Чехова переулок, 9	0101000020E6100000E4D70FB1C1DC4340CC6262F371CF4540
46427	2	20	\N	50262	24010	\N	43.622753000000003	Краснодарский край, город Сочи, Центральный район, Чехова, 25, телефон: 557230		0101000020E6100000D6ABC8E880DC4340323ECC5EB6CF4540
45591	2	20	\N	50371	\N	\N	45.160041999999997	хутор Свобода, клуб, телефон: 7-01-42		0101000020E61000000A9E42AED495434043FE99417C944640
46429	2	20	\N	50262	23973	\N	43.624163000000003	Краснодарский край, город Сочи, Центральный район, Чехова, 37, телефон: 555141,550871		0101000020E6100000946A9F8EC7DC4340C72FBC92E4CF4540
46386	2	20	\N	50262	21790	\N	43.572771923151798	город Сочи, Чекменева, 45, телефон: 67-71-50	Россия, Краснодарский край, Большой Сочи Хостинский район, село Краевско-Армянское, улица Чекменева, 45	0101000020E610000043554CA59FE643404208C89750C94540
46449	2	20	\N	50262	23892	\N	43.597304000000001	Краснодарский край, город Сочи, Центральный район, Чебрикова, 5, телефон: 610044		0101000020E6100000A038807EDFDD43408FE21C7574CC4540
46415	2	20	\N	50262	23968	\N	43.596741999999999	Краснодарский край, город Сочи, Центральный район, Чайковского, 7, телефон: 545706		0101000020E6100000F296AB1F9BDC43402713B70A62CC4540
46411	2	20	\N	50262	23968	\N	43.593510000000002	Краснодарский край, город Сочи, Центральный район, Чайковского, 4, телефон: 530701		0101000020E610000032AB77B81DDC4340ABECBB22F8CB4540
46419	2	20	\N	50262	20916	\N	43.6047177855949	г. Сочи, Центральный район, 354065, Краснодарский край, город Сочи, Центральный район, Чайковского, 45	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Чайковского, 45	0101000020E61000009C19FD6838DD4340B9A6406667CD4540
46418	2	20	\N	50262	20916	\N	43.602767999999998	Краснодарский край, город Сочи, Центральный район, Чайковского, 39, телефон: 544946		0101000020E61000000AF7CABC55DD4340A489778027CD4540
46417	2	20	\N	50262	4136	\N	43.603186000000001	Краснодарский край, город Сочи, Центральный район, Цветной бульвар, 40, телефон: 545171, 544825	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, Цветной бульвар, 40	0101000020E6100000FCC401F4FBDC4340D9B3E73235CD4540
46285	2	20	\N	50262	23364	\N	43.518464000000002	с.Казачий Брод, Форелевая, 45, телефон: 431119		0101000020E6100000A47213B534FF4340A11342075DC24540
46374	2	20	\N	50262	23876	\N	43.575141000000002	г. Сочи, Учительская, 19, телефон: 62-17-92		0101000020E610000080D3BB783FDE43405CCB64389EC94540
46460	2	20	\N	50262	23661	\N	43.591799999999999	Краснодарский край, город Сочи, Центральный район, Туапсинская, 11, телефон: 614252		0101000020E61000002384471B47DE4340EBE2361AC0CB4540
46448	2	20	\N	50262	23661	\N	43.591799999999999	Краснодарский край, город Сочи, Центральный район, Туапсинская, 11, телефон: 614205		0101000020E61000002384471B47DE4340EBE2361AC0CB4540
46450	2	20	\N	50262	4563	\N	43.595011999999997	Краснодарский край, город Сочи, Центральный район, Трунова переулок, 3, телефон: 610853	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, Трунова переулок, 3	0101000020E6100000963D096CCEDD4340205D6C5A29CC4540
46434	2	20	\N	50262	23840	\N	43.638066999999999	Краснодарский край, город Сочи, Центральный район, Труда, 29, телефон: 686139		0101000020E61000005875560BECDF434013D4F02DACD14540
46451	2	20	\N	50262	22315	\N	43.586805143151501	Краснодарский край, город Сочи, Центральный район, Тоннельная, 27, телефон: 616702		0101000020E61000008C6665FB90DD43408C101E6D1CCB4540
45467	2	20	\N	50262	23924	\N	43.626218000000001	Краснодарский край, Кавказский район, Кропоткинское городское поселение, Тимирязева, 2, телефон: 7-11-19		0101000020E610000047AB5AD251DC4340511553E927D04540
46463	2	20	\N	50262	23931	\N	43.572280999999997	Краснодарский край, город Сочи, Центральный район, Театральная, 2, телефон: 621620		0101000020E6100000E964A9F57EDD4340A38FF98040C94540
46396	2	20	\N	50262	20658	\N	43.512993399078702	город Сочи, Сухумское шоссе, 11, телефон: 65-43-43	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Кудепста, Сухумское шоссе	0101000020E6100000467EFD101BF04340D9092FC1A9C14540
46205	2	20	\N	50262	22413	\N	43.423853999999999	г. Сочи, Адлерский район, улица Станиславского, 1		0101000020E61000004F7633A31FF74340AF230ED940B64540
46454	2	20	\N	50262	23935	\N	43.588757000000001	Краснодарский край, город Сочи, Центральный район, Советская, 57, телефон: 645035, 646425		0101000020E61000000AA1832EE1DC43404225AE635CCB4540
46405	2	20	\N	50262	23920	\N	43.621395999999997	Краснодарский край, город Сочи, Центральный район, Санаторная, 49, телефон: 694959		0101000020E6100000B2D7BB3FDED94340BFEE74E789CF4540
46399	2	20	\N	50262	22366	\N	43.496841528267602	город Сочи, Ростовская, 7, телефон: 67-42-32	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Кудепста, улица Ростовская, 7	0101000020E61000002EE7525C55F24340BEA3C68498BF4540
46313	2	20	\N	50262	23072	\N	43.971211737276498	аул Тхагапш, Ровная, 33, телефон: 76-32-37, факс: 76-32-37	Россия, Краснодарский край, городской округ Сочи, поселок Тхагапш	0101000020E61000009E0B23BDA8B74340CBBDC0AC50FC4540
46406	2	20	\N	50262	24005	\N	43.613439999999997	Краснодарский край, город Сочи, Центральный район, Политехническая, 62, телефон: 596138		0101000020E61000001FBFB7E9CFDA43407407B13385CE4540
46325	2	20	\N	50262	22355	\N	43.911212999999996	микрорайон Лазаревское, Победы, 62, телефон: 70-32-88		0101000020E6100000C3BCC79926AA43405358A9A0A2F44540
46323	2	20	\N	50262	22355	\N	43.918691675019602	микрорайон Лазаревское, Победы, 153, телефон: 72-64-60	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, улица Победы, 153	0101000020E610000012DDB3AED1A84340658C0FB397F54540
46404	2	20	\N	50262	23710	\N	43.625565999999999	Краснодарский край, город Сочи, Центральный район, Плеханова, 42, телефон: 502416		0101000020E6100000641EF98381D94340A9BEF38B12D04540
46408	2	20	\N	50262	23649	\N	43.606558430462997	Краснодарский край, город Сочи, Центральный район, Пирогова, 3, телефон: 535126	Россия, Краснодарский край, Большой Сочи Центральный район, поселок Новый Сочи, улица Пирогова	0101000020E6100000492BBEA1F0DB434047904AB1A3CD4540
46243	2	20	\N	50262	24015	\N	43.427110380103201	с.Веселое, Петропавловская, 1, телефон: 416012	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Веселое, улица Петропавловская	0101000020E61000008DEDB5A0F7004440B4E55C8AABB64540
46423	2	20	\N	50262	23716	\N	43.618687000000001	Краснодарский край, город Сочи, Центральный район, Пасечная, 18, телефон: 557272		0101000020E61000007024D06053DD4340EDBAB72231CF4540
46458	2	20	\N	50262	23982	\N	43.587359999999997	Краснодарский край, город Сочи, Центральный район, Парковая, 19, телефон: 644871		0101000020E61000005D328E91ECDB4340417DCB9C2ECB4540
46329	2	20	\N	50262	23754	\N	43.919078952663398	микрорайн Лазаревское, Павлова  переулок, 18, телефон: 70-75-23		0101000020E6100000813E912749AB43405FB87361A4F54540
46462	2	20	\N	50262	23938	\N	43.577865000000003	Краснодарский край, город Сочи, Центральный район, Орджоникидзе, 10, телефон: 621486		0101000020E610000000AC8E1CE9DC43406440F67AF7C94540
46391	2	20	\N	50262	22644	\N	43.511755766438903	город Сочи, Октября, 1/4, телефон: 65-04-02	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, улица Октября	0101000020E610000078CF81E508EF434011C4793881C14540
46299	2	20	\N	50262	75540	\N	43.598792000000003	г. Сочи, Адлерский район, Микрорайон Мирный	Россия, Краснодарский край, Сочи	0101000020E61000002497FF907EDF4340A08D5C37A5CC4540
46339	2	20	\N	50262	22527	\N	43.785097	микрорайон Головинка, Медицинская, 9, телефон: 76-13-25		0101000020E6100000BC7A15191DBC43400798F90E7EE44540
46387	2	20	\N	50262	22601	\N	43.582794999999997	город Сочи, Мацестинская, 7, телефон: 67-71-22		0101000020E6100000B3EC496073DC4340DBA2CC0699CA4540
46443	2	20	\N	50262	21435	\N	43.612113940161798	Краснодарский край, город Сочи, Центральный район, Макаренко, 8/А, телефон: 688470	Россия, Краснодарский край, Большой Сочи Хостинский район, село Новагинка, улица Макаренко, 6	0101000020E6100000D21A834E08DF43403DB665C059CE4540
46375	2	20	\N	50262	23720	\N	43.576382000000002	город Сочи, Лысая гора, 34, телефон: 62-89-14		0101000020E6100000A20BEA5BE6DE43406500A8E2C6C94540
46250	2	20	\N	50262	21880	\N	43.565192127183202	г.Сочи, Лесная, 1, телефон: 638896		0101000020E610000094A0BFD023E24340FDFA213658C84540
46274	2	20	\N	50262	22161	\N	43.469041910643398	г.Сочи, Ленина, 282, телефон: 463465	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ленина, 282	0101000020E6100000F984ECBC8DF34340A839799109BC4540
46268	2	20	\N	50262	22161	\N	43.443544984804397	г.Сочи, Ленина, 97, телефон: 410063	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ленина, 97	0101000020E6100000E55FCB2BD7F34340F4A62215C6B84540
43010	2	20	\N	50262	22161	\N	43.451869907508801	г.Сочи, Ленина, 147, телефон: 462058	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ленина, 147	0101000020E61000007CBABA63B1F3434092054CE0D6B94540
46401	2	20	\N	50262	23921	\N	43.633822565130899	Краснодарский край, город Сочи, Центральный район, Ландышевая, 12, телефон: 501128		0101000020E610000059FD118601D94340EF39B01C21D14540
46461	2	20	\N	50262	21924	\N	43.572213085414198	Краснодарский край, город Сочи, Центральный район, Курортный проспект, 32, телефон: 623399		0101000020E6100000161747E526DE43404BAC8C463EC94540
46385	2	20	\N	50262	22212	\N	43.549594850645498	город Сочи, Курортный проспект, 106/А, телефон: 97-53-84	Россия, Краснодарский край, Большой Сочи Хостинский район, село Бытха, Курортный проспект, 106	0101000020E610000001857AFA08E44340C685032159C64540
46416	2	20	\N	50262	20580	\N	43.601416	Краснодарский край, город Сочи, Центральный район, Красноармейская, 28, телефон: 547262		0101000020E6100000F964C57075DC434044A51133FBCC4540
46414	2	20	\N	50262	20580	\N	43.600521999999998	Краснодарский край, город Сочи, Центральный район, Красноармейская, 24, телефон: 541808, 544373		0101000020E6100000AAF1D24D62DC4340A643A7E7DDCC4540
46413	2	20	\N	50262	20584	\N	43.595714984849302	Краснодарский край, город Сочи, Центральный район, Красноармейская, 6, телефон: 547143		0101000020E6100000CAE1934E24DC43404A5E9D6340CC4540
46457	2	20	\N	50262	23854	\N	43.592838	Краснодарский край, город Сочи, Центральный район, Конституции СССР, 26, телефон: 643372		0101000020E6100000BDE13E726BDC4340BCE9961DE2CB4540
46456	2	20	\N	50262	20736	\N	43.592728452151	Краснодарский край, город Сочи, Центральный район, Конституции СССР, 26, телефон: 645688		0101000020E6100000D53DB2B96ADC434035B6D782DECB4540
46296	2	20	\N	50262	22826	\N	43.426776583887701	с.Верхневеселое, Коммунаров, телефон: 639243	Россия, Краснодарский край, Большой Сочи Адлеровский район, село Верхневеселое, улица Коммунаров	0101000020E61000005F5CAAD216FD4340AED7F4A0A0B64540
34289	2	20	\N	50262	22932	\N	43.573414488682701	"Коммунальная, 1 ""А"""	Россия, Краснодарский край, Большой Сочи Хостинский район, село Бытха, улица Коммунальная	0101000020E61000003659A31EA2E14340C68844A165C94540
46390	2	20	\N	50262	21715	\N	43.514730848696203	город Сочи, Кипарисовая, 6, телефон: 65-03-93		0101000020E6100000AF06280D35EE4340629E95B4E2C14540
46328	2	20	\N	50262	23051	\N	43.915875111094003	микрорайон Лазаревское, Калараша, 147а, телефон: 70-98-43	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, улица Павлова	0101000020E6100000E50E9BC8CCAB4340AC1C5A643BF54540
46372	2	20	\N	50262	23724	\N	43.595892999999997	с. Краевско-Армянское, Измайловская, 57, телефон: 67-90-93		0101000020E61000000744882B67E743402975C93846CC4540
46284	2	20	\N	50262	23618	\N	43.474235999999998	с.Высокое, Ивановская, 54а, телефон: 430142		0101000020E61000000D18247D5AFD4340FD4AE7C3B3BC4540
46358	2	20	\N	50262	23490	\N	43.710228402591497	село Барановка, Золотая, 13, телефон: 52-85-18	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Барановка, улица Золотая	0101000020E6100000F0A5F0A0D9D743400C5A48C0E8DA4540
46389	2	20	\N	50262	20626	\N	43.528241121755798	город Сочи, Звездная, 14, телефон: 65-92-84	Россия, Краснодарский край, Большой Сочи Хостинский район, колхоз 16-й, улица Звездная, 14	0101000020E6100000C37DE4D6A4EB434003B4AD669DC34540
46428	2	20	\N	50262	23718	\N	43.623510000000003	Краснодарский край, город Сочи, Центральный район, Донская, 92, телефон: 555738		0101000020E6100000FD4B529962DC43404F5DF92CCFCF4540
46426	2	20	\N	50262	23718	\N	43.620618999999998	Краснодарский край, город Сочи, Центральный район, Донская, 17, телефон: 550400		0101000020E6100000A1F65B3B51DC43405B23827170CF4540
46421	2	20	\N	50262	23718	\N	43.615157000000004	Краснодарский край, город Сочи, Центральный район, Донская, 36, телефон: 557285		0101000020E610000009C4EBFA05DD4340E773EE76BDCE4540
46430	2	20	\N	50262	23613	\N	43.628867999999997	Краснодарский край, город Сочи, Центральный район, Донская, 108, телефон: 553600, 553601		0101000020E6100000F4FA93F8DCDB43401EC022BF7ED04540
46424	2	20	\N	50262	23613	\N	43.617936999999998	Краснодарский край, город Сочи, Центральный район, Донская, 13/А, телефон: 550637		0101000020E61000003201BF4692DC434082FE428F18CF4540
46376	2	20	\N	50262	23909	\N	43.572626999999997	город Сочи, Депутатская, 10, телефон: 62-19-63		0101000020E610000086E7A56263DE43403EE76ED74BC94540
46446	2	20	\N	50262	22436	\N	43.601384000000003	Краснодарский край, город Сочи, Центральный район, Дагомысская, 17, телефон: 615791,615831		0101000020E61000002384471B47DE4340392BA226FACC4540
46431	2	20	\N	50262	23929	\N	43.628117000000003	Краснодарский край, город Сочи, Центральный район, Гранатная, 3, телефон: 559507		0101000020E61000008D463EAF78DC4340E4874A2366D04540
46272	2	20	\N	50262	22067	\N	43.454565611148404	г.Сочи, Голубые Дали, 23, телефон: 461172		0101000020E610000098DEFE5C34F44340D0EFFB372FBA4540
46420	2	20	\N	50262	23828	\N	43.606822000000001	Краснодарский край, город Сочи, Центральный район, Гагарина, 64, телефон: 544572		0101000020E6100000E90E62670ADD4340253FE257ACCD4540
46455	2	20	\N	50262	23311	\N	43.590192999999999	Краснодарский край, город Сочи, Центральный район, Воровского, 54, телефон: 642326, 642331		0101000020E610000059C4B0C398DC434000AAB8718BCB4540
46403	2	20	\N	50262	23822	\N	43.627790205252097	Краснодарский край, город Сочи, Центральный район, Волжская, 64, телефон: 500617		0101000020E61000005BB56B425AD94340BF60376C5BD04540
46383	2	20	\N	50262	20605	\N	43.582794999999997	город Сочи, Возрождения, 8, телефон: 97-82-14		0101000020E6100000B3EC496073DC4340DBA2CC0699CA4540
46435	2	20	\N	50262	21593	\N	43.619502494072897	Краснодарский край, город Сочи, Центральный район, Вишневая, 7, телефон: 983845	Россия, Краснодарский край, Большой Сочи Хостинский район, село Новагинка, улица Вишневая	0101000020E6100000045ABA826DE043403EE76ED74BCF4540
46410	2	20	\N	50262	22215	\N	43.596585622654601	г. Сочи, Центральный район,  354000, Краснодарский край, город Сочи, Центральный район, Виноградная, 27	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Виноградная, 27	0101000020E6100000F294D5743DDB434030A017EE5CCC4540
46379	2	20	\N	50262	20628	\N	43.559967999999998	город Сочи, Бытха, 25, телефон: 67-20-19		0101000020E6100000054D4BAC8CE243403C670B08ADC74540
46255	2	20	\N	50262	20568	\N	43.4257656538798	г.Сочи, Богдана Хмельницкого, 24, телефон: 440172		0101000020E6100000D3DD7536E4F54340D7DF12807FB64540
46248	2	20	\N	50262	22116	\N	43.420022310424102	г.Сочи, Бакинская, 2, телефон: 411872		0101000020E61000004AB6BA9C12FC4340DECCE847C3B54540
46349	2	20	\N	50262	24054	\N	43.6931724980467	г. Сочи, Лазаревский район, 354208, микрорайон Лоо, Астраханская, 7		0101000020E61000008B1A4CC3F0CB43405F402FDCB9D84540
46439	2	20	\N	50262	22280	\N	43.617702000000001	Краснодарский край, город Сочи, Центральный район, Абрикосовая, 23, телефон: 985954		0101000020E610000056F2B1BB40DF43403F56F0DB10CF4540
46438	2	20	\N	50262	22280	\N	43.618754467118102	Краснодарский край, город Сочи, Центральный район, Абрикосовая, 29, телефон: 980421	Россия, Краснодарский край, Большой Сочи Центральный район, село Новагинка, улица Абрикосовая, 29	0101000020E610000094A2957B81DF43407522C15433CF4540
46369	2	20	\N	50262	22715	\N	43.627489795059198	с. Верхний Юрт, Абовяна, 39, телефон: 67-83-31	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Раздольное, улица Абовяна	0101000020E610000059DDEA39E9E143409548A29751D04540
46440	2	20	\N	50262	23722	\N	43.614308000000001	Краснодарский край, город Сочи, Центральный район, 60 лет ВЛКСМ, 12, телефон: 980255, 984630, 984603		0101000020E610000040BFEFDFBCDE4340E9D500A5A1CE4540
46346	2	20	\N	50262	23662	\N	43.717492999568002	село Горное Лоо, Лооская, 2/1, телефон: 50-90-37		0101000020E61000009D0DF96706CD4340F10D85CFD6DB4540
46256	2	20	\N	50262	21613	\N	43.582794999999997	г.Сочи, Кирова, 26, телефон: 401448		0101000020E6100000B3EC496073DC4340DBA2CC0699CA4540
46453	2	20	\N	50262	23636	\N	43.589736000000002	Краснодарский край, город Сочи, Центральный район, Горького, 48, телефон: 695755		0101000020E610000082E7DEC325DD43400EA320787CCB4540
46452	2	20	\N	50262	23484	\N	43.595657965306103	Краснодарский край, город Сочи, Центральный район, Горького, 85, телефон: 646072	Россия, Краснодарский край, Большой Сочи Центральный район, Сочи, улица Горького, 87	0101000020E6100000D8F335CB65DD4340E6CC76853ECC4540
46198	2	20	\N	50410	22622	\N	45.246632913785398	город Славянск-на-Кубани, Строителей, 49, телефон: 2-12-19,4-31-96		0101000020E6100000302DEA93DC134340A48E8EAB919F4640
46183	2	20	\N	50410	22563	\N	45.273462024786603	город Славянск-на-Кубани, Пролетарская, 4, телефон: 2-25-69	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E6100000D064FF3C0D0C4340715985CD00A34640
46197	2	20	\N	50410	22603	\N	45.254217385117798	город Славянск-на-Кубани, Победы, 380, телефон: 2-12-61	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E6100000E73A8DB4541043402A8BC22E8AA04640
46194	2	20	\N	50410	21692	\N	45.237589	город Славянск-на-Кубани, Отдельская, 32, телефон: 2-58-85		0101000020E61000000B630B410E104340D671FC50699E4640
46191	2	20	\N	50410	21692	\N	45.237589	город Славянск-на-Кубани, Отдельская, 213, телефон: 2-12-02		0101000020E61000000B630B410E104340D671FC50699E4640
46187	2	20	\N	50410	21692	\N	45.245214094819303	город Славянск-на-Кубани, Отдельская, 207, телефон: (246) 4-18-46	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E610000060048D99440F4340BB421F2C639F4640
46184	2	20	\N	50410	22282	\N	45.237589	город Славянск-на-Кубани, Набережная, 14, телефон: (246) 7-32-42		0101000020E61000000B630B410E104340D671FC50699E4640
44728	2	20	\N	50270	21339	\N	44.712197000000003	станица Саратовская, Школьная, 3 А, телефон: 3-11-28	Россия, Краснодарский край, Горячий Ключ, поселок Саратовская	0101000020E61000002FFA0AD28C9B434098A77345295B4640
44730	2	20	\N	50270	22061	\N	44.710850691172197	станица Саратовская, Табачная, 5, телефон: 3-21-72	Россия, Краснодарский край, Горячий Ключ, поселок Саратовская	0101000020E6100000CEFE40B96D9B434019AA622AFD5A4640
44729	2	20	\N	50270	20674	\N	44.712197000000003	станица Саратовская, Ленина, 69 А, телефон: 3-14-53		0101000020E61000002FFA0AD28C9B434098A77345295B4640
46015	2	20	\N	50586	22904	\N	45.023074000000001	ст. Передовая, ул. Ленина, 124, телефон: 9-54-91		0101000020E61000007347FFCBB57C4340A7B1BD16F4824640
45982	2	20	\N	50592	22931	\N	45.027521	ст.  Отрадненая, ул. Октябрьская, 210, телефон: 3-34-02		0101000020E610000060AB048BC37B4340037AE1CE85834640
46064	2	20	\N	50300	23355	\N	45.1849931233969	поселок Октябрьский, Советская, 10, телефон: 3-74-69		0101000020E61000000C207C28D18A4340957EC2D9AD974640
46172	2	20	\N	50300	21674	\N	45.181615000000001	п. Октябрьский, Пушкина, 46, телефон: 66-2-13		0101000020E61000004D327216F68A434045BB0A293F974640
44877	2	20	\N	50300	20918	\N	45.181615000000001	пос. Октябрьский, Мира, 38 Б, телефон: 97236		0101000020E61000004D327216F68A434045BB0A293F974640
45111	2	20	\N	50300	23362	\N	45.183401471728303	поселок Октябрьский, ул.Красная, 20/А, телефон: 91-3-74	Россия, Краснодарский край, Краснодар, поселок Октябрьский	0101000020E610000093AB58FCA68A4340E08618AF79974640
45968	2	20	\N	6023	6412	\N	44.701036999999999	г. Новороссийск, Набережная имени Адмирала Серебрякова, 53, телефон: 715-207	Россия, Краснодарский край, Новороссийск, улица набережная Адмирала Серебрякова, 53	0101000020E6100000EF3A1BF2CFE442409A249694BB594640
46918	2	20	\N	6023	1942	\N	44.677314000000003	город Новороссийск, Южная, 6, телефон: 648777	Россия, Краснодарский край, Новороссийск, улица Южная, 6	0101000020E6100000BA2F67B62BE44240BD8FA339B2564640
45958	2	20	\N	6023	6436	\N	44.713132000000002	г. Новороссийск, Энгельса, 49, телефон: 611-428, 610-167	Россия, Краснодарский край, Новороссийск, улица Энгельса, 49	0101000020E6100000406CE9D154E3424094DDCCE8475B4640
45918	2	20	\N	6023	20534	\N	44.7499309953553	город Новороссийск, Детская библиотека филиал №8 Мефодиевская, 118Б, телефон: 27-27-58	Россия, Краснодарский край, поселок Мефодиевка, улица Мефодиевская	0101000020E6100000B0E2546B61E04240D7A02FBDFD5F4640
45912	2	20	\N	6023	20534	\N	44.743333497009303	город Новороссийск, Мефодиевская, 15, телефон: 27-33-08	Россия, Краснодарский край, поселок Мефодиевка, улица Мефодиевская, 15	0101000020E61000003447567E19E24240CF842689255F4640
45906	2	20	\N	6023	21020	\N	44.735969686202999	город Новороссийск, Жуковского, 7, телефон: 67-80-48	Россия, Краснодарский край, поселок Мефодиевка, улица Жуковского	0101000020E6100000B2BAD573D2E34240276BD443345E4640
45959	2	20	\N	6023	6451	\N	44.7142993230757	г. Новороссийск, Грибоедова, 12, телефон: 610-586, 639-034	Россия, Краснодарский край, Новороссийск, улица Грибоедова	0101000020E6100000E90E62670AE3424062484E266E5B4640
46903	2	20	\N	6023	1750	\N	44.688479000000001	город Новороссийск, Героев Десантников, 29А, телефон: 714026	Россия, Краснодарский край, Новороссийск, улица Героев Десантников, 29а	0101000020E61000000BD0B69A75E44240CC7D721420584640
45930	2	20	\N	6023	6126	\N	44.732064000000001	город Новороссийск, ул. Видова, д. 164, телефон: 26-31-66		0101000020E610000049BA66F2CDDE42401B4AED45B45D4640
45927	2	20	\N	6023	6126	\N	44.728159421170702	город Новороссийск, ул. Видова, д. 109, телефон: 21-17-06	Россия, Краснодарский край, Новороссийск, улица Видова	0101000020E6100000DB696B4430E04240DFA46950345D4640
45956	2	20	\N	6023	23520	\N	44.718751995731701	г. Новороссийск, Набережная имени Адмирала Серебрякова, 9, телефон: 602-711, 602-816	Россия, Краснодарский край, Новороссийск, улица набережная Адмирала Серебрякова	0101000020E610000046CF2D7425E44240A1F7C610005C4640
46940	2	20	\N	6023	24026	\N	44.677346	Краснодарский край, город Новороссийск, х. Ленинский путь, Южная, 10, телефон: 8-918-15-73-208		0101000020E61000008FA850DD5CE44240C8091346B3564640
46950	2	20	\N	6023	22848	\N	44.688479000000001	Краснодарский край, город Новороссийск, с. Мысхако, Шоссейная, 34, телефон: 71-84-34		0101000020E61000009CFC169D2CE14240CC7D721420584640
46949	2	20	\N	6023	22848	\N	44.688479000000001	Краснодарский край, город Новороссийск, с. Мысхако, Шоссейная, 1, телефон: 71-91-02		0101000020E61000009CFC169D2CE14240CC7D721420584640
46939	2	20	\N	6023	22848	\N	44.688479000000001	Краснодарский край, город Новороссийск, х. Горный, Шоссейная, 53, телефон: 27-62-87		0101000020E61000009CFC169D2CE14240CC7D721420584640
45910	2	20	\N	6023	22431	\N	44.739472010957002	город Новороссийск, Шаумяна, 5, телефон: 26-50-46	Россия, Краснодарский край, поселок Мефодиевка, улица Шаумяна, 5	0101000020E61000004487C09140E342406327BC04A75E4640
45975	2	20	\N	6023	22996	\N	44.721285999999999	г.Новороссийск ул.Чайковского 15		0101000020E6100000EBC5504EB4E1424005888219535C4640
45957	2	20	\N	6023	23308	\N	44.713894000000003	г. Новороссийск, Цедрика, 7, телефон: 630-430, 645-592		0101000020E6100000A839799109E44240C367EBE0605B4640
46951	2	20	\N	6023	22699	\N	44.910409389838499	Краснодарский край, город Новороссийск, ст.Натухаевская, ул. Фрунзе, 50, телефон: 27-41-51	Россия, Краснодарский край, городской округ Новороссийск, поселок Натухаевская	0101000020E610000037548CF337C94240F67D384888744640
46943	2	20	\N	6023	22699	\N	44.906366398153899	Краснодарский край, город Новороссийск, ст. Натухаевская, Фрунзе, 54, телефон: 27-40-30		0101000020E61000005F29CB10C7C84240691A14CD03744640
46942	2	20	\N	6023	22699	\N	44.743397000000002	Краснодарский край, город Новороссийск, ст. Натухаевская, Фрунзе, 50, телефон: 27-40-48		0101000020E61000003E5A9C31CCDB4240E67805A2275F4640
45961	2	20	\N	6023	23430	\N	44.712498649025697	г. Новороссийск, Толстого, 4, телефон: 720-845	Россия, Краснодарский край, Новороссийск, улица Толстого, 11	0101000020E6100000E19BA6CF0EE4424063B7CF2A335B4640
45936	2	20	\N	6023	21202	\N	44.738003813479096	г.Новороссисйк ул.Тобольского 5 а	Россия, Краснодарский край, Новороссийск, улица Тобольская, 5	0101000020E6100000A0FEB3E6C7DD4240992842EA765E4640
45960	2	20	\N	6023	23111	\N	44.696942999999997	г. Новороссийск, Суворовская, 40, телефон: 714-608		0101000020E61000004C8A8F4FC8E442408B16A06D35594640
45937	2	20	\N	6023	23742	\N	44.744165000000002	город Новороссийск, с.Цемдолина, ул. Спортивная, д. 1, телефон: 67-25-71		0101000020E610000048FB1F60ADDC4240F7E978CC405F4640
45952	2	20	\N	6023	23097	\N	44.718239834014597	г.Новороссийск, Советов, 45, телефон: 610821		0101000020E6100000575A46EA3DE34240EB56CF49EF5B4640
45949	2	20	\N	6023	23097	\N	44.721317516593302	г. Новороссийск, Советов, 19, телефон: 676-491	Россия, Краснодарский край, Новороссийск, улица Свободы	0101000020E61000002997C62FBCE242401002F225545C4640
45948	2	20	\N	6023	23097	\N	44.722881752817997	г. Новороссийск, Советов, 9, телефон: 644763	Россия, Краснодарский край, Новороссийск, улица Советов	0101000020E6100000139ED0EB4FE24240FC6EBA65875C4640
45921	2	20	\N	6023	22382	\N	44.7227461029062	город Новороссийск, ул. Севрюкова, д. 6, телефон: 21-62-38	Россия, Краснодарский край, Новороссийск, улица Советов, 30	0101000020E61000002E54FEB5BCE242404CA8E0F0825C4640
46931	2	20	\N	6023	22689	\N	44.701402999999999	Краснодарский край, город Новороссийск, с. Васильевка, Садовая, 1а, телефон: 8-918-94-75-723		0101000020E61000007F15E0BBCDDF42407C28D192C7594640
45953	2	20	\N	6023	21095	\N	44.717571	г. Новороссийск, Рубина, 27, телефон: 644-515		0101000020E61000008C2FDAE385E242406DC7D45DD95B4640
45951	2	20	\N	6023	21095	\N	44.718998214209201	г. Новороссийск, Рубина, 5, телефон: 642-271, 611-868	Россия, Краснодарский край, Новороссийск, улица Рубина	0101000020E610000028EE7893DFE24240D8F15F20085C4640
45955	2	20	\N	6023	23081	\N	44.713906999999999	г. Новороссийск, Революции 1905 г, 23, телефон: 613-652, 613-474		0101000020E61000000E9E094D12E3424057B1F84D615B4640
45971	2	20	\N	6023	23460	\N	44.698118248023597	г. Новороссийск, Прямая, 33, телефон: 713-423		0101000020E6100000EEED96E480E34240DD5F3DEE5B594640
46926	2	20	\N	6023	23549	\N	44.709276000000003	Краснодарский край, город Новороссийск, п. Абрау-Дюрсо, Промышленная, 12, телефон: 27-54-40		0101000020E6100000CDE7DCED7ACB42403AEB538EC95A4640
45942	2	20	\N	6023	23518	\N	44.761480556012401	город Новороссийск, с.Цемдолина, ул. Полевая, д. 8, телефон: 67-19-26		0101000020E6100000574277499CDB424040C39B3578614640
46941	2	20	\N	6023	23633	\N	44.720793	Краснодарский край, город Новороссийск, х. Семигорье, Победы, 1-а, телефон: 8-918-157-32-08		0101000020E6100000D76B7A5050E24240C617EDF1425C4640
45939	2	20	\N	6023	21586	\N	44.747461999999999	город Новороссийск, с.Цемдолина, ул. Первомайская, д. 3-а, телефон: 76-36-29		0101000020E6100000A24621C9ACDC42405A80B6D5AC5F4640
45917	2	20	\N	6023	21586	\N	44.746970010012298	город Новороссийск, Первомайская, 9, телефон: 27-93-53	Россия, Краснодарский край, поселок Цемдолина, улица Мичурина, 10	0101000020E6100000E8BE9CD9AEDC4240EB8B84B69C5F4640
45907	2	20	\N	6023	21586	\N	44.746755928173599	город Новороссийск, Первомайская, 7, телефон: 27-86-41	Россия, Краснодарский край, поселок Цемдолина, улица Первомайская	0101000020E6100000C47AA35698DC4240BF0B5BB3955F4640
45974	2	20	\N	6023	23010	\N	44.711703999999997	г. Новороссийск, Пархоменко, 6, телефон: 644-667		0101000020E610000004C6FA0626E342405837DE1D195B4640
46923	2	20	\N	6023	1965	\N	44.689509999999999	город Новороссийск, Мысхакское шоссе, 56, телефон: 301732	Россия, Краснодарский край, Новороссийск, Мысхакское шоссе, 56	0101000020E61000000070ECD973E14240EA211ADD41584640
46919	2	20	\N	6023	1965	\N	44.69117	город Новороссийск, Мысхакское шоссе, 48, телефон: 224105	Россия, Краснодарский край, Новороссийск, Мысхакское шоссе, 48	0101000020E61000009A25016A6AE14240F8FC304278584640
45964	2	20	\N	6023	1965	\N	44.705399999999997	г. Новороссийск, Мысхакское шоссе, 21/23, телефон: 644-819, 64-37-09	Россия, Краснодарский край, Новороссийск, Мысхакское шоссе, 23	0101000020E6100000A9F7544E7BE24240984C158C4A5A4640
46934	2	20	\N	6023	23511	\N	44.716700452805199	Краснодарский край, город Новороссийск, п. Гайдук, Мира, 47, телефон: 26-92-42	Россия, Краснодарский край, Новороссийск, улица Мира, 47	0101000020E61000007DE6AC4F39E4424088855AD3BC5B4640
46928	2	20	\N	6023	23511	\N	44.676328233221902	Краснодарский край, город Новороссийск, с. Южная Озереевка, Мира, 27, телефон: 8-918-64-75-162		0101000020E6100000894160E5D0D042403EAF78EA91564640
45915	2	20	\N	6023	22368	\N	44.749659584029402	город Новороссийск, Мефодиевская, 118-б, телефон: 27-22-68	Россия, Краснодарский край, поселок Мефодиевка, улица Мефодиевская	0101000020E61000000B7F86376BE04240478FDFDBF45F4640
45909	2	20	\N	6023	21266	\N	44.746713040030599	город Новороссийск, Менжинского, 52, телефон: 26-56-54	Россия, Краснодарский край, поселок Мефодиевка, улица Керченская, 52	0101000020E61000004419AA622AE34240C03FA54A945F4640
45914	2	20	\N	6023	20539	\N	44.720478999999997	город Новороссийск, Межевая, 4, телефон: 76-86-64	Россия, Краснодарский край, Новороссийск, улица Рубина	0101000020E6100000CF66D5E76AE34240363AE7A7385C4640
46916	2	20	\N	6023	23627	\N	44.689484999999998	город Новороссийск, Малоземельская, 11А, телефон: 635389		0101000020E6100000B0E8D66B7AE24240910A630B41584640
46914	2	20	\N	6023	23627	\N	44.690035999999999	город Новороссийск, Малоземельская, 15, телефон: 637622		0101000020E6100000FC34EECD6FE242400588821953584640
45931	2	20	\N	6023	23941	\N	44.727933	город Новороссийск, ул. Луначарского, д. 21, телефон: 26-37-42		0101000020E6100000D7C0560916DF4240EF5696E82C5D4640
46932	2	20	\N	6023	1745	\N	44.785859000000002	Краснодарский край, город Новороссийск, п. Гайдук, Ленина, 1, телефон: 26-92-61		0101000020E6100000E659492BBED942403622180797644640
46921	2	20	\N	6023	1745	\N	44.688363000000003	город Новороссийск, проспект Ленина, 95А, телефон: 647992		0101000020E6100000A62BD8463CE5424063635E471C584640
46920	2	20	\N	6023	1745	\N	44.688363000000003	город Новороссийск, проспект Ленина, 93, телефон: 716233		0101000020E6100000A62BD8463CE5424063635E471C584640
45945	2	20	\N	6023	23372	\N	44.723246000000003	город Новороссийск, ул. Видова, д. 56, телефон: 21-13-10		0101000020E61000009DD9AED007E142403E7B2E53935C4640
46902	2	20	\N	6023	1745	\N	44.691279000000002	г.Новороссийск проспект Ленина 59	Россия, Краснодарский край, Новороссийск, Ленина проспект, 59	0101000020E6100000D670917BBAE44240AFB48CD47B584640
45969	2	20	\N	6023	1745	\N	44.698993999999999	г. Новороссийск, пр. Ленина, 22, телефон: 711-620	Россия, Краснодарский край, Новороссийск, Ленина проспект, 22	0101000020E61000006808C72C7BE44240D40CA9A278594640
45940	2	20	\N	6023	22596	\N	44.756467999999998	город Новороссийск, с.Цемдолина, ул. Ленина, д. 82, телефон: 67-23-52		0101000020E61000001766A19DD3DC42403A3C84F1D3604640
45963	2	20	\N	6023	23990	\N	44.709102999999999	г. Новороссийск, Лейтенанта Шмидта, 37, телефон: 630-261		0101000020E610000030D63730B9E342406C3F19E3C35A4640
45973	2	20	\N	6023	23691	\N	44.692262290679501	г. Новороссийск, Куникова, 28, телефон: 655-863, 601-736	Россия, Краснодарский край, Новороссийск, улица Куникова, 28	0101000020E61000007C9C69C2F6E34240BC218D0A9C584640
45972	2	20	\N	6023	23691	\N	44.694085999999999	г. Новороссийск, Куникова, 9, телефон: 702-100		0101000020E6100000C93EC8B260E44240444E5FCFD7584640
45920	2	20	\N	6023	6052	\N	44.715734777533697	город Новороссийск, пер. Краснознаменный, д. 2-а, телефон: 22-01-77	Россия, Краснодарский край, Новороссийск, Краснознаменный переулок	0101000020E6100000B5E0455F41E0424021CD58349D5B4640
45913	2	20	\N	6023	21995	\N	44.747936354985598	город Новороссийск, Краснодарская, 35, телефон: 27-30-51	Россия, Краснодарский край, поселок Мефодиевка, Школьный переулок	0101000020E6100000527FBDC282E1424023C0E95DBC5F4640
46945	2	20	\N	6023	20485	\N	44.699441999999998	Краснодарский край, город Новороссийск, ст. Раевская, Красная, 42, телефон: 270244	Россия, Краснодарский край, Новороссийск, Раевская балка	0101000020E61000009692E52494E0424073B9C15087594640
45943	2	20	\N	6023	20485	\N	44.771871883919403	город Новороссийск, с. Кирилловка, ул. Красная, д. 23, телефон: 26-89-02	Россия, Краснодарский край	0101000020E6100000D9D138D4EFDC42405C59A2B3CC624640
45928	2	20	\N	6023	23671	\N	44.728164	город Новороссийск, ул. Козлова, д. 76, телефон: 21-06-77		0101000020E61000004DF38E5374E04240F10F5B7A345D4640
46935	2	20	\N	6023	21808	\N	44.745150288939001	Краснодарский край, город Новороссийск, с. Владимировка, Кирова, 19, телефон: 26-87-39		0101000020E6100000DF52CE177BE34240A54E4013615F4640
45970	2	20	\N	6023	23377	\N	44.696768682920698	г. Новороссийск, Карамзина, 43, телефон: 633-097	Россия, Краснодарский край, Новороссийск, улица Карамзина	0101000020E6100000511553E927E44240EEEE01BA2F594640
45962	2	20	\N	6023	23753	\N	44.707808999999997	г. Новороссийск, Исаева, 2, телефон: 606-409, 606-406		0101000020E6100000D97A8670CCE4424040683D7C995A4640
46917	2	20	\N	6023	23768	\N	44.688555000000001	город Новороссийск, Золотаревского, 6, телефон: 221344		0101000020E61000008FC6A17E17E24240A73FFB9122584640
45944	2	20	\N	6023	21627	\N	44.720478999999997	город Новороссийск, с. Борисовка, ул. Дружбы, д. 5, телефон: 67-19-10		0101000020E6100000CF66D5E76AE34240363AE7A7385C4640
46924	2	20	\N	6023	1790	\N	44.678372000000003	город Новороссийск, проспект Дзержинского, 210, телефон: 649994	Россия, Краснодарский край, Новороссийск, Дзержинского проспект, 210	0101000020E6100000C5E40D30F3E34240D542C9E4D4564640
46922	2	20	\N	6023	1790	\N	44.689022999999999	город Новороссийск, проспект Дзержинского, 197, телефон: 633467	Россия, Краснодарский край, Новороссийск, Дзержинского проспект, 197	0101000020E61000000A302C7FBEE342408D98D9E731584640
46911	2	20	\N	6023	1790	\N	44.679569999999998	город Новороссийск, проспект Дзержинского, 213, телефон: 648858	Россия, Краснодарский край, Новороссийск, Дзержинского проспект, 213	0101000020E6100000ED612F14B0E34240DEAB5626FC564640
46909	2	20	\N	6023	1790	\N	44.679569999999998	город Новороссийск, проспект Дзержинского, 213, телефон: 648857	Россия, Краснодарский край, Новороссийск, Дзержинского проспект, 213	0101000020E6100000ED612F14B0E34240DEAB5626FC564640
46906	2	20	\N	6023	1790	\N	44.690337	город Новороссийск, проспект Дзержинского, 162, телефон: 725928	Россия, Краснодарский край, Новороссийск, Дзержинского проспект, 162	0101000020E610000076C1E09A3BE44240001C7BF65C584640
45967	2	20	\N	6023	1790	\N	44.7006542016791	г. Новороссийск, Дзержинского, 126, телефон: 712-253, 619-641	Россия, Краснодарский край, Новороссийск, Дзержинского проспект	0101000020E610000035255987A3E34240E2E7BF07AF594640
45938	2	20	\N	6023	23682	\N	44.715169000000003	город Новороссийск, с.Цемдолина, ул. Горького, д. 27, телефон: 26-35-53		0101000020E61000006B9DB81CAFE24240780E65A88A5B4640
45932	2	20	\N	6023	23857	\N	44.732050999999998	г.Новороссийск ул.Герцена 5		0101000020E61000007097FDBAD3DD42408600E0D8B35D4640
46915	2	20	\N	6023	20424	\N	44.689413999999999	город Новороссийск, Героев Десантников, 67, телефон: 634305		0101000020E6100000EEEE01BA2FE34240C8B3CBB73E584640
46908	2	20	\N	6023	20424	\N	44.687593999999997	город Новороссийск, Героев Десантников, 57А, телефон: 636518		0101000020E6100000DD25715644E342408176871403584640
46907	2	20	\N	6023	20424	\N	44.688638418697202	г.Новороссийск ул Г.Десантников 51а	Россия, Краснодарский край, Новороссийск, улица Героев Десантников, 51	0101000020E6100000EFFE78AF5AE3424034643C4A25584640
46905	2	20	\N	6023	20424	\N	44.687466000000001	город Новороссийск, Героев Десантников, 13, телефон: 713910		0101000020E6100000ABE97AA2EBE44240548EC9E2FE574640
46904	2	20	\N	6023	20424	\N	44.687466000000001	город Новороссийск, Героев Десантников, 13, телефон: 675496		0101000020E6100000ABE97AA2EBE44240548EC9E2FE574640
46913	2	20	\N	6023	23925	\N	44.685191000000003	город Новороссийск, Волгоградская, 46, телефон: 223707		0101000020E61000001899805F23E34240BC41B456B4574640
46912	2	20	\N	6023	23925	\N	44.685191000000003	город Новороссийск, Волгоградская, 46, телефон: 223047		0101000020E61000001899805F23E34240BC41B456B4574640
46910	2	20	\N	6023	23925	\N	44.684914999999997	353900, г. Новороссийск, ул.Волгоградская, 44, филиал №18 юношеской библиотеки		0101000020E610000012859675FFE2424019C5724BAB574640
46929	2	20	\N	6023	22994	\N	44.699865000000003	Краснодарский край, город Новороссийск, с. Северная Озереевка, Виноградная, 36, телефон: 8-918-46-89-632		0101000020E6100000E17EC00303E04240BA4E232D95594640
45935	2	20	\N	6023	6085	\N	44.739800581912803	город Новороссийск, Анапское шоссе, д. 55-а, телефон: 26-36-35	Россия, Краснодарский край, Новороссийск, Анапское шоссе, 51	0101000020E6100000CEDF844204DE4240284696CCB15E4640
45925	2	20	\N	6023	6085	\N	44.726672000000001	город Новороссийск, Анапское шоссе, д.6, телефон: 21-01-66	Россия, Краснодарский край, Новороссийск, Анапское шоссе, 6	0101000020E6100000A724EB7074E142409F758D96035D4640
45924	2	20	\N	6023	6085	\N	44.727606999999999	город Новороссийск, Анапское шоссе, д. 15, телефон: 21-63-44	Россия, Краснодарский край, Новороссийск, Анапское шоссе, 17	0101000020E61000009738F24064E142409BABE639225D4640
45923	2	20	\N	6023	6085	\N	44.727913999999998	город Новороссийск, Анапское шоссе, д. 18, телефон: 21-64-46	Россия, Краснодарский край, Новороссийск, Анапское шоссе, 18	0101000020E61000007920B24813E14240782634492C5D4640
46944	2	20	\N	6023	20479	\N	44.720478999999997	Краснодарский край, город Новороссийск, х. Победа, 50 лет Октября, 10-а, телефон: 8-918-16-92-885		0101000020E6100000CF66D5E76AE34240363AE7A7385C4640
46936	2	20	\N	6023	21684	\N	44.720478999999997	Краснодарский край, город Новороссийск, п. Верхнебаканский, 40 лет Октября, 8, телефон: 27-65-64		0101000020E6100000CF66D5E76AE34240363AE7A7385C4640
45954	2	20	\N	6023	23864	\N	44.713459	г. Новороссийск, Яковлева, 27, телефон: 645-116		0101000020E610000036583849F3E14240B804E09F525B4640
45926	2	20	\N	6023	23855	\N	44.725358999999997	город Новороссийск, ул. Чкалова, д. 48, телефон: 21-26-36		0101000020E6100000D219187959DF4240FC6D4F90D85C4640
45965	2	20	\N	6023	23799	\N	44.703919999999997	г. Новороссийск, Суворовская, 5, телефон: 716-535, 655-361, 61-85-85		0101000020E6100000378AAC3594E442400A80F10C1A5A4640
45922	2	20	\N	6023	23604	\N	44.728785000000002	город Новороссийск, ул. Козлова, д. 74-а, телефон: 21-30-50		0101000020E6100000F888981249E042405E68AED3485D4640
45950	2	20	\N	6023	23865	\N	44.719973000000003	г. Новороссийск, Гладкова, 3, телефон: 644-961		0101000020E610000078B6476FB8E1424063804413285C4640
45838	2	20	\N	50394	21600	\N	45.1071044698785	г.Новокубанск, ул.Чапаева, 63, телефон: 3-10-43	Россия, Краснодарский край, Новокубанский район, город Новокубанск	0101000020E61000005055A18158844440A9A27895B58D4640
45833	2	20	\N	50394	22665	\N	45.116138909992202	г.Новокубанск, ул.Победы, 4, телефон: 4-59-00		0101000020E61000009FCA694FC97F444023658BA4DD8E4640
45842	2	20	\N	50394	22008	\N	45.082984371916801	г.Новокубанск, ул.Первомайская, 132, телефон: 3-21-94	Россия, Краснодарский край, Новокубанский район	0101000020E6100000787FBC57AD884440AF0B3F389F8A4640
45840	2	20	\N	50394	22008	\N	45.111763185341999	г.Новокубанск, ул.Первомайская, 83, телефон: 3-07-45		0101000020E61000008A929048DB84444091F3FE3F4E8E4640
45832	2	20	\N	50394	21951	\N	45.123947521118303	г.Новокубанск, ул.Красная, 46, телефон: 3-60-33		0101000020E61000005CE674594C7C4440CA332F87DD8F4640
45843	2	20	\N	50394	21747	\N	45.106678999371901	г.Новокубанск, ул.Кооперативная, 64/1, телефон: 3-29-59		0101000020E6100000F0DDE68D93844440C21550A8A78D4640
45836	2	20	\N	50394	22175	\N	45.104430030802703	г.Новокубанск, ул.К.Маркса, 52, телефон: 4-56-03	Россия, Краснодарский край, Новокубанский район, город Новокубанск	0101000020E6100000B2DAFCBFEA844440535C55F65D8D4640
46166	2	20	\N	50329	\N	\N	44.605612000000001	п. Мирный, Здание сельского клуба, телефон: 57-3-10		0101000020E6100000876BB587BD8043405708ABB1844D4640
45908	2	20	\N	5827	21147	\N	44.741866999999999	город Новороссийск, Сакко и Ванцетти, 23, телефон: 60-40-87	Россия, Краснодарский край, поселок Мефодиевка, улица Сакко и Ванцетти, 21	0101000020E6100000CE35CCD078E44240A67D737FF55E4640
45905	2	20	\N	5827	21147	\N	44.742967999999998	город Новороссийск, Сакко и Ванцетти, 6, телефон: 60-47-00	Россия, Краснодарский край, поселок Мефодиевка, улица Сакко и Ванцетти, 4	0101000020E6100000FEEDB25F77E44240BDFC4E93195F4640
44490	2	20	\N	50462	22082	\N	45.031368000000001	Краснодарский край, город Армавир, п.Маяк, ул.Восточная, 10, телефон: 38240		0101000020E6100000FA7C9411177844400A12DBDD03844640
44734	2	20	\N	50248	20463	\N	44.760750000000002	станица Мартанская, Красная, 36, телефон: 5-33-47		0101000020E6100000207A522635B843404C37894160614640
45767	2	20	\N	50783	23587	\N	45.012634961099302	хутор Ленина, Казачья, 2, телефон: 4-62-45	Россия, Краснодарский край, Краснодар, поселок Ленина, улица Казачья, 2	0101000020E61000003B8DB454DE9A43407AE40F069E814640
45303	2	20	\N	50856	23886	\N	45.153011999999997	поселок Лазурный, Октябрьская, 1, телефон: 228-41-90		0101000020E61000007C60C77F81904340A1F2AFE595934640
45697	2	20	\N	50405	21673	\N	44.641345999999999	город Лабинск, Халтурина, 14, телефон: 32910		0101000020E6100000AA99B514905C4440D0B52FA017524640
45631	2	20	\N	50405	21709	\N	44.641345999999999	город Лабинск, Турчанинова, 65, телефон: 32857		0101000020E6100000AA99B514905C4440D0B52FA017524640
45690	2	20	\N	50405	21825	\N	44.6350155907963	город Лабинск, Победы, 268, телефон: 34390		0101000020E6100000DC7EF964C55E4440E7374C3448514640
45691	2	20	\N	50405	21945	\N	44.6413859078475	город Лабинск, Константинова, 89, телефон: 26708		0101000020E61000000725CCB4FD5D44405E0EBBEF18524640
45703	2	20	\N	50405	21795	\N	44.645750281624601	город Лабинск, Ватутина, 11, телефон: 68698		0101000020E6100000ADF71BEDB85B44402DB29DEFA7524640
45586	2	20	\N	50392	22182	\N	44.888172371960799	город Курганинск, Мира, 107, телефон: 2-19-06		0101000020E61000002288F370024B4440889CBE9EAF714640
45589	2	20	\N	50392	22261	\N	44.877970429883703	город Курганинск, Ленина, 369, телефон: 2-25-30	Россия, Краснодарский край, Курганинский район, город Курганинск	0101000020E6100000E014562AA84C44403F6F2A5261704640
45579	2	20	\N	50392	21588	\N	44.886830000000003	город Курганинск, Крупской, 1, телефон: 2-95-74		0101000020E610000084674293C44A44404C8E3BA583714640
44722	2	20	\N	50299	20908	\N	44.488264999999998	хутор Кура-Цеце, Октябрьская, 20, телефон: 4-85-62		0101000020E61000005567B5C01EAB43400664AF777F3E4640
44604	2	20	\N	50286	20779	\N	45.064259999999997	хутор Кубань, Центральная, 14, телефон: 52191	Россия, Краснодарский край, Краснодар, учебное хозяйство Кубань, улица Советская	0101000020E6100000471D1D57237143407138F3AB39884640
45523	2	20	\N	50444	21942	\N	44.918024000000003	город Крымск, Темченко, 18, телефон: 4-74-72		0101000020E6100000F81C588E90FF4240B87878CF81754640
3759	1	16	1223	23289	25323	\N	54.081986000000001	г. Болохово, Мира, 6		0101000020E61000004EB4AB90F2E942406C5D6A847E0A4B40
45524	2	20	\N	50444	22352	\N	44.918648639441003	город Крымск, Жукова, 35, телефон: 5-24-10	Россия, Краснодарский край, Крымский район, город Крымск	0101000020E6100000371B2B31CF00434066C0594A96754640
45528	2	20	\N	50444	21966	\N	44.943231630842497	город Крымск, Авиационная, 2, телефон: 2-35-43		0101000020E6100000E0BBCD1B27014340354580D3BB784640
45441	2	20	\N	50476	23395	\N	45.441760497032	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Черноморская, 79, телефон: 6-40-03	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E61000002D7AA702EE4744402A5778978BB84640
45471	2	20	\N	50476	22227	\N	45.4409661607869	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.С.Целых, 258, телефон: 7-20-17		0101000020E610000055DFF945094A4440F052EA9271B84640
45445	2	20	\N	50476	22882	\N	45.441336954712398	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Пушкина, 79, телефон: 6-34-01	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E610000017EFC7ED97494440E3C116BB7DB84640
45437	2	20	\N	50476	22882	\N	45.435657590919	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Пушкина, 82, телефон: 9-35-89		0101000020E610000057790261A74C4440D11E2FA4C3B74640
45439	2	20	\N	50476	23304	\N	45.440503792512096	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Мира, 146, телефон: 7-49-70		0101000020E61000006A87BF266B484440EBE0606F62B84640
45455	2	20	\N	50476	23506	\N	45.438766129317003	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Линейная, 13, телефон: 6-33-57		0101000020E610000093FDF33460484440624CFA7B29B84640
45454	2	20	\N	50476	22767	\N	45.438521807586099	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красная, 164, телефон: 7-11-41		0101000020E61000003CDD79E239494440CB49287D21B84640
45452	2	20	\N	50476	22767	\N	45.437047420045097	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красная, 166, телефон: 7-00-15		0101000020E6100000EEB43522184944404FE8F527F1B74640
45450	2	20	\N	50476	22767	\N	45.432515241530901	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красная, 234, телефон: 7-09-70		0101000020E61000009757AEB7CD464440C503CAA65CB74640
45449	2	20	\N	50476	22767	\N	45.434146868004397	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красная, 234, телефон: 7-06-13		0101000020E61000002AAA7EA5F34744400954FF2092B74640
45283	2	20	\N	50242	20429	\N	45.074534	поселок Пригородный, улица Сербская, дом 7, телефон: 2607677	Россия, Краснодарский край, Краснодар, поселок Пригородный, улица Донбасская	0101000020E61000001DCC26C0B0984340543882548A894640
45190	2	20	\N	242	5237	\N	45.053012801734702	город Краснодар, Гагарина, 135/1, телефон: 226-23-72, 226-34-12	Россия, Краснодарский край, Краснодар, улица космонавта Гагарина, 135к1	0101000020E6100000620FED63057B4340A5A14621C9864640
46646	2	20	\N	242	4749	\N	45.048526000000003	Краснодарский край, Тихорецкий район, станица Новоархангельская, улица Энгельса, 23, телефон: 94-3-88	Россия, Краснодарский край, Краснодар, улица Энгельса, 96	0101000020E6100000D2AB014A43794340BB80971936864640
45194	2	20	\N	242	4749	\N	45.044234000000003	город Краснодар, Энгельса, 57, телефон: 220-66-38, 255-93-54	Россия, Краснодарский край, Краснодар, улица Энгельса, 57	0101000020E6100000A0DD21C50079434086AFAF75A9854640
45348	2	20	\N	242	15429	\N	45.049787000000002	станица Елизаветинскаая, Широкая, 231, телефон: 229-13-35	Россия, Краснодарский край, Краснодар, деревня Елизаветинская, улица Широкая, 231	0101000020E6100000E5B9BE0F076743400B62A06B5F864640
45308	2	20	\N	242	16525	\N	45.173987889545003	хутор Копанской, Центральная, 16/2, телефон: 229-90-25	Россия, Краснодарский край, Краснодар, поселок Копанской, улица Центральная	0101000020E610000015E63DCE34674340BFF2203D45964640
45182	2	20	\N	242	5135	\N	45.0689668368856	город Краснодар, Федора Лузана, 1, телефон: 224-96-28, 224-01-18(день голосования)	Россия, Краснодарский край, Краснодар, улица Федора Лузана	0101000020E610000013D731AEB87C43406AC020E9D3884640
45196	2	20	\N	242	5320	\N	45.050211751627202	город Краснодар, Урицкого, 185, телефон: 220-63-89	Россия, Краснодарский край, Краснодар, улица Урицкого, 181а	0101000020E61000008202EFE4D3774340F2EEC8586D864640
45271	2	20	\N	242	6165	\N	45.005066999999997	город Краснодар, улица Трудовой Славы, дом 28, телефон: 2370356	Россия, Краснодарский край, Краснодар, улица Трудовой Славы, 28	0101000020E6100000E60819C8B3894340F8A41309A6804640
44291	2	20	\N	242	16089	\N	45.041043000000002	х.Первомайский, Труда, 10, телефон: 3-25-39	Россия, Краснодарский край, Краснодар, Западный район, улица Труда, 16	0101000020E6100000BDE2A9471A784340685DA3E540854640
45300	2	20	\N	242	6452	\N	45.110632000000003	город Краснодар, Тепличная, 16, телефон: 228-87-51	Россия, Краснодарский край, Краснодар, улица Тепличная, 16	0101000020E61000002D3F7095278243400FF27A30298E4640
45339	2	20	\N	242	6821	\N	45.065215000000002	город Краснодар, Темрюкская, 68, телефон: 222-28-35	Россия, Краснодарский край, Краснодар, улица Темрюкская, 68	0101000020E61000000DE198654F764340B51A12F758884640
44982	2	20	\N	242	2543	\N	45.024062000000001	Краснодарский край, Каневский район, Таманская, 182, телефон: 7-31-16	Россия, Краснодарский край, Краснодар, улица Таманская, 184	0101000020E61000003F52448655824340C689AF7614834640
46847	2	20	\N	242	20446	\N	45.0142287035424	х. Красный, Степная, 65, телефон: 75-6-32	Россия, Краснодарский край, Краснодар, Центральный район, улица Степная, 65	0101000020E610000003CE52B29C824340D0D38041D2814640
45272	2	20	\N	242	23884	\N	45.005066999999997	город Краснодар, улица Трудовой Славы, дом 28, телефон: 2375791		0101000020E6100000E60819C8B3894340F8A41309A6804640
45388	2	20	\N	242	5589	\N	45.017034000000002	город Краснодар, Ставропольская, 236/А, телефон: 2331558	Россия, Краснодарский край, Краснодар, улица Ставропольская, 236	0101000020E610000058FE7C5BB0844340C5758C2B2E824640
45219	2	20	\N	242	5589	\N	45.022654000000003	город Краснодар, улица Ставропольская, дом 123г, телефон: 2333251	Россия, Краснодарский край, Краснодар, улица Ставропольская, 123г	0101000020E61000006344A2D0B2824340D28F8653E6824640
45262	2	20	\N	242	5778	\N	45.039152000000001	город Краснодар, улица Сормовская, дом 187, телефон: 2360965	Россия, Краснодарский край, Краснодар, улица Сормовская, 187	0101000020E61000001ABFF04A928D434058C9C7EE02854640
45261	2	20	\N	242	5778	\N	45.039152000000001	город Краснодар, улица Сормовская, дом 187, телефон: 2322620	Россия, Краснодарский край, Краснодар, улица Сормовская, 187	0101000020E61000001ABFF04A928D434058C9C7EE02854640
45337	2	20	\N	242	6798	\N	45.064743	город Краснодар, Славянская, 65, телефон: 222-17-79	Россия, Краснодарский край, Краснодар, улица Славянская, 65	0101000020E6100000B6F5D37FD67643408DD2A57F49884640
45816	2	20	\N	242	15672	\N	45.029724999999999	п.Мирский, ул.Садовая, 1/2, телефон: 2-96-59	Россия, Краснодарский край, Краснодар, Центральный район, улица Садовая, 11	0101000020E6100000B58D3F51D97E4340D26F5F07CE834640
45184	2	20	\N	242	5042	\N	45.067996000000001	город Краснодар, Рашпилевская, 341, телефон: 224-54-09	Россия, Краснодарский край, Краснодар, улица Рашпилевская, 341	0101000020E610000084BA48A12C7C43402121CA17B4884640
46327	2	20	\N	242	15932	\N	45.010573000000001	микрорайон Лазаревское, Пугачева, 15, телефон: 70-92-97	Россия, Краснодарский край, Краснодар, улица Пугачева, 21	0101000020E610000015FE0C6FD68243403D9CC0745A814640
45249	2	20	\N	242	16247	\N	45.056052999999999	поселок Знаменский, улица Первомайская, дом 20, телефон: 2699940	Россия, Краснодарский край, Краснодар, поселок Знаменский, улица Первомайская, 20	0101000020E610000023DA8EA9BB924340DDEBA4BE2C874640
45867	2	20	\N	242	15449	\N	45.035133000000002	ст.Советская, ул.Октябрьская, 167, телефон: 5-64-05	Россия, Краснодарский край, Краснодар, Западный район, улица Октябрьская, 165	0101000020E61000006EC0E787117C43405401F73C7F844640
45160	2	20	\N	242	15449	\N	45.022787000000001	город Краснодар, Октябрьская, 67, телефон: 268-41-82	Россия, Краснодарский край, Краснодар, Западный район, улица Октябрьская, 67	0101000020E6100000CC79C6BE647B434011E335AFEA824640
45415	2	20	\N	242	4189	\N	45.050730000000001	город Краснодар, Московская, 2/3, телефон: 2596161	Россия, Краснодарский край, Краснодар, улица Московская, 2	0101000020E6100000FA47DFA4698043408A7615527E864640
45250	2	20	\N	242	23502	\N	45.019425208991301	хутор Ленина, улица Молодежная, дом 37, телефон: 2347429	Россия, Краснодарский край, Краснодар, поселок Ленина, улица Молодежная, 43а	0101000020E6100000A0E062450D9C4340C6DCB5847C824640
45402	2	20	\N	242	15891	\N	45.019908000000001	город Краснодар, Мира, 52, телефон: 2685526	Россия, Краснодарский край, Краснодар, Центральный район, улица Мира, 52	0101000020E61000008410902FA17C4340E27668588C824640
46853	2	20	\N	242	15379	\N	45.024571000000002	х. Братский, Ленина, 28, телефон: 79-2-76	Россия, Краснодарский край, Краснодар, Центральный район, улица Ленина, 26	0101000020E61000008FFCC1C0737B43400BB77C2425834640
46766	2	20	\N	242	15379	\N	45.025016999999998	поселок УЗК, Ленина, 8 а, телефон: 96190	Россия, Краснодарский край, Краснодар, Центральный район, улица Ленина, 10	0101000020E6100000EE056685227B4340096CCEC133834640
46119	2	20	\N	242	15379	\N	45.023054999999999	ст. Азовская, Ленина, 61, телефон: 51-2-68	Россия, Краснодарский край, Краснодар, Центральный район, улица Ленина, 65	0101000020E6100000026553AEF07C434030815B77F3824640
45084	2	20	\N	242	15379	\N	45.024360999999999	Верхний хутор, Ленина, 34, телефон: 21-1-32	Россия, Краснодарский край, Краснодар, Центральный район, улица Ленина, 32	0101000020E610000051A2258FA77B43402026E1421E834640
44690	2	20	\N	242	15379	\N	45.023525999999997	с. Марьина Роща, Ленина, 42а, телефон: 26824	Россия, Краснодарский край, Краснодар, Центральный район, улица Ленина, 42	0101000020E610000061FBC9181F7C4340874D64E602834640
44788	2	20	\N	242	23389	\N	45.024070069700699	пос. Новоивановка, ул. Ленина, (здание клуба), 36, телефон: 9-74-17	Россия, Краснодарский край, Краснодар, Центральный район, улица Ленина, 36к2	0101000020E61000000A9E42AED47B43404968CBB914834640
46636	2	20	\N	242	67	\N	45.021061000000003	хутор Ленинский, Красная, 38, телефон: 3-92-41, 3-91-14	Россия, Краснодарский край, Краснодар, улица Красная, 40	0101000020E61000002174D0251C7C43404C1C7920B2824640
45344	2	20	\N	242	67	\N	45.016773000000001	"город Краснодар, ""Учебно-опытное хозяйство ""Кубань"", Красная, 10, телефон: 228-30-74"	Россия, Краснодарский край, Краснодар, улица Красная, 8	0101000020E6100000156F641EF97B4340583A1F9E25824640
45306	2	20	\N	242	6495	\N	45.064641999999999	город Краснодар, Карякина, 8, телефон: 257-08-32	Россия, Краснодарский край, Краснодар, улица Карякина, 8	0101000020E6100000CBD93BA3AD80434059F9653046884640
45157	2	20	\N	242	4826	\N	45.009718999999997	город Краснодар, Индустриальная, 68, телефон: 268-79-61	Россия, Краснодарский край, Краснодар, улица Индустриальная, 68	0101000020E6100000CD237F30F07A43402D93E1783E814640
45288	2	20	\N	242	23410	\N	45.185788000000002	хутор Октябрьский, Заречная, 9, телефон: 213-08-72	Россия, Краснодарский край, Краснодар, поселок Октябрьский, улица Заречная, 1	0101000020E61000000AF5F411F8894340A0FEB3E6C7974640
45312	2	20	\N	242	15368	\N	45.124820036201598	город Краснодар, Дорожная, 1, телефон: 225-96-11	Россия, Краснодарский край, Краснодар, улица Дорожная, 1	0101000020E61000004298DBBDDC7D434080F10C1AFA8F4640
45417	2	20	\N	242	23759	\N	45.050455999999997	город Краснодар, Садовая, 245, телефон: 2542138		0101000020E6100000AC38D55A987F434088F19A5775864640
44986	2	20	\N	242	2601	\N	45.032533999999998	Краснодарский край, Каневский район, Длинная, 184, телефон: 7-43-47	Россия, Краснодарский край, Краснодар, улица Длинная, 180	0101000020E6100000C1C93670077E43400801F9122A844640
45377	2	20	\N	242	7205	\N	45.001167000000002	город Краснодар, Воронежская, 47, телефон: 2100292	Россия, Краснодарский край, Краснодар, улица Воронежская, 47	0101000020E6100000DDB1D82615834340CF6A813D26804640
45427	2	20	\N	242	7748	\N	45.029496000000002	город Краснодар, Володарского, 5, телефон: 2754377	Россия, Краснодарский край, Краснодар, улица Володарского, 5	0101000020E61000001616DC0F7880434071AE6186C6834640
45386	2	20	\N	242	4087	\N	45.013460000000002	город Краснодар, Бургасская, 29, телефон: 2334844	Россия, Краснодарский край, Краснодар, улица Бургасская, 29	0101000020E6100000D6E5948098844340EFE6A90EB9814640
45381	2	20	\N	242	4087	\N	45.011586000000001	город Краснодар, Бургасская, 65, телефон: 2338885	Россия, Краснодарский край, Краснодар, улица Бургасская, 65	0101000020E610000098DBBDDC27854340B58B69A67B814640
45334	2	20	\N	242	6693	\N	45.059873000000003	город Краснодар, Атарбекова, 5/1, телефон: 226-84-71	Россия, Краснодарский край, Краснодар, улица Атарбекова, 5	0101000020E6100000CFBEF2203D794340EB7420EBA9874640
45284	2	20	\N	242	21113	\N	45.050008785393203	поселок Знаменский, улица Андреевская, дом 1, телефон: 2609399	Россия, Краснодарский край, Краснодар, Карасунский район, улица Андреевская	0101000020E61000008D463EAF78904340BAC0E5B166864640
45204	2	20	\N	242	5371	\N	45.037260000000003	город Краснодар, им. 70-летия Октября, 30, телефон: 261-74-25	Россия, Краснодарский край, Краснодар, улица 70-летия Октября, 30	0101000020E6100000739F1C058874434078B988EFC4844640
45298	2	20	\N	242	15702	\N	45.068263999999999	город Краснодар, 1-го Мая, 298а, телефон: 252-83-18	Россия, Краснодарский край, Краснодар, Прикубанский район, улица 1-го Мая, 298а	0101000020E6100000815CE2C80383434040BFEFDFBC884640
45201	2	20	\N	242	23955	\N	45.035916	город Краснодар, им. 70-летия Октября, 28, телефон: 261-85-02, 261-74-76(день голосования)		0101000020E610000048A5D8D1387443409AB33EE598844640
45325	2	20	\N	242	23727	\N	45.061751000000001	город Краснодар, Яна Полуяна, 40, телефон: 226-54-76		0101000020E6100000111956F1467A434066BFEE74E7874640
45324	2	20	\N	242	23727	\N	45.061751000000001	город Краснодар, Яна Полуяна, 40, телефон: 226-20-19		0101000020E6100000111956F1467A434066BFEE74E7874640
45899	2	20	\N	242	23381	\N	45.185755211979497	х. Октябрьский, Южная, телефон: 59-7-26	Россия, Краснодарский край, Краснодар, поселок Октябрьский, улица Подсолнечная	0101000020E61000007D24253D0C8B4340C408E1D1C6974640
45195	2	20	\N	242	23901	\N	45.044234000000003	город Краснодар, Энгельса, 57, телефон: 255-91-98		0101000020E6100000A0DD21C50079434086AFAF75A9854640
46769	2	20	\N	242	23375	\N	45.181615000000001	п.Октябрьский, Школьная, 10, телефон: 96425		0101000020E61000004D327216F68A434045BB0A293F974640
45394	2	20	\N	242	23839	\N	45.011746000000002	город Краснодар, Шевченко, 2, телефон: 2397256		0101000020E61000006552431B80814340EEED96E480814640
45393	2	20	\N	242	23839	\N	45.016295	город Краснодар, Шевченко, 56, телефон: 2396064		0101000020E6100000DC48D922698143404E0B5EF415824640
45240	2	20	\N	242	23839	\N	45.016295	город Краснодар, улица Шевченко, дом 56, телефон: 2375524		0101000020E6100000DC48D922698143404E0B5EF415824640
45165	2	20	\N	242	23667	\N	45.034323999999998	город Краснодар, Чкалова, 75, телефон: 253-20-29, 253-03-81		0101000020E6100000B56FEEAF1E7B4340E4BB94BA64844640
45211	2	20	\N	242	5350	\N	45.028489	город Краснодар, проспект Чекистов, 18, телефон: 265-15-70	Россия, Краснодарский край, Краснодар, Чекистов проспект, 18	0101000020E6100000AD18AE0E80744340DBA50D87A5834640
45210	2	20	\N	242	5350	\N	45.033591000000001	город Краснодар, Проспект Чекистов, 31, телефон: 261-73-29	Россия, Краснодарский край, Краснодар, Чекистов проспект, 31	0101000020E6100000ACFE08C3807543405038BBB54C844640
45200	2	20	\N	242	5350	\N	45.028489	город Краснодар, Проспект Чекистов, 18, телефон: 265-15-72	Россия, Краснодарский край, Краснодар, Чекистов проспект, 18	0101000020E6100000AD18AE0E80744340DBA50D87A5834640
45199	2	20	\N	242	5350	\N	45.028489	город Краснодар, Проспект Чекистов, 18, телефон: 265-15-71	Россия, Краснодарский край, Краснодар, Чекистов проспект, 18	0101000020E6100000AD18AE0E80744340DBA50D87A5834640
45404	2	20	\N	242	23585	\N	45.029783193628901	город Краснодар, Чапаева, 85/1, телефон: 2594687	Россия, Краснодарский край, Краснодар, улица Чапаева, 85а	0101000020E61000001684F23E8E7C4340077DE9EDCF834640
45410	2	20	\N	242	23905	\N	45.042476000000001	город Краснодар, Хакурате, 5, телефон: 2533909		0101000020E6100000A565A4DE537D4340B56E83DA6F854640
45342	2	20	\N	242	22011	\N	45.035324726758503	город Краснодар, здание корпуса  КМЦУ ГНУ КНИИСХ Россельхозакадемии, центральная усадьба, телефон: 222-69-65		0101000020E610000017450F7C0C82434098DD938785844640
45287	2	20	\N	242	22011	\N	45.037050000000001	город Краснодар, Филатова, 17, телефон: 275-90-05		0101000020E6100000F5A276BF0A8243408D28ED0DBE844640
45183	2	20	\N	242	23253	\N	45.0689744396526	город Краснодар, Федора Лузана, 1, телефон: 225-34-35 (день голосования), 224-96-28		0101000020E61000002F88484DBB7C43401C23D923D4884640
45244	2	20	\N	242	24000	\N	45.024355	город Краснодар, улица Фадеева, дом 329, телефон: 2278107		0101000020E6100000EECD6F98688E43403E3F8C101E834640
45367	2	20	\N	242	23655	\N	45.074539999999999	город Краснодар, Уссурийская, 2, телефон: 228-89-97		0101000020E6100000492A53CC41824340361FD7868A894640
45359	2	20	\N	242	23655	\N	45.074539999999999	город Краснодар, Уссурийская, 2, телефон: 228-96-53		0101000020E6100000492A53CC41824340361FD7868A894640
45299	2	20	\N	242	23655	\N	45.074539999999999	город Краснодар, Уссурийская, 2, телефон: 228-96-54		0101000020E6100000492A53CC41824340361FD7868A894640
45282	2	20	\N	242	23670	\N	45.042368000000003	город Краснодар, улица Уральская, дом 196, телефон: 2366882		0101000020E6100000677E3507088E4340CF328B506C854640
45251	2	20	\N	242	23670	\N	45.041305000000001	город Краснодар, улица Уральская, дом 121, телефон: 2366476		0101000020E6100000B532E197FA8B4340A514747B49854640
45369	2	20	\N	242	23778	\N	45.111819214895398	город Краснодар, Тепличная, 11, телефон: 228-89-96	Россия, Краснодарский край, Краснодар, улица Тепличная, 11	0101000020E6100000CDC82077118243402409C215508E4640
45355	2	20	\N	242	23778	\N	45.111871999999998	город Краснодар, Тепличная, 11, телефон: 228-81-30		0101000020E61000001762F5471882434047AB5AD2518E4640
45338	2	20	\N	242	23852	\N	45.065215000000002	город Краснодар, Темрюкская, 68, телефон: 222-91-80		0101000020E61000000DE198654F764340B51A12F758884640
45392	2	20	\N	242	23795	\N	45.019545000000001	город Краснодар, Таманская, 137, телефон: 2397304		0101000020E61000002FF99FFCDD81434071E6577380824640
45181	2	20	\N	242	5123	\N	45.114117	город Краснодар, Строителей, 23, телефон: 224-97-27	Россия, Краснодарский край, Краснодар, Строителей бульвар, 29	0101000020E610000082531F48DE8143407575C7629B8E4640
45302	2	20	\N	242	23721	\N	45.09299	поселок Индустриальный, Степная, 10, телефон: 251-55-60		0101000020E61000001FF64201DB8D4340726DA818E78B4640
45387	2	20	\N	242	23861	\N	45.018168000000003	город Краснодар, Степана Разина, 51, телефон: 2336652		0101000020E61000009148DBF813834340B8EA3A5453824640
45285	2	20	\N	242	23875	\N	45.024940999999998	город Краснодар, улица Стасова, дом 175, телефон: 2314580		0101000020E610000059A48977808543402EAA454431834640
45233	2	20	\N	242	23875	\N	45.024940999999998	город Краснодар, улица Стасова, дом 175, телефон: 2314684		0101000020E610000059A48977808543402EAA454431834640
45227	2	20	\N	242	23875	\N	45.021144	город Краснодар, улица Стасова, дом 167, телефон: 2312440		0101000020E6100000AEB8382A37854340D940BAD8B4824640
45226	2	20	\N	242	23645	\N	45.019137000000001	город Краснодар, улица Старокубанская, дом 127, телефон: 2313878		0101000020E6100000EFE53E390A8643406092CA1473824640
45395	2	20	\N	242	23757	\N	45.019652999999998	город Краснодар, Ставропольская, 130, телефон: 2397334		0101000020E6100000802A6EDC62804340572250FD83824640
45223	2	20	\N	242	23757	\N	45.019634000000003	город Краснодар, улица Ставропольская, дом 149, телефон: 2199592		0101000020E610000097E5EB32FC834340E1F1ED5D83824640
45220	2	20	\N	242	23757	\N	45.022654000000003	город Краснодар, улица Ставропольская, дом 123г, телефон: 2333428		0101000020E61000006344A2D0B2824340D28F8653E6824640
45281	2	20	\N	242	23594	\N	45.026845999999999	город Краснодар, улица Сормовская, дом 25, телефон: 2321210		0101000020E61000007369FCC22B894340A30392B06F834640
45264	2	20	\N	242	23594	\N	45.039864999999999	город Краснодар, улица Сормовская, дом 199, телефон: 2367313		0101000020E6100000EF8D2100388E4340A5A0DB4B1A854640
45263	2	20	\N	242	23594	\N	45.039864999999999	город Краснодар, улица Сормовская, дом 199, телефон: 2361039		0101000020E6100000EF8D2100388E4340A5A0DB4B1A854640
45257	2	20	\N	242	23594	\N	45.034928999999998	город Краснодар, улица Сормовская, дом 167, телефон: 2603419		0101000020E610000066BFEE74E78B43404B57B08D78844640
45256	2	20	\N	242	23594	\N	45.0329978050843	город Краснодар, улица Сормовская, дом 171, телефон: 2328581		0101000020E61000000E164ED2FC8B4340AD6A494739844640
45255	2	20	\N	242	23594	\N	45.032921729208297	город Краснодар, улица Сормовская, дом 171, телефон: 2367526	Россия, Краснодарский край, Краснодар, улица Сормовская	0101000020E610000016C09481038C4340D2A8C0C936844640
45253	2	20	\N	242	23594	\N	45.033985999999999	город Краснодар, улица Сормовская, дом 169, телефон: 2327495		0101000020E6100000828DEBDFF58B4340CC423BA759844640
45252	2	20	\N	242	23594	\N	45.033985999999999	город Краснодар, улица Сормовская, дом 169, телефон: 2328854		0101000020E6100000828DEBDFF58B4340CC423BA759844640
45237	2	20	\N	242	23594	\N	45.0304	город Краснодар, улица Сормовская, дом 107, телефон: 2360818		0101000020E610000098689082A78A434032E6AE25E4834640
45236	2	20	\N	242	23594	\N	45.026845999999999	город Краснодар, улица Сормовская, дом 25, телефон: 2321760		0101000020E61000007369FCC22B894340A30392B06F834640
45235	2	20	\N	242	23594	\N	45.023463	город Краснодар, улица Сормовская, дом 12/6, телефон: 2346496		0101000020E61000002140868E1D88434041D5E8D500834640
45234	2	20	\N	242	23594	\N	45.024011000000002	город Краснодар, улица Сормовская, дом 5, телефон: 2796495		0101000020E610000093FFC9DFBD87434044DFDDCA12834640
45350	2	20	\N	242	23829	\N	45.0503659959736	станица Елизаветинская, Советская, 62, телефон: 229-13-68		0101000020E6100000588E90813C654340486AA16472864640
45349	2	20	\N	242	23829	\N	45.047514863921997	станица Елизаветинская, Советская, 26, телефон: 229-00-35	Россия, Краснодарский край, Краснодар, деревня Елизаветинская, улица Ленина	0101000020E61000009D7FBBECD7654340E388B5F814864640
45354	2	20	\N	242	23663	\N	45.063209000000001	город Краснодар, Славянская, 63, телефон: 222-07-17		0101000020E610000068AF3E1EFA7643400CE8853B17884640
45336	2	20	\N	242	23663	\N	45.063209000000001	город Краснодар, Славянская, 63, телефон: 222-84-89		0101000020E610000068AF3E1EFA7643400CE8853B17884640
45335	2	20	\N	242	23663	\N	45.064922000000003	город Краснодар, Славянская, 28, телефон: 222-12-83		0101000020E6100000246420CF2E7743403D65355D4F884640
45229	2	20	\N	242	23872	\N	45.027731000000003	город Краснодар, улица Селезнева, дом 4, телефон: 2271417		0101000020E61000006902452C62824340EE0A7DB08C834640
45228	2	20	\N	242	23872	\N	45.025222561856197	город Краснодар, улица Селезнева, дом 86, телефон: 2331523	Россия, Краснодарский край, Краснодар, улица Селезнева, 86	0101000020E6100000F5F3A62215844340B20DDC813A834640
45224	2	20	\N	242	23872	\N	45.015996000000001	город Краснодар, улица Селезнева, дом 242, телефон: 2315538		0101000020E610000037E15E99B7864340F46E2C280C824640
45420	2	20	\N	242	23809	\N	45.039310999999998	город Краснодар, Северная, 309, телефон: 2530414		0101000020E6100000C2A6CEA3E27D4340C0AF912408854640
45171	2	20	\N	242	23809	\N	45.041553	город Краснодар, Северная, 269, телефон: 259-06-00		0101000020E61000000E846401137C43407D06D49B51854640
45169	2	20	\N	242	23809	\N	45.043061999999999	город Краснодар, Северная, 255, телефон: 255-22-30		0101000020E6100000570A815CE27A4340A5D93C0E83854640
45385	2	20	\N	242	23789	\N	45.009267000000001	город Краснодар, Свободная, 51, телефон: 2337680		0101000020E61000009702D2FE078443404DF73AA92F814640
45382	2	20	\N	242	23789	\N	45.009267000000001	город Краснодар, Свободная, 51, телефон: 2336725		0101000020E61000009702D2FE078443404DF73AA92F814640
45421	2	20	\N	242	23759	\N	45.040329999999997	город Краснодар, Садовая, 112, телефон: 2541976		0101000020E6100000AA0B7899617F43401A868F8829854640
45191	2	20	\N	242	23683	\N	45.048501000000002	город Краснодар, Рылеева, 147, телефон: 221-35-39		0101000020E6100000C59272F7397A43406269E04735864640
45295	2	20	\N	242	23339	\N	45.060032	город Краснодар, Российская, 132, телефон: 257-50-72		0101000020E61000000CAD4ECE50824340535BEA20AF874640
45293	2	20	\N	242	23339	\N	45.046629000000003	город Краснодар, Российская, 10, телефон: 252-69-10		0101000020E61000000AD6389B8E824340C90567F0F7854640
45289	2	20	\N	242	23339	\N	45.046629000000003	город Краснодар, Российская, 10, телефон: 252-93-80		0101000020E61000000AD6389B8E824340C90567F0F7854640
45364	2	20	\N	242	7053	\N	45.075769000000001	город Краснодар, проезд Репина, 5, телефон: 224-77-83		0101000020E6100000C1E3DBBB067D43407B8670CCB2894640
45185	2	20	\N	242	23688	\N	45.066761	город Краснодар, Рашпилевская, 329, телефон: 224-01-73		0101000020E6100000331AF9BCE27B4340FAD2DB9F8B884640
45174	2	20	\N	242	23688	\N	45.045577999999999	город Краснодар, Рашпилевская, 134, телефон: 255-59-64		0101000020E610000078616BB6F27C434063B5F97FD5854640
46503	2	20	\N	242	21623	\N	45.181615000000001	поселок Октябрьский, улица Псурцева, дом 20, телефон: 6 91 72		0101000020E61000004D327216F68A434045BB0A293F974640
45205	2	20	\N	242	5397	\N	45.035356	город Краснодар, Бульвар Платановый, 3, телефон: 261-87-77	Россия, Краснодарский край, Краснодар, Платановый бульвар, 3	0101000020E610000079909E2287744340D3DB9F8B86844640
45203	2	20	\N	242	5397	\N	45.035356	город Краснодар, Бульвар Платановый, 3, телефон: 261-70-04	Россия, Краснодарский край, Краснодар, Платановый бульвар, 3	0101000020E610000079909E2287744340D3DB9F8B86844640
45390	2	20	\N	242	23793	\N	45.012740000000001	город Краснодар, Пионерская, 38, телефон: 2271635		0101000020E6100000EBFD463B6E824340EFACDD76A1814640
45156	2	20	\N	242	23675	\N	45.007744000000002	город Краснодар, Песчаная, 14, телефон: 268-86-96		0101000020E6100000AB97DF69327B4340C05E61C1FD804640
45153	2	20	\N	242	23675	\N	45.007744000000002	город Краснодар, Песчаная, 14, телефон: 268-87-03		0101000020E6100000AB97DF69327B4340C05E61C1FD804640
45424	2	20	\N	242	24024	\N	45.030540000000002	город Краснодар, Пашковская, 146, телефон: 2596618		0101000020E6100000ADFC3218237E4340249C16BCE8834640
45158	2	20	\N	242	23895	\N	45.016544000000003	город Краснодар, Октябрьская, 25 А, телефон: 268-58-79		0101000020E610000078EC67B1147B4340F778211D1E824640
45155	2	20	\N	242	23895	\N	45.013582198616596	город Краснодар, Октябрьская, 1, телефон: 262-88-37	Россия, Краснодарский край, Краснодар, улица Красина, 5	0101000020E6100000F6F065A2087B43403AE8120EBD814640
45175	2	20	\N	242	23740	\N	45.051048000000002	город Краснодар, Одесская, 25, телефон: 255-21-99		0101000020E6100000658EE55DF57C43405B43A9BD88864640
45231	2	20	\N	242	23696	\N	45.032768507330303	город Краснодар, улица Новгородская, дом 16, телефон: 2342535	Россия, Краснодарский край, Краснодар, улица Новгородская, 16	0101000020E61000009F5BE84A048443404CA94BC631844640
45230	2	20	\N	242	23696	\N	45.032814000000002	город Краснодар, улица Новгородская, дом 16, телефон: 2342533		0101000020E6100000B7B75B9203844340EC6CC83F33844640
45416	2	20	\N	242	20541	\N	45.050730000000001	город Краснодар, Московская, 2, телефон: 2594938		0101000020E6100000FA47DFA4698043408A7615527E864640
45304	2	20	\N	242	20541	\N	45.059089999999998	город Краснодар, Московская, 42, телефон: 252-13-00		0101000020E6100000E884D04197804340A4C2D84290874640
45426	2	20	\N	242	23699	\N	45.022137999999998	город Краснодар, Седина, 38, телефон: 2624493		0101000020E6100000EE974F560C7D4340DAFF006BD5824640
45399	2	20	\N	242	23689	\N	45.019008999999997	город Краснодар, Мира, 65, телефон: 2620095		0101000020E6100000EA23F0879F7D434032AA0CE36E824640
45757	2	20	\N	242	20550	\N	45.181615000000001	пос. Октябрьский, Мира, 13, телефон: 4-56-60		0101000020E61000004D327216F68A434045BB0A293F974640
45112	2	20	\N	242	20550	\N	45.181615000000001	поселок Октябрьский, ул.Мира, 15, телефон: 91-3-79		0101000020E61000004D327216F68A434045BB0A293F974640
44720	2	20	\N	242	20550	\N	45.181615000000001	поселок Октябрьский, Мира, 34 А, телефон: 4-65-10		0101000020E61000004D327216F68A434045BB0A293F974640
45198	2	20	\N	242	23715	\N	45.039107000000001	город Краснодар, Минская, 126, телефон: 221-01-53		0101000020E6100000791EDC9DB5774340B8054B7501854640
45197	2	20	\N	242	23715	\N	45.039107000000001	город Краснодар, Минская, 126, телефон: 259-12-51		0101000020E6100000791EDC9DB5774340B8054B7501854640
45414	2	20	\N	242	23620	\N	45.0505	город Краснодар, Механическая, 15/1, телефон: 2522774		0101000020E6100000BD8E3864037F43405839B4C876864640
45391	2	20	\N	242	23790	\N	45.011637	город Краснодар, Майкопская, 70, телефон: 2355446		0101000020E6100000CEA8F92AF982434037363B527D814640
45389	2	20	\N	242	23790	\N	45.011637	город Краснодар, Майкопская, 70, телефон: 2335623		0101000020E6100000CEA8F92AF982434037363B527D814640
45311	2	20	\N	242	23717	\N	45.153294841317397	город Краснодар, 2 отд СКЗНИИСиВ, Лунная, 1, телефон: 256-51-21		0101000020E6100000CD785BE9B5774340F6D1A92B9F934640
45351	2	20	\N	242	22693	\N	45.048430570161301	станица Елизаветинская, Ленина, 52, телефон: 229-12-16	Россия, Краснодарский край, Краснодар, деревня Елизаветинская, улица Центральная	0101000020E6100000F1A0D9756F654340698EACFC32864640
45419	2	20	\N	242	23761	\N	45.040464	город Краснодар, Леваневского, 187, телефон: 2595220		0101000020E610000052D4997B487E43402A55A2EC2D854640
45407	2	20	\N	242	23761	\N	45.030700000000003	город Краснодар, Леваневского, 82, телефон: 2595633		0101000020E61000001AF8510DFB7D43405DFE43FAED834640
45346	2	20	\N	242	24004	\N	45.034922999999999	станица Елизаветинская, Курганная, 136, телефон: 229-15-36		0101000020E61000006F6589CE3269434069705B5B78844640
45422	2	20	\N	242	23758	\N	45.034184000000003	город Краснодар, Кузнечная, 167, телефон: 2556566		0101000020E6100000A724EB70747F4340F3052D2460844640
45360	2	20	\N	242	22234	\N	45.062133794789702	город Краснодар, Красных Партизан, 135, телефон: 222-54-14	Россия, Краснодарский край, Краснодар, улица Заполярная	0101000020E610000003B34291EE7543401EFCC401F4874640
45406	2	20	\N	242	23690	\N	45.030521	город Краснодар, Красноармейская, 70, телефон: 2596902		0101000020E610000029E8F692C67C4340AD6BB41CE8834640
45403	2	20	\N	242	23690	\N	45.023876999999999	город Краснодар, Красноармейская, 52, телефон: 2673459		0101000020E61000002BBF0CC6887C43403410CB660E834640
45411	2	20	\N	242	22696	\N	45.048940000000002	город Краснодар, Красная, 186, телефон: 2551054		0101000020E61000002B6B9BE2717D4340AEBB79AA43864640
90246	1	13	\N	54800	39573	\N	55.122199999999999	г.Сафоново, Ковалева, 4		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
45162	2	20	\N	242	22696	\N	45.027042999999999	город Краснодар, Красная, 55, телефон: 267-26-26		0101000020E6100000BD564277497C4340F94A202576834640
45161	2	20	\N	242	22696	\N	45.023054999999999	город Краснодар, Красная, 31, телефон: 262-53-95		0101000020E6100000DFE2E13D077C434030815B77F3824640
45188	2	20	\N	242	23747	\N	45.055791999999997	город Краснодар, Котовского, 100, телефон: 220-29-47		0101000020E6100000568330B77B7B434070B0373124874640
45187	2	20	\N	242	23747	\N	45.055746342328199	город Краснодар, Котовского, 100, телефон: 221-01-74		0101000020E610000056B77A4E7A7B4340007157AF22874640
45316	2	20	\N	242	23725	\N	45.100923999999999	город Краснодар, Кореновская, 35, телефон: 258-13-71		0101000020E6100000221ADD41EC7C4340D5B0DF13EB8C4640
45315	2	20	\N	242	23725	\N	45.099924999999999	город Краснодар, Кореновская, 33, телефон: 258-12-40		0101000020E61000004FB16A10E67C4340C286A757CA8C4640
45314	2	20	\N	242	23725	\N	45.099015000000001	город Краснодар, Кореновская, 3, телефон: 258-51-07		0101000020E6100000A038807EDF7B43401F680586AC8C4640
45159	2	20	\N	242	23019	\N	45.019449000000002	город Краснодар, Комсомольская, 46, телефон: 262-95-79		0101000020E610000013D4F02DAC8D43404F78094E7D824640
45310	2	20	\N	242	21979	\N	45.042936718132601	"город Краснодар, здание конторы МУП совхоз ""Прогресс"", телефон: 258-91-21"		0101000020E61000001A6EC0E7877D4340E964A9F57E854640
45418	2	20	\N	242	23692	\N	45.046590000000002	город Краснодар, Колхозная, 9, телефон: 2541823		0101000020E610000030BB270F0B7F43400B293FA9F6854640
45413	2	20	\N	242	23692	\N	45.057282000000001	город Краснодар, Колхозная, 71, телефон: 2244966		0101000020E6100000560BEC31917E434022533E0455874640
45412	2	20	\N	242	23692	\N	45.057282000000001	город Краснодар, Колхозная, 71, телефон: 2240317		0101000020E6100000560BEC31917E434022533E0455874640
45193	2	20	\N	242	23949	\N	45.038348999999997	город Краснодар, Кожевенная, 42, телефон: 253-52-21		0101000020E6100000E95F92CA14794340CA6ABA9EE8844640
45323	2	20	\N	242	23586	\N	45.060732999999999	город Краснодар, Ковалева, 6а, телефон: 226-35-80		0101000020E61000004224438EAD794340DC645419C6874640
45166	2	20	\N	242	23046	\N	45.031036999999998	город Краснодар, Кирова, 79, телефон: 259-20-03		0101000020E61000002EE3A6069A7B4340A4FB3905F9834640
45164	2	20	\N	242	23046	\N	45.031036999999998	город Краснодар, Кирова, 79, телефон: 259-29-22		0101000020E61000002EE3A6069A7B4340A4FB3905F9834640
45371	2	20	\N	242	23769	\N	45.064474373880302	город Краснодар, Карякина, 8, телефон: 257-12-87	Россия, Краснодарский край, Краснодар, улица Карякина, 8	0101000020E6100000B37DC85BAE8043409DB81CAF40884640
45305	2	20	\N	242	23769	\N	45.064641999999999	город Краснодар, Карякина, 8, телефон: 252-17-08		0101000020E6100000CBD93BA3AD80434059F9653046884640
45357	2	20	\N	242	23739	\N	45.040913775547601	город Краснодар, Калинина, 13, телефон: 221-59-44	Россия, Краснодарский край, Краснодар, Западный район, улица Калинина	0101000020E6100000E6CE4C309C7543406AF981AB3C854640
45340	2	20	\N	242	23739	\N	45.043120000000002	город Краснодар, Калинина, 13, телефон: 221-58-69		0101000020E6100000CF13CFD902764340DAE6C6F484854640
45192	2	20	\N	242	23739	\N	45.04054	город Краснодар, Калинина, 233, телефон: 253-55-14		0101000020E610000021E868554B7A434005172B6A30854640
45423	2	20	\N	242	23810	\N	45.030082	город Краснодар, Казачья, 16, телефон: 2534436		0101000020E610000075392520267F434061191BBAD9834640
45396	2	20	\N	242	23794	\N	45.017620000000001	город Краснодар, КИМ, 17, телефон: 2395335		0101000020E610000005A73E90BC7F4340B5E0455F41824640
45268	2	20	\N	242	23915	\N	45.008406000000001	город Краснодар, улица Игнатова, дом 49, телефон: 2370422		0101000020E6100000501DAB949E8943408B8BA37213814640
45267	2	20	\N	242	23915	\N	45.008406000000001	город Краснодар, улица Игнатова, дом 49, телефон: 2377664		0101000020E6100000501DAB949E8943408B8BA37213814640
46176	2	20	479	\N	23356	\N	45.436222999999998	Краснодарский край, Славянский район, Зеленского, 10, телефон: (246) 3-17-39	Россия, Краснодарский край, Славянский район	0101000020E61000000133DFC14FF24240AA61BF27D6B74640
45365	2	20	\N	242	24014	\N	45.132973999999997	поселок Колосистый, Звездная, 5, телефон: 228-55-68		0101000020E6100000259012BBB6734340F19BC24A05914640
45154	2	20	\N	242	23898	\N	45.002657999999997	город Краснодар, Захарова, 7, телефон: 262-93-81		0101000020E610000013F241CF667B43405089EB1857804640
45398	2	20	\N	242	23991	\N	45.021901999999997	город Краснодар, Железнодорожная, 8, телефон: 2148012		0101000020E6100000A070766B997E4340C6DB4AAFCD824640
45307	2	20	\N	242	16518	\N	45.155515999999999	поселок Березовый, Ейское шоссе, 20/5, телефон: 211-32-99	Россия, Краснодарский край, Краснодар, поселок Березовый, Ейское шоссе, 18	0101000020E6100000FCDEA63FFB7F43409B00C3F2E7934640
45245	2	20	\N	242	23700	\N	45.030005000000003	город Краснодар, улица Евдокии Бершанской, дом 372, телефон: 2276649		0101000020E6100000C269C18BBE8E4340B6DB2E34D7834640
45242	2	20	\N	242	23700	\N	45.023487056034703	город Краснодар, улица Евдокии Бершанской, дом 220, телефон: 2373086	Россия, Краснодарский край, Краснодар, улица Евдокии Бершанской, 220	0101000020E610000065E1EB6B5D8C4340CA703C9F01834640
45239	2	20	\N	242	23700	\N	45.017454999999998	город Краснодар, улица Евдокии Бершанской, дом 19а, телефон: 2371732		0101000020E6100000425E0F26C58943406A1327F73B824640
45206	2	20	\N	242	23755	\N	45.037208999999997	город Краснодар, им. Думенко, 31, телефон: 261-88-13, 261-88-47(день голосования)		0101000020E6100000C26856B60F754340F50EB743C3844640
45363	2	20	\N	242	23237	\N	45.124917000000003	город Краснодар, Дорожная, 1, телефон: 225-96-10	Россия, Краснодарский край, Краснодар, улица Дорожная, 1	0101000020E6100000F52EDE8FDB7D434073DBBE47FD8F4640
45425	2	20	\N	242	23996	\N	45.025207999999999	город Краснодар, Дмитриевская Дамба, 3, телефон: 2685922		0101000020E61000008AE3C0ABE57E43407DCC07043A834640
45280	2	20	\N	242	23808	\N	45.021953000000003	город Краснодар, улица Димитрова, дом 172, телефон: 2199543		0101000020E6100000478FDFDBF483434049861C5BCF824640
45222	2	20	\N	242	23808	\N	45.021270999999999	город Краснодар, улица Димитрова, дом 170, телефон: 2199542		0101000020E6100000E144F46BEB83434036AD1402B9824640
45178	2	20	\N	242	23151	\N	45.060974999999999	город Краснодар, Дзержинского, 24, телефон: 224-63-11		0101000020E610000064CE33F6257D4340D26F5F07CE874640
45176	2	20	\N	242	23151	\N	45.060974999999999	город Краснодар, Дзержинского, 24, телефон: 224-02-34(день голосования), 224-52-53		0101000020E610000064CE33F6257D4340D26F5F07CE874640
45405	2	20	\N	242	23869	\N	45.029865000000001	город Краснодар, Горького, 173, телефон: 2530132		0101000020E61000002DE8BD31047E4340C425C79DD2834640
45243	2	20	\N	242	23288	\N	45.026927999999998	город Краснодар, улица Гоголя, дом 60/2, телефон: 2667332		0101000020E610000068CF656A127C434060AC6F6072834640
45241	2	20	\N	242	23288	\N	45.0284316457928	город Краснодар, улица Гоголя, дом 17, телефон: 2375378	Россия, Краснодарский край, Краснодар, Центральный район, улица Гоголя	0101000020E610000012F92EA52E7B43407714E7A8A3834640
45275	2	20	\N	242	24002	\N	45.003715999999997	город Краснодар, улица Гидростроителей, дом 41, телефон: 2372724		0101000020E6100000E04A766C048A4340683C11C479804640
45274	2	20	\N	242	24002	\N	45.002161000000001	город Краснодар, улица Гидростроителей, дом 20, телефон: 2377026		0101000020E6100000CA17B49080894340D029C8CF46804640
45318	2	20	\N	242	24008	\N	45.078651999999998	город Краснодар, Гастелло, 26, телефон: 224-09-58		0101000020E6100000EC33677DCA7D4340EBE1CB44118A4640
45317	2	20	\N	242	24008	\N	45.078651999999998	город Краснодар, Гастелло, 26, телефон: 224-07-58		0101000020E6100000EC33677DCA7D4340EBE1CB44118A4640
45331	2	20	\N	242	23657	\N	45.057358000000001	город Краснодар, Воровского, 229, телефон: 226-45-40		0101000020E610000012F6ED24227A4340FD14C78157874640
45330	2	20	\N	242	23657	\N	45.057358000000001	город Краснодар, Воровского, 229, телефон: 226-78-77		0101000020E610000012F6ED24227A4340FD14C78157874640
45329	2	20	\N	242	23657	\N	45.057358000000001	город Краснодар, Воровского, 229, телефон: 226-83-61		0101000020E610000012F6ED24227A4340FD14C78157874640
45327	2	20	\N	242	23657	\N	45.058236999999998	ород Краснодар, Воровского, 237, телефон: 226-06-70		0101000020E61000007365506D707A434065355D4F74874640
45232	2	20	\N	242	23264	\N	45.028729909972597	город Краснодар, улица Волжская, дом 39, телефон: 2314419		0101000020E6100000C9C859D8D38443400135B56CAD834640
45397	2	20	\N	242	23591	\N	45.012796999999999	город Краснодар, Вишняковой, 3/5, телефон: 2686955		0101000020E610000013437232717F4340533E0455A3814640
45266	2	20	\N	242	20647	\N	45.012742694406199	город Краснодар, улица В.Н.Мачуги, дом 80, телефон: 2376911	Россия, Краснодарский край, Краснодар, улица Василия Мачуги, 80	0101000020E610000079AD84EE928A434060200890A1814640
45265	2	20	\N	242	20647	\N	45.012572057120401	город Краснодар, улица В.Н.Мачуги, дом 78, телефон: 2666434	Россия, Краснодарский край, Краснодар, улица Василия Мачуги, 78	0101000020E6100000C26B97361C8A4340336C94F59B814640
45343	2	20	\N	242	23787	\N	45.054651999999997	город Краснодар, Вавилова, 21, телефон: 228-00-04		0101000020E6100000C153C8957A7243409B5434D6FE864640
45384	2	20	\N	242	23745	\N	45.013460000000002	город Краснодар, Бургасская, 29, телефон: 2336227		0101000020E6100000D6E5948098844340EFE6A90EB9814640
45383	2	20	\N	242	23745	\N	45.011586000000001	город Краснодар, Бургасская, 65, телефон: 2271829		0101000020E610000098DBBDDC27854340B58B69A67B814640
45208	2	20	\N	242	23802	\N	45.034184000000003	город Краснодар, Бульварное Кольцо, 22, телефон: 265-10-93, 261-10-95(день голосования)		0101000020E61000005D18E945ED744340F3052D2460844640
45279	2	20	\N	242	23118	\N	45.020710000000001	хутор Ленина, улица Буковая, дом 2, телефон: 2434832	Россия, Краснодарский край, Краснодар, поселок Ленина, улица Буковая, 4	0101000020E6100000DFE00B93A99A43409F5912A0A6824640
45168	2	20	\N	242	23527	\N	45.037343	город Краснодар, Буденного, 107, телефон: 255-97-27		0101000020E61000008928266F807B434005DEC9A7C7844640
45270	2	20	\N	242	23712	\N	45.008533999999997	город Краснодар, улица Благоева, дом 22, телефон: 2667993		0101000020E61000005454FD4AE7894340B87361A417814640
45269	2	20	\N	242	23712	\N	45.008533999999997	город Краснодар, улица Благоева, дом 22, телефон: 2375945		0101000020E61000005454FD4AE7894340B87361A417814640
45172	2	20	\N	242	23986	\N	45.046579164333501	город Краснодар, Бабушкина, 307, телефон: 255-74-84	Россия, Краснодарский край, Краснодар, улица Бабушкина	0101000020E6100000E527D53E1D7D434017D7F84CF6854640
45333	2	20	\N	242	23318	\N	45.058754332607101	город Краснодар, Атарбекова, 26, телефон: 226-49-55	Россия, Краснодарский край, Краснодар, улица Атарбекова	0101000020E61000009D9D0C8E927943402D41464085874640
45332	2	20	\N	242	23318	\N	45.059005268506198	город Краснодар, Атарбекова, 26, телефон: 226-00-18	Россия, Краснодарский край, Краснодар, улица Атарбекова	0101000020E6100000CA5180289879434076A6D0798D874640
45326	2	20	\N	242	23318	\N	45.058804591164296	город Краснодар, Атарбекова, 52, телефон: 226-02-16	Россия, Краснодарский край, Краснодар, улица Атарбекова, 52	0101000020E61000009B046F48A37A4340AFEB17EC86874640
45212	2	20	\N	242	24020	\N	45.038832999999997	город Краснодар, Алма-Атинская, 2, телефон: 261-72-52		0101000020E610000039D2191879754340B680D07AF8844640
46312	2	20	\N	242	24017	\N	45.065705000000001	село Алексеевка, ул.Алексеевская, 20, телефон: 76-63-20		0101000020E6100000228B34F10E86434083177D0569884640
45209	2	20	\N	242	23695	\N	45.035916	город Краснодар, им. 70-летия Октября, 28, телефон: 261-85-02, 261-73-50(день голосования)		0101000020E610000048A5D8D1387443409AB33EE598844640
45202	2	20	\N	242	23695	\N	45.037260000000003	город Краснодар, им. 70-летия Октября, 30, телефон: 261-53-31, 261-78-00		0101000020E6100000739F1C058874434078B988EFC4844640
45296	2	20	\N	242	23701	\N	45.055931999999999	город Краснодар, 40-летия Победы, 33, телефон: 257-76-33		0101000020E61000009D4830D5CC80434062669FC728874640
45260	2	20	\N	242	23819	\N	45.036706000000002	город Краснодар, улица 30-й Иркутской дивизии, дом 1, телефон: 2326136		0101000020E6100000056F48A3028D434093C83EC8B2844640
45259	2	20	\N	242	23819	\N	45.036660500324302	город Краснодар, улица 30-й Иркутской дивизии, дом 1, телефон: 2328550	Россия, Краснодарский край, Краснодар, улица 30-й Иркутской Дивизии, 1	0101000020E6100000029F1F46088D4340F304C24EB1844640
45258	2	20	\N	242	23819	\N	45.036934354988801	город Краснодар, улица 30-й Иркутской дивизии, дом 1, телефон: 2320727	Россия, Краснодарский край, Краснодар, улица 30-й Иркутской Дивизии, 1	0101000020E61000000CB1FA230C8D4340240ED940BA844640
45341	2	20	\N	242	23672	\N	45.051060999999997	город Краснодар, 2-я Линия, 49, телефон: 221-60-60		0101000020E6100000AD6D8AC745774340EF8CB62A89864640
45328	2	20	\N	242	23656	\N	45.058554999999998	город Краснодар, Атарбекова, 42, телефон: 226-12-80		0101000020E610000034D8D479547A43403602F1BA7E874640
45379	2	20	\N	242	7213	\N	45.008540000000004	город Краснодар, 2-й проезд Стасова, 54, телефон: 2335341	Россия, Краснодарский край, Краснодар, 2-й Стасова проезд, 54	0101000020E61000003E40F7E5CC8443409B5AB6D617814640
45378	2	20	\N	242	7213	\N	45.007604000000001	город Краснодар, 2-й проезд Стасова, 48, телефон: 2271692	Россия, Краснодарский край, Краснодар, 2-й Стасова проезд, 48	0101000020E610000058FE7C5BB0844340CEA8F92AF9804640
45221	2	20	\N	242	20578	\N	45.034942000000001	город Краснодар, улица 2-й Пятилетки, дом 12, телефон: 2337415		0101000020E6100000BBECD79DEE7C4340E0A0BDFA78844640
45173	2	20	\N	242	5034	\N	45.048265000000001	город Краснодар, 2-й Гаражный проезд, 3, телефон: 255-94-91	Россия, Краснодарский край, Краснодар, 2-й Гаражный проезд, 3	0101000020E6100000EC14AB06617C43404E452A8C2D864640
45362	2	20	\N	242	23252	\N	45.068263999999999	город Краснодар, 1-го Мая, 298а, телефон: 252-75-93		0101000020E6100000815CE2C80383434040BFEFDFBC884640
45301	2	20	\N	242	23252	\N	45.110689000000001	город Краснодар, 1-го Мая, 580/3, телефон: 228-87-51		0101000020E61000004643C6A3548243407383A10E2B8E4640
45294	2	20	\N	242	23252	\N	45.059052000000001	город Краснодар, 1-го Мая, 99, телефон: 252-78-68		0101000020E6100000399A232BBF824340B76114048F874640
45292	2	20	\N	242	23252	\N	45.052875999999998	город Краснодар, 1-го Мая, 93, телефон: 252-93-70		0101000020E6100000882AFC19DE824340245F09A4C4864640
45247	2	20	\N	242	23252	\N	45.048532999999999	город Краснодар, улица 1 мая, дом 65, телефон: 2279035		0101000020E61000007B4E7ADFF88243406DE34F5436864640
45246	2	20	\N	242	23252	\N	45.048532999999999	город Краснодар, улица 1 мая, дом 65, телефон: 2279057		0101000020E61000007B4E7ADFF88243406DE34F5436864640
46768	2	20	\N	242	21240	\N	45.181615000000001	п.Октябрьский, Школьная, 10, телефон: 96015	Россия, Краснодарский край, Краснодар, поселок Октябрьский, улица Северская	0101000020E61000004D327216F68A434045BB0A293F974640
45366	2	20	\N	242	21240	\N	45.037184000000003	город Краснодар, Школьная, 15/6, телефон: 274-53-20		0101000020E6100000F1845E7F128343409DF7FF71C2844640
45358	2	20	\N	242	21240	\N	45.037184000000003	город Краснодар, Школьная, 15/6, телефон: 274-60-34		0101000020E6100000F1845E7F128343409DF7FF71C2844640
45286	2	20	\N	242	21240	\N	45.038256659835298	город Краснодар, Школьная, 15/6, телефон: 275-73-77		0101000020E6100000C808A87004834340EAEBF99AE5844640
45322	2	20	\N	242	23654	\N	45.068677999999998	город Краснодар, Тургенева, 195, телефон: 220-67-13		0101000020E61000004A7EC4AF587B434033FAD170CA884640
45321	2	20	\N	242	23654	\N	45.068677999999998	город Краснодар, Тургенева, 195, телефон: 226-95-31		0101000020E61000004A7EC4AF587B434033FAD170CA884640
45320	2	20	\N	242	23654	\N	45.070293999999997	город Краснодар, Тургенева, 217, телефон: 224-37-32		0101000020E6100000E09C11A5BD7B4340718DCF64FF884640
45380	2	20	\N	242	23606	\N	45.013128000000002	город Краснодар, Старокубанская, 88/4, телефон: 2331766		0101000020E6100000878BDCD3D5854340B954A52DAE814640
45225	2	20	\N	242	23606	\N	45.019137000000001	город Краснодар, улица Старокубанская, дом 127, телефон: 2345264		0101000020E6100000EFE53E390A8643406092CA1473824640
45254	2	20	\N	242	23964	\N	45.029877999999997	город Краснодар, улица Сормовская, дом 114, телефон: 2328817		0101000020E6100000B83CD68C0C8C4340586FD40AD3834640
45408	2	20	\N	242	23614	\N	45.038371476045	город Краснодар, Седина, 168, телефон: 2551572	Россия, Краснодарский край, Краснодар, улица Митрофана Седина	0101000020E6100000CD785BE9B57D4340B20E4757E9844640
45428	2	20	\N	242	23669	\N	45.034381000000003	город Краснодар, Северная, 564, телефон: 2540624		0101000020E6100000D6E429ABE9804340494DBB9866844640
45170	2	20	\N	242	23669	\N	45.041553	город Краснодар, Северная, 269, телефон: 255-77-23		0101000020E61000000E846401137C43407D06D49B51854640
45248	2	20	\N	242	23919	\N	45.089804454730903	поселок Лорис, улица Рязанская, дом 12, телефон: 2515488	Россия, Краснодарский край, Краснодар, поселок Зональный, улица Рязанская	0101000020E6100000102384471B8F434066868DB27E8B4640
45291	2	20	\N	242	23762	\N	45.052551000000001	город Краснодар, Ростовская, 14, телефон: 252-03-61		0101000020E61000001749BBD1C7804340A12FBDFDB9864640
45290	2	20	\N	242	23762	\N	45.052551000000001	город Краснодар, Ростовская, 14, телефон: 257-04-56		0101000020E61000001749BBD1C7804340A12FBDFDB9864640
45401	2	20	\N	242	23806	\N	45.015174000000002	город Краснодар, Красноармейская, 2, телефон: 2685244		0101000020E610000037514B732B7C4340F0DFBC38F1814640
45400	2	20	\N	242	23806	\N	45.0177600341854	город Краснодар, Красноармейская, 7, телефон: 2685344	Россия, Краснодарский край, Краснодар, улица Красноармейская, 7	0101000020E6100000FC523F6F2A7C4340A796ADF545824640
45167	2	20	\N	242	23642	\N	45.032172019779303	город Краснодар, Красная, 87/89, телефон: 274-32-40	Россия, Краснодарский край, Краснодар, улица Красная, 87	0101000020E61000009758198D7C7C434068EC4B361E844640
45189	2	20	\N	242	23749	\N	45.055716042990497	город Краснодар, Котовского, 100, телефон: 255-64-63	Россия, Краснодарский край, Краснодар, улица Котовского, 100	0101000020E61000003D27BD6F7C7B434095EEAEB321874640
45370	2	20	\N	242	23678	\N	45.061751000000001	город Краснодар, Зиповская, 12, телефон: 252-47-13		0101000020E610000045B75ED38380434066BFEE74E7874640
45345	2	20	\N	242	23952	\N	45.132380282020598	поселок Колосистый, Звездная, 10, телефон: 228-55-95	Россия, Краснодарский край, Краснодар, поселок Колосистый, улица Звездная, 10	0101000020E61000003BA759A0DD7343407E52EDD3F1904640
45368	2	20	\N	242	23943	\N	45.060190426625603	город Краснодар, Восточно-Кругликовская, 49, телефон: 252-61-38	Россия, Краснодарский край, Краснодар, улица Восточно-Кругликовская, 49	0101000020E6100000EC866D8B32834340EBC5504EB4874640
45207	2	20	\N	242	23871	\N	45.034184000000003	город Краснодар, Бульварное Кольцо, 22, телефон: 265-10-93, 265-10-96(день голосования)		0101000020E61000005D18E945ED744340F3052D2460844640
45409	2	20	\N	242	23811	\N	45.035654999999998	город Краснодар, Буденного, 161, телефон: 2533715		0101000020E6100000B6847CD0B37D43402D78D15790844640
45177	2	20	\N	242	23677	\N	45.055835999999999	город Краснодар, Брянская, 6, телефон: 224-63-67		0101000020E61000001157CEDE197D434040F850A225874640
45179	2	20	\N	242	23779	\N	45.061547595367202	город Краснодар, Бакинская, 5, телефон: 224-23-32	Россия, Краснодарский край, Краснодар, улица Бакинская, 5	0101000020E610000012DBDD03747D43402E910BCEE0874640
45297	2	20	\N	242	23731	\N	45.055863618436298	город Краснодар, 40-летия Победы, 33, телефон: 275-60-20		0101000020E610000085ECBC8DCD8043400A83328D26874640
45033	2	20	\N	50406	21675	\N	45.462083999999997	Кореновск город, Выселковская, 29А, телефон: 4-71-43		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45031	2	20	\N	50457	22053	\N	45.462083999999997	Кореновск город, Матросова, 11, телефон: 4-25-02		0101000020E610000040DEAB5626BA43409F008A9125BB4640
46851	2	20	\N	50782	23583	\N	44.745944999999999	х. Калининский, Школьная, 14, телефон: 79-4-02		0101000020E61000000F7BA180EDE24240AFCE31207B5F4640
45356	2	20	\N	50854	23881	\N	45.09299	поселок Индустриальный, Степная, 10, телефон: 251-52-75		0101000020E61000001FF64201DB8D4340726DA818E78B4640
44727	2	20	\N	50468	22142	\N	44.685633000000003	станица Имеретинская, Ленина, 18, телефон: 5-31-40		0101000020E6100000994BAAB69BB64340790778D2C2574640
45347	2	20	\N	50598	22953	\N	45.047552099698699	станица Елизаветинская, Ленина, 276, телефон: 229-14-67		0101000020E6100000683D7C9928664340016E162F16864640
44903	2	20	\N	50422	21766	\N	46.698206999999996	город Ейск, Рабочая, 2А, телефон: 35440		0101000020E61000009F1C0588822343404C6BD3D85E594740
44904	2	20	\N	50422	22586	\N	46.696298076403401	город Ейск, Одесская, 261, телефон: 38449		0101000020E61000000F61FC34EE2143409622F94A20594740
44923	2	20	\N	50422	21741	\N	46.6858664857292	город Ейск, Коммунистическая, 67, телефон: 48444		0101000020E610000003B5183C4C2543401BB80375CA574740
44894	2	20	\N	50422	21873	\N	46.718800556776898	город Ейск, Калинина, 279а, телефон: 24073		0101000020E6100000469A78077822434082AAD1AB015C4740
44758	2	20	\N	50496	22358	\N	45.363773999999999	г.Гулькевичи, Гражданская площадь, (здание МОУ СОШ № 4), 17, телефон: 3-30-84		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44750	2	20	\N	50496	23983	\N	45.358027331150303	Краснодарский край, Гулькевичский район, ул. Братская, (здание МАОУ СОШ № 1), 2, телефон: 3-39-59		0101000020E610000002F566D47C594440E10A28D4D3AD4640
44549	2	20	\N	50863	23916	\N	44.752802019501097	хутор Грушевый, улица Речная, 4, телефон: 3-71-38		0101000020E6100000F357C85C19EE4240842EE1D05B604640
45605	2	20	\N	50377	21464	\N	44.691465000000001	поселок Первомайский, Школьная, 1, телефон: 6-68-48		0101000020E61000004089CF9D60A7434011AAD4EC81584640
46499	2	20	\N	27694	\N	\N	44.605612000000001	поселок Мирный, улица Центральная, дом 2, телефон: 6 92 36	Россия, Краснодарский край, Горячий Ключ, поселок Мирный	0101000020E6100000876BB587BD8043405708ABB1844D4640
44740	2	20	\N	27694	20645	\N	44.7127582823544	станица Саратовская, здание сельского клуба военного совхоза, телефон: 3-20-56		0101000020E6100000B33F506EDB9B43402FFB75A73B5B4640
45857	2	20	\N	27694	23342	\N	44.504595999999999	п.Веселый, ул.Молодежная, 11, телефон: 2-29-16	Россия, Краснодарский край, Горячий Ключ, поселок Веселый	0101000020E6100000B83F170D19AD4340A1D80A9A96404640
44717	2	20	\N	27694	21512	\N	44.630134101396898	город Горячий Ключ, Ярославского, 109, телефон: 4-31-34	Россия, Краснодарский край, Горячий Ключ	0101000020E610000092770E65A8904340800C1D3BA8504640
45115	2	20	\N	27694	22079	\N	44.691465000000001	поселок Первомайский, ул.Школьная, 5, телефон: 91-6-18		0101000020E61000004089CF9D60A7434011AAD4EC81584640
94980	2	20	\N	27694	20416	\N	44.632337161093197	г. Горячий Ключ, Хадыженская, 28 Б	Россия, Краснодарский край, Горячий Ключ	0101000020E61000005B0A48FB1F9043407F86376BF0504640
44715	2	20	\N	27694	20872	\N	44.630433729610999	город Горячий Ключ, Советская, 98, телефон: 3-72-89	Россия, Краснодарский край, Горячий Ключ	0101000020E6100000AA285E656D8F4340AB24B20FB2504640
44744	2	20	\N	27694	20487	\N	44.616649000000002	Краснодарский край, город Горячий Ключ, Псекупская, 2, телефон: 3-50-33		0101000020E6100000A9F57EA31D9F4340390EBC5AEE4E4640
44731	2	20	\N	27694	22085	\N	44.753799000000001	поселок Приреченский, Парковая, 8, телефон: 4-81-42		0101000020E610000090149161159F4340F660527C7C604640
44742	2	20	\N	27694	20461	\N	44.628417942716901	Краснодарский край, город Горячий Ключ, Ленина, 195, телефон: 3-46-72	Россия, Краснодарский край, Горячий Ключ	0101000020E6100000E09F5225CA904340DF1B430070504640
44714	2	20	\N	27694	20461	\N	44.628877992218698	город Горячий Ключ, Ленина, 203, телефон: 3-81-49	Россия, Краснодарский край, Горячий Ключ	0101000020E61000006F29E78BBD8F4340429605137F504640
44713	2	20	\N	27694	20461	\N	44.616649000000002	город Горячий Ключ, Ленина, 185 А, телефон: 4-48-84		0101000020E6100000A9F57EA31D9F4340390EBC5AEE4E4640
44711	2	20	\N	27694	20461	\N	44.630581088979497	город Горячий Ключ, Ленина, 137, телефон: 3-44-71	Россия, Краснодарский край, Горячий Ключ	0101000020E61000008010C990638F43404F3DD2E0B6504640
44710	2	20	\N	27694	20461	\N	44.6297667165354	город Горячий Ключ, Ленина, 35, телефон: 3-40-41		0101000020E6100000E63FA4DFBE904340CE8C7E349C504640
44709	2	20	\N	27694	20461	\N	44.630287327366197	город Горячий Ключ, Ленина, 26, телефон: 3-43-52	Россия, Краснодарский край, Горячий Ключ	0101000020E610000039F06AB9338F4340070C923EAD504640
44737	2	20	\N	27694	20880	\N	44.645899	станица Кутаисская, Ленина, 27 А, телефон: 5-86-34		0101000020E610000042E90B21E7A7434072C284D1AC524640
44712	2	20	\N	27694	20761	\N	44.6296441346854	город Горячий Ключ, Кучерявого, 42, телефон: 4-29-58	Россия, Краснодарский край, Горячий Ключ	0101000020E6100000F62686E464904340B20FB22C98504640
44738	2	20	\N	27694	21492	\N	44.797576275898599	хутор Молькин, Космонавтов, 20, телефон: 5-94-49	Россия, Краснодарский край, Горячий Ключ, поселок Молькин	0101000020E61000005F0B7A6F0C9D434089096AF816664640
44708	2	20	\N	27694	21353	\N	44.630134101396898	город Горячий Ключ, Кондратьева, 70, телефон: 4-27-19	Россия, Краснодарский край, Горячий Ключ	0101000020E610000007B47405DB904340800C1D3BA8504640
44718	2	20	\N	27694	9831	\N	44.629643775558499	город Горячий Ключ, Заводская, 37, телефон: 4-61-62	Россия, Краснодарский край, Горячий Ключ	0101000020E6100000DC4B1AA375924340B20FB22C98504640
44719	2	20	\N	27694	20772	\N	44.651183533189503	город Горячий Ключ, Вокзальная, 6, телефон: 4-48-91	Россия, Краснодарский край, Горячий Ключ	0101000020E61000008736001B10914340D8D64FFF59534640
44679	2	20	\N	25997	23465	\N	44.561413268957097	город-курорт Геленджик, Кирова, 66, телефон: 33038	Россия, Краснодарский край, Геленджик, улица Кирова, 66	0101000020E61000007A5567B5C00A43404E469561DC474640
14031	1	17	\N	3130	22836	\N	58.045848999999997	г.Рыбинск, пр. Серова, 21		0101000020E6100000B3614D65516C4340F3C64961DE054D40
44676	2	20	\N	25997	23392	\N	44.549753842465101	город-курорт Геленджик, Калинина, 33а, телефон: 53941		0101000020E610000047CCECF3180B43402F6CCD565E464640
44698	2	20	\N	25997	23584	\N	44.466251717350801	х. Джанхот, Черноморская, 18, телефон: 62810	Россия, Краснодарский край, городской округ Геленджик, поселок Джанхот	0101000020E6100000EAB303AE2B144340E8D84125AE3B4640
44686	2	20	\N	25997	23760	\N	44.588904999999997	город-курорт Геленджик, Туристическая, 19, телефон: 27164		0101000020E610000073BA2C2636054340B6B9313D614B4640
44682	2	20	\N	25997	22714	\N	44.564363315265801	город-курорт Геленджик, Толстого, 19, телефон: 21581	Россия, Краснодарский край, Геленджик, улица Толстого	0101000020E61000001DAF40F4A40A43404609FA0B3D484640
44688	2	20	\N	25997	24001	\N	44.582068	город-курорт Геленджик, Солнечная, 3, телефон: 28094	Россия, Краснодарский край, Геленджик, улица Солнечная, 3	0101000020E61000003CF6B3588A02434029064834814A4640
44673	2	20	\N	25997	23824	\N	44.552112596293597	город-курорт Геленджик, Полевая, 2, телефон: 59482	Россия, Краснодарский край, Геленджик, улица Полевая, 2	0101000020E6100000E8887C9752094340255987A3AB464640
44702	2	20	\N	25997	23868	\N	44.372401164247698	х. Бетта, Подгорная, 6, телефон: 68743	Россия, Краснодарский край, городской округ Геленджик, поселок Бетта	0101000020E6100000C710001C7B324340B5FF01D6AA2F4640
44677	2	20	\N	25997	23397	\N	44.5579288683358	город-курорт Геленджик, Первомайская, 37, телефон: 31955	Россия, Краснодарский край, Геленджик, Первомайская улица, 37	0101000020E61000007009C03FA50A4340B83EAC376A474640
44678	2	20	\N	25997	23394	\N	43.581488999999998	город-курорт Геленджик, Первомайская, 4, телефон: 33463		0101000020E610000074B515FBCBDC4340EBFD463B6ECA4540
44674	2	20	\N	25997	22591	\N	44.546072997934203	город-курорт Геленджик, Парус, 25, телефон: 51761	Россия, Краснодарский край, Геленджик	0101000020E6100000F06AB933130A4340431D56B8E5454640
44681	2	20	\N	25997	22973	\N	44.5533921927981	город-курорт Геленджик, Островского, 141а, телефон: 57309		0101000020E610000091B586527B0D43401CEF8E8CD5464640
44680	2	20	\N	25997	23705	\N	44.554327269247999	город-курорт Геленджик, Нахимова, 2, телефон: 52290	Россия, Краснодарский край, Геленджик, улица Нахимова, 2	0101000020E61000001BF4A5B73F0B43401825E82FF4464640
44685	2	20	\N	25997	23816	\N	44.575254999999999	город-курорт Геленджик, Маячная, 3, телефон: 33878		0101000020E610000072C119FCFD08434024EEB1F4A1494640
44683	2	20	\N	25997	23492	\N	44.570497000000003	город-курорт Геленджик, Луначарского, 95, телефон: 33330		0101000020E61000009D11A5BDC1094340AABBB20B06494640
44684	2	20	\N	25997	24029	\N	44.563029	город-курорт Геленджик, Ленина, 22, телефон: 32231	Россия, Краснодарский край, Геленджик, улица Ленина, 22	0101000020E61000009E616A4B1D0A43408CD9925511484640
44703	2	20	\N	25997	23408	\N	44.439092354008999	с. Текос, Ленина, 33а, телефон: 61620	Россия, Краснодарский край, городской округ Геленджик, поселок Текос	0101000020E6100000575F5D15A83B4340B6F7A92A34384640
44675	2	20	\N	25997	23877	\N	44.553612999999999	город-курорт Геленджик, Курзальная, 12, телефон: 52301		0101000020E61000009B012EC896094340FAD170CADC464640
44671	2	20	\N	25997	6744	\N	44.550767999999998	" г.Геленджик, ул.Крымская,21 здание ЦМИиАМ ""Южное НПО по морским геологоразведочным работам"	Россия, Краснодарский край, Геленджик, Крымская улица, 15	0101000020E610000073F22213F007434077D7D9907F464640
44672	2	20	\N	25997	23463	\N	44.552913439938102	город-курорт Геленджик, Красногвардейская, 38, телефон: 54299	Россия, Краснодарский край, Геленджик, Красногвардейская улица, 39	0101000020E610000044149337C008434041446ADAC5464640
44689	2	20	\N	25997	20498	\N	44.585495999999999	353460, город-курорт Геленджик, Взлетная, 39	Россия, Краснодарский край, Геленджик, улица Изумрудная	0101000020E610000081E84999D40643402BF86D88F14A4640
44687	2	20	\N	25997	21490	\N	44.603457599838997	город-курорт Геленджик, мкр. Северный, 55, телефон: 26867	Россия, Краснодарский край, Геленджик	0101000020E6100000E1B88C9B1A0443403A419B1C3E4D4640
46857	2	20	\N	50256	20544	\N	45.307335000000002	п. Вимовец, Батохина, 4-А, телефон: 34-1-69		0101000020E61000005CAB3DEC85F2434045F5D6C056A74640
46059	2	20	\N	50301	20934	\N	46.225698999999999	хутор Веселая Жизнь, Северная, 26 А, телефон: 4-26-31		0101000020E6100000E886A6ECF4E94340B5DE6FB4E31C4740
45309	2	20	\N	50388	\N	\N	45.159405999999997	поселок Березовый, 19/2, телефон: 274-79-57	Россия, Краснодарский край, Краснодар, поселок Березовый	0101000020E610000099F221A81A7F4340A164726A67944640
45361	2	20	\N	50388	23785	\N	45.147221000000002	поселок Березовый, Целиноградская, 1, телефон: 211-33-20		0101000020E610000059349D9D0C80434068244223D8924640
45771	2	20	\N	50696	23413	\N	45.0284081079391	х. Белый, Горького, 234, телефон: 4-13-32		0101000020E6100000D8BB3FDEAB7E4340EE7893DFA2834640
44538	2	20	\N	50428	22660	\N	44.769428636511499	город Белореченск, переулок Коммунальный, 2, телефон: 2-21-43	Россия, Краснодарский край, Белореченский район, город Белореченск	0101000020E610000087FA5DD89AF1434008CC43A67C624640
44534	2	20	\N	50428	22237	\N	44.769857000000002	город Белореченск, улица Толстого, 138, телефон: 2-72-66		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44519	2	20	\N	50428	22219	\N	44.770440578682397	город Белореченск, улица Мостовая, 75, телефон: 2-64-32		0101000020E6100000DC7F643A74F04340AF3F89CF9D624640
44537	2	20	\N	50428	22247	\N	44.769857000000002	город Белореченск, улица Мира, 106, телефон: 3-33-98		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44531	2	20	\N	50428	21781	\N	44.769857000000002	город Белореченск, улица Калинина, 260, телефон: 2-28-36		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44541	2	20	\N	50428	22264	\N	44.769857000000002	город Белореченск, улица Аэродромная, 15, телефон: 2-55-77		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44724	2	20	\N	50246	20458	\N	44.550972999999999	село Безымянное, Таманская, 80, телефон: 5-35-21		0101000020E61000008E06F0164890434050FD834886464640
44732	2	20	\N	50356	21338	\N	44.766292	станица Бакинская, Горбунова, 1, телефон: 5-89-45		0101000020E6100000035B25581CA44340DD9733DB15624640
44489	2	20	\N	50379	21472	\N	45.021112000000002	Краснодарский край, город Армавир, п.Южный, ул.Мичурина, 6, телефон: 49850		0101000020E610000085B1852007814440CEC64ACCB3824640
44444	2	20	\N	50370	\N	\N	44.988888465101702	г.Армавир п.ВНИИМК здание клуба	Россия, Краснодарский край, Армавир, поселок Опытная ст. ВНИИМК	0101000020E6100000C042E6CAA080444014B4C9E1937E4640
44493	2	20	\N	8849	\N	\N	44.952625324342598	"Краснодарский край, город Армавир, Центральная усадьба совхоза ""Юбилейный"", телефон: 33650"		0101000020E61000008E01D9EBDD8B44400E2DB29DEF794640
44448	2	20	\N	8849	20935	\N	44.972128248505499	Краснодарский край, город Армавир, пос.Мясокомбинат, 9-а, телефон: 36606	Россия, Краснодарский край, Армавир	0101000020E6100000FA43334FAE93444050C3B7B06E7C4640
44425	2	20	\N	8849	21357	\N	44.920647000000002	Краснодарский край, город Армавир, Шоссейная, 63, телефон: 45865		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44465	2	20	\N	8849	21236	\N	44.979648753761303	Краснодарский край, город Армавир, ул.Шмидта, 132, телефон: 57419	Россия, Краснодарский край, Армавир	0101000020E61000007EC344831490444091477023657D4640
44445	2	20	\N	8849	21643	\N	44.984521965123101	Краснодарский край, город Армавир, ул.Чехова, 46, телефон: 36211	Россия, Краснодарский край, Армавир	0101000020E61000007B4D0F0A4A8F4440A41820D1047E4640
44475	2	20	\N	8849	21244	\N	44.915937930139599	Краснодарский край, город Армавир, ул.Черноморская, 8, телефон: 27257	Россия, Краснодарский край, Армавир	0101000020E6100000BD0166BE838B4440F294D5743D754640
44426	2	20	\N	8849	21200	\N	44.977699352454103	Краснодарский край, город Армавир, ул.Центральная, 1, телефон: 33203	Россия, Краснодарский край, Армавир	0101000020E6100000B66455849B9044407C2AA73D257D4640
44494	2	20	\N	8849	21269	\N	44.994937056095502	Краснодарский край, город Армавир, ул.Урупская, 1, телефон: 58578	Россия, Краснодарский край, Армавир	0101000020E61000004182E2C7988F4440494A7A185A7F4640
44450	2	20	\N	8849	21438	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Урицкого, 106-а, телефон: 72652		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44483	2	20	\N	8849	21319	\N	45.011796754260601	Армавир, п.Старая Станица, ул.Ставропольская, 111		0101000020E6100000C2FC1532579244407098689082814640
44482	2	20	\N	8849	21319	\N	45.011743359078999	Краснодарский край, город Армавир, п.Старая Станица, ул.Ставропольская, 41, телефон: 37846	Россия, Краснодарский край, Армавир, поселок Стар. Станица	0101000020E6100000806264C91C9344407D7A6CCB80814640
44480	2	20	\N	8849	22565	\N	45.053725270068497	Краснодарский край, город Армавир, х.Красная Поляна, ул.Совецкая, 45, телефон: 24961	Россия, Краснодарский край, Армавир, поселок Кр. Поляна	0101000020E6100000FCA71B28F08C444022FDF675E0864640
44487	2	20	\N	8849	20846	\N	44.974775125390202	Краснодарский край, город Армавир, ул.С.Армии, 214, телефон: 73626	Россия, Краснодарский край, Армавир	0101000020E6100000AE9AE7887C914440ADFA5C6DC57C4640
44470	2	20	\N	8849	20846	\N	44.999129818765503	Краснодарский край, город Армавир, ул.С.Армии, 9, телефон: 53820	Россия, Краснодарский край, Армавир	0101000020E61000000DA5F622DA8A4440EB39E97DE37F4640
44495	2	20	\N	8849	20603	\N	44.981110760955801	Краснодарский край, город Армавир, ул.Свердлова, 92, телефон: 22012	Россия, Краснодарский край, Армавир	0101000020E61000008A56EE0566914440785F950B957D4640
44459	2	20	\N	8849	20603	\N	44.984818912960399	г.Армавир, ул. Свердлова, 174	Россия, Краснодарский край, Армавир	0101000020E61000000F9D9E77638D44405EBD8A8C0E7E4640
44429	2	20	\N	8849	20603	\N	44.920161997288297	Краснодарский край, город Армавир, ул.Свердлова, 79, телефон: 37784	Россия, Краснодарский край, Армавир	0101000020E610000003CC7C073F8B4440CF8250DEC7754640
44469	2	20	\N	8849	20825	\N	44.9884405564232	Краснодарский край, город Армавир, ул.С.Армии, 9-а, телефон: 53621	Россия, Краснодарский край, Армавир	0101000020E61000007A8B87F71C9044404583143C857E4640
44452	2	20	\N	8849	20825	\N	44.920647000000002	Краснодарский край, город Армавир, ул.С.Армии, 210-а, телефон: 73933		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44436	2	20	\N	8849	20545	\N	44.987597965092803	Краснодарский край, город Армавир, ул.Р.Люксембург, 233, телефон: 33243	Россия, Краснодарский край, Армавир	0101000020E6100000C4E8B985AE90444029CC7B9C697E4640
44435	2	20	\N	8849	21598	\N	45.005825230631203	Краснодарский край, город Армавир, ул.Р.Люксембург, 166, телефон: 32180	Россия, Краснодарский край, Армавир	0101000020E6100000E7ABE463778F4440E63FA4DFBE804640
44427	2	20	\N	8849	21598	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Р.Люксембург, 11, телефон: 42485		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44491	2	20	\N	8849	21256	\N	44.931981	Краснодарский край, город Армавир, п.Заветный, ул.Пушкина, 27, телефон: 24185		0101000020E6100000A01518B2BA91444027BF45274B774640
44485	2	20	\N	8849	21256	\N	44.932925441754598	п. Заветный.  ул. Пушкина, 29	Россия, Краснодарский край, Армавир, поселок Заветный	0101000020E6100000B2648EE55D914440764F1E166A774640
44481	2	20	\N	8849	20590	\N	44.980133238167802	Краснодарский край, город Армавир, ул.Песчаная, 40/2, телефон: 30041	Россия, Краснодарский край, Армавир	0101000020E6100000007157AF229144407D5D86FF747D4640
44488	2	20	\N	8849	20596	\N	44.981598088347098	Краснодарский край, город Армавир, ул.Островского, 162-а, телефон: 54352	Россия, Краснодарский край, Армавир	0101000020E6100000FFEC478AC8904440D5E8D500A57D4640
44474	2	20	\N	8849	20596	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Островского, 179, телефон: 75979		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44442	2	20	\N	8849	22013	\N	44.9811564480759	Краснодарский край, город Армавир, ул.Октябрьская, 143, телефон: 33043	Россия, Краснодарский край, Армавир	0101000020E6100000B77F65A54995444018231285967D4640
44476	2	20	\N	8849	20830	\N	44.919674144458703	Краснодарский край, город Армавир, ул.Новороссийская, 102, телефон: 78123	Россия, Краснодарский край, Армавир	0101000020E61000009F1C0588828B4440A27DACE0B7754640
44473	2	20	\N	8849	20830	\N	44.989169448066598	Краснодарский край, город Армавир, ул.Новороссийская, 147, телефон: 57299		0101000020E6100000FB912232AC884440C79BFC169D7E4640
14045	1	17	\N	3130	22522	\N	58.045848999999997	г. Рыбинск, Свободы, 12а		0101000020E6100000B3614D65516C4340F3C64961DE054D40
44471	2	20	\N	8849	20830	\N	44.998936662190602	Краснодарский край, город Армавир, ул.Новороссийская, 8, телефон: 78020	Россия, Краснодарский край, Армавир	0101000020E6100000355F251FBB8B4440D6E1E82ADD7F4640
44468	2	20	\N	8849	20830	\N	44.978186709036002	Краснодарский край, город Армавир, ул.Новороссийская, 104, телефон: 50713	Россия, Краснодарский край, Армавир	0101000020E61000001A14CD0358904440A92F4B3B357D4640
44467	2	20	\N	8849	20830	\N	44.988408099876501	Краснодарский край, город Армавир, ул.Новороссийская, 161, телефон: 54889	Россия, Краснодарский край, Армавир	0101000020E61000005ED905836B884440698D4127847E4640
44439	2	20	\N	8849	22223	\N	44.984521965123101	Краснодарский край, город Армавир, ул.Мира, 48, телефон: 33941	Россия, Краснодарский край, Армавир	0101000020E61000006B662D05A48F4440A41820D1047E4640
44462	2	20	\N	8849	20816	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Матвеева, 20, телефон: 23492		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44472	2	20	\N	8849	22540	\N	45.000946230766601	Краснодарский край, город Армавир, ул.Маркова, 36, телефон: 57450	Россия, Краснодарский край, Армавир	0101000020E6100000164F3DD2E08A4440F0879FFF1E804640
44447	2	20	\N	8849	20796	\N	44.977211991701999	Краснодарский край, город Армавир, ул.Луначарского, 279, телефон: 35354	Россия, Краснодарский край, Армавир	0101000020E6100000FFEC478AC89044401FA16648157D4640
44434	2	20	\N	8849	21822	\N	44.995409039940398	Краснодарский край, город Армавир, ул.Лермонтова, 93, телефон: 33913	Россия, Краснодарский край, Армавир	0101000020E61000009679ABAE438F44407192E68F697F4640
44484	2	20	\N	8849	22558	\N	45.008930407879703	Краснодарский край, город Армавир, п.Старая Станица, ул.Ленинградская, 122, телефон: 32363	Россия, Краснодарский край, Армавир, поселок Стар. Станица	0101000020E61000001CB3EC496093444005FA449E24814640
44440	2	20	\N	8849	20536	\N	44.986615437012901	Краснодарский край, город Армавир, ул.Ленина, 258, телефон: 33010	Россия, Краснодарский край, Армавир	0101000020E610000068226C787A9344401C5F7B66497E4640
44438	2	20	\N	8849	20536	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Ленина, 96, телефон: 33341		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44430	2	20	\N	8849	20536	\N	44.997137314114397	Краснодарский край, город Армавир, ул.Ленина, 103, телефон: 39036	Россия, Краснодарский край, Армавир	0101000020E6100000BDAB1E300F914440D7506A2FA27F4640
44428	2	20	\N	8849	20536	\N	45.004353155193101	Краснодарский край, город Армавир, ул.Ленина, 28, телефон: 39023	Россия, Краснодарский край, Армавир	0101000020E6100000A4C4AEEDED8E4440DB519CA38E804640
44449	2	20	\N	8849	20793	\N	44.964466908391501	Краснодарский край, город Армавир, ул.Лавриненко, 5-а, телефон: 35200	Россия, Краснодарский край, Армавир	0101000020E6100000408864C8B19144401E8997A7737B4640
44446	2	20	\N	8849	20793	\N	44.973536899621102	Краснодарский край, город Армавир, ул.Лавриненко, 172-а, телефон: 35810		0101000020E6100000D0ED258DD1924440153944DC9C7C4640
44443	2	20	\N	8849	20793	\N	44.979889568726101	Краснодарский край, город Армавир, ул.Лавриненко, 1, телефон: 47974	Россия, Краснодарский край, Армавир	0101000020E61000006E14596B288F4440B6D617096D7D4640
44460	2	20	\N	8849	20445	\N	44.989333852120502	Краснодарский край, город Армавир, ул.Кропоткина, 103, телефон: 20041		0101000020E61000001D007157AF8E444012691B7FA27E4640
44441	2	20	\N	8849	21432	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Кочубея, 47, телефон: 33566		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44437	2	20	\N	8849	21433	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Комсомольская, 136, телефон: 33579		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44486	2	20	\N	8849	21461	\N	44.8341753202223	Краснодарский край, город Армавир, х.Первомайский, ул.Комсомольская, 14, телефон: 40009	Россия, Краснодарский край, Армавир, поселок Первомайский	0101000020E610000085268925E59444400612143FC66A4640
44456	2	20	\N	8849	20569	\N	44.9942442985257	Краснодарский край, город Армавир, ул.Кирова, 57, телефон: 73496	Россия, Краснодарский край, Армавир	0101000020E6100000C2D9AD6532904440431F2C63437F4640
44454	2	20	\N	8849	20569	\N	44.978186709036002	Краснодарский край, город Армавир, ул.Кирова, 127, телефон: 73956	Россия, Краснодарский край, Армавир	0101000020E6100000639CBF0985904440A92F4B3B357D4640
44453	2	20	\N	8849	20569	\N	44.991526475876299	Краснодарский край, город Армавир, ул.Кирова, 129, телефон: 73765	Россия, Краснодарский край, Армавир	0101000020E61000006E52D158FB8D44401D91EF52EA7E4640
44432	2	20	\N	8849	20569	\N	44.920647000000002	г.Армавир, ул.Кирова		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44431	2	20	\N	8849	20569	\N	44.979648753761303	Краснодарский край, город Армавир, ул.Кирова, 43, телефон: 32487	Россия, Краснодарский край, Армавир	0101000020E6100000FFEC478AC890444091477023657D4640
44463	2	20	\N	8849	21234	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Калинина, 32, телефон: 53773		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44458	2	20	\N	8849	22031	\N	44.994845703931503	Краснодарский край, город Армавир, ул.К.Маркса, 156, телефон: 23438	Россия, Краснодарский край, Армавир	0101000020E6100000BABDA4315A8F444039471D1D577F4640
44433	2	20	\N	8849	20776	\N	44.980623429394399	Краснодарский край, город Армавир, ул.К.Либкнехта, 48, телефон: 32450	Россия, Краснодарский край, Армавир	0101000020E6100000DAA84E07B29044404B5AF10D857D4640
44457	2	20	\N	8849	20454	\N	44.9779430312663	Краснодарский край, город Армавир, ул.Ефремова, 57, телефон: 22395	Россия, Краснодарский край, Армавир	0101000020E6100000098849B890894440132D793C2D7D4640
44392	2	20	\N	8849	20454	\N	44.990118029344103	г.Армавир, ул. Ефремова, 123	Россия, Краснодарский край, Армавир	0101000020E610000010CCD1E3F78C44402997C62FBC7E4640
44479	2	20	\N	8849	21792	\N	44.997312160901402	"г.Армавир СПК ""Восток"" ул.Донская,6б"	Россия, Краснодарский край, Армавир	0101000020E610000081ED60C43E8F444045F46BEBA77F4640
44331	2	20	\N	7955	22706	\N	44.997979999999998	город-курорт Анапа, с.Витязево, Лиманная, 8, телефон: 73250		0101000020E6100000E5EC9DD156A34240F20703CFBD7F4640
44451	2	20	\N	8849	21440	\N	44.973792734173799	Краснодарский край, город Армавир, ул.Гоголя, 207, телефон: 46022	Россия, Краснодарский край, Армавир	0101000020E610000054742497FF9244407009C03FA57C4640
44464	2	20	\N	8849	21668	\N	44.9918310002749	Краснодарский край, город Армавир, ул.Володарского, 2, телефон: 21347	Россия, Краснодарский край, Армавир	0101000020E61000006D904946CE8E444059147651F47E4640
44461	2	20	\N	8849	21668	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Володарского, 68, телефон: 21709		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44455	2	20	\N	8849	21668	\N	44.920647000000002	Краснодарский край, город Армавир, ул.Володарского, 120, телефон: 71132		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44492	2	20	\N	8849	20495	\N	44.920647000000002	Краснодарский край, город Армавир, п.ВИМ, ул.Академическая, телефон: 27143	Россия, Краснодарский край, Армавир	0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44478	2	20	\N	8849	20835	\N	44.981110760955801	Краснодарский край, город Армавир, ул.Азовская, 20, телефон: 51347	Россия, Краснодарский край, Армавир	0101000020E6100000639CBF0985904440785F950B957D4640
44477	2	20	\N	8849	20835	\N	44.9839500215774	Краснодарский край, город Армавир, ул.Азовская,22, 169-а, телефон: 78123	Россия, Краснодарский край, Армавир	0101000020E61000007007EA94478944401973D712F27D4640
44466	2	20	\N	8849	21238	\N	44.920647000000002	Краснодарский край, город Армавир, ул.30 лет Победы, 110, телефон: 27858		0101000020E6100000A5F44C2F318A44408C14CAC2D7754640
44369	2	20	\N	50361	22339	\N	44.472883497121202	г. Апшеронск, Репина, 49/б, телефон: 28368	Россия, Краснодарский край, Апшеронский район, город Апшеронск	0101000020E6100000A9FA95CE87DB4340CDEA1D6E873C4640
44374	2	20	\N	50361	21590	\N	44.453890000000001	г. Апшеронск, Лесозаводская, 78, телефон: 28822		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44382	2	20	\N	50361	21393	\N	44.453044718618102	г.Апшеронск, Ленина, 224,	Россия, Краснодарский край, Апшеронский район, город Апшеронск	0101000020E6100000516C054D4BDE4340E44EE960FD394640
44322	2	20	\N	9001	22900	\N	44.890336117521798	"город-курорт Анапа, ст.Анапская, Кавказская, 90 ""А"", телефон: 71798"	Россия, Краснодарский край, Анапская, Кавказская улица	0101000020E6100000B3D2A41474B14240C939B187F6714640
44313	2	20	\N	7955	\N	\N	44.885935000000003	город-курорт Анапа, 12 микрорайон, 8, телефон: 36746	Россия, Краснодарский край, Анапа, 12-й микрорайон, 8	0101000020E6100000CA5356D3F5AA4240DEB06D5166714640
44307	2	20	\N	7955	16167	\N	44.884064000000002	город-курорт Анапа, Некрасова, 114, телефон: 42498	Россия, Краснодарский край, Анапа, улица Некрасова, 114	0101000020E6100000B6114F7633A9424015C9570229714640
44309	2	20	\N	7955	21274	\N	44.883280195949297	город-курорт Анапа, Ленина, МБОУ СОШ №7, телефон: 45686	Россия, Краснодарский край, Анапа, улица Ленина	0101000020E6100000E65C8AABCAA84240FE9AAC510F714640
44365	2	20	\N	7955	22986	\N	45.005845000000001	город-курорт Анапа,с.Витязево, Школьная, 4, телефон: 73377		0101000020E61000000E2F88484DA542402DEC6987BF804640
44350	2	20	\N	7955	22986	\N	45.1046213925597	город-курорт Анапа, х.Чекон, Школьная, 1, телефон: 98168		0101000020E6100000A1116C5CFFC04240C7BC8E38648D4640
44299	2	20	\N	7955	23750	\N	44.892040000000001	город  Анапа, Черноморская, 11, телефон: 43604, факс: 43604, email: УИК 201@mail.ru		0101000020E610000004C6FA0626A74240A75CE15D2E724640
44343	2	20	\N	7955	23263	\N	45.0932191165573	"город-курорт Анапа, х.Уташ, Центральная, 165 ""В"", телефон: 96519"	Россия, Краснодарский край, Анапский район, поселок Уташ	0101000020E61000002E1EDE7360A94240D32EA699EE8B4640
44315	2	20	\N	7955	22796	\N	44.896887987919598	город-курорт Анапа, Тургенева, 261, телефон: 32820	Россия, Краснодарский край, Анапа, улица Тургенева, 261	0101000020E6100000BEBD6BD097AA42406116DA39CD724640
44304	2	20	\N	7955	23910	\N	44.900717999999998	город-курорт Анапа, Терская, 190, телефон: 42639		0101000020E6100000960854FF20AA4240927538BA4A734640
44332	2	20	\N	7955	21607	\N	45.053053915729798	"город-курорт Анапа, п.Виноградный, Таманская, 2 ""В"", телефон: 96127"	Россия, Краснодарский край, Анапский район, поселок Виноградный	0101000020E6100000D11F9A7972A9424004763579CA864640
44367	2	20	\N	7955	23348	\N	44.905307999999998	город-курорт Анапа, Спортивная, 8, телефон: 40178		0101000020E610000007EA944737AC42405167EE21E1734640
44326	2	20	\N	7955	22957	\N	44.857673281511097	город-курорт Анапа,  х.Бужор, Солнечная, 43, телефон: 72986	Россия, Краснодарский край, Анапский район, поселок Бужор	0101000020E610000032923D42CDB44240C3D4963AC86D4640
44327	2	20	\N	7955	23057	\N	44.903112307413103	"город-курорт Анапа,  х.Курбацкий, Свободы, 9 ""А"", телефон: 71661"		0101000020E61000003E5DDDB1D8B0424005508C2C99734640
44325	2	20	\N	7955	23057	\N	44.903002999999998	город-курорт Анапа, ст.Анапская, Свободы, 10, телефон: 71776		0101000020E61000000B9B012EC8B042404E98309A95734640
44300	2	20	\N	7955	23813	\N	44.886740000000003	город  Анапа, Самбурова, 19, телефон: 54078, факс: 54078		0101000020E610000058703FE081A742400C0742B280714640
44317	2	20	\N	7955	2457	\N	44.948365000000003	город-курорт Анапа, Пионерский проспект, 103, телефон: 33351	Россия, Краснодарский край, Анапа, Пионерский проспект, 103	0101000020E61000008638D6C56DA64240E5D5390664794640
44310	2	20	\N	7955	23783	\N	44.889620000000001	город-курорт Анапа, Парковая, 29, телефон: 50001		0101000020E6100000EF703B342CAA42400BEF7211DF714640
44366	2	20	\N	7955	22804	\N	44.876285000000003	город-курорт Анапа, Омелькова, 32, телефон: 27450		0101000020E610000084622B685AAA4240D97C5C1B2A704640
44323	2	20	\N	7955	23017	\N	44.906317911013304	город-курорт Анапа,  ст.Анапская, Набережная, 148, телефон: 71795	Россия, Краснодарский край, Анапская, улица Набережная	0101000020E61000003EE76ED74BB1424058E36C3A02744640
44333	2	20	\N	7955	23095	\N	45.091070205062501	город-курорт Анапа, х.Уташ, Мира, 5, телефон: 96127		0101000020E61000006E88F19A57A94240C8D2872EA88B4640
44324	2	20	\N	7955	23095	\N	44.900545000000001	город-курорт Анапа, ст.Анапская, Мира, 46, телефон: 71875		0101000020E61000004A9BAA7B64B14240C5C9FD0E45734640
44320	2	20	\N	7955	23095	\N	44.900545000000001	город-курорт Анапа,  ст.Анапская, Мира, 25, телефон: 71774		0101000020E61000004A9BAA7B64B14240C5C9FD0E45734640
44330	2	20	\N	7955	22706	\N	44.997979999999998	город-курорт Анапа, с.Витязево, Лиманная, 8, телефон: 74529		0101000020E6100000E5EC9DD156A34240F20703CFBD7F4640
44316	2	20	\N	7955	23814	\N	44.905448	город-курорт Анапа, Ленинградская, 75, телефон: 52777		0101000020E6100000AE2B6684B7AB4240431D56B8E5734640
44349	2	20	\N	7955	22677	\N	44.8778185788127	город-курорт Анапа, Ленина, 159, телефон: 56449	Россия, Краснодарский край, Анапа, улица Ленина, 159	0101000020E6100000C6353E93FDA942405A677C5F5C704640
44301	2	20	\N	7955	23702	\N	44.881183999999998	город Анапа, Ленина, 125, телефон: 42949, факс: 42949		0101000020E6100000ED9DD15625A9424015E126A3CA704640
44314	2	20	\N	7955	23961	\N	44.901361999999999	город-курорт Анапа, Крымская, 209, телефон: 50837		0101000020E6100000224F92AE99AA4240B7ED7BD45F734640
44305	2	20	\N	7955	23961	\N	44.900418000000002	город-курорт Анапа, Крымская, 179, телефон: 56219		0101000020E61000007B67B45549AA4240685DA3E540734640
44303	2	20	\N	7955	23961	\N	44.896279999999997	город Анапа, Крымская, 115, телефон: 56734, факс: 56734		0101000020E61000000E30F31DFCA842408907944DB9724640
44302	2	20	\N	7955	23961	\N	44.893362000000003	город Анапа, Крымская, 122, телефон: 52848, факс: 52848		0101000020E6100000BB7F2C4487A842409DBE9EAF59724640
44308	2	20	\N	7955	23911	\N	44.879235999999999	"город-курорт Анапа, Крылова, 18 ""А"", телефон: 31986"		0101000020E6100000F698486936A94240A1BB24CE8A704640
44321	2	20	\N	7955	22704	\N	44.897250999999997	"город-курорт Анапа,  ст.Анапская, Комсомольская, 75 ""А"", телефон: 71836"		0101000020E6100000E3C798BB96B04240D2A6EA1ED9724640
44336	2	20	\N	7955	23320	\N	44.895583999999999	город-курорт Анапа, х.Рассвет, Коммунаров, 41, телефон: 75129		0101000020E6100000D0EE906280BA424012691B7FA2724640
44337	2	20	\N	7955	22814	\N	44.947497004811197	город-курорт Анапа, х.Заря, Дружбы, 4, телефон: 75142	Россия, Краснодарский край, Анапа, улица Дружбы	0101000020E61000003F70952710A842407007EA9447794640
44335	2	20	\N	7955	22814	\N	44.857982455800901	город-курорт Анапа, с.Гайкодзор, Дружбы, 50, телефон: 77274	Россия, Краснодарский край, Анапский район, поселок Гай-Кодзор	0101000020E6100000289EB30584B842404147AB5AD26D4640
44311	2	20	\N	7955	20618	\N	44.884824000000002	город-курорт Анапа, 12 микрорайон, МАОУ СОШ №6, телефон: 35446	Россия, Краснодарский край, Анапа, Гребенская улица	0101000020E61000001363997E89AA4240A35BAFE941714640
44319	2	20	\N	7955	16163	\N	44.883068000000002	город-курорт Анапа, Астраханская, 88, телефон: 42676	Россия, Краснодарский край, Анапа, Астраханская улица, 88	0101000020E610000085EFFD0DDAA9424073124A5F08714640
44306	2	20	\N	7955	23867	\N	44.887072000000003	город-курорт Анапа, Астраханская, 62, телефон: 42667		0101000020E61000003D9E961FB8A84240429946938B714640
44693	2	20	\N	50767	23558	\N	44.6022816317261	с. Адербиевка, Октябрьская, 49, телефон: 67732		0101000020E6100000E1D05B3CBC0D4340187C9A93174D4640
46307	2	20	842	50438	\N	\N	43.685088	г. Сочи, Адлерский район, Село  Эсто-Садок, ГТС	Россия, Краснодарский край, городской округ Сочи, поселок Эстосадок	0101000020E61000007C48F8DEDF204440E770ADF6B0D74540
46292	2	20	842	50438	\N	\N	43.6829288726831	с.Эсто-Садок, телефон: 439039		0101000020E61000008318E8DA17224440B83EAC376AD74540
46310	2	20	842	50438	75507	\N	43.685088	г. Сочи, Адлерский район, Село Эсто-Садок,  2-ая бригада	Россия, Краснодарский край, городской округ Сочи, поселок Эстосадок	0101000020E61000007C48F8DEDF204440E770ADF6B0D74540
46321	2	20	842	50263	20567	\N	44.049119892811298	аул Наджиго, Зыхы, 18, телефон: 74-71-96	Россия, Краснодарский край, городской округ Сочи, поселок Наджиго	0101000020E61000002FFA0AD28CA143402ECA6C9049064640
46303	2	20	842	60652	\N	\N	43.594242000000001	г. Сочи, Адлерский район, Село  Монастырь, Пикет № 234	Россия, Краснодарский край, городской округ Сочи, поселок Монастырь	0101000020E61000003B376DC6690044406FF4311F10CC4540
46305	2	20	842	46911	\N	\N	43.681221999999998	г. Сочи, Адлерский район, Поселок Красная Поляна,  Общество с ограниченной ответственностью «ЧЗК-Юг» Пикет № 391	Россия, Краснодарский край, городской округ Сочи, поселок Красная Поляна	0101000020E6100000D046AE9B521A444069A8514832D74540
46289	2	20	842	46911	21424	\N	43.681221999999998	п.Красная Поляна, Турчинского, 29, телефон: 437479	Россия, Краснодарский край, городской округ Сочи, поселок Красная Поляна	0101000020E6100000D046AE9B521A444069A8514832D74540
46306	2	20	842	46911	75539	\N	43.681221999999998	Поселок Красная Поляна, «БТС-Гидрострой», Пикет № 397		0101000020E6100000D046AE9B521A444069A8514832D74540
46291	2	20	842	46911	22679	\N	43.6766749267669	п.Красная Поляна, Защитников Кавказа, телефон: 437169	Россия, Краснодарский край, городской округ Сочи, поселок Красная Поляна	0101000020E6100000853FC39B351A4440AA8251499DD64540
46301	2	20	842	46911	75536	\N	43.681221999999998	г. Сочи, Адлерский район, 12-й км дороги Адлер - Красная Поляна, Пикет № 125		0101000020E6100000D046AE9B521A444069A8514832D74540
46287	2	20	842	8516	\N	\N	43.617128000000001	с.Кепша, телефон: 439536	Россия, Краснодарский край, городской округ Сочи, поселок Кепша	0101000020E6100000ED7DAA0A0D06444013B9E00CFECE4540
46279	2	20	842	50721	23457	\N	43.619573009318401	с.Калиновое Озеро, Центральная, 10, телефон: 659950	Россия, Краснодарский край, городской округ Сочи, поселок Калиновое Озеро	0101000020E61000004E603AADDBF04340083E062B4ECF4540
46314	2	20	842	50400	21649	\N	44.008658881216398	аул Калеж, Адыгахабль, 62, телефон: 76-92-30		0101000020E61000004208C89750AD434075E8F4BC1B014640
46241	2	20	842	45550	\N	\N	43.512763	с.Ермоловка, нет, телефон: сотовая связь	Россия, Краснодарский край, городской округ Сочи, поселок Ермоловка	0101000020E61000004E603AADDB064440A7CCCD37A2C14540
44360	2	20	842	49189	20668	\N	43.693646999999999	с.Варваровка, Калинина, 60, телефон: 91651, факс: 91651, email: уик260@mail.ru	Россия, Краснодарский край, городской округ Сочи, поселок Варваровка	0101000020E6100000FBE6FEEA71D94340F8FBC56CC9D84540
46302	2	20	842	6355	\N	\N	43.511783000000001	г. Сочи, Адлерский район, Село  Ахштырь, Пикет № 131	Россия, Краснодарский край, городской округ Сочи, поселок Ахштырь	0101000020E61000000FD3BEB9BF0044400BD3F71A82C14540
46242	2	20	842	6355	21328	\N	43.511783000000001	с.Ахштырь, Кропоткинская, 17а, телефон: 431128		0101000020E61000000FD3BEB9BF0044400BD3F71A82C14540
46240	2	20	842	6240	\N	\N	43.586517000000001	c.Аибга, нет, телефон: сотовая связь	Россия, Краснодарский край, городской округ Сочи, поселок Аибга	0101000020E610000019E3C3EC6519444026C632FD12CB4540
44723	2	20	1844	28335	20436	\N	44.669539	поселок Широкая Балка, Красная, 3, телефон: 4-86-31		0101000020E61000005C04C6FA06D84240C2323674B3554640
46948	2	20	1844	50250	20970	\N	44.834206453295302	Краснодарский край, город Новороссийск, ст. Раевская, Нижняя, 3, телефон: 8-918-48-48-354	Россия, Краснодарский край, городской округ Новороссийск, поселок Раевская	0101000020E61000006EA301BC05C8424041102043C76A4640
46946	2	20	1844	50250	22577	\N	44.832823583616602	Краснодарский край, город Новороссийск, ст. Раевская, Ленина, 27, телефон: 27-05-53	Россия, Краснодарский край, городской округ Новороссийск, поселок Раевская	0101000020E6100000234E27D9EAC6424076A911FA996A4640
46947	2	20	1844	50250	20477	\N	44.8354013029277	Краснодарский край, город Новороссийск, ст. Раевская, Красная, 40, телефон: 27-01-38	Россия, Краснодарский край, городской округ Новороссийск, поселок Раевская	0101000020E6100000A5D8D138D4C74240D905836BEE6A4640
46930	2	20	1844	45533	22058	\N	44.708680000000001	с.Глебовское ул.Чехова 1		0101000020E61000003868AF3E1ED2424026AAB706B65A4640
46933	2	20	1844	50249	20464	\N	44.785859000000002	Краснодарский край, город Новороссийск, п. Гайдук, Гагарина, 5, телефон: 26-94-47	Россия, Краснодарский край, городской округ Новороссийск, поселок Гайдук	0101000020E6100000E659492BBED942403622180797644640
46938	2	20	1844	50321	21683	\N	44.841691834388499	Краснодарский край, город Новороссийск, п. Верхнебаканский, Титан, 22, телефон: 276228	Россия, Краснодарский край, городской округ Новороссийск, поселок Верхнебаканский	0101000020E610000004E44BA8E0D4424005A73E90BC6B4640
46937	2	20	1844	50321	21051	\N	44.841450999999999	Краснодарский край, город Новороссийск, п. Верхнебаканский, Орловская, 11, телефон: 27-65-23	Россия, Краснодарский край, городской округ Новороссийск, поселок Верхнебаканский	0101000020E6100000DC679599D2D44240DF1797AAB46B4640
46927	2	20	1844	50487	22313	\N	44.744856514222803	Краснодарский край, город Новороссийск, х. Большие Хутора, Солнечная, 19, телефон: 27-59-33	Россия, Краснодарский край, городской округ Новороссийск, поселок Бол. Хутора	0101000020E6100000685E0EBBEFCC42402D996379575F4640
46925	2	20	1844	50308	20986	\N	44.716687782829901	Краснодарский край, город Новороссийск, п. Абрау-Дюрсо, ул. Островского, 8, телефон: 27-54-24	Россия, Краснодарский край, городской округ Новороссийск, поселок Абрау-Дюрсо	0101000020E61000006938656EBECB4240C3B7B06EBC5B4640
44706	2	20	1783	27612	21082	\N	44.372464000000001	с. Тешебс, Ленина, б/н, телефон: 61321		0101000020E6100000774EB340BB4B4340FB777DE6AC2F4640
44700	2	20	1783	27317	20640	\N	44.472597999999998	с. Пшада, Советская, 26а, телефон: 68343		0101000020E6100000F984ECBC8D334340D7135D177E3C4640
44668	2	20	1783	25873	20838	\N	44.474668999999999	с. Прасковеевка, Морская, 12, телефон: 62823		0101000020E610000044A852B3071C434067B62BF4C13C4640
44699	2	20	1783	50903	24041	\N	44.5154260614338	с. Михайловский Перевал, Школьная, 2, телефон: 98646	Россия, Краснодарский край, городской округ Геленджик, поселок Михайловский Перевал	0101000020E6100000EE5A423EE827434009C1AA7AF9414640
44692	2	20	1783	46814	20608	\N	44.668078000000001	с. Кабардинка, Революционная, 69, телефон: 65493		0101000020E6100000299485AFAFF54240AB96749483554640
44691	2	20	1783	46814	20863	\N	44.668078000000001	с. Кабардинка, Партизанская, 11, телефон: 65251		0101000020E6100000299485AFAFF54240AB96749483554640
44697	2	20	1783	27126	21506	\N	44.501280072123599	с. Дивноморское, Кирова, 17, телефон: 63252	Россия, Краснодарский край, городской округ Геленджик, поселок Дивноморское	0101000020E6100000EF1CCA5015114340C7116BF129404640
44696	2	20	1783	27126	21619	\N	44.518165000000003	с. Дивноморское, Горная, 23, телефон: 63639		0101000020E61000001477BCC96F1143404777103B53424640
44701	2	20	1783	50480	22244	\N	44.420563000000001	с. Береговое, Мира, 27, телефон: 68454	Россия, Краснодарский край, городской округ Геленджик, поселок Береговое	0101000020E610000032E4D87A862E43402E742502D5354640
44705	2	20	1783	27504	21296	\N	44.375061000000002	п. Архипо-Осиповка, Рабочая, 5, телефон: 61890		0101000020E61000007D2079E750444340A680B4FF01304640
44704	2	20	1783	27504	20791	\N	44.375061000000002	с. Архипо-Осиповка, Ленина, 116, телефон: 60248		0101000020E61000007D2079E750444340A680B4FF01304640
44707	2	20	1783	27504	22187	\N	44.375061000000002	с. Архипо-Осиповка, Красных партизан, 2а, телефон: 60555		0101000020E61000007D2079E750444340A680B4FF01304640
46893	2	20	776	5937	21237	\N	46.632894	пос. Щербиновский ул. К. Маркса, 12		0101000020E61000004D840D4FAF404340D5EAABAB02514740
46894	2	20	776	5987	21288	\N	46.851851000000003	село Шабельское, ул. Ленина, 20, телефон: 3-56-36		0101000020E6100000BF0F0709513C43404F081D74096D4740
46885	2	20	776	5481	21065	\N	46.629373000000001	станица Старощербиновская, ул. Шевченко, 195, телефон: 4-18-09		0101000020E6100000664CC11A6755434022FE614B8F504740
46884	2	20	776	5481	21065	\N	46.629373000000001	станица Старощербиновская, ул. Шевченко, 226, телефон: 4-14-11		0101000020E6100000664CC11A6755434022FE614B8F504740
46890	2	20	776	5481	21487	\N	46.629373000000001	станица Старощербиновская, ул. Тельмана, 183, телефон: 4-21-80		0101000020E6100000664CC11A6755434022FE614B8F504740
46887	2	20	776	5481	22605	\N	46.618847082945898	станица Старощербиновская, ул. Ленина, 170, телефон: 7-73-32	Россия, Краснодарский край, Щербиновский район, поселок Старощербиновская	0101000020E610000007978E39CF544340261DE560364F4740
46889	2	20	776	5481	20610	\N	46.629373000000001	станица Старощербиновская, ул. Красноармейская, 16, телефон: 4-23-47		0101000020E6100000664CC11A6755434022FE614B8F504740
46888	2	20	776	5481	21477	\N	46.629373000000001	станица Старощербиновская, ул. Красная, 3, телефон: 4-44-53		0101000020E6100000664CC11A6755434022FE614B8F504740
90433	1	13	452	46217	\N	\N	54.968153000000001	д.Новосельский, д.70		0101000020E610000056D28A6F28A43F401C430070EC7B4B40
46886	2	20	776	50466	22105	\N	46.629373000000001	станица Старощербиновская, ул. Первомайская, 93, телефон: 4-44-48		0101000020E6100000664CC11A6755434022FE614B8F504740
46891	2	20	776	5812	20862	\N	46.474165999999997	станица Новощербиновская, ул. Советов, 7, телефон: 3-05-34		0101000020E6100000CFA10C55315343400470B378B13C4740
46892	2	20	776	5812	21493	\N	46.473559596393798	станица Новощербиновская, ул. Мира, 39, телефон: 3-05-47	Россия, Краснодарский край, Щербиновский район, поселок Новощербиновская	0101000020E6100000AB5D13D21A534340CD58349D9D3C4740
46897	2	20	776	49293	21997	\N	46.731910999999997	село Николаевка, ул. 2-я Пятилетка, 7, телефон: 3-29-33		0101000020E6100000F52A323A20494340944A7842AF5D4740
46900	2	20	776	6311	20612	\N	46.814959999999999	хутор Любимов, ул. Мира, 2/2, телефон: 3-31-41		0101000020E6100000E59B6D6E4C6343402AC6F99B50684740
46901	2	20	776	6363	22172	\N	46.673589999999997	хутор Красный Дар, пер. Бригадный, 9, телефон: 3-84-09		0101000020E61000003C4ED1915C6C4340D174763238564740
46898	2	20	776	49302	21021	\N	46.692360000000001	село Екатериновка, пер. Советов, 22, телефон: 3-83-84		0101000020E6100000A913D044D86043407F87A2409F584740
46899	2	20	776	49302	21520	\N	46.692360000000001	село Екатериновка, ул. Крестьянская, 5/2, телефон: 3-88-76	Россия, Краснодарский край, Щербиновский район, поселок Екатериновка	0101000020E6100000A913D044D86043407F87A2409F584740
46896	2	20	776	50828	23782	\N	46.7078587940685	cело Еское Укрепление, ул. Советов, 2, телефон: 3-72-91	Россия, Краснодарский край, Щербиновский район, поселок Ейское Укрепление	0101000020E61000002331410DDF4E4340F296AB1F9B5A4740
46895	2	20	776	49260	22467	\N	46.763649999999998	село Глафировка, ул. Первомайская, 56, телефон: 3-43-71		0101000020E6100000F6436CB07034434092CB7F48BF614740
46858	2	20	421	45493	21523	\N	45.358971059076197	п. Южный, Школьная, 20, телефон: 33-7-06	Россия, Краснодарский край, Усть-Лабинский район, поселок Южный	0101000020E6100000B5C6A01342EB4340309B00C3F2AD4640
44858	2	20	421	45493	20709	\N	45.359727999999997	пос.Южный, Советская, 31, телефон: 44-1-82		0101000020E610000000378B170BEB43404DBA2D910BAE4640
46068	2	20	421	45493	21099	\N	45.359727999999997	поселок Южный, Кирова, 41, телефон: 3-75-55		0101000020E610000000378B170BEB43404DBA2D910BAE4640
46827	2	20	421	2261	21521	\N	45.218679000000002	г. Усть-Лабинск, Энгельса, 71, телефон: 4-56-08		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46834	2	20	421	2261	20506	\N	45.218679000000002	г. Усть-Лабинск, Советская, 56, телефон: 2-31-24		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46826	2	20	421	2261	20490	\N	45.218679000000002	г. Усть-Лабинск, Рубина, 30, телефон: 2-24-43		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46845	2	20	421	2261	21148	\N	45.218679000000002	г. Усть-Лабинск, Пролетарская, 79, телефон: 4-51-56		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46828	2	20	421	2261	21148	\N	45.218679000000002	г. Усть-Лабинск, Пролетарская, 104, телефон: 4-51-70		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46838	2	20	421	2261	20742	\N	45.213974455692899	г. Усть-Лабинск, Позиционная, 171, телефон: 2-16-32	Россия, Краснодарский край, Усть-Лабинский район, город Усть-Лабинск	0101000020E610000071AB2006BAD64340DF180280639B4640
46839	2	20	421	2261	20456	\N	45.218679000000002	г. Усть-Лабинск, Островского, 13, телефон: 2-24-00		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46836	2	20	421	2261	20456	\N	45.218679000000002	г. Усть-Лабинск, Островского, 63, телефон: 5-18-65		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46835	2	20	421	2261	20743	\N	45.213947203106997	г. Усть-Лабинск, Октябрьская, 117, телефон: 4-18-52	Россия, Краснодарский край, Усть-Лабинский район, город Усть-Лабинск	0101000020E610000034F44F70B1D64340E509849D629B4640
46829	2	20	421	2261	21571	\N	45.218679000000002	г. Усть-Лабинск, Ободовского, 153-А, телефон: 4-51-60		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46833	2	20	421	2261	21385	\N	45.215582098016	г. Усть-Лабинск, Ленина, 62, телефон: 2-35-18		0101000020E61000007D772B4B74D843409ACDE330989B4640
46832	2	20	421	2261	20500	\N	45.218679000000002	г. Усть-Лабинск, Куйбышева, 31, телефон: 2-29-14		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46825	2	20	421	2261	21057	\N	45.218679000000002	г. Усть-Лабинск, Комсомольская, 212, телефон: 4-18-67		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46830	2	20	421	2261	21156	\N	45.218679000000002	г. Усть-Лабинск, Кавказская, 28, телефон: 2-24-04		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46840	2	20	421	2261	20513	\N	45.218679000000002	г. Усть-Лабинск, Демьяна Бедного, 101, телефон: 2-16-86		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46842	2	20	421	2261	20940	\N	45.218679000000002	г. Усть-Лабинск, Воронежская, 2-А, телефон: 2-20-86		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46831	2	20	421	2261	20496	\N	45.218679000000002	г. Усть-Лабинск, Вокзальная, 37, телефон: 2-15-29		0101000020E6100000A4367172BFD7434037A968ACFD9B4640
46879	2	20	421	50684	23385	\N	45.098880999999999	ст. Тенгинская, Мира, 23, телефон: 56-4-25	Россия, Краснодарский край, Усть-Лабинский район, поселок Тенгинская	0101000020E61000000283A44FAB0244400F99F221A88C4640
46877	2	20	421	5068	20841	\N	45.281301999999997	с. Суворовское, Чапаева, 61/1, телефон: 57-4-75		0101000020E6100000558A1D8D43BB4340522635B401A44640
46878	2	20	421	5068	20745	\N	45.281301999999997	с. Суворовское, ул. Ленина, 80		0101000020E6100000558A1D8D43BB4340522635B401A44640
46850	2	20	421	50803	23652	\N	45.234089082954299	х. Согласный, Советская, 55, телефон: 79-4-46	Россия, Краснодарский край, Усть-Лабинский район, поселок Согласный	0101000020E610000036ACA92C0AFD43403AADDBA0F69D4640
46852	2	20	421	50676	23350	\N	45.209649072279397	х. Саратовский, Мира, 63-А, телефон: 79-0-63	Россия, Краснодарский край, Усть-Лабинский район, поселок Саратовский	0101000020E6100000EACE13CFD9FE4340CE5147C7D59A4640
46876	2	20	421	4970	21250	\N	45.113881999999997	ст. Новолабинская, Красноармейская, 63, телефон: 36-2-56		0101000020E6100000D36A48DC63F3434031CD74AF938E4640
46875	2	20	421	4970	20747	\N	45.113881999999997	ст. Новолабинская, Калинина, 12, телефон: 36-2-31		0101000020E6100000D36A48DC63F3434031CD74AF938E4640
46872	2	20	421	50774	23751	\N	45.146308032768502	ст. Некрасовская, Советская, 8, телефон: 78-1-77	Россия, Краснодарский край, Усть-Лабинский район, поселок Некрасовская	0101000020E61000005551BCCADAE0434053927538BA924640
46812	2	20	251	1488	\N	\N	44.861246999999999	село Коноково, сельский Дом культуры, телефон: 68203		0101000020E6100000E415889E94A94440996379573D6E4640
46871	2	20	421	50774	23571	\N	45.144256359157801	ст. Некрасовская, Ленина, 11, телефон: 78-1-67	Россия, Краснодарский край, Усть-Лабинский район, поселок Некрасовская	0101000020E6100000A379008BFCE043403A2009FB76924640
46865	2	20	421	50283	23781	\N	45.306283000000001	ст. Ладожская, Школьная, 17, телефон: 70-5-80	Россия, Краснодарский край, Усть-Лабинский район, поселок Ладожская	0101000020E61000007098689082F743400F29064834A74640
46883	2	20	421	50283	23612	\N	45.305124074310903	ст. Ладожская, ул. Красная, 98/А,	Россия, Краснодарский край, Усть-Лабинский район, поселок Ладожская	0101000020E61000004E64E60297F74340C39CA04D0EA74640
46869	2	20	421	50283	20746	\N	45.313763422095398	ст. Ладожская, Коншиных, 98, телефон: 70-4-33	Россия, Краснодарский край, Усть-Лабинский район, поселок Ладожская	0101000020E610000038F7578FFBF84340F1D8CF6229A84640
46868	2	20	421	50283	20746	\N	45.306859179192301	ст. Ладожская, ул. Коншиных, 167-Б	Россия, Краснодарский край, Усть-Лабинский район, поселок Ладожская	0101000020E61000002046088F36F84340DCBDDC2747A74640
46866	2	20	421	50283	21413	\N	45.308157985175797	ст. Ладожская, Комсомольская, 132	Россия, Краснодарский край, Усть-Лабинский район, поселок Ладожская	0101000020E6100000FAB5F5D37FF843401900AAB871A74640
46881	2	20	421	50708	23455	\N	45.374810013552199	ст. Кирпильская, ул. Советская, 2, телефон: 58-2-15	Россия, Краснодарский край, Усть-Лабинский район, поселок Кирпильская	0101000020E610000046EA3D95D3D843405C1B2AC6F9AF4640
46288	2	20	421	50708	23455	\N	45.375858560646499	ст. Кирпильская, Советская, 41	Россия, Краснодарский край, Усть-Лабинский район, поселок Кирпильская	0101000020E610000046EA3D95D3D843402174D0251CB04640
46126	2	20	421	50708	23575	\N	45.375535933210799	ст. Кирпильская, Красная, 45	Россия, Краснодарский край, Усть-Лабинский район, поселок Кирпильская	0101000020E6100000A7C98CB795D843403E3C4B9011B04640
46864	2	20	421	50708	23440	\N	45.377552000000001	ст. Кирпильская, Административное здание кирпичного завода, телефон: 58-0-02	Россия, Краснодарский край, Усть-Лабинский район, поселок Кирпильская	0101000020E6100000D47D00529BD843400B45BA9F53B04640
46873	2	20	421	50838	23833	\N	45.188650567502002	х. Кадухин, Степная, 19, телефон: 39-5-25	Россия, Краснодарский край, Усть-Лабинский район, поселок Кадухин	0101000020E6100000BB438A0112E74340C9AD49B725984640
46862	2	20	421	50771	23567	\N	45.298673616719597	х. Железный, Ленина, 37, телефон: 30-2-36	Россия, Краснодарский край, Усть-Лабинский район, поселок Железный	0101000020E6100000BBB6B75B92C743402F151BF33AA64640
46846	2	20	421	3433	20503	\N	45.270499999999998	п. Двубратский, Пионерская, 2, телефон: 48-2-00		0101000020E610000020459DB987E64340B4C876BE9FA24640
46856	2	20	421	50899	24019	\N	45.369195717006001	ст. Восточная, Школьная, 1, телефон: 33-1-50		0101000020E61000005DFE43FAEDE3434032E884D041AF4640
46860	2	20	421	50294	23665	\N	45.211302004583402	ст. Воронежская, Ленина, 60, телефон: 37-1-41	Россия, Краснодарский край, Усть-Лабинский район, поселок Воронежская	0101000020E6100000E4D70FB1C1C843402ACAA5F10B9B4640
46882	2	20	421	50294	22497	\N	45.210063456706898	ст. Воронежская, Красная, 112, телефон: 37-1-67	Россия, Краснодарский край, Усть-Лабинский район, поселок Воронежская	0101000020E6100000D1CB28965BC84340C18C2958E39A4640
46861	2	20	421	50294	23987	\N	45.210298000000002	ст. Воронежская, Заводская, 115, телефон: 37-2-80	Россия, Краснодарский край, Усть-Лабинский район, поселок Воронежская	0101000020E610000093C3279D48C8434005357C0BEB9A4640
46854	2	20	421	50703	23680	\N	45.231314908730603	х. Болгов, Советская, 110, телефон: 74-0-34		0101000020E61000009D8026C286F143408109DCBA9B9D4640
46855	2	20	421	50703	23426	\N	45.232212491524301	х. Болгов, Красная, 53, телефон: 74-0-44	Россия, Краснодарский край, Усть-Лабинский район, поселок Болгов	0101000020E6100000AC36FFAF3AF243408FDE701FB99D4640
46870	2	20	421	50859	23899	\N	45.419352261247198	х. Безлесный, Красная, 64, телефон: 76-1-33	Россия, Краснодарский край, Усть-Лабинский район, поселок Безлесный	0101000020E61000003DF0315871FE434090C18A53ADB54640
46849	2	20	421	50766	23557	\N	45.252062727464498	х. Александровский, Красная, 38, телефон: 75-0-30	Россия, Краснодарский край, Усть-Лабинский район, поселок Александровский	0101000020E61000000E863AAC700744400DC4B29943A04640
46806	2	20	251	1036	22003	\N	44.833959999999998	село Успенское, Молодежная, 1, телефон: 57651		0101000020E61000004CC45BE7DFB2444009168733BF6A4640
46804	2	20	251	1036	20542	\N	44.833959999999998	с.Успенское ул. Ленина 108		0101000020E61000004CC45BE7DFB2444009168733BF6A4640
46805	2	20	251	1036	22246	\N	44.833959999999998	село Успенское, Калинина, 77, телефон: 55693		0101000020E61000004CC45BE7DFB2444009168733BF6A4640
46803	2	20	251	50427	21759	\N	44.833959999999998	село Успенское, Школьная, 5, телефон: 55721		0101000020E61000004CC45BE7DFB2444009168733BF6A4640
46785	2	20	251	32332	22978	\N	44.915786656428203	станица Убеженская, Почтовая, 6, телефон: 63759	Россия, Краснодарский край, Успенский район, поселок Убеженская	0101000020E6100000B0E76B96CBA444400D8D278238754640
46820	2	20	251	1928	20716	\N	44.677518999999997	село Трехсельское, Мира, 4, телефон: 64334		0101000020E61000009AB1683A3BA7444095B54DF1B8564640
46821	2	20	251	2034	21368	\N	44.640684999999998	село Новоурупское, Ленина, 38, телефон: 64349		0101000020E61000003B8F8AFF3BAC4440D50451F701524640
46814	2	20	251	47840	21527	\N	44.985767000000003	хутор Новенький, Ленина, 77, телефон: 63791		0101000020E610000010E6762FF7994440EF3CF19C2D7E4640
46818	2	20	251	50671	23338	\N	44.860496089247398	станица Николаевская, Красная, 34 а, телефон: 60130	Россия, Краснодарский край, Успенский район, поселок Николаевская	0101000020E6100000E8154F3DD2C844405E2BA1BB246E4640
46807	2	20	251	47710	21110	\N	44.780946	поселок Мичуринский, Ленина, 13, телефон: 66321		0101000020E61000005CAD1397E3BD444094F8DC09F6634640
46823	2	20	251	50336	21161	\N	44.901508999999997	село Марьино, Центральная, 36 а, телефон: 51344	Россия, Краснодарский край, Успенский район, поселок Марьино	0101000020E6100000145FED28CEA144405B069CA564734640
46813	2	20	251	1543	22636	\N	44.828769000000001	село Маламино, Ленина, 47 б, телефон: 61625		0101000020E6100000416326512FC244402578431A156A4640
46816	2	20	251	1691	20632	\N	44.853721	хутор Державный, Советская, 4, телефон: 58112		0101000020E61000004EF2237EC5B644404774CFBA466D4640
46746	2	20	541	50679	\N	\N	44.063815728686897	"Поселок ЗАО ""Пансионат отдыха ""Южный"", здание МОУ НОШ № 21 п/о ""Южный"", телефон: 61459"	Россия, Краснодарский край, Туапсинский район, поселок Пансионат Южный	0101000020E6100000894160E5D08E4340147B681F2B084640
46744	2	20	541	30302	\N	\N	44.038458202983001	"с.Шепси, ЗАО ""Пансионат ""Шепси"", корпус № 16, телефон: 63634"	Россия, Краснодарский край, Туапсинский район, поселок Шепси	0101000020E6100000DBDB2DC90193434081221631EC044640
46743	2	20	541	30302	20833	\N	44.038952999999999	с.Шепси, Сочинская, 6, телефон: 63494		0101000020E61000000D7041B62C934340618A7269FC044640
46742	2	20	541	30302	20833	\N	44.038952999999999	с.Шепси, Сочинская, 2, телефон: 63615		0101000020E61000000D7041B62C934340618A7269FC044640
46763	2	20	541	31347	22590	\N	44.321326999999997	с.Шаумян, Шаумяна, 58, телефон: 96647		0101000020E6100000778368AD68A5434030293E3E21294640
46772	2	20	541	31791	20822	\N	44.159664999999997	с.Цыпка, Центральная, 2, телефон: 65514		0101000020E6100000802A6EDC629643406DA818E76F144640
46738	2	20	541	30112	\N	\N	44.180219999999998	п.Тюменский, здание КСК, телефон: 68424		0101000020E6100000DA740470B37C4340E50AEF7211174640
46764	2	20	541	31385	\N	\N	44.211881907910701	х.Терзиян, здание сельского клуба, телефон: 76829	Россия, Краснодарский край, Туапсинский район, поселок Терзиян	0101000020E6100000D7A3703D0AB74340384E0AF31E1B4640
46727	2	20	541	29551	20566	\N	44.3293267083058	с.Тенгинка, Шаумяна, 40, телефон: 95394	Россия, Краснодарский край, Туапсинский район, поселок Тенгинка	0101000020E610000052B648DA8D6443404B581B63272A4640
46726	2	20	541	29551	20566	\N	44.326988999999998	с.Тенгинка, Шаумяна, 40, телефон: 95469		0101000020E61000004FE61F7D936443406C938AC6DA294640
46735	2	20	541	50486	\N	\N	44.176959126639602	"ГУ ""ЦРВ и М ""Сосновый"" МВД Росии, здание клуба, телефон: 68846"	Россия, Краснодарский край, Туапсинский район, поселок Сосновый	0101000020E610000007EE409DF2784340CEDDAE97A6164640
46760	2	20	541	50338	21183	\N	44.386548309176597	с.Садовое, Баграмяна, 11, телефон: 96717	Россия, Краснодарский край, Туапсинский район, поселок Садовое	0101000020E6100000DA8EA9BBB2954340C72AA5677A314640
46732	2	20	541	50777	23576	\N	44.286277577200202	а.Псебе, Мира, 41, телефон: 75936	Россия, Краснодарский край, Туапсинский район, поселок Псебе	0101000020E61000000BD12170247A43403BC8EBC1A4244640
46762	2	20	541	50436	21844	\N	44.324673083890097	п.Джубга, Новороссийское шоссе, 1/Б, телефон: 94741		0101000020E6100000E2E5E95C515A4340757286E28E294640
46724	2	20	541	50436	23184	\N	44.338180468086897	п.Джубга, Колхозная, 38, телефон: 94694	Россия, Краснодарский край, Туапсинский район, шоссе главное шоссе	0101000020E610000064778192025B4340A514747B492B4640
46733	2	20	541	50302	20951	\N	44.260552637899302	с.Пляхо, Дорога Орлят, 1, телефон: 93850	Россия, Краснодарский край, Туапсинский район, шоссе главное шоссе	0101000020E61000005E2EE23B31694340F6EFFACC59214640
46759	2	20	541	50664	23294	\N	44.275968249508999	х.Островская Щель, Центральная, 3/А, телефон: 76073		0101000020E61000008449F1F109A543400B5F5FEB52234640
46734	2	20	541	29917	22510	\N	44.208528000000001	с.Ольгинка, переулок Ореховый, 5Б, телефон: 99750		0101000020E6100000884A2366F67143407026A60BB11A4640
46731	2	20	541	46103	21235	\N	44.256903999999999	п.Новомихайловский, Юности, 12, телефон: 92400		0101000020E61000008DB7955E9B6D4340151BF33AE2204640
46728	2	20	541	46103	20819	\N	44.256903999999999	п.Нововмихайловский, 1 Микрорайон, 6, телефон: 91225		0101000020E61000008DB7955E9B6D4340151BF33AE2204640
46737	2	20	541	30018	20828	\N	44.170721999999998	с.Небуг, переулок Фонтанный, 2, телефон: 97919		0101000020E610000087F8872D3D804340965AEF37DA154640
46736	2	20	541	30018	20828	\N	44.170721999999998	с.Небуг, переулок Фонтанный, 2, телефон: 97991		0101000020E610000087F8872D3D804340965AEF37DA154640
46761	2	20	541	31218	21264	\N	44.371859000000001	с.Навагинское, Центральная, 21, телефон: 96677		0101000020E6100000166C239EECAC434094DC6113992F4640
46721	2	20	541	32963	21038	\N	44.468378000000001	село Молдовановка, Центральная, 49, телефон: 95750		0101000020E61000007C26FBE7697043403C1570CFF33B4640
46771	2	20	541	31712	21895	\N	44.140345000000003	с.Мессажай, Шаумяна, 11, телефон: 65120		0101000020E6100000C8D3F203578F43401D9430D3F6114640
46756	2	20	541	31011	21702	\N	44.1152413144805	а.Малое Псеушхо, Тхагушева, здание сельского Дома культуры, телефон: 64900	Россия, Краснодарский край, Туапсинский район, поселок Мал. Псеушхо	0101000020E6100000D21BEE23B7A6434044149337C00E4640
46725	2	20	541	50346	21228	\N	44.305549999999997	с.Лермонтово, Ленина, 19Б, телефон: 74140	Россия, Краснодарский край, Туапсинский район, поселок Лермонтово	0101000020E6100000616EF7729F6043407AA52C431C274640
46753	2	20	541	30782	21056	\N	44.190244999999997	с.Кривенковское, Спорная, 1, телефон: 62420		0101000020E61000002123A0C2119E43401F9DBAF259184640
46752	2	20	541	30782	21056	\N	44.190244999999997	с.Кривенковское, Спорная, 1, телефон: 62503		0101000020E61000002123A0C2119E43401F9DBAF259184640
45180	2	20	541	32982	21372	\N	44.167366999999999	с.Кирпичное, Майкопская, 28, телефон: 64768		0101000020E61000002AC76471FF994340FEB627486C154640
45273	2	20	541	23288	22455	\N	44.235537000000001	с.Индюк, Майкопская, 95, телефон: 61634		0101000020E6100000842C0B26FE9E4340BDFF8F13261E4640
46722	2	20	541	29361	23117	\N	44.308589514309197	п.Джубга, Черноморская, 66, телефон: 94144	Россия, Краснодарский край, Туапсинский район, шоссе главное шоссе	0101000020E6100000684293C4925A4340B3EF8AE07F274640
46723	2	20	541	29361	20947	\N	44.323622999999998	п.Джубга, Советская, 33, телефон: 94298		0101000020E6100000653909A52F5A4340E09D7C7A6C294640
43866	2	20	541	18863	21010	\N	44.430297000000003	с.Дефановка, Школьная, 9, телефон: 95538		0101000020E61000009BFF571D396443409148DBF813374640
46745	2	20	541	30442	21455	\N	44.054478000000003	с.Дедеркой, Клубная, 2, телефон: 61150		0101000020E61000002E1A321EA5904340FE2C9622F9064640
46765	2	20	541	50755	23541	\N	44.275314777207399	с.4-я Гунайка, Школьная, 13, телефон: 96279		0101000020E6100000C18EFF0241B84340938C9C853D234640
44259	2	20	541	47394	20802	\N	44.387571999999999	с.Горское, Центральная, 5 А, телефон: 66760		0101000020E61000009A999999995D4340336C94F59B314640
46758	2	20	541	31096	21693	\N	44.283065000000001	п.Горный, Глебова, 19, телефон: 76088		0101000020E6100000FDF675E09CA3434035D252793B244640
46767	2	20	541	31552	\N	\N	44.246611999999999	"с.Гойтх, здание МОУ ""СОШ № 38"", телефон: 76824"		0101000020E6100000F4177AC4E8AF43408C6665FB901F4640
46754	2	20	541	46669	22075	\N	44.162737	352822, с.Георгиевское, ул.Советская, 23		0101000020E61000007A56D28A6FA04340B16CE690D4144640
46749	2	20	541	50574	\N	\N	44.071189503736697	"с.Вольное, представительство РГСУ БАЗА оск ""Строитель"", корпус № 1, телефон: 61498"	Россия, Краснодарский край, Туапсинский район, поселок Вольное	0101000020E61000006F8104C58F8D4340B0E600C11C094640
46757	2	20	541	50634	23136	\N	44.076346500444799	а.Большое Псеушхо, Центральная, здание Дома культуры, телефон: 78272		0101000020E610000007600322C4AB4340E8120EBDC5094640
44866	2	20	541	3297	21060	\N	44.357062999999997	c.Бжид, Черноморская, 65, телефон: 66599		0101000020E610000001FC53AA445543404ACE893DB42D4640
46755	2	20	541	46678	20594	\N	44.169305999999999	с.Анастасиевка, Центральная, телефон: 64262		0101000020E6100000033E3F8C10A443401F82AAD1AB154640
46741	2	20	541	50635	23148	\N	44.181728763877999	аул Агуй-Шапсуг, Шапсугская, 73, телефон: 65656	Россия, Краснодарский край, Туапсинский район, поселок Агуй-Шапсуг	0101000020E61000003561FBC9188943400DDE57E542174640
46739	2	20	541	30148	22529	\N	44.147596999999998	с.Агой, Горная, 12/Б, телефон: 67025		0101000020E61000008C868C47A98443406DFE5F75E4124640
46796	2	20	7087	50759	23545	\N	44.107900999999998	Краснодарский край, Туапсинский район, город Туапсе, Московских строителей, 1, телефон: 5-04-64		0101000020E6100000564ACFF412854340541A31B3CF0D4640
45871	2	20	1034	47442	20508	\N	45.984060999999997	п.Южный, ул.Цветочная, 3, телефон: 5-39-68		0101000020E6100000A1BC8FA3390E44407022FAB5F5FD4640
46686	2	20	1034	27723	22420	\N	45.759664000000001	Краснодарский край, Тихорецкий район, станица Юго-Северная, улица Северная, 67, телефон: 43-7-82		0101000020E61000008CF2CCCB611F44406AF981AB3CE14640
45549	2	20	1034	50691	23402	\N	45.784198438928399	хутор Школьный, Магистральная, 48а, телефон: 6-25-22		0101000020E610000051BB5F05F812444058CB9D9960E44640
46682	2	20	1034	27542	23090	\N	45.646442999999998	Тихорецкий район, станица Хоперская, улица Школьная, 3, телефон: 92-1-91	Россия, Краснодарский край, Тихорецкий район, поселок Хоперская	0101000020E6100000CEDF84420436444033DDEBA4BED24640
46678	2	20	1034	50367	21414	\N	45.905587977602899	Краснодарский край, Тихорецкий район, станица Фастовецкая, улица Ленина, 9, телефон: 45-3-56	Россия, Краснодарский край, Тихорецкий район	0101000020E6100000F243A5113313444035D3BD4EEAF34640
46676	2	20	1034	27259	21919	\N	45.913646	Краснодарский край, Тихорецкий район, станица Фастовецкая, улица Ленина, 9, телефон: 45-2-26		0101000020E6100000D95E0B7A6F144440840F255AF2F44640
46680	2	20	1034	27259	20757	\N	45.913646	Краснодарский край, Тихорецкий район, станица Фастовецкая, улица Азина, 4, телефон: 45-5-89		0101000020E6100000D95E0B7A6F144440840F255AF2F44640
46679	2	20	1034	27259	20757	\N	45.913646	Краснодарский край, Тихорецкий район, станица Фастовецкая, улица Азина, 4, телефон: 45-4-46		0101000020E6100000D95E0B7A6F144440840F255AF2F44640
46705	2	20	1034	50452	23359	\N	45.859825105381297	город Тихорецк, Юго-Восточный бульвар, 1, телефон: 5-67-10		0101000020E6100000A3E716BA120F444040A4DFBE0EEE4640
46717	2	20	1034	50452	22016	\N	45.855552000000003	город Тихорецк, ул.Парковая, 3, телефон: 5-66-27		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46693	2	20	1034	50452	22292	\N	45.855552000000003	город Тихорецк, ул.Октябрьская, 93, телефон: 2-69-35		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46703	2	20	1034	14835	21145	\N	45.838231954132397	город Тихорецк, Юго-Восточный бульвар, 2-Б, телефон: 5-56-91	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E610000057B5A4A31C0E4440F73AA92F4BEB4640
46720	2	20	1034	14835	21203	\N	45.855851530675999	город Тихорецк, Энгельса, 91, телефон: 7-11-25	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E6100000D02A33A5F50F4440AC1BEF8E8CED4640
46698	2	20	1034	14835	21203	\N	45.855552000000003	город Тихорецк, ул.Энгельса, 220-А, телефон: 4-14-84		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46719	2	20	1034	14835	21653	\N	45.843721013123897	город Тихорецк, ул.Чапаева, д.2/2, телефон: 7-55-48		0101000020E61000007102D369DD0C444066F9BA0CFFEB4640
46700	2	20	1034	14835	21628	\N	45.855552000000003	город Тихорецк, ул.Федосеева, 15, телефон: 7-17-20		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46708	2	20	1034	14835	21539	\N	45.855552000000003	город Тихорецк, ул.Ударников, 12, телефон: 5-80-81		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46718	2	20	1034	14835	20804	\N	45.855552000000003	город Тихорецк, ул.Подвойского, д.42-Б, телефон: 7-11-70		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46699	2	20	1034	14835	21965	\N	45.850619057416701	город Тихорецк, ул.Передовая, 326, телефон: 7-34-76	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E61000000C789961A3124440992D5915E1EC4640
46694	2	20	1034	14835	21347	\N	45.855552000000003	город Тихорецк, ул.Октябрьская, 106, телефон: 5-04-69		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46691	2	20	1034	14835	21347	\N	45.855552000000003	город Тихорецк, ул.Октябрьская, 96, телефон: 5-39-65		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46710	2	20	1034	14835	20786	\N	45.856196846172303	город Тихорецк, ул.Новорождественское шоссе, 3, телефон: 5-83-62	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E61000006F4562821A0E444077F700DD97ED4640
46704	2	20	1034	14835	21633	\N	45.855552000000003	город Тихорецк, ул.Набережная, 20, телефон: 5-50-36		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46713	2	20	1034	14835	21026	\N	45.859297448535102	город Тихорецк, ул.Меньшикова, 98, телефон: 7-10-52	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E61000001E6FF25B740E44408446B071FDED4640
46697	2	20	1034	14835	20699	\N	45.855552000000003	город Тихорецк, ул.Ляпидевского, 64, телефон: 7-22-87		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46690	2	20	1034	14835	21499	\N	45.854397620998597	город Тихорецк, ул.Ленинградская, 135, телефон: 7-47-68		0101000020E610000020F12BD67011444048E2E5E95CED4640
46707	2	20	1034	14835	21016	\N	45.8484930332448	город Тихорецк, ул.Ленина, 58, телефон: 5-80-61	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E610000072A8DF85AD0D444045F12A6B9BEC4640
46702	2	20	1034	14835	20939	\N	45.855552000000003	город Тихорецк, ул.Кирова, 19, телефон: 2-89-39		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46695	2	20	1034	14835	20644	\N	45.855552000000003	город Тихорецк, ул.Калинина/ул.Майская, 33/1, телефон: 7-14-47		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46715	2	20	1034	14835	21033	\N	45.855552000000003	город Тихорецк, ул.Калинина, 112-А, телефон: 7-65-56		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46716	2	20	1034	14835	21648	\N	45.856376765467097	г.Тихорецк, ул.Гражданская, 89, телефон: 7-09-01	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E6100000A51133FB3C0E4440F705F4C29DED4640
46714	2	20	1034	14835	20543	\N	45.855552000000003	г. Тихорецк, Гвардейская 2		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46688	2	20	1034	14835	20765	\N	45.855552000000003	город Тихорецк, ул.Ачкасова, 2, телефон: 7-52-21		0101000020E6100000D82B2CB81F0E444082035ABA82ED4640
46687	2	20	1034	14835	20765	\N	45.8557770322058	город Тихорецк, ул.Ачкасова, 78, телефон: 7-12-80	Россия, Краснодарский край, Тихорецкий район, город Тихорецк	0101000020E610000020EEEA55640E4440A2D5C9198AED4640
46675	2	20	1034	50278	23203	\N	45.848373890060699	Краснодарский край, Тихорецкий район, станица Терновская, улица Суворова, 1, телефон: 43-2-03	Россия, Краснодарский край, Тихорецкий район, поселок Терновская	0101000020E6100000C07630629F3444406B63EC8497EC4640
46674	2	20	1034	50278	23203	\N	45.851732762470697	Краснодарский край, Тихорецкий район, станица Терновская, улица Суворова, 1, телефон: 43-2-04	Россия, Краснодарский край, Тихорецкий район, поселок Терновская	0101000020E610000004745FCE6C33444045F6419605ED4640
46673	2	20	1034	50278	23945	\N	45.851549690763498	Краснодарский край, Тихорецкий район, станица Терновская, улица Пионерская, 14, телефон: 43-3-14	Россия, Краснодарский край, Тихорецкий район, поселок Терновская	0101000020E6100000CD22145B4135444054742497FFEC4640
46672	2	20	1034	50278	20694	\N	45.8496634812916	Краснодарский край, Тихорецкий район, станица Терновская, улица Малиновского, 5а, телефон: 43-3-05	Россия, Краснодарский край, Тихорецкий район, поселок Терновская	0101000020E6100000DB3521AD3134444085CFD6C1C1EC4640
46669	2	20	1034	26957	20788	\N	45.835549999999998	Краснодарский край, Тихорецкий район, поселок Садовый, улица Титова, 2а, телефон: 94-1-27		0101000020E6100000A62A6D718D1D44401E166A4DF3EA4640
44888	2	20	1034	26957	20909	\N	45.835549999999998	пос. Садовый, Советская, 8, телефон: 65095	Россия, Краснодарский край, Тихорецкий район, поселок Садовый	0101000020E6100000A62A6D718D1D44401E166A4DF3EA4640
46681	2	20	1034	50616	22995	\N	45.710079730952202	Тихорецкий район, хутор Привольный, улица Первомайская, 58, телефон: 92-4-33	Россия, Краснодарский край, Тихорецкий район, поселок Привольный	0101000020E6100000B22C98F8A332444097C5C4E6E3DA4640
46670	2	20	1034	26987	21712	\N	45.802926999999997	Краснодарский край, Тихорецкий район, поселок Полевой, улица Пионерская, 71а, телефон: 43-8-13		0101000020E6100000367689EAAD214440A609DB4FC6E64640
46668	2	20	1034	13198	21013	\N	45.838023999999997	Краснодарский край, Тихорецкий район, поселок Парковый, улица Дружбы, 9, телефон: 48-3-78		0101000020E6100000BBF083F3A9134440ADA1D45E44EB4640
46664	2	20	1034	13198	21199	\N	45.838023999999997	п.Парковый ул.Гагарина 32	Россия, Краснодарский край, Тихорецкий район, поселок Парковый	0101000020E6100000BBF083F3A9134440ADA1D45E44EB4640
46665	2	20	1034	13198	20540	\N	45.838023999999997	Краснодарский край, Тихорецкий район, поселок Парковый, улица Гагарина, 24, телефон: 47-2-74		0101000020E6100000BBF083F3A9134440ADA1D45E44EB4640
46663	2	20	1034	13198	20540	\N	45.838023999999997	Краснодарский край, Тихорецкий район, поселок Парковый, улица Гагарина, 22, телефон: 47-2-88	Россия, Краснодарский край, Тихорецкий район, поселок Парковый	0101000020E6100000BBF083F3A9134440ADA1D45E44EB4640
46662	2	20	1034	50818	23741	\N	45.8283212342063	Краснодарский край, Тихорецкий район, станица Отрадненская, улица Ленина, 10, телефон: 95-3-38	Россия, Краснодарский край, Тихорецкий район, поселок Шоссейный	0101000020E6100000F2EEC8586D18444086CB2A6C06EA4640
45978	2	20	1034	50343	23958	\N	45.609142596240702	ст. Отрадная, ул. Северная, 51, телефон: 3-13-02	Россия, Краснодарский край, Тихорецкий район, поселок Отрадная	0101000020E6100000BE30992A181144402ECBD765F8CD4640
45980	2	20	1034	50343	24022	\N	45.609825000000001	ст. Отрадная, ул. Первомайская, 20, телефон: 3-34-84	Россия, Краснодарский край, Тихорецкий район, поселок Отрадная	0101000020E610000022E010AAD410444040A4DFBE0ECE4640
45981	2	20	1034	50343	23626	\N	45.609961864919697	352290 ст. Отрадная, ул. Красная, 86А	Россия, Краснодарский край, Тихорецкий район, поселок Отрадная	0101000020E6100000F2D1E28C61104440C1E61C3C13CE4640
46671	2	20	1034	27043	21902	\N	45.936228	Краснодарский край, Тихорецкий район, станица Новоромановская, улица Набережная, 9а, телефон: 43-1-98		0101000020E610000015747B49632C4440BCCCB051D6F74640
46659	2	20	1034	9005	20978	\N	45.8655937998453	ст. Новорождественская ул. Красная 54	Россия, Краснодарский край, Тихорецкий район, поселок Новорождественская	0101000020E6100000F7E5CC7685F8434092CEC0C8CBEE4640
46658	2	20	1034	9005	20978	\N	45.865248999999999	Краснодарский край, Тихорецкий район, станица Новорождественская, улица Красная, 54, телефон: 46-1-47		0101000020E610000016359886E1F94340C7F2AE7AC0EE4640
46660	2	20	1034	9005	20514	\N	45.865248999999999	Краснодарский край, Тихорецкий район, станица Новорождественская, улица Кирпичная, 16, телефон: 46-9-18		0101000020E610000016359886E1F94340C7F2AE7AC0EE4640
46661	2	20	1034	9005	21604	\N	45.865248999999999	Краснодарский край, Тихорецкий район, станица Новорождественская, улица Горького, 1, телефон: 46-2-24		0101000020E610000016359886E1F94340C7F2AE7AC0EE4640
46656	2	20	1034	26333	21827	\N	45.999032	Краснодарский край, Тихорецкий район,  поселок Мирный, улица Мира, 2а, телефон: 92-5-98		0101000020E61000000971E5EC9D0D444028D4D347E0FF4640
46649	2	20	1034	26060	21242	\N	45.707923000000001	Краснодарский край, Тихорецкий район,  поселок Малороссийский, улица Мичурина, 4, телефон: 97-7-45		0101000020E61000009180D1E5CD234440098B8A389DDA4640
46677	2	20	1034	27309	21592	\N	45.974266	Краснодарский край, Тихорецкий район, хутор Ленинское Возрождение, улица Северная, 118а, телефон: 92-7-49		0101000020E6100000058C2E6F0E15444068CD8FBFB4FC4640
46683	2	20	1034	50797	23637	\N	45.596830599181096	Тихорецкий район, хутор Ленинский, улица Советская, 3а, телефон: 92-1-93	Россия, Краснодарский край, Тихорецкий район, поселок Ленинский	0101000020E61000005454FD4AE7374440971E4DF564CC4640
46666	2	20	1034	26806	21618	\N	45.872647999999998	Краснодарский край, Тихорецкий район, поселок Крутой, улица Новая, 10, телефон: 7-08-76		0101000020E6100000E5D4CE30B51D4440BC75FEEDB2EF4640
46684	2	20	1034	50796	23639	\N	45.615632484464598	Тихорецкий район, хутор Красный, улица Красная, 28а, телефон: 92-4-91		0101000020E610000039F06AB9332D44407F2F8507CDCE4640
46647	2	20	1034	25983	21388	\N	45.803417000000003	Краснодарский край, Тихорецкий район, станица Краснооктябрьская, улица Мира, 5, телефон: 94-2-34		0101000020E6100000FC89CA86350B44407506465ED6E64640
46711	2	20	1034	45758	22301	\N	45.866064999999999	пос.Каменный, ул.Ленина, 5, телефон: 99-2-38		0101000020E61000005F97E13FDD044440E99AC937DBEE4640
46685	2	20	1034	27701	20714	\N	45.716211000000001	Краснодарский край, Тихорецкий район,  хутор Казаче-Борисовский, улица Октябрьская, 23, телефон: 91-1-42		0101000020E6100000F9A23D5E483144408A0453CDACDB4640
46667	2	20	1034	26873	21207	\N	45.833804999999998	Краснодарский край, Тихорецкий район, поселок Зеленый, переулок Степной, 36, телефон: 94-1-13		0101000020E61000004F5AB8ACC2264440E21E4B1FBAEA4640
46815	2	20	1034	50667	23324	\N	46.008686497512002	хутор Западный, Центральная, 24 б, телефон: 63646	Россия, Краснодарский край, Тихорецкий район	0101000020E6100000C51D6FF25B0A44406EF7729F1C014740
46657	2	20	1034	26412	21843	\N	45.709200000000003	Краснодарский край, Тихорецкий район, станица Еремизино-Борисовская, улица Школьная, 7, телефон: 92-8-17		0101000020E6100000930035B56C3F44405F29CB10C7DA4640
44550	2	20	1034	40468	21395	\N	45.830351	поселок Восточный, улица Свободная, 28, телефон: 3-71-75		0101000020E61000000E68E90AB6134440B7990AF148EA4640
46655	2	20	1034	26303	20744	\N	46.034267999999997	Краснодарский край, Тихорецкий район, поселок Братский, улица Школьная, 20, телефон: 92-6-31		0101000020E610000085EE92382B0E444050A6D1E462044740
46650	2	20	1034	26082	20922	\N	45.684122528949104	Краснодарский край, Тихорецкий район,  станица Архангельская, улица Садовая, 3, телефон: 91-7-47	Россия, Краснодарский край, Тихорецкий район, поселок Архангельская	0101000020E61000008C9E5BE84A22444080B8AB5791D74640
46653	2	20	1034	26082	20941	\N	45.673112210024698	Краснодарский край, Тихорецкий район,  станица Архангельская, улица Первомайская, 75, телефон: 91-4-21	Россия, Краснодарский край, Тихорецкий район, поселок Архангельская	0101000020E6100000354415FE0C234440C845B58828D64640
46652	2	20	1034	26082	20677	\N	45.678944999999999	Краснодарский край, Тихорецкий район,  станица Архангельская, улица Ленина, 2, телефон: 91-6-59		0101000020E61000009A3FA6B569224440306475ABE7D64640
46651	2	20	1034	26082	20677	\N	45.678944999999999	Краснодарский край, Тихорецкий район,  станица Архангельская, улица Ленина, 6, телефон: 91-3-88		0101000020E61000009A3FA6B569224440306475ABE7D64640
46654	2	20	1034	26082	21891	\N	45.678944999999999	Краснодарский край, Тихорецкий район,  станица Архангельская, улица Буденного, 35а, телефон: 91-7-60		0101000020E61000009A3FA6B569224440306475ABE7D64640
46645	2	20	1034	25804	21168	\N	45.769573000000001	Краснодарский край, Тихорецкий район, станица Алексеевская, улица Ленина, 45, телефон: 94-3-43		0101000020E610000083A44FABE81344403B71395E81E24640
46644	2	20	1034	25804	21168	\N	45.769573000000001	Краснодарский край, Тихорецкий район, станица  Алексеевская, улица Ленина, 45, телефон: 9-43-43		0101000020E610000083A44FABE81344403B71395E81E24640
46604	2	20	1377	23047	22141	\N	45.602522999999998	город Тимашевск, мкр.Сахарного завода, д.8,  здание МДОУ д/с №11, телефон: 5-35-77		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46609	2	20	1377	23047	21489	\N	45.602522999999998	город Тимашевск, мкр.Индустриальный, 3, здание МБУДОД ЦРДиЮ, телефон: 5-52-54		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46608	2	20	1377	23047	21276	\N	45.605406608556798	город Тимашевск, мкр.Индустриальный, МОУ СОШ № 5, телефон: 5-54-51		0101000020E61000003C6A4C88B97A43407EE200FA7DCD4640
46603	2	20	1377	23047	20624	\N	45.601632815039203	город Тимашевск, мкр. Сахарного завода, МОУ СОШ № 4, телефон: 4-04-08	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E61000000DE4D9E55B774340E198654F02CD4640
46586	2	20	1377	23047	22007	\N	45.602522999999998	город Тимашевск, Шереметова, 36, телефон: 4-36-59		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46588	2	20	1377	23047	22163	\N	45.619363208861799	город Тимашевск, Степанова, 170/а, телефон: 4-15-54	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000C3F352B1317743401DAD6A4947CF4640
46587	2	20	1377	23047	21186	\N	45.602522999999998	город Тимашевск, Советская, 105, телефон: 9-03-87		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46585	2	20	1377	23047	20933	\N	45.617052549049099	Краснодарский край, Тимашевский район, Тимашевское городское поселение, Профильная, 47, телефон: 4-18-13	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E610000005C078060D7943400873BB97FBCE4640
46639	2	20	1377	23047	21662	\N	45.611363720148802	город Тимашевск, мкр.Южный, Набережная, 30, телефон: 7-74-45	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000137CD3F4D9794340D3F9F02C41CE4640
46638	2	20	1377	23047	20620	\N	45.602522999999998	город Тимашевск, Ленина, 152, телефон: 4-40-42	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E61000008A929048DB7A43403D0B42791FCD4640
34028	1	6	1067	20605	\N	\N	54.54325	Село Ферзиково, 46		0101000020E6100000041DAD6A495F4240A8C64B3789454B40
46593	2	20	1377	23047	20620	\N	45.617986262399299	город Тимашевск, Ленина, 154, телефон: 4-12-31		0101000020E6100000F836FDD98F78434064B14D2A1ACF4640
46591	2	20	1377	23047	20620	\N	45.6111111182068	город Тимашевск, Ленина, 120, телефон: 4-21-97	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E610000094F947DFA4794340E99C9FE238CE4640
46590	2	20	1377	23047	20620	\N	45.6142969847945	город Тимашевск, Ленина, 120, телефон: 4-12-52		0101000020E6100000CEC4742156794340F583BA48A1CE4640
46595	2	20	1377	23047	21078	\N	45.602522999999998	город Тимашевск, Красная, 179, телефон: 4-00-30		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46592	2	20	1377	23047	21078	\N	45.622502597539302	город Тимашевск, Красная, 105, телефон: 4-17-73, 4-24-68	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000F69A1E1494784340B954A52DAECF4640
46602	2	20	1377	23047	20422	\N	45.611954453615098	город Тимашевск, Котляра, 2/б, телефон: 4-19-65	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000F2086EA46C7943400454388254CE4640
46601	2	20	1377	23047	20422	\N	45.602522999999998	город Тимашевск, Котляра, 2/а, телефон: 5-85-75	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E61000008A929048DB7A43403D0B42791FCD4640
46598	2	20	1377	23047	20591	\N	45.602522999999998	город Тимашевск, Коммунальная, 16, телефон: 4-16-32		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46637	2	20	1377	23047	21519	\N	45.602918052833303	город Тимашевск, Комарова, 42, телефон: 4-20-67	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000EBE40CC51D7B4340BA15C26A2CCD4640
46605	2	20	1377	23047	21073	\N	45.602325576158101	город Тимашевск, Западная, 12, телефон: 5-48-09	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E6100000A35C1ABFF07A4340E7C3B30419CD4640
46643	2	20	1377	23047	20974	\N	45.602522999999998	город Тимашевск, Гибридная, 2, телефон: 4-24-89		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46642	2	20	1377	23047	20497	\N	45.602522999999998	город Тимашевск, Выборная, 68а, телефон: 4-24-55		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46607	2	20	1377	23047	20902	\N	45.602522999999998	город Тимашевск, Братьев Степановых, 2, здание МБОУ СОШ № 19, телефон: 4-06-08		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46606	2	20	1377	23047	20902	\N	45.626228980318203	"город Тимашевск, Братьев Степановых, 2, здание спорткомплекса ""Олимп"", телефон: 4-22-89"		0101000020E6100000E0F25833327A43404567994528D04640
46596	2	20	1377	23047	22217	\N	45.603183164984202	город Тимашевск, мкр.Садовод, ул. 70 лет Октября, дом №4, здание МОУ СОШ № 18, телефон: 5-02-23	Россия, Краснодарский край, Тимашевский район, город Тимашевск	0101000020E61000009C887E6DFD7A43406840BD1935CD4640
46599	2	20	1377	23047	20896	\N	45.602522999999998	"город Тимашевск, 50 лет Октября, 100, корп.""Ж"", телефон: 4-19-11"		0101000020E61000008A929048DB7A43403D0B42791FCD4640
46620	2	20	1377	24723	20630	\N	45.533862999999997	хутор Танцура-Крамаренко, Школьная, 12/а, здание СОШ № 6, телефон: 3-63-49	Россия, Краснодарский край, Тимашевский район, поселок Танцура Крамаренко	0101000020E6100000FED137691A764340B0C56E9F55C44640
46635	2	20	1377	25386	20489	\N	45.718929000000003	хутор Стринский, Красная, 91/а, телефон: 3-00-61		0101000020E61000005EBEF561BD9B4340B0928FDD05DC4640
46622	2	20	1377	50534	22645	\N	45.538679999999999	поселок Советский, Ленина, 19, телефон: 3-74-35	Россия, Краснодарский край, Тимашевский район, поселок Советский	0101000020E6100000F75AD07B6364434030815B77F3C44640
45538	2	20	1377	50295	20878	\N	45.518893604615101	хутор Садовый, Комсомольская, 22, телефон: 6-27-82	Россия, Краснодарский край, Тимашевский район, поселок Садовый	0101000020E6100000276893C3277743409A0B5C1E6BC24640
46628	2	20	1377	48647	23548	\N	45.729311000000003	станица Роговская, Свободная, 40, телефон: 6-62-01	Россия, Краснодарский край, Тимашевский район, поселок Роговская	0101000020E6100000AFE94141295E434079CE16105ADD4640
46627	2	20	1377	48647	20683	\N	45.729311000000003	станица Роговская, Ленина, 74, телефон: 6-62-31		0101000020E6100000AFE94141295E434079CE16105ADD4640
46631	2	20	1377	48647	22017	\N	45.729311000000003	станица Роговская, Коммунаров, 44/а, телефон: 6-65-84		0101000020E6100000AFE94141295E434079CE16105ADD4640
46629	2	20	1377	48647	22281	\N	45.729311000000003	станица Роговская, Гоголя, 18, телефон: 6-65-27		0101000020E6100000AFE94141295E434079CE16105ADD4640
46626	2	20	1377	50274	20681	\N	45.568607	хутор Ольховский, Степанова, 63/а, телефон: 7-82-04		0101000020E61000000989B48D3F7D43406AA33A1DC8C84640
46633	2	20	1377	25236	20721	\N	45.640538999999997	станица Новокорсунская, Пионерская, 23, телефон: 3-44-52		0101000020E610000002F22554709243400168942EFDD14640
46632	2	20	1377	25236	21093	\N	45.640538999999997	станица Новокорсунская, Красная, 2, телефон: 3-44-92		0101000020E610000002F22554709243400168942EFDD14640
46634	2	20	1377	25324	20906	\N	45.717790000000001	хутор Незаймановский, Школьная, 24/а, телефон: 3-08-65		0101000020E610000039B709F7CAA84340ABB2EF8AE0DB4640
46615	2	20	1377	14961	21926	\N	45.446607	станица Медведовская, Школьная, 34, телефон: 7-19-66		0101000020E6100000B43A39437183434014950D6B2AB94640
46617	2	20	1377	14961	20435	\N	45.446607	станица Медведовская, Пушкина, 7, здание СОШ № 10, телефон: 7-15-59		0101000020E6100000B43A39437183434014950D6B2AB94640
46616	2	20	1377	14961	20435	\N	45.4493437112585	ст. Медвёдовская ул. Пушкина 5	Россия, Краснодарский край, Тимашевский район, поселок Медведовская	0101000020E6100000C423F1F274824340B153AC1A84B94640
46612	2	20	1377	14961	20912	\N	45.443810562544897	станица Медведовская, Мира, 90, телефон: 7-14-06	Россия, Краснодарский край, Тимашевский район, поселок Медведовская	0101000020E61000000EF62686E4804340724D81CCCEB84640
46641	2	20	1377	14961	20666	\N	45.446607	станица Медведовская, Ленина, 54, телефон: 7-52-63		0101000020E6100000B43A39437183434014950D6B2AB94640
46614	2	20	1377	14961	20666	\N	45.446607	станица Медведовская, Ленина, 54, телефон: 7-53-58		0101000020E6100000B43A39437183434014950D6B2AB94640
46613	2	20	1377	14961	20666	\N	45.450129079281197	станица Медведовская, Ленина, 77, телефон: 7-13-98	Россия, Краснодарский край, Тимашевский район, поселок Медведовская	0101000020E6100000C68B85217282434097FDBAD39DB94640
45147	2	20	1377	16997	22748	\N	45.6540911819759	хутор Крупской, ул.Народная, 59, телефон: 93-7-92	Россия, Краснодарский край, Тимашевский район, поселок Крупской	0101000020E6100000F29881CAF86B4340D1CDFE40B9D34640
46625	2	20	1377	48609	20937	\N	45.669581000000001	хутор Калинина, Победы, 6а/2, телефон: 7-93-37		0101000020E6100000FDBB3E73D66F4340F18288D4B4D54640
46624	2	20	1377	24873	21707	\N	45.622892999999998	станица Днепровская, Ленина, 68, телефон: 3-31-02		0101000020E6100000BB5F05F86E67434023F433F5BACF4640
46621	2	20	1377	24738	20675	\N	45.520924999999998	хутор Беднягина, пер. Юбилейный, 5, телефон: 3-13-98		0101000020E6100000D5EC8156607E43409B559FABADC24640
46579	2	20	699	50463	22095	\N	45.209034000000003	Тамань станица, Карла Маркса, 102, адм. здание рыбколхоза, телефон: 31-3-69		0101000020E6100000DB6B41EF8D5B424044E048A0C19A4640
46570	2	20	699	50313	21018	\N	45.326882942738003	Юбилейный поселок, Ленина, 17, здание МБОУ СОШ №31, телефон: 76-4-31	Россия, Краснодарский край, Темрюкский район, поселок Юбилейный	0101000020E610000091813CBB7C7D4240274F594DD7A94640
46572	2	20	699	22417	22084	\N	45.363173000000003	Фонталовская станица, Ленина, 27, здание администрации поселения, телефон: 76-1-78		0101000020E6100000D673D2FBC677424026E5EE737CAE4640
46540	2	20	699	20427	21243	\N	45.371110405436603	г.Темрюк, площадь Терлецкого, здание МБОУ СОШ №2, телефон: 4-22-26	Россия, Краснодарский край, Темрюкский район	0101000020E6100000823B50A73CC44240FA9B508880AF4640
46531	2	20	699	20427	21658	\N	45.265749	г.Темрюк, пос. Первомайский, пер. имени Дуси Виноградовой, 1, здание Дома культуры, телефон: 94-1-64		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46536	2	20	699	20427	21041	\N	45.2816388896901	г.Темрюк, Шопена, 70, здание штаба ТРКО, телефон: 5-21-29	Россия, Краснодарский край, Темрюкский район, город Темрюк	0101000020E61000009E2633DE56B042409A232BBF0CA44640
46537	2	20	699	20427	20811	\N	45.265749	"г.Темрюк, Таманская, 69, здание кинотеатра ""Тамань"", телефон: 5-24-77"		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46535	2	20	699	20427	21441	\N	45.265749	г.Темрюк, Свердлова, 1 А, МБДОУ ДС КВ №11, телефон: 5-43-73		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46545	2	20	699	20427	21267	\N	45.265749	г.Темрюк, Полетаева, 2, здание детского сада №13, телефон: 4-27-27		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46539	2	20	699	20427	21232	\N	45.265749	г.Темрюк, Октябрьская, 109, здание МБОУ ООШ №14, телефон: 5-22-57		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46533	2	20	699	20427	21042	\N	45.265749	"г.Темрюк, Морская, 12, здание ООО ""Владимпекс-транс"", телефон: 5-13-17"		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46546	2	20	699	20427	21047	\N	45.265749	г.Темрюк, Молодежная, 1, администрат. здание рисосовхоза, телефон: 99-2-24		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46544	2	20	699	20427	20575	\N	45.265749	г.Темрюк, Мира, 152, здание соц.-центра, телефон: 4-28-65		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46542	2	20	699	20427	20575	\N	45.265749	г.Темрюк, Мира, 73 А, здание МБОУ СОШ №3, телефон: 4-21-55		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46541	2	20	699	20427	20575	\N	45.265749	г.Темрюк, Мира, 73 А, здание МБОУ СОШ №3, телефон: 4-29-20		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46534	2	20	699	20427	21246	\N	45.274980741043002	г.Темрюк, Ленина, 29, здание Дома культуры, телефон: 5-24-27	Россия, Краснодарский край, Темрюкский район, город Темрюк	0101000020E6100000F78F85E810B04240BC02D19332A34640
46543	2	20	699	20427	21045	\N	45.265749	г.Темрюк, Карла Маркса, 151, здание библиотеки, телефон: 4-38-03		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46532	2	20	699	20427	21437	\N	45.265749	г.Темрюк, Гагарина, здание МБОУ СОШ №15, телефон: 65-4-21		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46538	2	20	699	20427	20812	\N	45.265749	г.Темрюк, Бувина, 2, здание местного отделения ДОСААФ, телефон: 5-24-35		0101000020E6100000EDD808C4EBB64240ECF82F1004A24640
46580	2	20	699	50413	21703	\N	45.209034000000003	Тамань станица, Некрасова, 5, здание МБОУ СОШ №9, телефон: 31-2-07		0101000020E6100000DB6B41EF8D5B424044E048A0C19A4640
46578	2	20	699	50531	22606	\N	45.209034000000003	Тамань станица, Карла Маркса, 165, здание Дома культуры, телефон: 31-3-85		0101000020E6100000DB6B41EF8D5B424044E048A0C19A4640
46582	2	20	699	22866	20634	\N	45.145746000000003	Таманский поселок, Ленина, 14, здание Дома культуры, телефон: 36-8-94		0101000020E6100000AD4B8DD0CF644240ECC20FCEA7924640
46561	2	20	699	47422	20843	\N	45.202219999999997	Стрелка поселок, Ленина, 11, здание Дома культуры, телефон: 92-4-30		0101000020E610000029ED0DBE30A542406E4C4F58E2994640
46560	2	20	699	47422	20843	\N	45.202219999999997	Стрелка поселок, Ленина, 8 Б, здание администрации поселения, телефон: 92-5-75		0101000020E610000029ED0DBE30A542406E4C4F58E2994640
46565	2	20	699	22046	21697	\N	45.216456999999998	Старотитаровская станица, пер. Горького, 2, адмдминистративное здание ПЧ-2, телефон: 91-6-15		0101000020E61000008AE942ACFE944240C1FEEBDCB49B4640
46563	2	20	699	22046	21255	\N	45.216456999999998	Старотитаровская станица, Садовая, 151, здание МОУ СОШ №27, телефон: 90-5-71		0101000020E61000008AE942ACFE944240C1FEEBDCB49B4640
46566	2	20	699	22046	22568	\N	45.216456999999998	"Старотитаровская станица, пер. Ильича, 46, администр. здание ООО ""Кубань"", телефон: 91-9-16"		0101000020E61000008AE942ACFE944240C1FEEBDCB49B4640
46584	2	20	699	22046	21286	\N	45.216456999999998	Старотитаровская станица, Ленина, 211, здание МБОУ СОШ №6, телефон: 90-1-01		0101000020E61000008AE942ACFE944240C1FEEBDCB49B4640
46564	2	20	699	22046	21286	\N	45.216456999999998	Старотитаровская станица, Ленина, 310, здание Культурно-соц. центра, телефон: 90-6-63		0101000020E61000008AE942ACFE944240C1FEEBDCB49B4640
46558	2	20	699	47351	20589	\N	45.298288999999997	Сенной поселок, Мира, 38, здание Дома культуры, телефон: 38-4-08		0101000020E6100000F67AF7C77B7F4240D6E07D552EA64640
46557	2	20	699	47351	21456	\N	45.298288999999997	Сенной поселок, Кулакова, 31, здание музыкальной школы, телефон: 39-00-2		0101000020E6100000F67AF7C77B7F4240D6E07D552EA64640
46551	2	20	699	47218	22542	\N	45.206055999999997	Светлый путь поселок, Широкая, 45, здание Дома культуры, телефон: 93-6-43		0101000020E61000002577D84466D442408192020B609A4640
46559	2	20	699	47386	22220	\N	45.264906000000003	Приморский поселок, Ленина, 7, здание Дома культуры, телефон: 37-5-35		0101000020E6100000B950F9D7F2744240D1419770E8A14640
46086	2	20	699	47386	22153	\N	45.265569154793504	поселок Приморский, ул. Красная, 10, телефон: 57123	Россия, Краснодарский край, Темрюкский район, поселок Приморский	0101000020E6100000292158552F7542406CEA3C2AFEA14640
46555	2	20	699	47306	21052	\N	45.347751000000002	Пересыпь поселок, Бондаревой, 94, здание МБОУ СОШ №22, телефон: 79-1-02		0101000020E610000046ED7E15E09142405E13D21A83AC4640
46571	2	20	699	47616	20597	\N	45.405124000000001	Кучугуры поселок, Ленина, 41, здание Дома культуры, телефон: 79-2-98		0101000020E6100000433D7D04FE7A424090696D1ADBB34640
46548	2	20	699	21335	20831	\N	45.224139000000001	Курчанская станица, Чапаева, 38, телефон: 95-4-07		0101000020E6100000CBD8D0CDFEC842400B613596B09C4640
46550	2	20	699	21335	20829	\N	45.224139000000001	Курчанская станица, Красная, 198, здание МДОУ №17, телефон: 95-4-75		0101000020E6100000CBD8D0CDFEC842400B613596B09C4640
46549	2	20	699	21335	20829	\N	45.224139000000001	Курчанская станица, Красная, 79, здание Дома культуры, телефон: 95-2-69		0101000020E6100000CBD8D0CDFEC842400B613596B09C4640
46552	2	20	699	47233	22160	\N	45.193570000000001	Красный Октябрь поселок, Школьная, 1, здание МБОУ СОШ №20, телефон: 94-3-45		0101000020E6100000A25EF0694ED442404DBED9E6C6984640
46623	2	20	699	47327	20926	\N	45.394978999999999	поселок Красноармейский, Постовая, 35, телефон: 6-01-05		0101000020E6100000C58F31772D6F4240ABCDFFAB8EB24640
44946	2	20	699	47327	21185	\N	45.394978999999999	поселок Красноармейский, Первомайский, 4, телефон: 56-2-74		0101000020E6100000C58F31772D6F4240ABCDFFAB8EB24640
46574	2	20	699	50478	22231	\N	45.423554000000003	Ильич поселок, Ленина, 36, здание МБОУ СОШ №17, телефон: 94-7-93	Россия, Краснодарский край, Темрюкский район, поселок Ильич	0101000020E61000009605137F14634240850B790437B64640
46573	2	20	699	22486	21475	\N	45.377825000000001	Запорожская станица, Ленина, 21 А, здание Дома культуры, телефон: 77-4-14		0101000020E6100000020D36751E6F42403C4ED1915CB04640
46553	2	20	699	21558	21450	\N	45.322977999999999	Голубицкая станица, Советская, 116, здание администрации поселения, телефон: 63-1-17		0101000020E61000007FBF982D59A34240EBA9D55757A94640
46554	2	20	699	21558	20958	\N	45.322977999999999	"Голубицкая станица, Красная, 108, здание МКУ ""Голубицкий КСЦ"", телефон: 63-6-89"		0101000020E61000007FBF982D59A34240EBA9D55757A94640
46575	2	20	699	22583	21480	\N	45.319510999999999	"Гаркуша поселок, Ленина, 28, здание конторы отд. №2 ""Залив"", телефон: 77-2-86"		0101000020E61000002507EC6AF26C42402BDB87BCE5A84640
46568	2	20	699	22222	21263	\N	45.194687999999999	Вышестеблиевская станица, Ленина, 63, здание Дома культуры, телефон: 35-5-01		0101000020E610000030DAE385748042403A765089EB984640
46567	2	20	699	22222	21263	\N	45.194687999999999	Вышестеблиевская станица, Ленина, 94, здание администрации поселения, телефон: 35-5-25		0101000020E610000030DAE385748042403A765089EB984640
46577	2	20	699	47714	21229	\N	45.126308999999999	Волна поселок, Приморская, 2, здание МБОУ ООШ №32, телефон: 33-6-48		0101000020E610000044E048A0C15A42406118B0E42A904640
46569	2	20	699	4879	22226	\N	45.193277999999999	Виноградный поселок, площадь Ленина, 8, здание Дома культуры, телефон: 30-8-02		0101000020E61000004DBD6E1118734240A5846055BD984640
45555	2	20	699	4879	20474	\N	45.193277999999999	поселок Виноградный, Молодежная, 17а, телефон: 6-18-35	Россия, Краснодарский край, Темрюкский район, поселок Виноградный	0101000020E61000004DBD6E1118734240A5846055BD984640
46583	2	20	699	47818	21277	\N	45.128529	Веселовка поселок, Гвардейская, 18, здание Дома культуры, телефон: 36-4-33		0101000020E6100000732CEFAA0774424036CB65A373904640
46562	2	20	699	50688	23617	\N	45.170593745146597	Белый хутор, пер. Садовый, 7, здание Дома культуры, телефон: 93-3-69	Россия, Краснодарский край, Темрюкский район, поселок Белый	0101000020E610000047C8409E5DA2424069723106D6954640
46576	2	20	699	22620	21271	\N	45.392378000000001	Батарейка поселок, Степная, 8, здание Дома культуры, телефон: 3459504		0101000020E6100000919DB7B1D9694240BFD53A7139B24640
46556	2	20	699	21676	21677	\N	45.318351	Ахтанизовская станица, пер. Северный, 13, здание Дома культуры, телефон: 68-1-18		0101000020E61000008D9B1A683E8D42400FD3BEB9BFA84640
46511	2	20	1525	19326	21967	\N	45.326506999999999	село Шереметьевское, улица Колхозная, дом 106, телефон: 3 10 61		0101000020E610000057B08D78B219444021753BFBCAA94640
46063	2	20	1525	50843	23846	\N	45.324778128353699	хутор Шевченко, Длинная, 59, телефон: 4-20-10	Россия, Краснодарский край, Тбилисский район, поселок Шевченко	0101000020E6100000E563778192204440EB3A545392A94640
46524	2	20	1525	20008	21027	\N	45.549354000000001	хутор Чернобабов, улица Степная, дом 67, телефон: 6 53 15		0101000020E610000096CB46E7FC0C4440A1F65B3B51C64640
46521	2	20	1525	19836	20904	\N	45.324314999999999	хутор Терско-Каламбетский, улица Прикубанская, дом 33, телефон: 6 74 89		0101000020E6100000DE1CAED51E0E4440164D672783A94640
46500	2	20	1525	18756	20771	\N	45.459865000000001	поселок Терновый, улица Центральная, дом 2, телефон: 6 90 66		0101000020E610000041BAD8B4520244409BC937DBDCBA4640
46496	2	20	1525	18001	21538	\N	45.361913000000001	станица Тбилисская, переулок Средний, дом 13, телефон: 2 58 14		0101000020E610000004560E2DB2194440A67F492A53AE4640
46490	2	20	1525	18001	21922	\N	45.361913000000001	станица Тбилисская, улица Элеваторная, дом 70, телефон: 3 37 45		0101000020E610000004560E2DB2194440A67F492A53AE4640
46485	2	20	1525	18001	21908	\N	45.361913000000001	станица Тбилисская, улица Толстого, дом 24, телефон: 3 29 54		0101000020E610000004560E2DB2194440A67F492A53AE4640
46489	2	20	1525	18001	22383	\N	45.361913000000001	станица Тбилисская, улица Первомайская, дом 77, телефон: 3 21 01	Россия, Краснодарский край, Тбилисский район, поселок Тбилисская	0101000020E610000004560E2DB2194440A67F492A53AE4640
46494	2	20	1525	18001	20524	\N	45.361913000000001	станица Тбилисская, улица Октябрьская, дом 298 А, телефон: 2 36 08		0101000020E610000004560E2DB2194440A67F492A53AE4640
46488	2	20	1525	18001	20524	\N	45.361913000000001	станица Тбилисская, улица Октябрьская, дом 133, телефон: 2 46 51		0101000020E610000004560E2DB2194440A67F492A53AE4640
14055	1	17	\N	3130	22785	\N	58.045848999999997	г. Рыбинск, Свердлова, 26		0101000020E6100000B3614D65516C4340F3C64961DE054D40
46486	2	20	1525	18001	20524	\N	45.361913000000001	станица Тбилисская, улица Октябрьская, дом 2, телефон: 3 34 66		0101000020E610000004560E2DB2194440A67F492A53AE4640
46492	2	20	1525	18001	21411	\N	45.361913000000001	станица Тбилисская, улица Новая, дом 33, телефон: 2 38 46		0101000020E610000004560E2DB2194440A67F492A53AE4640
46497	2	20	1525	18001	20711	\N	45.361913000000001	станица Тбилисская, улица Набережная, дом 29, телефон: 3 39 53		0101000020E610000004560E2DB2194440A67F492A53AE4640
46495	2	20	1525	18001	20759	\N	45.361913000000001	станица Тбилисская, улица Красная, дом 134, телефон: 2 30 53		0101000020E610000004560E2DB2194440A67F492A53AE4640
46491	2	20	1525	18001	20759	\N	45.361913000000001	станица Тбилисская, улица Красная, дом 24, телефон: 3 29 72		0101000020E610000004560E2DB2194440A67F492A53AE4640
46487	2	20	1525	18001	20562	\N	45.361913000000001	станица Тбилисская, улица Водопроводная, дом 22, телефон: 2 49 68		0101000020E610000004560E2DB2194440A67F492A53AE4640
46493	2	20	1525	18001	21606	\N	45.361913000000001	станица Тбилисская, улица Базарная, дом 145, телефон: 3 27 58		0101000020E610000004560E2DB2194440A67F492A53AE4640
46516	2	20	1525	50716	23451	\N	45.202357975333001	хутор Средний, улица Коммунаров, здание ФАП, телефон: 6 88 50	Россия, Краснодарский край, Тбилисский район, поселок Средний	0101000020E6100000209C4F1DAB104440BF0AF0DDE6994640
46509	2	20	1525	19198	21624	\N	45.328795	хутор Северокубанский, улица Якубина, 239, телефон: 6 32 50	Россия, Краснодарский край, Тбилисский район, поселок Северокубанский	0101000020E610000031CD74AF932444404E0B5EF415AA4640
46508	2	20	1525	19198	21624	\N	45.328795	хутор Северокубанский, улица Якубина, дом 239, телефон: 6 34 51		0101000020E610000031CD74AF932444404E0B5EF415AA4640
46498	2	20	1525	18648	21000	\N	45.347548000000003	хутор Северин, улица Ленина, дом 9, телефон: 6 67 75		0101000020E610000077A1B94E231B444026E5EE737CAC4640
46526	2	20	1525	50380	21479	\N	45.256740948011	хутор Песчаный, улица Октябрьская, дом 38, телефон: 6 04 08	Россия, Краснодарский край, Тбилисский район, поселок Песчаный	0101000020E61000009148DBF8132F44406B459BE3DCA04640
46507	2	20	1525	19115	21425	\N	45.339319000000003	хутор Новопеховский Первый, улица Волкова, здание сельского клуба, телефон: 6 34 17	Россия, Краснодарский край, Тбилисский район, поселок Новопеховский-Первый	0101000020E6100000A646E867EA294440AAF413CE6EAB4640
46523	2	20	1525	19933	21442	\N	45.546823000000003	станица Нововладимировская, улица Ленина, дом 13, телефон: 6 53 33		0101000020E61000008E3BA583F50F4440AED9CA4BFEC54640
46525	2	20	1525	20061	21644	\N	45.556845000000003	станица Новобекешевская, улица Садовая, дом 79, телефон: 6 51 76		0101000020E6100000842D76FBAC14444077F86BB246C74640
46519	2	20	1525	50265	20573	\N	45.278625800850897	хутор Марьинский, улица Мамеева, дом 58, телефон: 6 74 42		0101000020E61000006C96CB46E71044405CE84A04AAA34640
46517	2	20	1525	19634	21635	\N	45.519061999999998	станица Ловлинская, переулок Школьный, дом 9, телефон: 6 42 30	Россия, Краснодарский край, Тбилисский район, поселок Ловлинская	0101000020E6100000C4E8B985AE1E4440554CA59F70C24640
46518	2	20	1525	19634	22899	\N	45.519755893812302	станица Ловлинская, переулок Школьный, дом 9, телефон: 6 42 69	Россия, Краснодарский край, Тбилисский район, поселок Ловлинская	0101000020E61000003F1F65C4051E44402CF3565D87C24640
46505	2	20	1525	19038	21007	\N	45.278098999999997	хутор Красный Зеленчук, улица Магазинная, дом 16, телефон: 6 38 93		0101000020E61000009AB0FD648C2B444070067FBF98A34640
46530	2	20	1525	20401	21036	\N	45.260623000000002	хутор Зубов, улица Зеленчукская, дом 26, телефон: 6 71 37	Россия, Краснодарский край, Тбилисский район, поселок Зубов	0101000020E6100000301004C8D0094440EFCA2E185CA14640
46520	2	20	1525	19803	21999	\N	45.281815000000002	хутор Зиссермановский, улица Верхняя, дом 2, телефон: 6 74 24		0101000020E61000004582A966D6164440D942908312A44640
46522	2	20	1525	19914	22487	\N	45.545889000000003	хутор Еремин, улица Светлая, дом 90, телефон: 6 53 21		0101000020E610000094DE37BEF6064440821FD5B0DFC54640
46529	2	20	1525	20294	21231	\N	45.343443000000001	хутор Екатеринославский, улица Колхозная, дом 29, телефон: 6 67 24		0101000020E61000000CCD751A691544402385B2F0F5AB4640
46512	2	20	1525	19397	21969	\N	45.266421999999999	станица Геймановская, улица Октябрьская, дом 72, телефон: 6 12 18		0101000020E610000073A1F2AFE5194440AB77B81D1AA24640
46482	2	20	1525	50723	\N	\N	45.261140766041997	"хутор Веселый, Административное здание бригады №2 ЗАО ""Красное Знамя"", телефон: 5-38-33"	Россия, Краснодарский край, Тбилисский район, поселок Веселый	0101000020E6100000FB07910C3926444087527B116DA14640
46506	2	20	1525	50723	23459	\N	45.2637222856265	хутор Веселый, улица Красная, здание ФАП, телефон: 6 21 03	Россия, Краснодарский край, Тбилисский район, поселок Веселый	0101000020E6100000AF7B2B12132644402C9E7AA4C1A14640
46527	2	20	1525	50832	23800	\N	45.2201937443538	хутор Веревкин, улица Красная, дом 25, телефон: 6 04 14	Россия, Краснодарский край, Тбилисский район, поселок Веревкин	0101000020E6100000CFF6E80DF72D4440416326512F9C4640
46510	2	20	1525	19298	21009	\N	45.324061	село Ванновское, улица Ленина, дом 69, телефон: 6 32 76		0101000020E6100000664D2CF0151D44405C74B2D47AA94640
46528	2	20	1525	19519	21650	\N	45.208418000000002	станица Алексее-Тенгинская, улица Октябрьская, здание автогаража, телефон: 6 86 33		0101000020E6100000DF87838428174440E9F2E670AD9A4640
46515	2	20	1525	50448	21987	\N	45.386738000000001	станица Алексее-Тенгинская, переулок Ушинского, дом 3, телефон: 6 86 45		0101000020E61000008995D1C8E71344406B0F7BA180B14640
46478	2	20	1478	17640	21003	\N	46.505479999999999	хутор Ясени, ул.Южная, 83, телефон: 4-38-37		0101000020E6100000A19E3E027F6C43401B649291B3404740
46464	2	20	1478	16957	22297	\N	46.555268476970198	станица Староминская, ул. Трудовая, 121, телефон: 5-73-11		0101000020E6100000B83D4162BB854340F641960513474740
46474	2	20	1478	16957	21189	\N	46.537475999999998	станица Староминская, ул. Петренко, 149, телефон: 5-73-21		0101000020E610000027BEDA519C87434044317903CC444740
46473	2	20	1478	16957	21197	\N	46.537475999999998	станица Староминская, ул. Орджоникидзе, 101, телефон: 5-73-20		0101000020E610000027BEDA519C87434044317903CC444740
13947	1	17	\N	3130	22894	\N	58.045848999999997	г.Рыбинск, Рокоссовского, 11		0101000020E6100000B3614D65516C4340F3C64961DE054D40
46468	2	20	1478	16957	21894	\N	46.537475999999998	станица Староминская, ул. Новощербиновская, 138, телефон: 5-73-15		0101000020E610000027BEDA519C87434044317903CC444740
46466	2	20	1478	16957	22322	\N	46.543398580637103	станица Староминская, ул. Ленина, 24-А, телефон: 5-44-03	Россия, Краснодарский край, Староминский район, поселок Староминская	0101000020E61000003274ECA012854340EDD632198E454740
46470	2	20	1478	16957	20515	\N	46.537475999999998	станица Староминская, ул. Краснознаменная, 126, телефон: 5-73-17		0101000020E610000027BEDA519C87434044317903CC444740
46467	2	20	1478	16957	21831	\N	46.5420512292214	станица Староминская, ул. Красная, 39, телефон: 5-72-28	Россия, Краснодарский край, Староминский район, поселок Староминская	0101000020E6100000FC71FBE593874340CEE15AED61454740
46472	2	20	1478	16957	20703	\N	46.537475999999998	станица Староминская, ул. Кольцовская, 52, телефон: 5-77-81		0101000020E610000027BEDA519C87434044317903CC444740
46465	2	20	1478	16957	21144	\N	46.537475999999998	станица Староминская, ул. Кирова, 33, телефон: 5-73-12		0101000020E610000027BEDA519C87434044317903CC444740
46469	2	20	1478	16957	20732	\N	46.537475999999998	станица Староминская, ул. Калинина, 2, телефон: 5-76-20		0101000020E610000027BEDA519C87434044317903CC444740
46475	2	20	1478	16957	20523	\N	46.537475999999998	станица Староминская, ул. Железнодорожная, 23, телефон: 4-23-43		0101000020E610000027BEDA519C87434044317903CC444740
46471	2	20	1478	16957	21542	\N	46.537475999999998	станица Староминская, ул. Большая Садовая, 113, телефон: 5-73-18		0101000020E610000027BEDA519C87434044317903CC444740
46479	2	20	1478	50322	21072	\N	46.420957999999999	поселок Рассвет, ул.Мира, Сельский Дом культуры, телефон: 5-32-05	Россия, Краснодарский край, Староминский район, поселок Рассвет	0101000020E61000002D793C2D3F8C4340AA7EA5F3E1354740
45759	2	20	1478	49448	22218	\N	46.450924000000001	пос. Первомайский, Комарова, 8, телефон: 5-24-06		0101000020E6100000959F54FB74884340A27DACE0B7394740
46477	2	20	1478	17604	20529	\N	46.485788999999997	станица Новоясенская, пер.Мира, 6-А, телефон: 5-17-97		0101000020E6100000AD6EF59CF4644340D6E07D552E3E4740
46484	2	20	1478	17895	20993	\N	46.590186000000003	станица Канеловская, ул. Пионерская, 43, телефон: 5-22-69		0101000020E6100000FD304278B49743404E4700378B4B4740
46483	2	20	1478	17895	20993	\N	46.590186000000003	станица Канеловская, ул. Пионерская, 39, телефон: 5-22-98		0101000020E6100000FD304278B49743404E4700378B4B4740
45110	2	20	1478	50297	20894	\N	46.397058999999999	поселок Заря, ул.Красноармейская, 15, телефон: 91-1-36	Россия, Краснодарский край, Староминский район, поселок Заря	0101000020E6100000643F8BA5488643408ECA4DD4D2324740
46476	2	20	1478	17535	21929	\N	46.404803000000001	хутор Желтые Копани, ул. Северная, 14, телефон: 4-38-30		0101000020E610000052D66F26A66F43404E29AF95D0334740
46481	2	20	1478	17803	\N	\N	46.434046000000002	"хутор Восточный Сосык, Здание МОУ ""СОШ №6"", телефон: 5-36-20"		0101000020E6100000A1681EC0229D4340D57ABFD18E374740
45720	2	20	1478	48880	20773	\N	46.474904000000002	пос. Веселый, Школьная, 4, телефон: 75185		0101000020E6100000CDAE7B2B12994340AB5E7EA7C93C4740
46216	2	20	479	50461	\N	\N	45.436222999999998	"Славянский район, пос. МТФ-2, ОАО""Аспект"", телефон: 8-918-6688251"		0101000020E61000000133DFC14FF24240AA61BF27D6B74640
46237	2	20	479	50885	23976	\N	45.586280537602697	Краснодарский край, Славянский район,х.Черный Ерик, Мира, 20, телефон: 9-57-17	Россия, Краснодарский край, Славянский район, поселок Черный Ерик	0101000020E6100000C93846B247DE424012A27C410BCB4640
46234	2	20	479	5046	21138	\N	45.437741000000003	Славянский район, ст.Черноерковская, Комсомольская, 2, телефон: 9-51-71		0101000020E610000088D51F6118E24240268FA7E507B84640
46233	2	20	479	50432	21823	\N	45.437741000000003	Славянский район, ст.Черноерковская, Красная, 31, телефон: 9-52-44		0101000020E610000088D51F6118E24240268FA7E507B84640
46231	2	20	479	5773	20457	\N	45.55829	Славянский район, п.Целинный, Красная, 1, телефон: 9-62-87		0101000020E61000008CF4A276BFFA424088D7F50B76C74640
46204	2	20	479	50555	22766	\N	45.162979302030003	Славянский район,х.Ханьков, Ленина, 133, телефон: 9-36-38	Россия, Краснодарский край, Славянский район, поселок Ханьков	0101000020E6100000D2A755F487F04240A777F17EDC944640
46224	2	20	479	5421	21090	\N	45.282585779863197	Славянский район, пос.Совхозный, Школьная, 607, телефон: 2-61-13	Россия, Краснодарский край, Славянский район, поселок Совхозный	0101000020E6100000D0D1AA96740E43405B272EC72BA44640
46196	2	20	479	2858	21444	\N	45.2508072169095	город Славянск-на-Кубани, Ярмарочная, 349, телефон: 2-34-08	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E6100000A260C614AC0D4340CF4D9B711AA04640
46179	2	20	479	2858	21247	\N	45.237452530133602	город Славянск-на-Кубани, Школьная, 201, телефон: (246) 2-28-78	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E61000002123A0C21110434026AB22DC649E4640
46178	2	20	479	2858	21054	\N	45.237589	город Славянск-на-Кубани, Стаханова, 16, телефон: (246) 2-35-56		0101000020E61000000B630B410E104340D671FC50699E4640
46195	2	20	479	2858	21265	\N	45.237589	город Славянск-на-Кубани, Совхозная, 100, телефон: 4-45-30		0101000020E61000000B630B410E104340D671FC50699E4640
46190	2	20	479	2858	21699	\N	45.237589	город Славянск-на-Кубани, Проточная, 136, телефон: 2-24-91	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E61000000B630B410E104340D671FC50699E4640
46182	2	20	479	2858	20839	\N	45.244986720406203	город Славянск-на-Кубани, Отдельская, 145, телефон: (246) 2-14-51		0101000020E61000006138D730430F4340FB78E8BB5B9F4640
46181	2	20	479	2858	20839	\N	45.237589	город Славянск-на-Кубани, Отдельская, 29а, телефон: (246) 2-30-60		0101000020E61000000B630B410E104340D671FC50699E4640
46185	2	20	479	2858	21473	\N	45.255103995088	город Славянск-на-Кубани, Крупской, 294, телефон: (246) 2-20-57	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E61000000803CFBD870F4340168A743FA7A04640
46189	2	20	479	2858	20845	\N	45.261112873162098	город Славянск-на-Кубани, Красная, 8, телефон: 2-23-63		0101000020E6100000954737C2A2104340BDC799266CA14640
46186	2	20	479	2858	20845	\N	45.237589	город Славянск-на-Кубани, Красная, 52, телефон: (246) 2-39-81		0101000020E61000000B630B410E104340D671FC50699E4640
46193	2	20	479	2858	21469	\N	45.237589	город Славянск-на-Кубани, Запорожская, 36-А, телефон: 2-19-49		0101000020E61000000B630B410E104340D671FC50699E4640
46188	2	20	479	2858	21686	\N	45.231783814945203	город Славянск-на-Кубани, Западная, 179, телефон: (246) 4-10-62		0101000020E610000024986A662D0F434037DE1D19AB9D4640
46177	2	20	479	2858	20867	\N	45.237589	город Славянск-на-Кубани, Донская, 7, телефон: (246) 3-13-97		0101000020E61000000B630B410E104340D671FC50699E4640
46192	2	20	479	2858	20860	\N	45.237589	город Славянск-на-Кубани, Дзержинского, 390, телефон: 2-11-53		0101000020E61000000B630B410E104340D671FC50699E4640
46180	2	20	479	2858	20860	\N	45.2698197087553	город Славянск-на-Кубани, Дзержинского, 76, телефон: (246) 4-41-49	Россия, Краснодарский край, Славянский район, город Славянск-На-Кубани	0101000020E610000023A298BC0110434043E7357689A24640
46213	2	20	479	50741	23509	\N	45.178453658622097	Славянский район, х.Сербин, Пионерская, 9, телефон: 9-91-61	Россия, Краснодарский край, Славянский район, поселок Сербин	0101000020E6100000CA8B4CC0AF19434092EBA694D7964640
46228	2	20	479	50710	23443	\N	45.2992842200794	Славянский район, х.Семисводный, Пионерская, 11, телефон: 9-22-88	Россия, Краснодарский край, Славянский район, поселок Семисводный	0101000020E61000009C4D470037FD4240A81B28F04EA64640
46226	2	20	479	5495	21746	\N	45.316820535130297	Славянский район, п.Садовый, Виноградная, 8, телефон: 2-66-83		0101000020E6100000637D03931B074340CFD72C978DA84640
46230	2	20	479	5717	21796	\N	45.294358000000003	Славянский район, пос.Рисовый, Октябрьская, 20, телефон: 9-42-30		0101000020E6100000253E7782FDF3424072A8DF85ADA54640
46236	2	20	479	50895	24009	\N	45.538276000000003	Славянский район, х.Прорвенский, Западная, 2, телефон: 9-56-74	Россия, Краснодарский край, Славянский район, поселок Прорвенский	0101000020E610000057AF22A303DA4240611C5C3AE6C44640
45854	2	20	479	19419	22501	\N	45.158061251956802	п.Прикубанский, ул.Школьная, 6, телефон: 2-21-82		0101000020E6100000575F5D15A8074340F3E2C4573B944640
46215	2	20	479	19419	23481	\N	45.158790000000003	Славянский район, х.Прикубанский, Победы, 30, телефон: 7-26-43	Россия, Краснодарский край, Славянский район, поселок Прикубанский	0101000020E6100000791F4773640943404777103B53944640
46203	2	20	479	19419	23467	\N	45.1632561581335	Славянский район, х.Прикубанский, Весёлая, 34-А, телефон: 9-36-43	Россия, Краснодарский край, Славянский район, поселок Прикубанский	0101000020E6100000CC9BC3B5DA09434019709692E5944640
46225	2	20	479	5474	21514	\N	45.303610784074003	Славянский район, п.Прибрежный, Советская, 6, телефон: 2-61-75	Россия, Краснодарский край, Славянский район, поселок Прибрежный	0101000020E6100000A379008BFC0A434059DAA9B9DCA64640
46218	2	20	479	50638	23165	\N	45.432145805622199	Славянский район, ст.Петровская, Чапаева, 177-А, телефон: 9-12-54		0101000020E61000002DB4739A05F84240728C648F50B74640
46217	2	20	479	50324	21501	\N	45.431517522926001	Славянский район, ст.Петровская, Черноерковская, 1, телефон: 9-11-57	Россия, Краснодарский край, Славянский район, поселок Петровская	0101000020E61000005709168733F9424052D158FB3BB74640
46221	2	20	479	50324	23347	\N	45.431303	Славянский район, ст.Петровская, Мелиораторов, 4, телефон: 9-11-50	Россия, Краснодарский край, Славянский район, поселок Петровская	0101000020E6100000F1D58EE21CF9424056D5CBEF34B74640
46220	2	20	479	50324	21091	\N	45.424775581742303	Славянский район, ст.Петровская, Красная, 20, телефон: 9-11-43	Россия, Краснодарский край, Славянский район, поселок Петровская	0101000020E6100000DDD26A48DCF9424017105A0F5FB64640
46219	2	20	479	50324	21511	\N	45.431303	Славянский район, ст.Петровская, Инкубаторская, 10, телефон: 9-12-40	Россия, Краснодарский край, Славянский район, поселок Петровская	0101000020E6100000F1D58EE21CF9424056D5CBEF34B74640
46222	2	20	479	50324	23850	\N	45.431303	Славянский район, ст.Петровская, Гагарина, 12, телефон: 9-11-14	Россия, Краснодарский край, Славянский район, поселок Петровская	0101000020E6100000F1D58EE21CF9424056D5CBEF34B74640
46229	2	20	479	50612	22982	\N	45.386569206573498	Славянский район, х.Нещадимовский, Безымянная, 35, телефон: 9-26-51	Россия, Краснодарский край, Славянский район, поселок Нещадимовский	0101000020E61000004C8A8F4FC8024340DF52CE177BB14640
46214	2	20	479	50864	23922	\N	45.169597067858398	Славянский район, х.Маевский, Мира, 7, телефон: 7-17-53	Россия, Краснодарский край, Славянский район, поселок Маевский	0101000020E6100000CD91955F06154340F73FC05AB5954640
46210	2	20	479	50823	23763	\N	45.528400559382597	Славянский район, х.Красноармейский городок, Красноармейская, 49, телефон: 9-64-07	Россия, Краснодарский край, Славянский район, поселок Красноармейский Городок	0101000020E6100000A391CF2B9E0843403C16DBA4A2C34640
46212	2	20	479	50670	23353	\N	45.194396721113499	Славянский район, х.Коржевский, Октябрьская, 13, телефон: 8-988-3696355	Россия, Краснодарский край, Славянский район, поселок Коржевский	0101000020E61000000B9755D80CDC424063B83A00E2984640
46211	2	20	479	50670	23337	\N	45.1965297568875	Славянский район, х.Коржевский, Октябрьская, 24-А, телефон: 9-82-21	Россия, Краснодарский край, Славянский район, поселок Коржевский	0101000020E610000033FE7DC685DB4240695721E527994640
46206	2	20	479	4420	22365	\N	45.572361000000001	Славянский район, пос.Забойский, Красная, 131, телефон: 9-71-53		0101000020E6100000F38E5374240B4340C040102043C94640
46207	2	20	479	50689	23396	\N	45.6548711020139	Славянский район, х.Деревянковка, Школьная, 12, телефон: 9-72-79	Россия, Краснодарский край, Славянский район, поселок Деревянковка	0101000020E610000043209738F20A4340A60C1CD0D2D34640
46232	2	20	479	5817	21134	\N	45.663426999999999	Славянский район, п.Голубая Нива, Школьная, 1, телефон: 9-61-17		0101000020E61000008BE255D636ED424046240A2DEBD44640
46208	2	20	479	50891	23999	\N	45.484209530457498	Славянский район,х.Галицин, Мира, 11, телефон: 9-65-77	Россия, Краснодарский край, Славянский район, поселок Галицын	0101000020E61000007C9A931799064340B532E197FABD4640
46223	2	20	479	50789	23608	\N	45.432579072347501	Славянский район, х.Водный, Кубанская, 1-А, телефон: 9-14-81	Россия, Краснодарский край, Славянский район, поселок Водный	0101000020E61000000D535BEA20074340DBF7A8BF5EB74640
46235	2	20	479	50764	23555	\N	45.483199524731397	Славянский район, х.Верхний, Рабочая, 1, телефон: 9-56-51	Россия, Краснодарский край, Славянский район	0101000020E61000007BA01518B2DC4240AEB6627FD9BD4640
46209	2	20	479	50325	21096	\N	45.487997036987501	Славянский район, х.Беликов, пер. Гвардейский, 14, телефон: 9-64-79	Россия, Краснодарский край, Славянский район, поселок Беликов	0101000020E6100000632827DA55FC4240E7C589AF76BE4640
46227	2	20	479	50881	23969	\N	45.352797716782398	Славянский район, х.Бараниковский, Советов, 13, телефон: 9-21-04	Россия, Краснодарский край, Славянский район, поселок Бараниковский	0101000020E6100000C9AA0837190343400F0C207C28AD4640
46238	2	20	479	6152	21536	\N	45.714795000000002	Краснодарский край, Славянский район,с.Ачуево, Ленина, 43, телефон: 7-55-67,7-55-16		0101000020E61000003DB665C059E24240132C0E677EDB4640
46202	2	20	479	4070	20607	\N	45.217396000000001	Славянский район, ст.Анастасиевская, Красная, 52, телефон: 5-32-14		0101000020E6100000FDD8243FE2F14240FF23D3A1D39B4640
46201	2	20	479	4070	20607	\N	45.217396000000001	Славянский район, ст. Анастасиевская, Красная, 87, телефон: 5-13-18		0101000020E6100000FDD8243FE2F14240FF23D3A1D39B4640
46200	2	20	479	4070	20607	\N	45.217396000000001	Славянский район, станица Анастасиевская, Красная, 181, телефон: 5-20-62		0101000020E6100000FDD8243FE2F14240FF23D3A1D39B4640
46199	2	20	479	4070	20607	\N	45.217396000000001	Славянский район, станица Анастасиевская, Красная, 162, телефон: 5-13-03		0101000020E6100000FDD8243FE2F14240FF23D3A1D39B4640
46157	2	20	85	40302	9758	\N	44.870797708123099	ст. Северская, Ленина, 230, телефон: 2-68-34	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E61000002594BE10725843400BB6114F766F4640
46156	2	20	85	40302	20447	\N	44.870919999999998	ст. Северская, Казачья, 147, телефон: 2-24-32		0101000020E6100000E8F86871C658434056B77A4E7A6F4640
46155	2	20	85	50402	21660	\N	44.870919999999998	ст. Северская, Ленина, 132, телефон: 2-16-95		0101000020E6100000E8F86871C658434056B77A4E7A6F4640
46151	2	20	85	50402	21660	\N	44.870919999999998	ст. Северская, Ленина, 19/А, телефон: 2-69-72		0101000020E6100000E8F86871C658434056B77A4E7A6F4640
46174	2	20	85	2709	21115	\N	44.567838999999999	с. Шабановское, Кирова, 48, телефон: 57-3-11		0101000020E61000005665DF15C16743405932C7F2AE484640
46168	2	20	85	2281	20824	\N	44.848436	п. Черноморский, Тельмана, 3, телефон: 66-8-81		0101000020E61000000BF148BC3C3F4340E15F048D996C4640
46170	2	20	85	2281	20599	\N	44.848436	п. Черноморский, Октябрьская, 2, телефон: 66-9-30		0101000020E61000000BF148BC3C3F4340E15F048D996C4640
46121	2	20	85	50733	23482	\N	44.732853474757803	ст. Убинская, Центральная, 48, телефон: 51-7-02	Россия, Краснодарский край, Северский район	0101000020E61000003FA7203F1B47434043E38920CE5D4640
46175	2	20	85	2730	21053	\N	44.602877999999997	с. Тхамаха, Школьная, 20, телефон: 57-3-21		0101000020E6100000B29DEFA7C66D43402BBD361B2B4D4640
46140	2	20	85	747	20548	\N	45.063409060594097	х. Стефановский, Соболя, 16, телефон: 3-78-90	Россия, Краснодарский край, Северский район, поселок Стефановский	0101000020E6100000A180ED60C4564340D3A23EC91D884640
46124	2	20	85	50404	21669	\N	44.716526999999999	ст. Ставропольская, 50-Лет ВЛКСМ, 50, телефон: 44-2-35	Россия, Краснодарский край, Северский район, поселок Ставропольская	0101000020E6100000CD3D247CEF694340BAD91F28B75B4640
46164	2	20	85	50614	22991	\N	44.784071278480098	ст. Смоленская, Почтовая, 23/А, телефон: 55-4-81	Россия, Краснодарский край, Северский район, поселок Смоленская	0101000020E61000008EAD6708C7664340FA5E43705C644640
46163	2	20	85	50614	23486	\N	44.784499162998003	ст. Смоленская, Мира, 151, телефон: 55-4-67	Россия, Краснодарский край, Северский район, поселок Смоленская	0101000020E6100000BAF94674CF664340525F96766A644640
46162	2	20	85	50614	23486	\N	44.778834329359199	ст. Смоленская, Мира, 121, телефон: 55-4-69	Россия, Краснодарский край, Северский район, поселок Смоленская	0101000020E61000009C50888043664340A6811FD5B0634640
46161	2	20	85	50614	23486	\N	44.7853671477774	ст. Смоленская, Мира, 2, телефон: 55-4-01	Россия, Краснодарский край, Северский район, поселок Смоленская	0101000020E61000006631B1F9B8664340C72DE6E786644640
46122	2	20	85	40276	\N	\N	44.870380481532798	ст. Северская-2, Здание главного корпуса интерната, телефон: 2-46-47	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E61000007365506D70584340D68BA19C686F4640
46154	2	20	85	40276	21098	\N	44.860151755895799	ст. Северская, Орджоникидзе, 2/1, телефон: 2-60-85	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E610000029081EDFDE57434064CBF275196E4640
46150	2	20	85	40276	22159	\N	44.856636050966301	ст. Северская, Октябрьская, 7, телефон: 2-68-92	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E6100000744012F6ED564340C3499A3FA66D4640
46159	2	20	85	40276	9696	\N	44.870309671917802	ст. Северская, Ленина, 151, телефон: 2-23-30	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E6100000BE141E34BB584340DEB06D51666F4640
46152	2	20	85	40276	9696	\N	44.858019813254103	ст. Северская, Ленина, 61, телефон: 2-15-33	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E6100000D99596917A5743402FA86F99D36D4640
46149	2	20	85	40276	20486	\N	44.870919999999998	ст. Северская, Комсомольская, 43, телефон: 2-12-30	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E6100000E8F86871C658434056B77A4E7A6F4640
46148	2	20	85	40276	20486	\N	44.870919999999998	ст. Северская, Комсомольская, 43, телефон: 2-22-57	Россия, Краснодарский край, Северский район, поселок Северская	0101000020E6100000E8F86871C658434056B77A4E7A6F4640
46153	2	20	85	40283	20818	\N	44.870919999999998	ст. Северская, Орджоникидзхе, 37/А, телефон: 2-22-25		0101000020E6100000E8F86871C658434056B77A4E7A6F4640
46029	2	20	1079	50450	21992	\N	46.175410999999997	станица Атаманская, Ленина, 3, телефон: 4-97-78		0101000020E6100000204432E4D8D24340E82D1EDE73164740
46103	2	20	85	50900	24027	\N	44.826107131318203	хутор Свободный, ул. Ленина, 22, телефон: 57557	Россия, Краснодарский край, Северский район, поселок Свободный	0101000020E6100000D4B837BF615C434093FFC9DFBD694640
46142	2	20	85	50314	21025	\N	44.964729209550299	х. Новоивановский, Широкова, 1, телефон: 3-72-38	Россия, Краснодарский край, Северский район, поселок Новоивановский	0101000020E6100000E38A8BA3724743405B40683D7C7B4640
46146	2	20	85	1034	20563	\N	44.832495999999999	ст. Новодмитриевская, Мичурина, 43, телефон: 42-4-99		0101000020E61000003BE5D18DB070434081069B3A8F6A4640
46147	2	20	85	1034	20794	\N	44.832495999999999	ст. Новодмитриевская, Красная, 69, телефон: 42-2-29	Россия, Краснодарский край, Северский район, поселок Новодмитриевская	0101000020E61000003BE5D18DB070434081069B3A8F6A4640
46145	2	20	85	1034	20794	\N	44.832495999999999	ст. Новодмитриевская, Красная, 69, телефон: 42-4-59		0101000020E61000003BE5D18DB070434081069B3A8F6A4640
46143	2	20	85	48207	20553	\N	45.009400999999997	с. Михайловское, Кооперативная, 3/А, телефон: 36-3-78		0101000020E61000000038F6ECB94043405CC64D0D34814640
46137	2	20	85	33113	20792	\N	44.993901000000001	с. Львовское, Советская, 80, телефон: 3-75-60		0101000020E6100000BFD364C6DB504340193BE125387F4640
46136	2	20	85	33113	20792	\N	44.993901000000001	с. Львовское, Советская, 66, телефон: 3-75-77		0101000020E6100000BFD364C6DB504340193BE125387F4640
46138	2	20	85	33113	20782	\N	44.993901000000001	с. Львовское, Северная, 75, телефон: 3-75-33		0101000020E6100000BFD364C6DB504340193BE125387F4640
46139	2	20	85	33113	21636	\N	44.993901000000001	с. Львовское, Октябрьская, 9/Б, телефон: 3-74-48		0101000020E6100000BFD364C6DB504340193BE125387F4640
46141	2	20	85	33113	20555	\N	44.993901000000001	с. Львовское, Ворошилова, 2/А, телефон: 3-75-67		0101000020E6100000BFD364C6DB504340193BE125387F4640
46165	2	20	85	50641	23195	\N	44.710538	ст. Крепостная, Клубная, 1, телефон: 55-5-39	Россия, Краснодарский край, Северский район, поселок Крепостная	0101000020E6100000A438471D1D5743405A48C0E8F25A4640
45719	2	20	85	50681	23374	\N	44.944493000000001	пос. Красный, Ленина, 6, телефон: 75149	Россия, Краснодарский край, Северский район, поселок Красный	0101000020E6100000414AECDADE48434085268925E5784640
46114	2	20	85	50615	22992	\N	44.939219531900001	х. Коваленко, Пролетарская, 21, телефон: 33-5-24	Россия, Краснодарский край, Северский район, поселок Коваленко	0101000020E6100000C556D0B4C4604340E3DF675C38784640
46173	2	20	85	50609	22966	\N	44.8212102405531	х. Карский, Восточная, 1/А, телефон: 66-5-38	Россия, Краснодарский край, Северский район, поселок Карский	0101000020E6100000B76114048F414340F792C6681D694640
46135	2	20	85	50287	20780	\N	44.7636350016002	ст. Калужская, Красная, 20, телефон: 42-4-06	Россия, Краснодарский край, Северский район, поселок Калужская	0101000020E6100000AC394030477D43405D8AABCABE614640
46132	2	20	85	102	22456	\N	44.841808999999998	п. Ильский, Пионерская, 32, телефон: 69-5-11		0101000020E610000072DF6A9DB84843403E3DB665C06B4640
46130	2	20	85	102	20795	\N	44.841808999999998	п. Ильский, Первомайская, 116, телефон: 68-0-17	Россия, Краснодарский край, Северский район, поселок Ильский	0101000020E610000072DF6A9DB84843403E3DB665C06B4640
46129	2	20	85	102	20795	\N	44.842344583308602	п. Ильский, Первомайская, 44/Б, телефон: 68-5-32	Россия, Краснодарский край, Северский район, поселок Ильский	0101000020E6100000D6726726184843407D7901F6D16B4640
46128	2	20	85	102	21223	\N	44.841808999999998	п. Ильский, Партизанская, 161, телефон: 69-5-12		0101000020E610000072DF6A9DB84843403E3DB665C06B4640
46125	2	20	85	102	21933	\N	44.841808999999998	п. Ильский, Мира, 24/Б, телефон: 68-5-36		0101000020E610000072DF6A9DB84843403E3DB665C06B4640
46131	2	20	85	102	21206	\N	44.841486693340002	п. Ильский, Длинная, 104, телефон: 68-5-41	Россия, Краснодарский край, Северский район, поселок Ильский	0101000020E610000020D5B0DF134943402C8194D8B56B4640
46127	2	20	85	102	21206	\N	44.841808999999998	п. Ильский, Длинная, 30, телефон: 68-5-92		0101000020E610000072DF6A9DB84843403E3DB665C06B4640
46133	2	20	85	102	21645	\N	44.841808999999998	п. Ильский, 50-Лет Октября, 123, телефон: 68-1-00		0101000020E610000072DF6A9DB84843403E3DB665C06B4640
46134	2	20	85	50736	23489	\N	44.7663456495616	ст. Дербентская, Калинина, 23, телефон: 69-2-85		0101000020E61000001DE38A8BA3404340D0B52FA017624640
46123	2	20	85	50682	23378	\N	44.773689683234103	ст. Григорьевская, Ленина, 6, телефон: 44-6-84	Россия, Краснодарский край, Северский район, поселок Григорьевская	0101000020E6100000CBD765F84F6B4340029F1F4608634640
45598	2	20	85	46541	21667	\N	44.871577000000002	поселок Веселый, Веселая, 3, телефон: 7-82-42		0101000020E6100000BB7D5699293F43401079CBD58F6F4640
46111	2	20	85	31543	21410	\N	44.903067	п. Афипский, Школьная, 43, телефон: 33-3-13		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46115	2	20	85	31543	21194	\N	44.903067	п. Афипский, Пушкина, 57, телефон: 33-6-12		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46109	2	20	85	31543	21404	\N	44.903067	п. Афипский, Привокзальная, 9, телефон: 34-5-57		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46113	2	20	85	31543	20847	\N	44.903067	п. Афипский, Победы, 9, телефон: 33-1-95		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46112	2	20	85	31543	20847	\N	44.903067	п. Афипский, Победы, 2, телефон: 33-4-56	Россия, Краснодарский край, Северский район, поселок Афипский	0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46108	2	20	85	31543	20953	\N	44.903067	п. Афипский, Ленина, 11, телефон: 33-5-31		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46116	2	20	85	31543	20790	\N	44.903067	п. Афипский, Комсомольская, 119, телефон: 33-3-23		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46110	2	20	85	31543	21416	\N	44.903067	п.Афипский, Калинина, 44, телефон: 35-3-96		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46117	2	20	85	31543	22010	\N	44.903067	п. Афипский, 50-лет Октября, 26, телефон: 35-3-97		0101000020E6100000AA108FC4CB6B4340658C0FB397734640
46144	2	20	85	50873	23950	\N	45.011338000000002	х. Ананьевский, Центральная, 9, телефон: 36-5-73	Россия, Краснодарский край, Северский район, поселок Ананьевский	0101000020E6100000524832AB77464340DD99098673814640
46120	2	20	85	50840	23838	\N	44.791386000000003	ст. Азовская, Советская, 8, телефон: 51-2-96	Россия, Краснодарский край, Северский район, поселок Азовская	0101000020E6100000DE59BBED424F43409241EE224C654640
46095	2	20	1082	30914	23564	\N	46.0638990990035	хутор им.Тамаровского, ул.Школьная, 6, телефон: 58348	Россия, Краснодарский край, Приморско-Ахтарский район, поселок им. Тамаровского	0101000020E6100000062CB98AC5334340A19FA9D72D084740
46105	2	20	1082	31371	21403	\N	45.755130999999999	станица Степная, ул. Ленина, 25, телефон: 55209		0101000020E6100000E49EAEEE583843400F99F221A8E04640
46160	2	20	1082	50692	23401	\N	45.943667070831502	х. Свободный, Центральная, 26, телефон: 2-43-34	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Свободный	0101000020E6100000B9E34D7E8B2E43403FA88B14CAF84640
45047	2	20	1082	50692	23401	\N	45.942955168198303	Свободный хутор, Центральная, 10, телефон: 25-1-68	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Свободный	0101000020E6100000DFC325C79D2E4340C24CDBBFB2F84640
46073	2	20	1082	50494	22346	\N	45.944754431100598	хутор Садки, ул. Чапаева, 98, телефон: 51744	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Садки	0101000020E6100000329067976F0D4340F261F6B2EDF84640
46075	2	20	1082	9539	21569	\N	46.046230000000001	город Приморско-Ахтарск, ул.Ленина, 70, телефон: 31747		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46077	2	20	1082	9539	21570	\N	46.046230000000001	город  Приморско-Ахтарск, ул. Зеленая, 1А, телефон: 31007		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46078	2	20	1082	9539	21166	\N	46.046230000000001	город  Приморско-Ахтарск, ул. Фестивальная, 2/2, телефон: 20309		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46088	2	20	1082	9539	21365	\N	46.046230000000001	город Приморско-Ахтарск, ул.Строителей, 85, телефон: 30682		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46080	2	20	1082	9539	22354	\N	46.046230000000001	город Приморско-Ахтарск, ул. Свободная, 113, телефон: 30604		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46081	2	20	1082	9539	21863	\N	46.050960289671004	город Приморско-Ахтарск, ул. Ростовская, 35/1, телефон: 23647		0101000020E610000015E5D2F885174340BCB376DB85064740
46076	2	20	1082	9539	20499	\N	46.046230000000001	город Приморско-Ахтарск, ул. Московская, 64, телефон: 33518		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46083	2	20	1082	9539	21869	\N	46.059259037304898	город Приморско-Ахтарск, ул. Мира, 263, телефон: 34091		0101000020E6100000B24CBF44BC154340307F85CC95074740
46085	2	20	1082	9539	20439	\N	46.043818339313397	г.Приморско-Ахтарск, ул. Ленина,56 , Мира 38	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск	0101000020E61000008FFE976BD1144340F27C06D49B054740
46074	2	20	1082	9539	20439	\N	46.046230000000001	город Приморско-Ахтарск, ул.Ленина, 15, телефон: 30774	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск	0101000020E6100000255AF2785A1643400B0C59DDEA054740
46084	2	20	1082	9539	21583	\N	46.046230000000001	город Приморско-Ахтарск, ул. Космонавтов, 111, телефон: 21241		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46087	2	20	1082	9539	21015	\N	46.046230000000001	город Приморско-Ахтарск, ул.Фестивальная - ул.Казачья, 59 - 2, телефон: 31105		0101000020E6100000255AF2785A1643400B0C59DDEA054740
46082	2	20	1082	9539	21391	\N	46.049654510115403	город Приморско-Ахтарск, ул. 50 лет Октября, 65, телефон: 34409	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск	0101000020E610000038D73043E31543409C8A54185B064740
46770	2	20	1082	32571	20613	\N	45.765191000000002	с.Пригородное, Майкопская, 77, телефон: 32600		0101000020E6100000FF959526A54E4340C61858C7F1E14640
46102	2	20	1082	31222	21213	\N	45.845683999999999	станица Приазовская, ул. Ленина, 24, телефон: 56082		0101000020E61000006C5ED5592D4E43400F60915F3FEC4640
46098	2	20	1082	50310	23513	\N	45.948009327863303	станица Ольгинская, ул. Ленина, 25, телефон: 53223	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Ольгинская	0101000020E6100000F0181EFB5946434026A8E15B58F94640
46100	2	20	1082	50310	21005	\N	45.941901896746501	станица Ольгинская, ул. Ленина, 100, телефон: 53160	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Ольгинская	0101000020E610000037DF88EE59474340BC04A73E90F84640
46099	2	20	1082	50310	23297	\N	45.943638392141501	станица Ольгинская, ул. Краснодарская, 11, телефон: 53211		0101000020E61000003E4162BB7B464340A5A14621C9F84640
46101	2	20	1082	31196	21208	\N	45.957000999999998	Приморско-Ахтарский район, п.Октябрьский, ул.Ленина,10		0101000020E61000006F6589CE323D4340A19E3E027FFA4640
46089	2	20	1082	30607	21547	\N	45.950291	хутор Огородный, ул.Центральная, 6, телефон: 31105	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Огородный	0101000020E61000008FC4CBD3B91643407157AF22A3F94640
46097	2	20	1082	47345	20522	\N	45.873488999999999	хутор Новонекрасовский, ул. Степная, 21, телефон: 51138		0101000020E6100000224F92AE992243403735D07CCEEF4640
46106	2	20	1082	50739	23495	\N	45.8309176312194	хутор Новые Лимано-Кирпили, ул. Бригадная, 35, телефон: 31105	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Нов. Лиманокирпили	0101000020E61000009DA04D0E9F2C434030D461855BEA4640
46092	2	20	1082	50363	21398	\N	46.144637000000003	хутор Морозовский, ул.Пионера - ул.Тельмана, 15/1 - 23/1, телефон: 58627	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Морозовский	0101000020E610000021753BFBCA1D43405265187783124740
46107	2	20	1082	31480	75498	\N	45.782843	Приморско-Ахтарский район,  п.Максима Горького ул.Центральная, 6		0101000020E61000004F5DF92CCF47434086730D3334E44640
44938	2	20	1082	31480	20671	\N	45.782843	поселок им. М.Горького, Ленина, 53, телефон: 54-5-53	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Максима Горького	0101000020E61000004F5DF92CCF47434086730D3334E44640
46104	2	20	1082	9689	23284	\N	45.972849336652402	Приморско-Ахтарский район, х.Курчанский, ул.Красная, 37	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Курчанский	0101000020E6100000651C23D9232E43402079E75086FC4640
44944	2	20	1082	47288	20977	\N	45.964055999999999	поселок Возрождение, Школьная, 4 а, телефон: 56-6-32		0101000020E6100000E9F2E670AD5843409CC1DF2F66FB4640
38560	1	6	1456	17092	35271	\N	54.104391	г. Сухиничи, Чкалова, 55		0101000020E6100000B2BCAB1E30AB4140957F2DAF5C0D4B40
46094	2	20	1082	30780	21187	\N	46.032602055262501	станица Бриньковская, ул. Красная, 134, телефон: 54522	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Бриньковская	0101000020E6100000E8C072840C4A434060E4654D2C044740
46093	2	20	1082	30780	21187	\N	46.032823	станица Бриньковская, ул.Красная, 79, телефон: 54112		0101000020E6100000287CB60E0E4A43403FC7478B33044740
46091	2	20	1082	47209	20976	\N	46.102772999999999	станица Бородинская, ул.Ленина, 17, телефон: 51498		0101000020E610000027C11BD2A8204340B6F468AA270D4740
46090	2	20	1082	30632	20984	\N	46.007264999999997	поселок Ахтарский, ул. Горького, 13, телефон: 52174		0101000020E61000000DA661F8882C4340E5B33C0FEE004740
42531	2	20	1082	9614	23610	\N	45.9688049943774	х.Аджановка ул.Гагарина 1\\1	Россия, Краснодарский край, Приморско-Ахтарский район, поселок Аджановка	0101000020E61000000DFAD2DB9F254340C4995FCD01FC4640
46033	2	20	1079	9528	21984	\N	46.142100999999997	352061, хутор Упорный, Ленина, 28		0101000020E6100000A94A5B5CE3FD43404CDD955D30124740
46072	2	20	1079	29696	21377	\N	45.988318999999997	станица Старолеушковская, Красная, 10, телефон: 4-54-58		0101000020E6100000C0E8F2E670E14340F981AB3C81FE4640
46071	2	20	1079	29696	22511	\N	45.988318999999997	станица Старолеушковская, Жлобы, 14, телефон: 4-55-92		0101000020E6100000C0E8F2E670E14340F981AB3C81FE4640
46066	2	20	1079	32677	22123	\N	45.950465999999999	хутор Средний Челбасс, Молодежная, 7 А, телефон: 3-02-62	Россия, Краснодарский край, Павловский район, поселок Сред. Челбас	0101000020E6100000E4DBBB067DC54340DFFAB0DEA8F94640
46062	2	20	1079	50762	23551	\N	46.048330723511903	хутор Пушкина, Южная, 2, телефон: 3-65-86	Россия, Краснодарский край, Павловский район, поселок Пушкина	0101000020E610000042E90B21E7E943400531D0B52F064740
44736	2	20	1079	47698	21135	\N	46.003822	поселок Первомайский, Бендуса, 10, телефон: 5-81-82		0101000020E6100000C078060DFDF14340AE80423D7D004740
46058	2	20	1079	46255	20928	\N	46.138779	станица Павловская, переулок Вокзальный, железнодорожный вокзал, телефон: 5-40-82		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46052	2	20	1079	46255	20440	\N	46.138779	станица Павловская, Шевченко, 47 А, телефон: 3-13-41		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46051	2	20	1079	46255	20440	\N	46.138779	станица Павловская, Шевченко, 36, телефон: 5-32-34		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46050	2	20	1079	46255	21375	\N	46.138779	станица Павловская, Чкалова, 3, телефон: 5-12-50		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46054	2	20	1079	46255	20444	\N	46.138779	станица Павловская, Спартаковская, 3, телефон: 4-17-81		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46057	2	20	1079	46255	23776	\N	46.138779	станица Павловская, Советская, 66, телефон: 5-17-34	Россия, Краснодарский край, Павловский район, поселок Павловская	0101000020E6100000DBFD2AC077E54340902FA182C3114740
46055	2	20	1079	46255	22092	\N	46.138779	станица Павловская, Промышленная, 22, телефон: 5-13-65		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46044	2	20	1079	46255	21859	\N	46.139495008687199	станица Павловская, Преградная, 2 А, телефон: 5-19-51		0101000020E6100000520ABABDA4E543404E7ADFF8DA114740
46049	2	20	1079	46255	21106	\N	46.138779	станица Павловская, Ленина, 13, телефон: 5-32-45		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46047	2	20	1079	46255	21362	\N	46.138779	станица Павловская, Крупская, 237, телефон: 3-11-52		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46046	2	20	1079	46255	21817	\N	46.138779	станица Павловская, Комсомольская, 17, телефон: 5-17-22		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46056	2	20	1079	46255	20448	\N	46.138779	станица Павловская, Заводская, 30, телефон: 5-20-79		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46053	2	20	1079	46255	21326	\N	46.138779	станица Павловская, Гражданская, 21, телефон: 4-17-21		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46048	2	20	1079	46255	20431	\N	46.138779	станица Павловская, Горького, 302, телефон: 5-41-86		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46045	2	20	1079	50434	22245	\N	46.138779	станица Павловская, Горького, 354, телефон: 5-18-71		0101000020E6100000DBFD2AC077E54340902FA182C3114740
46041	2	20	1079	28339	21308	\N	46.064948999999999	хутор Новый Урал, Заречная, 1, телефон: 5-85-47		0101000020E61000002DEA93DC61D143403674B33F50084740
46060	2	20	1079	50637	23162	\N	46.101315478750799	хутор Новый, Колхозная, 78 А, телефон: 3-61-79	Россия, Краснодарский край, Павловский район, поселок Новый	0101000020E61000002310AFEB17F8434010CCD1E3F70C4740
46038	2	20	1079	28223	21305	\N	46.061796999999999	станица Новопластуновская, Кооперативная, 23 А, телефон: 5-85-32		0101000020E6100000C1CAA145B6CD4340D6FECEF6E8074740
46043	2	20	1079	28433	21312	\N	46.212890999999999	станица Новопетровская, Ленина, 29, телефон: 3-05-38		0101000020E6100000B48F15FC36F843406E4E2503401B4740
46034	2	20	1079	28034	21355	\N	45.999464000000003	станица Новолеушковская, Ленина, 8, телефон: 4-43-51		0101000020E6100000A60D87A581FD4340C2C3B46FEEFF4640
46036	2	20	1079	28034	21302	\N	45.999464000000003	станица Новолеушковская, Красная, 13, телефон: 4-48-30		0101000020E6100000A60D87A581FD4340C2C3B46FEEFF4640
46035	2	20	1079	28034	21358	\N	45.999464000000003	станица Новолеушковская, Жлобы, 70, телефон: 4-45-88		0101000020E6100000A60D87A581FD4340C2C3B46FEEFF4640
46042	2	20	1079	28392	20660	\N	46.163035000000001	станица Незамаевская, Ленина, 6 Б, телефон: 3-81-57		0101000020E6100000E4BD6A65C22344403B8DB454DE144740
46069	2	20	1079	46773	21578	\N	46.033310999999998	поселок Набережный, Красноармейская, 18, телефон: 3-75-32		0101000020E610000023F433F5BAD343406CCCEB8843044740
46039	2	20	1079	46127	20900	\N	46.098948999999998	хутор Междуреченский, Ленина, 15 А, телефон: 5-86-67		0101000020E610000051BCCADAA6D24340677C5F5CAA0C4740
46065	2	20	1079	29439	20483	\N	45.980786000000002	хутор Ленинодар, Мира, 63, телефон: 3-02-20		0101000020E6100000726A6798DAC84340F52F49658AFD4640
46061	2	20	1079	29262	21126	\N	46.074784000000001	село Краснопартизанское, Советская, 64, телефон: 3-65-64		0101000020E6100000A2CF471971E34340CD21A98592094740
46030	2	20	1079	45921	22190	\N	46.169044999999997	станица Веселая, Ленина, 41 Г, телефон: 4-31-39		0101000020E6100000EB8F300C580C4440B2463D44A3154740
46067	2	20	1079	29548	21554	\N	45.893037999999997	хутор Бейсужек, Степная, 5, телефон: 3-01-68		0101000020E6100000F7C8E6AA79C44340E90AB6114FF24640
46040	2	20	1079	28306	20657	\N	46.090499000000001	хутор Бальчанский, Школьная, 12 А, телефон: 5-85-74		0101000020E61000001631EC3026C543400DA9A278950B4740
46002	2	20	1027	50648	23918	\N	44.505094558520497	352256 х. Чайкин, ул.Советская,54	Россия, Краснодарский край, Отрадненский район, поселок Чайкин	0101000020E6100000156F641EF9CB4440C22FF5F3A6404640
45996	2	20	1027	50890	23997	\N	44.488453541064999	х. Хорин, ул. Южная, 12, телефон: 9-53-34	Россия, Краснодарский край, Отрадненский район, поселок Хорин	0101000020E61000004293C49272A54440D9CC21A9853E4640
46006	2	20	1027	50649	23240	\N	44.289457176508101	352270 х. Хлопонин, ул. Полевая 31	Россия, Краснодарский край, Отрадненский район, поселок Хлопонин	0101000020E610000024B891B245CA4440944C4EED0C254640
46819	2	20	1027	9998	21344	\N	44.4522129392086	аул Урупский, Шовгенова, 36, телефон: 65679	Россия, Краснодарский край, Отрадненский район, поселок Урупский	0101000020E61000004C4F58E201C94440BCE9961DE2394640
46004	2	20	1027	9998	20706	\N	44.453387999999997	352260  пос. Урупский, ул. Центральная, 5		0101000020E61000006214048F6FC944400D33349E083A4640
46007	2	20	1027	50333	21143	\N	44.210804454941801	ст. Удобная, ул. Международная, 82 Б, телефон: 9-82-98	Россия, Краснодарский край, Отрадненский район, поселок Удобная	0101000020E6100000B56E83DA6FC74440D9EE1EA0FB1A4640
46010	2	20	1027	50333	22942	\N	44.211298330207697	ст. Удобная, ул. Ленина, 54, телефон: 9-82-09	Россия, Краснодарский край, Отрадненский район, поселок Удобная	0101000020E6100000B83EAC376AC74440E8DA17D00B1B4640
46009	2	20	1027	50333	23507	\N	44.212542573824301	352272 ст. Удобная, ул. Кооперативная,25 А	Россия, Краснодарский край, Отрадненский район, поселок Удобная	0101000020E6100000C7A17E17B6C8444032FFE89B341B4640
46008	2	20	1027	50563	22783	\N	44.212108585283097	352272 ст. Удобная, ул. Восточная, 42А	Россия, Краснодарский край, Отрадненский район, поселок Удобная	0101000020E610000074B33F506EC94440F8174163261B4640
45990	2	20	1027	26055	20837	\N	44.384614999999997	ст. Спокойная-Синюха, ул. Казачья, 16, телефон: 9-95-65		0101000020E610000008C89750C19F4440884677103B314640
46018	2	20	1027	50643	23427	\N	44.245623290469901	352281 ст. Спокойная, ул.Тихая,9	Россия, Краснодарский край, Отрадненский район, поселок Спокойная	0101000020E6100000EA944737C2B244409D121093701F4640
46020	2	20	1027	50643	23887	\N	44.250834482771403	ст. Спокойная, ул. Ленина, 39, телефон: 9-31-28	Россия, Краснодарский край, Отрадненский район, поселок Спокойная	0101000020E6100000BE2D58AA0BB44440C85C19541B204640
46019	2	20	1027	50643	23213	\N	44.253863000000003	352281 ст. Спокойная, ул. Ленина, 35	Россия, Краснодарский край, Отрадненский район, поселок Спокойная	0101000020E6100000D3BD4EEACBB244400D5531957E204640
46028	2	20	1027	50630	23083	\N	44.353140387951001	х. Солдатская Балка, ул. Шоссейная, 81, телефон: 9-95-98	Россия, Краснодарский край, Отрадненский район, поселок Солдатская Балка	0101000020E6100000978DCEF929A44440697407B1332D4640
44694	2	20	1027	46866	21402	\N	44.473016000000001	п. Светлый, Садовая, 13, телефон: 67326		0101000020E6100000D4635B069CC344400C3ECDC98B3C4640
45995	2	20	1027	26239	21252	\N	44.458773000000001	с. Рудь, ул. Ленина, 5, телефон: 9-53-41		0101000020E6100000A88AA9F4139C4440D7A4DB12B93A4640
46014	2	20	1027	50700	23418	\N	44.219324906637297	352271 х. Романчуков, ул. Центральная 46	Россия, Краснодарский край, Отрадненский район, поселок Романчуков	0101000020E610000028B682A625C64440FC1873D7121C4640
45994	2	20	1027	9857	21685	\N	44.515202000000002	ст.Попутная, ул.Степная, 11, телефон: 9-22-21		0101000020E61000002B8716D9CEB54440BA6A9E23F2414640
45993	2	20	1027	9857	20417	\N	44.515202000000002	352251 ст. Попутная, ул.Мащенко, 11Г		0101000020E61000002B8716D9CEB54440BA6A9E23F2414640
45991	2	20	1027	9857	20836	\N	44.515202000000002	352251 ст. Попутная, ул. Ленина, 75		0101000020E61000002B8716D9CEB54440BA6A9E23F2414640
45992	2	20	1027	9857	20840	\N	44.515202000000002	ст. Попутная, ул. Кирова, 68, телефон: 9-22-49		0101000020E61000002B8716D9CEB54440BA6A9E23F2414640
45989	2	20	1027	9832	21678	\N	44.376040000000003	352288 ст. Подгорная-Синюха, ул. Ленина, 15		0101000020E6100000B29FC552249B444072FE261422304640
46026	2	20	1027	50596	23176	\N	44.214181000000004	ст. Подгорная, ул. Шаумяна, 41, телефон: 9-42-53	Россия, Краснодарский край, Отрадненский район, поселок Подгорная	0101000020E61000001A6B7F677BA44440593673486A1B4640
46025	2	20	1027	50596	22951	\N	44.219123092264098	ст. Подгорная, ул. Комсомольская, 82, телефон: 9-42-34	Россия, Краснодарский край, Отрадненский район, поселок Подгорная	0101000020E610000005C24EB16AA444409566F3380C1C4640
45999	2	20	1027	8939	21272	\N	44.569983999999998	352263 с. Пискуновское, ул. Красная, 55		0101000020E6100000DE8FDB2F9FC24440239F573CF5484640
46001	2	20	1027	50281	20725	\N	44.476759000000001	с. Петровское, ул. Ленина, 107, телефон: 9-77-17	Россия, Краснодарский край, Отрадненский район, поселок Петровское	0101000020E61000000C59DDEA39D544406E895C70063D4640
46021	2	20	1027	50654	23254	\N	44.293296426648197	х. Отрадо-Тегинский, ул. Буденного, 106, телефон: 9-35-26	Россия, Краснодарский край, Отрадненский район, поселок Отрадо-Тенгинский	0101000020E6100000799274CDE4B9444018062CB98A254640
45987	2	20	1027	50577	22847	\N	44.375800918890597	х. Отрадо-Солдатский, ул. Первомайская, Здание сельского клуба, телефон: 3-11-69	Россия, Краснодарский край, Отрадненский район, поселок Отрадо-Солдатский	0101000020E6100000B98D06F016AA4440ED66463F1A304640
45985	2	20	1027	50345	21218	\N	44.375485408475498	ст. Отрадная, ул. Урупская, 68, телефон: 3-34-21	Россия, Краснодарский край, Отрадненский район, поселок Отрадная	0101000020E610000062D9CC21A9C34440BC9179E40F304640
45983	2	20	1027	50345	21218	\N	44.377350956911897	ст. Отрадная, ул. Урупская, 64, телефон: 3-84-31	Россия, Краснодарский край, Отрадненский район, поселок Отрадная	0101000020E6100000477364E597C34440730E9E094D304640
45984	2	20	1027	50345	23387	\N	44.391179195147103	ст. Отрадная, ул. Овражная, 83, телефон: 3-89-45	Россия, Краснодарский край, Отрадненский район, поселок Отрадная	0101000020E610000014CE6E2D93C14440E5F0492712324640
45979	2	20	1027	50345	21220	\N	44.4035554365759	ст. Отрадная, ул. Кизилова, 80 А, телефон: 3-12-71	Россия, Краснодарский край, Отрадненский район, поселок Отрадная	0101000020E6100000DE7536E49FBF44409291B3B0A7334640
14069	1	17	\N	3130	22690	\N	58.045848999999997	г. Рыбинск, Расплетина, 47		0101000020E6100000B3614D65516C4340F3C64961DE054D40
46024	2	20	1027	50599	22954	\N	44.196464097200703	352265 ст. Надежная, ул.Трактовая,45Б	Россия, Краснодарский край, Отрадненский район, поселок Надежная	0101000020E61000005FF0694E5EB24440B16B7BBB25194640
46022	2	20	1027	50599	23349	\N	44.199304519164599	ст. Надежная, ул. Лесная, 9 А, телефон: 9-40-88	Россия, Краснодарский край, Отрадненский район, поселок Надежная	0101000020E6100000AA4885B185B24440F37684D382194640
45988	2	20	1027	49443	23368	\N	44.318385999999997	пос. Маяк, ул. Красная, 14, телефон: 9-75-60		0101000020E6100000B3075A8121A944408BC058DFC0284640
46005	2	20	1027	10080	21349	\N	44.280284000000002	352270 ст. Малотенгинская, пер. Советский, 5		0101000020E6100000DF35E84B6FC34440C9CB9A58E0234640
46017	2	20	1027	47670	23565	\N	44.083761195544902	х. Ильич, ул. Ленина, 25, телефон: 9-55-33		0101000020E6100000A3E716BA12AF444013D731AEB80A4640
45997	2	20	1027	49576	20615	\N	44.492476000000003	352251 с .Изобильное, ул. Ленина,33		0101000020E6100000F1BC546CCC9B44404F081D74093F4640
46013	2	20	1027	50541	22705	\N	44.2535694888685	х. Зеленчук - Мостовой, ул. Набережная, 71, телефон: 9-86-35		0101000020E61000005FB4C70BE9DC4440C423F1F274204640
45998	2	20	1027	26410	21260	\N	44.595393999999999	с. Гусаровское, ул. Красная, 282, телефон: 9-65-23		0101000020E6100000FB592C45F2B34440081EDFDE354C4640
46000	2	20	1027	32572	21087	\N	44.499318564071302	352261 с. Благодарное, ул. Октябрьская, 102-А	Россия, Краснодарский край, Отрадненский район, поселок Благодарное	0101000020E610000044DE72F563C54440BEA25BAFE93F4640
46003	2	20	1027	32572	21797	\N	44.496662000000001	с. Благодарное, ул. Коммунаров, 2 А, телефон: 9-16-48		0101000020E6100000A5A487A1D5C544403E95D39E923F4640
46027	2	20	1027	27719	20414	\N	44.251945999999997	ст. Бесстрашная, ул. Красная, 35, телефон: 9-47-52	Россия, Краснодарский край, Отрадненский район, поселок Бесстрашная	0101000020E6100000F22895F084924440D32D3BC43F204640
45891	2	20	1132	50618	23023	\N	46.045374178710603	"х.Хлебороб  ул.Пролетарская 22"	Россия, Краснодарский край, Новопокровский район, поселок Хлебороб	0101000020E61000003866D993C05044405B0BB3D0CE054740
44889	2	20	1132	46117	23376	\N	45.820554000000001	пос. Степной, Советов, 8, телефон: 62763		0101000020E6100000917D9065C16444400E4DD9E907E94640
45621	2	20	1132	46117	21467	\N	45.820554000000001	поселок Степной, Мира, 34, телефон: 7-91-87		0101000020E6100000917D9065C16444400E4DD9E907E94640
46031	2	20	1132	13978	21094	\N	46.024971453754297	поселок Северный, Юбилейная, 25, телефон: 4-05-10	Россия, Краснодарский край, Новопокровский район, поселок Северный	0101000020E6100000ABE80FCD3C494440992CEE3F32034740
45895	2	20	1132	50812	23719	\N	46.224694999999997	"ст.Плоская  ул.Красная 26"	Россия, Краснодарский край, Новопокровский район, поселок Плоская	0101000020E6100000DECCE847C34F4440904946CEC21C4740
46096	2	20	1132	14264	23989	\N	45.838137000000003	хутор Новопокровский, ул. Центральная, 18, телефон: 51131	Россия, Краснодарский край, Новопокровский район, поселок Новопокровский	0101000020E6100000F0FACC599F624440A648BE1248EB4640
45900	2	20	1132	14264	21434	\N	45.838137000000003	"Пос.Новопокровский  ул.Ленина 16"		0101000020E6100000F0FACC599F624440A648BE1248EB4640
45882	2	20	1132	20617	21564	\N	45.952075999999998	Краснодарский край, Новопокровский район, ст. Новопокровская, ул. Первенцева, 1, телефон: 7-11-54		0101000020E6100000D6AC33BE2F5844403BA759A0DDF94640
45875	2	20	1132	20617	21517	\N	45.952075999999998	Краснодарский край, Новопкоровский район, ст. Новопокровская, ул. Черняховского, 1, телефон: 75-3-98		0101000020E6100000D6AC33BE2F5844403BA759A0DDF94640
45879	2	20	1132	20617	21836	\N	45.952075999999998	Краснодарский край, Новопокровский район, ст. Новопокровская, ул. Почтовая, 32, телефон: 7-16-80		0101000020E6100000D6AC33BE2F5844403BA759A0DDF94640
45878	2	20	1132	20617	20428	\N	45.952075999999998	Краснодарский край, Новопокровский район, ст. Новопокровская, ул. Первомайская, 203, телефон: 7-18-92		0101000020E6100000D6AC33BE2F5844403BA759A0DDF94640
45880	2	20	1132	20617	21101	\N	45.952075999999998	Краснодарский край, Новопокровский район, ст. Новопокровская, ул. Ленина, 80, телефон: 7-15-65		0101000020E6100000D6AC33BE2F5844403BA759A0DDF94640
45881	2	20	1132	20617	21105	\N	45.952075999999998	Краснодарский край, Новопокровский район, ст. Новопокровская, ул. Калинина, 103, телефон: 7-15-59		0101000020E6100000D6AC33BE2F5844403BA759A0DDF94640
45876	2	20	1132	20617	21551	\N	45.952075999999998	Краснодарский край, Новопокровский район, ст. Новопокровская, ул. Григорьева, 29, телефон: 7-10-64		0101000020E6100000D6AC33BE2F5844403BA759A0DDF94640
45894	2	20	1132	10454	23229	\N	46.173788000000002	"сНовоивановская  ул.Красная 87"	Россия, Краснодарский край, Новопокровский район, поселок Новоивановская	0101000020E61000001650A8A78F3E4440F83768AF3E164740
45890	2	20	1132	14085	21023	\N	46.121003999999999	"Пос.Незамаевский  ул.Красная 18"		0101000020E61000007651F4C0C7304440B4571F0F7D0F4740
44581	2	20	1132	49072	22213	\N	45.819034000000002	поселок Мирный, улица Шоссейная, 2/1, телефон: 60-1-43		0101000020E6100000BFF4F6E7A25F4440F2272A1BD6E84640
45886	2	20	1132	10927	20813	\N	45.987122999999997	"Пос.Малокубанский ул.Светлая 13 "		0101000020E6100000E107E753C74844409010E50B5AFE4640
45885	2	20	1132	10914	20853	\N	45.929257	"Пос.Кубанский   ул.Школьная 1"		0101000020E6100000E6948098844944401F4AB4E4F1F64640
45884	2	20	1132	10914	20800	\N	45.929257	"Пос.Кубанский   ул.Советская 5а"		0101000020E6100000E6948098844944401F4AB4E4F1F64640
44586	2	20	1132	10914	21417	\N	45.929257	хутор Кубанский, улица Молодежная, 9, телефон: 67-4-30		0101000020E6100000E6948098844944401F4AB4E4F1F64640
41942	2	20	1132	10994	23863	\N	46.006317744575597	"сКалниболотская  ул.Фрунзе 28"	Россия, Краснодарский край, Новопокровский район, поселок Калниболотская	0101000020E61000004626E0D74838444025B03907CF004740
45887	2	20	1132	10994	21447	\N	46.005049	"ст. Калниболотская  ул.Красная 45"		0101000020E6100000A6D1E4620C38444052F01472A5004740
42071	2	20	1132	10994	23616	\N	46.007317918116897	"сКалниболотская  ул.Октябрьская 27"	Россия, Краснодарский край, Новопокровский район, поселок Калниболотская	0101000020E6100000B48EAA26883844400856D5CBEF004740
45897	2	20	1132	50619	23932	\N	45.721019318887897	"ст.Ильинская  ул.Ленина 46"	Россия, Краснодарский край, Новопокровский район, поселок Ильинская	0101000020E6100000E3C3EC65DB5B4440B665C0594ADC4640
45896	2	20	1132	50619	23027	\N	45.726520404639103	"ст.Ильинская , ул.Крылова 91"	Россия, Краснодарский край, Новопокровский район, поселок Ильинская	0101000020E6100000062AE3DF675C4440E9F17B9BFEDC4640
45898	2	20	1132	10607	20960	\N	45.815365	, пос. Животновод, ул. Центральная, 12		0101000020E610000030BB270F0B594440CAA65CE15DE84640
45893	2	20	1132	14166	22513	\N	46.088424000000003	"Село Горькая Балка  ул. Советская 4"	Россия, Краснодарский край, Новопокровский район, поселок Горькая Балка	0101000020E6100000F8889812495844403C17467A510B4740
45888	2	20	1132	11044	23470	\N	45.980833932830699	"х.Грузская Балка , пер.Клубный 2"	Россия, Краснодарский край, Новопокровский район, поселок Балка Грузская	0101000020E6100000AEB8382A372344400667F0F78BFD4640
45599	2	20	937	50879	23962	\N	44.673447426064499	хутор Южный, Пролетарская, 38, телефон: 7-81-69	Россия, Краснодарский край, Новокубанский район, поселок Южный	0101000020E610000037C1374D9F9344406F4BE48233564640
45825	2	20	937	50756	23537	\N	45.125723999999998	х.Энгельса, ул.Урожайная, 16, телефон: 2-06-14	Россия, Краснодарский край, Новокубанский район, поселок Энгельса	0101000020E610000020D099B4A96C444041295AB917904640
45851	2	20	937	50655	23257	\N	45.031223071026197	х.Фортштадт, ул.Свободы, 19, телефон: 2-81-98	Россия, Краснодарский край, Новокубанский район, поселок Фортштадт	0101000020E6100000DE91B1DAFC91444006F1811DFF834640
45810	2	20	937	50845	23848	\N	45.098879169965699	х.Федоровский, ул.Широкая, 14/1, телефон: 2-61-80	Россия, Краснодарский край, Новокубанский район, поселок Федоровский	0101000020E6100000B39602D2FE7944406EA12B11A88C4640
44552	2	20	937	50435	21841	\N	44.886200297416003	поселок Степной, улица Школьная, 11, телефон: 72-1-37		0101000020E6100000676490BB088B44408CDB68006F714640
45862	2	20	937	50695	23407	\N	44.902676015937701	х.Стеблицкий, ул.Ленина, 15, телефон: 5-37-46	Россия, Краснодарский край, Новокубанский район, поселок Стебницкий	0101000020E6100000DBA2CC06999244402A711DE38A734640
45864	2	20	937	50593	23076	\N	44.765480317299499	ст.Советская, ул.Октябрьская, 356, телефон: 5-65-51	Россия, Краснодарский край, Новокубанский район, поселок Советская	0101000020E6100000F646AD307D974440FCDEA63FFB614640
45869	2	20	937	50593	23534	\N	44.7773372880444	ст.Советская, ул.Энгельса, 34, телефон: 5-36-39	Россия, Краснодарский край, Новокубанский район, поселок Советская	0101000020E6100000BDFF8F1326964440427C60C77F634640
45866	2	20	937	50593	22934	\N	44.768150872062897	ст.Советская, ул.Ленина, 293, телефон: 5-64-56	Россия, Краснодарский край, Новокубанский район, поселок Советская	0101000020E610000010768A5583964440E2B19FC552624640
45824	2	20	937	50836	23825	\N	45.141758325702298	х.Роте-Фане, ул.Садовая, 40, телефон: 2-03-82	Россия, Краснодарский край, Новокубанский район, поселок Роте-Фане	0101000020E610000048FE60E0B96F444023F94A2025924640
45870	2	20	937	50742	23512	\N	44.718637611352001	х.Родниковский, ул.Мира, 18/2, телефон: 5-39-82	Россия, Краснодарский край, Новокубанский район, поселок Родниковский	0101000020E6100000C85F5AD4279F4440D8D47954FC5B4640
44611	2	20	937	23141	21422	\N	44.809376999999998	поселок Раздольный, Западная, 14, телефон: 43659		0101000020E6100000D72FD80DDB8444403A9160AA99674640
45863	2	20	937	32712	20442	\N	44.875442	с.Радищево, ул.Школьная, 6, телефон: 5-37-48		0101000020E61000003FAC376A85914440BDC5C37B0E704640
45853	2	20	937	50613	22988	\N	45.061044913256602	ст.Прочноокопская, ул.Ленина, 92, телефон: 2-81-97	Россия, Краснодарский край, Новокубанский район, поселок Прочноокопская	0101000020E6100000096CCEC1338F4440CB4A9352D0874640
45852	2	20	937	50613	22988	\N	45.062081999999997	ст.Прочноокопская, ул.Ленина, 153, телефон: 2-81-67	Россия, Краснодарский край, Новокубанский район, поселок Прочноокопская	0101000020E61000005E9CF86A478F4440CBD58F4DF2874640
46581	2	20	937	50320	21043	\N	45.196408033792999	Прогресс поселок, Ленина, 31, здание Дома культуры, телефон: 36-6-98	Россия, Краснодарский край, Новокубанский район, поселок Прогресс	0101000020E6100000C097C283667D44401D56B8E523994640
45819	2	20	937	50320	22314	\N	45.196593	п.Прогресс, ул.Красноармейская, 2, телефон: 2-16-94	Россия, Краснодарский край, Новокубанский район, поселок Прогресс	0101000020E6100000D0ECBAB7227D4440AFCF9CF529994640
45856	2	20	937	47127	20663	\N	45.06447	п.Передовой, ул.Школьная, 13, телефон: 2-29-25		0101000020E6100000F4DC425722A244405CC98E8D40884640
45860	2	20	937	32676	20433	\N	44.892104000000003	с.Новосельское, ул.Ленина, 100, телефон: 2-56-40	Россия, Краснодарский край, Новокубанский район, поселок Новосельское	0101000020E6100000963FDF162C834440BE50C07630724640
45835	2	20	937	50393	21900	\N	45.106254999999997	г.Новокубанск, ул.Ленина, 60, телефон: 3-28-87		0101000020E610000022FDF675E0824440AB048BC3998D4640
45834	2	20	937	13546	21292	\N	45.113987531219301	г.Новокубанск, ул.Щорса, 78, телефон: 4-55-69	Россия, Краснодарский край, Новокубанский район, город Новокубанск	0101000020E6100000874D64E6028144407711A628978E4640
45846	2	20	937	13546	21510	\N	45.106254999999997	г.Новокубанск, ул.Тимирязева, 25, телефон: 3-10-91, 3-17-47		0101000020E610000022FDF675E0824440AB048BC3998D4640
45837	2	20	937	13546	20893	\N	45.106254999999997	г.Новокубанск, ул.Суворова, 1, телефон: 3-70-50		0101000020E610000022FDF675E0824440AB048BC3998D4640
45841	2	20	937	13546	21083	\N	45.1090646320473	г.Новокубанск, ул.Пушкина, 28, телефон: 3-40-83	Россия, Краснодарский край, Новокубанский район, город Новокубанск	0101000020E61000004C35B39602864440B21188D7F58D4640
45845	2	20	937	13546	20652	\N	45.106254999999997	г.Новокубанск, ул.Первомайская, 182, телефон: 3-04-65		0101000020E610000022FDF675E0824440AB048BC3998D4640
45839	2	20	937	13546	20652	\N	45.092272853061097	г.Новокубанск, ул.Первомайская, 23, телефон: 3-12-83	Россия, Краснодарский край, Новокубанский район, город Новокубанск	0101000020E610000079EBFCDB65874440E3A6069ACF8B4640
45848	2	20	937	13546	20655	\N	45.106254999999997	г.Новокубанск, ул.Обороны, 3, телефон: 3-17-06		0101000020E610000022FDF675E0824440AB048BC3998D4640
45847	2	20	937	13546	21088	\N	45.106254999999997	г.Новокубанск, ул.Новаторов, 5, телефон: 3-40-39		0101000020E610000022FDF675E0824440AB048BC3998D4640
45844	2	20	937	13546	21300	\N	45.104323658458497	г.Новокубанск, ул.Лермонтова, 41, телефон: 3-14-09	Россия, Краснодарский край, Новокубанский район, город Новокубанск	0101000020E610000021C84109338744400D18247D5A8D4640
45831	2	20	937	13546	20525	\N	45.106254999999997	г.Новокубанск, ул.Красная, 44, телефон: 3-63-31, 4-14-80		0101000020E610000022FDF675E0824440AB048BC3998D4640
44417	2	20	937	13546	20525	\N	45.123359000000001	ст. Кубанская, Красная, 28, телефон: 75119		0101000020E610000041F2CEA10C7D444069554B3ACA8F4640
45827	2	20	937	50288	20781	\N	45.058438760129903	х.Марьинский, ул.Мира, 14, телефон: 2-62-94	Россия, Краснодарский край, Новокубанский район, поселок Марьинский	0101000020E610000009DE904605724440CDE7DCED7A874640
45849	2	20	937	50728	23472	\N	45.153504911069	х.Ляпино, ул.Школьная, 5, телефон: 2-41-74	Россия, Краснодарский край, Новокубанский район, поселок Ляпино	0101000020E6100000FE98D6A6B18F4440E162450DA6934640
45859	2	20	937	19718	20913	\N	45.020952999999999	ст.Косякинская, ул.Ленина, 18/2, телефон: 2-29-41		0101000020E61000000873BB97FBB2444065E08096AE824640
44566	2	20	937	46881	23360	\N	45.212476000000002	поселок Комсомольский, улица Школьная, 17, телефон: 64-6-57		0101000020E61000006D718DCF646F4440AB97DF69329B4640
45615	2	20	937	46881	21351	\N	45.212476000000002	поселок Комсомольский, Комсомольская, 1, телефон: 6-61-35		0101000020E61000006D718DCF646F4440AB97DF69329B4640
45820	2	20	937	17692	21062	\N	45.164738	с.Ковалевское, ул.Мичурина, 46, телефон: 2-75-67		0101000020E61000001B84B9DDCB7F44404834812216954640
45823	2	20	937	50804	23660	\N	45.160573720886198	х.Кирова, ул.Мира, 26, телефон: 2-04-10	Россия, Краснодарский край, Новокубанский район, поселок Кирова	0101000020E6100000624D6551D8734440404B57B08D944640
45850	2	20	937	46999	21307	\N	45.206367	с.Камышеваха, ул.Коммунаров, 5, телефон: 2-46-36		0101000020E6100000D3D9C9E028A94440A0FCDD3B6A9A4640
45830	2	20	937	50690	23399	\N	44.997863697252299	х.Измайлов, ул.Механизаторов, 17, телефон: 3-12-32	Россия, Краснодарский край, Новокубанский район, поселок Измайлов	0101000020E6100000CD203EB0E375444089EDEE01BA7F4640
45829	2	20	937	18154	21289	\N	45.001083999999999	п.Зорька, ул.Пионерская, 18, телефон: 2-61-37		0101000020E6100000E7A6CD380D6744404146408523804640
45858	2	20	937	47835	23885	\N	45.100120509139799	х.Горькая Балка, ул.Красноармейская, 57, телефон: 2-29-57	Россия, Краснодарский край, Новокубанский район, поселок Горькая Балка	0101000020E6100000A79201A08AAB44404852D2C3D08C4640
45861	2	20	937	47215	21112	\N	44.9442428778178	п.Глубокий, ул.Школьная, 11А, телефон: 2-51-80	Россия, Краснодарский край, Новокубанский район, поселок Глубокий	0101000020E6100000C4B46FEEAF8244400C3D62F4DC784640
45901	2	20	937	46351	21160	\N	45.224266	"Пос.Восход, ул.Зелёная 1а"		0101000020E6100000EA5A7B9FAA7C444068CD8FBFB49C4640
45818	2	20	937	46351	21034	\N	45.224266	п.Восход, ул.Гагарина, 27, телефон: 2-93-23		0101000020E6100000EA5A7B9FAA7C444068CD8FBFB49C4640
45826	2	20	937	50851	23874	\N	45.118208310954998	х.Большевик, ул.Большевистская, 2, телефон: 2-61-87	Россия, Краснодарский край, Новокубанский район, поселок Большевик	0101000020E6100000EE073C308076444013109370218F4640
45872	2	20	937	20432	20684	\N	44.643295999999999	ст.Бесскорбная, ул.Московская, 70, телефон: 2-34-25		0101000020E6100000B72572C119A84440E5D2F88557524640
45873	2	20	937	20432	20686	\N	44.643295999999999	ст.Бесскорбная, ул.Ленина, 247, телефон: 2-34-12		0101000020E6100000B72572C119A84440E5D2F88557524640
45874	2	20	937	20432	23888	\N	44.643295999999999	ст.Бесскорбная, ул.Ленина, 362, телефон: 2-35-91	Россия, Краснодарский край, Новокубанский район, поселок Бесскорбная	0101000020E6100000B72572C119A84440E5D2F88557524640
45811	2	20	1395	50663	23292	\N	44.611179542305798	Краснодарский край, Мостовский район, ст-ца Ярославская, Школьная, 21, телефон: 6-33-53	Россия, Краснодарский край, Мостовский район, поселок Ярославская	0101000020E61000006C088ECBB83B444011FC6F253B4E4640
45812	2	20	1395	50663	24030	\N	44.607868673926802	Краснодарский край, Мостовский район, ст-ца Ярославская, Первомайская, 80 А, телефон: 6-32-72		0101000020E6100000E7E44526E03B444049A0C1A6CE4D4640
45795	2	20	1395	16433	9927	\N	44.232469000000002	Краснодарский край, Мостовский район, с. Шедок, Ленина, 50, телефон: 6-26-59		0101000020E6100000242A5437176D4440BB2A508BC11D4640
45798	2	20	1395	50724	23462	\N	44.361887701933398	Краснодарский край, Мостовский район, ст-ца Хамкетинская, Красная, 46, телефон: 6-63-19	Россия, Краснодарский край, Мостовский район, поселок Хамкетинская	0101000020E6100000A45181936D4044404D689258522E4640
45814	2	20	1395	17382	22579	\N	44.742462000000003	Краснодарский край, Мостовский район, с. Унароково, Ленина, 25, телефон: 6-43-58		0101000020E6100000E0D8B3E732414440EA42ACFE085F4640
45801	2	20	1395	16768	20588	\N	44.137718999999997	Краснодарский край, Мостовский район, п.Узловой, Клубная, 1, телефон: 6-66-13		0101000020E6100000ECDADE6E494C4440D784B4C6A0114640
45794	2	20	1395	16397	22528	\N	44.043028999999997	Краснодарский край, Мостовский район, с.Соленое, Калинина, 36 А, телефон: 6-21-52		0101000020E61000000FB8AE9811704440C9E369F981054640
45815	2	20	1395	50565	22791	\N	44.690037482833098	Краснодарский край, Мостовский район, х. Славянский, Дубовая, 34, телефон: 6-45-22	Россия, Краснодарский край, Мостовский район, поселок Славянский	0101000020E61000001FBB0B9414424440D503E62153584640
45808	2	20	1395	50770	23566	\N	44.635200278231402	Краснодарский край, Мостовский район, х.Северный, Комарова, 5, телефон: 6-55-39		0101000020E610000052D50451F7474440A835CD3B4E514640
45804	2	20	1395	50809	23694	\N	44.291612695021797	Краснодарский край, Мостовский район, х. Свободный Мир, Коммунаров, 52, телефон: 6-77-61	Россия, Краснодарский край, Мостовский район, поселок Свободный Мир	0101000020E6100000715985CD00714440520B259353254640
45791	2	20	1395	15931	22046	\N	44.133648999999998	Краснодарский край, Мостовский район, пгт.Псебай, Советская, 87, телефон: 6-11-17		0101000020E6100000F5D8960167674440511212691B114640
45788	2	20	1395	15931	22046	\N	44.133648999999998	Краснодарский край, Мостовский район, пгт.Псебай, Советская, 50, телефон: 6-14-86		0101000020E6100000F5D8960167674440511212691B114640
45787	2	20	1395	15931	20467	\N	44.133648999999998	Краснодарский край, Мостовский район, пгт.Псебай, Мостовая, 71, телефон: 6-15-80		0101000020E6100000F5D8960167674440511212691B114640
45790	2	20	1395	15931	21239	\N	44.133648999999998	Краснодарский край, Мостовский район, пгт.Псебай, Маяковского, 5, телефон: 6-11-23		0101000020E6100000F5D8960167674440511212691B114640
45785	2	20	1395	15931	22037	\N	44.133648999999998	Краснодарский край, Мостовский район, пгт.Псебай, Ленина, 14, телефон: 6-79-38		0101000020E6100000F5D8960167674440511212691B114640
45789	2	20	1395	15931	20943	\N	44.133648999999998	Краснодарский край, Мостовский район, пгт. Псебай, Красный, 7, телефон: 6-13-75		0101000020E6100000F5D8960167674440511212691B114640
45786	2	20	1395	15931	21448	\N	44.133648999999998	Краснодарский край, Мостовский район, пгт.Псебай, Главная, 27, телефон: 6-22-66		0101000020E6100000F5D8960167674440511212691B114640
44939	2	20	1395	45348	23363	\N	44.356337389054502	поселок Пролетарский, Школьная, 2, телефон: 21-6-38	Россия, Краснодарский край, Мостовский район, поселок Пролетарский	0101000020E6100000AC36FFAF3A5A444069AD68739C2D4640
45080	2	20	1395	45348	20471	\N	44.357726	Пролетарский поселок, Центральная, 4, телефон: 51-0-38		0101000020E6100000726BD26D895A4440E6762FF7C92D4640
45803	2	20	1395	50773	23570	\N	44.3382568266289	Краснодарский край, Мостовский район, ст-ца Переправная, Красная, 14, телефон: 6-76-32	Россия, Краснодарский край, Мостовский район, поселок Переправная	0101000020E6100000D0D556EC2F634440505260014C2B4640
45792	2	20	1395	16288	21048	\N	44.050733000000001	Краснодарский край, Мостовский район, п.Перевалка, Садовая, 1, телефон: 6-24-50		0101000020E61000009B5434D6FE604440FBE93F6B7E064640
45784	2	20	1395	50341	23559	\N	44.379233511166198	Краснодарский край, Мостовский район, х.Первомайский, Мостовая, 39, телефон: 6-74-10	Россия, Краснодарский край, Мостовский район, поселок Первомайский	0101000020E61000009BAC510FD15E444000C45DBD8A304640
46480	2	20	1395	50341	21214	\N	44.381370160642398	поселок Первомайский, ул.Комсомольская, Сельский Дом культуры, телефон: 5-33-73		0101000020E6100000DBA7E331035F444077D66EBBD0304640
45772	2	20	1395	15327	21227	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, мкр. Энергетиков, СОШ №30, телефон: 5-38-40		0101000020E61000001900AAB871654440CC2555DB4D344640
45776	2	20	1395	15327	20692	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Советская, 12, телефон: 5-10-93		0101000020E61000001900AAB871654440CC2555DB4D344640
45774	2	20	1395	15327	21348	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Садовая, 33, телефон: 5-10-41		0101000020E61000001900AAB871654440CC2555DB4D344640
45780	2	20	1395	15327	21449	\N	44.4091658964864	Краснодарский край, Мостовский район, пгт.Мостовской, Мичурина, 22, телефон: 5-16-71	Россия, Краснодарский край, Мостовский район, поселок Мостовской	0101000020E6100000CC441152B76544404C512E8D5F344640
45775	2	20	1395	15327	21535	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Ленина, 10, телефон: 5-15-42		0101000020E61000001900AAB871654440CC2555DB4D344640
45773	2	20	1395	15327	21037	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Красная, 46, телефон: 5-15-32		0101000020E61000001900AAB871654440CC2555DB4D344640
45781	2	20	1395	15327	20460	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Комарова, 35, телефон: 5-20-01		0101000020E61000001900AAB871654440CC2555DB4D344640
45778	2	20	1395	15327	21140	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Горького, 142, телефон: 5-12-90		0101000020E61000001900AAB871654440CC2555DB4D344640
45777	2	20	1395	15327	21140	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Горького, 137, телефон: 5-16-00		0101000020E61000001900AAB871654440CC2555DB4D344640
45779	2	20	1395	15327	21803	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Буденного, 177, телефон: 5-48-28		0101000020E61000001900AAB871654440CC2555DB4D344640
45783	2	20	1395	15327	21663	\N	44.408625999999998	Краснодарский край, Мостовский район, пгт.Мостовской, Боженко, 1 Г, телефон: 5-08-73		0101000020E61000001900AAB871654440CC2555DB4D344640
45813	2	20	1395	50892	24003	\N	44.551597273503702	"Краснодарский край, Мостовский район, ст-ца Махошевская, Советская, 8, телефон: 6-41-84, 6-41-39"	Россия, Краснодарский край, Мостовский район, поселок Махошевская	0101000020E61000005A2BDA1CE73844402EC901BB9A464640
45807	2	20	1395	50787	23599	\N	44.605539967266502	Краснодарский край, Мостовский район, х.Красный Кут, Советская, 41 А, телефон: 6-91-60	Россия, Краснодарский край, Мостовский район, поселок Красный Кут	0101000020E610000005E09F52254A4440BD35B055824D4640
45805	2	20	1395	50852	23879	\N	44.518959799805899	Краснодарский край, Мостовский район, ст-ца Костромская, Ленина, 72, телефон: 6-93-21	Россия, Краснодарский край, Мостовский район, поселок Костромская	0101000020E610000054E23AC6154B444051F701486D424640
45796	2	20	1395	50833	23812	\N	44.316389502516699	Краснодарский край, Мостовский район, ст-ца Губская, Мира, 129, телефон: 6-62-51	Россия, Краснодарский край, Мостовский район, поселок Губская	0101000020E6100000B5FD2B2B4D5044400664AF777F284640
45624	2	20	1395	47071	23373	\N	44.371142999999996	поселок Высокий, Кузнечная, 37, телефон: 7-61-45		0101000020E6100000EEE9EA8EC55E4440D591239D812F4640
45806	2	20	1395	17007	20842	\N	44.590606000000001	Краснодарский край, Мостовский район, п.Восточный, Ленина, 2, телефон: 6-91-19		0101000020E6100000BA4A77D7D94E4440236937FA984B4640
45802	2	20	1395	50683	23382	\N	44.228283846703597	Краснодарский край, Мостовский район, ст-ца Бесленеевская, Первомайская, 7, телефон: 6-67-37	Россия, Краснодарский край, Мостовский район, поселок Бесленеевская	0101000020E6100000DD442DCDAD5A44409C19FD68381D4640
45799	2	20	1395	16654	21055	\N	44.420538000000001	Краснодарский край, Мостовский район, с.Беноково, Красная, 35, телефон: 6-71-99		0101000020E6100000D09CF529C7564440D55C6E30D4354640
45797	2	20	1395	50752	23529	\N	44.292472126706699	Краснодарский край, Мостовский район, ст-ца Баракаевская, Школьная, 29, телефон: 6-69-38	Россия, Краснодарский край, Мостовский район, поселок Баракаевская	0101000020E61000001286014BAE424440737FF5B86F254640
45800	2	20	1395	50826	23775	\N	44.172564337053501	Краснодарский край, Мостовский район, ст-ца Баговская, Клубная, 1, телефон: 6-64-93		0101000020E6100000E82E89B3224E4440C53BC09316164640
45793	2	20	1395	50794	23628	\N	44.126832528002701	Краснодарский край, Мостовский район, ст-ца Андрюки, Советская, 79 А, телефон: 6-25-30	Россия, Краснодарский край, Мостовский район, поселок Андрюки	0101000020E6100000E751F17F476A4440DB8651103C104640
45758	2	20	1358	14667	21371	\N	46.235680000000002	пос. Уманский, Школьная, 2, телефон: 5-92-48		0101000020E6100000EEEBC03923A24340202922C32A1E4740
45769	2	20	1358	15176	21032	\N	46.106977999999998	пос. Образцовый, Школьная, 12, телефон: 5-53-17		0101000020E61000005BEB8B84B6C643401CB28174B10D4740
45766	2	20	1358	14966	21219	\N	46.104484999999997	ст. Новоплатнировская, Советов, 42, телефон: 7-83-88		0101000020E6100000D9EC48F59DB5434016F6B4C35F0D4740
45765	2	20	1358	14966	22001	\N	46.104484999999997	ст. Новоплатнировская, ул. Ленина, 83, телефон: 7-80-13		0101000020E6100000D9EC48F59DB5434016F6B4C35F0D4740
45740	2	20	1358	49148	23352	\N	46.320085550891697	ст. Ленинградская, Западная, 36, телефон: 5-83-59		0101000020E61000008C2B2E8ECAB1434028F4FA93F8284740
45742	2	20	1358	49148	23803	\N	46.322766038578102	ст. Ленинградская, Энергетиков, 1, телефон: 3-97-01	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E61000000B0DC4B299B143406021736550294740
45751	2	20	1358	49148	22977	\N	46.319490870597498	ст. Ленинградская, Школьная, 70 Б, телефон: 7-27-15	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E61000003E03EACDA8B14340E42EC214E5284740
45745	2	20	1358	49148	20530	\N	46.319133999999998	"Станица Ленинградская, ул.Шевченко 42 ""а"""		0101000020E6100000FCC7427408B2434055850662D9284740
45746	2	20	1358	49148	22987	\N	46.319847679554599	ст. Ленинградская, Чернышевского, 181, телефон: 3-65-45	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000151F9F909DB1434073D87DC7F0284740
45752	2	20	1358	49148	23756	\N	46.309805028879602	ст. Ленинградская, Терновая, 23, телефон: 3-61-33	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000A2D5C9198AB343409291B3B0A7274740
45749	2	20	1358	49148	23209	\N	46.319609807176697	ст. Ленинградская, Пролетарская, 33, телефон: 3-69-90	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E61000008C2B2E8ECAB14340BEBC00FBE8284740
45748	2	20	1358	49148	20695	\N	46.312294607332802	ст. Ленинградская, Красная, 98 А, телефон: 7-21-55	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000D5AE09698DB1434027DA5548F9274740
45747	2	20	1358	49148	20695	\N	46.329242806002902	ст. Ленинградская, Красная, Дворец культуры, телефон: 3-73-11	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000B33F506EDBB14340EDB776A2242A4740
45744	2	20	1358	49148	20695	\N	46.321155959029198	"ст. Ленинградская, Красная, 1 ""а"", телефон: 3-71-33"	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000D5592DB0C7B243400475CAA31B294740
45737	2	20	1358	49148	20695	\N	46.319133999999998	Станица Ленинградская, ул.Красная 247	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000FCC7427408B2434055850662D9284740
45739	2	20	1358	49148	20763	\N	46.321037025832503	ст. Ленинградская, Кооперации, 127, телефон: 7-07-81	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E61000005E4D9EB29AB2434029E78BBD17294740
45738	2	20	1358	49148	20763	\N	46.3278455323996	ст. Ленинградская, Кооперации, 159, телефон: 7-16-31	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000F1A1444B1EB14340ED0F94DBF6294740
45741	2	20	1358	49148	23788	\N	46.324007490346403	ст. Ленинградская, Заводская, 3, телефон: 5-85-79	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E610000050A912656FAF43406956B60F79294740
45743	2	20	1358	49148	23993	\N	46.319133999999998	ст. Ленинградская, 302 Дивизии, 18, телефон: 3-99-84	Россия, Краснодарский край, Ленинградский район, поселок Ленинградская	0101000020E6100000FCC7427408B2434055850662D9284740
45750	2	20	1358	49148	23425	\N	46.322556708313101	ст. Ленинградская, Школьная, 14 А, телефон: 7-24-49		0101000020E6100000A0E238F06AB14340460C3B8C49294740
45770	2	20	1358	50841	23841	\N	46.341000731723099	х. Куликовский, Красная, 96, телефон: 5-42-35	Россия, Краснодарский край, Ленинградский район, поселок Куликовский	0101000020E610000006D671FC50C743409F73B7EBA52B4740
45473	2	20	1358	50252	20493	\N	46.097279532410496	ст. Крыловская, здание Крыловского РС РОСТО (ДОСААФ), Шевченко, 16, телефон: 31360	Россия, Краснодарский край, Ленинградский район, поселок Крыловская	0101000020E610000044DFDDCA12A743400647C9AB730C4740
45755	2	20	1358	50661	23285	\N	46.174529366930599	х. Краснострелецкий, Дружная, 14, телефон: 5-14-33	Россия, Краснодарский край, Ленинградский район, поселок Краснострелецкий	0101000020E610000079793A5794BE43400F9A5DF756164740
45764	2	20	1358	50817	23737	\N	46.048031000000002	х. Коржи, Ленина, 1, телефон: 4-94-31	Россия, Краснодарский край, Ленинградский район, поселок Коржи	0101000020E6100000043DD4B661A04340DB183BE125064740
45760	2	20	1358	14761	21634	\N	46.190784999999998	пос. Звезда, Механическая, 2, телефон: 5-33-45		0101000020E610000049B9FB1C1FAF43409FC893A46B184740
45828	2	20	1358	46545	21494	\N	46.397171	п.Западный, ул.Центральная, 18, телефон: 2-61-74		0101000020E6100000041C42959AA74340B6F5D37FD6324740
44565	2	20	1358	21044	20501	\N	46.123289999999997	поселок Высотный, улица Центральная, 12, телефон: 64-6-19		0101000020E6100000C991CEC0C8C9434040F67AF7C70F4740
45754	2	20	1358	50821	23746	\N	46.2712583128761	х. Восточный, Юбилейная, 2, телефон: 3-99-89	Россия, Краснодарский край, Ленинградский район, поселок Восточный	0101000020E61000001327F73B14C34340A2630795B8224740
45768	2	20	1358	15108	21028	\N	46.244605999999997	пос. Бичевой, Красная, 3, телефон: 4-62-45		0101000020E6100000077E54C37ECB4340E333D93F4F1F4740
46366	2	20	7075	50378	21471	\N	43.822611900164098	аул Малый Кичмай, Убыхская, 39, телефон: 76-21-13	Россия, Краснодарский край, городской округ Сочи, поселок Мал. Кичмай	0101000020E6100000CF81E50819C0434009A69A594BE94540
46320	2	20	7075	50861	23904	\N	43.953657	микрорайон Аше, Туристская, 3, телефон: 74-61-43		0101000020E6100000A8E2C62DE6A34340FD4CBD6E11FA4540
45712	2	20	1002	50502	22409	\N	44.561950000000003	ст. Владимирская, Телефонная, 73, телефон: 64022		0101000020E61000003750E09D7C6244405DFE43FAED474640
45710	2	20	1002	50857	23889	\N	44.234829136046898	ст. Чернореченская, Советская, 28, телефон: 64617	Россия, Краснодарский край, Лабинский район, поселок Чернореченская	0101000020E6100000295E656D537A444081936DE00E1E4640
45724	2	20	1002	12231	20549	\N	44.709679999999999	ст.Чамлыкская, Центральная, 34, телефон: 62172		0101000020E6100000F3C64961DE6F4440095053CBD65A4640
45726	2	20	1002	12231	21901	\N	44.709679999999999	352512, ст.Чамлыкская, Ленина, 74		0101000020E6100000F3C64961DE6F4440095053CBD65A4640
45725	2	20	1002	12231	20557	\N	44.709679999999999	ст.Чамлыкская, Кооперативная, 18, телефон: 62126		0101000020E6100000F3C64961DE6F4440095053CBD65A4640
45736	2	20	1002	50849	23866	\N	44.475864999999999	х. Харьковский, Советская, 2, телефон: 70392	Россия, Краснодарский край, Лабинский район, поселок Харьковский	0101000020E61000005F97E13FDD924440D027F224E93C4640
45734	2	20	1002	13471	21921	\N	44.3935418661329	ст. Упорная, Ленина, 264, телефон: 65168	Россия, Краснодарский край, Лабинский район, поселок Упорная	0101000020E610000065726A67988244401CCD91955F324640
45733	2	20	1002	13471	21921	\N	44.393169999999998	ст. Упорная, Ленина, б/н, телефон: 65347		0101000020E61000002507EC6AF282444058E2016553324640
45735	2	20	1002	13471	22964	\N	44.392705642914798	ст. Упорная, Набережная, 94, телефон: 65323	Россия, Краснодарский край, Лабинский район, поселок Упорная	0101000020E6100000D7187442E8824440B378B13044324640
45727	2	20	1002	50311	21011	\N	44.646668185518799	х. Соколихин, Школьная, 1, телефон: 60626	Россия, Краснодарский край, Лабинский район, поселок Соколихин	0101000020E610000087A2409FC879444053AF5B04C6524640
45731	2	20	1002	50554	22763	\N	44.460781362605601	х. Сладкий, Ленина, 123, телефон: 76111	Россия, Краснодарский край, Лабинский район, поселок Сладкий	0101000020E61000005A677C5F5C84444020CF2EDFFA3A4640
45732	2	20	1002	13410	22620	\N	44.486220000000003	п. Розовый, Парковая, 2, телефон: 76201	Россия, Краснодарский край, Лабинский район, поселок Розовый	0101000020E6100000280D350A49844440A054FB743C3E4640
45073	2	20	1002	50442	21897	\N	44.709128999999997	Братский поселок, Садовая, 10Е, телефон: 52-0-15		0101000020E6100000BFEE74E78985444095D233BDC45A4640
45730	2	20	1002	50745	23516	\N	44.648615122569403	х. Первая Синюха, Мира, 136, телефон: 77274	Россия, Краснодарский край, Лабинский район, поселок Первая Синюха	0101000020E6100000105B7A34D5894440F758FAD005534640
45728	2	20	1002	49013	20517	\N	44.241188000000001	ст. Отважная, Ленина, 4, телефон: 66434		0101000020E6100000DBDFD91EBD8544400518963FDF1E4640
45892	2	20	1002	50769	23562	\N	44.318870534730401	"х.Новый Мир  ул.Первомайская 34"	Россия, Краснодарский край, Лабинский район, поселок Новый Мир	0101000020E61000004AB3791C068144404852D2C3D0284640
45687	2	20	1002	50385	21824	\N	44.641345999999999	352500, город Лабинск, Школьная, 177		0101000020E6100000AA99B514905C4440D0B52FA017524640
45707	2	20	1002	50385	21872	\N	44.644287349548598	город Лабинск, Центральная, 6, телефон: 60681	Россия, Краснодарский край, Лабинский район, город Лабинск	0101000020E61000009AE95E27F55F4440751E15FF77524640
45685	2	20	1002	50385	21550	\N	44.641345999999999	город Лабинск, Леонтьева, 91, телефон: 72674		0101000020E6100000AA99B514905C4440D0B52FA017524640
45705	2	20	1002	50385	21529	\N	44.641345999999999	город Лабинск, Калинина, 65, телефон: 31123		0101000020E6100000AA99B514905C4440D0B52FA017524640
45644	2	20	1002	50385	21603	\N	44.641345999999999	город Лабинск, Воровского, 92, телефон: 74176		0101000020E6100000AA99B514905C4440D0B52FA017524640
45706	2	20	1002	50385	21789	\N	44.641345999999999	город Лабинск, Армавирское шоссе, 12, телефон: 60361		0101000020E6100000AA99B514905C4440D0B52FA017524640
45693	2	20	1002	8663	21376	\N	44.641345999999999	город Лабинск, Селиверстова, 26, телефон: 31357		0101000020E6100000AA99B514905C4440D0B52FA017524640
45704	2	20	1002	8663	21119	\N	44.641345999999999	город Лабинск, Победы, 177, телефон: 35619		0101000020E6100000AA99B514905C4440D0B52FA017524640
45699	2	20	1002	8663	20502	\N	44.641345999999999	352500, город Лабинск, Мира, 167		0101000020E6100000AA99B514905C4440D0B52FA017524640
45695	2	20	1002	8663	21378	\N	44.641345999999999	город Лабинск, Международная, 31, телефон: 27104		0101000020E6100000AA99B514905C4440D0B52FA017524640
45696	2	20	1002	8663	20919	\N	44.641203988458898	город Лабинск, К. Маркса, 187, телефон: 34688	Россия, Краснодарский край, Лабинский район, город Лабинск	0101000020E610000033FAD170CA5C44403E0801F912524640
45698	2	20	1002	8663	20734	\N	44.641345999999999	город Лабинск, Красная, 102, телефон: 31764		0101000020E6100000AA99B514905C4440D0B52FA017524640
45694	2	20	1002	8663	20734	\N	44.641345999999999	город Лабинск, Красная, 27, телефон: 33464		0101000020E6100000AA99B514905C4440D0B52FA017524640
45692	2	20	1002	8663	20734	\N	44.641345999999999	город Лабинск, Красная, 14, телефон: 26149		0101000020E6100000AA99B514905C4440D0B52FA017524640
45702	2	20	1002	8663	9930	\N	44.641345999999999	352500, город Лабинск, Коммунаров, 7/1		0101000020E6100000AA99B514905C4440D0B52FA017524640
45688	2	20	1002	8663	21370	\N	44.641345999999999	город Лабинск, Делегатская, 9/1, телефон: 32828		0101000020E6100000AA99B514905C4440D0B52FA017524640
45684	2	20	1002	8663	20932	\N	44.659221297333801	город Лабинск, Д.Бедного, 67, телефон: 73830	Россия, Краснодарский край, Лабинский район, город Лабинск	0101000020E610000012DBDD03745B444010EB8D5A61544640
45686	2	20	1002	8663	20955	\N	44.641345999999999	город Лабинск, Военная, 69, телефон: 74089		0101000020E6100000AA99B514905C4440D0B52FA017524640
45701	2	20	1002	8663	21278	\N	44.641345999999999	город Лабинск, Владимирская, 171, телефон: 69344		0101000020E6100000AA99B514905C4440D0B52FA017524640
14051	1	17	\N	3130	22465	\N	58.045848999999997	г. Рыбинск, Радищева, 15		0101000020E6100000B3614D65516C4340F3C64961DE054D40
45689	2	20	1002	8663	21315	\N	44.641345999999999	город Лабинск, 40 лет Октября, 121, телефон: 31118		0101000020E6100000AA99B514905C4440D0B52FA017524640
45723	2	20	1002	12981	21429	\N	44.305376000000003	352532, ст. Каладжинская, Ленина, 69		0101000020E6100000861C5BCF10744440DD7D8E8F16274640
45722	2	20	1002	12955	20770	\N	44.432273000000002	ст. Зассовская, Советская, 15, телефон: 78419		0101000020E610000085798F334D684440CFF8BEB854374640
45721	2	20	1002	48885	21938	\N	44.595953000000002	ст. Ереминская, Ленина, 1, телефон: 70013		0101000020E610000033DE567A6D804440FF791A30484C4640
45729	2	20	1002	49033	22370	\N	44.251067999999997	село Гофицкое, Ленина, 146, телефон: 66421		0101000020E61000008A1EF818AC7C44403B8908FF22204640
45716	2	20	1002	48795	21458	\N	44.547716000000001	ст. Вознесенская, Мира, 76, телефон: 70131		0101000020E61000001D0247020D8444407BBFD18E1B464640
45715	2	20	1002	48795	21458	\N	44.547716000000001	ст. Вознесенская, Мира, 186, телефон: 70120		0101000020E61000001D0247020D8444407BBFD18E1B464640
45717	2	20	1002	48795	21282	\N	44.547716000000001	ст. Вознесенская, Калмыкова, 9, телефон: 70765		0101000020E61000001D0247020D8444407BBFD18E1B464640
45718	2	20	1002	48795	20798	\N	44.544401813466799	ст. Вознесенская, 50 лет Октября, 26, телефон: 70198	Россия, Краснодарский край, Лабинский район, поселок Вознесенская	0101000020E6100000A96BED7DAA84444041F0F8F6AE454640
45711	2	20	1002	50251	20478	\N	44.545284378192001	ст. Владимирская, Чапаева, 10, телефон: 63528	Россия, Краснодарский край, Лабинский район, поселок Владимирская	0101000020E610000074603942066644401B84B9DDCB454640
45713	2	20	1002	50251	20962	\N	44.542801794898999	ст. Владимирская, Телефонная, 32, телефон: 63557	Россия, Краснодарский край, Лабинский район, поселок Владимирская	0101000020E6100000D3156C239E664440091A33897A454640
45714	2	20	1002	50251	21575	\N	44.546607431094401	ст. Владимирская, Гагарина, 136, телефон: 63439		0101000020E6100000BFB854A52D664440E161DA37F7454640
46817	2	20	1002	50686	23390	\N	44.477067279253198	хутор Веселый, Почтовая, 12, телефон: 61148	Россия, Краснодарский край, Лабинский район, поселок Веселый	0101000020E610000071ADF6B0177444401B800D88103D4640
44880	2	20	1002	45934	\N	\N	44.709128999999997	пос. Братский, Спортивный переулок, 7, телефон: 97212	Россия, Краснодарский край, Лабинский район, поселок Братский	0101000020E6100000BFEE74E78985444095D233BDC45A4640
45709	2	20	1002	12373	21006	\N	44.149918999999997	ст. Ахметовская, Краснопартизанская, 13, телефон: 66233		0101000020E61000001135D1E7A38644404606B98B30134640
45682	2	20	1015	11046	20643	\N	46.587046000000001	Краснодарский край, Кущевский район, станица  Шкуринская, улица Ленина, 26, телефон: 4-53-64		0101000020E6100000F3AE7AC03CAE4340B29FC552244B4740
45681	2	20	1015	11046	20643	\N	46.587046000000001	Краснодарский край, Кущевский район, станица  Шкуринская, улица Ленина, 54, телефон: 4-51-64		0101000020E6100000F3AE7AC03CAE4340B29FC552244B4740
45680	2	20	1015	11003	21337	\N	46.758606	Краснодарский край, Кущевский район, хутор Тауруп Первый, улица Комсомольская, 2, телефон: 4-45-83		0101000020E61000004721C9ACDEC1434052465C001A614740
45649	2	20	1015	9478	20646	\N	46.650243000000003	Краснодарский край, Кущевский район, село Степное, улица Школьная, 2/1, телефон: 4-17-95		0101000020E61000005CE509849DD64340FAB9A1293B534740
45676	2	20	1015	10777	21772	\N	46.734763999999998	Краснодарский край, Кущевский район, хутор Средние Чубурки, улица Красная, 81, телефон: 4-43-40		0101000020E61000003B55BE6724B243409A232BBF0C5E4740
45675	2	20	1015	10777	21772	\N	46.734763999999998	Краснодарский край, Кущевский район, хутор Средние Чубурки, улица Красная, 67, телефон: 4-45-83		0101000020E61000003B55BE6724B243409A232BBF0C5E4740
45677	2	20	1015	50414	21705	\N	46.734763999999998	Краснодарский край, Кущевский район, хутор Средние Чубурки, улица Октябрьская, 21, телефон: 3-89-71		0101000020E61000003B55BE6724B243409A232BBF0C5E4740
45648	2	20	1015	9427	21723	\N	46.674987935311798	Краснодарский край, Кущевский район, поселок Северный, улица Школьная, 1/5, телефон: 4-18-12		0101000020E610000097C9703C9FC94340A298BC0166564740
45650	2	20	1015	9529	20648	\N	46.621878000000002	Краснодарский край, Кущевский район, поселок Садовый, улица Мира, 65, телефон: 4-26-91		0101000020E6100000B9196EC0E7DD43400B0DC4B2994F4740
45654	2	20	1015	9688	22200	\N	46.609831999999997	Краснодарский край, Кущевский район, поселок  Ровный, улица Центральная, 1, телефон: 3-76-69		0101000020E610000023A0C211A4004440F20698F90E4E4740
45669	2	20	1015	10461	21100	\N	46.709380000000003	Краснодарский край, Кущевский район, село Раздольное, улица Красная, 63, телефон: 3-41-31		0101000020E610000001A4367172D54340DF37BEF6CC5A4740
45067	2	20	1015	50765	23826	\N	46.391411911291797	Пролетарский хутор, Школьная, 10, телефон: 2-46-46	Россия, Краснодарский край, Кущевский район, поселок Пролетарский	0101000020E6100000D04543C6A3C4434088A1D5C919324740
45667	2	20	1015	50765	23556	\N	46.391185999999998	Краснодарский край, Кущевский район, хутор Пролетарский, улица Центральная, 11, телефон: 4-87-56	Россия, Краснодарский край, Кущевский район, поселок Пролетарский	0101000020E61000009BE61DA7E8C443409753026212324740
45668	2	20	1015	10440	22630	\N	46.729947000000003	Краснодарский край, Кущевский район, село Полтавченское, улица Трудовая, 1, телефон: 4-96-18		0101000020E61000001E51A1BAB90244401B683EE76E5D4740
45665	2	20	1015	10274	21313	\N	46.476951999999997	Краснодарский край, Кущевский район, поселок Первомайский, улица Советская, 10, телефон: 4-84-86		0101000020E6100000F6B52E3542C9434082E15CC30C3D4740
44564	2	20	1015	10274	21313	\N	46.476664166611698	поселок Первомайский, улица Советская, 6, телефон: 64-1-83	Россия, Краснодарский край, Кущевский район, поселок Первомайский	0101000020E610000015376E313FC943401C977153033D4740
45683	2	20	1015	10274	23607	\N	46.475558721003701	Краснодарский край, Кущевский район, хутор Первомайский, улица Первомайская, 11, телефон: 3-39-98	Россия, Краснодарский край, Кущевский район, поселок Первомайский	0101000020E6100000B35E0CE544C94340C328081EDF3C4740
45554	2	20	433	4819	20944	\N	44.945008999999999	село Молдаванское, Ленина, 11а, телефон: 6-93-33		0101000020E6100000EB1D6E8786EF42407CB60E0EF6784640
45663	2	20	1015	10138	21067	\N	46.546990999999998	Краснодарский край, Кущевский район, село Новомихайловское, улица Школьная, 11, телефон: 4-93-08		0101000020E6100000361D01DC2CEA4340691A14CD03464740
45652	2	20	1015	9610	21084	\N	46.538325999999998	Краснодарский край, Кущевский район, село Новоивановское, улица Парковая, 8, телефон: 4-16-16		0101000020E6100000C47C7901F6D54340124BCADDE7444740
45679	2	20	1015	10931	21124	\N	46.780203	Краснодарский край, Кущевский район, хутор Нововысоченский, улица Центральная, 24, телефон: 4-41-79		0101000020E61000003B8E1F2A8DB84340DC9E20B1DD634740
45651	2	20	1015	9534	21297	\N	46.615285999999998	Краснодарский край, Кущевский район, поселок Мирный, улица Мира, 9, телефон: 3-20-15		0101000020E6100000CD21A98592EB4340E4D70FB1C14E4740
45645	2	20	1015	8781	20890	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, переулок Школьный, 56, телефон: 4-02-39		0101000020E61000002E71E481C8D04340B22FD978B0474740
45643	2	20	1015	8781	20890	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, переулок Школьный, 55, телефон: 4-07-63		0101000020E61000002E71E481C8D04340B22FD978B0474740
45639	2	20	1015	8781	20637	\N	46.560073000000003	352030, Краснодарский край, Кущевский район, станица Кущевская, переулок Кавказский, 134		0101000020E61000002E71E481C8D04340B22FD978B0474740
45634	2	20	1015	8781	21478	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, переулок Б.Е. Москвича, 80, телефон: 5-46-69		0101000020E61000002E71E481C8D04340B22FD978B0474740
45641	2	20	1015	8781	21071	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, улица Элеваторная, 42, телефон: 5-47-44		0101000020E61000002E71E481C8D04340B22FD978B0474740
45638	2	20	1015	8781	21423	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, улица Ленинградская, 74, телефон: 5-57-65		0101000020E61000002E71E481C8D04340B22FD978B0474740
45637	2	20	1015	8781	20879	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, улица Ленина, 89, телефон: 5-40-41		0101000020E61000002E71E481C8D04340B22FD978B0474740
45636	2	20	1015	8781	20879	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, улица Ленина, 46, телефон: 5-40-69		0101000020E61000002E71E481C8D04340B22FD978B0474740
45635	2	20	1015	8781	20879	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, улица Ленина, 12, телефон: 5-52-81		0101000020E61000002E71E481C8D04340B22FD978B0474740
45640	2	20	1015	8781	21287	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, улица Красногвардейская, 1, телефон: 5-43-22		0101000020E61000002E71E481C8D04340B22FD978B0474740
45642	2	20	1015	50282	\N	\N	46.556644859681697	Краснодарский край, Кущевский район, станица Кущевская 2, здание МБОУ СОШ №30 (микрорайон Кущёвка - 2), телефон: 5-13-19		0101000020E610000022FE614B8FD24340B03DB32440474740
45646	2	20	1015	50419	21764	\N	46.560073000000003	Краснодарский край, Кущевский район, станица Кущевская, улица Ейская, 83, телефон: 4-02-91		0101000020E61000002E71E481C8D04340B22FD978B0474740
46032	2	20	1015	50395	21609	\N	46.767207854641498	хутор Красный, Советская, 40 А, телефон: 4-03-22	Россия, Краснодарский край, Кущевский район, поселок Красный	0101000020E61000001DC87A6AF5A54340629D2ADF33624740
46630	2	20	1015	50395	23771	\N	46.767561714552997	хутор Красный, Длинная, 34, телефон: 6-40-80	Россия, Краснодарский край, Кущевский район, поселок Красный	0101000020E6100000220038F6ECA5434080D3BB783F624740
45660	2	20	1015	10001	21483	\N	46.736426000000002	Краснодарский край, Кущевский район, село Красное, переулок Советов, 13, телефон: 3-51-78		0101000020E6100000EEB3CA4C69C5434049F60835435E4740
45661	2	20	1015	10001	24032	\N	46.732409887125598	Краснодарский край, Кущевский район, хутор Красное, переулок Клубный, 3, телефон: 3-59-42	Россия, Краснодарский край, Кущевский район, поселок Красное	0101000020E6100000E95F92CA14C74340B6A1629CBF5D4740
45659	2	20	1015	50714	23448	\N	46.6576068492611	"Краснодарский край, Кущевский район, хутор Красная Поляна, улица Мира, 55, телефон: 3-33-85, 3-34-73"	Россия, Краснодарский край, Кущевский район, поселок Красная Поляна	0101000020E61000006BF46A80D2AE4340724F57772C544740
45666	2	20	1015	10290	21488	\N	46.498539000000001	Краснодарский край, Кущевский район, поселок Комсомольский, улица Центральная, 16, телефон: 3-81-68		0101000020E61000005BB4006DABB14340E9633E20D03F4740
45664	2	20	1015	10238	20623	\N	46.53031	Краснодарский край, Кущевский район, поселок Коммунар, улица Мира, 1, телефон: 4-94-43		0101000020E6100000E9B7AF03E7F84340F25EB532E1434740
45657	2	20	1015	9831	20898	\N	46.434617000000003	Краснодарский край, Кущевский район, станица Кисляковская, улица Красная, 45, телефон: 4-31-44		0101000020E61000009818CBF44BD6434090A4A487A1374740
45656	2	20	1015	9831	20898	\N	46.434617000000003	Краснодарский край, Кущевский район, станица Кисляковская, улица Красная, 150, телефон: 4-33-01		0101000020E61000009818CBF44BD6434090A4A487A1374740
45658	2	20	1015	9916	22628	\N	46.391776	Краснодарский край, Кущевский район, поселок Кисляковка, улица Восточная, 3, телефон: 4-33-29		0101000020E6100000BBD39D279ECD4340C9AD49B725324740
45678	2	20	1015	50763	23554	\N	46.708354	Краснодарский край, Кущевский район, хутор Исаевский, улица Садовая, 31, телефон: 4-41-62	Россия, Краснодарский край, Кущевский район, поселок Исаевский	0101000020E6100000FC71FBE593C14340D2FE0758AB5A4740
45655	2	20	1015	9771	21507	\N	46.666980000000002	Краснодарский край, Кущевский район, село Ильинское, переулок Школьный, 6, телефон: 3-22-42		0101000020E610000040FA264D83EC4340058BC3995F554740
45673	2	20	1015	10671	22149	\N	46.658698000000001	Краснодарский край, Кущевский район, село  Ивано-Слюсаревское, улица Нижняя, 11/1, телефон: 4-23-11		0101000020E6100000124DA08845E0434066F84F3750544740
45562	2	20	433	5252	20945	\N	45.154277	хутор Могукоровский, Пролетарская, 46, телефон: 6-71-40		0101000020E6100000C0ED0912DB19434033C34659BF934640
45672	2	20	1015	50799	23640	\N	46.763559574626697	Краснодарский край, Кущевский район, хутор Зеленая Роща, улица Целинная, 16, телефон: 3-72-36	Россия, Краснодарский край, Кущевский район, поселок Зеленая Роща	0101000020E6100000C971A774B0E6434052448655BC614740
45674	2	20	1015	10690	21279	\N	46.654522999999998	Краснодарский край, Кущевский район, хутор Гослесопитомник, улица Ленина, 60, телефон: 4-24-46		0101000020E61000001F2FA4C343E043406ABDDF68C7534740
45653	2	20	1015	9666	20895	\N	46.642812999999997	Краснодарский край, Кущевский район, хутор Глебовка, улица Братская, 33, телефон: 3-76-75		0101000020E61000009A779CA223FF4340C93846B247524740
45670	2	20	1015	10533	20877	\N	46.728495000000002	Краснодарский край, Кущевский район, хутор Водяная Балка, улица Красная, 54, телефон: 3-41-31		0101000020E6100000EA7B0DC171D143405726FC523F5D4740
45647	2	20	1015	9373	20481	\N	46.643245999999998	Краснодарский край, Кущевский район, хутор Большая Лопатина, улица Большелопатинская, 1, телефон: 4-71-80		0101000020E61000005401F73C7FCA434033A48AE255524740
45671	2	20	1015	10594	20437	\N	46.754289999999997	Краснодарский край, Кущевский район, село Алексеевское, улица Школьная, 7, телефон: 3-72-43		0101000020E610000053978C6324DB434094D920938C604740
45619	2	20	821	8089	21531	\N	44.927252000000003	поселок Щебенозаводской, Заводская, 1 А, телефон: 7-98-01		0101000020E6100000A91611C5E46B444047938B31B0764640
45622	2	20	821	8253	21691	\N	44.852718000000003	поселок Урмия, Магистральная, 2, телефон: 7-38-30		0101000020E61000005798BED7106E4440F35A09DD256D4640
45608	2	20	821	7458	21524	\N	45.106579000000004	станица Темиргоевская, Школьная, 22, телефон: 7-15-89		0101000020E610000086048C2E6F2444405FB87361A48D4640
45606	2	20	821	7458	20917	\N	45.106579000000004	станица Темиргоевская, Прогонная, 43, телефон: 7-11-84		0101000020E610000086048C2E6F2444405FB87361A48D4640
45607	2	20	821	7458	22066	\N	45.106579000000004	станица Темиргоевская, Мира, 121, телефон: 7-11-81		0101000020E610000086048C2E6F2444405FB87361A48D4640
45610	2	20	821	7458	20676	\N	45.106579000000004	станица Темиргоевская, Ленина, 62, телефон: 7-12-82		0101000020E610000086048C2E6F2444405FB87361A48D4640
45612	2	20	821	7737	20678	\N	45.125731000000002	хутор Сухой Кут, Красная, 44, телефон: 7-51-90		0101000020E61000001AFCFD62B61A4440F48B12F417904640
45617	2	20	821	33091	20844	\N	44.957670999999998	поселок Светлая Заря, Центральная, 76, телефон: 7-43-68		0101000020E610000009E1D1C6115F4440EFA99CF6947A4640
45628	2	20	821	8486	21470	\N	44.756583999999997	станица Родниковская, Первомайская, 152, телефон: 6-42-27		0101000020E610000076C58CF0F6544440A35698BED7604640
45633	2	20	821	8486	20911	\N	44.756583999999997	станица Родниковская, Курганинская, 88, телефон: 6-42-37		0101000020E610000076C58CF0F6544440A35698BED7604640
45627	2	20	821	8486	20911	\N	44.756855372848896	станица Родниковская, Курганинская, 88, телефон: 6-41-57	Россия, Краснодарский край, Курганинский район, поселок Родниковская	0101000020E6100000F1845E7F125544403468E89FE0604640
45629	2	20	821	8486	21275	\N	44.756583999999997	станица Родниковская, Кирова, 143, телефон: 6-44-16		0101000020E610000076C58CF0F6544440A35698BED7604640
45600	2	20	821	40310	23433	\N	45.079554840659299	станица Петропавловская, Энгельса, 3, телефон: 6-22-49		0101000020E61000003A05F9D9C8394440DC9DB5DB2E8A4640
45601	2	20	821	40310	23998	\N	45.080606000000003	станица Петропавловская, Пролетарская, 69, телефон: 6-22-42	Россия, Краснодарский край, Курганинский район, поселок Петропавловская	0101000020E610000014AFB2B6293A444042EE224C518A4640
45604	2	20	821	40310	22073	\N	45.080606000000003	станица Петропавловская, Победы, 15, телефон: 7-59-19		0101000020E610000014AFB2B6293A444042EE224C518A4640
45602	2	20	821	40310	9782	\N	45.082551357043499	станица Петропавловская, КИМ, 51, телефон: 6-31-01	Россия, Краснодарский край, Курганинский район, поселок Петропавловская	0101000020E6100000739CDB847B39444045A0FA07918A4640
45603	2	20	821	40310	20826	\N	45.080606000000003	станица Петропавловская, Гагарина, 49, телефон: 6-27-78		0101000020E610000014AFB2B6293A444042EE224C518A4640
45623	2	20	821	8281	22574	\N	44.824314000000001	станица Новоалексеевская, 50 лет ВЛКСМ, 10, телефон: 7-73-39		0101000020E6100000D38558FD1174444046D1031F83694640
45595	2	20	821	46418	21233	\N	44.997284999999998	станица Михайловская, Революционная, 52, телефон: 6-17-98		0101000020E61000005708ABB1844D44404BE5ED08A77F4640
45592	2	20	821	46418	20950	\N	44.997284999999998	станица Михайловская, Острецова, 247, телефон: 6-12-72		0101000020E61000005708ABB1844D44404BE5ED08A77F4640
45594	2	20	821	46418	21664	\N	44.997284999999998	станица Михайловская, Октябрьская, 79, телефон: 6-13-72		0101000020E61000005708ABB1844D44404BE5ED08A77F4640
45593	2	20	821	46418	21445	\N	44.997284999999998	станица Михайловская, Ленина, 148, телефон: 6-14-85		0101000020E61000005708ABB1844D44404BE5ED08A77F4640
45580	2	20	821	46141	22113	\N	45.028666999999999	поселок Мира, Мира, 1, телефон: 6-61-12		0101000020E6100000FDF7E0B54B5B4440BABC395CAB834640
45574	2	20	821	5900	21468	\N	44.862200556497797	город Курганинск, Чапаева, 1, телефон: 2-99-58	Россия, Краснодарский край, Курганинский район, город Курганинск	0101000020E6100000938B31B08E4F44400CCA349A5C6E4640
45630	2	20	821	5900	20854	\N	44.886830000000003	город Курганинск, Серикова, 56, телефон: 2-66-01		0101000020E610000084674293C44A44404C8E3BA583714640
45632	2	20	821	5900	21273	\N	44.886830000000003	город Курганинск, Р. Люксембург, 293, телефон: 2-25-16		0101000020E610000084674293C44A44404C8E3BA583714640
45575	2	20	821	5900	21070	\N	44.886830000000003	город Курганинск, Пушкина, 57 А, телефон: 2-10-75		0101000020E610000084674293C44A44404C8E3BA583714640
45576	2	20	821	5900	20886	\N	44.886830000000003	город Курганинск, Первомайская, 1, телефон: 2-13-80		0101000020E610000084674293C44A44404C8E3BA583714640
45578	2	20	821	5900	20752	\N	44.886830000000003	город Курганинск, Партизанская, 154, телефон: 2-35-28		0101000020E610000084674293C44A44404C8E3BA583714640
45577	2	20	821	5900	20752	\N	44.886493943962499	город Курганинск, Партизанская, 154, телефон: 2-29-47	Россия, Краснодарский край, Курганинский район, город Курганинск	0101000020E61000006EF8DD74CB4A4440D40CA9A278714640
45582	2	20	821	5900	20473	\N	44.886830000000003	город Курганинск, Луговая, 3, телефон: 2-02-80		0101000020E610000084674293C44A44404C8E3BA583714640
45588	2	20	821	5900	21504	\N	44.886830000000003	город Курганинск, Ленина, 151, телефон: 2-27-85		0101000020E610000084674293C44A44404C8E3BA583714640
45581	2	20	821	5900	20990	\N	44.887177047703197	город Курганинск, Коммунистическая, 77, телефон: 2-261-9	Россия, Краснодарский край, Курганинский район, город Курганинск	0101000020E61000006D020CCB9F4B4440B76114048F714640
45587	2	20	821	5900	21081	\N	44.885548181138198	город Курганинск, Калинина, 48, телефон: 2-10-17	Россия, Краснодарский край, Курганинский район, город Курганинск	0101000020E61000007CF31B261A4C4440E48409A359714640
45583	2	20	821	5900	20991	\N	44.886830000000003	город Курганинск, Заводская, 20, телефон: 2-04-93		0101000020E610000084674293C44A44404C8E3BA583714640
45585	2	20	821	5900	20518	\N	44.886830000000003	город Курганинск, Д. Бедного, 213, телефон: 2-23-37		0101000020E610000084674293C44A44404C8E3BA583714640
45584	2	20	821	5900	20423	\N	44.886830000000003	город Курганинск, Д. Бедного, 313, телефон: 3-13-90		0101000020E610000084674293C44A44404C8E3BA583714640
45596	2	20	821	50266	20593	\N	45.036497145628203	хутор Красный, Синюхинская, 10, телефон: 6-13-01	Россия, Краснодарский край, Курганинский район, поселок Красный	0101000020E610000013F06B240948444078B306EFAB844640
45590	2	20	821	46377	22310	\N	44.903666999999999	хутор Красное Поле, Кочубея, 109, телефон: 7-02-71		0101000020E6100000FDBFEAC891584440BABC395CAB734640
45597	2	20	821	50729	23473	\N	45.006954296769003	хутор Красное Знамя, Коммунаров, 16/1, телефон: 6-11-85	Россия, Краснодарский край, Курганинский район, поселок Красное Знамя	0101000020E61000004A79AD84EE424440C74961DEE3804640
45620	2	20	821	8110	21261	\N	44.938048999999999	хутор Кочергин, Северная, 50, телефон: 7-98-73		0101000020E6100000C93CF20703654440D38558FD11784640
45626	2	20	821	47115	20858	\N	44.836331000000001	станица Константиновская, Кирова, 63, телефон: 7-32-53		0101000020E61000006494675E0E5D4440C4D0EAE40C6B4640
45625	2	20	821	47115	23815	\N	44.836086925706397	станица Константиновская, Калинина, 100, телефон: 7-31-16		0101000020E6100000F5F75278D05C44402DCE18E6046B4640
45611	2	20	821	7678	20930	\N	45.127770615540904	станица Воздвиженская, Советская, 12 А, телефон: 7-51-36	Россия, Краснодарский край, Курганинский район, поселок Воздвиженская	0101000020E61000001405FA449E1244404930D5CC5A904640
45618	2	20	821	50867	23930	\N	44.9508604630932	поселок Андреедмитриевский, Элеваторная, 1, телефон: 7-99-35	Россия, Краснодарский край, Курганинский район, поселок Андрее-Дмитриевский	0101000020E6100000C89750C1E16B44408B89CDC7B5794640
44865	2	20	433	45633	20852	\N	45.030903000000002	пос.Южный, Садовая, 36, телефон: 13-03-04		0101000020E61000005B26C3F17C0A4340952C27A1F4834640
45530	2	20	433	3535	22396	\N	44.991638000000002	село Экономическое, Почтовая, 12, телефон: 7-48-07		0101000020E61000001749BBD1C7F8424045BC75FEED7E4640
46169	2	20	433	2395	21452	\N	44.997852999999999	п. Черноморский, Суворова, 2, телефон: 66-3-56		0101000020E6100000FF91E9D0E9034340959BA8A5B97F4640
45566	2	20	433	2395	23801	\N	44.997852999999999	хутор Черноморский, Ленина, 7, телефон: 2-29-48		0101000020E6100000FF91E9D0E9034340959BA8A5B97F4640
46167	2	20	433	2395	20821	\N	44.997852999999999	п. Черноморский, Кирова, 30, телефон: 66-3-31		0101000020E6100000FF91E9D0E9034340959BA8A5B97F4640
46171	2	20	433	2395	20595	\N	44.997852999999999	п. Черноморский, Гоголя, 10, телефон: 67-0-00		0101000020E6100000FF91E9D0E9034340959BA8A5B97F4640
45548	2	20	433	45504	20865	\N	45.067481000000001	поселок Фадеево, Школьная, 2а, телефон: 6-24-24		0101000020E610000074D2FBC6D7C64240FA0CA837A3884640
45561	2	20	433	45726	21294	\N	45.136057000000001	станица Троицкая, Советская, 60, телефон: 6-71-95		0101000020E6100000062CB98AC50F434029B2D6506A914640
45560	2	20	433	45726	20708	\N	45.136057000000001	станица Троицкая, Пестеля, 58, телефон: 6-73-84		0101000020E6100000062CB98AC50F434029B2D6506A914640
45556	2	20	433	50693	23403	\N	44.9042776015364	поселок Саук-Дере, Школьная, 6, телефон: 6-34-70	Россия, Краснодарский край, Крымский район, поселок Саукдере	0101000020E61000003F55850662F14240033FAA61BF734640
45553	2	20	433	45601	20768	\N	44.959189000000002	село Русское, Высоцкой, 22а, телефон: 6-90-09		0101000020E61000004EF04DD367EB42406BD784B4C67A4640
45708	2	20	433	48674	22152	\N	44.978256999999999	пос.Прохладный, Коммунистическая, 45, телефон: 79125		0101000020E6100000960854FF20E64240A20A7F86377D4640
44881	2	20	433	45950	20722	\N	45.049824999999998	пос. Пролетарский, Зеленая, 22А, телефон: 97173		0101000020E6100000C7832D76FBE04240F8C264AA60864640
45572	2	20	433	50779	23578	\N	45.034422901387998	Краснодарский край, Крымский район, х.Плавненский, Широкая, 11в, телефон: 6-00-84	Россия, Краснодарский край, Крымский район, поселок Плавненский	0101000020E6100000A5828AAA5FF74240779D0DF967844640
45557	2	20	433	4961	20715	\N	44.895322	хутор Новоукраинский, Комарова, 5, телефон: 7-64-15		0101000020E6100000048E041A6C064340D5B14AE999724640
45573	2	20	433	4961	23354	\N	44.894651447065002	Краснодарский край, Крымский район, х.Новоукраинский, Кирова, 1в, телефон: 7-61-24	Россия, Краснодарский край, Крымский район, поселок Новоукраинский	0101000020E61000001D01DC2C5E064340B72A89EC83724640
45567	2	20	433	50887	23988	\N	45.0332158094524	хутор Новотроицкий, Шоссейная, 61, телефон: 6-65-66		0101000020E61000008D7DC9C6830143401BDA006C40844640
45542	2	20	433	45397	20938	\N	45.041929000000003	село Новопокровское, Новопокровская, 5а, телефон: 7-52-32		0101000020E6100000F435CB65A3D3424083E0F1ED5D854640
46730	2	20	433	50865	23928	\N	45.040993287428797	п.Нововмихайловский, Мира, 67, телефон: 91961		0101000020E61000004660AC6F60D84240B62E35423F854640
45552	2	20	433	4715	21543	\N	44.934685999999999	хутор Новокрымский, Фроловой, 10а, телефон: 6-93-37		0101000020E6100000BA9EE8BAF0E54240B80375CAA3774640
45570	2	20	433	50453	22020	\N	44.867125000000001	станица Нижнебаканская, Горького, 37, телефон: 2-88-92		0101000020E610000009336DFFCAEE4240A245B6F3FD6E4640
45569	2	20	433	5599	21270	\N	44.867125000000001	станица Нижнебаканская, Октябрьская, 5, телефон: 2-82-24		0101000020E610000009336DFFCAEE4240A245B6F3FD6E4640
45543	2	20	433	4224	23844	\N	45.052874130901401	хутор Непиль, Кубанская, 12а, телефон: 6-64-48	Россия, Краснодарский край, Крымский район, поселок Непиль	0101000020E61000000806103E94DE424084674293C4864640
45571	2	20	433	5706	20856	\N	44.826518999999998	станица Неберджаевская, Ленина, 48, телефон: 6-45-05	Россия, Краснодарский край, Крымский район, поселок Неберджаевская	0101000020E6100000C2FBAA5CA8F24240E542E55FCB694640
25184	1	2	1569	47662	24613	\N	53.153288000000003	с.Усошки, Молодежная, 3		0101000020E610000058552FBFD3C44040446FF1F09E934A40
44297	2	20	433	50778	23577	\N	44.916256080077801	х.Ленинский, Кирова, 69А, телефон: 67-3-94	Россия, Краснодарский край, Крымский район, поселок Ленинский	0101000020E6100000B81E85EB51F24240C36169E047754640
45563	2	20	433	5316	20688	\N	45.066837999999997	хутор Кувичинский, Зеленая, 59, телефон: 6-73-33		0101000020E61000009B92ACC3D1174340A510C8258E884640
45541	2	20	433	4110	21595	\N	45.084125	хутор Кубанская Колонка, Жукова, 51, телефон: 7-52-81		0101000020E6100000F180B22957D6424054E3A59BC48A4640
45516	2	20	433	2380	20452	\N	44.918024000000003	город Крымск, Фурманова, 40а, телефон: 4-05-00		0101000020E6100000F81C588E90FF4240B87878CF81754640
45522	2	20	433	2380	20482	\N	44.918024000000003	город Крымск, Фадеева, 60, телефон: 4-66-12		0101000020E6100000F81C588E90FF4240B87878CF81754640
45430	2	20	433	2380	21259	\N	44.918024000000003	город Крымск, Свердлова, 5, телефон: 3-63-68		0101000020E6100000F81C588E90FF4240B87878CF81754640
45509	2	20	433	2380	21157	\N	44.918202699803203	город Крымск, Родниковая, 2, телефон: 5-13-21	Россия, Краснодарский край, Крымский район, город Крымск	0101000020E61000005C1C959BA8FF4240670B08AD87754640
45515	2	20	433	2380	21174	\N	44.918024000000003	город Крымск, Луначарского, 9, телефон: 2-70-96		0101000020E6100000F81C588E90FF4240B87878CF81754640
45520	2	20	433	2380	21581	\N	44.918024000000003	город Крымск, Ленина, 168, телефон: 4-23-67		0101000020E6100000F81C588E90FF4240B87878CF81754640
45513	2	20	433	50253	21176	\N	44.918024000000003	город Крымск, Энергетиков, 61, телефон: 2-74-10		0101000020E6100000F81C588E90FF4240B87878CF81754640
45510	2	20	433	50253	21850	\N	44.914513803328198	город Крымск, Привокзальная, 16, телефон: 5-10-63		0101000020E6100000AC8BDB6800014340F8DD74CB0E754640
45525	2	20	433	50253	21184	\N	44.902928117043899	город Крымск, Луначарского, 303, телефон: 4-33-00		0101000020E610000010E7E104A6FB424044520B2593734640
45514	2	20	433	50253	21184	\N	44.918024000000003	город Крымск, Луначарского, 116, телефон: 4-02-01		0101000020E6100000F81C588E90FF4240B87878CF81754640
45526	2	20	433	50253	21899	\N	44.918024000000003	город Крымск, Либкнехта, 40, телефон: 4-89-93		0101000020E6100000F81C588E90FF4240B87878CF81754640
45521	2	20	433	50253	20989	\N	44.917897308685397	город Крымск, Ленина, 231, телефон: 4-79-57	Россия, Краснодарский край, Крымский район, город Крымск	0101000020E61000000AA359D93EFE42405B0C1EA67D754640
45519	2	20	433	50253	21809	\N	44.933938544521801	город Крымск, Крупской, 33, телефон: 4-39-01	Россия, Краснодарский край, Крымский район, город Крымск	0101000020E6100000ED0DBE3099FC4240BFBA2A508B774640
45511	2	20	433	50253	20509	\N	44.918024000000003	город Крымск, Гречко, 10а, телефон: 4-60-23		0101000020E6100000F81C588E90FF4240B87878CF81754640
45518	2	20	433	50253	21359	\N	44.927780107112703	город Крымск, Горная, 13, телефон: 4-34-55		0101000020E610000011346612F5FC424002F1BA7EC1764640
45527	2	20	433	50253	20635	\N	44.918024000000003	город Крымск, 50 лет Октября, 20, телефон: 4-22-01		0101000020E6100000F81C588E90FF4240B87878CF81754640
45568	2	20	433	50291	20803	\N	44.979697000000002	хутор Красный, Школьная, 3, телефон: 2-29-56	Россия, Краснодарский край, Крымский район, поселок Красный	0101000020E6100000BDE2A9471A064340A27E17B6667D4640
45535	2	20	433	3823	20787	\N	45.093429	хутор Красная Батарея, Комсомольская, 47а, телефон: 7-90-73		0101000020E61000009B20EA3E00E54240BEBF417BF58B4640
45532	2	20	433	49498	21936	\N	45.037278999999998	село Киевское, Красная, 117г, телефон: 6-01-05		0101000020E61000006FD8B628B3F14240EEE9EA8EC5844640
45533	2	20	433	49498	21201	\N	45.037278999999998	село Киевское, Горького, 116, телефон: 6-02-49		0101000020E61000006FD8B628B3F14240EEE9EA8EC5844640
45534	2	20	433	3741	21205	\N	45.063451000000001	село Кеслерово, Гастелло, 29, телефон: 7-37-39		0101000020E610000096B377465BE9424002F390291F884640
45756	2	20	433	50878	23959	\N	45.145892439319297	"х. Западный, Светлая, 153 ""а"", телефон: 4-43-61"	Россия, Краснодарский край, Крымский район, поселок Западный	0101000020E6100000588CBAD6DE074340C05FCC96AC924640
45565	2	20	433	50678	23365	\N	45.0468354094182	хутор Евсеевский, Школьная, 11, телефон: 6-54-31	Россия, Краснодарский край, Крымский район, поселок Евсеевский	0101000020E6100000B2DAFCBFEA12434072A774B0FE854640
45551	2	20	433	4663	20834	\N	44.969794999999998	хутор Даманка, Молодежная, 73, телефон: 6-11-66		0101000020E6100000DE8E705AF0E442408369183E227C4640
45539	2	20	433	3998	20995	\N	44.985059	станица Гладковская, Центральная, 19, телефон: 6-27-03		0101000020E6100000EFE2FDB8FDDC4240B3D0CE69167E4640
45531	2	20	433	49466	20998	\N	45.127696	село Гвардейское, Колобова, 16, телефон: 4-56-05		0101000020E61000008E1EBFB7E9EF42403EEAAF5758904640
45547	2	20	433	4280	20696	\N	45.118042000000003	станица Варениковская, Пушкина, 250, телефон: 7-14-58		0101000020E61000006F9EEA909BD14240F8C610001C8F4640
45544	2	20	433	4280	21717	\N	45.120867739296301	станица Варениковская, Красная, 74, телефон: 7-15-41	Россия, Краснодарский край, Крымский район, поселок Варениковская	0101000020E6100000F29716F549D242400491459A788F4640
45550	2	20	433	4280	21050	\N	45.118042000000003	станица Варениковская, Железнодорожная, 2, телефон: 7-13-35		0101000020E61000006F9EEA909BD14240F8C610001C8F4640
45545	2	20	433	50421	21801	\N	45.118042000000003	станица Варениковская, Чапаева, 53, телефон: 7-14-50		0101000020E61000006F9EEA909BD14240F8C610001C8F4640
45546	2	20	433	50421	22296	\N	45.118042000000003	станица Варениковская, Советская, 41, телефон: 7-12-60		0101000020E61000006F9EEA909BD14240F8C610001C8F4640
45558	2	20	433	45687	20713	\N	44.859101000000003	хутор Армянский, Миронова, 1, телефон: 6-40-27		0101000020E61000009A7D1EA33CFF4240FF7A8505F76D4640
45540	2	20	433	4075	21293	\N	45.103309000000003	хутор Адагум, Ленина, 47, телефон: 7-54-22		0101000020E6100000E63DCE3461DD4240F530B43A398D4640
45503	2	20	98	50387	21546	\N	46.469511666820502	"Центр отделение № 5 ЗАО ""Новосергиевское"", здание ФП, Пушкина, 16/2, телефон: 37379"	Россия, Краснодарский край, Крыловский район, отделение N5 совхоза Новосергиеский	0101000020E61000002463B5F97F0B44402F8A1EF8183C4740
45499	2	20	98	50245	20453	\N	46.520038382819301	"Центр отделения № 1 ЗАО ""Новосергиевское"", помещение фельдш-го пункта, Центральная, 1/2, телефон: 30309"	Россия, Краснодарский край, Крыловский район, отделение N1 Свсовхоза х Новосергиевский	0101000020E610000057410C74EDE14340B056ED9A90424740
45481	2	20	98	748	20672	\N	46.289498999999999	с. Шевченковское, здание МОУ СОШ № 4, Свердликова, 45, телефон: 33289		0101000020E6100000E8853B1746224440C39CA04D0E254740
45489	2	20	98	48855	21778	\N	46.254147000000003	п. Темп, здание магазина, пер. Парковый, 7, телефон: 38658		0101000020E610000063096B63ECEC434032B08EE387204740
45496	2	20	98	50316	21029	\N	46.414768698962497	х. Тверской, здание МОУ ООШ № 13, Первомайская, 30а, телефон: 37820	Россия, Краснодарский край, Крыловский район, поселок Тверской	0101000020E6100000CE4F711C7821444083328D2617354740
45507	2	20	98	62089	81126	\N	46.478192999999997	"х. Сиротино, здание  СК ""Сиротино"", Ленина, 65, телефон: 39457"	Россия, Краснодарский край, Крыловский район, поселок Сиротино	0101000020E6100000997FF44D9A1C44408B16A06D353D4740
45488	2	20	98	50275	20682	\N	46.243469899092403	х. Сборный, помещение для приема по личным вопросам депутата сельского, Хлеборобная, 60/1, телефон: 38761	Россия, Краснодарский край, Крыловский район, поселок Сборный	0101000020E61000000F99F221A8E2434050C763062A1F4740
45493	2	20	98	1428	21125	\N	46.244839655800298	п. Решетиловский, здание МОУ НОШ № 18, Суворова, 1, телефон: 35927	Россия, Краснодарский край, Крыловский район, поселок Решетиловский	0101000020E61000006440F67AF71344405760C8EA561F4740
45762	2	20	98	126	22468	\N	46.281901317937397	ст. Крыловская, Юбилейная, 6, телефон: 7-61-96	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E6100000A7CB6262F3E54340D7DAFB5415244740
45477	2	20	98	126	23523	\N	46.283239999999999	"ст. Крыловская, здание филиала МУК СДК ""Крыловский"", Чкалова, 33, телефон: 32376"	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E6100000B5C6A01342E74340A375543541244740
45484	2	20	98	126	23412	\N	46.280203735496599	"ст. Октябрьская, здание филиала МУК СДК ""Авангард"", Центральная, 8, телефон: 36920"	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E6100000749A05DA1DE24340AC1A84B9DD234740
45487	2	20	98	126	22074	\N	46.279535881804698	"ст. Октябрьская, здание конторы отделения № 2 ОАО ""Знамя Октябрь"", Трудовая, 347, телефон: 36134"	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E6100000ACFD9DEDD1E14340FF06EDD5C7234740
45508	2	20	98	126	20968	\N	46.283239999999999	ст. Крыловская, здание МОУ СОШ № 1, Первомайская, 86, телефон: 31634		0101000020E6100000B5C6A01342E74340A375543541244740
45763	2	20	98	126	22475	\N	46.282049858922001	ст. Крыловская, Ленина, 9, телефон: 7-63-49	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E6100000F2237EC51AE643401CEBE2361A244740
44576	2	20	98	126	20983	\N	46.279833000000004	станица Октябрьская, улица Красная, 8, телефон: 61-6-98		0101000020E6100000D6C56D3480E14340B9AB5791D1234740
45476	2	20	98	126	20905	\N	46.283239999999999	"ст. Крыловская, здание ДК ""Нива"", Кооперативная, 69, телефон: 31463"		0101000020E6100000B5C6A01342E74340A375543541244740
45486	2	20	98	126	21137	\N	46.279925550085103	"ст. Октябрьская, здание филиала МУК СДК ""Октябрь"", Кондратюка, 198, телефон: 36250"	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E6100000D1CB28965BE243406AA67B9DD4234740
45485	2	20	98	126	21137	\N	46.282748158839098	ст. Октябрьская, здание МОУ СОШ № 6, Кондратюка, 20, телефон: 38474	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E61000000C923EADA2E543403481221631244740
45472	2	20	98	126	21522	\N	46.283239999999999	ст. Крыловская, здание МОУ СОШ № 3, Комсомольская, 162, телефон: 32565		0101000020E6100000B5C6A01342E74340A375543541244740
45474	2	20	98	126	20659	\N	46.283239999999999	"ст. Крыловская, здание ""дом детского творчества"", Кирова, 1, телефон: 32247"		0101000020E6100000B5C6A01342E74340A375543541244740
45482	2	20	98	126	23630	\N	46.2809046416142	"ст. Октябрьская, здание  МУК СДК ""Октябрьский"", пер. Зеленый, 3, телефон: 38498"	Россия, Краснодарский край, Крыловский район, поселок Октябрьская	0101000020E61000001EA8531EDDE243403524EEB1F4234740
45490	2	20	98	1234	20927	\N	46.248930999999999	"п. Обильный, здание  филиала МУК СДК ""Обильный"", Лермонтова, 18, телефон: 39920"		0101000020E610000083F8C08EFFF64340F4FA93F8DC1F4740
45498	2	20	98	50335	21153	\N	46.467762168829303	"ст. Новосергиевская,здание филиала МУК СДК ""Новосергиевский"", Школьная, 8, телефон: 34245"	Россия, Краснодарский край, Крыловский район, поселок Новосергиевская	0101000020E61000000ED8D5E429F94340E1270EA0DF3B4740
45500	2	20	98	50335	21794	\N	46.469007579982602	"Центр отделения № 2 ЗАО ""Новосергиевское"", здание ФП, Красная, 12/2, телефон: 36679"	Россия, Краснодарский край, Крыловский район, поселок Новосергиевская	0101000020E61000005C001AA54BF94340FCC74274083C4740
45494	2	20	98	1484	23015	\N	46.409425670492297	ст. Новопашковская, здание МОУ СОШ № 8, Первомайская, 43, телефон: 37260	Россия, Краснодарский край, Крыловский район, поселок Новопашковская	0101000020E61000003D0E83F92B0A4440E910381268344740
45504	2	20	98	2056	22253	\N	46.532361999999999	ст. Кугоейская, здание МОУ СОШ № 10, Ленина, 49а, телефон: 33844		0101000020E6100000FB75A73B4F0C44400BD1217024444740
45761	2	20	98	50471	22165	\N	46.321930296048997	ст. Крыловская, Энгельса, 138, телефон: 7-70-58		0101000020E610000010B3976DA7F94340F7CC920035294740
45480	2	20	98	50471	22709	\N	46.323690660919901	ст. Крыловская, здание офиса врача общей практики, Халтурина, 35, телефон: 31244	Россия, Краснодарский край, Крыловский район, поселок Крыловская	0101000020E6100000056EDDCD53FB43403881E9B46E294740
45479	2	20	98	50471	22341	\N	46.326574576808497	"ст. Крыловская, здание конторы МУП ""Водоканал"", Орджоникидзе, 145, телефон: 31946"	Россия, Краснодарский край, Крыловский район, поселок Крыловская	0101000020E61000007D08AA46AFFA43407958A835CD294740
45475	2	20	98	50471	22341	\N	46.321668855459698	ст. Крыловская, здание МОУ СОШ № 2, Орджоникидзе, 41, телефон: 31294	Россия, Краснодарский край, Крыловский район, поселок Крыловская	0101000020E6100000533C2EAA45FC43408A9125732C294740
45492	2	20	98	48908	21784	\N	46.247304	п. Ковалевка, здание МОУ НОШ № 17, Фермерская, 7, телефон: 35865		0101000020E6100000D7338463960B4440C21550A8A71F4740
45501	2	20	98	49064	21833	\N	46.480229000000001	п. Ключевой, здание сельского клуба, Черемушки, 1, телефон: 34166		0101000020E61000001BA19FA9D7F143409FCBD424783D4740
44420	2	20	98	50307	20973	\N	46.530004425145698	пос. Калинин, пер. Школьный, 1, телефон: 26888	Россия, Краснодарский край, Крыловский район, поселок Калинин	0101000020E61000001FF5D72B2C184440E55FCB2BD7434740
45506	2	20	98	50307	22340	\N	46.531373816668498	х. Калинин, здание ФП, Калинина, 69а, телефон: 33819	Россия, Краснодарский край, Крыловский район, поселок Калинин	0101000020E610000056D3F544D7174440ECF82F1004444740
45505	2	20	98	49122	20964	\N	46.539788999999999	"с. Ириновка, здание сельского клуба ""Ириновка"", Мира, 12, телефон: 33998"		0101000020E6100000A8C821E2E6004440CADE52CE17454740
45491	2	20	98	48888	21122	\N	46.250165000000003	п. Запрудный, здание МОУ НОШ № 16, Советская, 1, телефон: 35819		0101000020E6100000922232ACE2FF43404BCD1E6805204740
45497	2	20	98	48983	22326	\N	46.409911000000001	с. Грузское, здание фельдшерского пункта, Трудовая, 13а, телефон: 37276		0101000020E610000082E7DEC325194440A5A2B1F677344740
45502	2	20	98	1922	21439	\N	46.471781999999997	п. Водораздельный, здание фельдшерского пункта, Центральная, 7/3, телефон: 34311		0101000020E610000093AAED26F8024440B56B425A633C4740
45145	2	20	1322	32734	20963	\N	45.337102000000002	поселок Элитный, ул.Садовая, 5, телефон: 93-5-89		0101000020E6100000DC4AAFCDC610434046B5882826AB4640
45124	2	20	1322	15828	22818	\N	45.237453477655301	хутор Чигрина, ул.Центральная, 5, телефон: 99-9-67	Россия, Краснодарский край, Красноармейский район, хутор Чигрина	0101000020E6100000F984ECBC8D15434026AB22DC649E4640
45138	2	20	1322	16519	21577	\N	45.556271000000002	станица Чебургольская, ул.Школьная, 2, телефон: 93-2-44		0101000020E6100000B857E6ADBA0C43404B5B5CE333C74640
45121	2	20	1322	15589	20881	\N	45.280109000000003	хутор Трудобеликовский, ул.Школьная, 1, телефон: 99-8-44		0101000020E61000004B3CA06CCA1143405B28999CDAA34640
45119	2	20	1322	15589	20881	\N	45.280109000000003	хутор Трудобеликовский, ул.Школьная, 1, телефон: 99-1-82		0101000020E61000004B3CA06CCA1143405B28999CDAA34640
45122	2	20	1322	15589	21561	\N	45.280109000000003	хутор Трудобеликовский, ул.Садовая, 70, телефон: 49-0-36		0101000020E61000004B3CA06CCA1143405B28999CDAA34640
45120	2	20	1322	15589	21549	\N	45.280109000000003	хутор Трудобеликовский, ул.Набережная, 387/3, телефон: 99-8-78		0101000020E61000004B3CA06CCA1143405B28999CDAA34640
45123	2	20	1322	15589	22643	\N	45.272481010103803	хутор Трудобеликовский, ул.Мазуренко, 58, телефон: 99-4-95	Россия, Краснодарский край, Красноармейский район, поселок Трудобеликовский	0101000020E610000054FEB5BC7213434004E44BA8E0A24640
45125	2	20	1322	15901	23004	\N	45.192324999999997	хутор Тиховский, ул.Школьная, 25, телефон: 92-7-68	Россия, Краснодарский край, Красноармейский район, поселок Тиховский	0101000020E6100000AC1F9BE4471C4340029A081B9E984640
45148	2	20	1322	17060	20697	\N	45.385972000000002	станица Старонижестеблиевская, ул.Северная, 30, телефон: 97-7-11		0101000020E6100000FA2B64AE0C384340FB95CE8767B14640
45152	2	20	1322	17060	21196	\N	45.385099451944903	станица Старонижестеблиевская, ул.Мира, 56, телефон: 97-1-89	Россия, Краснодарский край, Красноармейский район, поселок Старонижестеблиевская	0101000020E6100000404B57B08D384340745C8DEC4AB14640
45150	2	20	1322	17060	21196	\N	45.3869382404988	станица Старонижестеблиевская, ул.Мира, 179, телефон: 97-2-15	Россия, Краснодарский край, Красноармейский район, поселок Старонижестеблиевская	0101000020E6100000FBCC599F7238434032CA332F87B14640
45149	2	20	1322	17060	21196	\N	45.387168451511599	станица Старонижестеблиевская, ул.Мира, 174, телефон: 97-3-51	Россия, Краснодарский край, Красноармейский район, поселок Старонижестеблиевская	0101000020E6100000289EB30584384340640795B88EB14640
45151	2	20	1322	17060	20758	\N	45.385972000000002	станица Старонижестеблиевская, ул.Батарейная, 4, телефон: 97-4-74		0101000020E6100000FA2B64AE0C384340FB95CE8767B14640
45140	2	20	1322	16649	20739	\N	45.466256000000001	станица Староджерелиевская, ул.Красная, 102/А, телефон: 95-3-37		0101000020E61000001E6D1CB1162543402AC8CF46AEBB4640
45141	2	20	1322	16649	22906	\N	45.4678232537726	станица Староджерелиевская, ул.Дружбы, 9, телефон: 95-3-53	Россия, Краснодарский край, Красноармейский район, поселок Староджерелиевская	0101000020E610000020F12BD67025434087A8C29FE1BB4640
45114	2	20	1322	15385	20949	\N	45.227705999999998	поселок Рисоопытный, ул.Мира, 1, телефон: 92-2-15		0101000020E61000001B9B1DA9BE2743402E8D5F78259D4640
45139	2	20	1322	16597	21181	\N	45.523009000000002	хутор Протоцкие, ул.Набережная, 50, телефон: 95-6-30		0101000020E6100000A452EC681C0A4340C0417BF5F1C24640
45142	2	20	1322	16763	21810	\N	45.376880999999997	хутор Протичка, ул.Красная, 44, телефон: 93-3-18		0101000020E6100000D65757056A094340ECBDF8A23DB04640
45105	2	20	1322	50640	23189	\N	45.112145053819397	хутор Прикубанский, ул.Центральная, 46, телефон: 98-1-30	Россия, Краснодарский край, Красноармейский район, поселок Прикубанский	0101000020E6100000B1A206D3303E434078B471C45A8E4640
45094	2	20	1322	14023	23510	\N	45.353449302697101	станица Полтавская, ул.Элеваторная, 60/2, телефон: 3-16-27		0101000020E610000010E9B7AF031D4340E6E61BD13DAD4640
45086	2	20	1322	14023	20420	\N	45.366390000000003	станица Полтавская, ул.Школьная, 9, телефон: 3-35-23		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45096	2	20	1322	14023	20903	\N	45.366390000000003	станица Полтавская, улица Шевченко, 3, телефон: 3-18-35		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45100	2	20	1322	14023	23979	\N	45.369173029613002	станица Полтавская, ул.Центральная, 60, телефон: 3-27-64	Россия, Краснодарский край, Красноармейский район, поселок Полтавская	0101000020E6100000E01115AA9B1B43407AC8940F41AF4640
45087	2	20	1322	14023	21086	\N	45.351137554356299	станица Полтавская, ул.Таманская, 148/А, телефон: 3-15-95	Россия, Краснодарский край, Красноармейский район, поселок Полтавская	0101000020E6100000C87C40A0331B434001310917F2AC4640
14057	1	17	\N	3130	22866	\N	58.045848999999997	г. Рыбинск, Пятилетки, 27		0101000020E6100000B3614D65516C4340F3C64961DE054D40
45091	2	20	1322	14023	21301	\N	45.366390000000003	станица Полтавская, ул.Просвещения, 198, телефон: 3-28-31		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45099	2	20	1322	14023	23471	\N	45.364211833001299	станица Полтавская, ул.Народная, 3, телефон: 3-32-92	Россия, Краснодарский край, Красноармейский район, поселок Полтавская	0101000020E6100000CCB4FD2B2B1B4340C767B27F9EAE4640
45095	2	20	1322	14023	23471	\N	45.366390000000003	станица Полтавская, ул.Народная, 157, телефон: 4-35-94	Россия, Краснодарский край, Красноармейский район, поселок Полтавская	0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45092	2	20	1322	14023	23733	\N	45.366390000000003	станица Полтавская, ул.Ленина, 247 владение 1, телефон: 3-17-19	Россия, Краснодарский край, Красноармейский район, поселок Полтавская	0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45093	2	20	1322	14023	20425	\N	45.366390000000003	станица Полтавская, ул.Красная, 39, телефон: 3-16-65		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45089	2	20	1322	14023	20425	\N	45.366390000000003	станица Полтавская, ул.Красная, 194, телефон: 3-37-19		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45088	2	20	1322	14023	20425	\N	45.366390000000003	станица Полтавская, ул.Красная, 145, телефон: 3-20-88		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45090	2	20	1322	14023	21415	\N	45.366390000000003	станица Полтавская, ул.Комсомольская, 29, телефон: 3-28-21		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45098	2	20	1322	14023	20475	\N	45.366390000000003	станица Полтавская, ул. Жлобы, 60/А, телефон: 3-38-33		0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45097	2	20	1322	14023	20475	\N	45.366390000000003	станица Полтавская, ул.Жлобы, 78, телефон: 3-13-55	Россия, Краснодарский край, Красноармейский район, поселок Полтавская	0101000020E6100000815CE2C8031B43406DCA15DEE5AE4640
45118	2	20	1322	46110	20687	\N	45.201414	поселок Подлесный, ул.Кольцевая, 9, телефон: 46-0-64		0101000020E6100000C3D7D7BAD42A4340707A17EFC7994640
45855	2	20	1322	47108	21369	\N	45.177979999999998	п.Первомайский, ул.Мира, 15, телефон: 2-21-21		0101000020E610000071AFCC5B75274340C9AB730CC8964640
45613	2	20	1322	50376	21462	\N	45.232958426653099	поселок Октябрьский, Октябрьская, 7, телефон: 6-62-82	Россия, Краснодарский край, Красноармейский район, поселок Октябрьский	0101000020E61000000C74ED0BE8254340B9AB5791D19D4640
45103	2	20	1322	14725	20469	\N	45.198231999999997	станица Новомышастовская, ул.Красная, 52, телефон: 98-3-70		0101000020E61000006EC1525DC0494340A5828AAA5F994640
45102	2	20	1322	14725	20469	\N	45.198231999999997	станица Новомышастовская, ул.Красная, 81, телефон: 98-2-55		0101000020E61000006EC1525DC0494340A5828AAA5F994640
45101	2	20	1322	14725	21316	\N	45.198231999999997	станица Новомышастовская, ул.Гагарина, 15, телефон: 98-2-47		0101000020E61000006EC1525DC0494340A5828AAA5F994640
44871	2	20	1322	45742	\N	\N	45.249716999999997	пос. Мирный, Комарова, 22, телефон: 63226	Россия, Краснодарский край, Красноармейский район, поселок Мирный	0101000020E6100000D6E1E82ADD294340AB2006BAF69F4640
46619	2	20	1322	45742	23445	\N	45.247909148739701	хутор Мирный, Космонавтов, 16, телефон: 9-20-76	Россия, Краснодарский край, Красноармейский район, поселок Мирный	0101000020E610000065A9F57EA329434029B16B7BBB9F4640
45048	2	20	1322	45742	20598	\N	45.249716999999997	Мирный поселок, Клубная, 6, телефон: 2-66-43		0101000020E6100000D6E1E82ADD294340AB2006BAF69F4640
45137	2	20	1322	16281	20511	\N	45.104970000000002	станица Марьянская, ул.Шевченко, 43, телефон: 96-5-62		0101000020E6100000AEF02E17F1514340D3872EA86F8D4640
45133	2	20	1322	16281	20504	\N	45.104970000000002	станица Марьянская, ул.Соболя, 2, телефон: 96-3-75		0101000020E6100000AEF02E17F1514340D3872EA86F8D4640
45134	2	20	1322	16281	20994	\N	45.104970000000002	станица Марьянская, ул.Пионерская, 55, телефон: 96-2-99	Россия, Краснодарский край, Красноармейский район, поселок Марьянская	0101000020E6100000AEF02E17F1514340D3872EA86F8D4640
45136	2	20	1322	16281	20980	\N	45.100350461011097	станица Марьянская, ул.Ленина, 54, телефон: 96-2-41	Россия, Краснодарский край, Красноармейский район, поселок Марьянская	0101000020E61000004E9B711AA2524340A913D044D88C4640
45135	2	20	1322	16281	21173	\N	45.104970000000002	станица Марьянская, ул.Красная, 24, телефон: 96-4-12		0101000020E6100000AEF02E17F1514340D3872EA86F8D4640
45126	2	20	1322	15924	21994	\N	45.264150999999998	хутор Крикуна, ул.Молодежная, 1/А, телефон: 92-4-32		0101000020E61000001898158A741B4340541A31B3CFA14640
45117	2	20	1322	15524	20931	\N	45.180477000000003	поселок Красный Лес, ул.Октябрьская, 30, телефон: 91-6-40		0101000020E6100000228B34F10E3443401157CEDE19974640
45108	2	20	1322	15087	20925	\N	45.283813000000002	поселок Краснодарский, ул.Центральная, 7, телефон: 44-1-69		0101000020E61000005E82531F48284340FF9600FC53A44640
45116	2	20	1322	46052	20455	\N	45.149141	поселок Колос, ул.Первомайская, 3, телефон: 46-7-32		0101000020E6100000117008556A2C434012BF620D17934640
45144	2	20	1322	16838	21152	\N	45.413336999999999	поселок Казачий Ерик, ул.Рисовая, 9, телефон: 93-4-76		0101000020E61000001C08C902260C4340069D103AE8B44640
45132	2	20	1322	50416	21710	\N	45.272466999999999	станица Ивановская, ул.Пионерская, 12, телефон: 94-2-52		0101000020E6100000FE7DC685033B43409F1EDB32E0A24640
45129	2	20	1322	46321	21382	\N	45.272466999999999	станица Ивановская, ул.Черноморская, 86, телефон: 94-2-79		0101000020E6100000FE7DC685033B43409F1EDB32E0A24640
45127	2	20	1322	46321	22259	\N	45.272466999999999	станица Ивановская, ул.Советская, 28, телефон: 94-5-09		0101000020E6100000FE7DC685033B43409F1EDB32E0A24640
45128	2	20	1322	46321	21847	\N	45.272466999999999	станица Ивановская, ул.Ленина, 31, телефон: 94-1-43		0101000020E6100000FE7DC685033B43409F1EDB32E0A24640
45131	2	20	1322	46321	20441	\N	45.272466999999999	станица Ивановская, ул.Красная, 28, телефон: 94-3-01		0101000020E6100000FE7DC685033B43409F1EDB32E0A24640
45130	2	20	1322	46321	20441	\N	45.272466999999999	станица Ивановская, ул.Красная, 84, телефон: 94-2-50		0101000020E6100000FE7DC685033B43409F1EDB32E0A24640
45143	2	20	1322	16814	21545	\N	45.334744999999998	поселок Заветное, ул.Кирова, 25, телефон: 93-3-15		0101000020E610000027A25F5B3F094340F0BF95ECD8AA4640
46504	2	20	1322	40471	20526	\N	45.352071000000002	поселок Восточный, улица Пролетарская, дом 17, телефон: 6 91 21		0101000020E6100000D53C47E4BB3C43405D6F9BA910AD4640
45614	2	20	1322	40471	20737	\N	45.352071000000002	поселок Восточный, Матросова, 2, телефон: 6-63-44		0101000020E6100000D53C47E4BB3C43405D6F9BA910AD4640
45352	2	20	1322	50257	\N	\N	45.079254032594697	поселок Белозерный, 17/1, телефон: 229-50-31	Россия, Краснодарский край, Красноармейский район, поселок Белозерный	0101000020E61000006649809A5A564340E109BDFE248A4640
46012	2	20	6957	50785	23595	\N	44.938141883430802	352289 х. Чехрак, ул. Шоссейная 2А	Россия, Краснодарский край, Кошехаблинский район, поселок Чехрак	0101000020E6100000A8C7B60C3831444084807C0915784640
45817	2	20	6957	46308	23369	\N	44.902721999999997	п.Комсомольский, ул.Центральная, 15, телефон: 2-96-41		0101000020E6100000CEDF8442043644409AB0FD648C734640
45074	2	20	6957	46308	23369	\N	44.902721999999997	Комсомольский поселок, Центральная, 13, телефон: 96-1-90		0101000020E6100000CEDF8442043644409AB0FD648C734640
44782	2	20	6957	46308	21617	\N	44.902721999999997	пос. Комсомольский, ул. Кирова, (здание Дома культуры), 2, телефон: 2-81-31		0101000020E6100000CEDF8442043644409AB0FD648C734640
44947	2	20	6957	46308	21596	\N	44.902721999999997	поселок Комсомольский, Азовская, 19, телефон: 56-6-70		0101000020E6100000CEDF8442043644409AB0FD648C734640
46822	2	20	6957	46573	20735	\N	44.618208000000003	село Вольное, Школьная, 24, телефон: 69120		0101000020E6100000BD344580D359444013109370214F4640
45085	2	20	1193	49337	23858	\N	45.424945999999998	Сергиевская станица, Красная, 46В, телефон: 98-0-91	Россия, Краснодарский край, Кореновский район, поселок Сергиевская	0101000020E610000006B8205B9699434073486AA164B64640
45061	2	20	1193	49337	20753	\N	45.424720808118501	Сергиевская станица, Айвазяна, 48, телефон: 98-6-92	Россия, Краснодарский край, Кореновский район, поселок Сергиевская	0101000020E61000002AC8CF46AE9943405376FA415DB64640
45052	2	20	1193	49211	23488	\N	45.379253483051798	Раздольная станица, Фрунзе, 36, телефон: 21-1-74	Россия, Краснодарский край, Кореновский район, поселок Раздольная	0101000020E6100000797764AC36C9434077F4BF5C8BB04640
45051	2	20	1193	49211	22071	\N	45.376350000000002	Раздольная станица, Фрунзе, 38, телефон: 21-2-22		0101000020E610000017F2086EA4C84340C0EC9E3C2CB04640
45056	2	20	1193	12571	20849	\N	45.39284	Платнировская станица, Третьякова, 111, телефон: 71-1-46		0101000020E6100000BC77D49810B14340C347C49448B24640
45058	2	20	1193	12571	21058	\N	45.39284	Платнировская станица, Пролетарская, 36, телефон: 71-7-53		0101000020E6100000BC77D49810B14340C347C49448B24640
45057	2	20	1193	12571	21058	\N	45.39284	Платнировская станица, Пролетарская, 36, телефон: 71-6-82		0101000020E6100000BC77D49810B14340C347C49448B24640
45054	2	20	1193	12571	21262	\N	45.39284	Платнировская станица, Красная, 30, телефон: 7-12-00		0101000020E6100000BC77D49810B14340C347C49448B24640
45055	2	20	1193	50465	22103	\N	45.39284	Платнировская станица, Красная, 27, телефон: 7-12-32		0101000020E6100000BC77D49810B14340C347C49448B24640
45071	2	20	1193	13330	21068	\N	45.695239999999998	Новоберезанский поселок, Пионерская, 9, телефон: 51-1-41		0101000020E6100000ABCFD556ECB943407E6FD39FFDD84640
45060	2	20	1193	50904	24039	\N	45.4005325789322	Нижний хутор, Северная, 19, телефон: 76-1-39	Россия, Краснодарский край, Кореновский район, поселок Нижний	0101000020E6100000651BB803759C434001FC53AA44B34640
44726	2	20	1193	47524	21374	\N	45.493941999999997	поселок Мирный, Партизанская, 26, телефон: 5-32-24		0101000020E6100000116F9D7FBBC64340770FD07D39BF4640
45059	2	20	1193	50687	23391	\N	45.399619181179602	Левченко хутор, Центральная, 7, телефон: 76-3-30	Россия, Краснодарский край, Кореновский район, поселок Левченко	0101000020E61000004CA94BC631A243401CEE23B726B34640
45045	2	20	1193	11444	21195	\N	45.462083999999997	Кореновск город, Школьная, 7, телефон: 3-83-28		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45066	2	20	1193	11444	20611	\N	45.462083999999997	Кореновск город, Фрунзе, 180Г, телефон: 4-62-50		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45043	2	20	1193	11444	20583	\N	45.462083999999997	Кореновск город, Маяковского, 8, телефон: 3-60-00		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45083	2	20	1193	11444	20936	\N	45.462083999999997	Кореновск город, Матросова, 6Б, телефон: 4-58-88		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45032	2	20	1193	11444	20936	\N	45.462083999999997	Кореновск город, Матросова, 11, телефон: 4-25-03		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45077	2	20	1193	11444	20891	\N	45.462083999999997	Кореновск город, Маркса, 318А, телефон: 3-09-48		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45035	2	20	1193	11444	20891	\N	45.462083999999997	Кореновск город, Маркса, 215, телефон: 4-54-76		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45037	2	20	1193	11444	21345	\N	45.462083999999997	Кореновск город, Красная, 29, телефон: 4-54-48		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45038	2	20	1193	11444	20832	\N	45.462083999999997	Кореновск город, Коммунаров, 107, телефон: 4-15-30		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45042	2	20	1193	11444	20582	\N	45.462083999999997	Кореновск город, Заводская, 3, телефон: 4-50-68		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45034	2	20	1193	50348	21253	\N	45.462083999999997	Кореновск город, Октябрьская, 1, телефон: 4-02-10		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45039	2	20	1193	50348	22539	\N	45.462083999999997	Кореновск город, Лиманский переулок, 19, телефон: 4-16-40		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45040	2	20	1193	50348	21251	\N	45.462083999999997	Кореновск город, Красная, 5, телефон: 4-44-95		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45036	2	20	1193	50348	21251	\N	45.465937343076497	Кореновск город, Красная, 126, телефон: 4-50-57		0101000020E6100000CE4F711C78B94340887FD8D2A3BB4640
45044	2	20	1193	50348	21465	\N	45.462083999999997	Кореновск город, Клубная, 5, телефон: 3-86-61		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45046	2	20	1193	50348	21257	\N	45.462083999999997	Кореновск город, Запорожская, 12, телефон: 3-60-12		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45081	2	20	1193	50348	21481	\N	45.462083999999997	Кореновск город, Выселковская, 29А, телефон: 4-14-26		0101000020E610000040DEAB5626BA43409F008A9125BB4640
45478	2	20	1193	50298	20907	\N	45.385969945406202	"х. Казачий, здание филиала МУК СК ""Казачий"", Казачья, 50, телефон: 39424"	Россия, Краснодарский край, Кореновский район, поселок Казачий	0101000020E61000001077F52A32B843405A9E077767B14640
45053	2	20	1193	50474	22221	\N	45.561262999999997	Казачий хутор, Золотарева, 26, телефон: 7-13-13		0101000020E610000077F52A323AB2434038BA4A77D7C74640
45076	2	20	1193	13551	20888	\N	45.531647	Казаче-Малеваный хутор, Лунева, 63, телефон: 26-3-48		0101000020E6100000A1F65B3B51C643401D0247020DC44640
45068	2	20	1193	50622	23054	\N	45.586902000000002	Журавский хутор, Южная, 64, телефон: 92-2-47	Россия, Краснодарский край, Кореновский район, поселок Журавский	0101000020E61000004E266E15C4AA43407FFACF9A1FCB4640
45075	2	20	1193	13523	21496	\N	45.577806000000002	Журавская станица, Северная, 68, телефон: 25-1-68		0101000020E610000020240B98C0C743405FB7088CF5C94640
45062	2	20	1193	50583	22883	\N	45.554660655977102	"Дядьковская станица, Пролетарская, здание конторы АК ""Кубань-Люкс"", телефон: 66-2-82"		0101000020E6100000F5A0A014AD984340EFAEB321FFC64640
45063	2	20	1193	12907	20602	\N	45.551524999999998	Дядьковская станица, Советская, 42, телефон: 66-2-08		0101000020E6100000E0DBF4673F98434094F6065F98C64640
45064	2	20	1193	12907	20606	\N	45.551524999999998	Дядьковская станица, Ленина, 24, телефон: 66-4-04		0101000020E6100000E0DBF4673F98434094F6065F98C64640
45050	2	20	1193	12383	22070	\N	45.460180999999999	Бураковский хутор, Гагарина, 5, телефон: 27-3-85		0101000020E6100000261B0FB6D8CD4340CB9E0436E7BA4640
45069	2	20	1193	13245	22625	\N	45.638579999999997	Братковское село, Школьная, 1А, телефон: 92-6-61		0101000020E61000007920B24813AB434099F04BFDBCD14640
45070	2	20	1193	13245	20617	\N	45.638579999999997	Братковское село, Центральная, 81, телефон: 92-6-40		0101000020E61000007920B24813AB434099F04BFDBCD14640
45065	2	20	1193	13047	23896	\N	45.547866044668098	Бабиче-Кореновский хутор, Мира, 109, телефон: 2-32-80	Россия, Краснодарский край, Кореновский район, поселок Бабиче-Кореновский	0101000020E6100000240C03965CAB4340904B1C7920C64640
45072	2	20	1193	13367	20507	\N	45.781233999999998	Анапский поселок, Партизанская, 142А, телефон: 55-7-22		0101000020E6100000596C938AC6BE4340FA42C879FFE34640
45536	2	20	5147	39762	20572	\N	59.865122	хутор Павловский, Новая, 2, телефон: 7-94-12		0101000020E6100000E3A430EF71963F406A865451BCEE4D40
46611	2	20	7084	50580	22867	\N	45.0219227014545	хутор Ленинский, Центральная, 128, телефон: 6-10-29	Россия, Краснодарский край, Краснодар, Карасунский район, улица Центральная	0101000020E61000008B8BA37213894340DE03745FCE824640
45024	2	20	1033	40520	10085	\N	45.978130648842502	Краснодарский край, Каневский район, ст.Челбасская, Красная, 75, телефон: 6-27-70		0101000020E610000012C0CDE2C5AE4340151A886533FD4640
45007	2	20	1033	50241	20415	\N	45.994255000000003	Краснодарский край, Каневский район, ст.Придорожная, Красная, 40, телефон: 3-81-22		0101000020E61000006E895C70067D4340377172BF43FF4640
45018	2	20	1033	10778	22498	\N	45.978130999999998	Краснодарский край, Каневский район, ст.Челбасская, пер. Гоголя, 1, телефон: 6-31-88		0101000020E6100000FCC22B499EAF4340151A886533FD4640
45017	2	20	1033	10778	20806	\N	45.978130999999998	Краснодарский край, Каневский район, ст.Челбасская, Партизанская, 1, телефон: 6-31-25		0101000020E6100000FCC22B499EAF4340151A886533FD4640
45016	2	20	1033	10778	9706	\N	45.978130999999998	Краснодарский край, Каневский район, ст.Челбасская, Красная, 75, телефон: 6-34-14		0101000020E6100000FCC22B499EAF4340151A886533FD4640
45023	2	20	1033	50722	23461	\N	46.203818720812301	Краснодарский край, Каневский район, х.Ударный, Алтайская, 10 А, телефон: 6-86-53	Россия, Краснодарский край, Каневский район, поселок Ударный	0101000020E61000009AB1683A3B814340D7A6B1BD161A4740
45006	2	20	1033	50748	23522	\N	46.155666247440998	Краснодарский край, Каневский район, х.Труд, Длинная, 32, телефон: 3-79-31	Россия, Краснодарский край, Каневский район, поселок Труд	0101000020E61000008655BC9179444340B08C0DDDEC134740
44990	2	20	1033	50807	23686	\N	45.974455138304798	Краснодарский край, Каневский район, х. Сухие Челбасы, Северная, 38, телефон: 3-74-84		0101000020E61000007094BC3AC79643403B3602F1BAFC4640
45022	2	20	1033	11040	20574	\N	45.941648999999998	Краснодарский край, Каневский район, пос.Степной, Широкая, 2 А, телефон: 3-99-28		0101000020E61000006C7BBB2539944340D2A755F487F84640
45011	2	20	1033	10437	21793	\N	46.133096000000002	Краснодарский край, Каневский район, ст.Стародеревянковская, Лиманская, 23, телефон: 6-43-15		0101000020E6100000DF6FB4E3867B43403D9D2B4A09114740
45030	2	20	1033	10437	20556	\N	46.133096000000002	Краснодарский край, Каневский район, Стародеревянковская, Красная, 126 Б, телефон: 6-87-24		0101000020E6100000DF6FB4E3867B43403D9D2B4A09114740
45009	2	20	1033	10437	20556	\N	46.133096000000002	Краснодарский край, Каневский район, ст.Стародеревянковская, Красная, 82, телефон: 6-40-99		0101000020E6100000DF6FB4E3867B43403D9D2B4A09114740
45010	2	20	1033	10437	20491	\N	46.133096000000002	Краснодарский край, Каневский район, ст.Стародеревянковская, Коммунаров, 30, телефон: 6-42-23		0101000020E6100000DF6FB4E3867B43403D9D2B4A09114740
45012	2	20	1033	10437	22492	\N	46.133096000000002	Краснодарский край, Каневский район, ст.Стародеревянковская, Кирова, 24, телефон: 6-93-91		0101000020E6100000DF6FB4E3867B43403D9D2B4A09114740
44991	2	20	1033	50719	23454	\N	46.050285051328999	Краснодарский край, Каневской район, х. Средние Челбасы, Центральная, 18, телефон: 3-92-49	Россия, Краснодарский край, Каневский район, поселок Сред. Челбасы	0101000020E610000093A8177C9A9543405C3D27BD6F064740
45013	2	20	1033	50758	23539	\N	46.183444660230101	Краснодарский край, Каневский район, х.Сладкий Лиман, Широкая, 116, телефон: 3-76-17	Россия, Краснодарский край, Каневский район, поселок Сладкий Лиман	0101000020E6100000F2423A3C84654340AFCE31207B174740
45078	2	20	1033	50446	21972	\N	46.291770392327898	Раздольный поселок, Труда, 1, телефон: 52-0-24		0101000020E610000088D9CBB6D34E43401AFA27B858254740
44998	2	20	1033	50446	23207	\N	46.293674316434497	Краснодарский край, Каневский район, х. Раздольный, Светлая, 97,	Россия, Краснодарский край, Каневский район, поселок Раздольный	0101000020E610000040DCD5ABC84E4340BFD7101C97254740
44997	2	20	1033	50304	20961	\N	46.199518197165297	Краснодарский край, Каневской район, х. Приютный, Кондруцкого, 64 Г, телефон: 3-87-85	Россия, Краснодарский край, Каневский район, поселок Приютный	0101000020E61000003F7100FDBE5B43404E7B4ACE89194740
45004	2	20	1033	50423	21743	\N	46.139360000000003	Краснодарский край, Каневский район, ст.Привольная, Мира, 66, телефон: 4-88-98		0101000020E610000034D593F9475943406F2F698CD6114740
14049	1	17	\N	3130	22684	\N	58.045848999999997	г. Рыбинск, Пушкина, 53		0101000020E6100000B3614D65516C4340F3C64961DE054D40
45005	2	20	1033	10142	20546	\N	46.139360000000003	Краснодарский край, Каневский район, ст.Привольная, Мира, 66, телефон: 4-87-88		0101000020E610000034D593F9475943406F2F698CD6114740
45008	2	20	1033	10363	21210	\N	45.931801999999998	Краснодарский край, Каневский район, пос.Партизанский, Красноармейская, 4, телефон: 3-89-57		0101000020E6100000DF347D76C0834340772CB64945F74640
45021	2	20	1033	50668	23333	\N	46.127078745814998	Краснодарский край, Каневский район, х.Орджоникидзе, Светлая, 15, телефон: 39-0-48	Россия, Краснодарский край, Каневский район, поселок Орджоникидзе	0101000020E6100000A8C4758C2B6443401381EA1F44104740
45000	2	20	1033	9984	20774	\N	46.314017	Краснодарский край, Каневский район, ст.Новоминская, пер. Вольный, 41 А, телефон: 7-62-04		0101000020E61000003788D68A367B4340ABB184B531284740
45029	2	20	1033	9984	20576	\N	46.314017	Краснодарский край, Каневский район, Новоминская, Ленина, 25, телефон: 7-61-05		0101000020E61000003788D68A367B4340ABB184B531284740
45003	2	20	1033	9984	20576	\N	46.314017	Краснодарский край, Каневский район, ст. Новоминская, Ленина, 25, телефон: 7-61-05		0101000020E61000003788D68A367B4340ABB184B531284740
45002	2	20	1033	9984	20576	\N	46.314017	Краснодарский край, Каневский район, ст. Новоминская, Ленина, 25 А, телефон: 7-65-26		0101000020E61000003788D68A367B4340ABB184B531284740
45001	2	20	1033	9984	21430	\N	46.314017	Краснодарский край, Каневский район, ст.Новоминская, Дружбы, 49, телефон: 7-61-08		0101000020E61000003788D68A367B4340ABB184B531284740
45027	2	20	1033	9683	20480	\N	46.3208083342181	Краснодарский край, Каневский район, ст.Новодеревянковская, Мира, 50, телефон: 4-63-61	Россия, Краснодарский край, Каневский район, поселок Новодеревянковская	0101000020E6100000F931E6AE25604340C8258E3C10294740
44996	2	20	1033	9683	20480	\N	46.319619000000003	Краснодарский край, Каневской район, ст. Новодеревянковская, Мира, 22, телефон: 4-62-63		0101000020E6100000736891ED7C5F434012178046E9284740
44995	2	20	1033	9683	20480	\N	46.319619000000003	Краснодарский край, Каневский район, ст. Новодеревянковская, Мира, 1, телефон: 4-61-36		0101000020E6100000736891ED7C5F434012178046E9284740
45028	2	20	1033	9683	23807	\N	46.319619000000003	Краснодарский край, Каневский район, Новодеревянковская, Восточная, 4, телефон: 4-67-76	Россия, Краснодарский край, Каневский район, поселок Новодеревянковская	0101000020E6100000736891ED7C5F434012178046E9284740
45014	2	20	1033	50744	23515	\N	46.154651534757697	Краснодарский край, Каневский район, х.Мигуты, Охотничья, 17, телефон: 3-98-41	Россия, Краснодарский край, Каневский район, поселок Мигуты	0101000020E610000094F947DFA48F4340682101A3CB134740
44994	2	20	1033	9670	21024	\N	45.963523000000002	Краснодарский край, Каневский район, пос. Кубанская степь, Центральная, 75, телефон: 3-71-43		0101000020E6100000F8A92A34109D4340CFF8BEB854FB4640
44992	2	20	1033	9535	20587	\N	46.156412000000003	Краснодарский край, Каневский район, пос. Красногвардеец, Красная, 3, телефон: 3-97-94		0101000020E6100000FFCBB56801964340DA59F44E05144740
44989	2	20	1033	\N	23596	\N	46.138505000000002	Краснодарский край, Каневский район, Широкая, 109, телефон: 7-98-66	Россия, Краснодарский край, Каневский район	0101000020E6100000CBD58F4DF28143408FAA2688BA114740
45025	2	20	1033	9000	22027	\N	46.086399	Краснодарский край, Каневский район, ст. Каневская, Элеваторная, 8, телефон: 7-16-04		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
44985	2	20	1033	9000	20468	\N	46.086399	Краснодарский край, Каневской район, ст. Каневская, Чипигинская, 125, телефон: 4-50-61		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
44979	2	20	1033	9000	21923	\N	46.086399	Краснодарский край, Каневской район, ст. Каневская, Чигиринская, 72, телефон: 7-14-05		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
44980	2	20	1033	9000	22398	\N	46.086399	Краснодарский край, Каневский район, ст. Каневская, Таманская, 104, телефон: 7-90-98		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
45019	2	20	1033	9000	20807	\N	46.086399	Краснодарский край, Каневский район, ст.Каневская, Северная, 3, телефон: 7-31-06		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
45020	2	20	1033	9000	21612	\N	46.086399	Краснодарский край, Каневский район, ст.Каневская, Октябрьская, 109, телефон: 7-38-67		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
44988	2	20	1033	9000	21612	\N	46.086399	Краснодарский край, Каневский район, ст. Каневская, Октябрьская, 79, телефон: 7-52-82		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
44987	2	20	1033	9000	21612	\N	46.086399	Краснодарский край, Каневской район, ст.Каневская, Октябрьская, 1, телефон: 7-91-96		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
45026	2	20	1033	9000	20476	\N	46.086399	Краснодарский край, Каневский район, ст.Каневская, Горького, 64, телефон: 7-92-39		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
44984	2	20	1033	9000	20476	\N	46.086399	Краснодарский край, Каневской район, ст. Каневская, Горького, 55, телефон: 4-20-24		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
44983	2	20	1033	9000	20997	\N	46.086399	Краснодарский край, Каневский район, ст. Каневская, Герцена, 82, телефон: 7-16-91		0101000020E6100000F5BEF1B5677843401CB4571F0F0B4740
45015	2	20	1033	50561	22779	\N	46.108105391668097	Краснодарский край, Каневский район, х.Большие Челбасы, Полтавская, 63, телефон: 3-88-94	Россия, Краснодарский край, Каневский район, поселок Бол. Челбасы	0101000020E6100000259529E6209443405DC47762D60D4740
44993	2	20	1033	50792	23624	\N	46.218763798133402	Краснодарский край, Каневской район, ст. Александровская, Советская, 17 А, телефон: 3-85-34	Россия, Краснодарский край, Каневский район, поселок Александровская	0101000020E61000008F386403E988434065C57075001C4740
44999	2	20	1033	50579	22849	\N	46.258023376015402	Краснодарский край, Каневский район, х. Албаши, Светлая, 97, телефон: 4-62-65		0101000020E61000002BC1E270E64D4340D34ECDE506214740
44962	2	20	977	8182	21597	\N	45.429766000000001	ст. Старовеличковская, Школьная, 42, телефон: 26493		0101000020E6100000D234289A075A43406477819202B74640
44965	2	20	977	8182	21621	\N	45.429766000000001	ст. Старовеличковская, Северная, 1, телефон: 27776		0101000020E6100000D234289A075A43406477819202B74640
44964	2	20	977	8182	20764	\N	45.429766000000001	ст. Старовеличковская, Красная, 202, телефон: 26034		0101000020E6100000D234289A075A43406477819202B74640
44963	2	20	977	8182	20764	\N	45.429766000000001	ст. Старовеличковская, Красная, 127, телефон: 26591		0101000020E6100000D234289A075A43406477819202B74640
44971	2	20	977	8637	20564	\N	45.637905000000003	п. Рогачевский, Солнечная, 4, телефон: 42196		0101000020E610000033182312854E43403A7AFCDEA6D14640
44967	2	20	977	50753	23530	\N	45.7171863556622	х. Редант, Центральная, 7, телефон: 31075	Россия, Краснодарский край, Калининский район, поселок Редант	0101000020E61000009241EE224C434340149337C0CCDB4640
44978	2	20	977	50680	23371	\N	45.757036394154603	х. Пригибский, Центральная, 8, телефон: 46350		0101000020E61000002B4CDF6B080A434084F23E8EE6E04640
44966	2	20	977	50408	21687	\N	45.382598000000002	с. Гришковское, Гайдара, 30/А, телефон: 49183		0101000020E610000012FA997ADD4C4340ECC1A4F8F8B04640
44972	2	20	977	8669	21222	\N	45.584560943894303	ст. Новониколаевская, Ленина, 134, телефон: 47105	Россия, Краснодарский край, Калининский район, поселок Новониколаевская	0101000020E61000007AC7293A922F43402FC214E5D2CA4640
44970	2	20	977	50875	23953	\N	45.701899114626002	х. Могукоровка, Ленина, 84, телефон: 32120	Россия, Краснодарский край, Калининский район, поселок Могукоровка	0101000020E6100000C5ABAC6D8A3943402C0C91D3D7D94640
44955	2	20	977	47491	21397	\N	45.484414000000001	ст. Калининская, Фадеева, 146, телефон: 21471		0101000020E610000022382EE3A6544340BEDC274701BE4640
44954	2	20	977	47491	21281	\N	45.484414000000001	ст. Калининская, Ленина, 43, телефон: 21169		0101000020E610000022382EE3A6544340BEDC274701BE4640
44956	2	20	977	47491	21399	\N	45.486949720380998	ст. Калининская, Коваля, 41, телефон: 21409	Россия, Краснодарский край, Калининский район, поселок Калининская	0101000020E6100000999EB0C403544340C364AA6054BE4640
44957	2	20	977	47491	21400	\N	45.480908577869897	ст. Калининская, Заречная, 15/А, телефон: 21183	Россия, Краснодарский край, Калининский район, поселок Калининская	0101000020E61000007500C45DBD54434010AD156D8EBD4640
44959	2	20	977	50757	23538	\N	45.457206688328803	х. Джумайловка, Молодежная, 2, телефон: 40748	Россия, Краснодарский край, Калининский район, поселок Джумайловка	0101000020E6100000ECA4BE2CED4C43404A404CC285BA4640
44976	2	20	977	8785	21436	\N	45.648201	ст. Гривенская, Советская, 20, телефон: 57675		0101000020E6100000DD41EC4CA1154340041E1840F8D24640
44975	2	20	977	8785	21436	\N	45.645639659995602	ст. Гривенская, Советская, 20, телефон: 57770	Россия, Краснодарский край, Калининский район, поселок Гривенская	0101000020E61000002716F88A6E154340A67EDE54A4D24640
44977	2	20	977	8785	21412	\N	45.648201	ст. Гривенская, Мира, 12/Б, телефон: 57398		0101000020E6100000DD41EC4CA1154340041E1840F8D24640
44968	2	20	977	50822	23748	\N	45.663960393206096	х. Гречаная Балка, Советская, 37, телефон: 45639	Россия, Краснодарский край, Калининский район, поселок Гречаная Балка	0101000020E6100000A8FC6B79E548434014ED2AA4FCD44640
44969	2	20	977	50848	23862	\N	45.663027704765199	х. Греки, Мира, 23, телефон: 41385	Россия, Краснодарский край, Калининский район, поселок Греки	0101000020E6100000E0BDA3C684424340882AFC19DED44640
44960	2	20	977	50285	20750	\N	45.356498000000002	х. Бойкопонура, Бойко, 1/Б, телефон: 48701	Россия, Краснодарский край, Калининский район, поселок Бойкопонура	0101000020E61000002AC8CF46AE614340728BF9B9A1AD4640
44961	2	20	977	50717	23452	\N	45.319636781992102	ст. Андреевская, Красная, 23, телефон: 44162	Россия, Краснодарский край, Калининский район, поселок Андреевская	0101000020E61000007F50172994554340B8CB7EDDE9A84640
44973	2	20	977	50830	23791	\N	45.540688480805301	х. Ангелинский, Центральная, 18, телефон: 47116	Россия, Краснодарский край, Калининский район, поселок Ангелинский	0101000020E6100000DC662AC4233543407AABAE4335C54640
44936	2	20	91	6939	20426	\N	45.540649582327603	хутор Черномуровский, Красноармейская, 51, телефон: 54-4-46	Россия, Краснодарский край, Кавказский район, поселок Черномуровский	0101000020E61000002B8881AE7D6544408C4AEA0434C54640
44935	2	20	91	50391	21574	\N	45.461463654169201	станица Темижбекская, Вокзальная, 47, телефон: 51-4-44	Россия, Краснодарский край, Кавказский район	0101000020E610000025CADE52CE6B444003249A4011BB4640
44934	2	20	91	6848	21495	\N	45.443027999999998	станица Темижбекская, Трактовая, 58, телефон: 51-4-77		0101000020E61000002FDFFAB0DE6C44402C9B3924B5B84640
44942	2	20	91	50319	21035	\N	45.594994	поселок Степной, Ленина, 10, телефон: 55-8-76	Россия, Краснодарский край, Кавказский район, поселок Степной	0101000020E610000059DAA9B9DC4444407AA86DC328CC4640
44948	2	20	91	7533	22068	\N	45.558145000000003	поселок Расцвет, Школьная, 9, телефон: 56-6-80		0101000020E61000004AEF1B5F7B22444085B69C4B71C74640
44937	2	20	91	47140	20726	\N	45.531388	поселок Озерный, Первомайская, 11, телефон: 54-5-86		0101000020E6100000BBD1C77C405E444051BEA08504C44640
44949	2	20	91	47395	23367	\N	45.543869000000001	поселок Мирской, Ленина, 85, телефон: 56-1-49		0101000020E61000000A48FB1F603344407427D87F9DC54640
44941	2	20	91	47208	21989	\N	45.552168999999999	хутор Лосево, Мира, 7 а, телефон: 55-1-87		0101000020E610000042226DE34F4C4440B96E4A79ADC64640
45451	2	20	91	50328	23503	\N	45.444881795006097	Краснодарский край, Кавказский район, Кропоткинское городское поселение, пер.Белинского, 25, телефон: 7-30-60		0101000020E610000013B875374F4744401F4AB4E4F1B84640
45462	2	20	91	50328	21280	\N	45.445641164047899	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Целых, 45, телефон: 6-30-73	Россия, Краснодарский край, Кавказский район	0101000020E610000028D714C8EC4C4440DD60A8C30AB94640
45463	2	20	91	50328	21230	\N	45.444394311476202	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.С.Целых, 45, телефон: 6-30-80	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E61000008E0244C18C474440F24410E7E1B84640
45465	2	20	91	50328	21114	\N	45.525010999999999	Краснодарский край, Кавказский район, Кропоткинское городское поселение, Микрорайон-1, 11, телефон: 3-47-67		0101000020E6100000F1D58EE21C4B44402785798F33C34640
45442	2	20	91	50328	23823	\N	45.441911550637499	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красноармейская, 53, телефон: 7-27-98	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E610000006668522DD474440E0DA899290B84640
45438	2	20	91	32672	23298	\N	45.437828593690902	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Мира, 146, телефон: 4-05-48	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E6100000D943FB58C1474440C51EDAC70AB84640
45470	2	20	91	32672	23409	\N	45.437772534606303	Краснодарский край, Кавказский район, Кропоткинское городское поселение, пер.Белинского, 25, телефон: 7-30-56	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E61000000C06D7DCD1474440310917F208B84640
45458	2	20	91	32672	23084	\N	45.439101886940698	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Шоссейная, 59, телефон: 7-03-34		0101000020E6100000BC9179E40F464440D9CD8C7E34B84640
45446	2	20	91	32672	23500	\N	45.444271355871003	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Шаумяна, 17 А, телефон: 6-34-14	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E610000018B5FB5580474440D6C743DFDDB84640
45440	2	20	91	32672	23442	\N	45.437717897459699	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Черноморская, 79, телефон: 6-63-12		0101000020E6100000D26F5F07CE4944406D6FB72407B84640
45459	2	20	91	32672	22486	\N	45.441089560657304	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Целых, 258, телефон: 7-21-10	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E610000049145AD6FD494440DC4B1AA375B84640
45448	2	20	91	32672	22846	\N	45.439101886940698	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Пушкина, 211, телефон: 6-24-48		0101000020E61000000C06D7DCD1474440D9CD8C7E34B84640
45444	2	20	91	32672	22846	\N	45.434824573896897	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Пушкина, 69, телефон: 6-48-95		0101000020E6100000548CF337A14C4440D93D7958A8B74640
45466	2	20	91	32672	20629	\N	45.447252332028597	Краснодарский край, Кавказский район, Кропоткинское городское поселение, Микрорайон-1, 53, телефон: 3-49-61	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E6100000DA5548F9494744400989B48D3FB94640
45469	2	20	91	32672	20718	\N	45.438014237375597	Краснодарский край, Кавказский район, Кропоткинское городское поселение, Микрорайон №1, 11, телефон: 7-13-21	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E61000008C2FDAE3854844405798BED710B84640
45443	2	20	91	32672	23880	\N	45.437071591234798	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красноармейская, 53, телефон: 6-22-49		0101000020E6100000B4E908E066494440A8FFACF9F1B74640
45457	2	20	91	32672	22759	\N	45.434066255629801	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красная, 11, телефон: 6-17-60		0101000020E61000001CEDB8E1774744401C2785798FB74640
45456	2	20	91	32672	22759	\N	45.439004500287602	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красная, 64, телефон: 7-20-44		0101000020E6100000B83D4162BB474440E7E3DA5031B84640
45453	2	20	91	32672	22759	\N	45.442144856851598	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Красная, 164, телефон: 7-01-11	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E6100000F6ECB94C4D4A4440828B153598B84640
45461	2	20	91	32672	23074	\N	45.439101886940698	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Комсомольская, 206, телефон: 6-80-16	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E610000041D7BE805E484440D9CD8C7E34B84640
45460	2	20	91	32672	23542	\N	45.441354302426603	Краснодарский край, Кавказский район, Кропоткинское городское поселение, ул.Гоголя, 166, телефон: 6-57-67	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E61000007940D9942B484440B9FAB1497EB84640
45468	2	20	91	32672	23831	\N	45.448753970041302	Краснодарский край, Кавказский район, Кропоткинское городское поселение, 1 проезд, 1, телефон: 6-22-48	Россия, Краснодарский край, Кавказский район, город Кропоткин	0101000020E610000098309A95ED4744407FF964C570B94640
45822	2	20	91	50893	24011	\N	45.568955860383397	х.Красная Звезда, ул.Мира, 11, телефон: 2-41-62		0101000020E6100000B98AC56F0A3D4440766EDA8CD3C84640
44951	2	20	91	50591	23405	\N	45.412079419450599	станица Казанская, Ленина, 11, телефон: 25-9-11		0101000020E6100000A25D85949F364440272F3201BFB44640
44952	2	20	91	50591	22929	\N	45.410385396718802	станица Казанская, Красная, 307, телефон: 25-2-29	Россия, Краснодарский край, Кавказский район, поселок Казанская	0101000020E61000000E68E90AB63744406DE2E47E87B44640
44950	2	20	91	50600	22955	\N	45.412259480893503	станица Казанская, Красная, 221, телефон: 25-7-77		0101000020E6100000B937BF61A2374440A73D25E7C4B44640
44933	2	20	91	50484	22277	\N	45.444217000000002	станица Кавказская, Ленина, 220, телефон: 22-9-47		0101000020E6100000A2427573F1554440E3A9471ADCB84640
44953	2	20	91	6733	20982	\N	45.444726803168003	станица Кавказская, Первомайский, 18, телефон: 22-3-38	Россия, Краснодарский край, Кавказский район, поселок Кавказская	0101000020E6100000CAA65CE15D564440F85278D0ECB84640
44570	2	20	1205	21215	21525	\N	44.959049	станица Рязанская, улица Первомайская, 108, телефон: 71-1-30		0101000020E6100000CEFBFF3861CA434079211D1EC27A4640
44932	2	20	91	6733	21158	\N	45.444217000000002	станица Кавказская, Ленина, 158, телефон: 22-8-51	Россия, Краснодарский край, Кавказский район, поселок Кавказская	0101000020E6100000A2427573F1554440E3A9471ADCB84640
44931	2	20	91	6733	20959	\N	45.444217000000002	станица Кавказская, Калинина, 111, телефон: 22-8-01		0101000020E6100000A2427573F1554440E3A9471ADCB84640
44940	2	20	91	47206	20729	\N	45.656826000000002	станица Дмитриевская, Фрунзе, 2, телефон: 53-1-69		0101000020E610000089B48D3F51614440CD94D6DF12D44640
44945	2	20	91	7404	22133	\N	45.464435999999999	поселок Десятихатка, Молодежная, 6, телефон: 23-4-31		0101000020E6100000CA51802898414440E38A8BA372BB4640
44695	2	20	91	46882	21077	\N	45.514875000000004	с. Возрождение, Таманская, 50, телефон: 67443		0101000020E61000003A950C00553A444096438B6CE7C14640
44878	2	20	301	45882	21066	\N	46.440125999999999	пос. Н.Островского, Центральная, 64, телефон: 97219		0101000020E61000005837DE1D19294340450F7C0C56384740
44885	2	20	301	4271	20472	\N	46.255049999999997	пос. Ясенская Переправа, Кирова, 36, телефон: 65742		0101000020E6100000E36C3A02B8254340226C787AA5204740
44884	2	20	301	50811	23707	\N	46.358653067981102	ст-ца Ясенская, Ленина, 79, телефон: 90185	Россия, Краснодарский край, Ейский район, поселок Ясенская	0101000020E610000086048C2E6F2243405FCE6C57E82D4740
44883	2	20	301	50811	23707	\N	46.358831344201597	ст-ца Ясенская, Ленина, 80, телефон: 90355	Россия, Краснодарский край, Ейский район, поселок Ясенская	0101000020E6100000A510C8258E2243403FE5982CEE2D4740
44919	2	20	301	6025	20762	\N	46.658271999999997	поселок Широчанка, Косиора, 34, телефон: 79238		0101000020E61000007FF62345642A4340AEEFC34142544740
44918	2	20	301	6025	20762	\N	46.658271999999997	поселок Широчанка, Косиора, 36, телефон: 79171		0101000020E61000007FF62345642A4340AEEFC34142544740
44875	2	20	301	45824	20616	\N	46.516289999999998	пос. Советский, Ленина, 2, телефон: 61147		0101000020E610000067D7BD15891143403CA06CCA15424740
44921	2	20	301	6198	21646	\N	46.692655999999999	поселок Морской, Центральная, 12, телефон: 27074		0101000020E610000016FC36C47819434068B0A9F3A8584740
44870	2	20	301	50791	23625	\N	46.5497864199844	пос. Моревка, Шоссейная, 17, телефон: 63247	Россия, Краснодарский край, Ейский район, поселок Моревка	0101000020E610000017BCE82B480743403AE63C635F464740
45106	2	20	301	50334	21146	\N	46.558431028722097	поселок Мирный, ул.Светлая, 12, телефон: 91-4-17	Россия, Краснодарский край, Ейский район, поселок Мирный	0101000020E61000002AAC5450510143404A09C1AA7A474740
44869	2	20	301	3424	21063	\N	46.625808879216997	с. Кухаривка, Советов, 33А, телефон: 99293	Россия, Краснодарский край, Ейский район, поселок Кухаривка	0101000020E6100000914259F8FA1243406F4562821A504740
44920	2	20	301	6155	21579	\N	46.650056999999997	поселок Краснофлотский, Комсомольская, 12, телефон: 92762		0101000020E6100000139A24969421434097C4591135534740
44886	2	20	301	50357	21364	\N	46.279835882122697	ст-ца Копанская, Мешкова, 22, телефон: 95475		0101000020E61000002882380F273E43402A1F82AAD1234740
44874	2	20	301	3720	20604	\N	46.579427000000003	пос. Комсомолец, Школьная, 23, телефон: 67407		0101000020E61000003830B95164214340AFB5F7A92A4A4740
44891	2	20	301	50646	23305	\N	46.410424513634098	ст-ца Камышеватская, Победы, 9, телефон: 96346	Россия, Краснодарский край, Ейский район, поселок Камышеватская	0101000020E6100000B212F3ACA4F94240FB3A70CE88344740
44872	2	20	301	50646	23499	\N	46.410519503564899	ст-ца Камышеватская, Азовская, 3А, телефон: 96227		0101000020E6100000C40776FC17FA42404D2D5BEB8B344740
44873	2	20	301	50647	23227	\N	46.410780725355998	ст-ца Камышеватская, Советская, 172Б, телефон: 96102		0101000020E6100000C0CFB87020FA4240BA68C87894344740
44882	2	20	301	50473	22216	\N	46.426262999999999	пос. Заводской, Мира, 39, телефон: 64236	Россия, Краснодарский край, Ейский район, поселок Заводской	0101000020E61000000B7DB08C0D3B4340573F36C98F364740
44925	2	20	301	50243	\N	\N	46.7035096750081	г.Ейск, ЕВВАУЛ им.В.М. Комарова	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E6100000DF8783842823434059349D9D0C5A4740
44924	2	20	301	50243	\N	\N	46.698206999999996	город Ейск, клуб в/ч 37115, телефон: 29947		0101000020E61000009F1C0588822343404C6BD3D85E594740
44899	2	20	301	50243	21733	\N	46.698206999999996	г.Ейск, угол ул.К.Маркса и ул.Гоголя		0101000020E61000009F1C0588822343404C6BD3D85E594740
44892	2	20	301	50243	21498	\N	46.695707523859298	город Ейск, Ясенская, 31, телефон: 34422		0101000020E61000006DA983BC1E22434065C8B1F50C594740
44900	2	20	301	50243	21735	\N	46.7130596758699	город Ейск, Янышева, 22, телефон: 33314	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E61000001C23D923D4224340FA0AD28C455B4740
44927	2	20	301	50243	20778	\N	46.687556776820699	город Ейск, пер. Юности, 10, телефон: 48211	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E6100000645C717154264340649126DE01584740
44901	2	20	301	50243	21102	\N	46.698206999999996	город Ейск, Театральная площадь, 1, телефон: 20376		0101000020E61000009F1C0588822343404C6BD3D85E594740
44911	2	20	301	50243	20661	\N	46.699227328563602	город Ейск, Пушкина, 56, телефон: 20297		0101000020E6100000B0C7444AB323434077BD344580594740
44910	2	20	301	50243	20661	\N	46.698206999999996	город Ейск, Пушкина, 73, телефон: 21114		0101000020E61000009F1C0588822343404C6BD3D85E594740
44906	2	20	301	50243	20661	\N	46.706220833959001	г.Ейск, ул.Пушкина,98	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E6100000E353008C67244340CC5F2173655A4740
44905	2	20	301	50243	20661	\N	46.698206999999996	город Ейск, Пушкина, 120, телефон: 30251		0101000020E61000009F1C0588822343404C6BD3D85E594740
44898	2	20	301	50243	21509	\N	46.7192318678295	город Ейск, Портовая аллея, 6, телефон: 22961	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E61000002A1900AAB82343404B1E4FCB0F5C4740
44895	2	20	301	50243	21254	\N	46.698206999999996	город Ейск, Первомайская, 196, телефон: 24506		0101000020E61000009F1C0588822343404C6BD3D85E594740
44926	2	20	301	50243	20897	\N	46.698206999999996	город Ейск, Красная, 74/2, телефон: 47194		0101000020E61000009F1C0588822343404C6BD3D85E594740
44922	2	20	301	50243	20897	\N	46.698206999999996	город Ейск, Красная, 47/6, телефон: 45350		0101000020E61000009F1C0588822343404C6BD3D85E594740
44917	2	20	301	50243	20897	\N	46.698206999999996	город Ейск, Красная, 74/2, телефон: 77145		0101000020E61000009F1C0588822343404C6BD3D85E594740
44916	2	20	301	50243	20432	\N	46.698206999999996	город Ейск, Коммунистическая, 83/3, телефон: 45111		0101000020E61000009F1C0588822343404C6BD3D85E594740
24196	1	2	1179	46281	24831	\N	52.819713	п. Мирный, Ленина, 10		0101000020E610000011A62897C6BB3F40938D075BEC684A40
44929	2	20	301	50243	21136	\N	46.682920467757697	город Ейск, Герцена, 44, телефон: 77959	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E61000006571FF91E922434065E42CEC69574740
44912	2	20	301	50243	20861	\N	46.698206999999996	город Ейск, Баррикадная, 1, телефон: 45910		0101000020E61000009F1C0588822343404C6BD3D85E594740
44908	2	20	301	1328	21311	\N	46.698206999999996	город Ейск, Харьковская, 184, телефон: 38468		0101000020E61000009F1C0588822343404C6BD3D85E594740
44896	2	20	301	1328	21682	\N	46.698206999999996	город Ейск, Таманская, 23/1, телефон: 23514		0101000020E61000009F1C0588822343404C6BD3D85E594740
44897	2	20	301	1328	20419	\N	46.698206999999996	город Ейск, Свердлова, 19, телефон: 21835		0101000020E61000009F1C0588822343404C6BD3D85E594740
44909	2	20	301	1328	21154	\N	46.697903146925697	город Ейск, Романа, 275, телефон: 46910	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E6100000AE669DF17D234340E063B0E254594740
44893	2	20	301	1328	20418	\N	46.698206999999996	город Ейск, Первомайская, 189/2, телефон: 24459		0101000020E61000009F1C0588822343404C6BD3D85E594740
44915	2	20	301	1328	20427	\N	46.686132283910403	город Ейск, Коммунистическая, 63а, телефон: 48906	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E6100000FE7C5BB0542543409A5E622CD3574740
44914	2	20	301	1328	20427	\N	46.689325450841501	город Ейск, Коммунистическая, 49/12, телефон: 46747	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E610000040A6B5696C25434058A835CD3B584740
44913	2	20	301	1328	20427	\N	46.698206999999996	город Ейск, Коммунистическая, 14, телефон: 72248		0101000020E61000009F1C0588822343404C6BD3D85E594740
44832	2	20	301	1328	20809	\N	46.698206999999996	город Ейск, Коммунаров, 10, телефон: 23166		0101000020E61000009F1C0588822343404C6BD3D85E594740
44902	2	20	301	1328	22551	\N	46.718332806992301	город Ейск, Бердянская, 111, телефон: 23343	Россия, Краснодарский край, Ейский район, город Ейск	0101000020E6100000C9207711A62243409C51F355F25B4740
44890	2	20	301	50560	22775	\N	46.632246425125402	ст-ца Должанская, Октябрьская, 137, телефон: 91563		0101000020E6100000A6B4FE9600E642406F83DA6FED504740
44815	2	20	301	50560	23937	\N	46.629013999999998	ст-ца Должанская, Ленина, 1, телефон: 91546	Россия, Краснодарский край, Ейский район, поселок Должанская	0101000020E6100000D8BCAAB35AE64240F25CDF8783504740
44867	2	20	301	50567	22802	\N	46.628189254566699	ст-ца Должанская, Октябрьская, 210, телефон: 91594		0101000020E61000002DEDD45C6EE642407D5A457F68504740
44868	2	20	301	45686	20719	\N	46.652061000000003	с. Воронцовка, Мира, 63, телефон: 62395		0101000020E6100000C020E9D32A0A4340A0FF1EBC76534740
46618	2	20	301	45831	\N	\N	46.515493546340799	хутор Большевик, здание клуба, телефон: 6-50-74		0101000020E61000007216F6B4C31D434061A417B5FB414740
44876	2	20	301	45831	23370	\N	46.515509000000002	пос. Большевик, Парковая, 2А, телефон: 61269		0101000020E6100000C425C79DD21D434097E5EB32FC414740
44887	2	20	301	46070	21396	\N	46.645299999999999	с. Александровка, Советская, 30Д, телефон: 94236		0101000020E610000048A8195245334340ED0DBE3099524740
46514	2	20	2678	34234	\N	\N	47.121657999999996	"хутор Дальний, здание конторы МТФ № 2 ЗАО ""АФ ""Дружба"""", телефон: 6 11 44"		0101000020E6100000109546CCECAB4540FCA5457D928F4740
44835	2	20	175	50497	22360	\N	45.113410999999999	ст.Васюринская, Западная, 59, телефон: 31-2-44		0101000020E6100000A721AAF067B04340DA006C40848E4640
44834	2	20	175	32718	22499	\N	45.130761	пос.Янтарный, Садовая, 18, телефон: 3-97-43		0101000020E6100000C005D9B27C9F4340CF4BC5C6BC904640
46808	2	20	175	1227	23501	\N	45.255483120792697	хутор Украинский, Украинская, 26а, телефон: 62637	Россия, Краснодарский край, Динской район, поселок Украинский	0101000020E61000009F5BE84A04AE43408CD7BCAAB3A04640
44830	2	20	175	1227	20808	\N	45.254868999999999	п.Украинский ул.Советов-4/1		0101000020E6100000B7B2446799AD4340D2E1218C9FA04640
44847	2	20	175	2045	21049	\N	45.343747	ст.Старомышастовская, Советская, 59, телефон: 75-2-98		0101000020E610000077DCF0BBE98A43408F8CD5E6FFAB4640
44846	2	20	175	2045	21049	\N	45.343747	ст.Старомышастовская, Советская, 49, телефон: 75-2-19		0101000020E610000077DCF0BBE98A43408F8CD5E6FFAB4640
44845	2	20	175	2045	22516	\N	45.343747	ст.Старомышастовская, Красная, 34, телефон: 75-6-31		0101000020E610000077DCF0BBE98A43408F8CD5E6FFAB4640
44836	2	20	175	50344	21217	\N	45.112773108617098	ст.Васюринская, Луначарского, 94, телефон: 31-2-50	Россия, Краснодарский край, Динской район, поселок Ст. Васюринская	0101000020E61000005837DE1D19B14340976F7D586F8E4640
44855	2	20	175	50606	22963	\N	45.194862532722297	ст.Новотитаровская, х.Примаки, телефон: 43-4-39	Россия, Краснодарский край, Динской район, поселок Примаки	0101000020E61000005E66D828EB6D4340A8195245F1984640
44841	2	20	175	1795	20815	\N	45.291542999999997	ст.Пластуновская, Мира, 26-а, телефон: 37-5-03		0101000020E61000008E0244C18CA743405930F14751A54640
44843	2	20	175	1795	20585	\N	45.291357645203	ст.Пластуновская, Красная, 55, телефон: 37-2-17	Россия, Краснодарский край, Динской район, поселок Пластуновская	0101000020E6100000514CDE0033A34340C8B60C384BA54640
44842	2	20	175	1795	20585	\N	45.291542999999997	ст.Пластуновская, Красная, 187 А, телефон: 37-2-25		0101000020E61000008E0244C18CA743405930F14751A54640
44840	2	20	175	1795	21044	\N	45.291542999999997	ст.Пластуновская, Базарная, 82, телефон: 37-4-19		0101000020E61000008E0244C18CA743405930F14751A54640
44839	2	20	175	1688	22035	\N	45.160938000000002	с.Первореченское, Ленина, 100, телефон: 3-43-82		0101000020E610000066A208A9DBA743408257CB9D99944640
44856	2	20	175	50584	24035	\N	45.239559068609701	ст.Новотитаровская, х.К.Маркса, Южная, 90\\2, телефон: 4-71-46		0101000020E6100000AAF3A8F8BF7D4340323B8BDEA99E4640
44857	2	20	175	50584	23906	\N	45.241377999999997	ст.Новотитаровская, Широкая, 2, телефон: 4-97-26	Россия, Краснодарский край, Динской район, поселок Новотитаровская	0101000020E610000004560E2DB27B4340A8FC6B79E59E4640
44849	2	20	175	50584	23435	\N	45.243291620649998	ст.Новотитаровская, Степная, 21\\2, телефон: 48-1-19	Россия, Краснодарский край, Динской район, поселок Новотитаровская	0101000020E61000005F5D15A8C57C434070B03731249F4640
44852	2	20	175	50584	23016	\N	45.2417824599071	ст.Новотитаровская, Советская, 61, телефон: 40-4-82	Россия, Краснодарский край, Динской район, поселок Новотитаровская	0101000020E61000002592E865147D434078616BB6F29E4640
14064	1	17	\N	3130	22470	\N	58.045848999999997	г. Рыбинск, Полиграфская, 5		0101000020E6100000B3614D65516C4340F3C64961DE054D40
44851	2	20	175	50584	23016	\N	45.244046185887903	ст.Новотитаровская, Советская, 116, телефон: 43-5-62	Россия, Краснодарский край, Динской район, поселок Новотитаровская	0101000020E6100000B3B3E89D0A7C43401C5C3AE63C9F4640
44854	2	20	175	50584	22972	\N	45.240771838188898	ст.Новотитаровская, Октябрьская, 304, телефон: 43-4-69	Россия, Краснодарский край, Динской район, поселок Новотитаровская	0101000020E6100000956247E3507D434071E5EC9DD19E4640
44850	2	20	175	50584	23417	\N	45.240866163722302	ст.Новотитаровская, Широкая, 46, телефон: 48-7-55	Россия, Краснодарский край, Динской район, поселок Новотитаровская	0101000020E6100000992842EA767C4340F25B74B2D49E4640
44853	2	20	175	50584	22891	\N	45.238679794369801	ст.Новотитаровская, Луначарского, 169, телефон: 43-8-58	Россия, Краснодарский край, Динской район, поселок Новотитаровская	0101000020E61000006C2409C2157E4340CA1AF5108D9E4640
44848	2	20	175	50605	22962	\N	45.2471384509495	ст.Новотитаровская, Крайняя, 2/1 А, телефон: 49-0-19	Россия, Краснодарский край, Динской район	0101000020E61000006495D233BD7C4340A7CCCD37A29F4640
44861	2	20	175	50658	23703	\N	45.281658061977403	ст-ца Нововеличковская, Свердлова ул, 24, телефон: 76-6-36	Россия, Краснодарский край, Динской район, поселок Нововеличковская	0101000020E6100000D3F9F02C416C434011548D5E0DA44640
44864	2	20	175	50658	23275	\N	45.280658254002098	ст-ца Нововеличковская, Красная ул, 51, телефон: 76-7-43		0101000020E610000007978E39CF6C43402EAEF199ECA34640
44860	2	20	175	50658	23275	\N	45.276701216864801	ст-ца Нововеличковская, Красная ул, 124, телефон: 76-6-42	Россия, Краснодарский край, Динской район, поселок Нововеличковская	0101000020E61000004BC8073D9B6B4340A0E238F06AA34640
44859	2	20	175	50658	23275	\N	45.279537236090398	ст-ца Нововеличковская, Красная ул, 42, телефон: 76-7-57		0101000020E6100000E4486760E46B4340CF8250DEC7A34640
44862	2	20	175	3065	21460	\N	45.328471999999998	пос.Найдорф, Школьная ул, 9, телефон: 42-0-47		0101000020E610000053978C63246943406BD3D85E0BAA4640
44844	2	20	175	49526	20579	\N	45.290084999999998	с.Красносельское, Кирова, 62 А, телефон: 33-3-60		0101000020E610000071581AF851954340B3075A8121A54640
44833	2	20	175	1375	21661	\N	45.158180000000002	пос.Зарождение, Центральная, 22, телефон: 39-3-28		0101000020E6100000FF40B96DDF9D4340CE70033E3F944640
44829	2	20	175	554	21654	\N	45.195424000000003	ст.Динская, переулокТельмана, 3 А, телефон: 6-34-98		0101000020E6100000680586AC6E9D4340406D54A703994640
44827	2	20	175	554	21334	\N	45.195424000000003	ст.Динская, Тельмана, 102, телефон: 6-17-27		0101000020E6100000680586AC6E9D4340406D54A703994640
44818	2	20	175	554	23684	\N	45.2329550573156	Краснодарский край, Динской район, Мира, 2, телефон: 6-40-30	Россия, Краснодарский край, Динской район, поселок Динская	0101000020E6100000DA8CD310559C434047382D78D19D4640
44822	2	20	175	554	21226	\N	45.195424000000003	ст.Динская, Луначарского, 34, телефон: 5-94-03		0101000020E6100000680586AC6E9D4340406D54A703994640
44826	2	20	175	554	20799	\N	45.195424000000003	ст.Динская, Краснодарская, 7, телефон: 5-51-94		0101000020E6100000680586AC6E9D4340406D54A703994640
44825	2	20	175	554	20560	\N	45.195424000000003	ст.Динская, Красная, 23, телефон: 6-59-05		0101000020E6100000680586AC6E9D4340406D54A703994640
44824	2	20	175	554	20560	\N	45.222214336853597	ст.Динская, Красная, 34, телефон: 6-30-02, 6-31-16	Россия, Краснодарский край, Динской район, поселок Динская	0101000020E6100000529ACDE3309C43404F5B2382719C4640
44821	2	20	175	554	20560	\N	45.195424000000003	ст.Динская, Красная, 111, телефон: 6-41-22		0101000020E6100000680586AC6E9D4340406D54A703994640
44828	2	20	175	554	21652	\N	45.213202609979199	ст.Динская, Комарова, 3, телефон: 5-40-29	Россия, Краснодарский край, Динской район, поселок Динская	0101000020E610000074B4AA251D9D43405D34643C4A9B4640
44819	2	20	175	554	20785	\N	45.195424000000003	ст.Динская, Кирова, 95, телефон: 6-32-86	Россия, Краснодарский край, Динской район, поселок Динская	0101000020E6100000680586AC6E9D4340406D54A703994640
44823	2	20	175	554	21642	\N	45.199065090949098	ст.Динская, Калинина, 58, телефон: 6-15-43	Россия, Краснодарский край, Динской район, поселок Динская	0101000020E610000092E9D0E9799D43409D6340F67A994640
44820	2	20	175	554	9844	\N	45.205800697445	ст.Динская, Гоголя, 108, телефон: 6-14-77	Россия, Краснодарский край, Динской район, поселок Динская	0101000020E6100000D2A755F4879E4340F73DEAAF579A4640
94981	2	20	175	49685	20642	\N	45.404364000000001	Динской район Нововеличковское сельское поселение, поселок Дальний, Центральная ул., 7		0101000020E61000006B7F677BF46C434002D71533C2B34640
46118	2	20	175	50254	\N	\N	45.388645603546301	х. Восточный, Здание сельского клуба, телефон: 33-8-53	Россия, Краснодарский край, Динской район, поселок Восточный	0101000020E6100000B03A72A4338C434051DCF126BFB14640
44863	2	20	175	50775	23573	\N	45.2199789700121	ст-ца Воронцовская, Красная ул, 10, телефон: 42-5-41		0101000020E6100000BC900E0F615E434045679945289C4640
44837	2	20	175	50455	22032	\N	45.113410999999999	ст.Васюринская, Луначарского, 190, телефон: 31-0-10		0101000020E6100000A721AAF067B04340DA006C40848E4640
44838	2	20	175	50455	22493	\N	45.117689395138001	ст.Васюринская, Интернациональная, 59, телефон: 31-7-43	Россия, Краснодарский край, Динской район, поселок Васюринская	0101000020E61000007EFE7BF0DAB54340AA0CE36E108F4640
44831	2	20	175	1243	21040	\N	45.143037999999997	пос.Агроном, Почтовая, 1, телефон: 78-1-32		0101000020E6100000DC0DA2B5A2994340E90AB6114F924640
44765	2	20	1188	50571	22819	\N	45.418211101394	хут.Черединовский, ул. Северная (здание сельского клуба), телефон: 2-54-98	Россия, Краснодарский край, Гулькевичский район, поселок Черединовский	0101000020E610000003EACDA8F95C4440EAE923F087B54640
44813	2	20	1188	50882	23970	\N	45.114268728482003	"хут. Чаплыгин, ул., Советская, (здание правления ООО ""Маяк Революции""), 19, телефон: 9-68-34"	Россия, Краснодарский край, Гулькевичский район, поселок Чаплыгин	0101000020E6100000575A46EA3D6144402BF9D85DA08E4640
44786	2	20	1188	50289	20783	\N	45.345493769165898	пос. Урожайный, ул. Ветеранов, (здание клуба), 15, телефон: 9-47-38	Россия, Краснодарский край, Гулькевичский район, поселок Урожайный	0101000020E6100000CA37DBDC983C44406C7BBB2539AC4640
44814	2	20	1188	50665	23321	\N	45.1816571659609	хут. Тысячный, ул. Красная, (здание Дома культуры), 9, телефон: 9-62-36	Россия, Краснодарский край, Гулькевичский район, поселок Тысячный	0101000020E6100000D576137CD3624440740B5D8940974640
44783	2	20	1188	50369	21427	\N	45.3625317286726	хут. Тельман, ул. Шукшина, (здание Дома культуры), 26, телефон: 5-83-54	Россия, Краснодарский край, Гулькевичский район, поселок Тельман	0101000020E6100000E5620CACE350444072E0D57267AE4640
44808	2	20	1188	49010	21431	\N	45.256473999999997	с. Соколовское, ул. Ленина (здание Дома культуры), телефон: 3-77-22		0101000020E61000004B2366F6795244401C23D923D4A04640
44809	2	20	1188	49010	21212	\N	45.256473999999997	"с. Соколовское, ул. Кирова (здание отделения № 1 ООО ПЗ ""Наша Родина""), телефон: 3-77-79"		0101000020E61000004B2366F6795244401C23D923D4A04640
44785	2	20	1188	50312	21014	\N	45.362959647751701	пос. Советский, ул. Садовая, (здание МДОУ ДС № 25), 7, телефон: 9-45-31	Россия, Краснодарский край, Гулькевичский район, поселок Советский	0101000020E61000001C23D923D4384440CAE0287975AE4640
46513	2	20	1188	50312	23531	\N	45.362569899990298	"хутор Советский, улица Буденного, дом 44 ""Б"", телефон: 6 12 92"	Россия, Краснодарский край, Гулькевичский район, поселок Советский	0101000020E6100000459F8F32E23844405F419AB168AE4640
44806	2	20	1188	50660	23282	\N	45.196287252051299	ст. Скобелевская, ул. Октябрьская, (здание администрации поселения), 28, телефон: 9-79-51	Россия, Краснодарский край, Гулькевичский район, поселок Скобелевская	0101000020E6100000E7AA798EC8354440A2D0B2EE1F994640
44799	2	20	1188	50898	24016	\N	45.368349494747001	"хут. Самойлов, ул. Красная, (здание бригадного дома ЗАО КСП ""Дружба""), 81, телефон: 5-95-92"	Россия, Краснодарский край, Гулькевичский район, поселок Самойлов	0101000020E6100000D28E1B7E374D4440D5415E0F26AF4640
44804	2	20	1188	48947	21949	\N	45.176048999999999	с. Пушкинское, ул. Советская, (здание Дома культуры), 171, телефон: 9-82-37		0101000020E61000000FB9196EC04D44402BBF0CC688964640
44803	2	20	1188	32140	21420	\N	45.306441999999997	с. Отрадо-Ольгинское, ул. Красная, (здание Дома культуры), 37, телефон: 9-32-43		0101000020E6100000D1CC936B0A784440770FD07D39A74640
44793	2	20	1188	11374	23603	\N	45.242558494021203	с. Отрадо-Кубонское, ул. Ленина, 44а (ДК)	Россия, Краснодарский край, Гулькевичский район, поселок Отрадо-Кубанское	0101000020E61000000DC2DCEEE56A44400CB1FA230C9F4640
44792	2	20	1188	11374	20999	\N	45.242080984226199	с. Отрадо-Кубанское, ул. Ленина, (здание МОУ СОШ № 15), 35А, телефон: 9-66-76	Россия, Краснодарский край, Гулькевичский район, поселок Отрадо-Кубанское	0101000020E6100000D520CCED5E6A4440D2FD9C82FC9E4640
44797	2	20	1188	50627	23078	\N	45.245855238360697	хут. Орлов, ул. Октябрьская (здание МДОУ детского сада № 43), телефон: 9-92-73		0101000020E6100000B75F3E59313E44406F47382D789F4640
44801	2	20	1188	30791	20954	\N	45.379477000000001	с. Новоукраинское, ул. Красная, (МКУК СДК Новоукраинского сельского поселения), 131, телефон: 9-13-64		0101000020E6100000C500892650424440C74ACCB392B04640
44775	2	20	1188	30791	20954	\N	45.379477000000001	"с. Новоукраинское, ул. Красная, (здание магазина ""Спасибо""), 231, телефон: 9-13-11"		0101000020E6100000C500892650424440C74ACCB392B04640
44811	2	20	1188	50888	23985	\N	45.2489622063027	хут. Новопавловский, ул. Восточная, (здание сельского клуба), 24-а, телефон: 3-76-39	Россия, Краснодарский край, Гулькевичский район, поселок Новопавловский	0101000020E61000003C4A253CA15944402FF99FFCDD9F4640
44802	2	20	1188	33131	20512	\N	45.288575000000002	с. Новомихайловское, ул. Октябрьская, (здание Дома культуры), 5, телефон: 9-83-41		0101000020E6100000AE6186C613814440BBB88D06F0A44640
44805	2	20	1188	50860	23902	\N	45.151290000000003	хут. Новокрасный, ул. Красная, (здание МОУ ООШ № 26), 59, телефон: 9-81-01	Россия, Краснодарский край, Гулькевичский район, поселок Новокрасный	0101000020E6100000758E01D9EB5544401E1B81785D934640
44795	2	20	1188	31785	21172	\N	45.242711	"с. Николенское, ул. Октябрьская, (здание правления ООО Агрофирмы ""Победа""), 86, телефон: 9-95-88"	Россия, Краснодарский край, Гулькевичский район, поселок Николенское	0101000020E610000014CB2DAD8646444092B06F27119F4640
44796	2	20	1188	31785	21611	\N	45.242711	с. Николенское, ул. Заречная (здание МОУ СОШ № 18), телефон: 9-92-03		0101000020E610000014CB2DAD8646444092B06F27119F4640
44790	2	20	1188	50503	22430	\N	45.343164000000002	пос. Мирный, ул. Красная, (здание фельдшерско-акушерского пункта), 7, телефон: 9-77-54	Россия, Краснодарский край, Гулькевичский район, поселок Мирный	0101000020E610000085CC9541B5274440109546CCECAB4640
44812	2	20	1188	50644	23214	\N	45.2837615299837	хут. Машевский, ул. Первомайская (здание сельского клуба), телефон: 3-77-66	Россия, Краснодарский край, Гулькевичский район, поселок Машевский	0101000020E61000002BA6D24F385944407DEC2E5052A44640
44763	2	20	1188	30178	20470	\N	45.394269999999999	с. Майкопское, ул. Кирова, (здание МОУ СОШ № 12), 16а, телефон: 2-53-15		0101000020E61000007862D68BA16044409FE5797077B24640
44764	2	20	1188	30178	21361	\N	45.394269999999999	"с. Майкопское, ул. Базарная, (здание МУК Дом культуры ""Майкопский""), 1а, телефон: 2-54-74"		0101000020E61000007862D68BA16044409FE5797077B24640
44781	2	20	1188	31086	21188	\N	45.368282999999998	пос. Лесодача, ул. Рабочая, (здание сельского клуба), 2, телефон: 2-75-24		0101000020E6100000C6FA0626377844401D56B8E523AF4640
44784	2	20	1188	50309	21004	\N	45.355400117549202	пос. Кубань, ул. Школьная, (здание Дома культуры), 8, телефон: 9-45-79	Россия, Краснодарский край, Гулькевичский район, поселок Кубань	0101000020E6100000BDFDB968C8344440CC7F48BF7DAD4640
44779	2	20	1188	50902	24031	\N	45.342461725997602	хут. Крупский, ул. Мира, (здание сельского клуба), 18, телефон: 2-77-19	Россия, Краснодарский край, Гулькевичский район, поселок Крупский	0101000020E6100000D61D8B6D52634440B60F79CBD5AB4640
44569	2	20	1205	21215	22359	\N	44.959049	станица Рязанская, улица Кубанская, 6, телефон: 71-4-82		0101000020E6100000CEFBFF3861CA434079211D1EC27A4640
44772	2	20	1188	30608	20751	\N	45.391649999999998	пос. Красносельский, ул. Школьная, (здание МОУ СОШ № 16), 72, телефон: 3-03-71		0101000020E61000000B630B410E4C44403CBD529621B24640
44771	2	20	1188	30608	21401	\N	45.391649999999998	пос. Красносельский, ул. Строителей, (здание Дома культуры), 22, телефон: 3-08-20		0101000020E61000000B630B410E4C44403CBD529621B24640
44770	2	20	1188	30608	20748	\N	45.391649999999998	"пос. Красносельский, ул. Промышленная, (административное здание ОАО ""Блок""), 2, телефон: 3-08-82"		0101000020E61000000B630B410E4C44403CBD529621B24640
44773	2	20	1188	30608	21601	\N	45.391649999999998	пос. Красносельский, ул. Почтовая, 7, телефон: 3-01-92		0101000020E61000000B630B410E4C44403CBD529621B24640
46290	2	20	1188	46580	23358	\N	45.355541095157797	п.Красная поляна, Турчинского, 42, телефон: 437444	Россия, Краснодарский край, Гулькевичский район, поселок Красная Поляна	0101000020E61000001AFCFD62B66E44408EB1135E82AD4640
44789	2	20	1188	50366	\N	\N	45.259284999999998	хут. Киевка, здание сельского клуба, телефон: 9-89-31	Россия, Краснодарский край, Гулькевичский район, поселок Киевка	0101000020E6100000A01518B2BA814440F3AB394030A14640
44807	2	20	1188	50846	23851	\N	45.241508448915802	хут. Журавлев, ул. Красная, (здание фельдшерско-акушерского пункта), 8, телефон: 2-88-10	Россия, Краснодарский край, Гулькевичский район, поселок Журавлев	0101000020E6100000FCABC77DAB35444077DCF0BBE99E4640
44780	2	20	1188	50801	23647	\N	45.414501049889701	хут. Духовской, ул. Юбилейная, (здание библиотеки), 3, телефон: 9-75-83	Россия, Краснодарский край, Гулькевичский район, поселок Духовский	0101000020E610000012842BA0507544406494675E0EB54640
44787	2	20	1188	48646	22394	\N	45.304901000000001	"пос. Дальний, ул. Ленина, (столовая отделения № 3 ФГУП ""Племзавод Кубань""), 9, телефон: 9-69-56"	Россия, Краснодарский край, Гулькевичский район, поселок Дальний	0101000020E6100000DC2DC901BB42444044C2F7FE06A74640
44749	2	20	1188	29398	21107	\N	45.363773999999999	"г.Гулькевичи, ул.Энергетиков, (здание клуба ""ОАО АПСКГ""), 29, телефон: 5-51-31"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44759	2	20	1188	29398	21866	\N	45.363773999999999	"г.Гулькевичи, ул. Чехова, (здание столовой ЗАО ""Племзавод ""Гулькевичский""), 20, телефон: 5-97-59"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44762	2	20	1188	29398	20988	\N	45.363773999999999	"г.Гулькевичи, ул. Тимирязева, (здание Дома культуры ""Гулькевичский""), 14, телефон: 5-62-45"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44760	2	20	1188	29398	20969	\N	45.363773999999999	г.Гулькевичи, ул. Советская, (ГОУ СПО Гулькевичский строительный техникум), 49, телефон: 3-24-69		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44753	2	20	1188	29398	20969	\N	45.363773999999999	г.Гулькевичи, ул. Советская, (здание МАОУ СОШ № 3), 20, телефон: 3-48-37		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44752	2	20	1188	29398	20969	\N	45.363773999999999	г. Гулькевичи, ул. Советская, (здание администрации МО Гулькевичский район), 14, телефон: 3-35-54		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44746	2	20	1188	29398	21103	\N	45.363773999999999	"г.Гулькевичи, ул.Пионерская, (здание МАУК ""Центр досуга и кино ""Зодиак""), 96, телефон: 5-32-63"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44761	2	20	1188	29398	21129	\N	45.363773999999999	"г.Гулькевичи, ул. Нагорная, (здание ДК ЗАО КСП ""Дружба""), 10, телефон: 3-48-13"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44751	2	20	1188	29398	21446	\N	45.363773999999999	"г.Гулькевичи, ул. Ленина,  (административное здание ООО ""Керамика""), 88, телефон: 3-32-91"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44756	2	20	1188	29398	20740	\N	45.363773999999999	"г.Гулькевичи, ул. Короткова, (адм.здание ЗАО ""Гулькевичский маслозавод), 155, телефон: 3-21-57"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44754	2	20	1188	29398	21585	\N	45.363773999999999	"г.Гулькевичи, ул. Комсомольская, (здание МУК ""КДЦ Лукоморье""), 80, телефон: 3-47-63"		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44755	2	20	1188	29398	21167	\N	45.363773999999999	г.Гулькевичи, ул. Кирова, (здание МОУ СОШ № 7), 78, телефон: 3-30-98		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44757	2	20	1188	29398	20823	\N	45.363773999999999	г.Гулькевичи, Западный микрорайон (отделение почтовой связи г. Гулькевичи), 19, телефон: 5-90-65		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44748	2	20	1188	29398	20727	\N	45.363773999999999	г.Гулькевичи, ул.Волго-Донская, (здание МОУ СОШ № 2), 7, телефон: 5-32-94		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44747	2	20	1188	29398	21155	\N	45.363773999999999	г.Гулькевичи, ул.50 лет ВЛКСМ, (административное здание ЗАО ДСУ-7), 28, телефон: 5-47-30		0101000020E6100000F6CE68AB925844404B917C2590AE4640
44769	2	20	1188	30321	22364	\N	45.405800999999997	"пос. Гирей, ул. Шевченко, (здание магазина ""Надежда""), 15а, телефон: 9185064926"		0101000020E610000043705CC64D55444090D78349F1B34640
44768	2	20	1188	30321	22345	\N	45.405800999999997	"пос. Гирей, ул. Степная, (здание магазина ""Снежана""), 138, телефон: 9181698370"		0101000020E610000043705CC64D55444090D78349F1B34640
44766	2	20	1188	30321	21367	\N	45.405800999999997	"пос. Гирей, ул. Почтовая, (здание Дома культуры ""Эльдорадо""), 5, телефон: 2-91-42"		0101000020E610000043705CC64D55444090D78349F1B34640
44767	2	20	1188	30321	21565	\N	45.405800999999997	"пос. Гирей, ул. Красная, (здание Дома культуры ""Фламинго""), 6, телефон: 2-92-07"		0101000020E610000043705CC64D55444090D78349F1B34640
44816	2	20	1188	50339	21209	\N	45.170413265445099	хут. Воздвиженский, ул. Свободный Труд (здание сельского клуба), телефон: 9-61-83	Россия, Краснодарский край, Гулькевичский район, поселок Воздвиженский	0101000020E6100000E8BB5B59A267444019E8DA17D0954640
44776	2	20	1188	30748	21001	\N	45.374626999999997	"пос. Венцы, ул. Советская (корпус ФГОУ СПО ""Зооветтехникум ""Венцы-Заря""), 25, телефон: 3-18-54"		0101000020E61000002DEDD45C6E6A44406B990CC7F3AF4640
44774	2	20	1188	30748	21192	\N	45.374626999999997	пос. Венцы, ул. Советская, (здание Дома культуры), 10, телефон: 3-16-22		0101000020E61000002DEDD45C6E6A44406B990CC7F3AF4640
44419	2	20	722	32682	21381	\N	44.548333	с. Вперед, Кимовская, 80-а, телефон: 26995		0101000020E610000069C878944ADA4340A62897C62F464640
44798	2	20	1188	50666	23322	\N	45.188557961824799	хут. Булгаков, ул. Школьная, (здание фельдшерско-акушерского пункта), 20, телефон: 9-91-09	Россия, Краснодарский край, Гулькевичский район, поселок Булгаков	0101000020E610000025AE635C7141444018B325AB22984640
44791	2	20	1188	12269	21608	\N	45.215161999999999	п. Ботаника ул. Центральная, 1а (ДК)		0101000020E6100000D4D7F335CB654440C5ABAC6D8A9B4640
44810	2	20	1188	50602	22971	\N	45.228131699652003	хут. Алексеевский, ул. Ленина, (здание сельского клуба), телефон: 3-77-00	Россия, Краснодарский край, Гулькевичский район, поселок Алексеевский	0101000020E6100000B6F468AA274F4440E695EB6D339D4640
44721	2	20	7074	50349	21314	\N	44.524155	поселок Кутаис, Ленина, 84, телефон: 4-85-11		0101000020E6100000A774B0FECFA543407784D38217434640
44670	2	20	1739	50464	22098	\N	45.715226970129599	Краснодарский край, Выселковский район, ст. Березанская, Новобазарная, 4, телефон: 53-1-08		0101000020E61000002579AEEFC3C74340AC1BEF8E8CDB4640
44653	2	20	1739	25147	21046	\N	45.752018	Краснодарский край, Выселковский район, пос.Советский, Красная, 6, телефон: 33-7-59	Россия, Краснодарский край, Выселковский район, поселок Советский	0101000020E61000002EABB019E00044406D00362042E04640
44650	2	20	1739	25009	21354	\N	45.658313	Краснодарский край, Выселковский район, с.Первомайское, Комарова, 7, телефон: 37-6-59		0101000020E61000004FB0FF3A37DB43400DC4B29943D44640
46037	2	20	1739	25583	23980	\N	45.7054401245638	хутор Первомайский, Школьная, 1, телефон: 4-44-51	Россия, Краснодарский край, Выселковский район, поселок Первомайский	0101000020E61000006FD921FE610F444027A5A0DB4BDA4640
46501	2	20	1739	25583	21615	\N	45.705443000000002	поселок Первомайский, улица Молодежная, дом 5, телефон: 6 91 73		0101000020E610000060217365500F44409818CBF44BDA4640
44662	2	20	1739	25583	21360	\N	45.705443000000002	Краснодарский край, Выселковский район, пос.Первомайский, Дорожная, 1/А, телефон: 35-5-81		0101000020E610000060217365500F44409818CBF44BDA4640
44660	2	20	1739	25513	23966	\N	45.885530823732097	Краснодарский край, Выселковский район, х.Память Ленина, Красная, 28, телефон: 40-1-23	Россия, Краснодарский край, Выселковский район, поселок Память Ленина	0101000020E61000003944DC9C4AC443400E4C6E1459F14640
44654	2	20	1739	25171	20710	\N	45.805107	Краснодарский край, Выселковский район, пос.Октябрьский, Советская, 40, телефон: 33-6-40		0101000020E610000087A4164A26FF4340ED6305BF0DE74640
44666	2	20	1739	25709	22543	\N	45.631849000000003	Краснодарский край, Выселковский район, ст.Новомалороссийская, Украинская, 1/4, телефон: 43-7-55, 43-6-92		0101000020E610000090831266DAF243405281936DE0D04640
44665	2	20	1739	25709	22547	\N	45.631849000000003	Краснодарский край, Выселковский район, ст.Новомалороссийская, Почтовая, 29, телефон: 42-1-90		0101000020E610000090831266DAF243405281936DE0D04640
44667	2	20	1739	25709	21681	\N	45.631849000000003	Краснодарский край, Выселковский район, ст.Новомалороссийская, Красная, 58/3, телефон: 42-2-56		0101000020E610000090831266DAF243405281936DE0D04640
44632	2	20	1739	24155	23981	\N	45.701635000000003	Краснодарский край, Выселковский район, ст.Новодонецкая, Советская, 39/А, телефон: 37-6-48	Россия, Краснодарский край, Выселковский район, поселок Новодонецкая	0101000020E610000068EA758BC0E643404F5DF92CCFD94640
44633	2	20	1739	24155	23300	\N	45.695500245967303	Краснодарский край, Выселковский район, ст.Новодонецкая, Комсомольская, 25/А, телефон: 37-6-27	Россия, Краснодарский край, Выселковский район, поселок Новодонецкая	0101000020E61000007E71A94A5BE643401B2FDD2406D94640
44669	2	20	1739	50713	23447	\N	45.589993806923601	Краснодарский край, Выселковский район, ст.Новогражданская, Ленина, 2/А, телефон: 49-4-72	Россия, Краснодарский край, Тбилисский район, поселок Новогражданская	0101000020E6100000C99063EB19004440096B63EC84CB4640
44664	2	20	1739	25622	21245	\N	45.464398000000003	Краснодарский край, Выселковский район, ст.Новобейсугская, Ленина, 12, телефон: 46-4-06		0101000020E61000005D19541B9CF04340F629C76471BB4640
44663	2	20	1739	25622	21813	\N	45.464398000000003	Краснодарский край, Выселковский район, ст.Новобейсугская, Горького, 115, телефон: 46-5-43		0101000020E61000005D19541B9CF04340F629C76471BB4640
44661	2	20	1739	50889	23994	\N	45.697235001539198	Краснодарский край, Выселковский район, ст.Крупская, Ленина, 70/А, телефон: 35-6-46	Россия, Краснодарский край, Выселковский район, поселок Крупская	0101000020E6100000C3B7B06EBCFB4340335019FF3ED94640
44658	2	20	1739	25390	22054	\N	45.856215470657801	Краснодарский край, Выселковский район, ст.Ирклиевская, Красная, 49, телефон: 40-1-95		0101000020E6100000D76B7A5050D443401DACFF7398ED4640
44659	2	20	1739	25390	22057	\N	45.855315865698103	Краснодарский край, Выселковский район, ст.Ирклиевская, Кооперативная, 11, телефон: 40-1-92		0101000020E610000064CBF27519D443406EDFA3FE7AED4640
44649	2	20	1739	50576	22841	\N	45.542485855989703	Краснодарский край, Выселковский район, х.Иногородне-Малеванный, Южная, 4, телефон: 73-2-87	Россия, Краснодарский край, Выселковский район, поселок Иногородне-Малеваный	0101000020E61000007BDB4C8578D04340D844662E70C54640
44637	2	20	1739	24383	21647	\N	45.665288524378298	Краснодарский край, Выселковский район, с.Заря, Школьная, 67, телефон: 44-1-19		0101000020E6100000A376BF0AF0D14340BCB1A03028D54640
46824	2	20	1739	24451	21657	\N	45.736043117673702	поселок Заречный, Школьная, 33, телефон: 69148	Россия, Краснодарский край, Выселковский район, поселок Заречный	0101000020E61000001EC4CE143AD1434091B932A836DE4640
44638	2	20	1739	24451	21350	\N	45.736401000000001	Краснодарский край, Выселковский район, пос.Заречный, Садовая, 1, телефон: 79-0-60		0101000020E6100000A6B73F170DD14340F0DE516342DE4640
44655	2	20	1739	25229	21812	\N	45.783132000000002	Краснодарский край, Выселковский район, пос.Гражданский, пер.Школьный, 5, телефон: 34-2-45		0101000020E610000034A0DE8C9AEF4340BD395CAB3DE44640
44656	2	20	1739	25229	21672	\N	45.783132000000002	Краснодарский край, Выселковский район, пос.Гражданский, Мира, 15/Б, телефон: 34-2-33		0101000020E610000034A0DE8C9AEF4340BD395CAB3DE44640
44652	2	20	1739	25088	22038	\N	45.754722000000001	Краснодарский край, Выселковский район, пос.Газырь, Шевченко, 1/А, телефон: 33-7-00		0101000020E6100000CF4D9B711AF843402EC901BB9AE04640
44644	2	20	1739	24645	\N	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, Северная, 7, телефон: 72-6-57	Россия, Краснодарский край, Выселковский район, поселок Выселки, станция Выселки	0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44647	2	20	1739	24645	21811	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, пер.Полевой, 6, телефон: 72-9-38		0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44642	2	20	1739	24645	20571	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, пер.Якименко, 9/А, телефон: 73-6-00		0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44651	2	20	1739	24645	20814	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, пер.Первомайский, 15, телефон: 75-0-41		0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44648	2	20	1739	24645	22503	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, Свободы, 97/А, телефон: 73-9-75		0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44646	2	20	1739	24645	22022	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, Ленина, 94, телефон: 73-0-67		0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44645	2	20	1739	24645	22022	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, Ленина, 130/А, телефон: 73-7-09		0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44643	2	20	1739	24645	20810	\N	45.581364000000001	Краснодарский край, Выселковский район, ст.Выселки, Дзержинского, 2, телефон: 73-4-44		0101000020E6100000FA264D83A2D343402F89B3226ACA4640
44639	2	20	1739	24488	21651	\N	45.613702000000004	Краснодарский край, Выселковский район, ст.Бузиновская, Октябрьская, 38, телефон: 45-6-49		0101000020E610000035D07CCEDDE44340B2BE81C98DCE4640
44641	2	20	1739	24488	20705	\N	45.613702000000004	Краснодарский край, Выселковский район, ст.Бузиновская, Мира, 73, телефон: 45-5-34		0101000020E610000035D07CCEDDE44340B2BE81C98DCE4640
44636	2	20	1739	24278	21225	\N	45.708281999999997	Краснодарский край, Выселковский район, ст.Березанская, Красноармейская, 55, телефон: 52-3-99		0101000020E610000006D847A7AECA4340382C0DFCA8DA4640
44629	2	20	1739	24008	20702	\N	45.692110999999997	Краснодарский край, Выселковский район, пос.Бейсуг, Ленина, 2/А, телефон: 31-1-93		0101000020E61000002DCDAD1056ED4340D619DF1797D84640
44630	2	20	1739	24008	21221	\N	45.692110999999997	Краснодарский край, Выселковский район, пос.Бейсуг, Кочубея, 3/А, телефон: 31-1-33		0101000020E61000002DCDAD1056ED4340D619DF1797D84640
44657	2	20	1739	25312	23380	\N	45.803512589763002	Краснодарский край, Выселковский район, ст.Балковская, Красная, 10, телефон: 36-4-23	Россия, Краснодарский край, Выселковский район, поселок Балковская	0101000020E610000005E10A28D4DD434097749483D9E64640
44631	2	20	1739	50780	23580	\N	45.694469154856399	Краснодарский край, Выселковский район, ст.Александро-Невская, Чапаева, 33/А, телефон: 31-2-14	Россия, Краснодарский край, Выселковский район, поселок Александроневская	0101000020E6100000CE8C7E349CF04340FC8A355CE4D84640
44634	2	20	1739	50735	23485	\N	45.484356224460903	Краснодарский край, Выселковский район, х.Бейсужек-2, Октябрьская, 24, телефон: 47-1-84	Россия, Краснодарский край, Выселковский район, поселок 2-й Бейсужек	0101000020E610000073D6A71C93DB434089CF9D60FFBD4640
44610	2	20	1198	23118	21418	\N	45.930712	станица Чепигинская, Красная, 44, телефон: 43191	Россия, Краснодарский край, Брюховецкий район, поселок Чепигинская	0101000020E61000005BEECC04C36F434054FF209221F74640
44608	2	20	1198	23014	23679	\N	45.852960892939599	хутор Челюскинец, Матросова, 5, телефон: 65113	Россия, Краснодарский край, Брюховецкий район, поселок Челюскинец	0101000020E6100000B37E33315D504340B9E177D32DED4640
44619	2	20	1198	32644	20533	\N	45.880428999999999	село Свободное, Ленина, 1, телефон: 54182		0101000020E6100000C72C7B12D89A434099B9C0E5B1F04640
44620	2	20	1198	32644	21131	\N	45.880428999999999	село Свободное, 50 лет Победы, 1А, телефон: 54102		0101000020E6100000C72C7B12D89A434099B9C0E5B1F04640
44621	2	20	1198	50386	21532	\N	45.797190000000001	село Приречное, Суворова, 25/3, телефон: 45125	Россия, Краснодарский край, Брюховецкий район, поселок Приречное	0101000020E61000006F8445459CA64340605969520AE64640
44943	2	20	1198	49602	23419	\N	45.806695071459899	хутор Привольный, Мира, 84, телефон: 57-1-10	Россия, Краснодарский край, Брюховецкий район, поселок Привольный	0101000020E6100000C878944A78944340616C21C841E74640
45079	2	20	1198	49602	20649	\N	45.806413999999997	Привольный поселок, Партизанская, 16, телефон: 51-0-57		0101000020E610000025766D6FB7944340AD84EE9238E74640
44626	2	20	1198	15123	20421	\N	45.791043999999999	хутор Полтавский, Солнечная, 46/1, телефон: 46135	Россия, Краснодарский край, Брюховецкий район, поселок Полтавский	0101000020E6100000541B9C887EB9434038D906EE40E54640
45109	2	20	1198	15123	22087	\N	45.791043999999999	поселок Полтавский, ул.Набережная, 9, телефон: 92-9-09		0101000020E6100000541B9C887EB9434038D906EE40E54640
44617	2	20	1198	23322	21632	\N	45.842294000000003	станица Переясловская, Толстого, 22, телефон: 61273		0101000020E61000001B683EE76E834340FBCE2F4AD0EB4640
44618	2	20	1198	23322	20531	\N	45.842294000000003	станица Переясловская, Красная, 134, телефон: 61325		0101000020E61000001B683EE76E834340FBCE2F4AD0EB4640
44616	2	20	1198	23322	20531	\N	45.842294000000003	станица Переясловская, Красная, 76, телефон: 61213		0101000020E61000001B683EE76E834340FBCE2F4AD0EB4640
44615	2	20	1198	23322	20531	\N	45.842294000000003	станица Переясловская, Красная, 83, телефон: 61368		0101000020E61000001B683EE76E834340FBCE2F4AD0EB4640
44628	2	20	1198	50330	21118	\N	45.885772578824998	село Новое Село, Советская, 131А, телефон: 8-918-1136959	Россия, Краснодарский край, Брюховецкий район, поселок Новое Село	0101000020E6100000F4FBFECD8BBD43400457790261F14640
44627	2	20	1198	50330	23907	\N	45.8845254392646	село Новое Село, Красная, 75, телефон: 53139	Россия, Краснодарский край, Брюховецкий район, поселок Новое Село	0101000020E6100000062FFA0AD2BC434048BF7D1D38F14640
44607	2	20	1198	22929	20767	\N	45.772987000000001	станица Новоджерелиевская, Красная, 75, телефон: 65124		0101000020E6100000365B79C9FF544340D89DEE3CF1E24640
44606	2	20	1198	22929	20767	\N	45.774698727753503	станица Новоджерелиевская, Красная, 56, телефон: 65281	Россия, Краснодарский край, Брюховецкий район, поселок Новоджерелиевская	0101000020E6100000AE2EA704C4544340389F3A5629E34640
44612	2	20	1198	23220	21198	\N	45.863869000000001	поселок Лиманский, Красная, 19, телефон: 63571		0101000020E6100000A03715A9307843409D83674293EE4640
44614	2	20	1198	23286	20769	\N	45.884945999999999	поселок Лебяжий Остров, Гагарина, 6А, телефон: 63197		0101000020E6100000EDEF6C8FDE744340EE5C18E945F14640
44778	2	20	1198	50874	23951	\N	45.765050140724803	хут. Красная Поляна, ул. Советская, (здание сельского клуба), 7, телефон: 2-84-32	Россия, Краснодарский край, Брюховецкий район, поселок Красная Поляна	0101000020E6100000ED116A865483434004E78C28EDE14640
44603	2	20	1198	49360	22403	\N	45.746420682250502	хутор Красная Нива, длинная, 117, телефон: 51173	Россия, Краснодарский край, Брюховецкий район, поселок Красная Нива	0101000020E6100000247CEF6FD082434018062CB98ADF4640
44613	2	20	1198	23235	21002	\N	45.908667999999999	хутор Киновия, Гоголя, 7, телефон: 43030		0101000020E61000006ADC9BDF30774340FB75A73B4FF44640
44777	2	20	1198	48464	21204	\N	45.782246000000001	пос. Заря, ул. Восточная, (здание фельдшерско-акушерского пункта), 7, телефон: 2-82-37		0101000020E61000003A5D16139BA94340A2B60DA320E44640
44605	2	20	1198	22874	20996	\N	45.853034999999998	хутор Гарбузовая Балка, Центральная, 19, телефон: 66134		0101000020E6100000198EE733A0684340F3AB394030ED4640
44598	2	20	1198	50398	\N	\N	45.801400000000001	"станица Брюховецкая, поселок МКК, КДЦ Дом культуры ""Луч"", телефон: 21854"	Россия, Краснодарский край, Брюховецкий район	0101000020E61000009488F02F827E4340D881734694E64640
44596	2	20	1198	11582	20755	\N	45.805728999999999	станица Брюховецкая, Энгельса, 175, телефон: 20066		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44593	2	20	1198	11582	21903	\N	45.801880021269199	352750, станица Брюховецкая, Тимофеева, 2	Россия, Краснодарский край, Брюховецкий район, поселок Брюховецкая	0101000020E61000005ABDC3EDD07E434082A8FB00A4E64640
44595	2	20	1198	11582	20754	\N	45.805728999999999	станица Брюховецкая, Ростовская, 1, телефон: 33041		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44597	2	20	1198	11582	20519	\N	45.805728999999999	станица Брюховецкая, Ленина, 55А, телефон: 22480		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44601	2	20	1198	11582	20884	\N	45.805728999999999	352753, станица Брюховецкая, Красная, 280		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44594	2	20	1198	11582	20884	\N	45.805728999999999	станица Брюховецкая, Красная, 180, телефон: 32113		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44599	2	20	1198	11582	21408	\N	45.805728999999999	станица Брюховецкая, Кошевого Олега, 119А, телефон: 31578		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44600	2	20	1198	11582	20756	\N	45.805728999999999	станица Брюховецкая, Димитрова, 46, телефон: 32049		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44602	2	20	1198	11582	21193	\N	45.805728999999999	станица Брюховецкая, Выгонная, 35, телефон: 34474		0101000020E6100000F2B0506B9A7F43402A38BC2022E74640
44622	2	20	1198	50323	21079	\N	45.788034000000003	село Большой Бейсуг, Деркача, 1, телефон: 45122		0101000020E6100000889FFF1EBC9A43406B11514CDEE44640
44623	2	20	1198	23684	21533	\N	45.788034000000003	село Большой Бейсуг, Деркача, 244, телефон: 45142		0101000020E6100000889FFF1EBC9A43406B11514CDEE44640
44609	2	20	1198	23045	20527	\N	45.884770000000003	село Бейсугское, Ленина, 71, телефон: 68008		0101000020E6100000CFF753E3A5594340B03DB32440F14640
44625	2	20	1198	23767	21012	\N	45.793357	станица Батуринская, Красная, 45, телефон: 46239		0101000020E610000006F1811DFFAF4340BE86E0B88CE54640
44624	2	20	1198	23767	21012	\N	45.793357	станица Батуринская, Красная, 40, телефон: 46289		0101000020E610000006F1811DFFAF4340BE86E0B88CE54640
46023	2	20	440	50715	23449	\N	43.581809	ст. Надежная, ул. Кооперативная, 42, телефон: 9-41-97		0101000020E610000025ECDB4944DC43405DC2A1B778CA4540
46400	2	20	440	13823	20641	\N	43.648015999999998	с. Русская Мамайка, Целинная, 119/Г, телефон: 60-00-18		0101000020E6100000A5D7666325DC434072A43330F2D24540
46368	2	20	440	12377	21689	\N	43.681542	село Пластунка, Леселидзе, 51, телефон: 66-90-34		0101000020E61000009A25016A6AE14340DB6CACC43CD74540
46433	2	20	440	15416	23658	\N	43.638269999999999	Краснодарский край, город Сочи, Центральный район, Труда, 5, телефон: 686810		0101000020E6100000F75B3B5112E043404B02D4D4B2D14540
46441	2	20	440	15668	4401	\N	43.613329	Краснодарский край, город Сочи, Центральный район, Абрикосовая, 2, телефон: 982736	Россия, Краснодарский край, Большой Сочи Центральный район, село Новагинка, улица Абрикосовая, 2	0101000020E6100000A438471D1DDF43401D588E9081CE4540
46445	2	20	440	15668	4430	\N	43.614308000000001	Краснодарский край, город Сочи, Центральный район, 60 лет ВЛКСМ, 12, телефон: 982336	Россия, Краснодарский край, Большой Сочи Центральный район, село Новагинка, улица 60 Лет ВЛКСМ, 12	0101000020E610000040BFEFDFBCDE4340E9D500A5A1CE4540
46402	2	20	440	10695	21500	\N	43.636873999999999	Краснодарский край, город Сочи, Центральный район, Крымская, 22, телефон: 502425		0101000020E61000000F971C774AD943401BD6541685D14540
46308	2	20	440	9466	23738	\N	43.645439000000003	с. Барановка, Армянская, 9, телефон: 66-93-21		0101000020E61000001CCF6740BDDF43400F48C2BE9DD24540
46394	2	20	148	13693	21426	\N	43.513622454136403	город Сочи, Ялтинская, 16/А, телефон: 65-35-41	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, улица Ялтинская, 16а	0101000020E6100000AD32535A7FEF4340C8409E5DBEC14540
46395	2	20	148	13693	21162	\N	43.509164390317601	город Сочи, Краснополянская, 6, телефон: 65-43-66	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, улица Краснополянская	0101000020E61000006C088ECBB8EF4340782634492CC14540
44265	2	20	755	6114	21295	\N	44.867705999999998	г.Абинск, Мира, 200А, телефон: 4-42-84		0101000020E610000032AA0CE36E14434080457EFD106F4640
46393	2	20	148	13693	20633	\N	43.515303995802199	город Сочи, переулок Ушинского, 3, телефон: 65-09-69	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, улица Ушинского, 3	0101000020E61000009FCBD42478EF4340BEBF417BF5C14540
46293	2	20	148	8792	2434	\N	43.562463000000001	с.Хлебороб, Центральная, 27, телефон: 651128	Россия, Краснодарский край, Большой Сочи Хостинский район, село Хлебороб, улица Центральная, 27	0101000020E6100000EC6987BF26F14340E31A9FC9FEC74540
46370	2	20	148	12468	23622	\N	43.590269372957302	с. Раздольное, Буковая, 14, телефон: 96-41-25	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Раздольное, улица Буковая, 14к3	0101000020E610000094F6065F98E24340DB6B41EF8DCB4540
44794	2	20	148	12593	23687	\N	43.591049071146401	хут. Прогресс, ул. Новая, (здание фельдшерско-акушерского пункта), 11, телефон: 9-66-19	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Прогресс	0101000020E6100000583B8A73D4E94340B0AA5E7EA7CB4540
46373	2	20	148	12593	23632	\N	43.589024999999999	с. Прогресс, Юбилейная, 46, телефон: 67-90-49		0101000020E6100000F48B12F417EA434061C3D32B65CB4540
46444	2	20	148	50264	20570	\N	43.616371000000001	Краснодарский край, город Сочи, Центральный район, Макаренко, 31, телефон: 640874	Россия, Краснодарский край, Большой Сочи Хостинский район, село Новагинка, улица Макаренко, 31	0101000020E610000014B1886187DF4340F699B33EE5CE4540
46437	2	20	148	50264	20570	\N	43.619885881656998	Краснодарский край, город Сочи, Центральный район, Макаренко, 45, телефон: 980917		0101000020E61000002A1900AAB8DF4340C79FA86C58CF4540
46436	2	20	148	50264	21340	\N	43.621088999999998	Краснодарский край, город Сочи, Центральный район, Вишневая, 7, телефон: 982295	Россия, Краснодарский край, Большой Сочи Хостинский район, село Новагинка, улица Вишневая, 7	0101000020E6100000352905DD5EE04340E27327D87FCF4540
46388	2	20	148	9842	21791	\N	43.543508376778597	город Сочи, Дорога на Большой Ахун, 14, телефон: 61-95-38		0101000020E6100000F9DA334B02E84340A48E8EAB91C54540
46397	2	20	148	30712	22429	\N	43.502504000000002	город Сочи, Дарвина, 82, телефон: 47-22-63	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Кудепста, улица Дарвина, 82	0101000020E6100000397F130A11F24340FA0D130D52C04540
46398	2	20	148	30712	20889	\N	43.495403000000003	город Сочи, Апшеронская, 1, телефон: 47-24-66	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Кудепста, улица Апшеронская, 1	0101000020E610000043E7357689F243408FAB915D69BF4540
45537	2	20	148	50698	23415	\N	43.560471	хутор Красный Октябрь, Шаумяна, 36б, телефон: 7-93-14		0101000020E6100000FD885FB186F143409FAD8383BDC74540
44817	2	20	148	382	109	\N	43.556910000000002	Краснодарский край, Динской район, Ульянова, 50, телефон: 5-36-45	Россия, Краснодарский край, Большой Сочи Хостинский район, село Красная Воля, улица Володи Ульянова, 46к1	0101000020E61000003CDA38622DF643405E68AED348C74540
46280	2	20	148	382	23777	\N	43.560966999999998	с.Красная Воля, Школьная, 1, телефон: 667359		0101000020E610000010CAFB389AF543404F9143C4CDC74540
46371	2	20	148	48184	21249	\N	43.629018000000002	с. Измайловка, Калиновая, 22, телефон: 67-99-18		0101000020E61000009162804413EA4340344C6DA983D04540
46278	2	20	148	8095	20987	\N	43.513502524249802	п.Дубравный, Пробковая, 20, телефон: 472886	Россия, Краснодарский край, Большой Сочи Хостинский район, поселок Дубравный	0101000020E61000009357E71890F34340EEB25F77BAC14540
46380	2	20	148	40381	21474	\N	43.5655750100577	город Сочи, Ворошиловская, 2/24, телефон: 67-11-89		0101000020E61000009694BBCFF1E14340B537F8C264C84540
46378	2	20	148	40381	20625	\N	43.566892198368201	город Сочи, Бытха, 1, телефон: 97-40-34	Россия, Краснодарский край, Большой Сочи Хостинский район, село Бытха, улица Бытха, 1	0101000020E6100000D1E80E6267E04340992EC4EA8FC84540
46249	2	20	148	40381	21163	\N	43.565122522933599	г.Сочи, Лесная, 1, телефон: 639485	Россия, Краснодарский край, Большой Сочи Хостинский район, село Бытха, улица Лесная	0101000020E6100000B0C56E9F55E24340D49B51F355C84540
46384	2	20	148	40381	20601	\N	43.555309999999999	город Сочи, Курортный проспект, 100, телефон: 69-76-91	Россия, Краснодарский край, Большой Сочи Хостинский район, село Бытха, Курортный проспект, 100	0101000020E6100000C97553CA6BE343402592E86514C74540
46382	2	20	148	40381	20601	\N	43.563585601455102	город Сочи, Курортный проспект, 92, телефон: 67-15-69	Россия, Краснодарский край, Большой Сочи Хостинский район, село Бытха, Курортный проспект, 92	0101000020E610000051A3906456E14340E23D079623C84540
46381	2	20	148	40381	21059	\N	43.565087537929799	город Сочи, Возрождения, 19, телефон: 67-15-57	Россия, Краснодарский край, Большой Сочи Хостинский район, село Бытха, улица Возрождения	0101000020E6100000D82C978DCEE1434058AEB7CD54C84540
46341	2	20	1078	50368	21421	\N	45.160041999999997	микрорайон Якорная Щель, Череповецкая, 12, телефон: 52-69-67		0101000020E61000000A9E42AED495434043FE99417C944640
46357	2	20	1078	50284	20749	\N	43.659510707347401	микрорайон Дагомыс, Батумское шоссе, 20/2, телефон: 52-19-02		0101000020E6100000D672672618D44340172D40DB6AD44540
46798	2	20	1078	50712	23446	\N	43.792340000000003	аул Кургоковский, Центральная, 16а, телефон: 62229		0101000020E6100000D1764CDD95BD434005A8A9656BE54540
46340	2	20	1078	11043	3138	\N	43.769251150910499	микрорайон Якорная Щель, Главная, 66а, телефон: 52-68-88		0101000020E6100000902FA182C3BF434028B517D176E24540
46338	2	20	1078	9524	2696	\N	43.797975000000001	микрорайон Головинка, Центральная, 93/А, телефон: 76-12-11	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Шахе, улица Центральная, 93а	0101000020E61000009CA223B9FCBB43404703780B24E64540
44558	2	20	1078	9524	2696	\N	43.798149941584398	хутор Привольный, улица Центральная, 45, телефон: 75-1-21	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Шахе, улица Центральная	0101000020E6100000CC272B86ABBB4340B5A679C729E64540
46335	2	20	1078	50318	\N	\N	43.836413262181701	"микрорайон Чемитоквадже, Военный санаторий ""Чемитоквадже"", телефон: 74-98-70"	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Чемитоквадже, Магистральный переулок	0101000020E6100000588CBAD6DEB543408179C8940FEB4540
46363	2	20	1078	50293	20850	\N	43.8068631188819	село Харциз Первый, Лучевая, 7, телефон: 52-58-86	Россия, Краснодарский край, городской округ Сочи, поселок Харциз Первый	0101000020E61000001630815B77CD43401DAD6A4947E74540
46334	2	20	1078	10779	23752	\N	43.886062000000003	микрорайон Солоники, Солоники, 16, телефон: 70-17-29		0101000020E6100000ADC266800BB043403B1DC87A6AF14540
46863	2	20	1078	9976	16261	\N	43.997782999999998	х. Свободный, Кольцевая, 1, телефон: 30-3-53	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Совет-Квадже, улица Кольцевая, 5	0101000020E6100000F56393FC889B43409CC0745AB7FF4540
46318	2	20	1078	9976	23820	\N	43.983262000000003	микрорайон Советквадже, Сибирская, 9, телефон: 74-74-57		0101000020E6100000151E34BBEE9D434025B37A87DBFD4540
46359	2	20	1078	11935	22052	\N	43.674565999999999	село Сергей-Поле, Славы, 124, телефон: 32-52-47		0101000020E61000000892770E65DA43402C7FBE2D58D64540
46367	2	20	1078	12323	75557	\N	43.754861543687802	354209, г. Сочи, Лазаревский район, микрорайон Детляжка, ул. Рязанская, 12		0101000020E6100000446D1B4641C44340207F69519FE04540
46364	2	20	1078	12177	3428	\N	43.951827000000002	село Мамедова Щель, Верхняя, 12, телефон: 70-01-96	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Мамедова Щель, улица Верхняя, 10	0101000020E610000058C6866EF6A7434093399677D5F94540
46317	2	20	1078	9843	20650	\N	44.003956000000002	микрорайон Макопсе, Свободы, 13, телефон: 74-43-98		0101000020E610000073637AC212994340BE4F55A181004640
46316	2	20	1078	9843	20430	\N	44.006023999999996	микрорайон Вишневка, Майкопская, 69а, телефон: 74-44-45		0101000020E61000001F80D4264E984340DC7EF964C5004640
46315	2	20	1078	9837	23944	\N	44.024493999999997	микрорайон Магри, Магринская, 8, телефон: 74-40-77		0101000020E61000000F43AB93339443405F79909E22034640
46348	2	20	1078	10081	23609	\N	43.6993247361019	микрорайон Лоо, Весенняя, 2/1, телефон: 52-74-52		0101000020E6100000884CF91054CB43403A234A7B83D94540
46324	2	20	1078	10702	8224	\N	43.914057999999997	микрорайон Лазаревское, Победы, 101, телефон: 70-25-41	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, улица Победы, 101	0101000020E6100000BA4E232D95A94340D65240DAFFF44540
46333	2	20	1078	10702	3033	\N	43.900205	микрорайон Лазаревское, Сочинское шоссе, 6, телефон: 70-10-52	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Сочинское шоссе, 6а	0101000020E61000004A5E9D6340AC43400C59DDEA39F34540
46332	2	20	1078	10702	20728	\N	43.905673999999998	микрорайон Лазаревское, Победы, 2, телефон: 70-48-04		0101000020E6100000ABCB290131AB4340336B2920EDF34540
46330	2	20	1078	10702	20728	\N	43.908934000000002	микрорайон Лазаревское, Победы, 28, телефон: 70-47-56		0101000020E610000025766D6FB7AA43407A1C06F357F44540
46322	2	20	1078	10702	20728	\N	43.919849999999997	микрорайон Лазаревское, Победы, 167, телефон: 72-68-06		0101000020E6100000D74D29AF95A84340E09C11A5BDF54540
46326	2	20	1078	10702	23890	\N	43.914440999999997	микрорайон Лазаревское, Партизанская, 16, телефон: 70-25-07		0101000020E610000091442FA358AA43408E8F16670CF54540
46365	2	20	1078	10702	20952	\N	43.914646798525197	микрорайон Лазаревское, Павлова, 89, телефон: 70-71-84	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, улица Павлова, 89а	0101000020E6100000C4CF7F0F5EAB43403831242713F54540
46331	2	20	1078	10702	21443	\N	43.908408000000001	микрорайон Лазаревское, Нахимова, 16, телефон: 70-10-39	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, улица Нахимова, 16	0101000020E61000000CE9F010C6A943405FB69DB646F44540
46350	2	20	1078	11491	3253	\N	43.676708876458399	микрорайн Культурное  Учдере, Чайная, 7/А, телефон: 50-73-74	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Культурное Учдере, улица Чайная, 7	0101000020E61000001AC05B2041D1434056F487669ED64540
46360	2	20	1078	11491	75537	\N	43.668308000000003	село Верхнее Учдере, Образцовая, 2, телефон: 50-73-05	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Культурное Учдере	0101000020E61000007235B22B2DD14340DDD3D51D8BD54540
46336	2	20	1078	10856	3075	\N	43.853977999999998	село Каткова Щель, Магистральная, 26, телефон: 76-18-98	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Каткова Щель, улица Магистральная, 26	0101000020E61000007BBE66B96CB4434072C0AE264FED4540
44974	2	20	1078	11544	16059	\N	43.658301999999999	х. Лебеди, Фестивальная, 3/2, телефон: 43736	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Дагомыс, улица Фестивальная, 1	0101000020E6100000336DFFCA4AD3434019726C3D43D44540
46353	2	20	1078	11544	3296	\N	43.667256000000002	микрорайон Дагомыс, Барановское шоссе, 7, телефон: 52-38-37		0101000020E6100000465ED6C402D74340A70705A568D54540
46355	2	20	1078	11544	20494	\N	43.665044999999999	микрорайон Дагомыс, Армавирская, 116, телефон: 52-19-01		0101000020E6100000A8A9656B7DD3434025AFCE3120D54540
46354	2	20	1078	11544	20494	\N	43.664732000000001	микрорайон Дагомыс, Армавирская, 143, телефон: 52-20-42		0101000020E61000003E3F8C101ED34340664D2CF015D54540
46351	2	20	1078	11544	20494	\N	43.658346817476499	микрорайон Дагомыс, Армавирская, 56, телефон: 52-20-75		0101000020E6100000D4BB783F6ED34340B935E9B644D44540
46356	2	20	1078	11583	3275	\N	43.662241000000002	микрорайон Дагомыс, Батумское шоссе, 63, телефон: 52-36-46	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Грузинская Мамайка, Батумское шоссе, 63	0101000020E61000003526C45C52D5434001892650C4D44540
46352	2	20	1078	11583	3275	\N	43.660584999999998	микрорайон Дагомыс, Батумское шоссе, 25/1, телефон: 52-10-13	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Грузинская Мамайка, Батумское шоссе, 25	0101000020E610000094F947DFA4D34340349D9D0C8ED44540
46319	2	20	1078	10008	2844	\N	43.974919999999997	микрорайон Голубая  Дача, Авроры, 6, телефон: 74-61-11	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Голубая Дача, улица Авроры, 10	0101000020E6100000E33785950AA04340B01BB62DCAFC4540
46362	2	20	1078	10369	3410	\N	43.696372091461001	село Волковка, Космическая, 1, телефон: 50-74-05	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Волковка, улица Космическая, 1	0101000020E6100000FE7DC68503D54340D0ECBAB722D94540
46361	2	20	1078	10369	23878	\N	43.685387298877401	село Волковка, Надежная, 28, телефон: 50-76-66	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Волковка, улица Надежная, 28	0101000020E6100000FC1873D712D44340410DDFC2BAD74540
46347	2	20	1078	11371	3225	\N	43.758058792845098	село Верхнее Буу, Октемберянская, 23/Б, телефон: 52-91-29	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Верхнее Буу, улица Октемберянская	0101000020E610000088F6B182DFC6434020B8CA1308E14540
46345	2	20	1078	11241	3198	\N	43.738709	село Верхнеармянское Лоо, Краснооктябрьская, 18, телефон: 50-95-79	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Верхнеармянское Лоо, улица Краснооктябрьская	0101000020E6100000D789CBF10AD0434064213A048EDE4540
46344	2	20	1078	11208	3189	\N	43.729179999999999	микрорайон Вардане, Львовская, 11, телефон: 52-91-92	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Вардане, улица Львовская, 11к12	0101000020E6100000F27C06D49BC74340DA722EC555DD4540
46343	2	20	1078	11208	23805	\N	43.734088176467601	микрорайон Вардане, Молодежная, 36, телефон: 52-91-95	Россия, Краснодарский край, Большой Сочи Лазаревский район, поселок Вардане, улица Молодежная, 36	0101000020E6100000921FF12BD6C643406A317898F6DD4540
46337	2	20	1078	10913	3091	\N	43.832677843354098	аул Большой Кичмай, Ачмизова, 8/Б, телефон: 76-21-47	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Большой Кичмай, улица Ачмизова	0101000020E61000009CA6CF0EB8C04340A20C553195EA4540
46342	2	20	1078	11129	20981	\N	43.771828928464103	село Беранда, Араратская, 26/2, телефон: 52-66-68	Россия, Краснодарский край, Большой Сочи Лазаревский район, село Беранда, улица Араратская	0101000020E6100000608F899466C343405C8DEC4ACBE24540
46264	2	20	7073	50365	21407	\N	43.481652844838401	г.Сочи, Пензенская, 3, телефон: сотовая связь	Россия, Краснодарский край, Большой Сочи Адлерский район, село Высокое	0101000020E6100000EEED96E480FB4340998235CEA6BD4540
46295	2	20	7073	50317	21030	\N	43.416486068158598	с.Веселое, Худякова, 15, телефон: 416595 (деж-во), в день голос. сот.связь	Россия, Краснодарский край, Большой Сочи Адлерский район, поселок Веселое	0101000020E610000000C5C89239004440F59ECA694FB54540
46246	2	20	164	6574	1778	\N	43.450719999999997	с. Черешня, Владимировская, 67/1, телефон: 430155	Россия, Краснодарский край, Большой Сочи Адлеровский район, село Черешня, улица Владимировская, 67к1	0101000020E610000065A9F57EA3FD434099D36531B1B94540
46281	2	20	164	7182	15699	\N	43.456825000000002	с.Орел-Изумруд, Петрозаводская, 10, телефон: 466596	Россия, Краснодарский край, Большой Сочи Адлеровский район, село Орел-Изумрудный, улица Петрозаводская, 10	0101000020E610000036E9B6442EF64340637FD93D79BA4540
46729	2	20	164	50704	23428	\N	43.417444000000003	п.Нововмихайловский, Мира, 73, телефон: 92555		0101000020E610000025B03907CF004440AAF413CE6EB54540
46244	2	20	164	6456	21123	\N	43.452806261849801	Нижняя Шиловка, Светогорская, телефон: 498159	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Веселое, улица Светогорская	0101000020E61000002E55698B6B0244405FB7088CF5B94540
46245	2	20	164	6456	1772	\N	43.472162200157697	Нижняя Шиловка, Грушевая, 10, телефон: 498108		0101000020E6100000431EC18D94FF4340FC34EECD6FBC4540
46294	2	20	164	6456	21190	\N	43.456178000000001	с.Нижняя Шиловка, Светогорская, 16а, телефон: 416180		0101000020E61000009E961FB8CA014440CD936B0A64BA4540
46252	2	20	164	50280	21515	\N	43.399197798631903	г.Сочи, Нижнеимеретинская, телефон: 416442 (деж-во), в день голос. сот связь	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Нижнеимеретинская Бухта, улица Нижнеимеретинская	0101000020E6100000F277EFA831FB4340765089EB18B34540
46298	2	20	164	50280	75603	\N	43.401186296400503	г. Сочи, Адлерский район, Нижнеимеретинская низменность, микрорайон Мирный	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Нижнеимеретинская Бухта	0101000020E6100000176536C824FD434079CE16105AB34540
46251	2	20	164	50280	20942	\N	43.3929144709859	г.Сочи, Полевая, 12, телефон: сотовая связь	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Нижнеимеретинская Бухта, улица Полевая, 12	0101000020E61000003332C85D84FD4340FD1186014BB24540
46283	2	20	164	8335	23676	\N	43.4537992781352	с.Молдовка, Пчеловодов, 4, телефон: 430338	Россия, Краснодарский край, Большой Сочи Адлеровский район, село Молдовка, улица Пчеловодов, 4	0101000020E610000079AF5A99F0F943408FFAEB1516BA4540
46016	2	20	164	504	140	\N	43.420822999999999	ст. Передовая, ул. Мира, 94, телефон: 9-54-91	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Веселое, улица Мира, 102	0101000020E6100000569BFF571D014440CA332F87DDB54540
46247	2	20	164	504	23593	\N	43.412826252335996	с.Веселое, Мира, 16а, телефон: 416050	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Веселое, Мира переулок, 23	0101000020E61000000E4FAF946500444021787C7BD7B44540
46277	2	20	164	8028	23730	\N	43.515025000000001	с.Верхнениколаевское, Мостовая, 12а, телефон: 473132		0101000020E61000000FB6D8EDB3F64340ABCFD556ECC14540
14063	1	17	\N	3130	22811	\N	58.045848999999997	г. Рыбинск, Пархинская, 12		0101000020E6100000B3614D65516C4340F3C64961DE054D40
46257	2	20	164	13104	20698	\N	43.428496000000003	г.Сочи, Ульянова, 68, телефон: 401278	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ульянова	0101000020E61000008639419B1CF64340C13BF9F4D8B64540
46266	2	20	164	13104	20975	\N	43.432986304515502	г.Сочи, Ромашек, 1, телефон: 404165	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ромашек, 1	0101000020E610000096B4E21B0AF543401CD0D2156CB74540
46263	2	20	164	13104	20438	\N	43.433779999999999	г.Сочи, Революции, 4, телефон: 400881	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Революции, 4	0101000020E61000004CC631923DF6434056D4601A86B74540
46276	2	20	164	13104	20801	\N	43.4891986560907	г.Сочи, Ленина, 233, телефон: 902132 (собственная АТС)	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ленина, 233	0101000020E61000009CA38E8EABF14340321EA5129EBE4540
46260	2	20	164	13104	20801	\N	43.429706156663002	г. Сочи, Адлерский район,   улица Ленина, 42	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ленина, 42	0101000020E6100000E6EB32FCA7F543408F72309B00B74540
46265	2	20	164	13104	20738	\N	43.435773011465699	г.Сочи, Куйбышева, 32, телефон: 401222	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Куйбышева	0101000020E610000077A1B94E23F543406ABDDF68C7B74540
42682	2	20	164	13104	20691	\N	43.445450999999998	г.Сочи, Кирпичная, 3, телефон: 464878	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Кирпичная, 3	0101000020E61000005E471CB281F44340397CD28904B94540
46259	2	20	164	13104	20662	\N	43.428207999999998	г.Сочи, Ульянова, 55, телефон: 404423		0101000020E6100000FC523F6F2AF643405AF10D85CFB64540
46261	2	20	164	13104	20965	\N	43.432366000000002	г.Сочи, Свердлова, 94, телефон: 401685	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Свердлова, 94	0101000020E610000042EE224C51F6434080F3E2C457B74540
46258	2	20	164	13104	21104	\N	43.430940568503203	г.Сочи, Садовая, 51, телефон: 401313	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Садовая, 51	0101000020E6100000C1AA7AF99DF64340B5C01E1329B74540
46275	2	20	164	13104	21537	\N	43.480020354503999	г.Сочи, Просвещения, 139, телефон: 473472	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Просвещения, 139	0101000020E610000089CE328B50F2434085B69C4B71BD4540
46262	2	20	164	13104	21109	\N	43.431770748932699	г.Сочи, Молокова, 1, телефон: 403752	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Молокова, 1	0101000020E6100000861C5BCF10F643403C2EAA4544B74540
46267	2	20	164	13104	21116	\N	43.441000000000003	г.Сочи, Котовского, 3, телефон: 404353	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Котовского, 3	0101000020E6100000B534B74258F543409CC420B072B84540
46297	2	20	164	13104	21625	\N	43.4531042575383	с.Молдовка, Костромская, 58а, телефон: 430358		0101000020E61000000BD1217024FA4340E9D7D64FFFB94540
46269	2	20	164	13104	20690	\N	43.446054308339299	г.Сочи, Кирпичная, 1/1, телефон: 462810	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Кирпичная, 1к1	0101000020E610000050E09D7C7AF44340FF1F274C18B94540
46253	2	20	164	13104	21039	\N	43.423935819995897	г.Сочи, Демократическая, 43, телефон: 400495	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Демократическая	0101000020E6100000B1A888D349F643406CCCEB8843B64540
46271	2	20	164	13104	21179	\N	43.450589000000001	г.Сочи, Голубые дали, 60, телефон: 465157	Россия, Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Голубые Дали, 60	0101000020E61000005F07CE1951F44340FB777DE6ACB94540
42874	2	20	164	13104	21182	\N	43.449178479717297	г.Сочи, Гастелло, 29, телефон: 466631		0101000020E6100000F581E49D43F54340960A2AAA7EB94540
45464	2	20	164	13104	22937	\N	43.428024999999998	ул 8 Марта,127 В		0101000020E6100000AD33BE2F2EF54340696FF085C9B64540
46270	2	20	164	13104	21392	\N	43.454962757095103	г.Сочи, Голубые дали, 21, телефон: 462932		0101000020E61000007AA86DC328F44340EDF1423A3CBA4540
45883	2	20	1205	47651	22343	\N	44.727581000000001	"Пос. Южный  ул. Шоссейная 9"		0101000020E6100000933655F7C8EE43407218CC5F215D4640
44545	2	20	1205	47651	21127	\N	44.727921301045001	поселок Южный, улица Школьная, 16, телефон: 3-82-78	Россия, Краснодарский край, Белореченский район, поселок Южный	0101000020E6100000FC1D8A027DEE43402B89EC832C5D4640
45564	2	20	1205	47651	20693	\N	44.727581000000001	поселок Южный, Центральная, 1, телефон: 6-73-33	Россия, Краснодарский край, Белореченский район, поселок Южный	0101000020E6100000933655F7C8EE43407218CC5F215D4640
45049	2	20	1205	47651	23345	\N	44.7294577015412	Южный поселок, Краснооктябрьская, 1, телефон: 5-50-76	Россия, Краснодарский край, Белореченский район, поселок Южный	0101000020E61000000D6D003620EE43401DE736E15E5D4640
44553	2	20	1205	20418	20484	\N	44.905934000000002	село Школьное, улица Советская, 7, телефон: 75-1-85		0101000020E6100000AB5E7EA7C9EC4340D02A33A5F5734640
44578	2	20	1205	21652	23893	\N	44.703451058041203	станица Черниговская, улица Красная, 44, телефон: 65-3-36	Россия, Краснодарский край, Белореченский район, поселок Черниговская	0101000020E610000059A4897780D5434054ABAFAE0A5A4640
44568	2	20	1205	21189	20510	\N	45.01446	хутор Фокин, улица Школьная, 1, телефон: 71-3-19		0101000020E61000001FF46C567DC24340D28C45D3D9814640
44588	2	20	1205	22148	21976	\N	44.641345999999999	хутор Фадеевский, улица Мира, 52, телефон: 67-5-44		0101000020E61000005ED72FD80DEF4340D0B52FA017524640
45616	2	20	1205	46907	20609	\N	45.033954999999999	поселок Северный, Красная, 4, телефон: 6-61-55		0101000020E61000001E34BBEEADCC434091442FA358844640
44551	2	20	1205	48541	21133	\N	44.786543999999999	поселок Садовый, улица Комарова, 31/А, телефон: 2-55-27		0101000020E61000003CF54883DBE84340B96E4A79AD644640
44571	2	20	1205	21215	21121	\N	44.959049	станица Рязанская, улица Победы, 69/А, телефон: 71-2-01		0101000020E6100000CEFBFF3861CA434079211D1EC27A4640
44548	2	20	1205	48469	22126	\N	44.737887794646703	поселок Родники, улица Центральная, 11/А, телефон: 3-71-72	Россия, Краснодарский край, Белореченский район, поселок Родники	0101000020E6100000E97C789620F54340300E2E1D735E4640
44547	2	20	1205	48469	20680	\N	44.738512	поселок Родники, улица Норильская, 6, телефон: 3-71-18		0101000020E6100000DBC4C9FD0EF543400EDAAB8F875E4640
44589	2	20	1205	22165	20848	\N	44.696199999999997	станица Пшехская, улица Мира, 6, телефон: 67-1-12		0101000020E61000006E85B01A4BE64340D3BCE3141D594640
44590	2	20	1205	22165	21637	\N	44.696199999999997	станица Пшехская, улица Крестьянская, 4, телефон: 67-1-17		0101000020E61000006E85B01A4BE64340D3BCE3141D594640
44591	2	20	1205	22165	23248	\N	44.699567138963701	"станица Пшехская, улица Заречная, здание магазина ""Орфей"", телефон: 67-3-60"	Россия, Краснодарский край, Белореченский район, поселок Пшехская	0101000020E6100000C24D469561E64340302E55698B594640
44563	2	20	1205	48759	20817	\N	44.863199071160501	поселок Проточный, улица Мира, 22, телефон: 64-5-42	Россия, Краснодарский край, Белореченский район, поселок Проточный	0101000020E6100000265305A392E243404F78094E7D6E4640
45889	2	20	1205	50267	20614	\N	44.883146951289199	"Пос.Первомайский  Ул Центральная 12"	Россия, Краснодарский край, Белореченский район	0101000020E610000066BE839F38DE4340BF47FDF50A714640
45483	2	20	1205	50360	21390	\N	44.855604763553899	ст. Октябрьская, здание МОУ СОШ №30, Привокзальная, 1, телефон: 39005	Россия, Краснодарский край, Белореченский район, поселок Октябрьская	0101000020E6100000AEB6627FD9CF4340A4A5F276846D4640
44577	2	20	1205	21577	22127	\N	44.781112	хутор Новогурийский, улица Школьная, 5, телефон: 61-7-29		0101000020E61000002AE5B512BAD34340AF415F7AFB634640
44554	2	20	1205	32941	21656	\N	44.954884	село Новоалексеевское, улица Красная, 19, телефон: 75-6-19		0101000020E6100000B98C9B1A68EE4340A1BC8FA3397A4640
44572	2	20	1205	21351	21785	\N	44.878636	поселок Нижневеденеевский, улица Клубная, 1, телефон: 61-5-40		0101000020E61000004FAE2990D9D343404C8BFA2477704640
44579	2	20	1205	48813	20883	\N	44.678148	поселок Молодежный, улица Ленина, 10, телефон: 65-1-63		0101000020E6100000EBE5779ACCD6434085ECBC8DCD564640
44557	2	20	1205	48643	21562	\N	44.899754000000001	село Леонтьевское, улица Клубная, 15, телефон: 75-2-72		0101000020E610000014083BC5AAE34340FC389A232B734640
44556	2	20	1205	20569	21557	\N	44.912163999999997	хутор Лантратов, улица Мира, здание клуба, телефон: 75-5-30		0101000020E6100000A6EECA2E18F64340554B3ACAC1744640
46874	2	20	1205	50746	23517	\N	44.750292476933197	х. Заречный, Центральная, 21, телефон: 39-6-16	Россия, Краснодарский край, Белореченский район, поселок Заречный	0101000020E6100000A14D0E9F74EA4340A839799109604640
94979	2	20	1205	21831	21075	\N	44.731358999999998	Белореченский район, Дружненское сельское поселение, поселок Дружный, Химплощадка		0101000020E6100000A5660FB402E343405051F52B9D5D4640
44582	2	20	1205	21831	21386	\N	44.731358999999998	поселок Дружный, улица Советская, 61, телефон: 73-1-10		0101000020E6100000A5660FB402E343405051F52B9D5D4640
44583	2	20	1205	21831	22399	\N	44.731358999999998	поселок Дружный, улица Заводская, 8/А, телефон: 73-2-85		0101000020E6100000A5660FB402E343405051F52B9D5D4640
44584	2	20	1205	21924	21920	\N	44.807299	хутор Долгогусевский, улица Луценко, 5/2, телефон: 69-2-82		0101000020E6100000C861307F85E44340F88BD99255674640
44585	2	20	1205	21924	23211	\N	44.807299	хутор Долгогусевский, улица Голенева, 68/Б, телефон: 69-2-77	Россия, Краснодарский край, Белореченский район, поселок Долгогусевский	0101000020E6100000C861307F85E44340F88BD99255674640
44580	2	20	1205	21740	21387	\N	44.656781000000002	станица Гурийская, улица Школьная, 57, телефон: 65-4-16		0101000020E61000007D1F0E12A2CE43402DD1596611544640
44567	2	20	1205	21129	22025	\N	44.905053000000002	поселок Ганжинский, улица Солнечная, 7, телефон: 64-6-34		0101000020E61000000BB8E7F9D3D64340C712D6C6D8734640
44562	2	20	1205	20856	21379	\N	44.834363000000003	поселок Верхневеденеевский, улица Гагарина, 14, телефон: 62-1-43		0101000020E6100000C4245CC823E4434009FF2268CC6A4640
44559	2	20	1205	20721	21320	\N	44.934539000000001	село Великовечное, улица Советская, 55, телефон: 39-2-25		0101000020E61000008352B4722FE0434014EB54F99E774640
44561	2	20	1205	20721	20915	\N	44.934539000000001	село Великовечное, улица Почтовая, 59, телефон: 39-1-72		0101000020E61000008352B4722FE0434014EB54F99E774640
44560	2	20	1205	20721	22335	\N	44.934539000000001	село Великовечное, улица Ленина, 50/Б, телефон: 39-2-30		0101000020E61000008352B4722FE0434014EB54F99E774640
44574	2	20	1205	21439	23772	\N	44.839303803918199	станица Бжедуховская, улица Красная, 85, телефон: 61-1-21	Россия, Краснодарский край, Белореченский район, поселок Бжедуховская	0101000020E6100000E3A7716F7ED7434074B33F506E6B4640
44575	2	20	1205	21439	23849	\N	44.839232238553997	станица Бжедуховская, улица Комсомольская, 7, телефон: 61-1-45	Россия, Краснодарский край, Белореченский район, поселок Бжедуховская	0101000020E61000005BB4006DABD74340DBE044F46B6B4640
44532	2	20	1205	11745	22633	\N	44.780842700900997	город Белореченск, улица Совхозная, 3, телефон: 2-70-62	Россия, Краснодарский край, Белореченский район, город Белореченск	0101000020E6100000C80C54C6BFEB4340BF27D6A9F2634640
44521	2	20	1205	11745	9877	\N	44.769857000000002	г. Белореченск, ул. Ленина, 85		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44529	2	20	1205	40522	21317	\N	44.768564996505702	г. Белореченск, ул. Шалимова, 28	Россия, Краснодарский край, Белореченский район, город Белореченск	0101000020E61000004583143C85EE4340D5EC815660624640
44540	2	20	1205	40522	21327	\N	44.769857000000002	город Белореченск, улица Свердлова, 1, телефон: 3-36-01		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44542	2	20	1205	40522	20673	\N	44.769857000000002	город Белореченск, улица Пролетарская, 220, телефон: 2-73-09		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44536	2	20	1205	40522	20914	\N	44.769857000000002	город Белореченск, улица Победы, 170, телефон: 2-41-26		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44535	2	20	1205	40522	20914	\N	44.785235086176797	город Белореченск, улица Победы, 353, телефон: 3-37-12	Россия, Краснодарский край, Белореченский район, город Белореченск	0101000020E610000027327381CBEF434058569A9482644640
44533	2	20	1205	40522	20914	\N	44.785999134634203	г. Белореченск, ул. Победы, 461	Россия, Краснодарский край, Белореченский район, город Белореченск	0101000020E61000002A36E675C4EF434027D87F9D9B644640
44522	2	20	1205	40522	20876	\N	44.753926996330598	город Белореченск, улица Мира, 2, телефон: 2-21-85	Россия, Краснодарский край, Белореченский район, город Белореченск	0101000020E61000004BE82E89B3F04340234910AE80604640
44526	2	20	1205	40522	20873	\N	44.760990393119002	город Белореченск, улица Луначарского, 122, телефон: 2-35-23, 2-35-89		0101000020E61000001C40BFEFDFEE4340A14ACD1E68614640
44525	2	20	1205	40522	10084	\N	44.769857000000002	г. Белореченск, ул. Ленина, 119		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44527	2	20	1205	40522	20901	\N	44.769857000000002	город Белореченск, улица Красная, 50, телефон: 2-32-58		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44523	2	20	1205	40522	21069	\N	44.7671051860519	город Белореченск, улица Интернациональная, 153, телефон: 2-38-01	Россия, Краснодарский край, Белореченский район, город Белореченск	0101000020E610000006137F1475EE43408ECC237F30624640
44520	2	20	1205	40522	21069	\N	44.769857000000002	город Белореченск, улица Интернациональная, 1, телефон: 2-49-77		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44543	2	20	1205	40522	20923	\N	44.769857000000002	город Белореченск, улица Железнодорожная, 2, телефон: 3-23-44		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44539	2	20	1205	40522	20670	\N	44.769857000000002	город Белореченск, улица Деповская, 68, телефон: 76-9-52		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44524	2	20	1205	40522	20656	\N	44.769857000000002	город Белореченск, улица Гоголя, 51, телефон: 2-44-00		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44528	2	20	1205	40522	21485	\N	44.769857000000002	город Белореченск, улица 40 лет Октября, 33, телефон: 2-22-65		0101000020E610000069AB92C83EF0434060CC96AC8A624640
44555	2	20	1205	32947	20724	\N	45.005634000000001	село Архиповское, улица Первомайская, 8/А, телефон: 75-7-30		0101000020E610000021C8410933ED434072DF6A9DB8804640
44509	2	20	1501	18051	21132	\N	46.198683000000003	Краснодарский край, Белоглинский район, поселок Центральный, Советская, 3, телефон: 91199		0101000020E6100000B0743E3C4B6C4440B6A2CD716E194740
44517	2	20	1501	18377	21482	\N	45.768498000000001	Краснодарский край, Белоглинский район, станица Успенская, Советская, 113, телефон: 92714		0101000020E6100000171230BABC8744404D8578245EE24640
44516	2	20	1501	18377	20868	\N	45.768498000000001	Краснодарский край, Белоглинский район, станица Успенская, Краснопартизанская, 151, телефон: 92585		0101000020E6100000171230BABC8744404D8578245EE24640
44518	2	20	1501	18472	22434	\N	45.734141999999999	Краснодарский край, Белоглинский район, хутор Туркинский, Алексенко, 88, телефон: 97344	Россия, Краснодарский край, Белоглинский район, поселок Туркинский	0101000020E610000025ECDB49447A44405D4F745DF8DD4640
44508	2	20	1501	17991	21291	\N	46.186217999999997	Краснодарский край, Белоглинский район, поселок Селекционный, переулок Почтовый, 6, телефон: 91495		0101000020E61000004303B16CE65A444098F6CDFDD5174740
44510	2	20	1501	18074	20639	\N	46.200816000000003	Краснодарский край, Белоглинский район, поселок Садовый, Садовая, 25, телефон: 91716		0101000020E6100000F12C414640754440BC41B456B4194740
44512	2	20	1501	18186	20892	\N	45.981605999999999	Краснодарский край, Белоглинский район, село Новопавловка, Соболя, 64, телефон: 94208		0101000020E6100000AD1402B9C47B444058C7F143A5FD4640
44515	2	20	1501	18315	23883	\N	45.802606030095497	Краснодарский край, Белоглинский район, станица Новолокинская, Красная, 1, телефон: 97448	Россия, Краснодарский край, Белоглинский район, поселок Новолокинская	0101000020E610000097C5C4E6E39A444064C91CCBBBE64640
44514	2	20	1501	18285	20866	\N	45.8881178793538	Краснодарский край, Белоглинский район, хутор Меклета, 60 лет СССР, 279, телефон: 96166	Россия, Краснодарский край, Белоглинский район, поселок Меклета	0101000020E610000033FAD170CA7E4440957EC2D9ADF14640
44511	2	20	1501	18158	22661	\N	46.273536	Краснодарский край, Белоглинский район, поселок Магистральный, Новая, 14, телефон: 91741		0101000020E6100000F3E2C4573B7C4440AB23473A03234740
44513	2	20	1501	18220	20622	\N	45.960416000000002	Краснодарский край, Белоглинский район, село Кулешовка, Мира, 153, телефон: 95242		0101000020E610000061FBC9181F8C44400F4757E9EEFA4640
44507	2	20	1501	17927	21290	\N	46.175530000000002	Краснодарский край, Белоглинский район, поселок Западный, Степная, 3, телефон: 91430	Россия, Краснодарский край, Белоглинский район, поселок Западный	0101000020E6100000865968E7344D4440C3BB5CC477164740
44501	2	20	1501	17464	21298	\N	46.083117000000001	Краснодарский край, Белоглинский район, село Белая Глина, Толстого, 56, телефон: 72405		0101000020E6100000B11875ADBD754440EE5EEE93A30A4740
44505	2	20	1501	17464	21726	\N	46.072522459948601	Краснодарский край, Белоглинский район, село Белая Глина, Первомайская, 159, телефон: 72822	Россия, Краснодарский край, Белоглинский район, поселок Белая Глина	0101000020E6100000083C3080F06F4440C91EA16648094740
44503	2	20	1501	17464	21726	\N	46.083117000000001	Краснодарский край, Белоглинский район, село Белая Глина, Первомайская, 282, телефон: 72147		0101000020E6100000B11875ADBD754440EE5EEE93A30A4740
44502	2	20	1501	17464	21726	\N	46.083117000000001	Краснодарский край, Белоглинский район, село Белая Глина, Первомайская, 367, телефон: 74088		0101000020E6100000B11875ADBD754440EE5EEE93A30A4740
44498	2	20	1501	17464	22093	\N	46.083117000000001	Краснодарский край, Белоглинский район, село Белая Глина, Крестьянская, 92, телефон: 75452		0101000020E6100000B11875ADBD754440EE5EEE93A30A4740
44504	2	20	1501	17464	22648	\N	46.083117000000001	Краснодарский край, Белоглинский район, село Белая Глина, Красная, 132, телефон: 72381		0101000020E6100000B11875ADBD754440EE5EEE93A30A4740
44499	2	20	1501	17464	21476	\N	46.083117000000001	Краснодарский край, Белоглинский район, село Белая Глина, Красная, 20, телефон: 74538		0101000020E6100000B11875ADBD754440EE5EEE93A30A4740
14068	1	17	\N	3130	22844	\N	58.045848999999997	г. Рыбинск, ул. Ошанина, 14		0101000020E6100000B3614D65516C4340F3C64961DE054D40
44500	2	20	1501	17464	20979	\N	46.098144051855002	Краснодарский край, Белоглинский район, село Белая Глина, Колхозная, 104, телефон: 73925	Россия, Краснодарский край, Белоглинский район, поселок Белая Глина	0101000020E61000000DDFC2BAF172444039268BFB8F0C4740
44506	2	20	1501	17464	20887	\N	46.083117000000001	Краснодарский край, Белоглинский район, село Белая Глина, Капитана Молчанова, 49, телефон: 72142		0101000020E6100000B11875ADBD754440EE5EEE93A30A4740
44403	2	20	722	12901	22367	\N	44.376691000000001	ст. Ширванская, Советская, 14, телефон: 28864		0101000020E61000007235B22B2DE7434049D9226937304640
44406	2	20	722	45660	20466	\N	44.252648999999998	с. Черниговское, Шоссейная, б/н, телефон: 34147		0101000020E61000001D3EE94482E14340FD2E6CCD56204640
44384	2	20	722	50827	23784	\N	44.409193000000002	хут. Цуревский, Полевая, 1, телефон: 9205032		0101000020E6100000CAC16C020CE543404660AC6F60344640
44394	2	20	722	12074	20741	\N	44.425500999999997	г. Хадыженск, Промысловая, 24, телефон: 40188		0101000020E61000002B1895D409C4434028B517D176364640
44385	2	20	722	12074	20741	\N	44.425500999999997	г. Хадыженск, Промысловая, 18, телефон: 40146		0101000020E61000002B1895D409C4434028B517D176364640
44388	2	20	722	12074	21552	\N	44.425500999999997	г. Хадыженск, Первомайская, 128, телефон: 49352		0101000020E61000002B1895D409C4434028B517D176364640
44387	2	20	722	12074	20985	\N	44.425500995913701	г. Хадыженск, Кирова, 144, телефон: 4-91-25	Россия, Краснодарский край, Апшеронский район, город Хадыженск	0101000020E610000006D49B51F3C3434028B517D176364640
44386	2	20	722	12074	20592	\N	44.4299297378357	г. Хадыженск, Аэродромная, 43/а, телефон: 41797		0101000020E6100000EE7C3F355EC44340DEC83CF207374640
44410	2	20	722	13244	21191	\N	44.112205000000003	с. Тубы, Клубная, 25, телефон: 4855819		0101000020E6100000EFC8586DFED743404EB9C2BB5C0E4640
44391	2	20	722	50897	24013	\N	44.369330488965701	х. Травалев, Чкалова, 93, телефон: 41554	Россия, Краснодарский край, Апшеронский район, поселок Травалев	0101000020E61000006D01A1F5F0C3434041B79734462F4640
44422	2	20	722	13794	21541	\N	44.611939	ст. Тверская, Советская, 5, телефон: 30229		0101000020E6100000EB39E97DE3CF4340CF126404544E4640
44416	2	20	722	45837	21558	\N	44.436624000000002	пос. Станционный, Привокзальная, б/н, телефон: 46500		0101000020E6100000BF2A172AFFBC43400953944BE3374640
44371	2	20	722	50305	20966	\N	44.439607531234401	хут. Спасов, Хадыженское шоссе, 85, телефон: 27388	Россия, Краснодарский край, Апшеронский район, поселок Спасов	0101000020E610000075012F336CD44340AD872F1345384640
44402	2	20	722	50513	22490	\N	44.277436152374101	ст. Самурская, Ленина, 29, телефон: 33191	Россия, Краснодарский край, Апшеронский район, поселок Самурская	0101000020E6100000B5DE6FB4E3EA4340D55DD90583234640
44411	2	20	722	13271	20707	\N	44.186697000000002	пос. Режет, Железнодорожная, 9, телефон: 2260610		0101000020E6100000062D246074D7434073A1F2AFE5174640
44409	2	20	722	45713	20704	\N	44.067155	пос. Отдаленный, Клубная, 13, телефон: 4858100		0101000020E6100000F69507E929DA4340A661F88898084640
44401	2	20	722	12821	21638	\N	44.300950999999998	пос. Новые Поляны, Советская, 1а, телефон: 33098		0101000020E61000006077BAF3C4E943406859F78F85264640
44399	2	20	722	50871	23946	\N	44.409040202334502	х. Николаенко, Дружбы, 2, телефон: 26288	Россия, Краснодарский край, Апшеронский район, поселок Николаенко	0101000020E61000006AC2F69331D64340BF60376C5B344640
44404	2	20	722	45619	21640	\N	44.272964999999999	ст. Нижегородская, Центральная, 45, телефон: 77134		0101000020E61000007233DC80CFF54340F0F96184F0224640
44400	2	20	722	50747	23525	\N	44.376375986479403	ст. Нефтяная, Красная, 132, телефон: 78142		0101000020E61000005BECF65965D24340E97FB9162D304640
44396	2	20	722	9757	20760	\N	44.374056000000003	п. Нефтегорск, Школьная, 8, телефон: 31410		0101000020E610000083A5BA8097DB4340B16F2711E12F4640
44395	2	20	722	9757	20760	\N	44.374056000000003	п. Нефтегорск, Школьная, 8,1, телефон: 31415		0101000020E610000083A5BA8097DB4340B16F2711E12F4640
44397	2	20	722	9757	20451	\N	44.374056000000003	п. Нефтегорск, Советская, 22, телефон: 31408		0101000020E610000083A5BA8097DB4340B16F2711E12F4640
14682	2	20	722	9757	20451	\N	44.374056000000003	п. Нефтегорск, Советская, 72,		0101000020E610000083A5BA8097DB4340B16F2711E12F4640
44408	2	20	722	13125	21406	\N	44.200076000000003	пос. Мезмай, Железнодорожная, 6, телефон: 32018		0101000020E6100000FBE93F6B7EFA4340755B22179C194640
44421	2	20	722	50844	23847	\N	44.464006380569202	хут. Малько, Ленина, 33, телефон: 27587	Россия, Краснодарский край, Апшеронский район, поселок Малько	0101000020E61000003CA06CCA15D84340EA92718C643B4640
44424	2	20	722	50884	23974	\N	44.592827793148999	ст.Линейная, Школьная, 1,	Россия, Краснодарский край, Апшеронский район, поселок Линейная	0101000020E61000000ABFD4CF9BBE43409813B4C9E14B4640
44423	2	20	722	50896	24012	\N	44.545673000000001	ст.Лесогорская, Центральная, 5,	Россия, Краснодарский край, Апшеронский район, поселок Лесогорская	0101000020E6100000BB9BA73AE4C44340B5A7E49CD8454640
44414	2	20	722	50651	23736	\N	44.412399000000001	ст. Куринская, Новицкого, 118, телефон: 46042	Россия, Краснодарский край, Апшеронский район, поселок Куринская	0101000020E6100000B08C0DDDECB5434099F38C7DC9344640
44415	2	20	722	50653	23251	\N	44.412991251943197	ст. Куринская, Железнодорожная, 16, телефон: 46046	Россия, Краснодарский край, Апшеронский район, поселок Куринская	0101000020E6100000BDC458A65FB643406B459BE3DC344640
44412	2	20	722	13329	23845	\N	44.485351999999999	ст. Кабардинская, Ленина, 43, телефон: 47081	Россия, Краснодарский край, Апшеронский район, поселок Кабардинская	0101000020E6100000B284B53176BE43402B86AB03203E4640
44413	2	20	722	13329	21540	\N	44.485351999999999	ст.Кабардинская, Клубная, 13,		0101000020E6100000B284B53176BE43402B86AB03203E4640
44546	2	20	722	50868	23942	\N	44.597740054784403	аоселок Заречный, улица Советская, 18, телефон: 3-82-34	Россия, Краснодарский край, Апшеронский район, поселок Заречный	0101000020E6100000FC19DEACC1DD43406AC18BBE824C4640
44383	2	20	722	50258	20551	\N	44.440507762311597	х. Зозулин, Угольная, б/н, телефон: 9439702		0101000020E6100000F7031E1840EA43402DD0EE9062384640
44418	2	20	722	13606	21224	\N	44.583891000000001	пос. Ерик, Школьная, 18, телефон: 76181		0101000020E6100000BE69FAEC80D94340E1B6B6F0BC4A4640
44405	2	20	722	12989	20520	\N	44.232165999999999	пос. Гуамка, Клубная, 1, телефон: 77138		0101000020E61000004F75C8CD70F343401F9F909DB71D4640
14066	1	17	\N	3130	22844	\N	58.045848999999997	г. Рыбинск, Ошанина, 14		0101000020E6100000B3614D65516C4340F3C64961DE054D40
44375	2	20	722	10038	20971	\N	44.453890000000001	г. Апшеронск, Пролетарская, 62, телефон: 28307		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44380	2	20	722	10038	21169	\N	44.453890000000001	г. Апшеронск, Ленина, 74, телефон: 20909		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44378	2	20	722	10038	21169	\N	44.453890000000001	г. Апшеронск, Ленина, 47, телефон: 92648		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44373	2	20	722	10038	20731	\N	44.453890000000001	г. Апшеронск, Краснознаменная, 40, телефон: 28272		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44370	2	20	722	10038	20492	\N	44.453890000000001	г. Апшеронск, Красноармейская, 2, телефон: 25574		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44377	2	20	722	10038	21573	\N	44.453890000000001	г. Апшеронск, Коммунистическая, 15, телефон: 28485		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44372	2	20	722	10038	21566	\N	44.453890000000001	г. Апшеронск, Исполкомовская, 2, телефон: 26166		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44342	2	20	722	50326	21097	\N	44.453890000000001	г. Апшеронск, Пролетарская, 79, телефон: 28464		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44379	2	20	722	50326	21178	\N	44.453890000000001	г.  Апшеронск, Ленина, 30, телефон: 91605		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44381	2	20	722	50326	21180	\N	44.453890000000001	г. Апшеронск, Королева, 122, телефон: 21834		0101000020E6100000B81FF0C000DE4340A0FD4811193A4640
44376	2	20	722	50326	21165	\N	44.473989720254004	г. Апшеронск, Комарова, 76, телефон: 26574	Россия, Краснодарский край, Апшеронский район, город Апшеронск	0101000020E6100000FD87F4DBD7DD4340C6504EB4AB3C4640
44340	2	20	1018	50276	20685	\N	45.035598	город-курорт Анапа, ст.Гостагаевская, Советская, 112, телефон: 25272	Россия, Краснодарский край, Анапский район	0101000020E6100000CEC133A149AA4240C9E6AA798E844640
44345	2	20	1018	32915	20665	\N	45.113779999999998	город-курорт Анапа, с.Юровка, Садовая, 202, телефон: 95224		0101000020E6100000B5DD04DF34B542402D78D157908E4640
44344	2	20	1018	32915	20665	\N	45.113779999999998	город-курорт Анапа, с.Юровка, Садовая, 91, телефон: 95198		0101000020E6100000B5DD04DF34B542402D78D157908E4640
44351	2	20	1018	50732	23478	\N	45.085836999999998	город-курорт Анапа, х.Черный, Свободы, 9, телефон: 95199	Россия, Краснодарский край, Анапский район, поселок Черный	0101000020E610000043E7357689B04240B4E4F1B4FC8A4640
44318	2	20	1018	8867	\N	\N	44.928854000000001	город-курорт Анапа, п.Чембурка, отделение связи, телефон: 33658		0101000020E6100000431D56B8E5AB4240206118B0E4764640
44364	2	20	1018	10545	20720	\N	44.980373	город-курорт Анапа, с.Цибанобалка, Совхозная, 17, телефон: 23166		0101000020E6100000E52A16BF29AC4240D270CADC7C7D4640
44352	2	20	1018	10545	20921	\N	44.980373	город-курорт Анапа, с.Цибанобалка, Садовая, 74, телефон: 23110	Россия, Краснодарский край, Анапский район, поселок Цибанобалка	0101000020E6100000E52A16BF29AC4240D270CADC7C7D4640
44328	2	20	1018	32786	21299	\N	44.894875343405303	город-курорт Анапа, х.Усатова Балка, Чехова, 33, телефон: 71867	Россия, Краснодарский край, Анапский район, поселок Усатова Балка	0101000020E6100000C85BAE7E6CB64240068195438B724640
44359	2	20	1018	10845	21061	\N	44.863776999999999	город-курорт Анапа, с.Супсех, Фрунзе, 72, телефон: 29791		0101000020E6100000C5909C4CDCAE4240BC04A73E906E4640
44368	2	20	1018	10845	21373	\N	44.863776999999999	с.Супсех, ул.Советская, 42, телефон: 29666		0101000020E6100000C5909C4CDCAE4240BC04A73E906E4640
44358	2	20	1018	10845	23422	\N	44.865516110058401	город-курорт Анапа, с.Су-Псех, Парковый, 20, телефон: 29232	Россия, Краснодарский край, Анапский район, поселок Супсех	0101000020E61000005E49F25CDFAD42401615713AC96E4640
44361	2	20	1018	10940	21341	\N	44.797590999999997	с.Сукко, Советская, 103, телефон: 93154, факс: 93154, email: уик261@mail.ru		0101000020E6100000910A630B41B64240BE4A3E7617664640
44334	2	20	1018	32832	21896	\N	45.0616318307193	город-курорт Анапа, п.Суворово-Черкесский, Пушкина, 2, телефон: 96203	Россия, Краснодарский край, Анапский район, поселок Суворов-Черкесский	0101000020E6100000DE5A26C3F1A242408C31B08EE3874640
44356	2	20	1018	10699	23837	\N	44.975593367304299	город-курорт Анапа, пос.Пятихатки, Солнечная, 7, телефон: 23272	Россия, Краснодарский край, Анапский район, поселок Пятихатки	0101000020E61000004E9D47C5FFA74240709A3E3BE07C4640
44362	2	20	1018	10985	21149	\N	44.934672999999997	город-курорт Анапа,  п.Просторный, Школьная, 1, телефон: 97333		0101000020E61000007155D97745B0424023BA675DA3774640
44355	2	20	1018	32978	21366	\N	45.038566000000003	"город-курорт Анапа, х.Нижняя Гостагайка, Гремахова, 4 ""А"", телефон: 96498"		0101000020E610000044300E2E1DAD4240685E0EBBEF844640
44354	2	20	1018	50355	21335	\N	45.014651000000001	"город-курорт Анапа, х.Красный Курган, Свободы, 33 ""А"", телефон: 73470"	Россия, Краснодарский край, Анапский район, поселок Красный Курган	0101000020E6100000D107CBD8D0AB424046ED7E15E0814640
44393	2	20	1018	50498	22372	\N	45.132021570210597	х. Красная Горка, Красногорская, 29, телефон: 43328	Россия, Краснодарский край, Анапский район, поселок Красная Горка	0101000020E61000002F302B14E9BA42401F2DCE18E6904640
44348	2	20	1018	50839	23835	\N	45.112015763873501	город-курорт Анапа, х.Иванов, Солнечная, 6, телефон: 95286	Россия, Краснодарский край, Анапский район, поселок Иванов	0101000020E61000008B71FE2614BA42407A50508A568E4640
44363	2	20	1018	9950	20855	\N	45.133775	город-курорт Анапа,  с.Джигинка, Центральная, здание администрации с/о, телефон: 76182		0101000020E61000007AA9D898D7AB4240DE02098A1F914640
44341	2	20	1018	9950	21092	\N	45.133775	город-курорт Анапа, с.Джигинка, Октябрьская, 30, телефон: 76294		0101000020E61000007AA9D898D7AB4240DE02098A1F914640
44339	2	20	1018	50272	20664	\N	45.019578111068	город-курорт Анапа, ст.Гостагаевская, Новороссийская, 100, телефон: 25115	Россия, Краснодарский край, Анапский район, поселок Гостагаевская	0101000020E610000034677DCA31C142404DDC2A8881824640
44338	2	20	1018	50272	20784	\N	45.021066199686402	город-курорт Анапа, ст.Гостагаевская, Мира, 45, телефон: 25450	Россия, Краснодарский край, Анапский район, поселок Гостагаевская	0101000020E610000055DB4DF04DC142405D876A4AB2824640
44263	2	20	755	6114	21074	\N	44.867705999999998	г.Абинск, Интернациональная, 73, телефон: 5-13-54		0101000020E610000032AA0CE36E14434080457EFD106F4640
44357	2	20	1018	50734	23480	\N	44.9657343701776	"х.Воскресенский, Мира, 4 ""А"", телефон: 23266, факс: 23266, email: уик257@mail.ru"	Россия, Краснодарский край, Анапский район, поселок Воскресенский	0101000020E6100000F3CCCB61F7A942405051F52B9D7B4640
44347	2	20	1018	50657	23281	\N	45.100596945389597	город-курорт Анапа, х.Вестник, Центральная, 39, телефон: 95150		0101000020E61000006D3A02B859BA4240B189CC5CE08C4640
44346	2	20	1018	32919	22240	\N	45.144806707111499	"город-курорт Анапа, х.Большой Разнокол, Южная, 1 ""А"", телефон: 99146"	Россия, Краснодарский край, Анапский район, поселок Бол. Разнокол	0101000020E6100000B8CA13083BBB4240AE9D280989924640
44329	2	20	1018	50740	23505	\N	45.054906296135201	ст.Благовещенская, Лобача, 3, телефон: 78210, факс: 78210, email: уик230@mail.ru	Россия, Краснодарский край, Анапский район, поселок Благовещенская	0101000020E610000052D2C3D0EA904240562DE92807874640
44277	2	20	755	40434	21641	\N	44.725288999999997	ст.Эриванская, Ленина, 32, телефон: 9-02-42		0101000020E6100000F3AACE6A8117434003931B45D65C4640
44274	2	20	755	50894	24007	\N	44.748954792728298	ст.Шапсугская, Красная, 19, телефон: 6-12-44	Россия, Краснодарский край, Абинский район, поселок Шапсугская	0101000020E610000054C8957A160A43407D96E7C1DD5F4640
44287	2	20	755	50743	23514	\N	44.843348488661498	ст.Холмская, Каменеческая, 19, телефон: 3-11-78	Россия, Краснодарский край, Абинский район, шоссе главное шоссе	0101000020E610000093399677D5314340D192C7D3F26B4640
44283	2	20	755	50559	23971	\N	44.842743957943902	ст.Холмская, Лесная, 1, телефон: 3-12-81	Россия, Краснодарский край, Абинский район, поселок Холмская	0101000020E61000001E537765173243403B730F09DF6B4640
44284	2	20	755	50559	22773	\N	44.852800316577003	ст.Холмская, Толстого, 62, телефон: 3-16-85	Россия, Краснодарский край, Абинский район, поселок Холмская	0101000020E6100000569E40D829324340B003E78C286D4640
44282	2	20	755	50559	23343	\N	44.858356133564001	ст.Холмская, Рудничная, 5Б, телефон: 3-11-20	Россия, Краснодарский край, Абинский район, поселок Холмская	0101000020E6100000ACE63922DF314340A629029CDE6D4640
44285	2	20	755	50559	22950	\N	44.843397339053197	ст.Холмская, Мира, 151, телефон: 3-12-01	Россия, Краснодарский край, Абинский район, поселок Холмская	0101000020E610000037548CF337314340B345D26EF46B4640
44286	2	20	755	50559	22990	\N	44.842787000000001	ст.Холмская, Ленина, 181, телефон: 3-11-86	Россия, Краснодарский край, Абинский район, поселок Холмская	0101000020E610000020EF552B133243403A3FC571E06B4640
44296	2	20	755	48041	22976	\N	45.077317744049402	ст.Федоровская, Первомайская, 1, телефон: 98-1-34	Россия, Краснодарский край, Абинский район, поселок Федоровская	0101000020E6100000E197FA79533B434031B2648EE5894640
44294	2	20	755	48041	22549	\N	45.078530999999998	станица Федоровская, Красная, 3, телефон: 9-83-19		0101000020E6100000F9D687F5463B4340705CC64D0D8A4640
44288	2	20	755	7464	20586	\N	44.773817999999999	пос.Синегорск, Лесная, 3, телефон: 99-2-50		0101000020E610000017D86322A52B43402F87DD770C634640
44276	2	20	755	6909	20820	\N	44.837068945557903	с.Светлогорское, Центральная, 1А, телефон: 9-55-44	Россия, Краснодарский край, Абинский район, поселок Светлогорское	0101000020E61000001AA721AAF01B43406ABFB513256B4640
44275	2	20	755	50440	\N	\N	44.872208030663003	"пос.Пролетарий, здание филиала  МАУ ""Абинский КДЦ"",, телефон: 5-26-30"	Россия, Краснодарский край, Абинский район	0101000020E61000007AC2120F281F4340A0A70183A46F4640
44879	2	20	755	45897	21019	\N	44.932198	пос. Первомайский, Мира, 33А, телефон: 97182		0101000020E61000000400C79E3D394340C4B2994352774640
44298	2	20	755	50831	23804	\N	45.122816625689303	х.Ольгинский, Первомайская, 17, телефон: 63-2-92		0101000020E61000005DA5BBEB6C2E43404832AB77B88F4640
44530	2	20	755	48164	20700	\N	44.723739000000002	поселок Новый, улица Есенина, 8, телефон: 3-86-68		0101000020E61000007C4276DEC62A43407DEBC37AA35C4640
44289	2	20	755	48164	24038	\N	44.724347109998099	пос.Новый, Офицерская, 1, телефон: 6-81-55	Россия, Краснодарский край, Абинский район, поселок Новый	0101000020E6100000CDE49B6D6E2A434055FA0967B75C4640
44292	2	20	755	50472	22176	\N	45.012191999999999	ст.Мингрельская, Советская, 67, телефон: 97-3-49		0101000020E61000003FE257ACE12A4340ECA2E8818F814640
44293	2	20	755	7675	20559	\N	45.012191999999999	ст.Мингрельская, Мельничная, 20, телефон: 9-75-41		0101000020E61000003FE257ACE12A4340ECA2E8818F814640
46640	2	20	755	50544	23860	\N	45.1708910255023	хутор Ленинский, Красная, 36, телефон: 3-91-58	Россия, Краснодарский край, Абинский район, поселок Ленинский	0101000020E6100000FD1186014B1E434022179CC1DF954640
44290	2	20	755	50662	23287	\N	44.9310481598623	х.Краснооктябрьский, Пионерская, 38, телефон: 4-41-63		0101000020E6100000919DB7B1D92F4340CB80B3942C774640
44295	2	20	755	50707	23436	\N	45.088847000000001	х.Екатериновский, Суворова, 7А, телефон: 66-3-85	Россия, Краснодарский край, Абинский район, поселок Екатериновский	0101000020E6100000BD378600E03E434082ACA7565F8B4640
44245	2	20	755	5327	21466	\N	44.992956999999997	с.Варнавинское, Красная, 75, телефон: 9-42-60		0101000020E610000019709692E5184340C9AA0837197F4640
44280	2	20	755	6623	22146	\N	44.846198999999999	пос.Ахтырский, Школьная, 17, телефон: 3-31-38		0101000020E61000006DC83F33882743403674B33F506C4640
43979	2	20	755	6623	21336	\N	44.846198999999999	п.Ахтырский, Свободы, 8, телефон: 3-72-27		0101000020E61000006DC83F33882743403674B33F506C4640
44279	2	20	755	6623	21486	\N	44.846198999999999	пос.Ахтырский, Мира, 6, телефон: 6-24-43		0101000020E61000006DC83F33882743403674B33F506C4640
47070	2	20	755	6623	20521	\N	44.846198999999999	пос.Ахтырский, Красная, 25, телефон: 3-71-95		0101000020E61000006DC83F33882743403674B33F506C4640
44278	2	20	755	6623	20521	\N	44.846198999999999	пос.Ахтырский, Красная, 40, телефон: 6-22-50		0101000020E61000006DC83F33882743403674B33F506C4640
44281	2	20	755	6623	21491	\N	44.846198999999999	пос.Ахтырский, Колхозная, 46, телефон: 3-62-24		0101000020E61000006DC83F33882743403674B33F506C4640
44271	2	20	755	6114	20651	\N	44.867705999999998	г.Абинск, Советов, 2А, телефон: 5-12-95		0101000020E610000032AA0CE36E14434080457EFD106F4640
44268	2	20	755	6114	20651	\N	44.867705999999998	г.Абинск, Советов, 35, телефон: 5-25-78		0101000020E610000032AA0CE36E14434080457EFD106F4640
44272	2	20	755	6114	21303	\N	44.867705999999998	г.Абинск, Набережная, 59А, телефон: 4-21-06		0101000020E610000032AA0CE36E14434080457EFD106F4640
14072	1	17	\N	3130	22572	\N	58.045848999999997	г. Рыбинск, Моховая, 18		0101000020E6100000B3614D65516C4340F3C64961DE054D40
44262	2	20	755	6114	21074	\N	44.867705999999998	г.Абинск, Интернациональная, 32, телефон: 5-13-43		0101000020E610000032AA0CE36E14434080457EFD106F4640
44260	2	20	755	6114	21074	\N	44.867705999999998	г. Абинск, Интернациональная, 23, телефон: 5-15-54		0101000020E610000032AA0CE36E14434080457EFD106F4640
44266	2	20	755	6114	21076	\N	44.868184382466197	г.Абинск, Володарского, 55, телефон: 5-20-36	Россия, Краснодарский край, Абинский район, город Абинск	0101000020E6100000AF27BA2EFC1443408A743FA7206F4640
44264	2	20	755	6114	20465	\N	44.867705999999998	г.Абинск, Вокзальная, 16, телефон: 5-18-98		0101000020E610000032AA0CE36E14434080457EFD106F4640
47069	2	20	755	50350	21622	\N	44.867705999999998	г.Абинск, Тищенко, 84, телефон: 5-27-35		0101000020E610000032AA0CE36E14434080457EFD106F4640
44269	2	20	755	50350	21503	\N	44.867705999999998	г.Абинск, Советов, 15, телефон: 4-48-81		0101000020E610000032AA0CE36E14434080457EFD106F4640
44261	2	20	755	50350	21497	\N	44.867705999999998	г.Абинск, Пролетарская, 3, телефон: 5-35-68		0101000020E610000032AA0CE36E14434080457EFD106F4640
47071	2	20	755	50350	21318	\N	44.865491828663998	г.Абинск, Набережная, 11, телефон: 4-26-48		0101000020E61000003AB2F2CB601443408E791D71C86E4640
44267	2	20	755	50350	22369	\N	44.867705999999998	г.Абинск, Володарского, 1, телефон: 4-43-29		0101000020E610000032AA0CE36E14434080457EFD106F4640
27878	2	22	\N	51748	27822	\N	48.776510000000002	хутор Первомайский, ул.Первомайская, д.19 А. Первомайская НОШ		0101000020E6100000E21FB6F4683046402C82FFAD64634840
28057	2	22	\N	51447	27041	\N	49.383009000000001	хутор Княженский-1, Левинская, 10, Княженский-1 сельский клуб		0101000020E6100000F5F3A622152446406E895C7006B14840
28385	2	22	\N	51444	\N	\N	49.383009000000001	хутор Кепенский, Кепенский сельский клуб		0101000020E6100000F5F3A622152446406E895C7006B14840
28677	2	22	\N	16895	26809	\N	49.769717999999997	Волгоградская область, город Фролово, им.Чапаева, 17		0101000020E61000001CEE23B726D145403E92921E86E24840
28679	2	22	\N	16895	27047	\N	49.769717999999997	Волгоградская область, город Фролово, Фроловская, 6		0101000020E61000001CEE23B726D145403E92921E86E24840
28689	2	22	\N	16895	26459	\N	49.769717999999997	Волгоградская область, город Фролово, Строителей, 138		0101000020E61000001CEE23B726D145403E92921E86E24840
28687	2	22	\N	16895	26459	\N	49.769717999999997	Волгоградская область, город Фролово, Строителей, 206	Россия, Волгоградская область, Фролово	0101000020E61000001CEE23B726D145403E92921E86E24840
28680	2	22	\N	16895	27224	\N	49.769717999999997	Волгоградская область, город Фролово, им.Свердлова, 33		0101000020E61000001CEE23B726D145403E92921E86E24840
28682	2	22	\N	16895	26661	\N	49.769717999999997	Волгоградская область, город Фролово, Революционная, 17	Россия, Волгоградская область, Фролово	0101000020E61000001CEE23B726D145403E92921E86E24840
28678	2	22	\N	16895	26661	\N	49.767414455197297	Волгоградская область, город Фролово, Революционная, 13	Россия, Волгоградская область, Фролово городской округ	0101000020E6100000252367614FD345400C3F389F3AE24840
28672	2	22	\N	16895	27157	\N	49.770742984208503	Волгоградская область, город Фролово, Рабочая, 5а	Россия, Волгоградская область, Фролово	0101000020E610000002BC051214D145407B4FE5B4A7E24840
28670	2	22	\N	16895	27157	\N	49.769717999999997	Волгоградская область, город Фролово, Рабочая, 62	Россия, Волгоградская область, Фролово	0101000020E61000001CEE23B726D145403E92921E86E24840
28686	2	22	\N	16895	27251	\N	49.785951228094497	Волгоградская область, город Фролово, Пролетарская, 326	Россия, Волгоградская область, Фролово городской округ	0101000020E6100000CA8D226B0DD1454016A1D80A9AE44840
28691	2	22	\N	16895	26888	\N	49.769717999999997	Волгоградская область, город Фролово, Орджоникидзе, 10		0101000020E61000001CEE23B726D145403E92921E86E24840
28684	2	22	\N	16895	26784	\N	49.769717999999997	Волгоградская область, город Фролово, Народная, 97		0101000020E61000001CEE23B726D145403E92921E86E24840
28676	2	22	\N	16895	26784	\N	49.769717999999997	Волгоградская область, город Фролово, Народная, 23	Россия, Волгоградская область, Фролово	0101000020E61000001CEE23B726D145403E92921E86E24840
28681	2	22	\N	16895	26969	\N	49.769717999999997	Волгоградская область, город Фролово, Московская, 66		0101000020E61000001CEE23B726D145403E92921E86E24840
28685	2	22	\N	16895	27165	\N	49.769717999999997	Волгоградская область, город Фролово, Красноармейская, 79а		0101000020E61000001CEE23B726D145403E92921E86E24840
28674	2	22	\N	16895	27100	\N	49.769717999999997	Волгоградская область, город Фролово, Зеленая, 50		0101000020E61000001CEE23B726D145403E92921E86E24840
28690	2	22	\N	16895	26414	\N	49.769717999999997	Волгоградская область, город Фролово, Заречный квартал, 11а		0101000020E61000001CEE23B726D145403E92921E86E24840
28675	2	22	\N	16895	26414	\N	49.769717999999997	Волгоградская область, город Фролово, Заречный квартал, 36		0101000020E61000001CEE23B726D145403E92921E86E24840
28683	2	22	\N	16895	26522	\N	49.769717999999997	Волгоградская область, город Фролово, Донская, 7		0101000020E61000001CEE23B726D145403E92921E86E24840
28688	2	22	\N	16895	27070	\N	49.769717999999997	Волгоградская область, город Фролово, Гагарина, 23		0101000020E61000001CEE23B726D145403E92921E86E24840
28524	2	22	\N	7479	27208	\N	50.786504999999998	"г. Урюпинск, пр. Ленина, 64, МП Гостиница ""Урюпинск"""		0101000020E61000003B191C25AF024540FB912232AC644940
28472	2	22	\N	7479	26773	\N	50.786504999999998	г. Урюпинск, ул. Чапаева, 16, МОУ Гимназия	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28518	2	22	\N	7479	27260	\N	50.786504999999998	г. Урюпинск, ул. Советская, 150А, МОУ СОШ №4	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28528	2	22	\N	7479	26478	\N	50.786504999999998	"г. Урюпинск, ул. Разливаева, 6, ГОУНПО ""Казачье кадетское"" ПУ-41"	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28517	2	22	\N	7479	27261	\N	50.786504999999998	г. Урюпинск, ул. Пушкина, 111, Урюпинская автошкола РОСТО		0101000020E61000003B191C25AF024540FB912232AC644940
28523	2	22	\N	7479	26906	\N	50.786504999999998	г. Урюпинск, ул. Н. Островского, 20, Очно-заочная вечерняя школа УПЦ		0101000020E61000003B191C25AF024540FB912232AC644940
28515	2	22	\N	7479	26897	\N	50.786504999999998	"г. Урюпинск, ул. Октябрьская, ГОУ СПО ""Медицинский колледж №5 г.Урюпинск"", 43"		0101000020E61000003B191C25AF024540FB912232AC644940
28514	2	22	\N	7479	26897	\N	50.786504999999998	"г. Урюпинск, ул. Октябрьская, 6, МОУ ДОД ""Детская школа искусств"""	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28527	2	22	\N	7479	26943	\N	50.786504999999998	"г. Урюпинск, ул. Московская, 9, НОУ ВПО ""ВИБ"""		0101000020E61000003B191C25AF024540FB912232AC644940
28526	2	22	\N	7479	26477	\N	50.786504999999998	г. Урюпинск, ул. Мичурина, 42, МОУ СОШ №7	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28522	2	22	\N	7479	27093	\N	50.800852371990402	г. Урюпинск, ул. М. Горького, 47, МОУ СОШ №3	Россия, Волгоградская область, Урюпинск	0101000020E610000088BCE5EAC7024540D5777E5182664940
28516	2	22	\N	7479	26968	\N	50.786504999999998	"г. Урюпинск, ул. Льва Толстого, 42, МБОУ ""Лицей"""		0101000020E61000003B191C25AF024540FB912232AC644940
28510	2	22	\N	7479	26560	\N	50.794559407198598	г. Урюпинск, ул. Красноармейская, 5, МОУДОД Центр детского творчества	Россия, Волгоградская область, Урюпинск	0101000020E610000082E7DEC325FF444009DFFB1BB4654940
28513	2	22	\N	7479	26675	\N	50.786504999999998	"г. Урюпинск, ул. Гагарина, 29, Кинотеатр ""МИР"""	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28519	2	22	\N	7479	26823	\N	50.786504999999998	"г. Урюпинск, ул. Волгоградская, 1А, МДОУ Детский сад №5 ""Радуга"""		0101000020E61000003B191C25AF024540FB912232AC644940
28520	2	22	\N	7479	27117	\N	50.786504999999998	"г. Урюпинск, ул. Весенняя, 2, МДОУ Десткий сад №1 ""Березка"""		0101000020E61000003B191C25AF024540FB912232AC644940
28525	2	22	\N	7479	27094	\N	50.786504999999998	г. Урюпинск, ул. Большая Мушкетовская, 28, МУ Благоустройство и озеленение	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28512	2	22	\N	7479	26783	\N	50.786504999999998	г. Урюпинск, ул. 50-лет Победы, ГОУ Урюпинская Школа-интернат, 5		0101000020E61000003B191C25AF024540FB912232AC644940
28511	2	22	\N	7479	26783	\N	50.786504999999998	г. Урюпинск, ул. 50-лет Победы, 16, МОУ СОШ №6	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28521	2	22	\N	7479	27180	\N	50.786504999999998	г. Урюпинск, ул. Гастелло, 3, МОУ СОШ №5	Россия, Волгоградская область, Урюпинск	0101000020E61000003B191C25AF024540FB912232AC644940
28425	2	22	\N	51603	27311	\N	48.751159515441799	п. Третья Карта, Тракторная, 2/1, ФАП	Россия, Волгоградская область, поселок Третья Карта	0101000020E610000085B01A4B585B46401C08C90226604840
28449	2	22	\N	51547	27217	\N	48.695573000000003	п. Третий Решающий, Центральная, 2, Здание школы	Россия, Волгоградская область, поселок Третий Решающий	0101000020E610000082700514EA5B4640857D3B8908594840
28481	2	22	\N	51456	27059	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район, г.Суровикино, Орджоникидзе, 69		0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28423	2	22	\N	51659	27457	\N	48.748002999999997	х. Старенький, Центральная, 9, Здание клуба	Россия, Волгоградская область, хутор Старенький	0101000020E6100000F30016F9F5534640AA27F38FBE5F4840
28409	2	22	\N	51417	27296	\N	48.716329979607103	р.п.Средняя Ахтуба, Октябрьская, 91, ЖКО	Россия, Волгоградская область, поселок Средняя Ахтуба, Октябрьская улица, 91	0101000020E61000006BD8EF89756E4640649291B3B05B4840
28412	2	22	\N	51417	27115	\N	48.712209999999999	"р.п. Средняя Ахтуба, Ленина, 63, КДЦ ""Юбилейный"""	Россия, Волгоградская область, поселок Средняя Ахтуба	0101000020E6100000028063CF9E6F46402CF180B2295B4840
28410	2	22	\N	51417	27006	\N	48.712209999999999	"р.п.Средняя Ахтуба, Гагарина, 114, ДС ""Дельфиненок"""	Россия, Волгоградская область, поселок Средняя Ахтуба	0101000020E6100000028063CF9E6F46402CF180B2295B4840
28394	2	22	\N	51490	27109	\N	49.575665000000001	город Серафимович, ул.Пролетарская, 7, СОШ№1		0101000020E6100000DE3AFF76D95D4540D6390664AFC94840
28363	2	22	\N	51466	\N	\N	50.123038999999999	хутор Рыбный, Рыбинский сельский клуб		0101000020E6100000AE2D3C2F15C94640F790F0BDBF0F4940
28450	2	22	\N	51548	27220	\N	48.702848331436101	п. Рыбачий, Центральная, 42, Контора рыболовецкого колхоза	Россия, Волгоградская область, поселок Рыбачий	0101000020E6100000A629029CDE5D46408E075BECF6594840
27924	2	22	\N	51468	27071	\N	50.139259000000003	г.Петров Вал, пер.Карла Маркса, 1		0101000020E61000002FDB4E5B239A46403B56293DD3114940
28262	2	22	\N	51449	27045	\N	50.049681912030003	г. Палласовка, ул. Пугачева, 29-а	Россия, Волгоградская область, Палласовский район, Палласовка	0101000020E61000001021AE9CBD7147409599D2FA5B064940
28146	2	22	\N	51573	27333	\N	50.524201660866503	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Ленина, 70		0101000020E6100000C366800BB2554540B83F170D19434940
28418	2	22	\N	51612	27344	\N	48.709304400205198	х. Новенький, Центральная, 16, здание сельского клуба	Россия, Волгоградская область, хутор Новенький	0101000020E6100000DCF4673F5260464004763579CA5A4840
27960	2	22	\N	14060	\N	\N	50.068270031066703	х.Михайловка, здание Михайловской школы	Россия, Волгоградская область, Михайловка	0101000020E6100000AB97DF69329F454022A64412BD084940
28612	2	22	\N	14060	26745	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, площадь Конституции, 1, МУК ГДК		0101000020E610000044183F8D7B9F4540EC134031B2084940
28632	2	22	\N	14060	27140	\N	50.069043461727802	Волгоградская область, муниципальное образование городской округ - город Михайловка, Ясный, 5, МОУ ООШ №8	Россия, Волгоградская область, Михайловка	0101000020E6100000CFDBD8EC489F45404582A966D6084940
28614	2	22	\N	14060	27201	\N	50.071584645595898	Волгоградская область, муниципальное образование городской округ - город Михайловка, Южная, 1, общежитие тех. техникума	Россия, Волгоградская область, Михайловка	0101000020E61000000C772E8CF49E45402CF180B229094940
27406	2	22	\N	416	27590	\N	48.61506	Волгоградская область, город Волгоград, Кировский район, Турбинная, СОШ №100, 182		0101000020E61000005B5D4E0988354640F4893C49BA4E4840
28626	2	22	\N	14060	26570	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Энгельса, 19, МОУ СОШ №7	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28610	2	22	\N	14060	26570	\N	50.070700770912097	Волгоградская область, муниципальное образование городской округ - город Михайловка, Энгельса, 12, ГОУ ПТУ №23	Россия, Волгоградская область, Михайловка	0101000020E610000081B3942C279F4540B265F9BA0C094940
28617	2	22	\N	14060	26590	\N	50.0773018142526	"Волгоградская область, муниципальное образование городской округ - город Михайловка, Стройная, 42, МДОУ Школа-сад №14 ""Теремок"""	Россия, Волгоградская область, Михайловка городской округ	0101000020E6100000ADC1FBAA5C9E45402CF52C08E5094940
28613	2	22	\N	14060	27298	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Смехова, 1, МОУ СОШ №4	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28619	2	22	\N	14060	26832	\N	50.067937999999998	"Волгоградская область, муниципальное образование городской округ - город Михайловка, Свободы, 21, ГУП ПТП ""Михайловское"""	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28628	2	22	\N	14060	26609	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Республиканская, 42, МУК ЦБС гор. детская библиотека	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28625	2	22	\N	14060	26609	\N	50.079014608922897	Волгоградская область, муниципальное образование городской округ - город Михайловка, Республиканская, 26, МУК ЦБС центр. гор. библиотека		0101000020E6100000A321E3512AA145405C72DC291D0A4940
28622	2	22	\N	14060	26608	\N	50.063836913587402	"Волгоградская область, муниципальное образование городской округ - город Михайловка, Пирогова, 2, МОУ ДОД ""Стация юных юнатов"""		0101000020E6100000B43EE5982C9E45402BA391CF2B084940
28630	2	22	\N	14060	26844	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Новороссийская, 1, МОУ СОШ №10	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28609	2	22	\N	14060	27197	\N	50.068969802486201	Волгоградская область, муниципальное образование городской округ - город Михайловка, Мичурина, 26, МОУ СОШ №3	Россия, Волгоградская область, Михайловка	0101000020E6100000D2AB014A439F4540DB334B02D4084940
28631	2	22	\N	14060	27023	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Мира, 79, МОУ Открытая сменная школа	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28611	2	22	\N	14060	27019	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Магистральная, 2, МУ Мих. спортивный комплекс	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28634	2	22	\N	14060	26597	\N	50.069780050679803	"Волгоградская область, муниципальное образование городской округ - город Михайловка, Ленина, 185-В, МДОУ Дет. сад №21 ""Родничок"""	Россия, Волгоградская область, Михайловка	0101000020E61000008483BD89219F45401BF5108DEE084940
28624	2	22	\N	14060	26597	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Ленина, 66, МОУ СОШ №1	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28621	2	22	\N	14060	26839	\N	50.067937999999998	"Волгоградская область, муниципальное образование городской округ - город Михайловка, Кубанский, 2, МУ ""Клуб Заозерье"""		0101000020E610000044183F8D7B9F4540EC134031B2084940
28615	2	22	\N	14060	27129	\N	50.067920999999998	"Волгоградская область, муниципальное образование городской округ - город Михайловка, Крупской, 99-Е, МДОУ Дет.сад №25 ""Колосок"""	Россия, Волгоградская область, Михайловка	0101000020E61000009772BED87B9F454016DBA4A2B1084940
28633	2	22	\N	14060	27210	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, Карельская, 2-В, МУП Водоканал	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28623	2	22	7114	\N	26837	\N	50.059491340185602	Волгоградская область, муниципальное образование городской округ - город Михайловка, Гоголя, 29, ГОУ СПО Михайловский педколледж	Россия, Волгоградская область, Михайловка городской округ	0101000020E6100000E7E099D0249F454003B4AD669D074940
28616	2	22	\N	14060	26577	\N	50.070369313682399	Волгоградская область, муниципальное образование городской округ - город Михайловка, Байкальская, 31, МУ Себровский ДК	Россия, Волгоградская область, Михайловка	0101000020E610000012178046E99E45407CD3F4D901094940
28620	2	22	\N	14060	26630	\N	50.0689611342559	"Волгоградская область, муниципальное образование городской округ - город Михайловка, Александра Невского, 12, Подростковый клуб ""Одуванчик"""		0101000020E61000002E8CF4A2769B454088D9CBB6D3084940
28629	2	22	\N	14060	26864	\N	50.067937999999998	Волгоградская область, муниципальное образование городской округ - город Михайловка, 2 Краснознаменская, 18-А, МУ Соц.дос. центр для подрост	Россия, Волгоградская область, Михайловка	0101000020E610000044183F8D7B9F4540EC134031B2084940
28627	2	22	\N	14060	27133	\N	50.068767237931503	Волгоградская область, муниципальное образование городской округ - город Михайловка, 2 Краснознаменская, 55, Городской ЗАГС	Россия, Волгоградская область, Михайловка городской округ	0101000020E61000001503249A409D4540A305685BCD084940
28037	2	22	\N	51379	27114	\N	48.703035999999997	г. Ленинск, Крупской, 7		0101000020E6100000A9C1340C1F9B464090F46915FD594840
28422	2	22	\N	51669	27480	\N	48.76885	х. Лебяжья Поляна, Павших Борцов, 4,Дом культуры	Россия, Волгоградская область, хутор Лебяжья Поляна	0101000020E6100000A774B0FECF594640CAC342AD69624840
28426	2	22	\N	51495	27121	\N	48.724759283640601	п. Красный Буксир, Шоссейная, 2, клуб	Россия, Волгоградская область, поселок Красный Буксир	0101000020E6100000B72572C1195A4640A73D25E7C45C4840
28398	2	22	\N	51593	27293	\N	48.706816050797798	г.Краснослободск, Космонавтов, 22, школа № 2	Россия, Волгоградская область, Краснослободск, улица Космонавтов, 22	0101000020E610000009A52F849C49464010255AF2785A4840
28403	2	22	\N	51593	27542	\N	48.681305000000002	г.Краснослободжск, Горького, 1, школа № 3	Россия, Волгоградская область, Краснослободск, улица Горького, 1	0101000020E61000009015FC36C4464640F7CC920035574840
28396	2	22	\N	51593	27292	\N	48.698242999999998	г.Краснослободск, Ленина, 164, школа № 4	Россия, Волгоградская область, Краснослободск	0101000020E6100000C5758C2B2E4A464099D4D00660594840
28424	2	22	\N	51496	27127	\N	48.76211	п. Кировец, Ленина, 72а, сельский клуб	Россия, Волгоградская область, поселок Кировец	0101000020E6100000DDB1D826155D46402FFA0AD28C614840
28603	2	22	\N	12417	26776	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, Южный городок, Учреждение ЯР 154/5	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28587	2	22	\N	12417	26868	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, Феоктистова, 8 Школа №15	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28599	2	22	\N	12417	27566	\N	50.0938089447774	Волгоградская область, городской округ город Камышин, Титова, 11 МОУСОШ№8	Россия, Волгоградская область, Камышин	0101000020E6100000B6BE4868CBB346400589EDEE010C4940
28577	2	22	\N	12417	26717	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, Советская, 40	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28576	2	22	\N	12417	26717	\N	50.084034726714897	Волгоградская область, город Камышин, Советская, 36	Россия, Волгоградская область, Камышин городской округ	0101000020E61000004015376E31B34640145CACA8C10A4940
28608	2	22	\N	12417	27391	\N	50.105934195781899	Волгоградская область, городской округ город Камышин, Серафимовича, 67 МОУСОШ№5	Россия, Волгоградская область, Камышин городской округ	0101000020E6100000CEDF844204B6464069C4CC3E8F0D4940
28575	2	22	\N	12417	27496	\N	50.098557923339399	Волгоградская область, городской округ город Камышин, Республиканская, 25	Россия, Волгоградская область, Камышин	0101000020E61000005111A7936CB346402C616D8C9D0C4940
28583	2	22	\N	12417	27497	\N	50.098281223509098	Волгоградская область, городской округ город Камышин, Пролетарская, 6		0101000020E6100000C47B0E2C47B44640BA68C878940C4940
28604	2	22	\N	12417	27319	\N	50.0728775201841	Волгоградская область, городской округ город Камышин, Набережная, 11 МОУСОШ№4	Россия, Волгоградская область, Камышин городской округ	0101000020E610000038842A357BB44640884CF91054094940
28589	2	22	\N	12417	27703	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, Мира, 21 Школа №14	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28590	2	22	\N	12417	9783	\N	50.103360339612003	Волгоградская область, городской округ город Камышин, Ленина, 5 Камышинский ТИ		0101000020E61000001F9F909DB7B5464077DB85E63A0D4940
28601	2	22	\N	12417	27392	\N	50.103029109415097	Волгоградская область, городской округ город Камышин, Кубанская, 96	Россия, Волгоградская область, Камышин городской округ	0101000020E61000008AB0E1E995B4464011C5E40D300D4940
28593	2	22	\N	12417	27662	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, Короленко, 24 ДЮСШ №2	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28595	2	22	\N	12417	27368	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, Королева, 18 МОУСОШ№16	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28600	2	22	\N	12417	27330	\N	50.097066572041498	Волгоградская область, городской округ город Камышин, Казанская, 35/а	Россия, Волгоградская область, Камышин	0101000020E6100000C6A52A6D71B34640AB4203B16C0C4940
28574	2	22	\N	12417	26496	\N	50.098782	Волгоградская область, городской округ город Камышин, Давыдова, 27	Россия, Волгоградская область, Камышин	0101000020E61000003C6876DD5BB346407CB779E3A40C4940
28607	2	22	\N	12417	27466	\N	50.095796676035398	"Волгоградская область, городской округ город Камышин, Волгоградская, 37/к АК 1733 ""Камышинская"""	Россия, Волгоградская область, Камышин	0101000020E6100000A0F99CBB5DB3464007077B13430C4940
28579	2	22	\N	12417	27278	\N	50.100820849246396	Волгоградская область, городской округ город Камышин, Воинов интернационалистов, 8		0101000020E61000005C3AE63C63B5464001E0D8B3E70C4940
28605	2	22	\N	12417	27419	\N	50.095506803724803	Волгоградская область, городской округ город Камышин, Буденного, 16	Россия, Волгоградская область, Камышин городской округ	0101000020E6100000EE5F596952B4464000C5C892390C4940
28602	2	22	\N	12417	26979	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, 5 микрорайон, 63а	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28582	2	22	\N	12417	26979	\N	50.097618690183502	Волгоградская область, городской округ город Камышин, 5 микрорайон, 46 Школа №7	Россия, Волгоградская область, Камышин	0101000020E610000014CE6E2D93B34640EF3B86C77E0C4940
28580	2	22	\N	12417	26979	\N	50.0918763487836	Волгоградская область, городской округ город Камышин, 5 микрорайон, дом 12	Россия, Волгоградская область, Камышин	0101000020E6100000C70DBF9B6EB34640C6A4BF97C20B4940
28598	2	22	\N	12417	26966	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, 4 микрорайон, 17 Политехнический колледж	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28597	2	22	\N	12417	26966	\N	50.1026978769153	Волгоградская область, городской округ город Камышин, 4 микрорайон, 22 Общежитие Политехнического колле		0101000020E61000005740A19E3EB64640ABAE4335250D4940
28606	2	22	\N	12417	26930	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, 333 Стрелковой дивизии, 32 ПУ№57	Россия, Волгоградская область, Камышин	0101000020E61000008CBE823463B346407F4E417E360C4940
28585	2	22	\N	12417	26988	\N	50.100489601392503	Волгоградская область, городской округ город Камышин, 3 микрорайон, 24 Школа №18	Россия, Волгоградская область, Камышин городской округ	0101000020E610000011E2CAD93BB546409BC937DBDC0C4940
28578	2	22	\N	12417	27517	\N	50.097397843694402	Волгоградская область, городской округ город Камышин, Металлургов, 9	Россия, Волгоградская область, Камышин	0101000020E610000069FE98D6A6B346401059A489770C4940
28594	2	22	\N	12417	27721	\N	50.098943747622101	Волгоградская область, городской округ город Камышин, Короленко, 24 ДЮСШ№2	Россия, Волгоградская область, Камышин	0101000020E61000008D429259BDB3464056116E32AA0C4940
28581	2	22	\N	12417	27135	\N	50.095413000000001	Волгоградская область, городской округ город Камышин, 5 микрорайон, дом 63а Центр детского творчества		0101000020E61000008CBE823463B346407F4E417E360C4940
27811	2	22	\N	51589	\N	\N	49.305606353653403	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, здание районного Дома культуры"	Россия, Волгоградская область, Иловлинский район, Иловля	0101000020E6100000A0C1A6CEA3FE45400EBBEF181EA74840
27785	2	22	\N	51507	27152	\N	50.978554000000003	г.Жирновск, Ломоносова, 62		0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27708	2	22	\N	51453	27156	\N	49.052433999999998	"г. Дубовка, Северная, 15 (ООО ПК ""Техника"""		0101000020E61000003750E09D7C68464067994528B6864840
27715	2	22	\N	51453	27051	\N	49.052433999999998	"г. Дубовка, Московская, 1(МОУ ""Детская школа искусств"""		0101000020E61000003750E09D7C68464067994528B6864840
27713	2	22	\N	51453	27051	\N	49.052433999999998	г. Дубовка, Московская, 13 (Центр культуры и досуга)		0101000020E61000003750E09D7C68464067994528B6864840
28448	2	22	\N	51701	27547	\N	48.702441	х. Госпитомник, Переулок Школьный, 2, Здание школы	Россия, Волгоградская область, хутор Госпитомник	0101000020E61000009413ED2AA45046404D2F3196E9594840
27551	2	22	\N	51723	27678	\N	48.690192704110103	Волгоградская область, город Волгоград, поселок Горьковский, Валентины Терешковой, 52, МОУ СОШ №140		0101000020E61000004628B682A6274640CD76853E58584840
27603	2	22	\N	51270	27312	\N	48.789842999999998	Волгоградская область, городской округ город Волжский, им. генерала Карбышева улица, 40	Россия, Волгоградская область, Волжский, улица имени генерала Карбышева, 40	0101000020E6100000D63A71395E614640BDFC4E9319654840
27619	2	22	\N	51270	27320	\N	48.7793996863942	"Волгоградская область, городской округ город Волжский, Пушкина улица, 124""А"""	Россия, Волгоградская область, Волжский, улица Пушкина, 124	0101000020E610000035B22B2D236746404F401361C3634840
27608	2	22	\N	51270	27320	\N	48.787770999999999	Волгоградская область, городской округ город Волжский, Пушкина улица, 64	Россия, Волгоградская область, Волжский, улица Пушкина, 64	0101000020E610000071AFCC5B756346405DDE1CAED5644840
27637	2	22	\N	51270	27339	\N	48.756087119615003	"Волгоградская область, городской округ город Волжский, Мира улица, 127""Б"""	Россия, Волгоградская область, Волжский, улица Мира, 127б	0101000020E6100000395E81E84969464023F77475C7604840
27621	2	22	\N	51270	27306	\N	48.771466377707199	Волгоградская область, городской округ город Волжский, Дружбы улица, 36	Россия, Волгоградская область, Волжский, улица Дружбы, 36	0101000020E6100000E6965643E2644640EBFCDB65BF624840
27613	2	22	\N	51270	27306	\N	48.7778262213345	Волгоградская область, городской округ город Волжский, Дружбы улица, 9	Россия, Волгоградская область, Волжский, улица Дружбы, 9	0101000020E610000019726C3D436446403FFD67CD8F634840
27595	2	22	\N	51270	27272	\N	48.806697	Волгоградская область, городской округ город Волжский, 19 Партсъезда улица, 57	Россия, Волгоградская область, Волжский, улица 19 Партсъезда, 57	0101000020E6100000D311C0CDE25F46400264E8D841674840
27631	2	22	\N	51270	27421	\N	48.756459768336299	Волгоградская область, городской округ город Волжский, им. генерала Карбышева улица, 144		0101000020E61000008B71FE2614664640B75D68AED3604840
27600	2	22	\N	51270	27581	\N	48.795991999999998	Волгоградская область, городской округ город Волжский, им. Космонавтов улица, 19	Россия, Волгоградская область, Волжский, улица имени Космонавтов, 19	0101000020E6100000A19FA9D72D60464056F0DB10E3654840
27598	2	22	\N	51270	27443	\N	48.8023004935134	Волгоградская область, городской округ город Волжский, им. Карла Маркса улица, 36	Россия, Волгоградская область, Волжский, улица имени Карла Маркса, 36	0101000020E6100000CAC342AD6960464058CA32C4B1664840
27459	2	22	\N	416	5967	\N	48.499988000000002	Волгоградская область, город Волгоград, Красноармейский район, командира Рудь, 18 (МОУ СОШ №71)		0101000020E6100000F5108DEE204A46403C32569BFF3F4840
27593	2	22	\N	51270	27443	\N	48.807968357174801	Волгоградская область, городской округ город Волжский, им. Карла Маркса улица, 13	Россия, Волгоградская область, Волжский, улица имени Карла Маркса, 13	0101000020E6100000AF97A608705E4640761BD47E6B674840
27599	2	22	\N	51270	27334	\N	48.798644000000003	Волгоградская область, городской округ город Волжский, им. Аркадия Гайдара улица, 7	Россия, Волгоградская область, Волжский, улица имени Аркадия Гайдара, 7	0101000020E61000009E996038D75E4640C59272F739664840
27640	2	22	\N	51270	26733	\N	48.875188999999999	Волгоградская область, городской округ город Волжский, пос. Краснооктябрьский Чапаева улица, 5		0101000020E6100000950D6B2A8B604640D368723106704840
27614	2	22	\N	51270	26439	\N	48.793337786384598	Волгоградская область, городской округ город Волжский, Химиков улица, 5	Россия, Волгоградская область, Волжский	0101000020E6100000D767CEFA9467464047567E198C654840
27606	2	22	\N	51270	27571	\N	48.784067	Волгоградская область, городской округ город Волжский, Советская улица, 26	Россия, Волгоградская область, Волжский, Советская улица, 26	0101000020E6100000EFA83121E6604640B96FB54E5C644840
27602	2	22	\N	51270	27636	\N	48.788803999999999	Волгоградская область, городской округ город Волжский, Советская улица, 6		0101000020E61000009E08E23C9C6046401C7A8B87F7644840
27618	2	22	\N	51270	27409	\N	48.779626	Волгоградская область, городской округ город Волжский, Пушкина улица, 124		0101000020E61000001B4CC3F0116746403F8EE6C8CA634840
27597	2	22	\N	51270	27409	\N	48.802380890105901	Волгоградская область, городской округ город Волжский, Пушкина улица, 6		0101000020E61000002FFA0AD28C5F464044F7AC6BB4664840
27611	2	22	\N	51270	26870	\N	48.799033580177998	Волгоградская область, городской округ город Волжский, пос. Рабочий Прибрежная улица, 91	Россия, Волгоградская область, Волжский	0101000020E6100000C6BFCFB8706246402F3201BF46664840
27620	2	22	\N	51270	27426	\N	48.777151000000003	Волгоградская область, городской округ город Волжский, Пионерская улица, 14	Россия, Волгоградская область, Волжский, Пионерская улица, 14	0101000020E61000007218CC5F21654640E08618AF79634840
27615	2	22	\N	51270	27426	\N	48.783490999999998	Волгоградская область, городской округ город Волжский, Пионерская улица, 31		0101000020E6100000D1217024D0644640ECDADE6E49644840
27612	2	22	\N	51270	27426	\N	48.773201999999998	Волгоградская область, городской округ город Волжский, Пионерская улица, 1	Россия, Волгоградская область, Волжский, Пионерская улица, 1	0101000020E610000030B8E68EFE634640D4997B48F8624840
27601	2	22	\N	51270	27435	\N	48.7896870328319	Волгоградская область, городской округ город Волжский, Набережная улица, 12	Россия, Волгоградская область, Волжский, Набережная улица, 12	0101000020E61000009B5AB6D6175F4640C689AF7614654840
27636	2	22	\N	51270	27380	\N	48.753505325820498	Волгоградская область, городской округ город Волжский, Мира улица, 159	Россия, Волгоградская область, Волжский, улица Мира, 159	0101000020E6100000677E3507086A4640AD2F12DA72604840
27609	2	22	\N	51270	27052	\N	48.7866137020061	Волгоградская область, городской округ город Волжский, Машиностроителей улица, 13	Россия, Волгоградская область, Волжский, улица Машиностроителей, 13	0101000020E6100000C6E061DA37634640B2497EC4AF644840
27594	2	22	\N	51270	27494	\N	48.808176079861397	Волгоградская область, городской округ город Волжский, Комсомольская улица, 1		0101000020E6100000A01518B2BA5F4640C0B4A84F72674840
27625	2	22	\N	51270	27388	\N	48.773226637140503	Волгоградская область, городской округ город Волжский, Клавы Нечаевой улица, 7	Россия, Волгоградская область, Волжский, улица Клавы Нечаевой, 7	0101000020E61000007E8AE3C0AB6746402DB1321AF9624840
27596	2	22	\N	51270	27712	\N	48.808966990463801	Волгоградская область, городской округ город Волжский, Кирова улица, 20	Россия, Волгоградская область, Волжский, улица Кирова, 20	0101000020E6100000321F10E84C60464089450C3B8C674840
27638	2	22	\N	51270	26875	\N	48.791523173186	Волгоградская область, городской округ город Волжский, о. Зеленый Гидростроевская улица, 1		0101000020E6100000382C0DFCA862464012842BA050654840
27624	2	22	\N	51270	27313	\N	48.767361339201798	Волгоградская область, городской округ город Волжский, Дружбы улица, 65	Россия, Волгоградская область, Волжский, улица Дружбы, 65	0101000020E61000006F0F4240BE664640E99C9FE238624840
27622	2	22	\N	51270	27313	\N	48.767714511002097	Волгоградская область, городской округ город Волжский, Дружбы улица, 59		0101000020E610000002F225547066464007D3307C44624840
27610	2	22	\N	51270	27448	\N	48.779769000000002	Волгоградская область, городской округ город Волжский, Академика Королева улица, 6	Россия, Волгоградская область, Волжский, улица Академика Королева, 6	0101000020E610000051853FC39B614640A2B77878CF634840
27278	2	22	\N	51270	27271	\N	48.811419999999998	Волгоградская область, городской округ город Волжский Автодорога №7 6	Россия, Волгоградская область, Волжский, улица 7 Автодорога	0101000020E6100000997E8978EB6A464000A94D9CDC674840
27630	2	22	\N	51270	27294	\N	48.757516847452003	Волгоградская область, городской округ город Волжский, 40 Лет Победы улица, 37	Россия, Волгоградская область, Волжский, улица 40 лет Победы, 37	0101000020E6100000C66CC9AA08674640FF942A51F6604840
27635	2	22	\N	51270	26436	\N	48.808495000000001	Волгоградская область, городской округ город Волжский, 40 Лет Победы улица, 80	Россия, Волгоградская область, Волжский	0101000020E61000003944DC9C4A62464061FD9FC37C674840
27634	2	22	\N	51270	26436	\N	48.808495000000001	Волгоградская область, городской округ город Волжский, 40 Лет Победы улица, 58	Россия, Волгоградская область, Волжский	0101000020E61000003944DC9C4A62464061FD9FC37C674840
27632	2	22	\N	51270	26436	\N	48.792795949921	Волгоградская область, городской округ город Волжский, 40 Лет Победы улица, 11	Россия, Волгоградская область, Волжский	0101000020E6100000EDD3F198816246402733DE567A654840
27628	2	22	\N	51270	26436	\N	48.790514900068501	Волгоградская область, городской округ город Волжский, 40 Лет Победы улица, 59	Россия, Волгоградская область, Волжский	0101000020E6100000A86E2EFEB6634640ACFF73982F654840
27627	2	22	\N	51270	26436	\N	48.7962454603014	Волгоградская область, городской округ город Волжский, 40 Лет Победы улица, 79	Россия, Волгоградская область, Волжский	0101000020E61000008BE255D636634640404D2D5BEB654840
27604	2	22	\N	51270	27375	\N	48.7924503765758	Волгоградская область, городской округ город Волжский, Пушкина улица, 44	Россия, Волгоградская область, Волжский, улица Пушкина, 44	0101000020E6100000747CB438636246408CDB68006F654840
27639	2	22	\N	51270	27411	\N	48.847693848582097	Волгоградская область, городской округ город Волжский, пос. Паромный Плеханова улица, 8		0101000020E6100000C5E23785955E4640F981AB3C816C4840
27617	2	22	\N	51270	27273	\N	48.7799844328391	Волгоградская область, городской округ город Волжский, Наримана Нариманова улица, 27		0101000020E6100000EB56CF49EF6546409EB30584D6634840
27626	2	22	\N	51270	27440	\N	48.772454000000003	Волгоградская область, городской округ город Волжский, Клавы Нечаевой улица, 10		0101000020E6100000605AD427B96746400BD5CDC5DF624840
27633	2	22	\N	51270	26444	\N	48.802539357390003	Волгоградская область, городской округ город Волжский, 40 Лет Победы улица, 48	Россия, Волгоградская область, Волжский	0101000020E61000009160AA99B5604640DD611399B9664840
27557	2	22	\N	416	\N	\N	48.598033178947503	"Волгоградская область, город Волгоград, поселок Водный, контора ФГУП ОПХ ""Орошаемое"", контора ФГУП ОПХ ""Орошаемое"""		0101000020E6100000397F130A11164640E27668588C4C4840
27503	2	22	\N	416	\N	\N	48.835633000000001	Волгоградская область, город Волгоград, Тракторозаводский район	Россия, Волгоградская область, Волгоград, Тракторозаводский район	0101000020E6100000384A5E9D634C4640AC3AAB05F66A4840
27425	2	22	\N	416	\N	\N	48.6080713809895	Волгоградская область, город Волгоград, Кировский район, х. Песчаный, о. Сарпинский, фельдшерский пункт полик.№ 5		0101000020E6100000DB183BE125364640B1524145D54D4840
27424	2	22	\N	416	\N	\N	48.581198424471602	Волгоградская область, город Волгоград, Кировский район, х. Кожзавод, о. Сарпинский, школа №25	Россия, Волгоградская область, Волгоград, улица Писемского, 38	0101000020E6100000350873BB97374640144031B2644A4840
27396	2	22	\N	416	\N	\N	48.7822586524616	Волгоградская область, город Волгоград, Дзержинский район, п.Аэропорт, МОУ СОШ №73	Россия, Волгоградская область, Волгоград, Дзержинский район	0101000020E6100000B9A7AB3B162F464037001B1021644840
28588	2	22	6895	\N	3646	\N	50.108966320928303	Волгоградская область, городской округ город Камышин, Текстильная, 2	Россия, Волгоградская область, Камышин городской округ	0101000020E6100000DD94F25A09B346401F300F99F20D4940
27508	2	22	\N	416	26806	\N	48.779608857565499	Волгоградская область, город Волгоград, Краснооктябрьский район, Таращанцев, 11	Россия, Волгоградская область, Волгоград, улица Таращенцев	0101000020E6100000D09CF529C748464069554B3ACA634840
27496	2	22	\N	416	26806	\N	48.774425408532402	Волгоградская область, город Волгоград, Краснооктябрьский район, Таращанцев, 27а	Россия, Волгоградская область, Волгоград, улица Таращенцев, 29	0101000020E61000007FDB1324B6474640371AC05B20634840
27487	2	22	\N	416	26806	\N	48.779608082038401	Волгоградская область, город Волгоград, Краснооктябрьский район, Таращанцев, 51	Россия, Волгоградская область, Волгоград, улица Таращенцев, 51	0101000020E6100000C3802557B148464099D9E731CA634840
27343	2	22	\N	416	4517	\N	48.702874999999999	Волгоградская область, город Волгоград, Ворошиловский район, Саши Филиппова, 96	Россия, Волгоградская область, Волгоград, улица Саши Филиппова, 96	0101000020E610000050C24CDBBF3A46408716D9CEF7594840
27383	2	22	\N	416	5068	\N	48.770381999999998	город Волгоград, ул. Савкина, д. 8, Молодежный центр XXI век		0101000020E61000008E739B70AF3E4640AAB69BE09B624840
27516	2	22	\N	416	6508	\N	48.766623000000003	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Репина, 78	Россия, Волгоградская область, Волгоград, улица Репина, 78	0101000020E61000006C06B8205B46464043AED4B320624840
27419	2	22	\N	416	27279	\N	48.579297032865703	Волгоградская область, город Волгоград, Кировский район, им. Писемского, вечерняя школа №10, 30а	Россия, Волгоградская область, Волгоград, улица Писемского, 30а	0101000020E6100000902FA182C3374640E0D57267264A4840
27420	2	22	\N	416	5524	\N	48.574551026189802	Волгоградская область, город Волгоград, Кировский район, Первой пятилетки, ДК и Т профобразования, 9	Россия, Волгоградская область, Волгоград, улица Первой Пятилетки	0101000020E6100000CFF41263993846402A711DE38A494840
27489	2	22	\N	416	6244	\N	48.782713999999999	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Пельше, 3	Россия, Волгоградская область, Волгоград, улица Пельше, 3	0101000020E6100000E5D4CE30B5494640880FECF82F644840
28586	2	22	6895	\N	3619	\N	50.100268768210398	Волгоградская область, городской округ город Камышин, Некрасова, 13 Школа №3	Россия, Волгоградская область, Камышин городской округ	0101000020E6100000C8B3CBB73EB44640BCE6559DD50C4940
27535	2	22	\N	416	6722	\N	48.656475999999998	"Волгоградская область, город Волгоград, Крепильная, 128, ОАО ""Гипс"""		0101000020E6100000BB63B14D2A3A4640F04DD36707544840
27371	2	22	\N	416	4912	\N	48.751389000000003	город Волгоград, им.Константина Симонова, 20/А,  МОУ гимназия №11		0101000020E6100000D40AD3F71A4046407EC9C6832D604840
27402	2	22	\N	416	5302	\N	48.615394000000002	Волгоградская область, город Волгоград, Кировский район, им. Кирова,  лицей № 10, 141	Россия, Волгоградская область, Волгоград, улица Кирова, 141	0101000020E6100000677BF486FB364640CB13083BC54E4840
27319	2	22	\N	416	4290	\N	48.697893000000001	Волгоградская область, город Волгоград, Ворошиловский район, КИМ, 14	Россия, Волгоградская область, Волгоград, улица КИМ, 14	0101000020E61000001DB0ABC953404640BD8DCD8E54594840
27332	2	22	\N	416	4458	\N	48.703665999999998	Волгоградская область, город Волгоград, Ворошиловский район, Елецкая, 20	Россия, Волгоградская область, Волгоград, улица Елецкая, 20	0101000020E6100000F1F09E03CB3D464050A73CBA115A4840
27549	2	22	\N	416	27316	\N	48.6854186622976	Волгоградская область, город Волгоград, поселок Горьковский, Волгоградская, 134, ДК поселка Горьковский	Россия, Волгоградская область, Волгоград, поселок Горьковский, улица Голубятникова	0101000020E6100000DE8E705AF02846404D874ECFBB574840
27493	2	22	\N	416	6320	\N	48.777988000000001	Волгоградская область, город Волгоград, Краснооктябрьский район, им. генерала Штеменко, 50	Россия, Волгоградская область, Волгоград, улица Генерала Штеменко, 50	0101000020E61000007651F4C0C746464019575C1C95634840
27583	2	22	\N	416	7190	\N	48.714385999999998	Волгоградская область, город Волгоград, Центральный район, ул. им. Гагарина, 14	Россия, Волгоградская область, Волгоград, улица Гагарина, 14	0101000020E6100000B3D30FEA22434640315C1D00715B4840
27512	2	22	\N	416	6489	\N	48.767152000000003	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Вершинина, 5а	Россия, Волгоградская область, Волгоград, улица Вершинина, 5а	0101000020E61000003143E38920464640CF87670932624840
27521	2	22	\N	416	27626	\N	48.672054300726501	Волгоградская область, город Волгоград, Тулака, 1, МОУ СОШ №93	Россия, Волгоградская область, Волгоград, улица Тулака, 1	0101000020E6100000D6027B4CA43C4640B0928FDD05564840
27462	2	22	\N	416	5986	\N	48.511848999999998	Волгоградская область, город Волгоград, Красноармейский район, пр-т Столетова, 16а (МОУ СОШ №125)		0101000020E6100000DCD9571EA4494640C2BE9D4484414840
27461	2	22	\N	416	5986	\N	48.505628999999999	Волгоградская область, город Волгоград, Красноармейский район, пр-т Столетова, 50 (МОУ СОШ №38)	Россия, Волгоградская область, Волгоград, проспект Столетова, 50	0101000020E610000027309DD66D48464060747973B8404840
27364	2	22	\N	416	4669	\N	48.748876000000003	Волгоградская область, город Волгоград, Дзержинский район, пр-кт им.Маршала Советского Союза Г.К.Жукова, 153, ЦДТ		0101000020E61000001AE1ED41083E46403161342BDB5F4840
27361	2	22	\N	416	4669	\N	48.735810999999998	город Волгоград, пр-кт Маршала Г.К.Жукова, 83, технологический колледж		0101000020E61000006536C824233F4640BE840A0E2F5E4840
27351	2	22	\N	416	4669	\N	48.723218000000003	город Волгоград, пр-кт Маршала Г.К.Жукова, 13, МОУ СОШ №37	Россия, Волгоградская область, Волгоград, проспект Маршала Советского Союза Г. К. Жукова, 13	0101000020E610000074CE4F711C40464074F04C68925C4840
27350	2	22	\N	416	4669	\N	48.734557000000002	город Волгоград, пр-кт Маршала Г.К.Жукова, 90,ГОУ Профессиональное училище №11		0101000020E6100000658C0FB3973F46402106BAF6055E4840
27443	2	22	\N	416	5756	\N	48.514445000000002	Волгоградская область, город Волгоград, Красноармейский район, пр-т Героев Сталинграда, 33а (МОУ СОШ №120)		0101000020E6100000D8F15F20084646409D4B7155D9414840
27441	2	22	\N	416	5756	\N	48.514488403015399	Волгоградская область, город Волгоград, Красноармейский район, пр-т им. Героев Сталинграда, 33а(МОУ СОШ №120)	Россия, Волгоградская область, Волгоград, проспект Героев Сталинграда, 33	0101000020E6100000D655815A0C4646409C1727BEDA414840
27439	2	22	\N	416	5756	\N	48.516205999999997	Волгоградская область, город Волгоград, Красноармейский район, пр-т Героев Сталинграда, 43 (МОУ гимназия №2)		0101000020E61000003274ECA012454640DEFFC70913424840
27589	2	22	\N	416	3745	\N	48.703052558864201	Волгоградская область, город Волгоград, Центральный район, пр-кт. им. В.И.Ленина, 2б	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 2б	0101000020E61000006FBBD05CA7414640662D05A4FD594840
27588	2	22	\N	416	3745	\N	48.703992999999997	Волгоградская область, город Волгоград, Центральный район, пр-кт. им. В.И.Ленина, 4	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 4	0101000020E610000079245E9ECE41464074CE4F711C5A4840
27582	2	22	\N	416	3745	\N	48.713980999999997	Волгоградская область, город Волгоград, Центральный район, пр-кт. им. В.И.Ленина, 28	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 28	0101000020E6100000C619C39CA0434640917BBABA635B4840
27581	2	22	\N	416	3745	\N	48.717066000000003	Волгоградская область, город Волгоград, Центральный район, пр-кт. им. В.И.Ленина, 31	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 31	0101000020E61000002F51BD35B04346406A8995D1C85B4840
27577	2	22	\N	416	3745	\N	48.732067999999998	Волгоградская область, город Волгоград, Центральный район, пр-кт. им. В.И.Ленина, 59	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 59	0101000020E6100000A35698BED74446405C397B67B45D4840
27576	2	22	\N	416	3745	\N	48.725577999999999	Волгоградская область, город Волгоград, Центральный район, пр-кт. им. В.И.Ленина, 51а	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 51а	0101000020E6100000124C35B3964446403A596ABDDF5C4840
27575	2	22	\N	416	3745	\N	48.738117000000003	Волгоградская область, город Волгоград, Центральный район, пр-кт им В.И.Ленина, 78	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 78	0101000020E610000048FDF50A0B46464092CF2B9E7A5E4840
27518	2	22	\N	416	3745	\N	48.754649999999998	Волгоградская область, город Волгоград, Краснооктябрьский район, пр-кт им. В.И.Ленина, 69	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 69	0101000020E61000004356B77A4E46464094F6065F98604840
27517	2	22	\N	416	3745	\N	48.760916000000002	Волгоградская область, город Волгоград, Краснооктябрьский район, пр-кт им. В.И.Ленина, 83	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 83	0101000020E61000006AA2CF471947464067800BB265614840
27510	2	22	\N	416	3745	\N	48.766457000000003	Волгоградская область, город Волгоград, Краснооктябрьский район, пр-кт им. В.И. Ленина, 97	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 97	0101000020E6100000299485AFAF474640286552431B624840
27498	2	22	\N	416	3745	\N	48.779145999999997	Волгоградская область, город Волгоград, Краснооктябрьский район, пр-кт им. В.И.Ленина, 133	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 133	0101000020E6100000E99E758D9649464094675E0EBB634840
27497	2	22	\N	416	3745	\N	48.775744000000003	Волгоградская область, город Волгоград, Краснооктябрьский район, пр-кт им. В.И.Ленина, 121	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 121	0101000020E610000060394206F2484640BC0853944B634840
27488	2	22	\N	416	3745	\N	48.784951999999997	Волгоградская область, город Волгоград, Краснооктябрьский район, пр-кт им. В.И. Ленина, 151а	Россия, Волгоградская область, Волгоград, проспект В. И. Ленина, 151а	0101000020E6100000726BD26D894A46400377A04E79644840
27447	2	22	\N	416	27258	\N	48.529012097248497	Волгоградская область, город Волгоград, Красноармейский район, п. 19-го партсъезда, Волжский уч-к ВЭС- филиал ФБУ	Россия, Волгоградская область, Волгоград, Красноармейский район	0101000020E61000003BDF4F8D974A464085984BAAB6434840
27423	2	22	\N	416	27291	\N	48.551785323838999	Волгоградская область, город Волгоград, Кировский район, п. Веселая Балка, школа № 59, 62а		0101000020E6100000E960FD9FC338464031B610E4A0464840
27492	2	22	\N	416	26841	\N	48.7797081249333	Волгоградская область, город Волгоград, Краснооктябрьский район, пос. Сорок домиков, 21а	Россия, Волгоградская область, Волгоград, улица Маршала Еременко, 21а	0101000020E61000003F90BC7328474640FC36C478CD634840
27511	2	22	\N	416	26949	\N	48.776229999999998	Волгоградская область, город Волгоград, Краснооктябрьский район, пос. Металлургов, 120	Россия, Волгоградская область, Волгоград, улица Поддубного, 14	0101000020E610000055D97745F0454640481630815B634840
27587	2	22	\N	416	27363	\N	48.708897999999998	Волгоградская область, город Волгоград, Центральный район, площадь Павших Борцов, 1	Россия, Волгоградская область, Волгоград, улица Мира	0101000020E6100000B9AB5791D141464093196F2BBD5A4840
27486	2	22	\N	416	3805	\N	48.776758999999998	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Германа Титова, 1	Россия, Волгоградская область, Волгоград, площадь Германа Титова	0101000020E610000085984BAAB6494640D4EFC2D66C634840
27410	2	22	\N	416	5401	\N	48.608001000000002	Волгоградская область, город Волгоград, Кировский район, пер. Школьный, проф.училище №12, 1а		0101000020E6100000A30227DBC0354640B8770DFAD24D4840
27435	2	22	\N	416	5705	\N	48.513114000000002	Волгоградская область, город Волгоград, Красноармейский район, пер.Обводный, 1 (МОУ СОШ №62)		0101000020E6100000850B790437444640548F34B8AD414840
27436	2	22	\N	416	27513	\N	48.512649000000003	Волгоградская область, город Волгоград, Красноармейский район, пер.Обводной, 1(МОУ СОШ №62)		0101000020E6100000BEA1F0D93A444640DFA9807B9E414840
27554	2	22	\N	416	26894	\N	48.634774294731301	Волгоградская область, город Волгоград, поселок Гули Королевой, ул. им. лейтенанта Мостового, 7, общежитие	Россия, Волгоградская область, Волгоград, переулок Лейтенанта Мостового	0101000020E61000007A51BB5F05264640F12C414640514840
27422	2	22	\N	416	27621	\N	48.565955000000002	Волгоградская область, город Волгоград, Кировский район, п. им. Саши Чекалина,кола № 108, 10		0101000020E610000062BD512B4C374640FC00A43671484840
27400	2	22	\N	416	26393	\N	48.789846980422602	"п. Аэропорт, ОАО ""Международный Аэропорт Волгоград"""	Россия, Волгоградская область, Волгоград, Дзержинский район	0101000020E61000002C47C8409E2D4640FFEBDCB419654840
27505	2	22	\N	416	27696	\N	48.767257999999998	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Асланова, 39		0101000020E610000096B1A19BFD43464014CC988235624840
27444	2	22	\N	416	5736	\N	48.511390801936997	Волгоградская область, город Волгоград, Красноармейский район, б-р Энгельса, 33 (МОУ гимназия №7)	Россия, Волгоградская область, Волгоград, бульвар Энгельса	0101000020E6100000717500C45D454640003CA24275414840
27373	2	22	\N	416	4853	\N	48.74991	город Волгоград, б-р 30-летия Победы, 66/А, МОУСОШ №102	Россия, Волгоградская область, Волгоград, бульвар 30-летия Победы, 66а	0101000020E61000008CD8278062404640C078060DFD5F4840
27372	2	22	\N	416	4853	\N	48.74991	город Волгоград, б-р 30-летия Победы, 66/А,  МОУСОШ №102	Россия, Волгоградская область, Волгоград, бульвар 30-летия Победы, 66а	0101000020E61000008CD8278062404640C078060DFD5F4840
27366	2	22	\N	416	4853	\N	48.752226	Волгоградская область, город Волгоград, Дзержинский район, б-р 30-летия Победы, 29а, ДЮСШ		0101000020E61000004B22FB20CB3E4640B7990AF148604840
27531	2	22	\N	416	6674	\N	48.674041000000003	Волгоградская область, город Волгоград, Юрьевская, 4	Россия, Волгоградская область, Волгоград, Юрьевская улица, 4	0101000020E61000008731E9EFA53A4640E294B9F946564840
27380	2	22	\N	416	27588	\N	48.766765999999997	город Волгоград, ул. 51-й Гвардейской, 48, МОУ СОШ №40		0101000020E6100000F4DC425722404640A5D7666325624840
27476	2	22	\N	416	27142	\N	48.576912999999998	Волгоградская область, город Волгоград, Красноармейский район, рп Южный, МОУСОШ №22	Россия, Волгоградская область, Волгоград, Красноармейский район	0101000020E6100000944C4EED0C47464091D10149D8494840
27365	2	22	\N	416	27559	\N	48.751448000000003	Волгоградская область, город Волгоград, Дзержинский район, Эльбрусская, 91, МОУ СОШ №85		0101000020E61000003332C85D843D46408352B4722F604840
27533	2	22	\N	416	6687	\N	48.674242999999997	Волгоградская область, город Волгоград, Электролесовская, 5/А	Россия, Волгоградская область, Волгоград, Электролесовская улица, 5	0101000020E610000006D671FC503B4640494739984D564840
27545	2	22	\N	416	27555	\N	48.660837999999998	"Волгоградская область, город Волгоград, Электролесовская, 86, Центр ""Доверие"""	Россия, Волгоградская область, Волгоград, Электролесовская улица	0101000020E6100000C6DFF604893946401EFAEE5696544840
27532	2	22	\N	416	27555	\N	48.665664129417401	"Волгоградская область, город Волгоград, Электролесовская, 4а, подростковый клуб ""Надежда"""	Россия, Волгоградская область, Волгоград, Электролесовская улица, 4а	0101000020E610000012BC218D0A3A4640F10F5B7A34554840
27578	2	22	\N	416	27638	\N	48.724811000000003	Волгоградская область, город Волгоград, Центральный район, ул. Школьная, 11	Россия, Волгоградская область, Волгоград, улица Школьная, 11	0101000020E61000005C38109205444640FA635A9BC65C4840
27393	2	22	\N	416	27658	\N	48.759306000000002	"город Волгоград, ул. Шекснинская, д. 24, клуб ""Дзержинец"""		0101000020E61000001C977153033F46400BD462F030614840
27530	2	22	\N	416	27612	\N	48.672452999999997	Волгоградская область, город Волгоград, Чебышева, 38, МОУ СОШ №111		0101000020E61000007F677BF4863946406D8C9DF012564840
27363	2	22	\N	416	27605	\N	48.740262000000001	город Волгоград, Хорошева, 30а, ЦСЗН		0101000020E6100000DCD6169E973E46405C3CBCE7C05E4840
27484	2	22	\N	416	27587	\N	48.782784999999997	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Хользунова, 33		0101000020E61000006F2F698CD64746405166834C32644840
27560	2	22	\N	416	27673	\N	48.724898366221801	Волгоградская область, город Волгоград, Центральный район, ул. Хиросимы, 10	Россия, Волгоградская область, Волгоград, улица Хиросимы, 10	0101000020E6100000ECDFF599B3424640C9772975C95C4840
27559	2	22	\N	416	27673	\N	48.726267	Волгоградская область, город Волгоград, Центральный район, ул. Хиросимы, 11		0101000020E6100000CB64389ECF424640FF942A51F65C4840
27446	2	22	\N	416	27591	\N	48.502245000000002	Волгоградская область, город Волгоград, Красноармейский район, Хабаровская, 10 (МОУ СОШ №55)		0101000020E61000005C3D27BD6F4646402ECA6C9049404840
27345	2	22	\N	416	27695	\N	48.699033999999997	Волгоградская область, город Волгоград, Ворошиловский район, Феодосийская, 55		0101000020E6100000BD8A8C0E483A4640626534F279594840
27534	2	22	\N	416	27551	\N	48.662830999999997	Волгоградская область, город Волгоград, Ухтомского, 2, Детско-юношеский центр		0101000020E6100000564ACFF41239464032E36DA5D7544840
27543	2	22	\N	416	6639	\N	48.641736999999999	Волгоградская область, город Волгоград, проспект Университетский, 100, ГОУ ВПО ВолГУ		0101000020E61000002A52616C213646400BD1217024524840
27542	2	22	\N	416	6639	\N	48.677878	Волгоградская область, город Волгоград, проспект Университетский, 20/1, ГОУ ВПО ВолГУ	Россия, Волгоградская область, Волгоград, Университетский проспект, 20	0101000020E6100000315EF3AACE384640C556D0B4C4564840
27541	2	22	\N	416	6639	\N	48.649464000000002	Волгоградская область, город Волгоград, Советский район, Университетский проспект, 88, МОУ СОШ №103		0101000020E6100000C72AA5677A374640F5F6E7A221534840
27540	2	22	\N	416	6639	\N	48.658005000000003	Волгоградская область, город Волгоград, Советский район, Университетский проспект, 64, Дворец бракосочетания		0101000020E6100000EE26F8A6E937464060CD018239544840
27539	2	22	\N	416	6639	\N	48.658005000000003	Волгоградская область, город Волгоград, Советский район, Университетский, 64, НОУ ВИЭСП	Россия, Волгоградская область, Волгоград, Университетский проспект, 64	0101000020E6100000EE26F8A6E937464060CD018239544840
27537	2	22	\N	416	6639	\N	48.658225000000002	Волгоградская область, город Волгоград, Университетский проспект, 71, Колледж газа и нефти		0101000020E6100000ACE5CE4C303846406E3480B740544840
27529	2	22	\N	416	6639	\N	48.674903999999998	Волгоградская область, город Волгоград, Университетский проспект, 26, ВГСХА	Россия, Волгоградская область, Волгоград, Университетский проспект, 26	0101000020E61000002C4487C09138464044F8174163564840
27527	2	22	\N	416	6639	\N	48.674903999999998	Волгоградская область, город Волгоград, Советский район, Университетский проспект, 26, ВГСХА		0101000020E61000002C4487C09138464044F8174163564840
27469	2	22	\N	416	27692	\N	48.525646999999999	Волгоградская область, город Волгоград, Красноармейский район, Удмуртская, 1а (ГОУ ПУ №6)		0101000020E6100000D57ABFD18E4B4640C91EA16648434840
27455	2	22	\N	416	27692	\N	48.517214000000003	Волгоградская область, город Волгоград, Красноармейский район, Удмуртская, 18 (МОУ гимназия №8)		0101000020E61000003849F3C7B448464045847F1134424840
27452	2	22	\N	416	26529	\N	48.513239071677503	Волгоградская область, город Волгоград, Красноармейский район, Удмурская, 34 (МОУ СОШ № 121)	Россия, Волгоградская область, Волгоград, Удмуртская улица, 34	0101000020E6100000D6389B8E004846401004C8D0B1414840
27451	2	22	\N	416	26529	\N	48.513246088602301	Волгоградская область, город Волгоград, Красноармейский район, Удмурская, 34 (МОУ СОШ №121)	Россия, Волгоградская область, Волгоград, Удмуртская улица, 34	0101000020E6100000ED2C7AA702484640C366800BB2414840
27472	2	22	\N	416	27719	\N	48.676456999999999	Волгоградская область, город Волгоград, Туркменская, 17, МОУ МУК		0101000020E6100000C0594A96933C46403C139A2496564840
27401	2	22	\N	416	27590	\N	48.622529	Волгоградская область, город Волгоград, Кировский район, Турбинная, Волгоградский  энергетический колледж, 261		0101000020E6100000210725CCB4354640E2E7BF07AF4F4840
27520	2	22	\N	416	27550	\N	48.672136999999999	Волгоградская область, город Волгоград, Советский район, Тулака, 1, МОУ СОШ №93		0101000020E6100000CA54C1A8A43C46403DB7D09508564840
27564	2	22	\N	416	27608	\N	48.720846999999999	Волгоградская область, город Волгоград, Центральный район, ул. им. Ткачева, 7		0101000020E6100000CFF57D3848424640B935E9B6445C4840
27562	2	22	\N	416	27608	\N	48.721708999999997	Волгоградская область, город Волгоград, Центральный район, ул. им. Ткачева, 10а		0101000020E6100000503750E09D4246404B1DE4F5605C4840
27395	2	22	\N	416	27637	\N	48.781579999999998	Волгоградская область, город Волгоград, Дзержинский район, Строителей, 4а, МОУ СОШ №50		0101000020E6100000CC0BB08F4E314640959A3DD00A644840
27344	2	22	\N	416	27467	\N	48.699990428278397	Волгоградская область, город Волгоград, Ворошиловский район, Ставропольская, 72	Россия, Волгоградская область, Волгоград, Ставропольская улица, 70	0101000020E6100000BF60376C5B3C464076C3B64599594840
27329	2	22	\N	416	4428	\N	48.697518000000002	Волгоградская область, город Волгоград, Ворошиловский район, Социалистическая, 23	Россия, Волгоградская область, Волгоград, Социалистическая улица, 23	0101000020E6100000C05E61C1FD3E4640882F134548594840
27499	2	22	\N	416	6362	\N	48.779763000000003	Волгоградская область, город Волгоград, Краснооктябрьский район, Созидательская, 27	Россия, Волгоградская область, Волгоград, Созидательская улица, 27	0101000020E6100000BC067DE9ED454640C0D02346CF634840
27607	2	22	\N	416	3344	\N	48.715978999999997	Волгоградская область, городской округ город Волжский, Советская улица, 39	Россия, Волгоградская область, Волгоград, Советская улица, 39	0101000020E6100000FCFB8C0B07444640B7CF2A33A55B4840
27585	2	22	\N	416	3344	\N	48.709338000000002	Волгоградская область, город Волгоград, Центральный район, ул. Советская, 24	Россия, Волгоградская область, Волгоград, Советская улица, 24	0101000020E610000060C9552C7E434640B0E76B96CB5A4840
27586	2	22	\N	416	27594	\N	48.707031999999998	Волгоградская область, город Волгоград, Центральный район, ул. Советская, 18	Россия, Волгоградская область, Волгоград, Советская улица, 18	0101000020E6100000DE5A26C3F1424640DC9C4A06805A4840
27336	2	22	\N	416	27602	\N	48.693188999999997	Волгоградская область, город Волгоград, Ворошиловский район, Саши Филиппова, 1		0101000020E61000009D137B681F3D46403579CA6ABA584840
27471	2	22	\N	416	27567	\N	48.521093999999998	Волгоградская область, город Волгоград, Красноармейский район, Саушинская, 13а (ГОУ ПУ№36)	Россия, Волгоградская область, Волгоград, Саушинская улица, 13а	0101000020E61000009A44BDE0D34A464027124C35B3424840
27470	2	22	\N	416	27567	\N	48.521093999999998	Волгоградская область, город Волгоград, Красноармейский район, Саушинская, 13а (ГОУ ПУ №36)		0101000020E61000009A44BDE0D34A464027124C35B3424840
27467	2	22	\N	416	27567	\N	48.520609999999998	Волгоградская область, город Волгоград, Красноармейский район, Саушинская, 30 (муниципальное общежитие)		0101000020E6100000C9ACDEE1764A46403BFC3559A3424840
27466	2	22	\N	416	27567	\N	48.521953000000003	Волгоградская область, город Волгоград, Красноармейский район, Саушинская, 22 (МОУ СОШ №113)	Россия, Волгоградская область, Волгоград, Саушинская улица, 22	0101000020E610000049F4328AE54A464049861C5BCF424840
27331	2	22	\N	416	4435	\N	48.704897000000003	Волгоградская область, город Волгоград, Ворошиловский район, Ростовская, 4	Россия, Волгоградская область, Волгоград, Ростовская улица, 4	0101000020E6100000EEAF1EF7AD3E464036069D103A5A4840
27330	2	22	\N	416	4435	\N	48.703980999999999	Волгоградская область, город Волгоград, Ворошиловский район, Ростовская, 15А	Россия, Волгоградская область, Волгоград, Ростовская улица, 15а	0101000020E6100000C6DCB5847C3E4640B000A60C1C5A4840
27454	2	22	\N	416	27645	\N	48.520192000000002	Волгоградская область, город Волгоград, Красноармейский район, Российская, 8 (МОУ СОШ №118)		0101000020E6100000C32973F38D48464007D2C5A695424840
27567	2	22	\N	416	27644	\N	48.720329999999997	Волгоградская область, город Волгоград, Центральный район, ул. им. Рокоссовского, 40		0101000020E6100000BD6F7CED99414640F12900C6335C4840
27563	2	22	\N	416	27644	\N	48.724609000000001	Волгоградская область, город Волгоград, Центральный район, ул. им. Рокоссовского, 48		0101000020E610000066A19DD32C42464092B1DAFCBF5C4840
27558	2	22	\N	416	27644	\N	48.729399000000001	Волгоградская область, город Волгоград, Центральный район, ул. им. Рокоссовского, 60		0101000020E61000009AEC9FA701434640185E49F25C5D4840
27544	2	22	\N	416	27553	\N	48.655476	"Волгоградская область, город Волгоград, Советский район, Родниковая, 14, МУ ГМЦ ""Планета"""		0101000020E61000009A43520B253746400DA837A3E6534840
27362	2	22	\N	416	4808	\N	48.737921	город Волгоград, Рионская, 14, МОУ СОШ №96		0101000020E6100000CFD72C978D3E46400C040132745E4840
27359	2	22	\N	416	27554	\N	48.725239000000002	город Волгоград, Римского Корсакова, 1, МОУ СОШ №36		0101000020E61000008159A148F73B46405264ADA1D45C4840
27358	2	22	\N	416	27554	\N	48.725239000000002	город Волгоград, Римского-Корсакова, 1, МОУ СОШ №36		0101000020E61000008159A148F73B46405264ADA1D45C4840
27387	2	22	\N	416	27614	\N	48.769562999999998	город Волгоград, ул. Республиканская, д. 2, МОУ ЦПК	Россия, Волгоградская область, Волгоград, Республиканская улица, 2	0101000020E61000001C28F04E3E3D4640179B560A81624840
27386	2	22	\N	416	27614	\N	48.770440999999998	город Волгоград, ул. Республиканская, д. 5, МОУ СОШ № 89		0101000020E6100000137D3ECA883D4640AF3F89CF9D624840
27385	2	22	\N	416	27614	\N	48.769669	город Волгоград, ул. Республиканская, д. 18, МОУ СОШ № 101		0101000020E61000005B785E2A363E46405DDF878384624840
27515	2	22	\N	416	27548	\N	48.760511999999999	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Репина, 11		0101000020E6100000A0C552245F454640971B0C7558614840
27326	2	22	\N	416	27476	\N	48.692047000000002	Волгоградская область, город Волгоград, Ворошиловский район, Рабоче-Крестьянская, 38	Россия, Волгоградская область, Волгоград, Рабоче-Крестьянская улица, 38	0101000020E610000001A60C1CD03E4640C02500FF94584840
27325	2	22	\N	416	27476	\N	48.684987	Волгоградская область, город Волгоград, Ворошиловский район, Рабоче-Крестьянская, 54		0101000020E6100000094FE8F5273D4640B3976DA7AD574840
27324	2	22	\N	416	27476	\N	48.689573000000003	Волгоградская область, город Волгоград, Ворошиловский район, Рабоче-Крестьянская, 41		0101000020E61000002D0ABB287A3E4640319A95ED43584840
27392	2	22	\N	416	27686	\N	48.760465000000003	город Волгоград, ул. Пятиизбянская, д. 5, МОУ СОШ № 97		0101000020E610000054AA44D95B3E46405760C8EA56614840
27590	2	22	\N	416	27677	\N	48.705247999999997	Волгоградская область, город Волгоград, Центральный район, ул. им. Пушкина, 7		0101000020E6100000A88C7F9F71414640E2C80391455A4840
27440	2	22	\N	416	27685	\N	48.519291000000003	Волгоградская область, город Волгоград, Красноармейский район, Пролетарская, 9 (МОУ СОШ №75)		0101000020E6100000AB97DF6932454640B70DA32078424840
27592	2	22	\N	416	16501	\N	48.712506298187797	Волгоградская область, город Волгоград, Центральный район, площадь Привокзальная, 1	Россия, Волгоградская область, Волгоград, Центральный район	0101000020E61000007D3F355EBA414640151A8865335B4840
27490	2	22	\N	416	6284	\N	48.771498000000001	Волгоградская область, город Волгоград, Краснооктябрьский район, Прибалтийская, 1а	Россия, Волгоградская область, Волгоград, Прибалтийская улица, 1а	0101000020E61000005B94D920934A4640F7764B72C0624840
27501	2	22	\N	416	27596	\N	48.775607000000001	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Поддубного, 15		0101000020E610000094331477BC4546403BC6151747634840
27566	2	22	\N	416	27710	\N	48.716923999999999	Волгоградская область, город Волгоград, Центральный район, ул. им. Пархоменко, 23		0101000020E610000051A1BAB9F8414640D7DB662AC45B4840
27346	2	22	\N	416	4634	\N	48.734735999999998	город Волгоград, Охотская, 19, МОУ ООШкола №41	Россия, Волгоградская область, Волгоград, Охотская улица, 19	0101000020E6100000494C50C3B7424640D09849D40B5E4840
27552	2	22	\N	416	27613	\N	48.656672	Волгоградская область, город Волгоград, село Песчанка, Ольховская, 8, МОУ СОШ №114		0101000020E6100000A60F5D50DF2A46407619FED30D544840
27465	2	22	\N	416	27715	\N	48.511831000000001	Волгоградская область, город Волгоград, Красноармейский район, Олимпийская, 33 (МОУ СОШ №60)		0101000020E61000000CAEB9A3FF4946401C0A9FAD83414840
27339	2	22	\N	416	27627	\N	48.727884000000003	"город Волгоград, Новорядская, 124, ОАО ""Игрушка"""		0101000020E6100000D595CFF23C3E46400EA48B4D2B5D4840
27573	2	22	\N	416	7044	\N	48.712494999999997	Волгоградская область, город Волгоград, Центральный район, ул. Новороссийская, 2	Россия, Волгоградская область, Волгоград, Новороссийская улица, 2	0101000020E6100000971DE21FB640464021C84109335B4840
27570	2	22	\N	416	27632	\N	48.715076233024803	Волгоградская область, город Волгоград, Центральный район, ул. Новороссийская, 41	Россия, Волгоградская область, Волгоград, Новороссийская улица, 41	0101000020E6100000338B506C05414640C713419C875B4840
27348	2	22	\N	416	27653	\N	48.733333000000002	"город Волгоград, Новодвинская, 20, ГОУСПО""Волгоградский КРСиТ"""		0101000020E610000082AAD1AB01404640EE0912DBDD5D4840
27483	2	22	\N	416	27665	\N	48.791071000000002	Волгоградская область, город Волгоград, Краснооктябрьский район, Никопольская, 1		0101000020E6100000CF8426892549464032E884D041654840
27473	2	22	\N	416	6106	\N	48.520949999999999	Волгоградская область, город Волгоград, Красноармейский район, Николаевская, 17 (здание нач. школы МОУСОШ №117)		0101000020E610000056629E95B44C4640F46C567DAE424840
27513	2	22	\N	416	27552	\N	48.760465000000003	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Нестерова, 1а		0101000020E6100000B20FB22C984446405760C8EA56614840
27569	2	22	\N	416	27629	\N	48.718165999999997	Волгоградская область, город Волгоград, Центральный район, ул. Невская, 13		0101000020E61000000C3D62F4DC404640B08C0DDDEC5B4840
27584	2	22	\N	416	27657	\N	48.712851999999998	Волгоградская область, город Волгоград, Центральный район, ул. Мира, 17		0101000020E610000073F6CE68AB424640B071FDBB3E5B4840
27335	2	22	\N	416	27669	\N	48.690108000000002	Волгоградская область, город Волгоград, Ворошиловский район, Буханцева, 21		0101000020E61000005E6919A9F73C46409F5A7D7555584840
27580	2	22	\N	416	27720	\N	48.718480999999997	Волгоградская область, город Волгоград, Центральный район, ул. им. маршала Чуйкова, 53	Россия, Волгоградская область, Волгоград, улица Маршала Чуйкова, 53	0101000020E6100000FE7E315BB244464010E6762FF75B4840
27495	2	22	\N	416	27564	\N	48.777358999999997	Волгоградская область, город Волгоград, Краснооктябрьский район, им. маршала Еременко, 106		0101000020E6100000A94C3107414746402920ED7F80634840
27494	2	22	\N	416	27564	\N	48.778883999999998	Волгоградская область, город Волгоград, Краснооктябрьский район, им. маршала Еременко, 116а		0101000020E61000007B116DC7D447464057B08D78B2634840
27482	2	22	\N	416	27564	\N	48.790501999999996	Волгоградская область, город Волгоград, Краснооктябрьский район, им. маршала Еременко, 57		0101000020E61000002158552FBF49464017B6662B2F654840
27525	2	22	\N	416	27654	\N	48.683399000000001	Волгоградская область, город Волгоград, Мамина-Сибиряка, 28, МДОУ ДС №287	Россия, Волгоградская область, Волгоград, улица Мамина-Сибиряка, 28	0101000020E6100000D8666325E63746403F8F519E79574840
28415	2	22	629	4570	27113	\N	48.715716999999998	п. Колхозная Ахтуба, Веселая, 31, сельский дом культуры		0101000020E6100000DEFFC709136646407A185A9D9C5B4840
27428	2	22	\N	416	27631	\N	48.526117999999997	Волгоградская область, город Волгоград, Красноармейский район, Лазоревая, 197 (МОУСОШ №115)	Россия, Волгоградская область, Волгоград, Красноармейский район, улица Лазоревая, 197	0101000020E610000084F57F0EF33D464020EBA9D557434840
27384	2	22	\N	416	27656	\N	48.770566000000002	город Волгоград, ул. Кутузовская, д. 5, Педагогический колледж	Россия, Волгоградская область, Волгоград, Кутузовская улица, 5	0101000020E6100000D7187442E83E46406CB41CE8A1624840
27408	2	22	\N	416	27674	\N	48.605683999999997	"Волгоградская область, город Волгоград, Кировский район, им. Курчатова, школа-интернат ""Надежда"", 1"		0101000020E6100000B284B53176364640F0DAA50D874D4840
27519	2	22	\N	416	6555	\N	48.751353000000002	Волгоградская область, город Волгоград, Краснооктябрьский район, Кубинская, 26	Россия, Волгоградская область, Волгоград, Кубинская улица, 26	0101000020E6100000FED478E9264546403160C9552C604840
27572	2	22	\N	416	27691	\N	48.715962245302698	Волгоградская область, город Волгоград, Центральный район, ул. Кубанская, 20	Россия, Волгоградская область, Волгоград, Кубанская улица, 20	0101000020E6100000234910AE80404640E1968FA4A45B4840
27528	2	22	\N	416	6640	\N	48.670299	"Волгоградская область, город Волгоград, Криворожская, 2а, ""Дом престарелых"""	Россия, Волгоградская область, Волгоград, Криворожская улица, 2а	0101000020E6100000A54E40136137464050C58D5BCC554840
27538	2	22	\N	416	27709	\N	48.667791211209497	Волгоградская область, город Волгоград, Советский район, Криворожская, 1, МОУ СОШ №106	Россия, Волгоградская область, Волгоград, Криворожская улица, 1	0101000020E610000013B69F8CF137464015C8EC2C7A554840
27389	2	22	\N	416	27562	\N	48.765680885404002	город Волгоград, ул. Краснополянская, д. 40а, Межшкольный учеб. комбинат	Россия, Волгоградская область, Волгоград, Краснополянская улица, 40а	0101000020E6100000444C89247A3D46409415C3D501624840
27388	2	22	\N	416	27562	\N	48.770809	город Волгоград, ул. Краснополянская, д. 11, ПУ № 12		0101000020E6100000ADDC0BCC0A3D4640323B8BDEA9624840
27522	2	22	\N	416	6590	\N	48.680680000000002	Волгоградская область, город Волгоград, Красноволжская, 11, ГОУ ПУ №30		0101000020E6100000D07CCEDDAE3B46404985B18520574840
27377	2	22	\N	416	27697	\N	48.755890999999998	город Волгоград, им.Константина Симонова, 29, МОУСОШ №33		0101000020E6100000CCD24ECDE54046409D2B4A09C1604840
27376	2	22	\N	416	27697	\N	48.755890999999998	город Волгоград, им. Константина Симонова, 29, МОУСОШ №33		0101000020E6100000CCD24ECDE54046409D2B4A09C1604840
27579	2	22	\N	416	7151	\N	48.72099	Волгоградская область, город Волгоград, Центральный район, ул. Коммунистическая, 60	Россия, Волгоградская область, Волгоград, Коммунистическая улица, 60	0101000020E61000001DAB949EE94346401C5F7B66495C4840
27883	2	22	\N	416	27546	\N	48.710462	"поселок Отделение №2 совхоза ""Волго-Дон"", ул.Коммунистическая, д.10 А. Клуб"		0101000020E6100000D05FE811A34146407F86376BF05A4840
27491	2	22	\N	416	27624	\N	48.787092465070998	Волгоградская область, город Волгоград, Краснооктябрьский район, Коммунаров, 23	Россия, Волгоградская область, Волгоград, улица Коммунаров, 23	0101000020E6100000B4739A05DA454640BC783F6EBF644840
27338	2	22	\N	416	27694	\N	48.689103000000003	Волгоградская область, город Волгоград, Ворошиловский район, Комитетская, 58		0101000020E61000006CAF05BD373C4640AA49F08634584840
27429	2	22	\N	416	27660	\N	48.501987999999997	Волгоградская область, город Волгоград, Красноармейский район, Колесная, 82а (МДОШ детский сад №388)		0101000020E6100000D6A9F23D233D4640027E8D2441404840
27328	2	22	\N	416	27599	\N	48.698779000000002	Волгоградская область, город Волгоград, Ворошиловский район, Козловская, 10		0101000020E6100000D99596917A3F4640D8101C9771594840
27292	2	22	\N	416	27599	\N	48.694996000000003	Волгоградская область, город Волгоград, Ворошиловский район, Козловская, 33	Россия, Волгоградская область, Волгоград, Козловская улица, 33	0101000020E6100000F4E0EEACDD3E4640E86C01A1F5584840
27327	2	22	\N	416	4400	\N	48.699818999999998	Волгоградская область, город Волгоград, Ворошиловский район, Ковровская, 4	Россия, Волгоградская область, Волгоград, Ковровская улица, 4	0101000020E610000073F1B73D41404640490F43AB93594840
27337	2	22	\N	416	27371	\N	48.690975999999999	Волгоградская область, город Волгоград, Ворошиловский район, Клубная, 39	Россия, Волгоградская область, Волгоград, улица Клубная	0101000020E61000001EDC9DB5DB3C46401329CDE671584840
27415	2	22	\N	416	27641	\N	48.594755999999997	Волгоградская область, город Волгоград, Кировский район, им. Кирова, СОШ № 24, 94б		0101000020E6100000999D45EF54364640C58CF0F6204C4840
27409	2	22	\N	416	27641	\N	48.609389	Волгоградская область, город Волгоград, Кировский район, им. Кирова,  СОШ № 110, 116		0101000020E6100000BD8FA339B236464065C57075004E4840
27404	2	22	\N	416	26652	\N	48.615231102659997	Волгоградская область, город Волгоград, Кировский район, им. Кирова, сред.образоват. школа № 56, 128а	Россия, Волгоградская область, Волгоград, улица Кирова, 128б	0101000020E6100000215B96AFCB364640213EB0E3BF4E4840
27475	2	22	\N	416	27647	\N	48.537936999999999	Волгоградская область, город Волгоград, Красноармейский район, Кедроградская, 1а (ГОУ школа-интернат №11)		0101000020E61000005C9198A0864F464078279F1EDB444840
27349	2	22	\N	416	27579	\N	48.734290000000001	"город Волгоград, Качинцев, 63, НОУВПО ""Волг. институт бизнеса"""		0101000020E610000073BED87BF13F4640D2E3F736FD5D4840
27504	2	22	\N	416	27508	\N	48.772329999999997	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Качалова, 42а		0101000020E61000000ADAE4F0494546401EDC9DB5DB624840
28340	2	22	6	305	26842	\N	48.419817999999999	с.Большие Чапурники, Ильина, Здание Большечапурниковского СДК		0101000020E61000002AC6F99B504A4640D522A298BC354840
27500	2	22	\N	416	27508	\N	48.776558727134002	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Качалова, 58	Россия, Волгоградская область, Волгоград, улица Качалова, 54	0101000020E6100000CAFACDC4744546400D350A4966634840
27523	2	22	\N	416	6599	\N	48.676884999999999	Волгоградская область, город Волгоград, Казахская, 12, ГОУ СПО медицинский колледж		0101000020E6100000C1711937353A46409413ED2AA4564840
27524	2	22	\N	416	27604	\N	48.676498000000002	Волгоградская область, город Волгоград, Казахская, 20, МОУ СОШ №54		0101000020E6100000A30392B06F3946409BE7887C97564840
27320	2	22	\N	416	27573	\N	48.696068727805802	Волгоградская область, город Волгоград, Ворошиловский район, КИМ, 5	Россия, Волгоградская область, Волгоград, улица КИМ, 5	0101000020E6100000AD4CF8A57E4046403561FBC918594840
27347	2	22	\N	416	27672	\N	48.730046999999999	город Волгоград, Иртышская, 29а, МОУ МУК		0101000020E6100000548CF337A14046407EC51A2E725D4840
27323	2	22	\N	416	27598	\N	48.687539000000001	Волгоградская область, город Волгоград, Ворошиловский район, Иркутская, 1		0101000020E6100000C2189128B43E4640BEDC274701584840
27445	2	22	\N	416	27643	\N	48.509425999999998	Волгоградская область, город Волгоград, Красноармейский район, Изобильная, 16 (МОУ гимназия №6)		0101000020E6100000473D44A33B464640B5DD04DF34414840
27357	2	22	\N	416	27583	\N	48.71951	город Волгоград, Жирновская, 2, Общежитие		0101000020E6100000CA54C1A8A43C46408E9257E7185C4840
27340	2	22	\N	416	27549	\N	48.691149000000003	Волгоградская область, город Волгоград, Ворошиловский район, Ельшанская, 130		0101000020E6100000E8305F5E803B4640E1D4079277584840
27333	2	22	\N	416	27707	\N	48.700045000000003	Волгоградская область, город Волгоград, Ворошиловский район, Елецкая, 9/2		0101000020E6100000E9EFA5F0A03D46403A5D16139B594840
27565	2	22	\N	416	27711	\N	48.717672999999998	Волгоградская область, город Волгоград, Центральный район, ул. Двинская, 3		0101000020E6100000300F99F221424640711C78B5DC5B4840
27536	2	22	\N	416	27502	\N	48.659423605856901	Волгоградская область, город Волгоград, Даугавская, 1, Комплекс культуры и отдыха	Россия, Волгоградская область, Волгоград, Калининградская улица, 1	0101000020E610000003CDE7DCED3846404819710168544840
27414	2	22	\N	416	27680	\N	48.601323000000001	Волгоградская область, город Волгоград, Кировский район, им. Губкина, СОШ № 57, 2		0101000020E6100000B85851836936464093AAED26F84C4840
27437	2	22	\N	416	27329	\N	48.507469157998699	Волгоградская область, город Волгоград, Красноармейский район, Гражданская, 9 (МОУ ООШ №24)	Россия, Волгоградская область, Волгоград, Гражданская улица	0101000020E6100000CF30B5A50E464640EE5D83BEF4404840
27434	2	22	\N	416	27329	\N	48.513741000000003	Волгоградская область, город Волгоград, Красноармейский район, Гражданская, 64 (МОУ ДО ДШИ №2)	Россия, Волгоградская область, Волгоград, Гражданская улица, 64	0101000020E610000095287B4B39434640A3CEDC43C2414840
27433	2	22	\N	416	27683	\N	48.506262	Волгоградская область, город Волгоград, Красноармейский район, Героев Малой Земли, 34 (ПУ №19)	Россия, Волгоградская область, Волгоград, улица Героев Малой Земли, 34	0101000020E6100000A5DDE8633E444640919A7631CD404840
27432	2	22	\N	416	27683	\N	48.508249999999997	Волгоградская область, город Волгоград, Красноармейский район, Героев Малой Земли, 53 (МОУСОШ №64)		0101000020E6100000D45FAFB0E0424640931804560E414840
27426	2	22	\N	416	5583	\N	48.533446991306597	Волгоградская область, город Волгоград, Красноармейский район, Георгиевская, 4 (МОУСОШ №119)	Россия, Волгоградская область, Волгоград, Георгиевская улица, 2	0101000020E61000007CEE04FBAF3B46401D93C5FD47444840
27427	2	22	\N	416	27501	\N	48.533037276563803	Волгоградская область, город Волгоград, Красноармейский район, Георгиевская, 4 (МОУООШ №119)	Россия, Волгоградская область, Волгоград, Георгиевская улица	0101000020E61000004BE5ED08A73B46406B47718E3A444840
27507	2	22	\N	416	27600	\N	48.773909000000003	Волгоградская область, город Волгоград, Краснооктябрьский район, им. генерала Штеменко, 23		0101000020E6100000C72AA5677A474640408A3A730F634840
27391	2	22	\N	416	27563	\N	48.760173999999999	Волгоградская область, город Волгоград, Дзержинский район, им.Гейне, 7, МОУ СОШ № 128		0101000020E61000005227A089B03D46407FA2B2614D614840
27390	2	22	\N	416	27563	\N	48.760173999999999	город Волгоград, ул. Гейне, д. 7, МОУ СОШ № 128		0101000020E61000005227A089B03D46407FA2B2614D614840
27453	2	22	\N	416	27620	\N	48.522298999999997	"Волгоградская область, город Волгоград, Красноармейский район, Вучетича, 17 (МОУ СОШ №134 ""Дарование"")"	Россия, Волгоградская область, Волгоград, улица Вучетича, 17	0101000020E61000008C4D2B8540484640E3DD91B1DA424840
27450	2	22	\N	416	27620	\N	48.520049	Волгоградская область, город Волгоград, Красноармейский район, Вучетича, 30 (МОУ СОШ №124)		0101000020E610000007CF842689474640A4A833F790424840
27550	2	22	\N	416	16277	\N	48.684175463154403	Волгоградская область, город Волгоград, Советский район, поселок Горьковский, Волгоградская, 134	Россия, Волгоградская область, Волгоград, поселок Горьковский, Волгоградская улица	0101000020E6100000514A0856D5294640D3DEE00B93574840
27553	2	22	\N	416	27633	\N	48.630204999999997	Волгоградская область, город Волгоград, поселок Горная Поляна, Волгоградская, 1, МОУ СОШ №58		0101000020E6100000FE7F9C30613246404963B48EAA504840
27548	2	22	\N	416	27405	\N	48.683897999999999	Волгоградская область, город Волгоград, поселок Горьковский, Волгоградская, 2, МОУ СОШ №15		0101000020E6100000C8B4368DED2B464060E63BF889574840
27547	2	22	\N	416	27405	\N	48.687784207413998	Волгоградская область, город Волгоград, поселок Горьковский, Волгоградская, 156, МОУ СОШ №8	Россия, Волгоградская область, Волгоград, поселок Горьковский, Волгоградская улица, 156	0101000020E61000003881E9B46E294640255B5D4E09584840
27591	2	22	\N	416	27586	\N	48.707014000000001	Волгоградская область, город Волгоград, Центральный район, ул. им. В.И.Ленина, 21		0101000020E6100000E5EC9DD15641464036E84B6F7F5A4840
27438	2	22	\N	416	27336	\N	48.5114335733182	Волгоградская область, город Волгоград, Красноармейский район, б-р Энгельса, 30 (МОУ СОШ №65)	Россия, Волгоградская область, Волгоград, улица Энгельса, 30	0101000020E610000089981249F4444640FF0758AB76414840
27460	2	22	\N	416	27565	\N	48.509611	Волгоградская область, город Волгоград, Красноармейский район, Брестская, 15 (МОУ лицей №1)		0101000020E610000061C614AC714846404757E9EE3A414840
27353	2	22	\N	416	27580	\N	48.719313	"город Волгоград, Большая, 17, ГОУ школа-интернат""Созвездие"""		0101000020E6100000FA2B64AE0C3E4640384BC972125C4840
27509	2	22	\N	416	6388	\N	48.769401999999999	Волгоградская область, город Волгоград, Краснооктябрьский район, Богунская, 3	Россия, Волгоградская область, Волгоград, Богунская улица, 3	0101000020E6100000FDD98F14914746400EBDC5C37B624840
27506	2	22	\N	416	27593	\N	48.772793	Волгоградская область, город Волгоград, Краснооктябрьский район, Богунская, 18		0101000020E610000099F38C7DC9464640F3C98AE1EA624840
27502	2	22	\N	416	27593	\N	48.7759778184667	Волгоградская область, город Волгоград, Краснооктябрьский район, Богунская, 38	Россия, Волгоградская область, Волгоград, Богунская улица, 38	0101000020E61000009E29745E634546402F35423F53634840
27457	2	22	\N	416	27716	\N	48.525826000000002	Волгоградская область, город Волгоград, Красноармейский район, Бахтурова, 6 ( ПУ №33)	Россия, Волгоградская область, Волгоград, улица Бахтурова, 6	0101000020E61000002025766D6F49464079B130444E434840
27456	2	22	\N	416	27716	\N	48.524130999999997	Волгоградская область, город Волгоград, Красноармейский район, Бахтурова, 25г (Волгоградский филиал МФЮА)	Россия, Волгоградская область, Волгоград, улица Бахтурова, 25г	0101000020E610000044C18C2958494640EEE87FB916434840
27322	2	22	\N	416	27655	\N	48.690452999999998	Волгоградская область, город Волгоград, Ворошиловский район, Баррикадная, 2	Россия, Волгоградская область, Волгоград, улица Баррикадная, 2	0101000020E6100000F86D88F19A3F464069368FC360584840
27355	2	22	\N	416	4717	\N	48.715176	город Волгоград, Ангарская, 15, МОУСОШ №67	Россия, Волгоградская область, Волгоград, Ангарская улица, 15	0101000020E6100000A85489B2B73E46402A711DE38A5B4840
27356	2	22	\N	416	27592	\N	48.718963000000002	город Волгоград, Ангарская, 49, МОУ СОШ №82		0101000020E6100000A304FD851E3D46405C04C6FA065C4840
27354	2	22	\N	416	27592	\N	48.715176	город Волгоград, Ангарская, 15, МОУ СОШ №67		0101000020E6100000A85489B2B73E46402A711DE38A5B4840
27417	2	22	\N	416	27681	\N	48.582559742852403	Волгоградская область, город Волгоград, Кировский район, Алычевая, СОШ №112, 1а		0101000020E610000057CEDE196D35464098FA7953914A4840
27526	2	22	\N	416	27609	\N	48.688181	Волгоградская область, город Волгоград, поселок Верхняя Ельшанка, Алишера Навои, 2, МОУ СОШ №46		0101000020E6100000601F9DBAF2334640425DA45016584840
27430	2	22	\N	416	27618	\N	48.514541000000001	Волгоградская область, город Волгоград, Красноармейский район, Алданская, 10 (МОУООШ №63)		0101000020E610000044A67C08AA404640BFB9BF7ADC414840
27321	2	22	\N	416	27652	\N	48.693717999999997	Волгоградская область, город Волгоград, Ворошиловский район, Академическая, 1		0101000020E61000004704E3E0D23F4640C1525DC0CB584840
27341	2	22	\N	416	27575	\N	48.693367000000002	Волгоградская область, город Волгоград, Ворошиловский район, Автотранспортная, 29А		0101000020E6100000CF488446B03746401590F63FC0584840
27416	2	22	\N	416	26781	\N	48.589505574024997	Волгоградская область, город Волгоград, Кировский район, Абганеровская, школа № 122, 107		0101000020E61000003FFF3D78ED324640DC65BFEE744B4840
27369	2	22	\N	416	4861	\N	48.754756999999998	"город Волгоград, 8-й Воздушной Армии, 27/А, МОУ лицей №8""Олимпия"""		0101000020E6100000F4A96395D23F4640AAB69BE09B604840
27368	2	22	\N	416	4861	\N	48.754756999999998	"город Волгоград, 8-й Воздушной Армии, 27/А, МОУ лицей №8 ""Олимпия"""		0101000020E6100000F4A96395D23F4640AAB69BE09B604840
27378	2	22	\N	416	27526	\N	48.757418000000001	город Волгоград, ул. 8-й Воздушной Армии, д. 50, МОУ детский сад № 4		0101000020E6100000A2D288997D4046406CB3B112F3604840
27375	2	22	\N	416	27526	\N	48.752386999999999	город Волгоград, 8-й Воздушной Армии, 26а, МОУ Лицей №9		0101000020E6100000868DB27E33414640C0779B374E604840
27374	2	22	\N	416	27526	\N	48.752386999999999	город Волгоград, 8-й Воздушной Армии, 26/А, МОУ лицей №9		0101000020E6100000868DB27E33414640C0779B374E604840
27370	2	22	\N	416	27526	\N	48.754620000000003	город Волгоград, 8-й Воздушной Армии, 35,Библиотека №24 им.В.М.Шукшина		0101000020E61000005723BBD2324046402A745E6397604840
27367	2	22	\N	416	27526	\N	48.754756999999998	город Волгоград, 8-й Воздушной Армии, 27/А, МОУ лицей №8		0101000020E6100000F4A96395D23F4640AAB69BE09B604840
27413	2	22	\N	416	5346	\N	48.606982000000002	Волгоградская область, город Волгоград, Кировский район, 64 Армии, Центр детского творчества, 73а		0101000020E6100000292504ABEA3546405EA10F96B14D4840
27405	2	22	\N	416	5346	\N	48.615864000000002	Волгоградская область, город Волгоград, Кировский район, 64 Армии, проф.училище №26, 117		0101000020E6100000E8A38CB8003646405264ADA1D44E4840
27412	2	22	\N	416	27589	\N	48.601781000000003	Волгоградская область, город Волгоград, Кировский район, 64 Армии, гимназия № 10, 63		0101000020E61000002CEFAA07CC354640562DE928074D4840
27411	2	22	\N	416	27589	\N	48.601781000000003	Волгоградская область, город Волгоград, Кировский район, 64 Армии, гимназия №10, 63		0101000020E61000002CEFAA07CC354640562DE928074D4840
27382	2	22	\N	416	27588	\N	48.767448999999999	город Волгоград, ул. 51-й Гвардейской, д. 38б, общежитие ЖКХ		0101000020E6100000AAD72D02633F4640882CD2C43B624840
27381	2	22	\N	416	27588	\N	48.769010000000002	город Волгоград, 51-й Гвардейской, 59, МОУ лицей № 7		0101000020E610000088A1D5C919404640032670EB6E624840
27449	2	22	\N	416	27705	\N	48.523015000000001	Волгоградская область, город Волгоград, Красноармейский район, 50 лет Октября, 23 (МОУ лицей №4)		0101000020E6100000E2E82ADD5D474640A228D027F2424840
27474	2	22	\N	416	27533	\N	48.524315999999999	Волгоградская область, город Волгоград, Красноармейский район, 2-я Штурманская, 2а (МОУ СОШ №117)		0101000020E6100000193BE125384D4640806264C91C434840
27468	2	22	\N	416	27687	\N	48.513734999999997	Волгоградская область, город Волгоград, Красноармейский район, 2-я Динамовская, 11 (ПУ №31)		0101000020E6100000C98FF8156B4A4640C0E78711C2414840
27360	2	22	\N	416	27556	\N	48.736316000000002	"город Волгоград, Хорошева, 18а, ГОУ ""ВСКО школа-интернат№2"""		0101000020E61000000264E8D8413D4640C2C2499A3F5E4840
27568	2	22	\N	416	27607	\N	48.721138000000003	Волгоградская область, город Волгоград, Центральный район, ул. им. Рокоссовского, 40г		0101000020E6100000BB5F05F86E41464091F3FE3F4E5C4840
27352	2	22	\N	416	27607	\N	48.717922000000002	город Волгоград, им.Рокоссовского, 41, ФГУ Управление мелиорации		0101000020E6100000429605137F4046401A8A3BDEE45B4840
27514	2	22	\N	416	27574	\N	48.763876362575502	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Репина, 19	Россия, Волгоградская область, Волгоград, улица Репина, 19	0101000020E61000004F745DF8C1454640831953B0C6614840
27418	2	22	\N	416	27640	\N	48.58099	Волгоградская область, город Волгоград, Кировский район, им. Писемского, гимгазия № 9, 38		0101000020E6100000BA6B09F9A0374640CAA65CE15D4A4840
27485	2	22	\N	416	27622	\N	48.785710999999999	Волгоградская область, город Волгоград, Краснооктябрьский район, им. Пельше, 15б		0101000020E610000090DAC4C9FD484640C18D942D92644840
27561	2	22	\N	416	27557	\N	48.722724999999997	Волгоградская область, город Волгоград, Центральный район, ул. им. Пархоменко, 47а		0101000020E6100000ED461FF3014346403480B740825C4840
27334	2	22	\N	416	27693	\N	48.697822212002997	Волгоградская область, город Волгоград, Ворошиловский район, Липецкая, 3	Россия, Волгоградская область, Волгоград, улица Липецкая, 3	0101000020E61000002157EA59103E4640F436363B52594840
27407	2	22	\N	416	27628	\N	48.609318000000002	Волгоградская область, город Волгоград, Кировский район, им. Кирова, УПК, 121		0101000020E6100000DE8E705AF03646409C6ED921FE4D4840
27394	2	22	\N	416	27650	\N	48.760049000000002	"город Волгоград, Землячки, 27б, ЗАО """"ВМС- Ремонт"""		0101000020E6100000B2F50CE1983F4640C32D1F4949614840
27342	2	22	\N	416	27577	\N	48.708939999999998	Волгоградская область, город Волгоград, Ворошиловский район, Елецкая, 142		0101000020E6100000CAE1934E243C4640C269C18BBE5A4840
27431	2	22	\N	416	27682	\N	48.521116999999997	Волгоградская область, город Волгоград, Красноармейский район, Арсеньева, 32 (МОУСОШ №9)		0101000020E6100000B47405DB88414640DF313CF6B3424840
27546	2	22	\N	416	27532	\N	48.648655776241903	Волгоградская область, город Волгоград, академика Королева, 1, МОУ СОШ №52	Россия, Волгоградская область, Волгоград, улица Академика Королева, 1а	0101000020E6100000A52E19C748384640562DE92807534840
27464	2	22	\N	416	27570	\N	48.507683	"Волгоградская область, город Волгоград, Красноармейский район, 40 лет ВЛКСМ, 31 (ДК ""Царицын"")"		0101000020E61000000A117008554A46401ADEACC1FB404840
27463	2	22	\N	416	27570	\N	48.507683	"Волгоградская область, город Волгоград, Красноармейский район, 40 лет ВЛКСМ, 31 (ООО ""ДК Царицын"")"	Россия, Волгоградская область, Волгоград, улица 40 Лет ВЛКСМ, 31	0101000020E61000000A117008554A46401ADEACC1FB404840
27458	2	22	\N	416	27570	\N	48.501342999999999	"Волгоградская область, город Волгоград, Красноармейский район, 40-лет ВЛКСМ, 66 (МУП ""Метроэлектротранс"")"		0101000020E6100000B55208E4124B46400D8AE6012C404840
28447	2	22	\N	51656	27442	\N	48.705824999999997	х. Бурковский, Школьная, 6,Здание школы	Россия, Волгоградская область, хутор Бурковский	0101000020E61000004EB9C2BB5C5446407FD93D79585A4840
28554	2	22	1170	51476	\N	\N	48.4979467594979	Волгоградская область, Чернышковский муниципальный район, х. Ярской, помещение Ярского сельс.клуба	Россия, Волгоградская область, Чернышковский район, село Ярской	0101000020E61000006F2D93E1782A4540171230BABC3F4840
28552	2	22	1170	11109	26435	\N	48.421283000000003	Волгоградская область, Чернышковский муниципальный район, р.п.Чернышковский, Цимлянская, 64		0101000020E6100000FAD4B14AE91D45402EAEF199EC354840
28549	2	22	1170	11109	27062	\N	48.421283000000003	Волгоградская область, Чернышковский муниципальный район, р.п.Чернышковский, Советская, 31		0101000020E6100000FAD4B14AE91D45402EAEF199EC354840
28550	2	22	1170	11109	26645	\N	48.421283000000003	Волгоградская область, Чернышковский муниципальный район, р.п.Чернышковский, Ленина, 56		0101000020E6100000FAD4B14AE91D45402EAEF199EC354840
28551	2	22	1170	11109	26903	\N	48.421283000000003	Волгоградская область, Чернышковский муниципальный район, р.п.Чернышковский, 2-я Гвардейская, 16		0101000020E6100000FAD4B14AE91D45402EAEF199EC354840
28567	2	22	1170	51567	\N	\N	48.101139702442403	Волгоградская область, Чернышковский муниципальный район, х.Фирсов, помещение Фирсовского сельск.клуба	Россия, Волгоградская область, Чернышковский район, село Фирсовка	0101000020E61000004FADBEBA2A204540A228D027F20C4840
28568	2	22	1170	51722	27675	\N	48.171066861774896	Волгоградская область, Чернышковский муниципальный район, х.Тормосин, Октябрьская, 25	Россия, Волгоградская область, Чернышковский район, село Тормосин	0101000020E6100000827170E99857454061360186E5154840
28564	2	22	1170	51719	27659	\N	48.144883	Волгоградская область, Чернышковский муниципальный район, х.Сизов, Советская, 22	Россия, Волгоградская область, Чернышковский район, село Сизов	0101000020E6100000F9307BD976244540895FB1868B124840
28295	2	22	862	30556	26638	\N	49.127155999999999	п. Эльтон, Калинина, 10		0101000020E6100000D350A390646C4740BEBED6A546904840
28133	2	22	1170	51627	27372	\N	48.145117999999997	с.Раздольное, Гагарина, 28-а	Россия, Волгоградская область, Чернышковский район, село Раздольный	0101000020E6100000B35DA10F96114540CC07043A93124840
28572	2	22	1170	51404	\N	\N	48.2633391402737	Волгоградская область, Чернышковский муниципальный район, х. Пристеновский, помещ. администрации сел.поселения	Россия, Волгоградская область, Чернышковский район, село Пристеновский	0101000020E6100000AC53E57B467045407461A417B5214840
28571	2	22	1170	51340	\N	\N	48.184576999999997	Волгоградская область, Чернышковский муниципальный район, х.Попов, помещение МОУ СОШ	Россия, Волгоградская область, Чернышковский район, село Попов	0101000020E610000061A75835086D4540014C1938A0174840
28553	2	22	1170	51505	\N	\N	48.433078999999999	Волгоградская область, Чернышковский муниципальный район, х. Нижняя Вербовка, помещение Вербовского сельс. клуба	Россия, Волгоградская область, Чернышковский район, село Нижняя Вербовка	0101000020E610000057056A3178164540CDCAF6216F374840
28565	2	22	1170	51689	27521	\N	48.045112257995903	Волгоградская область, Чернышковский муниципальный район, х.Нижнегнутов, Ленина, 23		0101000020E6100000BBECD79DEE3045401E54E23AC6054840
28569	2	22	1170	51320	\N	\N	48.092900999999998	Волгоградская область, Чернышковский муниципальный район, х.Морской, помещение Морсковского сельск.клуба	Россия, Волгоградская область, Чернышковский район, село Морской	0101000020E61000003881E9B46E4B45400262122EE40B4840
28566	2	22	1170	51399	\N	\N	48.067009552484897	Волгоградская область, Чернышковский муниципальный район,  х.Лозной, помещение Лозновского сельс.клуба	Россия, Волгоградская область, Чернышковский район, село Лозной	0101000020E61000002AC58EC6A1384540A3409FC893084840
28558	2	22	1170	11547	\N	\N	48.391049000000002	Волгоградская область, Чернышковский муниципальный район, п.Красный, помещение Красновского МОУ		0101000020E61000007155D977452E45401711C5E40D324840
28557	2	22	1170	11483	26964	\N	48.402115999999999	Волгоградская область, Чернышковский муниципальный район, п.Красноярский, Советская, 14		0101000020E61000006DAD2F12DA24454063997E8978334840
28570	2	22	1170	51592	\N	\N	48.169475799041898	Волгоградская область, Чернышковский муниципальный район, х.Захаров, помещение МОУ СОШ	Россия, Волгоградская область, Чернышковский район, село Захаров	0101000020E6100000618A7269FC5E45407CBABA63B1154840
28560	2	22	1170	51687	27518	\N	48.307547999999997	Волгоградская область, Чернышковский муниципальный район, х.Елкин, Школьная, 6	Россия, Волгоградская область, Чернышковский район, село Елкино	0101000020E610000035423F53AF2D4540A0F99CBB5D274840
28555	2	22	1170	51460	\N	\N	48.367356999999998	Волгоградская область, Чернышковский муниципальный район, х.Волоцкий, помещение Дома культуры	Россия, Волгоградская область, Чернышковский район, село Волоцкий	0101000020E61000007BBB2539601B4540747ADE8D052F4840
28573	2	22	1170	51443	\N	\N	48.229242386233999	Волгоградская область, Чернышковский муниципальный район, х.Водяновский, помещение МОУ СОШ	Россия, Волгоградская область, Чернышковский район, село Водяновский	0101000020E61000001E54E23AC66D4540506F46CD571D4840
28562	2	22	1170	51671	27483	\N	48.24333	Волгоградская область, Чернышковский муниципальный район, х.Верхнегнутов, Октябрьская, 15	Россия, Волгоградская область, Чернышковский район, село Верхнегнутов	0101000020E6100000A60C1CD0D21F45405E11FC6F251F4840
28556	2	22	1170	51357	26800	\N	48.485329821283401	Волгоградская область, Чернышковский муниципальный район, х.Большетерновой, им. Г.Ф.Горбункова, 3	Россия, Волгоградская область, Чернышковский район, село Большетерновой	0101000020E6100000CE37A27BD639454043E21E4B1F3E4840
28559	2	22	1170	51536	\N	\N	48.381667143460099	Волгоградская область, Чернышковский муниципальный район, х.Богомазов, помещение Богомазовского МОУ	Россия, Волгоградская область, Чернышковский район, село Богомазовка	0101000020E6100000A0DFF76F5E284540317BD976DA304840
28563	2	22	1170	11785	26910	\N	48.165374	Волгоградская область, Чернышковский муниципальный район, п.Басакин, пл. Центральная, 5		0101000020E6100000FB3E1C2444234540EACDA8F92A154840
28561	2	22	1170	51704	27561	\N	48.2444419590121	Волгоградская область, Чернышковский муниципальный район, х.Алешкин, Октябрьская, 25	Россия, Волгоградская область, Чернышковский район, село Алешкин	0101000020E610000055C1A8A44E52454069E21DE0491F4840
28541	2	22	1121	10764	\N	\N	49.730086756669699	х. Шуруповский, здание школы	Россия, Волгоградская область, Фроловский район, село Шуруповский	0101000020E61000009B20EA3E00DB45400C1EA67D73DD4840
28535	2	22	1121	10484	\N	\N	49.584434417725497	х. Шляховский, здание клуба	Россия, Волгоградская область, Фроловский район, село Шляховский	0101000020E6100000CFF8BEB854D94540D255BABBCECA4840
28531	2	22	1121	51341	\N	\N	49.785173216092197	п. Школьный, здание клуба	Россия, Волгоградская область, Фроловский район	0101000020E610000057772CB649BD4540E259828C80E44840
28673	2	22	1121	51397	26959	\N	49.739381778246702	Волгоградская область, город Фролово, 40 Лет Октября, 7	Россия, Волгоградская область, Фроловский район	0101000020E6100000749A05DA1DD8454023A0C211A4DE4840
28544	2	22	1121	51398	\N	\N	49.820576745548998	Волгоградская область, Фроловский район, х. Рубежный, здание клуба	Россия, Волгоградская область, Фроловский район, село Рубежный	0101000020E610000062855B3E92064640C66CC9AA08E94840
28538	2	22	1121	45689	\N	\N	49.787455000000001	п. Пригородный, здание Зеленовской средней школы		0101000020E6100000BD715298F7D645402D095053CBE44840
28537	2	22	1121	51426	\N	\N	49.6900000654786	х. Писаревка, здание Дома культуры	Россия, Волгоградская область, Фроловский район, село Писаревка	0101000020E610000094128255F5FE4540B81E85EB51D84840
27983	2	22	1121	51633	27389	\N	50.0674274219216	х.Перелазовский, Центральная, 22		0101000020E6100000D717096D39DD454007EFAB72A1084940
28542	2	22	1121	10829	\N	\N	49.786036000000003	п. Образцы, здание Дома культуры		0101000020E61000001A6EC0E78701464045BDE0D39CE44840
28532	2	22	1121	10330	\N	\N	49.647608561035199	х. Новая Паника, здание начальной школы	Россия, Волгоградская область, Фроловский район, село Новая Паника	0101000020E61000000A9E42AED4D1454032CC09DAE4D24840
28543	2	22	1121	51284	\N	\N	49.819974242533597	х. Манский, здание школы	Россия, Волгоградская область, Фроловский район, село Манский	0101000020E6100000D68D7747C6FE454000C974E8F4E84840
28548	2	22	1121	11090	\N	\N	50.184069000000001	ст. Малодельская, здание кафетерия		0101000020E6100000245F09A4C4F245408D9AAF928F174940
28536	2	22	1121	10519	\N	\N	49.845661	п. Лычак, здание  Дома культуры	Россия, Волгоградская область, Фроловский район, село Лычак	0101000020E6100000A7751BD47EE545405740A19E3EEC4840
28530	2	22	1121	51257	\N	\N	49.786969093685698	п. Арчединского лесхоза, здание школы	Россия, Волгоградская область, Фроловский район, село Лесхоз Арчединский	0101000020E6100000F2785A7EE0BA4540A0FB7266BBE44840
28534	2	22	1121	10436	\N	\N	49.6428853232877	х. Красные Липки, здание  Дома культуры	Россия, Волгоградская область, Фроловский район, село Красные Липки	0101000020E610000021205F4205DF4540630B410E4AD24840
27958	2	22	1121	51501	27141	\N	49.751832589633302	х.Калиновский, здание сельского Дома культуры	Россия, Волгоградская область, Фроловский район, село Калиновский	0101000020E6100000B80721205FE24540DB8651103CE04840
28547	2	22	1121	11025	\N	\N	49.999735999999999	п. Дудаченский, здание администрации сельского посе		0101000020E61000008C81751C3F16464022516859F7FF4840
28529	2	22	1121	10178	\N	\N	49.789312338667798	х. Гуляевка, Дом культуры	Россия, Волгоградская область, Фроловский район, село Гуляевка	0101000020E61000004E2A1A6B7FBF4540912BF52C08E54840
28486	2	22	1121	51484	\N	\N	49.766629000000002	х. Ветютнев, средняя школа	Россия, Волгоградская область, Фроловский район, село Ветютнев	0101000020E61000002096CD1C92C44540259529E620E24840
28533	2	22	1121	10352	\N	\N	49.627831999999998	х. Верхние Липки, здание Дома культуры	Россия, Волгоградская область, Фроловский район, село Верхние Липки	0101000020E610000000E65AB400ED4540EEB089CC5CD04840
28546	2	22	1121	10975	\N	\N	50.108384038681699	х. Большой Лычак, здание клубв	Россия, Волгоградская область, Фроловский район, село Большой Лычак	0101000020E610000043723271ABE4454070B4E386DF0D4940
28545	2	22	1121	10951	\N	\N	49.874474060030003	х. Арчедино-Чернушинский, здание Дома культуры	Россия, Волгоградская область, Фроловский район, село Арчедино-Чернушинский	0101000020E610000051D845D103154640E59997C3EEEF4840
28540	2	22	1121	10724	\N	\N	49.796780115177299	х. Амелино, здание Дома культуры	Россия, Волгоградская область, Фроловский район, село Амелино	0101000020E6100000CE6C57E883ED4540AE0D15E3FCE54840
28671	2	22	7113	51462	27064	\N	49.753528049324999	Волгоградская область, город Фролово, 40 Лет Октября, 132		0101000020E6100000A65F22DE3AD54540664F029B73E04840
28636	2	22	1385	51309	\N	\N	50.661307000000001	Волгоградская область, Урюпинский район, ст-ца Тепикинская	Россия, Волгоградская область, Урюпинский район, село Тепикинская	0101000020E6100000C0E78711C2F34440D5CE30B5A5544940
28667	2	22	1385	51360	\N	\N	51.033971999999999	Волгоградская область, Урюпинский район, х.Салтынский	Россия, Волгоградская область, Урюпинский район, село Салтынский	0101000020E6100000B7CF2A33A5F34440677DCA3159844940
28663	2	22	1385	51575	\N	\N	50.6816409042655	Волгоградская область, Урюпинский район, х.Россошинский	Россия, Волгоградская область, Урюпинский район, село Россошинский	0101000020E610000059C2DA183BE544406E4E250340574940
28649	2	22	1385	51445	\N	\N	50.507662580332699	Волгоградская область, Урюпинский район, х.Провоторовский	Россия, Волгоградская область, Урюпинский район, село Провоторовский	0101000020E6100000AB798EC877F94440D331E719FB404940
28661	2	22	1385	51634	27386	\N	50.8309192813199	Волгоградская область, Урюпинский район, х.Попов, Школьная, 37	Россия, Волгоградская область, Урюпинский район, село Попов	0101000020E61000004DC0AF91240645400150C58D5B6A4940
28662	2	22	1385	51623	27378	\N	50.755007559002401	Волгоградская область, Урюпинский район, х.Петровский, Ленина, 56	Россия, Волгоградская область, Урюпинский район, село Петровский	0101000020E6100000CFD72C978DFC4440F31B261AA4604940
28665	2	22	1385	48248	\N	\N	51.114237681288401	Волгоградская область, Урюпинский район, х. Первомайский	Россия, Волгоградская область, Урюпинский район, село Первомайский	0101000020E61000009206B7B585ED4440F0FACC599F8E4940
28660	2	22	1385	51642	27401	\N	50.816789999999997	Волгоградская область, Урюпинский район, х.Ольшанка, Комарова, 45	Россия, Волгоградская область, Урюпинский район, село Ольшанка	0101000020E6100000723788D68A04454094D920938C684940
28648	2	22	1385	51297	\N	\N	50.604196000000002	Волгоградская область, Урюпинский район, х. Ольховский	Россия, Волгоградская область, Урюпинский район, село Ольховский	0101000020E6100000514F1F813FFE4440E02F664B564D4940
28658	2	22	1385	51478	\N	\N	50.733566000000003	Волгоградская область, Урюпинский район, х.Окладненский	Россия, Волгоградская область, Урюпинский район, село Окладненский	0101000020E610000012D90759161E454091BA9D7DE55D4940
28668	2	22	1385	51311	\N	\N	51.03707	Волгоградская область, Урюпинский район, х.Моховской	Россия, Волгоградская область, Урюпинский район, село Моховской	0101000020E610000034D93F4F03F64440D4D4B2B5BE844940
26012	5	44	1140	15775	76705	\N	52.253106000000002	с.Карымск, Чкалова, 30А		0101000020E61000003944DC9C4AED5A40F03504C765204A40
28657	2	22	1385	51666	27468	\N	50.960863000000003	Волгоградская область, Урюпинский район, ст-ца Михайловская, Октябрьская, 15	Россия, Волгоградская область, Урюпинский район, село Михайловская	0101000020E61000005760C8EA56F34440DE770C8FFD7A4940
28656	2	22	1385	51310	\N	\N	50.773271947803103	Волгоградская область, Урюпинский район, х.Лощиновский	Россия, Волгоградская область, Урюпинский район, село Лощиновский	0101000020E6100000CC7A319413AD4440CD74AF93FA624940
28669	2	22	1385	51342	\N	\N	51.1221150557637	Волгоградская область, Урюпинский район, х.Криушинский	Россия, Волгоградская область, Урюпинский район, село Криушинский	0101000020E6100000C217265305114540EFACDD76A18F4940
28655	2	22	1385	51598	27304	\N	50.841669000000003	Волгоградская область, Урюпинский район, х.Креповский, Центральная	Россия, Волгоградская область, Урюпинский район, село Креповский	0101000020E610000069C537143E0B45404D874ECFBB6B4940
28654	2	22	1385	51394	\N	\N	50.802213000000002	Волгоградская область, Урюпинский район, х.Красный	Россия, Волгоградская область, Урюпинский район, село Красный	0101000020E610000002B7EEE6A922454089B663EAAE664940
28653	2	22	1385	51502	\N	\N	50.8520865405563	Волгоградская область, Урюпинский муниципальный район, х.Котовский	Россия, Волгоградская область, Урюпинский район, село Котовский	0101000020E6100000B30B06D7DCF94440622CD32F116D4940
28368	2	22	1385	51502	\N	\N	50.852523958181898	хутор Котовский, Котовский ФАП	Россия, Волгоградская область, Урюпинский район, село Котовский	0101000020E610000017D7F84CF6F944400E87A5811F6D4940
28652	2	22	1385	15965	\N	\N	50.659388	Волгоградская область, Урюпинский район, п.Искра	Россия, Волгоградская область, Урюпинский район, село Искра	0101000020E610000070CE88D2DEB64440FBAF73D366544940
28651	2	22	1385	51370	\N	\N	50.858109024030497	Волгоградская область, Урюпинский район, х.Забурдяевский	Россия, Волгоградская область, Урюпинский район, село Забурдяевский	0101000020E610000041D653ABAFE444409EB30584D66D4940
28650	2	22	1385	51337	26771	\N	50.763038955237597	Волгоградская область, Урюпинский район,х.Дьяконовский-2, Юбилейная, 4	Россия, Волгоградская область, Урюпинский район, село Дьяконовский 2-й	0101000020E61000000C5BB395970A454049490F43AB614940
28647	2	22	1385	51371	\N	\N	50.532922659893401	Волгоградская область, Урюпинский район, х. Дубовский	Россия, Волгоградская область, Урюпинский район, село Дубовский	0101000020E610000096404AECDAFE4440A22424D236444940
28659	2	22	1385	51551	\N	\N	50.642235918636999	Волгоградская область, Урюпинский район, х. Долгий	Россия, Волгоградская область, Урюпинский район, село Долгий	0101000020E6100000855D143DF02745402C280CCA34524940
28645	2	22	1385	51261	26385	\N	50.823968238055897	Волгоградская область, Урюпинский район, ст-ца Добринка, Красноармейская	Россия, Волгоградская область, Урюпинский район, село Добринка	0101000020E61000000B9755D80CEC4440AB798EC877694940
28646	2	22	1385	51442	\N	\N	50.799845886336001	Волгоградская область, Урюпинский муниципальный район, х. Горский	Россия, Волгоградская область, Урюпинский район, село Горский	0101000020E6100000FCA5457D92F7444010EB8D5A61664940
28644	2	22	1385	51587	\N	\N	50.955705999999999	Волгоградская область, Урюпинский район, х.Вишняковский	Россия, Волгоградская область, Урюпинский район, село Вишняковский	0101000020E610000024438EAD670C4540A54BFF92547A4940
28643	2	22	1385	51441	\N	\N	50.950336056179303	Волгоградская область, Урюпинский район, х.Вихлянцевский	Россия, Волгоградская область, Урюпинский район, село Вихлянцевский	0101000020E6100000548B8862F2CC4440111B2C9CA4794940
28642	2	22	1385	51440	\N	\N	50.712166572380603	Волгоградская область, Урюпинский район, х.Верхнесоинский	Россия, Волгоградская область, Урюпинский район, село Верхнесоинский	0101000020E61000009E616A4B1DD844402D25CB49285B4940
28641	2	22	1385	51597	\N	\N	50.7737080884609	Волгоградская область, Урюпинский район, х.Верхнебезымяновский	Россия, Волгоградская область, Урюпинский район, село Верхнебезымянский	0101000020E6100000D7DD3CD521D74440A8531EDD08634940
28664	2	22	1385	51446	\N	\N	50.650554	Волгоградская область, Урюпинский район, х.Булековский	Россия, Волгоградская область, Урюпинский район, село Булековский	0101000020E61000002D5DC136E2E7444018247D5A45534940
28666	2	22	1385	51570	\N	\N	51.031219664455499	Волгоградская область, Урюпинский район, х.Бугровский	Россия, Волгоградская область, Урюпинский район, село Бугровский	0101000020E6100000170D198F52E94440957D5704FF834940
28640	2	22	1385	51542	\N	\N	50.970233999999998	Волгоградская область, Урюпинский район, х.Бубновский	Россия, Волгоградская область, Урюпинский район, село Бубновский	0101000020E6100000ECBDF8A23DEA4440CFBBB1A0307C4940
28639	2	22	1385	51259	\N	\N	51.055826161283001	Волгоградская область, Урюпинский район, х. Большинский	Россия, Волгоградская область, Урюпинский район, село Большинский	0101000020E6100000A1A17F828B1745401D226E4E25874940
28638	2	22	1385	51572	\N	\N	50.743701999999999	Волгоградская область, Урюпинский район, х.Бесплемяновский	Россия, Волгоградская область, Урюпинский район, село Бесплемяновский	0101000020E6100000209738F240EE444022FC8BA0315F4940
28637	2	22	1385	51390	\N	\N	50.880212310035901	Волгоградская область, Урюпинский район, х.Беспаловский	Россия, Волгоградская область, Урюпинский район, село Беспаловский	0101000020E610000011C8258E3CC44440FCC56CC9AA704940
28635	2	22	1385	51459	\N	\N	50.641472	Волгоградская область, Урюпинский район, х.Акчернский	Россия, Волгоградская область, Урюпинский район, село Акчернский	0101000020E6100000E3C281902C0045405DA626C11B524940
28499	2	22	940	51465	\N	\N	48.591081520768498	Волгоградская область, Суровикинский муниципальный район, Чувилеский хутор, МОУ Чувилевская НОШ	Россия, Волгоградская область, Суровикинский район, село Чувилевский	0101000020E61000004D309C6B985D45408CA03193A84B4840
28507	2	22	940	9104	\N	\N	48.454284999999999	"Волгоградская область, Суровикинский муниципальный район, Сысоевский хутор, МУК ""Искра"""		0101000020E6100000001B1021AE6C45401C08C902263A4840
28492	2	22	940	8447	\N	\N	48.921320999999999	Волгоградская область, Суровикинский муниципальный район, Сухановский хутор, МОУ Сухановская НОШ		0101000020E610000063F030ED9B9F45401B0FB6D8ED754840
28482	2	22	940	7598	26871	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район, г.Суровикино, Шоссейная, 69		0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28479	2	22	940	7598	26871	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район,  г.Суровикино, Шоссейная, 1		0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28476	2	22	940	7598	27061	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район,  г.Суровикино, Советская, 144А	Россия, Волгоградская область, Суровикинский район, Суровикино	0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28478	2	22	940	7598	26631	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район,  г.Суровикино, Ленина, 4		0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28477	2	22	940	7598	26631	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район, г.Суровикино, Ленина, 78		0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28475	2	22	940	7598	26631	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район,  г.Суровикино, Ленина, 296А		0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28480	2	22	940	7598	27444	\N	48.605820999999999	Волгоградская область, Суровикинский муниципальный район, Городское поселение г.Суровикино, Звездина, 20	Россия, Волгоградская область, Суровикинский район, Суровикино	0101000020E610000045D5AF743E6E4540711DE38A8B4D4840
28504	2	22	940	8992	\N	\N	48.239130000000003	Волгоградская область, Суровикинский муниципальный район, Суворовская станица, МОУ Суворовская ООШ	Россия, Волгоградская область, Суровикинский район, село Суворовская	0101000020E61000007AC6BE64E38545400ABFD4CF9B1E4840
28509	2	22	940	9188	\N	\N	48.510475999999997	"Волгоградская область, Суровикинский муниципальный район, Синяпкинский хутор, МУК ""Искра"""		0101000020E6100000CC96AC8A703F45404AB20E4757414840
28487	2	22	940	8189	\N	\N	48.337048000000003	"Волгоградская область, Суровикинский муниципальный район, Пещеровский хутор, ТОС ""Пещеровское"""		0101000020E6100000C005D9B27C69454053978C63242B4840
28505	2	22	940	9029	\N	\N	48.481185000000004	"Волгоградская область, Суровикинский муниципальный район, Новомаксимовский хутор, МУК ""Ритм"""		0101000020E6100000E5B512BA4B944540B3295778973D4840
28508	2	22	940	9181	\N	\N	48.543467	"Волгоградская область, Суровикинский муниципальный район, Новодербеновский хутор, МУК ""Искра"""	Россия, Волгоградская область, Суровикинский район, село Новодербеновский	0101000020E61000004948A46DFC59454045BA9F5390454840
28502	2	22	940	8790	\N	\N	48.358305000000001	Волгоградская область, Суровикинский муниципальный район, Нижний Чир станица, МОУ Нижнечирская ООШ		0101000020E6100000F1D6F9B7CB8A4540247F30F0DC2D4840
28501	2	22	940	8790	\N	\N	48.358305000000001	Волгоградская область, Суровикинский муниципальный район, Нижний Чир станица, ГОУ Профессиональное училище № 46		0101000020E6100000F1D6F9B7CB8A4540247F30F0DC2D4840
28500	2	22	940	8790	\N	\N	48.358305000000001	"Волгоградская область, Суровикинский муниципальный район, Нижний Чир станица, МУК ""Дом культуры Нижнечирского сельского поселения"""		0101000020E6100000F1D6F9B7CB8A4540247F30F0DC2D4840
28497	2	22	940	8654	\N	\N	48.627251000000001	Волгоградская область, Суровикинский муниципальный район, Нижнеосиновский хутор, МОУ Нижнеосиновская НОШ		0101000020E6100000A704C4245C64454010B1C1C249504840
28491	2	22	940	8393	\N	\N	48.894359999999999	Волгоградская область, Суровикинский муниципальный район, Майоровский хутор, МОУ Майоровская СОШ		0101000020E61000001EFD2FD7A2974540DF6C73637A724840
28495	2	22	940	8582	\N	\N	48.653570999999999	"Волгоградская область, Суровикинский муниципальный район, Лысов хутор, МУК ""Виктория"""		0101000020E6100000A1BC8FA339964540984EEB36A8534840
28493	2	22	940	8482	\N	\N	48.794995	"Волгоградская область, Суровикинский муниципальный район, Лобакин хутор, МУК ""Дружба"""		0101000020E6100000740B5D89406B4540E4BD6A65C2654840
27850	2	22	940	9183	27194	\N	48.628788	хутор Кумовка, ул.Центральная, д.15. Кумовская НОШ		0101000020E6100000A6B73F170DC14540020F0C207C504840
28494	2	22	940	8515	\N	\N	48.870880999999997	Волгоградская область, Суровикинский муниципальный район, Киселев хутор, МОУ Киселевская НОШ		0101000020E6100000C972124A5F66454098DA5207796F4840
28490	2	22	940	51564	\N	\N	48.749937460004297	Волгоградская область, Суровикинский муниципальный район, Качалин хутор, МОУ Качалинская СОШ	Россия, Волгоградская область, Суровикинский район, село Качалин	0101000020E610000018CFA0A17F9A4540BA8784EFFD5F4840
28484	2	22	940	8007	\N	\N	48.645296999999999	Волгоградская область, Суровикинский муниципальный район, Жирковский хутор, МОУ Жирковская начальная общеобразовательная школа		0101000020E6100000A94A5B5CE37545407C9A931799524840
27966	2	22	940	8007	27463	\N	48.645066874358101	х.Жирковский, Раздольная, 39	Россия, Волгоградская область, Суровикинский район, село Жирковский	0101000020E6100000E607AEF2047645404A5D328E91524840
28489	2	22	940	8268	\N	\N	48.818995999999999	"Волгоградская область, Суровикинский муниципальный район, Добринка хутор, МУК ""Добринское"""		0101000020E6100000164CFC51D47B454004C765DCD4684840
28506	2	22	940	51349	\N	\N	48.483788896585502	Волгоградская область, Суровикинский муниципальный район, Верхнечирский хутор, МОУ Новомаксимовская СОШ	Россия, Волгоградская область, Суровикинский район, село Верхнечирский	0101000020E61000002843554CA5994540109546CCEC3D4840
28485	2	22	940	8077	\N	\N	48.374586999999998	Волгоградская область, Суровикинский муниципальный район, Верхнесолоновский хутор, МОУ Верхнесолоновская СОШ		0101000020E6100000E7C41EDAC76A4540DD408177F22F4840
28498	2	22	940	8737	\N	\N	48.682929000000001	Волгоградская область, Суровикинский муниципальный район, Верхнеосиновский хутор, МОУ Ворхнеосиновская НОШ		0101000020E6100000FE2C9622F9624540B83EAC376A574840
28488	2	22	940	8264	\N	\N	48.343169000000003	Волгоградская область, Суровикинский муниципальный район, Верхнеаксеновский хутор, МОУ Верхнеаксеновская НОШ		0101000020E610000029594E42E94F4540220038F6EC2B4840
28496	2	22	940	8623	\N	\N	48.524273999999998	"Волгоградская область, Суровикинский муниципальный район, Бурацкий хутор, МУК ""Виктория"""	Россия, Волгоградская область, Суровикинский район, село Бурацкий	0101000020E61000004701A260C6904540511212691B434840
28483	2	22	940	51368	\N	\N	48.5270231042959	"Волгоградская область, Суровикинский муниципальный район, х.Ближнеосиновский, МУК ""Надежда"""	Россия, Волгоградская область, Суровикинский район, село Ближнеосиновский	0101000020E6100000A741D13C80854540B29E5A7D75434840
28503	2	22	940	8946	\N	\N	48.435499999999998	Волгоградская область, Суровикинский муниципальный район, Ближнемельничный хутор, МОУ Ближнемельничная ООШ		0101000020E6100000E4D6A4DB1287454039B4C876BE374840
28474	2	22	871	51377	\N	\N	50.7230293963676	с. Черебаево, Здание культурно-досугового объединения	Россия, Волгоградская область, Старополтавский район, село Черобаево	0101000020E61000002F4FE78A52F44640A087DA368C5C4940
28456	2	22	871	48634	\N	\N	50.348208	с. Цветочное, Здание сельского клуба	Россия, Волгоградская область, Старополтавский район, село Цветочное	0101000020E6100000A7AD11C138604740501A6A14922C4940
28473	2	22	871	48924	\N	\N	50.426558	с. Харьковка, Здание культурно-досугового объединения	Россия, Волгоградская область, Старополтавский район, село Харьковка	0101000020E6100000323CF6B35868474070ECD97399364940
28471	2	22	871	7432	\N	\N	50.298178999999998	с. Торгун, Здание культурно-досугового объединения	Россия, Волгоградская область, Старополтавский район, село Торгун	0101000020E6100000B2497EC4AF9A47404FADBEBA2A264940
28470	2	22	871	7394	\N	\N	50.483054000000003	с. Старая Полтавка, Здание культурно-досугового объединения		0101000020E6100000D10836AE7F3D4740DB19A6B6D43D4940
28469	2	22	871	7355	\N	\N	50.639786999999998	с. Салтово, Здание культурно-досугового объединения		0101000020E610000053EBFD463B524740F6B3588AE4514940
28468	2	22	871	7286	\N	\N	50.304830000000003	с. Новый Тихонов, Здание культурно-досугового объединения		0101000020E610000041F4A44C6A3847407B6B60AB04274940
28465	2	22	871	7142	\N	\N	50.427205999999998	с. Новая Полтавка, Здание культурно-досугового объединения		0101000020E610000086C954C1A8324740D653ABAFAE364940
28467	2	22	871	7259	\N	\N	50.574635999999998	с. Новая Квасниковка, Здание культурно-досугового объединения	Россия, Волгоградская область, Старополтавский район, село Новая Квасниковка	0101000020E6100000B37BF2B0503B4740588D25AC8D494940
28464	2	22	871	7106	\N	\N	50.613016000000002	с. Лятошинка, Здание культурно-досугового объединения		0101000020E6100000EDBAB722314747405EF6EB4E774E4940
28463	2	22	871	7059	\N	\N	50.387807000000002	с. Курнаевка, Здание культурно-досугового объединения		0101000020E61000000CE8853B17F846407714E7A8A3314940
28461	2	22	871	6980	\N	\N	50.443713000000002	с. Колышкино, Здание школы		0101000020E61000006B65C22FF5F54640B0E76B96CB384940
28459	2	22	871	6850	\N	\N	50.433793000000001	с. Кано, Здание культурно-досугового объединения	Россия, Волгоградская область, Старополтавский район, село Кано	0101000020E6100000C45E28603B504740EB1D6E8786374940
28466	2	22	871	48805	\N	\N	50.483673000000003	с. Калинино, Здание школы	Россия, Волгоградская область, Старополтавский район, село Калинино	0101000020E6100000567DAEB662194740A77A32FFE83D4940
28457	2	22	871	6789	\N	\N	50.512860000000003	с. Иловатка, Здание культурно-досугового объединения		0101000020E61000006F826F9A3EF146409AB67F65A5414940
28455	2	22	871	6650	\N	\N	50.376249999999999	с. Гмелинка, Здание центра досуга	Россия, Волгоградская область, Старополтавский район, село Гмелинка	0101000020E6100000A4E4D539067447405C8FC2F528304940
28454	2	22	871	6650	\N	\N	50.376249999999999	с. Гмелинка, Здание администрациии с/п		0101000020E6100000A4E4D539067447405C8FC2F528304940
28453	2	22	871	6560	\N	\N	50.397787000000001	с. Верхняя Водянка, Здание культурно-досугового объединения		0101000020E61000004D874ECFBB8D474011E335AFEA324940
28460	2	22	871	6911	\N	\N	50.509211999999998	с. Верхний Еруслан, Здание школы		0101000020E6100000516A2FA2ED424740895DDBDB2D414940
14666	2	22	871	51375	\N	\N	50.282905412739801	с. Вербное, Здание школы	Россия, Волгоградская область, Старополтавский район, село Вербный	0101000020E6100000CB845FEAE76D4740FC6F253B36244940
28452	2	22	871	48550	\N	\N	50.353444000000003	с. Валуевка, Здание школы		0101000020E610000043CA4FAA7D344740D57B2AA73D2D4940
28451	2	22	871	48538	\N	\N	50.307769999999998	с. Беляевка, Здание школы		0101000020E610000094BF7B478D1B47404F58E20165274940
28458	2	22	871	48668	\N	\N	50.558667999999997	с. Белокаменка, Здание школы	Россия, Волгоградская область, Старополтавский район, село Белокаменка	0101000020E6100000F3583332C8E946402EA9DA6E82474940
26021	5	44	1140	16223	76524	\N	52.153863000000001	с.Итанца, Советская, 28		0101000020E6100000EFACDD76A1DF5A40408864C8B1134A40
28427	2	22	629	51529	27186	\N	48.650605303843903	х.Ямы, Базовский переулок, 4, Здание школы	Россия, Волгоградская область, Среднеахтубинский район, село Ямы	0101000020E6100000EDD79DEE3C4F46409ACE4E0647534840
28445	2	22	629	51302	26588	\N	48.587403000000002	х.Чапаевец, Придорожная, 31/2, Помещение ТОС	Россия, Волгоградская область, Среднеахтубинский район, село Чапаевец	0101000020E61000006C5CFFAECF6C464041498105304B4840
28428	2	22	629	51691	27523	\N	48.626620000000003	х.Тумак, Центральная, 32/4,Здание школы	Россия, Волгоградская область, Среднеахтубинский район, село Тумак	0101000020E610000035B8AD2D3C4F464080828B1535504840
28444	2	22	629	51699	27541	\N	48.617812478300998	х. Суходол, Советская, 9, Здание СДК	Россия, Волгоградская область, Среднеахтубинский район, село Суходол	0101000020E6100000A54FABE80F734640C689AF76144F4840
28443	2	22	629	51699	27540	\N	48.617185999999997	х. Суходол, Молодежная, 12,Здание школы	Россия, Волгоградская область, Среднеахтубинский район, село Суходол	0101000020E6100000D97A8670CC72464047C66AF3FF4E4840
28435	2	22	629	5600	26937	\N	48.720669000000001	п. Стандартный, Совхозная, 11, начальная школа	Россия, Волгоградская область, Среднеахтубинский район, село Стандартный	0101000020E61000002F4FE78A52784640DA1EBDE13E5C4840
28407	2	22	629	4067	26546	\N	48.711424999999998	р.п.Средняя Ахтуба, микрорайон, 74, школа № 1	Россия, Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба	0101000020E6100000A661F888986E4640454772F90F5B4840
28406	2	22	629	4067	26546	\N	48.711424999999998	р.п.Средняя Ахтуба, микрорайон, 70, ПУ-50		0101000020E6100000A661F888986E4640454772F90F5B4840
28413	2	22	629	4067	26972	\N	48.711424999999998	р.п. Средняя Ахтуба, Садовая, 22, школа № 3 им Горького		0101000020E6100000A661F888986E4640454772F90F5B4840
28408	2	22	629	4067	26816	\N	48.711424999999998	р.п.Средняя Ахтуба, Партизанская, 47, школа № 2 им. Ломоносова	Россия, Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба	0101000020E6100000A661F888986E4640454772F90F5B4840
28411	2	22	629	4067	26735	\N	48.711424999999998	"р.п.Средняя Ахтуба, Гагарина, 114,ДС ""Дельфиненок"""	Россия, Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба	0101000020E6100000A661F888986E4640454772F90F5B4840
28414	2	22	629	4067	26736	\N	48.711424999999998	р.п. Средняя Ахтуба, Воровкого, 12, школа-интернат		0101000020E6100000A661F888986E4640454772F90F5B4840
28431	2	22	629	51721	27670	\N	48.555218753485903	х.Репино, Новостройка, 21,Школа-сад	Россия, Волгоградская область, Среднеахтубинский район, село Репино	0101000020E6100000E62329E961644640158F8B6A11474840
28442	2	22	629	6014	27305	\N	49.016770999999999	с.Рахинка, Советская, 35а, Здание дома культуры	Россия, Волгоградская область, Среднеахтубинский район, село Рахинка	0101000020E610000006BD378600764640B742588D25824840
27859	2	22	629	45891	26433	\N	48.755617999999998	поселок Приканальный, ул.Приканальная, д.33. ФАП		0101000020E6100000CCECF318E55546406C223317B8604840
28430	2	22	629	5374	27128	\N	48.574260000000002	х.Пламенка, Новая, 1, Здание школы	Россия, Волгоградская область, Среднеахтубинский район, село Пламенка	0101000020E610000092B245D26E5C464053B3075A81494840
28404	2	22	629	51434	27024	\N	48.677730534850802	п.Песчанка, Солнечная, 22а, начальная школа	Россия, Волгоградская область, поселок Песчанка	0101000020E6100000A86E2EFEB64B4640213EB0E3BF564840
28438	2	22	629	51695	27530	\N	48.947190003362103	п. Максим Горький, Школьная, 7, Здание школы	Россия, Волгоградская область, Среднеахтубинский район, село Максима Горького	0101000020E610000051DD5CFC6D934640938C9C853D794840
28439	2	22	629	47815	26821	\N	48.679496	п. Куйбышев, Турусова, 26а, школа		0101000020E6100000F3AB3940306D4640A4E194B9F9564840
14613	2	22	629	47815	26821	\N	48.679496	п. Куйбышев, Турусова, 26а, средняя школа		0101000020E6100000F3AB3940306D4640A4E194B9F9564840
28432	2	22	629	48202	26680	\N	48.680447999999998	х.Красный Сад, Школьная, 23, Здание школы	Россия, Волгоградская область, Среднеахтубинский район, село Красный Сад	0101000020E6100000F3CB608C48724640765089EB18574840
28437	2	22	629	51430	27206	\N	49.081782944434003	п. Красный Октябрь, Рыжовой, 44, Здание дома культуры	Россия, Волгоградская область, Среднеахтубинский район, село Красный Октябрь	0101000020E61000006214048F6FA74640342F87DD778A4840
28436	2	22	629	51430	27206	\N	49.0818391041852	п. Красный Октябрь, Рыжовой, 44, Здание ДК	Россия, Волгоградская область, Среднеахтубинский район, село Красный Октябрь	0101000020E61000008388D4B48BA74640C8444AB3798A4840
28399	2	22	629	47533	26990	\N	48.706574000000003	"г.Краснослободск, Шестакова, 29, ЦД и развлечений ""Остров"""		0101000020E6100000DDB243FCC34A46401A1A4F04715A4840
28401	2	22	629	47533	26919	\N	48.706574000000003	г.Краснослободск, Тимирязева, 65, Центр детского творчества		0101000020E6100000DDB243FCC34A46401A1A4F04715A4840
28402	2	22	629	47533	26718	\N	48.706574000000003	г.Краснослободск, Свердлова, 51,Здание Опытной станции ВИР	Россия, Волгоградская область, Среднеахтубинский район, Краснослободск	0101000020E6100000DDB243FCC34A46401A1A4F04715A4840
28397	2	22	629	47533	26812	\N	48.705340934165498	"г.Краснослободск, Ленина, 164, МОУ ""Краснослободская школа№4"""	Россия, Волгоградская область, Среднеахтубинский район, Краснослободск	0101000020E6100000E08442041C4C464093C3279D485A4840
28400	2	22	629	47533	26834	\N	48.707301459509502	г.Краснослободск, Ленина, 1, гимназия	Россия, Волгоградская область, Среднеахтубинский район, Краснослободск	0101000020E6100000B3EBDE8AC44A4640CCB6D3D6885A4840
28441	2	22	629	51620	27355	\N	48.639745366833303	х.Кочетково, Центральная, 27/5,Здание клуба	Россия, Волгоградская область, Среднеахтубинский район, село Кочетково	0101000020E61000000150C58D5B6E4640C763062AE3514840
28416	2	22	629	4570	26740	\N	48.715716999999998	п. Колхозная Ахтуба, Центральная, 35а, начальная школа		0101000020E6100000DEFFC709136646407A185A9D9C5B4840
28429	2	22	629	51718	27649	\N	48.597396000000003	х.Клетский, Советская, 21, дом культуры	Россия, Волгоградская область, Среднеахтубинский район, село Клетский	0101000020E6100000AF9811DE1E5A46407061DD78774C4840
28417	2	22	629	4648	26562	\N	48.735615000000003	"п. Киляковка, Тракторозаводская, 1, ТОС ""Киляковка"""		0101000020E61000003882548A1D65464039B9DFA1285E4840
28433	2	22	629	51491	27110	\N	48.669917536497401	п.Калинина, Калинина, 34б, Здание клуб	Россия, Волгоградская область, Среднеахтубинский район, село Калинина	0101000020E61000000133DFC14F78464039807EDFBF554840
28421	2	22	629	47990	27119	\N	48.815193000000001	п. Звездный, Школьная, 1, Здание школы	Россия, Волгоградская область, Среднеахтубинский район, село Звездный	0101000020E6100000FDF49F353F764640CD76853E58684840
28446	2	22	629	51608	27331	\N	48.677482081347101	"х. Закутский, Ленина, 2в, Здание СКДЦ ""Стимул"""	Россия, Волгоградская область, Среднеахтубинский район, село Закутский	0101000020E6100000CCED5EEE9355464078D0ECBAB7564840
28405	2	22	629	47688	26721	\N	48.666330000000002	п.Вторая Пятилетка, Молодежная, 21, библиотека	Россия, Волгоградская область, Среднеахтубинский район, село Вторая Пятилетка	0101000020E610000059FCA6B052474640FE2B2B4D4A554840
28420	2	22	629	4766	26743	\N	48.949219999999997	с. Верхнепогромное, Центральная, 32, дом культуры		0101000020E6100000EF01BA2F676C4640C45A7C0A80794840
28419	2	22	629	4766	26743	\N	48.949219999999997	с. Верхнепогромное, Центральная, 32,  дом культуры		0101000020E6100000EF01BA2F676C4640C45A7C0A80794840
28440	2	22	629	5913	26468	\N	48.657165999999997	п. Великий Октябрь, Школьная, 24,Здание школы		0101000020E6100000D2393FC5715C46408505F7031E544840
28367	2	22	313	1892	\N	\N	49.486798	хутор Чеботаревский, Чеботаревский ФАП		0101000020E6100000CFF3A78DEA2445400DE198654FBE4840
28371	2	22	313	2103	\N	\N	49.131849000000003	хутор Хохлачёв, Малаховский ФАП	Россия, Волгоградская область, Серафимовичский район, село Хохлачев	0101000020E61000006AA2CF47190B45405281936DE0904840
28360	2	22	313	1512	\N	\N	49.580286000000001	хутор Хованский, Хованский ФАП	Россия, Волгоградская область, Серафимовичский район, село Хованский	0101000020E6100000FB93F8DC09464540D029C8CF46CA4840
28376	2	22	313	2442	\N	\N	49.414544999999997	хутор Фомихинский, Фомихинский ФАП		0101000020E610000080F277EFA847454033DC80CF0FB54840
28361	2	22	313	1548	\N	\N	49.571598999999999	станица Усть-Хоперская, Усть-Хоперский дом культуры		0101000020E610000074B2D47ABF33454091B6F1272AC94840
28365	2	22	313	1755	\N	\N	49.580882000000003	хутор Тюковной, Тюковновский дом культуры		0101000020E6100000E3C798BB96124540E46A64575ACA4840
28384	2	22	313	2901	\N	\N	49.768456	хутор Трясиновский, Трясиновский дом культуры		0101000020E6100000F3AB3940307D45401E3526C45CE24840
28386	2	22	313	3016	\N	\N	49.741934000000001	хутор Теркин, зд.адм.Теркинского с/п		0101000020E610000029232E008D9045402EE57CB1F7DE4840
28375	2	22	313	2375	\N	\N	49.347408999999999	хутор Среднецарицынский, зд.адм.Среднецарицынского с/п	Россия, Волгоградская область, Серафимовичский район, село Среднецарицынский	0101000020E61000005952EE3EC747454004ABEAE577AC4840
28392	2	22	313	3360	27227	\N	49.577224925080301	город Серафимович, ул.Подтелкова, 63, техникум (СТМСХ)	Россия, Волгоградская область, Серафимовичский район, Серафимович	0101000020E61000008E209562475D454080B74082E2C94840
28393	2	22	313	3360	26549	\N	49.575665000000001	город Серафимович, ул.Октябрьская, 47, центральная библиотека	Россия, Волгоградская область, Серафимовичский район, Серафимович	0101000020E6100000DE3AFF76D95D4540D6390664AFC94840
28395	2	22	313	3360	26716	\N	49.575665000000001	город Серафимович, ул.68-Гвардейская, 105, ДРСУ		0101000020E6100000DE3AFF76D95D4540D6390664AFC94840
28370	2	22	313	2096	\N	\N	49.206862000000001	хутор Пронин, Пронинский дом культуры		0101000020E61000006170CD1DFD1B454080643A747A9A4840
28381	2	22	313	51328	\N	\N	49.687384115890403	хутор Подольховский, Подольховский ФАП	Россия, Волгоградская область, Серафимовичский район, село Подольховский	0101000020E6100000D811876C2065454097E5EB32FCD74840
28391	2	22	313	3274	\N	\N	49.570898	хутор Отрожки, здание администрации	Россия, Волгоградская область, Серафимовичский район, село Отрожки	0101000020E6100000DF6B088ECB6C454008AD872F13C94840
28387	2	22	313	3023	\N	\N	49.742086	хутор Орлиновский, Орлиновский медпункт		0101000020E6100000881057CEDE934540E4688EACFCDE4840
28374	2	22	313	2294	\N	\N	49.157679000000002	"хутор Новопавловский, адм.здание ТОСа ""Новопавловский"""	Россия, Волгоградская область, Серафимовичский район, село Новопавловский	0101000020E61000004243FF04171F45400C2252D32E944840
28380	2	22	313	51385	\N	\N	49.634788018761498	хутор Новоалександровский, Новоалександровский ФАП	Россия, Волгоградская область, Серафимовичский район, село Новоалександровский	0101000020E61000006C94F59B8959454056F2B1BB40D14840
28383	2	22	313	2789	\N	\N	49.739187000000001	хутор Мостовский, Мостовское ОПС	Россия, Волгоградская область, Серафимовичский район, село Мостовский	0101000020E6100000183F8D7BF37145406E50FBAD9DDE4840
28364	2	22	313	1742	\N	\N	49.582844000000001	хутор Крутовский, Крутовский дом культуры	Россия, Волгоградская область, Серафимовичский район, село Крутовский	0101000020E6100000A4703D0AD71D4540BD55D7A19ACA4840
28390	2	22	313	3242	\N	\N	49.377594999999999	хутор Козиновский, зда. бывшей администрации с/с		0101000020E61000006281AFE8D69D45400A11700855B04840
28388	2	22	313	3129	\N	\N	49.590746000000003	хутор Клетско-Почтовский, Клетско-Почтовский дом культуры		0101000020E6100000A2B8E34D7E874540151F9F909DCB4840
27973	2	22	313	51665	27470	\N	49.443770155183103	х.Калмыковский, Центральная, 10	Россия, Волгоградская область, Серафимовичский район, село Калмыковский	0101000020E61000000936AE7FD72F454014799274CDB84840
28296	2	22	862	30556	26962	\N	49.127155999999999	п. Эльтон, Вокзальная, 24		0101000020E6100000D350A390646C4740BEBED6A546904840
15214	5	43	323	3254	70855	\N	51.405918	с. Чемал, Пчелкина, 4		0101000020E6100000693BA6EECA805540CA6DFB1EF5B34940
28382	2	22	313	2779	\N	\N	49.719942000000003	хутор Зимняцкий, Зимняцкий дом культуры	Россия, Волгоградская область, Серафимовичский район, село Зимняцкий	0101000020E61000005B5CE333D96D45402882380F27DC4840
28358	2	22	313	51285	\N	\N	49.582313820624101	хутор Затонский, Затонский ФАП	Россия, Волгоградская область, Серафимовичский район, село Крутовский	0101000020E610000098C0ADBB791E45406000E14389CA4840
28389	2	22	313	51429	\N	\N	49.640314399442701	хутор Ендовский, Ендовский сельский клуб	Россия, Волгоградская область, Серафимовичский район, село Ендовский	0101000020E6100000E8DCED7A698A4540E19524CFF5D14840
28369	2	22	313	51534	\N	\N	49.364110397100198	хутор Горбатовский, Горбатовский дом культуры		0101000020E6100000444C89247A054540C2120F289BAE4840
28359	2	22	313	1407	\N	\N	49.549686999999999	хутор Буерак-Поповский, Буерак-Поповский дом культуры		0101000020E6100000E7A8A3E36A4E4540A704C4245CC64840
28063	2	22	313	51628	27379	\N	49.378516890118199	хутор Большой, Ленина, 25, Большовский сельский ДК	Россия, Волгоградская область, Серафимовичский район, село Большой	0101000020E6100000B81D1A16A328454072FDBB3E73B04840
28378	2	22	313	2547	\N	\N	49.488804999999999	хутор Бобровский-2, Бобровский-2 дом культуры		0101000020E61000000EBE30992A604540868F882991BE4840
28362	2	22	313	1603	\N	\N	49.591552	хутор Бобровский-1, Бобровский-1й дом культуры		0101000020E6100000F48C7DC9C629454013F1D6F9B7CB4840
28372	2	22	313	2211	\N	\N	49.297784999999998	хутор Блиновский, Блиновский сельский клуб	Россия, Волгоградская область, Серафимовичский район, село Блиновский	0101000020E61000009276A38FF9244540A31EA2D11DA64840
28379	2	22	313	47183	\N	\N	49.607550000000003	хутор Березки, Березкинский дом культуры	Россия, Волгоградская область, Серафимовичский район, село Березки	0101000020E6100000F0164850FC5E4540A857CA32C4CD4840
28377	2	22	313	51351	\N	\N	49.430616028172103	хутор Базки, Базковское ОПС	Россия, Волгоградская область, Серафимовичский район, село Базки	0101000020E6100000F18288D4B46145403291D26C1EB74840
28351	2	22	6	970	27284	\N	48.442374000000001	с.Червленое, Клубная, 7		0101000020E610000020F12BD6702F4640E44C13B69F384840
14665	2	22	6	8982	26857	\N	48.196122000000003	с.Цаца, 18 ГМП, 53	Россия, Волгоградская область, Светлоярский район, село Цаца	0101000020E61000000B60CAC001574640580394861A194840
28347	2	22	6	51362	26805	\N	48.140215518248098	ст.Абганерово, Сердюкова, 2	Россия, Волгоградская область, Светлоярский район, село Станция Абганерово	0101000020E6100000B3B3E89D0A0E46401F300F99F2114840
28350	2	22	6	51451	27049	\N	48.320519835899098	п.Северный, Школьная, 5	Россия, Волгоградская область, Светлоярский район, село Северный	0101000020E6100000202922C32A08464062DBA2CC06294840
28334	2	22	6	32203	\N	\N	48.471676000000002	"р.п.Светлый Яр, 1 микрорайон, Здание МКУ ""Электроник"""		0101000020E61000005A80B6D5AC614640702711E15F3C4840
28336	2	22	6	32203	26688	\N	48.471676000000002	р.п.Светлый Яр, Сидорова, 7		0101000020E61000005A80B6D5AC614640702711E15F3C4840
28330	2	22	6	32203	26688	\N	48.471676000000002	р.п.Светлый Яр, Сидорова, 3		0101000020E61000005A80B6D5AC614640702711E15F3C4840
28331	2	22	6	32203	26798	\N	48.471676000000002	р.п.Светлы Яр, пер.Зеленый, 1		0101000020E61000005A80B6D5AC614640702711E15F3C4840
28332	2	22	6	32203	26983	\N	48.473315222940698	р.п.Светлый Яр, ул.Мелиоративная, 1	Россия, Волгоградская область, Светлоярский район, Светлый Яр	0101000020E6100000E7C8CA2F8363464066DAFE95953C4840
28335	2	22	6	32203	27267	\N	48.471676000000002	"р.п.Светлый Яр, 1 микрорайон, дом "" 23 ""а"""		0101000020E61000005A80B6D5AC614640702711E15F3C4840
28333	2	22	6	32203	27267	\N	48.471676000000002	р.п. Светлый Яр, 1 микрорайон, 29	Россия, Волгоградская область, Светлоярский район, Светлый Яр	0101000020E61000005A80B6D5AC614640702711E15F3C4840
28339	2	22	6	173	\N	\N	48.421750000000003	с.Райгород, пос.Водстрой, Здание МКОУ Райгородская СОШ		0101000020E6100000A1A3552DE9744640448B6CE7FB354840
28338	2	22	6	173	27262	\N	48.421750000000003	с.Райгород, ул.Советская, 195	Россия, Волгоградская область, Светлоярский район, село Райгород	0101000020E6100000A1A3552DE9744640448B6CE7FB354840
28349	2	22	6	46559	26899	\N	48.315565999999997	п.Прудовый, Набережная, 35		0101000020E61000004721C9ACDE23464061DD787764284840
28308	2	22	6	45700	27035	\N	48.162706	п.Привольный, пер.Школьный, 3		0101000020E61000008E0244C18C0F4640766EDA8CD3144840
28344	2	22	6	46462	26689	\N	48.237828	п.Приволжский, Школьная, 291		0101000020E61000004FE960FD9F4946405B09DD25711E4840
28348	2	22	6	46555	26977	\N	48.478968999999999	п.Нариман, Дружбы, 1		0101000020E61000008DB5BFB33D1A46401F662FDB4E3D4840
28342	2	22	6	403	26684	\N	48.449503999999997	с.Малые Чапурники, Школьная, 20		0101000020E61000008E76DCF0BB494640E9B5D95889394840
28345	2	22	6	46480	27090	\N	48.220379999999999	п.Луговой, Красных Зорь, 23	Россия, Волгоградская область, Светлоярский район, село Луговой	0101000020E61000001C977153033F4640A3586E69351C4840
28346	2	22	6	46508	27092	\N	48.168505000000003	п.Краснопартизанский, Чапаева, Здание МОУ Краснопартизанской ООШ		0101000020E6100000C784984BAA204640331B649291154840
28354	2	22	6	46658	26763	\N	48.474058999999997	п.Кирова, Школьная, 2-а	Россия, Волгоградская область, Светлоярский район, село Кирова	0101000020E6100000BD1E4C8A8F434640EEAF1EF7AD3C4840
28355	2	22	6	51550	27230	\N	48.339581000000003	"п.Кирова, Кирова, 6 ""а"""	Россия, Волгоградская область, Волгоград городской округ, село Соляной	0101000020E610000012C0CDE2C5424640E7ABE463772B4840
28352	2	22	6	51565	27248	\N	48.424584000000003	ст.Канальная, Привокзальная, Здание вокзала ж/д	Россия, Волгоградская область, Светлоярский район, село Канальная	0101000020E61000009D9D0C8E92314640D333BDC458364840
28357	2	22	6	46722	\N	\N	48.474482999999999	с.Ивановка, Советская, 7	Россия, Волгоградская область, Светлоярский район, село Ивановка	0101000020E6100000FA4674CFBA30464005C1E3DBBB3C4840
28343	2	22	6	489	27177	\N	48.330877999999998	"с.Дубовый Овраг, Октябрьская, 62 ""а"""		0101000020E6100000191D90847D4F4640A27BD6355A2A4840
28341	2	22	6	305	26842	\N	48.419817999999999	"с.Большие Чапурники, Ильина, 46 ""а"""		0101000020E61000002AC6F99B504A4640D522A298BC354840
28324	2	22	1917	31945	26673	\N	50.644756999999998	"Волгоградская область, Руднянский муниципальный район, Лопуховское сельское поселение, с. Ушинка, Советская д.34, ""Берёзовский ФАБ"" МУЗ ЦРБ"		0101000020E61000001FD8F15F203E4640FC6EBA6587524940
28329	2	22	1917	32170	26976	\N	50.796008	"Волгоградская область, Руднянский муниципальный район, Сосновское сельское поселение, с. Сосновка, Мирная д.5, МУ ""Сосновский СДК"""		0101000020E610000011C64FE3DE2246405CAD1397E3654940
28315	2	22	1917	31540	26779	\N	50.869450999999998	"Волгоградская область, Руднянский муниципальный район, Руднянское городское поселение, п. Садовый, Новая, д.4, МДОУ ""Плодосовхозный д/сад"""	Россия, Волгоградская область, Руднянский район, село Садовый	0101000020E6100000501C40BFEF494640BC3C9D2B4A6F4940
28311	2	22	1917	51569	27252	\N	50.810136999999997	"Волгоградская область, Руднянский муниципальный район, Руднянское городское поселение, р.п. Рудня, Строителей, д.2, МОУ ""Щелканская СОШ"""	Россия, Волгоградская область, Руднянский район, поселок городского типа Рудня	0101000020E610000045662E7079464640C823B891B2674940
28314	2	22	1917	51569	27255	\N	50.810136999999997	"Волгоградская область, Руднянский муниципальный район, Руднянское городское поселение, р.п. Рудня, Советская, д.7, МОУ ""Руднянская СОШ"""	Россия, Волгоградская область, Руднянский район, поселок городского типа Рудня	0101000020E610000045662E7079464640C823B891B2674940
28316	2	22	1917	51569	75600	\N	50.802592476265602	"Волгоградская область, Руднянский муниципальный район, Руднянское городское поселение, с. Русская Бундевка, Горная, д.131, МУ ""Русско-Бундевский СДК"""	Россия, Волгоградская область, Руднянский район, поселок городского типа Рудня	0101000020E61000007BA35698BE474640FF03AC55BB664940
28313	2	22	1917	31297	26632	\N	50.810136999999997	"Волгоградская область, Руднянский муниципальный район, Руднянское городское поселение, р.п. Рудня, Октябрьская д.43, МОУ ДОД ""Центр детского творчества"""		0101000020E610000045662E7079464640C823B891B2674940
28310	2	22	1917	31297	26425	\N	50.810136999999997	"Волгоградская область, Руднянский муниципальный район, Руднянское городское поселение, р.п. Рудня, Комсомольская, д.2, МУ ""РЦКД ""Современник"""		0101000020E610000045662E7079464640C823B891B2674940
28312	2	22	1917	31297	26463	\N	50.810136999999997	"Волгоградская область, Руднянский муниципальный район, Руднянское городское поселение, р.п. Рудня, Володарского, д.2-в, НОУ Руднянский УСТК ДОСААФ"""		0101000020E610000045662E7079464640C823B891B2674940
28327	2	22	1917	32095	26974	\N	50.885547000000003	"Волгоградская область, Руднянский муниципальный район, Осичковское сельское поселение, с. Подкуйково, Полевая, д.10, МУ ""Подкуйковский СДК"""		0101000020E610000092E86514CB4746401409A69A59714940
28326	2	22	1917	32034	26975	\N	50.950105000000001	"Волгоградская область, Руднянский муниципальный район, Осичковское сельское поселение, с. Осички, Мирная, д.25, МБОУ ""Осичковская СОШ"""		0101000020E610000038143E5B074146400F62670A9D794940
28319	2	22	1917	31715	26682	\N	50.539710999999997	"Волгоградская область, Руднянский муниципальный район, Громковское сельское поселение, с. Новый Кондаль, Пролетарская д.49, МУ ""Новокондальский ФАП""МУЗ ЦРБ"		0101000020E610000029ED0DBE303346404E25034015454940
28325	2	22	1917	32013	27086	\N	50.836857000000002	"Волгоградская область, Руднянский муниципальный район, Матышевское сельское поселение, с. Матышево, Московская д.56, Библиотека МУ ""Матышевский СДК"""	Россия, Волгоградская область, Руднянский район, село Матышево	0101000020E61000000F4757E9EE1A4640DF3653211E6B4940
28323	2	22	1917	31924	27008	\N	50.625875000000001	Волгоградская область, Руднянский муниципальный район, Лопуховское сельское поселение, с. Лопуховка, Молодёжная д.2, Администрация Лопуховского с/пос	Россия, Волгоградская область, Руднянский район, село Лопуховка	0101000020E6100000FC53AA44D93B4640273108AC1C504940
28322	2	22	1917	31854	26840	\N	51.013027000000001	"Волгоградская область, Руднянский муниципальный район, Лемешкинское сельское поселение, с. Лемешкино, Кирова, д.97, МУ ""Лемешкинский СДК"""		0101000020E61000007B319413ED3C4640857B65DEAA814940
28321	2	22	1917	31826	27160	\N	50.997939000000002	Волгоградская область, Руднянский муниципальный район, Козловское сельское поселение, с. Козловка, Майская д.49, Администрация Козловского с/пос		0101000020E6100000D732198EE72D464094331477BC7F4940
28320	2	22	1917	31781	26685	\N	50.836981999999999	Волгоградская область, Руднянский муниципальный район, Ильменское сельское поселение, с. Ильмень, Мира д.1, Администрация Ильменск. с/пос		0101000020E6100000B9AB5791D13146409BABE639226B4940
28318	2	22	1917	31697	26958	\N	50.58766	"Волгоградская область, Руднянский муниципальный район, Громковское сельское поселение, с. Громки, Молодежная, д.4, МУ ""Громковский СДК"""		0101000020E61000000727A25F5B3946406C956071384B4940
28317	2	22	1917	31649	27081	\N	50.829461999999999	Волгоградская область, Руднянский муниципальный район, Большесудаченское сельское поселение, с. Большое Судачье, Школьная д.18, Администрация Большесудачен. с/пос	Россия, Волгоградская область, Руднянский район, село Большое Судачье	0101000020E6100000D593F947DF0A46402BA391CF2B6A4940
28328	2	22	1917	32122	26896	\N	50.894705999999999	"Волгоградская область, Руднянский муниципальный район, Осичковское сельское поселение, с. Баранниково, Центральная д.23, МУ ""Баранниковский СДК"""		0101000020E61000007094BC3AC74A46407AC4E8B985724940
28282	2	22	862	51527	\N	\N	49.898640611266103	х. Худушний, Худушнинская МНОШ	Россия, Волгоградская область, Палласовский район, село Худушный	0101000020E6100000E3FF8EA85065474020EC14AB06F34840
28209	2	22	862	26585	26535	\N	50.037526	с. Старая Иванцовка, Центральная, 28		0101000020E6100000938D075BEC5A4740F65FE7A6CD044940
28279	2	22	862	51675	27487	\N	49.987940000000002	х. Старая Балка, Школьная, 10	Россия, Волгоградская область, Палласовский район, село Старая Балка	0101000020E61000009D103AE812584740833463D174FE4840
28271	2	22	862	51621	27361	\N	50.112225570143103	х. Смычка, ул.Береговая, д26		0101000020E6100000B18861873195474065E1EB6B5D0E4940
28277	2	22	862	51461	27063	\N	49.932806427797097	п.Серогодского, Карпенко, 12		0101000020E6100000A5BDC117268547409CC1DF2F66F74840
28287	2	22	862	51544	\N	\N	49.8441609503232	х.Сапунки, Сапунсковская МНОШ	Россия, Волгоградская область, Палласовский район, село Сапунков	0101000020E61000001BBB44F5D630474082C7B7770DEC4840
28273	2	22	862	49370	27221	\N	50.074083999999999	с. Савинка, ул.Чапаева, д152		0101000020E610000034D769A4A58C47401494A2957B094940
28274	2	22	862	49370	27225	\N	50.074083999999999	с. Савинка, пер.Гагарина, д 4	Россия, Волгоградская область, Палласовский район, село Савинка	0101000020E610000034D769A4A58C47401494A2957B094940
28235	2	22	862	48783	26565	\N	50.197374000000003	п.Ромашки, А.Уриха, 55		0101000020E6100000F8C3CF7F0F564740558A1D8D43194940
28126	2	22	862	18989	\N	\N	49.322923000000003	с.Путь Ильича, Ильичевский СДК		0101000020E61000004051D9B0A65847402810768A55A94840
28288	2	22	862	51312	26641	\N	49.650126961086499	х. Пруденкотв, ул. Прудентовская, 1	Россия, Волгоградская область, Палласовский район, село Прудентов	0101000020E6100000709A3E3BE0264740909F8D5C37D34840
28297	2	22	862	51373	\N	\N	49.065515401361402	х. Приозерный, Приозерская МНОШ	Россия, Волгоградская область, Палласовский район, село Приозерный	0101000020E610000044FB58C16F614740DF32A7CB62884840
14612	2	22	862	6484	27032	\N	50.046922000000002	г. Палласовка, пл.Ленина, 1-а		0101000020E610000050A8A78FC071474041BB438A01064940
28265	2	22	862	6484	26574	\N	50.053357027513798	г. Палласовка, ул.Юбилейная, д 60	Россия, Волгоградская область, Палласовский район, Палласовка	0101000020E61000002B357BA0157047409F01F566D4064940
28267	2	22	862	6484	26849	\N	50.046922000000002	г. Палласовка, ул.Ушакова, д,2	Россия, Волгоградская область, Палласовский район, Палласовка	0101000020E610000050A8A78FC071474041BB438A01064940
28263	2	22	862	6484	26948	\N	50.046922000000002	г. Палласовка, ул. Советская, д.28-а	Россия, Волгоградская область, Палласовский район, Палласовка	0101000020E610000050A8A78FC071474041BB438A01064940
28269	2	22	862	6484	26604	\N	50.046922000000002	г. Палласовка, ул.Остравская, д.17		0101000020E610000050A8A78FC071474041BB438A01064940
28266	2	22	862	6484	26848	\N	50.046922000000002	г. Палласовка, ул.Новая, д,52		0101000020E610000050A8A78FC071474041BB438A01064940
28268	2	22	862	6484	27040	\N	50.046922000000002	г. Палласовка, ул.Мира, д,9	Россия, Волгоградская область, Палласовский район, Палласовка	0101000020E610000050A8A78FC071474041BB438A01064940
28264	2	22	862	6484	26946	\N	50.046922000000002	г. Палласовка, ул.Красноармейская, 1	Россия, Волгоградская область, Палласовский район, Палласовка	0101000020E610000050A8A78FC071474041BB438A01064940
28147	2	22	862	23656	26984	\N	50.028882000000003	п. Новая Иванцовка, Школьная, 6		0101000020E610000046B41D5377654740B7B8C667B2034940
28276	2	22	862	49408	26485	\N	50.027383	п.Лиманный, ул.Школьная, д.12	Россия, Волгоградская область, Палласовский район, село Лиманный	0101000020E6100000C8CF46AE9B864740B2BB404981034940
28270	2	22	862	51450	27046	\N	50.183532256656299	п.Кумысолечебница, ул.Центральная, 3	Россия, Волгоградская область, Палласовский район, село Кумысолечебница	0101000020E610000023F433F5BA9947407EE200FA7D174940
28272	2	22	862	29457	27219	\N	50.112572999999998	п. Куликов, ул. Школьная, д.10		0101000020E610000093FC885FB1A84740D0B4C4CA680E4940
28259	2	22	862	51546	27214	\N	49.984819280624997	п. Красный Октябрь, Цветочная, 1	Россия, Волгоградская область, Палласовский район, село Красный Октябрь	0101000020E6100000315EF3AACE4447405EBD8A8C0EFE4840
28291	2	22	862	45382	26879	\N	49.541328	п.Комсомольский, Мирная, 3	Россия, Волгоградская область, Палласовский район, село Комсомольский	0101000020E6100000CDE9B298D86047405D34643C4AC54840
28299	2	22	862	48208	26764	\N	49.120798043090801	х. Калинина, сельский клуб	Россия, Волгоградская область, Палласовский район, село Калинина	0101000020E6100000AB59677C5F7847400BB6114F768F4840
28283	2	22	862	29955	\N	\N	49.913158193105801	х. Калашники, Клашаниковская МНОШ	Россия, Волгоградская область, Палласовский район, село Калашники	0101000020E6100000D1CFD4EB165D4740570A815CE2F44840
28290	2	22	862	30266	27240	\N	49.742370999999999	с. Кайсацкое, Советская, 34		0101000020E610000097E315889E6C4740D93F4F0306DF4840
28284	2	22	862	29985	26863	\N	49.764341999999999	п. Золотари, Комсомольская, 14		0101000020E6100000B8205B96AF394740C87A6AF5D5E14840
28275	2	22	862	49391	26859	\N	50.038173999999998	п. Заливной, пер. Гоголя, 5		0101000020E6100000537AA697188547405CC7B8E2E2044940
28280	2	22	862	29827	\N	\N	49.8670543125222	х. Жолобов, Жолобская МНОШ	Россия, Волгоградская область, Палласовский район, село Жолобов	0101000020E6100000C11F7EFE7B4C4740D9EE1EA0FBEE4840
28286	2	22	862	51383	\N	\N	49.479321239638999	х. Ерши, Ершовская МНОШ	Россия, Волгоградская область, Палласовский район	0101000020E6100000E95F92CA143747409CA4F9635ABD4840
28289	2	22	862	30235	\N	\N	49.655954999999999	х.Гормаки, Гормаковуская МНОШ	Россия, Волгоградская область, Палласовский район, село Гормаки	0101000020E610000099D9E731CA0B4740E7525C55F6D34840
28292	2	22	862	45398	27158	\N	49.425778999999999	с. Вишневка, Мира, 19-а	Россия, Волгоградская область, Палласовский район, село Вишневка	0101000020E61000009B030473F46247406B2920ED7FB64840
28294	2	22	862	30510	26960	\N	49.282806999999998	п. Венгеловка, Ветеринаров, 15		0101000020E6100000FE63213A04684740390A100533A44840
28298	2	22	862	30708	\N	\N	48.892205870230796	х. Большой Симкин, Большисимкинская МООШ	Россия, Волгоградская область, Палласовский район, село Большой Симкин	0101000020E610000093A8177C9A554740C2A563CE33724840
28255	2	22	1835	51709	27606	\N	49.762168754223403	Волгоградская область, Ольховский муниципальный район, Ягодновское сельское поселение с. Ягодное, Советская, 3	Россия, Волгоградская область, Ольховский район, село Ягодное	0101000020E610000006F7031E186046403483F8C08EE14840
28258	2	22	1835	51361	26803	\N	49.652374999999999	Волгоградская область, Ольховский муниципальный район, Солодчинское сельское поселение с. Солодча, Краснопартизанская, 9	Россия, Волгоградская область, Ольховский район, село Солодча	0101000020E6100000E2CCAFE6002546402FDD240681D34840
28260	2	22	1835	51361	27458	\N	49.649699744650199	Волгоградская область, Ольховский муниципальный район, Солодчинское сельское поселение с. Солодча, Кирова, 2	Россия, Волгоградская область, Ольховский район, село Солодча	0101000020E6100000E59CD843FB244640091B9E5E29D34840
28246	2	22	1835	51641	27398	\N	49.993811999999998	Волгоградская область, Ольховский муниципальный район, Рыбинское сельское поселение с. Рыбинка, Центральная, 52	Россия, Волгоградская область, Ольховский район, село Рыбинка	0101000020E6100000D36C1E87C1624640A92F4B3B35FF4840
28257	2	22	1835	51524	27184	\N	49.766055659617201	Волгоградская область, Ольховский муниципальный район, Романовское сельское поселение с. Романовка, Ценральная, 68	Россия, Волгоградская область, Ольховский район, село Романовка	0101000020E6100000AE635C71718C4640C9737D1F0EE24840
28250	2	22	1835	51729	27718	\N	49.912648107578697	Волгоградская область, Ольховский муниципальный район, Нежинское сельское поселение х. П. Балка, Новая, 2	Россия, Волгоградская область, Ольховский район, село Погожья Балка	0101000020E61000008847E2E5E9224640416150A6D1F44840
28240	2	22	1835	51697	27535	\N	49.8584623297143	Волгоградская область, Ольховский муниципальный район, Ольховское сельское поселение с.Ольховка, Восточная, 9В	Россия, Волгоградская область, Ольховский район, поселок городского типа Ольховка	0101000020E610000085B01A4B58474640EC6D3315E2ED4840
28241	2	22	1835	51697	27702	\N	49.8564453149786	Волгоградская область, Ольховский муниципальный район, Ольховское сельское поселение с.Ольховка, Советская, 14	Россия, Волгоградская область, Ольховский район, поселок городского типа Ольховка	0101000020E610000098F6CDFDD54746404FE960FD9FED4840
28242	2	22	1835	51321	26693	\N	49.861902471560398	Волгоградская область, Ольховский муниципальный район, Ольховское сельское поселение с.Ольховка, Базарная, 9А	Россия, Волгоградская область, Ольховский район, поселок Ольховка	0101000020E6100000616C21C841474640B22D03CE52EE4840
28249	2	22	1835	51403	26981	\N	49.968284918417197	Волгоградская область, Ольховский муниципальный район, Нежинское сельское поселение п. Нежинский, Почтовая, 1	Россия, Волгоградская область, Ольховский район, село Нежинский	0101000020E61000001F477364E52946408B1A4CC3F0FB4840
28256	2	22	1835	51607	27328	\N	49.770749848481898	Волгоградская область, Ольховский муниципальный район, Липовское сельское поселение с. Липовка, Ленина, 54	Россия, Волгоградская область, Ольховский район, село Липовка	0101000020E6100000768C2B2E8E7646402DB29DEFA7E24840
28243	2	22	1835	51517	27170	\N	49.887620842888197	Волгоградская область, Ольховский муниципальный район, Ольховское сельское поселение с. Клиновка, Даниловка, 25	Россия, Волгоградская область, Ольховский район, село Клиновка	0101000020E6100000950B957F2D434640151F9F909DF14840
28247	2	22	1835	51611	27345	\N	50.015360200437499	Волгоградская область, Ольховский муниципальный район, Киреевское сельское поселение с. Киреево, Кооперативная, 6	Россия, Волгоградская область, Ольховский район, село Киреево	0101000020E6100000CFF41263993E464052D50451F7014940
28251	2	22	1835	28480	26678	\N	49.820281000000001	Волгоградская область, Ольховский муниципальный район, Каменнобродское сельское поселение с. Каменный брод, Верхняя, 5		0101000020E6100000B4739A05DA3D4640DD43C2F7FEE84840
28252	2	22	1835	51400	26967	\N	49.804933084168397	Волгоградская область, Ольховский муниципальный район, Зензеватское сельское поселение с. Зензеватка, Элеваторная, 1	Россия, Волгоградская область, Ольховский район, село Зензеватка	0101000020E6100000C0CB0C1B654546404F3C670B08E74840
28253	2	22	1835	51400	27704	\N	49.8023777192575	Волгоградская область, Ольховский муниципальный район, Зензеватское сельское поселение с. Зензеватка, Октябрьская, 1	Россия, Волгоградская область, Ольховский район, село Зензеватка	0101000020E6100000247B849A21454640D3838252B4E64840
28261	2	22	1835	51705	27572	\N	49.710757221203998	Волгоградская область, Ольховский муниципальный район, Солодчинское сельское поселение с. Захаровка, Московская, 14	Россия, Волгоградская область, Ольховский район, село Захаровка	0101000020E61000003A77BB5E9A2E46409833DB15FADA4840
28245	2	22	1835	51497	\N	\N	49.941374182001901	Волгоградская область, Ольховский муниципальный район, Гусевское сельское поселение х. Забурунный, сельский клуб	Россия, Волгоградская область, Ольховский район, село Забурунный	0101000020E6100000C66CC9AA0861464001A777F17EF84840
28244	2	22	1835	51322	26695	\N	49.909967471334397	Волгоградская область, Ольховский муниципальный район, Гусевское сельское поселение с. Гусевка, Почтовая, 62	Россия, Волгоградская область, Ольховский район, село Гусевка	0101000020E6100000901150E10858464039B874CC79F44840
28136	2	22	1688	23171	\N	\N	49.990406999999998	с.Очкуровка, Очкуровский СДК		0101000020E6100000B3B5BE4868B746405F5D15A8C5FE4840
28248	2	22	1835	51609	27338	\N	50.061650147138799	Волгоградская область, Ольховский муниципальный район, Гуровское сельское поселение х. Гурово, Центральная, 18	Россия, Волгоградская область, Ольховский район, село Гурово	0101000020E6100000EFE3688EAC34464032E6AE25E4074940
28237	2	22	1226	27854	26572	\N	47.985557999999997	Волгоградская область, Октябрьский район, с. Шелестово, Сердюкова, 27, Шелестовская средняя школа		0101000020E6100000C9AA083719074640D427B9C326FE4740
28236	2	22	1226	51688	27519	\N	48.273569000000002	Волгоградская область, Октябрьский район, х. Шебалино, Центральная, 7, Администрация сельского поселен	Россия, Волгоградская область, Октябрьский район, село Шебалино	0101000020E6100000F949B54FC7AD454087191A4F04234840
28232	2	22	1226	12440	27341	\N	48.095728136931797	Волгоградская область, Октябрьский район, п. Советский, Рабочая, 1, Администрация Советского с/п	Россия, Волгоградская область, Октябрьский район, село Советский	0101000020E6100000DF8AC40435C24540DFA7AAD0400C4840
28217	2	22	1226	26961	26547	\N	47.828319	Волгоградская область, Октябрьский район, с. Самохино, им. Дуенко, 4/1, Самохинский ФАП		0101000020E61000004C8DD0CFD4DF4540E5D3635B06EA4740
28231	2	22	1226	27590	26926	\N	47.898508999999997	Волгоградская область, Октябрьский район, с. Перегрузное, Центральная, 68, Перегрузненская средняя школа		0101000020E6100000253FE257ACFD4540B114C95702F34740
27863	2	22	1226	27400	\N	\N	47.967016000000001	"поселок Октябрьский, ФГУ ""61 дом офицеров (гарнизонный)"""	Россия, Волгоградская область, Октябрьский район, поселок Октябрьский	0101000020E61000008F352383DCD34540B85A272EC7FB4740
28229	2	22	1226	27400	26749	\N	47.967016000000001	Волгоградская область, Октябрьский муниципальный район, городское поселение р.п. Октябрьский, Небыкова, 2, МОУ ОСОШ № 1	Россия, Волгоградская область, Октябрьский район, поселок Октябрьский	0101000020E61000008F352383DCD34540B85A272EC7FB4740
28230	2	22	1226	51425	27584	\N	47.967016000000001	"Волгоградская область, Октябрьский муниципальный район, городское поселение р.п. Октябрьский, пер. Рабочий, 1, ОАО ""Октябрьская райагротехника"""	Россия, Волгоградская область, Октябрьский район, поселок городского типа Октябрьский	0101000020E61000008F352383DCD34540B85A272EC7FB4740
28227	2	22	1226	51425	27014	\N	47.967016000000001	Волгоградская область, Октябрьский район, р.п.Октябрьский, Октябрьская, 22, Районный Дом Культуры	Россия, Волгоградская область, Октябрьский район, поселок городского типа Октябрьский	0101000020E61000008F352383DCD34540B85A272EC7FB4740
28228	2	22	1226	51425	27016	\N	47.967016000000001	"Волгоградская область, Октябрьский район,р.п. Октябрьский, Ленина, 51, Кинотеатр ""Октябрь"""	Россия, Волгоградская область, Октябрьский район, поселок городского типа Октябрьский	0101000020E61000008F352383DCD34540B85A272EC7FB4740
28226	2	22	1226	51682	27499	\N	48.007342000000001	Волгоградская область, Октябрьский район, х. Новоаксайский, Центральная, 2, Сельский Дом культуры	Россия, Волгоградская область, Октябрьский район, село Новоаксайский	0101000020E6100000DB183BE125A2454091F12895F0004840
28234	2	22	1226	51640	27400	\N	48.216315999999999	Волгоградская область, Октябрьский район, х. Нижнекумский, Центральная, 20, Нижнекумский сельский клуб	Россия, Волгоградская область, Октябрьский район, село Нижнекумский	0101000020E6100000B438639813BE4540FFCC203EB01B4840
28220	2	22	1226	27100	26732	\N	48.198625999999997	Волгоградская область, Октябрьский район, х. Молокановский, Тихий пер, 4, Молокановская начальная школа		0101000020E6100000139CFA40F29045405111A7936C194840
28225	2	22	1226	27316	26738	\N	47.947496219390104	Волгоградская область, Октябрьский район, с. Ковалевка, Продольная, 34, Ковалевская начальная школа	Россия, Волгоградская область, Октябрьский район, село Ковалевка	0101000020E6100000DB5031CEDFE64540A08B868C47F94740
28224	2	22	1226	27268	27200	\N	47.986800000000002	Волгоградская область, Октябрьский район, с. Каменка, Школьная, 5, Каменская начальная школа	Россия, Волгоградская область, Октябрьский район, село Каменка	0101000020E61000005ED5592DB0E74540AED85F764FFE4740
28221	2	22	1226	51657	27449	\N	48.227246999999998	Волгоградская область, Октябрьский район, х. Ильмень-Суворовский, Школьная, 13, Сельский Дом культуры	Россия, Волгоградская область, Октябрьский район, село Ильмень-Суворовский	0101000020E6100000C39B35785F9145409B8E006E161D4840
28215	2	22	1226	26841	27190	\N	48.186559000000003	Волгоградская область, Октябрьский район, с. Ивановка, Центральная, 45, Сельский Дом культуры		0101000020E61000002331410DDFD8454022E3512AE1174840
28218	2	22	1226	51372	26851	\N	47.977010567252897	Волгоградская область, Октябрьский район, х. Заливский, Юбилейная, 8, Сельский Дом культуры	Россия, Волгоградская область, Октябрьский район, село Заливский	0101000020E610000047567E198CBB4540876A4AB20EFD4740
28216	2	22	1226	26925	26589	\N	47.803106	Волгоградская область, Октябрьский район, с. Жутово-2-е, им. Ю.М. Носачева, 9, Жутовская СОШ		0101000020E610000059FAD005F5ED4540569C6A2DCCE64740
28223	2	22	1226	27197	26818	\N	47.951822999999997	Волгоградская область, Октябрьский район, с. Жутово-1-е, Центральная, 40, Жутовский сельский Дом культуры		0101000020E6100000B24CBF44BCE14540514A0856D5F94740
28214	2	22	1226	26823	26922	\N	48.198590000000003	Волгоградская область, Октябрьский район,с. Громославка, Административная, 4, Администрация сельского пос	Россия, Волгоградская область, Октябрьский район, село Громославка	0101000020E6100000B14D2A1A6BCF454005A8A9656B194840
28238	2	22	1226	51693	27528	\N	48.014068999999999	Волгоградская область, Октябрьский район, с. Гончаровка, Молодежная, 4, Гончаровский сельский клуб	Россия, Волгоградская область, Октябрьский район, село Гончаровское	0101000020E6100000E179A9D89809464097715303CD014840
28219	2	22	1226	51615	27349	\N	47.975239507131903	Волгоградская область, Октябрьский район, х. Водянский, Дружбы, 12, Водянская начальная школа	Россия, Волгоградская область, Октябрьский район, село Водянский	0101000020E6100000AB75E272BCB4454022E010AAD4FC4740
28239	2	22	1226	27952	27123	\N	48.019108000000003	Волгоградская область, Октябрьский район, с. Водино, Центральная, 10, Водинский ФАП		0101000020E61000007F17B6662BFD4540C68B852172024840
28222	2	22	1226	51649	27420	\N	48.262390000000003	Волгоградская область, Октябрьский район, х. Верхнерубежный, Центральная, 44, Верхнерубежная начальная школа	Россия, Волгоградская область, Октябрьский район, село Верхнерубежный	0101000020E61000006ADE718A8E9445401366DAFE95214840
28233	2	22	1226	51381	26902	\N	48.090854999999998	Волгоградская область, Октябрьский район,х.Верхнекумский, Виноградная, 16, Верхнекумская начальная школа	Россия, Волгоградская область, Октябрьский район, село Верхнекумский	0101000020E610000034BA83D899B84540CBD6FA22A10B4840
28213	2	22	1226	26757	27295	\N	48.136285000000001	Волгоградская область, Октябрьский район, с. Васильевка, Центральная, 6, сельский Дом культуры		0101000020E6100000A5F9635A9BE84540BAF770C971114840
28212	2	22	1226	51480	27099	\N	47.979906999999997	Волгоградская область, Октябрьский район, х. Антонов, Татаренко, 8, Сельский Дом культуры	Россия, Волгоградская область, Октябрьский район, село Антонов	0101000020E61000001842CEFBFFCE45408C0FB3976DFD4740
28211	2	22	1226	26676	26992	\N	47.957326000000002	Волгоградская область, Октябрьский район, с. Аксай, Октябрьская, 1а, Сельский Дом культуры		0101000020E6100000E4486760E4FB454025CE8AA889FA4740
28210	2	22	1226	51367	26814	\N	48.081317559443903	Волгоградская область, Октябрьский муниципальный район, Абганеровское сельское поселение, Гордиенко, 12, Сельский Дом культуры	Россия, Волгоградская область, Октябрьский район, село Абганерово	0101000020E61000005C1D007157174640BF49D3A0680A4840
28207	2	22	1775	26485	27195	\N	51.005477999999997	"Новониколаевский муниципальный район, п. Хоперский, МОУ ""Хоперская средняя общеобразовательная школа"", Советская, 20"	Россия, Волгоградская область, Новониколаевский район, село Хоперский	0101000020E6100000DD5F3DEE5B6545407A6CCB80B3804940
28191	2	22	1775	51606	27323	\N	51.034866999999998	Новониколаевский муниципальный район, х. Фоминский, сельский клуб, Центральная, 88	Россия, Волгоградская область, Новониколаевский район, село Фоминский	0101000020E610000038A4518193254540D55A988576844940
28205	2	22	1775	26388	26510	\N	50.852843999999997	Новониколаевский муниципальный район, п. Серп и Молот, дом культуры, Центральная, 1		0101000020E61000006BD784B4C63E45407F4B00FE296D4940
28190	2	22	1775	51386	26912	\N	51.023797999999999	Новониколаевский муниципальный район, х. Орловский, сельский Дом культуры, Центральная, 11	Россия, Волгоградская область, Новониколаевский район, село Орловский	0101000020E61000000839EFFFE3304540E8DA17D00B834940
28184	2	22	1775	25387	\N	\N	50.972065999999998	Волгоградская область, Новониколаевский район, р.п. Новониколаевский, районный Дом культуры		0101000020E610000064AC36FFAF2E4540DAC69FA86C7C4940
28189	2	22	1775	25387	26940	\N	50.991985076127499	Волгоградская область, Новониколаевский муниципальный район, Усадьба СХТ, 4Б	Россия, Волгоградская область, Новониколаевский район	0101000020E6100000F31C91EF52304540B08F4E5DF97E4940
28188	2	22	1775	25387	26399	\N	50.972065999999998	"Новониколаевский муниципальный район, р.п. Новониколаевский, МОУ ""Новониколаевская средняя общеобразовательная школа №2"", Первомайская, 1"		0101000020E610000064AC36FFAF2E4540DAC69FA86C7C4940
28186	2	22	1775	25387	26703	\N	50.972065999999998	"Новониколаевский муниципальный район, р.п. Новониколаевский, МОУ ""Новониколаевская средняя общеобразовательная школа "" 1 им. А.Н. Левченко"", Народная, 20"		0101000020E610000064AC36FFAF2E4540DAC69FA86C7C4940
28185	2	22	1775	25387	26703	\N	50.972065999999998	Новониколаевский муниципальный район, р.п. Новониколаевский, администрация Новониколаевского городского поселения, Народная, 128		0101000020E610000064AC36FFAF2E4540DAC69FA86C7C4940
28183	2	22	1775	25387	26703	\N	50.972065999999998	"Новониколаевский муниципальный район, р.п. Новониколаевский, контора Новониколаевского участка ОГУП ""Волгоградавтодор"" ДРСУ-4, Народная, 123А"		0101000020E610000064AC36FFAF2E4540DAC69FA86C7C4940
28187	2	22	1775	51538	\N	\N	50.975543360189199	"Волгоградская область, Новониколаевский муниципальный район, МОУ ""Новониколаевская средняя общеобразовательная школа № 3"""	Россия, Волгоградская область, Новониколаевский район, поселок городского типа Новониколаевский	0101000020E6100000429770E82D2E4540BE6BD097DE7C4940
28199	2	22	1775	51276	\N	\N	50.979245979088603	Новониколаевский муниципальный район, х. Новокардаильский, х. Новокардаильский	Россия, Волгоградская область, Новониколаевский район, село Новокардаильский	0101000020E610000005A6D3BA0D524540925ED4EE577D4940
28195	2	22	1775	51292	\N	\N	51.144584999999999	Новониколаевский муниципальный район, х. Николаевский, х. Николаевский	Россия, Волгоградская область, Новониколаевский район, село Николаевский	0101000020E610000097E315889E564540FF3EE3C281924940
15211	5	43	323	3254	70855	\N	51.405918	с. Чемал, Пчелкина, 89		0101000020E6100000693BA6EECA805540CA6DFB1EF5B34940
28202	2	22	1775	51680	27495	\N	50.881109000000002	Новониколаевский муниципальный район, х. Нижнекардаильский, сельский клуб, Центральная, 10А	Россия, Волгоградская область, Новониколаевский район, село Нижнекардаильский	0101000020E61000005EBC1FB75F5E45400B9B012EC8704940
28203	2	22	1775	26276	26987	\N	51.184060000000002	Новониколаевский муниципальный район, п. Мирный, Народная, 4		0101000020E61000001FBFB7E9CF6845403A4030478F974940
28204	2	22	1775	26350	26431	\N	51.111505999999999	"Новоколаевский муниципальный район, с. Купава, филиал Муниципального образовательного учреждения ""Мирная средняя общеобразовательная школа"" Купавская основная общеобразовательная школа, Школьная, 11"		0101000020E61000005FEFFE78AF74454065A71FD4458E4940
28201	2	22	1775	51700	27543	\N	50.838279	Новониколаевский муниципальный район, х. Куликовский, кафетерий, Советская, 22А	Россия, Волгоградская область, Новониколаевский район, село Куликовский	0101000020E6100000B9FC87F4DB45454038F6ECB94C6B4940
28200	2	22	1775	26180	\N	\N	51.043674000000003	Волгоградская область, Новониколаевский муниципальный район, п. Красноармейский, сельский Дом культуры, сельский Дом Культуры		0101000020E6100000029A081B9E744540BFD7101C97854940
28198	2	22	1775	26101	\N	\N	50.980345999999997	Новониколаевский муниципальный район, п. Комсомольский, сельский Дом культуры		0101000020E6100000CFBEF2203D3D4540D8614CFA7B7D4940
28208	2	22	1775	51631	27387	\N	50.887962000000002	Новониколаевский муниципальный район, х. Киквидзе, Центральная, 24		0101000020E610000019558671376245409E0B23BDA8714940
28206	2	22	1775	51582	\N	\N	50.838542806199598	Новониколаевский муниципальный район, х. Каменка, сельский Дом культуры, сельский Дом Культуры	Россия, Волгоградская область, Новониколаевский район, село Каменка	0101000020E61000006AFAEC80EB2E454016A58460556B4940
28197	2	22	1775	51365	\N	\N	51.106714504923097	Новониколаевский муниципальный район, х. Дуплятский, сельский Дом культуры	Россия, Волгоградская область, Новониколаевский район, село Дуплятский	0101000020E6100000499F56D11F2C45400F7F4DD6A88D4940
28196	2	22	1775	51535	\N	\N	51.039918999999998	Новониколаевский муниципальный район, х. Двойновский, сельский Дом культуры	Россия, Волгоградская область, Новониколаевский район, село Двойновский	0101000020E6100000DF6C73637A3A454098BED7101C854940
28193	2	22	1775	51395	\N	\N	50.898439295822797	Новониколаевский муниципальный район, х. Грачи	Россия, Волгоградская область, Новониколаевский район, село Грачи	0101000020E6100000054D4BAC8C244540B939950C00734940
28194	2	22	1775	51555	\N	\N	51.083770145146502	Новониколаевский муниципальный район, х. Верхнекардаильский, сельский Дом культуры	Россия, Волгоградская область, Новониколаевский район, село Верхнекардаильский	0101000020E610000038876BB5875545406631B1F9B88A4940
28192	2	22	1775	51388	26914	\N	50.947066374968998	Новониколаевский муниципальный район, х. Алексиковский, сельский Дом культуры, Центральная, 22	Россия, Волгоградская область, Новониколаевский район, село Алексиковский	0101000020E61000005C1FD61BB52A4540A7936C7539794940
28155	2	22	1723	51577	\N	\N	50.517780999999999	Волгоградская область, Новоаннинский муниципальный район, Березовское сельское поселение, х. Ярыженский	Россия, Волгоградская область, Новоаннинский район, село Ярыженский	0101000020E610000015E126A3CA3C4540BEBED6A546424940
28182	2	22	1723	51324	\N	\N	50.687650002307798	Волгоградская область, Новоаннинский муниципальный район, Черкесовское сельское поселение, х. Черкесовский	Россия, Волгоградская область, Новоаннинский район, село Черкесовский	0101000020E61000004E2844C021484540158C4AEA04584940
28161	2	22	1723	51482	\N	\N	50.825752000000001	Волгоградская область, Новоаннинский муниципальный район, Галушкинское сельское поселение, х. Челышевский	Россия, Волгоградская область, Новоаннинский район, село Челышевский	0101000020E6100000015130630A684540A54DD53DB2694940
28179	2	22	1723	25180	\N	\N	50.579796000000002	Волгоградская область, Новоаннинский муниципальный район, Филоновское сельское поселение, ст. Филоновская	Россия, Волгоградская область, Новоаннинский район, село Филоновская	0101000020E610000023861DC6A45D4540022D5DC1364A4940
28177	2	22	1723	51583	\N	\N	50.470672579685001	Волгоградская область, Новоаннинский муниципальный район, Тростянское сельское поселение, х. Тростянский	Россия, Волгоградская область, Новоаннинский район, село Тростянский	0101000020E610000036AD1402B99C45401B0E4B033F3C4940
28170	2	22	1723	51364	\N	\N	50.362329000000003	Волгоградская область, Новоаннинский муниципальный район, Панфиловское сельское поселение, х. Троецкий	Россия, Волгоградская область, Новоаннинский район, село Троецкий	0101000020E6100000DEC66647AA6F45403AB2F2CB602E4940
27948	2	22	1723	51574	\N	\N	50.465032561020998	х.Страховский, здание Страховского сельского клуба	Россия, Волгоградская область, Новоаннинский район, село Страховский	0101000020E6100000AF777FBC57834540C7478B33863B4940
28173	2	22	1723	24922	\N	\N	50.494602	Волгоградская область, Новоаннинский муниципальный район, Староаннинское сельское поселение, ст. Староаннинская	Россия, Волгоградская область, Новоаннинский район, село Староаннинская	0101000020E610000006668522DD454540A2444B1E4F3F4940
28103	2	22	1657	51314	\N	\N	50.398158732938199	х. Авраамовский, школа	Россия, Волгоградская область, Нехаевский район, село Авраамовский	0101000020E6100000C0B0FCF9B6CE4440D5CDC5DFF6324940
28181	2	22	1723	51396	\N	\N	50.6326726017871	Волгоградская область, Новоаннинский муниципальный район, Филоновское сельское поселение, х. Саломатин	Россия, Волгоградская область, Новоаннинский район, село Соломатин	0101000020E6100000CEA5B8AAEC6B4540F607CA6DFB504940
28158	2	22	1723	51354	\N	\N	50.280260219353799	Волгоградская область, Новоаннинский муниципальный район, Бочаровское сельское поселение, х. Сатаровский	Россия, Волгоградская область, Новоаннинский район, село Сатаровский	0101000020E61000005E656D533C4C45404030478FDF234940
28180	2	22	1723	51286	\N	\N	50.613205000000001	Волгоградская область, Новоаннинский муниципальный район, Филоновское сельское поселение, х. Рожновский	Россия, Волгоградская область, Новоаннинский район, село Рожновский	0101000020E610000081785DBF60694540315F5E807D4E4940
28174	2	22	1723	51487	\N	\N	50.481777842746503	Волгоградская область, Новоаннинский муниципальный район, Староаннинское сельское поселение, х. Родниковский	Россия, Волгоградская область, Новоаннинский район, село Родниковский	0101000020E61000005EDBDB2DC94B454055F7C8E6AA3D4940
28166	2	22	1723	51401	\N	\N	50.6537322294826	Волгоградская область, Новоаннинский муниципальный район, Краснокоротковское сельское поселение, х. Рог-Измайловский	Россия, Волгоградская область, Новоаннинский район, село Рог-Измайловский	0101000020E61000008944A165DD5F4540A12C7C7DAD534940
28178	2	22	1723	51283	\N	\N	50.602933	Волгоградская область, Новоаннинский муниципальный район, Тростянское сельское поселение, х. Попов	Россия, Волгоградская область, Новоаннинский район, село Поповский	0101000020E610000076711B0DE0354540EF5696E82C4D4940
28156	2	22	1723	51283	\N	\N	50.602933	Волгоградская область, Новоаннинский муниципальный район, Березовское сельское поселение, х.Поповский	Россия, Волгоградская область, Новоаннинский район, село Поповский	0101000020E610000076711B0DE0354540EF5696E82C4D4940
28168	2	22	1723	51586	\N	\N	50.373257000000002	Волгоградская область, Новоаннинский муниципальный район, Новокиевское сельское поселение, х. Полтавский	Россия, Волгоградская область, Новоаннинский район, село Полтавский	0101000020E6100000C89A9141EE8845406500A8E2C62F4940
28172	2	22	1723	24905	\N	\N	50.730910000000002	Волгоградская область, Новоаннинский муниципальный район, Полевое сельское поселение, п. Полевой	Россия, Волгоградская область, Новоаннинский район, село Полевой	0101000020E6100000F568AA27F3514540E12879758E5D4940
28169	2	22	1723	24748	\N	\N	50.405968999999999	Волгоградская область, Новоаннинский муниципальный район, Панфиловское сельское поселение, п. Панфилово	Россия, Волгоградская область, Новоаннинский район, село Панфилово	0101000020E610000076525F96767045404C18CDCAF6334940
28171	2	22	1723	24831	\N	\N	50.371166000000002	Волгоградская область, Новоаннинский муниципальный район, Панфиловское сельское поселение, п. Новосельский	Россия, Волгоградская область, Новоаннинский район, село Новосельский	0101000020E6100000C4060B27697E45408EB1135E822F4940
28167	2	22	1723	51514	\N	\N	50.423800616849398	Волгоградская область, Новоаннинский муниципальный район, Новокиевское сельское поселение, х. Новокиевский	Россия, Волгоградская область, Новоаннинский район, село Новокиевка	0101000020E6100000774A07EBFF9045408C81751C3F364940
28142	2	22	1723	51269	27268	\N	50.521088747786898	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, п. Казачий, 85	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E6100000F94B8BFA2457454016A75A0BB3424940
28150	2	22	1723	51269	27454	\N	50.524974	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Советская, 41	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E6100000AA7D3A1E335645400AA0185932434940
28144	2	22	1723	51269	27364	\N	50.525077103757297	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Рабочая, 239	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E6100000628731E9EF554540DF701FB935434940
28141	2	22	1723	51269	26426	\N	50.526116670981601	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Подтелкова, 67	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E61000005FB7088CF5554540506F46CD57434940
28140	2	22	1723	51269	26426	\N	50.527435759731702	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Подтелкова, 41 а	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E610000014CD0358E4554540D55DD90583434940
28139	2	22	1723	51269	27615	\N	50.525356660693802	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Пионерская, 38	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E6100000BAA29410AC564540C2DCEEE53E434940
28148	2	22	1723	51269	27162	\N	50.524645368825503	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Народная, 11	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E610000070B20DDC8156454045813E9127434940
28145	2	22	1723	51269	27377	\N	50.525903800949401	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Ленина, 44	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E61000007D073F7100574540F46A80D250434940
28149	2	22	1723	51269	27318	\N	50.524974	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Калинина, 106	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E6100000AA7D3A1E335645400AA0185932434940
28143	2	22	1723	51269	27327	\N	50.525301946317398	Волгоградская область, Новоаннинский муниципальный район, городское поселение г. Новоаннинский, ул. Киквидзе, 95	Россия, Волгоградская область, Новоаннинский район, Новоаннинский	0101000020E61000004C6E14596B564540FF428F183D434940
28164	2	22	1723	51584	\N	\N	50.493484000000002	Волгоградская область, Новоаннинский муниципальный район, Деминское сельское поселение, х.Мартыновский	Россия, Волгоградская область, Новоаннинский район, село Мартыновский	0101000020E61000004640852348254540B58CD47B2A3F4940
28159	2	22	1723	51402	\N	\N	50.435572637007503	Волгоградская область, Новоаннинский муниципальный район, Бочаровское сельское поселение, х. Кузнецовский	Россия, Волгоградская область, Новоаннинский район, село Кузнецовский	0101000020E610000015E0BBCD1B594540A30227DBC0374940
28165	2	22	1723	51352	\N	\N	50.615854629344199	Волгоградская область, Новоаннинский муниципальный район, Краснокоротковское сельское поселение, х. Краснокоротковский	Россия, Волгоградская область, Новоаннинский район, село Краснокоротковский	0101000020E6100000336FD575A8544540FF092E56D44E4940
28152	2	22	1723	51345	\N	\N	50.424317454603397	Волгоградская область, Новоаннинский муниципальный район, Амовское сельское поселение, пх. Красногорский	Россия, Волгоградская область, Новоаннинский район, село Красногорский	0101000020E6100000A7ECF483BA6845408411FB0450364940
28176	2	22	1723	51387	\N	\N	50.469388000000002	Волгоградская область, Новоаннинский муниципальный район, Староаннинское сельское поселение, х. Дурновский	Россия, Волгоградская область, Новоаннинский район, село Дурновский	0101000020E6100000C9E9EBF99A3345404391EEE7143C4940
28162	2	22	1723	51358	\N	\N	50.572393817289402	Волгоградская область, Новоаннинский муниципальный район, Деминское сельское поселение, х. Деминский	Россия, Волгоградская область, Новоаннинский район, село Деминский	0101000020E610000022FC8BA0312545409C36E33444494940
28160	2	22	1723	51277	\N	\N	50.747790752708099	Волгоградская область, Новоаннинский муниципальный район, Галушкинское сельское поселение, х. Галушкинский	Россия, Волгоградская область, Новоаннинский район, село Галушкинский	0101000020E6100000E8A38CB8006C45401F9F909DB75F4940
28157	2	22	1723	51481	\N	\N	50.383436000000003	Волгоградская область, Новоаннинский муниципальный район, Бочаровское сельское поселение, х. Бочаровский	Россия, Волгоградская область, Новоаннинский район, село Бочаровский	0101000020E6100000302E55698B534540F60D4C6E14314940
28175	2	22	1723	51405	\N	\N	50.467810659410603	Волгоградская область, Новоаннинский муниципальный район, Староаннинское сельское поселение, х. Борисовский	Россия, Волгоградская область, Новоаннинский район, село Борисовский	0101000020E610000001DC2C5E2C404540C2DA183BE13B4940
28163	2	22	1723	51409	\N	\N	50.597836450745298	Волгоградская область, Новоаннинский муниципальный район, Деминское сельское поселение, х. Большой-Головский	Россия, Волгоградская область, Новоаннинский район, село Большой Головский	0101000020E6100000E8DB82A5BA1845408C2FDAE3854C4940
28154	2	22	1723	24001	\N	\N	50.547800000000002	Волгоградская область, Новоаннинский муниципальный район, Березовское сельское поселение, 2-я Березовка	Россия, Волгоградская область, Новоаннинский район, село Березовка 2-я	0101000020E610000077DA1A118C474540D95F764F1E464940
28153	2	22	1723	23928	\N	\N	50.548034000000001	Волгоградская область, Новоаннинский муниципальный район, Березовское сельское поселение, 1-я Березовка	Россия, Волгоградская область, Новоаннинский район, село Березовка 1-я	0101000020E61000005C9198A0864F45404C8C65FA25464940
28151	2	22	1723	23833	\N	\N	50.422868000000001	Волгоградская область, Новоаннинский муниципальный район, Амовское сельское поселение, п. АМО	Россия, Волгоградская область, Новоаннинский район, село АМО	0101000020E61000003CF54883DB7645403143E38920364940
28123	2	22	1688	22580	\N	\N	50.157263	"х.Торгунский, здание МОУ ""Торгунская НОШ"""	Россия, Волгоградская область, Николаевский район, село Торгунский	0101000020E61000003752B648DA33474078EFA83121144940
28138	2	22	1688	23253	\N	\N	49.943119000000003	п.Степновский, Степновский СДК		0101000020E6100000158BDF1456EA46403D9E961FB8F84840
28135	2	22	1688	23103	\N	\N	49.959482000000001	с.Солодушино, Солодушинский СДК		0101000020E6100000B900344A97B64640E38C614ED0FA4840
28137	2	22	1688	23189	\N	\N	50.021160999999999	п.Рулевой, Рулевской СК		0101000020E610000093C3279D48EE4640AF795567B5024940
28132	2	22	1688	46832	\N	\N	50.202188999999997	с.Политотдельское, здание администрации Политотдельского сельского поселения		0101000020E6100000FCC22B499EDB4640334E4354E1194940
28128	2	22	1688	46732	\N	\N	50.063654	"п.Пионер, здание МОУ ""Пионерская СОШ"""	Россия, Волгоградская область, Николаевский район, село Пионер	0101000020E6100000F3AD0FEB8DD646403A2174D025084940
28131	2	22	1688	51355	\N	\N	49.820348109829503	х.Новый Быт, здание администрации Новобытовского сельского поселения	Россия, Волгоградская область, Николаевский район, село Новый Быт	0101000020E61000009D103AE812F4464065ABCB2901E94840
28119	2	22	1688	22351	26810	\N	50.027973000000003	г.Николаевск, Чайковского, 3		0101000020E610000082AB3C81B0BB4640E415889E94034940
28118	2	22	1688	22351	27250	\N	50.027973000000003	г.Николаевск, Свердлова, 30	Россия, Волгоградская область, Николаевский район, Николаевск	0101000020E610000082AB3C81B0BB4640E415889E94034940
28121	2	22	1688	22351	26886	\N	50.027973000000003	г.Николаевск, Республиканская, 36		0101000020E610000082AB3C81B0BB4640E415889E94034940
28120	2	22	1688	22351	26579	\N	50.027973000000003	г.Николаевск, Октябрьская, 4	Россия, Волгоградская область, Николаевский район, Николаевск	0101000020E610000082AB3C81B0BB4640E415889E94034940
28122	2	22	1688	22351	26995	\N	50.027973000000003	г.Николаевск, Калинина, 28		0101000020E610000082AB3C81B0BB4640E415889E94034940
28129	2	22	1688	46765	\N	\N	50.042253000000002	с.Ленинское, Ленинский СДК	Россия, Волгоградская область, Николаевский район, село Ленинское	0101000020E6100000C5591135D1C546403694DA8B68054940
28127	2	22	1688	22761	\N	\N	50.120296000000003	"с.Левчуновка, здание МОУ ""Левчуновская СОШ"""		0101000020E6100000645A9BC6F6DA464079EBFCDB650F4940
28134	2	22	1688	23044	\N	\N	49.907702	"п.Кумысолечебница, здание конторы ОАО ""Новая Жизнь"""		0101000020E6100000E272BC02D1FF4640C44142942FF44840
28124	2	22	1688	22644	\N	\N	50.027086110028797	"х.Красный Мелиоратор, здание МОУ ""Вербенская СОШ"""	Россия, Волгоградская область, Николаевский район, село Красный Мелиоратор	0101000020E610000058E20165530C4740F816D68D77034940
28130	2	22	1688	46781	\N	\N	49.959342999999997	"с.Комсомолец, здание МОУ ""Комсомольская СОШ"""		0101000020E6100000A69D9ACB0DD24640C1525DC0CBFA4840
28125	2	22	1688	22663	\N	\N	50.259121	с.Бережновка, Бережновский СДК		0101000020E610000091F0BDBF41F34640795A7EE02A214940
28108	2	22	1657	21901	\N	\N	50.285715927973499	х. Хорошенский, здание СДК	Россия, Волгоградская область, Нехаевский район, село Хорошенский	0101000020E6100000BC22F8DF4ADE4440D3F8855792244940
28107	2	22	1657	51599	\N	\N	50.227435904985697	ст. Упорниковская, здание ЦКС	Россия, Волгоградская область, Нехаевский район, село Упорниковский	0101000020E6100000B9E177D32DED44406EF7729F1C1D4940
28097	2	22	1657	51601	\N	\N	50.530462983794699	х. Тушкановский, школа	Россия, Волгоградская область, Нехаевский район, село Тушкановский	0101000020E6100000D8800871E5E84440785E2A36E6434940
28109	2	22	1657	21950	\N	\N	50.359501000000002	ст. Тишанская, школа	Россия, Волгоградская область, Нехаевский район, село Тишанская	0101000020E61000008EEBDFF599FF44408DF0F620042E4940
28117	2	22	1657	22301	\N	\N	50.196779999999997	с. Солонка, администрация СП		0101000020E610000019575C1C95BB4440E140481630194940
28112	2	22	1657	51318	\N	\N	50.386744	х. Соколовский, здание ФАП	Россия, Волгоградская область, Нехаевский район, село Соколовский	0101000020E6100000912749D74CEC44404DF6CFD380314940
28100	2	22	1657	51431	\N	\N	50.378898	с. Успенка, администрация СП		0101000020E610000080D4264EEEE144408942CBBA7F304940
28115	2	22	1657	51467	\N	\N	50.131867585626502	п. Роднички, школа	Россия, Волгоградская область, Нехаевский район, село Роднички	0101000020E6100000A8380EBC5AD64440C8B1F50CE1104940
28099	2	22	1657	21466	\N	\N	50.5281497876082	х. Нижнедолговский, здание СДК	Россия, Волгоградская область, Нехаевский район, село Нижнедолговский	0101000020E61000003DB9A64066D74440F2B0506B9A434940
28092	2	22	1657	21130	26622	\N	50.411588999999999	Ст. Нехаевская, ул. Ленина, 40		0101000020E6100000677E350708E044405932C7F2AE344940
28094	2	22	1657	21130	26643	\N	50.411588999999999	Ст. Нехаевская, Коммнунистическая		0101000020E6100000677E350708E044405932C7F2AE344940
28093	2	22	1657	51526	\N	\N	50.411588999999999	Ст. Нехаевская, Лесхоз	Россия, Волгоградская область, Нехаевский район, поселок городского типа Нехаевская	0101000020E6100000677E350708E044405932C7F2AE344940
28111	2	22	1657	22047	\N	\N	50.363695174758199	х. Мазинский, здание СДК	Россия, Волгоградская область, Нехаевский район, село Мазинский	0101000020E610000067994528B6F24440FF5BC98E8D2E4940
28098	2	22	1657	21409	\N	\N	50.575048000000002	ст. Луковская, администрация СП		0101000020E6100000C5E57805A2ED4440ABD0402C9B494940
28104	2	22	1657	51301	\N	\N	50.400220468331497	х. Лобачевский, школа	Россия, Волгоградская область, Нехаевский район	0101000020E6100000B6F468AA27D74440419AB1683A334940
28116	2	22	1657	22280	\N	\N	50.119388999999998	х. Кулички, администрация СП	Россия, Волгоградская область, Нехаевский район, село Кулички	0101000020E61000005166834C32E2444046408523480F4940
28113	2	22	1657	51316	\N	\N	50.125931999999999	х. Кругловска, здание ЦКД	Россия, Волгоградская область, Нехаевский район, село Кругловка	0101000020E6100000FCFF3861C2CA44408BC22E8A1E104940
28101	2	22	1657	46163	\N	\N	50.496572999999998	с. Краснополье, школа	Россия, Волгоградская область, Нехаевский район, село Краснополье	0101000020E61000004C33DDEBA4BA4440CE893DB48F3F4940
28096	2	22	1657	51605	\N	\N	50.491205698740401	ст. Захоперская, школа	Россия, Волгоградская область, Нехаевский район, село Захоперский	0101000020E6100000D1E638B709F54440ABCC94D6DF3E4940
28105	2	22	1657	46267	\N	\N	50.244387000000003	п. Динамо, школа		0101000020E6100000A435069D10D44440A648BE12481F4940
28106	2	22	1657	51532	\N	\N	50.195412655334998	х. Денисовский, здание ЦКС	Россия, Волгоградская область, Нехаевский район, село Денисовский	0101000020E6100000C6DD205A2BF644404C1B0E4B03194940
28102	2	22	1657	21579	\N	\N	50.479678430130903	х. Верхнереченский, администрация СП	Россия, Волгоградская область, Нехаевский район, село Верхнереченский	0101000020E61000000247020D36CD44402B4EB516663D4940
28110	2	22	1657	21981	\N	\N	50.342643000000002	х. Артановский, здание ФАП	Россия, Волгоградская область, Нехаевский район, село Артановский	0101000020E6100000FF756EDA8CF74440079ACFB9DB2B4940
27932	2	22	1024	13098	27072	\N	50.029761000000001	с.Госселекстанция, Почтовая, 11		0101000020E6100000A8E15B58379046401FD95C35CF034940
28079	2	22	1310	20429	26422	\N	50.040528999999999	хутор Черемухов, Советская, 14, Черемуховский сельский ДК	Россия, Волгоградская область, Михайловский район, село Черемухов	0101000020E6100000A758350873C5454011C5E40D30054940
28090	2	22	1310	51710	27611	\N	50.235815932617903	хутор Троицкий, Советская, 32, Центр детского творчества	Россия, Волгоградская область, Михайловский район, село Троицкий	0101000020E610000033315D88D5854540D0EFFB372F1E4940
28078	2	22	1310	20414	26762	\N	49.995764000000001	"хутор Сухов-2, Мира, 16, д/с ""Солнышко"""	Россия, Волгоградская область, Михайловский район, село Сухов 2-й	0101000020E61000000D71AC8BDBBC45405F44DB3175FF4840
28062	2	22	1310	19496	26681	\N	49.915644	хутор Сухов-1, Садовая, 4, Суховский-1 сельский клуб	Россия, Волгоградская область, Михайловский район, село Сухов 1-й	0101000020E6100000BDFBE3BD6AB54540AA6395D233F54840
28081	2	22	1310	20544	26428	\N	50.143675999999999	хутор Субботин, Юрия Прищепного, 121, Субботинский сельский клуб	Россия, Волгоградская область, Михайловский район, село Субботин	0101000020E6100000DF15C1FF56CE45402C9CA4F963124940
28088	2	22	1310	13835	26380	\N	50.303742999999997	хутор Страховский, Школьная, 1, Страховская школа	Россия, Волгоградская область, Михайловский район, село Страховский	0101000020E6100000F7AB00DF6D7E4540C8B1F50CE1264940
28061	2	22	1310	45373	26585	\N	49.976633	село Староселье, Центральная, 24, Старосельская школа	Россия, Волгоградская область, Михайловский район, село Староселье	0101000020E610000009E066F1629D4540E198654F02FD4840
28085	2	22	1310	45801	26954	\N	50.120306999999997	село Сидоры, Ленина, 38, Сидорская школа		0101000020E6100000153AAFB14BAA45406C3D4338660F4940
28084	2	22	1310	45801	26954	\N	50.120306999999997	село Сидоры, Ленина, 5-А, Сидорский сельский ДК		0101000020E6100000153AAFB14BAA45406C3D4338660F4940
28082	2	22	1310	20629	26854	\N	50.260536999999999	хутор Сенной, Ленина, 36, Сенновский сельский ДК		0101000020E61000000FD07D39B3CF4540F032C34659214940
28070	2	22	1310	19919	26639	\N	50.043723	хутор Сеничкин, Центральная, 27-А, Сеничкинский сельский клуб		0101000020E6100000B471C45A7C724540A08A1BB798054940
28075	2	22	1310	20200	26961	\N	50.502324999999999	хутор Секачи, Первомайский, 4, Секачевский сельский ДК		0101000020E610000005F86EF3C6CF45404A7B832F4C404940
28091	2	22	1310	21103	27226	\N	50.170755	хутор Рогожин, Первомайский, 2, Рогожинская школа	Россия, Волгоградская область, Михайловский район, село Рогожин	0101000020E6100000DC9C4A06808045407250C24CDB154940
28087	2	22	1310	20864	27229	\N	50.262697000000003	поселок Реконструкция, Парковый, 8, Реконструкторский сельский ДК	Россия, Волгоградская область, Михайловский район, село Реконструкция	0101000020E6100000124A5F0839894540F0E0270EA0214940
28080	2	22	1310	20524	26383	\N	50.205745999999998	хутор Раздоры, Мира, 3, Раздорский сельский ДК		0101000020E61000006C26DF6C73D3454033A48AE2551A4940
28072	2	22	1310	20024	26876	\N	50.405923000000001	хутор Плотников-2, Школьная, 3, Плотниковская школа		0101000020E6100000F7E6374C34C84540DCD8EC48F5334940
28071	2	22	1310	19936	27161	\N	50.045481000000002	хутор Отруба, Украинская, 10, Отрубской сельский клуб		0101000020E6100000CFBEF2203D8F454071CB4752D2054940
28076	2	22	1310	45661	26423	\N	50.016074000000003	поселок Отрадное, Чекунова, 22, Отрадненская школа		0101000020E6100000E52A16BF2996454070287CB60E024940
28083	2	22	1310	45789	27044	\N	50.222445	хутор Орлы, Лесная, 1, Орловский сельский клуб	Россия, Волгоградская область, Михайловский район, село Орлы	0101000020E61000006346787B10DC45405114E813791C4940
28064	2	22	1310	19606	26419	\N	50.192050999999999	хутор Моховский, Маршала Жукова, 44, Моховский сельский клуб		0101000020E610000059880E8123B5454001158E2095184940
28073	2	22	1310	20084	27244	\N	50.361978000000001	хутор Мишин, Заречная, 4, Мишинский сельский клуб		0101000020E61000000395F1EF33C445408DEF8B4B552E4940
28618	2	22	1310	51439	27031	\N	50.070811256143401	Волгоградская область, муниципальное образование городской округ - город Михайловка, Свободы, 142-А, МОУ СОШ №9		0101000020E6100000D2AB014A439F45403999B85510094940
28068	2	22	1310	51643	27402	\N	50.226537	хутор Крутинский, Центральная, 22, Крутинский сельский клуб	Россия, Волгоградская область, Михайловский район, село Крутинский	0101000020E61000000EBC5AEECC6E4540BF2A172AFF1C4940
28069	2	22	1310	19863	26596	\N	50.090691	хутор Катасонов, Советская, 51, Катасоновский сельский ДК		0101000020E6100000DEC9A7C7B680454051853FC39B0B4940
28067	2	22	1310	19762	27144	\N	50.160259000000003	хутор Карагичевский, улица Центральная, 1, Карагичевский сельский ДК	Россия, Волгоградская область, Михайловский район, село Карагичевский	0101000020E61000002AA8A8FA95724540E1F1ED5D83144940
28066	2	22	1310	19694	26963	\N	50.231003000000001	хутор Ильменский-2, Центральная, 15/1, Ильменский-2 сельский клуб	Россия, Волгоградская область, Михайловский район, село Ильменский 2-й	0101000020E6100000FE0E45813EC7454092239D81911D4940
28058	2	22	1310	19269	26939	\N	49.959702	хутор Ильменский-1, Центральная, 31, Ильменский сельский клуб		0101000020E6100000D7BFEB33678F4540F1F3DF83D7FA4840
28065	2	22	1310	19660	26759	\N	50.18336	станица Етеревская, Красная, 21-А, Етеревская казачья школа		0101000020E6100000960854FF20C6454081B2295778174940
28086	2	22	1310	20842	27150	\N	50.156525000000002	хутор Большой Орешкин, Ольховая, 1, Большеорешкинский сельский клуб		0101000020E6100000567DAEB662B14540D200DE0209144940
28366	2	22	1310	51323	\N	\N	50.224587384253802	хутор Большой, Большовский дом культуры	Россия, Волгоградская область, Михайловский район, село Большой	0101000020E6100000396403E962B94540AA0D4E44BF1C4940
28089	2	22	1310	20999	27034	\N	50.230207999999998	хутор Большемедведевский, Зеленая, 4, Большемедведевский сельский клуб		0101000020E6100000BA2EFCE07C94454087A3AB74771D4940
28060	2	22	1310	51618	27446	\N	49.9058649265912	хутор Безымянка, Центральная, 1, Администрация поселения	Россия, Волгоградская область, Михайловский район, село Безымянка	0101000020E610000054ABAFAE0AA24540A7CB6262F3F34840
28059	2	22	1310	51618	27352	\N	49.9058649265912	хутор Безымянка, Советская, 130-А, Безымянский сельский ДК	Россия, Волгоградская область, Михайловский район, село Безымянка	0101000020E61000007C2766BD18A24540A7CB6262F3F34840
28056	2	22	1310	19174	27130	\N	49.895738000000001	станица Арчединская, улица Ленина, 29, Арчединская школа		0101000020E6100000F99FFCDD3B8E454069E4F38AA7F24840
28044	2	22	1151	18539	26929	\N	48.666384000000001	с. Царев, Бегичева, 14	Россия, Волгоградская область, Ленинский район, село Царев	0101000020E610000083DF8618AFAF4640F14927124C554840
28053	2	22	1151	19009	27302	\N	49.053857000000001	п. Тракторострой, Ленина, 21		0101000020E61000002DEC6987BFC8464091D442C9E4864840
28051	2	22	1151	51295	26581	\N	48.929234999999998	п. Степной, Добровольского, 29	Россия, Волгоградская область, Ленинский район, село Степной	0101000020E61000001633C2DB83CC464037A6272CF1764840
28048	2	22	1151	51541	27202	\N	48.505611000000002	П. Ст. Разина, Центральная, 32	Россия, Волгоградская область, Ленинский район, село Степана Разина	0101000020E610000058AEB7CD548A4640BABF7ADCB7404840
28045	2	22	1151	49382	26934	\N	48.677056999999998	с.Солодовка, Павших борцов, 1-А		0101000020E6100000BC5D2F4D11B246409143C4CDA9564840
28054	2	22	1151	49530	27027	\N	49.105846	п. Рассвет, Школьная, 8		0101000020E6100000A8C4758C2BBC4640CA349A5C8C8D4840
28293	2	22	1151	30424	26777	\N	48.970326	п. Путь Ильича, пер. Клубный, 1		0101000020E610000044FAEDEBC0C74640B03A72A4337C4840
28052	2	22	1151	30424	27026	\N	48.969478422888997	п. Путь Ильича, Барышнева, 46	Россия, Волгоградская область, Ленинский район, село Путь Ильича	0101000020E61000004146408523C846408318E8DA177C4840
28047	2	22	1151	49425	26566	\N	48.482188000000001	с. Покровка, Речная, 27		0101000020E61000001EA8531EDD84464007431D56B83D4840
28281	2	22	1151	49472	27149	\N	48.675251717444603	п. Новостройка, Школьная, 3	Россия, Волгоградская область, Ленинский район, село Новостройка	0101000020E6100000CBBA7F2C44A94640804754A86E564840
28055	2	22	1151	19113	26936	\N	49.234400000000001	п. Маяк Октября, Ленина, 14	Россия, Волгоградская область, Ленинский район, село Маяк Октября	0101000020E610000018265305A3D246405917B7D1009E4840
28042	2	22	1151	18454	27198	\N	48.683089000000002	с. Маляевка, Советская, 57	Россия, Волгоградская область, Ленинский район, село Маляевка	0101000020E61000002E55698B6BA44640F1A0D9756F574840
28049	2	22	1151	18786	27122	\N	48.502094999999997	п. Лещев, Павших Борцов, 15	Россия, Волгоградская область, Ленинский район, село Лещев	0101000020E6100000B4C70BE9F0784640183E22A644404840
28036	2	22	1151	10821	26820	\N	48.703035999999997	г.Ленинск, Ястребова, 89 А		0101000020E6100000A9C1340C1F9B464090F46915FD594840
28035	2	22	1151	10821	26554	\N	48.703035999999997	г. Ленинск, Чернышевского, 7		0101000020E6100000A9C1340C1F9B464090F46915FD594840
28038	2	22	1151	10821	26885	\N	48.703025151873298	г. Ленинск, ул. Ленина, 204 А	Россия, Волгоградская область, Ленинский район, Ленинск	0101000020E6100000B70BCD751A9B46409CA223B9FC594840
14703	2	22	1151	10821	26885	\N	48.706824261178603	г. Ленинск, Ленина, 241	Россия, Волгоградская область, Ленинский район, Ленинск	0101000020E6100000B742588D2598464092037635795A4840
28039	2	22	1151	10821	26925	\N	48.702584862610102	Волгоградская область, Ленинский муниципальный район, городское поселение г. Ленинск, Битюцкого, 30 А	Россия, Волгоградская область, Ленинский район, Ленинск	0101000020E610000036AFEAAC169A464080D4264EEE594840
28034	2	22	1151	10821	27351	\N	48.700766853015701	Волгоградская область, Ленинский муниципальный район, городское поселение г. Ленинск, Ленина, 51	Россия, Волгоградская область, Ленинский район, Ленинск	0101000020E61000002028B7ED7B9A4640DA8EA9BBB2594840
28041	2	22	1151	49342	26741	\N	48.875881999999997	п. Коммунар, Школьная, 12		0101000020E610000078F2E9B12DA74640D993C0E61C704840
28046	2	22	1151	18641	27301	\N	48.655839	с. Колобовка, Гагарина, 4		0101000020E6100000A54BFF9254BA46407E384888F2534840
28050	2	22	1151	18882	26828	\N	48.456699	с. Каршевитое, Заречная, 7		0101000020E6100000F3E2C4573BA84640D68EE21C753A4840
28043	2	22	1151	49361	27199	\N	48.704884999999997	с.Заплавное, Совхозная, 21		0101000020E61000009C340D8AE68146407138F3AB395A4840
28040	2	22	1151	18338	27060	\N	48.713524	с. Бахтияровка, Карла Маркса, 33		0101000020E6100000D464C6DB4A9146409F7422C1545B4840
28307	2	22	1624	51407	\N	\N	49.853090999999999	Волгоградская область, Кумылженский муниципальный район, Шакинское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Шакин	0101000020E6100000CE50DCF12619454087C1FC1532ED4840
28301	2	22	1624	51581	\N	\N	50.069362735599299	Волгоградская область, Кумылженский муниципальный район, Суляевское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Суляевский	0101000020E61000003F1BB96E4A4F4540B74604E3E0084940
28304	2	22	1624	51458	\N	\N	49.856859999999998	Волгоградская область, Кумылженский муниципальный район, Слащевское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Слащевская	0101000020E6100000CD3CB9A6402A454012A0A696ADED4840
28306	2	22	1624	51406	\N	\N	49.974558999999999	Волгоградская область, Кумылженский муниципальный район, Поповское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Попов	0101000020E610000067B796C9700C4540E0826C59BEFC4840
28077	2	22	1624	20334	27005	\N	49.886306632916899	хутор Поддубный, Центральная, 25, Поддубинский сельский клуб	Россия, Волгоградская область, Кумылженский район, село Поддубный	0101000020E610000053944BE317444540A29BFD8172F14840
28300	2	22	1624	51554	\N	\N	49.879753137380803	Волгоградская область, Кумылженский муниципальный район, Кумылженское сельское поселение	Россия, Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	0101000020E61000006F9EEA909B4B454069C70DBF9BF04840
28303	2	22	1624	51531	\N	\N	49.703363636773297	Волгоградская область, Кумылженский муниципальный район, Краснянское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Краснянский	0101000020E6100000441669E21D5245408597E0D407DA4840
28302	2	22	1624	51578	\N	\N	49.813391554776203	Волгоградская область, Кумылженский муниципальный район, Глазуновское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Глазуновская	0101000020E610000072A774B0FE6B4540FD69A33A1DE84840
28305	2	22	1624	51376	\N	\N	49.678438	Волгоградская область, Кумылженский муниципальный район, Букановское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Букановская	0101000020E61000007786A92D752845408C2E6F0ED7D64840
28309	2	22	1624	51454	\N	\N	49.9138183084698	Волгоградская область, Кумылженский муниципальный район, Белогорское сельское поселение	Россия, Волгоградская область, Кумылженский район, село Белогорский	0101000020E610000014B35E0CE5F64440813FFCFCF7F44840
28017	2	22	1459	51558	\N	\N	50.553534999999997	с.Тарасово и с.Дорошево, сельский клуб	Россия, Волгоградская область, Котовский район, село Тарасово	0101000020E6100000D8D2A3A99E6446407E18213CDA464940
28015	2	22	1459	51418	\N	\N	50.619499516508498	с.Сосновка, сельский клуб	Россия, Волгоградская область, Котовский район, село Сосновка	0101000020E6100000BCEA01F3904546409EEFA7C64B4F4940
28026	2	22	1459	49140	\N	\N	50.349806000000001	с.Смородино, Смородинская школа	Россия, Волгоградская область, Котовский район, село Смородино	0101000020E61000007AFB73D1908D4640E8F86871C62C4940
28018	2	22	1459	17226	\N	\N	50.477609000000001	с.Слюсарево, Слюсаревская школа	Россия, Волгоградская область, Котовский район, село Слюсарево	0101000020E61000004A09C1AA7A6346403CA3AD4A223D4940
28019	2	22	1459	51327	\N	\N	50.111115880529098	х.Романово, сельский клуб	Россия, Волгоградская область, Котовский район, село Романов	0101000020E61000001C2785798F4B4640FB07910C390E4940
27991	2	22	1459	51560	\N	\N	50.187634000000003	х.Попки, Дом культуры	Россия, Волгоградская область, Котовский район, село Попки	0101000020E610000035EB8CEF8B3F464010CF126404184940
28030	2	22	1459	17834	\N	\N	50.225332999999999	с.Племхоз, здание школы		0101000020E61000007E00529B386B4640D3DA34B6D71C4940
28023	2	22	1459	17489	\N	\N	50.534649999999999	с.Перещепное, сельский Дом культуры	Россия, Волгоградская область, Котовский район, село Перещепное	0101000020E610000085402E71E48D4640386744696F444940
28029	2	22	1459	49179	\N	\N	50.200631999999999	с.Новониколаевка, здание школы	Россия, Волгоградская область, Котовский район, село Новониколаевка	0101000020E610000038143E5B078D4640FA43334FAE194940
28020	2	22	1459	17328	\N	\N	50.329237018766001	х.Нижние Коробки, Дом культуры	Россия, Волгоградская область, Котовский район, село Нижние Коробки	0101000020E6100000A96A82A8FB3E46400BD12170242A4940
28022	2	22	1459	17426	\N	\N	50.542012999999997	с.Неткачево, сельский клуб		0101000020E6100000F645425BCE774640E08096AE60454940
28024	2	22	1459	17525	\N	\N	50.473567000000003	с.Мокрая Ольховка, сельский Дом культуры		0101000020E6100000B4B0A71DFE7E464080BBECD79D3C4940
28016	2	22	1459	51272	\N	\N	50.589018775270397	с.Мирошники и с.Гордиенки, Мирошниковский сельский Дом культуры	Россия, Волгоградская область, Котовский район, село Мирошники	0101000020E6100000C1AC50A4FB5346407FDC7EF9644B4940
28025	2	22	1459	51329	\N	\N	50.363965999999998	ст.Лапшинская, с.Новоалексеевка и с.Лобынец, Лапшингская школа	Россия, Волгоградская область, Котовский район, село Лапшинская	0101000020E610000050E3DEFC867F46408F6D1970962E4940
28027	2	22	1459	17701	\N	\N	50.319291999999997	с.Купцово, сельский Дом культуры		0101000020E6100000E2B034F0A3804640EDEF6C8FDE284940
28021	2	22	1459	17389	\N	\N	50.525585999999997	с.Крячки, Крячковская школа	Россия, Волгоградская область, Котовский район, село Крячки	0101000020E61000004D8578245E704640239EEC6646434940
28010	2	22	1459	16682	27105	\N	50.319499	г.Котово, Чапаева, 3, ГОУ школа-интернат		0101000020E61000002905DD5ED2664640670DDE57E5284940
28009	2	22	1459	16682	26513	\N	50.319499	г. Котово, Синельникова, 2  МОУ СОШ №6		0101000020E61000002905DD5ED2664640670DDE57E5284940
28011	2	22	1459	16682	27108	\N	50.319499	г.Котово, Мира, 128, районный Дом культуры	Россия, Волгоградская область, Котовский район, Котово	0101000020E61000002905DD5ED2664640670DDE57E5284940
28007	2	22	1459	16682	27104	\N	50.319499	г. Котово, Ленина, 89	Россия, Волгоградская область, Котовский район, Котово	0101000020E61000002905DD5ED2664640670DDE57E5284940
28013	2	22	1459	16682	26722	\N	50.319499	г.Котово, Зеленая, 154, школа № 4		0101000020E61000002905DD5ED2664640670DDE57E5284940
28012	2	22	1459	16682	27290	\N	50.319499	г.Котово, Губкина, 8, МОУ СОШ №2		0101000020E61000002905DD5ED2664640670DDE57E5284940
28008	2	22	1459	16682	27107	\N	50.319499	г. Котово, Ленина, 89, МОУ СОШ №3	Россия, Волгоградская область, Котовский район, Котово	0101000020E61000002905DD5ED2664640670DDE57E5284940
28031	2	22	1459	17880	\N	\N	50.178733000000001	с.Коростино, здание администрации		0101000020E6100000327381CB63774640A5DB12B9E0164940
27905	2	22	1459	51412	26999	\N	50.309866512942598	с.Калиновка, Зеленая, 5	Россия, Волгоградская область, Котовский район, село Калиновка	0101000020E610000049BE124889594640088ECBB8A9274940
28033	2	22	1459	49231	26731	\N	50.265945000000002	"с.Ефимовка, Мира, 55/3 , офис ТОС ""Ефимовский"""	Россия, Волгоградская область, Котовский район, село Ефимовка	0101000020E610000035423F53AF59464072C45A7C0A224940
28014	2	22	1459	17058	\N	\N	50.569516	с.Бурлук, сельский Дом культуры	Россия, Волгоградская область, Котовский район, село Бурлук	0101000020E6100000B29C84D2174446403D4679E6E5484940
28028	2	22	1459	17734	\N	\N	50.22184	с.Авилово, сельский клуб	Россия, Волгоградская область, Котовский район, село Авилово	0101000020E6100000B4E4F1B4FC884640EA78CC40651C4940
28591	2	22	1259	40325	\N	\N	47.635751860460999	Волгоградская область, городской округ город Камышин, Ленина, 24 ПУ №22	Россия, Волгоградская область, Котельниковский район, село Ленина	0101000020E610000048C0E8F2E6A24540EC2E505260D14740
27911	2	22	1024	12119	26633	\N	50.378225999999998	с.Галка, Цветочный бульвар, 16		0101000020E6100000ADDF4C4C17E646409A3FA6B569304940
27992	2	22	1259	51378	\N	\N	47.840156262006701	Волгоградская область, Котельниковский муниципальный район, Чилековское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Чилеково	0101000020E6100000DFDC5F3DEEBF4540E3C4573B8AEB4740
27998	2	22	1259	51595	\N	\N	47.618513962124197	Волгоградская область, Котельниковский муниципальный район, Семиченское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Семичный	0101000020E6100000321F10E84C8445401F0F7D772BCF4740
28005	2	22	1259	51590	\N	\N	48.015126780041903	Волгоградская область, Котельниковский муниципальный район, Пугачевское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Пугачевская	0101000020E6100000C1C760C5A9944540AF2479AEEF014840
27994	2	22	1259	51384	\N	\N	47.513154999999998	Волгоградская область, Котельниковский муниципальный район, Попереченское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Поперечный	0101000020E61000008BFED0CC93C34540B2632310AFC14740
27995	2	22	1259	51319	\N	\N	47.700882871083301	Волгоградская область, Котельниковский муниципальный район, Пимено-Чернянское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Пимено-Черни	0101000020E610000088A06AF46ABC454043A9BD88B6D94740
28003	2	22	1259	51353	\N	\N	47.848563684185898	Волгоградская область, Котельниковский муниципальный район, Нижнеяблочное сельское поселение	Россия, Волгоградская область, Котельниковский район, село Нижнеяблочный	0101000020E61000008A5B0531D08D45400F48C2BE9DEC4740
27997	2	22	1259	51464	\N	\N	47.577511999999999	Волгоградская область, Котельниковский муниципальный район, Наголенское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Нагольный	0101000020E61000000B7BDAE1AF9545401686C8E9EBC94740
28000	2	22	1259	51512	\N	\N	47.764473000000002	Волгоградская область, Котельниковский муниципальный район, Нагавское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Нагавская	0101000020E6100000B6BA9C121069454067D65240DAE14740
27999	2	22	1259	51489	\N	\N	47.6757585683592	Волгоградская область, Котельниковский муниципальный район, Майоровское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Майоровский	0101000020E61000004B3E7617287D4540247D5A457FD64740
28004	2	22	1259	51273	\N	\N	47.9009692187174	Волгоградская область, Котельниковский муниципальный район, Красноярское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Красноярский	0101000020E6100000A915A6EF35884540DCDAC2F352F34740
27996	2	22	1259	51339	\N	\N	47.635067999999997	Волгоградская область, Котельниковский муниципальный район, Котельниковское сельское поселение	Россия, Волгоградская область, Котельниковский район, Котельниково	0101000020E610000057B08D78B2914540395E81E849D14740
27990	2	22	1259	51339	\N	\N	47.633396264530901	Волгоградская область, Котельниковский муниципальный район, Котельниковское городское поселение	Россия, Волгоградская область, Котельниковский район, Котельниково	0101000020E61000000BD121702492454067B5C01E13D14740
28002	2	22	1259	51539	\N	\N	47.6832378983298	Волгоградская область, Котельниковский муниципальный район, Захаровское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Захаров	0101000020E61000003293A8177C8E454036B1C05774D74740
27968	2	22	1259	51539	27525	\N	47.6829872651291	х.Захаров, Центральная, 12		0101000020E6100000255987A3AB8E4540EC4B361E6CD74740
28006	2	22	1259	51477	\N	\N	48.006588999999998	Волгоградская область, Котельниковский муниципальный район, Генераловское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Генераловский	0101000020E6100000D4D17135B29B4540B5C189E8D7004840
27993	2	22	1259	51525	\N	\N	47.601019881683598	Волгоградская область, Котельниковский муниципальный район, Выпасновское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Выпасной	0101000020E61000005C72DC291DCA4540F71E2E39EECC4740
28001	2	22	1259	51428	\N	\N	47.835887701040598	Волгоградская область, Котельниковский муниципальный район, Верхнекурмоярское сельское поселение	Россия, Волгоградская область, Котельниковский район, село Веселый	0101000020E6100000433A3C84F17D4540368FC360FEEA4740
28074	2	22	1259	51428	27370	\N	47.8332354076963	хутор Веселый, Садовая, 12, Веселовский сельский клуб	Россия, Волгоградская область, Котельниковский район, село Веселый	0101000020E61000002BC0779B377E4540F870C971A7EA4740
27969	2	22	1353	51392	27484	\N	49.168140999999999	х.Селиванов, Пролетарская, 12	Россия, Волгоградская область, Клетский район, село Селиванов	0101000020E6100000AE8383BD897D4540F10EF0A485954840
27972	2	22	1353	51392	26951	\N	49.168140999999999	х.Селиванов, Придорожная, 6	Россия, Волгоградская область, Клетский район, село Селиванов	0101000020E6100000AE8383BD897D4540F10EF0A485954840
27976	2	22	1353	15186	27101	\N	49.407288999999999	ст.Перекопская, Казачья, 26	Россия, Волгоградская область, Клетский район, село Перекопская	0101000020E610000003D0285DFAAB4540A182C30B22B44840
27987	2	22	1353	51677	27491	\N	49.363863000000002	х.Перекопка, Центральная, 29А	Россия, Волгоградская область, Клетский район, село Перекопка	0101000020E61000004548DDCEBEAA4540BB9C121093AE4840
27907	2	22	1024	11924	26403	\N	50.539985999999999	с.Воднобуерачное, Советская, 14		0101000020E61000001FF296AB1FD146402026E1421E454940
27989	2	22	1353	51655	27437	\N	49.2350674690259	х.Орехов, Донская, 14А	Россия, Волгоградская область, Клетский район, село Орехов	0101000020E6100000A4C343183F9B454036AFEAAC169E4840
27967	2	22	1353	51662	27459	\N	49.183281830322002	х.Новоцарицынский, Молодежная, 4	Россия, Волгоградская область, Клетский район, село Новоцарицынский	0101000020E61000003D0B42791F4B454005F9D9C875974840
27980	2	22	1353	51287	26505	\N	49.301156129459997	х.Мелоклетский, Сухорукова, 69	Россия, Волгоградская область, Клетский район, село Мелоклетский	0101000020E61000003ECDC98B4C904540417FA1478CA64840
27981	2	22	1353	15432	26526	\N	49.009084000000001	х.Манойлин, Атамана Макарова, 3	Россия, Волгоградская область, Клетский район, село Манойлин	0101000020E6100000C4995FCD017445405C751DAA29814840
27985	2	22	1353	51674	27490	\N	49.088957000000001	х.Малая Донщинка, Центральная, 6	Россия, Волгоградская область, Клетский район, село Малая Донщинка	0101000020E6100000418177F2E937454009E066F1628B4840
27986	2	22	1353	51676	27489	\N	49.104424000000002	х.Максари, Центральная, 33	Россия, Волгоградская область, Клетский район, село Максари	0101000020E61000003CA1D79FC4514540717500C45D8D4840
27982	2	22	1353	51289	26518	\N	49.050156075242398	х.Майоровский, Келина, 64	Россия, Волгоградская область, Клетский район, село Майоровский	0101000020E6100000A0C03BF9F48045405ED905836B864840
27988	2	22	1353	51716	27642	\N	49.326100601848403	х.Логовский, Молодежная, 22	Россия, Волгоградская область, Клетский район, село Логовский	0101000020E610000087E123624AA24540B11875ADBDA94840
27984	2	22	1353	51667	27471	\N	49.069271000000001	х.Липовский, Молодежная, 13	Россия, Волгоградская область, Клетский район, село Липовский	0101000020E6100000B1A206D330444540D6C743DFDD884840
27975	2	22	1353	15129	26687	\N	49.478411000000001	ст.Кременская, Ленина, 22Б	Россия, Волгоградская область, Клетский район, село Кременская	0101000020E6100000501A6A1492BA4540F98557923CBD4840
27978	2	22	1353	15199	26434	\N	49.306384999999999	ст.Клетская, Ленина, 32		0101000020E6100000B7B2446799874540137EA99F37A74840
27977	2	22	1353	15199	26434	\N	49.306384999999999	ст.Клетская, Ленина, 63	Россия, Волгоградская область, Клетский район, поселок Клетская	0101000020E6100000B7B2446799874540137EA99F37A74840
27979	2	22	1353	51668	27477	\N	49.335945000000002	х.Караженский, пер.Школьный, 8		0101000020E6100000906B43C5388345409B20EA3E00AB4840
27971	2	22	1353	23437	27503	\N	49.138981000000001	х.Казачий, Центральная, 6	Россия, Волгоградская область, Клетский район, село Казачий	0101000020E6100000B3EA73B515734540F8E12021CA914840
27974	2	22	1353	51600	27309	\N	49.048360000000002	х.Зотовский, Центральная, 22	Россия, Волгоградская область, Клетский район, село Зотовский	0101000020E61000004E0D349F735D4540A03715A930864840
27970	2	22	1353	51650	27434	\N	49.188389000000001	х.Евстратовский, пер.Московский, 2		0101000020E61000005320B3B3E86F45408CF678211D984840
27962	2	22	1353	14524	27091	\N	49.058166999999997	Верхняя Бузиновка, Центральная, 103	Россия, Волгоградская область, Клетский район, село Верхняя Бузиновка	0101000020E61000007FBDC282FB9B45406C5A290472874840
27964	2	22	1353	51635	27433	\N	49.215114665534799	х.Верхнечеренский, пер.Больничный, 2	Россия, Волгоградская область, Клетский район, село Верхнечеренский	0101000020E61000005D37A5BC5656454084F068E3889B4840
27965	2	22	1353	51635	27390	\N	49.2191066651271	х.Верхнечеренский, Центральная, 24Б	Россия, Волгоградская область, Клетский район, село Верхнечеренский	0101000020E61000008F8B6A11515645408FA9BBB20B9C4840
27963	2	22	1353	51661	27456	\N	49.179435505413799	х.Венцы, Пролетарская, 7	Россия, Волгоградская область, Клетский район, село Венцы	0101000020E6100000DBDFD91EBDA74540CFDC43C2F7964840
27922	2	22	1353	51317	26664	\N	48.886612	х.Борисов, Чижова, 45	Россия, Волгоградская область, Клетский район, село Борисов	0101000020E61000008577B988EF764540DE1E84807C714840
28462	2	22	5103	37535	\N	\N	50.617295126957004	с. Красный Яр, Здание культурно-досугового объединения	Россия, Волгоградская область, Старополтавский район, село Красный Яр	0101000020E6100000A99F3715A9E24640FE7DC685034F4940
27773	2	22	5103	37535	26785	\N	50.616748999999999	р.п.Красный Яр, Центральная, 14А		0101000020E6100000E41071732AE346409C6B98A1F14E4940
27943	2	22	1306	51427	27015	\N	50.723818379053299	х.Ширяевский, здание Ширяевского сельского клуба	Россия, Волгоградская область, Киквидзенский район, село Ширяевский	0101000020E61000005DDC460378814540C9207711A65C4940
27954	2	22	1306	14129	\N	\N	50.637599000000002	х.Чернолагутинский, здание сельского Дома культуры	Россия, Волгоградская область, Киквидзенский район, село Чернолагутинский	0101000020E610000082A8FB00A4AA45402D7B12D89C514940
27734	2	22	1306	47878	27018	\N	50.798661000000003	с. Семеновка, Центральная, 19 (Семеновский сельский клуб)	Россия, Волгоградская область, Киквидзенский район, село Семеновка	0101000020E610000075560BEC319545409BCB0D863A664940
27950	2	22	1306	51549	\N	\N	50.7072759134807	х.Расстригин, здание Расстригинского сельского клуба	Россия, Волгоградская область, Киквидзенский район, село Расстригин	0101000020E610000014B35E0CE5704540739F1C05885A4940
27944	2	22	1306	51511	\N	\N	50.745491000000001	ст. Преображенская, здание Дон-Якушовского сельского клуба	Россия, Волгоградская область, Киквидзенский район, поселок городского типа Преображенская	0101000020E6100000AEB7CD54888745402E3BC43F6C5F4940
27942	2	22	1306	51511	\N	\N	50.745491000000001	ст. Преображенская, здание районного Дома культуры	Россия, Волгоградская область, Киквидзенский район, поселок городского типа Преображенская	0101000020E6100000AEB7CD54888745402E3BC43F6C5F4940
27941	2	22	1306	51511	\N	\N	50.742005971632899	"ст.Преображенская, Здание МУ ""Социально досуговый центр Ровесник"""	Россия, Волгоградская область, Киквидзенский район, поселок городского типа Преображенская	0101000020E61000004C546F0D6C874540C8B7770DFA5E4940
15210	5	43	323	3254	71652	\N	51.405918	с. Чемал, Курортная, 1		0101000020E6100000693BA6EECA805540CA6DFB1EF5B34940
27955	2	22	1306	51521	\N	\N	50.773357518008403	х.Озерки, здание Озерской школы	Россия, Волгоградская область, Киквидзенский район, село Озерки	0101000020E610000039D1AE42CA9D4540CC0C1B65FD624940
27952	2	22	1306	51282	\N	\N	50.548789279511603	х.Мордвинцево, здание Мордвинцевской общеобразовательной школы	Россия, Волгоградская область, Киквидзенский район, село Мордвинцево	0101000020E61000001CB4571F0FA14540C8B3CBB73E464940
27957	2	22	1306	14261	\N	\N	50.808354999999999	с.Мачеха, здание сельского Дома культуры		0101000020E61000009C6B98A1F1A645406F47382D78674940
27951	2	22	1306	51356	26792	\N	50.554078455289002	х.Калачевский, здание Калачевского сельского Дома культуры	Россия, Волгоградская область, Киквидзенский район, село Калачевский	0101000020E6100000D65416855D8045406FB72407EC464940
27945	2	22	1306	51566	\N	\N	50.769371999999997	х.Казарино, здание Казаринского сельского клуба	Россия, Волгоградская область, Киквидзенский район, село Казарино	0101000020E6100000D71533C2DB954540A33A1DC87A624940
27946	2	22	1306	13756	\N	\N	50.812947999999999	с.Завязка, здание Завязенского сельского Дома культуры		0101000020E610000001F9122A388645409FAC18AE0E684940
27949	2	22	1306	51338	\N	\N	50.731715035222102	х.Дубровский, здание Дубровского сельского клуба	Россия, Волгоградская область, Киквидзенский район, село Дубровский	0101000020E61000001A6B7F677B7645400F7F4DD6A85D4940
27953	2	22	1306	14067	\N	\N	50.635634000000003	п.Гришин, здание сельского Дома культуры		0101000020E6100000795BE9B5D9924540E31C75745C514940
27947	2	22	1306	13770	\N	\N	50.908003999999998	с.Алонцево, здание Алонцевского сельского клуба		0101000020E61000005B3FFD67CD8345408F519E7939744940
27909	2	22	1024	46971	26699	\N	50.489655999999997	с.Щербатовка, Мира, 28	Россия, Волгоградская область, Камышинский район, село Щербатовка	0101000020E6100000A60D87A581D7464024253D0CAD3E4940
27910	2	22	1024	46998	27057	\N	50.510609000000002	с.Щербаковка, Центральная, 14	Россия, Волгоградская область, Камышинский район, село Щербаковка	0101000020E610000041F163CC5DE146408A05BEA25B414940
27929	2	22	1024	12937	26458	\N	49.862631999999998	с.Чухонастовка, Советская, 14		0101000020E61000000F643DB5FA8C4640D53DB2B96AEE4840
27901	2	22	1024	11647	26766	\N	50.477620000000002	с.Усть-Грязнуха, Школьная, 22		0101000020E61000001A14CD0358B6464030F5F3A6223D4940
27884	2	22	1024	46470	27143	\N	50.290859664920902	с. Умет, 60 лет Октября, 75	Россия, Волгоградская область, Камышинский район, село Умет	0101000020E61000005280289831AB464077DB85E63A254940
28539	2	22	1024	51389	\N	\N	50.206637565358299	х. Терновка, здание Дома культуры	Россия, Волгоградская область, Камышинский район, село Терновка	0101000020E610000074435376FABF4640300E2E1D731A4940
27915	2	22	1024	51389	26918	\N	50.206968000000003	с.Терновка, Центральная, 5б	Россия, Волгоградская область, Камышинский район, село Терновка	0101000020E6100000F0FD0DDAABBF4640C6A86BED7D1A4940
27930	2	22	1024	51382	26904	\N	49.973247816315897	с.Таловка, Молодежная, 1	Россия, Волгоградская область, Камышинский район, село Таловка	0101000020E6100000B72A89EC83844640DE72F56393FC4840
27939	2	22	1024	13403	27080	\N	50.118696	с.Средняя Камышинка, Центральная, 8		0101000020E6100000D1AFAD9FFEA346404015376E310F4940
27904	2	22	1024	51416	27004	\N	50.489531710577502	с.Семеновка, Советская, 6	Россия, Волгоградская область, Камышинский район, село Семеновка	0101000020E6100000E71BD13DEBA84640382C0DFCA83E4940
27933	2	22	1024	13116	26676	\N	50.013330000000003	с.Саломатино, Советская, 31	Россия, Волгоградская область, Камышинский район, село Саломатино	0101000020E6100000A7C98CB7956C4640210725CCB4014940
27918	2	22	1024	12450	26412	\N	50.105080000000001	с.Петрунино, Школьная, 5		0101000020E610000012A0A696AD8946405ABBED42730D4940
27925	2	22	1024	12508	27164	\N	50.139259000000003	г.Петров Вал, Школьная, 3		0101000020E61000002FDB4E5B239A46403B56293DD3114940
27927	2	22	1024	12508	26679	\N	50.141562287261401	г.Петров Вал, Рихарда Зорге, 5	Россия, Волгоградская область, Камышинский район, Петров Вал	0101000020E6100000566133C0059B46409D2D20B41E124940
27921	2	22	1024	12508	26654	\N	50.139259000000003	г.Петров Вал, Пионерская, 14	Россия, Волгоградская область, Камышинский район, Петров Вал	0101000020E61000002FDB4E5B239A46403B56293DD3114940
27923	2	22	1024	12508	26453	\N	50.142365556112502	г.Петров Вал, Ленина, 15	Россия, Волгоградская область, Камышинский район, Петров Вал	0101000020E6100000CC7C073F719A4640FB07910C39124940
27919	2	22	1024	12508	26453	\N	50.139259000000003	г.Петров Вал, Ленина, 61	Россия, Волгоградская область, Камышинский район, Петров Вал	0101000020E61000002FDB4E5B239A46403B56293DD3114940
27920	2	22	1024	12508	27223	\N	50.139259000000003	г.Петров Вал, Коммунистическая, 67		0101000020E61000002FDB4E5B239A46403B56293DD3114940
27926	2	22	1024	12508	27067	\N	50.139259000000003	г.Петров Вал, 30 лет Победы, 2		0101000020E61000002FDB4E5B239A46403B56293DD3114940
27903	2	22	1024	46846	27231	\N	50.587648999999999	с.Пановка, Центральная, 5		0101000020E610000061545227A0B3464078431A15384B4940
27913	2	22	1024	12244	26874	\N	50.312798000000001	с.Нижняя Добринка, Ленина, 33б		0101000020E6100000BDA94885B1D946408A20CEC309284940
27935	2	22	1024	51638	27394	\N	50.220667552127999	п.Мичуринский, Совхозная, 5	Россия, Волгоградская область, Камышинский район	0101000020E6100000963FDF162CB346400AA359D93E1C4940
27940	2	22	1024	47599	26724	\N	50.178075999999997	с.Лебяжье, Советская, 27		0101000020E61000000F7C0C569C9A4640EB19C231CB164940
27934	2	22	1024	13196	27168	\N	50.065908999999998	с.Костарево, Центральная, 10		0101000020E6100000C172840CE47946408BC1C3B46F084940
27938	2	22	1024	13390	26957	\N	50.164627000000003	с.Ельшанка, Центральная, 10	Россия, Волгоградская область, Камышинский район, село Ельшанка	0101000020E610000083A44FABE8B14640F1845E7F12154940
27914	2	22	1024	47072	27234	\N	50.235688000000003	с.Дубовка, Центральная, 31а		0101000020E6100000C408E1D1C6C74640A3073E062B1E4940
27936	2	22	1024	13288	27053	\N	50.244231999999997	с.Дворянское, Советская, 7б		0101000020E61000006BD8EF8975A446407E5182FE421F4940
27937	2	22	1024	13288	26889	\N	50.244231999999997	с.Дворянское, Микрорайон, 6а		0101000020E61000006BD8EF8975A446407E5182FE421F4940
27906	2	22	1024	11862	26955	\N	50.458499000000003	с.Гуселка, Центральная, 73		0101000020E6100000FCFCF7E0B5934640D61F6118B03A4940
27931	2	22	1024	51728	27714	\N	50.008084647816297	с.Вихляенцево, Мира, 14	Россия, Волгоградская область, Камышинский район, село Вихлянцево	0101000020E610000018D00B772EA64640494BE5ED08014940
27916	2	22	1024	12358	26408	\N	50.17792	с.Верхняя Липовка, Школьная, 19		0101000020E6100000E7559DD502BB4640F4A62215C6164940
27908	2	22	1024	11978	26623	\N	50.417897000000004	с.Верхняя Куланинка, Школьная, 15		0101000020E610000008E6E8F17BD946405B0C1EA67D354940
27902	2	22	1024	11684	26620	\N	50.479173000000003	с.Верхняя Грязнуха, Песчаная, 8		0101000020E6100000451152B7B3BB46402810768A553D4940
14664	2	22	1024	8914	26855	\N	49.959864000000003	с.Белогорки, Новая, 10	Россия, Волгоградская область, Камышинский район, село Белогорки	0101000020E6100000397B67B455974640CB4DD4D2DCFA4840
27917	2	22	1024	47146	27192	\N	50.135869999999997	с.Барановка, Саратовская, 14		0101000020E6100000056B9C4D47944640F6402B3064114940
27928	2	22	1024	12931	27249	\N	49.827976	с.Антиповка, Дружбы, 58		0101000020E61000008E9257E718A84640BBEF181EFBE94840
28592	2	22	6895	40309	9777	\N	50.103360339612003	"Волгоградская область, городской округ город Камышин, Ленина, 17 ДК ""Текстильщик"""	Россия, Волгоградская область, Камышин городской округ	0101000020E6100000FB5A971AA1B5464077DB85E63A0D4940
28596	2	22	6895	40309	26869	\N	50.110906092704397	Волгоградская область, городской округ город Камышин, Краснодонская, 7 МОУСОШ№11		0101000020E61000005A10CAFB38B446401077F52A320E4940
27871	2	22	1048	10203	27125	\N	48.430627999999999	хутор Ярки-Рубежный, ул.Пушкина, д.14. Клуб	Россия, Волгоградская область, Калачевский район, село Ярки-Рубежный	0101000020E610000009C03FA54AF44540F65E7CD11E374840
27866	2	22	1048	51436	27030	\N	48.539428000000001	хутор Тихоновка, ул.Суворова, д.4. Клуб	Россия, Волгоградская область, Калачевский район, село Тихоновка	0101000020E61000008335CEA623D64540FA4509FA0B454840
27870	2	22	1048	10171	26833	\N	48.389870000000002	хутор Степаневка, ул.Верхне-Царицынская, д.36 А. МОУ Верхне-Царицынская НОШ	Россия, Волгоградская область, Калачевский район, село Степаневка	0101000020E6100000BC74931804F8454084D89942E7314840
27851	2	22	1048	9251	26825	\N	48.697488	хутор Светлый Лог, ул.Школьная, д.1. Логовская ООШ		0101000020E61000005001309E41A945401DAD6A4947594840
27855	2	22	1048	9432	26429	\N	48.809764999999999	хутор Рюмино-Красноярский, ул.Центральная, д.29. Клуб		0101000020E61000007B336ABE4ACC454004392861A6674840
27857	2	22	1048	51670	27481	\N	48.647829889457299	поселок Пятиморск, ул.Волгоградская, д.41. Клуб ДРГСиС		0101000020E6100000C1C41F459DCD454010AFEB17EC524840
27849	2	22	1048	9179	26927	\N	48.590907000000001	хутор Пятиизбянский, ул.Центральная, д.33. Администрация ПСП		0101000020E6100000F2785A7EE0B845401EFD2FD7A24B4840
27860	2	22	1048	9652	27021	\N	48.690429000000002	поселок Прудбой, ул.Молодежная, д.4. МОУ Прудбойская СОШ	Россия, Волгоградская область, Калачевский район, село Прудбой	0101000020E61000007638BA4A77F34540E19A3BFA5F584840
27868	2	22	1048	51305	26600	\N	48.566473999999999	хутор Приморский, ул.Победы, д.16. Дом культуры	Россия, Волгоградская область, Калачевский район, село Приморский	0101000020E61000001781B1BE81C545406404543882484840
28434	2	22	1048	51423	27010	\N	48.3934351660508	"п. Первомайский, Первомайская, 24а, здание магазина ""Лесовик"""	Россия, Волгоградская область, Калачевский район, село Первомайский	0101000020E6100000DE205A2BDAAC4540060DFD135C324840
27888	2	22	1048	11022	\N	\N	48.570576000000003	поселок Пархоменко, Селский клуб		0101000020E610000084622B685A124640F6F065A208494840
27862	2	22	1048	51596	\N	\N	48.652293181837003	"поселок Октябрьский, ФГУ ""61 Дом офицеров (гарнизрна)"""	Россия, Волгоградская область, Калачевский район, село Октябрьский	0101000020E6100000950B957F2DE74540723447567E534840
28254	2	22	1048	51596	27465	\N	48.652861867070598	Волгоградская область, Ольховский муниципальный район, Октябрьское сельское поселение п Октябрьский, Школьная, 12	Россия, Волгоградская область, Калачевский район, село Октябрьский	0101000020E6100000FEF2C98AE1E645408C6665FB90534840
27882	2	22	1048	46434	26947	\N	48.324547000000003	поселок Овражный, ул.Мира, д.15 А. Клуб	Россия, Волгоградская область, Калачевский район, село Овражный	0101000020E6100000CA89761552E24540E9818FC18A294840
27873	2	22	1048	10323	26757	\N	48.488428999999996	хутор Новоляпичев, ул.Молодежная, д.20. Дом культуры	Россия, Волгоградская область, Калачевский район, село Новоляпичев	0101000020E6100000BC96900F7AC8454080B56AD7843E4840
27858	2	22	1048	9540	26882	\N	48.687424999999998	село Мариновка, ул.Набережная, д.17 А. Дом культуры		0101000020E61000009031772D21EB4540F5B9DA8AFD574840
27852	2	22	1048	9277	27116	\N	48.899755999999996	хутор Малоголубинский, ул.Подгорная, д.91. Клуб	Россия, Волгоградская область, Калачевский район, село Малоголубинский	0101000020E61000000CE8853B17CC45409C3061342B734840
27875	2	22	1048	10442	\N	\N	48.493994000000001	хутор Ляпичев, ул.Семёнова, д.16. Дом культуры		0101000020E61000009DF3531C07C04540CA3505323B3F4840
27877	2	22	1048	10507	\N	\N	48.428398000000001	хутор Логовский, д..63. МОУ Логовская СОШ		0101000020E6100000A9BC1DE1B4AE4540FED5E3BED5364840
27881	2	22	1048	10725	27213	\N	48.359467000000002	поселок Крепинский, ул.Свободная, д. 31. МОУ Крепинская СОШ		0101000020E61000009C35785F95D74540E17EC003032E4840
27861	2	22	1048	51271	26447	\N	48.657302999999999	поселок Комсомольский, ул.Шлюзовая, д.11. Клуб	Россия, Волгоградская область, Калачевский район, село Комсомольский	0101000020E6100000185FB4C70BEF45400648348122544840
27867	2	22	1048	10044	27303	\N	48.605308000000001	хутор Колпачки, ул.Клубная, д.2. Клуб	Россия, Волгоградская область, Калачевский район, село Колпачки	0101000020E6100000FC1A498270CD4540EB0088BB7A4D4840
27854	2	22	1048	9357	26742	\N	48.736946000000003	хутор Камыши, ул.Донская, д.28. Клуб		0101000020E6100000CCB73EAC37C0454082751C3F545E4840
27890	2	22	1048	11110	26612	\N	48.684719000000001	"г.Калач-на-Дону, пер.Озёрный, д.9.  МОУ ""Черкасовская ООШ"""		0101000020E6100000B28174B169C3454094F947DFA4574840
27898	2	22	1048	11110	27154	\N	48.684719000000001	г.Калач-на-Дону, ул.Советская, д.5. МОУ СОШ №2		0101000020E6100000B28174B169C3454094F947DFA4574840
27892	2	22	1048	11110	26852	\N	48.684719000000001	г.Калач-на-Дону, Революционная, 421. МОУ СОШ №4		0101000020E6100000B28174B169C3454094F947DFA4574840
27891	2	22	1048	11110	26852	\N	48.684719000000001	г.Калач-на-Дону, Революционная, д.421.  МОУ СОШ №4		0101000020E6100000B28174B169C3454094F947DFA4574840
27900	2	22	1048	11110	26389	\N	48.684719000000001	"г.Калач-на-Дону, ул.Октябрьская, д.94 А. МУК ""Калачевская ГФ"""		0101000020E6100000B28174B169C3454094F947DFA4574840
27899	2	22	1048	11110	26389	\N	48.684719000000001	г.Калач-на-Дону, ул.Октябрьская, д.73. МОУ СОШ №2		0101000020E6100000B28174B169C3454094F947DFA4574840
27895	2	22	1048	11110	26389	\N	48.684719000000001	г.Калач-на-Дону, ул.Октябрьская, д.204. Районный ДК	Россия, Волгоградская область, Калачевский район, Калач-на-Дону	0101000020E6100000B28174B169C3454094F947DFA4574840
27894	2	22	1048	11110	26389	\N	48.684719000000001	"г.Калач-на-Дону, Октябрьская, д.271.  ГОУ ""ПУ-13"""	Россия, Волгоградская область, Калачевский район, Калач-на-Дону	0101000020E6100000B28174B169C3454094F947DFA4574840
27893	2	22	1048	11110	26389	\N	48.684719000000001	г.Калач-на-Дону, Октябрьская, 283, МОУ СОШ №1		0101000020E6100000B28174B169C3454094F947DFA4574840
27897	2	22	1048	11110	26953	\N	48.684719000000001	г.Калач-на-Дону, ул.Краснознаменская, д.103 А. Детский сад №1		0101000020E6100000B28174B169C3454094F947DFA4574840
27896	2	22	1048	11110	27033	\N	48.684719000000001	г.Калач-на-Дону, ул.Дубинец, д.18 А. МОУ СОШ №3		0101000020E6100000B28174B169C3454094F947DFA4574840
27856	2	22	1048	9439	26932	\N	48.649155	поселок Ильевка, пер.Советский, д.11. Ильевская СОШ	Россия, Волгоградская область, Калачевский район, село Ильевка	0101000020E61000003BE3FBE252D145407784D38217534840
27889	2	22	1048	46566	\N	\N	48.534584000000002	поселок Заря, Сельский дом культуры		0101000020E6100000E370E657730E4640817B9E3F6D444840
27853	2	22	1048	9328	26938	\N	48.850047000000004	станица Голубинская, пер.Клубный, д.9. Дом культуры	Россия, Волгоградская область, Калачевский район, село Голубинская	0101000020E6100000B4C876BE9FC845400E881057CE6C4840
27865	2	22	1048	9901	27028	\N	48.637028000000001	поселок Волгодонской, ул.Советская, д.17/1, Дом культуры	Россия, Волгоградская область, Калачевский район, село Волгодонской	0101000020E610000018601F9DBADC454072512D228A514840
27872	2	22	1048	10286	26765	\N	48.516748999999997	хутор Вербовский, ул.Донская, д.32. Дом культуры	Россия, Волгоградская область, Калачевский район, село Вербовский	0101000020E610000003CE52B29CCA4540CF9ECBD424424840
27869	2	22	1048	10132	26750	\N	48.501444999999997	хутор Бузиновка, ул.Центральная, д.45. Администрация Бузиновского СП		0101000020E6100000CD237F30F0F2454011DF89592F404840
27880	2	22	1048	51303	26591	\N	48.406399	хутор Братский, пер.Мирный, д.5, Клуб	Россия, Волгоградская область, Калачевский район, село Братский	0101000020E6100000624D6551D8CF45404510E7E104344840
27886	2	22	1048	10903	27218	\N	48.619675999999998	поселок Береславка, ул.Школьная, д.2. Администрация Береславског СП	Россия, Волгоградская область, Калачевский район, село Береславка	0101000020E6100000252367614F074640DC0E0D8B514F4840
27885	2	22	1048	10903	27039	\N	48.619675999999998	"поселок Береславка, ул.Ленина, д.23 А. Дом культуры ""Родина"""		0101000020E6100000252367614F074640DC0E0D8B514F4840
27887	2	22	1048	10903	26847	\N	48.619675999999998	поселок Береславка, ул.Волгоградская, д.32 А. Клуб Рокотинский		0101000020E6100000252367614F074640DC0E0D8B514F4840
27879	2	22	1048	10636	27307	\N	48.382905000000001	п.Белоглинский, пер.Трудовой, д.5, Сельский клуб		0101000020E6100000637B2DE8BDD34540C93CF20703314840
27845	2	22	917	51463	\N	\N	49.270862472330997	"Волгоградская область, муниципальное образование ""Иловлинский район"", Сиротинское сельское поселение, здание Шохинской начальной школы"	Россия, Волгоградская область, Иловлинский район, село Шохинский	0101000020E6100000C37DE4D6A4C7454055DD239BABA24840
27827	2	22	917	51343	\N	\N	49.584976868492397	"Волгоградская область, муниципальное образование ""Иловлинский район"", Ширяевское сельское поселение, здание Ж-Ширяйского сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Ширяевский	0101000020E610000002BC051214034640C3F4BD86E0CA4840
27826	2	22	917	51343	\N	\N	49.569963999999999	"Волгоградская область, муниципальное образование ""Иловлинский район"", Ширяевское сельское поселение, здание администрации Ширяевского сельского поселения"	Россия, Волгоградская область, Иловлинский район, село Ширяевский	0101000020E610000099A0866F61054640DCF29194F4C84840
27830	2	22	917	51280	\N	\N	49.4865514996524	"Волгоградская область, муниципальное образование ""Иловлинский район"", Кондрашовское сельское поселение, здание Чернозубовского сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Чернозубовка	0101000020E61000006937FA980F204640056B9C4D47BE4840
27842	2	22	917	51350	\N	\N	49.093510999999999	"Волгоградская область, муниципальное образование ""Иловлинский район"", Трехостровское сельское поселение, здание Трехостровского сельского Дома культуры"		0101000020E61000002C6519E258F545407B681F2BF88B4840
27818	2	22	917	51594	\N	\N	49.353512836191101	"Волгоградская область, муниципальное образование ""Иловлинский район"", Авиловское сельское поселение, здание Таровского сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Тары	0101000020E6100000EEE9EA8EC5FE4540FDDAFAE93FAD4840
27846	2	22	917	51344	\N	\N	49.255502	"Волгоградская область, муниципальное образование ""Иловлинский район"", Сиротинское сельское поселение, здание Камышинского сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Сиротинская	0101000020E6100000234910AE80D6454003081F4AB4A04840
27623	2	22	348	29901	26985	\N	49.231270000000002	с. Прямая Балка, Мира, 36 (Прямобалкинская ООШ)		0101000020E610000086CABF96575C4640E1455F419A9D4840
27844	2	22	917	51344	\N	\N	49.2561202150643	"Волгоградская область, муниципальное образование ""Иловлинский район"", Сиротинское сельское поселение, здание Сиротинского дома культуры"	Россия, Волгоградская область, Иловлинский район, село Сиротинская	0101000020E6100000ACE28DCC23D74540FFEC478AC8A04840
27843	2	22	917	51344	\N	\N	49.2545920542305	"Волгоградская область, муниципальное образование ""Иловлинский район"", Сиротинское сельское поселение, здание Хмелевской начальной школы"	Россия, Волгоградская область, Иловлинский район, село Сиротинская	0101000020E6100000C8091346B3D6454060E97C7896A04840
27824	2	22	917	51293	\N	\N	49.3572804985075	"Волгоградская область, муниципальное образование ""Иловлинский район"", Озерское сельское поселение, административное здание ООО ""Придонье"""	Россия, Волгоградская область, Иловлинский район, село Песчанка	0101000020E6100000AF3F89CF9D044640E8C1DD59BBAD4840
27825	2	22	917	51291	\N	\N	49.402156634491298	"Волгоградская область, муниципальное образование ""Иловлинский район"", Озерское сельское поселение, здание Б-Колдаировского культурно-досугового центра"	Россия, Волгоградская область, Иловлинский район, село Озерки	0101000020E61000002F302B14E9E24540C26D6DE179B34840
27848	2	22	917	51359	\N	\N	49.417029999999997	"Волгоградская область, муниципальное образование ""Иловлинский район"", Новогригорьевское сельское поселение, здание Старогригорьевской сельской библиотеки"	Россия, Волгоградская область, Иловлинский район, село Новогригорьевская	0101000020E61000007DCA3159DCD14540B6B9313D61B54840
27847	2	22	917	51359	\N	\N	49.415739186053003	"Волгоградская область, муниципальное образование ""Иловлинский район"", Новогригорьевское сельское поселение, здание Новогригорьевского Дома культуры"	Россия, Волгоградская область, Иловлинский район, село Новогригорьевская	0101000020E610000043FF04172BD24540FC5580EF36B54840
27836	2	22	917	51580	\N	\N	49.232676182000503	"Волгоградская область, муниципальное образование ""Иловлинский район"", Медведевское сельское поселение, здание Медведевского сельского Дома культуры"	Россия, Волгоградская область, Иловлинский район, село Медведев	0101000020E610000043588D25AC1D46403448C153C89D4840
27822	2	22	917	51268	\N	\N	49.489235634905299	"Волгоградская область, муниципальное образование ""Иловлинский район"", Логовское сельское поселение, здание МОУ ""Логовская СОШ"""	Россия, Волгоградская область, Иловлинский район, поселок Лог	0101000020E610000007CE1951DAED45404F0306499FBE4840
27823	2	22	917	51485	\N	\N	49.480959749409998	"Волгоградская область, муниципальное образование ""Иловлинский район"", Логовское сельское поселение, здание Вилтовского сельского клуба"	Россия, Волгоградская область, Иловлинский район, поселок городского типа Лог	0101000020E6100000E02F664B56ED45409357E71890BD4840
27821	2	22	917	51485	\N	\N	49.481912723062997	"Волгоградская область, муниципальное образование ""Иловлинский район"", Логовское сельское поселение, здание Логовской музыкальной школы"	Россия, Волгоградская область, Иловлинский район, поселок городского типа Лог	0101000020E6100000030AF5F411EE454035423F53AFBD4840
27834	2	22	917	51506	\N	\N	49.398907533188101	"Волгоградская область, муниципальное образование ""Иловлинский район"", Кондрашовское сельское поселение, здание Красноярского сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Красноярский	0101000020E6100000406B7EFCA50B46406F0ED76A0FB34840
27835	2	22	917	51559	\N	\N	49.188507844669701	"Волгоградская область, муниципальное образование ""Иловлинский район"", Краснодонское сельское поселение, здание Краснодонского сельского Дома культуры"	Россия, Волгоградская область, Иловлинский район, село Краснодонский	0101000020E61000001B12F758FA0846406684B70721984840
27833	2	22	917	51348	\N	\N	49.432833994180697	"Волгоградская область, муниципальное образование ""Иловлинский район"", Кондрашовское сельское поселение, здание Кондрашовской средней школы"	Россия, Волгоградская область, Иловлинский район, село Кондраши	0101000020E6100000130D52F014164640664CC11A67B74840
27832	2	22	917	51348	\N	\N	49.433923	"Волгоградская область, муниципальное образование ""Иловлинский район"", Кондрашовское сельское поселение, здание Писаревской начальной школы"	Россия, Волгоградская область, Иловлинский район, село Кондраши	0101000020E61000008446B071FD154640B9FDF2C98AB74840
27831	2	22	917	51348	\N	\N	49.435688796345502	"Волгоградская область, муниципальное образование ""Иловлинский район"", Кондрашовское сельское поселение, здание Бердиевского клуба"	Россия, Волгоградская область, Иловлинский район, село Кондраши	0101000020E6100000C190D5AD9E1746400D1D3BA8C4B74840
27816	2	22	917	51380	\N	\N	49.260915530524002	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, здание Колоцкого сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Колоцкий	0101000020E610000030629F008AFF454067800BB265A14840
27808	2	22	471	49305	26807	\N	51.097225999999999	с.Романовка, Степная, 10	Россия, Волгоградская область, Жирновский район, село Романовка	0101000020E61000003B8F8AFF3B2446401329CDE6718C4940
27839	2	22	917	51563	\N	\N	49.110471154251499	"Волгоградская область, муниципальное образование ""Иловлинский район"", Качалинское сельское поселение, здание Качалинской средней школы №1"	Россия, Волгоградская область, Иловлинский район, село Качалинская	0101000020E610000034D8D479540446400514EAE9238E4840
27841	2	22	917	51290	\N	\N	49.120004000000002	"Волгоградская область, муниципальное образование ""Иловлинский район"", Качалинское сельское поселение, здание клуба санатория ""Качалинский"""	Россия, Волгоградская область, Иловлинский район, село Качалино	0101000020E61000001BD47E6B27084640D1B1834A5C8F4840
27840	2	22	917	51290	\N	\N	49.120004000000002	"Волгоградская область, муниципальное образование ""Иловлинский район"", Качалинское сельское поселение, зданиен Качалинской средней школы №2"	Россия, Волгоградская область, Иловлинский район, село Качалино	0101000020E61000001BD47E6B27084640D1B1834A5C8F4840
27838	2	22	917	51290	\N	\N	49.120004000000002	"Волгоградская область, муниципальное образование ""Иловлинский район"", Качалинское сельское поселение, здание Широковского сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Качалино	0101000020E61000001BD47E6B27084640D1B1834A5C8F4840
27837	2	22	917	51290	\N	\N	49.120004000000002	"Волгоградская область, муниципальное образование ""Иловлинский район"", Качалинское сельское поселение, здание Фастовского сельского клуба"	Россия, Волгоградская область, Иловлинский район, село Качалино	0101000020E61000001BD47E6B27084640D1B1834A5C8F4840
28114	2	22	917	51552	27232	\N	49.467062237162402	х. Каменский, сдание СДК	Россия, Волгоградская область, Иловлинский район, село Каменский	0101000020E610000096404AECDACC4540289A07B0C8BB4840
27819	2	22	917	7291	\N	\N	49.377401999999996	Дом отдыха, д.14, кв.14. Медпункт		0101000020E6100000725303CDE7104640F5B86FB54EB04840
27815	2	22	917	7291	\N	\N	49.308763999999996	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, здание Песчанского сельского клуба"	Россия, Волгоградская область, Иловлинский район, Иловля	0101000020E610000057B3CEF8BEFE45405017299485A74840
27814	2	22	917	7291	\N	\N	49.2949416265416	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, здание офиса ОАО ""КХ Егорова А.В."""	Россия, Волгоградская область, Иловлинский район, Иловля	0101000020E6100000A2EBC20FCEFD4540C11BD2A8C0A54840
27813	2	22	917	7291	\N	\N	49.297860624655698	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, здание Иловлинской средней школы №1"	Россия, Волгоградская область, Иловлинский район, Иловля	0101000020E6100000C45F9335EAFD45407EE02A4F20A64840
27812	2	22	917	7291	\N	\N	49.297299292366901	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, Здание Иловлинской средней школы №2"	Россия, Волгоградская область, Иловлинский район, Иловля	0101000020E6100000FC00A43671FE45401711C5E40DA64840
27810	2	22	917	7291	\N	\N	49.308763999999996	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, р.п.Иловля здание Центрального детского творчества"		0101000020E610000057B3CEF8BEFE45405017299485A74840
27809	2	22	917	7291	27151	\N	49.308763999999996	"Волгоградская область, муниципальное образование ""Иловлинский район"", Иловлинское городское поселение, р.п.Иловля пл. Ленина д.1"		0101000020E610000057B3CEF8BEFE45405017299485A74840
27647	2	22	917	51471	27077	\N	48.8021399214186	"Волгоградская область, Городищенский муниципальный район, р.п. Городище, площадь Павших Борцов, 2, МКУ ""Центр культурного обслужива"	Россия, Волгоградская область, Иловлинский район	0101000020E6100000B37C5D86FF3C46401F680586AC664840
27829	2	22	917	51576	\N	\N	49.453437690979598	"Волгоградская область, муниципальное образование ""Иловлинский район"", Большеивановское сельское поселение, здание Большеивановского сельского Дома культуры"	Россия, Волгоградская область, Иловлинский район, село Большая Ивановка	0101000020E6100000DC7F643A742A4640BF61A2410ABA4840
27828	2	22	917	51266	\N	\N	49.569684342867802	"Волгоградская область, муниципальное образование ""Иловлинский район"", Александровское сельское поселение, здание Александровского сельского Дома культуры"	Россия, Волгоградская область, Иловлинский район, село Александровка	0101000020E61000005F268A90BA274640F986C267EBC84840
27820	2	22	917	51537	\N	\N	49.375566795905101	"Волгоградская область, муниципальное образование ""Иловлинский район"", Авиловское сельское поселение, здание конторы ОАО ""КХ Егорова А.В."""	Россия, Волгоградская область, Иловлинский район, село Авилов	0101000020E61000007A522635B4014640793A579412B04840
14663	2	22	471	48757	26761	\N	50.663094000000001	с.Фоменково, Победы, 2		0101000020E61000005AF5B9DA8A5346404016A243E0544940
27789	2	22	471	6323	27211	\N	50.663083	с.Тетеревятка, Молодежная, 36	Россия, Волгоградская область, Жирновский район, село Тетеревятка	0101000020E610000012BF620D179146404CC45BE7DF544940
27804	2	22	471	7047	26392	\N	50.945599000000001	с.Тарапатино, Молодежная, 7	Россия, Волгоградская область, Жирновский район, село Тарапатино	0101000020E61000000E84640113464640AE10566309794940
14047	1	17	\N	3130	22523	\N	58.045848999999997	г. Рыбинск, Моторостроителей, 15		0101000020E6100000B3614D65516C4340F3C64961DE054D40
27793	2	22	471	6537	27159	\N	50.876835	п.Подчинный, Центральная, 3А	Россия, Волгоградская область, Жирновский район, село Подчинный	0101000020E61000000536E7E0999C46407C7E18213C704940
27796	2	22	471	6679	26611	\N	51.067400999999997	с.Песковка, Эльтонская, 27		0101000020E6100000A0DCB6EF517B4640DD5B9198A0884940
27794	2	22	471	49106	27246	\N	51.019106999999998	с.Новинка, Молодежная, 7		0101000020E6100000930035B56C914640F50F221972824940
27802	2	22	471	6983	27145	\N	51.095252000000002	с.Новая Бахметьевка, Зеленая, 42		0101000020E610000037C7B94DB86146407670B037318C4940
27751	2	22	471	4282	27256	\N	50.838039999999999	с.Нижняя Добринка, Центральная, 63		0101000020E6100000C9CA2F83315E4640B35E0CE5446B4940
27787	2	22	471	51632	27384	\N	50.655708447427699	х.Недоступов, Центральная, 28	Россия, Волгоградская область, Жирновский район, село Недоступов	0101000020E610000090BDDEFDF1724640DFDC5F3DEE534940
28032	2	22	471	49220	\N	\N	50.643866000000003	с.Моисеево, здание школы		0101000020E610000013EE9579AB6C4640D0807A336A524940
27723	2	22	471	2780	27137	\N	50.819800000000001	п.Мельзавод, Ленина, 6	Россия, Волгоградская область, Жирновский район, село Мельзавод	0101000020E6100000D192C7D3F257464062A1D634EF684940
27803	2	22	471	6997	26482	\N	50.879289999999997	с.Меловатка, Центральная, 35	Россия, Волгоградская область, Жирновский район, село Меловатка	0101000020E6100000CA8D226B0D59464094D920938C704940
27629	2	22	471	30181	27288	\N	50.781270999999997	р.п.Медведицкий, Фрунзе, 17		0101000020E6100000E7C41EDAC75A4640172829B000644940
27795	2	22	471	49127	\N	\N	51.076892000000001	с.Медведица, пос.Газовик, 35 А		0101000020E610000010069E7B0F6946407AA9D898D7894940
27605	2	22	471	45450	27038	\N	50.886405000000003	р.п.Линево, Нефтяников, 33	Россия, Волгоградская область, Жирновский район, поселок городского типа Линево	0101000020E61000005DE2C80391694640650113B875714940
27616	2	22	471	45450	26697	\N	50.886405000000003	р.п.Линево, Ленина, 66	Россия, Волгоградская область, Жирновский район, поселок Линево	0101000020E61000005DE2C80391694640650113B875714940
27571	2	22	471	45450	26375	\N	50.886405000000003	р.п.Линево, Карла Маркса, 70	Россия, Волгоградская область, Жирновский район, поселок Линево	0101000020E61000005DE2C80391694640650113B875714940
27212	2	22	471	48739	26996	\N	50.6953173665786	р.п.Красный Яр, Новая, 104А	Россия, Волгоградская область, Жирновский район, поселок городского типа Красный Яр	0101000020E61000007AA52C431C5D46402AADBF2500594940
27762	2	22	471	48739	27001	\N	50.696407566778298	р.п.Красный Яр, Ленина, 64	Россия, Волгоградская область, Жирновский район, поселок городского типа Красный Яр	0101000020E6100000F0FD0DDAAB5D46401D56B8E523594940
27379	2	22	471	48739	27079	\N	50.697716	р.п.Красный Яр, Камышинская, 2А	Россия, Волгоградская область, Жирновский район, поселок городского типа Красный Яр	0101000020E61000003B3AAE46765D4640AEF204C24E594940
27805	2	22	471	7101	26394	\N	51.134819999999998	с.Кленовка, Продольная, 3	Россия, Волгоградская область, Жирновский район, село Кленовка	0101000020E6100000D95DA0A4C03C4640616C21C841914940
27784	2	22	471	5911	26440	\N	50.978554000000003	г.Жирновск, Строителей, 12		0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27782	2	22	471	5911	26900	\N	50.978554000000003	г.Жирновск, Советская, 25	Россия, Волгоградская область, Жирновский район, Жирновск	0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27421	2	22	471	5911	26945	\N	50.978554000000003	г.Жирновск, Мира, 49		0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27781	2	22	471	5911	26808	\N	50.978554000000003	г.Жирновск, Матросова, 18		0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27786	2	22	471	5911	9848	\N	50.978554000000003	г.Жирновск, Ленина, 1А	Россия, Волгоградская область, Жирновский район, Жирновск	0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27783	2	22	471	5911	9848	\N	50.978554000000003	г.Жирновск, Ленина, 9	Россия, Волгоградская область, Жирновский район, Жирновск	0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27442	2	22	471	5911	26986	\N	50.978554000000003	г.Жирновск, 35 лет Победы, 4А		0101000020E610000014ECBFCE4D6546405CAFE941417D4940
27807	2	22	471	49292	27276	\N	51.151573999999997	с.Ершовка, Школьная, 18		0101000020E61000004B22FB20CB2846404276DEC666934940
27797	2	22	471	6711	27178	\N	51.147658999999997	с.Гречихино, Верхняя, 10/1		0101000020E61000008E78B29B19674640E3FA777DE6924940
27791	2	22	471	49071	26599	\N	50.760468000000003	с.Вишневое, Мира, 11		0101000020E6100000284696CCB1A04640C8D3F20357614940
27790	2	22	471	6357	27017	\N	50.779938000000001	с.Верхняя Добринка, Центральная, 74		0101000020E61000004B21904B1C8746402E742502D5634940
27912	2	22	471	6357	27239	\N	50.779938000000001	с.Верхняя Добринка, Рабочая, 23б		0101000020E61000004B21904B1C8746402E742502D5634940
27806	2	22	471	7141	26980	\N	51.061836999999997	с.Бутырка, Центральная, 2		0101000020E6100000B6696CAF053F464064575A46EA874940
27788	2	22	471	6239	26843	\N	50.655734000000002	с.Бородачи, Лиманская, 67		0101000020E610000087FBC8AD497B464009707A17EF534940
27801	2	22	471	6918	27043	\N	51.132859000000003	с.Большая Князевка, Мира, 1/2		0101000020E6100000A9674128EF5F464059FD118601914940
27799	2	22	471	49178	26701	\N	50.981859999999998	с.Андреевка, Мира, 4	Россия, Волгоградская область, Жирновский район, село Андреевка	0101000020E6100000FC5580EF3659464012A0A696AD7D4940
27792	2	22	471	6476	27037	\N	50.901159	с.Алешники, Центральная, 3А		0101000020E6100000BA6A9E23F29546407FBF982D59734940
27304	2	22	471	51652	27427	\N	51.0298063250778	Волгоградская область, Быковский муниципальный район, Александровское сельское поселение, Центральная, 37, Сельский Дом культуры	Россия, Волгоградская область, Жирновский район, село Александровка	0101000020E6100000C156091687614640BF9CD9AED0834940
27759	2	22	599	51510	\N	\N	51.041442403844997	"Волгоградская область, Еланский муниципальный район, Морецкое сельское поселение, х. Щелоковка, здание МОУ ""Щелоковская НОШ"""	Россия, Волгоградская область, Еланский район, село Щелоковка	0101000020E610000080D3BB783F0E46402657B1F84D854940
27760	2	22	599	51408	\N	\N	51.080016000000001	"Волгоградская область, Еланский муниципальный район, Морецкое сельское поселение, х. Хвощинка, здание МОУ ""Хвощинская ООШ"""	Россия, Волгоградская область, Еланский район, село Хвощинка	0101000020E6100000986DA7AD111546401094DBF63D8A4940
27774	2	22	599	5521	27204	\N	50.821348	Волгоградская область, Еланский муниципальный район, Тростянское сельское поселение, с. Тростянка, Советская, 27, здание Тростянского СДК	Россия, Волгоградская область, Еланский район, село Тростянка	0101000020E6100000423EE8D9ACBA4540485167EE21694940
27779	2	22	599	5783	26901	\N	51.033999999999999	"Волгоградская область, Еланский муниципальный район, Дубовское сельское поселение, с. Торяное, Боевая, 20, здание МОУ ""Торяновская НОШ"""		0101000020E61000000DFAD2DB9FC345403108AC1C5A844940
27768	2	22	599	5184	26982	\N	50.890256999999998	Волгоградская область, Еланский муниципальный район, Терсинское сельское поселение, с. Терса, Красная, 45, здание администрации		0101000020E610000005C1E3DBBBE645407D04FEF0F3714940
27754	2	22	599	4476	26469	\N	51.041629	Волгоградская область, Еланский муниципальный район, Терновское сельское поселение, с. Терновое, Ленина, 6, здание администрации	Россия, Волгоградская область, Еланский район, село Терновое	0101000020E6100000DE04DF347DDA454058C85C1954854940
27771	2	22	599	5370	27172	\N	50.607534999999999	Волгоградская область, Еланский муниципальный район, Еланское городское поселение, п. Таловка, Центральная, 13, здание Таловского СДК		0101000020E6100000E413B2F336C845407216F6B4C34D4940
27780	2	22	599	5822	26795	\N	50.909111000000003	Волгоградская область, Еланский муниципальный район, Родинское сельское поселение, с. Родинское, Ленинская, 6, здание администрации		0101000020E6100000325A475513B2454089B7CEBF5D744940
27874	2	22	599	46233	26965	\N	50.677349	хутор Новопетровский, ул.Солнечная, д.44. сельский клуб		0101000020E610000020B3B3E89DEA4540397D3D5FB3564940
27758	2	22	599	51493	\N	\N	51.031701479317903	"Волгоградская область, Еланский муниципальный район, Морецкое сельское поселение, х. Новодобринка, здание МОУ ""Новодобринская НОШ"""	Россия, Волгоградская область, Еланский район, село Новодобринка	0101000020E6100000077AA86DC3124640102043C70E844940
27753	2	22	599	4405	27085	\N	50.977300999999997	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, п. Набат, Пролетарская, 21, здание МОУ ""Набатская ООШ"""		0101000020E61000006E4C4F58E2DF45408EACFC32187D4940
27757	2	22	599	4629	26472	\N	51.018410000000003	"Волгоградская область, Еланский муниципальный район, Морецкое сельское поселение, с. Морец, Московская, 96, здание МОУ ""Морецкая СОШ"""		0101000020E6100000174A26A776024640AEF545425B824940
27772	2	22	599	51646	27412	\N	50.772641999999998	"Волгоградская область, Еланский муниципальный район, Тростянское сельское поселение, х. Красноталовский, Центральная, 48,здание МОУ ""Красноталовская СОШ"""	Россия, Волгоградская область, Еланский район, село Красноталовский	0101000020E6100000F7CC920035C345400DC2DCEEE5624940
27764	2	22	599	5017	26796	\N	50.840240999999999	Волгоградская область, Еланский муниципальный район, Краишевское сельское поселение, с. Краишево, Центральная, 4, здание Краишевского СДК		0101000020E610000055849B8C2AF7454011E15F048D6B4940
27775	2	22	599	5579	27175	\N	50.818565	Волгоградская область, Еланский муниципальный район, Ивановское сельское поселение, с. Ивановка, Мира, 59, здание администрации		0101000020E6100000713AC95697D345403B53E8BCC6684940
27767	2	22	599	5163	27274	\N	50.854959999999998	Волгоградская область, Еланский муниципальный район, Журавское сельское поселение, с. Журавка, Новосельская, 90а, здание администрации		0101000020E610000045D7851F9CED4540AFB14B546F6D4940
27800	2	22	599	5163	27529	\N	50.855396995461298	х.Журавка, Сорокина, 17/2		0101000020E6100000BA13ECBFCEED45405B0C1EA67D6D4940
27744	2	22	599	3785	26970	\N	50.946263000000002	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Школьная, 2,  здание МОУ ""СОШ № 2"""		0101000020E6100000070B2769FEE045401A355F251F794940
27748	2	22	599	3785	27054	\N	50.946263000000002	Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Первомайская, 1, здание ГУПВО автоколонны №1727		0101000020E6100000070B2769FEE045401A355F251F794940
27746	2	22	599	3785	26466	\N	50.946263000000002	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р. п. Елань, Мира, 1А, здание МУЗ ""Еланская ЦРБ"""	Россия, Волгоградская область, Еланский район, поселок Елань	0101000020E6100000070B2769FEE045401A355F251F794940
27743	2	22	599	3785	27073	\N	50.946263000000002	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р. п. Елань, Ленинская, 63,МОУ ДОД ""Еланский детский центр"""		0101000020E6100000070B2769FEE045401A355F251F794940
27741	2	22	599	3785	27073	\N	50.946263000000002	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Ленинская, 95, здание МУ РДК ""Юбилейный"""		0101000020E6100000070B2769FEE045401A355F251F794940
27747	2	22	599	3785	26956	\N	50.946263000000002	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Красная, 134,филФГОУ""Жирнов-ий нефтяной техн"	Россия, Волгоградская область, Еланский район, поселок Елань	0101000020E6100000070B2769FEE045401A355F251F794940
27742	2	22	599	3785	27166	\N	50.9439073485023	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Гоголя, 15, здание МОУ ""ООШ № 2"""		0101000020E6100000C64D0D349FDF454095BBCFF1D1784940
27737	2	22	348	48095	27068	\N	49.30874	с. Родники, Мира, 24 (Родниковсий сельский клуб)		0101000020E61000000D18247D5A754640C87BD5CA84A74840
27750	2	22	599	51415	27003	\N	50.946263000000002	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р. п. Елань, Новоселовская, 13, здание МОУ ДОД ""ДЮСШ"""	Россия, Волгоградская область, Еланский район, поселок городского типа Елань	0101000020E6100000070B2769FEE045401A355F251F794940
27752	2	22	599	51415	27088	\N	50.958139214026097	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Вокзальная, здание ЖДстанции""Елань-Камышинская"""	Россия, Волгоградская область, Еланский район, поселок городского типа Елань	0101000020E61000005A48C0E8F2E44540D6027B4CA47A4940
27749	2	22	599	51415	27088	\N	50.948362619642801	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Вокзальная, 2,  ГОУ ""Еланский аграрный колледж"""	Россия, Волгоградская область, Еланский район, поселок городского типа Елань	0101000020E610000015C8EC2C7AE1454044DE72F563794940
27745	2	22	599	51415	27112	\N	50.946263000000002	"Волгоградская область, Еланский муниципальный район, Еланское городское поселение, р.п. Елань, Большая Казанская, 61, здание МОУ ""ООШ № 1"""	Россия, Волгоградская область, Еланский район, поселок городского типа Елань	0101000020E6100000070B2769FEE045401A355F251F794940
27776	2	22	599	5613	26793	\N	50.965105999999999	"Волгоградская область, Еланский муниципальный район, Дубовское сельское поселение, с. Дубовое, Советская, 5, здание МОУ ""Дубовская СОШ"""		0101000020E6100000E065868DB2CE45403196E997887B4940
27765	2	22	599	5048	27300	\N	50.885945	"Волгоградская область, Еланский муниципальный район, Вязовское сельское поселение, с. Вязовка, Усадьба школы, 4, здание МОУ ""Вязовская СОШ"""		0101000020E61000006AA33A1DC8F84540018750A566714940
27766	2	22	599	5048	27183	\N	50.885945	Волгоградская область, Еланский муниципальный район, Вязовское сельское поселение, с. Вязовка, Мельничная, 1Б, здание Вязовского СДК		0101000020E61000006AA33A1DC8F84540018750A566714940
27777	2	22	599	5690	27263	\N	50.992184999999999	Волгоградская область, Еланский муниципальный район, Дубовское сельское поселение, с. Волково, Новая, 1, фельдшерско-акушерский пункт		0101000020E6100000A5A14621C9CA4540774A07EBFF7E4940
27756	2	22	599	4582	27065	\N	51.043990999999998	"Волгоградская область, Еланский муниципальный район, Березовское сельское поселение, с. Водопьяново, Центральная, 11/2,""Фельдшерско-акушерский пункт"""		0101000020E6100000F9D687F546EF4540BF28417FA1854940
27763	2	22	599	4929	26978	\N	50.920901000000001	Волгоградская область, Еланский муниципальный район, Большеморецкое сельское поселение, с. Большой Морец, Советская, 39, здание администрации		0101000020E6100000E4F4F57CCDEC454046ED7E15E0754940
27770	2	22	599	5291	27171	\N	50.642766025548703	Волгоградская область, Еланский муниципальный район, Большевистское сельское поселение, п. Большевик, Микрорайон-1, 10, здание Большевистского СДК	Россия, Волгоградская область, Еланский район, село Большевик	0101000020E6100000909F8D5C37E14540897D022846524940
27755	2	22	599	4486	26892	\N	51.063862999999998	Волгоградская область, Еланский муниципальный район, Березовское сельское поселение, с. Березовка, Молодежная, 45, здание Березовского СДК	Россия, Волгоградская область, Еланский район, село Березовка	0101000020E6100000B08D78B29BF545405436ACA92C884940
27761	2	22	599	4486	27259	\N	51.063862999999998	Волгоградская область, Еланский муниципальный район, Рассветовское сельское поселение, с. Березовка, Ленина, 187, здание Рассветовского СДК	Россия, Волгоградская область, Еланский район, село Березовка	0101000020E6100000B08D78B29BF545405436ACA92C884940
27778	2	22	599	5744	27264	\N	51.017186000000002	"Волгоградская область, Еланский муниципальный район, Дубовское сельское поселение, с. Бабинкино, Веселая, 4, здание МОУ ""Бабинкинская ООШ"""	Россия, Волгоградская область, Еланский район, село Бабинкино	0101000020E61000005C9198A086C745407BF99D2633824940
27769	2	22	599	51679	27493	\N	50.758433501983397	Волгоградская область, Еланский муниципальный район, Алявское сельское поселение, х. Алявы, Степная, 42, здание администрации	Россия, Волгоградская область, Еланский район, село Алявы	0101000020E61000001EFB592C45DE45405516855D14614940
27739	2	22	348	51684	27506	\N	49.042818790612998	х. Челюскинец, Центральная, 41 (Челюскинский сельский клуб)	Россия, Волгоградская область, Дубовский район, село Челюскинец	0101000020E61000002EAEF199EC534640DF52CE177B854840
27727	2	22	348	3015	26873	\N	49.476953000000002	с. Усть-Погожье, Кленовая, 1 (МОУ Усть-Погожинская СОШ)	Россия, Волгоградская область, Дубовский район, село Усть-Погожье	0101000020E610000011A96917D34E4640535DC0CB0CBD4840
27728	2	22	348	3020	\N	\N	49.487693	ст. Суводская, Центральная, 13 (Суводской СДК)		0101000020E6100000C2340C1F118746407BBE66B96CBE4840
27725	2	22	348	2903	27237	\N	49.309280999999999	с. Стрельноширокое, Советская, 34 (МОУ Стрельношироковская СОШ)	Россия, Волгоградская область, Дубовский район, село Стрельноширокое	0101000020E6100000B4AA251DE57846401823128596A74840
27956	2	22	348	46858	\N	\N	49.517032921797302	с.Семеновка, здание Семеновской школы	Россия, Волгоградская область, Дубовский район, село Семеновка	0101000020E6100000172EABB019504640F4F928232EC24840
27736	2	22	348	48065	26456	\N	49.185833000000002	с. Садки, х. Спартак, Центральная, 15 (МОУ Садковская ООШ)	Россия, Волгоградская область, Дубовский район, село Садки	0101000020E6100000E466B8019F35464040C23060C9974840
27733	2	22	348	3366	26653	\N	49.633999000000003	с. Полунино, Комсомольская, 41 (МОУ Полунинская ООШ)		0101000020E6100000A46DFC89CA7446402E5915E126D14840
27720	2	22	348	2592	26838	\N	48.986953999999997	с. Пичуга, Степная, 29 (Пичужинская МОУ СОШ)		0101000020E6100000B9162D40DB5A464004543882547E4840
27740	2	22	348	2592	26787	\N	48.986953999999997	с. Пичуга, ВЛС, Песчанная, 5 (ФАП ВЛС с. Пичуга)	Россия, Волгоградская область, Дубовский район, село Пичуга	0101000020E6100000B9162D40DB5A464004543882547E4840
27738	2	22	348	48118	27247	\N	49.447519	с. Петропавловка, Большая, 28 (СК с. Петропавловка)	Россия, Волгоградская область, Дубовский район, село Петропавловка	0101000020E6100000D3A57F492A43464058AB764D48B94840
27721	2	22	348	51267	26407	\N	49.113377	с. Песковатка, Московская, 27 (МОУ Песковатская СОШ)	Россия, Волгоградская область, Дубовский район, село Песковатка	0101000020E61000003C84F1D3B86D46402E8F3523838E4840
27722	2	22	348	47806	26752	\N	49.179302999999997	с. Оленье, Центральная, 13 (Оленьевский СДК)	Россия, Волгоградская область, Дубовский район, село Оленье	0101000020E6100000AB3E575BB16F46408F899466F3964840
27403	2	22	348	19499	27136	\N	49.356886000000003	с. Малая Ивановка, Центральная, 25 (Малоивановский  СДК)		0101000020E610000072C5C551B94346403C33C170AEAD4840
27705	2	22	348	1739	26952	\N	49.287889999999997	с. Лозное, Гагарина, 2 (Лозновский СДК)	Россия, Волгоградская область, Дубовский район, село Лозное	0101000020E6100000B284B53176364640376C5B94D9A44840
27731	2	22	348	3230	26872	\N	49.725340000000003	с. Караваинка, Центральная, 12 (Административное здание)	Россия, Волгоградская область, Дубовский район, село Караваинка	0101000020E6100000AF21382EE39C4640863DEDF0D7DC4840
27711	2	22	348	1882	26616	\N	49.052433999999998	"г. Дубовка, Юбилейная, 44 (Дубовский ""Райпотребсоюз"")"		0101000020E61000003750E09D7C68464067994528B6864840
27709	2	22	348	1882	26616	\N	49.052433999999998	г. Дубовка, Юбилейная, 115		0101000020E61000003750E09D7C68464067994528B6864840
27719	2	22	348	1882	26836	\N	49.052433999999998	г. Дубовка, Шевченко, 2 (Межпоселковый СОК)		0101000020E61000003750E09D7C68464067994528B6864840
27714	2	22	348	1882	26769	\N	49.052433999999998	г. Дубовка, Советская, 62 (МОУ Дубовская СОШ №1)		0101000020E61000003750E09D7C68464067994528B6864840
27717	2	22	348	1882	26950	\N	49.052433999999998	г. Дубовка, Пугачева, 17 (Дубовское ХПП)		0101000020E61000003750E09D7C68464067994528B6864840
27718	2	22	348	1882	26941	\N	49.052433999999998	г. Дубовка, Почтовая, 52 (Дубовская МОУ СОШ №2)		0101000020E61000003750E09D7C68464067994528B6864840
27710	2	22	348	1882	26617	\N	49.052433999999998	"г. Дубовка, Магистральная, 10 (ФГОУ СПО ""ДЗВК"")"		0101000020E61000003750E09D7C68464067994528B6864840
27716	2	22	348	1882	26625	\N	49.052433999999998	"г. Дубовка, Гагарина, 143(МОУ ООШ ""Базовая школа"")"		0101000020E61000003750E09D7C68464067994528B6864840
27712	2	22	348	1882	27228	\N	49.052433999999998	г. Дубовка, 30 лет Победы, дом 81, 81		0101000020E61000003750E09D7C68464067994528B6864840
27645	2	22	348	46252	26541	\N	49.298214000000002	с. Давыдовка, Школьная, 1 (МОУ Давыдовская СОШ)	Россия, Волгоградская область, Дубовский район, село Давыдовка	0101000020E61000008F6E844545524640CC9A58E02BA64840
27730	2	22	348	3128	26390	\N	49.554350999999997	с. Горный Балыклей, Пушкина, 18 (МОУ Горнобалыклейская СОШ)		0101000020E6100000797764AC36894640A0C03BF9F4C64840
27729	2	22	348	3128	26944	\N	49.554350999999997	с. Горный Балыклей, Крестьянская, 2 (МУК Горнобалыклейский СДК)	Россия, Волгоградская область, Дубовский район, село Горный Балыклей	0101000020E6100000797764AC36894640A0C03BF9F4C64840
27724	2	22	348	2797	26942	\N	49.255367	с. Горноводяное, Школьный переулок, 4 (МОУ Горноводяновская СОШ)		0101000020E6100000E222F7747577464023BDA8DDAFA04840
27726	2	22	348	2937	27236	\N	49.381811999999996	с. Горная Пролейка, Школьная, 1 (МОУ Горнопролейская СОШ)		0101000020E61000008350DEC7D17C4640349C3237DFB04840
27732	2	22	348	3384	26398	\N	49.686365000000002	с. Варькино, Центральная, 11 (клуб с. Варькино)		0101000020E61000007B319413ED8846403D0FEECEDAD74840
27735	2	22	348	51452	27058	\N	49.217084569856702	х. Бойкие Дворики, Конторская, 25 (Сельский клуб х. Бойкие Дворики		0101000020E610000001A777F17E4A4640E0B9F770C99B4840
27693	2	22	145	1030	\N	\N	50.234333999999997	Волгоградская область, Даниловский муниципальный район, ст.Сергиевская, здание ДК		0101000020E61000001DE90C8CBCE44540A12B11A8FE1D4940
27700	2	22	145	51334	\N	\N	50.174335432593502	Волгоградская область, Даниловский муниципальный район, х.Рогачи, здание селького клуба	Россия, Волгоградская область, Даниловский район, село Рогачи	0101000020E610000099D53BDC0E1346402AC6F99B50164940
27686	2	22	145	593	\N	\N	50.496921999999998	Волгоградская область, Даниловский муниципальный район, п.Профсоюзник, здание МСОШ		0101000020E6100000FD4D2844C0E94540DA54DD239B3F4940
27703	2	22	145	51262	\N	\N	50.370522762004803	Волгоградская область, Даниловский муниципальный район, х.Попов, здание селького клуба	Россия, Волгоградская область, Даниловский район, село Попов	0101000020E6100000BCCADAA67836464039B5334C6D2F4940
27690	2	22	145	51347	\N	\N	50.290881036920297	Волгоградская область, Даниловский муниципальный район, х.Плотников, здание средней школы	Россия, Волгоградская область, Даниловский район, село Плотников 1-й	0101000020E6100000008E3D7B2EF945408E03AF963B254940
27702	2	22	145	51483	\N	\N	50.4319061559397	Волгоградская область, Даниловский муниципальный район, ст.Островская, здание ДК	Россия, Волгоградская область, Даниловский район, село Островская	0101000020E610000029CDE671183646401C7920B248374940
27689	2	22	145	807	\N	\N	50.474375000000002	Волгоградская область, Даниловский муниципальный район, с.Орехово, здание ДК		0101000020E6100000DE7536E49F3546401F85EB51B83C4940
27684	2	22	145	480	\N	\N	50.424813	Волгоградская область, Даниловский муниципальный район, с.Миусово, здание сельского клуба		0101000020E61000008B3386394107464034F5BA4560364940
19449	2	21	\N	3394	57070	\N	46.407294999999998	г. Астрахань, ул. 1-я Железнодорожная, дом 10		0101000020E6100000588D25AC8D0948408369183E22344740
27697	2	22	145	51336	\N	\N	50.310525983144501	Волгоградская область, Даниловский муниципальный район, Березовское сельское поселение, х.Ловягин	Россия, Волгоградская область, Даниловский район, село Ловягин	0101000020E6100000062AE3DF670646406347E350BF274940
27687	2	22	145	691	\N	\N	50.460178999999997	Волгоградская область, Даниловский муниципальный район, с.Лобойково, здание ДК		0101000020E6100000992D5915E11A46402AA73D25E73A4940
27701	2	22	145	51393	\N	\N	50.1914507002002	Волгоградская область, Даниловский муниципальный район, х.Кувшинов, здание селького клуба	Россия, Волгоградская область, Даниловский район, село Кувшинов	0101000020E61000000FF0A485CB1E4640ACE4637781184940
27698	2	22	145	51391	\N	\N	50.333802833954003	Волгоградская область, Даниловский муниципальный район, х.Красный, здание ДК	Россия, Волгоградская область, Даниловский район, село Красный	0101000020E6100000718E3A3AAE1046404227840EBA2A4940
27704	2	22	145	51335	\N	\N	50.379401136546797	Волгоградская область, Даниловский муниципальный район, х.Каменный, здание школы	Россия, Волгоградская область, Даниловский район, село Каменный	0101000020E610000000E5EFDE512B4640EC88433690304940
27688	2	22	145	51509	\N	\N	50.410174552852197	Волгоградская область, Даниловский муниципальный район, х.Каменночерновский, здание сельского клуба	Россия, Волгоградская область, Даниловский район, село Каменночерновский	0101000020E6100000037976F9D61D46408351499D80344940
27694	2	22	145	51306	\N	\N	50.213788000000001	Волгоградская область, Даниловский муниципальный район, х.Заполянский, здание сельского клуба	Россия, Волгоградская область, Даниловский район, село Заполянский	0101000020E6100000F64201DBC1E445407D23BA675D1B4940
27692	2	22	145	51332	\N	\N	50.379583798080603	Волгоградская область, Даниловский муниципальный район, х.Заплавка, здание школы	Россия, Волгоградская область, Даниловский район, село Заплавка	0101000020E6100000069CA56439F94540DD0A613596304940
27683	2	22	145	51692	27527	\N	50.359690999999998	Волгоградская область, Даниловский муниципальный район, городское поселение р.п. Даниловка, Комсомольская, 1	Россия, Волгоградская область, Даниловский район, поселок городского типа Даниловка	0101000020E6100000C311A452EC0E464030D5CC5A0A2E4940
27682	2	22	145	28213	26754	\N	50.347606305587597	Волгоградская область, Даниловский муниципальный район, городское поселение р.п. Даниловка, Федорцова, 28	Россия, Волгоградская область, Даниловский район, поселок Даниловка	0101000020E6100000363E93FDF30E46405AF2785A7E2C4940
27707	2	22	145	1850	\N	\N	50.700831000000001	Волгоградская область, Даниловский муниципальный район, с.Грязнуха, здание школы	Россия, Волгоградская область, Даниловский район, село Грязнуха	0101000020E61000004CC45BE7DF044640F18288D4B4594940
27695	2	22	145	51325	\N	\N	50.2646193918794	Волгоградская область, Даниловский муниципальный район, х.Горин, здание сельского клуба	Россия, Волгоградская область, Даниловский район, село Горин	0101000020E6100000000341800CEF45403B730F09DF214940
28285	2	22	145	51346	\N	\N	50.456745012219002	х. Гончары, Гончаровская МНОШ		0101000020E6100000130B7C45B7FA454046CEC29E763A4940
27685	2	22	145	51346	\N	\N	50.458388812275501	Волгоградская область, Даниловский муниципальный район, х.Гончары, здание сельского клуба	Россия, Волгоградская область, Даниловский район, село Гончары	0101000020E6100000792288F370FA45404EECA17DAC3A4940
27691	2	22	145	51258	\N	\N	50.319361000000001	Волгоградская область, Даниловский муниципальный район, х.Бобры, здание школы	Россия, Волгоградская область, Даниловский район, село Бобры	0101000020E6100000B804E09F52014640164F3DD2E0284940
27696	2	22	145	1200	\N	\N	50.265431999999997	Волгоградская область, Даниловский муниципальный район, ст.Березовская, здание ДК	Россия, Волгоградская область, Даниловский район, село Березовская	0101000020E610000030F488D173FD4540EBA7FFACF9214940
27706	2	22	145	51288	\N	\N	50.572966000000001	Волгоградская область, Даниловский муниципальный район, п.Белые Пруды, здание школы	Россия, Волгоградская область, Даниловский район, село Белые Пруды	0101000020E6100000513239B53304464027DC2BF356494940
27699	2	22	145	51333	\N	\N	50.169294999999998	Волгоградская область, Даниловский муниципальный район, х.Атамановка, здание ДК	Россия, Волгоградская область, Даниловский район, село Атамановка	0101000020E610000051A2258FA70946402B306475AB154940
27671	2	22	3	51717	27648	\N	48.878442	Волгоградская область, Городищенский муниципальный район, поселок Царицын, Центральная, 13, помещение Дом культуры		0101000020E61000004014CC988217464067B796C970704840
27864	2	22	3	31935	27324	\N	48.850735646509399	хутор Степной, ул.Центральная, д.64 А. Средне-Царицынская ООШ	Россия, Волгоградская область, Городищенский район, село Степной	0101000020E61000000B462575021C4640D2C3D0EAE46C4840
27665	2	22	3	31935	27118	\N	48.850687000000001	Волгоградская область, Городищенский  муниципальный район, поселок Степной, Центральная, 5, помещение Дом культуры	Россия, Волгоградская область, Городищенский район, село Степной	0101000020E61000008446B071FD1B4640F110C64FE36C4840
27675	2	22	3	32368	26935	\N	48.949196000000001	Волгоградская область, Городищенский муниципальный район, поселок Самофаловка, Советская, 22А, помещение Дом культуры		0101000020E61000007ADE8D05851B46403CBF28417F794840
19323	2	21	\N	57122	57062	\N	46.387785999999998	Астраханская область, Наримановский район. с.Солянка, Советская, 129А		0101000020E6100000960854FF200248405FECBDF8A2314740
27678	2	22	3	5	27203	\N	49.050811000000003	Волгоградская область, Городищенский муниципальный район, поселок Сады Придонья, Специалистов, 41, Культурно-развлекательный центр		0101000020E61000009581035ABA02464077A38FF980864840
27666	2	22	3	32007	26563	\N	48.828415	Волгоградская область, Городищенский муниципальный район, село Россошка, Рабочая, 26, павильон для приезжающих		0101000020E6100000AB7B6473D51246400742B280096A4840
27668	2	22	3	51369	26830	\N	48.8416093631824	Волгоградская область, Городищенский муниципальный район, поселок Радужный, 2-я Продольная, 132, помещение Правление ТСЖ	Россия, Волгоградская область, Городищенский район, село Новая Надежда	0101000020E6100000CB4DD4D2DC2646407782FDD7B96B4840
27681	2	22	3	306	26782	\N	48.907324000000003	Волгоградская область, Городищенский муниципальный район, хутор Песковатка, Спортивная, 14, помещение Дом культуры		0101000020E610000006BD378600E845401E705D3123744840
27679	2	22	3	166	27131	\N	49.037418000000002	Волгоградская область, Городищенский муниципальный район, хутор Паньшино, переулок Советский, 2, помещение Дом культуры		0101000020E61000002DB0C7444A0346401024EF1CCA844840
27656	2	22	3	31539	27193	\N	48.847283710520799	Волгоградская область, Городищенский муниципальный район, Орловка село, Советская, 1Б, средняя школа Орловская	Россия, Волгоградская область, Городищенский район, село Орловка	0101000020E6100000166EF9484A444640483657CD736C4840
27672	2	22	3	51622	27359	\N	48.885172303418699	Волгоградская область, Городищенский муниципальный район, поселок Областной опытной сельскохозяйственной станции, Молодежная, 51, помещение Дом культуры	Россия, Волгоградская область, Городищенский район, село Областная сельскохозяйственная опытная станция	0101000020E610000077A22424D2304640DEAAEB504D714840
27663	2	22	3	31777	26826	\N	48.675075999999997	Волгоградская область, Городищенский  муниципальный район, р.п. Новый Рогачик, Озерная, 2, средняя школа (правое крыло)	Россия, Волгоградская область, Городищенский район, поселок Новый Рогачик	0101000020E610000056D4601A860746404128EFE368564840
27662	2	22	3	31777	26826	\N	48.675075999999997	Волгоградская область, Городищенский  муниципальный район, р.п. Новый Рогачик, Озерная, 2, средняя школа (левое крыло)		0101000020E610000056D4601A860746404128EFE368564840
27661	2	22	3	31777	26744	\N	48.675075999999997	Волгоградская область, Городищенский  муниципальный район, р.п. Новый Рогачик, Ленина, 54, помещение администрации поселка		0101000020E610000056D4601A860746404128EFE368564840
27667	2	22	3	32023	26564	\N	48.839996999999997	Волгоградская область, Городищенский муниципальный район, поселок Новая Надежда, Центральная, 1, средняя школа Новонадеждинская		0101000020E610000004E5B67D8F2646407ADE8D05856B4840
27673	2	22	3	32282	26580	\N	48.916052000000001	Волгоградская область, Городищенский муниципальный район, поселок Кузьмичи, Нефтянников, 1, помещение Дом культуры	Россия, Волгоградская область, Городищенский район, село Кузьмичи	0101000020E6100000AA6400A8E22E4640BBB7223141754840
27669	2	22	3	51713	27625	\N	48.803287723685202	Волгоградская область, Городищенский муниципальный район, хутор Красный Пахарь, Новосельская, 18, помещение Дом культуры	Россия, Волгоградская область, Городищенский район, село Красный Пахарь	0101000020E6100000354069A8511E464077A22424D2664840
27676	2	22	3	32436	27029	\N	49.022348999999998	Волгоградская область, Городищенский муниципальный район, поселок Котлубань, Шлихтера, 17, помещение Дом культуры	Россия, Волгоградская область, Городищенский район, село Котлубань	0101000020E61000004301DBC1881D4640950C0055DC824840
27664	2	22	3	31917	26561	\N	48.705860000000001	Волгоградская область, Городищенский  муниципальный район, село Карповка, 51 Гвардейской дивизии, 5А, средняя школа Карповская		0101000020E6100000C11BD2A8C0FD4540FCC6D79E595A4840
27660	2	22	3	31717	26822	\N	48.981732999999998	Волгоградская область, Городищенский  муниципальный район, поселок Каменный, Ленина, 6, средняя школа Каменская		0101000020E6100000757632384A484640B5334C6DA97D4840
27658	2	22	3	31580	27297	\N	48.936622	Волгоградская область, Городищенский муниципальный район, р.п. Ерзовка, Школьная, 2, средняя школа Ерзовская		0101000020E6100000541EDD088B524640685BCD3AE3774840
27657	2	22	3	31580	26734	\N	48.936622	Волгоградская область, Городищенский муниципальный район, р.п. Ерзовка, Молодежная, 4 квартал, 1, музыкальная школа		0101000020E6100000541EDD088B524640685BCD3AE3774840
27659	2	22	3	51499	27138	\N	48.934758464846901	403030 Волгоградская область, Городищенский муниципальный район, Ерзовское городское поселение Мелиоративная 2, помещение Администрации поселка	Россия, Волгоградская область, Городищенский район, поселок городского типа Ерзовка	0101000020E610000094A5D6FB8D52464052D66F26A6774840
27876	2	22	3	51617	27479	\N	48.996484602746698	хутор Донской, ул.Центральная, д.10. МОУ Донская НОШ	Россия, Волгоградская область, Городищенский район, село Донской	0101000020E6100000408864C8B1FB45402FFA0AD28C7F4840
27674	2	22	3	51630	27382	\N	48.955074260089802	Волгоградская область, Городищенский муниципальный район, хутор Грачи, Ленина, 35, помещение Дом культуры	Россия, Волгоградская область, Городищенский район, село Грачи	0101000020E6100000F2B22616F826464045A165DD3F7A4840
19070	2	21	\N	57134	57169	\N	47.911368000000003	Астраханская область, Ахтубинский район, село Сокрутовска, Калинина, 37		0101000020E61000009D6516A1D84447407B4FE5B4A7F44740
27653	2	22	3	51703	27560	\N	48.802333936739799	"Волгоградская область, Городищенский муниципальный район,  р.п. Городище 2, Баррикадная, 2Б,  дом культуры ""Разгуляевка"""		0101000020E6100000C2C073EFE13C4640043C69E1B2664840
27644	2	22	3	30858	26991	\N	48.801262000000001	Волгоградская область, Городищенский муниципальный район, р.п. Городище, проспект им. Ленина, 8, помещение музея		0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27643	2	22	3	30858	26989	\N	48.801262000000001	Волгоградская область, Городищенский муниципальный район, р.п. Городище, площадь 40-лет Сталинградской битвы, 3, помещение Школы Исскуств		0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27642	2	22	3	30858	26780	\N	48.801262000000001	Волгоградская область, Городищенский муниципальный район, р.п.Городище, площадь 40 лет Сталинградской битвы, 3, районный Дворец культуры		0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27646	2	22	3	30858	26994	\N	48.801262000000001	Волгоградская область, Городищенский муниципальный район, р.п. Городище, Чуйкова, 6А, помещение Средняя школа №1		0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27649	2	22	3	30858	27111	\N	48.801262000000001	Волгоградская область, Городищенский муниципальный район, р.п. Городище, Центральная, 101, помещение ИП Казарян		0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27648	2	22	3	30858	27076	\N	48.803419722020301	"Волгоградская область, Городищенский муниципальный район, р.п. Городище, Промышленная, 2А, помещение кафе ""Дворик"""		0101000020E6100000A391CF2B9E3C4640E6797077D6664840
27651	2	22	3	30858	26813	\N	48.801262000000001	Волгоградская область, Городищенский муниципальный район, р.п. Городище, Пархоменко, 35А, помещение Средняя школа №2		0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27650	2	22	3	30858	26993	\N	48.801262000000001	"Волгоградская область, Городищенский муниципальный район, р.п. Городище, Октябрьская, 1а, помещение ""Казпромволга"""		0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27655	2	22	3	30858	26924	\N	48.801262000000001	Волгоградская область, Городищенский муниципальный район, р.п. Городище 2, Новоселовская, 2, помещение Средняя школа №3	Россия, Волгоградская область, Городищенский район, поселок Городище	0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27652	2	22	3	30858	26817	\N	48.801262000000001	"Волгоградская область, Городищенский муниципальный район, р.п. Городище, Краснознаменская, 54, помещение базы ООО ""Энергострой"	Россия, Волгоградская область, Городищенский район, поселок Городище	0101000020E6100000A837A3E6AB3E464087C3D2C08F664840
27654	2	22	3	30858	27216	\N	48.802713439135701	Волгоградская область, Городищенский муниципальный район, р.п. Городище 2, Демократическая, 35, продовольственный магазин		0101000020E61000000873BB97FB3C46407A89B14CBF664840
27680	2	22	3	195	26748	\N	48.943114000000001	Волгоградская область, Городищенский муниципальный район, хутор Вертячий, Мира, 58, помещение Дом культуры		0101000020E6100000596ABDDF68F345402B33A5F5B7784840
27677	2	22	3	51683	27505	\N	49.026752722981001	Волгоградская область, Городищенский муниципальный район, хутор Варламов, Центральная, 15, средняя школа Варламовская		0101000020E61000002C4833164D294640F2086EA46C834840
27641	2	22	1901	30725	26883	\N	48.875188999999999	Волгоградская область, городской округ город Волжский, пос. Краснооктябрьский им. Калинина улица, 1	Россия, Волгоградская область, Волжский городской округ, поселок Краснооктябрьский	0101000020E6100000950D6B2A8B604640D368723106704840
27670	2	22	1923	32172	27314	\N	48.715359999999997	Волгоградская область, Городищенский муниципальный район, село Студено-Яблоневка, Заречная, 10, помещение Дом культуры	Россия, Волгоградская область, Волгоград городской округ, село Студено-Яблоневка	0101000020E61000006C97361C962E4640EB6E9EEA905B4840
27448	2	22	1923	51494	\N	\N	48.438608422999202	Волгоградская область, город Волгоград, Красноармейский район, п.Соляной, (МОУ ООШ №79)	Россия, Волгоградская область, Волгоград городской округ, село Соляной	0101000020E6100000CF2EDFFAB0384640CAE1934E24384840
27556	2	22	1923	51522	27181	\N	48.546861	"Волгоградская область, город Волгоград, поселок Майский, Лундышева, 1а, контора ФГУП ""Горная Поляна"""	Россия, Волгоградская область, Волгоград городской округ, село Майский	0101000020E6100000A5315A47551746409B3A8F8AFF454840
27555	2	22	1923	51474	27087	\N	48.582276999999998	Волгоградская область, город Волгоград, поселок Горный, Семушкина, 1, МОУ СОШ №116	Россия, Волгоградская область, Волгоград городской округ, село Горный	0101000020E6100000DFA63FFB911E4640431B800D884A4840
28353	2	22	1346	46646	26657	\N	49.744030000000002	село Солянка, Центральная, 18		0101000020E610000001C3F2E7DBB04640179F02603CDF4840
27317	2	22	1346	51604	27317	\N	49.529868999999998	Волгоградская область, Быковский муниципальный район, Солдатско-Степновское сельское поселение, Мира, 50,Адм-ция Солдат-Степновского с.п	Россия, Волгоградская область, Быковский район, село Солдатско-Степное	0101000020E6100000DDB6EF517FC14640051555BFD2C34840
27316	2	22	1346	51647	27416	\N	49.677586614693197	Волгоградская область, Быковский муниципальный район, Садовское сельское поселение, Садовая, 2, Садовский Дом культуры	Россия, Волгоградская область, Быковский район, село Садовое	0101000020E610000060CD018239F64640EE98BA2BBBD64840
27303	2	22	1346	48570	26835	\N	49.766216	"п. Раздолье, Центральная, 25, МОУ ""Раздольевская ООШ"""		0101000020E6100000253D0CAD4EBA464002D6AA5D13E24840
15168	5	43	29	785	71106	\N	51.316695000000003	с. Турата, Елеусова, 22		0101000020E61000008104C58F3131554043E7357689A84940
27314	2	22	1346	51673	27812	\N	49.268779320572001	Волгоградская область, Быковский муниципальный район, Приморское сельское поселение, Пионерская, 6, МОУ Приморская СОШ		0101000020E61000008179C8940F854640016DAB5967A24840
27315	2	22	1346	51673	27485	\N	49.262193000000003	Волгоградская область, Быковский муниципальный район, Приморское сельское поселение, Горького, 18, Приморский Дом культуры	Россия, Волгоградская область, Быковский район, поселок городского типа Приморск	0101000020E61000004E9D47C5FF834640BD1E4C8A8FA14840
27313	2	22	1346	51660	27453	\N	49.649990687616302	Волгоградская область, Быковский муниципальный район, Побединское сельское поселение, Центральная, 10, МОУ Побединская СОШ	Россия, Волгоградская область, Быковский район, село Победа	0101000020E6100000DF701FB935BB4640E0D8B3E732D34840
28373	2	22	1346	51363	\N	\N	49.880895543027599	хутор Песчаный, зд. админ.Песчановского с/п	Россия, Волгоградская область, Быковский район, село Песчаный	0101000020E6100000A1F2AFE595BB4640AF963B33C1F04840
27312	2	22	1346	51653	27431	\N	49.195554000000001	Волгоградская область, Быковский муниципальный район, Новоникольское сельское поселение, Шурухина, 44, Сельский Дом культуры	Россия, Волгоградская область, Быковский район, село Новоникольское	0101000020E6100000514CDE00338146400E4DD9E907994840
27311	2	22	1346	51619	27353	\N	49.348728875605303	Волгоградская область, Быковский муниципальный район, Луговопролейское сельское поселение, Советская, 60,Адм-ция Луго-кого сельского пос	Россия, Волгоградская область, Быковский район, село Луговая Пролейка	0101000020E610000034F8FBC56C8946405915E126A3AC4840
27310	2	22	1346	51613	27346	\N	49.662802634265503	Волгоградская область, Быковский муниципальный район, Красносельцевское сельское поселение, пер. Центральный, 5, Красносельский Дом культуры	Россия, Волгоградская область, Быковский район, село Красноселец	0101000020E6100000E10CFE7E31DF464068588CBAD6D44840
27308	2	22	1346	51486	27103	\N	49.889931029011102	Волгоградская область, Быковский муниципальный район, Кисловское сельское поселение, Советсксая, 8а,Кисловский сельский Дом культуры	Россия, Волгоградская область, Быковский район, село Кислово	0101000020E6100000F9F4D89601B1464029594E42E9F14840
27309	2	22	1346	51486	27537	\N	49.887610120246102	"Волгоградская область, Быковский муниципальный район, Кисловское сельское поселение, Песчаная, 27,Сельский Дом культуры ""Источник"""	Россия, Волгоградская область, Быковский район, село Кислово	0101000020E6100000AC3B16DBA4B0464021CD58349DF14840
27318	2	22	1346	51424	27012	\N	49.384112407304698	Волгоградская область, Быковский муниципальный район, Урало-Ахтубинское сельское поселение, Шмарова, 9, МОУ Урало-Ахтубинская СОШ	Россия, Волгоградская область, Быковский район, село Катричев	0101000020E610000055DE8E705AC646402600FF942AB14840
27307	2	22	1346	51473	27083	\N	49.614341461656998	"Волгоградская область, Быковский муниципальный район, Зеленовское сельское поселение, Сереневая, 5, МОУ ""Быковская СОШ № 2"""	Россия, Волгоградская область, Быковский район, село Зеленый	0101000020E61000003F90BC7328AD4640C5CBD3B9A2CE4840
28278	2	22	1346	49438	26768	\N	49.912744000000004	п. Заволжский, Совхозная, 23		0101000020E61000000F4240BE84BC464064CF9ECBD4F44840
27306	2	22	1346	51686	27515	\N	49.226186856791699	Волгоградская область, Быковский муниципальный район, Демидовское сельское поселение, Советская, 35, МОУ Демидовская СОШ	Россия, Волгоградская область, Быковский район, село Демидов	0101000020E61000002AFD84B35BAF4640E3E313B2F39C4840
27305	2	22	1346	51715	27635	\N	49.535670180870099	Волгоградская область, Быковский муниципальный район, Верхнебалыклейское сельское поселение, Советская, 16, Сельский Дом культуры	Россия, Волгоградская область, Быковский район, село Верхний Балыклей	0101000020E610000071E657738096464063B9A5D590C44840
27300	2	22	1346	51470	27504	\N	49.765034999999997	"Волгоградская область, Быковский муниципальный район, Быковское городское поселение, пер. Набережный, 9, Дом культуры ""Строитель"""		0101000020E61000001990BDDEFDB14640CEA5B8AAECE14840
27302	2	22	1346	51470	27075	\N	49.765034999999997	Волгоградская область, Быковский муниципальный район, Быковское городское поселение, Загодзерновская, 17, ОАО Быковское ХПП	Россия, Волгоградская область, Быковский район, поселок городского типа Быково	0101000020E61000001990BDDEFDB14640CEA5B8AAECE14840
27299	2	22	1346	51470	27507	\N	49.765034999999997	"Волгоградская область, Быковский муниципальный район, Быковское городское поселение, Дзержинского, 95а, Детский сад ""Солнышко"""	Россия, Волгоградская область, Быковский район, поселок городского типа Быково	0101000020E61000001990BDDEFDB14640CEA5B8AAECE14840
27297	2	22	1346	51470	27315	\N	49.764426009931	Волгоградская область, Быковский муниципальный район, Быковское городское поселение, Волжская, 37, Центр культуры и досуга	Россия, Волгоградская область, Быковский район, поселок городского типа Быково	0101000020E610000004E78C28EDB14640261B0FB6D8E14840
27298	2	22	1346	51470	27422	\N	49.765034999999997	Волгоградская область, Быковский муниципальный район, Быковское городское поселение, Мира, 23а, МОУ Быковская СОШ № 1	Россия, Волгоградская область, Быковский район, поселок городского типа Быково	0101000020E61000001990BDDEFDB14640CEA5B8AAECE14840
19522	2	21	\N	3394	57080	\N	46.315897	г.Астрахань, ул.Чкалова, д.31		0101000020E6100000DF88EE59D7FA4740C7F319506F284740
27301	2	22	1346	51708	27603	\N	49.765034999999997	"Волгоградская область, Быковский муниципальный район, Быковское городское поселение, Строителей, 11, ФГУ ""Волгоградмеливодхоз"""		0101000020E61000001990BDDEFDB14640CEA5B8AAECE14840
27961	2	22	1346	40257	\N	\N	49.796706999999998	с.Александровка, здание Александровской школы		0101000020E6100000478E740646D2464044BFB67EFAE54840
27798	2	22	1346	40257	9651	\N	49.795744117592903	с.Александровка, Центральная, 49	Россия, Волгоградская область, Быковский район, село Александровка	0101000020E6100000B01D8CD827D246407EFE7BF0DAE54840
27260	2	22	521	12512	27191	\N	50.321857000000001	хутор Яминский, переулок Веселый, 10	Россия, Волгоградская область, Алексеевский район, село Яминский	0101000020E610000058ACE122F71A45408D7E349C32294940
27287	2	22	521	13761	\N	\N	50.199264999999997	хутор Шарашенский, здание МОУ Шарашенская средняя общеобразовательная школа, 242		0101000020E6100000917EFB3A70584540641EF98381194940
27280	2	22	521	13416	\N	\N	50.272531000000001	хутор Чечеровский, здание МОУ Чечеринская начальная общеобразовательная школа, 73А		0101000020E6100000AC70CB4752204540B612BA4BE2224940
27289	2	22	521	13837	26827	\N	50.185822999999999	станица Усть-Бузулукская, Хоперская, 35,Б		0101000020E610000098DBBDDC271345401CEC4D0CC9174940
27293	2	22	521	14042	\N	\N	50.075882	"хутор Трехложинский, здание МУК ""Трехложинский культурно-досуговый комплекс"", 60"		0101000020E6100000D3DC0A6135064540732D5A80B6094940
27290	2	22	521	13889	\N	\N	50.178294999999999	"хутор Титовский, здание МУК ""Титовский культурно-досуговый комплекс"", 66"	Россия, Волгоградская область, Алексеевский район, село Титовский	0101000020E61000006B7F677BF42045402905DD5ED2164940
27281	2	22	521	13476	\N	\N	50.288684000000003	хутор Стеженский, Здание МОУ Стеженская средняя общеобразовательная школа, 101	Россия, Волгоградская область, Алексеевский район, село Стеженский	0101000020E610000036AFEAAC161245407270E998F3244940
27288	2	22	521	51540	\N	\N	50.177817631451703	хутор Солонцовский, здание МОУ Солонцовуская средняя общеобразовательная школа, 147	Россия, Волгоградская область, Алексеевский район, село Солонцовский	0101000020E6100000417FA1478C344540F0517FBDC2164940
27282	2	22	521	13485	\N	\N	50.370010999999998	"хутор Самолшинский, здание МУК ""Самолшинский культурно-досуговый комплекс"", 72"		0101000020E6100000328E91EC1108454083143C855C2F4940
27295	2	22	521	51330	\N	\N	50.010505000000002	хутор Рябовский, здание МОУ Рябовская средняя общеобразовательная школа, 383	Россия, Волгоградская область, Алексеевский район, село Рябовский	0101000020E6100000BDAB1E300FF14440E5B8533A58014940
27294	2	22	521	14066	\N	\N	50.178063999999999	"хутор Реченский, здание МУК ""Реченский культурно-досуговый комплекс"", 56"		0101000020E6100000DA1EBDE13E044540274C18CDCA164940
27283	2	22	521	13563	\N	\N	50.404052	хутор Поклоновский, здание МОУ Поклоновская основная общеобразовательная школа, 5	Россия, Волгоградская область, Алексеевский район, село Поклоновский	0101000020E61000003A03232F6B12454013F1D6F9B7334940
27279	2	22	521	13352	\N	\N	50.242313000000003	хутор Ларинский, здание администрации Ларинского сельского поселения, 72	Россия, Волгоградская область, Алексеевский район, село Ларинский	0101000020E61000003561FBC9181F4540A532C51C041F4940
27286	2	22	521	48284	\N	\N	50.3255215897629	"поселок Красный Октябрь, здание МУК ""Краснооктябрьский культурно-досуговый компкекс"", 73"	Россия, Волгоградская область, Алексеевский район, село Красный Октябрь	0101000020E6100000AC38D55A98434540731074B4AA294940
27284	2	22	521	13610	\N	\N	50.469358999999997	"хутор Исакиевский, здание МУК ""Исакиевский культурно-досуговый комплекс"", 52"		0101000020E6100000DF6FB4E386194540A88AA9F4133C4940
27959	2	22	521	14178	\N	\N	49.9918954115698	х.Ежовка, здание сельского Дома культуры	Россия, Волгоградская область, Алексеевский район, село Ежовка	0101000020E6100000F6ED2422FCD944407008556AF6FE4840
27296	2	22	521	14178	\N	\N	49.991895	хутор Ежовка, здание МОУ Ежовская основная общеобразовательная школа, 31		0101000020E6100000AFCDC64ACCD944407008556AF6FE4840
27285	2	22	521	13643	\N	\N	50.370204162167902	хутор Большой Бабинский, здание администрации Большебабинского сельского поселения, 17/2	Россия, Волгоградская область, Алексеевский район, село Большой Бабинский	0101000020E6100000A65F22DE3A214540986C3CD8622F4940
27291	2	22	521	13927	\N	\N	50.116078999999999	"станица Аржановская, здание МУК ""Аржановский культурно-досуговый комплекс"", 116"		0101000020E6100000349C3237DF2C45404E603AADDB0E4940
27251	2	22	521	47387	26802	\N	50.296728999999999	станица Алексеевская, Ленина, 44		0101000020E610000070287CB60E1845402C634337FB254940
27239	2	22	521	47387	26802	\N	50.296728999999999	станица Алексеевская, Ленина, 37		0101000020E610000070287CB60E1845402C634337FB254940
19395	2	21	\N	57104	56867	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, Советскаяё, 151		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19387	2	21	\N	57104	56928	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, С.Перовской, 103		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19392	2	21	\N	57104	56927	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, Ленина, 18		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19386	2	21	\N	57104	56869	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, Интернациональная, 156		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19393	2	21	\N	57104	57127	\N	47.406958375115003	Астраханская область, Харабалинский район, Город Харабали, Б.Хмельницкого, 5		0101000020E6100000696E85B01AA147403C6C223317B44740
19506	2	21	\N	3394	56990	\N	46.319687999999999	г.Астрахань, ул.Чигорина, д.14А		0101000020E6100000871744A4A6FF47403A765089EB284740
19249	2	21	\N	57136	57179	\N	45.960133999999996	Астраханская область, Камызякский район, с.Образцово-Травино, Восточная, 5		0101000020E6100000BCCCB051D6FF47408AE3C0ABE5FA4640
19349	2	21	\N	57113	56924	\N	46.691741	Астраханская область, Наримановский район, г.Нариманов, Центральная, 3		0101000020E6100000E92B483316ED4740B32616F88A584740
19351	2	21	\N	57113	56923	\N	46.691741	Астраханская область, Наримановский район, г.Нариманов, Волжская, 6А		0101000020E6100000E92B483316ED4740B32616F88A584740
19350	2	21	\N	57113	56950	\N	46.691741	Астраханская область, Наримановский район, г.Нариманов, Астраханская, 9		0101000020E6100000E92B483316ED4740B32616F88A584740
19205	2	21	\N	57131	57157	\N	45.775463000000002	Астраханская область, Икрянинский район, село Мумра, Ленина, 20		0101000020E61000005ABC581822D547400821205F42E34640
19261	2	21	\N	57133	57165	\N	46.534711000000001	Астраханская область, Красноярский район, с.Красный Яр, Карла Маркса, 19А		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19211	2	21	\N	57109	57187	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, Молодежная, 32		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19215	2	21	\N	57109	56903	\N	46.1042566419165	Астраханская область, Камызякский район, г.Камызяк, М. Горького, 67	Россия, Астраханская область, Камызякский район, Камызяк	0101000020E6100000C7F2AE7AC00A484085B01A4B580D4740
19214	2	21	\N	57109	57119	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, им.А.П. Гужвина, 1		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19100	2	21	\N	15786	\N	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, микр.Мелиораторов, 4А		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19091	2	21	\N	15786	56893	\N	48.275419680875501	Астраханская область, Ахтубинский район, Город Ахтубинск, пл.Ленина, 1	Россия, Астраханская область, Ахтубинск	0101000020E6100000E75432005417474008556AF640234840
19097	2	21	\N	15786	56844	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Шоссе авиаторов, 5		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19087	2	21	\N	15786	56941	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Финогенова, 11А		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19103	2	21	\N	15786	56938	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Суворова, 1		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19095	2	21	\N	15786	56849	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Ст.Лаврентьева, 6		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19101	2	21	\N	15786	57152	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, П.О.Сухого, 4		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19086	2	21	\N	15786	56936	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Октябрьская, 81		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19092	2	21	\N	15786	56958	\N	48.280676243592502	Астраханская область, Ахтубинский район, Город Ахтубинск, Нестерова, 5	Россия, Астраханская область, Ахтубинск	0101000020E6100000D7506A2FA2154740D462F030ED234840
19102	2	21	\N	15786	56898	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Мира, 47А	Россия, Астраханская область, Ахтубинск	0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19089	2	21	\N	15786	56889	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Микрорайон-1, 9а	Россия, Астраханская область, Ахтубинск	0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19099	2	21	\N	15786	56937	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Котовского, 9		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19098	2	21	\N	15786	56937	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Котовского, 28		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19096	2	21	\N	15786	56841	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Конструкторская, 1А	Россия, Астраханская область, Ахтубинск	0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19019	2	21	\N	15786	57142	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, К.Маркса, 125		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19094	2	21	\N	15786	56895	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Иванова, 2		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19093	2	21	\N	15786	56895	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Иванова, 6А		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
18763	2	21	\N	15786	57138	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Заводская, 187		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19088	2	21	\N	15786	56888	\N	48.2702603888021	Астраханская область, Ахтубинский район, Город Ахтубинск, Добролюбова, 5	Россия, Астраханская область, Ахтубинск	0101000020E61000008AADA069891747405FB532E197224840
19085	2	21	\N	15786	56890	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Волгоградская, 41		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19084	2	21	\N	15786	56890	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Волгоградская, 4	Россия, Астраханская область, Ахтубинск	0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
18937	2	21	\N	15786	56967	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Величко, 10		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19090	2	21	\N	15786	56899	\N	48.273240000000001	Астраханская область, Ахтубинский район, Город Ахтубинск, Андреева, 6А		0101000020E6100000EB8CEF8B4B174740C2FA3F87F9224840
19429	2	21	\N	3394	56985	\N	46.346532000000003	г.Астрахань, Чалабяна, 17		0101000020E6100000F818AC38D50648403D821B295B2C4740
19544	2	21	\N	3394	57025	\N	46.411259000000001	414026, г.Астрахань, ул.Химиков, д.7		0101000020E6100000342BDB87BCFD4740C4978922A4344740
19362	2	21	\N	3394	15652	\N	46.301124999999999	Астраханская область, Приволжский район, п.Новоначаловский, Шоссейная, 23	Россия, Астраханская область, Астрахань, Трусовский район, улица Шоссейная, 15/10к1	0101000020E61000008F6FEF1AF4F94740068195438B264740
19196	2	21	\N	3394	1339	\N	46.344914000000003	г.Астрахань, Челюскинцев, 132	Россия, Астраханская область, Астрахань, улица Челюскинцев, 132	0101000020E6100000AFCDC64ACC0548405EF75624262C4740
19452	2	21	\N	3394	4781	\N	46.401690000000002	г. Астрахань, ул. Туркменская, дом 30	Россия, Астраханская область, Астрахань, улица Туркменская, 30	0101000020E6100000C310397D3D0B4840AC90F2936A334740
19468	2	21	\N	3394	4978	\N	46.377901000000001	г. Астрахань, ул. Татищева, дом 20А	Россия, Астраханская область, Астрахань, улица Татищева, 20а	0101000020E6100000425BCEA5B806484017105A0F5F304740
19514	2	21	\N	3394	16363	\N	46.282592999999999	г.Астрахань, ул.Таганская, д.36	Россия, Астраханская область, Астрахань, Трусовский район, улица Таганская, 36а	0101000020E610000061FC34EECDF747400D8AE6012C244740
19540	2	21	\N	3394	5846	\N	46.401373	г.Астрахань, ул.Староастраханская, д.92/97А	Россия, Астраханская область, Астрахань, улица Староастраханская, 90	0101000020E61000003927F6D03E004840AB3FC23060334740
19425	2	21	\N	3394	4475	\N	46.343440000000001	г.Астрахань, Сен-Симона, 31	Россия, Астраханская область, Астрахань, улица Сен-Симона, 31	0101000020E610000081EB8A19E1014840B21188D7F52B4740
94955	2	21	\N	3394	16858	\N	46.364941999999999	г. Астрахань, ул. Полякова д. 19	Россия, Астраханская область, Астрахань, улица Полякова, 19	0101000020E61000003BE12538F5054840EA77616BB62E4740
19370	2	21	\N	3394	56983	\N	46.261026000000001	Астраханская область, Приволжский район, с.Карагали, Пионерская, 48		0101000020E61000003271AB2006FE4740EEB3CA4C69214740
19512	2	21	\N	3394	57035	\N	46.388227000000001	г. Астрахань, ул.Пионерская, д.2А		0101000020E6100000BAA46ABB090248404C361E6CB1314740
19511	2	21	\N	3394	5517	\N	46.270415	г.Астрахань, ул.Панфилова, д.36	Россия, Астраханская область, Астрахань, улица Панфилова, 36	0101000020E61000005ABC581822FB474086AC6EF59C224740
19528	2	21	\N	3394	5712	\N	46.352037000000003	г.Астрахань, ул.Лепехинская, д.49	Россия, Астраханская область, Астрахань, улица Лепехинская, 49	0101000020E61000007EFD101B2CFE4740B1FD648C0F2D4740
19430	2	21	\N	3394	4542	\N	46.356211000000002	414040, г.Астрахань, ул. Куликова 61	Россия, Астраханская область, Астрахань, улица Куликова, 61	0101000020E6100000F032C34659094840DCBC7152982D4740
19426	2	21	\N	3394	4490	\N	46.344889000000002	г.Астрахань, Костина, 2	Россия, Астраханская область, Астрахань, улица Костина, 2	0101000020E6100000F981AB3C8102484005E09F52252C4740
19476	2	21	\N	3394	5079	\N	46.340578000000001	г.Астрахань, ул.Звездная, д.59, корп.1	Россия, Астраханская область, Астрахань, улица Звездная, 59к1	0101000020E610000067463F1A4E09484059DE550F982B4740
19523	2	21	\N	3394	5648	\N	46.338599000000002	414016, г.Астрахань, .пл. Заводская, 98	Россия, Астраханская область, Астрахань, улица Заводская Площадь, 98	0101000020E6100000A6D425E318FD4740AABA4736572B4740
19500	2	21	\N	3394	5281	\N	46.331543000000003	г.Астрахань, ул.Боевая, д.59А	Россия, Астраханская область, Астрахань, улица Боевая, 59а	0101000020E610000022C2BF081A034840DF1B4300702A4740
19493	2	21	\N	3394	5281	\N	46.329901	г.Астрахань, ул.Боевая, д.65А		0101000020E6100000B37C5D86FF02484077F52A323A2A4740
19503	2	21	\N	3394	5381	\N	46.335189999999997	г.Астрахань, ул.Б.Хмельницкого, д.16, корп.1	Россия, Астраханская область, Астрахань, улица Богдана Хмельницкого, 16к1	0101000020E61000009ACC785BE90148401EF98381E72A4740
19501	2	21	\N	3394	5381	\N	46.3353852972608	г.Астрахань, ул.Б.Хмельницкого, д.35, корп.1	Россия, Астраханская область, Астрахань, улица Богдана Хмельницкого, 35	0101000020E6100000FAB9A1293B034840D4484BE5ED2A4740
18286	2	21	\N	3394	5483	\N	46.314528000000003	г.Астрахань, ул.Безжонова, д.2	Россия, Астраханская область, Астрахань, улица Безжонова, 2	0101000020E61000001F8656276700484091D6187442284740
19494	2	21	\N	3394	5300	\N	46.325313999999999	г.Астрахань, ул.3-я Рыбацкая, д.5	Россия, Астраханская область, Астрахань, улица 3-я Рыбацкая, 5	0101000020E610000031CD74AF9304484029779FE3A3294740
19462	2	21	\N	3394	57075	\N	46.367716000000001	г. Астрахань, ул. Яблочкова, дом 28		0101000020E61000005456D3F544094840A41B6151112F4740
19450	2	21	\N	3394	57046	\N	46.408861000000002	г. Астрахань, ул. Энергетическая, дом 13 корп.1		0101000020E610000031CF4A5AF10B484010CEA78E55344740
19456	2	21	\N	3394	57022	\N	46.367567000000001	г. Астрахань, ул. Щукина, дом 79		0101000020E6100000AEBB79AA430E48405F0B7A6F0C2F4740
19322	2	21	\N	3394	57302	\N	46.339030262395298	Астраханская область, Наримановский район, п.Караагаш, Школьная, 24	Россия, Астраханская область, Астрахань, Наримановский микрорайон, улица Школьная	0101000020E610000053211E8997FB4740732EC555652B4740
19363	2	21	\N	3394	57240	\N	46.333170819743998	Астраханская область, Приволжский район, п.Садовый, Школьная, 4	Россия, Астраханская область, Астрахань, Садовый микрорайон	0101000020E610000057975302620C4840E17CEA58A52A4740
19343	2	21	\N	3394	57202	\N	46.344022185956497	416101, Астраханская область, Наримановский район, п.Трусово, Школьная, 2	Россия, Астраханская область, Астрахань, улица Центральная	0101000020E61000004A9BAA7B64F94740618DB3E9082C4740
18827	2	21	\N	3394	56879	\N	46.3487557070181	г.Астрахань, Шелгунова, 12	Россия, Астраханская область, Астрахань, улица Чернышевского	0101000020E6100000E6CAA0DAE004484053245F09A42C4740
18805	2	21	\N	3394	16270	\N	46.346245000000003	г.Астрахань, пл.Шаумяна, 1А	Россия, Астраханская область, Астрахань, Кировский район, Шаумяна площадь, 1а	0101000020E61000007D40A03369034840A7B393C1512C4740
18849	2	21	\N	3394	56976	\N	46.345947000000002	г.Астрахань, Шаумяна, 60	Россия, Астраханская область, Астрахань, улица Шаумяна, 60	0101000020E610000060E7A6CD380548401D93C5FD472C4740
19521	2	21	\N	3394	57072	\N	46.308129000000001	г.Астрахань, ул.Чкалова, д.80А		0101000020E6100000D25625917DFA47407FF964C570274740
19543	2	21	\N	3394	57025	\N	46.410024468381899	г.Астрахань, ул.Химиков, д.5А	Россия, Астраханская область, Астрахань, улица Химиков, 3	0101000020E61000008C834BC79CFD47409D499BAA7B344740
19492	2	21	\N	3394	56973	\N	46.310798039445402	г.Астрахань, ул.Фунтовское шоссе, д.9А	Россия, Астраханская область, Астрахань, Фунтовское шоссе, 9а	0101000020E61000006A4C88B9A4044840C3D4963AC8274740
19545	2	21	\N	3394	57054	\N	46.416037000000003	г.Астрахань, ул.Тренева, д.11		0101000020E6100000CE70033E3FFE474086764EB340354740
19532	2	21	\N	3394	56935	\N	46.360779553946699	г.Астрахань, ул.Л.Толстого, д.26	Россия, Астраханская область, Астрахань, улица Толстого	0101000020E6100000B8AD2D3C2F0148408386FE092E2E4740
19471	2	21	\N	3394	57063	\N	46.371105	г. Астрахань, ул. Татищева, дом 8А		0101000020E610000091F12895F0064840E8305F5E802F4740
19470	2	21	\N	3394	57063	\N	46.371105	г. Астрахань, ул. Татищева, дом 8		0101000020E6100000EC134031B2064840E8305F5E802F4740
19469	2	21	\N	3394	57063	\N	46.375346	г. Астрахань, ул. Татищева, дом 16		0101000020E61000005B5F24B4E50648409B5775560B304740
19515	2	21	\N	3394	57073	\N	46.281950999999999	г. Астрахань, ул. Таганская, 34		0101000020E610000045847F1134F8474089096AF816244740
19513	2	21	\N	3394	57037	\N	46.281700008225201	г. Астрахань, ул.Таганская, д.36	Россия, Астраханская область, Астрахань, Трусовский район, улица Таганская	0101000020E6100000C078060DFDF7474040A4DFBE0E244740
94954	2	21	\N	3394	56874	\N	46.346051286382703	414004, г.Астрахань,ул. Студенческая, 6/1	Россия, Астраханская область, Астрахань, улица Шаумяна	0101000020E61000000F09DFFB1B044840C2DF2F664B2C4740
19439	2	21	\N	3394	56874	\N	46.349635999999997	г.Астрахань, Студенческая, 4А		0101000020E61000005DE15D2EE20348408BC058DFC02C4740
19438	2	21	\N	3394	56874	\N	46.349635999999997	г.Астрахань, Студенческая, 6 корп.1		0101000020E61000005DE15D2EE20348408BC058DFC02C4740
19533	2	21	\N	3394	5775	\N	46.367106999999997	г.Астрахань, пер. Спортивный, 2		0101000020E6100000DAAD65321C014840FB90B75CFD2E4740
19446	2	21	\N	3394	57056	\N	46.346848999999999	г.Астрахань, С.Перовской, 103 корп.25		0101000020E6100000187959130B0A48403DD34B8C652C4740
19454	2	21	\N	3394	57019	\N	46.382415000000002	г. Астрахань, ул. Соликамская, дом 8		0101000020E61000001938A0A52B0C4840FB3F87F9F2304740
19341	2	21	\N	3394	57307	\N	46.337167532692398	Астраханская область, Наримановский район, с.Биштюбинка, Советская, 58	Россия, Астраханская область, Астрахань, Биштюбинка микрорайон	0101000020E6100000DE21C50089FA4740FDA02E52282B4740
19380	2	21	\N	3394	57201	\N	46.3238887956676	Астраханская область, Приволжский район, с.Кулаковка, Советская, 19	Россия, Астраханская область, Астрахань, Кулаковка микрорайон	0101000020E610000017467A51BB0948405F44DB3175294740
19428	2	21	\N	3394	57001	\N	46.3490281615722	"г. Астрахань, ул.Советская, 23. ФГБОУ ВПО «Астраханская государственная консерватория (академия)»"		0101000020E61000001B67D311C0054840B3B112F3AC2C4740
19552	2	21	\N	3394	57086	\N	46.461869999999998	г.Астрахань, ул.Силикатная, д.26		0101000020E61000002A711DE38AFB47407380608E1E3B4740
19474	2	21	\N	3394	56972	\N	46.367584999999998	г. Астрахань, ул. Ю. Селенского, дом 15А	Россия, Астраханская область, Астрахань, улица Селенского, 13	0101000020E61000004696CCB1BC05484005C078060D2F4740
19460	2	21	\N	3394	57061	\N	46.361758982981797	414011 пос. Мошаик, ул. Садовских, 3	Россия, Астраханская область, Астрахань, улица Садовских	0101000020E6100000FB5B02F04F1148404F04711E4E2E4740
19491	2	21	\N	3394	57049	\N	46.315815999999998	г.Астрахань, ул.Рождественского, д.4		0101000020E6100000656EBE11DD054840DAC69FA86C284740
19531	2	21	\N	3394	56993	\N	46.3611774092277	г.Астрахань, ул.Пушкина, д.2	Россия, Астраханская область, Астрахань, улица Пушкина	0101000020E610000050711C78B5004840A088450C3B2E4740
19550	2	21	\N	3394	57032	\N	46.441837973443903	г.Астрахань, ул.Промышленная, д.3	Россия, Астраханская область, Астрахань, улица Промышленная	0101000020E6100000029A081B9EFC4740A510C8258E384740
14691	2	21	\N	3394	57078	\N	46.354692999999997	г.Астрахань, Победы, 52		0101000020E6100000739CDB847B074840608F8994662D4740
19530	2	21	\N	3394	57021	\N	46.355757018647402	г.Астрахань, ул.Пирогова, д.39		0101000020E6100000EA059FE6E4FF47405A290472892D4740
19510	2	21	\N	3394	57071	\N	46.280169999999998	г.Астрахань, ул.Немова, д.28, корп.2		0101000020E6100000E161DA37F7FB474000A94D9CDC234740
19447	2	21	\N	3394	4728	\N	46.347476999999998	г.Астрахань, Началовское шоссе, 5/1	Россия, Астраханская область, Астрахань, Началовское шоссе, 5	0101000020E6100000FDBFEAC8910C48405C8E57207A2C4740
19539	2	21	\N	3394	56978	\N	46.398873961243098	г.Астрахань, ул.Нанайская, д.23	Россия, Астраханская область, Астрахань, улица Нанайская	0101000020E6100000FA42C879FF014840C39CA04D0E334740
19424	2	21	\N	3394	56932	\N	46.335638000000003	г.Астрахань, Наб.Прив.затона, 36	Россия, Астраханская область, Астрахань, улица Набережная Приволжского Затона, 32	0101000020E610000010CD3CB9A6004840BEA59C2FF62A4740
19489	2	21	\N	3394	57064	\N	46.335344999999997	г.Астрахань, ул.Н.Островского, д.111		0101000020E61000003D2828452B05484045F0BF95EC2A4740
19483	2	21	\N	3394	57064	\N	46.335313999999997	г.Астрахань, ул.Н.Островского, д.127		0101000020E610000095B54DF1B80648400AF2B391EB2A4740
19479	2	21	\N	3394	57064	\N	46.336993999999997	г.Астрахань, ул.Н.Островского, д.152, корп.1		0101000020E6100000E8A1B60DA30848405F79909E222B4740
18816	2	21	\N	3394	56880	\N	46.350444000000003	г.Астрахань, М.Гвардии, 3	Россия, Астраханская область, Астрахань, улица Молодой Гвардии, 3	0101000020E6100000EDD79DEE3C0548402B8A5759DB2C4740
19325	2	21	\N	3394	3183	\N	46.329675999999999	Астраханская область, Наримановский район, п.Мирный, 70 лет Октября, 21	Россия, Астраханская область, Астрахань, Мирный переулок, 19	0101000020E61000002D5E2C0C910148405723BBD2322A4740
19534	2	21	\N	3394	56998	\N	46.361092999999997	г.Астрахань, ул.Минина, д.54		0101000020E6100000D5B32094F7FF474042E8A04B382E4740
19551	2	21	\N	3394	57083	\N	46.457194999999999	г.Астрахань, ул.Мелиоративная, д.2В		0101000020E6100000D50627A25FFB47408672A25D853A4740
19548	2	21	\N	3394	56982	\N	46.391845000000004	г.Астрахань, ул.Магистральная, д.1		0101000020E61000008176871403004840F20C1AFA27324740
17903	2	21	\N	3394	57044	\N	46.359768000000003	г.Астрахань, 11 Красной Армии, 3		0101000020E6100000E3C3EC65DB094840DC12B9E00C2E4740
19487	2	21	\N	3394	56878	\N	46.3280187999936	г.Астрахань, ул.М.Луконина, д.6А	Россия, Астраханская область, Астрахань, Советский район	0101000020E6100000E9465854C4054840BABBCE86FC294740
19472	2	21	\N	3394	57058	\N	46.358997000000002	г. Астрахань, ул. Ляхова, дом 11		0101000020E61000001C5F7B66490648405A2E1B9DF32D4740
19488	2	21	\N	3394	56876	\N	46.326346999999998	г.Астрахань, ул.М.Луконина, д.4А	Россия, Астраханская область, Астрахань, улица Луконина, 4а	0101000020E610000023BA675DA3054840E8120EBDC5294740
19537	2	21	\N	3394	5802	\N	46.362157643490697	414038, г.Астрахань, пер.Ленинградский, д.55	Россия, Астраханская область, Астрахань, Ленинградский переулок	0101000020E6100000D219187959FF47400DFE7E315B2E4740
19536	2	21	\N	3394	5802	\N	46.362895999999999	г.Астрахань, пер.Ленинградский, д.55		0101000020E6100000FF942A51F6FE4740B3EC4960732E4740
19047	2	21	\N	3394	16332	\N	46.346823999999998	ЗАТО Знаменск, площадь Ленина, д.2	Россия, Астраханская область, Астрахань, Кировский район, Ленина площадь, 2	0101000020E61000008D09319754034840E4BB94BA642C4740
19360	2	21	\N	3394	57051	\N	46.347788000000001	Астраханская область, Приволжский район, с.Началово, Ленина, 48		0101000020E6100000A7AFE76B960548407BF83251842C4740
18838	2	21	\N	3394	57204	\N	46.348057906015697	г.Астрахань, Ленина, 17	Россия, Астраханская область, Астрахань, Кировский район, улица Ленина, 17/21	0101000020E6100000FF25A94C310548403B8E1F2A8D2C4740
19379	2	21	\N	3394	56981	\N	46.3274217677059	Астраханская область, Приволжский район, с.Три Протока, Ленина, 95	Россия, Астраханская область, Астрахань, Три Протока микрорайон	0101000020E61000009C8713984E0F4840D6FECEF6E8294740
19340	2	21	\N	3394	57052	\N	46.324686	Астраханская область, Наримановский район, с.Старокучергановка, Ленина, 58		0101000020E61000004CA7751BD4FA47400ABC934F8F294740
19435	2	21	\N	3394	56975	\N	46.348104999999997	г.Астрахань, Курская, 55		0101000020E61000000E15E3FC4D0848407B4963B48E2C4740
19444	2	21	\N	3394	57043	\N	46.354213999999999	г.Астрахань, Куликова, 46А		0101000020E6100000D1B01875AD09484086E464E2562D4740
19432	2	21	\N	3394	57043	\N	46.355289999999997	г.Астрахань, Куликова, 42		0101000020E610000020F12BD670094840444C89247A2D4740
19431	2	21	\N	3394	57043	\N	46.354998000000002	г.Астрахань, Куликова, 40		0101000020E610000006BAF605F40848409D121093702D4740
19490	2	21	\N	3394	57079	\N	46.323023999999997	г.Астрахань, ул.Краснодарская, д.43, корп.1		0101000020E610000062687572860448405BE9B5D958294740
19437	2	21	\N	3394	56896	\N	46.342306481658703	414004, г.Астрахань, ул. Кр. Набережная 227а	Россия, Астраханская область, Астрахань, Красная набережная, 227	0101000020E6100000D2E28C614E084840BF9CD9AED02B4740
19212	2	21	\N	3394	56896	\N	46.355321000000004	г.Астрахань, Кр.Набережная, 11	Россия, Астраханская область, Астрахань, Красная набережная, 7к1	0101000020E6100000D2E0B6B6F0044840804A95287B2D4740
18991	2	21	\N	3394	57095	\N	46.343079000000003	г.Астрахань, Котовского, 6		0101000020E610000094A46B26DF024840E2783E03EA2B4740
19480	2	21	\N	3394	57077	\N	46.332158999999997	г.Астрахань, ул.Космонавтов, д.10, корп.1		0101000020E6100000666A12BC210748403909A52F842A4740
19459	2	21	\N	3394	57010	\N	46.355998999999997	г. Астрахань, ул. Косм. В. Комарова, дом 154А		0101000020E610000043C6A354C20F484050340F60912D4740
19458	2	21	\N	3394	57010	\N	46.356471999999997	г. Астрахань, ул. Косм. В. Комарова, дом 53		0101000020E610000019575C1C950D484048F8DEDFA02D4740
19457	2	21	\N	3394	57010	\N	46.355413329465897	г. Астрахань, ул. Косм. В. Комарова, дом 25	Россия, Астраханская область, Астрахань, улица Космонавта В. Комарова	0101000020E6100000081C0934D80C484060C9552C7E2D4740
19473	2	21	\N	3394	56957	\N	46.371205695292403	г. Астрахань, ул. Ком. Набережная, дом 7А	Россия, Астраханская область, Астрахань, улица Комсомольская Набережная, 7а	0101000020E610000000581D39D20548401C0A9FAD832F4740
19339	2	21	\N	3394	57200	\N	46.326508380390599	Астраханская область, Наримановский район, с.Старокучергановка, Комсомольская, 99	Россия, Астраханская область, Астрахань, Старокучергановка микрорайон, улица Комсомольская	0101000020E6100000D862B7CF2AFB4740F1F09E03CB294740
19525	2	21	\N	3394	57068	\N	46.346587999999997	414015, г.Астрахань, ул. Комсомольская, 142		0101000020E610000093533BC3D4FE4740D097DEFE5C2C4740
19475	2	21	\N	3394	57038	\N	46.358164000000002	г. Астрахань, ул. Коммунистическая, дом 48		0101000020E6100000861DC6A4BF054840624D6551D82D4740
19291	2	21	\N	3394	57038	\N	46.356583999999998	г.Астрахань, Коммунистическая, 35		0101000020E61000006745D4449F0548407023658BA42D4740
19104	2	21	\N	3394	57009	\N	46.342151999999999	г.Астрахань, Кирова, 47		0101000020E610000032005471E3044840682101A3CB2B4740
19519	2	21	\N	3394	57085	\N	46.309142999999999	г. Астрахань, ул. Капитана Краснова, 26		0101000020E6100000268A90BA9DFB4740C76471FF91274740
19482	2	21	\N	3394	57060	\N	46.330385999999997	414057, г. Астрахань, ул. Звёздная, 15А		0101000020E6100000E54526E0D70648403387A4164A2A4740
19481	2	21	\N	3394	57060	\N	46.330858999999997	г.Астрахань, ул.Звездная, д.21А		0101000020E6100000B9E177D32D0748402B4B7496592A4740
19478	2	21	\N	3394	57060	\N	46.335780999999997	г.Астрахань, ул.Звездная, д.41, корп.4		0101000020E61000007EAA0A0DC408484020CF2EDFFA2A4740
19477	2	21	\N	3394	57060	\N	46.340578000000001	г.Астрахань, ул.Звездная, д.59, корп. 1		0101000020E610000067463F1A4E09484059DE550F982B4740
19524	2	21	\N	3394	57040	\N	46.337516999999998	г.Астрахань, пл.Заводская, д.12А		0101000020E61000004694F6065FFE4740096CCEC1332B4740
19451	2	21	\N	3394	57047	\N	46.405268999999997	г. Астрахань, ул. Жилая, дом 15		0101000020E61000001EFCC401F40B4840938AC6DADF334740
19364	2	21	\N	3394	57124	\N	46.287537999999998	Астраханская область, Приволжский район, с.Осыпной Бугор, Есенина, 1	Россия, Астраханская область, Астрахань, Осыпной Бугор микрорайон	0101000020E61000008B506C054D074840BA2D910BCE244740
19497	2	21	\N	3394	57027	\N	46.331935000000001	г.Астрахань, ул.Дубровинского, д.54А		0101000020E61000005C04C6FA06044840EAB298D87C2A4740
19516	2	21	\N	3394	56984	\N	46.289831305451202	г.Астрахань, ул.Докучаева, д.1	Россия, Астраханская область, Астрахань, улица Докучаева	0101000020E61000009411178046F94740F92EA52E19254740
19529	2	21	\N	3394	57050	\N	46.349685999999998	г.Астрахань, ул.Дзержинского, д.44		0101000020E6100000BFF38B12F4FF47403DEFC682C22C4740
19486	2	21	\N	3394	56964	\N	46.336023578597697	г.Астрахань, ул.Дж.Рида, д.39		0101000020E610000085D21742CE074840E7559DD5022B4740
19527	2	21	\N	3394	56951	\N	46.349262654810602	г.Астрахань, ул.Депутатская, д.2К1	Россия, Астраханская область, Астрахань, Депутатский переулок	0101000020E6100000AA9ECC3FFAFC4740F75965A6B42C4740
19455	2	21	\N	3394	56991	\N	46.376725999999998	г. Астрахань, ул. Дальняя, дом 91		0101000020E6100000E17A14AE470D4840C5C6BC8E38304740
19538	2	21	\N	3394	5822	\N	46.360776884546098	г.Астрахань, пер.Грановский, д.54	Россия, Астраханская область, Астрахань, Грановский переулок	0101000020E6100000DC0E0D8B51FF47401213D4F02D2E4740
19541	2	21	\N	3394	57002	\N	46.381425999999998	г.Астрахань, ул,Гагарина, д.12		0101000020E610000071A94A5B5C0148400BEC3191D2304740
19542	2	21	\N	3394	56979	\N	46.381762000000002	г.Астрахань, ул.Гагарина, д.104		0101000020E61000000B7C45B75E014840836DC493DD304740
19484	2	21	\N	3394	5173	\N	46.327908999999998	г.Астрахань, пр.Воробьева, д.14, корп.1	Россия, Астраханская область, Астрахань, Воробьева проезд, 14к1	0101000020E6100000EBC37AA35606484033880FECF8294740
19518	2	21	\N	3394	57074	\N	46.309480000000001	г.Астрахань, ул.Водников, д.14А		0101000020E6100000F0A7C64B37FB47400F62670A9D274740
19517	2	21	\N	3394	57074	\N	46.309480000000001	г. Астрахань, ул.Водников, д.14А		0101000020E6100000F0A7C64B37FB47400F62670A9D274740
19499	2	21	\N	3394	57066	\N	46.335189999999997	г.Астрахань, ул.Бэра, д.44		0101000020E6100000D21DC4CE140448401EF98381E72A4740
19547	2	21	\N	3394	5904	\N	46.419516000000002	г.Астрахань, пр.Бумажников, д.9А	Россия, Астраханская область, Астрахань, Бумажников проспект, 9а	0101000020E6100000FCDEA63FFBFD47400A1346B3B2354740
19546	2	21	\N	3394	5904	\N	46.420839999999998	414042, г.Астрахань, пр.Бумажников, д.17а	Россия, Астраханская область, Астрахань, Бумажников проспект, 17а	0101000020E6100000C39E76F86BFE4740A06CCA15DE354740
19467	2	21	\N	3394	57036	\N	46.364327000000003	г. Астрахань, ул. Ботвина, дом 32		0101000020E610000091BA9D7DE507484060066344A22E4740
19466	2	21	\N	3394	57036	\N	46.369115000000001	г. Астрахань, ул. Ботвина, дом 12В		0101000020E61000000FF27A302908484045BB0A293F2F4740
19549	2	21	\N	3394	57028	\N	46.367025707872898	г.Астрахань, ул. Алексеева, 7	Россия, Астраханская область, Астрахань, улица Бориса Алексеева	0101000020E6100000C9552C7E530848400F643DB5FA2E4740
19463	2	21	\N	3394	57028	\N	46.363562000000002	г. Астрахань, ул. Б. Алексеева, дом 12		0101000020E6100000FAB48AFED0084840C0081A33892E4740
19445	2	21	\N	3394	57028	\N	46.353566999999998	414004, г.Астрахань, ул.Б.Алексеева,61 к.2		0101000020E6100000971AA19FA9094840F0F8F6AE412D4740
19498	2	21	\N	3394	57041	\N	46.332084999999999	г.Астрахань, ул.Боевая, д.59Б		0101000020E6100000A1D634EF38034840FF3EE3C2812A4740
19496	2	21	\N	3394	57041	\N	46.324561000000003	г.Астрахань, ул.Боевая, д.81, корп.1		0101000020E610000089EFC4AC170348404E4700378B294740
19495	2	21	\N	3394	57041	\N	46.327410999999998	г.Астрахань, ул.Боевая, д.71, корп.1		0101000020E6100000541D7233DC024840E2AC889AE8294740
19504	2	21	\N	3394	57030	\N	46.331685999999998	г.Астрахань, ул.Б.Хмельницкого, д.3		0101000020E6100000D3122BA3910148404145D5AF742A4740
19502	2	21	\N	3394	57030	\N	46.332949999999997	г.Астрахань, ул.Б.Хмельницкого, д.9, корп.3А		0101000020E6100000001DE6CB0B024840029A081B9E2A4740
19508	2	21	\N	3394	57018	\N	46.306927000000002	г.Астрахань, ул.Безжонова, д.103		0101000020E610000002F566D47CFF474034A1496249274740
19434	2	21	\N	3394	56914	\N	46.345480573269697	414004, г.Астрахань, В.Барсовой, 8А	Россия, Астраханская область, Астрахань, улица Барсовой	0101000020E6100000D34A21904B084840D731AEB8382C4740
19433	2	21	\N	3394	56914	\N	46.3446544449681	г.Астрахань, В.Барсовой, 8А	Россия, Астраханская область, Астрахань, улица Барсовой, 12	0101000020E6100000FDFA213658084840C1374D9F1D2C4740
19167	2	21	\N	3394	57069	\N	46.340986404318002	г.Астрахань, Бакинская, 121	Россия, Астраханская область, Астрахань, Кировский район, улица Бакинская	0101000020E6100000A73FFB91220448406A32E36DA52B4740
19006	2	21	\N	3394	57065	\N	46.340777000000003	г.Астрахань, Бакинская, 83		0101000020E61000009C8BBFED09044840501DAB949E2B4740
19485	2	21	\N	3394	57082	\N	46.337598	г.Астрахань, ул.Ахшарумова, д.90		0101000020E6100000E1EF17B325054840F6984869362B4740
19461	2	21	\N	3394	56987	\N	46.366832024185598	г. Астрахань, ул. Ахтубинская, дом 6А	Россия, Астраханская область, Астрахань, улица Ахтубинская, 8	0101000020E61000004D4D8237A40948402A90D959F42E4740
18642	2	21	\N	3394	57014	\N	46.324784225643398	414000, г. Астрахань, ул. Ан. Сергеева, 20	Россия, Астраханская область, Астрахань, Трусовский район, Артема Сергеева площадь	0101000020E6100000DB8AFD65F7FC4740CD21A98592294740
19505	2	21	\N	3394	57005	\N	46.321114262752602	г.Астрахань, ул.Артезианская, д.27/17		0101000020E61000005DFC6D4F90004840D52478431A294740
19520	2	21	\N	3394	57011	\N	46.348081000000001	г.Астрахань, пл.А.Сергеева, д.22А		0101000020E6100000F5BD86E0B8024840F3AD0FEB8D2C4740
18035	2	21	\N	3394	57084	\N	46.318437000000003	г.Астрахань, ул.Александрова, д.3		0101000020E610000074D190F128FF47400E6B2A8BC2284740
19307	2	21	\N	3394	57016	\N	46.357618427457297	г.Астрахань, Ак.Королева, 40	Россия, Астраханская область, Астрахань, улица Академика Королева, 38	0101000020E61000009B92ACC3D1054840003B376DC62D4740
18774	2	21	\N	3394	57042	\N	46.351539000000002	г.Астрахань, Адмиралтейская, 21		0101000020E6100000EFE53E390A0448406022DE3AFF2C4740
19509	2	21	\N	3394	56997	\N	46.307693	г.Астрахань, ул.Адм.Нахимова, д.62		0101000020E610000040F9BB77D4FE4740A41AF67B62274740
19507	2	21	\N	3394	56997	\N	46.307678266381302	г.Астрахань, ул.Адм.Нахимова, д.58	Россия, Астраханская область, Астрахань, улица Адмирала Нахимова	0101000020E610000063096B63ECFE47406FD921FE61274740
18376	2	21	\N	3394	56997	\N	46.312536000000001	г.Астрахань, ул.Адм.Нахимова, д.44		0101000020E610000002F566D47CFF47404D69FD2D01284740
19453	2	21	\N	3394	57048	\N	46.385728	г. Астрахань, ул. Агрономическая, дом 15/14		0101000020E6100000C364AA60540A48406493FC885F314740
19464	2	21	\N	3394	57076	\N	46.375121999999998	г. Астрахань, ул. Авиационная, дом 14А		0101000020E6100000BA83D899420948404B0169FF03304740
19448	2	21	\N	3394	57045	\N	46.410761999999998	г. Астрахань, ул. 8-я Железнодорожная, дом 57А		0101000020E6100000299831056B0A4840433866D993344740
19526	2	21	\N	3394	56992	\N	46.346344999999999	г.Астрахань, ул.5-я Керченская, д.12		0101000020E6100000FE7F9C3061FC47400A117008552C4740
19441	2	21	\N	3394	57044	\N	46.359768000000003	414000, г. Астрахань, ул. 11 Красной Армии 3		0101000020E6100000E3C3EC65DB094840DC12B9E00C2E4740
19440	2	21	\N	3394	57044	\N	46.359712000000002	г.Астрахань, 11 Красной Армии, 11		0101000020E610000025CE8AA8890A484048FDF50A0B2E4740
19409	2	21	1383	15153	56966	\N	48.062049000000002	Астраханская область, Черноярский район, село Черный Яр, пл.Ленина, 2		0101000020E6100000D4981073490D4740F0DFBC38F1074840
19411	2	21	1383	15153	56929	\N	48.062049000000002	Астраханская область, Черноярский район, село Черный Яр, пл. Ленина, 6		0101000020E6100000D4981073490D4740F0DFBC38F1074840
19412	2	21	1383	15153	56840	\N	48.062049000000002	Астраханская область, Черноярский район, село Черный Яр, Комиссара Савельева, 2А		0101000020E6100000D4981073490D4740F0DFBC38F1074840
19410	2	21	1383	15153	56840	\N	48.062049000000002	Астраханская область, Черноярский район, село Черный Яр, Комиссара Савельева, 27		0101000020E6100000D4981073490D4740F0DFBC38F1074840
19423	2	21	1383	15849	56970	\N	48.428122999999999	Астраханская область, Черноярский район, Село Ушаковка, Школьная, 9		0101000020E6100000546EA296E68E46402CD505BCCC364840
19418	2	21	1383	15609	57247	\N	48.305121	Астраханская область, Черноярский район, Село Ступино, 1-го Мая, 19		0101000020E6100000DCA16131EAE44640522976340E274840
19415	2	21	1383	15410	57160	\N	48.219701000000001	Астраханская область, Черноярский район, село Старица, пл. Мира, 2а		0101000020E610000026DF6C7363F8464002F390291F1C4840
19421	2	21	1383	15733	56971	\N	48.406841	Астраханская область, Черноярский район, село Солодники, пер. Кооперативный, 12		0101000020E610000053CA6B2574A5464002D6AA5D13344840
19408	2	21	1383	15120	56965	\N	47.917492000000003	Астраханская область, Черноярский район, Село Соленое Займище, Победы, 2А		0101000020E6100000321CCF6740114740BB2BBB6070F54740
19416	2	21	1383	15512	57106	\N	48.254286	Астраханская область, Черноярский район, Село Поды, 1-го Мая, 8		0101000020E6100000454B1E4FCBF1464053EA92718C204840
19420	2	21	1383	15696	57109	\N	48.442255000000003	Астраханская область, Черноярский район, село Каменный Яр, Советская, 64		0101000020E610000007F0164850C846400ABFD4CF9B384840
19413	2	21	1383	15353	57105	\N	48.142893000000001	Астраханская область, Черноярский район, Село Зубовка, Комсомольская, 4		0101000020E610000056B950F9D7044740E6E95C514A124840
19419	2	21	1383	15637	57158	\N	48.317675000000001	Астраханская область, Черноярский район, село Вязовка, Ленина, 45		0101000020E61000001CEDB8E177CD4640DFE00B93A9284840
19385	2	21	996	14033	57224	\N	47.532584	Астраханская область, Харабалинский район, поселок Чапчачи, Железнодорожная, 13		0101000020E610000046787B1002904740BA2F67B62BC44740
19404	2	21	996	14918	56864	\N	47.035021	Астраханская область, Харабалинский район, село Хошеутово, Советская, 25		0101000020E61000003B8908FF22E847402CD670917B844740
19389	2	21	996	14090	56959	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, Терешковой, 11		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19390	2	21	996	14090	56834	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, Советская, 13		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19388	2	21	996	14090	56861	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, Лесхозная, 71		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19391	2	21	996	14090	56963	\N	47.401925202237202	Астраханская область, Харабалинский район, Город Харабали, Ленина, 29	Россия, Астраханская область, Харабалинский район, Харабали	0101000020E61000002DEE3F321DA04740EF38454772B34740
19394	2	21	996	14090	56961	\N	47.405996999999999	Астраханская область, Харабалинский район, Город Харабали, Гагарина, 118		0101000020E6100000BF81C98D22A1474016A3AEB5F7B34740
19396	2	21	996	14549	56930	\N	47.313961999999997	Астраханская область, Харабалинский район, село Тамбовка, Октябрьская, 38		0101000020E6100000CE716E13EEAF4740E71725E82FA84740
19402	2	21	996	57149	57311	\N	47.1447921018164	Астраханская область, Харабалинский район, поселок Серогазово, Светлая, 3	Россия, Астраханская область, Харабалинский район, село Сероглазово	0101000020E610000031957EC2D9D94740795C548B88924740
19398	2	21	996	14641	56836	\N	47.167178	Астраханская область, Харабалинский район, село Селитренное, Советская, 53		0101000020E6100000344C6DA983BA47402B4EB51666954740
19383	2	21	996	13948	56934	\N	47.548350999999997	Астраханская область, Харабалинский район, село Сасыколи, Ленина, 96		0101000020E61000001747E5266A7F47404CDD955D30C64740
19407	2	21	996	15070	57087	\N	46.93056	Астраханская область, Харабалинский район, село Речное, Школьная, 1		0101000020E6100000F0BE2A172ACF47409E7B0F971C774740
19381	2	21	996	13819	57107	\N	47.646966999999997	Астраханская область, Харабалинский район, село Михайловка, Ленина, 26 Б		0101000020E6100000D89C8367426F4740AD4B8DD0CFD24740
19405	2	21	996	14991	57193	\N	46.951509000000001	Астраханская область, Харабалинский район, село Лапас, Советская, 8		0101000020E61000005F0D501A6AEA4740C26C020CCB794740
19384	2	21	996	13969	56926	\N	47.543776999999999	Астраханская область, Харабалинский район, село Кочковатка, Почтовая, 70		0101000020E610000016342DB13284474093A8177C9AC54740
19406	2	21	996	15029	56870	\N	46.977184999999999	Астраханская область, Харабалинский район, село Заволжское, Набережная, 23		0101000020E61000008F386403E9CE47402592E865147D4740
19400	2	21	996	14740	56839	\N	47.139296000000002	Астраханская область, Харабалинский район, село Вольное, Советская, 31		0101000020E61000001C075E2D77D24740583B8A73D4914740
19382	2	21	996	13881	57244	\N	47.558805	Астраханская область, Харабалинский район, посело Бугор, Школьная, 8		0101000020E61000008194D8B5BD754740AFEB17EC86C74740
18609	2	21	996	14586	\N	\N	47.313327297938201	Астраханская область, Харабалинский район, гарнизон Ашулук	Россия, Астраханская область, Харабалинский район, село Ашулук	0101000020E6100000F277EFA831B3474016FA60191BA84740
19397	2	21	996	14586	57231	\N	47.315953999999998	Астраханская область, Харабалинский район, поселок Ашулук, Привокзальная, 50		0101000020E6100000DDB243FCC3B247402B85402E71A84740
19403	2	21	996	57146	57306	\N	47.071877000000001	Астраханская область, Харабалинский район, село Ахтубинска, Школьная, 26	Россия, Астраханская область, Харабалинский район, село Ахтубинка	0101000020E61000006F47382D78E34740D42AFA4333894740
19357	2	21	7418	57141	57295	\N	46.346707436522102	Астраханская область, Приволжский район, с.Яманцуг, Центральная, 4а	Россия, Астраханская область, Астрахань, Трусово микрорайон	0101000020E6100000FB3BDBA337FA4740AB251DE5602C4740
19378	2	21	1232	57115	56974	\N	46.497489339852599	Астраханская область, Приволжский район, с.Растопуловка, 50-летия Победы, 6		0101000020E610000001C3F2E7DB044840548F34B8AD3F4740
19375	2	21	1232	57143	57301	\N	46.282294	Астраханская область, Приволжский район, п.Ассадулаево, Парковая, 9		0101000020E6100000DA38622D3EF94740B3EDB43522244740
19372	2	21	1232	13389	56862	\N	46.243707999999998	Астраханская область, Приволжский район, с.Яксатово, Юность, 5		0101000020E6100000AF997CB3CD01484004E3E0D2311F4740
19371	2	21	1232	13389	56868	\N	46.243707999999998	Астраханская область, Приволжский район, с.Яксатово, Школьная, 1		0101000020E6100000AF997CB3CD01484004E3E0D2311F4740
19366	2	21	1232	13114	56922	\N	46.230001000000001	Астраханская область, Приволжский район, с.Фунтово-1, Чехова, 9		0101000020E610000034F279C5530D48400E863AAC701D4740
19374	2	21	1232	13520	56955	\N	46.241128000000003	Астраханская область, Приволжский район, с.Татарская Башмаковка, Ленина, 41		0101000020E61000009757AEB7CDFE474030134548DD1E4740
19376	2	21	1232	57142	57298	\N	46.347147	Астраханская область, Приволжский район, п.Стеклозавода, Ленина, 2		0101000020E6100000ED0E290648044840C7F319506F2C4740
19377	2	21	1232	13670	56921	\N	46.459404999999997	Астраханская область, Приволжский район, п.Пойменный, Советская, 17а		0101000020E61000001D1EC2F869184840374F75C8CD3A4740
19356	2	21	1232	12694	57130	\N	46.291448000000003	Астраханская область, Приволжский район, п.Начало, Советская, 30		0101000020E610000012C0CDE2C51C4840083E062B4E254740
19361	2	21	1232	12694	57004	\N	46.291448000000003	Астраханская область, Приволжский район, с.Началово, Ленина, 13	Россия, Астраханская область, Приволжский район, село Начало	0101000020E610000012C0CDE2C51C4840083E062B4E254740
19365	2	21	1232	57106	56887	\N	46.257570462044796	Астраханская область, Приволжский район, п.Кирпичного завода №1, Клубная, 33	Россия, Астраханская область, Приволжский район, село Кирпичный Завод №1	0101000020E610000070EEAF1EF70948402237C30DF8204740
19355	2	21	1232	12675	56863	\N	46.291853000000003	Астраханская область, Приволжский район, с.Килинчи, Ленина, 12		0101000020E61000008DEC4ACB481F4840A81E69705B254740
19369	2	21	1232	13270	56954	\N	46.236172000000003	Астраханская область, Приволжский район, с.Евпраксино, Ленина, 25		0101000020E6100000FAB48AFED01848408F1D54E23A1E4740
19368	2	21	1232	13235	57103	\N	46.240946999999998	Астраханская область, Приволжский район, с.Водяновка, Молодежная, 20		0101000020E61000004CAAB69BE0154840DF88EE59D71E4740
19367	2	21	1232	13184	57254	\N	46.192357999999999	Астраханская область, Приволжский район, с.Веселая Грива, Садовая, 39		0101000020E61000005723BBD2321A4840DE8FDB2F9F184740
19358	2	21	1232	12773	57273	\N	46.321598999999999	Астраханская область, Приволжский район, п.Болдинский, Школьная, 1		0101000020E61000007216F6B4C321484091B6F1272A294740
19354	2	21	1232	12638	56838	\N	46.317995000000003	Астраханская область, Приволжский район, с.Бирюковка, Юбилейная, 14		0101000020E6100000B14F00C5C828484051A5660FB4284740
19373	2	21	1232	13458	57192	\N	46.191409	Астраханская область, Приволжский район, с.Атал, Фрунзе, 11		0101000020E6100000E013EB54F90248407D94111780184740
19336	2	21	1186	11751	57249	\N	46.254465000000003	Астраханская область, Наримановский район, с.Янго-Аскер, М.Джалиля, 17		0101000020E61000008A75AA7CCFD24740037D224F92204740
19338	2	21	1186	11837	57274	\N	46.250118876291097	Астраханская область, Наримановский район, с.Туркменка, Советская, 47	Россия, Астраханская область, Наримановский район, село Туркменка	0101000020E61000001CD13DEB1ABB4740DA8D3EE603204740
19321	2	21	1186	57132	57163	\N	46.538046999999999	Астраханская область, Наримановский район, с.Тулугановка, Вересаева, 3	Россия, Астраханская область, Наримановский район, село Тулугановка	0101000020E6100000D7868A71FE064840FF5A5EB9DE444740
19330	2	21	1186	11446	57146	\N	46.395363000000003	"Астраханская область, Наримановский район, п.Тинаки 2-ые, Санаторная, ФГУ ЦСР ФССРФ ""Тинаки"""		0101000020E6100000FFE7305F5EF44740348639419B324740
19329	2	21	1186	11410	57245	\N	46.556805487294298	Астраханская область, Наримановский район, с.Рассвет, Советская, 31	Россия, Астраханская область, Астрахань, Наримановский район	0101000020E610000093AB58FCA6FA4740E89FE06245474740
19331	2	21	1186	11486	56953	\N	46.636465000000001	Астраханская область, Наримановский район, с.Разночиновка, Горького, 1		0101000020E6100000F836FDD98FF447403A0664AF77514740
19346	2	21	1186	12208	56919	\N	46.223104473481797	Астраханская область, Наримановский район, п.Прикаспийский, Ленина, 47	Россия, Астраханская область, Наримановский район, село Прикаспийский	0101000020E610000002D6AA5D13984740ABCDFFAB8E1C4740
19334	2	21	1186	11626	57243	\N	46.827607	Астраханская область, Наримановский район, с.Петропавловка, Набережная, 9		0101000020E6100000F7562426A8E347406878B306EF694740
19342	2	21	1186	12046	57271	\N	46.289605000000002	Астраханская область, Наримановский район, с.Новокучергановка, Кирова, 13А		0101000020E610000076FA415DA4F0474009E1D1C611254740
19352	2	21	1186	12538	56952	\N	46.332365000000003	Астраханская область, Наримановский район, с.Николаевка, Советская, 62		0101000020E6100000CEFA9463B2DC4740E3AAB2EF8A2A4740
19332	2	21	1186	11535	57269	\N	46.694226	Астраханская область, Наримановский район, с.Нижнелебяжье, Гагарина, 45		0101000020E6100000A968ACFD9DF147403604C765DC584740
94953	2	21	1186	12292	56881	\N	46.691741	416111, Астраханская область, Наримановский район, г. Нариманов, Школьная, 7		0101000020E6100000E92B483316ED4740B32616F88A584740
19337	2	21	1186	11792	56857	\N	46.256365000000002	Астраханская область, Наримановский район, с.Линейное, Ленина, 103		0101000020E6100000F67D384888B64740666B7D91D0204740
19335	2	21	1186	11693	57242	\N	46.233092999999997	Астраханская область, Наримановский район, с.Курченко, Ленина, 73		0101000020E6100000A4A833F790C4474098F6CDFDD51D4740
19327	2	21	1186	11297	56858	\N	46.655667999999999	Астраханская область, Наримановский район, с.Волжское, Почтовая, 23		0101000020E6100000F1B8A81611EF47405184D4EDEC534740
19328	2	21	1186	11355	57241	\N	46.753	Астраханская область, Наримановский район, с.Верхнелебяжье, Школьная, 12		0101000020E610000087527B116DE74740AAF1D24D62604740
19345	2	21	1186	12186	56860	\N	46.187534999999997	Астраханская область, Наримановский район, п.Буруны, Коммунистическая, 1		0101000020E61000006E68CA4E3FA047407CED992501184740
19333	2	21	1186	11584	57125	\N	46.788749000000003	Астраханская область, Наримановский район, с.Барановка, Пионерская, 36		0101000020E6100000772E8CF4A2E4474059E02BBAF5644740
19316	2	21	1098	10828	57221	\N	45.958699000000003	Астраханская область, Лиманский район, Село Яр-Базар, Иванова, 66		0101000020E610000060764F1E16C047409DDA19A6B6FA4640
19300	2	21	1098	9966	56856	\N	45.769202	"Астраханская область, Лиманский район, Село Яндыки, Кирова, 113 ""Б"""		0101000020E61000007E3B8908FF8E474047020D3675E24640
19299	2	21	1098	9966	56856	\N	45.769202	"Астраханская область, Лиманский район, Село Яндыки, Кирова, 122""А"""		0101000020E61000007E3B8908FF8E474047020D3675E24640
19320	2	21	1098	11000	57270	\N	45.858239996783603	Астраханская область, Лиманский район, Село Судачье, Полевая, -	Россия, Астраханская область, Лиманский район, село Судачье	0101000020E6100000F9BF232A54C747403D0FEECEDAED4640
19312	2	21	1098	57118	57067	\N	46.349219819240197	"Астраханская область, Лиманский район, Село Зензели, Советская, 53""В"""	Россия, Астраханская область, Астрахань, улица Коммунистическая	0101000020E61000007EA8346266054840F88DAF3DB32C4740
19314	2	21	1098	57140	57212	\N	46.267225000000003	Астраханская область, Лиманский район, Село Басы, Школьная, 50		0101000020E6100000A08A1BB798FB474039D6C56D34224740
19305	2	21	1098	10279	57217	\N	45.643545000000003	Астраханская область, Лиманский район, Село Рынок, Мира, 7		0101000020E6100000533C2EAA45C847408E40BCAE5FD24640
19318	2	21	1098	10882	57102	\N	45.891288000000003	Астраханская область, Лиманский район, Село Проточное, Октябрьская, 22		0101000020E610000033FB3C4679A647409CA8A5B915F24640
19308	2	21	1098	10444	56962	\N	45.722535000000001	Астраханская область, Лиманский район, Село Промысловка, Ленина, 115		0101000020E6100000ED9C668176954740919BE1067CDC4640
19298	2	21	1098	9905	57292	\N	45.807639000000002	Астраханская область, Лиманский район, Село Песчаное, Молодежная, 12/1		0101000020E6100000FE2955A2ECA94740B1FCF9B660E74640
19301	2	21	1098	10055	56910	\N	45.786915	Астраханская область, Лиманский район, Село Оля, Советская, 4		0101000020E610000085B35BCB64C44740ADDD76A1B9E44640
19311	2	21	1098	10577	57123	\N	45.927546	Астраханская область, Лиманский район, Село Михайловка, Кооперативная, 16		0101000020E6100000219221C7D68F47408FC4CBD3B9F64640
19294	2	21	1098	57112	56999	\N	45.784793905404399	Астраханская область, Лиманский район, Рабочий поселок Лиман, Победы, 36	Россия, Астраханская область, Лиманский район, поселок городского типа Лиман	0101000020E610000038C0CC77F09D47406B0C3A2174E44640
19296	2	21	1098	57112	56977	\N	45.784253446834597	Астраханская область, Лиманский район, Рабочий поселок Лиман, Космонавтов, 49	Россия, Астраханская область, Лиманский район, поселок городского типа Лиман	0101000020E6100000164CFC51D49D47401B65FD6662E44640
19297	2	21	1098	57111	56912	\N	45.785393999999997	Астраханская область, Лиманский район, Рабочий поселок Лиман, Ленина, 11	Россия, Астраханская область, Лиманский район, поселок городского типа Лиман	0101000020E6100000772B4B74969D4740C03C64CA87E44640
19295	2	21	1098	57111	56912	\N	45.785394408741098	Астраханская область, Лиманский район, Рабочий поселок Лиман, Ленина, 45	Россия, Астраханская область, Лиманский район, поселок городского типа Лиман	0101000020E6100000D7A205685B9D4740C03C64CA87E44640
19302	2	21	1098	10112	56859	\N	45.778920999999997	Астраханская область, Лиманский район, Село Лесное, Свердлова, 68		0101000020E61000007AC2120F28C347407495EEAEB3E34640
19319	2	21	1098	10943	57104	\N	45.855269999999997	Астраханская область, Лиманский район, Село Кряжевое, Колхозная, 47		0101000020E61000002E76FBAC32C34740FD9FC37C79ED4640
19313	2	21	1098	10658	56913	\N	45.985345000000002	Астраханская область, Лиманский район, Село Караванное, Советская, 1		0101000020E610000047B071FDBB9247407923F3C81FFE4640
19315	2	21	1098	10750	57194	\N	45.948267000000001	Астраханская область, Лиманский район, Село Камышово, Советская, 152		0101000020E6100000F90FE9B7AFB94740227024D060F94640
19317	2	21	1098	10853	56916	\N	45.878470999999998	Астраханская область, Лиманский район, Село Заречное, Советская, 110		0101000020E610000042E8A04B38BA474001BEDBBC71F04640
19304	2	21	1098	10200	57238	\N	45.725492000000003	Астраханская область, Лиманский район, Село Забурунное, Горького, 21		0101000020E61000001668774831C447403CC1FEEBDCDC4640
19306	2	21	1098	10302	57218	\N	45.611545999999997	Астраханская область, Лиманский район, Село Вышка, Октябрьская, 21		0101000020E6100000BABA63B14DD24740F3FFAA2347CE4640
19310	2	21	1098	10536	57220	\N	45.614331999999997	Астраханская область, Лиманский район, Село Воскресеновка, Южная, 22		0101000020E6100000637B2DE8BDC347407171546EA2CE4640
19309	2	21	1098	10456	57101	\N	45.700288	Астраханская область, Лиманский район, Село Бударино, Мира, 2		0101000020E6100000B91803EB38B4474000E48409A3D94640
19303	2	21	1098	10163	57100	\N	45.721774000000003	Астраханская область, Лиманский район, Село Бирючья Коса, Советская, 42		0101000020E61000003CFA5FAE45CB4740338D261763DC4640
19284	2	21	961	57125	57098	\N	46.672425118748102	Астраханская область, Красноярский район, с.Новоурусовка, Ленина, 21	Россия, Астраханская область, Красноярский район	0101000020E6100000FE614B8FA6084840A301BC0512564740
19277	2	21	961	57147	57308	\N	46.388513000000003	Астраханская область, Красноярский район, пос.Топал, Набережная, 12		0101000020E6100000F0A31AF67B024840128942CBBA314740
19292	2	21	961	9596	57219	\N	46.667994	Астраханская область, Красноярский район, с.Ясын-Сокан, Набережная, 64		0101000020E6100000E0A293A5D60F48404DF6CFD380554740
19290	2	21	961	9498	57222	\N	46.601326	Астраханская область, Красноярский район, пос.Шмагино, Мира, 12/1		0101000020E610000029CE5147C71B4840041E1840F84C4740
19280	2	21	961	9091	57162	\N	46.501081999999997	Астраханская область, Красноярский район, с.Черемуха, Елизарова, 21Б		0101000020E61000009F05A1BC8F2F4840A04E797423404740
19285	2	21	961	9297	57272	\N	46.639372999999999	Астраханская область, Красноярский район, пос.Тальниковый, Школьная, 1		0101000020E61000008D0A9C6C03074840037976F9D6514740
19271	2	21	961	8662	57268	\N	46.726488000000003	Астраханская область, Красноярский район, с.Сеитовка, ул. Юбилейная,21		0101000020E61000004CC3F01131074840DE770C8FFD5C4740
19279	2	21	961	9036	57300	\N	46.664054	Астраханская область, Красноярский район, с.Малый Арал, Набережная, 7		0101000020E6100000F949B54FC73B48409563B2B8FF544740
19268	2	21	961	8522	57128	\N	46.516749983588298	Астраханская область, Красноярский район, с.Кривой Бузан, Советская, 24		0101000020E6100000DF8AC40435444840A01A2FDD24424740
19264	2	21	961	8058	56906	\N	46.534711000000001	Астраханская область, Красноярский район, с.Красный Яр, Советская, 10		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19263	2	21	961	8058	56855	\N	46.534711000000001	Астраханская область, Красноярский район, с.Красный Яр, Мордовцева, 18		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19265	2	21	961	8058	56908	\N	46.534711000000001	Астраханская область, Красноярский район, с.Красный Яр, Леонова, 17		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19260	2	21	961	8058	56853	\N	46.534711000000001	Астраханская область, Красноярский район, с.Красный Яр, Ленинская, 2		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19266	2	21	961	8058	57174	\N	46.532164475200901	Астраханская область, Красноярский район, З.Ананьевой, 51А	Россия, Астраханская область, Красноярский район, село Красный Яр	0101000020E6100000EF6FD05E7D2C4840E50D30F31D444740
19259	2	21	961	8058	57099	\N	46.534711000000001	Астраханская область, Красноярский район, с.Красный Яр, Братская, 1А		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19267	2	21	961	8058	57267	\N	46.534711000000001	Астраханская область, Красноярский район, с.Красный Яр, Береговая, 25		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19262	2	21	961	8058	56948	\N	46.534711000000001	416150, Астраханская область, Красноярский район, с.Красный Яр, ул. Ахтубинская, 1		0101000020E6100000A8A9656B7D2B4840DEE7F86871444740
19288	2	21	961	9426	57216	\N	46.530762000000003	Астраханская область, Красноярский район, с.Кошелевка, Заречная, 17		0101000020E6100000AB798EC8775D4840D3FA5B02F0434740
19275	2	21	961	8843	57097	\N	46.855296000000003	Астраханская область, Красноярский район, пос.Комсомольский, Степная, 39А		0101000020E6100000406A1327F7F747402733DE567A6D4740
19278	2	21	961	8969	57290	\N	46.544635999999997	Астраханская область, Красноярский район, с.Караозек, Центральная, 22		0101000020E6100000AA807B9E3F514840B41CE8A1B6454740
19293	2	21	961	9674	56854	\N	46.523457999999998	Астраханская область, Красноярский район, с.Забузан, Советская, 15Б		0101000020E6100000EFAD484C502748402F6AF7AB00434740
19276	2	21	961	8885	57096	\N	46.903089831638198	Астраханская область, Красноярский район, пос.Досанг, Привокзальная, 50	Россия, Астраханская область, Красноярский район, село Досанг	0101000020E6100000739D465A2AF547401DACFF7398734740
18598	2	21	961	7974	57150	\N	46.626618999999998	Астраханская область, Красноярский район, с.Джанай, Мира, 6		0101000020E6100000E2AB1DC5391C4840AF06280D35504740
19274	2	21	961	8803	57239	\N	46.822969999999998	Астраханская область, Красноярский район, пос.Вишневый, Центральная, 9		0101000020E61000007CED992501F8474068CBB91457694740
19289	2	21	961	9469	56949	\N	46.619866999999999	Астраханская область, Красноярский район, пос.Верхний Бузан, Ленина, 1		0101000020E61000005EF415A419154840506F46CD574F4740
19287	2	21	961	9353	56909	\N	46.554385000000003	416155, Астраханская область, Красноярский район, с.Ватажное, ул. Гагарина, 31 «б»		0101000020E6100000D369DD06B53148404D327216F6464740
19272	2	21	961	8736	57129	\N	46.720117999999999	Астраханская область, Красноярский район, пос.Бузан-Пристань, Волгоградская, 2		0101000020E6100000B682A6255604484066A19DD32C5C4740
19283	2	21	961	9212	57126	\N	46.710800999999996	416166, Астраханская область, Красноярский район, пос.Бузан, ул. Советская,7 «а»		0101000020E610000020B8CA1308FD4740677BF486FB5A4740
19273	2	21	961	8740	57291	\N	46.810692000000003	Астраханская область, Красноярский район, пос.Бахаревский, Заречная, 1		0101000020E6100000ED7E15E0BBF947407E9065C1C4674740
19269	2	21	961	8586	57288	\N	46.475655000000003	Астраханская область, Красноярский район, с.Бакланье, Иришева, 8		0101000020E61000000EF62686E4584840E6965643E23C4740
19282	2	21	961	9175	57121	\N	46.652630000000002	Астраханская область, Красноярский район, с.Байбек, Советская, 10А		0101000020E61000009CF86A47713A4840BA313D6189534740
19270	2	21	961	8610	57191	\N	46.579118000000001	Астраханская область, Красноярский район, пос.Алча, Октябрьская, 23		0101000020E6100000DE72F563932A48403143E389204A4740
19286	2	21	961	9345	57225	\N	46.651027999999997	Астраханская область, Красноярский район, пос.Аллайский, Школьная, 1		0101000020E610000071A94A5B5C014840E063B0E254534740
19281	2	21	961	9103	57122	\N	46.792482	Астраханская область, Красноярский район, пос.Аксарайский, Набережная, 37		0101000020E6100000155454FD4A0148409755D80C70654740
19232	2	21	783	57151	57320	\N	46.128315312099801	Астраханская область, Камызякский район, п.Азовский, Молодежная, 2, кв.11	Россия, Астраханская область, Камызякский район	0101000020E6100000FA997ADD220E48400A4B3CA06C104740
19236	2	21	783	6999	57235	\N	45.976947000000003	Астраханская область, Камызякский район, с.Чапаево, Восточная, 14		0101000020E6100000C63368E89F22484071766B990CFD4640
19258	2	21	783	8016	56837	\N	46.173757000000002	Астраханская область, Камызякский район, с.Чаган, Школьная, 1		0101000020E61000002B6B9BE271FB4740BD395CAB3D164740
19242	2	21	783	7307	57263	\N	46.088079999999998	Астраханская область, Камызякский район, с.Хмелевка, Ленина, 24		0101000020E61000003D65355D4FF4474041B79734460B4740
19257	2	21	783	7976	57286	\N	46.072457999999997	Астраханская область, Камызякский район, п.Успех, Дорожная, 11б		0101000020E61000006ADC9BDF30054840B22AC24D46094740
19256	2	21	783	7938	57108	\N	46.046360999999997	Астраханская область, Камызякский район, с.Увары, Ксенофонтова, 22		0101000020E6100000B6F5D37FD6044840A9674128EF054740
19226	2	21	783	6507	57090	\N	46.141952000000003	Астраханская область, Камызякский район, с.Тузуклей, Школьная, 27а		0101000020E6100000E5805D4D9E2A484008CDAE7B2B124740
19227	2	21	783	6507	57185	\N	46.143145286377703	Астраханская область, Камызякский район, с.Тузуклей, Ленина, 53	Россия, Астраханская область, Камызякский район, село Тузуклей	0101000020E6100000F6CFD380412A4840FFCA4A9352124740
19228	2	21	783	6659	57262	\N	46.156742000000001	Астраханская область, Камызякский район, с.Трехизбинка, Джамбула, 35		0101000020E6100000B323D5777E2D48406FF4311F10144740
19224	2	21	783	6442	57234	\N	45.819215999999997	Астраханская область, Камызякский район, с.Станья, Советская, 52а		0101000020E61000003BAC70CB470E4840122EE411DCE84640
19229	2	21	783	6665	57289	\N	46.092692999999997	Астраханская область, Камызякский район, п.Сизова Грива, Маяковского, 14		0101000020E6100000A297512CB7324840B8C83D5DDD0B4740
19234	2	21	783	6915	56851	\N	46.165837614091998	Астраханская область, Камызякский район, с.Семибугры, Курманова, 10	Россия, Астраханская область, Камызякский район, село Семибугры	0101000020E61000004E9B711AA22048408F37F92D3A154740
19253	2	21	783	7771	56947	\N	46.028080000000003	Астраханская область, Камызякский район, с.Самосделка, Советская, 17		0101000020E61000004485EAE6E2EB4740FAD51C2098034740
19230	2	21	783	6734	56833	\N	46.070000999999998	Астраханская область, Камызякский район, с.Раздор, Степная, 33		0101000020E610000043554CA59F1C4840F9D7F2CAF5084740
19252	2	21	783	7735	57154	\N	45.853870000000001	Астраханская область, Камызякский район, с.Полдневое, Братьев Фоминых, 55		0101000020E6100000BA4C4D8237FA47408C84B69C4BED4640
19220	2	21	783	6217	57278	\N	45.941566999999999	Астраханская область, Камызякский район, с.Парыгино, Джамбула, 16		0101000020E6100000A43330F2B21E484015FF774485F84640
19245	2	21	783	7444	57237	\N	45.861634000000002	Астраханская область, Камызякский район, п.Октябрьский, Рыбацкая, 32		0101000020E61000003D1059A4890D4840938FDD054AEE4640
19223	2	21	783	6332	57236	\N	45.832649000000004	Астраханская область, Камызякский район, п.Обуховский, Садовая, 21а		0101000020E6100000D8EF8975AA1248400806103E94EA4640
19248	2	21	783	7582	56850	\N	45.960133999999996	Астраханская область, Камызякский район, с.Образцово-Травино, Хлебникова, 69		0101000020E6100000BCCCB051D6FF47408AE3C0ABE5FA4640
19246	2	21	783	7490	57161	\N	46.151161000000002	Астраханская область, Камызякский район, с.Никольское, Мира, 11а		0101000020E610000023DDCF29C8F5474020B75F3E59134740
19251	2	21	783	7697	57299	\N	45.908836999999998	Астраханская область, Камызякский район, п.Нижненикольский, Комсомольская, 82		0101000020E6100000AEF4DA6CACFE4740873254C554F44640
19240	2	21	783	7210	57214	\N	45.980303999999997	Астраханская область, Камызякский район, п.Нижнекалиновский, Джамбула, 30		0101000020E6100000DE718A8EE4164840A911FA997AFD4640
19243	2	21	783	7365	57094	\N	45.911245000000001	416325, Астраханская область, Камызякский район, село Лебяжье, ул. Степная,95		0101000020E610000023111AC1C60F48405FD218ADA3F44640
19247	2	21	783	7518	9677	\N	46.161851277065502	Астраханская область, Камызякский район, с.Комаровка, Мира, 31	Россия, Астраханская область, Камызякский район, село Комаровка	0101000020E61000007270E998F3F0474096E99788B7144740
19225	2	21	783	6477	\N	\N	45.844717000000003	Астраханская область, Камызякский район, р.п.Кировский, Народная, 2	Россия, Астраханская область, Камызякский район, поселок Кировский	0101000020E6100000DA01D7153310484008B0C8AF1FEC4640
19254	2	21	783	7849	57293	\N	46.003357999999999	Астраханская область, Камызякский район, п.Качкаринский, Садовая, 24		0101000020E61000002B6B9BE271FB47400917F2086E004740
19233	2	21	783	6854	57260	\N	46.051445999999999	Астраханская область, Камызякский район, п.Каспий, Придорожная, 1		0101000020E610000021054F21572E484048C153C895064740
19221	2	21	783	6255	57120	\N	45.875773000000002	Астраханская область, Камызякский район, с.Караульное, Молодежная, 31		0101000020E610000053758F6CAE10484023DC645419F04640
19219	2	21	783	6143	57093	\N	45.921320999999999	Астраханская область, Камызякский район, с.Каралат, Ленина, 62		0101000020E61000003E7B2E53932648401B0FB6D8EDF54640
19210	2	21	783	5539	56787	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, Ульянова, 10		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19213	2	21	783	5539	57188	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, Тараканова, 4		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19218	2	21	783	5539	56831	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, Пушкина, 90		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19217	2	21	783	5539	56902	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, М. Горького, 89		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19208	2	21	783	5539	56848	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, Любича, 16		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19207	2	21	783	5539	56848	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, Любича, 9а		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19209	2	21	783	5539	57092	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, Курмангазы, 22		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19216	2	21	783	5539	56830	\N	46.103779000000003	Астраханская область, Камызякский район, г.Камызяк, М. Горького, 75		0101000020E61000007B32FFE89B0A48407C8159A1480D4740
19241	2	21	783	7237	56946	\N	46.071250999999997	416302, Астраханская область, Камызякский район, село Иванчуг, ул. Васильева,45		0101000020E6100000E694809884FD47405567B5C01E094740
19222	2	21	783	57130	57155	\N	45.904194128062002	Астраханская область, Камызякский район, с.Затон, Абая, 83а	Россия, Астраханская область, Камызякский район, село Затон	0101000020E610000064B0E2546B134840A59E05A1BCF34640
19231	2	21	783	6794	57223	\N	46.098255000000002	Астраханская область, Камызякский район, с.Застенка, Степная, 9а		0101000020E61000001B2D077AA819484091D5AD9E930C4740
19239	2	21	783	57138	57198	\N	46.093943417306697	Астраханская область, Камызякский район, с.Жан-Аул, Школьная, 26	Россия, Астраханская область, Камызякский район	0101000020E6100000C22FF5F3A606484015580053060C4740
18576	2	21	783	57144	57303	\N	46.097205000000002	Астраханская область, Камызякский район, с.Грушева, Степная, 12	Россия, Астраханская область, Камызякский район, село Грушево	0101000020E6100000DEC7D11C593D4840FC00A436710C4740
19250	2	21	783	7657	57266	\N	45.852306650947099	Астраханская область, Камызякский район, с.Гандурино, Молодежная, 4	Россия, Астраханская область, Камызякский район, село Гандурино	0101000020E6100000151E34BBEEFF47407193516518ED4640
19238	2	21	783	7083	56904	\N	46.201034999999997	Астраханская область, Камызякский район, р.п.Волго-Каспийский, Ленина, 1		0101000020E6100000670B08AD87F54740F92CCF83BB194740
19237	2	21	783	7060	56832	\N	46.016114999999999	Астраханская область, Камызякский район, п.Верхнекалиновский, Набережная, 106		0101000020E6100000E99D0AB8E70F4840CEFC6A0E10024740
19235	2	21	783	6961	57232	\N	46.114232000000001	Астраханская область, Камызякский район, с.Бирючек, Степная, 12		0101000020E61000006150A6D1E41C48400E1478279F0E4740
19255	2	21	783	7861	57264	\N	45.945616000000001	Астраханская область, Камызякский район, с.Алексеевка, Набережная, 45		0101000020E6100000172829B000F047408449F1F109F94640
19186	2	21	544	4370	57259	\N	45.987192	Астраханская область, Икрянинский район, село Ямное, Школьная, 21		0101000020E61000008463963D09DA4740B96FB54E5CFE4640
19200	2	21	544	5132	57116	\N	45.894455999999998	Астраханская область, Икрянинский район, село Чулпан, Ленина, 115		0101000020E61000002BDB87BCE5DA474001DBC1887DF24640
19193	2	21	544	4791	57215	\N	45.831136000000001	Астраханская область, Икрянинский район, поселок Хмелевой, Мичурина, 14		0101000020E61000000FB4024356C947409E4319AA62EA4640
19192	2	21	544	4735	57159	\N	45.859582000000003	Астраханская область, Икрянинский район, село Федоровка, Пионерская, 27		0101000020E61000006F6589CE32D147407A1D71C806EE4640
19189	2	21	544	4537	56945	\N	45.933877000000003	Астраханская область, Икрянинский район, Село Трудфронт, Ленина, 6		0101000020E6100000336C94F59BD5474049BE124889F74640
19187	2	21	544	4453	57213	\N	45.981699999999996	Астраханская область, Икрянинский район, поселок Троицкий, Гагарина, 19		0101000020E6100000003961C268D24740D93D7958A8FD4640
19203	2	21	544	5295	57183	\N	45.775613999999997	Астраханская область, Икрянинский район, поселок Товарный, пер. Пионерский, 13		0101000020E61000004C1B0E4B03D34740ED28CE5147E34640
19201	2	21	544	57145	57305	\N	45.862198999999997	Астраханская область, Икрянинский район, поселок Старо-Волжский, Пушкина, 46В	Россия, Астраханская область, Икрянинский район, село Староволжское	0101000020E6100000C0EAC891CED847406BD26D895CEE4640
19181	2	21	544	4130	57285	\N	46.079028999999998	Астраханская область, Икрянинский район, село Сергино, Садовая, 15		0101000020E61000009C1A683EE7CE4740C1374D9F1D0A4740
19188	2	21	544	4507	57233	\N	45.968328	Астраханская область, Икрянинский район, село Сергиевка, Советская, 38		0101000020E6100000611A868F88CF47408AE6012CF2FB4640
19199	2	21	544	5084	57189	\N	45.816822999999999	Астраханская область, Икрянинский район, село Седлистое, Советская, 37		0101000020E6100000516B9A779CD4474070CFF3A78DE84640
19190	2	21	544	4609	57257	\N	45.891174999999997	Астраханская область, Икрянинский район, село Светлое, Колхозная, 1Б		0101000020E610000073BA2C2636CF4740A301BC0512F24640
19197	2	21	544	4816	57186	\N	45.847329000000002	Астраханская область, Икрянинский район, село Оранжереи, Первомайская, 102		0101000020E6100000AB21718FA5C74740E8F9D34675EC4640
19195	2	21	544	4816	56852	\N	45.847329000000002	Астраханская область, Икрянинский район, село Оранжереи, Кирова, 2		0101000020E6100000AB21718FA5C74740E8F9D34675EC4640
19194	2	21	544	4816	56852	\N	45.847329000000002	Астраханская область, Икрянинский район, село Оранжереи, Кирова, 17		0101000020E6100000AB21718FA5C74740E8F9D34675EC4640
19182	2	21	544	4183	57284	\N	46.078434999999999	Астраханская область, Икрянинский район, село Озерное, Степная, 7		0101000020E6100000789CA223B9BC47404EEE77280A0A4740
19173	2	21	544	57150	57314	\N	46.327685000000002	Астраханская область, Икрянинский район, село Ново-Булгары, Тукая, 4		0101000020E6100000452C62D861004840E4310395F1294740
19191	2	21	544	4651	57148	\N	45.868600999999998	Астраханская область, Икрянинский район, село Ниновка, Советская, 56		0101000020E61000008CD8278062CE4740EE224C512EEF4640
19204	2	21	544	5377	56901	\N	45.775463000000002	Астраханская область, Икрянинский район, село Мумра, Крупской, 18		0101000020E61000005ABC581822D547400821205F42E34640
19185	2	21	544	4349	57190	\N	46.030377000000001	Астраханская область, Икрянинский район, село Маячное, 70 лет Октября, 1		0101000020E610000078F01307D0DB47407AC6BE64E3034740
19169	2	21	544	3511	56847	\N	46.204129000000002	Астраханская область, Икрянинский район, Рабочий поселок Красные Баррикады, Мира, 2		0101000020E610000005E09F5225EE4740259529E6201A4740
19183	2	21	544	4219	57296	\N	46.056449999999998	Астраханская область, Икрянинский район, поселок Карабулак, Зеленая, 11А		0101000020E61000008196AE601BC94740FAEDEBC039074740
19176	2	21	544	3764	56828	\N	46.091258189558303	Астраханская область, Икрянинский район, село Икряное, Пионерская, 24	Россия, Астраханская область, Икрянинский район, село Икряное	0101000020E6100000CA6B257497DC4740CBBF9657AE0B4740
19175	2	21	544	3764	56843	\N	46.089168000000001	Астраханская область, Икрянинский район, село Икряное, О.Кошевого, 28		0101000020E61000007973B8567BDC4740C4EC65DB690B4740
19178	2	21	544	3764	56835	\N	46.089168000000001	Астраханская область, Икрянинский район, село Икряное, Молодежная, 1		0101000020E61000007973B8567BDC4740C4EC65DB690B4740
19177	2	21	544	3764	56944	\N	46.089168000000001	Астраханская область, Икрянинский район, село Икряное, Гастелло, 40		0101000020E61000007973B8567BDC4740C4EC65DB690B4740
19174	2	21	544	3764	56865	\N	46.089168000000001	Астраханская область, Икрянинский район, село Икряное, 1-го Мая, 21		0101000020E61000007973B8567BDC4740C4EC65DB690B4740
19206	2	21	544	5450	57256	\N	45.751627999999997	Астраханская область, Икрянинский район, село Зюзино, Советская, 19		0101000020E6100000D1B2EE1F0BD547400261A75835E04640
19202	2	21	544	5238	56829	\N	45.804026	Астраханская область, Икрянинский район, село Житное, Пущкина, 20		0101000020E61000000553CDACA5D847401D91EF52EAE64640
19180	2	21	544	4057	57117	\N	46.123584000000001	416372, Астраханская область, Икрянинский район, село Восточное, Школьная, 6		0101000020E61000007520EBA9D5D547408927BB99D10F4740
19198	2	21	544	5035	57210	\N	45.82593	Астраханская область, Икрянинский район, село Вахромеево, Волжская, 51		0101000020E61000001A19E42EC2C8474084640113B8E94640
19179	2	21	544	4000	57294	\N	46.055681	Астраханская область, Икрянинский район, село Боркино, Ленина, 10		0101000020E6100000E23D079623D247401901158E20074740
19184	2	21	544	4301	57261	\N	46.096468000000002	Астраханская область, Икрянинский район, село Бекетока, Степная, 8		0101000020E6100000726F7EC344E14740268E3C10590C4740
19171	2	21	544	3608	56900	\N	46.164288999999997	Астраханская область, Икрянинский район, село Бахтемир, Калинина, 3		0101000020E6100000A69D9ACB0DE84740D80B056C07154740
19172	2	21	544	3673	57211	\N	46.139415999999997	Астраханская область, Икрянинский район, поселок им. А.Зверева, Садовая, 16		0101000020E61000009A79724D81E6474002452C62D8114740
19170	2	21	544	3564	57282	\N	46.191160000000004	Астраханская область, Икрянинский район, село Алгаза, Победы, 19 А		0101000020E610000026E0D74812EC4740D5264EEE77184740
19158	2	21	403	2881	57178	\N	47.338168000000003	Астраханская область, Енотаевский район, с.Федоровка, Ленина/Садовая, 14/2		0101000020E6100000EC4FE273277A4740E146CA1649AB4740
19150	2	21	403	2421	57253	\N	47.048395999999997	Астраханская область, Енотаевский район, с.Табун-Арал, Зеленая, 19		0101000020E6100000DBC01DA853AA4740ECA012D731864740
19148	2	21	403	2308	57208	\N	47.007050999999997	Астраханская область, Енотаевский район, с.Сероглазка, Колхозная, 18		0101000020E6100000232E008DD2BD4740B933130CE7804740
19162	2	21	403	3104	57151	\N	47.675952000000002	416221, Астраханская область, Енотаевский район, с.Пришиб, Мира, 33, МУ Пришибинский СДК		0101000020E610000065506D70223E474039D55A9885D64740
19146	2	21	403	2199	57207	\N	46.884644999999999	Астраханская область, Енотаевский район, п.Новострой, Колхозная, 16		0101000020E61000001DAB949EE9CB4740F3C81F0C3C714740
19164	2	21	403	3179	56803	\N	47.759016000000003	Астраханская область, Енотаевский район, с.Никольское, Московская, 42		0101000020E6100000897956D28A3347400492B06F27E14740
19163	2	21	403	3179	56803	\N	47.759016000000003	416222, Астраханская область, Енотаевский район, с.Никольское, Московская, 21, МУК Дом культуры		0101000020E6100000897956D28A3347400492B06F27E14740
19159	2	21	403	2940	57304	\N	47.380541999999998	Астраханская область, Енотаевский район, с.Михайловка, Олега Кошевого, 14		0101000020E610000027D87F9D9B6C47409160AA99B5B04740
19149	2	21	403	2357	57176	\N	47.011800999999998	416203, Астраханская область, Енотаевский район, с.Ленино, Набережная, 17		0101000020E6100000D46531B1F9AA4740B187F6B182814740
19151	2	21	403	2485	57258	\N	47.095280000000002	Астраханская область, Енотаевский район, с.Косика, 1 Мая, 11А		0101000020E6100000CFDA6D179A9B474040FB9122328C4740
19160	2	21	403	2983	57147	\N	47.462122000000001	Астраханская область, Енотаевский район, с.Копановка, Ленина, 40а		0101000020E6100000A855F487666847408D614ED026BB4740
19157	2	21	403	2813	57177	\N	47.297561999999999	Астраханская область, Енотаевский район, с.Ивановка, Ленина, 53		0101000020E61000002E1F49490F8347402444F98216A64740
19145	2	21	403	2128	56897	\N	46.825961	Астраханская область, Енотаевский район, с.Замьяны, Зверобоева, 12		0101000020E6100000B8CA13083BD14740BF620D17B9694740
19156	2	21	403	2643	56800	\N	47.248724000000003	Астраханская область, Енотаевский район, с.Енотаевка, Чернышевского/Кирова, 30/50		0101000020E6100000D6390664AF8347407BDD2230D69F4740
19155	2	21	403	2643	56800	\N	47.248724000000003	416200, Астраханская область, Енотаевский район, с.Енотаевка, ул. Чернышевского, 19 б, помещение кинотеатра «Мир»		0101000020E6100000D6390664AF8347407BDD2230D69F4740
19154	2	21	403	2643	56797	\N	47.248724000000003	Астраханская область, Енотаевский район, с.Енотаевка, Мусаева, 55		0101000020E6100000D6390664AF8347407BDD2230D69F4740
19165	2	21	403	3293	57184	\N	47.795456000000001	416224, Астраханская область, Енотаевский район, с.Грачи, Советская, 63, Грачевский СДК		0101000020E61000003ED00A0C5923474018B49080D1E54740
19152	2	21	403	2526	57175	\N	47.122044000000002	Астраханская область, Енотаевский район, с.Восток, Октябрьская, 10		0101000020E6100000624A24D1CB8E4740265646239F8F4740
19147	2	21	403	2236	56846	\N	46.969633999999999	Астраханская область, Енотаевский район, п.Волжский, Ленина, 11		0101000020E61000008B53AD8559C647407A8B87F71C7C4740
19153	2	21	403	2587	57181	\N	47.174596000000001	Астраханская область, Енотаевский район, с.Владимировка, А.Кенжиева, 18		0101000020E610000060394206F28447409701672959964740
19161	2	21	403	3051	57227	\N	47.635055999999999	416220, Астраханская область, Енотаевский район, с.Ветлянка, Кирова, 20а, администрация		0101000020E6100000CC7C073F715047407590D78349D14740
19135	2	21	60	1546	57209	\N	46.324275	416181, Астраханская область, Володарский район, с.Ямное, Новоямнинская, 1		0101000020E610000065A6B4FE965A484088F4DBD781294740
19144	2	21	60	2089	57279	\N	46.229058999999999	Астраханская область, Володарский район, с.Яблонка, Школьная, 54		0101000020E61000000188BB7A153148405FED28CE511D4740
19114	2	21	60	273	57113	\N	46.191870999999999	Астраханская область, Володарский район, с.Цветное, Молодежная, 25		0101000020E61000007F2F8507CD5C484081069B3A8F184740
19132	2	21	60	1371	57228	\N	46.440567000000001	416181, Астраханская область, Володарский район, с.Тюрино, Набережная, 19		0101000020E6100000C32B499EEB4F48403259DC7F64384740
19140	2	21	60	1832	56795	\N	46.235779999999998	Астраханская область, Володарский район, с.Тумак, Боевая, 1а		0101000020E6100000D6FECEF6E83F48408386FE092E1E4740
19137	2	21	60	1658	57144	\N	46.347776000000003	Астраханская область, Володарский район, с.Тулугановка, Молодежная, 7		0101000020E61000009BCB0D863A3A4840B72A89EC832C4740
19128	2	21	60	1152	57143	\N	46.385137	Астраханская область, Володарский район, п.Трубный, Комсомольская, 26		0101000020E6100000529CA38E8E45484062BD512B4C314740
19139	2	21	60	1781	56942	\N	46.017217000000002	Астраханская область, Володарский район, с.Тишково, Советская, 9		0101000020E6100000062B4EB5164E4840B6F7A92A34024740
19116	2	21	60	436	57170	\N	46.252533	Астраханская область, Володарский район, с.Сорочье, И.Алтынсарина, 63		0101000020E61000001689096AF85A48409414580053204740
19141	2	21	60	1895	56872	\N	46.2127709483293	Астраханская область, Володарский район, с.Сизый Бугор, Нариманова, 172	Россия, Астраханская область, Володарский район, село Сизый Бугор	0101000020E610000098C0ADBB79404840C34483143C1B4740
19143	2	21	60	2015	57255	\N	46.241165000000002	Астраханская область, Володарский район, с.Сахма, Заречная, 71		0101000020E61000007171546EA23A48404DF8A57EDE1E4740
19133	2	21	60	1426	57246	\N	46.468729000000003	Астраханская область, Володарский район, п.Самойловский, Заводская, 2а		0101000020E610000056D80C7041584840E9D7D64FFF3B4740
19134	2	21	60	1489	57230	\N	46.391483999999998	Астраханская область, Володарский район, с.Разбугорье, Д.Нурпеисовой, 36		0101000020E6100000E4A25A44144D48402174D0251C324740
19122	2	21	60	779	57145	\N	46.370271228391502	Астраханская область, Володарский район, с.Новый Рычан, Центральная, 9	Россия, Астраханская область, Володарский район, село Новый Рычан	0101000020E6100000F46C567DAE2E484020D4450A652F4740
19130	2	21	60	1263	57206	\N	46.444398	Астраханская область, Володарский район, с.Новокрасное, Советская, 17		0101000020E61000004F3C670B086B484033349E08E2384740
19125	2	21	60	944	57226	\N	46.276806000000001	Астраханская область, Володарский район, с.Нововасильево, Жукова, 25		0101000020E610000073A087DA3668484015AB06616E234740
94412	2	21	60	21449	57172	\N	46.282350000000001	Астраханская область, Володарский район, с.Новинка, Центральная, 21		0101000020E61000002AC58EC6A14648404703780B24244740
19138	2	21	60	1713	57229	\N	46.280456000000001	Астраханская область, Володарский район, с.Нижняя Султановка, Школьная, 7а		0101000020E61000002B6C06B8203B4840C6FB71FBE5234740
19123	2	21	60	848	57140	\N	46.324317999999998	Астраханская область, Володарский район, с.Мултаново, Центральная, 10		0101000020E6100000D7F9B7CB7E63484087C0914083294740
19109	2	21	60	32438	56842	\N	46.405182000000003	Астраханская область, Володарский район, с.Марфино, Проходная, 3		0101000020E61000002157EA59105C4840C576F700DD334740
19110	2	21	60	32438	56940	\N	46.405182000000003	Астраханская область, Володарский район, с.Марфино, Победы, 41		0101000020E61000002157EA59105C4840C576F700DD334740
19121	2	21	60	729	57153	\N	46.167797	Астраханская область, Володарский район, с.Маково, Мыльникова, 24		0101000020E6100000B1E07EC003534840F7AE415F7A154740
19127	2	21	60	1080	57280	\N	46.380966000000001	Астраханская область, Володарский район, с.Лебяжье, Бакушина, 18а		0101000020E61000001DCBBBEA015F4840A8716F7EC3304740
18321	2	21	60	26437	57110	\N	46.265735999999997	Астраханская область, Володарский район, с.Крутое, Школьная, 22		0101000020E6100000B0C7444AB351484057AF22A303224740
19129	2	21	60	1199	57250	\N	46.432051999999999	Астраханская область, Володарский район, п.Костюбе, Набережная, 2		0101000020E6100000EF1AF4A5B7374840F015DD7A4D374740
19120	2	21	60	656	57283	\N	46.308228	Астраханская область, Володарский район, с.Коровье, Юрия Суюнчалиева, 16в		0101000020E6100000B0389CF9D54A484012DBDD0374274740
19131	2	21	60	1314	56877	\N	46.418709	Астраханская область, Володарский район, с.Козлово, 30 лет Победы, 2а		0101000020E610000071AC8BDB684848403BC5AA4198354740
19118	2	21	60	562	57205	\N	46.274775291322499	Астраханская область, Володарский район, п.Камардан, Гагарина, 8	Россия, Астраханская область, Володарский район, село Камардан	0101000020E6100000EA5910CAFB4648401361C3D32B234740
19126	2	21	60	1045	57180	\N	46.342748999999998	Астраханская область, Володарский район, с.Калинино, Ленина, 9а		0101000020E6100000F433F5BA457048404CDE0033DF2B4740
19119	2	21	60	599	57251	\N	46.226416	Астраханская область, Володарский район, с.Казенный Бугор, Школьная, 6		0101000020E61000008F5033A48A54484044A51133FB1C4740
19166	2	21	60	57121	64919	\N	46.364286800816203	Астраханская область, Икрянинский район, Рабочий поселок Ильинка, Пионерская, 85	Россия, Астраханская область, Володарский район, село Ильинка	0101000020E610000041B96DDFA3504840D1ADD7F4A02E4740
19168	2	21	60	57121	57039	\N	46.364846059242097	Астраханская область, Икрянинский район, Рабочий поселок Ильинка, Ленина, 33	Россия, Астраханская область, Володарский район, село Ильинка	0101000020E610000044882B67EF504840C8091346B32E4740
19113	2	21	60	218	56792	\N	46.176884000000001	Астраханская область, Володарский район, с.Зеленга, Советская, 32		0101000020E6100000C18BBE82344F4840C4978922A4164740
19108	2	21	60	20953	56791	\N	46.399743999999998	Астраханская область, Володарский район, п.Володарский, Чехова, 5а		0101000020E61000002E3D9AEAC9444840D862B7CF2A334740
19105	2	21	60	20953	56788	\N	46.399743999999998	Астраханская область, Володарский район, п.Володарский, Суворова, 3		0101000020E61000002E3D9AEAC9444840D862B7CF2A334740
18203	2	21	60	20953	56873	\N	46.399743999999998	Астраханская область, Володарский район, п.Володарский, Победы, 2		0101000020E61000002E3D9AEAC9444840D862B7CF2A334740
19107	2	21	60	20953	56790	\N	46.399743999999998	Астраханская область, Володарский район, п.Володарский, Маяковского, 44		0101000020E61000002E3D9AEAC9444840D862B7CF2A334740
19106	2	21	60	20953	56939	\N	46.399743999999998	Астраханская область, Володарский район, п.Володарский, Алешина, 4а		0101000020E61000002E3D9AEAC9444840D862B7CF2A334740
19136	2	21	60	1598	57118	\N	46.472383999999998	Астраханская область, Володарский район, п.Винный, Лати Каримова, 2		0101000020E6100000473EAF78EA234840AB933314773C4740
19111	2	21	60	73	57089	\N	46.312660000000001	Астраханская область, Володарский район, с.Большой Могой, Советская, 48		0101000020E61000005AF5B9DA8A53484039622D3E05284740
19112	2	21	60	136	57252	\N	46.350636999999999	Астраханская область, Володарский район, с.Болдырево, Молодежный, 12		0101000020E6100000D4B5F63E554948403FE257ACE12C4740
19124	2	21	60	927	57277	\N	46.262701999999997	Астраханская область, Володарский район, с.Блиново, Абая, 58		0101000020E61000003201BF4692704840014C1938A0214740
19142	2	21	60	1942	57276	\N	46.282131999999997	Астраханская область, Володарский район, с.Ахтерек, Набережная, 85		0101000020E6100000709692E5242C4840D993C0E61C244740
19117	2	21	60	457	56794	\N	46.275672999999998	Астраханская область, Володарский район, с.Алтынжар, Центральная, 26		0101000020E6100000BBB9F8DB9E404840F2B1BB4049234740
19115	2	21	60	346	57265	\N	46.181314	Астраханская область, Володарский район, с.Алексеевка, Г.Жукова, 1		0101000020E610000016A1D80A9A5848404A27124C35174740
19065	2	21	1175	30330	57134	\N	48.204379000000003	Астраханская область, Ахтубинский район, село Успенска, Школьная, 15		0101000020E6100000782975C9381E47409E7E5017291A4840
19073	2	21	1175	30734	57091	\N	47.746335999999999	Астраханская область, Ахтубинский район, село Удаченое, пер.Коммунальный, 6		0101000020E61000007DE6AC4F39664740EAE923F087DF4740
19083	2	21	1175	31214	57275	\N	48.210047366319699	Астраханская область, Ахтубинский район, Пос. Средний Баскунчак, Космонавтов, 44	Россия, Астраханская область, Ахтубинский район, село Средний Баскунчак	0101000020E610000038C0CC77F0654740BCCFF1D1E21A4840
19324	2	21	1175	11162	64916	\N	48.515418392405799	Астраханская область, Наримановский район, с.Солянка, Ленина, 3Б	Россия, Астраханская область, Ахтубинский район, село Солянка	0101000020E610000026DF6C7363F0464086E28E37F9414840
19326	2	21	1175	11162	56925	\N	48.515304999999998	Астраханская область, Наримановский район, с.Солянка, Геологическая, 65 кв.15		0101000020E6100000D6E6FF5547F046408E3BA583F5414840
19056	2	21	1175	57148	57309	\N	46.387580999999997	Астраханская область, Ахтубинский район, Село Садовое, Набережная, 154 А		0101000020E6100000AA0EB9196E02484086C613419C314740
19055	2	21	1175	57148	57309	\N	48.3248443918813	Астраханская область, Ахтубинский район, Село Садовое, Набережная, 62	Россия, Астраханская область, Ахтубинский район	0101000020E61000005839B4C876104740A226FA7C94294840
19062	2	21	1175	30196	57248	\N	48.480252999999998	Астраханская область, Ахтубинский район, село Пологое Займище, Братская, 5		0101000020E61000000A849D62D5F84640276728EE783D4840
19063	2	21	1175	30196	57141	\N	48.480252999999998	Астраханская область, Ахтубинский район, село Пологое Займище, 60 лет СССР, 19		0101000020E61000000A849D62D5F84640276728EE783D4840
19064	2	21	1175	57139	57199	\N	48.363912119413698	Астраханская область, Ахтубинский район, село Покровска, Почтовая, 14		0101000020E610000024D5777E510A47409C4F1DAB942E4840
19071	2	21	1175	30618	57112	\N	47.882342952835899	Астраханская область, Ахтубинский район, Село Пироговка, Ленина, 106	Россия, Астраханская область, Ахтубинский район, село Пироговка	0101000020E61000009BE447FC8A514740616D8C9DF0F04740
19067	2	21	1175	30423	57111	\N	48.054431000000001	Астраханская область, Ахтубинский район, Село Ново-Николаевка, Молодежная, 1		0101000020E6100000486E4DBA2D2F4740BD715298F7064840
19082	2	21	1175	31131	\N	\N	48.220218000000003	Астраханская область, Ахтубинский район, Пос.Нижний Баскунчак, Красноармейская, 39	Россия, Астраханская область, Ахтубинский район, поселок Нижний Баскунчак	0101000020E61000006F2EFEB6276A4740CAFE791A301C4840
19081	2	21	1175	31131	56885	\N	48.220218000000003	Астраханская область, Ахтубинский район, Пос. Нижний Баскунчак, М.Горького, 27		0101000020E61000006F2EFEB6276A4740CAFE791A301C4840
19060	2	21	1175	29009	57166	\N	48.402079999999998	Астраханская область, Ахтубинский район, село Капустин Яр, Советская, 134Б		0101000020E61000008C2B2E8ECAD946401630815B77334840
19036	2	21	1175	29009	57131	\N	48.402079999999998	Астраханская область, Ахтубинский район, село Капустин Яр, Октябрьская, 4		0101000020E61000008C2B2E8ECAD946401630815B77334840
19061	2	21	1175	29009	57136	\N	48.402937224697098	Астраханская область, Ахтубинский район, село Капустин Яр, Московская, 90	Россия, Астраханская область, Ахтубинский район, село Капустин Яр	0101000020E61000003E03EACDA8D9464097AC8A7093334840
19058	2	21	1175	29009	57171	\N	48.402079999999998	416510, Астраханская область, Ахтубинский район, село Капустин Яр, Лесная, 37		0101000020E61000008C2B2E8ECAD946401630815B77334840
19059	2	21	1175	29009	57132	\N	48.402079999999998	Астраханская область, Ахтубинский район, село Капустин Яр, Кирова, 8		0101000020E61000008C2B2E8ECAD946401630815B77334840
19072	2	21	1175	30696	56883	\N	47.807820999999997	Астраханская область, Ахтубинский район, село Золотуха, Ленина, 42		0101000020E6100000417FA1478C5C4740D102B4AD66E74740
19051	2	21	1175	57108	57026	\N	48.585447319743103	ЗАТО Знаменск, ул.Волгоградская, д.14-А	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E61000002ACAA5F10BDB46404A4563EDEF4A4840
19052	2	21	1175	57108	56891	\N	48.587725053930697	ЗАТО Знаменск, пр-т.9 Мая, д.2Б	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E6100000494DBB9866DC46405305A3923A4B4840
19053	2	21	1175	57108	56996	\N	48.590945736180799	ЗАТО Знаменск, ул.Янгеля, д.5	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E6100000C974E8F4BCDB4640DCD9571EA44B4840
19049	2	21	1175	57108	57034	\N	48.583041350867497	ЗАТО Знаменск, ул.Пионерская, д.2А	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E610000096CE876709DC4640139D6516A14A4840
19048	2	21	1175	57108	56980	\N	48.582774409350797	ЗАТО Знаменск, ул.Ленина, д.43	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E61000000C0742B280DD4640C47AA356984A4840
19050	2	21	1175	57108	57013	\N	48.584906342698602	ЗАТО Знаменск, ул.Волгоградская, д.12-А	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E610000023BC3D0801DB4640F99D2633DE4A4840
19046	2	21	1175	57108	57057	\N	48.582951480715302	ЗАТО Знаменск, ул.Ватутина, д.16	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E61000005260014C19DE4640D3156C239E4A4840
19054	2	21	1175	57108	56988	\N	48.592073815830702	ЗАТО Знаменск, ул.Янгеля, д.8	Россия, Астраханская область, Ахтубинский район, Знаменск	0101000020E6100000A452EC681CDC4640EC67B114C94B4840
19079	2	21	1175	30808	56884	\N	48.226652999999999	Астраханская область, Ахтубинский район, Пос. Верхний Баскунчак, Степная, 75		0101000020E61000000CCA349A5C5C474028452BF7021D4840
19078	2	21	1175	30808	57167	\N	48.225563291129703	Астраханская область, Ахтубинский район, Пос. Верхний Баскунчак, Советская, 36		0101000020E61000001E19ABCDFF5B47400518963FDF1C4840
19077	2	21	1175	30808	57167	\N	48.226652999999999	Астраханская область, Ахтубинский район, Пос. Верхний Баскунчак, Советская, 30		0101000020E61000000CCA349A5C5C474028452BF7021D4840
19080	2	21	1175	30808	56785	\N	48.226652999999999	Астраханская область, Ахтубинский район, Пос. Верхний Баскунчак, Рабочая, 2		0101000020E61000000CCA349A5C5C474028452BF7021D4840
19076	2	21	1175	30808	57137	\N	48.226652999999999	Астраханская область, Ахтубинский район, Пос. Верхний Баскунчак, ДЖАМБУЛА, 18		0101000020E61000000CCA349A5C5C474028452BF7021D4840
19075	2	21	1175	30808	57137	\N	48.226652999999999	Астраханская область, Ахтубинский район, Поселок Верхний Баскунчак, Джамбула, 22А		0101000020E61000000CCA349A5C5C474028452BF7021D4840
19074	2	21	1175	30808	57114	\N	48.225967661852998	Астраханская область, Ахтубинский район, пос. Верхний Баскунчак, Абая, 17		0101000020E610000075CDE49B6D5C4740A5F8F884EC1C4840
18674	2	21	1175	11592	57281	\N	47.725453000000002	Астраханская область, Ахтубинский район, пос.Верблюжий, Школьная, 1		0101000020E61000004DA25EF0697047407EE4D6A4DBDC4740
19069	2	21	1175	30487	56933	\N	47.990316	416523, Астраханская область, Ахтубинский район, Село Болхуны, Школьная, 20 (помещение школы)		0101000020E610000059A31EA2D13547404F5AB8ACC2FE4740
19066	2	21	1175	30400	57287	\N	48.140644000000002	Астраханская область, Ахтубинский район, село Батаевска, Школьная, 1		0101000020E6100000496760E4652547407730629F00124840
14563	1	17	\N	46844	\N	\N	57.687187000000002	р.п. Лесная Поляна, д. 37 ( Дом культуры)		0101000020E6100000F433F5BA45F24340419E5DBEF5D74C40
14307	1	17	\N	50639	23168	\N	57.763852	адрес помещения для голосования: д. Заболотье, ул. Школьная, д. 1, адрес УИК: д. Веретево, ул. Лесная, д.5		0101000020E61000002FDD240681A14340FA7DFFE6C5E14C40
14001	1	17	\N	2085	\N	\N	57.544486999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, поселок Прибрежный, 18а	Россия, Ярославская область, Ярославль, поселок Прибрежный, 18	0101000020E6100000BB44F5D6C0FC43406F0C01C0B1C54C40
14000	1	17	\N	2085	\N	\N	57.556362	Ярославская область, Городской округ Ярославль, Фрунзенский район, поселок Октябрьский, 19	Россия, Ярославская область, Ярославль, поселок Октябрьский, 19	0101000020E610000003B2D7BB3FFA43405B5EB9DE36C74C40
13977	1	17	\N	2085	2071	\N	57.640675999999999	Ярославская область, Городской округ Ярославль, Ленинский район, Юности, 15	Россия, Ярославская область, Ярославль, улица Юности, 15	0101000020E6100000C558A65F22E8434082AAD1AB01D24C40
14003	1	17	\N	2085	2431	\N	57.551495000000003	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Щепкина, 8	Россия, Ярославская область, Ярославль, улица Щепкина, 8	0101000020E6100000BE840A0E2FF843402A745E6397C64C40
14002	1	17	\N	2085	2431	\N	57.552836999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Щепкина, 10	Россия, Ярославская область, Ярославль, улица Щепкина, 10	0101000020E61000008F6CAE9AE7F843406682E15CC3C64C40
13981	1	17	\N	2085	2027	\N	57.637963999999997	Ярославская область, Городской округ Ярославль, Ленинский район, Чкалова, 34	Россия, Ярославская область, Ярославль, улица Чкалова, 34	0101000020E6100000834F73F222EB43403E03EACDA8D14C40
13974	1	17	\N	2085	2027	\N	57.638109	Ярославская область, Городской округ Ярославль, Ленинский район, Чкалова, 26	Россия, Ярославская область, Ярославль, улица Чкалова, 26	0101000020E61000009C8C2AC3B8EB43404224438EADD14C40
13747	1	17	\N	2085	7220	\N	57.685512000000003	город Ярославль, Урицкого, 32а	Россия, Ярославская область, Ярославль, улица Урицкого, 32а	0101000020E6100000F12A6B9BE2E54340FE8172DBBED74C40
13971	1	17	\N	2085	1994	\N	57.633161000000001	Ярославская область, Городской округ Ярославль, Ленинский район, Тургенева, 14	Россия, Ярославская область, Ярославль, улица Тургенева, 14	0101000020E610000078962023A0EC4340240D6E6B0BD14C40
13885	1	17	\N	2085	725	\N	57.691574000000003	город Ярославль, Туманова, 18в	Россия, Ярославская область, Ярославль, улица Туманова, 18в	0101000020E610000076DF313CF6E14340C861307F85D84C40
13893	1	17	\N	2085	646	\N	57.686647999999998	город Ярославль, Труфанова, 25а	Россия, Ярославская область, Ярославль, улица Труфанова, 25а	0101000020E6100000BDAB1E300FE1434091EEE714E4D74C40
13880	1	17	\N	2085	646	\N	57.679189999999998	город Ярославль, Труфанова, 4	Россия, Ярославская область, Ярославль, улица Труфанова, 4	0101000020E610000078EE3D5C72E4434097E2AAB2EFD64C40
13961	1	17	\N	2085	1856	\N	57.608637000000002	Ярославская область, Городской округ Ярославль, Красноперекопский район, Стачек, 53	Россия, Ярославская область, Ярославль, улица Стачек, 53	0101000020E6100000880D164ED2EA43405A1135D1E7CD4C40
13931	1	17	\N	2085	1457	\N	57.628072000000003	Ярославская область, Городской округ Ярославль, Кировский район, улица Собинова, 22	Россия, Ярославская область, Ярославль, улица Собинова, 22	0101000020E610000005DEC9A7C7F0434044C4CDA964D04C40
14015	1	17	\N	2085	2623	\N	57.580883	Ярославская область, Городской округ Ярославль, Фрунзенский район, Слепнева, 26	Россия, Ярославская область, Ярославль, улица Слепнева, 26	0101000020E610000059FAD005F5ED4340B4E6C75F5ACA4C40
13970	1	17	\N	2085	1987	\N	57.631025999999999	Ярославская область, Городской округ Ярославль, Ленинский район, Свердлова, 62	Россия, Ярославская область, Ярославль, улица Свердлова, 62	0101000020E6100000B9FFC874E8EE43407D76C075C5D04C40
13909	1	17	\N	2085	1090	\N	57.644077000000003	город Ярославль, улица Саукова, 5	Россия, Ярославская область, Ярославль, улица Саукова, 5	0101000020E61000004F081D7409F943408B8D791D71D24C40
13908	1	17	\N	2085	1090	\N	57.645767999999997	город Ярославль, улица Саукова, 13	Россия, Ярославская область, Ярославль, улица Саукова, 13	0101000020E61000003F8F519E79F94340D3669C86A8D24C40
13941	1	17	\N	2085	1534	\N	57.622891000000003	Ярославская область, Городской округ Ярославль, Кировский район, улица Салтыкова-Щедрина, 75	Россия, Ярославская область, Ярославль, улица Салтыкова-Щедрина, 75	0101000020E6100000B37C5D86FFEC434083FC6CE4BACF4C40
13951	1	17	\N	2085	1727	\N	57.578223999999999	Ярославская область, Городской округ Ярославль, Красноперекопский район, Рыкачева, 1	Россия, Ярославская область, Ярославль, улица Рыкачева, 1	0101000020E610000085D21742CEEB434093E1783E03CA4C40
13936	1	17	\N	2085	1516	\N	57.624063	Ярославская область, Городской округ Ярославль, Кировский район, улица Победы, 46	Россия, Ярославская область, Ярославль, улица Победы, 46	0101000020E6100000EBAA402D06EF434063D2DF4BE1CF4C40
13944	1	17	\N	2085	1642	\N	57.627170999999997	Ярославская область, Городской округ Ярославль, Кировский район, улица Павлика Морозова, 3	Россия, Ярославская область, Ярославль, улица Павлика Морозова, 3	0101000020E6100000715985CD00EB4340F3FFAA2347D04C40
13963	1	17	\N	2085	1868	\N	57.602609000000001	Ярославская область, Городской округ Ярославль, Красноперекопский район, Маланова, 14	Россия, Ярославская область, Ярославль, улица Маланова, 14	0101000020E610000012DBDD0374E943403CA3AD4A22CD4C40
13950	1	17	\N	2085	1714	\N	57.579946999999997	Ярославская область, Городской округ Ярославль, Красноперекопский район, Курчатова, 3	Россия, Ярославская область, Ярославль, улица Курчатова, 5	0101000020E6100000C7D6338463EC4340E7340BB43BCA4C40
13975	1	17	\N	2085	2041	\N	57.635584000000001	Ярославская область, Городской округ Ярославль, Ленинский район, Кудрявцева, 28	Россия, Ярославская область, Ярославль, улица Кудрявцева, 28	0101000020E610000000AAB8718BEB434031EE06D15AD14C40
14007	1	17	\N	2085	2518	\N	57.583478999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Кривова, 4	Россия, Ярославская область, Ярославль, улица Кривова, 4	0101000020E6100000CDAB3AAB05F043408E739B70AFCA4C40
13920	1	17	\N	2085	1273	\N	57.729115	город Ярославль, улица Комарова, 1а	Россия, Ярославская область, Ярославль, улица Комарова, 1а	0101000020E61000005EF415A419E94340F302ECA353DD4C40
14022	1	17	\N	2085	2746	\N	57.570400999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Калинина, 37а	Россия, Ярославская область, Ярославль, улица Калинина, 37а	0101000020E61000005DDDB1D826EF4340874D64E602C94C40
14021	1	17	\N	2085	2746	\N	57.570974999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Калинина, 35а	Россия, Ярославская область, Ярославль, улица Калинина, 35а	0101000020E6100000A52C431CEBEE4340B3EA73B515C94C40
13979	1	17	\N	2085	2101	\N	57.640965999999999	Ярославская область, Городской округ Ярославль, Ленинский район, Жукова, 7а	Россия, Ярославская область, Ярославль, улица Жукова, 7а	0101000020E6100000D0EFFB372FEA434089EC832C0BD24C40
13881	1	17	\N	2085	632	\N	57.674700000000001	город Ярославль, Елены Колесовой, 70	Россия, Ярославская область, Ярославль, улица Елены Колесовой, 70	0101000020E610000093020B60CAE443403C4ED1915CD64C40
13823	1	17	\N	2085	632	\N	57.680425999999997	город Ярославль, Елены Колесовой, 38	Россия, Ярославская область, Ярославль, улица Елены Колесовой, 38	0101000020E61000009F76F86BB2E643408EACFC3218D74C40
13891	1	17	\N	2085	687	\N	57.679541	город Ярославль, Громова, 36	Россия, Ярославская область, Ярославль, улица Громова, 36	0101000020E6100000CC608C4814E2434044A51133FBD64C40
14011	1	17	\N	2085	2571	\N	57.592761000000003	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Гоголя, 7	Россия, Ярославская область, Ярославль, улица Гоголя, 7	0101000020E61000005C001AA54BEF434011ACAA97DFCB4C40
13965	1	17	\N	2085	1902	\N	57.608944999999999	Ярославская область, Городской округ Ярославль, Красноперекопский район, Бахвалова, 3	Россия, Ярославская область, Ярославль, улица Бахвалова, 3	0101000020E610000044E048A0C1E843400708E6E8F1CD4C40
13874	1	17	\N	2085	556	\N	57.713470000000001	город Ярославль, 1905 года, 6	Россия, Ярославская область, Ярославль, улица 1905-го года, 6	0101000020E61000006325E65949E34340AC5626FC52DB4C40
14010	1	17	\N	2085	2394	\N	57.598443000000003	Ярославская область, Городской округ Ярославль, Фрунзенский район, проспект Фрунзе, 8	Россия, Ярославская область, Ярославль, проспект Фрунзе, 8	0101000020E61000001D925A2899F0434094C2BCC799CC4C40
13999	1	17	\N	2085	2394	\N	57.566496000000001	Ярославская область, Городской округ Ярославль, Фрунзенский район, проспект Фрунзе, 75а	Россия, Ярославская область, Ярославль, проспект Фрунзе, 75а	0101000020E61000002D077AA86DF743404CA8E0F082C84C40
13972	1	17	\N	2085	1968	\N	57.634293	Ярославская область, Городской округ Ярославль, Ленинский район, Ленина, 24а	Россия, Ярославская область, Ярославль, проспект Ленина, 24а	0101000020E61000004CFBE6FEEAED4340768A558330D14C40
13890	1	17	\N	2085	808	\N	57.677433000000001	город Ярославль, Архангельский проезд, 13	Россия, Ярославская область, Ярославль, Архангельский проезд, 13	0101000020E610000045D4449F8FE24340971DE21FB6D64C40
13969	1	17	\N	2085	1968	\N	57.636195999999998	Ярославская область, Городской округ Ярославль, Ленинский район, Ленина, 27	Россия, Ярославская область, Ярославль, проспект Ленина, 27	0101000020E61000004BE7C3B304EF43404AECDADE6ED14C40
13887	1	17	\N	2085	753	\N	57.687848818820697	город Ярославль, проспект Дзержинского, 21	Россия, Ярославская область, Ярославль, проспект Дзержинского, 21	0101000020E610000003D2FE0758E543400CCB9F6F0BD84C40
13907	1	17	\N	2085	963	\N	57.651808000000003	город Ярославль, проспект Авиаторов, 84	Россия, Ярославская область, Ярославль, проспект Авиаторов, 84	0101000020E6100000CD936B0A64F84340B6A2CD716ED34C40
13901	1	17	\N	2085	963	\N	57.644227000000001	город Ярославль, проспект Авиаторов, 37	Россия, Ярославская область, Ярославль, проспект Авиаторов, 37	0101000020E61000000B992B836AF54340A019C40776D24C40
14019	1	17	\N	2085	2704	\N	57.574430999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, проезд Ушакова, 11	Россия, Ярославская область, Ярославль, проезд Ушакова, 11	0101000020E6100000BF81C98D22ED43407F677BF486C94C40
14016	1	17	\N	2085	2655	\N	57.576352	Ярославская область, Городской округ Ярославль, Фрунзенский район, проезд Подвойского, 11	Россия, Ярославская область, Ярославль, проезд Подвойского, 11	0101000020E610000063EC8497E0EC4340FA7DFFE6C5C94C40
13894	1	17	\N	2085	858	\N	57.702612999999999	адрес помещения для голосования: город Ярославль, проезд Моторостроителей, 10, адрес УИК: город Ярославль,  Строителей, 21	Россия, Ярославская область, Ярославль, проезд Моторостроителей, 10	0101000020E61000008C834BC79CE143404A5F0839EFD94C40
14020	1	17	\N	2085	2722	\N	57.573909999999998	Ярославская область, Городской округ Ярославль, Фрунзенский район, проезд Матросова, 9	Россия, Ярославская область, Ярославль, проезд Матросова, 9	0101000020E610000071917BBABAED4340766C04E275C94C40
13912	1	17	\N	2085	1145	\N	57.653565	город Ярославль, проезд Доброхотова, 8	Россия, Ярославская область, Ярославль, проезд  Доброхотова, 8	0101000020E6100000CF66D5E76AF94340B6679604A8D34C40
14331	1	17	\N	2085	22947	\N	57.568045732951198	адрес помещения для голосования:  п.Пречистое,ул.Ярославская, д.92, адрес УИК:  п.Пречистое,ул.Ярославская, д.90	Россия, Ярославская область, Ярославль, Ярославская улица	0101000020E6100000E84CDA54DDF54340D34F38BBB5C84C40
14330	1	17	\N	2085	22947	\N	57.568714467037701	адрес помещения для голосования: п.Пречистое,ул.Ярославская, д.86, адрес УИК: п.Пречистое,ул.Ярославская, д.90	Россия, Ярославская область, Ярославль, Ярославская улица	0101000020E6100000EEEC2B0FD2F543408063CF9ECBC84C40
13915	1	17	\N	2085	1180	\N	57.648103999999996	город Ярославль, Школьный проезд, 15	Россия, Ярославская область, Ярославль, Школьный проезд, 15	0101000020E6100000D670917BBAFA434011346612F5D24C40
13914	1	17	\N	2085	1180	\N	57.649414	город Ярославль, Школьный проезд, 13	Россия, Ярославская область, Ярославль, Школьный проезд, 13	0101000020E610000093020B60CAFA434043C879FF1FD34C40
13929	1	17	\N	2085	24133	\N	57.633306655704601	Ярославская область, Городской округ Ярославль, Кировский район, улица Чайковского, 55	Россия, Ярославская область, Ярославль, улица Чайковского, 55	0101000020E6100000618DB3E908F04340F8A92A3410D14C40
14321	1	17	\N	2085	5966	\N	57.651922999999996	адрес помещения для голосования: д.Ефимовское, ул.Центральная, д.25, адрес УИК:  д.Ефимовское, ул.Центральная, д.26	Россия, Ярославская область, Ярославль, Центральная улица, 25	0101000020E6100000A0C6BDF90DF743404E417E3672D34C40
13976	1	17	\N	2085	1547	\N	57.634481000000001	Ярославская область, Городской округ Ярославль, Ленинский район, Угличская, 60	Россия, Ярославская область, Ярославль, Угличская улица, 60	0101000020E61000007D59DAA9B9E84340797764AC36D14C40
13938	1	17	\N	2085	1547	\N	57.62706	Ярославская область, Городской округ Ярославль, Кировский район, улица Угличская, 1/51	Россия, Ярославская область, Ярославль, Угличская улица, 1/51	0101000020E610000023A12DE752EE43409C50888043D04C40
13943	1	17	\N	2085	24090	\N	57.629189527293903	Ярославская область, Городской округ Ярославль, Кировский район, улица Угличская, 27	Россия, Ярославская область, Ярославль, Угличская улица, 27	0101000020E6100000FE2955A2ECEB4340317C444C89D04C40
13878	1	17	\N	2085	568	\N	57.674140999999999	город Ярославль, Тутаевское шоссе, 13	Россия, Ярославская область, Ярославль, Тутаевское шоссе, 13	0101000020E6100000D0622992AFEA434045F295404AD64C40
13875	1	17	\N	2085	568	\N	57.700136000000001	город Ярославль, Тутаевское шоссе, 74	Россия, Ярославская область, Ярославль, Тутаевское шоссе, 74	0101000020E610000003D19332A9E543404A60730E9ED94C40
13990	1	17	\N	2085	24117	\N	57.610013612867697	Ярославская область, город Ярославль, Фрунзенский район, ул.Туговская, 11	Россия, Ярославская область, Ярославль, Туговская улица, 11	0101000020E61000007E3672DD94F24340130D52F014CE4C40
13892	1	17	\N	2085	24104	\N	57.685232999999997	город Ярославль, Труфанова, 21а		0101000020E6100000DE9387855AE14340EA9106B7B5D74C40
13884	1	17	\N	2085	24104	\N	57.682648999999998	город Ярославль, Труфанова, 16		0101000020E61000000BB77C2425E34340D4D2DC0A61D74C40
13996	1	17	\N	2085	24118	\N	57.575000000000003	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Театральная, 21		0101000020E6100000153AAFB14BF643409A99999999C94C40
13900	1	17	\N	2085	944	\N	57.630293999999999	город Ярославль, Тверицкая набережная, 58а	Россия, Ярославская область, Ярославль, Тверицкая набережная, 58а	0101000020E6100000CA6B257497F44340B96E4A79ADD04C40
13916	1	17	\N	2085	1211	\N	57.655501000000001	город Ярославль, улица Алмазная, 25б	Россия, Ярославская область, Ярославль, Алмазная улица, 25	0101000020E61000003D80457EFDF6434066BFEE74E7D34C40
14009	1	17	\N	2085	2529	\N	57.597482999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, Суздальское шоссе, 15	Россия, Ярославская область, Ярославль, Суздальское шоссе, 15	0101000020E61000000DA661F888F043403E75AC527ACC4C40
14008	1	17	\N	2085	2529	\N	57.601649999999999	Ярославская область, Городской округ Ярославль, Фрунзенский район, Суздальское шоссе, 1	Россия, Ярославская область, Ярославль, Суздальское шоссе, 1	0101000020E6100000D7F6764B72F04340B7D100DE02CD4C40
13899	1	17	\N	2085	24096	\N	57.640155999999998	город Ярославль, Станция Урочь, 10		0101000020E6100000836A8313D1F34340492BBEA1F0D14C40
13997	1	17	\N	2085	24123	\N	57.572341000000002	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Спортивная, 4		0101000020E61000009F93DE37BEF6434079944A7842C94C40
13919	1	17	\N	2085	1258	\N	57.727645000000003	город Ярославль, улица Спартаковская, 7	Россия, Ярославская область, Ярославль, Спартаковская улица, 7	0101000020E61000005E81E84999E84340890CAB7823DD4C40
13904	1	17	\N	2085	24140	\N	57.6216930392455	город Ярославль, улица Союзная, 141	Россия, Ярославская область, Ярославль, Союзная улица, 141	0101000020E61000004F1E166A4DF743407993DFA293CF4C40
13927	1	17	\N	2085	1390	\N	57.632440214717398	Ярославская область, Городской округ Ярославль, Кировский район, улица Советская, 14	Россия, Ярославская область, Ярославль, Советская улица	0101000020E61000003332C85D84F1434054573ECBF3D04C40
13968	1	17	\N	2085	24128	\N	57.640416000000002	Ярославская область, Городской округ Ярославль, Ленинский район, Советская, 71		0101000020E610000076374F75C8EF4340E6EAC726F9D14C40
13967	1	17	\N	2085	24128	\N	57.639096000000002	Ярославская область, Городской округ Ярославль, Ленинский район, Советская, 68		0101000020E61000009E60FF756EF043409180D1E5CDD14C40
14018	1	17	\N	2085	23226	\N	57.578229	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Слепнева, 14а	Россия, Ярославская область, Ярославль, улица Слепнева, 14	0101000020E6100000CE8C7E349CEE4340A54C6A6803CA4C40
14014	1	17	\N	2085	23226	\N	57.580883	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Слепнева, 26		0101000020E610000059FAD005F5ED4340B4E6C75F5ACA4C40
13939	1	17	\N	2085	24102	\N	57.625933000000003	Ярославская область, Городской округ Ярославль, Кировский район, улица Свободы, 77		0101000020E61000008BA548BE12EE43405C3E92921ED04C40
13935	1	17	\N	2085	24102	\N	57.626033999999997	Ярославская область, Городской округ Ярославль, Кировский район, улица Свободы, 46		0101000020E6100000266E15C440EF43408F17D2E121D04C40
13998	1	17	\N	2085	2381	\N	57.569454999999998	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Светлая, 36	Россия, Ярославская область, Ярославль, Светлая улица, 36	0101000020E61000007AFD497CEEF6434097C5C4E6E3C84C40
14317	1	17	\N	2085	15729	\N	57.734444000000003	адрес помещения для голосования: д.Костромка, ул.Садовая, д.20, адрес УИК:  д.Костромка, ул.Полевая, д.8	Россия, Ярославская область, Ярославль, Садовая улица, 20	0101000020E61000002FF7C95180E24340295FD04202DE4C40
13942	1	17	\N	2085	1611	\N	57.624357000000003	Ярославская область, Городской округ Ярославль, Кировский район, улица Рыбинская, 51	Россия, Ярославская область, Ярославль, Рыбинская улица, 51	0101000020E6100000DAFF006BD5EC4340AC0320EEEACF4C40
13933	1	17	\N	2085	1443	\N	57.621499	Ярославская область, Городской округ Ярославль, Кировский район, улица Республиканская, 108		0101000020E61000007C7E18213CF0434094BF7B478DCF4C40
13930	1	17	\N	2085	1443	\N	57.632297999999999	Ярославская область, Городской округ Ярославль, Кировский район, улица Республиканская, 42	Россия, Ярославская область, Ярославль, Республиканская улица, 42	0101000020E61000006AFB57569AF04340C1A90F24EFD04C40
13925	1	17	\N	2085	1361	\N	57.624198	Ярославская область, Городской округ Ярославль, Кировский район, улица Революционная, 5	Россия, Ярославская область, Ярославль, Революционная улица, 5	0101000020E61000003E062B4EB5F24340431D56B8E5CF4C40
13945	1	17	\N	2085	22569	\N	57.630519999999997	Ярославская область, Городской округ Ярославль, Кировский район, Привокзальная площадь, 1а		0101000020E61000003C4A253CA1EB4340A9BC1DE1B4D04C40
13917	1	17	\N	2085	24139	\N	57.721853000000003	город Ярославль, улица Панфилова, 9а		0101000020E6100000B62BF4C132EA43407FC2D9AD65DC4C40
13955	1	17	\N	2085	24127	\N	57.589024180311299	Ярославская область, Городской округ Ярославль, Красноперекопский район, Павлова, 6		0101000020E6100000A0FA07910CEB43409147702365CB4C40
13953	1	17	\N	2085	24136	\N	57.583643000000002	Ярославская область, Городской округ Ярославль, Красноперекопский район, Нефтяников, 26		0101000020E6100000BAF59A1E14EA434009C556D0B4CA4C40
14013	1	17	\N	2085	1702	\N	57.583005999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, Московский проспект, 155	Россия, Ярославская область, Ярославль, Московский проспект, 155	0101000020E61000000C1EA67D73ED434096AFCBF09FCA4C40
14012	1	17	\N	2085	1702	\N	57.585692999999999	Ярославская область, Городской округ Ярославль, Фрунзенский район, Московский проспект, 151	Россия, Ярославская область, Ярославль, Московский проспект, 151	0101000020E610000044FAEDEBC0ED4340813FFCFCF7CA4C40
13958	1	17	\N	2085	1702	\N	57.606003999999999	Ярославская область, Городской округ Ярославль, Красноперекопский район, Московский проспект, 28	Россия, Ярославская область, Ярославль, Московский проспект, 28	0101000020E610000055FB743C66F04340629F008A91CD4C40
14026	1	17	\N	3130	22672	\N	58.045848999999997	г.Рыбинск, Космонавтов наб, 19		0101000020E6100000B3614D65516C4340F3C64961DE054D40
13980	1	17	\N	3130	22672	\N	58.045848999999997	г.Рыбинск, Космонавтов наб, 39		0101000020E6100000B3614D65516C4340F3C64961DE054D40
13956	1	17	\N	2085	1702	\N	57.586272000000001	Ярославская область, Городской округ Ярославль, Красноперекопский район, Московский проспект, 88	Россия, Ярославская область, Ярославль, Московский проспект, 88	0101000020E6100000B9C3263273ED4340BF47FDF50ACB4C40
13949	1	17	\N	2085	1702	\N	57.580824999999997	Ярославская область, Городской округ Ярославль, Красноперекопский район, Московский проспект, 92	Россия, Ярославская область, Ярославль, Московский проспект, 92	0101000020E6100000C2189128B4EC43407FD93D7958CA4C40
14288	1	17	\N	2085	15557	\N	57.612769	адрес помещения для голосования: п. Некрасовское, ул. Пролетарская, д.2, адрес УИК: п. Некрасовское, ул. Кооперативная, д.47	Россия, Ярославская область, Ярославль, Малая Пролетарская улица, 2	0101000020E610000053CA6B2574F143405680EF366FCE4C40
13962	1	17	\N	2085	24143	\N	57.605511999999997	Ярославская область, Городской округ Ярославль, Красноперекопский район, Маланова, 10		0101000020E6100000B2F4A10BEAE94340F3AACE6A81CD4C40
13946	1	17	\N	2085	24126	\N	57.639100999999997	Ярославская область, Городской округ Ярославль, Кировский район, улица Магистральная, 50		0101000020E61000007C48F8DEDFE44340A2EBC20FCED14C40
13960	1	17	\N	2085	1831	\N	57.603057999999997	Ярославская область, Городской округ Ярославль, Красноперекопский район, Лесная, 12	Россия, Ярославская область, Ярославль, Лесная улица, 12	0101000020E6100000F6D1A92B9FEB4340ABCB290131CD4C40
13889	1	17	\N	2085	690	\N	57.697057999999998	город Ярославль, Ленинградский проспект, 68а	Россия, Ярославская область, Ярославль, Ленинградский проспект, 68а	0101000020E61000005CE49EAEEEE2434024B5503239D94C40
13888	1	17	\N	2085	690	\N	57.695408	город Ярославль, Ленинградский проспект, 64а	Россия, Ярославская область, Ярославль, Ленинградский проспект, 64а	0101000020E6100000020CCB9F6FE343403AB01C2103D94C40
13883	1	17	\N	2085	690	\N	57.684578999999999	город Ярославль, Ленинградский проспект, 87	Россия, Ярославская область, Ярославль, Ленинградский проспект, 87	0101000020E6100000EE3EC7478BE34340A243E048A0D74C40
13872	1	17	\N	2085	533	\N	57.731076000000002	город Ярославль, Красноперевальский пер, 4	Россия, Ярославская область, Ярославль, Красноперевальский переулок, 4	0101000020E610000091ED7C3F35E24340FC71FBE593DD4C40
13921	1	17	\N	2085	22945	\N	57.7538350102256	город Ярославль, улица Колышкина, 47	Россия, Ярославская область, Ярославль, улица Колышкина	0101000020E61000009143C4CDA9E6434043CA4FAA7DE04C40
13906	1	17	\N	2085	1041	\N	57.609076000000002	город Ярославль, улица Клубная, 62	Россия, Ярославская область, Ярославль, Клубная улица, 62	0101000020E6100000D481ACA756FD4340A663CE33F6CD4C40
13905	1	17	\N	2085	1041	\N	57.606327	город Ярославль, улица Клубная, 19	Россия, Ярославская область, Ярославль, Клубная улица, 19	0101000020E61000001D76DF313CFA434045D7851F9CCD4C40
14004	1	17	\N	2085	2473	\N	57.550103999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, Индустриальный переулок, 10	Россия, Ярославская область, Ярославль, Индустриальный переулок, 10	0101000020E6100000A089B0E1E9F743400BB3D0CE69C64C40
13995	1	17	\N	2085	24144	\N	57.579386999999997	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Ильинская, 14		0101000020E610000083FC6CE4BAF54340205D6C5A29CA4C40
14006	1	17	\N	2085	2500	\N	57.559176999999998	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Звездная, 11	Россия, Ярославская область, Ярославль, Звездная улица, 11	0101000020E61000005C8FC2F528F6434073D6A71C93C74C40
13879	1	17	\N	2085	24113	\N	57.682172999999999	город Ярославль, Елены Колесовой, 26		0101000020E61000004A95287B4BE743406B9BE27151D74C40
14338	1	17	\N	2085	22949	\N	57.646515000000001	Ярославская область, Переславский  район,с.Новое, Дачная, 91		0101000020E61000005ABA826DC4F34340CDAFE600C1D24C40
13882	1	17	\N	2085	24115	\N	57.674146	город Ярославль, Громова, 10а		0101000020E6100000F65CA626C1E34340575D876A4AD64C40
13926	1	17	\N	2085	24130	\N	57.629026000000003	Ярославская область, Городской округ Ярославль, Кировский район, улица Волкова, 5		0101000020E6100000902DCBD765F24340B72A89EC83D04C40
14452	1	17	\N	2085	16352	\N	57.624896	п. Каменники, Волжская, 2а	Россия, Ярославская область, Ярославль, Волжская набережная, 2а	0101000020E6100000C097C28366F343405BB39597FCCF4C40
13993	1	17	\N	2085	24109	\N	57.604326	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Верхняя, 5а		0101000020E610000043AB933314F14340AE0FEB8D5ACD4C40
13959	1	17	\N	2085	1821	\N	57.609842	Ярославская область, Городской округ Ярославль, Красноперекопский район, Большая Федоровская, 62	Россия, Ярославская область, Ярославль, Большая Федоровская улица, 62	0101000020E61000001D56B8E523EF434016DD7A4D0FCE4C40
13940	1	17	\N	2085	1495	\N	57.620196999999997	Ярославская область, Городской округ Ярославль, Кировский район, улица Большая Октябрьская, 79	Россия, Ярославская область, Ярославль, Большая Октябрьская улица, 79	0101000020E610000041F0F8F6AEED4340E509849D62CF4C40
13934	1	17	\N	2085	1495	\N	57.622024000000003	Ярославская область, Городской округ Ярославль, Кировский район, улица Большая Октябрьская, 64а	Россия, Ярославская область, Ярославль, Большая Октябрьская улица, 64а	0101000020E61000006551D845D1EF4340DFA9807B9ECF4C40
13873	1	17	\N	2085	543	\N	57.718561000000001	город Ярославль, Б.Любимская, 71	Россия, Ярославская область, Ярославль, Большая Любимская улица, 71	0101000020E61000006A6CAF05BDE343402D978DCEF9DB4C40
13876	1	17	\N	2085	24132	\N	57.691769854350198	город Ярославль, Блюхера, 74		0101000020E61000001DC70F9546E643404D2D5BEB8BD84C40
14074	1	17	\N	3130	22926	\N	58.045848999999997	г. Рыбинск, Ярославский тракт, 43		0101000020E6100000B3614D65516C4340F3C64961DE054D40
13978	1	17	\N	2085	24146	\N	57.642514680644197	Ярославская область, Городской округ Ярославль, Ленинский район, Автозаводская, 69д	Россия, Ярославская область, Ярославль, Автозаводская улица, 69	0101000020E61000008847E2E5E9E84340401878EE3DD24C40
13994	1	17	\N	2085	2322	\N	57.598438000000002	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.2-я Портовая, 1	Россия, Ярославская область, Ярославль, 2-я Портовая улица, 1	0101000020E61000001D39D21918F543408257CB9D99CC4C40
13992	1	17	\N	2085	24100	\N	57.605874	Ярославская область, Городской округ Ярославль, Фрунзенский район, 2-я Полянская, 25		0101000020E6100000FC51D4997BF2434094BF7B478DCD4C40
13973	1	17	\N	2085	24125	\N	57.633378	Ярославская область, Городской округ Ярославль, Ленинский район, Щапова, 14		0101000020E61000001DE736E15EED4340C100C28712D14C40
13886	1	17	\N	2085	24134	\N	57.690412317170598	город Ярославль, Туманова, 10в	Россия, Ярославская область, Ярославль, улица Туманова, 10в	0101000020E6100000DCBA9BA73AE243400B62A06B5FD84C40
13928	1	17	\N	2085	24137	\N	57.635392000000003	Ярославская область, Городской округ Ярославль, Кировский район, улица Терешковой, 20		0101000020E61000009087BEBB95F14340ED116A8654D14C40
14017	1	17	\N	2085	24082	\N	57.578217012929102	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Слепнева, 14б	Россия, Ярославская область, Ярославль, улица Слепнева, 14	0101000020E6100000C5AEEDED96EE4340E17EC00303CA4C40
13913	1	17	\N	2085	24099	\N	57.652703000000002	город Ярославль, улица Серго Орджоникидзе, 35а		0101000020E6100000A662635E47FA434024809BC58BD34C40
13932	1	17	\N	2085	24145	\N	57.625194999999998	Ярославская область, Городской округ Ярославль, Кировский район, улица Свободы, 15		0101000020E61000000ABFD4CF9BF04340B54FC76306D04C40
13937	1	17	\N	2085	24105	\N	57.623984999999998	Ярославская область, Городской округ Ярославль, Кировский район, улица Салтыкова-Щедрина, 42а		0101000020E6100000F1457BBC90EE4340E71890BDDECF4C40
14005	1	17	\N	2085	24089	\N	57.552982	Ярославская область, Городской округ Ярославль, Фрунзенский район, ул.Пирогова, 12		0101000020E6100000737FF5B86FF743406AA33A1DC8C64C40
13911	1	17	\N	2085	24098	\N	57.642045000000003	город Ярославль, улица Папанина, 10а		0101000020E61000008867093202FA4340B9C7D2872ED24C40
13954	1	17	\N	2085	24121	\N	57.587744000000001	Ярославская область, Городской округ Ярославль, Красноперекопский район, Павлова, 37		0101000020E610000099D6A6B1BDEA4340CA3505323BCB4C40
13902	1	17	\N	2085	24120	\N	57.638267999999997	город Ярославль, улица Маяковского, 54		0101000020E6100000D2C5A69542F64340AA0A0DC4B2D14C40
13918	1	17	\N	2085	24091	\N	57.723847999999997	город Ярославль, улица Лебедева, 3а		0101000020E61000004963B48EAAEA434033A31F0DA7DC4C40
13952	1	17	\N	2085	24106	\N	57.581423000000001	Ярославская область, Городской округ Ярославль, Красноперекопский район, Зелинского, 6		0101000020E6100000C70DBF9B6EEB43403412A1116CCA4C40
13877	1	17	\N	2085	24093	\N	57.684964000000001	город Ярославль, Блюхера, 32а		0101000020E6100000AA44D95BCAE74340FB777DE6ACD74C40
13964	1	17	\N	2085	24141	\N	57.608419060416999	Ярославская область, Городской округ Ярославль, Красноперекопский район, Бахвалова, 1г	Россия, Ярославская область, Ярославль, улица Бахвалова, 1г	0101000020E610000036035C902DE94340ECA17DACE0CD4C40
14508	1	17	\N	50506	22437	\N	57.729763309182601	Ярославская область, Тутаевский район, д. Ченцы, Школа в д. Ченцы, ул. Звездная д. 2	Россия, Ярославская область, деревня Ченцы	0101000020E610000072DC291DACDD4340596ABDDF68DD4C40
14521	1	17	\N	165	22390	\N	57.526200000000003	Ярославская область, г.Углич, м-н Мирный, 23		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14439	1	17	\N	165	22390	\N	57.526200000000003	Ярославская область, г.Углич, м-н Мирный, 1		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14411	1	17	\N	165	22784	\N	57.526200000000003	Ярославская область, г.Углич, Ярославское шоссе, 10а		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14485	1	17	\N	165	22459	\N	57.526200000000003	Ярославская область, г.Углич, Ярославская, 47		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14499	1	17	\N	165	22393	\N	57.526200000000003	Ярославская область, г.Углич, Студенческий городок, 2		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14513	1	17	\N	165	22534	\N	57.526200000000003	Ярославская область, г.Углич, Старостина, 12		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14512	1	17	\N	165	22815	\N	57.526200000000003	Ярославская область, г.Углич, Рыбинское шоссе, 39		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14514	1	17	\N	165	22405	\N	57.526200000000003	Ярославская область, г.Углич, Опарина, 2		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14516	1	17	\N	165	22613	\N	57.526200000000003	Ярославская область, г.Углич, Ленинское шоссе, 1		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14515	1	17	\N	165	22613	\N	57.526200000000003	Ярославская область, г.Углич, Ленинское шоссе, 1а		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14373	1	17	\N	165	22910	\N	57.526200000000003	Ярославская область, г.Углич, Красноармейский бульвар, 3		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14520	1	17	\N	165	22782	\N	57.526200000000003	Ярославская область, г.Углич, Кирова, 83		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14511	1	17	\N	165	22712	\N	57.526200000000003	Ярославская область, г.Углич, Зины Золотовой, 31а		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14517	1	17	\N	165	22556	\N	57.526200000000003	Ярославская область, г.Углич, Волжская, 17А		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14519	1	17	\N	165	22479	\N	57.526200000000003	Ярославская область, г.Углич, Вокзальная, 20а		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14518	1	17	\N	165	22895	\N	57.526200000000003	Ярославская область, г.Углич, 1 линия Камышевского шоссе, 16а		0101000020E6100000FF59F3E32F274340DE9387855AC34C40
14033	1	17	\N	3130	22515	\N	58.045848999999997	г.Рыбинск, пр. Мира, 27		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14038	1	17	\N	3130	22562	\N	58.045848999999997	г.Рыбинск, пр. Ленина, 181		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14029	1	17	\N	3130	22598	\N	58.045848999999997	г.Рыбинск, пр. 50 лет Октября, 23		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14046	1	17	\N	3130	22523	\N	58.045848999999997	г. Рыбинск, Моторостроителей, 27		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14039	1	17	\N	3130	22887	\N	58.045848999999997	г.Рыбинск, Молодежная, 32		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14076	1	17	\N	3130	22446	\N	58.045848999999997	г. Рыбинск, Механизации, 7		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14053	1	17	\N	3130	22685	\N	58.045848999999997	г. Рыбинск, Ломоносова, 14		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14073	1	17	\N	3130	22943	\N	58.045848999999997	г. Рыбинск, Куйбышева, 26		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14040	1	17	\N	3130	22925	\N	58.045848999999997	г.Рыбинск, Кораблестроителей, 6		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14048	1	17	\N	3130	22474	\N	58.045848999999997	г. Рыбинск, Карякинская, 104		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14030	1	17	\N	3130	22928	\N	58.045848999999997	г.Рыбинск, Инженерная, 23а		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14028	1	17	\N	3130	22928	\N	58.045848999999997	г.Рыбинск, Инженерная, 39		0101000020E6100000B3614D65516C4340F3C64961DE054D40
13910	1	17	\N	3130	22727	\N	58.045848999999997	г.Рыбинск, Гончарова, 3		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14042	1	17	\N	3130	22639	\N	58.045848999999997	г.Рыбинск, Глеба Успенского, 4		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14075	1	17	\N	3130	22481	\N	58.045848999999997	г. Рыбинск, Гастелло, 5		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14061	1	17	\N	3130	22734	\N	58.045848999999997	г. Рыбинск, Гагарина, 22		0101000020E6100000B3614D65516C4340F3C64961DE054D40
11958	1	17	\N	3130	22746	\N	58.045848999999997	г.Рыбинск, Ворошилова, 3		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14065	1	17	\N	3130	22938	\N	58.045848999999997	г. Рыбинск, Волочаевская, 55		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14052	1	17	\N	3130	22608	\N	58.045848999999997	г. Рыбинск, Волжская Набережная, 173а		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14071	1	17	\N	3130	22869	\N	58.045848999999997	г. Рыбинск, Вихарева, 3		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14059	1	17	\N	3130	22780	\N	58.045848999999997	г. Рыбинск, Бурлацкая, 8		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14032	1	17	\N	3130	22616	\N	58.045848999999997	г.Рыбинск, Бориса Рукавицына, 35		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14037	1	17	\N	3130	22561	\N	58.045848999999997	г.Рыбинск, Бабушкина, 11		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14058	1	17	\N	3130	22442	\N	58.045848999999997	г. Рыбинск, Академика Павлова, 35		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14041	1	17	\N	3130	22395	\N	58.045848999999997	г.Рыбинск, Академика Губкина, 21		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14035	1	17	\N	3130	22512	\N	58.045848999999997	г.Рыбинск, 9 мая, 24		0101000020E6100000B3614D65516C4340F3C64961DE054D40
13071	1	17	\N	3130	22512	\N	58.045848999999997	г.Рыбинск, 9 мая, 14		0101000020E6100000B3614D65516C4340F3C64961DE054D40
14410	1	17	\N	28001	22930	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Октябрьская, 45-47		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14403	1	17	\N	28001	22519	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, Городское поселение Ростов, г. Ростов, 1-Й МКР, 27		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14137	1	17	\N	50628	\N	\N	57.763852	Покровское на Сити село, здание МОУ Покрово-Ситской общеобразовательной школы		0101000020E61000002FDD240681A14340FA7DFFE6C5E14C40
14086	1	17	\N	12457	22385	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, площадь Народная, 8		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14094	1	17	\N	12457	22824	\N	56.744213999999999	Ярославская область, город  Переславль - Залесский, площадь Менделеева, 2		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14090	1	17	\N	12457	22694	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, пер.Берендеевский, 27		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14081	1	17	\N	12457	22615	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, мкр.Чкаловский, гарнизонный офицерский клуб		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14080	1	17	\N	12457	22615	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, мкр.Чкаловский, 53		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14093	1	17	\N	12457	22391	\N	56.744213999999999	Ярославская область, город  Переславль - Залесский, Строителей, 33		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14092	1	17	\N	12457	22391	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, ул.Строителей, 22		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14084	1	17	\N	12457	22821	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, ул.Советская, 3		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14089	1	17	\N	12457	22614	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, Свободы, 61		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14088	1	17	\N	12457	22614	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, Свободы, 47-а		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14085	1	17	\N	12457	22618	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, Плещеевская, 17		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14091	1	17	\N	12457	22695	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, Октябрьская, 41		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14097	1	17	\N	12457	22621	\N	56.744213999999999	Ярославская область, город  Переславль - Залесский, Менделеева, 10		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14095	1	17	\N	12457	22621	\N	56.744213999999999	Ярославская область, город  Переславль - Залесский, Менделеева, 36		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14083	1	17	\N	12457	22755	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, Кардовского, 11		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14082	1	17	\N	12457	22755	\N	56.744213999999999	Ярославская область, город  Переславль - Залесский, Кардовского, 61		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14096	1	17	\N	12457	22825	\N	56.744213999999999	Ярославская область, город  Переславль - Залесский, 50 лет Комсомола, 1		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14087	1	17	\N	50631	\N	\N	56.744213999999999	Ярославская область, город Переславль - Залесский, пос.Красный химик, 1		0101000020E6100000AF3F89CF9D6E4340D89C8367425F4C40
14577	1	17	\N	50909	24048	\N	57.560764705196803	п. Нагорный, ул. Школьная, д. 1 А (КСК)	Россия, Ярославская область, поселок Нагорный	0101000020E6100000977329AE2AEB4340E8DEC325C7C74C40
14571	1	17	\N	4288	22838	\N	57.646558386212	п. Карачиха, Школьная, д. 31 ( Карачихская СОШ)	Россия, Ярославская область, поселок Карачиха	0101000020E6100000F7C77BD5CAE24340CC7B9C69C2D24C40
14570	1	17	\N	4225	22629	\N	57.617305000000002	Ярославская область, Ярославский район, п. Ивняки, УИК: ул.Светлая, д. 5  (Адм. с/п), ПДГ: ул. Луговая, 1а (Ивняковская СОШ)		0101000020E61000002A711DE38AE543402254A9D903CF4C40
14567	1	17	\N	4086	\N	\N	57.670344	п. Заволжье, д. 26  (Дом культуры)		0101000020E6100000B39602D2FE014440F0880AD5CDD54C40
14565	1	17	\N	3953	23044	\N	57.706021999999997	"д. Григорьевское , ул. Клубная  д. 15 (Дом культуры), УИК - ул. Клубная д. 6 (  Григорьевская СОШ),"		0101000020E61000009BE61DA7E8004440D520CCED5EDA4C40
14578	1	17	\N	47161	23109	\N	57.683515999999997	д. Ананьино, ул. Садовая, д. 11 (Дом Культуры)		0101000020E61000005ED89AADBCDC43407825C9737DD74C40
14579	1	17	585	50521	\N	\N	57.740585323571601	п. Ярославка, д. 25 (Дом культуры)	Россия, Ярославская область, Ярославский район, поселок Ярославка	0101000020E6100000E0BA624678EB43403F74417DCBDE4C40
14590	1	17	585	5299	22935	\N	57.553832	с. Ширинье, ул. Мира, д. 2 (Дом культуры)		0101000020E61000005517F032C3AA434038BD8BF7E3C64C40
14559	1	17	585	3666	22788	\N	57.541902999999998	"с. Туношна,  ул. Юбилейная д.7 ( Дом культуры), УИК - ул. Школьная  д. 3 (Адм. с/п),"		0101000020E6100000772B4B74960F4440594DD7135DC54C40
14560	1	17	585	3666	22889	\N	57.5433697989263	"Туношна -городок-26, МДОУ Детский сад №5, УИК - с. Туношна, ул. Школьная д. 3 (Адм. с/п),"	Россия, Ярославская область, Ярославский район, поселок Туношна	0101000020E6100000E2E82ADD5D0F444053D0ED258DC54C40
14584	1	17	585	4980	22440	\N	57.852224	с. Толбухино, ул. Социалистическая, д. 11 (Администрация с/п)		0101000020E610000048895DDBDB054440E36E10AD15ED4C40
14564	1	17	585	50944	\N	\N	57.799375136971001	"с. Спас-Виталий,  д. 18 (Дом культуры), УИК - Администрация Заволжского с/п,"	Россия, Ярославская область, Ярославский район, поселок Спасс	0101000020E6100000A661F88898184440B81E85EB51E64C40
14569	1	17	585	4179	\N	\N	57.460428	с. Сарафоново, д. 51 (Дом культуры)		0101000020E6100000279F1EDB32FE4340D314014EEFBA4C40
14531	1	17	585	46172	22480	\N	57.574415999999999	с. Прусово, Набережная, 13		0101000020E61000007041B62C5F1344404A26A77686C94C40
14568	1	17	585	4120	\N	\N	57.660046999999999	Ярославская область, Ярославский район, д. Пестрецово, д. 8 Б (Пестрецовская СОШ)		0101000020E61000001AA375543509444055698B6B7CD44C40
14591	1	17	585	5367	22611	\N	57.615347999999997	"д. Мордвиново,  ул. Советская д. 7 (Дом культуры), УИК - ул. Северная  д. 1 (Адм.с/п),"		0101000020E61000009AB0FD648CB943405AD427B9C3CE4C40
14448	1	17	585	49007	\N	\N	57.5488	с. Михайловское, 27		0101000020E6100000236AA2CF47C94340BC0512143FC64C40
14592	1	17	585	47457	22520	\N	57.783932999999998	п. Михайловский, ул. Школьная, д. 7  (Михайловская СОШ)		0101000020E61000002BA226FA7CDE4340A9A0A2EA57E44C40
14580	1	17	585	4792	\N	\N	57.756875999999998	"с. Медягино,  д. 34  (Дом культуры), УИК - д. 34 (Контора СПК ""Племзавод Горшиха""),"		0101000020E6100000DB17D00B77FA43404B901150E1E04C40
14588	1	17	585	47376	22798	\N	57.561123000000002	"с. Курба, ул. Школьная д. 1 ( Курбская СОШ), УИК - ул. Ярославская, д.13 (Адм. с/п),"		0101000020E61000007D772B4B74C043404704E3E0D2C74C40
14582	1	17	585	47226	22861	\N	57.716652000000003	д. Кузнечиха, ул. Центральная, д. 3  (Дом культуры)		0101000020E6100000514CDE0033F34340774EB340BBDB4C40
14581	1	17	585	47226	22861	\N	57.716652000000003	д. Кузнечиха, ул. Центральная, д. 34 (Кузнечихинская СОШ)		0101000020E6100000514CDE0033F34340774EB340BBDB4C40
14573	1	17	585	4344	22406	\N	57.485985999999997	"р.п. Красные Ткачи,  ул. Пушкина д. 8А (ЦДТ ""Ступеньки""), УИК - ул. Пушкина д. 39 (Адм. с/п),"		0101000020E6100000C11F7EFE7BE043402C280CCA34BE4C40
14572	1	17	585	4344	22406	\N	57.485985999999997	"р.п. Красные Ткачи,  ул. Пушкина д. 8А (ЦДТ ""Ступеньки""), УИК - ул. Пушкина д. 39 (Адм. с/п)"		0101000020E6100000C11F7EFE7BE043402C280CCA34BE4C40
14562	1	17	585	50910	24051	\N	57.590606713611898	"с. Красное д. 49, ( Красносельская ООШ), УИК - Туношна, ул. Школьная д. 3  (Адм. с/п),"		0101000020E61000007DCF4884462E4440F3E49A0299CB4C40
14576	1	17	585	50912	24053	\N	57.474475483819397	"д. Кормилицино ул. Лесная д. 41-А (библиотека), УИК - д. Карабиха, ул. Школьная д. 1Б ( Адм. с/п),"	Россия, Ярославская область, Ярославский район, поселок Кормилицыно	0101000020E6100000BA83D89942DD434082E2C798BBBC4C40
14587	1	17	585	5140	22649	\N	57.531902000000002	п. Козьмодемьянск, ул. Центральная, д. 36 (Дом культуры)		0101000020E610000076A911FA99D64340A8565F5D15C44C40
14575	1	17	585	4512	22438	\N	57.510509999999996	д. Карабиха, Школьная, 1 А (Карабихская ООШ)		0101000020E6100000C59272F739E24340F623456458C14C40
14447	1	17	585	50915	\N	\N	57.807269854387599	адрес помещения для голосования: п. Ермаково, д. 20, адрес УИК: п. Ермаково, д. 19	Россия, Ярославская область, Ярославский район, поселок Ермаково	0101000020E61000000D1AFA27B8FC43405E85949F54E74C40
14574	1	17	585	47078	23060	\N	57.530090000000001	п. Дубки, Некрасова, 1 (Дом культуры)		0101000020E6100000DC4B1AA375DE4340E4F736FDD9C34C40
14585	1	17	585	5042	22609	\N	57.795994	Ярославская область, Ярославский район, д. Глебовское, ул. Олимпийская, д. 1а (Дом культуры)		0101000020E61000005F0D501A6AFA4340F7E7A221E3E54C40
14583	1	17	585	4939	22526	\N	57.860258999999999	"с. Андроники,  ул. Ярославская д. 9 (столовая  ПСК ""Родина""), УИК - с. Толбухино, ул. Социалистическая д.11 (Адм. с/п),"		0101000020E6100000F2EF332E1CFE43407A8B87F71CEE4C40
14140	1	17	802	15292	22897	\N	58.662464	Ярославская область, Брейтовский район, д. Михальково, ул. Центральная, 6		0101000020E61000006BD3D85E0B0443408063CF9ECB544D40
14522	1	17	330	1534	\N	\N	57.607672000000001	Ярославская область, Угличский  район, д.Шубино	Россия, Ярославская область, Угличский район, поселок Шубино	0101000020E6100000AFB5F7A92A2E4340F3583332C8CD4C40
14149	1	17	1332	15757	22612	\N	58.297415999999998	Брейтово село, Республиканская, 23		0101000020E6100000F44F70B1A2EE424050A73CBA11264D40
14553	1	17	330	3337	\N	\N	57.413843999999997	Ярославская область, Угличский  район, д.Шишкино	Россия, Ярославская область, Угличский район, поселок Шишкино	0101000020E6100000209A79724DF94240AAD216D7F8B44C40
14544	1	17	330	2817	\N	\N	57.542732999999998	Ярославская область, Угличский  район, с.Чурьяково	Россия, Ярославская область, Угличский район, поселок Чурьяково	0101000020E6100000F54C2F31962F4340E0BA624678C54C40
14551	1	17	330	3253	\N	\N	57.518602999999999	Ярославская область, Угличский  район, д.Ульянкино	Россия, Ярославская область, Угличский район, поселок Ульянкино	0101000020E6100000F981AB3C81EC4240C24D469561C24C40
14541	1	17	330	2662	\N	\N	57.441256000000003	Ярославская область, Угличский  район, с.Улейма	Россия, Ярославская область, Угличский район, поселок Улейма	0101000020E6100000B01BB62DCA344340F7949C137BB84C40
14540	1	17	330	2573	\N	\N	57.491196000000002	Ярославская область, Угличский  район, п.Сосновый	Россия, Ярославская область, Угличский район, поселок Сосновый	0101000020E610000072DC291DAC27434088F6B182DFBE4C40
14555	1	17	330	3468	\N	\N	57.365589	Ярославская область, Угличский  район, с.Прилуки	Россия, Ярославская область, Угличский район, поселок Прилуки	0101000020E610000042EC4CA1F30443408063CF9ECBAE4C40
14545	1	17	330	2880	\N	\N	57.660156999999998	Ярославская область, Угличский  район, с.Покровское	Россия, Ярославская область, Угличский район, поселок Покровское	0101000020E61000000FD07D39B3474340DC9C4A0680D44C40
14526	1	17	330	1782	\N	\N	57.612735000000001	Ярославская область, Угличский  район,, д.Платуново	Россия, Ярославская область, Угличский район, поселок Платуново	0101000020E6100000A4198BA6B3034340AA0EB9196ECE4C40
14528	1	17	330	1872	\N	\N	57.587477999999997	Ярославская область, Угличский  район, п.Отрадный	Россия, Ярославская область, Угличский район, поселок Отрадный	0101000020E6100000DDCF29C8CF1E43404B8FA67A32CB4C40
14525	1	17	330	1730	\N	\N	57.603096000000001	Ярославская область, Угличский  район, с.Ордино	Россия, Ярославская область, Угличский район, поселок Ордино	0101000020E61000003E07962364F64240992CEE3F32CD4C40
14546	1	17	330	2919	\N	\N	57.475257999999997	Ярославская область, Угличский  район, с.Никольское	Россия, Ярославская область, Угличский район, поселок Овинищи Никольское	0101000020E61000007DB1F7E28B324340C8940F41D5BC4C40
14532	1	17	330	2131	\N	\N	57.300606000000002	Ярославская область, Угличский  район, д.Ново	Россия, Ярославская область, Угличский район, поселок Ново	0101000020E6100000D5EB1681B14E43409E7DE5417AA64C40
14524	1	17	330	1646	\N	\N	57.642814999999999	Ярославская область, Угличский  район, д.Нинорово	Россия, Ярославская область, Угличский район, поселок Нинорово	0101000020E61000001FDB32E02C2343406A300DC347D24C40
14538	1	17	330	2471	\N	\N	57.422443000000001	Ярославская область, Угличский  район,с.Нефедьево	Россия, Ярославская область, Угличский район, поселок Нефедьево	0101000020E6100000D49B51F3554E43404AB6BA9C12B64C40
14548	1	17	330	3026	\N	\N	57.544752000000003	Ярославская область, Угличский  район, с.Масальское	Россия, Ярославская область, Угличский район, поселок Масальское	0101000020E6100000386A85E97B0543401E37FC6EBAC54C40
14539	1	17	330	2522	\N	\N	57.412985999999997	Ярославская область, Угличский  район, д.Маймеры	Россия, Ярославская область, Угличский район, поселок Маймеры	0101000020E6100000E2AB1DC5391C434059DAA9B9DCB44C40
14550	1	17	330	3139	\N	\N	57.523001000000001	Ярославская область, Угличский  район, с.Климатино	Россия, Ярославская область, Угличский район, поселок Климатино	0101000020E6100000D6E07D552EFA42403D635FB2F1C24C40
14543	1	17	330	2773	\N	\N	57.501967	Ярославская область, Угличский  район, с.Клементьево	Россия, Ярославская область, Угличский район, поселок Клементьево	0101000020E6100000DFC325C79D644340EB55647440C04C40
14534	1	17	330	2225	\N	\N	57.260590000000001	Ярославская область, Угличский  район,.Каблуково	Россия, Ярославская область, Угличский район, поселок Каблуково	0101000020E6100000A4E2FF8EA840434013D55B035BA14C40
14529	1	17	330	1970	\N	\N	57.323160999999999	Ярославская область, Угличский  район, с.Ильинское	Россия, Ярославская область, Угличский район, поселок Ильинское	0101000020E61000001F10E84CDA404340DC2BF3565DA94C40
14542	1	17	330	50918	\N	\N	57.404986999999998	Ярославская область, Угличский  район, п. Зеленая  Роща		0101000020E61000003B014D840D2B43400F27309DD6B34C40
14552	1	17	330	3287	\N	\N	57.440320999999997	Ярославская область, Угличский  район, д.Заречье	Россия, Ярославская область, Угличский район, поселок Заречье	0101000020E6100000E31B0A9FADF54240FA5E43705CB84C40
14535	1	17	330	2327	\N	\N	57.196980000000003	Ярославская область, Угличский  район, с.Заозерье	Россия, Ярославская область, Угличский район, поселок Заозерье	0101000020E61000001EE0490B971F4340A9FB00A436994C40
14557	1	17	330	3579	\N	\N	57.493208000000003	Ярославская область, Угличский  район, д.Головино	Россия, Ярославская область, Угличский район, поселок Головино	0101000020E61000004D1421753B1543401310937021BF4C40
14536	1	17	330	2331	\N	\N	57.137822999999997	Ярославская область, Угличский  район, д.Вякирево	Россия, Ярославская область, Угличский район, поселок Вякирево	0101000020E61000005531957EC22743407CD11E2FA4914C40
14554	1	17	330	3386	\N	\N	57.390461999999999	Ярославская область, Угличский  район, с.Воздвиженское	Россия, Ярославская область, Угличский район, поселок Воздвиженское	0101000020E6100000D46531B1F9064340562AA8A8FAB14C40
14533	1	17	330	2195	\N	\N	57.235258999999999	Ярославская область, Угличский  район, с.Василево	Россия, Ярославская область, Угличский район, поселок Василево	0101000020E610000041D653ABAF4A43407A8B87F71C9E4C40
14547	1	17	330	2986	\N	\N	57.505128999999997	Ярославская область, Угличский  район, д.Варгуново	Россия, Ярославская область, Угличский район, поселок Варгуново	0101000020E6100000EC504D49D63B43406EA12B11A8C04C40
14527	1	17	330	1826	\N	\N	57.544637000000002	Ярославская область, Угличский  район, д.Бурмасово	Россия, Ярославская область, Угличский район, поселок Бурмасово	0101000020E6100000844BC79C6718434085984BAAB6C54C40
14537	1	17	330	2434	\N	\N	57.120485000000002	Ярославская область, Угличский  район, д.Белоусово	Россия, Ярославская область, Угличский район, поселок Белоусово	0101000020E6100000DB3521AD313443404C546F0D6C8F4C40
14523	1	17	330	1632	\N	\N	57.565564000000002	Ярославская область, Угличский  район,  п.Алтыново	Россия, Ярославская область, Угличский район, поселок Алтыново	0101000020E6100000745E6397A8244340C1E5B16664C84C40
14505	1	17	31	50520	22564	\N	57.930763561913899	Ярославская область, Тутаевский район, д.Ясиплево, Школа, Школьный переулок, д. 5	Россия, Ярославская область, Тутаевский район, поселок Ясиплево	0101000020E61000005A0D897B2CC14340A725564623F74C40
14510	1	17	31	836	22567	\N	57.756943	Ярославская область, Тутаевский район, п.Чебаково, Школа, ул. Школьная, д. 5		0101000020E6100000132D793C2DC54340D3F71A82E3E04C40
14498	1	17	31	37	\N	\N	57.840435999999997	Ярославская область, Тутаевский район, п.Фоминское, Школа в п. Фоминское		0101000020E6100000A7ECF483BAC84340C630276893EB4C40
14483	1	17	31	31124	22646	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Школа №3,  пр-т 50-летия Победы, д.32		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14481	1	17	31	31124	22646	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Средняя школа №3, пр-т 50-Летия Победы, д.32		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14480	1	17	31	31124	22646	\N	57.869799999999998	Ярославская область, Тутаевский район, г. Тутаев, Дом природы, пр-т 50-летия Победы, д.16-а		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14479	1	17	31	31124	22646	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Школа № 3 пр-т 50-летия Победы, д.32		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14477	1	17	31	31124	22646	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Лицей №1, пр-т 50-летия Победы, д.23		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14475	1	17	31	31124	22646	\N	57.871580798686097	Ярославская область, Тутаевский район.Тутаев, Лицей №1, пр-т 50-летия Победы, д. 23	Россия, Ярославская область, Тутаевский район, Тутаев	0101000020E6100000E833A0DE8CC24340516859F78FEF4C40
14484	1	17	31	31124	22624	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Школа № 3, пр-т 50-лет Победы, д.32		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14471	1	17	31	31124	22757	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Городской клуб , ул.  Ярославская д.93		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14469	1	17	31	31124	22823	\N	57.869799999999998	Ярославская область, Тутаевский  район, г.Тутаев, Средняя школа №5, ул.Ушакова, д.48		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14486	1	17	31	31124	22389	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, ул. Розы Люксембург, д. 57, ПУ-41		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14478	1	17	31	31124	22389	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, ПУ-41, ул. Розы Люксембург, д.57		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14470	1	17	31	31124	22878	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Д/к  ТМЗ, ул.П.Шитова, д.25		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14476	1	17	31	31124	22417	\N	57.869799999999998	Ярославская область, Тутаевский муниципальный район, г.Тутаев, Школа №6, Моторостроителей д.54		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14474	1	17	31	31124	22417	\N	57.879955994514297	Ярославская область, Тутаевский муниципальный район, Городское поселение Тутаев, Школа №6, Моторостроителей, 54	Россия, Ярославская область, Тутаевский район, Тутаев	0101000020E610000039B4C876BEC54340A1F5F065A2F04C40
14472	1	17	31	31124	22417	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Школа №6, Моторостроителей, 54		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14468	1	17	31	31124	22877	\N	57.869799999999998	Ярославская область, Тутаевский  район, г.Тутаев, Средняя школа №2, ул.Ленина, д.96		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14488	1	17	31	31124	22578	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Школа № 7, ул. Комсомольская, д.117		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14487	1	17	31	31124	22578	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Школа №7, Комсомольская 117		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14482	1	17	31	31124	22578	\N	57.869799999999998	Ярославская область, Тутаевский район, г.Тутаев, Школа №7, ул.Комсомольская 117		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14473	1	17	31	31124	22578	\N	57.869799999999998	"Ярославская область, Тутаевский район, г.Тутаев, ДЮСШ ""Старт"", ул.Комсомольская, д.78"		0101000020E61000006AC2F69331C44340C8073D9B55EF4C40
14490	1	17	31	50575	22835	\N	57.884710838441997	Ярославская область, Тутаевский  район, д.Столбищи, Школа в д. Столбищи, ул Центральная, д. 6	Россия, Ярославская область, Тутаевский район, поселок Столбищи	0101000020E61000007FD93D7958A44340ABB4C5353EF14C40
14504	1	17	31	50533	22632	\N	57.941719764761501	Ярославская область, Тутаевский район, д.Савинское, Школа, ул. Новая,д.17	Россия, Ярославская область, Тутаевский район, поселок Савинское	0101000020E61000007BBB253960AF43409BFEEC478AF84C40
14343	1	17	830	25327	22845	\N	56.810260999999997	Ярославская область, Переславский  район, п. Ивановское, прспект Мира, 9		0101000020E61000006589CE328B804340B41CE8A1B6674C40
14306	1	17	31	50924	24068	\N	57.918538013098498	адрес помещения для голосования: с. Рождественное, ул. Молодежная, д. 27, адрес УИК: с. Рождественное, ул. Молодежная, д. 29		0101000020E610000085798F334DAA43400E1137A792F54C40
14507	1	17	31	681	22460	\N	57.84525	Ярославская область, Тутаевский район, д.Пшеничище, Дом Культуры, ул. Школьная, д. 4		0101000020E610000058E4D70FB1D14340D578E92631EC4C40
14451	1	17	31	49056	23129	\N	58.061368999999999	с. Погорелка, Центральная, 19б		0101000020E610000001C287122DAD43407EFE7BF0DA074D40
14497	1	17	31	50543	22710	\N	58.1072959389099	Ярославская область, Тутаевский район, д. Першино, Школа в д. Першино, ул. Молодёжная, д. 14	Россия, Ярославская область, Тутаевский район, поселок Першино	0101000020E610000081069B3A8FBC4340ED7E15E0BB0D4D40
14496	1	17	31	50543	22710	\N	58.107659395083999	Ярославская область, Тутаевский район, д.Першино, Школа в д. Першино, ул. Молодёжная, д.14	Россия, Ярославская область, Тутаевский район, поселок Першино	0101000020E610000033DE567A6DBC43405E0F26C5C70D4D40
14492	1	17	31	50511	22473	\N	57.945097250189399	Ярославская область, Тутаевский район, д.Павловское, Школа в д. Павловское, ул. Школьная, д.6	Россия, Ярославская область, Тутаевский район, поселок Павловское	0101000020E6100000A2ED98BA2BCD43401B4641F0F8F84C40
14509	1	17	31	777	22641	\N	57.682673000000001	Ярославская область, Тутаевский район, п. Никульское, Дом Культуры, ул. Центральная, д. 41		0101000020E6100000C8B260E28FBC43405D6E30D461D74C40
14491	1	17	31	50519	22560	\N	58.003377006353702	Ярославская область, Тутаевский район, д.Никольское, Школа в д. Никольское, ул. Центральная, д. 49-а	Россия, Ярославская область, Тутаевский район, поселок Никольское	0101000020E6100000643A747ADEE14340804754A86E004D40
14314	1	17	31	50519	24058	\N	58.002884715924303	адрес помещения для голосования: с. Никольское, ул. Школьная. д.11, адрес УИК: с. Никольское, ул. Школьная. д.15	Россия, Ярославская область, Тутаевский район, поселок Никольское	0101000020E6100000AB21718FA5E14340115322895E004D40
14454	1	17	31	49107	23131	\N	57.982078999999999	д. Назарово, Заречная, 1		0101000020E6100000295AB91798EB4340508BC1C3B4FD4C40
14503	1	17	31	414	22880	\N	57.797462000000003	Ярославская область, Тутаевский район,  п. Микляиха, Дом Культуры, ул. Советская, д. 2		0101000020E6100000B9A7AB3B16D14340C1E61C3C13E64C40
14502	1	17	31	290	22463	\N	57.825687000000002	Ярославская область, Тутаевский район, п.Константинвоский, Школа, ул. Садовая, д. 8		0101000020E610000079060DFD13CC4340BEDD921CB0E94C40
14501	1	17	31	290	22463	\N	57.825687000000002	Ярославская область, Тутаевский  район, п.Константиновский, Школа, ул. Садовая, д. 8		0101000020E610000079060DFD13CC4340BEDD921CB0E94C40
14500	1	17	31	290	22463	\N	57.822479941179502	Ярославская область, Тутаевский район,п. п.Константиновский, Школа, ул. Садовая, д. 8	Россия, Ярославская область, Тутаевский район, поселок Константиновский	0101000020E610000078094E7D20CD43409ACE4E0647E94C40
14589	1	17	31	47392	22735	\N	57.693508000000001	д. Иванищево, ул. Молодежная, д. 12  (Иванищевская СОШ)		0101000020E61000006687F8872DB54340D7C1C1DEC4D84C40
14489	1	17	31	50558	22772	\N	57.900982258671597	Ярославская область, Тутаевский район, д.Емишево, Школа в д.Емишево, ул. Центральная, д.20	Россия, Ярославская область, Тутаевский район, поселок Емишево	0101000020E6100000F9DC09F65FB343407024D06053F34C40
14506	1	17	31	579	22871	\N	57.941678000000003	Ярославская область, Тутаевский  район, д.Выползово, Дом Культуры, ул. Анненская, д. 7.		0101000020E6100000B5FCC0559EBC43406DAE9AE788F84C40
14493	1	17	31	50542	22708	\N	57.947470427415503	Тутаевский район, д. Верещагино, Начальная школа в д. Верещагино, ул. Центральная, д. 19	Россия, Ярославская область, Тутаевский район, поселок Верещагино	0101000020E610000003D0285DFAE5434077F86BB246F94C40
14495	1	17	31	32383	22832	\N	58.094872000000002	Ярославская область, Тутаевский район, д.Великое село, Школа в д. Великое  село, ул. Солнечная, д.1-а		0101000020E6100000E4654D2CF0CF43402FA704C4240C4D40
14494	1	17	31	32325	\N	\N	57.935214000000002	Ярославская область, Тутаевский район, д.Борисоглеб, Детский сад		0101000020E6100000FE7BF0DAA5D743407461A417B5F74C40
14465	1	17	1894	49266	\N	\N	58.053741000000002	п. Юбилейный, 5		0101000020E6100000FE43FAEDEB5C434028BA2EFCE0064D40
14466	1	17	1894	49273	22544	\N	57.992593999999997	п. Тихменево, Тугаринова, 9		0101000020E6100000D8F50B76C34E4340581AF8510DFF4C40
14463	1	17	1894	30911	22822	\N	58.113432000000003	п. Судоверфь, Водников, 9		0101000020E6100000C7BAB88D06524340F22895F0840E4D40
14449	1	17	1894	49036	\N	\N	57.931739999999998	с. Сретенье, 60		0101000020E6100000CE380D518567434001309E4143F74C40
14319	1	17	1894	46562	24056	\N	58.029530999999999	с.Семеновское, Центральная, д.41		0101000020E6100000C9552C7E537C4340ED9BFBABC7034D40
14464	1	17	1894	30957	\N	\N	58.117482000000003	д. Свингино, 27		0101000020E610000058AA0B78994F434031EF71A6090F4D40
14457	1	17	1894	50537	\N	\N	57.985184951754803	адрес помещения для голосования: п. Октябрьский, д. 29а, адрес УИК: п. Октябрьский, д. 18а		0101000020E610000031410DDFC28C434040C1C58A1AFE4C40
14594	1	17	1894	47492	\N	\N	57.954492000000002	"д. Мокеевское, д. 34 (Дом культуры), УИК - д. 37 (Адм. с/п),"		0101000020E6100000C9C859D8D376434096253ACB2CFA4C40
14456	1	17	1894	30520	22691	\N	58.292983999999997	д. Милюшино, Приморская, 13		0101000020E6100000BADA8AFD656F43402920ED7F80254D40
14453	1	17	1894	49095	\N	\N	58.072693999999998	п. Майский, 26		0101000020E6100000A26131EA5A7D4340C64E78094E094D40
14296	1	17	1894	46044	\N	\N	57.910769999999999	д. Лапино, Осиново-Слободской сельский Дом культуры, 52		0101000020E6100000E67805A2279F4340C616821C94F44C40
14460	1	17	1894	49188	24060	\N	57.991349	п. Красная Горка, Центральная, 29		0101000020E61000009015FC36C46C43400EF62686E4FE4C40
14461	1	17	1894	30814	22381	\N	58.014851	п. Искра Октября, Молодежная, 35		0101000020E610000074F04C68926243400DA837A3E6014D40
14432	1	17	1827	29388	22834	\N	57.089931999999997	Ярославская область, Ростовский муниципальный район, село Лазарцево, Центральная, 2		0101000020E61000004565C39ACACA4340936E4BE4828B4C40
14458	1	17	1894	50570	\N	\N	57.9632958384964	адрес помещения для голосования: д. Дюдьково, д. 16, адрес УИК: д. Дюдьково, д. 10	Россия, Ярославская область, Рыбинский район, поселок Дюдьково	0101000020E61000001A87FA5DD89C43400E2F88484DFB4C40
14400	1	17	1827	27955	22737	\N	57.152535	Ярославская область, Ростовский муниципальный район, село Шурскол, Квартал В, д. 7		0101000020E610000087527B116DA54340683F524486934C40
14418	1	17	1827	28751	\N	\N	57.001907000000003	Ярославская область, Ростовский муниципальный район, д. Чепорово, д. 31		0101000020E610000018CC5F21738143401651137D3E804C40
14428	1	17	1827	29232	22524	\N	56.939539000000003	Ярославская область, Ростовский муниципальный район, пос. Хмельники, Заводская, 40		0101000020E6100000F2B0506B9AA5434085285FD042784C40
14433	1	17	1827	29434	22610	\N	57.163376999999997	Ярославская область, Ростовский муниципальный район, село Угодичи, Прудная, 27		0101000020E610000032AEB8382AC1434094F59B89E9944C40
14443	1	17	1827	29891	\N	\N	57.334259000000003	Ярославская область, Ростовский муниципальный район, село Татищев-Погост, 44А		0101000020E6100000CE70033E3FBC434064B2B8FFC8AA4C40
14435	1	17	1827	29529	\N	\N	57.203328999999997	Ярославская область, Ростовский муниципальный район, село Сулость, 132		0101000020E61000007F130A1170C2434008AA46AF069A4C40
14398	1	17	1827	27867	\N	\N	57.208311000000002	Ярославская область, Ростовский муниципальный район, д. Судино, д. 27		0101000020E61000009F39EB538EA54340D33252EFA99A4C40
14414	1	17	1827	28560	\N	\N	57.082292000000002	Ярославская область, Ростовский муниципальный район, село Скнятиново, д. 132		0101000020E6100000465D6BEF53AD4340795C548B888A4C40
14441	1	17	1827	29757	22530	\N	57.304228000000002	Ярославская область, Ростовский муниципальный район, п. Семибратово, Окружная, д.5		0101000020E6100000D7BD158909C4434085436FF1F0A64C40
14442	1	17	1827	29757	22812	\N	57.304228000000002	Ярославская область, Ростовский муниципальный район, п. Семибратово, Мира, 6		0101000020E6100000D7BD158909C4434085436FF1F0A64C40
14440	1	17	1827	29757	22750	\N	57.304228000000002	Ярославская область, Ростовский муниципальный район, п. Семибратово, Ленинская, 1		0101000020E6100000D7BD158909C4434085436FF1F0A64C40
14413	1	17	1827	50525	22602	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Спартаковская, 142		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14406	1	17	1827	50525	22594	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Революции, 12		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14405	1	17	1827	50525	22674	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Пролетарская, 40		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14404	1	17	1827	50525	22674	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, Городское поселение Ростов, г. Ростов, Пролетарская, 61		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14412	1	17	1827	50525	22805	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Московская, 49А		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14407	1	17	1827	50525	22675	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Моравского, 6		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14409	1	17	1827	50525	22744	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Ленинская, 39		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14408	1	17	1827	50525	22803	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, Каменный мост, 7		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14402	1	17	1827	50525	22670	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, 1-Й МКР, 27		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14401	1	17	1827	50525	22670	\N	57.192230000000002	Ярославская область, Ростовский муниципальный район, г. Ростов, 1-й МКР, 27		0101000020E6100000302E55698BB54340B1A71DFE9A984C40
14427	1	17	1827	29182	22683	\N	56.970495999999997	Ярославская область, Ростовский муниципальный район, пос. Приозерный, д. 39, кв. 10		0101000020E6100000DA9255116EB643400C738236397C4C40
14325	1	17	1827	46677	\N	\N	56.819507999999999	п.Пречистое, Советская, 8	Россия, Ярославская область, Ростовский район, поселок Пречистое	0101000020E6100000124E0B5EF4A74340BA675DA3E5684C40
14332	1	17	1827	46677	23220	\N	56.819507999999999	п.Пречистое, Советская, 54		0101000020E6100000124E0B5EF4A74340BA675DA3E5684C40
14333	1	17	1827	46677	23073	\N	56.819507999999999	п.Пречистое, Любимская, 12а		0101000020E6100000124E0B5EF4A74340BA675DA3E5684C40
14444	1	17	1827	29958	22751	\N	57.096058999999997	Ярославская область, Ростовский муниципальный район, пос. Поречье-Рыбное, Центральная, 62		0101000020E6100000A4C343183FB1434044BE4BA94B8C4C40
14430	1	17	1827	29249	22809	\N	57.006843000000003	Ярославская область, Ростовский муниципальный район, пос. Петровское, Советская, 33		0101000020E610000047B071FDBBA24340709A3E3BE0804C40
14429	1	17	1827	29249	22920	\N	57.006843000000003	Ярославская область, Ростовский муниципальный район, п. Петровское, ул. Пролетарская, д. 49		0101000020E610000047B071FDBBA24340709A3E3BE0804C40
14421	1	17	1827	50590	\N	\N	56.924225	Ярославская область, Ростовский муниципальный район, пос. Павлова Гора, д. 1, кв. 2		0101000020E610000001BF469220A24340A3923A014D764C40
14437	1	17	1827	29612	22810	\N	57.264994999999999	Ярославская область, Ростовский муниципальный район, село Ново-Никольское, Центральная, 8		0101000020E61000000B5F5FEB52C54340404D2D5BEBA14C40
14415	1	17	1827	28630	\N	\N	57.079079	Ярославская область, Ростовский муниципальный район, село Никольское, д. 156		0101000020E6100000B6D782DE1B9F43407366BB421F8A4C40
14431	1	17	1827	29337	22441	\N	57.110548999999999	Ярославская область, Ростовский муниципальный район, село Мосейцево, Труда, 41		0101000020E61000006C239EEC66DE434081CD3978268E4C40
14399	1	17	1827	27905	\N	\N	57.312351999999997	Ярославская область, Ростовский муниципальный район, село Марково, 11А		0101000020E610000059130B7C45AD43408B6B7C26FBA74C40
14420	1	17	1827	28863	22680	\N	56.954428999999998	Ярославская область, Ростовский муниципальный район, д. Коленово, ул. Заводская, д. 15		0101000020E6100000CC086F0F429843404FADBEBA2A7A4C40
14445	1	17	1827	30017	22940	\N	57.071730000000002	Ярославская область, Ростовский муниципальный район, с. Климатино, Нагорная, 1		0101000020E6100000401361C3D3B143403012DA722E894C40
14425	1	17	1827	29089	22933	\N	56.906182999999999	Ярославская область, Ростовский муниципальный район, село Караш, Сосновая, д. 9		0101000020E610000026AB22DC64B243407898F6CDFD734C40
14397	1	17	1827	27829	22862	\N	57.194532000000002	Ярославская область, Ростовский муниципальный район, пос. Ишня, Школьная, 4		0101000020E6100000B5C6A01342AB43404303B16CE6984C40
14422	1	17	1827	28953	22808	\N	56.858887000000003	Ярославская область, Ростовский муниципальный район, д. Итларь, Березовая, д. 2		0101000020E610000085ECBC8DCDA44340D3FA5B02F06D4C40
14424	1	17	1827	29034	\N	\N	56.824227	Ярославская область, Ростовский муниципальный район, д. Заозерье, д. 14		0101000020E61000005C035B2558AE434077BD344580694C40
14426	1	17	1827	29130	22682	\N	56.874484000000002	Ярославская область, Ростовский муниципальный район, д. Еремейцево, Центральная, 26		0101000020E61000004E8061F9F3A9434009707A17EF6F4C40
14417	1	17	1827	28738	22747	\N	57.098655999999998	Ярославская область, Ростовский муниципальный район, село Дмитриановское, Кузьмина, дом 39		0101000020E6100000FAD346753A924340EFC682C2A08C4C40
14416	1	17	1827	28689	\N	\N	57.039169000000001	Ярославская область, Ростовский муниципальный район, село Деревни, д. 49А		0101000020E6100000AB3DEC8502A243402E02637D03854C40
14419	1	17	1827	28826	\N	\N	56.979664	Ярославская область, Ростовский муниципальный район, пос. Горный, д. 39		0101000020E610000073F7393E5A924340C68844A1657D4C40
14450	1	17	1827	49042	\N	\N	57.372746649306002	с. Глебово, Рыбинская, 7	Россия, Ярославская область, Ростовский район, поселок Глебово	0101000020E6100000E695EB6D33B743404F57772CB6AF4C40
14438	1	17	1827	29659	22687	\N	57.301068000000001	Ярославская область, Ростовский муниципальный район, д. Вахрушево, квартал В, 2		0101000020E6100000BBD408FD4CCB4340A2EF6E6589A64C40
14434	1	17	1827	29492	\N	\N	57.200491	Ярославская область, Ростовский муниципальный район, село Васильково, 29		0101000020E6100000A6EF3504C7D34340381268B0A9994C40
14436	1	17	1827	29575	\N	\N	57.233041999999998	Ярославская область, Ростовский муниципальный район, село Белогостицы, 35		0101000020E61000007CD11E2FA4BF4340164CFC51D49D4C40
14423	1	17	1827	28999	22749	\N	56.806905	Ярославская область, Ростовский муниципальный район, п. при ж/д Беклемишево, Школьная, д. 10		0101000020E61000000938842A359F43404CFDBCA948674C40
14387	1	17	1803	27353	22731	\N	58.485393000000002	Ярославская область, Пошехонский  район,  с. Ясная Поляна, ул. Рыбинская, д18, здание сельского Дома Культуры		0101000020E6100000D63BDC0E0D8B43408A5A9A5B213E4D40
14386	1	17	1803	27302	22919	\N	58.497627000000001	Ярославская область, Пошехонский район,  д. Яковлевское, ул. Административная, д.4, здание сельского Дома Культуры		0101000020E6100000DEE4B7E864994340A54DD53DB23F4D40
14395	1	17	1803	27727	22668	\N	58.707886999999999	Ярославская область, Пошехонский  район,  д. Юдино, ул. Центральная, д.9, здание Юдинской школы		0101000020E6100000C9ACDEE176A64340BC218D0A9C5A4D40
14394	1	17	1803	27679	\N	\N	58.284936999999999	Ярославская область, Пошехонский район,  д. Холм, д23, здание сельского Дома Культуры		0101000020E610000008C72C7B12C24340CE35CCD078244D40
14392	1	17	1803	27591	\N	\N	58.497518999999997	"Ярославская область, Пошехонский  район,  с. Федорково, д.41, здание лагеря ДОЦ ""Солнышко"""		0101000020E610000021904B1C79724340BE11DDB3AE3F4D40
14381	1	17	1803	27089	22587	\N	58.735444999999999	Ярославская область, Пошехонский район,  с. Ракоболь, ул. Калининская, д.15, здание адм-и Пригородного СП		0101000020E61000006823D74D29B14340DC80CF0F235E4D40
14371	1	17	1803	26542	22839	\N	58.498144000000003	"Ярославская область, Пошехонский район, г. Пошехонье, ул. Строителей, д.14, Детский сад ""Матрешка"""		0101000020E6100000B5334C6DA98F43406D59BE2EC33F4D40
14370	1	17	1803	26542	22469	\N	58.498144000000003	Ярославская область, Пошехонский район, г. Пошехонье, ул. Советская, д.25, сельскохозяйственный техникум		0101000020E6100000B5334C6DA98F43406D59BE2EC33F4D40
14396	1	17	1803	26542	22553	\N	58.498144000000003	"Ярославская область, Пошехонский  район, г. Пошехонье, ул. Преображенского, д. 23, кинотеатр ""Юбилейный"""		0101000020E6100000B5334C6DA98F43406D59BE2EC33F4D40
14369	1	17	1803	26542	22553	\N	58.498144000000003	Ярославская область, Пошехонский район, г. Пошехонье, ул. Преображенского, д.1, районный Дом Культуры		0101000020E6100000B5334C6DA98F43406D59BE2EC33F4D40
14372	1	17	1803	26542	22789	\N	58.498144000000003	Ярославская область, Пошехонский  район, г. Пошехонье, ул. Заречная, д.31, здание Согожского лесничества		0101000020E6100000B5334C6DA98F43406D59BE2EC33F4D40
14390	1	17	1803	27481	22733	\N	58.303530000000002	Ярославская область, Пошехонский район,  с. Покров-Рогули, ул. Мирная, д.8, здание Покров-Рогульской школы		0101000020E61000002499D53BDCD043406DAD2F12DA264D40
14389	1	17	1803	27454	\N	\N	58.392539999999997	Ярославская область, Пошехонский  район,  д. Крестцы, д29, здание Крестцовской библиотеки		0101000020E6100000143E5B07077D4340982F2FC03E324D40
14388	1	17	1803	27392	22423	\N	58.426031000000002	Ярославская область, Пошехонский район,  с. Кременево, ул. Школьная, д.4, здание Кременевской школы		0101000020E6100000BEBF417BF57D4340850A0E2F88364D40
14384	1	17	1803	27204	\N	\N	58.617854000000001	Ярославская область, Пошехонский район,  с. Красное, д.38, здание адм-и Пригородного СП		0101000020E610000034DB15FA609B4340F5D901D7154F4D40
14385	1	17	1803	27258	22918	\N	58.787329999999997	Ярославская область, Пошехонский район,  с. Колодино, ул. Центральная, д.26, здание Колодинской школы		0101000020E6100000C2A2224E279543407094BC3AC7644D40
14383	1	17	1803	27173	22794	\N	58.514462999999999	Ярославская область, Пошехонский район,  с. Князево, ул. Ветеранская, д.1, здание сельского Дома Культуры		0101000020E6100000390F27309D8A4340430070ECD9414D40
14382	1	17	1803	27117	22756	\N	58.625290999999997	Ярославская область, Пошехонский район, д. Кладово, ул. Им. Огурцова, д25, здание сельского Дома Культуры		0101000020E610000031EA5A7B9FAC4340D7BD158909504D40
14393	1	17	1803	27638	\N	\N	58.489443000000001	Ярославская область, Пошехонский  район,  п. Зубарево, д87, здание сельского Дома Культуры		0101000020E610000097E315889E7C4340C9207711A63E4D40
14380	1	17	1803	27036	22916	\N	58.617100000000001	Ярославская область, Пошехонский район,  с. Ермаково, ул. Ильинская, д.1, здание адм-и Ермаковского СП		0101000020E6100000779D0DF967584340492EFF21FD4E4D40
14391	1	17	1803	27551	22922	\N	58.410628000000003	Ярославская область, Пошехонский  район,  д. Дубасово, ул. Школьная, д.7, здание Дубасовской нач. школы		0101000020E61000003602F1BA7EA54340346953758F344D40
14379	1	17	1803	27004	22427	\N	58.696849	Ярославская область, Пошехонский район,  с. Гаютино, ул. Молодежная, д.6, здание адм-и Ермаковского СП		0101000020E6100000200C3CF71E4243400AA0185932594D40
14378	1	17	1803	26954	22509	\N	58.322614999999999	Ярославская область, Пошехонский район,  д. Вощиково, ул. Школьная, д.9, здание Вощиковской школы		0101000020E61000002B323A20098D43407A19C5724B294D40
14377	1	17	1803	26904	22820	\N	58.809573	Ярославская область, Пошехонский район, с. Владычное, ул. Пошехонская, д21, здание сельского дома культуры		0101000020E6100000D82AC1E270BE4340C05C8B16A0674D40
14375	1	17	1803	26805	22504	\N	58.838251999999997	Ярославская область, Пошехонский  район,  д. Васильевское, ул. Солнечная, д.1, здание сельского Дома Культуры		0101000020E61000000CC85EEFFE9A43403EE76ED74B6B4D40
14374	1	17	1803	26764	22853	\N	58.381095000000002	Ярославская область, Пошехонский район, с. Белое, ул. Федоровская, д41, здание адм-и  Белосельского СП		0101000020E610000034643C4A25B24340A6D590B8C7304D40
14376	1	17	1803	26848	22505	\N	58.820416000000002	Ярославская область, Пошехонский район,  д. Андрюшино, ул. Центральная, д.5, здание ФАП		0101000020E6100000AD156D8E73A54340BD8E386403694D40
14357	1	17	830	26006	22485	\N	56.896937000000001	Ярославская область, Переславский  район, д. Фонинское, Мичуринская, 59		0101000020E610000079CC4065FC23434043C9E4D4CE724C40
14363	1	17	830	26251	22851	\N	56.778084999999997	Ярославская область, Переславский  район, с. Филимоново, Овражная, 8		0101000020E6100000280B5F5FEB8C43400B410E4A98634C40
14340	1	17	830	25179	22901	\N	56.774386999999997	Ярославская область, Переславский  район,Троицкая Слобода, Троицкая, 1А		0101000020E61000005F9A22C0E971434049B9FB1C1F634C40
14367	1	17	830	26438	22584	\N	56.633392000000001	Ярославская область, Переславский  район, с. Смоленское, Центральная, 7		0101000020E6100000D5E8D500A595434026C632FD12514C40
14365	1	17	830	26282	22502	\N	56.713991381379401	Ярославская область, Переславский  район, п. Рязанцево, ул.Республиканская, 13	Россия, Ярославская область, Переславский район, поселок Рязанцево	0101000020E61000003E062B4EB59A4340B5519D0E645B4C40
14364	1	17	830	26282	22726	\N	56.714604999999999	Ярославская область, Переславский  район, п. Рязанцево, Большая Октябрьская, 30		0101000020E61000004759BF99989843406F47382D785B4C40
14354	1	17	830	25867	22484	\N	57.032781999999997	Ярославская область, Переславский  район, с. Рахманово, Центральная, 91		0101000020E6100000D8F0F44A59524340E0F2583332844C40
14341	1	17	830	50564	22790	\N	56.716163952229103	Ярославская область, Переславский  район, с. Новоселье  ПДГ - ул. Моисеева д.11, УИК - ул. Центральная, 1	Россия, Ярославская область, Переславский район, поселок Новоселье	0101000020E610000015AC71361D5B434049490F43AB5B4C40
14356	1	17	830	25970	22421	\N	56.918453	Ярославская область, Переславский  район, с. Нагорье , ПДГ - ул. Адмирала Спиридова, д.1Б, УИК - ул.Адмирала Спиридова, 19		0101000020E6100000A6D1E4620C224340E0F42EDE8F754C40
14355	1	17	830	25970	22421	\N	56.919131077489801	Ярославская область, Переславский  район, ПДГ - с. Нагорье, ул. Адмирала Спиридова 1Б, УИК - Адмирала Спиридова, 19	Россия, Ярославская область, Переславский район, поселок Нагорье	0101000020E6100000DF6DDE3829224340B1DEA815A6754C40
14345	1	17	830	25428	22415	\N	56.956721000000002	Ярославская область, Переславский  район, с. Лыченцы, Школьная, 3		0101000020E61000007A51BB5F05684340BE326FD5757A4C40
14349	1	17	830	25572	22658	\N	56.817878	Ярославская область, Переславский  район, с. Купанское, Депутатская, 23		0101000020E6100000ABE7A4F78D554340170FEF39B0684C40
14348	1	17	830	25572	22658	\N	56.817878	Ярославская область, Переславский  район,с. Купанское, Депутатская, 23		0101000020E6100000ABE7A4F78D554340170FEF39B0684C40
14360	1	17	830	50501	22402	\N	56.733906336753599	Ярославская область, Переславский  район, с. Кубринск ПДГ - ул. Петрова д.21, УИК - ул. Парковая, 15	Россия, Ярославская область, Переславский район, Кубринск	0101000020E6100000B16B7BBB252D4340492BBEA1F05D4C40
14359	1	17	830	50501	22402	\N	56.726734895638899	Ярославская область, Переславский  район, с. Кубринск ПДГ - ул. Петрова, д.21, УИК - ул.Парковая, 15	Россия, Ярославская область, Переславский район, Кубринск	0101000020E6100000757632384A2E4340E5ED08A7055D4C40
14342	1	17	830	25271	22902	\N	56.793197999999997	Ярославская область, Переславский  район,Красная деревня, Совхозная, 31		0101000020E6100000810706103E70434055A0168387654C40
14350	1	17	830	25663	22659	\N	56.880296999999999	Ярославская область, Переславский  район, с. Копнино, Центральная, 47		0101000020E6100000268DD13AAA3C43402AE27492AD704C40
14339	1	17	830	25144	22720	\N	56.679994000000001	Ярославская область, Переславский  район, д.Кичибухино, Школьная, 1		0101000020E6100000FE28EACC3D7A4340F5BC1B0B0A574C40
4029	1	16	442	4378	26163	\N	54.101382000000001	пос. Новая Черепеть, За мир, 1		0101000020E61000000E83F92B642C42409833DB15FA0C4B40
14344	1	17	830	25327	22411	\N	56.810260999999997	Ярославская область, Переславский  район, п. Ивановское, проспект Мира, 9		0101000020E61000006589CE328B804340B41CE8A1B6674C40
14351	1	17	830	25732	22721	\N	57.028134000000001	Ярославская область, Переславский  район, с. Загорье, Центральная, 34		0101000020E6100000DA73999A042D4340EDF318E599834C40
14352	1	17	830	25782	22723	\N	56.63458	Ярославская область, Переславский  район, с. Ефимьево, Октябрьская, 4		0101000020E6100000E75608ABB17C43400C59DDEA39514C40
14362	1	17	830	26201	22653	\N	56.770465000000002	Ярославская область, Переславский  район, с. Дубровицы, Крутец, 4А		0101000020E6100000BB2A508BC195434038DBDC989E624C40
14361	1	17	830	50933	24081	\N	56.7096471524953	Ярославская область, Переславский  район, п. Дубки ПДГ - ул. Клубная, д.1а, УИК - ул.Центральная, 4А	Россия, Ярославская область, Переславский район, поселок Дубки	0101000020E6100000A3E6ABE4639143402D5A80B6D55A4C40
14353	1	17	830	25817	22483	\N	57.055354999999999	Ярославская область, Переславский  район, с. Дмитриевское, Школьная, 13		0101000020E6100000CD74AF93FA424340C55565DF15874C40
14366	1	17	830	26391	22654	\N	56.656455000000001	Ярославская область, Переславский  район, д. Горки, Центральная, 7		0101000020E6100000352905DD5EA44340D925AAB706544C40
14337	1	17	830	47634	24062	\N	56.657375999999999	Ярославская область, Переславский  район, с. Глебовское  ПДГ - ул.Центральная д.101, УИК - ул.Московская, 62		0101000020E61000005ED5592DB0594340709692E524544C40
14336	1	17	830	47634	24062	\N	56.657375999999999	Ярославская область, Переславский  район, с. Глебовское  ПДГ -  ул.Центральная д.101, УИК- ул.Московская, 62	Россия, Ярославская область, Переславский район, поселок Глебовское	0101000020E61000005ED5592DB0594340709692E524544C40
14347	1	17	830	25524	22852	\N	56.740679999999998	Ярославская область, Переславский  район,с. Б.Брембола, Советская, 35А		0101000020E61000002FDB4E5B2374434090662C9ACE5E4C40
14335	1	17	830	50927	24071	\N	56.600003803566899	Ярославская область, Переславский  район, с. Берендеево ПДГ - ул. Центральная , д.3, УИК - ул. Центральная, 6	Россия, Ярославская область, Переславский район, поселок Берендеево	0101000020E61000009697FC4FFE8243400EBC5AEECC4C4C40
14334	1	17	830	50927	24071	\N	56.600592462848603	Ярославская область, Переславский  район, с. Берендеево ПДГ - ул.Центральная д.3, УИК - ул.Центральная, 6		0101000020E6100000F06DFAB31F8343409F1EDB32E04C4C40
14368	1	17	830	26473	22908	\N	56.571823999999999	Ярославская область, Переславский  район, с. Бектышево, Центральная, 19		0101000020E6100000A2EBC20FCE9D4340B188618731494C40
14358	1	17	830	26043	22868	\N	56.866121	Ярославская область, Переславский  район, с. Андрианово, Садовая, 3		0101000020E6100000374F75C8CD2243407DB08C0DDD6E4C40
14327	1	17	1593	24609	\N	\N	58.392516000000001	д.Шильпухово, д.95		0101000020E61000008E90813CBB3844401094DBF63D324D40
14329	1	17	1593	50935	24084	\N	58.5427247822265	п.при Ж/Д станции Скалино, ул.Первомайская, д.11	Россия, Ярославская область, Первомайский район, поселок Скалино	0101000020E61000007715527E521B44405DDC460378454D40
14303	1	17	1593	46222	23085	\N	58.432237000000001	с. Путятино, Маслова, 1		0101000020E6100000433D7D04FE2E4440828FC18A53374D40
14320	1	17	1593	50934	24083	\N	58.651746428479399	адрес помещения для голосования: д.Паршино, ул.Молодежная, д.29, адрес УИК: д.Паршино, ул.Молодежная, д.30	Россия, Ярославская область, Первомайский район, поселок Паршино	0101000020E6100000776A2E3718C2434040A6B5696C534D40
14316	1	17	1593	24041	22607	\N	58.682547	с.Николо-Ухтома, Луговая, д.5		0101000020E6100000C53BC09316C24340D07D39B35D574D40
14324	1	17	1593	50917	\N	\N	58.430061919143903	адрес помещения для голосования: с.Николо-Гора, д.8, адрес УИК: с.Николо-Гора, д44	Россия, Ярославская область, Первомайский район, поселок Никола-Гора	0101000020E6100000E2E82ADD5D0F44404DA088450C374D40
14163	1	17	1593	40433	\N	\N	58.690606000000002	д.Малино, Школьная, д.5		0101000020E61000005CE49EAEEEE24340F03504C765584D40
14220	1	17	1593	19330	22676	\N	58.696703999999997	с.Кукобой, Школьная, д.4		0101000020E61000000C570740DCF34340067FBF982D594D40
14272	1	17	1593	19330	22617	\N	58.696703999999997	с.Кукобой, Советская, д.19		0101000020E61000000C570740DCF34340067FBF982D594D40
14323	1	17	1593	24394	22642	\N	58.454628	с.Коза, Заречная, д.31		0101000020E61000009F3D97A949F6434046EC1340313A4D40
14322	1	17	1593	24337	22719	\N	58.575800999999998	д.Игнатцево, Центральная, д.2		0101000020E61000005B9885764EE143408600E0D8B3494D40
14593	1	17	1593	47468	23238	\N	58.381146999999999	с. Григорьевское, ул. Мира, д. 34		0101000020E6100000F1D4230D6E1B4440F8FBC56CC9304D40
14318	1	17	1593	46548	22718	\N	58.642276000000003	с.Всехсвятское, Центральная, д.32		0101000020E610000038842A357BDE4340BB80971936524D40
14286	1	17	1593	22675	\N	\N	58.620319000000002	д.Вараково, д.9		0101000020E6100000E59B6D6E4C014440310BED9C664F4D40
14326	1	17	1593	24543	\N	\N	58.332132000000001	д.Багряники, Школьная, д.5		0101000020E6100000EFCB99ED0A25444040FA264D832A4D40
14299	1	17	1699	50929	24073	\N	57.758185167074799	д. Яснищи, Комсомольская, 1б	Россия, Ярославская область, Некрасовский район, поселок Яснища	0101000020E6100000E5EE737CB4384440ACA8C1340CE14C40
14297	1	17	1699	23149	22776	\N	57.732425999999997	с. Черная заводь, Школьная, 1а		0101000020E6100000A30227DBC0454440BB5E9A22C0DD4C40
14292	1	17	1699	45963	\N	\N	57.699635999999998	п. Приволжский, Приволжская сельская библиотека, 11а		0101000020E61000004CDE0033DF2F4440588D25AC8DD94C40
14467	1	17	1699	49294	23234	\N	57.675664371613003	п. Песочное, Заводская, 1б	Россия, Ярославская область, Некрасовский район, поселок Песочное	0101000020E610000075745C8DEC4A4440D28A6F287CD64C40
14291	1	17	1699	22791	22387	\N	57.676504000000001	п. Некрасовское, Строителей, 7		0101000020E6100000E8A1B60DA32E44407DCEDDAE97D64C40
14290	1	17	1699	22791	22387	\N	57.677885770847901	адрес помещения для голосования: п. Некрасовское, ул. Строителей, д.7, адрес УИК: п. Некрасовское, ул. Советская, д.135, 7		0101000020E610000075CDE49B6D2E44404835ECF7C4D64C40
14289	1	17	1699	22791	22827	\N	57.676504000000001	п. Некрасовское, Пролетарская, 2		0101000020E6100000E8A1B60DA32E44407DCEDDAE97D64C40
4302	1	16	\N	12984	75221	\N	54.185809999999996	город Тула, Советский район, Софьи Перовской, 40		0101000020E6100000C85C19541BCC424087A2409FC8174B40
14302	1	17	1699	50916	\N	\N	57.613498224041997	д. Наумиха, административное здание отд. Гребово СП Красный Профинтерн, 25	Россия, Ярославская область, Некрасовский район	0101000020E610000059880E8123314440A9143B1A87CE4C40
14293	1	17	1699	60501	\N	\N	57.633620551111498	"поселок при профилактории ""Строитель"", Малосольская сельская библиотека, 3а"	Россия, Ярославская область, Некрасовский район, поселок Малые Соли	0101000020E6100000C84109336D3144408787307E1AD14C40
14459	1	17	1699	49177	23120	\N	57.382762999999997	п. Лом, Пионерская, 10		0101000020E610000046CF2D7425324440368FC360FEB04C40
14295	1	17	1699	46033	22830	\N	57.643797999999997	с. Левашово, Молодежная, 13		0101000020E610000069A7E67283434440779D0DF967D24C40
14308	1	17	1699	50922	24114	\N	57.749255437572003	д. Грешнево, Центральная, 1		0101000020E6100000006F8104C5374440A7AE7C96E7DF4C40
14298	1	17	1699	50922	24064	\N	57.747952927377398	адрес помещения для голосования: п. Красный Профинтерн, ул. Набережная, д. 22, адрес УИК: п. Красный Профинтерн, ул. Советская, д. 20	Россия, Ярославская область, Некрасовский район, поселок Красный Профинтерн	0101000020E61000009888B7CEBF374440F9F884ECBCDF4C40
14287	1	17	1699	50572	\N	\N	57.4748164945048	адрес помещения для голосования: д. Коробиха, д. 51, Якушевский сельский Дом культуры, адрес УИК:д. Якушиха, д. 6, здание отд. Якушиха СП Бурмакино	Россия, Ярославская область, Некрасовский район, поселок Коробиха	0101000020E6100000BBF2599E072D44400BCF4BC5C6BC4C40
14301	1	17	1699	23332	\N	\N	57.728769	"п. Защитный, ЭЗС-филиал ФГУ ""Управления Ярославльмелиоводхоз"", 12а"		0101000020E6100000C37E4FAC532F444058AB764D48DD4C40
14305	1	17	1699	23529	9969	\N	57.639139999999998	с.Диево-Городище, Ярославская, 6		0101000020E6100000244223D8B818444060C8EA56CFD14C40
14285	1	17	1699	22631	24074	\N	57.499191000000003	д. Гашки, Молодежная, 7/2	Россия, Ярославская область, Некрасовский район, поселок Гашки	0101000020E6100000A3EA573A1F22444091BA9D7DE5BF4C40
14304	1	17	1699	50508	22454	\N	57.866824212331302	адрес помещения для голосования: с. Вятское, ул. Давыдковская, д. 25, адрес УИК: с. Вятское, ул. Давыдковская, д. 3	Россия, Ярославская область, Некрасовский район, поселок Вятское	0101000020E6100000B97020240B224440A7B1BD16F4EE4C40
14312	1	17	1699	50940	24095	\N	57.434235483415897	адрес помещения для голосования: с. Бурмакино, ул. Центральная, д.21, адрес УИК: с. Бурмакино, ул. Заречная, д. 31	Россия, Ярославская область, Некрасовский район, поселок Бурмакино	0101000020E6100000147B681F2B284440A8E3310395B74C40
14300	1	17	1699	50518	\N	\N	57.776695928192702	адрес помещения для голосования: д. Бор, д.44а, Боровская специальная (коррекционная) общеобразовательная школа-интернат, адрес УИК: п. Красный Профинтерн, Советская, д. 20	Россия, Ярославская область, Некрасовский район, поселок Бор	0101000020E6100000B1BFEC9E3C3444408E7747C66AE34C40
14278	1	17	820	22314	22876	\N	57.933985999999997	Ярославская область, Некоузский  район, п. Шестихино, пер. Клубный		0101000020E61000007BDB4C8578204340FF756EDA8CF74C40
14263	1	17	820	21592	\N	\N	58.022486999999998	Ярославская область, Некоузский  район, с. Станилово, д.7		0101000020E6100000236AA2CF47EF4240E6CAA0DAE0024D40
14264	1	17	820	21651	\N	\N	57.995714	Ярославская область, Некоузский  район, с. Спас-Ильдь, д.16		0101000020E610000073672618CE094340AD156D8E73FF4C40
14268	1	17	820	21839	\N	\N	57.984034999999999	Ярославская область, Некоузский  район, с. Рожалово	Россия, Ярославская область, Некоузский район, поселок Рожалово	0101000020E6100000A01B9AB2D3CD4240478FDFDBF4FD4C40
14262	1	17	820	21529	\N	\N	57.956086999999997	Ярославская область, Некоузский  район, д. Правдино	Россия, Ярославская область, Некоузский район, поселок Правдино	0101000020E61000007FF78E1A13F24240BC900E0F61FA4C40
14267	1	17	820	21782	\N	\N	57.990108999999997	Ярославская область, Некоузский район, с. Парфеньево, д.2		0101000020E61000003D9B559FABD94240D53C47E4BBFE4C40
14283	1	17	820	22474	22457	\N	57.826760999999998	Ярославская область, Некоузский  район, п. Октябрь, ул. Ленина, д. 11, Некоузский район, п.Октябрь, ул.Транспортная, д. 3		0101000020E6100000BAF605F4C2B14240DB4DF04DD3E94C40
14282	1	17	820	22474	22457	\N	57.826760999999998	Ярославская область, Некоузский район, п. Октябрь, ул. Ленина, д. 11, Некоузский район, п. Октябрь, ул.Транспортная, д. 3		0101000020E6100000BAF605F4C2B14240DB4DF04DD3E94C40
14260	1	17	820	21301	22444	\N	57.901823999999998	Ярославская область, Некоузский район, с. Новый Некоуз, ул. Советская, д.38, с. Новый Некоуз, ул. Ленина, д.38		0101000020E6100000E5F1B4FCC0074340BB5F05F86EF34C40
14259	1	17	820	21301	22444	\N	57.901823999999998	Ярославская область, Некоузский район, с. Новый Некоуз, ул. Советская, д.38		0101000020E6100000E5F1B4FCC0074340BB5F05F86EF34C40
14258	1	17	820	21301	22444	\N	57.901823999999998	Ярославская область, Некоузский  район, с. Новый Некоуз, ул.Советская, д.38		0101000020E6100000E5F1B4FCC0074340BB5F05F86EF34C40
14257	1	17	820	21301	22444	\N	57.901823999999998	Ярославская область, Некоузский район, с. Новый Некоуз, ул.Советская, д.19		0101000020E6100000E5F1B4FCC0074340BB5F05F86EF34C40
14266	1	17	820	21747	\N	\N	57.891243000000003	Ярославская область, Некоузский  район, с. Новинское, д.74		0101000020E6100000374F75C8CDE64240FCE4284014F24C40
14279	1	17	820	50948	24135	\N	57.931520118581297	Ярославская область, Некоузский  район, д. Новая Ура, ул.Центральная, д.5	Россия, Ярославская область, Некоузский район, поселок Ура	0101000020E6100000CD902A8A57194340F3C81F0C3CF74C40
14462	1	17	820	49224	23080	\N	57.912320000000001	с. Никольское, Мира, 7		0101000020E610000005DCF3FC692543404DBED9E6C6F44C40
14261	1	17	820	21519	22778	\N	57.912736000000002	Ярославская область, Некоузский  район, с. Некоуз, ул.Советская, д.13		0101000020E61000009CA4F9635AFF4240E1F08288D4F44C40
14196	1	17	1488	18087	22422	\N	58.200018999999998	Ярославская область, Даниловский район, с.Шаготь, ул.Нагорная, д.20		0101000020E6100000E789E76C01CF434010CAFB389A194D40
14284	1	17	820	50942	24101	\N	57.949750060419397	Ярославская область, Некоузский  район, с. Мокеиха, ул.Вокзальная, д.6/10	Россия, Ярославская область, Некоузский район	0101000020E61000002AC8CF46AEF1424021B0726891F94C40
14274	1	17	820	22143	22874	\N	58.008938999999998	Ярославская область, Некоузский  район, с. Марьино, ул.Центральная, д.9		0101000020E6100000B7CF2A33A51943405854C4E924014D40
14271	1	17	820	22007	22464	\N	58.074112	Ярославская область, Некоузский район, с. Лацкое, ул.Центральная, д.36		0101000020E61000009626A5A0DB0F4340DE1E84807C094D40
14265	1	17	820	21677	\N	\N	57.964787000000001	Ярославская область, Некоузский район, д. Данилово, д.32		0101000020E61000009D9CA1B8E3074340904DF2237EFB4C40
14281	1	17	820	5867	22386	\N	58.115529000000002	Ярославская область, Некоузский  район, с. Воскресенское, ул. Центральная, д. 37		0101000020E6100000B1C05774EB054340AB5E7EA7C90E4D40
14280	1	17	820	5867	22386	\N	58.115529000000002	Ярославская область, Некоузский  район, с. Воскресенское, ул.Центральная, д.37		0101000020E6100000B1C05774EB054340AB5E7EA7C90E4D40
14277	1	17	820	50923	24076	\N	57.949238976626702	Ярославская область, Некоузский район, п. Волга, ул. Линейная, д.3, Некоузский  район, п. Волга, ул. Ленина, д.20	Россия, Ярославская область, Некоузский район, поселок Волга	0101000020E6100000BA826DC4933143403B8BDEA980F94C40
14276	1	17	820	50923	24066	\N	57.950728208655299	Ярославская область, Некоузский  район, п. Волга, ул.Линейная, д.3	Россия, Ярославская область, Некоузский район, поселок Волга	0101000020E6100000E6913F18783243401CB28174B1F94C40
14273	1	17	820	22084	\N	\N	58.116070000000001	Ярославская область, Некоузский  район, с. Веретея, д.23, Ярославская область, Некоузский район, с. Веретея, д. 21		0101000020E61000003F524486551A4340FB05BB61DB0E4D40
14270	1	17	820	21913	\N	\N	58.060744999999997	Ярославская область, Некоузский  район, п. Борок, д.134		0101000020E610000074982F2FC01E4340A032FE7DC6074D40
14269	1	17	820	21913	\N	\N	58.060744999999997	Ярославская область, Некоузский район, п. Борок, д.134		0101000020E610000074982F2FC01E4340A032FE7DC6074D40
14275	1	17	820	50578	\N	\N	58.001770978402902	Ярославская область, Некоузский  район, м. Андреевское, д.40	Россия, Ярославская область, Некоузский район, поселок Андреевское	0101000020E61000008D47A984271A4340658A39083A004D40
14252	1	17	1633	50629	\N	\N	57.786653999999999	Ярославская область, Мышкинский район, с. Флоровское, здание администрации Приволжского сельского поселения		0101000020E6100000A4AA09A2EE11434040A20914B1E44C40
14253	1	17	1633	21144	\N	\N	57.760496000000003	"Ярославская область, Мышкинский район, с. Шипилово, здание общеобразовательной школы,, с.Шипилово, здание  Шипиловского Дома культуры"		0101000020E61000007270E998F31A4340925ED4EE57E14C40
14241	1	17	1633	20529	\N	\N	57.781688000000003	"Ярославская область, Мышкинский район, д.Ступино, здание  Ступинской начальной школы,, с.Архангельское, здание администрации Приволжского СП"		0101000020E610000075594C6C3E1243407CD6355A0EE44C40
14250	1	17	1633	20981	\N	\N	57.677230999999999	"Ярославская область, Мышкинский район, с. Сера, здание Серского сельского клуба,, с.Сера, здание Серской библиотеки"		0101000020E61000003541D47D002A43402F6B6281AFD64C40
14251	1	17	1633	21046	\N	\N	57.726956999999999	"Ярославская область, Мышкинский район, с. Рождествено, здание Рождественской средней общеобразовательной школы,, с.Рождествено, помещение администрации Приволжского СП"		0101000020E610000074081C0934F84240944C4EED0CDD4C40
14313	1	17	1633	21046	23077	\N	57.726956999999999	с. Рождествено, Центральная, 13	Россия, Ярославская область, Мышкинский район, поселок Рождествено	0101000020E610000074081C0934F84240944C4EED0CDD4C40
14249	1	17	1633	20959	\N	\N	57.745426000000002	Ярославская область, Мышкинский район, с.Поводнево, здание Дома культуры		0101000020E610000048DC63E94337434047CB811E6ADF4C40
14248	1	17	1633	20894	\N	\N	57.799160000000001	"Ярославская область, Мышкинский район, с. Охотино, здание Охотинской начальной школы,, с. Охотино, здание администрации Охотинского СП"		0101000020E6100000F6ECB94C4D404340BC22F8DF4AE64C40
14240	1	17	1633	21218	23182	\N	57.788291991013999	"Ярославская область, г.Мышкин,  ул.Угличская, д. 92, здание ГУП ""Автодор"",, г.Мышкин, ул.К.Либкнехта, д. 45, Межпоселенческий ДК"	Россия, Ярославская область, Мышкинский район, Мышкин	0101000020E6100000FA7B293C683A434066D993C0E6E44C40
14255	1	17	1633	21218	22813	\N	57.787925000000001	Ярославская область, г.Мышкин, ул.К.Либкнехта, 45, здание Межпоселенческого Дома культуры		0101000020E6100000A7B393C1513A4340B459F5B9DAE44C40
14256	1	17	1633	21218	22532	\N	57.787925000000001	"Ярославская область, г.Мышкин,  ул. Загородная, д. 93, здание средней общеобразовательной школы,, г.Мышкин, ул.К.Либкнехта, д. 45, Межпоселенческий ДК"		0101000020E6100000A7B393C1513A4340B459F5B9DAE44C40
14254	1	17	1633	21218	23250	\N	57.788200311713801	"Ярославская область, г. Мышкин, ул.К.Либкнехта, д. 35, здание ПУ-34,, г.Мышкин, ул.К.Либкнехта, д. 45, Межпоселенческий ДК"		0101000020E6100000F7AB00DF6D3A4340865AD3BCE3E44C40
14247	1	17	1633	50569	\N	\N	57.677936780149302	Ярославская область, Мышкинский район, д.Мартыново, помещение администрации Приволжского сельского поселения	Россия, Ярославская область, Мышкинский район, поселок Мартыново	0101000020E6100000E5266A696EFF4240CADFBDA3C6D64C40
14246	1	17	1633	20775	\N	\N	57.838529000000001	Ярославская область, Мышкинский район, д. Крюково, здание администрации  Приволжского сельского поселения		0101000020E6100000732A1900AA204340B1DF13EB54EB4C40
14244	1	17	1633	20675	\N	\N	57.839823000000003	Ярославская область, Мышкинский район, с. Кривец, помещение сельского клуба Кривецкого спец. дома-интерната		0101000020E6100000A741D13C803D4340DDB6EF517FEB4C40
14245	1	17	1633	20709	\N	\N	57.857075000000002	"Ярославская область, Мышкинский район, д. Коптево, здание общеобразовательной школы,, д.Коптево, здание сельского Дома культуры, тел. 3-26-48"		0101000020E6100000E9B81AD9953843400F9C33A2B4ED4C40
14141	1	17	1633	47617	\N	\N	57.826554000000002	Горелово село, здание Гореловского сельского клуба		0101000020E610000016325706D514434062307F85CCE94C40
14243	1	17	1633	20620	\N	\N	57.809964000000001	Ярославская область, Мышкинский район, д. Галачевская, здание Галачевского сельского клуба		0101000020E61000002769FE98D6384340FB777DE6ACE74C40
14242	1	17	1633	20540	\N	\N	57.659416	Ярославская область, Мышкинский район, с.Богородское, здание  Дома культуры		0101000020E6100000B62FA017EEE24240C53A55BE67D44C40
14455	1	17	818	49124	23106	\N	58.292150999999997	п. Шашково, Юбилейная, 32	Россия, Ярославская область, Любимский район, поселок Шашково	0101000020E61000005116BEBED6434440313F373465254D40
14238	1	17	818	20307	\N	\N	58.081251000000002	Ярославская область, Любимский район, д.Черново, здание Черновского сельского ДК		0101000020E6100000B6BC72BD6D4A444037E2C96E660A4D40
14206	1	17	818	18589	\N	\N	58.507435000000001	Ярославская область, Любимский район, д.Фрольцево, здание Воскресенской ООШ		0101000020E61000004792205C0143444042EC4CA1F3404D40
14216	1	17	818	19118	\N	\N	58.181317999999997	Ярославская область, Любимский район, с. Филиппово, здание Филипповской ООШ		0101000020E610000006668522DD4544408B16A06D35174D40
14239	1	17	818	20385	\N	\N	58.499433000000003	Ярославская область, Любимский район, с.Троица, здание Троицкого сельского ДК		0101000020E610000021CB82893F5A444087C5A86BED3F4D40
14230	1	17	818	19843	\N	\N	58.281283999999999	Ярославская область, Любимский район, д.Страшево, здание Страшевской ООШ		0101000020E610000062F9F36DC1384440AC71361D01244D40
14227	1	17	818	5841	22807	\N	58.341250000000002	Ярославская область, Любимский район, п.Соколиный, ул. Молодежная 7/2		0101000020E6100000E146CA164965444048E17A14AE2B4D40
14236	1	17	818	20182	\N	\N	58.184089999999998	Ярославская область, Любимский район, д.Семендяево, здание Семендяевского сельского ДК		0101000020E61000000745F300165D4440A4C2D84290174D40
14237	1	17	818	20262	\N	\N	58.075972999999998	Ярославская область, Любимский район, д.Рузбугино, здание администрации Осецкого сельского поселения		0101000020E6100000751F80D4265444408330B77BB9094D40
14235	1	17	818	20147	\N	\N	58.279944999999998	"Ярославская область, Любимский район, д.Раслово, здание МУК ""Расловского ЦДК"""		0101000020E6100000C093162EAB564440E0D6DD3CD5234D40
14233	1	17	818	20009	\N	\N	58.468007	Ярославская область, Любимский район, с. Покров, здание Покров-Кулижской ООШ		0101000020E6100000AE7FD767CE6E444048A643A7E73B4D40
14229	1	17	818	19795	\N	\N	58.376074000000003	"Ярославская область, Любимский район, п.Отрадный, здание МУК ""ЦДК п.Отрадный"""		0101000020E61000006C7A50508A5A44401E705D3123304D40
14234	1	17	818	20070	\N	\N	58.266703	Ярославская область, Любимский район, д.Обнорское, здание отделения администрации Ермаковского с/п		0101000020E61000001827BEDA517444405F5FEB5223224D40
14221	1	17	818	19380	\N	\N	58.344599000000002	Ярославская область, Любимский район, д.Минино, здание Мининского сельского ДК		0101000020E6100000BC3C9D2B4A8D4440FE9DEDD11B2C4D40
14228	1	17	818	17881	22892	\N	58.354890290460801	"Ярославская область, помещение для голосования - здание МУК Любимский районный ДК, г.Любим, Трефолева, 12/2, местонахождение УИК - Любимский район, д.Останково, здание конторы ЗАО""Заречье"""	Россия, Ярославская область, Любимский район, Любим	0101000020E6100000412B306475594440B6D617096D2D4D40
14218	1	17	818	17881	22545	\N	58.350923000000002	Ярославская область, г. Любим, Советская, 19		0101000020E6100000F27A30293E58444005357C0BEB2C4D40
14192	1	17	818	17881	22545	\N	58.350923000000002	Ярославская область, г.Любим, Советская, 119		0101000020E6100000F27A30293E58444005357C0BEB2C4D40
14217	1	17	818	17881	22801	\N	58.350923000000002	Ярославская область, г. Любим, Октябрьская, 11		0101000020E6100000F27A30293E58444005357C0BEB2C4D40
14219	1	17	818	17881	22927	\N	58.350923000000002	Ярославская область, г.Любим, Набережная реки Обноры, 14/62		0101000020E6100000F27A30293E58444005357C0BEB2C4D40
14224	1	17	818	50530	\N	\N	58.083864693067198	Ярославская область, Любимский район, д.Крутик, помещение сельского клуба	Россия, Ярославская область, Любимский район, поселок Крутик	0101000020E61000006F9D7FBBEC634440B8239C16BC0A4D40
14566	1	17	818	50906	\N	\N	58.113153465882498	п. Красный Бор, д. 1 (библиотека)	Россия, Ярославская область, Любимский район, поселок Красный Бор	0101000020E6100000DD2230D6376E4440DE3829CC7B0E4D40
14225	1	17	818	19590	\N	\N	58.404353	Ярославская область, Любимский район, д.Кириллово, здание Кирилловского сельского ДК		0101000020E6100000C9207711A66E44400E85CFD6C1334D40
14226	1	17	818	19648	\N	\N	58.374229	Ярославская область, Любимский район, д.Кинтаново, здание Кинтановской ООШ		0101000020E6100000077E54C37E7944407E1B62BCE62F4D40
14223	1	17	818	19480	\N	\N	58.105938999999999	Ярославская область, Любимский район, с. Закобякино, здание отделения Закобякино администрации Осецкого с/п		0101000020E61000002CD505BCCC5C44407B2FBE688F0D4D40
14222	1	17	818	19428	\N	\N	58.323442	Ярославская область, Любимский район, д.Ермаково, здание администрации Ермаковского сельского поселения		0101000020E61000005A2A6F47388144409013268C66294D40
14232	1	17	818	50920	\N	\N	58.348647720408401	Ярославская область, Любимский район, д.Гузыцино, здание спортивного зала	Россия, Ярославская область, Любимский район, поселок Гузыцыно	0101000020E61000001C42959A3D5044406CE8667FA02C4D40
14231	1	17	818	19903	\N	\N	58.360360999999997	"Ярославская область, Любимский район, д.Вахромейка, здание МУК ""Вахромеевский ЦДК"""		0101000020E610000038842A357B4644407EE02A4F202E4D40
14211	1	17	1488	18865	22518	\N	57.985366999999997	Ярославская область, Даниловский район, д.Чурьяково, ул.Старая, д.22		0101000020E61000009ECF807A3344444060C77F8120FE4C40
14194	1	17	1488	17993	22588	\N	58.301099999999998	Ярославская область, Даниловский район, с.Хабарово, ул.Школьная, д.1		0101000020E6100000D844662E70FF4340AD69DE718A264D40
14214	1	17	1488	19012	22740	\N	58.045887	Ярославская область, Даниловский район, д.Федурино, ул.Покровская, д.8		0101000020E6100000F88A6EBDA6394440E1270EA0DF054D40
14209	1	17	1488	50943	24103	\N	58.134453999999998	Ярославская область, Даниловский район, д.Трофимово, ул.Набережная, д.10	Россия, Ярославская область, Даниловский район	0101000020E6100000FB3E1C24440D44407F68E6C935114D40
14200	1	17	1488	18271	22424	\N	58.132671999999999	адрес помещения для голосования: Ярославская область, Даниловский район, с.Торопово, ул.Рабочая, д.2, адрес УИК: с.Торопово, ул.Запрудная, д.2		0101000020E61000000CAD4ECE50FA4340268C6665FB104D40
14208	1	17	1488	50524	22593	\N	57.915875651667498	Ярославская область, Даниловский район, д.Телицино, ул.Мира, д.3-Б	Россия, Ярославская область, Даниловский район, поселок Телицыно	0101000020E6100000DF6FB4E3861944407C98BD6C3BF54C40
14198	1	17	1488	18171	22857	\N	58.209702	Ярославская область, Даниловский район, с.Спас, ул.Школьная, д.17		0101000020E6100000F67D384888F24340F1F3DF83D71A4D40
14202	1	17	1488	18375	22921	\N	58.000411999999997	Ярославская область, Даниловский район, д.Скоково, ул.Центральная, д.8		0101000020E6100000A8E15B583702444052431B800D004D40
14212	1	17	1488	18909	22669	\N	58.005367	адрес помещения для голосования: Ярославская область, Даниловский район, с.Середа, ул.Ленина, д.33, адрес УИК: с.Середа, ул.Октябрьская, д.2/1		0101000020E610000052F01472A538444023BDA8DDAF004D40
14215	1	17	1488	19075	22673	\N	58.084434000000002	Ярославская область, Даниловский район, д.Семлово, ул.Школьная, д.1		0101000020E61000008D2958E36C2E4440D255BABBCE0A4D40
14201	1	17	1488	18331	22508	\N	58.035525999999997	Ярославская область, Даниловский район, д.Рыжиково, ул.Почтовая, д.7		0101000020E6100000F25F200890F343402F14B01D8C044D40
14193	1	17	1488	17947	22854	\N	58.264142	адрес помещения для голосования: Ярославская область, Даниловский район, п.Рощино, ул.Центральная, д.17, адрес УИК: д.Слобода, ул.Северная, д.33		0101000020E610000007EDD5C74319444001C0B167CF214D40
14190	1	17	1488	17785	22875	\N	58.249388000000003	Ярославская область, Даниловский район, с.Покров, ул.Центральная, д.4		0101000020E610000096B377465B254440E7012CF2EB1F4D40
14199	1	17	1488	18232	22507	\N	58.13156	Ярославская область, Даниловский район, д.Мишутино, ул.Молодежная, д.2		0101000020E61000001EE1B4E045ED43401BBB44F5D6104D40
14189	1	17	1488	17749	22914	\N	58.160235	адрес помещения для голосования: Ярославская область, Даниловский район, д.Малое Марьино, ул.Молодёжная, д.2а, адрес УИК: д.Малое Марьино, ул.Центральная, д.3		0101000020E61000004DBED9E6C624444058569A9482144D40
14191	1	17	1488	17844	22656	\N	58.310495000000003	Ярославская область, Даниловский район, д.Макарово, ул.Вологодская, д.17		0101000020E6100000D2A6EA1ED91A44402849D74CBE274D40
14210	1	17	1488	18802	22795	\N	57.96069	Ярославская область, Даниловский район, д.Лыкошино, ул.Центральная, д.4а		0101000020E61000005AD5928E7232444010CCD1E3F7FA4C40
14205	1	17	1488	18545	22589	\N	58.139043000000001	Ярославская область, Даниловский район, д.Кузьмино, ул.Ярославская, д.18		0101000020E610000093E1783E031244406EDE3829CC114D40
14203	1	17	1488	18441	22732	\N	57.963689000000002	Ярославская область, Даниловский район, д.Костюшино, ул.Центральная, д.1		0101000020E6100000F146E6913F024440EA4141295AFB4C40
14148	1	17	1488	47745	24057	\N	57.910632	Косково село, Советская, 22		0101000020E6100000DE1FEF552B2F44407558E1968FF44C40
14213	1	17	1488	18970	22799	\N	58.034077000000003	Ярославская область, Даниловский район, д.Козлово, ул.Южная, д.12		0101000020E610000075C93846B22D4440DD4598A25C044D40
14195	1	17	1488	18044	22855	\N	58.288395000000001	Ярославская область, Даниловский район, д.Ермаково, ул.Молодежная, д.1		0101000020E6100000E3FDB8FDF2E743403BAA9A20EA244D40
14207	1	17	1488	18658	22397	\N	57.995123	адрес помещения для голосования: Ярославская область, Даниловский район, с.Дмитриевское, ул.Южная, д.1, адрес УИК: с.Дмитриевское, ул.Свободы, д.9		0101000020E6100000D6E6FF5547164440AB3FC23060FF4C40
14182	1	17	1488	17191	22729	\N	58.186959999999999	Ярославская область, г.Данилов, пл.Советская, д.4		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14183	1	17	1488	17191	22717	\N	58.186959999999999	Ярославская область, г.Данилов, пл.Соборная, д.7		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14185	1	17	1488	17191	22692	\N	58.186959999999999	Ярославская область, г.Данилов, ул.Ярославская, д.52		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14181	1	17	1488	17191	22793	\N	58.186959999999999	Ярославская область, г.Данилов, ул.Урицкого, д.58-а		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14180	1	17	1488	17191	22793	\N	58.186959999999999	Ярославская область, г.Данилов, ул.Урицкого, д.46		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14178	1	17	1488	17191	22907	\N	58.186959999999999	Ярославская область, г.Данилов, ул.Заводская, д.5		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14186	1	17	1488	17191	22923	\N	58.186959999999999	Ярославская область, г.Данилов, ул.Гражданская, д.2		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14184	1	17	1488	17191	22911	\N	58.186959999999999	Ярославская область, г.Данилов, ул.Вятская, д.4		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14179	1	17	1488	17191	22585	\N	58.186959999999999	Ярославская область, г.Данилов, ул.Володарского, д.83		0101000020E6100000BF2CEDD45C16444080D4264EEE174D40
14188	1	17	1488	17679	22655	\N	58.184659000000003	адрес помещения для голосования: Ярославская область, Даниловский район, п.Горушка, ул.Гагарина, д.6, адрес УИК: п.Горушка, ул.Вахтинское шоссе, д.43		0101000020E61000002D27A1F485124440BFF4F6E7A2174D40
14197	1	17	1488	18150	22730	\N	58.177540999999998	Ярославская область, Даниловский район, с.Горинское, ул.Центральная, д.32		0101000020E6100000A8A78FC01FE243407D59DAA9B9164D40
14204	1	17	1488	18481	22843	\N	58.085675999999999	Ярославская область, Даниловский район, д.Бабаево, ул.Лесная, д.3		0101000020E6100000B03907CF840C4440AB06616EF70A4D40
14175	1	17	1422	17026	22583	\N	57.422311999999998	Ярославская область, Гаврилов-Ямский район, с. Шопша, Центральная, 5		0101000020E610000046EA3D95D3D24340AB5AD2510EB64C40
14176	1	17	1422	17089	22713	\N	57.361123999999997	Ярославская область, Гаврилов-Ямский район, д.Шалаево, Центральная, 6		0101000020E6100000E61E12BEF7CB43407DE6AC4F39AE4C40
14170	1	17	1422	16807	22581	\N	57.226844999999997	Ярославская область, Гаврилов-Ямский район, д. Ульяново, Центральная, 9		0101000020E61000000F5EBBB4E10E44406C21C841099D4C40
14169	1	17	1422	16743	22414	\N	57.235083000000003	Ярославская область, Гаврилов-Ямский район, с. Стогинское, Центральная, 16		0101000020E6100000990F0874260744403C6C2233179E4C40
14172	1	17	1422	16877	22724	\N	57.307121000000002	Ярославская область, Гаврилов-Ямский район, с. Ставотино, Школьная, 11		0101000020E61000009607E92972F843401975ADBD4FA74C40
14168	1	17	1422	16714	22580	\N	57.296773999999999	Ярославская область, Гаврилов-Ямский район, с. Пружинино, Центральная, 41		0101000020E6100000126A865451164440CC26C0B0FCA54C40
14173	1	17	1422	16954	22500	\N	57.376173999999999	Ярославская область, Гаврилов-Ямский район, д. Прошенино, Школьная, 29		0101000020E610000019FF3EE3C2FF434081CD397826B04C40
14162	1	17	1422	16389	22859	\N	57.391345000000001	Ярославская область, Гаврилов-Ямский район, д.Поляна, Клубная, 10		0101000020E61000007ADFF8DA33E34340003ACC9717B24C40
14160	1	17	1422	16271	22856	\N	57.331848999999998	Ярославская область, Гаврилов-Ямский муниципальный район, д.Плотина, Молодежная, 1		0101000020E61000007077D66EBBE84340EB1A2D077AAA4C40
14159	1	17	1422	16214	22418	\N	57.324370999999999	Ярославская область, Гаврилов-Ямский район, с. Плещеево, Центральная, 43		0101000020E6100000CD7344BE4BDD4340AA622AFD84A94C40
14166	1	17	1422	50566	22792	\N	57.297642158165203	Ярославская область, Гаврилов-Ямский район, с. Остров, Школьная, 1	Россия, Ярославская область, Гаврилов-Ямский район, поселок Остров	0101000020E61000007F83F6EAE32D444041F50F2219A64C40
14171	1	17	1422	16857	22652	\N	57.233651000000002	Ярославская область, Гаврилов-Ямский  район, с. Осенево, Центральная, 1		0101000020E610000029ECA2E881194440BFD6A546E89D4C40
14167	1	17	1422	16630	22850	\N	57.338014000000001	Ярославская область, Гаврилов-Ямский район, с. Митино, Колхозная, 20		0101000020E6100000C576F700DD2144408ACBF10A44AB4C40
14161	1	17	1422	16313	22858	\N	57.268839999999997	Ярославская область, Гаврилов-Ямский район, с.Лахость, Урицкого, 2		0101000020E6100000E17EC00303E04340A6ED5F5969A24C40
14177	1	17	1422	17129	22663	\N	57.418236	Ярославская область, Гаврилов-Ямский район, с. Ильинское-Урусово, Тенистая, 1		0101000020E6100000FA97A432C5B643404301DBC188B54C40
14174	1	17	1422	17001	22416	\N	57.409151000000001	Ярославская область, Гаврилов-Ямский район, с. Заячий-Холм, Центральная, 16		0101000020E610000051BB5F05F8F4434017105A0F5FB44C40
14151	1	17	1422	15842	22478	\N	57.309455	г. Гаврилов - Ям, Юбилейный проезд, 5		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14153	1	17	1422	15842	22448	\N	57.309455	г. Гаврилов - Ям, Чернышевского, 3		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14154	1	17	1422	15842	22407	\N	57.309455	г. Гаврилов - Ям, Спортивная, 14		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14155	1	17	1422	15842	22905	\N	57.309455	г. Гаврилов - Ям, Советская, 2		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14156	1	17	1422	15842	22582	\N	57.309455	г. Гаврилов-Ям, Клубная, 1		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14158	1	17	1422	15842	22445	\N	57.309455	г. Гаврилов - Ям, Кирова, 13		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14157	1	17	1422	15842	22445	\N	57.309455	г.Гаврилов-Ям, Кирова, 13		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14152	1	17	1422	15842	22754	\N	57.309455	г. Гаврилов - Ям, Калинина, 4		0101000020E610000050C3B7B06EEC4340B64AB0389CA74C40
14164	1	17	1422	16470	22410	\N	57.350714000000004	Ярославская область, Гаврилов-Ямский район, с.Великое, Р.Люксембург, 12		0101000020E610000088BB7A1519E34340EB1F4432E4AC4C40
14165	1	17	1422	16470	22903	\N	57.350714000000004	Ярославская область, Гаврилов-Ямский район, с. Великое, Некрасовская, 1		0101000020E610000088BB7A1519E34340EB1F4432E4AC4C40
14138	1	17	1332	47566	\N	\N	58.152313999999997	Ульяниха деревня, здание администрации Брейтовского сельского поселения		0101000020E610000033C51C041DE14240895C70067F134D40
14118	1	17	1332	14284	22662	\N	58.341631999999997	Сутка село, Молодёжная, 4		0101000020E6100000AD4F39268BC542402FA2ED98BA2B4D40
14145	1	17	1332	15564	\N	\N	58.365988000000002	Суминское деревня, здание Суминского сельского клуба, 7		0101000020E6100000950F41D5E8D942403E5DDDB1D82E4D40
14143	1	17	1332	15471	\N	\N	58.230708999999997	Севастьянцево деревня, здание Гореловского сельского поселения		0101000020E6100000C2BD326FD5F9424049F25CDF871D4D40
14146	1	17	1332	15617	\N	\N	58.368805999999999	Себельское деревня, здание Себельского сельского клуба, 63		0101000020E6100000085A8121ABC74240C748F608352F4D40
14144	1	17	1332	47668	22816	\N	58.394134000000001	Прозорово село, Михайловская, 8/2		0101000020E610000096766A2E37D44240EF1EA0FB72324D40
14142	1	17	1332	15394	\N	\N	58.268628999999997	Остряковка деревня, здание Остряковского Дома культуры		0101000020E6100000FB57569A94F84240EBE0606F62224D40
14135	1	17	1332	47499	\N	\N	58.327666999999998	Новинка деревня, здание Новинского сельского клуба	Россия, Ярославская область, Брейтовский район, поселок Новинка	0101000020E61000000BEF7211DFE542403D7D04FEF0294D40
14136	1	17	1332	47521	\N	\N	58.311100000000003	Логинцево деревня, здание Логинцевского сельского клуба		0101000020E6100000768D96033DE042408FE4F21FD2274D40
14147	1	17	1332	47708	\N	\N	58.341183999999998	Лискино деревня, здание Лискинского сельского клуба, 58		0101000020E61000000D6C956071BA424090F5D4EAAB2B4D40
14139	1	17	1332	50510	\N	\N	58.1991702696087	Коростель деревня, здание Коростельской начальной школы	Россия, Ярославская область, Брейтовский район, поселок Коростень	0101000020E6100000FBCC599F72F04240132C0E677E194D40
14150	1	17	1332	15757	22612	\N	58.297415999999998	Брейтово село, Республиканская, 54		0101000020E6100000F44F70B1A2EE424050A73CBA11264D40
14114	1	17	785	14077	22626	\N	57.355589000000002	Ярославская область, Борисоглебский район, с.Яковцево, ул.Центральная, д.11		0101000020E610000036E84B6F7FA643409FE8BAF083AD4C40
14123	1	17	785	14508	22840	\N	57.417639000000001	Адрес помещения для голосования: Ярославская область, Борисоглебский район, д.Юркино, ул.Транспортная, д.5, Адрес УИК: д.Юркино, ул.Центральная, д.18а		0101000020E6100000F627F1B9138A43405F44DB3175B54C40
14134	1	17	785	15014	22404	\N	57.167599000000003	Ярославская область, Борисоглебский район, с.Щурово, ул.Транспортная, д.24		0101000020E610000037397CD289684340D1EB4FE273954C40
14131	1	17	785	14895	22640	\N	57.194406000000001	Ярославская область, Борисоглебский район, с.Сущево, ул.Центральная, д.26		0101000020E610000087E123624A8C4340B612BA4BE2984C40
14124	1	17	785	50946	24122	\N	57.457426657952901	Адрес помещения для голосования: Ярославская область, Борисоглебский район, д.Сигорь, ул.Лесная, д.2, Адрес УИК: д.Сигорь, ул.Речная, д.8		0101000020E6100000F1D58EE21C8D434059A7CAF78CBA4C40
14119	1	17	785	14305	22703	\N	57.263086999999999	Ярославская область, Борисоглебский район, д.Селище, ул.Верхняя, д.1а		0101000020E6100000E82E89B3229043405A80B6D5ACA14C40
14132	1	17	785	14920	22477	\N	57.14902	Ярославская область, Борисоглебский район, с.Покровское, ул.Клубная, д.4		0101000020E61000008E01D9EBDD7D434097395D1613934C40
14122	1	17	785	14443	22627	\N	57.461022999999997	Ярославская область, Борисоглебский район, с.Неверково. ул.Школьная, д.5		0101000020E610000099D4D006607B434016DA39CD02BB4C40
14117	1	17	785	14224	22833	\N	57.324731	Ярославская область, Борисоглебский район, п.Красный Октябрь, ул.Советская. д.2а		0101000020E6100000AA9D616A4B814340AA7F10C990A94C40
14120	1	17	785	5557	22886	\N	57.227245000000003	Ярославская область, Борисоглебский район, с.Красново, пер.Луговой, д.4		0101000020E61000007AFEB4519D984340FB96395D169D4C40
14127	1	17	785	14714	\N	\N	57.289323000000003	Ярославская область, Борисоглебский район, с.Кондаково, д.60		0101000020E6100000284696CCB1644340857D3B8908A54C40
14126	1	17	785	14654	22842	\N	57.213034	Ярославская область, Борисоглебский район, д.Козино, ул.Красная, д.19		0101000020E610000008C89750C1634340D177B7B2449B4C40
14130	1	17	785	50936	24086	\N	57.198676347898598	Ярославская область, Борисоглебский район, д.Инальцино, ул.Новая, д.21	Россия, Ярославская область, Борисоглебский район, поселок Инальцыно	0101000020E61000000E10CCD1E37B4340034015376E994C40
14112	1	17	785	13992	22777	\N	57.117313000000003	Ярославская область, Борисоглебский район, с.Зачатье, ул.Центральная, д.16а		0101000020E6100000B972F6CE68614340A532C51C048F4C40
14128	1	17	785	14727	\N	\N	57.316197000000003	Ярославская область, Борисоглебский район, с.Давыдово, д.19		0101000020E6100000857AFA08FC6B4340F20BAF2479A84C40
14125	1	17	785	14594	22739	\N	57.238312999999998	Адрес помещения для голосования: Ярославская область, Борисоглебский район, с.Высоково, ул.Липовая, д.3, Адрес УИК: с.Высоково, ул.Центральная, д.12		0101000020E610000073BED87BF15F4340179B560A819E4C40
14121	1	17	785	14428	22888	\N	57.362352000000001	Адрес помещения для голосования: Ярославская область, Борисоглебский район, с.Вощажниково, ул.Советская, д.8, Адрес УИК: с.Вощажниково, ул.Советская, д.50		0101000020E61000007FA65EB708924340F2D1E28C61AE4C40
14310	1	17	785	46369	23123	\N	57.361244999999997	п. Бурмакино, Советская, 8б		0101000020E6100000483657CD739E4340F86BB2463DAE4C40
14311	1	17	785	46369	24061	\N	57.361043453559901	адрес помещения для голосования: с. Бурмакино, ул. Заречная, д. 30, адрес УИК: с. Бурмакино, ул. Заречная, д. 31		0101000020E6100000E5EE737CB49E434091B932A836AE4C40
14309	1	17	785	46369	23088	\N	57.361244999999997	п. Бурмакино, Ленина, 19		0101000020E6100000483657CD739E4340F86BB2463DAE4C40
14115	1	17	785	14143	22831	\N	57.260814000000003	Ярославская область, Борисоглебский район, п.Борисоглебский, ул.Победы, д.1а		0101000020E61000000A664CC11A934340632B685A62A14C40
14116	1	17	785	14143	22702	\N	57.260814000000003	Ярославская область, Борисоглебский район, п.Борисоглебский, ул.Первомайская, д.4а		0101000020E61000000A664CC11A934340632B685A62A14C40
14133	1	17	785	14984	22893	\N	57.164192	Ярославская область, Борисоглебский район,  д.Березники, ул.Транспортная, д.2		0101000020E6100000C8940F41D5724340E621533E04954C40
14113	1	17	785	14022	22461	\N	57.303916999999998	Адрес помещения для голосования: Ярославская область, Борисоглебский район, д.Андреевское, ул.Крестьянская, д.26, Адрес УИК: д.Андреевское, ул.Мира, д.2		0101000020E610000001FBE8D4959D434066D993C0E6A64C40
14129	1	17	785	14798	\N	\N	57.318894	Ярославская область, Борисоглебский район,  д.Алешкино, д.72		0101000020E61000009BABE639227B43400072C284D1A84C40
14098	1	17	1276	13305	22546	\N	57.769046000000003	Ярославская область, Большесельский район, село Шельшедом, улица Мира, дом 10		0101000020E6100000A3B1F677B6A94340508F6D1970E24C40
14111	1	17	1276	13933	22634	\N	57.673375999999998	Ярославская область, Большесельский район, деревня Чудиново, улица Школьная, дом 12		0101000020E6100000E6B1666490954340A5F44C2F31D64C40
14586	1	17	1276	47329	22433	\N	57.718147000000002	с. Устье, ул. Центральная, д. 48 А (ФАП)		0101000020E6100000710168942E5543403A5CAB3DECDB4C40
14103	1	17	1276	13577	22458	\N	57.803446999999998	Ярославская область, Большесельский район, деревня Новое Гостилово, улица Зеленая, дом 4		0101000020E610000077F35487DC7E4340DF88EE59D7E64C40
14110	1	17	1276	13874	22885	\N	57.701611999999997	Ярославская область, Большесельский район, село Новое, улица Октябрьская, дом 2		0101000020E610000088635DDC46634340963D096CCED94C40
14107	1	17	1276	13723	22884	\N	57.69547	Ярославская область, Большесельский район, деревня Миглино, улица Мира, дом 1А		0101000020E61000005439ED2939914340B0AC342905D94C40
14108	1	17	1276	13779	\N	\N	57.632896000000002	Ярославская область, Большесельский район, деревня Иванцево, дом 13		0101000020E6100000A99F3715A962434076E272BC02D14C40
4314	1	16	\N	12984	75201	\N	54.199485000000003	город Тула, Советский район, Сойфера, 35		0101000020E6100000121615713ACB4240738577B988194B40
14100	1	17	1276	13432	22700	\N	57.757345999999998	Ярославская область, Большесельский район, село Дунилово, улица Рабочая, дом 18		0101000020E61000006ABFB51325774340D2E0B6B6F0E04C40
14109	1	17	1276	13839	\N	\N	57.773068000000002	Ярославская область, Большесельский район, деревня Гари, дом 26		0101000020E61000000D6E6B0BCF5F4340C5CA68E4F3E24C40
14105	1	17	1276	13651	22774	\N	57.607277000000003	Ярославская область, Большесельский район, деревня Высоково, улица А.В.Романова, дом 19		0101000020E6100000BFB854A52D744340774EB340BBCD4C40
14101	1	17	1276	13452	22752	\N	57.776038999999997	Ярославская область, Большесельский район, село Варегово, улица Мира, дом 25		0101000020E61000003866D993C0A44340D4B5F63E55E34C40
14102	1	17	1276	13510	22879	\N	57.816834	Ярославская область, Большесельский район,  деревня Борисовское, улица Молодежная, дом 6		0101000020E610000067D311C0CD8A434064213A048EE84C40
14099	1	17	1276	13378	22760	\N	57.594579000000003	Ярославская область, Большесельский район, село Большое Село, улица Челюскинцев, дом 3А		0101000020E6100000DB368C82E0634340B7F1272A1BCC4C40
14104	1	17	1276	13378	22828	\N	57.594579000000003	Ярославская область, Большесельский район, село Большое Село, улица Заречная, дом 8		0101000020E6100000DB368C82E0634340B7F1272A1BCC4C40
14106	1	17	1276	13704	\N	\N	57.669468000000002	Ярославская область, Большесельский район, деревня Байково, дом 10		0101000020E6100000D6A71C93C5814340F9DB9E20B1D54C40
14446	1	17	1276	48967	23094	\N	57.714277000000003	с. Арефино, Советская, 4	Россия, Ярославская область, Большесельский район, поселок Арефино	0101000020E6100000897956D28A8F43407BA4C16D6DDB4C40
3460	1	16	\N	60607	75441	\N	53.910034000000003	д.Сестрики, Интернациональная, 10		0101000020E6100000DD79E2395BB64240C11F7EFE7BF44A40
4200	1	16	\N	60512	75277	\N	54.478147999999997	г.Ясногорск, ул.П.Смидовича, д.4		0101000020E6100000350A4966F5D84240EB5223F4333D4B40
4204	1	16	\N	60512	75112	\N	54.478147999999997	г.Ясногорск, ул.Машиностроителей, д.7		0101000020E6100000350A4966F5D84240EB5223F4333D4B40
4138	1	16	\N	60511	75108	\N	54.003118999999998	г. Щекино, ул. Учебная, 7		0101000020E6100000D3F4D901D7C14240847F113466004B40
4140	1	16	\N	60511	75110	\N	54.003118999999998	г. Щекино, ул. Советская, 40		0101000020E6100000D3F4D901D7C14240847F113466004B40
4065	1	16	\N	51156	75084	\N	53.972175999999997	г.  Узловая, кв-л им. 50-летия Октября, 7а		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4068	1	16	\N	51156	25298	\N	53.976464116280098	г. Узловая, Завенягина, 16а		0101000020E6100000D78A36C7B917434055DCB8C5FCFC4A40
94884	1	16	\N	12984	\N	\N	54.098461999999998	г Тула, пос. Южный		0101000020E6100000FF7A8505F7CD42400AF31E679A0C4B40
4336	1	16	\N	12984	\N	\N	54.0573549292941	город Тула, Центральный район, Озерный поселок, 1А	Россия, Тульская область, Тула городской округ, поселок Озерный	0101000020E6100000F31DFCC401CC42408CA19C6857074B40
3639	1	16	\N	12984	\N	\N	54.102000150114797	с.Овсянниково	Россия, Тульская область, Тула, поселок Овсянниково	0101000020E61000006BD26D895CCC4240931804560E0D4B40
201	1	16	\N	12984	\N	\N	54.111702000000001	поселок Октябрьский	Россия, Тульская область, Тула, поселок Октябрьский, улица Киреевская	0101000020E6100000F6ED2422FCCB4240EB724A404C0E4B40
3655	1	16	\N	12984	15364	\N	54.113196000000002	п.Маяк, Садовая, 3	Россия, Тульская область, Тула, поселок Горняк, улица Садовая, 9	0101000020E61000008C9DF0129CCA4240DE04DF347D0E4B40
4223	1	16	\N	12984	3910	\N	54.206173999999997	город Тула, Зареченский район, Дрейера Набережная, 33	Россия, Тульская область, Тула, улица Дрейера, 33	0101000020E6100000A96A82A8FBCC42408BA4DDE8631A4B40
4289	1	16	\N	12984	4723	\N	54.186816	город Тула, Пролетарский район, Дачная, 26	Россия, Тульская область, Тула, улица Дачная, 22	0101000020E61000009FCDAACFD5DA42404D2F3196E9174B40
4209	1	16	\N	12984	3687	\N	54.215282999999999	город Тула, Зареченский район, Галкина, 29	Россия, Тульская область, Тула, улица Галкина, 29	0101000020E61000001E3526C45CD042404031B2648E1B4B40
4338	1	16	\N	12984	75150	\N	54.119466000000003	город Тула, Центральный район, Скуратовский микрорайон, 10	Россия, Тульская область, Тула, микрорайон Скуратовский, 10а	0101000020E61000007C2AA73D25D14240F27D71A94A0F4B40
4231	1	16	\N	12984	75179	\N	54.146397	город Тула, Привокзальный район, Генерала Маргелова, 5		0101000020E61000008FAB915D69C94240C39D0B23BD124B40
4282	1	16	\N	12984	75219	\N	54.206305	город Тула, Пролетарский район, Ю. Фучика, 24 К1		0101000020E610000016A5846055D942402A00C633681A4B40
4265	1	16	\N	12984	75115	\N	54.220574552210799	город Тула, Пролетарский район, Щегловская засека, 35	Россия, Тульская область, Тула, улица Щегловская Засека	0101000020E61000007A37161406D9424058A835CD3B1C4B40
4264	1	16	\N	12984	75115	\N	54.221200000000003	город Тула, Пролетарский район, Щегловская засека, 17		0101000020E610000044317903CCD6424007F01648501C4B40
3988	1	16	\N	12984	75455	\N	54.111702000000001	п. Октябрьский, Школьная, 15		0101000020E6100000F6ED2422FCCB4240EB724A404C0E4B40
94878	1	16	\N	12984	75141	\N	54.165647	г Тула,  ул. Шевченко, 21		0101000020E6100000E560360186CD42401BD7BFEB33154B40
4307	1	16	\N	12984	75257	\N	54.192753000000003	город Тула, Советский район, Халтурина, 1		0101000020E61000005393E00D69CC42405B9A5B21AC184B40
4306	1	16	\N	12984	75165	\N	54.189270999999998	город Тула, Советский район, Фрунзе, 18		0101000020E6100000390CE6AF90CB4240658A39083A184B40
4324	1	16	\N	12984	75206	\N	54.185357000000003	город Тула, Центральный район, Фридриха Энгельса, 89		0101000020E6100000753E3C4B90CD4240D78A36C7B9174B40
4299	1	16	\N	12984	75206	\N	54.175792999999999	город Тула, Советский район, Фридриха Энгельса, 68		0101000020E610000007B7B585E7CB4240D0EE906280164B40
4328	1	16	\N	12984	75218	\N	54.173462999999998	город Тула, Центральный район, Тимирязева, 99		0101000020E6100000EDD45C6E30CE424074081C0934164B40
4233	1	16	\N	12984	75207	\N	54.165092999999999	город Тула, Привокзальный район, Сурикова, 5		0101000020E6100000871403249AC8424036E675C421154B40
4319	1	16	\N	12984	75181	\N	54.186641999999999	город Тула, Центральный район, Староникитская, 38Б		0101000020E610000026FDBD141ED04240AF0793E2E3174B40
4318	1	16	\N	12984	75181	\N	54.179107999999999	город Тула, Центральный район, Староникитская, 107		0101000020E6100000E9D500A5A1D04240DA39CD02ED164B40
4311	1	16	\N	12984	75201	\N	54.198805999999998	город Тула, Советский район, Сойфера, 8		0101000020E61000006A8995D1C8CD4240D11F9A7972194B40
4237	1	16	\N	12984	75122	\N	54.175015948208397	город Тула, Привокзальный район, Серебровская, 32	Россия, Тульская область, Тула, улица Серебровская	0101000020E6100000029F1F4608C942406C239EEC66164B40
4234	1	16	\N	12984	75224	\N	54.172525	город Тула, Привокзальный район, Седова, 35В		0101000020E610000032005471E3C84240075F984C15164B40
94882	1	16	\N	12984	75211	\N	54.163085000000002	г Тула ул. Рязанская, 40		0101000020E6100000DD0720B589CF4240EDBB22F8DF144B40
94881	1	16	\N	12984	75211	\N	54.163085000000002	г Тула, ул. Рязанская, 40		0101000020E6100000DD0720B589CF4240EDBB22F8DF144B40
4241	1	16	\N	12984	75154	\N	54.199663999999999	город Тула, Привокзальный район, Рогова, 30		0101000020E6100000BC2363B5F9C74240221807978E194B40
4276	1	16	\N	12984	75191	\N	54.208247999999998	город Тула, Пролетарский район, Рихарда Зорге, 29		0101000020E6100000707841446AD642408CBAD6DEA71A4B40
4308	1	16	\N	12984	75143	\N	54.193795841896801	город Тула, Советский район, Революции, 14	Россия, Тульская область, Тула, улица Курковая, 7	0101000020E610000057D11F9A79CC42403D0CAD4ECE184B40
4227	1	16	\N	12984	75190	\N	54.119354999999999	город Тула, Привокзальный район, поселок Косая Гора, улица Пушкина, 19		0101000020E610000081B4FF01D6C642409ACE4E06470F4B40
4225	1	16	\N	12984	75149	\N	54.118837755171	город Тула, Привокзальный район, поселок Косая Гора, улица Пушкина, 24		0101000020E6100000923CD7F7E1C64240D2C26515360F4B40
4217	1	16	\N	12984	75145	\N	54.217126	город Тула, Зареченский район, Пузакова, 12А		0101000020E61000006CB2463D44CF42403F8EE6C8CA1B4B40
4286	1	16	\N	12984	75212	\N	54.193595305055197	город Тула, Пролетарский район, Приупская, 9А	Россия, Тульская область, Тула, улица Приупская, 9а	0101000020E61000009D47C5FF1DD74240A6D590B8C7184B40
4274	1	16	\N	12984	75212	\N	54.194417999999999	город Тула, Пролетарский район, Приупская, 1		0101000020E6100000F3C7B4368DD542407AE063B0E2184B40
4238	1	16	\N	12984	75226	\N	54.194808000000002	город Тула, Привокзальный район, Привокзальная, 25		0101000020E6100000BCC96FD1C9C84240E57FF277EF184B40
4315	1	16	\N	12984	75222	\N	54.173437	город Тула, Центральный район, Перекопская, 2		0101000020E6100000D8101C9771CF42404B75012F33164B40
4248	1	16	\N	12984	75113	\N	54.188751650232597	город Тула, Привокзальный район, Первомайская, 53	Россия, Тульская область, Тула, улица Первомайская, 52	0101000020E610000080EECB99EDCA4240FD86890629184B40
4240	1	16	\N	12984	75072	\N	54.204231747140398	город Тула, Привокзальный район, Павшинский мост, 3	Россия, Тульская область, Тула, Туламаш завод	0101000020E61000003755F7C8E6CA4240F9653046241A4B40
4235	1	16	\N	12984	75184	\N	54.164302999999997	город Тула, Привокзальный район, Оружейная, 46А		0101000020E61000004C8DD0CFD4C942403DD175E107154B40
4337	1	16	\N	12984	75138	\N	54.205648388549498	город Тула, Центральный район, Победа поселок, Октябрьская улица, 6	Россия, Тульская область, Тула, улица Октябрьская, 8	0101000020E61000005F5CAAD216CF4240703E75AC521A4B40
4215	1	16	\N	12984	75138	\N	54.225642999999998	город Тула, Зареченский район, Октябрьская, 199		0101000020E6100000A053909F8DD0424021C9ACDEE11C4B40
4214	1	16	\N	12984	75138	\N	54.227454000000002	город Тула, Зареченский район, Октябрьская, 201А		0101000020E6100000A64412BD8CD0424015AC71361D1D4B40
4208	1	16	\N	12984	75138	\N	54.210718	город Тула, Зареченский район, Октябрьская, 41		0101000020E61000005725917D90CF4240DA56B3CEF81A4B40
4239	1	16	\N	12984	75192	\N	54.194882	город Тула, Привокзальный район, Одоевское шоссе, 25		0101000020E6100000C328081EDFC642401F4AB4E4F1184B40
4243	1	16	\N	12984	75135	\N	54.194057423043198	город Тула, Привокзальный район, Одоевское шоссе, 106	Россия, Тульская область, Тула, поселок Мясново, Одоевское шоссе, 108	0101000020E6100000EF39B01C21C54240AA471ADCD6184B40
4236	1	16	\N	12984	15928	\N	54.195782000000001	город Тула, Привокзальный район, Одоевское шоссе, 50	Россия, Тульская область, Тула, поселок Мясново, Одоевское шоссе, 50	0101000020E610000095BA641C23C742409F9273620F194B40
4316	1	16	\N	12984	75215	\N	54.176113999999998	город Тула, Центральный район, Новомосковская, 5А		0101000020E61000007C80EECB99D14240122F4FE78A164B40
4330	1	16	\N	12984	75116	\N	54.161530661807703	город Тула, Центральный район, Николая Руднева, 62	Россия, Тульская область, Тула, улица Николая Руднева, 62	0101000020E610000000C79E3D97CB424024253D0CAD144B40
4329	1	16	\N	12984	75116	\N	54.162547000000004	город Тула, Центральный район, Николая Руднева, 51	Россия, Тульская область, Тула, улица Николая Руднева, 51	0101000020E610000006DA1D520CCC42400E881057CE144B40
4277	1	16	\N	12984	75170	\N	54.204003999999998	город Тула, Пролетарский район, Немцова, 27		0101000020E6100000780DFAD2DBD54240682096CD1C1A4B40
3806	1	16	\N	12984	75427	\N	54.119971999999997	д.Маслово-Волосевич, Мира, 15		0101000020E6100000A9DC442DCDC34240C537143E5B0F4B40
4292	1	16	\N	12984	75174	\N	54.185541000000001	город Тула, Пролетарский район, Металлургов, 37		0101000020E61000009850C1E105D942409888B7CEBF174B40
4290	1	16	\N	12984	75174	\N	54.179713999999997	город Тула, Пролетарский район, Металлургов, 2		0101000020E610000046425BCEA5DA424011514CDE00174B40
4288	1	16	\N	12984	75174	\N	54.184730000000002	город Тула, Пролетарский район, Металлургов, 22		0101000020E61000007731CD74AFD94240884B8E3BA5174B40
4285	1	16	\N	12984	75174	\N	54.192574	город Тула, Пролетарский район, Металлургов, 70 К2		0101000020E61000008F8CD5E6FFD74240AB07CC43A6184B40
4323	1	16	\N	12984	75216	\N	54.196978000000001	город Тула, Центральный район, Металлистов, 2А		0101000020E610000079944A7842CF424008043A9336194B40
4322	1	16	\N	12984	75178	\N	54.191946999999999	город Тула, Центральный район, Менделеевская, 5		0101000020E61000003C84F1D3B8CF42405CC823B891184B40
4321	1	16	\N	12984	25317	\N	54.191872024162599	город Тула, Центральный район, Менделеевскакя, 5	Россия, Тульская область, Тула, улица Менделеевская, 5	0101000020E610000075E61E12BECF42405182FE428F184B40
4333	1	16	\N	12984	75205	\N	54.105404999999998	город Тула, Центральный район, Западный 2-й поселок, Маяковского улица, 1		0101000020E610000089247A19C5C84240DDEA39E97D0D4B40
94883	1	16	\N	12984	75132	\N	54.104808503772801	г Тула, пос. 2-й Западный ул Маяковского д 39	Россия, Тульская область, Тула, поселок 2-й Западный, улица Маяковского, 35	0101000020E61000005725917D90C94240CAA99D616A0D4B40
4210	1	16	\N	12984	75153	\N	54.213788000000001	город Тула, Зареченский район, Максимовского, 2	Россия, Тульская область, Тула, улица Максимовского, 2	0101000020E61000005EBC1FB75FD042407D23BA675D1B4B40
4219	1	16	\N	12984	75158	\N	54.2148985499581	город Тула, Зареченский район, Максима Горького, 20	Россия, Тульская область, Тула, улица Максима Горького, 20	0101000020E610000008AC1C5A64CD4240B87878CF811B4B40
4218	1	16	\N	12984	75158	\N	54.218468000000001	город Тула, Зареченский район, Максима Горького, 41		0101000020E6100000AE6186C613CD42407C9C69C2F61B4B40
4228	1	16	\N	12984	75156	\N	54.116294000000003	город Тула, Привокзальный район, поселок Косая Гора, улица Максима Горького, 40		0101000020E610000094F59B89E9C442404B5CC7B8E20E4B40
4212	1	16	\N	12984	75157	\N	54.255960999999999	город Тула, Зареченский район, поселок Горелки, улица Макаренко, 3		0101000020E610000045F30016F9CD424096067E54C3204B40
4281	1	16	\N	12984	75194	\N	54.212918999999999	город Тула, Пролетарский район, Майская, 5		0101000020E6100000548CF337A1D8424038D906EE401B4B40
4279	1	16	\N	12984	75194	\N	54.211734	город Тула, Пролетарский район, Майская, 4		0101000020E610000055698B6B7CD84240C3B986191A1B4B40
4291	1	16	\N	12984	26756	\N	54.188459999999999	город Тула, Пролетарский район, М. Мазая, 13		0101000020E61000008EE6C8CA2FD74240554D10751F184B40
4222	1	16	\N	12984	75130	\N	54.209485999999998	город Тула, Зареченский район, Луначарского, 67		0101000020E6100000954737C2A2CC4240247CEF6FD01A4B40
4269	1	16	\N	12984	75168	\N	54.201281000000002	город Тула, Пролетарский район, Ложевая, 124		0101000020E6100000DD3F16A243D2424031276893C3194B40
4221	1	16	\N	12984	75210	\N	54.212091999999998	г. Тула, ул. Литейная, д.25		0101000020E610000017B6662B2FCD424022DFA5D4251B4B40
4220	1	16	\N	12984	75210	\N	54.212091999999998	город Тула, Зареченский район, Литейная, 25		0101000020E610000017B6662B2FCD424022DFA5D4251B4B40
94879	1	16	\N	12984	4792	\N	54.156900999999998	г Тула, пр. Ленина, 125	Россия, Тульская область, Тула, Ленина проспект, 125	0101000020E610000042B115342DCB4240D7DAFB5415144B40
94877	1	16	\N	12984	4792	\N	54.184550999999999	г Тула, пр. Ленина, 46	Россия, Тульская область, Тула, Ленина проспект, 46	0101000020E61000002A029CDEC5CD4240D8B8FE5D9F174B40
4332	1	16	\N	12984	4792	\N	54.15099	город Тула, Центральный район, Ленина проспект, 139А	Россия, Тульская область, Тула, Ленина проспект, 139а	0101000020E61000005B9885764ECB4240F302ECA353134B40
4327	1	16	\N	12984	4792	\N	54.174306999999999	город Тула, Центральный район, Ленина проспект, 89	Россия, Тульская область, Тула, Ленина проспект, 89	0101000020E6100000DF89592F86CC4240603B18B14F164B40
4298	1	16	\N	12984	4792	\N	54.172251000000003	город Тула, Советский район, Ленина проспект, 84	Россия, Тульская область, Тула, Ленина проспект, 84	0101000020E61000005116BEBED6CB424006DA1D520C164B40
4297	1	16	\N	12984	4792	\N	54.167634	город Тула, Советский район, Ленина проспект, 90	Россия, Тульская область, Тула, Ленина проспект, 90	0101000020E6100000B4E386DF4DCB42404DD9E90775154B40
4296	1	16	\N	12984	4792	\N	54.166738000000002	город Тула, Советский район, Ленина проспект, 92	Россия, Тульская область, Тула, Ленина проспект, 92	0101000020E610000034A2B437F8CA42400F80B8AB57154B40
4335	1	16	\N	12984	75225	\N	54.136091	город Тула, Центральный район, Менделеевский поселок, Ленина улица, 11		0101000020E61000002670EB6E9ECA4240D5230D6E6B114B40
4303	1	16	\N	12984	75183	\N	54.191522542252301	город Тула, Советский район, Ленина, 21	Россия, Тульская область, Тула, улица Ленина, 21	0101000020E6100000B16F2711E1CD424045B75ED383184B40
3749	1	16	\N	12984	75185	\N	54.111702000000001	п. Октябрьский, Ленина, 18		0101000020E6100000F6ED2422FCCB4240EB724A404C0E4B40
4287	1	16	\N	12984	75220	\N	54.189518999999997	город Тула, Пролетарский район, Кутузова, 112		0101000020E61000003E05C07806D942403D7C992842184B40
4284	1	16	\N	12984	75220	\N	54.195224000000003	город Тула, Пролетарский район, Кутузова, 94		0101000020E6100000E2033BFE0BD8424079B29B19FD184B40
4313	1	16	\N	12984	75139	\N	54.200527999999998	город Тула, Советский район, Коминтерна, 22		0101000020E6100000512FF83427CD424055F7C8E6AA194B40
4312	1	16	\N	12984	75139	\N	54.199953999999998	город Тула, Советский район, Коминтерна, 21		0101000020E61000006552431B80CD4240295AB91798194B40
4275	1	16	\N	12984	75166	\N	54.206404999999997	город Тула, Пролетарский район, Кирова, 162А		0101000020E6100000DFA815A6EFD342408D5DA27A6B1A4B40
4263	1	16	\N	12984	75166	\N	54.215829999999997	город Тула, Пролетарский район, Кирова, 171		0101000020E610000087F9F202ECD5424072BF4351A01B4B40
4262	1	16	\N	12984	75166	\N	54.210464999999999	город Тула, Пролетарский район, Кирова, 186		0101000020E6100000992CEE3F32D54240F0F96184F01A4B40
4261	1	16	\N	12984	75166	\N	54.206899999999997	город Тула, Пролетарский район, Кирова, 135		0101000020E6100000637B2DE8BDD342406DC5FEB27B1A4B40
85233	1	16	\N	12984	75351	\N	54.111702000000001	пос.Октябрьский	Россия, Тульская область, Тула, поселок Октябрьский, улица Киреевская	0101000020E6100000F6ED2422FCCB4240EB724A404C0E4B40
4317	1	16	\N	12984	75223	\N	54.177394999999997	город Тула, Центральный район, Кауля, 9 корп.4		0101000020E6100000DAACFA5C6DD14240A9BC1DE1B4164B40
4232	1	16	\N	12984	75144	\N	54.181457999999999	город Тула, Привокзальный район, Карбышева, 20А		0101000020E6100000D7868A71FEC442407DCC07043A174B40
4230	1	16	\N	12984	3988	\N	54.156410999999999	город Тула, Привокзальный район, Калужское шоссе, 9	Россия, Тульская область, Тула, Калужское шоссе, 9	0101000020E6100000B77EFACF9AC9424009DE904605144B40
4271	1	16	\N	12984	75147	\N	54.200558079697899	город Тула, Пролетарский район, Калинина, 22 К5	Россия, Тульская область, Тула, улица Калинина, 26	0101000020E6100000CDEA1D6E87D44240C07971E2AB194B40
4270	1	16	\N	12984	75147	\N	54.196409000000003	город Тула, Пролетарский район, Калинина, 7		0101000020E610000080D6FCF84BD34240EED11BEE23194B40
4272	1	16	\N	12984	75213	\N	54.202565999999997	город Тула, Пролетарский район, Замочная, 105		0101000020E6100000EB3A545392D3424009A4C4AEED194B40
4320	1	16	\N	12984	75202	\N	54.186869000000002	город Тула, Центральный район, Жуковского, 27		0101000020E6100000EB707495EECE424070D1C952EB174B40
4273	1	16	\N	12984	75198	\N	54.193981000000001	город Тула, Пролетарский район, Епифанская, 189		0101000020E6100000BE86E0B88CD34240CF85915ED4184B40
4160	1	16	1060	45718	\N	\N	53.868620999999997	с. Малынь, 18		0101000020E6100000FB0626378A92424035CF11F92EEF4A40
4242	1	16	\N	12984	75164	\N	54.197594000000002	город Тула, Привокзальный район, Дружбы, 32		0101000020E610000014048F6FEFC4424063F19BC24A194B40
4310	1	16	\N	12984	75137	\N	54.193449000000001	город Тула, Советский район, Демонстрации, 6		0101000020E610000040FCFCF7E0CD4240D238D4EFC2184B40
4247	1	16	\N	12984	75137	\N	54.191163000000003	город Тула, Привокзальный район, Демонстрации, 134		0101000020E610000090847D3B89CA4240469A780778184B40
4246	1	16	\N	12984	75137	\N	54.192273998418997	г. Тула, ул. Демонстрации, д. 201	Россия, Тульская область, Тула, улица Демонстрации	0101000020E6100000008DD2A57FC9424080EF366F9C184B40
4267	1	16	\N	12984	75193	\N	54.200307000000002	город Тула, Пролетарский район, Демидовская плотина, 37		0101000020E610000010CCD1E3F7D042407714E7A8A3194B40
4305	1	16	\N	12984	75176	\N	54.189830000000001	город Тула, Советский район, Гоголевская, 92		0101000020E6100000A20C553195CC42405CE674594C184B40
4216	1	16	\N	12984	75209	\N	54.216361999999997	город Тула, Зареченский район, Герцена, 50		0101000020E6100000666B7D91D0CE42406F0C01C0B11B4B40
4268	1	16	\N	12984	75124	\N	54.205067999999997	город Тула, Пролетарский район, Гармонная, 37		0101000020E6100000BD344580D3D1424062BA10AB3F1A4B40
4207	1	16	\N	12984	75204	\N	54.208706999999997	город Тула, Зареченский район, Галкина, 14		0101000020E61000009CA38E8EABCF42401FB935E9B61A4B40
4229	1	16	\N	12984	26877	\N	54.120134042142801	город Тула, Привокзальный район, поселок Косая Гора, улица Гагарина, 1		0101000020E6100000B1C1C2499AC542409F91088D600F4B40
4224	1	16	\N	12984	26877	\N	54.120320999999997	город Тула, Привокзальный район, поселок Косая Гора, улица Гагарина, 3		0101000020E6100000E02D90A0F8C54240D102B4AD660F4B40
94880	1	16	\N	12984	75128	\N	54.154696999999999	г Тула, ул. Волоховская, 7		0101000020E61000006AF7AB00DFCB424008E57D1CCD134B40
4331	1	16	\N	12984	75128	\N	54.154696999999999	город Тула, Центральный район, Волоховская, 7		0101000020E61000006AF7AB00DFCB424008E57D1CCD134B40
4283	1	16	\N	12984	75172	\N	54.2072	город Тула, Пролетарский район, Вильямса, 26А		0101000020E6100000475A2A6F47D8424098DD9387851A4B40
4278	1	16	\N	12984	75172	\N	54.205841999999997	город Тула, Пролетарский район, Вильямса, 10		0101000020E6100000191D90847DD742405512D907591A4B40
4309	1	16	\N	12984	75200	\N	54.194986999999998	город Тула, Советский район, Вересаева, 10		0101000020E610000053978C6324CB424094128255F5184B40
4304	1	16	\N	12984	75200	\N	54.191983999999998	город Тула, Советский район, Вересаева, 12		0101000020E6100000C5C9FD0E45CB424079AD84EE92184B40
4301	1	16	\N	12984	75214	\N	54.184998	город Тула, Советский район, Бундурина, 45		0101000020E61000009A3E3BE0BACC4240A7E9B303AE174B40
4295	1	16	\N	12984	75125	\N	54.171112999999998	город Тула, Советский район, Болдина, 100		0101000020E6100000D369DD06B5C94240D175E107E7154B40
4293	1	16	\N	12984	75125	\N	54.181852999999997	город Тула, Советский район, Болдина, 47		0101000020E610000065FB90B75CC94240F9D687F546174B40
4211	1	16	\N	12984	75117	\N	54.288915000000003	город Тула, Зареченский район, поселок Хомяково, улица Березовская, 2		0101000020E61000006E162F1686CE42407429AE2AFB244B40
4266	1	16	\N	12984	75217	\N	54.209902	город Тула, Пролетарский район, Баженова, 25		0101000020E6100000F69A1E1494D64240B8AE9811DE1A4B40
4244	1	16	\N	12984	15970	\N	54.20402	город Тула, Привокзальный район, 6-й Полюсный проезд, 16	Россия, Тульская область, Тула, поселок Мясново, 6-й Полюсный проезд, 16	0101000020E6100000FB78E8BB5BC542406EDDCD531D1A4B40
4213	1	16	\N	12984	25635	\N	54.239365962183598	город Тула, Зареченский район, поселок Октябрьский, улица 18-й проезд, 2	Россия, Тульская область, Тула, 18-й проезд	0101000020E6100000096F0F4240D042401DE38A8BA31E4B40
4280	1	16	\N	12984	4627	\N	54.194318000000003	город Тула, Пролетарский район, Металлургов 1-й проезд, 7		0101000020E61000006FB88FDC9AD6424017838769DF184B40
3764	1	16	\N	12984	75426	\N	54.128362000000003	п. Круглянский, Школьная, 28		0101000020E6100000786000E143CB42404B06802A6E104B40
4115	1	16	\N	12984	75292	\N	54.140796000000002	Чернский район, с. Новое Покровское, ул. Центральная, д.8		0101000020E6100000DB8827BB99CD42402DB4739A05124B40
3999	1	16	\N	60507	75103	\N	54.115645000000001	г. Суворов,   ул. Тульская, 21		0101000020E610000067B62BF4C13E424014799274CD0E4B40
3784	1	16	\N	51300	26587	\N	54.250948281596898	п. Серебряные Ключи, Парковая, 55	Россия, Тульская область	0101000020E610000096CCB1BCABF64240917F66101F204B40
3809	1	16	\N	20502	25337	\N	54.245545	Тульская обл, Ленинский, поселок Плеханово, Ленина 45	Россия, Тульская область, поселок Плеханово	0101000020E61000000CE71A6668C842402159C0046E1F4B40
3812	1	16	\N	20502	26330	\N	54.245545	Тульская обл, Ленинский, поселок Плеханово, Заводская 19	Россия, Тульская область, поселок Плеханово	0101000020E61000000CE71A6668C842402159C0046E1F4B40
3810	1	16	\N	20502	26330	\N	54.245545	Тульская обл, Ленинский, поселок Плеханово, Заводская 16	Россия, Тульская область, поселок Плеханово	0101000020E61000000CE71A6668C842402159C0046E1F4B40
3966	1	16	\N	60504	75099	\N	53.703916999999997	г. Плавск, Победы, 22		0101000020E6100000A089B0E1E9A54240990CC7F319DA4A40
3740	1	16	\N	60498	75086	\N	53.932389000000001	г. Киреевск, Чехова, 6а		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3687	1	16	\N	60496	75081	\N	53.965322	город Кимовск, Островского, 8		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3633	1	16	\N	60494	75076	\N	53.149166999999998	г. Ефремов, ул. Мира, д.2_а		0101000020E6100000F1113125920A43403B527DE717934A40
3625	1	16	\N	60494	75079	\N	53.150408417108501	г. Ефремов, ул. Дачная, д.4	Россия, Тульская область, Ефремовский район, Ефремов	0101000020E6100000CEC64ACCB30C43404487C09140934A40
3598	1	16	\N	14206	25365	\N	53.966858000000002	г. Донской, мкр. Комсомольский, ул. Школьная, 11		0101000020E6100000498270051428434020F0C000C2FB4A40
3597	1	16	\N	14206	25365	\N	53.966858000000002	г. Донской, мкр. Подлесный, ул. Школьная, 4	Россия, Тульская область, Донской	0101000020E6100000498270051428434020F0C000C2FB4A40
3589	1	16	\N	14206	25365	\N	53.966858000000002	г. Донской, мкр. Северо-Задонск, ул. Школьная, 18		0101000020E6100000498270051428434020F0C000C2FB4A40
3590	1	16	\N	14206	25646	\N	53.966858000000002	г. Донской, мкр. Северо-Задонск, ул. Тургенева, 1		0101000020E6100000498270051428434020F0C000C2FB4A40
3586	1	16	\N	14206	25513	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Стахановская, 40		0101000020E6100000498270051428434020F0C000C2FB4A40
3584	1	16	\N	14206	25880	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Советская, 16		0101000020E6100000498270051428434020F0C000C2FB4A40
3599	1	16	\N	14206	25330	\N	53.922226221847701	г. Донской, мкр. Шахтерский, ул. Свердлова, 2а		0101000020E6100000DA56B3CEF8264340ADC266800BF64A40
3577	1	16	\N	14206	26112	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Первомайская, 1		0101000020E6100000498270051428434020F0C000C2FB4A40
3583	1	16	\N	14206	25921	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Октябрьская, 18		0101000020E6100000498270051428434020F0C000C2FB4A40
3580	1	16	\N	14206	25921	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Октябрьская, 55а		0101000020E6100000498270051428434020F0C000C2FB4A40
3579	1	16	\N	14206	25921	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Октябрьская, 46		0101000020E6100000498270051428434020F0C000C2FB4A40
3576	1	16	\N	14206	25921	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Октябрьская, 91		0101000020E6100000498270051428434020F0C000C2FB4A40
3575	1	16	\N	14206	25921	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Октябрьская, 105		0101000020E6100000498270051428434020F0C000C2FB4A40
3574	1	16	\N	14206	25921	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Октябрьская, 96		0101000020E6100000498270051428434020F0C000C2FB4A40
3578	1	16	\N	14206	25536	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Новая, 50		0101000020E6100000498270051428434020F0C000C2FB4A40
3596	1	16	\N	14206	26091	\N	53.966858000000002	г. Донской, мкр. Задонье, ул. Ленина, 8а		0101000020E6100000498270051428434020F0C000C2FB4A40
3595	1	16	\N	14206	26091	\N	53.966858000000002	г. Донской, мкр. Северо-Задонск, ул. Ленина, 36		0101000020E6100000498270051428434020F0C000C2FB4A40
3592	1	16	\N	14206	26091	\N	53.966858000000002	г. Донской, мкр. Северо-Задонск, ул. Ленина, 19		0101000020E6100000498270051428434020F0C000C2FB4A40
3591	1	16	\N	14206	26091	\N	53.966858000000002	г. Донской, мкр. Северо-Задонск, ул. Ленина, 7		0101000020E6100000498270051428434020F0C000C2FB4A40
3601	1	16	\N	14206	26815	\N	53.966858000000002	г. Донской, мкр. Новоугольный, ул. Кирпичная, 7а		0101000020E6100000498270051428434020F0C000C2FB4A40
3604	1	16	\N	14206	25958	\N	53.966858000000002	г. Донской, мкр. Новоугольный, ул. Кирова, 12		0101000020E6100000498270051428434020F0C000C2FB4A40
3603	1	16	\N	14206	25331	\N	53.966858000000002	г. Донской, мкр. Новоугольный, ул. Индустриальная, 1		0101000020E6100000498270051428434020F0C000C2FB4A40
3602	1	16	\N	14206	25331	\N	53.966858000000002	г. Донской, мкр. Новоугольный, ул. Индустриальная, 7		0101000020E6100000498270051428434020F0C000C2FB4A40
3581	1	16	\N	14206	25838	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Заводская, 22		0101000020E6100000498270051428434020F0C000C2FB4A40
3593	1	16	\N	14206	26774	\N	53.966858000000002	г. Донской, мкр. Северо-Задонск, ул. Горького, 9		0101000020E6100000498270051428434020F0C000C2FB4A40
3594	1	16	\N	14206	26573	\N	53.966858000000002	г. Донской, мкр. Северо-Задонск, ул. Вахрушева, 34		0101000020E6100000498270051428434020F0C000C2FB4A40
3573	1	16	\N	14206	26569	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. 328 Стрелковой дивизии, 10		0101000020E6100000498270051428434020F0C000C2FB4A40
3588	1	16	\N	14206	25882	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. 30 лет Победы, 4		0101000020E6100000498270051428434020F0C000C2FB4A40
3600	1	16	\N	14206	26895	\N	53.966858000000002	г. Донской, мкр. Руднев, ул. 10 Армии, 1а		0101000020E6100000498270051428434020F0C000C2FB4A40
3488	1	16	\N	60492	75075	\N	53.773052	г.Богородицк, Шахтная, 5		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3487	1	16	\N	60492	75100	\N	53.773052	г.Богородицк, Западный МКР, 22		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3582	1	16	7109	51186	25621	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Заводская, 11а		0101000020E6100000498270051428434020F0C000C2FB4A40
3585	1	16	7110	51189	25676	\N	53.966858000000002	г. Донской, мкр. Центральный, ул. Советская, 1		0101000020E6100000498270051428434020F0C000C2FB4A40
4199	1	16	1206	12660	26862	\N	54.478147999999997	г.Ясногорск, ул.Южная, д.8		0101000020E6100000350A4966F5D84240EB5223F4333D4B40
4201	1	16	1206	12660	25350	\N	54.488748750998298	г.Ясногорск, ул.Л.Толстого, д.1	Россия, Тульская область, Ясногорский район, Ясногорск	0101000020E6100000045ABA826DD84240F279C5538F3E4B40
4202	1	16	1206	12660	26656	\N	54.478147999999997	г.Ясногорск, ул.Комсомольская, д.5		0101000020E6100000350A4966F5D84240EB5223F4333D4B40
4205	1	16	1206	12660	26340	\N	54.478147999999997	г.Ясногорск, ул.Карбышева, д.1		0101000020E6100000350A4966F5D84240EB5223F4333D4B40
4198	1	16	1206	12660	25754	\N	54.478147999999997	г.Ясногорск, ул.Горького, д.3		0101000020E6100000350A4966F5D84240EB5223F4333D4B40
4203	1	16	1206	12660	25351	\N	54.478147999999997	г.Ясногорск, ул.Гайдара, д.8	Россия, Тульская область, Ясногорский район, Ясногорск	0101000020E6100000350A4966F5D84240EB5223F4333D4B40
84611	1	16	1206	60543	\N	\N	54.476031158835198	с.Шилово	Россия, Тульская область, Ясногорский район, поселок Шилово	0101000020E610000094F59B89E9D64240EB707495EE3C4B40
4196	1	16	1206	12550	26649	\N	54.543114000000003	с.Хотушь, ул.Школьная, д.31		0101000020E6100000605793A7ACDE4240F8FF71C284454B40
4184	1	16	1206	11946	75408	\N	54.368637	Ясногорский район, д.Федяшево, ул.Учительская, д.6		0101000020E6100000DA54DD239BD942403B8C497F2F2F4B40
4180	1	16	1206	11760	26729	\N	54.499679	д.Тормино, ул.Садовая, д.14		0101000020E6100000B01BB62DCAD24240BEBF417BF53F4B40
4179	1	16	1206	11760	26729	\N	54.499679	Ясногорский район, д.Тормино, ул.Садовая, д.14		0101000020E6100000B01BB62DCAD24240BEBF417BF53F4B40
4195	1	16	1206	46488	26142	\N	54.539892000000002	с.Теляково, ул.Мира, д.5-Б		0101000020E6100000020CCB9F6FF342409FAF592E1B454B40
3660	1	16	1206	18517	75272	\N	54.675719999999998	с.Страхово, ул.Экспериментальная, 14		0101000020E6100000D388997D1EE1424066A032FE7D564B40
4194	1	16	1206	12453	25903	\N	54.587406000000001	п.Спицинский, ул.Центральная, д.4		0101000020E610000050560C5707024340B2BCAB1E304B4B40
4193	1	16	1206	12436	25344	\N	54.523200000000003	п.Санталовский, ул.Зеленая, д.5		0101000020E610000089B5F81400DD424034A2B437F8424B40
4178	1	16	1206	46530	75471	\N	54.355606999999999	п.Ново-Ревякинский, ул.Центральная, д.12	Россия, Тульская область, Ясногорский район, поселок Ревякино	0101000020E6100000E90DF7915BD14240459DB987842D4B40
4197	1	16	1206	46530	26147	\N	54.366985	п.Ревякино, ул.Советская, д.12		0101000020E6100000A81C93C5FDD34240B08F4E5DF92E4B40
3959	1	16	1206	46368	\N	\N	54.453102999999999	деревня Мызовка, 1а		0101000020E6100000D3A3A99ECCE34240185C7347FF394B40
4084	1	16	606	46782	\N	\N	53.858260999999999	д. Волково, д. 59а		0101000020E6100000DCDAC2F3523743405437177FDBED4A40
3974	1	16	1206	46657	75393	\N	54.628919000000003	с.Михайловское, Новая, 4	Россия, Тульская область, Ясногорский район, поселок Михайловское	0101000020E6100000BF81C98D22FD4240A16AF46A80504B40
3509	1	16	1206	40440	\N	\N	54.469698000000001	д.Каменка, 33		0101000020E610000044F8174163D04240917F66101F3C4B40
4187	1	16	1206	33153	25340	\N	54.810237000000001	п.Есуковский, ул.Центральная, д.19	Россия, Тульская область, Ясногорский район, поселок Есуковский	0101000020E610000099F4F75278E842402C8194D8B5674B40
3951	1	16	1206	46170	75452	\N	54.459651000000001	деревня Денисово, Центральная, 9		0101000020E6100000A6D3BA0D6AED42406F490ED8D53A4B40
4183	1	16	1206	46170	75335	\N	54.459651000000001	с.Денисово, ул.Советская, д.72		0101000020E6100000A6D3BA0D6AED42406F490ED8D53A4B40
4186	1	16	1206	46295	25336	\N	54.821634000000003	д.Григорьевское, ул.Центральная, д.3		0101000020E6100000CEC133A149FC42400EA48B4D2B694B40
4191	1	16	1206	12266	25342	\N	54.494387000000003	д.Воловниково, ул.Мира, д.20		0101000020E610000038BC202235E14240A648BE12483F4B40
95002	1	16	1206	27468	\N	\N	54.646484000000001	Ясногорский район, с.Верхнее Красино, д.63		0101000020E610000073F56393FCEC424092B1DAFCBF524B40
4182	1	16	1206	11863	25358	\N	54.427419999999998	д.Бураково, ул.Молодежная, д.18		0101000020E61000001C9947FE60F4424002D4D4B2B5364B40
4181	1	16	1206	11836	75262	\N	54.454276	п.Боровковский, ул.Школьная, д.12	Россия, Тульская область, Ясногорский район, поселок Боровковский	0101000020E610000056D3F544D7DD4240C9AD49B7253A4B40
4185	1	16	1206	12036	26615	\N	54.772514999999999	с.Богословское, ул.Студенческая, д.3		0101000020E61000005C7347FFCBFF4240B05582C5E1624B40
3666	1	16	1206	47016	67861	\N	54.456949999999999	с.Архангельское ул.Тихомирова 28		0101000020E6100000B5C189E8D7CE42401FF46C567D3A4B40
3879	1	16	1060	49181	26553	\N	54.072535000000002	д. Ясная Поляна, ул. Школьная, 142а		0101000020E61000007EC85BAE7EC442405E68AED348094B40
30	1	16	1060	40371	\N	\N	54.025329999999997	деревня Ясенки	Россия, Тульская область, Щекинский район, поселок Ясенки	0101000020E6100000003CA24275C14240C8CD70033E034B40
3880	1	16	1060	49185	\N	\N	54.051333999999997	п. Юбилейный, 6		0101000020E61000007958A835CDBD42402096CD1C92064B40
4129	1	16	1060	9304	26465	\N	54.003118999999998	г. Щекино, ул. Юбилейная, 1		0101000020E6100000D3F4D901D7C14240847F113466004B40
4128	1	16	1060	9304	26465	\N	54.003118999999998	г. Щекино, ул. Юбилейная, 2		0101000020E6100000D3F4D901D7C14240847F113466004B40
4148	1	16	1060	9304	25449	\N	54.003118999999998	г. Щекино, ул. Стволовая, 3		0101000020E6100000D3F4D901D7C14240847F113466004B40
4135	1	16	1060	9304	25792	\N	54.003118999999998	г. Щекино, ул. Спортивная, 20		0101000020E6100000D3F4D901D7C14240847F113466004B40
4139	1	16	1060	9304	26536	\N	54.003118999999998	г. Щекино, ул. Свободы, 10		0101000020E6100000D3F4D901D7C14240847F113466004B40
4142	1	16	1060	9304	26595	\N	54.003118999999998	г. Щекино, ул. Пролетарская, 10		0101000020E6100000D3F4D901D7C14240847F113466004B40
4149	1	16	1060	9304	25767	\N	54.003118999999998	г. Щекино, ул. Пионерская, 39		0101000020E6100000D3F4D901D7C14240847F113466004B40
4147	1	16	1060	9304	25767	\N	54.003118999999998	г. Щекино, ул. Пионерская, 5		0101000020E6100000D3F4D901D7C14240847F113466004B40
4131	1	16	1060	9304	25461	\N	54.003118999999998	г. Щекино, ул. Мира, 18		0101000020E6100000D3F4D901D7C14240847F113466004B40
4130	1	16	1060	9304	25461	\N	54.003118999999998	г. Щекино, ул. Мира, 14		0101000020E6100000D3F4D901D7C14240847F113466004B40
4134	1	16	1060	9304	25320	\N	54.003118999999998	г. Щекино, ул. Лукашина, 2в		0101000020E6100000D3F4D901D7C14240847F113466004B40
4146	1	16	1060	9304	25542	\N	54.003118999999998	г. Щекино, ул. Лизы Шамшиковой, 18		0101000020E6100000D3F4D901D7C14240847F113466004B40
4145	1	16	1060	9304	25542	\N	54.003118999999998	г. Щекино, ул. Лизы Шамшиковой, 18а		0101000020E6100000D3F4D901D7C14240847F113466004B40
4144	1	16	1060	9304	26097	\N	54.003118999999998	г. Щекино, ул. Ленина, 36		0101000020E6100000D3F4D901D7C14240847F113466004B40
4143	1	16	1060	9304	26097	\N	54.003118999999998	г. Щекино, ул. Ленина, 45		0101000020E6100000D3F4D901D7C14240847F113466004B40
4141	1	16	1060	9304	26097	\N	54.003118999999998	г. Щекино, ул. Ленина, 58		0101000020E6100000D3F4D901D7C14240847F113466004B40
4136	1	16	1060	9304	26051	\N	54.003118999999998	г. Щекино, ул. Комсомольская, 32а		0101000020E6100000D3F4D901D7C14240847F113466004B40
4133	1	16	1060	9304	25348	\N	54.003118999999998	г. Щекино, ул. Коммунальная, 7		0101000020E6100000D3F4D901D7C14240847F113466004B40
4137	1	16	1060	9304	26799	\N	54.003118999999998	г. Щекино, ул. Болдина, 121		0101000020E6100000D3F4D901D7C14240847F113466004B40
3884	1	16	1060	60559	75287	\N	53.979687818874403	п. Шахтерский, ул. Центральная, 20	Россия, Тульская область, Щекинский район, поселок Шахтерский	0101000020E61000006B2920ED7FC042404F24986A66FD4A40
791	1	16	1060	40974	\N	\N	53.854480000000002	поселок Центральный	Россия, Тульская область, Щекинский район, поселок Центральный	0101000020E610000042EA76F695C14240058BC3995FED4A40
4010	1	16	1060	40974	75241	\N	53.855038225349098	пос. Центральный, Ленина, 37	Россия, Тульская область, Щекинский район, поселок Центральный	0101000020E6100000682096CD1CC242402B6B9BE271ED4A40
4170	1	16	1060	45930	\N	\N	53.743347999999997	с. Царево, 42а		0101000020E6100000F46E2C280CCA424004C6FA0626DF4A40
3787	1	16	1060	60587	\N	\N	53.756416999999999	д. Стубленка	Россия, Тульская область, Щекинский район, поселок Стублевка	0101000020E61000006A16687748B54240B891B245D2E04A40
4173	1	16	1060	45996	26928	\N	53.971943000000003	п. Социалистический, ул. Трудовая, 2		0101000020E610000079E8BB5B59CE4240BF49D3A068FC4A40
4154	1	16	1060	45596	26286	\N	53.940764000000001	г. Советск, ул. Энергетиков, 17а		0101000020E6100000E08096AE60D1424088A06AF46AF84A40
4153	1	16	1060	45596	26286	\N	53.940764000000001	г. Советск, ул. Энергетиков, 60		0101000020E6100000E08096AE60D1424088A06AF46AF84A40
4155	1	16	1060	45596	26470	\N	53.940764000000001	г. Советск, ул. Школьная, 2		0101000020E6100000E08096AE60D1424088A06AF46AF84A40
3883	1	16	1060	49235	26317	\N	53.991548999999999	с. Селиваново, ул. Советская, 15		0101000020E6100000D5CE30B5A5A04240D5B0DF13EBFE4A40
4162	1	16	1060	10933	26376	\N	53.926430000000003	с. Пришня, ул. А.Н.Козаченко, 2а		0101000020E610000098A3C7EF6DA8424043041C4295F64A40
4169	1	16	1060	11276	\N	\N	53.774737999999999	с. Пирогово-1, 25а		0101000020E6100000FE614B8FA6D24240F67B629D2AE34A40
4157	1	16	1060	10645	75233	\N	53.932707000000001	р.п. Огаревка, ул. Шахтерская, 108		0101000020E61000009FABADD85FC8424009E066F162F74A40
4156	1	16	1060	10645	67900	\N	53.932707000000001	р.п. Огаревка, ул. Клубная, 14		0101000020E61000009FABADD85FC8424009E066F162F74A40
4158	1	16	1060	10766	26804	\N	54.049996	Щекинский район, с.Никольское, ул.Речная, д.20		0101000020E6100000ED2B0FD2539642402577D84466064B40
4176	1	16	1060	11580	\N	\N	54.046095000000001	с. Мясоедово, 22а		0101000020E610000032755776C1CA42402BC1E270E6054B40
3887	1	16	1060	29360	\N	\N	53.979235000000003	Щекинский район, п.Майский	Россия, Тульская область, Щекинский район, поселок Майский	0101000020E6100000429770E82DC642409E0C8E9257FD4A40
3716	1	16	1060	46046	\N	\N	53.778309	д.Львово, 88	Россия, Тульская область, Щекинский район, поселок Львово	0101000020E6100000B1E1E995B2C242405B971AA19FE34A40
4166	1	16	1060	45839	75414	\N	53.812316000000003	д. Лукино, ул. Куприянова, 21		0101000020E6100000B5A50EF27AB242403F027FF8F9E74A40
4174	1	16	1060	11488	26258	\N	53.985027000000002	п. Ломинцевский, ул. Центральная, 6		0101000020E61000001CD2A8C0C9D44240A8565F5D15FE4A40
4175	1	16	1060	60575	75328	\N	54.012449270945098	с. Ломинцево, ул. Центральная, 138	Россия, Тульская область, Щекинский район, поселок Ломинцево	0101000020E6100000417FA1478CD6424017EFC7ED97014B40
4168	1	16	1060	45865	26099	\N	53.724775000000001	с. Липово, ул. Школьная, 18		0101000020E610000039268BFB8FC04240ADFA5C6DC5DC4A40
4165	1	16	1060	11086	\N	\N	53.843049000000001	с. Лапотково, 12б		0101000020E61000000934D8D479B6424077F69507E9EB4A40
4164	1	16	1060	45807	26093	\N	53.851336000000003	п. Лазарево, ул. Тульская, 16	Россия, Тульская область, Щекинский район, поселок Лазарево	0101000020E6100000D00CE2033BBE424028F4FA93F8EC4A40
4161	1	16	1060	10917	25884	\N	53.939900000000002	с. Крапивна, ул. Коммунаров, 31а		0101000020E6100000102043C70E94424055C1A8A44EF84A40
4189	1	16	1060	12235	25932	\N	54.035007999999998	Тульская обл, Ясногорский, с.Климовское, ул.Центральная, д.31		0101000020E6100000F2ED5D83BE944240978C63247B044B40
4163	1	16	1060	11008	75105	\N	53.904952000000002	Щекинский район, с.Карамышево, ул.Школьная, д.1А		0101000020E610000076C6F7C5A5BA424093399677D5F34A40
4081	1	16	1060	48715	\N	\N	53.807690000000001	село Ивановка, д.72	Россия, Тульская область, Щекинский район, поселок Ивановка	0101000020E6100000B98B3045B9D4424033A7CB6262E74A40
4167	1	16	1060	11175	25783	\N	53.750877000000003	д. Грецовка, ул. Молодежная, 1б		0101000020E61000000055DCB8C5B24240C828CFBC1CE04A40
3886	1	16	1060	49282	26907	\N	53.929727999999997	д. Горячкино, ул. Центральная, 17		0101000020E6100000A439B2F2CBCC42407616BD5301F74A40
3881	1	16	1060	29098	25704	\N	54.040354000000001	п. Головеньковский, ул. Шахтерская, 30		0101000020E61000000801F9122AB64240A321E3512A054B40
3882	1	16	1060	29136	26382	\N	54.012348000000003	д. Большая Тросна, ул. Агрохимиков, 33		0101000020E6100000BE4D7FF623BD4240E415889E94014B40
4177	1	16	1060	46072	75253	\N	53.853492000000003	с.Архангельское, ул.Бритикова, д.4		0101000020E610000051F69672BE8A4240E6B2D1393FED4A40
4159	1	16	1060	10810	25775	\N	53.939131000000003	п. Алимкина, ул. Комсомольская, 2		0101000020E6100000C573B680D08E424074D4D17135F84A40
4105	1	16	943	7658	26262	\N	53.453918000000002	Чернский район, п. Чернь, ул. Производственная, д.1		0101000020E6100000488C9E5BE87242406A882AFC19BA4A40
4094	1	16	943	7658	25993	\N	53.453918000000002	поселок Чернь, Космонавтов, 29, ЧСШ №1		0101000020E6100000488C9E5BE87242406A882AFC19BA4A40
4093	1	16	943	7658	25988	\N	53.453918000000002	поселок Чернь, К.Маркса, 22,   РДК		0101000020E6100000488C9E5BE87242406A882AFC19BA4A40
4122	1	16	943	9046	26512	\N	53.378960999999997	Тульская обл, Чернский, деревня Тургенево, ул.Школьная,9		0101000020E6100000B83D4162BBA54240CFBA46CB81B04A40
4118	1	16	943	51217	75434	\N	53.433897000000002	Чернский район, с. Троицкое Бачурино, ул. Центральная, д.1	Россия, Тульская область, Чернский район, поселок Троицкое-Бочурино	0101000020E6100000AD69DE718A3C4240906AD8EF89B74A40
3497	1	16	943	8322	\N	\N	53.593966000000002	пос.Степной	Россия, Тульская область, Чернский район, поселок Степной	0101000020E61000001B683EE76E834240CD77F01307CC4A40
4107	1	16	943	8322	26055	\N	53.593966000000002	Чернский район, п. Степной, ул. Школьная, д. 17		0101000020E61000001B683EE76E834240CD77F01307CC4A40
4095	1	16	943	51263	26401	\N	53.564359319181399	Чернский район, поселок Станция Скуратово, ул.Перронная,д.8	Россия, Тульская область, Чернский район, поселок Скуратово	0101000020E610000089B2B794F3834240051A6CEA3CC84A40
4124	1	16	943	9137	25492	\N	53.441406999999998	Тульская обл, Чернский, поселок Спартак, ул.Центральная,12		0101000020E61000004A07EBFF1C924240DC9C4A0680B84A40
4096	1	16	943	7806	26001	\N	53.442426622156397	Чернский район, п.Скуратовский, ул.А.Скуратова,д. 27	Россия, Тульская область, Чернский район, поселок Скуратовский	0101000020E6100000CA367007EA6E424007EFAB72A1B84A40
4110	1	16	943	8496	75348	\N	53.550317999999997	Чернский район, д. Синегубово 1, ул.Центральная, д.14		0101000020E610000013640454386242403733FAD170C64A40
3843	1	16	943	48579	\N	\N	53.524850999999998	"село Слободка, клуб санатория ""Слободка"""	Россия, Тульская область, Чернский район, поселок Сальница-Слободка	0101000020E61000007AFF1F274C4A4240EE224C512EC34A40
4123	1	16	943	9073	25949	\N	53.530450000000002	Тульская обл, Чернский, деревня Поповка-1, ул.Школьная,4		0101000020E610000038656EBE118B4240E4141DC9E5C34A40
4121	1	16	943	8981	75352	\N	53.476481	Тульская обл, Чернский, село Полтево,  ул.Молодежная,20		0101000020E61000002D0ABB287A4E42402B155454FDBC4A40
4127	1	16	943	9238	26017	\N	53.501730999999999	Тульская обл, Чернский, поселок Подгорный, ул.Центральная,12		0101000020E6100000E2ADF36F97854240D731AEB838C04A40
3964	1	16	943	46463	75375	\N	53.344757999999999	село Петровское, Школьная, 171		0101000020E6100000AF44A0FA078742406684B70721AC4A40
4100	1	16	943	7981	26416	\N	53.310603	Чернский район, с.Николо-Вяземское, ул. В.С.Усова,д.11		0101000020E6100000A67EDE54A46842400E85CFD6C1A74A40
4106	1	16	943	8309	25726	\N	53.557422000000003	Чернский район, с. Малое Скуратово, ул. Совхозная, д. 1 «а»		0101000020E610000069FD2D01F87F42401409A69A59C74A40
85631	1	16	943	46802	\N	\N	53.441032	с.Лобаново	Россия, Тульская область, Чернский район, поселок Лобаново	0101000020E6100000C39CA04D0E534240A73E90BC73B84A40
4112	1	16	943	8593	26492	\N	53.369813000000001	Чернский район, п. Липицы, ул. Школьная, д.14		0101000020E610000014CFD90242A142405D514A0856AF4A40
3822	1	16	943	25819	\N	\N	53.401364999999998	Тульская обл, Ленинский, поселок Петелино, Парковая 4	Россия, Тульская область, Чернский район, поселок Ленинский	0101000020E6100000371C96067E8442402861A6ED5FB34A40
4114	1	16	943	8689	26495	\N	53.330381000000003	Чернский район, д. Молчаново Левое, ул.Свободная, д. 6 «а»		0101000020E6100000BF0B5BB395B54240221CB3EC49AA4A40
4109	1	16	943	8429	75411	\N	53.502485999999998	Чернский район, д. Кресты, ул.Центральная, д.52		0101000020E61000003C4F3C670B7042405359147651C04A40
4116	1	16	943	8763	75406	\N	53.333306	Чернский район, п.Красный Путь, ул. Центральная, д.4		0101000020E61000009D499BAA7BAA4240C1C760C5A9AA4A40
3712	1	16	943	45968	\N	\N	53.437314000000001	с.Краснополье, 187		0101000020E6100000A054FB743C9842409E0AB8E7F9B74A40
4104	1	16	943	60564	75298	\N	53.394407000000001	Чернский район, д. Кожинка, ул.Луговая, д. 1 «а»		0101000020E6100000B01F6283857F42402028B7ED7BB24A40
4119	1	16	943	8874	26503	\N	53.433844000000001	Чернский район, п. Жизнь, ул.Советская, д. 5 «а»		0101000020E6100000C0B33D7AC34B42406DC83F3388B74A40
4103	1	16	943	8123	25293	\N	53.328488	Чернский район, с.Ержино, ул. Центральная, д.7		0101000020E6100000EACC3D247C734240719010E50BAA4A40
4120	1	16	943	8954	26406	\N	53.512740999999998	Чернский район, д. Дьяково, ул. Центральная, д. 4		0101000020E6100000DE74CB0EF1514240BF28417FA1C14A40
4099	1	16	943	7935	26917	\N	53.395066999999997	Чернский район, д.Долматово,ул.Юбилейная, д.2		0101000020E6100000CF2C0950536142404A5D328E91B24A40
4098	1	16	943	7896	25308	\N	53.430855999999999	Чернский район, п.Воропаевский,ул.Грушелевского, д.17		0101000020E61000002FC03E3A7565424087A4164A26B74A40
4125	1	16	943	9153	26519	\N	53.469738999999997	Тульская обл, Чернский, село Вельеникольское, ул.Победы,48		0101000020E6100000A437DC476E794240EF53556820BC4A40
4097	1	16	943	7808	26613	\N	53.381588000000001	Чернский район, с.Бредихино-1, ул.Садовая,д.12		0101000020E6100000A680B4FF01704240E54526E0D7B04A40
4101	1	16	943	8000	26913	\N	53.328181000000001	Чернский район, с.Архангельское, ул. Л.Н.Толстого, д.21		0101000020E6100000588E90813C8F42409415C3D501AA4A40
3870	1	16	606	28594	\N	\N	54.034151000000001	Узловский район, с. Шаховское	Россия, Тульская область, Узловский район, поселок Шаховское	0101000020E6100000494DBB98660A434017105A0F5F044B40
3800	1	16	606	28594	75445	\N	54.034151000000001	д.Шаховское, ул.Школьная, д.5		0101000020E6100000494DBB98660A434017105A0F5F044B40
4078	1	16	606	60585	\N	\N	53.979379027023697	д. Хитрово, д.53	Россия, Тульская область, Узловский район, поселок Хитрово	0101000020E6100000CBF78C4468104340D1B1834A5CFD4A40
4064	1	16	606	5644	25682	\N	53.972175999999997	г. Узловая, кв-л им. 50-летия Октября, 7а		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
94876	1	16	606	5644	26172	\N	53.972175999999997	г.Узловая, ул. Чехова, д. 13		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
3873	1	16	606	5644	26201	\N	53.972175999999997	г. Узловая, кв-л 5-я Пятилетка, ул. Центральная, 6		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
3872	1	16	606	5644	25363	\N	53.972175999999997	г. Узловая, Тульская, 13		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4061	1	16	606	5644	26891	\N	53.972175999999997	г. Узловая, Трудовые резервы, 7		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4059	1	16	606	5644	26891	\N	53.972175999999997	г. Узловая, Трудовые резервы, 13		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
3869	1	16	606	5644	25361	\N	53.972175999999997	г. Узловая, Смоленского, 9а		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
3868	1	16	606	5644	25361	\N	53.972175999999997	г. Узловая, Смоленского, 3		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4058	1	16	606	5644	26867	\N	53.972175999999997	г. Узловая, Октябрьская, 21		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4066	1	16	606	5644	25357	\N	53.972175999999997	г. Узловая, Мира, 5а		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
3871	1	16	606	5644	25357	\N	53.972175999999997	г. Узловая, Мира, 1		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4057	1	16	606	5644	25924	\N	53.972175999999997	г. Узловая, Кирова, 4		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4063	1	16	606	5644	25324	\N	53.972175999999997	г. Узловая, Заводская, 1а		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4067	1	16	606	5644	25291	\N	53.972175999999997	г. Узловая, Завенягина, 32		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4054	1	16	606	5644	26881	\N	53.972175999999997	г. Узловая, Горняцкая, 1		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4069	1	16	606	5644	25659	\N	53.972175999999997	г. Узловая, Генерала Васильева, 1		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4052	1	16	606	5644	25353	\N	53.972175999999997	г. Узловая, Гагарина, 16а	Россия, Тульская область, Узловский район, Узловая	0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4055	1	16	606	5644	26276	\N	53.972175999999997	г. Узловая, Володарского, 5		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4056	1	16	606	5644	25731	\N	53.972175999999997	г. Узловая, Беклемищева, 48		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4053	1	16	606	5644	25731	\N	53.972175999999997	г. Узловая, Беклемищева, 83		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4062	1	16	606	5644	25832	\N	53.972175999999997	г. Узловая, 14 Декабря, 32		0101000020E6100000AE81AD122C14434061FA5E4370FC4A40
4077	1	16	606	48642	\N	\N	53.952109999999998	д. Торбеевка	Россия, Тульская область, Узловский район, поселок Торбеевка	0101000020E6100000486DE2E47E0F4340E71890BDDEF94A40
4083	1	16	606	47922	\N	\N	53.933931999999999	село Смородино, д. 216		0101000020E610000098A1F144102943400C5872158BF74A40
4082	1	16	606	7154	\N	\N	53.846071999999999	д. Прилесье, д.81		0101000020E6100000C6866EF607124340D90759164CEC4A40
4075	1	16	606	48606	25375	\N	53.947256000000003	п. Партизан, Льва Толстого, 16		0101000020E6100000D21BEE23B70C43404B7842AF3FF94A40
4079	1	16	606	48680	75203	\N	53.962218	п. Майский, пер. Клубный, 1		0101000020E6100000658EE55DF51A4340AFCF9CF529FB4A40
3877	1	16	606	28908	\N	\N	53.899000000000001	с. Люторичи	Россия, Тульская область, Узловский район, поселок Люторичи	0101000020E6100000FDDB65BFEE384340508D976E12F34A40
4060	1	16	606	6066	26893	\N	54.005828999999999	п. Каменецкий, Центральная, 4		0101000020E6100000D2C5A695421C4340272F3201BF004B40
4076	1	16	606	45578	75231	\N	53.945514578615203	село Ильинка, ул. Центральная, д.39	Россия, Тульская область, Узловский район, поселок Ильинка	0101000020E61000001A868F88290543405070B1A206F94A40
3799	1	16	606	47756	75446	\N	53.866354000000001	д.Ивановка, Советская, 6		0101000020E6100000122F4FE78A1E4340206118B0E4EE4A40
4086	1	16	606	48802	\N	\N	53.976348999999999	д. Дубовое	Россия, Тульская область, Узловский район, поселок Дубовое	0101000020E6100000C217265305354340BC3D0801F9FC4A40
4074	1	16	606	48549	75101	\N	53.923706288181101	п. Дубовка, Театральная, 1	Россия, Тульская область, Узловский район, поселок Дубовка	0101000020E61000004128EFE3680E43403B8F8AFF3BF64A40
4072	1	16	606	48549	75182	\N	53.923859	п. Дубовка, Советская, 20		0101000020E6100000F12F82C64C0E4340C18EFF0241F64A40
4073	1	16	606	48549	67858	\N	53.923859	п. Дубовка, Пионерская, 30		0101000020E6100000F12F82C64C0E4340C18EFF0241F64A40
4071	1	16	606	48549	75161	\N	53.923859	п. Дубовка, Комсомольская, 2в		0101000020E6100000F12F82C64C0E4340C18EFF0241F64A40
4088	1	16	606	60598	\N	\N	53.754884129581299	село Бутырки, д.79	Россия, Тульская область, Узловский район, поселок Бутырки	0101000020E6100000A1116C5CFF3A43400723F609A0E04A40
3875	1	16	606	28780	75097	\N	53.998690000000003	п. Брусянский, Советская, 1		0101000020E610000066118AADA00B4340CF6BEC12D5FF4A40
3874	1	16	606	28780	25678	\N	53.998690000000003	п. Брусянский, Пугачёва, 53		0101000020E610000066118AADA00B4340CF6BEC12D5FF4A40
87712	1	16	606	3841	\N	\N	53.791677999999997	п. Бестужевский	Россия, Тульская область, Узловский район, поселок Бестужевский	0101000020E6100000E25CC30C8D2F4340397B67B455E54A40
4152	1	16	7509	60510	75107	\N	54.044444105889703	р.п. Первомайский, ул. Школьная, 8	Россия, Тульская область, Тула городской округ, поселок Первомайский	0101000020E6100000C87C40A033C1424070404B57B0054B40
4036	1	16	695	60545	75230	\N	53.437179428837098	п.Центральный, ул.Центральная, д.11	Россия, Тульская область, Тепло-Огаревский район, поселок Центральный	0101000020E61000001C0B0A8332CF4240BEBF417BF5B74A40
3876	1	16	695	60561	75290	\N	53.558257092819296	д. Фёдоровка, Школьная, 1а	Россия, Тульская область, Тепло-Огаревский район, поселок Федоровка	0101000020E610000032AD4D637BBF4240ACE122F774C74A40
4102	1	16	695	48221	75363	\N	53.667175999999998	Чернский район, с.Успенское, ул. Успенская, д.19		0101000020E610000038A27BD635E242408A56EE0566D54A40
4040	1	16	695	46974	\N	\N	53.480961000000001	деревня  Троекурово, дом 55		0101000020E61000002F51BD35B0B5424063D34A2190BD4A40
4047	1	16	695	5384	26794	\N	53.617761999999999	п.Теплое, ул.Сельхозтехниковская, д.14 А		0101000020E610000090847D3B89CA4240145B41D312CF4A40
4039	1	16	695	4957	\N	\N	53.500118999999998	д.Стрешнево, д.16		0101000020E610000051F9D7F2CAC14240DA8D3EE603C04A40
3863	1	16	695	48929	75377	\N	53.718141000000003	п.Северный, ул.Прудная, д.7		0101000020E610000039471D1D57DF42405875560BECDB4A40
4044	1	16	695	5204	26686	\N	53.613297000000003	д.Мосюковка, ул.Центральная, д.32		0101000020E61000005CE509849DD6424012DE1E8480CE4A40
3860	1	16	695	48877	\N	\N	53.592961000000003	п.Мичуринский, д.30		0101000020E6100000CA332F87DDCB4240D8666325E6CB4A40
3862	1	16	695	48914	\N	\N	53.697024999999996	п.Механизаторов, ул.Школьная, д.9	Россия, Тульская область, Тепло-Огаревский район, поселок Механизаторов	0101000020E6100000E44D7E8B4ED2424048BF7D1D38D94A40
4043	1	16	695	5145	25929	\N	53.632821	д.Малая Огаревка, ул.Школьная, д.2 А		0101000020E6100000C3B986191AEB42406B9C4D4700D14A40
4038	1	16	695	4869	26846	\N	53.446314000000001	д.Крюковка 1-я, ул.Центральная, д.3		0101000020E61000005C5A0D897BC242409CDF30D120B94A40
3864	1	16	695	28324	\N	\N	53.614130000000003	Тульская обл, Тепло-Огаревский, п.Красногвардеец, ул.Центральная, д.18	Россия, Тульская область, Тепло-Огаревский район, поселок Красногвардеец	0101000020E6100000301004C8D0DD42400ABFD4CF9BCE4A40
3859	1	16	695	48854	26289	\N	53.538836000000003	п.Кировский, ул.Центральная, д.11		0101000020E6100000BAA46ABB09C0424028F4FA93F8C44A40
3867	1	16	695	48993	\N	\N	53.477874	д.Доробино, д.70		0101000020E61000008A5A9A5B21DA4240EACDA8F92ABD4A40
3861	1	16	695	60540	\N	\N	53.658006869439198	п.Горьковский, д.70	Россия, Тульская область, Тепло-Огаревский район, поселок Горьковский	0101000020E6100000927538BA4ACF424000C5C89239D44A40
3866	1	16	695	28417	75372	\N	53.545090999999999	с.Волчья Дубрава, ул.Колоскова, д.3		0101000020E61000008BDF14562AD24240062CB98AC5C54A40
4045	1	16	695	5223	26691	\N	53.394025999999997	д.Бродиловка, ул.Молодежная, д.19		0101000020E6100000D20149D8B7E1424008E3A7716FB24A40
3865	1	16	695	28337	26850	\N	53.552785	с.Большое Огарево, ул.Базарная, д.26		0101000020E61000007DB08C0DDDDC4240145CACA8C1C64A40
4037	1	16	695	4853	\N	\N	53.399067000000002	деревня Большое Минино, дом 69, квартира 2		0101000020E6100000ABE97AA2EBBE4240D8F4A0A014B34A40
4021	1	16	695	47605	\N	\N	53.674254463170001	с. Богданово, 1	Россия, Тульская область, Тепло-Огаревский район, поселок Богданово	0101000020E6100000EEE9EA8EC5DA42403D997FF44DD64A40
4028	1	16	442	4355	25356	\N	54.119101999999998	пос. Черепеть, Молодежная, 4		0101000020E610000099F38C7DC9304240B071FDBB3E0F4B40
4006	1	16	442	3110	26140	\N	54.095230999999998	г. Чекалин,   ул. Чекалина д. 1А		0101000020E61000006FBDA607051F42405E488787300C4B40
4005	1	16	442	3110	26140	\N	54.095230999999998	"г. Чекалин, Чекалина, 1""А"""		0101000020E61000006FBDA607051F42405E488787300C4B40
4011	1	16	442	60503	75098	\N	54.160165037372003	пос. Центральный,   ул. Машиностроителей,   д. 5А	Россия, Тульская область, Суворовский район	0101000020E61000007555A016833F42405F7B664980144B40
4020	1	16	442	3860	75443	\N	54.220434857336102	пос. Старое Ханино, Молодежная, 3	Россия, Тульская область, Суворовский район, поселок Ханино	0101000020E610000075560BEC314D424067F2CD36371C4B40
4019	1	16	442	3860	25359	\N	54.214297999999999	пос. Ханино,   ул. Заводская, д. 6		0101000020E6100000D2E1218C9F4E424092CCEA1D6E1B4B40
3996	1	16	442	2477	25343	\N	54.115645000000001	"г. Суворов, пл. Победы, 1""А"""		0101000020E610000067B62BF4C13E424014799274CD0E4B40
3995	1	16	442	2477	25795	\N	54.115645000000001	г. Суворов, Суворова, 7		0101000020E610000067B62BF4C13E424014799274CD0E4B40
3997	1	16	442	2477	9687	\N	54.115645000000001	г. Суворов, просп.Мира, 20		0101000020E610000067B62BF4C13E424014799274CD0E4B40
4002	1	16	442	2477	25895	\N	54.115645000000001	г. Суворов, Пионерская, 4		0101000020E610000067B62BF4C13E424014799274CD0E4B40
3998	1	16	442	2477	25895	\N	54.115645000000001	г. Суворов, Пионерская, 11		0101000020E610000067B62BF4C13E424014799274CD0E4B40
4003	1	16	442	2477	25329	\N	54.115645000000001	г. Суворов,   ул. Октябрьская, 4		0101000020E610000067B62BF4C13E424014799274CD0E4B40
4001	1	16	442	2477	25549	\N	54.115645000000001	г. Суворов, Ленинского Юбилея, 4		0101000020E610000067B62BF4C13E424014799274CD0E4B40
3994	1	16	442	2477	26111	\N	54.115645000000001	г. Суворов,   ул. Белинского, 18		0101000020E610000067B62BF4C13E424014799274CD0E4B40
4000	1	16	442	2477	26647	\N	54.115645000000001	г. Суворов,   ул. Тульская, д. 5,		0101000020E610000067B62BF4C13E424014799274CD0E4B40
87774	1	16	442	7086	\N	\N	54.105252	д. Селюково, 1		0101000020E6100000D3122BA39111424057EBC4E5780D4B40
4033	1	16	442	4625	\N	\N	54.208858999999997	пос. Северо-Агеевский, 5		0101000020E61000006214048F6F254240D53C47E4BB1A4B40
4023	1	16	442	4049	\N	\N	54.154639000000003	д. Своино, д. 18		0101000020E6100000A62897C62F524240D4D7F335CB134B40
4015	1	16	442	3677	26659	\N	54.170147999999998	пос. Песоченский, Ленина, 12		0101000020E6100000A9674128EF0D42406ABDDF68C7154B40
4027	1	16	442	4296	\N	\N	54.047248000000003	с. Песковатское, 63		0101000020E6100000FFE9060ABC2142409566F3380C064B40
4024	1	16	442	4144	\N	\N	54.149265999999997	Тульская обл, Суворовский, с. Марково, 56		0101000020E610000005C3B986194A4240CE33F6251B134B40
4022	1	16	442	47629	\N	\N	54.272047000000001	д. Малиновка, 1		0101000020E61000000E65A88AA94E4240CAFCA36FD2224B40
4034	1	16	442	4674	26166	\N	54.122695	пос. Лужковский, 60 лет СССР, 9		0101000020E6100000AF264F594D374240FD304278B40F4B40
4031	1	16	442	4495	\N	\N	54.110166	"курорт Краинка, ДК ООО ""Санаторий (кур-т) ""Краинка"""		0101000020E6100000865AD3BCE32A4240C99063EB190E4B40
4014	1	16	442	47479	25326	\N	54.016649000000001	с. Кулешово, 40 лет Победы, 31		0101000020E610000003D0285DFA2D42406C41EF8D21024B40
4018	1	16	442	46171	\N	\N	54.133977634462298	д. Зеленино, д. 71	Россия, Тульская область, Суворовский район, поселок Зеленино	0101000020E6100000BAF8DB9E201F42401631EC3026114B40
4035	1	16	442	4748	26845	\N	54.182147999999998	пос. Збродовский, Полевая, 29		0101000020E610000083F92B64AE36424012842BA050174B40
4025	1	16	442	51177	\N	\N	54.035330000000002	д. Желоба-1, 21		0101000020E6100000AD50A4FB39154240AA4885B185044B40
4012	1	16	442	3508	25560	\N	54.174005999999999	"пос. Глубоковский, Глубокая, 1""А"""		0101000020E6100000A4E36A645744424065A71FD445164B40
4017	1	16	442	3773	\N	\N	54.160891999999997	д. Бряньково, 100		0101000020E6100000FBCA83F4141F42401118EB1B98144B40
3441	1	16	442	49469	75320	\N	54.189360999999998	д.Борисово, Южная		0101000020E61000001557957D57424240A51133FB3C184B40
3739	1	16	442	46560	\N	\N	54.025016999999998	п. Березовский, Луговая, 5а	Россия, Тульская область, Суворовский район, поселок Березовский	0101000020E61000008CBAD6DEA73C4240096CCEC133034B40
4013	1	16	442	60615	75456	\N	54.044179699864898	с. Березово, Романова, 25	Россия, Тульская область, Суворовский район, поселок Березово	0101000020E6100000CF691668773442409291B3B0A7054B40
4008	1	16	442	60608	75442	\N	54.158481875681801	пос. Агеево,   ул. Комсомольская, 14	Россия, Тульская область, Суворовский район, Агеево	0101000020E6100000D2E3F736FD3B424099805F2349144B40
4226	1	16	7111	51240	26176	\N	54.120320999999997	город Тула, Привокзальный район, поселок Косая Гора, улица Гагарина, 2		0101000020E6100000E02D90A0F8C54240D102B4AD660F4B40
3993	1	16	210	47056	26297	\N	53.693677000000001	с. Юсупово, Школьная, 3		0101000020E6100000B05758703F824240637E6E68CAD84A40
3991	1	16	210	2315	\N	\N	53.739033999999997	п. Юрьевский, 21		0101000020E6100000213D450E11A34240E75086AA98DE4A40
3985	1	16	210	60599	75420	\N	53.422641197390497	п. Стройка, Центральная, 36	Россия, Тульская область, Плавский район, поселок Стройка	0101000020E61000000ABABDA431AE42407079AC1919B64A40
4171	1	16	210	1459	75447	\N	53.678944899786501	д. Сорочинка, ул. Школьная, 29	Россия, Тульская область, Плавский район, поселок Сорочинка	0101000020E6100000EAEC647094B84240306475ABE7D64A40
3977	1	16	210	1459	75467	\N	53.6793783435363	с. Сорочинка, ул. Центральная, д.25	Россия, Тульская область, Плавский район, поселок Сорочинка	0101000020E61000009DF6949C13B942409ACFB9DBF5D64A40
3975	1	16	210	60563	75297	\N	53.597046854051001	п. Советский, Почтовая, 13		0101000020E610000032ACE28DCC91424064963D096CCC4A40
3983	1	16	210	1828	25551	\N	53.582949999999997	д. Савватеевка, Центральная, 21		0101000020E6100000CD02ED0E29984240029A081B9ECA4A40
4030	1	16	210	60551	\N	\N	53.681871229899798	с. Рождествено, 247	Россия, Тульская область, Плавский район, поселок Рождествено 1-е	0101000020E61000008C9DF0129C924240A08B868C47D74A40
3971	1	16	210	801	\N	\N	53.7213387491269	г. Плавск, п.Белая Гора, 19	Россия, Тульская область, Плавский район, Плавск	0101000020E610000006685BCD3AA34240282A1BD654DC4A40
3970	1	16	210	801	26746	\N	53.705394274185799	г. Плавск, Тимофеева, 7А	Россия, Тульская область, Плавский район, Плавск	0101000020E6100000C90567F0F7A54240B665C0594ADA4A40
3972	1	16	210	801	26575	\N	53.703916999999997	г. Плавск, Орлова, 10		0101000020E6100000A089B0E1E9A54240990CC7F319DA4A40
3967	1	16	210	801	26710	\N	53.703916999999997	г. Плавск, Ленина, 4		0101000020E6100000A089B0E1E9A54240990CC7F319DA4A40
3969	1	16	210	801	25514	\N	53.703916999999997	г. Плавск, ул. Коммунаров, д.25		0101000020E6100000A089B0E1E9A54240990CC7F319DA4A40
3968	1	16	210	801	25514	\N	53.703916999999997	г. Плавск, Коммунаров, 25		0101000020E6100000A089B0E1E9A54240990CC7F319DA4A40
3965	1	16	210	801	25514	\N	53.703916999999997	г. Плавск, Коммунаров, 68		0101000020E6100000A089B0E1E9A54240990CC7F319DA4A40
4172	1	16	210	45971	\N	\N	53.423971999999999	с. Новоникольское, 36а		0101000020E61000000AF5F411F8AF4240B935E9B644B64A40
3986	1	16	210	46922	75373	\N	53.486404999999998	д. Новое Жуково, Школьная, 26		0101000020E6100000259694BBCF99424031CEDF8442BE4A40
3981	1	16	210	1729	25864	\N	53.652796000000002	п. Молочные Дворы, Парковая, 2		0101000020E6100000271422E0109E4240D57ABFD18ED34A40
3978	1	16	210	46735	26259	\N	53.609343000000003	с. Мещерино, Центральная, 17		0101000020E61000008CDCD3D51DB14240F58590F3FECD4A40
3989	1	16	210	2200	25545	\N	53.774493999999997	д. Крекшино, Шоссейная, 75		0101000020E61000006823D74D29A142405F79909E22E34A40
3992	1	16	210	47026	26310	\N	53.743783999999998	с. Красногорье, Центральная, 6		0101000020E6100000DC9BDF30D18C4240DFA4695034DF4A40
3976	1	16	210	46706	25960	\N	53.672452	с. Камынино, Парковая, 1		0101000020E61000004FEACBD24EA942409D103AE812D64A40
3980	1	16	210	1676	25459	\N	53.584580000000003	д, Ивановское-1, Центральная, 14		0101000020E610000065E42CEC69A94240A6F27684D3CA4A40
3979	1	16	210	1588	26296	\N	53.546964000000003	п. Диктатура, Школьная, 1		0101000020E6100000A73CBA1116B34240700B96EA02C64A40
3987	1	16	210	46925	75339	\N	53.457730369058702	д. Гремячево, Молодежная, 6	Россия, Тульская область, Плавский район, поселок Гремячево	0101000020E6100000CB4BFE277FA34240F4328AE596BA4A40
3973	1	16	210	60553	75260	\N	53.602742030060199	п. Горбачево, Школьная, 18	Россия, Тульская область, Плавский район, поселок Горбачево	0101000020E61000008BA71E69709142407BF65CA626CD4A40
3984	1	16	210	46857	75312	\N	53.553559999999997	с. Большие Озерки, Школьная, 2	Россия, Тульская область, Плавский район, поселок Большие Озерки	0101000020E6100000338AE59656974240D72FD80DDBC64A40
3956	1	16	39	226	75383	\N	53.921588999999997	деревня Ченцовы Дворы, Школьная, 9		0101000020E6100000CFC0C8CB9A8042403AADDBA0F6F54A40
3963	1	16	39	674	26880	\N	53.788029000000002	поселок Стрелецкий, площадь Стрелецкая, 101		0101000020E61000003ACAC16C0252424059A65F22DEE44A40
3957	1	16	39	46302	25834	\N	53.887422000000001	село Стояново, Центральная, 7а		0101000020E6100000ED478AC8B06642401EE0490B97F14A40
3961	1	16	39	46409	75402	\N	53.861341000000003	село Сомово, Шарова, 15		0101000020E610000058AD4CF8A54442401BDA006C40EE4A40
14750	5	43	195	13010	74183	\N	50.849023000000003	с.Шиба, Трактовая, 31		0101000020E6100000DA0418963F6F5540A24621C9AC6C4940
3954	1	16	39	47	26357	\N	54.051836000000002	Северо-Ватцевское лесничество, Центральная, 17		0101000020E61000002B306475AB494240B360E28FA2064B40
3958	1	16	39	46337	26544	\N	53.850799000000002	село Рылево, Центральная, 28а		0101000020E61000002E20B41EBE6A4240193C4CFBE6EC4A40
3952	1	16	39	46205	\N	\N	54.040798000000002	деревня Окороково, 40		0101000020E61000007B6B60AB0457424001DF6DDE38054B40
3949	1	16	39	32223	25508	\N	53.932563999999999	поселок Одоев, Победы, 4		0101000020E6100000E25B5837DE574240A6B6D4415EF74A40
3948	1	16	39	32223	75271	\N	53.932563999999999	поселок Одоев, Ленина, 25а		0101000020E6100000E25B5837DE574240A6B6D4415EF74A40
3950	1	16	39	32223	26548	\N	53.932563999999999	поселок Одоев, Карла Маркса, 150		0101000020E6100000E25B5837DE574240A6B6D4415EF74A40
3947	1	16	39	32223	25829	\N	53.932563999999999	поселок Одоев, 50 лет Октября, 80а		0101000020E6100000E25B5837DE574240A6B6D4415EF74A40
3962	1	16	39	612	25843	\N	53.953795	село Николо-Жупань, Молодежная, 79		0101000020E6100000098849B8905342404E0B5EF415FA4A40
1474	1	16	39	8491	11712	\N	53.961805921690598	с.Мишенское, Бунина, 75	Россия, Тульская область, Одоевский район, поселок Мишенское	0101000020E6100000BF7E880D166642405D8C81751CFB4A40
3955	1	16	39	150	25876	\N	53.939915999999997	село Жемчужниково, Школьная, 32		0101000020E61000002BDEC83CF26742405A7EE02A4FF84A40
3608	1	16	39	48484	67859	\N	53.807434999999998	с.Воскресенское, Дружбы, 30		0101000020E6100000658F5033A4804240A852B3075AE74A40
3960	1	16	39	487	9870	\N	53.800410999999997	деревня Ботвиньево, Луговая, 10		0101000020E61000001E520C90687E4240E82D1EDE73E64A40
3463	1	16	39	45595	\N	\N	53.835929999999998	д.Березово, 64	Россия, Тульская область, Одоевский район, поселок Березово	0101000020E61000001D3C139A2478424065DF15C1FFEA4A40
3953	1	16	39	46207	26598	\N	53.980367999999999	село Апухтино, Центральная, 1		0101000020E610000077BCC96FD1594240C005D9B27CFD4A40
3938	1	16	1812	45879	26020	\N	54.237789999999997	село Шишлово, Центральная, 32	Россия, Тульская область, Новомосковский район, поселок Шишлово	0101000020E6100000202A8D98D94543406DA818E76F1E4B40
3931	1	16	1812	31513	25318	\N	54.068973999999997	пос. Ширинский, Зеленая, 25		0101000020E6100000F46F97FDBA2F43401C23D923D4084B40
3939	1	16	1812	31856	75376	\N	54.182606	дер. Холтобино, Гукова, 37		0101000020E6100000062E8F35233D4340D50627A25F174B40
856	1	16	1812	40896	\N	\N	54.167641131472003	деревня Хлопово		0101000020E61000002BDB87BCE5384340003CA24275154B40
3936	1	16	1812	51160	25321	\N	54.150486508894602	дер. Савино, Школьная, 3	Россия, Тульская область, Новомосковский район, поселок Савино	0101000020E6100000B9196EC0E745434090BC732843134B40
3927	1	16	1812	31299	\N	\N	54.055197999999997	дер. Рига-Васильевка, 62		0101000020E61000003E05C07806154340FD6662BA10074B40
86470	1	16	1812	49461	\N	\N	54.151850000000003	д.Пушкари	Россия, Тульская область, Новомосковский район, поселок Пушкари	0101000020E610000030BC92E4B9564340E5F21FD26F134B40
3943	1	16	1812	46000	26786	\N	54.197915999999999	пос. Правда, Молодежная, 11		0101000020E6100000122F4FE78A1E434075ADBD4F55194B40
4192	1	16	1812	45528	75340	\N	54.192717000000002	п.Первомайский, ул.Советская, д.2		0101000020E61000004BE658DE554D43400E315EF3AA184B40
4150	1	16	1812	45528	75436	\N	54.192717000000002	р.п. Первомайский, ул. Пролетарская, 1		0101000020E61000004BE658DE554D43400E315EF3AA184B40
3790	1	16	1812	47600	\N	\N	54.103656999999998	с.Орловка, 2		0101000020E6100000E2CD1ABCAF1243403080F0A1440D4B40
3933	1	16	1812	45796	75398	\N	54.105061999999997	дер. Ольховец, Победы, 35		0101000020E6100000CDCB61F71D374340B306EFAB720D4B40
3934	1	16	1812	51159	25312	\N	54.140552999999997	дер. Озерки, Центральная, 11	Россия, Тульская область, Новомосковский район, поселок Озерки	0101000020E61000008177F2E9B1394340662D05A4FD114B40
3903	1	16	1812	27080	25303	\N	54.039296	г. Новомосковск, проспект Победы, 7-б		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3902	1	16	1812	27080	25303	\N	54.039296	г. Новомосковск, проспект Победы, 4		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3909	1	16	1812	27080	26648	\N	54.039296	г. Новомосковск, Школьная, 13		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3908	1	16	1812	27080	26648	\N	54.040101614864703	г. Новомосковск, Школьная, 1	Россия, Тульская область, Новомосковский район, Новомосковск	0101000020E610000055A18158362143408940F50F22054B40
3922	1	16	1812	27080	26887	\N	54.039296	г. Новомосковск, микрорайон Сокольники, ул. Шахтерская, 16		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3918	1	16	1812	27080	25721	\N	54.039296	г. Новомосковск, Центральная, 27		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3911	1	16	1812	27080	25300	\N	54.039296	г. Новомосковск, Трудовые резервы, 73-б		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3896	1	16	1812	27080	25300	\N	54.039296	г. Новомосковск, Трудовые резервы, 21	Россия, Тульская область, Новомосковский район, Новомосковск	0101000020E6100000DD94F25A092143408B6EBDA607054B40
3895	1	16	1812	27080	26391	\N	54.039296	г. Новомосковск, Солнечная, 8		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3901	1	16	1812	27080	25302	\N	54.039296	г. Новомосковск, Свердлова, 32		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3899	1	16	1812	27080	25302	\N	54.039296	г. Новомосковск, Свердлова, 22		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3917	1	16	1812	27080	26021	\N	54.039296	г. Новомосковск, Рудничная, 6		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3924	1	16	1812	27080	25322	\N	54.039296	г. Новомосковск, микрорайон Сокольники, ул. Пушкина, 9	Россия, Тульская область, Новомосковский район, Новомосковск	0101000020E6100000DD94F25A092143408B6EBDA607054B40
3906	1	16	1812	27080	25434	\N	54.039296	г. Новомосковск, Присягина, 9		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3915	1	16	1812	27080	26462	\N	54.039296	г. Новомосковск, Орджоникидзе, 4-а		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3897	1	16	1812	27080	25412	\N	54.039296	г. Новомосковск, Октябрьская, 21		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3898	1	16	1812	27080	25716	\N	54.039296	г. Новомосковск, Московская, 10		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3892	1	16	1812	27080	25716	\N	54.039296	г. Новомосковск, Московская, 9		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3914	1	16	1812	27080	25762	\N	54.039296	г. Новомосковск, Молодежная, 2-а		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3916	1	16	1812	27080	25956	\N	54.039296	г. Новомосковск, Мира, 15-б		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3907	1	16	1812	27080	25956	\N	54.039296	г. Новомосковск, Мира, 8-б		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3890	1	16	1812	27080	26388	\N	54.039296	г. Новомосковск, Маяковского, 36/1		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3920	1	16	1812	27080	26396	\N	54.039296	г. Новомосковск, Маклец, 15-а		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3923	1	16	1812	27080	25472	\N	54.039296	г. Новомосковск, микрорайон Сокольники, ул. Ленина, 23		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3921	1	16	1812	27080	25472	\N	54.039296	г. Новомосковск, микрорайон Сокольники,  ул. Ленина, 13		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3891	1	16	1812	27080	25964	\N	54.039296	г. Новомосковск, Кукунина, 18		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3904	1	16	1812	27080	25980	\N	54.039296	г. Новомосковск, Куйбышева, 15-б		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3889	1	16	1812	27080	26216	\N	54.039296	г. Новомосковск, Клинский проезд, 7		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3900	1	16	1812	27080	26222	\N	54.039296	г. Новомосковск, Калинина, 24		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3913	1	16	1812	27080	26767	\N	54.039296	г. Новомосковск, Дружбы, 8		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3910	1	16	1812	27080	26884	\N	54.039296	г. Новомосковск, Донская, 17-а		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3912	1	16	1812	27080	25748	\N	54.039296	г. Новомосковск, Демкина, 7		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3893	1	16	1812	27080	25974	\N	54.038990192262098	г. Новомосковск, Березовая, 7	Россия, Тульская область, Новомосковский район, Новомосковск	0101000020E61000003F74417DCB2043407E6FD39FFD044B40
3905	1	16	1812	27080	25430	\N	54.039296	г. Новомосковск, Бережного, 16		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3888	1	16	1812	27080	25808	\N	54.039296	г. Новомосковск, Аварийная, 12		0101000020E6100000DD94F25A092143408B6EBDA607054B40
3919	1	16	1812	27080	25464	\N	54.039296	г. Новомосковск, 1-ая Транспортная, 3		0101000020E6100000DD94F25A092143408B6EBDA607054B40
4085	1	16	1812	48792	\N	\N	54.163449	д. Никольское, д. 123а		0101000020E61000001EA8531EDD3243402EC896E5EB144B40
3929	1	16	1812	31416	\N	\N	54.038021999999998	дер. Малое Колодезное, 113		0101000020E6100000B60F79CBD5294340A643A7E7DD044B40
3930	1	16	1812	45719	26788	\N	54.045454999999997	пос. Малиновский, Толстого, 16		0101000020E61000002367614F3B30434047382D78D1054B40
3642	1	16	1812	60536	\N	\N	54.122505817857203	д.Кукуй	Россия, Тульская область, Новомосковский район, поселок Кукуй	0101000020E610000074965984623F43402AC8CF46AE0F4B40
3551	1	16	1812	60536	75229	\N	54.124724144227102	д. Кукуй, ул. Центральная, д. 23	Россия, Тульская область, Новомосковский район, поселок Кукуй	0101000020E610000061DF4E22C23F43405E83BEF4F60F4B40
3940	1	16	1812	31902	25452	\N	54.147615000000002	пос. Красный Богатырь, Школьная, 19		0101000020E61000008D9AAF928F5D434014B35E0CE5124B40
3928	1	16	1812	31334	25736	\N	54.032088999999999	дер. Красное Гремячево, Новая, 11-а		0101000020E61000000821205F421D4340DAC70A7E1B044B40
3942	1	16	1812	31994	26260	\N	54.225642999999998	пос. Коммунаров, Садовая, 4		0101000020E6100000EE79FEB4512D434021C9ACDEE11C4B40
3926	1	16	1812	31235	26865	\N	54.113613000000001	дер. Грицово, Центральная, 44		0101000020E61000003C4B90115015434042B3EBDE8A0E4B40
3935	1	16	1812	31702	26072	\N	54.130937000000003	село Гремячее, Новики, 14		0101000020E6100000F96A47718E5443400E6B2A8BC2104B40
3937	1	16	1812	45849	\N	\N	54.109448	дер. Березовка	Россия, Тульская область, Новомосковский район, поселок Березовка	0101000020E61000008940F50F224D43406A4E5E64020E4B40
3785	1	16	1162	51175	\N	\N	54.119846000000003	ст. Присады, 15а		0101000020E6100000857B65DEAAE7424039471D1D570F4B40
3845	1	16	1162	27470	\N	\N	54.220395000000003	Тульская обл, Ленинский, деревня Ямны, 1а		0101000020E61000004FB2D5E594BC4240D99942E7351C4B40
3834	1	16	1162	26953	\N	\N	54.080142000000002	Ленинский район, п.Южный	Россия, Тульская область, Ленинский район, поселок Южный	0101000020E61000004A0A2C80299D42409D84D217420A4B40
3853	1	16	1162	20702	26878	\N	54.128999999999998	Тульская обл, Ленинский, поселок Шатск, Садовая 1а		0101000020E6100000A036AAD381EC42408D976E1283104B40
3854	1	16	1162	20702	26185	\N	54.128999999999998	Тульская обл, Ленинский, поселок Шатск, Ленина 15		0101000020E6100000A036AAD381EC42408D976E1283104B40
3855	1	16	1162	20800	25931	\N	54.177315999999998	Тульская обл, Ленинский, село Частое, Совхозная 20		0101000020E61000005C2041F163E442405D876A4AB2164B40
3851	1	16	1162	60495	75077	\N	54.2340070120243	Тульская обл, Ленинский, село Хрущево, Центральная, 142	Россия, Тульская область	0101000020E6100000B79BE09BA6C342407D04FEF0F31D4B40
3850	1	16	1162	60495	75197	\N	54.234135367110902	Тульская обл, Ленинский, село Хрущево, Совхозная 1	Россия, Тульская область	0101000020E6100000F90FE9B7AFC34240ABECBB22F81D4B40
3846	1	16	1162	27489	\N	\N	54.248564999999999	Тульская обл, Ленинский, село Федоровка, 7а		0101000020E61000000CC9C9C4ADB4424012F758FAD01F4B40
3840	1	16	1162	27227	75261	\N	54.299672000000001	Тульская обл, Ленинский, поселок Торхово, Центральная 22		0101000020E61000003BFE0B0401E4424072C3EFA65B264B40
4048	1	16	1162	48114	75279	\N	54.326123000000003	п.Теплое, ул.Советская, д.40		0101000020E610000044183F8D7BEB424099BC0166BE294B40
4051	1	16	1162	48114	26366	\N	54.325771857107704	п.Теплое, ул.Советская, д.16	Россия, Тульская область, Ленинский район, поселок Теплое	0101000020E6100000F7578FFB56EB4240ECF99AE5B2294B40
3823	1	16	1162	60555	\N	\N	54.219368000000003	Ленинский район, д.Старое Басово, д.21а		0101000020E6100000EC681CEA77C14240FCE42840141C4B40
3828	1	16	1162	26690	25906	\N	54.105626999999998	Тульская обл, Ленинский, поселок Сергиевский, Центральная		0101000020E61000000DFD135CACDE42408C497F2F850D4B40
3841	1	16	1162	27250	25916	\N	54.294843	Тульская обл, Ленинский, поселок Рождественский, Московская 18		0101000020E61000007E6FD39FFDC842402E3A596ABD254B40
3837	1	16	1162	27000	\N	\N	54.173664000000002	Тульская обл, Ленинский, поселок Рассвет, 35		0101000020E6100000581AF8510DB742400C3F389F3A164B40
3836	1	16	1162	27000	\N	\N	54.173664000000002	Тульская обл, Ленинский, поселок Рассвет, 38		0101000020E6100000581AF8510DB742400C3F389F3A164B40
3835	1	16	1162	27000	\N	\N	54.173664000000002	Тульская обл, Ленинский, поселок Рассвет, 44		0101000020E6100000581AF8510DB742400C3F389F3A164B40
3824	1	16	1162	26504	\N	\N	54.160801999999997	Ленинский район, с.Осиновая Гора	Россия, Тульская область, Ленинский район, поселок Осиновая Гора	0101000020E61000002619390B7BD64240D190F12895144B40
3842	1	16	1162	27328	\N	\N	54.337789000000001	Тульская обл, Ленинский, поселок Октябрьский, 93		0101000020E61000001900AAB871C742406AF981AB3C2B4B40
3820	1	16	1162	20469	25347	\N	54.296346	Ленинский район, п.Обидимо, ул.Школьная, д.3	Россия, Тульская область, Ленинский район, поселок Обидимо	0101000020E6100000DE1E84807CB3424074266DAAEE254B40
3856	1	16	1162	60558	75285	\N	54.219368000000003	Тульская обл, Ленинский, деревня Морозовка, Центральная 9	Россия, Тульская область	0101000020E6100000EC681CEA77C14240FCE42840141C4B40
3838	1	16	1162	27134	75078	\N	54.258485	Тульская обл, Ленинский, поселок Молодежный, Центральная 10		0101000020E6100000070B2769FEDA4240D7C0560916214B40
3827	1	16	1162	26645	\N	\N	54.083438000000001	Тульская обл, Ленинский, село Лутовиново, 2		0101000020E61000009240834D9DD74240309FAC18AE0A4B40
3818	1	16	1162	25905	26146	\N	54.2883	Тульская обл, Ленинский, поселок Ленинский, Центральная 1а		0101000020E61000001D0247020DBA4240E9B7AF03E7244B40
3811	1	16	1162	25905	75270	\N	54.2883	Тульская обл, Ленинский, поселок Плеханово, Свердлова 55		0101000020E61000001D0247020DBA4240E9B7AF03E7244B40
3813	1	16	1162	25905	26127	\N	54.2883	Тульская обл, Ленинский, поселок Ленинский, Механизаторов 11		0101000020E61000001D0247020DBA4240E9B7AF03E7244B40
3817	1	16	1162	25905	26861	\N	54.2883	Тульская обл, Ленинский, поселок Ленинский, Ленина 1		0101000020E61000001D0247020DBA4240E9B7AF03E7244B40
3816	1	16	1162	25905	25339	\N	54.2883	Тульская обл, Ленинский, поселок Ленинский, Гагарина 11		0101000020E61000001D0247020DBA4240E9B7AF03E7244B40
3815	1	16	1162	25905	75167	\N	54.293926590016099	п.Ленинский, ул.Гагарина, д.9	Россия, Тульская область, Ленинский район, поселок Ленинский	0101000020E61000005A2BDA1CE7BA4240A83462669F254B40
3826	1	16	1162	25905	75245	\N	54.2883	Тульская обл, Ленинский, поселок Прилепы, Буденного 7		0101000020E61000001D0247020DBA4240E9B7AF03E7244B40
1872	1	16	1162	40984	11990	\N	54.077984405068896	д.Кураково, Игоревская, 61А	Россия, Тульская область, Ленинский район, поселок Кураково	0101000020E6100000E3C798BB96A042403ECE3461FB094B40
3825	1	16	1162	26541	\N	\N	54.115909000000002	Ленинский район, д.Крутое, д. 6а		0101000020E61000007EE5417A8AD44240F2272A1BD60E4B40
3849	1	16	1162	27622	\N	\N	54.201745000000003	Тульская обл, Ленинский, деревня Коптево, 75		0101000020E6100000386744696FA84240D690B8C7D2194B40
3831	1	16	1162	22053	\N	\N	54.166131999999998	Тульская обл, Ленинский, поселок Иншинский, 22		0101000020E61000009BAC510FD1BA4240D76839D043154B40
3830	1	16	1162	22053	\N	\N	54.166131999999998	Тульская обл, Ленинский, поселок Иншинский, 34		0101000020E61000009BAC510FD1BA4240D76839D043154B40
3821	1	16	1162	26332	26149	\N	54.125022000000001	Тульская обл, Ленинский, поселок Ильинка, Центральная 19а		0101000020E61000002237C30DF8D84240E8A38CB800104B40
1130	1	16	1162	26886	\N	\N	54.145585816233002	д.Зайцево, 9	Россия, Тульская область, Ленинский район, поселок Зайцево	0101000020E61000001DE5603601B04240B360E28FA2124B40
3832	1	16	1162	26886	26159	\N	54.146797999999997	Тульская обл, Ленинский, село Зайцево, Школьная 12		0101000020E6100000E481C8224DB04240218FE046CA124B40
3833	1	16	1162	26886	26669	\N	54.146797999999997	Тульская обл, Ленинский, село Зайцево, Новая 1		0101000020E6100000E481C8224DB04240218FE046CA124B40
85353	1	16	1162	60548	\N	\N	54.312170000000002	пос.Восточный	Россия, Тульская область, Ленинский район, поселок Восточный	0101000020E6100000B0928FDD05CC42406B65C22FF5274B40
3814	1	16	1162	19609	26856	\N	54.267378000000001	Тульская обл, Ленинский, поселок Барсуки, Советская 16а		0101000020E610000033A9A10DC0BE4240BFD53A7139224B40
3819	1	16	1162	19609	26651	\N	54.267378000000001	Тульская обл, Ленинский, поселок Барсуки, Пушкина 1		0101000020E610000033A9A10DC0BE4240BFD53A7139224B40
3852	1	16	1162	19609	25613	\N	54.267378000000001	Тульская обл, Ленинский, деревня Барсуки, Клубная, 15		0101000020E610000033A9A10DC0BE4240BFD53A7139224B40
3844	1	16	1162	27418	26349	\N	54.290365999999999	Тульская обл, Ленинский, село Архангельское, Центральная 12		0101000020E61000003B54539275D4424067EF8CB62A254B40
3847	1	16	1162	27559	26683	\N	54.238920999999998	Тульская обл, Ленинский, село Алешня, Центральная 35		0101000020E610000024B5503239A14240EFA99CF6941E4B40
3808	1	16	1762	47918	26115	\N	53.411479	д.Травино, Молодежная, 3		0101000020E6100000EE96E4805D3D4340D2FE0758ABB44A40
3714	1	16	1762	46011	\N	\N	53.488778000000003	д.Софьинка, 2		0101000020E61000006325E659494543408D800A4790BE4A40
3801	1	16	1762	47792	75251	\N	53.413749000000003	п.Самарский, Центральная, 27		0101000020E61000008D5F7825C94F434059E02BBAF5B44A40
3804	1	16	1762	47792	26629	\N	53.413749000000003	п.Самарский, Запрудная, 19		0101000020E61000008D5F7825C94F434059E02BBAF5B44A40
4087	1	16	1762	46818	\N	\N	53.429690999999998	д. Ракитино, д.17а		0101000020E61000005308E4124736434059315C1D00B74A40
3792	1	16	1762	25027	25522	\N	53.456116999999999	п.Птань, Центральная, 2		0101000020E6100000252191B6F13543402713B70A62BA4A40
3797	1	16	1762	47690	75349	\N	53.555774999999997	п.Михайловский, Центральная, 4		0101000020E6100000A7052FFA0A3C43409A779CA223C74A40
3805	1	16	1762	60613	75451	\N	53.387949734327101	д.Марьинка, Школьная, 8	Россия, Тульская область, Куркинский район, поселок Марьинка	0101000020E610000033DFC14F1C324340D93D7958A8B14A40
3794	1	16	1762	25543	26379	\N	53.433570000000003	п.Куркино, Школьная, 6а		0101000020E6100000F8DD74CB0E5543406C43C5387FB74A40
3793	1	16	1762	25543	26819	\N	53.433570000000003	п.Куркино, Парковая, 2		0101000020E6100000F8DD74CB0E5543406C43C5387FB74A40
3803	1	16	1762	25543	26831	\N	53.433570000000003	п.Куркино, Октябрьская, 41а		0101000020E6100000F8DD74CB0E5543406C43C5387FB74A40
3802	1	16	1762	25543	26626	\N	53.433570000000003	п.Куркино, 1-ая Привокзальная, 2а		0101000020E6100000F8DD74CB0E5543406C43C5387FB74A40
3798	1	16	1762	60593	75392	\N	53.501466316358098	с.Кресты, Садовая, 14	Россия, Тульская область, Куркинский район, поселок Кресты	0101000020E6100000EB8D5A61FA4C43402907B30930C04A40
3789	1	16	1762	60609	75444	\N	53.569950752937302	п.Грибоедово, Центральная, 10	Россия, Тульская область, Куркинский район, поселок Грибоедова	0101000020E6100000D95BCAF9626F434048A98427F4C84A40
3796	1	16	1762	47694	26898	\N	53.561075000000002	д.Грачевка, Дорожная, 9		0101000020E61000001AC40776FC3D434036CD3B4ED1C74A40
3791	1	16	1762	60602	75430	\N	53.491875096893601	с.Андреевка, Центральная, 48	Россия, Тульская область, Куркинский район, поселок Андреевка	0101000020E61000003C670B08AD594340295C8FC2F5BE4A40
1480	1	16	6182	39105	11717	\N	56.920816000000002	д.Богданово, Школьная, 1		0101000020E6100000B2101D024742414018D1764CDD754C40
3767	1	16	1223	21284	26829	\N	54.092744000000003	п. Шварцевский, Советская, 9		0101000020E6100000C85EEFFE78FF42403B730F09DF0B4B40
3766	1	16	1223	21284	26198	\N	54.092744000000003	п. Шварцевский, Первомайская, 7		0101000020E6100000C85EEFFE78FF42403B730F09DF0B4B40
3765	1	16	1223	21284	25364	\N	54.092744000000003	Тульская обл, Киреевский, п. Шварцевский, Ленина, 17		0101000020E6100000C85EEFFE78FF42403B730F09DF0B4B40
4007	1	16	1223	47335	\N	\N	53.950800999999998	п. Шахтерский,   ул. Победы, д. 2	Россия, Тульская область, Киреевский район, поселок Шахтерский	0101000020E61000006473D53C47DC42408600E0D8B3F94A40
3781	1	16	1223	47425	25700	\N	53.900193999999999	д. Черная Грязь, Молодежная, 37		0101000020E610000001BF4692200443401807978E39F34A40
3738	1	16	1223	22498	26502	\N	53.888838999999997	п. Сеченский, Ленина, 7а		0101000020E6100000A04FE449D2E742406534F279C5F14A40
3770	1	16	1223	23969	25505	\N	54.108741000000002	Киреевский район, д. Сергиевское, ул.Центральная, д. 30а		0101000020E61000006CEEE87FB9E04240FF5D9F39EB0D4B40
3774	1	16	1223	47280	26284	\N	53.884338999999997	п. Прогресс, Молодежная, 14		0101000020E6100000006F8104C5ED4240E6C9350532F14A40
3736	1	16	1223	22405	75114	\N	53.908538503432602	п. Приупский, Клубная, 11а	Россия, Тульская область, Киреевский район, поселок Приупский	0101000020E610000073672618CEDD4240FD1186014BF44A40
3771	1	16	1223	24017	\N	\N	54.042980999999997	Киреевский район, д. Подосинки, д.80		0101000020E6100000BC5B59A2B3E04240B8ACC26680054B40
3750	1	16	1223	23025	26143	\N	54.032373999999997	Киреевский район, п. Октябрьский, ул. Ленина		0101000020E6100000FD2FD7A205E64240CF9ECBD424044B40
3788	1	16	1223	24866	25861	\N	54.072651999999998	с. Новоселебное, Комсомольская, 52		0101000020E61000001B4AED45B4FD424097FE25A94C094B40
3786	1	16	1223	60604	75435	\N	54.115120416817497	с. Новое Село, Центральная, 3		0101000020E6100000A3224E27D9EC4240C98E8D40BC0E4B40
3807	1	16	1223	47909	75423	\N	54.087363000000003	д.Моховое, Центральная, 31		0101000020E6100000DD9A745B22014340B3F0F5B52E0B4B40
3776	1	16	1223	47319	25851	\N	53.840499000000001	д. Мостовая, Зеленая, 30		0101000020E610000001F8A75489F442400DA9A27895EB4A40
3777	1	16	1223	47350	75450	\N	53.856577999999999	с. Майское, Центральная, 5		0101000020E6100000522CB7B41AE842408E3C1059A4ED4A40
3754	1	16	1223	23076	25465	\N	53.942560999999998	г. Липки, Советская, 17а		0101000020E6100000F10EF0A485D9424016BEBED6A5F84A40
3752	1	16	1223	23076	25465	\N	53.942560999999998	г. Липки, Советская, 40		0101000020E6100000F10EF0A485D9424016BEBED6A5F84A40
3753	1	16	1223	23076	75088	\N	53.942560999999998	г. Липки, Лермонтова, 23		0101000020E6100000F10EF0A485D9424016BEBED6A5F84A40
3751	1	16	1223	23076	25909	\N	53.942560999999998	г. Липки, Комсомольская, 2		0101000020E6100000F10EF0A485D9424016BEBED6A5F84A40
3775	1	16	1223	24183	75382	\N	53.830111000000002	Тульская обл, Киреевский, с. Кузнецово, Центральная, 14		0101000020E610000077BAF3C473F042406286C61341EA4A40
3778	1	16	1223	24358	\N	\N	54.011983000000001	д. Криволучье, 2		0101000020E61000005167EE21E1F54240D28DB0A888014B40
3783	1	16	1223	24626	26291	\N	54.173817	Киреевский район, пос. Красный Яр, ул. Школьная		0101000020E6100000FA9B508880F14240923EADA23F164B40
3782	1	16	1223	24626	75227	\N	54.173817	п. Красный Яр, Советская, 10		0101000020E6100000FA9B508880F14240923EADA23F164B40
3769	1	16	1223	40469	26921	\N	54.071097999999999	п. Красногвардейский, Красногвардейская, 3		0101000020E6100000CD57C9C7EEE04240CF6740BD19094B40
3755	1	16	1223	23258	26281	\N	53.952416999999997	Киреевский район, п. Комсомольский, ул. Школьная, д. 2		0101000020E6100000D82C978DCED54240C493DDCCE8F94A40
3742	1	16	1223	22107	25319	\N	53.932389000000001	г. Киреевск, Чехова, 15		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3741	1	16	1223	22107	25319	\N	53.921721871116198	г. Киреевск, Чехова, 13	Россия, Тульская область, Киреевский район, Киреевск	0101000020E6100000F607CA6DFBF642407A008BFCFAF54A40
3743	1	16	1223	22107	26508	\N	53.932389000000001	г. Киреевск, Толстого, 24		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3730	1	16	1223	22107	25411	\N	53.932389000000001	г. Киреевск, Тесакова, 2		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3729	1	16	1223	22107	25411	\N	53.932389000000001	г. Киреевск, Тесакова, 38		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3746	1	16	1223	22107	26274	\N	53.932389000000001	г. Киреевск, Октябрьская, 28		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3745	1	16	1223	22107	26274	\N	53.932389000000001	г. Киреевск, Октябрьская, 56		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3734	1	16	1223	22107	25976	\N	53.932389000000001	г. Киреевск, Мира, 10а		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3744	1	16	1223	22107	25362	\N	53.932389000000001	г. Киреевск, Ленина, 6		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3735	1	16	1223	22107	25362	\N	53.932389000000001	г. Киреевск, Ленина, 19		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3733	1	16	1223	22107	25362	\N	53.932389000000001	г. Киреевск, Ленина, 32		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3732	1	16	1223	22107	25417	\N	53.932389000000001	г. Киреевск, Комарова, 19а		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3731	1	16	1223	22107	25417	\N	53.932389000000001	г. Киреевск, Комарова, 17		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3747	1	16	1223	22107	26789	\N	53.932389000000001	г. Киреевск, ул. Торговая		0101000020E6100000427BF5F1D0F542403813D38558F74A40
3772	1	16	1223	24051	\N	\N	53.977936999999997	Киреевский район, с. Долгое	Россия, Тульская область, Киреевский район, поселок Долгое	0101000020E6100000BAC0E5B166E242403046240A2DFD4A40
3779	1	16	1223	21433	25307	\N	53.980649	Тульская обл, Киреевский, с. Дедилово, Советская, 62		0101000020E6100000711B0DE02DF8424074ED0BE885FD4A40
3780	1	16	1223	21433	26770	\N	53.980649	с. Дедилово, Грецова, 16		0101000020E6100000711B0DE02DF8424074ED0BE885FD4A40
3737	1	16	1223	22424	25316	\N	53.940223000000003	п. Головлинский, Победы, 24а		0101000020E61000001807978E39E1424038F92D3A59F84A40
3533	1	16	1223	12355	\N	\N	53.947949999999999	п. Васильевский	Россия, Тульская область, Киреевский район, поселок Васильевский	0101000020E6100000B75D68AED3E64240211FF46C56F94A40
3762	1	16	1223	21244	75091	\N	53.996541000000001	п. Бородинский, Пионерская, 8		0101000020E6100000E5B33C0FEEE84240C30FCEA78EFF4A40
3763	1	16	1223	21244	25519	\N	53.996541000000001	Тульская обл, Киреевский, п. Бородинский, Комсомольская, 13		0101000020E6100000E5B33C0FEEE84240C30FCEA78EFF4A40
3768	1	16	1223	23867	26797	\N	54.049463000000003	д. Большие Калмыки, Центральная, 13		0101000020E61000007E1CCD9195E9424058AEB7CD54064B40
3758	1	16	1223	23289	26378	\N	54.081986000000001	г. Болохово, Советская, 16		0101000020E61000004EB4AB90F2E942406C5D6A847E0A4B40
3756	1	16	1223	23289	75083	\N	54.081986000000001	Киреевский район, г. Болохово, ул. Первомайская, д. 4		0101000020E61000004EB4AB90F2E942406C5D6A847E0A4B40
3761	1	16	1223	23289	25323	\N	54.084206220473803	г. Болохово, Мира, 33	Россия, Тульская область, Киреевский район, Болохово	0101000020E61000005184D4EDECE9424041102043C70A4B40
3757	1	16	1223	23289	25323	\N	54.081986000000001	Киреевский район, г. Болохово, ул. Мира, д. 6		0101000020E61000004EB4AB90F2E942406C5D6A847E0A4B40
3701	1	16	153	51158	75237	\N	54.0132362796612	город Кимовск, пос.Шахтинский, Шахтная	Россия, Тульская область, Кимовский район, поселок Шахтерский	0101000020E6100000B284B531764C43409F909DB7B1014B40
3709	1	16	153	45887	\N	\N	53.800277999999999	с.Черемухово, 16а		0101000020E61000006C98A1F144684340A9DA6E826FE64A40
3725	1	16	153	21899	\N	\N	53.958371999999997	с.Хитровщина, 17		0101000020E6100000C16ED8B62865434078B306EFABFA4A40
3713	1	16	153	21339	\N	\N	53.812162000000001	д.Федосовка	Россия, Тульская область, Кимовский район, поселок Федосовка	0101000020E610000055C2137AFD4B4340E886A6ECF4E74A40
3718	1	16	153	46095	\N	\N	53.654024	д.Устье, 19а		0101000020E61000006C97361C966443404966F50EB7D34A40
3724	1	16	153	21198	\N	\N	53.849964999999997	Тульская обл, Кимовский, с.Таболо 16		0101000020E61000005645B8C9A862434050DF32A7CBEC4A40
3708	1	16	153	45869	\N	\N	53.712311999999997	с.Суханово, 67		0101000020E61000002AFEEF880A5D43403046240A2DDB4A40
84380	1	16	153	60539	\N	\N	53.751153048937297	пос.Совхозный	Россия, Тульская область, Кимовский район, поселок Совхозный	0101000020E6100000DAC9E028796343406AA510C825E04A40
3694	1	16	153	20345	25773	\N	54.035303999999996	пос.Пронь, Центральная, 12		0101000020E6100000914770236543434080B56AD784044B40
95189	1	16	153	22009	26708	\N	53.924999	Кимовский район, п.Новольвовск, Школьная, д.6		0101000020E6100000B282DF861865434096EA025E66F64A40
3720	1	16	153	46146	\N	\N	53.735284	с.Муравлянка, 46		0101000020E6100000E964A9F57E3F4340D3A23EC91DDE4A40
3695	1	16	153	20370	\N	\N	53.667943999999999	с.Монастырщино	Россия, Тульская область, Кимовский район, поселок Монастырщино	0101000020E61000001424B6BB075243409BC761307FD54A40
3719	1	16	153	46125	\N	\N	53.730187000000001	с.Молоденки, 56		0101000020E6100000469561DC0D744340707B82C476DD4A40
3795	1	16	153	60594	75394	\N	53.9161933029362	п.Михайловский, Центральная, 1	Россия, Тульская область, Кимовский район, поселок Михайловский	0101000020E61000005D6BEF53556443407DE9EDCF45F54A40
3641	1	16	153	60552	\N	\N	53.963583209032301	пос.Мирный	Россия, Тульская область, Кимовский район, поселок Мирный	0101000020E6100000632AFD84B34B4340A4FD0FB056FB4A40
3690	1	16	153	60552	75259	\N	53.966241139121898	город Кимовск, пос.Мирный, Кимовская, 9	Россия, Тульская область, Кимовский район, поселок Мирный	0101000020E6100000BE8575E3DD4B4340F486FBC8ADFB4A40
3722	1	16	153	21761	25998	\N	53.862912999999999	Тульская обл, Кимовский, с.Луговое, Молодежная 3		0101000020E61000002E3883BF5F4243408925E5EE73EE4A40
3692	1	16	153	45561	\N	\N	53.898082000000002	д.Кудашево, 31		0101000020E61000009CF86A47715A43402A90D959F4F24A40
3693	1	16	153	20230	\N	\N	53.924605999999997	д.Кропотово, 106		0101000020E6100000B77C24253D504340BAD7497D59F64A40
95188	1	16	153	19534	\N	\N	53.965322	г.Кимовск, п.Сельхозтехника АБЗ		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3707	1	16	153	19534	\N	\N	53.965322	город Кимовск, пос.Старый		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3698	1	16	153	19534	26384	\N	53.965322	город Кимовск, Шевченко, 3		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3682	1	16	153	19534	25512	\N	53.965322	город Кимовск, Толстого, 21		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3696	1	16	153	19534	25710	\N	53.965322	город Кимовск, Павлова, 19		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3681	1	16	153	19534	26244	\N	53.965322	город Кимовск, Октябрьская, 19		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3679	1	16	153	19534	26244	\N	53.965322	город Кимовск, Октябрьская, 16		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3680	1	16	153	19534	26243	\N	53.965322	город Кимовск, Маяковского, 37		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3688	1	16	153	19534	25310	\N	53.970167573504298	город Кимовск, Ленина, 35а	Россия, Тульская область, Кимовский район, Кимовск	0101000020E610000009185DDE1C46434018D00B772EFC4A40
3683	1	16	153	19534	26920	\N	53.965322	город Кимовск, Крылова, 6		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3686	1	16	153	19534	25447	\N	53.965322	город Кимовск, Коммунистическая, 20а		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3685	1	16	153	19534	25447	\N	53.965322	город Кимовск, Коммунистическая, 18		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3684	1	16	153	19534	25447	\N	53.965322	город Кимовск, Коммунистическая, 12		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3700	1	16	153	19534	26908	\N	53.965322	город Кимовск, Кирова, 5		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3697	1	16	153	19534	25371	\N	53.965322	город Кимовск, Больничная, 4		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
3699	1	16	153	19534	26775	\N	53.965322	город Кимовск, Бессолова, 65		0101000020E61000007D3ECA880B424340FE0DDAAB8FFB4A40
87786	1	16	153	60549	\N	\N	53.940847883248097	с. Каменка, 300	Россия, Тульская область, Кимовский район, поселок Каменка	0101000020E6100000CD1FD3DA34424340E6400FB56DF84A40
3726	1	16	153	46275	75410	\N	53.758889000000003	пос.Казановка, Центральная, 1		0101000020E610000021956247E3484340A725564623E14A40
3702	1	16	153	51157	\N	\N	53.994106000000002	Тульская обл, Кимовский, город Кимовск, пос. Зубовский, 50а	Россия, Тульская область, Кимовский район, поселок Зубовский	0101000020E61000003D44A33B88474340F2608BDD3EFF4A40
3721	1	16	153	46161	\N	\N	54.007221000000001	д.Зубовка, 50а		0101000020E6100000A60D87A581494340166C239EEC004B40
3728	1	16	153	22052	25313	\N	53.827097999999999	пос.Епифань, 50 лет Октября, 46		0101000020E610000066C1C41F45474340234BE658DEE94A40
3710	1	16	153	45917	\N	\N	53.983158000000003	с.Гранки, 80		0101000020E6100000D4635B069C3B43408066101FD8FD4A40
4026	1	16	153	47702	\N	\N	53.720443000000003	д. Горки, 51		0101000020E610000057B1F84D61434340EAD0E97937DC4A40
3717	1	16	153	60588	\N	\N	53.697576646407001	д.Вишневая, 7	Россия, Тульская область, Кимовский район, поселок Вишневая	0101000020E6100000F6798CF2CC5143408DB800344AD94A40
3689	1	16	153	20031	\N	\N	53.770311	с.Бучалки, 62		0101000020E610000058E1968FA45E4340E15F048D99E24A40
3925	1	16	153	45642	75371	\N	53.769655999999998	дер. Богдановка, Центральная, 20		0101000020E61000007313B534B74C4340C8957A1684E24A40
3458	1	16	153	45500	\N	\N	53.764254000000001	деревня Астапово	Россия, Тульская область, Кимовский район, поселок Астапово	0101000020E6100000E146CA164955434029EB3713D3E14A40
3715	1	16	153	21428	26227	\N	54.031405999999997	п.Апарки, Больничная, 4		0101000020E610000060CB2BD7DB5A4340F7729F1C05044B40
3645	1	16	827	49126	75362	\N	53.760145000000001	д.Александровка, ул.Школьная, 8		0101000020E6100000DA1EBDE13E144240E59B6D6E4CE14A40
3668	1	16	1565	47036	\N	\N	53.320318	с.Языково	Россия, Тульская область, Каменский район, поселок Языково	0101000020E6100000C993A46B26CB4240FA28232E00A94A40
3675	1	16	1565	19312	\N	\N	53.227305999999999	Каменский район, д.Яблонево	Россия, Тульская область, Каменский район, поселок Яблонево	0101000020E61000001475E61E12F44240A017EE5C189D4A40
4117	1	16	1565	46575	75405	\N	53.301110999999999	Чернский район, д. Соловьевка, ул. Центральная, д.1		0101000020E61000000C73823639EA4240A1BB24CE8AA64A40
3676	1	16	1565	19335	\N	\N	53.142409999999998	Каменский район, с.Соклаково	Россия, Тульская область, Каменский район, поселок Соклаково	0101000020E610000016C3D50110D74240CA4FAA7D3A924A40
3670	1	16	1565	19045	\N	\N	53.341925000000003	с.Ситово	Россия, Тульская область, Каменский район, поселок Ситово	0101000020E6100000F8F9EFC16BE94240A857CA32C4AB4A40
4041	1	16	1565	47989	\N	\N	53.283031000000001	д.Озерки, д.100		0101000020E6100000C58EC6A17EE3424089601C5C3AA44A40
3678	1	16	1565	19432	\N	\N	53.148800000000001	Каменский район, д.Новоселки	Россия, Тульская область, Каменский район, поселок Новоселки	0101000020E61000001135D1E7A3E2424089D2DEE00B934A40
3672	1	16	1565	47102	\N	\N	53.222929000000001	п.Новопетровский	Россия, Тульская область, Каменский район, поселок Новопетровский	0101000020E6100000A0A9D72D02E742403D2AFEEF889C4A40
3673	1	16	1565	47118	\N	\N	53.174542000000002	с.Каменское	Россия, Тульская область, Каменский район, поселок Каменское	0101000020E6100000402FDCB930E44240A4E36A6457964A40
3671	1	16	1565	19064	\N	\N	53.301476999999998	с.Кадное	Россия, Тульская область, Каменский район, поселок Кадное	0101000020E61000000A664CC11AF5424083BF5FCC96A64A40
3674	1	16	1565	19220	\N	\N	53.202976999999997	с.Закопы	Россия, Тульская область, Каменский район, поселок Закопы	0101000020E6100000C11F7EFE7BF642408B6B7C26FB994A40
3667	1	16	1565	18855	\N	\N	53.242462000000003	с.Долгие Лески	Россия, Тульская область, Каменский район, поселок Долгие Лески	0101000020E6100000A62A6D718DD14240EA42ACFE089F4A40
3677	1	16	1565	19403	\N	\N	53.126106	Каменский район, с.Галица	Россия, Тульская область, Каменский район, поселок Галица	0101000020E6100000A182C30B22EE424029EACC3D24904A40
3706	1	16	1565	45829	\N	\N	53.237757999999999	д.Барановка, 136	Россия, Тульская область, Каменский район, поселок Барановка	0101000020E610000086032159C0D44240622EA9DA6E9E4A40
3665	1	16	1565	60497	75082	\N	53.261455092068203	с. Архангельское, ул.Тихомирова, д.32	Россия, Тульская область, Каменский район, поселок Архангельское	0101000020E610000087A3AB7477D942401630815B77A14A40
3439	1	16	1565	49444	75265	\N	53.216549999999998	п. Авангард, Октябрьская, Авангардский СДК	Россия, Тульская область, Каменский район, поселок Авангард	0101000020E6100000B8239C16BCCA424072F90FE9B79B4A40
3657	1	16	1518	51246	\N	\N	54.828951403260497	п.Приокский, ж/д станция Приокская, служебное помещение	Россия, Тульская область, Заокский район, поселок Свинская	0101000020E61000001079CBD58FAF4240467EFD101B6A4B40
3647	1	16	1518	17825	75369	\N	54.631968000000001	д.Теряево-1, ул.Молодежная, 1А		0101000020E61000007520EBA9D5B942402C0FD253E4504B40
3656	1	16	1518	60518	75123	\N	54.824239843445397	"п.Сосновый, микрорайон ""В"", 4"	Россия, Тульская область	0101000020E6100000997E8978EBB842400C0742B280694B40
3659	1	16	1518	49312	26481	\N	54.531256999999997	д.Симоново, ул.238 Стрелковой дивизии, 11		0101000020E6100000177E703E75B44240B262B83A00444B40
3658	1	16	1518	18401	75258	\N	54.702131000000001	д.Русятино, ул.Болотова, 36		0101000020E6100000001E51A1BAC34240FF40B96DDF594B40
4080	1	16	1518	40360	\N	\N	54.790900637468702	д. Пашково, строение 55	Россия, Тульская область, Заокский район, поселок Пашково	0101000020E6100000F4328AE596AA4240D5AF743E3C654B40
3654	1	16	1518	49246	75163	\N	54.630268999999998	п.Пахомово, ул.Школьная, 13		0101000020E6100000D732198EE7C54240605793A7AC504B40
3653	1	16	1518	18129	25599	\N	54.578707999999999	с.Ненашево, ул.Кирова, 11А		0101000020E610000066C0594A96BB42407FF78E1A134A4B40
3723	1	16	1518	18943	\N	\N	54.675876000000002	д.Молчаново, 36	Россия, Тульская область, Заокский район, поселок Молчаново	0101000020E61000007C6308008ED742405E13D21A83564B40
3669	1	16	1518	18943	\N	\N	54.675876000000002	п.Молчаново	Россия, Тульская область, Заокский район, поселок Молчаново	0101000020E61000007C6308008ED742405E13D21A83564B40
3649	1	16	1518	17940	25354	\N	54.631827000000001	п.Миротинский, ул.Мира д.2	Россия, Тульская область, Заокский район, поселок Миротинский	0101000020E6100000D6E6FF5547DA42406ADD06B5DF504B40
3652	1	16	1518	60556	75274	\N	54.747995734836401	д.Малахово, ул.Мира, 1	Россия, Тульская область, Заокский район, поселок Малахово	0101000020E61000007A51BB5F05BA4240F8C43A55BE5F4B40
3651	1	16	1518	49207	25732	\N	54.830477000000002	п.Ланьшинский, ул.Школьная, 1		0101000020E6100000978DCEF929A24240448A01124D6A4B40
3662	1	16	1518	18613	26179	\N	54.734887000000001	р.п.Заокский, ул.Северная, 1		0101000020E61000007AC8940F41B34240B6A0F7C6105E4B40
3663	1	16	1518	18613	26355	\N	54.734887000000001	Заокский район, р.п. Заокский ул. Поленова, д.17,		0101000020E61000007AC8940F41B34240B6A0F7C6105E4B40
3664	1	16	1518	18613	26183	\N	54.734887000000001	р.п.Заокский, ул.Гагарина, 1		0101000020E61000007AC8940F41B34240B6A0F7C6105E4B40
3648	1	16	1518	49167	26256	\N	54.669091999999999	с.Дмитриевское, ул.Школьная, 1		0101000020E610000075E95F92CAD04240F30181CEA4554B40
3661	1	16	1518	51313	\N	\N	54.7037901910317	"с.п. Дом отдыха ""Велегож"", Дом Культуры"	Россия, Тульская область, Заокский район, поселок Велегож д.о.	0101000020E6100000CEE2C5C210A142403CA06CCA155A4B40
3646	1	16	1518	17805	26674	\N	54.706355000000002	п.Бутиково, ул.Новая, 6		0101000020E61000007BFA08FCE1AF4240DC2E34D7695A4B40
3644	1	16	328	60538	\N	\N	53.151759942798897	д.Ясеновая	Россия, Тульская область, Ефремовский район, поселок Ясеновая	0101000020E610000037548CF337054340A56B26DF6C934A40
85786	1	16	328	49558	\N	\N	53.067725000000003	д.Ярославка	Россия, Тульская область, Ефремовский район, поселок Ярославка	0101000020E6100000C82764E76D264340910F7A36AB884A40
85887	1	16	328	11333	\N	\N	53.027042999999999	д.Яндовка	Россия, Тульская область, Ефремовский район, поселок Яндовка	0101000020E61000008D5DA27A6B324340F94A202576834A40
86622	1	16	328	14919	\N	\N	53.057692000000003	д.Шкилевка	Россия, Тульская область, Ефремовский район, поселок Шкилевка	0101000020E61000005439ED2939094340D49E927362874A40
3637	1	16	328	48996	\N	\N	53.165193000000002	д.Чернятино	Россия, Тульская область, Ефремовский район, поселок Чернятино	0101000020E61000006E13EE95791543409A43520B25954A40
3640	1	16	328	17503	\N	\N	53.265143000000002	с.Тормасово	Россия, Тульская область, Ефремовский район, поселок Тормасово	0101000020E610000083143C855C294340B5E1B034F0A14A40
85652	1	16	328	40390	\N	\N	53.044257000000002	д.Сретенка	Россия, Тульская область, Ефремовский район, поселок Сретенка	0101000020E61000005726FC523F1F43403ECF9F36AA854A40
86235	1	16	328	40465	\N	\N	53.150430999999998	д.Покровка	Россия, Тульская область, Ефремовский район, поселок Покровка	0101000020E6100000C8B3CBB73E124340FCA6B05241934A40
84399	1	16	328	2846	\N	\N	53.120978000000001	с.Пожилино	Россия, Тульская область, Ефремовский район, поселок Пожилино	0101000020E6100000E2218C9FC6FB42408BC404357C8F4A40
3636	1	16	328	60569	\N	\N	53.322128999999997	с.Павло Хутор	Россия, Тульская область, Ефремовский район, поселок Павлов Хутор	0101000020E610000011ACAA97DF234340ED0BE8853BA94A40
14620	1	16	328	6853	\N	\N	53.168826000000003	с.Новокрасивое	Россия, Тульская область, Ефремовский район, поселок Новокрасивое	0101000020E6100000301004C8D0194340755B22179C954A40
86584	1	16	328	47477	\N	\N	52.993130999999998	д.Николаевка	Россия, Тульская область, Ефремовский район, поселок Николаевка	0101000020E6100000B709F7CABC29434067D2A6EA1E7F4A40
86946	1	16	328	45453	\N	\N	53.049703000000001	д.Мордовка	Россия, Тульская область, Ефремовский район, поселок Мордовка	0101000020E61000002DAF5C6F9B4B4340ADC1FBAA5C864A40
86636	1	16	328	15599	\N	\N	53.144424999999998	с.Мечнянка	Россия, Тульская область, Ефремовский район, поселок Мечнянка	0101000020E61000000B08AD872F494340C6DCB5847C924A40
84431	1	16	328	60574	\N	\N	53.204087350507599	с.Малая Хмелевая	Россия, Тульская область, Ефремовский район, поселок Малая Хмелевская	0101000020E61000001E6FF25B74004340F644D7851F9A4A40
84528	1	16	328	9350	\N	\N	53.167126000000003	д.Кытино	Россия, Тульская область, Ефремовский район, поселок Кытино	0101000020E61000007C2766BD18284340D927806264954A40
85834	1	16	328	46238	\N	\N	53.055359000000003	д.Круглики	Россия, Тульская область, Ефремовский район, поселок Круглики	0101000020E6100000DFA9807B9E1343400745F30016874A40
84376	1	16	328	1527	\N	\N	53.317385999999999	пос.Кременный	Россия, Тульская область, Ефремовский район, поселок Кременный	0101000020E610000004543882540C4340A81ABD1AA0A84A40
85942	1	16	328	13958	\N	\N	53.159188999999998	пос.Красина	Россия, Тульская область, Ефремовский район, поселок Красина	0101000020E6100000B115342DB118434004711E4E60944A40
3643	1	16	328	49101	\N	\N	53.059688999999999	д.Кочкино	Россия, Тульская область, Ефремовский район, поселок Кочкино	0101000020E61000005E48878730F2424029779FE3A3874A40
84498	1	16	328	7954	\N	\N	53.179189000000001	пос.Козьминский	Россия, Тульская область, Ефремовский район, поселок Козьминский	0101000020E6100000392861A6ED394340C76647AAEF964A40
84452	1	16	328	5726	\N	\N	53.258588000000003	с.Козье	Россия, Тульская область, Ефремовский район, поселок Козье	0101000020E61000003EAF78EA913A4340AC915D6919A14A40
86313	1	16	328	31803	\N	\N	53.110070999999998	д.Иноземка	Россия, Тульская область, Ефремовский район, поселок Иноземка	0101000020E61000006F0D6C95600F4340779E78CE168E4A40
3618	1	16	328	16197	25730	\N	53.149166999999998	г. Ефремов, ул. Тургенева, д.36		0101000020E6100000F1113125920A43403B527DE717934A40
3632	1	16	328	16197	25557	\N	53.149166999999998	г. Ефремов, ул. Тульское шоссе, д.14		0101000020E6100000F1113125920A43403B527DE717934A40
3631	1	16	328	16197	25493	\N	53.149166999999998	г. Ефремов, ул. Строителей, д.57		0101000020E6100000F1113125920A43403B527DE717934A40
3616	1	16	328	16197	25334	\N	53.149166999999998	г. Ефремов, ул. Словацкого восстания, д.16		0101000020E6100000F1113125920A43403B527DE717934A40
3623	1	16	328	16197	25977	\N	53.149166999999998	г. Ефремов, ул. Свердлова, д.55 А		0101000020E6100000F1113125920A43403B527DE717934A40
3627	1	16	328	16197	25435	\N	53.149166999999998	г. Ефремов, ул. Пионерская, д.4		0101000020E6100000F1113125920A43403B527DE717934A40
3614	1	16	328	16197	25333	\N	53.149166999999998	Тульская обл, Ефремовский, г.Ефремов, ул.Московская застава 17		0101000020E6100000F1113125920A43403B527DE717934A40
3634	1	16	328	16197	25349	\N	53.149166999999998	г. Ефремов, ул. Молодежная,  д.1_а		0101000020E6100000F1113125920A43403B527DE717934A40
3626	1	16	328	16197	26138	\N	53.149166999999998	г. Ефремов, ул. Мира, д.2 а		0101000020E6100000F1113125920A43403B527DE717934A40
3615	1	16	328	16197	25299	\N	53.149166999999998	г. Ефремов, ул. Ломоносова 48		0101000020E6100000F1113125920A43403B527DE717934A40
3628	1	16	328	16197	25345	\N	53.149166999999998	г. Ефремов, ул. Ленинградская, д.101	Россия, Тульская область, Ефремовский район, Ефремов	0101000020E6100000F1113125920A43403B527DE717934A40
3620	1	16	328	16197	26224	\N	53.149166999999998	г. Ефремов, ул. Ленина, д. 38		0101000020E6100000F1113125920A43403B527DE717934A40
3619	1	16	328	16197	26224	\N	53.149166999999998	г. Ефремов, ул. Ленина, д.38		0101000020E6100000F1113125920A43403B527DE717934A40
3624	1	16	328	16197	26129	\N	53.149166999999998	г. Ефремов, ул. Красноармейская, д.41		0101000020E6100000F1113125920A43403B527DE717934A40
3621	1	16	328	16197	26129	\N	53.149166999999998	г. Ефремов, ул. Красноармейская, д.68		0101000020E6100000F1113125920A43403B527DE717934A40
3622	1	16	328	16197	25338	\N	53.149166999999998	г. Ефремов, ул. Комсомольская, д.126		0101000020E6100000F1113125920A43403B527DE717934A40
3617	1	16	328	16197	25301	\N	53.149166999999998	г. Ефремов, ул. Карла Маркса, д. 41		0101000020E6100000F1113125920A43403B527DE717934A40
3629	1	16	328	16197	26145	\N	53.149166999999998	г. Ефремов, ул. Интернациональная, д.4_а		0101000020E6100000F1113125920A43403B527DE717934A40
3630	1	16	328	16197	25346	\N	53.149166999999998	г. Ефремов, ул. Дружбы, д.7		0101000020E6100000F1113125920A43403B527DE717934A40
3885	1	16	328	60542	\N	\N	53.116987120698603	п. 10-й Октябрь, 1	Россия, Тульская область, Ефремовский район, поселок Двенадцатый Октябрь	0101000020E6100000043A9336552143405187156EF98E4A40
3635	1	16	328	17234	\N	\N	53.304516999999997	д.Большие Плоты	Россия, Тульская область, Ефремовский район, поселок Большие Плоты	0101000020E6100000AAF1D24D62184340BB09BE69FAA64A40
3424	1	16	328	7190	\N	\N	53.238606189317103	д.Большие Медведки	Россия, Тульская область, Ефремовский район, поселок Большие Медведки	0101000020E6100000466117450FFE42408F5033A48A9E4A40
2461	1	16	1415	24415	\N	\N	54.083728999999998	с.Скоморошки, Молодежная, 9	Россия, Тульская область, Дубенский район, поселок Скоморошки	0101000020E6100000BC783F6EBF784240075DC2A1B70A4B40
3611	1	16	1415	16026	25332	\N	54.176557000000003	Дубенский район, с. Протасово, ул. Дружбы, д. 14		0101000020E6100000E675C4211B7E4240A070766B99164B40
2606	1	16	1415	60603	75431	\N	54.184275948511498	с.п.Поречье, Мира, 1	Россия, Тульская область, Дубенский район, поселок Поречье	0101000020E61000001EDFDE35E887424006B8205B96174B40
87227	1	16	1415	40670	\N	\N	54.105604999999997	пос.Первомайский	Россия, Тульская область, Дубенский район, поселок Первомайский	0101000020E6100000EBFCDB65BF8E4240A4A5F276840D4B40
299	1	16	1415	40670	\N	\N	54.105604999999997	поселок Первомайский		0101000020E6100000EBFCDB65BF8E4240A4A5F276840D4B40
3878	1	16	1415	40670	67871	\N	54.105604999999997	р.п. Первомайский, пр. Улитина, 16а		0101000020E6100000EBFCDB65BF8E4240A4A5F276840D4B40
3941	1	16	1415	40670	75296	\N	54.105604999999997	пос. Первомайский, Школьная, 5		0101000020E6100000EBFCDB65BF8E4240A4A5F276840D4B40
4151	1	16	1415	40670	75188	\N	54.105604999999997	р.п. Первомайский, пр. Улитина, 23/2		0101000020E6100000EBFCDB65BF8E4240A4A5F276840D4B40
2475	1	16	1415	25049	\N	\N	54.161999000000002	с.Опочня, Урожайная, 11	Россия, Тульская область, Дубенский район, поселок Опочня	0101000020E610000067F0F78BD98A42400B7E1B62BC144B40
3612	1	16	1415	16106	25533	\N	54.257291000000002	с.Новое Павшино, Центральная, 11		0101000020E61000000266BE839F9042400F4757E9EE204B40
2899	1	16	1415	60572	75323	\N	54.201226124053498	д.Надеждино, Дружбы, 21	Россия, Тульская область, Дубенский район, поселок Надеждино	0101000020E61000007A7077D66E6D42406D8D08C6C1194B40
3609	1	16	1415	48502	26182	\N	54.080148000000001	с.Лужное, им.Чирикова А.И, 1		0101000020E610000031D28BDAFD8842407F6B274A420A4B40
3253	1	16	1415	30558	26148	\N	54.246854999999996	д.Лобжа, Центральная, 40/2		0101000020E61000005DF92CCF836D424052EDD3F1981F4B40
3558	1	16	1415	47564	\N	\N	54.113326874568202	д. Красавка, д. 72	Россия, Тульская область, Дубенский район, поселок Красавка	0101000020E610000062BD512B4C9D42407C60C77F810E4B40
3605	1	16	1415	15723	75111	\N	54.157090863998498	п.Дубна, Фрунзе, 2а	Россия, Тульская область, Дубенский район, поселок Дубна	0101000020E610000082A8FB00A47A42407BBFD18E1B144B40
3607	1	16	1415	15723	26601	\N	54.155683000000003	п.Дубна, Красноармейская, 85	Россия, Тульская область, Дубенский район, поселок Дубна	0101000020E610000060E811A3E77A424087C5A86BED134B40
3610	1	16	1415	16007	26723	\N	54.120019999999997	Дубенский район, п. Гвардейский, ул. Молодежная, 12		0101000020E61000002DCE18E604794240D66EBBD05C0F4B40
3773	1	16	1415	16007	75345	\N	54.120019999999997	п. Гвардейский, Ленина, 5		0101000020E61000002DCE18E604794240D66EBBD05C0F4B40
2830	1	16	1415	46787	26801	\N	54.220984000000001	д.Бабошино, Дружбы, 6		0101000020E610000046240A2DEB9042403A782634491C4B40
3555	1	16	1270	13355	25823	\N	53.478121000000002	Воловский район, п. Ялта, ул. Школьная, д.99		0101000020E610000044A67C08AA044340F243A51133BD4A40
3571	1	16	1270	13903	75254	\N	53.449666000000001	д. Турдей, ул. Центральная, д. 10		0101000020E6100000593332C85D1A4340C30FCEA78EB94A40
3566	1	16	1270	13903	26279	\N	53.449666000000001	д. Турдей, ул. Железнодорожная, д.13		0101000020E6100000593332C85D1A4340C30FCEA78EB94A40
3560	1	16	1270	40344	\N	\N	53.447836889450798	д. Сухие Плоты, д. 69		0101000020E61000008997A7734513434029780AB952B94A40
1928	1	16	1270	47154	\N	\N	53.506487	д. Становая, д. 100		0101000020E6100000083BC5AA41FC4240B16CE690D4C04A40
3556	1	16	1270	60526	75173	\N	53.5404102429316	п. Садовый, ул. Садовская, д. 31	Россия, Тульская область, Воловский район, поселок Садовый	0101000020E61000005E13D21A83FE42403737A6272CC54A40
3562	1	16	1270	60580	75355	\N	53.563668895745899	п. Победа, ул. Центральная, д. 14	Россия, Тульская область, Воловский район, поселок Победа	0101000020E61000004AEF1B5F7BF442406F62484E26C84A40
3553	1	16	1270	47473	26747	\N	53.484363000000002	д. Панарино, ул. Административная, д. 1		0101000020E61000002E910BCEE0EB42403C32569BFFBD4A40
3567	1	16	1270	47721	26533	\N	53.543501999999997	с. Никитское, ул. Антонова, д.16		0101000020E61000004E9B711AA2144340C1A7397991C54A40
3568	1	16	1270	13998	75418	\N	53.544454999999999	с. Непрядва, ул. Главная, д. 152 а		0101000020E61000008C497F2F85234340649291B3B0C54A40
3569	1	16	1270	47752	75367	\N	53.581367999999998	д. Красный Холм, ул. Центральная, д. 10		0101000020E6100000E0D5726726104340707841446ACA4A40
3572	1	16	1270	14198	26351	\N	53.391990999999997	д. Красная Дубровка, ул. Школьная, д. 5		0101000020E6100000D905836BEEF24240C5A9D6C22CB24A40
3570	1	16	1270	14105	26078	\N	53.363729999999997	п. Казачка, ул. Молодежная, д. 8		0101000020E6100000817A336ABE0843407B4963B48EAE4A40
3554	1	16	1270	13347	75366	\N	53.537081000000001	с. Истленьево, ул. Школьная, д. 14		0101000020E61000003541D47D00EE4240C826F911BFC44A40
3559	1	16	1270	47587	26791	\N	53.393655000000003	п. Горный, ул. Весенняя, д. 6		0101000020E6100000815CE2C8030B434015747B4963B24A40
3563	1	16	1270	47640	26538	\N	53.560803	п. Волово, ул. имени Хрунова, д. 4		0101000020E6100000F48B12F417004340D53F8864C8C74A40
3564	1	16	1270	47640	25828	\N	53.560803	п. Волово, ул. имени Ленина, д. 50		0101000020E6100000F48B12F417004340D53F8864C8C74A40
3561	1	16	1270	13640	25498	\N	53.606057999999997	с. Верхоупье, ул. Школьная, д. 25		0101000020E61000002ECBD765F8F5424055BDFC4E93CD4A40
3557	1	16	1270	47546	\N	\N	53.409889999999997	с. Борятино, д. 31		0101000020E6100000EEEBC039231443408D7A884677B44A40
133	1	16	1270	40532	\N	\N	53.492624999999997	село Белый Колодезь	Россия, Тульская область, Воловский район, поселок Белый Колодезь	0101000020E61000007FA2B2614D1B4340931804560EBF4A40
3552	1	16	1270	13252	26504	\N	53.473699000000003	Воловский район, д. Баскаково, ул. Школьная, д.9		0101000020E61000005B5CE333D9F54240EF92382BA2BC4A40
4042	1	16	1270	47995	75316	\N	53.593645000000002	д.Алексеевка, д.4		0101000020E610000054E41071730C43408B37328FFCCB4A40
3537	1	16	777	12541	25672	\N	54.460828999999997	д. Тулубьево, ул. Молоддежная, д. 1а		0101000020E6100000448655BC912543403106D671FC3A4B40
4049	1	16	777	5483	26361	\N	54.290752470199202	п.Теплое, ул.Школьная, д.45	Россия, Тульская область, Веневский район, поселок Теплое	0101000020E6100000C77F8120403E4340909F8D5C37254B40
4046	1	16	777	5483	26188	\N	54.289698000000001	п.Теплое, ул.Привокзальная, д.13		0101000020E6100000DB368C82E03D4340BADBF5D214254B40
4050	1	16	777	5483	26283	\N	54.290685291961204	п.Теплое, ул.Комсомольская, д.28	Россия, Тульская область, Веневский район, поселок Теплое	0101000020E6100000FF5C34643C3E43400938842A35254B40
3536	1	16	777	12518	25311	\N	54.439276999999997	Веневский район, с. Студенец, ул. Центральная, д. 10		0101000020E61000003A950C00550E434047718E3A3A384B40
3543	1	16	777	12822	26161	\N	54.66892	Веневский район, д. Сетка, ул. Библиотечная, д. 24		0101000020E610000067F1626188164340F6D1A92B9F554B40
3535	1	16	777	45745	75453	\N	54.306139000000002	п. Рассвет, ул. Центральная, д. 5		0101000020E610000098689082A7124340DC8310902F274B40
3547	1	16	777	47353	25315	\N	54.394875999999996	с. Прудищи, ул. Молодежная, д. 47		0101000020E6100000A2444B1E4F374340D6FCF84B8B324B40
3546	1	16	777	12963	26778	\N	54.329425999999998	Веневский район, с. Поветкино, ул. Центральная, д. 54		0101000020E61000004D486B0C3A2F4340DE3994A12A2A4B40
3548	1	16	777	60565	75302	\N	54.266962999999997	д. Островки, ул. Клубная, д. 20а	Россия, Тульская область, Веневский район, поселок Островки	0101000020E6100000F35487DC0C3D4340FB1EF5D72B224B40
3542	1	16	777	12790	25583	\N	54.573436999999998	п. Оленьковский, ул. Дорожная, д. 19		0101000020E6100000F226BF45270D43407EA8346266494B40
3545	1	16	777	60557	75282	\N	54.365997999999998	Веневский район, сл. Озеренская, ул. Новая, д. 11	Россия, Тульская область, Веневский район, слобода Озеренская	0101000020E6100000E4654D2CF02343406133C005D92E4B40
3541	1	16	777	12742	26344	\N	54.577451000000003	Веневский район, п. Мордвес, ул. Советская,  д. 11		0101000020E6100000FACF9A1F7F1B4340710514EAE9494B40
3534	1	16	777	12435	26420	\N	54.406154999999998	п. Метростроевский, ул. Горная, д. 7		0101000020E6100000BEC0AC50A4194340AE0D15E3FC334B40
3540	1	16	777	60621	75474	\N	54.619677000000003	с. Козловка, ул. Липовая, д. 2		0101000020E61000008EACFC32182F4340AD8A7093514F4B40
3539	1	16	777	47181	26056	\N	54.561328000000003	д. Дьяконово, ул. Барская слобода, д. 2		0101000020E61000001FBE4C1421294340202A8D98D9474B40
3529	1	16	777	12170	26410	\N	54.139693000000001	п. Грицовский, ул. Школьная, д. 4а, Грицовский дом культуры		0101000020E6100000965AEF37DA134340753DD175E1114B40
3530	1	16	777	12170	25984	\N	54.139693000000001	п. Грицовский, ул. Первомайская, д. 21, Грицовская средняя школа		0101000020E6100000965AEF37DA134340753DD175E1114B40
3544	1	16	777	12883	26488	\N	54.288758000000001	с. Гати, ул. Воронковка, д. 15		0101000020E610000076FA415DA4264340AC3AAB05F6244B40
3524	1	16	777	11854	\N	\N	54.353166000000002	"г. Венев, микрорайон ""Южный"", д. 25, Веневская средняя школа №2"		0101000020E610000059C2DA183B2143409207228B342D4B40
3525	1	16	777	11854	25306	\N	54.353166000000002	"г.  Венев, микрорайон ""Южный"", д. 19"		0101000020E610000059C2DA183B2143409207228B342D4B40
3523	1	16	777	11854	25306	\N	54.3545196363089	"г. Венев, микрорайон ""Южный"", д. 44, клуб школьника ""Родничок"""	Россия, Тульская область, Веневский район, Венев	0101000020E61000004565C39ACA20434093E34EE9602D4B40
3527	1	16	777	11854	25739	\N	54.354118563268798	"г. Венев, ул. Л. Толстого, д. 16, МУК ""МКДЦ"""	Россия, Тульская область, Веневский район, Венев	0101000020E61000008EAF3DB32422434034F279C5532D4B40
3526	1	16	777	11854	26299	\N	54.354068428862298	г. Венев, ул. Бундурина, д. 13, Веневская средняя школа №1	Россия, Тульская область, Веневский район, Венев	0101000020E6100000C0417BF5F1204340B247A819522D4B40
3549	1	16	777	13068	26405	\N	54.175176	п. Бельковский, ул. Дружбы, д. 2		0101000020E61000009B20EA3E000B4340A585CB2A6C164B40
3532	1	16	777	12332	25989	\N	54.313997000000001	д. Анишино, ул. Новая, д. 14		0101000020E61000006F0D6C9560F942406405BF0D31284B40
3538	1	16	777	47153	25760	\N	54.504708000000001	с. Аксиньино, ул. Центральная, д. 6		0101000020E61000004FE78A52422C4340C90391459A404B40
3510	1	16	1094	60601	75422	\N	53.7716010518388	х.Шахтерский, 26	Россия, Тульская область, Богородицкий район, поселок Шахтерский	0101000020E610000028F38FBE49154340CB4752D2C3E24A40
3516	1	16	1094	46703	\N	\N	53.712802000000003	с.Черняевка, 130		0101000020E6100000A3B1F677B6F54240FF428F183DDB4A40
3514	1	16	1094	40444	25328	\N	53.794055	д.Упертовка, Липки, 5		0101000020E6100000BB270F0BB5124340D61C2098A3E54A40
3498	1	16	1094	10733	25587	\N	53.682969999999997	Богородицкий район, пос.Товарковский, ул.Трудовая		0101000020E6100000A0C552245F19434016139B8F6BD74A40
3500	1	16	1094	10733	26377	\N	53.682969999999997	пос.Товарковский, Советская, 6		0101000020E6100000A0C552245F19434016139B8F6BD74A40
3501	1	16	1094	10733	25697	\N	53.682969999999997	пос.Товарковский, Кирова, 3		0101000020E6100000A0C552245F19434016139B8F6BD74A40
3499	1	16	1094	10733	25289	\N	53.682969999999997	Богородицкий район, пос.Товарковский, ул.Воровского	Россия, Тульская область, Богородицкий район, поселок Товарковский	0101000020E6100000A0C552245F19434016139B8F6BD74A40
3519	1	16	1094	46776	26084	\N	53.705655	с.Товарково, слоб.1-ое общество, 73		0101000020E61000004818062CB912434023A12DE752DA4A40
3932	1	16	1094	60531	75196	\N	53.748521301246903	село Спасское, Центральная, 5-в	Россия, Тульская область, Богородицкий район, поселок Спасское	0101000020E6100000DD4257225023434042AF3F89CFDF4A40
3512	1	16	1094	11377	25943	\N	53.836530000000003	пос.Романцевский, Школьная, 6		0101000020E6100000A032FE7DC6294340BB0F406A13EB4A40
3990	1	16	1094	60567	75307	\N	53.7556023099839	п. Пригородный, Садовая, 1	Россия, Тульская область, Богородицкий район, поселок Пригородный	0101000020E6100000FAF19716F50D43406765FB90B7E04A40
3506	1	16	1094	46494	26082	\N	53.631416999999999	с.Папоротка, Центральная, 57		0101000020E61000001557957D572C4340B891B245D2D04A40
3517	1	16	1094	46717	75249	\N	53.797871341629502	с.Новопокровское, Восточная, 1а	Россия, Тульская область, Богородицкий район, поселок Новопокровское	0101000020E6100000663387A416084340A2B60DA320E64A40
3505	1	16	1094	51155	25295	\N	53.612116	с.Малевка, слоб.Бригада 3, 123	Россия, Тульская область, Богородицкий район, поселок Малевка	0101000020E6100000D7A6B1BD161C4340DEAD2CD159CE4A40
3522	1	16	1094	60596	75432	\N	53.702568999999997	с.Ломовка, слоб.Церковенка, 22		0101000020E61000002D93E1783E0943407A17EFC7EDD94A40
3520	1	16	1094	11761	\N	\N	53.670782000000003	с.Левинка, 169		0101000020E6100000CF83BBB3761943406C5F402FDCD54A40
3521	1	16	1094	46806	\N	\N	53.650196999999999	с.Кузовка, слоб.Поповка, 70б	Россия, Тульская область, Богородицкий район, поселок Кузовка	0101000020E61000009F58A7CAF70E4340897AC1A739D34A40
3511	1	16	1094	46621	\N	\N	53.820400999999997	д.Колодези, 2а		0101000020E6100000725303CDE7204340874D64E602E94A40
3513	1	16	1094	51232	\N	\N	53.816344935088097	х.Кобловский, 8а	Россия, Тульская область, Богородицкий район, поселок Кобловский	0101000020E61000004B77D7D99019434066A032FE7DE84A40
3503	1	16	1094	10929	25290	\N	53.636547999999998	пос.Кичевский, Лесная, 6		0101000020E61000004A7B832F4C444340C72AA5677AD14A40
3515	1	16	1094	46684	25327	\N	53.760071000000003	с.Иевлево, слоб.Бодаево, 181	Россия, Тульская область, Богородицкий район, поселок Иевлево	0101000020E61000000B96EA025E004340ABD1AB014AE14A40
4032	1	16	1094	47805	\N	\N	53.644801000000001	с. Доброе, 1		0101000020E61000008FC536A968404340CCB6D3D688D24A40
3504	1	16	1094	46465	26550	\N	53.707194999999999	с.Гагарино, Школьная, 6а		0101000020E6100000E1EEACDD763143408672A25D85DA4A40
3479	1	16	1094	9692	\N	\N	53.773052	г.Богородицк, Совхоз-техникум, уч.корп.№2		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3495	1	16	1094	9692	25457	\N	53.773052	г.Богородицк, микрорайон Жданковс­кий, пер.Школьный, д.2а,		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3491	1	16	1094	9692	26824	\N	53.773052	г.Богородицк, Центральная, 63		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3485	1	16	1094	9692	26702	\N	53.773052	г.Богородицк, Ф.Энгельса, 36		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3483	1	16	1094	9692	25937	\N	53.773052	г.Богородицк, Урицкого, 60		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3481	1	16	1094	9692	26386	\N	53.773052	г.Богородицк, Пролетарская, 68		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3493	1	16	1094	9692	26197	\N	53.773052	г.Богородицк, Макаренко, 16		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3484	1	16	1094	9692	75250	\N	53.773052	г.Богородицк, МКР Лесной, 47		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3482	1	16	1094	9692	26474	\N	53.773052	г.Богородицк, Ленина, 26а		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3492	1	16	1094	9692	26314	\N	53.773052	г.Богородицк, Л.Толстого, 5		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3480	1	16	1094	9692	25751	\N	53.773052	г.Богородицк, Коммунаров, 91		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3478	1	16	1094	9692	25751	\N	53.773052	г.Богородицк, ул.Коммунаров, д.157		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3496	1	16	1094	9692	25954	\N	53.773052	г.Богородицк, МКР Жданковский, ул.Клубная, 7		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3489	1	16	1094	9692	26277	\N	53.773052	г.Богородицк, Кирпичная, 14		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3486	1	16	1094	9692	26705	\N	53.773052	г.Богородицк, Западный МКР, 4а		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3490	1	16	1094	9692	25942	\N	53.773052	г.Богородицк, Воронежская, 3		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3494	1	16	1094	9692	26199	\N	53.773052	г.Богородицк, Вересаева, 4		0101000020E610000020F0C000C20F4340BF0D315EF3E24A40
3507	1	16	1094	11118	26514	\N	53.796933000000003	пос.Бегичевский, Победы, 4		0101000020E6100000C24D469561204340350D8AE601E64A40
3508	1	16	1094	11118	26238	\N	53.796933000000003	пос.Бегичевский, МКР Красницкий, Луговая, 2		0101000020E6100000C24D469561204340350D8AE601E64A40
3502	1	16	1094	46415	25849	\N	53.669128999999998	с.Бахметьево, Центральная, 2		0101000020E6100000AF9465886335434010E7E104A6D54A40
3518	1	16	1094	11648	\N	\N	53.848669436166396	х.Александринский	Россия, Тульская область, Богородицкий район, поселок Александринский	0101000020E61000006D3CD862B70943408410902FA1EC4A40
1422	1	16	827	5958	11651	\N	53.735391	д.Фединское, Ленина, 6		0101000020E6100000A6BA809719184240E962D34A21DE4A40
1143	1	16	827	40915	11390	\N	53.692152	д.Таратухино, Центральная, 29	Россия, Тульская область, Белевский район, поселок Таратухино	0101000020E61000005E4C33DDEB16424035EECD6F98D84A40
3462	1	16	827	60629	75482	\N	53.763424000000001	д.Слобода, Садовая, 1А		0101000020E610000011C8258E3CFE4140A27DACE0B7E14A40
3461	1	16	827	8950	25309	\N	53.775829000000002	п.Ровно, Школьный переулок, 1		0101000020E61000004A60730E9E054240EA245B5D4EE34A40
941	1	16	827	14407	\N	\N	53.613660000000003	д.Новые Дольцы	Россия, Тульская область, Белевский район, поселок Новые Дольцы	0101000020E6100000B685E7A5620F4240836E2F698CCE4A40
3468	1	16	827	9241	25420	\N	53.708148999999999	д.Кожурово, Центральная, 4		0101000020E61000009AEAC9FCA31F4240F9D85DA0A4DA4A40
3711	1	16	827	45942	\N	\N	53.904114	с.Иваньково, 84		0101000020E610000024624A24D107424089EDEE01BAF34A40
4188	1	16	827	45942	75289	\N	53.905229089875903	с.Иваньково, ул.Центральная, д.82	Россия, Тульская область, Белевский район, поселок Иваньково	0101000020E61000001213D4F02D08424005323B8BDEF34A40
3465	1	16	827	45632	\N	\N	53.921906999999997	д.Иваново, 100	Россия, Тульская область, Белевский район, поселок Иваново	0101000020E610000030F65E7CD11442400B7A6F0C01F64A40
3466	1	16	827	60550	75242	\N	53.833007124376401	с.Жуково, Школьный переулок, 3	Россия, Тульская область, Белевский район, поселок Жуково	0101000020E610000006465ED6C4164240672B2FF99FEA4A40
3606	1	16	827	48431	26046	\N	53.776733999999998	п.Дубна, Первомайская, 89а		0101000020E6100000AD6BB41CE8F741407BD80B056CE34A40
3464	1	16	827	45627	\N	\N	53.900820000000003	д.Давыдово	Россия, Тульская область, Белевский район, поселок Давыдово	0101000020E6100000696E85B01A11424097CADB114EF34A40
3470	1	16	827	9321	25341	\N	53.57253	д.Будоговищи, Центральная, 129		0101000020E61000002E1EDE73602742404CFDBCA948C94A40
1629	1	16	827	60631	75485	\N	53.802866999999999	с.Болото, Рабочая, 1	Россия, Тульская область, Белевский район, поселок Болото	0101000020E6100000618C48145A284240D1048A58C4E64A40
1104	1	16	827	40913	11335	\N	53.667534810056502	п.Бобрики, Садовая, 33	Россия, Тульская область, Белевский район, поселок Бобрики	0101000020E610000041D653ABAF164240BAF770C971D54A40
94875	1	16	827	49679	26713	\N	53.643461000000002	Белевский район, деревня Беляево ул.Садовая д.54		0101000020E6100000AF264F594D21424030A017EE5CD24A40
3471	1	16	827	9387	26539	\N	53.808695	г.Белев, Фрунзе, 37		0101000020E61000008869DFDC5F11424028B8585183E74A40
3477	1	16	827	9387	25546	\N	53.808695	г.Белев, Советская, 91А		0101000020E61000008869DFDC5F11424028B8585183E74A40
3474	1	16	827	9387	25546	\N	53.808695	г.Белев, Советская, 32		0101000020E61000008869DFDC5F11424028B8585183E74A40
3473	1	16	827	9387	25546	\N	53.808695	г.Белев, Советская, 43		0101000020E61000008869DFDC5F11424028B8585183E74A40
3476	1	16	827	9387	25926	\N	53.808695	г.Белев, Пушкина, 25		0101000020E61000008869DFDC5F11424028B8585183E74A40
3475	1	16	827	9387	25781	\N	53.808695	г.Белев, Карла Маркса, 84		0101000020E61000008869DFDC5F11424028B8585183E74A40
3472	1	16	827	9387	25781	\N	53.808695	г.Белев, Карла Маркса, 108		0101000020E61000008869DFDC5F11424028B8585183E74A40
3467	1	16	827	45675	\N	\N	53.748742	д.Астафьево, 60А	Россия, Тульская область, Белевский район, поселок Астафьево	0101000020E6100000C0417BF5F1284240219221C7D6DF4A40
14734	5	43	195	12281	70753	\N	50.786169000000001	с.Шашикман, Победы, 12		0101000020E610000035F10EF0A48355408410902FA1644940
4009	1	16	453	47380	75175	\N	53.762365000000003	"пос. Центральный, Ленина, 29""А"""		0101000020E6100000BD72BD6DA6364240BA4E232D95E14A40
929	1	16	453	60612	\N	\N	53.547710000000002	поселок Славный	Россия, Тульская область, Арсеньевский район	0101000020E6100000D6E59480983C424099D87C5C1BC64A40
3459	1	16	453	8857	\N	\N	53.761443999999997	деревня Рахлеево	Россия, Тульская область, Арсеньевский район, поселок Рахлеево	0101000020E6100000C1A8A44E4049424022DE3AFF76E14A40
239	1	16	453	40620	\N	\N	53.647530945835499	село Мокрое	Россия, Тульская область, Арсеньевский район, поселок Мокрое	0101000020E6100000583A1F9E256A4240B612BA4BE2D24A40
667	1	16	453	40873	\N	\N	53.591033245554101	село Меркулово	Россия, Тульская область, Арсеньевский район, поселок Меркулово	0101000020E610000093C83EC8B2584240ABED26F8A6CB4A40
701	1	16	453	40877	\N	\N	53.711827	село Манаенки		0101000020E61000006118B0E42A3A424074B4AA251DDB4A40
680	1	16	453	40876	\N	\N	53.670540778921797	село Кузьменки	Россия, Тульская область, Арсеньевский район, поселок Кузьменки	0101000020E6100000B79BE09BA635424046D09849D4D54A40
615	1	16	453	30431	\N	\N	53.672927000000001	поселок Иста	Россия, Тульская область, Арсеньевский район, поселок Иста	0101000020E610000004ABEAE57752424036CCD07822D64A40
479	1	16	453	40795	\N	\N	53.663479000000002	село Варварино	Россия, Тульская область, Арсеньевский район, поселок Варварино	0101000020E610000044C2F7FE06474240994A3FE1ECD44A40
602	1	16	453	40846	\N	\N	53.623657999999999	поселок Буревестник	Россия, Тульская область, Арсеньевский район, поселок Буревестник	0101000020E61000005FEB5223F4494240C3F17C06D4CF4A40
833	1	16	453	9291	\N	\N	53.530690999999997	деревня Большие Голубочки	Россия, Тульская область, Арсеньевский район, поселок Большие Голубочки	0101000020E61000002AFD84B35B2D424009A4C4AEEDC34A40
310	1	16	453	40815	\N	\N	53.701271323593097	деревня Боброво	Россия, Тульская область, Арсеньевский район, поселок Боброво	0101000020E6100000F7E978CC405342400D51853FC3D94A40
3565	1	16	453	47691	75310	\N	53.689976000000001	п. Белый Колодезь, ул. Школьная, д. 12		0101000020E61000001B683EE76E7342403083312251D84A40
3457	1	16	453	60506	75142	\N	53.736761912846703	поселок Арсеньево, Халтурина, 11	Россия, Тульская область, Арсеньевский район, поселок Арсеньево	0101000020E6100000C5573B8A73544240C0779B374EDE4A40
3456	1	16	453	60506	75102	\N	53.736711024601597	поселок Арсеньево, ул. Папанина, 5	Россия, Тульская область, Арсеньевский район, поселок Арсеньево	0101000020E61000004CE3175E495442403ECDC98B4CDE4A40
891	1	16	453	12077	\N	\N	53.585771999999999	село Араны	Россия, Тульская область, Арсеньевский район, поселок Араны	0101000020E6100000DB5031CEDF3C4240CD74AF93FACA4A40
3447	1	16	487	51163	25355	\N	54.566709595692899	д.Хатманово, Дорожная, 6	Россия, Тульская область, Алексинский район, поселок Хотманово	0101000020E61000000400C79E3DA3424078280AF489484B40
3452	1	16	487	60605	75437	\N	54.438843143208601	пос. при ст.Суходол, Садовая, 25 А		0101000020E6100000D15B3CBCE7AC42400D8AE6012C384B40
87246	1	16	487	46906	\N	\N	54.410482999999999	с.Ступино	Россия, Тульская область, Алексинский район, поселок Ступино	0101000020E6100000ACE0B721C69742403048FAB48A344B40
3451	1	16	487	8497	26010	\N	54.407890000000002	с.Спас-Конино, Юбилейная, 2 А		0101000020E6100000B5C2F4BD869C4240C72E51BD35344B40
3449	1	16	487	8405	\N	\N	54.544848000000002	с.Солопенки, СДК	Россия, Тульская область, Алексинский район, поселок Солопенки	0101000020E61000005320B3B3E87F424040A54A94BD454B40
3440	1	16	487	49462	25554	\N	54.428735000000003	с.Сенево, Садовая		0101000020E6100000249BABE63986424046D3D9C9E0364B40
3442	1	16	487	49491	75358	\N	54.3395561460528	с.Поповка, Победы	Россия, Тульская область, Алексинский район, поселок Поповка	0101000020E610000087FD9E58A79642408E942D92762B4B40
3443	1	16	487	8098	\N	\N	54.290255000000002	с.Пластово, СДК		0101000020E61000001F2DCE18E686424010406A1327254B40
3455	1	16	487	8616	9796	\N	54.469487500987398	р.п. Новогуровский, Школьная, 19	Россия, Тульская область, Алексинский район, поселок Новогуровский	0101000020E6100000C713419C87AB4240A6EECA2E183C4B40
3454	1	16	487	8616	9796	\N	54.466935999999997	р.п. Новогуровский, Школьная, 12		0101000020E610000051A3906456AB42409BA9108FC43B4B40
3448	1	16	487	8325	25352	\N	54.452328999999999	п.Мичурина, Центральная, 2	Россия, Тульская область, Алексинский район, поселок Мичурина	0101000020E6100000E09F5225CA7642402504ABEAE5394B40
3982	1	16	487	46815	\N	\N	54.497216000000002	д. Заречье, Центральная, 2	Россия, Тульская область, Алексинский район, поселок Заречье	0101000020E610000068B0A9F3A8B6424023861DC6A43F4B40
3638	1	16	487	46815	\N	\N	54.497216000000002	д.Заречье	Россия, Тульская область, Алексинский район, поселок Заречье	0101000020E610000068B0A9F3A8B6424023861DC6A43F4B40
3445	1	16	487	8200	\N	\N	54.633113999999999	д.Егнышевка, Библиотека		0101000020E61000005ED6C4025F994240E3512AE109514B40
3444	1	16	487	8119	25905	\N	54.577106000000001	с.Бунырево, Приокская		0101000020E61000008C84B69C4B934240A629029CDE494B40
3446	1	16	487	8227	25500	\N	54.537280000000003	д.Ботня, Центральная, 5		0101000020E6100000F7216FB9FA994240BF654E97C5444B40
3450	1	16	487	8433	26760	\N	54.481735999999998	д. Большое Шелепино, Новая, 6		0101000020E6100000234910AE8094424026A77686A93D4B40
3848	1	16	487	60568	\N	\N	54.2966712744172	военный городок Берники, дом 1, квартира 1	Россия, Тульская область, Алексинский район, поселок Берники	0101000020E6100000DF88EE59D7904240F855B950F9254B40
3435	1	16	487	2910	25997	\N	54.511823	г. Алексин, пл.Победы, 12		0101000020E6100000D881734694864240992B836A83414B40
93660	1	16	487	2910	26905	\N	54.511823	г. Алексин, Южная, 11		0101000020E6100000D881734694864240992B836A83414B40
3422	1	16	487	2910	26811	\N	54.511823	г. Алексин, Энгельса, 1		0101000020E6100000D881734694864240992B836A83414B40
3437	1	16	487	2910	25750	\N	54.511823	г. Алексин, Школьная, 4		0101000020E6100000D881734694864240992B836A83414B40
94285	1	16	487	2910	25596	\N	54.511823	г. Алексин, Центральная, 5		0101000020E6100000D881734694864240992B836A83414B40
3431	1	16	487	2910	25981	\N	54.511823	г. Алексин, Трудовые резервы, 35		0101000020E6100000D881734694864240992B836A83414B40
93896	1	16	487	2910	26911	\N	54.511823	г. Алексин, Сосновая, 1		0101000020E6100000D881734694864240992B836A83414B40
93138	1	16	487	2910	26272	\N	54.511823	г. Алексин, Советская, 38		0101000020E6100000D881734694864240992B836A83414B40
3438	1	16	487	2910	26758	\N	54.511823	г. Алексин, Серафимовича, 3		0101000020E6100000D881734694864240992B836A83414B40
3430	1	16	487	2910	25305	\N	54.511823	г.Алексин, Северная, 23		0101000020E6100000D881734694864240992B836A83414B40
3429	1	16	487	2910	25305	\N	54.511823	г. Алексин, Северная, 23		0101000020E6100000D881734694864240992B836A83414B40
3432	1	16	487	2910	26606	\N	54.511823	г. Алексин, Октябрьская, 1 А		0101000020E6100000D881734694864240992B836A83414B40
93708	1	16	487	2910	26273	\N	54.511823	г. Алексин, Некрасова, 60		0101000020E6100000D881734694864240992B836A83414B40
3428	1	16	487	2910	25455	\N	54.511823	г.Алексин, Мира, 19		0101000020E6100000D881734694864240992B836A83414B40
3427	1	16	487	2910	25455	\N	54.511823	г. Алексин, Мира, 19		0101000020E6100000D881734694864240992B836A83414B40
3436	1	16	487	2910	26415	\N	54.511823	г. Алексин, Металлистов, 4		0101000020E6100000D881734694864240992B836A83414B40
3434	1	16	487	2910	25743	\N	54.511823	г. Алексин, Ленина, 20		0101000020E6100000D881734694864240992B836A83414B40
3433	1	16	487	2910	25743	\N	54.511823	г.Алексин, Ленина, 20		0101000020E6100000D881734694864240992B836A83414B40
3423	1	16	487	2910	25296	\N	54.511823	г. Алексин, Дубравная, 32		0101000020E6100000D881734694864240992B836A83414B40
3421	1	16	487	2910	25296	\N	54.511823	г. Алексин, Дубравная, 23 кор.2-Б		0101000020E6100000D881734694864240992B836A83414B40
3420	1	16	487	2910	25965	\N	54.511823	г. Алексин, Болотова, 6		0101000020E6100000D881734694864240992B836A83414B40
3426	1	16	487	2910	25418	\N	54.511823	г. Алексин, Баумана, 6		0101000020E6100000D881734694864240992B836A83414B40
3425	1	16	487	2910	26220	\N	54.511823	г. Алексин, 50 лет Октября, 10		0101000020E6100000D881734694864240992B836A83414B40
3362	1	16	487	2910	25812	\N	54.511823	г. Алексин, 50 лет ВЛКСМ, 5		0101000020E6100000D881734694864240992B836A83414B40
3207	1	16	487	2910	25812	\N	54.511823	г. Алексин, 50 лет ВЛКСМ, 2		0101000020E6100000D881734694864240992B836A83414B40
3453	1	16	487	60600	75421	\N	54.455793598195598	д.Александровка, Полякова, 2 А	Россия, Тульская область, Алексинский район, поселок Александровка	0101000020E6100000F2CF0CE203B9424044DB3175573A4B40
4260	1	16	7112	51260	26381	\N	54.188459999999999	город Тула, Пролетарский район, Ступинская, 2		0101000020E61000008EE6C8CA2FD74240554D10751F184B40
2355	1	15	\N	41052	\N	\N	56.855525999999998	"г.Тверь, нп Черкассы, помещение ОАО ""ДЭП-74"""		0101000020E610000091ED7C3F35F2414058703FE0816D4C40
2576	1	15	\N	29318	18152	\N	57.878855999999999	Тверская область, г.Удомля, просп.Энергетиков, д.9		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2579	1	15	\N	29318	17933	\N	57.878890336438403	Тверская область, г.Удомля, просп.Курчатова, д.17	Россия, Тверская область, Удомля	0101000020E61000006B9F8EC70C8241400664AF777FF04C40
2578	1	15	\N	29318	17933	\N	57.878855999999999	Тверская область, г.Удомля, просп.Курчатова, д.9		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2575	1	15	\N	29318	17933	\N	57.878855999999999	Тверская область, г.Удомля, просп.Курчатова, д.3Б		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2574	1	15	\N	29318	17933	\N	57.878867206493297	Тверская область, г.Удомля, просп.Курчатова, д.8	Россия, Тверская область, Удомля	0101000020E6100000382EE3A6068241404E44BFB67EF04C40
2571	1	15	\N	29318	17933	\N	57.878855999999999	Тверская область, г.Удомля, просп.Курчатова, д.12а		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2573	1	15	\N	29318	18240	\N	57.878855999999999	Тверская область,  г.Удомля, пер.Автодорожный, д.1а		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2569	1	15	\N	29318	18042	\N	57.878855999999999	Тверская область, г.Удомля, ул.Пионерская, д.24		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2577	1	15	\N	29318	18206	\N	57.878855999999999	Тверская область, г.Удомля, ул.Левитана, д.5		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2572	1	15	\N	29318	18087	\N	57.878855999999999	Тверская область, г.Удомля, пер.Автодорожный, д.1а		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2570	1	15	\N	29318	18087	\N	57.878855999999999	Тверская область, г.Удомля, пер.Автодорожный, ,д.1б		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2580	1	15	\N	29318	17944	\N	57.878855999999999	Тверская область, г.Удомля, пер.1-й Красноармейский, д.1		0101000020E61000009DF4BEF1B58141405AF2785A7EF04C40
2534	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Белинского, д.12	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2533	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Старицкая, д.102	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2531	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Гражданская, д.5	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2530	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Володарского, д.3	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2529	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, пл.Ананьина, д.8	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2528	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Луначарского, д.35	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2527	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Кирова, д.31	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2526	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Луначарского, д.121	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2522	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Лермонтова, д.6	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2521	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Красноармейская, д.33	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2520	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Карла Маркса, д.25	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2519	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Студенческая, д.3	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2447	1	15	\N	1465	18764	\N	56.858961000000001	г.Тверь, ул.Учительская, д.6		0101000020E61000009EB64604E3F041400DC51D6FF26D4C40
2518	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Дзержинского, д.100	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2517	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Энгельса, д.4	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2516	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, ул.Дзержинского, д.119	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2515	1	15	\N	26786	\N	\N	57.049632000000003	Тверская область, г.Торжок, Ленинградское ш, д.19	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2514	1	15	\N	26786	\N	\N	57.049632000000003	"Тверская область, г.Торжок, Ленинградское ш, д.34""А"""	Россия, Тверская область, Торжок	0101000020E610000030F31DFCC47B4140E46A64575A864C40
2523	1	15	\N	26786	12289	\N	57.049632000000003	"Тверская область, г.Торжок, ул.Мира, д.30""А"""		0101000020E610000030F31DFCC47B4140E46A64575A864C40
2513	1	15	\N	26786	12288	\N	57.049632000000003	Тверская область, г.Торжок, Ленинградское ш, д.63		0101000020E610000030F31DFCC47B4140E46A64575A864C40
2512	1	15	\N	26786	12288	\N	57.049632000000003	Тверская область, г.Торжок, Ленинградское ш, д.44		0101000020E610000030F31DFCC47B4140E46A64575A864C40
2525	1	15	\N	26786	12290	\N	57.049632000000003	Тверская область, г.Торжок, Калининское ш, д.29		0101000020E610000030F31DFCC47B4140E46A64575A864C40
2524	1	15	\N	26786	12290	\N	57.049632000000003	"Тверская область, г.Торжок, Калининское ш, д.16""Г"""		0101000020E610000030F31DFCC47B4140E46A64575A864C40
2532	1	15	\N	26786	12291	\N	57.049632000000003	"Тверская область, г.Торжок, ул.Гоголя, д.2""А"""		0101000020E610000030F31DFCC47B4140E46A64575A864C40
2386	1	15	\N	1465	\N	\N	56.799782999999998	г.Тверь, пос.Химинститута, здание нового корпуса МОУ СОШ №37		0101000020E6100000B24B546F0D044240C972124A5F664C40
2376	1	15	\N	1465	\N	\N	56.855525999999998	"г.Тверь, пос.Сахарово, муниципальное учреждение ""МДК поселка Сахарово"""	Россия, Тверская область, Тверь	0101000020E610000091ED7C3F35F2414058703FE0816D4C40
2359	1	15	\N	1465	\N	\N	56.912821999999998	"г.Тверь, пос.Литвинки, учреждение ""МДК поселка Литвинки"""	Россия, Тверская область, Тверь, поселок Литвинки	0101000020E6100000EDD3F19881F04140DF88EE59D7744C40
2443	1	15	\N	1465	6023	\N	56.8439221317375	г.Тверь, ул.Маршала Конева, д.73-А	Россия, Тверская область, Тверь, улица маршала Конева, 73	0101000020E61000004A5E9D6340EA4140FD2FD7A2056C4C40
2429	1	15	\N	1465	390	\N	56.842013999999999	г.Тверь, ул.Ткача, д.18	Россия, Тверская область, Тверь, улица Ткача, 18	0101000020E6100000938B31B08EEB41401763601DC76B4C40
2401	1	15	\N	1465	5789	\N	56.838966999999997	г.Тверь, ул.Склизкова, д.52, корп.А		0101000020E6100000E1EEACDD76F541402CB64945636B4C40
2464	1	15	\N	1465	18396	\N	56.844352999999998	г.Тверь, просп.Чайковского, д.19		0101000020E6100000CF83BBB376F34140C6A354C2136C4C40
2399	1	15	\N	1465	18390	\N	56.838527999999997	г.Тверь, просп.Победы, д.49/21		0101000020E6100000FC71FBE593F74140E063B0E2546B4C40
1943	1	15	\N	1465	18390	\N	56.842187000000003	г.Тверь, просп.Победы, д.37		0101000020E610000041F4A44C6AF64140E50E9BC8CC6B4C40
2405	1	15	\N	1465	18382	\N	56.824404999999999	г.Тверь, просп.Октябрьский, д.71, корп.А		0101000020E6100000A583F57F0EF3414056D4601A86694C40
2430	1	15	\N	1465	18502	\N	56.849817000000002	г.Тверь, просп.Ленина, д.16		0101000020E6100000AA8251499DEA4140DC4AAFCDC66C4C40
1913	1	15	\N	1465	18527	\N	56.867946000000003	г.Тверь, Комсомольский проспект, д.6		0101000020E6100000618A7269FCF44140D658C2DA186F4C40
2419	1	15	\N	1465	18714	\N	56.855235999999998	г.Тверь, просп.Калинина, д.20		0101000020E610000017F2086EA4EE4140512E8D5F786D4C40
2418	1	15	\N	1465	18714	\N	56.855747999999998	г.Тверь, просп.Калинина, д.10		0101000020E61000003FABCC94D6EF414007CF8426896D4C40
2457	1	15	\N	1465	18505	\N	56.837972000000001	г.Тверь, просп.Волоколамский, д.20		0101000020E61000006F10AD156DF441405B7B9FAA426B4C40
2433	1	15	\N	1465	18370	\N	56.844662999999997	г.Тверь, просп.50 лет Октября, д.46		0101000020E61000003F7100FDBEE541401492CCEA1D6C4C40
2432	1	15	\N	1465	18370	\N	56.847380000000001	г.Тверь, просп.50 лет Октября, д.20-Б		0101000020E6100000827170E998E741406AA4A5F2766C4C40
2431	1	15	\N	1465	18370	\N	56.846888	г.Тверь, просп.50 лет Октября, д.3		0101000020E6100000B3EBDE8AC4E84140FBAF73D3666C4C40
2465	1	15	\N	1465	18734	\N	56.847935999999997	г.Тверь, пр-д Дарвина, д.3		0101000020E61000009293895B05F34140EF8CB62A896C4C40
2385	1	15	\N	1465	18260	\N	56.799782999999998	"г.Тверь, пос.Химинститута, здание МДК ""Синтетик"""		0101000020E6100000B24B546F0D044240C972124A5F664C40
2387	1	15	\N	1465	18855	\N	56.848137999999999	г.Тверь, пл.Гагарина, д.1		0101000020E6100000B8CCE9B298F84140573F36C98F6C4C40
2453	1	15	\N	1465	19062	\N	56.853699369537999	г.Тверь, пл.Славы, д.3	Россия, Тверская область, Тверь, улица Салтыкова-Щедрина, 3	0101000020E6100000BFD7101C97F541405FD04202466D4C40
2354	1	15	\N	1465	18365	\N	56.882373000000001	г.Тверь, Молодежный бульвар, д.10		0101000020E6100000CB811E6ADBEA4140CCEF3499F1704C40
2406	1	15	\N	1465	18495	\N	56.823591999999998	г.Тверь, бульв.Гусева, д.11		0101000020E6100000D106600322F44140A59F70766B694C40
2369	1	15	\N	1465	5351	\N	56.872988751241799	г.Тверь, бульв.Шмидта, д.15/13	Россия, Тверская область, Тверь, Шмидта бульвар, 15	0101000020E6100000E3512AE109F341404562821ABE6F4C40
2364	1	15	\N	1465	5351	\N	56.873401000000001	г.Тверь, бульв.Шмидта, д.13/16	Россия, Тверская область, Тверь, Шмидта бульвар, 13/16	0101000020E6100000A14CA3C9C5F2414098A59D9ACB6F4C40
2466	1	15	\N	1465	6411	\N	56.849964	г.Тверь, просп.Чайковского, д.5	Россия, Тверская область, Тверь, Чайковского проспект, 5	0101000020E6100000FD4D2844C0F341408063CF9ECB6C4C40
2462	1	15	\N	1465	6411	\N	56.841290999999998	г.Тверь, просп.Чайковского, д.70	Россия, Тверская область, Тверь, Чайковского проспект, 70	0101000020E61000006138D73043F34140A6B5696CAF6B4C40
2384	1	15	\N	1465	18709	\N	56.802351000000002	г.Тверь, пос.Элеватор, ул.Центральная, д.7		0101000020E610000001A1F5F065004240DA740470B3664C40
2402	1	15	\N	1465	5804	\N	56.834866537162	г.Тверь, бульв.Цанова, д.1	Россия, Тверская область, Тверь, Цанова бульвар	0101000020E610000041BAD8B452F441403CC1FEEBDC6A4C40
2417	1	15	\N	1465	18692	\N	56.832101999999999	г.Тверь, ул.Фадеева, д.39		0101000020E6100000F60B76C3B6F54140D5777E51826A4C40
2390	1	15	\N	1465	18692	\N	56.833545000000001	г.Тверь, ул.Фадеева, д.42		0101000020E610000093C5FD47A6F54140465F419AB16A4C40
654	1	15	\N	1465	8130	\N	56.875148000000003	г.Тверь, пер.Третьяковский, д.17	Россия, Тверская область, Тверь, Третьяковский переулок, 17	0101000020E610000062F3716DA8F64140759483D904704C40
2437	1	15	\N	1465	18386	\N	56.841355	г.Тверь, ул.Тракторная, д.8-А		0101000020E6100000E8FA3E1C24EE4140BDA94885B16B4C40
2393	1	15	\N	1465	19070	\N	56.844624560929802	г.Тверь, ул.Терещенко, д.5/25	Россия, Тверская область, Тверь, улица Терещенко	0101000020E6100000DF6DDE3829F64140273108AC1C6C4C40
2392	1	15	\N	1465	18862	\N	56.842801999999999	г.Тверь, ул.Тамары Ильиной, д.1		0101000020E610000071E316F373F541406F8099EFE06B4C40
2455	1	15	\N	1465	6315	\N	56.854813	г.Тверь, пер.Студенческий, д.13	Россия, Тверская область, Тверь, Студенческий переулок, 13	0101000020E61000006C5CFFAECFF441400B992B836A6D4C40
2451	1	15	\N	1465	6315	\N	56.860556000000003	г.Тверь, пер.Студенческий, д.33	Россия, Тверская область, Тверь, Студенческий переулок, 33	0101000020E6100000BA15C26A2CF541403430F2B2266E4C40
2460	1	15	\N	1465	6386	\N	56.838557999999999	г.Тверь, пер.Спортивный, д.12	Россия, Тверская область, Тверь, Спортивный переулок, 12	0101000020E61000000DE4D9E55BF341404BE658DE556B4C40
2459	1	15	\N	1465	6386	\N	56.836888999999999	г.Тверь, пер.Спортивный, д.11	Россия, Тверская область, Тверь, Спортивный переулок, 11	0101000020E61000002FC03E3A75F34140EAB0C22D1F6B4C40
2422	1	15	\N	1465	18493	\N	56.851514999999999	г.Тверь, ул.Спартака, д.39		0101000020E61000009F3D97A949F04140D7868A71FE6C4C40
2361	1	15	\N	1465	18780	\N	56.883740000000003	г.Тверь, ул.Соминка, д.65		0101000020E6100000A29C685721F3414062156F641E714C40
2280	1	15	\N	1465	18783	\N	56.831634999999999	Тверская область, Селижаровский район, дер.Большое Ларионово, ул.Солнечная, д.2		0101000020E6100000B0ABC95356ED4140BF9A0304736A4C40
2452	1	15	\N	1465	18374	\N	56.858676000000003	г.Тверь, ул.Советская, д.42		0101000020E610000079944A7842F5414018EE5C18E96D4C40
2449	1	15	\N	1465	18374	\N	56.860511000000002	г.Тверь, ул.Советская, д.4		0101000020E61000005E11FC6F25F34140946C7539256E4C40
2325	1	15	\N	1465	18374	\N	56.860757	Тверская область, Старицкий район, г.Старица, ул.Советская, д.8, здание Старицкого ПУ		0101000020E6100000E2395B4068F34140CB660E492D6E4C40
2400	1	15	\N	1465	18529	\N	56.834575000000001	г.Тверь, ул.Склизкова, д.95		0101000020E61000006DE4BA29E5F741409487855AD36A4C40
2450	1	15	\N	1465	6313	\N	56.860747000000003	г.Тверь, пер.Свободный, д.28	Россия, Тверская область, Тверь, Свободный переулок, 28	0101000020E610000076C1E09A3BF44140A8902BF52C6E4C40
2375	1	15	\N	1465	5489	\N	56.865191000000003	г.Тверь, Сахаровское шоссе, д.12	Россия, Тверская область, Тверь, Сахаровское шоссе, 12	0101000020E6100000D595CFF23CFC414093E52494BE6E4C40
2372	1	15	\N	1465	18491	\N	56.864821999999997	г.Тверь, ул.Розы Люксембург, д.116		0101000020E6100000B88FDC9A74F941403F6EBF7CB26E4C40
2424	1	15	\N	1465	18695	\N	56.855983999999999	г.Тверь, ул.Ржевская, д.12		0101000020E61000008445459C4EEC41401BF33AE2906D4C40
2426	1	15	\N	1465	6051	\N	56.852868000000001	г.Тверь, Ремесленный проезд, д.5	Россия, Тверская область, Тверь, Ремесленный проезд, 5	0101000020E610000083A5BA8097EB414008E753C72A6D4C40
2403	1	15	\N	1465	5779	\N	56.837288000000001	г.Тверь, просп.Победы, д.57	Россия, Тверская область, Тверь, Победы проспект, 57	0101000020E6100000A5A31CCC26F84140A8AAD0402C6B4C40
94132	1	15	\N	1465	684	\N	56.873918000000003	г.Тверь, Петербургское шоссе, д.42	Россия, Тверская область, Тверь, Петербургское шоссе, 42	0101000020E6100000D5B48B69A6ED414060B1868BDC6F4C40
93323	1	15	\N	1465	684	\N	56.872751999999998	г.Тверь, Петербургское шоссе, д.39	Россия, Тверская область, Тверь, Петербургское шоссе, 39	0101000020E6100000D464C6DB4AED414061C26856B66F4C40
2357	1	15	\N	1465	684	\N	56.874208000000003	г.Тверь, Петербургское шоссе, д.95	Россия, Тверская область, Тверь, Петербургское шоссе, 95	0101000020E610000039D384ED27EB414067F3380CE66F4C40
2356	1	15	\N	1465	684	\N	56.874586999999998	г.Тверь, Петербургское шоссе, д.105,  корп.1	Россия, Тверская область, Тверь, Петербургское шоссе, 105к1	0101000020E6100000E2E5E95C51EA4140DD408177F26F4C40
2309	1	15	\N	1465	684	\N	56.871940000000002	г.Тверь, Петербургское шоссе, д.51, корп.5	Россия, Тверская область, Тверь, Петербургское шоссе, 51к5	0101000020E610000030A182C30BEC41408109DCBA9B6F4C40
43	1	15	\N	1465	684	\N	56.871414000000001	г.Тверь, Петербургское шоссе, д.8	Россия, Тверская область, Тверь, Петербургское шоссе, 8	0101000020E6100000FFB0A54753EF414066A3737E8A6F4C40
2358	1	15	\N	1465	18743	\N	56.877572999999998	г.Тверь, ул.Паши Савельевой, д.4		0101000020E610000074B515FBCBEC4140226DE34F54704C40
2397	1	15	\N	1465	18388	\N	56.832231	г.Тверь, ул.Орджоникидзе, д.50		0101000020E6100000E36BCF2C09F64140D3DB9F8B866A4C40
2395	1	15	\N	1465	18388	\N	56.8305762193067	г.Тверь, ул.Орджоникидзе, д.53, корп.В		0101000020E61000003674B33F50F64140D76B7A50506A4C40
2394	1	15	\N	1465	18388	\N	56.8320379014637	г.Тверь, ул.Орджоникидзе, д.49, корп.Д	Россия, Тверская область, Тверь, улица Орджоникидзе, 49к5	0101000020E6100000E44C13B69FF64140BE839F38806A4C40
2389	1	15	\N	1465	18388	\N	56.835599000000002	г.Тверь, ул.Орджоникидзе, д.39		0101000020E6100000AE7FD767CEF6414000C974E8F46A4C40
2388	1	15	\N	1465	18388	\N	56.839936999999999	г.Тверь, ул.Орджоникидзе, д.25, корп.В		0101000020E6100000A911FA997AF74140A5D93C0E836B4C40
1117	1	15	\N	1465	18388	\N	56.838493999999997	г.Тверь, ул.Орджоникидзе, д.32		0101000020E6100000D044D8F0F4F6414034F279C5536B4C40
2404	1	15	\N	1465	5826	\N	56.825955999999998	г.Тверь, просп.Октябрьский, д.57	Россия, Тверская область, Тверь, Октябрьский проспект, 57	0101000020E61000007311DF8959F34140ADF71BEDB8694C40
761	1	15	\N	1465	18398	\N	56.843299000000002	г.Тверь, ул.Озерная, д.12		0101000020E6100000E1D4079277F64140F0DFBC38F16B4C40
740	1	15	\N	1465	18706	\N	56.869923999999997	г.Тверь, ул.Новая Заря, д.23		0101000020E610000054E4107173F64140B4006DAB596F4C40
2290	1	15	\N	1465	19040	\N	56.811644999999999	Тверская область, ЗАТО Солнечный, ул.Новая, д.50		0101000020E610000006BCCCB051F44140207BBDFBE3674C40
459	1	15	\N	1465	6166	\N	56.872961028214	г.Тверь, пер.Никитина, д.12	Россия, Тверская область, Тверь, Никитина переулок, 12	0101000020E61000008061F9F36DF141407BD7A02FBD6F4C40
2368	1	15	\N	1465	18848	\N	56.869146000000001	г.Тверь, ул.Мусоргского, д.5		0101000020E6100000239EEC6646F3414080B9162D406F4C40
2383	1	15	\N	1465	5576	\N	56.834547394792502	г.Тверь, Московское ш. (здание РЭУ Московского района), д.83	Россия, Тверская область, Тверь, Московское шоссе	0101000020E61000006214048F6FFB4140CAFCA36FD26A4C40
2353	1	15	\N	1465	5213	\N	56.883892000000003	г.Тверь, Молодежный бульвар, д.10/2		0101000020E6100000D769A4A5F2EA41401899805F23714C40
2412	1	15	\N	1465	18519	\N	56.811087999999998	г.Тверь, ул.Можайского, д.82		0101000020E610000022FDF675E0F44140CA1649BBD1674C40
2409	1	15	\N	1465	18519	\N	56.820596999999999	г.Тверь, ул.Можайского, д.63		0101000020E6100000B398D87C5CF341400D198F5209694C40
2423	1	15	\N	1465	18394	\N	56.851686999999998	г.Тверь, ул.Маршала Конева, д.1		0101000020E6100000D63BDC0E0DED4140D4B66114046D4C40
1570	1	15	\N	1465	18535	\N	56.817433999999999	г.Тверь, ул.Линейная, д.81		0101000020E6100000389F3A5629F74140B95164ADA1684C40
2425	1	15	\N	1465	6047	\N	56.849482000000002	г.Тверь, просп.Ленина, д.25	Россия, Тверская область, Тверь, Ленина проспект, 25	0101000020E610000045F5D6C056EB4140354580D3BB6C4C40
2408	1	15	\N	1465	18498	\N	56.820931999999999	г.Тверь, ул.Левитана, д.30		0101000020E61000001C9947FE60F44140B41EBE4C14694C40
2407	1	15	\N	1465	18498	\N	56.821356000000002	г.Тверь, ул.Левитана, д.28		0101000020E61000009AD024B1A4F44140CB2F833122694C40
2363	1	15	\N	1465	18798	\N	56.877946000000001	г.Тверь, ул.Красина, д.40		0101000020E610000053B29C84D2F34140B7D3D68860704C40
2446	1	15	\N	1465	67833	\N	56.846854	г.Тверь, ул.Коробкова, д.15		0101000020E6100000D1E80E6267F041404F3E3DB6656C4C40
2436	1	15	\N	1465	18392	\N	56.847346000000002	г.Тверь, ул.Константина Заслонова, д.4-А		0101000020E6100000295FD04202EE4140BE326FD5756C4C40
2295	1	15	\N	1465	4531	\N	56.873041999999998	г.Тверь, Комсомольский проспект, д.17/56	Россия, Тверская область, Тверь, Комсомольский проспект, 17/56	0101000020E61000001B12F758FAF4414068041BD7BF6F4C40
2438	1	15	\N	1465	19045	\N	56.833821	г.Тверь, ул.Карбышева, д.1		0101000020E6100000B77EFACF9AEF4140E8DB82A5BA6A4C40
2396	1	15	\N	1465	18510	\N	56.835436000000001	г.Тверь, ул.Ипподромная, д.26		0101000020E61000008AADA06989F5414056F31C91EF6A4C40
2441	1	15	\N	1465	18735	\N	56.828581	г.Тверь, ул.Ильи Касьянова, д.7		0101000020E6100000AAF1D24D62EC4140228B34F10E6A4C40
2370	1	15	\N	1465	18385	\N	56.874153999999997	г.Тверь, ул.Коноплянниковой, д.22-а		0101000020E61000006FF3C64961F4414073D53C47E46F4C40
2454	1	15	\N	1465	18383	\N	56.854354999999998	г.Тверь, ул.Желябова, д.22		0101000020E610000000C5C89239F44140481630815B6D4C40
2439	1	15	\N	1465	18699	\N	56.833117000000001	г.Тверь, ул.Железнодорожников, д.53		0101000020E61000006C7A50508AF24140EE5EEE93A36A4C40
2371	1	15	\N	1465	18253	\N	56.869785999999998	г.Тверь, ул.Фарафоновой, д.26		0101000020E6100000B6F81400E3F341406342CC25556F4C40
2448	1	15	\N	1465	18377	\N	56.857564000000004	г.Тверь, ул.Достоевского, д.10-а		0101000020E6100000051A6CEA3CF241400D1D3BA8C46D4C40
2360	1	15	\N	1465	18778	\N	56.888979570136897	г.Тверь, ул.Дачная, д.73	Россия, Тверская область, Тверь, улица Дачная, 73	0101000020E6100000252191B6F1F341402766BD18CA714C40
2411	1	15	\N	1465	5848	\N	56.817290999999997	г.Тверь, бульв.Гусева, д.47, корп.1	Россия, Тверская область, Тверь, Гусева бульвар, 47к1	0101000020E61000004016A243E0F241405628D2FD9C684C40
2410	1	15	\N	1465	5848	\N	56.818897	г.Тверь, бульв.Гусева, д.42	Россия, Тверская область, Тверь, Гусева бульвар, 42	0101000020E61000002FA704C424F2414071E5EC9DD1684C40
2435	1	15	\N	1465	18748	\N	56.843353	г.Тверь, ул.Громова, д.1		0101000020E61000006F2A52616CE34140E3FDB8FDF26B4C40
2362	1	15	\N	1465	19076	\N	56.880978916004103	г.Тверь, ул.Грибоедова, д.20/1	Россия, Тверская область, Тверь, улица Грибоедова	0101000020E61000000C59DDEA39F341403DBB7CEBC3704C40
2366	1	15	\N	1465	18256	\N	56.869328000000003	г.Тверь, ул.Горького, д.126		0101000020E61000007B1002F225F24140A1BFD023466F4C40
2365	1	15	\N	1465	18256	\N	56.869446000000003	г.Тверь, ул.Горького, д.97		0101000020E61000009E23F25D4AF14140ABD1AB014A6F4C40
2440	1	15	\N	1465	18702	\N	56.827216999999997	г.Тверь, ул.Георгиевская, д.12		0101000020E61000004CA59F7076ED4140FDD8243FE2694C40
2456	1	15	\N	1465	5766	\N	56.841738999999997	г.Тверь, просп.Волоколамский, д.10	Россия, Тверская область, Тверь, Волоколамский проспект, 10	0101000020E6100000874D64E602F541404562821ABE6B4C40
2398	1	15	\N	1465	5766	\N	56.846350999999999	г.Тверь, просп.Волоколамский, д.7, корп.1	Россия, Тверская область, Тверь, Волоколамский проспект, 7/1	0101000020E6100000042159C004F64140ECF7C43A556C4C40
2323	1	15	\N	1465	18384	\N	56.851765999999998	Тверская область, Старицкий район, г.Старица, ул.Володарского, д.4, здание РДК		0101000020E6100000F775E09C11F5414020EC14AB066D4C40
2420	1	15	\N	1465	18500	\N	56.857056999999998	г.Тверь, ул.Виноградова, д.4		0101000020E61000007D1F0E12A2EE414068E7340BB46D4C40
94093	1	15	\N	1465	18864	\N	56.876967999999998	г.Тверь, ул.Веселова, д.33		0101000020E61000005760C8EA56ED4140BBD1C77C40704C40
2382	1	15	\N	1465	18528	\N	56.849960000000003	г.Тверь, ул.Вагжанова, д.14		0101000020E610000092B3B0A71DF841403F74417DCB6C4C40
2381	1	15	\N	1465	18528	\N	56.853459000000001	г.Тверь, ул.Вагжанова, д.2		0101000020E6100000D72FD80DDBF641400ABDFE243E6D4C40
1684	1	15	\N	1465	5088	\N	56.821705000000001	г.Тверь, ш.Бурашевское, д.1	Россия, Тверская область, Тверь, Бурашевское шоссе, 5/21	0101000020E6100000042159C004F64140D7FA22A12D694C40
2442	1	15	\N	1465	18489	\N	56.832599999999999	г.Тверь, ул.Борихино Поле, д.2		0101000020E6100000CF30B5A50EE84140265305A3926A4C40
2428	1	15	\N	1465	18532	\N	56.843417000000002	г.Тверь, ул.Бориса Полевого, д.15		0101000020E6100000317898F6CDEB4140FAF19716F56B4C40
2367	1	15	\N	1465	18366	\N	56.869226859883803	г.Тверь, ул.Благоева, д.2-а		0101000020E61000000B62A06B5FF241406DE690D4426F4C40
2421	1	15	\N	1465	18694	\N	56.849935000000002	г.Тверь, ул.Баррикадная, д.5		0101000020E6100000535BEA20AFEF4140E65C8AABCA6C4C40
2458	1	15	\N	1465	18696	\N	56.835909000000001	г.Тверь, ул.Александра Завидова, д.24		0101000020E6100000B5C5353E93F341404EB7EC10FF6A4C40
2427	1	15	\N	1465	18722	\N	56.848050000000001	г.Тверь, ул.Академическая, д.18		0101000020E61000009014916115EB4140B8AF03E78C6C4C40
2374	1	15	\N	1465	18395	\N	56.864359	г.Тверь, ул.Туполева, д.118		0101000020E6100000CC5EB69DB6FA41406B80D250A36E4C40
2373	1	15	\N	1465	18395	\N	56.863616	г.Тверь, ул.Туполева, д.105		0101000020E61000001AC231CB9EFA4140B32616F88A6E4C40
2434	1	15	\N	1465	6101	\N	56.846598	г.Тверь, просп.50 лет Октября, д.40-А	Россия, Тверская область, Тверь, 50 Лет Октября проспект, 40а	0101000020E6100000CCB73EAC37E64140F46DC1525D6C4C40
2391	1	15	\N	1465	18369	\N	56.839433999999997	г.Тверь, ул.15 лет Октября, д.51/18		0101000020E6100000E2B19FC552F641404293C492726B4C40
2463	1	15	\N	1465	18700	\N	56.843870000000003	г.Тверь, ул.1-я Суворова, д.19		0101000020E6100000D2C43BC093F24140AB09A2EE036C4C40
2352	1	15	\N	1465	4680	\N	56.887745487603098	г.Тверь, 1-ый пер.Вагонников, д.5	Россия, Тверская область, Тверь, 1-й Вагонников переулок	0101000020E610000039D2191879ED41400118CFA0A1714C40
991	1	15	\N	1465	4680	\N	56.887516449715498	г.Тверь, 1-ый пер. Вагонников, д.1-а	Россия, Тверская область, Тверь, 1-й Вагонников переулок	0101000020E6100000E8D9ACFA5CED41409F56D11F9A714C40
2237	1	15	\N	12814	12210	\N	56.259777999999997	Тверская область, г.Ржев, ул.Чернышевского, д.1		0101000020E6100000100533A660294140321CCF6740214C40
2246	1	15	\N	12814	12218	\N	56.259777999999997	Тверская область, г.Ржев, ул.Челюскинцев, Дом офицеров		0101000020E6100000100533A660294140321CCF6740214C40
93246	1	15	\N	12814	18181	\N	56.259777999999997	Тверская область, г.Ржев, ул.Чайковского, д.2		0101000020E6100000100533A660294140321CCF6740214C40
2243	1	15	\N	12814	12216	\N	56.259777999999997	Тверская область, г.Ржев, ул.Центральная, д.17		0101000020E6100000100533A660294140321CCF6740214C40
2228	1	15	\N	12814	12202	\N	56.259777999999997	Тверская область, г.Ржев, ул.Урицкого, д.93		0101000020E6100000100533A660294140321CCF6740214C40
2227	1	15	\N	12814	12201	\N	56.259777999999997	Тверская область, г.Ржев, ул.Трудовая, д.4		0101000020E6100000100533A660294140321CCF6740214C40
2236	1	15	\N	12814	12209	\N	56.259777999999997	Тверская область, г.Ржев, тракт Торопецкий, д.48а		0101000020E6100000100533A660294140321CCF6740214C40
2247	1	15	\N	12814	12219	\N	56.259777999999997	Тверская область, г.Ржев, ул.Тертия Филиппова, д.65а		0101000020E6100000100533A660294140321CCF6740214C40
2244	1	15	\N	12814	12217	\N	56.259777999999997	Тверская область, г.Ржев, пр-д Селижаровский, д.4а		0101000020E6100000100533A660294140321CCF6740214C40
94068	1	15	\N	12814	17973	\N	56.255669371679197	Тверская область, г.Ржев, ул.Пионерская, д.40	Россия, Тверская область, Ржев	0101000020E6100000C7F143A5112D4140EECC04C3B9204C40
2232	1	15	\N	12814	12205	\N	56.259777999999997	Тверская область, г.Ржев, ул.Партизанская, д.9/7	Россия, Тверская область, Ржев	0101000020E6100000100533A660294140321CCF6740214C40
2245	1	15	\N	12814	12215	\N	56.259777999999997	Тверская область, г.Ржев, ул.Никиты Головни, д.31		0101000020E6100000100533A660294140321CCF6740214C40
2242	1	15	\N	12814	12215	\N	56.259777999999997	Тверская область, г.Ржев, ул.Никиты Головни, д.24		0101000020E6100000100533A660294140321CCF6740214C40
2238	1	15	\N	12814	12211	\N	56.259777999999997	Тверская область, г.Ржев, ш.Московское, д.6а		0101000020E6100000100533A660294140321CCF6740214C40
2234	1	15	\N	12814	12207	\N	56.259777999999997	Тверская область, г.Ржев, ул.Марата, д.25		0101000020E6100000100533A660294140321CCF6740214C40
2226	1	15	\N	12814	12200	\N	56.259777999999997	Тверская область, г.Ржев, ш.Ленинградское, д.42		0101000020E6100000100533A660294140321CCF6740214C40
2225	1	15	\N	12814	12200	\N	56.259777999999997	Тверская область, г.Ржев, ш.Ленинградское, д.5		0101000020E6100000100533A660294140321CCF6740214C40
2235	1	15	\N	12814	12208	\N	56.259777999999997	Тверская область, г.Ржев, ул.Кривощапова, д.6		0101000020E6100000100533A660294140321CCF6740214C40
2241	1	15	\N	12814	12214	\N	56.259777999999997	Тверская область, г.Ржев, ул.Краностроителей, д.15		0101000020E6100000100533A660294140321CCF6740214C40
2231	1	15	\N	12814	12204	\N	56.259777999999997	Тверская область, г.Ржев, ул.Карла Маркса, д.41		0101000020E6100000100533A660294140321CCF6740214C40
2230	1	15	\N	12814	12204	\N	56.259777999999997	Тверская область, г.Ржев, ул.Карла Маркса, д.46	Россия, Тверская область, Ржев	0101000020E6100000100533A660294140321CCF6740214C40
2239	1	15	\N	12814	12212	\N	56.259777999999997	Тверская область, г.Ржев, ш.Зубцовское, д.3/58		0101000020E6100000100533A660294140321CCF6740214C40
2229	1	15	\N	12814	12203	\N	56.259777999999997	Тверская область, г.Ржев, ул.Волосковская Горка, д.2		0101000020E6100000100533A660294140321CCF6740214C40
2240	1	15	\N	12814	12213	\N	56.259777999999997	Тверская область, г.Ржев, ул.Валентина Степанченко, д.27		0101000020E6100000100533A660294140321CCF6740214C40
2233	1	15	\N	12814	12206	\N	56.259777999999997	Тверская область, г.Ржев, ул.Большая Спасская, д.15а		0101000020E6100000100533A660294140321CCF6740214C40
2083	1	15	\N	5955	\N	\N	56.223061000000001	Тверская область, г.Нелидово, пос.шахты N3, административное здание производственной базы	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2082	1	15	\N	5955	\N	\N	56.223061000000001	Тверская область, г.Нелидово, пос.шахты N6, административное здание завода	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2087	1	15	\N	5955	12123	\N	56.223061000000001	Тверская область, г.Нелидово, пр.Ленина, д.12.	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2080	1	15	\N	5955	12109	\N	56.213202160277099	Тверская область, г.Нелидово, ул.Чайковского, д.13	Россия, Тверская область, Нелидово	0101000020E6100000DA0418963F6540408DB800344A1B4C40
2103	1	15	\N	5955	12138	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Торопецкий тракт, д.6		0101000020E6100000936E4BE482634040AC014A438D1C4C40
2078	1	15	\N	5955	12113	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Советская, д.40	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2097	1	15	\N	5955	12133	\N	56.230178134291897	Тверская область, г.Нелидово, ул.Пушкина, д.2	Россия, Тверская область, Нелидово	0101000020E610000079E75086AA6440401D210379761D4C40
2086	1	15	\N	5955	12118	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Правды, д.17		0101000020E6100000936E4BE482634040AC014A438D1C4C40
2096	1	15	\N	5955	12136	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Пионерская, д.5	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2085	1	15	\N	5955	12114	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Мира, д.8	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2079	1	15	\N	5955	12114	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Мира, д.18	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2081	1	15	\N	5955	12112	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Матросова, д.42		0101000020E6100000936E4BE482634040AC014A438D1C4C40
2095	1	15	\N	5955	12128	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Лесная, д.13	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2094	1	15	\N	5955	12128	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Лесная, д.10б	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2093	1	15	\N	5955	12128	\N	56.223101744585797	Тверская область, г.Нелидово, ул.Лесная, д.5	Россия, Тверская область, Нелидово	0101000020E6100000CDCB61F71D6340400AD6389B8E1C4C40
2084	1	15	\N	5955	12115	\N	56.223061000000001	Тверская область, г.Нелидово, пл.Ленина, д.2		0101000020E6100000936E4BE482634040AC014A438D1C4C40
2090	1	15	\N	5955	12121	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Кирова, д.10		0101000020E6100000936E4BE482634040AC014A438D1C4C40
2089	1	15	\N	5955	12121	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Кирова, д.8		0101000020E6100000936E4BE482634040AC014A438D1C4C40
2098	1	15	\N	5955	12134	\N	56.225970709387703	Тверская область, г.Нелидово, ул.Карбышева, д.14а		0101000020E61000000135B56CAD634040166C239EEC1C4C40
2088	1	15	\N	5955	12120	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Казанская, д.5		0101000020E6100000936E4BE482634040AC014A438D1C4C40
2092	1	15	\N	5955	12127	\N	56.223061000000001	Тверская область, г.Нелидово, ул.Заводская, д.7	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
2091	1	15	\N	5955	12126	\N	56.222150044886	Тверская область, г.Нелидово, ул.Больничная, д.6	Россия, Тверская область, Нелидово	0101000020E610000082035ABA82634040386744696F1C4C40
2076	1	15	\N	5955	12107	\N	56.223061000000001	Тверская область, г.Нелидово, ул.А.Невского, д.1	Россия, Тверская область, Нелидово	0101000020E6100000936E4BE482634040AC014A438D1C4C40
1968	1	15	\N	40997	12047	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.Горячева, д.64		0101000020E61000004A0A2C80291541402A5437177F834C40
1905	1	15	\N	28509	11997	\N	56.715707000000002	Тверская область, г.Конаково, просп.Ленина, д.11		0101000020E61000003C33C170AE634240574277499C5B4C40
1903	1	15	\N	28509	11997	\N	56.715707000000002	Тверская область, г.Конаково, просп.Ленина, д.28		0101000020E61000003C33C170AE634240574277499C5B4C40
1904	1	15	\N	28509	11996	\N	56.715707000000002	Тверская область, г.Конаково, ул.Энергетиков, д.38	Россия, Тверская область, Конаково	0101000020E61000003C33C170AE634240574277499C5B4C40
1902	1	15	\N	28509	11996	\N	56.715707000000002	Тверская область, г.Конаково, ул.Энергетиков, д.12		0101000020E61000003C33C170AE634240574277499C5B4C40
1894	1	15	\N	28509	11986	\N	56.715707000000002	Тверская область, г.Конаково, ул.Строителей, д.15		0101000020E61000003C33C170AE634240574277499C5B4C40
1895	1	15	\N	28509	11987	\N	56.715707000000002	Тверская область, г.Конаково, ул.Свободы, д.162		0101000020E61000003C33C170AE634240574277499C5B4C40
1899	1	15	\N	28509	11991	\N	56.7147653978151	Тверская область, г.Конаково, ул.Первомайская, д.18	Россия, Тверская область, Конаково	0101000020E6100000EC866D8B32634240A8A9656B7D5B4C40
1898	1	15	\N	28509	11991	\N	56.715707000000002	Тверская область, г.Конаково, ул.Первомайская, д.60		0101000020E61000003C33C170AE634240574277499C5B4C40
1906	1	15	\N	28509	12088	\N	56.715707000000002	"Тверская область, г.Конаково, ул.Набережная Волги, ДК ""Современник"""		0101000020E61000003C33C170AE634240574277499C5B4C40
1893	1	15	\N	28509	11985	\N	56.715707000000002	Тверская область, г.Конаково, ул.Маяковского, д.7		0101000020E61000003C33C170AE634240574277499C5B4C40
1892	1	15	\N	28509	11985	\N	56.715707000000002	Тверская область, г.Конаково, ул.Маяковского, д.16		0101000020E61000003C33C170AE634240574277499C5B4C40
1891	1	15	\N	28509	11983	\N	56.715707000000002	Тверская область, г.Конаково, ул.Комсомольская, д.9		0101000020E61000003C33C170AE634240574277499C5B4C40
1910	1	15	\N	28509	12000	\N	56.715707000000002	Тверская область, г.Конаково, ул.Горького, д.3		0101000020E61000003C33C170AE634240574277499C5B4C40
1909	1	15	\N	28509	12000	\N	56.715707000000002	Тверская область, г.Конаково, ул.Горького, д.13		0101000020E61000003C33C170AE634240574277499C5B4C40
1901	1	15	\N	28509	11993	\N	56.715707000000002	Тверская область, г.Конаково, ул.Гагарина, д.31		0101000020E61000003C33C170AE634240574277499C5B4C40
1900	1	15	\N	28509	11993	\N	56.715707000000002	Тверская область, г.Конаково, ул.Гагарина, д.23		0101000020E61000003C33C170AE634240574277499C5B4C40
1908	1	15	\N	28509	11999	\N	56.715707000000002	Тверская область, г.Конаково, ул.Баскакова, д.11		0101000020E61000003C33C170AE634240574277499C5B4C40
1907	1	15	\N	28509	11999	\N	56.715707000000002	Тверская область, г.Конаково, ул.Баскакова, д.3		0101000020E61000003C33C170AE634240574277499C5B4C40
1874	1	15	\N	27735	11965	\N	56.871709000000003	Тверская область, г.Кимры, пр-д Титова, д.12		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1883	1	15	\N	27735	11979	\N	56.871709000000003	Тверская область, г.Кимры, пр-д Савеловский, д.1		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1881	1	15	\N	27735	11972	\N	56.871709000000003	Тверская область, г.Кимры, пл.Южная, д.5		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1875	1	15	\N	27735	11966	\N	56.871709000000003	Тверская область, г.Кимры, ул.Шевченко, д.73		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1880	1	15	\N	27735	11971	\N	56.871709000000003	Тверская область, г.Кимры, ул.Троицкая, д.99		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1882	1	15	\N	27735	11974	\N	56.871709000000003	Тверская область, г.Кимры, ул.Русакова, д.14		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1878	1	15	\N	27735	11968	\N	56.871709000000003	Тверская область, г.Кимры, ул.Ленина, д.12-а		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1877	1	15	\N	27735	11968	\N	56.871709000000003	Тверская область, г.Кимры, ул.Ленина, д.11		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1889	1	15	\N	27735	11981	\N	56.871709000000003	Тверская область, г.Кимры, ул.Кропоткина, д.22		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1885	1	15	\N	27735	11976	\N	56.871709000000003	Тверская область, г.Кимры, адрес помещения для голосования: ул.Коммунистическая, д.8, адрес УИК: ул.Чапаева, д.6		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1884	1	15	\N	27735	11976	\N	56.871709000000003	Тверская область, г.Кимры, адрес помещения для голосования: ул.Коммунистическая, д.8, адрес УИК: ул.Туполева, д.7		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1886	1	15	\N	27735	11978	\N	56.871709000000003	Тверская область, г.Кимры, ул.Кириллова, д.20		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1879	1	15	\N	27735	11969	\N	56.871709000000003	Тверская область, г.Кимры, ул.Звиргздыня, д.55		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1876	1	15	\N	27735	11967	\N	56.871709000000003	Тверская область, г.Кимры, ул.Володарского, д.102		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1888	1	15	\N	27735	11980	\N	56.871709000000003	Тверская область, г.Кимры, ул.60 лет Октября, д.2		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1887	1	15	\N	27735	11980	\N	56.871709000000003	Тверская область, г.Кимры, адрес помещения для голосования: ул.60 лет Октября, д.2, адрес УИК: ул.Ильича, д.6а		0101000020E61000000EA48B4D2BAD42407F501729946F4C40
1812	1	15	\N	1349	11933	\N	57.359065000000001	Тверская область, г.Кашин, ул.Чистопрудная, д.28		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
514	1	15	\N	1349	10802	\N	57.359065000000001	Тверская область, г.Кашин, ул.Республиканская, д.20	Россия, Тверская область, Кашин	0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
1811	1	15	\N	1349	11932	\N	57.359065000000001	Тверская область, г.Кашин, ул.Максима Горького, д.1а		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
1808	1	15	\N	1349	11929	\N	57.359065000000001	Тверская область, г.Кашин, ул.Льва Толстого, д.18		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
1813	1	15	\N	1349	11934	\N	57.359065000000001	Тверская область, г.Кашин, ул.Ленина, д.30/5		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
21	1	15	\N	1349	8253	\N	57.3595749136121	Тверская область, г.Кашин, ул.Кашинская, д.17а		0101000020E6100000C8091346B3CE4240C7BAB88D06AE4C40
398	1	15	\N	1349	10595	\N	57.359065000000001	Тверская область, г.Кашин, ул.Карла Маркса, д.69	Россия, Тверская область, Кашин	0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
1810	1	15	\N	1349	11931	\N	57.359065000000001	Тверская область, г.Кашин, ул.Инны Константиновой, д.1		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
1809	1	15	\N	1349	11930	\N	57.359065000000001	Тверская область, г.Кашин, ул.Гражданская, д.26		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
1807	1	15	\N	1349	11928	\N	57.359065000000001	Тверская область, г.Кашин, ул.Анатолия Луначарского, д.2		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
589	1	15	\N	1349	10885	\N	57.359065000000001	Тверская область, г.Кашин, ул.25 Октября, д.20		0101000020E61000001F80D4264ECE4240B21188D7F5AD4C40
966	1	15	\N	8097	11210	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Ямская, д.259А		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1622	1	15	\N	8097	11810	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Шмидта, д.194		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1620	1	15	\N	8097	11810	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Шмидта, д.21		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1621	1	15	\N	8097	11809	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Узкоколейная, д.1		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1623	1	15	\N	8097	11811	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Советская, д.5		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1632	1	15	\N	8097	11817	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Сиверсова, д.75		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1644	1	15	\N	8097	11056	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Северная, д.7	Россия, Тверская область, Вышний Волочек	0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
807	1	15	\N	8097	11056	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Северная, д.5/49		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1639	1	15	\N	8097	11824	\N	57.584487000000003	Тверская область, г.Вышний Волочек, Ржевский тракт, д.24	Россия, Тверская область, Вышний Волочек	0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1640	1	15	\N	8097	11825	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Осташковская, д.3/7		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1638	1	15	\N	8097	11823	\N	57.584487000000003	Тверская область, г.Вышний Волочек, Московское ш, д.107А		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
816	1	15	\N	8097	11061	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Мира, д.70Б		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1627	1	15	\N	8097	11814	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Марины Расковой, д.73	Россия, Тверская область, Вышний Волочек	0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1643	1	15	\N	8097	11830	\N	57.588912547842597	Тверская область, г.Вышний Волочек, ул.Магистральная, д.19/24	Россия, Тверская область, Вышний Волочек	0101000020E61000001A69A9BC1D47414039984D8061CB4C40
1646	1	15	\N	8097	11831	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Льва Толстого, д.105А		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1645	1	15	\N	8097	11829	\N	57.584487000000003	Тверская область, г.Вышний Волочек, Ленинградское ш, д.57		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1633	1	15	\N	8097	11818	\N	57.584487000000003	Тверская область, г.Вышний Волочек, Красный Городок, д.239		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1642	1	15	\N	8097	11827	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Коммунаров, д.1/2		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1634	1	15	\N	8097	11819	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Карла Маркса, д.99		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1631	1	15	\N	8097	11812	\N	57.584487000000003	Тверская область, г.Вышний Волочек, Казанский просп, д.51/2		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1625	1	15	\N	8097	11812	\N	57.584487000000003	Тверская область, г.Вышний Волочек, Казанский просп, д.86А		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1624	1	15	\N	8097	11812	\N	57.584487000000003	Тверская область, г.Вышний Волочек, Казанский просп, д.98-100		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1635	1	15	\N	8097	11820	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Екатерининская, д.22		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1628	1	15	\N	8097	11815	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Демьяна Бедного, д.72/64		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1636	1	15	\N	8097	11821	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Венецианова, д.1	Россия, Тверская область, Вышний Волочек	0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1626	1	15	\N	8097	11813	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Вагжанова, д.30		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1630	1	15	\N	8097	11816	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.Большая Садовая, д.31/17		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
1641	1	15	\N	8097	11826	\N	57.584210708134599	Тверская область, г.Вышний Волочек, наб.Бейшлотская, д.129А	Россия, Тверская область, Вышний Волочек	0101000020E6100000354415FE0C454140537B116DC7CA4C40
1637	1	15	\N	8097	11822	\N	57.584487000000003	Тверская область, г.Вышний Волочек, ул.3-я Пролетарская, д.50/26		0101000020E6100000FF942A51F6444140F5F75278D0CA4C40
93377	1	15	\N	1361	17335	\N	57.785373	Тверская область, г.Бежецк, пер.Первомайский, д.35/7А		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
1503	1	15	\N	1361	11867	\N	57.785373	Тверская область, г.Бежецк, пер.Молодежный, д.9		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
1507	1	15	\N	1361	11732	\N	57.785373	Тверская область, г.Бежецк, ул.Школьная, д.24	Россия, Тверская область, Бежецк	0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
93309	1	15	\N	1361	18241	\N	57.785373	Тверская область, г.Бежецк, ул.Чудова, д.71/5		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
93695	1	15	\N	1361	18083	\N	57.785373	Тверская область, г.Бежецк, ул.Чехова, д.13		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
93599	1	15	\N	1361	18083	\N	57.785373	Тверская область, г.Бежецк, ул.Чехова, д.2/15		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
93506	1	15	\N	1361	18103	\N	57.785373	Тверская область, г.Бежецк, ул.Спасская, д.6/17		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
93574	1	15	\N	1361	18071	\N	57.785373	Тверская область, г.Бежецк, пл.Советская, д.1		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
1506	1	15	\N	1361	11731	\N	57.785373	Тверская область, г.Бежецк, ул.М.И.Кузнецова, д.7/4		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
93482	1	15	\N	1361	18099	\N	57.785373	Тверская область, г.Бежецк, ул.Красноармейская, д.2		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
1502	1	15	\N	1361	11725	\N	57.785373	Тверская область, г.Бежецк, ул.Клубная, д.1		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
93517	1	15	\N	1361	18118	\N	57.785373	Тверская область, г.Бежецк, ул.Кашинская, д.102		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
1505	1	15	\N	1361	11728	\N	57.785373	Тверская область, г.Бежецк, ул.Большая, д.29		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
1504	1	15	\N	1361	11728	\N	57.785373	Тверская область, г.Бежецк, ул.Большая, д.2		0101000020E6100000ED7F80B56A594240A9143B1A87E44C40
1723	1	15	\N	20700	\N	\N	56.880159999999997	Тверская область, Калининский район, дер.Аввакумово, д.5, админ.Аввакумовского с\\п		0101000020E6100000D5EC815660004240A99F3715A9704C40
2616	1	15	1908	31631	\N	\N	57.512690999999997	Тверская область, Фировский район, дер.Ходуново, Сельский Дом культуры		0101000020E61000007D94111780BA40400DFAD2DB9FC14C40
2615	1	15	1908	31018	17948	\N	57.479951999999997	Тверская область,  Фировский район,  пос.Фирово, ул.Советская, д.21		0101000020E6100000300F99F221DA40402CD32F116FBD4C40
2603	1	15	1908	31018	17948	\N	57.479951999999997	Тверская область, Фировский район, пос.Фирово, ул.Советская, д.25		0101000020E6100000300F99F221DA40402CD32F116FBD4C40
2611	1	15	1908	31409	18122	\N	57.609977000000001	Тверская область, Фировский район,  пос.Труд, ул.Толстова, д.2		0101000020E61000005DDC460378FB4040F627F1B913CE4C40
2609	1	15	1908	31288	\N	\N	57.258609	Тверская область, Фировский район, дер.Трестино, Сельский клуб		0101000020E61000009CF9D51C20D04040C3B986191AA14C40
2605	1	15	1908	31111	18082	\N	57.446671000000002	Тверская область, Фировский район, пос.Сосновка, ул.Школьная, д.100		0101000020E61000007F85CC9541F540402B89EC832CB94C40
2610	1	15	1908	31342	17905	\N	57.602494	Тверская область, Фировский район, с.Рождество, ул.Юбилейная, д.25		0101000020E6100000EA3F6B7EFCE54040A304FD851ECD4C40
2612	1	15	1908	31456	\N	\N	57.532327000000002	Тверская область,  Фировский район,  пос.Лесной, Сельский клуб		0101000020E61000004CFE277FF7E240408FE3874A23C44C40
2613	1	15	1908	31508	18033	\N	57.656160999999997	Тверская область,  Фировский район,  пос.Комсомольский, ул.Центральная, Сельский Дом культуры		0101000020E6100000F67EA31D37F0404090F46915FDD34C40
2607	1	15	1908	31191	18225	\N	57.406770999999999	Тверская область, Фировский район, дер.Жуково, ул.Новая, Сельский Дом культуры		0101000020E6100000C573B680D0EA404009FB761211B44C40
2608	1	15	1908	31231	\N	\N	57.341389999999997	Тверская область, Фировский район,  дер.Дубровка, Сельский Дом культуры		0101000020E61000004FCE50DCF1D840403997E2AAB2AB4C40
2604	1	15	1908	31051	18031	\N	57.434682000000002	Тверская область, Фировский район, пос.Великооктябрьский, ул.Профсоюзная, д.5		0101000020E610000093E00D6954E840407714E7A8A3B74C40
2597	1	15	1881	30680	\N	\N	57.933833	Тверская область, Удомельский район, дер.Ряд, до 04.12.11-администрация Рядского сельского поселения, 04.12.11-Рядская основная школа		0101000020E61000002F88484DBB8841407976F9D687F74C40
2602	1	15	1881	30680	75060	\N	57.935661099934102	Тверская область, Удомельский район, Рядское с/п, Городок монтажников кор.8	Россия, Тверская область, Удомельский район, поселок Ряд	0101000020E6100000F2ECF2AD0F894140439259BDC3F74C40
2594	1	15	1881	30550	\N	\N	57.962615	Тверская область, Удомельский район, дер.Порожки, Порожкинский сельский Дом Культуры		0101000020E6100000A2427573F17B4140CCD1E3F736FB4C40
2583	1	15	1881	30015	\N	\N	57.959974000000003	Тверская область, Удомельский район, дер.Попово, Зареченская общеобразовательная школа		0101000020E61000006B2920ED7FB241405281936DE0FA4C40
2593	1	15	1881	30508	18215	\N	58.037588999999997	Тверская область, Удомельский район, дер.Озера, ул.Центральная, д.30		0101000020E610000024D236FE444941403CD862B7CF044D40
92703	1	14	156	45576	26232	\N	52.933276999999997	с.Горелое, переулок Школьный, 1		0101000020E610000059350873BBBF4440F38DE89E75774A40
2592	1	15	1881	30441	18069	\N	57.914313	Тверская область, Удомельский район, пос.Мста, ул.Почтовая, д.17 (здание администрации)		0101000020E610000056116E32AA42414061A7583508F54C40
2590	1	15	1881	30356	\N	\N	57.747425445879699	Тверская область, Удомельский район, с.Молдино, до 04.12.11-администрация Молдинского сельского поселения, 04.12.11-Молдинская средняя школа	Россия, Тверская область, Удомельский район, поселок Молдино	0101000020E61000003524EEB1F49F41403D9B559FABDF4C40
2596	1	15	1881	30662	\N	\N	57.911769999999997	Тверская область, Удомельский район, дер.Мишнево, Мишневский сельский Дом Культуры		0101000020E61000009CDEC5FB717B4140A9BC1DE1B4F44C40
2591	1	15	1881	30401	\N	\N	57.935251999999998	Тверская область, Удомельский район, д.Михайлово, д.47а		0101000020E61000002A7288B83971414061C26856B6F74C40
2587	1	15	1881	30189	17975	\N	58.069000000000003	Тверская область, Удомельский район, с.Маслово, д.35 (Дом Культуры)		0101000020E6100000DCDAC2F3526D414046B6F3FDD4084D40
2588	1	15	1881	30260	\N	\N	58.185560000000002	Тверская область, Удомельский район, дер.Липны, Липенская библиотека		0101000020E6100000FD1186014B6A41400FB9196EC0174D40
2600	1	15	1881	30863	\N	\N	57.846524000000002	Тверская область, Удомельский район, дер.Лайково-Попово, Администрация Удомельского сельского поселения		0101000020E6100000A88FC01F7E824140BAA3FFE55AEC4C40
2589	1	15	1881	30279	\N	\N	58.058121999999997	Тверская область, Удомельский район, дер.Курово, Администрация Куровского сельского поселения		0101000020E6100000AB984A3FE18E4140CC96AC8A70074D40
2586	1	15	1881	30143	\N	\N	58.057212	Тверская область, Удомельский район, дер.Кузьминское, д.54 (здание библиотеки)		0101000020E6100000B96E4A79AD78414029780AB952074D40
2585	1	15	1881	30105	\N	\N	58.082416000000002	Тверская область, Удомельский район, с.Котлован, Администрация Котлованского сельского поселения		0101000020E6100000809BC58B857341406555849B8C0A4D40
2584	1	15	1881	30045	\N	\N	57.884349	Тверская область, Удомельский район, дер.Копачево, Копачевская общеобразовательная школа		0101000020E610000025C9737D1F6441400AA0185932F14C40
2595	1	15	1881	30580	\N	\N	57.984204610877399	Тверская область, Удомельский район, дер.Касково, Сиговская средняя школа	Россия, Тверская область, Удомельский район, поселок Касково	0101000020E61000005FB7088CF5834140A4C7EF6DFAFD4C40
2582	1	15	1881	29966	\N	\N	57.860374	Тверская область, Удомельский район, с.Еремково, до 04.12.11-администрация Еремковского сельского поселения, 04.12.11-Еремковская  школа		0101000020E61000004DA1F31ABBA24140132A38BC20EE4C40
2599	1	15	1881	30823	\N	\N	57.830891000000001	Тверская область, Удомельский район, дер.Дерягино, Дерягинский сельский Дом Культуры		0101000020E6100000418177F2E96D414037C5E3A25AEA4C40
2598	1	15	1881	30757	\N	\N	57.773403999999999	Тверская область, Удомельский район, дер.Выскодня, до 04.12.11-администрация Таракинского сельского поселения, 04.12.11-Дом Культуры		0101000020E61000004DDC2A88818441403C4CFBE6FEE24C40
2581	1	15	1881	29895	\N	\N	57.857835999999999	Тверская область, Удомельский район, пос.Брусово, Администрация Брусовского сельского поселения		0101000020E610000092CEC0C8CBB441406DAAEE91CDED4C40
2555	1	15	1790	28729	\N	\N	56.793098999999998	Тверская область, Торопецкий район, дер.Уварово, помещение администрации Уваровского сельского поселения		0101000020E6100000956588635DEC3E40C2BE9D4484654C40
2546	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Калинина, д.43	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2545	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Ленина, 13	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2544	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Ломоносова, д.1	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2543	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Ленинградская, д.65/49	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2541	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.М.Горького, д.49	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2540	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Мусоргского, д.94	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2539	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Чапаева, д.2	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2538	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Октябрьская, д.74	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2537	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Октябрьская, д.68	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2536	1	15	1790	27875	\N	\N	56.502087000000003	Тверская область, г.Торопец, ул.Комсомольская, д.4	Россия, Тверская область, Торопецкий район, Торопец	0101000020E6100000419FC893A4A33F40965F066344404C40
2566	1	15	1790	29215	\N	\N	56.465743000000003	Тверская область,Торопецкий район, дер.Талица, помещение Дома культуры		0101000020E6100000BEDC274701C63F40A4AB74779D3B4C40
2560	1	15	1790	28976	\N	\N	56.454135000000001	Тверская область, Торопецкий район, дер.Скворцово, помещение Центрального сельского Дома культуры		0101000020E61000003E40F7E5CC5A3F40077C7E18213A4C40
92702	1	14	156	45576	25709	\N	52.933276999999997	с.Горелое, Ленина, 45Д		0101000020E610000059350873BBBF4440F38DE89E75774A40
2562	1	15	1790	29062	\N	\N	56.42004	Тверская область, Торопецкий район, дер.Речане, здание администрации Речанского сельского поселения		0101000020E6100000B8E7F9D346A13F408481E7DEC3354C40
2561	1	15	1790	28992	\N	\N	56.376510000000003	Тверская область, Торопецкий район, дер.Пятницкое, помещение Дома культуры		0101000020E61000000D52F01472653F40F94ECC7A31304C40
2565	1	15	1790	29192	\N	\N	56.479118	Тверская область, Торопецкий район, дер.Понизовье, помещение Дома культуры		0101000020E6100000B11875ADBDD33F40647616BD533D4C40
2549	1	15	1790	28436	\N	\N	56.645924999999998	Тверская область, Торопецкий район, дер.Пожня, помещение Дома культуры		0101000020E61000006744696FF0693F409B559FABAD524C40
2547	1	15	1790	28344	\N	\N	56.515379000000003	Тверская область, Торопецкий район, дер.Подгороднее, помещение Дома культуры	Россия, Тверская область, Торопецкий район, поселок Подгороднее	0101000020E6100000EACDA8F92A993F40C90567F0F7414C40
2551	1	15	1790	28524	\N	\N	56.780231000000001	Тверская область, Торопецкий район, пос.Плоскошь, помещение администрации Плоскошского сельского поселения		0101000020E6100000CDE9B298D8403F40A629029CDE634C40
2554	1	15	1790	28685	\N	\N	56.690643000000001	Тверская область, Торопецкий район, дер.Пестряково, помещение Дома культуры		0101000020E6100000471E882CD2143F400D1B65FD66584C40
2558	1	15	1790	28887	\N	\N	56.511797999999999	Тверская область, Торопецкий район, дер.Озерец, помещение Дома культуры		0101000020E610000068E6C935051A3F404014CC9882414C40
2548	1	15	1790	28408	\N	\N	56.564945000000002	Тверская область, Торопецкий район, дер.Нишевицы, помещение Дома культуры	Россия, Тверская область, Торопецкий район, поселок Нишевицы	0101000020E6100000A5BC5642777D3F40F584251E50484C40
2496	1	15	1790	26059	\N	\N	56.469059999999999	Тверская область, Торжокский район, с.Никольское, д.66 - Здание школы	Россия, Тверская область, Торопецкий район, поселок Никольское	0101000020E6100000494C50C3B7743F404EEE77280A3C4C40
2550	1	15	1790	28503	\N	\N	56.828724000000001	Тверская область, Торопецкий район, дер.Наговье, помещение администрации Шешуринского сельского поселения		0101000020E61000000A12DBDD03903F4085B4C6A0136A4C40
2552	1	15	1790	28591	\N	\N	56.758229999999998	Тверская область,Торопецкий район, дер.Красноселье, помещение Дома культуры		0101000020E61000003EB324404D553F404C6C3EAE0D614C40
2557	1	15	1790	28825	\N	\N	56.877778999999997	Тверская область, Торопецкий район, дер.Кочута, помещение Кочутского Дома культуры		0101000020E61000006DAE9AE788F83E40CB0EF10F5B704C40
2553	1	15	1790	28614	\N	\N	56.832999000000001	Тверская область, Торопецкий район, дер.Захоломье, помещение Дома культуры		0101000020E6100000CFF41263994A3F40E44C13B69F6A4C40
2563	1	15	1790	29093	\N	\N	56.394545000000001	Тверская область, Торопецкий район, дер.Грядцы, бывшее здание администрации Грядецкого сельского округа		0101000020E610000034A1496249E93F4071E6577380324C40
2559	1	15	1790	28903	\N	\N	56.582369999999997	Тверская область, Торопецкий район, дер.Выдры, бывшее здание администрации Лужницкого сельского округа		0101000020E610000005871744A42E3F40F415A4198B4A4C40
2556	1	15	1790	28767	\N	\N	56.818247	Тверская область, Торопецкий район, дер.Волок, здание администрации Волокского сельского поселения		0101000020E61000004DA3C9C518283F406A865451BC684C40
2478	1	15	1463	41053	\N	\N	56.948915999999997	"Тверская область, Торжокский район, дер.Митино, д.11 -Здание ООО ""Санаторий Митино"""	Россия, Тверская область, Торжокский район	0101000020E6100000FD67CD8FBF7041405853591476794C40
2510	1	15	1463	26687	\N	\N	57.167399000000003	Тверская область, Торжокский район, с.Яконово, ул.Поселковая, д.11	Россия, Тверская область, Торжокский район, поселок Яконово	0101000020E61000002A90D959F44841400A3197546D954C40
2492	1	15	1463	25860	12284	\N	56.982886999999998	Тверская область, Торжокский район, дер.Тупиково, ул.Центральная, д.2		0101000020E6100000462234828D5D4140EF54C03DCF7D4C40
2509	1	15	1463	26637	\N	\N	56.734211999999999	Тверская область, Торжокский район, дер.Тредубье, д.72 - Здание администрации с/п	Россия, Тверская область, Торжокский район, поселок Тредубье	0101000020E61000000C3CF71E2E994140562AA8A8FA5D4C40
2508	1	15	1463	26592	\N	\N	57.264507999999999	Тверская область, Торжокский район, пос.Тверецкий, ул.Центральная, д.18	Россия, Тверская область, Торжокский район, поселок Тверецкий	0101000020E61000003C6C2233176A4140E3C3EC65DBA14C40
2501	1	15	1463	26238	\N	\N	57.106385000000003	Тверская область, Торжокский район, с.Таложня, д.110а - Здание школы	Россия, Тверская область, Торжокский район, поселок Таложня	0101000020E6100000C51F459DB94341407AE40F069E8D4C40
2506	1	15	1463	26497	\N	\N	56.888052999999999	Тверская область, Торжокский район, дер.Сукромля, адрес помещения для голосования: ул.Центральная, д.9, адрес УИК: ул.Центральная, д.2а	Россия, Тверская область, Торжокский район, поселок Сукромля	0101000020E61000007DAEB6627F5D4140AE0E80B8AB714C40
2502	1	15	1463	26312	\N	\N	56.820768999999999	Тверская область, Торжокский район, с.Страшевичи, ул.Центральная, д.6	Россия, Тверская область, Торжокский район, поселок Страшевичи	0101000020E61000000A698D41274C41400A4966F50E694C40
2307	1	15	1463	16726	\N	\N	57.103237	Тверская область, пос.Спирово, ул.Клубная, д.3	Россия, Тверская область, Торжокский район, поселок Спирово	0101000020E6100000C3A04CA3C93B41405B5EB9DE368D4C40
2477	1	15	1463	25154	\N	\N	57.089824999999998	Тверская область, Торжокский район, пос.Славный, ул.Школьная, д.5	Россия, Тверская область, Торжокский район, поселок Славный	0101000020E6100000E9263108AC8241407DAEB6627F8B4C40
2491	1	15	1463	25829	12283	\N	57.036343000000002	Тверская область, Торжокский район, дер.Селихово, ул.Совхозная, д.10		0101000020E610000068B114C95752414022382EE3A6844C40
2505	1	15	1463	26433	\N	\N	56.794770999999997	Тверская область, Торжокский район, дер.Русино, ул.Лесная, д.3	Россия, Тверская область, Торжокский район, поселок Русино	0101000020E61000008143A852B33F414094675E0EBB654C40
2500	1	15	1463	26218	\N	\N	57.067673999999997	Тверская область, Торжокский район, дер.Рудниково, д.59 - Здание школы	Россия, Тверская область, Торжокский район, поселок Рудниково	0101000020E610000027F8A6E9B34541400E65A88AA9884C40
2498	1	15	1463	26132	\N	\N	56.892881000000003	Тверская область, Торжокский район, дер.Пирогово, ул.Надежды, д.5	Россия, Тверская область, Торжокский район, поселок Пирогово	0101000020E610000003B00111E28A4140221CB3EC49724C40
2497	1	15	1463	26085	12286	\N	57.205703	Тверская область, Торжокский район, дер.Осташково, ул.Молодежная, д.9, кв.10		0101000020E61000003E92921E8650414034D8D479549A4C40
2493	1	15	1463	25921	\N	\N	56.832239999999999	Тверская область, Торжокский район, дер.Мошки, д.82 - Здание администрации с/п		0101000020E61000005C04C6FA0686414026361FD7866A4C40
2495	1	15	1463	25998	12285	\N	57.003348000000003	Тверская область, Торжокский район, пос.Мирный, ул.Советская, д.7а		0101000020E6100000A1DAE044F4934140E6400FB56D804C40
2490	1	15	1463	25765	12282	\N	57.002122999999997	Тверская область, Торжокский район, дер.Маслово, ул.Черемушки, д.3		0101000020E61000008C834BC79C534140E2C8039145804C40
2487	1	15	1463	25638	\N	\N	56.977383000000003	Тверская область, Торжокский район, с.Марьино, д.73 - Здание администрации с/п		0101000020E6100000DD28B2D650A241404C55DAE21A7D4C40
2503	1	15	1463	26327	\N	\N	56.851308000000003	Тверская область, Торжокский район, дер.Лужково, д.46 - Здание Дома досуга	Россия, Тверская область, Торжокский район, поселок Лужково	0101000020E6100000DC2C5E2C0C3941405E6919A9F76C4C40
2485	1	15	1463	25539	\N	\N	56.680306000000002	Тверская область, Торжокский район, дер.Ладьино, д.14а - Здание библиотеки		0101000020E61000004ED4D2DC0A7D4140E4A25A4414574C40
2470	1	15	1463	24863	\N	\N	57.117713999999999	Тверская область, Торжокский район, дер.Климово, д.38а - Здание администрации с/п	Россия, Тверская область, Торжокский район, поселок Климово	0101000020E610000022E010AAD492414003249A40118F4C40
2499	1	15	1463	26153	\N	\N	56.902603999999997	Тверская область, Торжокский район, дер.Ильино, ул.Молодежная, д.3	Россия, Тверская область, Торжокский район, поселок Ильино	0101000020E6100000412E71E481784140909E228788734C40
2488	1	15	1463	25677	\N	\N	56.932659000000001	Тверская область, Торжокский район, пос.Зеленый, д.26 - административное здание с/п		0101000020E6100000F8DF4A766CA84140F8A8BF5E61774C40
2486	1	15	1463	25577	\N	\N	56.703646999999997	Тверская область, Торжокский район, дер.Дудорово, д.35а - административное здание с/п		0101000020E610000028D6A9F23D854140D976DA1A115A4C40
2474	1	15	1463	25024	\N	\N	56.997754999999998	Тверская область, Торжокский район, дер.Дубровка, д.1, (Здание  фельдшерско-, медицинского пункта), кв.2	Россия, Тверская область, Торжокский район, поселок Дубровка	0101000020E610000073F38DE89E7D4140D235936FB67F4C40
2483	1	15	1463	25429	12280	\N	56.936636999999997	Тверская область,Торжокский район, дер.Грузины, ул.Центральная, д.7		0101000020E6100000F1129CFA408641409D9CA1B8E3774C40
2482	1	15	1463	25377	\N	\N	57.216622000000001	Тверская область, Торжокский район, дер.Глухово, д.15 - Здание школы		0101000020E610000050DF32A7CB4441400CCC0A45BA9B4C40
2481	1	15	1463	25345	\N	\N	56.697721000000001	Тверская область, Торжокский район, Высоковское с/поселение, пос.Высокое, адрес помещения для голосования: ул.Школьная (здание школы), д.1,	Россия, Тверская область, Торжокский район, поселок Высокое	0101000020E61000001FB935E9B6724140C05DF6EB4E594C40
2480	1	15	1463	25279	\N	\N	56.737504999999999	Тверская область, Торжокский район, дер.Воропуни, д.17 - административное здание с\\п	Россия, Тверская область, Торжокский район, поселок Воропуни	0101000020E6100000A6D0798D5D5A414078D15790665E4C40
2472	1	15	1463	60471	75063	\N	57.1835860286916	Тверская область, Торжокский район, дер.Быльцино, ул. Центральная, д.14а	Россия, Тверская область, Торжокский район, поселок Быльцыно	0101000020E6100000195932C7F26641407100FDBE7F974C40
2494	1	15	1463	25981	\N	\N	56.810068000000001	Тверская область, Торжокский район, дер.Булатниково, д.11 - Здание администрации с/п		0101000020E61000001343723271794140A0C4E74EB0674C40
2476	1	15	1463	25113	\N	\N	57.248170000000002	Тверская область, Торжокский район, дер.Будово, д.80 - Здание администрации с/п	Россия, Тверская область, Торжокский район, поселок Будово	0101000020E61000001F4B1FBAA074414096ECD808C49F4C40
2473	1	15	1463	24960	\N	\N	57.006538999999997	Тверская область, Торжокский район, дер. Борисцево, д.1- Здание администрации с/п	Россия, Тверская область, Торжокский район, поселок Борисцево	0101000020E61000009A417C60C775414003931B45D6804C40
2471	1	15	1463	24871	\N	\N	57.156553000000002	Тверская область, Торжокский район, дер.Большое Святцово, ул.Мира, д.1а	Россия, Тверская область, Торжокский район, поселок Большое Святцово	0101000020E6100000FF58880E816F41409C8BBFED09944C40
2469	1	15	1463	24796	\N	\N	57.192152	Тверская область, Торжокский район, дер.Большое Петрово, д.26 - Здание администрации с/п	Россия, Тверская область, Торжокский район, поселок Большое Петрово	0101000020E6100000984EEB36A885414035EECD6F98984C40
2511	1	15	1463	26729	\N	\N	57.145778	Тверская область, Торжокский район, дер.Большое Вишенье, д.107 - Здание школы	Россия, Тверская область, Торжокский район, поселок Большое Вишенье	0101000020E61000008066101FD8554140F73C7FDAA8924C40
2479	1	15	1463	25233	\N	\N	56.700434999999999	Тверская область, Торжокский район, дер.Богатьково, д.85 - Здание администрации с/п		0101000020E6100000ECA694D74A684140A4FCA4DAA7594C40
2507	1	15	1463	26525	\N	\N	56.845643000000003	Тверская область, Торжокский район, дер.Альфимово, д.12 - Здание библиотеки	Россия, Тверская область, Торжокский район, поселок Альфимово	0101000020E61000006EDE3829CC694140B18BA2073E6C4C40
2327	1	15	693	41037	\N	\N	56.551864000000002	Тверская область, Старицкий район, дер.Юрьевское Архангельского С/П, административное здание сельского поселения	Россия, Тверская область	0101000020E61000004A0856D5CB6F41407DEBC37AA3464C40
2351	1	15	693	18956	\N	\N	56.391122000000003	Тверская область, Старицкий район, дер.Степурино, здание администрации сельского поселения	Россия, Тверская область, Старицкий район, поселок Степурино	0101000020E6100000E4F6CB272BA24140815F234910324C40
2347	1	15	693	41036	\N	\N	56.512402207381299	Тверская область, Старицкий район, ст.Старица, здание администрации сельского поселения	Россия, Тверская область, Старицкий район, Старица	0101000020E6100000CD3E8F519E774140D733846396414C40
2324	1	15	693	41036	12272	\N	56.5122123876911	Тверская область, Старицкий район, г.Старица, ул.Иванцова, д.1-А, здание Старицкой СОШ	Россия, Тверская область, Старицкий район, Старица	0101000020E610000063EFC517ED774140334FAE2990414C40
2338	1	15	693	18295	\N	\N	56.713104000000001	Тверская область, Старицкий район, дер.Рясня, здание Ряснинского Центра культуры	Россия, Тверская область, Старицкий район, поселок Рясня	0101000020E610000031444E5FCF334140CA52EBFD465B4C40
2341	1	15	693	18417	\N	\N	56.370866999999997	Тверская область, Старицкий район, дер.Родня, административное здание сельского поселения	Россия, Тверская область, Старицкий район, поселок Родня	0101000020E61000004227840EBA7441403315E291782F4C40
2348	1	15	693	18827	\N	\N	56.474141000000003	Тверская область, Старицкий район, дер.Покровское, административное здание сельского поселения	Россия, Тверская область, Старицкий район, поселок Покровское	0101000020E61000008544DAC69F5A4140AC58FCA6B03C4C40
2346	1	15	693	18732	\N	\N	56.580595000000002	Тверская область, Старицкий район, дер.Паньково, здание администрации сельского поселения	Россия, Тверская область, Старицкий район, поселок Паньково	0101000020E61000000B2769FE987041404E9CDCEF504A4C40
2340	1	15	693	18395	\N	\N	56.443258999999998	Тверская область, Старицкий район, дер.Орлово, административное здание сельского поселения	Россия, Тверская область, Старицкий район, поселок Орлово	0101000020E6100000D00A0C59DD7A41402E54FEB5BC384C40
2343	1	15	693	18529	\N	\N	56.740003000000002	Тверская область, Старицкий район, дер.Орешки, здание администрации сельского поселения	Россия, Тверская область, Старицкий район, поселок Орешки	0101000020E61000008E3C1059A413414090F8156BB85E4C40
2345	1	15	693	49965	\N	\N	56.537429189048801	Тверская область, Старицкий район, дер.Новое, административное здание сельского поселения	Россия, Тверская область, Старицкий район, поселок Новое	0101000020E6100000F27B9BFEEC5B414004763579CA444C40
2332	1	15	693	18013	\N	\N	56.709581	Тверская область, Старицкий район, дер.Нестерово, административное здание сельского поселения	Россия, Тверская область, Старицкий район, поселок Нестерово	0101000020E6100000CA8AE1EA00AA4140766EDA8CD35A4C40
2337	1	15	693	18213	\N	\N	56.655110000000001	Тверская область, Старицкий район, с.Луковниково, здание администрации сельского поселения	Россия, Тверская область, Старицкий район, поселок Луковниково	0101000020E6100000E3A7716F7E2D41402BA4FCA4DA534C40
2335	1	15	693	18118	\N	\N	56.602046000000001	Тверская область, Старицкий район, дер.Красное, здание Красновской ООШ	Россия, Тверская область, Старицкий район, поселок Красное	0101000020E6100000CB4DD4D2DC5841400458E4D70F4D4C40
2344	1	15	693	18612	\N	\N	56.512042000000001	Тверская область, Старицкий район, дер.Коньково, административное помещение сельского поселения	Россия, Тверская область, Старицкий район, поселок Коньково	0101000020E610000067D311C0CD744140D7169E978A414C40
2333	1	15	693	18027	\N	\N	56.600746999999998	Тверская область, Старицкий район, с.Емельяново, здание администрации сельского поселения	Россия, Тверская область, Старицкий район, поселок Емельяново	0101000020E610000082A966D652AE4140C6151747E54C4C40
2329	1	15	693	17823	\N	\N	56.634436999999998	Тверская область, Старицкий район, дер.Дарьино, административное здание сельского поселения		0101000020E6100000A12DE7525C3D4140A92F4B3B35514C40
2350	1	15	693	18930	\N	\N	56.348841	Тверская область, Старицкий район, дер.Гурьево, административное здание сельского поселения	Россия, Тверская область, Старицкий район, поселок Гурьево	0101000020E6100000A3CD716E13B04140814067D2A62C4C40
2331	1	15	693	17919	\N	\N	56.638643999999999	Тверская область, Старицкий район, дер.Васильевское, здание Васльевской СОШ	Россия, Тверская область, Старицкий район, поселок Васильевское	0101000020E6100000166D8E739B944140B0E42A16BF514C40
2330	1	15	693	17907	\N	\N	56.663421	Тверская область, Старицкий район, дер.Броды, Бродовская сельская библиотека	Россия, Тверская область, Старицкий район, поселок Броды	0101000020E6100000315C1D0071A34140643DB5FAEA544C40
2336	1	15	693	18195	\N	\N	56.562351	Тверская область, Старицкий район, дер.Братково, здание Максимовской начальной школы	Россия, Тверская область, Старицкий район, поселок Братково	0101000020E610000014252191B6554140BBEF181EFB474C40
2287	1	15	1327	15734	12244	\N	56.904384	Тверская область, Селижаровский район, дер.Хотошино, ул.Центральная, д.2		0101000020E61000000971E5EC9DA540404983DBDAC2734C40
2328	1	15	693	17806	\N	\N	56.684429000000002	Тверская область, Старицкий район, дер.Берново, здание администрации сельского поселения		0101000020E61000009430D3F6AF5A41408DB7955E9B574C40
2349	1	15	693	18841	\N	\N	56.440592000000002	Тверская область, Старицкий район, дер.Бабынино, здание Бабынинской ООШ	Россия, Тверская область, Старицкий район, поселок Бабынино	0101000020E610000058535914769741408B70935165384C40
2342	1	15	693	18513	\N	\N	56.735796999999998	Тверская область, Старицкий район, дер.Бабино, здание Бабинской ООШ	Россия, Тверская область, Старицкий район, поселок Бабино	0101000020E6100000DD4598A25C24414059BF99982E5E4C40
2326	1	15	693	17712	\N	\N	56.607202999999998	Тверская область, Старицкий район, дер.Архангельское, здание администрации сельского поселения		0101000020E61000006150A6D1E49E41403C84F1D3B84D4C40
2306	1	15	1462	16708	\N	\N	57.422863999999997	Тверская область, пос.Спирово, ул.Карла Маркса, д.25	Россия, Тверская область, Спировский район, поселок Спирово	0101000020E61000001BF4A5B73F7F4140EF53556820B64C40
2321	1	15	1462	17393	12271	\N	57.414445000000001	Тверская область, Спировский район, дер.Пеньково, ул.Центральная, д.29		0101000020E610000090A339B2F27F4140D07EA4880CB54C40
2320	1	15	1462	17393	12269	\N	57.414445000000001	Тверская область, Спировский район, дер.Пеньково, ул.Советов, д.7		0101000020E610000090A339B2F27F4140D07EA4880CB54C40
2315	1	15	1462	17120	\N	\N	57.607942999999999	Тверская область, Спировский район, дер.Ососье, д.17		0101000020E6100000D6AA5D13D2C24140836A8313D1CD4C40
2322	1	15	1462	17497	12270	\N	57.360565000000001	Тверская область, Спировский район, пос.Новое Ободово, ул.Лесная, д.9А	Россия, Тверская область, Спировский район, поселок Новое Ободово	0101000020E610000038BF61A2418A4140878A71FE26AE4C40
2312	1	15	1462	17002	12251	\N	57.507928999999997	Тверская область, Спировский район, дер.Никулино, ул.Центральная, д.29		0101000020E6100000740987DEE2BF414051D845D103C14C40
2316	1	15	1462	17199	12265	\N	57.427923	Тверская область, Спировский район, с.Матвеево, ул.Климово, д.29		0101000020E6100000D7A205685B8F4140651A4D2EC6B64C40
2317	1	15	1462	17222	12266	\N	57.429972999999997	Тверская область, Спировский район, пос.Красное Знамя, ул.Советская, д.1А		0101000020E6100000D0D1AA96749A4140DD94F25A09B74C40
2314	1	15	1462	17100	12252	\N	57.567022000000001	Тверская область, Спировский район, с.Козлово, ул.Культурная, д.2		0101000020E61000005AB741EDB7BC4140670E492D94C84C40
2311	1	15	1462	16930	12250	\N	57.312877	Тверская область, Спировский район, дер.Заболотье, ул.Новая, д.20		0101000020E6100000397CD289045F4140D655815A0CA84C40
2313	1	15	1462	17021	\N	\N	57.573784000000003	Тверская область, Спировский район, дер.Еремеевка, д.40		0101000020E6100000DE1D19ABCDAF4140EA7B0DC171C94C40
2319	1	15	1462	17317	12267	\N	57.496864593778703	Тверская область, Спировский район, дер.Городок, ул.Центральная, д.6	Россия, Тверская область, Спировский район, поселок Городок	0101000020E610000032207BBDFB91414076C3B64599BF4C40
2310	1	15	1462	16907	12249	\N	57.364735000000003	Тверская область, Спировский район, с.Выдропужск, ул.Новая, д.4		0101000020E61000000F9A5DF7566C4140715AF0A2AFAE4C40
2318	1	15	1462	17302	12268	\N	57.371428000000002	Тверская область, Спировский район, дер.Бирючево, ул.Центральная, д.54А		0101000020E6100000F52A323A20A54140CB68E4F38AAF4C40
2291	1	15	1429	15923	12247	\N	57.780698999999998	Тверская область, пос.Сонково, ул.Широкая, д.21		0101000020E6100000EBAC16D8639442408C82E0F1EDE34C40
2292	1	15	1429	15923	12248	\N	57.780698999999998	Тверская область, пос.Сонково, ул.Новопромышленная, д.5а		0101000020E6100000EBAC16D8639442408C82E0F1EDE34C40
2303	1	15	1429	16512	\N	\N	57.938915999999999	"Тверская область, Сонковский район, дер.Сергеевское, здание правления колхоза ""Советская Россия"""		0101000020E6100000E15F048D99B2424077D844662EF84C40
2294	1	15	1429	16103	\N	\N	57.757375000000003	Тверская область, Сонковский район, дер.Пригорки, помещение фельдшерско-акушерского пункта		0101000020E61000008DB3E908E08442406DE7FBA9F1E04C40
2304	1	15	1429	16607	\N	\N	57.819834999999998	Тверская область, Сонковский район, пос.Пищалкино, здание администрации сельского поселения		0101000020E610000077BD344580AF4240DE8E705AF0E84C40
2302	1	15	1429	16505	\N	\N	57.857337999999999	Тверская область, Сонковский район, с.Петровское, здание администрации сельского поселения		0101000020E61000008E1F2A8D98A142401CCF6740BDED4C40
2299	1	15	1429	16311	\N	\N	57.772472999999998	Тверская область, Сонковский район, дер.Новые Горицы, помещение сельской библиотеки		0101000020E610000032C85D84299A424081053065E0E24C40
2300	1	15	1429	16396	\N	\N	57.714556000000002	Тверская область, Сонковский район, с.Кой, здание администрации сельского поселения		0101000020E61000000F643DB5FAC242408E942D9276DB4C40
2298	1	15	1429	16299	\N	\N	57.751142000000002	Тверская область, Сонковский район, дер.Григорково, здание администрации сельского поселения		0101000020E6100000A3CD716E13A042407653CA6B25E04C40
2297	1	15	1429	16211	\N	\N	57.702717999999997	Тверская область, Сонковский район, дер.Горка, здание администрации сельского поселения		0101000020E6100000A4349BC761944240BF27D6A9F2D94C40
2296	1	15	1429	16192	\N	\N	57.850963999999998	"Тверская область, Сонковский район, дер.Гладышево, здание МОУ ""Гладышевская основная общеобразовательная школа"""		0101000020E610000051DEC7D11C93424063096B63ECEC4C40
2301	1	15	1429	16413	\N	\N	57.735674000000003	"Тверская область, Сонковский район, дер.Вепрь, здание МОУ ""Вепревская основная общеобразовательная школа"""		0101000020E61000000F81238106AD42403E42CD902ADE4C40
2293	1	15	1429	16011	\N	\N	57.696173000000002	Тверская область, Сонковский район, с.Беляницы, здание администрации сельского поселения		0101000020E61000003293A8177C7C4240DAAD65321CD94C40
2289	1	15	1327	15814	12246	\N	56.849679000000002	Тверская область, Селижаровский район, дер.Шуваево, ул.Новая, д.8А		0101000020E610000007D3307C448640408B8C0E48C26C4C40
2275	1	15	1327	15146	12234	\N	56.792976000000003	Тверская область, Селижаровский район, дер.Филистово, ул.Центральная, д.5		0101000020E6100000E481C8224DB04040A741D13C80654C40
2285	1	15	1327	15635	12242	\N	56.888677000000001	Тверская область, Селижаровский район, пос.Селище, ул.Почтовая, д.22		0101000020E6100000B22AC24D46A340408CDAFD2AC0714C40
2268	1	15	1327	14116	12228	\N	56.851878999999997	Тверская область, пос.Селижарово, ул.Энгельса, д.103		0101000020E6100000CCD4247843BA40401893FE5E0A6D4C40
2266	1	15	1327	14116	12226	\N	56.851878999999997	Тверская область, Селижаровский район, пос.Селижарово, ул.Пушкина, д.58		0101000020E6100000CCD4247843BA40401893FE5E0A6D4C40
2267	1	15	1327	14116	12227	\N	56.851878999999997	Тверская область, пос.Селижарово, ул.Победы, д.15		0101000020E6100000CCD4247843BA40401893FE5E0A6D4C40
2269	1	15	1327	14116	12230	\N	56.852020393860698	Тверская область, пос.Селижарово, ул.Микрорайон, д.7	Россия, Тверская область, Селижаровский район, поселок Селижарово	0101000020E61000000C40A374E9B94040DBC4C9FD0E6D4C40
2265	1	15	1327	14116	12225	\N	56.851878999999997	Тверская область, Селижаровский район, пос.Селижарово, ул.Ленина, д.3 А		0101000020E6100000CCD4247843BA40401893FE5E0A6D4C40
2253	1	15	1327	14116	12223	\N	56.851878999999997	Тверская область, пос. Селижарово, ул.Зеленая, д.1		0101000020E6100000CCD4247843BA40401893FE5E0A6D4C40
2288	1	15	1327	15805	12245	\N	56.830038999999999	Тверская область, Селижаровский район, дер.Подсосонье, ул.Дружная, д.6		0101000020E6100000D923D40CA9C44040C8B3CBB73E6A4C40
2284	1	15	1327	15628	12241	\N	56.713914000000003	Тверская область, Селижаровский район, дер.Ольхово, ул.Центральная, д.9		0101000020E61000003D9D2B4A09CB40400A14B188615B4C40
2281	1	15	1327	15448	12238	\N	56.650646000000002	Тверская область, Селижаровский район, дер.Оковцы, ул.Советская, д.3		0101000020E6100000003B376DC6BD4040F9A23D5E48534C40
2283	1	15	1327	15548	12240	\N	56.604195234240599	Тверская область, Селижаровский район, дер.Малое Ананкино, ул.Центральная, д.9	Россия, Тверская область, Селижаровский район, поселок Малое  Ананкино	0101000020E6100000C9570229B1CF40400FB40243564D4C40
2279	1	15	1327	15348	12237	\N	56.648187	Тверская область, Селижаровский район, дер.Максимково, ул.Новая, д.11		0101000020E6100000C501F4FBFEA140409F58A7CAF7524C40
2272	1	15	1327	15044	12232	\N	56.755625000000002	Тверская область, Селижаровский район, дер.Киселево, ул.Центральная, д.26		0101000020E61000001F12BEF737E640401F85EB51B8604C40
2277	1	15	1327	15246	12236	\N	56.830669	Тверская область, Селижаровский район, дер.Захарово, ул.Молодежная, д.1		0101000020E61000008B170B43E4BE404088669E5C536A4C40
2276	1	15	1327	15234	12235	\N	56.663218000000001	Тверская область, Селижаровский район, дер.Ельцы, пер.Школьный, д.8		0101000020E61000009414580053EC40402C0FD253E4544C40
2286	1	15	1327	15713	12243	\N	56.818508000000001	Тверская область, Селижаровский район, дер.Дубровки, ул.Северная, д.3		0101000020E610000065C39ACAA29A4040D7C1C1DEC4684C40
2282	1	15	1327	15534	12239	\N	56.548361	Тверская область, Селижаровский район, дер.Дружная Горка, ул.Школьная, д.5		0101000020E610000086A92D7590BF404070B378B130464C40
2274	1	15	1327	15127	\N	\N	56.746327000000001	Тверская область, Селижаровский район, дер.Дмитрово, администрация Дмитровского сельского поселения		0101000020E6100000CE35CCD078A84040978FA4A4875F4C40
2273	1	15	1327	15053	12233	\N	56.699258	Тверская область, Селижаровский район, дер.Гора, ул.Зеленая, д.6		0101000020E61000001BF67B629D9C4040B2BB404981594C40
2278	1	15	1327	15330	\N	\N	56.564636999999998	Тверская область, Селижаровский район, дер.Большое Кашино, администрация Максимковского сельского поселения		0101000020E6100000618C48145A9A4040478E740646484C40
2271	1	15	1327	14969	12231	\N	56.738911999999999	Тверская область, Селижаровский район, дер.Большая Коша, ул.Центральная, д.11		0101000020E6100000F6ED2422FCDB40409C4F1DAB945E4C40
2261	1	15	1317	41031	\N	\N	58.370269	Тверская область, Сандовский район, ст.Топорово, Здание администрации Топоровского сельского поселения		0101000020E610000074B33F506E5D42407FDC7EF9642F4D40
2259	1	15	1317	14392	\N	\N	58.531802999999996	"Тверская область, Сандовский район,  с.Тухани, Здание конторы Крестьянско-фермерского хозяйства ""Козлов А"""		0101000020E61000000D51853FC34F42401475E61E12444D40
2258	1	15	1317	14380	\N	\N	58.285556999999997	Тверская область, Сандовский район,  дер.Топалки, Здание МОУ Топалковская  НОШ		0101000020E610000045BA9F53901342406A12BC218D244D40
2252	1	15	1317	14097	\N	\N	58.397925999999998	Тверская область, Сандовский район, с.Сушигорицы, Здание Сушигорицкого Дома Досуга		0101000020E6100000B07092E68F314240321D3A3DEF324D40
1834	1	15	1317	25924	\N	\N	58.442737000000001	Тверская область, Кашинский район, дер.Стулово, д.26		0101000020E610000016F9F5436C44424055DD239BAB384D40
2260	1	15	1317	14470	\N	\N	58.394049000000003	Тверская область, Сандовский район, с.Старое Сандово, Здание администрации Старосандовского сельского поселения		0101000020E6100000A41820D1044C4240C102983270324D40
2251	1	15	1317	14013	\N	\N	58.455711000000001	Тверская область, Сандовский район, дер.Соболины, Здание администрации Соболинского сельского поселения		0101000020E610000014B01D8CD83D4240B7B6F0BC543A4D40
2250	1	15	1317	13926	12222	\N	58.459829999999997	Тверская область, Сандовский район, пгт.Сандово, ул.Школьная, д.1		0101000020E610000077DB85E63A3542401EDC9DB5DB3A4D40
2249	1	15	1317	13926	12221	\N	58.459829999999997	Тверская область, Сандовский район, пгт.Сандово, ул.Советская, д.13А		0101000020E610000077DB85E63A3542401EDC9DB5DB3A4D40
1764	1	15	1317	22641	\N	\N	58.350232459395599	Тверская область, Калининский район, дер.Садовая, д.29	Россия, Тверская область, Сандовский район, поселок Садовая	0101000020E610000093718C648F2242409F01F566D42C4D40
2255	1	15	1317	14201	\N	\N	58.310783000000001	"Тверская область, Сандовский район, дер.Пнево, Здание конторы колхоза ""Заря"""		0101000020E6100000F9F719170E2E42408E93C2BCC7274D40
67663	5	53	873	53018	29573	\N	56.663115565229397	с.Орлово, Блочная, 14		0101000020E6100000399D64ABCB84524028BA2EFCE0544C40
2256	1	15	1317	14287	\N	\N	58.446269000000001	Тверская область, Сандовский район, с.Лукино, Здание администрации Лукинского сельского поселения		0101000020E61000002E3D9AEAC9184240FC1BB4571F394D40
2262	1	15	1317	14564	\N	\N	58.422218999999998	Тверская область, Сандовский район, с.Ладожское, Здание Ладожского Дома Досуга		0101000020E610000006D50627A2054240FA5FAE450B364D40
2257	1	15	1317	14299	\N	\N	58.439599999999999	Тверская область, Сандовский район,  дер.Кресты, Здание Свердловского Дома культуры		0101000020E6100000E8667FA0DC2042402AA913D044384D40
2264	1	15	1317	14660	\N	\N	58.434238999999998	Тверская область, Сандовский район,  дер.Вокшино, Здание Ростороповской библиотеки		0101000020E6100000D5EAABAB02614240E9D2BF2495374D40
2254	1	15	1317	14189	\N	\N	58.334561000000001	Тверская область, Сандовский район, дер.Большое Малинское, Здание МОУ Большемалинская СОШ		0101000020E6100000E4A3C519C31E42402FC214E5D22A4D40
2263	1	15	1317	14576	\N	\N	58.296937999999997	Тверская область, Сандовский район,  дер.Березье, Здание МОУ Березская НОШ		0101000020E610000028D53E1D8F55424046787B1002264D40
2203	1	15	928	11766	\N	\N	56.543309000000001	Тверская область, Ржевский район, дер.Шолохово, д.13, здание ДОУ		0101000020E6100000FE80070610FA4040AD4F39268B454C40
2222	1	15	928	12710	12199	\N	56.248010999999998	Тверская область, Ржевский район, пос.Чертолино, ул.Школьная, д.16		0101000020E6100000055262D7F6EE40402D060FD3BE1F4C40
2212	1	15	928	12230	\N	\N	56.252867000000002	Тверская область, Ржевский район, дер.Хорошево, д.5а, здание администрации		0101000020E61000003755F7C8E62241406B9E23F25D204C40
2112	1	15	928	7456	\N	\N	56.327145999999999	Тверская область, Ржевский район, дер.Успенское, д.9, здание СДК		0101000020E610000060747973B83A414034828DEBDF294C40
2201	1	15	928	11665	12279	\N	56.467354	Тверская область, Ржевский район, дер.Трубино, ул.Центральная, здание школы		0101000020E6100000D5B32094F7E94040D0D38041D23B4C40
2205	1	15	928	11851	\N	\N	56.508341000000001	Тверская область, Ржевский район, дер.Раменское, здание библиотеки		0101000020E6100000C0B4A84F72FD4040A41B615111414C40
2220	1	15	928	12613	\N	\N	56.094428999999998	Тверская область, Ржевский район, дер.Пятницкое, д.6, здание администрации		0101000020E6100000051A6CEA3C024140A165DD3F160C4C40
2198	1	15	928	11548	12190	\N	56.330894000000001	Тверская область, Ржевский район, пос.Победа, ул.Школьная, д.12а		0101000020E61000008DF0F62004224140A8380EBC5A2A4C40
2210	1	15	928	12121	\N	\N	56.348776000000001	Тверская область, Ржевский район, дер.Плешки, д.80, здание ДОУ		0101000020E6100000991249F4324841409AD024B1A42C4C40
2200	1	15	928	11643	12278	\N	56.400582999999997	Тверская область, Ржевский район, дер.Парихино, ул.Новая, здание школы		0101000020E61000007102D369DDF64040B22AC24D46334C40
2219	1	15	928	12543	12197	\N	56.031055000000002	Тверская область, Ржевский район, дер.Осуга, ул.Привокзальная, д.1а		0101000020E6100000F59CF4BEF12941404BB0389CF9034C40
2211	1	15	928	12169	12194	\N	56.309972999999999	Тверская область, Ржевский район, дер.Орехово, ул.Центральная, д.25		0101000020E6100000B41D5377655D41404ED2FC31AD274C40
2208	1	15	928	12027	\N	\N	56.473500000000001	Тверская область, Ржевский район, дер.Озерютино, д.21, здание библиотеки		0101000020E6100000C763062AE3214140F853E3A59B3C4C40
2197	1	15	928	11482	\N	\N	56.316464000000003	Тверская область, Ржевский район, дер.Образцово, д.24, здание ДОУ		0101000020E6100000C37FBA81022D4140412E71E481284C40
2202	1	15	928	11754	\N	\N	56.566496999999998	Тверская область, Ржевский район, дер.Михалево, д.4, здание школы		0101000020E61000005A1135D1E7F140401C2444F982484C40
2217	1	15	928	12444	\N	\N	56.180036000000001	Тверская область, Ржевский район, дер.Медведево, д.23, здание школы		0101000020E6100000D76839D043234140240D6E6B0B174C40
2218	1	15	928	12511	\N	\N	56.071157999999997	Тверская область, Ржевский район, дер.Курьяново, д.52, здание школы		0101000020E6100000446CB07092204140A46C91B41B094C40
2206	1	15	928	11928	\N	\N	56.479356000000003	Тверская область, Ржевский район, дер.Кривцово, д.61, здание ООО АПК		0101000020E61000001C5C3AE63C054140199293895B3D4C40
2214	1	15	928	12336	12196	\N	56.305449000000003	Тверская область, Ржевский район, дер.Кокошкино, ул.Банная, д.10		0101000020E61000002BDA1CE73607414047CCECF318274C40
2207	1	15	928	11948	12192	\N	56.495638	Тверская область, Ржевский район, дер.Итомля, ул.Центральная, д.10		0101000020E6100000F3C7B4368D114140D253E410713F4C40
2224	1	15	928	12788	\N	\N	56.341777	Тверская область, Ржевский район, пос.Ильченко, д.33, здание школы		0101000020E6100000CC5F217365EE404033C34659BF2B4C40
2221	1	15	928	12658	12198	\N	56.203968000000003	Тверская область, Ржевский район, дер.Звягино, ул.Центральная, д.28		0101000020E610000040868E1D54F840401CB7989F1B1A4C40
2213	1	15	928	12260	12195	\N	56.291569000000003	Тверская область, Ржевский район, пос.Заволжский, ул.Заводское шоссе, д.3		0101000020E61000003BA92F4B3B0D414083C30B2252254C40
2215	1	15	928	12344	\N	\N	56.226809000000003	Тверская область, Ржевский район, дер.Домашино, д.113, здание библиотеки		0101000020E61000008F334DD87E28414020B8CA13081D4C40
2204	1	15	928	11831	\N	\N	56.269990999999997	Тверская область, Ржевский район, дер.Дмитрово, д.46а, здание администрации		0101000020E6100000BA30D28BDAF740406F9BA9108F224C40
2209	1	15	928	12064	12193	\N	56.36477	Тверская область, Ржевский район, дер.Глебово, ул.Молодежная, д.1		0101000020E610000025E659492B384140ED478AC8B02E4C40
2199	1	15	928	11575	12191	\N	56.361902999999998	Тверская область, Ржевский район, дер.Бахмутово, ул.Приволжская, д.3		0101000020E6100000B4CA4C69FD05414082A966D6522E4C40
2223	1	15	928	12738	\N	\N	56.272125000000003	Тверская область, Ржевский район, дер.Азарово, д.48, здание администрации		0101000020E61000002507EC6AF2F4404046B6F3FDD4224C40
2196	1	15	1150	11282	12187	\N	57.341802000000001	Тверская область, Рамешковский район, пос. Рамешки, адрес помещения для голосования: ул. Советская, д.47, адрес УИК: ул. Советская, д.20, к.8		0101000020E610000032ACE28DCC0542408CDAFD2AC0AB4C40
92523	1	14	684	13506	25366	\N	52.078878000000003	Недобровка деревня, Школьная, 5		0101000020E6100000B535221807FF4440DC2F9FAC180A4A40
2195	1	15	1150	11282	12187	\N	57.341802000000001	Тверская область, Рамешковский район, пос. Рамешки, Советская, д.47		0101000020E610000032ACE28DCC0542408CDAFD2AC0AB4C40
2193	1	15	1150	11282	12187	\N	57.341802000000001	"Тверская область, Рамешковский район, пос. Рамешки"", адрес помещения для голосования: ул.Советская, д.18, адрес УИК: ул.Советская, д.16,к.3"		0101000020E610000032ACE28DCC0542408CDAFD2AC0AB4C40
2194	1	15	1150	11282	12188	\N	57.341802000000001	Тверская область, Рамешковский район, пос. Рамешки, ул.Пионерская, д.1		0101000020E610000032ACE28DCC0542408CDAFD2AC0AB4C40
2192	1	15	1150	11267	12186	\N	57.243411999999999	Тверская область, Рамешковский район, с.Никольское, ул.Центральная, д.8		0101000020E6100000309DD66D50F341401BBAD91F289F4C40
2191	1	15	1150	11186	\N	\N	57.375	Тверская область, Рамешковский район, д.Некрасово, д.2-А, здание Некрасовского СДК		0101000020E6100000D3156C239E5842400000000000B04C40
2189	1	15	1150	11099	12182	\N	57.128678000000001	Тверская область, Рамешковский район, с.Кушалино, ул.Пушкина, д.30-А		0101000020E6100000ED116A86540942407BDB4C8578904C40
2190	1	15	1150	11099	12184	\N	57.128678000000001	Рамешковский район, с.Кушалино,ул.Колхозная, д.33.		0101000020E6100000ED116A86540942407BDB4C8578904C40
2188	1	15	1150	11078	12181	\N	57.361463000000001	Тверская область, Рамешковский район, с.Киверичи, ул.Комсомольская, д.21		0101000020E6100000B1FA230C034C424066DB696B44AE4C40
2187	1	15	1150	11013	\N	\N	57.196765999999997	Тверская область,Рамешковский район, с.Ильгощи, д.22, здание администрации с/п Ильгощи		0101000020E610000005DD5ED2183F42407C7BD7A02F994C40
2186	1	15	1150	11002	12179	\N	57.209032000000001	Тверская область, Рамешковский район, с.Застолбье, ул.Школьная, д.8		0101000020E6100000B8020AF5F4094240A3E8818FC19A4C40
2185	1	15	1150	10925	\N	\N	57.450060999999998	Тверская область, Рамешковский район, с.Заклинье, адрес помещения для голосования: д.15-А, адрес УИК: д.28-А		0101000020E61000009966BAD7491B42403F1A4E999BB94C40
2184	1	15	1150	10909	12178	\N	57.321041999999998	Тверская область, Рамешковский район, дер.Высоково, ул.Центральная, д.9		0101000020E61000004983DBDAC2FF41403B527DE717A94C40
2183	1	15	1150	10832	12176	\N	57.131726999999998	Тверская область, Рамешковский район, с.Ведное, ул.Советская, д.30		0101000020E61000001EA67D737F15424006802A6EDC904C40
2182	1	15	1150	10804	\N	\N	57.308929999999997	Тверская область, Рамешковский район, дер. Алешино, д.22, здание администрации с/п Алешино		0101000020E6100000F1BBE9961D3042406B60AB048BA74C40
2179	1	15	741	10642	12171	\N	56.864561000000002	Тверская область, Пеновский район, пос.Соблаго, ул.Первомайская, д.12		0101000020E6100000D76D50FBAD4B4040D33252EFA96E4C40
2180	1	15	741	10720	12173	\N	57.064615000000003	Тверская область, Пеновский район, дер.Слаутино, ул.Советская, д.9		0101000020E61000009D2E8B89CD29404060EAE74D45884C40
2172	1	15	741	10292	12164	\N	56.926941999999997	Тверская область, Пеновский район, пос.Пено, ул.Лесная, д.15		0101000020E61000005454FD4AE75D4040F8A41309A6764C40
2173	1	15	741	10292	12165	\N	56.926941999999997	Тверская область, пос.Пено, ул.Восточная, д.2		0101000020E61000005454FD4AE75D4040F8A41309A6764C40
2174	1	15	741	10292	12180	\N	56.926941999999997	Тверская область, пос.Пено, ул.249 Стрелковой Дивизии, д.14		0101000020E61000005454FD4AE75D4040F8A41309A6764C40
2178	1	15	741	10620	12170	\N	56.772506999999997	Тверская область, Пеновский район, пос.Охват, ул.Советская, д.35		0101000020E61000003A9677D5033840402D776682E1624C40
2177	1	15	741	10568	12169	\N	56.643276999999998	Тверская область, Пеновский район, дер.Мошары, ул.Центральная, д.10		0101000020E61000008DD13AAA9A6C40406EA296E656524C40
2176	1	15	741	10541	12168	\N	57.001333000000002	Тверская область, Пеновский район, дер.Заево, ул.Центральная, д.34а		0101000020E6100000894160E5D0604040EAB303AE2B804C40
2067	1	15	741	5200	12105	\N	56.993547999999997	Тверская область, Пеновский район, дер.Забелино, ул.Центральная, д.8		0101000020E610000069C9E369F94F4040CB80B3942C7F4C40
2181	1	15	741	10760	12174	\N	56.885815000000001	Тверская область, Пеновский район, пос.Жукопа, ул.Набережная, д.13а		0101000020E6100000A24621C9AC64404033A7CB6262714C40
2175	1	15	741	10466	\N	\N	56.968719	Тверская область, Пеновский район, с.Ворошилово, Здание администрации Ворошиловского сельского поселения		0101000020E610000048A81952451D4040C501F4FBFE7B4C40
2162	1	15	1026	41047	\N	\N	57.167701000000001	"Тверская область, Осташковский район, турбаза ""Сокол"", помещение Зареченской начальной школы"		0101000020E610000045D8F0F44A894040D540F33977954C40
2161	1	15	1026	9772	\N	\N	57.368836000000002	Тверская область, Осташковский район, дер.Щучье, помещение администрации Щучьенского сельского поселения		0101000020E6100000E04735ECF7B4404032CB9E0436AF4C40
2164	1	15	1026	9890	\N	\N	57.097844000000002	Тверская область, Осташковский район, дер.Хитино, помещение администрации Хитинского сельского поселения		0101000020E6100000034356B77A7A40400F0EF626868C4C40
2170	1	15	1026	10205	\N	\N	57.400744000000003	Тверская область, Осташковский район, дер.Сосница, административное здание Залучьенского сельского поселения		0101000020E610000066683C11C4814040BC0853944BB34C40
2157	1	15	1026	9553	\N	\N	57.175317999999997	Тверская область, Осташковский район, дер.Сорога, помещение администрации Сорожского сельского поселения		0101000020E610000083E0F1ED5D9740403733FAD170964C40
2153	1	15	1026	9375	\N	\N	57.096362444166999	Тверская область, Осташковский район, пос.Сиговка, помещение средней школы	Россия, Тверская область, Осташковский район, поселок Сиговка	0101000020E6100000A94C3107419B4040E0490B97558C4C40
2158	1	15	1026	9585	\N	\N	57.254164000000003	Тверская область, Осташковский район, дер.Святое, помещение администрации Святосельского сельского поселения		0101000020E61000003BC269C18BAC404008E9297288A04C40
2168	1	15	1026	10091	\N	\N	57.263029000000003	Тверская область, Осташковский район, дер.Свапуще, помещение администрации Свапущенского сельского поселения		0101000020E6100000B2BCAB1E3059404026732CEFAAA14C40
2154	1	15	1026	9390	\N	\N	57.096732174188098	Тверская область, Осташковский район, пос.Рогожа, помещение клуба	Россия, Тверская область, Осташковский район, поселок Рогожа	0101000020E6100000DCF0BBE996A14040043DD4B6618C4C40
2146	1	15	1026	8934	12161	\N	57.149141999999998	Тверская область, г.Осташков, пер.Литвиненко, д.61а		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2148	1	15	1026	8934	12156	\N	57.149141999999998	Тверская область, г.Осташков, ул.Шевчука, д.7		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2147	1	15	1026	8934	12155	\N	57.149141999999998	Тверская область, г.Осташков, пер.Осташковский, д.4		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2149	1	15	1026	8934	12157	\N	57.149141999999998	Тверская область, г.Осташков, Микрорайон, д.20		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2150	1	15	1026	8934	12158	\N	57.149141999999998	Тверская область, г.Осташков, ул.Заслонова, д.3а	Россия, Тверская область, Осташковский район, Осташков	0101000020E6100000E7ABE463778F4040E23AC61517934C40
2152	1	15	1026	8934	12159	\N	57.149141999999998	Тверская область, г.Осташков, ул.Загородная, д.24		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2151	1	15	1026	8934	12159	\N	57.149141999999998	Тверская область, г.Осташков, ул.Загородная, д.22		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2143	1	15	1026	8934	12152	\N	57.149141999999998	Тверская область, г.Осташков, ул.Горького, д.32		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2145	1	15	1026	8934	12153	\N	57.149141999999998	Тверская область, г.Осташков, ул.Володарского, д.56		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2144	1	15	1026	8934	12153	\N	57.149141999999998	Тверская область, г.Осташков, ул.Володарского, д.13		0101000020E6100000E7ABE463778F4040E23AC61517934C40
2163	1	15	1026	9869	\N	\N	57.282085000000002	Тверская область, Осташковский район, дер.Новые Ельцы, помещение начальной школы		0101000020E6100000CF8767093274404099D87C5C1BA44C40
2159	1	15	1026	9654	\N	\N	57.363556000000003	Тверская область, Осташковский район, дер.Мошенка, помещение администрации Мошенского сельского поселения		0101000020E61000009FE8BAF083A14040DE21C50089AE4C40
2614	1	15	1026	49892	\N	\N	57.097851561265202	Тверская область, Фировский район, дер.Мартюшино, Сельский клуб	Россия, Тверская область, Осташковский район, поселок Мартюшино	0101000020E610000033535A7F4BC2404092EC116A868C4C40
2155	1	15	1026	9459	\N	\N	57.001108000000002	Тверская область, Осташковский район, дер.Зехново, помещение начальной школы		0101000020E6100000AE9D280989A24040CAE1934E24804C40
2167	1	15	1026	10084	\N	\N	56.968533000000001	Тверская область, Осташковский район, дер.Занепречье, административное здание Замошского сельского поселения		0101000020E61000007FBE2D58AA734040630CACE3F87B4C40
2166	1	15	1026	9988	\N	\N	57.099981	Тверская область, Осташковский район, дер.Замошье, помещение администрации Замошского сельского помещения		0101000020E6100000CBB91457958B4040569C6A2DCC8C4C40
2160	1	15	1026	9680	\N	\N	57.296588999999997	Тверская область, Осташковский район, дер.Задубье, административное здание Мошенского сельского поселения		0101000020E610000091D61874428040403AADDBA0F6A54C40
2156	1	15	1026	9491	\N	\N	57.110080000000004	Тверская область, Осташковский район, дер.Жданово, помещение администрации Ждановского сельского поселения		0101000020E6100000A6F10BAF24C54040CBF8F719178E4C40
2131	1	15	608	8403	\N	\N	56.161513999999997	Тверская область, Оленинский район, дер.Холмина, Здание школы		0101000020E61000003D1059A489C540404EECA17DAC144C40
2139	1	15	608	8761	12149	\N	56.346494890250298	Тверская область, Оленинский район, дер.Холмец, ул.Советская, д.2	Россия, Тверская область, Оленинский район, поселок Холмец	0101000020E6100000B3D1393FC5AD40401F9DBAF2592C4C40
2133	1	15	608	8481	\N	\N	56.109647000000002	Тверская область, Оленинский район, дер.Хлебники, Здание Хлебниковского территориального отдела	Россия, Тверская область, Оленинский район, поселок Хлебники	0101000020E61000007D2079E750E24040618DB3E9080E4C40
2128	1	15	608	8214	\N	\N	56.254302000000003	Тверская область, Оленинский район, дер.Толокново, Здание школы		0101000020E61000005F7B664980E2404059A7CAF78C204C40
2135	1	15	608	8576	12146	\N	56.165422999999997	Тверская область, Оленинский район, с.Татево, ул.Школьная, д.1		0101000020E61000006D59BE2EC3AD4040CB80B3942C154C40
2136	1	15	608	8603	12147	\N	56.069650000000003	Тверская область, Оленинский район, дер.Тархово, ул.Центральная, д.28		0101000020E61000008BC404357C9D40404D158C4AEA084C40
2126	1	15	608	8101	\N	\N	56.250596999999999	Тверская область, Оленинский район, дер.Сады, Здание Садовского территориального отдела		0101000020E6100000813FFCFCF7CE4040E4BCFF8F13204C40
2142	1	15	608	41049	\N	\N	56.864541000000003	"Тверская область, Оленинский район, дер.Отрадное. "	Россия, Тверская область, Торжокский район, поселок Отрадное	0101000020E610000001DBC1887D5C41408C868C47A96E4C40
2120	1	15	608	7795	12150	\N	56.208083999999999	Тверская область, пгт.Оленино, ул.Чехова, д.12		0101000020E61000006E4F90D8EEBE404012691B7FA21A4C40
2119	1	15	608	7795	12141	\N	56.208083999999999	Тверская область, пгт.Оленино, ул.Октябрьская, д.5		0101000020E61000006E4F90D8EEBE404012691B7FA21A4C40
2127	1	15	608	8184	\N	\N	56.215563000000003	Тверская область, Оленинский район, дер.Никулино, Здание школы		0101000020E6100000E4BCFF8F13E44040249D8191971B4C40
2121	1	15	608	7883	\N	\N	56.422593999999997	Тверская область, Оленинский район, с.Молодой Туд, Здание школы		0101000020E6100000DE3EABCC94CE40402FBE688F17364C40
2122	1	15	608	7916	12143	\N	56.232989000000003	Тверская область, Оленинский район, пос.Мирный, ул.Юбилейная, д.12		0101000020E610000018265305A3964040F4A96395D21D4C40
2124	1	15	608	8004	12144	\N	56.255431999999999	Тверская область, Оленинский район, дер.Козлы, ул.Центральная, д.6а		0101000020E61000006C04E275FDAA40400A2DEBFEB1204C40
2140	1	15	608	8779	\N	\N	56.332555999999997	Тверская область, Оленинский район, дер.Ильенки, Здание Первомайского территориального отдела		0101000020E6100000D7A3703D0ABF4040560BEC31912A4C40
2123	1	15	608	7973	\N	\N	56.310408000000002	Тверская область, Оленинский район, с.Знаменское, Здание школы		0101000020E6100000C0046EDDCD9B404059350873BB274C40
2132	1	15	608	8416	\N	\N	56.138838999999997	Тверская область, Оленинский район, дер.Завидово, Здание Завидовского территориального отдела		0101000020E6100000ADF886C267D140406534F279C5114C40
2134	1	15	608	8512	\N	\N	56.109386000000001	Тверская область, Оленинский район, дер.Гусево, Здание школы		0101000020E610000000C8091346AD4040F451465C000E4C40
2129	1	15	608	8296	\N	\N	56.112487999999999	Тверская область, Оленинский район, дер.Гришино, Здание школы		0101000020E6100000AD50A4FB39C34040A298BC01660E4C40
2138	1	15	608	8694	\N	\N	55.939928000000002	Тверская область, Оленинский район, дер.Городок, Здание Городковского территориального отдела		0101000020E6100000BA83D89942C740401F4C8A8F4FF84B40
2125	1	15	608	8088	12145	\N	56.218411000000003	Тверская область, Оленинский район, дер.Глазки, ул.Центральная, д.5		0101000020E6100000200A664CC1C24040180B43E4F41B4C40
2137	1	15	608	8687	12148	\N	55.950735999999999	Тверская область, Оленинский район, дер.Воротьково, ул.Советская, д.29		0101000020E6100000F8C43A55BEB540409F909DB7B1F94B40
2130	1	15	608	8313	\N	\N	56.172429999999999	Тверская область, Оленинский район, дер.Воронино, Здание Воронинского территориального отдела		0101000020E6100000213A048E04BE4040B56CAD2F12164C40
2141	1	15	608	8851	12151	\N	56.408318000000001	Тверская область, Оленинский район, дер.Большая Каденка, ул.Центральная, д.5		0101000020E6100000C70DBF9B6EA940401F2FA4C343344C40
2042	1	15	608	3855	\N	\N	56.258918000000001	Тверская область, Оленинский район, дер.Бобровка, Здание школы		0101000020E6100000E89FE06245BF4040412C9B3924214C40
2107	1	15	804	41045	\N	\N	56.263066999999999	Тверская область, Нелидовский район, пос.Заповедный, Помещение Дома досуга	Россия, Тверская область, Нелидовский район	0101000020E6100000C74B37894160404013D4F02DAC214C40
2165	1	15	804	6958	\N	\N	56.196241000000001	Тверская область, Осташковский район, пос.Южный, помещение Дома культуры	Россия, Тверская область, Нелидовский район, поселок Южный	0101000020E6100000020CCB9F6F6540403291D26C1E194C40
2101	1	15	804	6958	\N	\N	56.196241000000001	Тверская область, Нелидовский район, пос.Южный, Помещение Дома досуга		0101000020E6100000020CCB9F6F6540403291D26C1E194C40
2099	1	15	804	6958	12135	\N	56.195644411548798	"Тверская область, г.Нелидово, пос.Южный, Бельское шоссе, 2-й км, помещение ""ДРСУ"""	Россия, Тверская область, Нелидовский район, поселок Южный	0101000020E610000034828DEBDF6540404ED4D2DC0A194C40
2104	1	15	804	7092	\N	\N	56.285578000000001	Тверская область, Нелидовский район, дер.Старое Кутьево, Помещение ФАП НМУ ЦРБ		0101000020E6100000363D282845614040823AE5D18D244C40
2108	1	15	804	7278	\N	\N	56.293112000000001	Тверская область, Нелидовский район, дер.Селы, Помещение администрации с/п		0101000020E610000048E17A14AE8540405708ABB184254C40
2105	1	15	804	7145	\N	\N	56.407915000000003	Тверская область, Нелидовский район, дер.Пустое Подлесье, Помещение школы		0101000020E6100000AFB0E07EC06140402046088F36344C40
2109	1	15	804	7343	\N	\N	56.227964999999998	Тверская область, Нелидовский район, дер.Паникля, Помещение Нелидовского психоневрологического интерната		0101000020E610000068B114C957784040FAD005F52D1D4C40
2111	1	15	804	7428	\N	\N	56.064756000000003	Тверская область, Нелидовский район, дер.Новоселки, Помещение администрации с/п		0101000020E61000000F441669E26B4040221CB3EC49084C40
2077	1	15	804	5697	12108	\N	56.261713	Тверская область, г.Нелидово, ул.Советская, д.33		0101000020E6100000AB3E575BB169404012F8C3CF7F214C40
2619	1	15	804	31769	\N	\N	56.065810999999997	Тверская область, Нелидовский район, пос.Монино, Административное здание ФБУ-ИК-9		0101000020E6100000DFDE35E84B674040C85BAE7E6C084C40
2102	1	15	804	6984	\N	\N	56.208343999999997	Тверская область, Нелидовский район, пос.Межа, Помещение Дома досуга		0101000020E610000011AB3FC230604040AE282504AB1A4C40
2630	1	15	804	32272	\N	\N	56.102122000000001	Тверская область, Нелидовский район, дер.Кривцово, Помещение ФАП НМУ ЦРБ		0101000020E6100000ACE28DCC23634040DF196D55120D4C40
2629	1	15	804	32229	\N	\N	56.031804999999999	Тверская область, Нелидовский район, пос.Копейки, Помещение ФАП НМУ ЦРБ		0101000020E610000024D5777E516A4040B56CAD2F12044C40
2116	1	15	804	7555	\N	\N	56.244790000000002	Тверская область, Нелидовский район, пос.Земцы, Помещение ИП Степанова		0101000020E6100000C1560916872B4040A5315A47551F4C40
2115	1	15	804	7555	\N	\N	56.244790000000002	Тверская область, Нелидовский район, пос.Земцы, Помещение администрации с/п		0101000020E6100000C1560916872B4040A5315A47551F4C40
2114	1	15	804	7555	\N	\N	56.244694464244802	Тверская область, Нелидовский район, пос.Земцы, Помещение школы	Россия, Тверская область, Нелидовский район, поселок Земцы	0101000020E6100000F0DAA50D872B404083C30B22521F4C40
2100	1	15	804	6884	\N	\N	56.210721999999997	Тверская область, Нелидовский район, пос.Загородный, Помещение Нелидовского психоневрологического интерната, д.1а		0101000020E610000093382BA2266840401B4641F0F81A4C40
2113	1	15	804	7536	\N	\N	56.157407999999997	Тверская область, Нелидовский район, дер.Горки, Помещение ФАП НМУ ЦРБ		0101000020E61000005E2EE23B316540407B1002F225144C40
2106	1	15	804	7177	\N	\N	56.383533	Тверская область, Нелидовский район, дер.Высокое, Помещение администрации с/п		0101000020E61000008D45D3D9C9704040E8F7FD9B17314C40
2618	1	15	804	31718	\N	\N	56.068148000000001	Тверская область, Нелидовский район, дер.Верхнее Заборье, Помещение ФАП НМУ ЦРБ		0101000020E6100000CDACA580B47B4040D7A4DB12B9084C40
2617	1	15	804	31704	\N	\N	56.355954105446997	Тверская область, Нелидовский район, пос.Арбузово, Помещение администрации с/п	Россия, Тверская область, Нелидовский район, поселок Арбузово	0101000020E6100000F86BB2463D3C4040B07092E68F2D4C40
2075	1	15	697	5620	\N	\N	58.109566999999998	Тверская область, Молоковский район, дер.Черкасово, здание Черкасовской начальной  общеобразовательной школы		0101000020E61000000C59DDEA3973424044DC9C4A060E4D40
2068	1	15	697	5218	\N	\N	58.209811000000002	Тверская область, Молоковский район, дер.Тушитово, здание Тушитовской начальной общеобразовательной школы		0101000020E6100000FD82DDB06D534240A8AB3B16DB1A4D40
2070	1	15	697	5354	\N	\N	58.118760999999999	Тверская область, Молоковский район, дер.Рамешки, здание Рамешинской сельской библиотеки	Россия, Тверская область, Молоковский район, поселок Рамешки	0101000020E610000082FE428F185F42402785798F330F4D40
2063	1	15	697	4959	\N	\N	58.199562999999998	Тверская область, Молоковский район, дер.Покров, здание Покровской сельской библиотеки		0101000020E6100000A04FE449D2234240EE3EC7478B194D40
2073	1	15	697	5513	\N	\N	58.031595000000003	Тверская область, Молоковский район, дер.Подертово, здание Суборьской сельской библиотеки		0101000020E610000022FC8BA031534240CBDB114E0B044D40
2071	1	15	697	5380	\N	\N	58.028120999999999	Тверская область, Молоковский район, дер.Обросово, здание Обросовской основной общеобразовательной школы		0101000020E61000001B12F758FA46424058AA0B7899034D40
2061	1	15	697	4860	12276	\N	58.163865999999999	Тверская область, п.Молоково, пл.Корнилова, д.4	Россия, Тверская область, Молоковский район, поселок Молоково	0101000020E6100000D7506A2FA26142409276A38FF9144D40
2069	1	15	697	4860	12106	\N	58.164727816854601	Тверская область, п.Молоково, ул.Ленина, д.19	Россия, Тверская область, Молоковский район, поселок Молоково	0101000020E6100000D8B8FE5D9F614240245E9ECE15154D40
2060	1	15	697	4860	12106	\N	58.163865999999999	Тверская область, п.Молоково, ул.Ленина, д.22	Россия, Тверская область, Молоковский район, поселок Молоково	0101000020E6100000D7506A2FA26142409276A38FF9144D40
2072	1	15	697	41022	\N	\N	58.061112000000001	Тверская область, Молоковский район, дер.Кар.Городок, здание Каргородковской начальной общеобразовательной школы	Россия, Тверская область, Молоковский район, поселок Карельский Городок	0101000020E6100000C87E164B9140424053B29C84D2074D40
2064	1	15	697	5038	\N	\N	58.241036999999999	Тверская область, Молоковский район, с.Деледино, здание Делединской основной общеобразовательной школы		0101000020E61000000CCEE0EF177542401F10E84CDA1E4D40
2065	1	15	697	41021	\N	\N	58.141570000000002	Тверская область, Молоковский район, дер.Бикалово, здание отделения почтовой связи	Россия, Тверская область, Молоковский район, поселок Биколово	0101000020E6100000CCB392567C494240200C3CF71E124D40
2062	1	15	697	4945	\N	\N	58.203522999999997	Тверская область, Молоковский район, с.Ахматово, здание  Ахматовской  основной общеобразовательной школы		0101000020E6100000BA2D910BCE3E4240ED7DAA0A0D1A4D40
2074	1	15	697	5541	\N	\N	58.143374999999999	Тверская область, Молоковский район, с.Антоновское, здание Антоновской основной общеобразовательной школы		0101000020E6100000E4F560527C7842403108AC1C5A124D40
2066	1	15	697	5124	\N	\N	58.284444999999998	Тверская область, Молоковский район, дер.Андрейцево, здание Андрейцевской основной общеобразовательной школы		0101000020E6100000A3C9C518586542405F419AB168244D40
2054	1	15	545	4474	\N	\N	57.813338999999999	Тверская область, Максатихинский район, дер.Фабрика, Помещение сельского Дома культуры		0101000020E61000007B336ABE4AF24140DAC70A7E1BE84C40
2058	1	15	545	4740	\N	\N	58.006874000000003	Тверская область, Максатихинский район, пос.Труженик, Помещение Труженицкого сельского Дома культуры		0101000020E6100000B3D1393FC5D34140AB984A3FE1004D40
2057	1	15	545	4671	\N	\N	57.529530000000001	Тверская область, Максатихинский район, дер.Трестна, Помещение администрации Трестенского сельского поселения		0101000020E610000059C2DA183BFB41401D2098A3C7C34C40
2039	1	15	545	3718	\N	\N	57.800525999999998	Тверская область, Максатихинский район, дер.Сидорково, Помещение Сидорковского сельского Дома культуры		0101000020E6100000B1A71DFE9A0A424081CCCEA277E64C40
2055	1	15	545	4571	\N	\N	57.949272999999998	Тверская область, Максатихинский район, с.Сельцы, Помещение администрации Селецкого сельского поселения		0101000020E6100000401361C3D3FD4140E7FC14C781F94C40
2053	1	15	545	4443	\N	\N	57.817428	Тверская область, Максатихинский район, дер.Рыбинское Заручье, Помещение администрации Рыбинского сельского поселения		0101000020E6100000BD361B2B31FF4140D76A0F7BA1E84C40
2051	1	15	545	4336	\N	\N	57.846812	Тверская область, Максатихинский район, дер.Ручки, Помещение администрации Ручковского сельского поселения		0101000020E61000002D08E57D1CE5414020EEEA5564EC4C40
2049	1	15	545	4221	\N	\N	57.620032999999999	Тверская область, Максатихинский район, пос.Ривицкий, Помещение администрации Ривицкого сельского поселения		0101000020E6100000AAF3A8F8BFF341406BB8C83D5DCF4C40
2045	1	15	545	4022	\N	\N	57.874864000000002	Тверская область, Максатихинский район, с.Раевское, Помещение сельской библиотеки		0101000020E6100000632992AF04CC41405039268BFBEF4C40
2047	1	15	545	4136	\N	\N	57.733392000000002	Тверская область, Максатихинский район, дер.Пальчиха, Помещение администрации Пальчихинского сельского поселения		0101000020E6100000A583F57F0E034240F392FFC9DFDD4C40
2059	1	15	545	41020	\N	\N	58.028081999999998	Тверская область, Максатихинский район, дер.Ново-Пхово, Помещение сельского Дома культуры	Россия, Тверская область, Максатихинский район, поселок Новое Пхово	0101000020E610000068E6C93505C241409ACDE33098034D40
2013	1	15	333	2088	12081	\N	57.123640999999999	Тверская область, г.Лихославль, ул.Афанасьева, д.2		0101000020E61000008061F9F36DBB4140EDB8E177D38F4C40
2043	1	15	545	3895	\N	\N	57.8375537689232	Тверская область, Максатихинский район, пос.Малышево, Помещение администрации Малышевского сельского поселения	Россия, Тверская область, Максатихинский район, поселок Малышево	0101000020E610000097ADF54542D1414026512FF834EB4C40
2035	1	15	545	3351	12096	\N	57.793211999999997	Тверская область, пос.Максатиха, ул.Пролетарская, д.1	Россия, Тверская область, Максатихинский район, поселок Максатиха	0101000020E6100000E21E4B1FBAF04140BA6587F887E54C40
2032	1	15	545	3351	12097	\N	57.793211999999997	Тверская область, пос.Максатиха, ул.Парковская, д.50		0101000020E6100000E21E4B1FBAF04140BA6587F887E54C40
2033	1	15	545	3351	12094	\N	57.793211999999997	Тверская область, пос.Максатиха, ул.Красноармейская, д.58		0101000020E6100000E21E4B1FBAF04140BA6587F887E54C40
2034	1	15	545	3351	12095	\N	57.793211999999997	Тверская область, пос.Максатиха, ул.Краснослободская, д.7		0101000020E6100000E21E4B1FBAF04140BA6587F887E54C40
2041	1	15	545	3803	\N	\N	57.694422000000003	Тверская область, Максатихинский район, с.Кострецы, Помещение администрации Кострецкого сельского поселения		0101000020E6100000BCC96FD1C9DE4140BCCFF1D1E2D84C40
2048	1	15	545	4180	\N	\N	57.630144000000001	Тверская область, Максатихинский район, дер.Ключевая, Помещение администрации Пальчихинского сельского поселения		0101000020E6100000C0266BD443104240A4E2FF8EA8D04C40
2044	1	15	545	3946	\N	\N	57.789335999999999	Тверская область, Максатихинский район, дер.Кистутово, Помещение Кистутовской средней школы		0101000020E6100000492F6AF7ABCA414019C748F608E54C40
2040	1	15	545	3758	\N	\N	57.7134284202114	Тверская область, Максатихинский район, с.Каменка, Помещение администрации Каменского сельского поселения	Россия, Тверская область, Максатихинский район, поселок Каменка	0101000020E6100000A29C685721B541407D06D49B51DB4C40
2046	1	15	545	4030	\N	\N	57.762963999999997	"Тверская область, Максатихинский район, дер.Засека, Помещение конторы СПК ""Засека"""		0101000020E61000000EF62686E4DA41403E03EACDA8E14C40
2038	1	15	545	41012	\N	\N	57.769483000000001	Тверская область, Максатихинский район, хут.Заречье, Помещение Зареченского сельского Дома культуры	Россия, Тверская область, Максатихинский район, поселок Заречье	0101000020E6100000F607CA6DFBF64140FBE93F6B7EE24C40
2056	1	15	545	4608	\N	\N	58.063310999999999	Тверская область, Максатихинский район, дер.Дымцево, Помещение администрации Селецкого сельского поселения		0101000020E610000066C0594A96F14140103D29931A084D40
2037	1	15	545	3618	\N	\N	58.127482999999998	Тверская область, Максатихинский район, дер.Дубищи, Помещение Дубищенской основной общеобразовательной школы		0101000020E61000006519E25817134240E2E5E95C51104D40
2052	1	15	545	4375	\N	\N	57.876280999999999	Тверская область, Максатихинский район, дер.Горка, Помещение сельского Дома культуры		0101000020E6100000C87BD5CA84E34140978DCEF929F04C40
2036	1	15	545	3566	\N	\N	58.050778999999999	Тверская область, Максатихинский район, дер.Буденовка, Помещение администрации Буденовского сельского поселения		0101000020E610000005C3B986190E42406B2920ED7F064D40
2050	1	15	545	41019	\N	\N	57.610103000000002	Тверская область, Максатихинский район, дер.Большая Воздвиженка, Помещение фельдшерско-акушерского пункта	Россия, Тверская область, Максатихинский район, поселок Большая Воздвиженка	0101000020E6100000BAA46ABB09E641408318E8DA17CE4C40
2004	1	15	333	1727	\N	\N	57.359473000000001	Тверская область, Лихославльский район, дер.Язвиха, д.53		0101000020E61000006D5512D907C54140C365153603AE4C40
2009	1	15	333	2026	12076	\N	57.430787000000002	Тверская область, Лихославльский район, с.Толмачи, ул.Больничная 1-я, д.2		0101000020E6100000522CB7B41AD841405F45460724B74C40
2003	1	15	333	1682	\N	\N	57.382618000000001	Тверская область, Лихославльский район, дер.Стан, д.33		0101000020E6100000ABE80FCD3CB54140336E6AA0F9B04C40
2030	1	15	333	3245	\N	\N	57.218083999999998	Тверская область, Лихославльский район, дер.Сосновицы, д.113		0101000020E610000003B34291EEBB4140F3E32F2DEA9B4C40
2008	1	15	333	1965	\N	\N	57.449905999999999	Тверская область, Лихославльский район, дер.Прудово, д.62		0101000020E6100000601E32E543EE41401823128596B94C40
2026	1	15	333	3003	12091	\N	57.127374000000003	Тверская область, Лихославльский район, дер.Первитино, ул.Севастьянова, д.11		0101000020E6100000ED2C7AA702D641402C2E8ECA4D904C40
2022	1	15	333	2767	\N	\N	57.0336	Тверская область, Лихославльский район, пос.Осиновая Гряда, д.1А		0101000020E61000005C566133C0B34140A3923A014D844C40
2007	1	15	333	1894	\N	\N	57.528345999999999	Тверская область, Лихославльский район, дер.Назарово, д.83		0101000020E61000005401F73C7FE04140787C7BD7A0C34C40
2031	1	15	333	3290	\N	\N	57.256923999999998	Тверская область, Лихославльский район, дер.Михайлова Гора, д.53		0101000020E6100000FAB7CB7EDDBB41405CC7B8E2E2A04C40
2028	1	15	333	3117	\N	\N	57.241594999999997	Тверская область, Лихославльский район, с.Микшино, д.116		0101000020E610000027DD96C805DB414045F0BF95EC9E4C40
2014	1	15	333	2088	12082	\N	57.123640999999999	Тверская область, г.Лихославль, ул.Первомайская, д.13		0101000020E61000008061F9F36DBB4140EDB8E177D38F4C40
2010	1	15	333	2088	12077	\N	57.123640999999999	Тверская область, г.Лихославль, ул.Лихославльская, д.30Б		0101000020E61000008061F9F36DBB4140EDB8E177D38F4C40
2016	1	15	333	2088	12083	\N	57.123640999999999	Тверская область, г.Лихославль, ул.Комсомольская, д.66		0101000020E61000008061F9F36DBB4140EDB8E177D38F4C40
2015	1	15	333	2088	12083	\N	57.123640999999999	Тверская область, г.Лихославль, ул.Комсомольская, д.51		0101000020E61000008061F9F36DBB4140EDB8E177D38F4C40
2012	1	15	333	2088	12080	\N	57.123640999999999	Тверская область, г.Лихославль, ул.Гагарина, д.51		0101000020E61000008061F9F36DBB4140EDB8E177D38F4C40
2011	1	15	333	2088	12078	\N	57.123640999999999	Тверская область, г.Лихославль, ул.Бежецкая, д.24		0101000020E61000008061F9F36DBB4140EDB8E177D38F4C40
2025	1	15	333	2941	\N	\N	57.181451000000003	Тверская область, Лихославльский район, дер.Кузовино, д.105		0101000020E61000002D40DB6AD6C14140CB694FC939974C40
2023	1	15	333	2825	12090	\N	57.059002	Тверская область, Лихославльский район, пос.Крючково, ул.Комсомольская, д.18		0101000020E6100000A41820D104C441400533A6608D874C40
2018	1	15	333	2483	12084	\N	57.281812000000002	Тверская область, Лихославльский район, пос.Калашниково, ул.Ленина, д.51		0101000020E610000016889E94499D414068CF656A12A44C40
2017	1	15	333	2483	12084	\N	57.281812000000002	Тверская область, Лихославльский район, пос.Калашниково, ул.Ленина, д.45		0101000020E610000016889E94499D414068CF656A12A44C40
2024	1	15	333	2891	\N	\N	57.133153	Тверская область, Лихославльский район, дер.Кава, д.40		0101000020E6100000A8FFACF9F1C34140A12E52280B914C40
2020	1	15	333	2654	12086	\N	57.091903000000002	Тверская область, Лихославльский район, с.Ильинское, ул.Молодежная, д.21		0101000020E61000000EF62686E4AE4140C0B33D7AC38B4C40
2029	1	15	333	3173	\N	\N	57.339562999999998	Тверская область, Лихославльский район, с.Залазино, д.47А		0101000020E61000006C95607138D5414040F7E5CC76AB4C40
2005	1	15	333	1784	\N	\N	57.412801999999999	Тверская область, Лихославльский район, дер.Гнездово, д.94		0101000020E610000021AF0793E2BF414098DC28B2D6B44C40
2027	1	15	333	3055	\N	\N	57.180202000000001	Тверская область, Лихославльский район, с.Вышково, д.25		0101000020E61000003FE0810184D141403F56F0DB10974C40
2021	1	15	333	2704	12087	\N	57.067894000000003	Тверская область, Лихославльский район, дер.Вески, ул.Центральная, д.14А		0101000020E610000069E4F38AA7BA41401DCC26C0B0884C40
2006	1	15	333	1839	\N	\N	57.485483000000002	Тверская область, Лихославльский район, дер.Березовка, д.39А		0101000020E61000009301A08A1BCB4140CAE1934E24BE4C40
2019	1	15	333	2595	\N	\N	57.203631000000001	Тверская область, Лихославльский район, дер.Барановка, д.6		0101000020E6100000C4B2994352AB4140D4B9A294109A4C40
2002	1	15	333	1583	\N	\N	57.302230000000002	Тверская область, Лихославльский район, дер.Анцифарово, д.8		0101000020E6100000C959D8D30EB141405FEFFE78AFA64C40
1999	1	15	211	1455	12074	\N	58.04945	Тверская область, Лесной район, дер.Телятники, ул.Центральная, д.86		0101000020E61000009240834D9DD74140C364AA6054064D40
2308	1	15	211	16618	\N	\N	58.229334999999999	Тверская область, пос.Спирово, ул.Дачная, д.16	Россия, Тверская область, Лесной район, поселок Спирово	0101000020E610000033F9669B1BBF4140016A6AD95A1D4D40
2305	1	15	211	16618	\N	\N	58.229334999999999	Тверская область, пос.Спирово, пл.Советская, д.5	Россия, Тверская область, Лесной район, поселок Спирово	0101000020E610000033F9669B1BBF4140016A6AD95A1D4D40
1997	1	15	211	1342	12072	\N	58.401193999999997	Тверская область, Лесной район, с.Никольское, ул.Центральная, д.22		0101000020E61000002F4FE78A52D44140FBAC32535A334D40
1996	1	15	211	1253	12071	\N	58.169473000000004	Тверская область, Лесной район, дер.Мотыли, ул.Речная, д.10		0101000020E6100000310917F208BE41400B47904AB1154D40
1995	1	15	211	1230	12069	\N	58.380279000000002	Тверская область, Лесной район, с.Михайловское, ул.Советская, д.26		0101000020E6100000438F183DB7BE4140842D76FBAC304D40
1994	1	15	211	1128	12068	\N	58.243054999999998	Тверская область, Лесной район, пос.Медведково, ул.Новая, д.21		0101000020E6100000FAEC80EB8AC941408C101E6D1C1F4D40
1993	1	15	211	1108	12067	\N	58.286360999999999	Тверская область, с.Лесное, ул.Советская, д.3		0101000020E610000083C30B2252C34140C8EC2C7AA7244D40
1998	1	15	211	1108	12073	\N	58.286360999999999	Тверская область, с.Лесное, ул.Речная, д.23		0101000020E610000083C30B2252C34140C8EC2C7AA7244D40
1992	1	15	211	1004	12066	\N	58.115442999999999	Тверская область, Лесной район, дер.Кожина Гора, ул.Ленина, д.28		0101000020E6100000622EA9DA6EB84140ACC612D6C60E4D40
1991	1	15	211	989	12065	\N	58.325181000000001	Тверская область, Лесной район, дер.Застровье, ул.Речная, д.16		0101000020E61000006495D233BDBC4140EA23F0879F294D40
1990	1	15	211	913	12064	\N	58.251533000000002	Тверская область, Лесной район, дер.Городок, ул.Центральная, д.52		0101000020E610000052D2C3D0EAC24140B16EBC3B32204D40
1988	1	15	211	802	12062	\N	58.257452000000001	Тверская область, Лесной район, с.Борисовское, ул.Береговая, д.4		0101000020E610000045BDE0D39CF841401825E82FF4204D40
1989	1	15	211	864	12063	\N	58.210749999999997	Тверская область, Лесной район, дер.Бор-Пруды, ул.Центральная, д.25		0101000020E61000002385B2F0F5A54140E5D022DBF91A4D40
2001	1	15	211	1571	12075	\N	58.161721	Тверская область, Лесной район, с.Алексейково, ул.Центральная, д.42		0101000020E61000009B8E006E16B74140C8091346B3144D40
1986	1	15	45	679	\N	\N	57.014291999999998	Тверская область, Кувшиновский район, с.Тысяцкое, здание администрации сельского поселения		0101000020E6100000333674B33F204140164CFC51D4814C40
1979	1	15	45	227	\N	\N	56.895181999999998	Тверская область, Кувшиновский район, пос.Сокольники, здание администрации сельского поселения		0101000020E61000006DACC43C2B054140E3FBE25295724C40
1978	1	15	45	163	12060	\N	56.939641999999999	Тверская область, Кувшиновский район, пос.Ранцево, ул.Трудовая, д.4		0101000020E6100000C443183F8D05414059F9653046784C40
1985	1	15	45	611	\N	\N	56.936691000000003	Тверская область, Кувшиновский район, с.Прямухино, здание Прямухинской средней школы		0101000020E6100000960A2AAA7E39414091BA9D7DE5774C40
1984	1	15	45	550	\N	\N	57.029896999999998	Тверская область, Кувшиновский район, дер.Пречисто-Каменка, здание администрации сельского поселения		0101000020E6100000E200FA7DFF3E4140CF9F36AAD3834C40
1983	1	15	45	492	\N	\N	57.082071999999997	Тверская область, Кувшиновский район, дер.Пень, здание администрации сельского поселения		0101000020E61000000DAB7823F31241406AF5D555818A4C40
1977	1	15	45	53	\N	\N	57.079645999999997	Тверская область, Кувшиновский район, дер.Могилевка, здание администрации сельского поселения		0101000020E6100000A017EE5C18E54040ECA012D7318A4C40
1972	1	15	45	731	\N	\N	57.027315999999999	"Тверская область, г.Кувшиново, административное здание ООО ""Баховка"""		0101000020E61000004A0A2C80291541402A5437177F834C40
92519	1	14	684	46574	25482	\N	52.217613999999998	Лукино село, Проезжая, 4		0101000020E6100000BF9EAF592E0D45406C938AC6DA1B4A40
1957	1	15	45	731	12041	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.Степана Разина, д.55		0101000020E61000004A0A2C80291541402A5437177F834C40
1966	1	15	45	731	12042	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.Советская, д.55		0101000020E61000004A0A2C80291541402A5437177F834C40
1969	1	15	45	731	12050	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.Пионерский бульвар, д.9		0101000020E61000004A0A2C80291541402A5437177F834C40
1987	1	15	45	731	12061	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.Октябрьская, д.16		0101000020E61000004A0A2C80291541402A5437177F834C40
1967	1	15	45	731	12043	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.Карла Маркса, д.1		0101000020E61000004A0A2C80291541402A5437177F834C40
1971	1	15	45	731	12048	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.Бумажников, д.14		0101000020E61000004A0A2C80291541402A5437177F834C40
1970	1	15	45	731	12046	\N	57.027315999999999	Тверская область, г.Кувшиново, ул.8 Марта, д.5		0101000020E61000004A0A2C80291541402A5437177F834C40
1976	1	15	45	41007	\N	\N	57.179020999999999	Тверская область, Кувшиновский район, пос.Красный Городок, здание Красногородской школы	Россия, Тверская область, Кувшиновский район, поселок Красный Городок	0101000020E6100000E4141DC9E5DB40400B26FE28EA964C40
1975	1	15	45	32428	\N	\N	56.9026	Тверская область, Кувшиновский район, с.Заовражье, здание Заовражской ООШ		0101000020E61000001C412AC58E2841404FAF946588734C40
1974	1	15	45	32407	\N	\N	56.985736000000003	Тверская область, Кувшиновский район, дер.Васильково, здание администрации сельского поселения		0101000020E6100000A438471D1D154140B43EE5982C7E4C40
1981	1	15	45	356	\N	\N	57.214565	Тверская область, Кувшиновский район, с.Борзыни, здание Борзынской ООШ		0101000020E610000033C2DB8310224140E1EEACDD769B4C40
1982	1	15	45	426	\N	\N	56.980694	Тверская область, Кувшиновский район, с.Большой Борок, здание администрации сельского поселения		0101000020E6100000CB64389ECF3C414014B18861877D4C40
1980	1	15	45	298	\N	\N	57.085940999999998	Тверская область, Кувшиновский район, дер.Большое Кузнечково, здание сельского Дома Культуры		0101000020E6100000853FC39B3532414059315C1D008B4C40
1950	1	15	1266	31301	\N	\N	57.935969	Тверская область, Краснохолмский район, дер.Юрово, Здание администрации Большерагозинского сельского поселения		0101000020E61000004390831266964240F0880AD5CDF74C40
1955	1	15	1266	31553	\N	\N	58.135598999999999	"Тверская область, Краснохолмский район, с.Хабоцкое, Здание МОУ ""Хабоцкая СОШ"""		0101000020E61000002E58AA0B78834240662FDB4E5B114D40
1965	1	15	1266	32010	\N	\N	58.156089000000001	Тверская область, Краснохолмский район, дер.Ульянино, Здание администрации Ульянинского сельского поселения		0101000020E610000099A0866F618D4240F7216FB9FA134D40
1964	1	15	1266	31971	\N	\N	58.096018000000001	Тверская область, Краснохолмский район, дер.Толстиково, Здание администрации Утеховского сельского поселения		0101000020E6100000DCB75A272E994240E6E95C514A0C4D40
1952	1	15	1266	31415	\N	\N	58.061458999999999	Тверская область, Краснохолмский район, дер.Скоросово, Здание Скоросовского СДК		0101000020E610000097CADB114E7B4240BE8575E3DD074D40
1962	1	15	1266	31874	\N	\N	58.111182999999997	"Тверская область, Краснохолмский район, с.Рачево, Зданик МОУ ""Рачевская начальная школа-детский сад"""		0101000020E61000007784D38217B94240826F9A3E3B0E4D40
1574	1	15	1266	13170	\N	\N	58.261671	Тверская область, Весьегонский район, пос.Овинищи, Здание библиотеки		0101000020E6100000C47B0E2C47864240E3A7716F7E214D40
1961	1	15	1266	31836	\N	\N	58.085147999999997	Тверская область, Краснохолмский район, дер.Нивы, Здание администрации Нивского сельского поселения		0101000020E6100000FACF9A1F7FB94240EFA83121E60A4D40
1958	1	15	1266	31708	\N	\N	58.354987999999999	Тверская область, Краснохолмский район, с.Мартыново, Здание администрации Мартыновского сельского поселения		0101000020E6100000D90A9A9658A34240793C2D3F702D4D40
1947	1	15	1266	31023	12040	\N	58.061430999999999	Тверская область, г.Красный Холм, ул.Пионерская, д.2		0101000020E6100000143DF031588F4240F4FA93F8DC074D40
1944	1	15	1266	31023	12037	\N	58.061430999999999	Тверская область, г.Красный Холм, ул.Октябрьская, д.1/13		0101000020E6100000143DF031588F4240F4FA93F8DC074D40
1946	1	15	1266	31023	12039	\N	58.061430999999999	Тверская область, г.Красный Холм, ул.Мясникова, д.34		0101000020E6100000143DF031588F4240F4FA93F8DC074D40
1945	1	15	1266	31023	12038	\N	58.061430999999999	Тверская область, г.Красный Холм, ул.Калинина, д.37		0101000020E6100000143DF031588F4240F4FA93F8DC074D40
1954	1	15	1266	31516	\N	\N	58.014387999999997	Тверская область, Краснохолмский район, дер.Ивакино, Здание Ивакинского СДК		0101000020E610000092EA3BBF28AB424038BA4A77D7014D40
1956	1	15	1266	31613	\N	\N	58.242885000000001	"Тверская область, Краснохолмский район, дер.Дмитровка, Здание МОУ ""Дмитровская ООШ"""		0101000020E6100000C6C210397D85424030D80DDB161F4D40
1949	1	15	1266	31245	\N	\N	57.899521389517403	Тверская область, Краснохолмский район, дер.Грудино, Здание библиотеки, д.31	Россия, Тверская область, Краснохолмский район, поселок Грудино	0101000020E61000003FADA23F3487424059880E8123F34C40
1953	1	15	1266	31460	\N	\N	58.070638000000002	Тверская область, Краснохолмский район, дер.Глебени, Здание администрации Глебенского сельского поселения		0101000020E6100000C0B4A84F729B42406CED7DAA0A094D40
1951	1	15	1266	31348	\N	\N	58.020398999999998	Тверская область, Краснохолмский район, дер.Высокуша, Здание администрации Высокушинского сельского поселения		0101000020E6100000E2016553AE7E424080EF366F9C024D40
1959	1	15	1266	31733	\N	\N	58.295344	Тверская область, Краснохолмский район, дер.Васильки, Здание медпункта		0101000020E61000003A3C84F1D3B04240F0880AD5CD254D40
1800	1	15	203	24322	11921	\N	57.205240000000003	Тверская область, Калязинский район, дер.Липовка, ул.Центральная, д.1		0101000020E6100000992B836A83FD424060EAE74D459A4C40
1960	1	15	1266	31784	\N	\N	58.278185000000001	Тверская область, Краснохолмский район, дер.Братское	Россия, Тверская область, Краснохолмский район, поселок Братское	0101000020E61000007F85CC95419342406F9EEA909B234D40
1963	1	15	1266	31922	\N	\N	58.064421000000003	Тверская область, Краснохолмский район, дер.Бекрень, Здание Бекренской сельской библиотеки		0101000020E610000019E6046D72C242407B1684F23E084D40
1948	1	15	1266	31206	\N	\N	58.027687	Тверская область, Краснохолмский район, дер.Барбино, Здание администрации Барбинского сельского поселения		0101000020E6100000C8D2872EA88B42401EC3633F8B034D40
1924	1	15	1850	30023	12021	\N	56.702604000000001	Тверская область, Конаковский район, с.Юрьево-Девичье, ул.Центральная, д.16а		0101000020E61000009DF6949C13534240F70489EDEE594C40
1896	1	15	1850	28741	\N	\N	56.671661999999998	"Тверская область, Конаковский район, пос.Энергетик, База отдыха ""Энергетик"""		0101000020E610000068942EFD4B584240A4FB3905F9554C40
1929	1	15	1850	30256	12026	\N	56.666373999999998	Тверская область, Конаковский район, дер.Старое Мелково, ул.Парковая, д.1		0101000020E6100000753A90F5D4364240CD7344BE4B554C40
1922	1	15	1850	29906	12019	\N	56.661763999999998	Тверская область, Конаковский район, с.Селихово, ул.Новая, д.13		0101000020E6100000C76471FF91674240C7D5C8AEB4544C40
1936	1	15	1850	30361	12033	\N	56.651823999999998	Тверская область, Конаковский район, пос.Редкино, просп.Химиков, д.42		0101000020E61000003CBEBD6BD0254240BB5F05F86E534C40
1931	1	15	1850	30361	12028	\N	56.651823999999998	Тверская область, Конаковский район, пос.Редкино, ул.Фадеева, д.3		0101000020E61000003CBEBD6BD0254240BB5F05F86E534C40
1933	1	15	1850	30361	12030	\N	56.651823999999998	Тверская область, Конаковский район, пос.Редкино, ул.Правды, д.8		0101000020E61000003CBEBD6BD0254240BB5F05F86E534C40
1934	1	15	1850	30361	12031	\N	56.651823999999998	Тверская область, Конаковский район, пос.Редкино, ул.Погрузочная, д.2а		0101000020E61000003CBEBD6BD0254240BB5F05F86E534C40
1932	1	15	1850	30361	12029	\N	56.651823999999998	Тверская область, Конаковский район, пос.Редкино, ул.Калинина, д.4а		0101000020E61000003CBEBD6BD0254240BB5F05F86E534C40
1935	1	15	1850	30361	12032	\N	56.651823999999998	Тверская область, Конаковский район, пос.Редкино, ул.Диева, д.33а		0101000020E61000003CBEBD6BD0254240BB5F05F86E534C40
1911	1	15	1850	29406	\N	\N	56.682727999999997	Тверская область, Конаковский район, пос.Радченко, здание ДК		0101000020E61000001F300F99F22F4240200890A163574C40
1923	1	15	1850	29973	12020	\N	56.852316999999999	Тверская область, Конаковский район, дер.Поповское, ул.Школьная, д.4		0101000020E61000005116BEBED6594240946934B9186D4C40
1938	1	15	1850	30694	12035	\N	56.644202999999997	Тверская область, Конаковский район, пос.Озерки, ул.Школьная, д.1		0101000020E610000014B18861871B4240177E703E75524C40
1914	1	15	1850	29461	12009	\N	56.553099000000003	Тверская область, Конаковский район, пос.Новозавидовский, ул.Фабричная, д.7-а		0101000020E6100000EF90628044374240A439B2F2CB464C40
1917	1	15	1850	29461	12012	\N	56.553099000000003	Тверская область, Конаковский район, пос.Новозавидовский, ул.Советская, д.8-а		0101000020E6100000EF90628044374240A439B2F2CB464C40
1916	1	15	1850	29461	12011	\N	56.553099000000003	Тверская область, Конаковский район, пос.Новозавидовский, ул.Парковая, д.7		0101000020E6100000EF90628044374240A439B2F2CB464C40
1912	1	15	1850	29461	12008	\N	56.553099000000003	Тверская область, Конаковский район, пос. Новозавидовский, ул.Моховая, д.1		0101000020E6100000EF90628044374240A439B2F2CB464C40
1915	1	15	1850	29461	12010	\N	56.553099000000003	Тверская область, Конаковский район, пос.Новозавидовский, ул.Ленинская, д.17		0101000020E6100000EF90628044374240A439B2F2CB464C40
1927	1	15	1850	30157	12024	\N	56.585586999999997	Тверская область, Конаковский район, дер.Мокшино, ул.Школьная, д.4		0101000020E6100000567F8461C04042403BFBCA83F44A4C40
1921	1	15	1850	29882	12017	\N	56.591836999999998	Тверская область, Конаковский район, дер.Ручьи, ул.Гаранина, д.12		0101000020E61000002BA226FA7C7C424008C89750C14B4C40
1941	1	15	1850	30871	\N	\N	56.724193	Тверская область, Конаковский район, дер.Кошелево, Здание библиотеки		0101000020E6100000354580D3BB224240FE7E315BB25C4C40
1918	1	15	1850	29730	12013	\N	56.508350999999998	Тверская область, Конаковский район, пос.Козлово, ул.Дм.Обушева, д.16		0101000020E61000008081204086224240C7F143A511414C40
1919	1	15	1850	29730	12014	\N	56.508350999999998	Тверская область, Конаковский район, пос.Козлово, пер.Дачный, д.6		0101000020E61000008081204086224240C7F143A511414C40
1897	1	15	1850	28785	\N	\N	56.687078999999997	"Тверская область, Конаковский район, дер.Карачарово, ЗАО СОЦ ""Карачарово"", ДК"		0101000020E6100000ECA2E8818F5942405A626534F2574C40
1937	1	15	1850	30666	12034	\N	56.625044000000003	Тверская область, Конаковский район, пос.Изоплит, ул.Пионерская, д.1а		0101000020E6100000EE974F560C1B4240D047197101504C40
1940	1	15	1850	30829	\N	\N	56.779677999999997	"Тверская область, Конаковский район, дер.Игуменка, Главный корпус пансионата ""Игуменка"""		0101000020E61000002A560DC2DC28424091B41B7DCC634C40
1942	1	15	1850	30926	\N	\N	56.640006	Тверская область, Конаковский район, дер.Заполок, Административное здание		0101000020E610000050357A35401F4240349F73B7EB514C40
1926	1	15	1850	30121	12023	\N	56.525359999999999	Тверская область, Конаковский район, с.Завидово, ул.Школьная, д.1а		0101000020E6100000FD6B79E57A434240335019FF3E434C40
1920	1	15	1850	29829	12015	\N	56.662371999999998	Тверская область, Конаковский район, с.Дмитрова Гора, ул.Центральная, д.3б		0101000020E6100000B8E864A9F57C42409FE40E9BC8544C40
1939	1	15	1850	30765	12036	\N	56.708933999999999	Тверская область, Конаковский район, с.Городня, ул.Советская, д.18		0101000020E61000009450FA42C8294240E0826C59BE5A4C40
1930	1	15	1850	30285	12027	\N	56.545918999999998	Тверская область, Конаковский район, дер.Гаврилково, ул.Советская, д.8		0101000020E6100000A8C4758C2B2E4240ECA17DACE0454C40
1925	1	15	1850	30062	12022	\N	56.608739	Тверская область, Конаковский район, дер.Вахонино, ул.Большая, д.59		0101000020E61000009C6ED921FE4F42405E66D828EB4D4C40
92454	1	14	128	46683	26333	\N	52.714984000000001	п.Зеленый, Центральная, 7		0101000020E6100000FA0E7EE200024540E6948098845B4A40
1873	1	15	1769	41044	12275	\N	57.042214999999999	Тверская область, Кимрский район, пос.Центральный, пр-д Абрамовский, д.11	Россия, Тверская область	0101000020E61000009AB51490F68F42404833164D67854C40
1871	1	15	1769	27621	11961	\N	56.818434000000003	Тверская область, Кимрский район, дер.Фёдоровка, ул.Центральная, д.26	Россия, Тверская область, Кимрский район, поселок Федоровка	0101000020E61000004EB4AB90F29D42409DF7FF71C2684C40
1870	1	15	1769	27561	11959	\N	57.080447999999997	Тверская область, Кимрский район, дер.Устиново, ул.Солнечная, д.4		0101000020E610000037E0F3C308A94240A983BC1E4C8A4C40
1869	1	15	1769	27515	11958	\N	56.864294999999998	Тверская область, Кимрский район, дер.Титово, ул.Центральная, д.2а		0101000020E61000006552431B80B74240548CF337A16E4C40
1868	1	15	1769	27471	11957	\N	56.995637000000002	Тверская область, Кимрский район, с.Стоянцы, ул.Школьная, д.2		0101000020E6100000E2CAD93BA369424002D88008717F4C40
1857	1	15	1769	26966	\N	\N	57.251199	Тверская область, Кимрский район, дер.Радомино, д.47		0101000020E61000006C5F402FDC614240DAE4F04927A04C40
1867	1	15	1769	27421	11954	\N	56.957726999999998	Тверская область, Кимрский район, пос.Приволжский, ул.Заводская, д.1		0101000020E61000005E82531F48C6424083BF5FCC967A4C40
1865	1	15	1769	27329	\N	\N	57.138497000000001	Тверская область, Кимрский район, дер.Печетово, д.31		0101000020E61000005E2BA1BB248042400CCC0A45BA914C40
1866	1	15	1769	27350	11953	\N	57.089951999999997	Тверская область, Кимрский район, дер.Паскино, ул.Володарского, д.1		0101000020E6100000E481C8224D8A4240DA1A118C838B4C40
1864	1	15	1769	27267	\N	\N	57.137715	Тверская область, Кимрский район, дер.Неклюдово, д.58а		0101000020E6100000DB85E63A8DAC4240969526A5A0914C40
1863	1	15	1769	27230	11952	\N	56.991512999999998	Тверская область, Кимрский район, дер.Малое Василёво, пл.Советская, д.3		0101000020E6100000483657CD738842408847E2E5E97E4C40
1861	1	15	1769	27145	11950	\N	56.919981	Тверская область, Кимрский район, дер.Кучино, ул.Молодёжная, д.3		0101000020E6100000A1DB4B1AA38742407FF8F9EFC1754C40
1862	1	15	1769	27192	12070	\N	57.287081000000001	Тверская область, Кимрский район, с.Красное, ул.Лесная, д.2		0101000020E6100000CF86FC3383704240C826F911BFA44C40
1859	1	15	1769	27066	11948	\N	57.086835999999998	Тверская область, Кимрский район, дер.Кошкино, ул.Школьная, д.12		0101000020E6100000E17CEA58A5604240C70E2A711D8B4C40
1860	1	15	1769	27086	11949	\N	56.961692999999997	Тверская область, Кимрский район, с.Ильинское, ул.Центральная, д.13		0101000020E61000000740DCD5AB96424064E597C1187B4C40
1858	1	15	1769	27006	11947	\N	57.154293000000003	Тверская область, Кимрский район, с.Горицы, пер.Садовый, д.5		0101000020E61000000A4966F50E5D424039807EDFBF934C40
1856	1	15	1769	40978	11962	\N	56.964992218709199	Тверская область, Кимрский район, пос.Белый Городок, ул.Заводская, д.1	Россия, Тверская область, Кимрский район, поселок Белый Городок	0101000020E61000005B785E2A36C2424069739CDB847B4C40
1855	1	15	1794	26882	\N	\N	57.629902999999999	Тверская область, Кесовогорский район, дер.Фенево, здание администрации Феневского сельского поселения		0101000020E6100000422619390BBD42407E5358A9A0D04C40
1854	1	15	1794	26815	\N	\N	57.6207244999407	Тверская область, Кесовогорский район, дер.Федцово, здание Федцовского Дома культуры	Россия, Тверская область, Кесовогорский район, поселок Федцово	0101000020E610000042EE224C51D04240D1EB4FE273CF4C40
1843	1	15	1794	26317	\N	\N	57.470908000000001	Тверская область, Кесовогорский район, дер.Стрелиха, здание МОУ Стрелихинская средняя общеобразовательная школа		0101000020E61000004DDA54DD239342405FB69DB646BC4C40
1849	1	15	1794	26598	\N	\N	57.542076999999999	Тверская область, Кесовогорский район, дер.Страхиново, здание Страхиновской сельской библиотеки		0101000020E6100000151DC9E53FB04240F77475C762C54C40
1847	1	15	1794	26514	\N	\N	57.623060000000002	Тверская область, Кесовогорский район, дер.Петровское, здание Петровского филиала МОУ Кесовогорская СОШ		0101000020E6100000E8BCC62E51A942400FB9196EC0CF4C40
1853	1	15	1794	26335	\N	\N	57.587815999999997	Тверская область, Кесовогорский район, дер.Никольское, здание МОУ Николо-Поточинская начальная общеобразов. школа		0101000020E6100000F6CE68AB92B442406308008E3DCB4C40
1844	1	15	1794	26335	\N	\N	57.587815999999997	Тверская область, Кесовогорский район, дер.Никольское, здание Никольского сельского дома культуры		0101000020E6100000F6CE68AB92B442406308008E3DCB4C40
1852	1	15	1794	26740	\N	\N	57.468086	Тверская область, Кесовогорский район, дер.Матвеевское, здание Матвеевского филиала МОГУ Кесовогорская СОШ		0101000020E6100000E7012CF2EB8F424094DBF63DEABB4C40
1851	1	15	1794	26695	\N	\N	57.562156000000002	Тверская область, Кесовогорский район, дер.Лисково, здание администрации Лисковского сельского поселения		0101000020E6100000136404543888424006A051BAF4C74C40
1846	1	15	1794	26140	11941	\N	57.584598	Тверская область, п.Кесова Гора, ул.Советская, д.15		0101000020E6100000486B0C3A21A642404CA7751BD4CA4C40
1840	1	15	1794	26140	11941	\N	57.584598	Тверская область, п.Кесова Гора, ул.Советская, д.86		0101000020E6100000486B0C3A21A642404CA7751BD4CA4C40
1841	1	15	1794	26140	11942	\N	57.584598	Тверская область, п.Кесова Гора, ул.Ленинградская, д.2		0101000020E6100000486B0C3A21A642404CA7751BD4CA4C40
1839	1	15	1794	26140	11940	\N	57.584598	Тверская область, п.Кесова Гора, ул.Кооперативная, д.14		0101000020E6100000486B0C3A21A642404CA7751BD4CA4C40
1850	1	15	1794	26649	\N	\N	57.506704999999997	Тверская область, Кесовогорский район, с.Завидовская Горка, здание Завгорского детского сада		0101000020E6100000B1F7E28BF6A242401EDC9DB5DBC04C40
1848	1	15	1794	26540	\N	\N	57.539033000000003	Тверская область, Кесовогорский район, дер.Елисеево, здание администрации Елисеевского сельского поселения		0101000020E6100000B5C189E8D7A842407E3B8908FFC44C40
1791	1	15	203	23871	\N	\N	56.975470000000001	Тверская область, Калязинский район, дер.Крюково, д.34		0101000020E6100000BC9179E40FEC4240541D7233DC7C4C40
1845	1	15	1794	26394	\N	\N	57.639347000000001	Тверская область, Кесовогорский район, дер.Горка Ширятская, здание Горкоширятского филиала МОУ Кесовогорская СОШ		0101000020E61000005AF624B0399D4240DAE55B1FD6D14C40
1842	1	15	1794	26248	\N	\N	57.464494000000002	Тверская область, Кесовогорский район, дер.Борисовское, здание Борисовского Дома культуры		0101000020E610000036069D103A7E42401898158A74BB4C40
1836	1	15	1760	26008	\N	\N	57.523977000000002	Тверская область, Кашинский район, дер.Шепели, д.77		0101000020E61000003BFDA02E52E04240986DA7AD11C34C40
1835	1	15	1760	25984	\N	\N	57.443449999999999	Тверская область, Кашинский район, дер.Филипищево, д.25		0101000020E610000005F86EF3C6DF4240A2B437F8C2B84C40
1833	1	15	1760	25871	\N	\N	57.340642000000003	Тверская область, Кашинский район, дер.Фарафоновка, д.88		0101000020E61000001EA5129ED0D5424070D234289AAB4C40
1831	1	15	1760	25777	11938	\N	57.456457999999998	Тверская область, Кашинский район, дер.Уницы, ул.Центральная, д.4		0101000020E61000006556EF703BA04240B0FF3A376DBA4C40
1815	1	15	1760	25034	\N	\N	57.244419999999998	Тверская область, Кашинский район, дер.Тиволино, д.44		0101000020E61000009CFD8172DBCE4240813E9127499F4C40
1820	1	15	1760	25242	\N	\N	57.250019999999999	"Тверская область, Кашинский район, дер.Тетьково, Клуб ГУП""Тетьково"""		0101000020E61000001C9AB2D30F96424047ACC5A700A04C40
1830	1	15	1760	25748	\N	\N	57.321047	Тверская область, Кашинский район, дер.Спасское, д.84		0101000020E6100000A86F99D3658D42404DBD6E1118A94C40
1829	1	15	1760	25693	\N	\N	57.343701000000003	Тверская область, Кашинский район, дер.Славково, д.8		0101000020E61000005E0F26C5C78942401F4DF564FEAB4C40
1832	1	15	1760	25832	\N	\N	57.422040000000003	Тверская область, Кашинский район, дер.Савцыно, д.10		0101000020E61000004E2A1A6B7F9342404BCD1E6805B64C40
1828	1	15	1760	25646	\N	\N	57.355341000000003	Тверская область, Кашинский район, дер.Путилово, д.109		0101000020E6100000F0366F9C14C64240C7F65AD07BAD4C40
1826	1	15	1760	25546	\N	\N	57.341831999999997	Тверская область, Кашинский район, дер.Письяковка, д.1		0101000020E61000008B89CDC7B5CB4240F65CA626C1AB4C40
1824	1	15	1760	25440	\N	\N	57.372374000000001	Тверская область, Кашинский район, дер.Пестриково, д.41а		0101000020E610000047718E3A3AD24240BBF083F3A9AF4C40
1827	1	15	1760	25593	\N	\N	57.327632000000001	Тверская область, Кашинский район, дер.Никольское, д.43		0101000020E6100000335019FF3EC34240C18F6AD8EFA94C40
1822	1	15	1760	25349	\N	\N	57.388032000000003	Тверская область, Кашинский район, дер.Лобково, д.24		0101000020E610000096CB46E7FCBA424097E65608ABB14C40
1818	1	15	1760	25155	\N	\N	57.281106999999999	Тверская область, Кашинский район, дер.Леушино, д.38		0101000020E6100000FB05BB61DBB442409DD66D50FBA34C40
1816	1	15	1760	25065	11936	\N	57.173991000000001	Тверская область, Кашинский район, дер.Коробово, ул.Центральна, д.12		0101000020E6100000DA01D71533CE424030664B5645964C40
1837	1	15	1760	26069	\N	\N	57.495060000000002	Тверская область, Кашинский район, дер.Козьмодемьяновкое, д.73		0101000020E6100000925ED4EE57D5424065C746205EBF4C40
1823	1	15	1760	25391	\N	\N	57.339708999999999	Тверская область, Кашинский район, дер.Карабузино, д.20		0101000020E61000003C6BB75D68F442401494A2957BAB4C40
1838	1	15	1760	26093	\N	\N	57.571114999999999	Тверская область, Кашинский район, дер.Данильцево, д.67		0101000020E610000048A643A7E7D94240A5A0DB4B1AC94C40
1821	1	15	1760	25288	\N	\N	57.402751000000002	Тверская область, Кашинский район, дер.Давыдово, д.18		0101000020E61000005708ABB184A9424035B742588DB34C40
1819	1	15	1760	25194	11937	\N	57.255473000000002	Тверская область, Кашинский район, дер.Верхняя Троица, ул.Молодежная, д.1		0101000020E6100000FEBAD39D279242406901DA56B3A04C40
1817	1	15	1760	25117	\N	\N	57.275531000000001	Тверская область, Кашинский район, дер.Булатово, д.94		0101000020E6100000B071FDBB3EAD424060048D9944A34C40
1825	1	15	1760	25488	\N	\N	57.45579	Тверская область, Кашинский район, дер.Бузыково, д.23		0101000020E61000002CA0504F1FC7424003ECA35357BA4C40
1814	1	15	1760	24973	11935	\N	57.236418	Тверская область, Кашинский район, дер.Барыково, ул.Слободка, д.5		0101000020E61000002DEC6987BFC84240C617EDF1429E4C40
1794	1	15	203	24022	11915	\N	56.930404000000003	Тверская область, Калязинский район, дер.Яринское, ул.Центральная, д.33		0101000020E610000074EFE192E30C4340A708707A17774C40
1787	1	15	203	23695	11907	\N	57.261927999999997	Тверская область, Калязинский район, дер.Чигирево, ул.Чигиревская, д.46		0101000020E6100000A75CE15D2EF442400EF450DB86A14C40
1804	1	15	203	24528	11926	\N	57.118819469254802	Тверская область, Калязинский район, дер.Тимирязево, ул.Молодежная, д.10	Россия, Тверская область, Калязинский район, поселок Тимирязево	0101000020E610000091D442C9E40443405C920376358F4C40
1803	1	15	203	24467	11925	\N	57.110632000000003	Тверская область, Калязинский район, дер.Старобислово, ул.Широкая, д.14		0101000020E6100000A16AF46A801643400FF27A30298E4C40
1786	1	15	203	23632	11906	\N	57.105955000000002	Тверская область, Калязинский район, с.Спасское, ул.Центральная, д.16		0101000020E6100000856055BDFCEE424081ECF5EE8F8D4C40
1797	1	15	203	24173	11918	\N	57.304952999999998	Тверская область, Калязинский район, с.Семендяево, ул.Речная, д.27		0101000020E6100000C3B645990D1C434096E82CB308A74C40
1793	1	15	203	23974	11913	\N	57.086239999999997	Тверская область, Калязинский район, с.Поречье, ул.Школьная, д.9		0101000020E6100000C6C03A8E1FF64240B3CD8DE9098B4C40
1802	1	15	203	24425	11924	\N	57.169477999999998	Тверская область, Калязинский район, дер.Плоховка, ул.Школьная, д.22		0101000020E6100000ED9DD156250B43401CB28174B1954C40
1801	1	15	203	24361	11923	\N	57.049892	Тверская область, Калязинский район, дер.Пенье, ул.Школьная, д.1		0101000020E61000007365506D70084340802A6EDC62864C40
1759	1	15	203	22397	\N	\N	57.188752999999998	Тверская область, Калининский район, с. Никольское, д.13а	Россия, Тверская область, Калязинский район, поселок Никольское	0101000020E610000099F1B6D26B034340CD02ED0E29984C40
1792	1	15	203	23898	11912	\N	57.040495999999997	Тверская область, Калязинский район, с.Нерль, ул.Ленинская, д.49		0101000020E6100000F2086EA46CFF424035CF11F92E854C40
1796	1	15	203	24112	11917	\N	57.262619999999998	Тверская область, Калязинский район, дер.Малахово, ул.Новая, д.4		0101000020E61000004A79AD84EE06434044A33B889DA14C40
1790	1	15	203	23821	11909	\N	57.089579999999998	Тверская область, Калязинский район, с.Капшино, ул.Советская, д.38		0101000020E61000005471E316F3E542401630815B778B4C40
94248	1	15	203	766	\N	\N	57.238936000000002	Тверская область, г.Калязин, ул.Полевая, д.14/16	Россия, Тверская область, Калязинский район, Калязин	0101000020E6100000A087DA368CEA424025EB7074959E4C40
1781	1	15	203	766	11896	\N	57.238936000000002	Тверская область, г.Калязин, ул.Коминтерна, д.81	Россия, Тверская область, Калязинский район, Калязин	0101000020E6100000A087DA368CEA424025EB7074959E4C40
1780	1	15	203	766	11895	\N	57.238936000000002	Тверская область, г.Калязин, ул.Тверская, д.19		0101000020E6100000A087DA368CEA424025EB7074959E4C40
1782	1	15	203	766	11897	\N	57.238936000000002	Тверская область, г.Калязин, ул.Студенческая, д.27		0101000020E6100000A087DA368CEA424025EB7074959E4C40
1779	1	15	203	766	11894	\N	57.238936000000002	Тверская область, г.Калязин, ул.Коминтерна, д.101	Россия, Тверская область, Калязинский район, Калязин	0101000020E6100000A087DA368CEA424025EB7074959E4C40
1554	1	15	203	766	11769	\N	57.238936000000002	Тверская область, г.Калязин, ул.К.Маркса, д.22/20		0101000020E6100000A087DA368CEA424025EB7074959E4C40
1799	1	15	203	24269	11920	\N	57.192869000000002	Тверская область, Калязинский район, дер.Исаково, ул.Школьная, д.24		0101000020E6100000321F10E84C064340C4B46FEEAF984C40
1785	1	15	203	23606	11905	\N	57.230718000000003	Тверская область, Калязинский район, дер.Дымово, ул.Молодежная, д.33		0101000020E610000070EEAF1EF7E142409D4CDC2A889D4C40
1789	1	15	203	23776	11908	\N	56.941434000000001	Тверская область, Калязинский район, дер.Воронцово, ул.Центральная, д.11		0101000020E610000097ADF54542F94240D6ABC8E880784C40
1784	1	15	203	23546	11904	\N	57.143335999999998	Тверская область, Калязинский район, дер.Василево, ул.Советская, д.23		0101000020E61000002711E15F04F54240732B84D558924C40
1788	1	15	203	23730	\N	\N	56.833294000000002	Тверская область, Калязинский район, дер.Бителево, д.44		0101000020E61000006FD40AD3F7084340FDF9B660A96A4C40
1795	1	15	203	24065	11916	\N	57.248243000000002	Тверская область, Калязинский район, дер.Баринцево, ул.Цветочная, д.5		0101000020E6100000BEFA78E8BB134340003B376DC69F4C40
1798	1	15	203	24200	11919	\N	57.025286999999999	Тверская область, Калязинский район, с.Апухтино, ул.Центральная, д.1		0101000020E61000009604A8A965134340C901BB9A3C834C40
2484	1	15	203	25472	\N	\N	57.349863999999997	Тверская область, Торжокский район, дер.Андрианово, д.50 - Здание администрации с/п	Россия, Тверская область, Калязинский район, поселок Андрианово	0101000020E6100000BCCB457C272243401C06F357C8AC4C40
1783	1	15	203	23484	11903	\N	57.201611999999997	Тверская область, Калязинский район, дер.Алферово, ул.Центральная, д.27		0101000020E610000045BA9F5390ED4240963D096CCE994C40
1775	1	15	1614	23031	\N	\N	56.781759652658501	Тверская область, Калининский район, нп Эммаусская школа-интернат, здание музея	Россия, Тверская область, Калининский район, поселок Эммаус	0101000020E6100000CF81E508190E424015A930B610644C40
1774	1	15	1614	23031	\N	\N	56.774036000000002	Тверская область, Калининский район, пос.Эммаусс, д.29(малый зал)		0101000020E6100000CC5EB69DB61042409DF6949C13634C40
1773	1	15	1614	23031	\N	\N	56.774036000000002	Тверская область, Калининский район, пос.Эммаусс, д.29 (артистическая)		0101000020E6100000CC5EB69DB61042409DF6949C13634C40
1771	1	15	1614	40971	11890	\N	56.755043000000001	"Тверская область, Калининский район, ж.-д ст.Чуприяновка, ул.3-я Мира, здание ОАО""Автотранс"""	Россия, Тверская область, Калининский район, поселок Чуприяновка	0101000020E610000000E48409A30542407009C03FA5604C40
1769	1	15	1614	22845	\N	\N	56.936169999999997	Тверская область, Калининский район, дер.Черногубово, д.28а		0101000020E61000000E2F88484DE1414087BF266BD4774C40
1768	1	15	1614	22845	\N	\N	56.935458664477402	Тверская область, Калининский район, санаторий Черногубово, д.22	Россия, Тверская область, Калининский район, поселок Черногубово	0101000020E61000003C670B08ADE14140DBDFD91EBD774C40
1767	1	15	1614	22845	\N	\N	56.936169999999997	Тверская область, Калининский район, госпиталь ИОВ, д.15	Россия, Тверская область, Калининский район, поселок Черногубово	0101000020E61000000E2F88484DE1414087BF266BD4774C40
1765	1	15	1614	22681	11888	\N	56.507551999999997	Тверская область, Калининский район, с.Тургиново, ул.Кирова, д.22	Россия, Тверская область, Калининский район, поселок Тургиново	0101000020E6100000486E4DBA2DFD41407B82C476F7404C40
1778	1	15	1614	23260	11893	\N	56.626049000000002	Тверская область, Калининский район, пос.Суховерково, просп.Калинина, д.2		0101000020E6100000156F641EF9C74140C558A65F22504C40
1770	1	15	1614	22892	\N	\N	56.713272000000003	Тверская область, Калининский район, дер.Старый Погост, д.23б		0101000020E6100000E129E44A3D0942408693347F4C5B4C40
1753	1	15	1614	22132	11882	\N	56.914321000000001	"Тверская область, Калининский район, дер.Мермерины, ул.Центральная, здание конторы ООО""Меха"""		0101000020E61000005ABC581822CF4140E485747808754C40
1762	1	15	1614	22552	\N	\N	56.99447	"Тверская область, Калининский район, дер.Славное, здание МОУ ""Славновская ООШ"""		0101000020E610000073D9E89C9F064240336DFFCA4A7F4C40
1740	1	15	1614	21525	11868	\N	56.724499000000002	Тверская область, Калининский район, дер.Савино, ул.Слободская, д.58		0101000020E6100000698A00A777E141400B7E1B62BC5C4C40
1743	1	15	1614	21655	\N	\N	56.830876000000004	Тверская область, Калининский район, дер.Савватьево, д.33а		0101000020E61000002B137EA99F0D424002840F255A6A4C40
1736	1	15	1614	21326	\N	\N	56.704141	Тверская область, Калининский район, дер.Рязаново, д.21		0101000020E610000007EE409DF2E04140E962D34A215A4C40
1754	1	15	1614	22188	\N	\N	56.960794999999997	Тверская область, Калининский район, дер. Романово, д.71, кафе РАЙПО		0101000020E61000006D904946CEC2414085949F54FB7A4C40
1742	1	15	1614	21606	11870	\N	56.860683000000002	Тверская область, Калининский район, с.Рождествено, ул.Советская, д.61	Россия, Тверская область, Калининский район, поселок Рождествено	0101000020E61000006344A2D0B2464240919C4CDC2A6E4C40
1735	1	15	1614	21277	\N	\N	56.591867000000001	Тверская область, Калининский район, с.Пушкино, д.65, здание дома культуры		0101000020E61000002AFD84B35BE14140734A404CC24B4C40
1734	1	15	1614	21245	11861	\N	56.553108999999999	Тверская область, Калининский район, дер.Полубратово, ул.Беговая, д.11		0101000020E6100000F46A80D250CB4140C70F9546CC464C40
1733	1	15	1614	21186	11859	\N	56.663786999999999	Тверская область, Калининский район, с.Петровское, ул.Егорова, д.15а		0101000020E61000002E55698B6BDA41404641F0F8F6544C40
1746	1	15	1614	21809	11873	\N	56.968558000000002	Тверская область, Калининский район, дер. Первомайские Горки, ул.Береговая, д.4а		0101000020E610000001DA56B3CEE04140BC2363B5F97B4C40
1777	1	15	1614	23215	11892	\N	56.913440999999999	Тверская область, Калининский район, пос.Орша, ул.Привокзальная, д.7		0101000020E610000018EAB0C22D1D4240ABE97AA2EB744C40
1758	1	15	1614	22374	11884	\N	56.805934000000001	Тверская область, Калининский район, дер.Никулино, ул.Школьная, д.3		0101000020E61000005C3CBCE7C0EA4140035E66D828674C40
1732	1	15	1614	21156	11858	\N	56.464320999999998	Тверская область, Калининский район, дер.Нестерово, ул.Молодежная, д.11		0101000020E61000003AEAE8B81ABF41404AECDADE6E3B4C40
1745	1	15	1614	21764	\N	\N	57.068980000000003	"Тверская область, Калининский район, дер.Мухино, здание ""Мухинская сельск.библ"""		0101000020E610000004E8F7FD9BDF4140FF092E56D4884C40
1756	1	15	1614	22278	11883	\N	56.973056999999997	Тверская область, Калининский район, село Михайловское, ул.Центральная, д.44ж		0101000020E6100000C26B97361CF241406A12BC218D7C4C40
1731	1	15	1614	21110	11857	\N	56.500587000000003	Тверская область, Калининский район, дер.Митенево, ул.Центральная, д.16		0101000020E6100000DCA0F65B3BDB4140C1E61C3C13404C40
1752	1	15	1614	22051	11881	\N	56.928567999999999	Тверская область, Калининский район, с.Медное, ул.Тверская, д.7		0101000020E61000007808E3A771BD41405A0EF450DB764C40
1751	1	15	1614	22051	11880	\N	56.928567999999999	Тверская область, Калининский район, с.Медное, ул.Советская, д.126		0101000020E61000007808E3A771BD41405A0EF450DB764C40
1750	1	15	1614	22008	11879	\N	56.852307000000003	Тверская область, Калининский район,дер.Кумордино, ул.Школьная, д.5		0101000020E61000009A6038D730B3414071935165186D4C40
1744	1	15	1614	21708	11871	\N	56.977888999999998	Тверская область, Калининский район, ж/д ст.Кулицкая, ул.Титова, д.1а		0101000020E61000001BBAD91F28D741401F0F7D772B7D4C40
1772	1	15	1614	22974	\N	\N	56.731768000000002	Тверская область, Калининский район, с.Кузьминское, д.1а		0101000020E6100000E1B4E0455F1142403221E692AA5D4C40
1747	1	15	1614	21845	11874	\N	56.717993999999997	Тверская область, Калининский район, с.Красная Гора, ул.Зеленая, д.10		0101000020E61000004AB72572C1CD4140B35C363AE75B4C40
1748	1	15	1614	21916	11877	\N	56.678089999999997	Тверская область, Калининский район, дер.Колталово, ул.Зеленая, д.12		0101000020E6100000B37C5D86FFC0414050DF32A7CB564C40
1730	1	15	1614	21054	\N	\N	56.694958999999997	"Тверская область, Калининский район, дер.Квакшино, д.54, здание МУКДЦ""Квакшинский"""	Россия, Тверская область, Калининский район, поселок Квакшино	0101000020E6100000A0FA07910CEB4140CA87A06AF4584C40
1741	1	15	1614	21565	11869	\N	56.835495000000002	Тверская область, Калининский район, с. Каблуково, ул.Школьная, д.8а		0101000020E6100000E4A25A44141B42405B7C0A80F16A4C40
1729	1	15	1614	21012	\N	\N	56.574224000000001	Тверская область, Калининский район, с.Ильинское, д.14, здание адм. Бурашевского с/п		0101000020E61000005BB39597FCF94140064A0A2C80494C40
1755	1	15	1614	22229	\N	\N	56.917400999999998	"Тверская область, Калининский район, пос.Загородный, д.20, здание ""Загородный д/сад"""		0101000020E6100000139A249694FB4140AA285E656D754C40
1738	1	15	1614	21422	\N	\N	56.893096999999997	Тверская область, Калининский район, пос.Заволжский, д.7		0101000020E61000001D588E9081E04140EE93A30051724C40
1728	1	15	1614	20927	\N	\N	56.645747	Тверская область, Калининский район, дер.Езвино, д.26, здание адм.Бурашевского с/п		0101000020E610000038F92D3A59F64140BC3E73D6A7524C40
1766	1	15	1614	22729	\N	\N	56.728898999999998	Тверская область, Калининский район, дер.Дубровки, д.47		0101000020E6100000D40FEA2285C44140268BFB8F4C5D4C40
1749	1	15	1614	21953	\N	\N	56.845953000000002	Тверская область, Калининский район, дер Дмитровское, д.119		0101000020E610000009DE904605DC4140FF791A30486C4C40
1739	1	15	1614	40970	11866	\N	56.858304040520203	Тверская область, Калининский район, пос.Дмитрово-Черкассы, ул.Заводская, д.26а	Россия, Тверская область, Калининский район, поселок Дмитрово-Черкасский	0101000020E6100000A9674128EFDF41405303CDE7DC6D4C40
1757	1	15	1614	22325	\N	\N	56.796264000000001	Тверская область, Калининский район, дер.Даниловское, д.64в		0101000020E6100000D57954FCDFDF4140B77D8FFAEB654C40
1761	1	15	1614	22487	\N	\N	57.010390999999998	"Тверская область, Калининский район, пос.Восток, здание МОУ""Оршинская ООШ"""		0101000020E6100000670FB402431442401C96067E54814C40
1713	1	15	1614	20095	\N	\N	56.500544893863399	Тверская область, Зубцовский район. дер.Вахново, Здание библиотеки	Россия, Тверская область, Калининский район, поселок Вахново	0101000020E61000002849D74CBED541409296CADB11404C40
1776	1	15	1614	23166	11891	\N	57.011308	Тверская область, Калининский район, пос.Васильевский Мох, ул.Парковая, д.19/8	Россия, Тверская область, Калининский район, поселок Васильевский Мох	0101000020E61000001AF8510DFBF541407217618A72814C40
1725	1	15	1614	20722	\N	\N	56.732519000000003	Тверская область, Калининский район, с.Бурашево, здание администрации (зд.конт) ГУЗ ОКПБ №1 им.М.П.Литвинова		0101000020E61000008AE3C0ABE5F041406D59BE2EC35D4C40
1724	1	15	1614	20722	\N	\N	56.732519000000003	Тверская область, Калининский район, с.Бурашево, здание администрации (акт.зал) ГУЗ ОКПБ №1 им.М.П.Литвинова		0101000020E61000008AE3C0ABE5F041406D59BE2EC35D4C40
1763	1	15	1614	22595	\N	\N	56.471620999999999	Тверская область, Калининский район, дер.Большие Горки, д.31а		0101000020E61000002C836A8313ED4140AC8DB1135E3C4C40
92368	1	14	814	48122	75012	\N	53.248783000000003	р.п. Первомайский, переулок Школьный, 3		0101000020E6100000C4D155BABB2444408066101FD89F4A40
1737	1	15	1614	21367	12016	\N	56.826994999999997	Тверская область, Калининский район, дер.Большие Борки, пер.Административный, д.1а		0101000020E6100000890CAB7823CB41404E7ADFF8DA694C40
1727	1	15	1614	20913	11856	\N	56.679782000000003	Тверская область, Калининский район, дер.Березино, ул.Центральная, д..8		0101000020E610000000C63368E8F141406A34B91803574C40
1760	1	15	1614	22438	\N	\N	56.942833999999998	Тверская область, Калининский район, с.Беле-Кушальское, д.29		0101000020E61000004C361E6CB111424047C7D5C8AE784C40
1726	1	15	1614	41042	\N	\N	56.801825549387097	Тверская область, Калининский район, дер.Андрейково, д.1д	Россия, Тверская область	0101000020E61000001555BFD2F9E441408F8AFF3BA2664C40
1708	1	15	1572	40962	\N	\N	56.059317999999998	Тверская область, Зубцовский район, дер.Щеколдино, Здание Дома культуры		0101000020E61000002FBFD364C63B4140350873BB97074C40
1696	1	15	1572	19183	\N	\N	56.198933553077502	Тверская область, Зубцовский район, дер.Ульяново, Здание администрации Ульяновского сельского поселения	Россия, Тверская область, Зубцовский район, поселок Ульяново	0101000020E61000008D4468041B954140FF0758AB76194C40
1693	1	15	1572	19050	\N	\N	56.259672999999999	Тверская область, Зубцовский район, дер.Столипино, Здание администрации Столипинского сельского поселения		0101000020E61000008FE4F21FD26D4140BD5301F73C214C40
1695	1	15	1572	19141	\N	\N	56.219377000000001	Тверская область, Зубцовский район, дер.Старые Горки, Здание администрации Старогорского тер. подразделения		0101000020E6100000BB7EC16ED89E41404F3FA88B141C4C40
1717	1	15	1572	20357	\N	\N	55.988570000000003	Тверская область, Зубцовский район, дер.Старое Устиново, Здание Дома культуры		0101000020E610000042B456B43974414043E7357689FE4B40
1714	1	15	1572	40965	\N	\N	56.144517	"Тверская область, Зубцовский район, дер.Старое, Здание правления СХПК ""Колос"""		0101000020E610000037C5E3A25A644140A75B76887F124C40
1694	1	15	1572	19057	\N	\N	56.280656	Тверская область, Зубцовский район, дер.Салино, Здание администрации Салинского тер. подразделения	Россия, Тверская область, Зубцовский район, поселок Салино	0101000020E6100000136058FE7C8941408DB62A89EC234C40
1711	1	15	1572	41040	\N	\N	56.094458469489602	Тверская область, Зубцовский район, дер.Рыльцево, Здание школы	Россия, Тверская область, Зубцовский район, поселок Рыльцово	0101000020E61000001BBD1AA0345841403C6C2233170C4C40
1715	1	15	1572	20219	\N	\N	56.076774999999998	Тверская область, Зубцовский район, дер.Раково, Здание администрации Раковского тер. подразделения		0101000020E61000001C7BF65CA66E4140401361C3D3094C40
1719	1	15	1572	40966	\N	\N	56.136873000000001	Тверская область, Зубцовкий район, с.Погорелое Городище, Здание Дома культуры		0101000020E6100000CE5147C7D57841404B5AF10D85114C40
1692	1	15	1572	18960	\N	\N	56.289065999999998	Тверская область, Зубцовский район, дер.Ошурково, Здание администрации Ошурковского тер. подразделения	Россия, Тверская область, Зубцовский район, поселок Ошурково	0101000020E6100000FC389A232BA5414059315C1D00254C40
1716	1	15	1572	20258	\N	\N	56.160420999999999	"Тверская область, Зубцовский район, дер.Орловка, Здание правления СХПК ""Орловка"""	Россия, Тверская область, Зубцовский район, поселок Орловка	0101000020E6100000BB9BA73AE4884140BA4BE2AC88144C40
1718	1	15	1572	20380	\N	\N	56.048726000000002	"Тверская область, Зубцовский район, дер.Новое, Здание правления СХПК ""Рассвет"""		0101000020E61000009BC761307F814140823B50A73C064C40
1710	1	15	1572	19925	\N	\N	56.140515000000001	Тверская область, Зубцовский район, дер.Никольское, Здание администрации Никольского тер. подразделения		0101000020E61000009015FC36C456414079CC4065FC114C40
1722	1	15	1572	20618	\N	\N	56.034008	Тверская область, Зубцовский район, дер.Николо-Пустынь, Здание администрации Николо-Пустыньского тер. подразделения		0101000020E610000008556AF640994140B4E6C75F5A044C40
1721	1	15	1572	20581	\N	\N	56.182712000000002	Тверская область, Зубцовский район, дер.Мерейкино, Здание администрации Благининского тер. подразделения		0101000020E61000004F24986A66A341401B4B581B63174C40
1709	1	15	1572	19860	\N	\N	56.118012999999998	Тверская область, Зубцовский район, дер.Малое Коробино, Здание детского сада	Россия, Тверская область, Зубцовский район, поселок Малое Коробино	0101000020E61000006CEA3C2AFE4941405DC0CB0C1B0F4C40
1720	1	15	1572	20506	\N	\N	56.075302999999998	Тверская область, Зубцовский район, с.Княжьи Горы, Здание администрации Княжьегорского сельского поселения		0101000020E6100000D5963AC8EB9D414035255987A3094C40
1712	1	15	1572	40963	\N	\N	56.006542000000003	Тверская область, Зубцовский район, дер.Карамзино, Здание администрации Карамзинского тер. подразделения		0101000020E61000001213D4F02D4841407506465ED6004C40
1707	1	15	1572	19747	\N	\N	55.9927760493349	Тверская область, Зубцовский район, дер.Игнатово, Здание Дома культуры	Россия, Тверская область, Зубцовский район, поселок Игнатово	0101000020E6100000DB4FC6F8303F41407920B24813FF4B40
1705	1	15	1572	19639	\N	\N	56.169547999999999	Тверская область, Зубцовский район, дер.Зуево, Здание администрации Зуевского тер. подразделения	Россия, Тверская область, Зубцовский район, поселок Зуево	0101000020E6100000D7DEA7AAD0444140158DB5BFB3154C40
1700	1	15	1572	19301	9739	\N	56.177690731421599	Тверская область, г.Зубцов, ул.Советская, д.24	Россия, Тверская область, Зубцовский район, Зубцов	0101000020E6100000F777B6476F4A414093E52494BE164C40
1698	1	15	1572	19301	9739	\N	56.171272000000002	Тверская область, г.Зубцов, ул.Советская, д.1а		0101000020E6100000B03BDD79E24941403A5CAB3DEC154C40
1699	1	15	1572	19301	11848	\N	56.171272000000002	Тверская область, г.Зубцов, ул.Ржевская, д.44		0101000020E6100000B03BDD79E24941403A5CAB3DEC154C40
1702	1	15	1572	19301	11849	\N	56.171272000000002	Тверская область, г.Зубцов, ул.Октябрьская, д.2		0101000020E6100000B03BDD79E24941403A5CAB3DEC154C40
1701	1	15	1572	19301	11850	\N	56.171272000000002	Тверская область, г.Зубцов, ул.Декабристов, д.27		0101000020E6100000B03BDD79E24941403A5CAB3DEC154C40
1691	1	15	1572	18931	\N	\N	56.259854953892898	Тверская область, Зубцовский район, дер.Дорожаево, Здание администрации Дорожаевского сельского поселения	Россия, Тверская область, Зубцовский район, поселок Дорожаево	0101000020E610000024809BC58BB14140DE59BBED42214C40
1703	1	15	1572	19539	\N	\N	56.203006999999999	Тверская область, Зубцовский район, дер.Брычево, Здание администрации Брычевского тер. подразделения	Россия, Тверская область, Зубцовский район, поселок Брычево	0101000020E6100000F35487DC0C4D4140F6ED2422FC194C40
1704	1	15	1572	19605	\N	\N	56.205370000000002	Тверская область, Зубцовский район, дер.Борки, Здание администрации Борковского тер. подразделения		0101000020E6100000C39ACAA2B05B41402ECA6C90491A4C40
1706	1	15	1572	40959	\N	\N	56.214587000000002	Тверская область, Зубцовский район, дер.Большое Пищалино, Здание администрации Пищалинского тер. подразделения		0101000020E610000060CAC0012D574140C9923996771B4C40
1697	1	15	1572	19236	\N	\N	56.296228999999997	Тверская область, Зубцовский район, дер.Белавино, Здание администрации Белавинского тер. подразделения	Россия, Тверская область, Зубцовский район, поселок Белавино	0101000020E6100000AB764D486B9841403A90F5D4EA254C40
1688	1	15	1504	18739	\N	\N	56.155588000000002	Тверская область, Западнодвинский район, дер.Шарапово, Здание Шараповского офиса врача общей практики		0101000020E6100000F9BF232A54CB3F4035D3BD4EEA134C40
1677	1	15	1504	40954	\N	\N	56.210227000000003	Тверская область, Западнодвинский район, дер.Фофаново, Здание Фофановского сельского дома культуры		0101000020E61000003849F3C7B40640403CDEE4B7E81A4C40
1672	1	15	1504	17922	\N	\N	56.285992999999998	Тверская область, Западнодвинский район, дер.Улин, Здание сельского дома культуры		0101000020E61000004FEB36A8FDEA3F4045F12A6B9B244C40
1669	1	15	1504	17809	11842	\N	56.276504000000003	Тверская область, Западнодвинский район, пос.Старая Торопа, ул.Кирова, д.16	Россия, Тверская область, Западнодвинский район, поселок Старая Торопа	0101000020E61000002A1A6B7F67AB3F404A9BAA7B64234C40
1687	1	15	1504	40955	\N	\N	56.308746194473898	"Тверская область, Западнодвинский район, дер.Селяне, Здание МОУ ""Селянская НОШ"""	Россия, Тверская область, Западнодвинский район, поселок Селяны	0101000020E6100000EA7B0DC171B53F40AA622AFD84274C40
1689	1	15	1504	18830	\N	\N	56.054868999999997	Тверская область, Западнодвинский район, дер.Севостьяново, Здание Севостьяновского сельского дома культуры		0101000020E610000025CD1FD3DAD03F40384888F205074C40
1685	1	15	1504	18620	\N	\N	56.246606	"Тверская область, Западнодвинский район, дер.Пятиусово, Здание МОУ ""Пятиусовская НОШ"""		0101000020E6100000357A354069C43F40AA7F10C9901F4C40
1671	1	15	1504	17905	\N	\N	56.043427000000001	"Тверская область, Западнодвинский район, пос.Первомайский, Здание МОУ ""Первомайская общеобразовательная школа"""	Россия, Тверская область, Западнодвинский район, поселок Первомайский	0101000020E61000001349F4328AB13F40B76114048F054C40
1683	1	15	1504	18514	\N	\N	56.214061000000001	"Тверская область, Западнодвинский район, дер.Макеево, Здание МОУ ""Макеевская ООШ"""		0101000020E61000004643C6A3549E3F40AE2CD159661B4C40
1679	1	15	1504	18297	\N	\N	55.978265999999998	"Тверская область, Западнодвинский район, дер.Козино, Здание конторы СПК ""Западный"""		0101000020E6100000BF9EAF592E973F40F564FED137FD4B40
1678	1	15	1504	18214	\N	\N	55.946233999999997	Тверская область, Западнодвинский район, пос.Ильино, Здание администрации Ильинского сельского поселения		0101000020E61000003BC43F6CE9A93F407F2E1A321EF94B40
1666	1	15	1504	17512	11839	\N	56.255246999999997	Тверская область, г.Западная Двина, ул.Школьная, д.41		0101000020E6100000309FAC18AE0A404078B306EFAB204C40
1664	1	15	1504	17512	11837	\N	56.255246999999997	Тверская область, г.Западная Двина, ул.Первомайская, д.3		0101000020E6100000309FAC18AE0A404078B306EFAB204C40
1663	1	15	1504	17512	11836	\N	56.255246999999997	Тверская область, г.Западная Двина, ул.Молодежная, д.38	Россия, Тверская область, Западнодвинский район, Западная Двина	0101000020E6100000309FAC18AE0A404078B306EFAB204C40
1667	1	15	1504	17512	11840	\N	56.255246999999997	"Тверская область, г.Западная Двина, ул.Мира, Здание ""Западнодвинский агрострой"""		0101000020E6100000309FAC18AE0A404078B306EFAB204C40
1668	1	15	1504	17512	11841	\N	56.255246999999997	"Тверская область, г.Западная Двина, ул.Льнозаводская, Здание ООО ""Веста-СП"""		0101000020E6100000309FAC18AE0A404078B306EFAB204C40
1665	1	15	1504	17512	11838	\N	56.255246999999997	Тверская область, г.Западная Двина, ул.Кирова, д.16		0101000020E6100000309FAC18AE0A404078B306EFAB204C40
1675	1	15	1504	18110	\N	\N	56.284633999999997	Тверская область, Западнодвинский район, деревня Дуброво, Здание Дубровской сельской библиотеки	Россия, Тверская область, Западнодвинский район, поселок Дуброво	0101000020E6100000B20DDC813A21404032AA0CE36E244C40
1681	1	15	1504	18407	\N	\N	55.814931999999999	Тверская область, Западнодвинский район, дер.Глазомичи, Здание Глазомичской сельской  библиотеки	Россия, Тверская область, Западнодвинский район, поселок Глазомичи	0101000020E6100000C5538F34B8793F40603B18B14FE84B40
1673	1	15	1504	18015	\N	\N	56.279077000000001	"Тверская область, Западнодвинский район, пос.Велеса, Здание МОУ ""Велесовской начальной школы"""		0101000020E6100000A08CF161F61240406C088ECBB8234C40
92669	1	14	\N	127	26219	\N	52.731587523072399	г. Тамбов, Мастерских, 1	Россия, Тамбовская область, Тамбов	0101000020E6100000B28009DCBABD4440B212F3ACA45D4A40
1682	1	15	1504	18418	\N	\N	55.923054	Тверская область, Западнодвинский район, дер.Васьково, Здание Васьковской сельской библиотеки	Россия, Тверская область, Западнодвинский район, поселок Васьково	0101000020E61000003596B036C67E3F4093382BA226F64B40
1674	1	15	1504	18028	\N	\N	56.377851	Тверская область, Западнодвинский район, дер.Бибирево, Здание Бибиревского сельского дома культуры	Россия, Тверская область, Западнодвинский район, поселок Бибирево	0101000020E6100000E1EB6B5D6A26404065E1EB6B5D304C40
1670	1	15	1504	17843	\N	\N	56.165825580992497	Тверская область, Западнодвинский район, дер.Бенцы, Здание сельского дома культуры	Россия, Тверская область, Западнодвинский район, поселок Бенцы	0101000020E61000001711C5E40DBC3F40CB694FC939154C40
1676	1	15	1504	18145	\N	\N	56.209631000000002	Тверская область, Западнодвинский район, дер.Баево, Здание столовой  Баевской школы		0101000020E6100000A4FACE2F4A124040289D4830D51A4C40
1686	1	15	1504	18645	\N	\N	56.260933000000001	"Тверская область, Западнодвинский район, дер.Антоново, Здание МОУ ""Антоновская НОШ"""		0101000020E6100000DF1797AAB4A53F403DB9A64066214C40
1680	1	15	1504	18318	\N	\N	55.826735999999997	Тверская область, Западнодвинский  район, дер.Аксентьево, Здание Аксентьевского сельского дома культуры		0101000020E610000081B1BE81C9A13F408236397CD2E94B40
1662	1	15	1467	17427	\N	\N	55.749972	Тверская область, Жарковский район, дер.Щучье, Здание администрации Щучейского сельского поселения		0101000020E61000008B506C054D11404036751E15FFDF4B40
1660	1	15	1467	17326	\N	\N	55.847644000000003	Тверская область, Жарковский район, дер.Троицкое, Здание администрации Троицкого сельского поселения		0101000020E61000003106D671FC04404048533D997FEC4B40
1658	1	15	1467	17228	\N	\N	55.777175	Тверская область, Жарковский район, дер.Полоска, Сельский Дом культуры	Россия, Тверская область, Жарковский район, поселок Полоска	0101000020E61000004205871744B03F4068226C787AE34B40
1654	1	15	1467	17040	\N	\N	55.848790999999999	Тверская область, Жарковский район, пос.Новоселки, Здание администрации Новоселковского сельского поселения		0101000020E6100000DE91B1DAFCCF3F40CF11F92EA5EC4B40
1656	1	15	1467	17128	\N	\N	55.944147000000001	Тверская область, Жарковский район, пос.Кривая Лука, Сельский клуб		0101000020E6100000E7E099D024F53F40EACE13CFD9F84B40
1651	1	15	1467	16918	11834	\N	55.813110999999999	Тверская область, Жарковский район, пос.Кривая, ул.Октябрьская, Клуб		0101000020E6100000138255F5F22340404982700514E84B40
1657	1	15	1467	17204	\N	\N	55.812534999999997	Тверская область, Жарковский район, дер.Королевщина, Здание администрации Сычевского сельского поселения		0101000020E6100000711DE38A8BBF3F407CED992501E84B40
1653	1	15	1467	17020	\N	\N	55.982467	Тверская область, Жарковский район, пос.Кащенки, Сельский клуб		0101000020E6100000EB6E9EEA902940401A33897AC1FD4B40
1652	1	15	1467	16944	\N	\N	56.061267999999998	Тверская область, Жарковский район, дер.Зеленьково, Здание администрации Жарковского сельского поселения		0101000020E61000001405FA449E1440404A253CA1D7074C40
1650	1	15	1467	16749	\N	\N	55.850200999999998	Тверская область, Жарковский район, пос.Жарковский, ул.Октябрьский, д.1		0101000020E61000006E8B321B642240406403E962D3EC4B40
1649	1	15	1467	16749	11833	\N	55.850200999999998	Тверская область, Жарковский район, пос.Жарковский, ул.Советская, д.55		0101000020E61000006E8B321B642240406403E962D3EC4B40
1648	1	15	1467	16749	11833	\N	55.850200999999998	Тверская область, Жарковский район, пос.Жарковский, ул.Советская, д.37		0101000020E61000006E8B321B642240406403E962D3EC4B40
1655	1	15	1467	17106	\N	\N	55.873601999999998	Тверская область, Жарковский район, дер.Дубоцкое, Сельский Дом культуры		0101000020E610000017BB7D5699D53F402FDCB930D2EF4B40
1661	1	15	1467	17398	\N	\N	55.722740000000002	Тверская область, Жарковский район, дер.Гороватка, Здание администрации Щучейского сельского поселения		0101000020E61000000C040132741E40406AC18BBE82DC4B40
1659	1	15	1467	17309	\N	\N	55.818857000000001	Тверская область, Жарковский район, дер.Вороны, Сельский Дом культуры		0101000020E61000004628B682A6114040E38C614ED0E84B40
770	1	15	848	40885	\N	\N	57.714582787385602	Тверская область, Вышневолоцкий район, дер.Заречье, д.61А		0101000020E61000003465A71FD42D414087A3AB7477DB4C40
1615	1	15	848	15137	\N	\N	57.526978	Тверская область, Вышневолоцкий район, пос.Трудовой, д.19		0101000020E61000008925E5EE736A414012DBDD0374C34C40
1613	1	15	848	15048	11802	\N	57.563009999999998	Тверская область, Вышневолоцкий район, пос.Терелесовский, ул.Рабочая, д.7		0101000020E6100000FEB4519D0E60414015A930B610C84C40
1612	1	15	848	14980	\N	\N	57.734448671928099	Тверская область, Вышневолоцкий район, дер.Старое, д.82	Россия, Тверская область, Вышневолоцкий район, поселок Старое	0101000020E610000072512D228A5741403ACAC16C02DE4C40
1610	1	15	848	14891	11801	\N	57.629565999999997	Тверская область, Вышневолоцкий район, дер.Сороки, ул.Бежецкая, д.21		0101000020E61000001FA16648154F41403656629E95D04C40
1608	1	15	848	14773	11800	\N	57.670468999999997	Тверская область, Вышневолоцкий район, пос.Солнечный, ул.Центральная, д.12		0101000020E6100000F94A202576394140ACFD9DEDD1D54C40
1607	1	15	848	14773	11800	\N	57.670560967362398	Тверская область, Вышневолоцкий район, пос.Солнечный, ул.Центральная, д.9	Россия, Тверская область, Вышневолоцкий район, поселок Солнечный	0101000020E610000082E49D43193A41408D7C5EF1D4D54C40
1606	1	15	848	14688	11799	\N	57.739148	Тверская область, Вышневолоцкий район, пос.Садовый, ул.Центральная, д.53		0101000020E6100000CAFCA36FD23E4140B073D3669CDE4C40
1609	1	15	848	14866	\N	\N	57.759712999999998	Тверская область, Вышневолоцкий район, дер.Подол, д.19А		0101000020E610000078B471C45A3C41404BAC8C463EE14C40
92683	1	14	\N	127	25605	\N	52.719785000000002	г. Тамбов, Майская, 35		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
1589	1	15	848	13910	11788	\N	57.638753999999999	Тверская область, Вышневолоцкий район, с.Осечно, ул.Почтовая, д.29	Россия, Тверская область, Вышневолоцкий район, поселок Осечно	0101000020E61000009CC58B85217A41403718EAB0C2D14C40
1614	1	15	848	15065	11803	\N	57.542327999999998	Тверская область, Вышневолоцкий район, пос.Осеченка, ул.Карла Маркса, д.15		0101000020E610000030293E3E2167414040DAFF006BC54C40
1604	1	15	848	14595	11798	\N	57.719608999999998	Тверская область, Вышневолоцкий район, пос.Овсище, ул.Заводская, д.2	Россия, Тверская область, Вышневолоцкий район, поселок Овсище	0101000020E6100000B85CFDD8248141402174D0251CDC4C40
1601	1	15	848	14480	11796	\N	57.403934	Тверская область, Вышневолоцкий район, дер.Лужниково, ул.Солнечная, д.8		0101000020E6100000855FEAE74D11414009DFFB1BB4B34C40
1605	1	15	848	14669	\N	\N	57.693229000000002	Тверская область, Вышневолоцкий район, дер.Кузнецово, д.75		0101000020E61000000F27309DD6974140C4D155BABBD84C40
1619	1	15	848	15242	11806	\N	57.620068328616497	Тверская область, Вышневолоцкий район, пос.Красномайский, ул.Кирова, д.33	Россия, Тверская область, Вышневолоцкий район, поселок Красномайский	0101000020E610000072193735D0344140E8A562635ECF4C40
1618	1	15	848	15242	11807	\N	57.620621	Тверская область, Вышневолоцкий район, пос.Красномайский, ул.Боровая, д.1А	Россия, Тверская область, Вышневолоцкий район, поселок Красномайский	0101000020E6100000384E0AF31E354140FC1A498270CF4C40
1617	1	15	848	15242	11805	\N	57.620621	Тверская область, Вышневолоцкий район, пос.Красномайский, ул.1 Мая, д.2		0101000020E6100000384E0AF31E354140FC1A498270CF4C40
1602	1	15	848	14499	11797	\N	57.466788999999999	Тверская область, Вышневолоцкий район, пос.Красная Заря, ул.Школьная, д.4А	Россия, Тверская область, Вышневолоцкий район, поселок Красная Заря	0101000020E61000007F164B917C094140F790F0BDBFBB4C40
1597	1	15	848	14294	\N	\N	57.698650000000001	Тверская область, Вышневолоцкий район, с.Коломно, д.112А		0101000020E61000004FE61F7D93224140DAACFA5C6DD94C40
1594	1	15	848	14123	\N	\N	57.297488999999999	Тверская область, Вышневолоцкий район, дер.Княщины, д.13	Россия, Тверская область, Вышневолоцкий район, поселок Княщины	0101000020E6100000865451BCCA4A4140BAF59A1E14A64C40
1595	1	15	848	14196	\N	\N	57.373263000000001	Тверская область, Вышневолоцкий район, дер.Ильинское, д.35А		0101000020E61000006571FF91E956414047E7FC14C7AF4C40
1593	1	15	848	14102	11792	\N	57.506604000000003	Тверская область, Вышневолоцкий район, пос.Зеленогорский, ул.Микробиологов, д.31	Россия, Тверская область, Вышневолоцкий район, поселок Зеленогорский	0101000020E6100000B28009DCBA474140EB025E66D8C04C40
1603	1	15	848	14569	\N	\N	57.532448000000002	Тверская область, Вышневолоцкий район, дер.Жилотково, д.10Б		0101000020E6100000C5C6BC8E381C41400A698D4127C44C40
1591	1	15	848	14009	11790	\N	57.279569000000002	Тверская область, Вышневолоцкий район, с.Есеновичи, ул.Первомайская, д.2		0101000020E6100000EDF318E5991B4140DBFCBFEAC8A34C40
1590	1	15	848	13932	11789	\N	57.707608999999998	Тверская область, Вышневолоцкий район, дер.Дятлово, ул.Школьная, д.3		0101000020E61000001BD47E6B2764414079AD84EE92DA4C40
1600	1	15	848	14405	11795	\N	57.644944000000002	Тверская область, Вышневолоцкий район, пос.Дорки, пер.Некрасовский, д.1Б	Россия, Тверская область, Вышневолоцкий район, поселок Дорки	0101000020E610000071AE6186C63341402FE065868DD24C40
1588	1	15	848	13829	11785	\N	57.578006999999999	Тверская область, Вышневолоцкий район, пос.Горняк, ул.Центральная, д.6А		0101000020E610000032ACE28DCC514140F6ED2422FCC94C40
1592	1	15	848	14028	11791	\N	57.360075000000002	Тверская область, Вышневолоцкий район, дер.Бухолово, ул.Советская, д.8		0101000020E61000008386FE092E364140B98D06F016AE4C40
1596	1	15	848	14216	\N	\N	57.779254999999999	Тверская область, Вышневолоцкий район, дер.Боровно, д.78		0101000020E6100000A60D87A5813341404B1FBAA0BEE34C40
1586	1	15	848	13727	11783	\N	57.661605999999999	Тверская область, Вышневолоцкий район, пос.Борисовский, ул.Октябрьская, д.17А		0101000020E6100000D714C8EC2C1441402F6B6281AFD44C40
1599	1	15	848	14391	11794	\N	57.746267000000003	Тверская область, Вышневолоцкий район, пос.Бельский, ул.Фабричная, д.6А	Россия, Тверская область, Вышневолоцкий район, поселок Бельский	0101000020E610000055F99E91081F4140C28A53AD85DF4C40
1587	1	15	848	13812	11784	\N	57.548012999999997	Тверская область, Вышневолоцкий район, пос.Белый Омут, ул.Советская, д.10		0101000020E61000003526C45C5257414034643C4A25C64C40
1616	1	15	848	15164	11804	\N	57.469032607547199	Тверская область, Вышневолоцкий район, дер.Афимьино, ул.Мира, д.8	Россия, Тверская область, Вышневолоцкий район, поселок Афимьино	0101000020E61000001827BEDA515C414055DFF94509BC4C40
1598	1	15	848	14310	11793	\N	57.711925999999998	Тверская область, Вышневолоцкий район, пос.Академический, ул.Октябрьская, д.19А		0101000020E6100000BB6070CD1D2941400796236420DB4C40
1583	1	15	1246	13623	\N	\N	58.502305999999997	Тверская область, Весьегонский район, дер.Чистая Дуброва, Здание Дома культуры	Россия, Тверская область, Весьегонский район, поселок Чистая Дуброва	0101000020E610000062F3716DA8A44240D34A21904B404D40
1584	1	15	1246	13638	\N	\N	58.465757000000004	Тверская область, Весьегонский район, с.Чамерово, Здание средней школы		0101000020E6100000C3D66CE525AF42400971E5EC9D3B4D40
1575	1	15	1246	13249	\N	\N	58.391227999999998	Тверская область, Весьегонский район, дер.Тимошкино, Здание библиотеки	Россия, Тверская область, Весьегонский район, поселок Тимошкино	0101000020E6100000FD69A33A1D784240C6A354C213324D40
1585	1	15	1246	13710	\N	\N	58.392738000000001	Тверская область, Весьегонский район, дер.Телятово, Здание медпункта		0101000020E6100000BF7E880D16A64240BFF2203D45324D40
1580	1	15	1246	13448	\N	\N	58.426271999999997	Тверская область, Весьегонский район, дер.Столбищи, Здание Дома культуры		0101000020E61000009813B4C9E19D4240AA99B51490364D40
1581	1	15	1246	13533	\N	\N	58.442717999999999	Тверская область, Весьегонский район, с.Романовское, Здание администрации Романовского сельского поселения	Россия, Тверская область, Весьегонский район, поселок Романовское	0101000020E610000030116F9D7FBB4240DEACC1FBAA384D40
1579	1	15	1246	13436	\N	\N	58.465747	Тверская область, Весьегонский район, дер.Пронино, Здание администрации Пронинского сельского поселения		0101000020E61000005BED612F14924240E59A02999D3B4D40
1577	1	15	1246	13345	\N	\N	58.580511000000001	Тверская область, Весьегонский район, с.Любегощи, Здание администрации Любегощинского сельского поселения		0101000020E61000002366F6798C684240F0FB372F4E4A4D40
1576	1	15	1246	13269	\N	\N	58.399053000000002	Тверская область, Весьегонский район, с.Кесьма, Здание администрации Кесемского сельского поселения		0101000020E61000008463963D09884240732F302B14334D40
1572	1	15	1246	13074	\N	\N	58.547763000000003	Тверская область, Весьегонский район, дер.Иваново, Здание администрации Ивановского сельского поселения		0101000020E61000001900AAB8718B4240BC7A15191D464D40
1569	1	15	1246	12966	\N	\N	58.682822999999999	Тверская область, Весьегонский район, дер.Ёгна, Здание администрации Ёгонского сельского поселения		0101000020E61000002DCC423BA771424072FA7ABE66574D40
1582	1	15	1246	13550	\N	\N	58.421883999999999	Тверская область, Весьегонский район, дер.Дюдиково, Здание Дома культуры		0101000020E61000009F73B7EBA5C54240535A7F4B00364D40
1568	1	15	1246	12899	\N	\N	58.620175134041297	Тверская область, Весьегонский район, дер.Гора, Здание медпункта	Россия, Тверская область, Весьегонский район, поселок Гора	0101000020E61000002849D74CBE734240FE65F7E4614F4D40
1567	1	15	1246	12795	11779	\N	58.658678000000002	Тверская область, г.Весьегонск, ул.Южная, д.24А		0101000020E6100000B779E3A430A142401F4C8A8F4F544D40
1565	1	15	1246	12795	11777	\N	58.658678000000002	Тверская область, г.Весьегонск, ул.Тихонова, д.4		0101000020E6100000B779E3A430A142401F4C8A8F4F544D40
1566	1	15	1246	12795	11778	\N	58.658678000000002	Тверская область, г.Весьегонск, ул.Панфилова, д.17	Россия, Тверская область, Весьегонский район, Весьегонск	0101000020E6100000B779E3A430A142401F4C8A8F4F544D40
1571	1	15	1246	40951	\N	\N	58.732455999999999	Тверская область, Весьегонский район, дер.Б.Овсяниково, Здание Большеовсяниковской средней школы	Россия, Тверская область, Весьегонский район, поселок Большое Овсянниково	0101000020E6100000653909A52F6A424026E1421EC15D4D40
1573	1	15	1246	13150	\N	\N	58.639223000000001	Тверская область, Весьегонский район, дер.Бараново, Здание администрации Ивановского сельского поселения		0101000020E61000004ED53DB2B9A64240EEEC2B0FD2514D40
1578	1	15	1246	13362	\N	\N	58.536717000000003	Тверская область, Весьегонский район, дер.Алферово, Здание библиотеки		0101000020E6100000D0D556EC2F6D4240871A8524B3444D40
86	1	15	6917	40537	11192	\N	57.861503927483099	Тверская область, г.Бологое, Заозерный м/р-н, д.1		0101000020E61000003FE42D573F0E4140C4AF58C345EE4C40
1558	1	15	711	12442	11773	\N	57.721924999999999	Тверская область, Бологовский район, с.Хотилово, ул.Центральная, д.121		0101000020E61000006E8B321B640C41401895D40968DC4C40
1555	1	15	711	12335	11770	\N	57.995775999999999	Тверская область, Бологовский район, дер.Тимково, ул.Центральная, д.55		0101000020E610000007EFAB72A12041402312859675FF4C40
1556	1	15	711	12335	11771	\N	57.995775999999999	Тверская область, Бологовский район, дер.Тимково, ул.Озерная, д.16		0101000020E610000007EFAB72A12041402312859675FF4C40
1547	1	15	711	11933	\N	\N	58.124026999999998	Тверская область, Бологовский район, дер.Михайловское, Дом культуры ЛИУ-3	Россия, Тверская область, Бологовский район, поселок Михайловское	0101000020E6100000C634D3BD4EDE40401669E21DE00F4D40
1545	1	15	711	11832	11763	\N	58.114207	Тверская область, Бологовский район, с.Лыкошино, ул.Первомайская, д.9		0101000020E610000036583849F3E14040B5FCC0559E0E4D40
1550	1	15	711	12071	11767	\N	57.726112000000001	Тверская область, Бологовский район, пос.Куженкино, ул.Советская, д.1		0101000020E6100000B5C35F9335FC4040D89DEE3CF1DC4C40
1559	1	15	711	12071	11774	\N	57.726112000000001	Тверская область, Бологовский район, с.Куженкино, ул.Полевая, д.13		0101000020E6100000B5C35F9335FC4040D89DEE3CF1DC4C40
1546	1	15	711	11860	11764	\N	58.041832999999997	Тверская область, Бологовский район, дер.Корыхново, ул.Советская, д.7	Россия, Тверская область, Бологовский район, поселок Корыхново	0101000020E610000083E0F1ED5DE340406072A3C85A054D40
527	1	15	711	26375	10819	\N	58.073307999999997	Тверская область, Бологовский район, с.Кемцы, ул.Центральная, д.22	Россия, Тверская область, Бологовский район, поселок Кемцы	0101000020E610000035B742588D1F41408044132862094D40
1557	1	15	711	12439	11772	\N	57.935180000000003	Тверская область, Бологовский район, пос.Кафтино, ул.Ленина, д.34		0101000020E6100000397D3D5FB3264140C8EF6DFAB3F74C40
1549	1	15	711	12033	11766	\N	57.810079000000002	Тверская область, Бологовский район, с.Ильятино, ул.Зеленая, д.6		0101000020E61000007D3D5FB35CDC404094162EABB0E74C40
1560	1	15	711	12548	11775	\N	58.096969000000001	Тверская область, Бологовский район, дер.Заборки, ул.Лесная, д.2а		0101000020E61000003674B33F50044140E8DCED7A690C4D40
1544	1	15	711	11775	11762	\N	57.905487000000001	Тверская область, Бологовский район, пос.Гузятино, ул.Новая, д.2		0101000020E610000020D5B0DF13F1404001FA7DFFE6F34C40
1548	1	15	711	11962	11765	\N	57.873427999999997	Тверская область, Бологовский район, пос.Выползово, ул.Октябрьская, д.60а		0101000020E6100000C100C28712D9404091B41B7DCCEF4C40
1561	1	15	711	4965	\N	\N	57.869279943162603	"Тверская область, г.Бологое, База отдыха ""Озерный"""	Россия, Тверская область, Бологовский район, Бологое	0101000020E61000007E8E8F16670841409088299144EF4C40
94179	1	15	711	4965	18158	\N	57.871107000000002	Тверская область, г.Бологое, пер.Школьный, д.9		0101000020E6100000CCB6D3D6880841408928266F80EF4C40
65274	5	52	1564	23611	13992	\N	55.4348695998872	с. Успенка, Союзная, 36		0101000020E6100000D6011077F5CF54407901F6D1A9B74B40
1540	1	15	711	4965	11758	\N	57.871107000000002	Тверская область, г.Бологое, ул.Студенческая, учебный корпус аграрного колледжа		0101000020E6100000CCB6D3D6880841408928266F80EF4C40
214	1	15	711	4965	12256	\N	57.870283805347498	Тверская область, г.Бологое, ул.О.Кошевого, д.1а		0101000020E6100000A872DA5372084140B41D537765EF4C40
1541	1	15	711	4965	11759	\N	57.870011716630202	Тверская область, г.Бологое, ул.Народная, д.12	Россия, Тверская область, Бологовский район, Бологое	0101000020E610000030664B564508414054909F8D5CEF4C40
1539	1	15	711	4965	11757	\N	57.871107000000002	Тверская область, г.Бологое, ул.Мира, д.28а		0101000020E6100000CCB6D3D6880841408928266F80EF4C40
1563	1	15	711	4965	11776	\N	57.871107000000002	Тверская область, г.Бологое, ул.Линейная, д.9		0101000020E6100000CCB6D3D6880841408928266F80EF4C40
1536	1	15	711	4965	11753	\N	57.871107000000002	Тверская область, г.Бологое, ул.Кирова, д.35		0101000020E6100000CCB6D3D6880841408928266F80EF4C40
1534	1	15	711	4965	11753	\N	57.871107000000002	Тверская область, г.Бологое, ул.Кирова, д.39		0101000020E6100000CCB6D3D6880841408928266F80EF4C40
1533	1	15	711	4965	11753	\N	57.871107000000002	Тверская область, г.Бологое, ул.Кирова, д.18а	Россия, Тверская область, Бологовский район, Бологое	0101000020E6100000CCB6D3D6880841408928266F80EF4C40
123	1	15	711	4965	10049	\N	57.871107000000002	Тверская область, г.Бологое, Заозерный м/р-н, д.9	Россия, Тверская область, Бологовский район, Бологое	0101000020E6100000CCB6D3D6880841408928266F80EF4C40
1535	1	15	711	4965	11754	\N	57.871107000000002	Тверская область, г.Бологое, Заводской м/р-н, д.10	Россия, Тверская область, Бологовский район, Бологое	0101000020E6100000CCB6D3D6880841408928266F80EF4C40
1537	1	15	711	4965	11755	\N	57.871107000000002	Тверская область, г.Бологое, ул.Дзержинского, д.11		0101000020E6100000CCB6D3D6880841408928266F80EF4C40
274	1	15	711	4965	10365	\N	57.871107000000002	Тверская область, г.Бологое, ул.Главная, д.10	Россия, Тверская область, Бологовский район, Бологое	0101000020E6100000CCB6D3D6880841408928266F80EF4C40
1538	1	15	711	4965	11756	\N	57.871107000000002	Тверская область, г.Бологое, ул.Гагарина, д.5	Россия, Тверская область, Бологовский район, Бологое	0101000020E6100000CCB6D3D6880841408928266F80EF4C40
2169	1	15	711	12246	\N	\N	58.099998999999997	Тверская область, Осташковский район, дер.Березовый Рядок, помещение администрации Залучьенского сельского поселения	Россия, Тверская область, Бологовский район, поселок Березовский Рядок	0101000020E61000006A4B1DE4F53C4140FC5069C4CC0C4D40
1553	1	15	711	12246	11768	\N	58.099998999999997	Тверская область, Бологовский район, с.Березовский Рядок, ул.Новая, д.1а		0101000020E61000006A4B1DE4F53C4140FC5069C4CC0C4D40
1542	1	15	711	11676	11760	\N	57.984941999999997	Тверская область, Бологовский район, пос.Березайка, ул.Победы, д.30		0101000020E6100000EE5BAD1397F34040793A579412FE4C40
1543	1	15	711	11676	11761	\N	57.984941999999997	Тверская область, Бологовский район, пос.Березайка, ул.Крестьянская, д.8		0101000020E6100000EE5BAD1397F34040793A579412FE4C40
1530	1	15	1143	11112	11750	\N	55.817072000000003	Тверская область, Бельский район, дер.Шайтровщина, ул.Центральная, д.35		0101000020E61000005F419AB168864040193DB7D095E84B40
1526	1	15	1143	49954	18775	\N	55.753771567295999	Тверская область, Бельский район, дер.Чичаты, ул.Школьная, д.1	Россия, Тверская область, Бельский район, поселок Чичата	0101000020E6100000CCB73EAC374A4040FC51D4997BE04B40
1532	1	15	1143	11192	11752	\N	55.935389999999998	Тверская область, Бельский район, дер.Нестерово, ул.Зеленая, д.5		0101000020E61000006CEBA7FFAC834040B28009DCBAF74B40
1529	1	15	1143	11085	11749	\N	55.715099000000002	Тверская область, Бельский район, дер.Комары, ул.Советская, д.32		0101000020E61000009E7B0F971C9740407F33315D88DB4B40
1528	1	15	1143	11023	11748	\N	55.788004000000001	Тверская область, Бельский район, с.Кавельщино, ул.Центральная, д.76		0101000020E610000021E9D32AFA8D4040008FA850DDE44B40
1525	1	15	1143	10904	11746	\N	55.717897999999998	Тверская область, Бельский район, дер.Демяхи, ул.Центральная, д.33		0101000020E6100000314278B47162404091EEE714E4DB4B40
1524	1	15	1143	10839	11745	\N	55.868868999999997	Тверская область, Бельский район, дер.Грибаново, ул.Зеленая, д.4		0101000020E610000089618731E9A140400DC1711937EF4B40
1523	1	15	1143	10809	11744	\N	55.914659999999998	Тверская область, Бельский район, дер.Верховье, ул.Центральная, д.8		0101000020E6100000FAF02C4146B24040CC7A319413F54B40
1527	1	15	1143	11012	11747	\N	55.801298981427799	Тверская область, Бельский район, дер.Будино, ул.Школьная, д.4	Россия, Тверская область, Бельский район, поселок Будино	0101000020E6100000FCDEA63FFB714040A4A833F790E64B40
1521	1	15	1143	10727	11742	\N	55.839289000000001	Тверская область, г.Белый, ул.Ленина, д.21		0101000020E6100000321F10E84C7840403F726BD26DEB4B40
1522	1	15	1143	10727	11743	\N	55.839289000000001	Тверская область, г.Белый, ул.Кирова, д.47		0101000020E6100000321F10E84C7840403F726BD26DEB4B40
1531	1	15	1143	10727	11751	\N	55.839289000000001	Тверская область, г.Белый, ул.1 Мая, д.3		0101000020E6100000321F10E84C7840403F726BD26DEB4B40
1512	1	15	591	10269	11738	\N	57.535091000000001	Тверская область, Бежецкий район, дер.Шульгино, ул.Центральная, д.11	Россия, Тверская область, Бежецкий район, поселок Шульгино	0101000020E6100000397B67B45535424025B1A4DC7DC44C40
1520	1	15	591	40952	\N	\N	57.786270784247897	Тверская область, Бежецкий район, дер.Шишково-Дуброво, д.12	Россия, Тверская область, Бежецкий район, поселок Шишкова-Дубрава	0101000020E6100000982F2FC03E38424088653387A4E44C40
1516	1	15	591	10475	\N	\N	57.510288000000003	Тверская область, Бежецкий район, дер.Хозницы, д.37		0101000020E610000042EA76F6956F424048C5FF1D51C14C40
1518	1	15	591	10573	\N	\N	57.813890000000001	Тверская область, Бежецкий район, дер.Фралево, д.95	Россия, Тверская область, Бежецкий район, поселок Фралево	0101000020E61000001C7A8B87F75442404E452A8C2DE84C40
1517	1	15	591	40948	11740	\N	57.795048999999999	Тверская область, Бежецкий район, дер.Филиппково, ул.Большая, д.44		0101000020E6100000CB9D996038434240D7DB662AC4E54C40
92369	1	14	814	48122	75014	\N	53.248783000000003	р.п. Первомайский, Э.Тельмана, 5		0101000020E6100000C4D155BABB2444408066101FD89F4A40
1509	1	15	591	10100	11734	\N	57.670902025148798	Тверская область, Бежецкий район, дер.Сырцевка, ул.Косарева, д.15	Россия, Тверская область, Бежецкий район, поселок Сырцевка	0101000020E61000009DA1B8E34D3842401669E21DE0D54C40
1515	1	15	591	10403	\N	\N	57.666227999999997	Тверская область, Бежецкий район, с.Сукромны, д.151	Россия, Тверская область, Бежецкий район, поселок Сукромны	0101000020E61000001C06F357C8664240F9D687F546D54C40
1519	1	15	591	10626	11741	\N	57.889105000000001	Тверская область, Бежецкий район, дер.Потесы, ул.Молодежная, д.7		0101000020E610000030D63730B9454240E4DA5031CEF14C40
1513	1	15	591	40947	\N	\N	58.036588000000002	Тверская область, Бежецкий район, с.Поречье, д.120		0101000020E6100000EF8FF7AA9533424089B663EAAE044D40
916	1	15	591	13257	11159	\N	57.802219000000001	Тверская область, Бежецкий район, дер.Подобино, ул.Центральная, д.6		0101000020E6100000E43098BF427042406B9DB81CAFE64C40
1514	1	15	591	10379	11737	\N	57.613492000000001	Тверская область, Бежецкий район, дер.Плотники, ул.Челябинская, д.19		0101000020E61000007B6B60AB046D4240C72DE6E786CE4C40
93821	1	15	591	12634	\N	\N	57.973565000000001	Тверская область, Бежецкий район, дер.Морозово, д.61		0101000020E61000000169FF03AC5F4240DFC325C79DFC4C40
1511	1	15	591	10213	11735	\N	57.552377999999997	Тверская область, Бежецкий район, с.Моркины Горы, ул.Восточная, д.6		0101000020E6100000A391CF2B9E264240D3838252B4C64C40
1510	1	15	591	10177	\N	\N	57.822868999999997	Тверская область, Бежецкий район, дер.Михайлова Гора, д.18		0101000020E6100000B6BA9C12103D424034F279C553E94C40
1508	1	15	591	10088	11733	\N	57.718859000000002	Тверская область, Бежецкий район, дер.Лаптиха, ул.Молодежная, д.3В		0101000020E61000001A5245F12A414240B7B75B9203DC4C40
1493	1	15	591	9316	11723	\N	57.735813	Тверская область, Бежецкий район, дер.Зобы, ул.Солнечная, д.3		0101000020E6100000A4DFBE0E9C5B42405F7CD11E2FDE4C40
1013	1	15	591	17944	11254	\N	57.461440000000003	Тверская область, Бежецкий район, дер.Житищи, ул.Школьная, д.3		0101000020E6100000D7D9907F664242407B88467710BB4C40
93932	1	15	591	17969	\N	\N	57.858004000000001	Тверская область, Бежецкий район, с.Градницы, д.32		0101000020E61000000729780AB966424029EB3713D3ED4C40
754	1	15	591	5476	11027	\N	57.791525864598597	Тверская область, Бежецкий район, дер.Городищи, ул.Центральная, д.6	Россия, Тверская область, Бежецкий район, поселок Городищи	0101000020E61000007AA52C431C61424083F755B950E54C40
721	1	15	591	3717	11019	\N	57.650218508908303	Тверская область, Бежецкий район, дер.Васюково, ул.Центральная, д.50	Россия, Тверская область, Бежецкий район, поселок Васюково	0101000020E6100000C2F9D4B14A594240711E4E603AD34C40
93793	1	15	591	11232	\N	\N	57.910059767335703	Тверская область, Бежецкий район, дер.Борок Сулежский, д.34	Россия, Тверская область, Бежецкий район, поселок Борок-Сулежский	0101000020E6100000A4FCA4DAA76B4240EAB298D87CF44C40
1500	1	15	995	9664	\N	\N	56.648093000000003	Тверская область, Андреапольский район, с.Хотилицы, помещение сельского Дома культуры		0101000020E61000006C21C84109E33F401EE21FB6F4524C40
1497	1	15	995	9501	\N	\N	56.783096	Тверская область, Андреапольский район, с.Торопаца, помещение администрации Торопацкого сельского поселения		0101000020E6100000FA9CBB5D2FD53F4070D05E7D3C644C40
1496	1	15	995	9471	\N	\N	56.768797999999997	Тверская область, Андреапольский район, дер.Студеница, помещение администрации Торопацкого сельского поселения		0101000020E6100000BCCADAA678024040779D0DF967624C40
1499	1	15	995	9591	\N	\N	56.621344999999998	Тверская область, Андреапольский район, дер.Спиридово, помещение конторы СПК им.Кирова	Россия, Тверская область, Андреапольский район, поселок Спиридово	0101000020E6100000931D1B8178E93F403D44A33B884F4C40
1488	1	15	995	9132	\N	\N	56.637594999999997	"Тверская область, Андреапольский район, дер.Рогово, помещение  Дома культуры КФХ ""Андреапольское"""		0101000020E61000009EEBFB7090244040EB8B84B69C514C40
1482	1	15	995	8856	\N	\N	57.042434999999998	"Тверская область, Андреапольский район, дер.Мякишево, контора колхоза ""К Новой жизни"""		0101000020E6100000DCB8C5FCDCD43F40569A94826E854C40
1492	1	15	995	9301	\N	\N	56.970824	Тверская область, Андреапольский район, дер. Любино, помещение администрации Волокского сельского поселения		0101000020E61000004DDA54DD230540400116F9F5437C4C40
1495	1	15	995	9398	\N	\N	56.715583000000002	Тверская область, Андреапольский район, дер.Луги, помещение администрации Луговского сельского поселения		0101000020E610000026016A6AD93A40406B494739985B4C40
1483	1	15	995	8869	\N	\N	57.065570000000001	"Тверская область, Андреапольский район, дер.Крючково, здание СПК ""Колос"""		0101000020E61000000C0742B280C93F40A3CC069964884C40
1485	1	15	995	8974	\N	\N	56.692042000000001	Тверская область, Андреапольский район, пос.Костюшино, штаб ФГУ ЛИУ №8 УФСИН МЮ РФ по Тверской области	Россия, Тверская область, Андреапольский район, поселок Костюшино	0101000020E610000058FE7C5BB01C4040AEBA0ED594584C40
1484	1	15	995	8941	\N	\N	56.566274	Тверская область, Андреапольский район, дер.Козлово, помещение сельского Дома культуры	Россия, Тверская область, Андреапольский район, поселок Козлово	0101000020E6100000BF7D1D38672440409D499BAA7B484C40
1494	1	15	995	9381	\N	\N	56.623815999999998	Тверская область, Андреапольский район, дер. Горка, помещение администрации Луговского сельского поселения	Россия, Тверская область, Андреапольский район, поселок Горка	0101000020E610000061C5A9D6C2D83F405B5CE333D94F4C40
1491	1	15	995	9232	\N	\N	56.863025999999998	Тверская область, Андреапольский район, дер.Горицы, помещение Горицкого сельского филиала Андреапольской ЦБС		0101000020E61000005B07077B13DF3F4081CCCEA2776E4C40
92688	1	14	\N	127	26094	\N	52.719785000000002	г. Тамбов, Лесная, 25	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
1498	1	15	995	9564	\N	\N	56.659210999999999	Тверская область, Андреапольский район, с.Воскресенское, помещение Воскресенского филиала Андреапольской ЦБС	Россия, Тверская область, Андреапольский район, поселок Воскресенское	0101000020E610000030D461855BC23F40EC14AB0661544C40
1490	1	15	995	9208	\N	\N	56.854542000000002	Тверская область, Андреапольский район, дер.Волок, помещение администрации Волокского сельского поселения		0101000020E6100000A35BAFE9410540407B87DBA1616D4C40
1489	1	15	995	9145	\N	\N	56.898558999999999	Тверская область, Андреапольский район, пос.Бологово, помещение администрации Бологовского сельского поселения		0101000020E6100000EA9788B7CEB33F40634337FB03734C40
1487	1	15	995	9069	\N	\N	56.745773999999997	Тверская область, Андреапольский район, пос.Бобровец, помещение сельского клуба	Россия, Тверская область, Андреапольский район, поселок Бобровец	0101000020E6100000B96E4A79AD264040821ABE85755F4C40
1476	1	15	995	8508	11713	\N	56.647281	Тверская область, г.Андреаполь, ул.Парковая, д.2		0101000020E6100000E3C798BB962240403D29931ADA524C40
1475	1	15	995	8508	11713	\N	56.647281	Тверская область, г.Андреаполь, ул.Парковая, д.11		0101000020E6100000E3C798BB962240403D29931ADA524C40
93259	1	15	995	8508	17923	\N	56.647281	Тверская область, г.Андреаполь, ул.Октябрьская, д.20		0101000020E6100000E3C798BB962240403D29931ADA524C40
93302	1	15	995	8508	18234	\N	56.647281	Тверская область, г.Андреаполь, ул.Новгородская, д.13		0101000020E6100000E3C798BB962240403D29931ADA524C40
93166	1	15	995	8508	18237	\N	56.647281	Тверская область, г.Андреаполь, ул.Кленовая, помещение ЦСРНД		0101000020E6100000E3C798BB962240403D29931ADA524C40
93126	1	15	995	8508	18117	\N	56.647281	Тверская область, г.Андреаполь, ул.Авиаторов, д.54		0101000020E6100000E3C798BB962240403D29931ADA524C40
1479	1	15	995	8508	11716	\N	56.647281	Тверская область, г.Андреаполь, ул.8 Марта, д.37	Россия, Тверская область, Андреапольский район, Андреаполь	0101000020E6100000E3C798BB962240403D29931ADA524C40
1486	1	15	995	8508	11715	\N	56.647281	Тверская область, г.Андреаполь, ул.50 лет Октября, д.9		0101000020E6100000E3C798BB962240403D29931ADA524C40
1478	1	15	995	8508	11715	\N	56.647281	Тверская область, г.Андреаполь, ул.50лет Октября, д.9		0101000020E6100000E3C798BB962240403D29931ADA524C40
1477	1	15	995	8508	11714	\N	56.647281	Тверская область, г.Андреаполь, ул.1-ый Измайловский пер, д.1А		0101000020E6100000E3C798BB962240403D29931ADA524C40
1481	1	15	995	40945	\N	\N	57.019314999999999	Тверская область, Андреапольский район, дер.Аксёново, администрация сельского поселения		0101000020E6100000CD1E680586DC3F403FA9F6E978824C40
92809	1	14	\N	51213	25967	\N	51.963398988878403	"г. Уварово, Южная, 40 ""а"""	Россия, Тамбовская область, Уварово городской округ	0101000020E6100000B37DC85BAE204540E3FF8EA850FB4940
92644	1	14	\N	127	25695	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, пл.Комсомольская, 5		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92635	1	14	\N	127	25699	\N	52.740157652585602	Тамбовская область, город Тамбов, Октябрьский район, пл.Л.Толстого, 4а	Россия, Тамбовская область, Тамбов	0101000020E610000076C075C58CB84440B7EF517FBD5E4A40
92615	1	14	\N	127	26040	\N	52.743048712464201	Тамбовская область, город Тамбов, Ленинский район, им. маршала Малиновского, 12	Россия, Тамбовская область, Тамбов	0101000020E610000021956247E3B84440AA29C93A1C5F4A40
92659	1	14	\N	127	25471	\N	52.723433013335097	Тамбовская область, город Тамбов, Октябрьский район, бульвар Энтузиастов, 2	Россия, Тамбовская область, Тамбов	0101000020E610000005A4FD0FB0B8444070ECD973995C4A40
92672	1	14	\N	127	25992	\N	52.692414297487701	г. Тамбов, Южная, 116	Россия, Тамбовская область, Тамбов	0101000020E61000009010E50B5ABA444072A59E05A1584A40
92648	1	14	\N	127	26261	\N	52.736699848168001	Тамбовская область, город Тамбов, Октябрьский район, Широкая, 8	Россия, Тамбовская область, Тамбов	0101000020E6100000DD99098673B744404A7B832F4C5E4A40
92641	1	14	\N	127	25692	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Чичканова, 125	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92663	1	14	\N	127	25588	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Чичерина, 30а		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92664	1	14	\N	127	25714	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Цветочная/М.Н.Мордасовой, 6/20		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92623	1	14	\N	127	26320	\N	52.705528101324603	Тамбовская область, город Тамбов, Ленинский район, Фридриха Энгельса, 73	Россия, Тамбовская область, Тамбов	0101000020E61000001ADEACC1FBBA4440C634D3BD4E5A4A40
92687	1	14	\N	127	26170	\N	52.709848532236698	г. Тамбов, Ударная, 2	Россия, Тамбовская область, Тамбов	0101000020E61000002CF4C13236B44440950C0055DC5A4A40
92631	1	14	\N	127	26321	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Студенецкая набережная, 23		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92630	1	14	\N	127	25907	\N	52.737969695378098	Тамбовская область, город Тамбов, Октябрьский район, Степана Разина, 7	Россия, Тамбовская область, Тамбов	0101000020E610000073BC02D193B84440EDB60BCD755E4A40
92658	1	14	\N	127	25578	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Социалистическая, 5		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92291	1	14	\N	127	75036	\N	52.714219999999997	п.Устьинский, Солнечная, 24	Россия, Тамбовская область, Тамбов, Солнечная улица, 16/48	0101000020E6100000529B38B9DFB3444016139B8F6B5B4A40
92707	1	14	\N	127	25483	\N	52.758937000000003	д.Красненькая, Совхозная, 166А		0101000020E6100000EAEC647094BA4440B85CFDD824614A40
92621	1	14	\N	127	26313	\N	52.719785000000002	Тамбовская область, город Тамбов, Ленинский район, Лермонтовская, 1А		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92647	1	14	\N	127	26028	\N	52.688320311337797	Тамбовская область, город Тамбов, Октябрьский район, Советская, 193	Россия, Тамбовская область, Тамбовский район, поселок Покрово-Пригородное	0101000020E61000002BF697DD93B744406397A8DE1A584A40
92638	1	14	\N	127	25504	\N	52.737998999105599	Тамбовская область, город Тамбов, Октябрьский район, Советская, 159	Россия, Тамбовская область, Тамбов	0101000020E610000087A8C29FE1B9444088BD50C0765E4A40
92628	1	14	\N	127	25504	\N	52.719785000000002	Тамбовская область, город Тамбов, Ленинский район, Советская, 89	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92627	1	14	\N	127	25504	\N	52.691084853636198	Тамбовская область, город Тамбов, Ленинский район, Советская, 110	Россия, Тамбовская область, Тамбов	0101000020E61000000C3A2174D0B74440CAE0287975584A40
92625	1	14	\N	127	25504	\N	52.719785000000002	Тамбовская область, город Тамбов, Ленинский район, Советская, 93		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92618	1	14	\N	127	25504	\N	52.701774255807898	Тамбовская область, город Тамбов, Ленинский район, Советская, 6	Россия, Тамбовская область, Тамбов	0101000020E610000061DD787764BC44407097FDBAD3594A40
92667	1	14	\N	127	26042	\N	52.719785000000002	г. Тамбов, Серпуховская, 15		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92671	1	14	\N	127	25991	\N	52.719785000000002	г. Тамбов, Сергея Лазо, 18	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92624	1	14	\N	127	26066	\N	52.711777273599502	Тамбовская область, город Тамбов, Ленинский район, Сергеева-Ценского, 4	Россия, Тамбовская область, Тамбов	0101000020E6100000A8565F5D15BC4440C2853C821B5B4A40
92665	1	14	\N	127	26347	\N	52.719785000000002	г. Тамбов, Сенько, 10		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92619	1	14	\N	127	25424	\N	52.719785000000002	Тамбовская область, город Тамбов, Ленинский район, Самарская, 9		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92656	1	14	\N	127	26083	\N	52.775618414162899	Тамбовская область, город Тамбов, Октябрьский район, Рылеева, 52	Россия, Тамбовская область, Тамбовский район	0101000020E6100000C095ECD808B444402F185C7347634A40
92662	1	14	\N	127	25582	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Рылеева, 84		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92661	1	14	\N	127	25582	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Рылеева, 77	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92660	1	14	\N	127	25582	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Рылеева, 69		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92657	1	14	\N	127	25582	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Рылеева, 67		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92645	1	14	\N	127	25973	\N	52.743048712464301	Тамбовская область, город Тамбов, Октябрьский район, Пролетарская, 252/2	Россия, Тамбовская область, Тамбов	0101000020E6100000807EDFBF79B94440AA29C93A1C5F4A40
92643	1	14	\N	127	26206	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, проезд Энергетиков, 7		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92686	1	14	\N	127	26102	\N	52.735260643054502	г. Тамбов, Полынковская, 47	Россия, Тамбовская область, Тамбов	0101000020E61000004149810530B744401B834E081D5E4A40
92617	1	14	\N	127	26318	\N	52.702647575220801	Тамбовская область, город Тамбов, Ленинский район, Пионерская, 11	Россия, Тамбовская область, Тамбов	0101000020E610000029081EDFDEBB4440C74CA25EF0594A40
92670	1	14	\N	127	25675	\N	52.713764569495702	г. Тамбов, Петропавловская, 3		0101000020E610000053B3075A81B54440C503CAA65C5B4A40
92634	1	14	\N	127	26192	\N	52.732795649163002	Тамбовская область, город Тамбов, Октябрьский район, Пензенская, 62	Россия, Тамбовская область, Тамбов	0101000020E61000005E6919A9F7B84440DF516342CC5D4A40
92666	1	14	\N	127	26331	\N	52.725438910006197	г. Тамбов, Ново-рубежный переулок, 28	Россия, Тамбовская область, Тамбов	0101000020E6100000342BDB87BCB94440191F662FDB5C4A40
92682	1	14	\N	127	25853	\N	52.719785000000002	г. Тамбов, Новикова-Прибоя, 53 корп. 1		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92680	1	14	\N	127	25526	\N	52.719785000000002	г. Тамбов, Нагорная, 14		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92655	1	14	\N	127	25444	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Н.Вирты, 120	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92654	1	14	\N	127	25444	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Н.Вирты, 96		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92632	1	14	\N	127	25825	\N	52.734544278818902	Тамбовская область, город Тамбов, Октябрьский район, Московская, 23а	Россия, Тамбовская область, Тамбов	0101000020E610000038DC476E4DBC44408CBCAC89055E4A40
92629	1	14	\N	127	25825	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Московская, 46		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92642	1	14	\N	127	25972	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Моршанское шоссе, 17		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92653	1	14	\N	127	25975	\N	52.738217148455	Тамбовская область, город Тамбов, Октябрьский район, Мичуринская, 112б	Россия, Тамбовская область, Тамбов	0101000020E610000013D38558FDB74440F52C08E57D5E4A40
92652	1	14	\N	127	25975	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Мичуринская, 129		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92651	1	14	\N	127	25975	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Мичуринская, 110		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92649	1	14	\N	127	25975	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Мичуринская, 93	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92342	1	14	\N	127	74475	\N	52.720205	рп.Дмитриевка, Мира, 41в		0101000020E61000002EABB019E0B4444035B56CAD2F5C4A40
92637	1	14	\N	127	25963	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Куйбышева, 1		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92620	1	14	\N	127	26063	\N	52.719785000000002	Тамбовская область, город Тамбов, Ленинский район, Кронштадтская, 83		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92678	1	14	\N	127	25462	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Карла Маркса, 167		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92646	1	14	\N	127	25462	\N	52.745858195229303	Тамбовская область, город Тамбов, Октябрьский район, Карла Маркса, 259	Россия, Тамбовская область, Тамбов	0101000020E61000002E39EE940EB84440E0BA6246785F4A40
92626	1	14	\N	127	25462	\N	52.719785000000002	Тамбовская область, город Тамбов, Ленинский район, Карла Маркса, 153	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92684	1	14	\N	127	25718	\N	52.726878440968697	г. Тамбов, Кавалерийская, 7А	Россия, Тамбовская область, Тамбов	0101000020E6100000FF959526A5B6444048179B560A5D4A40
92689	1	14	\N	127	26096	\N	52.718742183489603	г. Тамбов, Интернациональная, 118	Россия, Тамбовская область, Тамбов	0101000020E6100000F1845E7F12B744407D21E4BCFF5B4A40
92668	1	14	\N	127	25460	\N	52.719785000000002	г. Тамбов, Ивана Франко, 6		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92650	1	14	\N	127	25440	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, Защитная, 1а	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92674	1	14	\N	127	26052	\N	52.706271011451598	г. Тамбов, Железнодорожная, 51а	Россия, Тамбовская область, Тамбов	0101000020E61000005114E81379B844407E8E8F16675A4A40
92673	1	14	\N	127	26052	\N	52.7203930489623	г. Тамбов, Железнодорожная, 10	Россия, Тамбовская область, Тамбов	0101000020E61000006E32AA0CE3B6444038A27BD6355C4A40
92679	1	14	\N	127	26352	\N	52.719785000000002	г. Тамбов, Делегатская, 20В		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92616	1	14	\N	127	25422	\N	52.719785000000002	Тамбовская область, город Тамбов, Ленинский район, Гоголя, 1	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92685	1	14	\N	127	25915	\N	52.719785000000002	г. Тамбов, Гастелло, 38		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92636	1	14	\N	127	25837	\N	52.726402945072998	Тамбовская область, город Тамбов, Октябрьский район, Володарского, 7	Россия, Тамбовская область, Тамбов	0101000020E6100000CD74AF93FAB64440AF5B04C6FA5C4A40
92681	1	14	\N	127	26200	\N	52.7374812970045	г. Тамбов, Бастионная, 19	Россия, Тамбовская область, Тамбов	0101000020E6100000F792C6681DB14440F03504C7655E4A40
92677	1	14	\N	127	25594	\N	52.719785000000002	г. Тамбов, Астраханская, 159		0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92676	1	14	\N	127	25594	\N	52.703859765598601	г. Тамбов, Астраханская, 182	Россия, Тамбовская область, Тамбов	0101000020E6100000CA8B4CC0AFBB4440357BA015185A4A40
92675	1	14	\N	127	25594	\N	52.6805354583934	г. Тамбов, Астраханская, 181а	Россия, Тамбовская область, Тамбов	0101000020E61000002B6B9BE271BB4440456458C51B574A40
92622	1	14	\N	127	25429	\N	52.708943183421397	Тамбовская область, город Тамбов, Ленинский район, А.Бебеля, 108	Россия, Тамбовская область, Тамбов	0101000020E610000077F4BF5C8BBA444033DDEBA4BE5A4A40
92639	1	14	\N	127	25835	\N	52.719785000000002	Тамбовская область, город Тамбов, Октябрьский район, 1-я Полковая, 25	Россия, Тамбовская область, Тамбов	0101000020E6100000DD5B9198A0B84440609335EA215C4A40
92496	1	14	\N	4588	25595	\N	52.666629	Тамбовская область, город Рассказово, Тимирязева, 3		0101000020E6100000373811FDDAF2444058C85C1954554A40
92487	1	14	\N	4588	25797	\N	52.666629	Тамбовская область, город Рассказово, Тамбовская, 122		0101000020E6100000373811FDDAF2444058C85C1954554A40
92495	1	14	\N	4588	25469	\N	52.666629	Тамбовская область, город Рассказово, Спортивная, 75		0101000020E6100000373811FDDAF2444058C85C1954554A40
92485	1	14	\N	4588	25996	\N	52.666629	Тамбовская область, город Рассказово, Советская, 1	Россия, Тамбовская область, Рассказово	0101000020E6100000373811FDDAF2444058C85C1954554A40
92483	1	14	\N	4588	25996	\N	52.666629	г.Рассказово, Советская, 2		0101000020E6100000373811FDDAF2444058C85C1954554A40
92481	1	14	\N	4588	25996	\N	52.666629	Тамбовская область, город Рассказово, Советская, 83		0101000020E6100000373811FDDAF2444058C85C1954554A40
92489	1	14	\N	4588	26290	\N	52.662086098738101	г.Рассказово, Пушкина, 103	Россия, Тамбовская область, Рассказово городской округ	0101000020E6100000933655F7C8F04440DA91EA3BBF544A40
92491	1	14	\N	4588	25913	\N	52.666629	г.Рассказово, Пролетарская, 23А		0101000020E6100000373811FDDAF2444058C85C1954554A40
92494	1	14	\N	4588	25999	\N	52.666629	Тамбовская область, город Рассказово, Победы, 9	Россия, Тамбовская область, Рассказово	0101000020E6100000373811FDDAF2444058C85C1954554A40
92479	1	14	\N	4588	26039	\N	52.666629	Тамбовская область, город Рассказово,ул.Некрасова, 4		0101000020E6100000373811FDDAF2444058C85C1954554A40
92478	1	14	\N	4588	26039	\N	52.666629	Тамбовская область, город Рассказово, Некрасова, 4		0101000020E6100000373811FDDAF2444058C85C1954554A40
92484	1	14	\N	4588	25579	\N	52.666629	Тамбовская область, город Рассказово, Маяковского, 6		0101000020E6100000373811FDDAF2444058C85C1954554A40
92482	1	14	\N	4588	25655	\N	52.666629	Тамбовская область, город Рассказово, Комсомольская, 115А		0101000020E6100000373811FDDAF2444058C85C1954554A40
92493	1	14	\N	4588	25468	\N	52.666629	Тамбовская область, город Рассказово, Гоголя, 5А		0101000020E6100000373811FDDAF2444058C85C1954554A40
92486	1	14	\N	4588	26350	\N	52.666629	Тамбовская область, город Рассказово, Аптекарская, 16		0101000020E6100000373811FDDAF2444058C85C1954554A40
92490	1	14	\N	4588	25717	\N	52.666629	Тамбовская область, город Рассказово, Академика Маркова, 27		0101000020E6100000373811FDDAF2444058C85C1954554A40
92488	1	14	\N	4588	26353	\N	52.666629	Тамбовская область, город Рассказово, ул.60 лет, д.7	Россия, Тамбовская область, Рассказово	0101000020E6100000373811FDDAF2444058C85C1954554A40
92704	1	14	156	45607	26053	\N	52.776705	с.Донское, Советская, 218		0101000020E610000073840CE4D9BD4440E1D1C6116B634A40
92311	1	14	\N	2288	\N	\N	53.443638	"г.Моршанск, поселок Газопровод, Здание ООО ""ГазпромТрансгазМосква"""		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92317	1	14	\N	2288	25922	\N	53.443638	г.Моршанск, Южная, 55		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92309	1	14	\N	2288	25800	\N	53.448503391925598	г.Моршанск, Фрунзе, 35	Россия, Тамбовская область, Моршанск	0101000020E61000003A083A5AD5E444403694DA8B68B94A40
92310	1	14	\N	2288	26092	\N	53.443638	г.Моршанск, Пролетарская, 4	Россия, Тамбовская область, Моршанск	0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92315	1	14	\N	2288	26364	\N	53.443638	г.Моршанск, Пионерская, 38		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92307	1	14	\N	2288	25928	\N	53.443638	г.Моршанск, Октябрьская площадь, 41		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92306	1	14	\N	2288	25928	\N	53.442767524060699	г.Моршанск, Октябрьская площадь, 12	Россия, Тамбовская область, Моршанск	0101000020E6100000B22E6EA301E8444090DB2F9FACB84A40
92313	1	14	\N	2288	25600	\N	53.443638	г.Моршанск, Лотикова, 90		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92312	1	14	\N	2288	25600	\N	53.443638	г.Моршанск, Лотикова, 52		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92305	1	14	\N	2288	25567	\N	53.443638	г.Моршанск, Ленина, СПТУ №9		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92302	1	14	\N	2288	25784	\N	53.4562396558917	г.Моршанск, Крупской, 13	Россия, Тамбовская область, Моршанск	0101000020E610000095BBCFF1D1E844404390831266BA4A40
92304	1	14	\N	2288	25534	\N	53.443638	г.Моршанск, Красноармейская, 112		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92314	1	14	\N	2288	26359	\N	53.443638	г.Моршанск, Красная, 2		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92298	1	14	\N	2288	25855	\N	53.443638	г.Моршанск, Кирова, 69 А	Россия, Тамбовская область, Моршанск	0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92303	1	14	\N	2288	25966	\N	53.443638	г.Моршанск, Интернациональная, 89		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92297	1	14	\N	2288	26358	\N	53.436162786165497	г.Моршанск, Зеленая, 16	Россия, Тамбовская область, Моршанск	0101000020E6100000C70E2A711DE54440D55C6E30D4B74A40
92300	1	14	\N	2288	25723	\N	53.443638	г.Моршанск, Дзержинского, 22		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92316	1	14	\N	2288	25575	\N	53.443638	г.Моршанск, Горького, 1		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92308	1	14	\N	2288	26275	\N	53.443638	г.Моршанск, Гибнера, 13	Россия, Тамбовская область, Моршанск	0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92301	1	14	\N	2288	25690	\N	53.443638	г.Моршанск, 7-й городок, 24		0101000020E6100000E7C589AF76E64440A5A14621C9B84A40
92206	1	14	\N	2401	25715	\N	52.896342300063203	г. Мичуринск, Федеративная, 48	Россия, Тамбовская область, Мичуринск городской округ	0101000020E61000008CBB41B456404440FF03AC55BB724A40
92203	1	14	\N	2401	25794	\N	52.889153	г. Мичуринск, Турбинная, 3		0101000020E610000043E73576893E4440F511F8C3CF714A40
92188	1	14	\N	2401	25591	\N	52.882325640412098	г. Мичуринск, Тамбовская, 270		0101000020E6100000AB3E575BB14144408B34F10EF0704A40
92191	1	14	\N	2401	25889	\N	52.889153	г. Мичуринск, Средняя, 30-а		0101000020E610000043E73576893E4440F511F8C3CF714A40
92211	1	14	\N	2401	25735	\N	52.889153	г. Мичуринск, Социалистическая, 2		0101000020E610000043E73576893E4440F511F8C3CF714A40
92210	1	14	\N	2401	25735	\N	52.906125305460797	г.Мичуринск, Социалистическая, 2	Россия, Тамбовская область, Мичуринск городской округ	0101000020E61000003D80457EFD3E4440448B6CE7FB734A40
92184	1	14	\N	2401	25393	\N	52.889153	г. Мичуринск, Советская, 351		0101000020E610000043E73576893E4440F511F8C3CF714A40
92182	1	14	\N	2401	25393	\N	52.889153	г. Мичуринск, Советская, 262	Россия, Тамбовская область, Мичуринск	0101000020E610000043E73576893E4440F511F8C3CF714A40
92183	1	14	\N	2401	25652	\N	52.889153	г. Мичуринск, Революционная, 94-а	Россия, Тамбовская область, Мичуринск	0101000020E610000043E73576893E4440F511F8C3CF714A40
92190	1	14	\N	2401	25888	\N	52.889153	г. Мичуринск, Новая, 13-а		0101000020E610000043E73576893E4440F511F8C3CF714A40
92196	1	14	\N	2401	25535	\N	52.889529214922803	г.Мичуринск, Мичурина, 1-Б		0101000020E6100000F8DEDFA0BD3C4440FBEB1516DC714A40
92193	1	14	\N	2401	25400	\N	52.889153	г.Мичуринск, Мира, 12-а		0101000020E610000043E73576893E4440F511F8C3CF714A40
92200	1	14	\N	2401	25383	\N	52.889153	г. Мичуринск, Мартовская, 3	Россия, Тамбовская область, Мичуринск	0101000020E610000043E73576893E4440F511F8C3CF714A40
92198	1	14	\N	2401	25541	\N	52.891644833613803	г.Мичуринск, Липецкое шоссе, 240	Россия, Тамбовская область, Мичуринск	0101000020E6100000B7EF517FBD3E44402A52616C21724A40
92197	1	14	\N	2401	25541	\N	52.892098847719097	г. Мичуринск, Липецкое шоссе, 66	Россия, Тамбовская область, Мичуринск	0101000020E610000008AA46AF063E4440ACE5CE4C30724A40
92201	1	14	\N	2401	25803	\N	52.895122512483098	г. Мичуринск, Лермонтова, 1		0101000020E61000006EC1525DC03D4440DE72F56393724A40
92189	1	14	\N	2401	25791	\N	52.896679682026502	г. Мичуринск, Лаврова, 98	Россия, Тамбовская область, Мичуринск городской округ	0101000020E61000008E3F51D9B03E4440187D0569C6724A40
92205	1	14	\N	2401	25799	\N	52.889153	г. Мичуринск, Красная, 72		0101000020E610000043E73576893E4440F511F8C3CF714A40
92180	1	14	\N	2401	25398	\N	52.889153	г. Мичуринск, Кооперативная, 71	Россия, Тамбовская область, Мичуринск	0101000020E610000043E73576893E4440F511F8C3CF714A40
92199	1	14	\N	2401	25480	\N	52.899177524067198	г. Мичуринск, Киевская, 2		0101000020E6100000AF7C96E7C13B44402FA4C34318734A40
92187	1	14	7107	\N	25654	\N	52.890087279501699	г. Мичуринск, Интернациональная, 94-а	Россия, Тамбовская область, Мичуринск городской округ	0101000020E61000001DE4F5605242444021CCED5EEE714A40
92299	1	14	\N	2401	25852	\N	52.889153	г.Мичуринск, Дзержинского, 22	Россия, Тамбовская область, Мичуринск	0101000020E610000043E73576893E4440F511F8C3CF714A40
92194	1	14	\N	2401	25919	\N	52.889153	г. Мичуринск, Автозаводская, 3-а		0101000020E610000043E73576893E4440F511F8C3CF714A40
92214	1	14	\N	2401	25671	\N	52.889153	г. Мичуринск, 7 Ноября, 11		0101000020E610000043E73576893E4440F511F8C3CF714A40
92213	1	14	\N	2401	25671	\N	52.889153	г. Мичуринск, 7 Ноября, 7-д		0101000020E610000043E73576893E4440F511F8C3CF714A40
92212	1	14	\N	2401	25671	\N	52.889153	г. Мичуринск, 7 Ноября, 1		0101000020E610000043E73576893E4440F511F8C3CF714A40
92208	1	14	\N	51231	\N	\N	52.889153	г. Мичуринск, ЦГЛ		0101000020E610000043E73576893E4440F511F8C3CF714A40
92202	1	14	\N	51231	26164	\N	52.9080063981949	г. Мичуринск, Энгельса, 2	Россия, Тамбовская область, Мичуринск городской округ	0101000020E6100000DF6B088ECB3E44403049658A39744A40
92186	1	14	\N	51231	26368	\N	52.889153	г. Мичуринск, Тамбовская, 146		0101000020E610000043E73576893E4440F511F8C3CF714A40
92209	1	14	\N	51231	26223	\N	52.889153	г. Мичуринск, Советская, 274		0101000020E610000043E73576893E4440F511F8C3CF714A40
92204	1	14	\N	51231	26223	\N	52.899897654253998	г. Мичуринск, Советская, 240		0101000020E6100000DC4B1AA3754044402FDE8FDB2F734A40
92215	1	14	\N	51231	26311	\N	52.889153	г. Мичуринск, Привокзальная площадь, 1		0101000020E610000043E73576893E4440F511F8C3CF714A40
92207	1	14	\N	51231	26110	\N	52.897665860324302	г. Мичуринск, Полтавская, 159		0101000020E6100000E50E9BC8CC414440965D30B8E6724A40
92192	1	14	\N	51231	26132	\N	52.898639040483701	г. Мичуринск, Мира, 12-а	Россия, Тамбовская область, Мичуринск городской округ	0101000020E61000008FFE976BD13A444080F44D9A06734A40
92181	1	14	\N	51231	26150	\N	52.889671976316201	г.Мичуринск, Красная, 134	Россия, Тамбовская область, Мичуринск	0101000020E6100000DF37BEF6CC3E44405D15A8C5E0714A40
92195	1	14	\N	51231	26215	\N	52.889153	г.Мичуринск, Дубровского, 2		0101000020E610000043E73576893E4440F511F8C3CF714A40
92185	1	14	\N	51231	26154	\N	52.883519829621697	г.Мичуринск, Герасимова, 132-а	Россия, Тамбовская область, Мичуринск городской округ	0101000020E6100000BC92E4B9BE41444053AEF02E17714A40
92134	1	14	\N	26221	25868	\N	52.587399975257497	Тамбовская область, город Котовск, Свободы, 8	Россия, Тамбовская область, Котовск	0101000020E6100000D8F15F2008C04440D0D556EC2F4B4A40
92137	1	14	\N	26221	25920	\N	52.578682047153201	Тамбовская область, город Котовск, Посконкина, 34	Россия, Тамбовская область, Котовск	0101000020E61000005AF5B9DA8AC1444056647440124A4A40
92136	1	14	\N	26221	25920	\N	52.590628000000002	Тамбовская область, город Котовск, Посконкина, 1		0101000020E610000014B35E0CE5C044400B0DC4B2994B4A40
92133	1	14	\N	26221	26004	\N	52.590628000000002	Тамбовская область, город Котовск, Октябрьская, 13	Россия, Тамбовская область, Котовск	0101000020E610000014B35E0CE5C044400B0DC4B2994B4A40
92130	1	14	\N	26221	26004	\N	52.590628000000002	Тамбовская область, город Котовск, Октябрьская, 38		0101000020E610000014B35E0CE5C044400B0DC4B2994B4A40
92127	1	14	\N	26221	26004	\N	52.590628000000002	Тамбовская область, город Котовск, Октябрьская, 75		0101000020E610000014B35E0CE5C044400B0DC4B2994B4A40
92131	1	14	\N	26221	25479	\N	52.5877626399081	Тамбовская область, город Котовск, Набережная, 3	Россия, Тамбовская область, Котовск	0101000020E6100000680586AC6EBF4440416667D13B4B4A40
92125	1	14	\N	26221	26006	\N	52.600506263196301	Тамбовская область, город Котовск, Лесхозная, 8а	Россия, Тамбовская область, Котовск	0101000020E6100000DC7EF964C5BE4440A1866F61DD4C4A40
92126	1	14	\N	26221	25603	\N	52.590628000000002	Тамбовская область, город Котовск, Красногвардейская, 1		0101000020E610000014B35E0CE5C044400B0DC4B2994B4A40
92128	1	14	\N	26221	26363	\N	52.590628000000002	Тамбовская область, город Котовск, Котовского, 37		0101000020E610000014B35E0CE5C044400B0DC4B2994B4A40
92129	1	14	\N	26221	25401	\N	52.589922331206402	Тамбовская область, город Котовск, Кирова, 10		0101000020E6100000B22D03CE52C0444070986890824B4A40
92135	1	14	\N	26221	25738	\N	52.590628000000002	Тамбовская область, город Котовск, 9-й Пятилетки, 5а		0101000020E610000014B35E0CE5C044400B0DC4B2994B4A40
92116	1	14	\N	60648	75504	\N	52.661085673599402	улица Спортивная, дом 32, здание МБОУ ДОД д/с «Улыбка»		0101000020E6100000E89FE062455B4540F6EB4E779E544A40
92694	1	14	\N	60435	75007	\N	52.638489406880403	с.Бокино, переулок Березовый, 1	Россия, Тамбовская область, село Бокино	0101000020E6100000AC90F2936ABB444089EDEE01BA514A40
92693	1	14	\N	60435	75013	\N	52.638837063168701	с.Бокино, Советская, 52	Россия, Тамбовская область, село Бокино	0101000020E6100000E20511A969BB4440C53C2B69C5514A40
92838	1	14	548	45628	25574	\N	52.562980000000003	р.п.Умет,ул.Транспортная,д.14, здание Липовского сельского клуба		0101000020E6100000179CC1DF2F7C4540AB2688BA0F484A40
92839	1	14	548	45628	26210	\N	52.562980000000003	р.п.Умет,ул.Советская,д.85,  здание РДК		0101000020E6100000179CC1DF2F7C4540AB2688BA0F484A40
92837	1	14	548	51179	25581	\N	52.612401658751502	пос. совхоза «Сулакский»,ул.Школьная,д.5, здание Сулакского филиала МОУ Уметской средней общеобразоват	Россия, Тамбовская область, Уметский район, поселок Совхоз Сулакский	0101000020E6100000D6FECEF6E87F4540A4005130634E4A40
92825	1	14	548	51193	26204	\N	52.664311312359899	пос. Центральное отделение совхоза «Глуховский», ул.Центральная,д.2а,здание Глуховского филиала МОУ Уметской средней общеобразова	Россия, Тамбовская область, Уметский район, поселок Совхоз Глуховский	0101000020E610000031D3F6AFAC924540C0AF912408554A40
92836	1	14	548	48277	25702	\N	52.606912000000001	"""с.Скачиха, ул.Ленина,д.3а,здание МУК """"Скачихинский Дом культуры"""""""		0101000020E610000037FE4465C370454065C6DB4AAF4D4A40
92331	1	14	548	4166	25387	\N	52.474792999999998	с. Сергиевка, Коммунальная, 43		0101000020E6100000C72AA5677A6D454053AF5B04C63C4A40
92832	1	14	548	4166	25842	\N	52.474792999999998	с.Сергиевка, ул.Заречная,д.54, здание Сергиевского Дома культуры		0101000020E6100000C72AA5677A6D454053AF5B04C63C4A40
92460	1	14	548	45358	25707	\N	52.538859000000002	с.Осиновка, Центральная, 3		0101000020E61000009010E50B5A6A4540E013EB54F9444A40
92828	1	14	548	46436	25970	\N	52.714460000000003	с.Оржевка, ул.Молодежная,д.19, здание Оржевского филиала МОУ Уметской средней общеобразоват		0101000020E6100000B22C98F8A37445406C26DF6C735B4A40
92824	1	14	548	51169	25463	\N	52.775824582066797	д.Нововздвиженка, ул.Центральная,д.9а, здание Ново-Воздвиженского Дома культуры	Россия, Тамбовская область, Уметский район, поселок Нововоздвиженка	0101000020E6100000E90AB6114F8A4540A835CD3B4E634A40
92830	1	14	548	3371	26049	\N	52.816606	с.Нижние Пески, ул.Парковая,д.3,здание Нижне-Песковского филиала МОУ Уметской СОШ		0101000020E6100000AE635C7171784540D3DB9F8B86684A40
92829	1	14	548	51168	25448	\N	52.724126456641599	с.Масловка, ул.Быковская,д.26, здание администрации Оржевского сельсовета	Россия, Тамбовская область, Уметский район, поселок Масловка	0101000020E61000007EE5417A8A72454076172829B05C4A40
92827	1	14	548	46432	25982	\N	52.572625000000002	пос.Красный Октябрь, ул.Центральная,д.62, здание Краснооктябрьского филиала МОУ Уметской средней общео	Россия, Тамбовская область, Уметский район, поселок Красный Октябрь	0101000020E61000008D614ED0268345409EEFA7C64B494A40
92833	1	14	548	40452	26336	\N	52.481214999999999	д.Ильинка,ул.Луговая,д.2, здание администрации Сергиевского сельсовета	Россия, Тамбовская область, Уметский район, поселок Ильинка	0101000020E61000006E32AA0CE36845401DACFF73983D4A40
92221	1	14	548	46283	\N	\N	52.498823000000002	д.Ивановка, д. 78,  здание администрации Ивановского сельсовета		0101000020E610000090DC9A745B7645400EBF9B6ED93F4A40
92826	1	14	548	46283	25454	\N	52.4947883539377	с.Ивановка,  ул.Верхняя,д.25,здание Ивановского филиала МОУ Уметской средней общеобразова	Россия, Тамбовская область, Уметский район, поселок Ивановка	0101000020E610000077BAF3C473764540043A9336553F4A40
92267	1	14	548	60584	\N	\N	52.782398858623999	с.Екатериновка, администрация Екатериновского сельсовета, 4	Россия, Тамбовская область, Уметский район, поселок Екатериновка	0101000020E61000002AC93A1C5D89454028B682A625644A40
92831	1	14	548	51207	25845	\N	52.842998999999999	с.Васильевка, ул.Начальная,д.31/1,здание Васильевской библиотеки	Россия, Тамбовская область, Уметский район, поселок Васильевка	0101000020E610000036CB65A373804540C5C72764E76B4A40
92835	1	14	548	30783	25576	\N	52.515381581877598	"""д.Варварьинка,ул.Центральная,д.16, здание МУК """"Софьинскисельский Дом культуры"""""""	Россия, Тамбовская область, Уметский район, поселок Варваринка	0101000020E6100000F3E84658546445403A799109F8414A40
92823	1	14	548	47795	25839	\N	52.744824999999999	с.Бибиково, ул.Центральная,д.10,здание администрации Бибиковского сельсовета		0101000020E6100000A0E062450D8A4540211FF46C565F4A40
92351	1	14	548	47795	75384	\N	52.744824999999999	с.Бибиково, Мира, 8		0101000020E6100000A0E062450D8A4540211FF46C565F4A40
92821	1	14	548	47977	\N	\N	52.446989000000002	с.Березовска, ул.Садовая,д.2,задание Березовского сельского клуба	Россия, Тамбовская область, Уметский район, поселок Березовка	0101000020E6100000E55E6056287A4540FC5580EF36394A40
92822	1	14	548	49233	26203	\N	52.373485342327903	пос.п.№14, ул.Молодежная,д.1, здание Березовского филиала МОУ Уметской СОШ	Россия, Тамбовская область, Уметский район, поселок 14-й	0101000020E61000009CBF098508784540F645425BCE2F4A40
92792	1	14	16	26647	25807	\N	51.841309000000003	с.Энгуразово, Школьная, 38		0101000020E6100000AA622AFD84FB44404D6A6803B0EB4940
92787	1	14	16	26371	25804	\N	51.882139000000002	д.Чуево-Подгорное, Школьная, 1		0101000020E61000003D1059A4891D454059C345EEE9F04940
92803	1	14	16	27112	26308	\N	51.853003999999999	с.Чуево-Алабушка, Попова, 40а	Россия, Тамбовская область, Уваровский район, поселок Чуево-Алабушка	0101000020E61000002C4487C0910C4540B8AD2D3C2FED4940
92100	1	14	16	47278	25878	\N	51.890366	с.Ульяновка, ул.Центральная, д.13, здание клуба		0101000020E61000004240BE840AFE444034BC5983F7F14940
92784	1	14	16	47278	26374	\N	51.890366	д.Ульяновка, Молодежная, 11	Россия, Тамбовская область, Уваровский район, поселок Ульяновка	0101000020E61000004240BE840AFE444034BC5983F7F14940
92815	1	14	16	20	26316	\N	51.982162000000002	г. Уварово, пер. Первомайский, 4		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92811	1	14	16	20	25673	\N	51.982162000000002	г. Уварово, Шоссейная, 39		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92810	1	14	16	20	25673	\N	51.982162000000002	"г. Уварово, Шоссейная, 71 ""г"""		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92808	1	14	16	20	25674	\N	51.982162000000002	г. Уварово, Центральная, 22	Россия, Тамбовская область, Уваровский район, Уварово	0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92804	1	14	16	20	25644	\N	51.982162000000002	г. Уварово, Микрорайон Молодежный, 13	Россия, Тамбовская область, Уваровский район, Уварово	0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92820	1	14	16	20	26326	\N	51.982162000000002	г. Уварово, Дачная, 1		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92813	1	14	16	20	25679	\N	51.982162000000002	г. Уварово, Гагарина, 1	Россия, Тамбовская область, Уваровский район, Уварово	0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92816	1	14	16	20	26241	\N	51.982162000000002	г. Уварово, Большая Садовая, 83		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92812	1	14	16	20	25423	\N	51.982162000000002	г. Уварово, 4 микрорайон, 1		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92814	1	14	16	20	26015	\N	51.982162000000002	"""г. Уварово, 2 микрорайон, 4 """"а"""""""		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92807	1	14	16	20	25433	\N	51.982162000000002	"г. Уварово, 1 микрорайон, 25 ""а"""		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92806	1	14	16	20	25433	\N	51.982162000000002	"г. Уварово, 1 микрорайон, здание МУК УГДК ""Дружба"""		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92805	1	14	16	20	25433	\N	51.982162000000002	"г. Уварово, 1 микрорайон, 17 ""а"""		0101000020E6100000B43EE5982C204540DEAF027CB7FD4940
92783	1	14	16	47261	25681	\N	51.912705000000003	с.Репное, Молодежная, 4		0101000020E61000000A11700855F84440A6F27684D3F44940
92011	1	14	16	20965	25944	\N	51.733277999999999	с.Павлодар, Юбилейная, 35	Россия, Тамбовская область, Уваровский район, поселок Павлодар	0101000020E61000003D9E961FB80A45402A70B20DDCDD4940
92793	1	14	16	20965	25816	\N	51.733277999999999	с.Павлодар, Центральная, 106д	Россия, Тамбовская область, Уваровский район, поселок Павлодар	0101000020E61000003D9E961FB80A45402A70B20DDCDD4940
92796	1	14	16	26829	25947	\N	52.025584000000002	с.Нижний Шибряй, Центральная, 16		0101000020E61000007769C3616928454083A6255646034A40
92797	1	14	16	26829	26180	\N	52.025584000000002	с.Нижний Шибряй, Кировская, 3		0101000020E61000007769C3616928454083A6255646034A40
92785	1	14	16	26278	25827	\N	51.911470999999999	с.Моисеево-Алабушка, Советская, 131		0101000020E6100000D89DEE3CF10A45404F20EC14ABF44940
92786	1	14	16	26278	25930	\N	51.911470999999999	с.Моисеево-Алабушка, Молодежная, 4		0101000020E6100000D89DEE3CF10A45404F20EC14ABF44940
92788	1	14	16	47377	26294	\N	51.928902000000001	с.Моисеево, Центральная, 51а		0101000020E61000009D4CDC2A882D45403198BF42E6F64940
92791	1	14	16	47430	26169	\N	51.773899999999998	п.Луч, Школьная, 8		0101000020E61000002A029CDEC5F94440EC2FBB270FE34940
92799	1	14	16	47573	26023	\N	52.11927	с.Лебяжье, 4-я Лопатинская, 3а	Россия, Тамбовская область, Уваровский район, поселок Лебяжье	0101000020E6100000710514EAE92D45406CB2463D440F4A40
92798	1	14	16	47557	25810	\N	52.001023000000004	с.Канино, Молодежная, 26		0101000020E6100000F0BE2A172A2B45409CC58B8521004A40
92795	1	14	16	26752	26177	\N	51.678213999999997	д.Григорьевка 2-я, Григорьевская, 52б		0101000020E6100000F46C567DAE0E45403CD862B7CFD64940
92790	1	14	16	26563	25665	\N	51.840601999999997	с.Вольная Вершина, Центральная, 125		0101000020E6100000A5BC5642771F4540E179A9D898EB4940
92801	1	14	16	27027	25419	\N	52.032803999999999	с.Верхний Шибряй, Куракинский, 16		0101000020E61000006EA296E656424540C896E5EB32044A40
92789	1	14	16	26503	25936	\N	51.907732000000003	с.Верхнее Чуево, Советская, 28		0101000020E6100000698D4127842E45402FC4EA8F30F44940
92781	1	14	16	60444	75024	\N	52.000781662551702	с.Берёзовка, Советская, 23	Россия, Тамбовская область, Уваровский район, поселок Березовка	0101000020E61000007FF62345640845407636E49F19004A40
92800	1	14	16	47591	26202	\N	52.155830000000002	с.Алаторка, Алаторская, 26		0101000020E610000091459A78072645402BDEC83CF2134A40
92817	1	14	7105	51167	25438	\N	52.014717942751702	г. Уварово, пер. Большой Садовый, 57	Россия, Тамбовская область, Уварово городской округ	0101000020E6100000555051F52B1F4540CE548847E2014A40
92767	1	14	569	46946	26026	\N	52.105730999999999	д. Ястребовка, ул.Школьная,д.10, Здание филиала МБОУ ТСОШ №2 в с. Гладышево	Россия, Тамбовская область, Токаревский район, поселок Ястребовка	0101000020E6100000F435CB65A38744403196E997880D4A40
92780	1	14	569	32188	25558	\N	52.034731999999998	"""д. Чичерино,   ул.Полевая,д.28,Административное здание ООО """"Агро-Вилион"""""""		0101000020E61000007EA99F3715AD4440F50F221972044A40
92779	1	14	569	3534	26171	\N	51.965345999999997	с Троицкий Росляй,ул.Центральная,д.13, Здание администрации Троицкоросляского сельсовета		0101000020E61000005019FF3EE38A444086A92D7590FB4940
92752	1	14	569	24737	25630	\N	51.991973000000002	р.п. Токаревка, пр-кт Революции, 2		0101000020E6100000EB5223F433954440ECC1A4F8F8FE4940
92753	1	14	569	24737	25530	\N	51.991973000000002	р.п. Токаревка, Чичканова, 25		0101000020E6100000EB5223F433954440ECC1A4F8F8FE4940
92751	1	14	569	24737	25914	\N	51.991973000000002	р.п. Токаревка, пр-кт Революции, 72		0101000020E6100000EB5223F433954440ECC1A4F8F8FE4940
92754	1	14	569	24737	26156	\N	51.991973000000002	р.п. Токаревка, 40 лет Октября, 46		0101000020E6100000EB5223F433954440ECC1A4F8F8FE4940
92755	1	14	569	24915	26255	\N	51.973857000000002	д. Старогрязное, Школьная, 14		0101000020E6100000997E8978EB90444087FD9E58A7FC4940
92777	1	14	569	60441	75022	\N	51.774090564365302	с. Сергиевка, ул.Центральная,д.10, Здание филиала МБОУ ТСОШ №1 в с. Сергиевка	Россия, Тамбовская область, Токаревский район, поселок Сергиевка	0101000020E610000045F0BF95EC8A44406090F46915E34940
92758	1	14	569	25039	\N	\N	52.196361000000003	д. Розановка, Здание филиала МБОУ ТСОШ №2 в д. Розановка		0101000020E610000017BB7D5699A34440DD9A745B22194A40
92775	1	14	569	47095	25544	\N	51.886108	с. Полетаево,ул.Центральная,д.71, Здание администрации Полетаевского сельсовета		0101000020E61000002BC3B81B448B4440AB5CA8FC6BF14940
92778	1	14	569	51239	26174	\N	51.929479000000001	с. Новоникольское,  ул.Дружбы,д.42,Здание филиала МБОУ ТСОШ №1 в с. Новоникольское	Россия, Тамбовская область, Токаревский район, поселок Новоникольское	0101000020E6100000E15F048D997C4440CEA8F92AF9F64940
92715	1	14	569	45820	25494	\N	52.219700000000003	с.Малиновка, Энтузиастов, 1		0101000020E610000093C3279D48A2444032772D211F1C4A40
92763	1	14	569	25261	25793	\N	52.164686000000003	с. Малая Зверяевка,   ул.Молодежная,д.33,Административное здание Александровского сельсовета		0101000020E610000000C45DBD8AB44440F60D4C6E14154A40
92768	1	14	569	49381	25568	\N	52.015825	с. Малая Даниловка,  ул.Центральная,д.4,Здание администрации Даниловского сельсовета	Россия, Тамбовская область, Токаревский район, поселок Малая Даниловка	0101000020E61000007AABAE43357D4440C7BAB88D06024A40
92776	1	14	569	32110	26165	\N	51.819819000000003	д. Кулешовка, ул. Новая,д.5,Здание филиала МБОУ ТСОШ №1 в д. Кулешовка		0101000020E6100000E8BE9CD9AE8A4440D9D138D4EFE84940
92327	1	14	569	47348	26114	\N	51.886924999999998	поселок Красный Куст, Парковая, 2а		0101000020E6100000C138B874CC9544409D8026C286F14940
92772	1	14	569	47042	25403	\N	51.83211	д. Карловка,  ул.Речная,д.52,Здание филиала МБОУ ТСОШ №1 в д. Карловка	Россия, Тамбовская область, Токаревский район, поселок Карловка	0101000020E6100000210725CCB481444058569A9482EA4940
92756	1	14	569	24991	25532	\N	52.147208999999997	с. Ивано - Лебедянь, ул.Центральная,д.19,Здание администрации Абакумовского сельсовета		0101000020E6100000DC847B65DE984440A35698BED7124A40
92770	1	14	569	51190	25881	\N	51.967671000000003	"""д. Знаменка, ул. Каменка,д.17, Административное здание ООО """"Знаменское"""""""	Россия, Тамбовская область, Токаревский район, поселок Знаменка	0101000020E6100000DA1A118C837D4440D124B1A4DCFB4940
92765	1	14	569	51254	26328	\N	51.977713000000001	с. Васильевка, ул. Новая,д.9,Здание администрации Васильевского сельсовета	Россия, Тамбовская область, Токаревский район, поселок Васильевка	0101000020E6100000A6B5696CAFA34440E1EF17B325FD4940
92757	1	14	569	51218	25917	\N	52.111666	с. Березовка, ул.Кавказская д.21,Здание филиала МБОУ ТСОШ №2 в с. Березовка	Россия, Тамбовская область, Токаревский район, поселок Березовка	0101000020E61000000A9FAD83839944409E094D124B0E4A40
92764	1	14	569	25305	\N	\N	52.005640999999997	"д. Безукладовка, Здание конторы СХПК ""Заря"""	Россия, Тамбовская область, Токаревский район, поселок Безукладовка	0101000020E61000002D978DCEF98F4440244223D8B8004A40
92511	1	14	569	45706	25615	\N	52.088901	Александровка деревня, Школьная, 15		0101000020E6100000D047197101A6444075CAA31B610B4A40
92019	1	14	569	45706	25660	\N	52.088901	с.Александровка, Молодежная, 30		0101000020E6100000D047197101A6444075CAA31B610B4A40
92737	1	14	156	24027	25380	\N	52.849373999999997	п.Горельский лесхоз, Интернациональная, 1А		0101000020E61000000E4A9869FBC344404E098849B86C4A40
14675	5	51	632	9411	75968	\N	53.152946999999998	с.Лыс, Мира, 22		0101000020E61000002A745E6397C25540BA826DC493934A40
92762	1	14	569	45706	75487	\N	52.091280135802897	д. Александровка,   ул.Александровская,д.76,Здание администрации Александровского сельсовета	Россия, Тамбовская область, Токаревский район, поселок Александровка	0101000020E610000049BC3C9D2BA64440B2632310AF0B4A40
92721	1	14	156	51183	\N	\N	52.749569371498701	"п.6 км, детский сад ""Земляничка"""	Россия, Тамбовская область, Тамбовский район, поселок Шестой километр	0101000020E6100000BD70E7C248CF4440378C82E0F15F4A40
92749	1	14	156	24636	26045	\N	52.983401000000001	с.Черняное, Ленина, 178		0101000020E610000063B7CF2A33BF444046ED7E15E07D4A40
92230	1	14	156	1176	26037	\N	52.632406000000003	с.Черняевка, ул. Совхозная, д.2, здание Черняевского филиала МБОУ «Оборонинская СОШ»	Россия, Тамбовская область, Тамбовский район, поселок Черняевка	0101000020E6100000D0285DFA97784440A8E507AEF2504A40
92581	1	14	156	47159	75417	\N	52.583792870181597	с.Федоровка, Школьная, 1	Россия, Тамбовская область, Тамбовский район, поселок Федоровка	0101000020E61000002EE3A6069AA944401E51A1BAB94A4A40
92697	1	14	156	22213	\N	\N	52.701355	"п.Учебное хозяйство Авангард, контора ОАО ""Тамбовагропромхолдинг"", 30"		0101000020E61000007497C459119344406BF12900C6594A40
92736	1	14	156	51199	25763	\N	52.810842000000001	с.Тулиновка, Советская, 66	Россия, Тамбовская область, Тамбовский район, поселок Тулиновка	0101000020E610000042791F4773C84440931CB0ABC9674A40
92716	1	14	156	23039	26118	\N	53.049708000000003	с.Троицкая Дубрава, БОЛЬШАЯ, 1		0101000020E6100000DDD1FF722DC44440BF2CEDD45C864A40
92739	1	14	156	24133	26024	\N	52.844087000000002	с.Татаново, Совхозная, 7		0101000020E610000092205C0185BC444048FDF50A0B6C4A40
92734	1	14	156	23877	9898	\N	52.939658999999999	с.Сурава, переулок Школьный, 2		0101000020E610000098DD938785A244402F3201BF46784A40
92746	1	14	156	46417	25620	\N	52.653629000000002	"п.Строитель,мкр."" Центральный"", 21"		0101000020E6100000B282DF8618B74440CD5B751DAA534A40
92744	1	14	156	46417	25620	\N	52.653629000000002	"п.Строитель, мкр.""Центральный"", 16"		0101000020E6100000B282DF8618B74440CD5B751DAA534A40
92742	1	14	156	46417	25899	\N	52.653629000000002	"п.Строитель,мкр.""Северный"",19"		0101000020E6100000B282DF8618B74440CD5B751DAA534A40
92747	1	14	156	46417	26032	\N	52.653629000000002	п.Строитель, Центральный, 21	Россия, Тамбовская область, Тамбовский район, поселок Строитель	0101000020E6100000B282DF8618B74440CD5B751DAA534A40
92745	1	14	156	46417	26032	\N	52.653629000000002	п.Строитель, Центральный, 16		0101000020E6100000B282DF8618B74440CD5B751DAA534A40
92743	1	14	156	46417	26288	\N	52.653629000000002	п.Строитель, Северный, 19	Россия, Тамбовская область, Тамбовский район, поселок Строитель	0101000020E6100000B282DF8618B74440CD5B751DAA534A40
92730	1	14	156	23738	25629	\N	52.721578999999998	с.Стрельцы, Филимонова, 10Б		0101000020E6100000FF209221C7A844407D3D5FB35C5C4A40
92733	1	14	156	23835	25727	\N	52.786057	с.Столовое, Чапаева, 23Б		0101000020E6100000FFE89B340DE244405CE509849D644A40
92741	1	14	156	24243	26137	\N	52.908290999999998	с.Солдатская Духовка, Школьная, 1		0101000020E61000009E7E501729B84440252026E142744A40
92748	1	14	156	46551	26269	\N	52.811283000000003	с.Селезни, Центральная, 22	Россия, Тамбовская область, Тамбовский район, поселок Селезни	0101000020E6100000C18C2958E39E44408066101FD8674A40
92729	1	14	156	51174	25886	\N	52.820818000000003	"п.совхоза ""Селезневский"", 2-я Школьная, 11"	Россия, Тамбовская область, Тамбовский район, поселок Селезневский	0101000020E6100000252026E142944440ECFB709010694A40
92750	1	14	156	51174	25515	\N	52.82320993575	"п. совхоза ""Селезневский"",  2-я Школьная, 11"	Россия, Тамбовская область, Тамбовский район, поселок Селезневский	0101000020E6100000D5CDC5DFF6944440BEDEFDF15E694A40
92713	1	14	156	51216	\N	\N	52.784139593060303	д.Роща, 17	Россия, Тамбовская область, Тамбовский район, поселок Роща	0101000020E61000001D3BA8C4759E444023BE13B35E644A40
92731	1	14	156	46158	25634	\N	52.745986000000002	с.Пушкари, 50 лет Октября, 80А		0101000020E61000008F8EAB915DA944400EA320787C5F4A40
92738	1	14	156	51212	25877	\N	52.755521116730201	п.Пригородное лесничество, Дорожная, 1	Россия, Тамбовская область, Тамбовский район, поселок Лесничество	0101000020E61000004359F8FA5AC144407A3881E9B4604A40
92726	1	14	156	23554	26250	\N	52.680286000000002	с.Покрово-Пригородное, Советская, 122		0101000020E610000032AB77B81DB644409DF6949C13574A40
92727	1	14	156	23554	25501	\N	52.680286000000002	с.Покрово-Пригородное, Садовая, 50А		0101000020E610000032AB77B81DB644409DF6949C13574A40
92722	1	14	156	45979	26247	\N	52.557198999999997	с.Новосельцево, Центральная, 26		0101000020E61000009D9D0C8E92834440942EFD4B52474A40
92719	1	14	156	23099	25368	\N	52.712535000000003	р.п.Новая Ляда, Советская, 169В	Россия, Тамбовская область, Тамбовский район, поселок Новая Ляда	0101000020E6100000CF9ECBD424D64440B020CD58345B4A40
92717	1	14	156	23099	25368	\N	52.712535000000003	р.п.Новая Ляда, Советская, 80		0101000020E6100000CF9ECBD424D64440B020CD58345B4A40
92718	1	14	156	23099	25746	\N	52.712535000000003	р.п.Новая Ляда, Малоталинская, 2А		0101000020E6100000CF9ECBD424D64440B020CD58345B4A40
92714	1	14	156	22990	25873	\N	52.848357	с.Лысые Горы, Советская, 21		0101000020E6100000E3FF8EA8509D4440952A51F6966C4A40
92740	1	14	156	24178	26131	\N	52.863756000000002	с.Куксово, Интернациональная, 1		0101000020E61000005FD0420246BF4440A5DC7D8E8F6E4A40
92708	1	14	156	22733	25741	\N	52.550426000000002	с.Кузьмино-Гать, Колхозная, 43А		0101000020E610000069C6A2E9ECBC44401E6FF25B74464A40
92710	1	14	156	22776	25859	\N	52.650635000000001	с.Красносвободное, Центральная, 5		0101000020E61000009CDEC5FB71A744400551F70148534A40
92700	1	14	156	22378	26109	\N	52.79654	с.Красная Криуша, Школьная, 2А		0101000020E6100000C4995FCD0184444059FAD005F5654A40
92712	1	14	156	22897	25642	\N	52.769387999999999	п.Комсомолец, Ново-Южная, 28		0101000020E61000002AA73D25E7A44440A9F7544E7B624A40
91971	1	14	156	440	25521	\N	52.876801999999998	с.Козьмодемьяновка, Молодежная, 7а		0101000020E6100000B3B45373B99D4440A088450C3B704A40
92735	1	14	156	23930	26263	\N	52.929949000000001	с.Иноземная Духовка, Школьная, 1		0101000020E610000042AF3F89CFB3444055F99E9108774A40
92692	1	14	156	45389	\N	\N	52.612155999999999	с.Иванково, 134А		0101000020E6100000EA793716147E44406C06B8205B4E4A40
92691	1	14	156	45374	25771	\N	52.601453999999997	с.Дубровка, Центральная, 15		0101000020E6100000E6B16664906F44403106D671FC4C4A40
92705	1	14	156	45607	25520	\N	52.776705	с.Донское, Школьная, 5А		0101000020E610000073840CE4D9BD4440E1D1C6116B634A40
41057	5	51	815	47728	75934	\N	56.239922999999997	Тюменево, Радищева, 53		0101000020E6100000117008556AD055407347FFCBB51E4C40
92720	1	14	156	5063	\N	\N	52.700111	"""п.Георгиевский, п/о Лесное """"Аграрно-технологический техникум"""""""		0101000020E6100000BEFA78E8BBC74440F148BC3C9D594A40
92711	1	14	156	45736	26116	\N	52.609444000000003	с.Борщевка, ЦЕНТРАЛЬНАЯ, 13		0101000020E610000003CFBD874BA84440295FD042024E4A40
92732	1	14	156	23824	26253	\N	52.840133000000002	с.Большая Талинка, 2-я Советская, 55		0101000020E6100000B876A22424E844402BA5677A896B4A40
92698	1	14	156	45502	26073	\N	52.545622321040199	с.Большая Липовица, Советская, 54	Россия, Тамбовская область, Тамбовский район, поселок Большая Липовица	0101000020E610000008008E3D7BAA444033FD12F1D6454A40
92699	1	14	156	22313	25985	\N	52.787016000000001	с.Беломестная Криуша, Школьная, 2А	Россия, Тамбовская область, Тамбовский район, поселок Беломестная-Криуша	0101000020E610000054FCDF1115924440E1B6B6F0BC644A40
92696	1	14	156	22197	25772	\N	52.700482000000001	с.Беломестная Двойня, Центральная, 48	Россия, Тамбовская область, Тамбовский район, поселок Беломестная Двойня	0101000020E610000002452C62D8874440E5B7E864A9594A40
92690	1	14	156	45343	26267	\N	52.639100999999997	с.Авдеевка, Молодежная, 4		0101000020E6100000E0DBF4673F724440A2EBC20FCE514A40
92706	1	14	1702	22652	25737	\N	52.758937000000003	д.Красненькая, переулок Совхозный, 19	Россия, Тамбовская область, Тамбов городской округ, поселок Красненькая	0101000020E6100000EAEC647094BA4440B85CFDD824614A40
92609	1	14	806	17681	26305	\N	53.446406000000003	Тамбовская область, Староюрьевский район, село Троицко-Ивановское, Молодежная, дом 8		0101000020E6100000556AF6402B4444407D5EF1D423B94A40
92614	1	14	806	5796	25818	\N	53.325040000000001	Тамбовская область, Староюрьевский район, с. Староюрьево, Элеваторная, 15		0101000020E610000048A819524559444028F224E99AA94A40
92612	1	14	806	5796	26058	\N	53.325040000000001	Тамбовская область, Староюрьевский район, село Староюрьево, Советская, дом 98		0101000020E610000048A819524559444028F224E99AA94A40
92610	1	14	806	5796	25416	\N	53.325040000000001	Тамбовская область, Староюрьевский район, село Староюрьево, Московская, дом 15-б		0101000020E610000048A819524559444028F224E99AA94A40
92611	1	14	806	5796	26141	\N	53.325040000000001	Тамбовская область, Староюрьевский район, село Староюрьево, Ломоносова, дом 4		0101000020E610000048A819524559444028F224E99AA94A40
92613	1	14	806	5796	25645	\N	53.325040000000001	Тамбовская область, Староюрьевский район, с. Староюрьево, Заречная, дом 31		0101000020E610000048A819524559444028F224E99AA94A40
92599	1	14	806	51251	26278	\N	53.2781229619778	Тамбовская область, Староюрьевский район, село Староалександровка, Центральная, дом 4	Россия, Тамбовская область, Староюрьевский район, поселок Старая Александровка	0101000020E61000006A6D1ADB6B4D4440F9A1D28899A34A40
92607	1	14	806	17584	26303	\N	53.406567000000003	Тамбовская область, Староюрьевский район,  село Спасское, Уваркина, дом 1		0101000020E6100000F836FDD98F3A4440015130630AB44A40
92608	1	14	806	17671	26302	\N	53.390577999999998	Тамбовская область, Староюрьевский район, деревня Скобелевка, Центральная, дом 25		0101000020E6100000E42EC214E5424440BF44BC75FEB14A40
92420	1	14	806	8660	25445	\N	53.277825	с. Рахманино, Школьная, 1		0101000020E610000083DBDAC2F35E44406F8104C58FA34A40
92606	1	14	806	17514	25858	\N	53.328504000000002	Тамбовская область, Староюрьевский район, село Поповка, Пажа, дом 236	Россия, Тамбовская область, Староюрьевский район, поселок Поповка	0101000020E610000089247A19C56C4440774D486B0CAA4A40
92603	1	14	806	17365	25940	\N	53.263995999999999	Тамбовская область, Староюрьевский район, село Подгорное, Центральная, дом 6		0101000020E61000008672A25D855E44402D23F59ECAA14A40
92602	1	14	806	17365	25688	\N	53.263995999999999	Тамбовская область, Староюрьевский район, село Подгорное, Рабочая, дом 9		0101000020E61000008672A25D855E44402D23F59ECAA14A40
92600	1	14	806	17217	25935	\N	53.366943999999997	Тамбовская область, Староюрьевский район, с. Новоюрьево, Советская, дом 112		0101000020E6100000F3ACA415DF70444051BB5F05F8AE4A40
92601	1	14	806	17217	26095	\N	53.366943999999997	Тамбовская область, Староюрьевский район,  село Новоюрьево, Бутырская, дом 64-а		0101000020E6100000F3ACA415DF70444051BB5F05F8AE4A40
92597	1	14	806	5722	26193	\N	53.332025999999999	Тамбовская область, Староюрьевский район, село Новиково, Центральная, дом 97	Россия, Тамбовская область, Староюрьевский район, поселок Новиково	0101000020E61000002577D844664C4440FAB5F5D37FAA4A40
92604	1	14	806	17453	25953	\N	53.214728000000001	Тамбовская область, Староюрьевский район, деревня Надеждина, Школьная, дом 6		0101000020E61000008A592F86726444408BC404357C9B4A40
92596	1	14	806	17070	25566	\N	53.472188000000003	Тамбовская область, Староюрьевский район, село Мезинец, Кончанка, дом 5		0101000020E610000093AAED26F84E444026C808A870BC4A40
92605	1	14	806	17462	26370	\N	53.295019000000003	Тамбовская область, Староюрьевский район, село Крутовское, школьная, дом 166		0101000020E6100000B5352218077144406D59BE2EC3A54A40
92593	1	14	806	16881	26064	\N	53.393799999999999	Тамбовская область, Староюрьевский район, село Заворонежское, Школьная, д. 112		0101000020E6100000AEB9A3FFE55244401895D40968B24A40
92594	1	14	806	16925	25421	\N	53.225181999999997	Тамбовская область, Староюрьевский район, село Вишневое, Центр, дом 51		0101000020E6100000274D83A279584440EDD286C3D29C4A40
92595	1	14	806	16925	25565	\N	53.225181999999997	Тамбовская область, Староюрьевский район, село Вишневое, Племзавод, дом 42		0101000020E6100000274D83A279584440EDD286C3D29C4A40
92592	1	14	806	51252	26282	\N	53.393414	Тамбовская область, Староюрьевский район,с. Большая Дорога, Совхозная, 2	Россия, Тамбовская область, Староюрьевский район, поселок Большая Дорога	0101000020E610000006D9B27C5D564440EFE4D3635BB24A40
92598	1	14	806	17161	26293	\N	53.331349000000003	Тамбовская область, Староюрьевский район, село Боголюбово, Сельскохозяйственная, дом 10	Россия, Тамбовская область, Староюрьевский район, поселок Боголюбово	0101000020E61000008CDAFD2AC0474440FA47DFA469AA4A40
92573	1	14	799	51253	26287	\N	52.960272000000003	с.Челнаво-Рождественское, Центральная, 39		0101000020E6100000ED612F14B0974440DCA16131EA7A4A40
92572	1	14	799	47620	25657	\N	53.020110000000003	с.Чекмари, Октябрьская, 28		0101000020E6100000CD0182397AA444404A29E8F692824A40
92579	1	14	799	47762	25860	\N	53.255231999999999	с.Христофоровка, Молодежная, 1а		0101000020E6100000BCEA01F39075444043723271ABA04A40
92587	1	14	799	16570	25870	\N	53.360317999999999	с.Троицкие Росляи, Московская, 6		0101000020E6100000F226BF4527B144407F1475E61EAE4A40
92566	1	14	799	15585	25788	\N	53.093634999999999	с.Троицкая-Вихляйка, Полевая, 11		0101000020E61000003F8F519E79AD444067614F3BFC8B4A40
92563	1	14	799	15403	25396	\N	53.201298999999999	с.Третьи Левые Ламки, Интернациональная, 47б		0101000020E61000000B42791F47A54440D7DB662AC4994A40
92569	1	14	799	47176	25789	\N	53.086680000000001	с.Стежки, Советская, 114		0101000020E6100000DE03745FCE9A4440D09B8A54188B4A40
92549	1	14	799	47176	25789	\N	53.086680000000001	с.Стежки, Советская, 60		0101000020E6100000DE03745FCE9A4440D09B8A54188B4A40
92589	1	14	799	16676	26087	\N	53.249974000000002	с.Старое Грязное, Ленина, 97		0101000020E61000001477BCC96FBF4440D76CE525FF9F4A40
92244	1	14	799	45623	26085	\N	53.231057999999997	с.Сосновка, ул. Прогресс, д. 7, здание Сосновского филиала МБОУ «Новопокровская СОШ	Россия, Тамбовская область, Сосновский район, поселок Сосновка	0101000020E61000005C76887FD8AE444055BDFC4E939D4A40
92553	1	14	799	45623	25404	\N	53.231057999999997	р.п.Сосновка, Набережная, 5		0101000020E61000005C76887FD8AE444055BDFC4E939D4A40
92548	1	14	799	45623	26295	\N	53.231057999999997	р.п.Сосновка, Мичурина, 128	Россия, Тамбовская область, Сосновский район, поселок Сосновка	0101000020E61000005C76887FD8AE444055BDFC4E939D4A40
92552	1	14	799	45623	75018	\N	53.231057999999997	р.п.Сосновка, Красноармейская, 2		0101000020E61000005C76887FD8AE444055BDFC4E939D4A40
92550	1	14	799	45623	75016	\N	53.231057999999997	р.п.Сосновка, Котовского, 12		0101000020E61000005C76887FD8AE444055BDFC4E939D4A40
92551	1	14	799	45623	25987	\N	53.231057999999997	р.п.Сосновка, Интернациональная, 207		0101000020E61000005C76887FD8AE444055BDFC4E939D4A40
92554	1	14	799	45623	26029	\N	53.231057999999997	р.п.Сосновка, Высотная, 4	Россия, Тамбовская область, Сосновский район, поселок Сосновка	0101000020E61000005C76887FD8AE444055BDFC4E939D4A40
84239	1	14	799	46579	26264	\N	53.119405	с.Советское, Мира, 2	Россия, Тамбовская область, Сосновский район, поселок Советское	0101000020E6100000C02154A9D99B44404CFDBCA9488F4A40
92558	1	14	799	15150	25910	\N	53.142794000000002	д.Семикино, Колхозная, 120а		0101000020E610000038BEF6CC92C844405308E41247924A40
92588	1	14	799	16620	26153	\N	53.337150999999999	с.Савинские Карпели, Интернациональная, 13		0101000020E61000004C3448C153BE4440276893C327AB4A40
92557	1	14	799	47355	\N	\N	53.188912999999999	п.Рабочий, 22		0101000020E61000009B00C3F2E7C9444006651A4D2E984A40
92564	1	14	799	15449	26014	\N	53.223618999999999	с.Правые Ламки, Центральная, 85		0101000020E61000000457790261A54440D2E1218C9F9C4A40
92723	1	14	799	45993	25647	\N	53.253329999999998	д.Поповка, Клубная, 8		0101000020E6100000880E8123819C44403F8C101E6DA04A40
92584	1	14	799	16459	26270	\N	53.400866000000001	с.Покрово-Васильевка, Пролетарская, 41		0101000020E6100000B6300BED9C844440070ABC934FB34A40
92570	1	14	799	47601	26168	\N	53.157192000000002	с.Подлесное, Советская бригада №2, 27	Россия, Тамбовская область, Сосновский район, поселок Подлесное	0101000020E6100000EC134031B29E4440AF9811DE1E944A40
92561	1	14	799	5651	\N	\N	53.094434999999997	"""п.Перкинский лесокомбинат, ул. здание конторы ТОГАУ """"Цнинский лесхоз"""""""		0101000020E610000023D923D40CCB4440834C3272168C4A40
92560	1	14	799	15285	25911	\N	53.108238	с.Перкино, Центральная, 315		0101000020E6100000359BC76130C744409C1727BEDA8D4A40
92562	1	14	799	15392	25912	\N	53.182609999999997	с.Первые Левые Ламки, Пролетарская, 37		0101000020E61000001A506F46CDA1444016F6B4C35F974A40
92591	1	14	799	16784	25415	\N	53.238194	с.Отъяссы, Захарова, 70а		0101000020E610000096CCB1BCABD444403D0D18247D9E4A40
92586	1	14	799	47884	25405	\N	53.290351999999999	с.Ольхи, Советская, 1		0101000020E61000004B22FB20CB9A4440022A1C412AA54A40
92583	1	14	799	16364	26151	\N	53.430506999999999	с.Новочеркасовка, Слободская, 5а		0101000020E6100000D4EFC2D66C9944407BD976DA1AB74A40
92590	1	14	799	16776	25407	\N	53.241013000000002	с.Новое Грязное, Молодежная, 1		0101000020E6100000D575A8A624BB444097749483D99E4A40
92571	1	14	799	51219	25918	\N	53.039937735332998	с.Новая Слобода, Ленинская, 2	Россия, Тамбовская область, Сосновский район, поселок Новая Слобода	0101000020E6100000569DD5027BA444400FEF39B01C854A40
92578	1	14	799	16150	26134	\N	53.154161999999999	п.Новая Поповка, Молодежная, 8		0101000020E610000054ABAFAE0A7E44409A249694BB934A40
92577	1	14	799	16066	25759	\N	53.195537999999999	п.Новая Павловка, Молодежная, 4б		0101000020E61000002D7AA702EE7F44400890A16307994A40
92575	1	14	799	15967	25511	\N	53.243858000000003	с.Нижняя Ярославка, Половинкина, 126		0101000020E6100000651C23D9238644401A6F2BBD369F4A40
92559	1	14	799	51227	26048	\N	53.126656474798899	п.Красный Хутор, Бахмут, 17а	Россия, Тамбовская область, Сосновский район, поселок Красный Хутор	0101000020E6100000BEBED6A546C04440CCEB884336904A40
92555	1	14	799	15016	26031	\N	53.311931000000001	с.Космачевка, Интернациональная, 52	Россия, Тамбовская область, Сосновский район, поселок Космачевка	0101000020E61000008FC70C54C6AF4440E6CDE15AEDA74A40
92568	1	14	799	47553	25531	\N	52.987465999999998	с.Каменный Брод, Центральная, 70		0101000020E6100000B07614E7A8994440BAF42F49657E4A40
92576	1	14	799	47692	25539	\N	53.205376999999999	с.Зеленое, Центральная, 20		0101000020E6100000B56E83DA6F774440E02C25CB499A4A40
92434	1	14	799	49251	25680	\N	53.102665000000002	с.Заречье, Новая, 17		0101000020E6100000C2887D0228CC4440D0B87020248D4A40
92585	1	14	799	16468	25801	\N	53.374867999999999	с.Дельная Дубрава, Советская, 81а		0101000020E610000089981249F4A644409128B4ACFBAF4A40
92567	1	14	799	47551	26280	\N	53.025841	с.Дегтянка, Ленинская, 95		0101000020E610000044317903CC9A4440AEF204C24E834A40
92574	1	14	799	15959	9931	\N	53.276037000000002	с.Вторые Левые Ламки, Больничная, 35		0101000020E6100000CF85915ED488444034BE2F2E55A34A40
92556	1	14	799	15091	26034	\N	53.181105000000002	с.Вирятино, Тамбовская, 4		0101000020E610000043209738F2BC44403012DA722E974A40
92582	1	14	799	16309	25389	\N	53.373165	с.Верхняя Ярославка, Школьная, 3а		0101000020E6100000944BE3175E8F44408481E7DEC3AF4A40
92565	1	14	799	51202	25790	\N	53.127780771827098	с.Атманов Угол, Школьная, 13	Россия, Тамбовская область, Сосновский район, поселок Атаманов Угол	0101000020E61000001F4DF564FEB144406C06B8205B904A40
41062	5	51	815	10753	76029	\N	56.539121000000002	Тундинка, Лесная, 39 А		0101000020E610000048895DDBDB1356401DCBBBEA01454C40
92531	1	14	610	13867	25753	\N	52.339373999999999	Тамбовская область, Сампурский район, село Текино, Советская, 79		0101000020E6100000774B72C0AEC844406D8E739B702B4A40
92532	1	14	610	13964	25854	\N	52.244675000000001	"""Тамбовская область, Сампурский район, поселок совхоза """"Россия"""", Ленина, 12"""		0101000020E6100000C9AA083719CB44400C93A982511F4A40
92541	1	14	610	14352	25506	\N	52.249423	Тамбовская область, Сампурский район, Серединовский сельсовет, село Серединовка, Школьная, 17		0101000020E6100000FCFB8C0B07E2444063EFC517ED1F4A40
92544	1	14	610	5587	25510	\N	52.378253000000001	"Тамбовская область, Сампурский район, поселок Сатинка, Олимпийская, 1""А"""		0101000020E610000053CDACA580D64440944E24986A304A40
92530	1	14	610	13860	25490	\N	52.313257	Тамбовская область, Сампурский район, село Сампур, Советская, 1		0101000020E6100000EB56CF49EFCF44401D1F2DCE18284A40
92542	1	14	610	14436	25633	\N	52.246870000000001	"Тамбовская область, Сампурский район, село Понзари, Придорожная, 104""а"""		0101000020E61000006E6DE179A9D84440882EA86F991F4A40
92546	1	14	610	14578	25890	\N	52.412785	Тамбовская область, Сампурский район, село Петровка, Школьная, 15		0101000020E6100000C3B7B06EBCD34440C2A38D23D6344A40
92728	1	14	610	14533	26252	\N	52.401297999999997	д.Перикса, Центральная, 1А		0101000020E6100000AC5791D101E34440A0F99CBB5D334A40
92545	1	14	610	14533	25592	\N	52.401297999999997	Тамбовская область, Сампурский район, село Перикса, Рабочая, 9		0101000020E6100000AC5791D101E34440A0F99CBB5D334A40
92534	1	14	610	5433	\N	\N	52.130676999999999	Тамбовская область, Сампурский район, село Первомайское, Школьная, 20		0101000020E61000008C6665FB90BB444071AB2006BA104A40
92539	1	14	610	14252	25503	\N	52.089626000000003	Тамбовская область, Сампурский район, село Пановы-Кусты, Театральная, 87а		0101000020E610000008008E3D7BC84440876F61DD780B4A40
92547	1	14	610	51214	25891	\N	52.3057120750763	Тамбовская область, Сампурский район, селоОсино-Лазовка, Центральная, 19	Россия, Тамбовская область, Сампурский район, поселок Осино-Лазовка	0101000020E6100000B64B1B0E4BDF444054FF209221274A40
92543	1	14	610	14444	26125	\N	52.335836	Тамбовская область, Сампурский район, Медненский сельсовет, село Медное, Центральная, 35		0101000020E6100000E15F048D99EE4440E4688EACFC2A4A40
92533	1	14	610	4426	25562	\N	52.206065000000002	"""Тамбовская область, Сампурский район, деревня Марьевка (отделение совхоза """"Россия""""), Садовая, 25"""	Россия, Тамбовская область, Сампурский район, поселок Марьевка	0101000020E6100000EFFE78AF5AC34440D5EC8156601A4A40
92536	1	14	610	4426	25636	\N	52.206065000000002	Тамбовская область, Сампурский район, деревня Марьевка, Кооперативная, 98а		0101000020E6100000EFFE78AF5AC34440D5EC8156601A4A40
92535	1	14	610	14078	25777	\N	52.266776	Тамбовская область, Сампурский район, Ивановский сельсовет, село Ивановка, Олимпийская, 1в	Россия, Тамбовская область, Сампурский район, поселок Ивановка	0101000020E6100000BE88B663EACA4440C9AD49B725224A40
91970	1	14	610	14078	26013	\N	52.264524096400699	с.Ивановка, Гагарина, 14	Россия, Тамбовская область, Сампурский район, поселок Ивановка	0101000020E61000007FF5B86FB5CA4440E98024ECDB214A40
92540	1	14	610	14300	25466	\N	52.251601000000001	Тамбовская область, Сампурский район, село Верхоценье, Центральная, 25		0101000020E6100000B03A72A433EA44400952297634204A40
92537	1	14	610	14154	26136	\N	52.187313000000003	Тамбовская область, Сампурский район, село Бахарево, Школьная, 104а	Россия, Тамбовская область, Сампурский район, поселок Бахарево	0101000020E61000000A2B155454D14440CE8E54DFF9174A40
92513	1	14	610	46451	75364	\N	52.427197	Андреевка деревня, Парковая, 32		0101000020E6100000D2C8E7154FDB444083F92B64AE364A40
92538	1	14	610	4529	25590	\N	52.134839999999997	Тамбовская область, Сампурский район, деревня Александровские Верхи, Школьная, 124а		0101000020E61000004A44F81741D34440A818E76F42114A40
92525	1	14	684	13589	26225	\N	52.234473000000001	Чакино поселок, Зеленая, 18		0101000020E6100000AB2688BA0FFA4440C3651536031E4A40
92517	1	14	684	46531	26122	\N	52.345426000000003	Траковка деревня, Мичуринская, 13	Россия, Тамбовская область, Ржаксинский район, поселок Траковка	0101000020E61000007218CC5F2103454014984EEB362C4A40
92526	1	14	684	46705	26240	\N	52.186269000000003	Тимофеевка село, Основная, 19		0101000020E610000085436FF1F0FA44401BA19FA9D7174A40
92522	1	14	684	46640	25378	\N	52.026891999999997	Степановка село, Школьная, 12		0101000020E6100000A6EF3504C7FF44401343723271034A40
92516	1	14	684	46499	25941	\N	52.306088000000003	Серебряное деревня, Садовая, 48		0101000020E610000094111780460D45405AD93EE42D274A40
92502	1	14	684	12483	25439	\N	52.138869	р.п.Ржакса, Школьная, 36	Россия, Тамбовская область, Ржаксинский район, поселок Ржакса	0101000020E6100000E7E104A6D3024540D0B69A75C6114A40
92500	1	14	684	12483	26103	\N	52.138869	р.п.Ржакса, Советская, 8		0101000020E6100000E7E104A6D3024540D0B69A75C6114A40
92499	1	14	684	12483	25524	\N	52.135806314225299	Ржаксинский поссовет, Первомайская, 36	Россия, Тамбовская область, Ржаксинский район, поселок Ржакса	0101000020E61000009813B4C9E1034540E04C4C1762114A40
92501	1	14	684	12483	26354	\N	52.138869	р.п.Ржакса, Комсомольская, 51		0101000020E6100000E7E104A6D3024540D0B69A75C6114A40
92510	1	14	684	46378	25745	\N	52.031163999999997	Ракитино деревня, Школьная, 1	Россия, Тамбовская область, Ржаксинский район, поселок Ракитино	0101000020E6100000871744A4A6D344400168942EFD034A40
92518	1	14	684	46536	25871	\N	52.131357000000001	Протасово село, Юбилейная, 47	Россия, Тамбовская область, Ржаксинский район, поселок Протасово	0101000020E6100000F913950D6BDE4440E38C614ED0104A40
92508	1	14	684	46343	26367	\N	52.128841000000001	Перевоз село, Центральная, 35	Россия, Тамбовская область, Ржаксинский район, поселок Перевоз	0101000020E61000000E68E90AB623454025B1A4DC7D104A40
92503	1	14	684	46214	26098	\N	52.106467000000002	Пахарь поселок, Молодежная, 6		0101000020E610000049BBD1C77CF24440378DEDB5A00D4A40
92524	1	14	684	13580	26009	\N	52.063732000000002	Отхожее село, Школьная, 17		0101000020E610000075012F336C0A4540B6DAC35E28084A40
92504	1	14	684	46227	25525	\N	52.163642000000003	Николаевский поселок, Зеленая, 48		0101000020E610000047382D78D1F1444043209738F2144A40
92497	1	14	684	51196	25740	\N	52.074233999999997	Каменка село, Советская, 2а	Россия, Тамбовская область, Ржаксинский район, поселок Каменка	0101000020E6100000BFD53A7139E644402920ED7F80094A40
92005	1	14	684	45440	25537	\N	52.254833145008803	с.Ивановка, Мира, 11	Россия, Тамбовская область, Ржаксинский район, поселок Ивановка	0101000020E6100000124BCADDE7FA44408578245E9E204A40
92515	1	14	684	46491	26000	\N	52.30415	Золотовка село, Школьная, 14		0101000020E6100000734C16F71F074540098A1F63EE264A40
92527	1	14	684	13677	25747	\N	52.246980000000001	Жемчужный поселок, Школьная, 1		0101000020E6100000C2D9AD6532F644400F62670A9D1F4A40
92512	1	14	684	60699	75582	\N	52.112561999999997	Гавриловка деревня, Новая, 6	Россия, Тамбовская область, Ржаксинский район, поселок Гавриловка	0101000020E61000002028B7ED7B024540DC627E6E680E4A40
92521	1	14	684	51185	25618	\N	51.970061999999999	Вишневка деревня, Вишневая, 18	Россия, Тамбовская область, Ржаксинский район, поселок Вишневка	0101000020E61000002C64AE0CAAF14440D28BDAFD2AFC4940
92506	1	14	684	12735	25663	\N	52.126823000000002	Большая Ржакса село, Центральная, 8		0101000020E61000001D0247020D1C4540B8B06EBC3B104A40
92505	1	14	684	46273	26362	\N	52.228504999999998	Богданово село, Центральная, 82	Россия, Тамбовская область, Ржаксинский район, поселок Богданово	0101000020E61000006FBDA607052545407AFCDEA63F1D4A40
92520	1	14	684	46585	26236	\N	52.021211999999998	Афанасьевка деревня, Молодежная, 2	Россия, Тамбовская область, Ржаксинский район, поселок Афанасьевка	0101000020E6100000D235936FB6EB444031242713B7024A40
92514	1	14	684	13105	26371	\N	52.1404	Алкаладка деревня, Центральная, 76	Россия, Тамбовская область, Ржаксинский район, поселок Алкаладка	0101000020E61000003A2174D025104540E02D90A0F8114A40
92012	1	14	684	45569	75360	\N	52.126601999999998	д.Александровка 2-я, Центральная, 1		0101000020E6100000352905DD5EF64440D9CD8C7E34104A40
92465	1	14	128	45444	26211	\N	52.472307999999998	с.Хитрово, Центральная, 60		0101000020E61000007B1002F225F24440D0D1AA96743C4A40
92695	1	14	128	22115	\N	\N	52.656135999999996	п.Тригуляй, здание филиала МОУ Цнинская СОЩ №2 в п.Тригуляй		0101000020E61000006C5D6A847EC2444037DDB243FC534A40
92449	1	14	128	48818	\N	\N	52.741973999999999	с.Телешовка, здание Телешовского филиала МОУ Платоновской СОШ		0101000020E61000003A58FFE7301F4540BC3D0801F95E4A40
92446	1	14	128	9886	26071	\N	52.833714000000001	с.Татарщино, Школьная, 5		0101000020E61000003255302AA9014540D21BEE23B76A4A40
92445	1	14	128	9802	25962	\N	52.787359000000002	с.Саюкино, улица Октябрьская, 18	Россия, Тамбовская область, Рассказовский район, поселок Саюкино	0101000020E6100000C362D4B5F6FC44400B9B012EC8644A40
92448	1	14	128	49437	25968	\N	52.772199999999998	с.Рождественское, Школьная, 63	Россия, Тамбовская область, Рассказовский район, поселок Рождественское	0101000020E6100000E622BE13B316454050FC1873D7624A40
92452	1	14	128	51248	\N	\N	52.667308525308897	"д.Каменные Озерки, здание конторы 3-го отделения ОАО ППЗ ""Арженка"""	Россия, Тамбовская область, Рассказовский район	0101000020E610000089B7CEBF5D104540CAA99D616A554A40
92470	1	14	128	11051	\N	\N	52.581167999999998	с.Подоскляй, здание Подоскляйского филиала имени Героя Советского Союза А.Н.Московского МОУ Верхнеспасской СОШ		0101000020E6100000CDC8207711DA4440A9BD88B6634A4A40
92455	1	14	128	49537	26208	\N	52.717700999999998	с.Платоновка, Советская, 35		0101000020E61000007C9E3F6D54FB44403BA759A0DD5B4A40
92456	1	14	128	49537	26337	\N	52.717700999999998	с.Платоновка, Киевская, 32а	Россия, Тамбовская область, Рассказовский район, поселок Платоновка	0101000020E61000007C9E3F6D54FB44403BA759A0DD5B4A40
92458	1	14	128	10491	26292	\N	52.592860000000002	с.Пичер, Советская, 56а		0101000020E6100000E6C9350532054540A48D23D6E24B4A40
92451	1	14	128	51172	\N	\N	52.6399435482735	с.Новгородовка, здание Новгородовского филиала МОУ Платоновской СОШ	Россия, Тамбовская область, Рассказовский район, поселок Новогородовка	0101000020E61000000FB9196EC0194540BEA25BAFE9514A40
92450	1	14	128	48518	\N	\N	52.699632023419802	с.Никольское, здание Никольского филиала имени Героя Советского Союза З.А.Космодемьянской МОУ Платоновской СОШ	Россия, Тамбовская область, Рассказовский район, поселок Никольское	0101000020E610000097C62FBC92184540179E978A8D594A40
92389	1	14	128	48518	25604	\N	52.700727000000001	с.Никольское, Школьная, 2		0101000020E6100000738236397C1845404C361E6CB1594A40
90804	1	14	128	48518	25604	\N	52.700727000000001	с.Никольское, Школьная, 14		0101000020E6100000738236397C1845404C361E6CB1594A40
92469	1	14	128	45497	25370	\N	52.638438999999998	с.Нижнеспасское, Коммунальная, 2		0101000020E610000082CAF8F719E34440D7BE805EB8514A40
92468	1	14	128	45497	25370	\N	52.638438999999998	с.Нижнеспасское, Коммунальная, 21		0101000020E610000082CAF8F719E34440D7BE805EB8514A40
92480	1	14	128	51220	\N	\N	52.678733300894699	Тамбовская область, город Рассказово, Меховой фабрики поселок, 34	Россия, Тамбовская область, Рассказовский район, поселок Меховая Фабрика	0101000020E61000000F48C2BE9DE84440A5DB12B9E0564A40
92529	1	14	128	46757	25892	\N	52.688802000000003	Маяк поселок, Школьная, 12		0101000020E6100000881057CEDE054540AFB5F7A92A584A40
92457	1	14	128	46757	25865	\N	52.688802000000003	п.Маяк, Центральная, 32		0101000020E6100000881057CEDE054540AFB5F7A92A584A40
92435	1	14	128	48434	75027	\N	52.556601999999998	с.Липовка, Молодёжная, 3		0101000020E610000003965CC5E2034540B071FDBB3E474A40
92476	1	14	128	11324	\N	\N	52.528987999999998	с.Котовское, здание Котовского филиала МОУ Верхнеспасской СОШ		0101000020E61000008AE8D7D64FE34440FCFCF7E0B5434A40
92474	1	14	128	45621	25774	\N	52.478062000000001	с.Коптево, Молодежная,23		0101000020E6100000B613252191DC4440EDBAB722313D4A40
92447	1	14	128	9892	75399	\N	52.803241999999997	с.Керша, Молодежная, 7		0101000020E6100000950F41D5E8054540066344A2D0664A40
92461	1	14	128	51221	25979	\N	52.434979206150103	п.имени 2-й пятилетки, Больничный проезд, 6	Россия, Тамбовская область, Рассказовский район, поселок Имени 2-й Пятилетки	0101000020E6100000730F09DFFB05454030B95164AD374A40
92782	1	14	128	60448	75029	\N	52.636691319731	д.Ивановка, Проезжая, 1	Россия, Тамбовская область, Рассказовский район, поселок Ивановка	0101000020E61000001E3691990B0845402A5437177F514A40
92453	1	14	128	10201	25437	\N	52.737318000000002	с.Дмитриевщина, Советская, 35а	Россия, Тамбовская область, Рассказовский район, поселок Дмитриевщина	0101000020E61000000514EAE9230245404660AC6F605E4A40
92463	1	14	128	10688	26341	\N	52.573484000000001	с.Верхнеспасское, Центральная, 84а		0101000020E61000008C0FB3976DF34440BF6378EC67494A40
92464	1	14	128	10688	25900	\N	52.573484000000001	с.Верхнеспасское, Больничная, 24		0101000020E61000008C0FB3976DF34440BF6378EC67494A40
92701	1	14	128	45405	25556	\N	52.500523000000001	с.Богословка, Советская, 1		0101000020E610000053E8BCC62E0B4540AAF23D2311404A40
92462	1	14	128	45405	25580	\N	52.500523000000001	с.Богословка, Новое село, 42		0101000020E610000053E8BCC62E0B4540AAF23D2311404A40
92473	1	14	128	45573	25456	\N	52.546602999999998	д.Ахтырка, Красная, 15а	Россия, Тамбовская область, Рассказовский район, поселок Ахтырка	0101000020E610000006F52D73BAD444409F724C16F7454A40
92030	1	14	128	60583	75361	\N	52.567118424483198	д.Алексеевка, Центральная, 46	Россия, Тамбовская область, Рассказовский район, поселок Алексеевка	0101000020E61000009CA73AE466FC4440897C975297484A40
92216	1	14	128	49411	\N	\N	52.526670000000003	с.Александровка, д. 160, здание администрации Александровского сельсовета		0101000020E610000009FD4CBD6E09454065E42CEC69434A40
92492	1	14	7106	51171	25840	\N	52.677416480498202	г.Рассказово, Ремесленная, 2	Россия, Тамбовская область, Рассказово городской округ	0101000020E610000067F3380CE6F34440C1E44691B5564A40
84225	1	14	137	26643	26254	\N	53.334037000000002	с.Таракса, Красная, 19		0101000020E6100000888384285F1C4540B55373B9C1AA4A40
92444	1	14	137	49374	26324	\N	53.105497999999997	с.Рудовка, Садовая, 11	Россия, Тамбовская область, Пичаевский район, поселок Рудовка	0101000020E6100000E7C589AF763245408EE55DF5808D4A40
92442	1	14	137	9645	26068	\N	53.184618	с.Покрово-Васильево, Рубцовка, 2 А		0101000020E61000000820B589931F454060200890A1974A40
92441	1	14	137	49334	25685	\N	53.320393000000003	с.Подъём, Заречная, 13 А	Россия, Тамбовская область, Пичаевский район, поселок Подъем	0101000020E610000097E5EB32FC274540056F48A302A94A40
92438	1	14	137	9489	25563	\N	53.237278000000003	с.Пичаево, Пролетарская, 17		0101000020E61000008751103CBE194540B80721205F9E4A40
92436	1	14	137	45387	25883	\N	53.213417999999997	с.Питим, Молодёжная, 12	Россия, Тамбовская область, Пичаевский район, поселок Питим	0101000020E61000008655BC91792E45405930F147519B4A40
92440	1	14	137	9575	26334	\N	53.304161999999998	"п. совхоза ""Подъём"" 1-ое отделение, Школьная, 17"		0101000020E6100000C2DEC4909C1E4540CD57C9C7EEA64A40
92427	1	14	137	49149	25969	\N	53.266581000000002	п.Октябрьский, Новая, 16 А		0101000020E61000003B18B14F00FF4440145E82531FA24A40
92466	1	14	137	45460	75391	\N	53.220529999999997	с.Липовка, Молодежная, 28		0101000020E61000001827BEDA51284540B8E4B8533A9C4A40
92429	1	14	137	46668	25978	\N	53.114125000000001	с.Коршуновка, Центральная, 65	Россия, Тамбовская область, Пичаевский район, поселок Коршуновка	0101000020E6100000C11E1329CD084540F853E3A59B8E4A40
92433	1	14	137	49232	25446	\N	53.284173000000003	с.Егоровка, Центральная, 50 В		0101000020E6100000E19BA6CF0E164540FFB3E6C75FA44A40
92431	1	14	137	9142	25527	\N	53.154010999999997	с.Вышенка, Новая, 7		0101000020E6100000D717096D39254540B41CE8A1B6934A40
92426	1	14	137	8959	26062	\N	53.248238999999998	с.Волхонщина, Садовая, 9 Б		0101000020E610000073D9E89C9F0C4540BE4BA94BC69F4A40
92443	1	14	137	49362	25431	\N	53.197426	д.Васильево, Новая, 2	Россия, Тамбовская область, Пичаевский район, поселок Васильево	0101000020E6100000F701486DE21C4540A7B0524145994A40
92428	1	14	137	9056	26312	\N	53.174957999999997	с.Большой Ломовис, Центральная, 47	Россия, Тамбовская область, Пичаевский район, поселок Большой Ломовис	0101000020E6100000828C800A470645403716140665964A40
92430	1	14	137	40388	25923	\N	53.098312	с.Большое Шереметьево, Центральная, 2		0101000020E61000000F5EBBB4E1244540F566D47C958C4A40
92425	1	14	137	8872	25948	\N	53.280284999999999	с.Байловка 2-я, Школьная, 22 А		0101000020E61000002843554CA50745409947FE60E0A34A40
92437	1	14	137	9393	25780	\N	53.169505999999998	с.Бадин Угол, Центральная, 6		0101000020E6100000486C770FD0374540E63C635FB2954A40
14610	1	14	137	51194	\N	\N	53.137733478821701	с.Гагарино 2-е, 6 А	Россия, Тамбовская область, Пичаевский район, поселок 2-е	0101000020E61000009E23F25D4A0145403C4A253CA1914A40
92414	1	14	800	48945	25667	\N	52.459623000000001	с. Яблоновец, Советская, 72		0101000020E6100000BB7CEBC37A3B4440A5BE2CEDD43A4A40
92411	1	14	800	51238	26155	\N	52.5186806013131	Тамбовская область, Петровский район, Шехманский сельсовет, Первомайская, 63	Россия, Тамбовская область, Петровский район, поселок Шехмань	0101000020E61000006F7EC344833C44403E07962364424A40
92404	1	14	800	48775	25609	\N	52.686126999999999	д.Чибизовка, Молодежная, 1		0101000020E610000055849B8C2A33444088F37002D3574A40
92459	1	14	800	5652	25705	\N	52.429827000000003	п.2-го отделения совхоза Арженка, Центральная, 1		0101000020E61000001E51A1BAB92E44400AF8359204374A40
92415	1	14	800	8424	26173	\N	52.474989999999998	с. Хренное, Колхозная, 18	Россия, Тамбовская область, Петровский район, поселок Хренное	0101000020E6100000EE409DF2E83C4440A9F6E978CC3C4A40
92422	1	14	800	48995	\N	\N	52.422612000000001	с. Федоровка,здание администрации Первомайского сельсовета	Россия, Тамбовская область, Петровский район, поселок Федоровка	0101000020E6100000327216F6B45D4440D672672618364A40
92406	1	14	800	48809	75356	\N	52.743915000000001	с. Успеновка, Центральная, 60		0101000020E61000006AF6402B301A44407E00529B385F4A40
92400	1	14	800	48706	25664	\N	52.530504999999998	с. Тынково, Центральная, 5		0101000020E6100000116DC7D45D274440A7AE7C96E7434A40
92405	1	14	800	7907	25955	\N	52.744923	с. Сестренка, Центральная, 26	Россия, Тамбовская область, Петровский район, поселок Сестренка	0101000020E61000005BCD3AE3FB2A4440E48409A3595F4A40
92097	1	14	800	7907	25955	\N	52.746589733674	с. Сестренка, Центральная, 9	Россия, Тамбовская область, Петровский район, поселок Сестренка	0101000020E6100000ACC5A700182B4440A4C2D842905F4A40
92761	1	14	800	46798	25661	\N	52.721966000000002	с. Семеновка,  ул.Школьная,д.5,Здание филиала МБОУ ТСОШ №2 в с. Семеновка		0101000020E6100000B6679604A82144407769C361695C4A40
92416	1	14	800	8498	26054	\N	52.434868000000002	с. Свинино, Молодежная, 9		0101000020E61000005E9D6340F6304440D9092FC1A9374A40
91966	1	14	814	48122	75387	\N	53.248783000000003	п.Первомайский, Советская, 10		0101000020E6100000C4D155BABB2444408066101FD89F4A40
92395	1	14	800	48619	25658	\N	52.662238000000002	с.Покровское, Советская, 14	Россия, Тамбовская область, Петровский район, поселок Покровское	0101000020E61000007C65DEAAEB1A44409015FC36C4544A40
92403	1	14	800	7824	26057	\N	52.644182999999998	с. Покрово- Чичерино, Кооперативная, 72		0101000020E6100000AED4B320942F4440D0D1AA9674524A40
92766	1	14	800	25453	25896	\N	52.630524999999999	д. Петровское, ул.Советская,д.2, Здание филиала МБОУ ТСОШ №2 в д. Петровское	Россия, Тамбовская область, Петровский район, поселок Петровское	0101000020E6100000842A357BA01F4440BB270F0BB5504A40
92328	1	14	800	25453	26237	\N	52.630524999999999	с. Петровское, Приозерная, 27	Россия, Тамбовская область, Петровский район, поселок Петровское	0101000020E6100000842A357BA01F4440BB270F0BB5504A40
92393	1	14	800	25453	75015	\N	52.630524999999999	с.Петровское, Первомайская, 1Б		0101000020E6100000842A357BA01F4440BB270F0BB5504A40
92394	1	14	800	25453	25516	\N	52.630524999999999	с.Петровское, Моторина, 14		0101000020E6100000842A357BA01F4440BB270F0BB5504A40
92771	1	14	800	25453	25885	\N	52.630524999999999	д. Петровское,  ул.Молодежная,д.47, Здание филиала МБОУ ТСОШ №2 в д. Петровское		0101000020E6100000842A357BA01F4440BB270F0BB5504A40
92392	1	14	800	25453	74984	\N	52.630524999999999	с.Петровское, Кооперативная, 7		0101000020E6100000842A357BA01F4440BB270F0BB5504A40
92421	1	14	800	49074	25379	\N	52.639155000000002	с.Песчаное, Центральная, 1А		0101000020E6100000C74961DEE34844409609BFD4CF514A40
92398	1	14	800	48659	\N	\N	52.539188000000003	с. Песковатка, Советская, 45	Россия, Тамбовская область, Петровский район, поселок Песковатка	0101000020E6100000055262D7F61A4440A532C51C04454A40
92412	1	14	800	60597	75415	\N	52.576380046097597	с. Озерки, Советская, 22	Россия, Тамбовская область, Петровский район, поселок Озерки	0101000020E61000000D8E9257E73C4440C408E1D1C6494A40
92409	1	14	800	8121	25550	\N	52.662786025904602	с. Новоситовка, Садовая, 1	Россия, Тамбовская область, Петровский район, поселок Новоситовка	0101000020E610000001DE02098A054440921FF12BD6544A40
92407	1	14	800	8049	26190	\N	52.780894000000004	с. Новое Гаритово, Гагарина, 36		0101000020E6100000134548DDCE0E444042D2A755F4634A40
95185	1	14	800	51256	\N	\N	52.761291	"д.Нарышкино, здание Успеновского  сельского совета Петровского района ""Досуговый центр."""		0101000020E610000057772CB6491344409CDEC5FB71614A40
92424	1	14	800	47229	\N	\N	52.381994746487997	"здание Найденовского сельского филиала МБУК Петровского района ""Досуговый центр"""	Россия, Тамбовская область, Петровский район, поселок Найденовка	0101000020E61000004E7CB5A338654440261E5036E5304A40
92410	1	14	800	8211	25933	\N	52.677965	с. Малый Самовец, Школьная, 25		0101000020E6100000309FAC18AE104440946A9F8EC7564A40
92397	1	14	800	48650	26160	\N	52.552610999999999	с.Крутое, Советская, 18А	Россия, Тамбовская область, Петровский район, поселок Крутое	0101000020E6100000C03FA54A9421444076340EF5BB464A40
92423	1	14	800	60591	75386	\N	52.452493645486797	п.Красный, Центральная, 18А	Россия, Тамбовская область, Петровский район, поселок Красный	0101000020E6100000BBB54C86E35B444070D1C952EB394A40
92399	1	14	800	48690	25650	\N	52.510311534957303	с. Красиловка, Молодежная, 14	Россия, Тамбовская область, Петровский район, поселок Красиловка	0101000020E61000009D2D20B41E2C4440D06053E751414A40
92774	1	14	800	47081	25552	\N	52.522364000000003	с. Калиновка,  ул.Школьная,д.15, Здание филиала МБОУ ТСОШ №1 в с. Калиновка		0101000020E6100000FB07910C39244440CB4DD4D2DC424A40
92419	1	14	800	45988	\N	\N	52.473151999999999	с. Знаменка, Советская, 34	Россия, Тамбовская область, Петровский район, поселок Знаменка	0101000020E6100000BF805EB8734B4440BC04A73E903C4A40
92345	1	14	800	45988	25766	\N	52.473151999999999	с.Знаменка, Советская, 19		0101000020E6100000BF805EB8734B4440BC04A73E903C4A40
92033	1	14	800	45988	25766	\N	52.473151999999999	р.п.Знаменка, Советская, 1		0101000020E6100000BF805EB8734B4440BC04A73E903C4A40
92032	1	14	800	45988	74976	\N	52.472418234962802	р.п.Знаменка, Красная площадь, 6	Россия, Тамбовская область, Петровский район, поселок Знаменка	0101000020E6100000BCB0355B794B444057056A31783C4A40
92396	1	14	800	48629	25802	\N	52.609470999999999	с.Дубовое, Центральная, 11		0101000020E6100000689599D2FA254440226E4E25034E4A40
92417	1	14	800	48990	25833	\N	52.494217999999996	с. Волчки, Советская, 17	Россия, Тамбовская область, Петровский район, поселок Волчки	0101000020E61000009F39EB538E594440198C1189423F4A40
92413	1	14	800	8365	25666	\N	52.542856999999998	с. Большой Избердей, Пионерская, 44		0101000020E6100000B9347EE195324440CCB392567C454A40
92402	1	14	800	48740	26181	\N	52.611708	с. Большая Алексеевка, Колхозная, 10А		0101000020E610000025CD1FD3DA004440CD599F724C4E4A40
92418	1	14	800	51241	26178	\N	52.530723999999999	д. Барановка, Полевая, 33	Россия, Тамбовская область, Петровский район, поселок Барановка	0101000020E61000005C7347FFCB614440E59997C3EE434A40
92379	1	14	814	48342	26018	\N	53.15737	с.Чернышевка, Новая, 2		0101000020E6100000B8E7F9D3461744408EAF3DB324944A40
92164	1	14	814	5801	\N	\N	53.074693000000003	с.Хоботово, здание школы	Россия, Тамбовская область, Первомайский район	0101000020E6100000A1116C5CFF304440BD1E4C8A8F894A40
92361	1	14	814	5801	26230	\N	53.065463000000001	п.Хоботово, Лесная, 1		0101000020E6100000ED9DD156253144408D0C721761884A40
92390	1	14	814	7230	25608	\N	53.185611000000002	с.Хоботец-Васильевское, Школьная, 32		0101000020E6100000D1E7A38CB83E44409163EB19C2974A40
92385	1	14	814	7026	26365	\N	53.181207000000001	с.Хобот-Богоявленское, Интернациональная, 12		0101000020E610000092205C018544444034677DCA31974A40
92380	1	14	814	48350	25734	\N	53.149324	д.Фонвизино, Школьная, 2а		0101000020E6100000EBA9D557572744400341800C1D934A40
92391	1	14	814	7325	25770	\N	53.201483000000003	с. Старосеславино, Советская, 111а		0101000020E6100000AD174339D134444099D9E731CA994A40
92386	1	14	814	51195	25733	\N	53.197636959113602	с.Старое Козьмодемьяновское, Школьная, 18	Россия, Тамбовская область, Первомайский район, поселок Старокозьмодемьяновское	0101000020E61000005C001AA54B43444062BD512B4C994A40
92376	1	14	814	6565	25653	\N	53.211556999999999	с.Старокленское, Пионерская, 41	Россия, Тамбовская область, Первомайский район, поселок Старокленское	0101000020E6100000882D3D9AEA154440B41EBE4C149B4A40
41074	5	51	815	48032	76036	\N	56.602060000000002	Туйла, Паромская, 2 А		0101000020E61000002E3883BF5FCD5540691D554D104D4C40
92371	1	14	814	48122	25651	\N	53.241043756488899	р.п. Первомайский, Дружбы, 6	Россия, Тамбовская область, Первомайский район, поселок Первомайский	0101000020E6100000BBEF181EFB234440D272A087DA9E4A40
92370	1	14	814	48122	25651	\N	53.248783000000003	р.п. Первомайский, Дружбы, 1а		0101000020E6100000C4D155BABB2444408066101FD89F4A40
92374	1	14	814	48235	25785	\N	53.303381999999999	с.Парижская Коммуна, Колхозная, 4а		0101000020E6100000BA2C26361F254440F818AC38D5A64A40
92358	1	14	814	47923	26373	\N	53.271222999999999	с.Озерки, Центральная, 53	Россия, Тамбовская область, Первомайский район, поселок Озерки	0101000020E6100000E3C62DE6E70E444025766D6FB7A24A40
92381	1	14	814	48378	26325	\N	53.125889999999998	с. Новоспасское, Набережная, 65		0101000020E610000073D87DC7F02844405C72DC291D904A40
92388	1	14	814	7125	26307	\N	53.325428000000002	с.Новосеславино, Школьная, 1	Россия, Тамбовская область, Первомайский район, поселок Новосеславино	0101000020E6100000A13028D368384440F299EC9FA7A94A40
92387	1	14	814	51181	25586	\N	53.223625132756503	с.Новое Козьмодемьяновское, Школьная, 63	Россия, Тамбовская область, Первомайский район, поселок Новокозьмодемьяновское	0101000020E61000008978EBFCDB414440B4C876BE9F9C4A40
92375	1	14	814	6502	26157	\N	53.199244	с. Новокленское, Советская, 51д		0101000020E61000001F115322891E44404DF6CFD380994A40
92373	1	14	814	48227	26033	\N	53.284280000000003	с. Новоархангельское, Ленина, 1б		0101000020E6100000F54C2F31961F444015747B4963A44A40
92377	1	14	814	6606	26191	\N	53.216647999999999	с. Малый Снежеток, Центральная Усадьба, 31		0101000020E6100000FD4D2844C00F4440355F251FBB9B4A40
92384	1	14	814	6951	25724	\N	53.140309000000002	с.Иловай-Рождественское, Заречная, 30	Россия, Тамбовская область, Первомайский район, поселок Иловай-Рождественское	0101000020E610000054707841442E4440D02A33A5F5914A40
92372	1	14	814	6333	26335	\N	53.201920000000001	с. Иловай-Дмитриевское, Школьная, 1		0101000020E6100000F19F6EA0C02944404434BA83D8994A40
92383	1	14	814	6882	25491	\N	53.164073979176699	д.Иванжитово, Школьная, 1а	Россия, Тамбовская область, Первомайский район, поселок Иванжитово	0101000020E6100000D68F4DF2232C4440DC0F786000954A40
92378	1	14	814	48313	25408	\N	53.263274000000003	с.Змеевка, Совхозная, 20 б		0101000020E61000004ED2FC31AD1344408DF161F6B2A14A40
92320	1	14	814	47191	25805	\N	53.101702000000003	п.Заводской, Заводская, 2		0101000020E6100000236937FA982744400AF83592048D4A40
92341	1	14	753	60421	74990	\N	52.590170000000001	рп.Дмитриевка, площадь Ленина, 6	Россия, Тамбовская область, Никифоровский район	0101000020E6100000971AA19FA95D4440488AC8B08A4B4A40
92528	1	14	753	46749	75064	\N	52.908448	Ярославка село, Центральная, 5		0101000020E6100000323D6189076C4440ED0E290648744A40
92347	1	14	753	46749	25874	\N	52.908448	с.Ярославка, Криворотченко, 153	Россия, Тамбовская область, Никифоровский район, поселок Ярославка	0101000020E6100000323D6189076C4440ED0E290648744A40
92363	1	14	753	5917	25764	\N	52.709429999999998	с.Юрловка, площадь Советов, 18		0101000020E6100000EA5C514A0858444090662C9ACE5A4A40
92357	1	14	753	47911	25683	\N	52.873758000000002	д.Чебоксары, Молодежная, 37а		0101000020E6100000F10F5B7A347B4440274F594DD76F4A40
92365	1	14	753	5984	26005	\N	52.746526000000003	с.Туровка, Тамбовская, 11		0101000020E6100000E08442041C5844408ECEF9298E5F4A40
92346	1	14	753	47706	25624	\N	52.938786	с.Сычевка, Школьная, 1		0101000020E61000007C9C69C2F6654440A9F8BF232A784A40
92349	1	14	753	51243	26186	\N	52.977111205079098	п.Степановка, Новая, 20	Россия, Тамбовская область, Никифоровский район, поселок Степановка	0101000020E610000010CCD1E3F7664440EBC726F9117D4A40
92354	1	14	753	5431	25632	\N	52.972768000000002	с.Старое Сабурово, Зеленая, 19		0101000020E6100000B7291E17D5804440344C6DA9837C4A40
92356	1	14	753	47876	26257	\N	52.827646999999999	пос.Свобода, Пушкина, 2		0101000020E6100000268FA7E507804440F6D03E56F0694A40
92355	1	14	753	5437	26003	\N	52.84357	с.Сабуро-Покровское, Красная, 51а	Россия, Тамбовская область, Никифоровский район, поселок Сабуро-Покровское	0101000020E6100000C8B1F50CE182444080F10C1AFA6B4A40
92360	1	14	753	5711	25606	\N	52.779727999999999	с.Машково-Сурена, Молодежная, 12		0101000020E6100000C5387F130A6B444043E38920CE634A40
92364	1	14	753	5921	25518	\N	52.685718000000001	д.Любезная, Редькино, 4		0101000020E61000008066101FD86B4440A723809BC5574A40
92348	1	14	753	47735	25728	\N	52.988669999999999	с.Екатеринино, Советская, 47		0101000020E61000002EE3A6069A6B4440A64412BD8C7E4A40
92367	1	14	753	48103	75381	\N	52.882151214629502	с.Дмитриевка, Центральная, 13	Россия, Тамбовская область, Никифоровский район, поселок Дмитриевка	0101000020E6100000DDE9CE13CF6544401D91EF52EA704A40
91980	1	14	753	48103	75381	\N	52.880905063874501	с.Дмитроиевка, Центральная, 1	Россия, Тамбовская область, Никифоровский район, поселок Дмитриевка	0101000020E610000007CE1951DA65444002F1BA7EC1704A40
92340	1	14	753	48103	26245	\N	52.878748959587	рп.Дмитриевка, Победы, 10	Россия, Тамбовская область, Никифоровский район, поселок Дмитриевка	0101000020E6100000D93F4F03066544404432E4D87A704A40
92344	1	14	753	48103	75488	\N	52.880865999999997	рп.Дмитриевка, Коммунальная, 14	Россия, Тамбовская область, Никифоровский район, поселок Дмитриевка	0101000020E6100000BF620D17B965444044149337C0704A40
92343	1	14	753	51187	25627	\N	52.592812371307403	рп.Дмитриевка, Заводская, 10	Россия, Тамбовская область, Никифоровский район	0101000020E610000022DE3AFF765D444093567C43E14B4A40
92352	1	14	753	5319	25475	\N	53.087145	д.Гомзяки, Центральная, 3		0101000020E6100000D93EE42D5771444045813E91278B4A40
92366	1	14	753	48071	25898	\N	52.638762	с.Голицыно, Молодежная, 37а	Россия, Тамбовская область, Никифоровский район, поселок Голицыно	0101000020E6100000DCB930D28B544440BAF605F4C2514A40
92350	1	14	753	47774	25844	\N	53.093710999999999	д.Вырубово, Молодежная, 11а		0101000020E61000002DD2C43BC07744404223D8B8FE8B4A40
92359	1	14	753	5671	25729	\N	52.857101	с.Восточная Старинка, Школьная, 2	Россия, Тамбовская область, Никифоровский район, поселок Восточная Старинка	0101000020E61000008731E9EFA5604440382F4E7CB56D4A40
92353	1	14	753	47830	25507	\N	53.017401	с.Богородицкое, Центральная, 1а		0101000020E6100000390B7BDAE17B444077F52A323A824A40
92339	1	14	558	47568	25622	\N	51.708126	с. Шапкино, пер.Коммунульный, 6		0101000020E6100000759318045632454041B96DDFA3DA4940
40476	5	51	815	14164	75978	\N	56.380806999999997	Тенгулы, Городская, 27		0101000020E6100000CCCF0D4DD9E355403F8BA548BE304C40
92338	1	14	558	47568	25540	\N	51.708126	с.Шапкино, Интернациональная, 91		0101000020E6100000759318045632454041B96DDFA3DA4940
92323	1	14	558	47250	25410	\N	51.818845000000003	с. Чащино, Молодежная, 101		0101000020E6100000543882548A3145401FBFB7E9CFE84940
92333	1	14	558	47475	26128	\N	51.908242999999999	с. Троицкое, Центральная, 54	Россия, Тамбовская область, Мучкапский район, поселок Троицкое	0101000020E6100000B0AD9FFEB34C454014E97E4E41F44940
92382	1	14	558	6879	25382	\N	51.656768999999997	с.Степанищево, Советская, 77		0101000020E6100000C6A52A6D713F45406803B00111D44940
92324	1	14	558	47283	75054	\N	51.798659000000001	с. Прудки, Октябрьская, 22		0101000020E61000004D2CF015DD284540FAD346753AE64940
92334	1	14	558	47481	\N	\N	51.862242999999999	с.Покровка, Советская, 17	Россия, Тамбовская область, Мучкапский район, поселок Покровка	0101000020E61000004CFBE6FEEA5545403B1A87FA5DEE4940
92326	1	14	558	47326	25612	\N	51.745916000000001	п. Новосельцы, Центральная, 19		0101000020E6100000378C82E0F117454015C8EC2C7ADF4940
92329	1	14	558	4048	25481	\N	51.893433999999999	с.Нижнее - Чуево, Советская, 111		0101000020E61000006DE4BA29E53345403691990B5CF24940
92321	1	14	558	3472	25602	\N	51.851835000000001	Тамбовская область, р.п. Мучкапский, Свердлова,15		0101000020E610000065C8B1F50C3B4540494BE5ED08ED4940
92318	1	14	558	3472	26101	\N	51.851835000000001	Тамбовская область, р.п. Мучкапский, Красная, 13		0101000020E610000065C8B1F50C3B4540494BE5ED08ED4940
92319	1	14	558	3472	25607	\N	51.851835000000001	Тамбовская область, р.п.Мучкапский, Заводская, 63		0101000020E610000065C8B1F50C3B4540494BE5ED08ED4940
92336	1	14	558	4436	25879	\N	51.781117000000002	с. Кулябовка, Советская, 9	Россия, Тамбовская область, Мучкапский район, поселок Кулябовка	0101000020E61000004CC5C6BC8E2E4540C1AC50A4FBE34940
92322	1	14	558	47247	25477	\N	51.832911000000003	с. Коростелево, Первомайская, 26		0101000020E61000006B4947399835454045BDE0D39CEA4940
92332	1	14	558	47445	25486	\N	51.942034	д.Владимировка, Садовая, 24а		0101000020E6100000A1815836734C45402BDCF29194F84940
92337	1	14	558	47540	26117	\N	51.733407	с. Варварино, Клубная, 2		0101000020E61000002713B70A6238454028D4D347E0DD4940
92335	1	14	558	51211	25875	\N	51.791601999999997	с. Березовка-1ое, Красная, 53а	Россия, Тамбовская область, Мучкапский район, поселок Березовка 1-я	0101000020E6100000042159C0043845405EB9DE3653E54940
92330	1	14	558	4091	26113	\N	52.060077999999997	с.Арбеньевка, Малиновская, 4а		0101000020E61000008BC058DFC0584540C39ACAA2B0074A40
92325	1	14	558	47304	25478	\N	51.746924999999997	д.Андриановка, Набережная, 2		0101000020E6100000CF49EF1B5F2545404BC8073D9BDF4940
92580	1	14	558	47764	25821	\N	51.730356	с.Андреевка, Центральная, 50		0101000020E6100000018750A566174540FC372F4E7CDD4940
92276	1	14	127	46287	26213	\N	53.510165999999998	п.Центральный, Школьная, 8а		0101000020E6100000310A82C7B7C74440FCC3961E4DC14A40
92282	1	14	127	46422	\N	\N	53.596567999999998	с.Хлыстово, Хлыстовский филиал МОУ Большекуликовской СОШ, 97		0101000020E6100000BD5301F73CD3444089EB18575CCC4A40
92289	1	14	127	1815	25850	\N	53.47692	с.Устьи, Центральная, 12		0101000020E61000008CF4A276BFEA44407767EDB60BBD4A40
92292	1	14	127	1815	25990	\N	53.47692	с.Устьи, Рабочая, 175а		0101000020E61000008CF4A276BFEA44407767EDB60BBD4A40
92293	1	14	127	1815	26074	\N	53.47692	с.Устьи, Октяборьская, 1а		0101000020E61000008CF4A276BFEA44407767EDB60BBD4A40
92290	1	14	127	1815	75295	\N	53.484392999999997	п.Устьинский, МСО, 4а	Россия, Тамбовская область, Моршанский район, поселок Устьи	0101000020E61000003813D38558EB4440A6B4FE9600BE4A40
92287	1	14	127	1697	26080	\N	53.747335999999997	с. Старотомниково, Центральная, 111		0101000020E61000000B0BEE073CF24440CD8FBFB4A8DF4A40
92281	1	14	127	51228	26079	\N	53.461637550972	п. Базевского совхоза, Привокзальная, 15	Россия, Тамбовская область, Моршанский район, поселок Совхоз Базевский	0101000020E6100000469A780778D44440A14B38F416BB4A40
92286	1	14	127	1638	25925	\N	53.619011999999998	с.Серповое, Центральная, 36		0101000020E610000012A0A696ADEB444070EA03C93BCF4A40
92256	1	14	127	32359	25961	\N	53.693404999999998	с.Рысли, Центральная, 32а		0101000020E61000009E616A4B1DE4444002F1BA7EC1D84A40
92252	1	14	127	45767	26323	\N	53.652129000000002	с.Рыбное, Интернациональная, 4		0101000020E6100000569A94826ED74440F8E28BF678D34A40
84195	1	14	127	1984	25848	\N	53.558075000000002	с.Ракша, Центральная, 140	Россия, Тамбовская область, Моршанский район, поселок Ракша	0101000020E6100000FA9CBB5D2FCF44408CDB68006FC74A40
92288	1	14	127	46537	25986	\N	53.732588999999997	с.Раево, Хлебная, 7		0101000020E6100000D542C9E4D40645406534F279C5DD4A40
92273	1	14	127	45914	25402	\N	53.405574000000001	п. Пригородный, Новая, 1в	Россия, Тамбовская область, Моршанский район, поселок Пригородный	0101000020E6100000F629C76471E34440D00D4DD9E9B34A40
92255	1	14	127	45814	25497	\N	53.679301607897003	д. Погореловка, Молодежная, 17	Россия, Тамбовская область, Моршанский район, поселок Погореловка	0101000020E6100000E412471E88C24440BF0D315EF3D64A40
92270	1	14	127	694	25703	\N	53.362951000000002	с.Питерское, Молодёжная, 15	Россия, Тамбовская область, Моршанский район, поселок Питерское	0101000020E6100000F437A11001E144407786A92D75AE4A40
92268	1	14	127	40376	\N	\N	53.528395000000003	д. Петровка, отдел организации досуга населения с.Петровка, дом 39	Россия, Тамбовская область, Моршанский район, поселок Петровка	0101000020E610000087A5811FD5B644405A2F8672A2C34A40
92285	1	14	127	46478	26345	\N	53.618611000000001	с.Пеньки, Центральная, 75		0101000020E61000004BE5ED08A7E7444012F92EA52ECF4A40
92263	1	14	127	262	26329	\N	53.481105999999997	с.Парский Угол, Мира, 6б		0101000020E61000001C60E63BF8A1444066F4A3E194BD4A40
92280	1	14	127	1298	26196	\N	53.793028999999997	с. Носины, Центральная, 125б		0101000020E6100000B4AD669DF1E54440C9E369F981E54A40
92279	1	14	127	1248	25450	\N	53.776186000000003	с.Новотомниково, Школьная, 21б	Россия, Тамбовская область, Моршанский район, поселок Новотомниково	0101000020E6100000EE7A698A00E5444079CE16105AE34A40
92262	1	14	127	45973	25786	\N	53.506224000000003	д. Новоалександровка, 1-ая Заводская, 2	Россия, Тамбовская область, Моршанский район, поселок Новоалександровка	0101000020E610000060E5D022DBC14440A439B2F2CBC04A40
92259	1	14	127	32492	25687	\N	53.552321694584997	с.Мутасьево, Лоскутовка, 32а	Россия, Тамбовская область, Моршанский район, поселок Мутасьево	0101000020E610000045F46BEBA7ED44403F6EBF7CB2C64A40
91982	1	14	169	45520	25406	\N	53.104303000000002	с.Глуховка, Молодежная, 7		0101000020E610000049F4328AE54A4540F6EFFACC598D4A40
92253	1	14	127	51250	\N	\N	53.639559564791597	"п.Молодежный, МУК ""ДК пос. Молодежный"", 1"	Россия, Тамбовская область, Моршанский район, поселок При Алгасовской газоперекачивающей станции	0101000020E6100000CA89761552DA444036EA211ADDD14A40
92296	1	14	127	46697	\N	\N	53.387447000000002	с.Марусино, Марусинский филиал МОУ Устьинская СОШ		0101000020E61000007C0C569C6AF9444077F700DD97B14A40
92275	1	14	127	1002	26209	\N	53.453499999999998	с.Малые Кулики, Ольховка, 37		0101000020E610000012A452EC68C44440355EBA490CBA4A40
92265	1	14	127	392	25570	\N	53.442597999999997	с Маломоршевка, Школьная, 14		0101000020E6100000459DB987841F454033A31F0DA7B84A40
92278	1	14	127	46329	25712	\N	53.289065999999998	с.Левино, Центральная, 74		0101000020E6100000FB1EF5D72BE2444059315C1D00A54A40
92272	1	14	127	46194	26076	\N	53.390588999999999	с.Крюково, 60 лет СССР, 9		0101000020E610000011DF89592FE24440B39602D2FEB14A40
92294	1	14	127	49176	\N	\N	53.455854000000002	"с.Коршуновка, здание Коршуновского ФАП МУЗ ""Карельская  больница"", 21а"	Россия, Тамбовская область, Моршанский район, поселок Коршуновка	0101000020E610000028B9C32632ED44401AE0826C59BA4A40
90611	1	14	127	49479	26107	\N	53.750917969970601	с.Княжево, Центральная, 96	Россия, Тамбовская область, Моршанский район, поселок Княжево	0101000020E6100000CF488446B0E5444026FDBD141EE04A40
92277	1	14	127	1133	26214	\N	53.273947999999997	с.Кершинские Борки, Тамбовская, 18б		0101000020E6100000FDDD3B6A4CDE4440FD6662BA10A34A40
92271	1	14	127	774	25523	\N	53.498603000000003	с.Карели, Новая, 4в		0101000020E61000009B728577B9EC444000581D39D2BF4A40
92269	1	14	127	653	25399	\N	53.326476	с.Ивенье, Ламзина, 15		0101000020E6100000718E3A3AAEE24440E6762FF7C9A94A40
92295	1	14	127	51255	\N	\N	53.672947999999998	п.Зеленый, клуб Моршанского Психоневрологического интерната	Россия, Тамбовская область, Моршанский район, поселок Зеленый Луг	0101000020E61000006B2DCC423BF344404DF4F92823D64A40
92284	1	14	127	51180	25585	\N	53.677103684296902	п.Зеленый Бор, Колхозная, 1	Россия, Тамбовская область, Моршанский район, поселок Зеленый Бор	0101000020E6100000739D465A2AEF4440D2FE0758ABD64A40
92254	1	14	127	51197	25752	\N	53.719025400750198	с.Дъячи, Зеленая, 4а	Россия, Тамбовская область, Моршанский район, поселок Дьячи	0101000020E61000005DE0F25833BC4440D200DE0209DC4A40
92283	1	14	127	46437	26162	\N	53.631096999999997	с.Давыдово, 1-ая Лимасово, 9		0101000020E610000031EE06D15AE1444046CD57C9C7D04A40
92264	1	14	127	46006	26194	\N	53.410995	п. Вяжли, Школьная, 18а	Россия, Тамбовская область, Моршанский район, поселок Вяжли	0101000020E610000022A64412BD064540E6E8F17B9BB44A40
92432	1	14	127	46006	25649	\N	53.410995	с.Вяжли, Центральная, 5		0101000020E610000022A64412BD064540E6E8F17B9BB44A40
92261	1	14	127	45952	25373	\N	53.475842999999998	с.Весёлое, Школьная, 1		0101000020E6100000D88349F1F1B94440E883656CE8BC4A40
92260	1	14	127	45926	25830	\N	53.763131000000001	с. Ваново, Советская, 10		0101000020E6100000B438639813CE44402AC8CF46AEE14A40
92274	1	14	127	46236	25577	\N	53.390551000000002	д.Быковка, Заря, 37		0101000020E61000008B18761893C24440C6353E93FDB14A40
92258	1	14	127	32451	25372	\N	53.598833999999997	с. Алкужинские Борки, Центральная, 119а		0101000020E61000000C2252D32EEC4440CEDDAE97A6CC4A40
92257	1	14	127	32361	25496	\N	53.573481999999998	с.Алкужи, Новая, 17		0101000020E610000060C8EA56CFED44401E6CB1DB67C94A40
92251	1	14	127	32108	25428	\N	53.682447000000003	с. Алгасово, Ильинка, 24		0101000020E610000001E0D8B3E7D644406D205D6C5AD74A40
92250	1	14	127	32108	25436	\N	53.682447000000003	с.Алгасово, Гоголя, 6а		0101000020E610000001E0D8B3E7D644406D205D6C5AD74A40
92249	1	14	217	45711	\N	\N	52.208950999999999	с.Шульгино, д.24, здание Шульгинского Дома  культуры		0101000020E6100000DBA2CC06996A4440B6BB07E8BE1A4A40
92245	1	14	217	1758	26187	\N	52.028039	с.Шмаровка, ул. Центральная, д. 23, здание Шмаровского филиала МБОУ «Оборонинская СОШ»		0101000020E610000037E15E99B75044409B012EC896034A40
92228	1	14	217	1059	26301	\N	52.189515999999998	" д.Центральное отделение совхоза им.Ленина, ул. Луговая д.1""а"", здание Ленинского филиала МБОУ «Новопокровская СОШ»"	Россия, Тамбовская область, Мордовский район, поселок Центральное отделение совхоза имени Ленина	0101000020E6100000BF60376C5B6C4440CC086F0F42184A40
92248	1	14	217	827	\N	\N	52.288668000000001	д.Хоперка, д.41,  здание Хоперского филиала МБОУ «Новопокровская СОШ»	Россия, Тамбовская область, Мордовский район, поселок Хоперка	0101000020E6100000EFC682C2A06E44406CB3B112F3244A40
92222	1	14	217	46307	\N	\N	52.332715	д.Плоское, д. 3, здание Плоскинского филиала МБОУ «Новопокровская СОШ»		0101000020E61000000744882B67494440BFF1B567962A4A40
92217	1	14	217	40479	\N	\N	51.965356999999997	д.Отрада, д. 126, бывшее здание Отрадовского филиала МОУ «Оборонинская СОШ»		0101000020E610000040BFEFDFBC6644407AFB73D190FB4940
92243	1	14	217	45577	26081	\N	52.143628	р.п.Новопокровка, ул. Школьная, д.14,  здание МБОУ «Новопокровская СОШ»	Россия, Тамбовская область, Мордовский район, поселок Новопокровка	0101000020E6100000FA804067D27044401B65FD6662124A40
92240	1	14	217	45577	75468	\N	52.151620999999999	с.Мельгуны, ул. Техническая, д.11,  здание Калининского филиала МБОУ «Новопокровская СОШ»	Россия, Тамбовская область, Мордовский район, поселок Новопокровка	0101000020E6100000C0401020436D44408331225168134A40
92241	1	14	217	45577	25571	\N	52.143628	р.п.Новопокровка, ул. Революционная, д.3, здание администрации Новопокровского поссовета	Россия, Тамбовская область, Мордовский район, поселок Новопокровка	0101000020E6100000FA804067D27044401B65FD6662124A40
92242	1	14	217	45577	25701	\N	52.143628	"р.п.Новопокровка, ул. Кирпичная, д. 1""а"", административное здание «ООО «Строма-5» "	Россия, Тамбовская область, Мордовский район, поселок Новопокровка	0101000020E6100000FA804067D27044401B65FD6662124A40
92219	1	14	217	51164	\N	\N	51.956624295866398	с.  Николо-Сергиевка, здание  Николо-Сергиевского дома  досуга	Россия, Тамбовская область, Мордовский район, поселок Николо-Сергеевка	0101000020E6100000DCB75A272E594440CB48BDA772FA4940
92232	1	14	217	1250	25814	\N	52.09901	р.п.Мордово, ул. Школьная, д.8, здание №1 МБОУ «Оборонинская СОШ» (ул.Школьная, 8)		0101000020E6100000BFB854A52D6444400DFD135CAC0C4A40
92231	1	14	217	1250	25811	\N	52.09901	р.п.Мордово, ул. Техническая, д.40, здание МБДОУ «Детский сад «Солнышко»	Россия, Тамбовская область, Мордовский район, поселок Мордово	0101000020E6100000BFB854A52D6444400DFD135CAC0C4A40
92233	1	14	217	1250	25538	\N	52.09901	р.п.Мордово, ул. Пятилетка, д.53, административное здание «ТОГУ «Мордовская районная станция по борьбе с болезнями животных»		0101000020E6100000BFB854A52D6444400DFD135CAC0C4A40
92237	1	14	217	1250	25559	\N	52.09901	"р.п.Мордово, ул. Интернациональная, д. 4""б"", здание №2 МБОУ «Оборонинская СОШ» (ул.Интернациональная, 4 «б»)"		0101000020E6100000BFB854A52D6444400DFD135CAC0C4A40
92236	1	14	217	1250	26060	\N	52.09901	"р.п.Мордово, ул. 70 лет Октября, д. 6""а"", бывшее административное здание СХПК «Дружба»"		0101000020E6100000BFB854A52D6444400DFD135CAC0C4A40
92235	1	14	217	1250	26233	\N	52.09901	р.п.Мордово, ул. 2-я Революционная, д.77,  здание администрации Мордовского поссовета		0101000020E6100000BFB854A52D6444400DFD135CAC0C4A40
92234	1	14	217	1250	25643	\N	52.09901	р.п.Мордово, ул.1-я Революционная, д.18, здание МБОУДОД «Районный Дом детского творчества»	Россия, Тамбовская область, Мордовский район, поселок Мордово	0101000020E6100000BFB854A52D6444400DFD135CAC0C4A40
92227	1	14	217	49579	\N	\N	52.340226999999999	с.  Лаврово, Здание администрации Лавровского  сельсовета		0101000020E6100000209C4F1DAB784440AC1BEF8E8C2B4A40
92247	1	14	217	45677	\N	\N	52.242277000000001	д.  Лавровка, Здание  Лавровского СДК		0101000020E6100000ED6305BF0D63444058C9C7EE021F4A40
92246	1	14	217	3585	26139	\N	51.997990000000001	"с.Кужное, ул. Школьная, д.2""а"", здание Кужновского филиала МБОУ «Оборонинская СОШ»"		0101000020E610000052448655BC47444016DEE522BEFF4940
92224	1	14	217	3013	25869	\N	52.024569999999997	с.Карпели, ул. Центральная, д.22, здание администрации Карпельского сельсовета		0101000020E6100000CDAB3AAB056844403A3B191C25034A40
92226	1	14	217	49543	\N	\N	52.020259000000003	"с.  Борисовка, Бывшее здание Борисовского филиала МОУ ""Оборонинская СОШ"""	Россия, Тамбовская область, Мордовский район, поселок Борисовка	0101000020E6100000C899266C3F5F44408F39CFD897024A40
92220	1	14	217	2781	\N	\N	52.045983999999997	с.Большая Даниловка, д. 16, здание администрации Большеданиловского сельсовета		0101000020E610000057B5A4A31C784440D311C0CDE2054A40
92238	1	14	217	45503	\N	\N	52.135894999999998	с.Ахматово, д. 5, здание Ахматовского Дома досуга		0101000020E6100000C15774EB358144404F58E20165114A40
92155	1	14	1811	48438	25495	\N	52.862341999999998	с. Ярок, Советская, 40		0101000020E6100000519FE40E9B0E4440CEFBFF38616E4A40
92176	1	14	1811	48803	26135	\N	52.933923	п. Мичурина, Горького, 6а		0101000020E61000002E1A321EA5444440B9FDF2C98A774A40
92149	1	14	1811	48332	25488	\N	52.825279999999999	с. Устье, Советская, 184		0101000020E6100000E17CEA58A53A44407D0569C6A2694A40
92175	1	14	1811	28510	25637	\N	52.946235999999999	с. Турмасово, Исакова, 123		0101000020E61000001C9947FE604644402026E1421E794A40
92145	1	14	1811	48255	26104	\N	52.780653999999998	с. Терское, Поперечная, 9		0101000020E6100000890AD5CDC5514440ECBE6378EC634A40
92162	1	14	1811	48556	26124	\N	53.006999	с. Терновое, Советская, 2		0101000020E610000057ED9A90D62E4440670DDE57E5804A40
92147	1	14	1811	27279	25367	\N	52.794198999999999	с. Старое Хмелевое, Белаховой, 78	Россия, Тамбовская область, Мичуринский район, поселок Старое Хмелевое	0101000020E6100000A88E554ACF42444009C21550A8654A40
92153	1	14	1811	27575	26119	\N	52.862157000000003	с. Старое Тарбеево, Советская, 3		0101000020E61000002D5A80B6D52844403D821B295B6E4A40
92156	1	14	1811	27670	26121	\N	52.857399999999998	с. Старая Казинка, Рахманинова, 16		0101000020E6100000548CF337A114444092CB7F48BF6D4A40
90928	1	14	1811	46966	25822	\N	52.849162	с. Стаево, Красноармейская, 7		0101000020E610000002124DA088354440C3802557B16C4A40
92158	1	14	1811	48491	26248	\N	52.955253999999996	п. Зеленый Гай, Центральная, 10		0101000020E6100000B98E71C5C5314440C4AF58C3457A4A40
92173	1	14	1811	51215	25894	\N	53.132953560157503	"п. совхоза ""Глазковский"", Центральная, 8"	Россия, Тамбовская область, Мичуринский район, поселок Совхоз Глазковский	0101000020E6100000E52A16BF295A4440AAEFFCA204914A40
92160	1	14	1811	27849	26012	\N	52.973911999999999	с. Ранино, Революционная, 26а		0101000020E610000000FE2955A22044404A97FE25A97C4A40
92138	1	14	1811	48110	26008	\N	52.893304000000001	с. Панское, Луговая, 28		0101000020E610000073BC02D19348444068B114C957724A40
92177	1	14	1811	28650	25385	\N	52.973277000000003	п. Отделение Садострой, Спортивная, 1		0101000020E6100000410B09185D42444079793A57947C4A40
92179	1	14	1811	28697	\N	\N	52.912531999999999	п. Отделение Коммунар	Россия, Тамбовская область, Мичуринский район, поселок Отделение Коммунар	0101000020E61000006284F068E3464440D8463CD9CD744A40
92163	1	14	1811	27987	25631	\N	53.021118000000001	с. Остролучье, Коммунистическая, 41		0101000020E61000005A2F8672A2314440B0AD9FFEB3824A40
92152	1	14	1811	45526	25451	\N	52.824705929982898	с. Новоникольское, Советская, 23	Россия, Тамбовская область, Мичуринский район, поселок Новоникольское	0101000020E6100000B81FF0C000344440516859F78F694A40
92151	1	14	1811	45526	25867	\N	52.825226000000001	с. Новоникольское, Максима Горького, 1а	Россия, Тамбовская область, Мичуринский район, поселок Новоникольское	0101000020E61000001B67D311C03344408AE76C01A1694A40
92148	1	14	1811	27282	26011	\N	52.779820999999998	с. Новое Хмелевое, Замостье, 58		0101000020E6100000EF8CB62A893E4440F4DDAD2CD1634A40
92157	1	14	1811	27716	25623	\N	52.839588999999997	с. Новое Тарбеево, Центральная, 100		0101000020E6100000EFE4D3635B204440698A00A7776B4A40
92161	1	14	1811	27933	25626	\N	52.994805999999997	п. Мичуринский лесоучасток, Лесная, 17		0101000020E61000006C938AC6DA194440AAEE91CD557F4A40
92154	1	14	1811	51249	26251	\N	52.918309999999998	с. Липовка, Липовская, 26	Россия, Тамбовская область, Мичуринский район, поселок Липовка	0101000020E6100000BF0E9C33A22844407DCB9C2E8B754A40
92146	1	14	1811	48281	25749	\N	52.763176999999999	с. Крюковка, Леонова, 4		0101000020E610000083C13577F44944409A07B0C8AF614A40
84017	1	14	1811	46727	25742	\N	52.981600999999998	с. Круглое, Центральная, 57а		0101000020E61000000C59DDEA394D4440465C001AA57D4A40
92170	1	14	1811	48702	26022	\N	53.042427000000004	с. Красивое, Коммунальная, 51		0101000020E61000009EB30584D64D4440D4BB783F6E854A40
92769	1	14	1811	46977	25836	\N	52.995299000000003	с. Кочетовка, ул.Центральная,д.5, Здание филиала МБОУ ТСОШ №1 в с. Кочетовка		0101000020E6100000F6402B30643F4440EA5E27F5657F4A40
92168	1	14	1811	46977	25836	\N	52.995299000000003	с. Кочетовка, Центральная, 20		0101000020E6100000F6402B30643F4440EA5E27F5657F4A40
92167	1	14	1811	46977	25836	\N	52.972553187141997	с. Кочетовка, Центральная, 19	Россия, Тамбовская область, Мичуринский район, поселок Кочетовка	0101000020E610000080289831053F44403750E09D7C7C4A40
92401	1	14	1811	46977	25442	\N	52.995299000000003	с. Кочетовка, Мира, 48		0101000020E6100000F6402B30643F4440EA5E27F5657F4A40
92139	1	14	1811	48134	25831	\N	52.905239000000002	п. Коминтерн, Парковая, 8		0101000020E610000067EF8CB62A4B444029081EDFDE734A40
92709	1	14	1811	48240	75327	\N	52.848756586225598	"п.Калинин, мкр.""Южный"", 2Б"	Россия, Тамбовская область, Мичуринский район, поселок Имени Калинина	0101000020E61000002F8672A25D57444023A0C211A46C4A40
92144	1	14	1811	48240	25862	\N	52.848182999999999	п. имени Калинина, Школьная, 2		0101000020E61000008410902FA1564440F702B342916C4A40
92178	1	14	1811	48836	26030	\N	52.971553	с. Изосимово, Ворошилова, 47		0101000020E61000001E4E603AAD49444054AA44D95B7C4A40
92143	1	14	1811	26945	25778	\N	52.879019	с. Заворонежское, Строителей, 25	Россия, Тамбовская область, Мичуринский район, поселок Заворонежское	0101000020E610000004E5B67D8F46444004C8D0B183704A40
92142	1	14	1811	26945	25377	\N	52.879019	с. Заворонежское, Советская, 136		0101000020E610000004E5B67D8F46444004C8D0B183704A40
92141	1	14	1811	26945	25377	\N	52.879019	с. Заворонежское, Советская, 121		0101000020E610000004E5B67D8F46444004C8D0B183704A40
92140	1	14	1811	26945	25377	\N	52.879019	с. Заворонежское, Советская, 89		0101000020E610000004E5B67D8F46444004C8D0B183704A40
92159	1	14	1811	48515	25386	\N	52.947262000000002	с. Жидиловка, Советская, 13		0101000020E6100000EBE1CB44112A44402D5F97E13F794A40
92166	1	14	1811	28105	25755	\N	53.012189999999997	д. Гостеевка, Заречная, 16а		0101000020E6100000DB6AD619DF4144404BAB21718F814A40
91924	1	14	1811	48413	25994	\N	53.131324999999997	с. Гололобовка, Школьная, 7		0101000020E610000087BF266BD4534440D712F241CF904A40
92172	1	14	1811	28371	25761	\N	53.103762000000003	с. Глазок, Пушкина, 7		0101000020E61000002252D32EA6594440A648BE12488D4A40
92171	1	14	1811	28371	25761	\N	53.103762000000003	с. Глазок, Пушкина, 1		0101000020E61000002252D32EA6594440A648BE12488D4A40
92150	1	14	1811	48357	25369	\N	52.845246000000003	с. Борщевое, Центральная, 110		0101000020E6100000D47D00529B40444094895B05316C4A40
92132	1	14	1811	51184	25616	\N	52.719287999999999	с. Большая Сосновка, Ленина, 37		0101000020E610000098DF6932E3314440DF3312A1115C4A40
92362	1	14	1811	47996	25765	\N	53.115248999999999	с.Александровка, Советская, 1а		0101000020E6100000AD84EE9238454440C7F2AE7AC08E4A40
92165	1	14	1811	48618	25374	\N	52.999158000000001	п. 2-я Пятилетка, Молодежная, 1		0101000020E61000007764AC36FF3B4440B5C4CA68E47F4A40
92174	1	14	6963	48770	75433	\N	52.606386999999998	п. Лесной Воронеж, Лесная, 14а		0101000020E61000007157AF22A3BD44401ADCD6169E4D4A40
92085	1	14	407	3975	\N	\N	52.646608999999998	с.Шиновка, здание филиала МБОУ Уваровщинской СОШ в селе Шиновка		0101000020E61000008DD47B2AA75745404E266E15C4524A40
92096	1	14	407	2172	26346	\N	52.601185999999998	с.Чутановка, ул.Октябрьская, д.67, здание Дома культуры		0101000020E6100000E126A3CA306045401268B0A9F34C4A40
92760	1	14	407	46786	75378	\N	52.595014999999997	д. Федоровка, ул.Центральная,д.2,Здание филиала МБОУ ТСОШ №2 в д. Федоровка		0101000020E6100000F99FFCDD3B3C454091D09673294C4A40
92108	1	14	407	2737	26226	\N	52.645477	пос. Тоновка, ул.Кирова, д.1в, здание Дома культуры		0101000020E6100000B3D1393FC5614540FCA886FD9E524A40
92088	1	14	407	47164	25983	\N	52.686635000000003	пос. Сурки, ул.Заброд, д.28, здание библиотеки	Россия, Тамбовская область, Кирсановский район, поселок Сурки	0101000020E6100000001AA54BFF424540FDA4DAA7E3574A40
92103	1	14	407	46153	26086	\N	52.808942000000002	с.Соколово, ул.Центральная, д.5, здание Соколовского дома культуры		0101000020E6100000155454FD4A374540302E55698B674A40
92092	1	14	407	47220	\N	\N	52.591596000000003	с.Свищевка, здание Свищевского фельдшерско-акушерского пункта	Россия, Тамбовская область, Кирсановский район, поселок Свищевка	0101000020E6100000C8957A16843A4540E338F06AB94B4A40
92105	1	14	407	51182	25601	\N	52.796399000000001	пос.Садовый, ул.Зеленая, д.54, здание филиала МБОУ Уваровщинской СОШ п.Садовый	Россия, Тамбовская область, Кирсановский район, поселок Садовый	0101000020E61000007FF8F9EFC131454097C80567F0654A40
92099	1	14	407	46083	\N	\N	52.483173000000001	с.Рамза,, ул.Свечинка, д.3, здание филиала МБОУ Уваровщинской СОШ в с.Рамза	Россия, Тамбовская область, Кирсановский район, поселок Рамза	0101000020E61000003F1EFAEE56524540B5A7E49CD83D4A40
92109	1	14	407	25548	25995	\N	52.642865999999998	п.Прямица, Строителей, 5		0101000020E61000003524EEB1F46B4540ECDADE6E49524A40
92104	1	14	407	2557	25725	\N	52.818413	пос. Полевой, ул.Набережная, д.3.здание дома культуры	Россия, Тамбовская область, Кирсановский район, поселок Полевой	0101000020E61000001650A8A78F3E454085CFD6C1C1684A40
92101	1	14	407	46086	25458	\N	52.820911000000002	с.Подвигаловка, ул.Советская, д.22,здание Дома культуры		0101000020E6100000522CB7B41A2445409DF6949C13694A40
92017	1	14	407	60589	75379	\N	52.6286211946016	д.Петровка, Юбилейная, 9	Россия, Тамбовская область, Кирсановский район, поселок Петровка	0101000020E6100000043BFE0B04254540174A26A776504A40
92724	1	14	407	46007	25757	\N	52.672570999999998	д.Орловка, Полякова, 1А	Россия, Тамбовская область, Кирсановский район, поселок Орловка	0101000020E610000082AD122C0E354540779E78CE16564A40
92102	1	14	407	51201	25779	\N	52.644555718620602	с.Ольшановка, ул.Садовая, д.2, здание Березовского сельского клуба	Россия, Тамбовская область, Кирсановский район	0101000020E6100000770FD07D3949454065389ECF80524A40
92095	1	14	407	24835	\N	\N	52.705753000000001	с.Овсяновка, здание Екатериновского дома культуры		0101000020E6100000B6D8EDB3CA664540E606431D565A4A40
92086	1	14	407	24434	26212	\N	52.636187999999997	с.Молоканщина, передвижное помещение, установленное напротив домовладения по улице Рабочая, д.6		0101000020E61000003526C45C525D4540C70DBF9B6E514A40
91969	1	14	169	18682	25499	\N	52.872664999999998	с.Гавриловка 2-я, Школьная, 3		0101000020E61000002DCC423BA761454092AE997CB36F4A40
92239	1	14	407	60592	\N	\N	52.7760887958909	с.Михайловка, д. 140,здание Михайловского филиала МБОУ «Новопокровская СОШ»	Россия, Тамбовская область, Кирсановский район, поселок Михайловка	0101000020E6100000FC523F6F2A2A454086E464E256634A40
91997	1	14	407	60592	75389	\N	52.776349043798298	с.Михайловка, Центральная, 51	Россия, Тамбовская область, Кирсановский район, поселок Михайловка	0101000020E6100000D7A6B1BD162A454023A46E675F634A40
92090	1	14	407	51170	25589	\N	52.655890999999997	пос. Мирный, ул.Мирная, д.1 здание клуба закрытого акционерного общества «Ковыльское»	Россия, Тамбовская область, Кирсановский район, поселок Мирный	0101000020E6100000309DD66D502F4540D05E7D3CF4534A40
92098	1	14	407	47379	26348	\N	52.543526	с.Марьинка,, ул.Дорожная, д.67, административное здание Марьинского сельсовета	Россия, Тамбовская область, Кирсановский район, поселок Марьинка	0101000020E61000007EFD101B2C5A45404A438D4292454A40
92093	1	14	407	46733	25711	\N	52.766238999999999	с.Ленинское, ул.Новая, д.15в, здание дома культуры.		0101000020E6100000C3651536036A4540BAF59A1E14624A40
92089	1	14	407	4952	26077	\N	52.640286000000003	пос. Краснослободский, ул.Железнодорожная, д.12, здание Дома культуры		0101000020E6100000A3E8818FC1304540180B43E4F4514A40
92106	1	14	407	25367	26221	\N	52.679963999999998	пос. Компрессорная, ул.Газопроводская, д.27, здание клуба		0101000020E61000003BFE0B04016245408A3A730F09574A40
92087	1	14	407	47132	26342	\N	52.699711999999998	с.Кобяки, ул.Гордеевка, д.36, здание Дома культуры		0101000020E61000005A1135D1E7494540334FAE2990594A40
92122	1	14	407	3087	\N	\N	52.653880000000001	г.Кирсанов, колледж ГА	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92124	1	14	407	3087	25720	\N	52.656779964430903	г.Кирсанов, Школьная, 21	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E610000030833122515C45405C55F65D11544A40
92117	1	14	407	3087	25467	\N	52.658241343807198	г.Кирсанов, Спортивная, 13	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E61000009D2B4A09C15A454073F1B73D41544A40
92113	1	14	407	3087	25593	\N	52.653880000000001	г.Кирсанов, Советская, 25		0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92110	1	14	407	3087	25593	\N	52.643925540098301	г.Кирсанов, Советская, 3	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E6100000B9895A9A5B5D4540A585CB2A6C524A40
92114	1	14	407	3087	25597	\N	52.653880000000001	г.Кирсанов, Рабоче-Крестьянская, 50		0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92111	1	14	407	3087	25597	\N	52.653880000000001	г.Кирсанов, Рабоче-Крестьянская, 35		0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92118	1	14	407	3087	25662	\N	52.653880000000001	г.Кирсанов, Пушкинская, 29		0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92115	1	14	407	3087	25662	\N	52.656832157396899	г.Кирсанов, Пушкинская, 56	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E6100000AB2688BA0F5C4540AF7B2B1213544A40
92120	1	14	407	3087	25473	\N	52.653880000000001	г.Кирсанов, Моршанский тракт, 17	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92123	1	14	407	3087	26002	\N	52.653880000000001	г.Кирсанов, Микрорайон №1, 15		0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92119	1	14	407	3087	25856	\N	52.653880000000001	г.Кирсанов, Интернациональная, 15	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92121	1	14	407	3087	25598	\N	52.653880000000001	г.Кирсанов, Заводской, 1 Б		0101000020E61000006C3F19E3C35C454016C1FF56B2534A40
92112	1	14	407	3087	25768	\N	52.652552126216598	г.Кирсанов, 50 лет Победы, 23	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E6100000176536C8245D45403E78EDD286534A40
92082	1	14	407	3087	25768	\N	52.652552126216598	г.Кирсанов, 50 лет Победы, 27	Россия, Тамбовская область, Кирсановский район, Кирсанов	0101000020E6100000A699EE75525D45403E78EDD286534A40
92084	1	14	407	24327	\N	\N	52.620057000000003	с.Калаис, административное здание Калаисского сельсовета	Россия, Тамбовская область, Кирсановский район, поселок Калаис	0101000020E610000074417DCB9C504540F4531C075E4F4A40
92083	1	14	407	24327	26338	\N	52.620057000000003	с.Калаис, ул.Подвячка, д.1а, здание филиала МБОУ Уваровщинской СОШ в с.Калаис		0101000020E610000074417DCB9C504540F4531C075E4F4A40
92080	1	14	407	24129	26207	\N	52.562246999999999	с.Иноковка 2, ул.Верхняя Луговка, д.14а здание Дома культуры		0101000020E6100000C214E5D2F83F454016A3AEB5F7474A40
92079	1	14	407	24123	25698	\N	52.542392	с.Иноковка 1, ул.Площадь д.1б, здание Дома культуры		0101000020E6100000D8B628B34148454057CEDE196D454A40
92077	1	14	407	24031	\N	\N	52.676594999999999	"с.Голынщина, здание ""Поселенческого центра досуга"" Голынщинского сельсове, 79 А"		0101000020E610000023111AC1C65B45408DD13AAA9A564A40
92078	1	14	407	24031	25971	\N	52.676594999999999	с.Голынщина, Приовражная, 21		0101000020E610000023111AC1C65B45408DD13AAA9A564A40
92081	1	14	407	3936	26339	\N	52.595283999999999	с.Вячка, ул.Городок,д.67 здание филиала МБОУ Уваровщинской СОШ в с.Вячка		0101000020E610000012BC218D0A4A454081EA1F44324C4A40
92107	1	14	407	2674	\N	\N	52.653562999999998	с.Большая Уваровщина, д.1а,здание МОУ Уваровщинской СОШ		0101000020E61000006ADC9BDF306145401570CFF3A7534A40
92069	1	14	512	23607	25826	\N	52.273311999999997	Тамбовская область, Инжавинский район, Балыклейский сельсовет, п. Юбилейный, Центральная, 35		0101000020E6100000C6353E93FD5F45405BCD3AE3FB224A40
92062	1	14	512	23271	26189	\N	52.168967000000002	Тамбовская область, Инжавинский район, Чернавский сельсовет, с. Чернавка, Чапаевская, 22	Россия, Тамбовская область, Инжавинский район, поселок Чернавка	0101000020E6100000093543AA28384540378DEDB5A0154A40
92059	1	14	512	23177	26319	\N	52.231406	Тамбовская область, Инжавинский район, Красивский сельсовет, с. Хорошавка, Набережная, 269		0101000020E6100000A0353FFED23A4540910C39B69E1D4A40
92065	1	14	512	23449	26322	\N	52.179659000000001	Тамбовская область, Инжавинский район, Марьевский сельсовет, п. Филатовский, Молодежная, 4		0101000020E6100000AC71361D014A45404EB7EC10FF164A40
92053	1	14	512	22896	26184	\N	52.338262	Тамбовская область, Инжавинский район, Калугинский сельсовет, д. Соболевка, Соболевка, д. 34, кв.2		0101000020E6100000459E245D3323454062BD512B4C2B4A40
92507	1	14	512	22453	25388	\N	52.369142186258799	Семеновка село, Центральная, 12	Россия, Тамбовская область, Инжавинский район, поселок Семеновка	0101000020E61000008F1A13622E3F45403ECA880B402F4A40
92043	1	14	512	22453	25388	\N	52.369835000000002	Тамбовская область, Инжавинский район, Никитинский сельсовет, д. Семеновка, Центральная, 45		0101000020E610000063096B63EC3E454045F5D6C0562F4A40
92063	1	14	512	23318	26041	\N	52.105786000000002	Тамбовская область, Инжавинский район, Марьевский сельсовет, с. Сатино, Центральная, 5		0101000020E6100000060E68E90A4E4540F52F49658A0D4A40
92058	1	14	512	23100	25820	\N	52.272998000000001	Тамбовская область, Инжавинский район, Красивский сельсовет, п. Плодопитомник, Садовая, 9		0101000020E610000044300E2E1D4B4540CCEF3499F1224A40
92046	1	14	512	22573	25815	\N	52.43047	Тамбовская область, Инжавинский район, Паревский сельсовет, с. Паревка, Центральная, 41		0101000020E6100000BF982D59154945405EF415A419374A40
92074	1	14	512	23838	26332	\N	52.401825000000002	Тамбовская область, Инжавинский район, Михайловский сельсовет, с. Павловка, Центральная, 66		0101000020E6100000EE9579ABAE6545408CDB68006F334A40
92045	1	14	512	22517	25670	\N	52.449333000000003	Тамбовская область, Инжавинский район, Паревский сельсовет, с. Ольховка, Краснофлотская, 23		0101000020E61000006AF7AB00DF434540BD0166BE83394A40
92725	1	14	512	46030	75419	\N	52.167647000000002	п.Новая Жизнь, Молодежная, 22		0101000020E610000062D7F6764B624540E222F77475154A40
92067	1	14	512	23552	26152	\N	52.187224000000001	Тамбовская область, Инжавинский район, Николинский сельсовет, с. Николино, Школьная, 1		0101000020E6100000D9EA724A406245405E83BEF4F6174A40
92044	1	14	512	22467	26044	\N	52.430090999999997	Тамбовская область, Инжавинский район, Никитинский сельсовет, с. Никитино, Молодежная, 2	Россия, Тамбовская область, Инжавинский район, поселок Никитино	0101000020E61000002786E464E2384540E7A6CD380D374A40
92075	1	14	512	23875	25528	\N	52.358280999999998	Тамбовская область, Инжавинский район, Михайловский сельсовет, с. Михайловка, Петровка, 39		0101000020E6100000E95F92CA146945409BE3DC26DC2D4A40
92054	1	14	512	22904	25819	\N	52.363852000000001	Тамбовская область, Инжавинский район, Инжавинский поссовет, с. Лопатино, Богачевская, 7		0101000020E6100000E17A14AE47334540C74ACCB3922E4A40
92064	1	14	512	23376	25686	\N	52.114834999999999	Тамбовская область, Инжавинский район, Марьевский сельсовет, с. Ломовка, Центральная, 46		0101000020E6100000496760E4655B4540D4B7CCE9B20E4A40
92076	1	14	512	23932	25569	\N	52.335335000000001	Тамбовская область, Инжавинский район, Михайловский сельсовет, с. Леонтьевка, Калиновка, 16		0101000020E6100000594E42E90B6F4540221ADD41EC2A4A40
92051	1	14	512	22778	25391	\N	52.373387000000001	Тамбовская область, Инжавинский район, Караваинский сельсовет, д. Лебедевка, Якова Синева, 56		0101000020E610000039B69E211C1D454033E02C25CB2F4A40
92049	1	14	512	22732	25817	\N	52.507561000000003	Тамбовская область, Инжавинский район, Землянский сельсовет, д. Курдюки, Курдюковская, 29		0101000020E61000008DD5E6FF551F4540CFDC43C2F7404A40
92066	1	14	512	23455	9642	\N	52.231666763344997	Тамбовская область, Инжавинский район, Марьевский сельсовет, с. Кулевча, Кирова, 95		0101000020E610000085B2F0F5B5524540FE47A643A71D4A40
92057	1	14	512	23038	25684	\N	52.258094999999997	Тамбовская область, Инжавинский район, Красивский сельсовет, с. Красивка, Советская, 18	Россия, Тамбовская область, Инжавинский район, поселок Красивка	0101000020E6100000BF0AF0DDE63F45406C21C84109214A40
92055	1	14	512	22992	26065	\N	52.341030000000003	Тамбовская область, Инжавинский район, Инжавинский поссовет, д. Кишкино, Поселковая, 6а		0101000020E6100000A79201A08A3145403A7AFCDEA62B4A40
92061	1	14	512	23262	25564	\N	52.240544999999997	Тамбовская область, Инжавинский район, Караульский сельсовет, с. Караул, Садовая, 56		0101000020E6100000C53C2B69C52D4540B01BB62DCA1E4A40
92056	1	14	512	23004	25677	\N	52.284916000000003	Тамбовская область, Инжавинский район, Инжавинский поссовет, д. Карандеевка, Карандеевская, 92		0101000020E6100000FE2AC0779B354540B70DA32078244A40
92072	1	14	512	23739	26195	\N	52.364435	Тамбовская область, Инжавинский район, Карай- Салтыковский сельсовет, с. Карай-Салтыково, пер. Школьный, 2	Россия, Тамбовская область, Инжавинский район, поселок Карай-Салтыково	0101000020E61000007EC344831450454046425BCEA52E4A40
92071	1	14	512	23739	25689	\N	52.364435	Тамбовская область, Инжавинский район, Карай- Салтыковский сельсовет, с. Карай-Салтыково, Высотная, 4	Россия, Тамбовская область, Инжавинский район, поселок Карай-Салтыково	0101000020E61000007EC344831450454046425BCEA52E4A40
92073	1	14	512	23825	26327	\N	52.398836000000003	Тамбовская область, Инжавинский район, Карай- Салтыковский сельсовет, с. Карай-Пущино, Центральная, 97а		0101000020E61000006FF085C954514540D63BDC0E0D334A40
92050	1	14	512	22744	25950	\N	52.422403000000003	Тамбовская область, Инжавинский район, Караваинский сельсовет, с. Караваино, Школьная, 8	Россия, Тамбовская область, Инжавинский район, поселок Караваино	0101000020E6100000A182C30B221A4540BC5D2F4D11364A40
92052	1	14	512	22827	26309	\N	52.406934999999997	Тамбовская область, Инжавинский район, Калугинский сельсовет, с. Калугино, Школьная, 15		0101000020E6100000B37BF2B050254540834C327216344A40
92041	1	14	512	3143	25669	\N	52.326985999999998	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Техническая, 4	Россия, Тамбовская область, Инжавинский район, поселок Инжавино	0101000020E61000007286E28E373D4540FB1F60ADDA294A40
90252	1	13	\N	54800	39629	\N	55.122199999999999	г.Сафоново, Куйбышева, 2		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
92038	1	14	512	3143	25414	\N	52.326985999999998	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Советская, 15	Россия, Тамбовская область, Инжавинский район, поселок Инжавино	0101000020E61000007286E28E373D4540FB1F60ADDA294A40
92037	1	14	512	3143	25414	\N	52.326985999999998	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Советская, 19		0101000020E61000007286E28E373D4540FB1F60ADDA294A40
92036	1	14	512	3143	25414	\N	52.326985999999998	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Советская, 56	Россия, Тамбовская область, Инжавинский район, поселок Инжавино	0101000020E61000007286E28E373D4540FB1F60ADDA294A40
92035	1	14	512	3143	25806	\N	52.326985999999998	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Рылеева, 6	Россия, Тамбовская область, Инжавинский район, поселок Инжавино	0101000020E61000007286E28E373D4540FB1F60ADDA294A40
92039	1	14	512	3143	25548	\N	52.326985999999998	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Лунина, 2		0101000020E61000007286E28E373D4540FB1F60ADDA294A40
92042	1	14	512	3143	25813	\N	52.330905176813197	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Карла Маркса, 4	Россия, Тамбовская область, Инжавинский район, поселок Инжавино	0101000020E6100000280F0BB5A63F45409C8A54185B2A4A40
92040	1	14	512	3143	25553	\N	52.326985999999998	Тамбовская область, Инжавинский район, Инжавинский поссовет, р.п. Инжавино, Белинского, 21		0101000020E61000007286E28E373D4540FB1F60ADDA294A40
92048	1	14	512	22656	26059	\N	52.509977999999997	Тамбовская область, Инжавинский район, Землянский сельсовет, д. Ивановка, Молодежная, 1		0101000020E6100000EBC37AA3562C4540F9D687F546414A40
92047	1	14	512	22653	26061	\N	52.463107000000001	Тамбовская область, Инжавинский район, Землянский сельсовет, п. Землянский, Школьная, 15	Россия, Тамбовская область, Инжавинский район, поселок Землянский	0101000020E61000001975ADBD4F3145403BC61517473B4A40
92068	1	14	512	23566	25432	\N	52.262250999999999	Тамбовская область, Инжавинский район, Балыклейский сельсовет, с. Екатеринополье, Школьная, 31		0101000020E610000066F7E461A1684540F12BD67091214A40
92060	1	14	512	23180	25957	\N	52.288854999999998	Тамбовская область, Инжавинский район, Караульский сельсовет, д. Грушевка, Центральная, 25		0101000020E610000021E692AAED2645409E245D33F9244A40
92070	1	14	512	23664	25904	\N	52.321250999999997	Тамбовская область, Инжавинский район, Балыклейский сельсовет, с. Балыклей, Центральная, 4		0101000020E61000004CA8E0F0824A45405567B5C01E294A40
92467	1	14	512	45484	25453	\N	52.410341000000003	д.Алексеевка, Школьная, 8		0101000020E6100000404B57B08D3C45409E9ACB0D86344A40
92266	1	14	512	45484	25453	\N	52.410131216985803	д.Алексеевка, Школьная, 133	Россия, Тамбовская область, Инжавинский район, поселок Алексеевка	0101000020E6100000B14F00C5C83C4540B309302C7F344A40
92003	1	14	512	45484	75032	\N	52.409658613304899	с.Алексеевка, Советская, 10	Россия, Тамбовская область, Инжавинский район, поселок Алексеевка	0101000020E61000001C075E2D773C45408BC1C3B46F344A40
90728	1	14	1673	45946	25951	\N	52.511288	с.Сухотинка, Суренка		0101000020E61000005470784144CC44402B6B9BE271414A40
92031	1	14	1673	45946	25611	\N	52.511288	с.Сухотинка, Молодежная, 14		0101000020E61000005470784144CC44402B6B9BE271414A40
92026	1	14	1673	45832	25426	\N	52.414960999999998	пос.Кузьминский, Школьная, 29		0101000020E61000004582A966D69E4440C70E2A711D354A40
92028	1	14	1673	21736	25427	\N	52.407494999999997	с.Покрово-Марфино, Дзержинского, 1		0101000020E610000023A30392B08344404A24D1CB28344A40
92023	1	14	1673	45784	79322	\N	52.448813999999999	"пос.Первомайское, Школьная, 1 ""А"""	Россия, Тамбовская область, Знаменский район, поселок Первомайское	0101000020E6100000DF701FB935BD444054FEB5BC72394A40
92029	1	14	1673	21823	26069	\N	52.359622999999999	с.Новознаменка, Центральная, 128		0101000020E610000037C478CDAB8C4440D8F15F20082E4A40
92027	1	14	1673	45850	25561	\N	52.464018000000003	д.Михайловка, Центральная, 18		0101000020E6100000CA8AE1EA00AA4440AF601BF1643B4A40
92025	1	14	1673	21621	26108	\N	52.268402000000002	с.Кариан, Московская, 30	Россия, Тамбовская область, Знаменский район, поселок Кариан	0101000020E6100000CF49EF1B5F9D44402B172AFF5A224A40
92020	1	14	1673	45727	25641	\N	52.330195000000003	с.Измайловка, Победы, 15	Россия, Тамбовская область, Знаменский район, поселок Измайловка	0101000020E61000008A9125732CB34440C0266BD4432A4A40
92034	1	14	1673	51203	26175	\N	52.419322000000001	"р.п.Знаменка, Гагарина, 8 ""А"""	Россия, Тамбовская область, Знаменский район, поселок Знаменка	0101000020E6100000BF1072DEFFB74440253FE257AC354A40
92024	1	14	1673	51176	25555	\N	52.374325850650798	с.Дуплято-Маслово, Гагарина, 29	Россия, Тамбовская область, Знаменский район, поселок Дуплятово-Маслово	0101000020E610000038BC2022359D4440710514EAE92F4A40
92022	1	14	1673	45771	25934	\N	52.521788000000001	"д.Даниловка, Школьная, 84 ""А"""		0101000020E6100000B936548CF3B14440FEB8FDF2C9424A40
92021	1	14	1673	45753	25543	\N	52.454293999999997	с.Воронцовка, Сергеева, 24		0101000020E6100000DEAAEB504DB544406F62484E263A4A40
92169	1	14	1673	46833	75374	\N	52.280949	д. Александровка, Зеленая, 49		0101000020E6100000E54350357AAD4440056C0723F6234A40
90501	1	14	1070	11384	26218	\N	51.745882999999999	с.Шпикулово, Школьная, 12		0101000020E610000094BF7B478DEF444039D2191879DF4940
92009	1	14	1070	20807	25893	\N	51.925592000000002	с.Чикаревка, Центральная, 33		0101000020E61000005E9CF86A47CB444039B874CC79F64940
91999	1	14	1070	20285	25529	\N	51.850344	д.Цветовка, Центральная, 7		0101000020E610000019709692E5A64440C72C7B12D8EC4940
92006	1	14	1070	20647	25939	\N	51.941972999999997	с.Туголуково, Фиолетова, 21	Россия, Тамбовская область, Жердевский район, поселок Туголуково	0101000020E6100000EB538EC9E2D44440855B3E9292F84940
92004	1	14	1070	45433	26217	\N	51.791423000000002	с.Сукмановка, Международная, 1		0101000020E61000003C4B901150C94440AF264F594DE54940
92016	1	14	1070	51206	25841	\N	51.864462000000003	пос.Степной, Трудовая, 96	Россия, Тамбовская область, Жердевский район, поселок Степной	0101000020E6100000205D6C5A29E444404051D9B0A6EE4940
92223	1	14	1070	51206	75028	\N	51.864090069652903	"пос.Степной, ул. Школьная д.12 ""а"", здание Степновского филиала МБОУ «Новопокровская СОШ»"	Россия, Тамбовская область, Жердевский район, поселок Степной	0101000020E6100000F8E0B54B1BE444407B6649809AEE4940
92000	1	14	1070	46797	26158	\N	51.832459999999998	пос.Садовый, Вишневая, 7	Россия, Тамбовская область, Жердевский район, поселок Садовый	0101000020E61000000E828E56B5B04440349D9D0C8EEA4940
91996	1	14	1070	20057	25656	\N	51.916316000000002	пос.Рымарево, Трудовая, 14а		0101000020E6100000AB93331477A844409966BAD749F54940
92001	1	14	1070	9479	25901	\N	51.792064000000003	с.Пичаево, Центральная, 19		0101000020E61000003140A209149D4440632B685A62E54940
92439	1	14	1070	9479	75020	\N	51.791848216865603	с.Пичаево, Ленинская, 1	Россия, Тамбовская область, Жердевский район, поселок Пичаево	0101000020E6100000E1D1C6116B9D444096B377465BE54940
92002	1	14	1070	51226	26036	\N	51.752617999999998	с.Питим, Кировская, 6	Россия, Тамбовская область, Жердевский район, поселок Питим	0101000020E610000090F98040679C4440C23060C955E04940
92007	1	14	1070	51234	26126	\N	51.922669999999997	с.Петровское, Кропоткина, 60	Россия, Тамбовская область, Жердевский район, поселок Петровское	0101000020E6100000A2F14410E7DF44400A80F10C1AF64940
92794	1	14	1070	45540	75395	\N	52.033171651747601	с.Павлодар, Центральная, 106з	Россия, Тамбовская область, Жердевский район, поселок Павлодар	0101000020E61000003E096CCEC1CD44404B92E7FA3E044A40
92014	1	14	1070	21071	25648	\N	51.8723504740666	пос.Новый Свет 1-й, Луговая, 34	Россия, Тамбовская область, Жердевский район, поселок Новый Свет 1-й	0101000020E6100000A6D3BA0D6AEB44403255302AA9EF4940
91998	1	14	1070	20181	26047	\N	51.789825	с.Новорусаново, Центральная, 63		0101000020E6100000BB46CB811EB84440174850FC18E54940
92013	1	14	1070	45585	26038	\N	51.882272	с.Максим Горький, Мира, 238		0101000020E6100000CEAACFD556F244409816F549EEF04940
92008	1	14	1070	45495	25798	\N	51.853794000000001	с.Искра, Зеленая, 27	Россия, Тамбовская область, Жердевский район, поселок Искра	0101000020E6100000721AA20A7FDE4440B1C22D1F49ED4940
91993	1	14	1070	10689	25572	\N	51.830534999999998	г.Жердевка, Энгельса, 43		0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
90486	1	14	1070	10689	25787	\N	51.835384582752802	г.Жердевка, Чкалова, 19а	Россия, Тамбовская область, Жердевский район, Жердевка	0101000020E61000009BC8CC052EBB4440D4484BE5EDEA4940
91988	1	14	1070	10689	26027	\N	51.830534999999998	г.Жердевка, Тухачевского, 5	Россия, Тамбовская область, Жердевский район, Жердевка	0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
91990	1	14	1070	10689	26266	\N	51.830534999999998	г.Жердевка, Серова, 1		0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
91986	1	14	1070	10689	25517	\N	51.830534999999998	г.Жердевка, Семашко, 7а		0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
91984	1	14	1070	10689	25638	\N	51.843189774946403	г.Жердевка, Первомайская, 124	Россия, Тамбовская область, Жердевский район, Жердевка	0101000020E61000003430F2B226BC4440392861A6EDEB4940
91985	1	14	1070	10689	25897	\N	51.830534999999998	г.Жердевка, Нагорная		0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
91987	1	14	1070	10689	25384	\N	51.830534999999998	г.Жердевка, Кировская, 44	Россия, Тамбовская область, Жердевский район, Жердевка	0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
91992	1	14	1070	10689	25392	\N	51.830534999999998	г.Жердевка, Интернациональная, 3	Россия, Тамбовская область, Жердевский район, Жердевка	0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
91991	1	14	1070	10689	25392	\N	51.830534999999998	г.Жердевка, Интернациональная, 8		0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
91989	1	14	1070	10689	26265	\N	51.830534999999998	г.Жердевка, Заводская, 28		0101000020E6100000A6D0798D5DBC444078978BF84EEA4940
92015	1	14	1070	21123	26043	\N	51.825603000000001	пос.Демьян Бедный, Мира, 25		0101000020E61000003563D17476EA4440603DEE5BADE94940
92018	1	14	1070	51230	26090	\N	51.674393999999999	с.Григорьевка, Северный микрарайон, 10	Россия, Тамбовская область, Жердевский район, поселок Григорьевка	0101000020E61000009D0DF96706FB44402F4FE78A52D64940
92010	1	14	1070	45538	26285	\N	51.911921	с.Вязовое, Жукова, 57		0101000020E610000075AE282504C344408FC4CBD3B9F44940
91994	1	14	1070	49523	25782	\N	51.87079	с.Бурнак, Свободы, 27а		0101000020E61000000457790261BB444088D7F50B76EF4940
91995	1	14	1070	49523	25394	\N	51.87079	с.Бурнак, Колхозная, 21в	Россия, Тамбовская область, Жердевский район, поселок Бурнак	0101000020E61000000457790261BB444088D7F50B76EF4940
91972	1	14	1070	49219	25502	\N	51.681798999999998	с.Булгаково, Торговая , 2		0101000020E6100000276A696E85F0444006B98B3045D74940
91973	1	14	169	60484	\N	\N	52.966020999999998	д.Синявка-1, Здание ФАП, 1а	Россия, Тамбовская область, Гавриловский район, поселок 1-я	0101000020E6100000554CA59F704A4540E61F7D93A67B4A40
91976	1	14	169	525	25376	\N	52.790185000000001	с.Чуповка, Заречная, 16		0101000020E61000004700378B17514540176536C824654A40
91983	1	14	169	51236	26133	\N	53.037365000000001	д.Старая Рожковка, Центральная, 2	Россия, Тамбовская область, Гавриловский район, поселок Станция Рожковка	0101000020E610000017B7D100DE584540ED815660C8844A40
91950	1	14	169	51210	25872	\N	52.931182	с.Пересыпкиноно 2-е, Поповка, 8	Россия, Тамбовская область, Гавриловский район, поселок Пересыпкино 2-е	0101000020E6100000EA3D95D39E6C4540DB4FC6F830774A40
91908	1	14	169	45428	25409	\N	52.908774000000001	с.Пересыпкино 1-е, Гагарина, 12	Россия, Тамбовская область, Гавриловский район, поселок Пересыпкино 1-е	0101000020E61000001409A69A5975454041BAD8B452744A40
91979	1	14	169	575	25381	\N	53.030600999999997	с.Осино-Гай, Центральная, 3		0101000020E610000087A8C29FE1334540C91CCBBBEA834A40
92802	1	14	169	46637	\N	\N	52.842286999999999	с.Ольшанка, Ольшанская, 59	Россия, Тамбовская область, Гавриловский район, поселок Ольшанка	0101000020E610000042B5C189E8514540486C770FD06B4A40
91977	1	14	169	46637	75403	\N	52.834671999999998	с.Ольшанка, Новая, 240а	Россия, Тамбовская область, Гавриловский район, поселок Ольшанка	0101000020E6100000B18BA2073E52454086713788D66A4A40
91978	1	14	169	19114	25509	\N	52.82676	с.Кондаурово, Бурчановка, 80г		0101000020E6100000AA0B7899614345400BD28C45D3694A40
91975	1	14	169	51166	25397	\N	52.919770385910098	с.Гусевка, Прудная, 4	Россия, Тамбовская область, Гавриловский район, поселок Гусевка	0101000020E6100000399B8E006E3E4540C4EBFA05BB754A40
91848	1	14	169	12809	26298	\N	52.847715000000001	с.Гавриловка 1-я, Гагарина, 28	Россия, Тамбовская область, Гавриловский район, поселок Гавриловка 1-я	0101000020E610000081ECF5EE8F67454011AAD4EC816C4A40
91981	1	14	169	49333	26130	\N	53.015928000000002	с.Анненка, ул.Новая, д.32, здание Анненского филиала МБОУ 2-Гавриловской СОШ	Россия, Тамбовская область, Гавриловский район, поселок Анненка	0101000020E610000062F71DC3634745409C8BBFED09824A40
91960	1	14	230	3658	26268	\N	53.068849999999998	д.Шача Молоканская, Школьная , 3		0101000020E6100000FB912232AC184540302AA913D0884A40
91952	1	14	230	48917	25484	\N	52.926025000000003	п.Строительный, Молодежная, 2		0101000020E6100000766F456282084540A323B9FC87764A40
91951	1	14	230	51223	26019	\N	52.947732492391701	"""п.1-е отделение с-за """"Бондарский"""", Совхозная, 33"	Россия, Тамбовская область, Бондарский район, поселок Совхоз Бондарский	0101000020E61000005EDBDB2DC9054540B4AF3C484F794A40
91968	1	14	230	49171	26249	\N	52.900691999999999	с.Прибытки, Центральная, 73		0101000020E6100000C9ACDEE17608454069E21DE049734A40
91965	1	14	230	18416	26271	\N	52.973570000000002	с.Пахотный Угол, Октябрьская, 2		0101000020E6100000C501F4FBFEF34440F12E17F19D7C4A40
92773	1	14	230	47049	25425	\N	52.911571836929298	с. Павловка,  ул.Молодежная,д.35, Здание филиала МБОУ ТСОШ №1 в с. Павловка	Россия, Тамбовская область, Бондарский район, поселок Павловка	0101000020E61000004D1421753BF7444083F92B64AE744A40
92229	1	14	230	47049	75397	\N	52.911883156541101	с.Павловка, ул. Ильменовка, д.42, здание Павловского филиала МБОУ «Новопокровская СОШ»	Россия, Тамбовская область, Бондарский район, поселок Павловка	0101000020E61000006FF085C954F74440A2630795B8744A40
91964	1	14	230	49109	25693	\N	52.857976000000001	п.Озерный, Совхозная, 2		0101000020E610000011E15F048D1545405F605628D26D4A40
91961	1	14	230	49059	26242	\N	52.999634999999998	с.Митрополье, Школьная, 17		0101000020E61000001D925A2899064540EE77280AF47F4A40
91959	1	14	230	18120	25619	\N	53.056258	с.Малое Гагарино, Молодежная, 8		0101000020E6100000D61D8B6D52054540B6114F7633874A40
91958	1	14	230	60620	75472	\N	52.964296058287204	с.Максимовка, Максимовка, 40а	Россия, Тамбовская область, Бондарский район, поселок Максимовка	0101000020E61000003DB665C059184540F1D4230D6E7B4A40
91957	1	14	230	48997	26239	\N	52.893728000000003	с.Куровщина, Центральная, 40		0101000020E6100000FFCA4A93523645407FC2D9AD65724A40
91955	1	14	230	17966	25487	\N	53.048386999999998	с.Кривополянье, Советская, 51		0101000020E6100000810A47904AF344409946938B31864A40
91962	1	14	230	49086	75424	\N	53.027281000000002	с.Коровино, Центральная, 99		0101000020E61000004C16F71F990C4540AE669DF17D834A40
91954	1	14	230	17871	25485	\N	52.884327999999996	с.Керша, Школьная, 2		0101000020E6100000205F420587F14440F277EFA831714A40
91953	1	14	230	48925	26067	\N	52.952790999999998	с.Граждановка, Центральная, 8		0101000020E610000012F5824F732445402976340EF5794A40
91956	1	14	230	48979	25617	\N	53.018571999999999	с.Городище, Набережная, 72		0101000020E610000055BFD2F9F0F44440874F3A9160824A40
92509	1	14	230	46360	26007	\N	52.857067999999998	Волхонщино деревня, Советская, 25	Россия, Тамбовская область, Бондарский район, поселок Волхонщино	0101000020E6100000EBE40CC51D3545405C397B67B46D4A40
91963	1	14	230	18351	25625	\N	52.866957999999997	с.Верхнее Нащекино, Кольцевая, 14		0101000020E610000033A83638110D4540B680D07AF86E4A40
91967	1	14	230	18574	26246	\N	52.917690999999998	с.Вердеревщино, Центральная, 146	Россия, Тамбовская область, Бондарский район, поселок Вердеревщино	0101000020E6100000D11F9A79720B4540B16A10E676754A40
91949	1	14	230	895	26372	\N	52.953051000000002	Тамбовская область, Бондарский район, Бондарский сельсовет, с. Бондари, Советская , 4	Россия, Тамбовская область, Бондарский район, поселок Бондари	0101000020E6100000DC8310902F074540C6353E93FD794A40
91948	1	14	230	895	25614	\N	52.953051000000002	с.Бондари, Октябрьская, 9		0101000020E6100000DC8310902F074540C6353E93FD794A40
92834	1	14	230	40435	25639	\N	52.987065000000001	"""пос.с-за «Софьинский», 1-й участок, ул.Совхозная,д.29,административное здание СПК """"Софьинский"""""""		0101000020E610000011E15F048DE944405C035B25587E4A40
90553	1	13	\N	54805	39781	\N	55.054836000000002	г.Ярцево, пр-кт Металлургов, д.25, средняя общеобраз.школа №7		0101000020E61000000D7217618A5840405D52B5DD04874B40
90559	1	13	\N	54805	39780	\N	55.054836000000002	"г.Ярцево, ул.Энтузиастов, д.33, Центр досуга ""Современник"""		0101000020E61000000D7217618A5840405D52B5DD04874B40
90564	1	13	\N	54805	40017	\N	55.054836000000002	г.Ярцево, ул.Энгельса, д.1, основная общеобраз.школа №5		0101000020E61000000D7217618A5840405D52B5DD04874B40
90563	1	13	\N	54805	40000	\N	55.054836000000002	г.Ярцево, ул.Шоссейная, д.21, здание ФГУ ДЭП-3		0101000020E61000000D7217618A5840405D52B5DD04874B40
90567	1	13	\N	54805	39782	\N	55.054836000000002	"г.Ярцево, Школьный переулок, д.8, ""Центр детского творчества"""		0101000020E61000000D7217618A5840405D52B5DD04874B40
90566	1	13	\N	54805	39601	\N	55.054836000000002	г.Ярцево, ул.Школьная, д.11, средняя общеобраз.школа №1		0101000020E61000000D7217618A5840405D52B5DD04874B40
90571	1	13	\N	54805	40159	\N	55.054836000000002	"г.Ярцево, ул.Центральная, д.14, Фил.МУК ""ЯРЦКИ""-клуб п.Пологи"		0101000020E61000000D7217618A5840405D52B5DD04874B40
90555	1	13	\N	54805	40217	\N	55.054836000000002	г.Ярцево, ул.Тургенева, д.33		0101000020E61000000D7217618A5840405D52B5DD04874B40
90551	1	13	\N	54805	39716	\N	55.0705012588827	г.Ярцево, ул.Старозавопье, д.15, средняя общеобраз.школа №10	Россия, Смоленская область, Ярцевский район, Ярцево	0101000020E6100000CA1AF5108D584040EBAA402D06894B40
90547	1	13	\N	54805	39593	\N	55.054836000000002	г.Ярцево, ул.Советская, д.26а,Центр по библиот.раб.с детьми		0101000020E61000000D7217618A5840405D52B5DD04874B40
90543	1	13	\N	54805	39675	\N	55.054836000000002	г.Ярцево, ул.Пугачева, д.3, Ярцевск.индустриальн. техникум		0101000020E61000000D7217618A5840405D52B5DD04874B40
90561	1	13	\N	54805	39597	\N	55.054836000000002	г.Ярцево, ул.Победы, д.1, здание МДОУ детский сад №10		0101000020E61000000D7217618A5840405D52B5DD04874B40
90558	1	13	\N	54805	39777	\N	55.054836000000002	"г.Ярцево, ул.Ольховская, д.1а, Центр досуга ""Современник"""		0101000020E61000000D7217618A5840405D52B5DD04874B40
90568	1	13	\N	54805	39603	\N	55.060206158395303	г.Ярцево, ул.Октябрьская, д.8, НОУ Ярцевская АШ ДОСААФ России	Россия, Смоленская область, Ярцевский район, Ярцево	0101000020E61000006E35EB8CEF574040F18288D4B4874B40
90552	1	13	\N	54805	39595	\N	55.054836000000002	г.Ярцево, пр-кт Металлургов, д.19а, средняя общеобраз.школа №8		0101000020E61000000D7217618A5840405D52B5DD04874B40
90562	1	13	\N	54805	40001	\N	55.054836000000002	г.Ярцево, ул.Макаренко, д.3, школа-интернат для детей-сирот		0101000020E61000000D7217618A5840405D52B5DD04874B40
90550	1	13	\N	54805	39772	\N	55.054836000000002	"г.Ярцево, ул.Лесная, д.1а, здание ООО ""Раздолье"""		0101000020E61000000D7217618A5840405D52B5DD04874B40
90570	1	13	\N	54805	39999	\N	55.054836000000002	"г.Ярцево, ул.Кузнецова, д.56, здание ООО ""СМИТ-Ярцево"""		0101000020E61000000D7217618A5840405D52B5DD04874B40
90545	1	13	\N	54805	39870	\N	55.054836000000002	г.Ярцево, ул.Интернациональная, д.5, средняя обшеобраз.школа №4		0101000020E61000000D7217618A5840405D52B5DD04874B40
90554	1	13	\N	54805	39951	\N	55.054836000000002	г.Ярцево, ул.Дачная, д.20, Ярцевский геронтологич. центр		0101000020E61000000D7217618A5840405D52B5DD04874B40
90549	1	13	\N	54805	39678	\N	55.054836000000002	г.Ярцево, ул.Гагарина, д.52, средняя общеобраз.школа №2		0101000020E61000000D7217618A5840405D52B5DD04874B40
90546	1	13	\N	54805	39678	\N	55.063482160719602	"г.Ярцево, ул.Гагарина, д.5, здание МУК ""ЯРЦКИ"""	Россия, Смоленская область, Ярцевский район, Ярцево	0101000020E6100000E04735ECF75840403DF19C2D20884B40
90557	1	13	\N	54805	39596	\N	55.054836000000002	г.Ярцево, ул.Автозаводская, д.18, средняя общеобраз.школа №9		0101000020E61000000D7217618A5840405D52B5DD04874B40
90556	1	13	\N	54805	39596	\N	55.054836000000002	г.Ярцево, ул.Автозаводская, д.32, Детская музыкальная школа		0101000020E61000000D7217618A5840405D52B5DD04874B40
90560	1	13	\N	54805	39872	\N	55.054836000000002	г.Ярцево, ул.30 лет Победы, д.21, Детская художественная школа		0101000020E61000000D7217618A5840405D52B5DD04874B40
90569	1	13	\N	54805	39676	\N	55.054836000000002	г.Ярцево, ул.1-я Рабочая, д.20, средняя общеобраз.школа №6		0101000020E61000000D7217618A5840405D52B5DD04874B40
90457	1	13	\N	54804	39860	\N	55.833551999999997	г.Сычевка, ул.Станционное шоссе, д.15а		0101000020E6100000E413B2F336244140F8C1F9D4B1EA4B40
90455	1	13	\N	54804	39590	\N	55.833551999999997	г.Сычевка, Проспект Коммунистов, д.5		0101000020E6100000E413B2F336244140F8C1F9D4B1EA4B40
90456	1	13	\N	54804	39592	\N	55.833551999999997	г.Сычевка, ул. Большая Пролетарская, д.16		0101000020E6100000E413B2F336244140F8C1F9D4B1EA4B40
90410	1	13	\N	54885	\N	\N	54.7233625631699	д.Станички, д.43	Россия, Смоленская область, Смоленск	0101000020E610000056647440120440407711A628975C4B40
90349	1	13	\N	6	\N	\N	54.762818000000003	"Смоленская область, город Смоленск, Ленинский район, МБУК ""Дом культуры"" п. Миловидово, поселок Миловидово, здание библиотеки"		0101000020E6100000C6FCDCD0940140406B662D05A4614B40
90331	1	13	\N	6	\N	\N	54.762818000000003	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №26 им. А.С. Пушкина, Николаева, 49а, каб. №19, 2-й этаж	Россия, Смоленская область, Смоленск, Ленинский район	0101000020E6100000C6FCDCD0940140406B662D05A4614B40
90330	1	13	\N	6	\N	\N	54.7526889800384	"Смоленская область, город Смоленск, Ленинский район, СОГУ ""Геронтологический центр ""Вишенки"", поселок Вишенки, здание геронтологического центра, корп. 2, каб. №1, 1-й этаж"	Россия, Смоленская область, Смоленск, поселок Вишенки	0101000020E6100000CEFC6A0E100440408B87F71C58604B40
90282	1	13	\N	6	\N	\N	54.794764704764702	"Смоленская область, город Смоленск, Заднепровский район, СОГБОУ ДОД ""Детско-юношеский центр туризма, краеведения и спорта"", поселок Нижняя Дубровенка, дом 13"	Россия, Смоленская область, Смоленск, поселок Дубровенка	0101000020E61000000F643DB5FAF63F40B28009DCBA654B40
90281	1	13	\N	6	\N	\N	54.806102139453799	"Смоленская область, город Смоленск, Заднепровский район, НУ ""Санаторий ""Красный Бор"", поселок Красный Бор, клуб санатория"	Россия, Смоленская область, Смоленск, улица Слободская	0101000020E610000097900F7A36E73F40BF9EAF592E674B40
90364	1	13	\N	6	1263	\N	54.7911948314676	Смоленская область, город Смоленск, Промышленный район, Соболева, 24, СОШ №1, канцелярия, 2 эт		0101000020E6100000386744696F0840401EE1B4E045654B40
90393	1	13	\N	6	1221	\N	54.772229000000003	Смоленская область, город Смоленск, Промышленный район, Румянцева, 7А, СОШ №12, канцелярия	Россия, Смоленская область, Смоленск, улица Румянцева, 7а	0101000020E6100000ADDA3521AD094040EB025E66D8624B40
90279	1	13	\N	6	75034	\N	54.806963000000003	"Смоленская область, город Смоленск, Заднепровский район, ОАО ""Смоленский ДОК"", поселок Пронино, здание ОАО ""Смоленский ДОК"""	Россия, Смоленская область, Смоленск, улица Белинского, 6а	0101000020E6100000DD989EB0C4FF3F40810A47904A674B40
90328	1	13	\N	6	39770	\N	54.768546999999998	Смоленская область, город Смоленск, Ленинский район, филиал ГБОУ ВПО - Всероссийского заочного финансово-экономического института в г.Смоленске, проспект Гагарина, 22, приемная, 2-й этаж		0101000020E61000000CE9F010C60540402E3883BF5F624B40
90363	1	13	\N	6	39790	\N	54.758111	Смоленская область, город Смоленск, Промышленный район, мкр. Южный, 31А, СОШ №38, 2 эт., каб.29		0101000020E6100000925D6919A90D404072DEFFC709614B40
90362	1	13	\N	6	39790	\N	54.758111	Смоленская область, город Смоленск, Промышленный район, мкр. Южный, 31А, СОШ №38, 2 эт.,каб.27		0101000020E6100000925D6919A90D404072DEFFC709614B40
90304	1	13	\N	6	39909	\N	54.782023000000002	Смоленская область, город Смоленск, Промышленный район, Маршала Жукова, 17,  МБОУ СОШ №6, 2 этаж каб.22		0101000020E6100000126C5CFFAE07404023DC645419644B40
90290	1	13	\N	6	39578	\N	54.809188186524203	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №32 им. С.А. Лавочкина, улица Генерала Городнянского, дом 6	Россия, Смоленская область, Смоленск, улица генерала Городнянского, 6	0101000020E61000001D56B8E5230140406728EE7893674B40
90235	1	13	\N	54800	39720	\N	55.122199999999999	г.Сафоново, Комсомольская, 1		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90289	1	13	\N	6	39578	\N	54.809229843312501	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №32 им. С.А.Лавочкина, улица Генерала Городнянского, дом 6	Россия, Смоленская область, Смоленск, улица генерала Городнянского, 6	0101000020E61000000C1F115322014040967840D994674B40
90287	1	13	\N	6	39578	\N	54.808525114728603	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №36 им. генерала А.М. Городнянского, улица Генерала Городнянского, дом 4		0101000020E61000007DCD72D9E8004040CC7F48BF7D674B40
90286	1	13	\N	6	39578	\N	54.808512720759197	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №36 им. генерала А.М.Городнянского, улица Генерала Городнянского, дом 4	Россия, Смоленская область, Смоленск, улица генерала Городнянского, 4	0101000020E6100000897B2C7DE800404007B29E5A7D674B40
90323	1	13	\N	6	39886	\N	54.763907112342999	"Смоленская область, город Смоленск, Ленинский район, ФГБОУ ВПО ""Национальный исследовательский университет ""МЭИ"" в г.Смоленске, Энергетический проезд, 1, 1-й этаж, каб. №105"	Россия, Смоленская область, Смоленск, Энергетический проезд, 1	0101000020E61000002FF99FFCDD034040BE175FB4C7614B40
90324	1	13	\N	6	39541	\N	54.764297177876998	"Смоленская область, город Смоленск, Ленинский район, ФГБОУ ВПО ""Национальный исследовательский университет ""МЭИ"" в г.Смоленске"", Энергетический проезд, 1, каб. №105, 1-й этаж"	Россия, Смоленская область, Смоленск, Энергетический проезд, 1	0101000020E610000013B69F8CF103404028B7ED7BD4614B40
90277	1	13	\N	6	39631	\N	54.806963000000003	Смоленская область, город Смоленск, Заднепровский район, детская бибилиотека №3 филиала МУК ЦБС г.Смоленска, улица Щорса, дом 8		0101000020E6100000DD989EB0C4FF3F40810A47904A674B40
90367	1	13	\N	6	39915	\N	54.786732000000001	Смоленская область, город Смоленск, Промышленный район, Шевченко, 91, Смол. машиностр.колледж, 2 эт		0101000020E610000078B7B244670B4040BC5B59A2B3644B40
90294	1	13	\N	6	39756	\N	54.814393000000003	"Смоленская область, город Смоленск, Заднепровский район, МБОУ ДОД ""Детская школа искусств №2 г.Смоленска"", улица Чкалова, дом 6А"	Россия, Смоленская область, Смоленск, улица Чкалова, 6а	0101000020E6100000A69883A0A3054040B18BA2073E684B40
90302	1	13	\N	6	39582	\N	54.812190581935901	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №23, улица Центральная, дом 10	Россия, Смоленская область, Смоленск, улица Центральная, 10	0101000020E61000004F22C2BF08104040828DEBDFF5674B40
90308	1	13	\N	6	39634	\N	54.802031044587501	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №22, улица Фрунзе, дом 12	Россия, Смоленская область, Смоленск, улица Фрунзе, 12	0101000020E610000086AE44A0FA05404068B0A9F3A8664B40
90293	1	13	\N	6	39634	\N	54.814205905980401	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №3, улица Фрунзе, дом 62А	Россия, Смоленская область, Смоленск, улица Фрунзе, 62а	0101000020E61000006FD39FFD480540407E1AF7E637684B40
90284	1	13	\N	6	39964	\N	54.800528392743203	"Смоленская область, город Смоленск, Заднепровский район, Смоленский филиал ГОУ ВПО ""Саратовская государственная академия права"", улица Ударников, дом 3"		0101000020E610000001892650C402404022C495B377664B40
90356	1	13	\N	6	39897	\N	54.775283000000002	Смоленская область, город Смоленск, Промышленный район, Твардовского, 14, СОШ №27, 1 эт., канцелярия		0101000020E6100000562AA8A8FA07404088122D793C634B40
90384	1	13	\N	6	1550	\N	54.765310999999997	Смоленская область, город Смоленск, Промышленный район, проспект Строителей, 9, СОШ №11, канцелярия, 1эт		0101000020E610000052F01472A50C40407022FAB5F5614B40
90383	1	13	\N	6	1550	\N	54.765310999999997	Смоленская область, город Смоленск, Промышленный район, проспект Строителей, 9, СОШ №11,каб.3		0101000020E610000052F01472A50C40407022FAB5F5614B40
90382	1	13	\N	6	1550	\N	54.761648999999998	Смоленская область, город Смоленск, Промышленный район, проспект Строителей, 24, Библиотека, каб.зам. директора		0101000020E61000006F490ED8D50A4040FB03E5B67D614B40
90389	1	13	\N	6	39689	\N	54.765269000000004	Смоленская область, город Смоленск, Промышленный район, Маршала Соколовского, 7Б, СОШ №29,каб.зам.дир.по АХР		0101000020E61000004B901150E10A404042D2A755F4614B40
90388	1	13	\N	6	39689	\N	54.765202437187298	Смоленская область, город Смоленск, Промышленный район, Маршала Соколовского, 7Б, СОШ №29, кабинет вожатых	Россия, Смоленская область, Смоленск, улица Соколовского, 7б	0101000020E6100000166C239EEC0A4040BA6A9E23F2614B40
90366	1	13	\N	6	39901	\N	54.791201000000001	Смоленская область, город Смоленск, Промышленный район, Соболева, 24, СОШ №1, каб. зам. дир		0101000020E61000000D1B65FD6608404000C8091346654B40
90365	1	13	\N	6	39901	\N	54.791201000000001	Смоленская область, город Смоленск, Промышленный район, Соболева, 24, СОШ №1, каб. зам. директ. 3 эт		0101000020E61000000D1B65FD6608404000C8091346654B40
90303	1	13	\N	6	39583	\N	54.8107038979851	"Смоленская область, город Смоленск, Заднепровский район, МБУК ""Дом культуры ""Сортировка"" г. Смоленска, улица Седова, дом 1"	Россия, Смоленская область, Смоленск, улица Седова	0101000020E6100000C845B58828104040425E0F26C5674B40
90394	1	13	\N	6	39893	\N	54.772229000000003	Смоленская область, город Смоленск, Промышленный район, Румянцева, 7А, СОШ №12, учительская,2 эт		0101000020E6100000ADDA3521AD094040EB025E66D8624B40
90392	1	13	\N	6	39893	\N	54.772229000000003	Смоленская область, город Смоленск, Промышленный район, Румянцева, 7А, СОШ №12, каб.воспитат.раб		0101000020E6100000ADDA3521AD094040EB025E66D8624B40
90361	1	13	\N	6	39893	\N	54.770245000000003	Смоленская область, город Смоленск, Промышленный район, Румянцева, 8, СГИИ,  1 эт., каб. 105		0101000020E6100000B08EE3874A0940402A745E6397624B40
90305	1	13	\N	6	39679	\N	54.805093894299901	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №13 им. Э.Д. Балтина, улица Революционная, дом 8	Россия, Смоленская область, Смоленск, улица Радищева, 6	0101000020E610000004C93B8732004040581AF8510D674B40
90371	1	13	\N	6	39919	\N	54.771189999999997	Смоленская область, город Смоленск, Промышленный район, Раевского, 2, Смол. пед.кол-дж, каб.17, 1 этаж		0101000020E61000009548A2975106404049809A5AB6624B40
90278	1	13	\N	6	39622	\N	54.802912310809198	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №18, улица Рабочая, дом 4		0101000020E610000002D369DD0601404071C806D2C5664B40
90275	1	13	\N	6	39622	\N	54.806963000000003	Смоленская область, город Смоленск, Заднепровский район, МБУК Дом культуры микрорайона Гнездово, улица Рабочая, дом 10		0101000020E6100000DD989EB0C4FF3F40810A47904A674B40
90314	1	13	\N	6	39900	\N	54.784244999999999	"Смоленская область, город Смоленск, Ленинский район, ФГБОУ ВПО ""Смоленский государственный университет"", Пржевальского, 4, каб. №32, 1-й этаж"		0101000020E6100000A4DE5339ED0540409886E12362644B40
90399	1	13	\N	6	39887	\N	54.758668100375601	Смоленская область, город Смоленск, Промышленный район, Попова, 108, СОШ №37, каб.завуча, 1эт	Россия, Смоленская область, Смоленск, улица Попова	0101000020E6100000276BD443340E4040C84274081C614B40
90398	1	13	\N	6	39887	\N	54.758501000000003	Смоленская область, город Смоленск, Промышленный район, Попова, 108, СОШ №37, каб.зам.дир		0101000020E61000001BBD1AA0340E4040DD7D8E8F16614B40
90397	1	13	\N	6	39887	\N	54.758897672225601	Смоленская область, город Смоленск, Промышленный район, Попова, 108, СОШ №37, каб. зам. дир	Россия, Смоленская область, Смоленск, улица Рыленкова, 108	0101000020E61000008C82E0F1ED0D4040FA7FD59123614B40
90396	1	13	\N	6	39887	\N	54.758871399499903	Смоленская область, город Смоленск, Промышленный район, Попова, 108, СОШ №37, каб.завуча,1 эт	Россия, Смоленская область, Смоленск, улица Рыленкова, 108	0101000020E6100000A5129ED0EB0D4040007157AF22614B40
90387	1	13	\N	6	39887	\N	54.774312000000002	Смоленская область, город Смоленск, Промышленный район, Попова, 10А, СОШ №16, каб.36		0101000020E6100000C5573B8A730A40403F73D6A71C634B40
90386	1	13	\N	6	39887	\N	54.764718999999999	Смоленская область, город Смоленск, Промышленный район, Попова, 62, СОШ №34, каб.5		0101000020E6100000D6355A0EF40C40409ED0EB4FE2614B40
90385	1	13	\N	6	39887	\N	54.764718999999999	Смоленская область, город Смоленск, Промышленный район, Попова, 62,СОШ №34, каб.5		0101000020E6100000D6355A0EF40C40409ED0EB4FE2614B40
90381	1	13	\N	6	39887	\N	54.770183000000003	Смоленская область, город Смоленск, Промышленный район, Попова, 36А, СОШ №31, каб.19, 2 эт		0101000020E6100000A2B77878CF0B4040B477465B95624B40
90380	1	13	\N	6	39887	\N	54.770183000000003	Смоленская область, город Смоленск, Промышленный район, Попова, 36А, СОШ №31, каб.14, 2 эт		0101000020E6100000A2B77878CF0B4040B477465B95624B40
90379	1	13	\N	6	39887	\N	54.770183000000003	Смоленская область, город Смоленск, Промышленный район, Попова, 36А, СОШ 31, приемн. директ., 2 эт		0101000020E6100000A2B77878CF0B4040B477465B95624B40
90378	1	13	\N	6	39887	\N	54.770183000000003	Смоленская область, город Смоленск, Промышленный район, Попова, 36А, СОШ №31, каб.завуча, 2 эт		0101000020E6100000A2B77878CF0B4040B477465B95624B40
90377	1	13	\N	6	39926	\N	54.762011999999999	Смоленская область, город Смоленск, Промышленный район, Петра Алексеева, 20, СОШ №35, каб. зам. дир. по АХР		0101000020E6100000213B6F63B30D40406C94F59B89614B40
90376	1	13	\N	6	39926	\N	54.762011999999999	Смоленская область, город Смоленск, Промышленный район, Петра Алексеева, 20, СОШ №35, каб. соц.педагога,1эт		0101000020E6100000213B6F63B30D40406C94F59B89614B40
90375	1	13	\N	6	39926	\N	54.762011999999999	Смоленская область, город Смоленск, Промышленный район, Петра Алексеева, 20, СОШ №35, каб.соц.педагога, 2эт		0101000020E6100000213B6F63B30D40406C94F59B89614B40
90335	1	13	\N	6	39762	\N	54.789105881573803	"Смоленская область, город Смоленск, Ленинский район, СОГОУ ""Педагогический лицей-интернат им. Кирилла и Мефодия"", Парковая, 20, каб. №15, 1-й этаж"		0101000020E61000001F9DBAF259024040E789E76C01654B40
90288	1	13	\N	6	39752	\N	54.812192808773901	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №30, улица Островского, дом 3	Россия, Смоленская область, Смоленск, улица Островского, 3	0101000020E6100000008BFCFA210640402385B2F0F5674B40
90322	1	13	\N	6	39639	\N	54.775669434718203	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №14, Октябрьской Революции, 7а, каб. зам. директ. по УВР, 1 эт	Россия, Смоленская область, Смоленск, улица Октябрьской Революции, 7а	0101000020E6100000BD1DE1B4E0054040B1C22D1F49634B40
90319	1	13	\N	6	39639	\N	54.7746445580688	"Смоленская область, город Смоленск, Ленинский район, ГАУ ДОПС ""Смоленский областной институт развития образования"", Октябрьской революции, 20а, уч.-метод. каб., 1-й этаж"	Россия, Смоленская область, Смоленск, улица Октябрьской Революции, 20а	0101000020E6100000E7C2482F6A05404045813E9127634B40
90318	1	13	\N	6	39639	\N	54.775677000000002	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №14, Октябрьской Революции, 7а, каб. директора, 1-й этаж	Россия, Смоленская область, Смоленск, улица Октябрьской Революции, 7а	0101000020E6100000C493DDCCE805404034A1496249634B40
90233	1	13	\N	54800	39941	\N	55.122199999999999	г.Сафоново, Коммунистическая, 4		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90340	1	13	\N	6	39922	\N	54.775734	"Смоленская область, город Смоленск, Ленинский район, ФГОУ СПО ""Смоленский торгово-экономический техникум"", Нормандия-Неман, 21, каб. №3, 1-й этаж"		0101000020E6100000BF7E880D16024040983270404B634B40
90311	1	13	\N	6	39991	\N	54.794736421345199	Смоленская область, город Смоленск, Заднепровский район, МБОУ О(с)ОШ №1, улица Ново-Московская, дом 2/8	Россия, Смоленская область, Смоленск, улица Новоленинградская, 2	0101000020E610000085ECBC8DCD064040187AC4E8B9654B40
90341	1	13	\N	6	39670	\N	54.786670670836003	"Смоленская область, город Смоленск, Ленинский район, МБОУ ДОД ""Детская школа искусств №3 г. Смоленска"", Ново-Краснофлотская, 6, каб.№1, 1-й этаж"		0101000020E6100000C6A4BF97C201404016DBA4A2B1644B40
90352	1	13	\N	6	39657	\N	54.771216000000003	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №26 им. А.С. Пушкина, Николаева, 49а, каб. метод-й раб., 2-й этаж	Россия, Смоленская область, Смоленск, улица Николаева, 49а	0101000020E6100000D4BA0D6ABF0340407313B534B7624B40
90332	1	13	\N	6	39657	\N	54.771208959510801	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №26, Николаева, 49а, канцелярия, 1-й этаж	Россия, Смоленская область, Смоленск, улица Николаева, 49а	0101000020E6100000D6390664AF034040C0B0FCF9B6624B40
90321	1	13	\N	6	39699	\N	54.771219728137403	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №2, Неверовского, 11, каб. 101, 1-й этаж	Россия, Смоленская область, Смоленск, улица Неверовского, 11	0101000020E6100000622CD32F11054040B4024356B7624B40
90320	1	13	\N	6	39699	\N	54.770879000000001	"Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №2 (УИК - ул. Октябрьской Революции, д.20, ""ЦРТДиЮ""), Неверовского, 11, каб. №1, 1-й этаж"	Россия, Смоленская область, Смоленск, улица Неверовского, 11	0101000020E61000009148DBF8130540402B16BF29AC624B40
90350	1	13	\N	6	39579	\N	54.781050920688898	"Смоленская область, город Смоленск, Ленинский район, МБУК ""Дом культуры ""Шарм"" города Смоленска, Нахимова, 17, каб. №4, 1-й этаж"	Россия, Смоленская область, Смоленск, улица Нахимова	0101000020E6100000BB7EC16ED802404009C1AA7AF9634B40
90339	1	13	\N	6	39579	\N	54.779944860552703	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №39, Нахимова, 35, каб. №308, 3-й этаж	Россия, Смоленская область, Смоленск, улица Нахимова, 35	0101000020E610000002486DE2E4004040E0D6DD3CD5634B40
90338	1	13	\N	6	39579	\N	54.780637062785502	"Смоленская область, город Смоленск, Ленинский район, МБУК ""Дом культуры ""Шарм"" города Смоленска"", Нахимова, 17, каб. директора, 2-й этаж"	Россия, Смоленская область, Смоленск, улица Нахимова, 17	0101000020E6100000F3CCCB61F70140401686C8E9EB634B40
90333	1	13	\N	6	39579	\N	54.780902091238502	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №8, Нахимова, 9, каб. псих. разгр. 1 этаж	Россия, Смоленская область, Смоленск, улица Нахимова, 9	0101000020E6100000A8C7B60C38034040C4B0C398F4634B40
90336	1	13	\N	6	39667	\N	54.777873999999997	"Смоленская область, город Смоленск, Ленинский район, МБОУ ДОД ""Специализированная детско-юношеская спортивная школа олимпийского резерва №1"", Нарвская, 5, каб. директора, 1-й этаж"	Россия, Смоленская область, Смоленск, улица Нарвская, 5к1	0101000020E6100000B9895A9A5B03404050340F6091634B40
90306	1	13	\N	6	40038	\N	54.805376170629302	"Смоленская область, город Смоленск, Заднепровский район, МБОУ ДОД ""Детская школа искусств №7 г. Смоленска"", улица Московский Большак, дом 12"	Россия, Смоленская область, Смоленск, поселок Валутино	0101000020E6100000B858518369144040DD7D8E8F16674B40
90276	1	13	\N	6	39648	\N	54.800703007720401	Смоленская область, город Смоленск, Заднепровский район, филиал МБУК Дом культуры микрорайона Гнездово.Дом творчества, улица Минская, дом 21	Россия, Смоленская область, Смоленск, улица Новомопровская, 1а	0101000020E6100000FCFB8C0B070240409067976F7D664B40
90390	1	13	\N	6	39587	\N	54.765264473701301	Смоленская область, город Смоленск, Промышленный район, Маршала Соколовского, 7Б, СОШ №29, учительская,2 эт	Россия, Смоленская область, Смоленск, улица Соколовского, 7б	0101000020E61000000F2A711DE30A40403067B62BF4614B40
90355	1	13	\N	6	39585	\N	54.770443119519797	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №21 им. Н.И. Рыленкова, М. Расковой, 6, учительская, 1-й этаж	Россия, Смоленская область, Смоленск, улица Марины Расковой, 6	0101000020E6100000DEAF027CB7014040503750E09D624B40
90351	1	13	\N	6	39585	\N	54.770461728063097	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №21 им. Н.И. Рыленкова, М. Расковой, 6, тренаж-й зал, 2-й этаж		0101000020E6100000F60B76C3B6014040C767B27F9E624B40
90347	1	13	\N	6	39585	\N	54.770486539440803	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №21 им. Н.И. Рыленкова, М. Расковой, 6, каб. №1, 1-й этаж	Россия, Смоленская область, Смоленск, улица Марины Расковой, 6	0101000020E6100000C9570229B1014040207F69519F624B40
90346	1	13	\N	6	39585	\N	54.771047408186703	"Смоленская область, город Смоленск, Ленинский район, СОГУ СПО ""Колледж профессиональных технологий и спорта"", М. Расковой, 11а, каб. соц. раб., 1-й этаж"	Россия, Смоленская область, Смоленск, улица Марины Расковой, 10	0101000020E610000029779FE3A3014040E75608ABB1624B40
90357	1	13	\N	6	39928	\N	54.784244999999999	Смоленская область, город Смоленск, Промышленный район, Ленина, 37, Смол. политех. колледж, каб.106		0101000020E6100000E7012CF2EB0740409886E12362644B40
90313	1	13	\N	6	39884	\N	54.7821446344796	Смоленская область, город Смоленск, Ленинский район, МБОУ гимназия №1 им. Н.М. Пржевальского, Ленина, 4, актовый зал, 1-й этаж	Россия, Смоленская область, Смоленск, улица Ленина, 4	0101000020E610000025AE635C710540406EDDCD531D644B40
90312	1	13	\N	6	39884	\N	54.783096300958199	Смоленская область, город Смоленск, Ленинский район, Смоленское областное объединение организации профессиональных союзов, Ленина, 13а, ком. №18, 3-й этаж	Россия, Смоленская область, Смоленск, улица Ленина, 13а	0101000020E6100000BBB9F8DB9E06404070D05E7D3C644B40
90373	1	13	\N	6	39894	\N	54.768084999999999	Смоленская область, город Смоленск, Промышленный район, Крупской, 28, СГМА, зал Учен. Совета, 2 этажа		0101000020E61000005BEECC04C30740402AC6F99B50624B40
90372	1	13	\N	6	39894	\N	54.768084999999999	Смоленская область, город Смоленск, Промышленный район, Крупской, 28, СГМА, каб.319, 3 этаж		0101000020E61000005BEECC04C30740402AC6F99B50624B40
90369	1	13	\N	6	39894	\N	54.769455999999998	Смоленская область, город Смоленск, Промышленный район, Крупской, 37, МУК №2, каб. директора, 2 этаж		0101000020E61000006ADAC534D307404001DBC1887D624B40
90360	1	13	\N	6	39894	\N	54.761882999999997	Смоленская область, город Смоленск, Промышленный район, Крупской, 67/1, Дом культуры ВОС, 1 этаж		0101000020E61000007E703E75AC0840406E30D46185614B40
90359	1	13	\N	6	39894	\N	54.761882999999997	Смоленская область, город Смоленск, Промышленный район, Крупской, 67/1, Дом культуры ВОС, 1 эт		0101000020E61000007E703E75AC0840406E30D46185614B40
90358	1	13	\N	6	39913	\N	54.780216000000003	Смоленская область, город Смоленск, Промышленный район, Коммунистическая, 21, Смол. кол-дж телекоммун		0101000020E6100000F1660DDE5707404071E82D1EDE634B40
90370	1	13	\N	6	39917	\N	54.772671000000003	Смоленская область, город Смоленск, Промышленный район, Коммунальная, 5, СОШ №25, учительская, 2 этаж		0101000020E6100000CA1AF5108D064040A8C821E2E6624B40
90343	1	13	\N	6	39686	\N	54.776816236691097	"Смоленская область, город Смоленск, Ленинский район, Смоленский филиал ФГБОУ ВПО ""Российская академия народного хозяйства и государственной службы при Президенте Российский Федерации"", Кловская, 13, ауд. №12, 1-й этаж"		0101000020E61000008099EFE0270040403881E9B46E634B40
90354	1	13	\N	6	39537	\N	54.768194000000001	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №33, Кирова, 22а, каб. вожатых, 1-й этаж		0101000020E6100000DF15C1FF56044040E17D552E54624B40
90348	1	13	\N	6	39537	\N	54.768173566603103	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №33, Кирова, 22а, учительская, 2-й этаж	Россия, Смоленская область, Смоленск, улица Кирова, 22а	0101000020E6100000FFE7305F5E0440409AD18F8653624B40
90327	1	13	\N	6	39537	\N	54.768194000000001	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №33, Кирова, 22а, каб. директора, 1-й эт	Россия, Смоленская область, Смоленск, улица Кирова, 22а	0101000020E6100000DF15C1FF56044040E17D552E54624B40
90326	1	13	\N	6	39537	\N	54.7684007796475	Смоленская область, город Смоленск, Ленинский район, Региональное отделение ДОСААФ России Смоленской области, Кирова, 22б, каб. №35, 3-й этаж	Россия, Смоленская область, Смоленск, улица Кирова, 22б	0101000020E6100000C878944A780440405A9BC6F65A624B40
90317	1	13	\N	6	39850	\N	54.783095913401901	Смоленская область, город Смоленск, Ленинский район, Смоленское областное объединение физкультурно-оздоровительных и спортивных организаций профсоюзов, Дзержинского, 18, корп.2, ком. №15, 2-й этаж	Россия, Смоленская область, Смоленск, улица Дзержинского, 18	0101000020E61000003B376DC66904404070D05E7D3C644B40
90298	1	13	\N	6	39575	\N	54.814822999999997	"Смоленская область, город Смоленск, Заднепровский район, филиал ФГБОУ ВПО ""Московский государственный университет технологий и управления им. К.Г. Разумовского"" в г. Смоленске, улица Губенко, дом 26"		0101000020E6100000D1CB28965B064040A983BC1E4C684B40
90297	1	13	\N	6	39575	\N	54.814742457430398	"Смоленская область, город Смоленск, Заднепровский район, филиаил ФГБОУ ВПО ""Московский государственный университет технологий и управления им. К.Г. Разумовского"" в г. Смоленске, улица Губенко, дом 26"	Россия, Смоленская область, Смоленск, улица Губенко, 22	0101000020E6100000A1478C9E5B064040BD56427749684B40
90295	1	13	\N	6	39575	\N	54.813827661892098	"Смоленская область, город Смоленск, Заднепровский район, МБУК ""Культурный центр ""Заднепровье"" г.Смоленска, улица Губенко, дом 5"	Россия, Смоленская область, Смоленск, улица Губенко, 5	0101000020E61000001EC18D942D064040D84812842B684B40
90299	1	13	\N	6	39653	\N	54.810633023760197	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №19 им. Героя России Панова, улица Генерала Лукина, дом 1	Россия, Смоленская область, Смоленск, улица генерала Лукина	0101000020E61000009AD2FA5B02084040790778D2C2674B40
90300	1	13	\N	6	39569	\N	54.803913831909703	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №10, улица Гастелло, дом 8	Россия, Смоленская область, Смоленск, улица Гастелло, 8	0101000020E6100000FA7B293C68084040F56569A7E6664B40
90344	1	13	\N	6	39907	\N	54.771273999999998	"Смоленская область, город Смоленск, Ленинский район, СОГБОУ СПО ""Смоленский монтажный техникум"", Гарабурды, 17, каб. №107, 1-й этаж"		0101000020E6100000552E54FEB5004040A7203F1BB9624B40
90231	1	13	\N	54800	39820	\N	55.116244676687899	г.Сафоново, Красногвардейская, 34	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E6100000622CD32F119D404069A9BC1DE18E4B40
90342	1	13	\N	6	39846	\N	54.772837000000003	"Смоленская область, город Смоленск, Ленинский район, ФГОУ СПО ""Смоленский автотранспортный колледж им. Е.Г. Трубицина"", Гарабурды, 13, ком. №109, 1-й этаж"	Россия, Смоленская область, Смоленск, улица Гарабурды, 13	0101000020E610000015CAC2D7D7004040C311A452EC624B40
90353	1	13	\N	6	39588	\N	54.761680642143702	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №9, проспект Гагарина, 52, каб.зам. директора, 3-й этаж	Россия, Смоленская область, Смоленск, Гагарина проспект	0101000020E61000007958A835CD054040077E54C37E614B40
90329	1	13	\N	6	39588	\N	54.7599706706091	"Смоленская область, город Смоленск, Ленинский район, ФГОУ СПО ""Смоленский промышленно-экономический колледж"", проспект Гагарина, 56, каб.№108, 1-й этаж"	Россия, Смоленская область, Смоленск, Гагарина проспект, 56	0101000020E61000009206B7B5850540404774CFBA46614B40
90374	1	13	\N	6	1437	\N	54.768324	Смоленская область, город Смоленск, Промышленный район, пр-т Гагарина, 23, СГАФКСТ, каб. 109, 1 этаж		0101000020E61000000D1CD0D215064040AF5DDA7058624B40
90285	1	13	\N	6	39637	\N	54.8002319426189	Смоленская область, город Смоленск, Заднепровский район, МБОУ МУК №1, Витебское шоссе, дом 42		0101000020E6100000E3FDB8FDF2034040399B8E006E664B40
90292	1	13	\N	6	39574	\N	54.808761686033797	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ № 40, улица Валентины Гризодубовой, дом 6	Россия, Смоленская область, Смоленск, улица Валентины Гризодубовой, 6	0101000020E610000074D2FBC6D7024040B01F628385674B40
90291	1	13	\N	6	39574	\N	54.808705913469502	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №40, улица Валентины Гризодубовой, дом 6	Россия, Смоленская область, Смоленск, улица Валентины Гризодубовой, 6	0101000020E61000008F6CAE9AE70240401C0A9FAD83674B40
90316	1	13	\N	6	39873	\N	54.785051862503003	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №28, Бакунина, 14, каб. зам. директора, 1-й этаж	Россия, Смоленская область, Смоленск, улица Пржевальского	0101000020E6100000B950F9D7F204404067D47C957C644B40
90334	1	13	\N	6	39662	\N	54.783967422532498	Смоленская область, город Смоленск, Ленинский район, МБОУ лицей №1 им. академика Б.Н. Петрова, Багратиона, 57, каб. завуча, 1-й этаж	Россия, Смоленская область, Смоленск, улица Багратиона, 57	0101000020E610000080D8D2A3A90240405512D90759644B40
90337	1	13	\N	6	39761	\N	54.775448701625301	Смоленская область, город Смоленск, Ленинский район, МБОУ СОШ №17, Академика Петрова, 5а, каб. №2, 1-й этаж	Россия, Смоленская область, Смоленск, улица академика Петрова, 5а	0101000020E6100000F19C2D20B4024040A35BAFE941634B40
90296	1	13	\N	6	39644	\N	54.821226355444701	Смоленская область, город Смоленск, Заднепровский район, филиал МБОУ СОШ №30, улица Автозаводская, дом 31	Россия, Смоленская область, Смоленск, улица Автозаводская, 31	0101000020E610000056D7A19A92084040FD4FFEEE1D694B40
90395	1	13	\N	6	39906	\N	54.766038000000002	Смоленская область, город Смоленск, Промышленный район, 25 Сентября, 28А, МБОУ гимназия №4, учительская		0101000020E6100000BCE9961DE209404023BF7E880D624B40
90310	1	13	\N	6	39889	\N	54.80103606214	МБОУ СОШ № 7 г. Смоленск, ул.12 лет Октября, д. № 9	Россия, Смоленская область, Смоленск, улица 12 Лет Октября, 9	0101000020E6100000927A4FE5B40540409775FF5888664B40
90307	1	13	\N	6	39835	\N	54.801018436182801	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №7, улица 12 лет Октября, дом 9	Россия, Смоленская область, Смоленск, улица 12 Лет Октября, 9	0101000020E61000008DF161F6B2054040F0C000C287664B40
90283	1	13	\N	6	39581	\N	54.805029110876603	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №15, улица Радищева, дом 6		0101000020E61000001BBD1AA03400404071AAB5300B674B40
90301	1	13	\N	6	39632	\N	54.805899466002103	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №24, улица Папанина, дом 1		0101000020E6100000446D1B46410040408670CCB227674B40
90240	1	13	\N	54800	39567	\N	55.122199999999999	г.Сафоново, микрорайон-2, 23		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90245	1	13	\N	54800	39623	\N	55.113221745785701	г.Сафоново, микрорайон-1, 7-а	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E610000025917D90659D40400798F90E7E8E4B40
90243	1	13	\N	54800	39623	\N	55.122199999999999	г.Сафоново, микрорайон-1, 11-а		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90242	1	13	\N	54800	39623	\N	55.122199999999999	г.Сафоново, микрорайон-1, 14-а		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90236	1	13	\N	54800	39805	\N	55.122199999999999	г.Сафоново, Энгельса, 6		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90234	1	13	\N	54800	39546	\N	55.113477309789303	г.Сафоново, Строителей, 22	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E6100000EE9579ABAE9D404092EC116A868E4B40
90238	1	13	\N	54800	39722	\N	55.122199999999999	г.Сафоново, Советская, 29		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90237	1	13	\N	54800	39722	\N	55.122199999999999	г.Сафоново, Советская, 52		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90248	1	13	\N	54800	39983	\N	55.122199999999999	г.Сафоново, Районная подстанция, 3-а		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90247	1	13	\N	54800	40012	\N	55.122199999999999	г.Сафоново, Пушкина, 14		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90244	1	13	\N	54800	39823	\N	55.119712837974703	г.Сафоново, Октябрьская, 37		0101000020E6100000C9022670EB9E4040F9F36DC1528F4B40
90230	1	13	\N	54800	39803	\N	55.110586743224999	г.Сафоново, Ленина, 4-а	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E6100000FE7C5BB0549D40406F2EFEB6278E4B40
90241	1	13	\N	54800	39746	\N	55.114230667629997	г.Сафоново, Кутузова, 1	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E6100000E3FBE252959E40403D98141F9F8E4B40
90249	1	13	\N	54800	40273	\N	55.122199999999999	г.Сафоново, Горняцкая, 1		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90232	1	13	\N	54800	39832	\N	55.122199999999999	г.Сафоново, Вахрушева, 11		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90253	1	13	\N	54800	39822	\N	55.118261658350498	г.Сафоново, 40 лет Октября, 3	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E61000007505DB88279F4040062E8F35238F4B40
90197	1	13	\N	54806	39624	\N	54.947428736591199	г. Рудня, Молкомбината, Здание дома культуры	Россия, Смоленская область, Руднянский район, Рудня	0101000020E6100000AE10566309133F4018247D5A45794B40
90196	1	13	\N	54806	39978	\N	54.945473999999997	г. Рудня, Мелиораторов, 35		0101000020E6100000F645425BCE113F40F19BC24A05794B40
89631	1	13	\N	54806	39719	\N	54.945473999999997	г. Рудня, Красноярская, 44		0101000020E6100000F645425BCE113F40F19BC24A05794B40
90181	1	13	\N	54806	39743	\N	54.945473999999997	г. Рудня, Киреева, 80		0101000020E6100000F645425BCE113F40F19BC24A05794B40
90198	1	13	\N	54806	39800	\N	54.945473999999997	г. Рудня, Западная, 22		0101000020E6100000F645425BCE113F40F19BC24A05794B40
90145	1	13	\N	54794	39594	\N	53.944165735417002	"г.Рославль, пл.Бернандоса, д.3, здание центра ""Юбилейный"""		0101000020E6100000572250FD836C404061FF756EDAF84A40
90158	1	13	\N	54794	39621	\N	53.947054000000001	г.Рославль, пер.1-й Братский, д.15, здание средней школы №8		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90148	1	13	\N	54794	39797	\N	53.947054000000001	г.Рославль, ул.Энергетиков, д.18, здание красного уголка РЭС		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90150	1	13	\N	54794	39561	\N	53.9471024962954	г.Рославль, ул.Советская, д.63, здание музыкальной школы	Россия, Смоленская область, Рославльский район, Рославль	0101000020E61000004FCFBBB1A06E4040F4FC69A33AF94A40
90159	1	13	\N	54794	39741	\N	53.947054000000001	г.Рославль, ул.Пушкина, д.4, помещение ДРСУ		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90156	1	13	\N	54794	39562	\N	53.947054000000001	г.Рославль, ул.Пролетарская, д.66, здание библиотеки		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90155	1	13	\N	54794	39562	\N	53.947054000000001	г.Рославль, ул.Пролетарская, д.65, здание средней школы №7		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90144	1	13	\N	54794	39562	\N	53.947054000000001	г.Рославль, ул.Пролетарская, д.93, здание межрайонной ИФНС		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90153	1	13	\N	54794	39794	\N	53.947054000000001	г.Рославль, ул.Мичурина, д.175, здание школы-интерната		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90147	1	13	\N	54794	39620	\N	53.940165330388503	г.Рославль, ул.Ленина, д.57, средняя школа №6	Россия, Смоленская область, Рославльский район, Рославль	0101000020E61000005A2E1B9DF36F404003ECA35357F84A40
90149	1	13	\N	54794	39740	\N	53.947054000000001	"г.Рославль, ул.Красноармейская, д.9, здание ОАО ""Апрель"""		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90151	1	13	\N	54794	39615	\N	53.947482234689602	г.Рославль, ул.Красина, д.12, здание автомобильной школы		0101000020E61000002A5778978B6E40403BC6151747F94A40
90160	1	13	\N	54794	39877	\N	53.947054000000001	г.Рославль, ул.Каляева, д.4 А, здание призывного пункта		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90146	1	13	\N	54794	39975	\N	53.947054000000001	"г.Рославль, ул.К.Маркса, д.47-а (административное здание МБОУ ДОД ДЮСШ ""Торпедо"")"		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90143	1	13	\N	54794	39876	\N	53.947054000000001	г.Рославль, ул.Заслонова, д.2 (здание Администрации Рославльского городского поселения Рославльского района Смоленской области)		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90154	1	13	\N	54794	39619	\N	53.954949717243501	г.Рославль, ул.Горького, д.42 А, здание средней школы №3		0101000020E61000008E942D92766D404058A835CD3BFA4A40
90166	1	13	\N	54794	39530	\N	53.947054000000001	г.Рославль, 34 микрорайон, д.11, здание центра дет.творчества		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90157	1	13	\N	54794	39618	\N	53.949077098015202	г.Рославль, ул.2-я Дачная, здание красного уголка ПАТП	Россия, Смоленская область, Рославльский район, Рославль	0101000020E610000041D47D00526D40406231EA5A7BF94A40
90164	1	13	\N	54794	39565	\N	53.947054000000001	"г.Рославль, 17 микрорайон, д.16, здание МУ ФОК ""Снегирь"""		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90162	1	13	\N	54794	39565	\N	53.947054000000001	"г.Рославль, 17 микрорайон, д.2/1, здание МУП ""Жилищник"""		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90161	1	13	\N	54794	39565	\N	53.947054000000001	г.Рославль, 17 микрорайон, д.23, здание профлицея №7		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90165	1	13	\N	54794	39742	\N	53.947054000000001	г.Рославль, 16 микрорайон, д.39, здание средней школы №10		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90163	1	13	\N	54794	39798	\N	53.947054000000001	г.Рославль, 15 микрорайон, д.33, здание средней школы №9		0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90104	1	13	\N	54803	39616	\N	54.408524	г. Починок, ул. Толстого, д.30		0101000020E6100000FDBE7FF3E2384040C8D0B1834A344B40
90103	1	13	\N	54803	39564	\N	54.408524	г. Починок, ул. Красноармейская, д.78		0101000020E6100000FDBE7FF3E2384040C8D0B1834A344B40
90102	1	13	\N	54803	39564	\N	54.410050607946502	г. Починок, ул. Красноармейская, д.11		0101000020E61000007497C459113940409758198D7C344B40
90101	1	13	\N	54803	39738	\N	54.408524	г. Починок, ул. Кирова, д.1		0101000020E6100000FDBE7FF3E2384040C8D0B1834A344B40
90421	1	13	\N	7627	39706	\N	54.786166000000001	д.Новые Батеки, ул.Северная, д.20а		0101000020E610000069FCC22B49DA3F40139D6516A1644B40
90419	1	13	\N	45893	39534	\N	54.755971000000002	д.Михновка, ул.Молодежная, д.4		0101000020E6100000DE58501894F53F40BADC60A8C3604B40
90280	1	13	\N	54828	39890	\N	54.805771160494103	Смоленская область, город Смоленск, Заднепровский район, МБОУ СОШ №5, поселок Красный Бор, дом 5	Россия, Смоленская область, Смоленск, поселок Красный Бор, Станционный переулок	0101000020E61000000917F2086EE83F4059880E8123674B40
89801	1	13	\N	52446	\N	\N	61.858449999999998	д.Заозерье, Помещение Администрации Заозерского с\\п	Россия, республика Карелия, поселок Заозерье	0101000020E610000090F8156BB830414027A089B0E1ED4E40
89872	1	13	\N	54797	\N	\N	54.576976000000002	д.Ельня, Ельнинский Дом культуры		0101000020E610000097900F7A36974040D8497D59DA494B40
89984	1	13	\N	54797	39611	\N	54.576976000000002	г. Ельня, мкр. Кутузовский, д. 22		0101000020E610000097900F7A36974040D8497D59DA494B40
89983	1	13	\N	54797	39607	\N	54.576976000000002	г. Ельня, ул. Смоленский большак, д. 8		0101000020E610000097900F7A36974040D8497D59DA494B40
89980	1	13	\N	54797	39655	\N	54.576976000000002	г. Ельня, ул. Пролетарская, д. 46		0101000020E610000097900F7A36974040D8497D59DA494B40
89982	1	13	\N	54797	39874	\N	54.576976000000002	г. Ельня, ул. Ленина, д. 46		0101000020E610000097900F7A36974040D8497D59DA494B40
89981	1	13	\N	54797	39535	\N	54.576976000000002	г. Ельня, ул. Кировская, д. 1		0101000020E610000097900F7A36974040D8497D59DA494B40
89960	1	13	\N	54802	39732	\N	55.195416000000002	"г.Духовщина, ул.Смоленская, д.60 (МУК ""Кинотеатр Заря"")"		0101000020E6100000D5CBEF3499334040BD8E386403994B40
89133	1	13	\N	54798	39538	\N	54.912092000000001	г.Дорогобуж, Седова, 4		0101000020E61000008AC745B588A84040BC783F6EBF744B40
89953	1	13	\N	54798	39735	\N	54.912092000000001	г.Дорогобуж, Пушкина, 9		0101000020E61000008AC745B588A84040BC783F6EBF744B40
89597	1	13	\N	54798	39698	\N	54.921486092830101	г.Дорогобуж, Путенкова, 9		0101000020E6100000145B41D312A7404066DCD440F3754B40
89521	1	13	\N	54798	39698	\N	54.912092000000001	г.Дорогобуж, Путенкова, 7		0101000020E61000008AC745B588A84040BC783F6EBF744B40
89936	1	13	\N	54795	39554	\N	54.151891999999997	"г. Десногорск, 4 микрорайон, Здание МУ ""ЦДБ"""		0101000020E6100000D238D4EFC2A440401343723271134B40
89935	1	13	\N	54795	39554	\N	54.151891999999997	г. Десногорск, 4 микрорайон, Здание ЦИСО		0101000020E6100000D238D4EFC2A440401343723271134B40
89931	1	13	\N	54795	39554	\N	54.155779602102498	г. Десногорск, 4 микрорайон, Здание РО и ДЦ	Россия, Смоленская область, Рославльский район, Десногорск	0101000020E6100000365B79C9FFA4404079AF5A99F0134B40
89932	1	13	\N	54795	39532	\N	54.151891999999997	"г.  Десногорск, 3 микрорайон, Здание МОУ ""СОШ №4"" г. Десногорска"		0101000020E6100000D238D4EFC2A440401343723271134B40
89930	1	13	\N	54795	39729	\N	54.151891999999997	"г.  Десногорск, 2 микрорайон, Здание МОУ ""СОШ №2"" г. Десногорска"		0101000020E6100000D238D4EFC2A440401343723271134B40
89926	1	13	\N	54795	39786	\N	54.151891999999997	г. Десногорск, 1 микрорайон, Десногорский энергетический колледж		0101000020E6100000D238D4EFC2A440401343723271134B40
89927	1	13	\N	54795	39787	\N	54.151891999999997	"г. Десногорск, 1 микрорайон, Здание МУ ""ГЦД"" г. Десногорска"		0101000020E6100000D238D4EFC2A440401343723271134B40
89906	1	13	\N	54796	39669	\N	55.26643	г.Демидов, Суворовский проезд, д.7 здание Демидовского ДК		0101000020E61000004E25034015873F402E56D4601AA24B40
89907	1	13	\N	54796	39533	\N	55.26643	г.Демидов, ул.Советская, д.25 А здание техникума		0101000020E61000004E25034015873F402E56D4601AA24B40
89908	1	13	\N	54796	39727	\N	55.26643	г.Демидов, ул.Октябрьская, д.9 здание МБОУ СОШ №2		0101000020E61000004E25034015873F402E56D4601AA24B40
89905	1	13	\N	54796	39728	\N	55.26643	г.Демидов, ул.Вакарина, д.10  здание МОУ СОШ №1		0101000020E61000004E25034015873F402E56D4601AA24B40
90404	1	13	\N	54812	\N	\N	54.833949131506998	п.Гедеоновка, административный корпус ОГОУЗ областной клинической, психиатрической больницы	Россия, Смоленская область	0101000020E61000001E520C906812404015C440D7BE6A4B40
89867	1	13	\N	54801	39725	\N	55.550967	"г.Гагарин, ул.Строителей, д.50 (социальный приют ""Яуза"")"		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89860	1	13	\N	54801	39827	\N	55.543329882138401	г.Гагарин, ул.Советская, д.5 (педагогический колледж)		0101000020E61000004B22FB20CB804140C47762D68BC54B40
89865	1	13	\N	54801	39880	\N	55.550967	"г.Гагарин, проезд Первомайский, д.1 (МУП ""Управление ЖКХиС"")"		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89864	1	13	\N	54801	39550	\N	55.550967	г.Гагарин, ул.П.Алексеева, д.2 (МСОШ № 2)		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89868	1	13	\N	54801	40009	\N	55.550967	"г.Гагарин, ул.Молодежная, д.1 (ЗАО ""Гагаринконсервмолоко"")"		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89859	1	13	\N	54801	39818	\N	55.550967	г.Гагарин, ул.Ленина, д.73 (аграрно-эконом. колледж)		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89858	1	13	\N	54801	39818	\N	55.554375572519902	г.Гагарин, ул.Ленина, д.14 (МСОШ № 1)	Россия, Смоленская область, Гагаринский район, Гагарин	0101000020E610000074EE76BD347F4140F9D7F2CAF5C64B40
89869	1	13	\N	54801	39665	\N	55.550967	г.Гагарин, ул.Гагарина, д.87 (МСОШ № 4)		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89863	1	13	\N	54801	39665	\N	55.550967	г.Гагарин, ул.Гагарина, д.8 (адм. здание РАЙПО)		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89861	1	13	\N	54801	39665	\N	55.558072992587398	"г.Гагарин, ул.Гагарина, д.62 (МКДЦ ""Комсомолец"")"	Россия, Смоленская область, Гагаринский район, Гагарин	0101000020E6100000F22895F0847E4140EBE3A1EF6EC74B40
89862	1	13	\N	54801	39710	\N	55.550967	г.Гагарин, ул.Бахтина, д.8 (МСОШ № 3)		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89822	1	13	\N	54793	39666	\N	55.188442000000002	г.Вязьма, ул.Юбилейная, здание МОУ СОШ № 7		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89821	1	13	\N	54793	39666	\N	55.206018255302403	г.Вязьма, ул.Юбилейная, здание подросткового клуба		0101000020E6100000D1E979371628414094313ECC5E9A4B40
89826	1	13	\N	54793	39659	\N	55.216324726305501	г.Вязьма, ул.Строителей, д.18	Россия, Смоленская область, Вяземский район, Вязьма	0101000020E61000009B560A815C2841405227A089B09B4B40
89816	1	13	\N	54793	39783	\N	55.188442000000002	г.Вязьма, ул.Пушкина, д.25		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89828	1	13	\N	54793	39544	\N	55.201404014145098	г.Вязьма, ул.Ползунова, д.9	Россия, Смоленская область, Вяземский район, Вязьма	0101000020E610000027DC2BF3562741404CA4349BC7994B40
89643	1	13	\N	54793	39806	\N	55.207736186602602	г.Вязьма, ул.Покровского, д.2		0101000020E6100000DD79E2395B264140D619DF17979A4B40
89827	1	13	\N	54793	39553	\N	55.205085632844302	г.Вязьма, ул.Плотникова, д.11		0101000020E6100000F965304624284140096F0F42409A4B40
89813	1	13	\N	54793	39553	\N	55.188442000000002	г.Вязьма, ул.Плотникова, д.10		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89820	1	13	\N	54793	39528	\N	55.206116424811	г.Вязьма, ул.Московская, д.14а		0101000020E610000095826E2F6928414057975302629A4B40
89819	1	13	\N	54793	39528	\N	55.188442000000002	г.Вязьма, ул.Московская, д.6а		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89818	1	13	\N	54793	39528	\N	55.1985566612369	г.Вязьма, ул.Московская, д.6	Россия, Смоленская область, Вяземский район, Вязьма	0101000020E61000002B306475AB25414029B2D6506A994B40
89830	1	13	\N	54793	39545	\N	55.220348430245501	г.Вязьма, ул.Ленина, д.67а	Россия, Смоленская область, Вяземский район, Вязьма	0101000020E6100000FBCDC4742128414098DEFE5C349C4B40
89824	1	13	\N	54793	39545	\N	55.222507322441203	г.Вязьма, ул.Ленина, д.77		0101000020E6100000207A522635284140C710001C7B9C4B40
89817	1	13	\N	54793	39545	\N	55.188442000000002	г. Вязьма, ул.Ленина, д.9		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89695	1	13	\N	54793	39545	\N	55.1993421583255	г.Вязьма, ул.Ленина, д.47	Россия, Смоленская область, Вяземский район, Вязьма	0101000020E6100000E0D7481284254140105CE50984994B40
89814	1	13	\N	54793	39875	\N	55.188442000000002	г.Вязьма, ул.Заслонова, д.8		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89811	1	13	\N	54793	39811	\N	55.188442000000002	г.Вязьма, пер.Загородный, д.23		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89815	1	13	\N	54793	39625	\N	55.188442000000002	г.Вязьма, ул.Докучаева, д.2		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89812	1	13	\N	54793	39810	\N	55.188442000000002	г.Вязьма, ул.25 Октября, д.21		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89810	1	13	\N	54793	39810	\N	55.188442000000002	г.Вязьма, ул.25 Октября, д.3а		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89829	1	13	\N	54793	40247	\N	55.188442000000002	г.Вязьма, ул.Ленина, д.75		0101000020E6100000EA40D653AB254140AF9811DE1E984B40
89807	1	13	\N	54799	39703	\N	55.6115912966618	г.Велиж, ул.Советская, 11 А	Россия, Смоленская область, Велижский район, Велиж	0101000020E6100000F73AA92F4B333F4093C3279D48CE4B40
89809	1	13	\N	54799	39539	\N	55.609065000000001	г.Велиж, ул.Недоговорова, 15		0101000020E610000090A0F831E62E3F40B21188D7F5CD4B40
89937	1	13	\N	54841	\N	\N	54.740192587277797	с.Алексино, Здание администрации Алексинского с/п		0101000020E61000000ABE69FAECFC3F4033DDEBA4BE5E4B40
90548	1	13	987	13395	39885	\N	55.060945226029403	г.Ярцево, ул.Чайковского, д.11, Ярцевский спортивный комплекс	Россия, Смоленская область, Ярцевский район, Ярцево	0101000020E610000020CF2EDFFA58404067EDB60BCD874B40
90565	1	13	987	13395	39878	\N	55.054836000000002	"г.Ярцево, ул.Советская, д.24а, МБОУДОД ""Ярцевская ДЮСШ"""		0101000020E61000000D7217618A5840405D52B5DD04874B40
90544	1	13	987	13395	39869	\N	55.054836000000002	г.Ярцево, ул.Ленинская, д.15, Детская школа искусств		0101000020E61000000D7217618A5840405D52B5DD04874B40
90583	1	13	987	15281	9766	\N	55.095763235953797	д.Суетово, ул.Магистральная, д.4,  Администрация сельс.поселения	Россия, Смоленская область, Ярцевский район, поселок Суетово	0101000020E610000016DD7A4D0F7440405B9544F6418C4B40
89876	1	13	987	13017	\N	\N	55.110233999999998	с.Самуйлово, здание начальной школы	Россия, Смоленская область, Ярцевский район, поселок Самуйлово	0101000020E610000037C478CDAB5040402174D0251C8E4B40
90582	1	13	987	40398	40221	\N	55.405777	д.Репино, пер.Центральный, д.3,  Администрация сельс.поселения		0101000020E61000000AD7A3703D704040083C3080F0B34B40
89881	1	13	987	48887	\N	\N	55.155164999999997	д.Потапово, Потаповский Дом культуры		0101000020E61000008E5A61FA5E4D4040EE3D5C72DC934B40
90581	1	13	987	15152	40019	\N	54.991315	д.Подроща, пер.Центральный, д.3,  Администрация сельс.поселения		0101000020E61000006C3D4338664F40406284F068E37E4B40
90579	1	13	987	54879	75055	\N	55.021576000000003	д.Петрово, ул.Парковая, д.2,  Администрация сельс.поселения		0101000020E610000064778192026D404073309B00C3824B40
90580	1	13	987	49055	40219	\N	55.042695000000002	д.Ольхово, ул.Школьная, д.2, Ольховский фил.Засижьевск.СОШ		0101000020E6100000F279C5538F644040F3599E0777854B40
90578	1	13	987	15015	40033	\N	55.059905000000001	д.Мушковичи, ул.Школьная, д.8, Мушковичск.основная общеобр.шк		0101000020E6100000957F2DAF5C414040F6EE8FF7AA874B40
90577	1	13	987	54813	39701	\N	55.089520999999998	д.Михейково, ул.Советская, д.2,  Администрация сельс.поселения	Россия, Смоленская область, Ярцевский район, поселок Михейково	0101000020E6100000EBFD463B6E56404011A7936C758B4B40
90576	1	13	987	14927	40101	\N	55.388623930173203	д.Мирополье, ул.Победы, д.3, здание Миропольского СДК	Россия, Смоленская область, Ярцевский район, поселок Мирополье	0101000020E610000024473A03237B40406938656EBEB14B40
90575	1	13	987	48958	75021	\N	55.414993505981897	д Львово, Марковский сельский клуб, ул.Школьная, д.40		0101000020E6100000E90AB6114F604040A304FD851EB54B40
90574	1	13	987	48953	40104	\N	55.290756999999999	д.Кротово, ул.Школьная, д.12, Администрация сельс.поселения		0101000020E6100000A8A78FC01F544040A20A7F8637A54B40
90573	1	13	987	14822	39687	\N	55.223889	д.Капыревщина, ул.Школьная, д.4, Капыревщинск. общеобраз.ср.шк		0101000020E6100000D6027B4CA46E404092770E65A89C4B40
90263	1	13	987	47460	\N	\N	55.073380999999998	д.Вышегор, здание Вышегорского сельского дома культуры	Россия, Смоленская область, Ярцевский район, поселок Вышегор	0101000020E610000013807F4A95684040EA92718C64894B40
90133	1	13	1216	25558	\N	\N	53.928407999999997	дер. Яново, Здание филиала начальных классов рябцевской школы, д.69		0101000020E6100000B323D5777E3D404021ACC612D6F64A40
90530	1	13	1216	12734	39769	\N	53.857236	п.Шумячи, ул.Советская, д.109, помещение районного ДК		0101000020E61000000DC347C494364040187AC4E8B9ED4A40
90529	1	13	1216	12734	39769	\N	53.859519334538703	"п.Шумячи, ул.Советская, д.75, помещение кинотеатра ""Юность"""	Россия, Смоленская область, Шумячский район, поселок Шумячи	0101000020E61000005BEB8B84B636404033A5F5B704EE4A40
90539	1	13	1216	48347	\N	\N	53.877507999999999	д.Студенец, д.136, помещение Администрации		0101000020E61000002881CD39780A40403BFDA02E52F04A40
90533	1	13	1216	48229	40283	\N	53.931668000000002	д.Снегиревка, ул.Молодежная, д.1, помещение Снегиревского СДК		0101000020E61000004BE48233F82F4040685DA3E540F74A40
90537	1	13	1216	48298	\N	\N	53.859105999999997	с.Русское, д.186, помещение Администрации		0101000020E61000009C86A8C29F21404010E6762FF7ED4A40
90531	1	13	1216	54852	40086	\N	53.840538708931703	д.Озерная, ул.Руссковская, д.24, помещение Руссковской школы	Россия, Смоленская область, Шумячский район, поселок Руссковский	0101000020E6100000B612BA4BE23240409B012EC896EB4A40
90535	1	13	1216	13018	\N	\N	53.987918000000001	д.Починичи, д.13, помещение Починичского СДК		0101000020E610000033DC80CF0F2140409B90D61874FE4A40
90540	1	13	1216	54834	39949	\N	53.795557659343302	ст.Понятовка, ул.Первомайская, д.6, помещение Администрации	Россия, Смоленская область, Шумячский район, поселок Понятовка	0101000020E6100000A41CCC26C03C40401C0934D8D4E54A40
90538	1	13	1216	13119	\N	\N	53.977719999999998	д.Петровичи, д.90, помещение Петровичской школы		0101000020E61000005CE7DF2EFB1340409352D0ED25FD4A40
90534	1	13	1216	12935	\N	\N	53.963166000000001	д.Новое Заселье, д.2, помещение Ново-Засельской школ		0101000020E6100000FA62EFC517314040404F030649FB4A40
90541	1	13	1216	13302	\N	\N	53.857565999999998	д.Надейковичи, д.77, помещение Администрации		0101000020E6100000E8323509DEEC3F40AD1402B9C4ED4A40
90113	1	13	1216	24634	\N	\N	53.858691999999998	дер. Лысовка, Здание администрации поселения, д.45	Россия, Смоленская область, Шумячский район, поселок Лысовка	0101000020E6100000A182C30B223A40401DAB949EE9ED4A40
90516	1	13	1216	12113	\N	\N	53.859977000000001	д.Криволес, д.8, помещение Криволесского СДК		0101000020E610000095F430B43A494040F627F1B913EE4A40
90542	1	13	1216	13309	\N	\N	53.792065999999998	д.Зимонино, д.43, помещение Зимонинского СДК		0101000020E610000049861C5BCFE03F4003232F6B62E54A40
90266	1	13	1216	47527	\N	\N	53.78839	д.Зимницы, здание Зимницкого сельского дома культуры	Россия, Смоленская область, Шумячский район, поселок Зимницы	0101000020E61000002063EE5A42364040293FA9F6E9E44A40
90309	1	13	1216	15291	\N	\N	53.904108999999998	д. Гневково, помещение Гневковского сельского Дома культуры (д. 28)	Россия, Смоленская область, Шумячский район, поселок Гневково	0101000020E6100000E60297C79A4140407782FDD7B9F34A40
90532	1	13	1216	48196	\N	\N	53.955596	д.Балахоновка, д.66, помещение Балахоновской школы		0101000020E610000026E2ADF36F2940401E1840F850FA4A40
89996	1	13	7242	52876	\N	\N	57.739272999999997	д. Малое Павлово, помещение Администрации Малышевского сельского поселения	Россия, Нижегородская область, Шахунский район, село Малое Павлово	0101000020E6100000DA39CD02ED4847406CE8667FA0DE4C40
89857	1	13	1213	48477	75090	\N	55.634456	д.Юшково, ул.Школьная, д.3		0101000020E610000097C62FBC92A840402060ADDA35D14B40
90526	1	13	1213	12603	39864	\N	55.510181000000003	пгт.Холм-Жирковский, ул.Старшины Сорокина, д.21, здание ЦРБ		0101000020E61000009626A5A0DBBD404032056B9C4DC14B40
90528	1	13	1213	12603	39865	\N	55.510181000000003	пгт.Холм-Жирковский, ул.Советская, д.13А, здание Холмовской СШ		0101000020E61000009626A5A0DBBD404032056B9C4DC14B40
90527	1	13	1213	12603	39591	\N	55.510181000000003	пгт.Холм-Жирковский, ул.Нахимовская, д.2, здание Дома культуры		0101000020E61000009626A5A0DBBD404032056B9C4DC14B40
90523	1	13	1213	48013	40215	\N	55.447014000000003	д.Стешино, ул.Центральная, д.33, здание администрации с/п		0101000020E6100000C6F7C5A52AC94040556D37C137B94B40
90522	1	13	1213	12400	40185	\N	55.432147999999998	д.Пигулино, ул.Грибоедова, д.98А, здание администрации с/п		0101000020E610000070438CD7BCDE404012842BA050B74B40
90521	1	13	1213	12353	40100	\N	55.632280999999999	д.Печатники, ул.Школьная, д.9, здание Дома культуры		0101000020E610000023A12DE752B24040EB707495EED04B40
89991	1	13	1213	60524	\N	\N	55.435623255955797	д. Новоспасское, помещение Новоспасского сельского Дома культуры	Россия, Смоленская область, Холм-Жирковский район, поселок Новоспасское	0101000020E610000007280D350ABD40405531957EC2B74B40
90520	1	13	1213	54864	40156	\N	55.616548999999999	ст.Никитинка, ул.Базарная, д.24, здание администрации с/п		0101000020E610000029CB10C7BAA24040D5B0DF13EBCE4B40
90519	1	13	1213	47941	\N	\N	55.528564000000003	с.Нахимовское, ул.Волочковская, д.2, здание администрации с/п	Россия, Смоленская область, Холм-Жирковский район, поселок Нахимовское	0101000020E61000006B0DA5F622E24040E6EB32FCA7C34B40
90518	1	13	1213	12256	40282	\N	55.547051000000003	д.Лехмино, пер.Центральный, д.2, здание администрации с/п		0101000020E610000024F1F274AEB240403F1F65C405C64B40
90443	1	13	1213	40461	\N	\N	55.628039999999999	д.Караваево, помещение Дома культуры	Россия, Смоленская область, Холм-Жирковский район, поселок Караваево	0101000020E610000076AA7CCF48B64040384A5E9D63D04B40
90085	1	13	1213	40461	\N	\N	55.627991000000002	д.Караваево, МОУ Караваевская начальная школа - детский сад	Россия, Смоленская область, Холм-Жирковский район, поселок Караваево	0101000020E6100000C6A2E9EC64B640405797530262D04B40
90517	1	13	1213	54882	40216	\N	55.5336900124274	ст.Канютино, ул.Железнодорожная, д.15, здание администрации с/п	Россия, Смоленская область, Холм-Жирковский район, поселок Канютино	0101000020E6100000C2887D0228A04040E31934F44FC44B40
90515	1	13	1213	54825	39866	\N	55.456570999999997	"ст.Игоревская, ул.Южная, д.4, здание КСК ""Модуль"""		0101000020E610000080B74082E2A54040A8A624EB70BA4B40
89888	1	13	1213	40324	\N	\N	55.568405424952203	д.Ивашково, Ивашковский Дом культуры	Россия, Смоленская область, Холм-Жирковский район, поселок Ивашково	0101000020E610000029E8F692C6BA404002F1BA7EC1C84B40
90572	1	13	1213	48920	75070	\N	55.591985999999999	д.Зайцево, ул.Центральная, д.19, здание Зайцевского СДК		0101000020E6100000D9EC48F59DDB40404DD87E32C6CB4B40
90525	1	13	1213	54849	40071	\N	55.6949561684185	ст.Владимирский Тупик, ул.Железнодорожная, д.29, здание Дома культуры		0101000020E6100000E00F3FFF3DA8404059147651F4D84B40
90524	1	13	1213	60530	75186	\N	55.500701346634102	д.Верховье, ул.Новая, д.7, здание Дома культуры	Россия, Смоленская область, Холм-Жирковский район, поселок Верховье	0101000020E6100000B4AD669DF183404089096AF816C04B40
90514	1	13	1213	12056	\N	\N	55.576070000000001	д.Болышево, ул.Центральная, д.5, здание администрации с/п	Россия, Смоленская область, Холм-Жирковский район, поселок Болышево	0101000020E610000005A73E90BCCB4040761A69A9BCC94B40
90513	1	13	1213	47823	39948	\N	55.502803	с.Боголюбово, ул.Центральная, д.3, здание администрации с/п		0101000020E6100000003961C2687A404054AA44D95BC04B40
90512	1	13	1213	47802	40677	\N	55.563792986041797	с.Батурино, ул.Лесная, д.1, здание администрации с/п	Россия, Смоленская область, Холм-Жирковский район, поселок Батурино	0101000020E6100000FD868906296640405B5B785E2AC84B40
90511	1	13	1213	11896	40214	\N	55.409900999999998	д.Агибалово, ул.Черемушки, д.5, здание администрации с/п		0101000020E6100000C61858C7F1C1404081CCCEA277B44B40
90509	1	13	883	11780	\N	\N	54.251327000000003	Смоленская область, Хиславичский район, д.Черепово, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Черепово	0101000020E6100000AB59677C5F20404008CDAE7B2B204B40
90490	1	13	883	10876	39767	\N	54.195540000000001	Смоленская область, Хиславичский район, п.Хиславичи, ул.Советская, д.32		0101000020E61000000DA7CCCD37144040A987687407194B40
90493	1	13	883	10876	40322	\N	54.210695127058898	Смоленская область, Хиславичский район, п.Фролово, ул.Северная, д.3	Россия, Смоленская область, Хиславичский район, поселок Хиславичи	0101000020E61000003F19E3C3EC1540402237C30DF81A4B40
90491	1	13	883	10876	39674	\N	54.195540000000001	Смоленская область, Хиславичский район, п.Хиславичи, пер.Пушкина, д.15		0101000020E61000000DA7CCCD37144040A987687407194B40
90492	1	13	883	10876	40152	\N	54.195540000000001	"Смоленская область, Хиславичский район, п.Хиславичи, ул.Берестнева, здание детского сада ""Ленок"""		0101000020E61000000DA7CCCD37144040A987687407194B40
90508	1	13	883	11721	\N	\N	54.254009000000003	Смоленская область, Хиславичский район, д.Упино, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Упино	0101000020E61000006E4F90D8EE0A4040E1F1ED5D83204B40
90507	1	13	883	11714	\N	\N	53.971493000000002	Смоленская область, Хиславичский район, д.Соино, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Соино	0101000020E610000003B00111E2FE3F407FA5F3E159FC4A40
90504	1	13	883	11566	\N	\N	54.119861	Смоленская область, Хиславичский район, д.Печерская Буда, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Печерская Буда	0101000020E6100000CB4BFE277F2540406E88F19A570F4B40
90345	1	13	883	6702	39847	\N	54.153036	с.Печерск, ул.Школьная, д.1а		0101000020E6100000A73B4F3C672140402A8E03AF96134B40
90505	1	13	883	11572	\N	\N	54.080950999999999	Смоленская область, Хиславичский район, д.Петрополье, Здание ФАП	Россия, Смоленская область, Хиславичский район, поселок Петрополье	0101000020E610000004543882543240400CCA349A5C0A4B40
90510	1	13	883	11839	\N	\N	54.207031999999998	Смоленская область, Хиславичский район, д.Новая Рудня, Здание ФАБ	Россия, Смоленская область, Хиславичский район, поселок Новая Рудня	0101000020E6100000A5846055BD2C4040DC9C4A06801A4B40
90053	1	13	883	47822	75177	\N	54.207411	д. Николаевка, ул. Октябрьская, д.12		0101000020E61000001D90847D3B1F404053EA92718C1A4B40
90503	1	13	883	11475	\N	\N	54.059013	Смоленская область, Хиславичский район, д.Микшино, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Микшино	0101000020E6100000471FF30181164040F984ECBC8D074B40
90108	1	13	883	24423	\N	\N	54.179619000000002	дер. Красиловка, Здание красиловского ФАПа, д.26		0101000020E610000033DC80CF0F374040C05E61C1FD164B40
90502	1	13	883	11471	\N	\N	54.194960999999999	Смоленская область, Хиславичский район, д.Корзово, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Корзово	0101000020E6100000DDD1FF722D1040406B7F677BF4184B40
90506	1	13	883	11655	\N	\N	54.166094999999999	Смоленская область, Хиславичский район, д.Козловка, Здание ФАП	Россия, Смоленская область, Хиславичский район, поселок Козловка	0101000020E61000004E452A8C2D344040BA83D89942154B40
90499	1	13	883	11322	\N	\N	54.081738000000001	Смоленская область, Хиславичский район, д.Клюкино, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Клюкино	0101000020E610000045DAC69FA8F43F40946B0A64760A4B40
90497	1	13	883	11226	\N	\N	54.083253999999997	Смоленская область, Хиславичский район, д.Иозефовка, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Йозефовка	0101000020E610000062F4DC42570A40406EA12B11A80A4B40
90496	1	13	883	11148	\N	\N	54.019950000000001	Смоленская область, Хиславичский район, д.Жанвиль, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Жанвиль	0101000020E6100000E162450DA6E53F4011C7BAB88D024B40
90495	1	13	883	11140	\N	\N	54.076281000000002	Смоленская область, Хиславичский район, д.Городище, Здание средней школы	Россия, Смоленская область, Хиславичский район, поселок Городище	0101000020E61000006138D73043FF3F4031276893C3094B40
90494	1	13	883	11055	\N	\N	54.178733000000001	Смоленская область, Хиславичский район, д.Владимировка, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Владимировка	0101000020E61000001536035C901D4040A5DB12B9E0164B40
90498	1	13	883	11233	\N	\N	54.147742000000001	Смоленская область, Хиславичский район, д.Братковая, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Братковая	0101000020E6100000DFE2E13D07044040711FB935E9124B40
90500	1	13	883	11340	\N	\N	54.124563000000002	Смоленская область, Хиславичский район, д.Большие Хутора, Здание сельской администрации	Россия, Смоленская область, Хиславичский район, поселок Большая Хутора	0101000020E610000045B75ED383DE3F4055A52DAEF10F4B40
90207	1	13	1127	46322	\N	\N	54.595471000000003	д. Шилово, Здание ФАП	Россия, Смоленская область, Угранский район, поселок Шилово	0101000020E61000007C7DAD4B8DEC4040B45BCB64384C4B40
90487	1	13	1127	60514	\N	\N	54.588512000000001	д.Холмы, помещение администрации Холмовского сельского поселения	Россия, Смоленская область, Угранский район, поселок Холмы	0101000020E6100000C0CFB87020F04040DBA6785C544B4B40
90489	1	13	1127	47370	39673	\N	54.777982999999999	п.Угра, Советская, 28		0101000020E610000022C495B3772A414007EC6AF294634B40
90488	1	13	1127	47370	39859	\N	54.777982999999999	п.Угра, Мира, 32		0101000020E610000022C495B3772A414007EC6AF294634B40
90485	1	13	1127	54872	\N	\N	54.860069765914801	д.Слободка, помещение администрации Слободского сельского поселения	Россия, Смоленская область, Угранский район, поселок Слободка	0101000020E6100000B6D95889796C4140A72215C6166E4B40
90483	1	13	1127	52725	\N	\N	54.739721000000003	д.Полднево, помещение администрации Полдневского сельского поселения	Россия, Смоленская область, Угранский район, поселок Полднево	0101000020E6100000EFACDD76A10741400C957F2DAF5E4B40
90482	1	13	1127	52719	\N	\N	54.774701	д.Подсосонки, помещение администрации Подсосонского сельского поселения	Россия, Смоленская область, Угранский район, поселок Подсосонки	0101000020E61000007995B54DF15A4140D996016729634B40
90479	1	13	1127	54863	\N	\N	54.583540930419403	п.Ново-Милятино, помещение Ново-Милятинского сельского клуба	Россия, Смоленская область, Угранский район, поселок Новомилятино	0101000020E610000085EE92382B2841400470B378B14A4B40
90481	1	13	1127	54867	\N	\N	54.7994518257631	д.Мытишино, помещение администрации Мытишинского сельского поселения	Россия, Смоленская область, Угранский район, поселок Мытыщино	0101000020E610000073A25D8594014140645C717154664B40
90480	1	13	1127	54881	\N	\N	54.913003059657299	д.Михали, помещение администрации Михалевского сельского поселения	Россия, Смоленская область, Угранский район, поселок Михали	0101000020E6100000734C16F71F2D414030134548DD744B40
90477	1	13	1127	47131	\N	\N	54.910136000000001	с.Знаменка, помещение администрации Знаменского сельского поселения	Россия, Смоленская область, Угранский район, поселок Знаменка	0101000020E6100000D95E0B7A6F4A4140C57421567F744B40
90475	1	13	1127	52697	\N	\N	54.847907999999997	д.Желанья, помещение администрации Желаньинского сельского поселения	Россия, Смоленская область, Угранский район, поселок Желанья	0101000020E6100000B98E71C5C54141402502D53F886C4B40
90474	1	13	1127	52695	\N	\N	55.006042999999998	д.Дрожжино, помещение администрации Дрожжинского сельского поселения	Россия, Смоленская область, Угранский район, поселок Дрожжино	0101000020E61000003F1F65C40550414053AF5B04C6804B40
90473	1	13	1127	47062	\N	\N	54.671169999999996	с.Всходы, помещение администрации Всходского сельского поселения	Россия, Смоленская область, Угранский район, поселок Всходы	0101000020E6100000B2497EC4AF0C4140350708E6E8554B40
90472	1	13	1127	60486	\N	\N	54.948892000000001	д.Вешки, помещение администрации Вешковского сельского поселения	Россия, Смоленская область, Угранский район, поселок Вешки	0101000020E61000004EB51666A1394140D0B7054B75794B40
90471	1	13	1127	52688	\N	\N	54.882933999999999	д.Великополье, помещение администрации Великопольевского сельского поселени	Россия, Смоленская область, Угранский район, поселок Великополье	0101000020E61000007E6E68CA4E3D4140634337FB03714B40
90476	1	13	1127	54862	\N	\N	54.695718556176303	д.Захарьевское, помещение администрации Захарьевского сельского поселения	Россия, Смоленская область, Угранский район, поселок Большое Захарьевское	0101000020E6100000B890477023ED4040581AF8510D594B40
90478	1	13	1127	10342	\N	\N	54.614286	с.Баскаковка, помещение администрации Ключиковского сельского поселения	Россия, Смоленская область, Угранский район, поселок Баскаковка	0101000020E6100000A60BB1FA232C4140013274ECA04E4B40
90470	1	13	1127	52680	\N	\N	54.588309000000002	д. Арнишицы, помещение администрации Арнишицкого сельского поселения	Россия, Смоленская область, Угранский район, поселок Арнишицы	0101000020E6100000B96C74CE4F094140A37895B54D4B4B40
90451	1	13	3320	52623	\N	\N	57.183753000000003	д.Соколино, помещение МОУ Соколинская основная школа	Россия, Тверская область, Торжокский район, поселок Соколино	0101000020E6100000E5F21FD26F5741405DC5E23785974C40
90463	1	13	1064	9576	\N	\N	55.0827616066423	с. Темкино, помещение Администрации Темкинского сельского поселения	Россия, Смоленская область, Темкинский район, поселок Темкино	0101000020E6100000C808A8700481414000ADF9F1978A4B40
90468	1	13	1064	9809	40242	\N	55.117164000000002	Смоленская область, Темкинский район, д.Селенки, ул.Центральная, д.20		0101000020E61000006F4A79AD847041406022DE3AFF8E4B40
90271	1	13	1064	49129	\N	\N	54.9941250876604	д.Прудки, здание Администрации Прудковского сельского поселения	Россия, Смоленская область, Темкинский район, поселок Прудки	0101000020E6100000880D164ED26841406891ED7C3F7F4B40
90126	1	13	1064	49129	75056	\N	54.99447	дер. Прудки, ул. Центральная, д.18		0101000020E61000004F20EC14AB684140336DFFCA4A7F4B40
90222	1	13	1064	46638	\N	\N	55.044789000000002	с. Понизовье, Здание администрации с/п		0101000020E61000006A15FDA1996741403B1C5DA5BB854B40
90459	1	13	1064	9361	40120	\N	55.226790000000001	Смоленская область, Темкинский район, д.Нарытка, ул.Возрождения, д.13		0101000020E6100000BFD364C6DB664140A9876874079D4B40
90465	1	13	1064	15584	\N	\N	55.1076877975541	д. Кикино, помещение Администрации Кикинского сельского поселения	Россия, Смоленская область, Темкинский район, поселок Кикино	0101000020E61000003E0455A357654140F9156BB8C88D4B40
90462	1	13	1064	15506	\N	\N	54.979298999999997	д. Замыцкое, помещение Администрации Вязищенского сельского поселения	Россия, Смоленская область, Темкинский район, поселок Замыцкое	0101000020E6100000A2B77878CF7D4140B4006DAB597D4B40
90464	1	13	1064	15390	\N	\N	55.239100999999998	д. Горки, помещение Администрации Долматовского сельского поселения	Россия, Смоленская область, Темкинский район, поселок Горки	0101000020E610000047AB5AD251A041406FB88FDC9A9E4B40
90466	1	13	1064	9732	40277	\N	55.055646000000003	Смоленская область, Темкинский район, д.Власово, ул.Центральная, д.7		0101000020E6100000F8325184D47741409D137B681F874B40
90262	1	13	1064	9476	\N	\N	55.188478000000003	с.Васильевское, здание Администрации Васильевского сельского поселения		0101000020E61000006AF7AB00DF8F4140FC010F0C20984B40
90046	1	13	382	54853	\N	\N	54.682668999999997	ст. Красное, Здание школы		0101000020E610000001DA56B3CE083F401B7FA2B261574B40
90461	1	13	1064	9476	40278	\N	55.188478000000003	Смоленская область, Темкинский район, д.Васильевское, ул.Молодежная, д.19		0101000020E61000006AF7AB00DF8F4140FC010F0C20984B40
89968	1	13	1064	9743	\N	\N	55.084626	д.Булгаково, ул.Центральная, д.23 (здание Администрации СП)	Россия, Смоленская область, Темкинский район, поселок Булгаково	0101000020E610000046240A2DEB8A414016325706D58A4B40
90467	1	13	1064	9743	39998	\N	55.084626	Смоленская область, Темкинский район, д.Булгаково, ул.Липовая Аллея, д.8		0101000020E610000046240A2DEB8A414016325706D58A4B40
90460	1	13	1064	15446	\N	\N	55.223981999999999	д. Бекрино, помещение Администрации Батюшковского сельского поселения	Россия, Смоленская область, Темкинский район, поселок Бекрино	0101000020E6100000448B6CE7FB83414043723271AB9C4B40
90452	1	13	7207	52629	\N	\N	54.742798000000001	д.Сутормино, помещение МОУ Суторминская основная школа	Россия, Калужская область, Тарусский район, поселок Сутормино	0101000020E6100000ABB2EF8AE093424061C43E01145F4B40
90454	1	13	1051	52637	\N	\N	55.957948000000002	д.Хлепень, помещение администрации Хлепенского с/п	Россия, Смоленская область, Сычевский район, поселок Хлепень	0101000020E61000001A69A9BC1D3B414062A2410A9EFA4B40
90453	1	13	1051	60541	\N	\N	55.743943999999999	д.Софьино, помещение клуба	Россия, Смоленская область, Сычевский район, поселок Софьино	0101000020E6100000CCB392567C4541401807978E39DF4B40
90449	1	13	1051	54880	\N	\N	55.947943000000002	д.Середа, помещение администрации Середского с/п	Россия, Смоленская область, Сычевский район, поселок Середа	0101000020E6100000EDF0D7648D1041406FBC3B3256F94B40
90054	1	13	1051	47845	\N	\N	55.941687000000002	д. Павлово, Здание администрации с/п		0101000020E610000044334FAE29DE4040C0081A3389F84B40
90444	1	13	1051	54886	\N	\N	55.908255741199397	д.Никитье, помещение Дома культуры	Россия, Смоленская область, Сычевский район, поселок Никитье	0101000020E61000003196E99788174140A9328CBB41F44B40
90446	1	13	1051	46515	\N	\N	55.810015	д.Мальцево, ул.Октябрьская, д.14	Россия, Смоленская область, Сычевский район, поселок Мальцево	0101000020E610000007F01648502441407D224F92AEE74B40
90445	1	13	1051	53063	\N	\N	55.784384000000003	д.Лукино, помещение Лукинского сельского Дома культуры	Россия, Смоленская область, Сычевский район, поселок Лукино	0101000020E610000045662E70791A4140BAC0E5B166E44B40
90447	1	13	1051	52609	\N	\N	55.815468000000003	д.Елманово, помещение МОУ Елмановская основная школа	Россия, Смоленская область, Сычевский район, поселок Елманово	0101000020E6100000DF878384282741409F77634161E84B40
90442	1	13	1051	54836	\N	\N	55.6888969402657	д.Дугино, помещение администрации Дугинского с/п	Россия, Смоленская область, Сычевский район, поселок Дугино	0101000020E6100000C04010204319414000A8E2C62DD84B40
90264	1	13	1051	47496	\N	\N	55.872481000000001	д.Дроздово, здание Дроздовского сельского дома культуры		0101000020E61000001D3A3DEFC62E4140D1B01875ADEF4B40
90441	1	13	1051	60544	\N	\N	56.010936000000001	д.Вараксино, помещение администрации Вараксинского с/п	Россия, Смоленская область, Сычевский район, поселок Вараксино	0101000020E61000002FA4C34318234140AE2CD15966014C40
90440	1	13	1051	52600	\N	\N	55.823717000000002	д.Большая Моховатка, помещение администрации Бехтеевского с/п	Россия, Смоленская область, Сычевский район, поселок Большая Моховатка	0101000020E6100000F6D03E56F00D41406214048F6FE94B40
90439	1	13	1051	52597	\N	\N	55.780870999999998	д.Бехтеево, помещение администрации Бехтеевского с/п	Россия, Смоленская область, Сычевский район, поселок Бехтеево	0101000020E61000004968CBB914FD404089B2B794F3E34B40
90450	1	13	7204	52620	\N	\N	53.982199999999999	д.Субботники, помещение администрации Субботниковского с/п	Россия, Калужская область, Сухиничский район, поселок Субботники	0101000020E6100000D65757056AB74140CB10C7BAB8FD4A40
89904	1	13	7210	52636	\N	\N	54.301600000000001	д.Ромоданово, здание Администрации сельского поселения	Россия, Рязанская область, Старожиловский район, поселок Ромоданово	0101000020E6100000747B4963B4E843409F3C2CD49A264B40
90420	1	13	452	7565	40234	\N	54.750675999999999	д.Чекулино, ул.Смоленская, д.2		0101000020E610000008556AF640BB3F4030F2B22616604B40
90417	1	13	452	54843	40029	\N	54.700752000000001	д.Хохлово, ул.Мира, д.12	Россия, Смоленская область, Смоленский район, поселок Хохлово	0101000020E6100000FB90B75CFDD43F40A54DD53DB2594B40
90414	1	13	452	7321	39855	\N	54.653281999999997	с.Талашкино, ул.Ленина, д.7		0101000020E6100000B01F62838517404061889CBE9E534B40
90428	1	13	452	46102	39963	\N	54.782863999999996	д.Сметанино, ул.Озерная, д.1а		0101000020E6100000CBD58F4DF2A33F409D9B36E334644B40
90416	1	13	452	60508	75104	\N	54.546014138503097	д.Санники, ул.Центральная, д.23а	Россия, Смоленская область, Смоленский район, поселок Санники	0101000020E6100000520ABABDA4E53F403E9468C9E3454B40
90424	1	13	452	54842	\N	\N	54.7677075701408	"д.Санаторий Борок, помещение клуба санатория ""Борок"""	Россия, Смоленская область, Смоленский район, поселок Катынь	0101000020E6100000CD57C9C7EEBA3F405470784144624B40
90415	1	13	452	45823	39990	\N	54.626683	д.Русилово, ул.Центральная, д.2		0101000020E61000004CC2853C82F33F40C6FA062637504B40
90406	1	13	452	45653	40095	\N	54.838737000000002	д.Рогачево, ул.Центральная, д.10		0101000020E61000003B51121269154040FB78E8BB5B6B4B40
90409	1	13	452	7028	39671	\N	54.687488000000002	с.Пригорское, ул.Спортивная, д.2		0101000020E61000007C462234821340403C32569BFF574B40
90429	1	13	452	46126	40202	\N	54.801971000000002	д.Почаево, Витебское шоссе, д.7Б		0101000020E61000004A4563EDEF903F4093AB58FCA6664B40
90402	1	13	452	3690	39599	\N	54.850960979537803	с.Печерск, ул.Автодорожная, д.1	Россия, Смоленская область, Смоленский район, поселок Печерск	0101000020E610000012876C205D044040F295404AEC6C4B40
90315	1	13	452	48429	40249	\N	54.846046999999999	д.Ольша, Садовый переулок, д.1а		0101000020E6100000A4C343183FD93F4080F0A1444B6C4B40
89944	1	13	452	16248	\N	\N	55.089238000000002	д.Озерище, Здание Озерищенской средней общеобразовательной школы		0101000020E6100000A304FD851EA53F40BDC799266C8B4B40
90194	1	13	452	46017	\N	\N	54.966225000000001	д.Новоселки, здание администрации Сырокоренского сельского поселения		0101000020E6100000C2DA183BE1F53F40EFC9C342AD7B4B40
90422	1	13	452	7634	40207	\N	54.810631000000001	д.Новое Куприно, ул.Парковая, д.13		0101000020E6100000DB32E02C25B33F40D80FB1C1C2674B40
90423	1	13	452	45998	40035	\N	54.808000999999997	д.Нивищи, ул.Мира, д.10а		0101000020E6100000AF3F89CF9DCC3F405111A7936C674B40
90391	1	13	452	6147	40031	\N	54.958880000000001	д.Мощинки, ул.Лесная, д.9		0101000020E61000002FE065868D084040ED647094BC7A4B40
90413	1	13	452	7229	40209	\N	54.597791999999998	д.Моготово, ул.Школьная, д.8		0101000020E6100000BDC458A65F024040BCE7C072844C4B40
90401	1	13	452	6690	40203	\N	55.024332000000001	д.Мазальцево, ул.Мира, д.3		0101000020E610000094BC3AC7800A4040861F9C4F1D834B40
90405	1	13	452	6876	39852	\N	54.825440999999998	д.Магалинщина, ул.Садовая , д.49		0101000020E6100000D481ACA7560D404086E3F90CA8694B40
90418	1	13	452	7506	39961	\N	54.717120999999999	д.Лубня, ул.Садовая, д.2		0101000020E6100000CC63CDC820E33F402D23F59ECA5B4B40
90437	1	13	452	46318	40237	\N	55.034317000000001	д.Лоино, Колхозный переулок, д.1		0101000020E610000031957EC2D9793F403259DC7F64844B40
89941	1	13	452	45546	\N	\N	54.678035999999999	д.Кузино, Здание Администрации Кузинского с/п	Россия, Смоленская область, Смоленский район, поселок Кузино	0101000020E61000009BE271512D863F405DC136E2C9564B40
90412	1	13	452	7215	39672	\N	54.597583999999998	д.Кощино, ул.Дружбы, д.27		0101000020E6100000361FD7868A174040724EECA17D4C4B40
90425	1	13	452	7759	39652	\N	54.771814701197997	с.Катынь, Витебское шоссе, д.10а		0101000020E6100000D1AFAD9FFEAF3F40F7C77BD5CA624B40
90434	1	13	452	8219	75017	\N	54.988385999999998	с.Каспля, ул.Советская (здание администрации сельского поселения), д.15		0101000020E6100000501A6A1492A03F4081E9B46E837E4B40
90436	1	13	452	54896	40292	\N	54.857864999999997	д.Замощье, ул.Молодежная, д.123	Россия, Смоленская область, Смоленский район, поселок Замощье	0101000020E6100000276A696E85843F4007B13385CE6D4B40
90368	1	13	452	49303	39774	\N	54.900134999999999	д.Жуково, ул.Мира, д.48		0101000020E61000003C2F151BF3024040137EA99F37734B40
90411	1	13	452	7126	\N	\N	54.683616000000001	д.Дрюцк, дом-интернат, корпус №3		0101000020E6100000C22FF5F3A6064040DC82A5BA80574B40
90325	1	13	452	2561	40044	\N	54.858989000000001	д.Дивасы, ул.Мичурина, д.23		0101000020E6100000B16EBC3B32FA3F40D74FFF59F36D4B40
90140	1	13	452	49323	\N	\N	54.608973156820902	дер. Горяны, Здание Дома культуры	Россия, Смоленская область, Смоленский район, поселок Горяны	0101000020E61000006268757286164040D192C7D3F24D4B40
90431	1	13	452	8044	40079	\N	55.048735000000001	д.Вязгино, ул.Мира, д.20		0101000020E610000096E7C1DD59EF3F40D595CFF23C864B40
90427	1	13	452	46062	\N	\N	54.713766999999997	д.Высокий Холм, д.16		0101000020E61000006F46CD57C9733F4065FB90B75C5B4B40
90435	1	13	452	8305	40069	\N	54.919466	д.Волоковая, ул.Центральная, д.9		0101000020E6100000323B8BDEA9903F4058E4D70FB1754B40
90432	1	13	452	60502	75096	\N	54.911168552351597	д.Верховье, ул.Речная, д.2	Россия, Смоленская область, Смоленский район, поселок Верховье	0101000020E610000050A912656FC13F408410902FA1744B40
90408	1	13	452	45688	75085	\N	54.702921000000003	д.Бубново, ул.Почтовая, д.28		0101000020E61000005B40683D7C1F4040F855B950F9594B40
90438	1	13	452	8428	40075	\N	55.118353999999997	д.Бабны, ул.Молодежная, д.20		0101000020E610000036CCD07822903F40E6AC4F39268F4B40
90430	1	13	452	8039	40163	\N	55.058121	д.Аполье, ул.Ефимова, д.1		0101000020E61000007AC2120F28DF3F40FC1A498270874B40
90426	1	13	452	54815	\N	\N	54.760102418260502	п.Авторемзавод, д.19	Россия, Смоленская область, Смоленский район, поселок Катынь	0101000020E6100000008E3D7B2EAF3F40E6CFB7054B614B40
89922	1	13	1173	60470	75062	\N	55.096623444984402	д.Холм, ул.Центральная, д.11 здание МОУ Холмовская №2 ООШ	Россия, Смоленская область, Сафоновский район, поселок Холм	0101000020E61000009AEE75525F8640404D8578245E8C4B40
89989	1	13	1173	53056	\N	\N	55.165148000000002	д. Уварово, помещение Уваровского сельского Дома культуры	Россия, Смоленская область, Сафоновский район, поселок Уварово	0101000020E6100000F29881CAF8DD4040FA7FD59123954B40
90095	1	13	1173	48611	\N	\N	55.118868999999997	д.Татарка, здание МОУ Татаркинская основная общеобразовательная школа	Россия, Смоленская область, Сафоновский район, поселок Татарка	0101000020E6100000AAB8718BF9CF40400DC17119378F4B40
90274	1	13	1173	60535	\N	\N	55.320605999999998	д.Старое Село, здание Администрации Старосельского сельского поселения	Россия, Смоленская область, Сафоновский район, поселок Старое Село	0101000020E61000003CA583F57FE8404060730E9E09A94B40
90403	1	13	1173	45598	40123	\N	55.290224000000002	д.Синьково, ул.Ковалева, д.7		0101000020E6100000984F560C57E54040D5415E0F26A54B40
90258	1	13	1173	16147	\N	\N	55.122199999999999	г.Сафоново, здание школы-интернат	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90239	1	13	1173	16147	\N	\N	55.122199999999999	"г.Сафоново, помещение МБОУ центр развития ребенка - детский сад № 16 ""Золотой ключик"""	Россия, Смоленская область, Сафоновский район, Сафоново	0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90250	1	13	1173	16147	39947	\N	55.122199999999999	г.Сафоново, Калинина, 49		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90251	1	13	1173	16147	39628	\N	55.122199999999999	г.Сафоново, микрорайон ГМП, 18		0101000020E61000009ACDE330989D40401DC9E53FA48F4B40
90273	1	13	1173	32164	\N	\N	55.149310999999997	д.Рыбки, здание МДОУ Рыбковского детского сада	Россия, Смоленская область, Сафоновский район, поселок Рыбки	0101000020E610000000E48409A37D40406EF7729F1C934B40
89837	1	13	1173	11147	\N	\N	55.083060000000003	д.Путьково, здание школы		0101000020E6100000C636A968ACD540408ACDC7B5A18A4B40
90270	1	13	1173	31946	\N	\N	55.237684000000002	д.Николо-Погорелое, здание Администрации Николо-Погореловского сельского поселен	Россия, Смоленская область, Сафоновский район, поселок Николо-Погорелое	0101000020E61000003D27BD6F7CBF40402864E76D6C9E4B40
90078	1	13	1173	22902	39612	\N	55.089562999999998	п.Монастырщина, ул.Революционная, д.36		0101000020E610000098C1189128BC404040F7E5CC768B4B40
90077	1	13	1173	22902	39609	\N	55.089562999999998	п.Монастырщина, ул.1-я Краснинская, д.11		0101000020E610000098C1189128BC404040F7E5CC768B4B40
90043	1	13	382	47641	\N	\N	54.738339000000003	д. Комиссарово, Здание сельского Дома культуры		0101000020E610000088307E1AF7523F40412E71E4815E4B40
90257	1	13	1173	47341	\N	\N	55.152886000000002	д.Мишенино, здание фельдшерско-акушерского пункта	Россия, Смоленская область, Сафоновский район, поселок Мишенино	0101000020E6100000D8666325E6A340401502B9C491934B40
89891	1	13	1173	49066	\N	\N	55.330920999999996	д.Мальцево, администрация сельского поселения		0101000020E6100000919DB7B1D9E14040A1478C9E5BAA4B40
90261	1	13	1173	47423	\N	\N	55.261510999999999	с.Лесное, здание Ново-Тимошинского филиала МОУ Вадинской средней школы		0101000020E61000009D499BAA7B944040AA45443179A14B40
90269	1	13	1173	31888	\N	\N	55.333241000000001	д.Казулино, здание Администрации Казулинского сельского поселения	Россия, Смоленская область, Сафоновский район, поселок Казулино	0101000020E6100000815F234910C44040DA571EA4A7AA4B40
90254	1	13	1173	31164	\N	\N	55.143939000000003	п.Издешково, здание Администрации сельского поселения	Россия, Смоленская область, Сафоновский район, поселок Издешково	0101000020E61000004E637B2DE8CF40403ACFD8976C924B40
90268	1	13	1173	47567	\N	\N	55.075046	"д.Игнатково, Административное здание МУСХП ""Исток"""		0101000020E6100000DA54DD239BD340400AD9791B9B894B40
90265	1	13	1173	31750	\N	\N	55.152686000000003	д.Дурово, здание Администрации Дуровского сельского поселения	Россия, Смоленская область, Сафоновский район, поселок Дурово	0101000020E6100000FCC7427408AC40404E4700378B934B40
90081	1	13	1173	60476	\N	\N	55.0660693463931	"с.Высокое, здание МКОУ ""Высоковская СОШ"""		0101000020E6100000908653E6E6A34040C423F1F274884B40
89998	1	13	1173	60476	\N	\N	55.063628999999999	д. Высокое, помещение МБОУ Высоковской основной школы	Россия, Смоленская область, Сафоновский район, поселок Высокое	0101000020E6100000804A95287BA34040E109BDFE24884B40
90260	1	13	1173	31474	\N	\N	55.259284000000001	п.Вадино, здание Администрации Вадинского сельского поселения	Россия, Смоленская область, Сафоновский район, поселок Вадино	0101000020E61000008E06F01648A040402330D63730A14B40
90259	1	13	1173	47401	\N	\N	55.274923999999999	д.Богдановщина, здание Администрации Богдановщинского сельского поселения	Россия, Смоленская область, Сафоновский район, поселок Богдановщина	0101000020E6100000CBF44BC45BD540405871AAB530A34B40
90256	1	13	1173	31312	\N	\N	55.219873999999997	д.Беленино, здание Администрации Беленинского сельского поселения	Россия, Смоленская область, Сафоновский район, поселок Беленино	0101000020E6100000499F56D11FAA4040CF9ECBD4249C4B40
90267	1	13	1173	47543	\N	\N	55.157736999999997	п.Алферово, здание Администрации Зимницкого сельского поселения		0101000020E610000043A9BD88B6E34040402FDCB930944B40
90210	1	13	170	29114	\N	\N	54.873905999999998	д. Шубки, Здание медицинского пункта	Россия, Смоленская область, Руднянский район, поселок Шубки	0101000020E6100000DF1797AAB40D3F409BE3DC26DC6F4B40
90220	1	13	170	29554	\N	\N	54.949539000000001	д. Чистик, Здание дома культуры	Россия, Смоленская область, Руднянский район, поселок Чистик	0101000020E61000003082C64CA2323F4066A3737E8A794B40
90226	1	13	170	46693	\N	\N	55.204849000000003	д. Узгорки, Здание медицинского пункта	Россия, Смоленская область, Руднянский район, поселок Узгорки	0101000020E6100000A19E3E027F003F4025CFF57D389A4B40
90204	1	13	170	28843	\N	\N	54.902082	д. Суфляново, Здание административного помещения	Россия, Смоленская область, Руднянский район, поселок Суфляново	0101000020E610000095D4096822503F40B727486C77734B40
90203	1	13	170	28748	\N	\N	54.866771999999997	д. Сташки, Здание дома культуры	Россия, Смоленская область, Руднянский район, поселок Сташки	0101000020E6100000AF264F594D433F40548B8862F26E4B40
90215	1	13	170	46487	\N	\N	55.012269000000003	д. Стаи, Здание школы	Россия, Смоленская область, Руднянский район, поселок Стаи	0101000020E6100000AE484C50C3F33E4098E0D40792814B40
90205	1	13	170	28854	\N	\N	54.837566000000002	д. Смолиговка, Здание администрации с/п	Россия, Смоленская область, Руднянский район, поселок Смолиговка	0101000020E610000092239D81915B3F40EB1ED95C356B4B40
90206	1	13	170	46293	\N	\N	54.790225	д. Приволье, Здание школы	Россия, Смоленская область, Руднянский район, поселок Приволье	0101000020E61000009C6F44F7AC3F3F40A5BDC11726654B40
90216	1	13	170	29369	\N	\N	55.000456	д. Переволочье, Здание администрации с/п	Россия, Смоленская область, Руднянский район, поселок Переволочье	0101000020E6100000C8B5A1629C1F3F40228B34F10E804B40
90223	1	13	170	29651	\N	\N	55.378667	д. Никонцы, Здание ФАП	Россия, Смоленская область, Руднянский район, поселок Никонцы	0101000020E6100000C5FEB27BF2403F408789062978B04B40
90213	1	13	170	29205	\N	\N	54.929850000000002	д. Могильно, Здание школы	Россия, Смоленская область, Руднянский район, поселок Могильно	0101000020E6100000E9B7AF03E7E43E40C217265305774B40
90075	1	13	170	52027	\N	\N	54.832354000000002	д.Любавичи, помещение администрации Любавичского сельского поселения	Россия, Смоленская область, Руднянский район, поселок Любавичи	0101000020E61000002E03CE52B2F43E40EF586C938A6A4B40
90221	1	13	170	29559	\N	\N	54.946083999999999	д. Лешно, Здание клуба	Россия, Смоленская область, Руднянский район, поселок Лешно	0101000020E61000007445292158453F406AA2CF4719794B40
90214	1	13	170	29289	\N	\N	54.970815000000002	д. Кругловка, Здание администрации с/п	Россия, Смоленская область, Руднянский район, поселок Кругловка	0101000020E61000008735954561033F40AEBB79AA437C4B40
90217	1	13	170	40472	\N	\N	54.9636	д. Красный Двор, Здание лесхоза	Россия, Смоленская область, Руднянский район, поселок Красный Двор	0101000020E61000006AF7AB00DF193F407A36AB3E577B4B40
90228	1	13	170	29923	\N	\N	55.157103999999997	д. Кляриново, Здание администрации с/п	Россия, Смоленская область, Руднянский район, поселок Кляриново	0101000020E6100000E6762FF7C9153F400F09DFFB1B944B40
89874	1	13	1480	46240	\N	\N	55.508743000000003	с.Пречистое, администрация сельского поселения		0101000020E6100000B3B27DC85B2E4040D388997D1EC14B40
90218	1	13	170	29417	\N	\N	55.071447999999997	д. Карташевичи, Здание ФАП	Россия, Смоленская область, Руднянский район, поселок Карташевичи	0101000020E610000084F57F0EF32D3F40ABAE433525894B40
90211	1	13	170	29122	\N	\N	54.811357999999998	д. Казимирово, Здание школы	Россия, Смоленская область, Руднянский район, поселок Казимирово	0101000020E6100000B115342DB11A3F408AAC3594DA674B40
89923	1	13	170	49508	75080	\N	55.036369999999998	д.Заборье, ул.Молодежная, д.40 здание Администрации		0101000020E61000008D976E12830C3F401B47ACC5A7844B40
89835	1	13	170	48056	75133	\N	54.803362	д.Ефремово, ул.Школьная, д.16		0101000020E6100000F0A5F0A0D9F93E40B16CE690D4664B40
90202	1	13	170	54871	\N	\N	54.852699876454999	д. Гранки, Здание школы	Россия, Смоленская область, Руднянский район, поселок Голынки	0101000020E61000001041D5E8D5703F404CA60A46256D4B40
90201	1	13	170	28566	39980	\N	54.8664600433491	п. Голынки, Ленина, Здание дома культуры	Россия, Смоленская область, Руднянский район, поселок Голынки	0101000020E61000003FE0810184633F4065A54929E86E4B40
90200	1	13	170	28566	39980	\N	54.867378000000002	п. Голынки, Ленина, Здание школы	Россия, Смоленская область, Руднянский район, поселок Голынки	0101000020E610000099BC0166BE633F408CA2073E066F4B40
90199	1	13	170	28566	39980	\N	54.865420458113	п. Голынки, Ленина, Здание администрации г/п	Россия, Смоленская область, Руднянский район, поселок Голынки	0101000020E6100000D960E124CD633F40F4A62215C66E4B40
90034	1	13	170	47482	75169	\N	54.778419	д. Волково, ул. Гореленкова, д. 14		0101000020E6100000E23C9CC074EA3E40E2CAD93BA3634B40
90225	1	13	170	29743	\N	\N	55.299081000000001	д. Кошевичи, Здание школы	Россия, Смоленская область, Руднянский район, поселок Верхнии Кошевичи	0101000020E610000001DBC1887DF63E4070ED444948A64B40
90229	1	13	170	29935	\N	\N	55.167647000000002	д. Братышки, Здание клуба	Россия, Смоленская область, Руднянский район, поселок Братышки	0101000020E6100000C7BC8E38642F3F40E222F77475954B40
90227	1	13	170	14636	\N	\N	55.311093	д. Боярщина, Здание школы		0101000020E6100000F0F78BD992F13E40DC813AE5D1A74B40
89911	1	13	170	14636	\N	\N	55.311093	д.Боярщина, здание МОУ Андреевская ООШ	Россия, Смоленская область, Руднянский район, поселок Боярщина	0101000020E6100000F0F78BD992F13E40DC813AE5D1A74B40
90185	1	13	1164	54840	\N	\N	54.0802428786211	д.Чижовка-2, здание бывшей администрации сельского округа	Россия, Смоленская область, Рославльский район, поселок Чижовка	0101000020E61000002BD9B11188974040D15D1267450A4B40
90195	1	13	1164	46043	\N	\N	54.000923	д.Хорошово, здание администрации Хорошовского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Хорошево	0101000020E61000000667F0F78B5940403868AF3E1E004B40
90065	1	13	1164	54858	\N	\N	53.886068058789697	д.Слобода, помещение администрации Александровского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Слобода	0101000020E6100000A22424D2365640401D041DAD6AF14A40
90193	1	13	1164	28286	\N	\N	54.230390999999997	д.Савеево, здание администрации Савеевского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Савеево	0101000020E6100000AB9509BFD4A940407825C9737D1D4B40
90142	1	13	1164	16009	39792	\N	53.954063814974397	г.Рославль, пер.Димитрова, д.3 А, здание средней школа №2		0101000020E61000005F28603B186F40403E25E7C41EFA4A40
90152	1	13	1164	16009	9743	\N	53.947054000000001	г.Рославль, ул.Первомайская, д.21 А, здание средней школы №5	Россия, Смоленская область, Рославльский район, Рославль	0101000020E6100000F5D555815A6C4040E3C5C21039F94A40
90189	1	13	1164	28113	\N	\N	53.807951000000003	д.Пригоры, здание администрации Пригорьевского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Пригоры	0101000020E610000044A7E7DD58904040A0E238F06AE74A40
90188	1	13	1164	28064	\N	\N	53.916567000000001	д.Перенка, здание администрации Перенского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Перенка	0101000020E61000002A6F47382D764040E2CB441152F54A40
90186	1	13	1164	28019	39744	\N	54.01567	с.Остер, ул.Советская, д.11, здание Дома культуры		0101000020E610000010070951BE664040A0C37C7901024B40
90176	1	13	1164	27533	39799	\N	53.979595000000003	д.М.Кириллы, ул.Совхозная, д.2, здание администрации с/п		0101000020E61000003FC4060B277340409E29745E63FD4A40
90182	1	13	1164	45760	\N	\N	54.107225999999997	д.Липовка, здание администрации Липовского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Липовка	0101000020E6100000AA7EA5F3E1894040F4A3E194B90D4B40
90183	1	13	1164	27856	\N	\N	53.950467000000003	д.Лесники, здание администрации Лесниковского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Лесники	0101000020E610000020D5B0DF13534040B07614E7A8F94A40
90190	1	13	1164	28194	\N	\N	53.855165	д.Лахи, здание бывшей администрации сельского округа	Россия, Смоленская область, Рославльский район, поселок Лахи	0101000020E61000004D0F0A4AD19A404088D7F50B76ED4A40
90032	1	13	1164	41362	39739	\N	54.053089	п. Красный, ул. Советская, д. 17, 1 этаж		0101000020E610000025E82FF4888B40408063CF9ECB064B40
90031	1	13	1164	41362	39739	\N	54.053089	п. Красный, ул. Советская, д.17, 2 этаж		0101000020E610000025E82FF4888B40408063CF9ECB064B40
90179	1	13	1164	45710	\N	\N	54.195276999999997	д.Крапивна, здание администрации Крапивенского сельского поселения		0101000020E6100000546F0D6C95C840409B5434D6FE184B40
90191	1	13	1164	28197	\N	\N	54.095272999999999	д.Крапивенский-1, здание администрации Рославльского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Крапивенский 1-й	0101000020E6100000FDF50A0BEE5D40408D98D9E7310C4B40
90180	1	13	1164	27754	\N	\N	54.295841000000003	д.Коханы, здание бывшей админстрации сельского округа	Россия, Смоленская область, Рославльский район, поселок Коханы	0101000020E610000043FE99417CD0404071E82D1EDE254B40
90177	1	13	1164	27587	\N	\N	54.158873	д.Костыри, здание администрации Костыревского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Костыри	0101000020E6100000AA9A20EA3E864040D49B51F355144B40
90184	1	13	1164	27943	\N	\N	54.042881000000001	д.Коски, здание администрации Любовского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Коски	0101000020E6100000CB2C42B115864040554FE61F7D054B40
90187	1	13	1164	54807	39630	\N	53.992692636217498	д.Козловка, ул.Мира, д.44, здание Дома культуры	Россия, Смоленская область, Рославльский район, поселок Козловка	0101000020E6100000FC1C1F2DCE6A4040ECFB709010FF4A40
90173	1	13	1164	27384	\N	\N	53.790985999999997	д.Жарынь, здание администрации Жарынского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Жарынь	0101000020E6100000C32D1F494987404003CC7C073FE54A40
90172	1	13	1164	54893	\N	\N	53.725983553853197	д.Епишево-2, здание администрации Епишевского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Епишево	0101000020E61000003B8908FF228C4040AAB5300BEDDC4A40
90171	1	13	1164	27286	39568	\N	54.112124000000001	с.Екимовичи, ул.Комсомольская, д.14 А, здание администрации с\\п		0101000020E6100000E04DB7EC10A54040618C48145A0E4B40
90192	1	13	1164	28273	\N	\N	54.125349	д.Доротовка, здание фельдшерско-акушерского пункта	Россия, Смоленская область, Рославльский район, поселок Доротовка	0101000020E61000003944DC9C4A6C40400CCB9F6F0B104B40
89934	1	13	1164	15391	\N	\N	54.154310274072103	"г. Десногорск здание МБОУ ДОД ""Детская музыкальная школа"" (3 микрорайон)"	Россия, Смоленская область, Рославльский район, Десногорск	0101000020E6100000D0D03FC1C5A440400FB9196EC0134B40
89933	1	13	1164	15391	\N	\N	54.151891999999997	"г. Десногорск, 3 микрорайон, Здание МОУ "" СОШ №3"" г. Десногорска"	Россия, Смоленская область, Рославльский район, Десногорск	0101000020E6100000D238D4EFC2A440401343723271134B40
89929	1	13	1164	15391	39650	\N	54.155617275333199	"г. Десногорск, 2 микрорайон, Здание МУ ""ДЦБ"""	Россия, Смоленская область, Рославльский район, Десногорск	0101000020E6100000365B79C9FFA44040CFD90242EB134B40
89928	1	13	1164	15391	39551	\N	54.151891999999997	"г. Десногорск, 1 микрорайон, Здание МОУ ""СОШ №1"" г. Десногорска"		0101000020E6100000D238D4EFC2A440401343723271134B40
90170	1	13	1164	27241	\N	\N	53.803724000000003	д.Грязенять, здание Грязенятской основной школы	Россия, Смоленская область, Рославльский район, поселок Грязенять	0101000020E6100000AC1F9BE4476840405281936DE0E64A40
90174	1	13	1164	27469	\N	\N	53.756334000000003	д.Волконщина, здание сельского клуба	Россия, Смоленская область, Рославльский район, поселок Волконщина	0101000020E610000049658A39087A40402B6D718DCFE04A40
90169	1	13	1164	27201	\N	\N	53.894945999999997	д.Волковичи, здание администрации Волковичского сельского поселения	Россия, Смоленская область, Рославльский район, поселок Волковичи	0101000020E610000004AA7F10C9844040CFD72C978DF24A40
90168	1	13	1164	45501	40443	\N	54.242162	"с.Богданово, ул.им.колхоза ""Быстрые волны"", д.8, здание администрации с/п"		0101000020E61000009CF9D51C20944040BF2A172AFF1E4B40
90178	1	13	1164	60517	\N	\N	54.134498000000001	д.Барсуки, здание Красниковской средней школы	Россия, Смоленская область, Рославльский район, поселок Барсуки	0101000020E6100000DD257156448140404FB0FF3A37114B40
90167	1	13	1164	27109	\N	\N	53.908701999999998	д.Астапковичи, здание Астапковичской средней школы	Россия, Смоленская область, Рославльский район, поселок Астапковичи	0101000020E6100000E144F46BEB5D4040A7E7DD5850F44A40
90110	1	13	1740	24477	\N	\N	54.328113000000002	дер. Шмаково, Здание администрации поселения, д.56		0101000020E61000004162BB7B808240403C32569BFF294B40
90122	1	13	1740	49075	\N	\N	54.332416667817803	пос. Шаталово-1, Здание школы	Россия, Смоленская область, Починковский район, поселок Шаталово	0101000020E6100000D97745F0BF3B404035D1E7A38C2A4B40
90121	1	13	1740	49075	\N	\N	54.329909000000001	дер. Шаталово, Здание Дома культуры, д.238		0101000020E6100000543882548A3B4040FAD346753A2A4B40
90118	1	13	1740	24912	\N	\N	54.208370000000002	дер. Шанталово, Здание совхоза-техникума	Россия, Смоленская область, Починковский район, поселок Шанталово	0101000020E61000004F5DF92CCF474040D8BB3FDEAB1A4B40
90107	1	13	1740	48823	\N	\N	54.447705999999997	дер. Стригино, Здание Дома культуры, д.86		0101000020E61000008C6665FB905340408A1C226E4E394B40
90117	1	13	1740	24779	39558	\N	54.183971	пос. Стодолище, ул. Ленина, д.21-а		0101000020E61000005070B1A206534040CA349A5C8C174B40
90116	1	13	1740	24779	39558	\N	54.183971	пос. Стодолище, ул. Ленина, д.16		0101000020E61000005070B1A206534040CA349A5C8C174B40
90131	1	13	1740	49203	\N	\N	54.546332	дер. Старинки, Здание Дома культуры, д.59		0101000020E61000004298DBBDDC2B40400F61FC34EE454B40
90134	1	13	1740	49244	\N	\N	54.641680000000001	дер. Рябцево, Здание Дома культуры, д.68		0101000020E6100000DCD440F3392B4040A73FFB9122524B40
90141	1	13	1740	25941	\N	\N	54.313546000000002	дер. Прилепово, Здание Дома культуры, д.1		0101000020E6100000333509DE901C404054E57B4622284B40
90128	1	13	1740	49162	\N	\N	54.436197999999997	дер. Плоское, Здание администрации поселения, д.86	Россия, Смоленская область, Починковский район, поселок Плоское	0101000020E610000012A3E716BA2C4040514A0856D5374B40
90135	1	13	1740	25661	\N	\N	54.518481000000001	дер. Пересна, Здание школы, д.90		0101000020E6100000880E812381344040774CDD955D424B40
90112	1	13	1740	54859	\N	\N	54.207996000000001	дер. Ново-Головачи, Здание школы, д.29	Россия, Смоленская область, Починковский район, поселок Новые Головачи	0101000020E6100000C2DF2F664B6E404073D9E89C9F1A4B40
90129	1	13	1740	54832	39946	\N	54.4865527786285	дер. Мурыгино, ул. Центральная, д.71	Россия, Смоленская область, Починковский район, поселок Мурыгино	0101000020E610000057957D5704294040A662635E473E4B40
90123	1	13	1740	25092	\N	\N	54.334854	дер. Мачулы, Здание Дома культуры, д.96		0101000020E610000003D19332A9474040A777F17EDC2A4B40
90130	1	13	1740	49187	\N	\N	54.550269	дер. Макшеево, Здание школы	Россия, Смоленская область, Починковский район, поселок Макшеево	0101000020E610000088F37002D31B40405680EF366F464B40
90105	1	13	1740	24242	39971	\N	54.412050000000001	дер. Лучеса, ул. имени С.И.Бизунова, д.6		0101000020E6100000CE8DE9094B3E40408D28ED0DBE344B40
90132	1	13	1740	25555	\N	\N	54.596680999999997	дер. Лосня, Здание МДОУ Детский сад №21, д.1		0101000020E61000009F05A1BC8F2940408192020B604C4B40
90137	1	13	1740	49290	\N	\N	54.501089999999998	дер. Ламоново, Здание администрации поселения, д.14		0101000020E610000022C5008926184040232D95B723404B40
90115	1	13	1740	48964	\N	\N	54.123851000000002	дер. Красное Знамя, Здание администрации поселения, д.11		0101000020E61000006FB72407EC444040D8497D59DA0F4B40
90139	1	13	1740	49316	\N	\N	54.380856999999999	дер. Княжое, Здание администрации поселения, д.131		0101000020E6100000E94317D4B71A4040F1B913ECBF304B40
90109	1	13	1740	24433	\N	\N	54.357289999999999	дер. Климщина, Здание администрации поселения, д.52		0101000020E6100000EF022505165A40400B98C0ADBB2D4B40
90138	1	13	1740	60534	\N	\N	54.460901999999997	"дер. Клемятино, Здание СПК ""Клемятино"", д.1"	Россия, Смоленская область, Починковский район, поселок Клемятино	0101000020E61000006150A6D1E41040409B5434D6FE3A4B40
90073	1	13	1740	60482	\N	\N	54.214472000000001	д.Доброселье, помещение МОУ Добросельская ООШ	Россия, Смоленская область, Починковский район, поселок Доброселье	0101000020E6100000A5A2B1F67776404030F488D1731B4B40
90114	1	13	1740	24725	\N	\N	54.076698	"дер. Деребуж, Здание СПК ""Деребуж"", д.30"		0101000020E61000009C508880434C404095D5743DD1094B40
90124	1	13	1740	25157	\N	\N	54.362521000000001	дер. Даньково, Здание Дома культуры, д.94		0101000020E61000009C6D6E4C4F3640407E8E8F16672E4B40
90119	1	13	1740	49019	\N	\N	54.237937000000002	дер. Ворошилово, Здание школы, д.76		0101000020E6100000B1355B79C959404012C138B8741E4B40
90120	1	13	1740	49044	\N	\N	54.269092000000001	дер. Васьково, Здание школы, д.5		0101000020E6100000E6AE25E483484040C0CE4D9B71224B40
90127	1	13	1740	25260	\N	\N	54.431291000000002	"дер. Бояды, Здание СОГУ ""Починковский психо-неврологический интернат"""	Россия, Смоленская область, Починковский район, поселок Бояды 1-е	0101000020E6100000A11342075D3840409207228B34374B40
90111	1	13	1740	24541	\N	\N	54.30057	дер. Белик, Здание ФАПа, д.26		0101000020E61000000169FF03AC6F40405114E81379264B40
90106	1	13	1740	24321	\N	\N	54.464942000000001	дер. Бобыново, Здание школы	Россия, Смоленская область, Починковский район, поселок Бабыново	0101000020E61000001B6327BC04454040B7442E38833B4B40
90099	1	13	1419	48665	\N	\N	55.649393000000003	"д.Хвощевотое, здание МКОУ ""Хвощеватовская ООШ"""		0101000020E610000031B5A50EF2DA40402CA0504F1FD34B40
90096	1	13	1419	48626	\N	\N	55.481096999999998	"д.Торбеево, здание МКОУ ""Торбеевская ООШ"""	Россия, Смоленская область, Новодугинский район, поселок Торбеево	0101000020E61000004703780B24204140139A249694BD4B40
90094	1	13	1419	23737	\N	\N	55.613717000000001	с.Тесово, МОУ Тесовская основная общеобразовательная школа		0101000020E6100000F5F6E7A2213F4140E7FF55478ECE4B40
90093	1	13	1419	60521	\N	\N	55.665084999999998	д.Селище, здание МОУ Селищенская основная общеобразовательная школа	Россия, Смоленская область, Новодугинский район, поселок Селище	0101000020E6100000107A36AB3E2D4140B3075A8121D54B40
89964	1	13	1419	46008	75146	\N	55.656671000000003	д.Савино, ул.Центральная, д.7 (здание медпункта)		0101000020E610000001BF469220EE4040A69D9ACB0DD44B40
90092	1	13	1419	48558	\N	\N	55.650317000000001	д.Рябинки, Здание МОУ Рябинковская основная общеобразовательная школа	Россия, Смоленская область, Новодугинский район, поселок Рябинки	0101000020E6100000080264E8D81B4140348463963DD34B40
90091	1	13	1419	23562	\N	\N	55.647021000000002	д.Печеничено, Здание МОУ Печениченская основная общеобразовательная школа	Россия, Смоленская область, Новодугинский район, поселок Печеничено	0101000020E61000002AC93A1C5DFD4040A1698995D1D24B40
90100	1	13	1419	23443	\N	\N	55.620479000000003	Новодугино 1, Здание Дома культуры		0101000020E61000004EB4AB90F22541406A6D1ADB6BCF4B40
90090	1	13	1419	23443	40018	\N	55.620479000000003	с.Новодугино, Чкалова, 27		0101000020E61000004EB4AB90F22541406A6D1ADB6BCF4B40
90088	1	13	1419	23443	39968	\N	55.620479000000003	с.Новодугино, Советская, 1		0101000020E61000004EB4AB90F22541406A6D1ADB6BCF4B40
90089	1	13	1419	23443	39969	\N	55.620479000000003	с.Новодугино, Горького, 4		0101000020E61000004EB4AB90F22541406A6D1ADB6BCF4B40
89892	1	13	1419	49077	\N	\N	55.492787999999997	д.Никольское, Никольский Дом культуры		0101000020E6100000FDF50A0BEE2741403DEE5BAD13BF4B40
90047	1	13	1419	47713	\N	\N	55.578772000000001	д. Малеево, Здание администрации с/п	Россия, Смоленская область, Новодугинский район, поселок Малеево	0101000020E6100000E00F3FFF3D3A414096EB6D3315CA4B40
90087	1	13	1419	15869	\N	\N	55.608007000000001	"д.Липецы, здание МКОУ ""Липецкая ООШ"""		0101000020E6100000CAC4AD82181641409A5E622CD3CD4B40
90084	1	13	1419	15862	\N	\N	55.5636255927487	"д.Извеково, здание МКОУ ""Извековская ООШ"""	Россия, Смоленская область, Новодугинский район, поселок Извеково	0101000020E6100000D2A92B9FE5FD4040709692E524C84B40
90083	1	13	1419	15777	\N	\N	55.657093000000003	"с.Днепровское, здание МКОУ ""Днепровская СОШ"""	Россия, Смоленская область, Новодугинский район, поселок Днепровское	0101000020E6100000EE2422FC8BF440401CB7989F1BD44B40
90082	1	13	1419	48394	\N	\N	55.445098999999999	д.Григорьевское, здание МОУ Григорьевская основная общеобразовательная школа	Россия, Смоленская область, Новодугинский район, поселок Григорьевское	0101000020E61000006F9D7FBBECF34040BC3D0801F9B84B40
90080	1	13	1419	60478	\N	\N	55.624567584802598	д.Бурцево, здание МОУ Бурцевская начальная школа - детский сад	Россия, Смоленская область, Новодугинский район, поселок Бурцево	0101000020E6100000DB19A6B6D42F414066101FD8F1CF4B40
90079	1	13	1419	48341	\N	\N	55.730578000000001	" д. Болшево, здание МКОУ ""Печениченская ООШ"""		0101000020E610000074D3669C86EA4040AB96749483DD4B40
90255	1	13	1419	47293	\N	\N	55.415927000000003	д.Бараново, здание Администрации Барановского сельского поселения		0101000020E61000005721E527D5F64040FF428F183DB54B40
90072	1	13	1859	53064	\N	\N	54.252730999999997	д.Татарск, помещение Татарского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Татарск	0101000020E61000008318E8DA17903F40BAD7497D59204B40
90060	1	13	1859	51969	\N	\N	54.470007000000003	д.Стегримово, помещение администрации Соболевского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Стегримово	0101000020E610000047E867EA75E73F400FF27A30293C4B40
90059	1	13	1859	54857	\N	\N	54.431895741865098	д.Соболево, помещение администрации Соболевского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Соболево	0101000020E6100000D9D0CDFE40E53F40F9A23D5E48374B40
90074	1	13	1859	54877	\N	\N	54.192805999999997	д.Раевка, помещение администрации Добросельского селького поселения	Россия, Смоленская область, Монастырщинский район, поселок Раевка	0101000020E61000008658FD1186913F407D3CF4DDAD184B40
90058	1	13	1859	54895	\N	\N	54.377767804601397	д.Октябрьское, помещение администрации Слободского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Октябрьское	0101000020E61000009373620FEDD73F40D8BCAAB35A304B40
90056	1	13	1859	51957	\N	\N	54.383451999999998	д.Носково-2, помещение администрации Александровского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Носково 2-е	0101000020E6100000A79196CADBC13F40FBCA83F414314B40
89942	1	13	1859	45564	\N	\N	54.364435	д.Ново-Михайловское, Здание Администрации Михайловского с/п	Россия, Смоленская область, Монастырщинский район, поселок Новомихайловское	0101000020E6100000FD6A0E10CC9D3F4046425BCEA52E4B40
89844	1	13	1859	48243	39708	\N	54.413322999999998	д.Новое Село, ул.Центральная, д.61		0101000020E6100000D8EF8975AABC3F40A1D79FC4E7344B40
90066	1	13	1859	60499	\N	\N	54.366014	д.Михайловка, помещение администрации Новомихайловского сельского поселени	Россия, Смоленская область, Монастырщинский район, поселок Михайловка	0101000020E61000006BB933130CAF3F4067F0F78BD92E4B40
90209	1	13	1859	29028	\N	\N	54.187533000000002	д. Любавичи, Здание администрации с/п		0101000020E610000049861C5BCFB43F40DCF5D21401184B40
90068	1	13	1859	52003	\N	\N	54.238111000000004	д.Лыза, помещение Лызянского сельского клуба	Россия, Смоленская область, Монастырщинский район, поселок Лыза	0101000020E61000000D37E0F3C3E43F40B0E8D66B7A1E4B40
90076	1	13	1859	54876	\N	\N	54.2991738859251	д.Кадино, помещение МОУ Кадинская основная общеобразовательная школа	Россия, Смоленская область, Монастырщинский район, поселок Кадино	0101000020E6100000D55A988576763F4021E868554B264B40
90069	1	13	1859	54891	\N	\N	54.235443839388999	д.Железняк-1, помещение Железняковской сельской библиотеки	Россия, Смоленская область, Монастырщинский район, поселок Железняк	0101000020E610000075CB0EF10FBF3F400C056C07231E4B40
90057	1	13	1859	51959	\N	\N	54.417599000000003	д.Досугово, помещение администрации Александровского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Досугово	0101000020E610000001857AFA08B43F40D1EB4FE273354B40
90062	1	13	1859	51981	\N	\N	54.444968000000003	д.Долгие Нивы, помещение администрации Барсуковского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Долгие Нивы	0101000020E610000036936FB6B90540401EE21FB6F4384B40
90061	1	13	1859	51974	\N	\N	54.428891999999998	д.Дмыничи, помещение сельского клуба	Россия, Смоленская область, Монастырщинский район, поселок Дмыничи	0101000020E6100000DDEF5014E8F33F400DC2DCEEE5364B40
90070	1	13	1859	54861	\N	\N	54.280562676502598	д.Гоголевка, помещение администрации Гоголевского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Гоголевка	0101000020E6100000E3361AC05BF83F40DCBB067DE9234B40
90064	1	13	1859	60461	\N	\N	54.367215999999999	д.Барсуки, помещение администрации Барсуковского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Барсуки	0101000020E6100000E3512AE109074040B24813EF002F4B40
90063	1	13	1859	60461	\N	\N	54.368668999999997	д.Сычевка, помещение администрации Барсуковского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Барсуки	0101000020E610000091D5AD9E930640404606B98B302F4B40
90071	1	13	1859	52014	\N	\N	54.325755999999998	д.Багрецы, помещение администрации Гоголевского сельского поселения	Россия, Смоленская область, Монастырщинский район, поселок Багрецы	0101000020E61000000BF0DDE68DDF3F40E63C635FB2294B40
90219	1	13	382	29474	\N	\N	54.741104	д. Шеровичи, Здание школы		0101000020E61000007B82C476F75C3F40A777F17EDC5E4B40
90049	1	13	382	21623	\N	\N	54.655704	д. Сырокоренье, Здание библиотеки	Россия, Смоленская область, Краснинский район, поселок Сырокоренье	0101000020E6100000594E42E90B813F409EEDD11BEE534B40
90035	1	13	382	20974	40137	\N	54.596128	д. Рогайлово, ул. Центральная, д. 9		0101000020E610000097E2AAB2EFC63F406D1D1CEC4D4C4B40
90039	1	13	382	21175	\N	\N	54.692712999999998	д. Миганово, Здание медпункта	Россия, Смоленская область, Краснинский район, поселок Миганово	0101000020E610000045F30016F9613F40CC41D0D1AA584B40
90050	1	13	382	47767	39943	\N	54.602330000000002	д. Мерлино, ул. Парковая, д.12		0101000020E610000027A089B0E1953F4029B34126194D4B40
90048	1	13	382	47734	\N	\N	54.599648999999999	д. Маньково, здание Дома культуры	Россия, Смоленская область, Краснинский район, поселок Маньково	0101000020E6100000FD6CE4BA29793F40200A664CC14C4B40
90045	1	13	382	21447	\N	\N	54.683241000000002	д. Лонница, Здание администрации с/п	Россия, Смоленская область, Краснинский район, поселок Лонница	0101000020E61000008B389D64AB0F3F40A724EB7074574B40
90055	1	13	382	21930	\N	\N	54.508791000000002	д.Зверовичи, Здание мед.пункта	Россия, Смоленская область, Краснинский район, поселок Зверовичи	0101000020E610000032B08EE387463F40E4BF401020414B40
90038	1	13	382	21072	40193	\N	54.617243000000002	д. Двуполяны, ул. Мира, д. 24, каб. №2		0101000020E610000076887FD8D23B3F40AC5791D1014F4B40
90037	1	13	382	21072	40193	\N	54.617243000000002	д. Двуполяны, ул. Мира, д. 24, каб. №3		0101000020E610000076887FD8D23B3F40AC5791D1014F4B40
90041	1	13	382	47589	39563	\N	54.718212999999999	д. Гусино, ул. Советская, д. 15		0101000020E61000008257CB9D99603F40F1475167EE5B4B40
90040	1	13	382	47589	39563	\N	54.718212999999999	д. Гусино, ул. Советская, д. 17		0101000020E61000008257CB9D99603F40F1475167EE5B4B40
90042	1	13	382	47589	39958	\N	54.718212999999999	д. Гусино, ул. Молодежная, д.1, кв.77		0101000020E61000008257CB9D99603F40F1475167EE5B4B40
90051	1	13	382	21735	\N	\N	54.551960999999999	д. Гребени, Здание администрации с/п	Россия, Смоленская область, Краснинский район, поселок Гребени	0101000020E61000005C77F35487403F406FD575A8A6464B40
90033	1	13	382	20867	\N	\N	54.395001999999998	д. Викторово, Здание администрации с/п	Россия, Смоленская область, Краснинский район, поселок Викторово	0101000020E6100000BEBF417BF5793F4063EDEF6C8F324B40
89896	1	13	382	49133	\N	\N	54.453622000000003	д.Болтутино, здание Администрации  сельского поселения	Россия, Смоленская область, Краснинский район, поселок Болтутино	0101000020E610000059897956D2623F40815F2349103A4B40
90212	1	13	382	54833	\N	\N	54.713012109437202	д. Березино, Здание дома культуры	Россия, Смоленская область, Краснинский район, поселок Березино	0101000020E6100000E44A3D0B42553F40E9D32AFA435B4B40
90044	1	13	382	21396	\N	\N	54.702412000000002	д. Белеи, Здание медпункта	Россия, Смоленская область, Краснинский район, поселок Белеи	0101000020E6100000DFE00B93A92E3F40B328ECA2E8594B40
90036	1	13	382	47538	\N	\N	54.440392000000003	д. Алушково, Здание администрации с/п	Россия, Смоленская область, Краснинский район, поселок Алушково	0101000020E610000053CBD6FA22893F40C4B5DAC35E384B40
90028	1	13	1378	20645	40192	\N	54.706318000000003	д.Шутовка, ул.Молодежная, д.10, здание Дома культуры		0101000020E6100000CEFC6A0E10404040BF49D3A0685A4B40
90029	1	13	1378	47388	40133	\N	54.975614999999998	д.Шокино, ул.Молодежнвя, д.16, здание Шокинской школы		0101000020E6100000DAC70A7E1B364040573ECBF3E07C4B40
90030	1	13	1378	47420	40135	\N	54.964654000000003	д.Шестаково, ул.Школьная, д.1, здание Шестаковской школы		0101000020E610000078D0ECBAB742404051FA42C8797B4B40
90027	1	13	1378	47346	39957	\N	54.783321000000001	д.Тюшино, ул.Приозерная, д.75, здание Тюшинской школы		0101000020E610000073F6CE68AB3C404090A2CEDC43644B40
90025	1	13	1378	20431	40190	\N	54.831800000000001	д.Титково, ул.Центральная, д.15, здание Администрации с/п		0101000020E61000007427D87F9D4B40400A68226C786A4B40
90020	1	13	1378	20112	40188	\N	54.940784000000001	д.Тверицы, ул.Зеленая, д.1, здание клуба		0101000020E6100000A837A3E6AB384040CF4C309C6B784B40
90026	1	13	1378	47315	40266	\N	54.929653000000002	д.Соловьево, ул.Школьная, д.4, здание Администрации с/п		0101000020E6100000286211C30E5B40406CD097DEFE764B40
90484	1	13	1378	60489	\N	\N	54.921881999999997	д.Русаново, помещение администрации Русановского сельского поселения	Россия, Смоленская область, Кардымовский район, поселок Русаново	0101000020E6100000C4060B2769444040B262B83A00764B40
90019	1	13	1378	20058	\N	\N	54.883209000000001	д.Пищулино, ул.Школа-интернат, д.17, актовый зал школы-интернат		0101000020E6100000CC9BC3B5DA3B4040354415FE0C714B40
90023	1	13	1378	20290	40138	\N	54.708820000000003	д.Нетризово, ул.Школьная, д.4, здание Администрации с/п		0101000020E61000002025766D6F2D404018601F9DBA5A4B40
90022	1	13	1378	47240	40023	\N	54.866228	д.Мольково, ул.Административная, д.7, здание Администрации с/п		0101000020E610000098DF6932E33140409370218FE06E4B40
90016	1	13	1378	19927	39613	\N	54.889308999999997	п.Кардымово, ул.Школьная, д.4, актовый зал Кардымовской школы		0101000020E6100000B1DCD26A48384040EC8497E0D4714B40
90017	1	13	1378	19927	39737	\N	54.889308999999997	п.Кардымово, ул.Ленина, д.18, актовый зал Центра культуры		0101000020E6100000B1DCD26A48384040EC8497E0D4714B40
90021	1	13	1378	47221	75053	\N	55.019877999999999	д.Каменка, ул.Центральная, д.13, здание Администрации с/п		0101000020E61000006DAB59677C27404077F4BF5C8B824B40
90024	1	13	1378	20420	\N	\N	54.847633000000002	д.Вачково, ул.Первомайская, д.2, здание клуба	Россия, Смоленская область, Кардымовский район, поселок Вачково	0101000020E610000036902E36AD4640405401F73C7F6C4B40
90018	1	13	1378	20040	40187	\N	54.936335999999997	д.Варваровщина, ул.Центральная, д.20, здание Варваровщинской школы		0101000020E610000041D5E8D500314040A208A9DBD9774B40
89895	1	13	1378	49120	\N	\N	54.901719	д.Берёзкино, здание Администрации сельского поселения		0101000020E6100000C45BE7DF2E3F4040469737876B734B40
90006	1	13	1586	46908	\N	\N	53.622782000000001	д. Сукромля, здание Администрации Сукромлянского с/п	Россия, Смоленская область, Ершичский район, поселок Сукромля	0101000020E6100000CE6E2D93E1784040CC441152B7CF4A40
90012	1	13	1586	19721	\N	\N	53.527313999999997	д. Рухань, здание сельского дома культуры	Россия, Смоленская область, Ершичский район, поселок Рухань	0101000020E6100000E86C01A1F56C4040895C70067FC34A40
90011	1	13	1586	54856	\N	\N	53.739086405982498	д. Поселки, здание Администрации Поселковского с/п	Россия, Смоленская область, Ершичский район	0101000020E6100000E1F08288D44640403A77BB5E9ADE4A40
90536	1	13	1586	48278	39540	\N	53.545304999999999	с.Первомайский, ул.Никольская, д.38, помещение Первомайской школы		0101000020E6100000793A5794126E404032ACE28DCCC54A40
90010	1	13	1586	19623	\N	\N	53.516018000000003	д. Малая Язовка, здание МОУ Язовской основной общеобразовательной школы	Россия, Смоленская область, Ершичский район, поселок Малая Язовка	0101000020E6100000CCEEC9C342574040DC12B9E00CC24A40
90015	1	13	1586	47105	\N	\N	53.568973999999997	д. Лужная, здание Администрации Сеннянского с/п	Россия, Смоленская область, Ершичский район, поселок Лужная	0101000020E610000073672618CE4540401C23D923D4C84A40
89873	1	13	1219	48754	\N	\N	55.841999000000001	с.Карманово, МУК Кармановский КДЦ		0101000020E6100000AD855968E76E4140E2218C9FC6EB4B40
90008	1	13	1586	46947	\N	\N	53.614871999999998	д. Литвиновка, здание Администрации Беседковского с/п	Россия, Смоленская область, Ершичский район, поселок Литвиновка	0101000020E61000002905DD5ED24A4040F19C2D20B4CE4A40
90009	1	13	1586	46981	\N	\N	53.545240999999997	с. Кузьмичи, здание сельского дома культуры	Россия, Смоленская область, Ершичский район, поселок Кузьмичи	0101000020E6100000E4D6A4DB124B40401BB80375CAC54A40
90014	1	13	1586	19790	\N	\N	53.465074999999999	д. Корсики, здание МОУ Корсиковской основной общеобразовательной школы	Россия, Смоленская область, Ершичский район, поселок Корсики	0101000020E6100000728BF9B9A16F4040F697DD9387BB4A40
90013	1	13	1586	19744	\N	\N	53.486978000000001	д. Карды, здание МОУ Кардовской основной общеобразовательной школы	Россия, Смоленская область, Ершичский район, поселок Карды	0101000020E6100000B537F8C2646240408DEF8B4B55BE4A40
90003	1	13	1586	19208	39734	\N	53.672841078112398	с. Ершичи, ул. Понятовская, д.11,здание районного центра досуга	Россия, Смоленская область, Ершичский район, поселок Ершичи	0101000020E61000006380441328604040373465A71FD64A40
90005	1	13	1586	46901	\N	\N	53.653036058798797	д. Егоровка, здание Администрации Егоровского с/п	Россия, Смоленская область, Ершичский район, поселок Егоровка	0101000020E6100000FC372F4E7C6740402A8E03AF96D34A40
90007	1	13	1586	19416	39937	\N	53.752676000000001	с. Ворга, ул.Ленина, д.3, здание Администрации с/п		0101000020E61000005ED72FD80D614040F73DEAAF57E04A40
90004	1	13	1586	19260	\N	\N	53.617173999999999	д. Блинные Кучи, здание фельдшерско акушерского пункта	Россия, Смоленская область, Ершичский район, поселок Блинные Кучи	0101000020E6100000E29178793A63404083F8C08EFFCE4A40
89992	1	13	1248	60513	\N	\N	54.568318371906003	д. Шарапово, помещение Администрации Леонидовского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Шарапово	0101000020E6100000992B836A8391404033DDEBA4BE484B40
90000	1	13	1248	54873	\N	\N	54.743360909932001	д. Фенино, помещение Администрации Рождественского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Фенино	0101000020E6100000C1A7397991994040990F0874265F4B40
90002	1	13	1248	46824	\N	\N	54.502679999999998	с. Теренино, помещение Администрации Теренинского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Теренино	0101000020E610000035EECD6F98CC4040382D78D157404B40
90001	1	13	1248	54874	\N	\N	54.655532000000001	д. Старое Устиново, помещение Старое Устиновского сельского Дома культуры	Россия, Смоленская область, Ельнинский район, поселок Старое Устиново	0101000020E6100000C5AEEDED96964040A1BDFA78E8534B40
89997	1	13	1248	52877	\N	\N	54.438858000000003	д. Старое Мутище, помещение Администрации Мутищенского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Старое Мутище	0101000020E6100000170D198F52A5404043CBBA7F2C384B40
89999	1	13	1248	54889	\N	\N	54.566311968996999	д. Пронино, помещение Администрации Пронинского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Пронино	0101000020E6100000469A780778AA40408BAA5FE97C484B40
89995	1	13	1248	54888	\N	\N	54.637998286495801	д. Мазово, помещение Администрации Мазовского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Мазово	0101000020E6100000D52137C30DCA4040EB7420EBA9514B40
89993	1	13	1248	60546	\N	\N	54.512149000000001	д. Леоново, помещение МБОУ Леоновской основной школы	Россия, Смоленская область, Ельнинский район, поселок Леоново	0101000020E6100000F3052D2460864040EDD632198E414B40
89990	1	13	1248	54887	\N	\N	54.415914045347002	д. Лапино, помещение Администрации Новоспасского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Лапино	0101000020E610000098DEFE5C349240406AF981AB3C354B40
89988	1	13	1248	18411	\N	\N	54.515565000000002	с. Коробец, помещение Администрации Коробецкого сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Коробец	0101000020E6100000E65DF58079BC40402BFBAE08FE414B40
89987	1	13	1248	52849	\N	\N	54.646979000000002	д. Ивано-Гудино, помещение МБОУ Ивано-Гудинской  основной школы	Россия, Смоленская область, Ельнинский район, поселок Ивано-Гудино	0101000020E6100000AF795567B5B4404072193735D0524B40
89994	1	13	1248	52872	\N	\N	54.597014999999999	д. Демщино, помещение ФАП	Россия, Смоленская область, Ельнинский район, поселок Демщино	0101000020E610000080290307B48C4040581CCEFC6A4C4B40
89986	1	13	1248	52846	\N	\N	54.701630999999999	д. Гаристово, помещение Гаристовского сельского Дома культуры	Россия, Смоленская область, Ельнинский район, поселок Гаристово	0101000020E6100000EFE2FDB8FDA040400D6E6B0BCF594B40
90208	1	13	1248	60529	\N	\N	54.738542326697399	д. Волково, Здание ФАП	Россия, Смоленская область, Ельнинский район, поселок Волково	0101000020E6100000DD09F65FE79C4040795C548B885E4B40
89985	1	13	1248	45681	\N	\N	54.6569482448934	д. Богородицкое, помещение Администрации Бобровичского сельского поселения	Россия, Смоленская область, Ельнинский район, поселок Богородицкое	0101000020E6100000349F73B7EBA5404018963FDF16544B40
90407	1	13	1248	45681	39589	\N	54.657843999999997	д.Богородицкое, ул.Викторова, д.23		0101000020E6100000984EEB36A8A5404056EF703B34544B40
89976	1	13	1480	17819	\N	\N	55.414679999999997	д.Шиловичи, д.52 (здание сельского ДК)		0101000020E610000098A3C7EF6D4640401327F73B14B54B40
89977	1	13	1480	54854	40089	\N	55.158326704388202	д.Третьяково, ул.Московская, д.18 (здание сельского ДК)	Россия, Смоленская область, Духовщинский район, поселок Третьяково	0101000020E6100000B4B0A71DFE3C40407289230F44944B40
89979	1	13	1480	17972	40084	\N	55.329636000000001	д.Спас-Углы, ул.Центральная, д.5 (здание Администрации СП)		0101000020E610000090DD054A0A3E4040C9CA2F8331AA4B40
89974	1	13	1480	46240	39935	\N	55.508743000000003	с.Пречистое, ул.Б.Советская, д.24 (здание сельского ДК)		0101000020E6100000B3B27DC85B2E4040D388997D1EC14B40
89965	1	13	1480	46025	75067	\N	55.130414999999999	д.Петрищево, ул.Центральная, д.17 (здание Администрации СП)		0101000020E6100000A0E238F06A03404034F44F70B1904B40
89961	1	13	1480	45951	39606	\N	55.5911979373601	п.Озерный, ул.Парковая, д.5 (здание филиала колледжа)	Россия, Смоленская область, Духовщинский район, поселок Озерный	0101000020E610000057B08D78B2354040F5BA4560ACCB4B40
89962	1	13	1480	45951	39751	\N	55.594123000000003	п.Озерный, ул.Строителей, д.22 (здание средней школы)		0101000020E6100000802C4487C03540409566F3380CCC4B40
89967	1	13	1480	46078	40253	\N	55.278365000000001	д.Митяево, ул.Центральная, д.1 (здание Администрации СП)		0101000020E6100000DCF29194F42E4040EFACDD76A1A34B40
90125	1	13	1480	49128	\N	\N	55.576717000000002	дер. Липки, Здание школы, д.42		0101000020E6100000AF3E1EFAEE4440400C06D7DCD1C94B40
89970	1	13	1480	17519	40171	\N	55.219925000000003	д.Зимец, ул.Центральная, д.25 (здание Администрации СП)		0101000020E6100000D9CC21A98532404052499D80269C4B40
89969	1	13	1480	17468	40128	\N	55.248621999999997	д.Ерыши, ул.Центральная, д.6 (здание сельского ДК)		0101000020E6100000A8531EDD081F404076887FD8D29F4B40
89959	1	13	1480	16976	39560	\N	55.195587894003403	"г.Духовщина, ул.Бугаева, д.44/47а (МУК ""РДК"")"	Россия, Смоленская область, Духовщинский район, Духовщина	0101000020E6100000392BA226FA344040BABE0F0709994B40
89972	1	13	1480	54944	75061	\N	55.613885000000003	д.Добрино, ул.Школьная, д.1 (здание школы)		0101000020E610000083A5BA8097374040A3409FC893CE4B40
89973	1	13	1480	54890	40264	\N	55.582920000000001	д.Воронцово, ул.Школьная, д.4 (здание школы)	Россия, Смоленская область, Духовщинский район, поселок Воронцово	0101000020E6100000C2853C821B4340409817601F9DCA4B40
89975	1	13	1480	17779	\N	\N	55.505372999999999	д.Верешковичи-1, д.8 (здание Администрации СП)		0101000020E6100000745E6397A834404005A4FD0FB0C04B40
89971	1	13	1480	17581	40255	\N	55.654792	д.Велисто, ул.Центральная, д.12 (здание сельского ДК)		0101000020E6100000392A37514B1B40405AD76839D0D34B40
89966	1	13	1480	17359	40124	\N	55.354194999999997	д.Б.Береснево, ул.Лесная, д.3 (здание Администрации СП)		0101000020E61000006F7EC344832840400FB4024356AD4B40
89963	1	13	1480	45984	40231	\N	55.166491636746997	д.Бабино, ул.Солнечная, д.4 (здание Администрации СП)	Россия, Смоленская область, Духовщинский район, поселок Бабино	0101000020E6100000916456EF70314040D7851F9C4F954B40
90052	1	13	303	21825	\N	\N	55.031664999999997	д. Марково, Здание школы	Россия, Смоленская область, Дорогобужский район, нежилой населенный пункт Марково	0101000020E61000001FF296AB1F8F4040C3B645990D844B40
89943	1	13	303	45603	\N	\N	54.987389	д.Шаломино, Здание сельского Дома досуга	Россия, Смоленская область, Дорогобужский район, поселок Шаломино	0101000020E6100000DB34B6D782A840400FB743C3627E4B40
89949	1	13	303	45705	\N	\N	54.740132000000003	д.Ушаково, Здание Администрации Ушаковского с/п	Россия, Смоленская область, Дорогобужский район, поселок Ушаково	0101000020E6100000253FE257ACBB40408E5C37A5BC5E4B40
89948	1	13	303	16460	\N	\N	54.938845000000001	д.Усвятье, Здание Усвятской средней общеобразовательной школы	Россия, Смоленская область, Дорогобужский район, поселок Усвятье	0101000020E610000081423D7D048E4040AE81AD122C784B40
89947	1	13	303	54894	\N	\N	54.941690312545397	д.Слойково, Здание Администрации Слойковского с/п	Россия, Смоленская область, Дорогобужский район, поселок Слоиково	0101000020E61000007044F7AC6B944040317C444C89784B40
89951	1	13	303	54845	\N	\N	54.943636715906898	д.Садовая, Здание Администрации Фрунзенского с/п	Россия, Смоленская область, Дорогобужский район, поселок Садовая	0101000020E6100000D844662E70A34040D525E318C9784B40
89946	1	13	303	45650	\N	\N	54.945019000000002	д.Полибино, Здание Администрации Полибинского с/п	Россия, Смоленская область, Дорогобужский район, поселок Полибино	0101000020E61000004BB1A371A8B74040A08CF161F6784B40
89950	1	13	303	16559	\N	\N	54.670206999999998	д.Мархоткино, Здание сельского Дома досуга	Россия, Смоленская область, Дорогобужский район, поселок Мархоткино	0101000020E610000076AA7CCF48C440406F46CD57C9554B40
89940	1	13	303	45524	\N	\N	54.832593000000003	д.Княщина, Здание Администрации Княщинского с/п	Россия, Смоленская область, Дорогобужский район, поселок Княщина	0101000020E6100000390A100533AE404074F04C68926A4B40
89945	1	13	303	45636	\N	\N	54.801482999999998	д.Каськово, Здание Администрации Озерищенского с/п	Россия, Смоленская область, Дорогобужский район, поселок Каськово	0101000020E6100000A4880CAB788D404065A6B4FE96664B40
89900	1	13	303	49192	\N	\N	54.924806991025903	д.Ивонино, здание Дома культуры	Россия, Смоленская область, Дорогобужский район, поселок Ивонино	0101000020E6100000757632384AA84040520E661360764B40
88986	1	13	303	1355	39656	\N	54.912092000000001	г.Дорогобуж, Лермонтова, 18		0101000020E61000008AC745B588A84040BC783F6EBF744B40
89952	1	13	303	1355	39953	\N	54.912092000000001	г.Дорогобуж, Карла Маркса, 176а		0101000020E61000008AC745B588A84040BC783F6EBF744B40
89958	1	13	303	16780	39602	\N	54.982585	п.Верхнеднепровский, Советская, 1		0101000020E6100000D236FE4465AD404024456458C57D4B40
89957	1	13	303	16780	39733	\N	54.982585	п.Верхнеднепровский, Молодежная, 5		0101000020E6100000D236FE4465AD404024456458C57D4B40
89956	1	13	303	16780	39733	\N	54.982585	п.Верхнеднепровский, Молодежная, 19		0101000020E6100000D236FE4465AD404024456458C57D4B40
89955	1	13	303	16780	39555	\N	54.982585	п.Верхнеднепровский, Комсомольская, 20		0101000020E6100000D236FE4465AD404024456458C57D4B40
89954	1	13	303	16780	39555	\N	54.982585	п.Верхнеднепровский, Комсомольская, 18		0101000020E6100000D236FE4465AD404024456458C57D4B40
89939	1	13	303	60532	\N	\N	54.953912000000003	д.Васино, Здание Администрации Васинского с/п	Россия, Смоленская область, Дорогобужский район, поселок Васино	0101000020E610000045BC75FEEDCE404088A1D5C9197A4B40
89938	1	13	303	45498	\N	\N	54.905881000000001	д.Быково, Здание Администрации Балакиревского с/п		0101000020E610000083E0F1ED5D814040AD889AE8F3734B40
89916	1	13	1341	14877	40223	\N	55.325302999999998	д.Шапы, ул.Боровая, д.15 здание МБОУ Шаповская ООШ		0101000020E6100000EED0B01875D13F4035255987A3A94B40
89915	1	13	1341	54899	40306	\N	55.184735427366697	д.Центральная Усадьба, ул.Дорожная, д.11 здание Администрации	Россия, Смоленская область, Демидовский район, поселок Диво	0101000020E61000000438BD8BF7CF3F409AB67F65A5974B40
89978	1	13	1341	46340	75095	\N	55.404969000000001	д.Троицкое, ул.Школьная, д.9 (здание школы)		0101000020E61000001A6CEA3C2A7E3F4069723106D6B34B40
89914	1	13	1341	14821	40059	\N	55.241103000000003	д.Титовщина, ул.Центральная, д.18 здание Титовщинского СДК		0101000020E610000001A5A146217D3F40D7FB8D76DC9E4B40
89917	1	13	1341	14926	39526	\N	55.500895999999997	п.Пржевальское, ул.Советская, д.23 здание Администрации		0101000020E61000009D7FBBECD7DD3F403E59315C1DC04B40
89918	1	13	1341	14926	40056	\N	55.500895999999997	п.Пржевальское, ул.Курортная, д.1 здание санатория		0101000020E61000009D7FBBECD7DD3F403E59315C1DC04B40
89919	1	13	1341	14926	40063	\N	55.500895999999997	п.Пржевальское, ул. 1 Мая, д.2 здание Администрации		0101000020E61000009D7FBBECD7DD3F403E59315C1DC04B40
89925	1	13	1341	49534	40168	\N	55.680107999999997	п.Подосинки, ул.Лесная, д.8 здание Администрации		0101000020E6100000AC376A85E9E33F40BDDF68C70DD74B40
89920	1	13	1341	15092	40050	\N	55.368855000000003	д.Корево, ул.Ямская, д.2 здание Администрации		0101000020E610000014ED2AA4FCEC3F40A9FB00A436AF4B40
89924	1	13	1341	15290	40164	\N	55.367592000000002	д.Закрутье, ул.Центральная, д.19 здание МБОУ Бурлыгинская ООШ		0101000020E6100000558A1D8D43653F40B82231410DAF4B40
90067	1	13	1341	60515	\N	\N	55.685364	д.Жуково, помещение Жуковского сельского клуба	Россия, Смоленская область, Демидовский район, поселок Жуково	0101000020E6100000001AA54BFFEE3F4089EDEE01BAD74B40
89913	1	13	1341	14722	40222	\N	55.106535999999998	д.Жичицы, ул.Егорова, д.28 здание Жичицкого СДК		0101000020E6100000A6F10BAF24493F405FECBDF8A28D4B40
89912	1	13	1341	54941	40608	\N	55.182611120714398	д.Дубровка, ул.Парковая, д.19 здание Дубровского СДК		0101000020E61000005F984C158C5A3F40E77118CC5F974B40
89909	1	13	1341	54898	40297	\N	55.344575365451597	д.Верхние Моховичи, ул.Парковая, д.2 здание Администрации	Россия, Смоленская область, Демидовский район, поселок Верхнии Моховичи	0101000020E610000014CFD90242873F4075029A081BAC4B40
89910	1	13	1341	14580	40105	\N	55.331310999999999	д.Борода, ул.Верхняя, д.10 здание Администрации		0101000020E610000066DAFE95954E3F400CE71A6668AA4B40
90224	1	13	1341	46666	\N	\N	55.699795999999999	д. Борки, Здание дома культуры		0101000020E6100000FFE6C589AFE63F4091EF52EA92D94B40
89921	1	13	1341	54897	40296	\N	55.5095665867562	д.Бакланово, ул.Центральная, д.54 здание Администрации	Россия, Смоленская область, Демидовский район, поселок Бакланово	0101000020E6100000AF230ED940AA3F40770FD07D39C14B40
89902	1	13	1311	60472	\N	\N	54.473432352589398	д. Ново-Ханино, здание Новоханинской  школы	Россия, Смоленская область, Глинковский район, поселок Ханино	0101000020E6100000874F3A9160664040A070766B993C4B40
89903	1	13	1311	49238	\N	\N	54.639310000000002	д.Петропавловка, здание Дома культуры	Россия, Смоленская область, Глинковский район, поселок Петропавловка	0101000020E61000000C2252D32E6E4040BD00FBE8D4514B40
89901	1	13	1311	14152	\N	\N	54.677515999999997	д.Новобрыкино, здание Администрации сельского поселения в д.Новобрыкино	Россия, Смоленская область, Глинковский район, поселок Новобрыкино	0101000020E6100000B876A22424804040244223D8B8564B40
89899	1	13	1311	14075	\N	\N	54.646687	с.Дубосище, здание Дубосищенской школы	Россия, Смоленская область, Глинковский район, поселок Дубосище	0101000020E6100000899AE8F3515C4040CADFBDA3C6524B40
89898	1	13	1311	14014	\N	\N	54.704284000000001	д.Добромино, здание  Администрации  сельского поселения	Россия, Смоленская область, Глинковский район, поселок Добромино	0101000020E6100000834E081D745940404C8C65FA255A4B40
89897	1	13	1311	49147	39668	\N	54.638407999999998	с.Глинка, ул.Ленина, д.5Б		0101000020E610000062F54718067040409CC0745AB7514B40
89894	1	13	1311	13855	\N	\N	54.608739	д.Белый  Холм, здание Администрации сельского поселения		0101000020E610000082C476F7004F40405E66D828EB4D4B40
89871	1	13	1219	12810	\N	\N	55.553390999999998	д.Черногубцево, Черногубцевская сельская библиотека		0101000020E610000062105839B47841404B732B84D5C64B40
89886	1	13	1219	48974	\N	\N	55.318956999999997	с.Токарево, администрация сельского поселения		0101000020E61000009692E524948E414046EA3D95D3A84B40
89885	1	13	1219	13398	\N	\N	55.486642000000003	с.Серго-Ивановское, администрация сельского поселения		0101000020E61000000796236420614140166EF9484ABE4B40
89883	1	13	1219	13307	\N	\N	55.634461000000002	д.Родоманово, Родомановский Дом культуры		0101000020E6100000A779C7293A66414032CB9E0436D14B40
89889	1	13	1219	40431	\N	\N	55.627060999999998	д.Пышково, Пышковская основная школа		0101000020E610000082FDD7B969A741406CCCEB8843D04B40
89879	1	13	1219	49322	75059	\N	55.362158000000001	"д. Покров, помещение СПК ""Мишино"" (ул. Центральная, д. 11)"	Россия, Смоленская область, Гагаринский район, поселок Покров	0101000020E6100000581F0F7D778541400DFE7E315BAE4B40
89877	1	13	1219	48827	\N	\N	55.855759999999997	д.Петушки, здание бывшей сельск. администрации	Россия, Смоленская область, Гагаринский район, поселок Петушки	0101000020E6100000E10B93A982934140CB9C2E8B89ED4B40
90448	1	13	1219	60547	\N	\N	55.431201999999999	д.Никольское, помещение администрации Никольского с/п	Россия, Смоленская область, Гагаринский район, поселок Никольское	0101000020E6100000C3BB5CC47786414022FC8BA031B74B40
89880	1	13	1219	13156	\N	\N	55.370215999999999	д.Молоченево, Молоченевская сельская библиотека		0101000020E6100000FD6662BA107D41405C3AE63C63AF4B40
89875	1	13	1219	48796	\N	\N	55.735773000000002	д.Липцы, Липецкий клуб		0101000020E6100000E7525C55F66D4140D12346CF2DDE4B40
89893	1	13	1219	60488	\N	\N	55.5025497809889	д.Колокольня, Колокольнинская основная школа	Россия, Смоленская область, Гагаринский район, поселок Колокольня	0101000020E6100000315F5E807D7A41406A4DF38E53C04B40
89890	1	13	1219	49051	\N	\N	55.668863999999999	д.Клушино, Клушинский Дом культуры		0101000020E61000008B1876189386414062BCE6559DD54B40
89884	1	13	1219	40430	\N	\N	55.746187999999997	д.Ивино, Ивинская основная школа		0101000020E61000009D121093705941407555A01683DF4B40
90175	1	13	1219	45646	\N	\N	55.419114999999998	д.Ивановское, здание администрации Ивановского сельского поселения		0101000020E6100000CF49EF1B5F974140AB21718FA5B54B40
89866	1	13	1219	12155	40022	\N	55.550967	г.Гагарин, микрорайон Лесной, адм.здание Гагаринского лесхоза		0101000020E61000002DEA93DC617F41406E162F1686C64B40
89878	1	13	1219	54839	\N	\N	55.547870032128699	с.Баскаково, Баскаковская средняя школа	Россия, Смоленская область, Гагаринский район, поселок Баскаково	0101000020E61000007DCB9C2E8B614140D23AAA9A20C64B40
89870	1	13	1219	40427	\N	\N	55.599468000000002	д.Ашково, Ашковская средняя школа		0101000020E61000002EC55565DF7D4140D07F0F5EBBCC4B40
89882	1	13	1219	40429	\N	\N	55.427335999999997	д.Астахово, Астаховская основная школа		0101000020E6100000E9279CDD5A764140A43330F2B2B64B40
89887	1	13	1219	54855	\N	\N	55.595278867976504	д.Акатово, Акатовский Дом культуры		0101000020E6100000FE481119569941406F7F2E1A32CC4B40
89856	1	13	291	12060	40248	\N	55.480556	с.Шуйское, ул.Новоселов, д.21		0101000020E6100000AFCF9CF529434140C3F2E7DB82BD4B40
89846	1	13	291	48292	40051	\N	55.191957000000002	д.Черное, ул.Окружная, д.5, кв.1		0101000020E610000007793D9814FF4040809E060C92984B40
89848	1	13	291	48325	39942	\N	55.171900000000001	д.Черемушки, ул.Школьная, д.15		0101000020E6100000815A0C1EA62341405917B7D100964B40
89855	1	13	291	12052	\N	\N	55.426063999999997	д.Царево-Займище, здание Администрации Царево-Займищенского с/п	Россия, Смоленская область, Вяземский район, поселок Царево-Займище	0101000020E6100000AC527AA6976841406000E14389B64B40
89854	1	13	291	11993	40111	\N	55.404029000000001	с.Хмелита, ул.Центральная, д.11		0101000020E6100000AE65321CCFF140405BD1E638B7B34B40
89836	1	13	291	11145	\N	\N	54.892152000000003	д.Хватов-Завод, здание Администрации Заводского с\\п	Россия, Смоленская область, Вяземский район, поселок Хватов Завод	0101000020E61000004417D4B7CC1D4140CF87670932724B40
89834	1	13	291	48028	39977	\N	55.345799999999997	д.Успенское, ул.Успенская, д.3		0101000020E61000007E39B35DA1554140787AA52C43AC4B40
89853	1	13	291	48405	39681	\N	55.420535999999998	с.Туманово, ул.Почтовая, д.6		0101000020E6100000FA28232E005341403465A71FD4B54B40
89849	1	13	291	11777	40027	\N	55.147400217591802	ст.Семлево, ул.Советская, д.12	Россия, Смоленская область, Вяземский район, поселок Семлево	0101000020E610000004392861A6FF404017B7D100DE924B40
89850	1	13	291	11777	40010	\N	55.145341005639096	с.Семлево, ул.Ленина, д.50	Россия, Смоленская область, Вяземский район, поселок Семлево	0101000020E610000082734694F60041404CE2AC889A924B40
90272	1	13	291	47635	\N	\N	55.150412000000003	д.Пушкино, здание Администрации Пушкинского сельского поселения		0101000020E6100000C520B0726857414086764EB340934B40
89847	1	13	291	11661	40252	\N	55.079374999999999	д.Поляново, ул.Гагарина, д.1		0101000020E6100000215C01857A0641405C8FC2F5288A4B40
89845	1	13	291	11568	40003	\N	55.215164000000001	д.Относово, ул.Школьная, д.7		0101000020E6100000A31D37FC6E12414066A3737E8A9B4B40
89851	1	13	291	54846	40049	\N	55.162331054729798	с.Новый, ул.Рабочая, здание Шимановской СОШ	Россия, Смоленская область, Вяземский район, поселок Новый	0101000020E610000040683D7C9944414041102043C7944B40
89852	1	13	291	60474	\N	\N	55.230903343748899	с.Ново-Никольское, здание Ново-Никольского дома-интерната	Россия, Смоленская область, Вяземский район, поселок Новоникольское	0101000020E61000002BA6D24F383941402EC6C03A8E9D4B40
89840	1	13	291	11323	40110	\N	54.954248999999997	д.Малая Калпита, ул.Молодежная, д.11		0101000020E6100000346612F582EF4040CF9ECBD4247A4B40
89802	1	13	291	52449	\N	\N	55.320545000000003	д.Крутое, Помещение МБОУ Крутовская ООШ	Россия, Смоленская область, Вяземский район, поселок Крутое	0101000020E61000005CACA8C134684140BBF2599E07A94B40
89841	1	13	291	11341	39945	\N	55.399157000000002	д.Касня, ул.Ленина, здание Каснянской СОШ		0101000020E610000006103E9468294140187C9A9317B34B40
90086	1	13	291	60493	\N	\N	55.055532231700397	д.Капустино, Здание Администрации	Россия, Смоленская область, Вяземский район, поселок Капустино	0101000020E61000007349D576130C4140D4F02DAC1B874B40
89839	1	13	291	11236	39815	\N	55.104846999999999	д.Кайдаково, ул.Парковая, д.17		0101000020E61000006AFB57569A264140B70A62A06B8D4B40
89838	1	13	291	54878	40201	\N	55.176817667967804	с.Исаково, ул.Школьная, д.8	Россия, Смоленская область, Вяземский район, поселок Исаково	0101000020E61000000CB08F4E5D5341400CACE3F8A1964B40
89843	1	13	291	40424	\N	\N	55.352578000000001	д.Дмитровка, здание Администрации Мещерского с/п		0101000020E6100000E75432005439414001A5A14621AD4B40
90136	1	13	291	54838	\N	\N	55.298515150822801	дер. Денисово, Здание администрации поселения, д.5		0101000020E610000008944DB9C2334140C72E51BD35A64B40
89833	1	13	291	10964	39549	\N	55.165930000000003	с.Вязьма-Брянская, ул.Авиационная, д.1а		0101000020E610000087DEE2E13D2F414070B6B9313D954B40
89832	1	13	291	10964	39661	\N	55.165930000000003	с.Вязьма-Брянская, ул.50 лет Победы, здание Вязьма-Брянской СОШ		0101000020E610000087DEE2E13D2F414070B6B9313D954B40
89825	1	13	291	1259	39714	\N	55.207294439950999	г.Вязьма, ул.Песочная, д.2	Россия, Смоленская область, Вяземский район, Вязьма	0101000020E6100000231631EC3028414019541B9C889A4B40
89823	1	13	291	1259	39543	\N	55.198065717654103	г.Вязьма, ул.Кашена, д.15	Россия, Смоленская область, Вяземский район, Вязьма	0101000020E610000076887FD8D22541408A39083A5A994B40
89842	1	13	291	60475	\N	\N	55.311687185227697	с.Богородицкое, здание Администрации Масловского с/п, д.62	Россия, Смоленская область, Вяземский район, поселок Богородицкое	0101000020E61000003196E997880941404FCB0F5CE5A74B40
89831	1	13	291	47987	39548	\N	55.236333999999999	с.Андрейково, ул.Ленина, д.10		0101000020E6100000D272A087DA20414068774831409E4B40
89806	1	13	1097	54844	\N	\N	55.658723000000002	д.Ситьково, Помещение Администтрации Ситьковского с\\п	Россия, Смоленская область, Велижский район, поселок Ситьково	0101000020E610000098C0ADBB79523F40BF0F070951D44B40
89805	1	13	1097	52458	\N	\N	55.647177999999997	д.Селезни, Помещение Селезневского ДК	Россия, Смоленская область, Велижский район, поселок Селезни	0101000020E61000004D309C6B98793F4068588CBAD6D24B40
41048	5	51	815	10066	76000	\N	56.279997000000002	Кайдулы, Дорожная, 18		0101000020E6100000DF196D5512E0554033FD12F1D6234C40
89804	1	13	1097	52456	\N	\N	55.576115999999999	д.Погорелье, Помещение Администрации Погорельского с\\п	Россия, Смоленская область, Велижский район, поселок Погорелье	0101000020E6100000BA15C26A2C693F40E659492BBEC94B40
89803	1	13	1097	52452	\N	\N	55.538677	д.Печенки, Помещение Администрации Печенковского с\\п	Россия, Смоленская область, Велижский район, поселок Печенки	0101000020E6100000CB811E6ADB583F40BF0D315EF3C44B40
89808	1	13	1097	9728	39702	\N	55.609065000000001	г.Велиж, ул.Володарского, 11		0101000020E610000090A0F831E62E3F40B21188D7F5CD4B40
89800	1	13	1097	54869	\N	\N	55.607884132200603	д.Будница, Помещение МБОУ Будницкая ООШ	Россия, Смоленская область, Велижский район, поселок Будница	0101000020E6100000083C3080F00D3F407EE19524CFCD4B40
89799	1	13	1097	53067	\N	\N	55.509365000000003	д.Беляево, Помещение Администрации Беляевского с\\п	Россия, Смоленская область, Велижский район, поселок Беляево	0101000020E61000007847C66AF3173F40105D50DF32C14B40
78762	1	12	\N	54631	38278	\N	54.029201	Рязанская область, Шацкий район,  г. Шацк, Цюрупы, здание техникума		0101000020E6100000C3D8429083DC44405801BEDBBC034B40
78368	1	12	\N	29992	\N	\N	54.663905999999997	Рязанская область, Рязанский район, д.Хирино, здание спорткомплекса		0101000020E6100000A0E238F06AC7434020CF2EDFFA544B40
78365	1	12	\N	23653	\N	\N	54.550477999999998	Рязанская область, Рязанский район, д.Турлатово, здание Дома культуры	Россия, Рязанская область, поселок Турлатово	0101000020E61000006B2C616D8CE943407095271076464B40
78578	1	12	\N	54626	38533	\N	54.412484999999997	Рязанская область, Спасский район, г. Спасск, Набережная, 30 (Пед. Колледж)		0101000020E61000006CE9D1544F304440978BF84ECC344B40
78574	1	12	\N	54626	38260	\N	54.412484999999997	Рязанская область, Спасский район, г. Спасск, Ломоносова, 34 (Средняя общеобразовательная школа)		0101000020E61000006CE9D1544F304440978BF84ECC344B40
78567	1	12	\N	7320	38208	\N	53.828170502798599	Рязанская область, Скопинский район, г. Скопин, мкр.Октябрьский (Здание дома культуры)	Россия, Рязанская область, Скопин	0101000020E61000007555A01683C94340703FE08101EA4A40
78568	1	12	\N	7320	38788	\N	53.827747359577302	Рязанская область, Скопинский район, г. Скопин, мкр.Комсомольский ( Здание здравпункта)	Россия, Рязанская область, Скопин	0101000020E61000005111A7936CC943405A2E1B9DF3E94A40
78571	1	12	\N	7320	38544	\N	53.8274596193001	Рязанская область, Скопинский район, г. Скопин, мкр.Коготково (Здание здравпункта)	Россия, Рязанская область, Скопин	0101000020E61000007B4FE5B4A7C84340C45F9335EAE94A40
78572	1	12	\N	7320	38273	\N	53.8246046794157	Рязанская область, Скопинский район, г. Скопин, мкр.Заречный (Здание клуба)	Россия, Рязанская область, Скопин	0101000020E6100000F31DFCC401C843401D8F19A88CE94A40
78555	1	12	\N	7320	38527	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Пушкина, 84 (Агротехникум)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78560	1	12	\N	7320	38268	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Поташная, 3а (ВДПО)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78559	1	12	\N	7320	38053	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Площадь Ленина, 1 (ДК)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78554	1	12	\N	7320	38279	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Орджоникидзе, 139 (Средняя общеобразовательная школа №5)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78558	1	12	\N	7320	38512	\N	53.823749896105099	Рязанская область, Скопинский район, г. Скопин, Октябрьская, 26 (Мед. Колледж)	Россия, Рязанская область, Скопин городской округ	0101000020E610000090300C5872C743403D0AD7A370E94A40
78566	1	12	\N	7320	38076	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Мира 12 (здание клуба п.Металлург)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78565	1	12	\N	7320	38076	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Мира, 4 (Средняя общеобразовательная школа №3)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78556	1	12	\N	7320	38046	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Ленина, 19 (Средняя общеобразовательная школа №6)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78553	1	12	\N	7320	38046	\N	53.825129427214698	Рязанская область, Скопинский район, г. Скопин, Ленина, 183 (Детский центр)		0101000020E610000044882B67EFCA434097FDBAD39DE94A40
78563	1	12	\N	7320	38083	\N	53.835424629821702	Рязанская область, Скопинский район, г. Скопин, Карла Маркса, 259 (ТЭ колледж)	Россия, Рязанская область, Скопин	0101000020E6100000906802452CC6434062A1D634EFEA4A40
78561	1	12	\N	7320	38083	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Карла Маркса, 162а (Мед.колледж)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78564	1	12	\N	7320	38221	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Автозаводской микрорайон, 6 (Средняя общеобразовательная школа №4)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78562	1	12	\N	7320	38221	\N	53.825578	Рязанская область, Скопинский район, г. Скопин, Автозаводской микрорайон, 22 (Клуб)		0101000020E61000004E9B711AA2C843400726378AACE94A40
78350	1	12	\N	29173	\N	\N	54.580510508278699	Рязанская область, Рязанский район, д.Секиотово, здание Семено-Оленинской основной школы	Россия, Рязанская область, Секиотово	0101000020E610000053CDACA580D04340F0FB372F4E4A4B40
78465	1	12	\N	4031	\N	\N	54.3461285960502	Рязанская область, Сасовский район, поселок Сасовский, администрация сельского поселения	Россия, Рязанская область, Сасово	0101000020E610000099F04BFDBCF544403D997FF44D2C4B40
78506	1	12	\N	4031	38131	\N	54.348925999999999	"Рязанская область, Сасовский район, г. Сасово, микрорайон ""Южный"", 38 детский сад"		0101000020E610000044F8174163F64440AF5C6F9BA92C4B40
73115	7	71	913	30951	\N	\N	60.199753999999999	пос.УстьКоса, клуб		0101000020E6100000DFA63FFB91964B40629F008A91194E40
78505	1	12	\N	4031	38131	\N	54.349424169214899	"Рязанская область, Сасовский район, г. Сасово, микрорайон ""Южный"", 36 детский сад"	Россия, Рязанская область, Сасово	0101000020E61000009D0DF96706F744400038F6ECB92C4B40
78504	1	12	\N	4031	38131	\N	54.341651710892599	"Рязанская область, Сасовский район, г. Сасово, микрорайон ""Южный"", 35 детский сад"	Россия, Рязанская область, Сасово	0101000020E61000003B6D8D08C6F14440774EB340BB2B4B40
78501	1	12	\N	4031	38131	\N	54.345061745364802	"Рязанская область, Сасовский район, г. Сасово, микрорайон ""Южный"", 44а поликлинника"		0101000020E61000006FBA6587F8F34440D28BDAFD2A2C4B40
78499	1	12	\N	4031	38131	\N	54.354752484037903	"Рязанская область, Сасовский район, г. Сасово, микрорайон ""Южный"", 57 школа"	Россия, Рязанская область, Сасово	0101000020E610000099F04BFDBCF5444065187783682D4B40
78503	1	12	\N	4031	38267	\N	54.348925999999999	"Рязанская область, Сасовский район, г. Сасово, микрорайон ""Северный"", 57 ДК"		0101000020E610000044F8174163F64440AF5C6F9BA92C4B40
78502	1	12	\N	4031	38267	\N	54.348772342337298	"Рязанская область, Сасовский район, г. Сасово, микрорайон ""Северный"", 40 школа"		0101000020E6100000DD787764ACF6444058E1968FA42C4B40
78495	1	12	\N	4031	38246	\N	54.348925999999999	Рязанская область, Сасовский район, г. Сасово, Типанова, 2 Управление образования		0101000020E610000044F8174163F64440AF5C6F9BA92C4B40
78494	1	12	\N	4031	37985	\N	54.354088502216101	"Рязанская область, Сасовский район, г. Сасово, проспект Свободы, 19а кафе ""Цна"""	Россия, Рязанская область, Сасово	0101000020E6100000828DEBDFF5F34440CA6FD1C9522D4B40
78496	1	12	\N	4031	38035	\N	54.362069082858802	Рязанская область, Сасовский район, г. Сасово, Пушкина, 106 школа	Россия, Рязанская область, Сасово	0101000020E6100000F2272A1BD6F644409DF2E846582E4B40
78498	1	12	\N	4031	38210	\N	54.348925999999999	Рязанская область, Сасовский район, г. Сасово, Островитянова, 133 Распределительные сети		0101000020E610000044F8174163F64440AF5C6F9BA92C4B40
78492	1	12	\N	4031	38104	\N	54.346930894882902	Рязанская область, Сасовский район, г. Сасово, Ново-Елатомская, 31школа	Россия, Рязанская область, Сасово	0101000020E610000010B1C1C249F44440FA7B293C682C4B40
78491	1	12	\N	4031	38104	\N	54.345376426606002	Рязанская область, Сасовский район, г. Сасово, Ново-Елатомская, 31 школа	Россия, Рязанская область, Сасово	0101000020E6100000130F289B72F344406269E047352C4B40
78493	1	12	\N	4031	38206	\N	54.343019539471101	Рязанская область, Сасовский район, г. Сасово, Ленина, 34 школа	Россия, Рязанская область, Сасово	0101000020E61000005CAFE94141F54440DDEF5014E82B4B40
78490	1	12	\N	4031	38206	\N	54.341426036821197	Рязанская область, Сасовский район, г. Сасово, Ленина, 42 техникум	Россия, Рязанская область, Сасово	0101000020E610000047E9D2BF24F544408600E0D8B32B4B40
78500	1	12	\N	4031	38288	\N	54.348925999999999	Рязанская область, Сасовский район, г. Сасово, Киевская, 6 детский сад		0101000020E610000044F8174163F64440AF5C6F9BA92C4B40
78497	1	12	\N	4031	38105	\N	54.347822885418097	Рязанская область, Сасовский район, г. Сасово, Вокзальная, 18 ДК	Россия, Рязанская область, Сасово	0101000020E610000031410DDFC2F64440F7E5CC76852C4B40
78862	1	12	\N	1114	\N	\N	54.619427000000002	Рязанская область, г. Рязань, Мехзавода поселок, 25 (Средняя общеобразовательная школа №54)		0101000020E6100000DF8C9AAF92DD434034A14962494F4B40
78933	1	12	\N	1114	15395	\N	54.599679999999999	Рязанская область, г. Рязань, Новоселов, 58 (ООО Вектор+)	Россия, Рязанская область, Рязань, поселок Черезово-Песочня, улица Новоселов, 58	0101000020E610000036EA211ADDE943405B087250C24C4B40
78947	1	12	\N	1114	6827	\N	54.629444999999997	Рязанская область, г. Рязань, Щедрина проезд, 14 (Средняя общеобразовательная школа №8)	Россия, Рязанская область, Рязань, проезд Щедрина, 14	0101000020E6100000D46531B1F9E04340BBD05CA791504B40
78889	1	12	\N	1114	15923	\N	54.655766	Рязанская область, г. Рязань, пр. Шабулина, 22 (РССК РГРТУ)	Россия, Рязанская область, Рязань, поселок Приокский, проезд Шабулина, 20	0101000020E61000002904728923D5434014EAE923F0534B40
78845	1	12	\N	1114	5794	\N	54.604602999999997	Рязанская область, г. Рязань, Гоголя проезд, 5 (средняя общеобразовательная школа № 42)	Россия, Рязанская область, Рязань, проезд Гоголя, 5	0101000020E61000003065E08096DA4340200890A1634D4B40
78893	1	12	\N	1114	38334	\N	54.636889661639501	Рязанская область, г. Рязань, Юбилейная, 24 (Средняя общеобразовательная школа №55)		0101000020E61000001668774831D2434021938C9C85514B40
78938	1	12	\N	1114	38439	\N	54.618937000000003	Рязанская область, г. Рязань, Электрозаводская, 56 (Средняя общеобразовательная школа №14)		0101000020E6100000F08975AA7CE1434066A4DE53394F4B40
78843	1	12	\N	1114	38369	\N	54.595115999999997	Рязанская область, г. Рязань, Щорса, 38/11 (Россельхоз академия)		0101000020E61000001EDC9DB5DBDA4340C5A9D6C22C4C4B40
78841	1	12	\N	1114	38367	\N	54.599831999999999	Рязанская область, г. Рязань, Черновицкая, 23а  (Средняя общеобразовательная школа №64)		0101000020E610000002BA2F67B6DB4340118C834BC74C4B40
78840	1	12	\N	1114	38367	\N	54.599831999999999	Рязанская область, г.Рязань, Черновицкая, 23а  (Средняя общеобразовательная школа №64)		0101000020E610000002BA2F67B6DB4340118C834BC74C4B40
78914	1	12	\N	1114	38347	\N	54.603776790024703	Рязанская область, г. Рязань, Трудовая, 6/6 (Средняя общеобразовательная школа №41)	Россия, Рязанская область, Рязань, Октябрьский район, улица Бабушкина, 6/6	0101000020E61000006DAB59677CE14340DB899290484D4B40
78839	1	12	\N	1114	38364	\N	54.604343	Рязанская область, г.Рязань, Толстого, 5 (Средняя общеобразовательная школа №37)		0101000020E61000005B785E2A36DC43408448861C5B4D4B40
78838	1	12	\N	1114	38364	\N	54.604343	Рязанская область, г. Рязань, Толстого, 5 (Средняя общеобразовательная школа №37)		0101000020E61000005B785E2A36DC43408448861C5B4D4B40
78920	1	12	\N	1114	38447	\N	54.616242	Рязанская область, г. Рязань, Тимуровцев, 4 (Средняя общеобразовательная школа №50)		0101000020E6100000B1FD648C0FE54340F8359204E14E4B40
78930	1	12	\N	1114	38418	\N	54.61206	Рязанская область, г. Рязань, Тимакова, 7 (Средняя общеобразовательная школа №67)		0101000020E61000008995D1C8E7E743404A9869FB574E4B40
78929	1	12	\N	1114	38418	\N	54.61168	Рязанская область, г. Рязань, Тимакова, 9 (Средняя общеобразовательная школа №63)		0101000020E610000062BCE6559DE7434003CFBD874B4E4B40
78847	1	12	\N	1114	38445	\N	54.611299000000002	Рязанская область, г. Рязань, Стройкова, 86 (Средняя общеобразовательная школа №34)		0101000020E61000002F88484DBBDA4340EC89AE0B3F4E4B40
78884	1	12	\N	1114	38362	\N	54.636955	Рязанская область, г. Рязань, Солнечная, 6 (политехнический техникум)		0101000020E61000008CB96B09F9DC43400803CFBD87514B40
78922	1	12	\N	1114	38436	\N	54.609828999999998	Рязанская область, г.Рязань, Советской Армии, 24 кор 1 (Средняя общеобразовательная школа №9)		0101000020E6100000874D64E602E5434081936DE00E4E4B40
78923	1	12	\N	1114	38417	\N	54.610188000000001	Рязанская область, г. Рязань, Советской Армии, 15а (Средняя общеобразовательная школа №62)		0101000020E61000007B116DC7D4E54340B134F0A31A4E4B40
78960	1	12	\N	1114	38302	\N	54.633336917805103	Рязанская область, г. Рязань, Соборная площадь, 15 (Средняя общеобразовательная школа №4)	Россия, Рязанская область, Рязань, Советский район, улица Соборная, 16	0101000020E610000033C51C041DDF4340622CD32F11514B40
78959	1	12	\N	1114	38178	\N	54.632345742535499	Рязанская область, г. Рязань, Семинарская, 6 (Средняя общеобразовательная школа №6)	Россия, Рязанская область, Рязань, Советский район, Семинарская улица, 6	0101000020E61000002AC58EC6A1DE4340D2E0B6B6F0504B40
78952	1	12	\N	1114	38177	\N	54.619427000000002	Рязанская область, г. Рязань, Семинарская, 44/3 (Железнодорожный колледж)		0101000020E6100000DF8C9AAF92DD434034A14962494F4B40
78909	1	12	\N	1114	38319	\N	54.616574999999997	Рязанская область, г. Рязань, Семашко, 18 (административный корпус ОАО «Рязаньгоргаз»)		0101000020E6100000E256410C74DD4340FE43FAEDEB4E4B40
78870	1	12	\N	1114	38402	\N	54.691006000000002	Рязанская область, г. Рязань, Сельских Строителей, 4а (Средняя общеобразовательная школа №70)		0101000020E6100000B51A12F758D043407EAB75E272584B40
78935	1	12	\N	1114	38384	\N	54.583925999999998	Рязанская область, г. Рязань, Связи, 17а  (Средняя общеобразовательная школа №38)		0101000020E6100000F4C1323674E543405DA45016BE4A4B40
78936	1	12	\N	1114	38379	\N	54.583925999999998	Рязанская область, г. Рязань, Связи, 17а (Средняя общеобразовательная школа №38)		0101000020E6100000F4C1323674E543405DA45016BE4A4B40
78949	1	12	\N	1114	38443	\N	54.629044	Рязанская область, г. Рязань, Свободы, 46 (РГУ)		0101000020E6100000AB4203B16CE043405DDF878384504B40
78913	1	12	\N	1114	38304	\N	54.536172999999998	Рязанская область, г. Рязань, Предзаводская, 17 (Средняя общеобразовательная школа №49)		0101000020E6100000698F17D2E1E34340C5FF1D51A1444B40
78908	1	12	\N	1114	38372	\N	54.609943000000001	Рязанская область, г. Рязань, Полетаева, 30 корп 1 (общежитие № 4 ФГБОУ ВПО РГРТУ)		0101000020E61000001CCEFC6A0EDC43404AB6BA9C124E4B40
78869	1	12	\N	1114	38372	\N	54.606313999999998	Рязанская область, г. Рязань, Полетаева, 14 (Школа-интернат № 1 среднего общего образования)		0101000020E610000015562AA8A8DC4340B08D78B29B4D4B40
78956	1	12	\N	1114	38406	\N	54.595815000000002	Рязанская область, г. Рязань, Полевая, 38 (Автотранспортный техникум)		0101000020E61000006D58535914E64340AEBB79AA434C4B40
78954	1	12	\N	1114	6012	\N	54.628574999999998	Рязанская область, г. Рязань, Первомайский проспект, 17 (Дом офицеров)		0101000020E6100000742843554CDD4340A60A462575504B40
78953	1	12	\N	1114	6012	\N	54.628574999999998	Рязанская область, г. Рязань, Первомайский проспект, 17 (Спортзал Волна)		0101000020E6100000742843554CDD4340A60A462575504B40
78868	1	12	\N	1114	6012	\N	54.629721000000004	Рязанская область, г. Рязань, Первомайский проспект, 62 корп.1 (Средняя общеобразовательная школа №39)	Россия, Рязанская область, Рязань, Первомайский проспект, 62к1	0101000020E61000008692C9A99DDB43405E4D9EB29A504B40
78867	1	12	\N	1114	6012	\N	54.630102000000001	Рязанская область, г. Рязань, Первомайский проспект, 68 (МКЦ)	Россия, Рязанская область, Рязань, Первомайский проспект, 68	0101000020E6100000BDC804FC1ADB43407592AD2EA7504B40
78866	1	12	\N	1114	6012	\N	54.629643000000002	Рязанская область, г. Рязань, Первомайский проспект, 61 (Средняя общеобразовательная школа №13)	Россия, Рязанская область, Рязань, Первомайский проспект, 61	0101000020E6100000AF40F4A44CDA4340E2934E2498504B40
78846	1	12	\N	1114	38428	\N	54.606231000000001	Рязанская область, г. Рязань, Островского, 44 (Средняя общеобразовательная школа №33)		0101000020E6100000255AF2785ADA4340236937FA984D4B40
78837	1	12	\N	1114	38428	\N	54.604207000000002	Рязанская область, г.Рязань, Островского, 33 корп. 1 (Средняя общеобразовательная школа №19)		0101000020E6100000944BE3175EDB4340D481ACA7564D4B40
78836	1	12	\N	1114	38428	\N	54.605902	Рязанская область, г. Рязань, Островского, 24 (Средняя общеобразовательная школа №25)		0101000020E6100000E9D2BF2495DB43405E4A5D328E4D4B40
78860	1	12	\N	1114	38438	\N	54.607576000000002	Рязанская область, г. Рязань, Октябрьский городок, 39а (Техникум пищевой промышленности, общественного питания и сервиса города)		0101000020E610000016FA60191BD64340D1EAE40CC54D4B40
78882	1	12	\N	1114	16177	\N	54.663448000000002	"Рязанская область, г. Рязань, Октябрьская, 5 ДК ""Приокский"""	Россия, Рязанская область, Рязань, поселок Приокский, Октябрьская улица, 5	0101000020E61000002AA913D044D243405E4C33DDEB544B40
78886	1	12	\N	1114	38401	\N	54.657317999999997	"Рязанская область, г. Рязань, Октябрьская, 37 (ЦДТ ""Приокский"")"		0101000020E6100000B83F170D19D343403B8908FF22544B40
78887	1	12	\N	1114	38441	\N	54.653041999999999	Рязанская область, г. Рязань, Октябрьская, 56а (Средняя общеобразовательная школа №48)		0101000020E61000007217618A72D343400C7558E196534B40
78926	1	12	\N	1114	38424	\N	54.606507000000001	Рязанская область, г. Рязань, Новоселов, 30б (Средняя общеобразовательная школа №68)		0101000020E6100000E86B96CB46E74340C5E57805A24D4B40
78921	1	12	\N	1114	38426	\N	54.611454999999999	Рязанская область, г. Рязань, Новоселов, 6а (Средняя общеобразовательная школа №31)		0101000020E610000027C11BD2A8E44340E3FC4D28444E4B40
78895	1	12	\N	1114	38348	\N	54.631841999999999	Рязанская область, г. Рязань, Новаторов, 21а (Средняя общеобразовательная школа №60)		0101000020E61000008C852172FAD243409F1EDB32E0504B40
78894	1	12	\N	1114	38348	\N	54.631841999999999	Рязанская область, г. Рязань, Новаторов, 21 (Средняя общеобразовательная школа №61)		0101000020E61000008C852172FAD243409F1EDB32E0504B40
78958	1	12	\N	1114	38349	\N	54.629211885810001	Рязанская область, г. Рязань, Николодворянская, 19/40 (Средняя общеобразовательная школа №7)	Россия, Рязанская область, Рязань, Советский район, улица Полонского	0101000020E6100000A1BE654E97DF43401920D1048A504B40
78844	1	12	\N	1114	38394	\N	54.59787	Рязанская область, г. Рязань, Нахимова, 1  (Средняя общеобразовательная школа №57)		0101000020E6100000CA54C1A8A4DA434038A11001874C4B40
78842	1	12	\N	1114	38394	\N	54.594724999999997	Рязанская область, г. Рязань, Нахимова, 13 (Россельхоз академия)		0101000020E61000000C79043752DA43408A8EE4F21F4C4B40
78899	1	12	\N	1114	6347	\N	54.644145000000002	Рязанская область, г. Рязань, Московское шоссе, 18 (административное здание)	Россия, Рязанская область, Рязань, Московское шоссе, 18	0101000020E6100000C0CC77F013D54340E370E65773524B40
78863	1	12	\N	1114	15472	\N	54.618347999999997	"Рязанская область, г. Рязань, Михайловское шоссе, 63 ЗАО ""Рязаньагроснаб"""		0101000020E6100000A8A8FA95CED5434004C6FA06264F4B40
78948	1	12	\N	1114	38398	\N	54.639831000000001	Рязанская область, г. Рязань, Лесопарковая, 52 (ЗАО Речной порт)		0101000020E61000003C6A4C88B9E04340C6FB71FBE5514B40
78940	1	12	\N	1114	38396	\N	54.623493000000003	Рязанская область, г. Рязань, Лермонтова, 2 (Средняя общеобразовательная школа №36)		0101000020E61000006FD40AD3F7E2434079245E9ECE4F4B40
78939	1	12	\N	1114	38396	\N	54.622007000000004	Рязанская область, г. Рязань, Лермонтова, 22 (Средняя общеобразовательная школа №15)		0101000020E610000052F355F2B1E143400971E5EC9D4F4B40
78855	1	12	\N	1114	38410	\N	54.620109999999997	Рязанская область, г. Рязань, Ленинского Комсомола, 13 (Средняя общеобразовательная школа №44)		0101000020E61000001A14CD0358DC434016F6B4C35F4F4B40
78853	1	12	\N	1114	38410	\N	54.621642000000001	Рязанская область, г. Рязань, Ленинского Комсомола, 7 (Министерство социальной защиты населения Рязанской области)		0101000020E6100000D8D2A3A99EDC4340F7E80DF7914F4B40
78957	1	12	\N	1114	38358	\N	54.624738999999998	Рязанская область, г. Рязань, Ленина, 29 (Средняя общеобразовательная школа №10)		0101000020E61000000A4CA7751BE0434093C49272F74F4B40
78950	1	12	\N	1114	38358	\N	54.626604999999998	Рязанская область, г. Рязань, Ленина, 28 (ДМШ №1)		0101000020E6100000586FD40AD3DF43404A41B79734504B40
78945	1	12	\N	1114	38358	\N	54.621850999999999	Рязанская область, г. Рязань, Ленина, 1/70 (Рязанский филиал Московского института кьтуры)		0101000020E6100000E9F2E670ADE0434011FE45D0984F4B40
78916	1	12	\N	1114	398	\N	54.606558999999997	Рязанская область, г. Рязань, Куйбышевское шоссе, 2/1 (Средняя общеобразовательная школа №11)	Россия, Рязанская область, Рязань, Куйбышевское шоссе, 2/1	0101000020E61000005FCFD72C97E14340170CAEB9A34D4B40
78915	1	12	\N	1114	398	\N	54.605412000000001	"Рязанская область, г. Рязань, Куйбышевское шоссе, 9 (ООО ЖКО ""Соколовка"")"	Россия, Рязанская область, Рязань, Куйбышевское шоссе, 9	0101000020E610000071E82D1EDEE14340904DF2237E4D4B40
78955	1	12	\N	1114	38405	\N	54.627298000000003	Рязанская область, г. Рязань, Кудрявцева, 36 (Средняя общеобразовательная школа №18)		0101000020E610000068CF656A12DE4340516C054D4B504B40
78898	1	12	\N	1114	38399	\N	54.638513000000003	Рязанская область, г. Рязань, Крупской, 17 (РЭА Минэнерго)		0101000020E6100000C5E40D30F3D34340128942CBBA514B40
78892	1	12	\N	1114	38399	\N	54.640262999999997	Рязанская область, г. Рязань, Крупской, 7 (Средняя общеобразовательная школа №53)		0101000020E61000003A083A5AD5D243405FEB5223F4514B40
78883	1	12	\N	1114	38375	\N	54.664468999999997	Рязанская область, г. Рязань, Космонавтов, 13 (Лицеей №52)		0101000020E61000005C3AE63C63D34340581AF8510D554B40
78861	1	12	\N	1114	38346	\N	54.607304999999997	Рязанская область, г. Рязань, Керамзавода, 8а (Средняя общеобразовательная школа №22)		0101000020E610000020EF552B13D6434040D9942BBC4D4B40
78924	1	12	\N	1114	1277	\N	54.614035999999999	Рязанская область, г. Рязань, Касимовское шоссе, 38б (Средняя общеобразовательная школа №59)	Россия, Рязанская область, Рязань, Касимовское шоссе, 38б	0101000020E6100000213F1BB96EE6434088484DBB984E4B40
78852	1	12	\N	1114	1277	\N	54.624822000000002	Рязанская область, г. Рязань, Касимовское шоссе, 9 (МП Водоканал)	Россия, Рязанская область, Рязань, Касимовское шоссе, 9	0101000020E61000003C855CA967E3434021E9D32AFA4F4B40
78932	1	12	\N	1114	38354	\N	54.598678999999997	Рязанская область, г. Рязань, Зубковой, 28а (Средняя общеобразовательная школа №71)		0101000020E61000009DD5027B4CE84340A7E67283A14C4B40
78931	1	12	\N	1114	38354	\N	54.600129000000003	Рязанская область, г. Рязань, Зубковой, 27 (ЦДТ Октяборьский)		0101000020E61000002C634337FBE74340CB30EE06D14C4B40
78927	1	12	\N	1114	38354	\N	54.605589000000002	Рязанская область, г. Рязань, Зубковой, 22а (Средняя общеобразовательная школа №51)		0101000020E6100000DA8F149161E743409FE8BAF0834D4B40
78832	1	12	\N	1114	38354	\N	54.599074999999999	Рязанская область, г. Рязань, Зубковой, 30 кор 2 (Библиотека №7)		0101000020E61000001A868F8829E94340F46C567DAE4C4B40
78906	1	12	\N	1114	38313	\N	54.661840711905299	Рязанская область, г. Рязань, Забайкальская (Здание столовой 360 АРЗ)	Россия, Рязанская область, Рязань, поселок Дягилево, Забайкальская улица	0101000020E6100000DA006C4084CA43407313B534B7544B40
78918	1	12	\N	1114	38377	\N	54.618645000000001	Рязанская область, г. Рязань, Есенина, 57 (Средняя общеобразовательная школа №43)		0101000020E610000053B131AF23E04340BE6A65C22F4F4B40
78937	1	12	\N	1114	38459	\N	54.625010855496299	Рязанская область, г. Рязань, Есенина, 46 (Дворец детского творчества)		0101000020E61000008B33863941E14340F451465C00504B40
78850	1	12	\N	1114	38403	\N	54.6174948534251	Рязанская область, г. Рязань, Дзержинского, 78 (Средняя общеобразовательная школа №16)	Россия, Рязанская область, Рязань, Железнодорожный район, улица Дзержинского, 78	0101000020E6100000566133C005DD4340C5387F130A4F4B40
78854	1	12	\N	1114	38386	\N	54.622413999999999	Рязанская область, г. Рязань, Дзержинского, 42 (Муз. Колледж)		0101000020E61000005F42058717DC434049490F43AB4F4B40
78851	1	12	\N	1114	38386	\N	54.618572	Рязанская область, г. Рязань, Дзержинского, 71 (Средняя общеобразовательная школа №3)		0101000020E6100000613255302ADD4340541C075E2D4F4B40
78885	1	12	\N	1114	38392	\N	54.661568000000003	Рязанская область, г. Рязань, Дачная, 2а  (Средняя общеобразовательная школа №40)		0101000020E610000004763579CAD24340420A9E42AE544B40
78944	1	12	\N	1114	38450	\N	54.624124000000002	Рязанская область, г. Рязань, Горького, 49 (Средняя общеобразовательная школа №1)		0101000020E610000032569BFF57DF43400953944BE34F4B40
78946	1	12	\N	1114	38381	\N	54.626584000000001	Рязанская область, г. Рязань, Вознесенская, 44 (Специальная школа №23)		0101000020E6100000C45C52B5DDE0434033198EE733504B40
78900	1	12	\N	1114	38062	\N	54.636612330509102	Рязанская область, г. Рязань, Вишневая, 35 (ВПО РГАТУ)	Россия, Рязанская область, Рязань, Московский район, Вишневая улица, 35	0101000020E6100000ABCB290131D54340DE1E84807C514B40
78864	1	12	\N	1114	38435	\N	54.666989000000001	Рязанская область, г. Рязань, Весенняя, 14 (Средняя общеобразовательная школа №24)		0101000020E61000000327DBC01DD6434058E542E55F554B40
78891	1	12	\N	1114	38390	\N	54.643211999999998	Рязанская область, г. Рязань, Великанова, 9 (Средняя общеобразовательная школа №47)		0101000020E6100000247B849A21D34340873254C554524B40
78943	1	12	\N	1114	38204	\N	54.618118070309997	Рязанская область, г. Рязань, Введенская, 131 (Рязанский торгово-экономический техникум)	Россия, Рязанская область, Рязань, Советский район, Введенская улица, 131	0101000020E6100000508D976E12DF4340D388997D1E4F4B40
78879	1	12	\N	1114	38361	\N	54.662464	Рязанская область, г. Рязань, Бирюзова, 25а (Средняя общеобразовательная школа №66)		0101000020E6100000FA62EFC517D543408063CF9ECB544B40
78878	1	12	\N	1114	38361	\N	54.664608999999999	Рязанская область, г. Рязань, Бирюзова, 23а (Средняя общеобразовательная школа №65)		0101000020E6100000B39AAE27BAD443404AD05FE811554B40
78876	1	12	\N	1114	38361	\N	54.667858000000003	Рязанская область, г. Рязань, Бирюзова, 19а (Средняя общеобразовательная школа №35)		0101000020E6100000A435069D10D443409D2FF65E7C554B40
78875	1	12	\N	1114	38361	\N	54.670211999999999	Рязанская область, г. Рязань, Бирюзова, 13а (Средняя общеобразовательная школа №56)		0101000020E610000033E02C25CBD3434081B1BE81C9554B40
78871	1	12	\N	1114	38361	\N	54.676333999999997	Рязанская область, г. Рязань, Бирюзова, 2 (Профессиональное училище № 10)		0101000020E6100000F17F4754A8D243402096CD1C92564B40
78905	1	12	\N	1114	38299	\N	54.656115	Рязанская область, г. Рязань, Белякова, 7а, (Здание Дома офицеров)		0101000020E6100000E12879758EC9434020B58993FB534B40
78904	1	12	\N	1114	38315	\N	54.657477162509203	Рязанская область, г. Рязань, Белякова, 1а (Средняя общеобразовательная школа №21)	Россия, Рязанская область, Рязань, поселок Дягилево, улица Белякова, 1	0101000020E61000004417D4B7CCCB4340A46FD23428544B40
78901	1	12	\N	1114	38176	\N	54.632220385143498	Рязанская область, г. Рязань, Бахмачеевская, 34 (Средняя общеобразовательная школа №28)		0101000020E610000059DFC0E446D5434045F0BF95EC504B40
78910	1	12	\N	1114	38385	\N	54.605845000000002	Рязанская область, г. Рязань, Баженова, 36 корп 1 (ГОУ СПО «Рязанский медико-социальный колледж»)		0101000020E61000001E705D3123DE4340FAB836548C4D4B40
78902	1	12	\N	1114	38414	\N	54.644311000000002	Рязанская область, г. Рязань, Аллейная, 52 (Средняя общеобразовательная школа №30)		0101000020E6100000F3E49A0299CF4340FEB968C878524B40
78858	1	12	\N	1114	38432	\N	54.614035999999999	Рязанская область, г. Рязань, 9-я Линия, 18 (кооперативный техникум)		0101000020E61000003FC8B260E2D9434088484DBB984E4B40
78951	1	12	\N	1114	38216	\N	54.656167000000003	Рязанская область, г. Рязань, п. Борки 9-й район, (Средняя общеобразовательная школа №29)		0101000020E61000009AEC9FA701DB434073DBBE47FD534B40
78848	1	12	\N	1114	38298	\N	54.610605459695201	"Рязанская область, г. Рязань, 50-летия Октября площадь, МАУК ""Дворец молодежи города Рязани"	Россия, Рязанская область, Рязань, Железнодорожный район, улица Гагарина	0101000020E6100000B1A6B228ECDA434015E3FC4D284E4B40
78857	1	12	\N	1114	38430	\N	54.619124999999997	Рязанская область, г. Рязань, 2-я Линия, 25а (МОУ ДОД «СДЮСШОР по легкой атлетике»)		0101000020E6100000DD7D8E8F16DB43406891ED7C3F4F4B40
78856	1	12	\N	1114	38388	\N	54.618191000000003	Рязанская область, г. Рязань, 2-я Линия, 25 (спорткомплекс)		0101000020E6100000FE7C5BB054DB43403DD7F7E1204F4B40
78859	1	12	\N	1114	38382	\N	54.613425999999997	Рязанская область, г. Рязань, 12-я Линия, 1г (Техникум легкой промышленности и сферы обслуживания города Рязани)		0101000020E61000007FDC7EF964D943400F4240BE844E4B40
78934	1	12	\N	1114	38350	\N	54.589775000000003	Рязанская область, г. Рязань, 1-я Механизаторов, 25а (Средняя общеобразовательная школа №38)		0101000020E6100000944E24986AE64340CC7F48BF7D4B4B40
78890	1	12	\N	1114	38359	\N	54.644030000000001	Рязанская область, г. Рязань, 1-я Красная, 22а (ДОТ ЦРТДЮ)		0101000020E610000023F59ECA69D743404AD235936F524B40
95165	1	12	\N	1114	38510	\N	54.5758552796879	"Рязанская область, г. Рязань, Южный промузел, д.8  ЗАО ""РНПК"""		0101000020E6100000444DF4F928DF4340791EDC9DB5494B40
78865	1	12	\N	1114	38370	\N	54.624566999999999	Рязанская область, г. Рязань, Чкалова, 9а (Средняя общеобразовательная школа №17)		0101000020E61000003EEB1A2D07DA43409694BBCFF14F4B40
78917	1	12	\N	1114	38451	\N	54.612359418689699	Рязанская область, г. Рязань, Циолковского, 22 (ФГОУ СПО Рязанский государственный колледж отраслевых технологий, экономики и права  )		0101000020E6100000F2608BDD3EE14340A4349BC7614E4B40
78919	1	12	\N	1114	38397	\N	54.615448999999998	Рязанская область, г. Рязань, Урицкого, 2а (ГОУ ДПО «Рязанский областной институт развития образования»)		0101000020E61000002C2AE27492E143408EAD6708C74E4B40
78907	1	12	\N	1114	38408	\N	54.691006000000002	Рязанская область, г. Рязань, Сельских строителей, 4а (Средняя общеобразовательная школа №70		0101000020E6100000B51A12F758D043407EAB75E272584B40
78888	1	12	\N	1114	38440	\N	54.653376000000002	Рязанская область, г. Рязань, Пирогова, 11 (Средняя общеобразовательная школа №45)		0101000020E61000001B9FC9FE79D44340E3FE23D3A1534B40
78925	1	12	\N	1114	38380	\N	54.612352000000001	Рязанская область, г. Рязань, Новоселов, 17 кор 1 (Средняя общеобразовательная школа №72)		0101000020E61000007E71A94A5BE64340F2D1E28C614E4B40
78928	1	12	\N	1114	38404	\N	54.608305999999999	Рязанская область, г. Рязань, Новоселов, 28 (ОАО Рязанская НПНК3)		0101000020E6100000D27135B22BE74340F4FA93F8DC4D4B40
78897	1	12	\N	1114	38393	\N	54.636375999999998	Рязанская область, г. Рязань, Костычева, 1 (ВПО РГАТУ)		0101000020E6100000D8B79388F0D34340CAFACDC474514B40
78881	1	12	\N	1114	38374	\N	54.659277000000003	Рязанская область, г. Рязань, Карла Маркса, 4 корп.1 (Средняя общеобразовательная школа №46)		0101000020E61000008962F20698D14340A400513063544B40
78874	1	12	\N	1114	38368	\N	54.674834203722497	Рязанская область, г. Рязань, Интернациональная,5д Детский центр		0101000020E6100000317E1AF7E6D343404B1DE4F560564B40
78880	1	12	\N	1114	38411	\N	54.664588000000002	Рязанская область, г. Рязань, Интернациональная, 27 (Средняя общеобразовательная школа №69)		0101000020E6100000C576F700DDD5434033A8363811554B40
78872	1	12	\N	1114	38411	\N	54.675427999999997	Рязанская область, г. Рязань, Интернациональная, 6 (Средняя общеобразовательная школа №58)		0101000020E610000098DA520779D34340BE66B96C74564B40
78849	1	12	\N	1114	38400	\N	54.611252	Рязанская область, г. Рязань, Гагарина, 158 (Гимназия №5)		0101000020E6100000EEEC2B0FD2DB4340ABCE6A813D4E4B40
78877	1	12	\N	1114	38373	\N	54.667858000000003	Рязанская область, г. Рязань, Бирюзова, 19а (Средняя общеобразовательная школа №65)		0101000020E6100000A435069D10D443409D2FF65E7C554B40
78274	1	12	\N	54596	38220	\N	53.7094683839656	Рязанская область, Ряжский район, г.Ряжск, Строителей, 17, детский сад №8		0101000020E61000003F8F519E790B44407EC7F0D8CFDA4A40
78285	1	12	\N	54596	38577	\N	53.709060999999998	"Рязанская область, Ряжский район, г.Ряжск, Пожалостина, 15,  здание ОАО ""Ряжский элеватор"""		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78284	1	12	\N	54596	38496	\N	53.709060999999998	Рязанская область, Ряжский район, г.Ряжск, Новоряжская, 31, школа №4		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78279	1	12	\N	54596	38244	\N	53.7017527814888	Рязанская область, Ряжский район, г.Ряжск, Мичуринская, 122, клуб		0101000020E6100000A33D5E4887094440586FD40AD3D94A40
78283	1	12	\N	54596	38080	\N	53.709060999999998	Рязанская область, Ряжский район, г.Ряжск, Лермонтова, 2, дом детства		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78282	1	12	\N	54596	38266	\N	53.713032432532501	Рязанская область, Ряжский район, г.Ряжск, Кольцова, 28А, детский сад №1	Россия, Рязанская область, Ряжский район, Ряжск	0101000020E61000002FA2ED98BA0944403080F0A144DB4A40
78278	1	12	\N	54596	38247	\N	53.713312475507202	Рязанская область, Ряжский район, г.Ряжск, Горького, 115, техникум		0101000020E61000006E3315E29108444014ECBFCE4DDB4A40
78276	1	12	\N	54596	38283	\N	53.709060999999998	Рязанская область, Ряжский район, г.Ряжск, Гагарина, 11, Библиотека		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78239	1	12	\N	54596	38241	\N	53.709060999999998	Рязанская область, Ряжский район, г.Ряжск, Волгоградская, детский сад №6		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78263	1	12	\N	54589	38285	\N	54.725129000000003	Рязанская область, Рыбновский район, г.Рыбное, переулок Набережный, 2, школа № 1		0101000020E610000095F430B43AC14340CB30EE06D15C4B40
78267	1	12	\N	54589	38222	\N	54.723291049959002	" Рязанская область, Рыбновский район, г.Рыбное, Мира, 18, МОУ ""Лицей г.Рыбное"" "		0101000020E61000007D0569C6A2C14340DE3EABCC945C4B40
78265	1	12	\N	54589	38499	\N	54.725129000000003	Рязанская область, Рыбновский район, г.Рыбное, Куйбышева, 96, школа №5		0101000020E610000095F430B43AC14340CB30EE06D15C4B40
78325	1	12	\N	54646	\N	\N	54.604008999999998	Рязанская область, Рязанский район, п.Новоселки, здание детского сада	Россия, Рязанская область, Новоселки	0101000020E610000060AB048BC3F34340ADBEBA2A504D4B40
78058	1	12	\N	54591	38054	\N	54.230333000000002	Рязанская область, Михайловский район, г.Михайлов, Воеводина, 9-а ПУ 25		0101000020E61000001211FE45D082434044183F8D7B1D4B40
77981	1	12	\N	54625	38256	\N	53.919830278703103	Рязанская область, Кораблинский район, г. Кораблино, Коминтерна, д.36, здание школы №1	Россия, Рязанская область, Кораблинский район, Кораблино	0101000020E61000004B1FBAA0BE01444099F04BFDBCF54A40
77931	1	12	\N	8703	38462	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, академика В.Ф. Уткина, 5 ДК		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77930	1	12	\N	8703	38503	\N	54.934490526977498	Рязанская область, Касимовский район, г. Касимов, Широкая, 11, Детский сад	Россия, Рязанская область, Касимов	0101000020E610000012D9075916B4444003B4AD669D774B40
77941	1	12	\N	8703	38099	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Татарская, 7 (школа)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77937	1	12	\N	8703	38089	\N	54.940716999999999	"Рязанская область, Касимовский район, г. Касимов, Советская, 226 МП ""Городская управляющая компания"""		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77936	1	12	\N	8703	38089	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Советская, 199 (ДЮСШ)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77935	1	12	\N	8703	38089	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Советская, 195В (Начальная школа)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77932	1	12	\N	8703	38089	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Советская, 18 (ФГОУ СПО «Касимовский нефтегазовый техникум»)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77925	1	12	\N	8703	38224	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Северная, 1 (Оздоровительный центр)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77924	1	12	\N	8703	38235	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Приоский, 6 (Средняя общеобразовательная школа №6)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77923	1	12	\N	8703	38223	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Приокский, 6 (Средняя общеобразовательная школа №6)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77929	1	12	\N	8703	38228	\N	54.944274205523698	Рязанская область, Касимовский район, г. Касимов, Московская, 1 (Средняя общеобразовательная школа №4)	Россия, Рязанская область, Касимов	0101000020E6100000C9AA083719B34440473B6EF8DD784B40
77926	1	12	\N	8703	38228	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Московская, 67 (Средняя общеобразовательная школа)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77939	1	12	\N	8703	38227	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Ленина, 25 (Педагогический колледж)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77934	1	12	\N	8703	38281	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, К. Либкнехта, 6 библиотека		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77927	1	12	\N	8703	38225	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Затонная, 9Б (Библиотека)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77938	1	12	\N	8703	38097	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Гагарина, 1 (Школа)	Россия, Рязанская область, Касимов	0101000020E61000007BDCB75A27B2444047E5266A69784B40
77942	1	12	\N	8703	38193	\N	54.940716999999999	Рязанская область, Касимовский район, г. Касимов, Большакова, 51 (школа)		0101000020E61000007BDCB75A27B2444047E5266A69784B40
77933	1	12	\N	8703	38240	\N	54.944060359094003	Рязанская область, Касимовский район, г. Касимов, 50 лет ВЛКСМ, 26Б школа	Россия, Рязанская область, Касимов	0101000020E6100000BF4351A04FB244401BBB44F5D6784B40
78324	1	12	\N	19327	\N	\N	54.608258999999997	Рязанская область, Рязанский район, с.Дядьково, здание Дома культуры	Россия, Рязанская область, село Дядьково	0101000020E6100000AF95D05D12ED4340B33F506EDB4D4B40
78811	1	12	114	19821	\N	\N	54.386991000000002	Рязанская область, Шиловский район, с.Юшта, Помещение администрации  сельского поселения	Россия, Рязанская область, Шиловский район, поселок Юшта	0101000020E6100000D447E00F3F6B4440556CCCEB88314B40
78835	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Помещение Центра психолого - медико - социального сопров.	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78834	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Помещение Шиловской средней общеобразовательной школы № 2	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78833	1	12	114	20535	\N	\N	54.309097000000001	"Рязанская область, Шиловский район, р.п.Шилово, Помещение красного уголка Общежития № 2  ЗАО ""ОПС - Шилово"""	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78828	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Помещение Шиловского РЭС	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78827	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Помещение Первомайского Лесхоза	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78826	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Помещение Шиловской средней общеобразовательной школы № 3	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78825	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Здание бывшей детско-юношеской  спортивной школы	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78824	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Помещение Шиловской средней общеобразовательной школы № 1	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78760	1	12	1207	17113	38203	\N	54.029201	Рязанская область, Шацкий район, г. Шацк, Тараскина, здание ФГУ ДЭП-81		0101000020E6100000C3D8429083DC44405801BEDBBC034B40
78823	1	12	114	20535	\N	\N	54.309097000000001	Рязанская область, Шиловский район, р.п.Шилово, Помещение районного ДК	Россия, Рязанская область, Шиловский район, поселок Шилово	0101000020E6100000B439CE6DC26F44405725917D90274B40
78807	1	12	114	52418	\N	\N	54.305525000000003	Рязанская область, Шиловский район, д.Фролово, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Фролово	0101000020E61000008AAC3594DA434440228E75711B274B40
78817	1	12	114	20165	\N	\N	54.466250000000002	Рязанская область, Шиловский район, с.Тырново, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Тырново	0101000020E610000036E9B6442E84444048E17A14AE3B4B40
78815	1	12	114	19990	\N	\N	54.282786999999999	Рязанская область, Шиловский район, с.Тимошкино, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Тимошкино	0101000020E6100000EE04FBAF73774440F25D4A5D32244B40
78812	1	12	114	19829	\N	\N	54.406716000000003	Рязанская область, Шиловский район, с.Терехово, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Терехово	0101000020E610000043E21E4B1F784440466117450F344B40
78798	1	12	114	4595	\N	\N	54.473706	Рязанская область, Шиловский район, с.Сельцо-Сергиевка, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Сельцо-Сергиевка	0101000020E61000001EFB592C45904440A1F5F065A23C4B40
78769	1	12	114	17672	\N	\N	54.573698	Рязанская область, Шиловский район, с.Свинчус, школа	Россия, Рязанская область, Шиловский район, поселок Свинчус	0101000020E61000001F680586AC8A4440EBE3A1EF6E494B40
78796	1	12	114	54660	\N	\N	54.256910226820501	Рязанская область, Шиловский район, с.Сасыкино, Помещение дома культуры	Россия, Рязанская область, Шиловский район, поселок Саськино	0101000020E6100000FD3383F8C06A4440F701486DE2204B40
78795	1	12	114	54660	\N	\N	54.256709212511304	Рязанская область, Шиловский район, с.Сасыкино, Помещение филиала № 1 средней общеобразовательной школы	Россия, Рязанская область, Шиловский район, поселок Саськино	0101000020E61000009BAE27BA2E6A444060CB2BD7DB204B40
78809	1	12	114	19513	\N	\N	54.379975999999999	Рязанская область, Шиловский район, с.Санское, Помещение администрации сельского поселения	Россия, Рязанская область, Шиловский район, поселок Санское	0101000020E61000005778978BF8624440E8A1B60DA3304B40
78780	1	12	114	198	\N	\N	54.225800999999997	Рязанская область, Шиловский район, с.Сановка, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Сановка	0101000020E61000003A7AFCDEA66D4440B933130CE71C4B40
78785	1	12	114	18464	\N	\N	54.348705000000002	Рязанская область, Шиловский район, с.Пустополье, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Пустополье	0101000020E6100000335184D4ED544440D1798D5DA22C4B40
78829	1	12	114	20853	\N	\N	54.353717000000003	Рязанская область, Шиловский район, п.Прибрежный, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Прибрежный	0101000020E6100000E371512D2274444006854199462D4B40
78776	1	12	114	17780	\N	\N	54.667239000000002	Рязанская область, Шиловский район, с.Нармушадь, Помещение средней общеобразовательной школы	Россия, Рязанская область, Шиловский район, поселок Нармушадь	0101000020E6100000A67EDE54A48E4440D1CE691668554B40
78808	1	12	114	19622	\N	\N	54.381601000000003	Рязанская область, Шиловский район, с.Муратово, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Муратово	0101000020E6100000A7CF0EB8AE4644407A8F334DD8304B40
78803	1	12	114	19303	\N	\N	54.286124999999998	Рязанская область, Шиловский район, с.Мосолово, Помещение администрации поселения	Россия, Рязанская область, Шиловский район, поселок Мосолово	0101000020E61000007E5182FE42434440B4C876BE9F244B40
78801	1	12	114	19303	\N	\N	54.286124999999998	Рязанская область, Шиловский район, с.Мосолово, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Мосолово	0101000020E61000007E5182FE42434440B4C876BE9F244B40
78822	1	12	114	20301	\N	\N	54.210597	Рязанская область, Шиловский район, р.п.Лесной, Помещение админситрации городского поселеня	Россия, Рязанская область, Шиловский район, поселок Лесной	0101000020E61000008E1EBFB7E93B44405FD1ADD7F41A4B40
78821	1	12	114	20301	\N	\N	54.210597	Рязанская область, Шиловский район, р.п.Лесной, Помещение  средней общеобразовательной школы	Россия, Рязанская область, Шиловский район, поселок Лесной	0101000020E61000008E1EBFB7E93B44405FD1ADD7F41A4B40
78820	1	12	114	20301	\N	\N	54.210597	Рязанская область, Шиловский район, р.п.Лесной, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Лесной	0101000020E61000008E1EBFB7E93B44405FD1ADD7F41A4B40
78775	1	12	114	52386	\N	\N	54.798031999999999	Рязанская область, Шиловский район, д.Ладышкино, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Ладышкино	0101000020E610000030D978B0C5924440AB949EE925664B40
78773	1	12	114	17862	\N	\N	54.735844	Рязанская область, Шиловский район, с.Куземкино, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Куземкино	0101000020E61000009F758D96039744409A7ADD22305E4B40
78800	1	12	114	19207	\N	\N	54.181578999999999	Рязанская область, Шиловский район, с.Красный Холм, Помещение администрации сельского поселения	Россия, Рязанская область, Шиловский район, поселок Красный Холм	0101000020E6100000435376FA415B4440F8510DFB3D174B40
78611	1	12	124	10048	38547	\N	54.517299999999999	Рязанская область, Спасский район, с. Михали, Центральная, 38 (ДК)		0101000020E6100000CA4E3FA88B364440431CEBE236424B40
78802	1	12	114	19357	\N	\N	54.249917000000003	Рязанская область, Шиловский район, п.Красногвардейский, Помещение медпункта	Россия, Рязанская область, Шиловский район, поселок Красногвардейский	0101000020E610000015527E52ED45444073DBBE47FD1F4B40
78787	1	12	114	18568	\N	\N	54.317006999999997	Рязанская область, Шиловский район, с.Константиново, Помещение медпункта	Россия, Рязанская область, Шиловский район, поселок Константиново	0101000020E61000000F0D8B51D75C444031CD74AF93284B40
78814	1	12	114	19735	\N	\N	54.375197999999997	Рязанская область, Шиловский район, с.Ирицы, Помещение медпункта	Россия, Рязанская область, Шиловский район, поселок Ирицы	0101000020E61000002D9963795781444026C3F17C06304B40
78797	1	12	114	377	\N	\N	54.437493666084698	Рязанская область, Шиловский район, с.Инякино, детский сад	Россия, Рязанская область, Шиловский район, поселок Инякино	0101000020E6100000F5BD86E0B88E44401E19ABCDFF374B40
78794	1	12	114	52407	\N	\N	54.277520000000003	Рязанская область, Шиловский район, д.Ибредь, Помещение администрации сельского поселения	Россия, Рязанская область, Шиловский район, поселок Ибредь	0101000020E6100000E0F76F5E9C6E444033FE7DC685234B40
78805	1	12	114	19509	\N	\N	54.306144000000003	Рязанская область, Шиловский район, с.Заполье, ФАП		0101000020E6100000683F5244864B4440EEEE01BA2F274B40
78790	1	12	114	18468	\N	\N	54.605798	Рязанская область, Шиловский район, с.Занино-Починки, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Занино-Починки	0101000020E6100000D7DD3CD521A34440B9FDF2C98A4D4B40
78789	1	12	114	18468	\N	\N	54.605399375961497	Рязанская область, Шиловский район, с.Занино-Починки, Помещение администрации сельского поселения	Россия, Рязанская область, Шиловский район, поселок Занино-Починки	0101000020E61000003B8DB454DEA24440FB03E5B67D4D4B40
78784	1	12	114	18255	\N	\N	54.292042000000002	Рязанская область, Шиловский район, с.Задубровье, Помещение администрации сельского поселения	Россия, Рязанская область, Шиловский район, поселок Задубровье	0101000020E6100000AFB0E07EC05744407B87DBA161254B40
78777	1	12	114	18018	\N	\N	54.264432999999997	Рязанская область, Шиловский район, с.Желудево, Помещение общеобразовательной школы	Россия, Рязанская область, Шиловский район, поселок Желудево	0101000020E61000009961A3ACDF704440D87DC7F0D8214B40
78771	1	12	114	17726	\N	\N	54.704976000000002	Рязанская область, Шиловский район, с.Ерахтур, Помещение ДК	Россия, Рязанская область, Шиловский район, поселок Ерахтур	0101000020E6100000014C1938A0914440823B50A73C5A4B40
78818	1	12	114	20168	\N	\N	54.519354	Рязанская область, Шиловский район, с.Дубровка, Помещение медпункта	Россия, Рязанская область, Шиловский район, поселок Дубровка	0101000020E6100000537765170C8A4440FD851E317A424B40
78830	1	12	114	20860	\N	\N	54.335794	Рязанская область, Шиловский район, с.Борок, Помещение клуба	Россия, Рязанская область, Шиловский район, поселок Борок	0101000020E610000050560C57077A4440B5183C4CFB2A4B40
78770	1	12	114	17680	\N	\N	54.320903999999999	Рязанская область, Шиловский район, с.Боровое, Помещение администрации сельского поселения	Россия, Рязанская область, Шиловский район, поселок Боровое	0101000020E6100000051A6CEA3C904440EA93DC6113294B40
78768	1	12	114	17571	\N	\N	54.622059	Рязанская область, Шиловский район, с.Борки, Помещение средней общеобразовательной школы	Россия, Рязанская область, Шиловский район, поселок Борки	0101000020E61000008A3DB48F159444405B971AA19F4F4B40
78792	1	12	114	54680	\N	\N	54.642611671785403	Рязанская область, Шиловский район, с.Большие - Пекселы, Помещение медпункта	Россия, Рязанская область, Шиловский район, поселок Большые Пекселы	0101000020E6100000E7C2482F6AA3444032022A1C41524B40
78816	1	12	114	20067	\N	\N	54.311622999999997	Рязанская область, Шиловский район, с.Березово, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Березово	0101000020E6100000DE02098A1F81444038D73043E3274B40
78767	1	12	114	17466	\N	\N	54.464433999999997	Рязанская область, Шиловский район, с.Аделино, Помещение сельского клуба	Россия, Рязанская область, Шиловский район, поселок Аделино	0101000020E6100000761A69A9BCA344404293C492723B4B40
78766	1	12	114	17466	\N	\N	54.464433999999997	Рязанская область, Шиловский район,  с.Аделино, Помещение средней общеобразовательной школы	Россия, Рязанская область, Шиловский район, поселок Аделино	0101000020E6100000761A69A9BCA344404293C492723B4B40
78782	1	12	114	51975	\N	\N	54.241131000000003	Рязанская область, Шиловский район, д.Авдотьинка (ДИ), Помещение ДИ для престарелых и инвалидов	Россия, Рязанская область, Шиловский район, поселок Авдотьинка	0101000020E61000005CCCCF0D4D734440A1866F61DD1E4B40
78779	1	12	114	51975	\N	\N	54.241131000000003	Рязанская область, Шиловский район, д.Авдотьинка, Помещение бывшей начальной общеобразовательной школы	Россия, Рязанская область, Шиловский район, поселок Авдотьинка	0101000020E61000005CCCCF0D4D734440A1866F61DD1E4B40
78763	1	12	1207	17361	38543	\N	54.122146000000001	Рязанская область, Шацкий район, с. Ямбирно, Центральная, здание школы		0101000020E6100000FD8348861C0B45402AABE97AA20F4B40
78755	1	12	1207	16841	38671	\N	54.100389999999997	Рязанская область, Шацкий район,  с. Шевырляй, Центральная, здание администрации		0101000020E610000023F609A018CB4440376C5B94D90C4B40
78761	1	12	1207	17113	38107	\N	54.029201	Рязанская область, Шацкий район,  г. Шацк, Энгельса, здание Дома творчества		0101000020E6100000C3D8429083DC44405801BEDBBC034B40
78759	1	12	1207	17113	74891	\N	54.029201	Рязанская область, Шацкий район,  г. Шацк, Республиканская площадь, здание СДК	Россия, Рязанская область, Шацкий район, Шацк	0101000020E6100000C3D8429083DC44405801BEDBBC034B40
78718	1	12	1207	15099	38697	\N	53.889757000000003	Рязанская область, Шацкий район, с. Шарик, Центральная, здание администрации		0101000020E6100000FBB1497EC40D45408C31B08EE3F14A40
78757	1	12	1207	54604	38125	\N	54.015493650871903	Рязанская область, Шацкий район, с. Черная слобода, Морина, здание школы	Россия, Рязанская область, Шацкий район, поселок Черная Слобода	0101000020E6100000053411363CDD444061A417B5FB014B40
78756	1	12	1207	54604	38326	\N	54.017667182445301	Рязанская область, Шацкий район, с. Черная Слобода, Базарная, здание СДК	Россия, Рязанская область, Шацкий район, поселок Черная Слобода	0101000020E610000078465B9544DE4440F69B89E942024B40
78707	1	12	1207	14619	38666	\N	54.189145000000003	Рязанская область, Шацкий район, с. Федяево, Центральная, здание библиотеки		0101000020E6100000AE11C138B8D24440D99942E735184B40
78744	1	12	1207	16210	38668	\N	53.960729999999998	Рязанская область, Шацкий район,  с. Федосово, Центральная, здание СДК		0101000020E6100000C25087156EB344409E245D33F9FA4A40
78726	1	12	1207	15498	38615	\N	54.060645999999998	Рязанская область, Шацкий район, с. Темешево, Центральная, здание ФАП		0101000020E6100000AF7AC03C64FA44400D51853FC3074B40
78751	1	12	1207	16775	38700	\N	53.946329460816202	Рязанская область, Шацкий район, с. Тарадеи, Центральная, здание библиотеки	Россия, Рязанская область, Шацкий район, поселок Тарадей	0101000020E61000008A592F8672CC4440D120054F21F94A40
78739	1	12	1207	16153	38694	\N	53.89622	Рязанская область, Шацкий район, д. Сявель, Центральная, здание ФАП		0101000020E6100000D942908312F84440B4024356B7F24A40
78738	1	12	1207	15930	38792	\N	53.856743000000002	Рязанская область, Шацкий район,  с. Старочернеево, Центральная, здание СДК		0101000020E6100000F56393FC88ED4440D9092FC1A9ED4A40
78728	1	12	1207	15598	38672	\N	54.102463999999998	Рязанская область, Шацкий район,  с. Сново-Здорово, Центральная, здание СДК		0101000020E6100000D427B9C326EE44403882548A1D0D4B40
78734	1	12	1207	54669	38704	\N	54.003273	Рязанская область, Шацкий район,  п. Свеженькая, Центральная, здание администрации		0101000020E61000008CF4A276BF364540DBFAE93F6B004B40
78733	1	12	1207	15866	38667	\N	53.894145000000002	Рязанская область, Шацкий район,  п. Садовый, Центральная, здание ФАП		0101000020E6100000874D64E602CF4440E370E65773F24A40
78747	1	12	1207	16518	38720	\N	53.989516999999999	Рязанская область, Шацкий район, с. Польное Ялтуново, Центральная, здание СДК		0101000020E6100000CFBD874B8EED444003EB387EA8FE4A40
78748	1	12	1207	16518	38618	\N	53.989516999999999	Рязанская область, Шацкий район,  с. Польное Ялтуново, Набережная, здание библиотеки		0101000020E6100000CFBD874B8EED444003EB387EA8FE4A40
78730	1	12	1207	15686	38542	\N	54.052280000000003	Рязанская область, Шацкий район,  с. Польное Конобеево, Центральная, здание Шацкая МТС		0101000020E6100000DBA7E33103F54440111E6D1CB1064B40
78745	1	12	1207	16463	38669	\N	53.822654999999997	Рязанская область, Шацкий район,  с. Печины, Центральная, здание СДК		0101000020E6100000251FBB0B94E24440087250C24CE94A40
78742	1	12	1207	16065	38613	\N	53.866688000000003	Рязанская область, Шацкий район, д. Парсаты, Центральная, здание СДК		0101000020E6100000889CBE9EAFF14440F7EAE3A1EFEE4A40
78743	1	12	1207	16163	38695	\N	53.880564999999997	Рязанская область, Шацкий район,  с. Ольхи, Центральная, здание СДК		0101000020E6100000073F7100FDBE444049809A5AB6F04A40
78736	1	12	1207	15976	38612	\N	53.885522000000002	Рязанская область, Шацкий район, с Новочернеево, Центральная, здание СДК		0101000020E610000031444E5FCFE74440BBF1EEC858F14A40
78710	1	12	1207	14732	38691	\N	53.910035784711901	Рязанская область, Шацкий район, с. Новософьино, Центральная, здание школы	Россия, Рязанская область, Шацкий район, поселок Новософьино	0101000020E61000000EF8FC3042DE44406117450F7CF44A40
78723	1	12	1207	15345	38696	\N	54.072429999999997	Рязанская область, Шацкий район, с. Новоселки, Центральная, здание СДК		0101000020E6100000007157AF220B4540E89FE06245094B40
78729	1	12	1207	15587	38705	\N	54.038223000000002	Рязанская область, Шацкий район,  с. Лесное Конобеево, Центральная, здание школы		0101000020E6100000C974E8F4BCF544403E7AC37DE4044B40
78750	1	12	1207	16677	38614	\N	54.003109000000002	Рязанская область, Шацкий район, с. Лесное Ялтуново, Центральная, здание СДК		0101000020E61000003AE8120EBDF3444061A92EE065004B40
78731	1	12	1207	15772	38611	\N	53.867032999999999	Рязанская область, Шацкий район, с. Лесная Поляна, Центральная, здание СДК		0101000020E6100000DCDAC2F352D54440C1C6F5EFFAEE4A40
78725	1	12	1207	15490	38609	\N	54.1004	Рязанская область, Шацкий район, с. Кучасьево, Центральная, здание школы		0101000020E6100000E199D024B1FE44405B423EE8D90C4B40
78724	1	12	1207	15201	38702	\N	54.042039724739901	Рязанская область, Шацкий район, с. Купля, Центральная, здание администрации	Россия, Рязанская область, Шацкий район, поселок Купля	0101000020E6100000FC51D4997B0C4540DA8F149161054B40
78752	1	12	1207	16679	38698	\N	53.939994912962597	Рязанская область, Шацкий район,  с. Кулики, Центральная, здание ФАП	Россия, Рязанская область, Шацкий район, поселок Кулики	0101000020E61000009DD843FB58C34440A7B393C151F84A40
78705	1	12	1207	14343	38689	\N	53.876742999999998	Рязанская область, Шацкий район,  с. Кривая Лука, Центральная, здание школы		0101000020E6100000C7F65AD07BCB44409BFF571D39F04A40
78765	1	12	1207	17417	38699	\N	54.088487999999998	Рязанская область, Шацкий район, с. Красный Холм, Центральная, здание библиотеки		0101000020E61000005E2EE23B31194540520B2593530B4B40
78717	1	12	1207	15054	38621	\N	53.853428000000001	Рязанская область, Шацкий район, с. Кермись, Центральная, здание администрации		0101000020E61000005D1ABFF04A0A4540CFBEF2203DED4A40
70437	1	11	\N	9161	7375	\N	52.985281999999998	г. Орел, Московское шоссе, 1А		0101000020E610000032772D211F0E424032AB77B81D7E4A40
78708	1	12	1207	14630	38790	\N	54.086967000000001	Рязанская область, Шацкий район, с. Карнаухово, Центральная, здание администрации		0101000020E61000003DB5FAEAAADE4440666A12BC210B4B40
78715	1	12	1207	54633	38310	\N	54.003990180001203	Рязанская область, Шацкий район, с. Казачья Слобода, Центральная, здание школы	Россия, Рязанская область, Шацкий район, поселок Казачья-Слобода	0101000020E6100000A0A52BD846DA44406AC18BBE82004B40
78716	1	12	1207	54633	38337	\N	54.003939222336498	Рязанская область, Шацкий район,  с. Казачья Слобода, Ленина, здание СДК	Россия, Рязанская область, Шацкий район, поселок Казачья-Слобода	0101000020E6100000899AE8F351DA4440E816BA1281004B40
78754	1	12	1207	16885	38616	\N	54.012484999999998	Рязанская область, Шацкий район,  с. Казачий Дюк, Центральная, здание библиотеки		0101000020E61000001213D4F02DC644406458C51B99014B40
78714	1	12	1207	14921	38540	\N	54.162678999999997	Рязанская область, Шацкий район,  с. Каверино, Центральная, здание СДК		0101000020E61000008D7F9F71E1E244407C5F5CAAD2144B40
78712	1	12	1207	14778	38665	\N	53.963219000000002	Рязанская область, Шацкий район, с. Завидное, Центральная, здание СДК		0101000020E61000008DB62A89EC07454063F19BC24AFB4A40
78713	1	12	1207	14914	38610	\N	53.94529	Рязанская область, Шацкий район, с. Желанное, ул. Плетнева, школа		0101000020E6100000FF93BF7B470B4540309E4143FFF84A40
78721	1	12	1207	15282	38692	\N	54.028449999999999	Рязанская область, Шацкий район, с. Выша, Центральная, ДК		0101000020E6100000D9CF6229920D45401DC9E53FA4034B40
78746	1	12	1207	16480	38617	\N	53.859763999999998	Рязанская область, Шацкий район, с. Высокое, Центральная, здание СДК		0101000020E61000007FF8F9EFC1E544409A232BBF0CEE4A40
78704	1	12	1207	14445	38664	\N	53.945872999999999	Рязанская область, Шацкий район,  п. Вачкас, Центральная, здание СДК		0101000020E61000001329CDE671DC4440AF95D05D12F94A40
78722	1	12	1207	15296	38794	\N	54.024281999999999	Рязанская область, Шацкий район, с. Важная, Центральная, школа		0101000020E610000077A38FF9800C4540D4F02DAC1B034B40
78709	1	12	1207	14720	38690	\N	53.948506000000002	Рязанская область, Шацкий район, с. Борки, Центральная, здание СДК		0101000020E61000000168942EFDE94440A70705A568F94A40
78706	1	12	1207	14535	38791	\N	54.123539000000001	Рязанская область, Шацкий район, с. Большое Агишево, Центральна, здание администрации		0101000020E61000008B8862F206DE4440E9633E20D00F4B40
78701	1	12	1207	14334	38787	\N	53.808807000000002	Рязанская область, Шацкий район,  с. Апушка, Центральная, здание СДК		0101000020E6100000C74961DEE3C0444050E3DEFC86E74A40
78700	1	12	363	14251	\N	\N	54.296208999999998	Рязанская область, Чучковский район, село Шеметово, здание  сельской  администрации	Россия, Рязанская область, Чучковский район, поселок Шеметово	0101000020E610000011001C7BF6C44440F3E32F2DEA254B40
78698	1	12	363	14145	\N	\N	54.265590000000003	Рязанская область, Чучковский район, поселок Чучково, здание  школы	Россия, Рязанская область, Чучковский район, поселок Чучково	0101000020E61000000AF2B391EBBA4440841266DAFE214B40
78697	1	12	363	14145	\N	\N	54.265590000000003	Рязанская область, Чучковский район, поселок Чучково, здание  администрации  городского поселения	Россия, Рязанская область, Чучковский район, поселок Чучково	0101000020E61000000AF2B391EBBA4440841266DAFE214B40
78699	1	12	363	14145	38608	\N	54.265590000000003	Рязанская область, Чучковский район, поселок  Чучково, Сосновая, Культурно-досуговый  центр  Русь		0101000020E61000000AF2B391EBBA4440841266DAFE214B40
78696	1	12	363	14062	\N	\N	54.408549999999998	Рязанская область, Чучковский район, село  Церлево, здание  школы	Россия, Рязанская область, Чучковский район, поселок Церлево	0101000020E6100000CBB9145795C74440F163CC5D4B344B40
78695	1	12	363	14056	\N	\N	54.242508999999998	Рязанская область, Чучковский район, село  Протасьев  Угол, здание  сельской  администрации	Россия, Рязанская область, Чучковский район, поселок Протасьев Угол	0101000020E6100000CD74AF93FAA444402AFEEF880A1F4B40
78694	1	12	363	13974	\N	\N	54.359980999999998	Рязанская область, Чучковский район, село  Пертово, Дом  культуры		0101000020E610000012C2A38D23C2444037177FDB132E4B40
78693	1	12	363	1864	\N	\N	54.196904000000004	Рязанская область, Чучковский район, село  Остро-Пластиково, здание  школы	Россия, Рязанская область, Чучковский район, поселок Остро-Пластиково	0101000020E6100000D5CC5A0A48AF4440CE39782634194B40
78692	1	12	363	13876	\N	\N	54.300074172919402	Рязанская область, Чучковский район, село  Назаровка, Медпункт	Россия, Рязанская область, Чучковский район, поселок Назаровка	0101000020E6100000143FC6DCB5A64440A13028D368264B40
78691	1	12	363	13854	\N	\N	54.424942999999999	Рязанская область, Чучковский район, село Мелехово, здание  администрации  поселения	Россия, Рязанская область, Чучковский район, поселок Мелехово	0101000020E61000001DE5603601B0444002D53F8864364B40
78688	1	12	363	47060	\N	\N	54.332279900180097	Рязанская область, Чучковский район, с. Красное Озеро, здание  администрации   поселения	Россия, Рязанская область, Чучковский район, поселок Красное Озеро	0101000020E6100000E3A59BC420D44440B48EAA26882A4B40
78686	1	12	363	13591	\N	\N	54.246265999999999	Рязанская область, Чучковский район, село Кистенево, Дом  культуры		0101000020E61000001C40BFEFDFC24440F10EF0A4851F4B40
78685	1	12	363	13579	\N	\N	54.287106999999999	Рязанская область, Чучковский район, село  Завидово, Дом культуры		0101000020E610000055DFF94509A84440F1B913ECBF244B40
78684	1	12	363	13492	\N	\N	54.192025999999998	Рязанская область, Чучковский район, село Дудкино, Здание  администрации  поселения	Россия, Рязанская область, Чучковский район, поселок Дудкино	0101000020E6100000D57B2AA73DC14440A8FDD64E94184B40
78683	1	12	363	13488	\N	\N	54.336402999999997	Рязанская область, Чучковский район, поселок Дубровка, Дом культуры		0101000020E6100000202A8D98D9A744405DA3E5400F2B4B40
78681	1	12	363	13349	\N	\N	54.144055000000002	Рязанская область, Чучковский район, село  Алеево, здание  администрации  поселения	Россия, Рязанская область, Чучковский район, поселок Алеево	0101000020E610000084656CE866B54440A3E9EC6470124B40
78680	1	12	363	13311	\N	\N	54.275601000000002	Рязанская область, Чучковский район, село Аладьино, здание  администрации поселения	Россия, Рязанская область, Чучковский район, поселок Аладьино	0101000020E6100000A036AAD381D6444059DFC0E446234B40
78679	1	12	363	13301	\N	\N	54.269159999999999	Рязанская область, Чучковский район, п. Авангард,  Дом культуры		0101000020E61000009CE1067C7EC8444018B2BAD573224B40
78674	1	12	1014	13030	38687	\N	53.821933098367701	Рязанская область, Ухоловский район, с. Ясенок, Однодворцы, 1 школа	Россия, Рязанская область, Ухоловский район, поселок Ясенок	0101000020E6100000844BC79C673044406840BD1935E94A40
78673	1	12	1014	13016	38623	\N	53.722574000000002	Рязанская область, Ухоловский район, с. Чуриловка, Молодежная, 11 ФАП		0101000020E6100000ED612F14B03544404F78094E7DDC4A40
78677	1	12	1014	13067	38058	\N	53.799852000000001	"Рязанская область, Ухоловский район, р.п. Ухолово, Совхозная, 20 А СПК ""Маяк"""		0101000020E6100000C4094CA7753D4440F2D1E28C61E64A40
78678	1	12	1014	13067	38094	\N	53.799852000000001	Рязанская область, Ухоловский район, р.п. Ухолово, Советская, 15 ДК		0101000020E6100000C4094CA7753D4440F2D1E28C61E64A40
78675	1	12	1014	13067	38789	\N	53.799852000000001	Рязанская область, Ухоловский район, р.п.Ухолово, Гагарина, 15 ДК		0101000020E6100000C4094CA7753D4440F2D1E28C61E64A40
78670	1	12	1014	12856	38685	\N	53.869267173657903	Рязанская область, Ухоловский район, с. Соловачево, Юбилейная, 10 ФАП	Россия, Рязанская область, Ухоловский район, поселок Соловачево	0101000020E61000004C530438BD3F4440FB3E1C2444EF4A40
78669	1	12	1014	12813	38661	\N	53.695729	Рязанская область, Ухоловский район, с. Смолеевка, Молодежная, 14 ДК		0101000020E610000024F25D4A5D4444407CF0DAA50DD94A40
78668	1	12	1014	12808	38793	\N	53.895260356058003	Рязанская область, Ухоловский район, с. Покровское, Центральная, 18 ДК	Россия, Рязанская область, Ухоловский район, поселок Покровское	0101000020E61000008E3D7B2E533744405FB532E197F24A40
78661	1	12	1014	12481	38683	\N	53.775149780884298	"Рязанская область, Ухоловский район, с. Погореловка, Правобережная, 11 КФХ ""Зоринское"""	Россия, Рязанская область, Ухоловский район, поселок Погореловка	0101000020E61000009FAEEE586C3B444048BF7D1D38E34A40
78665	1	12	1014	12651	38786	\N	53.830897999999998	Рязанская область, Ухоловский район, с. Ольхи, Центральная, 46 ДК		0101000020E610000012BD8C62B9374440E9279CDD5AEA4A40
78656	1	12	1014	12250	38607	\N	53.757968770659303	Рязанская область, Ухоловский район, с. Мостье, Школьная, 9 школа	Россия, Рязанская область, Ухоловский район, поселок Мостье	0101000020E61000005F5D15A8C5464440E030D12005E14A40
78664	1	12	1014	12587	38670	\N	53.651702	Рязанская область, Ухоловский район, с. Лубянки, Центральная, 17 школа		0101000020E610000083C13577F4334440705E9CF86AD34A40
78654	1	12	1014	12106	38663	\N	53.810077	Рязанская область, Ухоловский район, п. Красный, Центральная, 8 администрация		0101000020E6100000787AA52C43584440F31E679AB0E74A40
78658	1	12	1014	12342	38605	\N	53.610689999999998	Рязанская область, Ухоловский район, с. Коноплино, Школьный переулок, 5 школа		0101000020E6100000840EBA84434F444043FF04172BCE4A40
78663	1	12	1014	12583	38784	\N	53.656664999999997	Рязанская область, Ухоловский район, с. Кобылино, Центральная, 26 школа		0101000020E61000007845F0BF953A4440C3B645990DD44A40
78659	1	12	1014	8776	38606	\N	53.767660999999997	Рязанская область, Ухоловский район, с. Кензино, Аничкова, 39 ДК		0101000020E610000001F8A7548930444013B534B742E24A40
78653	1	12	1014	12096	38785	\N	53.751376999999998	Рязанская область, Ухоловский район, п. Калинин, Новоселов, 2 ДК		0101000020E610000001892650C4544440B9FB1C1F2DE04A40
78652	1	12	1014	12013	38783	\N	53.779026999999999	Рязанская область, Ухоловский район, с. Дегтяные Борки, Центральная, 3 ДК		0101000020E61000000F80B8AB575D4440BAD91F28B7E34A40
78651	1	12	1014	11988	38681	\N	53.616325000000003	Рязанская область, Ухоловский район, с. Волынщино, Центральная, 35 ФАП		0101000020E6100000D5CE30B5A5444440865AD3BCE3CE4A40
78650	1	12	1014	11899	38679	\N	53.550837000000001	Рязанская область, Ухоловский район, с. Богородицкое, Солнечная, 14 детский сад		0101000020E61000003D997FF44D4A4440A036AAD381C64A40
78638	1	12	885	11337	38721	\N	54.303727770273298	Рязанская область, Старожиловский район, с. Чернобаево, Колхозная, 59 администрация	Россия, Рязанская область, Старожиловский район, поселок Чернобаево	0101000020E61000002EC72B103DFB43409370218FE0264B40
78632	1	12	885	10978	38202	\N	54.234918550324103	Рязанская область, Старожиловский район, р.п. Старожилово, Школьная, 14 ДК	Россия, Рязанская область, Старожиловский район, поселок Старожилово	0101000020E6100000ADF6B0170AF44340C11A67D3111E4B40
78630	1	12	885	10978	38275	\N	54.230342999999998	Рязанская область, Старожиловский район, р.п.Старожилово, Советская, 5 ДК		0101000020E61000001F477364E5F3434067EE21E17B1D4B40
78631	1	12	885	10978	38061	\N	54.230342999999998	Рязанская область, Старожиловский район, р.п. Старожилово, Денисова, 16 школа		0101000020E61000001F477364E5F3434067EE21E17B1D4B40
78635	1	12	885	11219	38674	\N	54.14781	Рязанская область, Старожиловский район, д. Соха, Новая, 1А школа		0101000020E61000003621AD31E8E84340C9022670EB124B40
78641	1	12	885	9578	38323	\N	54.167493584285801	Рязанская область, Старожиловский район, п. с-за им. Ленина, Советская, 8 администрация	Россия, Рязанская область, Старожиловский район, поселок Совхоз Имени Ленина	0101000020E61000003049658A39FE43405B23827170154B40
78639	1	12	885	6746	38088	\N	54.263939000000001	Рязанская область, Старожиловский район, п. Рязанские Сады, Весенняя, 4 администрация		0101000020E6100000B1E07EC003FB4340C991CEC0C8214B40
78633	1	12	885	11102	38795	\N	54.236879000000002	Рязанская область, Старожиловский район, д. Панинская Слобода, Молодежная, 2 администрация		0101000020E6100000D4F2035779E04340FA0D130D521E4B40
78645	1	12	885	11682	38458	\N	54.157428000000003	Рязанская область, Старожиловский район, д. Мелекшино, Речная, 2Б администрация		0101000020E61000000DAB7823F3184440C3BCC79926144B40
78634	1	12	885	11151	\N	\N	54.336424000000001	Рязанская область, Старожиловский район, с. Киселево, 39 Здание администрации поселения		0101000020E61000006B11514CDEE0434075CB0EF10F2B4B40
78640	1	12	885	11470	38277	\N	54.296162457735001	Рязанская область, Старожиловский район, с. Истье, Центральная, 20 ДК	Россия, Рязанская область, Старожиловский район, поселок Истье	0101000020E6100000EA793716140E4440B328ECA2E8254B40
78636	1	12	885	11238	\N	\N	54.2353215769703	Рязанская область, Старожиловский район, с. Ивановское, 72, Дом культуры	Россия, Рязанская область, Старожиловский район, поселок Ивановское	0101000020E6100000E5EFDE5163EE4340C00303081F1E4B40
78646	1	12	885	11732	38539	\N	54.218446999999998	Рязанская область, Старожиловский район, д. Ершово, Молодежная, 20 ДК		0101000020E610000055A69883A019444064744012F61B4B40
78637	1	12	885	11328	\N	\N	54.361949000000003	Рязанская область, Старожиловский район, с. Гребнево, 70А Дом культуры		0101000020E6100000DD94F25A09FB4340F3E84658542E4B40
78642	1	12	885	11567	38604	\N	54.174132999999998	Рязанская область, Старожиловский район, с. Большие Поляны, Колхозная, 3 администрация		0101000020E61000000953944BE3F94340C2137AFD49164B40
78644	1	12	885	11653	38629	\N	54.145854	Рязанская область, Старожиловский район, д. Аристово, Центральная, 1 администрация		0101000020E6100000AB06616EF71A4440D2FE0758AB124B40
78629	1	12	124	10930	38782	\N	54.557479999999998	Рязанская область, Спасский район, с. Федотьево, Школьная, 11 (администрация)		0101000020E61000008FE21C75742A4440481630815B474B40
78606	1	12	124	9792	\N	\N	54.416880999999997	Рязанская область, Спасский район, с. Фатьяновка, 100 (ФАП)		0101000020E6100000711C78B5DC37444071A94A5B5C354B40
78587	1	12	124	257	38749	\N	54.209944	Рязанская область, Спасский район, д. Ухорское, Школьная, 1 (Администрация)		0101000020E61000004A7CEE04FB214440E7FEEA71DF1A4B40
78605	1	12	124	9740	38546	\N	54.439366	Рязанская область, Спасский район, с. Устрань, Кооперативная, 1 (Средняя общеобразовательная школа)		0101000020E6100000AED85F764F3E4440B77C24253D384B40
78625	1	12	124	10743	38457	\N	54.397590999999998	Рязанская область, Спасский район, с. Троица, ул. Школьная,  д. 2а школа		0101000020E610000010E9B7AF031D44408B170B43E4324B40
78600	1	12	124	9354	38535	\N	54.280569	Рязанская область, Спасский район, с.Сушки, Административная, 1 (Администрация)		0101000020E61000003C1570CFF32F4440BEA25BAFE9234B40
78603	1	12	124	54692	38813	\N	54.490362471168297	Рязанская область, Спасский район, с. Старый Киструс, Школьная, 52 (Средняя общеобразовательная школа)	Россия, Рязанская область, Спасский район, поселок Старый Киструсс	0101000020E6100000AE0E80B8AB494440BF99982EC43E4B40
78613	1	12	124	10187	38552	\N	54.547412999999999	Рязанская область, Спасский район, с. Старое Тонино, Федина, 10 (администрация)		0101000020E610000055C03DCF9F444440DF3312A111464B40
78586	1	12	124	8865	\N	\N	54.303758999999999	"Рязанская область, Спасский район, п. Спиртзаводской (ООО ""Экстра"")"	Россия, Рязанская область, Спасский район, поселок Спиртзаводской	0101000020E61000005BB22AC24D224440CE6E2D93E1264B40
78579	1	12	124	8266	38106	\N	54.412484999999997	Рязанская область, Спасский район, г. Спасск, Советская, 96 (техникум)		0101000020E61000006CE9D1544F304440978BF84ECC344B40
78575	1	12	124	8266	38286	\N	54.412484999999997	Рязанская область, Спасский район, г. Спасск, Рязанское шоссе, 5а администрация		0101000020E61000006CE9D1544F304440978BF84ECC344B40
78577	1	12	124	8266	38534	\N	54.412484999999997	Рязанская область, Спасский район, г. Спасск, Луначарского, 25 (Средняя общеобразовательная школа)		0101000020E61000006CE9D1544F304440978BF84ECC344B40
78576	1	12	124	8266	38545	\N	54.404584171768697	Рязанская область, Спасский район, г. Спасск, Ленина, 50 (Школа искуств)	Россия, Рязанская область, Спасский район, Спасск-Рязанский	0101000020E6100000A27C410B09304440103E9468C9334B40
78573	1	12	124	8266	37969	\N	54.401329329490302	Рязанская область, Спасский район, г. Спасск, Войкова, 68 (Средняя общеобразовательная школа)	Россия, Рязанская область, Спасский район, Спасск-Рязанский	0101000020E61000004563EDEF6C2F4440DBF7A8BF5E334B40
78622	1	12	124	10499	38541	\N	54.405479	Рязанская область, Спасский район, с. Собчаково, Центральная, 27 (ДК)		0101000020E61000000612143FC61044407E1B62BCE6334B40
78598	1	12	124	9405	38549	\N	54.341704	Рязанская область, Спасский район, д. Разбердеево, Почтовая, 34 (Администрация)		0101000020E61000006E4E250340394440C974E8F4BC2B4B40
78621	1	12	124	10560	38781	\N	54.458170000000003	Рязанская область, Спасский район, с. Половское, Назина, 34 (библиотека)		0101000020E6100000BA69334E431A444011018750A53A4B40
78618	1	12	124	10402	38603	\N	54.323802000000001	Рязанская область, Спасский район, с. Перкино, ул.Школьная д.21 школа		0101000020E61000008E06F016481E444090300C5872294B40
78615	1	12	124	10101	38513	\N	54.461984999999999	Рязанская область, Спасский район, с. Панино, ул.Рязанская,  д.2  школа		0101000020E610000008043A93362344400C1F1153223B4B40
78616	1	12	124	10341	38538	\N	54.346538000000002	Рязанская область, Спасский район, с. Огородниково, Мартынова, 1 (школа)		0101000020E6100000CE37A27BD61744401F69705B5B2C4B40
78602	1	12	124	54651	38551	\N	54.467198114813399	Рязанская область, Спасский район, с.Новый Киструс, Центральная, 66 (детский сад)	Россия, Рязанская область, Спасский район, поселок Новый Киструсс	0101000020E61000001DAB949EE9494440D960E124CD3B4B40
78614	1	12	124	10191	38673	\N	54.576574000000001	Рязанская область, Спасский район, с. Новики, Школьная, 66		0101000020E6100000B01BB62DCA1E4440A9DC442DCD494B40
78608	1	12	124	9939	38485	\N	54.675007000000001	Рязанская область, Спасский район, с. Лакаш, Молодежная, 2 (Средняя общеобразовательная школа)		0101000020E6100000B071FDBB3E71444019C91EA166564B40
78604	1	12	124	9724	38537	\N	54.426703000000003	Рязанская область, Спасский район, с.Кутуково, Центральная, 48 ДК		0101000020E6100000894160E5D0404440740D33349E364B40
78624	1	12	124	10687	38660	\N	54.421187000000003	Рязанская область, Спасский район, с. Красильниково, Центральная, 29 (ФАП)		0101000020E610000079CA6ABA9E1C44400C40A374E9354B40
78595	1	12	124	9267	38454	\N	54.291943811381103	Рязанская область, Спасский район, с. Кирицы, Интернатская, 5/1 (Средняя общеобразовательная школа)	Россия, Рязанская область, Спасский район, поселок Кирицы	0101000020E6100000EDD79DEE3C2D4440B821C66B5E254B40
78594	1	12	124	9267	38454	\N	54.294353847178698	Рязанская область, Спасский район, с. Кирицы, Интернатская, 5/2 (Средняя общеобразовательная школа)	Россия, Рязанская область, Спасский район, поселок Кирицы	0101000020E61000002579AEEFC32D444030B95164AD254B40
78593	1	12	124	9220	38750	\N	54.409184000000003	Рязанская область, Спасский район, с. Исады, Василия Игонина, 46 (ДК)		0101000020E61000006E3480B740444440F3052D2460344B40
78590	1	12	124	8964	\N	\N	54.551298000000003	Рязанская область, Спасский район, с. Ижевское, Школьный пер, 2 (Средняя общеобразовательная школа)	Россия, Рязанская область, Спасский район, поселок Ижевское	0101000020E61000000BB8E7F9D36E4440D42CD0EE90464B40
78591	1	12	124	8964	38532	\N	54.551298000000003	Рязанская область, Спасский район, с. Ижевское, Советская, 12 (детский сад)		0101000020E61000000BB8E7F9D36E4440D42CD0EE90464B40
78589	1	12	124	8964	38531	\N	54.551298000000003	Рязанская область, Спасский район, с. Ижевское, Красная, 94 (ДК)		0101000020E61000000BB8E7F9D36E4440D42CD0EE90464B40
78588	1	12	124	8964	38536	\N	54.551298000000003	Рязанская область, Спасский район, с. Ижевское, Банникова, 17 (детский сад)		0101000020E61000000BB8E7F9D36E4440D42CD0EE90464B40
78582	1	12	124	8704	38658	\N	54.506087999999998	Рязанская область, Спасский район, с. Иванково, Молодежная, 2а  (ДК)		0101000020E610000083F755B9506B4440F372D87DC7404B40
78585	1	12	124	8825	38599	\N	54.297385999690199	Рязанская область, Спасский район, с. Заречье, Дачная, 40 (ДК)	Россия, Рязанская область, Спасский район, поселок Заречье	0101000020E6100000889E94490D1D4440E62494BE10264B40
78610	1	12	124	10002	38548	\N	54.478132000000002	Рязанская область, Спасский район, д. Желобова Слобода, Магистральная, 80 (медпункт)		0101000020E61000002827DA5548374440E695EB6D333D4B40
78619	1	12	124	10498	38778	\N	54.441696	Рязанская область, Спасский район, с. Дубовичье, Молодежная, 1а (ФАП)		0101000020E6100000CA17B490801144401363997E89384B40
78601	1	12	124	9577	38715	\N	54.500869264696	Рязанская область, Спасский район, с.Деревенское, Перышкина, 2 (ФАП)	Россия, Рязанская область, Спасский район, поселок Деревенское	0101000020E61000007A56D28A6F584440454AB3791C404B40
78581	1	12	124	8649	38657	\N	54.439360999999998	Рязанская область, Спасский район, с. Дегтяное, Школьная, 12 (Средняя общеобразовательная школа)		0101000020E6100000077E54C37E534440A51133FB3C384B40
78584	1	12	124	8778	38043	\N	54.431977000000003	Рязанская область, Спасский район, с. Гавриловское, Центральная, 119 (администрация)	Россия, Рязанская область, Спасский район, поселок Гавриловское	0101000020E6100000AB97DF69322F4440E6CFB7054B374B40
78580	1	12	124	8598	38716	\N	54.455528018608298	Рязанская область, Спасский район, с. Выжелес, Школьная, 6 (Средняя общеобразовательная школа)	Россия, Рязанская область, Спасский район, поселок Выжелес	0101000020E61000000A85083884624440C634D3BD4E3A4B40
78628	1	12	124	10926	38779	\N	54.659157	Рязанская область, Спасский район, с. Веретье, Масловка, 6 (администрация)		0101000020E6100000DD239BABE63D4440F9F6AE415F544B40
78609	1	12	124	54659	\N	\N	54.707970134828699	Рязанская область, Спасский район, п. Брыкин Бор (ФГБУ окский Заповедник)	Россия, Рязанская область, Спасский район, поселок Брыкин Бор	0101000020E61000009F8F32E2026E44404A46CEC29E5A4B40
78626	1	12	124	10789	\N	\N	54.738889999999998	Рязанская область, Спасский район, с. Бельское (администрация)	Россия, Рязанская область, Спасский район, поселок Бельское	0101000020E6100000DA8EA9BBB22F4440B4AB90F2935E4B40
78592	1	12	124	9144	38601	\N	54.417012	Рязанская область, Спасский район, д. Аргамаково, Центральная, 19а (администрация)		0101000020E6100000AE7FD767CE424440100533A660354B40
78546	1	12	712	7023	38776	\N	53.701135000000001	Рязанская область, Скопинский район, село Шелемишево, Октябрьская, 24, школа		0101000020E6100000FA997ADD22EA43405D8AABCABED94A40
78516	1	12	712	5435	38218	\N	53.741292000000001	Рязанская область, Скопинский район, село Чулково, Большак, 12, школа	Россия, Рязанская область, Скопинский район, поселок Чулково	0101000020E6100000A7AFE76B96C94340AA6400A8E2DE4A40
78543	1	12	712	6747	38461	\N	53.755194000000003	Рязанская область, Скопинский район, поселок Желтухинский, Школьная, 19А, администрация		0101000020E610000047CB811E6AE7434056116E32AAE04A40
78540	1	12	712	6747	38526	\N	53.755194000000003	Рязанская область, Скопинский район, поселок Желтухинский, Гагарина, 3, ДК В/ч 86741		0101000020E610000047CB811E6AE7434056116E32AAE04A40
78547	1	12	712	54587	38808	\N	53.841883679203498	Рязанская область, Скопинский район, село Успенское, Мичурина, 2В, ДК	Россия, Рязанская область, Скопин	0101000020E61000000EDAAB8F87C643404983DBDAC2EB4A40
78515	1	12	712	5428	38091	\N	53.744807000000002	Рязанская область, Скопинский район, село Секирино, Школьная, 25, школа		0101000020E610000012C2A38D23C243407B6AF5D555DF4A40
78539	1	12	712	6696	38525	\N	53.737495000000003	Рязанская область, Скопинский район, д.Свинушки, мкр. Заречный, Клубная, 11А, ДК		0101000020E6100000605B3FFD67CD434055FB743C66DE4A40
69757	1	11	\N	9161	37892	\N	52.972155000000001	город Орел, Московская, 34		0101000020E61000002844C021540B42404AD235936F7C4A40
78528	1	12	712	5960	38772	\N	53.807913999999997	Рязанская область, Скопинский район, село Рудинка, Школьная, 39, детский сад		0101000020E6100000E6797077D67C434082FDD7B969E74A40
78551	1	12	712	7232	38654	\N	53.908181999999996	Рязанская область, Скопинский район, село Рождествено, Карла Маркса, 43, ДК		0101000020E6100000D47FD6FCF8CF43406E68CA4E3FF44A40
78533	1	12	712	6345	38652	\N	53.776606000000001	Рязанская область, Скопинский район, село Пупки, Первомайская, 4, ФАП		0101000020E6100000CEFDD5E3BEBB43404EF04DD367E34A40
78537	1	12	712	6557	38598	\N	53.682451999999998	Рязанская область, Скопинский район, село Поляны, 40 лет Победы, 11, школа		0101000020E6100000D82AC1E270D443407E8B4E965AD74A40
78513	1	12	712	5282	38038	\N	53.713889000000002	Рязанская область, Скопинский район, поселок Побединка, Горняцкая, 10, ДК		0101000020E6100000323D618907C84340B1FCF9B660DB4A40
78535	1	12	712	6496	38773	\N	53.888072498942002	Рязанская область, Скопинский район, село Петрушино, Набережная, 32, ДК	Россия, Рязанская область, Скопинский район, поселок Петрушино	0101000020E61000000DFFE9060A804340253FE257ACF14A40
78511	1	12	712	5055	38746	\N	53.839463000000002	Рязанская область, Скопинский район, село Павелец, Центральная, 15, администрация		0101000020E6100000EB3713D385A24340DD99098673EB4A40
78512	1	12	712	5055	38190	\N	53.839463000000002	Рязанская область, Скопинский район, рабочий поселок Павелец, Первомайская, 41, ДК		0101000020E6100000EB3713D385A24340DD99098673EB4A40
78536	1	12	712	6500	38748	\N	53.803016	Рязанская область, Скопинский район, село Новые Кельцы, Центральная, 2, ДК		0101000020E6100000BDFBE3BD6AB543401615713AC9E64A40
78519	1	12	712	54693	38815	\N	53.808654890615102	Рязанская область, Скопинский район, село Новое, Рабочая, 13, администация	Россия, Рязанская область, Скопинский район, поселок Новое	0101000020E6100000A796ADF545DA43409A5FCD0182E74A40
78527	1	12	712	6075	38600	\N	53.844300471589897	Рязанская область, Скопинский район, село Нагиши, Молодежная, 6, школа	Россия, Рязанская область, Скопинский район, поселок Нагиши	0101000020E61000009A7CB3CD8D754340A301BC0512EC4A40
78550	1	12	712	7220	38777	\N	53.954833000000001	Рязанская область, Скопинский район, село Моховое, Советская, 57, администрация		0101000020E61000003A02B859BCCC43401F12BEF737FA4A40
78549	1	12	712	7139	38528	\N	53.845028019796302	Рязанская область, Скопинский район, село Лопатино, Советская, 1В,ДК	Россия, Рязанская область, Скопинский район, поселок Лопатино	0101000020E610000052280B5F5FBB4340261AA4E029EC4A40
78510	1	12	712	5114	9916	\N	53.798780721019298	Рязанская область, Скопинский район, село Кремлево, Молодежная, 20, библиотека	Россия, Рязанская область, Скопинский район, поселок Кремлево	0101000020E610000047E6913F18A6434045D5AF743EE64A40
78532	1	12	712	6288	38189	\N	53.777406407619097	Рязанская область, Скопинский район, село Корневое, Мира, 1, ДК	Россия, Рязанская область, Скопинский район, поселок Корневое	0101000020E61000009221C7D633C043406ADB300A82E34A40
78534	1	12	712	6393	38653	\N	53.739289999999997	Рязанская область, Скопинский район, село Князево, Центральная, 13, администрация		0101000020E61000005DF92CCF83AF43404221020EA1DE4A40
78526	1	12	712	5971	38524	\N	53.884242999999998	Рязанская область, Скопинский район, село Клекотки, Школьная, 31, школа		0101000020E610000056B77A4E7A6F4340C45BE7DF2EF14A40
78524	1	12	712	5919	38747	\N	53.930629000000003	Рязанская область, Скопинский район, село Катино, Советская, 14, администрация		0101000020E61000009BE447FC8A974340C7DADFD91EF74A40
78530	1	12	712	6186	38650	\N	53.901642000000002	Рязанская область, Скопинский район, село Казинка, Школьная, 2Б, администрация		0101000020E6100000C100C28712B343409B594B0169F34A40
78529	1	12	712	6140	38522	\N	53.921080000000003	Рязанская область, Скопинский район, село Ильинка, Попова, 2, школа		0101000020E6100000C824236761B94340F67F0EF3E5F54A40
78523	1	12	712	5728	38712	\N	53.763359999999999	Рязанская область, Скопинский район, село Затворное, Казинка, 5, администрация		0101000020E61000008B6D52D1588943408B89CDC7B5E14A40
78538	1	12	712	6615	38502	\N	53.735374999999998	Рязанская область, Скопинский район, село Ермолово, Церковная, 41, администрация		0101000020E61000003BC269C18BD24340E3A59BC420DE4A40
78507	1	12	712	4974	38744	\N	53.788626762484903	Рязанская область, Скопинский район, село Делехово, Советская, 4, здание ФАП	Россия, Рязанская область, Скопинский район, поселок Делехово	0101000020E6100000E5637781929643400DDFC2BAF1E44A40
78548	1	12	712	7079	38659	\N	53.921000999999997	Рязанская область, Скопинский район, село Гремячка, Молодежная, 34, школа		0101000020E6100000560DC2DCEEC14340A94A5B5CE3F54A40
78544	1	12	712	6881	38656	\N	53.713692000000002	Рязанская область, Скопинский район, село Городецкое, Гагарина, 4, ФАП		0101000020E6100000772FF7C951E243405BB56B425ADB4A40
78522	1	12	712	5810	38523	\N	53.834021999999997	Рязанская область, Скопинский район, село Горлово, Базарная, 2А, ДК		0101000020E61000005340DAFF008543407F129F3BC1EA4A40
78517	1	12	712	5491	38075	\N	53.836391999999996	Рязанская область, Скопинский район, село Вослебово, Школьная, 73А, ДК		0101000020E6100000B7989F1B9ACE434069519FE40EEB4A40
78518	1	12	712	5593	38460	\N	53.878681	Рязанская область, Скопинский район, село Вердерево, Центральная, здание Дома культуры		0101000020E610000013B875374FD34340EC4E779E78F04A40
78520	1	12	712	5654	38775	\N	53.901615	Рязанская область, Скопинский район, село Богослово, Запрудная, 2, школа		0101000020E610000018D2E1218C874340A14ACD1E68F34A40
78531	1	12	712	6283	38774	\N	53.885627999999997	Рязанская область, Скопинский район, село Березняги, Ленина, 119, администрация		0101000020E61000005A2A6F4738A74340003620425CF14A40
78466	1	12	281	2729	\N	\N	54.406092000000001	Рязанская область, Сасовский район, село Чубарово, администация		0101000020E6100000BF61A2410AD24440689599D2FA334B40
78452	1	12	281	1921	\N	\N	54.384916493460999	Рязанская область, Сасовский район, село Фроловское, школа		0101000020E6100000077E54C37EEF444083DA6FED44314B40
78458	1	12	281	2269	\N	\N	54.451711000000003	Рязанская область, Сасовский район, село Устье, здание администрации сельского поселения	Россия, Рязанская область, Сасовский район, поселок Устье	0101000020E6100000C3D66CE5250145402A1F82AAD1394B40
78440	1	12	281	1244	\N	\N	54.149276	Рязанская область, Сасовский район, село Усады, здание администрации сельского поселения	Россия, Рязанская область, Сасовский район, поселок Усады	0101000020E61000009010E50B5A084540F209D9791B134B40
78489	1	12	281	3986	\N	\N	54.336975000000002	Рязанская область, Сасовский район, деревня Трудолюбовка, администрация сельского поселения		0101000020E6100000081C0934D8104540E9482EFF212B4B40
78457	1	12	281	2230	\N	\N	54.383583000000002	Рязанская область, Сасовский район, село Темгенево, здание администрации сельского поселения	Россия, Рязанская область, Сасовский район, поселок Темгенево	0101000020E6100000E3FDB8FDF2F744409A266C3F19314B40
78485	1	12	281	3740	\N	\N	54.278402999999997	Рязанская область, Сасовский район, поселок Сотницыно, клуб		0101000020E61000000AF8359204E74440DC0DA2B5A2234B40
78487	1	12	281	3740	38087	\N	54.275539919626397	Рязанская область, Сасовский район, поселок Сотницыно, Больничная, участковая больница	Россия, Рязанская область, Сасовский район, поселок Сотницыно	0101000020E6100000425BCEA5B8E64440B35E0CE544234B40
78480	1	12	281	3530	\N	\N	54.144409000000003	Рязанская область, Сасовский район, село Салтыково, здание администрации сельского поселения	Россия, Рязанская область, Сасовский район, поселок Салтыково	0101000020E61000005DBF60376C2D4540C11F7EFE7B124B40
78443	1	12	281	1415	\N	\N	54.299366999999997	Рязанская область, Сасовский район, село Саблино, кафе Кучеренко		0101000020E610000059DC7F643AF04440354069A851264B40
78478	1	12	281	3426	\N	\N	54.163997000000002	Рязанская область, Сасовский район, поселок Придорожный, школа		0101000020E61000000EBDC5C37B36454031D28BDAFD144B40
78476	1	12	281	3321	\N	\N	54.197420000000001	Рязанская область, Сасовский район, село Пичкиряево, здание администрации сельского поселения	Россия, Рязанская область, Сасовский район, поселок Пичкиряево	0101000020E6100000EEB25F77BA394540C5C9FD0E45194B40
78456	1	12	281	2170	\N	\N	54.474950999999997	Рязанская область, Сасовский район, село Огарево-Почково, здание администрации сельского поселения	Россия, Рязанская область, Сасовский район, поселок Огарево-Почково	0101000020E6100000A699EE7552F94440EB19C231CB3C4B40
78471	1	12	281	3024	\N	\N	54.209096000000002	Рязанская область, Сасовский район, село Новое Березово, начальная школа		0101000020E610000080F44D9A06FD4440BADC60A8C31A4B40
78470	1	12	281	2963	\N	\N	54.253894000000003	Рязанская область, Сасовский район, село Нижнее Мальцево, школа		0101000020E6100000A587A1D5C9DB444048533D997F204B40
78455	1	12	281	2115	\N	\N	54.519275999999998	Рязанская область, Сасовский район, село Мыс Доброй Надежды, школа		0101000020E61000001689096AF808454081CCCEA277424B40
78464	1	12	281	2625	\N	\N	54.423910999999997	Рязанская область, Сасовский район, село Мокрое, администрация сельского поселения		0101000020E6100000AB5E7EA7C9D6444013B534B742364B40
78474	1	12	281	3206	\N	\N	54.111496000000002	Рязанская область, Сасовский район, село Матвеевское, здание администрации сельского поселения	Россия, Рязанская область, Сасовский район, поселок Матвеевское	0101000020E61000003DD4B6611442454042D13C80450E4B40
78469	1	12	281	2920	\N	\N	54.217219999999998	Рязанская область, Сасовский район, село Малый Студенец, библиотека	Россия, Рязанская область, Сасовский район, поселок Малый Студенец	0101000020E6100000DBFCBFEAC8F74440C0046EDDCD1B4B40
78451	1	12	281	1861	\N	\N	54.446083000000002	Рязанская область, Сасовский район, село Любовниково, здание Дома культуры	Россия, Рязанская область, Сасовский район, поселок Любовниково	0101000020E6100000174850FC18E544409A266C3F19394B40
78468	1	12	281	2855	\N	\N	54.264586000000001	Рязанская область, Сасовский район, поселок Кустаревка, Дом культуры		0101000020E61000009C16BCE82B2245405F7D3CF4DD214B40
78462	1	12	281	2463	\N	\N	54.427928000000001	Рязанская область, Сасовский район, село Кошибеево, Дом культуры		0101000020E61000002098A3C7EF07454077853E58C6364B40
78447	1	12	281	1653	\N	\N	54.268230000000003	Рязанская область, Сасовский район, село Ключи, медпункт		0101000020E6100000FD135CACA81545402EE7525C55224B40
78463	1	12	281	2567	\N	\N	54.400143999999997	Рязанская область, Сасовский район, село Каргашино, Дом культуры		0101000020E6100000B9196EC0E7DD444066D828EB37334B40
78460	1	12	281	2402	\N	\N	54.425478712885102	Рязанская область, Сасовский район, село Демушкино, Дом культуры	Россия, Рязанская область, Сасовский район, поселок Демушкино	0101000020E61000006A1668774811454041118B1876364B40
78453	1	12	281	1996	\N	\N	54.415109999999999	Рязанская область, Сасовский район, село Глядково, администрация сельского поселения		0101000020E6100000B9FE5D9F39FB44400C1F115322354B40
78450	1	12	281	1800	\N	\N	54.415042	Рязанская область, Сасовский район, село Гавриловское, здание школы	Россия, Рязанская область, Сасовский район, поселок Гавриловское	0101000020E61000003145B9347EEB4440B43BA41820354B40
78446	1	12	281	1533	\N	\N	54.272793999999998	Рязанская область, Сасовский район, село Вялсы, медпункт		0101000020E61000003A5AD5928E004540C345EEE9EA224B40
78483	1	12	281	3631	\N	\N	54.312263999999999	Рязанская область, Сасовский район, село Верхнее Мальцево, библиотека		0101000020E61000009AE95E27F5E54440ECDB4944F8274B40
78472	1	12	281	3084	\N	\N	54.164122999999996	Рязанская область, Сасовский район, село Боковой Майдан, медпункт		0101000020E610000071E316F373414540BDC282FB01154B40
78330	1	12	1339	54667	\N	\N	54.564596000000002	Рязанская область, Рязанский район, п.Приозерный, контора МУП ЖКХ		0101000020E61000005B9A5B21ACE84340E9B985AE44484B40
78449	1	12	281	1763	\N	\N	54.331825000000002	Рязанская область, Сасовский район, село Берестянки, здание школы	Россия, Рязанская область, Сасовский район, поселок Берестянки	0101000020E6100000F2EF332E1CFE4440637FD93D792A4B40
78444	1	12	281	1457	\N	\N	54.265695000000001	Рязанская область, Сасовский район, поселок Батьки, школа		0101000020E6100000F4C473B680064540F9DA334B02224B40
78459	1	12	281	2341	\N	\N	54.385010000000001	Рязанская область, Сасовский район, село Бастаново, школа		0101000020E6100000ED9FA701830245400551F70148314B40
78442	1	12	281	1345	\N	\N	54.275469380829101	Рязанская область, Сасовский район, село Алешино, администрация сельского поселения	Россия, Рязанская область, Сасовский район, поселок Алешино	0101000020E6100000B91AD99596EF4440EA07759142234B40
78439	1	12	281	1190	\N	\N	54.163496000000002	Рязанская область, Сасовский район, село Агломазово, медпункт		0101000020E61000002D05A4FD0F0645406F83DA6FED144B40
78432	1	12	75	761	\N	\N	53.611235000000001	Рязанская область, Сараевский район, с.Ягодное, здание администрации Ягодновского с/п	Россия, Рязанская область, Сараевский район, поселок Ягодное	0101000020E6100000A60A462575A04440D595CFF23CCE4A40
78397	1	12	75	31463	\N	\N	53.454106000000003	Рязанская область, Сараевский район, с.Троицкое, Здание бывшей администрации Троицкого сельского округа	Россия, Рязанская область, Сараевский район, поселок Троицкое	0101000020E6100000137F1475E69044406D75392520BA4A40
78427	1	12	75	456	\N	\N	53.633606	Рязанская область, Сараевский район, с.Телятники, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Телятники	0101000020E6100000DCA16131EA7C444052465C001AD14A40
78408	1	12	75	31892	\N	\N	53.744737000000001	Рязанская область, Сараевский район, с.Таптыково, Здание Дома культуры	Россия, Рязанская область, Сараевский район, поселок Таптыково	0101000020E610000016F6B4C35FA14440828FC18A53DF4A40
78425	1	12	75	327	\N	\N	53.826354000000002	Рязанская область, Сараевский район, с.Сысои, здание администрации Сысоевского с/п	Россия, Рязанская область, Сараевский район, поселок Сысои	0101000020E6100000BDC804FC1A8944409B75C6F7C5E94A40
78403	1	12	75	27065	\N	\N	53.581031000000003	Рязанская область, Сараевский район, с. Старобокино, Здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Старобокино	0101000020E61000001F2C634337634440297B4B395FCA4A40
78435	1	12	75	881	38199	\N	53.729382999999999	Рязанская область, Сараевский район, р.п. Сараи, Ленина, 153 (клуб)		0101000020E6100000D1B1834A5C7F444012A1116C5CDD4A40
78434	1	12	75	881	38199	\N	53.729382999999999	Рязанская область, Сараевский район, р.п. Сараи, Ленина, 122 административное здание		0101000020E6100000D1B1834A5C7F444012A1116C5CDD4A40
78436	1	12	75	881	38265	\N	53.729382999999999	Рязанская область, Сараевский район, р.п. Сараи, Казинка, 3 (школа)		0101000020E6100000D1B1834A5C7F444012A1116C5CDD4A40
78438	1	12	75	881	38519	\N	53.729382999999999	Рязанская область, Сараевский район, р.п. Сараи, 1 Мая, 23 (клуб)		0101000020E6100000D1B1834A5C7F444012A1116C5CDD4A40
78421	1	12	75	32481	\N	\N	53.587689231818899	Рязанская область, Сараевский район, д. Ремизово-1 администрация	Россия, Рязанская область, Сараевский район, поселок Ремизово 1-е	0101000020E61000002F36AD1402894440069CA56439CB4A40
78426	1	12	75	379	\N	\N	53.772216	Рязанская область, Сараевский район, с.Паники, здание бывшей администрации Паниковского с/о	Россия, Рязанская область, Сараевский район, поселок Паники	0101000020E6100000726C3D433884444056B950F9D7E24A40
78596	1	12	75	9314	75045	\N	53.493845999999998	Рязанская область, Спасский район, п. Павловка, Курская, 6 (Детский сад)		0101000020E61000006E52D158FB6D444055A1815836BF4A40
78410	1	12	75	32040	\N	\N	53.799229101381698	Рязанская область, Сараевский район, с. Островка, ДК	Россия, Рязанская область, Сараевский район, поселок Островка	0101000020E610000060764F1E16B44440E481C8224DE64A40
78402	1	12	75	31676	\N	\N	53.642302999999998	Рязанская область, Сараевский район, с.Озерки, Здание ФАП	Россия, Рязанская область, Сараевский район, поселок Озерки	0101000020E6100000501A6A1492684440B48F15FC36D24A40
78422	1	12	75	108	\N	\N	53.555934999999998	Рязанская область, Сараевский район, с.Новобокино, здание администрации Новобокинского с/п	Россия, Рязанская область, Сараевский район, поселок Новобокино	0101000020E610000022C154336B6B4440D3D9C9E028C74A40
78423	1	12	75	189	\N	\N	53.529716999999998	Рязанская область, Сараевский район, п.Низовка, здание сельского клуба	Россия, Рязанская область, Сараевский район, поселок Низовка	0101000020E6100000EB8D5A61FA6C44404F9143C4CDC34A40
78419	1	12	75	32430	\N	\N	53.537872999999998	Рязанская область, Сараевский район, с. Напольное, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Напольное	0101000020E6100000DEFFC709138C44406133C005D9C44A40
78405	1	12	75	31807	\N	\N	53.770347999999998	Рязанская область, Сараевский район, с. Назарьево, Здание Назарьевского ФАП	Россия, Рязанская область, Сараевский район, поселок Назарьево	0101000020E6100000EBC6BB2363994440FE4465C39AE24A40
78417	1	12	75	32322	\N	\N	53.643690999999997	Рязанская область, Сараевский район, с. Муравлянка, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Муравлянка	0101000020E61000000EBDC5C37B98444061DD787764D24A40
78433	1	12	75	838	\N	\N	53.616363	Рязанская область, Сараевский район, с.Мордово, ДК		0101000020E61000001ABFF04A92A3444073BB97FBE4CE4A40
78292	1	12	757	26524	38644	\N	53.663558999999999	Рязанская область, Ряжский район, с.Введеновка, Солнечная, 99, СДК		0101000020E610000051C0763062074440B5FB5580EFD44A40
78415	1	12	75	5807	\N	\N	53.886116000000001	Рязанская область, Сараевский район, с. Меньшие Можары, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Меньшие Можары	0101000020E6100000A96BED7DAA8444402E3BC43F6CF14A40
78428	1	12	75	520	\N	\N	53.509909	Рязанская область, Сараевский район, с.Витуша, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Малая Витуша	0101000020E61000000D8D2782387D4440D177B7B244C14A40
78418	1	12	75	5956	\N	\N	53.707242999999998	Рязанская область, Сараевский район, с. Максы, здание школы	Россия, Рязанская область, Сараевский район, поселок Максы	0101000020E61000002FDE8FDB2FA5444097A949F086DA4A40
78413	1	12	75	32177	\N	\N	53.709279000000002	Рязанская область, Сараевский район, с. Кривское, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Кривское	0101000020E610000097E315889E824440AB5E7EA7C9DA4A40
78412	1	12	75	5658	\N	\N	53.692673999999997	Рязанская область, Сараевский район, п. Красная Вершина, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Красная Вершина	0101000020E6100000F0C2D66CE55F44400E65A88AA9D84A40
78396	1	12	75	31377	\N	\N	53.521233000000002	"Рязанская область, Сараевский район, д.  Калиновка, Здание правления ООО ""Алексеевское"""	Россия, Рязанская область, Сараевский район, поселок Калиновка	0101000020E610000011001C7BF69E4440494C50C3B7C24A40
78430	1	12	75	638	\N	\N	53.637867	Рязанская область, Сараевский район, д. Ивановка, здание бывшей администрации Ивановского с/о	Россия, Рязанская область, Сараевский район, поселок Ивановка	0101000020E61000007A53910A638544404C1938A0A5D14A40
78400	1	12	75	54670	\N	\N	53.818994830603302	Рязанская область, Сараевский район, п.Зеркальные пруды, Здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Зеркальные Пруды	0101000020E6100000D4F02DAC1B954440344B02D4D4E84A40
78411	1	12	75	4692	\N	\N	53.730826	Рязанская область, Сараевский район, с. Желобово, здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Желобово	0101000020E6100000FD4AE7C3B36044408388D4B48BDD4A40
78406	1	12	75	31871	\N	\N	53.753847999999998	Рязанская область, Сараевский район, с. Высокое, Здание сельского Дома культуры	Россия, Рязанская область, Сараевский район, поселок Высокое	0101000020E61000007250C24CDB9D4440D7135D177EE04A40
78416	1	12	75	32318	\N	\N	53.906633999999997	Рязанская область, Сараевский район, п. Веселый, здание конторы Лесопункта	Россия, Рязанская область, Сараевский район, поселок Веселый	0101000020E6100000D925AAB70686444088B839950CF44A40
78401	1	12	75	31654	\N	\N	53.622045	"Рязанская область, Сараевский район, с.Бычки, Здание правления СПК колхоз ""Возрождение"""	Россия, Рязанская область, Сараевский район, поселок Бычки	0101000020E61000000A4B3CA06C744440F6D1A92B9FCF4A40
78399	1	12	75	31565	\N	\N	53.803297999999998	Рязанская область, Сараевский район, с.Борец, Здание администрации Борецкого сельского поселения	Россия, Рязанская область, Сараевский район, поселок Борец	0101000020E61000008E75711B0D9244409A780778D2E64A40
78414	1	12	75	27194	\N	\N	53.877262999999999	Рязанская область, Сараевский район, с. Большие Можары, школа		0101000020E6100000310C587215834440D47E6B274AF04A40
78409	1	12	75	32018	\N	\N	53.858739	Рязанская область, Сараевский район, с.Белоречье, Здание бывшей адмирнистрации Белореченского с/о	Россия, Рязанская область, Сараевский район, поселок Белоречье	0101000020E610000069AD68739CAB44405E66D828EBED4A40
78395	1	12	75	31356	\N	\N	53.531863000000001	Рязанская область, Сараевский район, с.Алексеевка, Здание Дома культуры	Россия, Рязанская область, Сараевский район, поселок Алексеевка	0101000020E6100000529CA38E8EA14440EA79371614C44A40
78377	1	12	637	54656	\N	\N	53.857940853023003	Рязанская область, Сапожковский район, с. Черная Речка, здание школы	Россия, Рязанская область, Сапожковский район, поселок Черная Речка	0101000020E61000008EB27E33315F4440E272BC02D1ED4A40
78394	1	12	637	4308	\N	\N	53.940472	Рязанская область, Сапожковский район, с. Собчаково, здание ФАП	Россия, Рязанская область, Сапожковский район, поселок Собчаково	0101000020E6100000B56FEEAF1E7B4440E066F16261F84A40
78376	1	12	637	30086	\N	\N	53.949328000000001	"Рязанская область, Сапожковский район, р.п. Сапожок, Воздвиженская, 15 магазин ООО ""Феникс"""		0101000020E6100000F90FE9B7AF574440AB96749483F94A40
78371	1	12	637	30086	38245	\N	53.950238991731503	Рязанская область, Сапожковский район, р.п. Сапожок, Советская, 19 школа искуств	Россия, Рязанская область, Сапожковский район, поселок Сапожок	0101000020E610000079CA6ABA9E5644401F317A6EA1F94A40
78370	1	12	637	30086	38245	\N	53.949328000000001	Рязанская область, Сапожковский район, р.п. Сапожок, Советская, 15 здание КСК «Надежда»,		0101000020E6100000F90FE9B7AF574440AB96749483F94A40
78372	1	12	637	30086	38516	\N	53.949328000000001	Рязанская область, Сапожковский район, р.п. Сапожок, Свободы, 13 школа		0101000020E6100000F90FE9B7AF574440AB96749483F94A40
78375	1	12	637	30086	38518	\N	53.949328000000001	Рязанская область, Сапожковский район, р.п. Сапожок, Пролетарская, 48 Техникум		0101000020E6100000F90FE9B7AF574440AB96749483F94A40
78373	1	12	637	30086	38743	\N	53.950390876029999	Рязанская область, Сапожковский район, р.п. Сапожок, Гусева, 24 школа	Россия, Рязанская область, Сапожковский район, поселок Сапожок	0101000020E61000003B8908FF22564440D5B48B69A6F94A40
78374	1	12	637	30086	38517	\N	53.949328000000001	Рязанская область, Сапожковский район, р.п. Сапожок, Большая Дорога, 55 ДРСУ		0101000020E6100000F90FE9B7AF574440AB96749483F94A40
78384	1	12	637	26456	\N	\N	53.993009999999998	Рязанская область, Сапожковский район, с. Парышка, здание сельского Дома культуры	Россия, Рязанская область, Сапожковский район, поселок Парышка	0101000020E610000086E464E256354440EC4CA1F31AFF4A40
78383	1	12	637	30762	\N	\N	54.042095864735899	Рязанская область, Сапожковский район, с. Новокрасное, здание Новокрасненской школы	Россия, Рязанская область, Сапожковский район, поселок Новокрасное	0101000020E61000006891ED7C3F4344406EA5D76663054B40
78393	1	12	637	27020	\N	\N	53.959542999999996	Рязанская область, Сапожковский район,  с. Морозовы Борки, здание средней школы	Россия, Рязанская область, Сапожковский район, поселок Морозовы-Борки	0101000020E610000091442FA358744440880D164ED2FA4A40
78387	1	12	637	4164	\N	\N	54.012591	Рязанская область, Сапожковский район, с. Михеи, здание школы	Россия, Рязанская область, Сапожковский район, поселок Михей	0101000020E610000004FF5BC98E614440AA9CF6949C014B40
78385	1	12	637	30870	\N	\N	53.962107000000003	Рязанская область, Сапожковский район, с. Малый Сапожок, здание сельского клуба	Россия, Рязанская область, Сапожковский район, поселок Малый Сапожок	0101000020E6100000E277D32D3B4E444058207A5226FB4A40
78391	1	12	637	31151	\N	\N	54.094222000000002	Рязанская область, Сапожковский район, с. Лукмос, ФАП		0101000020E61000003F8BA548BE4C444028486C770F0C4B40
78380	1	12	637	30587	\N	\N	54.037266000000002	Рязанская область, Сапожковский район, с. Красный Угол, здание Красноуглянского сельского клуба	Россия, Рязанская область, Сапожковский район, поселок Красный Угол	0101000020E610000069C6A2E9EC7044405AA0DD21C5044B40
78379	1	12	637	30539	\N	\N	53.988616999999998	Рязанская область, Сапожковский район, с. Красное, здание школы	Россия, Рязанская область, Сапожковский район, поселок Красное	0101000020E6100000B1F84D61A570444083A279008BFE4A40
78390	1	12	637	4216	\N	\N	54.013188999999997	Рязанская область, Сапожковский район, с. Коровка, здание сельского Дома культуры	Россия, Рязанская область, Сапожковский район, поселок Коровка	0101000020E6100000A27E17B6665744405ED5592DB0014B40
78382	1	12	637	30682	\N	\N	53.941876999999998	Рязанская область, Сапожковский район, с. Канино, здание Канинской средней школы	Россия, Рязанская область, Сапожковский район, поселок Канино	0101000020E6100000BD378600E03E444063EDEF6C8FF84A40
78388	1	12	637	31016	\N	\N	54.074485000000003	Рязанская область, Сапожковский район, д. Васильевка, здание сельского Дома культуры	Россия, Рязанская область, Сапожковский район, поселок Васильевка	0101000020E61000007B32FFE89B664440738577B988094B40
78378	1	12	637	30505	\N	\N	53.964908999999999	Рязанская область, Сапожковский район, д. Березники, здание администрации сельского поселения	Россия, Рязанская область, Сапожковский район, поселок Березники	0101000020E6100000D594641D8E604440DB4E5B2382FB4A40
78647	1	12	637	54686	38806	\N	53.931262037297998	Рязанская область, Ухоловский район, с. Александровка, Центральная, 38 ДК	Россия, Рязанская область, Сапожковский район, поселок Александровка	0101000020E61000003E5A9C31CC434440F700DD9733F74A40
78357	1	12	1339	29508	\N	\N	54.667020000000001	Рязанская область, Рязанский район, с.Шумашь, здание основной школы	Россия, Рязанская область, Рязанский район, поселок Шумашь	0101000020E6100000B4722F302BE8434093E34EE960554B40
78361	1	12	1339	23650	\N	\N	54.374406	Рязанская область, Рязанский район, д.Шевцово, здание начальной школы	Россия, Рязанская область, Рязанский район, поселок Шевцово	0101000020E61000005F419AB168EE43408DB62A89EC2F4B40
78367	1	12	1339	29938	\N	\N	54.673470999999999	Рязанская область, Рязанский район, с.Тюшево, здание средней школы	Россия, Рязанская область, Рязанский район, поселок Тюшево	0101000020E6100000BE13B35E0CC34340F7E6374C34564B40
78363	1	12	1339	29773	\N	\N	54.526069	Рязанская область, Рязанский район, п.Стенькино, здание учреждения ЯМ-401/6	Россия, Рязанская область, Рязанский район, поселок Стенькино	0101000020E6100000E84A04AA7FC243403F389F3A56434B40
78312	1	12	1339	29773	\N	\N	54.519964511905997	"Рязанская область, Рязанский район, п.учхоза ""Стенькино"", здание столовой"	Россия, Рязанская область, Рязанский район, поселок Стенькино	0101000020E61000007CBABA63B1C1434046088F368E424B40
78942	1	12	1339	54621	\N	\N	54.789574170716499	Рязанская область, г. Рязань, п. Солотча, (Средняя общеобразовательная школа №32)	Россия, Рязанская область, Рязанский район, поселок Солотча	0101000020E61000008F39CFD897EA4340CEE2C5C210654B40
78317	1	12	1339	27681	\N	\N	54.466526999999999	"Рязанская область, Рязанский район, д.Сажнево, здание турбазы ""Серебряные пруды"""	Россия, Рязанская область, Рязанский район, поселок Сажнево	0101000020E610000087C0914083DF4340BAD91F28B73B4B40
78327	1	12	1339	28135	\N	\N	54.510474000000002	Рязанская область, Рязанский район, д.Рожок, здание администрации сельского поселения	Россия, Рязанская область, Рязанский район, поселок Рожок	0101000020E6100000B22D03CE52CA4340AABA473657414B40
78362	1	12	1339	29688	\N	\N	54.522373999999999	Рязанская область, Рязанский район, д.Ровное, здание основной школы	Россия, Рязанская область, Рязанский район, поселок Ровное	0101000020E61000005C92037635DB4340EE23B726DD424B40
78366	1	12	1339	54648	\N	\N	54.520988082305301	Рязанская область, Рязанский район, с.Реткино, здание администрации сельского поселения		0101000020E6100000A245B6F3FDE44340E2CD1ABCAF424B40
78356	1	12	1339	29413	\N	\N	54.717838999999998	Рязанская область, Рязанский район, с.Поляны, здание средней школы	Россия, Рязанская область, Рязанский район, поселок Поляны	0101000020E6100000075F984C15EA43408C65FA25E25B4B40
78355	1	12	1339	29413	\N	\N	54.717838999999998	"Рязанская область, Рязанский район, с.Поляны, здание ФСК ""Витязь"""	Россия, Рязанская область, Рязанский район, поселок Поляны	0101000020E6100000075F984C15EA43408C65FA25E25B4B40
78338	1	12	1339	28607	\N	\N	54.777473999999998	Рязанская область, Рязанский район, д.Полково, здание администрации сельского поселения	Россия, Рязанская область, Рязанский район, поселок Полково	0101000020E610000014419C8713F04340C2BE9D4484634B40
78352	1	12	1339	29268	\N	\N	54.590024999999997	Рязанская область, Рязанский район, с.Подвязье, здание ДК	Россия, Рязанская область, Рязанский район, поселок Подвязье	0101000020E61000000E6954E064C5434044696FF0854B4B40
78351	1	12	1339	54629	\N	\N	54.564596000000002	Рязанская область, Рязанский район, п.Окский, здание Дома культуры		0101000020E61000005B9A5B21ACE84340E9B985AE44484B40
78347	1	12	1339	29070	\N	\N	54.481909000000002	Рязанская область, Рязанский район, д.Наумово, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Наумово	0101000020E6100000FC5580EF36074440F452B131AF3D4B40
78354	1	12	1339	29329	\N	\N	54.572383000000002	Рязанская область, Рязанский район, д.Насурово, здание клуба	Россия, Рязанская область, Рязанский район, поселок Насурово	0101000020E61000007100FDBE7FB34340A8E49CD843494B40
78369	1	12	1339	22814	\N	\N	54.612639000000001	Рязанская область, Рязанский район, с.Мушковатово, здание основной школы	Россия, Рязанская область, Рязанский район, поселок Мушковатово	0101000020E6100000BAD8B45208CA434088A06AF46A4E4B40
78305	1	12	1339	14339	\N	\N	54.605375000000002	Рязанская область, Рязанский район, п.Мурмино, здание средней школы	Россия, Рязанская область, Рязанский район, поселок Мурмино	0101000020E61000004242942F68054440736891ED7C4D4B40
78304	1	12	1339	14339	37968	\N	54.605375000000002	Рязанская область, Рязанский район, п.Мурмино, Лесная, 15, детский сад		0101000020E61000004242942F68054440736891ED7C4D4B40
78348	1	12	1339	29074	\N	\N	54.588194000000001	Рязанская область, Рязанский район, с.Льгово, здание ДК	Россия, Рязанская область, Рязанский район, поселок Льгово	0101000020E61000000B0DC4B299F943400ADAE4F0494B4B40
78343	1	12	1339	28865	\N	\N	54.511603000000001	Рязанская область, Рязанский район, п.Листвянка, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Листвянка	0101000020E6100000EE9579ABAEFD43408BC404357C414B40
78329	1	12	1339	54676	\N	\N	54.844753225029102	Рязанская область, Рязанский район, п.Ласковский, здание фельдшерско-акушерского пункта	Россия, Рязанская область, Рязанский район, поселок Ласково	0101000020E61000008DD31055F8F943405419C6DD206C4B40
78342	1	12	1339	28838	\N	\N	54.730266	Рязанская область, Рязанский район, с.Коростово, здание администрации сельского поселения	Россия, Рязанская область, Рязанский район, поселок Коростово	0101000020E6100000DFC2BAF1EED84340BCB0355B795D4B40
78306	1	12	1339	27156	\N	\N	54.568547000000002	Рязанская область, Рязанский район, с.Казарь, здание фельдшерско-акушерского пункта	Россия, Рязанская область, Рязанский район, поселок Казарь	0101000020E610000024809BC58B0B4440959EE925C6484B40
78359	1	12	1339	29595	\N	\N	54.444747999999997	Рязанская область, Рязанский район, п.Искра, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Искра	0101000020E61000002B6A300DC3F143400F7BA180ED384B40
78339	1	12	1339	28673	\N	\N	54.694259000000002	Рязанская область, Рязанский район, с.Заокское, здание средней школы	Россия, Рязанская область, Рязанский район, поселок Заокское	0101000020E61000000B43E4F4F5DE434012FA997ADD584B40
78328	1	12	1339	28154	\N	\N	54.814574	Рязанская область, Рязанский район, с.Заборье, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Заборье	0101000020E6100000271422E010F043400116F9F543684B40
78326	1	12	1339	19418	\N	\N	54.478136999999997	Рязанская область, Рязанский район, с.Екимовка, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Екимовка	0101000020E6100000BCB0355B79CD4340F700DD97333D4B40
78320	1	12	1339	27815	\N	\N	54.655797999999997	Рязанская область, Рязанский район, с.Дубровичи, здание клуба	Россия, Рязанская область, Рязанский район, поселок Дубровичи	0101000020E61000002E71E481C8F643401F645930F1534B40
78308	1	12	1339	27274	\N	\N	54.629409000000003	Рязанская область, Рязанский район, с.Долгинино, здание администрации сельского поселения	Россия, Рязанская область, Рязанский район, поселок Долгинино	0101000020E610000028B9C326321344406F675F7990504B40
78336	1	12	1339	28538	\N	\N	54.821271000000003	Рязанская область, Рязанский район, д.Деулино, здание администрации сельского поселения	Россия, Рязанская область, Рязанский район, поселок Деулино	0101000020E610000009371955862944409D137B681F694B40
78319	1	12	1339	16060	\N	\N	54.446219999999997	Рязанская область, Рязанский район, с.Дашки-2, здание Дашковской основной школы	Россия, Рязанская область, Рязанский район, поселок Дашки 2-е	0101000020E6100000630E828E56D943401A69A9BC1D394B40
78314	1	12	1339	27530	\N	\N	54.504745	Рязанская область, Рязанский район, с.Гавердово, администрация		0101000020E6100000BF49D3A068104440E6E8F17B9B404B40
78316	1	12	1339	22157	\N	\N	54.432096999999999	Рязанская область, Рязанский район, с.Вышетравино, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Вышетравино	0101000020E610000039ED293927E0434090D959F44E374B40
78313	1	12	1339	27516	\N	\N	54.517305	Рязанская область, Рязанский район, с.Вышгород, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Вышгород	0101000020E6100000EBC9FCA36F0644405587DC0C37424B40
78311	1	12	1339	27425	\N	\N	54.518856999999997	Рязанская область, Рязанский район, с.Высокое, здание основной школы	Россия, Рязанская область, Рязанский район, поселок Высокое	0101000020E6100000983270404BB543407C26FBE769424B40
78310	1	12	1339	54592	\N	\N	54.6971291891359	Рязанская область, Рязанский район, п.Варские, здание аграрного техникума	Россия, Рязанская область, Рязанский район, поселок Рязанскийсовхозтехникум	0101000020E6100000397EA83462EE4340ED0BE8853B594B40
78334	1	12	1339	28460	\N	\N	54.777099999999997	Рязанская область, Рязанский район, с.Борисково, здание администрации сельского поселения	Россия, Рязанская область, Рязанский район, поселок Борисково	0101000020E61000008A1EF818AC1A44405DDC460378634B40
78346	1	12	1339	28955	\N	\N	54.496876	Рязанская область, Рязанский район, с.Болошнево, здание сельского клуба	Россия, Рязанская область, Рязанский район, поселок Болошнево	0101000020E610000029232E008D0244406A15FDA1993F4B40
78344	1	12	1339	28922	\N	\N	54.514645000000002	Рязанская область, Рязанский район, с.Александрово, здание Дома культуры	Россия, Рязанская область, Рязанский район, поселок Александрово	0101000020E6100000718E3A3AAEF2434064062AE3DF414B40
78323	1	12	1339	27976	38646	\N	54.622508000000003	Рязанская область, Рязанский район, с.Алеканово, Центральная, приемная администрации		0101000020E61000001DAED51EF6FC4340CBBF9657AE4F4B40
78332	1	12	1339	19620	\N	\N	54.756287999999998	Рязанская область, Рязанский район, с.Агро-Пустынь, здание начальной школы	Россия, Рязанская область, Рязанский район, поселок Агро-Пустынь	0101000020E6100000E6CFB7054BE54340BA2D910BCE604B40
78294	1	12	757	54682	38802	\N	53.573024677232198	Рязанская область, Ряжский район, с.Шереметьево, Центральная, 100, СДК	Россия, Рязанская область, Ряжский район, поселок Шереметьево	0101000020E61000001A31B3CF630A44402C6519E258C94A40
78303	1	12	757	27054	38771	\N	53.786656000000001	Рязанская область, Ряжский район, с.Чирково, Есенина, 32, школа №3		0101000020E610000003EFE4D363F94340E199D024B1E44A40
78289	1	12	757	26407	38739	\N	53.649514000000003	Рязанская область, Ряжский район, с.Турово, Совхозная, 13, СДК		0101000020E61000009B1DA9BEF3254440A725564623D34A40
78291	1	12	757	26421	38770	\N	53.679769999999998	Рязанская область, Ряжский район, п.Свет, Дорожная, 6, СДК		0101000020E610000020D5B0DF130D4440A5660FB402D74A40
78299	1	12	757	26888	38740	\N	53.582517000000003	Рязанская область, Ряжский район, с.Салтыки, Поповка, 16, СДК		0101000020E6100000BF654E97C5F64340992EC4EA8FCA4A40
78272	1	12	757	5337	38030	\N	53.7062694624356	Рязанская область, Ряжский район, г.Ряжск, пл.Свободы, 12 центр внешкольной работы	Россия, Рязанская область, Ряжский район, Ряжск	0101000020E61000007FBF982D59074440DD96C80567DA4A40
78273	1	12	757	5337	38048	\N	53.709060999999998	Рязанская область, Ряжский район, г.Ряжск, Совхозная, 2 здание культуры и спорта		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78280	1	12	757	5337	38070	\N	53.703318874018997	Рязанская область, Ряжский район, г.Ряжск, Свободы, 48, школа №6	Россия, Рязанская область, Ряжский район, Ряжск	0101000020E61000009FE925C6320B4440E5D3635B06DA4A40
78277	1	12	757	5337	38032	\N	53.717411071992998	Рязанская область, Ряжский район, г.Ряжск, ул. М.Горького, 79, школа №3	Россия, Рязанская область, Ряжский район, Ряжск	0101000020E61000006FA0C03BF90844403465A71FD4DB4A40
78281	1	12	757	5337	38188	\N	53.709060999999998	Рязанская область, Ряжский район, г.Ряжск, Лермонтова, 13, музыкал. школа		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78275	1	12	757	5337	38184	\N	53.709060999999998	Рязанская область, Ряжский район, г.Ряжск, Ленина, 7, музык.школа		0101000020E610000002F4FBFECD0B44403DEFC682C2DA4A40
78271	1	12	757	5337	38093	\N	53.710894159137801	"Рязанская область, Ряжский район, г.Ряжск, Красной Армии, 43 НПО ""ПЛ№36"""	Россия, Рязанская область, Ряжский район, Ряжск	0101000020E61000003CBF28417F0B444019761893FEDA4A40
78288	1	12	757	26347	38643	\N	53.589396000000001	Рязанская область, Ряжский район, С.Ратманово, Центральная, 102, библиотека		0101000020E610000063450DA6611444405532005471CB4A40
78301	1	12	757	26968	38647	\N	53.793353000000003	Рязанская область, Ряжский район, с.Поплевино, Большая Дорога, 62, школа №3		0101000020E610000072C0AE264F0B44407D9752978CE54A40
78302	1	12	757	14257	38581	\N	53.826473704588999	Рязанская область, Ряжский район, с.Подвислово, Новая, 18, школа	Россия, Рязанская область, Ряжский район, поселок Подвислово	0101000020E610000075CDE49B6D084440457F68E6C9E94A40
78300	1	12	757	26895	38495	\N	53.759517000000002	Рязанская область, Ряжский район, с.Петрово, Новая, 17, школа №4		0101000020E610000090696D1ADB134440C6E061DA37E14A40
78296	1	12	757	10501	38493	\N	53.736749000000003	Рязанская область, Ряжский район, с.Новое Еголдаево, Школьная, 3, школа №4		0101000020E6100000AE8218E8DA2744402C2E8ECA4DDE4A40
78298	1	12	757	54673	\N	\N	53.616320000000002	Рязанская область, Ряжский район, с.Марчуки 2, 76, СДК	Россия, Рязанская область, Ряжский район, поселок Марчуки 2-е	0101000020E6100000CF85915ED4E4434074EFE192E3CE4A40
78287	1	12	757	13917	38741	\N	53.626739999999998	Рязанская область, Ряжский район, с.Марчуки 1, Новая, 6, клуб		0101000020E610000036E84B6F7F1844402A8C2D0439D04A40
78297	1	12	757	10561	38645	\N	53.636276000000002	Рязанская область, Ряжский район, с.Журавинка, Центральная, 61, администация		0101000020E6100000E5D022DBF9F84340679DF17D71D14A40
78295	1	12	757	26682	38497	\N	53.724130000000002	Рязанская область, Ряжский район, с.Дегтяное, Советской Армии, 1а, администрация		0101000020E6100000BE33DAAA241A4440B806B64AB0DC4A40
69747	1	11	\N	9161	37892	\N	52.969205000000002	город Орел, Московская, 26		0101000020E610000062F4DC42570A4240520FD1E80E7C4A40
78286	1	12	757	26263	38597	\N	53.641047999999998	Рязанская область, Ряжский район, с.Большая Алешня, Гагарина, 21, администрация		0101000020E61000003F8BA548BE104440469561DC0DD24A40
78261	1	12	703	25116	\N	\N	54.952925	Рязанская область, Рыбновский район, с.Шехмино, здание администрации поселения	Россия, Рязанская область, Рыбновский район, поселок Шехмино	0101000020E6100000D8D30E7F4DE0434039454772F9794B40
78260	1	12	703	25052	\N	\N	54.811435000000003	Рязанская область, Рыбновский район, д.Чурилково, здание средней общеобраз.школы	Россия, Рязанская область, Рыбновский район, поселок Чурилково	0101000020E6100000946A9F8EC7B6434036EA211ADD674B40
78258	1	12	703	24954	\N	\N	54.728346999999999	Рязанская область, Рыбновский  район, с.Ходынино, здание администрации поселения	Россия, Рязанская область, Рыбновский район, поселок Ходынино	0101000020E6100000986E1283C0C64340E29178793A5D4B40
78255	1	12	703	24818	\N	\N	54.863636999999997	Рязанская область, Рыбновский  район, с.Федякино, школа		0101000020E610000070287CB60EC64340CA4E3FA88B6E4B40
78253	1	12	703	24760	\N	\N	54.908918999999997	Рязанская область, Рыбновский район, с.Сельцы, здание администрации поселения	Россия, Рязанская область, Рыбновский район, поселок Сельцы	0101000020E610000059130B7C45C3434044DB317557744B40
78264	1	12	703	4913	37972	\N	54.72907845548	Рязанская область, Рыбновский район, г.Рыбное, Электротяговая, 16, академия пчеловодства	Россия, Рязанская область, Рыбновский район, Рыбное	0101000020E610000083C13577F4BF4340D61D8B6D525D4B40
78266	1	12	703	4913	38051	\N	54.725129000000003	Рязанская область, Рыбновский район, г.Рыбное, Театральная, 1, социально-культурный центр		0101000020E610000095F430B43AC14340CB30EE06D15C4B40
78262	1	12	703	4913	38047	\N	54.725129000000003	Рязанская область, Рыбновский район, г.Рыбное, Почтовая, 22		0101000020E610000095F430B43AC14340CB30EE06D15C4B40
78268	1	12	703	4913	37977	\N	54.726638159308699	Рязанская область, Рыбновский район, г.Рыбное, Новосельская, 17, школа № 3	Россия, Рязанская область, Рыбновский район, Рыбное	0101000020E610000033A8363811C14340F3035779025D4B40
78270	1	12	703	4913	38271	\N	54.729128129187302	Рязанская область, Рыбновский район, г.Рыбное, Макаренко, 13, школа № 2	Россия, Рязанская область, Рыбновский район, Рыбное	0101000020E6100000EDD286C3D2BE4340884CF910545D4B40
78269	1	12	703	4913	38068	\N	54.725129000000003	"Рязанская область, Рыбновский район, г.Рыбное, Заготовительная, 7 здание ОАО ""Рыбновская МСО"""		0101000020E610000095F430B43AC14340CB30EE06D15C4B40
78252	1	12	703	24682	\N	\N	54.820580999999997	Рязанская область, Рыбновский район, с.Пощупово, здание администрации поселения	Россия, Рязанская область, Рыбновский район, поселок Пощупово	0101000020E610000006F7031E18DC4340075C57CC08694B40
78259	1	12	703	60422	\N	\N	54.822888147815	"Рязанская область, Рыбновский район, п.завода ""Ветзоотехника"", здание завода"	Россия, Рязанская область	0101000020E6100000C347C49448BC4340AB22DC6454694B40
78250	1	12	703	24586	\N	\N	54.583764000000002	Рязанская область, Рыбновский район, п.Пионерский, здание основной общеобраз.школы	Россия, Рязанская область, Рыбновский район, поселок Пионерский	0101000020E61000000742B280098E4340844A5CC7B84A4B40
78257	1	12	703	24950	\N	\N	54.722518999999998	Рязанская область, Рыбновский  район, д.Перекаль, здание основной общеобраз.школы		0101000020E610000005C078060DCD43408BDEA9807B5C4B40
78249	1	12	703	24524	\N	\N	54.613379000000002	Рязанская область, Рыбновский район, с.Пальные, адмистрация		0101000020E6100000D93D7958A8A34340CF86FC33834E4B40
78230	1	12	703	23651	\N	\N	54.686937	Рязанская область, Рыбновский  район, с.Ногино, Здание начальной общеобраз. школы	Россия, Рязанская область, Рыбновский район, поселок Ногино	0101000020E610000003965CC5E2B14340C8B4368DED574B40
78247	1	12	703	24472	\N	\N	54.841703000000003	Рязанская область, Рыбновский район, с.Новоселки, здание администрации поселения		0101000020E610000052431B800DE24340F9F884ECBC6B4B40
78234	1	12	703	23786	\N	\N	54.775827999999997	Рязанская область, Рыбновский  район, д.Новое Батурино, здание основной общеобраз. школы	Россия, Рязанская область, Рыбновский район, поселок Новое Батурино	0101000020E61000001D0247020DBA434019A9F7544E634B40
78246	1	12	703	24385	\N	\N	54.778013999999999	Рязанская область, Рыбновский район, д.Марково, здание администрации поселения	Россия, Рязанская область, Рыбновский район, поселок Марково	0101000020E6100000DDB1D82615CF434042EA76F695634B40
78232	1	12	703	23733	\N	\N	54.6841919131843	Рязанская область, Рыбновский  район, д.Мантурово, здание дома культуры	Россия, Рязанская область, Рыбновский район, поселок Мантурово	0101000020E6100000467D923B6CB84340A9177C9A93574B40
78241	1	12	703	24151	\N	\N	54.797975000000001	Рязанская область, Рыбновский район, с.Летово, здание начальной общеобраз.школы		0101000020E61000004640852348C343404703780B24664B40
78245	1	12	703	24370	\N	\N	54.866875999999998	"Рязанская область,  Рыбновский район, с.Кузьминское, здание СПК колхоза ""Есенинский"""	Россия, Рязанская область, Рыбновский район, поселок Кузьминское	0101000020E61000004D81CCCEA2D34340F9D7F2CAF56E4B40
78251	1	12	703	24671	\N	\N	54.806569000000003	Рязанская область,  Рыбновский  район, с.Костино, здание средней общеобраз.школы		0101000020E6100000621399B9C0D54340D57B2AA73D674B40
78244	1	12	703	24292	\N	\N	54.862166000000002	Рязанская область, Рыбновский район, с.Константиново, здание музея им.С.Есенина		0101000020E6100000A6D590B8C7CE434090DC9A745B6E4B40
78243	1	12	703	24251	\N	\N	54.529935000000002	Рязанская область, Рыбновский  район, п.Комсомольский, здание администрации поселения		0101000020E6100000656D533C2E844340BD00FBE8D4434B40
78240	1	12	703	24117	\N	\N	54.762318999999998	Рязанская область, Рыбновский  район, с.Истобники, здание начальной общеобраз. школы	Россия, Рязанская область, Рыбновский район, поселок Истобники	0101000020E61000009221C7D633C04340490F43AB93614B40
78242	1	12	703	24211	\N	\N	54.721006000000003	Рязанская область, Рыбновский район, с.Житово, здание сельского дома культуры	Россия, Рязанская область, Рыбновский район, поселок Житово	0101000020E6100000F4A8F8BF23AE4340221CB3EC495C4B40
78256	1	12	703	24891	\N	\N	54.635923370302102	Рязанская область, Рыбновский район, с.Городище, здание сельского дома культуры	Россия, Рязанская область, Рыбновский район, поселок Глебово-Городище	0101000020E6100000161406651A9F434019E3C3EC65514B40
78235	1	12	703	23840	\N	\N	54.755398999999997	Рязанская область, Рыбновский  район, д.Высокое, здание сельского дома культуры		0101000020E610000058552FBFD3B443402E3718EAB0604B40
78237	1	12	703	23921	\N	\N	54.872087999999998	"Рязанская область, Рыбновский  район, с.Вакино, здание правления  СПК ""Вакинское"""	Россия, Рязанская область, Рыбновский район, поселок Вакино	0101000020E6100000E38920CEC3BD4340F59D5F94A06F4B40
78236	1	12	703	4905	\N	\N	54.571218999999999	Рязанская область,  Рыбновский  район, с.Большое Жоково, здание дома культуры	Россия, Рязанская область, Рыбновский район, поселок Большое Жоково	0101000020E6100000BBB4E1B0347A43404AED45B41D494B40
78231	1	12	703	23658	\N	\N	54.724218999999998	Рязанская область,  Рыбновский район, д.Баграмово, Здание Центра народной культуры	Россия, Рязанская область, Рыбновский район, поселок Баграмово	0101000020E6100000CE380D5185B9434027124C35B35C4B40
78229	1	12	703	23571	\N	\N	54.653547000000003	Рязанская область, Рыбновский  район, с.Алешня, Здание сельского дома культуры		0101000020E6100000EBC726F911AD434010B3976DA7534B40
78238	1	12	7324	54622	\N	\N	54.779265803062501	Рязанская область, Рыбновский район, п.Глебково, здание сельского дома культуры	Россия, Рязанская область	0101000020E610000064247B849AB343403F7100FDBE634B40
78228	1	12	507	6498	38641	\N	54.033754000000002	Рязанская область, Путятинский район, с. Унгор, Молодежная, 6,Здание школы		0101000020E61000002497FF907E8D4440FA0D130D52044B40
78209	1	12	507	22657	9850	\N	54.186578456097998	Рязанская область, Путятинский район, с. Строевское, Новая, 4, (клуб)	Россия, Рязанская область, Путятинский район, поселок Строевское	0101000020E6100000B3EBDE8AC49A44409813B4C9E1174B40
78227	1	12	507	23359	38711	\N	54.064234999999996	Рязанская область, Путятинский район, с. Романовы Дарки, Сельская, 27, Здание библиотеки		0101000020E610000046B5882826A5444018213CDA38084B40
78220	1	12	507	23178	38217	\N	54.158945568600899	Рязанская область, Путятинский район, с. Путятино, ул. Ленинский проспект, д. 59а корпус 2 здание ГУ	Россия, Рязанская область, Путятинский район, поселок Путятино	0101000020E6100000BB0B9414588E44403EEAAF5758144B40
78221	1	12	507	23178	38253	\N	54.154058999999997	Рязанская область, Путятинский район, с. Путятино, ул. Ворошилова, д. 41 школа		0101000020E610000080D8D2A3A98E4440C5538F34B8134B40
78218	1	12	507	23090	\N	\N	54.201745000000003	Рязанская область, Путятинский район, с. Поляки, 67, (медпункт)		0101000020E6100000BA15C26A2C6D4440D690B8C7D2194B40
78219	1	12	507	23094	38498	\N	54.109321999999999	Рязанская область, Путятинский район, с. Песочня, Революции, 4 (школа)		0101000020E610000074CFBA46CB694440DD5D6743FE0D4B40
78203	1	12	507	22382	38765	\N	54.127184999999997	Рязанская область, Путятинский район, с. Отрада, Поселковая, 18, (клуб)		0101000020E6100000D7BD15890978444058C51B9947104B40
78207	1	12	507	54675	38745	\N	54.081419235087402	Рязанская область, Путятинский район, п. Новая Деревня, Черемушки, 1, (клуб)	Россия, Рязанская область, Путятинский район, поселок Новая Деревня	0101000020E610000011E50B5A48B84440F22213F06B0A4B40
78213	1	12	507	22819	38738	\N	54.116252000000003	Рязанская область, Путятинский район, с. Макеево, Центральная, д.30, (клуб)		0101000020E61000002522FC8BA09B44401C0C7558E10E4B40
78215	1	12	507	22898	38769	\N	54.168455999999999	Рязанская область, Путятинский район, с. Летники, Школьная,18, (школа)		0101000020E6100000AFB321FFCC724440516859F78F154B40
78223	1	12	507	23275	38648	\N	54.084294	Рязанская область, Путятинский район, с. Караулово, Центральная, 55, Здание библиотеки		0101000020E61000005A8121AB5BB14440E09F5225CA0A4B40
78212	1	12	507	3203	38595	\N	54.115566000000001	Рязанская область, Путятинский район, с. Карабухино, Луговая, 8, (школа)		0101000020E610000095D74AE82EA14440C843DFDDCA0E4B40
78211	1	12	507	22745	38640	\N	54.212777000000003	Рязанская область, Путятинский район, с. Екатериновка, Солнечный переулок, 13,  (клуб)		0101000020E610000036583849F3854440A62BD8463C1B4B40
78222	1	12	507	23228	38596	\N	54.134470999999998	Рязанская область, Путятинский район, с. Глебово, Молодежная, (клуб)		0101000020E6100000849ECDAACF95444055A1815836114B40
78208	1	12	507	3086	38593	\N	54.209067585441403	Рязанская область, Путятинский район, с. Воршево, Центральная, (школа)	Россия, Рязанская область, Путятинский район, поселок Воршево	0101000020E6100000E6913F1878904440F0517FBDC21A4B40
78205	1	12	507	22476	38768	\N	54.035176999999997	Рязанская область, Путятинский район, с. Большая Екатериновка, Центальная, 87, (администрация)		0101000020E6100000CC9BC3B5DAB34440234910AE80044B40
78202	1	12	507	22375	38767	\N	54.175961000000001	Рязанская область, Путятинский район, с. Береговое, Центральная, 104, здание  школы		0101000020E61000001DE6CB0BB07744408C2FDAE385164B40
78172	1	12	415	20966	\N	\N	54.286355999999998	Рязанская область, Пронский район, с. Тырново, здание средней школы	Россия, Рязанская область, Пронский район, поселок Тырново	0101000020E61000000BCF4BC5C6CA4340B6813B50A7244B40
69808	1	11	\N	9161	37928	\N	52.926074	Орловская область, город Орел, Бетонный переулок, 5		0101000020E61000002E56D4601A04424084D6C39789764A40
78178	1	12	415	2223	38764	\N	54.083400552135998	Рязанская область, Пронский район, п. Орловский, ул.Центральная, 38, здание дома культуры	Россия, Рязанская область, Пронский район, поселок Совхоз Орловский	0101000020E61000001FB935E9B6C0434013BA4BE2AC0A4B40
78184	1	12	415	2499	38642	\N	54.082518999999998	Рязанская область, Пронский район, п. Погореловский, ул.Садовая, 29, здание дома культуры		0101000020E6100000B2135E8253DB434039268BFB8F0A4B40
78183	1	12	415	2460	38736	\N	53.989823999999999	Рязанская область, Пронский район, п. Синь, ул.Центральная, 10, здание клуба		0101000020E61000002A5437177FBF4340E065868DB2FE4A40
78180	1	12	415	2335	38737	\N	54.004261999999997	Рязанская область, Пронский район, с. Семенск, ул.Степановка, 24, здание дома культуры		0101000020E6100000957EC2D9ADB54340CA4E3FA88B004B40
78191	1	12	415	2627	38102	\N	54.121248503210303	Рязанская область, Пронский район, р.п. Пронск, ул.Первомайская, 30, здание средней школы	Россия, Рязанская область, Пронский район, поселок Пронск	0101000020E61000006B7F677BF4CC43401BD65416850F4B40
78190	1	12	415	2627	38102	\N	54.106676999999998	Рязанская область, Пронский район, р.п. Пронск,  Первомайская 32 , здание районного дома культуры		0101000020E61000009293895B05CD4340211E8997A70D4B40
78192	1	12	415	2627	38492	\N	54.105214283551497	Рязанская область, Пронский район, р.п. Пронск, Верхне-Архангельская, 30, здание дома культуры	Россия, Рязанская область, Пронский район, поселок Пронск	0101000020E6100000965984622BCC4340698A00A7770D4B40
78179	1	12	415	2270	38488	\N	54.068018000000002	Рязанская область, Пронский район, с. Октябрьское, ул.Большая, 76, здание дома культуры		0101000020E6100000CCD3B9A294B6434009C556D0B4084B40
78201	1	12	415	2792	\N	\N	54.038730000000001	"Рязанская область, Пронский район, г. Новомичуринск, 21 ""Д"", здание спортшколы м-н ""Д"""		0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78200	1	12	415	2792	\N	\N	54.038730000000001	"Рязанская область, Пронский район, г. Новомичуринск, 26 ""Д"", здание школы №3"	Россия, Рязанская область, Пронский район, Новомичуринск	0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78195	1	12	415	2792	38064	\N	54.038730000000001	Рязанская область, Пронский район, г. Новомичуринск, пр. Энергетиков, 20, здание д/с №3		0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78193	1	12	415	2792	38063	\N	54.038730000000001	Рязанская область, Пронский район, г. Новомичуринск, пр. Энергетиков, 28, здание техникума		0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78194	1	12	415	2792	38200	\N	54.038730000000001	Рязанская область, Пронский район, г. Новомичуринск, пр. Смирягина, 18, здание школы №1		0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78198	1	12	415	2792	38066	\N	54.038730000000001	"Рязанская область, Пронский район, г. Новомичуринск, ул. Строителей, 16, здание дома культуры ""Энергетик"""		0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78196	1	12	415	2792	38066	\N	54.038730000000001	Рязанская область, Пронский район, г. Новомичуринск, ул. Строителей, 18, здание школы искусств		0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78199	1	12	415	2792	38103	\N	54.038730000000001	Рязанская область, Пронский район, г. Новомичуринск, ул. Комсомольская, 6, здание школы №2		0101000020E6100000AD50A4FB39DF4340E2AFC91AF5044B40
78182	1	12	415	21435	\N	\N	53.990611999999999	Рязанская область, Пронский район, д. Мамоново, здание школы	Россия, Рязанская область, Пронский район, поселок Мамоново	0101000020E6100000026553AEF0C843403883BF5FCCFE4A40
78169	1	12	415	19209	38489	\N	54.362191653060201	Рязанская область, Пронский район, с. Малинищи, ул.Школьная, 73, здание школы	Россия, Рязанская область, Пронский район, поселок Малинищи	0101000020E6100000492C29779FCD4340B96FB54E5C2E4B40
78186	1	12	415	2570	\N	\N	54.013061999999998	Рязанская область, Пронский район, с. Маклаково, здание школа	Россия, Рязанская область, Пронский район, поселок Маклаково	0101000020E6100000D15790662CE243400169FF03AC014B40
78187	1	12	415	21636	\N	\N	54.091962000000002	Рязанская область, Пронский район, с. Кисьва, здание школы	Россия, Рязанская область, Пронский район, поселок Кисьва	0101000020E61000000394861A85E64340C53C2B69C50B4B40
78175	1	12	415	21078	38762	\N	54.171708000000002	Рязанская область, Пронский район, с. Елшино, ул.Октябрьская, 27, здание СДК		0101000020E61000002A560DC2DCCC4340153B1A87FA154B40
78188	1	12	415	21718	\N	\N	54.064266000000003	Рязанская область, Пронский район, д. Денисово, здание школы	Россия, Рязанская область, Пронский район, поселок Денисово	0101000020E610000080F44D9A06E74340541F48DE39084B40
78171	1	12	415	20859	\N	\N	54.332144999999997	Рязанская область, Пронский район, с. Гремяки, здание школы	Россия, Рязанская область, Пронский район, поселок Гремяки	0101000020E6100000164ED2FC31CF4340D44334BA832A4B40
78181	1	12	415	2396	38717	\N	53.994942000000002	Рязанская область, Пронский район, п. Восточный, ул.Молодежная, 30, здание дома культуры		0101000020E610000019AF795567AD43405BB56B425AFF4A40
78189	1	12	415	54655	\N	\N	54.1433535533045	Рязанская область, Пронский район, с. Большое Село, здание администрации	Россия, Рязанская область, Пронский район, поселок Большое Село	0101000020E6100000C51A2E724FDF43401AE0826C59124B40
78177	1	12	415	21165	38594	\N	54.162126000000001	Рязанская область, Пронский район, с. Березово, ул.Советская, 11, здание администрации		0101000020E61000006FD921FE61B9434068EA758BC0144B40
78185	1	12	415	21533	\N	\N	54.095067	Рязанская область, Пронский район, с. Береговая Погореловка, здание детского сада	Россия, Рязанская область, Пронский район, поселок Береговая Погореловка	0101000020E61000002C64AE0CAADB4340E4F6CB272B0C4B40
78174	1	12	415	21019	38638	\N	54.185761999999997	Рязанская область, Пронский район, д. Альютово, ул.Почтовая,6 здание школы		0101000020E61000008C648F5033C44340766B990CC7174B40
78173	1	12	415	20977	\N	\N	54.256354999999999	Рязанская область, Пронский район, с. Абакумово, здание ФАП	Россия, Рязанская область, Пронский район, поселок Абакумово	0101000020E6100000F0A65B7688CB434042959A3DD0204B40
78160	1	12	1568	20287	38801	\N	54.546013000000002	Рязанская область, Пителинский район, с. Юрьево, им. Дмитрия Кокорева, 29, здание Дома культуры		0101000020E6100000B3EA73B515FB44406E1805C1E3454B40
78159	1	12	1568	19021	38733	\N	54.620026000000003	Рязанская область, Пителинский район, с. Темирево, Школьная, 43, здание школы		0101000020E61000008481E7DEC3ED4440B95510035D4F4B40
78163	1	12	1568	19107	38639	\N	54.604509999999998	Рязанская область, Пителинский район,  с. Потапьево, Первомайская, 64, здание Дома культуры		0101000020E61000002D0B26FE28E044406F0D6C95604D4B40
78161	1	12	1568	19102	38763	\N	54.503343999999998	Рязанская область, Пителинский район, с. Подболотье, Школьная, 6, здание школы		0101000020E6100000460C3B8C49F54440A45181936D404B40
78168	1	12	1568	19205	38491	\N	54.580998999999998	Рязанская область, Пителинский район, р.п. Пителино, Павлова, 10, здание Пителинской ЦРБ		0101000020E6100000651C23D923E844401D01DC2C5E4A4B40
78166	1	12	1568	19205	38514	\N	54.580219958986099	Рязанская область, Пителинский район, р.п. Пителино, Красная, 27, здание Дома культуры	Россия, Рязанская область, Пителинский район, поселок Пителино	0101000020E6100000DC80CF0F23E84440183E22A6444A4B40
78167	1	12	1568	19205	38490	\N	54.579303904527499	Рязанская область, Пителинский район,  р.п. Пителино, Горького, 56, здание средней школы	Россия, Рязанская область, Пителинский район, поселок Пителино	0101000020E6100000624CFA7B29E8444093382BA2264A4B40
78164	1	12	1568	20533	38731	\N	54.625833	Рязанская область, Пителинский район, с. Пёт, Николаевка, 16, здание Дома культуры		0101000020E61000002F3196E997D64440F8E0B54B1B504B40
78162	1	12	1568	20365	38761	\N	54.598230000000001	Рязанская область, Пителинский район, с. Пеньки, Заречная, 6/2, здание Дома культуры		0101000020E61000009604A8A965ED444038BEF6CC924C4B40
78157	1	12	1568	20065	38591	\N	54.476610000000001	Рязанская область, Пителинский район, с. Новый Ункор, Молодежная, 4а, здание ДК		0101000020E61000001310937021CB44402979758E013D4B40
78156	1	12	1568	18902	38487	\N	54.514985000000003	Рязанская область, Пителинский район,  с. Нестерово, Молодежная, 1, здание КСК		0101000020E6100000207BBDFBE3E744401D774A07EB414B40
78154	1	12	1568	18891	38636	\N	54.716731000000003	Рязанская область, Пителинский район,  п. Краснопартизанский, Есенина, 1а, здание Дома культуры		0101000020E6100000B0E3BF4010E04440C38366D7BD5B4B40
78155	1	12	1568	19938	38766	\N	54.700310000000002	Рязанская область, Пителинский район, с. Ермо-Николаевка, Николаевка, 25, здание Дома культуры		0101000020E6100000A7CEA3E2FFE04440E88711C2A3594B40
78158	1	12	1568	18945	38573	\N	54.551392532197902	Рязанская область, Пителинский район, с. Гридино, Крупской, 2, здание администрации	Россия, Рязанская область, Пителинский район, поселок Гридино	0101000020E61000005B09DD2571D04440251FBB0B94464B40
78153	1	12	1568	19825	38732	\N	54.737527999999998	Рязанская область, Пителинский район, с. Высокие Поляны, Центральная, 45, школа		0101000020E610000087DD770C8FDF444030F14751675E4B40
78165	1	12	1568	20539	38592	\N	54.584724000000001	Рязанская область, Пителинский район,  с. Веряево, Колхозная, 91, здание дома культуры		0101000020E6100000CEDDAE97A6CC4440D9976C3CD84A4B40
78134	1	12	1538	18888	\N	\N	53.403866999999998	Рязанская область, Новодеревенский район, д.Чернышевка, 67 ФАП		0101000020E6100000698B6B7C261144408177F2E9B1B34A40
78131	1	12	1538	18697	38728	\N	53.440666999999998	Рязанская область, Новодеревенский район, с.Студенки, Молодежная, 10а ДК		0101000020E6100000511553E92730444095B6B8C667B84A40
78150	1	12	1538	18788	38729	\N	53.488232000000004	Рязанская область, Новодеревенский район, с.Спешнево, Центральная, 33 школа		0101000020E61000008237A451813F44402B6EDC627EBE4A40
78141	1	12	1538	18587	38718	\N	53.502979000000003	Рязанская область, Новодеревенский район, с.Сергиевский Боровок, Центральная, 119 библиотека		0101000020E6100000429946938B1F444093C9A99D61C04A40
78149	1	12	1538	18784	\N	\N	53.492052000000001	Рязанская область, Новодеревенский район, с.Просечье, Колхозная, 10 администрация	Россия, Рязанская область, Новодеревенский район, поселок Просечье	0101000020E61000007DCF48844630444038F7578FFBBE4A40
78132	1	12	1538	18785	38726	\N	53.361854999999998	Рязанская область, Новодеревенский район, д.Павловка, Центральная, 46 школа		0101000020E6100000C5008926502C44407172BF4351AE4A40
78127	1	12	1538	18470	38582	\N	53.445825999999997	Рязанская область, Новодеревенский район, с. Ольховка, Крутякова, 24 ДК		0101000020E61000002A70B20DDC1D44406EDA8CD310B94A40
78144	1	12	1538	54688	38809	\N	53.484210755442902	Рязанская область, Новодеревенский район, с.Ново-Тишевое, Вишневая, 17 ФАП	Россия, Рязанская область, Новодеревенский район, поселок Новотишевое	0101000020E61000004DF8A57EDE0E444086AE44A0FABD4A40
78140	1	12	1538	19204	\N	\N	53.539928000000003	Рязанская область, Новодеревенский район, с.Ново-Сергиевка, 39 ДК		0101000020E6100000EA961DE21F164440EC18575C1CC54A40
78143	1	12	1538	18636	38760	\N	53.485745999999999	Рязанская область, Новодеревенский район, с.Нижний Якимец, Молодежная, 20 детский сад		0101000020E610000076374F75C8154440D714C8EC2CBE4A40
78152	1	12	1538	19822	38735	\N	53.558658000000001	Рязанская область, Новодеревенский район, д.Михалково, Центральная, 17 школа		0101000020E61000008A5B0531D03F44400BD3F71A82C74A40
78689	1	12	1538	45853	\N	\N	53.466186286943199	Рязанская область, Чучковский район, поселок  Луговой, сельский  клуб	Россия, Рязанская область, Новодеревенский район, поселок Луговой	0101000020E6100000367689EAAD23444031ED9BFBABBB4A40
78142	1	12	1538	19307	38486	\N	53.425887000000003	Рязанская область, Новодеревенский район, с.Ленино, Центральная, 43 ДК		0101000020E61000008AC8B08A370444405265187783B64A40
78146	1	12	1538	19510	38589	\N	53.481147999999997	Рязанская область, Новодеревенский район, с.Красное Знамя, Почтовая, 30		0101000020E6100000938C9C853D0544409544F64196BD4A40
78138	1	12	1538	18575	\N	\N	53.492838999999996	Рязанская область, Новодеревенский район, п. Каширин,  школьная 5 НПО «ПУ №30»	Россия, Рязанская область, Новодеревенский район, поселок Каширин	0101000020E6100000DFFB1BB4571B4440BF982D5915BF4A40
78148	1	12	1538	19618	38590	\N	53.524734000000002	Рязанская область, Новодеревенский район, с.Калинино, Молодежная, 1а школа		0101000020E6100000F9A3A833F70E4440B58CD47B2AC34A40
78136	1	12	1538	18467	38727	\N	53.366546	Рязанская область, Новодеревенский район, с.Зимарово, Заречная, 50 ДК		0101000020E6100000C214E5D2F8194440643DB5FAEAAE4A40
78137	1	12	1538	18469	38730	\N	53.578651999999998	Рязанская область, Новодеревенский район, с.Бурминка, Молодежная 6Б Школа		0101000020E610000093E34EE9601F4440EBE1CB4411CA4A40
78133	1	12	1538	18789	38734	\N	53.436515	Рязанская область, Новодеревенский район, д.Борисовка, Зеленая, 1а школа		0101000020E61000001D3C139A24164440529B38B9DFB74A40
78126	1	12	1538	18465	38725	\N	53.414102999999997	Рязанская область, Новодеревенский район, с.Благие, Центральная, 28 школа		0101000020E610000087359545612344407616BD5301B54A40
78129	1	12	1538	18582	38635	\N	53.398611000000002	Рязанская область, Новодеревенский район, д.Бахметьево, Мичурина, 45 ФАП		0101000020E61000001FD61BB5C2204440B6696CAF05B34A40
78123	1	12	1538	18263	38092	\N	53.476883239628499	Рязанская область, Новодеревенский район, р.п. Александро-Невский, Советская, 27 ДК	Россия, Рязанская область, Новодеревенский район, поселок Александро-Невский	0101000020E61000003DD4B661141A44405A828C800ABD4A40
78124	1	12	1538	18263	38481	\N	53.476320000000001	Рязанская область, Новодеревенский район, р.п. Александро-Невский, Весенняя 15 Детский сад		0101000020E6100000D9243FE2571A44402237C30DF8BC4A40
78118	1	12	1071	18019	\N	\N	54.221895000000004	Рязанская область, Михайловский район, с.Щетиновка, администрация муниципального образования		0101000020E61000008ACBF10A44814340AE122C0E671C4B40
78095	1	12	1071	16888	\N	\N	54.006686000000002	Рязанская область, Михайловский район, д.Щеголево,д. 39 Администрация муниципального образования		0101000020E6100000E4486760E4834340A8AB3B16DB004B40
78115	1	12	1071	15491	38759	\N	53.967801000000001	Рязанская область, Михайловский район, с.Чурики, Верховка, 1-а, Администрация муниципального образования		0101000020E6100000D940BAD8B49E43409F0436E7E0FB4A40
77940	1	12	1071	9480	\N	\N	54.139076000000003	Рязанская область, Михайловский район, с.Фирюлевка, медпункт		0101000020E6100000D82E6D382CA743404AD40B3ECD114B40
78116	1	12	1071	17970	\N	\N	54.342742999999999	Рязанская область, Михайловский район, п.Трепольский, администрация муниципального образования		0101000020E61000004FAC53E57B6A43406AF7AB00DF2B4B40
78104	1	12	1071	17364	38626	\N	54.314264999999999	Рязанская область, Михайловский район, с.Стубле, Кадушная, клуб		0101000020E61000000CE544BB0A85434083A3E4D539284B40
78114	1	12	1071	17856	\N	\N	54.202482000000003	Рязанская область, Михайловский район, с.Стрелецкие Выселки, д. 135 администрация муниципального образования		0101000020E6100000CBA0DAE0447A4340AC0320EEEA194B40
78097	1	12	1071	54684	38804	\N	54.060590979858702	Рязанская область, Михайловский район, п. центрального отделения с-за им. Ильича, Центральная, 13-а, Администрация муниципального образования	Россия, Рязанская область, Михайловский район, поселок Совхоз им. Ильича	0101000020E610000044A852B3079443404AB72572C1074B40
78117	1	12	1071	54672	\N	\N	54.339852062692202	"Рязанская область, Михайловский район, п.центрального отделения с-за ""Фрунзенский"", помещение Дома культуры"	Россия, Рязанская область, Михайловский район, поселок Совхоз Фрунзенский	0101000020E610000040A4DFBE0E68434077BD3445802B4B40
78110	1	12	1071	54677	\N	\N	54.1828464985038	Рязанская область, Михайловский район, д.Слободка, администрация муниципального образования	Россия, Рязанская область, Михайловский район, поселок Слободка	0101000020E61000008BA8893E1FA343402A1A6B7F67174B40
78090	1	12	1071	16668	\N	\N	54.132266000000001	Рязанская область, Михайловский район, д.Садовый поселок, медпункт	Россия, Рязанская область, Михайловский район, поселок Садовый Поселок	0101000020E6100000A60BB1FA23684340B62FA017EE104B40
78109	1	12	1071	17568	\N	\N	54.2075412951652	Рязанская область, Михайловский район, с.Рачатники, д.1 администрация муниципального образования	Россия, Рязанская область, Михайловский район, поселок Рачатники	0101000020E61000002A1DACFF7390434021CA17B4901A4B40
78122	1	12	1071	18254	\N	\N	54.275091000000003	"Рязанская область, Михайловский район, с. Пушкари, администрация ООО ""Пушкари"""		0101000020E6100000BB9A3C65358B43404436902E36234B40
78120	1	12	1071	18078	\N	\N	54.201917999999999	Рязанская область, Михайловский район, д.Прудские Выселки, медпункт	Россия, Рязанская область, Михайловский район, поселок Прудские Выселки	0101000020E6100000C636A968AC894340A33CF372D8194B40
78107	1	12	1071	17471	38632	\N	54.283890999999997	Рязанская область, Михайловский район, д.Поярково, Поярковская ООШ		0101000020E6100000499EEBFB709643407A50508A56244B40
78067	1	12	1071	15487	\N	\N	54.148300999999996	Рязанская область, Михайловский район, с.Помозово, помещение администрации	Россия, Рязанская область, Михайловский район, поселок Помозово	0101000020E6100000A6B5696CAF7D4340677BF486FB124B40
78106	1	12	1071	17412	\N	\N	54.128999999999998	Рязанская область, Михайловский район, с.Печерники, Административный центр, 6, здание СДК	Россия, Рязанская область, Михайловский район, поселок Печерники	0101000020E6100000529CA38E8EA143408D976E1283104B40
78069	1	12	1071	15591	38506	\N	54.220953000000002	Рязанская область, Михайловский район, п.Первомайский, Почтовая, 2, помещение клуба		0101000020E6100000C90567F0F77B4340FF791A30481C4B40
78084	1	12	1071	16358	38758	\N	54.083728999999998	Рязанская область, Михайловский район, д.Павелково, Лесная, 52, здание медпункта		0101000020E61000008C2E6F0ED7924340075DC2A1B70A4B40
78086	1	12	1071	54685	38805	\N	53.978236032507503	"Рязанская область, Михайловский район, п. отделения ""Возрождение"" с-за ""Калининский"", Луговая, 2, здание медпункта"	Россия, Рязанская область, Михайловский район, поселок Отделение совхоза Возрождение	0101000020E61000002368CC24EA8D43408BE255D636FD4A40
78080	1	12	1071	15769	38480	\N	54.234000999999999	Рязанская область, Михайловский район, п.Октябрьский, Цементников, 4, здание школы искусств		0101000020E6100000AC53E57B467243409B1DA9BEF31D4B40
78076	1	12	1071	15769	38477	\N	54.235609997851903	Рязанская область, Михайловский район, п.Октябрьский, Кочубина, 15-а, здание школы	Россия, Рязанская область, Михайловский район, поселок Октябрьский	0101000020E6100000978E39CFD8714340274EEE77281E4B40
78072	1	12	1071	15769	38483	\N	54.234000999999999	Рязанская область, Михайловский район, п.Октябрьский, Клубная, 10, здание школы №1		0101000020E6100000AC53E57B467243409B1DA9BEF31D4B40
78073	1	12	1071	15769	38633	\N	54.234000999999999	Рязанская область, Михайловский район, п.Октябрьский, Больничная, 1-а, здание администрации		0101000020E6100000AC53E57B467243409B1DA9BEF31D4B40
78079	1	12	1071	15769	38478	\N	54.234000999999999	Рязанская область, Михайловский район, п.Октябрьский, 3-ий Строительный переулок, 5, здание дома культуры		0101000020E6100000AC53E57B467243409B1DA9BEF31D4B40
78103	1	12	1071	17266	38714	\N	54.345157999999998	Рязанская область, Михайловский район, с.Новопанское, Слобода, дом культуры		0101000020E61000001C5E10919A844340F4F928232E2C4B40
78112	1	12	1071	17730	38724	\N	54.191321306174203	Рязанская область, Михайловский район, п.Некрасово, Новая, 6, здание СОШ №2	Россия, Рязанская область, Михайловский район, поселок Некрасово	0101000020E6100000C18EFF0241744340DE04DF347D184B40
78111	1	12	1071	54662	\N	\N	54.169285459905197	"Рязанская область, Михайловский район, п.центрального отделения с-за ""Мишино"", помещение библиотеки"	Россия, Рязанская область, Михайловский район, поселок Мишино	0101000020E6100000478E740646A64340085A8121AB154B40
78062	1	12	1071	15018	38198	\N	54.230333000000002	Рязанская область, Михайловский район, г.Михайлов, ст. Михайлов, 21-б, здание школы №2		0101000020E61000001211FE45D082434044183F8D7B1D4B40
78059	1	12	1071	15018	38257	\N	54.230333000000002	Рязанская область, Михайловский район,г.Михайлов, Школьная, 2, здание школы №3		0101000020E61000001211FE45D082434044183F8D7B1D4B40
78061	1	12	1071	15018	38468	\N	54.230333000000002	Рязанская область, Михайловский район, г.Михайлов, Октябрьская, 7, здание спортшколы		0101000020E61000001211FE45D082434044183F8D7B1D4B40
78065	1	12	1071	15018	38211	\N	54.230333000000002	Рязанская область, Михайловский район, г.Михайлов, Новая, 7, помещение дома-интерната для престарелых и инвалидов		0101000020E61000001211FE45D082434044183F8D7B1D4B40
78064	1	12	1071	15018	38211	\N	54.226482758792599	Рязанская область, Михайловский район, г.Михайлов, Новая, 5, помещение экономического колледжа-интерната	Россия, Рязанская область, Михайловский район, поселок Щетиновка	0101000020E6100000E6AF90B932804340CC0C1B65FD1C4B40
78057	1	12	1071	15018	38186	\N	54.2360368806088	Рязанская область, Михайловский район, г.Михайлов, Нагорная, 25-а, здание школы №1	Россия, Рязанская область, Михайловский район, Михайлов	0101000020E61000009ACC785BE9834340AFD2DD75361E4B40
78060	1	12	1071	15018	38471	\N	54.230333000000002	Рязанская область, Михайловский район, г.Михайлов, Карла Маркса, 11, помещение МУП		0101000020E61000001211FE45D082434044183F8D7B1D4B40
78121	1	12	1071	15018	38637	\N	54.230333000000002	Рязанская область, Михайловский район, г. Михайлов, Зеленая, д. 20 контора МУП Михайловсое МСО		0101000020E61000001211FE45D082434044183F8D7B1D4B40
78063	1	12	1071	15018	38505	\N	54.230333000000002	"Рязанская область, Михайловский район, г.Михайлов, 23 Партсъезда, 1, контора ООО ""Управление жилыми домами"""		0101000020E61000001211FE45D082434044183F8D7B1D4B40
78088	1	12	1071	16516	38572	\N	54.080418338640698	Рязанская область, Михайловский район, с.Малинки, Кулькова, клуб	Россия, Рязанская область, Михайловский район, поселок Малинки	0101000020E61000003604C765DC7E43403F0114234B0A4B40
78102	1	12	1071	17260	\N	\N	54.170847201278498	Рязанская область, Михайловский район, с.Красное, администрация муниципального образования	Россия, Рязанская область, Михайловский район, поселок Красное	0101000020E6100000CBB914579599434053CF8250DE154B40
78098	1	12	1071	54689	38810	\N	54.0861233404109	Рязанская область, Михайловский район, п.Коровинского спиртзавода, Центральная, 4, здание дома культуры	Россия, Рязанская область, Михайловский район, поселок Коровинский спирт. завод	0101000020E610000022C154336B9743407A371614060B4B40
78071	1	12	1071	15640	\N	\N	54.246960000000001	Рязанская область, Михайловский район,с.Козловка, помещение неполной средней школы	Россия, Рязанская область, Михайловский район, поселок Козловка	0101000020E6100000A4DFBE0E9C814340C8B5A1629C1F4B40
78070	1	12	1071	15640	38474	\N	54.246960000000001	"Рязанская область, Михайловский район,с.Козловка, Лещенка, 142, помещение конторы ООО ""Михайлов-Лада"""		0101000020E6100000A4DFBE0E9C814340C8B5A1629C1F4B40
78035	1	12	759	13972	38752	\N	53.441567999999997	Рязанская область, Милославский район, с. Кочуры, Зеленая, 1, администрация		0101000020E61000004DBD6E1118AF4340E57ADB4C85B84A40
78100	1	12	1071	17116	\N	\N	54.278675999999997	Рязанская область, Михайловский район,  д.Каморино, Школьная, 1, Администрация муниципального образования	Россия, Рязанская область, Михайловский район, поселок Каморино	0101000020E610000058AA0B78995F43400D17B9A7AB234B40
78108	1	12	1071	17564	\N	\N	54.239688999999998	Рязанская область, Михайловский район, с.Ижеславль, Дом культуры		0101000020E6100000E8A04B38F4A24340001B1021AE1E4B40
78092	1	12	1071	16778	\N	\N	54.231468999999997	Рязанская область, Михайловский район, д.Иваньково, сельский клуб		0101000020E61000009F71E140485C4340D784B4C6A01D4B40
78077	1	12	1071	15972	\N	\N	54.234547999999997	Рязанская область, Михайловский район, п.Змеинка здание клуба		0101000020E61000004E64E60297774340CDAB3AAB051E4B40
78089	1	12	1071	16579	38475	\N	54.098639549103602	Рязанская область, Михайловский район, п.Заря, Центральная, 4, здание администрации м.о.	Россия, Рязанская область, Михайловский район, поселок Заря	0101000020E6100000952C27A1F4674340EA094B3CA00C4B40
78101	1	12	1071	17175	\N	\N	54.264859000000001	Рязанская область, Михайловский район, Завидовка, д. 41 медпункт		0101000020E61000000E66136058684340908653E6E6214B40
78096	1	12	1071	16968	\N	\N	53.968102999999999	Рязанская область, Михайловский район, с.Жмурово, Администрация муниципального образования		0101000020E6100000B28009DCBA7343406A1492CCEAFB4A40
78094	1	12	1071	16832	38511	\N	54.040906943448	Рязанская область, Михайловский район, с.Грязное, Центральная, 74, здание администрации	Россия, Рязанская область, Михайловский район, поселок Грязное	0101000020E61000007BA2EBC20F8E4340B796C9703C054B40
78075	1	12	1071	15858	38757	\N	54.249395999999997	Рязанская область, Михайловский район, п.Горенка, Школьная, помещение бывшей начальной школы		0101000020E61000005471E316F36D434069E04735EC1F4B40
78083	1	12	1071	16269	38479	\N	54.117243999999999	Рязанская область, Михайловский район, с.Голдино, Школьная, 1, здание администрации		0101000020E6100000567DAEB6628B43407CD3F4D9010F4B40
78081	1	12	1071	16156	\N	\N	54.267136000000001	Рязанская область, Михайловский район, с.Виленка, здание сельского ДК	Россия, Рязанская область, Михайловский район, поселок Виленка	0101000020E61000004487C09140754340C9CA2F8331224B40
78091	1	12	1071	16674	\N	\N	54.180615000000003	Рязанская область, Михайловский район, д.Бычки, здание бывшей школы	Россия, Рязанская область, Михайловский район, поселок Бычки	0101000020E61000007E6E68CA4E63434062156F641E174B40
78042	1	12	759	14333	38754	\N	53.543930950251301	Рязанская область, Милославский район, п. Южный, Центральная, 5, администрация	Россия, Рязанская область, Милославский район, поселок Южный	0101000020E6100000A75D4C33DDB94340EA23F0879FC54A40
78051	1	12	759	14734	38473	\N	53.611789999999999	Рязанская область, Милославский район, с. Чернава, Ленина, 34, администрация		0101000020E6100000A779C7293A9243408A027D224FCE4A40
78056	1	12	759	15008	38469	\N	53.676729999999999	Рязанская область, Милославский район, п. Центральный, Мира, 6а, администация		0101000020E610000064ADA1D45ED043406D1CB1169FD64A40
78046	1	12	759	54683	38803	\N	53.742997264284497	Рязанская область, Милославский район, п. ст. Топилы, Центральная, 13а, здание ФАП	Россия, Рязанская область, Милославский район, поселок Топилы	0101000020E61000003B8DB454DEAA4340580394861ADF4A40
78021	1	12	759	13316	38567	\N	53.645881987082802	Рязанская область, Милославский район, с. Спасское, Новая, 30, администрация	Россия, Рязанская область, Милославский район, поселок Спасское	0101000020E6100000F015DD7A4DAF43409C89E942ACD24A40
78045	1	12	759	54652	38571	\N	53.689939151559599	"Рязанская область, Милославский район, п. с-за ""Большевик"", Центральная, 2 школа"	Россия, Рязанская область, Милославский район, поселок Совхоз Большевик	0101000020E61000008255F5F23B9F4340139ED0EB4FD84A40
78033	1	12	759	13859	38580	\N	53.679023000000001	Рязанская область, Милославский район, д. Роговое, Луговая, 1, медпункт		0101000020E61000009E78CE1610C84340AC1DC539EAD64A40
78044	1	12	759	14431	38753	\N	53.560198044049699	Рязанская область, Милославский район, п. Пролетарский, Новоселов, 2, администрация	Россия, Рязанская область, Милославский район, поселок Пролетарский	0101000020E6100000179F02603CA943406EA46C91B4C74A40
78052	1	12	759	14782	38722	\N	53.538767	Рязанская область, Милославский район, с. Потапово, Центральная, 4, администрация		0101000020E6100000CEA5B8AAEC8D4340FF942A51F6C44A40
78514	1	12	759	5341	38520	\N	53.683790999999999	Рязанская область, Скопинский район, поселок Поплевинский, Центральная, 20, ЖЭУ		0101000020E610000000AAB8718BC543404A26A77686D74A40
78049	1	12	759	54691	38814	\N	53.7342816352337	Рязанская область, Милославский район, с. Ново-Александрово, Центральная, 38, школа		0101000020E6100000E2EA0088BB9843404F05DCF3FCDD4A40
78043	1	12	759	14340	\N	\N	53.493493000000001	Рязанская область, Милославский район, с. Мураевня, Центральная, 13, администрация	Россия, Рязанская область, Милославский район, поселок Мураевня	0101000020E6100000EE940ED6FFBD434008E753C72ABF4A40
78034	1	12	759	13915	38570	\N	53.659184000000003	Рязанская область, Милославский район, п. Молодежный, Центральная, 4, администрация		0101000020E610000043E55FCB2BBF4340F3052D2460D44A40
78054	1	12	759	14911	\N	\N	53.580550000000002	Рязанская область, Милославский район, р.п. Милославское, Ленина, 11, здание ДК	Россия, Рязанская область, Милославский район, поселок Милославское	0101000020E6100000DBFB54151AB84340AED85F764FCA4A40
78055	1	12	759	14911	38252	\N	53.580550000000002	Рязанская область, Милославский район, р.п. Милославское, Центральная, 14а, здание КСЦ		0101000020E6100000DBFB54151AB84340AED85F764FCA4A40
78039	1	12	759	14157	38569	\N	53.698459	Рязанская область, Милославский район, с. Липяги, Поповка, 6, администрация		0101000020E6100000D2C77C40A0854340664CC11A67D94A40
78029	1	12	759	13679	38678	\N	53.635907000000003	Рязанская область, Милославский район, д. Казначеевка, Московская, 11, контора		0101000020E610000018265305A3BC434014268C6665D14A40
78053	1	12	759	14829	38755	\N	53.54072	Рязанская область, Милославский район, с. Змеевка, Центральная, 3, школа		0101000020E6100000EED11BEE239D434085251E5036C54A40
78031	1	12	759	13772	38713	\N	53.669753	Рязанская область, Милославский район, п. Зеленый, Вишневая, 22, администрация		0101000020E610000098DEFE5C34CC4340EEB25F77BAD54A40
78025	1	12	759	13493	38576	\N	53.564011999999998	Рязанская область, Милославский район, с. Дегтярка, Центральная, 15, школа		0101000020E610000008AC1C5A64C943409946938B31C84A40
78026	1	12	759	13582	38751	\N	53.603856999999998	Рязанская область, Милославский район, п. Горняк, Ленина, 1, администрация		0101000020E610000008E9297288BE4340F73AA92F4BCD4A40
78022	1	12	759	13354	38677	\N	53.640273999999998	Рязанская область, Милославский район, д. Воскресенское-1, Центральная, 36, медпункт		0101000020E610000018D1764CDDA94340533D997FF4D14A40
78036	1	12	759	14055	38628	\N	53.441910999999998	Рязанская область, Милославский район, с. Воейково, Центральная, 39, администрация		0101000020E61000003C6C2233179643400F5F268A90B84A40
78041	1	12	759	14255	38620	\N	53.666088000000002	Рязанская область, Милославский район, д. Бугровка, Молодежная, 44, дом культуры		0101000020E6100000BC7669C3618743400821205F42D54A40
78048	1	12	759	14621	38756	\N	53.711075000000001	Рязанская область, Милославский район, с. Боршевое, Центральная, 6, администрация		0101000020E610000083893F8A3A93434069006F8104DB4A40
78024	1	12	759	13486	38723	\N	53.590229999999998	Рязанская область, Милославский район,с. Большое Подовечье, Центральная, 4, администрация		0101000020E610000092770E65A8D643401D8F19A88CCB4A40
78019	1	12	759	13207	38634	\N	53.648195999999999	Рязанская область, Милославский район, с. Богородицкое, Школьная, 3, администрация		0101000020E610000058E1968FA49A4340F2B22616F8D24A40
78028	1	12	759	60465	75057	\N	53.641353018427303	Рязанская область, Милославский район, п. Арцыбашевской Шахты-3, Центральная, 28, клуб		0101000020E6100000E89FE06245C543408318E8DA17D24A40
78038	1	12	759	14146	38568	\N	53.423918	Рязанская область, Милославский район, с. Архангельское, Ерзикова, 20, дом культуры		0101000020E6100000629D2ADF33A44340C617EDF142B64A40
78018	1	12	1174	13206	38710	\N	53.862127000000001	Рязанская область, Кораблинский район, с.Яблонево, Молодежная, 2, здание школы		0101000020E610000012D9075916E24340D2FF722D5AEE4A40
78014	1	12	1174	13022	38719	\N	54.016385	Рязанская область, Кораблинский район, с.Юраково, Новая 26, здание администрации		0101000020E61000005EF415A419F943408E9257E718024B40
78012	1	12	1174	12928	38563	\N	53.957058000000004	Рязанская область, Кораблинский район, с.Чижово, Верхняя, 4, здание библиотеки		0101000020E610000060E7A6CD38DF4340063065E080FA4A40
77997	1	12	1174	12247	38560	\N	53.946953999999998	Рязанская область, Кораблинский район, п.Быковская Степь, Центральная, 27, здание объекта досуговой работы		0101000020E610000076FBAC32531A44407F68E6C935F94A40
78009	1	12	1174	12812	38561	\N	54.063685	Рязанская область, Кораблинский район, с.Семион, Набережная, 3, здание СДК		0101000020E610000056F0DB10E3134440751F80D426084B40
78008	1	12	1174	12726	38472	\N	54.059632000000001	Рязанская область, Кораблинский район, с.Пустотино, Школьная 2, здание школы		0101000020E6100000D05E7D3CF4274440C5E57805A2074B40
78005	1	12	1174	12589	38255	\N	53.937795999999999	Рязанская область, Кораблинский район, с.Пехлец, Центральная, 76, здание СДК		0101000020E610000012F92EA52E0D4440E92807B309F84A40
78003	1	12	1174	12497	38562	\N	54.077565	Рязанская область, Кораблинский район, с.Никитино, Новая, 10, здание школы		0101000020E6100000A7C98CB795044440392861A6ED094B40
78002	1	12	1174	12479	38476	\N	54.024853999999998	Рязанская область, Кораблинский район, с.Незнаново, Молодежная, 30, здание администрации		0101000020E61000002DEA93DC610D44405F96766A2E034B40
78000	1	12	1174	12392	38559	\N	53.953111	Рязанская область, Кораблинский район, д.Моловка, Новая 19 кв.2, здание ФАП		0101000020E61000008D63247B84EC43409B3A8F8AFFF94A40
78004	1	12	1174	22014	38564	\N	53.975292283790303	Рязанская область, Кораблинский район, с.Молвина Слобода, Кукуевская, 13, здание СДК	Россия, Рязанская область, Кораблинский район, поселок Молвина Слобода	0101000020E610000057B3CEF8BEF643407506465ED6FC4A40
78011	1	12	1174	12860	38566	\N	54.020183000000003	Рязанская область, Кораблинский район, с.Лесуново, Лесная, 2, здание СДК		0101000020E6100000118AADA069214440B477465B95024B40
77999	1	12	1174	12338	38565	\N	54.090389000000002	Рязанская область, Кораблинский район, с.Курбатово, Цветочная 1, здание библиотеки		0101000020E6100000F9F719170E1E44408675E3DD910B4B40
78349	1	12	1174	11153	\N	\N	53.922310000000003	Рязанская область, Рязанский район, с.Кораблино, здание основной школы	Россия, Рязанская область, Кораблинский район, Кораблино	0101000020E6100000293C6876DD0344400B630B410EF64A40
77980	1	12	1174	11153	37921	\N	53.930506613259702	Рязанская область, Кораблинский район, г. Кораблино, Школьная, д.18, здание школы им.И.В.Сарычева (школа развития)	Россия, Рязанская область, Кораблинский район, Кораблино	0101000020E6100000E1ECD632190444407BD976DA1AF74A40
77978	1	12	1174	11153	37921	\N	53.922310000000003	Рязанская область, Кораблинский район, г. Кораблино, Школьная, д.20, здание школы	Россия, Рязанская область, Кораблинский район, Кораблино	0101000020E6100000293C6876DD0344400B630B410EF64A40
77977	1	12	1174	11153	38197	\N	53.922310000000003	Рязанская область, Кораблинский район, г. Кораблино, Шахтерская, д.21, здание школы №2		0101000020E6100000293C6876DD0344400B630B410EF64A40
77976	1	12	1174	11153	38195	\N	53.922310000000003	Рязанская область, Кораблинский район, г. Кораблино, Маяковского, д.29, детская музыкальная школа		0101000020E6100000293C6876DD0344400B630B410EF64A40
77975	1	12	1174	11153	38195	\N	53.926606206473302	Рязанская область, Кораблинский район, г. Кораблино, Маяковского, д.30, дом культуры		0101000020E61000007573F1B73D054440812381069BF64A40
77982	1	12	1174	11153	38504	\N	53.923424586878198	"Рязанская область, Кораблинский район, г. Кораблино, Заводская, д.3, бывшее помещение магазина ООО ""Кораблинский завод модульных конструкций"""	Россия, Рязанская область, Кораблинский район, Кораблино	0101000020E61000007F2E1A321E03444087A757CA32F64A40
77979	1	12	1174	11338	38555	\N	53.857539000000003	Рязанская область, Кораблинский район, д.Ковалинка, Луговая, 8, здание школы №1		0101000020E6100000F8A41309A6024440B40584D6C3ED4A40
77994	1	12	1174	12099	38557	\N	53.893604000000003	Рязанская область, Кораблинский район, с.Княжое, микрорайон Каменный карьер, 8, здание объекта досуговой работы		0101000020E6100000A855F4876616444093C9A99D61F24A40
77996	1	12	1174	12159	38467	\N	53.981622999999999	Рязанская область, Кораблинский район, с.Ключ, Школьная 39, здание школы		0101000020E61000003C6BB75D681A44402E008DD2A5FD4A40
77991	1	12	1174	11900	38466	\N	53.875718501292901	Рязанская область, Кораблинский район, с. Кипчаково, Школьная, 26, здание администрации	Россия, Рязанская область, Кораблинский район, поселок Кипчаково	0101000020E61000004B033FAA611144402FBE688F17F04A40
77993	1	12	1174	12011	38558	\N	53.858266999999998	Рязанская область, Кораблинский район, п.Ибердский, переулок Центральный, 2 а, здание СДК		0101000020E610000064E94317D41D4440361E6CB1DBED4A40
77988	1	12	1174	11768	\N	\N	53.912871000000003	Рязанская область, Кораблинский район, с.Ерлино, Административный центр, 3, здание медпункта		0101000020E610000071CADC7C23DE4340C13BF9F4D8F44A40
78006	1	12	1174	54696	38827	\N	53.913992378228102	Рязанская область, Кораблинский район, п. Газопровод, Центральная, 14, здание СДК		0101000020E61000001E4E603AAD0D44401F679AB0FDF44A40
77986	1	12	1174	11672	38556	\N	53.839750000000002	Рязанская область, Кораблинский район, д.Великая Лука, Центральная, 39, здание школа-сад		0101000020E6100000C345EEE9EAEC4340736891ED7CEB4A40
77985	1	12	1174	11652	38470	\N	53.927072000000003	Рязанская область, Кораблинский район, д.Бобровинки, Братьев Лукьяновых, 43, здание СДК		0101000020E61000003354C554FAFD4340C784984BAAF64A40
78016	1	12	1174	13069	38631	\N	54.031770999999999	Рязанская область, Кораблинский район, с. Бестужево, Полевая, 4, здание СДК		0101000020E6100000026553AEF0EE434009FB761211044B40
77984	1	12	1174	11571	38554	\N	53.923864000000002	Рязанская область, Кораблинский район, с.Аманово, Новая, 23, здание СДК		0101000020E6100000ED815660C8EE4340D3F9F02C41F64A40
77989	1	12	1174	54687	38847	\N	53.998233345099003	Рязанская область, Кораблинский район, п.Проницы, Школьная, 10, здание объекта досуговой работы		0101000020E61000009B00C3F2E7014440DC645419C6FF4A40
77971	1	12	478	10979	\N	\N	55.161327	Рязанская область, Клепиковский район, д. Шопино, 45 ФАП		0101000020E610000022FC8BA0314344401C7BF65CA6944B40
77965	1	12	478	10686	\N	\N	55.125937	Рязанская область, Клепиковский район, д. Уткино, 1 Здание администрации с/п		0101000020E61000003A75E5B33C4544409D2D20B41E904B40
77953	1	12	478	10105	\N	\N	55.112757000000002	Рязанская область, Клепиковский район, с.Тюково, 7 Здание администрации с/п		0101000020E6100000AAEFFCA204FB434092B245D26E8E4B40
77948	1	12	478	9795	38507	\N	55.147571999999997	Рязанская область, Клепиковский район, р.п. Тума, Советская, 76 а (Средняя общеобразовательная школа №3)		0101000020E61000004D9EB29AAE45444014E7A8A3E3924B40
77950	1	12	478	9795	38056	\N	55.147571999999997	Рязанская область, Клепиковский район, р.п. Тума, Ленина, 18 (Музыкальная школа)		0101000020E61000004D9EB29AAE45444014E7A8A3E3924B40
77949	1	12	478	9795	38056	\N	55.147571999999997	Рязанская область, Клепиковский район, р.п. Тума, Ленина, 133 (Дворец детского творчества)		0101000020E61000004D9EB29AAE45444014E7A8A3E3924B40
77947	1	12	478	9795	38056	\N	55.147571999999997	Рязанская область, Клепиковский район, р.п. Тума, Ленина, 141 (Средняя общеобразовательная школа №46)		0101000020E61000004D9EB29AAE45444014E7A8A3E3924B40
77966	1	12	478	10744	\N	\N	55.109518000000001	Рязанская область, Клепиковский район, с. Спирино, 1 Здание администрации с/п		0101000020E6100000A933F790F03F4440632992AF048E4B40
77943	1	12	478	9580	38196	\N	55.137276231322502	Рязанская область, Клепиковский район, г. Спас-Клепики, Московская, 33 (Клепиковский технологический техникум)	Россия, Рязанская область, Клепиковский район, Спас-Клепики	0101000020E6100000E833A0DE8C1644404A438D4292914B40
77944	1	12	478	9580	37935	\N	55.132420406730901	Рязанская область, Клепиковский район, г. Спас-Клепики, Ленина, 88 (Средняя общеобразовательная школа №1)	Россия, Рязанская область, Клепиковский район, Спас-Клепики	0101000020E610000098DC28B2D61644400DAB7823F3904B40
77946	1	12	478	9580	38508	\N	55.134092352546702	Рязанская область, Клепиковский район, г. Спас-Клепики, Интернациональная, 26 (Дворец детского творчества)	Россия, Рязанская область, Клепиковский район, Спас-Клепики	0101000020E61000007364E597C1164440DF5339ED29914B40
77945	1	12	478	9580	38055	\N	55.127920556159097	Рязанская область, Клепиковский район, г. Спас-Клепики, Есенина, 8 (МКЦ)	Россия, Рязанская область, Клепиковский район, Спас-Клепики	0101000020E6100000D76D50FBAD1544405EBC1FB75F904B40
77956	1	12	478	10261	\N	\N	55.271667000000001	Рязанская область, Клепиковский район, д. Прудки, 43 Прудковское лесничество Национальный парк Мещерский		0101000020E6100000992A1895D41F44408333F8FBC5A24B40
77958	1	12	478	10346	\N	\N	55.120052999999999	Рязанская область, Клепиковский район, д. Первушкино, 13 Детский сад		0101000020E6100000AA7D3A1E33144440B2648EE55D8F4B40
77963	1	12	478	10599	\N	\N	55.149661000000002	Рязанская область, Клепиковский район, д. Оськино, 54 Здание Дома культуры		0101000020E61000003D65355D4F2A44404B3E761728934B40
77969	1	12	478	10920	\N	\N	55.014530000000001	Рязанская область, Клепиковский район, д. Норино, 2 Здание медпункта		0101000020E6100000FAEE5696E86E4440CB67791EDC814B40
77955	1	12	478	10197	\N	\N	55.168434941944703	Рязанская область, Клепиковский район, п. Ненашкино, 2 Здание администрации с/п	Россия, Рязанская область, Клепиковский район, поселок Ненашкино	0101000020E61000008CA37213B51244403A4030478F954B40
77973	1	12	478	11094	\N	\N	55.096028760662399	Рязанская область, Клепиковский район, д. Мягково, 30 Здание администрации с/п	Россия, Рязанская область, Клепиковский район, поселок Мягково	0101000020E61000006000E143897C4440DA3BA3AD4A8C4B40
77970	1	12	478	10924	38553	\N	55.167138000000001	Рязанская область, Клепиковский район, д. Молькино, 9 Дружбы		0101000020E61000008B709351654844409DF529C764954B40
77967	1	12	478	10787	\N	\N	54.997709	Рязанская область, Клепиковский район, с. Малахово, 122 Здание администрации с/п		0101000020E61000001A868F882961444062F6B2EDB47F4B40
77951	1	12	478	10007	38464	\N	54.951172	"Рязанская область, Клепиковский район, с. Криуша, 1 Мая, 1 ""А"" (Клуб)"		0101000020E610000063B7CF2A33FB43407A6F0C01C0794B40
77954	1	12	478	10188	\N	\N	55.177620384726097	Рязанская область, Клепиковский район, с. Колычево, 38 Здание администрации с/п	Россия, Рязанская область, Клепиковский район, поселок Колычево	0101000020E6100000DA03ADC090F14340C98E8D40BC964B40
77968	1	12	478	10872	\N	\N	54.990549999999999	Рязанская область, Клепиковский район, д. Колесниково, 63 Здание администрации		0101000020E6100000AAF1D24D626A4440C286A757CA7E4B40
77957	1	12	478	10183	\N	\N	55.134708000000003	Рязанская область, Клепиковский район, д. Калдево, 55 Здание сельского Дома культуры		0101000020E6100000B27F9E060C0E44403A419B1C3E914B40
77959	1	12	478	54690	38811	\N	55.0682049877271	Рязанская область, Клепиковский район, с. Задне-Пилево, Центральная 45 администрация	Россия, Рязанская область, Клепиковский район, поселок Заднепилево	0101000020E61000006A1492CCEA1744403B3602F1BA884B40
77960	1	12	478	10257	38100	\N	55.108773016873002	"Рязанская область, Клепиковский район, с. Екшур, Красный Октябрь, 1 ""А"" школа"	Россия, Рязанская область, Клепиковский район, поселок Екшур	0101000020E6100000BEC0AC50A41B44400AD80E46EC8D4B40
77974	1	12	478	11100	\N	\N	55.147567000000002	Рязанская область, Клепиковский район, с. Давыдово, 85 Здание сельского дома культуры		0101000020E610000030D978B0C5564440037CB779E3924B40
77964	1	12	478	10682	\N	\N	55.138848484707097	"Рязанская область, Клепиковский район, д. Гуреево, 13 здание МОУ ""Гуреевская начальная школа"""	Россия, Рязанская область, Клепиковский район, поселок Гуреево	0101000020E610000043AA285E65394440B98E71C5C5914B40
77962	1	12	478	10557	\N	\N	55.041750999999998	Рязанская область, Клепиковский район, с. Гришино, 49 Здание администрации с/п		0101000020E6100000B4C70BE9F0264440A3C9C51858854B40
77961	1	12	478	10503	\N	\N	55.082374000000002	"Рязанская область, Клепиковский район, с. Бусаево, 139 Здание МОУ ""Бусаевская начальная школа-детский сад"""		0101000020E6100000BDE47FF2773344403605323B8B8A4B40
77952	1	12	478	9944	37966	\N	55.054608999999999	Рязанская область, Клепиковский район, п. Болонь, Школьная, 5 (Средняя общеобразовательная школа)		0101000020E61000002BF86D88F10A44409C887E6DFD864B40
77972	1	12	478	11039	\N	\N	55.119197999999997	Рязанская область, Клепиковский район, с. Алексеево, 53 Здание администрации с/п		0101000020E6100000514EB4AB90724440D2DF4BE1418F4B40
77900	1	12	780	7628	\N	\N	54.809282000000003	Рязанская область, Касимовский район, с. Щербатовка, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Щербатовка	0101000020E610000068CEFA9463E04440E99E758D96674B40
77913	1	12	780	7025	\N	\N	54.737918000000001	Рязанская область, Касимовский район, с. Шостье, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Шостье	0101000020E6100000710168942EA744409B90D618745E4B40
77916	1	12	780	7072	\N	\N	55.143439999999998	Рязанская область, Касимовский район, д. Чаур, Здание ФАП	Россия, Рязанская область, Касимовский район, поселок Чаур	0101000020E6100000BAF770C9719544401878EE3D5C924B40
77911	1	12	780	8099	\N	\N	55.023805000000003	Рязанская область, Касимовский район, с. Торбаево, Здание Дома культуры	Россия, Рязанская область, Касимовский район, поселок Торбаево	0101000020E6100000EA758BC058BB44409B3DD00A0C834B40
77908	1	12	780	7962	\N	\N	54.83222	Рязанская область, Касимовский район, с. Токарево, Здание школы	Россия, Рязанская область, Касимовский район, поселок Токарево	0101000020E6100000CD237F30F0A04440DF89592F866A4B40
77903	1	12	780	7751	\N	\N	54.845735807753201	Рязанская область, Касимовский район, п. Ташенка, Здание Дома культуры	Россия, Рязанская область, Касимовский район, поселок Ташенка	0101000020E610000009C6C1A563B244406286C613416C4B40
77922	1	12	780	8651	38085	\N	55.002160000000003	Рязанская область, Касимовский район, р.п. Сынтул, Советская, 8, дом культуры		0101000020E6100000AA7EA5F3E1A5444000AE64C746804B40
77899	1	12	780	54671	\N	\N	54.823982961858803	Рязанская область, Касимовский район, п. Сосновка, Здание лесничества	Россия, Рязанская область, Касимовский район, поселок Сосновка	0101000020E61000004D4C1762F5D34440E0BA624678694B40
77912	1	12	780	8205	\N	\N	54.709335000000003	Рязанская область, Касимовский район, д. Сиверка, Здание ФАП	Россия, Рязанская область, Касимовский район, поселок Сиверка	0101000020E610000015E63DCE34B144403F74417DCB5A4B40
77901	1	12	780	7632	\N	\N	54.912936000000002	Рязанская область, Касимовский район, д. Селизово, Здание Дома культуры	Россия, Рязанская область, Касимовский район, поселок Селизово	0101000020E610000022DE3AFF76A74440A8AB3B16DB744B40
77897	1	12	780	7500	\N	\N	54.948566	Рязанская область, Касимовский район, с. Самылово, Здание школы	Россия, Рязанская область, Касимовский район, поселок Самылово	0101000020E6100000C9AB730CC8A244407C0C569C6A794B40
77907	1	12	780	7905	\N	\N	55.021354000000002	Рязанская область, Касимовский район, с. Савостьяново, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Савостьяново	0101000020E61000009FCC3FFA26D74440C4D155BABB824B40
77881	1	12	780	6740	\N	\N	54.929533999999997	Рязанская область, Касимовский район, с. Пустынь, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Пустынь	0101000020E6100000D53C47E4BBE04440914259F8FA764B40
77873	1	12	780	6289	\N	\N	54.892167000000001	Рязанская область, Касимовский район, д. Поповка, Здание ФАП	Россия, Рязанская область, Касимовский район, поселок Поповка	0101000020E6100000C619C39CA0B5444004C93B8732724B40
77910	1	12	780	8048	\N	\N	55.025951999999997	Рязанская область, Касимовский район, с. Подлипки, Здание Дома культуры	Россия, Рязанская область, Касимовский район, поселок Подлипки	0101000020E6100000A5F5B704E0C3444005A2276552834B40
77905	1	12	780	7811	\N	\N	55.007752000000004	Рязанская область, Касимовский район, с. Погост, Здание Дома культуры	Россия, Рязанская область, Касимовский район, поселок Погост	0101000020E6100000C8ED974F56944440433D7D04FE804B40
77904	1	12	780	7767	\N	\N	54.831561000000001	Рязанская область, Касимовский район, с. Перво, Здание администации	Россия, Рязанская область, Касимовский район, поселок Перво	0101000020E610000027DE019EB4B8444085D04197706A4B40
77877	1	12	780	5646	\N	\N	55.087052999999997	Рязанская область, Касимовский район, п. Озерный, Здание сельского клуба	Россия, Рязанская область, Касимовский район, поселок Озерный	0101000020E61000008BDEA9807BA8444064027E8D248B4B40
77898	1	12	780	54641	\N	\N	54.891967682335498	Рязанская область, Касимовский район, д. Новая Деревня, Здание школы	Россия, Рязанская область, Касимовский район, поселок Новая Деревня	0101000020E6100000FE8172DBBED544400D8AE6012C724B40
77906	1	12	780	7902	\N	\N	54.977815999999997	Рязанская область, Касимовский район, д. Мишуково, Здание ФАП	Россия, Рязанская область, Касимовский район, поселок Мишуково	0101000020E61000008B87F71C58DA4440B5C01E13297D4B40
77894	1	12	780	7369	\N	\N	54.926921999999998	Рязанская область, Касимовский район, с. Малеево, Здание ФАП	Россия, Рязанская область, Касимовский район, поселок Малеево	0101000020E610000070404B57B09D4440B1F84D61A5764B40
77889	1	12	780	7071	\N	\N	54.960270999999999	Рязанская область, Касимовский район, с. Любовниково, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Любовниково	0101000020E6100000D8D64FFF59D544400B26FE28EA7A4B40
77887	1	12	780	7018	\N	\N	54.797144000000003	Рязанская область, Касимовский район, с. Лубяники, Здание сельского клуба	Россия, Рязанская область, Касимовский район, поселок Лубяники	0101000020E6100000E4BA29E5B56A4440F01989D008664B40
77896	1	12	780	7423	\N	\N	54.957014000000001	Рязанская область, Касимовский район, д. Лощинино, Здание школы	Россия, Рязанская область, Касимовский район, поселок Лощинино	0101000020E610000000529B38B9A7444036E84B6F7F7A4B40
77921	1	12	780	8601	38194	\N	54.9293219860647	Рязанская область, Касимовский район, р.п. Лашма, Академика Уткина, 23, школа	Россия, Рязанская область, Касимовский район, поселок Лашма	0101000020E610000026A77686A991444006BAF605F4764B40
77891	1	12	780	7222	\N	\N	54.910114999999998	Рязанская область, Касимовский район, д. Крюково, Здание школы	Россия, Рязанская область, Касимовский район, поселок Крюково	0101000020E61000006F2F698CD6CF4440AD4CF8A57E744B40
77893	1	12	780	7231	\N	\N	54.905721	Рязанская область, Касимовский район, п. Крутоярский, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Крутоярский	0101000020E6100000C18D942D92A2444074266DAAEE734B40
77886	1	12	780	6942	\N	\N	54.834563000000003	Рязанская область, Касимовский район, д. Кочемары, Здание ФАП	Россия, Рязанская область, Касимовский район, поселок Кочемары	0101000020E61000005E4BC8073D7B4440D0B9DBF5D26A4B40
77890	1	12	780	7134	\N	\N	54.898390999999997	Рязанская область, Касимовский район, с. Которово, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Которово	0101000020E61000008E1EBFB7E9C94440A702EE79FE724B40
77909	1	12	780	8036	\N	\N	55.003776000000002	Рязанская область, Касимовский район, с. Кольдюки, Здание ФАП	Россия, Рязанская область, Касимовский район, поселок Кольдюки	0101000020E6100000847EA65EB7CC44403E4162BB7B804B40
77888	1	12	780	7065	\N	\N	55.000874000000003	Рязанская область, Касимовский район, д. Клетино, Здание Дома культуры	Россия, Рязанская область, Касимовский район, поселок Клетино	0101000020E6100000ADDF4C4C179A444057B5A4A31C804B40
77885	1	12	780	6883	\N	\N	54.863180999999997	Рязанская область, Касимовский район, с. Китово, Здание сельского клуба	Россия, Рязанская область, Касимовский район, поселок Китово	0101000020E61000001172DEFFC7754440A8C30AB77C6E4B40
77883	1	12	780	6807	\N	\N	54.902470000000001	Рязанская область, Касимовский район, с. Квасьево, Здание сельской библиотеки	Россия, Рязанская область, Касимовский район, поселок Квасьево	0101000020E6100000FDBFEAC891E0444081CF0F2384734B40
77884	1	12	780	6870	\N	\N	54.905740999999999	Рязанская область, Касимовский район, с. Ибердус, Здание школы	Россия, Рязанская область, Касимовский район, поселок Ибердус	0101000020E610000052D66F26A6854440BBD23252EF734B40
77882	1	12	780	6755	\N	\N	54.916257999999999	Рязанская область, Касимовский район, с. Ермолово, Здание администации	Россия, Рязанская область, Касимовский район, поселок Ермолово	0101000020E6100000EECD6F9868DA4440645930F147754B40
77918	1	12	780	7133	38192	\N	54.964793999999998	Рязанская область, Касимовский район, р.п. Елатьма, Янина, 3, дом культуры		0101000020E610000070067FBF98DF444042B0AA5E7E7B4B40
77917	1	12	780	7133	38182	\N	54.970027490168498	Рязанская область, Касимовский район, р.п. Елатьма, Луначарского, 48, школа	Россия, Рязанская область, Касимовский район, поселок Елатьма	0101000020E6100000F1475167EEDF4440569E40D8297C4B40
77879	1	12	780	6610	\N	\N	55.066730999999997	Рязанская область, Касимовский район, с. Дмитриево, Здание Дома культуры	Россия, Рязанская область, Касимовский район, поселок Дмитриево	0101000020E6100000A3E716BA12CB44408F5033A48A884B40
77880	1	12	780	6697	\N	\N	55.071834000000003	Рязанская область, Касимовский район, с. Данево, Здание сельского клуба	Россия, Рязанская область, Касимовский район, поселок Данево	0101000020E610000003B4AD669DC54440D55E44DB31894B40
77915	1	12	780	7067	38501	\N	55.058456	Рязанская область, Касимовский район, р.п. Гусь-Железный, Центральная, Здание фил-ла Районного ДДТ		0101000020E6100000A79201A08A934440A320787C7B874B40
77914	1	12	780	7067	38234	\N	55.058456	Рязанская область, Касимовский район, р.п. Гусь-Железный, Первомайская, Здание Районного ДДТ		0101000020E6100000A79201A08A934440A320787C7B874B40
77878	1	12	780	6550	\N	\N	54.967233	Рязанская область, Касимовский район, с. Гиблицы, Здание школы	Россия, Рязанская область, Касимовский район, поселок Гиблицы	0101000020E6100000726E13EE958B4440554E7B4ACE7B4B40
77876	1	12	780	6491	\N	\N	55.016759999999998	Рязанская область, Касимовский район, д. Булгаково, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Булгаково	0101000020E6100000172CD505BCAC4440C3F0113125824B40
77874	1	12	780	5492	\N	\N	54.767586000000001	Рязанская область, Касимовский район, с. Балушевы Починки, Здание сельского клуба	Россия, Рязанская область, Касимовский район, поселок Балушево-Починки	0101000020E610000089EDEE01BACF4440096F0F4240624B40
77872	1	12	780	6279	\N	\N	54.917307999999998	Рязанская область, Касимовский район, д. Ахматово, Здание администрации с/п	Россия, Рязанская область, Касимовский район, поселок Ахматово	0101000020E610000038876BB587C34440F92D3A596A754B40
77871	1	12	780	6183	\N	\N	55.063498000000003	Рязанская область, Касимовский район, с. Ардабьево, здание школы	Россия, Рязанская область, Касимовский район, поселок Ардабьево	0101000020E61000003F58C6866ED4444043AED4B320884B40
77875	1	12	780	6391	\N	\N	55.006208000000001	Рязанская область, Касимовский район, д. Алешино, Здание сельского клуба	Россия, Рязанская область, Касимовский район, поселок Алешино	0101000020E6100000581D39D219B244409E7C7A6CCB804B40
77853	1	12	725	5268	38585	\N	54.648817999999999	Рязанская область, Кадомский район, с.Четово, Центральная, 10, дом культуры		0101000020E610000061A92EE0653845402F87DD770C534B40
77855	1	12	725	5336	38586	\N	54.427143000000001	Рязанская область, Кадомский район, с. Чермные, Школьная, 2, ФАП		0101000020E6100000724F57772C3E454090DB2F9FAC364B40
77859	1	12	725	5591	\N	\N	54.579684	Рязанская область, Кадомский район, д. Сумерки, клуб		0101000020E6100000A5A31CCC264A4540DA01D715334A4B40
77854	1	12	725	5276	\N	\N	54.620021000000001	Рязанская область, Кадомский район, с. Старый Кадом, дом культуры		0101000020E61000002BFBAE08FE3B4540A7EA1ED95C4F4B40
77850	1	12	725	5109	38799	\N	54.619410999999999	Рязанская область, Кадомский район, с. Новоселки, Почтовая, 4, школа		0101000020E61000002C802903072445402EE411DC484F4B40
77851	1	12	725	5115	38798	\N	54.625771	Рязанская область, Кадомский район, с. Никиткино, Молодежная, 31, сельский дом культуры		0101000020E61000007DE6AC4F392A454082E49D4319504B40
77858	1	12	725	5496	38707	\N	54.605401000000001	Рязанская область, Кадомский район, д. Кущапино, Базарная, 4, администация		0101000020E610000072A609DB4F4245409CFBABC77D4D4B40
77861	1	12	725	5653	38709	\N	54.621006000000001	Рязанская область, Кадомский район, с. Кочемирово, Центральная, 21, клуб		0101000020E6100000DA588979564A4540554FE61F7D4F4B40
77856	1	12	725	5424	38622	\N	54.400672999999998	Рязанская область, Кадомский район, с. Котелино, Школьная, 6, администация		0101000020E6100000E561A1D634334540F2B1BB4049334B40
77867	1	12	725	5724	38500	\N	54.564433999999999	Рязанская область, Кадомский район, р.п. Кадом, Центральная, 31, дом культуры		0101000020E6100000359A5C8C813B45400F60915F3F484B40
77863	1	12	725	5724	38452	\N	54.564433999999999	Рязанская область, Кадомский район, р.п. Кадом, Первомайская, 2 Б, общежитие технологического техникума		0101000020E6100000359A5C8C813B45400F60915F3F484B40
77869	1	12	725	5724	38588	\N	54.564433999999999	Рязанская область, Кадомский район, р.п. Кадом, Московская, 31, школа		0101000020E6100000359A5C8C813B45400F60915F3F484B40
77866	1	12	725	5724	38455	\N	54.564433999999999	Рязанская область, Кадомский район, р.п. Кадом, Ленина, 8, здание начальной школы КСШ		0101000020E6100000359A5C8C813B45400F60915F3F484B40
77865	1	12	725	5724	38455	\N	54.564433999999999	Рязанская область, Кадомский район, р.п. Кадом, Ленина, 32 А, школа искусств		0101000020E6100000359A5C8C813B45400F60915F3F484B40
77864	1	12	725	5724	38455	\N	54.564433999999999	Рязанская область, Кадомский район, р.п. Кадом, Ленина, 34, дом культуры		0101000020E6100000359A5C8C813B45400F60915F3F484B40
77862	1	12	725	5724	38484	\N	54.564433999999999	Рязанская область, Кадомский район, р.п. Кадом, Касимовская, 4, дом детского творчества		0101000020E6100000359A5C8C813B45400F60915F3F484B40
77860	1	12	725	5650	38587	\N	54.664910999999996	Рязанская область, Кадомский район, д. Заулки, Школьная, 4, клуб		0101000020E6100000BEDA519CA34A454015E0BBCD1B554B40
77852	1	12	725	5214	38703	\N	54.6604490610504	Рязанская область, Кадомский район, с.Енкаево, Центральная, д.2, администация	Россия, Рязанская область, Кадомский район, поселок Енкаево	0101000020E610000081B3942C2737454084D6C39789544B40
77857	1	12	725	5434	38706	\N	54.393087999999999	Рязанская область, Кадомский район, п. Дарьино, Почтовая, 1/3, дом культуры		0101000020E61000007E37DDB2432E45409B3924B550324B40
77849	1	12	725	5053	38630	\N	54.577252000000001	Рязанская область, Кадомский район, с. Восход,  Почтовая, 1, сельский дом культуры		0101000020E6100000DA588979560E45407AC6BE64E3494B40
77829	1	12	401	3932	\N	\N	54.392926000000003	Рязанская область, Захаровский район, с. Федоровское, здание школы	Россия, Рязанская область, Захаровский район, поселок Федоровское	0101000020E61000007D073F7100BB4340C2DF2F664B324B40
77836	1	12	401	4311	\N	\N	54.432281000000003	Рязанская область, Захаровский район, с. Субботино, здание филиала ЗСОШ № 1	Россия, Рязанская область, Захаровский район, поселок Субботино	0101000020E6100000ACA8C1340C95434052D7DAFB54374B40
77844	1	12	401	4757	\N	\N	54.541688999999998	Рязанская область, Захаровский район, с. Старое Зимино, здание бывшей школы (сельская библиотека)	Россия, Рязанская область, Захаровский район, поселок Старое Зимино	0101000020E6100000A4A5F276849D43402DCDAD1056454B40
77847	1	12	401	54643	\N	\N	54.297584483292098	"Рязанская область, Захаровский район, пос. с-за ""Смена"", здание администрации сельского поселения"	Россия, Рязанская область, Захаровский район, поселок Совхоз Смена	0101000020E61000004FB2D5E594A443400CE8853B17264B40
77843	1	12	401	4753	\N	\N	54.477054000000003	Рязанская область, Захаровский район, д. Пупкино, здание медицинского пункта	Россия, Рязанская область, Захаровский район, поселок Пупкино	0101000020E61000006B662D05A4A743408736001B103D4B40
77833	1	12	401	4161	\N	\N	54.466292000000003	Рязанская область, Захаровский район, с. Поливаново, библиотека		0101000020E6100000C9AF1F62837543407731CD74AF3B4B40
77842	1	12	401	4689	\N	\N	54.462634000000001	Рязанская область, Захаровский район, с. Плахино, здание сельского Дома культуры	Россия, Рязанская область, Захаровский район, поселок Плахино	0101000020E61000004985B18520AB434043024697373B4B40
77835	1	12	401	4307	\N	\N	54.416854999999998	Рязанская область, Захаровский район, с. Остроухово, здание сельского Дома культуры	Россия, Рязанская область, Захаровский район, поселок Остроухово	0101000020E61000003A3C84F1D38A4340481630815B354B40
77831	1	12	401	4037	\N	\N	54.500275000000002	Рязанская область, Захаровский район, с. Осово, здание школы	Россия, Рязанская область, Захаровский район, поселок Осово	0101000020E61000004FAC53E57B6A4340D200DE0209404B40
77832	1	12	401	4101	\N	\N	54.516689	"Рязанская область, Захаровский район, с. Окуньково, здание конторы ООО ""Спартак"""	Россия, Рязанская область, Захаровский район, поселок Окуньково	0101000020E610000082E50819C8734340FA997ADD22424B40
77840	1	12	401	4533	\N	\N	54.371911122444303	Рязанская область, Захаровский район, с. Катагоща, ДК	Россия, Рязанская область, Захаровский район, поселок Катагоща	0101000020E61000004034F3E49A9E4340E60297C79A2F4B40
77838	1	12	401	4419	38237	\N	54.368473999999999	Рязанская область, Захаровский район, с. Захарово, ул. Школьная, д. 1 школа		0101000020E61000008E01D9EBDDA3434091B6F1272A2F4B40
77839	1	12	401	4419	38096	\N	54.368473999999999	Рязанская область, Захаровский район, с. Захарово, ул. Центральная, д. 190 ДК		0101000020E61000008E01D9EBDDA3434091B6F1272A2F4B40
77848	1	12	401	54681	\N	\N	54.328318932938899	Рязанская область, Захаровский район, с. Жокино, административное здание сельского поселения	Россия, Рязанская область, Захаровский район, поселок Жонино	0101000020E6100000126745D444994340E5D3635B062A4B40
77837	1	12	401	4367	\N	\N	54.409047999999999	Рязанская область, Захаровский район, с. Елино, здание школы	Россия, Рязанская область, Захаровский район, поселок Елино	0101000020E6100000DE59BBED42B14340423F53AF5B344B40
77834	1	12	401	4213	\N	\N	54.397030000000001	Рязанская область, Захаровский район, с. Добрые Пчелы, здание администрации сельского поселения	Россия, Рязанская область, Захаровский район, поселок Добрые Пчелы	0101000020E6100000E4F6CB272BA24340F4C308E1D1324B40
77830	1	12	401	3991	\N	\N	54.509669000000002	Рязанская область, Захаровский район, с. Большое Коровино, здание сельской администрации	Россия, Рязанская область, Захаровский район, поселок Большое Коровино	0101000020E6100000164ED2FC318343407C6473D53C414B40
77828	1	12	401	2112	\N	\N	54.436680000000003	Рязанская область, Захаровский район, д. Безлычное, здание школы	Россия, Рязанская область, Захаровский район, поселок Безлычное 3-е	0101000020E61000004DBC033C69BB43409D685721E5374B40
77845	1	12	401	4856	\N	\N	54.547224999999997	Рязанская область, Захаровский район, с. Альяшево, здание библиотеки	Россия, Рязанская область, Захаровский район, поселок Альяшево	0101000020E6100000FD169D2CB5A84340DC4603780B464B40
77827	1	12	388	3829	38682	\N	54.706817999999998	Рязанская область, Ермишинский район, с. Царево, Центральная, 20, здание Дома культуры		0101000020E6100000B5A7E49CD81B4540B01C2103795A4B40
77826	1	12	388	2004	38680	\N	54.716699646503699	Рязанская область, Ермишинский район, с. Турмадеево, Центральная, 62,  здание Дома культуры	Россия, Рязанская область, Ермишинский район, поселок Турмадеево	0101000020E610000022C32ADEC82E454088855AD3BC5B4B40
69791	1	11	\N	9161	7526	\N	52.949391433178498	Орловская область, город Орел, Циолковского переулок, 6	Россия, Орловская область, Орел, переулок Циолковского	0101000020E6100000848252B472054240F10EF0A485794A40
77825	1	12	388	3742	38676	\N	54.6153759805063	Рязанская область, Ермишинский район, с. Торопово, центральная, 24, здание Дома культуры	Россия, Рязанская область, Ермишинский район, поселок Торопово	0101000020E6100000DB6B41EF8D0D4540245F09A4C44E4B40
77824	1	12	388	54679	38800	\N	54.891350231609302	Рязанская область, Ермишинский район, с. Спасско-Раменье, Моложежная, 20,  здание бывшей администрации	Россия, Рязанская область, Ермишинский район, поселок Спас-Раменье	0101000020E6100000A19FA9D72D1E454012A5BDC117724B40
77823	1	12	388	3596	38574	\N	54.825586999999999	Рязанская область, Ермишинский район, с. Свестур, Свестурская, 30,  здание бывшей администрации		0101000020E610000041B96DDFA31445405A80B6D5AC694B40
77822	1	12	388	3603	38625	\N	54.703873000000002	Рязанская область, Ермишинский район, с. Савватьма, Центральная, 114, здание Дома культуры		0101000020E6100000D1CC936B0A164540CAC4AD82185A4B40
77821	1	12	388	3539	38624	\N	54.754089999999998	Рязанская область, Ермишинский район, с. Нарма, Центральная, 13, здание Дома культуры		0101000020E6100000BA68C87894004540CD1E680586604B40
77820	1	12	388	3484	38797	\N	54.744669000000002	Рязанская область, Ермишинский район, с. Надежка, Центральная, 79,здание Дома культуры		0101000020E6100000E65DF580792445402AAC5450515F4B40
77819	1	12	388	3425	38627	\N	54.867088000000003	Рязанская область, Ермишинский район, с. Мердушь, Поляна, 1, здание администрации		0101000020E61000002AE5B512BA254540856055BDFC6E4B40
77818	1	12	388	3378	38583	\N	54.764423000000001	Рязанская область, Ермишинский район, с. Кафтейка, Зеленая, 66, здание начальной школы		0101000020E610000096253ACB2C324540B5A7E49CD8614B40
77817	1	12	388	3320	38579	\N	54.813070000000003	Рязанская область, Ермишинский район, п. Игошино, Школьная, 15,  здание школы		0101000020E6100000BFB7E9CF7EF84440EBAD81AD12684B40
77814	1	12	388	3159	38262	\N	54.770235	Рязанская область, Ермишинский район, р.п. Ермишь, пл.Ленина, 62, здание ДЮСШ		0101000020E61000006FBC3B3256214540069E7B0F97624B40
77816	1	12	388	3159	38095	\N	54.770235	Рязанская область, Ермишинский район, р.п. Ермишь, Садовая, 40,здание Дома культуры		0101000020E61000006FBC3B3256214540069E7B0F97624B40
77815	1	12	388	3159	38259	\N	54.770235	Рязанская область, Ермишинский район, р.п. Ермишь, Московская, 63, здание администрации		0101000020E61000006FBC3B3256214540069E7B0F97624B40
77813	1	12	388	3089	38708	\N	54.722887999999998	Рязанская область, Ермишинский район, поселок Гремячий Ключ, Центальная, 4, здание Дома культуры		0101000020E61000009D9B36E334044540DE550F98875C4B40
77812	1	12	388	3029	38796	\N	54.727530999999999	Рязанская область, Ермишинский район, с. Власово, Солнечная, 4, здание Дома культуры		0101000020E610000079EBFCDB65154540C0E95DBC1F5D4B40
77811	1	12	388	2967	38575	\N	54.6459470958917	Рязанская область, Ермишинский район, с. Большое Ляхово, Молодежная, 1, здание Дома культуры	Россия, Рязанская область, Ермишинский район, поселок Большое Ляхово	0101000020E6100000C38366D7BD0D454083F92B64AE524B40
77810	1	12	388	2918	38465	\N	54.669504000000003	Рязанская область, Ермишинский район, с. Азеево, Советская, 14,здание администрации		0101000020E61000002E008DD2A503454046459C4EB2554B40
70187	1	11	\N	54364	\N	\N	52.801729000000002	с.Отрадинское, д.4		0101000020E6100000D7A3703D0A3742409DA04D0E9F664A40
70289	1	11	\N	54569	\N	\N	53.036807624691498	пос.Стальной Конь, Здание Булановского ФАП	Россия, Орловская область	0101000020E6100000D00F238447114240971DE21FB6844A40
70281	1	11	\N	54562	\N	\N	53.014156577079099	дер.Хардиково, Здание сельского дома культуры	Россия, Орловская область	0101000020E610000084BBB376DB154240360186E5CF814A40
70282	1	11	\N	39304	\N	\N	56.164416000000003	с.Старцево, Здание учебного корпуса ПЛ-22	Россия, Красноярский край, деревня Старцево	0101000020E6100000FBAE08FEB73E574036785F950B154C40
69832	1	11	\N	9161	7969	\N	52.989223000000003	Орловская область, город Орел, Цветаева, 42	Россия, Орловская область, Орел, улица Цветаева, 42	0101000020E6100000FF1F274C18074240BBB9F8DB9E7E4A40
69816	1	11	\N	9161	7824	\N	52.972279999999998	Орловская область, город Орел, Тургенева, 44	Россия, Орловская область, Орел, улица Тургенева, 44	0101000020E61000009692E524940642400647C9AB737C4A40
69767	1	11	\N	9161	7264	\N	53.008505999999997	г. Орел, Силикатная, 12	Россия, Орловская область, Орел, улица Силикатная, 12	0101000020E6100000FF25A94C310D4240EEE87FB916814A40
69824	1	11	\N	9161	7899	\N	52.981861000000002	Орловская область, город Орел, Пожарная, 52	Россия, Орловская область, Орел, улица Пожарная, 52	0101000020E610000090F8156BB80A4240E31B0A9FAD7D4A40
69831	1	11	\N	9161	7956	\N	52.987780999999998	Орловская область, город Орел, Матвеева, 12	Россия, Орловская область, Орел, улица Матвеева, 12	0101000020E6100000EB1B98DC280842401A4E999B6F7E4A40
69823	1	11	\N	9161	7781	\N	52.983102000000002	Орловская область, город Орел, Максима Горького, 93	Россия, Орловская область, Орел, улица Максима Горького, 93	0101000020E61000006ABC7493180A4240EC504D49D67D4A40
69796	1	11	\N	9161	7584	\N	52.940479000000003	Орловская область, город Орел, Латышских стрелков, 103	Россия, Орловская область, Орел, улица Латышских Стрелков, 103	0101000020E61000001975ADBD4F05424093C9A99D61784A40
69776	1	11	\N	9161	7363	\N	53.000242	г. Орел, Блынского, 6	Россия, Орловская область, Орел, улица Дмитрия Блынского, 6	0101000020E6100000AA7CCF4884104240F60A0BEE07804A40
69778	1	11	\N	9161	7376	\N	52.958881599810397	Орловская область, город Орел, Гагарина, 35А	Россия, Орловская область, Орел, улица Гагарина	0101000020E610000065DEAAEB500942408E5C37A5BC7A4A40
69760	1	11	\N	9161	7191	\N	52.972073999999999	город Орел, пер.Южный, 26	Россия, Орловская область, Орел, переулок Южный, 26	0101000020E6100000252367614F1142405DA5BBEB6C7C4A40
69759	1	11	\N	9161	7191	\N	52.972073999999999	город Орел, пер. Южный, 26	Россия, Орловская область, Орел, переулок Южный, 26	0101000020E6100000252367614F1142405DA5BBEB6C7C4A40
69786	1	11	\N	9161	7479	\N	52.953957000000003	Орловская область, город Орел, Соляной переулок, 2	Россия, Орловская область, Орел, переулок Соляной, 2	0101000020E61000002843554CA5074240286552431B7A4A40
70436	1	11	\N	9161	7369	\N	52.991943999999997	г. Орел, Артельный пер, 3	Россия, Орловская область, Орел, переулок Артельный, 3а	0101000020E6100000BC5D2F4D110E424051BB5F05F87E4A40
69749	1	11	\N	9161	7076	\N	52.962809999999998	город Орел, Набережная Дубровинского, 40	Россия, Орловская область, Орел, набережная Дубровинского, 40	0101000020E61000000F441669E20942408121AB5B3D7B4A40
70451	1	11	\N	9161	37919	\N	52.976775000000004	Орловская область, город Орел, Советский район, Генерала Родина, 69		0101000020E610000067F2CD3637044240744694F6067D4A40
69781	1	11	\N	9161	37910	\N	52.954109000000003	Орловская область, город Орел, Черкасская, 81		0101000020E6100000048F6FEF1A0A4240DEE8633E207A4A40
69780	1	11	\N	9161	37910	\N	52.955525000000002	Орловская область, город Орел, Черкасская, 74		0101000020E6100000D9942BBCCB09424055C1A8A44E7A4A40
69792	1	11	\N	9161	37999	\N	52.956822000000003	Орловская область, город Орел, Энгельса, 90		0101000020E61000006D1FF296AB054240F20BAF24797A4A40
69810	1	11	\N	9161	7747	\N	52.934004000000002	Орловская область, город Орел, Узловая, 5	Россия, Орловская область, Орел, Узловая улица, 3	0101000020E61000008B8A389D640B4240A62A6D718D774A40
69762	1	11	\N	9161	37925	\N	52.976546999999997	город Орел, Тульская, 63		0101000020E610000065FED13769104240E200FA7DFF7C4A40
70450	1	11	\N	9161	37894	\N	52.966233000000003	Орловская область, город Орел, Советский район, Трудовых резервов, 32		0101000020E610000016BF29AC5404424072A8DF85AD7B4A40
69837	1	11	\N	9161	37920	\N	52.966233000000003	Орловская область, город Орел, Трудовых резервов, 32		0101000020E610000016BF29AC5404424072A8DF85AD7B4A40
69752	1	11	\N	9161	37881	\N	52.964588999999997	город Орел, Студенческая, 2		0101000020E61000002F4E7CB5A30C4240698A00A7777B4A40
69755	1	11	\N	9161	36872	\N	52.968153000000001	город Орел, Старо-Привокзальная, 2		0101000020E61000005A492BBEA10A42401C430070EC7B4A40
70258	1	11	\N	9161	2572	\N	52.970371	пгт.Знаменка, Советская, 21	Россия, Орловская область, Орел, Советская улица, 17	0101000020E610000027DBC01DA809424050FEEE1D357C4A40
69743	1	11	\N	9161	37915	\N	52.971308999999998	город Орел, Советская, 29		0101000020E610000051853FC39B094240BDA772DA537C4A40
69766	1	11	\N	9161	37912	\N	53.006501	г. Орел, Силикатная, 22		0101000020E6100000A2D0B2EE1F0D424016325706D5804A40
69822	1	11	\N	9161	37930	\N	52.976112999999998	Орловская область, город Орел, Салтыкова-Щедрина, 41		0101000020E610000039D55A9885084240A8195245F17C4A40
69814	1	11	\N	9161	37930	\N	52.971141000000003	Орловская область, город Орел, Салтыкова-Щедрина, 31		0101000020E6100000481B47ACC5074240026729594E7C4A40
69774	1	11	\N	9161	7300	\N	53.014356999999997	г. Орел, Рошинская, 11А	Россия, Орловская область, Орел, Рощинская улица, 11а	0101000020E61000006F0ED76A0F134240FDBB3E73D6814A40
69772	1	11	\N	9161	37874	\N	53.018947317061603	г. Орел, Рощинская, 33	Россия, Орловская область, Орел, Рощинская улица	0101000020E61000009109F83592124240BCADF4DA6C824A40
69770	1	11	\N	9161	37874	\N	53.013993999999997	г. Орел, Рощинская, 3		0101000020E61000007632384A5E1342408C2B2E8ECA814A40
69745	1	11	\N	9161	37927	\N	52.971938000000002	город Орел, Революции, 4		0101000020E61000005839B4C8760A4240ADDEE176687C4A40
69748	1	11	\N	9161	37906	\N	52.967919000000002	город Орел, Пушкина, 80		0101000020E61000002A711DE38A0B4240A91611C5E47B4A40
69813	1	11	\N	9161	37880	\N	52.970694421655402	Орловская область, город Орел, Пролетарская гора, 7	Россия, Орловская область, Орел, улица Пролетарская гора	0101000020E6100000BE839F3880084240333674B33F7C4A40
69756	1	11	\N	9161	7162	\N	52.979284999999997	город Орел, Привокзальная площадь, 8		0101000020E6100000CD76853E580E42404F3BFC35597D4A40
69817	1	11	\N	9161	37911	\N	52.977643	Орловская область, город Орел, Полесская, 53		0101000020E6100000E12879758E054240E814E467237D4A40
69746	1	11	\N	9161	37908	\N	52.968727000000001	город Орел, Покровская, 8		0101000020E6100000A7E9B303AE09424048E00F3FFF7B4A40
69806	1	11	\N	9161	37917	\N	52.927072000000003	Орловская область, город Орел, Планерная, 55		0101000020E6100000533D997FF4014240C784984BAA764A40
69805	1	11	\N	9161	37917	\N	52.931235999999998	Орловская область, город Орел, Планерная, 35		0101000020E6100000CF2D742502034240CE6DC2BD32774A40
69820	1	11	\N	9161	37891	\N	52.976992000000003	Орловская область, город Орел, Пионерская, 8		0101000020E6100000382F4E7CB5074240113AE8120E7D4A40
69761	1	11	\N	9161	37883	\N	52.976866938412599	город Орел, Паровозная, Красный уголок локомотивного депо		0101000020E61000002BC3B81B440F424054C554FA097D4A40
69785	1	11	\N	9161	37870	\N	52.963585999999999	Панчука 85, МУП совхоз "комунальник"		0101000020E6100000ECA694D74A06424015713AC9567B4A40
69782	1	11	\N	9161	37870	\N	52.955077079972803	Орловская область, город Орел, Панчука, 1	Россия, Орловская область, Орел, улица Панчука	0101000020E610000033880FECF8074240B61490F63F7A4A40
69693	1	11	\N	9161	37901	\N	52.978786999999997	город Орел, Орджоникидзе, 3		0101000020E6100000D2C77C40A00D4240FE5F75E4487D4A40
69830	1	11	\N	9161	37890	\N	52.984143000000003	Орловская область, город Орел, Октябрьская, 65		0101000020E6100000286211C30E0942402ECBD765F87D4A40
69828	1	11	\N	9161	37890	\N	52.990653999999999	Орловская область, город Орел, Октябрьская, 209		0101000020E6100000111B2C9CA409424067D311C0CD7E4A40
69819	1	11	\N	9161	37890	\N	52.976655999999998	Орловская область, город Орел, Октябрьская, 44		0101000020E6100000E46A64575A08424099B85510037D4A40
69818	1	11	\N	9161	37890	\N	52.973981999999999	Орловская область, город Орел, Октябрьская, 35		0101000020E6100000EBC5504EB407424043723271AB7C4A40
69815	1	11	\N	9161	37890	\N	52.969096	Орловская область, город Орел, Октябрьская, 12		0101000020E610000033A83638110742409B5775560B7C4A40
69836	1	11	\N	9161	7980	\N	52.989635	Орловская область, город Орел, Наугорское шоссе, 29	Россия, Орловская область, Орел, Наугорское шоссе, 29	0101000020E6100000C03DCF9F360442400DFD135CAC7E4A40
69833	1	11	\N	9161	7980	\N	52.985872999999998	Орловская область, город Орел, Наугорское шоссе, 17	Россия, Орловская область, Орел, Наугорское шоссе, 17	0101000020E6100000AE8383BD8905424034812216317E4A40
70446	1	11	\N	9161	7375	\N	53.003098000000001	г. Орел, Московское шоссе, 137	Россия, Орловская область, Орел, Московское шоссе, 137	0101000020E610000003B4AD669D1142406D57E88365804A40
70478	1	11	\N	9161	37885	\N	53.0101770952256	г. Орел ул Металлургов 3а	Россия, Орловская область, Орел, улица Металлургов, 3	0101000020E610000008AEF204C2124240F015DD7A4D814A40
69773	1	11	\N	9161	37885	\N	53.01576	г. Орел, Металлургов, 42		0101000020E61000006B813D2652124240E04A766C04824A40
69768	1	11	\N	9161	37885	\N	53.013765999999997	г. Орел, Металлургов, 17		0101000020E610000021AF0793E2114240FBE59315C3814A40
69779	1	11	\N	9161	37899	\N	52.954684	Орловская область, город Орел, Маяковского, 55		0101000020E61000002E5393E00D094240DA01D715337A4A40
69804	1	11	\N	9161	37914	\N	52.925884000000003	Орловская область, город Орел, Машкарина, 12		0101000020E61000004A5F0839EF014240E1F1ED5D83764A40
69834	1	11	\N	9161	37932	\N	52.977919	Орловская область, город Орел, Матросова, 3	Россия, Орловская область, Орел, улица Матросова, 3	0101000020E61000005BCF108E590642408A9125732C7D4A40
69799	1	11	\N	9161	7637	\N	52.938948000000003	Орловская область, город Орел, Маслозаводской переулок, 2	Россия, Орловская область, Орел, Маслозаводской переулок, 2	0101000020E61000000798F90E7E0642408352B4722F784A40
69775	1	11	\N	9161	37887	\N	53.011344999999999	г. Орел, Маринченко, 25		0101000020E6100000ED6305BF0D1142408FFCC1C073814A40
69771	1	11	\N	9161	37887	\N	53.008045000000003	г. Орел, Маринченко, 9		0101000020E61000000AF5F411F8114240BBF2599E07814A40
69769	1	11	\N	9161	37887	\N	53.010288000000003	г. Орел, Маринченко, 10		0101000020E610000022E2E6543212424048C5FF1D51814A40
69827	1	11	\N	9161	37905	\N	52.988062999999997	Орловская область, город Орел, Максима Горького, 117		0101000020E6100000CA1B60E63B0A42409EB12FD9787E4A40
69826	1	11	\N	9161	37905	\N	52.969811141146799	Орловская область, город Орел, Максима Горького, 115	Россия, Орловская область, Орел, улица Максима Горького, 29	0101000020E6100000FCAA5CA8FC074240892650C4227C4A40
69812	1	11	\N	9161	37905	\N	52.968651999999999	Орловская область, город Орел, Максима Горького, 25		0101000020E61000002766BD18CA0742403D9AEAC9FC7B4A40
69789	1	11	\N	9161	37886	\N	52.950538999999999	Орловская область, город Орел, Мопра, 42		0101000020E61000006E15C440D706424049490F43AB794A40
69788	1	11	\N	9161	37886	\N	52.949491999999999	Орловская область, город Орел, Мопра, 24		0101000020E6100000460BD0B69A07424025E82FF488794A40
69764	1	11	\N	9161	37875	\N	52.997585999999998	город Орел, Льва Толстого, 6		0101000020E61000009A999999990B42404679E6E5B07F4A40
69765	1	11	\N	9161	37879	\N	52.954493999999997	город Орел, Ливенская, 15		0101000020E610000071AE6186C60D4240361D01DC2C7A4A40
69753	1	11	\N	9161	37923	\N	52.970767000000002	город Орел, Лесная, 9		0101000020E610000045679945280E42409D84D217427C4A40
69835	1	11	\N	9161	37896	\N	52.977148999999997	Орловская область, город Орел, Лескова, 15		0101000020E61000009F93DE37BE064240D828EB37137D4A40
69801	1	11	\N	9161	37888	\N	52.940446000000001	Орловская область, город Орел, Латышских стрелков, 105		0101000020E61000004015376E31054240B7D3D68860784A40
69795	1	11	\N	9161	37888	\N	52.942101999999998	Орловская область, город Орел, Латышских стрелков, 98		0101000020E61000002861A6ED5F05424083BF5FCC96784A40
69807	1	11	\N	9161	7722	\N	52.916257000000002	Орловская область, город Орел, Кромское шоссе, 29		0101000020E6100000D7BFEB336701424094DDCCE847754A40
69821	1	11	\N	9161	37904	\N	52.980401999999998	Орловская область, город Орел, Красноармейская, 17		0101000020E6100000D71533C2DB0742406C770FD07D7D4A40
70440	1	11	\N	9161	37876	\N	52.933	Орловская область, город Орел, Комсомольская, 320		0101000020E6100000397EA834620442408195438B6C774A40
69803	1	11	\N	9161	37876	\N	52.929009999999998	Орловская область, город Орел, Комсомольская, 374		0101000020E6100000D828EB371303424017D4B7CCE9764A40
69802	1	11	\N	9161	37876	\N	52.931077999999999	Орловская область, город Орел, Комсомольская, 261А		0101000020E6100000F3E2C4573B04424036035C902D774A40
69797	1	11	\N	9161	37876	\N	52.944419000000003	Орловская область, город Орел, Комсомольская, 182		0101000020E610000008E8BE9CD90642404B5CC7B8E2784A40
69790	1	11	\N	9161	37876	\N	52.945884	Орловская область, город Орел, Комсомольская, 170		0101000020E6100000D07EA4880C074240A3E716BA12794A40
69787	1	11	\N	9161	37876	\N	52.950870000000002	Орловская область, город Орел, Комсомольская, 95		0101000020E610000018D00B772E084240AF5FB01BB6794A40
69783	1	11	\N	9161	37876	\N	52.958177999999997	Орловская область, город Орел, Комсомольская, 39		0101000020E6100000802A6EDC6208424093DFA293A57A4A40
70452	1	11	\N	9161	37922	\N	52.993115000000003	Орловская область, город Орел, Советский район, Картукова, 8		0101000020E610000088BA0F406A05424062156F641E7F4A40
69794	1	11	\N	9161	7573	\N	52.947805000000002	Орловская область, город Орел, Карачевское шоссе, 86	Россия, Орловская область, Орел, Карачевское шоссе, 86	0101000020E61000000306499F560342401EFE9AAC51794A40
69798	1	11	\N	9161	7626	\N	52.943697	Орловская область, город Орел, Карачевский переулок, 6	Россия, Орловская область, Орел, Карачевский переулок, 6	0101000020E6100000D7BFEB3367074240AA2A3410CB784A40
69784	1	11	\N	9161	38000	\N	52.958877999999999	Орловская область, город Орел, Карачевская, 29		0101000020E6100000601F9DBAF20742404C6DA983BC7A4A40
69829	1	11	\N	9161	37903	\N	52.987623999999997	Орловская область, город Орел, Игнатова, 9		0101000020E6100000AD342905DD084240525F96766A7E4A40
69758	1	11	\N	9161	37852	\N	52.973169478272098	город Орел, Ем. Пугачева, 2а	Россия, Орловская область, Орел, улица Емельяна Пугачева, 2а	0101000020E61000006153E751F10B4240923D42CD907C4A40
69763	1	11	\N	9161	37926	\N	52.982613999999998	город Орел, Деповская, 6		0101000020E6100000793BC269C10F4240BE4BA94BC67D4A40
69754	1	11	\N	9161	37893	\N	52.973168999999999	город Орел, Грузовая, 1		0101000020E61000007C444C89240C4240923D42CD907C4A40
69809	1	11	\N	9161	37884	\N	52.941906000000003	Орловская область, город Орел, Городская, 64А,Б		0101000020E610000058207A5226094240FEF3346090784A40
69744	1	11	\N	9161	37916	\N	52.973461999999998	город Орел, Герцена, 19		0101000020E6100000297B4B395F0A42400AF31E679A7C4A40
69777	1	11	\N	9161	7368	\N	52.962333000000001	Орловская область, город Орел, Воскресенский переулок, 7	Россия, Орловская область, Орел, Воскресенский переулок, 7	0101000020E61000006EA7AD11C1084240486E4DBA2D7B4A40
69838	1	11	\N	9161	37929	\N	52.972231000000001	Орловская область, город Орел, Веселая, 28		0101000020E61000002F336C94F50342402594BE10727C4A40
69793	1	11	\N	9161	37918	\N	52.948700000000002	Орловская область, город Орел, Васильевская, 151		0101000020E61000005BB05417F00442408CDB68006F794A40
69800	1	11	\N	9161	37913	\N	52.933124999999997	Орловская область, город Орел, Автовокзальная, 34		0101000020E6100000B8E864A9F50442403D0AD7A370774A40
69751	1	11	\N	9161	37909	\N	52.946393999999998	город Орел, Абрамова-Соколова, 76		0101000020E6100000E3175E49F20C4240B890477023794A40
69811	1	11	\N	9161	37889	\N	52.934514	Орловская область, город Орел, 6-й Орловской дивизии, 25		0101000020E6100000CBDAA6785C0C4240BBD39D279E774A40
69825	1	11	\N	9161	37924	\N	52.986696999999999	Орловская область, город Орел, Полярная, 11		0101000020E6100000FF7A8505F7094240D90759164C7E4A40
70389	1	11	\N	9161	38175	\N	52.992550999999999	д. Студенка, ул. Молодежная, 7		0101000020E6100000AEF36F97FD0A4240594E42E90B7F4A40
69750	1	11	\N	9161	37907	\N	52.963118999999999	город Орел, 5 Августа, 25		0101000020E61000009AE95E27F50B4240FF93BF7B477B4A40
70249	1	11	\N	54594	\N	\N	53.012850850241499	дер.Нижняя Лужна, Здание сельского дома культуры	Россия, Орловская область	0101000020E61000006B7D91D0960B4240465C001AA5814A40
70261	1	11	\N	36621	8979	\N	54.615214999999999	пгт.Знаменка, Школьная, 8 (левое крыло)	Россия, республика Башкортостан, село Нижегородка, улица Школьная, 8	0101000020E61000006AC18BBE82EC4B401B81785DBF4E4B40
70259	1	11	\N	36621	8979	\N	54.615214999999999	пгт.Знаменка, Школьная, 8 (правое крыло)	Россия, республика Башкортостан, село Нижегородка, улица Школьная, 8	0101000020E61000006AC18BBE82EC4B401B81785DBF4E4B40
70106	1	11	\N	54574	\N	\N	52.442827999999999	пос. Нагорный, 20		0101000020E610000053245F09A4CA424065E08096AE384A40
69889	1	11	\N	1325	\N	\N	53.281453999999997	Орловская область, город Мценск, Автомагистраль, Отделение скорой медицинской помощ		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69885	1	11	\N	1325	\N	\N	53.281453999999997	"Орловская область, город Мценск, Микрорайон ""Коммаш"", школа №8"		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69884	1	11	\N	1325	36828	\N	53.281453999999997	Орловская область, город Мценск, Тургенева, 32		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69879	1	11	\N	1325	36828	\N	53.281453999999997	Орловская область, город Мценск, Тургенева, 196		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69878	1	11	\N	1325	36828	\N	53.281453999999997	Орловская область, город Мценск, Тургенева, 96		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69882	1	11	\N	1325	37944	\N	53.281453999999997	Орловская область, город Мценск, Рева, 32		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69876	1	11	\N	1325	36775	\N	53.281453999999997	Орловская область, город Мценск, Мира, 21		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69874	1	11	\N	1325	36775	\N	53.281453999999997	Орловская область, город Мценск, Мира, 35		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
70448	1	11	\N	1325	37862	\N	53.287523305764203	"Орловская область, город Мценск, Микрорайон ""Коммаш"", Клуб ОАО ""Коммаш"""	Россия, Орловская область, Мценск	0101000020E6100000EE3D5C72DC49424085ECBC8DCDA44A40
69883	1	11	\N	1325	37851	\N	53.281453999999997	"Орловская область, город Мценск, Микрорайон ""1"", 1"		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69888	1	11	\N	1325	36915	\N	53.281453999999997	Орловская область, город Мценск, Машиностроителей, 2		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69880	1	11	\N	1325	36820	\N	53.281453999999997	Орловская область, город Мценск, Ленина, 194		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69887	1	11	\N	1325	36882	\N	53.281453999999997	Орловская область, город Мценск, Кузьмина, 1/1		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69886	1	11	\N	1325	36882	\N	53.290197744883301	Орловская область, город Мценск, Кузьмина, 18	Россия, Орловская область, Мценск	0101000020E6100000F14BFDBCA94A4240ABAE433525A54A40
69890	1	11	\N	1325	37866	\N	53.292280604977897	Орловская область, город Мценск, Катукова, 1	Россия, Орловская область, Мценск	0101000020E61000005F5FEB52234C4240001FBC7669A54A40
69877	1	11	\N	1325	36773	\N	53.281453999999997	Орловская область, город Мценск, Карла Маркса, 45		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69875	1	11	\N	1325	36773	\N	53.281453999999997	Орловская область, город Мценск, Карла Маркса, 73		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
69881	1	11	\N	1325	36877	\N	53.281453999999997	Орловская область, город Мценск, Болховская, 60		0101000020E610000055BDFC4E9349424008AA46AF06A44A40
70160	1	11	\N	54560	37853	\N	52.400621999999998	город Малоархангельск, Советская, 25		0101000020E610000020D4450A653F42407007EA9447334A40
70159	1	11	\N	54560	37872	\N	52.404189060047301	город Малоархангельск, Ленина, 57	Россия, Орловская область, Малоархангельский район, Малоархангельск	0101000020E6100000E8F4BC1B0B40424094331477BC334A40
69873	1	11	\N	92	38130	\N	52.415342334642197	Орловская область, город Ливны, ул. Энергетиков, д. 1А		0101000020E610000053E751F17FCB4240DF5339ED29354A40
69848	1	11	\N	92	36901	\N	52.418805999999996	Орловская область, город Ливны, ул. Элеваторная, д. 1		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69849	1	11	\N	92	37863	\N	52.418805999999996	Орловская область, город Ливны, ул. Фрунзе, д. 11	Россия, Орловская область, Ливны	0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69851	1	11	\N	92	36736	\N	52.418805999999996	Орловская область, город Ливны, ул. Селитренникова, д. 5		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69857	1	11	\N	92	36857	\N	52.418805999999996	Орловская область, город Ливны, ул. Пушкина, д. 3		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69859	1	11	\N	92	37858	\N	52.418805999999996	Орловская область, город Ливны, пл. Октябрьская, д. 5		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69866	1	11	\N	92	36923	\N	52.418805999999996	Орловская область, город Ливны, ул. Октябрьская, д. 39		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69858	1	11	\N	92	36923	\N	52.409565834761302	Орловская область, город Ливны, ул. Октябрьская, д. 7А	Россия, Орловская область, Ливны	0101000020E6100000D55DD90583C94240DAC69FA86C344A40
70445	1	11	\N	92	36853	\N	52.418805999999996	Орловская область, город Ливны, ул. Московская, д. 111		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69846	1	11	\N	92	36853	\N	52.418805999999996	Орловская область, город Ливны, ул. Московская, д. 106 Б		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69871	1	11	\N	92	37849	\N	52.418805999999996	Орловская область, город Ливны, ул. Мира, д. 207А		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69868	1	11	\N	92	37849	\N	52.420747670287803	Орловская область, город Ливны, ул. Мира, д. 180А		0101000020E61000009C1551137DCC4240C0ED0912DB354A40
69865	1	11	\N	92	37849	\N	52.418805999999996	Орловская область, город Ливны, ул. Мира, д. 152 А		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69853	1	11	\N	92	36881	\N	52.424411186562502	Орловская область, город Ливны, ул. Максима Горького, д. 18	Россия, Орловская область, Ливны	0101000020E61000008AE76C01A1CD42400588821953364A40
69854	1	11	\N	92	36911	\N	52.418805999999996	Орловская область, город Ливны, ул. Ленина, д. 24		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69850	1	11	\N	92	36759	\N	52.418805999999996	Орловская область, город Ливны, ул. Кирова, д. 71		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69847	1	11	\N	92	36759	\N	52.418805999999996	Орловская область, город Ливны, ул. Кирова, д. 22		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69855	1	11	\N	92	36921	\N	52.418805999999996	Орловская область, город Ливны, ул. Карла Маркса, д. 120		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69852	1	11	\N	92	36837	\N	52.418805999999996	Орловская область, город Ливны, ул. Дзержинского, д. 112		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69867	1	11	\N	92	37854	\N	52.418805999999996	Орловская область, город Ливны, ул. Денисова, д. 30А		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69861	1	11	\N	92	37867	\N	52.418805999999996	Орловская область, город Ливны, ул. Гайдара, д. 5		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69860	1	11	\N	92	36861	\N	52.418805999999996	Орловская область, город Ливны, ул. Пухова, д. 28		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69872	1	11	\N	92	36735	\N	52.418805999999996	Орловская область, город Ливны, ул. Мира, д. 223А		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69870	1	11	\N	92	36735	\N	52.418805999999996	Орловская область, город Ливны, ул. Мира, д. 186		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69863	1	11	\N	92	36735	\N	52.418805999999996	Орловская область, город Ливны, ул. Мира, д. 138		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69856	1	11	\N	92	36817	\N	52.418805999999996	Орловская область, город Ливны, ул. Елецкая, д. 16 А		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69864	1	11	\N	92	36864	\N	52.418805999999996	Орловская область, город Ливны, ул. Гайдара, д. 8		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
69862	1	11	\N	92	36864	\N	52.418805999999996	Орловская область, город Ливны, ул. Гайдара, д. 1		0101000020E61000003D601E32E5CB42402DAF5C6F9B354A40
70272	1	11	\N	21308	\N	\N	52.942970000000003	пос.Куликовский, Здание сельского дома культуры	Россия, Орловская область, поселок Куликовский	0101000020E61000003B00E2AE5E114240F88DAF3DB3784A40
70292	1	11	\N	22250	\N	\N	53.002816000000003	дер.Жилина, Здание школы	Россия, Орловская область, деревня Жилина	0101000020E61000000553CDACA5084240E9F351465C804A40
70291	1	11	\N	22250	36961	\N	53.002816000000003	дер.Жилина, Строительная, 17 общественное помещение дома		0101000020E61000000553CDACA5084240E9F351465C804A40
70251	1	11	\N	60462	\N	\N	53.001434000000003	пос.Биофабрика, Здание культурно-спортивного центра		0101000020E6100000D9D0CDFE400B42401E8D43FD2E804A40
69936	1	11	2131	33719	\N	\N	52.095939000000001	"д. Капитановка, здание МОУ ""Нижне-Жерновская ср. общеобразовательная школа"""	Россия, Курская область, Щигровский район, поселок Капитановка	0101000020E61000006C088ECBB86D42409AB4A9BA470C4A40
70405	1	11	1822	27538	36841	\N	52.865516999999997	пос. Шаблыкино, ул. Советская, д. 20		0101000020E610000020B41EBE4C9C4140E690D442C96E4A40
70407	1	11	1822	27538	36897	\N	52.865516999999997	пос. Шаблыкино, ул. Ленина, д.2а		0101000020E610000020B41EBE4C9C4140E690D442C96E4A40
70406	1	11	1822	27538	36897	\N	52.865516999999997	пос. Шаблыкино, ул. Ленина, д.19		0101000020E610000020B41EBE4C9C4140E690D442C96E4A40
70415	1	11	1822	46037	37994	\N	52.908197999999999	с. Хотьково, ул. Тургенева, д.7	Россия, Орловская область, Шаблыкинский район, поселок Хотьково	0101000020E61000005DA5BBEB6CB04140742502D53F744A40
70418	1	11	1822	46105	38701	\N	52.765600999999997	с. Титово, ул. Центральная, д.1	Россия, Орловская область, Шаблыкинский район, поселок Титово	0101000020E61000005BEA20AF079741407764AC36FF614A40
70350	1	11	1822	49193	\N	\N	52.858843416203797	деревня Сомово, здание Сомовского СДК	Россия, Орловская область, Шаблыкинский район, поселок Сомово	0101000020E6100000A2B8E34D7E7D414003B34291EE6D4A40
70410	1	11	1822	49193	38191	\N	52.858635614740599	с. Сомово, ул. Комсомольская, д.2	Россия, Орловская область, Шаблыкинский район, поселок Сомово	0101000020E6100000EF3A1BF2CF7C41408995D1C8E76D4A40
70414	1	11	1822	27913	38077	\N	52.929439000000002	пос. Сельстрой, ул. Советская, д.5		0101000020E61000000A1346B3B2AD414040506EDBF7764A40
70411	1	11	1822	45945	\N	\N	52.849542	дер. Рядовичи, помещение Глыбоченского ФАПа, д.78а		0101000020E61000009468C9E3697341400A4AD1CABD6C4A40
70417	1	11	1822	28054	38150	\N	52.791705	с. Робье, пер. Почтовый, д.1		0101000020E61000007D789620239E4140338AE59656654A40
70413	1	11	1822	27872	\N	\N	52.934449000000001	с. Навля, помещение администрации Навлинского сельского поселения	Россия, Орловская область, Шаблыкинский район, поселок Навля	0101000020E610000072DF6A9DB8944140D4635B069C774A40
70416	1	11	1822	28018	38141	\N	52.868696999999997	с. Молодовое, ул. Садовая, д.4		0101000020E61000009161156F64A4414010919A76316F4A40
70409	1	11	1822	27703	38006	\N	52.853468999999997	дер. Косуличи, пер.Школьный, д.3	Россия, Орловская область, Шаблыкинский район, поселок Косуличи	0101000020E61000003DB9A640668541402D93E1783E6D4A40
70419	1	11	1822	46132	38005	\N	52.800820000000002	с. Герасимово, ул. Медведевка, д.1а		0101000020E6100000BF0B5BB3958F4140CAFD0E4581664A40
70408	1	11	1822	54637	38420	\N	52.847757999999999	с. Высокое, пер. Школьный, д.1	Россия, Орловская область, Шаблыкинский район, поселок Высокое	0101000020E6100000A27E17B6668D414010768A55836C4A40
70397	1	11	570	27121	37861	\N	53.129525999999998	пгт. Хотынец, ул.им. Пушкина, д.25		0101000020E61000009483D90418B24140A8FDD64E94904A40
70399	1	11	570	27121	37934	\N	53.129525999999998	пгт. Хотынец, ул.Школьная, д.1		0101000020E61000009483D90418B24140A8FDD64E94904A40
70398	1	11	570	27121	37933	\N	53.129525999999998	пгт. Хотынец, ул.Батова, д.47		0101000020E61000009483D90418B24140A8FDD64E94904A40
70201	1	11	1470	17600	36985	\N	52.488574999999997	с.Дросково, ул.Советская, 69		0101000020E610000010C99063EB894240545227A0893E4A40
70395	1	11	570	54578	38002	\N	53.201396123537499	д. Хотимль-Кузменковско, ул. Школьная, д.9	Россия, Орловская область, Хотынецкий район, поселок Хотимль Кузьменово	0101000020E61000004983DBDAC2A74140CAC51858C7994A40
70365	1	11	570	49390	38016	\N	53.163732446289501	с. Мощеное, ул. Школьная, д.6	Россия, Орловская область, Хотынецкий район, поселок Мощеное	0101000020E6100000F0DB10E335BB414083A7902BF5944A40
70391	1	11	570	45557	\N	\N	53.283683000000003	с. Льгов, Льговский сельский клуб		0101000020E610000056D4601A86B5414031B77BB94FA44A40
70394	1	11	570	60451	75031	\N	53.108953648532598	д. Кукуевка, ул. им. Ефимова, д.3	Россия, Орловская область, Хотынецкий район, поселок Кукуевка	0101000020E610000039268BFB8FB041405A626534F28D4A40
70392	1	11	570	26921	37975	\N	53.102065000000003	с. Красные Рябинки, ул. Школьная, д.9		0101000020E61000000932022A1CC541407B884677108D4A40
70240	1	11	570	47187	\N	\N	53.165807999999998	с.Клейменово, Здание сельского дома культуры		0101000020E6100000E04A766C04B0414024B5503239954A40
70393	1	11	570	45586	38003	\N	53.098106999999999	п. Звезда, ул. им. Алдобаева, д.7		0101000020E610000054C72AA567AA41401C412AC58E8C4A40
70396	1	11	570	27098	38036	\N	53.257058000000001	пос. Жудерский, ул. Школьная, д.6	Россия, Орловская область, Хотынецкий район, поселок Жудерский	0101000020E6100000E3512AE109A541406C96CB46E7A04A40
70385	1	11	570	45441	37989	\N	53.140994999999997	с. Воейково, ул. Молодежная, д.1		0101000020E6100000F2D1E28C61AE414023F3C81F0C924A40
69912	1	11	570	3545	36754	\N	53.3123335583185	п. Верховье, Привокзальная, 3	Россия, Орловская область, Хотынецкий район, поселок Верховье	0101000020E6100000A379008BFCA64140E5B67D8FFAA74A40
70387	1	11	570	54582	\N	\N	53.151036668727201	д. Большое Юрьево, МОУ - Юрьевская средняя общеобразовательная школа	Россия, Орловская область, Хотынецкий район, поселок Большое Юрьево	0101000020E610000087FD9E58A79E414034BE2F2E55934A40
70388	1	11	570	45489	\N	\N	53.058531000000002	с. Богородицкое, ул.Школьная, д.21	Россия, Орловская область, Хотынецкий район, поселок Богородицкое	0101000020E6100000211D1EC2F8AD4140AE669DF17D874A40
70386	1	11	570	26638	\N	\N	53.223328000000002	Орловская область, Хотынецкий район, Алехинское сельское поселение, д. Алехино, Алехинский сельский Дом культуры		0101000020E61000002541B8020A9D4140FB230C03969C4A40
70379	1	11	509	49594	38314	\N	52.904446	пос.Ясная Поляна, ул.Центральная, д.12		0101000020E61000004DBD6E1118E54140BF7FF3E2C4734A40
70412	1	11	509	60419	\N	\N	53.128004113318298	"с. Юшково, помещение конторы ООО ""Агротех-Юшково"""	Россия, Орловская область, Урицкий район, поселок Юшково	0101000020E610000037C5E3A25ADE4140EBE0606F62904A40
70366	1	11	509	25734	38018	\N	53.013198000000003	дер.Юшино, ул.Первомайская, д.6		0101000020E610000013EE9579ABCE4140B22FD978B0814A40
69905	1	11	509	3107	\N	\N	53.115417000000001	деревня Черногрязка	Россия, Орловская область, Урицкий район, поселок Черногрязка	0101000020E6100000DC4AAFCDC6D441408333F8FBC58E4A40
70348	1	11	509	49123	74977	\N	53.018136701110102	пос.Совхозный, ул.Советская, д.10	Россия, Орловская область, Урицкий район, поселок Совхозный	0101000020E61000001348895DDBD141407DEC2E5052824A40
70380	1	11	509	26355	38020	\N	52.826281999999999	дер.Себякино, ул.Молодежная, д.19		0101000020E61000002BC1E270E6DF414001A3CB9BC3694A40
70144	1	11	509	49519	\N	\N	52.858998	п. Прогресс, Здание Дома культуры		0101000020E6100000925B936E4BE041402AAA7EA5F36D4A40
70381	1	11	509	26374	37954	\N	53.054697143561803	с.Подзавалово, ул.Школьная, д.2	Россия, Орловская область, Урицкий район, поселок Подзавалово	0101000020E61000003D64CA87A0D641403B18B14F00874A40
70372	1	11	509	49484	38205	\N	53.160431929225901	с.Парамоново, ул.Д.Давыдова, д.23		0101000020E6100000A452EC681CDC4140AE9D280989944A40
70374	1	11	509	26081	38019	\N	52.937168	с.Муравлево, ул.Микрорайон Школьный, д.5		0101000020E61000002025766D6FBB4140CA6DFB1EF5774A40
70378	1	11	509	26260	38149	\N	52.93967	пос.Максимовский, ул.Школьная, д.6		0101000020E6100000C11DA8531EE941402384471B47784A40
70370	1	11	509	54668	38693	\N	52.877898999999999	дер.Лески, ул.Школьная, д.2	Россия, Орловская область, Урицкий район, поселок Лески	0101000020E6100000A9C0C93670CD4140761893FE5E704A40
70377	1	11	509	26197	37950	\N	52.957211999999998	дер.Ледно, ул.Молодежная, д.24а	Россия, Орловская область, Урицкий район, поселок Ледно	0101000020E6100000F69A1E1494E641405CAB3DEC857A4A40
70327	1	11	509	48817	\N	\N	52.991222999999998	д. Кошелево, Здание Кошелевской основной школы		0101000020E61000009ACDE33098D9414081053065E07E4A40
70373	1	11	509	49512	38137	\N	52.948081000000002	с.Городище, ул.Центральная, д.47	Россия, Орловская область, Урицкий район, поселок Городище	0101000020E6100000C4EDD0B018C94140C07ADCB75A794A40
70367	1	11	509	25795	38121	\N	52.981552000000001	пос.Бунинский, ул.Центральная, д.4		0101000020E610000055698B6B7CC2414065A9F57EA37D4A40
70371	1	11	509	49470	38148	\N	52.981698000000002	с.Бунино, ул.Державина, д.15		0101000020E6100000C040102043C341403946B247A87D4A40
70376	1	11	509	26177	38159	\N	53.034965999999997	дер.Большое Сотниково, ул.Победы, д.13		0101000020E6100000814067D2A6E84140683C11C479844A40
70357	1	11	1495	25297	\N	\N	52.323000999999998	деревня Чермошное, здание Чермошновского СДК		0101000020E61000008EAD6708C7E64140A3C9C51858294A40
70359	1	11	1495	49317	\N	\N	52.382441999999998	деревня Турейка, здание Турейского ФАПа	Россия, Орловская область, Троснянский район, поселок Турейка	0101000020E6100000B54E5C8E57FA4140F44E05DCF3304A40
70347	1	11	1495	54567	37953	\N	52.446736999999999	село Тросна, улица Московская, 31	Россия, Орловская область, Троснянский район, поселок Тросна	0101000020E610000027F8A6E9B3E34140E27492AD2E394A40
70351	1	11	1495	25019	\N	\N	52.491036999999999	Орловская обл. Троснянский р-н, д. Н. Муханово	Россия, Орловская область, Троснянский район, поселок Нижнее Муханово	0101000020E61000000D17B9A7ABE341401F10E84CDA3E4A40
70358	1	11	1495	25309	\N	\N	52.359490999999998	Орловская обл. Троснянский р-н, с. Муравль	Россия, Орловская область, Троснянский район, поселок Муравль	0101000020E610000072BF4351A0F14140691A14CD032E4A40
70332	1	11	1212	48913	\N	\N	52.648127000000002	с. Никольское, Здание Никольской средней школы		0101000020E610000091F3FE3F4E084240CA5356D3F5524A40
70353	1	11	1495	25121	\N	\N	52.499980000000001	Орловская обл. Троснянский р-н, с. Ломовец	Россия, Орловская область, Троснянский район, поселок Ломовец	0101000020E6100000C345EEE9EAD64140B9533A58FF3F4A40
70349	1	11	1495	24927	\N	\N	52.438557000000003	"деревня Ладарево, здание МОУ ""Троснянская средняя общеобразовательная школа"""	Россия, Орловская область, Троснянский район, поселок Ладарево	0101000020E6100000FB761211FED341404837C2A222384A40
70356	1	11	1495	49280	\N	\N	52.354320999999999	поселок Красноармейский, здание администрации Малахово-Слободского сельского поселени	Россия, Орловская область, Троснянский район, поселок Красноармейский	0101000020E6100000800D881057E841409CA4F9635A2D4A40
70361	1	11	1495	25465	\N	\N	52.311318999999997	деревня Красавка, здание Красавского СДК	Россия, Орловская область, Троснянский район, поселок Красавка	0101000020E61000001955867137004240CCCF0D4DD9274A40
70355	1	11	1495	25196	\N	\N	52.305014999999997	поселок Колычевский, здание Колычевского СК	Россия, Орловская область, Троснянский район, поселок Колычевский	0101000020E610000017BA1281EADB41400CE544BB0A274A40
70364	1	11	1495	25626	\N	\N	52.480612000000001	Орловская обл. Троснянский р-н, д. Каменец	Россия, Орловская область, Троснянский район, поселок Каменец	0101000020E610000097FE25A94CF741405708ABB1843D4A40
70352	1	11	1495	25070	\N	\N	52.509884999999997	"деревня Жизло-Павлово, здание МОУ ""Жерновецкая средняя общеобразовательная школа"""	Россия, Орловская область, Троснянский район, поселок Жизло-Павлово	0101000020E61000002254A9D903E9414048DC63E943414A40
70362	1	11	1495	25523	\N	\N	52.362482999999997	село Гнилец, здание Гнилецкого СК	Россия, Орловская область, Троснянский район, поселок Гнилец	0101000020E61000002C64AE0CAA014240902DCBD7652E4A40
70363	1	11	1495	49367	\N	\N	52.427455000000002	"село Воронец, здание МОУ ""Воронецкая средняя общеобразовательная школа"""	Россия, Орловская область, Троснянский район, поселок Воронец	0101000020E61000000E1478279FFE41407FC16ED8B6364A40
70196	1	11	1495	17353	\N	\N	52.340834673525798	д.Бобрик, здание Погореловского клуба	Россия, Орловская область, Троснянский район, поселок Бобрик	0101000020E61000007157AF22A3094240842A357BA02B4A40
70425	1	11	1493	60458	\N	\N	52.740436430128298	д. Хмелевая, Здание Чмелевского СК МУКТТ Алпеевское КДО	Россия, Орловская область, Сосковский район, поселок Хмелевая	0101000020E61000003E3DB665C0BB4140FA635A9BC65E4A40
70433	1	11	1493	46399	36965	\N	52.750936898819198	Сосковский   Советская 26, здание сельского поселения	Россия, Орловская область, Сосковский район, поселок Сосково	0101000020E610000099D711876CB041409D2D20B41E604A40
70432	1	11	1493	46399	36965	\N	52.748821	с. Сосково, ул.Советская, 29		0101000020E61000009FAF592E1BB141406DC7D45DD95F4A40
70431	1	11	1493	46399	38078	\N	52.748821	с. Сосково, ул. Ленина, 18		0101000020E61000009FAF592E1BB141406DC7D45DD95F4A40
70421	1	11	1493	28241	\N	\N	52.849030999999997	д. Сковородовка, д 46		0101000020E6100000CC63CDC820C1414024253D0CAD6C4A40
70428	1	11	1493	28552	\N	\N	52.618242000000002	с. Новогнездилово, Здание администрации Кировского сельского поселения	Россия, Орловская область, Сосковский район, поселок Новогнездилово	0101000020E61000004084B872F6B44140BF81C98D224F4A40
70434	1	11	1493	28799	\N	\N	52.790806000000003	с. Мыцкое, Здание МУККТ Мыцковское КДО	Россия, Орловская область, Сосковский район, поселок Мыцкое	0101000020E61000007445292158AB414084BD892139654A40
70426	1	11	1493	17299	\N	\N	52.696672	д. Мураевка, Здание Мураевского СК МУКТТ Мураевское КДО	Россия, Орловская область, Сосковский район, поселок Мураевка	0101000020E6100000E563778192C24140FB04508C2C594A40
70427	1	11	1493	28502	\N	\N	52.669167999999999	Орловская область, Сосковский район,с. Кирово, Здание Кировского СК МУККТ Кировское КДО	Россия, Орловская область, Сосковский район, поселок Кирово	0101000020E6100000F2CF0CE203B74140CEC3094CA7554A40
70423	1	11	1493	54605	\N	\N	52.800520169211701	с.Гнилое Болото	Россия, Орловская область, Сосковский район, поселок Гнилое Болото	0101000020E6100000E884D04197B841409FE5797077664A40
70429	1	11	1493	46355	\N	\N	52.636619000000003	д. Волчьи Ямы, Здание Лебяженского  СК МУККТ Кировское КДО	Россия, Орловская область, Сосковский район, поселок Волчьи Ямы	0101000020E610000044DC9C4A06AE414091813CBB7C514A40
70420	1	11	1493	46137	\N	\N	52.824997000000003	с. Алмазово, Алмазовское сельское поселение	Россия, Орловская область, Сосковский район, поселок Алмазово	0101000020E6100000ADA7565F5DCD414029266F8099694A40
70337	1	11	1212	24344	\N	\N	52.779701000000003	д. Хотетово, Здание Хотетовской основной школы		0101000020E6100000D2FF722D5A2642404AD40B3ECD634A40
70278	1	11	1212	45523	\N	\N	52.673603	с.Троицкое, Здание сельского дома культуры		0101000020E61000009946938B3116424066BE839F38564A40
70307	1	11	1212	40293	9737	\N	52.619551152033402	с.Столбецкое, ул.Школьная, 23	Россия, Орловская область, Свердловский район, поселок Столбецкое	0101000020E61000002EC55565DF4B4240209A79724D4F4A40
70344	1	11	1212	49113	\N	\N	52.623386000000004	д. Степановка, Здание Степановской сельской библиотеки		0101000020E6100000DB32E02C253F42406364C91CCB4F4A40
70444	1	11	1212	29243	\N	\N	52.695286000000003	д. Разбегаевка, Здание дорожного участка	Россия, Орловская область, Свердловский район, поселок Разбегаевка	0101000020E61000006E6C76A4FA304240EFAEB321FF584A40
70339	1	11	1212	49026	\N	\N	52.747709	д. Новопетровка, Здание Новопетровской средней школы	Россия, Орловская область, Свердловский район, поселок Новопетровка	0101000020E6100000DB8AFD65F736424062F6B2EDB45F4A40
70360	1	11	1212	48913	\N	\N	52.660260241829299	село Никольское, здание Никольского СДК	Россия, Орловская область, Свердловский район, поселок Никольское	0101000020E61000006C94F59B89094240B16D516683544A40
70326	1	11	1212	23796	\N	\N	52.654263	д. Нахлестово, Здание Нахлестовского сельского Дома Культуры	Россия, Орловская область, Свердловский район, поселок Нахлестово	0101000020E61000003C16DBA4A22D4240CEFDD5E3BE534A40
70082	1	11	1212	11892	\N	\N	52.678899000000001	пос.Морозовский, здание Федотовского социального центра		0101000020E61000009C6C0377A0324240C0249529E6564A40
70194	1	11	1212	46230	\N	\N	52.670119	п. Михайловка, здание Мансуровской школы		0101000020E610000098309A95ED4B4240D0B69A75C6554A40
70346	1	11	1212	49137	\N	\N	52.576121999999998	п. Куракинский, Здание Куракинской средней школы	Россия, Орловская область, Свердловский район, поселок Куракинский	0101000020E61000003750E09D7C3C4240C8409E5DBE494A40
70329	1	11	1212	23942	\N	\N	52.582037965472502	д. Красная Рыбница, Здание Краснорыбницкого сельского Дома культуры	Россия, Орловская область, Свердловский район, поселок Красная Рыбница	0101000020E61000000BF148BC3C214240BE839F38804A4A40
70325	1	11	1212	48788	\N	\N	52.662489000000001	д. Котовка, Здание Котовского сельского Дома культуры		0101000020E6100000DA39CD02ED324240D97A8670CC544A40
70328	1	11	1212	23915	\N	\N	52.648690000000002	с. Козьминское, Здание Козьминской основной школы	Россия, Орловская область, Свердловский район, поселок Козьминское	0101000020E610000001A1F5F065164240029F1F4608534A40
69903	1	11	1212	49355	\N	\N	52.593187999999998	деревня Знаменское	Россия, Орловская область, Свердловский район, поселок Знаменское	0101000020E61000008CF7E3F6CB05424098309A95ED4B4A40
70334	1	11	1212	24223	\N	\N	52.732612000000003	Орловская обл, Свердловский р-н, с Змиево, Кимовский СК		0101000020E61000008237A451811342401E54E23AC65D4A40
70443	1	11	1212	23615	36967	\N	52.668954999999997	п. Змиевка, Школьная, 5		0101000020E610000036E49F19C42F424072BF4351A0554A40
70324	1	11	1212	23615	37860	\N	52.668954999999997	п. Змиевка, Чкалова, 12		0101000020E610000036E49F19C42F424072BF4351A0554A40
70323	1	11	1212	23615	36963	\N	52.668954999999997	п. Змиевка, Садовая, 45		0101000020E610000036E49F19C42F424072BF4351A0554A40
70322	1	11	1212	23615	36744	\N	52.668954999999997	п. Змиевка, Ленина, 25		0101000020E610000036E49F19C42F424072BF4351A0554A40
70336	1	11	1212	24308	\N	\N	52.749617000000001	д. Еропкино-Большак, Здание Еропкинской начальной школы	Россия, Орловская область, Свердловский район, поселок Еропкино-Большак	0101000020E6100000A164726A6726424048C32973F35F4A40
70338	1	11	1212	24403	\N	\N	52.759869000000002	д. Гостиново, Здание Гостиновского сельского Дома Культуры	Россия, Орловская область, Свердловский район, поселок Гостиново	0101000020E61000005C8DEC4ACB2A4240431F2C6343614A40
70345	1	11	1212	24770	\N	\N	52.576833999999998	д. Борисоглебское, Здание Борисоглебской основной школы	Россия, Орловская область, Свердловский район, поселок Борисоглебское	0101000020E61000000685419946314240459C4EB2D5494A40
70343	1	11	1212	24681	\N	\N	52.686788	д. Богодухово, Здание Богодуховского сельского Дома культуры	Россия, Орловская область, Свердловский район, поселок Богодухово	0101000020E6100000D8666325E641424083A44FABE8574A40
70314	1	11	1470	23255	38157	\N	52.529201	д.Шалимовка, ул.Центральная, 24		0101000020E6100000A0FD4811199442405801BEDBBC434A40
70300	1	11	1470	48359	38179	\N	52.590065000000003	д.Хаустово, ул.Центральная, 12		0101000020E6100000C66F0A2B157A4240D3C1FA3F874B4A40
70306	1	11	1470	54654	38584	\N	52.525066649864698	с.Федоровка, ул.Центральная, 16	Россия, Орловская область, Покровский район, поселок Федоровка	0101000020E610000016359886E1634240BB9A3C6535434A40
70305	1	11	1470	49166	38082	\N	52.702673135027801	с.Успенское, ул.Овалова, 10	Россия, Орловская область, Покровский район, поселок Успенское	0101000020E6100000B98D06F0166842401F645930F1594A40
70118	1	11	1470	49166	36888	\N	52.702986000000003	с. Успенское, Мира, 8а		0101000020E61000006B65C22FF5674240DFC5FB71FB594A40
69930	1	11	1470	60418	\N	\N	52.578655188961903	"с. Троицкое, здание МОУ ""Троицкая средняя общеобразовательная школа"""	Россия, Орловская область, Покровский район, поселок Троицкое	0101000020E610000041D7BE805E5842405C55F65D114A4A40
70319	1	11	1470	54658	38602	\N	52.403247999999998	с.Топки, ул.Центральная, 5	Россия, Орловская область, Покровский район, поселок Топки	0101000020E610000040C1C58A1A6E4240B51666A19D334A40
70308	1	11	1470	48488	38619	\N	52.619548999999999	д.Тимирязево, ул.Школьная, 6	Россия, Орловская область, Покровский район, поселок Тимирязево	0101000020E6100000E1ED4108C85942407FA2B2614D4F4A40
70299	1	11	1470	48329	38116	\N	52.637991	д.Тетерье, ул.Центральная, 22		0101000020E61000003CBD5296216E4240381268B0A9514A40
70320	1	11	1470	23507	38146	\N	52.425434000000003	с.Смирные, ул.Центральная, 6		0101000020E61000006E5166834C7A4240A14D0E9F74364A40
70312	1	11	1470	54617	38169	\N	52.482823927988903	д.Сетенёво, ул.Центральная, 42	Россия, Орловская область, Покровский район, поселок Сетенева	0101000020E6100000A089B0E1E98F4240A9DC442DCD3D4A40
70304	1	11	1470	54640	38427	\N	52.675578999999999	д.Протасово, ул.Заречная, 14	Россия, Орловская область, Покровский район, поселок Протасово	0101000020E6100000D2FE0758AB744240A46E675F79564A40
70295	1	11	1470	54566	37979	\N	52.607306000000001	поселок Покровское, ул.Советская, 14	Россия, Орловская область, Покровский район, поселок Покровское	0101000020E61000007F85CC95416D42401155F833BC4D4A40
70294	1	11	1470	54566	37947	\N	52.607306000000001	поселок Покровское, ул.50 лет Октября, 4	Россия, Орловская область, Покровский район, поселок Покровское	0101000020E61000007F85CC95416D42401155F833BC4D4A40
70310	1	11	1470	48525	38118	\N	52.6771577782715	д.Озерное, ул.Центральная, 5	Россия, Орловская область, Покровский район, поселок Озерное	0101000020E6100000F435CB65A3574240C51C041DAD564A40
70303	1	11	1470	22770	38120	\N	52.661183999999999	д.Нижний Туровец, ул.Советская, 1		0101000020E6100000C095ECD808844240B95164ADA1544A40
70297	1	11	1470	48302	38074	\N	52.554170999999997	д.Малая Казинка, ул.Центральная, 23		0101000020E6100000D2A92B9FE571424020B24813EF464A40
70439	1	11	1470	46567	38117	\N	52.613463000000003	пос. Дубки, Рабочая, 10		0101000020E6100000456458C51B4F42402D27A1F4854E4A40
70298	1	11	1470	54628	38276	\N	52.630907999999998	д.Даниловка, ул.Административная, 2	Россия, Орловская область, Покровский район, поселок Даниловка	0101000020E610000036AFEAAC166442407364E597C1504A40
70313	1	11	1470	40410	38147	\N	52.437328000000001	д.Внуково, ул.Школьная, 13		0101000020E6100000EA20AF079392424003D0285DFA374A40
70321	1	11	1470	54612	38160	\N	52.449006599360501	с.Верхососенье Первая Середина, ул.Алферьева, 24	Россия, Орловская область, Покровский район, поселок Верхососенье Средина 1-я	0101000020E61000009DA1B8E34D6642406956B60F79394A40
70315	1	11	1470	23311	38034	\N	52.534723999999997	д.Вепринец, ул.Цветочная, 22		0101000020E6100000CF31207BBD894240723106D671444A40
70309	1	11	1470	54632	38297	\N	52.576138999999998	с.Алексеевка, ул.Центральная, 28	Россия, Орловская область, Покровский район, поселок Алексеевка	0101000020E6100000DFE2E13D075042409E7939ECBE494A40
69901	1	11	1598	49336	\N	\N	53.175902000000001	село Щербово	Россия, Орловская область, Орловский район, поселок Щербово	0101000020E6100000657094BC3AF1414087A6ECF483964A40
70253	1	11	1598	47472	\N	\N	52.984668999999997	пос.Шиловский, Здание культурно-оздоровительного центра	Россия, Орловская область, Орловский район, поселок Шиловский	0101000020E61000001C5E10919AFC4140483140A2097E4A40
70287	1	11	1598	22059	\N	\N	53.124786999999998	дер.Шепино, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Шепино	0101000020E610000020B41EBE4C244240A4FB3905F98F4A40
70257	1	11	1598	20572	\N	\N	52.892249999999997	дер.Усть-Рыбница, Здание медпункта	Россия, Орловская область, Орловский район, поселок Усть-Рыбница	0101000020E6100000B81FF0C00004424091ED7C3F35724A40
70244	1	11	1598	47286	\N	\N	53.051656999999999	дер.Тайное, Здание Тайнинского ФАП	Россия, Орловская область, Орловский район, поселок Тайное	0101000020E6100000C153C8957A10424003CE52B29C864A40
70274	1	11	1598	54585	\N	\N	52.959079425551302	дер.Ступишино, Здание школы	Россия, Орловская область, Орловский район, поселок Ступишено	0101000020E61000006D74CE4F71244240E4A3C519C37A4A40
70246	1	11	1598	47316	\N	\N	53.010103999999998	пос.Стрелецкий, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Стрелецкий	0101000020E61000002B6D718DCFFC414086C77E164B814A40
70268	1	11	1598	21106	\N	\N	52.827364000000003	с.Становой Колодезь, Здание школы	Россия, Орловская область, Орловский район, поселок Становой Колодезь	0101000020E6100000329067976F1F4240A2F14410E7694A40
70267	1	11	1598	21106	\N	\N	52.827364000000003	с.Становой Колодезь, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Становой Колодезь	0101000020E6100000329067976F1F4240A2F14410E7694A40
70266	1	11	1598	21029	\N	\N	52.761637805678902	с.Путимец, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Путимец	0101000020E6100000677E3507080A424007B29E5A7D614A40
70276	1	11	1598	54571	\N	\N	53.001745866663597	дер.Пугачевка, Здание школы	Россия, Орловская область, Орел, улица Раздольная	0101000020E6100000809C3061340B42400C73823639804A40
70238	1	11	1598	19504	\N	\N	53.206051000000002	дер.Полозовские Дворы, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Полозовские Дворы	0101000020E6100000AF433525590B4240702711E15F9A4A40
70290	1	11	1598	48163	\N	\N	53.027124000000001	с.Плещеево, Здание лицея	Россия, Орловская область, Орловский район, поселок Плещеево	0101000020E6100000E202D0285D0A4240E6779ACC78834A40
70242	1	11	1598	19679	\N	\N	53.1719733059116	с.Паюсово, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Паюсово	0101000020E6100000B34291EEE7FE4140C365153603964A40
69980	1	11	1598	54590	\N	\N	53.030851619458801	Орловская область, Должанский район, Кудиновское сельское поселение, д.Новотроицкое, помещение Кудиновского филиала Никольской средней общеобразовательной школы	Россия, Орловская область, Орловский район, поселок Новотроицкое	0101000020E610000067F0F78BD9F24140138255F5F2834A40
70293	1	11	1598	48203	\N	\N	53.103211000000002	дер.Новоселово, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Новоселово	0101000020E6100000CEC133A1490C424032CB9E04368D4A40
70269	1	11	1598	21204	\N	\N	52.847416000000003	с.Новодмитровка, Здание школы	Россия, Орловская область, Орловский район, поселок Новодмитровка	0101000020E610000016DD7A4D0F284240B70DA320786C4A40
70284	1	11	1598	21878	\N	\N	53.055948999999998	дер.Нижняя Калиновка, Здание администрации с/пос.	Россия, Орловская область, Орловский район, поселок Нижняя Калиновка	0101000020E6100000D32F116F9D1B4240389F3A5629874A40
70250	1	11	1598	40403	\N	\N	52.985427999999999	дер.Некрасовка, Здание школы	Россия, Орловская область, Орловский район, поселок Некрасовка	0101000020E61000003929CC7B9C01424006483481227E4A40
70241	1	11	1598	19661	\N	\N	53.222411000000001	с.Моховица, Здание администрации с/пос.	Россия, Орловская область, Орловский район, поселок Моховица	0101000020E6100000B3D1393FC5F94140A5A2B1F6779C4A40
70252	1	11	1598	60409	\N	\N	52.878869546062099	дер.Михайловка, Здание детского сада	Россия, Орловская область, Орловский район, поселок Михайловка	0101000020E6100000ACE3F8A1D2144240BFB7E9CF7E704A40
70275	1	11	1598	54576	\N	\N	52.9904815243016	дер.Малая Рябцева, Здание столовой УПХ ПЛ-22	Россия, Орловская область, Орловский район, поселок Малое Рябцево	0101000020E6100000315BB22AC22142406AA33A1DC87E4A40
70271	1	11	1598	47798	\N	\N	52.838495999999999	с.Лаврово, Здание школы	Россия, Орловская область, Орловский район, поселок Лаврово	0101000020E61000005778978BF8004240D5E940D6536B4A40
70277	1	11	1598	60417	\N	\N	52.885572366507603	"пос.Красная Звезда, Здание столовой ОПХ ""Красная Звезда"""	Россия, Орловская область, Орловский район, поселок Красная Звезда	0101000020E61000009EB64604E32C42406D205D6C5A714A40
70279	1	11	1598	47951	\N	\N	53.042800999999997	дер.Карпова, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Карпова	0101000020E6100000FC00A436712A4240389ECF807A854A40
70248	1	11	1598	47373	\N	\N	53.025320999999998	дер.Истомино, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Истомино	0101000020E6100000081C0934D8F441407573F1B73D834A40
70286	1	11	1598	48078	\N	\N	53.080482000000003	дер.Ивановское, Здание школы	Россия, Орловская область, Орловский район, поселок Ивановское	0101000020E610000073F4F8BD4D1F424056F5F23B4D8A4A40
70330	1	11	1598	48867	\N	\N	52.928077000000002	с. Знаменское, Здание Знаменского сельского Дома Культуры		0101000020E6100000C1FEEBDCB4234240BC95253ACB764A40
70260	1	11	1598	20743	\N	\N	52.896242999999998	Орловская обл. Орловский р-н,п Знаменка ул Ленина 10а	Россия, Орловская область, Орловский район, поселок Знаменка	0101000020E610000094FAB2B453FD41406C223317B8724A40
70255	1	11	1598	20477	\N	\N	52.958460000000002	с.Звягинки, Здание школы	Россия, Орловская область, Орловский район, поселок Звягинки	0101000020E6100000F357C85C19F64140184339D1AE7A4A40
70148	1	11	1598	49589	\N	\N	52.815854999999999	с. Дубовик, Здание Дома культуры	Россия, Орловская область, Орловский район, поселок Дубовик	0101000020E6100000EB025E66D80C424098A3C7EF6D684A40
70239	1	11	1598	47178	\N	\N	53.159756000000002	дер.Дубовая Роща, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Дубовая Роща	0101000020E6100000570740DCD50742407EAB75E272944A40
70341	1	11	1598	49065	\N	\N	52.931585659256797	д. Домнино, Здание Первомайской основной школы		0101000020E6100000D219187959254240ABB4C5353E774A40
70265	1	11	1598	20958	\N	\N	52.818978999999999	пос.Добрый, Здание администрации с/пос.	Россия, Орловская область, Орловский район, поселок Добрый	0101000020E6100000ADDD76A1B9EE41402E8ECA4DD4684A40
70264	1	11	1598	20958	\N	\N	52.818978999999999	"пос.Добрый, Здание ОПХ ""Орловское"""	Россия, Орловская область, Орловский район, поселок Добрый	0101000020E6100000ADDD76A1B9EE41402E8ECA4DD4684A40
70317	1	11	1598	48654	74998	\N	52.919542	д.Грачевка, пер.Школьный, 5		0101000020E6100000FF5A5EB9DE14424033A6608DB3754A40
70007	1	11	1598	48654	38057	\N	52.919542	с. Грачевка, ул. Луговая, 4	Россия, Орловская область, Орловский район, поселок Грачевка	0101000020E6100000FF5A5EB9DE14424033A6608DB3754A40
70283	1	11	1598	21866	\N	\N	53.066320285129699	пос.Вязки, Здание школы	Россия, Орловская область, Орловский район, поселок Вязки	0101000020E6100000548B8862F21642400D897B2C7D884A40
70273	1	11	1598	21384	\N	\N	52.916198000000001	дер.Большая Куликовка, Здание сельского клуба	Россия, Орловская область, Орловский район, поселок Большая Куликовка	0101000020E6100000C8D0B1834A1C42408F54DFF945754A40
70247	1	11	1598	19977	\N	\N	53.046005999999998	дер.Болотовские Дворы, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Болотовские Дворы	0101000020E61000004DBB9866BAF34140BBB54C86E3854A40
70288	1	11	1598	22076	\N	\N	53.058385000000001	пос.Белоберезовский, Здание сельского дома культуры	Россия, Орловская область, Орловский район, поселок Белоберезовский	0101000020E6100000BAA1293BFD064240DAC9E02879874A40
70245	1	11	1598	47291	\N	\N	53.111071000000003	с.Бакланово, Здание школы	Россия, Орловская область, Орловский район, поселок Бакланово	0101000020E6100000FE28EACC3DF241405B441493378E4A40
70263	1	11	1598	20879	\N	\N	52.85492	с.Альшань, Здание бывшей школы	Россия, Орловская область, Орловский район, поселок Альшань	0101000020E61000000917F2086EF841402159C0046E6D4A40
70217	1	11	1532	18389	38113	\N	53.073444000000002	Орловская область, Новосильский район, с. Чулково, ул. Раздольная, д. 38		0101000020E6100000D7135D177E784240310BED9C66894A40
70221	1	11	1532	54619	38174	\N	52.922202149220901	Орловская область, Новосильский район, дер. Михалево, ул. Центральная, д. 5	Россия, Орловская область, Новосильский район, поселок Хутор	0101000020E6100000AC8C463EAF8C4240242713B70A764A40
70225	1	11	1532	18829	38098	\N	53.135966000000003	Орловская область, Новосильский район, дер. Хворостянка, ул. Центральная, д. 26	Россия, Орловская область, Новосильский район, поселок Хворостянка	0101000020E6100000776A2E37188E424019AF795567914A40
70226	1	11	1532	18857	38067	\N	53.129614165528999	Орловская область, Новосильский район, дер. Селезнево, ул. Школьная, д. 8	Россия, Орловская область, Новосильский район, поселок Селезнево	0101000020E6100000A86F99D365914240478D093197904A40
70219	1	11	1532	18519	38152	\N	53.036741999999997	Орловская область, Новосильский район, дер. Ржавка, ул. Садовая, д. 3		0101000020E6100000410FB56D189D4240DF313CF6B3844A40
70216	1	11	1532	18350	38031	\N	53.061047000000002	Орловская область, Новосильский район, дер. Одинок, ул. Школьная, д. 13		0101000020E6100000A5129ED0EB7142406C425A63D0874A40
70213	1	11	1532	18127	36894	\N	52.974378000000002	Орловская область, Новосильский район, город Новосиль, ул. Карла Маркса, д. 86		0101000020E6100000087767EDB685424090F8156BB87C4A40
70212	1	11	1532	18127	36894	\N	52.974378000000002	Орловская область, Новосильский район, город Новосиль, ул. Карла Маркса, д. 37		0101000020E6100000087767EDB685424090F8156BB87C4A40
70223	1	11	1532	18729	38014	\N	53.029020000000003	Орловская область, Новосильский район, дер. Мужиково, ул. Победы, д. 101		0101000020E6100000F3565D876A904240087767EDB6834A40
70243	1	11	1532	47254	\N	\N	53.152509999999999	с.Маслово, Здание сельского дома культуры	Россия, Орловская область, Новосильский район, поселок Маслово	0101000020E6100000AE9D2809899242400F289B7285934A40
70220	1	11	1532	18562	37973	\N	52.962088999999999	Орловская область, Новосильский район, с. Заречье, ул. Центральная, д. 28		0101000020E6100000ABCC94D6DF824240B16B7BBB257B4A40
70177	1	11	1037	16380	37978	\N	53.348274000000004	с.Тельчье, ул.Ленина, д.1		0101000020E610000040A20914B12A42400806103E94AC4A40
70215	1	11	1532	18290	38164	\N	52.9811084207983	Орловская область, Новосильский район, с. Задушное, ул. Центральная, д. 21	Россия, Орловская область, Новосильский район, поселок Задушное	0101000020E61000003D9E961FB87C424007EC6AF2947D4A40
70218	1	11	1532	18459	38037	\N	53.055531999999999	Орловская обл Новосильский р-н,с Голунь,ул. Центральная д.15/3		0101000020E6100000BB6246787B984240D4F02DAC1B874A40
70214	1	11	1532	18215	38138	\N	53.022725999999999	Орловская область, Новосильский район, с. Вяжи-Заверх, ул. Лесная, д. 37		0101000020E6100000DBBFB2D2A47A42406B6281AFE8824A40
70224	1	11	1532	18737	38115	\N	52.988318	Орловская область, Новосильский район, с. Воротынцево, ул. Образцовая, д. 2		0101000020E6100000D6389B8E0090424029064834817E4A40
70222	1	11	1532	18669	38114	\N	53.032057999999999	Орловская область, Новосильский район, дер. Большие Пруды, ул. Центральная, д. 17	Россия, Орловская область, Новосильский район, поселок Большие Пруды	0101000020E6100000A4FACE2F4A8A42409FC9FE791A844A40
70200	1	11	1144	10761	\N	\N	53.002766999999999	п. Шатилово, здание Шатиловского лицея		0101000020E6100000A1A014ADDCAF4240074147AB5A804A40
70189	1	11	1144	16981	72345	\N	52.856099999999998	Орловская обл. Новодеревеньковский р-н, Хомутово, ул Победы д. 1а		0101000020E61000005EF7562426B84240840D4FAF946D4A40
70190	1	11	1144	16981	36892	\N	52.856201483012399	пгт. Хомутово, Комсомольская, д.22	Россия, Орловская область, Новодеревеньковский район, поселок Хомутово	0101000020E61000002594BE1072B84240B8E68EFE976D4A40
70198	1	11	1144	60452	\N	\N	52.984842999999998	д. Суры, здание Суровской начальной школы	Россия, Орловская область, Новодеревеньковский район, поселок Суры	0101000020E610000016BD5301F7AA4240E658DE550F7E4A40
70203	1	11	1144	54608	\N	\N	52.9549250411118	с. Судбище, здание Судбищенской школы	Россия, Орловская область, Новодеревеньковский район, поселок Судбищи	0101000020E6100000359A5C8C81D1424000917EFB3A7A4A40
70209	1	11	1144	46577	\N	\N	53.051743999999999	с. Старогольское, здание админ.Старогольского с/п	Россия, Орловская область, Новодеревеньковский район, поселок Старогольское	0101000020E6100000679C86A8C2DD4240D2E1218C9F864A40
70333	1	11	1144	48928	\N	\N	52.813988000000002	с. Плоское, Здание Плосковской основной школы		0101000020E6100000BEA25BAFE9B9424011AB3FC230684A40
70210	1	11	1144	46601	\N	\N	53.044657999999998	д. Пасынки, здание Пасынковской школы	Россия, Орловская область, Новодеревеньковский район, поселок Пасынки	0101000020E610000053094FE8F5E742409CC0745AB7854A40
70206	1	11	1144	60405	\N	\N	53.0546816898595	с. Паньково, здание Паньковской школы	Россия, Орловская область, Новодеревеньковский район, поселок Паньково	0101000020E6100000B95510035DC5424006D7DCD1FF864A40
70191	1	11	1144	46165	\N	\N	52.835457550940497	"п. Новая Заря, здание МДОУ ""Новозоренский детский"	Россия, Орловская область, Новодеревеньковский район, поселок Новая Заря	0101000020E61000008028983105B942403E97A949F06A4A40
70192	1	11	1144	46197	\N	\N	52.855240999999999	д. Никольское, здание МОУ Никольская нач. школа		0101000020E6100000F10D85CFD6AF424063997E89786D4A40
70133	1	11	1144	46197	72129	\N	52.855240999999999	с. Никольское, Колхозная, 1а		0101000020E6100000F10D85CFD6AF424063997E89786D4A40
70195	1	11	1144	60408	74973	\N	52.893363228497101	Орловская обл. Новодеревеньковский р-н, Мураевка, ул. Школьная 3	Россия, Орловская область, Новодеревеньковский район, поселок Муравьевка	0101000020E610000022FB20CB82BB42406D3A02B859724A40
70202	1	11	1144	17631	\N	\N	53.043520999999998	Орловская обл. Новодеревеньковский р-н, Моховое 3	Россия, Орловская область, Новодеревеньковский район, поселок Моховое	0101000020E61000004EB857E6ADAC424038D89B1892854A40
70197	1	11	1144	17383	\N	\N	52.889746000000002	с.Лазавка, здание Лазавской школы	Россия, Орловская область, Новодеревеньковский район, поселок Лазавка	0101000020E6100000388600E0D8D5424098DF6932E3714A40
70199	1	11	1144	17506	\N	\N	52.983123999999997	д. Кулеши, здание администрации Суровского сп	Россия, Орловская область, Новодеревеньковский район, поселок Кулеши	0101000020E61000000B0A83328DB24240D3F4D901D77D4A40
70193	1	11	1144	46213	\N	\N	52.933487999999997	с. Косарёво, здание Косаревской школы	Россия, Орловская область, Новодеревеньковский район, поселок Косарево	0101000020E6100000242BBF0CC6A64240AE9AE7887C774A40
70208	1	11	1144	17957	\N	\N	52.982706999999998	с. Кологривово, здание Кологривовской школы	Россия, Орловская область, Новодеревеньковский район, поселок Кологривово	0101000020E610000003232F6B62ED42406F46CD57C97D4A40
70204	1	11	1144	46473	\N	\N	52.983969999999999	д. Дементьевка, здание Журавлиновской школы	Россия, Орловская область, Новодеревеньковский район, поселок Дементьевка	0101000020E6100000789B374E0AC34240601F9DBAF27D4A40
70211	1	11	1144	46613	\N	\N	53.105243000000002	д. Благодать, здание Смоленской школы	Россия, Орловская область, Новодеревеньковский район, поселок Благодать	0101000020E61000004628B682A6DB42400491459A788D4A40
70166	1	11	1037	45656	\N	\N	53.245685000000002	д.Ядрино, д.54		0101000020E6100000C61858C7F14F4240130F289B729F4A40
70176	1	11	1037	45825	38081	\N	53.421444999999999	д.Шашкино, ул.Школьная, д.4		0101000020E610000046B3B27DC83542400708E6E8F1B54A40
70163	1	11	1037	15700	37991	\N	53.159106975800199	с.Черемошны, ул.Садовая, д.2	Россия, Орловская область, Мценский район, поселок Черемошны	0101000020E6100000CFBC1C76DF6B424047C8409E5D944A40
70170	1	11	1037	16052	38090	\N	53.166068000000003	д.Чахино, ул.Мичурина, д.44	Россия, Орловская область, Мценский район, поселок Чахино	0101000020E610000040683D7C994C4240C1745AB741954A40
70174	1	11	1037	54634	38332	\N	53.339877000000001	д.Фроловка, ул.Центральная, д.2	Россия, Орловская область, Мценский район, поселок Фроловка	0101000020E6100000DBDC989EB0384240D0D4EB1681AB4A40
70180	1	11	1037	45918	38128	\N	53.290756000000002	д.Фарафоново, ул.Школьная, д.5		0101000020E6100000145CACA8C13E4240D28E1B7E37A54A40
55525	1	11	1037	9082	38040	\N	53.070310999999997	д.Сычи, ул.Центральная, д.1		0101000020E610000039EE940ED645424047C66AF3FF884A40
70172	1	11	1037	16135	37949	\N	53.370114000000001	с.Спасское-Лутовиново, ул.Никольская, д.19		0101000020E61000002C465D6BEF4F424058E542E55FAF4A40
69907	1	11	1037	49414	\N	\N	53.266903999999997	село Руднево	Россия, Орловская область, Мценский район, поселок Руднево	0101000020E61000002159C0046E374240F69507E929A24A40
70181	1	11	1037	16608	38419	\N	53.078951000000004	д.Протасово, ул.Полянская, д.27		0101000020E61000008928266F803F4240467EFD101B8A4A40
70165	1	11	1037	54635	\N	\N	53.260160999999997	д.Подберезово, д.24	Россия, Орловская область, Мценский район, поселок Подберезово	0101000020E6100000AF97A60870504240EA58A5F44CA14A40
70169	1	11	1037	15996	38136	\N	53.177840000000003	с.Подбелевец, ул.Школьная, д.1		0101000020E6100000299831056B564240D8F50B76C3964A40
70132	1	11	1037	40392	72291	\N	53.143765999999999	д. Петровка, Центральная, 4		0101000020E6100000738236397C3842406C239EEC66924A40
70188	1	11	1037	54614	38165	\N	53.165504055516202	Орловская обл. Мценский р-н, с. Отрадинское, ул Совхозная д.3	Россия, Орловская область, Мценский район, поселок Отрадинский	0101000020E6100000A5164A26A72C4240B8AD2D3C2F954A40
70184	1	11	1037	16752	37959	\N	53.226401000000003	п.Нововолковский, ул.Центральная, д.18		0101000020E61000009488F02F823C42400F643DB5FA9C4A40
70318	1	11	1037	60445	75025	\N	53.207125433690699	д.Никольское, ул.Центральная, 1	Россия, Орловская область, Мценский район, поселок Никольское	0101000020E610000079B29B19FD7242408D976E12839A4A40
70173	1	11	1037	16194	38029	\N	53.326051999999997	д.Нижняя Зароща, ул.Мира, д.28а		0101000020E61000004F779E78CE4C4240CF656A12BCA94A40
70384	1	11	1037	45394	36752	\N	53.214761000000003	пос.Нарышкино, ул.Чапаева, д.26		0101000020E6100000E15F048D992A424067BAD7497D9B4A40
70383	1	11	1037	45394	36752	\N	53.214761000000003	пос.Нарышкино, ул.Чапаева, д.6		0101000020E6100000E15F048D992A424067BAD7497D9B4A40
70382	1	11	1037	45394	36749	\N	53.214761000000003	пос.Нарышкино, ул.Ленина, д.95		0101000020E6100000E15F048D992A424067BAD7497D9B4A40
70167	1	11	1037	15912	38416	\N	53.08972	д.Мелынь, ул.Квартальная, д.7		0101000020E61000001E5036E50A61424008E6E8F17B8B4A40
70164	1	11	1037	45608	38153	\N	53.206282999999999	д.Жилино, ул.Минаева, д.7		0101000020E610000082E673EE76614240425C397B679A4A40
70182	1	11	1037	16664	38011	\N	53.117308000000001	д.Добрая Вода, пер.Школьный, д.3		0101000020E61000008C4D2B854042424093C7D3F2038F4A40
70342	1	11	1037	49079	\N	\N	53.258522999999997	д. Городище, Здание Городищенского сельского Дома культуры		0101000020E6100000E8DCED7A69264240C4211B4817A14A40
70175	1	11	1037	54586	38033	\N	53.321803000000003	д.Глазуново, ул.Школьная, д.4	Россия, Орловская область, Мценский район, поселок Глазуново	0101000020E610000080643A747A3E42409A6038D730A94A40
70162	1	11	1037	45575	38079	\N	53.217106000000001	д.Гладкое, ул.Школьная, д.8		0101000020E61000005B5D4E0988714240F8E12021CA9B4A40
70168	1	11	1037	45886	38688	\N	53.115417000000001	д.Высокое, ул.Школьная, д.1	Россия, Орловская область, Мценский район, поселок Высокое	0101000020E610000042EBE1CB445D42408333F8FBC58E4A40
70185	1	11	1037	46036	38550	\N	53.250129999999999	д.Волково, ул.Центральная, д.2		0101000020E6100000FF3EE3C281444240CEDF844204A04A40
70183	1	11	1037	16697	37940	\N	53.182146000000003	д.Первый Воин, ул.Тюленина, д.1	Россия, Орловская область, Мценский район, поселок Воин 1-й	0101000020E61000002F8A1EF818344240728C648F50974A40
70142	1	11	1037	14703	37938	\N	53.264119999999998	д.Верхнее Алябьево, пл.Центральная, д.2		0101000020E6100000BC749318046A4240191C25AFCEA14A40
70178	1	11	1037	45880	37981	\N	53.329816000000001	д.Брагино, ул.Молодежная, д.36		0101000020E6100000EF552B137E29424049D9226937AA4A40
70171	1	11	1037	16075	\N	\N	53.330311000000002	Орловская обл. Мценский р-н,д. Б.Каменка д 4		0101000020E61000008A93FB1D8A58424029417FA147AA4A40
70186	1	11	1037	54639	38423	\N	53.165058000000002	д.Башкатово, ул.Школьная, д.4	Россия, Орловская область, Мценский район, поселок Башкатово	0101000020E610000038F4160FEF1F4240BAF8DB9E20954A40
70080	1	11	1037	30248	\N	\N	53.234113999999998	с.Апальково, здание администрации Апальковского сельского поселения		0101000020E61000002426A8E15B1C424093C49272F79D4A40
70179	1	11	1037	45911	38065	\N	53.27713	д.Аниканово, ул.Центральная, д.13	Россия, Орловская область, Мценский район, поселок Аниканово	0101000020E6100000D7F84CF6CF334240C85EEFFE78A34A40
70151	1	11	1381	60429	\N	\N	52.3821528254146	с. Хитрово, Здание Дома культуры	Россия, Орловская область, Малоархангельский район, поселок Хитрово	0101000020E61000006B65C22FF5614240BE88B663EA304A40
70154	1	11	1381	15278	\N	\N	52.279076000000003	п. Рогатый, Здание Дома культуры	Россия, Орловская область, Малоархангельский район, поселок Рогатый	0101000020E61000002CF2EB87D85042409C8C2AC3B8234A40
70158	1	11	1381	15477	\N	\N	52.395605000000003	д. Подгородняя 2-я, Здание администрации Октябрьского с/п	Россия, Орловская область, Малоархангельский район, поселок Подгородняя 2-я	0101000020E61000001C7BF65CA64242402A91442FA3324A40
70153	1	11	1381	15232	\N	\N	52.314737999999998	п. Плещеевский Завод, Здание Плещеевского завода	Россия, Орловская область, Малоархангельский район, поселок Плещеевский Завод	0101000020E61000006F66F4A3E15642407B67B45549284A40
70114	1	11	1381	54575	37995	\N	52.319697272579198	с. Остров, Центральная, 10	Россия, Орловская область, Малоархангельский район, поселок Остров	0101000020E6100000C1E10511A93B42408DD0CFD4EB284A40
70141	1	11	1381	54572	\N	\N	52.404106215410003	п. Новая Стройка, Здание  Дома культуры	Россия, Орловская область, Малоархангельский район, поселок Новая Стройка	0101000020E61000007061DD7877364240060FD3BEB9334A40
70143	1	11	1381	54573	\N	\N	52.391325763095402	п. станция Малоархангельск, Здание ХПП административное помещение	Россия, Орловская область, Малоархангельский район, поселок Малоархангельск	0101000020E610000039B35DA10F28424089096AF816324A40
70161	1	11	1381	15516	36835	\N	52.400621999999998	город Малоархангельск, К.Либкнехта, 64		0101000020E610000020D4450A653F42407007EA9447334A40
70152	1	11	1381	45401	\N	\N	52.294727000000002	с. Луковец, Здание Луковской средней школы	Россия, Орловская область, Малоархангельский район, поселок Луковец	0101000020E6100000F86F5E9CF8564240C51F459DB9254A40
70155	1	11	1381	15303	\N	\N	52.234555999999998	с. Легостаево Первое, Здание Легостаевской основной школы	Россия, Орловская область, Малоархангельский район, поселок Легостаево 1-е	0101000020E61000008E5BCCCF0D514240508A56EE051E4A40
70145	1	11	1381	49545	\N	\N	52.299557	д. Костино, Здание Костинской основной школы	Россия, Орловская область, Малоархангельский район, поселок Костино	0101000020E6100000E338F06AB9414240D9243FE257264A40
70150	1	11	1381	15083	\N	\N	52.402237	с. Ивань 1-я, Здание Дома культуры	Россия, Орловская область, Малоархангельский район, поселок Ивань 1-я	0101000020E610000009E066F1625B4240DE1E84807C334A40
70157	1	11	1381	45481	\N	\N	52.358665999999999	с. Губкино, Здание Дома культуры	Россия, Орловская область, Малоархангельский район, поселок Губкино	0101000020E61000000892770E65524240F4177AC4E82D4A40
70056	1	11	1381	48062	38154	\N	52.397940925816698	дер.Гриневка, Садовая, 51а	Россия, Орловская область, Малоархангельский район, поселок Гриневка	0101000020E61000005322895E46374240685E0EBBEF324A40
70156	1	11	1381	15380	\N	\N	52.271498999999999	с. Гнилая Плота, Здание Гнилоплотской основной школы	Россия, Орловская область, Малоархангельский район, поселок Гнилая Плота	0101000020E61000006CB2463D44474240C7F2AE7AC0224A40
70149	1	11	1381	49596	\N	\N	52.473278999999998	с. Архарово, Здание Дома культуры	Россия, Орловская область, Малоархангельский район, поселок Архарово	0101000020E6100000A680B4FF015A424019710168943C4A40
70121	1	11	6911	40391	36890	\N	52.405622000000001	сл. Беломестное, Воронежская, 17		0101000020E6100000732EC55565CD4240E144F46BEB334A40
70122	1	11	1236	54627	38270	\N	52.335076000000001	с. Троицкое, Садовая, 4	Россия, Орловская область, Ливенский район, поселок Троицкое	0101000020E61000005FB7088CF5CD424056D636C5E32A4A40
70101	1	11	1236	12794	38135	\N	52.411841000000003	с. Теличье, Дружбы Народов, 33		0101000020E6100000C5E3A25A44BA42407313B534B7344A40
70099	1	11	1236	47023	74971	\N	52.338952745221498	Орловская обл. Ливенский р-н д. Сосновка, ул. Центральная д 2	Россия, Орловская область, Ливенский район, поселок Сосновка	0101000020E6100000130EBDC5C3AD4240C7F0D8CF622B4A40
70115	1	11	1236	54577	38001	\N	52.432996000000003	пос. Совхозный, Центральная, 8	Россия, Орловская область, Ливенский район, поселок Совхозный	0101000020E6100000713AC95697D3424040A6B5696C374A40
70130	1	11	1236	54584	38015	\N	52.355944000000001	с. Сергиевское, Пентюхова, 15	Россия, Орловская область, Ливенский район, поселок Сергиевское	0101000020E610000060C8EA56CFD742408D9AAF928F2D4A40
70110	1	11	1236	13195	37948	\N	52.573255000000003	д. Семенихино, Школьная, 1а	Россия, Орловская область, Ливенский район, поселок Семенихино	0101000020E610000079EBFCDB65C342405EA27A6B60494A40
70137	1	11	1236	14467	38162	\N	52.284166999999997	с. Свободная Дубрава, Центральная, 21		0101000020E61000006536C82423E742401CCD91955F244A40
70107	1	11	1236	13064	36953	\N	52.430008999999998	пос. Сахзаводской, пл. Комсомольская, 34		0101000020E610000012F5824F73C242402AFEEF880A374A40
70127	1	11	1236	13994	37965	\N	52.330492	д. Росстани, Ассовиахим, 41		0101000020E61000006F0ED76A0FC1424079CBD58F4D2A4A40
70100	1	11	1236	48865	37942	\N	52.39067	с. Речица, Центральная, 58	Россия, Орловская область, Ливенский район, поселок Речица	0101000020E6100000F9BD4D7FF6B14240A0C37C7901324A40
70102	1	11	1236	12849	37936	\N	52.429563999999999	с. Покровка 1-я, Молодежная, 18		0101000020E6100000BE839F3880A24240FCC401F4FB364A40
55934	1	11	1236	46226	38042	\N	52.591710302732302	д. Пешково, Советская, 20	Россия, Орловская область, Ливенский район, поселок Пешково	0101000020E6100000971AA19FA9D94240AB5B3D27BD4B4A40
70111	1	11	1236	13221	38127	\N	52.553404999999998	д. Орлово, Орловская, 96		0101000020E61000009E616A4B1DCE4240B0389CF9D5464A40
70280	1	11	1236	47957	\N	\N	52.561075000000002	дер.Овсянниково, Здание школы	Россия, Орловская область, Ливенский район, поселок Овсянниково	0101000020E61000000A4966F50ECF424036CD3B4ED1474A40
70136	1	11	1236	49400	38027	\N	52.219991999999998	с. Норовка, Фрунзе, 17		0101000020E610000021956247E3E64240D9B0A6B2281C4A40
70138	1	11	1236	14520	38013	\N	52.280673999999998	с. Навесное, Центральная, 23		0101000020E6100000F65CA626C1F94240336B2920ED234A40
70105	1	11	1236	48957	37964	\N	52.41189	пос. Набережный, Школьная, 35		0101000020E6100000AAD216D7F8C4424054C6BFCFB8344A40
70104	1	11	1236	48946	38024	\N	52.465055	д. Моногарово, Октябрьская, 2		0101000020E610000022E17B7F83C24240AFEB17EC863B4A40
70301	1	11	1236	54603	38295	\N	52.440753000000001	д.Липовец, ул.Центральная, 34	Россия, Орловская область, Ливенский район, поселок Липовец	0101000020E61000003737A6272CD94240944E24986A384A40
70116	1	11	1236	54603	38122	\N	52.440753000000001	д. Липовец, Н.А. Кузьмина, 36	Россия, Орловская область, Ливенский район, поселок Липовец	0101000020E61000003737A6272CD94240944E24986A384A40
69945	1	11	1236	49180	\N	\N	52.414020521236502	д. Кунач, помещение Куначевского дома культуры	Россия, Орловская область, Ливенский район, поселок Кунач	0101000020E610000028F224E99AE34240B96DDFA3FE344A40
70119	1	11	1236	49180	38119	\N	52.413417000000003	с. Кунач, Церковная, 28		0101000020E6100000D8614CFA7BE34240234E27D9EA344A40
70103	1	11	1236	54563	37859	\N	52.441242000000003	с. Крутое, Комсомольская, 1	Россия, Орловская область, Ливенский район, поселок Крутое	0101000020E6100000B9895A9A5BBD424092CF2B9E7A384A40
70140	1	11	1236	54623	38233	\N	52.322719999999997	с. Круглое, Круглянская, 36	Россия, Орловская область, Ливенский район, поселок Круглое	0101000020E61000004D68925852FE4240EFE192E34E294A40
70125	1	11	1236	49263	36742	\N	52.368355999999999	с. Коротыш, Молодежная, 7		0101000020E610000050A8A78FC0BD424087A4164A262F4A40
70117	1	11	1236	49153	37937	\N	52.451752999999997	с. Козьминка, Центральная, 28	Россия, Орловская область, Ливенский район, поселок Козьминка	0101000020E6100000B47570B037E34240586FD40AD3394A40
70270	1	11	1236	47768	\N	\N	52.384388000000001	с.Калинино, Здание школы	Россия, Орловская область, Ливенский район, поселок Калинино	0101000020E6100000BE2F2E5569F54240C87C40A033314A40
70135	1	11	1236	49398	38028	\N	52.274777999999998	с. Казанское, М. Горького, 25		0101000020E610000059FCA6B052DF424084D4EDEC2B234A40
70108	1	11	1236	49000	38161	\N	52.526522	д. Зубцово, Вишневая, 13		0101000020E6100000DA3BA3AD4AC24240F04FA91265434A40
70109	1	11	1236	13145	37988	\N	52.508729000000002	д. Здоровецкие Выселки, Центральная, 75		0101000020E6100000C899266C3FC142406EC328081E414A40
70375	1	11	1236	49531	\N	\N	52.349359	пос.Заречный, ул.Заречная, д.5	Россия, Орловская область, Ливенский район, поселок Заречный	0101000020E61000008FFF024180D8424019C8B3CBB72C4A40
70254	1	11	1236	47490	\N	\N	52.294269999999997	пос.Зареченский, Здание сельского клуба	Россия, Орловская область, Ливенский район, поселок Зареченский	0101000020E61000004240BE840AD84240D218ADA3AA254A40
70131	1	11	1236	49330	38134	\N	52.341816999999999	с. Жерино, Воронежская, 2		0101000020E61000008E588B4F01E44240C11BD2A8C02B4A40
70134	1	11	1236	49376	38431	\N	52.248446999999999	с. Екатериновка, Центральная, 3		0101000020E61000004E2844C021D8424008E57D1CCD1F4A40
70112	1	11	1236	13281	37958	\N	52.546411999999997	д. Гремячий Колодезь, Центральная, 5а		0101000020E6100000C558A65F22D242402B1213D4F0454A40
70124	1	11	1236	49252	38163	\N	52.528332732813801	д. Горностаевка, пл. Центральная, 5		0101000020E610000058E71890BDC64240E4326E6AA0434A40
70139	1	11	1236	14570	38126	\N	52.300063999999999	с. Вязовая Дубрава, Центральная, 13		0101000020E61000008DF161F6B2EF42407D5A457F68264A40
70113	1	11	1236	13339	38072	\N	52.505625999999999	с. Воротынск, Школьная, 5а		0101000020E6100000A48AE255D6D04240EF004F5AB8404A40
70120	1	11	1236	13632	38112	\N	52.383133999999998	д. Викторовка, Центральная, 44		0101000020E6100000DA0418963FEF42402AFEEF880A314A40
70128	1	11	1236	49306	38025	\N	52.276316435938703	с. Введенское, Ливенская, 38	Россия, Орловская область, Ливенский район, поселок Введенское	0101000020E610000069E21DE049B5424047AE9B525E234A40
70126	1	11	1236	54616	38168	\N	52.274286033445399	д. Вахново, Центральная, 44	Россия, Орловская область, Ливенский район, поселок Вахново	0101000020E610000047AE9B525EBB424015E0BBCD1B234A40
70098	1	11	1236	12684	38012	\N	52.307724	д. Важжова, Полевая, 2	Россия, Орловская область, Ливенский район, поселок Важжова	0101000020E6100000B54E5C8E57A84240DF18028063274A40
70123	1	11	1236	54653	38578	\N	52.375075000000002	д. Барково, Карла Маркса, 41	Россия, Орловская область, Ливенский район, поселок Барково	0101000020E61000001F9DBAF259C842400B46257502304A40
70129	1	11	1236	49318	38529	\N	52.259343331344098	с. Бараново, Войнова, 5	Россия, Орловская область, Ливенский район, поселок Бараново	0101000020E610000012842BA050BF424028B9C32632214A40
70335	1	11	1180	48965	\N	\N	52.621796000000003	д.Яковлево, Здание администрации Яковлевского сельского поселения	Россия, Орловская область, Кромский район, поселок Яковлево	0101000020E61000000E12A27C41F741404E64E602974F4A40
70093	1	11	1180	54606	\N	\N	52.553437000000002	пос.Шоссе, здание сельского дома культуры	Россия, Орловская область, Кромский район, поселок Шоссе	0101000020E6100000FDF84B8BFAE04140BCB20B06D7464A40
70066	1	11	1180	54638	38421	\N	52.759106000000003	с.Шахово, ул.Победы, здание Шаховского сельского клуба		0101000020E610000046B41D5377ED41404419AA622A614A40
70070	1	11	1180	11314	\N	\N	52.695843000000004	дер.Черкасская, здание Черкасского СДК	Россия, Орловская область, Кромский район, поселок Черкасская	0101000020E610000009185DDE1CE641404513286211594A40
70068	1	11	1180	11223	\N	\N	52.707051	дер.Стрелецкая, здание администрации Стрелецкого сельского поселения	Россия, Орловская область, Кромский район, поселок Стрелецкая	0101000020E6100000EB8EC536A9E2414053CDACA5805A4A40
70079	1	11	1180	48513	\N	\N	52.575054999999999	дер.Семенково, здание Семенковского сельского клуба	Россия, Орловская область, Кромский район, поселок Семенково	0101000020E61000003F8F519E79F941405D33F9669B494A40
70430	1	11	1180	46375	\N	\N	52.644537999999997	с. Рыжково, Здание  Рыжковского СК МУККТ Рыжковское КДО		0101000020E6100000C25087156EC94140BE839F3880524A40
70077	1	11	1180	48467	\N	\N	52.675705000000001	дер.Родина, здание бывшей Родинской школы	Россия, Орловская область, Кромский район, поселок Родина	0101000020E6100000F4A62215C6F24140315F5E807D564A40
70092	1	11	1180	48731	\N	\N	52.596142	с. Ржава, д.56		0101000020E61000001E335019FFD84140D2E28C614E4C4A40
70078	1	11	1180	11701	\N	\N	52.598247999999998	с.Ретяжи, здание администрации Ретяжского сельского поселения	Россия, Орловская область, Кромский район, поселок Ретяжи	0101000020E61000001DAED51EF6F64140DE72F563934C4A40
70069	1	11	1180	60468	\N	\N	52.7184992000834	дер.Рассыльная, филиал структурного подразделения МОУ Черкасская школа	Россия, Орловская область, Кромский район	0101000020E6100000A7CD380D51E94140B79A75C6F75B4A40
70095	1	11	1180	12494	\N	\N	52.549658999999998	дер.Рассоховец, здание администрации Красниковского сельского поселения	Россия, Орловская область, Кромский район, поселок Рассоховец	0101000020E6100000CFA3E2FF8ED24140DD79E2395B464A40
70071	1	11	1180	11344	\N	\N	52.699193999999999	дер.Пушкарная, здание магазина Кромского  райпо №22	Россия, Орловская область, Кромский район, поселок Пушкарная	0101000020E6100000902E36AD14E041409BC761307F594A40
70094	1	11	1180	47343	\N	\N	52.545048000000001	дер.Моховое, здание Моховского сельского дома культуры		0101000020E6100000F35487DC0CEB414007600322C4454A40
70311	1	11	1180	47343	74985	\N	52.547121054594299	с.Моховое, ул.Лесная, 3	Россия, Орловская область, Кромский район, поселок Моховое	0101000020E61000000CE544BB0AED414037FA980F08464A40
70088	1	11	1180	12188	\N	\N	52.668964914575803	дер.Малая Драгунская, здание магазина ИП Пясецкого В.Ф.	Россия, Орловская область, Кромский район, поселок Малая Драгунская	0101000020E6100000ECDE8AC404D94140969526A5A0554A40
70097	1	11	1180	48816	\N	\N	52.533068999999998	дер.Макеево, здание Макеевского СДК	Россия, Орловская область, Кромский район, поселок Макеево	0101000020E6100000EC3191D26CFE414076C1E09A3B444A40
70090	1	11	1180	12284	\N	\N	52.634439	с.Кутафино, здание администрации Кутафинского сельского поселения	Россия, Орловская область, Кромский район, поселок Кутафино	0101000020E61000002FDFFAB0DECE41404A27124C35514A40
70438	1	11	1180	11969	\N	\N	52.693491000000002	ст.Кромы, красный уголок отделения Орловской дистанции пути ПЧ-25		0101000020E6100000DACBB6D3D6E2414001892650C4584A40
70085	1	11	1180	11969	36943	\N	52.693491000000002	пос. Кромы, пер.Бобкова, корпус ПУ-19		0101000020E6100000DACBB6D3D6E2414001892650C4584A40
70084	1	11	1180	11969	37869	\N	52.693491000000002	пос.Кромы, ул.Советская, д.1 районный дом культуры		0101000020E6100000DACBB6D3D6E2414001892650C4584A40
70086	1	11	1180	11969	37990	\N	52.693491000000002	"пос.Кромы, пер.Заводской, д.6,кр. уг. треста ""Кромымежрайгаз"""		0101000020E6100000DACBB6D3D6E2414001892650C4584A40
70087	1	11	1180	11969	36830	\N	52.693491000000002	"пос.Кромы, ул.Карла Маркса, здание магазина ""Витязь"""		0101000020E6100000DACBB6D3D6E2414001892650C4584A40
70072	1	11	1180	11413	\N	\N	52.633175999999999	пос.Кромской, здание СДК пос.Кромской	Россия, Орловская область, Кромский район, поселок Кромской	0101000020E61000002920ED7F80E14140594E42E90B514A40
70074	1	11	1180	54583	\N	\N	52.671188999999998	дер.Кромской Мост, здание магазина №5 Кромского райпо	Россия, Орловская область, Кромский район, поселок Кромский Мост	0101000020E6100000295C8FC2F5DC4140AC376A85E9554A40
70075	1	11	1180	11527	\N	\N	52.711924000000003	с.Кривчиково, здание МОУ Кривчиковской средней общеобразовательной школы	Россия, Орловская область, Кромский район, поселок Кривчиково	0101000020E6100000653909A52FF24140679E5C53205B4A40
70207	1	11	1180	46527	\N	\N	52.620631000000003	п. Красный Октябрь, здание Краснооктябрьской школы		0101000020E6100000E8BE9CD9AEEC414020F12BD6704F4A40
56192	1	11	1180	60416	74983	\N	52.535827319062697	с. Красниково, Майская, 21	Россия, Орловская область, Кромский район, поселок Красниково	0101000020E6100000CA3505323BD141402AA8A8FA95444A40
70096	1	11	1180	48797	\N	\N	52.544877999999997	с. Короськово, здание администрации Короськовского сельского поселения	Россия, Орловская область, Кромский район, поселок Короськово	0101000020E610000096EA025E66F84140AA27F38FBE454A40
70083	1	11	1180	54580	\N	\N	52.7888731505046	с.Коровье Болото, здание МОУ Коровье - Болотовской школы	Россия, Орловская область, Кромский район, поселок Коровье Болото	0101000020E610000091F2936A9FDA414045D95BCAF9644A40
70089	1	11	1180	60420	\N	\N	52.6688326340375	дер.Глинки, здание МОУ Глинская средняя общеобразовательная школа	Россия, Орловская область, Кромский район, поселок Глинки	0101000020E6100000F0A31AF67BD2414027BEDA519C554A40
70091	1	11	1180	12330	\N	\N	52.624988000000002	с.Бельдяжки, здание МОУ Бельдяжской основной школы	Россия, Орловская область, Кромский район, поселок Бельдяжки	0101000020E61000000EDDEC0F94D941403C32569BFF4F4A40
70073	1	11	1180	11435	\N	\N	52.676212999999997	дер.Атяевка, здание администрации Большеколчевского сельского поселения	Россия, Орловская область, Кромский район, поселок Атяевка	0101000020E6100000187B2FBE68E54140A510C8258E564A40
70076	1	11	1180	48453	\N	\N	52.633077999999998	дер.Арбузово, здание Гуторовского СДК	Россия, Орловская область, Кромский район, поселок Арбузово	0101000020E610000032C7F2AE7AF8414096E82CB308514A40
70058	1	11	1135	54649	38521	\N	52.757607	с.Шатилово, Школьная, 3	Россия, Орловская область, Краснозоренский район, поселок Шатилово	0101000020E61000009D8026C286E542403F1C2444F9604A40
70055	1	11	1135	10611	37945	\N	52.769976999999997	пос.Россошенский, Ленина, 18		0101000020E61000002C8194D8B5D542400AD6389B8E624A40
70046	1	11	1135	54663	38651	\N	52.674143000000001	дер.Протасово, Центральная, 2	Россия, Орловская область, Краснозоренский район, поселок Протасово	0101000020E6100000520FD1E80EC84240E6E95C514A564A40
70060	1	11	1135	10837	38069	\N	52.660845000000002	с.Пол-Успенье, Центральная, 33		0101000020E61000009DDA19A6B6E44240D15CA79196544A40
70064	1	11	1135	54666	38684	\N	52.718300999999997	с.Покровское, Ленина, 4	Россия, Орловская область, Краснозоренский район, поселок Покровское	0101000020E6100000B5FD2B2B4DBA424090D78349F15B4A40
70053	1	11	1135	10516	38026	\N	52.829408348055303	с.Орево, Школьная, 3	Россия, Орловская область, Краснозоренский район, поселок Орево	0101000020E6100000BCADF4DA6CD242403885950A2A6A4A40
55492	1	11	1135	46635	38044	\N	52.656935931506503	с.Медвежье, Толстовка, 31	Россия, Орловская область, Краснозоренский район, поселок Медвежье	0101000020E61000005CFFAECF9CD1424054C8957A16544A40
70062	1	11	1135	48190	38071	\N	52.764887999999999	с.Малиново, Центральная, 2		0101000020E6100000BC96900F7AEE42402A8D98D9E7614A40
70052	1	11	1135	54565	37946	\N	52.787216999999998	пос.Красная Заря, Ленина, 9	Россия, Орловская область, Краснозоренский район, поселок Красная Заря	0101000020E6100000F2B391EBA6D6424078EDD286C3644A40
70061	1	11	1135	10901	38023	\N	52.659660000000002	дер.Зверево-Бакулино, Молодежная, 6		0101000020E6100000E04BE141B3D942405C3D27BD6F544A40
70054	1	11	1135	10590	38009	\N	52.805343999999998	с.Верхняя Любовша, Набережная, 10		0101000020E61000004205871744C44240D1031F8315674A40
70059	1	11	1135	10797	38111	\N	52.719614999999997	с.Большая Чернава, Школьная, 18		0101000020E610000022AAF06778D94240035B25581C5C4A40
70057	1	11	1135	48098	38129	\N	52.752358999999998	дер.Бегичево, 8 Марта, 5		0101000020E6100000BEBED6A546DC4240F6ECB94C4D604A40
70228	1	11	1571	18994	\N	\N	53.131405999999998	Орловская область, Корсаковский район, д. Страховка, д.36		0101000020E61000005BB4006DABC14240C43F6CE9D1904A40
70230	1	11	1571	19084	\N	\N	53.223668000000004	Орловская область, Корсаковский район, с. Спешнево	Россия, Орловская область, Корсаковский район, поселок Спешнево	0101000020E6100000FE45D098498A4240B4942C27A19C4A40
70340	1	11	1571	49046	\N	\N	53.241131000000003	д. Петрово, Здание Никуличинского сельского дома культуры	Россия, Орловская область, Корсаковский район, поселок Петрово	0101000020E61000001F4B1FBAA0B04240A1866F61DD9E4A40
70235	1	11	1571	19354	\N	\N	53.164501999999999	Орловская область, Корсаковский район, д. Парамоново, д.52		0101000020E6100000895FB1868BB042403410CB660E954A40
70256	1	11	1571	60411	\N	\N	53.2487449406023	дер.Образцово, Здание сельского дома культуры		0101000020E6100000D7C056091691424092054CE0D69F4A40
70229	1	11	1571	19033	\N	\N	53.122993000000001	Орловская область, Корсаковский район, с. Новомихайловка, д.100		0101000020E6100000A6B4FE9600B042408751103CBE8F4A40
70236	1	11	1571	19377	\N	\N	53.210991	Орловская область, Корсаковский район, д. Новомалиново, д.48	Россия, Орловская область, Корсаковский район, поселок Новомалиново	0101000020E61000009E5C5320B3A542400B60CAC0019B4A40
70237	1	11	1571	19458	\N	\N	53.182772	Орловская область, Корсаковский район, д.Нечаево, д.53		0101000020E6100000419DF2E846B64240F04FA91265974A40
70232	1	11	1571	19180	\N	\N	53.140909000000001	Орловская область, Корсаковский район, д. Мельничная Слобода, д.36		0101000020E61000008AE6012CF2994240255B5D4E09924A40
70231	1	11	1571	19129	\N	\N	53.245953999999998	Орловская область, Корсаковский район, д. Малое Теплое, д.34	Россия, Орловская область, Корсаковский район, поселок Малое Теплое	0101000020E6100000834E081D748542400229B16B7B9F4A40
70233	1	11	1571	19251	36786	\N	53.266779999999997	Орловская область, Корсаковский район, с. Корсаково, ул. Советская, д.7		0101000020E610000048C32973F3AD42400A9DD7D825A24A40
70400	1	11	1571	60432	75004	\N	53.215469512301702	с. Глотово, Школьная, 8	Россия, Орловская область, Корсаковский район, поселок Глотово	0101000020E61000005987A3AB7481424073A25D85949B4A40
70368	1	11	1571	25809	37951	\N	53.133913	пос.Гагаринский, ул.Центральная, д.5		0101000020E610000059A48977809B42402FC1A90F24914A40
70227	1	11	1571	18928	\N	\N	53.213158999999997	Орловская область, Корсаковский район, д. Большие Озерки, д.23/2		0101000020E61000001C615111A7BB42408DEC4ACB489B4A40
70048	1	11	1062	10263	\N	\N	52.240319	Орловская область, Колпнянский район, с.Ярище, здание администрации Ярищенского сельского поселения	Россия, Орловская область, Колпнянский район, поселок Ярище	0101000020E610000009FD4CBD6E914240C0CDE2C5C21E4A40
70034	1	11	1062	9562	\N	\N	52.123018471585397	Орловская область, Колпнянский район, с.Яковка, здание Яковского сельского Дома культуры	Россия, Орловская область, Колпнянский район, поселок Яковка	0101000020E610000014083BC5AA9D4240E068C70DBF0F4A40
70044	1	11	1062	10063	\N	\N	52.217939999999999	Орловская область, Колпнянский район, д.Хутор-Лимовое, здание сельского Дома культуры	Россия, Орловская область, Колпнянский район, поселок Хутор Лимовое	0101000020E6100000895E46B1DC9C4240C03E3A75E51B4A40
70050	1	11	1062	10347	\N	\N	52.298636999999999	"Орловская область, Колпнянский район, с.Фошня, здание МОУ ""Фошнянская средняя общеобразовательная школа"""	Россия, Орловская область, Колпнянский район, поселок Фошня	0101000020E6100000C47762D68B9D42401230BABC39264A40
70045	1	11	1062	10115	\N	\N	52.382106	Орловская область, Колпнянский район, с.Ушаково, здание администрации Ушаковского сельского поселения	Россия, Орловская область, Колпнянский район, поселок Ушаково	0101000020E6100000594E42E90B9542407DCD72D9E8304A40
70065	1	11	1062	60407	\N	\N	52.098577728532	дер.Ульяновка, здание администрации  Шаховского сельского поселени	Россия, Орловская область, Колпнянский район, поселок Ульяновка	0101000020E6100000E1EF17B3259B4240740D33349E0C4A40
70043	1	11	1062	10039	\N	\N	52.215153999999998	Орловская область, Колпнянский район, д.Тимирязево, здание сельского Дома культуры	Россия, Орловская область, Колпнянский район, поселок Тимирязево	0101000020E6100000DE74CB0EF18D424042CD902A8A1B4A40
69869	1	11	1062	48856	\N	\N	52.263545999999998	село Струково	Россия, Орловская область, Колпнянский район, поселок Струково	0101000020E61000004241295AB9794240ED7E15E0BB214A40
70051	1	11	1062	54597	\N	\N	52.300317	Орловская область, Колпнянский район, д.Остров, здание сельского Дома культуры	Россия, Орловская область, Колпнянский район, поселок Остров	0101000020E6100000B62FA017EE96424067B796C970264A40
70041	1	11	1062	9893	\N	\N	52.151702	"Орловская область, Колпнянский район, с.Нетрубеж, здание МОУ ""Нетрубежская основная общеобразовательная школа"""	Россия, Орловская область, Колпнянский район, поселок Нетрубеж	0101000020E6100000CCD4247843684240705E9CF86A134A40
70018	1	11	1062	54363	36779	\N	52.1169931402179	с. Моховое, ул. Первомайская, 6	Россия, Орловская область, Колпнянский район, поселок Моховое	0101000020E6100000BEBC00FBE87A4240336E6AA0F90E4A40
70039	1	11	1062	9816	\N	\N	52.276720654157501	"Орловская область, Колпнянский район, с.Мисайлово, здание МОУ ""Мисайловская основная общеобразовательная школа"""	Россия, Орловская область, Колпнянский район, поселок Мисайлово	0101000020E610000078B988EFC4604240E78EFE976B234A40
70047	1	11	1062	10214	\N	\N	52.375591999999997	Орловская область, Колпнянский район, д.Маркино, здание сельского Дома культуры	Россия, Орловская область, Колпнянский район, поселок Маркино	0101000020E6100000850838842A854240D2510E6613304A40
70040	1	11	1062	9873	\N	\N	52.126262824605199	Орловская область, Колпнянский район, с.Крутое, здание администрации Крутовского сельского поселения	Россия, Орловская область, Колпнянский район, поселок Крутое	0101000020E61000001096B1A19B974240F1D8CF6229104A40
70038	1	11	1062	9749	\N	\N	52.252819000000002	Орловская область, Колпнянский район, с.Красное, здание администрации Краснянского сельского поселения	Россия, Орловская область, Колпнянский район, поселок Красное	0101000020E610000021E4BCFF8F6B42405A677C5F5C204A40
70030	1	11	1062	54561	37856	\N	52.222750742476798	Орловская область, Колпнянский район, поселок Колпна, Терешковой, 2	Россия, Орловская область, Колпнянский район, поселок Колпны	0101000020E610000098A59D9ACB8342405E13D21A831C4A40
70026	1	11	1062	54561	37997	\N	52.2225398928502	Орловская область, Колпнянский район, поселок Колпна, Советская, 3	Россия, Орловская область, Колпнянский район, поселок Колпны	0101000020E6100000ACE0B721C6834240A306D3307C1C4A40
70025	1	11	1062	54561	37897	\N	52.2213297530243	Орловская область, Колпнянский район, поселок Колпна, Пионерская, 2	Россия, Орловская область, Колпнянский район, поселок Колпны	0101000020E6100000CEDE196D55844240D5CF9B8A541C4A40
70027	1	11	1062	54561	37902	\N	52.223476994644798	Орловская область, Колпнянский район, поселок Колпна, Комсомольская, 3	Россия, Орловская область, Колпнянский район, поселок Колпны	0101000020E61000005CE84A04AA8342404034F3E49A1C4A40
70029	1	11	1062	54561	74975	\N	52.224068529846697	Оловская обл.Колпнянский р-н п. Колпна, ул. К.Маркса 32	Россия, Орловская область, Колпнянский район, поселок Колпны	0101000020E6100000335019FF3E8542401286014BAE1C4A40
70028	1	11	1062	54561	37900	\N	52.223665579349202	Орловская область, Колпнянский район, поселок Колпна, Железнодорожная, 5		0101000020E6100000B9A6406667834240139D6516A11C4A40
70037	1	11	1062	54561	37992	\N	52.222592605351203	Орловская область, Колпнянский район, поселок Колпна, пер.Октябрьский 1-й, 6	Россия, Орловская область, Колпнянский район, поселок Колпны	0101000020E6100000D34ECDE506834240C6A86BED7D1C4A40
70036	1	11	1062	9662	\N	\N	52.306309210887498	Орловская область, Колпнянский район, д.Клевцово, здание сельского Дома культуры	Россия, Орловская область, Колпнянский район, поселок Клевцово	0101000020E6100000FF3C0D18249D424038BC202235274A40
70035	1	11	1062	9587	\N	\N	52.145595999999998	"Орловская область, Колпнянский район, с.Знаменское, здание МОУ ""Знаменская основная общеобразовательная школа"""	Россия, Орловская область, Колпнянский район, поселок Знаменское	0101000020E61000005A677C5F5C804240D636C5E3A2124A40
70042	1	11	1062	9971	\N	\N	52.207698000000001	Орловская область, Колпнянский район, с.Дровосечное, здание МОУ Дровосеченская средняя общеобразовательная школа	Россия, Орловская область, Колпнянский район, поселок Дровосечное	0101000020E61000006C770FD07D5F4240E9B81AD9951A4A40
70049	1	11	1062	10333	\N	\N	52.257829999999998	Орловская область, Колпнянский район, с.Городецкое, здание филиала МОУ Фошнянская средняя общеобразоват. школа	Россия, Орловская область, Колпнянский район, поселок Городецкое	0101000020E61000000283A44FABA04240BEF6CC9200214A40
70032	1	11	1062	9435	\N	\N	52.371335999999999	"Орловская область, Колпнянский район, с.Вороново, здание МОУ ""Вороновская средняя общеобразовательная школа"""	Россия, Орловская область, Колпнянский район, поселок Вороново	0101000020E6100000FB90B75CFD764240EAE923F0872F4A40
70302	1	11	1062	48395	71993	\N	52.205717	с.Березовка, ул.Лесная, 3		0101000020E6100000E36F7B82C47C4240999D45EF541A4A40
70033	1	11	1062	9525	\N	\N	52.129472	"Орловская область, Колпнянский район, д.Белый Колодезь Первый, здание МОУ ""Дубовская средняя общеобразовательная школа"""	Россия, Орловская область, Колпнянский район, поселок Белый Колодезь 1-й	0101000020E6100000B60F79CBD58B4240B5DFDA8992104A40
70031	1	11	1062	9410	\N	\N	52.300268000000003	"Орловская область, Колпнянский район, с.Ахтырка, здание МОУ ""Ахтырская основная общеобразовательная школа"""	Россия, Орловская область, Колпнянский район, поселок Ахтырка	0101000020E6100000A58636001B76424086048C2E6F264A40
70147	1	11	1062	49569	\N	\N	52.174616999999998	д. Александровка, Здание  Дома культуры		0101000020E61000008E1F2A8D987B4240AE2990D959164A40
70354	1	11	7147	52112	\N	\N	50.767919999999997	"поселок Рождественский, здание МОУ ""Октябрьская средняя общеобразовательная школа"""	Россия, Воронежская область, Каменский район, поселок Рождественский	0101000020E61000007B849A2155E04340DFF8DA334B624940
56885	1	11	1166	11068	38045	\N	53.335500000000003	с. Узкое, Садовая, 2а		0101000020E61000001DB0ABC953C841406DE7FBA9F1AA4A40
56379	1	11	1166	45913	\N	\N	53.215423999999999	с. Селихово, Школьная, 1	Россия, Орловская область, Знаменский район, поселок Селихово	0101000020E610000086E3F90CA8DF414002637D03939B4A40
70422	1	11	1166	46202	\N	\N	53.254424	д. Прилепы, Здание прилепской средней шкоолы		0101000020E6100000273108AC1CD44140A4A833F790A04A40
56550	1	11	1166	26780	38142	\N	53.302923999999997	с. Мымрино, Школьная, 1а		0101000020E6100000BA68C87894BE41403596B036C6A64A40
70404	1	11	1166	45810	38124	\N	53.331789999999998	с. Локно, 1-ая Русская, 1а	Россия, Орловская область, Знаменский район, поселок Локно	0101000020E6100000336C94F59BE54140E6913F1878AA4A40
55925	1	11	1166	46026	38140	\N	53.372546999999997	с. Коптево, Центральная, 2		0101000020E61000005A2C45F295D44140889CBE9EAFAF4A40
70403	1	11	1166	45786	37871	\N	53.278331000000001	с. Знаменское, Совхозная, 3а		0101000020E61000008B4F01309ED74140433BA759A0A34A40
70401	1	11	1166	27320	38123	\N	53.213352999999998	с. Ждимир, Никольская, 8		0101000020E61000002385B2F0F5D1414072C0AE264F9B4A40
69897	1	11	1166	49288	\N	\N	53.239131999999998	село Гнездилово	Россия, Орловская область, Знаменский район, поселок Гнездилово	0101000020E610000026FC523F6FC64140AAB69BE09B9E4A40
69900	1	11	1166	49321	\N	\N	53.289779774409503	деревня Вязовая	Россия, Орловская область, Знаменский район, поселок Вязовая	0101000020E6100000C9022670EBC241407784D38217A54A40
70402	1	11	1166	45761	38073	\N	53.290013000000002	д. Ворошилово, Молодежная, 2		0101000020E6100000BC3D0801F9DC41401A355F251FA54A40
70369	1	11	973	61083	77159	\N	52.801729000000002	хут.Сеина, ул.Лесная, д.8	Россия, Орловская область, Залегощенский район	0101000020E6100000D7A3703D0A3742409DA04D0E9F664A40
70285	1	11	973	48045	\N	\N	52.990188000000003	дер.Становое, Здание сельского дома культуры	Россия, Орловская область, Залегощенский район, поселок Становое	0101000020E6100000A568E55E603642402272FA7ABE7E4A40
69999	1	11	973	54661	38649	\N	52.866033461456901	д. Слобода, ул. Малая Выгонская, 14	Россия, Орловская область, Залегощенский район, поселок Слобода	0101000020E61000002C62D8614C6C4240DE205A2BDA6E4A40
70009	1	11	973	8451	38007	\N	52.945856999999997	с. Сетуха, ул. Паршина, 2		0101000020E61000006DAB59677C634240A9D898D711794A40
70019	1	11	973	8881	38022	\N	52.910299999999999	д. Ржаное, ул. Школьная, 5		0101000020E6100000815EB873614E42403FC6DCB584744A40
70022	1	11	973	54664	38662	\N	52.873387999999998	д. Ржавец, ул. Школьная, 8	Россия, Орловская область, Залегощенский район, поселок Ржавец	0101000020E61000009B745B2217404240035C902DCB6F4A40
70023	1	11	973	9093	38109	\N	53.01829	д. Победное, ул. Центральная, 1		0101000020E61000001C7E37DDB253424003ECA35357824A40
70014	1	11	973	47272	38132	\N	52.768875999999999	д. Ольховец, ул. Молодежная, 5		0101000020E61000009B559FABAD644240F3565D876A624A40
70021	1	11	973	47434	37962	\N	52.854996593362202	с. Ломовое, пер. Почтовый, 1	Россия, Орловская область, Залегощенский район, поселок Ломовое	0101000020E610000085402E71E4474240CC96AC8A706D4A40
70012	1	11	973	54665	38675	\N	52.823419000000001	с. Красное, ул. Центральная, 21	Россия, Орловская область, Залегощенский район, поселок Красное	0101000020E61000005E126745D45E4240D8F335CB65694A40
70011	1	11	973	54618	38170	\N	52.853576131826401	д. Котлы, ул. Советская, 4	Россия, Орловская область, Залегощенский район, поселок Котлы	0101000020E6100000BE310400C7684240435376FA416D4A40
70016	1	11	973	47328	37976	\N	52.896906000000001	с. Казарь, ул. Октябрьская, 7		0101000020E6100000E23E726BD26D424008CBD8D0CD724A40
70024	1	11	973	47494	37984	\N	52.943398000000002	с. Золотарево, ул. Привокзальная, 9		0101000020E6100000AA4885B185324240508E0244C1784A40
70006	1	11	973	8137	36851	\N	52.901235	поселок Залегощь, ул. М. Горького, 10		0101000020E6100000EDB776A2247242405A8121AB5B734A40
70003	1	11	973	8137	37993	\N	52.901235	поселок Залегощь, ул.Ленина, 17		0101000020E6100000EDB776A2247242405A8121AB5B734A40
70005	1	11	973	8137	38052	\N	52.901235	поселок Залегощь, ул. Гагарина, 34		0101000020E6100000EDB776A2247242405A8121AB5B734A40
70004	1	11	973	8137	36972	\N	52.901235	поселок Залегощь, ул. М.Горького, 26		0101000020E6100000EDB776A2247242405A8121AB5B734A40
70013	1	11	973	8619	38110	\N	52.785724999999999	с. Верхнее Скворчее, ул. Центральная, 6		0101000020E6100000E7E44526E06F4240265305A392644A40
70015	1	11	973	54581	38010	\N	52.881323493832902	д. Васильевка, ул. Мира, 17	Россия, Орловская область, Залегощенский район, поселок Васильевка	0101000020E6100000E27492AD2E774240371B2B31CF704A40
69972	1	11	973	46421	\N	\N	53.039383999999998	д.Бычки, Здание СДК		0101000020E6100000BB97FBE4283E42402AFEEF880A854A40
70010	1	11	973	47201	74989	\N	52.884034999999997	с. Березовец, ул. Школьная, 2		0101000020E6100000DB519CA38E6642407AC2120F28714A40
70008	1	11	973	47150	38133	\N	52.915568	с. Архангельское, ул. Привокзальная, 3		0101000020E6100000A8E507AEF25C4240CFA10C5531754A40
69895	1	11	6867	40185	\N	\N	52.139145999999997	деревня Козюлькина	Россия, Курская область, Железногорский район, поселок Козюлькина	0101000020E6100000C9AF1F6283C7414042AF3F89CF114A40
69998	1	11	896	7875	\N	\N	52.079604000000003	Орловская область, Должанский район, Урыновское сельское поселение, с.Урынок, помещение Урыновской средней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Урынок	0101000020E6100000AA9A20EA3EAC4240BE50C076300A4A40
69978	1	11	896	6968	\N	\N	52.182187999999996	Орловская область, Должанский район, Дубровское сельское поселение,  с. Тим, помещение Тимского сельского Дома культуры	Россия, Орловская область, Должанский район, поселок Тим	0101000020E61000000A9FAD8383A94240A0DCB6EF51174A40
69983	1	11	896	7218	\N	\N	52.169899999999998	Орловская область, Должанский район, Вышнее Ольшанское сельское поселение, с.Студеное, помещение Студеновской основной общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Студеное	0101000020E6100000DC847B65DECE424092CB7F48BF154A40
69987	1	11	896	7400	\N	\N	52.091932999999997	Орловская область, Должанский район, Рогатинское сельское поселение, с.Рогатик, помещение Рогатинской основной общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Рогатик	0101000020E6100000C460FE0A99DF42402A36E675C40B4A40
70001	1	11	896	52405	\N	\N	52.022857999999999	Орловская область, Должанский район, Урыновское сельское поселение д.Петровка, помещение Егорьевской основной общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Петровка	0101000020E6100000EA40D653AB9D4240DA39CD02ED024A40
69981	1	11	896	7099	\N	\N	52.106152000000002	Орловская область, Должанский район, Кудиновское сельское поселение, с. Никольское, помещение Никольского сельского Дома культуры	Россия, Орловская область, Должанский район, поселок Никольское	0101000020E610000035EB8CEF8BC14240D7338463960D4A40
69986	1	11	896	7505	\N	\N	52.142766000000002	Орловская область, Должанский район, Вышнее Ольшанское сельское поселение, с.Нижнее Ольшаное, помещение Нижнеольшанского сельского клуба	Россия, Орловская область, Должанский район, поселок Нижнее Ольшаное	0101000020E61000009E280989B4DD4240897D022846124A40
69982	1	11	896	7146	\N	\N	52.159692	Орловская область, Должанский район, Кудиновское сельское поселение, с. Кривцово-Плота, помещение Кривцово-Плотской средней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Кривцово-Плота	0101000020E6100000C43F6CE9D1C0424067B796C970144A40
69989	1	11	896	7501	\N	\N	52.016556000000001	Орловская область, Должанский район, Козьма-Демьяновское сельское поселение, с.Козьма-Демьяновское, помещение Козьма-Демьяновской средней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Козьма-Демьяновское	0101000020E610000040A20914B1CE4240BB46CB811E024A40
69959	1	11	832	6004	\N	\N	52.587318000000003	дер.Рублино, Здание сельского ДК	Россия, Орловская область, Дмитровский район, поселок Рублино	0101000020E610000092CD55F31C8B4140132D793C2D4B4A40
69990	1	11	896	52385	\N	\N	52.042293999999998	Орловская область, Должанский район, Козьма-Демьяновское сельское поселение, д.Калиновка, помещение бывшей начальной школы	Россия, Орловская область, Должанский район, поселок Калиновка	0101000020E6100000F54718062CCB42409468C9E369054A40
69988	1	11	896	7427	\N	\N	52.023833000000003	Орловская область, Должанский район, Козьма-Демьяновское сельское поселение, с.Знаменское, помещение Знаменской основной общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Знаменское	0101000020E61000004F9143C4CDD9424065C8B1F50C034A40
69979	1	11	896	52375	\N	\N	52.220930000000003	Орловская область, Должанский район, Кудиновское сельское поселение, д.Евланово, помещение Евлановской основной общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Евланово	0101000020E6100000DF18028063B34240475A2A6F471C4A40
70205	1	11	896	46479	\N	\N	52.095568999999998	д. Дубровка, здание Дубровской школы		0101000020E61000005E30B8E68EA8424076C1E09A3B0C4A40
69977	1	11	896	46479	\N	\N	52.095568999999998	Орловская область, Должанский район, Дубровское сельское поселение, д. Дубровка, помещение Дубровской средней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Дубровка	0101000020E61000005E30B8E68EA8424076C1E09A3B0C4A40
69991	1	11	896	7581	38008	\N	52.058334000000002	Орловская область, Должанский район, поселок Долгое, помещение Фроловскойо Дома культуры, Луговая	Россия, Орловская область, Должанский район, поселок Долгое	0101000020E610000074B4AA251DC34240581F0F7D77074A40
69993	1	11	896	7581	36937	\N	52.058334000000002	Орловская обл, Должанский р-н, п. Долгое, ул. Ленина 24		0101000020E610000074B4AA251DC34240581F0F7D77074A40
69992	1	11	896	7581	36937	\N	52.058334000000002	Орловская область, Должанский район, поселок Долгое, помещение районного Дома культуры, Ленина		0101000020E610000074B4AA251DC34240581F0F7D77074A40
69996	1	11	896	52395	\N	\N	52.036472000000003	Орловская область, Должанский район, Успенское сельское поселение, д.Гремячка, помещение Гремячинского филиала Должанской средней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Гремячка	0101000020E610000001A777F17EBA4240209C4F1DAB044A40
70002	1	11	896	8069	\N	\N	52.062420000000003	Орловская область, Должанский район, Урыновское сельское поселение, д.Вышняя Замарайка Первая, помещение Замарайского сельского клуба	Россия, Орловская область, Должанский район, поселок Вышняя Замарайка 1-я	0101000020E6100000A14D0E9F74A44240E44EE960FD074A40
69985	1	11	896	52380	\N	\N	52.125374999999998	Орловская область, Должанский район, Вышнее Ольшанское сельское поселение. с.Вышнее Ольшаное, помещение Вышнеольшанской средней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Вышнее Ольшаное	0101000020E610000007B309302CD34240355EBA490C104A40
69997	1	11	896	7842	\N	\N	52.059873000000003	Орловская область, Должанский район, Урыновское сельское поселение, с.Вышнее Долгое. помещение Вышне-Должанской основной общеобразовательной школы		0101000020E6100000BC9179E40FB04240EB7420EBA9074A40
69994	1	11	896	52390	\N	\N	51.991889999999998	Орловская область, Должанский район, Успенское сельское поселение, д. Выгон,  помещение Успенского филиала Алексеевской  средней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Выгон	0101000020E610000092CEC0C8CBB442405E9D6340F6FE4940
70000	1	11	896	54600	\N	\N	52.044024819189097	Орловская область, Должанский район, Урыновское сельское поселение, д.Быстра. помещение Быстринской основной общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Быстра	0101000020E6100000DD408177F2A942406B9A779CA2054A40
69984	1	11	896	7242	\N	\N	52.192005000000002	Орловская область, Должанский район, Вышнее Ольшанское сельское поселение, с.Баранчик, помещение Баранчинского сельского клуба	Россия, Орловская область, Должанский район, поселок Баранчик	0101000020E6100000CFD90242EBCD424091D5AD9E93184A40
69995	1	11	896	52392	\N	\N	52.011130000000001	Орловская область, Должанский район, Успенское сельское поселение, д.Алексеевка, помещение Алексеевской српедней общеобразовательной школы	Россия, Орловская область, Должанский район, поселок Алексеевка	0101000020E6100000D40D147827AD4240930035B56C014A40
69955	1	11	832	54620	\N	\N	52.519183629025797	пос.Занеруссовский, дом досуга	Россия, Орловская область, Дмитровский район	0101000020E6100000613255302A9D4140A14D0E9F74424A40
69970	1	11	832	6567	\N	\N	52.457152999999998	Дмитровский д. Хальзево, здание администрации	Россия, Орловская область, Дмитровский район, поселок Хальзево	0101000020E61000005646239F57B24140572250FD833A4A40
69957	1	11	832	46077	\N	\N	52.407501000000003	с.Упорой, Здание Упоройского медпункта	Россия, Орловская область, Дмитровский район, поселок Упорой	0101000020E61000005E2C0C91D37341402D0B26FE28344A40
69963	1	11	832	54588	\N	\N	52.396176911497101	пос.Артель Труд, Долбенкинский СДК	Россия, Орловская область, Дмитровский район, поселок Труд	0101000020E6100000B82231410DAD4140B5368DEDB5324A40
69961	1	11	832	6085	\N	\N	52.489759999999997	"пос.Сторожище, здание правления СПК ""Память Ленина"	Россия, Орловская область, Дмитровский район, поселок Сторожище	0101000020E610000098141F9F908B4140C971A774B03E4A40
69974	1	11	832	6775	\N	\N	52.68188	с.Работьково, Административное здание		0101000020E61000006170CD1DFD934140F3E505D847574A40
69969	1	11	832	46365	\N	\N	52.435718999999999	с.Плоское, Административное здание		0101000020E610000031D28BDAFDBE4140779FE3A3C5374A40
69964	1	11	832	54579	\N	\N	52.416091999999999	с.Мало-Боброво, Здание школы	Россия, Орловская область, Дмитровский район, поселок Малое Боброво	0101000020E6100000A3E5400FB59741404910AE8042354A40
69966	1	11	832	46291	\N	\N	52.560276000000002	с.Лубянки, Здание средней школы	Россия, Орловская область, Дмитровский район, поселок Лубянки	0101000020E6100000BA2EFCE07CB44140EA5DBC1FB7474A40
69967	1	11	832	6392	\N	\N	52.569209999999998	с.Крупышино, Здание СДК	Россия, Орловская область, Дмитровский район, поселок Крупышино	0101000020E6100000A88FC01F7EBE414030478FDFDB484A40
69973	1	11	832	46445	\N	\N	52.622025000000001	пос.Красное Знамя, Здание СДК		0101000020E6100000A6423C122FA34140AF25E4839E4F4A40
69971	1	11	832	6628	\N	\N	52.554724	дер.Дружно, Здание администрации	Россия, Орловская область, Дмитровский район, поселок Дружно	0101000020E6100000533F6F2A5297414035272F3201474A40
69965	1	11	832	6316	\N	\N	52.467830999999997	с.Домаха, Здание СДК	Россия, Орловская область, Дмитровский район, поселок Домаха	0101000020E6100000EF3CF19C2D7A41400987DEE2E13B4A40
69975	1	11	832	6843	36879	\N	52.507801999999998	г.Дмитровск, Социалистическая, 63		0101000020E6100000F6CFD38041924140F46BEBA7FF404A40
69976	1	11	832	6843	36871	\N	52.507801999999998	Орловская область, Дмитровский район, город Дмитровск, Советская, 152 А		0101000020E6100000F6CFD38041924140F46BEBA7FF404A40
69956	1	11	832	46050	\N	\N	52.396158862850399	с.Девятино, Здание Девятинского СДК	Россия, Орловская область, Дмитровский район, поселок Девятино	0101000020E6100000D923D40CA98241400E828E56B5324A40
69960	1	11	832	46145	\N	\N	52.515529999999998	дер.Горбуновка, Здание администрации	Россия, Орловская область, Дмитровский район, поселок Горбуновка	0101000020E6100000F62686E464964140AE0D15E3FC414A40
69968	1	11	832	6472	\N	\N	52.545847999999999	дер.Брусовец, Здание СДК	Россия, Орловская область, Дмитровский район, поселок Брусовец	0101000020E6100000C9AD49B725BA4140234BE658DE454A40
69958	1	11	832	46101	\N	\N	52.625140999999999	с.Бородино, Здание школы	Россия, Орловская область, Дмитровский район, поселок Бородино	0101000020E61000002A5778978B8E4140C231CB9E04504A40
69954	1	11	832	46015	\N	\N	52.484867999999999	дер.Алешинка, Здание Алешинского СДК	Россия, Орловская область, Дмитровский район, поселок Алешинка	0101000020E610000089230F44168941403F709527103E4A40
69940	1	11	691	4999	\N	\N	52.469137000000003	пос. Техникумовский, Здание Глазуновского с/х техникума	Россия, Орловская область, Глазуновский район, поселок Техникумовский	0101000020E61000003B8908FF222E4240FA2B64AE0C3C4A40
69953	1	11	691	5682	\N	\N	52.424802999999997	"п. Тагинский, помещение бывшей столовой х/п ""Тагино"""	Россия, Орловская область, Глазуновский район, поселок Тагинский	0101000020E6100000B72A89EC830C4240101FD8F15F364A40
69952	1	11	691	5645	\N	\N	52.413944000000001	с. Тагино, помещение Тагинской средней школы	Россия, Орловская область, Глазуновский район, поселок Тагино	0101000020E61000006075E448670842400E30F31DFC344A40
69951	1	11	691	54613	\N	\N	52.362471999999997	д. Степная, помещение Хуторо-Подолянского дома культуры	Россия, Орловская область, Глазуновский район, поселок Степная	0101000020E61000004A97FE25A91442409CDB847B652E4A40
69950	1	11	691	54607	\N	\N	52.422799711614701	д. Сеньково, помещение Сеньковского дома культуры	Россия, Орловская область, Глазуновский район, поселок Сеньково	0101000020E610000082A8FB00A4144240D95F764F1E364A40
70262	1	11	691	47618	\N	\N	52.458843999999999	с.Сабурово, Здание школы		0101000020E610000036E50AEF72334240A0FB7266BB3A4A40
69947	1	11	691	60481	\N	\N	52.515332999999998	д. Отрада, помещение Отрадинской сельской администрации	Россия, Орловская область, Глазуновский район, поселок Отрада	0101000020E6100000992842EA7628424058C6866EF6414A40
69946	1	11	691	52328	\N	\N	52.531004000000003	д. Новополево, помещение Новополевского дома культуры	Россия, Орловская область, Глазуновский район, поселок Новополево	0101000020E6100000C901BB9A3C2B4240C90567F0F7434A40
69949	1	11	691	60459	\N	\N	52.384585000000001	д. Никольское, помещение Очкинской основной школы	Россия, Орловская область, Глазуновский район, поселок Никольское	0101000020E610000023F8DF4A761E42401EC4CE143A314A40
69944	1	11	691	52322	\N	\N	52.49953	д. Ловчиково, помещение Ловчиковской школы	Россия, Орловская область, Глазуновский район, поселок Ловчиково	0101000020E610000043AD69DE711E424079AF5A99F03F4A40
69925	1	11	691	54611	\N	\N	52.484718527877298	с. Красная Слободка, Помещение Краснослободского дома культуры	Россия, Орловская область, Глазуновский район, поселок Красная Слободка	0101000020E610000085CD001764374240FA5FAE450B3E4A40
70390	1	11	691	45534	37971	\N	52.416488000000001	с. Ильинское, ул. Школьная, д.17		0101000020E610000047C8409E5D2242409696917A4F354A40
70316	1	11	691	48622	72243	\N	52.544632	д. Ивановка, ул.Школьная, 18		0101000020E610000087890629782C4240732D5A80B6454A40
69943	1	11	691	54610	\N	\N	52.485607999999999	д. Гремячево, Помещение Гремячевского дома культуры	Россия, Орловская область, Глазуновский район, поселок Гремячево	0101000020E6100000E8A04B38F414424086562767283E4A40
69942	1	11	691	54595	\N	\N	52.509748000000002	д. Гнилуша, Помещение Гнилушинской школы	Россия, Орловская область, Глазуновский район, поселок Гнилуша	0101000020E6100000D3F4D901D70D4240C899266C3F414A40
69937	1	11	691	4828	37974	\N	52.497557	п.Глазуновка, ул. Советская, 4		0101000020E610000007B64AB0382A4240AC72A1F2AF3F4A40
69939	1	11	691	4828	37983	\N	52.497557	п. Глазуновка, ул. Привокзальная, № 4		0101000020E610000007B64AB0382A4240AC72A1F2AF3F4A40
70442	1	11	691	4828	37952	\N	52.497557	п. Глазуновка, Ленина, 17		0101000020E610000007B64AB0382A4240AC72A1F2AF3F4A40
70441	1	11	691	4828	37952	\N	52.497557	п.Глазуновка, ул. Ленина, 67		0101000020E610000007B64AB0382A4240AC72A1F2AF3F4A40
69938	1	11	691	4828	37952	\N	52.497557	п. Глазуновка, ул. Ленина, 174		0101000020E610000007B64AB0382A4240AC72A1F2AF3F4A40
69941	1	11	691	45747	\N	\N	52.508190999999997	с. Богородское, Помещение Богородской сельской администрации	Россия, Орловская область, Глазуновский район, поселок Богородское	0101000020E6100000609335EA210642408E8F16670C414A40
70296	1	11	603	22425	\N	\N	52.611488999999999	д.Юдинка, 4		0101000020E610000066FA25E2AD9942408F6E8445454E4A40
69915	1	11	603	49535	\N	\N	52.826569999999997	д. Туровка, здание Туровского сельского клуба	Россия, Орловская область, Верховский район, поселок Туровка	0101000020E61000009B00C3F2E78D424067EDB60BCD694A40
69931	1	11	603	4511	\N	\N	52.635013000000001	с. Теляжье, здание администрации Теляженского сельского поселения	Россия, Орловская область, Верховский район, поселок Теляжье	0101000020E61000003CF71E2E39A4424076C4211B48514A40
69918	1	11	603	3806	\N	\N	52.781830999999997	д. Сухотиновка, здание администрации Песоченского сельского поселения	Россия, Орловская область, Верховский район, поселок Сухотиновка	0101000020E610000042E90B21E7A74240DEFFC70913644A40
69919	1	11	603	54602	\N	\N	52.816380834885997	п. Суровцев, здание Галичинского сельского клуба	Россия, Орловская область, Верховский район	0101000020E610000065506D7022A04240B309302C7F684A40
69926	1	11	603	4246	\N	\N	52.718153999999998	п. Скорятино, здание администрации Васильевского сельского поселения	Россия, Орловская область, Верховский район, поселок Скорятино	0101000020E61000007099D36531A94240ECBE6378EC5B4A40
69924	1	11	603	45430	\N	\N	52.770139999999998	с. Скородное, здание администрации Скородненского сельского поселения	Россия, Орловская область, Верховский район, поселок Скородное	0101000020E61000008CA19C68578D4240B4AB90F293624A40
69932	1	11	603	4545	37943	\N	52.602701000000003	с. Русский Брод, Кооперативная, 41		0101000020E6100000346953758FAE42401D226E4E254D4A40
69933	1	11	603	4545	36929	\N	52.602701000000003	с. Русский Брод, Гайтеровой, 40		0101000020E6100000346953758FAE42401D226E4E254D4A40
69934	1	11	603	4656	38041	\N	52.550770999999997	д. Прусынок, Центральная, 21А		0101000020E61000005FEE93A300BD4240E84A04AA7F464A40
69917	1	11	603	49572	\N	\N	52.881974999999997	"с. Песочное, здание МОУ ""Песоченская основная общеобразовательная школа"""	Россия, Орловская область, Верховский район, поселок Песочное	0101000020E610000059BE2EC37F9A4240DE718A8EE4704A40
69935	1	11	603	4746	38084	\N	52.552903650272	с. Пеньшино, Молодежная, 5	Россия, Орловская область, Верховский район, поселок Пеньшино	0101000020E610000041F33977BBAA4240EEE9EA8EC5464A40
69962	1	11	603	60415	\N	\N	52.800310563170797	дер.Круглое, Административное здание	Россия, Орловская область, Верховский район, поселок Круглое	0101000020E61000006B44300E2E99424085D0419770664A40
69922	1	11	603	4013	\N	\N	52.720134000000002	с. Корсунь, здание администрации Корсунского сельского поселения	Россия, Орловская область, Верховский район, поселок Корсунь	0101000020E6100000853E58C6868042406C5ED5592D5C4A40
69929	1	11	603	45515	\N	\N	52.661326000000003	с. Коньшино, здание Коньшинского сельского клуба	Россия, Орловская область, Верховский район, поселок Коньшино	0101000020E61000009DBD33DAAAAE42404CFF9254A6544A40
70063	1	11	603	48215	37963	\N	52.761318000000003	пос.Ключики, Школьная, 4		0101000020E61000003197546D378B424096ED43DE72614A40
69921	1	11	603	45375	\N	\N	52.760866	"д. Карповка, здание МОУ ""Карповская основная общеобразовательная школа"	Россия, Орловская область, Верховский район, поселок Карповка	0101000020E610000048A46DFC89AC4240B5519D0E64614A40
69920	1	11	603	54609	38139	\N	52.798473000000001	д. Долгое, Славянская, 6	Россия, Орловская область, Верховский район, поселок Долгое	0101000020E6100000363B527DE79B424098DEFE5C34664A40
69913	1	11	603	49500	36848	\N	52.814352999999997	п. Верховье, Ленина, 2		0101000020E610000032E6AE25E49D4240223317B83C684A40
69914	1	11	603	49500	36909	\N	52.814977081104203	п. Верховье, Коминтерна, 29	Россия, Орловская область, Верховский район, поселок Верховье	0101000020E61000006A87BF266B9E424000FF942A51684A40
69923	1	11	603	4073	\N	\N	52.794553000000001	с. Верхняя Залегощь, здание Верхне-Залегощенского сельского клуба	Россия, Орловская область, Верховский район, поселок Верхняя Залегощь	0101000020E610000043E4F4F57C7F424027F8A6E9B3654A40
69928	1	11	603	4351	\N	\N	52.678095999999996	"д. Большой Синковец, здание МОУ ""Синковская основная общеобразовательная школа"""	Россия, Орловская область, Верховский район, поселок Большой Синковец	0101000020E610000026C45C52B59D424032C687D9CB564A40
70067	1	11	434	48291	\N	\N	53.472842	дер.Выселки, здание Лысовского сельского клуба		0101000020E61000001BF2CF0CE20542406E162F1686BC4A40
69893	1	11	434	2426	\N	\N	53.472397000000001	село Фатнево	Россия, Орловская область, Болховский район, поселок Фатнево	0101000020E6100000F2E9B12D031E424040DD408177BC4A40
31838	1	11	434	10840	\N	\N	53.578935000000001	село Середичи	Россия, Орловская область, Болховский район, поселок Середичи	0101000020E6100000925A28999CEC414040C1C58A1ACA4A40
69902	1	11	434	2958	\N	\N	53.518073999999999	село Репнино	Россия, Орловская область, Болховский район, поселок Репнино	0101000020E6100000B5E0455F411242403674B33F50C24A40
69892	1	11	434	2386	\N	\N	53.528281999999997	деревня Пальчикова	Россия, Орловская область, Болховский район, поселок Пальчикова	0101000020E610000098F8A3A8331D424061889CBE9EC34A40
69906	1	11	434	3178	\N	\N	53.418165999999999	село Однолуки	Россия, Орловская область, Болховский район, поселок Однолуки	0101000020E610000098A432C51C0E42404A26A77686B54A40
69904	1	11	434	3062	\N	\N	53.306379	деренвя Новый Синец	Россия, Орловская область, Болховский район, поселок Новый Синец	0101000020E61000004F5AB8ACC21042403197546D37A74A40
31907	1	11	434	14061	\N	\N	53.479064000000001	село Кривчее	Россия, Орловская область, Болховский район, поселок Кривчее	0101000020E6100000C364AA6054FE414071581AF851BD4A40
70146	1	11	434	49553	\N	\N	53.237600999999998	с. Каменка, Здание Дома Культуры		0101000020E610000039D6C56D340C42409A3FA6B5699E4A40
69916	1	11	434	49553	\N	\N	53.239091943883601	с. Каменка, здание Каменского сельского клуба	Россия, Орловская область, Болховский район, поселок Каменка	0101000020E610000099F38C7DC90C42401C5E10919A9E4A40
69899	1	11	434	2755	\N	\N	53.275129428515903	село Злынь	Россия, Орловская область, Болховский район, поселок Злынь	0101000020E61000008B355CE49EF441403197546D37A34A40
69896	1	11	434	49274	\N	\N	53.592416	деревня Герасимова	Россия, Орловская область, Болховский район, поселок Герасимова	0101000020E610000084BD892139F9414046D09849D4CB4A40
69927	1	11	434	45485	\N	\N	53.340682999999999	"п. Васильевский, здание МОУ ""Васильевская основная общеобразовательная школа"""		0101000020E6100000EB5223F433074240CEA623809BAB4A40
69948	1	11	434	60516	\N	\N	53.448058000000003	д. Васильевка, помещение Васильевского дома культуры	Россия, Орловская область, Болховский район, поселок Васильевка	0101000020E6100000809F71E140E04140085BECF659B94A40
69894	1	11	434	49256	\N	\N	53.366776999999999	село Борилово	Россия, Орловская область, Болховский район, поселок Борилово	0101000020E61000009F1D705D31FB414066F6798CF2AE4A40
69898	1	11	434	2716	\N	\N	53.347327999999997	село Большая Чернь	Россия, Орловская область, Болховский район, поселок Большая Чернь	0101000020E61000003CA06CCA15EC4140177E703E75AC4A40
69911	1	11	434	3310	36839	\N	53.446351999999997	город Болхов, переулок Земляной, 9		0101000020E610000032AF230ED90042408940F50F22B94A40
69910	1	11	434	3310	36843	\N	53.446351999999997	город Болхов, Ленина, 165		0101000020E610000032AF230ED90042408940F50F22B94A40
69908	1	11	434	3310	36843	\N	53.446351999999997	город Болхов, Ленина, 22		0101000020E610000032AF230ED90042408940F50F22B94A40
69909	1	11	434	3310	36740	\N	53.446351999999997	город Болхов, Василия Ермакова, 19		0101000020E610000032AF230ED90042408940F50F22B94A40
70020	1	11	434	8948	74967	\N	53.562350293246801	д. Алешня, пер. Школьный, 7	Россия, Орловская область, Болховский район, поселок Алешня	0101000020E61000000490DAC4C9F74140EB73B515FBC74A40
57824	1	10	\N	62013	80876	\N	56.295189999999998	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул. Бусалова, помещение красного уголка общежития, 8		0101000020E61000003A02B859BCBC4240990D32C9C8254C40
58557	1	10	\N	62016	80905	\N	55.961757307891801	д.Яковлево, ул.Школьная, д.33	Россия, Московская область, Химки, квартал Яковлево	0101000020E6100000C3EFA65B76BA42407BD976DA1AFB4B40
60261	1	10	\N	11204	4186	\N	55.93535	Московская область, город Юбилейный, Школьный проезд, 2	Россия, Московская область, Юбилейный, Школьный проезд, 2	0101000020E61000007522C15433ED424024287E8CB9F74B40
60259	1	10	\N	11204	71925	\N	55.937070659567802	Московская область, город Юбилейный, М.К.Тихонравова, 24/1	Россия, Московская область, Юбилейный, улица Тихонравова, 24/1	0101000020E61000003E5C72DC29EB4240D88349F1F1F74B40
60257	1	10	\N	11204	71805	\N	55.938113573632997	город Юбилейный, М.К.Тихонравова, 19		0101000020E610000022895E46B1EA4240BAF59A1E14F84B40
60260	1	10	\N	11204	4172	\N	55.934139000000002	Московская область, город Юбилейный, Лесная, 22	Россия, Московская область, Юбилейный, Лесная улица, 22	0101000020E6100000B519A721AAEC42408675E3DD91F74B40
60262	1	10	\N	11204	80566	\N	55.927683999999999	Московская область, город Юбилейный, Комитетская, 31	Россия, Московская область, Юбилейный, Комитетская улица, 31	0101000020E6100000CC96AC8A70ED4240E0826C59BEF64B40
60258	1	10	\N	11204	71863	\N	55.932001	Московская область, город Юбилейный, АМ.К.Тихонравова, 19		0101000020E61000000AD80E46ECEB42406E6B0BCF4BF74B40
60183	1	10	\N	11204	71862	\N	55.934723811628203	Московская область, город Юбилейный, А.И.Соколова, 3	Россия, Московская область, Юбилейный, Лесная улица, 3	0101000020E6100000D061BEBC00EB4240A6643909A5F74B40
58967	1	10	\N	61947	80677	\N	55.720165000000001	г.Электроугли, Маяковского, 34 (МОУ СОШ № 30, новое здание)		0101000020E61000001684F23E8E1C4340A75CE15D2EDC4B40
60234	1	10	\N	13377	3847	\N	55.768571999999999	Московская область, городской округ Электросталь, Ялагина, 22а	Россия, Московская область, Электросталь, улица Ялагина, 22а	0101000020E6100000242713B70A364340874F3A9160E24B40
60242	1	10	\N	13377	3955	\N	55.778689	Московская область, городской округ Электросталь, Тевосяна, 23	Россия, Московская область, Электросталь, улица Тевосяна, 23	0101000020E6100000BE310400C7384340A260C614ACE34B40
60254	1	10	\N	13377	4108	\N	55.807299	Московская область, городской округ Электросталь, Сталеваров, 19	Россия, Московская область, Электросталь, улица Сталеваров, 19	0101000020E61000005AD6FD6321364340F88BD99255E74B40
60243	1	10	\N	13377	3972	\N	55.784972000000003	Московская область, городской округ Электросталь, Корешкова, 16	Россия, Московская область, Электросталь, улица Корешкова, 16	0101000020E610000059DB148F8B3843404B2366F679E44B40
60253	1	10	\N	13377	3985	\N	55.804253000000003	Московская область, городской округ Электросталь, Ленина проспект, 2 кор 4	Россия, Московская область, Электросталь, проспект Ленина, 2к4	0101000020E61000007BD7A02FBD374340DE5A26C3F1E64B40
60245	1	10	\N	13377	3985	\N	55.790084	Московская область, городской округ Электросталь, Ленина проспект, 32а	Россия, Московская область, Электросталь, проспект Ленина, 32а	0101000020E61000005FD218ADA3384340E38BF67821E54B40
60247	1	10	\N	13377	81048	\N	55.789300267907997	Электросталь,пр-зд Чернышевского, д.22	Россия, Московская область, Электросталь, проезд Чернышевского, 22	0101000020E610000079E6E5B0FB384340CC5D4BC807E54B40
60235	1	10	\N	13377	80564	\N	55.769413	Московская область, городской округ Электросталь, Ялагина, 14		0101000020E610000037C30DF8FC364340020F0C207CE24B40
94656	1	10	\N	96	80079	\N	55.890867570119902	Московская область, городской округ Химки, 9 Мая 3а	Россия, Московская область, Химки, улица 9 Мая, 3	0101000020E6100000D8BB3FDEABB64240C6866EF607F24B40
60233	1	10	\N	13377	79829	\N	55.766407680225797	Московская область, городской округ Электросталь, Южный проспект, 7	Россия, Московская область, Электросталь, Южный проспект, 7	0101000020E610000030DAE3857438434046B247A819E24B40
60244	1	10	\N	13377	71920	\N	55.790959776150899	Московская область, городской округ Электросталь, Советская, 3	Россия, Московская область, Электросталь, Советская улица, 3	0101000020E6100000793C2D3F70374340DA38622D3EE54B40
60241	1	10	\N	13377	71820	\N	55.782024606822297	Московская область, городской округ Электросталь, Радио, 36	Россия, Московская область, Электросталь, улица Радио, 36	0101000020E6100000E2AE5E4546394340C3D32B6519E44B40
60252	1	10	\N	13377	79836	\N	55.799186563720603	Московская область, городской округ Электросталь, Пушкина, 23а	Россия, Московская область, Электросталь, улица Пушкина, 23а	0101000020E6100000626534F279374340B63176C24BE64B40
60251	1	10	\N	13377	79836	\N	55.800604958533903	Московская область, городской округ Электросталь, Пушкина, 30	Россия, Московская область, Электросталь, улица Пушкина, 30	0101000020E6100000FCC8AD49B7374340CD0182397AE64B40
60250	1	10	\N	13377	79836	\N	55.792451572843703	Московская область, городской округ Электросталь, Пушкина, 6	Россия, Московская область, Электросталь, улица Пушкина, 6	0101000020E6100000BE50C076303843402CD32F116FE54B40
60232	1	10	\N	13377	71959	\N	55.769156282543797	Московская область, городской округ Электросталь, Победы, 12 кор 3		0101000020E61000003201BF4692384340D7C22CB473E24B40
60248	1	10	\N	13377	79835	\N	55.7930463865722	Московская область, городской округ Электросталь, Первомайская, 7	Россия, Московская область, Электросталь, Первомайская улица, 7	0101000020E61000001F49490F433943409F1C058882E54B40
60238	1	10	\N	13377	71802	\N	55.774469877891697	Московская область, городской округ Электросталь, Мира, 24в	Россия, Московская область, Электросталь, улица Мира, 24в	0101000020E61000003480B74082384340D7DD3CD521E34B40
60246	1	10	\N	13377	81058	\N	55.784972000000003	Электросталь, Корешкова, д.16		0101000020E610000059DB148F8B3843404B2366F679E44B40
60227	1	10	\N	13377	80580	\N	55.802875736382703	Московская область, городской округ Электросталь, Комсомольская, 4а	Россия, Московская область, Электросталь, Комсомольская улица, 4	0101000020E61000005E6919A9F73C4340245F09A4C4E64B40
60231	1	10	\N	13377	79920	\N	55.794057000000002	Московская область, городской округ Электросталь, Карла Маркса, 9	Россия, Московская область, Электросталь, улица Карла Маркса, 9	0101000020E6100000EE04FBAF733B43407714E7A8A3E54B40
60230	1	10	\N	13377	79920	\N	55.798149717429503	Московская область, городской округ Электросталь, Карла Маркса, 23	Россия, Московская область, Электросталь, улица Карла Маркса, 23	0101000020E6100000D1B1834A5C3B4340B5A679C729E64B40
60236	1	10	\N	13377	79834	\N	55.771055354392097	Московская область, городской округ Электросталь, Западная, 1а	Россия, Московская область, Электросталь, Западная улица, 1а	0101000020E610000055151A8865374340693524EEB1E24B40
60229	1	10	\N	13377	79828	\N	55.801703000000003	Московская область, городской округ Электросталь, Загонова, 18		0101000020E6100000D9CD8C7E343C4340740D33349EE64B40
60237	1	10	\N	13377	80614	\N	55.774796000000002	Московская область, городской округ Электросталь, Журавлева, 5		0101000020E61000003AEAE8B81A3743402B89EC832CE34B40
60240	1	10	\N	13377	79816	\N	55.781065525641303	Московская область, городской округ Электросталь, 1-я Поселковая, 20	Россия, Московская область, Электросталь, 1-я Поселковая улица	0101000020E61000009FCA694FC93943403F027FF8F9E34B40
60225	1	10	\N	13129	71445	\N	55.869709094385001	Московская область, городской округ Электрогорск, Советская, 36а	Россия, Московская область, Электрогорск, Советская улица, 36а	0101000020E61000007769C36169644340B804E09F52EF4B40
60222	1	10	\N	13129	72185	\N	55.8742975535475	Московская область, городской округ Электрогорск, Советская, 47	Россия, Московская область, Электрогорск, Советская улица, 47	0101000020E6100000B1F9B83654644340A77A32FFE8EF4B40
60221	1	10	\N	13129	71804	\N	55.890845431752702	Московская область, городской округ Электрогорск, Ленина, 34		0101000020E610000000C974E8F46243400E677E3507F24B40
60224	1	10	\N	13129	79989	\N	55.875475999999999	Московская область, городской округ Электрогорск, Кржижановского, 13		0101000020E6100000406A1327F76343406937FA980FF04B40
60223	1	10	\N	13129	74097	\N	55.881078348755899	Московская область, городской округ Электрогорск, М.Горького, 5		0101000020E6100000A0A52BD846644340D09CF529C7F04B40
60206	1	10	\N	618	80036	\N	55.500600006598098	Московская область, городской округ Щербинка, Театральная, 1А	Россия, Московская область, Щербинка, Театральная улица, 1а	0101000020E610000053EBFD463BC8424055302AA913C04B40
60218	1	10	\N	618	80578	\N	55.502925052190001	Московская область, городской округ Щербинка, Новостроевская, 4	Россия, Московская область, Щербинка, Новостроевская улица	0101000020E610000032E719FB92C742409FABADD85FC04B40
60219	1	10	\N	618	79815	\N	55.510612373435002	Московская область, городской округ Щербинка, Молодежная, 1	Россия, Московская область, Щербинка, Молодежная улица	0101000020E61000001AF7E6374CC44240FB78E8BB5BC14B40
60220	1	10	\N	618	79825	\N	55.5147603318309	Московская область, городской округ Щербинка, Авиаторов, 9	Россия, Московская область, Щербинка, улица Авиаторов	0101000020E61000008A3DB48F15C44240FDA4DAA7E3C14B40
60215	1	10	\N	618	71799	\N	55.510565473929603	Московская область, городской округ Щербинка, 40 лет Октября, 8		0101000020E61000005019FF3EE3C84240BABDA4315AC14B40
60214	1	10	\N	618	71800	\N	55.511559388964997	Московская область, городской округ Щербинка, 40 лет Октября, 5/1	Россия, Московская область, Щербинка, улица 40 Лет Октября, 5	0101000020E6100000C808A87004C94240BB7CEBC37AC14B40
60124	1	10	\N	60268	81065	\N	55.943235000000001	Щелково, Проспект 60 лет Октября, 10		0101000020E6100000AEEFC34142FC4240A6B8AAECBBF84B40
60141	1	10	\N	60268	80543	\N	55.922609999999999	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, площадь Ленина, 5 (ООО ""Агростройпроект"")"		0101000020E6100000DFA5D425E3FE4240357BA01518F64B40
60146	1	10	\N	60268	80545	\N	55.919441579651703	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Центральная, 23 (Средняя школа №4)		0101000020E6100000103E9468C9FD4240CF488446B0F54B40
60133	1	10	\N	60268	80524	\N	55.924860000000002	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Талсинская, 1 (Дом Быта ""Подмосковье"")"		0101000020E610000094DC611399FF424075B0FECF61F64B40
60149	1	10	\N	60268	80562	\N	55.912888114074498	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Советская, 3 (городская библиотека №3)	Россия, Московская область, Щелковский район, Щелково, Советская улица, 3	0101000020E61000007E9065C1C4FF424097749483D9F44B40
60145	1	10	\N	60268	80232	\N	55.923943565234602	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Пушкина, 22 ( районный культурный комплекс)	Россия, Московская область, Щелковский район, Щелково, улица Пушкина, 22	0101000020E6100000DBBE47FDF5FC4240EFAA07CC43F64B40
60136	1	10	\N	60268	80536	\N	55.926009999999998	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Пролетарский проспект, 11 (Клуб ""Заречный"")"		0101000020E6100000211D1EC2F8FF42406DE2E47E87F64B40
60140	1	10	\N	60268	80542	\N	55.918559999999999	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Парковая, 3 Б (Средняя школа №16)		0101000020E610000042B3EBDE8AFE4240F6B4C35F93F54B40
60154	1	10	\N	60268	80029	\N	55.900283999999999	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Московская, 68 А (Жегаловская библиотека №14)		0101000020E61000000490DAC4C9FD4240588E90813CF34B40
60152	1	10	\N	60268	80026	\N	55.915759999999999	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Краснознаменская, 4 А (Помещение ЖРЭУ-1)		0101000020E61000000E87A5811FFF4240137EA99F37F54B40
60134	1	10	\N	60268	80544	\N	55.9273474507768	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Комсомольская, 8 А (Средняя школа №2)		0101000020E6100000FF76D9AF3BFF42409885764EB3F64B40
60165	1	10	\N	60268	80550	\N	55.902631	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Институтская, 18 (Средняя школа №14)		0101000020E61000004084B872F60643408AADA06989F34B40
60157	1	10	\N	60268	79819	\N	55.903309397923998	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Институтская, Средняя школа №11	Россия, Московская область, Щелковский район, Щелково, микрорайон Щелково-3, Институтская улица	0101000020E610000011A96917D30643405B971AA19FF34B40
60158	1	10	\N	60268	81040	\N	55.9093975496559	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Гагарина, Средняя школа №12		0101000020E61000007FFB3A70CE0843401F86562767F44B40
60153	1	10	\N	60268	79818	\N	55.907686613441598	Московская область, Щелковский муниципальный район, городское поселение Щёлково, 8-го Марта, 11 (ООО Эко-Солид)		0101000020E6100000C8CF46AE9BFE42408F006E162FF44B40
60150	1	10	\N	60268	80342	\N	55.918509	Московская область, Щелковский муниципальный район, городское поселение Щёлково, 1-ый Советский переулок, 32  (Средняя школа №6)		0101000020E6100000B6D782DE1B014340740AF2B391F54B40
60142	1	10	\N	60268	80342	\N	55.919342	Московская область, Щелковский муниципальный район, городское поселение Щёлково, 1-ый Советский переулок, 17 (Политехнический колледж)		0101000020E61000004CFA7B293C0043406CEBA7FFACF54B40
60076	1	10	\N	59533	80521	\N	55.583378000000003	Московская область, Шатурский район, г. Шатура, пр. Борзова, 13		0101000020E61000004981053065C243405B9A5B21ACCA4B40
60070	1	10	\N	59533	80517	\N	55.576549	Московская область, Шатурский район, г. Шатура, пр. Ильича, д. 25		0101000020E6100000E318C91EA1C4434050C58D5BCCC94B40
60069	1	10	\N	59533	80517	\N	55.574858999999996	Московская область, Шатурский район, г. Шатура, пр. Ильича, д.24		0101000020E61000002CF180B229C54340D767CEFA94C94B40
60080	1	10	\N	59533	71853	\N	55.610717000000001	Московская область, Шатурский район, г. Шатура, м-он Керва, ул. Первомайская, д.1		0101000020E61000009432A9A10DCA43403D0E83F92BCE4B40
60078	1	10	\N	59533	80870	\N	55.562906705461998	Московская область, Шатурский район, г. Шатура, ул. Вокзальная, д.76	Россия, Московская область, Шатурский район, Шатура, улица Чехова, 76а	0101000020E6100000321EA5129EC2434041D829560DC84B40
60030	1	10	\N	61885	79855	\N	55.146912999999998	г.Чехов, ул.Чехова, д.27, Центр развития творчества		0101000020E610000098DA520779BD4240BA2D910BCE924B40
60027	1	10	\N	61885	79855	\N	55.146064000000003	г.Чехов, ул.Чехова, д.8А, Гимназия № 2		0101000020E6100000BF9D44847FBD4240BD8FA339B2924B40
60031	1	10	\N	61885	80086	\N	55.139997999999999	г.Чехов, ул.Солнышевская, д.2А, Лицей №4		0101000020E61000007BF7C77BD5BA4240B1C05774EB914B40
60038	1	10	\N	61885	81066	\N	55.153816999999997	г. Чехов, ул. Полиграфистов (здание лицея № 56), д.11		0101000020E61000001C075E2D77BC4240CF488446B0934B40
94661	1	10	\N	61885	80185	\N	55.167025000000002	Московская область, Чеховский муниципальный район, г. Чехов, ул. Гагарина, д 112 (помещение СОШ №9, спортивный зал)		0101000020E610000004E3E0D231B74240A54E401361954B40
60039	1	10	\N	61885	80185	\N	55.166008239985899	г.Чехов, ул.Гагарина, д.86А, Средняя общеобразовательная школа №8		0101000020E61000005969520ABAB74240EB6F09C03F954B40
59907	1	10	\N	61868	79809	\N	56.724451511859797	"город Талдом, ул. Шишунова (МУ Дом Культуры ""Колос""), строение 5"		0101000020E6100000E8A38CB800C24240CAC2D7D7BA5C4C40
60017	1	10	\N	3200	\N	\N	56.002666310879	Московская область, городской округ Черноголовка, клуб села Макарово	Россия, Московская область, городской округ Черноголовка, село Макарово	0101000020E61000006473D53C47284340D367075C57004C40
60021	1	10	\N	3200	824	\N	56.012954000000001	Московская область, городской округ Черноголовка, проспект Академика Семенова, д. 1	Россия, Московская область, Черноголовка, проспект Академика Семенова, 1	0101000020E6100000541B9C887E3143401B2D077AA8014C40
60020	1	10	\N	3200	80328	\N	56.013255336542699	Московская область, городской округ Черноголовка, проезд Строителей, д. 3 (спортзал)	Россия, Московская область, Черноголовка, проезд Строителей, 3	0101000020E6100000EBA7FFACF92F434016C1FF56B2014C40
60019	1	10	\N	3200	80328	\N	56.013288016238199	Московская область, городской округ Черноголовка, проезд строителей, д. 3 (фойе)	Россия, Московская область, Черноголовка, проезд Строителей, 3	0101000020E6100000BEBF417BF52F4340F2B6D26BB3014C40
60024	1	10	\N	3200	855	\N	56.005172999999999	Московская область, городской округ Черноголовка, школьный бульвар, д. 1	Россия, Московская область, Черноголовка, Школьный бульвар, 1	0101000020E610000051DEC7D11C3143403EE94482A9004C40
60025	1	10	\N	3200	72270	\N	56.0019822842522	Московская область, городской округ Черноголовка, центральная, д.1	Россия, Московская область, Черноголовка, Центральная улица, 1	0101000020E6100000BB9C121093304340209738F240004C40
60023	1	10	\N	3200	834	\N	56.009098999999999	Московская область, городской округ Черноголовка, институтский проспект, д. 8	Россия, Московская область, Черноголовка, Институтский проспект, 8	0101000020E6100000D847A7AE7C30434091B6F1272A014C40
60022	1	10	\N	3200	834	\N	56.010306999999997	Московская область, городской округ Черноголовка, институтский проспект, д. 7	Россия, Московская область, Черноголовка, Институтский проспект, 7	0101000020E6100000425C397B67304340BEF561BD51014C40
60016	1	10	\N	96	\N	\N	55.962226529194602	"Московская область, городской округ Химки, Аэропорт ""Шереметьево""Терминал D"	Россия, Московская область, Химки	0101000020E6100000B1170AD80EB44240022A1C412AFB4B40
60015	1	10	\N	96	\N	\N	55.972482053927401	"Московская область, городской округ Химки, Аэропорт ""Шереметьево""Терминал С"	Россия, Московская область, Химки	0101000020E61000001AF7E6374CB442406EF9484A7AFC4B40
60001	1	10	\N	96	79997	\N	55.946844755486097	Московская область, городской округ Химки, мкр. Сходня, Чапаева, 11	Россия, Московская область, Химки, микрорайон Сходня, улица Чапаева, 13	0101000020E6100000A9BEF38B12A64240C9B08A3732F94B40
59960	1	10	\N	96	69721	\N	55.890616416665402	Московская область, городской округ Химки, Маяковского, 23а	Россия, Московская область, Химки, улица Маяковского, 23а	0101000020E6100000AFCC5B751DB84240ADA580B4FFF14B40
60011	1	10	\N	96	16461	\N	55.957146999999999	Московская область, городской округ Химки, мкр. Фирсановка, Маяковского, 3	Россия, Московская область, Химки, микрорайон Фирсановка, улица Маяковского, 3	0101000020E61000004F1F813FFCA04240753BFBCA83FA4B40
59979	1	10	\N	96	71918	\N	55.889928892219601	Московская область, городской округ Химки, Машинцева, 6	Россия, Московская область, Химки, улица Машенцева, 6	0101000020E610000007D3307C44B4424089618731E9F14B40
60005	1	10	\N	96	16432	\N	55.951421000000003	Московская область, городской округ Химки, мкр. Сходня, Горького, 7	Россия, Московская область, Химки, микрорайон Сходня, улица Горького, 7	0101000020E610000003D0285DFAA5424023DDCF29C8F94B40
59968	1	10	\N	96	71860	\N	55.908626743196599	Московская область, городской округ Химки, Глинки, 9	Россия, Московская область, Химки, улица Глинки	0101000020E6100000D15CA79196BA42409DA1B8E34DF44B40
59970	1	10	\N	96	80039	\N	55.903033745378998	Московская область, городской округ Химки, Проспект Мира, 22/7	Россия, Московская область, Химки, проспект Мира	0101000020E610000041F4A44C6ABA424089963C9E96F34B40
59988	1	10	\N	96	331	\N	55.901525999999997	Московская область, городской округ Химки, пр-т Мельникова, 2а	Россия, Московская область, Химки, проспект Мельникова, 2а	0101000020E6100000382D78D157B44240313F373465F34B40
60010	1	10	\N	96	71771	\N	55.920053000000003	Московская область, городской округ Химки, мкр. Планерная, Помещение школы № 19	Россия, Московская область, Химки, микрорайон Планерная	0101000020E6100000F88BD99255AF424019CBF44BC4F54B40
59998	1	10	\N	96	80766	\N	55.887434181760902	"Московская область, городской округ Химки, мкр. Новогорск, Помещение НОУ ""Школа современного образования"""	Россия, Московская область, Химки, улица Чапаева	0101000020E610000067D7BD1589B94240E2ADF36F97F14B40
94657	1	10	\N	96	229	\N	55.887613999999999	Московская область, городской округ Химки, Юбилейный пр-т 20	Россия, Московская область, Химки, Юбилейный проспект, 20	0101000020E61000006556EF703BB6424062BCE6559DF14B40
59985	1	10	\N	96	229	\N	55.892698000000003	Московская область, городской округ Химки, Юбилейный пр-т, 59	Россия, Московская область, Химки, Юбилейный проспект, 59	0101000020E6100000AB4203B16CB44240319A95ED43F24B40
60000	1	10	\N	96	80557	\N	55.944620999999998	Московская область, городской округ Химки, мкр. Сходня, Тюкова, 8		0101000020E6100000C365153603A64240B20E4757E9F84B40
60013	1	10	\N	96	81043	\N	55.940230647630599	Московская область, городской округ Химки, мкр. Клязьма-Старбеево, Спортивная, 34	Россия, Московская область, Химки, садовое товарищество Октябрьский, Спортивная улица	0101000020E61000000C59DDEA39AB4240BAD7497D59F84B40
59364	1	10	377	3282	\N	\N	55.485892	"п. Фабрики им. 1 Мая, здание МУК СДК ""Десна"", 37"		0101000020E6100000F99E91088DC04240ABB184B531BE4B40
94659	1	10	\N	96	80209	\N	55.894715402464499	Московская область, городской округ Химки, мкр. Новогорск, Соколовская, 11, кв. 2	Россия, Московская область, Химки	0101000020E610000072A8DF85ADAB4240CD1E680586F24B40
59994	1	10	\N	96	80298	\N	55.891804	Московская область, городской округ Химки, Пожарского, 14		0101000020E610000022C154336BBD424093382BA226F24B40
60006	1	10	\N	96	80511	\N	55.956572000000001	Московская область, городской округ Химки, мкр. Сходня, Первомайская, 33		0101000020E6100000DCF29194F4A64240792288F370FA4B40
59987	1	10	\N	96	80515	\N	55.896930367550702	Московская область, городской округ Химки, Парковая, 10	Россия, Московская область, Химки, Парковая улица, 10	0101000020E6100000CDCB61F71DB5424090662C9ACEF24B40
59973	1	10	\N	96	80510	\N	55.880546418695403	Московская область, городской округ Химки, Панфилова, 14	Россия, Московская область, Химки, улица Панфилова, 14	0101000020E6100000139CFA40F2B64240D34F38BBB5F04B40
60004	1	10	\N	96	80908	\N	55.950327000000001	Московская область, городской округ Химки, мкр. Сходня, Октябрьская, 30		0101000020E6100000A16AF46A80A44240BEC0AC50A4F94B40
59996	1	10	\N	96	80310	\N	55.892124725947802	Московская область, городской округ Химки, Нахимова, 2	Россия, Московская область, Химки, улица Нахимова, 2	0101000020E61000005325CADE52BC4240D578E92631F24B40
59959	1	10	\N	96	80504	\N	55.886718147504801	Московская область, городской округ Химки, Московская, 38	Россия, Московская область, Химки, Московская улица, 38	0101000020E6100000446CB07092B842402463B5F97FF14B40
59992	1	10	\N	96	80229	\N	55.899328207859597	Московская область, городской округ Химки, Молодежный проезд, 4	Россия, Московская область, Химки, Молодежный проезд, 4	0101000020E6100000C366800BB2B3424044300E2E1DF34B40
59978	1	10	\N	96	74113	\N	55.888579	Московская область, городской округ Химки, Молодежная, 44	Россия, Московская область, Химки, Молодежная улица, 44	0101000020E6100000CAC4AD8218B44240C974E8F4BCF14B40
59974	1	10	\N	96	74113	\N	55.878171443076504	Московская область, городской округ Химки, Молодежная, 1	Россия, Московская область, Химки, Молодежная улица, 1	0101000020E6100000410C74ED0BB64240D7A546E867F04B40
59991	1	10	\N	96	71859	\N	55.907426435268299	Московская область, городской округ Химки, М.Рубцовой, 4	Россия, Московская область, Химки, улица Марии Рубцовой	0101000020E61000009A25016A6AB3424022C5008926F44B40
59969	1	10	\N	96	16	\N	55.899098000000002	Московская область, городской округ Химки, Ленинский пр-т, 2	Россия, Московская область, Химки, Ленинский проспект, 2	0101000020E6100000F6D4EAABABBA424013F3ACA415F34B40
59965	1	10	\N	96	16	\N	55.897295999999997	Московская область, городской округ Химки, Ленинский пр-т, 7	Россия, Московская область, Химки, Ленинский проспект, 7	0101000020E61000000D39B69E21BA4240726A6798DAF24B40
59961	1	10	\N	96	80073	\N	55.891596810265398	Московская область, городской округ Химки, Ленинградская, 18а		0101000020E610000006D50627A2B74240191BBAD91FF24B40
94655	1	10	\N	96	80138	\N	55.890416000000002	Московская область, городской округ Химки,Лавочкина 12		0101000020E6100000C45F9335EAB54240E6EAC726F9F14B40
59980	1	10	\N	96	80138	\N	55.890416000000002	Московская область, городской округ Химки, Лавочкина, 12		0101000020E6100000C45F9335EAB54240E6EAC726F9F14B40
59975	1	10	\N	96	74084	\N	55.884697540355901	Московская область, городской округ Химки, Куркинское ш, 18	Россия, Москва, Куркинское шоссе, 18	0101000020E610000003B4AD669DB54240166BB8C83DF14B40
59972	1	10	\N	96	74091	\N	55.884929794009501	Московская область, городской округ Химки, Куркинское ш, 18а	Россия, Москва, район Куркино, Куркинское шоссе	0101000020E61000004A7D59DAA9B34240E89FE06245F14B40
59964	1	10	\N	96	80056	\N	55.890208999999999	Московская область, городской округ Химки, Кирова, 11а	Россия, Московская область, Химки, улица Кирова, 11а	0101000020E6100000637AC2120FBA42406CCD565EF2F14B40
94660	1	10	\N	96	80785	\N	55.890058000000003	Московская область, городской округ Химки, мкр. Клязьма-Старбеево Квартал Свистуха 11	Россия, Московская область, Химки, Московская улица	0101000020E6100000F86F5E9CF8B8424087C5A86BEDF14B40
59995	1	10	\N	96	71840	\N	55.890388624911402	Московская область, городской округ Химки, Зеленая, 22	Россия, Московская область, Химки, Зеленая улица, 22	0101000020E6100000655419C6DDBC4240ECDB4944F8F14B40
59984	1	10	\N	96	81056	\N	55.884864499309998	Московская область, городской округ Химки Горшина 7	Россия, Московская область, Химки	0101000020E6100000802DAF5C6FB7424031B43A3943F14B40
60007	1	10	\N	96	81017	\N	55.957554999999999	Московская область, городской округ Химки, мкр. Сходня, Горная, 21		0101000020E61000003480B74082A84240868F882991FA4B40
59958	1	10	\N	96	79807	\N	55.886614509868799	Московская область, городской округ Химки, Ватутина, 2	Россия, Московская область, Химки, улица Ватутина, 2	0101000020E610000010B1C1C249BA42404F92AE997CF14B40
59967	1	10	\N	96	80513	\N	55.903716704626099	Московская область, городской округ Химки, Бурденко, 5	Россия, Московская область, Химки, улица Бурденко, 5	0101000020E61000001F300F99F2B942406CEBA7FFACF34B40
59993	1	10	\N	96	401	\N	55.895766999999999	Московская область, городской округ Химки, Библиотечная, 9	Россия, Московская область, Химки, Библиотечная улица, 7	0101000020E61000001CEA77616BBC424003EB387EA8F24B40
94658	1	10	\N	96	79985	\N	55.896321999999998	Московская область, городской округ Химки, Библиотечная, 13		0101000020E610000019A9F7544EBD4240B857E6ADBAF24B40
59966	1	10	\N	96	80520	\N	55.901174192956297	Московская область, городской округ Химки, Березовая аллея, 1	Россия, Московская область, Химки, улица Березовая Аллея	0101000020E6100000E60819C8B3B94240B4006DAB59F34B40
59971	1	10	\N	96	80506	\N	55.881207000000003	Московская область, городской округ Химки, Бабакина, 1а		0101000020E6100000D7FB8D76DCB64240CE001764CBF04B40
59990	1	10	\N	96	80079	\N	55.9046994026506	Московская область, городской округ Химки 9 Мая 19	Россия, Московская область, Химки, улица 9 Мая, 19	0101000020E61000004694F6065FB44240A9DC442DCDF34B40
60003	1	10	\N	96	16417	\N	55.947358999999999	Московская область, городской округ Химки, мкр. Сходня, 2-ой Чапаевский пер, 3	Россия, Московская область, Химки, микрорайон Сходня, 2-й Чапаевский переулок, 3	0101000020E61000006CB1DB6795A542401F49490F43F94B40
60002	1	10	\N	96	16417	\N	55.947358999999999	Московская область, городской округ Химки, мкр. Сходня 2-ой Чапаевский пер. 3а	Россия, Московская область, Химки, микрорайон Сходня, 2-й Чапаевский переулок, 3	0101000020E61000006CB1DB6795A542401F49490F43F94B40
59955	1	10	\N	11769	80022	\N	55.952593276906299	Московская область, городской округ Фрязино, проспект Мира, д. 18Б	Россия, Московская область, Фрязино, проспект Мира, 18б	0101000020E6100000070951BEA007434003B34291EEF94B40
59950	1	10	\N	11769	80022	\N	55.956653000000003	Московская область, городской округ Фрязино, проспект Мира, д. 23	Россия, Московская область, Фрязино, проспект Мира, 23	0101000020E6100000B35C363AE7074340664F029B73FA4B40
59949	1	10	\N	11769	80481	\N	55.956527000000001	Московская область, городской округ Фрязино, ул. Школьная, д. 10	Россия, Московская область, Фрязино, Школьная улица, 10	0101000020E610000056BB26A435064340D95E0B7A6FFA4B40
94437	1	10	\N	11769	81091	\N	55.958542000000001	ул. проф. Попова, 39 Петростат	Россия, Московская область, Фрязино, улица Попова, 37	0101000020E610000023BBD23252034340D5EB1681B1FA4B40
59956	1	10	\N	11769	80490	\N	55.945825125084397	Московская область, городской округ Фрязино, ул. Полевая, д. 29	Россия, Московская область, Фрязино, Полевая улица, 29	0101000020E6100000E8A1B60DA30843409E5E29CB10F94B40
59954	1	10	\N	11769	80490	\N	55.950484000000003	Московская область, городской округ Фрязино, ул. Полевая, д. 3	Россия, Московская область, Фрязино, Полевая улица, 3	0101000020E610000019E42EC21407434086AFAF75A9F94B40
59945	1	10	\N	11769	80019	\N	55.957157000000002	Московская область, городской округ Фрязино, ул. Нахимова, д. 23А	Россия, Московская область, Фрязино, улица Нахимова, 23а	0101000020E6100000E86A2BF6970343409911DE1E84FA4B40
59951	1	10	\N	11769	80492	\N	55.950977999999999	Московская область, городской округ Фрязино, ул. Луговая, д. 31	Россия, Московская область, Фрязино, Луговая улица, 31	0101000020E610000004E8F7FD9B054340959BA8A5B9F94B40
59948	1	10	\N	11769	80480	\N	55.957368354606203	Московская область, городской округ Фрязино, ул. Комсомольская, д. 17		0101000020E6100000008DD2A57F054340541EDD088BFA4B40
59947	1	10	\N	11769	80480	\N	55.960019000000003	Московская область, городской округ Фрязино, ул. Комсомольская, д. 19	Россия, Московская область, Фрязино, Комсомольская улица, 19	0101000020E61000008BA71E6970054340F24410E7E1FA4B40
59589	1	10	\N	61953	80712	\N	55.601745680284701	Московская область, Рузский муниципальный район, городское поселение Тучково, Новая, 15		0101000020E61000002FC4EA8F303C4240D93F4F0306CD4B40
59936	1	10	\N	31250	\N	\N	55.4876870483616	"Московская область, городской округ Троицк, Микрорайон ""В"", 26"	Россия, Московская область, Троицк, микрорайон В, 22	0101000020E610000083A279008BA6424099D711876CBE4B40
94652	1	10	\N	31250	74101	\N	55.475591999999999	Московская область, город Троицк, Микрорайон "В", д.26		0101000020E6100000700B96EA02A642409F1EDB32E0BC4B40
59940	1	10	\N	31250	80053	\N	55.475336189150397	Московская область, городской округ Троицк, Школьная, 10	Россия, Московская область, Троицк, Школьная улица, 10	0101000020E6100000B9FAB1497EA64240444E5FCFD7BC4B40
59939	1	10	\N	31250	80053	\N	55.475609649670801	Московская область, городской округ Троицк, Школьная, 10а		0101000020E6100000BE66B96C74A6424046D3D9C9E0BC4B40
59942	1	10	\N	31250	7911	\N	55.468964	Московская область, городской округ Троицк, Сиреневый бульвар, 1	Россия, Московская область, Троицк, Сиреневый бульвар, 1	0101000020E610000087C5A86BEDA542402C80290307BC4B40
59941	1	10	\N	31250	7911	\N	55.468836000000003	Московская область, городской округ Троицк, Сиреневый бульвар, 2	Россия, Московская область, Троицк, Сиреневый бульвар, 2	0101000020E6100000397F130A11A64240FF976BD102BC4B40
94654	1	10	\N	31250	72154	\N	55.476296149057298	Московская область, город Троицк, площадь Верещагина, д.1	Россия, Московская область, Троицк, Пионерская улица	0101000020E6100000D7851F9C4FA74240999B6F44F7BC4B40
94653	1	10	\N	31250	16895	\N	55.476875141492897	Московская область, город Троицк, Октябрьский проспект, д.16Б	Россия, Московская область, Троицк, Октябрьский проспект, 16	0101000020E61000002367614F3BA64240D7A3703D0ABD4B40
59944	1	10	\N	31250	16895	\N	55.475733429920602	Московская область, городской округ Троицк, Октябрьский проспект, 9 б	Россия, Московская область, Троицк, Октябрьский проспект, 9	0101000020E6100000C6C1A563CEA542406150A6D1E4BC4B40
59943	1	10	\N	31250	16895	\N	55.472350184775003	Московская область, городской округ Троицк, Октябрьский проспект, 6	Россия, Московская область, Троицк, Октябрьский проспект, 6	0101000020E61000000B47904AB1A54240FF21FDF675BC4B40
94651	1	10	\N	31250	74072	\N	55.487894173470302	"Московская область, городской округ Троицк, Микрорайон ""В"", д.6а		0101000020E6100000D6C4025FD1A5424012F5824F73BE4B40
94650	1	10	\N	31250	74072	\N	55.4902238748626	Московская область, город Троицк,Микрорайон "В", д.53		0101000020E61000009E4319AA62A642406EDBF7A8BFBE4B40
59934	1	10	\N	31250	71856	\N	55.490209026738199	"Московская область, городской округ Троицк, Микрорайон ""В"", 53"		0101000020E61000000A2E56D460A64240399A232BBFBE4B40
59933	1	10	\N	31250	80502	\N	55.493358511682899	Московская область, городской округ Троицк, Комсомольский проезд, 3	Россия, Московская область, Троицк, Комсомольский проезд, 3	0101000020E6100000672C9ACE4EA84240F817416326BF4B40
59906	1	10	\N	61868	79809	\N	56.724687450763298	МУ Дом культуры «Колос», улица Шишунова, строение 5, кабинет хариографии, г. Талдом	Россия, Московская область, Талдомский район, Талдом, улица Шишунова	0101000020E61000004EEFE2FDB8C142400E6B2A8BC25C4C40
59905	1	10	\N	61868	79805	\N	56.733614157596797	город Талдом, ул. Победы (МУ Районный Дом культуры), дом 10		0101000020E610000001857AFA08C44240A2F14410E75D4C40
59904	1	10	\N	61868	80849	\N	56.723520999999998	город Талдом, ул. Орлова (МОУ ТСОШ №1), дом 5		0101000020E61000009813B4C9E1C342400F7C0C569C5C4C40
94647	1	10	\N	59517	79984	\N	54.886046999999998	Московская обл., г. Ступино, ул. Чайковского, вл. 54, лицей №1		0101000020E61000009DD9AED00707434005DCF3FC69714B40
59874	1	10	\N	59517	79984	\N	54.883358999999999	Московская область, Ступино, Чайковского, 3/10		0101000020E6100000A30227DBC00943404AD05FE811714B40
59851	1	10	\N	59517	79984	\N	54.886046999999998	Московская область, Ступино, Чайковского, 54		0101000020E61000009DD9AED00707434005DCF3FC69714B40
59865	1	10	\N	59517	80006	\N	54.8873555112134	Московская область, Ступино, Тургенева, 14/19		0101000020E61000003ECA880B400B434066F4A3E194714B40
59857	1	10	\N	59517	80688	\N	54.900284999999997	Московская область, Ступино, Пушкина, 101		0101000020E6100000E65C8AABCA0A4340280AF4893C734B40
59858	1	10	\N	59517	80698	\N	54.89226	Московская область, Ступино, Куйбышева, 63		0101000020E6100000B08EE3874A094340B5C35F9335724B40
59853	1	10	\N	59517	80445	\N	54.885798000000001	Московская область, Ступино, Колхозная, 173		0101000020E6100000CEFDD5E3BE0D43405D6E30D461714B40
59854	1	10	\N	59517	80467	\N	54.866643000000003	Московская область, Ступино, Есенина, 2		0101000020E61000004C1762F54710434057276728EE6E4B40
59864	1	10	\N	59517	80452	\N	54.889127999999999	Московская область, Ступино, Горького, 21		0101000020E6100000CE52B29C840A43409CFA40F2CE714B40
59862	1	10	\N	59517	80452	\N	54.890619000000001	Московская область, Ступино, Горького, 18		0101000020E61000006893C3279D0843401E19ABCDFF714B40
59855	1	10	\N	59517	71815	\N	54.887269000000003	Московская область, Ступино, Городищенская, 8		0101000020E610000058207A522609434098E0D40792714B40
59859	1	10	\N	59517	80493	\N	54.891897999999998	Московская область, Ступино, Тимирязева, 58		0101000020E6100000BDC62E51BD09434014AFB2B629724B40
58977	1	10	\N	61948	80662	\N	55.815436497310898	г.Старая Купавна, Большая Московская, 3 а		0101000020E6100000677BF486FB18434093FDF33460E84B40
58974	1	10	\N	61948	80662	\N	55.811608999999997	"г.Старая Купавна, Большая Московская, 116 (ДК ""Акрихин"")"		0101000020E610000038F6ECB94C174340D311C0CDE2E74B40
59507	1	10	\N	59505	\N	\N	55.601325000000003	"Московская область, Раменский муниципальный район,поселок Спартак, Помещение Дома культуры ""Спартак"""		0101000020E61000007B849A215506434034A2B437F8CC4B40
59825	1	10	\N	61911	79982	\N	56.183633846144801	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Обуховская, 2/96	Россия, Московская область, Солнечногорский район, Солнечногорск, Обуховская улица	0101000020E6100000B2B96A9E237C42408237A45181174C40
59811	1	10	\N	61911	80432	\N	56.200769000000001	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Вертлинская, 17		0101000020E610000081ED60C43E7B42407B8670CCB2194C40
59815	1	10	\N	61911	80441	\N	56.189779999999999	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Банковская, 6а		0101000020E6100000252026E1427E4240AAB706B64A184C40
94555	1	10	\N	12304	5798	\N	54.910393999999997	Ул. Чехова, д.5 Выставочный зал Управления Культуры		0101000020E6100000663387A416B64240C03C64CA87744B40
59734	1	10	\N	12304	5798	\N	54.912044999999999	Московская область, городской округ Серпухов, Чехова, 58/27	Россия, Московская область, Серпухов, улица Чехова, 56	0101000020E6100000601F9DBAF2B542407BBDFBE3BD744B40
59748	1	10	\N	12304	5943	\N	54.925860999999998	Московская область, городской округ Серпухов, Ворошилова, 148/2	Россия, Московская область, Серпухов, улица Ворошилова, 148/2	0101000020E6100000957F2DAF5CB9424028D2FD9C82764B40
59736	1	10	\N	12304	5811	\N	54.920645999999998	Московская область, городской округ Серпухов, Мишина проезд, 12б	Россия, Московская область, Серпухов, проезд Мишина, 12б	0101000020E6100000BE4BA94BC6B54240BB9866BAD7754B40
59741	1	10	\N	12304	80410	\N	54.939859820749	Московская область, городской округ Серпухов, Юбилейная, 14	Россия, Московская область, Серпухов, Юбилейная улица, 14	0101000020E6100000D09A1F7F69B34240C7681D554D784B40
59725	1	10	\N	12304	79999	\N	54.910924588906902	Московская область, городской округ Серпухов, Чернышевского, 42а	Россия, Московская область, Серпухов, улица Чернышевского, 42а	0101000020E61000002A5437177FB14240ED0DBE3099744B40
59733	1	10	\N	12304	71841	\N	54.905805360184203	Московская область, городской округ Серпухов, Центральная, 79а	Россия, Московская область, Серпухов, Центральная улица, 79а	0101000020E61000004451A04FE4B74240D2C6116BF1734B40
59731	1	10	\N	12304	71841	\N	54.907721730749898	Московская область, городской округ Серпухов, Центральная, 97а	Россия, Московская область, Серпухов, Центральная улица, 97а	0101000020E610000073DBBE47FDB742400BEE073C30744B40
59752	1	10	\N	12304	72105	\N	54.920527475632099	Московская область, городской округ Серпухов, Центральная, 154	Россия, Московская область, Серпухов, Центральная улица, 154	0101000020E6100000A20BEA5BE6B84240E10A28D4D3754B40
59739	1	10	\N	12304	80365	\N	54.931835999999997	Московская область, городской округ Серпухов, Химиков, 6		0101000020E61000006022DE3AFFB04240239EEC6646774B40
59747	1	10	\N	12304	80393	\N	54.928457999999999	Московская область, городской округ Серпухов, Фирсова, 9		0101000020E6100000914259F8FAB84240D3DA34B6D7764B40
59744	1	10	\N	12304	80379	\N	54.937401999999999	Московская область, городской округ Серпухов, Тяговая, 8		0101000020E61000009AED0A7DB0B842403D9AEAC9FC774B40
59756	1	10	\N	12304	80424	\N	54.932740114772798	Московская область, городской округ Серпухов, Текстильная, 2		0101000020E610000069C878944ABA4240E5D5390664774B40
59743	1	10	\N	12304	69615	\N	54.924694223072301	Московская область, городской округ Серпухов, Советская, 90	Россия, Московская область, Серпухов, Советская улица, 90	0101000020E6100000AF42CA4FAAB742405A677C5F5C764B40
59749	1	10	\N	12304	72094	\N	54.928030784400299	Московская область, городской округ Серпухов, Советская, 83	Россия, Московская область, Серпухов, Советская улица, 83	0101000020E6100000DB696B4430B842404B5645B8C9764B40
59746	1	10	\N	12304	72094	\N	54.920603466772903	Московская область, городской округ Серпухов, Советская, 45	Россия, Московская область, Серпухов, Советская улица, 45	0101000020E6100000FF2268CC24B64240BCCCB051D6754B40
59735	1	10	\N	12304	80015	\N	54.912409787541201	Московская область, городской округ Серпухов, Свердлова, 33/4	Россия, Московская область, Серпухов, улица Свердлова	0101000020E6100000FA0CA837A3B442408D45D3D9C9744B40
59740	1	10	\N	12304	80013	\N	54.930882474420997	Московская область, городской округ Серпухов, Пушкина, 40а	Россия, Московская область, Серпухов, улица Пушкина	0101000020E610000088F71C588EB24240B037312427774B40
59726	1	10	\N	12304	74195	\N	54.916350999999999	Московская область, городской округ Серпухов, Пролетарская, 78	Россия, Московская область, Серпухов, Пролетарская улица, 78	0101000020E6100000CC5F217365B24240155454FD4A754B40
59753	1	10	\N	12304	80010	\N	54.920769999999997	Московская область, городской округ Серпухов, Осенняя, 7д	Россия, Московская область, Серпухов, Осенняя улица, 7	0101000020E61000007FA2B2614DB94240A79196CADB754B40
59730	1	10	\N	12304	79941	\N	54.907313447182197	Московская область, городской округ Серпухов, Новослободская, 2		0101000020E6100000D15CA79196B642402A1E17D522744B40
59737	1	10	\N	12304	79967	\N	54.930883999999999	Московская область, городской округ Серпухов, Московское шоссе, 64	Россия, Московская область, Серпухов, Московское шоссе, 64	0101000020E6100000BFB9BF7ADCB34240512FF83427774B40
59723	1	10	\N	12304	68475	\N	54.920169999999999	Московская область, городской округ Серпухов, Красный Текстильщик, 6а		0101000020E6100000225514AFB2B0424052616C21C8754B40
59728	1	10	\N	12304	80326	\N	54.909471111616398	Московская область, городской округ Серпухов, Космонавтов, 17	Россия, Московская область, Серпухов, улица Космонавтов, 17	0101000020E6100000CD1FD3DA34B2424089D4B48B69744B40
59727	1	10	\N	12304	80011	\N	54.906601959419703	Московская область, городской округ Серпухов, Клубный переулок, 1/2	Россия, Московская область, Серпухов, Клубный переулок	0101000020E6100000E8C1DD59BBB342407D3ECA880B744B40
59755	1	10	\N	12304	80012	\N	54.925658726392598	Московская область, городской округ Серпухов, Дзержинского, 2а	Россия, Московская область, Серпухов, улица Дзержинского, 2	0101000020E6100000768D96033DBA4240C11F7EFE7B764B40
59732	1	10	\N	12304	80352	\N	54.919482000000002	Московская область, городской округ Серпухов, Джона Рида, 6		0101000020E610000000A8E2C62DB842405EA10F96B1754B40
59742	1	10	\N	12304	71912	\N	54.929187896105702	Московская область, городской округ Серпухов, Горького, 32	Россия, Московская область, Серпухов, улица Горького, 32	0101000020E6100000FA449E245DB74240F7EAE3A1EF764B40
59757	1	10	\N	12304	80014	\N	54.927208062082599	Московская область, городской округ Серпухов, Войкова, 11	Россия, Московская область, Серпухов, улица Войкова	0101000020E61000005628D2FD9CBA4240774B72C0AE764B40
94629	1	10	\N	12304	79983	\N	54.917882565816001	Московская область  городской округ Серпухов  Водонапорная (здание школы №6)  д.6	Россия, Московская область, Серпухов, Водонапорная улица, 8/3	0101000020E6100000FBCA83F414B74240F646AD307D754B40
59729	1	10	\N	12304	71911	\N	54.899089226384397	Московская область, городской округ Серпухов, Большой Ударный переулок, 1	Россия, Московская область, Серпухов, Большой Ударный переулок, 1	0101000020E61000007E737FF5B8B34240BF982D5915734B40
59724	1	10	\N	12304	80341	\N	54.914950664968899	Московская область, городской округ Серпухов, 1905 года, 15	Россия, Московская область, Серпухов, улица 1905 года	0101000020E6100000C72FBC92E4AF4240A438471D1D754B40
59738	1	10	\N	12304	80353	\N	54.921349999999997	Московская область, городской округ Серпухов, 1-я Московская, 42/8		0101000020E61000000D501A6A14B44240B515FBCBEE754B40
59633	1	10	\N	59528	71838	\N	56.3220254775228	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, пр. Красной Амии, 212а	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 212а	0101000020E61000003EE94482A912434048BF7D1D38294C40
59613	1	10	\N	59528	80049	\N	56.295475000000003	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Хотьковский проезд, 18а		0101000020E610000019FF3EE3C20F43408FE4F21FD2254C40
59647	1	10	\N	59528	80244	\N	56.294280999999998	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Птицеградская, 2		0101000020E6100000217365506D164340C66AF3FFAA254C40
59646	1	10	\N	59528	79978	\N	56.3017859725908	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад-7, Молодежная, 4		0101000020E61000003D47E4BB94164340013274ECA0264C40
59616	1	10	\N	59528	80702	\N	56.293591999999997	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Куликова, 16		0101000020E6100000E90DF7915B0F4340012F336C94254C40
59617	1	10	\N	59528	80172	\N	56.3093739739627	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Кирова, 8		0101000020E610000085D21742CE0F4340C91D369199274C40
59625	1	10	\N	59528	80157	\N	56.328169000000003	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Дружбы, 5А		0101000020E610000083C2A04CA3114340D0471971012A4C40
59624	1	10	\N	59528	80157	\N	56.327579999999998	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Дружбы, 5		0101000020E610000082C8224DBC1143406E693524EE294C40
59640	1	10	\N	59528	80235	\N	56.311706000000001	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Валовая, 5		0101000020E61000008AE6012CF2114340C6FB71FBE5274C40
59578	1	10	\N	61950	80696	\N	55.702197313831299	Московская область, Рузский муниципальный район, городское поселение Руза, Ульяновская, 22	Россия, Московская область, Рузский район, Руза	0101000020E61000009A5DF75624184240B62C5F97E1D94B40
59574	1	10	\N	61950	80701	\N	55.700219801135098	Московская область, Рузский муниципальный район, городское поселение Руза, Волоколамское шоссе, 2	Россия, Московская область, Рузский район, Руза	0101000020E61000005854C4E924194240A80018CFA0D94B40
59569	1	10	\N	13222	80122	\N	55.657136243876799	Московская область, городской округ Рошаль, Фридриха Энгельса, 4/2	Россия, Московская область, Рошаль, улица Энгельса, 4	0101000020E61000000247020D36EF43401B834E081DD44B40
59568	1	10	\N	13222	80707	\N	55.656834384843897	Московская область, городской округ Рошаль, Фридриха Энгельса, 12	Россия, Московская область, Рошаль, улица Энгельса, 12	0101000020E610000019C5724BABEF43405073F22213D44B40
59566	1	10	\N	13222	80058	\N	55.656580006374703	Московская область, городской округ Рошаль, Фридриха Энгельса, 28 а	Россия, Московская область, Рошаль, улица Энгельса, 28а	0101000020E6100000E9D500A5A1F04340959A3DD00AD44B40
59570	1	10	\N	13222	71928	\N	55.662751153901702	Московская область, городской округ Рошаль, Советская, 36	Россия, Московская область, Рошаль, Советская улица, 36	0101000020E61000007CD5CA845FEE434016325706D5D44B40
59572	1	10	\N	13222	80711	\N	55.670735955808098	Московская область, городской округ Рошаль, Свердлова, 48	Россия, Московская область, Рошаль, улица Свердлова, 48	0101000020E61000000DDFC2BAF1EC4340FB1F60ADDAD54B40
59567	1	10	\N	13222	80693	\N	55.658580999999998	Московская область, городской округ Рошаль, Октябрьской революции, 24		0101000020E6100000823CBB7CEBEF43402C62D8614CD44B40
59571	1	10	\N	13222	80720	\N	55.659316857164697	Московская область, городской округ Рошаль, Карла Маркса, 1	Россия, Московская область, Рошаль, улица Карла Маркса	0101000020E61000009E7C7A6CCBEC43403259DC7F64D44B40
59560	1	10	\N	52779	61939	\N	55.7613888336776	Московская область, городской округ Реутов, Победы, 4	Россия, Московская область, Реутов, улица Победы, 4	0101000020E61000000D1CD0D215EE42405F44DB3175E14B40
59555	1	10	7460	\N	61942	\N	55.748262156002099	Московская область, городской округ Реутов, Котовского, 13	Россия, Московская область, городской округ Реутов	0101000020E610000037C2A2224EEF4240766B990CC7DF4B40
59556	1	10	\N	52779	67004	\N	55.747399000000001	Московская область, городской округ Реутов, Южная, 17		0101000020E610000094F6065F98EE424014083BC5AADF4B40
59503	1	10	\N	52779	67004	\N	55.747956000000002	Московская область, городской округ Реутов, Южная, 8		0101000020E61000002174D0251CEE42406A6CAF05BDDF4B40
59557	1	10	\N	52779	59437	\N	55.749794999999999	Московская область, городской округ Реутов, Юбилейный проспект, 15а	Россия, Московская область, Реутов, Юбилейный проспект, 15	0101000020E61000001A33897AC1ED424027DA5548F9DF4B40
59554	1	10	\N	52779	59437	\N	55.749755	Московская область, городской округ Реутов, Юбилейный проспект, 38	Россия, Московская область, Реутов, Юбилейный проспект, 38	0101000020E6100000CF328B506CEF42409981CAF8F7DF4B40
59564	1	10	\N	52779	59466	\N	55.768419999999999	Московская область, городской округ Реутов, Советская, 27		0101000020E6100000B378B13044EE4240D1CB28965BE24B40
59562	1	10	\N	52779	59466	\N	55.764834999999998	Московская область, городской округ Реутов, Советская, 6а		0101000020E61000003BE2900DA4ED424007EBFF1CE6E14B40
59565	1	10	\N	52779	66985	\N	55.768501999999998	Московская область, городской округ Реутов, Победы, 32		0101000020E610000069AA27F38FEC42408E7406465EE24B40
59563	1	10	\N	52779	66985	\N	55.760914999999997	Московская область, городской округ Реутов, Победы, 2		0101000020E6100000D32D3BC43FEE42409604A8A965E14B40
59559	1	10	\N	52779	66999	\N	55.758088000000001	Московская область, городской округ Реутов, Новая, 16		0101000020E61000001F6ADB300AEE4240BABE0F0709E14B40
59561	1	10	\N	52779	59452	\N	55.761451999999998	Московская область, городской округ Реутов, Лесная, 12		0101000020E6100000AD68739CDBEC4240A5BC564277E14B40
59558	1	10	\N	52779	59461	\N	55.753580880142501	Московская область, городской округ Реутов, Комсомольская, 15	Россия, Московская область, Реутов, Комсомольская улица, 15	0101000020E610000075914259F8EC424088F19A5775E04B40
59471	1	10	\N	59541	80747	\N	55.565762999999997	Московская область, Раменский муниципальный район, город Раменское, Улица Михалевича, Дом 29		0101000020E6100000DB5207793D1E4340B72407EC6AC84B40
59478	1	10	\N	59541	80687	\N	55.571958000000002	Московская область, Раменский муниципальный район, город Раменское, Улица Красноармейская, Дом 27		0101000020E61000008EB27E33311F4340C15774EB35C94B40
59463	1	10	\N	59541	80676	\N	55.585493999999997	Московская область, Раменский муниципальный район, город Раменское, Улица Космонавтов, Дом 19		0101000020E61000002F89B3226A1A43408A00A777F1CA4B40
59462	1	10	\N	59541	80676	\N	55.585571000000002	Московская область, Раменский муниципальный район, город Раменское, Улица Космонавтов, Дом 1		0101000020E61000006CB07092E6194340363E93FDF3CA4B40
59475	1	10	\N	59541	80700	\N	55.567951999999998	Московская область, Раменский муниципальный район, город Раменское, Улица Карла Маркса, Дом 1		0101000020E61000009E60FF756E1C434051D9B0A6B2C84B40
59472	1	10	\N	59541	80094	\N	55.575923000000003	Московская область, Раменский муниципальный район, город Раменское, Улица Гурьева, Дом 1-а		0101000020E6100000B1F84D61A51E4340D20149D8B7C94B40
59469	1	10	\N	59541	79959	\N	55.565178655794	Московская область, Раменский муниципальный район, город Раменское, Улица 100-й Свирской дивизии, Дом 11	Россия, Московская область, Раменский район, Раменское, улица 100-й Свирской Дивизии	0101000020E61000003D601E32E519434068B114C957C84B40
59459	1	10	\N	4258	\N	\N	54.834456282385297	"Московская область, городской округ Пущино, микрорайон ""АБ"", д.4А"	Россия, Московская область, Пущино, микрорайон АБ, 4а	0101000020E6100000ECDD1FEF55CD4240BAF94674CF6A4B40
59458	1	10	\N	4258	\N	\N	54.835348062798197	"Московская область, городской округ Пущино, микрорайон ""Г"", д.23А"	Россия, Московская область, Пущино, микрорайон Г, 23а	0101000020E6100000217365506DD04240B763EAAEEC6A4B40
59457	1	10	\N	4258	\N	\N	54.833867944195099	"Московская область, городской округ Пущино, микрорайон ""В"", д.6А"	Россия, Московская область, Пущино, микрорайон В, 6а	0101000020E6100000AA81E673EECE42402997C62FBC6A4B40
59409	1	10	\N	4258	\N	\N	54.8295759113347	"Московская область, городской округ Пущино, микрорайон ""Д"", д.2А"	Россия, Московская область, Пущино, микрорайон Д, 2а	0101000020E61000001840F850A2D14240F4C5DE8B2F6A4B40
59383	1	10	\N	4258	15660	\N	54.832614	Московская область, городской округ Пущино, проспект Науки, д.2	Россия, Московская область, Пущино, микрорайон АБ, проспект Науки, 2	0101000020E61000007C0DC17119D142408B187618936A4B40
59456	1	10	\N	4258	71916	\N	54.836054331874998	"Московская область, городской округ Пущино, микрорайон ""В"", д.32Б"	Россия, Московская область, Пущино, микрорайон АБ, бульвар Иерусалимского, 32б	0101000020E6100000DDB1D82615CF424051D845D1036B4B40
59402	1	10	\N	59520	71825	\N	56.011281825882897	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Дзержинец, 10а	Россия, Московская область, Пушкинский район, Пушкино, улица Дзержинского, 10а	0101000020E6100000B84082E2C7EE4240498446B071014C40
59447	1	10	\N	59520	80841	\N	56.019011999999996	Московская область, Пушкинский муниципальный район, сельское поселение Тарасовское, Центральная, 5		0101000020E6100000C156091687EF4240A31D37FC6E024C40
59391	1	10	\N	59520	80498	\N	56.013150000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Тургенева, 3		0101000020E6100000F240649126EC4240A1F831E6AE014C40
59400	1	10	\N	59520	71915	\N	56.007161000000004	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Серебрянка, СОШ №6		0101000020E61000007B88467710EF42404167D2A6EA004C40
59414	1	10	\N	59520	80906	\N	55.975440999999996	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Клязьма, ул.Кольцовская, 2		0101000020E610000025AE635C71E94240B9162D40DBFC4B40
59403	1	10	\N	59520	80639	\N	56.014619000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Институтская, 15		0101000020E61000006DAAEE91CDED42403B730F09DF014C40
59394	1	10	\N	59520	80514	\N	56.004486878391504	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Горького, 20	Россия, Московская область, Пушкинский район, Пушкино, улица Горького, 20	0101000020E61000000569C6A2E9EC4240EA20AF0793004C40
59406	1	10	\N	59520	80644	\N	56.043838999999998	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Заветы Ильича,  ул.Вокзальная, 14		0101000020E6100000130F289B72ED424009A52F849C054C40
59376	1	10	\N	4116	80640	\N	54.8635513370361	Московская область, городской округ Протвино, ул. Школьная, 12		0101000020E6100000514F1F813F9C4240CCB6D3D6886E4B40
59381	1	10	\N	4116	1115	\N	54.879686999999997	Московская область, городской округ Протвино, Северный проезд, 9	Россия, Московская область, Протвино, Северный проезд, 9	0101000020E6100000C9FFE4EFDE9B4240B1DB679599704B40
59380	1	10	\N	4116	1104	\N	54.875056000000001	Московская область, городской округ Протвино, Лесной бульвар, 1Б	Россия, Московская область, Протвино, Лесной бульвар, 1	0101000020E61000006072A3C85A9B42409415C3D501704B40
59377	1	10	\N	4116	80459	\N	54.864938000000002	Московская область, городской округ Протвино, ул. Ленина, 8	Россия, Московская область, Протвино, улица Ленина, 8	0101000020E6100000B212F3ACA49B4240A988D349B66E4B40
59378	1	10	\N	4116	80457	\N	54.870347000000002	Московская область, городской округ Протвино, ул. Дружбы, 20	Россия, Московская область, Протвино, улица Дружбы, 20	0101000020E6100000ABD1AB014A9B4240FB95CE87676F4B40
59382	1	10	\N	4116	80465	\N	54.874724000000001	Московская область, городской округ Протвино, проезд Архитектора Корина, 6		0101000020E61000006EC328081E9D42405E83BEF4F66F4B40
59297	1	10	\N	204	8053	\N	55.444144000000001	Московская область, городской округ Подольск, ул. Ульяновых, д. 27	Россия, Московская область, Подольск, улица Ульяновых, 27	0101000020E610000009C03FA54AC84240795BE9B5D9B84B40
59292	1	10	\N	204	8001	\N	55.440626000000002	Московская область, городской округ Подольск, ул. Павлика Морозова, д. 30	Россия, Московская область, Подольск, улица Павлика Морозова, 30	0101000020E6100000FD4B529962C6424037E2C96E66B84B40
59316	1	10	\N	204	80405	\N	55.420282254148397	Московская область, городской округ Подольск, ул. Гайдара, д. 10	Россия, Московская область, Подольск, улица Гайдара, 10	0101000020E610000045F6419605C342407A8CF2CCCBB54B40
59266	1	10	\N	204	7750	\N	55.486412999999999	Московская область, городской округ Подольск, пр. Юных Ленинцев, 90	Россия, Московская область, Подольск, проспект Юных Ленинцев, 90	0101000020E61000008F554ACFF4C84240B4ACFBC742BE4B40
59289	1	10	\N	204	7978	\N	55.463211999999999	Московская область, городской округ Подольск, пр-д. Авиаторов, д. 4	Россия, Московская область, Подольск, проезд Авиаторов, 4	0101000020E6100000E1D39CBCC8C64240B08EE3874ABB4B40
59307	1	10	\N	204	80392	\N	55.428317	Московская область, городской округ Подольск, ул. Юбилейная, д. 19	Россия, Московская область, Подольск, Юбилейная улица, 19	0101000020E6100000492C29779FBF424011A96917D3B64B40
59311	1	10	\N	204	80389	\N	55.421218388513303	Московская область, городской округ Подольск, ул. Юбилейная, д. 5	Россия, Московская область, Подольск, Юбилейная улица	0101000020E6100000B6A1629CBFBF4240473EAF78EAB54B40
59306	1	10	\N	204	80389	\N	55.428272337640301	Московская область, городской округ Подольск, ул. Юбилейная, д.19	Россия, Московская область, Подольск, Юбилейная улица, 19	0101000020E6100000D32F116F9DBF424071E5EC9DD1B64B40
59326	1	10	\N	204	80897	\N	55.441560000000003	Московская область, городской округ Подольск, ул. Халатова, д. 3		0101000020E6100000D042024697C94240639CBF0985B84B40
59333	1	10	\N	204	80440	\N	55.406114000000002	Московская область, городской округ Подольск, ул. Филиппова, д. 6б		0101000020E61000006EA6423C12C942405039268BFBB34B40
59296	1	10	\N	204	8043	\N	55.433281999999998	Московская область, городской округ Подольск, ул. Февральская, д. 65	Россия, Московская область, Подольск, Февральская улица, 65	0101000020E6100000F1F09E03CBC5424005F9D9C875B74B40
59301	1	10	\N	204	80375	\N	55.429859	Московская область, городской округ Подольск, ул. Февральская, д. 30		0101000020E6100000B282DF8618C742401572A59E05B74B40
59299	1	10	\N	204	80372	\N	55.434460999999999	Московская область, городской округ Подольск, ул. Ульяновых, д. 1		0101000020E610000090BFB4A84FC842409831056B9CB74B40
59337	1	10	\N	204	80471	\N	55.397803668403803	Московская область, городской округ Подольск, ул. Сосновая, д. 10	Россия, Московская область, Подольск, Сосновая улица, 10	0101000020E61000006556EF703BC84240E71BD13DEBB24B40
59329	1	10	\N	204	80446	\N	55.421517000000001	Московская область, городской округ Подольск, ул. Северная, д. 9	Россия, Московская область, Подольск, Северная улица, 9	0101000020E6100000022EC896E5C94240A1DAE044F4B54B40
59317	1	10	\N	204	79995	\N	55.418114000000003	Московская область, городской округ Подольск, ул. Свердлова, д. 48а	Россия, Московская область, Подольск, улица Свердлова, 48а	0101000020E6100000ED444948A4C34240F8FF71C284B54B40
59302	1	10	\N	204	8104	\N	55.430880999999999	Московская область, городской округ Подольск, Революционный проспект, д. 27/16	Россия, Московская область, Подольск, Революционный проспект, 25/12	0101000020E6100000E50AEF7211C74240E0BBCD1B27B74B40
59287	1	10	\N	204	80364	\N	55.466327780125702	Московская область, городской округ Подольск, ул. Профсоюзная, д. 6	Россия, Московская область, Подольск, Профсоюзная улица, 6	0101000020E61000002EC901BB9AC64240C39ACAA2B0BB4B40
59334	1	10	\N	204	80075	\N	55.405859460436702	Московская область, городской округ Подольск, ул. Правды, д. 21	Россия, Московская область, Подольск, улица Правды, 21	0101000020E61000004BB0389CF9C74240C5E40D30F3B34B40
59330	1	10	\N	204	80075	\N	55.411423248979503	Московская область, городской округ Подольск, ул. Правды, д. 4а	Россия, Московская область, Подольск, улица Правды, 4а	0101000020E61000005BD07B6308C842403EE94482A9B44B40
59320	1	10	\N	204	80024	\N	55.415853287068202	Московская область, городской округ Подольск, ул. Победы, д. 2	Россия, Московская область, Подольск, улица Победы, 2	0101000020E610000021AD31E884C44240C478CDAB3AB54B40
59288	1	10	\N	204	80369	\N	55.456000000000003	Московская область, городской округ Подольск, ул. Плещеевская, д. 48а		0101000020E6100000567E198C11CB4240EE7C3F355EBA4B40
59305	1	10	\N	204	8134	\N	55.431524000000003	Московская область, городской округ Подольск, Пахринский проезд, д. 6	Россия, Московская область, Подольск, Пахринский проезд, 8	0101000020E61000006971C63027C0424035B8AD2D3CB74B40
59304	1	10	\N	204	80406	\N	55.429565284564298	Московская область, городской округ Подольск, ул. Парковая, д. 18	Россия, Московская область, Подольск, Парковая улица, 20	0101000020E61000004B2366F679C24240CC4065FCFBB64B40
59291	1	10	\N	204	79840	\N	55.4458378315434	Московская область, городской округ Подольск, ул. Павлика Морозова, д. 69		0101000020E6100000B9718BF9B9C5424033A8363811B94B40
59310	1	10	\N	204	71843	\N	55.423261635556401	Московская область, городской округ Подольск, Октябрьский проспек, д. 7	Россия, Московская область, Подольск, Октябрьский проспект, 7	0101000020E61000009160AA99B5C04240DDD1FF722DB64B40
59309	1	10	\N	204	71843	\N	55.423162860400097	Московская область, городской округ Подольск, Октябрьский проспект, д. 7	Россия, Московская область, Подольск, Октябрьский проспект, 7	0101000020E61000004963B48EAAC042404AF086342AB64B40
59315	1	10	\N	204	80400	\N	55.419958539840202	Московская область, городской округ Подольск, ул. Народная, д. 4	Россия, Московская область, Подольск, Народная улица, 4	0101000020E6100000A8195245F1C4424097546D37C1B54B40
59298	1	10	\N	204	8057	\N	55.440728	Московская область, городской округ Подольск, ул. Мраморная, д. 5	Россия, Московская область, Подольск, Мраморная улица, 5	0101000020E6100000C1374D9F1DC842403B376DC669B84B40
59332	1	10	\N	204	79785	\N	55.407382632203998	Московская область, городской округ Подольск, ул. Молодежная, д. 9	Россия, Московская область, Подольск, Молодежная улица, 9	0101000020E6100000B4E55C8AABC8424023F94A2025B44B40
59328	1	10	\N	204	80425	\N	55.421609788666601	Московская область, городской округ Подольск, ул. Мира, д. 4	Россия, Московская область, Подольск, улица Мира, 4	0101000020E6100000CEC5DFF604C9424052D50451F7B54B40
59303	1	10	\N	204	80374	\N	55.427723999999998	Московская область, городской округ Подольск, ул. Маштакова, д. 7		0101000020E61000003FFF3D78EDC242406EDBF7A8BFB64B40
59167	1	10	\N	18912	79905	\N	55.811890872766199	Московская область, городской округ Орехово-Зуево, Волкова, 29	Россия, Московская область, Орехово-Зуево, улица Волкова	0101000020E610000075B0FECF618043405875560BECE74B40
59331	1	10	\N	204	80443	\N	55.409815000000002	Московская область, городской округ Подольск, ул. Машиностроителей, д. 9	Россия, Московская область, Подольск, улица Машиностроителей, 9	0101000020E6100000EAB0C22D1FC94240833463D174B44B40
59321	1	10	\N	204	79784	\N	55.4149067257908	Московская область, городской округ Подольск, ул. Литейная, д. 27	Россия, Московская область, Подольск, Литейная улица, 27	0101000020E6100000F65CA626C1C54240D4F02DAC1BB54B40
59325	1	10	\N	204	80456	\N	55.404989999999998	Московская область, городской округ Подольск, ул. Лапшенкова, д. 5		0101000020E6100000F7AE415F7AC54240809A5AB6D6B34B40
59300	1	10	\N	204	80394	\N	55.432975856012803	Московская область, городской округ Подольск, ул. Красная, д. 20	Россия, Московская область, Подольск, Красная улица	0101000020E6100000456458C51BC74240F8F9EFC16BB74B40
58449	1	10	\N	204	6143	\N	55.433925000000002	Московская область, городской округ Королёв, Кооперативный проезд, 1	Россия, Московская область, Подольск, Кооперативный проезд, 3	0101000020E61000009E280989B4C742405AF5B9DA8AB74B40
59294	1	10	\N	204	79783	\N	55.433996996690901	Московская область, городской округ Подольск, ул. Комсомольская, д. 84	Россия, Московская область, Подольск, Комсомольская улица, 84	0101000020E610000000AB23473AC54240F3C7B4368DB74B40
59319	1	10	\N	204	79945	\N	55.414794197345799	Московская область, городской округ Подольск, ул. Высотная, д. 17	Россия, Московская область, Подольск, Высотная улица, 17	0101000020E6100000AB06616EF7C24240DC4944F817B54B40
59318	1	10	\N	204	79945	\N	55.419288999999999	Московская область, городской округ Подольск, ул. Высотная, д. 5	Россия, Московская область, Подольск, Высотная улица, 5/12	0101000020E61000003EAF78EA91C2424049490F43ABB54B40
59324	1	10	\N	204	80412	\N	55.413980000000002	Московская область, городской округ Подольск, ул. Володи Дубинина, д. 3		0101000020E6100000D368723106C642405B99F04BFDB44B40
59322	1	10	\N	204	80412	\N	55.414403999999998	Московская область, городской округ Подольск, ул. Володи Дубинина, д. 6/29		0101000020E6100000B56D1805C1C5424071AAB5300BB54B40
59323	1	10	\N	204	80409	\N	55.411848999999997	Московская область, городской округ Подольск, ул. Ватутина, д. 34		0101000020E6100000744012F6EDC44240F5F1D077B7B44B40
59286	1	10	\N	204	80363	\N	55.473979999999997	Московская область, городской округ Подольск, ул. Быковская, д. 9		0101000020E61000005E64027E8DC84240A27A6B60ABBC4B40
59336	1	10	\N	204	80455	\N	55.399295000000002	«Средняя общеобразовательная школа № 13» - ул. Бородинская, 20	Россия, Московская область, Подольск, Бородинская улица, 20	0101000020E6100000FE648C0FB3C74240693A3B191CB34B40
59335	1	10	\N	204	80455	\N	55.3988799108892	Московская область, городской округ Подольск, ул. Бородинская, д. 20	Россия, Московская область, Подольск, Бородинская улица, 20	0101000020E610000000016BD5AEC74240A583F57F0EB34B40
59312	1	10	\N	204	52	\N	55.427908000000002	Московская область, городской округ Подольск, ул. Большая Серпуховская, д. 2/24	Россия, Московская область, Подольск, Большая Серпуховская улица, 4	0101000020E6100000AF7C96E7C1C5424030D978B0C5B64B40
59314	1	10	\N	204	80414	\N	55.423549999999999	Московская область, городской округ Подольск, ул. Большая Серпуховская, д. 20/1		0101000020E610000011C30E63D2C54240431CEBE236B64B40
59295	1	10	\N	204	79948	\N	55.4320441957016	Московская область, городской округ Подольск, ул. Большая Зеленовская, д. 54/82	Россия, Московская область, Подольск, Большая Зеленовская улица	0101000020E6100000EB3BBF2841C542406D37C1374DB74B40
59293	1	10	\N	204	79839	\N	55.434459946998203	Московская область, городской округ Подольск, ул. Большая Зеленовская, д. 50	Россия, Московская область, Подольск, Большая Зеленовская улица	0101000020E6100000DC2A8881AEC54240C8B5A1629CB74B40
59327	1	10	\N	204	80065	\N	55.418860000000002	Московская область, городской округ Подольск, ул. Батырева, д. 2/7		0101000020E6100000C710001C7BCA424021CD58349DB54B40
59660	1	10	\N	61915	80017	\N	56.414424451161899	Московская область, Сергиево-Посадский муниципальный район, городское поселение Пересвет, Пионерская, 1		0101000020E61000003318231285164340B8567BD80B354C40
59662	1	10	\N	61915	80196	\N	56.415701598856899	Московская область, Сергиево-Посадский муниципальный район, городское поселение Пересвет, Мира, 13		0101000020E6100000F25EB532E1154340DF701FB935354C40
59263	1	10	\N	61875	80356	\N	55.790255999999999	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Школьная, 14		0101000020E6100000D175E107E7574340E0BBCD1B27E54B40
59267	1	10	\N	61875	79841	\N	55.770146276057503	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Тимирязева, 13		0101000020E6100000F6D03E56F05543409692E52494E24B40
59256	1	10	\N	61875	80357	\N	55.780304000000001	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Кирова, 87		0101000020E61000005C74B2D47A55434010786000E1E34B40
59986	1	10	\N	61875	80509	\N	55.792346000000002	Московская область, городской округ Химки, Дружбы, 3		0101000020E61000008D63247B844E4340E78EFE976BE54B40
59260	1	10	\N	61875	79847	\N	55.781434347687302	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Выставкина, 1	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Карповская улица, 1	0101000020E6100000D1B2EE1F0B554340C1FD800706E44B40
59270	1	10	\N	61875	80355	\N	55.770992999999997	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Большая Покровская, 37		0101000020E6100000265646239F534340F3380CE6AFE24B40
58864	1	10	\N	59539	80335	\N	55.377982000000003	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Ленина, 23		0101000020E6100000DD9A745B225D4240043DD4B661B04B40
60192	1	10	\N	62020	80913	\N	55.881890505617903	Московская область, Щелковский муниципальный район, деревня Осеево, Центральная, 24 ( Сельский ДК деревни Осеево)	Россия, Московская область, городской округ Лосино-Петровский, деревня Осеево, Центральная улица, 22	0101000020E61000002FA86F99D317434081D1E5CDE1F04B40
59143	1	10	\N	18912	70966	\N	55.807840598995803	Московская область, городской округ Орехово-Зуево, Володарского, 6	Россия, Московская область, Орехово-Зуево, улица Володарского, 6	0101000020E6100000EFE2FDB8FD7A434019AF795567E74B40
59171	1	10	\N	18912	6764	\N	55.802897000000002	Московская область, городской округ Орехово-Зуево, Бугрова, 5	Россия, Московская область, Орехово-Зуево, улица Бугрова, 5	0101000020E61000002E01F8A7547F43403C873254C5E64B40
59146	1	10	\N	18912	6516	\N	55.811098000000001	Московская область, городской округ Орехово-Зуево, Бирюкова, 25	Россия, Московская область, Орехово-Зуево, улица Бирюкова, 25	0101000020E61000000ED8D5E4297B4340EEEC2B0FD2E74B40
59159	1	10	\N	18912	6634	\N	55.82132	Московская область, городской округ Орехово-Зуево, пр.Беляцкого, 17	Россия, Московская область, Орехово-Зуево, проезд Беляцкого, 17	0101000020E6100000CD57C9C7EE7E43407EC6850321E94B40
59156	1	10	\N	18912	79826	\N	55.817212019495898	Московская область, городской округ Орехово-Зуево, Пушкина, 6	Россия, Московская область, Орехово-Зуево, площадь Пушкина, 6	0101000020E6100000DBDD03745F7C43400AF31E679AE84B40
59168	1	10	\N	18912	80869	\N	55.815510876248403	Московская область, городской округ Орехово-Зуево, Торфобрикетная, 18	Россия, Московская область, Орехово-Зуево, Торфобрикетная улица	0101000020E61000006170CD1DFD8143409E4319AA62E84B40
59149	1	10	\N	18912	79823	\N	55.812978136459201	Московская область, городской округ Орехово-Зуево, Пушкина, 3 а	Россия, Московская область, Орехово-Зуево, улица Пушкина, 3а	0101000020E6100000077B1343727C43400A2FC1A90FE84B40
59140	1	10	\N	18912	80125	\N	55.791800000000002	Московская область, городской округ Орехово-Зуево, Правды, 7	Россия, Московская область, Орехово-Зуево, улица Правды, 7	0101000020E6100000A3E716BA12794340857CD0B359E54B40
59161	1	10	\N	18912	80184	\N	55.820708000000003	Московская область, городской округ Орехово-Зуево, Парковская, 57		0101000020E610000067EDB60BCD7F434065C8B1F50CE94B40
59162	1	10	\N	18912	80205	\N	55.815633299014003	Московская область, городской округ Орехово-Зуево, Набережная, 3		0101000020E61000006CCF2C09507F4340E94482A966E84B40
59166	1	10	\N	18912	71880	\N	55.815363062128498	Московская область, городской округ Орехово-Зуево, Мира, 12	Россия, Московская область, Орехово-Зуево, улица Мира	0101000020E61000007C4276DEC680434029AF95D05DE84B40
59175	1	10	\N	18912	80206	\N	55.801712999999999	Московская область, городской округ Орехово-Зуево, Мадонская, 4		0101000020E6100000E833A0DE8C7C434097E315889EE64B40
59160	1	10	\N	18912	80188	\N	55.815119000000003	Московская область, городской округ Орехово-Зуево, Лопатина, 17		0101000020E6100000C66AF3FFAA7D434093ACC3D155E84B40
59177	1	10	\N	18912	71807	\N	55.807660090276102	Московская область, городской округ Орехово-Зуево, Ленина, 93	Россия, Московская область, Орехово-Зуево, улица Ленина, 93	0101000020E61000002A1E17D5227E4340C824236761E74B40
59176	1	10	\N	18912	71807	\N	55.800907780663103	Московская область, городской округ Орехово-Зуево, Ленина, 55		0101000020E6100000F4FC69A33A7D4340698D412784E64B40
59169	1	10	\N	18912	80203	\N	55.081065000000002	Московская область, городской округ Орехово-Зуево, Красина, 1		0101000020E6100000EEAF1EF7AD644340D5EC8156608A4B40
59151	1	10	\N	18912	80170	\N	55.815919863464202	Московская область, городской округ Орехово-Зуево, Козлова, 5	Россия, Московская область, Орехово-Зуево, улица Козлова, 5	0101000020E6100000971AA19FA97B43407F130A1170E84B40
59150	1	10	\N	18912	74074	\N	55.816269193460798	Московская область, городской округ Орехово-Зуево, Колзлова, 5		0101000020E6100000731074B4AA7B43408BDEA9807BE84B40
59165	1	10	\N	18912	72048	\N	55.818165959781403	Московская область, городской округ Орехово-Зуево, Клязьминский пр, 8	Россия, Московская область, Орехово-Зуево, Клязьменский проезд	0101000020E6100000E8F527F1B97F43407D59DAA9B9E84B40
59147	1	10	\N	18912	80147	\N	55.813869315007302	Московская область, городской округ Орехово-Зуево, Иванова, 11	Россия, Московская область, Орехово-Зуево, улица Иванова, 11	0101000020E6100000F5DA6CACC47A4340361D01DC2CE84B40
59145	1	10	\N	18912	80147	\N	55.811195340282602	Московская область, городской округ Орехово-Зуево, Иванова, 4		0101000020E61000000D384BC9727A4340E0D6DD3CD5E74B40
59172	1	10	\N	18912	71791	\N	55.798249909342204	Московская область, городской округ Орехово-Зуево, Зеленая, 26	Россия, Московская область, Орехово-Зуево	0101000020E6100000B56D1805C18143401904560E2DE64B40
59174	1	10	\N	18912	79910	\N	55.794696762729501	Московская область, городской округ Орехово-Зуево, Егорьевская, 2	Россия, Московская область, Орехово-Зуево, Егорьевская улица, 2	0101000020E6100000718FA50F5D7C43405A9D9CA1B8E54B40
59173	1	10	\N	18912	71905	\N	55.792701000000001	Московская область, городской округ Орехово-Зуево, Горького, 11	Россия, Московская область, Орехово-Зуево, улица Горького, 11	0101000020E61000006E895C70067D4340D540F33977E54B40
59158	1	10	\N	18912	80182	\N	55.816423999999998	Московская область, городской округ Орехово-Зуево, Галочкина, 24		0101000020E6100000406B7EFCA57D4340B2D5E59480E84B40
59142	1	10	\N	18912	80136	\N	55.804389999999998	Московская область, городской округ Орехово-Зуево, Гагарина, 8	Россия, Московская область, Орехово-Зуево, улица Гагарина, 8	0101000020E6100000755B22179C7B43405E9D6340F6E64B40
59141	1	10	\N	18912	80136	\N	55.800716380733597	Московская область, городской округ Орехово-Зуево, Гагарина, 21	Россия, Московская область, Орехово-Зуево, улица Гагарина, 21	0101000020E6100000B114C957027B434025B1A4DC7DE64B40
59170	1	10	\N	18912	80189	\N	55.799076647995903	Московская область, городской округ Орехово-Зуево, Бугрова, 7	Россия, Московская область, Орехово-Зуево, улица Бугрова, 7	0101000020E610000009DE9046058043402EFEB62748E64B40
59138	1	10	\N	18912	80679	\N	55.788291999999998	Московская область, городской округ Орехово-Зуево, Бондаренко, 15		0101000020E61000002905DD5ED276434066D993C0E6E44B40
59137	1	10	\N	18912	80679	\N	55.788291999999998	Московская область, городской округ Орехово-Зуево, ул.Бондаренко, д.15		0101000020E61000002905DD5ED276434066D993C0E6E44B40
59148	1	10	\N	18912	6533	\N	55.814597999999997	Московская область, городской округ Орехово-Зуево, пр.4 Козлова, 1	Россия, Московская область, Орехово-Зуево, 4-й проезд Козлова, 1	0101000020E6100000CAC342AD697A434089B14CBF44E84B40
59126	1	10	\N	60229	80839	\N	54.857145241075202	Московская область, г. Озёры, пл. Советская, 1	Россия, Московская область, Озерский район, Озеры, улица Карла Маркса	0101000020E610000006103E9468474340087767EDB66D4B40
59115	1	10	\N	60229	81047	\N	54.859222000000003	Московская область,г.Озеры,микрорайон им. Маршала Катукова, Помещение гимназии №4		0101000020E610000020B75F3E594543407A008BFCFA6D4B40
55997	1	10	\N	62063	81055	\N	54.790132	г.Ожерелье, ул.Советская, д.20		0101000020E6100000598B4F0130224340F4C29D0B23654B40
59034	1	10	\N	61912	80370	\N	55.695332000000001	г. Одинцово, Чистяковой, 10		0101000020E61000008A03E8F7FDA942405FEE93A300D94B40
59032	1	10	\N	61912	80667	\N	55.684671000000002	г. Одинцово, Чикина, 13		0101000020E610000096E82CB308A5424083C2A04CA3D74B40
59039	1	10	\N	61912	81020	\N	55.681788194517203	г. Одинцово, Трудовая, 36	Россия, Московская область, Одинцовский район, Одинцово, поселок Баковка, Трудовая улица, 6	0101000020E61000003BDF4F8D97A84240126745D444D74B40
59962	1	10	\N	61912	79988	\N	55.671945000000001	Московская область, городской округ Химки, Союзная, 3		0101000020E6100000207F69519FA44240F9DA334B02D64B40
59021	1	10	\N	61912	80658	\N	55.678555000000003	г. Одинцово, Северная, 20		0101000020E610000026A60BB1FA9F4240C6C4E6E3DAD64B40
59030	1	10	\N	61912	80665	\N	55.682904000000001	г. Одинцово, Ново-Спортивная, 14		0101000020E6100000342F87DD77A442405F27F56569D74B40
94491	1	10	\N	61912	80083	\N	55.673605000000002	Одинцовская средняя общеобразовательная школа № 12 – 143002, Московская область, Одинцовский район, город Одинцово, улица Молодежная, дом № 16В		0101000020E610000088D860E124A1424007B64AB038D64B40
58621	1	10	\N	61912	80083	\N	55.674768	г. Одинцово, Молодежная, 3А		0101000020E610000052D32EA699A0424094313ECC5ED64B40
59040	1	10	\N	61912	80692	\N	55.685614000000001	г. Одинцово, Можайское шоссе, 149		0101000020E610000032E4D87A86A6424002D71533C2D74B40
59045	1	10	\N	61912	80681	\N	55.667212999999997	г. Одинцово, Комсомольская, 9		0101000020E6100000904DF2237EA54240A73B4F3C67D54B40
59038	1	10	\N	61912	80672	\N	55.674726999999997	г. Одинцово, Вокзальная, 5		0101000020E61000003F0114234BA44240355D4F745DD64B40
59043	1	10	\N	61912	80318	\N	55.656086999999999	г. Одинцово, Верхне-Пролетарская, 14	Россия, Московская область, Одинцовский район, Одинцово, 14	0101000020E61000003543AA285EA34240562AA8A8FAD34B40
58951	1	10	\N	60231	80615	\N	55.835917999999999	г.Ногинск, Юбилейная, 3		0101000020E6100000B189CC5CE0324340A1116C5CFFEA4B40
58809	1	10	\N	60231	80630	\N	55.848685000000003	г.Ногинск, 3-го Интернационала, 117		0101000020E6100000242713B70A3643408ACDC7B5A1EC4B40
58955	1	10	\N	60231	79992	\N	55.882278999999997	г.Ногинск, Советской Конституции, 16		0101000020E6100000FBCDC474213A43404A79AD84EEF04B40
58702	1	10	\N	60231	74114	\N	55.850995895141402	г.Ногинск, Советская, 101	Россия, Московская область, Ногинский район, Ногинск, Советская улица	0101000020E6100000F04FA912653743406F83DA6FEDEC4B40
58937	1	10	\N	60231	80642	\N	55.852789000000001	г.Ногинск, Октябрьская, 83		0101000020E6100000E5603601863F4340BCB1A03028ED4B40
58960	1	10	\N	60231	74078	\N	55.8558065565324	г.Ногинск, наб.60-летия Октября, 2		0101000020E61000002AAC5450513743400C5872158BED4B40
58944	1	10	\N	60231	80069	\N	55.878611999999997	городское поселение Ногинск, город Ногинск Краснослободская 2 в		0101000020E610000033A6608DB33B4340C3EFA65B76F04B40
58939	1	10	\N	60231	79943	\N	55.856360042206198	г.Ногинск, Комсомольская, 3		0101000020E6100000DF516342CC39434021CD58349DED4B40
58957	1	10	\N	60231	80643	\N	55.887286000000003	г.Ногинск, Кирова, 3		0101000020E61000006ABE4A3E763D43406E19709692F14B40
58961	1	10	\N	60231	80651	\N	55.872121999999997	г.Ногинск, Зенитчиков, 1		0101000020E6100000679AB0FD64384340A10F96B1A1EF4B40
58963	1	10	\N	60231	80648	\N	55.878162000000003	г.Ногинск, Декабристов, 79 б		0101000020E610000051A4FB3905374340844BC79C67F04B40
58950	1	10	\N	60231	80652	\N	55.842847999999996	г.Ногинск, Бабушкина, 3		0101000020E6100000AE9E93DE37344340DFBF7971E2EB4B40
58514	1	10	\N	61934	80311	\N	55.839689	Московская область, Красногорский муниципальный район, городское поселение Нахабино, Институтская, 1		0101000020E6100000759483D904984240CDE7DCED7AEB4B40
58509	1	10	\N	59557	\N	\N	55.844353189584801	Московская область, Красногорский муниципальный район, городское поселение Нахабино, Нахабинский учебный центр		0101000020E610000083F92B64AE944240C6A354C213EC4B40
58512	1	10	\N	59557	80313	\N	55.851798000000002	Московская область, Красногорский муниципальный район, городское поселение Нахабино, 11 Саперов, 6		0101000020E610000067EF8CB62A9742402C6684B707ED4B40
58862	1	10	\N	59539	80627	\N	55.387315000000001	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Школьная, 6		0101000020E610000000AE64C7465C42400820B58993B14B40
58872	1	10	\N	59539	80694	\N	55.412492999999998	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Шибанкова, 28	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, улица Шибанкова, 28	0101000020E6100000F702B342915C42401A6A1492CCB44B40
58865	1	10	\N	59539	80105	\N	55.371592	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Погодина, 93а		0101000020E610000060C8EA56CF5F424045BA9F5390AF4B40
58870	1	10	\N	59539	71871	\N	55.392204175849599	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Парк Воровского, 14		0101000020E61000007AFD497CEE5E424021AE9CBD33B24B40
58866	1	10	\N	59539	80899	\N	55.382072999999998	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Московская, 9		0101000020E6100000F8E0B54B1B604240A1D79FC4E7B04B40
58667	1	10	\N	59539	80335	\N	55.383474999999997	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Ленина, 5		0101000020E61000004D309C6B985D4240B3EA73B515B14B40
58818	1	10	\N	60249	80616	\N	55.906047000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Щербакова, дом 1А		0101000020E61000002461DF4E22DE4240C8D11C59F9F34B40
58788	1	10	\N	60249	80055	\N	55.901116999999999	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Фрунзе, дом 11 в помещении бывшей общеобраз		0101000020E6100000EDB60BCD75E04240506F46CD57F34B40
58695	1	10	\N	60249	80378	\N	55.938651999999998	Московская область, Мытищинский муниципальный район, г. Мытищи, Силикатная улица, дом 33		0101000020E61000005793A7ACA6E342409929ADBF25F84B40
58817	1	10	\N	60249	80612	\N	55.898800000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Семашко, дом 2		0101000020E6100000FEBAD39D27DE424089D2DEE00BF34B40
58857	1	10	\N	60249	80080	\N	55.88456	Московская область, Мытищинский муниципальный район, г. Мытищи, Октябрьская улица, дом 4А в помещении МОУ средня		0101000020E6100000CAFB389A23DF4240C5AC174339F14B40
58826	1	10	\N	60249	79927	\N	55.899960999999998	Московская область, Мытищинский муниципальный район, г. Мытищи, Новомытищинский проспект, дом 88, корп.5		0101000020E6100000CEE15AED61DB424075560BEC31F34B40
58822	1	10	\N	60249	79927	\N	55.904079000000003	Московская область, Мытищинский муниципальный район, г. Мытищи, Новомытищинский проспект, дом 82, корп.10		0101000020E61000005A2E1B9DF3DB42400D0055DCB8F34B40
58820	1	10	\N	60249	79927	\N	55.906793999999998	Московская область, Мытищинский муниципальный район, г. Мытищи, Новомытищинский проспект, дом 74		0101000020E61000000C5BB39597DC4240C11A67D311F44B40
58810	1	10	\N	60249	79927	\N	55.909978000000002	Московская область, Мытищинский муниципальный район, г. Мытищи, Новомытищинский проспект, дом 38		0101000020E6100000AF415F7AFBDD42402D0ABB287AF44B40
58812	1	10	\N	60249	80599	\N	55.920763999999998	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Колпакова, дом 34		0101000020E6100000E50AEF7211DD4240C5AA4198DBF54B40
58803	1	10	\N	60249	80606	\N	55.924748999999998	Московская область, Мытищинский муниципальный район, г. Мытищи, Индустриальная улица, дом 7 корп.2		0101000020E610000068CA4E3FA8E142401D01DC2C5EF64B40
58829	1	10	\N	60249	80076	\N	55.894646000000002	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Веры Волошиной, дом 12		0101000020E610000085CE6BEC12DD4240A5BF97C283F24B40
58813	1	10	\N	60249	80618	\N	55.909474000000003	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Борисовка, дом 4		0101000020E6100000C7D79E5912DA4240FA47DFA469F44B40
58805	1	10	\N	60249	80610	\N	55.921723	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Белобородова, дом 5		0101000020E6100000DCBA9BA73AE042404A7CEE04FBF54B40
58792	1	10	\N	60249	80525	\N	55.916446000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Академика Каргина, дом 36, корп.2		0101000020E6100000494DBB9866E4424067463F1A4EF54B40
58856	1	10	\N	60249	80081	\N	55.883555000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, 4-я Парковая улица, дом 20 в помещении библиотек		0101000020E6100000E0F76F5E9CE04240D09B8A5418F14B40
58831	1	10	\N	60249	80641	\N	55.893914000000002	Московская область, Мытищинский муниципальный район, г. Мытищи, 3-я Крестьянская улица, дом 17		0101000020E61000003C2D3F7095DB4240E1B721C66BF24B40
60177	1	10	\N	61942	80571	\N	55.833297028385999	Московская область, Щелковский муниципальный район, городское поселение Монино, Авиационная, 25 (Дом офицеров гарнизона)		0101000020E6100000E65C8AABCA1643406E6DE179A9EA4B40
58738	1	10	\N	61930	80535	\N	55.507427999999997	Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, Полосухина, 7 (Филиал МГУПИ)		0101000020E6100000481ADCD6160442408F899466F3C04B40
58734	1	10	\N	61930	80489	\N	55.505229999999997	Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, Московская, 48 (Средняя школа№1)		0101000020E610000075E8F4BC1B034240A27A6B60ABC04B40
58729	1	10	\N	61930	80489	\N	55.508023999999999	Московская область, Можайский муниципальный район, городское поселение Можайск,  г.Можайск, Московская, 9 (РКДЦ)		0101000020E61000004D69FD2D01024240A3CA30EE06C14B40
58742	1	10	\N	61930	80527	\N	55.504669999999997	Московская область, Можайский муниципальный район, городское поселение Можайск, г. Можайск, Мира, 93 (ПУ №70)		0101000020E610000067B5C01E13054240DBA2CC0699C04B40
59155	1	10	\N	61930	80179	\N	55.502578999999997	Московская область, городской округ Орехово-Зуево, Красноармейская, 10		0101000020E6100000F8AA9509BF0242400454388254C04B40
59437	1	10	\N	61954	80715	\N	56.139114999999997	Московская область, Пушкинский муниципальный район, городское поселение Софрино, Митрополье, Совхозная, 27		0101000020E6100000179CC1DF2FEE424007B13385CE114C40
59804	1	10	\N	59512	71788	\N	56.039291028031798	Менделеево, Куйбышево, 11		0101000020E6100000D68F4DF2239E42407903CC7C07054C40
58723	1	10	\N	59538	71868	\N	55.6226004527689	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, МЭЗ, Быковское шоссе, 52а (средняя школа № 52)		0101000020E61000007F6DFDF49FFF4240AB3E575BB1CF4B40
58666	1	10	\N	61892	79892	\N	55.6918706155679	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, поселок Калинина, 56 (школа № 10)	Россия, Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 55к1	0101000020E6100000BF805EB873EF424081069B3A8FD84B40
58583	1	10	\N	22625	79907	\N	55.868152000000002	Московская область, город Лосино-Петровский, Ленина, 1		0101000020E6100000C828CFBC1C1A43407FFACF9A1FEF4B40
58688	1	10	\N	61892	80377	\N	55.662537	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Электрификации, 30 (средняя школа № 2)		0101000020E6100000A3AD4A22FBF64240EAB12D03CED44B40
58681	1	10	\N	61892	80293	\N	55.666035000000001	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 348 (гимназия № 5)		0101000020E6100000BA2F67B62BF44240E57E87A240D54B40
58673	1	10	\N	61892	80293	\N	55.677768	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 178 (гимназия № 1)		0101000020E610000040C05AB56BF242403E23111AC1D64B40
58670	1	10	\N	61892	80293	\N	55.681077000000002	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 136 (училище им. Ю.А.Гагарина)		0101000020E61000002A1A6B7F67F142406687F8872DD74B40
58665	1	10	\N	61892	80293	\N	55.684483	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 114 (Областной техникум)		0101000020E610000070ECD97399F0424080D591239DD74B40
58697	1	10	\N	61892	80383	\N	55.692506000000002	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Красногорская, 3 (гимназия № 24)		0101000020E61000002B84D558C2F0424053245F09A4D84B40
58700	1	10	\N	61892	80384	\N	55.684066999999999	"Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Инициативная, 5 (УПП ""ВОС"")"		0101000020E610000066D993C0E6F24240ECA2E8818FD74B40
58652	1	10	\N	211	\N	\N	55.589310086225197	Московская область, городской округ Лыткарино, 5 микрорайон квартал 1, дом 21	Россия, Московская область, Лыткарино, 1-й квартал, 21	0101000020E61000002F3196E997F24240569A94826ECB4B40
58658	1	10	\N	211	74109	\N	55.5796972106384	Московская область, город Лыткарино, проезд Шестакова, стр.2	Россия, Московская область, Лыткарино, 7-й квартал, проезд Шестакова	0101000020E6100000234DBC033CF342406F4BE48233CA4B40
58653	1	10	\N	211	80317	\N	55.586578000000003	Московская область,г.Лыткарино, Спортивная, дом 24		0101000020E61000001C430070ECF34240CC46E7FC14CB4B40
58654	1	10	\N	211	80321	\N	55.586578000000003	Московская область, город Лыткарино, Спортивная, дом 24		0101000020E61000001C430070ECF34240CC46E7FC14CB4B40
58661	1	10	\N	211	80327	\N	55.572996000000003	Московская область,г.Лыткарино, Сафонова, дом 2а		0101000020E610000056293DD34BF44240925ED4EE57C94B40
58662	1	10	\N	211	80333	\N	55.576681000000001	Московская область, городской округ Лыткарино, Пионерская, дом 6	Россия, Московская область, Лыткарино, Пионерская улица, 6	0101000020E610000053CF8250DEF34240BF9CD9AED0C94B40
58655	1	10	\N	211	81154	\N	55.585560928192102	Московская область, городской округ Лыткарино, квартал 3а, дом 11	Россия, Московская область, Лыткарино, 3-й квартал, 11	0101000020E61000001A3048FAB4F442401268B0A9F3CA4B40
58660	1	10	\N	211	80325	\N	55.574832999999998	Московская область, г.Лыткарино, Парковая, дом 16		0101000020E6100000F3380CE6AFF44240AED4B32094C94B40
58659	1	10	\N	211	80330	\N	55.574832999999998	Московская область, город Лыткарино, Парковая, 16		0101000020E6100000F3380CE6AFF44240AED4B32094C94B40
58657	1	10	\N	211	71897	\N	55.579166268701499	Московская область, городской округ Лыткарино, Ленина, 2а	Россия, Московская область, Лыткарино, улица Ленина, 2а	0101000020E6100000C45DBD8A8CF44240427A8A1C22CA4B40
58656	1	10	\N	211	71897	\N	55.579044999070099	Московская область, городской округ Лыткарино, Ленина, дом 2а	Россия, Московская область, Лыткарино, улица Ленина, 2а	0101000020E6100000FD101B2C9CF44240C7F484251ECA4B40
58651	1	10	\N	211	80319	\N	55.5828355180222	Московская область, городской округ Лыткарино, Комсомольская, дом 34	Россия, Московская область, Лыткарино, Колхозная улица	0101000020E6100000BDC3EDD0B0F242403A77BB5E9ACA4B40
58650	1	10	\N	211	81151	\N	55.598822549072501	Московская область, городской округ Лыткарино, 6 микрорайон, строение 26	Россия, Московская область, Лыткарино, 6-й микрорайон, 26	0101000020E61000000D5531957EF04240DB8B683BA6CC4B40
58606	1	10	\N	61945	80622	\N	54.955422359494797	г. Луховицы, Пушкина, 180	Россия, Московская область, Луховицкий район, Луховицы, улица Пушкина, 178	0101000020E61000009BE271512D82434080F0A1444B7A4B40
58604	1	10	\N	61945	80622	\N	54.968200000000003	г. Луховицы, Пушкина, 132		0101000020E610000087A3AB74778343405DFE43FAED7B4B40
58603	1	10	\N	61945	80626	\N	54.971347000000002	г. Луховицы, Первомайская, 18А		0101000020E6100000A81B28F04E844340AB083719557C4B40
58608	1	10	\N	61945	80620	\N	54.950319	г. Луховицы, Мира, 16		0101000020E6100000CA349A5C8C8343403BE2900DA4794B40
58607	1	10	\N	61945	80620	\N	54.951793000000002	г. Луховицы, Мира, 12		0101000020E61000007C7BD7A02F834340E7C75F5AD4794B40
58586	1	10	\N	22625	7501	\N	55.873884376073001	Московская область, город  Лосино-Петровский, площадь Революции, 24	Россия, Московская область, Лосино-Петровский, площадь Революции	0101000020E6100000F29716F5491A4340B33F506EDBEF4B40
58585	1	10	\N	22625	79921	\N	55.867466363824597	Московская область, город  Лосино-Петровский, Чехова, 8	Россия, Московская область, Лосино-Петровский, улица Чехова	0101000020E6100000653909A52F1843402B323A2009EF4B40
58580	1	10	\N	22625	80323	\N	55.872950000000003	Московская область, город  Лосино-Петровский, Строителей, 2		0101000020E6100000D6011077F518434088855AD3BCEF4B40
58579	1	10	\N	22625	80323	\N	55.872950000000003	Московская область, город Лосино-Петровский, Строителей, 2		0101000020E6100000D6011077F518434088855AD3BCEF4B40
59271	1	10	\N	22625	7810	\N	55.878838999999999	Московская область, городской округ Подольск, ул. Почтовая, д. 2	Россия, Московская область, Лосино-Петровский, Почтовая улица, 2	0101000020E61000000A6AF816D619434084B9DDCB7DF04B40
58581	1	10	\N	22625	79877	\N	55.868611168989702	Московская область, город  Лосино-Петровский, Октябрьская, 12		0101000020E6100000158E20956219434012F92EA52EEF4B40
58582	1	10	\N	22625	79907	\N	55.870753451909302	Московская область, город  Лосино-Петровский, Ленина, 6	Россия, Московская область, Лосино-Петровский, улица Ленина	0101000020E61000007AA9D898D71943406BF294D574EF4B40
58584	1	10	\N	22625	79911	\N	55.867677	Московская область, город Лосино-Петровский, Чехова, 8		0101000020E6100000683D7C9928184340E63E390A10EF4B40
94557	1	10	\N	29102	80730	\N	56.007234192339801	Ул. Победы д.18, ЦДТ	Россия, Московская область, Лобня, улица Победы, 18	0101000020E6100000D0B7054B75BB4240AAB5300BED004C40
94551	1	10	\N	29102	28789	\N	56.020045000000003	Ул. Проезд Шадунца, д.1, школа № 9	Россия, Московская область, Лобня, проезд Шадунца, 1	0101000020E61000006A334E4354BD424063B9A5D590024C40
94554	1	10	\N	29102	79926	\N	56.015529983651902	Ул. Чехова, д. 13, школа № 8	Россия, Московская область, Лобня, улица Чехова, 13	0101000020E61000004774CFBA46BD4240AE0D15E3FC014C40
94556	1	10	\N	29102	80208	\N	56.003209146207404	Ул. Фестивальная, д.2, школа № 2	Россия, Московская область, Лобня, Фестивальная улица, 2	0101000020E6100000BBF083F3A9BD4240C4060B2769004C40
94507	1	10	\N	29102	16868	\N	56.006169999999997	Ул. Первая д. 3, ЛТСИиП	Россия, Московская область, Лобня, Первая улица, 3	0101000020E61000007958A835CDBD4240B01BB62DCA004C40
94552	1	10	\N	29102	80386	\N	56.016416	Ул. Павлика Морозова, д. 1, школа № 1		0101000020E61000001F86562767BE4240C99063EB19024C40
94572	1	10	\N	29102	80388	\N	56.047288000000002	Ул. Научный городок, д. 4, ДК «Луговая»		0101000020E6100000E1B20A9B01BE424023BF7E880D064C40
94560	1	10	\N	29102	80619	\N	56.008178000000001	Ул. Мирная, д. 24а, школа № 3		0101000020E6100000295DFA97A4BA4240FA4509FA0B014C40
94561	1	10	\N	29102	79975	\N	56.008208000000003	Ул.Ленина д.65, ДС «Лобня»		0101000020E6100000399D64ABCBB9424065C8B1F50C014C40
94559	1	10	\N	29102	79975	\N	56.009920640856201	Ул. Ленина д.29  МОУ лицей		0101000020E6100000FFCBB56801BC42409545611745014C40
94501	1	10	\N	29102	79975	\N	56.010458	Ул. Ленина, д. 15а, школа искусств	Россия, Московская область, Лобня, улица Ленина, 15а	0101000020E6100000EB3A545392BD4240A4FD0FB056014C40
94568	1	10	\N	29102	16890	\N	56.023021999999997	Ул. Краснополянская, д. 31а, спорткомплекс школы № 6,	Россия, Московская область, Лобня, Краснополянская улица, 31	0101000020E61000007FA1478C9EB54240548B8862F2024C40
94553	1	10	\N	29102	80283	\N	56.023802000000003	Ул. Комиссара Агапова, д. 8а, Досуговый центр «Восточный»		0101000020E6100000DD442DCDADBE42402ACAA5F10B034C40
94558	1	10	\N	29102	80617	\N	56.009264999999999	Ул. Дружбы д. 3, КДЦ «Чайка»	Россия, Московская область, Лобня, улица Дружбы, 3	0101000020E6100000570740DCD5BB4240ACFF73982F014C40
94566	1	10	\N	29102	80261	\N	56.026513000000001	Ул. Деповская д.18, Досуговый центр		0101000020E6100000CFF3A78DEABC42409DF529C764034C40
94571	1	10	\N	29102	80439	\N	56.020913999999998	Ул. Булычева д. 7, филиал ЦДТ	Россия, Московская область, Лобня, улица Булычева, 7	0101000020E6100000AED85F764FB64240A703594FAD024C40
94564	1	10	\N	29102	28799	\N	56.016571999999996	Ул. Букинское шоссе, д. 19, школа № 7	Россия, Московская область, Лобня, Букинское шоссе, 19	0101000020E6100000A54DD53DB2BB4240C00303081F024C40
58578	1	10	\N	29102	81059	\N	56.048299	Лобня, Ул. Большая, д. 2, Луговская средняя школа		0101000020E6100000FB027AE1CEBF4240FAB660A92E064C40
94570	1	10	\N	29102	16886	\N	56.022066000000002	Ул. Аэропортовская, д.1, школа № 6		0101000020E610000006F7031E18B64240412D060FD3024C40
94569	1	10	\N	29102	80350	\N	56.022066000000002	Ул. Аэропортовская, д.1,  школа № 6		0101000020E610000006F7031E18B64240412D060FD3024C40
94563	1	10	\N	29102	80703	\N	56.010708999999999	Ул. Авиационная, д.1, школа № 5		0101000020E6100000EEB25F77BABB4240ED629AE95E014C40
94562	1	10	\N	29102	80661	\N	56.010708999999999	Ул. Авиационная. д. 1, школа № 5		0101000020E6100000EEB25F77BABB4240ED629AE95E014C40
59194	1	10	\N	61867	79803	\N	55.715302362753	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Октябрьская, 40		0101000020E61000008AB0E1E9957A4340B76114048FDB4B40
59092	1	10	\N	61867	80220	\N	55.731115000000003	д. Ликино, Новая, 9		0101000020E610000080BA8102EF7A4340BA4E232D95DD4B40
59192	1	10	\N	61867	80300	\N	55.706780999999999	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Коммунистическая, 38		0101000020E6100000A9A10DC0067A43409337C0CC77DA4B40
59182	1	10	\N	61936	80896	\N	55.582318999999998	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Совхозная, 2		0101000020E61000009ACDE33098774340726BD26D89CA4B40
59188	1	10	\N	61936	80338	\N	55.578741999999998	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Лесная, 50		0101000020E61000009BFEEC478A7043402B69C53714CA4B40
59485	1	10	\N	61968	80746	\N	55.597459000000001	Московская область, Раменский муниципальный район,поселок Кратово, Улица Чурилина, Дом 27		0101000020E6100000F08B4B55DA144340B6D9588979CC4B40
58525	1	10	\N	59506	74117	\N	55.597575989844799	Московская область, городской округ Краснознаменск, проспект Мира, 8	Россия, Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск, проспект Мира	0101000020E6100000016A6AD95A854240EF6FD05E7DCC4B40
58535	1	10	\N	59506	79814	\N	55.600727478225103	Московская область, городской округ Краснознаменск, Молодёжная, 6	Россия, Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск, Молодежная улица	0101000020E610000009E23C9CC08442407F69519FE4CC4B40
58492	1	10	\N	59506	79814	\N	55.600678883279798	Московская область, городской округ Краснознаменск, Молодёжная, 2	Россия, Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск, Молодежная улица	0101000020E610000009168733BF8442406E32AA0CE3CC4B40
58536	1	10	\N	59506	71779	\N	55.594794	Московская область, городской округ Краснознаменск, Комсомольский бульвар, 2		0101000020E61000003D635FB2F1844240B3EDB43522CC4B40
58534	1	10	\N	59506	71896	\N	55.594268091565802	Московская область, городской округ Краснознаменск, Генерала Шлыкова, 3	Россия, Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск	0101000020E6100000E50B5A48C084424098874CF910CC4B40
59665	1	10	\N	61932	80270	\N	56.439841000000001	Московская область, Сергиево-Посадский муниципальный район, городское поселение Краснозаводск, Строителей, 17		0101000020E6100000E7A7380EBC1E43405038BBB54C384C40
58502	1	10	\N	59550	79817	\N	55.806277074813401	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Южный бульвар, 3		0101000020E6100000A647533D99A942402D42B11534E74B40
58481	1	10	\N	59550	80909	\N	55.833849999999998	Московская область, Красногорский муниципальный район, городское поселение Красногорск, мкр.Опалиха, Чапаева, 59		0101000020E6100000D5CE30B5A5A0424082E2C798BBEA4B40
94546	1	10	\N	59550	71917	\N	55.842951015582301	Г.Красногорск, мкр. Опалиха, ул. Ткацкой фабрики,д.18, Новоникольская амбулатория		0101000020E61000003B3602F1BAA04240B49080D1E5EB4B40
58497	1	10	\N	59550	80119	\N	55.824182	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Речная, 8/1		0101000020E610000047AE9B525EAB4240D7F9B7CB7EE94B40
94547	1	10	\N	59550	80454	\N	55.821871000000002	Г.Красногорск, ул. Пионерская, д. 4, ГПУ № 4		0101000020E6100000C158DFC0E4AA4240F243A51133E94B40
58499	1	10	\N	59550	79885	\N	55.796233000000001	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Ильинское шоссе, 6		0101000020E610000083C13577F4A542407C7F83F6EAE54B40
58501	1	10	\N	59550	80894	\N	55.812683904278501	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Вокзальная, 11а		0101000020E610000054E6E61BD1AB4240C1FD800706E84B40
58476	1	10	\N	15725	\N	\N	56.115608999999999	Московская область, городской округ Красноармейск, микрорайон Северный, 24	Россия, Московская область, Красноармейск, микрорайон Северный, 24	0101000020E6100000965E9B8D95124340C70F9546CC0E4C40
58478	1	10	\N	15725	6419	\N	56.100338999999998	Московская область, городской округ Красноармейск, Академика Янгеля, 31	Россия, Московская область, Красноармейск, улица Академика Янгеля, 31	0101000020E61000000C90680245104340B5C189E8D70C4C40
58473	1	10	\N	15725	80312	\N	56.1215384516764	Московская область, городской округ Красноармейск, Спортивная, 9	Россия, Московская область, Красноармейск, Спортивная улица, 4	0101000020E6100000EAE74D452A124340529CA38E8E0F4C40
58475	1	10	\N	15725	80287	\N	56.119296954629398	Московская область, городской округ Красноармейск, Комсомольская, 3	Россия, Московская область, Красноармейск, Комсомольская улица, 3	0101000020E6100000EF5355682012434066C1C41F450F4C40
58474	1	10	\N	15725	80287	\N	56.119981984875501	Московская область, городской округ Красноармейск, Комсомольская, 5а	Россия, Московская область, Красноармейск, Комсомольская улица, 5а	0101000020E6100000F7216FB9FA114340E90DF7915B0F4C40
58472	1	10	\N	15725	72027	\N	56.123084648602998	Московская область, городской округ Красноармейск, Горького, 4	Россия, Московская область, Красноармейск, проспект Испытателей, 4	0101000020E6100000C9737D1F0E12434068D0D03FC10F4C40
94545	1	10	\N	15725	80280	\N	56.100042999999999	Московская область, городской округ Красноармейск, Академика Янгеля, 33		0101000020E6100000FE80070610104340CC988235CE0C4C40
58477	1	10	\N	15725	80274	\N	56.100465	Московская область, городской округ Красноармейск, Новая Жизнь, 1а		0101000020E61000009E40D8295611434042B28009DC0C4C40
94544	1	10	\N	1202	\N	\N	55.648921000000001	Московская область, городской округ Котельники, микрорайон "Силикат", 32 (ДК "Силикат")		0101000020E61000004DF564FED1ED42400458E4D70FD34B40
58470	1	10	\N	1202	\N	\N	55.662156000000003	"Московская область, городской округ Котельники, микрорайон ""Ковровый"", 39"	Россия, Московская область, Котельники, микрорайон Ковровый, 39	0101000020E6100000D2C3D0EAE4EE4240D36C1E87C1D44B40
58538	1	10	\N	1202	316	\N	55.648555000000002	Московская область, городской округ Краснознаменск, Парковая, 4а	Россия, Московская область, Котельники, Парковая улица, 4	0101000020E61000008446B071FDEF42402254A9D903D34B40
57902	1	10	\N	1202	316	\N	55.649886000000002	Московская область, городской округ Долгопрудный, Парковая, 10а	Россия, Московская область, Котельники, Парковая улица, 10	0101000020E610000058923CD7F7EF42406B10E6762FD34B40
58468	1	10	\N	1202	81037	\N	55.652903000000002	Московская область, городской округ Котельники, Малая Колхозная, 1 а		0101000020E6100000E78C28ED0DF04240EB3A545392D34B40
58435	1	10	\N	722	15451	\N	55.924768999999998	Московская область, городской округ Королёв, Сакко и Ванцетти, 28	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 28	0101000020E6100000AB4198DBBDEC424064ADA1D45EF64B40
58434	1	10	\N	722	15451	\N	55.924309999999998	Московская область, городской округ Королёв, Сакко и Ванцетти, 12а	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 12а	0101000020E610000033E202D028EB4240D1AE42CA4FF64B40
94622	1	10	\N	722	15609	\N	55.908327999999997	ул. Победы, д. 34	Россия, Московская область, Королев, микрорайон Валентиновка, улица Победы, 34	0101000020E61000008750A5660FF042404205871744F44B40
58441	1	10	\N	722	80116	\N	55.917648903921297	Московская область, городской округ Королёв, Дзержинского, 20а	Россия, Московская область, Королев, микрорайон Костино, улица Дзержинского, 20	0101000020E610000042EA76F695ED4240821ABE8575F54B40
58452	1	10	\N	722	15571	\N	55.909286999999999	Московская область, городской округ Королёв, проспект Космонавтов, 37б	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 37б	0101000020E61000005D50DF32A7EF4240C7D6338463F44B40
58446	1	10	\N	722	71801	\N	55.942906155832198	Московская область, городской округ Королёв, Мичурина, 25		0101000020E61000005610035DFBE84240E199D024B1F84B40
58451	1	10	\N	722	15571	\N	55.915331000000002	Московская область, городской округ Королёв, проспект Космонавтов, 18	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 18	0101000020E6100000A4FFE55AB4EE4240EB01F39029F54B40
58450	1	10	\N	722	15571	\N	55.919564000000001	Московская область, городской округ Королёв, проспект Космонавтов, 5а	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 5а	0101000020E61000009DBAF2599EEF42401B4AED45B4F54B40
58440	1	10	\N	722	15481	\N	55.918706	Московская область, городской округ Королёв, проспект Королёва, 6а	Россия, Московская область, Королев, микрорайон Костино, проспект Королева, 6а	0101000020E6100000A60EF27A30EB4240CA51802898F54B40
58438	1	10	\N	722	15481	\N	55.919438	Московская область, городской округ Королёв, проспект Королёва, 14а	Россия, Московская область, Королев, микрорайон Костино, проспект Королева, 14а	0101000020E6100000C636A968ACEB42408E59F624B0F54B40
58457	1	10	\N	722	80282	\N	55.931381000000002	Московская область, городской округ Королёв, мкрн. Болшево, ул. Школьная, 19		0101000020E61000001B4641F0F8EE4240D28E1B7E37F74B40
58453	1	10	\N	722	80991	\N	55.919685000000001	Московская область, городской округ Королёв, Торфопредприятие, 1		0101000020E61000006C96CB46E7EE424096CFF23CB8F54B40
58431	1	10	\N	722	80250	\N	55.917490935855497	Московская область, городской округ Королёв, Терешковой, 3		0101000020E6100000923EADA23FE84240EAAF575870F54B40
58427	1	10	\N	722	80250	\N	55.9184085160637	Московская область, городской округ Королёв, Терешковой, 1	Россия, Московская область, Королев, улица Терешковой, 1	0101000020E6100000EDF1423A3CE8424010AD156D8EF54B40
58436	1	10	\N	722	80253	\N	55.920138999999999	Московская область, городской округ Королёв, Суворова, 16	Россия, Московская область, Королев, микрорайон Костино, улица Суворова, 16	0101000020E6100000A3409FC893EC42401763601DC7F54B40
58447	1	10	\N	722	80134	\N	55.908325987028803	Московская область, городской округ Королёв, Стадионная, 4а		0101000020E6100000D9CD8C7E34EE4240A20DC00644F44B40
58458	1	10	\N	722	15626	\N	55.926963000000001	Московская область, городской округ Королёв, мкрн. Болшево, ул. Спартаковская, 5	Россия, Московская область, Королев, микрорайон Болшево, Спартаковская улица, 5	0101000020E61000009E7939ECBEF1424010CD3CB9A6F64B40
58463	1	10	\N	722	79906	\N	55.941465000000001	Московская область, городской округ Королёв, мкрн. Первомайский, ул. Солнечная, 35/25		0101000020E6100000E27492AD2EF1424011AAD4EC81F84B40
58460	1	10	\N	722	80271	\N	55.946668000000003	Московская область, городской округ Королёв, мкрн. Первомайский, ул. Советская, 18		0101000020E6100000CEFFAB8E1CEF4240BA15C26A2CF94B40
58462	1	10	\N	722	80276	\N	55.947898000000002	Московская область, городской округ Королёв, мкрн. Первомайский, ул. Советская, 5		0101000020E61000006FD39FFD48EF4240CFF8BEB854F94B40
58466	1	10	\N	722	80268	\N	55.951380999999998	Московская область, городской округ Королёв, мкрн. Текстильщик, ул. Советская, 8		0101000020E610000038A0A52BD8EA4240948444DAC6F94B40
58461	1	10	\N	722	79898	\N	55.939606385857303	Московская область, городской округ Королёв, мкрн. Первомайский, ул. Советская, 71	Россия, Московская область, Королев, микрорайон Первомайский, Советская улица, 73	0101000020E6100000A051BAF42FEF42400C90680245F84B40
94543	1	10	\N	722	80411	\N	55.924768999999998	место нахождения УИК: Московская область, городской округ Королёв, ул. Сакко и Ванцетти, д. 28; место для голосования: Московская область, городской округ Королёв, ул. Суворова, дом 19а		0101000020E6100000AB4198DBBDEC424064ADA1D45EF64B40
94623	1	10	\N	722	80503	\N	55.910669073619601	ул. Победы, д. 35	Россия, Московская область, Королев, микрорайон Валентиновка, улица Победы, 35	0101000020E6100000B3B27DC85BF04240923D42CD90F44B40
94621	1	10	\N	722	80503	\N	55.911240605481801	ул. Победы, д. 33	Россия, Московская область, Королев, микрорайон Валентиновка, улица Победы, 33а	0101000020E6100000B7B6F0BC54F042401DE38A8BA3F44B40
58433	1	10	\N	722	80277	\N	55.913466486092197	Московская область, городской округ Королёв, Пионерская, 8		0101000020E6100000AE64C74620E8424004013274ECF44B40
58420	1	10	\N	722	79929	\N	55.946183630921801	Московская область, городской округ Королёв, Первомайская, дом 7а, корп. 2	Россия, Московская область, Королев, микрорайон Первомайский, Первомайская улица, 7	0101000020E6100000336B2920EDED4240CEFFAB8E1CF94B40
58459	1	10	\N	722	81026	\N	55.920763792926302	Московская область, городской округ Королёв, мкрн. Болшево, ул. Пашенной, 17а	Россия, Московская область, Королев, микрорайон Болшево, улица Пашенной	0101000020E6100000E1EF17B325F34240C5AA4198DBF54B40
58439	1	10	\N	722	15487	\N	55.918565000000001	Московская область, городской округ Королёв, Октябрьский бульвар, 33	Россия, Московская область, Королев, микрорайон Костино, Октябрьский бульвар, 33	0101000020E610000070D234289AEB42400820B58993F54B40
58425	1	10	\N	722	80269	\N	55.918252245608599	Московская область, городской округ Королёв, Октябрьская, 10	Россия, Московская область, Королев, Октябрьская улица, 10	0101000020E6100000A31F0DA7CCE7424049BE124889F54B40
58428	1	10	\N	722	80258	\N	55.918936347797299	Московская область, городской округ Королёв, Октябрьская, 23	Россия, Московская область, Королев, Октябрьская улица, 23	0101000020E610000048FAB48AFEE84240FC8EE1B19FF54B40
58467	1	10	\N	722	15678	\N	55.946547000000002	Московская область, городской округ Королёв, мкрн. Текстильщик, ул. Молодёжная, 7	Россия, Московская область, Королев, микрорайон Текстильщик, Молодежная улица, 7	0101000020E610000091813CBB7CEB42403F90BC7328F94B40
58424	1	10	\N	722	72310	\N	55.937833182691399	Московская область, городской округ Королёв, Ленина, 2	Россия, Московская область, Королев, микрорайон Первомайский, улица Ленина, 2/30	0101000020E6100000DEAD2CD159F04240060E68E90AF84B40
58464	1	10	\N	722	81033	\N	55.953114999999997	Московская область, городской округ Королёв, мкрн. Первомайский, ул. Краснооктябрьская, 40		0101000020E61000001D8F19A88CF54240DC291DACFFF94B40
58423	1	10	\N	722	80246	\N	55.930261000000002	Московская область, городской округ Королёв, Комсомольская, 12	Россия, Московская область, Королев, Комсомольская улица, 12	0101000020E6100000D40D147827E9424044DFDDCA12F74B40
58456	1	10	\N	722	80263	\N	55.928421	Московская область, городской округ Королёв, мкрн. Болшево, ул. Комитетский лес, 14		0101000020E61000007CB8E4B853EA4240B6F5D37FD6F64B40
58442	1	10	\N	722	6065	\N	55.914034999999998	Московская область, городской округ Королёв, Калининградская, 12	Россия, Московская область, Королев, Калининградская улица, 12	0101000020E6100000F2EA1C03B2EB42401E335019FFF44B40
58448	1	10	\N	722	80265	\N	55.923690000000001	Московская область, городской округ Королёв, Исаева, 2/30		0101000020E61000000D6E6B0BCFED424035D252793BF64B40
58444	1	10	\N	722	80123	\N	55.916335339312703	Московская область, городской округ Королёв, Дзержинского, 24/2		0101000020E61000009C69C2F693ED42400F971C774AF54B40
58443	1	10	\N	722	80272	\N	55.921131003599001	Московская область, городской округ Королёв, Дзержинского, 5	Россия, Московская область, Королев, микрорайон Костино, улица Дзержинского, 5	0101000020E6100000FDBB3E73D6ED4240782AE09EE7F54B40
58445	1	10	\N	722	80257	\N	55.915143367607001	Московская область, городской округ Королёв, Дзержинского, 26	Россия, Московская область, Королев, микрорайон Костино, улица Дзержинского, 26	0101000020E6100000A741D13C80ED4240E814E46723F54B40
58422	1	10	\N	722	80241	\N	55.926363000000002	Московская область, городской округ Королёв, Грабина, 2а		0101000020E6100000CF30B5A50EE84240BB9C121093F64B40
58432	1	10	\N	722	71806	\N	55.916030218396003	Московская область, городской округ Королёв, Гагарина, 42		0101000020E6100000FC56EBC4E5E84240D313967840F54B40
58429	1	10	\N	722	71806	\N	55.917753399724099	Московская область, городской округ Королёв, Гагарина, 5		0101000020E610000055FA0967B7E64240276728EE78F54B40
58421	1	10	\N	722	5847	\N	55.930492999999998	Московская область, городской округ Королёв, Болшевское шоссе, 2	Россия, Московская область, Королев, Болшевское шоссе, 2	0101000020E61000005B44149337E84240161406651AF74B40
58437	1	10	\N	722	79860	\N	55.919522442492799	Московская область, городской округ Королёв, 50-летия ВЛКСМ, 5/16		0101000020E6100000B456B439CEEB4240ECF99AE5B2F54B40
58308	1	10	\N	5426	16517	\N	55.089475	Московская область, городской округ Коломна, ул. Партизан, ПТУ № 6	Россия, Московская область, Коломна, район Митяево, улица Партизан, 6	0101000020E6100000E9BAF083F3654340A167B3EA738B4B40
58363	1	10	\N	5426	16260	\N	55.106242000000002	Московская область, городской округ Коломна, набережная реки Коломенки, д.7, Конькобежный центр	Россия, Московская область, Коломна, район Старая Коломна, улица Набережная реки Коломенки, 7	0101000020E61000002E90A0F83160434017BB7D56998D4B40
58362	1	10	\N	5426	74986	\N	55.104399000000001	Московская область, городской округ Коломна, ул. Менделеева, д.18, школа №1	Россия, Московская область, Коломна, район Запруды, улица Менделеева, 18	0101000020E6100000B003E78C285D4340185E49F25C8D4B40
58382	1	10	\N	5426	16354	\N	55.081643	Московская область, городской округ Коломна, ул. Малышева, д.19а, Центр детского творчества	Россия, Московская область, Коломна, район Центральный, улица Малышева, 19а	0101000020E6100000CD7344BE4B65434042791F47738A4B40
58409	1	10	\N	5426	72300	\N	55.039277766191503	Московская область, городской округ Коломна, ул. Ларцевы Поляны, школа № 28	Россия, Московская область, Коломна, район Ларцевы Поляны, улица Ларцевы Поляны, 11	0101000020E6100000B80375CAA36B4340E5B9BE0F07854B40
58379	1	10	\N	5426	16343	\N	55.078535000000002	Московская область, городской округ Коломна, ул.Дзержинского, д.11, школа № 21	Россия, Московская область, Коломна, район Центральный, улица Дзержинского, 11	0101000020E6100000F0C4AC1743674340B24B546F0D8A4B40
58395	1	10	\N	5426	80207	\N	55.085177999999999	Московская область, городской округ Коломна, пр. Кирова, д.28, Шахматный клуб		0101000020E61000004A9A3FA6B56143405A2BDA1CE78A4B40
58391	1	10	\N	5426	80207	\N	55.090041999999997	"Московская область, городской округ Коломна, пр. Кирова, д.3, ""Мособлэлектротранс"""		0101000020E61000009946938B316243401AA20A7F868B4B40
58371	1	10	\N	5426	80207	\N	55.090763000000003	Московская область, городской округ Коломна, пр.Кирова, д.4, Спортивная школа		0101000020E61000005EA0A4C002624340EB573A1F9E8B4B40
58397	1	10	\N	5426	80576	\N	55.075040999999999	Московская область, городской округ Коломна, пр. Кирова, д.49, Детская художественная школа		0101000020E61000003B6EF8DD74614340F86D88F19A894B40
58398	1	10	\N	5426	80243	\N	55.062301607038599	Московская область, городской округ Коломна, бульвар 800-летия Коломны, д.9, школа № 15	Россия, Московская область, Коломна, район Колычево, бульвар 800-летия Коломны, 9	0101000020E61000009AD18F8653604340DA3C0E83F9874B40
58405	1	10	\N	5426	80254	\N	55.646000000000001	Московская область, городской округ Коломна, ул. Южная, д.7, школа № 18		0101000020E6100000FD32182312014340A69BC420B0D24B40
94542	1	10	\N	5426	80223	\N	55.091005000000003	Московская область, городской округ Коломна, ул. Шилова (здание школы № 14), д. 5		0101000020E610000084F068E388614340E162450DA68B4B40
58393	1	10	\N	5426	80223	\N	55.091005000000003	Московская область, городской округ Коломна, ул. Шилова, д.5, школа № 14		0101000020E610000084F068E388614340E162450DA68B4B40
58392	1	10	\N	5426	80223	\N	55.091005000000003	Московская область, городской округ Коломна, ул.Шилова, д.5, школа № 14		0101000020E610000084F068E388614340E162450DA68B4B40
58376	1	10	\N	5426	80212	\N	55.079844000000001	Московская область, городской округ Коломна, ул. Шавырина, д.5, школа № 20		0101000020E61000004E7ADFF8DA67434013640454388A4B40
58412	1	10	\N	5426	79870	\N	55.055055012309303	Московская область, городской округ Коломна, ул.Цементников, д.17, школа № 30	Россия, Московская область, Коломна, район Ларцевы Поляны, улица Цементников	0101000020E6100000A032FE7DC66B43409B3DD00A0C874B40
58410	1	10	\N	5426	79870	\N	55.055917255723898	Московская область, городской округ Коломна, ул. Цементников, д.17, школа № 30	Россия, Московская область, Коломна, район Ларцевы Поляны, улица Цементников, 9	0101000020E6100000A9DC442DCD6B43402D25CB4928874B40
58426	1	10	\N	5426	80242	\N	55.079787000000003	Московская область, городской округ Королёв, Фрунзе, 19		0101000020E6100000A60A462575644340AFD2DD75368A4B40
58404	1	10	\N	5426	80230	\N	55.055531999999999	Московская область, городской округ Коломна, ул. Спирина, д.8. школа № 17		0101000020E6100000B0AE0AD462604340D4F02DAC1B874B40
58402	1	10	\N	5426	80230	\N	55.055531999999999	Московская область, городской округ Коломна, ул. Спирина, д.8, школа № 17		0101000020E6100000B0AE0AD462604340D4F02DAC1B874B40
58411	1	10	\N	5426	80366	\N	55.052626484326801	"Московская область, городской округ Коломна, ул.Советская, д.60а, Дворец культуры ""Цементник"""		0101000020E61000004F05DCF3FC6B4340AB75E272BC864B40
57933	1	10	\N	5426	80556	\N	55.043747000000003	Московская область, городской округ Дубна, Свободы, 20		0101000020E6100000349C3237DF68434029266F8099854B40
58375	1	10	\N	5426	79779	\N	55.088889163446503	"Московская область, городской округ Коломна, ул. Октябрьской революции, д.324, ДК ""Тепловозостроитель"""	Россия, Московская область, Коломна, район Запруды, улица Октябрьской Революции, 324	0101000020E6100000CE18E6046D644340B1FCF9B6608B4B40
58377	1	10	\N	5426	80851	\N	55.079854478448397	Московская область, городской округ Коломна, ул.Октябрьской революции, д.408, институт МГОУ	Россия, Московская область, Коломна, район Запруды, улица Октябрьской Революции, 408	0101000020E6100000C171193735684340363AE7A7388A4B40
58374	1	10	\N	5426	74323	\N	55.088409170442297	Московская область, городской округ Коломна, ул.Октябрьской революции, 322, гимназия № 9	Россия, Московская область, Коломна, район Запруды, улица Октябрьской Революции, 322а	0101000020E6100000D4B9A2941064434006D671FC508B4B40
58372	1	10	\N	5426	74323	\N	55.093147999999999	"Московская область, городской округ Коломна, ул. Октябрьской революции, д.277, школа ""Надежда"""	Россия, Московская область, Коломна, район Запруды, улица Октябрьской Революции, 277	0101000020E6100000170E8464016343400AD80E46EC8B4B40
58368	1	10	\N	5426	74323	\N	55.0991645484578	"Московская область, городской округ Коломна, ул. Октябрьской революции, д.222, центр ""Выбор"""		0101000020E6100000132D793C2D61434034F44F70B18C4B40
58364	1	10	\N	5426	74323	\N	55.098235565837101	Московская область, городской округ Коломна, ул. Октябрьской революции, д.232, Дом учителя	Россия, Московская область, Коломна, район Запруды, улица Октябрьской Революции, 232	0101000020E610000058AB764D486143401AA54BFF928C4B40
58360	1	10	\N	5426	74323	\N	55.113004435926896	Московская область, городской округ Коломна, ул. Октябрьской революции, д.128, автоколонна 1417	Россия, Московская область, Коломна, район Запруды, улица Октябрьской Революции, 128	0101000020E610000045F295404A5E4340992842EA768E4B40
58408	1	10	\N	5426	79419	\N	55.0603443316962	Московская область, городской округ Коломна, ул. Октябрьская, д.107, управления завода ЖБКиСД	Россия, Московская область, Коломна, район Дубовая Роща, Октябрьская улица	0101000020E6100000A59E05A1BC6D43404241295AB9874B40
58380	1	10	\N	5426	80214	\N	55.075875000000003	"Московская область, городской округ Коломна, Окский проспект, д.17, ""Дворец культуры ""Коломна"""		0101000020E6100000E773EE76BD664340C1CAA145B6894B40
58378	1	10	\N	5426	80214	\N	55.075875000000003	"Московская область, городской округ Коломна, Окский проспект, д.17, Дворец культуры ""Коломна"""		0101000020E6100000E773EE76BD664340C1CAA145B6894B40
94541	1	10	\N	5426	16283	\N	55.078973325403297	Московская область, городской округ Коломна, Озерское шоссе (здание РЭУ "Коломенский"), д.9	Россия, Московская область, Коломна, район Подлипки, Озерское шоссе	0101000020E610000053B131AF235C43402D228AC91B8A4B40
58361	1	10	\N	5426	16255	\N	55.109059000000002	Московская область, городской округ Коломна, Малинское шоссе, д.36, Коломенский аграрный колледж	Россия, Московская область, Коломна, район Запруды, Малинское шоссе, 36	0101000020E61000002C2B4D4A415D4340D02A33A5F58D4B40
58406	1	10	\N	5426	80171	\N	55.0677980519702	Московская область, городской округ Коломна, ул. Лесная, д.13а, бывший клуб КСД		0101000020E6100000EB6F09C03F6D4340FB5DD89AAD884B40
58394	1	10	\N	5426	80231	\N	55.085467548451099	Московская область, городской округ Коломна, ул. Леваневского, д.8, гимназия № 8	Россия, Московская область, Коломна, район Репинский, улица Леваневского	0101000020E61000004D31074147614340616D8C9DF08A4B40
58366	1	10	\N	5426	80238	\N	55.095647	"Московская область, городской округ Коломна, ул. Красногвардейская, д.36, ""Коломенские электросети"""		0101000020E61000001EDC9DB5DB624340F27A30293E8C4B40
58367	1	10	\N	5426	80163	\N	55.1017995919429	"Московская область, городской округ Коломна, ул. Комсомольская, д.12а, ""Тепло Коломны"""		0101000020E6100000C91CCBBBEA614340CC5D4BC8078D4B40
58399	1	10	\N	5426	80867	\N	55.0636262878606	Московская область, городской округ Коломна, ул.Кирова, д.163, Культурный центр	Россия, Московская область, Коломна, район Колычево, улица Кирова	0101000020E610000099F1B6D26B614340709692E524884B40
58383	1	10	\N	5426	80145	\N	55.083393512776503	Московская область, городской округ Коломна, ул. Калинина, д.14а, гимназия № 2	Россия, Московская область, Коломна, район Центральный, улица Калинина	0101000020E61000000951BEA085644340605793A7AC8A4B40
58385	1	10	\N	5426	79901	\N	55.076653999999998	Московская область, городской округ Коломна, ул.Зеленая, д.30, Пединститут	Россия, Московская область, Коломна, район Центральный, Зеленая улица, 30	0101000020E61000009031772D21634340C58D5BCCCF894B40
58396	1	10	\N	5426	80248	\N	55.080630015488602	Московская область, городской округ Коломна, ул. Зеленая, д.3, школа № 12		0101000020E6100000EB56CF49EF614340CA897615528A4B40
58365	1	10	\N	5426	79912	\N	55.104838811822802	Московская область, городской округ Коломна, ул. Зайцева, д.11, школа № 7	Россия, Московская область, Коломна, район Старая Коломна, улица Зайцева, 11	0101000020E61000004696CCB1BC614340342C465D6B8D4B40
58390	1	10	\N	5426	80114	\N	55.087553	Московская область, городской округ Коломна, ул. Добролюбова, д.2а, лицей № 4	Россия, Московская область, Коломна, район Центральный, улица Добролюбова, 2	0101000020E6100000ACFF73982F63434056D5CBEF348B4B40
58389	1	10	\N	5426	80114	\N	55.084167999999998	"Московская область, городской округ Коломна, ул. Добролюбова, д.4, ""Мособлстрой-3"""		0101000020E6100000C5909C4CDC62434053AF5B04C68A4B40
58386	1	10	\N	5426	80221	\N	55.082349000000001	Московская область, городской округ Коломна, ул. Дзержинского, д.90, школа № 10		0101000020E6100000DA1D520C90624340DDED7A698A8A4B40
58384	1	10	\N	5426	80221	\N	55.076365000000003	Московская область, городской округ Коломна, ул. Дзержинского, д.27, школа № 11		0101000020E6100000D1E7A38CB86443408FC70C54C6894B40
58388	1	10	\N	5426	80322	\N	55.081404999999997	Московская область, городской округ Коломна, ул. Дзержинского, д.80, Центр занятости		0101000020E61000002313F06B246343408D5DA27A6B8A4B40
58401	1	10	\N	5426	80227	\N	55.059945999999997	Московская область, городской округ Коломна, ул. Девичье Поле, д.9, школа № 16		0101000020E6100000A12C7C7DAD5F434054C37E4FAC874B40
58400	1	10	\N	5426	80237	\N	55.063392297471999	"Московская область, городской округ Коломна, ул. Астахова, д.23, центр ""Русь"""		0101000020E6100000A4198BA6B35F4340FD69A33A1D884B40
58271	1	10	\N	59548	80193	\N	56.326299892671301	Московская область, Клинский муниципальный район, г.Клин, Самодеятельная, 11а	Россия, Московская область, Клинский район, Клин, Самодеятельная улица, 11а	0101000020E6100000C367EBE060614240A857CA32C4294C40
58267	1	10	\N	59548	81061	\N	56.335979000000002	Московская область, г. Клин,  ул. Папивина, д. 1/20		0101000020E61000007940D9942B5E42404792205C012B4C40
58275	1	10	\N	59548	80572	\N	56.319589000000001	Московская область, Клинский муниципальный район, г.Клин, К.Маркса, 99		0101000020E61000001C959BA8A55D4240A794D74AE8284C40
58277	1	10	\N	59548	80111	\N	56.317946999999997	Московская область, Клинский муниципальный район, г.Клин, 50 лет Октября, 13а		0101000020E6100000C971A774B05C42403F6EBF7CB2284C40
58254	1	10	\N	13220	3801	\N	55.372374999999998	Московская область, городской округ Климовск, Проспект 50 Летия Октября, 18	Россия, Московская область, Климовск, проспект 50 лет Октября, 18	0101000020E6100000EB36A8FDD6C442408B6CE7FBA9AF4B40
58259	1	10	\N	13220	3869	\N	55.381270000000001	Московская область, городской округ Климовск, пр-д Юности, 1		0101000020E6100000E5B8533A58C5424014799274CDB04B40
58246	1	10	\N	13220	80199	\N	55.366159622229901	Московская область, городской округ Климовск, Школьная, 10	Россия, Московская область, Климовск, Школьная улица, 10	0101000020E61000008B37328FFCC142403B8DB454DEAE4B40
58255	1	10	\N	13220	80186	\N	55.373378000000002	Московская область, городской округ Климовск, Театральная, 6	Россия, Московская область, Климовск, Театральная улица, 6	0101000020E61000000ADCBA9BA7C44240E085ADD9CAAF4B40
58257	1	10	\N	13220	80110	\N	55.379153000000002	Московская область, городской округ Климовск, Симферопольская, 5А		0101000020E6100000FCFF3861C2C442401497E31588B04B40
58251	1	10	\N	13220	80041	\N	55.355642025410901	Московская область, городской округ Климовск, Серпуховская, 1-Б	Россия, Московская область, Климовск	0101000020E6100000E2AFC91AF5C44240C28A53AD85AD4B40
58247	1	10	\N	13220	80102	\N	55.363044714497498	Московская область, городской округ Климовск, Рощинская, 17А	Россия, Московская область, Климовск, Рощинская улица, 17а	0101000020E61000006A32E36DA5C14240F8FC304278AE4B40
58249	1	10	\N	13220	80183	\N	55.356389999999998	Московская область, городской округ Климовск, Рожкова, 6		0101000020E61000007D09151C5EC242408B4F01309EAD4B40
58252	1	10	\N	13220	80194	\N	55.359886109746498	Московская область, городской округ Климовск, Революции, 4	Россия, Московская область, Климовск, улица Революции	0101000020E6100000647616BD53C54240E62494BE10AE4B40
58253	1	10	\N	13220	80050	\N	55.358444757640797	Московская область, городской округ Климовск, Первомайская, 3А	Россия, Московская область, Климовск, Первомайская улица, 3	0101000020E610000073F1B73D41C4424016359886E1AD4B40
58260	1	10	\N	13220	74300	\N	55.3826016653789	Московская область, городской округ Климовск, Молодежная, 2А	Россия, Московская область, Климовск, Молодежная улица, 2к1	0101000020E610000087A2409FC8C542402DB1321AF9B04B40
58250	1	10	\N	13220	71898	\N	55.356051937560302	Московская область, городской округ Климовск, Ленина, 23		0101000020E6100000E5B33C0FEEC2424073D6A71C93AD4B40
58248	1	10	\N	13220	71898	\N	55.3587838759668	Московская область, городской округ Климовск, Ленина, 20	Россия, Московская область, Климовск, улица Ленина, 20	0101000020E6100000C616821C94C24240FE2955A2ECAD4B40
58245	1	10	\N	13220	71898	\N	55.364327010757997	Московская область, городской округ Климовск, Ленина, 2А	Россия, Московская область, Климовск, улица Ленина	0101000020E61000006E15C440D7C2424060066344A2AE4B40
58258	1	10	\N	13220	80195	\N	55.378979216607902	Московская область, городской округ Климовск, Заводская, 3	Россия, Московская область, Климовск, Заводская улица, 3	0101000020E610000085EFFD0DDAC54240766F456282B04B40
58192	1	10	\N	61929	80174	\N	54.848333049857303	г.Кашира, ул.Металлистов, д.6		0101000020E6100000EE27637C981F43400C8FFD2C966C4B40
55589	1	10	\N	61929	80236	\N	54.840857999999997	г.Кашира, ул.Гвардейская, д.6		0101000020E61000005C035B25582043403C4A253CA16B4B40
94511	1	10	\N	60277	80109	\N	55.905714000000003	Московская область, Истринский муниципальный район, городское поселение Истра, ул.Юбилейная, д.11а, Истр.ср.школа №2		0101000020E61000003B53E8BCC66E4240C2C3B46FEEF34B40
58163	1	10	\N	60277	80077	\N	55.9056226545637	Московская область, Истринский муниципальный район, городское поселение Истра, Ленина, здание Агитпункта, 6		0101000020E610000012BC218D0A6E4240B1C05774EBF34B40
58168	1	10	\N	60277	74272	\N	55.913254175703599	Московская область, Истринский муниципальный район, городское поселение Истра, 9 Гвардейской дивизии, здание Педагогического колледжа, 33а	Россия, Московская область, Истринский район, Истра, улица 9 Гвардейской Дивизии, 33а	0101000020E6100000F94CF6CFD36E42407978CF81E5F44B40
57826	1	10	\N	61889	79873	\N	56.1497747022119	"Московская область, Дмитровский муниципальный район, городское поселение Икша, ц.у.ОПХ ""Ермолино"", ДК ц.у. ОПХ ""Ермолино"""		0101000020E6100000E09F5225CABE42401361C3D32B134C40
58156	1	10	\N	7706	2454	\N	55.967139000000003	Московская область, городской округ Ивантеевка, Центральный проезд, 1	Россия, Московская область, Ивантеевка, Центральный проезд, 3	0101000020E6100000DCD8EC48F5F34240D4D7F335CBFB4B40
58160	1	10	\N	7706	79883	\N	55.971839982619201	Московская область, городской округ Ивантеевка, Хлебозаводская, 18	Россия, Московская область, Ивантеевка, Хлебозаводская улица, 20	0101000020E6100000B11875ADBDF74240EA78CC4065FC4B40
58159	1	10	\N	7706	80148	\N	55.966180999999999	Московская область, городской округ Ивантеевка, Трубниковская, 27		0101000020E610000077DA1A118CF542401F82AAD1ABFB4B40
58155	1	10	\N	7706	80098	\N	55.9710142989112	Московская область, городской округ Ивантеевка, Советский проспект, 12/8	Россия, Московская область, Ивантеевка, Советский проспект, 12/8	0101000020E6100000728A8EE4F2F34240A4FACE2F4AFC4B40
58157	1	10	\N	7706	80144	\N	55.963818000000003	Московская область, городской округ Ивантеевка, Смурякова, 10		0101000020E61000003D0B42791FF54240E8A562635EFB4B40
58153	1	10	\N	7706	80165	\N	55.976132538263599	Московская область, городской округ Ивантеевка, Первомайская, 35	Россия, Московская область, Ивантеевка, Первомайская улица, 35	0101000020E61000004A5E9D6340F44240EFC517EDF1FC4B40
58152	1	10	\N	7706	80152	\N	55.976664999999997	Московская область, городской округ Ивантеевка, Первомайская, 37	Россия, Московская область, Ивантеевка, Первомайская улица, 37	0101000020E61000004206F2ECF2F34240EC12D55B03FD4B40
58140	1	10	\N	7706	80139	\N	55.970548999999998	Московская область, городской округ Ивантеевка, Задорожная, 18		0101000020E61000009DBB5D2F4DF342402F151BF33AFC4B40
58158	1	10	\N	7706	80097	\N	55.970156445278498	Московская область, городской округ Ивантеевка, Дзержинского, 1а	Россия, Московская область, Ивантеевка, улица Дзержинского, 1а	0101000020E61000003815A930B6F44240540262122EFC4B40
58154	1	10	\N	7706	80097	\N	55.974217943070599	Московская область, городской округ Ивантеевка, Дзержинского, 7	Россия, Московская область, Ивантеевка, улица Дзержинского	0101000020E61000006743FE9941F442405796E82CB3FC4B40
59830	1	10	\N	5833	\N	\N	55.735180793123703	Санаторий МО, Здание клуба Санатория МО	Россия, Московская область, Звенигород, поселок Санаторий	0101000020E6100000F1845E7F126B4240FED137691ADE4B40
58145	1	10	\N	5833	\N	\N	55.723804147132299	Московская область, городской округ Звенигород, Военный санаторий МО РФ, клуб	Россия, Московская область, Звенигород	0101000020E6100000B491EBA6946D4240645B069CA5DC4B40
58142	1	10	\N	5833	\N	\N	55.7205715704008	"Московская область, городской округ Звенигород, м-н ""Восточный"", 8"	Россия, Московская область, Звенигород, Игнатьевская улица, 8	0101000020E6100000ED461FF3016F4240E7340BB43BDC4B40
94509	1	10	\N	5833	2365	\N	55.736345999999998	Московская область, г.Звенигород,микрорайон ""Шихово"",ул.Кирова,магазин ""Продукты"""		0101000020E61000007DEA58A5F46E42402C45F29540DE4B40
58146	1	10	\N	5833	80889	\N	55.737290643473301	Московская область, городской округ Звенигород, Спортивная, 4	Россия, Московская область, Звенигород, улица Герцена, 4	0101000020E6100000AC394030476D42404C512E8D5FDE4B40
58144	1	10	\N	5833	68989	\N	55.735967826948396	Московская область, городской округ Звенигород, Советская, 4	Россия, Московская область, Звенигород, Советская улица	0101000020E6100000BA30D28BDA6D424086730D3334DE4B40
58143	1	10	\N	5833	80191	\N	55.731841326210798	Московская область, городской округ Звенигород, Некрасова, 8	Россия, Московская область, Звенигород, улица Некрасова, 10	0101000020E6100000427A8A1C226E42409C6F44F7ACDD4B40
58148	1	10	\N	5833	79880	\N	55.743162380031002	Московская область, городской округ Звенигород, Нахабинское шоссе, 15	Россия, Московская область, Звенигород, квартал Маяковского, Нахабинское шоссе	0101000020E61000007F6C921FF16D4240A2D0B2EE1FDF4B40
94489	1	10	\N	5833	81052	\N	55.740071286649098	Московская область, г.Звенигород,ул.Мояковского,д.№ 4	Россия, Московская область, Звенигород, квартал Маяковского, улица Маяковского	0101000020E61000001EFB592C456E4240E8DB82A5BADE4B40
58094	1	10	\N	5833	72274	\N	55.740809138966	Московская область, городской округ Жуковский, Маяковского, 15	Россия, Московская область, Звенигород, квартал Маяковского, улица Маяковского	0101000020E61000005DC0CB0C1B6F42408ECA4DD4D2DE4B40
58139	1	10	\N	5833	80845	\N	55.723900999999998	Московская область, городской округ Звенигород, Звенигородское шоссе, 7	Россия, Московская область, Звенигород	0101000020E6100000A471A8DF856D42405645B8C9A8DC4B40
58138	1	10	\N	5833	74136	\N	55.705805123336702	Московская область, городской округ Звенигород, Верхне Посадское шоссе, 1	Россия, Московская область, Звенигород, Луцинское шоссе	0101000020E61000006877483140684240382D78D157DA4B40
58151	1	10	\N	61931	\N	\N	55.878890651190503	"Московская область, п. Звездный городок, МБУК ""Дом космонавтов"", д. 7"	Россия, Московская область, городской округ Звездный городок (ЗАТО)	0101000020E6100000658BA4DDE80D4340D7DF12807FF04B40
57900	1	10	\N	60232	\N	\N	54.754178000000003	г.Зарайск, Микрорайон-1, д.30		0101000020E6100000EBFD463B6E7243406DAE9AE788604B40
58114	1	10	\N	60232	74081	\N	54.766408060952401	г.Зарайск, ул.Московская, д.1	Россия, Московская область, Зарайский район, Зарайск, Московская улица	0101000020E610000055698B6B7C70434046B247A819624B40
58112	1	10	\N	60232	74081	\N	54.771315000000001	г.Зарайск, Здание ПУ №85, ул.Московская, д.110		0101000020E61000004ED53DB2B970434006F52D73BA624B40
58124	1	10	\N	60232	80130	\N	54.755082000000002	г.Зарайск, Микрорайон-1, д.34 МОУ гимназия № 2		0101000020E61000008FA850DD5C7243402EE6E786A6604B40
58123	1	10	\N	60232	80130	\N	54.755673999999999	г. Зарайск, Микрорайон-1, д.35		0101000020E61000007E1CCD91957143400038F6ECB9604B40
58105	1	10	\N	5694	1697	\N	55.601832999999999	Московская область, городской округ Жуковский, Дугина, 16	Россия, Московская область, Жуковский, улица Дугина, 16	0101000020E61000002DEE3F321D0C4340A8531EDD08CD4B40
58102	1	10	\N	5694	1697	\N	55.600898000000001	Московская область, городской округ Жуковский, Дугина, 19	Россия, Московская область, Жуковский, улица Дугина, 19	0101000020E61000001059A489770C4340AC1DC539EACC4B40
58096	1	10	\N	5694	80127	\N	55.598184799419897	Московская область, городской округ Жуковский, Фрунзе, 28	Россия, Московская область, Жуковский, улица Фрунзе, 28	0101000020E61000009C6A2DCC420F434098FA795391CC4B40
58095	1	10	\N	5694	80127	\N	55.600159331199599	Московская область, городской округ Жуковский, Фрунзе, 8	Россия, Московская область, Жуковский, улица Фрунзе, 8	0101000020E61000005F24B4E55C10434035B39602D2CC4B40
58110	1	10	\N	5694	79863	\N	55.603313	Московская область, городской округ Жуковский, Федотова, 19		0101000020E610000056664AEB6F0943403620425C39CD4B40
58092	1	10	\N	5694	79851	\N	55.590011304432899	Московская область, городской округ Жуковский, Пушкина, 3	Россия, Московская область, Жуковский, улица Пушкина	0101000020E6100000F086342A70104340DFA3FE7A85CB4B40
58090	1	10	\N	5694	80131	\N	55.587699970971897	Московская область, городской округ Жуковский, Осипенко, 7	Россия, Московская область, Жуковский, улица Осипенко	0101000020E6100000BA6B09F9A0114340FAEDEBC039CB4B40
58107	1	10	\N	5694	74149	\N	55.603791000000001	Московская область, городской округ Жуковский, Молодежная, 9	Россия, Московская область, Жуковский, Молодежная улица, 9	0101000020E61000004DA3C9C5180C4340404F030649CD4B40
58106	1	10	\N	5694	74149	\N	55.604650999999997	Московская область, городской округ Жуковский, Молодежная, 10	Россия, Московская область, Жуковский, Молодежная улица, 10	0101000020E6100000FB75A73B4F0C4340313F373465CD4B40
58087	1	10	\N	5694	74149	\N	55.606150999999997	Московская область, городской округ Жуковский, Молодежная, 25	Россия, Московская область, Жуковский, Молодежная улица, 25	0101000020E610000083893F8A3A0B434006B8205B96CD4B40
58099	1	10	\N	5694	79853	\N	55.600119999999997	Московская область, городской округ Жуковский, Менделеева, 12		0101000020E6100000096D3997E20E434077D66EBBD0CC4B40
58098	1	10	\N	5694	79853	\N	55.600008000000003	Московская область, городской округ Жуковский, Менделеева, 9		0101000020E610000004594FADBE0E434050ABE80FCDCC4B40
58089	1	10	\N	5694	71884	\N	55.586752042626799	Московская область, городской округ Жуковский, Лесная, 7	Россия, Московская область, Жуковский, Лесная улица, 7	0101000020E610000094BF7B478D114340696E85B01ACB4B40
94508	1	10	\N	5694	79862	\N	55.594172999999998	Московская область, городской округ Жуковский, ул.Левченко, 5		0101000020E6100000367689EAAD0B4340469561DC0DCC4B40
58091	1	10	\N	5694	80021	\N	55.5862661065023	Московская область, городской округ Жуковский, Гарнаева, 3а	Россия, Московская область, Жуковский, Комсомольская улица, 3а	0101000020E61000003F3A75E5B3104340DD60A8C30ACB4B40
58093	1	10	\N	5694	80124	\N	55.595255136673799	Московская область, городской округ Жуковский, Дзержинского, 18	Россия, Московская область, Жуковский, улица Дзержинского, 18	0101000020E61000005FF0694E5E104340E7E3DA5031CC4B40
58103	1	10	\N	5694	80043	\N	55.596156999999998	Московская область, городской округ Жуковский, Гудкова, 7а		0101000020E6100000289A07B0C80B4340072461DF4ECC4B40
58104	1	10	\N	5694	79843	\N	55.594514617862899	Московская область, городской округ Жуковский, Гризодубовой, 12	Россия, Московская область, Жуковский, улица Гризодубовой	0101000020E61000003D9D2B4A090B4340A0FD481119CC4B40
58108	1	10	\N	5694	72001	\N	55.608694	Московская область, городской округ Жуковский, Гагарина, 56	Россия, Московская область, Жуковский, улица Гагарина, 56	0101000020E61000005E66D828EB0B4340BEA25BAFE9CD4B40
58101	1	10	\N	5694	72001	\N	55.604313846100197	Московская область, городской округ Жуковский, Гагарина, 16	Россия, Московская область, Жуковский, улица Гагарина, 16	0101000020E6100000EE27637C980D4340EA4141295ACD4B40
58111	1	10	\N	5694	80126	\N	55.607621000000002	Московская область, городской округ Жуковский, Баженова, 12		0101000020E6100000DFFC86890609434071AE6186C6CD4B40
58083	1	10	\N	2581	\N	\N	55.744252000000003	Московская область, город Железнодорожный, ул. Озерная, 10	Россия, Московская область, Железнодорожный	0101000020E61000004374081C09024340C6FD47A643DF4B40
58082	1	10	\N	2581	\N	\N	55.744252000000003	Московская область, город Железнодорожный, ул.Адмирала Кузнецова, 10	Россия, Московская область, Железнодорожный	0101000020E61000004374081C09024340C6FD47A643DF4B40
58051	1	10	\N	2581	921	\N	55.749809999999997	Московская область, город Железнодорожный, ул. Юнатов, 8	Россия, Московская область, Железнодорожный, улица Юннатов, 8	0101000020E6100000548F34B8ADF942405C1B2AC6F9DF4B40
58049	1	10	\N	2581	881	\N	55.753914000000002	Московская область, город Железнодорожный, ул.Смельчак, 9а	Россия, Московская область, Железнодорожный, улица Смельчак, 9	0101000020E6100000C7116BF129FA42408FFF024180E04B40
58055	1	10	\N	2581	977	\N	55.745888999999998	Московская область, город Железнодорожный, ул. Свободы, 4	Россия, Московская область, Железнодорожный, улица Свободы, 4	0101000020E6100000853FC39B35FC42401BB96E4A79DF4B40
57795	1	10	\N	2581	1286	\N	55.748995000000001	Московская область, город Железнодорожный, ул. новая, 17	Россия, Московская область, Железнодорожный, улица Новая, 17	0101000020E610000021054F21570243400BEF7211DFDF4B40
58080	1	10	\N	2581	1388	\N	55.730759999999997	Московская область, город Железнодорожный, ул. 1 Мая, 11	Россия, Московская область, Железнодорожный, улица 1 Мая, 11	0101000020E61000003E7958A835034340CB9C2E8B89DD4B40
58058	1	10	\N	2581	80132	\N	55.728845824823701	Московская область, город Железнодорожный, микр. Павлино, 12/1		0101000020E61000001CD0D2156CFB424003E962D34ADD4B40
58057	1	10	\N	2581	80088	\N	55.730851999999999	Московская область, город Железнодорожный, микр. Павлино, 3/1		0101000020E6100000EF0390DAC4FB4240AC1BEF8E8CDD4B40
58079	1	10	\N	2581	80118	\N	55.737603	Московская область, город Железнодорожный, ул. Юбилейная, 16а		0101000020E6100000FF78AF5A990243403B376DC669DE4B40
58069	1	10	\N	2581	80587	\N	55.746943000000002	Московская область, город Железнодорожный, ул. школьная, 3		0101000020E61000004D69FD2D01024340F27C06D49BDF4B40
58052	1	10	\N	2581	79949	\N	55.750035932873999	Московская область, город Железнодорожный, ул. Центральная, 11	Россия, Московская область, Железнодорожный, Центральная улица	0101000020E6100000EA08E066F1FA42404D69FD2D01E04B40
58050	1	10	\N	2581	80601	\N	55.754434758013801	Московская область, город Железнодорожный, ул. Смельчак, 7		0101000020E610000005FC1A4982FA424098FA795391E04B40
58068	1	10	\N	2581	80588	\N	55.746416000000004	Московская область, город Железнодорожный, ул. Пролетарская, 8		0101000020E6100000E0641BB803014340079B3A8F8ADF4B40
58084	1	10	\N	2581	74143	\N	55.745877999999998	Московская область, город Железнодорожный, ул. Победы, 2а		0101000020E610000026C79DD2C1104340276728EE78DF4B40
58076	1	10	\N	2581	80591	\N	55.743046	Московская область, город Железнодорожный, ул пионерская, 26		0101000020E610000044334FAE2904434039B69E211CDF4B40
58075	1	10	\N	2581	80591	\N	55.743046	Московская область, город Железнодорожный, ул. Пионерская, 26		0101000020E610000044334FAE2904434039B69E211CDF4B40
58066	1	10	\N	2581	1142	\N	55.750667	Московская область, город Железнодорожный, ул. октябрьская, 11	Россия, Московская область, Железнодорожный, Октябрьская улица, 11	0101000020E6100000A872DA5372004340DD9733DB15E04B40
58065	1	10	\N	2581	1142	\N	55.749313999999998	Московская область, город Железнодорожный, ул. октябрьская, 7	Россия, Московская область, Железнодорожный, Октябрьская улица, 7	0101000020E61000002096CD1C92004340AC376A85E9DF4B40
58054	1	10	\N	2581	943	\N	55.750369594323203	Московская область, город Железнодорожный, ул. носовихинское шосе, 13	Россия, Московская область, Железнодорожный, Носовихинское шоссе, 13	0101000020E6100000FE48111956FD424023F3C81F0CE04B40
58053	1	10	\N	2581	943	\N	55.750236000000001	Московская область, город Железнодорожный, Носовихинское шоссе, 13	Россия, Московская область, Железнодорожный, Носовихинское шоссе, 13	0101000020E610000027DC2BF356FD42401424B6BB07E04B40
58074	1	10	\N	2581	80590	\N	55.749125999999997	Московская область, город Железнодорожный, ул. новая, 55		0101000020E6100000897E6DFDF4034340A94A5B5CE3DF4B40
58064	1	10	\N	2581	80108	\N	55.749758241916801	Московская область, город Железнодорожный, ул. некрасова, 4 стр 1	Россия, Московская область, Железнодорожный, улица Некрасова, 4	0101000020E6100000AE8383BD89FF42400AF5F411F8DF4B40
94506	1	10	\N	2581	74194	\N	55.745828000000003	Московская область, город Железнодорожный, ул.Колхозная, дом № 9		0101000020E6100000BD378600E00243407638BA4A77DF4B40
58072	1	10	\N	2581	74194	\N	55.746284000000003	Московская область, город Железнодорожный, ул. Колхозная, 9		0101000020E61000001AC05B204103434098C3EE3B86DF4B40
58070	1	10	\N	2581	74194	\N	55.746284000000003	Московская область, город Железнодорожный, ул. колхозная, 9		0101000020E61000001AC05B204103434098C3EE3B86DF4B40
58078	1	10	\N	2581	80594	\N	55.740780999999998	г.Железнодорожный, ул.Калинина, 7		0101000020E610000023BBD23252034340C43F6CE9D1DE4B40
58077	1	10	\N	2581	80594	\N	55.740780999999998	Московская область, город Железнодорожный, ул. Калинина, 7		0101000020E610000023BBD23252034340C43F6CE9D1DE4B40
58056	1	10	\N	2581	80585	\N	55.745457999999999	Московская область, город Железнодорожный, ул. Заводская, 8		0101000020E61000006022DE3AFFFC42405245F12A6BDF4B40
58063	1	10	\N	2581	79952	\N	55.748376	Московская область, город Железнодорожный, ул. Жилгородок, 4		0101000020E6100000E90DF7915BFF42403F8EE6C8CADF4B40
58062	1	10	\N	2581	79952	\N	55.749443485278697	Московская область, город Железнодорожный, ул. Жилгородок, 35а	Россия, Московская область, Железнодорожный, улица Жилгородок	0101000020E6100000E8A221E351FE4240AA9B8BBFEDDF4B40
58060	1	10	\N	2581	1077	\N	55.745933999999998	Московская область, город Железнодорожный, ул. Граничная, 22 стр1	Россия, Московская область, Железнодорожный, Граничная улица, 22	0101000020E61000002C465D6BEFFD4240BB7CEBC37ADF4B40
58061	1	10	\N	2581	80573	\N	55.749851	Московская область, город Железнодорожный, ул. Граничная, 6		0101000020E6100000C6353E93FDFD4240BBEF181EFBDF4B40
58034	1	10	\N	2581	80969	\N	55.744252000000003	Московская область, город Железнодорожный, ул. Гидрогородок, а		0101000020E61000004374081C09024340C6FD47A643DF4B40
58081	1	10	\N	2581	80115	\N	55.730759999999997	Московская область, город Железнодорожный, ул.1 Мая, 11		0101000020E61000003E7958A835034340CB9C2E8B89DD4B40
94502	1	10	\N	61924	\N	\N	55.372892	г.Егорьевск, 1-й микрорайон (школа №4), д.69		0101000020E61000001C7C6132558843405378D0ECBAAF4B40
58001	1	10	\N	61924	80598	\N	55.379204000000001	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. С.Перовской, дом 101А		0101000020E610000075AE2825048743409641B5C189B04B40
57999	1	10	\N	61924	80091	\N	55.375802999999998	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Советская, дом 174		0101000020E61000002A53CC41D08543408D5E0D501AB04B40
57989	1	10	\N	61924	80091	\N	55.390431078880503	Московская область, Егорьевский муниципальный районг.Егорьевск, ул.Советская, дом 2Д		0101000020E6100000239F573CF58243401B2C9CA4F9B14B40
57997	1	10	\N	61924	80292	\N	55.369224000000003	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Горшкова, дом 32		0101000020E6100000DA20938C9C834340FC7266BB42AF4B40
58006	1	10	\N	61924	80596	\N	55.374391000000003	Московская область, Егорьевский муниципальный район, г.Егорьевск, 1-й микрорайон, дом 46		0101000020E6100000D122DBF97E8843405875560BECAF4B40
57998	1	10	\N	61924	80895	\N	55.361784	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. 1 Мая, дом 77		0101000020E61000004A0856D5CB854340A81B28F04EAE4B40
57980	1	10	\N	1343	8056	\N	56.744950000000003	Московская область, городской округ Дубна, Сахарова, 17	Россия, Московская область, Дубна, улица Сахарова, 17	0101000020E610000072A43330F2964240DE9387855A5F4C40
57978	1	10	\N	1343	8042	\N	56.737051000000001	Московская область, городской округ Дубна, Понтекорво, 16	Россия, Московская область, Дубна, улица Понтекорво, 16	0101000020E610000046D1031F83954240F73DEAAF575E4C40
94497	1	10	\N	1343	7976	\N	56.757539000000001	Адрес УИК и помещения для голосования:Московская область, г.Дубна,пл. Космонавтов, (здание ДК "Октябрь"), д.1		0101000020E6100000EACE13CFD9904240E738B709F7604C40
57968	1	10	\N	1343	71865	\N	56.759381465793602	Московская область, городской округ Дубна, Центральная, 23	Россия, Московская область, Дубна, Центральная улица, 23/6	0101000020E6100000E529ABE97A924240151A886533614C40
57982	1	10	\N	1343	80030	\N	56.746741	Московская область, городской округ Дубна, Флерова, 8		0101000020E6100000C767B27F9E9842408ACA8635955F4C40
57986	1	10	\N	1343	80880	\N	56.741537385027698	Московская область, городской округ Дубна, Университетская, 19	Россия, Московская область, Дубна	0101000020E61000001650A8A78F9C424011E335AFEA5E4C40
57969	1	10	\N	1343	80044	\N	56.762941858361401	Московская область, городской округ Дубна, Тверская, 12а	Россия, Московская область, Дубна, Тверская улица, 12а	0101000020E6100000A724EB7074914240575F5D15A8614C40
57977	1	10	\N	1343	71936	\N	56.732232000000003	Московская область, городской округ Дубна, А.С.Попова, 9	Россия, Московская область, Дубна, улица Попова, 9	0101000020E6100000D3A23EC91D944240D78A36C7B95D4C40
57972	1	10	\N	1343	71878	\N	56.748297138047398	Московская область, городской округ Дубна, Ленина, 39а	Россия, Московская область, Дубна, улица Ленина, 39а	0101000020E610000069554B3ACA914240F3583332C85F4C40
57971	1	10	\N	1343	79938	\N	56.755118106049302	Московская область, городской округ Дубна, Карла Маркса, 9а	Россия, Московская область, Дубна, улица Карла Маркса, 9а	0101000020E610000019A9F7544E9142407B4FE5B4A7604C40
94498	1	10	\N	1343	79940	\N	56.742344087566799	Адрес УИК и помещения для голосования:Московская область, г.Дубна,ул. Московская, (здание городской библиотеки семейного чтения), д.5	Россия, Московская область, Дубна, Дачный проезд, 5	0101000020E61000008EE89E758D964240E030D120055F4C40
57984	1	10	\N	1343	80558	\N	56.754035999999999	Московская область, городской округ Дубна, Векслера, 23		0101000020E6100000F29A577556994240DA006C4084604C40
57983	1	10	\N	1343	80561	\N	56.749209	Московская область, городской округ Дубна, Блохинцева, 3		0101000020E6100000C2A38D23D6984240376F9C14E65F4C40
57981	1	10	\N	1343	71927	\N	56.741267000000001	Московская область, городской округ Дубна, Алея Высоцкого, 1		0101000020E6100000226C787AA5944240514D49D6E15E4C40
57985	1	10	\N	1343	80560	\N	56.751396	Московская область, городской округ Дубна, Ак.Балдина, 2		0101000020E61000009F03CB11329A4240302C7FBE2D604C40
57966	1	10	\N	4639	\N	\N	55.414415317426503	"Московская область, городской округ Домодедово,аэропорт ""Домодедово"", здание аэропорта"		0101000020E6100000790261A758F3424065FCFB8C0BB54B40
57957	1	10	\N	4639	\N	\N	55.324325000000002	"Московская область, городской округ Домодедово, тер.ГУ ЦВМиР ""Зеленая Роща"", Клуб ГУ ЦВМиР ""Зеленая Роща"""		0101000020E6100000F50F221972EE42403A234A7B83A94B40
57948	1	10	\N	4639	\N	\N	55.330440000000003	Московская область, городской округ Домодедово, г.Домодедово, мкр.Белые Столбы, Шаховский СДК	Россия, Московская область, Домодедово, микрорайон Белые Столбы	0101000020E61000009C3237DF88EC424027A5A0DB4BAA4B40
57937	1	10	\N	4639	\N	\N	55.330440000000003	Московская область, городской округ Домодедово, г.Домодедово, мкр.Белые Столбы, Кирова, 3а	Россия, Московская область, Домодедово, микрорайон Белые Столбы	0101000020E61000009C3237DF88EC424027A5A0DB4BAA4B40
57924	1	10	\N	4639	7478	\N	55.438746999999999	Московская область, городской округ Домодедово, г.Домодедово, Текстильщиков, 13а	Россия, Московская область, Домодедово, улица Текстильщиков, 13а	0101000020E61000001ADD41EC4CDD4240EB1B98DC28B84B40
59077	1	10	108	21669	80678	\N	55.705005999999997	рп Новоивановское, Агрохимиков, 2		0101000020E6100000E92CB308C5AE4240ECBDF8A23DDA4B40
57914	1	10	\N	4639	7357	\N	55.452477000000002	Московская область, городской округ Домодедово, г.Домодедово, Гагарина, 13	Россия, Московская область, Домодедово, улица Гагарина, 13	0101000020E61000009C89E942ACE042409A982EC4EAB94B40
57953	1	10	\N	4639	71789	\N	55.430134289757	"Московская область, городской округ Домодедово, пос.ГПЗ ""Константиново"", Константиновский СДК"		0101000020E61000008CF4A276BFDA4240E77283A10EB74B40
57930	1	10	\N	4639	71885	\N	55.414325675028998	Московская область, городской округ Домодедово, г.Домодедово, мкр.Авиационный, пл.Гагарина, 5	Россия, Московская область, Домодедово, микрорайон Авиационный, улица Гагарина, 5	0101000020E61000009E29745E63EB4240F6F065A208B54B40
57928	1	10	\N	4639	71885	\N	55.414630839801397	Московская область, городской округ Домодедово, г.Домодедово, мкр.Авиационный, пл.Гагарина, 1	Россия, Московская область, Домодедово, микрорайон Авиационный, улица Гагарина, 1	0101000020E610000018CDCAF621EB42403274ECA012B54B40
57934	1	10	\N	4639	80769	\N	55.265305612847499	Московская область, городской округ Домодедово, г.Домодедово, мкр.Барыбино, Южная, клуб	Россия, Московская область, Домодедово, микрорайон Барыбино	0101000020E61000005FB7088CF5F142405FB7088CF5A14B40
57922	1	10	\N	4639	67099	\N	55.425846672417499	Московская область, городской округ Домодедово, г.Домодедово, Ю.Корнеева, 39		0101000020E61000009E0C8E9257E34240C30C8D2782B64B40
57931	1	10	\N	4639	71766	\N	55.267422426377401	Московская область, городской округ Домодедово, г.Домодедово, мкр.Барыбино, Чкалова, 1	Россия, Московская область, Домодедово, микрорайон Барыбино	0101000020E6100000CEA623809BF142408F1D54E23AA24B40
94496	1	10	\N	4639	16867	\N	55.444991999999999	г.Домодедово, с.Ям, ул.Центральная, д.7/ г.Домодедово, с.Ям, ул.Школьная, д.14	Россия, Московская область, Домодедово, Центральная улица, 7	0101000020E61000009D66817687E04240A67D737FF5B84B40
57927	1	10	\N	4639	79918	\N	55.423998055638201	Московская область, городской округ Домодедово, г.Домодедово, Талалихина, 6	Россия, Московская область, Домодедово, улица Талалихина, 2	0101000020E6100000EB19C231CBE24240E2C8039145B64B40
57916	1	10	\N	4639	7327	\N	55.442408	Московская область, городской округ Домодедово, г.Домодедово, Советская, 32	Россия, Московская область, Домодедово, Советская улица, 32	0101000020E6100000B69DB64604E1424090BE49D3A0B84B40
57926	1	10	\N	4639	80190	\N	55.4420128824637	Московская область, городской округ Домодедово, г.Домодедово, Советская, 19 корп.1	Россия, Московская область, Домодедово, Советская улица, 19с1	0101000020E6100000234BE658DEDF424014B4C9E193B84B40
57911	1	10	\N	4639	80190	\N	55.446548999999997	Московская область, городской округ Домодедово, г.Домодедово, Советская, 70		0101000020E6100000D63730B951DE4240DF87838428B94B40
57918	1	10	\N	4639	80552	\N	55.433219999999999	Московская область, городской округ Домодедово, г.Домодедово, Рабочая, 25		0101000020E610000022FC8BA031E142408FFCC1C073B74B40
57940	1	10	\N	4639	79928	\N	55.423309974273202	Московская область, городской округ Домодедово, г.Домодедово, мкр.Востряково, Парковая, 1	Россия, Московская область, Домодедово, Парковая улица, 3	0101000020E6100000EBABAB02B5E04240EE08A7052FB64B40
58071	1	10	\N	4639	81106	\N	55.433310806042201	ул.Новая, дом№38/ул.Колхозная, дом № 9	Россия, Московская область, Домодедово, Новая улица	0101000020E6100000C30FCEA78EE14240A0FF1EBC76B74B40
57939	1	10	\N	4639	71767	\N	55.397213969299798	Московская область, городской округ Домодедово, г.Домодедово, мкр.Востряково, Луговая, 1а	Россия, Московская область, Домодедово, поселок Востряково	0101000020E61000006D3A02B859E84240B5C189E8D7B24B40
57910	1	10	\N	4639	80035	\N	55.452821817216503	Московская область, городской округ Домодедово,г.Домодедово, Ломоносова, 12/1	Россия, Московская область, Домодедово, улица Ломоносова	0101000020E61000008DEE2076A6DE424064744012F6B94B40
57923	1	10	\N	4639	71809	\N	55.424626347212701	Московская область, городской округ Домодедово, г.Домодедово, Ю.Корнеева, 42		0101000020E6100000603DEE5BADE3424002840F255AB64B40
57920	1	10	\N	4639	80554	\N	55.434430999999996	Московская область, городской округ Домодедово, г.Домодедово, Коломийца, 4		0101000020E61000009E25C808A8E242402DAF5C6F9BB74B40
57921	1	10	\N	4639	7393	\N	55.426195999999997	Московская область, городской округ Домодедово, г.Домодедово, Каширское шоссе, 100а	Россия, Московская область, Домодедово, Каширское шоссе, 100а	0101000020E61000009143C4CDA9E24240CFD72C978DB64B40
57917	1	10	\N	4639	7393	\N	55.445636392307101	Московская область, городской округ Домодедово, г.Домодедово, Каширское шоссе, 14	Россия, Московская область, Домодедово, Каширское шоссе	0101000020E6100000178046E9D2E14240CBF5B6990AB94B40
57956	1	10	\N	4639	74060	\N	55.394959999999998	Московская область, городской округ Домодедово, г.Домодедово, мкр.Востряково, Заборье, 58	Россия, Московская область, Домодедово, поселок Востряково	0101000020E6100000B48F15FC36E84240349D9D0C8EB24B40
57929	1	10	\N	4639	80264	\N	55.412799	Московская область, городской округ Домодедово, г.Домодедово, мкр.Авиационный, Жуковского, 15		0101000020E610000088635DDC46EB42402769FE98D6B44B40
94495	1	10	\N	4639	80074	\N	55.438583000000001	г.Домодедово, ул.Горького, д.8/ г.Домодедово, площадь 30-летия Победы, МУ «Молодежный комплексный центр «Победа»		0101000020E61000009AEE75525FE2424071CADC7C23B84B40
59588	1	10	\N	4639	4024	\N	55.433266000000003	Московская область, Рузский муниципальный район, городское поселение Тучково, Восточная, 6/1	Россия, Московская область, Домодедово, Восточная улица, 6	0101000020E6100000C6F8307BD9E24240003CA24275B74B40
58614	1	10	\N	4639	4024	\N	55.433909999999997	г. Луховицы-3, Восточная, Здание школы	Россия, Московская область, Домодедово, Восточная улица, 1	0101000020E6100000008FA850DDE2424024B4E55C8AB74B40
57932	1	10	\N	4639	80753	\N	55.265168000000003	Московская область, городской округ Домодедово, г.Домодедово, мкр.Барыбино, Агрохимиков, 4б		0101000020E61000006B9DB81CAFF242400EF96706F1A14B40
57935	1	10	\N	4639	72272	\N	55.330440000000003	Московская область, городской округ Домодедово,г.Домодедово, мкр.Белые Столбы, Авенариуса, 1а		0101000020E61000009C3237DF88EC424027A5A0DB4BAA4B40
57915	1	10	\N	4639	7367	\N	55.448872999999999	Московская область, городской округ Домодедово, г.Домодедово, 3-й Московский проезд, 7	Россия, Московская область, Домодедово, 3-й Московский проезд, 7	0101000020E6100000F19D98F562E042405987A3AB74B94B40
57912	1	10	\N	4639	7332	\N	55.446066140800902	Московская область, городской округ Домодедово, г.Домодедово, 2-ая Коммунистическая, 2	Россия, Московская область, Домодедово, 2-я Коммунистическая улица, 5	0101000020E61000003B342C465DDF4240C4EDD0B018B94B40
57936	1	10	\N	4639	71992	\N	55.330440000000003	Московская область, городской округ Домодедово, г.Домодедово, мкр.Белые Столбы, 2-ая Московская, 56		0101000020E61000009C3237DF88EC424027A5A0DB4BAA4B40
57913	1	10	\N	4639	7341	\N	55.453063999999998	Московская область, городской округ Домодедово, г.Домодедово, 1-ая Коммунистическая, 33	Россия, Московская область, Домодедово, 1-я Коммунистическая улица, 33	0101000020E6100000D219187959DF42405A7F4B00FEB94B40
57938	1	10	\N	4639	80815	\N	55.442865402178001	Московская область, городской округ Домодедово, г.Домодедово, мкр.Белые Столбы, 1-й Московский проезд, 6	Россия, Московская область, Домодедово	0101000020E61000004CA59F7076E1424082C5E1CCAFB84B40
57899	1	10	\N	10881	7215	\N	55.949312584064501	Московская область, городской округ Долгопрудный, Проспект Пацаева, 16	Россия, Московская область, Долгопрудный, проспект Пацаева, 16	0101000020E610000020B75F3E59BF42407555A01683F94B40
57875	1	10	\N	10881	6944	\N	55.933377999999998	Московская область, городской округ Долгопрудный, пл. Собина, 3		0101000020E6100000AD4ECE50DCC14240276728EE78F74B40
57873	1	10	\N	10881	6944	\N	55.933377999999998	Московская область, городской округ Долгопрудный, пл. Собина, 1		0101000020E6100000AD4ECE50DCC14240276728EE78F74B40
94492	1	10	\N	10881	16863	\N	55.975445999999998	Московская область, городской округ Долгопрудный, мкр. Шереметьевский, ул. Южная, д.1	Россия, Московская область, Долгопрудный, микрорайон Шереметьевский, Южная улица, 1а	0101000020E6100000D235936FB6BF4240CB811E6ADBFC4B40
57878	1	10	\N	10881	80202	\N	55.939933712921203	Московская область, городской округ Долгопрудный, Циолковского, 32	Россия, Московская область, Долгопрудный, улица Циолковского, 32	0101000020E61000000B2AAA7EA5C142400133DFC14FF84B40
57876	1	10	\N	10881	80202	\N	55.934162131525902	Московская область, городской округ Долгопрудный, Циолковского, 10	Россия, Московская область, Долгопрудный, улица Циолковского, 10	0101000020E61000008E075BECF6C142403E95D39E92F74B40
57903	1	10	\N	10881	80546	\N	55.961000993874997	Московская область, городской округ Долгопрудный, Флотская, 1	Россия, Московская область, Долгопрудный, Флотская улица, 1	0101000020E6100000344B02D4D4C042402F36AD1402FB4B40
57890	1	10	\N	10881	80225	\N	55.941428148189502	Московская область, городской округ Долгопрудный, Спортивная, 9	Россия, Московская область, Долгопрудный, Спортивная улица, 9	0101000020E61000009B1E1494A2BF4240F4C473B680F84B40
57888	1	10	\N	10881	80225	\N	55.945391922164497	Московская область, городской округ Долгопрудный, Спортивная, 3а		0101000020E61000007CD11E2FA4BF424034F3E49A02F94B40
57891	1	10	\N	10881	80037	\N	55.9415594871259	Московская область, городской округ Долгопрудный, Спортивная, 7а		0101000020E6100000E1D1C6116BBF424092205C0185F84B40
57889	1	10	\N	10881	80037	\N	55.944414869440102	Московская область, городской округ Долгопрудный, Спортивная, 3	Россия, Московская область, Долгопрудный, Спортивная улица, 3	0101000020E61000001CB28174B1BF4240096D3997E2F84B40
57874	1	10	\N	10881	71955	\N	55.934240000000003	Московская область, городской округ Долгопрудный, Советская, 6	Россия, Московская область, Долгопрудный, Советская улица, 6	0101000020E610000011C8258E3CC24240BA4E232D95F74B40
57877	1	10	\N	10881	80027	\N	55.937956	Московская область, городской округ Долгопрудный, Первомайская, 50/4	Россия, Московская область, Долгопрудный, Первомайская улица, 50	0101000020E6100000F03504C765C24240228B34F10EF84B40
57881	1	10	\N	10881	80040	\N	55.945059999999998	Московская область, городской округ Долгопрудный, Октябрьская, 24а	Россия, Московская область, Долгопрудный, Октябрьская улица, 24а	0101000020E6100000AA44D95BCAC14240FE60E0B9F7F84B40
57892	1	10	\N	10881	7141	\N	55.937204999999999	Московская область, городской округ Долгопрудный, Новый бульвар, 21, к.3		0101000020E6100000C93A1C5DA5BF4240E7525C55F6F74B40
57882	1	10	\N	10881	5831	\N	55.947499999999998	Московская область, городской округ Долгопрудный, Московское шоссе, 53а	Россия, Московская область, Долгопрудный, Московское шоссе, 53а	0101000020E610000066868DB27EC14240E17A14AE47F94B40
57895	1	10	\N	10881	74142	\N	55.941208464943003	Московская область, городской округ Долгопрудный, Молодежная, 10а	Россия, Московская область, Долгопрудный, Молодежная улица, 10а	0101000020E610000039268BFB8FBE4240E65DF58079F84B40
57894	1	10	\N	10881	74142	\N	55.942574055929498	Московская область, городской округ Долгопрудный, Молодежная, 13	Россия, Московская область, Долгопрудный, Молодежная улица	0101000020E6100000A439B2F2CBBE4240AB07CC43A6F84B40
58617	1	10	109	61952	80708	\N	54.942377	р.п. Белоомут, Большая Огаревская, 26		0101000020E6100000EA758BC058AB434055C03DCF9F784B40
57901	1	10	\N	10881	7148	\N	55.952005999999997	Московская область, городской округ Долгопрудный, Лихачевское шоссе, 24	Россия, Московская область, Долгопрудный, Лихачевское шоссе, 24	0101000020E6100000D6A9F23D23BF424042CC2555DBF94B40
57898	1	10	\N	10881	7148	\N	55.950716	Московская область, городской округ Долгопрудный, Лихачевское шоссе, 27	Россия, Московская область, Долгопрудный, Лихачевское шоссе, 27	0101000020E61000005F0D501A6ABE424058E4D70FB1F94B40
57893	1	10	\N	10881	7148	\N	55.935889000000003	Московская область, городской округ Долгопрудный, Лихачевское шоссе, 1, к.Г	Россия, Московская область, Долгопрудный, Лихачевское шоссе, 1	0101000020E6100000753A90F5D4BE4240D4D7F335CBF74B40
94493	1	10	\N	10881	16864	\N	55.967390000000002	Московская область, городской округ Долгопрудный, мкр. Хлебниково, ул. Ленинградская, д. 10а	Россия, Московская область, Долгопрудный, микрорайон Хлебниково, Ленинградская улица, 10а	0101000020E61000009A22C0E95DC042401D3D7E6FD3FB4B40
94490	1	10	\N	10881	6922	\N	55.929544999999997	Московская область, городской округ Долгопрудный, Институтский переулок, 9, строение 3		0101000020E610000003098A1F63C2424085949F54FBF64B40
57872	1	10	\N	10881	6922	\N	55.932102	Московская область, городской округ Долгопрудный, Институтский переулок, 1	Россия, Московская область, Долгопрудный, Институтский переулок, 1	0101000020E61000008A3BDEE4B7C24240A2444B1E4FF74B40
57884	1	10	\N	10881	80204	\N	55.942433000000001	Московская область, городской округ Долгопрудный, Дирижабельная, 17		0101000020E6100000B680D07AF8C04240E9D500A5A1F84B40
57883	1	10	\N	10881	80204	\N	55.945160999999999	Московская область, городской округ Долгопрудный, Дирижабельная, 21		0101000020E61000006BD784B4C6C04240323A2009FBF84B40
57897	1	10	\N	10881	74115	\N	55.947777000000002	Московская область, городской округ Долгопрудный, Гранитная, 7		0101000020E6100000E71C3C139ABE42405473B9C150F94B40
57896	1	10	\N	10881	74115	\N	55.947777000000002	Московская область, городской округ Долгопрудный, Гранитная, 6		0101000020E6100000E71C3C139ABE42405473B9C150F94B40
57886	1	10	\N	10881	80160	\N	55.938667000000002	Московская область, городской округ Долгопрудный, Ак. Лаврентьева, 29		0101000020E6100000C2120F289BC04240CF6A813D26F84B40
94494	1	10	\N	10881	80801	\N	55.965142999999998	Московская область, городской округ Долгопрудный, мкр. Павельцево, ул. 25 -го съезда, д. 1		0101000020E6100000E9F351465CBE42404E7B4ACE89FB4B40
57782	1	10	\N	60253	80854	\N	56.356646252797702	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр. Махалина, здание Еврохимчистки, д. 21, 2 этаж		0101000020E6100000C170AE6186C44240E61F7D93A62D4C40
57776	1	10	\N	60253	80843	\N	56.353510781203703	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Старо-Рогачевская, Дмитровская Автошкола, д. 34		0101000020E6100000DC2A8881AEBF42405CE333D93F2D4C40
57788	1	10	\N	60253	74213	\N	56.362406999999997	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Профессиональная, админ. зд. ""Роспотребнадзора"""		0101000020E6100000588CBAD6DEC34240B56B425A632E4C40
57787	1	10	\N	60253	81022	\N	56.344735999999997	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул.Больничная, административный корпус ДТМО		0101000020E610000054C8957A16C442407EE02A4F202C4C40
57769	1	10	\N	22061	5925	\N	55.628585999999999	Московская область, город Дзержинский, ул.Лермонтова, д.1а	Россия, Московская область, Дзержинский, улица Лермонтова, 1а	0101000020E61000000229B16B7BED42409A5C8C8175D04B40
57766	1	10	\N	22061	5888	\N	55.635832999999998	Московская область, город Дзержинский, пр.Пушкина, д.2	Россия, Московская область, Дзержинский, проезд Пушкина, 2	0101000020E61000004F965AEF37EC4240D95BCAF962D14B40
57767	1	10	\N	22061	80016	\N	55.631126999999999	Московская область, город Дзержинский, ул.Школьная, д.5а		0101000020E6100000BCAE5FB01BEC4240B14F00C5C8D04B40
57770	1	10	\N	22061	80529	\N	55.631958668129201	Московская область, город Дзержинский, ул.Угрешская, д.32	Россия, Московская область, Дзержинский, Угрешская улица, 32	0101000020E610000064027E8D24EF4240D9B45208E4D04B40
57773	1	10	\N	22061	80533	\N	55.625933000000003	Московская область, город Дзержинский, ул.Томилинская, д.9		0101000020E61000007905A22765EE42405C3E92921ED04B40
57772	1	10	\N	22061	80533	\N	55.628006999999997	Московская область, город Дзержинский, ул.Томилинская, д.23а		0101000020E61000005305A3923AEF42405C548B8862D04B40
57771	1	10	\N	22061	80533	\N	55.627218999999997	Московская область, город Дзержинский, ул.Томилинская, д.11а		0101000020E610000092EC116A86EE4240043752B648D04B40
57775	1	10	\N	22061	80033	\N	55.626655	Московская область, город Дзержинский, ул.Спортивная, д.1а		0101000020E6100000662D05A4FDEB4240FC6F253B36D04B40
57768	1	10	\N	22061	79888	\N	55.6307145890461	Московская область, город Дзержинский, ул.Лесная, д.3		0101000020E6100000618907944DED42405F0CE544BBD04B40
57774	1	10	\N	22061	80540	\N	55.628444000000002	Московская область, город Дзержинский, ул.Лермонтова, д.42		0101000020E6100000BA13ECBFCEED424008AF5DDA70D04B40
94517	1	10	\N	61926	80169	\N	55.855325000000001	Московская область, Истринский муниципальный район, г.Дедовск, ул.Ленина, д.4, помещение МОУ "Дедовская ср.общеоб.школа №4",  центральный вход		0101000020E610000036751E15FF8F4240C139234A7BED4B40
58177	1	10	\N	61926	80103	\N	55.860297000000003	Московская область, Истринский муниципальный район, городское поселение Дедовск, Гагарина, здание Дома культуры, 14		0101000020E610000011397D3D5F8F424068EC4B361EEE4B40
58624	1	10	\N	61956	80718	\N	54.957329999999999	с. Городна, Центральная, 92А		0101000020E6100000F1F109D97967434066BD18CA897A4B40
53183	1	9	\N	3727	39075	\N	52.615650000000002	Липецкая область, город Липецк, ул. Им. Семашко, 68		0101000020E610000036C98FF815CB434026E4839ECD4E4A40
57700	1	10	\N	61895	79902	\N	55.322383689598098	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, пл. Ленина, 1	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Центральный, улица Победы	0101000020E610000061360186E5554340786000E143A94B40
57722	1	10	\N	61895	80496	\N	55.253784000000003	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Чапаева, 1		0101000020E6100000E49F19C407624340C11F7EFE7BA04B40
94471	1	10	\N	61895	80396	\N	55.308971	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Цесиса, 17 МУ "Молодежный центр "Олимпиец"		0101000020E61000001233FB3C46534340CA349A5C8CA74B40
57697	1	10	\N	61895	80458	\N	55.322850000000003	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Менделеева, 11		0101000020E6100000077AA86DC3544340BEC1172653A94B40
57711	1	10	\N	61895	80551	\N	55.3116978938885	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Маркина, 3		0101000020E61000006B82A8FB00584340431D56B8E5A74B40
57724	1	10	\N	61895	80484	\N	55.248477999999999	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Карла Маркса, 12		0101000020E6100000F5F57CCD7261434043E38920CE9F4B40
57723	1	10	\N	61895	80007	\N	55.248477999999999	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Карла Маркса, 12А		0101000020E6100000F5F57CCD7261434043E38920CE9F4B40
57693	1	10	\N	61895	80448	\N	55.313018999999997	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Кагана, 22		0101000020E610000081053065E05243406803B00111A84B40
57692	1	10	\N	61895	80448	\N	55.310842000000001	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Кагана, 21		0101000020E61000006F6589CE32534340931CB0ABC9A74B40
57675	1	10	\N	61890	80153	\N	56.044291999999999	город Волоколамск, Катукова, 32		0101000020E6100000A699EE7552F94140BABC395CAB054C40
57683	1	10	\N	61890	79874	\N	56.003399827158098	город Волоколамск, Волоколамская, 59		0101000020E6100000C11F7EFE7BF64140386744696F004C40
57764	1	10	\N	60269	74205	\N	55.684756635580101	Московская область, городской округ Власиха, ул. Спортивная, д. 98	Россия, Московская область, поселок городского типа Власиха	0101000020E61000004D13B69F8C994240815A0C1EA6D74B40
94487	1	10	\N	60269	80534	\N	55.6823374423129	Московская область, городской округ Власиха, ул. Лесная, д. 37	Россия, Московская область, поселок городского типа Власиха	0101000020E6100000207EFE7BF0984240E5EC9DD156D74B40
57698	1	10	\N	59566	71947	\N	55.685116999999998	Московская область, городской округ Власиха, мкр. Школьный, д. 10		0101000020E6100000D503E621539842408177F2E9B1D74B40
57751	1	10	\N	59566	80512	\N	55.685229	Московская область, городской округ Власиха, ул. Маршала Жукова, д. 9	Россия, Московская область, поселок городского типа Власиха	0101000020E6100000EE073C3080984240A9A27895B5D74B40
58547	1	10	\N	61935	80324	\N	55.543700000000001	г.Видное, ул.Ольховая, д.5		0101000020E610000076C58CF0F6DC4240E86A2BF697C54B40
58889	1	10	\N	61946	80633	\N	55.343082000000003	Московская область, Наро-Фоминский район, г.Верея, пл.Советская, 2		0101000020E61000001E882CD2C417424053EC681CEAAB4B40
57671	1	10	\N	13981	\N	\N	55.400562999999998	Московская область, городской округ Бронницы, поселок Горка, 17	Россия, Московская область, Бронницы, поселок Горка, 17	0101000020E6100000359A5C8C812543406B7EFCA545B34B40
57665	1	10	\N	13981	37279	\N	55.417388000000003	"Московская область, городской округ Бронницы, пл. Тимофеева, помещение КДЦ ""Бронницы"""	Россия, Московская область, Бронницы, Каширский переулок	0101000020E610000044F982161220434016DF50F86CB54B40
57668	1	10	\N	13981	80464	\N	55.420914419032002	Московская область, городской округ Бронницы, Строительная, 17	Россия, Московская область, Бронницы, Строительная улица, 17	0101000020E6100000F623456458254340DB368C82E0B54B40
59583	1	10	\N	13981	3952	\N	55.429757000000002	Московская область, Рузский муниципальный район, городское поселение Тучково, Советская, 17	Россия, Московская область, Бронницы, Советская улица, 17	0101000020E6100000E35295B6B8204340111D024702B74B40
57666	1	10	\N	13981	80438	\N	55.422609999999999	Московская область, городской округ Бронницы, Московская, 120		0101000020E6100000B8EA3A5453224340357BA01518B64B40
57667	1	10	\N	13981	74075	\N	55.425952781717697	Московская область, городской округ Бронницы, Москворецкая, 44	Россия, Московская область, Бронницы, площадь Ленина, 2	0101000020E61000000D17B9A7AB2143400951BEA085B64B40
57670	1	10	\N	13981	74133	\N	55.415227000000002	Московская область, городской округ Бронницы, Льва Толстого, 8	Россия, Московская область, Бронницы, улица Льва Толстого, 8	0101000020E61000002CF015DD7A23434046B5882826B54B40
57669	1	10	\N	13981	74133	\N	55.413590999999997	Московская область, городской округ Бронницы, Льва Толстого, 11	Россия, Московская область, Бронницы, улица Льва Толстого, 11	0101000020E610000024D6E25300224340C075C58CF0B44B40
57664	1	10	\N	13981	4677	\N	55.416463	Московская область, городской округ Бронницы, пер. Комсомольский, 60	Россия, Московская область, Бронницы, Комсомольский переулок, 60	0101000020E6100000D2393FC5712043403D7FDAA84EB54B40
59139	1	10	\N	3929	\N	\N	55.826847000000001	Московская область, городской округ Орехово-Зуево, Гагарина, 55	Россия, Московская область, Балашиха, микрорайон имени Гагарина	0101000020E61000007B6B60AB04F54240DAE55B1FD6E94B40
57662	1	10	\N	3929	\N	\N	55.804136999999997	Московская область, городской округ Балашиха, микрорайон 1 Мая, 33	Россия, Московская область, Балашиха, микрорайон 1 Мая, 33	0101000020E6100000874F3A9160EC4240744012F6EDE64B40
57641	1	10	\N	3929	\N	\N	55.802973000000001	Московская область, городской округ Балашиха, микрорайон ВНИИПО, 3	Россия, Московская область, Балашиха, микрорайон ВНИИПО	0101000020E610000054C8957A160043401749BBD1C7E64B40
57622	1	10	\N	3929	\N	\N	55.826361403256499	Московская область, городской округ Балашиха, микрорайон Гагарина, 14А	Россия, Московская область, Балашиха, микрорайон имени Гагарина, 14а	0101000020E6100000598638D6C5F542404DD87E32C6E94B40
57636	1	10	\N	3929	80038	\N	55.795267743472401	Московская область, городской округ Балашиха, шоссе Энтузиастов, 56	Россия, Московская область, Балашиха, шоссе Энтузиастов, 56	0101000020E61000001F2BF86D88FB424015C78157CBE54B40
57634	1	10	\N	3929	80038	\N	55.798398733043904	Московская область, городской округ Балашиха, шоссе Энтузиастов, 53	Россия, Московская область, Реутов, шоссе Энтузиастов	0101000020E6100000096EA46C91FC42405E143DF031E64B40
57613	1	10	\N	3929	80038	\N	55.792397000000001	Московская область, городской округ Балашиха, шоссе Энтузиастов, 38	Россия, Московская область, Балашиха, шоссе Энтузиастов, 38	0101000020E6100000516C054D4BF842406939D0436DE54B40
57635	1	10	\N	3929	79879	\N	55.7983263987526	Московская область, городской округ Балашиха, проспект Ленина, 55	Россия, Московская область, Балашиха, проспект Ленина, 55	0101000020E610000097C79A9141FA4240F4C5DE8B2FE64B40
57617	1	10	\N	3929	79879	\N	55.796410000000002	Московская область, городской округ Балашиха, проспект Ленина, 20		0101000020E6100000323A2009FBF842408B1A4CC3F0E54B40
57648	1	10	\N	3929	79891	\N	55.784150901238498	Московская область, городской округ Балашиха, микрорайон ЦОВБ, 14		0101000020E6100000A1BB24CE8AF0424017105A0F5FE44B40
57643	1	10	\N	3929	71783	\N	55.793647	Московская область, городской округ Балашиха, микрорайон Северный, 63	Россия, Московская область, Балашиха, микрорайон Северный	0101000020E6100000569BFF571D014340C5C8923996E54B40
57649	1	10	\N	3929	79882	\N	55.776212999999998	Московская область, городской округ Балашиха, микрорайон Дзержинского, 50		0101000020E61000000DC1711937F3424072DD94F25AE34B40
94469	1	10	\N	3929	80399	\N	55.8110177735972	Московская область, городской округ Балашиха, микрорайон 1 Мая, 12	Россия, Московская область, Балашиха, микрорайон 1 Мая	0101000020E610000095607138F3EB4240D13B1570CFE74B40
57653	1	10	\N	3929	80786	\N	55.837763586696298	Московская область, городской округ Балашиха, квартал Абрамцово, 103А	Россия, Московская область, Балашиха	0101000020E6100000529CA38E8EEB424011E2CAD93BEB4B40
57147	1	10	\N	3929	80419	\N	55.793222	Московская область, городской округ Балашиха, Фучика, 5		0101000020E61000002C0E677E35FB4240DE3B6A4C88E54B40
57623	1	10	\N	3929	4164	\N	55.827722000000001	Московская область, городской округ Балашиха, Щелковское шоссе, 102		0101000020E6100000B7CF2A33A5F34240011764CBF2E94B40
57639	1	10	\N	3929	80417	\N	55.794583000000003	Московская область, городской округ Балашиха, Фадеева, 8		0101000020E6100000389F3A5629FD4240927A4FE5B4E54B40
57638	1	10	\N	3929	80417	\N	55.793824000000001	Московская область, городской округ Балашиха, Фадеева, 8А		0101000020E6100000CC4065FCFBFC4240D4635B069CE54B40
57640	1	10	\N	3929	80422	\N	55.795068999999998	Московская область, городской округ Балашиха, Твардовского, 19		0101000020E610000089450C3B8CFD42401E882CD2C4E54B40
57637	1	10	\N	3929	80422	\N	55.791100999999998	Московская область, городской округ Балашиха, Твардовского, 3		0101000020E610000058E1968FA4FC42409C6A2DCC42E54B40
57629	1	10	\N	3929	80234	\N	55.817610323331699	Московская область, городской округ Балашиха, Спортивная, 17	Россия, Московская область, Балашиха, Спортивная улица, 17	0101000020E6100000EAE923F087FB4240F870C971A7E84B40
57644	1	10	\N	3929	80142	\N	55.775610999999998	Московская область, городской округ Балашиха, микрорайон Никольско-Архангельский, Сосновый бор, 2		0101000020E6100000787AA52C43F642407CB5A33847E34B40
57621	1	10	\N	3929	71794	\N	55.823787755863002	Московская область, городской округ Балашиха, Солнечная, 10	Россия, Московская область, Балашиха, Солнечная улица, 10	0101000020E61000000F7C0C569CFA42402B6B9BE271E94B40
56805	1	10	\N	3929	74185	\N	55.7961708504968	Московская область, городской округ Балашиха, Советская, 4	Россия, Московская область, Балашиха, Советская улица, 4	0101000020E6100000C4CE143AAFF7424006836BEEE8E54B40
57658	1	10	\N	3929	74129	\N	55.799201294670397	Московская область, городской округ Балашиха, микрорайон Заря, Советская, 11	Россия, Московская область, Балашиха, Советская улица	0101000020E6100000967840D994F742401AF7E6374CE64B40
57616	1	10	\N	3929	74129	\N	55.802528000000002	Московская область, городской округ Балашиха, Советская, 17	Россия, Московская область, Балашиха, Советская улица, 17	0101000020E61000008C497F2F85F74240E90FCD3CB9E64B40
57624	1	10	\N	3929	80216	\N	55.830822722973103	Московская область, городской округ Балашиха, Свердлова, 43	Россия, Московская область, Балашиха, улица Свердлова, 43	0101000020E61000009F3D97A949FC4240DFE1766858EA4B40
57655	1	10	\N	3929	80466	\N	55.759811904259799	Московская область, городской округ Балашиха, микрорайон Заря, Садовая, 10	Россия, Московская область, Балашиха, микрорайон Салтыковка, Садовая улица, 10	0101000020E6100000A6F27684D3F64240DE8D058541E14B40
57645	1	10	\N	3929	15378	\N	55.764445000000002	мкр. Салтыковка, Разинское шоссе, д. 27А	Россия, Московская область, Балашиха, микрорайон Салтыковка, Разинское шоссе, 31	0101000020E61000005D6C5A2904F642409D4B7155D9E14B40
57614	1	10	\N	3929	80140	\N	55.791500999999997	Московская область, городской округ Балашиха, Разина, 5	Россия, Московская область, Балашиха, улица Разина, 5	0101000020E6100000C8B60C384BF742402AE09EE74FE54B40
60093	1	10	794	6955	80768	\N	55.602505000000001	Московская область, Шатурский район, пос. Пустоши, ул. Школьная, д.1		0101000020E610000002BC051214F94340975643E21ECD4B40
57647	1	10	\N	3929	15945	\N	55.750686999999999	Московская область, городской округ Балашиха, микрорайон Салтыковка, Носовихинское шоссе, 230	Россия, Московская область, Балашиха, микрорайон Салтыковка, Носовихинское шоссе, 230	0101000020E6100000B0C6D97404F642402444F98216E04B40
57642	1	10	\N	3929	71938	\N	55.768394586499603	Московская область, городской округ Балашиха, Новая, 6	Россия, Московская область, Балашиха, микрорайон Салтыковка, Новая улица, 6	0101000020E61000007381CB63CDF6424078B471C45AE24B40
57632	1	10	\N	3929	80415	\N	55.807672835427702	Московская область, городской округ Балашиха, Московский проезд, 9	Россия, Московская область, Балашиха, Пушкинская улица, 16	0101000020E6100000F8C43A55BEFD42405D6E30D461E74B40
57646	1	10	\N	3929	80431	\N	55.756360999999998	Московская область, городской округ Балашиха, микрорайон Салтыковка, Московская, 18		0101000020E6100000C216BB7D56F54240247CEF6FD0E04B40
94470	1	10	\N	3929	68803	\N	55.742058	Московская область, городской округ Балашиха, микрорайон Салтыковка, Мирской проезд, 12	Россия, Московская область, Балашиха, Мирской проезд, 12	0101000020E6100000438EAD6708F142401ADEACC1FBDE4B40
57618	1	10	\N	3929	68803	\N	55.742046017362497	Московская область, городской округ Балашиха, микрорайон Салтыковка, Мирской проезд, 8		0101000020E610000071033E3F8CF042405610035DFBDE4B40
58067	1	10	\N	3929	80971	\N	55.743997385100201	Московская область, городской округ Железнодорожный, Лесопарковая ул, 19	Россия, Московская область, Балашиха, микрорайон Салтыковка, Лесопарковая улица	0101000020E6100000A835CD3B4EF742403BA92F4B3BDF4B40
57628	1	10	\N	3929	80224	\N	55.822043000000001	Московская область, городской округ Балашиха, Кудаковского, 7		0101000020E6100000C2C2499A3FFC4240EF737CB438E94B40
57627	1	10	\N	3929	80224	\N	55.822104000000003	Московская область, городской округ Балашиха, Кудаковского, 1		0101000020E6100000E60819C8B3FB424095F430B43AE94B40
56969	1	10	\N	3929	80499	\N	55.800045198774001	Московская область, городской округ Балашиха, Крупской, 16	Россия, Московская область, Балашиха, улица Крупской, 14	0101000020E6100000E010AAD4ECF74240062AE3DF67E64B40
57631	1	10	\N	3929	79845	\N	55.816324598928801	Московская область, городской округ Балашиха, Крупешина, 9	Россия, Московская область, Балашиха, Спортивная улица, 9	0101000020E61000001764CBF275FB42401FF46C567DE84B40
57619	1	10	\N	3929	72244	\N	55.748251660599401	Московская область, городской округ Балашиха, Зеленая, 18	Россия, Московская область, Балашиха, микрорайон Салтыковка, Зеленая улица, 18	0101000020E610000031D3F6AFACF842405395B6B8C6DF4B40
57630	1	10	\N	3929	71933	\N	55.814388003392502	Московская область, городской округ Балашиха, Заречная, 3	Россия, Московская область, Балашиха, Заречная улица, 3	0101000020E6100000B39943520BFB42409F20B1DD3DE84B40
57656	1	10	\N	3929	79886	\N	55.827717753165402	Московская область, городской округ Балашиха, микрорайон Заря, Гагарина, 2	Россия, Московская область, Балашиха, микрорайон имени Гагарина	0101000020E610000017670C7382F44240BF27D6A9F2E94B40
57651	1	10	\N	3929	16186	\N	55.761882	Московская область, городской округ Балашиха, микрорайон Никольско-Архангельский, Вишняковское шоссе, 9	Россия, Московская область, Балашиха, микрорайон Никольско-Архангельский, Вишняковское шоссе, 9	0101000020E610000051D9B0A6B2F242409EB4705985E14B40
57633	1	10	\N	3929	80426	\N	55.802047000000002	Московская область, городской округ Балашиха, Белякова, 10		0101000020E610000043C70E2A71FD42406E6DE179A9E64B40
57654	1	10	\N	3929	80866	\N	55.820855000000002	Московская область, городской округ Балашиха, микрорайон Янтарный, Акуловский проезд, 1		0101000020E61000000ABFD4CF9BF0424009E1D1C611E94B40
57650	1	10	\N	3929	80436	\N	55.770760000000003	Московская область, городской округ Балашиха, микрорайон Никольско-Архангельский, 9-я линия, 60		0101000020E610000039252026E1F2424051888043A8E24B40
57663	1	10	\N	3929	79896	\N	55.832107494536999	Московская область, городской округ Балашиха, 40 лет Победы, 23	Россия, Московская область, Балашиха, улица 40 лет Победы, 25	0101000020E61000000EBBEF181EFD4240E7E26F7B82EA4B40
59418	1	10	\N	61951	80706	\N	56.169788241627501	Московская область, Пушкинский муниципальный район, городское поселение Ашукино, ул. Кольцова, 11	Россия, Московская область, Пушкинский район, поселок Ашукино	0101000020E6100000DA91EA3BBFF842406AA0F99CBB154C40
58881	1	10	\N	61944	80608	\N	55.549995000000003	Московская область, Наро-Фоминский район, г.Апрелевка, Февральская, 65		0101000020E6100000F209D9791B8B424055FB743C66C64B40
58883	1	10	\N	61944	80631	\N	55.545788000000002	Московская область, Наро-Фоминский район, г.Апрелевка, Ленина, 9		0101000020E6100000925ED4EE578942404E469561DCC54B40
60018	1	10	490	62034	\N	\N	56.050379999999997	Московская область, городской округ Черноголовка, клуб  д. Ботово	Россия, Московская область, городской округ Черноголовка, деревня Ботово	0101000020E6100000EAB303AE2B364340AD2F12DA72064C40
59781	1	10	1692	61962	\N	\N	54.894619906754301	Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, п. Мирный, помещение Дома культуры	Россия, Московская область, городской округ Серпухов, поселок Мирный	0101000020E610000020B41EBE4CBC42407C2C7DE882724B40
94602	1	10	89	2295	\N	\N	55.413043999999999	142133, Московская область, Подольский район, п. Кузнечики, Молодежном центре "Максимум" (правая часть здания) д.8		0101000020E6100000E54350357ABD42408EE733A0DEB44B40
59347	1	10	89	2295	\N	\N	55.413043999999999	"п. Кузнечики, здание Молодежного центра ""Максимум"", 8"	Россия, Московская область, городской округ Подольск, поселок Кузнечики	0101000020E6100000E54350357ABD42408EE733A0DEB44B40
58540	1	10	1767	25140	81121	\N	55.594815060785102	ул. Связистов, д. 8 , помещение ДЮСШ	Россия, Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск, Краснознаменная улица	0101000020E6100000DAC69FA86C864240CA15DEE522CC4B40
58533	1	10	1767	25140	71893	\N	55.601937966396697	Московская область, городской округ Краснознаменск, Генерала Шлыкова, 10	Россия, Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск	0101000020E61000007C444C89248442401D1CEC4D0CCD4B40
58354	1	10	1433	18301	\N	\N	55.138216999999997	Московская область, Коломенский  район, поселок Радужный, Здание средней школы	Россия, Московская область, городской округ Коломна, поселок Радужный	0101000020E6100000B1E07EC0035D434028603B18B1914B40
58353	1	10	1433	18301	\N	\N	55.138216999999997	"Московская область, Коломенский  район, поселок Радужный, Здание КТЦ ""Радуга"""	Россия, Московская область, городской округ Коломна, поселок Радужный	0101000020E6100000B1E07EC0035D434028603B18B1914B40
59360	1	10	7481	59553	\N	\N	55.342868433258403	"п. МИС, здание МУК СДК ""Надежда"", 25"		0101000020E61000007DEA58A5F4C64240276C3F19E3AB4B40
57962	1	10	344	59514	71812	\N	55.478715939818699	Московская область, городской округ Домодедово, с.Ям, Связистов, 5а		0101000020E6100000EB025E66D8E042403509DE9046BD4B40
57944	1	10	344	30238	\N	\N	55.495659000000003	"Московская область, городской округ Домодедово, д.Чурилково, ДК ""Пахра"""		0101000020E6100000D636C5E3A2EA4240EA7B0DC171BF4B40
59105	1	10	344	22988	\N	\N	55.356645999999998	п. Сосны, 30		0101000020E6100000115663096BF14240E61F7D93A6AD4B40
57955	1	10	344	30786	\N	\N	55.376800000000003	"Московская область, городской округ Домодедово, пос.санатория ""Подмосковье"", СДК ""Подмосковье"""	Россия, Московская область, городской округ Домодедово, поселок Санатория Подмосковье	0101000020E6100000FA7E6ABC74E1424000917EFB3AB04B40
57958	1	10	344	30955	71997	\N	55.273744000000001	Московская область, городской округ Домодедово, с.Растуново, Заря, 33		0101000020E6100000591822A7AFEB4240F5BC1B0B0AA34B40
57942	1	10	344	30144	\N	\N	55.192270999999998	"Московская область, городской округ Домодедово, пос.Повадино, Актовый зал конторы племзавода ""Повадино"""		0101000020E610000036CAFACDC4DE42400F7C0C569C984B40
57960	1	10	344	31058	\N	\N	55.485881999999997	Московская область, городской округ Домодедово, д.Павловское, Павловский СДК		0101000020E6100000A52DAEF199DC424087DBA16131BE4B40
57954	1	10	344	60233	\N	\N	55.324325000000002	"Московская область, городской округ Домодедово, пос.ОПК БОР, Клуб ОПК ""Бор"""		0101000020E6100000F50F221972EE42403A234A7B83A94B40
57947	1	10	344	30363	\N	\N	55.382094000000002	Московская область, городской округ Домодедово, с.Лямцино, Лямцинская сельская библиотека		0101000020E610000003CE52B29CF04240B9FFC874E8B04B40
57950	1	10	344	30560	\N	\N	55.298265999999998	Московская область, городской округ Домодедово, с.Лобаново, Лобановская основная общеобразовательная школа		0101000020E6100000FBCA83F414F942401EC18D942DA64B40
57945	1	10	344	30282	\N	\N	55.345514000000001	"Московская область, городской округ Домодедово, с.Красный Путь, СДК ""Русь"""	Россия, Московская область, городской округ Домодедово, село Красный Путь	0101000020E61000000875914259F64240B32781CD39AC4B40
57951	1	10	344	30605	\N	\N	55.241801000000002	Московская область, городской округ Домодедово, с.Ильинское, Ильинская средняя общеобразовательная школа, 9	Россия, Московская область, городской округ Домодедово, село Ильинское	0101000020E6100000E9995E622CFB4240EF91CD55F39E4B40
59087	1	10	344	49289	\N	\N	55.352654000000001	д. Ивановка, 43		0101000020E610000017D86322A5D94240DC662AC423AD4B40
57952	1	10	344	30629	\N	\N	55.447901999999999	Московская область, городской округ Домодедово, д.Заболотье, Заболотьевский СДК		0101000020E61000007E54C37E4FD6424010E84CDA54B94B40
57946	1	10	344	59562	\N	\N	55.340016534738602	"Московская область, городской округ Домодедово, д.Житнево, ЦФКС ""Горизонт"""	Россия, Московская область, городской округ Домодедово, деревня Житнево	0101000020E6100000A988D349B6F44240C28A53AD85AB4B40
57959	1	10	344	30987	\N	\N	55.182921999999998	Московская область, городской округ Домодедово, с.Добрыниха, Добрыниховский СДК		0101000020E61000009B1DA9BEF3D9424005DCF3FC69974B40
57943	1	10	344	30191	\N	\N	55.229322000000003	Московская область, городской округ Домодедово, д.Голубино, Голубинский ДК		0101000020E6100000C158DFC0E4E642406D205D6C5A9D4B40
57949	1	10	344	30466	\N	\N	55.272399999999998	"Московская область, городской округ Домодедово, д.Гальчино, СДК ""Барыбино"""		0101000020E610000001F8A75489F4424017B7D100DEA24B40
57941	1	10	344	30104	\N	\N	55.191752000000001	Московская область, городской округ Домодедово, с.Вельяминово, Повадинский сельский дом культуры		0101000020E6100000176536C824EF4240A7785C548B984B40
57657	1	10	915	7280	74181	\N	55.760565	Московская область, городской округ Балашиха, микрорайон Заря, Ленина, 6		0101000020E6100000BDDF68C70D0B4340BABDA4315AE14B40
57403	1	10	915	7280	72229	\N	55.757035000000002	дер. Черное, ул. Агрогородок, д. 1А		0101000020E6100000206118B0E4084340B476DB85E6E04B40
57659	1	10	915	16550	71803	\N	55.754814326793301	Московская область, городской округ Балашиха, дер. Федурново, Авиарембаза, 7	Россия, Московская область, городской округ Балашиха, деревня Федурново	0101000020E610000018B49080D10543400F48C2BE9DE04B40
57660	1	10	915	16586	72248	\N	55.729883000000001	Московская область, городской округ Балашиха, дер. Соболиха, Новослободская, 15		0101000020E6100000F4FBFECD8B05434004745FCE6CDD4B40
57661	1	10	915	15718	80784	\N	55.708060000000003	Московская область, городской округ Балашиха, село Новый Милет, Парковая, 6		0101000020E6100000B2D991EA3B0743408ACDC7B5A1DA4B40
94576	1	10	930	60260	\N	\N	55.326159297079002	поселок Молодежный МОУ СОШ пос.Молодежный		0101000020E610000018213CDA38644240E525FF93BFA94B40
60179	1	10	78	61919	80034	\N	55.839733161532003	Московская область, Щелковский муниципальный район, городское поселение Монино, Баранова, 1 А (Средняя школа №1)		0101000020E61000000DE36E10AD1743409D2FF65E7CEB4B40
60187	1	10	78	11406	\N	\N	55.919977000000003	"Московская область, Щелковский муниципальный район, поселок Юность, Помещение МУ СПА ФСК ""Биолог"", 12"	Россия, Московская область, Щелковский район, поселок Юность	0101000020E6100000E02BBAF59A1043403E096CCEC1F54B40
60161	1	10	78	271	80579	\N	55.903970315623603	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Супруна, 2 (ДОЦ ""Лесная сказка"")"	Россия, Московская область, Щелковский район, Щелково, микрорайон Щелково-3, улица Супруна, 2	0101000020E61000003DF20703CF0743405648F949B5F34B40
60170	1	10	78	271	79	\N	55.932721999999998	Московская область, Щелковский муниципальный район, городское поселение Загорянский, Свердлова, 10 (Средняя школа №2)	Россия, Московская область, Щелковский район, Щелково, улица Свердлова, 10	0101000020E61000007522C15433FD42403E213B6F63F74B40
59313	1	10	78	271	79	\N	55.934755000000003	Московская область, городской округ Подольск, ул. Свердлова, д. 38	Россия, Московская область, Щелковский район, Щелково, улица Свердлова, 38	0101000020E61000001990BDDEFDFD4240E162450DA6F74B40
57625	1	10	78	271	79	\N	55.935929000000002	ул. Свердлова, д.49	Россия, Московская область, Щелковский район, Щелково, улица Свердлова, 51	0101000020E610000081CD397826FE424062307F85CCF74B40
60125	1	10	78	271	2331	\N	55.943773999999998	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Неделина, 8 (Средняя школа №10)	Россия, Московская область, Щелковский район, Щелково, улица Неделина, 8	0101000020E6100000D9226937FAFC424055682096CDF84B40
57744	1	10	78	271	2317	\N	55.942191000000001	Московская область, Воскресенский муниципальный район, городское поселение Белоозерский, 60 лет Октября, 8	Россия, Московская область, Щелковский район, Щелково, проспект 60 лет Октября, 8	0101000020E6100000DDB3AED172FC4240F3CAF5B699F84B40
60205	1	10	78	271	2574	\N	55.922564999999999	Московская область, Щелковский муниципальный район, городское поселение Фряново, площадь Ленина, 8 (Помещение дома культуры)	Россия, Московская область, Щелковский район, Щелково, площадь Ленина, 8	0101000020E61000009B5434D6FEFE424095B7239C16F64B40
60127	1	10	78	271	80532	\N	55.937829999999998	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Школьная, 1 (Средняя школа №1)	Россия, Московская область, Щелковский район, Щелково, Школьная улица, 1	0101000020E6100000917C259012FF4240959A3DD00AF84B40
60144	1	10	78	271	80559	\N	55.922745521868698	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Центральная, 55 (Средняя школа №8)		0101000020E61000005DA5BBEB6CFC4240E5417A8A1CF64B40
60135	1	10	78	271	2485	\N	55.938051999999999	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Фряновское шоссе, 70 (бывший фельдшерский пункт)	Россия, Московская область, Щелковский район, Щелково, Фряновское шоссе, 70	0101000020E610000008E3A7716F04434044F9821612F84B40
94540	1	10	78	271	79871	\N	55.936388000000001	Ул. Фестивальня, д.2, школа № 2		0101000020E610000026FBE769C0FE4240F52EDE8FDBF74B40
94678	1	10	78	271	81069	\N	55.911819999999999	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Фабричная, 2	Россия, Московская область, Щелковский район, Щелково, Фабричная улица, 1	0101000020E6100000EA3C2AFEEF0043405BEB8B84B6F44B40
60160	1	10	78	271	81028	\N	55.942301999999998	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Урожайная, 37		0101000020E6100000EFE4D3635BFA42404A7A185A9DF84B40
60132	1	10	78	271	80541	\N	55.929718369309199	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Талсинская, 10 (Щёлковский учебный центр)	Россия, Московская область, Щелковский район, Щелково, Талсинская улица, 10	0101000020E610000084BA48A12CFE42405340DAFF00F74B40
60128	1	10	78	271	80522	\N	55.926302	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Талсинская, 60 (ЗАО ""Щёлковская ШТФ"")"		0101000020E6100000109546CCECFD4240151C5E1091F64B40
60167	1	10	78	271	81062	\N	55.904018999999998	Щелково, Супруна, 2		0101000020E6100000541A31B3CF07434037FB03E5B6F34B40
94679	1	10	78	271	74126	\N	55.903008999999997	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Супруна, Дом офицеров (1-й этаж)		0101000020E610000079E9263108084340307F85CC95F34B40
94680	1	10	78	271	79813	\N	55.903685156168002	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Супруна, Дом офицеров (2-й этаж)	Россия, Московская область, Щелковский район, Щелково, микрорайон Щелково-3, улица Супруна, 2	0101000020E61000003465A71FD4074340617138F3ABF34B40
60159	1	10	78	271	79813	\N	55.903799672239302	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Супруна, Дом офицеров	Россия, Московская область, Щелковский район, Щелково, микрорайон Щелково-3, улица Супруна, 2	0101000020E61000004CC11A67D3074340F90FE9B7AFF34B40
94672	1	10	957	7945	67038	\N	56.152169000000001	Шаховской район, с. Раменье, ул. Центральная, дом 2Б/                                                                                                                                               ул. Колхозная, дом 1А		0101000020E610000003D19332A9BF4140863B17467A134C40
60148	1	10	78	271	2502	\N	55.918135999999997	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Пролетарский проспект, 6 А (ЦТР и ГУ ""Романтик"" )"	Россия, Московская область, Щелковский район, Щелково, Пролетарский проспект, 6	0101000020E6100000E068C70DBFFF4240DFA3FE7A85F54B40
60137	1	10	78	271	2502	\N	55.927069000000003	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Пролетарский проспект, 14 (Клуб ""Ровесник"")"		0101000020E610000011AAD4EC8100434056116E32AAF64B40
60131	1	10	78	271	80032	\N	55.932425000000002	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Полевая, 12 Б (Помещение ЖЭУ-4)	Россия, Московская область, Щелковский район, Щелково, Полевая улица, 12б	0101000020E6100000CD9541B5C1FF4240857CD0B359F74B40
60143	1	10	78	271	80548	\N	55.922657417902997	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Пионерская, 19 (НОУ ""Колледж экономики и прав"")"	Россия, Московская область, Щелковский район, Щелково, Пионерская улица, 19	0101000020E610000047C9AB730CFC42407636E49F19F64B40
60147	1	10	78	271	80538	\N	55.922984	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Парковая, 18 (Щёлковский лицей)		0101000020E6100000B3EF8AE07FFD42409A5DF75624F64B40
60126	1	10	78	271	80113	\N	55.944031000000003	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Неделина, 18 А (ГДК ""Спутник"")"		0101000020E6100000D27135B22BFD424081B4FF01D6F84B40
60139	1	10	78	271	79810	\N	55.922071559067703	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Малопролетарская, ГПТУ-38	Россия, Московская область, Щелковский район, Щелково, Малопролетарская улица	0101000020E6100000404CC2853C00434056478E7406F64B40
60130	1	10	78	271	80530	\N	55.930427019045297	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Комсомольская, 3 А (ЗАО ""Новые Технологии"")"	Россия, Московская область, Щелковский район, Щелково, Комсомольская улица, 3а	0101000020E6100000AB984A3FE1FE42405F28603B18F74B40
60129	1	10	78	271	80537	\N	55.930250999999998	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Комсомольская, 5 А (Средняя школа №3)	Россия, Московская область, Щелковский район, Щелково, Комсомольская улица, 5а	0101000020E6100000CD22145B41FF42402009FB7612F74B40
60162	1	10	78	271	74199	\N	55.902728236809303	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Институтская, (Средняя школа №11)	Россия, Московская область, Щелковский район, Щелково, микрорайон Щелково-3, Институтская улица	0101000020E6100000C1E44691B50643407D9752978CF34B40
60138	1	10	78	271	81030	\N	55.924028	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Заречная, 82 (Республиканский политех.колледж		0101000020E61000000A82C7B7770143404D4BAC8C46F64B40
60164	1	10	78	271	80549	\N	55.904251000000002	"Московская область, Щелковский муниципальный район, городское поселение Щёлково, Гагарина, 1 А (ДОЦ ""Лесная сказка"")"		0101000020E6100000E90B21E7FD0743400A302C7FBEF34B40
60163	1	10	78	271	74111	\N	55.906517000000001	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Гагарина, (Средняя школа №12)		0101000020E6100000349E08E23C0843404F22C2BF08F44B40
60166	1	10	78	271	80553	\N	55.884216000000002	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Беляева, 14 (Средняя школа №13)		0101000020E6100000BF1072DEFF094340CB4C69FD2DF14B40
60210	1	10	78	61943	80577	\N	56.130116000000001	Московская область, Щелковский муниципальный район, городское поселение Фряново, Механизаторов, 12 (Средняя школа №1)		0101000020E6100000834F73F222374340DA571EA4A7104C40
60209	1	10	78	61941	80565	\N	56.130116000000001	Московская область, Щелковский муниципальный район, городское поселение Фряново, Текстильщиков, 3	Россия, Московская область, Щелковский район, поселок городского типа Фряново	0101000020E6100000834F73F222374340DA571EA4A7104C40
60207	1	10	78	61941	80583	\N	56.137125570521	Московская область, Щелковский муниципальный район, городское поселение Фряново, Первомайская, 12 (Средняя школа №2)	Россия, Московская область, Щелковский район, поселок городского типа Фряново	0101000020E6100000D4B9A2941038434035B742588D114C40
60202	1	10	78	12116	\N	\N	55.989984999999997	Московская область, Щелковский муниципальный район, село Трубино, Сельский дом культуры села Трубино		0101000020E6100000DB17D00B77104340E94317D4B7FE4B40
60155	1	10	78	9861	\N	\N	55.896593915798903	Московская область, Щелковский муниципальный район, деревня Серково, Средняя школа деревни Серково	Россия, Московская область, Щелковский район, деревня Серково	0101000020E6100000209A79724DFB424019E59997C3F24B40
60191	1	10	78	61937	80359	\N	55.901783000000002	Московская область, Щелковский муниципальный район, городское поселение Свердловский, Набережная, 5 (Средняя школа п. Свердловский)		0101000020E610000023861DC6A41143405D8B16A06DF34B40
60208	1	10	78	94	3500	\N	55.927024000000003	Московская область, Щелковский муниципальный район, городское поселение Фряново, Текстильщиков, 4	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, улица Текстильщиков, 4	0101000020E61000009CF86A4771F84240B64DF1B8A8F64B40
60190	1	10	78	9552	3267	\N	55.897579	"Московская область, Щелковский муниципальный район, городское поселение Свердловский, Дзержинского, 1 (КСК ""Городище"")"	Россия, Московская область, Щелковский район, поселок городского типа Свердловский, улица Дзержинского, 1	0101000020E6100000624A24D1CB104340C74961DEE3F24B40
60156	1	10	78	9552	2708	\N	55.905214999999998	Московская область, Щелковский муниципальный район, городское поселение Щёлково, Советская, 1 А (Вспомогательная школа №5)	Россия, Московская область, Щелковский район, поселок городского типа Свердловский, Советская улица, 1	0101000020E6100000E71890BDDE114340A06CCA15DEF34B40
60201	1	10	78	12068	\N	\N	56.089050999999998	Московская область, Щелковский муниципальный район, село Петровское, Помещение библиотеки №17 села Петровское	Россия, Московская область, Щелковский район, село Петровское	0101000020E6100000FD153257061D43408A56EE05660B4C40
60196	1	10	78	11823	\N	\N	56.010407000000001	"Московская область, Щелковский муниципальный район, деревня 1-я Алексеевка, ООО АРСУ ""Дом отдыха Алексеевка"", здание столовой"		0101000020E6100000566133C0051D434022533E0455014C40
60199	1	10	78	11944	\N	\N	56.0625142495579	Московская область, Щелковский муниципальный район, деревня Огуднево, Сельский дом культуры деревни Огуднево	Россия, Московская область, Щелковский район, деревня Огуднево	0101000020E6100000AF230ED94022434065C5707500084C40
60174	1	10	78	10819	\N	\N	55.887068999999997	Московская область, Щелковский муниципальный район, деревня Оболдино, Оболдинский СДК Загорянского культурно-досугового центра, 60		0101000020E610000019E42EC214F74240D0251C7A8BF14B40
59957	1	10	78	31977	8054	\N	55.965435999999997	Московская область, городской округ Фрязино, Окружной проезд, д. 2А	Россия, Московская область, Щелковский район, деревня Новофрязино, Окружной проезд, 2а	0101000020E6100000126BF129000A4340C630276893FB4B40
60182	1	10	78	11152	\N	\N	55.845435109529802	Московская область, Щелковский муниципальный район, деревня Никифорово, Сельский дом культуры деревни Никифорово	Россия, Московская область, Щелковский район, деревня Никифорово	0101000020E610000021205F42050B434067F2CD3637EC4B40
60176	1	10	78	61873	79824	\N	55.844369412476702	Московская область, Щелковский муниципальный район, городское поселение Монино, 1-я Дачная, 2 (Средняя школа №2)		0101000020E610000000581D39D2194340CC608C4814EC4B40
60204	1	10	78	12204	\N	\N	55.989758000000002	Московская область, Щелковский муниципальный район, деревня Мишнево, Сельский дом культуры деревни Мишнево		0101000020E61000006956B60F79194340297AE063B0FE4B40
60188	1	10	78	11461	\N	\N	55.951618000000003	Московская область, Щелковский муниципальный район, деревня Мизиново, Сельский дом культуры деревни Мизиново		0101000020E6100000F17EDC7EF91A434079245E9ECEF94B40
60189	1	10	78	11520	\N	\N	55.939126000000002	Московская область, Щелковский муниципальный район, поселок Медное Власово, Административное здание детской психиатрической больницы №11		0101000020E6100000A6B6D4415E1943406269E04735F84B40
60181	1	10	78	11138	80592	\N	55.867925	Московская область, Щелковский муниципальный район, сельское поселение Медвежье-Озёрское, Юбилейная, 5 (ДК МУ Медвежье-Озёрская ЦКС)		0101000020E6100000ABCDFFAB8EFE4240BE30992A18EF4B40
59290	1	10	78	11138	4586	\N	55.870545999999997	Московская область, городской округ Подольск, ул. Садовая, д. 2	Россия, Московская область, Щелковский район, деревня Медвежьи Озера, Садовая улица, 2	0101000020E6100000A6B915C26AFE4240F1D4230D6EEF4B40
60203	1	10	78	12201	\N	\N	56.013919999999999	Московская область, Щелковский муниципальный район, поселок Литвиново, Сельский дом культуры поселка Литвиново	Россия, Московская область, Щелковский район, деревня Литвиново	0101000020E6100000DD442DCDAD10434052616C21C8014C40
60168	1	10	78	10517	\N	\N	55.935471	"Московская область, Щелковский муниципальный район, посёлок Краснознаменский, КСК ""Мальцево"""	Россия, Московская область, Щелковский район, поселок Краснознаменский	0101000020E6100000BB9D7DE541F842409FAD8383BDF74B40
60193	1	10	78	11677	\N	\N	55.873693000000003	"Московская область, Щелковский муниципальный район, деревня Корпуса, Помещение библиотеки санатория ""Монино"""		0101000020E61000003C4D66BCAD1C434040DF162CD5EF4B40
60169	1	10	78	60271	80900	\N	55.932192999999998	Московская область, Щелковский муниципальный район, городское поселение Загорянский, Школьная, 27 (Средняя школа №1)		0101000020E6100000800C1D3BA8F44240B247A81952F74B40
60171	1	10	78	60271	80285	\N	55.907657	Московская область, Щелковский муниципальный район, городское поселение Загорянский, Сергея Лазо, 7 ( культурно-досуговый центр)		0101000020E610000022A81ABD1AF84240247EC51A2EF44B40
94620	1	10	78	60271	80306	\N	55.919004000000001	ул. Комсомольская, д. 17		0101000020E6100000D3A23EC91DF6424054724EECA1F54B40
94619	1	10	78	60271	80306	\N	55.919251000000003	ул. Комсомольская, д. 16		0101000020E61000003ACAC16C02F642405CE84A04AAF54B40
60173	1	10	78	60271	74218	\N	55.908561488535099	Московская область, Щелковский муниципальный район, городское поселение Загорянский, Димитрова, 47 (Помещение домоуправления)	Россия, Московская область, Щелковский район, поселок городского типа Загорянский	0101000020E6100000105839B4C8F64240E5B512BA4BF44B40
60108	1	10	794	7669	\N	\N	55.288105999999999	Московская область, Шатурский район, с. Пышлицы, д.55А		0101000020E6100000C251F2EA1C09444004E44BA8E0A44B40
94681	1	10	78	94	3025	\N	55.907657	Московская область, Щелковский муниципальный район, городское поселение Загорянский, Сергея Лазо, 7	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, улица Сергея Лазо, 7	0101000020E610000022A81ABD1AF84240247EC51A2EF44B40
60175	1	10	78	94	15	\N	55.922187000000001	Московская область, Щелковский муниципальный район, городское поселение Монино, Комсомольская, 10 (Средняя школа №3)	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, Комсомольская улица, 10	0101000020E61000006F62484E26F64240EFE53E390AF64B40
59946	1	10	78	94	15	\N	55.918695999999997	Московская область, городской округ Фрязино, ул. Комсомольская, д. 19, стр.3	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, Комсомольская улица, 19	0101000020E61000007366BB421FF64240A67B9DD497F54B40
60172	1	10	78	94	80860	\N	55.915962	Московская область, Щелковский муниципальный район, городское поселение Загорянский, Димитрова, 31 (Детская музыкальная школа)	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, Пионерская улица	0101000020E61000008ECA4DD4D2F642407B30293E3EF54B40
60212	1	10	78	12596	\N	\N	56.113356000000003	Московская область, Щелковский муниципальный район, деревня Ерёмино, Сельский дом культуры деревни Ерёмино		0101000020E61000009DF7FF71C240434017670C73820E4C40
60200	1	10	78	12018	\N	\N	56.059533999999999	Московская область, Щелковский муниципальный район, село Душоново, Сельский дом культуры села Душоново		0101000020E6100000473CD9CD8C264340028063CF9E074C40
60180	1	10	78	11072	\N	\N	55.854739000000002	Московская область, Щелковский муниципальный район, деревня Долгое Лёдово, Московский областной с/х колледж		0101000020E61000001D91EF52EAFC4240D1CE691668ED4B40
60211	1	10	78	12584	\N	\N	56.131996999999998	Московская область, Щелковский муниципальный район, деревня Головино, Сельский дом культуры деревни Головино		0101000020E6100000F46C567DAE344340C6151747E5104C40
94682	1	10	78	49658	\N	\N	56.053210999999997	Московская область, Щелковский муниципальный район, Деревня Воря-Богородское, Административное здание дома отдыха "Щелково"		0101000020E61000004E452A8C2D144340CB64389ECF064C40
60213	1	10	78	12679	\N	\N	56.183959000000002	Московская область, Щелковский муниципальный район, деревня Булаково, Сельский дом культуры деревни Булаково		0101000020E61000005FB7088CF52F43400667F0F78B174C40
60195	1	10	78	11771	\N	\N	56.013221000000001	Московская область, Щелковский муниципальный район, деревня Богослово, Сельский дом культуры деревни Богослово		0101000020E6100000D9B5BDDD920843406A4FC939B1014C40
60186	1	10	78	11316	\N	\N	55.917389999999997	Московская область, Щелковский муниципальный район, поселок Биокомбината, Средняя школа п.Биокомбината	Россия, Московская область, Щелковский район, поселок Биокомбината	0101000020E6100000D7F84CF6CF0D4340B6D617096DF54B40
60185	1	10	78	11316	\N	\N	55.917389999999997	Московская область, Щелковский муниципальный район, поселок Биокомбината, Дом культуры п.Биокомбината	Россия, Московская область, Щелковский район, поселок Биокомбината	0101000020E6100000D7F84CF6CF0D4340B6D617096DF54B40
60184	1	10	78	62012	80873	\N	55.909549336263403	Московская область, Щелковский муниципальный район, сельское поселение Анискинское, Центральная, 19 ( Сельский ДК села Анискино)	Россия, Московская область, Щелковский район, село Анискино, Центральная улица	0101000020E61000005725917D900D4340048E041A6CF44B40
57472	1	10	957	49227	\N	\N	56.059925999999997	село Шестаково, 7		0101000020E61000005663096B63C241400D17B9A7AB074C40
94670	1	10	957	60263	80850	\N	56.025234903847903	Московская область, Шаховской муниципальный район, пос. Шаховская, ул. Лесная, дом 23		0101000020E6100000FF243E7782C3414077DB85E63A034C40
94667	1	10	957	60263	74176	\N	56.03105	Московская область, Шаховской муниципальный район, пос. Шаховская, ул. 1-ая Советская, дом 21		0101000020E6100000A0FF1EBC76C1414039454772F9034C40
94668	1	10	957	60263	79811	\N	56.033017000000001	Московская область, Шаховской муниципальный район, пос. Шаховская, 1-ый Советский переулок, дом 11		0101000020E6100000034015376EC14140249BABE639044C40
94671	1	10	957	7863	80846	\N	56.024293671873302	Московская область, Шаховской муниципальный район, пос. Шаховская, ул. Южная, дом 32		0101000020E610000082700514EAC1414098BED7101C034C40
94666	1	10	957	7863	16896	\N	56.033383999999998	Московская область, Шаховской муниципальный район, пос. Шаховская, ул. Комсомольская, дом 10Б		0101000020E6100000A85489B2B7C04140D61A4AED45044C40
94669	1	10	957	7863	2149	\N	56.0311348688222	Московская область, Шаховской муниципальный район, пос. Шаховская, ул. 1-ая Советская,  дом 61	Россия, Московская область, Шаховской район, поселок городского типа Шаховская, 1-я Советская улица	0101000020E6100000A30392B06FC1414067614F3BFC034C40
94674	1	10	957	8163	71926	\N	56.003548000000002	Шаховской р-н, д. Степаньково, ул. Промышленная, д. 36/                                                                                                                               микрорайон, дом 18А		0101000020E6100000E5B33C0FEED24140ADFBC74274004C40
94675	1	10	957	8303	71929	\N	55.896816999999999	Шаховской район, с. Середа, ул. Школьная, дом 13/                                                                                                                                                     ул. Льнозаводская, дом 12		0101000020E6100000A4FACE2F4AC0414098BF42E6CAF24B40
53182	1	9	\N	3727	39075	\N	52.614983000000002	Липецкая область, город Липецк, ул. Им. Семашко, 5		0101000020E6100000700B96EA02CC4340494C50C3B74E4A40
60116	1	10	957	8009	\N	\N	56.112729000000002	Московская область, Шаховской муниципальный район, деревня Новоникольское, 93	Россия, Московская область, Шаховской район, деревня Новоникольское	0101000020E6100000A20BEA5BE6C84140C82764E76D0E4C40
60120	1	10	957	8246	71858	\N	55.995381999999999	Московская область, Шаховской муниципальный район, деревня Муриково, Микрорайон, 19		0101000020E610000059A5F44C2FAF4140778368AD68FF4B40
60115	1	10	957	7991	71932	\N	56.221874999999997	Московская область, Шаховской муниципальный район, село Ивашково, Новая, 14		0101000020E6100000B4AED172A0AD414066666666661C4C40
94676	1	10	957	8317	80767	\N	55.872895	Шаховской район, дер. Дубранивка, ул. Школьная, дом 3/                                                                                                                                     ул. Школьная, дом 9		0101000020E6100000B262B83A00AC4140C4EBFA05BBEF4B40
94677	1	10	957	62018	80948	\N	56.001041000000001	Шаховской район, дер. Дор, микрорайон, дом 14/                                                                                                                                                           микрорайон, дом 13	Россия, Московская область, Шаховской район	0101000020E61000002C4833164DB94140427A8A1C22004C40
94673	1	10	957	8140	80763	\N	56.089649000000001	Шаховской район, с. Белая Колпь, ул. Центральная, д. 14/                                                                                                                                   ул. Центральная, дом 12		0101000020E61000006C223317B8D441403F8F519E790B4C40
60111	1	10	794	59537	\N	\N	55.255954000000003	"Московская область, Шатурский район, пос. санатория ""Озеро Белое"", д.8"		0101000020E61000002AA913D044FE4340E4A3C519C3A04B40
60110	1	10	794	7717	\N	\N	55.352398000000001	Московская область, Шатурский район, дер. Шеино, д.53		0101000020E6100000CE1B2785790B44408196AE601BAD4B40
60083	1	10	794	6454	\N	\N	55.564653	Московская область, Шатурский район, пос. Шатурторф, ул. Интернациональная, д.14	Россия, Московская область, Шатурский район, поселок Шатурторф	0101000020E6100000234C512E8DB543404D4BAC8C46C84B40
60084	1	10	794	6454	72180	\N	55.564653	Московская область, Шатурский район, пос. Шатурторф, ул. Интернациональная, д.24		0101000020E6100000234C512E8DB543404D4BAC8C46C84B40
58471	1	10	794	5601	6357	\N	55.563997000000001	"Московская область, городской округ Котельники, микрорайон ""Белая Дача"", 3"	Россия, Московская область, Шатурский район, Шатура, улица Дача Винтера, 3	0101000020E610000078B5DC9909C843406405BF0D31C84B40
60074	1	10	794	5601	1639	\N	55.578060000000001	Московская область, Шатурский район, г. Шатура, пр. Борзова, д.4/34	Россия, Московская область, Шатурский район, Шатура, проспект Маршала Борзова, 4/34	0101000020E6100000B3EBDE8AC4C243401990BDDEFDC94B40
60071	1	10	794	5601	1575	\N	55.576396000000003	Московская область, Шатурский район, г. Шатура, пр. Ильича, д.39/1	Россия, Московская область, Шатурский район, Шатура, проспект Ильича, 39/1	0101000020E61000003CBEBD6BD0C34340CAC51858C7C94B40
60067	1	10	794	5601	1530	\N	55.577531	Московская область, Шатурский район, г. Шатура, пл. Ленина, д.1	Россия, Московская область, Шатурский район, Шатура, площадь Ленина, 1	0101000020E6100000D7F9B7CB7EC543408DB62A89ECC94B40
60075	1	10	794	5601	79986	\N	55.581515000000003	Московская область, Шатурский район, г. Шатура, ул. Спортивная, д.3		0101000020E6100000321D3A3DEFC24340159161156FCA4B40
60073	1	10	794	5601	79986	\N	55.581546000000003	Московская область, Шатурский район, г. Шатура, ул. Спортивная, д.9А		0101000020E6100000A054FB743CC44340508F6D1970CA4B40
60079	1	10	794	5601	81027	\N	55.570981000000003	Московская область, Шатурский район, г. Шатура, ул. Новый тупик, в помещении общежития ПУ-66		0101000020E61000002A0307B474C1434096D1C8E715C94B40
60068	1	10	794	5601	1558	\N	55.580080000000002	Московская область, Шатурский район, г. Шатура, ул Московская, д.10	Россия, Московская область, Шатурский район, Шатура, Московская улица, 10	0101000020E61000001DC87A6AF5C543402788BA0F40CA4B40
60077	1	10	794	5601	1679	\N	55.573524999999997	Московская область, Шатурский район, г. Шатура, Конный проезд, д.4	Россия, Московская область, Шатурский район, Шатура, Конный проезд, 4	0101000020E6100000F52B9D0FCFC443401D38674469C94B40
60072	1	10	794	5601	80519	\N	55.577815999999999	Московская область, Шатурский район, г. Шатура, ул. Жарова, д.16		0101000020E610000098E0D40792C34340828DEBDFF5C94B40
60106	1	10	794	7586	80759	\N	55.287824000000001	Московская область, Шатурский район, с. Шарапово, ул. Центральная, д.9		0101000020E6100000BE4BA94BC6C543408080B56AD7A44B40
60092	1	10	794	62055	81011	\N	55.542743886126601	Московская область, Шатурский район, пос. Черусти, ул. Вокзальная, д.1		0101000020E610000097E2AAB2EF004440D40CA9A278C54B40
60091	1	10	794	6872	71852	\N	55.548197000000002	Московская область, Шатурский район, пос. Черусти, ул. Вокзальная, д.14		0101000020E61000008509A359D9004440F661BD512BC64B40
60096	1	10	794	59535	\N	\N	55.544442917723998	"Московская область, Шатурский район, ЦУС ""Мир"", д. 6А"	Россия, Московская область, Шатурский район, поселок Центральной усадьбы совхоза "Мир"	0101000020E61000003BC780ECF5D84340A0C4E74EB0C54B40
60099	1	10	794	7276	71832	\N	55.559852999999997	Московская область, Шатурский район, пос. Туголесский Бор, ул. Горького, д.11		0101000020E61000005471E316F3E54340A3C85A43A9C74B40
60102	1	10	794	7410	\N	\N	55.256745000000002	Московская область, Шатурский район, с. Середниково, д.265		0101000020E6100000E8120EBDC5D54340AD342905DDA04B40
60081	1	10	794	6376	\N	\N	55.709505	Московская область, Шатурский район, пос. Северная Грива, д.34		0101000020E61000002733DE567ACB43409BAC510FD1DA4B40
60112	1	10	794	7846	74094	\N	55.129261999999997	Московская область, Шатурский район, пос. Радовицкий, ул. Клубная, д.2		0101000020E610000076FD82DDB0E54340CA4E3FA88B904B40
60109	1	10	794	7669	\N	\N	55.288105999999999	Московская область, Шатурский район, с. Пышлицы, д.38		0101000020E6100000C251F2EA1C09444004E44BA8E0A44B40
60094	1	10	794	7012	81010	\N	55.593009000000002	Московская область, Шатурский район, с. Пустоша, ул. Парковая, д.2		0101000020E61000004EB51666A1034440E99D0AB8E7CB4B40
60101	1	10	794	7335	\N	\N	55.356594999999999	Московская область, Шатурский район, дер. Пестовская, д.69		0101000020E6100000444FCAA486EA43406475ABE7A4AD4B40
60098	1	10	794	7201	80744	\N	55.478147999999997	Московская область, Шатурский район, пос. Осаново-Дубовое, ул. Клубная, д.1		0101000020E6100000BF99982EC4D44340EB5223F433BD4B40
60082	1	10	794	6436	\N	\N	55.560687999999999	Московская область, Шатурский район, дер. Новосидориха, д.3		0101000020E610000049809A5AB6CE43403CA1D79FC4C74B40
60087	1	10	794	6609	71850	\N	55.718218	Московская область, Шатурский район, пос. Мишеронский, ул. Советская, д.13А		0101000020E610000066321CCF67DE434003B34291EEDB4B40
60086	1	10	794	6609	72182	\N	55.718654037679997	Московская область, Шатурский район, пос. Мишеронский, ул. Луначарского, д. 1	Россия, Московская область, Шатурский район, поселок городского типа Мишеронский	0101000020E61000002997C62FBCDE4340DE91B1DAFCDB4B40
60097	1	10	794	7122	\N	\N	55.521945000000002	Московская область, Шатурский район, дер. Лузгарино, д.39Б		0101000020E6100000132D793C2DDB4340C6A70018CFC24B40
60085	1	10	794	6597	\N	\N	55.579372999999997	Московская область, Шатурский район, дер. Левошево, д.37А		0101000020E61000003D9E961FB8BE4340BB97FBE428CA4B40
60095	1	10	794	7037	80761	\N	55.559159999999999	Московская область, Шатурский район, с. Кривандино, ул. Центральная, д.19		0101000020E6100000306475ABE7D643409D9D0C8E92C74B40
60103	1	10	794	7416	\N	\N	55.250217999999997	Московская область, Шатурский район, дер. Дубровка, д.35		0101000020E6100000E1ED4108C8E143406D6FB72407A04B40
60100	1	10	794	7285	74093	\N	55.319186999999999	Московская область, Шатурский район, с. Дмитровский Погост, ул. Пролетарская, д.1		0101000020E61000006458C51B99E9434078279F1EDBA84B40
60105	1	10	794	7546	\N	\N	55.233089999999997	Московская область, Шатурский район, дер. Дерзсковская, д.23		0101000020E6100000F1D8CF6229F443402783A3E4D59D4B40
60104	1	10	794	7480	\N	\N	55.350217999999998	Московская область, Шатурский район, дер. Губино, д.24А		0101000020E61000000A11700855E243403A3C84F1D3AC4B40
60090	1	10	794	6830	\N	\N	55.657052	Московская область, Шатурский район, с. Власово, д.19А		0101000020E6100000FF791A3048E04340BDE2A9471AD44B40
60089	1	10	794	6757	\N	\N	55.595286999999999	Московская область, Шатурский район, дер. Бордуки, д.94		0101000020E6100000F7C8E6AA79DA4340F25D4A5D32CC4B40
60088	1	10	794	6743	\N	\N	55.712136999999998	Московская область, Шатурский район, пос. Бакшеево, ул. Советская, д.6	Россия, Московская область, Шатурский район, поселок Бакшеево	0101000020E61000003E78EDD286EF4340C2A2224E27DB4B40
94665	1	10	565	49697	\N	\N	55.190702999999999	Адрес УИК и помещения для голосования: Московская область, Чеховский муниципальный район, с. Шарапово, ул. Колхозная (здание школы с. Шарапово), д.3	Россия, Московская область, Чеховский район, село Шарапово	0101000020E6100000B0389CF9D5A04240E21FB6F468984B40
60037	1	10	565	3514	1073	\N	55.156019000000001	"г.Чехов, ул.Полиграфистов, стр.30, ДС ""Олимпийский"""	Россия, Московская область, Чеховский район, Чехов, улица Полиграфистов, с30	0101000020E6100000F8C610001CBD4240FE463B6EF8934B40
60043	1	10	565	3514	1162	\N	55.150901160850999	г.Чехов, ул.Гарнаева, д.7, Школа №6	Россия, Московская область, Чеховский район, Чехов, улица Гарнаева	0101000020E6100000A67C08AA46B7424083F755B950934B40
60041	1	10	565	3514	1105	\N	55.167025000000002	г.Чехов, ул.Гагарина, д.112, Средняя общеобразовательная школа №9	Россия, Московская область, Чеховский район, Чехов, улица Гагарина, 112	0101000020E610000004E3E0D231B74240A54E401361954B40
60040	1	10	565	3514	1105	\N	55.166170999999999	г.Чехов, ул.Гагарина, д.34, Начальная общеобразовательная школа №5	Россия, Московская область, Чеховский район, Чехов, улица Гагарина, 34	0101000020E61000000F98874CF9B642409545611745954B40
94475	1	10	565	3514	74125	\N	55.142113000000002	Ул. Чехова, д. 3а ДЮСШ	Россия, Московская область, Чеховский район, Чехов, улица Чехова	0101000020E6100000BFBB95253ABB424011AB3FC230924B40
60029	1	10	565	3514	74125	\N	55.146912999999998	г. Чехов, ул.Чехова, д.27, Центр развития творчества		0101000020E610000098DA520779BD4240BA2D910BCE924B40
60028	1	10	565	3514	74125	\N	55.146064000000003	г.Чехов, ул.Чехова, д.8А, Гимназия №2		0101000020E6100000BF9D44847FBD4240BD8FA339B2924B40
60035	1	10	565	3514	1049	\N	55.158225000000002	"г. Чехов, ул. Московская (здание Ледового хоккейного центра ""Витязь""), влад.104"	Россия, Московская область, Чеховский район, Чехов, Московская улица, 104	0101000020E61000008FFD2C9622BB42406E3480B740944B40
60034	1	10	565	3514	1027	\N	55.152037	г.Чехов, ул.Молодежная, д.6, Средняя общеобразовательная школа №1	Россия, Московская область, Чеховский район, Чехов, Молодежная улица, 6	0101000020E6100000F08975AA7CBB42401764CBF275934B40
60033	1	10	565	3514	80284	\N	55.152577999999998	г.Чехов, ул.Мира, д.9, Гимназия №7		0101000020E6100000944DB9C2BBBC4240670B08AD87934B40
60032	1	10	565	3514	79869	\N	55.148640056470903	г.Чехов, ул.Лопасненская, стр. 1/1, Средняя общеобразовательная школа №3	Россия, Московская область, Чеховский район, Чехов, Лопасненская улица	0101000020E61000007995B54DF1BA42405070B1A206934B40
60036	1	10	565	3514	1056	\N	55.167507999999998	г.Чехов, ул.Земская, д.2	Россия, Московская область, Чеховский район, Чехов, Земская улица, 2	0101000020E61000000A9E42AED4BB4240C0E8F2E670954B40
60056	1	10	565	5021	74058	\N	55.183852000000002	"д.Чепелево, ул.Вокзальная, д.14, ДК ""Заря"""		0101000020E61000005872158BDFBE4240F0A65B7688974B40
60054	1	10	565	45811	\N	\N	55.212053502416097	"с.Талалихино, ДК ""Фортуна"""		0101000020E610000022C2BF081AD74240357EE195249B4B40
60060	1	10	565	5255	80743	\N	55.144922000000001	с.Стремилово, ул.Платонова, д.42, Основная общеобразовательная школа		0101000020E6100000C53D963E74934240473CD9CD8C924B40
94663	1	10	565	4438	\N	\N	55.250095000000002	Адрес УИК и помещения для голосования: Московская область, Чеховский муниципальный район, п. Столбовая, ул. Парковая (здание Администрации ГП "Столбовая"), д.2	Россия, Московская область, Чеховский район, поселок городского типа Столбовая	0101000020E6100000F31B261AA4BE424052F2EA1C03A04B40
94662	1	10	565	4438	\N	\N	55.250095000000002	Московская область, Чеховский муниципальный район, п. Столбовая, адрес помещения для голосования: ул. Школьная (здание школы п. Столбовая), д.1, адрес УИК: ул.Парковая (здание администрации ГП "Столбовая"), д.2	Россия, Московская область, Чеховский район, поселок городского типа Столбовая	0101000020E6100000F31B261AA4BE424052F2EA1C03A04B40
60048	1	10	565	59155	71769	\N	55.059905000000001	"с.Новый Быт, ул.Новая, д.8А, ДК ""Меридиан"""	Россия, Московская область, Чеховский район, село Новый Быт	0101000020E610000056664AEB6FCD4240F6EE8FF7AA874B40
94664	1	10	565	4863	\N	\N	55.275826000000002	Московская область, Чеховский муниципальный район, с. Молоди, адрес помещения для голосования: (здание школы с. Молоди), д.5, адрес УИК: (здание ДК "Радуга" с. Молоди)		0101000020E6100000B80375CAA3C1424079B130444EA34B40
60050	1	10	565	4732	\N	\N	55.279044024416699	п.Мещерское, д.15, Администрация сельского поселения Любучанское	Россия, Московская область, Чеховский район, поселок Мещерское	0101000020E61000005D52B5DD04CF42409012BBB6B7A34B40
60058	1	10	565	5131	\N	\N	55.116093999999997	"д.Манушкино, д.28, ДК ""Русь"""		0101000020E61000001EA8531EDDBA424083A10E2BDC8E4B40
60052	1	10	565	61920	80046	\N	55.2420940253756	место нахождения: п.Любучаны, ул.Спортивная, д.17А, Администрация сельского поселения Любучанское, место голосования: п.Любучаны, ул.Заводская, д.17, Средняя общеобразовательная школа	Россия, Московская область, Чеховский район, поселок Любучаны	0101000020E6100000448655BC91C542406747AAEFFC9E4B40
60059	1	10	565	59523	\N	\N	55.122188999999999	"с.Дубна, д.30, ДК ""Мечта"""	Россия, Московская область, Чеховский район, село Дубна	0101000020E610000073B8567BD8AB424029779FE3A38F4B40
60057	1	10	565	61972	80749	\N	55.097752801612103	место нахождения: д.Манушкино, Администрация сельского поселения Стремиловское, место голосования: д.Гришенки, ул.Русское поле, д.8		0101000020E6100000F0BE2A172AB74240FE0A992B838C4B40
60047	1	10	565	45682	\N	\N	55.132993999999997	"п.Васькино, д.4, ДК ""Каскад"""		0101000020E6100000A6ED5F5969CC4240384888F205914B40
59931	1	10	1865	30746	81008	\N	56.635531	село Темпы, ул. Шоссейная (администрация сп Темповое), дом 6		0101000020E6100000FCDEA63FFBA542400E4C6E1459514C40
59902	1	10	1865	29255	7488	\N	56.737870999999998	"город Талдом, ул. Зины Голициной (МУ РДС ""Атлант""), дом 24"	Россия, Московская область, Талдомский район, Талдом, улица Зины Голицыной	0101000020E6100000DE3B6A4C88C342405AD5928E725E4C40
59901	1	10	1865	29255	71847	\N	56.740142449646001	город Талдом, микрорайон Юбилейный (МОУ ТСОШ № 3)	Россия, Московская область, Талдомский район, Талдом	0101000020E6100000B5C35F9335C44240B1321AF9BC5E4C40
59903	1	10	1865	29255	71848	\N	56.731780960078602	"город Талдом, микрорайон ""ПМК-21"" (Дом детского творчества г.Талдом), дом 1"	Россия, Московская область, Талдомский район, Талдом, улица ПМК	0101000020E6100000319413ED2AC64240C66AF3FFAA5D4C40
59900	1	10	1865	29255	72415	\N	56.741085800886601	город Талдом, микрорайон Юбилейный (МОУ ТСОШ № 2), дом 47	Россия, Московская область, Талдомский район, Талдом	0101000020E6100000F12F82C64CC4424001C3F2E7DB5E4C40
59919	1	10	1865	60241	74106	\N	56.724287459714901	поселок Северный, ул. Клубная (МУ Центральный Дом культуры Северный), дом 2	Россия, Московская область, Талдомский район, поселок городского типа Северный	0101000020E61000002F185C7347CF42407FF5B86FB55C4C40
59924	1	10	1865	30377	\N	\N	56.563918000000001	деревня Павловичи, МОУ Павловическая средняя общеобразовательная школа, дом 32		0101000020E610000061DD787764DA424018D00B772E484C40
59922	1	10	1865	61976	\N	\N	56.566383000000002	село Новоникольское, МУ Новоникольский центральный Дом культуры, дом 10А	Россия, Московская область, Талдомский район, деревня Новоникольское	0101000020E6100000DBA4A2B1F6C342405401F73C7F484C40
59923	1	10	1865	30352	80742	\N	56.552598000000003	село Новогуслево, ул. Садовая (администрация сп Гуслевское), дом 2		0101000020E6100000CFF8BEB854CF4240E2EA0088BB464C40
59925	1	10	1865	30465	\N	\N	56.737707999999998	село Николо-Кропотки, МОУ Николо-кропоткинская средняя общеобразовательная школа, дом 98		0101000020E6100000B77A4E7ADFF64240B0FF3A376D5E4C40
59929	1	10	1865	30641	\N	\N	56.847385000000003	деревня Кошелёво, МУ Кошелёвский центральный Дом культуры, дом 66		0101000020E61000008C84B69C4BDF42407C0F971C776C4C40
59928	1	10	1865	30613	\N	\N	56.808093	село Квашёнки, МОУ Квашёнковская средняя общеобразовательная школа, дом 90		0101000020E6100000555051F52BC74240329067976F674C40
59914	1	10	1865	29869	\N	\N	56.552185999999999	"поселок Запрудня, ул. Первомайская (Спортивный комплекс ""Антей""), дом 59"	Россия, Московская область, Талдомский район, поселок городского типа Запрудня	0101000020E6100000EEE87FB916B742408FA7E507AE464C40
59916	1	10	1865	29869	71831	\N	56.560243933188097	"поселок Запрудня, Пролетарский переулок (МОУ ДОД ""Запрудненская ДШИ""), дом 28А"	Россия, Московская область, Талдомский район, поселок городского типа Запрудня	0101000020E610000011A96917D3B84240DEE34C13B6474C40
59912	1	10	1865	29869	72416	\N	56.557563540953602	"поселок Запрудня, ул. Первомайская (МУ Дворец культуры ""Прогресс""), дом 29"	Россия, Московская область, Талдомский район, поселок городского типа Запрудня	0101000020E61000008A9466F338B64240A6B6D4415E474C40
59913	1	10	1865	29869	71830	\N	56.561642049352201	поселок Запрудня, ул. Ленина (МОУ ЗСОШ №1), дом 19	Россия, Московская область, Талдомский район, поселок городского типа Запрудня	0101000020E610000084D72E6D38B84240AF0793E2E3474C40
59915	1	10	1865	29869	72419	\N	56.552089135105902	поселок Запрудня, ул. Карла Маркса (МОУ ЗСОШ №2), дом 4		0101000020E6100000FB592C45F2B742409DBD33DAAA464C40
94649	1	10	1865	29869	71839	\N	56.566592244651098	Гос. обр уч нач. проф. Обр. ПУ № 48 МО, ул. К Маркса, дом 14 корп.2, актовый зал, п. Запрудня.	Россия, Московская область, Талдомский район, поселок городского типа Запрудня	0101000020E6100000FE2955A2ECB742406E162F1686484C40
59918	1	10	1865	62054	\N	\N	56.552185999999999	поселок Запрудня, ул. Соревнование (МОУ Запрудненская школа-интернат 3-8 вида), дом 47		0101000020E6100000EEE87FB916B742408FA7E507AE464C40
59927	1	10	1865	61966	\N	\N	56.808372655385199	МУ Ермолинский центральный Дом культуры, дом 20а, 2-ой этаж, танцевальный зал,  д. Ермолино	Россия, Московская область, Талдомский район, деревня Ермолино	0101000020E610000038A0A52BD8E8424016FC36C478674C40
59911	1	10	1865	61966	\N	\N	56.809549690235997	деревня Ермолино, МУ Ермолинский центральный Дом культуры, дом 20А	Россия, Московская область, Талдомский район, деревня Ермолино	0101000020E610000043ACFE08C3E84240083D9B559F674C40
59909	1	10	1865	29625	\N	\N	56.534787000000001	"поселок Вербилки, ул. Забырина (МУ ДОД ""Вербилковская Детская школа искуств""), дом 9"	Россия, Московская область, Талдомский район, поселок городского типа Вербилки	0101000020E61000004434BA83D8CB4240B9A981E673444C40
59908	1	10	1865	29625	71875	\N	56.533055892384198	поселок Вербилки, ул. Советская (МУ Вербилковский Дом культуры), дом 11		0101000020E61000007D3D5FB35CCC4240E277D32D3B444C40
59910	1	10	1865	29625	71829	\N	56.532510456810101	поселок Вербилки, ул. Рубцова (ГОУНПО ПУ №79 МО), дом 2	Россия, Московская область, Талдомский район, поселок городского типа Вербилки	0101000020E6100000800D881057CC42408065A54929444C40
59930	1	10	1865	47962	\N	\N	56.765112999999999	село Великий Двор, Великодворский сельский Дом культуры, дом 59А	Россия, Московская область, Талдомский район, деревня Великий Двор	0101000020E610000018CE35CCD0B442404A5F0839EF614C40
59880	1	10	675	28328	71782	\N	55.0538772885455	Московская область, Ступинский муниципальный район с.Шугарово, Совхозная, 15		0101000020E610000078EDD286C3FE4240D8800871E5864B40
59899	1	10	675	29241	80740	\N	55.002873000000001	Московская область, Ступинский муниципальный район с.Хатунь, Школьная, 2а		0101000020E6100000C7D79E5912EA42404D8578245E804B40
59889	1	10	675	28793	72113	\N	55.142401	Московская область, Ступинский муниципальный район п. Усады, Пролетарская, 12		0101000020E6100000350BB43BA4F2424077F52A323A924B40
59890	1	10	675	28801	72115	\N	55.215466999999997	Московская область, Ступинский муниципальный район с. Татариново, Ленина, 4		0101000020E6100000B9533A58FFF74240012F336C949B4B40
94565	1	10	675	13685	6950	\N	54.883431000000002	Ул. Чайковского, д. 2, школа № 4	Россия, Московская область, Ступинский район, Ступино, улица Чайковского, 2/11	0101000020E6100000E048A0C1A60A4340E4A25A4414714B40
59872	1	10	675	13685	7170	\N	54.882275999999997	Московская область, Ступино, Калинина, 1	Россия, Московская область, Ступинский район, Ступино, улица Калинина, 1	0101000020E610000062A2410A9E084340D905836BEE704B40
59870	1	10	675	13685	7126	\N	54.886972999999998	Московская область, Ступино, Андропова, 32	Россия, Московская область, Ступинский район, Ступино, улица Андропова, 32	0101000020E6100000BE66B96C740A4340AEB7CD5488714B40
94648	1	10	675	13685	7140	\N	54.885033618803497	Московская обл., г. Ступино, ул. Проспект Победы, дом 18/43, Дворец культуры	Россия, Московская область, Ступинский район, Ступино, проспект Победы	0101000020E6100000048F6FEF1A0A43408DEC4ACB48714B40
59871	1	10	675	13685	7140	\N	54.884740999999998	Московская область, Ступино, проспект Победы, 25	Россия, Московская область, Ступинский район, Ступино, проспект Победы, 25	0101000020E610000056BC9179E409434015376E313F714B40
59867	1	10	675	13685	80453	\N	54.884881	Московская область, Ступино, Чайковского, 42		0101000020E6100000DB5207793D08434007EDD5C743714B40
59860	1	10	675	13685	80450	\N	54.891793999999997	Московская область, Ступино, Тимирязева, 50		0101000020E610000018B2BAD5730A43406F62484E26724B40
59873	1	10	675	13685	80469	\N	54.879479000000003	Московская область, Ступино, Службина, 8		0101000020E61000008A1F63EE5A084340684293C492704B40
94646	1	10	675	13685	79802	\N	54.888545397573502	Московская обл., г. Ступино, ул. Куйбышева, д. № 55, авиационно-металлургический техникум	Россия, Московская область, Ступинский район, Ступино, улица Куйбышева, 55	0101000020E6100000F0DB10E3350943401D03B2D7BB714B40
59861	1	10	675	13685	79802	\N	54.890411999999998	Московская область, Ступино, Куйбышева, 61		0101000020E6100000C1745AB741094340A4FB3905F9714B40
59868	1	10	675	13685	80463	\N	54.885880999999998	Московская область, Ступино, Андропова, 61/11		0101000020E6100000C4E8B985AE084340EA92718C64714B40
59856	1	10	675	13685	71846	\N	54.887269000000003	Московская область, Ступино, Авиаторов, 10		0101000020E610000058207A522609434098E0D40792714B40
59877	1	10	675	28219	9928	\N	54.946916999999999	Московская область, Ступинский муниципальный район с. Старая Ситня, Центральная, 11а		0101000020E610000025E659492B1243406283859334794B40
59878	1	10	675	28272	71780	\N	54.972894993182102	Московская область, Ступинский муниципальный район с.Ситне-Щелканово, Дружбы, 4		0101000020E61000001F679AB0FDFA424091B8C7D2877C4B40
59898	1	10	675	29187	72117	\N	55.062251000000003	Московская область, Ступинский муниципальный район с. Семеновское, 40 лет Победы, 37		0101000020E610000096B1A19BFDE1424058923CD7F7874B40
94628	1	10	560	20993	\N	\N	54.421103000000002	п.Дмитриевский,  д. 5а	Россия, Московская область, Серебряно-Прудский район, поселок Дмитриевский	0101000020E6100000E3512AE109694340AE9FFEB3E6354B40
59888	1	10	675	28599	\N	\N	55.122143000000001	Московская область, Ступинский муниципальный район р.п Михнево, Библеотечная, 19	Россия, Московская область, Ступинский район, поселок городского типа Михнево	0101000020E61000006FD6E07D55FA4240B937BF61A28F4B40
59887	1	10	675	28599	\N	\N	55.122143000000001	Московская область, Ступинский муниципальный район р.п Михнево, Гоголя, 5	Россия, Московская область, Ступинский район, поселок городского типа Михнево	0101000020E61000006FD6E07D55FA4240B937BF61A28F4B40
59885	1	10	675	28599	\N	\N	55.122143000000001	Московская область, Ступинский муниципальный район р.п Михнево, Тимирязева, 1а	Россия, Московская область, Ступинский район, поселок городского типа Михнево	0101000020E61000006FD6E07D55FA4240B937BF61A28F4B40
59886	1	10	675	28599	72265	\N	55.123077614613699	Московская область, Ступинский муниципальный район р.п Михнево, Московская, 26	Россия, Московская область, Ступинский район, поселок городского типа Михнево	0101000020E6100000247EC51A2EFA4240B56D1805C18F4B40
59893	1	10	675	28975	80738	\N	55.196998999999998	Московская область, Ступинский муниципальный район с. Мещерено, Новая, 1а		0101000020E610000086E81038122E43401F2C634337994B40
59881	1	10	675	60254	74138	\N	55.110177453542498	Московская область, Ступинский муниципальный район г.п. Малино, Промышленная, 1	Россия, Московская область, Ступинский район, поселок городского типа Малино	0101000020E61000000B9B012EC8164340BDE2A9471A8E4B40
59876	1	10	675	28185	\N	\N	54.843958000000001	Московская область, Ступинский муниципальный район с. Лужники, Центральная, 1	Россия, Московская область, Ступинский район, село Лужники	0101000020E61000002D211FF46C0C43404A99D4D0066C4B40
59896	1	10	675	29110	71913	\N	55.060828000000001	Московская область, Ступинский муниципальный район д.Леонтьево, Центральная, 19		0101000020E61000003F8C101E6D2443402E573F36C9874B40
59897	1	10	675	29131	80748	\N	55.076895999999998	Московская область, Ступинский муниципальный район с. Ивановское, Школьная, 11		0101000020E6100000998235CEA6EB4240BB9866BAD7894B40
59879	1	10	675	28315	72395	\N	54.984181	Московская область, Ступинский муниципальный район р.п Жилево, Комсомольская, 3а		0101000020E61000009D82FC6CE40243401B2C9CA4F97D4B40
59884	1	10	675	28529	72420	\N	55.104841	Московская область, Ступинский муниципальный район д. Дубнево, Новые Дома, 18		0101000020E61000009C4EB2D5E50E4340D5230D6E6B8D4B40
59875	1	10	675	28143	\N	\N	54.883949000000001	Московская область, Ступинский муниципальный район д. Городище, Центральная, 41	Россия, Московская область, Ступинский район, деревня Городище	0101000020E610000084F23E8EE61C43407C2AA73D25714B40
59883	1	10	675	28488	\N	\N	55.107612000000003	Московская область, Ступинский муниципальный район с. Березнецово, проезд Центральный, 4/12	Россия, Московская область, Ступинский район, село Березнецово	0101000020E61000002C2D23F59E1243401E54E23AC68D4B40
59895	1	10	675	29063	72399	\N	55.111443999999999	Московская область, Ступинский муниципальный район д. Алфимово, Новоселов, 3		0101000020E6100000D55A9885762A4340EFAA07CC438E4B40
59891	1	10	675	28880	80736	\N	55.148085999999999	Московская область, Ступинский муниципальный район с. Аксиньино, Шоссейная, 12		0101000020E610000060AE450BD02443406B7F677BF4924B40
59835	1	10	143	59507	\N	\N	56.141354205069597	"Московская область, Солнечногорский муниципальный район, сельское поселение Кривцовское, Здание Дома культуры ""Истра"""		0101000020E61000000DC2DCEEE570424053944BE317124C40
94632	1	10	143	49690	\N	\N	55.974513999999999	в помещении Складского комплекса Многофункционального Логистического парка  «МЛП» закрытого акционерного общества «Стик», деревня Черная Грязь	Россия, Московская область, Солнечногорский район, деревня Черная Грязь	0101000020E6100000878A71FE26A8424040BFEFDFBCFC4B40
94639	1	10	143	49694	74086	\N	56.031844999999997	в помещении актового зала административного корпуса Закрытого акционерного общества Агроплеменная фирма «Искра», деревня Чашниково, микрорайон «Новые дома»	Россия, Московская область, Солнечногорский район, деревня Чашниково	0101000020E61000003A3FC571E095424043C5387F13044C40
59828	1	10	143	62067	\N	\N	56.224984999999997	в помещении муниципального общеобразовательного учреждения Тимоновская средняя общеобразовательная школа	Россия, Московская область, Солнечногорский район, деревня Тимоново	0101000020E6100000033E3F8C10844240978BF84ECC1C4C40
59831	1	10	143	60242	\N	\N	56.187044999999998	Солнечногорск-7, Здание 139 Дома культуры РА		0101000020E6100000B2463D44A37D4240AEF02E17F1174C40
59832	1	10	143	11017	\N	\N	56.186647592017302	Солнечногорск-7, Здание Тимоновской школы	Россия, Московская область, Солнечногорский район, Солнечногорск, Почтовая улица, 12	0101000020E6100000FF5A5EB9DE7C424091EEE714E4174C40
59818	1	10	143	11017	\N	\N	56.179414999999999	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Мкр. Рекинцо, Здание школы	Россия, Московская область, Солнечногорский район, Солнечногорск, микрорайон Рекинцо-1	0101000020E6100000BD344580D37F4240B7B41A12F7164C40
59817	1	10	143	11017	\N	\N	56.184888940267697	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Здание Дома офицеров	Россия, Московская область, Солнечногорский район, Солнечногорск, Почтовая улица, 18/10	0101000020E61000003C17467A517D4240F0315871AA174C40
30266	1	10	560	48067	\N	\N	54.54195	с.Глубокое, 40а		0101000020E610000043209738F24443409A081B9E5E454B40
59892	1	10	143	11017	6718	\N	56.172462206928401	Московская область, Солнечногорский муниципальный район с. Большое Алексеевское, Школьная, 2/9	Россия, Московская область, Солнечногорский район, Солнечногорск, Школьная улица, 6	0101000020E610000014B01D8CD8794240C1E61C3C13164C40
59826	1	10	143	11017	6718	\N	56.173251999999998	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Школьная, 1	Россия, Московская область, Солнечногорский район, Солнечногорск, Школьная улица, 1	0101000020E6100000C66F0A2B157A4240B9FB1C1F2D164C40
59823	1	10	143	11017	80871	\N	56.176163000000003	"Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Стеклозаводская, Здание спортпавильона ОАО""Солстек"""		0101000020E6100000310C5872157D4240F4E159828C164C40
59821	1	10	143	11017	80435	\N	56.185147000000001	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Советская, 3	Россия, Московская область, Солнечногорский район, Солнечногорск, Советская улица, 3	0101000020E6100000BDAC8905BE7C4240ECF99AE5B2174C40
59822	1	10	143	11017	79980	\N	56.186210086811599	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Почтовая, 9	Россия, Московская область, Солнечногорский район, Солнечногорск, Почтовая улица, 9	0101000020E61000003DBB7CEBC37C42401618B2BAD5174C40
59820	1	10	143	11017	79980	\N	56.181206279000698	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Почтовая, 33	Россия, Московская область, Солнечногорский район, Солнечногорск, Почтовая улица, 33	0101000020E610000014596B28B57D424064EB19C231174C40
59824	1	10	143	11017	6702	\N	56.183343000000001	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Обуховская, 9а	Россия, Московская область, Солнечногорский район, Солнечногорск, Обуховская улица, 9а	0101000020E6100000FF4124438E7B4240AB798EC877174C40
59819	1	10	143	11017	74065	\N	56.179307311963697	"Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Мкр. Рекинцо, Здание МУП ""СГХ"""		0101000020E610000058E4D70FB17F4240D1782288F3164C40
59813	1	10	143	11017	80428	\N	56.191077999999997	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Красная, 113		0101000020E6100000B45BCB64387C4240177E703E75184C40
59812	1	10	143	11017	80428	\N	56.197561725581302	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Красная, 176		0101000020E610000090BC7328437B424057772CB649194C40
59816	1	10	143	11017	80430	\N	56.186013000000003	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Дзержинского, 21/19		0101000020E6100000774D486B0C7E4240C0D02346CF174C40
59814	1	10	143	11017	80430	\N	56.188839000000002	Московская область, Солнечногорский муниципальный район, городское поселение Солнечногорск, Дзержинского, 5		0101000020E610000012842BA0507D4240CC9A58E02B184C40
59848	1	10	143	62058	\N	\N	56.0399379806369	Московская область, Солнечногорский муниципальный район, сельское поселение Соколовское, ДК	Россия, Московская область, Солнечногорский район, деревня Соколово	0101000020E610000037C64E78097442400FEF39B01C054C40
94640	1	10	143	60248	\N	\N	56.220896641653802	в помещении администрации сельского поселения Смирновское, кабинет № 2, поселок Смирновка и место голосования в помещении администрации сельского поселения Смирновское, кабинет № 7, поселок Смирновка	Россия, Московская область, Солнечногорский район, поселок Смирновка	0101000020E610000004AA7F10C97842406B64575A461C4C40
59839	1	10	143	26442	\N	\N	55.932873999999998	в здании Манежа усадьбы Середниково, деревня Середниково	Россия, Московская область, Солнечногорский район, деревня Середниково	0101000020E6100000698CD651D59C4240F4A44C6A68F74B40
59809	1	10	143	61909	\N	\N	56.013591898513901	РЖАВКИ, здание школы		0101000020E6100000F4E159828C9C42405EBEF561BD014C40
59810	1	10	143	25094	\N	\N	56.015207711812998	Московская область, Солнечногорский муниципальный район, городское поселение Ржавки, Здание школы	Россия, Московская область, Солнечногорский район, поселок городского типа Ржавки	0101000020E6100000F583BA48A19C42409C51F355F2014C40
94637	1	10	143	49692	74087	\N	56.071845000000003	в здании администрации  сельского поселения Пешковское, деревня Радумля, микрорайон Механического завода № 1, дом №16		0101000020E6100000404E98309A914240C9B08A3732094C40
94633	1	10	143	60237	\N	\N	56.010763991471002	в помещении муниципального образовательного учреждения  Поярковская начальная школа, деревня Поярково	Россия, Московская область, Солнечногорский район, деревня Поярково	0101000020E6100000177E703E75AA4240B1FCF9B660014C40
59807	1	10	143	24931	\N	\N	56.075839999999999	ПОВАРОВО, здание школы	Россия, Московская область, Солнечногорский район, поселок городского типа Поварово	0101000020E610000085402E71E487424044DD0720B5094C40
94630	1	10	143	24931	71924	\N	56.061340300739801	в помещении Дома культуры «Геофизик», дачный  поселок Поварово, микрорайон Поваровка	Россия, Московская область, Солнечногорский район, поселок городского типа Поварово	0101000020E6100000F6285C8FC2894240E4F736FDD9074C40
59806	1	10	143	24931	71827	\N	56.062925221639603	ПОВАРОВО, МКР№2		0101000020E6100000BE874B8E3B894240E78C28ED0D084C40
59805	1	10	143	24931	71814	\N	56.075167958350598	ПОВАРОВО, МЕХЛЕСХОЗА, 1	Россия, Московская область, Солнечногорский район, поселок городского типа Поварово	0101000020E610000036B05582C587424055DAE21A9F094C40
94643	1	10	143	61965	\N	\N	56.079994999999997	в помещении муниципального общеобразовательного учреждения средняя общеобразовательная школа «Лесные озера», деревня Новая	Россия, Московская область, Солнечногорский район, деревня Новая	0101000020E610000015C9570229754240F86BB2463D0A4C40
59593	1	10	143	45782	\N	\N	56.063715000000002	с.Никольское, д.5		0101000020E610000089EAAD81AD984240E0A128D027084C40
59803	1	10	143	24762	6477	\N	56.038977000000003	Менделеево, Куйбышева, 11		0101000020E610000044BFB67EFA9D4240EA25C632FD044C40
59801	1	10	143	24762	6477	\N	56.038977000000003	Менделеево, Куйбышева, 7	Россия, Московская область, Солнечногорский район, поселок городского типа Менделеево, улица Куйбышева	0101000020E610000044BFB67EFA9D4240EA25C632FD044C40
58313	1	10	143	60223	74064	\N	56.181732475330598	Московская область, Клинский муниципальный район, Малеевка, Центральная усадьба, 17		0101000020E610000053EBFD463B6442407E5182FE42174C40
94638	1	10	143	49693	\N	\N	56.093249	в помещении  муниципального дошкольного образовательного учреждения Майдаровская  школа-сад № 46, поселок Майдарово	Россия, Московская область, Солнечногорский район, поселок Майдарово	0101000020E6100000640795B88E9342403EB14E95EF0B4C40
59802	1	10	143	24805	\N	\N	56.051431000000001	д.Льялово, здание дома спорта и творчества		0101000020E6100000D2C3D0EAE49C424013807F4A95064C40
94642	1	10	143	49695	\N	\N	56.021613000000002	в помещении муниципального дошкольного образовательного учреждения школа-сад № 28, деревня Лыткино	Россия, Московская область, Солнечногорский район, деревня Лыткино	0101000020E6100000B30C71AC8B7F42409015FC36C4024C40
59841	1	10	143	59432	\N	\N	55.995663809566302	Московская область, Солнечногорский муниципальный район, сельское поселение Луневское	Россия, Московская область, Солнечногорский район, поселок Лунево	0101000020E6100000FC1BB4571FAD4240FBE6FEEA71FF4B40
94636	1	10	143	49691	\N	\N	56.094152999999999	в помещении  Центрального сельского Дома культуры, деревня Ложки		0101000020E6100000F778211D1E8E4240FFE89B340D0C4C40
59834	1	10	143	59433	\N	\N	56.140769610921701	"Московская область, Солнечногорский муниципальный район, сельское поселение Кривцовское, Здание спортклуба ""Истра"""	Россия, Московская область, Солнечногорский район, деревня Кривцово	0101000020E610000076A73B4F3C714240042159C004124C40
59836	1	10	143	26321	\N	\N	56.195354999999999	Московская область, Солнечногорский муниципальный район, сельское поселение Кривцовское, Здание Дома культуры д. Замятино (Никулино)		0101000020E610000036069D103A684240170E846401194C40
94635	1	10	143	61969	\N	\N	56.1085257139192	в помещении  сельского Дома культуры на территории посёлка Жуково, микрорайон Берёзки	Россия, Московская область, Солнечногорский район, деревня Жуково	0101000020E6100000D7DCD1FF728542400262122EE40D4C40
59800	1	10	143	45346	\N	\N	55.984133999999997	д.Голубое, здание больницы	Россия, Московская область, Солнечногорский район, деревня Голубое	0101000020E6100000B3412619398D4240DA70581AF8FD4B40
59837	1	10	143	26383	\N	\N	55.927483000000002	Московская область, Солнечногорский муниципальный район, сельское поселение Кутузовское, Здание школы д. Брехово		0101000020E61000002063EE5A42984240494C50C3B7F64B40
94631	1	10	143	62015	80904	\N	55.911411000000001	в помещении магазина «М 5» (собственник Общество с ограниченной ответственностью «Де-Флорес»), деревня Благовещенка, улица Липовая аллея, дом 1	Россия, Московская область, Солнечногорский район, деревня Благовещенка	0101000020E61000002497FF907E9D42407A1B9B1DA9F44B40
59799	1	10	143	1689	\N	\N	55.980296000000003	Андреевка, здание Дома Культуры		0101000020E610000042E90B21E79142402733DE567AFD4B40
59798	1	10	143	1689	\N	\N	55.980296000000003	Андреевка, здание школы		0101000020E610000042E90B21E79142402733DE567AFD4B40
59797	1	10	143	341	\N	\N	56.006193523503697	Алабушево, здание школы	Россия, Московская область, Солнечногорский район, село Алабушево, Первомайская улица, 35	0101000020E6100000A1BDFA78E88F424039B709F7CA004C40
60249	1	10	143	341	2398	\N	56.003129999999999	Московская область, городской округ Электросталь, Первомайская, 16	Россия, Московская область, Солнечногорский район, село Алабушево, Первомайская улица, 16	0101000020E610000090DD054A0A90424078D1579066004C40
59963	1	10	143	341	80141	\N	56.002068000000001	Московская область, городской округ Химки, Первомайская, 6		0101000020E61000004C5299620E9042401F2FA4C343004C40
57848	1	10	143	341	80141	\N	56.002142999999997	Московская область, городской округ Долгопрудный, Первомайская, 3		0101000020E61000001D8EAED2DD8F42402975C93846004C40
59770	1	10	532	61981	\N	\N	54.917282992596803	"Московская область, Серпуховский муниципальный район, сельское поселение Данковское, ц\\у Совхоза ""Серпуховский"", МОУ ""Начальная школа-детский сад ""Улыбка"""	Россия, Московская область, Серпуховский район, местечко Данки	0101000020E6100000EA25C632FDC84240A016838769754B40
59788	1	10	532	61963	\N	\N	54.858725948011099	"Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, п. Кирпичного завода, ДК ""Юность"""	Россия, Московская область, Серпуховский район, поселок кирпичного завода	0101000020E6100000BDAB1E300FB74240C91CCBBBEA6D4B40
59772	1	10	532	23216	\N	\N	54.915134999999999	Московская область, Серпуховский муниципальный район, сельское поселение Данковское, м. Данки, помещение администрации Данковского с/п		0101000020E6100000C66E9F5566C842406536C82423754B40
59760	1	10	532	61959	\N	\N	54.964148000000002	Московская область, Серпуховский муниципальный район, сельское поселение Васильевское,  п. Авангард, помещение Центра Досуга	Россия, Московская область, Серпуховский район, поселок дома отдыха "Авангард"	0101000020E6100000FD4CBD6E11BA42407D40A033697B4B40
59763	1	10	532	22944	\N	\N	55.037036000000001	"Московская область, Серпуховский муниципальный район, сельское поселение Васильевское, п. Шарапова Охота, МОУ ""Шарапово-Охотская средняя общеобразовательная школа"""	Россия, Московская область, Серпуховский район, деревня Шарапова Охота	0101000020E6100000868E1D54E2BC424028637C98BD844B40
59766	1	10	532	62050	\N	\N	55.016471000000003	Московская область, Серпуховский муниципальный район, сельское поселение Васильевское, п/о Фенино, помещение библиотеки	Россия, Московская область, Серпуховский район, деревня Фенино	0101000020E610000003EFE4D363BD42408D2AC3B81B824B40
59768	1	10	532	23154	\N	\N	54.876795999999999	Московская область, Серпуховский муниципальный район, сельское поселение Данковское, с. Турово, помещение администрации Туровского с/о		0101000020E6100000C1E09A3BFAE94240BEA1F0D93A704B40
59775	1	10	532	23497	\N	\N	55.036416566372601	"Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, д. Съяново-2, СДК ""Ровесник"""	Россия, Московская область, Серпуховский район, деревня Съяново-2	0101000020E6100000AFB5F7A92AA042405C02F04FA9844B40
59765	1	10	532	52786	\N	\N	55.040992519977202	Московская область, Серпуховский муниципальный район, сельское поселение Васильевское, д. Старые Кузьменки, помещение библиотеки	Россия, Московская область, Серпуховский район, деревня Старые Кузьменки	0101000020E6100000C5538F34B8B34240B62E35423F854B40
59363	1	10	532	60227	\N	\N	54.759093796127601	"п. Рогово, здание МУК СДК ""Юбилейный"", д. 1а"		0101000020E6100000EE073C3080C842407F4B00FE29614B40
59774	1	10	532	23411	\N	\N	55.006791	"Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, с. Райсеменовское, МОУ ""Райсеменовская средняя общеобразовательная школа"""		0101000020E61000008FFD2C9622AB42401D740987DE804B40
59778	1	10	532	56686	\N	\N	54.940886999999996	Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, д. Пущино, помещение ФАПа		0101000020E6100000A46C91B41BAD4240A31D37FC6E784B40
59785	1	10	532	52829	\N	\N	54.802329	Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, д. Прончищево, помещение клуба		0101000020E61000006A334E4354DD4240F2D077B7B2664B40
59794	1	10	532	24366	\N	\N	55.021735999999997	Московская область, Серпуховский муниципальный район, городское поселение Пролетарский, п. Пролетарский, Администрация городского поселения Пролетарский		0101000020E61000001956F146E6B14240AB92C83EC8824B40
59793	1	10	532	24366	\N	\N	55.021735999999997	Московская область, Серпуховский муниципальный район, городское поселение Пролетарский, п. Пролетарский, помещение администрации городского поселения Пролетарский		0101000020E61000001956F146E6B14240AB92C83EC8824B40
59789	1	10	532	52838	\N	\N	54.864123999999997	Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, д. Подмоклово, помещение СДК		0101000020E61000003E26529ACDAB424027D87F9D9B6E4B40
59792	1	10	532	15310	\N	\N	54.976457000000003	Московская область, Серпуховский муниципальный район, городское поселение Оболенск, п. Оболенск, ДК Оболенск		0101000020E6100000C66F0A2B15A04240A379008BFC7C4B40
59791	1	10	532	15310	\N	\N	54.976457000000003	Московская область, Серпуховский муниципальный район, городское поселение Оболенск, п. Оболенск, помещение ДК	Россия, Московская область, Серпуховский район, поселок городского типа Оболенск	0101000020E6100000C66F0A2B15A04240A379008BFC7C4B40
59761	1	10	532	52774	\N	\N	54.945391999999998	Московская область, Серпуховский муниципальный район, сельское поселение Васильевское, д. Нефедаво, помещение ФАПа		0101000020E61000006E4E250340BB424034F3E49A02794B40
59790	1	10	532	56687	\N	\N	54.871786999999998	"Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, д. Лукьяново, МОУ ""Липицкая средняя общеобразовательная школа"""		0101000020E6100000D905836BEEB64240FA0967B7966F4B40
59786	1	10	532	23994	\N	\N	54.847214000000001	Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, с. Липицы, помещение ЦСДК	Россия, Московская область, Серпуховский район, село Липицы	0101000020E61000007444BE4BA9BD42404F5B2382716C4B40
59780	1	10	532	52816	\N	\N	54.896417999999997	Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, д. Калиново, помещение библиотеки	Россия, Московская область, Серпуховский район, деревня Калиново	0101000020E6100000C075C58CF0A44240DAC534D3BD724B40
59762	1	10	532	57915	\N	\N	54.944786999999998	Московская область, Серпуховский муниципальный район, сельское поселение Васильевское, д. Ивановское, помещение ФАПа		0101000020E6100000E3FC4D2844B84240CD57C9C7EE784B40
59779	1	10	532	23699	\N	\N	54.862015	"Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, д. Дракино, МУК ""Дракинский центр досуга"""		0101000020E6100000ADFC321823A44240AAD4EC81566E4B40
30499	1	10	560	9815	\N	\N	54.627229999999997	с.Крутое, 13		0101000020E6100000B6300BED9C484340F888981249504B40
59717	1	10	560	20797	\N	\N	54.479329999999997	с.Дудино, 38а		0101000020E6100000CBA2B08BA2554340EFFE78AF5A3D4B40
59769	1	10	532	23216	\N	\N	54.915134999999999	"Московская область, Серпуховский муниципальный район, сельское поселение Данковское, м. Данки, МОУ ""Данковская средняя общеобразовательная школа"""		0101000020E6100000C66E9F5566C842406536C82423754B40
59776	1	10	532	61961	\N	\N	54.949950657780498	Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, д. Глазово, помещение библиотеки	Россия, Московская область, Серпуховский район, деревня Глазово	0101000020E61000002E20B41EBEAE4240B8E68EFE97794B40
59777	1	10	532	62052	\N	\N	54.956273540172603	Московская область, Серпуховский муниципальный район, сельское поселение Дашковское, д. Гавшино, помещение СДК		0101000020E6100000643E20D099AA4240EF01BA2F677A4B40
59764	1	10	532	52788	\N	\N	55.001694585474503	Московская область, Серпуховский муниципальный район, сельское поселение Васильевское, д. Васильевское, помещение администрации Васильевского сельского поселения	Россия, Московская область, Серпуховский район, деревня Васильевское	0101000020E6100000A59F70766BB542408AC8B08A37804B40
59771	1	10	532	52795	\N	\N	54.929119999999998	Московская область, Серпуховский муниципальный район, сельское поселение Данковское, д. Бутурлино, помещение администрации Данковского сельского поселения		0101000020E6100000FEF3346090BE42409E077767ED764B40
59783	1	10	532	52824	\N	\N	54.801743000000002	Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, д. Большое Грызлово, Помещение ЦДТ	Россия, Московская область, Серпуховский район, деревня Большое Грызлово	0101000020E61000002A3A92CB7FD042400266BE839F664B40
59782	1	10	532	3247	837	\N	54.903106999999999	Московская область, Серпуховский муниципальный район, сельское поселение Калиновское, п. Большевик, Ленина, 36	Россия, Московская область, Серпуховский район, поселок Большевик, улица Ленина, 36	0101000020E61000001895D40968AE4240F3E49A0299734B40
58381	1	10	532	3247	837	\N	54.903246000000003	Московская область, городской округ Коломна, ул. Ленина, д.1, школа № 24	Россия, Московская область, Серпуховский район, поселок Большевик, улица Ленина, 1б	0101000020E6100000645A9BC6F6AE4240151F9F909D734B40
59787	1	10	532	52832	\N	\N	54.751444999999997	Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, д. Б. Городня, помещение разновозрастного отряда		0101000020E61000004CE3175E49CA424011DF89592F604B40
59784	1	10	532	52827	\N	\N	54.836269000000001	Московская область, Серпуховский муниципальный район, сельское поселение Липицкое, д. Балково, помещение СДК		0101000020E610000027BD6F7CEDD542404ED4D2DC0A6B4B40
59767	1	10	532	52789	\N	\N	54.970286999999999	Московская область, Серпуховский муниципальный район, сельское поселение Данковское, д. Арнеево, помещение администрации Арнеевского с/о		0101000020E6100000ECDD1FEF55C94240F25D4A5D327C4B40
59720	1	10	560	48300	\N	\N	54.433255000000003	п.Успенский, 50 лет Октября, 15	Россия, Московская область, Серебряно-Прудский район, поселок Успенский	0101000020E610000045DAC69FA85A43400CEA5BE674374B40
59257	1	10	560	48300	80716	\N	54.433255000000003	п.Успенский, Запрудная, 17		0101000020E610000045DAC69FA85A43400CEA5BE674374B40
59639	1	10	560	46759	\N	\N	54.542424280773901	"с.Узуново, м-н ""Северный"", 12"		0101000020E6100000C7832D76FB4E434062484E266E454B40
59657	1	10	560	46759	71973	\N	54.542074999999997	с.Узуново, Советская, 7а		0101000020E6100000904AB1A3714E4340567DAEB662454B40
59714	1	10	560	59148	80304	\N	54.474245000000003	п.Серебряные Пруды, Школьная, 1	Россия, Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды	0101000020E610000085D04197705C434051A5660FB43C4B40
59711	1	10	560	59148	79990	\N	54.474245000000003	п.Серебряные Пруды, Центральный, 1	Россия, Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды	0101000020E610000085D04197705C434051A5660FB43C4B40
59710	1	10	560	59148	71772	\N	54.469541985365602	п.Серебряные Пруды, И.Садофьева, 13	Россия, Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды	0101000020E6100000CD751A69A95C4340990CC7F3193C4B40
59713	1	10	560	59148	81078	\N	54.474245000000003	р.п. Серебряные Пруды, ул.Б.Луговая, д. 8	Россия, Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды	0101000020E610000085D04197705C434051A5660FB43C4B40
59716	1	10	560	61914	80331	\N	54.470095999999998	"п.Серебряные Пруды, м-н ""Западный"", 10"	Россия, Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды	0101000020E61000002829B000A65C43407EFD101B2C3C4B40
94627	1	10	560	61914	81021	\N	54.474245000000003	Московская область, р.п.Серебряные Пруды, ул.Привокзальная, д. 7		0101000020E610000085D04197705C434051A5660FB43C4B40
59712	1	10	560	61914	80003	\N	54.4642637901363	п.Серебряные Пруды, Первомайская, 12		0101000020E6100000D2C3D0EAE45C4340E65AB4006D3B4B40
59614	1	10	560	5274	80734	\N	54.327855999999997	"с.Подхожее, м-он ""Юбилейный"", 10"		0101000020E61000002B8A5759DB48434010E6762FF7294B40
59401	1	10	560	5274	80732	\N	54.327855999999997	"с.Подхожее, м-он ""Юбилейный"", д. 12"		0101000020E61000002B8A5759DB48434010E6762FF7294B40
59703	1	10	560	61977	\N	\N	54.515341999999997	с.Петрово, 9	Россия, Московская область, Серебряно-Прудский район, село Петрово	0101000020E61000003563D17476364340AB2006BAF6414B40
59718	1	10	560	20808	\N	\N	54.535974000000003	п.Новоклемово, 61	Россия, Московская область, Серебряно-Прудский район, поселок Новоклемово	0101000020E6100000B4C876BE9F664340CFC0C8CB9A444B40
59691	1	10	560	19341	\N	\N	54.494717000000001	с.Мягкое, 1а		0101000020E61000002A38BC20225143403BE3FBE2523F4B40
42893	1	10	560	3492	80760	\N	54.330973999999998	с.Мочилы, Школьная, 9		0101000020E6100000BAA29410AC564340C4E9245B5D2A4B40
59701	1	10	506	59547	71902	\N	56.520831445109998	Московская область, Сергиево-Посадский муниципальный район, сельское поселение Шеметовское, м-он Новый, 34	Россия, Московская область, Сергиево-Посадский район, село Шеметово	0101000020E61000003CA3AD4A220B43401ADF1797AA424C40
59702	1	10	506	59547	79801	\N	56.5183007863548	Московская область, Сергиево-Посадский муниципальный район, сельское поселение Шеметовское, Центральная, 36	Россия, Московская область, Сергиево-Посадский район, село Шеметово	0101000020E61000001250E108520B4340F73DEAAF57424C40
59708	1	10	506	20283	\N	\N	56.548127999999998	Московская область, Сергиево-Посадский муниципальный район, д. Шабурново, Дом культуры, 47		0101000020E6100000FDA204FD85F64240CD02ED0E29464C40
59671	1	10	506	3067	80281	\N	56.246195999999998	Московская область, Сергиево-Посадский муниципальный район, городское поселение Хотьково, Седина, 30		0101000020E6100000DAAED007CBFE4240F833BC59831F4C40
59673	1	10	506	3067	80299	\N	56.269784879728903	Московская область, Сергиево-Посадский муниципальный район, городское поселение Хотьково, Пушкина, 11	Россия, Московская область, Сергиево-Посадский район, Хотьково, улица Пушкина, 6	0101000020E61000002F6EA301BCFD4240C6F99B5088224C40
59670	1	10	506	3067	80290	\N	56.262178814022398	Московская область, Сергиево-Посадский муниципальный район, городское поселение Хотьково, Октябрьская, 1	Россия, Московская область, Сергиево-Посадский район, Хотьково, Октябрьская улица, 1	0101000020E610000086E5CFB7050143405859DB148F214C40
59674	1	10	506	3067	79924	\N	56.253520183039903	Московская область, Сергиево-Посадский муниципальный район, городское поселение Хотьково, Майолик, 5		0101000020E61000008D9B1A683EFD4240E370E65773204C40
59672	1	10	506	3067	79858	\N	56.252201364253999	Московская область, Сергиево-Посадский муниципальный район, городское поселение Хотьково, Михеенко, 12б	Россия, Московская область, Сергиево-Посадский район, Хотьково, улица Михеенко, 19	0101000020E6100000CD237F30F0FC42405E82531F48204C40
59700	1	10	506	19783	\N	\N	56.673268999999998	Московская область, Сергиево-Посадский муниципальный район, д. Федорцово, Дом культуры, 15а		0101000020E6100000232C2AE2741243408F34B8AD2D564C40
59629	1	10	506	16195	\N	\N	56.273854999999998	Московская область, Сергиево-Посадский муниципальный район, д. Тураково, Клуб д. Тураково, 102		0101000020E610000075E8F4BC1B1943404C6C3EAE0D234C40
59699	1	10	506	19776	\N	\N	56.631287999999998	Московская область, Сергиево-Посадский муниципальный район, д. Торгашино, Клуб, 5		0101000020E6100000B7EC10FFB0194340BA2D910BCE504C40
57424	1	10	506	48407	80777	\N	56.617209000000003	деревня Судниково, Школьная, 12		0101000020E61000007289230F44F6424000E65AB4004F4C40
59684	1	10	506	59580	\N	\N	56.3683294189617	Московская область, Сергиево-Посадский муниципальный район, городское поселение Скоропусковский, Школа №15, 31	Россия, Московская область, Сергиево-Посадский район, поселок городского типа Скоропусковский	0101000020E61000002F151BF33A1243408E959867252F4C40
59637	1	10	506	15436	4637	\N	56.314427000000002	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Л. Булавина, 6	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица Леонида Булавина, 6	0101000020E6100000CEAACFD5561243405DFDD8243F284C40
59631	1	10	506	15436	4569	\N	56.324210999999998	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, 40 лет Октября, 2	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица 40 лет Октября, 2	0101000020E61000009D9B36E3341443407100FDBE7F294C40
59632	1	10	506	15436	4399	\N	56.322024999999996	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, пр. Красной Армии, 212а	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 212а	0101000020E610000072C284D1AC12434048BF7D1D38294C40
59628	1	10	506	15436	4399	\N	56.318930000000002	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, пр. Красной Армии, 192/2	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 192/2	0101000020E61000007022FAB5F51143404DDBBFB2D2284C40
59627	1	10	506	15436	4399	\N	56.3180173983909	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, пр. Красной Армии, 185		0101000020E610000042075DC2A11143403849F3C7B4284C40
59618	1	10	506	15436	4399	\N	56.303925999999997	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, пр. Красной Армии, 111	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 111	0101000020E61000002A8BC22E8A104340B933130CE7264C40
59644	1	10	506	15436	15815	\N	56.301603999999998	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад-7, Бульвар Свободы, 5	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, городок Сергиев Посад-7, бульвар Свободы, 5	0101000020E610000038F6ECB94C174340E02BBAF59A264C40
59645	1	10	506	15436	80112	\N	56.303027	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад-7, Бульвар Свободы, 2		0101000020E6100000486FB88FDC1643400A67B796C9264C40
59003	1	10	506	19477	\N	\N	56.198335	д.Зубцово, Школьная, 16 б (библиотека)		0101000020E6100000BE310400C71243407A53910A63194C40
59643	1	10	506	15436	80240	\N	56.304046	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад-7, Ясная, 4		0101000020E6100000DEAAEB504D174340643DB5FAEA264C40
59635	1	10	506	15436	4621	\N	56.3408586755031	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Ярославское шоссе, 13	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Ярославское шоссе, 13	0101000020E610000082548A1D8D1543400DC68844A12B4C40
59615	1	10	506	15436	80047	\N	56.295045000000002	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Школьная, 2		0101000020E6100000C26D6DE1790F434096ECD808C4254C40
59622	1	10	506	15436	4332	\N	56.295475000000003	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Хотьковский проезд, 16		0101000020E610000019FF3EE3C20F43408FE4F21FD2254C40
94626	1	10	506	15436	74307	\N	56.311926917906703	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, м-он Семхоз, ул. Советская, д. 1		0101000020E6100000655419C6DD0E4340A4DE5339ED274C40
59650	1	10	506	15436	4772	\N	56.289859999999997	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Скобяное шоссе (ОДЦ <Октябрь>)		0101000020E6100000CCD1E3F7361143409335EA211A254C40
59654	1	10	506	15436	80000	\N	56.282279181482899	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, м-он Семхоз, Парковая, 16	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, дачный поселок Семхоз, Парковая улица, 18	0101000020E6100000EE224C512E0B43407EACE0B721244C40
59652	1	10	506	15436	4780	\N	56.274633999999999	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Московское шоссе, 22а	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Московское шоссе, 22а	0101000020E6100000E659492BBE0F4340512FF83427234C40
59651	1	10	506	15436	4780	\N	56.289040999999997	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Московское шоссе, 12а	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Московское шоссе, 12	0101000020E610000057CC086F0F104340001AA54BFF244C40
59630	1	10	506	15436	80175	\N	56.325637929558702	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Матросова, 2	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица Матросова, 2	0101000020E6100000BB287AE063124340DC2A8881AE294C40
59649	1	10	506	15436	4760	\N	56.292727999999997	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Клубная, 9	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Клубная улица, 9	0101000020E610000014967840D9124340CE4F711C78254C40
59638	1	10	506	15436	79968	\N	56.314434223255503	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, К.Либкнехта, 9	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица Карла Либкнехта, 5	0101000020E6100000D0D03FC1C51243400F60915F3F284C40
59642	1	10	506	15436	80213	\N	56.299933637884401	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Институтская, 10	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Институтская улица, 10	0101000020E6100000CE1C925A28134340AF7AC03C64264C40
59641	1	10	506	15436	4675	\N	56.302188000000001	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Железнодорожная, 29	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Железнодорожная улица, 29	0101000020E6100000A8AAD0402C134340309FAC18AE264C40
59634	1	10	506	15436	79969	\N	56.326482170345002	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Глинки, 2	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица Глинки	0101000020E6100000B2F50CE198134340C85D8429CA294C40
59619	1	10	506	15436	4414	\N	56.300750000000001	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, Вознесенская, 81	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Вознесенская улица, 81	0101000020E6100000A321E3512A114340D122DBF97E264C40
59620	1	10	506	15436	81044	\N	56.300631000000003	Школа № 7 Сергиев Посад, ул. Вознесенская, д. 81		0101000020E6100000AE6708C72C114340F7949C137B264C40
59623	1	10	506	15436	80133	\N	56.322944	Московская область, Сергиево-Посадский муниципальный район, городское поселение Сергиев Посад, 1-й Ударной Армии, 93		0101000020E6100000D34F38BBB51043403F389F3A56294C40
59669	1	10	506	18176	\N	\N	56.424430999999998	Московская область, Сергиево-Посадский муниципальный район, д. Семенково, Контора ООО < Ассортимент-Нива>, 5а	Россия, Московская область, Сергиево-Посадский район, деревня Семенково	0101000020E61000007B4E7ADFF82043404C3448C153364C40
59688	1	10	506	19172	\N	\N	56.390101647415001	Московская область, Сергиево-Посадский муниципальный район, с. Сватково, Школа, 91	Россия, Московская область, Сергиево-Посадский район, деревня Сватково	0101000020E61000005C397B67B41B4340560DC2DCEE314C40
59706	1	10	506	20114	\N	\N	56.645811000000002	Московская область, Сергиево-Посадский муниципальный район, д. Самотовино, Административное здание, 5		0101000020E610000095F0845E7FE84240D33252EFA9524C40
59676	1	10	506	18540	\N	\N	56.222185000000003	Московская область, Сергиево-Посадский муниципальный район, п. Репихово, Школа-сад №8, 3		0101000020E610000001A5A14621FF4240B554DE8E701C4C40
59685	1	10	506	17824	80295	\N	56.452027536038202	Московская область, Сергиево-Посадский муниципальный район, сельское поселение Реммаш, Институтская, 8		0101000020E6100000E15D2EE23B0B43402A70B20DDC394C40
59920	1	10	506	30164	71834	\N	56.332096999999997	поселок Северный, ул. 8 Марта (МОУ ССОШ), дом 14		0101000020E6100000A43330F2B2F24240C30C8D27822A4C40
59663	1	10	506	61913	80005	\N	56.412935475282502	Московская область, Сергиево-Посадский муниципальный район, городское поселение Пересвет, Строителей, 12в		0101000020E6100000F48B12F417164340D72FD80DDB344C40
59661	1	10	506	61913	80004	\N	56.415886421161701	Московская область, Сергиево-Посадский муниципальный район, городское поселение Пересвет, Советская, 1		0101000020E6100000EC3026FDBD164340A06EA0C03B354C40
59679	1	10	506	61983	\N	\N	56.2897008326471	Московская область, Сергиево-Посадский муниципальный район. п. ОРГРЭС, ОАО <Цент инжиниринга воздушных электролиний-фирма ОРГРЭС>	Россия, Московская область, Сергиево-Посадский район	0101000020E6100000DA91EA3BBFFE42402B4F20EC14254C40
59659	1	10	506	17718	\N	\N	56.321351	Московская область, Сергиево-Посадский муниципальный район, п. НИИРП, Конференцзал ОАО НИИРП		0101000020E610000075392520261D4340B9C4910722294C40
59682	1	10	506	18889	\N	\N	56.508673999999999	Московская область, Сергиево-Посадский муниципальный район, с. Муханово, Дом культуры с. Муханово, 1/3		0101000020E6100000EFFFE38409294340AA29C93A1C414C40
59697	1	10	506	19649	\N	\N	56.30509	Московская область, Сергиево-Посадский муниципальный район. п. Мостовик, Первомайская, 2	Россия, Московская область, Сергиево-Посадский район, село Мостовик	0101000020E610000054AD855968F74240172B6A300D274C40
59677	1	10	506	18621	\N	\N	56.247286000000003	Московская область, Сергиево-Посадский муниципальный район, д. Морозово, ФАП (фельдшерско-амбулаторный пункт), 34		0101000020E610000044882B67EF0643401C615111A71F4C40
59648	1	10	506	17159	\N	\N	56.383707000000001	Московская область, Сергиево-Посадский муниципальный район, д. Мишутино, Мишутинская средняя школа		0101000020E6100000F1F3DF83D70C4340861F9C4F1D314C40
59707	1	10	506	20207	\N	\N	56.498663999999998	Московская область, Сергиево-Посадский муниципальный район, д. Марьино, Дом культуры, 12		0101000020E61000006AFAEC80EBEC4240A5D8D138D43F4C40
59692	1	10	506	59563	\N	\N	56.258757212625	Московская область, Сергиево-Посадский муниципальный район, сельское поселение Лозовское, Дом культуры, 4б	Россия, Московская область, Сергиево-Посадский район, поселок Лоза	0101000020E6100000CB85CABF961B4340384E0AF31E214C40
59690	1	10	506	59563	\N	\N	56.259115509893299	Московская область, Сергиево-Посадский муниципальный район, сельское поселение Лозовское, Библиотека, 4д	Россия, Московская область, Сергиево-Посадский район, поселок Лоза	0101000020E61000001DE6CB0BB01B434067EF8CB62A214C40
59636	1	10	506	16553	\N	\N	56.348596999999998	Московская область, Сергиево-Посадский муниципальный район, п. Лесхоз, Помещение конторы Сергиево-Посадского ф-ла ФГУ <Мособллес>	Россия, Московская область, Сергиево-Посадский район, поселок Лесхоз	0101000020E6100000A52C431CEB144340EA3D95D39E2C4C40
59705	1	10	506	61979	\N	\N	56.595632678719397	Московская область, Сергиево-Посадский муниципальный район, д. Кузьмино, Школа, 11	Россия, Московская область, Сергиево-Посадский район, деревня Кузьмино	0101000020E610000011001C7BF6F642408DB5BFB33D4C4C40
59686	1	10	506	16736	\N	\N	56.434963334699802	Московская область, Сергиево-Посадский муниципальный район, п. Зеленая Дубрава, Клуб НИЛИЛ с клиникой, 3	Россия, Московская область, Сергиево-Посадский район, Краснозаводск, улица 50 лет Октября	0101000020E6100000D9960167291F43402BFC19DEAC374C40
59668	1	10	506	16736	4989	\N	56.438178999999998	Московская область, Сергиево-Посадский муниципальный район, городское поселение Краснозаводск, 1 Мая, 28	Россия, Московская область, Сергиево-Посадский район, Краснозаводск, улица 1 Мая, 28	0101000020E6100000779E78CE16204340A165DD3F16384C40
59667	1	10	506	16736	80267	\N	56.437651000000002	Московская область, Сергиево-Посадский муниципальный район, городское поселение Краснозаводск, Трудовые резервы, 4		0101000020E6100000ACADD85F761F4340E607AEF204384C40
59666	1	10	506	16736	80722	\N	56.437797779896201	Московская область, Сергиево-Посадский муниципальный район, городское поселение Краснозаводск, Новая, 2а	Россия, Московская область, Сергиево-Посадский район, Краснозаводск, Новая улица, 2	0101000020E6100000D5928E72301F43408A20CEC309384C40
59664	1	10	506	16736	80255	\N	56.437725999999998	Московская область, Сергиево-Посадский муниципальный район, городское поселение Краснозаводск, Горького, 4	Россия, Московская область, Сергиево-Посадский район, Краснозаводск, улица Горького, 4	0101000020E610000000CADFBDA31C4340F04DD36707384C40
59704	1	10	506	20012	80731	\N	56.551174000000003	Московская область, Сергиево-Посадский муниципальный район, с. Константиново, Октябрьская, 12		0101000020E6100000C5ABAC6D8A034340E833A0DE8C464C40
59694	1	10	506	19477	\N	\N	56.198335	Московская область, Сергиево-Посадский муниципальный район, д. Зубцово, Дом культуры, 49		0101000020E6100000BE310400C71243407A53910A63194C40
59693	1	10	506	19438	\N	\N	56.191684000000002	Московская область, Сергиево-Посадский муниципальный район, п. Заречный, Дом культуры, 19		0101000020E610000008E3A7716F0443404F95EF1989184C40
59675	1	10	506	18507	\N	\N	56.246326000000003	Московская область, Сергиево-Посадский муниципальный район, д. Жучки, Школа-сад №3, 10а	Россия, Московская область, Сергиево-Посадский район, деревня Жучки	0101000020E610000028EFE3688EF84240C713419C871F4C40
59658	1	10	506	17656	\N	\N	56.293738184299997	Московская область, Сергиево-Посадский муниципальный район, с. Глинково, Российский центр сельскохозяйственного консультирования, 77	Россия, Московская область, Сергиево-Посадский район, село Глинково	0101000020E6100000FD4B529962184340D5CBEF3499254C40
59696	1	10	506	52599	\N	\N	56.340809	Московская область, Сергиево-Посадский муниципальный район, сельское поселение Васильевское, Дом культуры, 21а		0101000020E6100000DAE21A9FC9F242405B971AA19F2B4C40
59687	1	10	506	19148	72082	\N	56.390799402135698	Московская область, Сергиево-Посадский муниципальный район, с. Бужаниново, Полевая, 3	Россия, Московская область, Сергиево-Посадский район, село Бужаниново	0101000020E61000006CB587BD502643409E279EB305324C40
57686	1	10	506	17897	80775	\N	56.269986000000003	деревня Ботово, микрорайон, 12		0101000020E6100000198F52094F3043405E30B8E68E224C40
59681	1	10	506	59529	\N	\N	56.498344720093101	Московская область, Сергиево-Посадский муниципальный район, городское поселение Богородское, Школа №28, 35	Россия, Московская область, Сергиево-Посадский район, поселок городского типа Богородское	0101000020E6100000473B6EF8DD1643400490DAC4C93F4C40
59680	1	10	506	59529	\N	\N	56.496920519056999	Московская область, Сергиево-Посадский муниципальный район, городское поселение Богородское, Школа №17, 9		0101000020E61000005AF2785A7E1643400AD9791B9B3F4C40
59689	1	10	506	59581	\N	\N	56.3393558230118	Московская область, Сергиево-Посадский муниципальный район, сельское поселение Березняковское, Дом культуры, 120	Россия, Московская область, Сергиево-Посадский район, деревня Березняки	0101000020E61000000D8AE6012C204340C7D97404702B4C40
59099	1	10	792	59543	\N	\N	55.605168440330999	п. Санатория им. Герцена, Дом культуры	Россия, Московская область, Рузский район, поселок санатория "имени Герцена"	0101000020E6100000D4997B48F84C4240F94A202576CD4B40
59584	1	10	792	45676	80920	\N	55.601650485970701	Московская область, Рузский муниципальный район, городское поселение Тучково, Студенческая, 1	Россия, Московская область, Рузский район, поселок городского типа Тучково	0101000020E61000006CEA3C2AFE3B4240B7D100DE02CD4B40
59587	1	10	792	45676	81035	\N	55.597200000000001	Здание железнодорожного вокзала, п. Тучково, ул. Привокзальная	Россия, Московская область, Рузский район, поселок городского типа Тучково	0101000020E610000055FB743C663C4240EA95B20C71CC4B40
59586	1	10	792	45676	72065	\N	55.602039234170903	Московская область, Рузский муниципальный район, городское поселение Тучково, Восточный микрорайн, 15	Россия, Московская область, Рузский район, поселок городского типа Тучково	0101000020E61000004BADF71BED3E424051F52B9D0FCD4B40
59585	1	10	792	45676	71776	\N	55.600265539064701	Московская область, Рузский муниципальный район, городское поселение Тучково, Восточный микрорайон, 24 А	Россия, Московская область, Рузский район, поселок городского типа Тучково	0101000020E6100000EBA86A82A83942404B732B84D5CC4B40
54671	1	10	792	48542	71770	\N	55.960835000000003	поселок Сычево, Нерудная, 6	Россия, Московская область, Рузский район, поселок городского типа Сычево	0101000020E6100000C45C52B5DD1C424014ED2AA4FCFA4B40
94625	1	10	792	15215	\N	\N	55.699269000000001	Здание МОУ "Сытьковская СОШ", д. Сытьково		0101000020E61000002041F163CC134240A60D87A581D94B40
59604	1	10	792	14993	\N	\N	55.619365999999999	д.Старониколаево, д.197	Россия, Московская область, Рузский район, деревня Старониколаево	0101000020E61000006DE179A9D82242408E20956247CF4B40
59607	1	10	792	15084	\N	\N	55.648471344266	"д.Старая Руза, здание МОУ ""Старорузская СОШ"""	Россия, Московская область, Рузский район, деревня Старая Руза	0101000020E610000007978E39CF2A4240C4B3041901D34B40
59606	1	10	792	15084	\N	\N	55.649442042258997	"Санаторий ""Дорохово"", здание клуба, д. Старая Руза"	Россия, Московская область, Рузский район, деревня Старая Руза	0101000020E610000091F2936A9F2A42400D535BEA20D34B40
59582	1	10	792	13943	81083	\N	55.705510267297903	Здание автовокзала, г. Руза, ул. Федеративная, д. 17	Россия, Московская область, Рузский район, Руза	0101000020E610000059897956D21842401F80D4264EDA4B40
59580	1	10	792	13943	81032	\N	55.701515999999998	Московская область, Рузский муниципальный район, городское поселение Руза, Щербакова, 33	Россия, Московская область, Рузский район, Руза	0101000020E6100000726BD26D8918424074CFBA46CBD94B40
59577	1	10	792	13943	79799	\N	55.704490417336203	Московская область, Рузский муниципальный район, городское поселение Руза, Социалистическая, 63	Россия, Московская область, Рузский район, Руза	0101000020E6100000A67F492A531A4240F52D73BA2CDA4B40
59575	1	10	792	13943	79964	\N	55.701515999999998	Московская область, Рузский муниципальный район, городское поселение Руза, Микрорайон, 19	Россия, Московская область, Рузский район, Руза	0101000020E6100000726BD26D8918424074CFBA46CBD94B40
59573	1	10	792	13943	80048	\N	55.701515999999998	Московская область, Рузский муниципальный район, городское поселение Руза, Волоколамское шоссе, 4	Россия, Московская область, Рузский район, Руза	0101000020E6100000726BD26D8918424074CFBA46CBD94B40
59611	1	10	792	61986	\N	\N	55.723098	д.Орешки, д.90		0101000020E61000002C2CB81FF02C4240C9E6AA798EDC4B40
94624	1	10	792	14324	\N	\N	55.774051	Здание музыкальной школы, с.п. Волковское, д. Нововолково, ул. Центральная, д. 7	Россия, Московская область, Рузский район, деревня Нововолково	0101000020E61000008E03AF963B234240D237691A14E34B40
59603	1	10	792	14939	\N	\N	55.577694000000001	д.Лыщиково, д.200		0101000020E61000007A1D71C806284240378C82E0F1C94B40
59600	1	10	792	14801	\N	\N	55.473857000000002	п.Космодемьянский, д.17		0101000020E6100000C77F8120402E424087FD9E58A7BC4B40
59610	1	10	792	15268	71910	\N	55.667091999999997	п.Колюбакино, Красная Горка, д.1		0101000020E6100000382F4E7CB54342402CB6494563D54B40
59592	1	10	792	45766	\N	\N	55.918565000000001	д.Ивойлово, 8 А		0101000020E6100000AD68739CDB2242400820B58993F54B40
94598	1	10	792	14842	\N	\N	55.552021000000003	Здание Дома Культуры, п. Дорохово, ул. Стеклозаводская, д. 21	Россия, Московская область, Рузский район, поселок Дорохово	0101000020E61000000F441669E22F424045DAC69FA8C64B40
59605	1	10	792	14842	72346	\N	55.552021000000003	здание железнодорожного вокзала, п. Дорохово, ул. Невкипелого, д. 1 п.Кожино, д. 8		0101000020E61000000F441669E22F424045DAC69FA8C64B40
59601	1	10	792	14842	72346	\N	55.552823791069002	п.Дорохово, Невкипелого, д.49	Россия, Московская область, Рузский район, поселок Дорохово	0101000020E61000005DFA97A4322F4240D238D4EFC2C64B40
59608	1	10	792	15175	\N	\N	55.662714999999999	д.Воробьево, д.22		0101000020E6100000D2FE0758AB224240C9C859D8D3D44B40
59594	1	10	792	14522	80727	\N	55.907854	п.Брикет, Центральная, 1		0101000020E6100000C39FE1CD1A3842407AC5538F34F44B40
59597	1	10	792	14646	\N	\N	55.794263999999998	п.Беляная Гора, д.4		0101000020E610000045D5AF743E0C4240F0315871AAE54B40
59541	1	10	443	12029	71824	\N	55.504109	"Московская область, Раменский муниципальный район, деревня Юрово, Улица Мира, помещение Дома культуры ""Юровский"""		0101000020E6100000292504ABEA2F4340444FCAA486C04B40
59551	1	10	443	12448	\N	\N	55.587691999999997	Московская область, Раменский муниципальный район,поселок Электроизолятор, Помещение администрации, Дом 50	Россия, Московская область, Раменский район, поселок Электроизолятор	0101000020E610000095D39E9273404340770FD07D39CB4B40
59550	1	10	443	12448	\N	\N	55.587691999999997	"Московская область, Раменский муниципальный район, поселок Электроизолятор, Помещение ОАО ""Гжельская УГ"", Дом 55"		0101000020E610000095D39E9273404340770FD07D39CB4B40
59483	1	10	443	9244	80999	\N	55.631282670938297	Московская область, Раменский муниципальный район,деревня Хрипань, Улица Школьная, Помещение основной школы	Россия, Московская область, Раменский район, деревня Хрипань	0101000020E6100000B5E0455F41144340A9C29FE1CDD04B40
59543	1	10	443	12118	\N	\N	55.579546000000001	Московская область, Раменский муниципальный район,деревня Фенино, Помещение Дома культуры		0101000020E61000000667F0F78B334340894336902ECA4B40
59526	1	10	443	11317	\N	\N	55.349445000000003	Московская область, Раменский муниципальный район, село Ульянино, дом 26	Россия, Московская область, Раменский район, село Ульянино	0101000020E610000049861C5BCF36434018601F9DBAAC4B40
94618	1	10	443	9807	67078	\N	55.634003999999997	Раменский  район, пос.Удельная, ул. Солнцева, д.35 - в помещении дворца культуры "Победа".		0101000020E6100000AC5626FC520543403FC4060B27D14B40
59498	1	10	443	9807	79790	\N	55.638854535908699	Московская область, Раменский муниципальный район,поселок Удельная, Улица Первомайская, Дом 15	Россия, Московская область, Раменский район, поселок Удельная, Первомайская улица	0101000020E6100000C6C4E6E3DA0643406BF12900C6D14B40
59497	1	10	443	9807	80128	\N	55.634893354030503	Московская область, Раменский муниципальный район,поселок Удельная, Улица Октябрьская, Дом 1		0101000020E610000059349D9D0C064340CBBA7F2C44D14B40
59496	1	10	443	9807	80695	\N	55.627569999999999	Московская область, Раменский муниципальный район,поселок Удельная, Улица Горячева, Дом 38		0101000020E6100000E7A6CD380D054340B1F9B83654D04B40
59516	1	10	443	10867	\N	\N	55.479424000000002	Московская область, Раменский муниципальный район,деревня Тимонино, Помещение бывшей администрации Тимонинского сельского округа		0101000020E61000001CCEFC6A0E184340717500C45DBD4B40
59513	1	10	443	10697	\N	\N	55.561338999999997	Московская область, Раменский муниципальный район,поселок им. Тельмана, Помещение Дома культуры	Россия, Московская область, Раменский район, поселок Тельмана	0101000020E610000085B01A4B58054340137CD3F4D9C74B40
59493	1	10	443	9695	\N	\N	55.675387000000001	Московская область, Раменский муниципальный район,село Строкино, Помещение Власовской общеобразовательной средней школы №13	Россия, Московская область, Раменский район, село Строкино	0101000020E6100000197442E8A01743406092CA1473D64B40
59515	1	10	443	10818	\N	\N	55.499065999999999	Московская область, Раменский муниципальный район,село Софьино, Помещение Софьинской общеобразовательной средней школы	Россия, Московская область, Раменский район, село Софьино	0101000020E6100000A7785C548B164340D4450A65E1BF4B40
59536	1	10	443	59554	\N	\N	55.542846352890898	"Московская область, Раменский муниципальный район, поселок совхоза ""Раменское"", Помещение дома культуры ОАО ""Раменское"""	Россия, Московская область, Раменский район, поселок Совхоза Раменское	0101000020E61000002992AF0452264340D8614CFA7BC54B40
59521	1	10	443	11065	\N	\N	55.341146999999999	Московская область, Раменский муниципальный район, поселок Рылеево, Помещение Ганусовской общеобразовательной средней школы		0101000020E61000004AB89047700D4340731074B4AAAB4B40
59529	1	10	443	11457	\N	\N	55.399096	Московская область, Раменский муниципальный район, село Рыболово, Помещение Дома культуры		0101000020E610000089B14CBF4430434072FBE59315B34B40
38627	1	6	1067	20605	35290	\N	54.54325	Поселок Ферзиково, Красноцветова, 1		0101000020E6100000041DAD6A495F4240A8C64B3789454B40
59537	1	10	443	11828	80957	\N	55.480137999999997	Московская область, Раменский муниципальный район, деревня Рыбаки, Улица Садовая, Дом 1-а		0101000020E6100000433A3C84F11D43408EC8772975BD4B40
59492	1	10	443	9648	72061	\N	55.650357999999997	Московская область, Раменский муниципальный район,поселок Родники, Улица Трудовая, Дом 3		0101000020E6100000DB15FA6019094340925852EE3ED34B40
59491	1	10	443	61910	79981	\N	55.650292898455199	Московская область, Раменский муниципальный район,поселок Родниик, Улица Центральная, Дом 3		0101000020E61000001C075E2D77084340ABE80FCD3CD34B40
59549	1	10	443	12365	\N	\N	55.598868000000003	"Московская область, Раменский муниципальный район, село Речицы, Улица Центральная, Помещение Дома культуры ""Гжельский"""	Россия, Московская область, Раменский район, село Речицы	0101000020E610000083C30B22523B43407B4FE5B4A7CC4B40
59548	1	10	443	12365	72064	\N	55.598868000000003	Московская область, Раменский муниципальный район, село Речицы, Улица Центральная, Помещение администрации		0101000020E610000083C30B22523B43407B4FE5B4A7CC4B40
59476	1	10	443	8168	2422	\N	55.569758999999998	Московская область, Раменский муниципальный район, город Раменское, Улица Гурьева, Дом 23	Россия, Московская область, Раменский район, Раменское, улица Гурьева, 23	0101000020E61000000CCB9F6F0B1E434003CDE7DCEDC84B40
59467	1	10	443	8168	71887	\N	55.572228984135897	Московская область, Раменский муниципальный район, поселок Красный Октябрь, Помещение по работе с населением залинейной части города, Дом 43	Россия, Московская область, Раменский район, Раменское, Десантная улица, 49	0101000020E6100000C7681D554D1A43405169C4CC3EC94B40
59464	1	10	443	8168	80059	\N	55.575713999999998	Московская область, Раменский муниципальный район, город Раменское, Улица Чугунова, Дом 10-а		0101000020E6100000C4EDD0B0181B4340B7EC10FFB0C94B40
59468	1	10	443	8168	79953	\N	55.564012819278602	Московская область, Раменский муниципальный район, город Раменское, Улица Серова, Дом 18	Россия, Московская область, Раменский район, Раменское, улица Серова	0101000020E61000000B7BDAE1AF1943406AC2F69331C84B40
59474	1	10	443	8168	80683	\N	55.567993000000001	Московская область, Раменский муниципальный район, город Раменское, Улица Михалевича, Дом 2		0101000020E6100000DB334B02D41C4340B0AD9FFEB3C84B40
59470	1	10	443	8168	80683	\N	55.562570999999998	Московская область, Раменский муниципальный район, город Раменское, Улица Михалевича, Дом 58		0101000020E6100000A27F828B151F4340C956975302C84B40
59477	1	10	443	8168	80686	\N	55.570878999999998	Московская область, Раменский муниципальный район, город Раменское, Улица Красноармейская, Дом 22		0101000020E6100000204432E4D81E4340917C259012C94B40
59461	1	10	443	8168	2235	\N	55.590150000000001	Московская область, Раменский муниципальный район, город Раменское, Улица Коммунистическая, Дом 30/1	Россия, Московская область, Раменский район, Раменское, Коммунистическая улица, 30	0101000020E61000009F7422C1541B434001DE02098ACB4B40
59460	1	10	443	8168	80090	\N	55.590150000000001	Московская область, Раменский муниципальный район, город Раменское, Коммунистическая, Дом 30/1		0101000020E61000009F7422C1541B434001DE02098ACB4B40
59473	1	10	443	8168	80690	\N	55.564749999999997	Московская область, Раменский муниципальный район, город Раменское, Коминтерна, Красный уголок ОАО РПЗ, Дом 9		0101000020E6100000739EB12FD91E43403F355EBA49C84B40
59479	1	10	443	8168	79950	\N	55.573922000000003	Московская область, Раменский муниципальный район, город Раменское, Улица Интернациональная, Дом 20		0101000020E6100000C87BD5CA841F43403B3AAE4676C94B40
59466	1	10	443	8168	80684	\N	55.573906999999998	Московская область, Раменский муниципальный район, город Раменское, Улица Воровского, Дом 4		0101000020E61000005C3D27BD6F1A434005F9D9C875C94B40
59514	1	10	443	61964	\N	\N	55.475444000000003	Московская область, Раменский муниципальный район,поселок РАОС, Помещение Дома культуры		0101000020E610000031D120054F2343402B8A5759DBBC4B40
59014	1	10	443	48034	80985	\N	55.367120999999997	д.Починки, Советская, 20 (Библиотека)		0101000020E6100000A2B8E34D7E0F4340605628D2FDAE4B40
59542	1	10	443	12067	80960	\N	55.539976000000003	Московская область, Раменский муниципальный район, деревня Пласкинино, Улица Центральная, Помещение ФАПа		0101000020E6100000F6251B0FB6364340FD4FFEEE1DC54B40
56701	1	10	443	47785	\N	\N	55.468494	п/о Петровское, д.18	Россия, Московская область, Раменский район, деревня Петровское	0101000020E6100000B79BE09BA62B4340A52F849CF7BB4B40
59520	1	10	443	11015	\N	\N	55.388558000000003	"Московская область, Раменский муниципальный район, деревня Панино, Дом культуры ""Лель"""		0101000020E6100000957EC2D9AD174340B24CBF44BCB14B40
59510	1	10	443	10584	2997	\N	55.587789000000001	Московская область, Раменский муниципальный район,деревня Островцы, Улица Центральная, Дом 24	Россия, Московская область, Раменский район, деревня Островцы, Центральная улица, 24	0101000020E6100000C7A01342070143406AF981AB3CCB4B40
59511	1	10	443	10584	3015	\N	55.599023297106399	Московская область, Раменский муниципальный район,деревня Островцы, Улица Подмосковная, Помещение средней школы	Россия, Московская область, Раменский район, деревня Островцы, Подмосковная улица	0101000020E61000004910AE8042FD4240A24621C9ACCC4B40
59508	1	10	443	61974	\N	\N	55.621363379671998	Московская область, Раменский муниципальный район,поселок Опытное поле, Помещение клуба, Дом 8	Россия, Московская область, Раменский район	0101000020E6100000645C717154024340E4F8A1D288CF4B40
59534	1	10	443	11666	74102	\N	55.555987999999999	Московская область, Раменский муниципальный район, село Новое, Ленинская, Помещение основной школы		0101000020E6100000B950F9D7F2184340F67B629D2AC74B40
59530	1	10	443	11518	\N	\N	55.420316	Московская область, Раменский муниципальный район, деревня Никулино, Помещение Никулинской  школы		0101000020E6100000EF92382BA22E434026FE28EACCB54B40
59522	1	10	443	11137	80726	\N	55.282209999999999	Московская область, Раменский муниципальный район, село Никоновское, улица Центральная, дом 74		0101000020E6100000179CC1DF2F144340554D10751FA44B40
59525	1	10	443	11278	\N	\N	55.2975282739026	Московская область, Раменский муниципальный район, село Никитское, помещение общеобразовательной средней школы	Россия, Московская область, Раменский район, село Никитское	0101000020E6100000018750A5663B434078D2C26515A64B40
59512	1	10	443	10676	\N	\N	55.540221000000003	Московская область, Раменский муниципальный район,деревня Нижнее Мячково, Помещение Дома культуры		0101000020E61000001DAED51EF6FC424064CE33F625C54B40
59528	1	10	443	11401	\N	\N	55.386676000000001	Московская область, Раменский муниципальный район, деревня Морозово, Помещение Рыболовской средней школы		0101000020E610000041D47D00522D4340F51263997EB14B40
59545	1	10	443	12203	\N	\N	55.645456000000003	Московская область, Раменский муниципальный район, деревня Минино, Помещение Мининского ФАПа		0101000020E6100000A62A6D718D334340E5805D4D9ED24B40
59552	1	10	443	12585	\N	\N	55.614150000000002	"Московская область, Раменский муниципальный район,поселок Кузяевского фарфорового завода, Помещение дома культуры ""Кузяевский"""	Россия, Московская область, Раменский район, поселок Кузяевского фарфорового завода	0101000020E6100000D4D4B2B5BE444340516B9A779CCE4B40
59532	1	10	443	11598	71876	\N	55.498614735774503	Московская область, Раменский муниципальный район, деревня Кузнецово, Улица Центральная, Помещение администрации	Россия, Московская область, Раменский район, деревня Кузнецово	0101000020E610000038876BB5872B4340C425C79DD2BF4B40
59484	1	10	443	9286	72057	\N	55.598190874179203	Московская область, Раменский муниципальный район,поселок Кратово, Улица Мира, Помещение Дома культуры	Россия, Московская область, Раменский район, поселок городского типа Кратово, улица Горького	0101000020E61000003C4CFBE6FE1443407AE1CE8591CC4B40
59486	1	10	443	9286	80853	\N	55.590032999999998	Московская область, Раменский муниципальный район,поселок Кратово, Улица Карла Маркса, Дом 21		0101000020E61000007B82C476F7144340C7478B3386CB4B40
59505	1	10	443	61905	79962	\N	55.592388953793197	Московская область, Раменский муниципальный район, поселок Кратово, Улица Центральная, Дом 5	Россия, Московская область, Раменский район, поселок городского типа Кратово, улица Карла Маркса	0101000020E61000003FAA61BF271443404CC11A67D3CB4B40
59518	1	10	443	10884	\N	\N	55.4863428026704	"Московская область, Раменский муниципальный район, село Константиново, Помещение Дома культуры ""Константиновский"""	Россия, Московская область, Раменский район, поселок Константиново	0101000020E6100000E0D6DD3CD5FD4240BBD1C77C40BE4B40
59517	1	10	443	10884	\N	\N	55.487899694253301	"Московская область, Раменский муниципальный район, село Константиново, Помещение дома культуры ""Константиновский"""		0101000020E61000001EC2F869DCFD4240F5DBD78173BE4B40
59524	1	10	443	11203	79796	\N	55.547138784965803	Московская область, Раменский муниципальный район,  деревня Клишева, Улица Школьная, Дом 90	Россия, Московская область, Раменский район, деревня Клишева	0101000020E6100000EFCB99ED0A1F4340DEAE97A608C64B40
59489	1	10	443	61872	80697	\N	55.622450999999998	Московская область, Раменский муниципальный район,поселок Ильинский, Улица Первомайская, Дом 15		0101000020E6100000444E5FCFD70C4340662E7079ACCF4B40
59488	1	10	443	61872	79822	\N	55.625938580582698	Московская область, Раменский муниципальный район,поселок Ильинский, Улица Октябрьская, Дом 60		0101000020E6100000B29DEFA7C60F43403E25E7C41ED04B40
59504	1	10	443	9407	2916	\N	55.611068000000003	Московская область, Раменский муниципальный район,поселок Ильинский, Улица Опаленной юности, Дом 23	Россия, Московская область, Раменский район, поселок городского типа Ильинский, улица Опаленной Юности, 23	0101000020E6100000A8FE4124430C4340EAD0E97937CE4B40
59487	1	10	443	9407	80685	\N	55.617561000000002	Московская область, Раменский муниципальный район,поселок Ильинский, Улица Ленинская, Дом 38		0101000020E61000004D49D6E1E80C43407D24253D0CCF4B40
59482	1	10	443	15908	\N	\N	55.656572329502403	Раменский  район, деревня Захарова - в помещении Дома культуры	Россия, Московская область, Раменский район, деревня Захарово	0101000020E61000005C1C959BA827434012BC218D0AD44B40
59523	1	10	443	11146	\N	\N	55.344147	"Московская область, Раменский муниципальный район, село Заворово, Дом культуры ""Заря"""	Россия, Московская область, Раменский район, село Заворово	0101000020E6100000AAEE91CD551D43401D0247020DAC4B40
59535	1	10	443	11749	\N	\N	55.545935	Московская область, Раменский муниципальный район, деревня Заболотье, Помещение СПТУ-93	Россия, Московская область, Раменский район, деревня Заболотье	0101000020E61000006729594E42194340F25EB532E1C54B40
58088	1	10	443	61876	79842	\N	55.579135120390397	Московская область, городской округ Жуковский, Кирова, 4	Россия, Московская область, Раменский район, поселок городского типа Кратово, улица Кирова, 4	0101000020E61000002E55698B6B124340077C7E1821CA4B40
59553	1	10	443	12590	\N	\N	55.577866999999998	Московская область, Раменский муниципальный район, деревня Антоново, Помещение Карповской общеоюразовательной школы		0101000020E61000003067B62BF44943400438BD8BF7C94B40
59538	1	10	443	11852	\N	\N	55.542003000000001	Московская область, Раменский муниципальный район, поселок Дубовая Роща, Помещение общеобразовательной средней школы №22	Россия, Московская область, Раменский район, поселок Дубовая Роща	0101000020E61000005F09A4C4AE274340BDAAB35A60C54B40
59540	1	10	443	11852	80729	\N	55.541271490852303	Московская область, Раменский муниципальный район, поселок Дубовая Роща, Улица Спортивная, Строение 1а	Россия, Московская область, Раменский район, поселок Совхоза Сафоновский, Спортивная улица	0101000020E6100000E4D87A8670284340F9A23D5E48C54B40
59533	1	10	443	11649	71835	\N	55.509175999999997	Московская область, Раменский муниципальный район, поселок Дружба, Улица Ленина, Помещение средней школы №11		0101000020E6100000F06E6589CE2A43403CF4DDAD2CC14B40
59480	1	10	443	9127	74197	\N	55.5798604517556	Московская область, Раменский муниципальный район, деревня Дергаево, Улица Октябрьская, Помещение средней школы №23	Россия, Московская область, Раменский район, деревня Дергаево, Октябрьская улица	0101000020E6100000815EB8736120434018213CDA38CA4B40
59519	1	10	443	11009	\N	\N	55.440437000000003	Московская область, Раменский муниципальный район,поселок Денежниково, Помещение Ильинской общеобразовательной школы №17		0101000020E6100000C408E1D1C60D43406479573D60B84B40
59481	1	10	443	9155	\N	\N	55.610595000000004	Московская область, Раменский муниципальный район,деревня Дементьево, Помещение Дома культуры	Россия, Московская область, Раменский район, деревня Дементьево	0101000020E61000003D9B559FAB254340F20C1AFA27CE4B40
59547	1	10	443	12288	\N	\N	55.61571	"Московская область, Раменский муниципальный район, поселок Гжельского завода стройматериалов, Помещение Дома культуры ""Строитель"", Дом 1"		0101000020E6100000A04E797423364340FBE8D495CFCE4B40
59546	1	10	443	12288	\N	\N	55.61571	"Московская область, Раменский муниципальный район,поселок Гжельского кирпичного завода, Помещение ОАО ""Гжельская УК"", Дом 7"		0101000020E6100000A04E797423364340FBE8D495CFCE4B40
59544	1	10	443	12200	\N	\N	55.608170000000001	Московская область, Раменский муниципальный район, село Гжель, Улица Новая, Помещение средней школы	Россия, Московская область, Раменский район, поселок Гжель	0101000020E61000003D0D18247D3243404434BA83D8CD4B40
59539	1	10	443	11917	\N	\N	55.557180000000002	Московская область, Раменский муниципальный район, поселок Гжелка, Помещение Дома культуры	Россия, Московская область, Раменский район, поселок Гжелка	0101000020E6100000284696CCB12843401EFE9AAC51C74B40
59494	1	10	443	9763	72384	\N	55.654131999999997	Московская область, Раменский муниципальный район,деревня Вялки, Улица Кооперативная, Дом 52		0101000020E61000001D1CEC4D0C0B43402FA2ED98BAD34B40
59527	1	10	443	11353	\N	\N	55.401840999999997	Московская область, Раменский муниципальный район, деревня Вохринка, Помещение Вохринского Дома культуры		0101000020E6100000CC9A58E02B2843409198A0866FB34B40
59509	1	10	443	10504	81016	\N	55.547865999999999	Московская область, Раменский муниципальный район,село Верхнее Мячково, улица Центральная, помещение ФАП-а		0101000020E61000009DF529C764FD4240904B1C7920C64B40
60009	1	10	443	2489	635	\N	55.630268000000001	Московская область, городской округ Химки, мкр. Подрезково, Школьная, 2	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 2	0101000020E610000053B29C84D209434090DB2F9FACD04B40
59353	1	10	443	2489	635	\N	55.634242	п. Быково, Школьная, д.9	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 9	0101000020E61000008811C2A38D094340F4DF83D72ED14B40
58100	1	10	443	2489	635	\N	55.630628999999999	Московская область, городской округ Жуковский, Школьная, 6	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 6	0101000020E6100000AA108FC4CB09434060747973B8D04B40
57973	1	10	443	2489	635	\N	55.633642999999999	Московская область, городской округ Дубна, Школьная, 3	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 3	0101000020E6100000F165A208A90943406F2BBD361BD14B40
59499	1	10	443	2489	79956	\N	55.643118999999999	Московская область, Раменский муниципальный район,поселок Быково, Улица Чапаева, Дом 2		0101000020E6100000D7A3703D0A0B4340D63730B951D24B40
59500	1	10	443	2489	79791	\N	55.6300708161301	Московская область, Раменский муниципальный район,поселок Быково, Улица Станционная, Дом 9	Россия, Московская область, Раменский район, поселок городского типа Быково, Станционная улица	0101000020E61000000DFB3DB14E0943403A94A12AA6D04B40
59502	1	10	443	61874	79831	\N	55.622559853185301	Московская область, Раменский муниципальный район,поселок Быково, Улица Чкалова, Дом 2		0101000020E6100000EE5A423EE80943401DE6CB0BB0CF4B40
59501	1	10	443	61874	79830	\N	55.623938507938	Московская область, Раменский муниципальный район.поселок Быково, Улица Советская, Дом 21		0101000020E610000044F7AC6BB408434077D9AF3BDDCF4B40
59506	1	10	443	10368	71808	\N	55.610895304982598	Московская область, Раменский муниципальный район,село Быково, Улица Колхозная, Помещение основной школы  №16	Россия, Московская область, Раменский район, село Быково	0101000020E61000004E7B4ACE890743401C25AFCE31CE4B40
59531	1	10	443	11529	80937	\N	55.455137000000001	Московская область, Раменский муниципальный район, деревня Бояркино, улица Центральная, Помещение ФАПа		0101000020E6100000D9960167292743408B19E1ED41BA4B40
58636	1	10	443	62048	\N	\N	55.675330092383398	д. Аксеново, 227	Россия, Московская область, Раменский район, деревня Аксеново	0101000020E6100000726E13EE951F4340FC00A43671D64B40
59441	1	10	367	61949	80682	\N	55.970156000000003	Московская область, Пушкинский муниципальный район, городское поселение Черкизово, Главная, 99		0101000020E610000040F850A225E54240540262122EFC4B40
59432	1	10	367	61901	79954	\N	56.1397006397466	Московская область, Пушкинский муниципальный район, городское поселение Софрино, Школьная, 3	Россия, Московская область, Пушкинский район, поселок городского типа Софрино	0101000020E61000000E4E44BFB6F64240F81BEDB8E1114C40
59425	1	10	367	59472	71507	\N	56.063443999999997	Московская область, Пушкинский муниципальный район, городское поселение Правдинский, Степаньковское шоссе, 31а		0101000020E6100000E6046D72F8EC42404F90D8EE1E084C40
59440	1	10	367	1881	80990	\N	55.9679389108992	Московская область, Пушкинский муниципальный район, городское поселение Черкизово, Школьная, 6/6	Россия, Московская область, Пушкинский район, поселок городского типа Черкизово, Школьная улица	0101000020E61000007C293C6876E74240F0C2D66CE5FB4B40
60012	1	10	367	1881	679	\N	55.96799	Московская область, городской округ Химки, Речная, 20	Россия, Московская область, Пушкинский район, поселок городского типа Черкизово, Речная улица, 20	0101000020E6100000E7525C55F6E54240726DA818E7FB4B40
59417	1	10	367	1881	679	\N	55.967672999999998	Московская область, Пушкинский муниципальный район, городское поселение Ашукино, ул.Речная, 16а	Россия, Московская область, Пушкинский район, поселок городского типа Черкизово, Речная улица, 16	0101000020E61000003D9AEAC9FCE54240711C78B5DCFB4B40
94615	1	10	367	7840	\N	\N	56.082607000000003	Адрес помещения для голосования: Московская область, Пушкинский муниципальный район, с.Царево, 1б (Школа), Адрес УИК: Царево, (Администрация), 1-а		0101000020E61000005B3FFD67CD0B4340D9B5BDDD920A4C40
59443	1	10	367	7411	\N	\N	56.089793999999998	Московская область, Пушкинский муниципальный район, сельское поселение Ельдигинское, Тишково, 7		0101000020E6100000546F0D6C95DE424042B0AA5E7E0B4C40
94612	1	10	367	60276	\N	\N	55.962938342989602	Адрес УИК и помещения для голосования: Московская область, Пушкинский муниципальный район, сельское поселение Тарасовское, Учебный центр, в/ч 43431	Россия, Московская область, Пушкинский район, село Тарасовка	0101000020E6100000ACFE08C380E94240AF09698D41FB4B40
94613	1	10	367	60276	74282	\N	55.961060705890603	Адрес УИК и помещения для голосования: Московская область, Пушкинский муниципальный район, сельское поселение Тарасовское, Б.Тарасовская (РИАМА), 108	Россия, Московская область, Пушкинский район, село Тарасовка	0101000020E61000003DB7D09508E84240043BFE0B04FB4B40
59448	1	10	367	60276	74282	\N	55.961381550600997	Московская область, Пушкинский муниципальный район, сельское поселение Тарасовское, Б.Тарасовская, 26	Россия, Московская область, Пушкинский район, село Тарасовка, Вокзальная улица	0101000020E61000005E126745D4E84240467BBC900EFB4B40
59444	1	10	367	7417	\N	\N	56.066021999999997	Московская область, Пушкинский муниципальный район, сельское поселение Ельдигинское, Степаньково, ДК	Россия, Московская область, Пушкинский район, деревня Степаньково	0101000020E61000001F813FFCFCE742408368AD6873084C40
94610	1	10	367	59551	\N	\N	56.1452113105561	адрес помещения для голосования:Московская область, Пушкинский муниципальный район, Софрино-1, Майская школа, Адрес УИК: солдатский клуб, 1	Россия, Московская область, Пушкинский район, поселок городского типа Софрино	0101000020E610000007D0EFFB37F942407E02284696124C40
59434	1	10	367	59138	71768	\N	56.138644742847099	Московская область, Пушкинский муниципальный район, городское поселение Софрино, Тютчева, 18		0101000020E610000029E9616875F6424080608E1EBF114C40
59430	1	10	367	59138	78635	\N	56.130985000000003	Московская область, Пушкинский муниципальный район, городское поселение Софрино, Крайняя, 2	Россия, Московская область, Пушкинский район, поселок городского типа Софрино	0101000020E61000003621AD31E8F442401FA2D11DC4104C40
59435	1	10	367	61906	80992	\N	56.143776534800203	Московская область, Пушкинский муниципальный район, городское поселение Софрино, Талицы, 23	Россия, Московская область, Пушкинский район, поселок городского типа Софрино	0101000020E610000027C0B0FCF9F842406075E44867124C40
59431	1	10	367	61906	79963	\N	56.140565946182299	Московская область, Пушкинский муниципальный район, городское поселение Софрино, Полевая, 5	Россия, Московская область, Пушкинский район, поселок городского типа Софрино	0101000020E610000040D9942BBCF74240FB761211FE114C40
59436	1	10	367	61906	80998	\N	56.139460999999997	Московская область, Пушкинский муниципальный район, городское поселение Софрино, Дальняя, клуб Дальний		0101000020E6100000AA9ECC3FFAF64240A208A9DBD9114C40
59144	1	10	367	4327	15594	\N	56.044849999999997	Московская область, городской округ Орехово-Зуево, Коминтерна, 39	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, улица Коминтерна, 39	0101000020E6100000D2C2651536EB4240E09C11A5BD054C40
58161	1	10	367	4327	15594	\N	56.045267000000003	Московская область, городской округ Ивантеевка, Коминтерна, 2а	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, улица Коминтерна, 2	0101000020E6100000DA5548F949ED4240454B1E4FCB054C40
59397	1	10	367	4327	1371	\N	55.993872000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Арманд, 15	Россия, Московская область, Пушкинский район, Пушкино, улица Инессы Арманд, 13	0101000020E61000004B74965984EE42407F349C3237FF4B40
59404	1	10	367	4327	80898	\N	56.036164999999997	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Заветы Ильича, пр.Дзержинского, 2		0101000020E6100000D0F0660DDEED42404221020EA1044C40
59399	1	10	367	4327	1405	\N	55.999539434056999	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Ярославское шоссе, 170а	Россия, Московская область, Пушкинский район, Пушкино	0101000020E6100000DD5D6743FEEF4240CC09DAE4F0FF4B40
59407	1	10	367	4327	79976	\N	56.005437518175398	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Мамонтовка, ул. Школьная, 5	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Мамонтовка, Школьная улица	0101000020E61000002FFA0AD28CE74240EC134031B2004C40
59393	1	10	367	4327	80505	\N	56.007945999999997	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Чехова, 8		0101000020E61000000874266DAAEC42402711E15F04014C40
59398	1	10	367	4327	15735	\N	55.985321999999996	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, фабричная, 7	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Клязьма, Фабричная улица, 7	0101000020E6100000F8AA9509BFEC4240C00303081FFE4B40
59412	1	10	367	4327	80666	\N	55.974735000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Клязьма, ул Сологубовская, 3		0101000020E6100000016E162F16EA42401FA2D11DC4FC4B40
59415	1	10	367	4327	15826	\N	55.980840000000001	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Звягино, ул.Советская, 25	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Звягино, Советская улица, 25	0101000020E610000003965CC5E2E74240E84D452A8CFD4B40
59427	1	10	367	4327	15885	\N	56.033504999999998	Московская область, Пушкинский муниципальный район, городское поселение Правдинский, Советская, 1а	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, Советская улица, 1	0101000020E6100000359BC76130ED424051A04FE449044C40
59411	1	10	367	4327	15799	\N	56.004111000000002	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Мамонтовка, ул. Рабочая, 1	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Мамонтовка, Рабочая улица, 1	0101000020E6100000AD855968E7E64240E54691B586004C40
59392	1	10	367	4327	1284	\N	56.009376000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Писаревский проезд, 5	Россия, Московская область, Пушкинский район, Пушкино, Писаревский проезд, 5	0101000020E6100000AE9FFEB3E6EB424004AF963B33014C40
59408	1	10	367	4327	80724	\N	55.991681999999997	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Мамонтовка, ул. Октябрьская, 23	Россия, Московская область, Пушкинский район, Пушкино, Октябрьская улица, 23	0101000020E61000009BAF928FDDEB424014048F6FEFFE4B40
59390	1	10	367	4327	80500	\N	56.013242565159899	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Некрасова, 3	Россия, Московская область, Пушкинский район, Пушкино, улица Некрасова, 3	0101000020E6100000A5BF97C283EC424052F355F2B1014C40
59413	1	10	367	4327	15811	\N	55.983201999999999	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Клязьма, ул. Лермонтовская, 25	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Клязьма, Лермонтовская улица, 25	0101000020E610000048A98427F4EA42404FAE2990D9FD4B40
59410	1	10	367	4327	80689	\N	55.995694999999998	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Мамонтовка, ул. Кузнецкий мост, 1		0101000020E61000009AEAC9FCA3E9424036E50AEF72FF4B40
59405	1	10	367	4327	80883	\N	56.045554000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, м-н Заветы Ильича,  ул.Коминтерна, 16/22	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, улица Коминтерна, 16	0101000020E61000000664AF777FEC4240DB19A6B6D4054C40
59387	1	10	367	4327	79955	\N	56.0146370624254	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Железнодорожная, 14		0101000020E610000074EFE192E3EA4240E1270EA0DF014C40
59385	1	10	367	4327	79947	\N	56.009134000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Боголюбская, 1(ГУ УПФ РФ № 16 по г. Москве и МО)		0101000020E6100000102384471BEB42400EA48B4D2B014C40
59388	1	10	367	4327	1227	\N	56.018791	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, Авиационная, 35	Россия, Московская область, Пушкинский район, Пушкино, Авиационная улица, 35	0101000020E6100000005471E316EB4240C53A55BE67024C40
59384	1	10	367	4327	1159	\N	56.005229	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, 2 Домбровская, 26, МОУ СОШ №5	Россия, Московская область, Пушкинский район, Пушкино, 2-я Домбровская улица, 26	0101000020E6100000BB4560AC6FEA4240D2FE0758AB004C40
59395	1	10	367	4327	1340	\N	56.001479000000003	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, 2 Надсоновский проезд, 14	Россия, Московская область, Пушкинский район, Пушкино, 2-й Надсоновский проезд, 14	0101000020E61000004C88B9A46AED4240BE50C07630004C40
94607	1	10	367	4327	1358	\N	56.003022691260703	адрес помещения для голосования:Московская область, Пушкинский муниципальный район, г.п.Пушкино, 1-Фабричный, 6(СГА), адрес УИК: Московской проспект (Центр соц. обслуживания), 51а		0101000020E61000002C103D2993EE42406211C30E63004C40
59386	1	10	367	4327	1195	\N	56.011887000000002	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, 1 Добролюбовский пр, 30		0101000020E6100000B7EBA52902EA4240B01F628385014C40
59426	1	10	367	61861	79979	\N	56.065661797125401	Московская область, Пушкинский муниципальный район, городское поселение Правдинский, Ленина, 15/1		0101000020E6100000D7A3703D0AEF4240844BC79C67084C40
59428	1	10	367	61861	80757	\N	56.065373999999998	Московская область, Пушкинский муниципальный район, городское поселение Правдинский, Зеленый городок, 5	Россия, Московская область, Пушкинский район, поселок городского типа Правдинский	0101000020E61000005F97E13FDDEE42401D01DC2C5E084C40
59424	1	10	367	61870	79820	\N	56.0674528448735	Московская область, Пушкинский муниципальный район, городское поселение Правдинский, Лесная, 60		0101000020E610000051888043A8EE42403082C64CA2084C40
59416	1	10	367	6026	\N	\N	56.178466350780397	Московская область, Пушкинский муниципальный район, городское поселение Ашукино, д.Мураново, 90		0101000020E6100000CB4752D2C3F2424056B950F9D7164C40
59357	1	10	367	2890	80725	\N	55.9582246121279	"п. Лесные поляны, здание ФГУЗ ЦКБВЛ ФМБА и Р ""Лесные поляны"", корп. 1"	Россия, Московская область, Пушкинский район, поселок Лесные Поляны, Новая улица, 1	0101000020E61000008044132862ED4240D49AE61DA7FA4B40
59451	1	10	367	2890	79788	\N	55.958498460052198	Московская область, Пушкинский муниципальный район, сельское поселение Тарасовское, Лесные Поляны, Ленина, ДК Современник	Россия, Московская область, Пушкинский район, поселок Лесные Поляны, улица Комбикормовый Завод, 22а	0101000020E610000056F487669EEE424005A4FD0FB0FA4B40
94609	1	10	367	6433	74214	\N	56.077055999999999	адрес помещения для голосования:Московская область, Пушкинский муниципальный район, г.п.Лесной, Титова, 11 (Школа), Адрес УИК: г.п.Лесной, Гагарина (Администрация), 1		0101000020E6100000D21BEE23B7F64240F4FA93F8DC094C40
59422	1	10	367	6433	80671	\N	56.0808450272092	Московская область, Пушкинский муниципальный район, городское поселение Лесной, ул. Гагарина, 1	Россия, Московская область, Пушкинский район, поселок городского типа Лесной, улица Пушкина	0101000020E6100000FD3383F8C0F64240C6850321590A4C40
59423	1	10	367	61869	79808	\N	56.0765959295396	Московская область, Пушкинский муниципальный район, городское поселение Лесной, ул.Титова, 11	Россия, Московская область, Пушкинский район, поселок городского типа Лесной, улица Титова	0101000020E610000057B2632310F742409180D1E5CD094C40
94617	1	10	367	7942	\N	\N	56.012103000000003	Московская область, Пушкинский муниципальный район, сельское поселение Царевское, Левково, 20-а ДК		0101000020E610000023A46E675FF942407D9752978C014C40
59420	1	10	367	59545	71892	\N	56.102754743129204	Московская область, Пушкинский муниципальный район, городское поселение Зеленоградский, ул.Школьная, 1	Россия, Московская область, Пушкинский район, поселок городского типа Зеленоградский	0101000020E6100000D2AC6C1FF2F4424010406A13270D4C40
94614	1	10	367	61925	80093	\N	56.043456999999997	Адрес помещения для голосования: Московская область, Пушкинский муниципальный район, Зверосовхоз, Школьная, 6а (Школа), Адрес УИК:Зверосовхоз, Школьная (здание старой школы), 6	Россия, Московская область, Пушкинский район, поселок Зверосовхоза	0101000020E610000009E1D1C611FD424021E4BCFF8F054C40
94611	1	10	367	7334	\N	\N	56.117184755562	Адрес помещения для голосования: Московская область, Пушкинский муниципальный район, с.п.Ельдигинское, Дом культуры, Адрес УИК: Администрация с.п.Ельдигинское, 1	Россия, Московская область, Пушкинский район, село Ельдигино	0101000020E6100000A0C552245FE74240774A07EBFF0E4C40
59429	1	10	367	6744	80713	\N	56.050456235675902	Московская область, Пушкинский муниципальный район, городское поселение Правдинский, Братовщина, Огородная, 17а	Россия, Московская область, Пушкинский район, село Братовщина	0101000020E61000009B8E006E16F1424088F19A5775064C40
94616	1	10	367	7867	\N	\N	56.158802000000001	Адрес помещения для голосования: Московская область, Пушкинский муниципальный район, Барково, 64а (Православный центр), Адрес УИК: Барково, 13а (ФГУП МО Орловское)		0101000020E610000018EE5C18E90B43400B45BA9F53144C40
94608	1	10	367	61988	\N	\N	56.167340247254799	Московская область, Пушкинский муниципальный район, г.п.Ашукино, Росхмель (Племсадпитомник), контора 4 отделения	Россия, Московская область, Пушкинский район, поселок Ашукино	0101000020E61000005B79C9FFE4F9424005A8A9656B154C40
59446	1	10	367	7551	81000	\N	56.147385	Московская область, Пушкинский муниципальный район, сельское поселение Ельдигинское, Алешино, Парковая, 1		0101000020E6100000DA70581AF8DF4240E275FD82DD124C40
59389	1	10	7541	61940	80495	\N	56.013804971520699	Московская область, Пушкинский муниципальный район, городское поселение Пушкино, 2 Некрасовский проезд, 4		0101000020E61000007DB08C0DDDEC4240B9C2BB5CC4014C40
59349	1	10	377	62000	\N	\N	55.442332	"п. санатория ""Родина"", здание п. санатория ""Родина"", здание МАУ Центр ""Родина"		0101000020E6100000641EF98381B34240B5FCC0559EB84B40
59358	1	10	377	61957	\N	\N	55.313203999999999	"п. радиоцентра ""Романцево"", здание  СДК, МУК СДК ""Романцево"""		0101000020E610000001F73C7FDACA4240FA7C941117A84B40
94604	1	10	377	57500	\N	\N	55.318980066722297	142113, Московская область, Подольский район, п.Молодёжный, д.30, помещение МУК СДК "Молодёжный"	Россия, Московская область, Подольский район	0101000020E6100000E449D23593BF4240FF092E56D4A84B40
59345	1	10	377	58934	\N	\N	55.316051999999999	"п. дома отдыха ""Вороново"", здание администрации с/п Вороново, д.31, стр.1"		0101000020E6100000CEA623809B914240EEEA556474A84B40
59344	1	10	377	59521	71828	\N	55.318665000000003	п. Львовский, Строителей, 4		0101000020E6100000FC6D4F90D8C242409FB0C403CAA84B40
59342	1	10	377	59521	71826	\N	55.318665000000003	п. Львовский, Московская, 1		0101000020E6100000FC6D4F90D8C242409FB0C403CAA84B40
59374	1	10	377	3735	\N	\N	55.417853000000001	"п. Щапово, здание МУК СДК ""Щапово, 23"		0101000020E6100000BF9CD9AED0B342408BC404357CB54B40
59373	1	10	377	3735	\N	\N	55.417853000000001	"п. Щапово, здание МУК СДК ""Солнечный"", 23"		0101000020E6100000BF9CD9AED0B342408BC404357CB54B40
59362	1	10	377	59264	\N	\N	55.413144378947202	п. Шишкин лес, здание МОУ Михайловской СОШ, 28		0101000020E61000009599D2FA5B984240F24410E7E1B44B40
59361	1	10	377	59264	\N	\N	55.409966710024499	п. Шишкин лес, здание МОУ Михайловская СОШ, 28	Россия, Московская область, Подольский район, поселок Шишкин Лес	0101000020E6100000CD94D6DF1298424039B874CC79B44B40
60051	1	10	377	56688	\N	\N	55.386512000000003	место нахождения: с.Троицкое, д.4, Администрация сельского поселения Любучанское, место голосования: с.Троицкое, д.50, Средняя общеобразовательная школа		0101000020E6100000DF87838428B542407BC1A73979B14B40
59359	1	10	377	2987	\N	\N	55.350760999999999	"с. Сынково, здание МУК СДК ""Родник"", 24"		0101000020E61000008602B68311D142402BDB87BCE5AC4B40
59591	1	10	377	45757	74077	\N	55.327080000000002	с.Покровское, Мира, 1 А		0101000020E61000000A68226C789A42407D96E7C1DDA94B40
59365	1	10	377	3330	\N	\N	55.499820999999997	"п. Остафьево, здание МОУ ""Остафьево"", прогимназия МОУ"		0101000020E6100000B7088CF50DBE4240506D7022FABF4B40
59343	1	10	377	1945	71844	\N	55.318665000000003	п. Львовский, Горького, 6		0101000020E6100000FC6D4F90D8C242409FB0C403CAA84B40
59341	1	10	377	1945	71844	\N	55.318665000000003	п. Львовский, Горького, 5		0101000020E6100000FC6D4F90D8C242409FB0C403CAA84B40
59346	1	10	377	2237	\N	\N	55.311292000000002	"п. ЛМС, микрорайон ""Центральный"", д.16, стр.1"	Россия, Московская область, Подольский район, поселок ЛМС	0101000020E6100000B421FFCC20984240D3C08F6AD8A74B40
59375	1	10	377	46031	71842	\N	55.373663999999998	п. Курилово, Центральная, д.32		0101000020E6100000A2F0D93A38B04240A5D8D138D4AF4B40
94603	1	10	377	2717	\N	\N	55.430231999999997	142150, Московская область, Подольский район,  с. Красная Пахра, д.20, помещение МУК СДК «Звездный»		0101000020E61000000B43E4F4F5A24240A9D898D711B74B40
94645	1	10	377	62059	81031	\N	55.362713081009801	в помещении  сельского Дома культуры, деревня Новая	Россия, Московская область, Климовск, Новая улица	0101000020E61000003753211E89C14240C26A2C616DAE4B40
59351	1	10	377	45544	71845	\N	55.321891999999998	с. Кленово, Центральная, строение 1		0101000020E61000009CA4F9635AAD4240096CCEC133A94B40
94606	1	10	377	3416	\N	\N	55.473300999999999	142134, Московская область, Подольский район,  п. Знамя Октября, д. 31 стр. 3, помещение МУ спортивный клуб «Десна»,		0101000020E610000045F5D6C056C5424001158E2095BC4B40
59370	1	10	377	3416	\N	\N	55.473725000000002	"п. Знамя Октября, мкрн. ""Родники"", д. 11"	Россия, Московская область, Подольский район, поселок Знамя Октября, 11	0101000020E6100000205F420587C5424018265305A3BC4B40
59368	1	10	377	3416	\N	\N	55.476852000000001	п. Знамя Октября, здание школы пос. Знамя Октября, 40	Россия, Московская область, Подольский район, поселок Знамя Октября, 40	0101000020E61000000D198F5209C542401F84807C09BD4B40
59366	1	10	377	3416	\N	\N	55.476852000000001	п. Знамя Октября, здание МОУ СОШ пос. Знамя Октября, 40		0101000020E61000000D198F5209C542401F84807C09BD4B40
94605	1	10	377	2834	74201	\N	55.389099999999999	142108, Московская область, Подольский район, п.Железнодорожный, ул.Б.Серпуховская, д.202а, помещении конференц-зала  ОАО “Сынково”		0101000020E61000000551F70148C54240D26F5F07CEB14B40
59369	1	10	377	3569	923	\N	55.447586000000001	п. Ерино, Высокая, д.3, стр.2	Россия, Московская область, Подольский район, поселок Ерино, Высокая улица, 3	0101000020E61000002D095053CBC24240E012807F4AB94B40
59348	1	10	377	2383	\N	\N	55.444257	"п. Дубровицы, здание МУК СДК ""Дубровицы"", д.51"	Россия, Московская область, Подольский район, поселок Дубровицы	0101000020E61000009DF4BEF1B5BD42407102D369DDB84B40
59352	1	10	377	2585	\N	\N	55.443605171510498	"с. Былово, здание МУК СДК ""Юбилейный"", 8а"	Россия, Московская область, Подольский район, село Былово	0101000020E610000034D6FECEF69E4240C9AB730CC8B84B40
59599	1	10	377	45896	80737	\N	55.220295	с.Богородское, ул.Центральная, д.4		0101000020E61000006A17D34CF7844240753C66A0329C4B40
59372	1	10	377	45975	81006	\N	55.412334000000001	п. Александровка, Центральная, д.41		0101000020E6100000EC6AF294D5CE4240B2834A5CC7B44B40
59274	1	10	273	48593	\N	\N	55.697889000000004	д. Семеново, 18/А		0101000020E6100000D446753A905143407C9E3F6D54D94B40
59164	1	10	273	25772	\N	\N	55.774472000000003	д. Саурово, 29		0101000020E610000045A0FA079160434078D503E621E34B40
59281	1	10	273	31168	\N	\N	55.745350999999999	с. Рахманово, д.84	Россия, Московская область, Павлово-Посадский район, село Рахманово	0101000020E61000005EF58079C84E43403C855CA967DF4B40
59379	1	10	273	1147	1093	\N	55.784014999999997	Московская область, городской округ Протвино, ул. Гагарина, 7	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица Гагарина, 7	0101000020E610000035D3BD4EEA5143406649809A5AE44B40
59235	1	10	554	29020	\N	\N	55.492375000000003	Московская область, Орехово-Зуевский муниципальный район, д. Цаплино, 141		0101000020E61000003F19E3C3EC7543401B2FDD2406BF4B40
59251	1	10	273	1147	7581	\N	55.780962000000002	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, 1 Мая, 66	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица 1 Мая, 66а	0101000020E610000092CD55F31C4F43409AB51490F6E34B40
59254	1	10	273	1147	7622	\N	55.7802375527259	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, пл. Революции, 13,15	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица Ленина	0101000020E61000001E1B81785D534340588CBAD6DEE34B40
94600	1	10	273	1147	68850	\N	55.7837719026112	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, пк. Герцена, д.19/14, МОУ ДОД ДЭБЦ		0101000020E6100000486B0C3A21564340A0C211A452E44B40
59269	1	10	273	1147	80354	\N	55.767752000000002	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Южная, 14		0101000020E6100000A40051306354434024B891B245E24B40
59253	1	10	273	1147	80358	\N	55.776507000000002	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Сенная, 42		0101000020E6100000386A85E97B514340BB0ED59464E34B40
59250	1	10	273	1147	79837	\N	55.784994282703998	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Мира, 1	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица Мира	0101000020E6100000342DB1321A53434032C7F2AE7AE44B40
94601	1	10	273	1147	80362	\N	55.762115000000001	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Кузьмина, 53		0101000020E6100000F98381E7DE5543404165FCFB8CE14B40
59265	1	10	273	1147	7735	\N	55.776446	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, пер. Корнево-Юдинский, 12	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Корнево-Юдинский переулок, 12	0101000020E6100000B0027CB779594340158E209562E34B40
59255	1	10	273	1147	80345	\N	55.780157000000003	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Кирова, 83		0101000020E610000078CF81E5085543406C5F402FDCE34B40
59258	1	10	273	1147	80346	\N	55.777403	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Каляева, 2		0101000020E6100000349D9D0C8E564340F96706F181E34B40
59259	1	10	273	1147	80380	\N	55.780293999999998	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Герцена, 15		0101000020E610000028486C770F564340ECA17DACE0E34B40
59264	1	10	273	1147	7730	\N	55.773569999999999	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Большая Покровская, 33	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Большая Покровская улица, 33	0101000020E610000056F146E69153434057957D5704E34B40
59262	1	10	273	1147	80376	\N	55.786248999999998	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, Белинского, 7	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица Белинского, 7	0101000020E6100000FBE59315C3594340A0C1A6CEA3E44B40
59252	1	10	273	1147	7599	\N	55.777636000000001	Московская область, Павлово-Посадский муниципальный район, городское поселение Павловский Посад, 1-й пер. 1 Мая, 1	Россия, Московская область, Павлово-Посадский район, Павловский Посад, 1-й переулок 1 Мая, 1	0101000020E610000011E2CAD93B4F43409C18929389E34B40
59277	1	10	273	30994	\N	\N	55.645456000000003	д. Ново-Загарье, д.106/Б		0101000020E61000009259BDC3ED604340E5805D4D9ED24B40
59284	1	10	273	48763	\N	\N	55.706654999999998	д. Логиново, д.22/А		0101000020E6100000D02B9E7AA45D43400647C9AB73DA4B40
59279	1	10	273	60235	74092	\N	55.844246231511498	д. Кузнецы, ул. Новая, д.1/1	Россия, Московская область, Павлово-Посадский район, деревня Кузнецы	0101000020E61000006CAF05BD37544340B0E3BF4010EC4B40
59278	1	10	273	31054	80813	\N	55.630704999999999	д. Крупино, Школьная, д.11/А		0101000020E6100000062B4EB5165E43403B3602F1BAD04B40
59282	1	10	273	31246	\N	\N	55.741252000000003	с. Казанское, д.42		0101000020E610000024809BC58B4743401C0C7558E1DE4B40
59285	1	10	273	31384	\N	\N	55.711914	д. Ефимово, 69/Г		0101000020E610000078B81D1A1661434043C879FF1FDB4B40
59283	1	10	273	31307	\N	\N	55.754156999999999	д. Евсеево, 13/А		0101000020E61000005E9ECE15A55A43405586713788E04B40
59280	1	10	273	31158	\N	\N	55.924925999999999	д. Васютино, д.72/1		0101000020E61000005B5EB9DE365F43402C9CA4F963F64B40
59272	1	10	273	21386	\N	\N	55.816752999999999	пос. Большие Дворы, пр Чкалова, 2	Россия, Московская область, Павлово-Посадский район, поселок городского типа Большие дворы	0101000020E6100000CC41D0D1AA52434077F4BF5C8BE84B40
59273	1	10	273	21386	80361	\N	55.809621	пос. Большие Дворы, Спортивная ул, 12		0101000020E6100000FAD2DB9F8B524340D19332A9A1E74B40
59275	1	10	273	48608	\N	\N	55.682397000000002	д. Алферово, 5/1	Россия, Московская область, Павлово-Посадский район, деревня Алферово	0101000020E6100000742502D53F5A4340BBF1EEC858D74B40
59201	1	10	554	27446	\N	\N	55.697645000000001	Московская область, Орехово-Зуевский муниципальный район, д. Яковлево, 2а		0101000020E6100000828C800A479E4340E59B6D6E4CD94B40
59921	1	10	554	28017	\N	\N	55.702728999999998	деревня Юркино, Юркинский сельский Дом культуры, дом 12А		0101000020E610000092CF2B9E7A6C4340B3791C06F3D94B40
59213	1	10	554	28017	\N	\N	55.702728999999998	Московская область, Орехово-Зуевский муниципальный район, д. Юркино, 98в		0101000020E610000092CF2B9E7A6C4340B3791C06F3D94B40
59076	1	10	108	61893	79899	\N	55.703980999999999	рп Новоивановское, Аграхимиков, 1		0101000020E61000004582A966D6AE4240B000A60C1CDA4B40
59246	1	10	554	29506	\N	\N	55.503191000000001	Московская область, Орехово-Зуевский муниципальный район, с. Хотеичи, 263 а		0101000020E6100000E71890BDDE6343401E520C9068C04B40
59222	1	10	554	28398	\N	\N	55.814179000000003	Московская область, Орехово-Зуевский муниципальный район, д. Федорово, 137а		0101000020E61000000CE8853B176A4340850B790437E84B40
59234	1	10	554	28978	\N	\N	55.535564000000001	Московская область, Орехово-Зуевский муниципальный р-н, д. Степановка, 109 а		0101000020E610000063EFC517ED8543401D75745C8DC44B40
59247	1	10	554	29553	\N	\N	55.521548033901901	Московская область, Орехово-Зуевский муниципальный район, д. Соболево, д. 7а	Россия, Московская область, Орехово-Зуевский район, деревня Соболево	0101000020E61000006A6803B0015B4340A9A5B915C2C24B40
59210	1	10	554	27892	80705	\N	55.772666033941803	Московская обл., Орехово-Зуевский муниципальный р-н, п. Снопок Новый, Центральная, 15	Россия, Московская область, Орехово-Зуевский район, поселок Снопок Новый	0101000020E6100000E6CC76853E944340965D30B8E6E24B40
59242	1	10	554	29309	\N	\N	55.6238069430837	Московская область, Орехово-Зуевский муниципальный район, д. Смолево, 93 а	Россия, Московская область, Орехово-Зуевский район, деревня Смолево	0101000020E61000007E703E75AC7A4340080264E8D8CF4B40
59237	1	10	554	29103	80914	\N	55.506903000000001	Московская область, Орехово-Зуевский муниципальный район, д. Слободище, Советская, 55 б		0101000020E610000096B20C71AC6D4340459F8F32E2C04B40
59212	1	10	554	27982	81019	\N	55.740890375630997	Московская обл., Орехово-Зуевский муниципальный район, д. Савостьяново, Слободка, 7а	Россия, Московская область, Орехово-Зуевский район, деревня Савостьяново, улица Слободка	0101000020E610000042E90B21E76943407BF7C77BD5DE4B40
59200	1	10	554	27414	\N	\N	55.689672884703398	Московская область, Орехово-Зуевский муниципальный район, д. Савинская, 30 а	Россия, Московская область, Орехово-Зуевский район, деревня Савинская	0101000020E61000007B4ACE893DA8434094F7713447D84B40
59224	1	10	554	28482	\N	\N	55.587350999999998	Московская область, Орехово-Зуевский муниципальный р-н, д. Понарино, 75 а		0101000020E61000005C566133C08D4340EE224C512ECB4B40
59231	1	10	554	28813	\N	\N	55.608998999999997	Московская область, Орехово-Зуевский муниципальный район, д. Петрушино, 121 б		0101000020E6100000D65757056A974340FA25E2ADF3CD4B40
59209	1	10	554	27809	\N	\N	55.824176999999999	Московская область, Орехово-Зуевский муниципальный район, п. Озерецкий, 32а		0101000020E6100000C6E061DA37894340C58EC6A17EE94B40
59241	1	10	554	62011	80912	\N	55.6321626599306	Московская область, Орехово-Зуевский муниципальный район, д. Новое, Дружбы, 1 а	Россия, Московская область, Орехово-Зуевский район, деревня Новое	0101000020E6100000F0880AD5CD754340E15E99B7EAD04B40
59240	1	10	554	62011	80865	\N	55.629788948746402	Московская область, Орехово-Зуевский муниципальный район, д. Новое, Дружбы, 1а		0101000020E61000003EB48F15FC764340B6300BED9CD04B40
59244	1	10	554	29415	\N	\N	55.640619000000001	Московская область, Орехово-Зуевский муниципальный район, п. Мисцево, 28		0101000020E610000069AA27F38F8A43401E19ABCDFFD14B40
94599	1	10	554	28765	\N	\N	55.598461	Московская область, Орехово-Зуевский муниципальный район, д. Мисцево, 178		0101000020E610000079C9FFE4EF9043403A77BB5E9ACC4B40
59248	1	10	554	29576	\N	\N	55.589568985883197	Московская область, Орехово-Зуевский муниципальный район, д. Минино, 179 а	Россия, Московская область, Орехово-Зуевский район, деревня Минино	0101000020E61000006C06B8205B52434022DE3AFF76CB4B40
59239	1	10	554	29172	\N	\N	55.876890000000003	Московская область, Орехово-Зуевский муниципальный р-н, д. Малая Дубна, 15 а		0101000020E6100000BA2D910BCE7A4340401878EE3DF04B40
59193	1	10	554	5501	6960	\N	55.716822999999998	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Степана Морозкина, 14	Россия, Московская область, Орехово-Зуевский район, Ликино-Дулево, улица Степана Морозкина, 14	0101000020E6100000DC4603780B7A4340A30227DBC0DB4B40
59199	1	10	554	5501	6988	\N	55.738621999999999	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Калинина, 14	Россия, Московская область, Орехово-Зуевский район, Ликино-Дулево, улица Калинина, 14	0101000020E61000004C1938A0A5794340950D6B2A8BDE4B40
59195	1	10	554	5501	6976	\N	55.723404000000002	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Советская, 34	Россия, Московская область, Орехово-Зуевский район, Ликино-Дулево, Советская улица, 34	0101000020E610000056BABBCE867A4340D6E5948098DC4B40
59190	1	10	554	5501	80340	\N	55.706147000000001	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Ленина, 1		0101000020E6100000AB24B20FB27A434092955F0663DA4B40
59191	1	10	554	5501	79833	\N	55.7109164265812	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Кирова, 73	Россия, Московская область, Орехово-Зуевский район, Ликино-Дулево	0101000020E610000006DA1D520C7A4340001AA54BFFDA4B40
59198	1	10	554	5501	80343	\N	55.738652000000002	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Калинина, 12		0101000020E6100000DE1D19ABCD794340009013268CDE4B40
59197	1	10	554	5501	80343	\N	55.731819999999999	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Калинина, 2 в		0101000020E6100000BEA1F0D93A7A434084471B47ACDD4B40
59196	1	10	554	5501	80343	\N	55.731251999999998	Московская обл., Орехово-Зуевский муниципальный р-н, г. Ликино-Дулево, Калинина, 3		0101000020E61000002E742502D57943403A9160AA99DD4B40
59185	1	10	554	22533	80332	\N	55.574649999999998	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Школьная, 1		0101000020E61000002A73F38DE8744340BD5296218EC94B40
59187	1	10	554	22533	6902	\N	55.578197000000003	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Советская, 1а	Россия, Московская область, Орехово-Зуевский район, Куровское, Советская улица, 1а	0101000020E61000000E130D52F07243409AD2FA5B02CA4B40
59186	1	10	554	22533	80339	\N	55.577103000000001	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Советская, 4		0101000020E6100000DDEA39E97D73434035B6D782DEC94B40
59181	1	10	554	22533	6861	\N	55.587778999999998	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Новинское шоссе, 12	Россия, Московская область, Орехово-Зуевский район, Куровское, Новинское шоссе, 12	0101000020E6100000C53BC0931676434046239F573CCB4B40
59163	1	10	554	22533	6666	\N	55.584848000000001	Московская область, городской округ Орехово-Зуево, Набережная, 15	Россия, Московская область, Орехово-Зуевский район, Куровское, Набережная улица, 15	0101000020E61000005BD2510E66734340C5909C4CDCCA4B40
59189	1	10	554	22533	6920	\N	55.586975000000002	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Коммунистическая, 2	Россия, Московская область, Орехово-Зуевский район, Куровское, Коммунистическая улица, 2	0101000020E6100000D2C77C40A0754340E9482EFF21CB4B40
59183	1	10	554	22533	6870	\N	55.577866999999998	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Вокзальная, 5	Россия, Московская область, Орехово-Зуевский район, Куровское, Вокзальная улица, 5	0101000020E610000081CD3978267643400438BD8BF7C94B40
59184	1	10	554	22533	80334	\N	55.577230999999998	Московская область, Орехово-Зуевский муниципальный район, г. Куровское, Вокзальная, 7		0101000020E61000004A5E9D6340764340629E95B4E2C94B40
59221	1	10	554	28353	\N	\N	55.782460999999998	Московская обл., Орехово-Зуевский муниципальный р., д. Красная Дубрава, 57а		0101000020E610000092CEC0C8CB6843409EB29AAE27E44B40
59215	1	10	554	15377	\N	\N	55.749932000000001	Московская обл., Орехово-Зуевский район, д. Кабаново д. 134	Россия, Московская область, Орехово-Зуевский район, деревня Кабаново	0101000020E6100000AEA0698995774340A81C93C5FDDF4B40
59238	1	10	554	29129	71907	\N	55.477902999999998	Московская обл., Орехово-Зуевский муниципальный р., с Ильинский Погост, Совхозная, 10		0101000020E6100000E0BDA3C68474434084D4EDEC2BBD4B40
59229	1	10	554	28709	\N	\N	55.580435999999999	Московская область, Орехово-Зуевский муниципальный район, д. Запутное, 58		0101000020E6100000FC8EE1B19FA54340E5B512BA4BCA4B40
59227	1	10	554	28631	\N	\N	55.558396000000002	Московская область, Орехово-Зуевский муниципальный район, д. Заполицы, 35а		0101000020E6100000300E2E1D739A4340CE1B278579C74B40
59245	1	10	554	29423	80836	\N	55.580374999999997	Московская область, Орехово-Зуевский муниципальный район, д. Заволенье, Школьная, 89		0101000020E610000087191A4F047943403F355EBA49CA4B40
59243	1	10	554	29355	\N	\N	55.664324000000001	Московская область, Орехово-Зуевский муниципальный район, д. Дуброво, 90		0101000020E61000009B70AFCC5B7D434055F99E9108D54B40
59206	1	10	554	27709	\N	\N	55.780981916672602	Московская область, Орехово-Зуевский муниципальный район, д. Дровосеки, 21а	Россия, Московская область, Орехово-Зуевский район, деревня Дровосеки	0101000020E6100000E294B9F9467E4340E161DA37F7E34B40
59179	1	10	554	21773	6845	\N	55.742508999999998	Московская область, Орехово-Зуевский муниципальный район, г. Дрезна, Центральная, 20	Россия, Московская область, Орехово-Зуевский район, Дрезна, Центральная улица, 20	0101000020E6100000E44C13B69F6C43402AFEEF880ADF4B40
59211	1	10	554	21773	81023	\N	55.745716000000002	Московская область, Орехово-Зуевский муниципальный район, г. Дрезна, Советская, 17		0101000020E6100000263ACB2C426D43404E0D349F73DF4B40
59180	1	10	554	21773	80222	\N	55.738931000000001	Московская область, Орехово-Зуевский муниципальный район, г. Дрезна, Коммунистическая, 12		0101000020E61000008657923CD76B434013807F4A95DE4B40
59178	1	10	554	21773	80215	\N	55.745888999999998	Московская область, Орехово-Зуевский муниципальный район, г. Дрезна, Зимина, 2		0101000020E6100000CC988235CE6C43401BB96E4A79DF4B40
59220	1	10	554	28293	80351	\N	55.793813999999998	Московская область, Орехово-Зуевский муниципальный район, д. Демихово, Заводская, 8		0101000020E610000049BDA772DA714340B08D78B29BE54B40
59216	1	10	554	28133	\N	\N	55.608409000000002	Московская область, Орехово-Зуевский муниципальный район, д. Давыдово, Заводская, 30	Россия, Московская область, Орехово-Зуевский район, деревня Давыдово	0101000020E6100000F12A6B9BE26D4340C9CB9A58E0CD4B40
59218	1	10	554	28133	72049	\N	55.608409000000002	Московская область, Орехово-Зуевский муниципальный район, д. Давыдово, 2-й микрорайон, 11		0101000020E6100000F12A6B9BE26D4340C9CB9A58E0CD4B40
59217	1	10	554	28133	72049	\N	55.608409000000002	Московская область, Орехово-Зуевский муниципальный район, д. Давыдово, 2-й микрорайон, 31		0101000020E6100000F12A6B9BE26D4340C9CB9A58E0CD4B40
59204	1	10	554	27560	\N	\N	55.696854000000002	Московская область, Орехово-Зуевский муниципальный район, д. Губино, Железнодорожная, 7	Россия, Московская область, Орехово-Зуевский район, деревня Губино	0101000020E6100000115663096B8F43401C0B0A8332D94B40
59203	1	10	554	27560	72366	\N	55.696854000000002	Московская область, Орехово-Зуевский муниципальный район, д. Губино, Ленинская-2, 95а		0101000020E6100000115663096B8F43401C0B0A8332D94B40
59214	1	10	554	28040	\N	\N	55.738315497393998	Московская область, Орехово-Зуевский муниципальный район, д. Гора, 51а	Россия, Московская область, Орехово-Зуевский район, деревня Гора	0101000020E6100000FBAC32535A7F4340B8921D1B81DE4B40
59208	1	10	554	27792	80916	\N	55.843969999999999	Московская обл., Орехово-Зуевский муниципальный р-н, д. Войново-Гора, Новая, 138а		0101000020E610000030B95164AD8743400E677E3507EC4B40
59205	1	10	554	27644	72369	\N	55.772329999999997	Московская область, Орехово-Зуевский муниципальный район, п. Верея, Школьная, 6		0101000020E61000005E64027E8D8C43401EDC9DB5DBE24B40
59228	1	10	554	28669	\N	\N	55.580508000000002	Московская область, Орехово-Зуевский муниципальный район, д. Велино, 83		0101000020E61000000BEBC6BB23B143407F880D164ECA4B40
59226	1	10	554	14746	\N	\N	55.527810000000002	Московская область, Орехово-Зуевский муниципальный р-н, с. Богородское, 183 а		0101000020E6100000568330B77B8B43403A4030478FC34B40
59202	1	10	554	27511	\N	\N	55.664772831395197	Московская область, Орехово-Зуевский муниципальный район, д. Белавино, 72	Россия, Московская область, Орехово-Зуевский район, деревня Белавино	0101000020E61000007B67B45549B24340C4211B4817D54B40
59236	1	10	554	29044	\N	\N	55.447844639739003	Московская область, Орехово-Зуевский муниципальный район, д. Беззубово, 80 а	Россия, Московская область, Орехово-Зуевский район, деревня Беззубово	0101000020E61000008351499D80764340AC5626FC52B94B40
59219	1	10	554	28276	\N	\N	55.554257	Московская область, Орехово-Зуевский муниципальный р-н, д. Анциферово, Школьная, 30	Россия, Московская область, Орехово-Зуевский район, деревня Анциферово	0101000020E6100000ED832C0B266843401F4AB4E4F1C64B40
59225	1	10	554	28457	\N	\N	55.563848999999998	Московская область, Орехово-Зуевский муниципальный район, д. Авсюнино, 177 б		0101000020E61000006EC328081E8D4340EF703B342CC84B40
59223	1	10	554	28457	\N	\N	55.563848999999998	Московская область, Орехово-Зуевский муниципальный район, п. Авсюнино, Ленина, 12а	Россия, Московская область, Орехово-Зуевский район, поселок Авсюнино	0101000020E61000006EC328081E8D4340EF703B342CC84B40
59232	1	10	554	28877	\N	\N	55.512709000000001	Московская область, Орехово-Зуевский муниципальный район, д. Абрамовка, 102 б		0101000020E61000009DF2E84658804340B4AED172A0C14B40
59114	1	10	1241	62004	80828	\N	54.894803000000003	Московская область, с. Горы, Багратиона, 28б		0101000020E610000086AFAF75A94D43406DAE9AE788724B40
94594	1	10	1241	23214	80776	\N	54.872791999999997	Московская область,Озерский р-н,д.Тарбушево,ул.Набережная, дом  34		0101000020E61000005303CDE7DC334340EF1AF4A5B76F4B40
59132	1	10	1241	24271	\N	\N	54.898774000000003	Московская область,Озерский р-н, с. Сосновка, Помещение Сосновского фельдшерско-акушерского пункта		0101000020E610000081CF0F2384574340603FC4060B734B40
59133	1	10	1241	24271	80961	\N	54.898774000000003	Московская область, с. Сосновка, Советская, 136		0101000020E610000081CF0F2384574340603FC4060B734B40
59134	1	10	1241	24363	\N	\N	54.836736000000002	"Московская область, с. Редькино, Фабрика ""Ока"", 21"		0101000020E6100000C0E78711C23F434064B14D2A1A6B4B40
59129	1	10	1241	16867	\N	\N	54.855634999999999	"Московская область, пос. Центральная усадьба совхоза ""Озеры"", Помещение сельского клуба"	Россия, Московская область, Озерский район, Озеры	0101000020E6100000D7868A71FE4643400F289B72856D4B40
59128	1	10	1241	16867	\N	\N	54.859222000000003	Московская область, г. Озёры, квартал Текстильщики, 43	Россия, Московская область, Озерский район, Озеры	0101000020E610000020B75F3E594543407A008BFCFA6D4B40
59116	1	10	1241	16867	\N	\N	54.859222000000003	Московская область, г. Озёры, Микр.им.Маршала Катукова, 38	Россия, Московская область, Озерский район, Озеры	0101000020E610000020B75F3E594543407A008BFCFA6D4B40
59124	1	10	1241	16867	80835	\N	54.8559320824548	Московская область, г. Озёры, пл. Карла Маркса, 57	Россия, Московская область, Озерский район, Озеры, улица Карла Маркса	0101000020E6100000A39410ACAA474340C9CC052E8F6D4B40
59127	1	10	1241	16867	80826	\N	54.859222000000003	Московская область, г. Озёры, пл. Карла Маркса, 55		0101000020E610000020B75F3E594543407A008BFCFA6D4B40
94595	1	10	1241	16867	74079	\N	54.856823386237799	Московская область,г.Озеры,микрорайон 1, Помещение средней школы №1	Россия, Московская область, Озерский район, Озеры	0101000020E610000041B8020AF54A4340F5BA4560AC6D4B40
59117	1	10	1241	16867	74079	\N	54.859222000000003	Московская область, г. Озёры, микрорайон 1, 7		0101000020E610000020B75F3E594543407A008BFCFA6D4B40
59112	1	10	1241	16867	71888	\N	54.859222000000003	Московская область, г.Озеры, Микр.им.маршала Катукова, Гимназия №4		0101000020E610000020B75F3E594543407A008BFCFA6D4B40
59113	1	10	1241	16867	81004	\N	54.855449284644997	Московская область, г. Озеры, Микр. им.Маршала Катукова, Гимназия №4	Россия, Московская область, Озерский район, Озеры	0101000020E610000045D5AF743E464340AD32535A7F6D4B40
59123	1	10	1241	16867	74157	\N	54.851283000000002	Московская область, г. Озёры, Ленина, 20	Россия, Московская область, Озерский район, Озеры, Луговая улица	0101000020E6100000E605D847A7424340055262D7F66C4B40
59122	1	10	1241	16867	74157	\N	54.851846396798898	Московская область, г. Озёры, Ленина, 63	Россия, Московская область, Озерский район, Озеры	0101000020E6100000FC8C0B07424243403D9D2B4A096D4B40
59120	1	10	1241	16867	74157	\N	54.851283000000002	Московская область, г. Озёры, Ленина, 102		0101000020E6100000E605D847A7424340055262D7F66C4B40
59119	1	10	1241	16867	74157	\N	54.851283000000002	Московская область, г. Озёры, Ленина, 71		0101000020E6100000E605D847A7424340055262D7F66C4B40
59111	1	10	1241	16867	74157	\N	54.851283000000002	Московская область, Озёрский муниципальный район, г. Озеры, Ленина, 216		0101000020E6100000E605D847A7424340055262D7F66C4B40
59125	1	10	1241	16867	72356	\N	54.859222000000003	Московская область, г. Озёры, Болотный переулок, 4		0101000020E610000020B75F3E594543407A008BFCFA6D4B40
94596	1	10	1241	16867	80856	\N	54.859704000000001	Московская область,г.Озеры,ул.2-я Высокополянская, дом 63		0101000020E61000002E1C08C902464340C51EDAC70A6E4B40
59135	1	10	1241	52586	\N	\N	54.815238000000001	Московская область, д. Емельяновка, Помещение сельского клуба	Россия, Московская область, Озерский район, деревня Емельяновка	0101000020E6100000AFEE586C934443406D3A02B859684B40
59130	1	10	1241	24142	71890	\N	54.955871999999999	Московская область, с. Бояркино, Школьная, 34		0101000020E61000004A29E8F692424340C09481035A7A4B40
94597	1	10	1241	24203	\N	\N	54.918964000000003	Московская область,Озерский р-н,с.Белые-Колодези, Помещение Белоколодезской сельской библиотеки		0101000020E61000004F20EC14AB584340C619C39CA0754B40
59036	1	10	108	62006	80830	\N	55.725661000000002	с. Ромашково, Советская, 8	Россия, Московская область, Одинцовский район, коттеджный поселок Ромашково	0101000020E6100000B9C5FCDCD0A84240C87DAB75E2DC4B40
59095	1	10	108	59420	70909	\N	55.660204458548201	с. Юдино, 1 Успенское шоссе, 2А	Россия, Московская область, Одинцовский район, село Юдино	0101000020E61000007100FDBE7F9742401D588E9081D44B40
59109	1	10	108	23010	\N	\N	55.618617999999998	п. Часцы, Часцовская школа		0101000020E61000009E4319AA626E4240C45BE7DF2ECF4B40
59106	1	10	108	23010	\N	\N	55.618617999999998	п. Часцы, Культурно спортивный центр		0101000020E61000009E4319AA626E4240C45BE7DF2ECF4B40
59097	1	10	108	22630	71811	\N	55.662984000000002	д. Хлюпино, Заводская, 2А	Россия, Московская область, Одинцовский район, деревня Хлюпино, Московское Малое кольцо	0101000020E6100000F56915FDA17B4240B9E2E2A8DCD44B40
59104	1	10	108	49520	\N	\N	55.716113	с. Успенское, Успенский дом культуры		0101000020E610000058552FBFD3884240C79E3D97A9DB4B40
59083	1	10	108	59234	\N	\N	55.736294610135801	"дом отдыха ""Огарево"", Усовская начальная школа"		0101000020E610000016DBA4A2B19A4240AA9A20EA3EDE4B40
94592	1	10	108	53053	29899	\N	55.600983999999997	Старогородковская средняя общеобразовательная школа - 143079, Московская область, Одинцовский район, поселок Старый Городок, улица Школьная, дом № 28	Россия, Московская область, Одинцовский район, поселок Старый Городок	0101000020E610000002B7EEE6A9584240AAB5300BEDCC4B40
59089	1	10	108	61897	79937	\N	55.722665999999997	с. Савинская Слобода, Юбилейная, 80А	Россия, Московская область, Одинцовский район, село Саввинская Слобода	0101000020E61000006BB933130C6542402FF7C95180DC4B40
59108	1	10	108	60224	\N	\N	55.648192999999999	п. Покровский городок, филиал Часцовской школы	Россия, Московская область, Одинцовский район, поселок Покровское	0101000020E610000066D828EB376B4240813FFCFCF7D24B40
59094	1	10	108	22475	\N	\N	55.654842909625202	с. Перхушково, 2Б	Россия, Московская область, Одинцовский район, село Перхушково	0101000020E610000002F1BA7EC1924240DC813AE5D1D34B40
59041	1	10	108	1096	\N	\N	55.682051999999999	г. Одинцово, БЗРИ, Столовая БЗРИ	Россия, Московская область, Одинцовский район, Одинцово, поселок БЗРИ	0101000020E61000007A89B14CBFA64240F015DD7A4DD74B40
58790	1	10	108	1096	\N	\N	55.656742999999999	г. Одинцово-1, ДЮСШ	Россия, Московская область, Одинцовский район, Одинцово, микрорайон Одинцово-1	0101000020E61000004FB16A10E6A242403F70952710D44B40
58778	1	10	108	1096	\N	\N	55.654817999999999	г. Одинцово, Новое Яскино, 3	Россия, Московская область, Одинцовский район, Одинцово, 3	0101000020E61000008D7E349C32A34240836A8313D1D34B40
59027	1	10	108	1096	5122	\N	55.681128000000001	г. Одинцово, Маршала Жукова, 38	Россия, Московская область, Одинцовский район, Одинцово, улица Маршала Жукова, 38	0101000020E61000009BCAA2B08BA24240E831CA332FD74B40
59075	1	10	108	1096	16370	\N	55.660404	п. ВНИИССОК, Дениса Давыдова, 1	Россия, Московская область, Одинцовский район, Одинцово, поселок ВНИИССОК, улица Дениса Давыдова, 1	0101000020E610000003B5183C4C9D4240E412471E88D44B40
59037	1	10	108	1096	5287	\N	55.68835	г. Одинцово, Маршала Крылова, 20	Россия, Московская область, Одинцовский район, Одинцово, бульвар Маршала Крылова, 20	0101000020E610000078CF81E508A74240CE1951DA1BD84B40
59033	1	10	108	1096	5287	\N	55.687238000000001	г. Одинцово, Маршала Крылова, 5	Россия, Московская область, Одинцовский район, Одинцово, бульвар Маршала Крылова, 5	0101000020E61000000971E5EC9DA54240C3482F6AF7D74B40
59025	1	10	108	1096	5182	\N	55.682051999999999	г. Одинцово, бульвар Любы Новоселовой, 7	Россия, Московская область, Одинцовский район, Одинцово, бульвар Любы Новоселовой, 7	0101000020E610000003B68311FBA04240F015DD7A4DD74B40
59024	1	10	108	1096	5182	\N	55.679645999999998	г. Одинцово, бульвар Любы Новоселовой, 8	Россия, Московская область, Одинцовский район, Одинцово, бульвар Любы Новоселовой, 8	0101000020E6100000FD4B529962A04240B96DDFA3FED64B40
59044	1	10	108	1096	80669	\N	55.668802999999997	г. Одинцово, Солнечная, 14		0101000020E61000004B395FECBDA44240BC3B32569BD54B40
59026	1	10	108	1096	5139	\N	55.682889000000003	г. Одинцово, Северная, 60	Россия, Московская область, Одинцовский район, Одинцово, Северная улица, 60к1	0101000020E610000001FC53AA44A142402AE620E868D74B40
59029	1	10	108	1096	80670	\N	55.654817999999999	г. Одинцово, Пово-Спортивная, 3		0101000020E61000008D7E349C32A34240836A8313D1D34B40
58008	1	10	108	1096	283	\N	55.672438	г. Одинцово, Молодежная, 14	Россия, Московская область, Одинцовский район, Одинцово, Молодежная улица, 14	0101000020E61000009BABE63922A14240384BC97212D64B40
59031	1	10	108	1096	5258	\N	55.683441999999999	г. Одинцово, Можайское шоссе, 109	Россия, Московская область, Одинцовский район, Одинцово, Можайское шоссе, 109	0101000020E61000004565C39ACAA442403E5B07077BD74B40
59028	1	10	108	1096	80660	\N	55.681128000000001	г. Одинцово, Ьаршала Жукова, 38		0101000020E61000009BCAA2B08BA24240E831CA332FD74B40
59020	1	10	108	1096	80660	\N	55.678457999999999	г. Одинцово, Маршала Жукова, 26		0101000020E61000009206B7B585A14240D3DA34B6D7D64B40
59072	1	10	108	1096	80555	\N	55.656880000000001	п. ВНИИССОК, Липовая, 1		0101000020E6100000E84EB0FF3A9B4240C0B2D2A414D44B40
59047	1	10	108	1096	80675	\N	55.667192999999997	г. Одинцово, Комсомольская, 1		0101000020E6100000BCE82B4833A44240608F899466D54B40
59073	1	10	108	1096	79936	\N	55.657733	п. ВНИИССОК, Дружбы, 11		0101000020E6100000D2E5CDE15A994240FF3F4E9830D44B40
59042	1	10	108	1096	79996	\N	55.679605000000002	г. Одинцово, Вокзальная, 35А		0101000020E6100000948444DAC6A542405B99F04BFDD64B40
59098	1	10	108	60258	\N	\N	55.616027000000003	п. Новый Городок, школа	Россия, Московская область, Одинцовский район, поселок Новый Городок	0101000020E61000009F94490D6D524240FC3905F9D9CE4B40
59035	1	10	108	1576	2439	\N	55.716670999999998	с. Немчиновка, Советский проспект, 4	Россия, Московская область, Одинцовский район, село Немчиновка, Советский проспект, 4	0101000020E6100000F3C7B4368DAF4240ED7E15E0BBDB4B40
59001	1	10	108	40459	74082	\N	55.675093833551799	п. Назарьево, стр. 39		0101000020E61000005AB741EDB7844240E8DCED7A69D64B40
59049	1	10	108	20282	5500	\N	55.627990905584902	Тренажерный зал дома № 3 – 143050, Московская область, Одинцовский район, деревня Малые Вяземы, Петровское шоссе, дом № 3		0101000020E6100000C13A8E1F2A8342405797530262D04B40
59096	1	10	108	22571	72207	\N	55.636743000000003	п. Летний отдых, Зеленая, 9А		0101000020E6100000FF4124438E7B42407D7A6CCB80D14B40
59071	1	10	108	21381	5746	\N	55.637915999999997	п. Лесной Городок, Фасадная, 10	Россия, Московская область, Одинцовский район, поселок городского типа Лесной городок, Фасадная улица, 10	0101000020E6100000B8904770239B42402DCC423BA7D14B40
59070	1	10	108	61938	80470	\N	55.635472	п. Лесной Городок, Фасадная, 7		0101000020E6100000ADBEBA2A509B424009C3802557D14B40
59093	1	10	108	61938	81014	\N	55.631661000000001	д. Осоргино, административное здание пасионата		0101000020E6100000F06C8FDE709B42404F948444DAD04B40
59063	1	10	108	20908	\N	\N	55.572980999999999	г. Кубинка, поселок Сосновка, Клуб города Кубинка		0101000020E6100000CB660E492D5A42405C1D007157C94B40
59061	1	10	108	20908	\N	\N	55.576131280994801	Кубинка-8, ГДО №140	Россия, Московская область, Одинцовский район, Кубинка	0101000020E610000077F700DD975942401B9B1DA9BEC94B40
59060	1	10	108	20908	\N	\N	55.575244520199298	г. Кубинка, ГДО №140	Россия, Московская область, Одинцовский район, Кубинка, Можайское шоссе	0101000020E610000070D1C952EB5942400118CFA0A1C94B40
59088	1	10	108	22251	\N	\N	55.711503	с. Каринское, 10Б	Россия, Московская область, Одинцовский район, село Каринское	0101000020E6100000E97FB9162D584240C100C28712DB4B40
59078	1	10	108	61904	79960	\N	55.687411106503099	рп Заречье, Лучистая, главный корпус МУ	Россия, Московская область, Одинцовский район, поселок Заречье, Заречная улица, 4	0101000020E6100000E2934E2498B2424090F46915FDD74B40
59058	1	10	108	61904	80420	\N	55.688468241850799	рп Заречье, Заречная, 2	Россия, Московская область, Одинцовский район, поселок Заречье, Заречная улица, 2	0101000020E61000009758198D7CB24240D82B2CB81FD84B40
59079	1	10	108	49174	\N	\N	55.738242	д. Жуковка, Дом культуры		0101000020E61000002A00C63368A042404E44BFB67EDE4B40
59090	1	10	108	22339	5960	\N	55.646222999999999	с.Жаворонки, Лесная, 9		0101000020E610000039471D1D578D424025766D6FB7D24B40
59091	1	10	108	22339	79800	\N	55.632851823785998	с. Жаворонки, 30 лет Октября, 11	Россия, Московская область, Одинцовский район, село Жаворонки, улица 30 Лет Октября	0101000020E610000085268925E58A4240A69A594B01D14B40
59085	1	10	108	22093	\N	\N	55.759946413175498	с. Ершово, 3А	Россия, Московская область, Одинцовский район, село Ершово	0101000020E610000059198D7C5E6D4240EE5C18E945E14B40
59069	1	10	108	49025	\N	\N	55.570191999999999	п. Дубки, 9		0101000020E6100000927538BA4A4142406D382C0DFCC84B40
59084	1	10	108	59549	\N	\N	55.725594999999998	п. Горски-2, 3		0101000020E6100000EACF7EA4889442401092054CE0DC4B40
94593	1	10	108	22855	\N	\N	55.706000000000003	МУККТ «Горковский муниципальный сельский дом культуры» - 143032, Московская область, Одинцовский район, поселок Горки-10,                   дом № 6А		0101000020E6100000B517D1764C834240EE7C3F355EDA4B40
59103	1	10	108	22855	\N	\N	55.706000000000003	п. Горки-10, школа		0101000020E6100000B517D1764C834240EE7C3F355EDA4B40
58852	1	10	108	61967	\N	\N	55.717230999999998	п. Горбольница №45, 3	Россия, Московская область, Одинцовский район, поселок Горбольницы № 45	0101000020E6100000596C938AC6764240B456B439CEDB4B40
59750	1	10	108	152	5961	\N	55.611077999999999	Московская область, городской округ Серпухов, Луначарского, 33	Россия, Московская область, Одинцовский район, Голицыно, проспект Луначарского, 33	0101000020E6100000F5A10BEA5B7E42400DA7CCCD37CE4B40
59054	1	10	108	152	5547	\N	55.610523999999998	г. Голицыно, проспект Керамиков, 98	Россия, Московская область, Одинцовский район, Голицыно, проспект Керамиков, 98	0101000020E6100000DCBB067DE97B424028B682A625CE4B40
59052	1	10	108	152	5528	\N	55.619498	г. Голицыно, Советская, 58	Россия, Московская область, Одинцовский район, Голицыно, Советская улица, 56к1	0101000020E6100000A0A70183A47D4240FDF7E0B54BCF4B40
59055	1	10	108	152	5540	\N	55.609462000000001	г. Голицыно, Пролетарский проспект, 27	Россия, Московская область, Одинцовский район, Голицыно, Пролетарский проспект, 27	0101000020E61000001BF2CF0CE27D4240CF13CFD902CE4B40
59053	1	10	108	152	5540	\N	55.610123000000002	г. Голицыно, Пролетарский проспект, 50А	Россия, Московская область, Одинцовский район, Голицыно, Пролетарский проспект, 50	0101000020E610000038DA71C3EF7C4240CAC4AD8218CE4B40
59051	1	10	108	152	388	\N	55.621836000000002	г. Голицыно, Молодежный проезд, 3	Россия, Московская область, Одинцовский район, Голицыно, Молодежный проезд, 1	0101000020E6100000A3B1F677B67D4240DCBC715298CF4B40
59056	1	10	108	152	71786	\N	55.602457020281598	г. Голицыно, Минское шоссе, 45км	Россия, Московская область, Одинцовский район, Голицыно	0101000020E610000034BA83D8997E4240861F9C4F1DCD4B40
94590	1	10	108	20810	\N	\N	55.694626999999997	Административное помещение – 143059, Московская область, Одинцовский район, деревня Гигирево, дом № 1, кв. 3	Россия, Московская область, Одинцовский район, деревня Гигирево	0101000020E61000000C5C1E6B4658424094F59B89E9D84B40
59107	1	10	108	23054	\N	\N	55.610626000000003	п. Гарь-Покровское, детский сад №66	Россия, Московская область, Одинцовский район, поселок Гарь-Покровское	0101000020E61000006B65C22FF56742402D0B26FE28CE4B40
58824	1	10	108	48771	\N	\N	55.695317000000003	с. Введенское, 156А		0101000020E6100000D9942BBCCB7142402AADBF2500D94B40
58983	1	10	152	16719	4655	\N	55.832414	пос.Обухово, Советская, 25	Россия, Московская область, Ногинский район, поселок городского типа Обухово, Советская улица, 25	0101000020E61000001A4E999B6F224340C45DBD8A8CEA4B40
59074	1	10	108	62064	81057	\N	55.659211094217099	Детский сад № 6 – 143080, Московская область, Одинцовский район, поселок ВНИИССОК, улица Дружбы, дом № 11	Россия, Московская область, Одинцовский район, Одинцово, поселок ВНИИССОК, 11	0101000020E61000008D976E12839A4240EC14AB0661D44B40
59048	1	10	108	20319	\N	\N	55.638572000000003	рп Большие Вяземы, Городок-17, 20А	Россия, Московская область, Одинцовский район, поселок городского типа Большие Вяземы, поселок Городок-17, 18	0101000020E6100000CF12640454824240171230BABCD14B40
59050	1	10	108	20319	80367	\N	55.628771952023797	рп Большие Вяземы, 49	Россия, Московская область, Одинцовский район, поселок городского типа Большие Вяземы, 49	0101000020E610000012143FC6DC7F4240FC51D4997BD04B40
94591	1	10	108	21838	\N	\N	55.723232000000003	Культурный центр «Барвиха» - 143083, Московская область, Одинцовский район, поселок Барвиха, дом № 39		0101000020E61000001EFCC401F4A34240D9B5BDDD92DC4B40
59082	1	10	108	21838	\N	\N	55.723232000000003	д. Барвиха, 40		0101000020E61000001EFCC401F4A34240D9B5BDDD92DC4B40
59081	1	10	108	21838	\N	\N	55.723232000000003	п. Барвиха, Барвихинская школа	Россия, Московская область, Одинцовский район, поселок Барвиха	0101000020E61000001EFCC401F4A34240D9B5BDDD92DC4B40
58985	1	10	152	16961	4709	\N	55.726410999999999	пос. им. Воровского, Сергеева, 13 (МОУ СОШ № 39)	Россия, Московская область, Ногинский район, поселок городского типа имени Воровского, улица Сергеева	0101000020E61000001E335019FF2A4340323A2009FBDC4B40
59013	1	10	152	18299	71903	\N	55.927483000000002	с.Ямкино, Центральная усадьба, 43 (ДК)		0101000020E6100000AF25E4839E334340494C50C3B7F64B40
59012	1	10	152	18299	80855	\N	55.927483000000002	с.Ямкино, Московская, 12		0101000020E6100000AF25E4839E334340494C50C3B7F64B40
58973	1	10	152	15982	74062	\N	55.743816000000002	г.Электроугли, мкр.Светлый, 27 (Библиотека)		0101000020E6100000D2544FE61F134340EB1ED95C35DF4B40
58968	1	10	152	15982	80653	\N	55.719014000000001	"г.Электроугли, Школьная, 57 (КДЦ ""Квант"")"		0101000020E6100000BD0166BE831D4340DEAE97A608DC4B40
58971	1	10	152	15982	4566	\N	55.716163999999999	г.Электроугли, мкр.Вишняковские дачи, Советская, 11 (МОУ СОШ № 28)	Россия, Московская область, Ногинский район, Электроугли, Советская улица, 11	0101000020E6100000A915A6EF351C434049490F43ABDB4B40
58969	1	10	152	15982	4529	\N	55.7137204391667	г.Электроугли, Парковая, 20 б (МОУ СОШ № 33)	Россия, Московская область, Ногинский район, Электроугли, Парковая улица	0101000020E6100000C85D8429CA1B434025404D2D5BDB4B40
58970	1	10	152	15982	72343	\N	55.7128778748801	г.Электроугли, пл.Октября, 4 (колледж)	Россия, Московская область, Ногинский район, Электроугли, Октябрьская улица	0101000020E61000007FA31D37FC1A4340DA0418963FDB4B40
58966	1	10	152	15982	80656	\N	55.719403999999997	г.Электроугли, Маяковского, 12 (МОУ СОШ № 30, старое здание)		0101000020E6100000F3AB3940301B4340484E266E15DC4B40
59952	1	10	152	61916	80025	\N	55.812327000000003	Московская область, городской округ Фрязино, ул. Полевая, д. 18А		0101000020E61000005646239F571443403354C554FAE74B40
59006	1	10	152	17999	\N	\N	55.731311128115102	пос.Фрязево, МОУ СОШ № 41	Россия, Московская область, Ногинский район, поселок Фрязево	0101000020E61000009AB67F65A53B43403F1A4E999BDD4B40
59009	1	10	152	17999	80822	\N	55.733998999999997	пос.Фрязево, Железнодорожная, 1		0101000020E610000035D3BD4EEA3B4340FA25E2ADF3DD4B40
58988	1	10	152	47555	80827	\N	55.774335000000001	"д.Тимохово, Совхозная, 19 (СДК ""Тимоховский"")"		0101000020E6100000109546CCEC234340F792C6681DE34B40
58998	1	10	152	62024	80926	\N	55.931950999999998	д.Тимково, Школьная, МОУ ТООШ № 59	Россия, Московская область, Ногинский район, деревня Тимково	0101000020E6100000F27C06D49B4F4340BC3C9D2B4AF74B40
59004	1	10	152	17900	80930	\N	56.042225000000002	с.Стромынь, Большая Стромынка, МОУ СОШ № 54	Россия, Московская область, Ногинский район, село Стромынь	0101000020E6100000EFC9C342AD3D43406C09F9A067054C40
58989	1	10	152	17156	\N	\N	55.822305999999998	д.Старые Псарьки, МОУ СОШ № 67		0101000020E6100000BFB9BF7ADC2B4340FCA6B05241E94B40
58975	1	10	152	402	4600	\N	55.806742	г.Старая Купавна, Школьный пр-д, 2 (МОУ СОШ № 25)	Россия, Московская область, Ногинский район, Старая Купавна, Школьный проезд, 2	0101000020E6100000EBC37AA356164340A227655243E74B40
57880	1	10	152	402	5700	\N	55.803291999999999	Московская область, городской округ Долгопрудный, Октябрьская, 33	Россия, Московская область, Ногинский район, Старая Купавна, Октябрьская улица, 33	0101000020E610000036069D103A164340B891B245D2E64B40
94587	1	10	152	402	71923	\N	55.808956581156103	городское поселение Старая Купавна, город Старая Купавна Большая Масковская МОУ СОШ №22		0101000020E61000003EB0E3BF40164340656F29E78BE74B40
58978	1	10	152	402	71923	\N	55.811107999999997	г.Старая Купавна, Большая Московская, МОУ СОШ № 22		0101000020E6100000B2834A5CC716434011C30E63D2E74B40
58976	1	10	152	402	71923	\N	55.811107999999997	г.Старая Купавна, Большая Московская, 190		0101000020E6100000B2834A5CC716434011C30E63D2E74B40
58992	1	10	152	62039	\N	\N	55.835973000000003	пос.Радиоцентра-9, здание ЖКО	Россия, Московская область, Ногинский район, поселок Радиоцентра	0101000020E6100000755776C1E02C434065ABCB2901EB4B40
94589	1	10	152	48099	80817	\N	55.909539000000002	сельское поселение Ямкинское, дер. Пятково Береговая 1/1, МОУ ООШ №78	Россия, Московская область, Ногинский район, деревня Пятково	0101000020E61000009C4EB2D5E51E4340E1B721C66BF44B40
59017	1	10	152	48099	80790	\N	55.909539000000002	д.Пятково, Береговая, 2/1 (здание администрации)		0101000020E61000009C4EB2D5E51E4340E1B721C66BF44B40
58407	1	10	152	21126	80911	\N	55.853734000000003	"Московская область, городской округ Коломна, ул. Лесная, д.15, РЭУ ""Заречный"""		0101000020E6100000382F4E7CB5334340DCBDDC2747ED4B40
58387	1	10	152	16719	5404	\N	55.829841000000002	Московская область, городской округ Коломна, ул.Калинина, д.24, поликлиника	Россия, Московская область, Ногинский район, поселок городского типа Обухово, улица Калинина, 24	0101000020E6100000EBFEB1101D244340A2F0D93A38EA4B40
58980	1	10	152	16719	4655	\N	55.832414	пос.Обухово, Советская, 25 (левое фойе)	Россия, Московская область, Ногинский район, поселок городского типа Обухово, Советская улица, 25	0101000020E61000001A4E999B6F224340C45DBD8A8CEA4B40
58984	1	10	152	16719	80663	\N	55.832414	пос.Обухово, Советская, 25 (правое фойе)		0101000020E61000001A4E999B6F224340C45DBD8A8CEA4B40
58981	1	10	152	16719	80659	\N	55.834082000000002	пос.Обухово, Московская, 4 (МОУ СОШ № 24)		0101000020E610000045BC75FEED2043405517F032C3EA4B40
58982	1	10	152	16719	4674	\N	55.823818000000003	"пос.Обухово, Кудиновское ш, 8 (ЗАО ""Центрдорстрой"")"	Россия, Московская область, Ногинский район, поселок городского типа Обухово, Кудиновское шоссе, 6	0101000020E610000022533E045521434096ED43DE72E94B40
59011	1	10	152	3079	\N	\N	55.854031999999997	Ногинск-5, МОУ СОШ № 42	Россия, Московская область, Ногинский район, Ногинск, Соборная улица	0101000020E6100000A94E07B29E38434065DEAAEB50ED4B40
57976	1	10	152	3079	4050	\N	55.857038000000003	Московская область, городской округ Дубна, Энтузиастов, 9	Россия, Московская область, Ногинский район, Ногинск, шоссе Энтузиастов, 9	0101000020E6100000923CD7F7E13A4340F2B6D26BB3ED4B40
57974	1	10	152	3079	4050	\N	55.857548000000001	Московская область, городской округ Дубна, Энтузиастов, 21	Россия, Московская область, Ногинский район, Ногинск, шоссе Энтузиастов, 21	0101000020E610000055320054713B434007600322C4ED4B40
58946	1	10	152	3079	2367	\N	55.855567999999998	г.Ногинск, 3-го Интернационала, 59	Россия, Московская область, Ногинский район, Ногинск, улица Третьего Интернационала, 59	0101000020E6100000FF959526A538434087C0914083ED4B40
58959	1	10	152	3079	4334	\N	55.883246999999997	г.Ногинск, Текстилей, 17	Россия, Московская область, Ногинский район, Ногинск, улица Текстилей, 17	0101000020E6100000F5BD86E0B838434022A5D93C0EF14B40
56730	1	10	152	3079	874	\N	55.866081000000001	г.Ногинск, 28 Июня, 5	Россия, Московская область, Ногинский район, Ногинск, улица 28 Июня 1906 Года, 5	0101000020E610000098689082A7384340EF5701BEDBEE4B40
58949	1	10	152	3079	80609	\N	55.838535999999998	г.Ногинск, Юбилейная, 13		0101000020E61000009E62D520CC3343406342CC2555EB4B40
58952	1	10	152	3079	4299	\N	55.840435256446199	г.Ногинск, Электростальское шоссе, 14	Россия, Московская область, Ногинский район, Ногинск, Электростальское шоссе	0101000020E610000020274C18CD364340F6B4C35F93EB4B40
94584	1	10	152	3079	80575	\N	55.831918999999999	городское поселение Ногинск, город Ногинск Центральная 8		0101000020E610000047054EB6813D4340E4F560527CEA4B40
58948	1	10	152	3079	80603	\N	55.846800000000002	г.Ногинск, 3-го Интернационала, 117 а		0101000020E6100000C64E78094E3543405C2041F163EC4B40
58943	1	10	152	3079	80603	\N	55.844783999999997	г.Ногинск, 3-го Интернационала, 139		0101000020E6100000F7764B72C03443408F17D2E121EC4B40
58958	1	10	152	3079	79944	\N	55.891168	г.Ногинск, Советской Конституции, 58		0101000020E6100000757286E28E394340F19E03CB11F24B40
58947	1	10	152	3079	80291	\N	55.854233999999998	г.Ногинск, Советская, 57		0101000020E61000000B9B012EC8384340CD902A8A57ED4B40
58956	1	10	152	3079	4358	\N	55.879919000000001	г.Ногинск, Ремесленная, 15	Россия, Московская область, Ногинский район, Ногинск, Ремесленная улица, 15	0101000020E610000060730E9E093D43408410902FA1F04B40
58962	1	10	152	3079	80649	\N	55.876793999999997	г.Ногинск, Новая, 1		0101000020E61000003B1DC87A6A3743401DAA29C93AF04B40
58936	1	10	152	3079	4107	\N	55.850852271448403	г.Ногинск, Нижегородская, 30	Россия, Московская область, Ногинский район, Ногинск, Нижегородская улица	0101000020E6100000D1949D7E503943403CDEE4B7E8EC4B40
58945	1	10	152	3079	4142	\N	55.856378145862799	Ногинск ул. Комсомольская д. 3 МОУ СОШ № 14	Россия, Московская область, Ногинский район, Ногинск, Комсомольская улица, 1	0101000020E61000001D8EAED2DD394340C78157CB9DED4B40
94585	1	10	152	3079	80752	\N	55.864661848599198	городское поселение Ногинск, город Ногинск Климова 35, Дом художника		0101000020E6100000F0366F9C143A4340070C923EADEE4B40
58942	1	10	152	3079	80752	\N	55.862166000000002	г.Ногинск, Климова, 30 а		0101000020E61000000AD7A3703D3A434090DC9A745BEE4B40
56739	1	10	152	3079	80023	\N	55.862493999999998	г.Ногинск, Белякова, 21 а		0101000020E6100000A0A9D72D02394340847F113466EE4B40
58935	1	10	152	3079	80638	\N	55.842134999999999	г.Ногинск, Аэроклубная, 4		0101000020E61000007C444C892438434092E86514CBEB4B40
58938	1	10	152	3079	4130	\N	55.860048999999997	г.Ногинск, Автобазовая, 4	Россия, Московская область, Ногинский район, Ногинск, Автобазовая улица, 4	0101000020E610000057CEDE196D3D43408FFAEB1516EE4B40
58954	1	10	152	3079	80249	\N	55.881484999999998	г.Ногинск, Текстилей, 31		0101000020E6100000E8120EBDC537434010751F80D4F04B40
58940	1	10	152	3079	80668	\N	55.867046000000002	г.Ногинск, Климова, 48		0101000020E61000006B4606B98B3A43405610035DFBEE4B40
59008	1	10	152	18094	\N	\N	55.711072000000001	пос.Новые Дома, 6 (СДК)		0101000020E6100000EF91CD55F33A4340F88C446804DB4B40
58997	1	10	152	61900	\N	\N	55.877955	пос.Новостройка, 3 а (СДК)	Россия, Московская область, Ногинский район	0101000020E61000004F3DD2E0B62C43400A2E56D460F04B40
58964	1	10	152	15914	80095	\N	55.892702999999997	д.Молзино, Советская, 61		0101000020E610000045BC75FEED3043404205871744F24B40
58999	1	10	152	17660	\N	\N	55.949435000000001	"с.Мамонтово, Горьково, адм. здание ООО ""Элота"""	Россия, Московская область, Ногинский район, село Мамонтово	0101000020E61000000762D9CC21474340C156091687F94B40
59000	1	10	152	17660	81053	\N	55.949435000000001	" сельское поселение Мамонтовское, с. Мамонтово Горького адм. здание ООО ""Эллота"""		0101000020E61000000762D9CC21474340C156091687F94B40
58987	1	10	152	17013	71886	\N	55.766112433001197	"с.Кудиново, Центральная, 17 (СДК ""Центральный"")"	Россия, Московская область, Ногинский район, село Кудиново	0101000020E610000064963D096C1C43405D8940F50FE24B40
58986	1	10	152	17013	80825	\N	55.763088000000003	"с.Кудиново, Напрудная, 5 (СДК ""Кудиновский"")"		0101000020E6100000EC89AE0B3F1C43402BFC19DEACE14B40
58990	1	10	152	17184	\N	\N	55.789876	"д.Колонтаево, административное здание д/о ""Колонтаево"""		0101000020E61000005CCCCF0D4D21434099F221A81AE54B40
58994	1	10	152	59544	71891	\N	55.863837263020898	д.Караваево, Спортивная, 3/4 (клуб)		0101000020E610000060048D99444B43409109F83592EE4B40
59010	1	10	152	18189	\N	\N	55.742316000000002	"д.Иванисово, Ценральная усадьба, адм. здание ЗАО ""Электростальское"""		0101000020E61000002B323A20093B434016A6EF3504DF4B40
58979	1	10	152	47393	\N	\N	55.809407999999998	пос.Зеленый, 4 (МОУ СОШ № 20)		0101000020E61000001E3526C45C0C4340758F6CAE9AE74B40
59005	1	10	152	17954	\N	\N	55.715738000000002	д.Есино, 36 (фельдшерско-акушерский пункт)		0101000020E6100000350708E6E82F43409240834D9DDB4B40
94588	1	10	152	62040	\N	\N	55.843392000000001	сельское поселение Аксено-Бытурское, дер.Ельня   Библиотека	Россия, Московская область, Ногинский район, деревня Ельня	0101000020E610000055A01683872B4340A1DAE044F4EB4B40
59007	1	10	152	47906	80823	\N	55.727567000000001	пос.Елизаветино, Центральная, 29 а		0101000020E61000006B9C4D47004143400D535BEA20DD4B40
58993	1	10	152	62053	\N	\N	55.877955	пос.Горбуша, здание бывшего клуба	Россия, Московская область, Ногинский район	0101000020E61000004F3DD2E0B62C43400A2E56D460F04B40
94586	1	10	152	16279	80778	\N	55.742548999999997	городское поселение Электроугли, деревня Вишняково Школьная 1, МОУ НОШ №29		0101000020E61000007100FDBE7F154340B8567BD80BDF4B40
59002	1	10	152	17801	80940	\N	55.991706999999998	д.Боровково, поселок Фабрики, здание бывшего д/с		0101000020E61000003A75E5B33C4543406D1B4641F0FE4B40
58995	1	10	152	17446	72344	\N	55.848937017890201	д.Большое Буньково, мкр.Фабрики, 37 а	Россия, Московская область, Ногинский район, деревня Большое Буньково	0101000020E6100000639B5434D64E4340A3AEB5F7A9EC4B40
58996	1	10	152	17446	80824	\N	55.848261000000001	д.Большое Буньково, Демонстрационная, 24		0101000020E61000002BFA43334F4E434073BC02D193EC4B40
58921	1	10	260	59519	\N	\N	55.357776999999999	"Московская область, Наро-Фоминский район, п.совхоза ""Архангельский"", Здание МУК ""ДК поселка с-за ""Архангельский"""		0101000020E6100000A680B4FF01344240682101A3CBAD4B40
94644	1	10	260	49696	80756	\N	55.591894000000003	в помещении домоуправления Открытого акционерного общества санаторий «Лесное озеро», поселок Лесное озеро	Россия, Московская область, Наро-Фоминский район, коттеджный поселок Лесное озеро, Садовая улица	0101000020E6100000A9A0A2EA578C42406D59BE2EC3CB4B40
58925	1	10	260	14046	\N	\N	55.465457999999998	"Московская область, Наро-Фоминский район, д.Яковлевское, Здание ДКиС ""Яковлевское"""	Россия, Московская область, Наро-Фоминский район, деревня Яковлевское	0101000020E6100000C0EC9E3C2C784240AED4B32094BB4B40
58918	1	10	260	13690	\N	\N	55.268512999999999	Московская область, Наро-Фоминский район, д.Шустиково, Здание Шустиковского д/с		0101000020E61000009DD66D50FBFB414082C64CA25EA24B40
59101	1	10	260	49464	\N	\N	55.582940000000001	с. Шарапово, школа		0101000020E6100000E57ADB4C85964240DFC325C79DCA4B40
58920	1	10	260	13781	\N	\N	55.275975000000003	"Московская область, Наро-Фоминский район, д.Устье, Здание ЗАО ""Татищево"""		0101000020E61000001AFCFD62B62A4240BEC1172653A34B40
58930	1	10	260	14268	71785	\N	55.427273546830001	Московская область, Наро-Фоминский район, д.Таширово, Центральная, 5		0101000020E610000045F0BF95EC5442402E3718EAB0B64B40
58910	1	10	260	13327	\N	\N	55.515267999999999	Московская область, Наро-Фоминский муниципальный район, д.Софьино, Здание Софьинской СШ		0101000020E6100000A3ACDF4C4C8142407156444DF4C14B40
58923	1	10	260	13939	\N	\N	55.585759000000003	Московская область, Наро-Фоминский район, п.совхоза Крекшино, Здание МОУ Крекшинская СОШ	Россия, Московская область, Наро-Фоминский район, поселок Совхоза Крекшино	0101000020E610000050C422861D8E4240392BA226FACA4B40
58891	1	10	260	12454	80983	\N	55.384999000000001	Московская область, Наро-Фоминский район, д.Симбухово, Нарская, стр.12		0101000020E610000098A59D9ACB27424011FFB0A547B14B40
58907	1	10	260	60222	\N	\N	55.512860820188003	"Московская область, Наро-Фоминский муниципальный район, п.Селятино, Здание спорткомбината ""Строитель"""		0101000020E6100000857CD0B3597D42406A32E36DA5C14B40
58908	1	10	260	13133	\N	\N	55.514468000000001	Московская область, Наро-Фоминский муниципальный район, п.Селятино, Здание Селятинской СОШ №2	Россия, Московская область, Наро-Фоминский район, поселок городского типа Селятино	0101000020E61000003A24B550327D4240556B6116DAC14B40
58906	1	10	260	13133	\N	\N	55.514468000000001	Московская область, Наро-Фоминский муниципальный район, п.Селятино, Здание Селятинской СОШ №1	Россия, Московская область, Наро-Фоминский район, поселок городского типа Селятино	0101000020E61000003A24B550327D4240556B6116DAC14B40
58892	1	10	260	12509	80981	\N	55.379465000000003	Московская область, Наро-Фоминский район, д.Рождествено, Школьная, стр.16		0101000020E6100000F1643733FA154240037D224F92B04B40
58924	1	10	260	62042	80989	\N	55.478088608038497	Московская область, Наро-Фоминский район, п.Рассудово, Майская, 25	Россия, Московская область, Наро-Фоминский район, поселок Рассудово	0101000020E610000014CE6E2D93754240E6C9350532BD4B40
58928	1	10	260	14117	\N	\N	55.518810000000002	"Московская область, Наро-Фоминский район, п.Птичное, Здщание ОНО ХО ГУП ППЗ ""Птичное"""	Россия, Московская область, Наро-Фоминский район, поселок Птичное	0101000020E6100000ED815660C89C42403C6BB75D68C24B40
58927	1	10	260	14117	\N	\N	55.518810000000002	"Московская область, Наро-Фоминский район, п.Птичное, Здание ДКиС ""Десна"""		0101000020E6100000ED815660C89C42403C6BB75D68C24B40
58893	1	10	260	12582	81013	\N	55.335438000000003	Московская область, Наро-Фоминский район, п.Пионерский, Центральная		0101000020E61000005723BBD232144240F7EAE3A1EFAA4B40
58926	1	10	260	14104	72038	\N	55.535353975595598	Московская область, Наро-Фоминский район, п.Первомайское, Центральная	Россия, Московская область, Наро-Фоминский район, поселок Первомайское	0101000020E6100000D7FA22A12D95424032E4D87A86C44B40
58914	1	10	260	13518	71901	\N	55.30377	Московская область, Наро-Фоминский район, п.Новая Ольховка, Школьная, 2/1		0101000020E61000000DA661F888524240C2C073EFE1A64B40
58875	1	10	260	1095	80604	\N	55.411403999999997	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Шибанкова, 13		0101000020E61000000262122EE45B4240C7B8E2E2A8B44B40
58874	1	10	260	1095	80604	\N	55.413550000000001	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Шибанкова, 44		0101000020E61000001AC231CB9E5C424062A1D634EFB44B40
94579	1	10	260	1095	81045	\N	55.372529129319901	Московская область, Наро-Фоминский район, г.Наро-Фоминск Чехова 1а	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, улица Чехова, 3	0101000020E6100000A6D1E4620C5C4240E2E7BF07AFAF4B40
58841	1	10	260	1095	2866	\N	55.376973999999997	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Профсоюзная, 9а	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, Профсоюзная улица, 9а	0101000020E6100000F6D1A92B9F5D42409DB81CAF40B04B40
58861	1	10	260	1095	72323	\N	55.384454518428598	Московская область, Наро-Фоминский район, г.Наро-Фоминск, М.Жукова, 10	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, улица Маршала Жукова, 10	0101000020E6100000971E4DF5645C424050E449D235B14B40
58863	1	10	260	1095	80344	\N	55.377982000000003	Наро-Фоминский район, Московская область, г.Наро-Фоминск, Ленина, 23		0101000020E6100000DD9A745B225D4240043DD4B661B04B40
58678	1	10	260	1095	80344	\N	55.381346999999998	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Ленина, 17		0101000020E610000062BD512B4C5D4240BFB67EFACFB04B40
58860	1	10	260	1095	3118	\N	55.384200999999997	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Комсомольская, 9	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, Комсомольская улица, 9	0101000020E6100000910C39B69E5B4240950B957F2DB14B40
58868	1	10	260	1095	80629	\N	55.386108	Московская область, Наро-Фоминский район, г.Наро-Фоминск, Ефремова, 11		0101000020E6100000DD26DC2BF35E4240AB5CA8FC6BB14B40
58869	1	10	260	1095	3231	\N	55.388103000000001	Московская область, Наро-Фоминский район, г.Наро-Фоминск, 2-й Володарский пер, 4	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, 2-й Володарский переулок, 4	0101000020E61000001D774A07EB5F4240603DEE5BADB14B40
94580	1	10	260	1095	16892	\N	55.379460000000002	Московская область, Наро-Фоминский район, г.Наро-Фоминск 1-й Брянский переулок (ООО "УК Жилкомсервис") 1, часть 1	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, 1-й Колхозный переулок, 1	0101000020E61000007D957CEC2E5C4240F111312592B04B40
59154	1	10	260	40475	\N	\N	55.372824999999999	д. Назарьево, д.160		0101000020E610000036E50AEF72334240CB10C7BAB8AF4B40
58922	1	10	260	13891	80634	\N	55.593277999999998	Московская область, Наро-Фоминский район, д.Марушкино, Липовая аллея, 6		0101000020E6100000E6AE25E4839A4240D8B79388F0CB4B40
58888	1	10	260	61989	\N	\N	55.522062829775997	Московская область, Наро-Фоминский район, д.Мартемьяново, 104а	Россия, Московская область, Наро-Фоминский район, деревня Мартемьяново	0101000020E610000078616BB6F2884240D0B9DBF5D2C24B40
58932	1	10	260	14389	\N	\N	55.448199000000002	Московская область, Наро-Фоминский район, д.Любаново, Здание Любановского сельского клуба	Россия, Московская область, Наро-Фоминский район, деревня Любаново	0101000020E61000009F5912A0A64E4240CA8CB7955EB94B40
60046	1	10	260	4480	\N	\N	55.265065999999997	д.Крюково, д.17, Средняя общеобразовательная школа		0101000020E6100000FE7F9C3061F6414009A4C4AEEDA14B40
58905	1	10	260	13041	80646	\N	55.600740000000002	Московская область, Наро-Фоминский муниципальный район, п.Кокошкино, Ленина, 2		0101000020E61000005567B5C01E95424014B35E0CE5CC4B40
58904	1	10	260	61923	80066	\N	55.596772999999999	Московская область, Наро-Фоминский муниципальный район, п.Кокошкино, Дачная, 3а		0101000020E61000008198840B799442406211C30E63CC4B40
59233	1	10	260	28906	\N	\N	55.323874000000004	д. Ковригино, д.156		0101000020E6100000AB3DEC85021A42402A0307B474A94B40
58903	1	10	260	12922	\N	\N	55.430650999999997	Московская область, Наро-Фоминский муниципальный район, п.Киевский, Здание СОШ п.Киевский	Россия, Московская область, Наро-Фоминский район, поселок городского типа Киевский	0101000020E6100000EA25C632FD6E4240AE7E6C921FB74B40
58902	1	10	260	12922	\N	\N	55.430650999999997	Московская область, Наро-Фоминский муниципальный район, п.Киевский, 24	Россия, Московская область, Наро-Фоминский район, поселок городского типа Киевский	0101000020E6100000EA25C632FD6E4240AE7E6C921FB74B40
58901	1	10	260	12922	\N	\N	55.430650999999997	Московская область, Наро-Фоминский муниципальный район, п.Киевский, Здание общежития, общ	Россия, Московская область, Наро-Фоминский район, поселок городского типа Киевский	0101000020E6100000EA25C632FD6E4240AE7E6C921FB74B40
58915	1	10	260	13569	\N	\N	55.269410000000001	"Московская область, Наро-Фоминский район, с.Каменское, Здание МОУ ""Каменская СОШ"""	Россия, Московская область, Наро-Фоминский район, село Каменское	0101000020E6100000BFB5132521694240919BE1067CA24B40
94583	1	10	260	12600	\N	\N	55.553918406803902	Московская область, Наро-Фоминский муниципальный район, п.Калининец МУ "СДЦ Калининец", спортивный зал 233/1		0101000020E6100000E8DB82A5BA7C42403755F7C8E6C64B40
58900	1	10	260	12600	\N	\N	55.534174	Московская область, Наро-Фоминский муниципальный район, с.Петровское, 1	Россия, Московская область, Наро-Фоминский район, поселок Калининец, село Петровское	0101000020E6100000CBF78C44687E4240CF2F4AD05FC44B40
58897	1	10	260	12600	\N	\N	55.544758999999999	Московская область, Наро-Фоминский муниципальный район, п.Калининец, 233. к.1	Россия, Московская область, Наро-Фоминский район, поселок Калининец	0101000020E6100000957F2DAF5C7D4240D099B4A9BAC54B40
58896	1	10	260	12600	\N	\N	55.544758999999999	Московская область, Наро-Фоминский район, п.Калининец, 233, к.1	Россия, Московская область, Наро-Фоминский район, поселок Калининец	0101000020E6100000957F2DAF5C7D4240D099B4A9BAC54B40
58894	1	10	260	12600	71777	\N	55.555050145890398	Московская область, Наро-Фоминский район, п.Калининец, мкрн Тарасково		0101000020E6100000315EF3AACE7C424089D2DEE00BC74B40
58895	1	10	260	12600	71774	\N	55.554988761049898	Московская область, Наро-Фоминский район, п.Калининец, мкрн КЭЧ, 245		0101000020E61000000C207C28D17C4240E3512AE109C74B40
58899	1	10	260	12600	74151	\N	55.526499999999999	Московская область, Наро-Фоминский муниципальный район, п.Калининец, Фабричная, 1		0101000020E610000045662E70797C424008AC1C5A64C34B40
58929	1	10	260	59527	\N	\N	55.507586336595601	Московская область, Наро-Фоминский район, х.Ильичевка, Здание ДК х.Ильичевка, 5	Россия, Московская область, Наро-Фоминский район, хутор Ильичёвка	0101000020E6100000F758FAD005A3424028F4FA93F8C04B40
58867	1	10	260	11319	\N	\N	55.375317000000003	Московская область, Наро-Фоминский район, д.Ивановка, Здание библиотеки (читальный зал)		0101000020E610000019AC38D55A664240015130630AB04B40
58558	1	10	260	28167	80951	\N	55.500819999999997	д.Десна, ул.Административная, д.9а		0101000020E61000008B6D52D1589942406397A8DE1AC04B40
58933	1	10	260	14400	\N	\N	55.489809999999999	Московская область, Наро-Фоминский район, д.Головково, Здание ДК	Россия, Московская область, Наро-Фоминский район, деревня Головково	0101000020E61000006E52D158FB4142407BA01518B2BE4B40
58931	1	10	260	59560	\N	\N	55.367041284894697	Московская область, Наро-Фоминский район, г.Наро-Фоминск-10, Здание гарнизонного офицерского клуба	Россия, Московская область, Наро-Фоминский район, садовое товарищество Восток	0101000020E61000006A4E5E640244424044A51133FBAE4B40
58919	1	10	260	13746	\N	\N	55.318700999999997	"Московская область, Наро-Фоминский район, д.Волченки, Здание ООО ""Агрофирма ""Ковригино"""		0101000020E6100000B4588AE42B1F4240EB19C231CBA84B40
58917	1	10	260	13660	\N	\N	55.305466000000003	Московская область, Наро-Фоминский район, д.Веселево, Здание Веселевской СОШ	Россия, Московская область, Наро-Фоминский район, деревня Веселево	0101000020E610000061E0B9F7700B42401D05888219A74B40
58890	1	10	260	12366	79935	\N	55.3425596547374	Московская область, Наро-Фоминский район, г.Верея, пл.Советская, стр.8/1	Россия, Московская область, Наро-Фоминский район, Верея, Первомайская улица	0101000020E6100000CD9541B5C117424079758E01D9AB4B40
58871	1	10	260	61984	\N	\N	55.423549999999999	Московская область, Наро-Фоминский район, п.д/о Бекасово, Здание Бекасовской СОШ	Россия, Московская область, Наро-Фоминский район, поселок Бекасово	0101000020E61000002C7FBE2D58664240431CEBE236B64B40
57620	1	10	260	58932	67047	\N	55.508645999999999	Московская область, городской округ Балашиха, Орджоникидзе, 14		0101000020E6100000452E3883BF8F4240E09EE74F1BC14B40
58912	1	10	260	13409	\N	\N	55.330787999999998	Московская область, Наро-Фоминский муниципальный район, с.Атепцево, Совхозная, 3	Россия, Московская область, Наро-Фоминский район, село Атепцево	0101000020E6100000D06394675E60424062F4DC4257AA4B40
58913	1	10	260	13409	74146	\N	55.325031460472601	Московская область, Наро-Фоминский район, с.Атрепцево, Речная, 1а	Россия, Московская область, Наро-Фоминский район, село Атепцево	0101000020E6100000CE18E6046D604240D597A59D9AA94B40
58886	1	10	260	2721	79934	\N	55.537699000000003	Московская область, Наро-Фоминский район, г.Апрелевка, Школьная, 4		0101000020E6100000F9D687F546874240C40B2252D3C44B40
94567	1	10	260	2721	704	\N	55.540638000000001	Ул. Спортивная, д. 4,  помещение ДК	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 4	0101000020E610000088D7F50B76874240C87C40A033C54B40
60226	1	10	260	2721	704	\N	55.538238999999997	Московская область, городской округ Электросталь, Спортивная, 12	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 12	0101000020E6100000D06394675E8642404337FB03E5C44B40
57887	1	10	260	2721	704	\N	55.540832000000002	Московская область, городской округ Долгопрудный, Спортивная, 2	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 2	0101000020E610000098E0D40792874240AD50A4FB39C54B40
58885	1	10	260	2721	80632	\N	55.550885999999998	Московская область, Наро-Фоминский район, г.Апрелевка, Самохина, 9		0101000020E610000052B81E85EB87424081E9B46E83C64B40
58884	1	10	260	2721	3418	\N	55.556109999999997	Московская область, Наро-Фоминский район, г.Апрелевка, Парковая, 6, к.3	Россия, Московская область, Наро-Фоминский район, Апрелевка, Парковая улица, 6/3	0101000020E61000008E5A61FA5E894240417DCB9C2EC74B40
94581	1	10	260	2721	80832	\N	55.5648129106279	Московская область, Наро-Фоминский район, г.Апрелевка, Куйбышева(Апрелевская СОШ № 2)	Россия, Московская область, Наро-Фоминский район, Апрелевка, улица Куйбышева	0101000020E610000085950A2AAA8C424086ADD9CA4BC84B40
58880	1	10	260	2721	3374	\N	55.552816	Московская область, Наро-Фоминский район, г.Апрелевка, Комсомольская, 15а	Россия, Московская область, Наро-Фоминский район, Апрелевка, Комсомольская улица, 15а	0101000020E6100000904AB1A3718A42404F5AB8ACC2C64B40
58882	1	10	260	2721	80645	\N	55.544606000000002	Московская область, Наро-Фоминский район, г.Апрелевка, Горького, 2		0101000020E610000045D8F0F44A8942404A9A3FA6B5C54B40
94582	1	10	260	2721	80413	\N	55.538356	Московская область, Наро-Фоминский район, г.Апрелевка, Апрелевская, 65 (здание ЦНИИЭПсельстрой)		0101000020E6100000AC8C463EAF8842407DCD72D9E8C44B40
58357	1	10	1350	18506	\N	\N	55.214480999999999	Московская область, Коломенский  район, деревня Новая, Здание клуба		0101000020E6100000A96C585359724340834E081D749B4B40
58909	1	10	260	13293	\N	\N	55.526737528592299	Московская область, Наро-Фоминский муниципальный район, д.Алабино, Здание ПУ №71	Россия, Московская область, Наро-Фоминский район, деревня Алабино	0101000020E6100000274D83A2797E4240BDC799266CC34B40
59932	1	10	464	22526	\N	\N	56.001745999999997	деревня Юдино, Юдинский сельский Дом культуры, дом 16		0101000020E610000092239D8191DD42400C73823639004C40
58848	1	10	464	10414	\N	\N	56.051611999999999	Московская область, Мытищинский муниципальный район, село Федоскино, в помещении административного здани		0101000020E61000001DC9E53FA4C94240630AD6389B064C40
58845	1	10	464	59366	\N	\N	55.994798237071798	Московская область, Мытищинский муниципальный район, пос. Туристический Пансионат «Клязьминское водохранилище», общеобразовательная школа №22		0101000020E6100000A376BF0AF0D542402810768A55FF4B40
58836	1	10	464	9806	\N	\N	55.985772406246099	Московская область, Мытищинский муниципальный район, село Троицкое, в помещении санатория «Дружба»	Россия, Московская область, Мытищинский район, село Троицкое	0101000020E6100000B876A22424CA424000A8E2C62DFE4B40
58851	1	10	464	10586	\N	\N	56.077351999999998	Московская область, Мытищинский муниципальный район, дер. Сухарево, дом 56		0101000020E61000005DFE43FAEDC14240DD239BABE6094C40
58837	1	10	464	9866	\N	\N	55.977252318025002	Московская область, Мытищинский муниципальный район, пос. Поведники, Поведниковская школа		0101000020E610000080B74082E2CD4240ADF9F19716FD4B40
58840	1	10	464	10013	80625	\N	55.980497999999997	Московская область, Мытищинский муниципальный район, пос. Пироговский, улица Пионерская, дом 4		0101000020E610000008AC1C5A64DF42408EE55DF580FD4B40
58842	1	10	464	10103	\N	\N	55.983701000000003	Московская область, Мытищинский муниципальный район, дер. Пирогово, в помещении ДК «Пироговский»	Россия, Московская область, Мытищинский район, деревня Пирогово	0101000020E6100000B4E89D0AB8DD4240710514EAE9FD4B40
58816	1	10	464	2720	2467	\N	55.906047000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Щербакова, дом 1а	Россия, Московская область, Мытищинский район, Мытищи, улица Щербакова, 1а	0101000020E61000002461DF4E22DE4240C8D11C59F9F34B40
58811	1	10	464	2720	2399	\N	55.915382000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Мира, дом 22	Россия, Московская область, Мытищинский район, Мытищи, улица Мира, 22	0101000020E61000000306499F56DD42406DACC43C2BF54B40
58806	1	10	464	2720	2316	\N	55.917647000000002	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Комарова, дом 5	Россия, Московская область, Мытищинский район, Мытищи, улица Комарова, 5	0101000020E61000003F1BB96E4ADF4240E222F77475F54B40
58807	1	10	464	2720	2410	\N	55.913929328107699	Московская область, Мытищинский муниципальный район, г. Мытищи, Новомытищинский проспект, дом 22	Россия, Московская область, Мытищинский район, Мытищи, улица Колпакова, 2/22	0101000020E61000007E3B8908FFDE4240D9EE1EA0FBF44B40
58832	1	10	464	2720	2656	\N	55.896099999999997	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Веры Волошиной, дом 56	Россия, Московская область, Мытищинский район, Мытищи, улица Веры Волошиной, 56	0101000020E61000008BDD3EABCCDA424009F9A067B3F24B40
58804	1	10	464	2720	2269	\N	55.924734000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Белобородова, дом 2 корп.3	Россия, Московская область, Мытищинский район, Мытищи, улица Белобородова, 2к3	0101000020E61000005401F73C7FE04240E8BF07AF5DF64B40
58825	1	10	464	2720	2437	\N	55.904013999999997	Московская область, Мытищинский муниципальный район, г. Мытищи, Юбилейная улица, дом 42, корп.2	Россия, Московская область, Мытищинский район, Мытищи, Юбилейная улица, 42к2	0101000020E610000045B9347EE1D94240259012BBB6F34B40
94577	1	10	464	2720	80092	\N	55.911714000000003	г. Мытищи, Юбилейная улица, дом 13, корп.2, в помещении МОУ средняя общеобразовательная школа №26;		0101000020E61000005C38109205DC424016A75A0BB3F44B40
58819	1	10	464	2720	80092	\N	55.911714000000003	Московская область, Мытищинский муниципальный район, г. Мытищи, Юбилейная улица, дом 13, корп.2		0101000020E61000005C38109205DC424016A75A0BB3F44B40
58787	1	10	464	2720	2045	\N	55.891976	Московская область, Мытищинский муниципальный район, г. Мытищи, Школьный переулок, дом 3, в помещении МОУ средняя	Россия, Московская область, Мытищинский район, Мытищи, Школьный переулок, 3	0101000020E6100000C51EDAC70ADE4240906802452CF24B40
58808	1	10	464	2720	80628	\N	55.913393999999997	Московская область, Мытищинский муниципальный район, г. Мытищи, Шараповская улица, дом 6 корп.2		0101000020E61000002E1B9DF353E042406A2E3718EAF44B40
58798	1	10	464	2720	74131	\N	55.9328210860361	"Московская область, Мытищинский муниципальный район, г. Мытищи, улица Чапаева, в помещении санатория «Подлипки»,"	Россия, Московская область, Мытищинский район, Мытищи, улица Чапаева	0101000020E6100000C5AD8218E8E64240D102B4AD66F74B40
58801	1	10	464	2720	702	\N	55.927916000000003	Московская область, Мытищинский муниципальный район, г. Мытищи, Силикатная улица, дом 12	Россия, Московская область, Мытищинский район, Мытищи, Силикатная улица, 12	0101000020E610000082CAF8F719E34240B3B794F3C5F64B40
58800	1	10	464	2720	702	\N	55.941459999999999	Московская область, Мытищинский муниципальный район, г. Мытищи, Силикатная улица, дом 36	Россия, Московская область, Мытищинский район, Мытищи, Силикатная улица, 36	0101000020E6100000EC8A19E1EDE34240FF3EE3C281F84B40
58802	1	10	464	2720	80071	\N	55.924907488747301	Московская область, Мытищинский муниципальный район, г. Мытищи, Силикатная улица, дом 1/9	Россия, Московская область, Мытищинский район, Мытищи, Силикатная улица, 1	0101000020E6100000412E71E481E24240B56B425A63F64B40
58827	1	10	464	2720	2327	\N	55.899960999999998	Московская область, Мытищинский муниципальный район, . Мытищи, Новомытищинский проспект, дом 88, корп.5	Россия, Московская область, Мытищинский район, Мытищи, Новомытищинский проспект, 88к5	0101000020E6100000CEE15AED61DB424075560BEC31F34B40
58821	1	10	464	2720	2327	\N	55.902898	Московская область, Мытищинский муниципальный район, г. Мытищи, Новомытищинский проспект, дом 39, корп.3	Россия, Московская область, Мытищинский район, Мытищи, Новомытищинский проспект, 39к3	0101000020E6100000E04C4C1762DD4240D9CF622992F34B40
58823	1	10	464	2720	2456	\N	55.907772999999999	Московская область, Мытищинский муниципальный район, г. Мытищи, Летная улица, дом 30, корп.2	Россия, Московская область, Мытищинский район, Мытищи, Летная улица, 30к2	0101000020E6100000D11E2FA4C3DB42408D98D9E731F44B40
94578	1	10	464	2720	80085	\N	55.913868000000001	г. Мытищи, Летная улица, дом 14, корп.1, в помещении центральной библиотеки ЦБС Мытищинского района;		0101000020E610000072FBE59315DD4240336E6AA0F9F44B40
58789	1	10	464	2720	80060	\N	55.915765	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Карла Маркса, дом 4, в помещении администра		0101000020E6100000EA3E00A94DE2424025E99AC937F54B40
58828	1	10	464	2720	80624	\N	55.896473999999998	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Веры Волошиной, дом 24		0101000020E610000032384A5E9DDB42406EDBF7A8BFF24B40
58795	1	10	464	2720	80516	\N	55.918010000000002	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Академика Каргина, дом 38, корп.4		0101000020E61000004E44BFB67EE4424053B3075A81F54B40
58793	1	10	464	2720	80516	\N	55.916446000000001	Московская область, Мытищинский муниципальный район, г. Мытищи, улица Академика Каргина, дом 36, корп.2, в помеще		0101000020E6100000494DBB9866E4424067463F1A4EF54B40
58799	1	10	464	2720	2205	\N	55.946885000000002	Московская область, Мытищинский муниципальный район, г. Мытищи, 2-я Новая улица, дом 30	Россия, Московская область, Мытищинский район, Мытищи, 2-я Новая улица, 30	0101000020E61000002EE57CB1F7E442405709168733F94B40
58797	1	10	464	2720	2176	\N	55.929942258859299	Московская область, Мытищинский муниципальный район, г. Мытищи, 2-я Институтская улица, общежитие №5 Московского государств	Россия, Московская область, Мытищинский район, Мытищи, 2-я Институтская улица, 20	0101000020E61000009FCBD42478E54240A296E65608F74B40
58791	1	10	464	2720	2106	\N	55.91798	Московская область, Мытищинский муниципальный район, г. Мытищи, 2-й Первомайский проезд, дом 1	Россия, Московская область, Мытищинский район, Мытищи, 2-й Первомайский проезд, 1	0101000020E61000003561FBC918E34240E8305F5E80F54B40
58830	1	10	464	2720	2690	\N	55.890860000000004	Московская область, Мытищинский муниципальный район, г. Мытищи, 1-я Крестьянская улица, дом 14	Россия, Московская область, Мытищинский район, Мытищи, 1-я Крестьянская улица, 14	0101000020E610000009DE904605DC424044A852B307F24B40
58796	1	10	464	2720	2146	\N	55.920799375143901	Московская область, Мытищинский муниципальный район, г. Мытищи, 1-й Щелковский проезд, дом 9	Россия, Московская область, Мытищинский район, Мытищи, 1-й Щелковский проезд, 9	0101000020E6100000F7B0170AD8E442404298DBBDDCF54B40
58794	1	10	464	2720	2146	\N	55.920955999999997	Московская область, Мытищинский муниципальный район, г. Мытищи, 1-й Щелковский проезд, дом 9, в помещении МОУ лиц		0101000020E61000000F0D8B51D7E442400987DEE2E1F54B40
58850	1	10	464	10511	\N	\N	56.073971	Московская область, Мытищинский муниципальный район, село Марфино, Марфинская средняя школа	Россия, Московская область, Мытищинский район, село Марфино	0101000020E6100000CA8CB7955EC742401CEDB8E177094C40
58853	1	10	464	10511	71879	\N	56.073971	Московская область, Мытищинский муниципальный район, село Марфино, улица Усадебная, дом 21А		0101000020E6100000CA8CB7955EC742401CEDB8E177094C40
58846	1	10	464	10313	\N	\N	56.015017	Московская область, Мытищинский муниципальный район, дер. Манюхино, в помещении сельского ДК «Манюхинск		0101000020E61000000C5BB39597DC424028F1B913EC014C40
58847	1	10	464	10364	80773	\N	55.988832000000002	Московская область, Мытищинский муниципальный район, дер. Красная Горка, ул. Светлая, дом 16		0101000020E6100000F08B4B55DAC24240809E060C92FE4B40
58843	1	10	464	10157	80831	\N	55.958565511118998	Московская область, Мытищинский муниципальный район, пос. Здравница,улица Дубки, дом 1	Россия, Московская область, Мытищинский район, поселок Здравница, 1	0101000020E610000036CEA62380DD42405D876A4AB2FA4B40
58844	1	10	464	10219	\N	\N	56.007685000000002	Московская область, Мытищинский муниципальный район, дер. Жостово, в помещении сельского ДК «Жостовски	Россия, Московская область, Мытищинский район, поселок Жостово	0101000020E610000079E57ADB4CD34240BBD573D2FB004C40
58835	1	10	464	62061	\N	\N	55.945587593141298	Московская область, Мытищинский муниципальный район, село Виноградово, строение 36-Г		0101000020E61000007FFB3A70CEC44240BABE0F0709F94B40
58834	1	10	464	9701	80739	\N	55.926428999999999	Московская область, Мытищинский муниципальный район, пос. Вешки, улица Заводская, дом 5		0101000020E610000054FCDF1115CE42407288B83995F64B40
58833	1	10	464	9644	\N	\N	55.923896999999997	Московская область, Мытищинский муниципальный район, дер. Бородино, администрация городского поселения		0101000020E6100000FDF9B660A9D44240AEEFC34142F64B40
58854	1	10	464	10691	\N	\N	56.136116000000001	Московская область, Мытищинский муниципальный район, дер. Большое Ивановское, дом 113		0101000020E610000093567C43E1C742402E3BC43F6C114C40
58838	1	10	464	9913	\N	\N	55.968141000000003	Московская область, Мытищинский муниципальный район, дер. Болтино, в помещении клуба		0101000020E6100000AEF545425BD642405875560BECFB4B40
58839	1	10	464	9969	\N	\N	55.949869	Московская область, Мытищинский муниципальный район, дер. Беляниново, общеобразовательная школа № 29		0101000020E61000001FF46C567DD24240FB3DB14E95F94B40
58849	1	10	464	10483	\N	\N	56.042833999999999	Московская область, Мытищинский муниципальный район, дер. Аксаково, в помещении пансионата «Русь»		0101000020E6100000618A7269FCCE42401494A2957B054C40
58373	1	10	7507	60426	74999	\N	55.086109999999998	Московская область, городской округ Коломна, ул.Октябрьской революции, д.318, ЦРБ		0101000020E610000013B534B742664340E5ED08A7058B4B40
58774	1	10	670	61960	\N	\N	55.526331999999996	"Московская область, Можайский муниципальный район, сельское поселение Порецкое,  пос. ц/у с-за ""Синичино"", 30"		0101000020E6100000DEC66647AAE141404C6BD3D85EC34B40
58751	1	10	670	5747	\N	\N	55.510781999999999	Московская область, Можайский муниципальный район, городское поселение Можайск, пос. им Дзержинского, Центр культуры и искусств	Россия, Московская область, Можайский район, поселок имени Дзержинского	0101000020E6100000336B2920ED07424057B1F84D61C14B40
58744	1	10	670	5350	\N	\N	55.485474000000004	Московская область, Можайский муниципальный район, городское поселение Можайск, д. Ямская, Отдел УФМС, 47		0101000020E6100000431A1538D90242407787140324BE4B40
58754	1	10	670	5872	\N	\N	55.504573000000001	Московская область, Можайский муниципальный район, городское поселение Уваровка, д. Шохово, детский сад №22		0101000020E6100000E257ACE122D14140E9B81AD995C04B40
58776	1	10	670	7021	\N	\N	55.510689999999997	"Московская область, Можайский муниципальный район, сельское поселение Спутник, д.Шаликово, Сельский клуб ""Шаликово"""		0101000020E6100000E01115AA9B1B42407632384A5EC14B40
58766	1	10	670	6532	\N	\N	55.527555	"Московская область, Можайский муниципальный район, сельское поселение Дровнинское, пос.Цветковский, КДЦ ""Цветковский"""		0101000020E610000098FC4FFEEEB34140AFEB17EC86C34B40
58753	1	10	670	5763	80758	\N	55.527009999999997	Московская область, Можайский муниципальный район, городское поселение Уваровка, пос. Уваровка, Урицкого, 32 (Средняя школа)		0101000020E61000008099EFE027CE41401D554D1075C34B40
94575	1	10	670	5763	80868	\N	55.528019999999998	в помещении муниципального учреждения культуры «Уваровский культурно-досуговый центр» (фойе) по адресу: поселок Уваровка, ул. Партизанская	Россия, Московская область, Можайский район, поселок городского типа Уваровка	0101000020E6100000F1BDBF417BCD414024D1CB2896C34B40
94574	1	10	670	5763	80842	\N	55.531008	в помещении муниципального учреждения культуры «Уваровский культурно-досуговый центр» (танцевальный зал) по адресу: поселок Уваровка, ул. Партизанская	Россия, Московская область, Можайский район, поселок городского типа Уваровка	0101000020E6100000691EC022BFCC41400AF5F411F8C34B40
58781	1	10	670	7203	\N	\N	55.374237000000001	Московская область, Можайский муниципальный район, сельское поселение Юрловское, с.Тропарево, Советская, 14 (администрация С/П)	Россия, Московская область, Можайский район, деревня Тропарево	0101000020E6100000D95BCAF962F3414001FA7DFFE6AF4B40
58780	1	10	670	7203	80977	\N	55.374237000000001	Московская область, Можайский муниципальный район, сельское поселение Юрловское, с. Тропарево, Советская, 14 (администрация С/П)		0101000020E6100000D95BCAF962F3414001FA7DFFE6AF4B40
58763	1	10	670	6379	\N	\N	55.594183999999998	"Московская область, Можайский муниципальный район, сельское поселение Бородинское, д.Троица, Троицкий клуб ""Сельский КДЦ ""Горки"""		0101000020E610000064AE0CAA0DE441403AE7A7380ECC4B40
58750	1	10	670	5603	\N	\N	55.497504999999997	"Московская область, Можайский муниципальный район, городское поселение Можайск, пос.Строитель, Актовый зал ЗАО ""198 КЖИ"""		0101000020E6100000FAD4B14AE9074240594C6C3EAEBF4B40
58749	1	10	670	5603	\N	\N	55.498114191483097	Московская область, Можайский муниципальный район, городское поселение Можайск, пос.Строитель, Профессиональное училище №97	Россия, Московская область, Можайский район, поселок Строитель	0101000020E610000049658A390808424002D71533C2BF4B40
58775	1	10	670	6957	\N	\N	55.512923000000001	"Московская область, Можайский муниципальный район, сельское поселение Спутник, пос. Спутник, КДЦ ""Спутник"""	Россия, Московская область, Можайский район, поселок Спутник	0101000020E61000009207228B340D4240E02EFB75A7C14B40
58783	1	10	670	7290	80733	\N	55.342826000000002	Московская область, Можайский муниципальный район, сельское поселение Юрловское, с. Сокольниково, Школьная, 1 (Средняя школа)		0101000020E6100000BC5D2F4D11E84140F81BEDB8E1AB4B40
58782	1	10	670	7290	80733	\N	55.353547987826801	Московская область, Можайский муниципальный район, сельское поселение Юрловское, с.Сокольниково, Школьная, 1 (Средняя школа)	Россия, Московская область, Можайский район, село Сокольниково	0101000020E61000001D76DF313CE841407AC8940F41AD4B40
38626	1	6	1067	20605	35294	\N	54.54325	Поселок Ферзиково, Карпова, 20		0101000020E6100000041DAD6A495F4240A8C64B3789454B40
58768	1	10	670	6611	\N	\N	55.509849000000003	"Московская область, Можайский муниципальный район, сельское поселение Замошинское, с.Семеновское, ДК КДЦ ""Замошинское"""		0101000020E610000093C83EC8B2EA4140FC7266BB42C14B40
58772	1	10	670	6829	\N	\N	55.7129988236779	"Московская область, Можайский муниципальный район, сельское поселение Порецкое, д.Поречье, КДЦ ""Поречье"""	Россия, Московская область, Можайский район, село Поречье	0101000020E610000075E61E12BEC74140558A1D8D43DB4B40
58771	1	10	670	6756	\N	\N	55.568415000000002	Московская область, Можайский муниципальный район, сельское поселение Клементьевское, д.Павлищево, Павлищевский ДК	Россия, Московская область, Можайский район, деревня Павлищево	0101000020E6100000618DB3E90800424026C79DD2C1C84B40
58769	1	10	670	6675	80728	\N	55.4484358667994	"Московская область, Можайский муниципальный район, сельское поселение Замошинское, д.Мокрое, Пионерская, 26  (КДЦ ""Замошинское"")"	Россия, Московская область, Можайский район, деревня Мокрое	0101000020E610000082035ABA82C14140AE2CD15966B94B40
58748	1	10	670	4563	\N	\N	55.528299282601999	Московская область, Можайский муниципальный район, городское поселение Можайск, пос. Медико-инструментального завода, Сельский дом культуры пос.МИЗ	Россия, Московская область, Можайский район, поселок Медико-Инструментального Завода	0101000020E610000056478E7406FC414037C1374D9FC34B40
58747	1	10	670	4563	\N	\N	55.530689000000002	Московская область, Можайский муниципальный район, городское поселение Можайск, пос. Гидроузел, Гидроузловский сельский дом культуры		0101000020E610000044E048A0C1F8414069ACFD9DEDC34B40
58730	1	10	670	4563	\N	\N	55.503216000000002	Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, Переяслав-Хмельницкого, 13 (ПУ-25)	Россия, Московская область, Можайский район, Можайск	0101000020E6100000AB4198DBBD0242407769C36169C04B40
58733	1	10	670	4563	80482	\N	55.505229999999997	Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, Московская, 48 (Средняя школа №1)		0101000020E610000075E8F4BC1B034240A27A6B60ABC04B40
58739	1	10	670	4563	80531	\N	55.505312000000004	"Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, Мира, 15 (Дворец спорта ""Багратион"")"		0101000020E6100000A1D80A9A9604424060234910AEC04B40
58737	1	10	670	4563	80531	\N	55.506157999999999	Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, Мира, 1 (Школа искусств №1)		0101000020E6100000459DB98784034240EC4D0CC9C9C04B40
59153	1	10	670	4563	6580	\N	55.503945999999999	Московская область, городской округ Орехово-Зуево, Красноармейская, 11	Россия, Московская область, Можайский район, Можайск, Красноармейская улица, 11	0101000020E61000005019FF3EE30242409A79724D81C04B40
58741	1	10	670	4563	80623	\N	55.495955000000002	Московская область, Можайский муниципальный район, городское поселение Можайск, г Можайск, Восточная, 19 (Гимназия №4)		0101000020E61000006CCF2C0950054240D3A414747BBF4B40
58740	1	10	670	4563	80539	\N	55.495918477510699	Московская область, Можайский муниципальный район, городское поселение Можайск, г. Можайск, Восточная, 19 (Гимназия №4)	Россия, Московская область, Можайский район, Можайск, Восточная улица, 19	0101000020E61000006CCF2C0950054240B6BFB33D7ABF4B40
58743	1	10	670	4563	80593	\N	55.490473000000001	Московская область, Можайский муниципальный район, городское поселение Можайск, г. Можайск, Ватутина, 9 (Центр культуры и искусств)		0101000020E61000007DCF4884460442401749BBD1C7BE4B40
58732	1	10	670	4563	79930	\N	55.508623899312703	"Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, Бородинская, 33 (ЗАО ""Дорожник"")"	Россия, Московская область, Можайский район, Можайск, Бородинская улица	0101000020E61000007AC7293A92FF4140F8FA5A971AC14B40
58736	1	10	670	4563	80508	\N	55.502915999999999	Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, 20 Января, 19 (Средняя школа №2)		0101000020E6100000A46FD234280442404C512E8D5FC04B40
58735	1	10	670	4563	80508	\N	55.502915999999999	Московская область, Можайский муниципальный район, городское поселение Можайск, г.Можайск, 20 Января, 19 (Средняя школа№2)		0101000020E6100000A46FD234280442404C512E8D5FC04B40
60239	1	10	670	13784	\N	\N	55.355572000000002	Московская область, городской округ Электросталь, Мира, 20в	Россия, Московская область, Можайский район, поселок Мира	0101000020E61000005663096B63AC4140C9AF1F6283AD4B40
58746	1	10	670	5438	\N	\N	55.486994000000003	Московская область, Можайский муниципальный район, городское поселение Можайск, д.Красный Балтиец, (Средняя школа), 24		0101000020E6100000C3B81B446BFD414093ACC3D155BE4B40
58745	1	10	670	5427	\N	\N	55.470086000000002	Московская область, Можайский муниципальный район, городское поселение Можайск,пос.Колычево, (Средняя школа), 33		0101000020E6100000F50EB743C30042405B272EC72BBC4B40
58770	1	10	670	6741	\N	\N	55.645293000000002	Московская область, Можайский муниципальный район, сельское поселение Клементьевское, д.Клементьево, КДЦ с/п Клементьвское	Россия, Московская область, Можайский район, деревня Клементьево	0101000020E61000007A6F0C01C00342403BAB05F698D24B40
58731	1	10	670	4658	\N	\N	55.523214000000003	"Московская область, Можайский муниципальный район, городское поселение Можайск, д.Исавицы, административное здание ЗАО ""Рассвет"""		0101000020E6100000CB0EF10F5B004240996725ADF8C24B40
58779	1	10	670	7131	\N	\N	55.327602307455003	Московская область, Можайский муниципальный район, сельское поселение Юрловское, д.Ивакино, 5, квартира 9		0101000020E6100000676325E659CF4140560DC2DCEEA94B40
58767	1	10	670	6598	\N	\N	55.533776000000003	"Московская область, Можайский муниципальный район, сельское поселение Дровнинское, пос. Дровнино, КДЦ ""Цветковский"""		0101000020E61000004087F9F202B04140E2B19FC552C44B40
58760	1	10	670	6185	\N	\N	55.532176999999997	Московская область, Можайский муниципальный район, сельское поселение Бородинское, д. Горки, (Ворошиловская средняя школа), 1а		0101000020E61000000000000000EC414079573D601EC44B40
58764	1	10	670	6429	\N	\N	55.609495788047397	"Московская область, Можайский муниципальный район, сельское поселение Горетовское, д.Горетово, КДЦ ""Горетово"""	Россия, Московская область, Можайский район, деревня Горетово	0101000020E61000002639605793E741407B8505F703CE4B40
58765	1	10	670	6429	80980	\N	55.609376415442803	Московская область, Можайский муниципальный район, сельское поселение Горетовское, д.Красновидово, Центральная, 4 (Филиал почтампта)	Россия, Московская область, Можайский район, деревня Горетово	0101000020E6100000B4E89D0AB8E74140D07B630800CE4B40
58759	1	10	670	6178	\N	\N	55.515501999999998	Московская область, Можайский муниципальный район, сельское поселение Бородинское, пос. Бородинское поле, Детский сад №26		0101000020E610000001857AFA08F44140E48233F8FBC14B40
58761	1	10	670	62044	\N	\N	55.5274589822438	"Московская область, Можайский муниципальный район, сельское поселение Бородинское,пос. Бородино, Сельский КДЦ ""Горки"""		0101000020E6100000310BED9C66E941408D7DC9C683C34B40
58757	1	10	670	5947	\N	\N	55.418610734541097	Московская область, Можайский муниципальный район, сельское поселение Борисовское, с. Борисово, Администрация сельского поселения Борисовское	Россия, Московская область, Можайский район, село Борисово	0101000020E6100000F0181EFB59064240785F950B95B54B40
58756	1	10	670	5947	\N	\N	55.419248000000003	Московская область, Можайский муниципальный район, сельское поселение Борисовское, с. Борисово, Средняя школа		0101000020E6100000C2A2224E27074240EB7420EBA9B54B40
58755	1	10	670	5947	\N	\N	55.419248000000003	"Московская область, Можайский муниципальный район, сельское поселение Борисовское, с. Борисово, ""КДЦ Борисово"""		0101000020E6100000C2A2224E27074240EB7420EBA9B54B40
58777	1	10	670	7033	\N	\N	55.564709000000001	"Московская область, Можайский муниципальный район, сельское поселение Спутник, д.Большое Тесово, Сельский клуб  ""Тесово"""		0101000020E6100000412B3064750B4240E1606F6248C84B40
60117	1	10	670	8087	\N	\N	55.514254000000001	Московская область, городской округ Щербинка, местечко Барыши, 5/1	Россия, Московская область, Можайский район, деревня Барыши	0101000020E61000006D0377A04EAD414029EB3713D3C14B40
58773	1	10	670	6869	\N	\N	55.728459000000001	Московская область, Можайский муниципальный район, сельское поселение Порецкое, д.Астафьево, Астафьевский ФАП		0101000020E61000003D9E961FB8B841400ABDFE243EDD4B40
58758	1	10	670	6112	\N	\N	55.389651999999998	"Московская область, Можайский муниципальный район, сельское поселение Борисовское, д. Андреевское, Клуб КДЦ ""Борисово"""		0101000020E6100000E9F010C64FFF41401669E21DE0B14B40
58762	1	10	670	6297	\N	\N	55.518616999999999	"Московская область, Можайский муниципальный район, сельское поселение Бородинское, пос. Александрово, Александровский  СДК ""Сельский КДЦ ""Горки"""""		0101000020E6100000B3B27DC85B0E42402713B70A62C24B40
58716	1	10	227	62022	80919	\N	55.657280999999998	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, Б. Кореневское шоссе, 25 (детский санаторий)		0101000020E61000002CF180B2290143401EA4A7C821D44B40
58707	1	10	227	3237	\N	\N	55.656082807300798	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Птицефабрика микрорайон, 12/1 (средняя школа № 19)	Россия, Московская область, Люберецкий район, поселок Томилино, микрорайон Птицефабрики	0101000020E61000001895D40968F64240153B1A87FAD34B40
58705	1	10	227	3237	\N	\N	55.633678000000003	Московская область, Люберецкий муниципальный район, городское поселение Томилино, село Жилино, 128 (школа № 23)		0101000020E6100000C6F8307BD9F84240EC18575C1CD14B40
58717	1	10	227	3237	1048	\N	55.659607000000001	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, Грибоедова, 1 (гимназия № 46)	Россия, Московская область, Люберецкий район, поселок Томилино, улица Грибоедова, 1	0101000020E6100000778192020BFA4240399B8E006ED44B40
58712	1	10	227	3237	947	\N	55.664521999999998	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Гаршина, 9а, кор. 8 (пом. Совета ветеранов)	Россия, Московская область, Люберецкий район, поселок Томилино, улица Гаршина, 9ак8	0101000020E610000089EAAD81ADFA42407BBC900E0FD54B40
58709	1	10	227	3237	80881	\N	55.653866185209402	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Чехова, 2 (школа № 17)	Россия, Московская область, Люберецкий район, поселок Томилино, улица Чехова, 2	0101000020E61000001B2E724F57F94240B1FB8EE1B1D34B40
58706	1	10	227	3237	71790	\N	55.655779518438401	"Московская область, Люберецкий муниципальный район, городское поселение Томилино, Птицефабрика микрорайон, ЛИТ ""Б"" (ДК Птицефабрики)"		0101000020E6100000B1E1E995B2F6424079AF5A99F0D34B40
33786	1	6	1067	9419	\N	\N	54.686193000000003	Деревня Сугоново, 51		0101000020E6100000C1E3DBBB0657424040DF162CD5574B40
58714	1	10	227	3237	80404	\N	55.670699290725302	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Пионерская, 1 (гимназия № 18)		0101000020E6100000511212691BF94240DE3AFF76D9D54B40
58704	1	10	227	3237	80723	\N	55.627462999999999	Московская область, Люберецкий муниципальный район, городское поселение Томилино, деревня Токарево, Октябрьская, 172 (школа № 22)		0101000020E61000007AE40F069EF542409B3924B550D04B40
58711	1	10	227	3237	79933	\N	55.665127597261304	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Гоголя, 19 (помещение Совета депутатов)	Россия, Московская область, Люберецкий район, поселок Томилино, улица Гоголя, 19	0101000020E6100000CF143AAFB1F94240B3D30FEA22D54B40
58713	1	10	227	3237	80385	\N	55.663531999999996	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Гаршина, 9а, кор. 5 (Дом детск. творчества)		0101000020E61000004D4A41B797FA4240BBECD79DEED44B40
58710	1	10	227	2591	667	\N	55.611683999999997	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Гоголя, 2 (школа № 14)	Россия, Московская область, Люберецкий район, поселок городского типа Октябрьский, улица Гоголя, 2	0101000020E61000002B4EB51666FB424044BE4BA94BCE4B40
58703	1	10	227	2591	80301	\N	55.605922	Московская область, Люберецкий муниципальный район, городское поселение Октябрьский, Первомайская, 22 (средняя школа № 53)		0101000020E61000008258367348FC4240A5F622DA8ECD4B40
58708	1	10	227	62005	80829	\N	55.612360000000002	Московская область, Люберецкий муниципальный район, городское поселение Томилино, Пушкина, 34 (Центр культуры и досуга)		0101000020E610000005E10A28D4FB424075B0FECF61CE4B40
58728	1	10	227	4477	80893	\N	55.689399999999999	Московская область, Люберецкий муниципальный район, городское поселение Красково, деревня Марусино, Заречная, 26 (школа-интернат)		0101000020E6100000CB13083BC5FC424063EE5A423ED84B40
58722	1	10	227	2042	\N	\N	55.625281999999999	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, МЭЗ, Быковское шоссе, 47 (средняя школа № 47)	Россия, Московская область, Люберецкий район, поселок городского типа Малаховка, поселок МЭЗ	0101000020E61000005B09DD25710043408463963D09D04B40
58720	1	10	227	2042	80402	\N	55.635091000000003	"Московская область, Люберецкий муниципальный район, городское поселение Малаховка, Шоссейная, 40 (клуб ""Шахтер"")"		0101000020E61000003EE76ED74B014340F27D71A94AD14B40
58718	1	10	227	2042	81076	\N	55.663023000000003	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, деревня Овражки, Новая, 23 (школа № 50)	Россия, Московская область, Люберецкий район, поселок городского типа Малаховка, Новая улица	0101000020E6100000DCB8C5FCDC04434077BF0AF0DDD44B40
58715	1	10	227	2042	1015	\N	55.652617999999997	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, Б. Кореневское шоссе, 1 (ЖЭУ-2)	Россия, Московская область, Люберецкий район, поселок городского типа Малаховка, Большое Кореневское шоссе, 1	0101000020E610000052D7DAFB54014340F56393FC88D34B40
58721	1	10	227	61928	80613	\N	55.638607	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, Шоссейная, 33 (Академия физкультуры)		0101000020E6100000008DD2A57F01434093FFC9DFBDD14B40
58719	1	10	227	61928	80475	\N	55.645102247030202	Московская область, Люберецкий муниципальный район, городское поселение Малаховка, Комсомольская, 4 (средняя школа № 48)		0101000020E610000041800C1D3B004340C74ACCB392D24B40
58690	1	10	227	877	\N	\N	55.659820000000003	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, ВУГИ поселок, 9а (средняя школа № 8)		0101000020E6100000D238D4EFC2F64240959F54FB74D44B40
58679	1	10	227	877	\N	\N	55.682168946528797	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Люберцы-3, 50 (кадетская школа № 45)	Россия, Московская область, Люберецкий район, Люберцы, Инициативная улица	0101000020E6100000F8C5A52A6DF342402AAC545051D74B40
58692	1	10	227	877	654	\N	55.701684	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Урицкого, 10 (средняя школа № 13)	Россия, Московская область, Люберецкий район, Люберцы, улица Урицкого, 10	0101000020E6100000AD889AE8F3F14240301004C8D0D94B40
58699	1	10	227	877	745	\N	55.687897999999997	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Побратимов, 28 (средняя школа № 21)	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 28	0101000020E61000002FFD4B5299F24240ED7DAA0A0DD84B40
58698	1	10	227	877	745	\N	55.692870999999997	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Побратимов, 19 (лицей № 12)	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 19	0101000020E6100000384888F205F3424064AC36FFAFD84B40
58671	1	10	227	877	354	\N	55.680463000000003	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Кирова, 47 (лицей № 4)	Россия, Московская область, Люберецкий район, Люберцы, улица Кирова, 47	0101000020E61000006C5B94D920F14240AC915D6919D74B40
58724	1	10	227	2491	80407	\N	55.660485000000001	Московская область, Люберецкий муниципальный район, городское поселение Красково, 2-я Заводская, 28 (гимназия № 56)		0101000020E6100000A530EF71A6FD4240D13FC1C58AD44B40
58701	1	10	227	877	793	\N	55.688634	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Победы проспект, 21 (лицей № 15)	Россия, Московская область, Люберецкий район, Люберцы, проспект Победы, 13	0101000020E6100000A438471D1DF54240F374AE2825D84B40
58683	1	10	227	877	80373	\N	55.663093240286699	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Южная, 20 (гимназия № 20)	Россия, Московская область, Люберецкий район, Люберцы, Южная улица, 20	0101000020E61000009B7631CD74F34240709A3E3BE0D44B40
58696	1	10	227	877	80042	\N	55.695295999999999	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Попова, 14/1 (институт коммунального хоз.)		0101000020E61000008274B169A5F2424012859675FFD84B40
59308	1	10	227	877	225	\N	55.695493999999997	Московская область, городской округ Подольск, Октябрьский проспект, д. 11	Россия, Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 11	0101000020E6100000F50F221972EE4240384888F205D94B40
58689	1	10	227	877	225	\N	55.661977999999998	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 403 (комбинат ВИНИТИ)		0101000020E61000006798DA5207F54240F355F2B1BBD44B40
58687	1	10	227	877	225	\N	55.667234000000001	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 349-а (средняя школа № 7)	Россия, Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 341	0101000020E6100000F3E8465854F44240BF6378EC67D54B40
58686	1	10	227	877	225	\N	55.667234000000001	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 349-а ((ДЮСШ)		0101000020E6100000F3E8465854F44240BF6378EC67D54B40
58685	1	10	227	877	225	\N	55.674011	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 259 (Университет Сервиса)		0101000020E6100000027FF8F9EFF34240771211FE45D64B40
58674	1	10	227	877	225	\N	55.676082999999998	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 200-а (Дворец культуры)		0101000020E610000060E811A3E7F24240D73043E389D64B40
58669	1	10	227	877	225	\N	55.683011	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 118 (школа № 6)		0101000020E6100000CD74AF93FAF0424075E789E76CD74B40
58668	1	10	227	877	225	\N	55.687126999999997	"Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 123 (ОАО ""ЛГЖТ"")"		0101000020E6100000E2AB1DC539F042406B990CC7F3D74B40
58664	1	10	227	877	225	\N	55.689805999999997	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 24а (гимназия № 43)	Россия, Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 24а	0101000020E6100000215A2BDA1CEF4240D34A21904BD84B40
58663	1	10	227	877	225	\N	55.689805999999997	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Октябрьский проспект, 24А (гимназия № 43)		0101000020E6100000215A2BDA1CEF4240D34A21904BD84B40
58680	1	10	227	877	79925	\N	55.671387000000003	"Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Котельническая, 12 (учебный центр ""Мособлгаз"")"		0101000020E6100000266F8099EFF24240D3FA5B02F0D54B40
58682	1	10	227	877	80360	\N	55.659286999999999	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Космонавтов, 7 (средняя школа № 9)		0101000020E610000011E4A08499F44240C7D6338463D44B40
58672	1	10	227	877	80349	\N	55.674641000000001	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Калараш, 3 (гимназия № 44)		0101000020E6100000D505BCCCB0F1424037C5E3A25AD64B40
58693	1	10	227	877	79894	\N	55.702556000000001	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Гоголя, 21 (средняя школа № 11)	Россия, Московская область, Люберецкий район, Люберцы, улица Гоголя, 21	0101000020E6100000ACCABE2B82F34240E6CDE15AEDD94B40
58694	1	10	227	877	80387	\N	55.696528999999998	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Воинов-интернационалистов, 7 (средняя школа № 25)		0101000020E610000046D09849D4F3424098DBBDDC27D94B40
58676	1	10	227	877	80018	\N	55.671706999999998	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Авиаторов, 10 (гимназия № 41)		0101000020E610000033FCA71B28F0424044BFB67EFAD54B40
58675	1	10	227	877	80018	\N	55.669884000000003	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Авиаторов, 3 (лицей № 42)		0101000020E61000001E6FF25B74F042408D0E48C2BED54B40
58677	1	10	227	877	78618	\N	55.680770000000003	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Люберцы-3, 30 (Дом офицеров)	Россия, Московская область, Люберецкий район, Люберцы, улица 3-е Почтовое отделение, 30	0101000020E610000028F04E3E3DF04240890CAB7823D74B40
58727	1	10	227	2491	80476	\N	55.658099	Московская область, Люберецкий муниципальный район, городское поселение Красково, Чехова, 11 (школа № 59)		0101000020E61000008B54185B08004340E14389963CD44B40
58725	1	10	227	2491	80468	\N	55.660784999999997	Московская область, Люберецкий муниципальный район, городское поселение Красково, Федянина, 16 (школа № 55)		0101000020E610000008008E3D7BFE4240FB57569A94D44B40
58726	1	10	227	61922	80064	\N	55.661460200865299	Московская область, Люберецкий муниципальный район, городское поселение Красково, К. Маркса, 117 (ВНИИСТРОМ)	Россия, Московская область, Люберецкий район, поселок городского типа Красково, улица Карла Маркса, 117к1	0101000020E6100000F08AE07F2BFF42405BCEA5B8AAD44B40
58691	1	10	227	61922	81024	\N	55.669761999999999	Московская область, Люберецкий муниципальный район, городское поселение Люберцы, Железнодорожная, 4 (заводоуправление завода)		0101000020E6100000A8C30AB77CFE4240410DDFC2BAD54B40
58623	1	10	109	59213	71775	\N	54.881644000000001	"поселок совхоза ""Астапово"", Садовая, 37А"	Россия, Московская область, Луховицкий район, деревня совхоза "Астапово"	0101000020E61000005793A7ACA67B4340795BE9B5D9704B40
58648	1	10	109	32372	71857	\N	54.905301000000001	п. Фруктовая, Вокзальная, 1А		0101000020E61000002E008DD2A5A143409F0436E7E0734B40
94466	1	10	109	61998	80802	\N	54.956119999999999	п. Сельхозтехника, 24		0101000020E610000003CC7C073F9743409886E123627A4B40
59136	1	10	109	24473	80987	\N	54.858905999999998	Московская область, д. Протасово, Победы, 9		0101000020E61000007EA8346266934340492BBEA1F06D4B40
58637	1	10	109	62019	\N	\N	54.958319078162901	с. Подлесная Слобода, 152А	Россия, Московская область, Луховицкий район, деревня Подлесная Слобода	0101000020E610000048C153C89588434056116E32AA7A4B40
58626	1	10	109	49279	80782	\N	54.849868000000001	п. Орешково, Парковая, 2		0101000020E6100000A77A32FFE8A543405EF58079C86C4B40
58647	1	10	109	49566	80943	\N	54.940500072798102	д. Озерицы, Озерная, 27А	Россия, Московская область, Луховицкий район, деревня Озерицы	0101000020E6100000EF8D2100389E4340AAF1D24D62784B40
58632	1	10	109	31710	\N	\N	54.834023999999999	с. Нижне-Маслово, д.134А		0101000020E6100000EF3A1BF2CFAE4340200A664CC16A4B40
58625	1	10	109	31335	80717	\N	54.950696999999998	с. Матыра, Школьная, 8		0101000020E610000014D1AFAD9F724340E1B37570B0794B40
58630	1	10	109	31571	80995	\N	54.772582	д. Марьина Гора, Молодежная, д.7		0101000020E61000006FF3C64961A8434038BD8BF7E3624B40
58641	1	10	109	32071	80966	\N	55.030664000000002	с. Любичи, Советская, 68		0101000020E6100000D80E46EC139C4340109546CCEC834B40
58601	1	10	109	158	\N	\N	54.954909999999998	г. Луховицы, Советский переулок, 4	Россия, Московская область, Луховицкий район, Луховицы	0101000020E61000005858703FE0834340CA4FAA7D3A7A4B40
58612	1	10	109	158	7815	\N	54.943437000000003	г. Луховицы, Островского, 8	Россия, Московская область, Луховицкий район, Луховицы, улица Островского, 8	0101000020E61000009DF3531C078443400E6B2A8BC2784B40
58611	1	10	109	158	7791	\N	54.945081000000002	г. Луховицы, Жуковского, 28/2	Россия, Московская область, Луховицкий район, Луховицы, улица Жуковского, 28/2	0101000020E6100000A4C16D6DE18343401689096AF8784B40
58610	1	10	109	158	7791	\N	54.946947999999999	г. Луховицы, Жуковского, 18	Россия, Московская область, Луховицкий район, Луховицы, улица Жуковского, 18	0101000020E6100000460C3B8C498343409D81919735794B40
58609	1	10	109	158	7778	\N	54.947429	г. Луховицы, Гайдара, 2	Россия, Московская область, Луховицкий район, Луховицы, улица Гайдара, 2	0101000020E6100000DA571EA4A782434018247D5A45794B40
58605	1	10	109	158	7732	\N	54.954599999999999	г. Луховицы, 40 лет Октября, 26	Россия, Московская область, Луховицкий район, Луховицы, улица 40 лет Октября, 26	0101000020E6100000E78F696D1A8343407C613255307A4B40
59152	1	10	109	158	80178	\N	54.981655000000003	Московская область, городской округ Орехово-Зуево, Пушкина, 4		0101000020E6100000B29FC552248543403A7AFCDEA67D4B40
14681	1	10	109	158	80178	\N	54.932414999999999	г. Луховицы, Пушкина, 341А		0101000020E6100000BFD4CF9B8A80434061A6ED5F59774B40
58602	1	10	109	158	80964	\N	54.954712401337801	г. Луховицы, Озерная, 4		0101000020E61000007F6C921FF1834340A48CB800347A4B40
58613	1	10	109	158	80348	\N	54.944637	г. Луховицы, Мира, 35		0101000020E61000006CD102B4AD844340B8CB7EDDE9784B40
58644	1	10	109	32165	80719	\N	55.006244000000002	с. Ловцы, Садовая, 7		0101000020E61000007C0A80F10CA04340EBE5779ACC804B40
58643	1	10	109	32165	80973	\N	55.006244000000002	с. Ловцы, Октябрьской революции, 18		0101000020E61000007C0A80F10CA04340EBE5779ACC804B40
58640	1	10	109	32051	80907	\N	55.105820000000001	д. Лисьи Норы, Околопрудная, 20А		0101000020E61000002EC55565DF934340A1A17F828B8D4B40
58645	1	10	109	32244	72197	\N	55.003962000000001	п. Красная Пойма, Школьная, 6		0101000020E6100000732CEFAA078A4340A036AAD381804B40
58646	1	10	109	32244	72200	\N	55.004798103393703	п. Красная Пойма, Лесная, 4	Россия, Московская область, Луховицкий район, поселок Красная Пойма	0101000020E61000009276A38FF98A4340098B8A389D804B40
58638	1	10	109	31974	80770	\N	55.053458999999997	с. Дединово, Совхозная, 9		0101000020E6100000D505BCCCB08F4340A35698BED7864B40
58639	1	10	109	31974	80939	\N	55.053458999999997	с. Дединово, Набережная, 4		0101000020E6100000D505BCCCB08F4340A35698BED7864B40
58629	1	10	109	31558	80751	\N	54.800611000000004	с. Григорьевское, Центральная, 25		0101000020E610000006BAF605F4A04340B0E8D66B7A664B40
58633	1	10	109	49371	71931	\N	54.930775998243497	д. Головачево, Мира, 102	Россия, Московская область, Луховицкий район, деревня Головачево	0101000020E61000004B749659849043406BF3FFAA23774B40
58628	1	10	109	31479	71866	\N	54.839421203984102	п. Газопроводск, Центральная, 17	Россия, Московская область, Луховицкий район, поселок Газопроводск	0101000020E6100000F59CF4BEF19D4340AE49B725726B4B40
58634	1	10	109	31767	80765	\N	54.975341	д. Выкопанка, Советская, 75		0101000020E61000001D90847D3B97434056B950F9D77C4B40
58649	1	10	109	32440	80754	\N	54.912956000000001	п. Врачово-Горки, Клубная, 11		0101000020E610000069368FC3609C4340EF5701BEDB744B40
58622	1	10	109	30864	71894	\N	54.942377	р.п. Белоомут, Советская площадь, 20		0101000020E6100000EA758BC058AB434055C03DCF9F784B40
58615	1	10	109	30864	71894	\N	54.942377	р.п. Белоомут, Советская площадь, 1		0101000020E6100000EA758BC058AB434055C03DCF9F784B40
58619	1	10	109	30864	80709	\N	54.942377	р.п. Белоомут, Малая Огаревская, 113		0101000020E6100000EA758BC058AB434055C03DCF9F784B40
58618	1	10	109	30864	80704	\N	54.942377	р.п. Белоомут, Большая Огаревская, 20		0101000020E6100000EA758BC058AB434055C03DCF9F784B40
58616	1	10	109	61952	80968	\N	54.942377	р.п. Белоомут, Советская площадь, 15		0101000020E6100000EA758BC058AB434055C03DCF9F784B40
58620	1	10	109	61952	80781	\N	54.942871058735399	р.п. Белоомут, Гагарина, Здание клуба		0101000020E61000009BE5B2D139AB434064AC36FFAF784B40
58627	1	10	109	31471	\N	\N	54.879492367433997	с. Алпатьево, 20Б	Россия, Московская область, Луховицкий район, деревня Алпатьево	0101000020E610000040A0336953A94340FC8BA03193704B40
58591	1	10	993	59531	\N	\N	56.250115443294298	Московская область, Лотошинский муниципальный район, п. Новолотошино, Здание СДК, 18	Россия, Московская область, Лотошинский район	0101000020E6100000217711A628D34140999EB0C403204C40
58588	1	10	993	61898	79942	\N	56.227129627820297	п. Лотошино, Центральная, 14	Россия, Московская область, Лотошинский район, поселок городского типа Лотошино, Центральная улица	0101000020E6100000C2137AFD49D2414062F88898121D4C40
58598	1	10	993	29978	\N	\N	56.194443	Московская область, Лотошинский муниципальный район, д. Ушаково, Здание СДК, 60	Россия, Московская область, Лотошинский район, деревня Ушаково	0101000020E61000008A90BA9D7DD54140D3F71A82E3184C40
58597	1	10	993	29974	80821	\N	56.356262999999998	Московская область, Лотошинский муниципальный район, д. Савостино, Школьная, 22		0101000020E61000004832AB77B8DB41402EE3A6069A2D4C40
94634	1	10	993	59518	\N	\N	56.307257168565499	в помещении  сельского Дома культуры, деревня Пешки	Россия, Московская область, Лотошинский район, деревня Пешки	0101000020E61000000491459A78C94140C93B873254274C40
58592	1	10	993	61982	\N	\N	56.249410622406799	Московская область, Лотошинский муниципальный район, д. Монасеино, Территория школы, 4	Россия, Московская область, Лотошинский район, деревня Монасеино	0101000020E6100000A7CF0EB8AEC041409F211CB3EC1F4C40
58594	1	10	993	29821	80978	\N	56.185712839237198	Московская область, Лотошинский муниципальный район, д. Михалево, Микрорайон, 28	Россия, Московская область, Лотошинский район, деревня Михалево	0101000020E6100000D74D29AF95C6414095B88E71C5174C40
58595	1	10	993	29853	71900	\N	56.4432268401264	Московская область, Лотошинский муниципальный район, с. Микулино, Микрорайон, 15	Россия, Московская область, Лотошинский район, село Микулино	0101000020E610000031992A1895CE414023DA8EA9BB384C40
59576	1	10	993	8402	2304	\N	56.234814999999998	Московская область, Рузский муниципальный район, городское поселение Руза, Микрорайон, 4	Россия, Московская область, Лотошинский район, поселок городского типа Лотошино, улица Микрорайон, 4	0101000020E6100000F8FD9B1727D241401CCEFC6A0E1E4C40
94573	1	10	993	8402	80437	\N	56.235677735024801	п. Лотошино, ул. Центральная, дом 18/ п. Лотошино, Микрорайон, дом 8	Россия, Московская область, Лотошинский район, поселок городского типа Лотошино, улица Микрорайон, 8	0101000020E61000007349D57613D241407F315BB22A1E4C40
58589	1	10	993	61908	79970	\N	56.227531085392997	п. Лотошино, Центральная, 22	Россия, Московская область, Лотошинский район, поселок городского типа Лотошино, Центральная улица	0101000020E610000046B3B27DC8D14140C0E95DBC1F1D4C40
58593	1	10	993	29771	80965	\N	56.162190000000002	Московская область, Лотошинский муниципальный район, д. Кульпино, Микрорайон, 20		0101000020E6100000527C7C4276D241407FDE54A4C2144C40
58590	1	10	993	29616	71784	\N	56.225992842164501	Московская область, Лотошинский муниципальный район, п. Кировский, Волоколамское шоссе, 2	Россия, Московская область, Лотошинский район, поселок Кировский	0101000020E610000033C51C041DD54140FE0FB056ED1C4C40
58599	1	10	993	30067	\N	\N	56.267927	Московская область, Лотошинский муниципальный район, д. Доры, Здание СДК, 5		0101000020E61000001B12F758FAF44140925B936E4B224C40
58596	1	10	993	29916	80820	\N	56.373050999999997	Московская область, Лотошинский муниципальный район, д. Введенское, Микрорайон, 14		0101000020E6100000FDA204FD85D04140BB5E9A22C02F4C40
58600	1	10	993	30113	\N	\N	56.217751	Московская область, Лотошинский муниципальный район, п. Большая Сестра, Здание СДК, 25		0101000020E610000020B24813EFF64140EDD5C743DF1B4C40
58556	1	10	150	60246	\N	\N	55.525669999999998	пос. п/х Воскресенское, д.28а	Россия, Московская область, Ленинский район, поселок подсобного хозяйства Воскресенское	0101000020E61000004E9D47C5FFB94240813E912749C34B40
58555	1	10	150	60246	\N	\N	55.525669999999998	"пос. п/х Воскресенское, МУ ""Дом культуры"""	Россия, Московская область, Ленинский район, поселок подсобного хозяйства Воскресенское	0101000020E61000004E9D47C5FFB94240813E912749C34B40
58570	1	10	150	397	71819	\N	55.584534423331398	пос.Совхоз им.Ленина, д.7а	Россия, Московская область, Ленинский район, поселок Совхоза им.Ленина	0101000020E6100000390A100533DE424035B39602D2CA4B40
94548	1	10	150	28574	\N	\N	55.587448000000002	Моск.обл., пос.Развилка,МОУДОД "ЦДТ"Гармония"		0101000020E61000003FE42D573FE04240E10CFE7E31CB4B40
58569	1	10	150	28574	\N	\N	55.587448000000002	пос.Развилка, МОУ Развилковская средняя школа		0101000020E61000003FE42D573FE04240E10CFE7E31CB4B40
58568	1	10	150	28574	\N	\N	55.587448000000002	"пос.Развилка, Центр ""Вера"""		0101000020E61000003FE42D573FE04240E10CFE7E31CB4B40
58563	1	10	150	48219	\N	\N	55.584750999999997	село Остров, Животноводческий комплекс		0101000020E610000014B01D8CD8EB4240D2A6EA1ED9CA4B40
58550	1	10	150	27812	\N	\N	55.534030999999999	пос.Новодрожжино, Опытно-производственный центр	Россия, Московская область, Ленинский район, поселок Новодрожжино	0101000020E6100000B69DB64604CB42406C06B8205BC44B40
57368	1	10	150	2202	\N	\N	55.595506	г.Московский, микрорайон №3, д.8	Россия, Московская область, Ленинский район, Московский, 3-й микрорайон, 8	0101000020E6100000FC17080264AC42403049658A39CC4B40
57156	1	10	150	2202	\N	\N	55.601939999999999	г.Московский, микрорайон №1, 19а	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 19а	0101000020E6100000596DFE5F75AC4240BE13B35E0CCD4B40
58295	1	10	205	15441	\N	\N	56.349030999999997	Московская область, Клинский муниципальный район, Папивино, 6а		0101000020E610000056BB26A43552424024253D0CAD2C4C40
57121	1	10	150	2202	\N	\N	55.600383999999998	пос. института Полиомиелита, д.4	Россия, Московская область, Ленинский район, Московский, поселок Института Полиомиелита, 4	0101000020E610000085950A2AAAAA424055850662D9CC4B40
57094	1	10	150	2202	\N	\N	55.600191000000002	г.Московский, микрорайон №1, д.22а	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 22а	0101000020E6100000F853E3A59BAC4240412D060FD3CC4B40
57069	1	10	150	2202	\N	\N	55.601874000000002	г.Московский, микрорайон №1, д.49	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 49	0101000020E6100000EA211ADD41AC424007280D350ACD4B40
56933	1	10	150	2202	\N	\N	55.601939999999999	г.Московский, микрорайон №1, д.19а	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 19а	0101000020E6100000596DFE5F75AC4240BE13B35E0CCD4B40
56839	1	10	150	2202	\N	\N	55.603242000000002	г.Московский, микрорайон №1, д.46	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 46	0101000020E61000000403081F4AAC42406DC9AA0837CD4B40
56867	1	10	150	2202	80497	\N	55.602860999999997	г.Московский, микрорайон №1, д.47		0101000020E6100000A58636001BAC424055849B8C2ACD4B40
58562	1	10	150	28351	72029	\N	55.564387406947702	село Молоково, ул.Революционная, д.161 корп.1	Россия, Московская область, Ленинский район, село Молоково	0101000020E6100000A81ABD1AA0EE4240CFA44DD53DC84B40
94550	1	10	150	48443	\N	\N	55.548039000000003	Моск.обл., пос.Марьино, д.3	Россия, Московская область, Ленинский район, поселок Марьино	0101000020E610000021CCED5EEEA942405EF7562426C64B40
58571	1	10	150	28770	\N	\N	55.570053999999999	пос.Коммунарка, д.14а	Россия, Московская область, Ленинский район, поселок Коммунарка, 14а	0101000020E61000001A868F8829BD42401C7A8B87F7C84B40
56648	1	10	150	46739	\N	\N	55.518892000000001	д.Калиновка, д.89	Россия, Московская область, Ленинский район, деревня Калиновка	0101000020E61000002ECA6C9049DC4240F913950D6BC24B40
58415	1	10	150	49532	\N	\N	55.561767000000003	пос.Измайлово, МОУ Измайловская средняя школа	Россия, Московская область, Ленинский район, поселок Измайлово	0101000020E610000052EFA99CF6D242406C7C26FBE7C74B40
58566	1	10	150	28484	\N	\N	55.614119000000002	Моск.обл., пос.Мосрентген, помещение МОУ Теплостанская СОШ		0101000020E61000006666666666BC4240166D8E739BCE4B40
58565	1	10	150	28484	\N	\N	55.622771	пос.Мосрентген, д.39		0101000020E6100000CADFBDA3C6BC4240D8F2CAF5B6CF4B40
57393	1	10	150	47817	\N	\N	55.604951	"д.Дроздово, Центр досуга ""Дроздово"""	Россия, Московская область, Ленинский район, деревня Дроздово	0101000020E6100000D3F8855792E642405C57CC086FCD4B40
58552	1	10	150	27898	80915	\N	55.649112538501001	пос. ДСК Мичуринец, ул.Погодина, д.4	Россия, Московская область, Ленинский район, поселок ДСК Мичуринец, улица Ленина	0101000020E61000006117450F7CA842404834812216D34B40
58564	1	10	150	29022	\N	\N	55.508124000000002	"пос. Санаторий Горки Ленинские, ГУ ""Реабилитационный центр Детство"	Россия, Московская область, Ленинский район, поселок городского типа Горки Ленинские	0101000020E61000009544F64196E3424007280D350AC14B40
56599	1	10	150	29022	\N	\N	55.508690999999999	"пос. Горки Ленинские, ГУ ГИМЗ ""Горки Ленинские"""	Россия, Московская область, Ленинский район, поселок городского типа Горки Ленинские	0101000020E61000008F19A88C7FE34240806264C91CC14B40
56622	1	10	150	61978	80762	\N	55.508232999999997	д.Горки, ул.Полковникова, д.2	Россия, Московская область, Ленинский район, деревня Горки	0101000020E6100000E8154F3DD2E04240BDDF68C70DC14B40
94549	1	10	150	28812	\N	\N	55.582894000000003	Моск.обл., пос.Газопровод, д.15	Россия, Московская область, Ленинский район, поселок Газопровод, 15	0101000020E6100000F3ACA415DFBC42406F8445459CCA4B40
58573	1	10	150	28812	\N	\N	55.582206999999997	Моск.обл., пос.Газопровод, д.17	Россия, Московская область, Ленинский район, поселок Газопровод, 17	0101000020E61000004834812216BD42404A404CC285CA4B40
59046	1	10	150	20107	\N	\N	55.566909000000003	д. Вырубово, 22А		0101000020E610000000C79E3D97CF42406F675F7990C84B40
58554	1	10	150	24806	80401	\N	55.504852999999997	пос. Володарского, ул.Текстильная, д.16		0101000020E6100000B4588AE42BF94240CC24EA059FC04B40
58553	1	10	150	24806	80401	\N	55.504852999999997	пос.Володарского, ул.Текстильная, д.16		0101000020E6100000B4588AE42BF94240CC24EA059FC04B40
58551	1	10	150	40399	\N	\N	55.646309000000002	пос.Внуково, д.50		0101000020E6100000EECEDA6D17A24240240ED940BAD24B40
58549	1	10	150	5502	7079	\N	55.542614999999998	г.Видное, проспект Ленинского Комсомола, д.23 корп.3	Россия, Московская область, Ленинский район, Видное, проспект Ленинского Комсомола, 23к3	0101000020E6100000A391CF2B9EDA4240D6A8876874C54B40
58546	1	10	150	5502	7079	\N	55.548501999999999	г.Видное, проспект Ленинского Комсомола, д.1	Россия, Московская область, Ленинский район, Видное, проспект Ленинского Комсомола, 1	0101000020E6100000304B3B3597DB424032E5435035C64B40
56417	1	10	150	5502	80755	\N	55.550947000000001	г.Видное, Площадь Вокзальная, депо ПАТП		0101000020E6100000FE2C9622F9DA4240276A696E85C64B40
56289	1	10	150	5502	3407	\N	55.553279000000003	г.Видное, ул.Школьная, д.77	Россия, Московская область, Ленинский район, Видное, Школьная улица, 77	0101000020E6100000FB40F2CEA1D842402448A5D8D1C64B40
56247	1	10	150	5502	3407	\N	55.555788999999997	г.Видное, ул.Школьная, д.40	Россия, Московская область, Ленинский район, Видное, Школьная улица, 40	0101000020E6100000F1811DFF05DA4240FF3C0D1824C74B40
58542	1	10	150	5502	80259	\N	55.557735000000001	Московская область, Ленинский муниципальный район, г.Видное, ул.Школьная, д.11		0101000020E61000008255F5F23BDB4240D36A48DC63C74B40
56309	1	10	150	5502	80259	\N	55.554364	г.Видное, ул.Школьная, д.78		0101000020E61000006919A9F754D84240350A4966F5C64B40
58545	1	10	150	5502	1508	\N	55.551619000000002	г.Видное, ул.Советская, д.17-а	Россия, Московская область, Ленинский район, Видное, Советская улица, 17а	0101000020E6100000E882FA9639DB4240166D8E739BC64B40
38625	1	6	1067	20553	\N	\N	54.574278	Село Сашкино, 27		0101000020E61000003944DC9C4A6C4240F96706F181494B40
56111	1	10	150	5502	1508	\N	55.552377999999997	г.Видное, ул.Советская, д.7	Россия, Московская область, Ленинский район, Видное, Советская улица, 5	0101000020E6100000E8323509DEDA4240D3838252B4C64B40
58544	1	10	150	5502	80315	\N	55.549149	г.Видное, ул.Советская, д.20		0101000020E6100000A7785C548BDA4240C8D0B1834AC64B40
55719	1	10	150	5502	80233	\N	55.548900000000003	г.Видное, ул.Советская, д.24		0101000020E6100000679B1BD313DA42402063EE5A42C64B40
56522	1	10	150	5502	16258	\N	55.537348000000001	г.Видное, Петровский проезд, д.2а	Россия, Московская область, Ленинский район, Видное, микрорайон Расторгуево, Петровский проезд, 12	0101000020E610000008228B34F1D442401749BBD1C7C44B40
56454	1	10	150	5502	79872	\N	55.541768917606099	г.Видное, ул.Ольгинская, д.53		0101000020E6100000B70C384BC9D242404A7EC4AF58C54B40
58543	1	10	150	5502	5718	\N	55.558410011318102	г.Видное, Клубный переулок, д.1	Россия, Московская область, Ленинский район, Видное, Клубный переулок, 1	0101000020E610000063450DA661DA424033E197FA79C74B40
58548	1	10	150	5502	7095	\N	55.544376999999997	г.Видное, Жуковский проезд, д.10	Россия, Московская область, Ленинский район, Видное, Жуковский проезд, 10	0101000020E61000007B6AF5D555DB4240E8D84125AEC54B40
58561	1	10	150	28229	\N	\N	55.501519000000002	"пос.Ватутинки, МОУДОД ""Детская школа исскуств"""	Россия, Московская область, Ленинский район, поселок Ватутинки	0101000020E610000046088F368EAA42404CA94BC631C04B40
58560	1	10	150	28229	\N	\N	55.501519000000002	"пос.Ватутинки, МБУ ""Дом культуры Ватутинки"""		0101000020E610000046088F368EAA42404CA94BC631C04B40
58559	1	10	150	28229	\N	\N	55.501519000000002	пос.Ватутинки, МОУ Ватутинская средняя школа	Россия, Московская область, Ленинский район, поселок Ватутинки	0101000020E610000046088F368EAA42404CA94BC631C04B40
58574	1	10	150	48409	\N	\N	55.571489263739302	"пос.Валуево, КС ""Главмосстроя"""	Россия, Московская область, Ленинский район, деревня Валуево	0101000020E610000054E1CFF066AD42400A83328D26C94B40
58530	1	10	292	26906	\N	\N	55.896538999999997	Московская область, Красногорский муниципальный район, сельское поселение Отрадненское, пос. Светлые Горы, помещение библиотеки		0101000020E610000033349E08E2A64240554B3ACAC1F24B40
58532	1	10	292	27016	\N	\N	55.864393999999997	"Московская область, Красногорский муниципальный район, сельское поселение Отрадненское, дер. Путилково, ""Ульяновская школа"""	Россия, Московская область, Красногорский район, деревня Путилково	0101000020E61000007AFF1F274CB24240E76D6C76A4EE4B40
58524	1	10	292	26603	\N	\N	55.751947999999999	Московская область, Красногорский муниципальный район, сельское поселение Ильинское,пос.петрово-Дальнее, Школьная (помещение Петрово-Дальневской гимназии)	Россия, Московская область, Красногорский район, село Петрово-Дальнее	0101000020E610000001309E4143954240742502D53FE04B40
58523	1	10	292	26603	\N	\N	55.751947999999999	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, пос.Петрово-Дальнее, Школьная (помещение Петрово-Дальневской гимназии)	Россия, Московская область, Красногорский район, село Петрово-Дальнее	0101000020E610000001309E4143954240742502D53FE04B40
58531	1	10	292	26874	\N	\N	55.874808999999999	Красногорский район, пос. Отрадное,д.1,  в помещении администрации с/п Отрадненское		0101000020E6100000A96C585359A842408C9FC6BDF9EF4B40
58529	1	10	292	26874	\N	\N	55.874808999999999	Московская область, Красногорский муниципальный район, сельское поселение Отрадненское,пос.Отрадное, помещение детского сада	Россия, Московская область, Красногорский район, поселок Отрадное	0101000020E6100000A96C585359A842408C9FC6BDF9EF4B40
58520	1	10	292	26461	\N	\N	55.807794999999999	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, пос.Новый, 9	Россия, Московская область, Красногорский район, поселок Новый, 9	0101000020E6100000A45181936DA44240A86F99D365E74B40
58521	1	10	292	26476	\N	\N	55.801465	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, с.Николо-Урюпино, Сокольники, 1	Россия, Московская область, Красногорский район, село Николо-Урюпино	0101000020E6100000336E6AA0F99A4240BFF1B56796E64B40
58489	1	10	292	25032	6534	\N	55.857436999999997	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Кирова, 23	Россия, Московская область, Красногорский район, поселок городского типа Нахабино, улица Кирова	0101000020E610000063B83A00E2964240AFB0E07EC0ED4B40
58513	1	10	292	25032	80309	\N	55.841788189415297	Московская область, Красногорский муниципальный район, городское поселение Нахабино, Школьная, 6	Россия, Московская область, Красногорский район, поселок городского типа Нахабино, Школьная улица, 6	0101000020E610000010ECF82F1092424027158DB5BFEB4B40
58511	1	10	292	25032	6762	\N	55.847594000000001	Московская область, Красногорский муниципальный район, городское поселение Нахабино, Советская, 30	Россия, Московская область, Красногорский район, поселок городского типа Нахабино, Советская улица, 30	0101000020E61000006ABC7493189842409624CFF57DEC4B40
58510	1	10	292	25032	80581	\N	55.850059999999999	Московская область, Красногорский муниципальный район, городское поселение Нахабино, Красноармейская, 56		0101000020E6100000ACE4637781964240A2D11DC4CEEC4B40
58358	1	10	1350	18538	\N	\N	55.144356000000002	Московская область, Коломенский  район, село Нижнее Хорошово, Здание администрации сельского поселения Хорошовское	Россия, Московская область, Коломенский район, село Нижнее Хорошово	0101000020E610000058AA0B78996543409E7DE5417A924B40
58516	1	10	292	25032	80120	\N	55.840957000000003	Московская область, Красногорский муниципальный район, городское поселение Нахабино, Институтская, 21а	Россия, Московская область, Красногорский район, поселок городского типа Нахабино, Институтская улица, 21а	0101000020E6100000C28A53AD85974240D02B9E7AA4EB4B40
58515	1	10	292	25032	80120	\N	55.840048000000003	Московская область, Красногорский муниципальный район, городское поселение Нахабино, Институтская, 10б		0101000020E61000008544DAC69F964240FD885FB186EB4B40
58490	1	10	292	1264	6484	\N	55.826498000000001	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Ленина, 9	Россия, Московская область, Красногорский район, Красногорск, улица Ленина, 9	0101000020E6100000B0AD9FFEB3A84240CE1ABCAFCAE94B40
58480	1	10	292	1264	15745	\N	55.830694999999999	Московская область, Красногорский муниципальный район, городское поселение Красногорск,мкр.Опалиха, Геологов, 3	Россия, Московская область, Красногорский район, Красногорск, микрорайон Опалиха, улица Геологов, 3	0101000020E61000004C50C3B7B09E4240B1F9B83654EA4B40
58498	1	10	292	1264	80303	\N	55.815826999999999	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Чайковского, 12а	Россия, Московская область, Красногорский район, Красногорск, улица Чайковского, 12а	0101000020E6100000F99E91088DAA4240CE18E6046DE84B40
58487	1	10	292	1264	80288	\N	55.829396000000003	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Успенская, 20		0101000020E610000059DE550F98A5424074B7EBA529EA4B40
58496	1	10	292	1264	79917	\N	55.822274515188603	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Пионерская, 11	Россия, Московская область, Красногорский район, Красногорск, Школьная улица, 16а	0101000020E6100000499EEBFB70AA4240C1A8A44E40E94B40
58495	1	10	292	1264	80305	\N	55.834583000000002	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Первомайская, 13	Россия, Московская область, Красногорский район, Красногорск, Первомайская улица, 13	0101000020E61000003C670B08ADA942401766A19DD3EA4B40
58482	1	10	292	1264	80275	\N	55.823621000000003	Московская область, Красногорский муниципальный район, городское поселение Красногорск, мкр.Опалиха, Мира, 15		0101000020E6100000D89B189293A1424040A6B5696CE94B40
58486	1	10	292	1264	80279	\N	55.831457999999998	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Ленина, 32		0101000020E61000006B2A8BC22EA64240B0FF3A376DEA4B40
58484	1	10	292	1264	80279	\N	55.830857633243298	"Г.Красногорск, ул. Ленина, д. 62, ОАО ""Водоканал"""	Россия, Московская область, Красногорский район, Красногорск, улица Ленина	0101000020E6100000C2340C1F11A742405BCF108E59EA4B40
58493	1	10	292	1264	79909	\N	55.816443999999997	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Комсомольская, 7а		0101000020E6100000D1CFD4EB16A94240F981AB3C81E84B40
58491	1	10	292	1264	79909	\N	55.814973000000002	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Комсомольская, 41		0101000020E6100000EDB776A224A84240BF0F070951E84B40
58488	1	10	292	1264	80278	\N	55.836000610082301	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Карбышева, 5	Россия, Московская область, Красногорский район, Красногорск, улица Карбышева, 5	0101000020E6100000BAF8DB9E20A742402F36AD1402EB4B40
58485	1	10	292	1264	80278	\N	55.839426000000003	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Карбышева, 21	Россия, Московская область, Красногорский район, Красногорск, улица Карбышева, 21	0101000020E6100000E38DCC237FA64240C0B4A84F72EB4B40
58505	1	10	292	1264	71821	\N	55.820840869202101	Московская область, Красногорский муниципальный район, городское поселение Красногорск, мкр.Павшинская пойма. ул.Игната Титова, 5	Россия, Московская область, Красногорский район, Красногорск, улица Игната Титова	0101000020E61000003ACB2C42B1AF4240A41B615111E94B40
58504	1	10	292	1264	71796	\N	55.8212550851866	Московская область, Красногорский муниципальный район, городское поселение Красногорск, мкр.Павшинская пойма.ул.Игната Титова, 5		0101000020E61000003BFF76D9AFAF4240975643E21EE94B40
58500	1	10	292	1264	79908	\N	55.811335999999997	Московская область, Красногорский муниципальный район, городское поселение Красногорск, Вокзальная, 19	Россия, Московская область, Красногорский район, Красногорск, Вокзальная улица, 19	0101000020E6100000C2853C821BAB4240A208A9DBD9E74B40
58508	1	10	292	25932	80927	\N	55.891359999999999	Московская область, Красногорский муниципальный район, городское поселение Нахабино, дер.Козино, ул.Центральная, помещ.детского сада		0101000020E6100000234E27D9EA964240357BA01518F24B40
58527	1	10	292	26777	\N	\N	55.774147999999997	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, пос.Истра	Россия, Московская область, Красногорский район, поселок Истра	0101000020E610000083893F8A3A934240C4211B4817E34B40
58522	1	10	292	26545	\N	\N	55.757609597156502	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, пос.Ильинское	Россия, Московская область, Красногорский район, село Ильинское	0101000020E6100000C39D0B23BD9E4240B08F4E5DF9E04B40
58517	1	10	292	60273	\N	\N	55.7590731839542	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, Помещение красного уголка дачного хозяйства Архангельское	Россия, Московская область, Красногорский район, поселок Ильинка	0101000020E6100000492C29779F9F42406823D74D29E14B40
58526	1	10	292	62014	80877	\N	55.753540889609297	Московская область, Красногорский муниципальный район, сельское поселение Ильинское. с.Дмитровское, Центральная (фельдшерско-акушерский пункт0	Россия, Московская область, Красногорский район, село Дмитровское	0101000020E610000067817687148F4240FA980F0874E04B40
58503	1	10	292	25704	81025	\N	55.801148846916	Московская область, Красногорский муниципальный район, городское поселение Красногорск, дер.Гольево.ул.Центральная, 1	Россия, Московская область, Красногорский район, деревня Гольево, Центральная улица	0101000020E6100000F834272F32A742408F1CE90C8CE64B40
58519	1	10	292	25492	\N	\N	55.789436000000002	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, пос.Архангельское	Россия, Московская область, Красногорский район, поселок Архангельское	0101000020E61000005C8E57207AA642407D24253D0CE54B40
58518	1	10	292	25492	\N	\N	55.789436000000002	Московская область, Красногорский муниципальный район, сельское поселение Ильинское, пос Архангельское	Россия, Московская область, Красногорский район, поселок Архангельское	0101000020E61000005C8E57207AA642407D24253D0CE54B40
58528	1	10	292	26794	\N	\N	55.859063999999996	"Московская область, Красногорский муниципальный район, сельское поселение Отрадненское, с. Ангелово, ""Ангеловская школа"""		0101000020E6100000C93A1C5DA5A94240E19524CFF5ED4B40
58343	1	10	1350	14464	\N	\N	55.160293000000003	Московская область, Коломенский  район, село Шеметово, Здание сельского дома культуры		0101000020E6100000749B70AFCC4F43408D63247B84944B40
31256	1	10	1350	14464	\N	\N	55.160293000000003	д.Шеметово, 10		0101000020E6100000749B70AFCC4F43408D63247B84944B40
58355	1	10	1350	18393	\N	\N	55.202418999999999	"Московская область, Коломенский  район, село Черкизово, Здание районного дома культуры ""Черкизово"""		0101000020E610000039268BFB8F5E4340658BA4DDE8994B40
58359	1	10	1350	18623	\N	\N	55.130122711125601	Московская область, Коломенский  район, село Чанки, Здание начальной школы - детского сада	Россия, Московская область, Коломенский район, село Чанки	0101000020E610000038BF61A2416A43408CBAD6DEA7904B40
58339	1	10	1350	60236	\N	\N	55.100731000000003	Московская область, Коломенский  район, населенный пунк Сосновый Бор, Здание средней школы		0101000020E61000004E8061F9F36D4340C158DFC0E48C4B40
58348	1	10	1350	18042	\N	\N	55.089762999999998	Московская область, Коломенский  район, село Сергиевское, Здание сельской библиотеки		0101000020E6100000C1FD8007066C434007B29E5A7D8B4B40
58347	1	10	1350	17960	\N	\N	55.098007354247102	Московская область, Коломенский  район, поселок Сергиевский, здание сельской библиотеки	Россия, Московская область, Коломенский район, Сергиевский поселок, Центральная улица	0101000020E610000024624A24D16D4340B9E34D7E8B8C4B40
58346	1	10	1350	17960	\N	\N	55.097588999999999	Московская область, Коломенский  район, поселок Сергиевский, Здание средней школы	Россия, Московская область, Коломенский район, Сергиевский поселок	0101000020E61000004E7ADFF8DA6D434084B9DDCB7D8C4B40
58335	1	10	1350	17385	\N	\N	55.136349000000003	Московская область, Коломенский  район, деревня Сельниково, Здание сельского дома культуры	Россия, Московская область, Коломенский район, деревня Сельниково	0101000020E61000002907B30930944340D1EB4FE273914B40
58351	1	10	1350	18180	\N	\N	55.137146999999999	Московская область, Коломенский  район, поселок Проводник, Здание средней школы		0101000020E61000007A724D81CC4A43404CDF6B088E914B40
58338	1	10	1350	17553	\N	\N	55.072834	Московская область, Коломенский  район, село Пирочи, Здание сельского дома культуры	Россия, Московская область, Коломенский район, село Пирочи	0101000020E6100000A5DDE8633E7A4340B804E09F52894B40
58349	1	10	1350	62002	\N	\N	55.088078498818099	Московская область, Коломенский  район, село Пестриковское, Здание сельского дома культуры	Россия, Московская область, Коломенский район, село Пестриково	0101000020E6100000FAB660A92E724340A1BFD023468B4B40
58327	1	10	1350	16953	\N	\N	55.210582000000002	Московская область, Коломенский  район, поселок Пески, Почтовая, дом 34  (средняя школа)	Россия, Московская область, Коломенский район, поселок городского типа Пески	0101000020E6100000A5315A47556343402A90D959F49A4B40
58326	1	10	1350	16953	\N	\N	55.210582000000002	Московская область, Коломенский  район, поселок Пески, Советская, дом 19  (дом культуры)	Россия, Московская область, Коломенский район, поселок городского типа Пески	0101000020E6100000A5315A47556343402A90D959F49A4B40
58333	1	10	1350	17282	\N	\N	55.061631264047101	Московская область, Коломенский  район, поселок Первомайский, Здание сельской библиотеки	Россия, Московская область, Коломенский район, поселок Первомайский	0101000020E6100000E3C798BB96544340BBB54C86E3874B40
58345	1	10	1350	17898	\N	\N	55.104945000000001	Московская область, Коломенский  район, село Парфентьево, Здание сельской библиотеки		0101000020E61000004A29E8F6926843407A7077D66E8D4B40
58337	1	10	1350	17482	\N	\N	55.101844	Московская область, Коломенский  район, село Октябрьское, Здание сельской библиотеки		0101000020E6100000D15B3CBCE77E43409CA56439098D4B40
58631	1	10	204	10780	80741	\N	55.871535999999999	д. Павловское, Молодежная, д.6А		0101000020E61000006D01A1F5F0794240B1A4DC7D8EEF4B40
58341	1	10	1350	17645	\N	\N	55.199449741065699	Московская область, Коломенский  район, село Непецино, Здание сельского дома культуры	Россия, Московская область, Коломенский район, село Непецино	0101000020E6100000FD4AE7C3B34C4340F697DD9387994B40
58340	1	10	1350	17645	\N	\N	55.199400648086701	Московская область, Коломенский район, село Непецино, Здание Администрации сельского поселения Непецинское	Россия, Московская область, Коломенский район, село Непецино	0101000020E6100000D89E5912A04C434015E5D2F885994B40
58334	1	10	1350	17343	\N	\N	55.008572999999998	Московская область, Коломенский  район, деревня Малое карасево, Здание клуба		0101000020E6100000CA181F662F514340765089EB18814B40
58350	1	10	1350	18151	\N	\N	55.100577000000001	Московская область, Коломенский  район, село Лукерьино, Здание сельского дома культуры		0101000020E61000005514AFB2B65343406ADD06B5DF8C4B40
58332	1	10	1350	17237	\N	\N	55.034229000000003	Московская область, Коломенский  район, поселок Лесной, Здание сельского дома культуры		0101000020E610000021C84109334F434093C9A99D61844B40
58342	1	10	1350	17724	\N	\N	55.195195397901799	Московская область, Коломенский  район, поселок Индустрия, Здание администрации сельского поселения Непецинское	Россия, Московская область, Коломенский район, деревня Индустрия	0101000020E610000045813E9127434340DEAB5626FC984B40
58336	1	10	1350	17442	\N	\N	55.120680999999998	Московская область, Коломенский  район, деревня Зарудня, Здание средней школы		0101000020E61000003C4A253CA1894340D11F9A79728F4B40
58329	1	10	1350	17094	\N	\N	55.05086	Московская область, Коломенский  район, поселок Заречный, Здание начальной школы-детского сада		0101000020E61000001EF98381E746434058569A9482864B40
58356	1	10	1350	18436	\N	\N	55.222178999999997	Московская область, Коломенский  район, деревня Губастово, Здание сельской библиотеки		0101000020E61000009F55664AEB654340D26D895C709C4B40
58344	1	10	1350	17828	\N	\N	55.170594000000001	Московская область, Коломенский  район, поселок Возрождение, Здание школы	Россия, Московская область, Коломенский район, поселок Возрождение	0101000020E6100000FD885FB18653434069723106D6954B40
58352	1	10	1350	18246	\N	\N	55.138860999999999	Московская область, Коломенский  район, деревня Богдановка, Здание клуба		0101000020E61000006919A9F7543A43404DD87E32C6914B40
58330	1	10	1350	17158	\N	\N	55.054031000000002	Московская область, Коломенский  район, поселок Биорки, Здание сельского дома культуры	Россия, Московская область, Коломенский район, поселок Биорки	0101000020E61000006C5ED5592D4E43402FFCE07CEA864B40
58328	1	10	1350	17016	\N	\N	54.977784999999997	Московская область, Коломенский  район, село Акатьево, Здание администрации сельского поселения Акатьевское	Россия, Московская область, Коломенский район, село Акатьево	0101000020E61000000740DCD5AB6043407AC2120F287D4B40
58294	1	10	205	15378	\N	\N	56.392432999999997	Московская область, Клинский муниципальный район, д.Ямуга, 55а		0101000020E6100000EB1ED95C35554240826F9A3E3B324C40
58310	1	10	205	16118	\N	\N	56.398566000000002	Московская область, Клинский муниципальный район, п.Шевляково, 10а	Россия, Московская область, Клинский район, поселок Шевляково	0101000020E610000004711E4E606E424016A6EF3504334C40
58300	1	10	205	15660	\N	\N	56.287652000000001	Московская область, Клинский район, пос.Чайковского,  д.22		0101000020E610000088D860E1246542408350DEC7D1244C40
58311	1	10	205	16185	\N	\N	56.374451999999998	Московская область, Клинский муниципальный район, Струбково, Центральная, 3	Россия, Московская область, Клинский район, деревня Струбково	0101000020E610000041F0F8F6AE754240FDF50A0BEE2F4C40
58297	1	10	205	15532	\N	\N	56.299090999999997	Московская область, Клинский муниципальный район, Стеглово, 96		0101000020E61000006ADB300A825D424093C3279D48264C40
58291	1	10	205	15219	\N	\N	56.477229000000001	Московская область, Клинский муниципальный район, Спас-Заулок, Центральная, 19	Россия, Московская область, Клинский район, село Спас-Заулок	0101000020E61000003C4F3C670B4A4240F5D901D7153D4C40
58309	1	10	205	60286	74294	\N	56.474284928702502	Московская область, Клинский муниципальный район, д.Слобода, Центральная, 11	Россия, Московская область, Клинский район, деревня Слобода	0101000020E6100000459C4EB2D56F4240DFFDF15EB53C4C40
58302	1	10	205	15735	\N	\N	56.309058999999998	Московская область, Клинский муниципальный район, Селинское, 111		0101000020E6100000DAE1AFC91A51424069C4CC3E8F274C40
58301	1	10	205	15721	\N	\N	56.285358000000002	Московская область, Клинский муниципальный район, Решоткино, 57		0101000020E610000052F2EA1C0356424074D3669C86244C40
58306	1	10	205	15906	\N	\N	56.445408999999998	Московская область, Клинский муниципальный район, Решетниково, Центральная, 14	Россия, Московская область, Клинский район, поселок городского типа Решетниково	0101000020E610000083DF8618AF4742400A2C802903394C40
58305	1	10	205	15906	72017	\N	56.442903796429697	Московская область, Клинский муниципальный район, Решетниково, Лесная, 3	Россия, Московская область, Клинский район, поселок городского типа Решетниково	0101000020E6100000ED629AE95E47424040A20914B1384C40
58296	1	10	205	15454	80935	\N	56.231903000000003	Московская область, Клинский муниципальный район, Покровка, Покровская, 2а		0101000020E61000006B65C22FF5674240126C5CFFAE1D4C40
58319	1	10	205	16590	74099	\N	56.256338	Московская область, Клинский муниципальный район, с.Петровское, Центральная, 6		0101000020E6100000E5D2F885573C42406C5CFFAECF204C40
58303	1	10	205	15803	\N	\N	56.327536000000002	Московская область, Клинский муниципальный район, Першутино, 1		0101000020E6100000CE8DE9094B5442409F211CB3EC294C40
94503	1	10	81	98	452	\N	55.362107000000002	г.Егорьевск, ул.Совхозная (ДК "Лад"), д.45		0101000020E6100000CC0C1B65FD8043408B53AD8559AE4B40
58315	1	10	205	16417	\N	\N	56.093005485860203	"Московская область, Клинский муниципальный район, Нудоль, Кинотеатр ЦСГ ""Чайковский"""	Россия, Московская область, Клинский район, поселок Нудоль	0101000020E61000008F183DB7D03F4240A7AE7C96E70B4C40
58316	1	10	205	16417	67029	\N	56.090893999999999	Московская область, Клинский муниципальный район, п.Нудоль, Советская, 8		0101000020E610000073F1B73D4140424089B3226AA20B4C40
58312	1	10	205	16249	71899	\N	56.371904000000001	Московская область, Клинский муниципальный район, Новощапово, Центральная, 60		0101000020E6100000B665C0594A66424034A0DE8C9A2F4C40
58317	1	10	205	16498	71882	\N	56.1067020154197	Московская область, Клинский муниципальный район, п.Нарынка, Королева, 10а	Россия, Московская область, Клинский район, поселок Нарынка	0101000020E6100000BCCD1B27854142407A354069A80D4C40
58298	1	10	205	15581	\N	\N	56.265307	Московская область, Клинский муниципальный район, Мисирево, 76а		0101000020E610000080F0A1444B6042402F336C94F5214C40
58320	1	10	205	16646	\N	\N	56.337322	Московская область, Клинский муниципальный район, Масюгино, 15		0101000020E61000004912842BA0484240541C075E2D2B4C40
58304	1	10	205	62035	\N	\N	56.261524598328798	Московская область, Клинский муниципальный район, п.Марков Лес, 10	Россия, Московская область, Клинский район	0101000020E610000036AE7FD7675442400F0BB5A679214C40
58314	1	10	205	16341	\N	\N	56.126750000000001	Московская область, Клинский муниципальный район, Кузнецово, 12		0101000020E6100000EEEC2B0FD25342404E62105839104C40
58274	1	10	205	776	\N	\N	56.328493999999999	Московская область, Клинский муниципальный район, г.Клин, Бородинский сад, 1	Россия, Московская область, Клинский район, Клин	0101000020E61000005C59A2B3CC5C4240537765170C2A4C40
58263	1	10	205	776	\N	\N	56.328350908509798	Московская область, Клинский муниципальный район, г.Клин, Майданово, 86	Россия, Московская область, Клинский район, Клин, улица Гагарина	0101000020E61000006F490ED8D55C4240F04DD367072A4C40
58430	1	10	205	776	5905	\N	56.356721999999998	Московская область, городской округ Королёв, Терешковой, 7	Россия, Московская область, Клинский район, Клин, улица Терешковой, 7	0101000020E61000003ACC971760594240C1E10511A92D4C40
58261	1	10	205	776	3901	\N	56.369416999999999	Московская область, Клинский муниципальный район, г.Клин, Мичурина, 1	Россия, Московская область, Клинский район, Клин, улица Мичурина, 1	0101000020E6100000C32973F38D58424010CB660E492F4C40
60008	1	10	205	776	319	\N	56.327075999999998	Московская область, городской округ Химки, мкр. Подрезково, Мира, 6	Россия, Московская область, Клинский район, Клин, улица Мира, 6	0101000020E6100000971C774A075D42403BA759A0DD294C40
58280	1	10	205	776	319	\N	56.329251999999997	Московская область, Клинский муниципальный район, г.Клин, Мира, 5	Россия, Московская область, Клинский район, Клин, улица Мира, 5	0101000020E6100000164ED2FC315D42404012F6ED242A4C40
58256	1	10	205	776	3833	\N	56.336753000000002	Московская область, Клинский муниципальный район, г.Клин, Ленина, 18	Россия, Московская область, Клинский район, Клин, улица Ленина, 18	0101000020E6100000BC0853944B5D42403AEAE8B81A2B4C40
58286	1	10	205	776	4091	\N	56.324741000000003	Московская область, г. Клин, ул.К.Маркса, д.18/20		0101000020E61000005C902DCBD75B4240CE55F31C91294C40
58284	1	10	205	776	4091	\N	56.319409	Московская область, Клинский муниципальный район, г.Клин, К.Маркса, 76а	Россия, Московская область, Клинский район, Клин, улица Карла Маркса, 76а	0101000020E61000009B90D618745C42402786E464E2284C40
58283	1	10	205	776	4165	\N	56.328403999999999	Московская область, Клинский муниципальный район г.Клин, Гагарина, 39	Россия, Московская область, Клинский район, Клин, улица Гагарина, 39	0101000020E6100000B2DAFCBFEA5C424013F06B24092A4C40
58273	1	10	205	776	4069	\N	56.317008000000001	Московская область, Клинский муниципальный район, г.Клин, 60 лет Комсомола, 5а	Россия, Московская область, Клинский район, Клин, улица 60 лет Комсомола, 5а	0101000020E6100000471D1D57236142400249D8B793284C40
58269	1	10	205	776	79895	\N	56.333159999999999	Московская область, Клинский муниципальный район, г.Клин, Чайковского, 14		0101000020E61000009C4F1DAB945E4240ED2AA4FCA42A4C40
58270	1	10	205	776	4025	\N	56.337052	Московская область, Клинский муниципальный район, г.Клин, Талицкий проезд, 49	Россия, Московская область, Клинский район, Клин, Талицкий проезд, 49	0101000020E61000004E64E6029761424094861A85242B4C40
58272	1	10	205	776	80150	\N	56.326571999999999	Московская область, Клинский муниципальный район, г.Клин, Спортивная, 3а		0101000020E6100000325A47551360424008E57D1CCD294C40
58268	1	10	205	776	80890	\N	56.334297999999997	Московская область, Клинский муниципальный район, г.Клин, Сестрорецкая, 43а		0101000020E61000007AA9D898D75F4240218FE046CA2A4C40
58265	1	10	205	776	3954	\N	56.343628000000002	Московская область, Клинский муниципальный район, г.Клин, Пролетарский проезд, 8	Россия, Московская область, Клинский район, Клин, Пролетарский проезд, 4	0101000020E6100000064A0A2C805F4240B5FE9600FC2B4C40
58287	1	10	205	776	4219	\N	56.324764999999999	Московская область, Клинский муниципальный район, г.Клин, Московская, 4		0101000020E6100000D367075C575A424056F146E691294C40
58262	1	10	205	776	80201	\N	56.368958075583997	Московская область, Клинский муниципальный район, г. Клин, Мичурина, 1	Россия, Московская область, Клинский район, Клин, Речная улица, 1	0101000020E61000005BCF108E595842407DCC07043A2F4C40
58281	1	10	205	776	79887	\N	56.328654253122998	Московская область, Клинский муниципальный район, г.Клин, Захватаева, 9а	Россия, Московская область, Клинский район, Клин, улица Захватаева, 5	0101000020E6100000DE1E84807C5D42408CD99255112A4C40
38536	1	6	1067	47885	\N	\N	54.568410999999998	д.Покровское, 65		0101000020E6100000698A00A777434240E4D70FB1C1484B40
58285	1	10	205	776	79961	\N	56.326409054469501	Московская область, Клинский муниципальный район, г.Клин, Загородная, 3/29	Россия, Московская область, Клинский район, Клин, Загородная улица, 10б	0101000020E6100000F86D88F19A5B42405E0F26C5C7294C40
58282	1	10	205	776	80107	\N	56.328403999999999	Московская область, Клинский муниципальный район, г.Клин, Гагарина, 39/2		0101000020E6100000B2DAFCBFEA5C424013F06B24092A4C40
58288	1	10	205	776	4230	\N	56.327804999999998	Московская область, Клинский муниципальный район, г.Клин, Волоколамское шоссе, 20/1	Россия, Московская область, Клинский район, Клин, Волоколамское шоссе, 20/1	0101000020E610000072FE2614225A42408E3BA583F5294C40
58279	1	10	205	776	4121	\N	56.322110000000002	Московская область, Клинский муниципальный район, г.Клин, Бородинский проезд, 28	Россия, Московская область, Клинский район, Клин, Бородинский проезд, 28	0101000020E610000073637AC2125D424077DB85E63A294C40
58278	1	10	205	776	4121	\N	56.324361000000003	Московская область, Клинский муниципальный район, г.Клин, Бородинский проезд, 23	Россия, Московская область, Клинский район, Клин, Бородинский проезд, 23	0101000020E6100000CD21A985925D4240878C47A984294C40
58276	1	10	205	776	74123	\N	56.316558734685202	Московская область, Клинский муниципальный район, г.Клин, 50 лет Октября, 90а	Россия, Московская область, Клинский район, Клин, улица Карла Маркса, 90а	0101000020E61000002EC72B103D5D424092205C0185284C40
58264	1	10	205	776	79867	\N	56.331686821091999	Московская область, Клинский муниципальный район, г.Клин, Дзержинского, 2	Россия, Московская область, Клинский район, Клин, улица Дзержинского, 4	0101000020E61000008AE6012CF25B424012C138B8742A4C40
58292	1	10	205	15273	\N	\N	56.522078	Московская область, Клинский муниципальный район, д.Захарово, 41б		0101000020E61000009A999999995D424005FBAF73D3424C40
58318	1	10	205	16551	\N	\N	56.233854000000001	Московская область, Клинский муниципальный район, Елгозино, 46		0101000020E61000003B394371C72D4240F70489EDEE1D4C40
58299	1	10	205	15606	81038	\N	56.283149999999999	Московская область, Клинский район, д. Давыдково, д.24а		0101000020E6100000C2BF081A3369424063EE5A423E244C40
58323	1	10	205	16720	4673	\N	56.324666000000001	Московская область, Клинский муниципальный район, Высоковск, Текстильная, 4а	Россия, Московская область, Клинский район, Высоковск, Текстильная улица, 4а	0101000020E61000001EC6A4BF97464240C30FCEA78E294C40
58321	1	10	205	16720	4656	\N	56.319828999999999	Московская область, Клинский муниципальный район, Высоковск, Первомайская, 2а	Россия, Московская область, Клинский район, Высоковск, Первомайская улица, 2а	0101000020E6100000B43A394371474240FCA71B28F0284C40
58325	1	10	205	16720	81063	\N	56.319828999999999	Московская область, Клинский район, г.Высоковск, ул.Первомайская, д.2а		0101000020E6100000B43A394371474240FCA71B28F0284C40
58322	1	10	205	16720	80198	\N	56.319220000000001	Московская область, Клинский муниципальный район, Высоковск, Ленина, 11		0101000020E61000001DCC26C0B0464240541D7233DC284C40
58324	1	10	205	16720	80892	\N	56.306812000000001	Московская область, Клинский муниципальный район, Высоковск, Курятникова, 97		0101000020E6100000A5F8F884EC4642409B02999D45274C40
58307	1	10	205	15981	\N	\N	56.383113999999999	Московская область, Клинский муниципальный район с.Воздвиженское, 17	Россия, Московская область, Клинский район, село Воздвиженское	0101000020E6100000A2B8E34D7E254240E3512AE109314C40
58293	1	10	205	62030	\N	\N	56.441622000000002	Московская область, Клинский муниципальный район, д.Бирево, 70а	Россия, Московская область, Клинский район, деревня Бирево	0101000020E6100000910DA48B4D5F4240D998D71187384C40
58240	1	10	484	12844	80922	\N	54.748441999999997	д.Яковское, ул.Клубная, д.1а		0101000020E6100000B2F336363B224340F6798CF2CC5F4B40
58242	1	10	484	12926	80812	\N	54.714920999999997	д.Топканово, ул.Новая, д.16		0101000020E6100000302E55698B3D43409F1C0588825B4B40
58235	1	10	484	46247	71883	\N	54.813231000000002	д.Тарасково, ул.Комсомольская, д.28		0101000020E6100000F964C57075024340F48B12F417684B40
56062	1	10	484	2897	746	\N	54.796475000000001	г.Ожерелье, ул.Строительная, д.15	Россия, Московская область, Каширский район, Ожерелье, Строительная улица, 15	0101000020E61000000EF96706F1214340728A8EE4F2654B40
55891	1	10	484	2897	80252	\N	54.791865999999999	г.Ожерелье, ул.Советская, д.10		0101000020E610000010035DFB022243403C6876DD5B654B40
94467	1	10	484	2897	1288	\N	54.796838000000001	г.Ожерелье, ул.Заводская, д.1	Россия, Московская область, Каширский район, Ожерелье, Заводская улица, 1	0101000020E61000000D6E6B0BCF234340E31A9FC9FE654B40
56105	1	10	484	2897	80834	\N	54.807704999999999	г.Ожерелье, ул.1 Мая, д.29		0101000020E61000006118B0E42A24434068E89FE062674B40
94536	1	10	484	46121	68090	\N	54.828401890068001	поселок Новоселки, ул.Центральная, д.32, Здание Новоселковской начальной общеобразовательной школы	Россия, Московская область, Каширский район, поселок Новоселки	0101000020E610000063450DA66124434072F8A413096A4B40
58243	1	10	484	46446	80976	\N	54.739252999999998	поселок Маслово, ул.Фабричная, д.5а		0101000020E6100000A6643909A53D4340253CA1D79F5E4B40
58236	1	10	484	12682	80933	\N	54.815621999999998	д.Лиды, Иваньковское шоссе, д.6		0101000020E61000006649809A5A0E4340F5F23B4D66684B40
58239	1	10	484	59526	71837	\N	54.748473326597598	д.Ледово, ул.Стадионная, д.1	Россия, Московская область, Каширский район, деревня Ледово	0101000020E6100000F2EB87D860334340317898F6CD5F4B40
58234	1	10	484	12586	80924	\N	54.803091999999999	д.Корыстово, ул.Центральная, д.13		0101000020E61000007FDAA84E070E4340F1D6F9B7CB664B40
94539	1	10	484	12446	80774	\N	54.765098000000002	д.Кокино, ул.Садовая, д.33 Здание Кокинской основной общеобразовательной школы		0101000020E610000059897956D21A4340151E34BBEE614B40
58226	1	10	484	10588	3420	\N	54.838228999999998	г.Кашира, ул.Победы, д.7	Россия, Московская область, Каширский район, Кашира, улица Победы, 7к1	0101000020E61000004CE2AC889A18434086C77E164B6B4B40
58222	1	10	484	10588	3378	\N	54.837384	г.Кашира, ул. Моргунова, д.15	Россия, Московская область, Каширский район, Кашира, улица Моргунова, 15	0101000020E610000019AF795567154340CA181F662F6B4B40
58224	1	10	484	10588	80861	\N	54.842537999999998	г.Кашира, ул. Школьная, д.1		0101000020E610000044882B67EF16434091D10149D86B4B40
55302	1	10	484	10588	7646	\N	54.842117999999999	г.Кашира, ул.Центральная, д.17	Россия, Московская область, Каширский район, Кашира, Центральная улица, 17	0101000020E61000003F390A10051F4340BCAFCA85CA6B4B40
58219	1	10	484	10588	3342	\N	54.826509999999999	г.Кашира, ул.Стрелецкая, д.65	Россия, Московская область, Каширский район, Кашира, Стрелецкая улица, 65	0101000020E6100000F12C41464013434092E86514CB694B40
58220	1	10	484	10588	80168	\N	54.838520000000003	г.Кашира, ул.Советская, д.38		0101000020E6100000EB3BBF28411343405E85949F546B4B40
55317	1	10	484	10588	7811	\N	54.843418999999997	г.Кашира, ул.Садовая, д.27	Россия, Московская область, Каширский район, Кашира, Садовая улица, 27	0101000020E610000022C7D633841F43409AE95E27F56B4B40
58225	1	10	484	10588	80045	\N	54.838228999999998	г.Кашира, ул. Победы, д.7		0101000020E61000004CE2AC889A18434086C77E164B6B4B40
55271	1	10	484	10588	80256	\N	54.847000999999999	г.Кашира, ул.Новокаширская, д.4		0101000020E610000085949F54FB1E4340F3565D876A6C4B40
58214	1	10	484	10588	80159	\N	54.848281	г.Кашира, ул.Металлистов, д.8		0101000020E6100000EEEE01BA2F1F4340BA68C878946C4B40
58221	1	10	484	10588	80173	\N	54.831933999999997	г.Кашира, ул. Маршала Астахова, д.1		0101000020E6100000E27327D87F134340193735D07C6A4B40
58228	1	10	484	10588	80218	\N	54.852728999999997	г.Кашира, ул.Клубная, д.2		0101000020E6100000D099B4A9BA1F4340E6AC4F39266D4B40
58223	1	10	484	10588	80177	\N	54.856749999999998	г.Кашира, ул.Ильича, д.69а		0101000020E6100000420A9E42AE1843408B6CE7FBA96D4B40
94538	1	10	484	12437	72277	\N	54.805982	поселок Зендиково, ул.Октябрьская, д.5,  Здание Зендиковской средней общеобразовательной школы		0101000020E6100000EFE53E390A14434014950D6B2A674B40
94537	1	10	484	12371	72010	\N	54.852246999999998	поселок Большое Руново, ул.Южная, д.8, Здание Руновской основной общеобразовательной школы		0101000020E6100000BE840A0E2F3443409B8E006E166D4B40
58241	1	10	484	46393	71836	\N	54.681779499486602	поселок Богатищево, ул.Новая, д.16		0101000020E61000006EFC89CA86434340BF0CC68844574B40
58233	1	10	484	46210	\N	\N	54.716059999999999	д.Барабаново, ул.Ленина, д.5	Россия, Московская область, Каширский район, деревня Барабаново	0101000020E610000030B95164AD154340A4FCA4DAA75B4B40
94524	1	10	204	10812	80819	\N	55.893667000000001	Московская область, Истринский муниципальный район, сельское поселение Ивановское, п. станции Манихино,ул.Железнодорожная, д.22 помещение МОУ "Манихинская основная общеоб.школа"	Россия, Московская область, Истринский район, поселок станции Манихино	0101000020E6100000D4635B069C774240D94125AE63F24B40
59612	1	10	204	60251	\N	\N	55.793958706193401	д.Поречье, д.32	Россия, Московская область, Истринский район, дачный поселок Поречье	0101000020E610000016DD7A4D0F904240B4AED172A0E54B40
58185	1	10	204	60278	74280	\N	55.880955	Московская область, Истринский муниципальный район, городское поселение Снегири, Станционная, здание Дома культуры (фойе), 22		0101000020E610000065E08096AE844240B41F2922C3F04B40
58184	1	10	204	60278	74280	\N	55.880955	Московская область, Истринский муниципальный район, городское поселение Снегири, Станционная, здание Снегиревского Дома культуры(актовый зал), 22		0101000020E610000065E08096AE844240B41F2922C3F04B40
58187	1	10	204	10166	\N	\N	55.883848	Московская область, Истринский муниципальный район, городское поселение Снегири, д.Ленино, 90		0101000020E6100000396403E962874240485167EE21F14B40
58203	1	10	204	11073	\N	\N	55.945135999999998	Московская область, Истринский муниципальный район, сельское поселение Лучинское, п. Северный, здание Клуба		0101000020E6100000FAEDEBC0396B4240D9226937FAF84B40
94535	1	10	204	11756	\N	\N	56.005400000000002	Московская область, Истринский муниципальный район, сельское поселение Ядроминское, д. Савельево,  д56, помещение МУК "Ядроминская сельская центр.библиотечная система"		0101000020E6100000CDAE7B2B124D4240FFB27BF2B0004C40
94530	1	10	204	11210	\N	\N	55.972538999999998	Московская область, Истринский муниципальный район, сельское поселение Новопетровское, п. Румянцево, Волоколамское ш., д.117 здание Румянцевской ср.школы	Россия, Московская область, Истринский район, поселок Румянцево	0101000020E6100000B77F65A549454240D28A6F287CFC4B40
94534	1	10	204	60280	74283	\N	55.853506536026103	Московская область, Истринский муниципальный район, сельское поселение Павло-Слободское, с.Рождественно, ул.Южная, д.19, помещение МОУ "Рождественская сред.общеобр.школа"		0101000020E6100000E94999D4D08642401BF4A5B73FED4B40
94531	1	10	204	11272	\N	\N	56.068193000000001	Московская область, Истринский муниципальный район, сельское поселение Новопетровское, д. Пречистое,  д.38/3 здание Дома культуры		0101000020E6100000CFA2772AE04042407768588CBA084C40
94532	1	10	204	11348	\N	\N	55.811568000000001	Московская область, Истринский муниципальный район, сельское поселение Обушковское, д. Покровское, ул.Майская, д.7, здание Покровской средней школы	Россия, Московская область, Истринский район, деревня Покровское	0101000020E610000019C6DD205A814240753DD175E1E74B40
94526	1	10	204	11010	\N	\N	55.914119999999997	Московская область, Истринский муниципальный район, сельское поселение Лучинское, п. Первомайский, д.33 здание Клуба		0101000020E61000009CFBABC77D6542404C4F58E201F54B40
94523	1	10	204	10780	\N	\N	55.871535999999999	Московская область, Истринский муниципальный район, д.Павловское, д.16, помещение МОУ "Октябрьская сред.общеоб.школа"	Россия, Московская область, Истринский район, деревня Павловское	0101000020E61000006D01A1F5F0794240B1A4DC7D8EEF4B40
58213	1	10	204	773	\N	\N	55.814342128775998	Московская область, Истринский муниципальный район, сельское поселение Павло-Слободское, Здание Научного отдела ГБС	Россия, Московская область, Истринский район, село Павловская Слобода, улица Ленина	0101000020E6100000543541D47D8A42402FE1D05B3CE84B40
58212	1	10	204	773	80158	\N	55.818387000000001	Московская область, Истринский муниципальный район, сельское поселение Павло-Слободское, Комсомольская, 5а		0101000020E61000007E569929AD8B42405C3CBCE7C0E84B40
58211	1	10	204	773	80106	\N	55.818382	Московская область, Истринский муниципальный район, сельское поселение Павло-Слободское, Дзержинского, здание Красного уголка, 4		0101000020E6100000793C2D3F708B42404AD1CABDC0E84B40
94533	1	10	204	11402	80814	\N	55.851191999999998	Московская область, Истринский муниципальный район, сельское поселение Онуфриевское, д. Онуфриево, ул.Центральная, д.1, здание Дома культуры		0101000020E610000063D4B5F63E414240F44E05DCF3EC4B40
94529	1	10	204	11150	80061	\N	55.9896758066308	Московская область, Истринский муниципальный район, сельское поселение Новопетровское,   ул.Северная, д.49, помещение Дома культуры	Россия, Московская область, Истринский район, село Новопетровское	0101000020E61000007AC37DE4D63C42406CD102B4ADFE4B40
94528	1	10	204	11150	74118	\N	55.995352363548101	Московская область, Истринский муниципальный район, сельское поселение Новопетровское, ул.Полевая, д.7, помещение МОУ "Новопетровская сред.общеобр.школа"	Россия, Московская область, Истринский район, село Новопетровское	0101000020E6100000D978B0C56E3D42400C01C0B167FF4B40
59019	1	10	204	18678	\N	\N	55.891157999999997	д. Новодарьино, 15		0101000020E61000002C0C91D3D7554240CDC8207711F24B40
58200	1	10	204	40338	\N	\N	55.908620999999997	"Московская область, Истринский муниципальный район, сельское поселение Лучинское, Здание Административного корпуса санатория ""Истра"""		0101000020E61000001807978E39694240BABA63B14DF44B40
94527	1	10	204	40338	81079	\N	55.909271845034901	Московская область, Истринский муниципальный район, сельское поселение Лучинское, ул.Железнодорожная, д.72, помещение МОУ "Лучинская сред.общеобр.школа"	Россия, Московская область, Истринский район, село Лучинское	0101000020E6100000A5660FB40269424092955F0663F44B40
58216	1	10	204	11662	\N	\N	55.962598999999997	Московская область, Истринский муниципальный район, сельское поселение Ядроминское, п. Курсаково, Здание Администрации с. поселения Ядроминское, 1	Россия, Московская область, Истринский район, поселок Курсаково	0101000020E61000000E9F7422C1484240C614AC7136FB4B40
58199	1	10	204	62008	\N	\N	55.868462426355897	Московская область, Истринский муниципальный район, сельское поселение Лучинское, п. Котово, здание Клуба	Россия, Московская область, Истринский район, деревня Котово	0101000020E6100000446E861BF0614240CDE847C329EF4B40
94525	1	10	204	10871	71968	\N	55.8939764245617	Московская область, Истринский муниципальный район, сельское поселение Костровское, д. Кострово, ул.Центральная, д.17, здание Дома Культуры	Россия, Московская область, Истринский район, деревня Кострово	0101000020E6100000FE99417C6059424057B439CE6DF24B40
57685	1	10	204	48961	71816	\N	55.930388000000001	село Кашино, Ленина, 94		0101000020E61000006F0ED76A0F754240A14B38F416F74B40
58172	1	10	204	9201	\N	\N	55.935505999999997	Московская область, Истринский муниципальный район, городское поселение Истра, Здание Клуба войсковой части		0101000020E6100000923F1878EE5B42401B9B1DA9BEF74B40
58169	1	10	204	9201	2657	\N	55.924092999999999	Московская область, Истринский муниципальный район, городское поселение Истра, Кирова, здание Истринской средней школы №3, 61	Россия, Московская область, Истринский район, Истра, улица Кирова, 61	0101000020E6100000E3FDB8FDF26F424034BBEEAD48F64B40
94514	1	10	204	9201	80099	\N	55.905714000000003	Московская область, Истринский муниципальный район, городское поселение Истра, ул.Юбилейная, д.11а, помещение МОУ "Сред. школа №2"		0101000020E61000003B53E8BCC66E4240C2C3B46FEEF34B40
94515	1	10	204	9201	16873	\N	55.920935999999998	Московская область, Истринский муниципальный район, г.Истра, ул.Советская, д.10а, помещение МОУ "Сред.общеобр.школа им.Чехова"	Россия, Московская область, Истринский район, Истра, Советская улица, 10а/1	0101000020E6100000C18F6AD8EF6D4240C2DA183BE1F54B40
94510	1	10	204	9201	80398	\N	55.916607999999997	Московская область, Истринский муниципальный район, г.Истра, ул.Первомайская, д.3, помещение ДК		0101000020E6100000B6847CD0B36D424040A0336953F54B40
94512	1	10	204	9201	80154	\N	55.908414	Московская область, Истринский муниципальный район, г.Истра, ул.Ленина, д.12, помещение Центра досуга "Мир"		0101000020E610000025034015376E4240419DF2E846F44B40
58186	1	10	204	9201	80874	\N	55.915633999999997	Московская область, Истринский муниципальный район, городское поселение Снегири, Кирова, здание Снегиревской средней школы (фойе), 10а		0101000020E61000003735D07CCE6F4240868DB27E33F54B40
94513	1	10	204	9201	80162	\N	55.911144	Московская область, Истринский муниципальный район, городское поселение Истра, ул.Босова, д.17а, помещение МОУ Лицей г.Истра		0101000020E6100000B91798158A6E42402BF9D85DA0F44B40
58167	1	10	204	9201	74209	\N	55.911960999999998	Московская область, Истринский муниципальный район, городское поселение Истра, 9 Гвардейской дивизии, Здание Истринской гор. библиотеки, 49	Россия, Московская область, Истринский район, Истра, улица 9 Гвардейской Дивизии, 49	0101000020E6100000193A7650896F42401D1D5723BBF44B40
58208	1	10	204	11320	\N	\N	56.006723000000001	Московская область, Истринский муниципальный район, сельское поселение Новопетровское, д. Деньково, здание Дома культуры, 80		0101000020E6100000E50B5A48C02C4240C5909C4CDC004C40
58182	1	10	204	875	\N	\N	55.860229600493902	"Московская область, Истринский муниципальный район, городское поселение Дедовск, Здание Клуба АО ""Сокол"""	Россия, Московская область, Истринский район, Дедовск, улица Гагарина, 14	0101000020E61000005BE9B5D9588F4240E08442041CEE4B40
58171	1	10	204	875	2688	\N	55.872804000000002	Московская область, Истринский муниципальный район, городское поселение Истра, Панфилова, здание ГУП НИИЭМ	Россия, Московская область, Истринский район, Дедовск, улица Панфилова, 1	0101000020E6100000E1D231E7198D4240B4E89D0AB8EF4B40
58178	1	10	204	875	2723	\N	55.861353000000001	Московская область, Истринский муниципальный район, городское поселение Дедовск, Гагарина, здание Дедовской средней школы, 6	Россия, Московская область, Истринский район, Дедовск, улица Гагарина, 6	0101000020E61000008AC91B60E68F4240DFA7AAD040EE4B40
57975	1	10	204	875	224	\N	55.868606999999997	Московская область, городской округ Дубна, 9 Мая, 3	Россия, Московская область, Истринский район, Дедовск, улица 9 Мая, 3	0101000020E6100000BFF2203D458E4240D009A1832EEF4B40
94519	1	10	204	875	80167	\N	55.868485999999997	Московская область, Истринский муниципальный район, г.Дедовск, ул.Энергетиков д.15, помещение МОУ Лицей г.Дедовска		0101000020E610000013286211C38C424055849B8C2AEF4B40
58180	1	10	204	875	80054	\N	55.865551000000004	Московская область, Истринский муниципальный район, городское поселение Дедовск, Победы, здание Детской общеобразовательной школы, 2		0101000020E61000006B7EFCA5458F424093020B60CAEE4B40
58179	1	10	204	875	80054	\N	55.865551000000004	Московская область, Истринский муниципальный район, городское поселение Дедовск, Победы, здание Дедовской общеобр. школы, 2		0101000020E61000006B7EFCA5458F424093020B60CAEE4B40
94518	1	10	204	875	80286	\N	55.870429999999999	Московская область, Истринский муниципальный район, г.Дедовск, ул.Осипенко, д.1а, помещение МОУ "Дедовская сред.общеобр.школа №3		0101000020E61000005760C8EA5691424088BA0F406AEF4B40
94516	1	10	204	875	80434	\N	55.855325000000001	Московская область, Истринский муниципальный район, г.Дедовск, ул.Ленина, д.4, помещение МОУ "Дедовс кая ср.общеоб.школа №4" вход с ул.Ленина		0101000020E610000036751E15FF8F4240C139234A7BED4B40
58176	1	10	204	875	79884	\N	55.859773940297799	Московская область, Истринский муниципальный район, городское поселение Дедовск, Гагарина, здание филиала Московского Гос.соц. университета, 16	Россия, Московская область, Истринский район, Дедовск, улица Гагарина, 16	0101000020E6100000ED28CE51478F4240BEF90D130DEE4B40
58173	1	10	204	875	79884	\N	55.861732000000003	Московская область, Истринский муниципальный район, городское поселение Дедовск, Гагарина, здание Дедовской средней школы №1(2 этаж), 6		0101000020E610000018D00B772E90424056F5F23B4DEE4B40
94522	1	10	204	49687	\N	\N	55.938994999999998	Московская область, Истринский муниципальный район, п.Глебовский, ул.Гагарина, д.31, помещение Администрации сельского поселения Букаревское	Россия, Московская область, Истринский район, поселок Глебовский	0101000020E610000014200A664C594240C30DF8FC30F84B40
94521	1	10	204	49687	\N	\N	55.938994999999998	Московская область, Истринский муниципальный район, п.Глебовский, д.21а, помещение МОУ "Глебовская сред.общеобр.школа"	Россия, Московская область, Истринский район, поселок Глебовский	0101000020E610000014200A664C594240C30DF8FC30F84B40
94520	1	10	204	49687	71895	\N	55.938994999999998	Московская область, Истринский муниципальный район, п.Глебовский, ул.Октябрьская, д.58а, помещение Дома культуры		0101000020E610000014200A664C594240C30DF8FC30F84B40
57763	1	10	204	59516	\N	\N	55.972358340873598	городской округ Восход, Здание администрации, 12	Россия, Московская область, Истринский район, поселок городского типа Восход	0101000020E6100000CD91955F063B42408200193A76FC4B40
58189	1	10	204	10359	\N	\N	55.984223999999998	Московская область, Истринский муниципальный район, сельское поселение Бужаровское, Здание Клуба Гидроузла имени Куйбышева	Россия, Московская область, Истринский район, деревня Бужарово	0101000020E6100000785F950B956542401AF8510DFBFD4B40
58188	1	10	204	10359	\N	\N	55.984223999999998	Московская область, Истринский муниципальный район, сельское поселение Бужаровское, д. Бужарово, Здание Дома культуры	Россия, Московская область, Истринский район, деревня Бужарово	0101000020E6100000785F950B956542401AF8510DFBFD4B40
58195	1	10	204	10701	\N	\N	55.922648099202597	Московская область, Истринский муниципальный район, сельское поселение Ермолинское, п. Агрогородок, здание Дома культуры, 23		0101000020E6100000F9A3A833F77A424023DC645419F64B40
58137	1	10	886	62021	80918	\N	54.776035999999998	"пос.""Центральная усадьба совхоза ""40 лет Октября"", ул.Садовая, Здание Октябрьской средней школы"		0101000020E61000000A4CA7751B5243406342CC2555634B40
58128	1	10	886	7540	\N	\N	54.734372999999998	с.Чулки-Соколово, Здание МУК Чулковский сельский Дом культуры		0101000020E6100000DEC9A7C7B66A43405F0839EFFF5D4B40
58136	1	10	886	7860	\N	\N	54.825208000000003	с.Протекино, Здание Протекинского сельского Дома культуры		0101000020E6100000DA5548F949654340E4326E6AA0694B40
58000	1	10	81	98	80089	\N	55.374589999999998	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул.Советская, дом 193		0101000020E610000003098A1F638643404EB4AB90F2AF4B40
58132	1	10	886	62026	\N	\N	54.821647141836898	д.Новоселки, Здание МОУ Новоселковская начальная школа-детский сад	Россия, Московская область, Зарайский район, деревня Новоселки	0101000020E6100000C5E2378595744340A2ED98BA2B694B40
58135	1	10	886	7845	\N	\N	54.776097999999998	д.Мендюкино, Здание Администрации сельского поселения Машоновское, д.10	Россия, Московская область, Зарайский район, деревня Мендюкино	0101000020E6100000AE9D2809896C4340D93EE42D57634B40
58134	1	10	886	7787	\N	\N	54.777697000000003	п.Масловский, Здание МОУ Масловская средняя общеобразовательная школа	Россия, Московская область, Зарайский район, поселок Масловский	0101000020E6100000BA2D910BCE8A4340429946938B634B40
58127	1	10	886	48652	71818	\N	54.669592000000002	д.Макеево, ул.Центральная, д.15		0101000020E61000001283C0CAA18F4340E5D4CE30B5554B40
58126	1	10	886	7420	81042	\N	54.700387999999997	д.Летуново, ул.Центральная, (здание Летуновского СДК), д.14		0101000020E610000065A88AA9F481434063416150A6594B40
58125	1	10	886	7412	\N	\N	54.689501999999997	"п.Зарайский, здание СДК ц/о АО ""Зарайское"", д.1"		0101000020E6100000AB24B20FB28043406743FE9941584B40
58121	1	10	886	6754	\N	\N	54.764344999999999	г.Зарайск, Микрорайон-2, Здание МОУ лицей № 5	Россия, Московская область, Зарайский район, Зарайск, 2-й микрорайон	0101000020E610000014AE47E17A72434039EE940ED6614B40
58113	1	10	886	6754	\N	\N	54.783933123180098	г.Зарайск, поселок Текстильщиков, д.30	Россия, Московская область, Зарайский район, Зарайск	0101000020E6100000C7D45DD905734340A9A0A2EA57644B40
58120	1	10	886	6754	74095	\N	54.771315000000001	г.Зарайск, ул.Школьная, д.3	Россия, Московская область, Зарайский район, Зарайск, Московская улица	0101000020E61000004ED53DB2B970434006F52D73BA624B40
58115	1	10	886	6754	74105	\N	54.777241934522401	г.Зарайск, ул. Рабочая Слободка, Здание МОУ ДЮСШ	Россия, Московская область, Зарайский район, Зарайск	0101000020E6100000E065868DB2724340F08975AA7C634B40
57925	1	10	886	6754	79903	\N	54.751970386536101	г.Зарайск, ул. Пионерская, д.22	Россия, Московская область, Зарайский район, Зарайск, квартал Южный, Пионерская улица, 20	0101000020E6100000E010AAD4EC7143405CC98E8D40604B40
58118	1	10	886	6754	74173	\N	54.761243999999998	г.Зарайск, ул. Красноармейская, д.51		0101000020E6100000EB1B98DC287043405B23827170614B40
58116	1	10	886	6754	74173	\N	54.761636631087001	г.Зарайск, ул.Красноармейская, д.31	Россия, Московская область, Зарайский район, Зарайск, Красноармейская улица	0101000020E610000033198EE73370434037363B527D614B40
58117	1	10	886	6754	74237	\N	54.759160689380501	г.Зарайск, ул. Карла Маркса, д.36	Россия, Московская область, Зарайский район, Зарайск, улица Карла Маркса	0101000020E6100000700A2B155470434007B309302C614B40
58119	1	10	886	6754	72194	\N	54.757664289856102	г.Зарайск, ул.Дим.Благоева, д.40	Россия, Московская область, Зарайский район, Зарайск, улица Благоева, 40	0101000020E610000040BE840A0E714340A3AD4A22FB604B40
58122	1	10	886	6754	80135	\N	54.764541999999999	г.Зарайск, Микрорайон-2, д.35		0101000020E6100000FBCC599F727243408F352383DC614B40
58130	1	10	886	7608	\N	\N	54.673220999999998	"д.Журавна, Здание Журавенского участка МУП ""ЕСКХ Зарайского района"", д.64"		0101000020E6100000B4E55C8AAB4A43407EFD101B2C564B40
58133	1	10	886	7730	\N	\N	54.757311000000001	д.Ерново, Здание МОУ Ерновская средняя общеобразовательная школа		0101000020E610000078D503E62181434056F31C91EF604B40
58131	1	10	886	7664	\N	\N	54.764035648271602	д.Гололобово, д.64	Россия, Московская область, Зарайский район, деревня Гололобово	0101000020E610000003ECA35357764340BB7B80EECB614B40
58129	1	10	886	48679	80810	\N	54.652786999999996	д.Алферьево, Микрорайон, д.8А		0101000020E61000003D7C992842604340812040868E534B40
55576	1	10	886	11493	\N	\N	54.670613000000003	д.Авдеево, Здание Авдеевского СДК, д.22		0101000020E610000065726A6798704340E0A293A5D6554B40
58033	1	10	81	2535	\N	\N	55.317281999999999	Московская область, Егорьевский муниципальный район, дер.Юрцово, ул. Новая, дом 208	Россия, Московская область, Егорьевский район, деревня Юрцово	0101000020E610000018EB1B98DC98434003CE52B29CA84B40
58023	1	10	81	60225	74066	\N	55.468561000000001	Московская область, Егорьевский муниципальный район, пос.Шувое, ул. Ленинская, дом 159		0101000020E6100000C422861DC68A43402D978DCEF9BB4B40
94504	1	10	81	1879	\N	\N	55.377009999999999	Егорьевский район, дер.Челохово, д.1, кв.11		0101000020E6100000FA27B85851754340EA211ADD41B04B40
58041	1	10	81	2982	\N	\N	55.167724	Московская область, Егорьевский муниципальный район, дер.Старое, учебный корпус ГПЛ-96		0101000020E6100000DA1CE736E19A43408D60E3FA77954B40
59977	1	10	81	391	560	\N	55.398777640020597	Московская область, городской округ Химки, Молодежная, 20	Россия, Московская область, Егорьевский район, деревня Селиваниха, улица Юбилейная, 20	0101000020E61000007A008BFCFA894340A12E52280BB34B40
58027	1	10	81	391	80586	\N	55.398809	Московская область, Егорьевский муниципальный район, дер.Селиваниха, ул.Юбилейная, дом 16		0101000020E6100000AE9FFEB3E6894340DC2C5E2C0CB34B40
58028	1	10	81	2238	\N	\N	55.429986999999997	Егорьевский район, село Саввино, Восточный микрорайн (школа им.Калабалина), д.8а		0101000020E61000003C4A253CA1994340425A63D009B74B40
58045	1	10	81	61902	79957	\N	55.133056000000003	Московская область, Егорьевский муниципальный район, раб.пос.Рязановский, ул. Ленина, дом 2		0101000020E61000008D463EAF78C64340AF44A0FA07914B40
58040	1	10	81	2933	\N	\N	55.171334000000002	Московская область, Егорьевский муниципальный район, село Раменки, ул. Новая, дом 24	Россия, Московская область, Егорьевский район, село Раменки	0101000020E6100000B11A4B581B934340B058C345EE954B40
58046	1	10	81	3283	\N	\N	55.097084000000002	Московская область, Егорьевский муниципальный район, село Радовицы, ул. Советская, дом 33		0101000020E6100000CEC29E76F8C34340817B9E3F6D8C4B40
57995	1	10	81	98	80569	\N	55.376759	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Рязанская, дом 9		0101000020E61000008BF9B9A129854340A1BC8FA339B04B40
58035	1	10	81	2635	\N	\N	55.267954000000003	Московская область, Егорьевский муниципальный район, село Починки, ул. Молодежная, дом 4	Россия, Московская область, Егорьевский район, деревня Починки	0101000020E610000080290307B4B843408C6A11514CA24B40
58043	1	10	81	3078	\N	\N	55.175997000000002	Московская область, Егорьевский муниципальный район, дер.Поповская, дом 66	Россия, Московская область, Егорьевский район, деревня Поповская	0101000020E6100000BBB54C86E3A34340D998D71187964B40
58036	1	10	81	2718	80805	\N	55.259217	Московская область, Егорьевский муниципальный район, дер.Полбино, ул. Молодежная, дом 9		0101000020E61000007B6649809AA643409BC8CC052EA14B40
58021	1	10	81	59564	\N	\N	55.410016018832103	Московская область, Егорьевский муниципальный район, пос Новый, дом 52	Россия, Московская область, Егорьевский район, деревня Новый	0101000020E6100000378C82E0F17F43401A6B7F677BB44B40
58042	1	10	81	3070	\N	\N	55.156471000000003	Московская область, Егорьевский муниципальный район, село Никиткино, дом 255		0101000020E61000004C3448C153A84340DFE2E13D07944B40
58038	1	10	81	2829	72000	\N	55.294089	Московская область, Егорьевский муниципальный район, дер.Михали, ул. Гагарина, дом 6		0101000020E6100000C959D8D30E8B4340828E56B5A4A54B40
58044	1	10	81	3187	\N	\N	55.197656000000002	Московская область, Егорьевский муниципальный район, село Лелечи, дом 44		0101000020E6100000FA7C941117AE4340D9EDB3CA4C994B40
58024	1	10	81	2038	\N	\N	55.441085999999999	Московская область, Егорьевский муниципальный район, дер.Костылево, дом 1В		0101000020E610000002D71533C28943409A5C8C8175B84B40
58039	1	10	81	2894	80804	\N	55.228670000000001	Московская область, Егорьевский муниципальный район, дер.Колычево, ул. З.Самсоновой, дом 36		0101000020E610000006A051BAF4854340C5C9FD0E459D4B40
58031	1	10	81	2400	80934	\N	55.391599999999997	Московская область, Егорьевский муниципальный район, дер. Клеменово, ул. Фабричная, дом 2		0101000020E6100000CF656A12BC9343408A8EE4F21FB24B40
94505	1	10	81	2500	\N	\N	55.377782000000003	Московская область, Егорьевский муниципальный район, Егорьевский район, дер.Иваново (Иншинская школа), д.62		0101000020E61000007B4FE5B4A79C43403D821B295BB04B40
58026	1	10	81	2142	\N	\N	55.338855652670802	Московская область, Егорьевский муниципальный район, дер.Захарово, дом 1Д	Россия, Московская область, Егорьевский район, деревня Захарово	0101000020E6100000E738B709F7884340D50627A25FAB4B40
58013	1	10	81	98	\N	\N	55.366773000000002	Московская область, Егорьевский муниципальный район, г.Егорьевск, 3-й микрорайон, дом 30	Россия, Московская область, Егорьевский район, Егорьевск, 3-й микрорайон, 30	0101000020E610000062BEBC00FB8643402507EC6AF2AE4B40
58012	1	10	81	98	\N	\N	55.366829000000003	Московская область, Егорьевский муниципальный район, г.Егорьевск, 2-й микрорайон, дом 45	Россия, Московская область, Егорьевский район, Егорьевск, 2-й микрорайон, 45	0101000020E6100000D7BD158909884340B91CAF40F4AE4B40
58011	1	10	81	98	\N	\N	55.36927	Московская область, Егорьевский муниципальный район, г.Егорьевск, 2-й микрорайон, дом 25	Россия, Московская область, Егорьевский район, Егорьевск, 2-й микрорайон, 25	0101000020E610000004FF5BC98E8743406CB2463D44AF4B40
58005	1	10	81	98	\N	\N	55.373823000000002	Московская область, Егорьевский муниципальный район, г.Егорьевск, 1-й микрорайон, дом 61	Россия, Московская область, Егорьевский район, Егорьевск, 1-й микрорайон, 61	0101000020E61000005C7347FFCB8743400EBF9B6ED9AF4B40
58003	1	10	81	98	\N	\N	55.3797	Московская область, Егорьевский муниципальный район, г.Егорьевск, 6-й микрорайон, дом 14А	Россия, Московская область, Егорьевский район, Егорьевск, 6-й микрорайон, 14а	0101000020E61000005B40683D7C874340462575029AB04B40
58002	1	10	81	98	\N	\N	55.378539000000004	Московская область, Егорьевский муниципальный район, г.Егорьевск, 6-й микрорайон, дом 9А	Россия, Московская область, Егорьевский район, Егорьевск, 6-й микрорайон, 9а	0101000020E61000005A0D897B2C8743405AA148F773B04B40
94500	1	10	81	98	58	\N	55.383569141556599	г.Егорьевск, ул.П.Коммуны (гимназия №10), д.14/91	Россия, Московская область, Егорьевский район, Егорьевск, улица Парижской Коммуны, 14	0101000020E61000001211FE45D08443403561FBC918B14B40
57615	1	10	81	98	4071	\N	55.384441000000002	Московская область, городской округ Балашиха, Крупской, 4	Россия, Московская область, Егорьевский район, Егорьевск, улица Крупской, 4	0101000020E6100000202A8D98D9814340EB1ED95C35B14B40
60228	1	10	81	98	3762	\N	55.382354999999997	Московская область, городской округ Электросталь, Карла Маркса, 44	Россия, Московская область, Егорьевский район, Егорьевск, улица Карла Маркса, 44	0101000020E6100000F817416326854340253B3602F1B04B40
58010	1	10	81	98	318	\N	55.370860999999998	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Горького, дом 13	Россия, Московская область, Егорьевский район, Егорьевск, улица Горького, 13	0101000020E6100000BAF94674CF864340512E8D5F78AF4B40
57996	1	10	81	98	95	\N	55.379465000000003	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. 9 Января, дом 69	Россия, Московская область, Егорьевский район, Егорьевск, улица 9 Января, 69	0101000020E610000081EA1F4432864340037D224F92B04B40
58004	1	10	81	98	223	\N	55.373393	Московская область, Егорьевский муниципальный район, г.Егорьевск, проспект Ленина, дом 3	Россия, Московская область, Егорьевский район, Егорьевск, проспект Ленина, 3	0101000020E610000030134548DD86434015C78157CBAF4B40
57988	1	10	81	98	80888	\N	55.383991000000002	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул.Профсоюзная, дом 24		0101000020E6100000F46BEBA7FF824340AB7AF99D26B14B40
57990	1	10	81	98	80570	\N	55.38147	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Парижской Коммуны, дом 1Б		0101000020E6100000C7D6338463844340DB334B02D4B04B40
57993	1	10	81	98	80062	\N	55.392214000000003	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Нечаевская, дом 24/59		0101000020E61000009885764EB384434045847F1134B24B40
58016	1	10	81	98	80809	\N	55.367996540401698	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Кассимовское шоссе, дом 4	Россия, Московская область, Егорьевский район, Егорьевск, Касимовское шоссе, 4	0101000020E6100000213D450E11894340580394861AAF4B40
57992	1	10	81	98	80568	\N	55.389499000000001	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Владимирская, дом 2		0101000020E610000037A968ACFD83434090696D1ADBB14B40
57991	1	10	81	98	80568	\N	55.391579999999998	Московская область, Егорьевский муниципальный район, г.Егорьевск, ул. Владимирская, дом 15А		0101000020E610000069FE98D6A683434043E21E4B1FB24B40
94499	1	10	81	98	80104	\N	55.389473886304202	г.Егорьевск, ул.50 лет ВЛКСМ (ДК "Факел"), д. 3А,	Россия, Московская область, Егорьевский район, Егорьевск, улица 50 лет ВЛКСМ, 5	0101000020E6100000691A14CD038043403752B648DAB14B40
58015	1	10	81	98	80584	\N	55.365847000000002	Московская область, Егорьевский муниципальный район, г.Егорьевск, 4-й микрорайон, дом 22		0101000020E6100000AB59677C5F8843407C2B1213D4AE4B40
58014	1	10	81	98	80611	\N	55.366773000000002	Московская область, Егорьевский муниципальный район, г.Егорьевск, 3-й микрорайон, 30		0101000020E610000062BEBC00FB8643402507EC6AF2AE4B40
58009	1	10	81	98	79931	\N	55.374270766521498	Московская область, Егорьевский муниципальный район, 1-й микрорайон, дом 67	Россия, Московская область, Егорьевский район, Егорьевск, 1-й микрорайон, 65	0101000020E610000089601C5C3A884340AD6BB41CE8AF4B40
58037	1	10	81	2734	\N	\N	55.268825	Московская область, Егорьевский муниципальный район, дер.Дмитровка, Дом Культуры		0101000020E610000067463F1A4EA1434071AC8BDB68A24B40
59276	1	10	81	48632	\N	\N	55.418747000000003	д. Данилово, д.65		0101000020E610000029417FA14788434029266F8099B54B40
58029	1	10	81	2292	80800	\N	55.432321000000002	Московская область, Егорьевский муниципальный район, дер.Верейка, ул. Советская, дом 12		0101000020E6100000AD342905DDA64340E02F664B56B74B40
58030	1	10	81	2389	\N	\N	55.432004999999997	Московская область, Егорьевский муниципальный район, дер.Большое Гридино, дом 203		0101000020E6100000575BB1BFECB44340AF5A99F04BB74B40
58025	1	10	81	2050	\N	\N	55.361955460378198	Московская область, Егорьевский муниципальный район, дер.Бережки, дом 76	Россия, Московская область, Егорьевский район, деревня Бережки, Касимовское шоссе, 70	0101000020E61000003D9E961FB88C4340D5CF9B8A54AE4B40
58047	1	10	81	3336	80962	\N	55.166007	Московская область, Егорьевский муниципальный район, дер.Алферово, ул. Горького, дом 79		0101000020E610000013D55B035BBD43401BF4A5B73F954B40
57851	1	10	749	59565	\N	\N	56.059099972529602	Московская область, Дмитровский муниципальный район, сельское поселение Габовское, Останкинская школа	Россия, Московская область, Дмитровский район, поселок совхоза Останкино	0101000020E6100000E2C8039145B44240C898BB9690074C40
57868	1	10	749	62060	81034	\N	56.379272902039297	Московская область, Дмитровский муниципальный район, сельское поселение Якотское, ул.Транспортная, Буденновский СДК		0101000020E61000001A16A3AEB5CF4240BEA085048C304C40
57853	1	10	749	59558	\N	\N	56.191758085788798	Московская область, Дмитровский муниципальный район, сельское поселение Габовское, Дом Офицеров Флота	Россия, Московская область, Дмитровский район, поселок дома отдыха "Горки"	0101000020E610000090DB2F9FACAC4240895FB1868B184C40
57812	1	10	749	58955	\N	\N	56.361424	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, п. Горшково, ДК п. Горшково		0101000020E61000003126FDBD14BE4240A8FE4124432E4C40
57794	1	10	749	59515	71813	\N	56.263002	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Подъячево, помещение МОУ ДОД СДЮШОР ""Динамо-Дмитров"", д. 60"	Россия, Московская область, Дмитровский район, деревня Подъячево	0101000020E6100000FCFB8C0B07A042402C64AE0CAA214C40
57828	1	10	749	24478	\N	\N	56.293616999999998	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, средняя школа №3	Россия, Московская область, Дмитровский район, Яхрома	0101000020E6100000CAA8328CBBBD42405A46EA3D95254C40
57823	1	10	749	24478	\N	\N	56.285063999999998	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, мкр. Левобережье, школа №1, д.17	Россия, Московская область, Дмитровский район, Яхрома, микрорайон Левобережье	0101000020E61000009DBD33DAAABE42402BA226FA7C244C40
57804	1	10	749	24478	\N	\N	56.281857971498603	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, спортивно-развлекательный парк ""Яхрома"""	Россия, Московская область, Дмитровский район, Яхрома, микрорайон Левобережье	0101000020E6100000904DF2237EBF4240D80E46EC13244C40
57809	1	10	749	59504	\N	\N	56.203947374199302	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, пос. Подосинки, ДК пос. Подосинки		0101000020E61000000F0BB5A679C74240048F6FEF1A1A4C40
57819	1	10	749	24478	6418	\N	56.293879973728401	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул. Кирьянова, помещение изостудии, д.32	Россия, Московская область, Дмитровский район, Яхрома, улица Кирьянова, 32	0101000020E610000016F9F5436CBC424068791EDC9D254C40
57827	1	10	749	24478	80872	\N	56.280596000000003	"Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул. Ленина, здание проход. ЗАО""Яхромский автобусный завод"", д.42"	Россия, Московская область, Дмитровский район, Яхрома, микрорайон Левобережье, улица Ленина, 42	0101000020E610000000A8E2C62DBE4240B8B1D991EA234C40
57822	1	10	749	24478	74148	\N	56.285407999999997	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул.Конярова, красный уголок ЯТМК, 9	Россия, Московская область, Дмитровский район, Яхрома, улица Конярова, 9	0101000020E6100000C05DF6EB4EBD42402502D53F88244C40
57821	1	10	749	24478	74148	\N	56.288138151587098	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул. Конярова, Вечерняя школа, д.31	Россия, Московская область, Дмитровский район, Яхрома, улица Конярова	0101000020E6100000750305DEC9BD42400F5EBBB4E1244C40
57818	1	10	749	24478	80847	\N	56.292073000000002	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул. Кирьянова, школа № 2, 12	Россия, Московская область, Дмитровский район, Яхрома, улица Кирьянова, 12	0101000020E610000054C6BFCFB8BC4240B685E7A562254C40
57820	1	10	749	24478	74227	\N	56.290654017017701	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул.Заречная, ДК г.Яхромы, 2		0101000020E61000007AE2395B40BE4240CE39782634254C40
57825	1	10	749	24478	74187	\N	56.2791460584003	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, г. Яхрома, ул. Большевистская, Яхромская техшкола, д.16	Россия, Московская область, Дмитровский район, Яхрома, Большевистская улица, 16	0101000020E6100000EA9788B7CEBD424094675E0EBB234C40
57870	1	10	749	26798	\N	\N	56.399546999999998	Московская область, Дмитровский муниципальный район, сельское поселение Якотское, административное здание ВНИИПРХ	Россия, Московская область, Дмитровский район, село Якоть	0101000020E61000004E469561DCDB4240821B295B24334C40
57869	1	10	749	26798	\N	\N	56.399546999999998	Московская область, Дмитровский муниципальный район, сельское поселение Якотское, с. Якоть, Якотский СДК		0101000020E61000004E469561DCDB4240821B295B24334C40
57811	1	10	749	61991	\N	\N	56.238859057457901	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, д.Целеево, администрация Кузяевского территориального отдела,	Россия, Московская область, Дмитровский район, деревня Целеево	0101000020E6100000815F234910C0424079AD84EE921E4C40
59719	1	10	749	20896	\N	\N	56.348835999999999	д.Тютьково, 14б		0101000020E610000002B9C491079C42406FD575A8A62C4C40
57815	1	10	749	62038	\N	\N	56.394210999999999	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, дер.Татищево, клуб дер.Татищево	Россия, Московская область, Дмитровский район, деревня Татищево	0101000020E61000000DA5F622DAC042409A5C8C8175324C40
57847	1	10	749	60240	74104	\N	56.388737808576202	Московская область, Дмитровский муниципальный район, сельское поселение Синьковское, мкр. Дуброво, дом 2, кв. 76	Россия, Московская область, Дмитровский район, деревня Синьково	0101000020E6100000651A4D2EC6A64240315BB22AC2314C40
57849	1	10	749	25929	\N	\N	56.323033000000002	Московская область, Дмитровский муниципальный район, сельское поселение Синьковское, с. Семеновское, Молодежный Центр с. Семеновское		0101000020E610000012D9075916904240AF43352559294C40
57857	1	10	749	26148	\N	\N	56.431356000000001	"Московская область, Дмитровский муниципальный район, сельское поселение Большерогачевское, с. Рогачево, ул. Мира, здание Спорткомплекса ""Рогачево"""	Россия, Московская область, Дмитровский район, село Рогачево	0101000020E61000007A7077D66E954240797764AC36374C40
57855	1	10	749	26148	80792	\N	56.431356000000001	Московская область, Дмитровский муниципальный район, сельское поселение Большерогачевское, с. Рогачево, пл. Осипова, здание Дома Культуры	Россия, Московская область, Дмитровский район, село Рогачево	0101000020E61000007A7077D66E954240797764AC36374C40
57856	1	10	749	26148	80947	\N	56.431356000000001	Московская область, Дмитровский муниципальный район, сельское поселение Большерогачевское, с. Рогачево, ул. Ракетчиков, здание магазина	Россия, Московская область, Дмитровский район, село Рогачево	0101000020E61000007A7077D66E954240797764AC36374C40
59207	1	10	749	27717	80952	\N	56.088558999999997	Московская область, Орехово-Зуевский муниципальный район, п. Приозерье, 2-й проезд строителей, 2		0101000020E61000005BD2510E66AF42401B62BCE6550B4C40
57858	1	10	749	26301	\N	\N	56.412298	Московская область, Дмитровский муниципальный район, сельское поселение Большерогачевское, с. Покровское, ДК с. Покровское		0101000020E610000035D1E7A38C864240651A4D2EC6344C40
57830	1	10	749	25036	\N	\N	56.263002	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, с. Подъячево, школа с. Подъячево		0101000020E6100000FCFB8C0B07A042402C64AE0CAA214C40
57814	1	10	749	59588	72212	\N	56.435257999999997	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, с. Орудьево, ул.Фабричная, Орудьевская средняя школа	Россия, Московская область, Дмитровский район, село Орудьево	0101000020E61000005B9A5B21ACC2424043A9BD88B6374C40
57817	1	10	749	61993	\N	\N	56.431674000000001	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, пос.Орево, ДК пос.Орево	Россия, Московская область, Дмитровский район, поселок Орево	0101000020E61000001366DAFE95BB42404A44F81741374C40
57867	1	10	749	26715	37284	\N	56.503866000000002	Московская область, Дмитровский муниципальный район, сельское поселение Якотское, с. Ольявидово, ул. Центральная, Дом культуры		0101000020E6100000CA6ABA9EE8E042407EC85BAE7E404C40
57831	1	10	749	25042	\N	\N	56.270260999999998	Московская область, Дмитровский муниципальный район, городское поселение Яхрома, с. Ольгово, библиотека с. Ольгово		0101000020E6100000381268B0A9AB42402F3196E997224C40
57845	1	10	749	25636	\N	\N	56.379930000000002	Московская область, Дмитровский муниципальный район, сельское поселение Синьковское, п. Новосиньково, здание Яхромского аграрного колледжа,	Россия, Московская область, Дмитровский район, поселок Новосиньково	0101000020E61000005B0C1EA67DA942407862D68BA1304C40
57844	1	10	749	25636	\N	\N	56.379930000000002	Московская область, Дмитровский муниципальный район, сельское поселение Синьковское, пос. Новосиньково, ДК пос. Новосиньково		0101000020E61000005B0C1EA67DA942407862D68BA1304C40
57843	1	10	749	25636	\N	\N	56.375762382248404	Московская область, Дмитровский муниципальный район, сельское поселение Синьковское, п. Новосиньково, Синьковская школа №2	Россия, Московская область, Дмитровский район, поселок Новосиньково	0101000020E61000007CB4386398A942402F8A1EF818304C40
57864	1	10	749	26605	\N	\N	56.196596999999997	Московская область, Дмитровский муниципальный район, сельское поселение Костинское, п. Новое Гришино, Гришинская средняя общеобразовательная школа		0101000020E6100000B9A981E673D24240F0BE2A172A194C40
58237	1	10	749	46306	80818	\N	56.229942000000001	д.Никулино, ул.Новая, д.12		0101000020E610000029417FA147DA424009FD4CBD6E1D4C40
57839	1	10	749	25396	\N	\N	56.084173999999997	"Московская область, Дмитровский муниципальный район, городское поселение Некрасовский, пос. Некрасовский, ул. Заводская, ДК ""Керамик"""	Россия, Московская область, Дмитровский район, поселок городского типа Некрасовский	0101000020E61000007730629F00C042403596B036C60A4C40
57841	1	10	749	25396	80808	\N	56.084173999999997	"Московская область, Дмитровский муниципальный район, городское поселение Некрасовский, п. Некрасовский, мкр. Строителей, ДК ""Строитель"""		0101000020E61000007730629F00C042403596B036C60A4C40
57840	1	10	749	25396	72271	\N	56.084173999999997	Московская область, Дмитровский муниципальный район, городское поселение Некрасовский, п. Некрасовский, ул. Ушакова, помещение Некрасовской поликлиники, д.20		0101000020E61000007730629F00C042403596B036C60A4C40
57842	1	10	749	25396	37280	\N	56.084173999999997	Московская область, Дмитровский муниципальный район, городское поселение Некрасовский, п. Некрасовский, Городок -1 , Дом офицеров		0101000020E61000007730629F00C042403596B036C60A4C40
57838	1	10	749	60239	74103	\N	56.084173999999997	Московская область, Дмитровский муниципальный район, городское поселение Некрасовский, п. Некрасовский, ул. Краснофлотская, д.10		0101000020E61000007730629F00C042403596B036C60A4C40
57813	1	10	749	62017	\N	\N	56.350940802588802	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, д.Настасьино, ФАП д.Настасьино	Россия, Московская область, Дмитровский район, деревня Настасьино	0101000020E6100000BAA46ABB09BA4240ABE97AA2EB2C4C40
57859	1	10	749	26334	80816	\N	56.483055	Московская область, Дмитровский муниципальный район, сельское поселение Куликовское, д. Насадкино, здание администрации, 9		0101000020E61000007B4FE5B4A7AC4240AB9509BFD43D4C40
57807	1	10	749	61990	\N	\N	56.335470000000001	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, дер. Митькино, КДЦ ""Романтик"","	Россия, Московская область, Дмитровский район, деревня Митькино	0101000020E61000002BA226FA7CC84240026553AEF02A4C40
57863	1	10	749	26556	\N	\N	56.466763	Московская область, Дмитровский муниципальный район, сельское поселение Куликовское, пос. Мельчевка, ДК пос. Мельчевка		0101000020E6100000637E6E68CAB24240CEFDD5E3BE3B4C40
57862	1	10	749	26471	\N	\N	56.457695999999999	Московская область, Дмитровский муниципальный район, сельское поселение Куликовское, пос. Луговой, Клуб пос. Луговой		0101000020E6100000CF9F36AAD39D424048C153C8953A4C40
57860	1	10	749	26392	\N	\N	56.645777000000002	Московская область, Дмитровский муниципальный район, сельское поселение Куликовское, п. Липино, административное здание больницы, 14		0101000020E61000003FAC376A8591424027C11BD2A8524C40
57866	1	10	749	26699	\N	\N	56.305779000000001	Московская область, Дмитровский муниципальный район, сельское поселение Костинское, с. Костино, СДК с. Костино		0101000020E61000006D01A1F5F0DB4240DC662AC423274C40
57816	1	10	749	61997	\N	\N	56.4702815002139	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, д. Княжево, здание СДК д. Княжево	Россия, Московская область, Дмитровский район, деревня Княжево	0101000020E6100000B9DE365321C04240E0F25833323C4C40
57852	1	10	749	62003	\N	\N	56.179313202553899	Московская область, Дмитровский муниципальный район, сельское поселение Габовское, д. Каменка, школа N 1 д. Каменка	Россия, Московская область, Дмитровский район, деревня Каменка	0101000020E6100000E94482A966A64240B35F77BAF3164C40
58238	1	10	749	62003	80902	\N	56.178908432748202	д.Каменка, ул.Центральная, д.8	Россия, Московская область, Дмитровский район, деревня Каменка	0101000020E6100000BE839F3880A64240137F1475E6164C40
57808	1	10	749	62029	\N	\N	56.274514000000003	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, с. Ильинское, Центр активного отдыха X-LAND - здание боулинга	Россия, Московская область, Дмитровский район, село Ильинское	0101000020E61000008692C9A99DCB4240A725564623234C40
57837	1	10	749	25306	71935	\N	56.173997999999997	Московская область, Дмитровский муниципальный район, городское поселение Икша, пос. Икша, ул. Комсомольская, Дом культуры		0101000020E61000008BE07F2BD9BF4240E2C8039145164C40
57810	1	10	749	62023	80925	\N	56.202862000000003	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, д.Дубровки, ул.Триумфальная, казарма №1	Россия, Московская область, Дмитровский район, деревня Дубровки	0101000020E61000008A93FB1D8ACA4240F3CCCB61F7194C40
57789	1	10	749	15109	\N	\N	56.348695999999997	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр Маркова, школа 9	Россия, Московская область, Дмитровский район, Дмитров, микрорайон имени А.М. Маркова	0101000020E6100000BD361B2B31C342407D1F0E12A22C4C40
57786	1	10	749	15109	\N	\N	56.352037283533903	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр. Аверьянова, школа №10		0101000020E6100000AD84EE9238C34240B1FD648C0F2D4C40
57784	1	10	749	15109	\N	\N	56.356681999999999	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр. Махалина, средняя школа № 4	Россия, Московская область, Дмитровский район, Дмитров, микрорайон Махалина	0101000020E6100000AA7CCF4884C4424033897AC1A72D4C40
57781	1	10	749	15109	\N	\N	56.3574574181728	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, Внуковская школа	Россия, Московская область, Дмитровский район, Дмитров, микрорайон Внуковский, 20	0101000020E610000041F33977BBC84240F65CA626C12D4C40
57779	1	10	749	15109	\N	\N	56.366346	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр.ДЗФС, средняя школа № 3	Россия, Московская область, Дмитровский район, Дмитров, микрорайон ДЗФС	0101000020E61000007C0E2C47C8C442409D82FC6CE42E4C40
57778	1	10	749	15109	\N	\N	56.368453160099698	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр. ДЗФС, средняя школа №3	Россия, Московская область, Дмитровский район, Дмитров, микрорайон ДЗФС, 24	0101000020E610000090831266DAC442407A8EC877292F4C40
57777	1	10	749	15109	\N	\N	56.366346	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, пос. ДЗФС, Дом культуры ""Содружество"""	Россия, Московская область, Дмитровский район, Дмитров, микрорайон ДЗФС	0101000020E61000007C0E2C47C8C442409D82FC6CE42E4C40
57785	1	10	749	15109	74045	\N	56.352100297648398	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр. Аверьянова, школа № 10		0101000020E6100000E4F90CA837C34240F775E09C112D4C40
57799	1	10	749	15109	74223	\N	56.338818000000003	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Школьная, средняя школа №1, д.11		0101000020E6100000467D923B6CC24240E8A562635E2B4C40
57798	1	10	749	15109	74223	\N	56.337983269464402	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул.Школьная, начальная школа №5, д.14	Россия, Московская область, Дмитровский район, Дмитров, Школьная улица, 14	0101000020E6100000BF4868CBB9C242404FCDE506432B4C40
94488	1	10	749	15109	74186	\N	56.354396999999999	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Профессиональная, Центр детского творчества, 21		0101000020E61000005BCD3AE3FBC24240776682E15C2D4C40
57796	1	10	749	15109	74140	\N	56.340958999999998	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Почтовая, городская библиотека	Россия, Московская область, Дмитровский район, Дмитров, Почтовая улица	0101000020E610000006BD378600C242407023658BA42B4C40
57790	1	10	749	15109	72262	\N	56.349673015212602	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, мкр. Маркова, школа № 9	Россия, Московская область, Дмитровский район, Дмитров, улица Маркова, 6	0101000020E610000071AAB5300BC34240A9A5B915C22C4C40
57802	1	10	749	15109	74150	\N	56.339256102488797	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Космонавтов, средняя школа №8	Россия, Московская область, Дмитровский район, Дмитров, улица Космонавтов, 11	0101000020E61000002D7B12D89CC54240637C98BD6C2B4C40
57680	1	10	584	4726	80151	\N	56.027805999999998	город Волоколамск, Школьная, 12		0101000020E6100000F3AE7AC03CFA4140F850A2258F034C40
57801	1	10	749	15109	74150	\N	56.338209999999997	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Космонавтов, Политехнический колледж, 33		0101000020E6100000B613252191C642400F971C774A2B4C40
57793	1	10	749	15109	74216	\N	56.339477000000002	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Комсомольская, средняя школа № 2	Россия, Московская область, Дмитровский район, Дмитров, Комсомольская улица	0101000020E6100000118DEE2076C44240425F7AFB732B4C40
57792	1	10	749	15109	74211	\N	56.338160000000002	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул.Инженерная, гимназия ""Дмитров"", 24а"	Россия, Московская область, Дмитровский район, Дмитров, Инженерная улица, 24а	0101000020E61000004696CCB1BCC342405E68AED3482B4C40
57905	1	10	749	15109	6157	\N	56.342061999999999	Московская область, городской округ Долгопрудный, Загорская, 30	Россия, Московская область, Дмитровский район, Дмитров, Загорская улица, 30	0101000020E6100000081D740987C24240289A07B0C82B4C40
57791	1	10	749	15109	74137	\N	56.342279166080502	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул.Загорская, Дворец Культуры, 64	Россия, Московская область, Дмитровский район, Дмитров, Загорская улица	0101000020E6100000C6A86BED7DC24240C58D5BCCCF2B4C40
57797	1	10	749	15109	74141	\N	56.335598385162598	Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Волгостроевская, школа № 7, 2а	Россия, Московская область, Дмитровский район, Дмитров, Волгостроевская улица, 3	0101000020E6100000C634D3BD4EC242402F4D11E0F42A4C40
57780	1	10	749	15109	74124	\N	56.355116000000002	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул.Внуковская, здание  ООО ""Дмитров - Кабель"", строение 40"		0101000020E6100000E90E62670AC74240A724EB70742D4C40
57803	1	10	749	15109	74156	\N	56.331304000000003	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул.Веретенникова, помещение красного уголка АО ""СМПК-73"", д.13а"		0101000020E61000008A3F8A3A73C142405A84622B682A4C40
57800	1	10	749	15109	6251	\N	56.343204	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, г. Дмитров, ул. Большевистская, ДК ""Современник"", 14"		0101000020E61000009A9658198DC442409EEDD11BEE2B4C40
57836	1	10	749	25110	\N	\N	56.243434999999998	Московская область, Дмитровский муниципальный район, городское поселение Деденево, п. Деденево, Горнолыжный клуб Л.Тягачева		0101000020E6100000C61858C7F1C14240D3D9C9E0281F4C40
57835	1	10	749	25110	\N	\N	56.243434999999998	Московская область, Дмитровский муниципальный район, городское поселение Деденево, п. Деденево, общеобразовательная средняя школа	Россия, Московская область, Дмитровский район, поселок городского типа Деденево	0101000020E6100000C61858C7F1C14240D3D9C9E0281F4C40
57834	1	10	749	25110	71934	\N	56.243434999999998	Московская область, Дмитровский муниципальный район, городское поселение Деденево, п. Деденево, ул. Советская, здание ФОКа		0101000020E6100000C61858C7F1C14240D3D9C9E0281F4C40
57832	1	10	749	25110	72266	\N	56.243434999999998	Московская область, Дмитровский муниципальный район, городское поселение Деденево, п. Деденево, ул.Заречная, здание детского сада № 42	Россия, Московская область, Дмитровский район, поселок городского типа Деденево	0101000020E6100000C61858C7F1C14240D3D9C9E0281F4C40
57833	1	10	749	60214	\N	\N	56.243434999999998	"Московская область, Дмитровский муниципальный район, городское поселение Деденево, п. Деденево, клуб ""Комсомольский"""		0101000020E6100000C61858C7F1C14240D3D9C9E0281F4C40
57865	1	10	749	62032	\N	\N	56.217194999999997	Московская область, Дмитровский муниципальный район, сельское поселение Костинское, д. Гришино, помещение администрации, д. Гришино, д.95	Россия, Московская область, Дмитровский район, деревня Гришино	0101000020E61000006A183E22A6D4424067EDB60BCD1B4C40
57854	1	10	749	26133	\N	\N	56.209980999999999	Московская область, Дмитровский муниципальный район, сельское поселение Габовское, пос.Горки -25, Каменская средняя школа №2		0101000020E6100000B1FCF9B660CB424004E44BA8E01A4C40
57806	1	10	749	61995	\N	\N	56.363258290391698	"Московская область, Дмитровский муниципальный район, городское поселение Дмитров, с.Внуково, здание Внуковского территориального отдела, д.60 ""А"""		0101000020E610000063EC8497E0CA42405401F73C7F2E4C40
57850	1	10	749	25946	\N	\N	56.403502000000003	Московская область, Дмитровский муниципальный район, сельское поселение Синьковское, д. Бунятино, СДК д. Бунятино	Россия, Московская область, Дмитровский район, деревня Бунятино	0101000020E6100000C382FB010FA0424070EF1AF4A5334C40
57829	1	10	749	24986	\N	\N	56.305334000000002	"Московская область, Дмитровский муниципальный район, городское поселение Яхрома, д. Астрецово, ОАО ""Гамма"""		0101000020E6100000478E740646B64240AE2D3C2F15274C40
57846	1	10	749	25780	\N	\N	56.349170000000001	"Московская область, Дмитровский муниципальный район, сельское поселение Синьковское, пос. Автополигон, клуб ""Испытатель"""		0101000020E610000018080264E8A84240465F419AB12C4C40
57674	1	10	584	4726	74162	\N	56.054380749270599	город Волоколамск, Тихая, 4	Россия, Московская область, Волоколамский район, Волоколамск, Тихая улица	0101000020E6100000D34CF73AA9F741400B43E4F4F5064C40
57759	1	10	1242	61896	79915	\N	55.4920039909954	Московская область, Воскресенский муниципальный район, городское поселение им. Цюрупы, Зайцева, 22	Россия, Московская область, Воскресенский район, поселок городского типа имени Цюрупы	0101000020E6100000BFD18E1B7E53434027C0B0FCF9BE4B40
57755	1	10	1242	60266	74193	\N	55.493627088009902	Московская область, Воскресенский муниципальный район, городское поселение им. Цурюпы, Октябрьская, 75	Россия, Московская область, Воскресенский район, поселок городского типа имени Цюрупы	0101000020E6100000DFDFA0BDFA52434017B6662B2FBF4B40
94484	1	10	1242	59174	71773	\N	55.497558636934698	Московская область, Воскресенский муниципальный район, городское поселение им. Цюрупы, Новомалинная, 5-а/МОУ СОШ № 13		0101000020E610000096ED43DE725543404D6A6803B0BF4B40
57704	1	10	1242	18806	71861	\N	55.354982999999997	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, д. Чемодурово, Центральная, 12		0101000020E610000097CADB114E55434067D13B1570AD4B40
57760	1	10	1242	61891	80518	\N	55.328260141342597	Московская область, Воскресенский муниципальный район, городское поселение Хорлово, Советская, 4	Россия, Московская область, Воскресенский район, поселок городского типа Хорлово	0101000020E61000004B2025766D714340E04A766C04AA4B40
57758	1	10	1242	61891	79889	\N	55.335366	Московская область, Воскресенский муниципальный район, городское поселение Хорлово, Зайцева, 22	Россия, Московская область, Воскресенский район, поселок городского типа Хорлово	0101000020E61000006364C91CCB7143405D18E945EDAA4B40
57747	1	10	1242	21135	\N	\N	55.307581825276202	Московская область, Воскресенский муниципальный район, сельское поселение Фединское, с. Федино, здание школы	Россия, Московская область, Воскресенский район, село Федино	0101000020E61000005E4C33DDEB4E43404C6BD3D85EA74B40
57754	1	10	1242	21477	\N	\N	55.248119000000003	Московская область, Воскресенский муниципальный район, сельское поселение Фединское, д. Степанщино, Центральная, 26	Россия, Московская область, Воскресенский район, деревня Степанщино	0101000020E610000062D9CC21A94343401442075DC29F4B40
57736	1	10	1242	20557	\N	\N	55.392828000000002	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, д. Старая, сельский клуб		0101000020E61000008CF7E3F6CB574340FF791A3048B24B40
57753	1	10	1242	21425	67060	\N	55.272226000000003	Московская область, Воскресенский муниципальный район, сельское поселение Фединское, д. Ратчино, Некрасова, 11А		0101000020E610000075560BEC315343407A8F334DD8A24B40
57749	1	10	1242	21234	\N	\N	55.279780000000002	Московская область, Воскресенский муниципальный район, сельское поселение Фединское, с. Невское, здание фельдшерско-акушерского пункта		0101000020E6100000EA245B5D4E4543409609BFD4CFA34B40
57699	1	10	1242	18554	\N	\N	55.348992677971097	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, д. Маришкино, 1А	Россия, Московская область, Воскресенский район, деревня Маришкино	0101000020E61000003BA92F4B3B4F434037C478CDABAC4B40
59598	1	10	1242	14704	\N	\N	55.439084000000001	д.Лидино, 13		0101000020E6100000AB77B81D1A60434033198EE733B84B40
94483	1	10	1242	21385	\N	\N	55.354793999999998	Московская область, Воскресенский муниципальный район, сельское поселение Фединское, с. Косяково, 73-б/Дом культуры		0101000020E6100000D591239D813F43409468C9E369AD4B40
94480	1	10	1242	15658	80764	\N	55.407131	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, с. Конобеево, Центральня, 123-а/Сельский клуб		0101000020E6100000D80B056C0755434009185DDE1CB44B40
57735	1	10	1242	15658	80764	\N	55.409548000000001	с. Конобеево, ул. Центральная, 123-а/Сельский клуб	Россия, Московская область, Воскресенский район, село Конобеево	0101000020E61000000038F6ECB95443403412A1116CB44B40
57734	1	10	1242	15658	9973	\N	55.407131	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, с. Конобеево, Новые дома, 13А		0101000020E6100000D80B056C0755434009185DDE1CB44B40
94478	1	10	1242	19971	71874	\N	55.430078999999999	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, д. Золотово, Моховая, 1/МОУ Золотовская СОШ		0101000020E6100000C5E3A25A4442434023D923D40CB74B40
57762	1	10	1242	21864	80921	\N	55.313183000000002	Московская область, Воскресенский муниципальный район, городское поселение Хорлово, д. Ёлкино, Советская, 84		0101000020E610000026529ACDE36A4340E3546B6116A84B40
94485	1	10	1242	21603	\N	\N	55.504888999999999	Московская область, Воскресенский муниципальный район, городское поселение им. Цюрупы, д. Дворниково, 71А/Библиотека-филиал № 14 Воскресенской ЦБС		0101000020E6100000EBE1CB4411504340198EE733A0C04B40
94479	1	10	1242	20208	80783	\N	55.454222999999999	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, д. Губино, Лесная, 1-б/Сельский клуб		0101000020E610000045132862114B4340A60BB1FA23BA4B40
57748	1	10	1242	21199	80910	\N	55.346347999999999	Московская область, Воскресенский муниципальный район, сельское поселение Фединское, д. Городище, Мира, 9/1		0101000020E61000003067B62BF44943407B849A2155AC4B40
94474	1	10	1242	12774	16380	\N	55.323756000000003	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Менделеева, 11/МОУ Лицей № 22		0101000020E61000003A1F9E25C854434020F12BD670A94B40
57684	1	10	584	4726	79854	\N	55.992842664933299	город Волоколамск, Терешковой, 18		0101000020E610000058C85C1954F741400188BB7A15FF4B40
57696	1	10	1242	12774	5045	\N	55.316231000000002	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Зелинского, 5Д	Россия, Московская область, Воскресенский район, Воскресенск, улица Зелинского, 5д	0101000020E610000001DD9733DB5343409E7DE5417AA84B40
94476	1	10	1242	12774	16463	\N	55.340342999999997	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Андреса, 1-б/МУ ДК "Юбилейный"	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Лопатинский, улица Андреса	0101000020E610000019E59997C35C43401536035C90AB4B40
94486	1	10	1242	12774	74196	\N	55.323070000000001	Московская область, Воскресенский муниципальный район, городское поселение Хорлово, пл. Ленина, 3/Дом культуры Хорлово		0101000020E6100000A06B5F402F564340CC28965B5AA94B40
57713	1	10	1242	12774	5259	\N	55.297409999999999	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Юбилейная, д.24	Россия, Московская область, Воскресенский район, Воскресенск, Юбилейная улица, 24/1	0101000020E610000082E50819C85D43406EC0E78711A64B40
57714	1	10	1242	12774	80501	\N	55.278764506840702	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Толстого, 1	Россия, Московская область, Воскресенский район, Воскресенск, улица Толстого, 1	0101000020E6100000EA245B5D4E5F43407D224F92AEA34B40
57707	1	10	1242	12774	80472	\N	55.315646999999998	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Советская, 1А		0101000020E61000005648F949B55743404E0AF31E67A84B40
94477	1	10	1242	12774	74182	\N	55.280436000000002	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Рабочая, 105/МОУ ДОД ДШИ № 5		0101000020E6100000728BF9B9A15F43407F4FAC53E5A34B40
57701	1	10	1242	12774	80460	\N	55.32602	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Победы, 25		0101000020E610000054E3A59BC4544340C4EBFA05BBA94B40
57705	1	10	1242	12774	80462	\N	55.320841999999999	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Пионерская, 8		0101000020E61000004225AE635C5743407497C45911A94B40
57706	1	10	1242	12774	15525	\N	55.322839000000002	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Октябрьская, 9	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Центральный, Октябрьская улица, 9	0101000020E61000008333F8FBC5564340CA6FD1C952A94B40
57703	1	10	1242	12774	80474	\N	55.322937000000003	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Октябрьская, 21		0101000020E6100000249D8191975743408DD5E6FF55A94B40
57718	1	10	1242	12774	80884	\N	55.272067	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Некрасова, 17		0101000020E6100000E19A3BFA5F5E434011A96917D3A24B40
57719	1	10	1242	12774	80478	\N	55.269748999999997	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Московская, 23		0101000020E61000000F7C0C569C5E434079909E2287A24B40
57717	1	10	1242	12774	80479	\N	55.270018847755601	г. Воскресенск, ул. Ломоносова, 117/ГОУ НПО ПУ 44	Россия, Московская область, Воскресенский район, Воскресенск, улица Ломоносова	0101000020E6100000D386C3D2C05F434039268BFB8FA24B40
57715	1	10	1242	12774	80479	\N	55.271456999999998	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Ломоносова, 100		0101000020E61000002522FC8BA05F434098A25C1ABFA24B40
57725	1	10	1242	12774	80020	\N	55.245852026098902	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Ленинская, 1А		0101000020E61000001C0A9FAD83614340FED30D14789F4B40
57742	1	10	1242	12774	15433	\N	55.342861999999997	Московская область, Воскресенский муниципальный район, городское поселение Белоозерский, Комсомольская, 1	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Лопатинский, Комсомольская улица, 1	0101000020E6100000423F53AF5B5C43404485EAE6E2AB4B40
94482	1	10	1242	12774	74179	\N	55.313018999999997	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Кагана, 22/здание МОУ "Гимназия № 1" МОУ ДОД ДШИ "Элегия"	Россия, Московская область, Воскресенский район, Воскресенск, улица Кагана, 22	0101000020E610000081053065E05243406803B00111A84B40
94472	1	10	1242	12774	74179	\N	55.313761999999997	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Кагана, 22/МОУ "Гимназия № 1"		0101000020E6100000149337C0CC534340205D6C5A29A84B40
94473	1	10	1242	12774	80485	\N	55.314704999999996	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Зелинского, 5 Д/МОУ СОШ № 3		0101000020E61000004DF6CFD3805343409F71E14048A84B40
57709	1	10	1242	12774	80491	\N	55.328368807602402	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, пер. Зеленый, 3		0101000020E61000003596B036C65643409702D2FE07AA4B40
60216	1	10	1242	12774	16324	\N	55.328831999999998	Московская область, городской округ Щербинка, Железнодорожная, 41	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Центральный, Железнодорожная улица, 41	0101000020E610000037FDD98F145743406BF0BE2A17AA4B40
57673	1	10	584	4726	80447	\N	56.066721000000001	город Волоколамск, Текстильщиков, 15		0101000020E61000009067976F7DF641406C7A50508A084C40
57720	1	10	1242	12774	16491	\N	55.257790999999997	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Гражданская, 29	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Цемгигант, Гражданская улица, 27	0101000020E6100000D9CD8C7E34624340001AA54BFFA04B40
57708	1	10	1242	12774	80473	\N	55.320569999999996	Московская область, Воскресенский муниципальный район, городское поселение Воскресенск, Быковского, 23		0101000020E6100000C0B167CF655A4340130A117008A94B40
57727	1	10	1242	20018	80788	\N	55.426431000000001	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, пос. Виноградово, Коммунистическая, здание школы		0101000020E610000005A8A9656B47434013807F4A95B64B40
57728	1	10	1242	20018	80789	\N	55.426431000000001	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, пос. Виноградово, Зеленая, здание конторы Лесхоза		0101000020E610000005A8A9656B47434013807F4A95B64B40
57745	1	10	1242	59555	79890	\N	55.452671000000002	Московская область, Воскресенский муниципальный район, городское поселение Белоозерский, 60 лет Октября, 18	Россия, Московская область, Воскресенский район, поселок городского типа Белоозерский	0101000020E6100000AE0E80B8AB3943407F6C921FF1B94B40
94481	1	10	1242	59555	71930	\N	55.455952869346397	Московская область, Воскресенский муниципальный район, городское поселение Белоозерский, ул. Молодежная, 34-а/агитцентр		0101000020E61000002D228AC91B384340ADC1FBAA5CBA4B40
57743	1	10	1242	60262	74169	\N	55.460342362086699	Московская область, Воскресенский муниципальный район, городское поселение Белоозерский, Молодежная, 39	Россия, Московская область, Воскресенский район, поселок городского типа Белоозерский	0101000020E6100000F2EEC8586D384340D47C957CECBA4B40
57738	1	10	1242	20692	71873	\N	55.400486000000001	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, с. Барановское, Центральная, 1А		0101000020E6100000116E32AA0C614340C040102043B34B40
57740	1	10	1242	20255	\N	\N	55.429970328643002	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, пос. ст. Берендино, здание станции кабинет начальника станции	Россия, Московская область, Воскресенский район, село Ашитково	0101000020E610000089997D1EA34C43406C21C84109B74B40
57733	1	10	1242	20255	80787	\N	55.432474999999997	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, с. Ашитково, Школьная, 1А		0101000020E6100000070951BEA04B434036AB3E575BB74B40
57732	1	10	1242	20255	80917	\N	55.432474999999997	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, с. Ашитково, Центральная, 57		0101000020E6100000070951BEA04B434036AB3E575BB74B40
57731	1	10	1242	20255	67053	\N	55.432474999999997	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, с. Ашитково, Парковая, 1		0101000020E6100000070951BEA04B434036AB3E575BB74B40
57739	1	10	1242	20255	80806	\N	55.434557931251803	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, с. Усадище, Королькова, 103	Россия, Московская область, Воскресенский район, село Ашитково	0101000020E6100000FD135CACA84D43408B1BB7989FB74B40
57729	1	10	1242	20255	80791	\N	55.432374387640301	Московская область, Воскресенский муниципальный район, сельское поселение Ашитковское, пос. Виноградово, Заводская, 2А		0101000020E61000001C78B5DC994B434003D2FE0758B74B40
57750	1	10	1242	21295	\N	\N	55.257841491039898	Московская область, Воскресенский муниципальный район, сельское поселение Фединское, с. Ачкасово, здание школы, 76		0101000020E6100000B7D3D688605C4340B24813EF00A14B40
54307	1	10	584	13797	\N	\N	56.131641000000002	село Ярополец, микрорайон, 13	Россия, Московская область, Волоколамский район, село Ярополец	0101000020E61000002BA5677A89E9414008E8BE9CD9104C40
57676	1	10	584	48808	80923	\N	56.045040999999998	деревня Ченцы, Советская, 5А		0101000020E610000071E2AB1DC501424054FD4AE7C3054C40
59371	1	10	584	3661	\N	\N	56.000346	д. Федюково, Строителей, стр.1	Россия, Московская область, Волоколамский район, деревня Федюково	0101000020E6100000D76CE525FF2142409B5775560B004C40
57626	1	10	584	47877	80803	\N	56.042864000000002	деревня Тимонино, Парковая, 2		0101000020E610000011548D5E0DEA41407F164B917C054C40
57440	1	10	584	6106	71976	\N	56.171292000000001	село Теряево, Теряевская, 92 А		0101000020E6100000C904FC1A49104240810871E5EC154C40
57690	1	10	584	18088	80735	\N	55.920689000000003	село Спасс, Центральная, 47		0101000020E6100000DD0BCC0A45F44140BB641C23D9F54B40
57688	1	10	584	17990	71864	\N	55.861469	село Осташево, микрорайон, 1		0101000020E6100000446ADAC534ED414048C2BE9D44EE4B40
57573	1	10	584	12447	71937	\N	55.984205259007901	деревня Нелидово, Крестьянская, 18	Россия, Московская область, Волоколамский район, деревня Нелидово	0101000020E6100000C47B0E2C47024240A4C7EF6DFAFD4B40
53948	1	10	584	47920	80796	\N	56.025708000000002	деревня Курьяново, Центральная, 60	Россия, Московская область, Волоколамский район, деревня Курьяново	0101000020E61000000229B16B7BDD41406F9F55664A034C40
57419	1	10	584	5005	74096	\N	55.909095000000001	деревня Клишино, Центральная, 6		0101000020E61000009E961FB8CAEB414083FA96395DF44B40
57687	1	10	584	17961	80941	\N	56.076413000000002	деревня Калистово, Центральная, 21		0101000020E61000006268757286FE4140A0FEB3E6C7094C40
54042	1	10	584	49481	80772	\N	56.066087000000003	село Ильинское, Центральная, 16		0101000020E61000000F0C207C28E141406BD8EF8975084C40
57588	1	10	584	13136	\N	\N	56.013271000000003	деревня Гряды, Микрорайон, 5 А		0101000020E6100000984EEB36A81D42401C7E37DDB2014C40
57672	1	10	584	4726	\N	\N	56.072920654798999	город Волоколамск, Щекино, 57	Россия, Московская область, Волоколамский район, Волоколамск, деревня Щекино	0101000020E610000018D2E1218CF741408718AF7955094C40
57677	1	10	584	4726	4815	\N	56.034897999999998	город Волоколамск, Советская, 11	Россия, Московская область, Волоколамский район, Волоколамск, Советская улица, 11	0101000020E61000005FB35C363AFB41401059A48977044C40
57678	1	10	584	4726	79878	\N	56.034407470127597	город Волоколамск, Советская, 2	Россия, Московская область, Волоколамский район, Волоколамск, Советская улица	0101000020E6100000E54526E0D7FA414072E0D57267044C40
57682	1	10	584	4726	67810	\N	56.020879001289899	город Волоколамск, Пороховская, 3	Россия, Московская область, Волоколамский район, Волоколамск, Прохоровская улица	0101000020E610000033897AC1A7F741402B16BF29AC024C40
59722	1	10	584	4726	5646	\N	56.034419999999997	Московская область, городской округ Серпухов, Пролетарская, 145	Россия, Московская область, Волоколамский район, Волоколамск, Пролетарская улица	0101000020E610000032E6AE25E4F94140062AE3DF67044C40
57679	1	10	584	4726	80239	\N	56.027067000000002	город Волоколамск, Панфилова, 42/3		0101000020E6100000271763601DFB414082E673EE76034C40
57681	1	10	584	4726	4866	\N	56.030521999999998	город Волоколамск, Ново-солдатский переулок, 1	Россия, Московская область, Волоколамский район, Волоколамск, Ново-Солдатский переулок, 1	0101000020E610000093A9825149F941407DE71725E8034C40
57689	1	10	584	18043	80779	\N	55.760767999999999	село Болычево, Новая, 1		0101000020E610000045847F1134DC4140F2EB87D860E14B40
53901	1	9	\N	54699	38986	\N	53.2351729635133	Липецкая область, Чаплыгинский район, г.Чаплыгин, Советская, 74		0101000020E6100000E12879758EFD43407CF31B261A9E4A40
53903	1	9	\N	54699	38990	\N	53.246828875039	Липецкая область, Чаплыгинский район, г.Чаплыгин, пер.Московский, 7	Россия, Липецкая область, Чаплыгинский район, Чаплыгин	0101000020E61000000E87A5811FFB4340295AB917989F4A40
53902	1	9	\N	54699	38868	\N	53.240194000000002	Липецкая область, Чаплыгинский район, г.Чаплыгин, Ленина, 3		0101000020E6100000A88FC01F7EFA434004594FADBE9E4A40
53842	1	9	\N	54735	39049	\N	52.050954907486698	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, Новоселов, 4-а	Россия, Липецкая область, Усманский район, Усмань	0101000020E61000002FC4EA8F30DC4340AA4885B185064A40
53838	1	9	\N	54735	39014	\N	52.049712890829603	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, Шмидта, 15	Россия, Липецкая область, Усманский район, Усмань	0101000020E6100000069E7B0F97DC4340D097DEFE5C064A40
53836	1	9	\N	54735	39002	\N	52.049289540949097	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, Чернышевского, 118	Россия, Липецкая область, Усманский район, Усмань	0101000020E610000054C6BFCFB8DC43408A027D224F064A40
53840	1	9	\N	54735	39003	\N	52.021523316075097	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, Радищева, 50	Россия, Липецкая область, Усманский район, Усмань	0101000020E61000006765FB90B7DC4340508E0244C1024A40
53837	1	9	\N	54735	39003	\N	52.017394417488703	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, Радищева, 122		0101000020E6100000CD069964E4DC4340C59272F739024A40
53867	1	9	\N	54735	38934	\N	52.047041	Липецкая область, Усманский муниципальный район, город Усмань, Первомайская, 1-а		0101000020E61000002F6AF7AB00DD43401B49827005064A40
53841	1	9	\N	54735	39087	\N	52.044117442727703	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, Ленина, 2	Россия, Липецкая область, Усманский район, Усмань	0101000020E61000003E92921E86DE43404C1938A0A5054A40
53839	1	9	\N	54735	39087	\N	52.059420822017998	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, Ленина, 89	Россия, Липецкая область, Усманский район, Усмань	0101000020E6100000CE8AA8893EDD43400AD9791B9B074A40
53763	1	9	\N	19463	38997	\N	52.544505999999998	Липецкая область, Липецкий муниципальный район, сельское поселение Сырский сельсовет, село Подгорное, Центральная, 76а		0101000020E61000003849F3C7B4C04340E63C635FB2454A40
53827	1	9	\N	54758	\N	\N	52.745899000000001	Липецкая область Тербунский района село Бурдино, поселок Молодежный, 8		0101000020E6100000D68C0C72179F43403F8F519E795F4A40
53184	1	9	\N	3727	\N	\N	52.603586999999997	Липецкая область, город Липецк, Липецк-2, гарнизонный Дом офицеров		0101000020E6100000E97E4E417ECC434037A5BC56424D4A40
53152	1	9	\N	3727	\N	\N	52.596684000000003	Липецкая область, город Липецк, 15 микрорайон, 5/2		0101000020E6100000BB5E9A22C0C54340F3052D24604C4A40
53137	1	9	\N	3727	4765	\N	52.584817999999999	Липецкая область, город Липецк, Хорошавина, 9	Россия, Липецкая область, Липецк, улица Хорошавина, 9	0101000020E6100000BE175FB4C7C143405A0EF450DB4A4A40
52400	1	9	\N	3727	4765	\N	52.585529000000001	Липецкая область, город Липецк, Хорошавина, 14	Россия, Липецкая область, Липецк, улица Хорошавина, 14	0101000020E6100000CCD0782288C1434007EE409DF24A4A40
53170	1	9	\N	3727	6064	\N	52.593784999999997	Липецкая область, город Липецк, Фрунзе, 91		0101000020E6100000A33D5E4887CB43407CED9925014C4A40
53154	1	9	\N	3727	5887	\N	52.594217	Липецкая область, город Липецк, Студенческий городок, 10	Россия, Липецкая область, Липецк, улица Студенческий Городок, 10	0101000020E6100000ADFBC74274C6434016DD7A4D0F4C4A40
53139	1	9	\N	3727	5747	\N	52.589091000000003	Липецкая область, город Липецк, Стаханова, 28б	Россия, Липецкая область, Липецк, улица Стаханова, 28б	0101000020E6100000A54FABE80FC3434019AF7955674B4A40
53110	1	9	\N	3727	5388	\N	52.529552000000002	Липецкая область, город Липецк, Писарева Д, 37	Россия, Липецкая область, Липецк, улица Писарева, 37	0101000020E61000004C33DDEBA4E0434005C4245CC8434A40
50074	1	9	\N	3727	3605	\N	52.580730000000003	Липецкая область, город Липецк, Парковая, 5	Россия, Липецкая область, Липецк, улица Парковая, 5	0101000020E61000002E8F352383CE43402EE7525C554A4A40
53162	1	9	\N	3727	5914	\N	52.592855	Липецкая область, город Липецк, Папина, 3а	Россия, Липецкая область, Липецк, улица Папина, 3а	0101000020E610000052D32EA699C64340922232ACE24B4A40
53160	1	9	\N	3727	5914	\N	52.599117999999997	Липецкая область, город Липецк, Папина, 4а	Россия, Липецкая область, Липецк, улица Папина, 4а	0101000020E61000002E008DD2A5C74340F3380CE6AF4C4A40
53815	1	9	\N	3727	5093	\N	52.540815000000002	Липецкая область Тербунский района село Покровское, Молодежная, 49	Россия, Липецкая область, Липецк, улица Молодежная	0101000020E610000046239F573CC94340D717096D39454A40
53803	1	9	\N	3727	5093	\N	52.542206	Липецкая область Тербунский района село Дуброво, Молодежная, 2	Россия, Липецкая область, Липецк, улица Молодежная, 2	0101000020E61000007C65DEAAEBC84340F5D8960167454A40
53231	1	9	\N	3727	15345	\N	52.651187	Липецкая область, город Липецк, Ленина, 42	Россия, Липецкая область, Липецк, село Сселки, улица Ленина, 42	0101000020E610000015562AA8A8DC4340494A7A185A534A40
53199	1	9	\N	3727	15723	\N	52.613447000000001	Липецкая область, город Липецк, ул. Космонавтов, 82/4	Россия, Липецкая область, Липецк, Советский район, улица Космонавтов, 82/4	0101000020E6100000D064FF3C0DC64340276A696E854E4A40
53192	1	9	\N	3727	15723	\N	52.615262000000001	Липецкая область, город Липецк, ул. Космонавтов, 54а	Россия, Липецкая область, Липецк, Советский район, улица Космонавтов, 54а	0101000020E61000004E5FCFD72CC743405C3CBCE7C04E4A40
53188	1	9	\N	3727	15723	\N	52.618220000000001	Липецкая область, город Липецк, ул. Космонавтов, 36/3	Россия, Липецкая область, Липецк, Советский район, улица Космонавтов, 36/3	0101000020E6100000F1F5B52E35C84340D7DD3CD5214F4A40
53127	1	9	\N	3727	4313	\N	52.538843	Липецкая область, город Липецк, Ильича, 18	Россия, Липецкая область, Липецк, улица Ильича, 18	0101000020E61000006C5B94D920CB4340DA56B3CEF8444A40
53132	1	9	\N	3727	38826	\N	52.538659101762697	Липецкая область, город Липецк, Рубена Ибаррури, 1	Россия, Липецкая область, Липецк, улица Ибаррури, 1	0101000020E610000094F6065F98C84340195932C7F2444A40
53172	1	9	\N	3727	6080	\N	52.586257000000003	Липецкая область, город Липецк, 50 лет НЛМК, 19	Россия, Липецкая область, Липецк, улица 50 лет НЛМК, 19	0101000020E610000064CA87A06ACA43408A0629780A4B4A40
53166	1	9	\N	3727	5799	\N	52.594752999999997	Липецкая область, город Липецк, Проспект Победы, 51/1	Россия, Липецкая область, Липецк, проспект Победы, 51/2	0101000020E610000095F0845E7FC843405419C6DD204C4A40
53164	1	9	\N	3727	5799	\N	52.591728000000003	Липецкая область, город Липецк, Проспект Победы, 69а	Россия, Липецкая область, Липецк, проспект Победы, 69а	0101000020E61000009450FA42C8C7434052103CBEBD4B4A40
53161	1	9	\N	3727	5799	\N	52.591782000000002	Липецкая область, город Липецк, пр.Победы, 96	Россия, Липецкая область, Липецк, проспект Победы, 96	0101000020E61000003DB9A64066C74340452E3883BF4B4A40
53146	1	9	\N	3727	5799	\N	52.582574000000001	Липецкая область, город Липецк, пр. Победы, 122	Россия, Липецкая область, Липецк, проспект Победы, 122	0101000020E6100000F5DBD78173C44340FDBFEAC8914A4A40
53145	1	9	\N	3727	5799	\N	52.582574000000001	Липецкая область, город Липецк, пр.Победы, 122	Россия, Липецкая область, Липецк, проспект Победы, 122	0101000020E6100000F5DBD78173C44340FDBFEAC8914A4A40
53144	1	9	\N	3727	5799	\N	52.581856999999999	Липецкая область, город Липецк, пр.Победы, 130	Россия, Липецкая область, Липецк, проспект Победы, 130	0101000020E61000008EAED2DD75C443406EF9484A7A4A4A40
53124	1	9	\N	3727	5494	\N	52.585912	Липецкая область, город Липецк, проспект Мира, 10	Россия, Липецкая область, Липецк, проспект Мира, 10	0101000020E6100000D07F0F5EBBCE4340BF2A172AFF4A4A40
53118	1	9	\N	3727	5494	\N	52.586426000000003	Липецкая область, город Липецк, проспект Мира, 7	Россия, Липецкая область, Липецк, проспект Мира, 7	0101000020E61000004AED45B41DCF434016C3D501104B4A40
53216	1	9	\N	3727	39026	\N	52.575129473777899	Липецкая область, город Липецк, ул. Ударников, 21	Россия, Липецкая область, Липецк, проезд Ударников	0101000020E6100000B709F7CABCBD434097FDBAD39D494A40
53147	1	9	\N	3727	5833	\N	52.587515000000003	Липецкая область, город Липецк, проезд Сиреневый, 9	Россия, Липецкая область, Липецк, проезд Сиреневый, 9	0101000020E61000007C6473D53CC54340697407B1334B4A40
53211	1	9	\N	3727	38957	\N	52.599058256096001	Липецкая область, город Липецк, пр. Сержанта Кувшинова, 5	Россия, Липецкая область, Липецк, проезд Кувшинова, 5	0101000020E6100000179CC1DF2FC243401E34BBEEAD4C4A40
53125	1	9	\N	3727	5569	\N	52.528188	Липецкая область, город Липецк, проезд Ильича, 1	Россия, Липецкая область, Липецк, проезд Ильича, 1	0101000020E6100000D9CF622992CB4340E01115AA9B434A40
53220	1	9	\N	3727	6561	\N	52.629584999999999	Липецкая область, город Липецк, Боевой проезд, 24а	Россия, Липецкая область, Липецк, проезд Боевой, 24а	0101000020E6100000A7B0524145C74340AD86C43D96504A40
53210	1	9	\N	3727	38877	\N	52.603586999999997	Липецкая область, город Липецк, пр. Сержанта Кувшинова, 3		0101000020E6100000E97E4E417ECC434037A5BC56424D4A40
53179	1	9	\N	3727	6160	\N	52.598336000000003	Липецкая область, город Липецк, пл. Торговая, 14а		0101000020E610000054C4E9245BCB43407E022846964C4A40
53116	1	9	\N	3727	5469	\N	52.590519	Липецкая область, город Липецк, площадь Мира, 1		0101000020E6100000A7CF0EB8AECE434054556820964B4A40
53243	1	9	\N	3727	6735	\N	52.638680000000001	Липецкая область, город Липецк, площадь К.С. Константиновой, 3	Россия, Липецкая область, Липецк, площадь Константиновой, 3	0101000020E6100000F3CB608C48D44340FD4D2844C0514A40
53242	1	9	\N	3727	6735	\N	52.638680000000001	Липецкая область, город Липецк, площади К.С. Константиновой, 3	Россия, Липецкая область, Липецк, площадь Константиновой, 3	0101000020E6100000F3CB608C48D44340FD4D2844C0514A40
53113	1	9	\N	3727	39070	\N	52.590234000000002	Липецкая область, город Липецк, Силикатная, 19		0101000020E6100000B69E211CB3D443405F7EA7C98C4B4A40
53237	1	9	\N	3727	6735	\N	52.638024000000001	Липецкая область, город Липецк, площадь К.С. Константиновой, 2	Россия, Липецкая область, Липецк, площадь Константиновой, 2	0101000020E61000008D7BF31B26D4434014083BC5AA514A40
53135	1	9	\N	3727	5688	\N	52.581425000000003	Липецкая область, город Липецк, переулок Учебный, 1	Россия, Липецкая область, Липецк, переулок Учебный, 1	0101000020E6100000DE8FDB2F9FC24340D50968226C4A4A40
53140	1	9	\N	3727	5724	\N	52.589556000000002	Липецкая область, город Липецк, бульвар  Шубина, 7а	Россия, Липецкая область, Липецк, бульвар Шубина, 7	0101000020E61000008D45D3D9C9C243408E942D92764B4A40
53138	1	9	\N	3727	5724	\N	52.590890999999999	Липецкая область, город Липецк, бульвар  Шубина, 15	Россия, Липецкая область, Липецк, бульвар Шубина, 15	0101000020E6100000D06394675EC243401840F850A24B4A40
53142	1	9	\N	3727	5773	\N	52.586267999999997	Липецкая область, город Липецк, бульвар Есенина, 7а	Россия, Липецкая область, Липецк, бульвар Есенина, 7а	0101000020E61000002E8CF4A276C343407D586FD40A4B4A40
53168	1	9	\N	3727	39074	\N	52.59984	Липецкая область, город Липецк, Юных Натуралистов, 12а		0101000020E610000073F1B73D41C84340946A9F8EC74C4A40
53167	1	9	\N	3727	39074	\N	52.599381000000001	Липецкая область, город Липецк, Юных Натуралистов, 12		0101000020E610000081CD397826C84340016C4084B84C4A40
53214	1	9	\N	3727	39080	\N	52.582213000000003	Липецкая область, город Липецк, ул. Юношеская, 23а		0101000020E6100000BF61A2410ABC43402D27A1F4854A4A40
53100	1	9	\N	3727	39037	\N	52.530664000000002	Липецкая область, город Липецк, Энергостроителей, 21		0101000020E6100000EED0B01875E54340109546CCEC434A40
53090	1	9	\N	3727	39037	\N	52.532893999999999	Липецкая область, город Липецк, Энергостроителей, строение 5а		0101000020E610000042D13C8045E64340081EDFDE35444A40
53829	1	9	\N	3727	39253	\N	52.595075999999999	Липецкая область Тербунский района село Тульское, Школьная, 3		0101000020E61000007A37161406CB434037514B732B4C4A40
53805	1	9	\N	3727	39253	\N	52.595512999999997	Липецкая область Тербунский района село Казинка, Школьная, 8		0101000020E61000008D0A9C6C03CB4340E2AB1DC5394C4A40
53136	1	9	\N	3727	39019	\N	52.581669330524399	Липецкая область, город Липецк, Шерстобитова, 8	Россия, Липецкая область, Липецк, улица Шерстобитова	0101000020E61000004985B18520C143406B0C3A21744A4A40
53195	1	9	\N	3727	39052	\N	52.608449	Липецкая область, город Липецк, ул. Циолковского, 34/4		0101000020E610000067B5C01E13C94340572426A8E14D4A40
53194	1	9	\N	3727	39052	\N	52.611215999999999	Липецкая область, город Липецк, ул. Циолковского, 31		0101000020E61000003F6F2A5261C843405E656D533C4E4A40
53808	1	9	\N	3727	39261	\N	52.529820999999998	Липецкая область Тербунский района село Марьино-Николаевка, Центральная, 19		0101000020E6100000AED3484BE5DF4340F4DDAD2CD1434A40
53807	1	9	\N	3727	39261	\N	52.530427482042299	Липецкая область Тербунский района деревня Никольское, Центральная, 52		0101000020E61000007F2F8507CDDE43402CF52C08E5434A40
53804	1	9	\N	3727	39261	\N	52.534395000000004	Липецкая область Тербунский района село Заречное, Центральная, 26		0101000020E6100000A4E2FF8EA8DE4340AE122C0E67444A40
53802	1	9	\N	3727	39261	\N	52.534395000000004	Липецкая область Тербунский района село Вислая Поляна, Центральная, 20		0101000020E6100000A4E2FF8EA8DE4340AE122C0E67444A40
53800	1	9	\N	3727	39261	\N	52.529820999999998	Липецкая область Тербунский района село Борки, Центральная, 19		0101000020E6100000AED3484BE5DF4340F4DDAD2CD1434A40
53798	1	9	\N	3727	39261	\N	52.531689	Липецкая область Тербунский района деревня Ивановка, Центральная, 12		0101000020E6100000A9D903ADC0DE43404C5299620E444A40
53115	1	9	\N	3727	39264	\N	52.595661	Липецкая область, город Липецк, Фурманова, 27		0101000020E6100000E1D4079277D043405740A19E3E4C4A40
53206	1	9	\N	3727	39053	\N	52.603237	Липецкая область, город Липецк, ул. Филипченко, 8/1		0101000020E6100000168733BF9AC543405B5EB9DE364D4A40
53204	1	9	\N	3727	39053	\N	52.606211999999999	Липецкая область, город Липецк, ул. Филипченко, 7/4		0101000020E6100000C8B3CBB73EC64340AC38D55A984D4A40
53240	1	9	\N	3727	39056	\N	52.642111999999997	Липецкая область, город Липецк, Ушинского, 14		0101000020E6100000D7DAFB5415D44340402FDCB930524A40
53239	1	9	\N	3727	39056	\N	52.644078999999998	Липецкая область, город Липецк, Ушинского, 19		0101000020E61000004E2B85402ED343402B85402E71524A40
53238	1	9	\N	3727	39056	\N	52.637548000000002	Липецкая область, город Липецк, Ушинского, 5		0101000020E6100000A181583673D44340ABD0402C9B514A40
53215	1	9	\N	3727	39081	\N	52.577091000000003	Липецкая область, город Липецк, ул. Ударников, 13		0101000020E6100000CE39782634BD434071E82D1EDE494A40
53156	1	9	\N	3727	39011	\N	52.5945588790456	Липецкая область, город Липецк, Студенческий городок, 2	Россия, Липецкая область, Липецк, улица Папина, 2	0101000020E6100000B8CB7EDDE9C643406F4562821A4C4A40
53153	1	9	\N	3727	39011	\N	52.595233656977797	Липецкая область, город Липецк, Студенческий городок, 24	Россия, Липецкая область, Липецк, улица Студенческий Городок	0101000020E6100000EFC7ED974FC64340CFBBB1A0304C4A40
53158	1	9	\N	3727	39073	\N	52.595239999999997	Липецкая область, город Липецк, Студенческий городок, 1		0101000020E61000006022DE3AFFC64340B1A206D3304C4A40
53232	1	9	\N	3727	39062	\N	52.617919000000001	Липецкая область, город Липецк, Студеновская, 4а		0101000020E61000003A57941282CF4340DC4944F8174F4A40
53151	1	9	\N	3727	39033	\N	52.595014999999997	Липецкая область, город Липецк, Стаханова, 6		0101000020E6100000F99FFCDD3BC4434091D09673294C4A40
53150	1	9	\N	3727	39033	\N	52.592171	Липецкая область, город Липецк, Стаханова, 17		0101000020E610000080828B1535C44340DF516342CC4B4A40
53149	1	9	\N	3727	39033	\N	52.592466000000002	Липецкая область, город Липецк, Стаханова, 15		0101000020E61000004128EFE368C44340F8FE06EDD54B4A40
53141	1	9	\N	3727	39033	\N	52.586480999999999	Липецкая область, город Липецк, Стаханова, 39а		0101000020E61000008C683BA6EEC24340D95C35CF114B4A40
53823	1	9	\N	3727	39531	\N	52.625731999999999	Липецкая область Тербунский района село Малые Борки, Совхозная, 9		0101000020E610000015191D9084C74340C40776FC17504A40
53825	1	9	\N	3727	39064	\N	52.660778999999998	Липецкая область Тербунский района село Вторые Тербуны, Советская, 35		0101000020E610000088D860E124DD43401971016894544A40
53217	1	9	\N	3727	39142	\N	52.695314341609901	Липецкая область, город Липецк, Северный рудник, 27	Россия, Липецкая область, Липецкий район, поселок Северная шахта	0101000020E6100000AF09698D41B74340B939950C00594A40
53246	1	9	\N	3727	38998	\N	52.663776627320402	Липецкая область, город Липецк, с. Ссёлки, Ракитная, 2	Россия, Липецкая область, Липецк, улица Ракитная	0101000020E610000006D9B27C5DDE4340236B0DA5F6544A40
53123	1	9	\N	3727	39086	\N	52.577983000000003	Липецкая область, город Липецк, Прокатная, 10		0101000020E61000006F0C01C0B1CF43406E52D158FB494A40
53112	1	9	\N	3727	39071	\N	52.561841999999999	Липецкая область, город Липецк, Пришкольная, 21		0101000020E610000086AB0320EEDC434076C24B70EA474A40
53111	1	9	\N	3727	39000	\N	52.549341824588502	Липецкая область, город Липецк, Привокзальная, 101	Россия, Липецкая область, Липецк, улица Привокзальная, 76	0101000020E610000064AC36FFAFDE4340DD28B2D650464A40
53799	1	9	\N	3727	39255	\N	52.579658000000002	Липецкая область Тербунский района село Большая Поляна, Почтовая, 56		0101000020E6100000EF1B5F7B66BD4340B16EBC3B324A4A40
53212	1	9	\N	3727	39040	\N	52.607545999999999	Липецкая область, город Липецк, ул. Политехническая, 9а		0101000020E610000000E65AB400C1434066683C11C44D4A40
50994	1	9	\N	3727	39066	\N	52.577736999999999	Липецкая область, город Липецк, Осипенко, 18		0101000020E6100000126BF12900CE434036583849F3494A40
50194	1	9	\N	3727	39066	\N	52.578480999999996	Липецкая область, город Липецк, Осипенко, 12		0101000020E61000005E4D9EB29ACE4340BE2D58AA0B4A4A40
53226	1	9	\N	3727	39084	\N	52.615628000000001	Липецкая область, город Липецк, Плеханова, 51а		0101000020E610000012A27C410BCD43403E40F7E5CC4E4A40
53180	1	9	\N	3727	39061	\N	52.601629000000003	Липецкая область, город Липецк, ул. Первомайская, 59		0101000020E61000003929CC7B9CCB4340A0A9D72D024D4A40
53177	1	9	\N	3727	39061	\N	52.603225999999999	Липецкая область, город Липецк, ул. Первомайская, 58		0101000020E6100000A988D349B6CA4340670C7382364D4A40
53159	1	9	\N	3727	39047	\N	52.598303000000001	Липецкая область, город Липецк, Папина, 4		0101000020E610000022FB20CB82C74340A20C5531954C4A40
53155	1	9	\N	3727	39047	\N	52.593642000000003	Липецкая область, город Липецк, Папина, 3		0101000020E61000004B051555BFC643401AC40776FC4B4A40
53178	1	9	\N	3727	39025	\N	52.6016380147558	Липецкая область, город Липецк, ул. Октябрьская, 88а	Россия, Липецкая область, Липецк, Октябрьская улица	0101000020E610000018CFA0A17FCA4340F3035779024D4A40
53218	1	9	\N	3727	39254	\N	52.632337478920597	Липецкая область, город Липецк, Одоевского, 10	Россия, Липецкая область, Липецк, улица Одоевского	0101000020E6100000B937BF61A2C143407F86376BF0504A40
53120	1	9	\N	3727	39090	\N	52.58137	Липецкая область, город Липецк, Невского, 2		0101000020E61000002A711DE38ACF4340117008556A4A4A40
53200	1	9	\N	3727	39077	\N	52.610363	Липецкая область, город Липецк, ул. Московская, 51а		0101000020E61000003596B036C6C443401FD8F15F204E4A40
53108	1	9	\N	3727	39044	\N	52.529432	Липецкая область, город Липецк, Моршанская, 10		0101000020E61000005EBC1FB75FE643405ABA826DC4434A40
53817	1	9	\N	3727	39519	\N	52.542079999999999	Липецкая область Тербунский района деревня Петровское, Молодежная, 3		0101000020E610000045F6419605C9434068E89FE062454A40
53813	1	9	\N	3727	39519	\N	52.542544999999997	Липецкая область Тербунский района село Озерки, Молодежная, 5		0101000020E6100000FE7DC68503C94340DDCD531D72454A40
53811	1	9	\N	3727	39519	\N	52.541203000000003	Липецкая область Тербунский района село Новосильское, Молодежная, 8		0101000020E61000004AED45B41DC94340A1BFD02346454A40
53821	1	9	\N	3727	39036	\N	52.597712000000001	Липецкая область Тербунский района село Тербуны, Мичурина, 26 б		0101000020E6100000D673D2FBC6C94340A036AAD3814C4A40
53169	1	9	\N	3727	39036	\N	52.598117000000002	Липецкая область, город Липецк, Им. Мичурина, 30		0101000020E6100000A5828AAA5FC9434040170D198F4C4A40
53157	1	9	\N	3727	39036	\N	52.596606999999999	Липецкая область, город Липецк, Им. Мичурина, 22		0101000020E61000007A6EA12B11CA434047C8409E5D4C4A40
53163	1	9	\N	3727	39072	\N	52.583689999999997	Липецкая область, город Липецк, Механизаторов, 21		0101000020E61000009B374E0AF3C8434049809A5AB64A4A40
53134	1	9	\N	3727	39072	\N	52.585856999999997	Липецкая область, город Липецк, Механизаторов, 10		0101000020E6100000D3FA5B02F0C74340FB90B75CFD4A4A40
53148	1	9	\N	3727	39057	\N	52.587722999999997	Липецкая область, город Липецк, Меркулова, 11а		0101000020E610000061C3D32B65C54340B20DDC813A4B4A40
53176	1	9	\N	3727	39048	\N	52.602229999999999	Липецкая область, город Липецк, ул. М. Горького, 10		0101000020E6100000A4C4AEEDEDCA4340C55565DF154D4A40
53831	1	9	\N	3727	39525	\N	52.607261999999999	Липецкая область Тербунский района село  Хутор-Березовка, Луговая, 29		0101000020E610000050AA7D3A1EC54340410DDFC2BA4D4A40
53174	1	9	\N	3727	38942	\N	52.603586999999997	Липецкая область, город Липецк, ул. Л. Толстого, д.23а		0101000020E6100000E97E4E417ECC434037A5BC56424D4A40
53133	1	9	\N	3727	39022	\N	52.542756750570398	Липецкая область, город Липецк, Краснознаменная, 4	Россия, Липецкая область, Липецк, улица Краснознаменная	0101000020E61000006D73637AC2C843406956B60F79454A40
53131	1	9	\N	3727	39058	\N	52.541839000000003	Липецкая область, город Липецк, Краснозаводская, 8		0101000020E6100000C710001C7BCA43404359F8FA5A454A40
53248	1	9	\N	3727	39259	\N	52.705293498320003	Липецкая область, город Липецк, с. Ж Пески, Космонавтов, 1	Россия, Липецкая область, Липецк, деревня Желтые Пески, улица Космонавтов, 1	0101000020E6100000FD6A0E10CCDB4340828C800A475A4A40
53203	1	9	\N	3727	39051	\N	52.610931000000001	Липецкая область, город Липецк, ул. Космонавтов, 90		0101000020E61000004B3CA06CCAC54340698EACFC324E4A40
53202	1	9	\N	3727	39051	\N	52.605687000000003	Липецкая область, город Липецк, ул. Космонавтов, 108		0101000020E6100000A60EF27A30C54340624ED026874D4A40
53193	1	9	\N	3727	39051	\N	52.614353999999999	Липецкая область, город Липецк, ул. Космонавтов, 11б		0101000020E6100000541F48DE39C843405915E126A34E4A40
53186	1	9	\N	3727	39051	\N	52.619024000000003	Липецкая область, город Липецк, ул. Космонавтов, 16а		0101000020E61000005E10919A76C9434035B8AD2D3C4F4A40
53130	1	9	\N	3727	39091	\N	52.541521000000003	Липецкая область, город Липецк, Коммунистическая, 17		0101000020E610000065C405A051CA4340728C648F50454A40
53128	1	9	\N	3727	39091	\N	52.540118999999997	Липецкая область, город Липецк, Коммунистическая, 20		0101000020E61000004CE3175E49CA43405F79909E22454A40
53225	1	9	\N	3727	39020	\N	52.616284	Липецкая область, город Липецк, Интернациональная, 53а		0101000020E610000000750305DECD43402786E464E24E4A40
53181	1	9	\N	3727	39020	\N	52.609909075035901	Липецкая область, город Липецк, ул. Интернациональная, 5а	Россия, Липецкая область, Липецк, улица Зегеля, 5б	0101000020E6100000B267CF656ACC43409E44847F114E4A40
51045	1	9	\N	3727	39094	\N	52.535725999999997	Липецкая область, город Липецк, Ильича, 31		0101000020E610000047E867EA75CB4340F6CE68AB92444A40
53224	1	9	\N	3727	38846	\N	52.606615004801597	Липецкая область, город Липецк, И.В. Шкатова, 25	Россия, Липецкая область, Липецк, улица 8 Марта, 21	0101000020E61000008CD7BCAAB3CA4340AB21718FA54D4A40
53114	1	9	\N	3727	39045	\N	52.579455000000003	Липецкая область, город Липецк, З.Космодемьянской, 178		0101000020E61000007F164B917CD343407940D9942B4A4A40
53227	1	9	\N	3727	39059	\N	52.611390999999998	Липецкая область, город Липецк, Зегеля, 6		0101000020E6100000C405A051BACC4340CC086F0F424E4A40
53207	1	9	\N	3727	39054	\N	52.601311000000003	Липецкая область, город Липецк, ул. Звездная, 12		0101000020E6100000117349D576C54340CFDC43C2F74C4A40
53205	1	9	\N	3727	39054	\N	52.605041	Липецкая область, город Липецк, ул. Звездная, 6		0101000020E610000078962023A0C643409CDEC5FB714D4A40
53221	1	9	\N	3727	39082	\N	52.630848	Липецкая область, город Липецк, Железнякова, 8		0101000020E6100000DB183BE125C843409E5F94A0BF504A40
53233	1	9	\N	3727	39032	\N	52.623580202871999	Липецкая область, город Липецк, Елецкая, 63	Россия, Липецкая область, Липецк, Елецкая улица	0101000020E6100000664D2CF015D1434047382D78D14F4A40
53236	1	9	\N	3727	39083	\N	52.639986	Липецкая область, город Липецк, Дружбы, 32		0101000020E610000004A9143B1AD34340EDF2AD0FEB514A40
53119	1	9	\N	3727	39089	\N	52.585718425675097	Липецкая область, город Липецк, Дзержинского, 27	Россия, Липецкая область, Липецк, улица Дзержинского, 27	0101000020E6100000560F98874CCF4340DA56B3CEF84A4A40
53213	1	9	\N	3727	39055	\N	52.582405000000001	Липецкая область, город Липецк, ул. Детская, 2в		0101000020E6100000739EB12FD9BC434071033E3F8C4A4A40
53165	1	9	\N	3727	39050	\N	52.590820000000001	Липецкая область, город Липецк, Депутатская, 55б		0101000020E61000004AED45B41DC943404FE960FD9F4B4A40
53234	1	9	\N	3727	39041	\N	52.639740000000003	Липецкая область, город Липецк, Гражданская, 1а		0101000020E6100000F299EC9FA7D14340B6F81400E3514A40
53191	1	9	\N	3727	38944	\N	52.618349261298398	Липецкая область, город Липецк, ул. Германа Титова, 8	Россия, Липецкая область, Липецк, улица Титова, 8	0101000020E61000002FFB75A73BC74340D5415E0F264F4A40
53190	1	9	\N	3727	39012	\N	52.6218331227495	Липецкая область, город Липецк, ул. Гагарина, 129		0101000020E6100000957EC2D9ADC743406B494739984F4A40
53223	1	9	\N	3727	39063	\N	52.618952999999998	Липецкая область, город Липецк, Гагарина, 24		0101000020E61000004BB1A371A8CD43406B6116DA394F4A40
53222	1	9	\N	3727	39063	\N	52.620068000000003	Липецкая область, город Липецк, Гагарина, 84		0101000020E61000009F5A7D7555CA4340E8A562635E4F4A40
53189	1	9	\N	3727	39063	\N	52.619390000000003	Липецкая область, город Липецк, ул. Гагарина, 123/3		0101000020E61000002C29779FE3C7434017BCE82B484F4A40
53187	1	9	\N	3727	39063	\N	52.620471999999999	Липецкая область, город Липецк, ул. Гагарина, 73а		0101000020E61000006DC9AA0837C94340B70A62A06B4F4A40
53249	1	9	\N	3727	39508	\N	52.623394508450602	Липецкая область, город Липецк, Гагарина, 106		0101000020E61000001286014BAEC84340B6BE4868CB4F4A40
53126	1	9	\N	3727	39046	\N	52.539105999999997	Липецкая область, город Липецк, Волгоградская, 4		0101000020E6100000EA3C2AFEEFCA4340E789E76C01454A40
53209	1	9	\N	3727	39078	\N	52.602514999999997	Липецкая область, город Липецк, ул. Вермишева, 23б		0101000020E61000005F9A22C0E9C34340BA2C26361F4D4A40
53208	1	9	\N	3727	39078	\N	52.601207000000002	Липецкая область, город Липецк, ул. Вермишева, 16		0101000020E6100000D6E07D552EC443402A90D959F44C4A40
53185	1	9	\N	3727	38949	\N	52.615714990124502	Липецкая область, город Липецк, ул. В. Терешковой, 13		0101000020E610000032FFE89B34C943400D54C6BFCF4E4A40
53245	1	9	\N	3727	39067	\N	52.652563999999998	Липецкая область, город Липецк, Баумана, 262		0101000020E6100000CB9F6F0B96D843400246973787534A40
53244	1	9	\N	3727	38994	\N	52.639414172595799	Липецкая область, город Липецк, Арсеньева, 38а	Россия, Липецкая область, Липецк, улица Арсеньева, 53а	0101000020E6100000C47B0E2C47D64340624D6551D8514A40
53117	1	9	\N	3727	39088	\N	52.588265	Липецкая область, город Липецк, Адмирала Макарова, 4		0101000020E6100000BF29AC5450CF4340D3307C444C4B4A40
53201	1	9	\N	3727	38838	\N	52.606566999999998	Липецкая область, город Липецк, 9 микрорайон, 42а		0101000020E6100000D9B3E73235C543409AEAC9FCA34D4A40
53175	1	9	\N	3727	39035	\N	52.608465000000002	Липецкая область, город Липецк, ул. 8 Марта, 22/4		0101000020E61000001C42959A3DCA43405DE15D2EE24D4A40
53173	1	9	\N	3727	39035	\N	52.607430999999998	Липецкая область, город Липецк, ул. 8 Марта, 20а		0101000020E6100000EEB089CC5CCA4340CDC98B4CC04D4A40
53171	1	9	\N	3727	39060	\N	52.585889999999999	Липецкая область, город Липецк, 50 лет НЛМК, 9		0101000020E61000002D0B26FE28CA4340D7868A71FE4A4A40
53229	1	9	\N	3727	39108	\N	52.612291859900097	Липецкая область, город Липецк, Ленина, 28		0101000020E6100000B0AA5E7EA7CD43401CCD91955F4E4A40
53751	1	9	\N	18875	39007	\N	52.523980000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Ленинский сельсовет, село Ленино, Гурьева, 205а		0101000020E6100000D61C2098A3BF434009E1D1C611434A40
53661	1	9	\N	54697	38879	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Шоссейный проезд, 10		0101000020E6100000487023658B924340A75D4C33DD814A40
53660	1	9	\N	54697	38975	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Школьная, 17		0101000020E6100000487023658B924340A75D4C33DD814A40
53653	1	9	\N	54697	38971	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Шахрая, 40		0101000020E6100000487023658B924340A75D4C33DD814A40
53663	1	9	\N	54697	39118	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Тургенева, 32		0101000020E6100000487023658B924340A75D4C33DD814A40
53654	1	9	\N	54697	38860	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Студенческая, 12		0101000020E6100000487023658B924340A75D4C33DD814A40
53658	1	9	\N	54697	39239	\N	53.014045366893598	Липецкая область, Лебедянский район, г.Лебедянь, ул.Привокзальная, 1	Россия, Липецкая область, Лебедянский район, Лебедянь	0101000020E610000099D36531B19543400FD6FF39CC814A40
53659	1	9	\N	54697	38932	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Первомайская, 13		0101000020E6100000487023658B924340A75D4C33DD814A40
53652	1	9	\N	54697	38933	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Антонова, 14		0101000020E6100000487023658B924340A75D4C33DD814A40
53543	1	9	\N	54743	39024	\N	52.392523755221397	Липецкая область, Задонский муниципальный район, городское поселение г. Задонск, Степанищева, 21	Россия, Липецкая область, Задонский район, Задонск	0101000020E610000090D8EE1EA07743409372F7393E324A40
53545	1	9	\N	54743	38992	\N	52.388375307898698	Липецкая область, Задонский муниципальный район ,городское поселение город Задонск, Крупской, 56	Россия, Липецкая область, Задонский район, Задонск	0101000020E6100000AEF545425B764340C1CAA145B6314A40
53542	1	9	\N	54743	39034	\N	52.388532851030597	Липецкая область, Задонский муниципальный район, городское поселение г. Задонск, Коммуны, 17		0101000020E6100000D2393FC57176434059350873BB314A40
53465	1	9	\N	4018	38839	\N	52.611636632563403	Липецкая область, город Елец, микрорайон Александровский, 15	Россия, Липецкая область, Елец	0101000020E61000004B00FE29554443400403081F4A4E4A40
53502	1	9	\N	4018	38854	\N	52.613517999999999	Липецкая область, город Елец, Юбилейная, 7-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53506	1	9	\N	4018	38853	\N	52.613517999999999	Липецкая область, город Елец, Электриков, 2-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53470	1	9	\N	4018	38824	\N	52.613517999999999	Липецкая область, город Елец, Спутников, 9-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53469	1	9	\N	4018	38824	\N	52.6179871005614	Липецкая область, город Елец, Спутников, 9	Россия, Липецкая область, Елец	0101000020E6100000FAEC80EB8A3F4340342DB1321A4F4A40
53468	1	9	\N	4018	38824	\N	52.613517999999999	Липецкая область, город Елец, Спутников, 15		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53459	1	9	\N	4018	39132	\N	52.613517999999999	Липецкая область, город Елец, Советская, 121		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53472	1	9	\N	4018	38844	\N	52.613517999999999	Липецкая область, город Елец, Свердлова, 137		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53485	1	9	\N	4018	38965	\N	52.613517999999999	Липецкая область, город Елец, Рязано-Уральская, 43		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53500	1	9	\N	4018	38850	\N	52.613517999999999	Липецкая область, город Елец, Радиотехническая, 3		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53474	1	9	\N	4018	38850	\N	52.611323148564999	Липецкая область, город Елец, Радиотехническая, 6-а	Россия, Липецкая область, Елец	0101000020E6100000A2EE0390DA3C4340742502D53F4E4A40
53496	1	9	\N	4018	38857	\N	52.613517999999999	Липецкая область, город Елец, Пушкина, 54		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53493	1	9	\N	4018	38849	\N	52.613517999999999	Липецкая область, город Елец, Профинтерна, 2-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53494	1	9	\N	4018	38830	\N	52.6132045289324	Липецкая область, город Елец, Мира, 83	Россия, Липецкая область, Елец	0101000020E610000097FE25A94C434340315F5E807D4E4A40
53447	1	9	\N	4018	39270	\N	52.613517999999999	Липецкая область, город Елец, Пригородная, 55-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53504	1	9	\N	4018	38964	\N	52.613517999999999	Липецкая область, город Елец, Плеханова, 1-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53481	1	9	\N	4018	38923	\N	52.617151260064503	Липецкая область, город Елец, Орджоникидзе, 9-а		0101000020E610000083E0F1ED5D3F4340CBD8D0CDFE4E4A40
53497	1	9	\N	4018	37428	\N	52.613517999999999	Липецкая область, город Елец, Октябрьская, 22		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53488	1	9	\N	4018	38961	\N	52.613517999999999	Липецкая область, город Елец, Новолипецкая, 1-б		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53478	1	9	\N	4018	38845	\N	52.613517999999999	Липецкая область, город Елец, Мира, 84		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53477	1	9	\N	4018	38845	\N	52.613517999999999	Липецкая область, город Елец, Мира, 94		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53460	1	9	\N	4018	37426	\N	52.613517999999999	Липецкая область, город Елец, Маяковского, 64		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53495	1	9	\N	4018	38941	\N	52.618091579495797	Липецкая область, город Елец, Лермонтова, 3	Россия, Липецкая область, Елец	0101000020E61000008010C990633F4340A9F57EA31D4F4A40
53461	1	9	\N	4018	38825	\N	52.619786424895402	Липецкая область, город Елец, Ленина, 91	Россия, Липецкая область, Елец	0101000020E610000081785DBF603F43406342CC25554F4A40
53489	1	9	\N	4018	38925	\N	52.613517999999999	Липецкая область, город Елец, Кротевича, 25		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53479	1	9	\N	4018	38881	\N	52.611898377728899	Липецкая область, город Елец, Красноармейская, 45	Россия, Липецкая область, Елец	0101000020E61000009204E10A28444340703E75AC524E4A40
53501	1	9	\N	4018	38851	\N	52.613517999999999	Липецкая область, город Елец, Костенко, 57		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53462	1	9	\N	4018	38823	\N	52.613517999999999	Липецкая область, город Елец, Комсомольская, 83		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53464	1	9	\N	4018	38958	\N	52.615166074608702	Липецкая область, город Елец, Коммунаров, 48	Россия, Липецкая область, Елец	0101000020E6100000D3D85E0B7A3F43403ACE6DC2BD4E4A40
53463	1	9	\N	4018	38958	\N	52.618718447840401	Липецкая область, город Елец, Коммунаров, 30	Россия, Липецкая область, Елец	0101000020E6100000C07B478D093F434028B9C326324F4A40
53482	1	9	\N	4018	38924	\N	52.617360221692202	Липецкая область, город Елец, Клубная, 10	Россия, Липецкая область, Елец	0101000020E610000083E0F1ED5D3F4340E5ED08A7054F4A40
53487	1	9	\N	4018	38852	\N	52.616456165126699	Липецкая область, город Елец, Известковая, 77	Россия, Липецкая область, Елец	0101000020E61000000F45813E913F434024B6BB07E84E4A40
53486	1	9	\N	4018	38963	\N	52.613517999999999	Липецкая область, город Елец, Задонское шоссе, 2		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53491	1	9	\N	4018	38962	\N	52.613517999999999	Липецкая область, город Елец, Задонская, 47		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53498	1	9	\N	4018	38848	\N	52.613517999999999	Липецкая область, город Елец, Ефремовская, 1		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53473	1	9	\N	4018	38922	\N	52.617151260064503	Липецкая область, город Елец, Гагарина, 20-а		0101000020E6100000AAF413CE6E3F4340CBD8D0CDFE4E4A40
53490	1	9	\N	4018	38832	\N	52.618702485938201	Липецкая область, город Елец, Верхняя, 17	Россия, Липецкая область, Елец	0101000020E6100000514F1F813F42434022FC8BA0314F4A40
53484	1	9	\N	4018	37427	\N	52.613517999999999	Липецкая область, город Елец, Вермишева, 1		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53483	1	9	\N	4018	37427	\N	52.613517999999999	Липецкая область, город Елец, Вермишева, 12		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53499	1	9	\N	4018	38855	\N	52.613517999999999	Липецкая область, город Елец, Барковского, 3		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53505	1	9	\N	4018	38926	\N	52.613517999999999	Липецкая область, город Елец, Ани Гайтеровой, 1-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53466	1	9	\N	4018	38983	\N	52.637465186545199	Липецкая область, город Елец, Александровский мкрн, 15		0101000020E61000007FF5B86FB53A43401DACFF7398514A40
53480	1	9	\N	4018	38960	\N	52.613517999999999	Липецкая область, город Елец, А Оборотова, 4		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53458	1	9	\N	4018	38843	\N	52.613517999999999	Липецкая область, город Елец, 3-й Ламской переулок, 43-а		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53507	1	9	\N	4018	37429	\N	52.613517999999999	Липецкая область, город Елец, 1-я Речная, 34		0101000020E6100000AAB5300BED424340F0C000C2874E4A40
53293	1	9	\N	54756	35365	\N	53.245608866668	Липецкая область, Данковский район, г.Данков, ул.Энгельса, 7	Россия, Липецкая область, Данковский район, Данков	0101000020E61000004BAE62F19B904340384D9F1D709F4A40
53332	1	9	\N	54756	35356	\N	53.253354366029697	Липецкая область, Данковский район, г.Данков, ул.Чапаева, 13/1	Россия, Липецкая область, Данковский район, Данков	0101000020E61000003F73D6A71C934340C82764E76DA04A40
53327	1	9	\N	54756	39217	\N	53.248942313784703	Липецкая область, Данковский район, г.Данков, ул.Свердлова, 1б		0101000020E610000048C2BE9D44924340E84CDA54DD9F4A40
53334	1	9	\N	54756	35391	\N	53.252108203404703	Липецкая область, Данковский район, г.Данков, ул.Пионерская, 11	Россия, Липецкая область, Данковский район, Данков	0101000020E6100000D7338463968F4340AD872F1345A04A40
53319	1	9	\N	54756	39282	\N	53.242054222848203	Липецкая область, Данковский район, г.Данков, ул.Островского, 30	Россия, Липецкая область, Данковский район, Данков	0101000020E6100000F54C2F3196954340D9EE1EA0FB9E4A40
53329	1	9	\N	54756	35360	\N	53.2513210763248	Липецкая область, Данковский район, г.Данков, ул.Молодежная, 2	Россия, Липецкая область, Данковский район, Данков	0101000020E61000009929ADBF2594434025E659492BA04A40
53331	1	9	\N	54756	35325	\N	53.255943000000002	Липецкая область, Данковский район, г.Данков, ул.Мичурина, 7/1	Россия, Липецкая область, Данковский район, Данков	0101000020E6100000E1421EC18D924340F0517FBDC2A04A40
53330	1	9	\N	54756	35325	\N	53.2521532448513	Липецкая область, Данковский район, г.Данков, ул.Мичурина, 8	Россия, Липецкая область, Данковский район, Данков	0101000020E6100000B40584D6C39343404D4BAC8C46A04A40
53256	1	9	\N	54756	35313	\N	53.248105758918399	Липецкая область, Данковский район, г.Данков, ул.Мира, 40	Россия, Липецкая область, Данковский район, Данков	0101000020E610000030F65E7CD19443407FF8F9EFC19F4A40
53328	1	9	\N	54756	35305	\N	53.253305002798598	Липецкая область, Данковский район, г.Данков, ул.Ленина, д.18	Россия, Липецкая область, Данковский район, Данков	0101000020E6100000297B4B395F944340E674594C6CA04A40
53335	1	9	\N	54756	39143	\N	53.250358733155302	Липецкая область, Данковский район, г.Данков, ул.Коммунальная, 21		0101000020E610000093E52494BE90434030A182C30BA04A40
53326	1	9	\N	54756	35374	\N	53.275291811363203	Липецкая область, Данковский район, г.Данков, ул.Зеленая, 4	Россия, Липецкая область, Данковский район, Данков	0101000020E6100000931ADA006C924340DB6CACC43CA34A40
53333	1	9	\N	54756	35382	\N	53.248813614105799	Липецкая область, Данковский район, г.Данков, ул.Володарского, 44	Россия, Липецкая область, Данковский район, Данков	0101000020E61000000F4757E9EE904340BB641C23D99F4A40
53276	1	9	\N	54694	39030	\N	52.502611450655102	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Шкатова, 1		0101000020E6100000D388997D1EF7434010CEA78E55404A40
53272	1	9	\N	54694	39068	\N	52.501443983331903	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Станционная, д.1		0101000020E6100000B857E6ADBAF84340416326512F404A40
53282	1	9	\N	54694	39267	\N	52.497492040938802	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Советская, 92		0101000020E61000008315A75A0BF74340C5025FD1AD3F4A40
53288	1	9	\N	54694	38816	\N	52.499901633906198	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Правды, 26		0101000020E6100000E0A0BDFA78F843403D9AEAC9FC3F4A40
53286	1	9	\N	54694	38816	\N	52.501787310367	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Правды, 58	Россия, Липецкая область, Грязинский район, Грязи	0101000020E61000009818CBF44BF843406B47718E3A404A40
53287	1	9	\N	54694	38954	\N	52.496989582174102	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Первогмайская, 31		0101000020E61000009CA8A5B915F8434032384A5E9D3F4A40
53278	1	9	\N	54694	38939	\N	52.497934431645497	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Осовиахима, 1		0101000020E610000023DC645419F8434082C8224DBC3F4A40
53526	1	9	914	8013	38856	\N	52.710079999999998	Липецкая область, Елецкий район, с.Талица, Советская, 26		0101000020E6100000A2D11DC4CE5C434097C5C4E6E35A4A40
53273	1	9	\N	54694	39008	\N	52.476821705208003	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Орджоникидзе, 80а		0101000020E6100000336ABE4A3EF24340B401D880083D4A40
53290	1	9	\N	54694	38917	\N	52.496781976378301	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Некрасова, 1		0101000020E61000006077BAF3C4F74340E99E758D963F4A40
53297	1	9	\N	54694	38993	\N	52.497353407504697	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, М.Расковой, 33		0101000020E6100000799274CDE4F74340A3C85A43A93F4A40
53295	1	9	\N	54694	39004	\N	52.496863429433802	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, М.Расковой, 30	Россия, Липецкая область, Грязинский район, Грязи	0101000020E61000005AD76839D0F74340D5CBEF34993F4A40
53284	1	9	\N	54694	39028	\N	52.500916505401896	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Крылова, 4		0101000020E6100000F0517FBDC2F8434056815A0C1E404A40
53285	1	9	\N	54694	38948	\N	52.498434941261699	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Красная Площадь, 37		0101000020E6100000AA29C93A1CF743404417D4B7CC3F4A40
53283	1	9	\N	54694	39015	\N	52.499249117703798	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Коммунальная, 5		0101000020E6100000F0164850FCF64340C5C72764E73F4A40
53291	1	9	\N	54694	39085	\N	52.495828308418901	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Гастелло, 5	Россия, Липецкая область, Грязинский район, Грязи	0101000020E6100000D0F1D1E28CF543407638BA4A773F4A40
53296	1	9	\N	54694	39043	\N	52.503172462248898	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Гагарина, 1а		0101000020E6100000166EF9484AF84340A721AAF067404A40
53274	1	9	\N	54694	38929	\N	52.497387272981904	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, 18 Партсъезд, 81а		0101000020E6100000A8FFACF9F1F74340503A9160AA3F4A40
53934	1	9	1793	27712	39159	\N	53.220534318687498	Липецкая область, Чаплыгинский район, с.Юсово, Советская, 9	Россия, Липецкая область, Чаплыгинский район, поселок Юсово	0101000020E6100000A1BAB9F8DBFC4340FAD346753A9C4A40
53932	1	9	1793	27600	\N	\N	53.507669999999997	Липецкая область, Чаплыгинский район, с.Шишкино, здание Досугового Центра с.Шишкино	Россия, Липецкая область, Чаплыгинский район, поселок Шишкино	0101000020E6100000F645425BCEEF434085949F54FBC04A40
53914	1	9	1793	26779	39441	\N	53.138370000000002	Липецкая область, Чаплыгинский район, с.Чечеры, Зеленая, 61		0101000020E610000038F4160FEFE94340AF5FB01BB6914A40
53900	1	9	1793	26134	38833	\N	53.240194000000002	Липецкая область, Чаплыгинский район, г.Чаплыгин, Советская, 10 А		0101000020E6100000A88FC01F7EFA434004594FADBE9E4A40
53931	1	9	1793	27555	39326	\N	53.516548	Липецкая область, Чаплыгинский район, с.Урусово, Центральная, 8		0101000020E61000000E65A88AA9CC43403868AF3E1EC24A40
53930	1	9	1793	27507	39164	\N	53.417290121166801	Липецкая область, Чаплыгинский район, с.Троекурово, Советская, 4	Россия, Липецкая область, Чаплыгинский район, поселок Троекурово	0101000020E6100000DA53724EECDB434053793BC269B54A40
53923	1	9	1793	27172	39443	\N	53.402987000000003	Липецкая область, Чаплыгинский район, с.Топтыково, Центральная, 78		0101000020E61000003A234A7B83EB434049DBF81395B34A40
53928	1	9	1793	27415	39446	\N	53.357410543531103	Липецкая область, Чаплыгинский район, с.Соловое, Центральная, 7	Россия, Липецкая область, Чаплыгинский район, поселок Соловое	0101000020E61000007156444DF40B4440861DC6A4BFAD4A40
53929	1	9	1793	27448	39330	\N	53.333758000000003	Липецкая область, Чаплыгинский район, с.Солнцево, Школьная, 7		0101000020E61000005D5320B3B3104440A2630795B8AA4A40
53933	1	9	1793	27652	39122	\N	53.263463000000002	Липецкая область, Чаплыгинский район, пос.Рощинский, Школьная, 12		0101000020E61000007FA5F3E159004440605AD427B9A14A40
53927	1	9	1793	27335	39322	\N	53.292624000000004	Липецкая область, Чаплыгинский район, с.Пиково, Красиловка, 2		0101000020E610000074B33F506EEB43402A0307B474A54A40
53925	1	9	1793	27266	39121	\N	53.180267999999998	Липецкая область, Чаплыгинский район, с.Новополянье, Школьная, 4		0101000020E6100000D6FECEF6E8E74340F641960513974A40
53926	1	9	1793	27313	39281	\N	53.528147121777799	Липецкая область, Чаплыгинский район, с.Новое Петелино, Молодежная, 17	Россия, Липецкая область, Чаплыгинский район, поселок Новое Петелино	0101000020E61000006150A6D1E4DA4340813D26529AC34A40
53922	1	9	1793	27128	39343	\N	53.277781939000903	Липецкая область, Чаплыгинский район, с.Ломовое, Советская, 24	Россия, Липецкая область, Чаплыгинский район, поселок Ломовое	0101000020E6100000618907944DF1434070B54E5C8EA34A40
53921	1	9	1793	27101	39437	\N	53.387307999999997	Липецкая область, Чаплыгинский район, с.Лозовка, Центральная		0101000020E6100000DACA4BFE27F5434055BDFC4E93B14A40
53919	1	9	1793	26901	37438	\N	53.219833999999999	Липецкая область, Чаплыгинский район, с.Кривополянье, им.Радина, 2 А		0101000020E610000059C16F438CF7434041464085239C4A40
53918	1	9	1793	26901	38870	\N	53.219833999999999	Липецкая область, Чаплыгинский район, с.Кривополянье, Пролетарская, 2 Б		0101000020E610000059C16F438CF7434041464085239C4A40
53917	1	9	1793	26901	38871	\N	53.219833999999999	Липецкая область, Чаплыгинский район, с.Кривополянье, Дзержинского, 35		0101000020E610000059C16F438CF7434041464085239C4A40
53916	1	9	1793	26877	39438	\N	53.432304000000002	Липецкая область, Чаплыгинский район, с.Конюшки, Центральная, 133		0101000020E6100000F14BFDBCA9DE43400AF7CABC55B74A40
53920	1	9	1793	27040	39161	\N	53.099918000000002	Липецкая область, Чаплыгинский район, с.Колыбельское, Революционная, 52		0101000020E6100000D61BB5C2F4F743401024EF1CCA8C4A40
53880	1	9	1681	25193	39187	\N	52.189449000000003	Липецкая область, Хлевенский район, с. Верхняя Колыбелька, Мира, 15		0101000020E6100000CD902A8A5775434045A165DD3F184A40
53915	1	9	1793	26789	39436	\N	53.1465793493253	Липецкая область, Чаплыгинский район, с.Истобное, Ленинская, 1	Россия, Липецкая область, Чаплыгинский район, поселок Истобное	0101000020E61000000AD7A3703DFC4340E4A3C519C3924A40
53913	1	9	1793	26714	39344	\N	53.132075999999998	Липецкая область, Чаплыгинский район, с.Зенкино, Советская, 4		0101000020E6100000CAFB389A23DF4340124BCADDE7904A40
53912	1	9	1793	26705	39320	\N	53.256028999999998	Липецкая область, Чаплыгинский район, с.Жабино, Спортивная, 4		0101000020E6100000AD4CF8A57EF04340EEE9EA8EC5A04A40
53924	1	9	1793	27216	39439	\N	53.435739945310402	Липецкая область, Чаплыгинский район, с.Дуровщино, Богдановка, 38	Россия, Липецкая область, Чаплыгинский район, поселок Дуровщино	0101000020E6100000AED689CBF1EC43408FC70C54C6B74A40
53910	1	9	1793	26600	39126	\N	53.127062000000002	Липецкая область, Чаплыгинский район, с. Дубовое, Театральная, 33		0101000020E6100000A87004A9140944403D484F9143904A40
53911	1	9	1793	26600	39243	\N	53.127062000000002	Липецкая область, Чаплыгинский район, с.Дубовое, Авиационная		0101000020E6100000A87004A9140944403D484F9143904A40
53909	1	9	1793	26543	39485	\N	53.083964999999999	Липецкая область, Чаплыгинский район, с.Демкино, Махоново, 103		0101000020E610000077DA1A118CF543401B81785DBF8A4A40
53908	1	9	1793	26475	\N	\N	53.509335999999998	Липецкая область, Чаплыгинский район, с. Выселки, Здание объекта досуга с. Выселки	Россия, Липецкая область, Чаплыгинский район, поселок Выселки	0101000020E6100000BFD2F9F02CF1434075560BEC31C14A40
53905	1	9	1793	26331	39433	\N	53.329718999999997	Липецкая область, Чаплыгинский район, д. Воскресенское, Центральная, 1		0101000020E61000006C26DF6C73F9434056EF703B34AA4A40
53907	1	9	1793	26459	39435	\N	53.489212000000002	Липецкая область, Чаплыгинский район, с. Ведное, Центральная, 7 А		0101000020E610000009F9A067B3E44340C767B27F9EBE4A40
53906	1	9	1793	26393	39321	\N	53.071446999999999	Липецкая область, Чаплыгинский район, с. Буховое, Красноармейская, 1		0101000020E610000042CD902A8AFD4340DB32E02C25894A40
53904	1	9	1793	60438	75009	\N	53.338096999999998	Липецкая область, Чаплыгинский район, Братовский сельсовет, Свинушки, 1	Россия, Липецкая область, Чаплыгинский район, поселок Братовка	0101000020E61000003CBD529621FC434017F032C346AB4A40
53935	1	9	1793	27720	\N	\N	53.237983999999997	Липецкая область, Чаплыгинский район, с.Б.Снежеток, здание отделения связи с.Б.Снежеток	Россия, Липецкая область, Чаплыгинский район, поселок Большой Снежеток	0101000020E6100000C442AD69DE074440527C7C42769E4A40
53897	1	9	1681	25952	38985	\N	52.201301000000001	Липецкая область, Хлевенский район, с. Хлевное, Юбилейная, 2		0101000020E6100000145FED28CE8B434078D32D3BC4194A40
53896	1	9	1681	25952	37436	\N	52.201301000000001	Липецкая область, Хлевенский район, с. Хлевное, Свободы, 54		0101000020E6100000145FED28CE8B434078D32D3BC4194A40
53899	1	9	1681	25952	39189	\N	52.201301000000001	Липецкая область, Хлевенский район, с. Хлевное, Пугачева, 5		0101000020E6100000145FED28CE8B434078D32D3BC4194A40
53895	1	9	1681	54767	39266	\N	52.037455611604003	Липецкая область, Хлевенский район, с. Фомино-Негачевка, Центральная, 20	Россия, Липецкая область, Хлевенский район, поселок Фомина-Негачевка	0101000020E610000010B22C98F8874340FD84B35BCB044A40
53886	1	9	1681	54785	39516	\N	52.245881670015997	Липецкая область, Хлевенский район, с. Старое Дубовое, Школьная, 13	Россия, Липецкая область, Хлевенский район, поселок Старо Дубовое	0101000020E6100000882CD2C43B8443406956B60F791F4A40
53893	1	9	1681	25801	39483	\N	52.113176000000003	Липецкая область, Хлевенский район, с. Синдякино, Центральная, 25		0101000020E61000001DAED51EF6AA43409758198D7C0E4A40
53894	1	9	1681	25881	39391	\N	52.171363999999997	Липецкая область, Хлевенский район, д. Подгорное, Молодежная, 15		0101000020E61000001A4F04711EAE43401ADB6B41EF154A40
53892	1	9	1681	25781	39190	\N	52.098163	Липецкая область, Хлевенский район, с. Отскочное, Центральная, 2		0101000020E61000006D74CE4F71904340B056ED9A900C4A40
53891	1	9	1681	25710	38938	\N	52.309277000000002	Липецкая область, Хлевенский район, с. Новое Дубовое, Советская, 105		0101000020E61000007845F0BF959C4340D733846396274A40
53890	1	9	1681	25703	39170	\N	52.19211	Липецкая область, Хлевенский район, с. Нижняя Колыбелька, Центральная, 50		0101000020E6100000F697DD93877F4340069E7B0F97184A40
53884	1	9	1681	25399	39482	\N	52.106803999999997	Липецкая область, Хлевенский район, с. Муравьевка, Школьная, 1		0101000020E6100000B4CBB73EAC7143407E8AE3C0AB0D4A40
53889	1	9	1681	25641	39327	\N	52.247520999999999	Липецкая область, Хлевенский район, д. Малый Мечек, Центральная, 21		0101000020E6100000412B306475A943405F09A4C4AE1F4A40
53812	1	9	1681	22065	39345	\N	52.270656000000002	Липецкая область, Хлевенский район, с. Малинино, Мирная, 37		0101000020E610000015FF774485AC4340AC3B16DBA4224A40
53888	1	9	1681	25598	37435	\N	52.133380000000002	Липецкая область, Хлевенский район, с. Конь-Колодезь, Ленина, 155		0101000020E6100000C22FF5F3A694434062F8889812114A40
53885	1	9	1681	54770	39318	\N	52.227573035274197	Липецкая область, Хлевенский район, с. Елец-Маланино, Дорожная, 5	Россия, Липецкая область, Хлевенский район, поселок Елецко-Маланинский	0101000020E6100000A01B9AB2D3894340EF39B01C211D4A40
53887	1	9	1681	54760	39201	\N	52.260904640111598	Липецкая область, Хлевенский район, с. Елец-Лозовка, Выгонская-Буторина, 20	Россия, Липецкая область, Хлевенский район, поселок Елецкая Лозовка	0101000020E61000003DB7D09508964340732EC55565214A40
53883	1	9	1681	25314	38937	\N	52.151144000000002	Липецкая область, Хлевенский район, с. Дмитряшевка, Ленина, 38		0101000020E6100000DC63E943178A43404A7EC4AF58134A40
53882	1	9	1681	54784	39514	\N	52.204905371270797	Липецкая область, Хлевенский район, с. Ворон-Лозовка, Дорожная, 40	Россия, Липецкая область, Хлевенский район, поселок Воронежская Лозовка	0101000020E6100000D9E9077591A24340B8E4B8533A1A4A40
53881	1	9	1681	25238	39188	\N	52.228323000000003	Липецкая область, Хлевенский район, с. Воробьевка, Мира, 4		0101000020E6100000C8940F41D59843405AF624B0391D4A40
53879	1	9	1681	25137	39242	\N	52.292298000000002	Липецкая область, Хлевенский район, с. Введенка, Центральная, 15		0101000020E6100000D253E41071874340D65757056A254A40
53851	1	9	1726	54700	38869	\N	52.286678999999999	Липецкая область, Усманский муниципальный район, станция Дрязги, Центральная, 9-а		0101000020E61000004FCB0F5CE5E3434099B9C0E5B1244A40
53873	1	9	1726	54783	39513	\N	52.106168440266501	"Липецкая область, Усманский муниципальный район, поселок совхоза ""Ударник"", Молодежная, 19-а"		0101000020E610000016A243E048DE4340DCF0BBE9960D4A40
53835	1	9	1726	24577	39001	\N	52.047041	Липецкая область, Усманский муниципальный район, городское поселение г. Усмань, К.Маркса, 30	Россия, Липецкая область, Усманский район, Усмань	0101000020E61000002F6AF7AB00DD43401B49827005064A40
53877	1	9	1726	25051	39430	\N	52.013674000000002	Липецкая область, Усманский муниципальный район, село Студенки, Первомайская, 52		0101000020E61000006C97361C96CC43401B67D311C0014A40
53870	1	9	1726	54757	39162	\N	52.090012999999999	Липецкая область, Усманский муниципальный район, село Стрелецкие Хутора, Г.Телегина, 187-а		0101000020E61000006AA510C825DA4340809BC58B850B4A40
53875	1	9	1726	24982	39245	\N	52.1740946332066	Липецкая область, Усманский муниципальный район, село Сторожевские Хутора, Центральная, 72	Россия, Липецкая область, Усманский район, поселок Сторожевские Хутора	0101000020E61000004CA60A4625F54340D5B2B5BE48164A40
53872	1	9	1726	24844	37434	\N	52.100183000000001	Липецкая область, Усманский муниципальный район, село Сторожевое, Школьная, 54		0101000020E6100000D28F8653E6E44340BE4EEACBD20C4A40
53866	1	9	1726	24566	\N	\N	52.128736000000004	Липецкая область, Усманский муниципальный район, село Поддубровка, Центральная, 14	Россия, Липецкая область, Усманский район, поселок Поддубровка	0101000020E61000008D463EAF78C64340B0E8D66B7A104A40
53865	1	9	1726	54766	39263	\N	52.259396514268602	Липецкая область, Усманский муниципальный район, село Пластинки, Центральная, 14	Россия, Липецкая область, Усманский район, поселок Пластинка	0101000020E61000003AB2F2CB600044401BD7BFEB33214A40
53864	1	9	1726	24480	39374	\N	52.021011999999999	Липецкая область, Усманский муниципальный район, село Пашково, Заречная, 34		0101000020E6100000213B6F63B3FD43406A696E85B0024A40
53862	1	9	1726	24365	39240	\N	52.301347	Липецкая область, Усманский муниципальный район, село Октябрьское, Проспект Революции, 77		0101000020E6100000514CDE0033DD4340B5DFDA8992264A40
53863	1	9	1726	24365	39241	\N	52.301347	Липецкая область, Усманский муниципальный район, село Октябрьское, Базарная, 1		0101000020E6100000514CDE0033DD4340B5DFDA8992264A40
53849	1	9	1726	23711	38936	\N	52.018479999999997	Липецкая область, Усманский муниципальный район, село Новоуглянка, Дзержинского, 25		0101000020E610000023F3C81F0CE04340A6D0798D5D024A40
53861	1	9	1726	24270	\N	\N	52.155940000000001	Липецкая область, Усманский муниципальный район, село Никольское, Ленина, 159-а	Россия, Липецкая область, Усманский район, поселок Никольское	0101000020E6100000B4E4F1B4FCD44340B21188D7F5134A40
53860	1	9	1726	24270	39158	\N	52.155940000000001	Липецкая область, Усманский муниципальный район, село Никольское, Ленина, 117		0101000020E6100000B4E4F1B4FCD44340B21188D7F5134A40
53876	1	9	1726	25033	39319	\N	51.950910999999998	Липецкая область, Усманский муниципальный район, село Никольские Выселки, Центральная, 60		0101000020E6100000A88FC01F7EE443400D349F73B7F94940
53852	1	9	1726	23843	39370	\N	52.251368999999997	Липецкая область, Усманский муниципальный район, село Московка, Центральная, 21-а		0101000020E6100000F73B1405FAEA4340361D01DC2C204A40
53869	1	9	1726	24721	39317	\N	52.074433999999997	Липецкая область, Усманский муниципальный район, село Медовка, Молодежная, 12-а		0101000020E6100000D15B3CBCE7CA4340F0DAA50D87094A40
53871	1	9	1726	24807	39449	\N	52.201660592829398	Липецкая область, Усманский муниципальный район, село Куриловка, Б.Котова, 28	Россия, Липецкая область, Усманский район, поселок Куриловка	0101000020E6100000096EA46C91E8434078F01307D0194A40
53859	1	9	1726	24164	39372	\N	52.226861	Липецкая область, Усманский муниципальный район, село Куликово, Лесная, 10		0101000020E610000079E75086AACA434072DEFFC7091D4A40
53858	1	9	1726	24164	39238	\N	52.226861	Липецкая область, Усманский муниципальный район, село Куликово, Ленина, 96		0101000020E610000079E75086AACA434072DEFFC7091D4A40
53857	1	9	1726	24078	39127	\N	51.987664000000002	Липецкая область, Усманский муниципальный район, село Крутченская Байгора, Центральная, 27		0101000020E61000009225732CEFFA4340E1B721C66BFE4940
53856	1	9	1726	24066	39252	\N	52.329925000000003	Липецкая область, Усманский муниципальный район, село Кривка, Садовая, 1		0101000020E6100000FA0D130D52D8434000917EFB3A2A4A40
53874	1	9	1726	24926	39484	\N	52.113236999999998	Липецкая область, Усманский муниципальный район, село Красное, 60 лет Победы, 104		0101000020E6100000DC48D92269E343403CD9CD8C7E0E4A40
53855	1	9	1726	23982	39339	\N	52.119866999999999	Липецкая область, Усманский муниципальный район, село Излегоще, Центральная, 73		0101000020E6100000C8409E5DBEAF4340506F46CD570F4A40
53854	1	9	1726	23910	39373	\N	52.05603	Липецкая область, Усманский муниципальный район, село Завальное, Пионерская, 37		0101000020E610000095D74AE82EED434025CCB4FD2B074A40
53853	1	9	1726	23910	39186	\N	52.05603	Липецкая область, Усманский муниципальный район, село Завальное, Ленина, 119		0101000020E610000095D74AE82EED434025CCB4FD2B074A40
53850	1	9	1726	23773	39481	\N	52.282608000000003	Липецкая область, Усманский муниципальный район, село Дмитриевка, Центральная, 10		0101000020E6100000F295404AECEE434043CBBA7F2C244A40
53848	1	9	1726	23669	38867	\N	51.991057616493599	Липецкая область, Усманский муниципальный район, село Девица, Советская, 5-а	Россия, Липецкая область, Усманский район, поселок Девица	0101000020E610000098309A95EDE54340373811FDDAFE4940
53847	1	9	1726	23639	39185	\N	52.098765999999998	Липецкая область, Усманский муниципальный район, село Грачевка, Ленина, 4		0101000020E61000007C6473D53C01444076FA415DA40C4A40
53846	1	9	1726	23581	39431	\N	52.054966999999998	Липецкая область, Усманский муниципальный район, село Верхняя Мосоловка, Попова, 1		0101000020E61000006A8995D1C8094440FBAD9D2809074A40
53845	1	9	1726	23548	\N	\N	52.229272000000002	Липецкая область, Усманский муниципальный район, село Бреславка, Молодежная, 4-а	Россия, Липецкая область, Усманский район, поселок Бреславка	0101000020E61000005ED905836BF64340BBF1EEC8581D4A40
53868	1	9	1726	24673	39432	\N	52.078862000000001	Липецкая область, Усманский муниципальный район, деревня Бочиновка, Заречная, 33		0101000020E6100000BF982D5915E14340D6726726180A4A40
53844	1	9	1726	23493	39371	\N	52.196063000000002	Липецкая область, Усманский муниципальный район, село Боровое, Новая, 12		0101000020E61000005A2BDA1CE7C04340537AA69718194A40
53843	1	9	1726	23412	39184	\N	52.156762999999998	Липецкая область, Усманский муниципальный район, село Березняговка, Ворошилова, 95-а		0101000020E61000008E06F01648084440861C5BCF10144A40
53878	1	9	1726	25115	39480	\N	51.989195000000002	Липецкая область, Усманский муниципальный район, село Беляево, Лесная, 1		0101000020E6100000BC783F6EBFC44340F12E17F19DFE4940
53828	1	9	1665	60436	75008	\N	52.126564000000002	Липецкая область Тербунский района село Яковлево, переулок Почтовый, 6	Россия, Липецкая область, Тербунский район, поселок Яковлево	0101000020E6100000793BC269C14B4340EC6CC83F33104A40
53833	1	9	1665	60430	75003	\N	52.028100000000002	Липецкая область Тербунский района село Урицкое, Пятая Сотня, 34	Россия, Липецкая область, Тербунский район, поселок Урицкое	0101000020E61000006A1492CCEA1743404182E2C798034A40
53819	1	9	1665	60427	75001	\N	52.1512466151651	Липецкая область Тербунский района село Тербуны, Октябрьская, 39 а	Россия, Липецкая область, Тербунский район, поселок Тербуны	0101000020E610000003ED0E29062443401E4FCB0F5C134A40
53820	1	9	1665	60427	75000	\N	52.144910000000003	Липецкая область Тербунский района село Тербуны, Ленина, 45	Россия, Липецкая область, Тербунский район, поселок Тербуны	0101000020E6100000D908C4EBFA234340836E2F698C124A40
53818	1	9	1665	60427	75002	\N	52.144910000000003	Липецкая область Тербунский района село Тербуны, Красноармейская, 4	Россия, Липецкая область, Тербунский район, поселок Тербуны	0101000020E6100000D908C4EBFA234340836E2F698C124A40
53816	1	9	1665	60453	75033	\N	52.122256	Липецкая область Тербунский района село Солдатское, Сельская, 34	Россия, Липецкая область, Тербунский район, поселок Солдатское	0101000020E6100000EACDA8F92A2B4340B1DEA815A60F4A40
53809	1	9	1665	60440	75011	\N	52.194760205283401	Липецкая область Тербунский района деревня Петропавловка, Высота, 1	Россия, Липецкая область, Тербунский район, поселок Петропавловка	0101000020E6100000A0DFF76F5E184340D4484BE5ED184A40
53806	1	9	1665	60439	75010	\N	52.030913760824099	Липецкая область Тербунский района деревня Михайловка, Садовая, 34	Россия, Липецкая область, Тербунский район, поселок Михайловка	0101000020E6100000172D40DB6A384340897E6DFDF4034A40
53796	1	9	1665	21292	39163	\N	52.013491000000002	Липецкая область Тербунский район село Березовка, Центральная, 25		0101000020E6100000E50E9BC8CC2743402AE5B512BA014A40
53834	1	9	1665	60434	75006	\N	52.013734549205402	Липецкая область Тербунский района деревня Барышниково, Лесная, 11	Россия, Липецкая область, Тербунский район, поселок Барышниково	0101000020E61000008EB1135E821D4340C0E78711C2014A40
53795	1	9	1606	21238	39367	\N	52.822744999999998	Липецкая область, Становлянский район, д.Яркино, Московская, 14		0101000020E61000004487C0914029434048F949B54F694A40
53793	1	9	1606	21136	39479	\N	52.927793999999999	Липецкая область, Становлянский район, д.Чернолес, Лесная, 15		0101000020E610000084F068E3883B434067B62BF4C1764A40
53782	1	9	1606	20530	39427	\N	53.028196999999999	Липецкая область, Становлянский район, д.Чемоданово, Центральная, 6		0101000020E610000082734694F6FE4240336C94F59B834A40
53794	1	9	1606	21192	39316	\N	52.981264000000003	Липецкая область, Становлянский район, с.Успенское, Соборная, 29		0101000020E6100000E6E5B0FB8E374340FF5E0A0F9A7D4A40
53791	1	9	1606	21035	39157	\N	52.706178000000001	Липецкая область, Становлянский район, с.Тростное, Центральная, 9		0101000020E6100000D68D7747C6304340CD936B0A645A4A40
53778	1	9	1606	20335	39183	\N	52.980462000000003	Липецкая область, Становлянский район, с.Толстая Дубрава, Центральная, 28		0101000020E6100000B84082E2C7124340427C60C77F7D4A40
53792	1	9	1606	21097	39429	\N	52.693097999999999	Липецкая область, Становлянский район, с.Телегино, Механизаторов, 58		0101000020E61000000056478E742E434025766D6FB7584A40
53769	1	9	1606	54746	39440	\N	52.733726856142901	Липецкая область, Становлянский район, с.Становое, Новая, 2	Россия, Липецкая область, Становлянский район, поселок Становая	0101000020E6100000551344DD072A43409A982EC4EA5D4A40
53768	1	9	1606	54746	39016	\N	52.738624140576803	Липецкая область, Становлянский район,с.Становое, Московская, 62	Россия, Липецкая область, Становлянский район, поселок Становая	0101000020E61000006B7EFCA5452943403605323B8B5E4A40
53767	1	9	1606	54746	39123	\N	52.737790616612997	Липецкая область, Становлянский район, с.Становое, Ленина, 7	Россия, Липецкая область, Становлянский район, поселок Становая	0101000020E61000000667F0F78B2943403E247CEF6F5E4A40
53790	1	9	1606	21007	39130	\N	52.784019999999998	Липецкая область, Становлянский район, с.Соловьево, Садовая, 24		0101000020E6100000CB2C42B1153A434078B471C45A644A40
53779	1	9	1606	20387	39400	\N	53.021481660998397	Липецкая область, Становлянский район, с.Семенек, Поволяева, 2	Россия, Липецкая область, Становлянский район, поселок Семенек	0101000020E610000025AFCE31200B4340F1B913ECBF824A40
44094	1	7	1847	29706	\N	\N	57.880937000000003	Костромская область, Островский район, с. Юрьево, 24		0101000020E61000001A3048FAB40E45400E6B2A8BC2F04C40
53776	1	9	1606	20203	39478	\N	52.905411999999998	Липецкая область, Становлянский район, д.Плоты, Советская, 50		0101000020E6100000D68EE21C751E4340F6B3588AE4734A40
53786	1	9	1606	20777	39182	\N	52.751775000000002	Липецкая область, Становлянский район, с.Пальна-Михайловка, 9 мая, 5		0101000020E6100000D5D0066003464340A779C7293A604A40
53789	1	9	1606	20920	39235	\N	52.905009999999997	Липецкая область, Становлянский район, д.Паленка, Ленина, 2		0101000020E6100000F2CF0CE2032F4340C746205ED7734A40
53774	1	9	1606	20082	39463	\N	52.861255	Липецкая область, Становлянский район, д.Озерки, им.А.И.Бунина, 5		0101000020E6100000247D5A457F2643401C42959A3D6E4A40
53777	1	9	1606	20257	39180	\N	52.966085999999997	Липецкая область, Становлянский район, д.Лукьяновка, Центральная, 17		0101000020E61000000A86730D33204340CD8FBFB4A87B4A40
53780	1	9	1606	20476	39251	\N	52.963111798611301	Липецкая область, Становлянский район, с.Ламское, Победы, 4		0101000020E610000047C7D5C8AE0643404D310741477B4A40
53788	1	9	1606	20904	39428	\N	52.887746	Липецкая область, Становлянский район, с.Красная Пальна, Фермерская, 12		0101000020E6100000471E882CD23E4340D19332A9A1714A40
53785	1	9	1606	20742	39366	\N	52.953674412279298	Липецкая область, Становлянский район, д.Кличено, Центральная, 40	Россия, Липецкая область, Становлянский район, поселок Кличено	0101000020E6100000C0B2D2A414024340D38558FD117A4A40
53771	1	9	1606	19882	39120	\N	52.733975000000001	Липецкая область, Становлянский район, с.Кириллово, Центральная, 7		0101000020E6100000C689AF76141D4340728A8EE4F25D4A40
53772	1	9	1606	19975	39314	\N	52.786203999999998	Липецкая область, Становлянский район, с.Злобино, Центральная, 2		0101000020E6100000A5660FB4021F434000FE2955A2644A40
53770	1	9	1606	19879	\N	\N	52.754528000000001	Липецкая область, Становлянский район, пос.Дружба, здание дома культуры, 2-в		0101000020E61000006EC493DDCC28434049F59D5F94604A40
53773	1	9	1606	20027	39181	\N	52.741636984470198	Липецкая область, Становлянский район, с.Дмитриевка, Центральная, 10	Россия, Липецкая область, Становлянский район, поселок Дмитриевка	0101000020E61000008046E9D2BF124340744012F6ED5E4A40
53775	1	9	1606	20132	39476	\N	52.849857999999998	Липецкая область, Становлянский район, с.Грунин Воргол, Советская, 13		0101000020E6100000AEF36F97FD2043403A1F9E25C86C4A40
53787	1	9	1606	20834	39426	\N	52.825018999999998	Липецкая область, Становлянский район, д.Бродки, Солнечная, 26		0101000020E610000042D2A755F43B434010CAFB389A694A40
53783	1	9	1606	20625	39236	\N	52.911000999999999	Липецкая область, Становлянский район, д.Березовка, Ю.Тарасова, 18		0101000020E610000033A5F5B704024340C8CF46AE9B744A40
53784	1	9	1606	20696	39425	\N	52.962262000000003	Липецкая область, Становлянский район, с.Барсуково, Ленина, 8		0101000020E6100000348463963DF342407F17B6662B7B4A40
53766	1	9	1512	19664	37433	\N	52.546236999999998	Липецкая область, Липецкий муниципальный район, сельское поселение Частодубравский сельсовет, село Частая Дубрава, Московская, 13		0101000020E6100000715AF0A2AFA24340BD6E1118EB454A40
53764	1	9	1512	54701	38872	\N	52.534519360492197	Липецкая область, Липецкий муниципальный район, сельское поселение Сырский сельсовет, село Хрущёвка, Титова, 79	Россия, Липецкая область, село Хрущевка	0101000020E6100000E38BF67821C143409A0B5C1E6B444A40
53749	1	9	1512	18781	39196	\N	52.760708000000001	Липецкая область, Липецкий муниципальный район, сельское поселение Кузьмино-Отвержский сельсовет, село Тюшевка, Центральная, 18		0101000020E610000082C476F700C743401DE736E15E614A40
53750	1	9	1512	18808	38882	\N	52.489654999999999	Липецкая область, Липецкий муниципальный район, сельское поселение Ленинский сельсовет, село Троицкое, Гагарина, 70		0101000020E61000006A865451BCC2434054A9D903AD3E4A40
53765	1	9	1512	19582	39237	\N	52.821384000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Тележенский сельсовет, село Тележенка, Фунзе, 4		0101000020E6100000DB300A82C7BF434095BA641C23694A40
53762	1	9	1512	54744	39009	\N	52.564397999999997	Липецкая область, Липецкий муниципальный район, сельское поселение Сырский сельсовет, село Сырское, Советская, 139б		0101000020E61000005322895E46C34340C2F693313E484A40
53761	1	9	1512	54744	38995	\N	52.568471000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Сырский сельсовет, село Сырское, Ленина, 7		0101000020E61000007FC2D9AD65C44340BADC60A8C3484A40
53752	1	9	1512	18950	38883	\N	52.797465614265299	Липецкая область, Липецкий муниципальный район, сельское поселение Лубновский сельсовет, село Сухая Лубна, Ксении Константиновой, 1в	Россия, Липецкая область, Липецкий район, поселок Сухая Лубна	0101000020E61000001BBE8575E3AB434002D6AA5D13664A40
53743	1	9	1512	18457	39368	\N	52.553404999999998	Липецкая область, Липецкий муниципальный район, сельское поселение Круто-Хуторской сельсовет, село Студёные Хутора, Терешковой, 2а		0101000020E61000001FF5D72B2CB04340B0389CF9D5464A40
53746	1	9	1512	18601	39129	\N	52.725588000000002	Липецкая область, Липецкий муниципальный район, Студёные Выселки, Комсомольская, 20		0101000020E6100000C05E61C1FDC043405E2F4D11E05C4A40
53729	1	9	1512	17754	39155	\N	52.418922278088402	Липецкая область, Липецкий муниципальный район, Стебаево, Шумная, 8	Россия, Липецкая область, Липецкий район, поселок Стебаево	0101000020E6100000D68D7747C6A2434097C9703C9F354A40
53759	1	9	1512	17754	39125	\N	52.418987000000001	Липецкая область, Липецкий муниципальный район, сельское поселение Стебаевский сельсовет, село Стебаево, Садовая, 1		0101000020E6100000C93846B247A243407E39B35DA1354A40
53736	1	9	1512	54698	38866	\N	52.673073000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Введенский сельсовет, село Ситовка, Парковая, 15		0101000020E6100000915F3FC406D943400A698D4127564A40
53708	1	9	1442	16703	39361	\N	53.287010000000002	Липецкая область, Лев-Толстовский район, с.Свищевка, ул.Новая, 1		0101000020E6100000D93D7958A8B94340FFCF61BEBCA44A40
53758	1	9	1512	19228	38940	\N	52.641449999999999	Липецкая область, Липецкий муниципальный район, сельское поселение Сенцовский сельсовет, село Сенцово, 8 Марта, 157		0101000020E61000006F8099EFE0AD434075029A081B524A40
53757	1	9	1512	19182	39198	\N	52.727420000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Пружинский сельсовет, село Пружинки, 50-лет Октября, 201а		0101000020E610000063EE5A423E984340693A3B191C5D4A40
53747	1	9	1512	54778	39504	\N	52.402009722405602	Липецкая область, Липецкий муниципальный район, сельское поселение Падовский сельсовет, село Пады, Юбилейная, 41	Россия, Липецкая область	0101000020E61000008CBB41B456BC43401D554D1075334A40
53755	1	9	1512	19097	38884	\N	52.647932759632504	Липецкая область, Липецкий муниципальный район, сельское поселение Новодмитриевский сельсовет, село Новодмитриевка, Кирова, 14	Россия, Липецкая область, Липецкий район, поселок Новодмитриевка	0101000020E6100000D1CE6916689D4340E57FF277EF524A40
53753	1	9	1512	54753	39099	\N	52.727746879248599	Липецкая область, Липецкий муниципальный район, сельское поселение Новодеревенский сельсовет, деревня Новая Деревня, Советская, 2в	Россия, Липецкая область, Липецкий район, поселок Новая Деревня	0101000020E6100000B8B06EBC3BB243408D614ED0265D4A40
53745	1	9	1512	54752	39093	\N	52.691765775983797	Липецкая область, Липецкий муниципальный район, сельское поселение Кузьмино-Отвержский сельсовет, село Кузьминский Отвержки, Молодёжная, 1	Россия, Липецкая область, Липецкий район, поселок Кузьминские Отвержки	0101000020E610000002F2255470BC43400C3ECDC98B584A40
53742	1	9	1512	18408	39248	\N	52.504677999999998	Липецкая область, Липецкий муниципальный район, сельское поселение Круто-Хуторской сельсовет, село Крутые Хутора, Школьная, 1		0101000020E6100000F12BD67091AD43405E81E84999404A40
53756	1	9	1512	19134	39457	\N	52.411735999999998	Липецкая область, Липецкий муниципальный район, сельское поселение Падовский сельсовет, село Крутогорье, Свободы, 11		0101000020E610000090BFB4A84FB84340FD4AE7C3B3344A40
53740	1	9	1512	54748	39039	\N	52.608760699679699	Липецкая область, Липецкий муниципальный район, сельское поселение Косырёвский сельсовет, село Косырёвка, Советская, 73а	Россия, Липецкая область	0101000020E61000002BA391CF2BB44340460A65E1EB4D4A40
53744	1	9	1512	18503	38837	\N	52.677506999999999	Липецкая область, Липецкий муниципальный район, сельское поселение Кузьмино-Отвержский сельсовет, деревня Копцевы Хутора, Котовского, 6а		0101000020E6100000FAB5F5D37FBA4340D1E7A38CB8564A40
53734	1	9	1512	18009	38981	\N	52.723674000000003	Липецкая область, Липецкий муниципальный район, сельское поселение Введенский сельсовет, село Ильино, Административная, 3		0101000020E6100000F581E49D43D54340967B8159A15C4A40
53739	1	9	1512	18230	39315	\N	52.693109662311301	Липецкая область, Липецкий муниципальный район, сельское поселение Ивовский сельсовет, село Ивово, Советская, 48б	Россия, Липецкая область, Липецкий район, поселок Ивово	0101000020E61000006902452C628A4340E94317D4B7584A40
53738	1	9	1512	18194	39234	\N	52.356422000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Грязновский сельсовет, село Грязное, Ленинская, 15		0101000020E61000001DE736E15EB1434097C9703C9F2D4A40
53754	1	9	1512	19041	39195	\N	52.755955999999998	Липецкая область, Липецкий муниципальный район, сельское поселение Новодеревенский сельсовет, село Вешаловка, 8 Марта, 72		0101000020E6100000ECA694D74AA44340849B8C2AC3604A40
53737	1	9	1512	18144	39178	\N	52.299937	Липецкая область, Липецкий муниципальный район, сельское поселение Вербиловский сельсовет, село Вербилово, Ленина, 2		0101000020E610000085ECBC8DCDB4434020EEEA5564264A40
53733	1	9	1512	17952	39119	\N	52.506366	Липецкая область, Липецкий муниципальный район, сельское поселение Васильевский сельсовет, село Васильевка, Центральная, 51		0101000020E61000000CAEB9A3FF9B434036E7E099D0404A40
53741	1	9	1512	18328	39489	\N	52.603231000000001	Липецкая область, Липецкий муниципальный район, сельское поселение Косыревский сельсовет, деревня Бруслановка, Ленина, 5		0101000020E61000004051D9B0A6A44340797764AC364D4A40
53730	1	9	1512	17697	38984	\N	52.459870000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Боринский сельсовет, село Боринское, Советская, 9		0101000020E610000043C879FF1FAF4340AD342905DD3A4A40
53728	1	9	1512	17697	38831	\N	52.459870000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Боринский сельсовет, село Боринское, Салтыкова-Щедрина, 31а		0101000020E610000043C879FF1FAF4340AD342905DD3A4A40
53731	1	9	1512	17697	38935	\N	52.459870000000002	Липецкая область, Липецкий муниципальный район, сельское поселение Боринский сельсовет, село Боринское, Дзержинского, 2		0101000020E610000043C879FF1FAF4340AD342905DD3A4A40
53732	1	9	1512	17887	39140	\N	52.751987999999997	Липецкая область, Липецкий муниципальный район, сельское поселение Большекузьминский сельсовет, село Большая Кузьминка, Московская, 1		0101000020E61000005C38109205DC4340027E8D2441604A40
53722	1	9	1442	54759	39192	\N	53.186813999999998	Липецкая область, Лев-Толстовский район, пос. СХПК им.Л.Толстого, ул.Центрльная, 19		0101000020E61000006BB6F292FFB74340AC376A85E9974A40
53726	1	9	1442	17613	39474	\N	53.186247000000002	Липецкая область, Лев-Толстовский район, с.Троицкое, ул.Новая, 4		0101000020E6100000B6A2CD716ECD434033FD12F1D6974A40
53714	1	9	1442	16996	39421	\N	53.336441000000001	Липецкая область, Лев-Толстовский район, с.Топки, ул.Советская, 6		0101000020E61000007F8461C092CB43404B04AA7F10AB4A40
53724	1	9	1442	17485	39312	\N	53.082715999999998	Липецкая область, Лев-Толстовский район, с.Первомайское, ул.Центральная, 22		0101000020E6100000B2D47ABFD1CE43408F6D1970968A4A40
53711	1	9	1442	16848	39308	\N	53.202491000000002	Липецкая область, Лев-Толстовский район, с.Острый Камень, ул.Графская, 17		0101000020E610000077137CD3F4AF4340FF5D9F39EB994A40
53706	1	9	1442	16604	39415	\N	53.398654063901397	Липецкая область, Лев-Толстовский район, с.Орловка, ул.Центральная, 10А	Россия, Липецкая область, Лев-Толстовский район, поселок Орловка	0101000020E6100000C5707500C4B74340B535221807B34A40
53720	1	9	1442	17292	39422	\N	53.252370999999997	Липецкая область, Лев-Толстовский район, с.Новочемоданово, ул.Механизаторов, 9		0101000020E6100000630AD6389BDA4340BABA63B14DA04A40
53721	1	9	1442	17323	39434	\N	53.205807999999998	Липецкая область, Лев-Толстовский район, с.Митягино, ул.Горбатовка, 4		0101000020E6100000F1B913ECBFDC4340A9A0A2EA579A4A40
53703	1	9	1442	16295	38980	\N	53.210273999999998	Липецкая область, Лев-Толстовский район, пос. Лев Толстой, пер. Советский, 1		0101000020E6100000AC1F9BE447BA43407C992842EA9A4A40
53701	1	9	1442	16295	38865	\N	53.210686212389902	Липецкая область, Лев-Толстовский район, пос. Лев Толстой, ул.Слонского, 1	Россия, Липецкая область, Лев-Толстовский район, поселок Лев Толстой	0101000020E61000001407D0EFFBB94340CFDC43C2F79A4A40
53702	1	9	1442	16295	38976	\N	53.210273999999998	Липецкая область, Лев-Толстовский район, пос. Лев Толстой, ул.Коммунистическая, 16		0101000020E6100000AC1F9BE447BA43407C992842EA9A4A40
53700	1	9	1442	16295	38974	\N	53.210273999999998	Липецкая область, Лев-Толстовский район, пос. Лев Толстой, ул.Володарского, 24		0101000020E6100000AC1F9BE447BA43407C992842EA9A4A40
53704	1	9	1442	16295	38982	\N	53.210273999999998	Липецкая область, Лев-Толстовский район, пос. Лев Толстой, ул.1-ая Садовая, 1А		0101000020E6100000AC1F9BE447BA43407C992842EA9A4A40
53725	1	9	1442	17551	39423	\N	53.121270000000003	Липецкая область, Лев-Толстовский район, с.Кузовлево, ул.Школьная, 7		0101000020E61000008BDEA9807BCE434033FE7DC6858F4A40
53713	1	9	1442	16945	39424	\N	53.147038999999999	Липецкая область, Лев-Толстовский район, с.Круглое, ул.Поповка, 5		0101000020E6100000E02A4F20ECAA4340471E882CD2924A40
53709	1	9	1442	16745	39418	\N	53.252586999999998	Липецкая область, Лев-Толстовский район, пос. Красный, ул.Центральная, 2		0101000020E61000008CBB41B456B84340873254C554A04A40
53710	1	9	1442	16815	39420	\N	53.244812000000003	Липецкая область, Лев-Толстовский район, д.Котовка, ул.Центральная, 7		0101000020E610000079AC1919E4A643408DD5E6FF559F4A40
53719	1	9	1442	17240	39473	\N	53.238706000000001	Липецкая область, Лев-Толстовский район, с.Ильинка, ул.Школьная, 2		0101000020E6100000B1F7E28BF6CE4340F3AD0FEB8D9E4A40
53712	1	9	1442	16900	39231	\N	53.172502000000001	Липецкая область, Лев-Толстовский район, с.Золотуха, ул.Школьная, 8		0101000020E6100000C93846B247A243404F3FA88B14964A40
53707	1	9	1442	16642	39342	\N	53.284193999999999	Липецкая область, Лев-Толстовский район, с.Знаменское, ул.Промстроевская, 5		0101000020E6100000FB90B75CFDB2434016DC0F7860A44A40
53716	1	9	1442	17095	39362	\N	53.363725000000002	Липецкая область, Лев-Толстовский район, с.Загрядчино, ул.Молодежная, 15		0101000020E6100000959C137B68C943406ADE718A8EAE4A40
53705	1	9	1442	16537	39364	\N	53.339526999999997	Липецкая область, Лев-Толстовский район, с.Домачи, ул.Молодежная, 37		0101000020E6100000DE57E542E5B94340F38DE89E75AB4A40
53727	1	9	1442	17666	39456	\N	53.193828000000003	Липецкая область, Лев-Толстовский район, с.Головинщино, ул.Вязинская, 10		0101000020E61000008BA8893E1FD3434049861C5BCF984A40
53715	1	9	1442	17039	39287	\N	53.338951999999999	Липецкая область, Лев-Толстовский район, с.Гагино, ул.Центральная, 36		0101000020E610000040A374E95FD24340F77475C762AB4A40
53717	1	9	1442	17131	39309	\N	53.342027000000002	Липецкая область, Лев-Толстовский район, с.Гагарино, ул.Новая, 20		0101000020E610000015AB06616ED94340ACAC6D8AC7AB4A40
53718	1	9	1442	17190	39365	\N	53.375942000000002	Липецкая область, Лев-Толстовский район, д.Бычки, ул.Полевая, 16А		0101000020E6100000397B67B455E34340AF9811DE1EB04A40
53723	1	9	1442	17454	39472	\N	53.207901	Липецкая область, Лев-Толстовский район, с.Астапово, ул.Центральная, 12		0101000020E610000073F4F8BD4DC3434021E7FD7F9C9A4A40
53698	1	9	1315	16190	39471	\N	53.099161000000002	Липецкая область, Лебедянский район, с.Яблонево, ул.Школьная, 6		0101000020E610000096D05D12675B4340F304C24EB18C4A40
53695	1	9	1315	16035	39416	\N	53.046194999999997	Липецкая область, Лебедянский район, с.Шовское, ул.Бутырки, 2		0101000020E6100000DC8310902FB543408E1EBFB7E9854A40
53673	1	9	1315	14983	39469	\N	52.973061000000001	Липецкая область, Лебедянский район, с.Черепянь, ул.Школьная, 17		0101000020E6100000E3E2A8DC448D4340AC014A438D7C4A40
53678	1	9	1315	15231	39390	\N	53.080784999999999	Липецкая область, Лебедянский район, с.Хорошовка, ул.Большой Порядок, 91		0101000020E6100000F698486936834340F180B229578A4A40
53693	1	9	1315	15939	38863	\N	52.978293000000001	Липецкая область, Лебедянский район, с.Троекурово, ул.Ленина, 12		0101000020E610000020240B98C07B4340EF737CB4387D4A40
53671	1	9	1315	14892	39311	\N	52.914205000000003	Липецкая область, Лебедянский район, с.Теплое, ул.Кривка, 37		0101000020E6100000F25D4A5D329A43407B6B60AB04754A40
53675	1	9	1315	15067	39412	\N	53.083359000000002	Липецкая область, Лебедянский район, с.Сурки, ул.Новая, 44		0101000020E61000006C770FD07DB14340E469F981AB8A4A40
53692	1	9	1315	54782	39511	\N	53.034864654667302	Липецкая область, Лебедянский район, д.Старый Копыл, ул.Садовая, 84	Россия, Липецкая область, Лебедянский район, поселок Старо Копыл	0101000020E6100000DD96C805677443403563D17476844A40
53691	1	9	1315	54776	39502	\N	53.049406298729401	Липецкая область, Лебедянский район, с.Слободка, ул.Школьная, 98	Россия, Липецкая область, Лебедянский район, поселок Слободка	0101000020E6100000425A63D0096F4340F31C91EF52864A40
53670	1	9	1315	14854	39230	\N	52.907758999999999	Липецкая область, Лебедянский район, п.Сахарного завода, ул.Октябрьская, 56		0101000020E61000003563D1747688434028D3687231744A40
53684	1	9	1315	15530	39470	\N	53.125203999999997	Липецкая область, Лебедянский район, с.Романово, ул.Ермаковка, 164 б		0101000020E61000007EFD101B2C96434008AA46AF06904A40
53690	1	9	1315	15751	38835	\N	52.991109000000002	Липецкая область, Лебедянский район, сл.Покрово-Казацкая, ул.Серединка, 59 а		0101000020E6100000CA703C9F01954340B9E2E2A8DC7E4A40
53689	1	9	1315	15751	37440	\N	52.991109000000002	Липецкая область, Лебедянский район, сл.Покрово-Казацкая, ул.Воронежская, 35		0101000020E6100000CA703C9F01954340B9E2E2A8DC7E4A40
53687	1	9	1315	15645	39414	\N	52.863380999999997	Липецкая область, Лебедянский район, с.Павловское, ул.Почтовая, 75		0101000020E610000092CD55F31C9B43406F7EC344836E4A40
53680	1	9	1315	15315	\N	\N	52.915405	Липецкая область, Лебедянский район, с.Павелка, здание сельского клуба	Россия, Липецкая область, Лебедянский район, поселок Павелка	0101000020E6100000790261A758A7434025CCB4FD2B754A40
53683	1	9	1315	15464	39176	\N	53.086945	Липецкая область, Лебедянский район, с.Ольховец, ул.Школьная, 108 а		0101000020E61000003881E9B46E9743407EC68503218B4A40
53685	1	9	1315	15568	39305	\N	53.050147000000003	Липецкая область, Лебедянский район, с.Новое Ракитино, ул.Школьная, 220 а		0101000020E6100000944DB9C2BB9643400B7F86376B864A40
53668	1	9	1315	14754	\N	\N	52.905554000000002	Липецкая область, Лебедянский район, с.Мокрое, здание сельского клуба	Россия, Липецкая область, Лебедянский район, поселок Мокрое	0101000020E6100000DB19A6B6D4B5434089618731E9734A40
53667	1	9	1315	14691	39358	\N	52.919412000000001	Липецкая область, Лебедянский район, с.Михайловка, ул.Центральная, 21		0101000020E61000003C66A032FEBB434065C6DB4AAF754A40
53662	1	9	1315	13900	38864	\N	53.0137347856502	Липецкая область, Лебедянский район, г.Лебедянь, ул.Школьная, 10	Россия, Липецкая область, Лебедянский район, Лебедянь	0101000020E61000003CDD79E239914340C0E78711C2814A40
53651	1	9	1315	13900	38836	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Мира, 1		0101000020E6100000487023658B924340A75D4C33DD814A40
53655	1	9	1315	13900	37431	\N	53.014563000000003	Липецкая область, Лебедянский район, г.Лебедянь, ул.Ленина, 44		0101000020E6100000487023658B924340A75D4C33DD814A40
53656	1	9	1315	13900	38829	\N	53.015494716330302	Липецкая область, Лебедянский район, г.Лебедянь, ул.Карла Маркса, 57	Россия, Липецкая область, Лебедянский район, Лебедянь	0101000020E610000087DBA1613192434032207BBDFB814A40
53694	1	9	1315	15989	\N	\N	52.964291000000003	"Липецкая область, Лебедянский район, с.Курапово, здание конторы ЗАО ""Агрофирма имени 15 лет Октября"""	Россия, Липецкая область, Лебедянский район, поселок Курапово	0101000020E61000003561FBC918814340E06932E36D7B4A40
53696	1	9	1315	16099	39310	\N	53.054113999999998	Липецкая область, Лебедянский район, п.Культура, ул.Садовая, 1		0101000020E61000001899805F23BD4340BC202235ED864A40
53681	1	9	1315	15357	39419	\N	52.889305	Липецкая область, Лебедянский район, с.Куликовка Вторая, ул.Центральная, 10 а		0101000020E6100000C2DF2F664B844340AB9509BFD4714A40
53679	1	9	1315	15255	39177	\N	52.862076000000002	Липецкая область, Лебедянский район, с.Куймань, ул.Центральная, 22 б		0101000020E6100000F982161230A443405055A181586E4A40
53677	1	9	1315	15167	39360	\N	52.771366	Липецкая область, Лебедянский район, с.Каменная Лубна, ул.Школьная, 13		0101000020E6100000F2237EC51A904340889FFF1EBC624A40
53697	1	9	1315	16133	39278	\N	53.086101999999997	Липецкая область, Лебедянский район, п.Инициатор, ул.Трудовая, 22		0101000020E61000002CF015DD7AC14340620FED63058B4A40
53682	1	9	1315	15434	39442	\N	52.849302999999999	Липецкая область, Лебедянский район, с.Донские Избищи, ул.Центральная, 2 а		0101000020E610000055A4C2D84284434085B2F0F5B56C4A40
53676	1	9	1315	15119	39413	\N	52.795330999999997	Липецкая область, Лебедянский район, с.Докторово, ул.Ленина, 2 а		0101000020E61000007D40A033698543405B3FFD67CD654A40
53688	1	9	1315	15704	39313	\N	52.805692000000001	Липецкая область, Лебедянский район, с.Грязновка, ул.Центральная, 153		0101000020E6100000EFC7ED974F9E43400D535BEA20674A40
53674	1	9	1315	15034	39306	\N	53.023333000000001	Липецкая область, Лебедянский район, с.Вязово, ул.Центральная, 86		0101000020E6100000809D9B36E3A6434073F56393FC824A40
53672	1	9	1315	14953	39232	\N	52.964360999999997	Липецкая область, Лебедянский район, с.Волотово, ул.Центральная, 19		0101000020E6100000DD4598A25C8C4340D844662E707B4A40
53699	1	9	1315	16230	39363	\N	53.0985026531933	Липецкая область, Лебедянский район, д.Большой Верх, ул.Центральная, 16	Россия, Липецкая область, Лебедянский район, поселок Большой Верх	0101000020E610000044882B67EF5E434069C70DBF9B8C4A40
53669	1	9	1315	14795	39151	\N	52.921253	Липецкая область, Лебедянский район, с.Большое Попово, ул.Центральная, 25		0101000020E6100000B2D6506A2F8A4340C32B499EEB754A40
53666	1	9	1315	14661	39307	\N	52.96134	Липецкая область, Лебедянский район, с.Большие Избищи, ул.Большак, 220		0101000020E610000012691B7FA2B04340172B6A300D7B4A40
53665	1	9	1315	54764	39258	\N	53.039371001969101	Липецкая область, Лебедянский район, п.свх.Агроном, ул.Октябрьская, 14	Россия, Липецкая область, Лебедянский район, колхоз Агроном	0101000020E6100000B952CF825082434096B4E21B0A854A40
53664	1	9	1315	54751	39092	\N	53.039577932758199	Липецкая область, Лебедянский район, п.свх.Агроном, ул.Советская, 22	Россия, Липецкая область, Лебедянский район, колхоз Агроном	0101000020E610000006D50627A28143400FD253E410854A40
53648	1	9	1229	13803	39304	\N	52.820981000000003	Липецкая область, Краснинский район, с.Яблоново, ул.Советская, 23		0101000020E6100000D122DBF97E78434096D1C8E715694A40
53644	1	9	1229	13615	39411	\N	53.034229000000003	Липецкая область, Краснинский район, д.Щербаково, ул.Центральная, 14		0101000020E610000004560E2DB255434093C9A99D61844A40
53647	1	9	1229	13731	39408	\N	52.927719993082697	Липецкая область, Краснинский район, с.Суходол, ул.Торговая, 9	Россия, Липецкая область, Краснинский район, поселок Суходол	0101000020E6100000AF7D01BD704943402DEC6987BF764A40
53642	1	9	1229	13525	39303	\N	52.978591000000002	Липецкая область, Краснинский район, с.Сотниково, ул.Парковая, 1		0101000020E610000087A2409FC859434079944A78427D4A40
53636	1	9	1229	54788	39520	\N	53.018986157586099	Липецкая область, Краснинский район, с.Сергиевское первое, ул.Новая, 14	Россия, Липецкая область, Краснинский район, поселок Сергиевское	0101000020E610000029E78BBD176B43407A8A1C226E824A40
53646	1	9	1229	13652	39417	\N	52.885252000000001	Липецкая область, Краснинский район, с.Решетово-Дуброво, ул.Центральная, 11		0101000020E61000007905A22765504340FB5B02F04F714A40
53621	1	9	1229	12506	39175	\N	53.059764999999999	Липецкая область, Измалковский район, с. Пятницкое, Клубная, 2		0101000020E61000000A9DD7D82556434004392861A6874A40
53643	1	9	1229	13557	39466	\N	53.012450000000001	Липецкая область, Краснинский район, д.Половнево, ул.Центральная, 2		0101000020E610000034BE2F2E554F4340E86A2BF697814A40
53631	1	9	1229	12991	39300	\N	52.778078000000001	Липецкая область, Краснинский район, д.Морево, ул.Клубная, 36		0101000020E6100000DA03ADC0904D434059DE550F98634A40
53649	1	9	1229	13834	39117	\N	52.878644000000001	Липецкая область, Краснинский район, пос.Лески, ул.Мира, 4		0101000020E610000054A703594F7F4340CF69166877704A40
53630	1	9	1229	12951	39357	\N	52.824987	Липецкая область, Краснинский район, д.Лаухино, ул.Цветочная, 3а		0101000020E61000008E588B4F014C434005508C2C99694A40
53637	1	9	1229	13273	38862	\N	52.866528000000002	Липецкая область, Краснинский район, с.Красное, ул.Первомайская, 20		0101000020E61000009ACE4E0647654340BE88B663EA6E4A40
53639	1	9	1229	13273	39137	\N	52.866528000000002	Липецкая область, Краснинский район, с.Красное, ул.Октябрьская, 73		0101000020E61000009ACE4E0647654340BE88B663EA6E4A40
53638	1	9	1229	13273	38861	\N	52.866528000000002	Липецкая область, Краснинский район, с.Красное, ул.Красноармейская, 6		0101000020E61000009ACE4E0647654340BE88B663EA6E4A40
53627	1	9	1229	54750	39079	\N	52.854061801515101	Липецкая область, Краснинский район, пос.Краснинский, ул.Парковая, 15а		0101000020E61000007EC3448314644340D06053E7516D4A40
53633	1	9	1229	13081	39302	\N	52.769753000000001	Липецкая область, Краснинский район, д.Корытное, ул.Клубная, 51		0101000020E610000047C7D5C8AE604340BB7F2C4487624A40
53634	1	9	1229	13142	39369	\N	52.959572000000001	Липецкая область, Краснинский район, с.Ищеино, ул.Школьная, 22		0101000020E61000000BD3F71A8267434023145B41D37A4A40
53628	1	9	1229	12875	\N	\N	52.825595999999997	Липецкая область, Краснинский район, д.Знаменка, здание сельского клуба, 63		0101000020E6100000EF2076A6D05D4340ADDA3521AD694A40
53641	1	9	1229	13459	\N	\N	52.881464000000001	Липецкая область, Краснинский район, д.Епанчино, здание Дома культуры, 45		0101000020E61000000ABDFE243E714340F94CF6CFD3704A40
53640	1	9	1229	13417	39116	\N	52.866061000000002	Липецкая область, Краснинский район, д.Дегтевая, ул.Центральная, 24		0101000020E6100000E17A14AE47594340A8AB3B16DB6E4A40
53635	1	9	1229	13179	39356	\N	52.930297000000003	Липецкая область, Краснинский район, с.Верхнее Брусланово, ул.Школьная, 24		0101000020E6100000C119FCFD627843409148DBF813774A40
53632	1	9	1229	13048	39135	\N	52.768822	Липецкая область, Краснинский район, с.Верхнедрезгалово, ул.Парковая, 26		0101000020E61000008F554ACFF4664340003961C268624A40
53629	1	9	1229	12903	\N	\N	52.845235000000002	Липецкая область, Краснинский район, с.Бредихино, здание муниципального учреждения ДЦК, 19		0101000020E610000018D1764CDD6D4340A03715A9306C4A40
53611	1	9	1081	12081	39407	\N	52.625064999999999	Липецкая область, Измалковский район, д. Ясенок, ул. Советская, 6		0101000020E61000009642209738064340E76F422102504A40
53614	1	9	1081	12224	39410	\N	52.579439000000001	Липецкая область, Измалковский район, с. Черник, ул. Центральная, 4		0101000020E6100000014F5AB8ACFE42407383A10E2B4A4A40
53626	1	9	1081	12755	38859	\N	52.486342999999998	Липецкая область, Измалковский район, с. Чернава, ул. Первомайская, 260		0101000020E610000013471E882C064340BBD1C77C403E4A40
53625	1	9	1081	12755	38859	\N	52.486342999999998	Липецкая область, Измалковский район, с. Чернава, ул. Первомайская, 124		0101000020E610000013471E882C064340BBD1C77C403E4A40
53624	1	9	1081	12697	\N	\N	52.656059999999997	Липецкая область, Измалковский район, с. Чермошное, 39		0101000020E6100000F836FDD98FEE42405C1B2AC6F9534A40
53602	1	9	1081	11636	39404	\N	52.728467999999999	Липецкая область, Измалковский район, д. Сухой Семенек, ул. Школьная, 69		0101000020E610000027C11BD2A8F442405D177E703E5D4A40
53623	1	9	1081	54789	39521	\N	52.7030142704536	Липецкая область, Измалковский район, с. Слобода, ул. Маяковского, 24	Россия, Липецкая область, Измалковский район, поселок Слобода	0101000020E61000008D9944BDE0F34240A950DD5CFC594A40
53622	1	9	1081	12608	39402	\N	52.419711999999997	Липецкая область, Измалковский район, с. Ровенка, ул. Московская, 21		0101000020E610000033A48AE255F842408FDE701FB9354A40
53617	1	9	1081	12317	39115	\N	52.576182000000003	Липецкая область, Измалковский район, с. Преображенье, Ленина, 8		0101000020E61000000D6E6B0BCFED42409E45EF54C0494A40
53608	1	9	1081	11925	39299	\N	52.708426000000003	Липецкая область, Измалковский район, с. Предтечево, ул. имени Белякова, 16		0101000020E6100000C1012D5DC10843406CD102B4AD5A4A40
53610	1	9	1081	12024	\N	\N	52.863222999999998	Липецкая область, Измалковский район, с. Полевые Локотцы, 13		0101000020E610000070ECD97399F04240D7135D177E6E4A40
53612	1	9	1081	12114	39133	\N	52.633799000000003	Липецкая область, Измалковский район, д. Панкратовка, ул. Школьная, 18		0101000020E6100000B6BC72BD6D0E4340679E5C5320514A40
53613	1	9	1081	12180	39276	\N	52.634602999999998	Липецкая область, Измалковский район, д. Недоходовка, ул. Центральная, 54		0101000020E6100000E9995E622CFB4240C478CDAB3A514A40
53603	1	9	1081	11683	39409	\N	52.68759	Липецкая область, Измалковский район, с. Мягкое, ул. Молодежная, 16		0101000020E61000008A1F63EE5A1843404087F9F202584A40
53607	1	9	1081	11867	39387	\N	52.674290999999997	Липецкая область, Измалковский район, д. Мульгино, ул. Центральная, 13		0101000020E61000003752B648DAF742405A7EE02A4F564A40
53609	1	9	1081	11953	39355	\N	52.881075032519497	Липецкая область, Измалковский район, с. Лебяжье, ул. Луговая, 16	Россия, Липецкая область, Измалковский район, поселок Лебяжье	0101000020E61000005E0F26C5C7FD42405F29CB10C7704A40
53605	1	9	1081	11755	38969	\N	52.689205999999999	Липецкая область, Измалковский район, с. Измалково, ул. Советская, 53А		0101000020E61000006FB88FDC9AFC42407E1AF7E637584A40
53604	1	9	1081	11755	38970	\N	52.689205999999999	Липецкая область, Измалковский район, с. Измалково, ул. Ленина, 38		0101000020E61000006FB88FDC9AFC42407E1AF7E637584A40
53600	1	9	1081	11546	39335	\N	52.593395999999998	Липецкая область, Измалковский район, д. Иваницкое-Троицкое, ул. Центральная, 4		0101000020E610000021037976F9204340E2C96E66F44B4A40
53599	1	9	1081	11506	39354	\N	52.514108704766201	Липецкая область, Измалковский район, д. Денисово, ул. Поселковая, 1	Россия, Липецкая область, Измалковский район, поселок Денисово	0101000020E61000003D450E113713434025CADE52CE414A40
53619	1	9	1081	12452	\N	\N	52.527957999999998	Липецкая область, Измалковский район, с. Гниловоды, 22		0101000020E6100000030B60CAC0EF4240AED4B32094434A40
53598	1	9	1081	11452	39298	\N	52.529781999999997	Липецкая область, Измалковский район, с. Власово, ул. Центральная, 20		0101000020E61000008E5A61FA5E174340360186E5CF434A40
53601	1	9	1081	11588	39403	\N	52.762135999999998	Липецкая область, Измалковский район, с. Васильевка, ул. Центральная, 88		0101000020E61000005C1D007157FF4240588D25AC8D614A40
53618	1	9	1081	12432	39399	\N	52.511918999999999	Липецкая область, Измалковский район, с. Быково, ул. Центральная, 53		0101000020E610000034F44F70B1F84240BB99D18F86414A40
53596	1	9	1081	11359	39338	\N	52.571956999999998	Липецкая область, Измалковский район, с. Афанасьево, пер. Школьный, 1		0101000020E6100000043DD4B661184340F0DB10E335494A40
53597	1	9	1081	11359	39194	\N	52.571956999999998	Липецкая область, Измалковский район, с. Афанасьево, ул. Елецкая, 145		0101000020E6100000043DD4B661184340F0DB10E335494A40
53594	1	9	1012	11255	39467	\N	52.359557000000002	Липецкая область, Задонский муниципальный район, с. Яблоново, Центральная, 4		0101000020E61000003DB9A640665F43402106BAF6052E4A40
53595	1	9	1012	11299	39296	\N	52.342680999999999	Липецкая область, Задонский муниципальный район, с. Юрьево, Советская, 25		0101000020E61000009014916115634340F4FA93F8DC2B4A40
53582	1	9	1012	10711	39346	\N	52.496405000000003	Липецкая область, Задонский муниципальный район, с. Черниговка, Молодежная, 49		0101000020E61000009373620FED8B43401349F4328A3F4A40
53591	1	9	1012	11075	39139	\N	52.468972000000001	Липецкая область, Задонский муниципальный район, с. Хмелинец, Степанищева, 68		0101000020E61000003B8BDEA980714340AF5E4546073C4A40
53590	1	9	1012	11075	39139	\N	52.468972000000001	Липецкая область, Задонский муниципальный район, с. Хмелинец, Степанищева, 79		0101000020E61000003B8BDEA980714340AF5E4546073C4A40
53552	1	9	1012	9255	39226	\N	52.355761999999999	"Липецкая область, Задонский муниципальный район,с.Уткино, Центральная, 107""а"""		0101000020E6100000E5603601867B43406C94F59B892D4A40
53568	1	9	1012	10022	\N	\N	52.401985000000003	Липецкая область,Задонский муниципальный район, д. Успеновка, 3, кв.3		0101000020E610000033DFC14F1C584340C53D963E74334A40
53554	1	9	1012	9312	39490	\N	52.413961	"Липецкая область, Задонский муниципальный район, с. Тюнино, Карла-Маркса, 2""ж"""		0101000020E61000003BAB05F698764340E4688EACFC344A40
53585	1	9	1012	10846	39341	\N	52.701087000000001	Липецкая область,Задонский муниципальный район, с. Тростяное, Школьная, 5		0101000020E6100000ECF82F10048043404C530438BD594A40
53586	1	9	1012	54791	39524	\N	52.503793106188802	Липецкая область, Задонский муниципальный район, пос. Тимирязево, Дорожная, 1	Россия, Липецкая область, Задонский район, поселок Тимирязев	0101000020E61000005951836918624340147AFD497C404A40
53553	1	9	1012	9296	39386	\N	52.373398000000002	Липецкая область,Задонский муниципальный район, д. Тешевка, Задонская, 120		0101000020E6100000236937FA9879434027327381CB2F4A40
53579	1	9	1012	10587	39336	\N	52.247576000000002	Липецкая область,Задонский муниципальный район, с. Сцепное, Клубная, 1		0101000020E6100000BAD7497D5974434023A30392B01F4A40
53559	1	9	1012	54772	39359	\N	52.338458222552497	Липецкая область, Задонский муниципальный район, д. Старая Воскресеновка, Сосновая, 94	Россия, Липецкая область, Задонский район, поселок Старо Воскресеновка	0101000020E610000025EB707495844340E8887C97522B4A40
53583	1	9	1012	10775	39332	\N	52.667017000000001	Липецкая область, Задонский муниципальный район, с. Скорняково, Советская, 16		0101000020E61000001FBAA0BE65764340227024D060554A40
53581	1	9	1012	10655	39337	\N	52.561447000000001	Липецкая область, Задонский муниципальный район, с. Рогожино, Школьная, 23		0101000020E6100000D55DD90583874340FAB7CB7EDD474A40
53572	1	9	1012	10241	39293	\N	52.396972890457903	Липецкая область, Задонский муниципальный район, с.Репец, Покровская, 2	Россия, Липецкая область, Задонский район, поселок Репец	0101000020E610000082A8FB00A48643409032E202D0324A40
53569	1	9	1012	10089	39113	\N	52.384782999999999	Липецкая область, Задонский муниципальный район, с. Паниковец, Запрудная, 2		0101000020E610000036CB65A3736A43404487C09140314A40
53577	1	9	1012	10469	39247	\N	52.269477000000002	Липецкая область, Задонский муниципальный район, пос. Освобождение, Заводская, 18		0101000020E6100000E5D3635B066643401903EB387E224A40
53551	1	9	1012	9182	39385	\N	52.355339000000001	Липецкая область,Задонский муниципальный район ,с. Нижнее Казачье, Центральная, 52		0101000020E61000008D4127840E68434026FF93BF7B2D4A40
53574	1	9	1012	54790	39522	\N	52.440386118216203	Липецкая область, Задонский муниципальный район, с. Мирное, Кленовая, 3	Россия, Липецкая область, Задонский район	0101000020E61000004DF38E5374784340E1CE85915E384A40
53548	1	9	1012	9087	39340	\N	52.462899	Липецкая область,Задонский муниципальный район,д.Ливенская, Молодежная, 14		0101000020E61000004C5299620E6A4340F12C4146403B4A40
53575	1	9	1012	10375	39114	\N	52.289127993174503	Липецкая область, Задонский муниципальный район, с Ксизово, Центральная, 71	Россия, Липецкая область, Задонский район, поселок Ксизово	0101000020E6100000C34A051555794340CF2D742502254A40
38647	1	6	\N	54182	35225	\N	54.741078000000002	гор.Юхнов, ул.Билибина, 40		0101000020E6100000AC1919E42E9E41407EE4D6A4DB5E4B40
53588	1	9	1012	9013	39512	\N	52.432412853895201	Липецкая область, Задонский муниципальный район, пос. Колодезское, Солнечная, 8	Россия, Липецкая область, Задонский район, поселок Колодезная	0101000020E61000002009FB7612714340C0AE264F59374A40
53547	1	9	1012	9013	39462	\N	52.429228999999999	Липецкая область, Задонский муниципальный район , д.Колодезная, Мира, 19		0101000020E61000007171546EA270434055BFD2F9F0364A40
53593	1	9	1012	11157	39454	\N	52.471972999999998	Липецкая область, Задонский муниципальный район, д.1е Колесово,ул.Молодежная 1 (здание сахзавода)		0101000020E610000050172994856D434029CC7B9C693C4A40
53573	1	9	1012	10247	39295	\N	52.482306999999999	Липецкая область, Задонский муниципальный район, с. Кашары, Донская, 24		0101000020E6100000A96A82A8FB7A4340E1D05B3CBC3D4A40
53571	1	9	1012	10165	39464	\N	52.398071999999999	Липецкая область, Задонский муниципальный район, с.Камышевка, Центральная, 83		0101000020E61000006C5A2904728B434006BAF605F4324A40
53567	1	9	1012	9951	39453	\N	52.378692999999998	Липецкая область, Задонский муниципальный район, с. Каменка, Центральная, 1		0101000020E61000004BCD1E6805624340B01C210379304A40
53566	1	9	1012	9935	39111	\N	52.288640000000001	Липецкая область, Задонский муниципальный район, с. Калабино, Весенняя, 21		0101000020E61000009C31CC09DA604340A228D027F2244A40
53557	1	9	1012	9448	39465	\N	52.588209999999997	Липецкая область, Задонский муниципальный район, с. Казино, Центральная, 75		0101000020E61000001B9DF3531C9143400F971C774A4B4A40
53544	1	9	1012	54739	39038	\N	52.394230281183297	"Липецкая область ,Задонский  муниципальный  район, городское поселение город  Задонск, Советская, 109 ""а"""	Россия, Липецкая область, Задонский район, Задонск	0101000020E6100000E09C11A5BD774340118DEE2076324A40
53541	1	9	1012	54739	38972	\N	52.395811219855503	"Липецкая область, Задонский муниципальный район, городское поселение г. Задонск, Свободы, 57""а"""	Россия, Липецкая область, Задонский район, Задонск	0101000020E610000043572250FD754340D33252EFA9324A40
53565	1	9	1012	9868	39275	\N	52.626694000000001	Липецкая область, Задонский муниципальный район, пос. Донской Рудник, Первомайская, 16		0101000020E61000009E44847F11824340BA4C4D8237504A40
53564	1	9	1012	9633	39389	\N	52.616109000000002	Липецкая область, Задонский муниципальный район, с. Донское, Свердлова, 201а		0101000020E6100000001B1021AE7C4340B9E2E2A8DC4E4A40
53562	1	9	1012	9633	39174	\N	52.616109000000002	Липецкая область, Задонский муниципальный район, с. Донское, Октябрьская, 38		0101000020E6100000001B1021AE7C4340B9E2E2A8DC4E4A40
53563	1	9	1012	9633	38931	\N	52.616109000000002	Липецкая область, Задонский муниципальный район, с. Донское, Мира, 19		0101000020E6100000001B1021AE7C4340B9E2E2A8DC4E4A40
53561	1	9	1012	9633	39405	\N	52.616109000000002	Липецкая область, Задонский муниципальный район, с. Донское, Новая, 1		0101000020E6100000001B1021AE7C4340B9E2E2A8DC4E4A40
53578	1	9	1012	10530	39294	\N	52.254841999999996	Липецкая область, Задонский муниципальный район, с. Дегтевое, Ерисова, 27		0101000020E6100000A9674128EF6F4340D8D2A3A99E204A40
53558	1	9	1012	9511	38987	\N	52.320899580368703	Липецкая область, Задонский муниципальный район, с. Гнилуша, Ленина, 69	Россия, Липецкая область, Задонский район, поселок Гнилуша	0101000020E61000007FBE2D58AA8B4340A9A44E4013294A40
53560	1	9	1012	54777	39503	\N	52.601810000042498	Липецкая область,Задонский муниципальный район, д.Г-Гора, Рабочая, 74	Россия, Липецкая область, Задонский район, поселок Галичья Гора	0101000020E6100000ADBF2500FF724340F0332E1C084D4A40
53584	1	9	1012	10801	39491	\N	52.749377000000003	Липецкая область, Задонский муниципальный район, с. Гагарино, Молодежная, 1		0101000020E6100000B1BFEC9E3C7A4340F3AFE595EB5F4A40
53555	1	9	1012	9376	39138	\N	52.601782	Липецкая область, Задонский муниципальный район, с. Верхний Студенец, Центральная, 90		0101000020E6100000079623642087434026A94C31074D4A40
53550	1	9	1012	9166	39291	\N	52.346603000000002	"Липецкая область, Задонский муниципальный район , с.Верхнее Казачье, Молодежная, 31""а"""		0101000020E610000084807C091572434006D9B27C5D2C4A40
53549	1	9	1012	9133	39468	\N	52.547184000000001	Липецкая область, Задонский муниципальный район,с.Бутырки, Центральная, 2		0101000020E61000004AD40B3ECD7B43407E7214200A464A40
53546	1	9	1012	8996	39228	\N	52.414279999999998	Липецкая область,Задонский муниципальный район,с.Болховское, Центральная, 3		0101000020E61000005EBC1FB75F6E434085B1852007354A40
53570	1	9	1012	54771	\N	\N	52.381968075101099	Липецкая область, Задонский муниципальный район, д, Большое Панарино, 83,кв.2	Россия, Липецкая область, Задонский район, поселок Болальшое Панарино	0101000020E6100000F2D077B7B27243402C0FD253E4304A40
53576	1	9	1012	10406	39297	\N	52.293317000000002	Липецкая область, Задонский муниципальный район,с. Балахна, Центральная, 47		0101000020E610000089D00836AE6D4340302E55698B254A40
53580	1	9	1012	10616	\N	\N	52.2167424723891	Липецкая область, Задонский муниципальный район, д.Алексеевка, 1	Россия, Липецкая область, Задонский район, поселок Алексеевка	0101000020E6100000DDB419A721664340B7D5AC33BE1B4A40
53518	1	9	914	7655	39447	\N	52.520291999999998	Липецкая область, Елецкий район, д.Чернышевка, Клубная, 31		0101000020E6100000F1F44A59863643406A2FA2ED98424A40
53539	1	9	914	8682	39249	\N	52.692819	Липецкая область, Елецкий район, с.Черкассы, Советская, 6		0101000020E61000002A029CDEC55B43401286014BAE584A40
53534	1	9	914	8431	37430	\N	52.6524	Липецкая область, Елецкий район, д.Хмелинец, Совхозная		0101000020E61000002FA4C3431839434088F4DBD781534A40
53587	1	9	914	54779	39507	\N	52.542822083200598	Липецкая область, Задонский муниципальный район, ж.д.с.Улусарка, Садовая, 13 а		0101000020E610000009FD4CBD6E57434050C6F8307B454A40
53522	1	9	914	7827	39459	\N	52.670921	Липецкая область, Елецкий район, д.Трубицино, Центральная, 77		0101000020E6100000344C6DA9835243408D9944BDE0554A40
38495	1	6	\N	1634	35412	\N	55.106453999999999	город Обнинск, ул.Гурьянова, 13		0101000020E61000006E4F90D8EE4C4240A243E048A08D4B40
53509	1	9	914	7252	38880	\N	52.592379000000001	Липецкая область, Елецкий район, п.Солидарность, Первомайская, 2		0101000020E6100000340EF5BBB049434029EB3713D34B4A40
53536	1	9	914	8526	38967	\N	52.618242000000002	Липецкая область, Елецкий район, п.Соколье, Лорха, 12		0101000020E61000008272DBBE475D4340BF81C98D224F4A40
53519	1	9	914	7690	39455	\N	52.467485000000003	Липецкая область, Елецкий район, с.Паниковец, Клубная, 31		0101000020E61000003D29931ADA2E43406F2F698CD63B4A40
53532	1	9	914	8324	39172	\N	52.583514999999998	Липецкая область, Елецкий район, с.Ольховец, Школьная		0101000020E6100000F10F5B7A342F4340DBDC989EB04A4A40
53533	1	9	914	8397	39171	\N	52.565207999999998	Липецкая область, Елецкий район, с.Нижний Воргол, Клубная		0101000020E61000008411FB045034434002B859BC58484A40
53513	1	9	914	7424	39169	\N	52.493878000000002	Липецкая область, Елецкий район, п.Маяк, Школьная, 8		0101000020E61000004DDA54DD23214340611BF164373F4A40
53530	1	9	914	8235	39227	\N	52.445056999999998	Липецкая область, Елецкий район, с.Малая Боевка, Мира, 35		0101000020E6100000C79DD2C1FA4743408DEDB5A0F7384A40
53529	1	9	914	8179	38928	\N	52.576439999999998	Липецкая область, Елецкий район, с.Лавы, Северная, 3-а		0101000020E61000001CEDB8E1773F4340990D32C9C8494A40
53516	1	9	914	7569	39274	\N	52.534618999999999	Липецкая область, Елецкий район, с.Крутое, Транспортная, 10		0101000020E61000005B61FA5E432E4340FD6838656E444A40
53535	1	9	914	54774	\N	\N	52.639260182314899	Липецкая область, Елецкий район, жд ст.Телегино, п.Капани		0101000020E610000063D34A21903543400BD28C45D3514A40
53537	1	9	914	8570	38858	\N	52.457344999999997	Липецкая область, Елецкий район, с.Каменское, Октябрьская, 4		0101000020E610000013B534B7425043409BFEEC478A3A4A40
53528	1	9	914	8120	38828	\N	52.585988	Липецкая область, Елецкий район, д.Казинка, Клубная, 2		0101000020E6100000833463D1744443409AEC9FA7014B4A40
53524	1	9	914	7929	38966	\N	52.620767999999998	Липецкая область, Елецкий район, с.Казаки, Мира, 55		0101000020E61000002C8194D8B5214340A0336953754F4A40
53525	1	9	914	7929	38927	\N	52.620767999999998	Липецкая область, Елецкий район, с.Казаки, Заводская, 96		0101000020E61000002C8194D8B5214340A0336953754F4A40
53527	1	9	914	8072	39292	\N	52.466849000000003	Липецкая область, Елецкий район, д.Ивановка, Центральная, 4		0101000020E6100000A0DD21C500534340CD9541B5C13B4A40
53538	1	9	914	8072	39401	\N	52.467343719497997	Липецкая область, Елецкий район, д.Ивановка, Рабочая, 45	Россия, Липецкая область, Елецкий район, поселок Ивановка	0101000020E6100000D57B2AA73D534340ACFD9DEDD13B4A40
53540	1	9	914	8701	39461	\N	52.686771	Липецкая область, Елецкий район, с.Ериловка, 40 лет Победы		0101000020E61000004145D5AF74624340AD6BB41CE8574A40
53521	1	9	914	7788	39112	\N	52.633346000000003	Липецкая область, Елецкий район, п.Елецкий, 50лет Октября, 2		0101000020E6100000B2BCAB1E30494340B686527B11514A40
53512	1	9	914	7403	39450	\N	52.557510999999998	Липецкая область, Елецкий район, д.Екатериновка, Клубная, 30		0101000020E610000048A819524559434083143C855C474A40
53520	1	9	914	7732	39397	\N	52.693801999999998	Липецкая область, Елецкий район, с.Голиково, Центральная, 23		0101000020E61000003F8F519E796B43401FF30181CE584A40
53531	1	9	914	54734	38930	\N	52.600953752714602	Липецкая область, Елецкий район, п.Газопровод, Советская	Россия, Липецкая область, Елецкий район, поселок Ключ Жизни	0101000020E6100000317DAF21383843404033880FEC4C4A40
53517	1	9	914	7612	38875	\N	52.527596000000003	Липецкая область, Елецкий район, с.Воронец, Клубная, 17		0101000020E6100000EDD808C4EB3E43400EC0064488434A40
53515	1	9	914	7535	39460	\N	52.525536000000002	Липецкая область, Елецкий район, д.Волчье, Придорожная, 14		0101000020E6100000973AC8EBC1244340726F7EC344434A40
53511	1	9	914	7339	39396	\N	52.546394999999997	Липецкая область, Елецкий район, д.Большие Извалы, Советская, 5		0101000020E610000068CC24EA0561434055D97745F0454A40
53510	1	9	914	7298	39277	\N	52.562871000000001	Липецкая область, Елецкий район, с.Архангельское, Клубная, 16		0101000020E6100000B0AF75A9114E4340F46E2C280C484A40
53523	1	9	914	7878	39458	\N	52.683649000000003	Липецкая область, Елецкий район, с.Аргамач-Пальна, Библиотечная, 11		0101000020E6100000419FC893A44B4340B87878CF81574A40
53432	1	9	492	54773	39383	\N	52.3358077697361	Липецкая область, Долгоруковский муниципальный район, п.Тимирязевский, Фруктовая, Здание дома культуры	Россия, Липецкая область, Долгоруковский район, поселок 1-е отделение имени Тимирязева	0101000020E61000003B1DC87A6A2743401ADEACC1FB2A4A40
53442	1	9	492	3746	39394	\N	52.303269	Липецкая область, Долгоруковский муниципальный район, д.Тепленькая Первая, Тепленькая, 41		0101000020E610000008E57D1CCD4743400072C284D1264A40
53454	1	9	492	4387	39398	\N	52.409670505347201	Липецкая область, Долгоруковский муниципальный район, с.Стрелец, Архангельская, 20		0101000020E6100000B933130CE71C4340508F6D1970344A40
53457	1	9	492	4559	38956	\N	52.411186999999998	Липецкая область, Долгоруковский муниципальный район, с.Стегаловка, Центральная, 24		0101000020E6100000CBF6216FB92843402AC58EC6A1344A40
53438	1	9	492	3543	39273	\N	52.334135000000003	Липецкая область, Долгоруковский муниципальный район, с.Слепуха, Центральная, 15		0101000020E610000038143E5B0751434078B988EFC42A4A40
53456	1	9	492	4494	39445	\N	52.455638999999998	Липецкая область, Долгоруковский муниципальный район, с.Свишни, Соборная, 6		0101000020E610000016DBA4A2B12043401DE4F560523A4A40
53436	1	9	492	3448	\N	\N	52.370593999999997	Липецкая область, Долгоруковский муниципальный район, д.Пашинино, Здание дома культуры	Россия, Липецкая область, Долгоруковский район, поселок Пашинино	0101000020E61000000AF65FE7A63B4340020CCB9F6F2F4A40
53444	1	9	492	3839	39352	\N	52.255526000000003	Липецкая область, Долгоруковский муниципальный район, с.Нижний Ломовец, Речная, 60		0101000020E6100000D9CD8C7E345243408CA37213B5204A40
53445	1	9	492	3916	39271	\N	52.254721000000004	Липецкая область, Долгоруковский муниципальный район, с.Меньшой Колодезь, Дорожная, 21		0101000020E6100000D4D688601C3643405E4D9EB29A204A40
38522	1	6	\N	1634	35352	\N	55.094183999999998	город Обнинск, ул.Гастелло, 17		0101000020E610000087C43D963E5042403AE7A7380E8C4B40
53449	1	9	492	4127	39272	\N	52.322566000000002	Липецкая область, Долгоруковский муниципальный район, д.Красотыновка, Школьная, 22		0101000020E610000029CE5147C71543409966BAD749294A40
53435	1	9	492	3409	\N	\N	52.362197000000002	Липецкая область, Долгоруковский муниципальный район, с.Красное, Евгения Рощупкина, Здание фельдшерского пункта	Россия, Липецкая область, Долгоруковский район, поселок Красное	0101000020E6100000A45016BEBE284340CBDAA6785C2E4A40
53440	1	9	492	54775	39392	\N	52.2962439607509	Липецкая область, Долгоруковский муниципальный район, с.Карташовка, Нижняя, 13	Россия, Липецкая область, Долгоруковский район, поселок Карташевка	0101000020E6100000062CB98AC54B434070D1C952EB254A40
53452	1	9	492	4270	39444	\N	52.418854300379898	Липецкая область, Долгоруковский муниципальный район, с.Войсковая Казинка, Центральная, 11	Россия, Липецкая область, Долгоруковский район, поселок Казинка Войсковая	0101000020E61000000798F90E7E0A43403FE603029D354A40
53441	1	9	492	54769	39301	\N	52.312979708536297	Липецкая область, Долгоруковский муниципальный район, с.Жерновное, Центральная, 30	Россия, Липецкая область, Долгоруковский район, поселок Жерновое	0101000020E6100000E8667FA0DC3C4340AB2688BA0F284A40
53434	1	9	492	3326	39105	\N	52.329391000000001	Липецкая область, Долгоруковский муниципальный район, д.Екатериновка, Школьная, Здание дома культуры		0101000020E6100000E01115AA9B314340624CFA7B292A4A40
53448	1	9	492	4060	39134	\N	52.273085999999999	Липецкая область, Долгоруковский муниципальный район, с.Дубовец, Центральная, 3		0101000020E61000007B336ABE4A1843406B7F677BF4224A40
53439	1	9	492	3626	39351	\N	52.296593999999999	Липецкая область, Долгоруковский муниципальный район, с.Долгуша, Центральная, 1		0101000020E6100000D1066003225643404C18CDCAF6254A40
53427	1	9	492	2943	38821	\N	52.325860190956298	Липецкая область, Долгоруковский муниципальный район, с.Долгоруково, Тимирязева, 3	Россия, Липецкая область, Долгоруковский район, поселок Долгоруково	0101000020E6100000A59E05A1BC2B43408B89CDC7B5294A40
53429	1	9	492	2943	39173	\N	52.322071000000001	Липецкая область, Долгоруковский муниципальный район, с.Долгоруково, Терешковой, 19		0101000020E6100000C11F7EFE7B2C4340B9FE5D9F39294A40
53428	1	9	492	2943	38822	\N	52.322071000000001	Липецкая область, Долгоруковский муниципальный район, с.Долгоруково, Советская, 32		0101000020E6100000C11F7EFE7B2C4340B9FE5D9F39294A40
53430	1	9	492	2943	39128	\N	52.322071000000001	Липецкая область, Долгоруковский муниципальный район, с.Долгоруково, Мира, Здание автохозяйства		0101000020E6100000C11F7EFE7B2C4340B9FE5D9F39294A40
53453	1	9	492	4329	39290	\N	52.439326000000001	Липецкая область, Долгоруковский муниципальный район, с.Грызлово, Рягузова, 1		0101000020E6100000B56FEEAF1E194340292499D53B384A40
53451	1	9	492	4241	39349	\N	52.373756	Липецкая область, Долгоруковский муниципальный район, с.Вязовое, Молодежная, 17		0101000020E61000005A46EA3D951543408657923CD72F4A40
53450	1	9	492	4174	39107	\N	52.348292000000001	Липецкая область, Долгоруковский муниципальный район, д.Веселая, Молодежная, 22		0101000020E6100000B30B06D7DC094340AEBA0ED5942C4A40
53443	1	9	492	3821	39167	\N	52.237456999999999	Липецкая область, Долгоруковский муниципальный район, с.Верхний Ломовец, Центральная, 99		0101000020E61000003A90F5D4EA4D4340679AB0FD641E4A40
53431	1	9	492	3185	39131	\N	52.306584000000001	Липецкая область, Долгоруковский муниципальный район, с.Братовщина, Власова, Здание дома культуры		0101000020E6100000209738F2402A43400ABDFE243E274A40
53446	1	9	492	3939	39269	\N	52.228963	Липецкая область, Долгоруковский муниципальный район, д.Большой Колодезь, Центральная, 7		0101000020E6100000FCA9F1D24D3C43403D7FDAA84E1D4A40
53437	1	9	492	3513	39106	\N	52.390900999999999	Липецкая область, Долгоруковский муниципальный район, с.Большая Боевка, Школьная, 12		0101000020E610000065A88AA9F4454340A27C410B09324A40
53455	1	9	492	32509	\N	\N	52.494107999999997	Липецкая область, Долгоруковский муниципальный район, д.Набережная Вторая, Здание фельдшерского пункта	Россия, Липецкая область, Долгоруковский район, поселок 2-я Набережная	0101000020E61000002CD49AE61D174340925852EE3E3F4A40
53400	1	9	286	1359	39384	\N	52.787004141145097	Липецкая область, Добровский район, с.Чечеры, ул.Романовская, д.1	Россия, Липецкая область, Добровский район, поселок Чечеры	0101000020E610000011381268B0F943401DE90C8CBC644A40
53410	1	9	286	1943	38819	\N	52.889212999999998	Липецкая область, Добровский район, с.Трубетчино, ул.Почтовая, д.23		0101000020E6100000A704C4245CC64340CA1649BBD1714A40
53419	1	9	286	2486	39154	\N	53.037581000000003	Липецкая область, Добровский район, с.Ратчино, ул.Ленина, д.2		0101000020E6100000EB707495EEF44340BAF94674CF844A40
53420	1	9	286	2528	39208	\N	53.044944999999998	Липецкая область, Добровский район, с.Путятино, ул.Костикова, д.20		0101000020E61000002B84D558C2E04340328FFCC1C0854A40
53397	1	9	286	1215	39499	\N	52.956766999999999	Липецкая область, Добровский район, с.Преображеновка, ул.Центральная, 6		0101000020E6100000A54C6A68030A44402E724F57777A4A40
53411	1	9	286	2035	39100	\N	52.878166	Липецкая область, Добровский район, с.Порой, ул.Сельская, д.31		0101000020E6100000745C8DEC4ABB4340C53A55BE67704A40
53407	1	9	286	1709	39146	\N	52.804859	Липецкая область, Добровский район, с.Панино, ул.Ленина, д.36		0101000020E6100000B7ED7BD45FE143401572A59E05674A40
53406	1	9	286	1709	39146	\N	52.804859	Липецкая область, Добровский район, с.Панино, ул.Ленина, д.56		0101000020E6100000B7ED7BD45FE143401572A59E05674A40
53408	1	9	286	1818	\N	\N	52.907133999999999	"Липецкая область, Добровский район, с.Махоново, Здание МУ Махоновский ""Досуговый центр культуры"""	Россия, Липецкая область, Добровский район, поселок Махоново	0101000020E6100000DE567A6D36E243407A8B87F71C744A40
53401	1	9	286	1438	39501	\N	52.798577000000002	Липецкая область, Добровский район, с.Лебяжье, ул.Центральная, д.86		0101000020E610000023111AC1C6F343403D2B69C537664A40
53417	1	9	286	2378	39150	\N	53.011617498183597	Липецкая область, Добровский район, с.Крутое, ул.Комсомольская, д.19	Россия, Липецкая область, Добровский район, поселок Крутое	0101000020E6100000C78157CB9DE74340F08975AA7C814A40
53398	1	9	286	1257	39205	\N	52.876057000000003	Липецкая область, Добровский район, с.Кривец, ул.Нвоая, д.2		0101000020E6100000A45181936D0644404837C2A222704A40
53403	1	9	286	54755	\N	\N	52.7361930181604	"Липецкая область, Добровский район, с.Кореневщино, Здание МУ Кореневщинский ""Досуговый центр культуры"""	Россия, Липецкая область, Добровский район, поселок Кореневщина	0101000020E6100000D68F4DF223EC4340A6457D923B5E4A40
53414	1	9	286	2188	38842	\N	52.949345999999998	Липецкая область, Добровский район, с.Каликино, пл.Ленина, д.14		0101000020E610000016BD5301F7E64340514B732B84794A40
53416	1	9	286	2188	39207	\N	52.950670187654801	Липецкая область, Добровский район, с.Каликино, ул.Советская, д.100		0101000020E6100000E700C11C3DE84340E8A4F78DAF794A40
53421	1	9	286	60447	\N	\N	52.868059643206202	Липецкая область, Добровский район, поселок Зарницы, Здание клуба		0101000020E61000007286E28E37ED43409E7B0F971C6F4A40
53409	1	9	286	1899	39250	\N	52.856285	Липецкая область, Добровский район, с.Замартынье, ул.Центральная, д.86		0101000020E6100000EFFFE38409D74340168733BF9A6D4A40
53412	1	9	286	2069	39382	\N	52.937998999999998	Липецкая область, Добровский район, с.Екатериновка, ул.Черемушки, д.1		0101000020E6100000F6F065A208C743402157EA5910784A40
53422	1	9	286	2640	39165	\N	52.864370000000001	Липецкая область, Добровский район, с.Доброе, пл.Октябрьская, д.10		0101000020E61000004968CBB914E743405FD218ADA36E4A40
53424	1	9	286	2640	39103	\N	52.864370000000001	Липецкая область, Добровский район, с.Доброе, пер.Ленина, д.5		0101000020E61000004968CBB914E743405FD218ADA36E4A40
53426	1	9	286	2640	38953	\N	52.864370000000001	Липецкая область, Добровский район, с.Доброе, ул.Школьная, д.57		0101000020E61000004968CBB914E743405FD218ADA36E4A40
53425	1	9	286	2640	39225	\N	52.864370000000001	Липецкая область, Добровский район, с.Доброе, ул.Победы, д.13		0101000020E61000004968CBB914E743405FD218ADA36E4A40
53423	1	9	286	2640	39102	\N	52.8646040295544	Липецкая область, Добровский район, с.Доброе, ул.Ленина, д.39	Россия, Липецкая область, Добровский район, поселок Доброе	0101000020E6100000F37519FED3E74340D2FE0758AB6E4A40
53415	1	9	286	2252	39288	\N	52.988914000000001	Липецкая область, Добровский район, с.Гудово, ул.Чкалова, д.54		0101000020E61000008BC6DADFD9E643403D47E4BB947E4A40
53404	1	9	286	1593	39381	\N	52.7594000828635	Липецкая область, Добровский район, с.Горицы, ул.Центральная, д.93	Россия, Липецкая область, Добровский район, поселок Горицы	0101000020E61000007F87A2409FEC43408C4AEA0434614A40
53413	1	9	286	2147	39148	\N	53.027259999999998	Липецкая область, Добровский район, с.Волчье, ул.Центральная, д.37		0101000020E6100000C1525DC0CBD04340963E74417D834A40
53399	1	9	286	1327	38841	\N	52.848047000000001	Липецкая область, Добровский район, с.Борисовка, ул.Новая, д.1/2		0101000020E61000003A78263449FE4340473CD9CD8C6C4A40
53402	1	9	286	1472	39244	\N	52.792983999999997	Липецкая область, Добровский район, с.Большой Хомутец, ул.Советская, д.41		0101000020E6100000B1C403CAA6EE43402920ED7F80654A40
53380	1	9	70	129	39286	\N	52.256425	Липецкая область, Добринский район, п.им.Ильича, Центральная, 46		0101000020E61000003DEE5BAD134744403B70CE88D2204A40
53312	1	9	70	29358	38820	\N	52.017071999999999	Липецкая область, Грязинский муниципальный район, сельское поселение Ярлуковский сельсовет, с.Ярлуково, Молодежная, 4б		0101000020E61000003123BC3D082B4440B2D6506A2F024A40
53373	1	9	70	54765	39262	\N	52.055818871671697	Липецкая область, Добринский район, с.Чамлык Никольское, Школьная, 12	Россия, Липецкая область, Добринский район, поселок Чалмык-Никольское	0101000020E610000021938C9C854944406ABFB51325074A40
53396	1	9	70	1131	39223	\N	52.322673396946598	Липецкая область, Добринский район, с.Хворостянка, Школьная, 17	Россия, Липецкая область, Добринский район, поселок Хворостянка	0101000020E6100000637E6E68CA1E4440AF264F594D294A40
53386	1	9	70	1131	39153	\N	52.327570127976401	Липецкая область, Добринский район, ж.д.ст.Хворостянка, Первомайская, 1	Россия, Липецкая область, Добринский район, поселок Хворостянка	0101000020E610000044C18C29581D44404B9352D0ED294A40
53383	1	9	70	351	39285	\N	52.175942999999997	Липецкая область, Добринский район, с.Тихвинка, Садовая, 63		0101000020E61000003737A6272C2B4440E57ADB4C85164A40
53372	1	9	70	32209	37424	\N	52.040356000000003	Липецкая область, Добринский район, с.Талицкий Чамлык, Советская, 1		0101000020E6100000041C42959A4544404419AA622A054A40
53385	1	9	70	494	39101	\N	52.107368000000001	Липецкая область, Добринский район, с.Средняя Матренка, Центральная, 14		0101000020E61000006FF1F09E031944408751103CBE0D4A40
53387	1	9	70	617	39376	\N	52.284018000000003	Липецкая область, Добринский район, с.Салтычки, Молодежная, 108		0101000020E6100000BD361B2B31154440D8BCAAB35A244A40
53371	1	9	70	32190	39496	\N	51.952447999999997	Липецкая область, Добринский район, с.Ровенка, Чиркова, 11б		0101000020E6100000292499D53B424440FF91E9D0E9F94940
53388	1	9	70	648	38920	\N	52.334757000000003	Липецкая область, Добринский район, с.Пушкино, Мира, 33а		0101000020E61000006B662D05A42F4440B58D3F51D92A4A40
53390	1	9	70	54737	38959	\N	52.240374000000003	Липецкая область, Добринский район, ж.д.ст.Плавица, Школьная, 1		0101000020E6100000B08D78B29B2B444084674293C41E4A40
53376	1	9	70	32384	37425	\N	52.242144000000003	Липецкая область, Добринский район, п.Петровский, Победы, 3		0101000020E61000000F9C33A2B453444019761893FE1E4A40
53370	1	9	70	32146	39224	\N	51.993431999999999	Липецкая область, Добринский район, с.Паршиновка, Победы, 1		0101000020E6100000E8323509DE42444062669FC728FF4940
53379	1	9	70	85	39204	\N	52.22824	Липецкая область, Добринский район, с.Павловка, Центральная, 64		0101000020E61000001405FA449E3A4440CCD1E3F7361D4A40
53392	1	9	70	900	39388	\N	52.175153000000002	Липецкая область, Добринский район, с.Отскочное, Васильевская, 26		0101000020E6100000E179A9D898194440ED65DB696B164A40
53394	1	9	70	1014	39289	\N	52.203961999999997	Липецкая область, Добринский район, с.Ольховка, Дружбы, 24		0101000020E610000013807F4A950C444039D0436D1B1A4A40
53381	1	9	70	225	39395	\N	52.308902000000003	Липецкая область, Добринский район, с.Новочеркутино, Школьная, 6		0101000020E61000006116DA39CD324440A2D5C9198A274A40
53378	1	9	70	32465	39284	\N	52.198304	Липецкая область, Добринский район, с.Новопетровка, Школьная, 4		0101000020E610000086C954C1A85244403F55850662194A40
53377	1	9	70	32435	39498	\N	52.244139645483799	Липецкая область, Добринский район, д.Николаевка, Молодежная, 4	Россия, Липецкая область, Добринский район, поселок Николаевка	0101000020E6100000A7B05241454D44409ED2C1FA3F1F4A40
53393	1	9	70	974	39221	\N	52.256821000000002	Липецкая область, Добринский район, с. Нижняя Матренка, Центральная, 8		0101000020E610000091F3FE3F4E0E444088F6B182DF204A40
53369	1	9	70	32075	39495	\N	51.974922999999997	Липецкая область, Добринский район, д.Матвеевка, Центральная, 1		0101000020E6100000412C9B3924254440218FE046CAFC4940
53374	1	9	70	32306	39500	\N	52.087677999999997	Липецкая область, Добринский район, с.Мазейка, Центральная, 14		0101000020E610000045DAC69FA8344440124A5F08390B4A40
53368	1	9	70	32052	39451	\N	52.002769999999998	Липецкая область, Добринский район, с.Лебедянка, Школьная, 49		0101000020E610000054E23AC6152B444078B471C45A004A40
53364	1	9	70	54754	39109	\N	52.166165999999997	Липецкая область, Добринский район, п.Кооператор, 60 лет Победы, 7		0101000020E6100000AC376A85E94F444083DA6FED44154A40
53375	1	9	70	32358	39497	\N	52.351840000000003	Липецкая область, Добринский район, д.Заря, Заречная, 18		0101000020E6100000F1D8CF62293044405BB6D617092D4A40
53391	1	9	70	865	39378	\N	52.216687	Липецкая область, Добринский район, с.Дурово, Центральная, 9		0101000020E610000059A2B3CC221C4440F33B4D66BC1B4A40
53395	1	9	70	1098	38952	\N	52.377049	Липецкая область, Добринский район, с.Дубовое, Лермонтова, 2а		0101000020E61000008FAA2688BA274440A8FE412443304A40
53363	1	9	70	31620	39329	\N	52.171458000000001	Липецкая область, Добринский район, п.Добринка, Терпигорева, 1		0101000020E61000000AA01859323B44409C51F355F2154A40
53360	1	9	70	31620	38873	\N	52.171458000000001	Липецкая область, Добринский район, п.Добринка, Октябрьская, 79		0101000020E61000000AA01859323B44409C51F355F2154A40
53362	1	9	70	31620	39152	\N	52.1674598154938	Липецкая область, Добринский район, п.Добринка, Народная, 1	Россия, Липецкая область, Добринский район, поселок Добринка	0101000020E61000000C906802453E4440AFB14B546F154A40
53359	1	9	70	31620	38874	\N	52.171458000000001	Липецкая область, Добринский район, п.Добринка, Ленинская, 4		0101000020E61000000AA01859323B44409C51F355F2154A40
53361	1	9	70	31620	38988	\N	52.171458000000001	Липецкая область, Добринский район, п.Добринка, Кирова, 4		0101000020E61000000AA01859323B44409C51F355F2154A40
53365	1	9	70	31927	39246	\N	52.114288000000002	Липецкая область, Добринский район, с.Демшинка, Центральная, 62		0101000020E610000096E7C1DD59294440A2293BFDA00E4A40
53735	1	9	70	18032	39233	\N	52.115260999999997	Липецкая область, Липецкий муниципальный район, сельское поселение Введенский сельсовет, село Воскресеновка, Звонная, 9		0101000020E6100000227024D0604144408BC058DFC00E4A40
53366	1	9	70	31949	37439	\N	52.054910999999997	Липецкая область, Добринский район, с.Верхняя Матренка, Центральная, 32		0101000020E6100000E1B4E0455F1744406798DA5207074A40
53384	1	9	70	400	39375	\N	52.205288614937203	Липецкая область, Добринский район, д.Большая Плавица, Центральная, 220	Россия, Липецкая область, Добринский район, поселок Большая Плавица	0101000020E61000003526C45C522B4440419DF2E8461A4A40
53389	1	9	70	725	39377	\N	52.263855	Липецкая область, Добринский район, с.Богородицкое, Богородицкая, 51		0101000020E6100000FCFF3861C22C44406BF12900C6214A40
53367	1	9	70	32000	39220	\N	52.061157999999999	Липецкая область, Добринский район, с.Березнеговатка, Центральная, 37		0101000020E610000035EB8CEF8B294440C3F17C06D4074A40
53382	1	9	70	269	39523	\N	52.304972400530502	Липецкая область, Добринский район, с.Александровка, Интернациональная, 22	Россия, Липецкая область, Добринский район, поселок Александровка	0101000020E6100000DDB3AED1723A44400D198F5209274A40
53347	1	9	1695	31063	39380	\N	53.285535000000003	Липецкая область, Данковский район, с.Ярославы, ул.Центральная, 19		0101000020E6100000334E4354E16F4340836E2F698CA44A40
53358	1	9	1695	31596	39156	\N	53.339672	Липецкая область, Данковский район, с.Ягодное, ул.Советская, 3		0101000020E6100000A5164A26A7A64340F7AE415F7AAB4A40
53357	1	9	1695	31556	39488	\N	53.130839000000002	Липецкая область, Данковский район, с.Хрущево-Подлесное, ул.Деминская, 5		0101000020E6100000C80C54C6BF7F43404B051555BF904A40
53356	1	9	1695	31476	39328	\N	53.306567000000001	Липецкая область, Данковский район, с.Требунки, ул.Центральная, 163		0101000020E61000000133DFC14F904340348463963DA74A40
53355	1	9	1695	31462	39193	\N	53.220314000000002	Липецкая область, Данковский район, с.Теплое, ул.Советская, 3		0101000020E61000005A80B6D5AC714340EC6CC83F339C4A40
53354	1	9	1695	31375	39486	\N	53.119231999999997	Липецкая область, Данковский район, с.Телепнево, ул.Советская, 1		0101000020E610000078279F1EDB7243407E5182FE428F4A40
53353	1	9	1695	31357	39191	\N	53.260145000000001	Липецкая область, Данковский район, с.Спешнево-Ивановское, ул.Центральная, 22		0101000020E6100000E59D4319AA804340E59B6D6E4CA14A40
53345	1	9	1695	54761	39218	\N	53.342525071201898	Липецкая область, Данковский район, ст.Политово, ул.Спортивная, 1а	Россия, Липецкая область, Данковский район, поселок Политово	0101000020E610000020D4450A657B4340FD87F4DBD7AB4A40
53352	1	9	1695	31266	39323	\N	53.508065999999999	Липецкая область, Данковский район, с.Полибино, ул.Школьная, 1		0101000020E61000000E10CCD1E37D4340D21A834E08C14A40
53351	1	9	1695	31251	39334	\N	53.256459999999997	Липецкая область, Данковский район, с.Плахово, ул.Центральная, 10		0101000020E6100000BBEEAD484C584340B75D68AED3A04A40
53350	1	9	1695	31171	39283	\N	53.138365	Липецкая область, Данковский район, с.Перехваль, ул.Школьная, 1		0101000020E610000087E123624A8C43409DF4BEF1B5914A40
53346	1	9	1695	30972	39219	\N	53.202686	Липецкая область, Данковский район, с.Новоникольское, ул.Центральная, 8		0101000020E6100000D57954FCDF934340B4AD669DF1994A40
53344	1	9	1695	30915	39145	\N	53.388672	Липецкая область, Данковский район, с.Кудрявщино, ул.Зеленая, 21		0101000020E61000009E25C808A88043407A6F0C01C0B14A40
53822	1	9	1695	22514	\N	\N	53.193434000000003	Липецкая область Тербунский района деревня Васильевка, Красный Луч, 42		0101000020E6100000268A90BA9D9343409DF7FF71C2984A40
53343	1	9	1695	30879	39494	\N	53.464126	Липецкая область, Данковский район, с.Ивановка, ул.Фролова, 4		0101000020E61000003541D47D00664340959C137B68BB4A40
53342	1	9	1695	30771	39215	\N	53.457543000000001	Липецкая область, Данковский район, с.Долгое, ул.Советская, 68		0101000020E6100000852348A5D88D4340C2C1DEC490BA4A40
53349	1	9	1695	30768	39147	\N	53.199950999999999	Липецкая область, Данковский район, с.Воскресенское, ул.Мира, 6/1		0101000020E610000066F84F37505C4340B8E68EFE97994A40
53341	1	9	1695	30768	39202	\N	53.199950999999999	Липецкая область, Данковский район, с.Воскресенское, ул.Гагарина, 1		0101000020E610000066F84F37505C4340B8E68EFE97994A40
53340	1	9	1695	30705	33443	\N	53.347127448452099	Липецкая область, Данковский район, с.Бигильдино, ул.Центральная, 60	Россия, Липецкая область, Данковский район, поселок Бигильдино	0101000020E610000023BA675DA3914340804754A86EAC4A40
53339	1	9	1695	30638	39214	\N	53.434493000000003	Липецкая область, Данковский район, с.Березовка, ул.Парковая, 1		0101000020E61000003B35971B0C714340A4AB74779DB74A40
53338	1	9	1695	30591	39097	\N	53.343263999999998	Липецкая область, Данковский район, с.Барятино, ул.Центральная, 107		0101000020E6100000A41CCC26C060434073F22213F0AB4A40
53337	1	9	1695	30545	39144	\N	53.2127838563135	Липецкая область, Данковский район, с.Баловнево, ул.Ново-Советская, 14	Россия, Липецкая область, Данковский район, поселок Баловнево	0101000020E6100000EA5910CAFB844340588E90813C9B4A40
53336	1	9	1695	30491	\N	\N	53.299436999999998	Липецкая область, Данковский район, с.Авдулово, здание МБОУ СОШ с.Воскресенское филиал с.Авдулово, 63		0101000020E6100000EB54F99E915043402E1B9DF353A64A40
53325	1	9	1823	54787	39518	\N	52.4331583789753	Липецкая область, Грязинский муниципальный район, сельское поселение Телелюйский сельсовет, пос.св.Красная Дубрава, Лесная, 12		0101000020E610000098C3EE3B86ED43401900AAB871374A40
53306	1	9	1823	29094	39353	\N	52.387174000000002	Липецкая область, Грязинский муниципальный район, сельское поселение Карамышевский сельсовет, с.Ямань, Казанская, 2		0101000020E6100000CE1ABCAFCACB434046EEE9EA8E314A40
53311	1	9	1823	29307	38919	\N	52.463590000000003	Липецкая область, Грязинский муниципальный район, сельское поселение Фащевский сельсовет, с.Фащевка, Советская, 5		0101000020E6100000ED82C13577DC43405760C8EA563B4A40
53323	1	9	1823	29814	39324	\N	52.356729999999999	Липецкая область, Грязинский муниципальный район, сельское поселение Сошкинский сельсовет, с.Сошки, Мира, 37		0101000020E61000003D62F4DC42D3434044C02154A92D4A40
53322	1	9	1823	29814	38913	\N	52.356729999999999	Липецкая область, Грязинский муниципальный район, сельское поселение Сошкинский сельсовет, с.Сошки, Ленина, 129		0101000020E61000003D62F4DC42D3434044C02154A92D4A40
53320	1	9	1823	29718	38878	\N	52.426028000000002	Липецкая область, Грязинский муниципальный район, сельское поселение Кузовский сельсовет, с.Синявка, Центральная, 5		0101000020E61000006614CB2DAD0044401497E31588364A40
53321	1	9	1823	29754	39492	\N	52.448070000000001	Липецкая область, Грязинский муниципальный район, сельское поселение Кузовский сельсовет, пос.Светлая Поляна, Авиационная, 2		0101000020E6100000A41AF67B62F74340CC28965B5A394A40
53324	1	9	1823	54768	39268	\N	52.418982727853297	Липецкая область, Грязинский муниципальный район, сельское поселение Телелюйский сельсовет, пос.свх.Прибытковский, 19 съезд ВЛКСМ, 1а	Россия, Липецкая область, Грязинский район, колхоз Прибытковский	0101000020E6100000DA8CD31055EA43403C4A253CA1354A40
53308	1	9	1823	29167	38840	\N	52.634898	Липецкая область, Грязинский муниципальный район, сельское поселение Плехановский сельсовет, с.Плеханово, Плеханова, 45в		0101000020E6100000CDEA1D6E87EC4340DD25715644514A40
53303	1	9	1823	28981	39213	\N	52.486511856372097	Липецкая область, Грязинский муниципальный район, сельское поселение Петровский сельсовет, с.Петровка, Асфальтная, 1	Россия, Липецкая область, Грязинский район, поселок Петровка	0101000020E6100000D5EDEC2B0F104440478E7406463E4A40
53300	1	9	1823	54762	39256	\N	52.533947914953899	Липецкая область, Грязинский муниципальный район, сельское поселение Грязинский сельсовет, п.свх.Песковатский, Школьная, 6а		0101000020E6100000D07D39B35D034440DFE1766858444A40
53310	1	9	1823	29286	39487	\N	52.333804999999998	Липецкая область, Грязинский муниципальный район, сельское поселение Коробовский сельсовет, с.Падворки, Советская, 14		0101000020E6100000485167EE21034440E21E4B1FBA2A4A40
53317	1	9	1823	29602	39166	\N	52.404187999999998	Липецкая область, Грязинский муниципальный район, сельское поселение Княжебайгорский сельсовет, д.Кубань, Лесная, 17		0101000020E6100000B7B8C667B20F4440C3B7B06EBC334A40
53318	1	9	1823	29611	39331	\N	52.330479477116	Липецкая область, Грязинский муниципальный район, сельское поселение Коробовский сельсовет, с.Коробовка, 26 Партсъезд, 42	Россия, Липецкая область, Грязинский район, поселок Коробовка	0101000020E6100000CF9ECBD424084440E481C8224D2A4A40
53266	1	9	1804	27245	39477	\N	52.139730999999998	Липецкая область, Воловский муниципальный район, сельское поселение Ломигорский сельсовет, д.Мишино, Центральная, 4		0101000020E610000009E1D1C611ED4240629E95B4E2114A40
53315	1	9	1823	54763	39257	\N	52.388153351641897	Липецкая область, Грязинский муниципальный район, сельское поселение Княжебайгорский сельсовет, с.Кн.Байгора, Советская, 1	Россия, Липецкая область, Грязинский район, поселок Княжая Байгора	0101000020E6100000BD6F7CED99014440126C5CFFAE314A40
53314	1	9	1823	29427	39168	\N	52.369517870891698	Липецкая область, Грязинский муниципальный район, сельское поселение Карамышевский сельсовет, с.Карамышево, Центральная площадь, 3	Россия, Липецкая область, Грязинский район, поселок Карамышево	0101000020E610000041118B1876BE434044A4A65D4C2F4A40
53302	1	9	1823	54741	38979	\N	52.5298009796443	Липецкая область, Грязинский муниципальный район, сельское поселение Казинский сельсовет, с.Казинка, Гагарина, здание администрации		0101000020E6100000815CE2C803E94340AD31E884D0434A40
53309	1	9	1823	29233	\N	\N	52.649160000000002	Липецкая область, Грязинский муниципальный район, сельское поселение Плехановский сельсовет, д.Гудаловка, ОКУ ЛОПНБ, клуб		0101000020E6100000A8363811FDE8434089EFC4AC17534A40
53292	1	9	1823	54494	38977	\N	52.484142337474601	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Чпнышевского, 7	Россия, Липецкая область, Грязинский район, Грязи	0101000020E6100000F19F6EA0C0F943405D4F745DF83D4A40
53301	1	9	1823	54494	39023	\N	52.473955205611198	Липецкая область, Грязинский муниципальный район, сельское поселение Двуреченский сельсовет, Тимирязева, здание администрации	Россия, Липецкая область, Грязинский район, Грязи	0101000020E610000005508C2C99F943404963B48EAA3C4A40
53279	1	9	1823	54494	37442	\N	52.495737144566498	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Песковатская, 17	Россия, Липецкая область, Грязинский район, Грязи	0101000020E61000004EB6813B50F7434065355D4F743F4A40
53277	1	9	1823	54494	39065	\N	52.500980036342199	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Партизанская, 2	Россия, Липецкая область, Грязинский район, Грязи	0101000020E6100000AEEFC34142F843409CF9D51C20404A40
53280	1	9	1823	54494	38916	\N	52.501182075439203	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Лихачева, 11	Россия, Липецкая область, Грязинский район, Грязи	0101000020E6100000FCC7427408F8434004AC55BB26404A40
53294	1	9	1823	54494	39029	\N	52.502947812956002	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, Авиационная, 39	Россия, Липецкая область, Грязинский район, Грязи	0101000020E61000008F6E844545F8434058CB9D9960404A40
53275	1	9	1823	54494	39200	\N	52.4949120570204	Липецкая область, Грязинский муниципальный район, городское поселение г. Грязи, 2-я Чапаева, 56	Россия, Липецкая область, Грязинский район, Грязи	0101000020E61000000F7F4DD6A8F74340F032C346593F4A40
53307	1	9	1823	29149	39280	\N	52.617662000000003	Липецкая область, Грязинский муниципальный район, сельское поселение Плехановский сельсовет, с.Головщино, Школьная, 41		0101000020E61000007E6E68CA4EF14340B1FD648C0F4F4A40
94353	1	9	1823	29409	39149	\N	52.3476299354788	Липецкая область, Грязинский муниципальный район, сельское поселение В.Телелюй, ул.Некрасова,55 , здание администрации сельского поселения Верхнетелелюйский сельсовет	Россия, Липецкая область, Грязинский район, поселок Верхний Телелюй	0101000020E6100000E8F527F1B9F14340E38DCC237F2C4A40
53299	1	9	1823	28788	39203	\N	52.682400649933101	Липецкая область, Грязинский муниципальный район, сельское поселение Бутырский сельсовет, с.Бутырки, Ленинская, 5	Россия, Липецкая область, Грязинский район, поселок Бутырки	0101000020E6100000D2FF722D5AEA4340FCE07CEA58574A40
53298	1	9	1823	28706	38918	\N	52.535637999999999	Липецкая область, Грязинский муниципальный район, сельское поселение Большесамовецкий сельсовет, с.Б.Самовец, Советская, 135а		0101000020E6100000B939950C00F94340573F36C98F444A40
53316	1	9	1823	28995	39124	\N	52.481878999999999	"Липецкая область, Грязинский муниципальный район, сельское поселение Петровский сельсовет, с.Аннино, Социалистическая, контора ЗАО СХП ""Липецкрыбхоз"""		0101000020E61000009DF529C76403444089D00836AE3D4A40
53304	1	9	1823	28995	39209	\N	52.481878999999999	Липецкая область, Грязинский муниципальный район, сельское поселение Петровский сельсовет, с.Аннино, Набережная, дом Культуры		0101000020E61000009DF529C76403444089D00836AE3D4A40
53271	1	9	1804	27521	39493	\N	52.192661999999999	Липецкая область, Воловский муниципальный район, сельское поселение Юрский сельсовет, с.Юрское, Центральная, 25		0101000020E6100000EAB0C22D1FEF42404A97FE25A9184A40
53260	1	9	1804	27023	39452	\N	52.217227999999999	Липецкая область, Воловский муниципальный район, сельское поселение Гатищенский сельсовет, д.Пикалово, Луговая, 2		0101000020E6100000EB1D6E8786FF424043E38920CE1B4A40
53265	1	9	1804	27237	39210	\N	52.006368000000002	Липецкая область, Воловский муниципальный район, сельское поселение Липовский сельсовет, д.Новопавловка, Центральная, 4		0101000020E6100000EF59D76839FC4240D7DEA7AAD0004A40
53252	1	9	1804	26619	39216	\N	51.996160000000003	Липецкая область, Воловский муниципальный район, сельское поселение Большовский сельсовет, с.Нижнее Большое, Молодежная, 1		0101000020E6100000BF4351A04FF44240ACCABE2B82FF4940
53267	1	9	1804	27306	39212	\N	51.968624270449702	Липецкая область, Воловский муниципальный район, сельское поселение Набережанский сельсовет, с.Набережное, Совхозная, 1	Россия, Липецкая область, Воловский район, поселок Набережное	0101000020E610000005DF347D76104340730F09DFFBFB4940
53268	1	9	1804	27340	39348	\N	51.953420000000001	Липецкая область, Воловский муниципальный район, сельское поселение Набережанский сельсовет, д.Княжная, Школьная, 7		0101000020E610000094A12AA6D217434019ADA3AA09FA4940
53270	1	9	1804	27436	39199	\N	52.057927749264898	Липецкая область, Воловский муниципальный район, сельское поселение Спасский сельсовет, с.Казаково, Новая, 8	Россия, Липецкая область, Воловский район, поселок Казаково	0101000020E610000028BB99D18FF84240E7C2482F6A074A40
53269	1	9	1804	27420	39211	\N	52.036704999999998	Липецкая область, Воловский муниципальный район, сельское поселение Ожогинский сельсовет, д.Ивановка, Центральная, 32		0101000020E6100000B0E595EB6D0D4340C24CDBBFB2044A40
53262	1	9	1804	27083	39136	\N	52.100299	Липецкая область, Воловский муниципальный район, сельское поселение Захаровский сельсовет, с.Захаровка, Сельская, 30		0101000020E610000054FEB5BC72FB42402769FE98D60C4A40
53261	1	9	1804	27051	39475	\N	52.069662000000001	Липецкая область, Воловский муниципальный район, сельское поселение Замарайский сельсовет, с.Замарайка, Центральная, 2		0101000020E610000092CB7F48BFE5424011E335AFEA084A40
53259	1	9	1804	26975	39279	\N	52.213453999999999	Липецкая область, Воловский муниципальный район, сельское поселение Гатищенский сельсовет, с.Гатище, Центральная, 3		0101000020E6100000ACFD9DEDD1F94240A699EE75521B4A40
53251	1	9	1804	26577	39096	\N	51.971391466137803	Липецкая область, Воловский муниципальный район, сельское поселение Большовский сельсовет, с.Вышнее Большое, Центральная, 7	Россия, Липецкая область, Воловский район, поселок Вышнее Большое	0101000020E610000072DF6A9DB8EE42407A50508A56FC4940
53258	1	9	1804	26897	39347	\N	52.019615999999999	Липецкая область, Воловский муниципальный район, сельское поселение Воловчинский сельсовет, с.Воловчик, Центральная, 28		0101000020E61000001172DEFFC7E742403A3DEFC682024A40
53257	1	9	1804	26770	38943	\N	52.025579	Липецкая область, Воловский муниципальный район, сельское поселение Воловский сельсовет, с.Волово, Первомайская, 1		0101000020E61000001C42959A3DF04240713B342C46034A40
53255	1	9	1804	26770	38817	\N	52.025579	Липецкая область, Воловский муниципальный район, сельское поселение Воловский сельсовет, с.Волово, Ленина, 5		0101000020E61000001C42959A3DF04240713B342C46034A40
53254	1	9	1804	26734	39206	\N	51.926079999999999	Липецкая область, Воловский муниципальный район, сельское поселение Верхнечесноченский сельсовет, д.Верхнее Чесночное, В.Чернова, 24		0101000020E6100000D8F4A0A014FF424066BD18CA89F64940
53253	1	9	1804	26667	39197	\N	51.977502000000001	Липецкая область, Воловский муниципальный район, сельское поселение Васильевский сельсовет, с.Васильевка, Парковая, 10		0101000020E61000008A558330B703434026E318C91EFD4940
53250	1	9	1804	26547	39379	\N	52.149612026584698	Липецкая область, Воловский муниципальный район, сельское поселение Большеивановский сельсовет, с.Большая Ивановка, Школьная, 3	Россия, Липецкая область, Воловский район, поселок Большая Ивановка	0101000020E6100000D19332A9A1014340698B6B7C26134A40
53263	1	9	1804	27159	39448	\N	52.104303999999999	Липецкая область, Воловский муниципальный район, сельское поселение Захаровский сельсовет, д.Алексеевка, Центральная, 10		0101000020E61000008AE8D7D64FF34240C66B5ED5590D4A40
53264	1	9	1804	27165	39350	\N	52.098577625289302	Липецкая область, Воловский муниципальный район, сельское поселение Захаровский сельсовет, д.Александровка, Родниковая, 30	Россия, Липецкая область, Воловский район, поселок Александровка	0101000020E6100000A6457D923B064340740D33349E0C4A40
50908	1	8	\N	54500	\N	\N	51.755673999999999	Курская область, Курский район, Клюквинский сельсовет, п.Маршала Жукова, средняя общеобразовательная школа		0101000020E61000000D1B65FD661E42400038F6ECB9E04940
50946	1	8	\N	54481	\N	\N	51.773632999999997	Курская область, Курский район, Щетинский сельсовет, п.Юбилейный, детский сад №8 п.Юбилейный	Россия, Курская область, поселок Юбилейный	0101000020E6100000AC72A1F2AF2142409D0DF96706E34940
51365	1	8	\N	1787	37302	\N	51.876528999999998	Курская область, город Щигры, ул.Черняховского (здание военного комиссариата), 7		0101000020E61000004CFC51D4997942406F7F2E1A32F04940
51453	1	8	\N	1787	37637	\N	51.876528999999998	Курская область, город Щигры, ул. Плеханова (здание Дворца культуры "Аврора"), 15		0101000020E61000004CFC51D4997942406F7F2E1A32F04940
51183	1	8	\N	1787	37335	\N	51.873078091171202	Курская область, город Щигры, ул. Октябрьская (здание школы №4), 42	Россия, Курская область, Щигры городской округ	0101000020E6100000806264C91C754240B56D1805C1EF4940
51451	1	8	\N	1787	37601	\N	51.877753153462201	Курская область, город Щигры, ул. Мичурина (актовый зал ООО"Русский Дом-Зернопродукт"), 2	Россия, Курская область, Щигры городской округ	0101000020E6100000882CD2C43B744240A27BD6355AF04940
51452	1	8	\N	1787	37481	\N	51.876528999999998	Курская область, город Щигры, ул. Лермонтова (здание школы №3), 15		0101000020E61000004CFC51D4997942406F7F2E1A32F04940
51449	1	8	\N	1787	37473	\N	51.876528999999998	Курская область, город Щигры, ул. Лазарева (здание школы №2), 2		0101000020E61000004CFC51D4997942406F7F2E1A32F04940
51450	1	8	\N	1787	37295	\N	51.870580982750504	Курская область, город Щигры, ул. Красная (здание "Городского Дома культуры"), 52	Россия, Курская область, Щигры городской округ	0101000020E610000065AA6054527342406EC2BD326FEF4940
51430	1	8	\N	1787	37295	\N	51.876528999999998	Курская область, город Щигры, ул. Красная (здание школы №5), 44	Россия, Курская область, Щигры	0101000020E61000004CFC51D4997942406F7F2E1A32F04940
51257	1	8	\N	1787	37295	\N	51.876528999999998	Курская область, город Щигры, ул. Красная (здание ПУ №39), 29		0101000020E61000004CFC51D4997942406F7F2E1A32F04940
50943	1	8	\N	54508	\N	\N	51.786169999999998	Курская область, Курский район, Щетинский сельсовет, д.Щетинка, администрация сельсовета	Россия, Курская область, деревня Щетинка	0101000020E6100000F44D9A06451D4240548CF337A1E44940
50926	1	8	\N	9704	37328	\N	51.628917081922403	Курская область, Курский район, Новопоселеновский сельсовет, д.1-е Цветово, Новопоселеновская средняя школа	Россия, Курская область, деревня Цветово 1-е	0101000020E6100000904FC8CEDB0C424000732D5A80D04940
51301	1	8	\N	54478	37366	\N	51.199566090735097	Курская область, Суджанский район, город Суджа, Советская площадь (здание  МКУК "Районный ЦНТ"), 18		0101000020E6100000BD8BF7E3F6A141405FB2F1608B994940
51190	1	8	\N	54502	37503	\N	51.565729231747603	Курская область, Рыльский район, г.Рыльск здание МБОУ "Рыльская, средняя общеобразовательная школа №5") ул.Маяковского, д.41		0101000020E61000002D5BEB8B845841400BB3D0CE69C84940
51184	1	8	\N	54463	37474	\N	51.567227000000003	Курская область, Рыльский район, г.Рыльск (здание МБОУ "Рыльская средняя, общеобразовательная школа №1 им.Г.И.Шелехова) улЛуначарского, д.17		0101000020E61000001AA4E029E45841404034F3E49AC84940
51186	1	8	\N	54463	37414	\N	51.5688911463048	Курская область, Рыльский район, г.Рыльск (здание ФГОУ СПО, "Рыльский аграрный техникумул") ул.Ленина, д.42		0101000020E6100000CDAD1056635741408FFE976BD1C84940
51191	1	8	\N	54463	37437	\N	51.567708418681001	Курская область, Рыльский район, г.Рыльск (здание МБОУ "Рыльская основна, общеобразовательная школа №2") ул.Кирова, д.102	Россия, Курская область, Рыльский район, Рыльск	0101000020E61000005F7EA7C98C5B4140BBD6DEA7AAC84940
51106	1	8	\N	54486	37410	\N	51.216820418232899	Курская область, Обоянский район,город Обоянь,здание муниципального общеобразовательного учреждения "Обоянская СОШ № 3", Курская, 95	Россия, Курская область, Обоянский район, Обоянь	0101000020E6100000E4D87A8670204240328FFCC1C09B4940
50486	1	8	\N	54484	37458	\N	51.660612999999998	Курсая область, город Льгов, Энгельса, 138/82		0101000020E6100000679C86A8C2A14140FE277FF78ED44940
51018	1	8	\N	54484	37382	\N	51.643661470134099	Курсая область, город Льгов, Куйбышева, 20	Россия, Курская область, Льгов городской округ	0101000020E6100000E1D231E719A14140F75AD07B63D24940
50982	1	8	\N	54484	37402	\N	51.654447080886897	Курсая область, город Льгов, Красная, 27	Россия, Курская область, Льгов городской округ	0101000020E61000006DFE5F75E4A041408FFB56EBC4D34940
50847	1	8	\N	54484	37469	\N	51.690469398263701	Курсая область, город Льгов, К. Маркса, 49/43	Россия, Курская область, Льговский район, Льгов	0101000020E61000003673486AA1A441406FF3C64961D84940
51019	1	8	\N	54484	37411	\N	51.660612999999998	Курсая область, город Льгов, К. Либкнехта, 4		0101000020E6100000679C86A8C2A14140FE277FF78ED44940
50681	1	8	\N	54484	37411	\N	51.660612999999998	Курская область, город Льгов, К. Либкнехта, 4		0101000020E6100000679C86A8C2A14140FE277FF78ED44940
50580	1	8	\N	24756	37493	\N	51.659043613378103	Курская область, город Курчатов, Энергетиков (здание школы №5), 16	Россия, Курская область, Курчатовский район	0101000020E6100000D5B2B5BE48D641400150C58D5BD44940
50579	1	8	\N	24756	37479	\N	51.661766027732099	Курская область, город Курчатов, Строителей (здание школы №4), 10	Россия, Курская область, Курчатов	0101000020E6100000B5A9BA4736D3414068CD8FBFB4D44940
50581	1	8	\N	24756	37480	\N	51.659897999999998	Курская область, город Курчатов, Садовая (здание "Дом детского и юношеского туризма, и экскурсий) 9а		0101000020E610000084F068E388D341401059A48977D44940
50585	1	8	\N	24756	37291	\N	51.659897999999998	Курская область, город Курчатов, Набережная (здание школы №6), 9А	Россия, Курская область, Курчатов	0101000020E610000084F068E388D341401059A48977D44940
50582	1	8	\N	24756	37291	\N	51.660137936947798	Курская область, город Курчатов, Набережная (здание школы №6), 9а	Россия, Курская область, Курчатов	0101000020E61000004850FC1873D34140666CE8667FD44940
50577	1	8	\N	24756	37347	\N	51.663794386444003	Курская область, город Курчатов, Молодежная (здание МОУ Гимназия № 2), 14	Россия, Курская область, Курчатов	0101000020E610000047AF06280DD34140F9A3A833F7D44940
50575	1	8	\N	24756	37347	\N	51.659897999999998	Курская область, город Курчатов, Молодежная, (здание УКМЦ Комсомолец"), 13	Россия, Курская область, Курчатов	0101000020E610000084F068E388D341401059A48977D44940
50576	1	8	\N	24756	36710	\N	51.658596534520797	Курская область, город Курчатов, Ленинградская (здание МОУ Гимназия № 1), 25	Россия, Курская область, Курчатов	0101000020E610000097FDBAD39DD34140321F10E84CD44940
50578	1	8	\N	24756	37348	\N	51.6640479248654	Курская область, город Курчатов, Космонавтов (здание МОУ Лицей № 3), 34	Россия, Курская область, Курчатов	0101000020E610000029B2D6506AD34140B37C5D86FFD44940
50584	1	8	\N	24756	36712	\N	51.6629069907382	Курская область, город Курчатов, Набережная (здание КБО 6 микрорайона"), 4	Россия, Курская область, Курчатов	0101000020E6100000718FA50F5DD441400DA5F622DAD44940
50583	1	8	\N	24756	36712	\N	51.661966198769399	Курская область, город Курчатов, Набережная (здание "Дом детского творчества"), 15	Россия, Курская область, Курчатов	0101000020E61000007E8E8F1667D441402F88484DBBD44940
50472	1	8	\N	4134	5308	\N	51.721391204089102	Курская область, город Курск, ул.Дзержинского (здание школы №7), д.95	Россия, Курская область, город Курск, улица Чернышевского, 95	0101000020E610000092E9D0E9791542407A50508A56DC4940
50400	1	8	\N	4134	4509	\N	51.714281999999997	Курская область, город Курск, Железнодорожный округ, ул. Полевая (здание школы №12), д. 19	Россия, Курская область, город Курск, улица Полевая, 19а	0101000020E61000004D6551D8451942408C0FB3976DDB4940
50490	1	8	\N	4134	37508	\N	51.732006970358498	Курская область, город Курск, ул.К.Воробьева (здание школы №57), д.13		0101000020E61000009204E10A28104240B7B8C667B2DD4940
50473	1	8	\N	4134	5375	\N	51.721964867619398	Курская область, город Курск, ул.Пирогова (здание ОАО "Плодоовощторг"), д.3	Россия, Курская область, город Курск, улица Пирогова	0101000020E610000044DB317557144240A6ED5F5969DC4940
50432	1	8	\N	4134	37528	\N	51.670570187714702	Курская область, город Курск, Сеймский административный округ, ул. Белгородская (здание ОГУ  "Областной Дворец молодежи"), д. 14Б	Россия, Курская область, город Курск, улица Парковая	0101000020E6100000BEA59C2FF6124240E0D6DD3CD5D54940
50475	1	8	\N	4134	5385	\N	51.734588726131101	Курская область, город Курск, ул.Павлуновского (здание школы №19), д.99	Россия, Курская область, город Курск, улица Павлуновского, 99	0101000020E610000066321CCF671442402C80290307DE4940
50457	1	8	\N	4134	5138	\N	51.668663000000002	Курская область, город Курск, Сеймский административный округ, ул. Менделеева (здание "Детская школа искусств № 3"), д. 20	Россия, Курская область, город Курск, улица Менделеева, 20	0101000020E610000024EEB1F4A1094240CB85CABF96D54940
50458	1	8	\N	4134	5194	\N	51.671590000000002	Курская область, город Курск, Сеймский административный округ, ул. Крюкова (здание МОУ"СОШ№ 45"), д. 5	Россия, Курская область, город Курск, улица Крюкова, 5	0101000020E6100000A1A2EA573A0942400B293FA9F6D54940
50517	1	8	\N	4134	5806	\N	51.764470000000003	Курская область, город Курск, ул.Карла Маркса (здание института земледелия и защиты почв), д.70б	Россия, Курская область, город Курск, улица Карла Маркса, 70б	0101000020E6100000E2C8039145164240F6622827DAE14940
50525	1	8	\N	4134	5982	\N	51.746423999999998	Курская область, город Курск, ул.Блинова (здание гимназии №44), д.3	Россия, Курская область, город Курск, улица Блинова, 3	0101000020E6100000C992399677194240897956D28ADF4940
50478	1	8	\N	4134	5443	\N	51.738137000000002	Курская область, город Курск, ул, 50 лет Октября (здание общежития Юго-Западного университета), д.94	Россия, Курская область, город Курск, улица 50-летия Октября, 94	0101000020E6100000139CFA40F2124240D97BF1457BDE4940
50452	1	8	\N	4134	5114	\N	51.667763266769398	Курская область, город Курск, Сеймский административный округ, пр. Ленинского Комсомола здание общежития Управляющая компан, д. 61	Россия, Курская область, город Курск, проспект Ленинского Комсомола, 61	0101000020E6100000419B1C3EE90C42404B3D0B4279D54940
50537	1	8	\N	4134	1254	\N	51.726742945545503	Курская область, город Курск, проспект Вячеслава Клыкова (здание торгового центра), д.1А		0101000020E61000007B681F2BF811424068CC24EA05DD4940
50535	1	8	\N	4134	5553	\N	51.741833999999997	Курская область, город Курск, проезд Сергеева (здание центра детского творчества), д.18		0101000020E6100000CAE1934E24104240CA87A06AF4DE4940
50453	1	8	\N	4134	5089	\N	51.669288000000002	Курская область, город Курск, Сеймский административный округ, ул. Широкая (здание МОУ ДОД"Детская школа искусств № 9"), д. 2	Россия, Курская область, город Курск, Широкая улица, 2	0101000020E6100000D7851F9C4F0D424079CDAB3AABD54940
50414	1	8	\N	4134	37461	\N	51.710413950964103	Курская область, город Курск, Сеймский административный округ, ул. Тракторная (здание "Профессиональное училище № 41", д. 8		0101000020E6100000F92EA52E191342406E4F90D8EEDA4940
50420	1	8	\N	4134	1108	\N	51.707495999999999	Курская область, город Курск, Сеймский административный округ, ул.Сумская (здание МОУ ДОД"Детская школа искусств № 6"), д. 6		0101000020E61000000D6E6B0BCF13424081069B3A8FDA4940
50394	1	8	\N	4134	37505	\N	51.7447665310509	Курская область, город Курск, Железнодорожный  округ, ул. Социалистическая (здание школы №10), д. 10		0101000020E610000040BE840A0E1F4240ED116A8654DF4940
50393	1	8	\N	4134	37505	\N	51.744777631183197	Курская область, город Курск, Железнодорожный  округ, ул. Социалистическая  (здание школы №10), д. 10	Россия, Курская область, город Курск, Социалистическая улица	0101000020E61000004B04AA7F101F4240E063B0E254DF4940
50395	1	8	\N	4134	4443	\N	51.743340000000003	Курская область, город Курск, Железнодорожный  округ, Республиканская (здание школы №8), 46а	Россия, Курская область, город Курск, Республиканская улица, 46а	0101000020E610000079AEEFC34120424082E7DEC325DF4940
50909	1	8	\N	4134	37446	\N	51.755673984284499	Курская область, Курский район, Клюквинский сельсовет, п.Маршала Жукова, Гарнизонный Дом офицеров		0101000020E6100000F5F23B4D661E42400038F6ECB9E04940
50446	1	8	\N	4134	5015	\N	51.648795	Курская область, город Курск, Сеймский административный округ, Магистральный проезд(здание "Профессиональное училище № 14"), д. 11	Россия, Курская область, город Курск, Магистральный проезд, 11	0101000020E6100000A6D1E4620C1242407767EDB60BD34940
50407	1	8	\N	4134	37510	\N	51.719811999999997	Курская область, город Курск, Сеймский административный округ, ул. Литовская (здание МОУ ДОД "ДЮСШ Картинг"), д. 12		0101000020E610000089EC832C0B18424059A2B3CC22DC4940
50429	1	8	\N	4134	4834	\N	51.671678999999997	Курская область, город Курск, Сеймский административный округ, ул. Краснополянская (здание МОУ"СОШ№ 29"), д. 2А	Россия, Курская область, город Курск, Краснополянская улица, 2а	0101000020E61000000A6AF816D61342407A34D593F9D54940
50416	1	8	\N	4134	37586	\N	51.709572000000001	Курская область, город Курск, Сеймский административный округ, ул. Конорева (здание МОУ"СОШ№ 1"), д. 8		0101000020E6100000484F9143C411424023145B41D3DA4940
50442	1	8	\N	4134	37506	\N	51.669588717591203	Курская область, город Курск, Сеймский административный округ, ул. Гагарина (здание общежития ФГУСПО  КГПК"), д. 27	Россия, Курская область, город Курск, улица Гагарина	0101000020E6100000170FEF39B01042407461A417B5D54940
50477	1	8	\N	4134	37511	\N	51.736179	Курская область, город Курск, ул.Бойцов 9-й дивизии, здание центра досуга "Юность "		0101000020E61000001FD95C35CF15424041800C1D3BDE4940
50401	1	8	\N	4134	37537	\N	51.718214867468198	Курская область, город Курск, Железнодорожный округ, ул. Антокольского (здание школы №11), д. 1	Россия, Курская область, город Курск, 2-я Кожевенная улица, 1	0101000020E6100000C634D3BD4E184240923F1878EEDB4940
50460	1	8	\N	4134	37459	\N	51.669337190893302	Курская область, город Курск, Сеймский административный округ, 7-й Промышленный переулок (здание МОУ"СОШ№ 47"), д. 9		0101000020E61000009F56D11F9A0942405A80B6D5ACD54940
50405	1	8	\N	54503	\N	\N	51.730466999999997	Курская область, город Курск, Железнодорожный  округ, Вокзал ст. Курск (здание вокзала Курск)		0101000020E61000002D996379571F424053E751F17FDD4940
50533	1	8	\N	54503	37538	\N	51.736570068529602	Курская область, город Курск, проспект Хрущева (здание дома искусств "Ритм"), д.4а	Россия, Курская область, город Курск, проспект Хрущева	0101000020E61000007A8CF2CCCB1142407C9BFEEC47DE4940
50488	1	8	\N	54503	37550	\N	51.741087	Курская область, город Курск, проспект Дружбы (здание центра досуга "Сказка"), д.18		0101000020E61000006F9F55664A114240D13E56F0DBDE4940
50485	1	8	\N	54503	37550	\N	51.741131000000003	Курская область, город Курск, проспект Дружбы (здание школы №52), д.14		0101000020E610000010C99063EB114240A1866F61DDDE4940
50383	1	8	\N	54503	37547	\N	51.751944000000002	Курская область, город Курск, Железнодорожный округ, проезд Театральный (здание Дома культуры железнодорожников), д. 1		0101000020E6100000452BF702B31C4240333674B33FE04940
50487	1	8	\N	54503	37576	\N	51.741833999999997	Курская область, город Курск, проезд Сергеева (здание школы №54), д.14		0101000020E6100000CAE1934E24104240CA87A06AF4DE4940
50528	1	8	\N	54503	37556	\N	51.771515000000001	Курская область, город Курск, проезд Светлый (здание школы №22), д.15		0101000020E61000003BC5AA4198194240CDAFE600C1E24940
50512	1	8	\N	54503	37593	\N	51.751185	Курская область, город Курск, Южный переулок (здание протезно-ортопедического предприятия), д.16		0101000020E61000007F4B00FE29174240751F80D426E04940
50425	1	8	\N	54503	37574	\N	51.696857000000001	Курская область, город Курск, Сеймский административный округ, ул. Энгельса (здание Центральных электрических сетей ), д. 171В		0101000020E61000008FC360FE0A1342408D7E349C32D94940
50516	1	8	\N	54503	37534	\N	51.759475999999999	Курская область, город Курск, ул.Школьная (здание школы №42), д.1а		0101000020E6100000EE79FEB451174240670C738236E14940
50513	1	8	\N	54503	37534	\N	51.758575089442502	Курская область, город Курск, ул.Школьная (здание школы №31), д.3б		0101000020E6100000227024D060174240174850FC18E14940
50451	1	8	\N	54503	37542	\N	51.668328000000002	Курская область, город Курск, Сеймский административный округ, ул. Широкая (здание МОУ"СОШ  № 28"), д. 8		0101000020E61000009CC24A05150D424024809BC58BD54940
50450	1	8	\N	54503	37542	\N	51.668328000000002	Курская область, город Курск, Сеймский административный округ, ул. Широкая (здание МОУ"СОШ № 28"), д. 8		0101000020E61000009CC24A05150D424024809BC58BD54940
50428	1	8	\N	54503	37571	\N	51.675488000000001	Курская область, город Курск, Сеймский административный округ, ул. Черняховского (здание библиотеки № 5), д. 4А		0101000020E610000001F6D1A92B134240946B0A6476D64940
50427	1	8	\N	54503	37571	\N	51.676678000000003	Курская область, город Курск, Сеймский административный округ, ул. Черняховского (здание МОУ"СОШ № 53"), д. 32		0101000020E6100000F7E6374C341442401BF67B629DD64940
50467	1	8	\N	54503	37543	\N	51.723945979644299	Курская область, город Курск, ул.Чернышевского (здание гимназии №25), д.7	Россия, Курская область, город Курск, улица Чернышевского, 7	0101000020E6100000C4EC65DB69154240F6083543AADC4940
50526	1	8	\N	54503	37535	\N	51.745140999999997	Курская область, город Курск, ул.Челюскинцев (здание Юго-Западного университета), д.19а		0101000020E6100000CB9C2E8B8919424051F4C0C760DF4940
50402	1	8	\N	54503	37662	\N	51.733440000000002	Курская область, город Курск, Железнодорожный округ, ул. Чайковского (здание Торговой Компании "Людиновокабель), д. 49 в		0101000020E6100000C39E76F86B1E424004CAA65CE1DD4940
50415	1	8	\N	54503	37548	\N	51.711899000000003	Курская область, город Курск, Сеймский административный округ, ул. Сумская (здание ОАО Курские электрические сети"), д. 41		0101000020E610000036AFEAAC161242400E87A5811FDB4940
50413	1	8	\N	54503	37548	\N	51.709572000000001	Курская область, город Курск, Сеймский административный округ, ул. Сумская (здание ОГОУ СПОКурский колледж культуры"), д. 29		0101000020E61000007505DB882713424023145B41D3DA4940
50410	1	8	\N	54503	37548	\N	51.706921000000001	Курская область, город Курск, Сеймский административный округ, ул. Сумская( здание КОТШ РОСТО (ДОСААФ)), д. 5		0101000020E610000093196F2BBD14424085ED27637CDA4940
50409	1	8	\N	54503	37548	\N	51.706921000000001	Курская область, город Курск, Сеймский административный округ, ул. Сумская (здание КОТШ РОСТО (ДОСААФ)), д. 5	Россия, Курская область, город Курск, Сумская улица, 5	0101000020E610000093196F2BBD14424085ED27637CDA4940
50387	1	8	\N	54503	37520	\N	51.750889999999998	Курская область, город Курск, Железнодорожный округ, ул. Станционная (здание школы №36), д. 8		0101000020E610000020EEEA55641E42405C72DC291DE04940
50386	1	8	\N	54503	37520	\N	51.749361999999998	Курская область, город Курск, Железнодорожный округ, ул. Станционная (здание центра досуга "Мир"), д. 14а		0101000020E61000000116F9F5431E4240BD6E1118EBDF4940
50397	1	8	\N	54503	37525	\N	51.743991999999999	Курская область, город Курск, Железнодорожный округ, ул. Союзная (здание Курского профессионального лицея), д. 67 корпус 1		0101000020E6100000B7EEE6A90E214240293E3E213BDF4940
38505	1	6	\N	1634	35357	\N	55.120825000000004	город Обнинск, Гагарина, 20		0101000020E6100000BFD6A546E84B424005C58F31778F4B40
50469	1	8	\N	54503	37531	\N	51.728861000000002	Курская область, город Курск, ул.Советская (здание школы №18), д.25		0101000020E6100000CA37DBDC98164240392A37514BDD4940
50468	1	8	\N	54503	37531	\N	51.72972	Курская область, город Курск, ул.Советская (здание школы №2), д.40		0101000020E61000008C6A11514C1642405A9E077767DD4940
50466	1	8	\N	54503	37531	\N	51.726756999999999	Курская область, город Курск, ул.Советская (здание монтажного техникума), д.14		0101000020E610000083BF5FCC96164240CD91955F06DD4940
50441	1	8	\N	54503	37579	\N	51.671126000000001	Курская область, город Курск, Сеймский административный округ, ул. Серегина (здание филиала РГСУ), д. 16А		0101000020E6100000B20DDC813A11424066BFEE74E7D54940
50440	1	8	\N	54503	37579	\N	51.669891999999997	Курская область, город Курск, Сеймский административный округ, ул. Серегина (здание МОУ"СОШ№ 50"), д. 12		0101000020E6100000C8EA56CF491142400FED6305BFD54940
50438	1	8	\N	54503	37579	\N	51.669361000000002	Курская область, город Курск, Сеймский административный округ, ул. Серегина (здание МОУ"СОШ№ 48"), д. 17		0101000020E6100000295AB91798114240E31B0A9FADD54940
50436	1	8	\N	54503	37579	\N	51.676287000000002	Курская область, город Курск, Сеймский административный округ, ул. Серегина (здание МОУ"СОШ№ 30"), д. 41		0101000020E6100000C8B3CBB73E124240E0DA899290D64940
50499	1	8	\N	54503	37655	\N	51.733109306504602	Курская область, город Курск, ул.Серафима Саровского (здание профессионального лицея №1), д.12		0101000020E610000001DF6DDE381942409EB30584D6DD4940
50505	1	8	\N	54503	37577	\N	51.742368999999997	Курская область, город Курск, ул.Семеновская (здание центра "Ступени"), д.78		0101000020E6100000FFAF3A72A4174240384888F205DF4940
50508	1	8	\N	54503	37554	\N	51.742102000000003	Курская область, город Курск, ул.Садовая (здание электромеханического техникума), д.19		0101000020E610000031CEDF8442184240EA25C632FDDE4940
50506	1	8	\N	54503	37554	\N	51.742413999999997	Курская область, город Курск, ул.Садовая (здание института повышения квалификации), д.31		0101000020E6100000EDB94C4D82174240D80B056C07DF4940
50403	1	8	\N	54503	37529	\N	51.742598000000001	Курская область, город Курск, Железнодорожный округ, ул. Республиканская (здание школы №35), д. 50 б/1		0101000020E6100000B18A37328F2042409A0986730DDF4940
50396	1	8	\N	54503	37529	\N	51.743340000000003	Курская область, город Курск, Железнодорожный  округ, ул. Республиканская (здание школы №8), д. 46а		0101000020E610000079AEEFC34120424082E7DEC325DF4940
50431	1	8	\N	54503	37582	\N	51.672477999999998	Курская область, город Курск, Сеймский административный округ, ул. Резиновая (здание МОУ "Межшкольный учебный комбинат"), д. 14		0101000020E610000037A5BC5642134240C6A354C213D64940
50511	1	8	\N	54503	37562	\N	51.750349	Курская область, город Курск, ул, Радищева (здание университета кооперации, экономики и права), д.116		0101000020E610000025C9737D1F1842400CCB9F6F0BE04940
50504	1	8	\N	54503	37562	\N	51.736915000000003	Курская область, город Курск, ул.Радищева (здание общества "Знание"), д.35		0101000020E6100000F964C570751842404777103B53DE4940
50503	1	8	\N	54503	37562	\N	51.735492999999998	Курская область, город Курск, ул.Радищева (здание Курского государственного университета), д.33		0101000020E61000006589CE328B184240EDB776A224DE4940
50529	1	8	\N	54503	37517	\N	51.755043999999998	Курская область, город Курск, ул.Пучковка (здание дома-интерната ветеранов войны и труда), д.82		0101000020E6100000294014CC9812424040852348A5E04940
50493	1	8	\N	54503	37517	\N	51.757151	Курская область, город Курск, ул.Пучковка (здание школы №14), д.13		0101000020E610000069739CDB841342401D91EF52EAE04940
50492	1	8	\N	54503	37517	\N	51.757145000000001	Курская область, город Курск, ул.Пучковка (здание заочного автотранспортного техникума), д.35		0101000020E6100000D40E7F4DD61242403BAA9A20EAE04940
50502	1	8	\N	54503	37526	\N	51.733173000000001	Курская область, город Курск, ул.Почтовая (здание школы №58), д.18а		0101000020E6100000D047197101184240B5A7E49CD8DD4940
50476	1	8	\N	54503	37663	\N	51.776786999999999	Курская область, город Курск, ул.Понизовка (здание учхоза сельскохозяйственной академии), д.52		0101000020E6100000930035B56C1342409E7AA4C16DE34940
50531	1	8	\N	54503	37584	\N	51.714320999999998	Курская область, город Курск, ул.Пионеров (здание школы №17), д.84	Россия, Курская область, город Курск, улица Пионеров, 84	0101000020E6100000581F0F7D771542404AECDADE6EDB4940
50411	1	8	\N	54503	37559	\N	51.707217	Курская область, город Курск, Сеймский административный округ, ул. Пигорева (здание МОУ ДОД "Дворец детского творчества"), д. 7		0101000020E610000055A01683871342406E162F1686DA4940
50474	1	8	\N	54503	37551	\N	51.727800999999999	Курская область, город Курск, ул.Павлуновского (здание торгово-экономического колледжа), д.65		0101000020E6100000C40AB77C24154240807F4A9528DD4940
50381	1	8	\N	54503	37585	\N	51.756141999999997	Курская область, город Курск, Железнодорожный округ, ул. Островского (здание школы №38), д. 10а		0101000020E610000056D5CBEF341B4240E690D442C9E04940
50417	1	8	\N	54503	37541	\N	51.706555896306902	Курская область, город Курск, Сеймский административный округ, ул. Ольшанского (здание МОУ"СОШ№ 39"), д. 27	Россия, Курская область, город Курск, улица Ольшанского	0101000020E610000097E2AAB2EF1242407365506D70DA4940
50412	1	8	\N	54503	37541	\N	51.706455053569897	Курская область, город Курск, Сеймский административный округ, ул .Ольшанского (здание МОУ"СОШ№ 39"), д .27	Россия, Курская область, город Курск, улица Ольшанского, 27	0101000020E61000009BE61DA7E81242403F8C101E6DDA4940
50434	1	8	\N	54503	37539	\N	51.667984884948801	Курская область, город Курск, Сеймский административный округ, ул. Обоянская (здание МУ "Центр народного творчества "Русь"), д. 26		0101000020E6100000B6F468AA27134240FA9B508880D54940
38504	1	6	\N	1634	35357	\N	55.120393	город Обнинск, Гагарина, 47		0101000020E610000051A5660FB44A42406BD5AE09698F4B40
50435	1	8	\N	54503	37589	\N	51.666249999999998	Курская область, город Курск, Сеймский административный округ, ул. Народная (здание ФГО УСПО КГПК"), д. 8		0101000020E610000068CD8FBFB4124240E17A14AE47D54940
50491	1	8	\N	54503	37546	\N	51.732944000000003	Курская область, город Курск, ул.Мыльникова (здание школы №59), д.8		0101000020E61000004014CC988211424054E6E61BD1DD4940
50501	1	8	\N	54503	37553	\N	51.741264999999999	Курская область, город Курск, ул.Мирная (здание школы №5), д.5		0101000020E610000092B06F2711194240B05582C5E1DE4940
50459	1	8	\N	54503	37519	\N	51.668107889864999	Курская область, город Курск, Сеймский административный округ, ул. Менделеева здание МУ "Городской культурный центр "Лира", д. 59		0101000020E61000003198BF42E608424015191D9084D54940
50455	1	8	\N	54503	37519	\N	51.670177000000002	Курская область, город Курск, Сеймский административный округ, ул. Менделеева (здание МОУ"СОШ№ 33"), д. 19		0101000020E61000006494675E0E0B424005C4245CC8D54940
50454	1	8	\N	54503	37519	\N	51.670177000000002	Курская область, город Курск, Сеймский административный округ, ул. Менделеева ( здание МОУ"СОШ№ 33"), д. 19		0101000020E61000006494675E0E0B424005C4245CC8D54940
50382	1	8	\N	54503	37587	\N	51.756242	Курская область, город Курск, Железнодорожный округ, ул. Маяковского (здание института РОСИ), д. 85		0101000020E6100000003ACC97171C42404AEEB089CCE04940
50449	1	8	\N	54503	37581	\N	51.648063	Курская область, город Курск, Сеймский административный округ, Магистральный проезд (здание центра семейного чтения), д. 17		0101000020E610000003CDE7DCED124240B35F77BAF3D24940
50448	1	8	\N	54503	37581	\N	51.648063	Курская область, город Курск, Сеймский административный округ, Магистральный проезд (здание МОК "Центр досуга "Спутник"), д. 17		0101000020E610000003CDE7DCED124240B35F77BAF3D24940
50445	1	8	\N	54503	37581	\N	51.651342999999997	Курская область, город Курск, Сеймский административный округ, Магистральный проезд (здание МОУ"СОШ № 56"), д. 22В		0101000020E6100000C7D633846312424040BD19355FD34940
50444	1	8	\N	54503	37581	\N	51.651063999999998	Курская область, город Курск, Сеймский административный округ, Магистральный проезд (здание МОУ"СОШ№ 41"), д. 20		0101000020E610000001BF4692201442402DCDAD1056D34940
50471	1	8	\N	54503	37592	\N	51.724291999999998	Курская область, город Курск, ул.Ломоносова (здание финансово-экономического института), д.3		0101000020E6100000F5BEF1B5671642409160AA99B5DC4940
50500	1	8	\N	54503	37516	\N	51.7373392344956	Курская область, город Курск, ул.Ленина (здание дворца пионеров и школьников), д.43		0101000020E6100000D1782288F31842405D88D51F61DE4940
50470	1	8	\N	54503	37590	\N	51.723683999999999	Курская область, город Курск, ул.Красной Армии (здание лицея связи), д.23		0101000020E6100000B70A62A06B174240B95164ADA1DC4940
50392	1	8	\N	54503	37540	\N	51.743546000000002	Курская область, город Курск, Железнодорожный округ, ул. Краснознаменная (здание школы №15), д. 13		0101000020E61000008C12F4177A1E42402B89EC832CDF4940
50391	1	8	\N	54503	37540	\N	51.743546000000002	Курская область, город Курск, Железнодорожный округ, ул. Краснознаменная (зание школы №15), д. 13		0101000020E61000008C12F4177A1E42402B89EC832CDF4940
50489	1	8	\N	54503	37575	\N	51.734800999999997	Курская область, город Курск, ул.Косухина (здание школы №55), д.25		0101000020E6100000601DC70F95104240B7088CF50DDE4940
50422	1	8	\N	54503	37572	\N	51.702399999999997	Курская область, город Курск, Сеймский административный округ, ул. Комарова (здание МОУ"СОШ№ 20"), д. 3		0101000020E610000004AA7F10C9124240EE5A423EE8D94940
50421	1	8	\N	54503	37572	\N	51.702399999999997	Курская область, город Курск, Сеймский административный округ, ул. Комарова (здание МОУ"СОШ № 20"), д. 3		0101000020E610000004AA7F10C9124240EE5A423EE8D94940
50418	1	8	\N	54503	37572	\N	51.705492	Курская область, город Курск, Сеймский административный округ, ул. Комарова (здание МОУ"СОШ № 46"), д. 27		0101000020E61000007D91D0967311424079CBD58F4DDA4940
50497	1	8	\N	54503	37563	\N	51.734282	Курская область, город Курск, ул.Кирова (здание гимназии №4), д.22		0101000020E610000026AC8DB1131842404F05DCF3FCDD4940
50404	1	8	\N	54503	37522	\N	51.748473204090899	Курская область, город Курск, Железнодорожный округ, ул. Каширцева (здание Дома детского творчества), д. 5		0101000020E6100000B7989F1B9A1E4240317898F6CDDF4940
50390	1	8	\N	54503	37522	\N	51.752200000000002	Курская область, город Курск, Железнодорожный округ, ул. Каширцева (здание школы №37), д. 54		0101000020E6100000787B1002F21F42408E06F01648E04940
50389	1	8	\N	54503	37522	\N	51.752200000000002	Курская область, город Курск, Железнодорожный округ, Каширцева (здание школы №37), 54		0101000020E6100000787B1002F21F42408E06F01648E04940
50536	1	8	\N	54503	37527	\N	51.784509999999997	Курская область, город Курск, ул.Карла Маркса (здание центра по гидрометеорологии), д.76		0101000020E6100000DCBA9BA73A16424046B1DCD26AE44940
50527	1	8	\N	54503	37527	\N	51.792287000000002	Курская область, город Курск, ул.Карла Маркса (здание УМВД России), д.101		0101000020E610000002D8800871154240E20511A969E54940
50524	1	8	\N	54503	37527	\N	51.751654000000002	Курская область, город Курск, ул, Карла Маркса (здание музыкального колледжа-интерната слепых), д.23		0101000020E6100000B2F2CB608C1842402CF4C13236E04940
50523	1	8	\N	54503	37527	\N	51.759821000000002	Курская область, город Курск, ул.Карла Маркса (здание института сахарной промышленности), д.63		0101000020E61000007AE3A430EF17424032E884D041E14940
50522	1	8	\N	54503	37527	\N	51.755891632624298	Курская область, город Курск, ул.Карла Маркса (здание социального университета), д.51а		0101000020E61000004E621058391842406EA7AD11C1E04940
50521	1	8	\N	54503	37527	\N	51.760936000000001	Курская область, город Курск, ул.Карла Маркса (здание медико-фармацевтического колледжа), д.69		0101000020E61000001A1A4F0471184240AE2CD15966E14940
50519	1	8	\N	54503	37527	\N	51.765054999999997	Курская область, город Курск, ул.Карла Маркса (здание сельскохозяйственной академии), д.70		0101000020E61000003EEDF0D76417424015527E52EDE14940
50518	1	8	\N	54503	37527	\N	51.763500000000001	Курская область, город Курск, ул.Карла Маркса (здание сельскохозяйственной академии), д.70/1		0101000020E6100000FA9B5088801742407D3F355EBAE14940
50515	1	8	\N	54503	37527	\N	51.752946999999999	Курская область, город Курск, ул.Карла Маркса (здание ОАО Курскэнерго"), д.27/31		0101000020E61000001329CDE671184240874F3A9160E04940
50510	1	8	\N	54503	37527	\N	51.749713	Курская область, город Курск, ул.Карла Маркса (здание медицинского университета), д.3		0101000020E610000091B6F1272A1942406A317898F6DF4940
50509	1	8	\N	54503	37527	\N	51.748587000000001	Курская область, город Курск, ул.Карла Маркса (здание педагогического колледжа), д.2		0101000020E6100000FA97A432C5184240FA9AE5B2D1DF4940
50388	1	8	\N	54503	37564	\N	51.759569999999997	Курская область, город Курск, Железнодорожный округ, ул. Ильича (здание школы-интерната №4), д. 31		0101000020E6100000E4C0ABE5CE1E4240E882FA9639E14940
50480	1	8	\N	54503	37545	\N	51.744202778600197	Курская область, город Курск, ул.Запольная (здание дома культуры ОАО "Прибор"), д.45	Россия, Курская область, город Курск, улица Скорятина, 45	0101000020E610000090C18A53AD134240E44A3D0B42DF4940
50424	1	8	\N	54503	37544	\N	51.698028999999998	Курская область, город Курск, Сеймский административный округ, ул. Заводская (здание МОУ "Лицей № 21"), д. 81	Россия, Курская область, город Курск, Заводская улица, 81	0101000020E61000006DC83F33881142406D54A70359D94940
50465	1	8	\N	54503	37661	\N	51.726433999999998	Курская область, город Курск, ул.Добролюбова, (здание детской школы искусств №4), д.4		0101000020E610000068E7340BB4174240EA5910CAFBDC4940
50507	1	8	\N	54503	37555	\N	51.748832	Курская область, город Курск, ул.Димитрова (здание школы №27), д.101		0101000020E61000009FC9FE791A18424061191BBAD9DF4940
50496	1	8	\N	54503	37660	\N	51.726104999999997	Курская область, город Курск, ул.Дзержинского (здание ЦНТИ), д.50		0101000020E6100000166A4DF38E174240253B3602F1DC4940
50423	1	8	\N	54503	37558	\N	51.698169	Курская область, город Курск, Сеймский административный округ, ул. Дейнеки (здание МОУ"СОШ№ 49"), д. 36		0101000020E61000001B0E4B033F1242405F0A0F9A5DD94940
50439	1	8	\N	54503	37552	\N	51.671996999999998	Курская область, город Курск, Сеймский административный округ, ул. Гагарина (здание МОУ ДОД"Дворец детского творчества"), д. 4		0101000020E6100000B4739A05DA1142404B0169FF03D64940
50437	1	8	\N	54503	37552	\N	51.671996999999998	Курская область, город Курск, Сеймский административный округ, ул. Гагарина (здание библиотеки №6), д. 4		0101000020E6100000B4739A05DA1142404B0169FF03D64940
50498	1	8	\N	54503	37566	\N	51.738053000000001	Курская область, город Курск, ул.Володарского (здание школы №32), д.44		0101000020E61000000B24287E8C1942407BDB4C8578DE4940
50482	1	8	\N	54503	37565	\N	51.745134999999998	Курская область, город Курск, ул.Веспремская (здание школы №51), д.1а		0101000020E6100000A35A4414931142406F0D6C9560DF4940
50495	1	8	\N	54503	37569	\N	51.748403000000003	Курская область, город Курск, ул.Верхняя Луговая (здание библиотечной системы), д.241		0101000020E61000004419AA622A154240399D64ABCBDF4940
50494	1	8	\N	54503	37599	\N	51.749372999999999	Курская область, город Курск, ул.Верхняя Казацкая (здание школы №9), д.196		0101000020E6100000EF1EA0FB72144240B1C05774EBDF4940
50384	1	8	\N	54503	37568	\N	51.749920000000003	Курская область, город Курск, Железнодорожный округ, ул. ВЧК (здание школы №34), д. 47		0101000020E61000007C613255301C4240E44EE960FDDF4940
50433	1	8	\N	54503	37557	\N	51.668719000000003	Курская область, город Курск, Сеймский административный округ, ул. Белгородская (здание МОУ"СОШ№ 43 имени Г.К. Жукова"), д. 21		0101000020E61000005CC823B8911242405F9B8D9598D54940
50479	1	8	\N	54503	37561	\N	51.733685999999999	Курская область, город Курск, ул.Аэродромная (здание ОАО Курскгаз"), д.18		0101000020E6100000139CFA40F21242403BC43F6CE9DD4940
50530	1	8	\N	54503	37524	\N	51.717903	Курская область, город Курск, ул.Антокольского (здание школы №11), д.1		0101000020E6100000D788601C5C184240A359D93EE4DB4940
50483	1	8	\N	54503	37532	\N	51.749752000000001	Курская область, город Курск, ул.50 лет Октября (здание профессиональноого училища №5), д.165		0101000020E61000004C8C65FA25124240280EA0DFF7DF4940
50481	1	8	\N	54503	37532	\N	51.748654000000002	Курская область, город Курск, ул.50 лет Октября (здание школы №40), д.163		0101000020E61000004F965AEF371242408202EFE4D3DF4940
50426	1	8	\N	54503	37573	\N	51.702388999999997	Курская область, город Курск, Сеймский административный округ, ул. 3-я Песковская (здание МОУ"СОШ № 3"), д. 23		0101000020E6100000DAE731CA33154240FA08FCE1E7D94940
50408	1	8	\N	54503	37573	\N	51.702388999999997	Курская область, город Курск, Сеймский административный округ, ул.3-я Песковская (здание МОУ"СОШ № 3"), д. 23		0101000020E6100000DAE731CA33154240FA08FCE1E7D94940
50456	1	8	\N	54503	37560	\N	51.67107	Курская область, город Курск, Сеймский административный округ, 3-й Промышленный переулок (здание Автотехнического колледжа), д. 4А		0101000020E610000040DF162CD5094240D2A92B9FE5D54940
50443	1	8	\N	54503	37536	\N	51.663629703874101	Курская область, город Курск, Сеймский административный округ, ул. Энергетиков-2 (здание ОГСКОУ КСКОШ"), д. 22	Россия, Курская область, город Курск, 2-я Энергетиков улица, 21	0101000020E6100000D82D02637D1142407E52EDD3F1D44940
50399	1	8	\N	54503	37518	\N	51.732247286807997	Курская область, город Курск, Железнодорожный округ, ул. 2-я Стрелецкая (здание школы №16), д. 46		0101000020E6100000EBE2361AC01B42400CCC0A45BADD4940
50398	1	8	\N	54503	37533	\N	51.740662999999998	Курская область, город Курск, Железнодорожный  округ, ул. 2-я Рабочая (здание Дорсервиса города Курска), д. 18 в		0101000020E6100000624ED026871F4240BA2D910BCEDE4940
50514	1	8	\N	54503	37580	\N	51.754474999999999	Курская область, город Курск, ул.1-я Офицерская (здание школы №13), д.29		0101000020E610000025B03907CF164240265305A392E04940
50385	1	8	\N	54503	37591	\N	51.757223000000003	Курская область, город Курск, Железнодорожный округ, ул. Профсоюзная (здание Курского техникума ЖД транспорта), д. 11		0101000020E610000096E82CB3081D4240B763EAAEECE04940
50484	1	8	\N	54503	37578	\N	51.743277999999997	Курская область, город Курск, ул.50 лет Октября (здание молодежного центра "Гелиос"), д.102		0101000020E6100000ED82C135771242400BEBC6BB23DF4940
50555	1	8	\N	54489	37415	\N	52.331522202985497	Курская область, город Железногорск, Ленина (здание ОДК ОАО "МГОК"), 11	Россия, Курская область, Железногорск городской округ	0101000020E6100000EE0912DBDDAD4140C7F319506F2A4A40
50552	1	8	\N	4934	37812	\N	52.332787000000003	Курская область, город Железногорск, проезд Ветеранов (Дом Ветеранов войны и труда), 10		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50570	1	8	\N	4934	37499	\N	52.332787000000003	Курская область, город Железногорск, Энтузиастов (здание школы №13), 6		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50571	1	8	\N	4934	37603	\N	52.332787000000003	Курская область, город Железногорск, Привокзальная (здание "Дом-интернат "Надежда"), 7		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50558	1	8	\N	4934	37450	\N	52.332787000000003	Курская область, город Железногорск, Первомайская (здание МУК КЦ "АРТ"), 8		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50560	1	8	\N	4934	37494	\N	52.332787000000003	Курская область, город Железногорск, Парковая (здание школы №3), 10		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50569	1	8	\N	4934	36677	\N	52.338856839473898	Курская область, город Железногорск, Мира (здание школы №9), 47		0101000020E61000001C45D61A4AAF4140A5828AAA5F2B4A40
50574	1	8	\N	4934	37349	\N	52.332787000000003	Курская область, город Железногорск, Маршала Жукова (здание библиотеки), 12	Россия, Курская область, Железногорск	0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50573	1	8	\N	4934	37478	\N	52.332787000000003	Курская область, город Железногорск, Ленина (здание МУК КЦ "Забава"), 84/2		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50556	1	8	\N	4934	37478	\N	52.332787000000003	Курская область, город Железногорск, Ленина (здание школы №2), 15		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50554	1	8	\N	4934	37423	\N	52.332787000000003	Курская область, город Железногорск, Лени Голенькова (здание школы №6), 15		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50553	1	8	\N	4934	37423	\N	52.324712252676498	Курская область, город Железногорск, Лени Голенькова (здание горно-металлургического колледжа), 2а	Россия, Курская область, Железногорск городской округ	0101000020E6100000C2340C1F11AF4140334FAE2990294A40
50568	1	8	\N	4934	37278	\N	52.345953710854999	Курская область, город Железногорск, Курская (здание школы №7), 43	Россия, Курская область, Железногорск	0101000020E61000003F90BC7328AD4140CFF57D38482C4A40
50565	1	8	\N	4934	37278	\N	52.3384756788044	Курская область, город Железногорск, Курская (здание лицея №1), 21		0101000020E6100000D311C0CDE2AD41408E3D7B2E532B4A40
50562	1	8	\N	4934	37278	\N	52.332787000000003	Курская область, город Железногорск, Курская (здание школы №8), 68		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50561	1	8	\N	4934	37278	\N	52.332787000000003	Курская область, город Железногорск, Курская (здание лицея №5), 21		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50559	1	8	\N	4934	37278	\N	52.332787000000003	Курская область, город Железногорск, Курская (здание школы №4), 7		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50557	1	8	\N	4934	37044	\N	52.332787000000003	Курская область, город Железногорск, Комсомольская (здание гимназии №1), 2		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50566	1	8	\N	4934	37447	\N	52.332787000000003	Курская область, город Железногорск, Дружбы (здание гимназии №10), 14		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50567	1	8	\N	4934	37496	\N	52.332787000000003	Курская область, город Железногорск, Детский переулок (здание лицея №12), 18		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50564	1	8	\N	4934	37421	\N	52.340302591308401	Курская область, город Железногорск, Гагарина (здание МОУДОД "Центр детского творчества"), 14	Россия, Курская область, Железногорск городской округ	0101000020E6100000FD2E6CCD56AE414087DD770C8F2B4A40
50572	1	8	\N	4934	37296	\N	52.332787000000003	Курская область, город Железногорск, Воинов Интернационалистов (здание школы №11), 1		0101000020E6100000C0AF912408AF414059C4B0C3982A4A40
50919	1	8	\N	54549	\N	\N	51.640819999999998	Курская область, Курский район, Моковский сельсовет, д.Духовец, Духовецкий сельский клуб	Россия, Курская область, деревня Духовец	0101000020E6100000A2B60DA320084240B54FC76306D24940
50918	1	8	\N	54551	\N	\N	51.757055999999999	Курская область, Курский район, Моковский сельсовет, д.Гремячка, Гремяченская начальная школа	Россия, Курская область, деревня Гремячка	0101000020E61000007FDB1324B60B4240CB9E0436E7E04940
50700	1	8	\N	21688	5814	\N	51.665931	Курская область, Горшеченский район, Старороговский сельсовет село Старороговое, Центральная, здание Старороговского сельсовета	Россия, Курская область, деревня Голубицкое, улица Центральная	0101000020E6100000DAC9E0287917424040321D3A3DD54940
51169	1	8	859	\N	37855	\N	51.223095739674498	Курская область, Пристенский район, село Верхнее Плоское, ул. Центральная (здание администрации Черновецкого с/совета), д. 6	Россия, Курская область, Пристенский район	0101000020E6100000B0C91AF51061424028EFE3688E9C4940
50917	1	8	\N	54499	\N	\N	51.721496999999999	Курская область, Курский район, Моковский сельсовет, д.1-я Моква, Моковская средняя школа	Россия, Курская область, деревня 1-я Моква	0101000020E61000007216F6B4C30B4240C09481035ADC4940
51476	1	8	525	4335	\N	\N	51.862015	Курская область, Щигровский район, Охочевский сельсовет, д.Хитровка, (здание Большеохочевского филиала МОУ "Охочевская средняя общеобразовательная школа")	Россия, Курская область, Щигровский район, поселок Хитровка	0101000020E61000000C1F115322534240AAD4EC8156EE4940
51457	1	8	525	3331	\N	\N	51.936909	Курская область, Щигровский район, Троицкокраснянский сельсовет, д.Сидоровка, (здание администрации муниципального образования "Троицкокраснянский сельсовет")	Россия, Курская область, Щигровский район, поселок Сидоровка	0101000020E6100000618C48145A4E4240FE2955A2ECF74940
51460	1	8	525	3517	\N	\N	51.815972000000002	Курская область, Щигровский район, Вишневский сельсовет, д.Сергеевка, (здание ФАП)	Россия, Курская область, Щигровский район, поселок Сергеевка	0101000020E610000075CB0EF10F814240D2393FC571E84940
51474	1	8	525	4244	\N	\N	51.883179456313698	Курская область, Щигровский район, Охочевский сельсовет, д.1-я Семеновка, (здание администрации муниципального образования "Охочевский сельсовет")	Россия, Курская область, Щигровский район, поселок Семеновка 1-я	0101000020E6100000D07B6308005E4240CAC16C020CF14940
51477	1	8	525	54514	\N	\N	51.849128896914998	Курская область, Щигровский район, Пригородненский сельсовет, сл.Пригородняя, (здание администрации муниципального образования "Пригородненский сельсовет)	Россия, Курская область, Щигровский район, поселок Пригородняя	0101000020E6100000D0F0660DDE714240E78A5242B0EC4940
51464	1	8	525	3722	\N	\N	51.992488999999999	Курская область, Щигровский район, Знаменский сельсовет, д.Пожидаевка, (здание МУК "Знаменский СДК")	Россия, Курская область, Щигровский район, поселок Пожидаевка	0101000020E6100000630CACE3F8594240E3512AE109FF4940
51471	1	8	525	4052	\N	\N	51.791128	Курская область, Щигровский район, Озерский сельсовет, п.Плодовый, (здание администрации муниципального образования "Озерский сельсовет")	Россия, Курская область, Щигровский район, поселок Плодовый	0101000020E6100000D2C6116BF16B42409679ABAE43E54940
51456	1	8	525	3298	\N	\N	51.800141000000004	Курская область, Щигровский район, Титовский сельсовет, д.Новосергиевка, (здание ФАП)	Россия, Курская область, Щигровский район, поселок Новосергиевка	0101000020E6100000209BE447FC4E4240299831056BE64940
51454	1	8	525	3188	\N	\N	52.045912000000001	Курская область, Щигровский район, Теребужский сельсовет,с.Нижний Теребуж, (здание администрации муниципального образования  "Теребужский сельсовет")	Россия, Курская область, Щигровский район, поселок Нижний Теребуж	0101000020E610000003D0285DFA5942403A3FC571E0054A40
51478	1	8	525	4437	\N	\N	51.812998999999998	Курская область, Щигровский район, Пригородненский сельсовет, д.Куликовка, (здание ФАП)	Россия, Курская область, Щигровский район, поселок Куликовка	0101000020E6100000E7ABE463777942402157EA5910E84940
51468	1	8	525	3914	\N	\N	51.845343	Курская область, Щигровский район, Крутовский сельсовет, д.Крутое, (здание администрации муниципального образования Крутовский сельсовет")	Россия, Курская область, Щигровский район, поселок Крутое	0101000020E6100000E1421EC18D66424086730D3334EC4940
51467	1	8	525	3846	\N	\N	51.945436999999998	Курская область, Щигровский район, Кривцовский сельсовет, д.Кривцовка, (здание администрации муниципального образования Кривцовский сельсовет")	Россия, Курская область, Щигровский район, поселок Кривцовка	0101000020E61000001EA7E8482E6B4240D4B6611404F94940
51466	1	8	525	3819	\N	\N	52.095723	Курская область, Щигровский район, Косоржанский сельсовет, с.Косоржа, (здание МУК Косоржанский СДК")	Россия, Курская область, Щигровский район, поселок Косоржа	0101000020E61000000AF65FE7A6614240CD3CB9A6400C4A40
51479	1	8	525	4499	\N	\N	51.848953999999999	Курская область, Щигровский район, Пригородненский сельсовет, д. Козловка, (здание ФАП)	Россия, Курская область, Щигровский район, поселок Козловка	0101000020E6100000471D1D572371424079E75086AAEC4940
51465	1	8	525	3756	\N	\N	52.032383000000003	Курская область, Щигровский район, Касиновский сельсовет, д.Касиновка, (здание МУК Касиновский СДК")	Россия, Курская область, Щигровский район, поселок Касиновка	0101000020E61000004E9D47C5FF67424023F94A2025044A40
51475	1	8	525	54513	\N	\N	51.877806693512802	Курская область, Щигровский район, Охочевский сельсовет, п.Зеленая Роща, (здание Зеленорощинского ФАП)	Россия, Курская область, Щигровский район, поселок Зеленая Роща	0101000020E6100000D55B035B256242409599D2FA5BF04940
51463	1	8	525	3655	\N	\N	51.702126999999997	Курская область, Щигровский район, Защитенский сельсовет, с.Защитное, (здание администрации муниципального образования "Защитенский сельсовет")	Россия, Курская область, Щигровский район, поселок Защитное	0101000020E6100000E10D6954E05E4240BD512B4CDFD94940
51470	1	8	525	4020	\N	\N	52.067740999999998	Курская область, Щигровский район, Никольский сельсовет, д.Длинная, (здание администрации муниципального образования "Никольский сельсовет")	Россия, Курская область, Щигровский район, поселок Длинная	0101000020E61000003D64CA87A078424096CCB1BCAB084A40
51349	1	8	876	29980	37741	\N	51.641412000000003	Курская область, Тимский район, Становской сельсовет,село Становое, ул. Бахаровская, 41		0101000020E610000016DC0F786086424088A1D5C919D24940
51462	1	8	525	3616	\N	\N	51.899107999999998	Курская область, Щигровский район, Вязовский сельсовет, с.Вязовое, (здание МУК "Вязовский СДК")	Россия, Курская область, Щигровский район, поселок Вязовое	0101000020E610000073D87DC7F07A424036C98FF815F34940
51459	1	8	525	3444	\N	\N	51.843561999999999	Курская область, Щигровский район, Вишневский сельсовет, п.Вишневка, (здание Вишневского филиала МОУ "Пригородненская средняя общеобразовательная школа")	Россия, Курская область, Щигровский район, поселок Вишневка	0101000020E6100000AB5CA8FC6B7D4240FD12F1D6F9EB4940
51473	1	8	525	4171	\N	\N	51.913327000000002	Курская область, Щигровский район, Охочевский сельсовет, д.Верхняя Гремячка, (здание Гремяченского филиала МОУ "Охочевская средняя общеобразовательная школа")	Россия, Курская область, Щигровский район, поселок Верхняя Гремячка	0101000020E61000005E68AED3485F4240E3C62DE6E7F44940
51458	1	8	525	3407	\N	\N	52.088276	Курская область, Щигровский район, Большезмеинский сельсовет, с.Большой Змеинец, (здание администрации муниципального образования "Большезмеинский сельсовет")	Россия, Курская область, Щигровский район, поселок Большой Змеинец	0101000020E6100000774D486B0C6E4240C782C2A04C0B4A40
51455	1	8	525	3229	\N	\N	51.767285000000001	Курская область, Щигровский район, Титовский сельсовет, д.Басово, (здание Титовского филиала МОУ "Защитенская средняя общеобразовательная школа")	Россия, Курская область, Щигровский район, поселок Басово	0101000020E6100000F2ECF2AD0F5542400EDB166536E24940
51461	1	8	525	3549	\N	\N	51.977823999999998	Курская область, Щигровский район, Вышнеольховатский сельсовет, д.Апухтина, (здание администрации муниципального образования "Вышнеольховатский сельсовет")	Россия, Курская область, Щигровский район, поселок Апухтина	0101000020E6100000E55FCB2BD7774240389F3A5629FD4940
51469	1	8	525	54546	\N	\N	51.797709017354101	Курская область, Щигровский район, Мелехинский сельсовет, с.2-е Мелехино, (здание Мелехинского филиала МОУ "Защитенская средняя общеобразовательная школа")	Россия, Курская область, Щигровский район, поселок 2-е Мелехино	0101000020E6100000670A9DD7D85B4240C85C19541BE64940
51445	1	8	304	2637	\N	\N	52.018807000000002	Курская область, Черемисиновский район, Стакановский сельсовет, д. Юдинка, здание ООО "Черемисиновское агрообъединение"	Россия, Курская область, Черемисиновский район, поселок Юдинка	0101000020E610000021B07268918D4240CBF78C4468024A40
51424	1	8	304	1360	37368	\N	51.888533941658103	Курская область, Черемисиновский район, п. Черемисиново, Советская, 27	Россия, Курская область, Черемисиновский район, поселок Черемисиново	0101000020E6100000EAEC647094A2424029B16B7BBBF14940
51423	1	8	304	1360	37340	\N	51.887684171534403	Курская область, Черемисиновский район, п. Черемисиново, Кооперативная, 2	Россия, Курская область, Черемисиновский район, поселок Черемисиново	0101000020E61000008D614ED026A142405B971AA19FF14940
51425	1	8	304	1468	\N	\N	51.904986999999998	Курская область, Черемисиновский район, Краснополянский сельсовет, д. Хмелевская, здание администрации Краснополянского сельсовета	Россия, Курская область, Черемисиновский район, поселок Хмелевская	0101000020E61000000C022B8716A542400F27309DD6F34940
51447	1	8	304	2745	\N	\N	51.994751999999998	Курская область, Черемисиновский район, Удеревский сельсовет, д. Удерево здание Удеревского филиала МКОУ "Стакановская средняя, общеобразовательная школа имени лейтенанта А.С. Сергеева"		0101000020E610000063F030ED9B994240B7D0950854FF4940
51433	1	8	304	1936	\N	\N	51.854967000000002	Курская область, Черемисиновский район, Михайловский сельсовет, с. Толстый Колодезь здание Толстоколодезского сельского дома культуры-, филиала МКУК "Михайловский сельский дом культуры"		0101000020E61000005396218E759B42406214048F6FED4940
51434	1	8	304	2027	\N	\N	51.847112000000003	Курская область, Черемисиновский район, Михайловский сельсовет, д. Теплое, здание МКУК "Липовский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Теплое	0101000020E61000001B2B31CF4AAA42404B06802A6EEC4940
51431	1	8	304	1821	\N	\N	51.924303000000002	Курская область, Черемисиновский район, Краснополянский сельсовет, с. Старые Савины, здание МКУК "Старосавинский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Старые Савины	0101000020E61000008DF161F6B2A342401F4C8A8F4FF64940
51444	1	8	304	2599	\N	\N	52.028919999999999	Курская область, Черемисиновский район, Стакановский сельсовет, с. Стаканово, здание МКУК "Стакановский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Стаканово	0101000020E6100000751DAA29C9884240A4198BA6B3034A40
51428	1	8	304	1675	\N	\N	51.989051000000003	Курская область, Черемисиновский район, Краснополянский сельсовет, д. Серединка, здание МКУК "Новосавинский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Серединка	0101000020E6100000BDAC8905BEA84240BE89213999FE4940
51400	1	8	77	32441	\N	\N	51.859512000000002	Курская область, Хомутовский район, Калиновский сельсовет, село Жеденовка, здание Жеденовского филиала МКОУ Калиновская СОШ"	Россия, Курская область, Хомутовский район, поселок Жеденовка	0101000020E6100000D73043E38946414081423D7D04EE4940
51438	1	8	304	2254	\N	\N	51.799695	Курская область, Черемисиновский район, Покровский сельсовет, д. Сельский Рогачик, здание МКОУ "Покровская средняя общеобразовательная школа"	Россия, Курская область, Черемисиновский район, поселок Сельский Рогачик	0101000020E61000008A05BEA25BA142402AE3DF675CE64940
51440	1	8	304	2374	\N	\N	51.918671000000003	Курская область, Черемисиновский район, Русановский сельсовет, с. Русаново, здание МКУК "Русановский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Русаново	0101000020E6100000B804E09F528942404E64E60297F54940
51437	1	8	304	2179	\N	\N	51.903765	Курская область, Черемисиновский район, Петровский сельсовет, с. Петрово-Хутарь, здание МКУК "Петровский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Петрово-Хутарь	0101000020E610000098DBBDDC279B42407D224F92AEF34940
51439	1	8	304	2291	\N	\N	51.771498000000001	Курская область, Черемисиновский район, Покровский сельсовет, д. Огневка, здание фельдшерско-акушерского пункта	Россия, Курская область, Черемисиновский район, поселок Огневка	0101000020E6100000A86DC328089C4240F7764B72C0E24940
51442	1	8	304	2490	\N	\N	51.945470999999998	Курская область, Черемисиновский район, Русановский сельсовет, д. Никитское здание Никитского сельского клуба - филиал МКУК "Русановский сельский дом культуры"		0101000020E6100000DC0F7860008B42408028983105F94940
51443	1	8	304	2519	\N	\N	52.000745999999999	Курская область, Черемисиновский район, Русановский сельсовет, с. Нижнеольховатое здание Нижнеольховатского филиала МКОУ "Русановская средняя, общеобразовательная школа имени В.С. Шатохина"		0101000020E6100000520DFB3DB184424029CDE67118004A40
51436	1	8	304	2150	\N	\N	51.817425	Курская область, Черемисиновский район, Ниженский сельсовет, д. Ниженка, здание МКУК "Ниженский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Ниженка	0101000020E610000084D4EDEC2BA7424066F7E461A1E84940
51432	1	8	304	1901	\N	\N	51.825012999999998	Курская область, Черемисиновский район, Михайловский сельсовет, с. Михайловка, здание МКУК "Михайловский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Михайловка	0101000020E6100000793D98141F8F42402EE3A6069AE94940
51448	1	8	304	2843	\N	\N	51.977103	Курская область, Черемисиновский район, Удеревский сельсовет, д. Крюково здание Крюковского сельского клуба - филиала МКУК "Удеревский сельский дом культуры"		0101000020E61000008AAF7614E79A424068E90AB611FD4940
51427	1	8	304	1595	\N	\N	51.952010000000001	Курская область, Черемисиновский район, Краснополянский сельсовет, д. Карасевка, здание администрации бывшего Новосавинского сельсовета	Россия, Курская область, Черемисиновский район, поселок Карасевка	0101000020E6100000EF1F0BD121A6424084BBB376DBF94940
51446	1	8	304	1705	\N	\N	52.059375000000003	Курская область, Черемисиновский район, Стакановский сельсовет, с. Исаково здание Исаковского филиала МКОУ "Стакановская средняя общеобразовательная, школа имени лейтенанта А.С. Сергеева"		0101000020E610000050711C78B59242409A99999999074A40
51429	1	8	304	1705	\N	\N	52.065829227939602	Курская область, Черемисиновский район, Краснополянский сельсовет, д. Исаково, здание администрации бывшего Старосавинского сельсовета	Россия, Курская область, Черемисиновский район, поселок Исаково	0101000020E61000002A1F82AAD19142406F10AD156D084A40
51426	1	8	304	1565	\N	\N	51.896168000000003	Курская область, Черемисиновский район, Краснополянский сельсовет, д. Ефремовка, здание МКУК "Ефремовский сельский дом культуры"	Россия, Курская область, Черемисиновский район, поселок Ефремовка	0101000020E61000004208C89750A9424062DC0DA2B5F24940
51419	1	8	77	1143	\N	\N	51.988857000000003	Курская область, Хомутовский район, Сальновский сельсовет, деревня Ярославка, здание МУК "Ярославский сельский клуб"	Россия, Курская область, Хомутовский район, поселок Ярославка	0101000020E61000001893FE5E0A3F4140D9B5BDDD92FE4940
51393	1	8	77	32148	37492	\N	51.925381000000002	Курская область, Хомутовский район, поселок Хомутовка, адрес помещения для голосования: ул.Советская, д.11, адрес УИК: ул.Память Ильича, д.176		0101000020E61000005708ABB1844741407EAB75E272F64940
51394	1	8	77	32148	37369	\N	51.917927058966598	Курская область, Хомутовский район, поселок Хомутовка, адрес помещения для голосования: ул.Кирова, д.5, адрес УИК: ул.Память Ильича, д.176	Россия, Курская область, Хомутовский район, поселок Хомутовка	0101000020E6100000909F8D5C37474140C58EC6A17EF54940
51397	1	8	77	32311	\N	\N	51.897835999999998	Курская область, Хомутовский район, Гламаздинский сельсовет, деревня Стрекалово, здание Администрации Гламаздинского с/с	Россия, Курская область, Хомутовский район, поселок Стрекалово	0101000020E6100000CDCD37A27B4E4140F295404AECF24940
51415	1	8	77	896	\N	\N	52.010103999999998	Курская область, Хомутовский район, Романовский сельсовет, село Старшее, адрес помещения для голосования: здание Старшенского филиала МКОУ "Хомутовская СОШ", адрес УИК: здание Администрации Романовского с/с		0101000020E61000001CEC4D0CC94B414086C77E164B014A40
51335	1	8	876	6585	37470	\N	51.621034999999999	Курская область, Тимский район, поселок Тим, ул. Кирова, 25А		0101000020E6100000101FD8F15F904240EF552B137ECF4940
51420	1	8	77	1221	\N	\N	51.861280999999998	Курская область, Хомутовский район, Сковородневский сельсовет, село Сковороднево, адрес помещения для голосования: здание МКОУ "Сковородневская СОШ", адрес УИК: здание Администрации Сковородневского с/с		0101000020E6100000C1E09A3BFA71414045D5AF743EEE4940
51417	1	8	77	1012	\N	\N	51.962749000000002	Курская область, Хомутовский район, Сальновский сельсовет, село Сальное, адрес помещения для голосования: здание МУК "Сальновский СДК", адрес УИК: здание Администрации Сальновского с/с		0101000020E6100000B6D782DE1B374140DCA0F65B3BFB4940
51413	1	8	77	775	\N	\N	51.960796000000002	Курская область, Хомутовский район, Романовский сельсовет, село Романово, здание Администрации Романовского с/с	Россия, Курская область, Хомутовский район, поселок Романово	0101000020E610000040321D3A3D5141405610035DFBFA4940
51403	1	8	77	137	\N	\N	51.832031999999998	Курская область, Хомутовский район, Калиновский сельсовет, деревня Приходьково, здание Приходьковского филиала МКОУ Калиновская СОШ"	Россия, Курская область, Хомутовский район, поселок Приходьково	0101000020E610000025C9737D1F3E4140DC9C4A0680EA4940
51418	1	8	77	1099	\N	\N	52.028615000000002	Курская область, Хомутовский район, Сальновский сельсовет, село Прилепы, адрес помещения для голосования: здание МУК "Прилеповский центральный СДК", адрес УИК: здание Администрации Сальновского с/с		0101000020E6100000B16F2711E13D4140689604A8A9034A40
51411	1	8	77	654	\N	\N	51.828409830277799	Курская область, Хомутовский район, Петровский сельсовет, село Поды, адрес помещения для голосования: здание МКОУ "Подовская СОШ", адрес УИК: здание Администрации Петровского с/с	Россия, Курская область, Хомутовский район, поселок Поды	0101000020E610000087527B116D5B4140F5D6C05609EA4940
51409	1	8	77	534	\N	\N	51.807046	Курская область, Хомутовский район, Петровский сельсовет, село Петровское, здание Петровского филиала МКОУ "Ольховская СОШ"	Россия, Курская область, Хомутовский район, поселок Петровское	0101000020E610000033C51C041D6941400E2F88484DE74940
51410	1	8	77	626	\N	\N	51.790390642005697	Курская область, Хомутовский район, Петровский сельсовет, деревня Переступлено, здание ООО "Переступленское", помещение медпункта	Россия, Курская область, Хомутовский район, поселок Переступлено	0101000020E6100000CBB91457955F4140C00644882BE54940
51404	1	8	77	234	37793	\N	51.835838000000003	Курская область, Хомутовский район, Ольховский сельсовет, село Ольховка, ул.Школьная, д.6		0101000020E610000056647440124E4140856055BDFCEA4940
51406	1	8	77	364	\N	\N	51.758499999999998	Курская область, Хомутовский район, Ольховский сельсовет, деревня Нижняя Туранка, здание Администрации Ольховского с/с	Россия, Курская область, Хомутовский район, поселок Нижняя Туранка	0101000020E6100000CE6F9868905641400C022B8716E14940
51408	1	8	77	498	\N	\N	51.730226999999999	Курская область, Хомутовский район, Ольховский сельсовет, село Нижнее Чупахино, здание МКУК "Нижнечупахинский СДК"	Россия, Курская область, Хомутовский район, поселок Нижнее Чупахино	0101000020E6100000E92807B309644140FED30D1478DD4940
51407	1	8	77	405	\N	\N	51.750025999999998	Курская область, Хомутовский район, Ольховский сельсовет, село Надейка, здание Администрации Ольховского сельсовета	Россия, Курская область, Хомутовский район, поселок Надейка	0101000020E61000009F5A7D75554C414029931ADA00E04940
51421	1	8	77	1268	\N	\N	51.931122999999999	Курская область, Хомутовский район, Сковородневский сельсовет, деревня Меньшиково, здание МУК "Меньшиковский СДК"	Россия, Курская область, Хомутовский район, поселок Меньшиково	0101000020E6100000E63FA4DFBE724140D6C6D8092FF74940
51396	1	8	77	32256	\N	\N	51.884706999999999	Курская область, Хомутовский район, Гламаздинский сельсовет, деревня Малеевка, здание Малеевского филиала МКОУ "Хомутовская СОШ"	Россия, Курская область, Хомутовский район, поселок Малеевка	0101000020E61000002A1A6B7F6763414069C537143EF14940
51412	1	8	77	736	\N	\N	51.749518000000002	Курская область, Хомутовский район, Петровский сельсовет, село Луговое, здание Луговского филиала МКОУ "Ольховская СОШ"	Россия, Курская область, Хомутовский район, поселок Луговое	0101000020E6100000A708707A17734140B5E1B034F0DF4940
51405	1	8	77	268	37698	\N	51.802458000000001	Курская область, Хомутовский район, Ольховский сельсовет, деревня Красная Поляна, ул.Ольховская, 12		0101000020E6100000E527D53E1D4F4140F03499F1B6E64940
51402	1	8	77	93	\N	\N	51.864939999999997	Курская область, Хомутовский район, Калиновский сельсовет, село Клевень, здание клевенского фельдшерско-акушерского пункта	Россия, Курская область, Хомутовский район, поселок Клевень	0101000020E61000000FB402435635414049809A5AB6EE4940
51399	1	8	77	32373	37339	\N	51.899045088229997	Курская область, Хомутовский район, Калиновский сельсовет, село Калиновка, адрес помещения для голосования: ул.Пионерская, д.1, адрес УИК: ул.Ленина, д.11	Россия, Курская область, Хомутовский район, поселок Калиновка	0101000020E61000003BAB05F698404140F05014E813F34940
51422	1	8	77	1337	\N	\N	51.969535	Курская область, Хомутовский район, Сковородневский сельсовет, село Звенячка, здание Звеняченского филиала МКОУ "Хомутовская СОШ"	Россия, Курская область, Хомутовский район, поселок Звенячка	0101000020E6100000AED4B320946B4140E7A90EB919FC4940
51376	1	8	77	31355	\N	\N	51.962598999999997	Курская область, Хомутовский район, Дубовицкий сельсовет, село Дубовица, здание Администрации Дубовицкого с/с	Россия, Курская область, Хомутовский район, поселок Дубовица	0101000020E6100000E4DA5031CE434140C614AC7136FB4940
51416	1	8	77	982	\N	\N	52.030959000000003	Курская область, Хомутовский район, Романовский сельсовет, село Деменино, здание Деменинского филиала МКОУ "Хомутовская СОШ"	Россия, Курская область, Хомутовский район, поселок Деменино	0101000020E6100000FF976BD1025641402942EA76F6034A40
51395	1	8	77	32206	\N	\N	51.9290489733283	Курская область, Хомутовский район, Гламаздинский сельсовет, село Гламаздино, здание МКОУ "Гламаздинская СОШ"	Россия, Курская область, Хомутовский район, поселок Гламаздино	0101000020E6100000CB0F5CE509584140D5B0DF13EBF64940
51414	1	8	77	876	\N	\N	51.982267	Курская область, Хомутовский район, Романовский сельсовет, село Веть, здание МКУК "Ветской СДК"	Россия, Курская область, Хомутовский район, поселок Веть	0101000020E6100000381268B0A95941405378D0ECBAFD4940
51401	1	8	77	32473	\N	\N	51.789256000000002	Курская область, Хомутовский район, Калиновский сельсовет, село Амонь, здание СПК "Мир", каб. Администрации Калиновского с/с		0101000020E6100000DC10E335AF424140FD15325706E54940
51377	1	8	1895	31380	\N	\N	52.278834000000003	Курская область, Фатежский район, Верхнелюбажский сельсовет, д. Ясенок, (здание бывшей администрации Ясенецкого сельсовета)	Россия, Курская область, Фатежский район, поселок Ясенок	0101000020E610000030BC92E4B9E44140A6811FD5B0234A40
51383	1	8	1895	31699	\N	\N	52.199005	Курская область, Фатежский район, Молотычевский сельсовет, с. Хмелевое, (здание МОУ "Хмелевская средняя общеобразовательная школа")	Россия, Курская область, Фатежский район, поселок Хмелевое	0101000020E6100000CA501553E9014240C85EEFFE78194A40
51361	1	8	1895	30548	37301	\N	52.091197000000001	Курская область, Фатежский район, город Фатеж, ул. Тихая (здание МБОУ "ФСОШ №2"), 33		0101000020E6100000CC46E7FC14ED4140253FE257AC0B4A40
51360	1	8	1895	30548	37352	\N	52.091197000000001	Курская область, Фатежский район, город Фатеж, ул.К.Маркса (здание МУК "Районный Дом народного творчества"), 32		0101000020E6100000CC46E7FC14ED4140253FE257AC0B4A40
51385	1	8	1895	31780	\N	\N	52.085979000000002	Курская область, Фатежский район, Русановский сельсовет, с. Сухочево, (здание МКОУ "Сухочевская основная общеобразовательная школа		0101000020E6100000FB5C6DC5FEE441404792205C010B4A40
51368	1	8	1895	30971	\N	\N	52.171816999999997	Курская область, Фатежский район, Банинский сельсовет, с. Сотниково, (здание МУК "Сотниковский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Сотниково	0101000020E610000091D10149D8FB4140CBF27519FE154A40
51388	1	8	1895	54515	\N	\N	52.076090713409997	Курская область, Фатежский район, Солдатский сельсовет, адреc УИК и помещения для голосования: с. Солдатское, (здание МУК "Солдатский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Солдатское	0101000020E610000039ECBE6378DE41408D429259BD094A40
51384	1	8	1895	31726	\N	\N	52.076796999999999	Курская область, Фатежский район, Русановский сельсовет, д. Русановка, (здание МУК "Русановский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Русановка	0101000020E61000003E42CD902AEE414028B7ED7BD4094A40
51367	1	8	1895	30920	\N	\N	52.155132999999999	Курская область, Фатежский район, Банинский сельсовет, д. Ржава, (здание МУК "Ржавский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Ржава	0101000020E6100000232E008DD2ED4140E3C3EC65DB134A40
51390	1	8	1895	32004	\N	\N	52.020414000000002	Курская область, Фатежский район, Солдатский сельсовет, д. Репринка, (здание МКОУ "Любимовская начальная общеобразовательная школ		0101000020E610000012C138B874DE4140B6300BED9C024A40
51392	1	8	1895	32080	\N	\N	51.949849999999998	Курская область, Фатежский район, Солдатский сельсовет, д. Поздняково, (здание МУК "Шуклинский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Поздняково	0101000020E6100000EF02250516D24140840D4FAF94F94940
51387	1	8	1895	31868	\N	\N	52.179853024800501	Курская область, Фатежский район, Русановский сельсовет, с. Нижний Реут, (здание МКОУ "Нижнереутская средняя общеобразовательная школ	Россия, Курская область, Фатежский район, поселок Нижний Реут	0101000020E610000051C1E10511DF4140338B506C05174A40
51391	1	8	1895	54536	\N	\N	52.035293573912	Курская область, Фатежский район, Солдатский сельсовет, д. Нижние Халчи, (здание МУК "Нижнехалчанский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Нижние Холчи	0101000020E6100000DCD7817346D641405DDF878384044A40
51382	1	8	1895	31616	\N	\N	52.254913999999999	Курская область, Фатежский район, Молотычевский сельсовет, с. Молотычи, (здание администрации Молотычевского сельсовета)	Россия, Курская область, Фатежский район, поселок Молотычи	0101000020E61000007D21E4BCFFFB414072A59E05A1204A40
51379	1	8	1895	31475	\N	\N	52.053139000000002	Курская область, Фатежский район, Верхнехотемльский сельсовет, д. Миролюбово, (здание МУК "Миролюбовский сельский клуб")	Россия, Курская область, Фатежский район, поселок Миролюбово	0101000020E6100000787DE6AC4FEB414032923D42CD064A40
44140	1	7	\N	31594	32399	\N	58.365634	Костромская область, город Шарья, ул. 50 лет Советской власти, д. 9		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
51381	1	8	1895	31603	\N	\N	52.086781999999999	Курская область, Фатежский район, Миленинский сельсовет, с. Миленино, (здание администрации Миленинского сельсовета)	Россия, Курская область, Фатежский район, поселок Миленино	0101000020E61000009E5C5320B3F74140D4F02DAC1B0B4A40
51372	1	8	1895	54557	\N	\N	51.911651303905501	Курская область, Фатежский район, Большежировский сельсовет, х. Мелешинка, (здание бывшей администрации Кромского сельсовета)	Россия, Курская область, Фатежский район, поселок Мелешинка	0101000020E61000004B3B35971BE04140CF2EDFFAB0F44940
51371	1	8	1895	54553	\N	\N	51.936512783177399	Курская область, Фатежский район, Большежировский сельсовет, х. Кукуевка, (здание МКОУ Колычевская основная общеобразовательная школа	Россия, Курская область, Фатежский район, поселок Кукуевка	0101000020E6100000D15966118AE74140B1A371A8DFF74940
51375	1	8	1895	31270	\N	\N	52.228141000000001	Курская область, Фатежский район, Верхнелюбажский сельсовет, с. Игино, (здание бывшей администрации Игинского сельсовета)	Россия, Курская область, Фатежский район, поселок Игино	0101000020E6100000FF9600FC53DA414039F06AB9331D4A40
51380	1	8	1895	31569	\N	\N	52.088790000000003	Курская область, Фатежский район, Глебовский сельсовет, д. Зыковка, (здание МУК "Глебовская средняя общеобразовательная школа")	Россия, Курская область, Фатежский район, поселок Зыковка	0101000020E6100000DCD6169E97FC41401E1B81785D0B4A40
51366	1	8	1895	30876	\N	\N	52.199038000000002	Курская область, Фатежский район, Банинский сельсовет, д. Жердево, (здание МУК "Жердевский сельский клуб")	Россия, Курская область, Фатежский район, поселок Жердево	0101000020E6100000C59272F739F24140A454C2137A194A40
51364	1	8	1895	30772	\N	\N	51.985495999999998	Курская область, Фатежский район, Банинский сельсовет, с. Горки, здание МКОУ "Дмитриевская основная общеобразовательная школа	Россия, Курская область, Фатежский район, поселок Горки	0101000020E6100000E675C4211BE041405E2BA1BB24FE4940
51378	1	8	1895	31468	\N	\N	52.005696999999998	Курская область, Фатежский район, Верхнехотемльский сельсовет, д. Верхний Хотемль, (здание администрации Верхнехотемльского сельсовета)	Россия, Курская область, Фатежский район, поселок Верхняя Хотемль	0101000020E61000007D7A6CCB80F14140B857E6ADBA004A40
51374	1	8	1895	31174	\N	\N	52.217305000000003	Курская область, Фатежский район, Верхнелюбажский сельсовет, с. Верхний Любаж, (здание МУК Фатежская межпоселенческая библиотека")	Россия, Курская область, Фатежский район, поселок Верхний Любаж	0101000020E6100000554B3ACAC1EA4140EF2076A6D01B4A40
51373	1	8	1895	31174	\N	\N	52.217305000000003	Курская область, Фатежский район, Верхнелюбажский сельсовет, с. Верхний Любаж, (здание администрации Верхнелюбажского сельсовета)	Россия, Курская область, Фатежский район, поселок Верхний Любаж	0101000020E6100000554B3ACAC1EA4140EF2076A6D01B4A40
51363	1	8	1895	30703	\N	\N	52.089785999999997	Курская область, Фатежский район, Банинский сельсовет, с. Бычки, (здание МУК "Бычковский сельский клуб")	Россия, Курская область, Фатежский район, поселок Бычки	0101000020E61000008429CAA5F1054240BFD18E1B7E0B4A40
51370	1	8	1895	31066	\N	\N	51.957937000000001	Курская область, Фатежский район, Большежировский сельсовет, с. Большое Жирово, (здание МУК "Большежировский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Большое Жирово	0101000020E61000005A68E7340BFC41406E50FBAD9DFA4940
51369	1	8	1895	30984	\N	\N	52.122007000000004	Курская область, Фатежский район, Большеанненковский сельсовет, д. Большое Анненково, (здание МУК "Большеанненковский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок Большое Анненково	0101000020E6100000737FF5B86F0742400971E5EC9D0F4A40
51386	1	8	1895	54545	\N	\N	52.1007524842965	Курская область, Фатежский район, Русановский сельсовет, д. Басовка, (здание администрации Русановского сельсовета)	Россия, Курская область, Фатежский район	0101000020E6100000567F8461C0EA4140D8800871E50C4A40
51389	1	8	1895	31956	\N	\N	51.976858999999997	Курская область, Фатежский район, Солдатский сельсовет, с.Алисово-Покровское, (здание МУК "Алисовский сельский клуб")	Россия, Курская область, Фатежский район, поселок Алисово-Покровское	0101000020E6100000E96514CB2DE14140D1E638B709FD4940
50922	1	8	1895	54517	\N	\N	51.936271971085503	Курская область, Курский район, Нижнемедведицкий сельсовет, с.1-е Шемякино, Шемякинская основная школа	Россия, Курская область, Фатежский район, поселок 1-е Шемякино	0101000020E61000008B37328FFC0342408C14CAC2D7F74940
51362	1	8	1895	30635	\N	\N	52.131726999999998	Курская область, Фатежский район, Банинский сельсовет, с. 1-е Банино, (здание МУК "Банинский сельский Дом культуры")	Россия, Курская область, Фатежский район, поселок 1-е Банино	0101000020E6100000AA4885B185F6414006802A6EDC104A40
51355	1	8	876	30301	37719	\N	51.678688000000001	Курская область, Тимский район, Тимский сельсовет, деревня Шабановка, ул. Шабаново, 49		0101000020E6100000680586AC6E8D42400518963FDFD64940
51356	1	8	876	30331	37744	\N	51.736530000000002	Курская область, Тимский район, Успенский сельсовет, село Успенка, ул. Школьная, 2		0101000020E61000003885950A2A964240EE42739D46DE4940
51336	1	8	876	6585	37472	\N	51.621034999999999	Курская область, Тимский район, поселок Тим, ул. Красноармейская  (МКУК Тимский культурно-спортивный  комплекс)		0101000020E6100000101FD8F15F904240EF552B137ECF4940
51305	1	8	876	27991	37712	\N	51.714666999999999	Курская область, Тимский район, Барковский сельсовет, село Соколье, ул. Школьная, 23		0101000020E610000016C1FF56B27D4240E54350357ADB4940
51338	1	8	876	29497	37804	\N	51.610503999999999	Курская область, Тимский район, Барковский сельсовет, село Рождественка, ул. Центральная, 11		0101000020E6100000739F1C0588744240E109BDFE24CE4940
51341	1	8	876	29617	37805	\N	51.585939000000003	Курская область, Тимский район, Быстрецкий сельсовет, село Рогозцы, ул. Школьная, 29		0101000020E6100000A99F3715A9BE4240B939950C00CB4940
51346	1	8	876	54559	37845	\N	51.685808000000002	Курская область, Тимский район, Ленинский сельсовет, село Рог-Колодезь, ул. Мирная, 8	Россия, Курская область, Тимский район, поселок Рогозецкий Колодезь	0101000020E61000009F3E027FF8B74240E7AA798EC8D74940
51345	1	8	876	29813	\N	\N	51.674382000000001	Курская область, Тимский район, Ленинский сельсовет, деревня Постояновка, ул. Парковая, 6	Россия, Курская область, Тимский район, поселок Постояновка	0101000020E610000095D74AE82EB142406B813D2652D64940
51347	1	8	876	29898	37740	\N	51.594476999999998	Курская область, Тимский район, Погоженский сельсовет, село Погожее, ул. Садовая, 51А		0101000020E6100000A7069ACFB9A14240B29C84D217CC4940
51339	1	8	876	29543	37824	\N	51.618982232083603	Курская область, Тимский район, Барковский сельсовет, село Пахонок, ул. Новая, 10	Россия, Курская область, Тимский район, поселок Пахонок	0101000020E6100000A5DAA7E3316D424006685BCD3ACF4940
51348	1	8	876	29969	37837	\N	51.591355	Курская область, Тимский район, Погоженский сельсовет, деревня Лисий-Колодезь, ул. Репьевская, 1А		0101000020E6100000B76114048FA94240BDA94885B1CB4940
51359	1	8	876	30482	37672	\N	51.752127999999999	Курская область, Тимский район, Успенский сельсовет, село Леженьки, ул. Школьная, 12		0101000020E6100000ABCDFFAB8E864240F433F5BA45E04940
51343	1	8	876	29721	37670	\N	51.556655999999997	Курская область, Тимский район, Выгорновский сельсовет, деревня Кировка, ул. Центральная, 9		0101000020E61000008CDAFD2AC0834240A38FF98040C74940
51358	1	8	876	30455	37720	\N	51.740875000000003	Курская область, Тимский район, деревня Канищево, ул. Школьная, 1		0101000020E610000060E7A6CD389D424046B6F3FDD4DE4940
51357	1	8	876	30371	37807	\N	51.735230999999999	Курская область, Тимский район, Успенский сельсовет, деревня Заречье, пер. Молодежный, 1		0101000020E61000003D27BD6F7C994240B000A60C1CDE4940
51350	1	8	876	30069	37767	\N	51.686244000000002	Курская область, Тимский район, Становской сельсовет, хутор Гнилуши, ул. Камышенская, 22А		0101000020E6100000D15966118A874240C289E8D7D6D74940
51351	1	8	876	30074	37806	\N	51.665210999999999	Курская область, Тимский район, Становской сельсовет, село Гнилое, ул. Ниженка, 1		0101000020E61000003C4D66BCAD7E424040F850A225D54940
51352	1	8	876	30158	37721	\N	51.622131000000003	Курская область, Тимский район, Становской сельсовет, село Третье Выгорное, ул. Запрудная, 67		0101000020E61000002B323A20098D4240F56915FDA1CF4940
51342	1	8	876	29681	37673	\N	51.600921999999997	Курская область, Тимский район, Выгорновский сельсовет, село Второе Выгорное, ул. Придорожная, 22	Россия, Курская область, Тимский район, поселок Выгорное 2-е	0101000020E6100000CE1ABCAFCA8F424034B91803EBCC4940
51353	1	8	876	30209	37613	\N	51.645325	Курская область, Тимский район, Тимский сельсовет, село Первое Выгорное, ул. Мичурина, 8		0101000020E61000001E8997A7738D4240462575029AD24940
51344	1	8	876	29747	37696	\N	51.678376	Курская область, Тимский район, Ленинский сельсовет, село Волобуевка, ул. Придорожная, 40		0101000020E610000063EFC517EDAB424016325706D5D64940
51354	1	8	876	30225	37790	\N	51.669009000000003	Курская область, Тимский район, Тимский сельсовет, село Введенка, ул. Хуторская, 13		0101000020E61000004AB20E475795424066DD3F16A2D54940
51340	1	8	876	29608	37768	\N	51.610644000000001	Курская область, Тимский район, Быстрецкий сельсовет, село Быстрецы, ул. Новая, 22		0101000020E610000091D3D7F335B74240D3BF249529CE4940
51337	1	8	876	29432	37697	\N	51.6988383780524	Курская область, Тимский район, Барковский сельсовет, деревня Барковка, ул. Школьная, 5	Россия, Курская область, Тимский район, поселок Барковка	0101000020E610000015C78157CB714240DD99098673D94940
51306	1	8	740	28060	37789	\N	51.188994000000001	Курская область, Суджанский район, Воробжанский сельсовет, с. Черный Олех, Советская (здание  бывшей Осиповской школы), 1		0101000020E6100000BBB9F8DB9EC24140F39194F430984940
51315	1	8	740	28430	37618	\N	51.294932000000003	Курская область, Суджанский район, Пореченский сельсовет, с. Черкасское Поречное, Выгонок 2 (здание МКУК "Черкасскопореченский СДК"), 11		0101000020E6100000E3C116BB7DAA41409E45EF54C0A54940
51308	1	8	740	28123	37791	\N	51.135865000000003	Курская область, Суджанский район, Уланковский сельсовет, с. Уланок, Центральная (здание  МКУК "Уланковский СДК"), 29		0101000020E61000001FD95C35CFB34140E5D5390664914940
51328	1	8	740	29061	\N	\N	51.299832000000002	Курская область, Суджанский район, Новоивановский сельсовет, с. Толстый Луг, (здание МКОУ "Толстолужская ООШ"), 105		0101000020E6100000CFDC43C2F7864140AB251DE560A64940
51300	1	8	740	6248	37303	\N	51.190883397786997	Курская область, Суджанский район, город Суджа, улица Щепкина (здание МК ДОУ "Детско-юношеский центр"), 18	Россия, Курская область, Суджанский район, Суджа	0101000020E6100000E6B2D1393FA34140622EA9DA6E984940
51302	1	8	740	6248	37476	\N	51.197772000000001	Курская область, Суджанский район, город Суджа, Октябрьская (здание МКОУ "Суджанская СОШ №2"), 12		0101000020E6100000F56915FDA1A141404208C89750994940
51303	1	8	740	6248	37343	\N	51.197921359040798	Курская область, Суджанский район, город Суджа, пер. Заводской (здание МКДОУ "Детский сад №7), 21 А	Россия, Курская область, Суджанский район, Суджа	0101000020E6100000D9EBDD1FEFA141408718AF7955994940
51314	1	8	740	28423	\N	\N	51.085368000000003	Курская область, Суджанский район, Борковский сельсовет, с. Спальное, (здание Спальнянского ФАПа), 109		0101000020E6100000E08442041CBA4140FE0FB056ED8A4940
51324	1	8	740	28873	37792	\N	51.246319	Курская область, Суджанский район, Свердликовский сельсовет, с. Свердликово, Село (здание МКУК "Свердликовский ЦСДК"), 69		0101000020E6100000E5F1B4FCC08F414014B18861879F4940
51316	1	8	740	28491	37841	\N	51.322206000000001	Курская область, Суджанский район, Пореченский сельсовет, с. Русское Поречное, Гора (здание МКОУ "Русскопореченская ООШ), 10		0101000020E6100000B55373B9C1AA41409949D40B3EA94940
51311	1	8	740	28263	37680	\N	51.186635000000003	Курская область, Суджанский район, Махновский сельсовет, д. Русская Конопелька, Центральная, (здание Русскоконопельского ФАПа)		0101000020E610000016DEE522BEB34140FDA4DAA7E3974940
50620	1	8	740	26802	\N	\N	51.333911999999998	Курская область, Большесолдатский район, Большесолдатский сельсовет, село Розгребли, здание МКУК "Розгребельский ЦСДК"	Россия, Курская область, Суджанский район, поселок Розгребли	0101000020E6100000E0D8B3E732B34140F8DEDFA0BDAA4940
51334	1	8	740	29310	\N	\N	51.212347999999999	Курская область, Суджанский район, Замостянский сельсовет, с. Пушкарное, (здание Пушкарского сельского клуба), 35		0101000020E61000000F7F4DD6A8B541407DAF21382E9B4940
51331	1	8	740	29160	37742	\N	51.380077	Курская область, Суджанский район, Погребской сельсовет, с. Погребки, Село (здание МКОУ "Погребская СОШ"), 14		0101000020E6100000139B8F6B439D41401C7BF65CA6B04940
51312	1	8	740	28291	37612	\N	51.102711999999997	Курская область, Суджанский район, Плеховский сельсовет, с. Плехово, Новая (здание  МКУК "Плеховский СДК"), 2	Россия, Курская область, Суджанский район, поселок Плехово	0101000020E6100000EA25C632FDAA41401074B4AA258D4940
51327	1	8	740	28989	\N	\N	51.322054000000001	Курская область, Суджанский район, Новоивановский сельсовет, с. Новоивановка, (здание МКОУ "Новоивановская ООШ"), 87		0101000020E6100000A27E17B6668D4140E3C5C21039A94940
51307	1	8	740	6378	37695	\N	51.120801	Курская область, Суджанский район, Воробжанский сельсовет, с. Нижнемахово, Мира (здание  Нижнемаховского сельского дома культуры), 30 А		0101000020E6100000A01B9AB2D3BD41407C293C68768F4940
51310	1	8	740	28212	37633	\N	51.167836999999999	Курская область, Суджанский район, Махновский сельсовет, с. Махновка, Школьная, (здание МКОУ "Махновская СОШ")		0101000020E6100000AB5D13D21AA741408507CDAE7B954940
51309	1	8	740	28169	37615	\N	51.24492	Курская область, Суджанский район, Мартыновский сельсовет, с. Мартыновка, Центр (здание  МКУК "Мартыновский СДК"), 10		0101000020E6100000B6813B50A7AE41407311DF89599F4940
51330	1	8	740	29152	9892	\N	51.333935052797202	Курская область, Суджанский район, Малолокнянский сельсовет, с. Малая Локня, Молодежная (здание МКОУ "Малолокнянская СОШ"), 7	Россия, Курская область, Суджанский район, поселок Малая Локня	0101000020E61000009ACE4E06479D4140B0FECF61BEAA4940
51326	1	8	740	28983	37758	\N	51.2593417272426	Курская область, Суджанский район, Свердликовский сельсовет, с. Лебедевка, Церковщина (здание МКОУ "Лебедевская ООШ"), 8	Россия, Курская область, Суджанский район, поселок Лебедевка	0101000020E61000000D8AE6012C964140573D601E32A14940
51317	1	8	740	28523	\N	\N	51.379531999999998	Курская область, Суджанский район, Пореченский сельсовет, с. Киреевка, Школьная (здание МКОУ Киреевская ООШ"), 3	Россия, Курская область, Суджанский район, поселок Киреевка	0101000020E61000000AD7A3703DAC41408AE42B8194B04940
51329	1	8	740	29101	37644	\N	51.240882999999997	Курская область, Суджанский район, Казачелокнянский сельсовет, с. Казачья Локня, Новоселовка (здание МКОУ Казачелокнянская СОШ"), 24		0101000020E6100000541A31B3CF9F4140C8940F41D59E4940
51332	1	8	740	29238	\N	\N	51.419479000000003	Курская область, Суджанский район, Погребской сельсовет, с. Ивница, (здание МКОУ "Ивницкая ООШ"), 23		0101000020E6100000357BA01518A64140ED2DE57CB1B54940
51322	1	8	740	28702	37298	\N	51.214751	Курская область, Суджанский район, Заолешенский сельсовет, сл. Заолешенка, Школьная (здание МКОУ "Заолешенская ООШ"), 2		0101000020E6100000DD42572250A1414043E4F4F57C9B4940
51321	1	8	740	28702	37292	\N	51.214751	Курская область, Суджанский район, Заолешенский сельсовет, сл. Заолешенка, Новоселовка (здание МКУК "Заолешенский СДК"), 6		0101000020E6100000DD42572250A1414043E4F4F57C9B4940
51333	1	8	740	54466	37319	\N	51.207928705568698	Курская область, Суджанский район, Замостянский сельсовет, с. Замостье, Ленина, (здание МКУК "Замостянский ЦСДК")	Россия, Курская область, Суджанский район	0101000020E6100000C2A38D23D6A64140EB71DF6A9D9A4940
51325	1	8	740	28918	37836	\N	51.257931999999997	Курская область, Суджанский район, Свердликовский сельсовет, с. Дарьино, Большая (здание МКОУ "Дарьинская ООШ"), 33		0101000020E6100000C780ECF5EE834140C24B70EA03A14940
51318	1	8	740	28598	37640	\N	51.092117999999999	Курская область, Суджанский район, Гуевский сельсовет, с. Гуево, Шлях (здание МКУК "Гуевский ЦСДК"), 9		0101000020E61000009F9273620FA14140BCAFCA85CA8B4940
51320	1	8	740	28620	37293	\N	51.190393999999998	Курская область, Суджанский район, Гончаровский сельсовет, с. Гончаровка, пер. Гагарина 2й (здание МКОУ "Гончаровская СОШ"), 8		0101000020E6100000518369183EA0414064ADA1D45E984940
51319	1	8	740	28620	37337	\N	51.190393999999998	Курская область, Суджанский район, Гончаровский сельсовет, сл. Гончаровка, Мира, (здание МКУК "Гончаровский ЦСДК")		0101000020E6100000518369183EA0414064ADA1D45E984940
51323	1	8	740	28842	37803	\N	51.181322000000002	Курская область, Суджанский район, Заолешенский сельсовет, с. Гоголевка, Центральная (здание МКУК "Гоголевский СДК"), 32		0101000020E610000044E048A0C1964140CD052E8F35974940
51304	1	8	740	27980	37823	\N	51.161527999999997	Курская область, Суджанский район, Воробжанский сельсовет, с. Воробжа, Центральная (здание  МКУК "Воробжанский ЦСДК"), 7		0101000020E6100000BC3FDEAB56BE4140B3B112F3AC944940
51313	1	8	740	5197	37766	\N	51.099024	Курская область, Суджанский район, Борковский сельсовет, с. Борки, Королевка (здание МКОУ "Борковская ООШ"), 36		0101000020E6100000D769A4A5F2B4414072C284D1AC8C4940
51299	1	8	1660	27740	37616	\N	51.510804	Курская область, Солнцевский район, Шумаковский сельсовет, с. Шумаково, Садовая, 4		0101000020E6100000CBD93BA3AD5442403F55850662C14940
51289	1	8	1660	54558	37838	\N	51.334509047512299	Курская область, Солнцевский район, Ивановский сельсовет, х. Шлях, Центральная, 4	Россия, Курская область, Солнцевский район, поселок Шлях	0101000020E6100000B3EE1F0BD14B4240DC9BDF30D1AA4940
51288	1	8	1660	27236	37813	\N	51.378874000000003	Курская область, Солнцевский район, Ивановский сельсовет, с. Чермошное, Центральная, 14		0101000020E6100000C5A9D6C22C48424001A777F17EB04940
51268	1	8	1660	26283	37703	\N	51.577615999999999	Курская область, Солнцевский район, Бунинский сельсовет, д. Хахилево, Садовая, 9		0101000020E610000037FE4465C35A4240BBD23252EFC94940
51278	1	8	1660	26774	37738	\N	51.579323000000002	Курская область, Солнцевский район, Бунинский сельсовет, д. Толмачевка, Толмачевская, 1		0101000020E6100000960A2AAA7E6542400A698D4127CA4940
51293	1	8	1660	27427	37641	\N	51.424106999999999	Курская область, Солнцевский район, Субботинский сельсовет, с. Субботино, переулок Школьный, 4		0101000020E6100000A27C410B0970424099805F2349B64940
51276	1	8	1660	26665	37444	\N	51.410828000000002	Курская область, Солнцевский район, поселок Солнцево, Первомайская, 31		0101000020E61000004A5E9D6340604240FB230C0396B44940
51294	1	8	1660	27512	37816	\N	51.367122999999999	Курская область, Солнцевский район, Субботинский сельсовет, д. Сеймица, Сеймская, 3		0101000020E6100000A3E9EC6470704240014EEFE2FDAE4940
51282	1	8	1660	26972	37669	\N	51.302	Курская область, Солнцевский район, Зуевский сельсовет, с. Сараевка, Школьная, 3		0101000020E61000002C6684B7076B42402DB29DEFA7A64940
51284	1	8	1660	54522	37694	\N	51.348851003813401	Курская область, Солнцевский район, Зуевский сельсовет, х. Ржаво-Плота, Припрудная, 2	Россия, Курская область, Солнцевский район, поселок Ржаво-Плота	0101000020E6100000EC6987BF26634240A5164A26A7AC4940
51298	1	8	1660	27691	37656	\N	51.540010000000002	Курская область, Солнцевский район, Шумаковский сельсовет, с. Плоское, Центральная, 3		0101000020E61000005B5F24B4E54C4240A9C1340C1FC54940
51295	1	8	1660	27566	37600	\N	51.363850999999997	Курская область, Солнцевский район, Субботинский сельсовет, с. Орлянка, Молодежная, 1		0101000020E6100000DC8310902F794240F6CE68AB92AE4940
51297	1	8	1660	54552	37808	\N	51.344932945808203	Курская область, Солнцевский район, Шумаковский сельсовет, х. Малиновка, Можайская, 3	Россия, Курская область, Солнцевский район, поселок Малиновка	0101000020E6100000B51666A19D694240D427B9C326AC4940
51285	1	8	1660	27092	37668	\N	51.401609000000001	Курская область, Солнцевский район, Зуевский сельсовет, д. Княжая, Школьная, 6		0101000020E6100000B5C4CA68E4674240BF6378EC67B34940
51286	1	8	1660	27146	37290	\N	51.431761000000002	Курская область, Солнцевский район, Ивановский сельсовет, д. Ивановка, Жуковка, 11		0101000020E6100000355D4F745D5C42401958C7F143B74940
51283	1	8	1660	27017	37620	\N	51.391638999999998	Курская область, Солнцевский район, Зуевский сельсовет, с. Зуевка, Центральная, 4		0101000020E610000065C405A051624240486B0C3A21B24940
51291	1	8	1660	27342	37739	\N	51.546681999999997	Курская область, Солнцевский район, Старолещинский сельсовет, д. Ефросимовка, Набережная, 2		0101000020E61000004F081D7409714240EBA7FFACF9C54940
51287	1	8	1660	27154	37782	\N	51.472839999999998	Курская область, Солнцевский район, Ивановский сельсовет, с. Дорохо-Доренское, Веселая, 1а		0101000020E6100000A530EF71A6594240CD1E680586BC4940
51159	1	8	1660	21233	37762	\N	51.632345999999998	Курская область, Солнцевский район, Бунинский сельсовет, с. Доброе, Победы, 22		0101000020E610000068CC24EA055B4240D2E0B6B6F0D04940
51281	1	8	1660	26896	37765	\N	51.354689	Курская область, Солнцевский район, Зуевский сельсовет, с. Дежевка, переулок Школьный, 1		0101000020E6100000B1DD3D40F76742401FA0FB7266AD4940
51280	1	8	1660	26879	37692	\N	51.476374	Курская область, Солнцевский район, Зуевский сельсовет, д. Гридасово, Марии Овсянниковой, 22		0101000020E61000007F315BB22A5E42401555BFD2F9BC4940
51290	1	8	1660	27315	37794	\N	51.534256999999997	Курская область, Солнцевский район, Старолещинский сельсовет, с. Гололобовка, Школьная, 1		0101000020E61000007B4B395FEC7742405C548B8862C44940
51194	1	8	1660	22851	37835	\N	51.492134	Курская область, Солнцевский район, Зуевский сельсовет, с. Выползово, Гвардейская, 17		0101000020E610000063F030ED9B5D4240F59F353FFEBE4940
51296	1	8	1660	27589	37717	\N	51.448188000000002	Курская область, Солнцевский район, Шумаковский сельсовет, с. Воробьевка, Центральная, 10		0101000020E6100000C0232A54373B4240D63A71395EB94940
51246	1	8	1660	25290	37748	\N	51.546362000000002	Курская область, Солнцевский район, Бунинский сельсовет, с. Бунино, Центральная, 35		0101000020E61000009CA38E8EAB5742407AE3A430EFC54940
51292	1	8	1660	27424	37769	\N	51.460934029291003	Курская область, Солнцевский район, Старолещинский сельсовет, д. Большая Козьмодемьяновка, Молодежная, 4	Россия, Курская область, Солнцевский район, поселок Большая Козьмодемьяновка	0101000020E61000008789062978724240A7CEA3E2FFBA4940
38281	1	6	\N	40	35380	\N	54.554566999999999	Город  Калуга, ул.Тарутинская, 70/1 (средняя школа №25)		0101000020E610000008C90226702542406D382C0DFC464B40
51277	1	8	1660	26724	37781	\N	51.591428000000001	Курская область, Солнцевский район, Бунинский сельсовет, с. Афанасьевка, Школьная, 13		0101000020E6100000AEB6627FD967424027F8A6E9B3CB4940
51253	1	8	737	25616	\N	\N	51.797500999999997	Курская область, Советский район, Краснодолинский сельсовет, поселок имени Пушкина, здание бывшей Пушкинской начальной школы	Россия, Курская область, Советский район, поселок имени Пушкина	0101000020E6100000064B75012FDB42407EC3448314E64940
51269	1	8	737	26348	\N	\N	51.960424000000003	Курская область, Советский район, Михайлоанненский сельсовет, поселок Садовый, здание cельского клуба филиала п. Садовый	Россия, Курская область, Советский район, поселок Садовый	0101000020E61000008CBD175FB4E542409225732CEFFA4940
51262	1	8	737	26063	\N	\N	51.894311999999999	Курская область, Советский район, Ленинский сельсовет, поселок Расховецкий, здание Расховецкой средней общеобразовательной школы	Россия, Курская область, Советский район, поселок Расховецкий	0101000020E610000060C9552C7EB54240CE35CCD078F24940
51261	1	8	737	26014	\N	\N	51.907932000000002	Курская область, Советский район, Ленинский сельсовет, село Расховец, здание Расховецкого сельского Дома культуры	Россия, Курская область, Советский район, поселок Расховец	0101000020E6100000B35C363AE7BB4240F67EA31D37F44940
51241	1	8	737	25069	\N	\N	51.680939000000002	Курская область, Советский район, Александровский сельсовет, село 1-е Подгородище, здание Подгородищенской основной общеобразовательной школы	Россия, Курская область, Советский район, поселок Подгородище 1-е	0101000020E61000000CB08F4E5DC9424015C9570229D74940
51275	1	8	737	26627	\N	\N	51.910626999999998	Курская область, Советский район, Советский сельсовет, село Петрово-Карцево, здание Петровокарцевской основной общеобразовательной школы	Россия, Курская область, Советский район, поселок Петрово-Карцево	0101000020E61000001C075E2D77E2424063EDEF6C8FF44940
51258	1	8	737	25876	\N	\N	51.903993	Курская область, Советский район, Ледовский сельсовет, село Перцевка, здание филиала № 1 "Мармыжанская средняя общеобразов. школа"	Россия, Курская область, Советский район, поселок Перцевка	0101000020E61000004D4BAC8C46C842400E68E90AB6F34940
51260	1	8	737	25955	\N	\N	51.846989999999998	Курская область, Советский район, Ленинский сельсовет, село Переволочное, здание бывшей администрации Переволоченского сельсовета	Россия, Курская область, Советский район, поселок Переволочное	0101000020E6100000EE98BA2BBBBC4240FF04172B6AEC4940
51254	1	8	737	25696	\N	\N	51.803009000000003	Курская область, Советский район, Краснодолинский сельсовет, село Октябрьское, здание бывшей администрации Октябрьского сельсовета	Россия, Курская область, Советский район, поселок Октябрьское	0101000020E61000007A7077D66ECB424064B2B8FFC8E64940
51272	1	8	737	26470	\N	\N	51.796163999999997	Курская область, Советский район, Нижнеграйворонский сельсовет, село Нижняя Грайворонка, здание Нижнеграйворонского сельского Дома культуры	Россия, Курская область, Советский район, поселок Нижняя Грайворонка	0101000020E610000089981249F4E242405320B3B3E8E54940
51251	1	8	737	25517	\N	\N	51.932073000000003	Курская область, Советский район, Волжанский сельсовет, село Нижнее Гурово, здание Нижнегуровской основная общеобразовательной школа	Россия, Курская область, Советский район, поселок Нижнее Гурово	0101000020E610000083DA6FED44D34240083E062B4EF74940
51270	1	8	737	26369	\N	\N	51.762719449716499	Курская область, Советский район, Нижнеграйворонский сельсовет, деревня Натальино, здание Натальинской основной общеобразовательной школы	Россия, Курская область, Советский район, поселок Натальино	0101000020E6100000FD87F4DBD7E54240D784B4C6A0E14940
51248	1	8	737	25397	\N	\N	51.930289999999999	Курская область, Советский район, Волжанский сельсовет, поселок Моздовка, здание Куйбышевского медпункта	Россия, Курская область, Советский район, поселок Моздовка	0101000020E610000006668522DDDD4240DEE522BE13F74940
51266	1	8	737	54535	\N	\N	51.942518780146898	Курская область, Советский район, Михайлоанненский сельсовет, деревня Михайлоанненка, здание администрации Михайлоанненского сельсовета	Россия, Курская область, Советский район, поселок Михайло-Анненка	0101000020E6100000629D2ADF33DE4240E76D6C76A4F84940
51250	1	8	737	25503	\N	\N	51.879880999999997	Курская область, Советский район, Волжанский сельсовет, село Мелехово, здание Мелеховской начальной школы-детского сада	Россия, Курская область, Советский район, поселок Мелехово	0101000020E6100000E71C3C139AD4424096AFCBF09FF04940
51264	1	8	737	26108	\N	\N	51.773020000000002	Курская область, Советский район, Мансуровский сельсовет, село Мансурово, здание администрации Мансуровского сельсовета	Россия, Курская область, Советский район, поселок Мансурово	0101000020E6100000234DBC033CB94240B493C151F2E24940
51249	1	8	737	25447	\N	\N	51.838403999999997	Курская область, Советский район, Волжанский сельсовет, село Липовчик, здание Липовчанской сельской библиотеки	Россия, Курская область, Советский район, поселок Липовчик	0101000020E61000003291D26C1ED74240F46A80D250EB4940
51160	1	8	859	21286	37679	\N	51.200310999999999	Курская область, Пристенский район, село Большие Сети, ул. Садовая (здание МУК Большесетинский сельский клуб), д. 9		0101000020E61000004B3CA06CCA734240B80375CAA3994940
51256	1	8	737	25757	\N	\N	51.976886	Курская область, Советский район, Ледовский сельсовет, село Ледовское, здание Ледовской средней общеобразовательной школы	Россия, Курская область, Советский район, поселок Ледовское	0101000020E6100000F4A5B73F17C94240CBF5B6990AFD4940
51237	1	8	737	5153	37468	\N	51.844580000000001	Курская область, Советский район, поселок Кшенский, Свердлова (здание Советского педколледжа), 3 "а"		0101000020E6100000D6E253008CDB4240876D8B321BEC4940
51215	1	8	737	5153	37398	\N	51.848357492217197	Курская область, Советский район, поселок Кшенский, Пролетарская (Советский Дом народного творчества), 52	Россия, Курская область, Советский район, поселок Кшенский	0101000020E6100000073F7100FDDC4240952A51F696EC4940
51235	1	8	737	5153	37300	\N	51.844580000000001	Курская область, Советский район, поселок Кшенский, Ленина (здание Дома пионеров и школьников), 13	Россия, Курская область, Советский район, поселок Кшенский	0101000020E6100000D6E253008CDB4240876D8B321BEC4940
51236	1	8	737	5153	37475	\N	51.844580000000001	Курская область, Советский район, поселок Кшенский, Заводская (здание Дома культуры), 2		0101000020E6100000D6E253008CDB4240876D8B321BEC4940
51265	1	8	737	26172	\N	\N	51.765931000000002	Курская область, Советский район, Мансуровский сельсовет, село Крестище, здание Крестищенской средней общеобразовательной школы	Россия, Курская область, Советский район, поселок Крестище	0101000020E6100000747E8AE3C0C742400DFFE9060AE24940
51252	1	8	737	25600	\N	\N	51.780031774870203	Курская область, Советский район, Краснодолинский сельсовет, село Красная Долина, здание Краснодолинской основной общеобразовательной школы	Россия, Курская область, Советский район, поселок Красная Долина	0101000020E610000072193735D0D64240AFEAAC16D8E34940
51274	1	8	737	26581	\N	\N	51.861958999999999	Курская область, Советский район, Советский сельсовет, поселок Коммунар, здание ОБОУ НПО Профессиональное училище № 33	Россия, Курская область, Советский район, поселок Коммунар	0101000020E61000007233DC80CFDF424016BF29AC54EE4940
51267	1	8	737	26261	\N	\N	51.974479000000002	Курская область, Советский район, Михайлоанненский сельсовет, деревня Кирилловка, здание Кирилловской центральной сельской бибилиотеки	Россия, Курская область, Советский район, поселок Кирилловка	0101000020E61000002F52280B5FDF4240C4D155BABBFC4940
51242	1	8	737	25100	\N	\N	51.708696000000003	Курская область, Советский район, Александровский сельсовет, деревня Каменогорка, здание Каменогорского сельского Дома культуры	Россия, Курская область, Советский район, поселок Каменогорка	0101000020E6100000079ACFB9DBC142402C67EF8CB6DA4940
51259	1	8	737	25919	\N	\N	51.867966000000003	Курская область, Советский район, Ленинский сельсовет, поселок имени Ленина, здание администрации Ленинского сельсовета	Россия, Курская область, Советский район, поселок Имени Ленина	0101000020E610000071AB2006BAC642401D05888219EF4940
51243	1	8	737	6529	\N	\N	51.606968999999999	Курская область, Советский район, Верхнерагозецкий сельсовет, деревня Ефросимовка, здание администрации Верхнерагозецкого сельсовета	Россия, Курская область, Советский район, поселок Ефросимовка	0101000020E61000008EAED2DD75C44240C9570229B1CD4940
51273	1	8	737	26550	\N	\N	51.873030999999997	Курская область, Советский район, Советский сельсовет, деревня Дицево, здание администрации Советского сельсовета	Россия, Курская область, Советский район, поселок Дицево	0101000020E6100000B58828266FDE424074B2D47ABFEF4940
51239	1	8	737	24989	\N	\N	51.685886000000004	Курская область, Советский район, Александровский сельсовет, село Грязное, здание Грязновской средней общеобразовательной школы	Россия, Курская область, Советский район, поселок Грязное	0101000020E61000006EDA8CD310D342406364C91CCBD74940
51240	1	8	737	25011	\N	\N	51.70552	Курская область, Советский район, Александровский сельсовет, деревня Городище, здание бывшей администрации Городищенского сельсовета	Россия, Курская область, Советский район, поселок Городище	0101000020E610000007077B1343CC42404356B77A4EDA4940
51247	1	8	737	25329	\N	\N	51.879736999999999	Курская область, Советский район, Волжанский сельсовет, деревня Голощаповка, здание Голощаповского сельского Дома культуры	Россия, Курская область, Советский район, поселок Голощаповка	0101000020E6100000CE6E2D93E1DA4240630AD6389BF04940
51245	1	8	737	25232	\N	\N	51.857976999999998	Курская область, Советский район, Волжанский сельсовет, деревня Волжанец, здание администрации Волжанского сельсовета	Россия, Курская область, Советский район, поселок Волжанец	0101000020E61000009813B4C9E1D942402FDCB930D2ED4940
51244	1	8	737	25186	\N	\N	51.585960999999998	Курская область, Советский район, Верхнерагозецкий сельсовет, село Верхние Апочки, здание Верхнеапоченской средней общеобразовательной школы	Россия, Курская область, Советский район, поселок Верхние Апочки	0101000020E6100000BDAC8905BECE4240A0DD21C500CB4940
51271	1	8	737	26449	\N	\N	51.831052	Курская область, Советский район, Нижнеграйворонский сельсовет, деревня 2-ая Васильевка, здание Васильевского сельского клуба	Россия, Курская область, Советский район, поселок Васильевка 2-я	0101000020E610000068B114C957E0424040A374E95FEA4940
38482	1	6	1252	13373	35585	\N	54.616309000000001	д. Рамено, ул. Садовая, д. 14		0101000020E610000013BBB6B75B664140809D9B36E34E4B40
51263	1	8	737	26104	\N	\N	51.724822000000003	Курская область, Советский район, Мансуровский сельсовет, деревня Бородаевка, здание Кшенской основной общеобразовательной школы	Россия, Курская область, Советский район, поселок Бородаевка	0101000020E61000004D6A6803B0B34240EEB5A0F7C6DC4940
51255	1	8	737	25738	\N	\N	51.821178000000003	Курская область, Советский район, Краснодолинский сельсовет, деревня Березовчик, здание Березовчанской основной общеобразовательной школы	Россия, Курская область, Советский район, поселок Березовчик	0101000020E6100000226DE34F54D44240EC18575C1CE94940
51238	1	8	737	24944	\N	\N	52.001061999999997	Курская область, Советский район, Александровский сельсовет, деревня Александровка, здание администрации Александровского сельсовета	Россия, Курская область, Советский район, поселок Александровка	0101000020E6100000F5A10BEA5BE0424059A2B3CC22004A40
51234	1	8	720	24750	\N	\N	51.549655999999999	Курская область, Рыльский район, Щекинский сельсовет, с.Щекино (здание МКУ, "Щекинский сельский Дом культуры"), д.53		0101000020E6100000BD378600E03E41406C06B8205BC64940
51202	1	8	720	23225	\N	\N	51.563223999999998	Курская область, Рыльский район, Ивановский сельсовет, пос.Учительский (здание Марьинского филиала №2, МБОУ "Ивановская средняя общеобразовательная школа"), д.7 "А"		0101000020E6100000931B45D61A7E414041295AB917C84940
51218	1	8	720	23940	\N	\N	51.428424999999997	Курская область, Рыльский район, Некрасовский сельсовет, д.Сухая  (здание МКУК, "Сухорляновский сельский Дом культуры"), д.127		0101000020E610000040A6B5696C4F4140F7E461A1D6B64940
51231	1	8	720	24601	\N	\N	51.565435000000001	Курская область, Рыльский район, Студенокский сельсовет, с.Студенок (здание МБОУ, "Студенокская средняя общеобразовательная школа"), д.107		0101000020E61000001FBAA0BE652A4140C381902C60C84940
51227	1	8	720	24392	\N	\N	51.579155999999998	Курская область, Рыльский район, Октябрьский сельсовет, с.Степановка (здание филиалам МБОУ, "Рыльская средняя общеобразовательная школа №5"), д.157		0101000020E6100000B745990D327141401EA4A7C821CA4940
51219	1	8	720	5088	\N	\N	51.491069000000003	Курская область, Рыльский район, Некрасовский сельсовет, д.Семеново (здание МКУК, "Семеновский сельский Дом культуры"), д.43		0101000020E610000062855B3E925A41402B8A5759DBBE4940
51212	1	8	720	23633	\N	\N	51.444735999999999	Курская область, Рыльский район, Ломакинский сельсовет, д.Свобода (здание МКУ, "Ломакинский сельский Дом культуры"), д.80		0101000020E61000000892770E653C41404BADF71BEDB84940
51185	1	8	720	22418	9676	\N	51.567227000000003	Курская область, Рыльский район, г.Рыльск (здание МБОУ "Рыльская средняя, общеобразовательная школа №4) ул.Р.Люксембург, д.50	Россия, Курская область, Рыльский район, Рыльск	0101000020E61000001AA4E029E45841404034F3E49AC84940
51188	1	8	720	40354	37490	\N	51.567227000000003	Курская область, Рыльский район, г.Рыльск (здание ОБО У СПО, "Рыльский медицинский колледж) ул.Советская площадь, д.15		0101000020E61000001AA4E029E45841404034F3E49AC84940
51229	1	8	720	40354	37611	\N	51.567714373663001	Курская область, Рыльский район, Пригородненский сельсовет, с.Пригородняя Слободка (здание Администрации Пригородненского сельсовета, Рыльского района Курской области) ул.Советская, д.7 "А"	Россия, Курская область, Рыльский район, Рыльск	0101000020E6100000DA740470B35841409DBD33DAAAC84940
51193	1	8	720	40354	9914	\N	51.567227000000003	Курская область, Рыльский район, г.Рыльск (здание ООО "Рыльск"), ул.Р.Люксембург, д.77	Россия, Курская область, Рыльский район, Рыльск	0101000020E61000001AA4E029E45841404034F3E49AC84940
51192	1	8	720	40354	67738	\N	51.567227000000003	Курская область, Рыльский район, г.Рыльск (здание МБОУ ДОД  "Рыльская, детско-юношеская спортивная школа") ул.Кирова, д.2 м		0101000020E61000001AA4E029E45841404034F3E49AC84940
51189	1	8	720	40354	37412	\N	51.573186363143201	Курская область, Рыльский район, г.Рыльск (здание Рыльского АТК - филиала ФГБОУ высшего ПО "Московский, государственный технический университет ГА") ул.Дзержинского, д.18	Россия, Курская область, Рыльский район, Рыльск	0101000020E610000066FA25E2AD5741403543AA285EC94940
51187	1	8	720	40354	37412	\N	51.567227000000003	Курская область, Рыльский район, г.Рыльск (здание ОБОУСПО "Рыльский социально-педагогический, колледж Курской области") ул.Дзержинского, д.53		0101000020E61000001AA4E029E45841404034F3E49AC84940
51207	1	8	720	23410	\N	\N	51.645229999999998	Курская область, Рыльский район, Крупецкий сельсовет, д.Рыжевква  (здание МКУ, "Рыжевский сельский Дом культуры"), д.185		0101000020E6100000AF78EA9106294140F4328AE596D24940
51225	1	8	720	24293	\N	\N	51.718037000000002	Курская область, Рыльский район, Никольниковский сельсовет, с.Поповка  (здание МКУ, "Поповкинский сельский Дом культуры"), д.37		0101000020E610000063D2DF4BE1394140B328ECA2E8DB4940
51226	1	8	720	24362	\N	\N	51.578299000000001	Курская область, Рыльский район, Октябрьский сельсовет, с.Октябрьское (здание Октябрьского филиала МКУ, "Степановский центральный сельский Дом культуры"), д.103		0101000020E61000005A10CAFB386641409E279EB305CA4940
51220	1	8	720	24076	37787	\N	51.680464000000001	Курская область, Рыльский район, Нехаевский сельсовет, с.Нехаевка  (здание МКУ, "Нехаевский сельский Дом культуры" ) ул.Центральная, д.56		0101000020E6100000810A47904A3941407C0DC17119D74940
51026	1	8	786	14465	37708	\N	51.414046999999997	Курская область, Мантуровский район, Ястребовский сельсовет, село Крутые Верхи, Школьная (здание школы), 76		0101000020E61000002524D236FEB24240E200FA7DFFB44940
51214	1	8	720	23780	\N	\N	51.617019999999997	Курская область, Рыльский район, Михайловский сельсовет, с.Михайловка  (здание Михайловского филиала МБОУ, "Щекинская средняя общеобразовательная школа"), д.160		0101000020E61000009F3BC1FEEB3A41402C7DE882FACE4940
51222	1	8	720	24168	\N	\N	51.675018999999999	Курская область, Рыльский район, Никольниковский сельсовет, с.Макеево (здание МКУ, "Макеевский сельский Дом культуры"), д.83		0101000020E6100000D9EE1EA0FB444140DD96C80567D64940
51228	1	8	720	24468	\N	\N	51.612887000000001	Курская область, Рыльский район, Октябрьский сельсовет, с.Мазеповка (здание Мазеповского филиала МКУ, "Степановский центральный сельский Дом культуры"), д.127		0101000020E6100000B9162D40DB6A41406092CA1473CE4940
51206	1	8	720	23402	\N	\N	51.670216000000003	Курская область, Рыльский район, Козинский сельсовет, с.Локоть (здание МКУ, "Локотский сельский Дом культуры"), 278		0101000020E61000002CF4C132361C4140C3A04CA3C9D54940
51198	1	8	720	23035	37811	\N	51.569941999999998	Курская область, Рыльский район, Бобровский сельсовет, д.Кулига (здание Бобровского, филиала МБОУ "Рыльская средняя  бщеобразовательная школа №5", д.60	Россия, Курская область, Рыльский район, поселок Кулига	0101000020E61000005BEB8B84B6484140F44E05DCF3C84940
51196	1	8	720	22940	\N	\N	51.657043000000002	Курская область, Рыльский район, Березниковский сельсовет, с.Кострова  (здание МКУ, Костровский сельский Дом культуры"), д.80		0101000020E6100000D3D9C9E0285741406A882AFC19D44940
51205	1	8	720	23324	\N	\N	51.632702999999999	Курская область, Рыльский район, Козинский сельсовет, с.Козино (здание МКУ, Козинский сельский Дом культуры"), д.183	Россия, Курская область, Рыльский район, поселок Козино	0101000020E610000082700514EA194140618A7269FCD04940
51197	1	8	720	22951	\N	\N	51.693657999999999	Курская область, Рыльский район, Березниковский сельсовет, с.Капыстичи  (здание Капыстичанского  филиала, МБОУ Костровская средняя общеобразовательная школа"), д.103		0101000020E6100000373465A71F6C4140EC4D0CC9C9D84940
51213	1	8	720	23701	37396	\N	51.504604	Курская область, Рыльский район, Малогнеушевский сельсовет, пос.им.Куйбышева (здание здание МКУ "Дом, культуры пос. им.Куйбышева") ул.Лесная, д.9 "А"		0101000020E6100000CDAE7B2B125D414024B726DD96C04940
51201	1	8	720	54534	37743	\N	51.614061	Курская область, Рыльский район, Ивановский сельсовет, с.Ивановское (здание Комаровского филиала МКУК, "Ивановская поселенческая библиотека") ул.Комаровка, д.37		0101000020E61000000C23BDA8DD774140E15F048D99CE4940
51200	1	8	720	23129	37443	\N	51.614061	Курская область, Рыльский район, Ивановский сельсовет, с.Ивановское (здание МКУ "Ивановский, сельский Дом культуры") ул.Ананьева, д.1 "А"		0101000020E61000000C23BDA8DD774140E15F048D99CE4940
51199	1	8	720	23049	\N	\N	51.503757999999998	Курская область, Рыльский район, Дуровский сельсовет, с.Дурово (здание МКУ, "Дуровский сельский Дом культуры"), д.85		0101000020E61000003885950A2A444140978C63247BC04940
51210	1	8	720	23495	\N	\N	51.611159000000001	Курская область, Рыльский район, Крупецкий сельсовет, д.Воронок (помещение МКУК, "Воронокская поселенческая библиотека"), д.131		0101000020E6100000A7052FFA0A264140FAD346753ACE4940
51208	1	8	720	23495	\N	\N	51.611159000000001	Курская область, Рыльский район, Крупецкий сельсовет, д.Воронок  (здание МКУК, "Воронокская поселенческая библиотека"), 131		0101000020E6100000A7052FFA0A264140FAD346753ACE4940
51217	1	8	720	23905	\N	\N	51.483452999999997	Курская область, Рыльский район, Некрасовский сельсовет, с.Большенизовцево (здание Большенизовцевского филиала  МБОУ, "Рыльская средняя общеобразовательная школа №5"), д.113		0101000020E6100000A296E656084F41409813B4C9E1BD4940
51224	1	8	720	24263	\N	\N	51.716178999999997	Курская область, Рыльский район, Никольниковский сельсовет, с.Большегнеушево  (здание МКУ, "Большегнеушевский сельский  Дом культуры"), д.146		0101000020E610000027DBC01DA84541407E8AE3C0ABDB4940
51195	1	8	720	22867	\N	\N	51.615085000000001	Курская область, Рыльский район, Березниковский сельсовет, с.Березники, (здание МКУ "Стропицкой сельский Дом культуры"), д.72		0101000020E6100000E4D70FB1C16441404DA1F31ABBCE4940
51221	1	8	720	24087	37772	\N	51.685512000000003	Курская область, Рыльский район, Нехаевский сельсовет, с.Бегоща (здание Бегощанского филиала МКУ, "Нехаевский сельский Дом культуры") ул.Дубовка, д.60		0101000020E610000059DE550F982D4140FE8172DBBED74940
51216	1	8	720	23853	\N	\N	51.450612999999997	Курская область, Рыльский район, Некрасовский сельсовет, с.Артюшково  (здание МКУК, "Артюшковский сельский Дом культуры"), д.33		0101000020E6100000E814E467236541408313D1AFADB94940
51233	1	8	720	24722	\N	\N	51.490670999999999	Курская область, Рыльский район, Студенокский сельсовет, д.Анатольевка (здание Анатольевского филиала, "Студенокская средняя общеобразовательная школа"), д.74		0101000020E610000075B169A5102A41403D0CAD4ECEBE4940
51230	1	8	720	54518	\N	\N	51.584691866613802	Курская область, Рыльский район, Студенокский сельсовет, х.Александровка  (здание МБОУ, "Александровский сельский Дом культуры"), 103	Россия, Курская область, Рыльский район, поселок Александровка	0101000020E610000044300E2E1D2F4140CD1DFD2FD7CA4940
51232	1	8	720	24669	\N	\N	51.507995999999999	Курская область, Рыльский район, Студенокский сельсовет, с.Акимовка (здание Акимовского филиала, МБОУ "Студенокская средняя общеобразовательная школа"), д.129		0101000020E6100000224F92AE99324140D93F4F0306C14940
51223	1	8	720	24181	\N	\N	51.627626999999997	Курская область, Рыльский район, Никольниковский сельсовет, д.1-е Яньково (здание  Администрации Никольниковского сельсовета, Рыльского района Курской области), д.40		0101000020E6100000C7D79E59124C4140158BDF1456D04940
51175	1	8	859	21994	37788	\N	51.205739999999999	Курская область, Пристенский район, село Ярыгино, ул. Центральная (здание МОУ Ярыгинская НОШ), д. 32		0101000020E6100000D734EF38455B424051BD35B0559A4940
51168	1	8	859	21667	\N	\N	51.258473000000002	Курская область, Пристенский район, село Черновец, ул.Молодежная (здание администрации Черновецкого сельсовета), д. 1		0101000020E6100000BB473657CD79424013F3ACA415A14940
51155	1	8	859	21025	37726	\N	51.195830000000001	Курская область, Пристенский район, село Троицкое, ул. Клубная (здание МУК Троицкий сельский клуб), д. 40		0101000020E6100000BB9C121093404240B0C91AF510994940
51174	1	8	859	21959	37763	\N	51.147754999999997	Курская область, Пристенский район, село Средняя Ольшанка, ул. Школьная (здание МОУ Среднеольшанская СОШ), д. 51		0101000020E61000009BC761307F4B42400569C6A2E9924940
51157	1	8	859	21162	37617	\N	51.341648999999997	Курская область, Пристенский район, село Сазановка, ул. Школьная (здание МОУ Сазановская СОШ), д. 6		0101000020E6100000A5A14621C978424005DB8827BBAB4940
51156	1	8	859	21109	\N	\N	51.156840000000003	Курская область, Пристенский район, село Ракитинка, ул. Плант (здание администрации Бобрышевского сельсовета), д. 19		0101000020E61000002992AF0452404240325A475513944940
51164	1	8	859	21470	\N	\N	51.285778999999998	Курская область, Пристенский район, село Пселец, ул. Центральная (здание администрации Котовского сельсовета), д. 88		0101000020E6100000FAB660A92E4642401971016894A44940
51182	1	8	859	22244	37407	\N	51.236433933747001	Курская область, Пристенский район, поселок Пристень, ул. Советская (здание МУК РДК п. Пристень), д. 53	Россия, Курская область, Пристенский район, поселок Пристень	0101000020E610000016A75A0BB3584240CCD42478439E4940
51181	1	8	859	22244	37407	\N	51.236220000000003	Курская область, Пристенский район, поселок Пристень, ул. Советская (здание МОУ СОШ №2 п. Пристень), д. 49		0101000020E61000005E85949F54594240A054FB743C9E4940
51180	1	8	859	22244	37466	\N	51.236220000000003	Курская область, Пристенский район, поселок Пристень, ул. Почтовая (здание МОУ СОШ №1 п. Пристень), д. 56		0101000020E61000005E85949F54594240A054FB743C9E4940
51148	1	8	859	20680	37693	\N	51.212336999999998	Курская область, Пристенский район, село Пристенное, ул. Центральная (здание администрации Пристенского с/совета), д. 30		0101000020E61000000D52F01472694240895DDBDB2D9B4940
51172	1	8	859	21858	37735	\N	51.244993999999998	Курская область, Пристенский район, деревня Прилепы, ул. Пигоревых (здание МОУ Прилепская ООШ), д. 8-А		0101000020E610000029081EDFDE6B4240ADDBA0F65B9F4940
51166	1	8	859	21563	37736	\N	51.220320000000001	Курская область, Пристенский район, село Нагольное, ул. Центральная (здание МОУ Нагольненская ООШ), д. 17		0101000020E6100000569E40D829484240CE531D72339C4940
51167	1	8	859	21590	\N	\N	51.266019	Курская область, Пристенский район, хутор Луг, ул.Школьная (здание администрации Нагольненского сельсовета), д. 7		0101000020E6100000BA1457957D534240AC8E1CE90CA24940
51163	1	8	859	21411	37764	\N	51.243763999999999	Курская область, Пристенский район, село Красниково, ул. Кирова (здание Красниковского медпункта), д. 21		0101000020E6100000DF6C73637A34424098F8A3A8339F4940
51162	1	8	859	21371	37727	\N	51.270741999999998	Курская область, Пристенский район, село Котово, ул. Центральная (здание МУК Котовский ЦСДК), д. 11-А		0101000020E610000028D714C8EC364240AAD381ACA7A24940
51161	1	8	859	21323	37834	\N	51.258991000000002	Курская область, Пристенский район, село Колбасовка, ул. Центральная (здание МУК Колбасовский СДК), д. 128		0101000020E6100000C91D369199634240AB7AF99D26A14940
51178	1	8	859	22145	37394	\N	51.303677999999998	Курская область, Пристенский район, поселок Кировский, ул. Ломоносова (здание МОУ Кировская СОШ), д. 16		0101000020E6100000488AC8B08A5B4240E141B3EBDEA64940
51179	1	8	859	22145	37604	\N	51.303677999999998	Курская область, Пристенский район, поселок Кировский, ул. Дзержинского (здание администрации п. Кировский), д. 40		0101000020E6100000488AC8B08A5B4240E141B3EBDEA64940
51158	1	8	859	21182	37761	\N	51.324187000000002	Курская область, Пристенский район, село Ильинка, ул. Центральная (здание МОУ Донсемицкая ООШ), д. 6-А		0101000020E61000007102D369DD6E4240E964A9F57EA94940
51154	1	8	859	6432	37678	\N	51.254633862386498	Курская область, Пристенский район, Бобрышевский сельсовет, хутор Еринка, ул. Центральная (здание МУК Еринский сельский клуб), д. 76	Россия, Курская область, Пристенский район, поселок Еринка	0101000020E610000014AFB2B6293E42408F39CFD897A04940
51170	1	8	859	21767	37725	\N	51.279311999999997	Курская область, Пристенский район, село Владимировка, ул. Владимировская (здание МОУ Владимировская ООШ), д. 1		0101000020E61000008E91EC116A884240AFB0E07EC0A34940
51177	1	8	859	22089	37737	\N	51.219439999999999	Курская область, Пристенский район, поселок Вихровский, ул. Ватутина (здание ЧП Сосолопов Ю. Г.), д. 14		0101000020E6100000B4E4F1B4FC56424095B7239C169C4940
51176	1	8	859	22060	37770	\N	51.196173999999999	Курская область, Пристенский район, деревня Вихровка, ул. Молодежная (здание МОУ Вихровская ООШ), д. 27		0101000020E610000034F5BA45605E4240AA29C93A1C994940
51173	1	8	859	21891	\N	\N	51.158138999999998	Курская область, Пристенский район, село Верхняя Ольшанка, ул. Озерова (здание МУК Верхнеольшанский дом культуры), д. 17	Россия, Курская область, Пристенский район, поселок Верхняя Ольшанка	0101000020E61000002B16BF29AC5442406F9C14E63D944940
51165	1	8	859	21504	\N	\N	51.328838721465502	Курская область, Пристенский район, село Большие Крюки, ул. Выгон (здание администрации Котовского сельсовета), д. 41	Россия, Курская область, Пристенский район, поселок Большие Крюки	0101000020E610000030664B56453842401E53776517AA4940
51153	1	8	859	20938	37654	\N	51.20973	Курская область, Пристенский район, с. Бобрышево, ул. Плант (здание МУК Бобрышевский ЦСДК), д. 131/1		0101000020E61000006ADB300A82374240BB7EC16ED89A4940
51147	1	8	681	20616	\N	\N	52.189056999999998	Курская область, Поныровский район, Ольховатский сельсовет, село Становое (помещение МКОУ "Становская средняя общеобразовательная школа")	Россия, Курская область, Поныровский район, поселок Становое	0101000020E610000056D636C5E30E4240390A100533184A40
51136	1	8	681	19867	37465	\N	52.318393999999998	Курская область, Поныровский район, поселок Поныри, ул. Октябрьская (помещение МКОУ "Поныровская средняя общеобразовательная школа"), 119		0101000020E6100000AB5FE97C782642400E9F7422C1284A40
51134	1	8	681	19867	37406	\N	52.318393999999998	Курская область, Поныровский район, поселок Поныри, ул. Ленина (помещение МКУК "Поныровский центр культуры и досуга"), 12		0101000020E6100000AB5FE97C782642400E9F7422C1284A40
51135	1	8	681	19867	37334	\N	52.318393999999998	Курская область, Поныровский район, поселок Поныри, ул. Веселая (помещение МКОУ "Поныровская средняя общеобразовательная школа"), 14		0101000020E6100000AB5FE97C782642400E9F7422C1284A40
51137	1	8	681	20010	\N	\N	52.276750999999997	Курская область, Поныровский район, Первомайский сельсовет, село Первомайское (помещение МКУК "Первомайский сельский Дом культуры")	Россия, Курская область, Поныровский район, поселок Первомайское	0101000020E61000004930D5CC5A3642405111A7936C234A40
51146	1	8	681	20574	\N	\N	52.252912999999999	Курская область, Поныровский район, Ольховатский сельсовет, село Ольховатка (помещение МКОУ "Ольховатская средняя общеобразовательная школа"		0101000020E61000000455A35703104240DBDD03745F204A40
51145	1	8	681	20514	\N	\N	52.179118000000003	Курская область, Поныровский район, Верхне-Смородинский сельсовет, село Нижнесмородино (помещение МКУК "Матвеевский сельский Дом культуры")	Россия, Курская область, Поныровский район, поселок Нижнесмородино	0101000020E610000011E4A084991A4240FE0FB056ED164A40
51149	1	8	681	20724	\N	\N	52.297953999999997	Курская область, Поныровский район, Ольховатский сельсовет, село Игишево (помещение МКУК "Игишевский сельский Дом культуры")	Россия, Курская область, Поныровский район, поселок Игишево	0101000020E61000009737876BB50342402FDB4E5B23264A40
51140	1	8	681	4738	\N	\N	52.166310000000003	Курская область, Поныровский район, Горяйновский сельсовет, село Горяйново (помещение МКУК "Горяйновский сельский Дом культуры")	Россия, Курская область, Поныровский район, поселок Горяйново	0101000020E6100000E98024ECDB354240B77F65A549154A40
51142	1	8	681	20349	37659	\N	52.185220000000001	Курская область, Поныровский район, Возовский сельсовет, поселок Возы, ул. Комсомольская (помещение МКОУ "Возовская средняя общеобразовательная школа")		0101000020E6100000340EF5BBB02342405648F949B5174A40
51144	1	8	681	20462	\N	\N	52.206240999999999	Курская область, Поныровский район, Верхне-Смородинский сельсовет, село Верхнесмородино помещение МКУК "Верхнесмородинский сельский Дом культуры")		0101000020E61000000C01C0B167194240130CE71A661A4A40
51143	1	8	681	20375	\N	\N	52.215257999999999	Курская область, Поныровский район, Возовский сельсовет, село Брусовое помещение МКУК "Брусовской сельский Дом культуры")		0101000020E61000006342CC2555294240E719FB928D1B4A40
51141	1	8	681	20281	\N	\N	52.212178999999999	Курская область, Поныровский район, Горяйновский сельсовет, село Бобровка (здание МКОУ "Бобровская основная общеобразовательная школа")	Россия, Курская область, Поныровский район, поселок Бобровка	0101000020E6100000179B560A81364240F1F274AE281B4A40
51139	1	8	681	20146	\N	\N	52.249488999999997	Курская область, Поныровский район, Первомайский сельсовет, село Березовец (помещение МКОУ "Березовецкая основная общеобразовательная школа")	Россия, Курская область, Поныровский район, поселок Березовец	0101000020E6100000CDE7DCED7A2D42401ADB6B41EF1F4A40
51150	1	8	681	20784	37652	\N	52.270017000000003	Курская область, Поныровский район, 2-й Поныровский сельсовет, село 2-Поныри, ул. Писаревка (помещение МКУК "2-Поныровский сельский Дом культуры)		0101000020E610000018B2BAD5731A4240992EC4EA8F224A40
51151	1	8	681	20828	37724	\N	52.321734999999997	Курская область, Поныровский район, 1-й Поныровский сельсовет, село 1-Поныри, ул. Майоровка (помещение МКОУ "Первопоныровская основная общеобразовательная школа)		0101000020E6100000F10D85CFD6214240417DCB9C2E294A40
51152	1	8	681	20828	37802	\N	52.321734999999997	Курская область, Поныровский район, 1-й Поныровский сельсовет, село 1-Поныри, ул. Бугровка (помещение МКОУ "1-Поныровская начальная общеобразовательная школа"		0101000020E6100000F10D85CFD6214240417DCB9C2E294A40
51112	1	8	1552	18723	\N	\N	51.649242000000001	Курская область, Октябрьский район, Черницынский сельсовет, село Черницыно, помещение МКОУ "Черницынская СОШ"	Россия, Курская область, Октябрьский район, поселок Черницыно	0101000020E610000086915ED4EEFD41404698A25C1AD34940
43790	1	7	\N	53351	32511	\N	58.820864	Костромская область, Кологривский район, город Кологрив, ул. Центральная, д.13		0101000020E610000014596B28B52946405C3B511212694D40
51114	1	8	1552	18723	37609	\N	51.649242000000001	Курская область, Октябрьский район, Черницынский сельсовет, село Черницыно, Центральная, помещение "Черницынская библиотека"		0101000020E610000086915ED4EEFD41404698A25C1AD34940
51130	1	8	1552	19632	\N	\N	51.760272999999998	Курская область, Октябрьский район, Старковский сельсовет, село Старково, помещение "Старковский СДК"	Россия, Курская область, Октябрьский район, поселок Старково	0101000020E61000004B0169FF03EE414012842BA050E14940
51115	1	8	1552	18505	37651	\N	51.652461000000002	Курская область, Октябрьский район, посёлок Прямицыно, Сеймская, помещение "Черницынский сельсовет"		0101000020E61000000917F2086EF841402E7590D783D34940
51108	1	8	1552	18505	37386	\N	51.652461000000002	Курская область, Октябрьский район, поселок Прямицыно, Первомайская, помещение МКДОУ "Радуга"		0101000020E61000000917F2086EF841402E7590D783D34940
51109	1	8	1552	18505	37405	\N	51.652461000000002	Курская область, Октябрьский район, поселок Прямицыно, Октябрьская, помещение МКОУ "Ленинская СОШ"		0101000020E61000000917F2086EF841402E7590D783D34940
51110	1	8	1552	18505	37485	\N	51.652461000000002	Курская область, Октябрьский район, поселок Прямицыно, Коммунистическая, 73		0101000020E61000000917F2086EF841402E7590D783D34940
51132	1	8	1552	19756	\N	\N	51.825491999999997	Курская область, Октябрьский район, Никольский сельсовет, деревня Провоторова, помещение "Никольский СДК"	Россия, Курская область, Октябрьский район, поселок Провоторова	0101000020E6100000A1D9756F45DC4140088ECBB8A9E94940
51121	1	8	1552	19165	\N	\N	51.532268000000002	Курская область, Октябрьский район, Плотавский сельсовет, деревня Плотава, помещение МКОУ "Плотавская СОШ"	Россия, Курская область, Октябрьский район, поселок Плотава	0101000020E610000079B130444EF541408A5A9A5B21C44940
51128	1	8	1552	19561	\N	\N	51.715381000000001	Курская область, Октябрьский район, Большедолженковский сельсовет, деревня Горбулина, помещение "Горбулинский ФАП"	Россия, Курская область, Октябрьский район, поселок Нижняя Горбулина	0101000020E610000079EBFCDB65E941400397C79A91DB4940
51113	1	8	1552	18762	\N	\N	51.639361000000001	Курская область, Октябрьский район, Черницынский сельсовет, деревня Нижняя Воробжа, помещение филиала ОАО "МРСК Центра"-Курскэнерго"	Россия, Курская область, Октябрьский район, поселок Нижняя Ворожба	0101000020E61000001157CEDE19F541403FABCC94D6D14940
51123	1	8	1552	19279	\N	\N	51.644492	Курская область, Октябрьский район, Катыринский сельсовет, деревня Митрофанова, помещение администрации МО Катыренский сельсовет"	Россия, Курская область, Октябрьский район, поселок Митрофанова	0101000020E61000006F63B323D5E941404E44BFB67ED24940
51127	1	8	1552	19467	\N	\N	51.672108999999999	Курская область, Октябрьский район, Большедолженковский сельсовет, деревня Липина, помещение "Липинский ФАП"	Россия, Курская область, Октябрьский район, поселок Липина	0101000020E610000010786000E1E74140732CEFAA07D64940
51119	1	8	1552	19073	\N	\N	51.563313000000001	Курская область, Октябрьский район, Лобазовский сельсовет, село Журавлино, помещение администрации МО "Лобазовский сельсовет"	Россия, Курская область, Октябрьский район, поселок Журавлино	0101000020E6100000931804560EFB4140B134F0A31AC84940
51131	1	8	1552	32508	\N	\N	51.802523999999998	Курская область, Октябрьский район, Никольский сельсовет, деревня Дюмина, помещение "Никольский ФАП"	Россия, Курская область, Октябрьский район, поселок Дюмина	0101000020E61000007CEE04FBAFDF4140A7203F1BB9E64940
51118	1	8	1552	18924	37289	\N	51.643507999999997	Курская область, Октябрьский район, Дьяконовский сельсовет, село Дьяконово, Школьная, помещение МКОУ "Дьяконовская СОШ"		0101000020E61000004033880FECF24140705B5B785ED24940
51116	1	8	1552	18924	37389	\N	51.643507999999997	Курская область, Октябрьский район, Дьяконовский сельсовет, село Дьяконово, Победы, помещение МКОУ "Залининская СОШ"		0101000020E61000004033880FECF24140705B5B785ED24940
51117	1	8	1552	18924	37751	\N	51.643507999999997	Курская область, Октябрьский район, Дьяконовский сельсовет, село Дьяконово, Красной Звезды, помещение "1 Дьяконовский ФАП"		0101000020E61000004033880FECF24140705B5B785ED24940
51129	1	8	1552	54523	\N	\N	51.762143577947299	Курская область, Октябрьский район, Старковский сельсовет, деревня Волобуева, помещение "Волобуевский ФАП"	Россия, Курская область, Октябрьский район, поселок Волобуево	0101000020E61000007808E3A771E74140DB6B41EF8DE14940
51122	1	8	1552	19249	\N	\N	51.53922	Курская область, Октябрьский район, Плотавский сельсовет, деревня Верхние Постоялые Дворы, помещение "Двориковский ФАП"	Россия, Курская область, Октябрьский район, поселок Верхние Постоялые Дворы	0101000020E610000091459A7807EA4140B0AC342905C54940
51126	1	8	1552	19462	\N	\N	51.682485999999997	Курская область, Октябрьский район, Большедолженковский сельсовет, деревня Ванина, помещение МКУК "Ванинский СДК"	Россия, Курская область, Октябрьский район, поселок Ванина	0101000020E6100000B3EDB43522F641402AFD84B35BD74940
51125	1	8	1552	19398	\N	\N	51.709097999999997	Курская область, Октябрьский район, Большедолженковский сельсовет, село Большое Долженково, помещение МКУК "Б-Долженковский СДК"	Россия, Курская область, Октябрьский район, поселок Большое Долженково	0101000020E6100000FCC8AD49B7EB41405AD427B9C3DA4940
43993	1	7	1104	25087	32575	\N	58.625745999999999	Костромская область, Шарьинский район, село Головино, ул.Центральная, д.16, здание школы		0101000020E6100000A41CCC26C0D8464029CDE67118504D40
51120	1	8	1552	19150	\N	\N	51.561494000000003	Курская область, Октябрьский район, Артюховский сельсовет, деревня Артюховка, помещение администрации МО "Артюховский сельсовет"	Россия, Курская область, Октябрьский район, поселок Артюховка	0101000020E61000003198BF42E6E041403B730F09DFC74940
51111	1	8	1552	54496	\N	\N	51.649630979530301	Курская область, Октябрьский район, Черницынский сельсовет, деревня Анахина, помещение МКОУ "Анахинская школа"	Россия, Курская область	0101000020E61000005BD3BCE314034240E0BBCD1B27D34940
51133	1	8	1552	19798	\N	\N	51.834842000000002	Курская область, Октябрьский район, Филипповский сельсовет, деревня Алябьева, помещение МКОУ "Филипповская ООШ"	Россия, Курская область, Октябрьский район, поселок Алябьева	0101000020E6100000689599D2FAE94140E3A9471ADCEA4940
51124	1	8	1552	19353	\N	\N	51.688884999999999	Курская область, Октябрьский район, Большедолженковский сельсовет, деревня Авдеева, помещение "Авдеевский ФАП"	Россия, Курская область, Октябрьский район, поселок Авдеева	0101000020E610000038DC476E4DE641403CDA38622DD84940
51078	1	8	817	16991	37783	\N	51.133034000000002	Курская область, Обоянский район,Зоринский сельсовет,село Шипы, здание филиала муниципального общеобразовательного учреждения "Зоринская СОШ", Садовая, 51		0101000020E61000006FBDA60705354240C7A0134207914940
51098	1	8	817	18007	37784	\N	51.235976999999998	Курская область, Обоянский район,Шевелевский сельсовет, село Шевелево,здание муниципального учреждения культуры"Шевелевский СДК", Молодежная, 17		0101000020E610000090D78349F1014240D9CD8C7E349E4940
51075	1	8	817	16859	37829	\N	51.276206999999999	Курская область, Обоянский район,Гридасовский сельсовет,село Чекмаревка,здание муниципального общеобразовательного учреждения"Чекмаревская ООШ", Выгон, 7		0101000020E6100000FB58C16F430C424090F63FC05AA34940
51094	1	8	817	17808	37832	\N	51.234703000000003	Курская область, Обоянский район,Рыбино-Будский сельсовет,село Филатово,здание муниципального общеобразовательного учреждения"Филатовская ООШ", План, 43		0101000020E61000002D793C2D3FEE4140F5A276BF0A9E4940
51095	1	8	817	17838	37639	\N	51.18909	Курская область, Обоянский район,Усланский сельсовет, село Усланка,здание Администрации Усланского сельсовета, Центральная, 9А		0101000020E6100000C3B986191A1142401500E31934984940
51097	1	8	817	17949	37653	\N	51.199114999999999	Курская область, Обоянский район,Усланский сельсовет, село Трубеж,здание муниципального учреждения культуры"Трубежанский СК", Центральная, 9А		0101000020E6100000A41B6151111B42404F92AE997C994940
51090	1	8	817	17608	37650	\N	51.229480000000002	Курская область, Обоянский район,Рудавский сельсовет,село Стрелецкое,здание муниципального учреждения культуры"Стрелецкий СДК", Ленина, 189		0101000020E61000007D224F92AE254240058BC3995F9D4940
51092	1	8	817	17711	37638	\N	51.204945000000002	Курская область, Обоянский район,Рыбино-Будский сельсовет,слобода Рыбинские-Буды,здание Администрации Рыбино-Будского сельсовета, Карачёвка, 32		0101000020E6100000C4EA8F300CFA4140473D44A33B9A4940
51089	1	8	817	17550	37608	\N	51.25	Курская область, Обоянский район,Рудавский сельсовет,поселок Рудавский,здание муниципального учреждения культуры"СДК пос. Рудавский", Лесная, 17		0101000020E6100000F6B4C35F932742400000000000A04940
51088	1	8	817	17504	37682	\N	51.258783000000001	Курская область, Обоянский район,Рудавский сельсовет,село Рудавец,здание муниципального учреждения культуры "Рудавский СДК", Выгон, 33		0101000020E61000004B06802A6E2C424061E124CD1FA14940
51091	1	8	817	17641	37830	\N	51.221719	Курская область, Обоянский район,Рудавский сельсовет,село Пушкарное,здание муниципального учреждения культуры"Пушкарский СДК", Верхняя Поповка, 45		0101000020E6100000A2630795B82242406FF3C649619C4940
51077	1	8	817	16962	37627	\N	51.199668000000003	Курская область, Обоянский район,Зоринский сельсовет,поселок Пригородный,здание муниципального учреждения культуры"Дворец культуры им. Мичурина", Центральная, 3		0101000020E610000028F1B913EC254240640795B88E994940
51087	1	8	817	17435	37833	\N	51.351888000000002	Курская область, Обоянский район,Котельниковский сельсовет,деревня Потопахино,здание муниципального учреждения культуры"Полукотельниковский СДК", Молодежная, 6		0101000020E61000000E83F92B642642406CED7DAA0AAD4940
51079	1	8	817	17054	37750	\N	51.087999000000003	Курская область, Обоянский район,Зоринский сельсовет,хутор Пересыпь,здание муниципального учреждения культуры"Пересыпьский СК", Тополевая, 54		0101000020E6100000450F7C0C563C4240558A1D8D438B4940
51073	1	8	817	16769	37711	\N	51.264722999999996	Курская область, Обоянский район,Быкановский сельсовет,поселок Пасечный, здание муниципального учреждения культуры "Пасечный сельский клуб", Садовая, 23		0101000020E6100000838593347F1C4240DFBF7971E2A14940
51096	1	8	817	17902	37632	\N	51.156049000000003	Курская область, Обоянский район,Усланский сельсовет, село Павловка,здание муниципального общеобразовательного учреждения"Павловская СОШ", Садовая, 3		0101000020E6100000E94482A9660E424069C9E369F9934940
51103	1	8	817	5830	37486	\N	51.211692999999997	Курская область, Обоянский район,город Обоянь,здание Обоянского участка закрытого акционерного общества "Медвенская ДЭП", Мирная, 17		0101000020E61000003EEAAF575822424064E597C1189B4940
51025	1	8	786	14414	37647	\N	51.347718999999998	Курская область, Мантуровский район, Сеймский сельсовет, село Кривец, Школьная (здание школы), 1		0101000020E6100000FC19DEACC18D42405299620E82AC4940
51101	1	8	817	5830	37489	\N	51.206143163553698	Курская область, Обоянский район,город Обоянь,здание муниципального учреждения культуры "Обоянский районный Дом народного творчества", Луначарского, 28	Россия, Курская область, Обоянский район, Обоянь	0101000020E61000005039268BFB23424050A6D1E4629A4940
51105	1	8	817	5830	37350	\N	51.211692999999997	Курская область, Обоянский район,город Обоянь,здание муниципального общеобразовательного учреждения дошкольного образования детей "Районный Дом Пионеров и школьников", Ленина, 23		0101000020E61000003EEAAF575822424064E597C1189B4940
51102	1	8	817	5830	37350	\N	51.211429671306902	Курская область, Обоянский район,город Обоянь,здание Обоянского филиала областного бюджетного образовательного учреждения среднего профессионального образования Курский колледж культуры", Ленина, 30	Россия, Курская область, Обоянский район, Обоянь	0101000020E610000087FBC8AD4923424057B26323109B4940
51100	1	8	817	5830	37350	\N	51.2109684739305	Курская область, Обоянский район,город Обоянь,здание областного бюджетного образовательного учреждения начального профессионального образования "Профессиональный лицей № 23, (г. Обоянь Курской области), Ленина, 77	Россия, Курская область, Обоянский район, Обоянь	0101000020E6100000274BADF71B2342405340DAFF009B4940
51099	1	8	817	5830	37350	\N	51.212558827992197	Курская область, Обоянский район,город Обоянь,здание муниципального общеобразовательного учреждения "Обоянская СОШ № 2", Ленина, 90	Россия, Курская область, Обоянский район, Обоянь	0101000020E6100000B056ED9A9024424038BC2022359B4940
51064	1	8	817	16291	37677	\N	51.179046999999997	Курская область, Обоянский район, Афанасьевский сельсовет, село Нижнее Солотино, здание муниципального общеобразовательного учреждения "Н-Солотинская ООШ", Выгон, 22А		0101000020E610000022FE614B8F1E424034B91803EB964940
51068	1	8	817	16496	37690	\N	51.266775000000003	Курская область,Обоянский район,Бабинский сельсовет,село Нижнее Бабино,здание муниципального учреждения культуры "Н-Бабинский СДК", Выгон		0101000020E6100000527C7C4276E84140F931E6AE25A24940
51086	1	8	817	17403	37722	\N	51.314708000000003	Курская область, Обоянский район,Котельниковский сельсовет,село Малые Крюки,здание муниципального учреждения культуры"Малокрюковский СДК", Молодежная, 18		0101000020E61000005E4D9EB29A30424011E50B5A48A84940
51083	1	8	817	17245	37796	\N	51.327457000000003	Курская область, Обоянский район,Котельниковский сельсовет, село Котельниково,здание муниципального учреждения культурыКотельниковский СДК", Центральная, 18		0101000020E61000001F69705B5B26424053EC681CEAA94940
50534	1	8	817	16660	\N	\N	51.262796919973397	Курская область, город Курск, поселок Косиново (здание Косиновской школы), Косиновская  школа	Россия, Курская область, Обоянский район, поселок Косиново	0101000020E61000000F5EBBB4E1F64140533E0455A3A14940
51071	1	8	817	16660	37714	\N	51.263511000000001	Курская область, Обоянский район,Башкатовский сельсовет,село Косиново,здание муниципального общеобразовательного учрежденияКосиновская ООШ", Выгон, 26		0101000020E61000008602B68311F7414071917BBABAA14940
51065	1	8	817	16342	37676	\N	51.157535000000003	Курская область, Обоянский район, Афанасьевский сельсовет, село Камынино, здание муниципального общеобразовательного учреждения Камынинская ООШ", Молодежная, 22		0101000020E61000004565C39ACA2C4240D97C5C1B2A944940
51080	1	8	817	17087	37753	\N	51.172604	Курская область, Обоянский район,Каменский сельсовет, село Каменка,здание муниципального общеобразовательного учреждения Каменская СОШ", Молодежная, 16А		0101000020E6100000F8325184D405424053944BE317964940
51066	1	8	817	16384	37287	\N	51.174987000000002	Курская область, Обоянский район,Зоринский сельсовет,село Зорино, здание муниципального учреждения культуры"СДК села Зорино", Октябрьская, 106		0101000020E610000026AC8DB1132E4240D21C59F965964940
51067	1	8	817	16443	37828	\N	51.133564999999997	Курская область, Обоянский район, Афанасьевский сельсовет, деревня Знобиловка,здание Знобиловского сельского клуба филиала муниципального учреждения культуры "Афанасьевский ЦСДК", Верхняя Знобиловка, 74		0101000020E61000006A166877482F4240F3716DA818914940
51084	1	8	817	17312	37718	\N	51.315631000000003	Курская область, Обоянский район,Котельниковский сельсовет,хутор Дрозды,здание муниципального учреждения культуры"Дроздовский СДК", Центральная, 55		0101000020E6100000906AD8EF89174240494DBB9866A84940
51093	1	8	817	17748	37831	\N	51.216258000000003	Курская область, Обоянский район,Рыбино-Будский сельсовет,село Долженково,здание муниципального общеобразовательного учреждения"Должёнковская ООШ", Выгон, 40		0101000020E610000013286211C3EE4140CBBF9657AE9B4940
51074	1	8	817	16805	37734	\N	51.224263000000001	Курская область, Обоянский район,Гридасовский сельсовет,село Гридасово,здание муниципального общеобразовательного учреждения"Гридасовская СОШ", Выгон, 24		0101000020E61000008B34F10EF00A4240F75965A6B49C4940
51072	1	8	817	16696	37689	\N	51.263691999999999	Курская область, Обоянский район,Быкановский сельсовет,село Быканово, здание Администрации Быкановского сельсовета, Молодежная, 15		0101000020E6100000C0EB33677D124240C11BD2A8C0A14940
50915	1	8	269	9195	\N	\N	51.600133999999997	Курская область, Курский район, Лебяженский сельсовет, п.Черемушки, Черемушинский СДК		0101000020E6100000EA03C93B87204240DC9BDF30D1CC4940
51081	1	8	817	17153	37713	\N	51.161777000000001	Курская область, Обоянский район,Каменский сельсовет, село Бушмено,здание муниципального общеобразовательного учреждения"Бушменская ООШ", Выгон, 13		0101000020E6100000CC988235CEF441405C1FD61BB5944940
51082	1	8	817	17189	37715	\N	51.189236774304597	Курская область, Обоянский район,Каменский сельсовет, село Бегичево,здание муниципального общеобразовательного учреждения"Бегичевская НШ", Кузьминова, 25	Россия, Курская область, Обоянский район, поселок Бегичево	0101000020E6100000605B3FFD67F14140B91803EB38984940
51070	1	8	817	16591	37716	\N	51.266002765645702	Курская область, Обоянский район,Башкатовский сельсовет,село Башкатово, здание Администрации Башкатовского сельсовета, Лугачевка, 2	Россия, Курская область, Обоянский район, поселок Башкатово	0101000020E6100000B79A75C6F7FD4140A6D1E4620CA24940
51063	1	8	817	16179	37622	\N	51.172265000000003	Курская область, Обоянский район, Афанасьевский сельсовет, село Афанасьево, здание №2 муниципального общеобразовательного учреждения "Афанасьевская СОШ", Центральная, 36А		0101000020E61000002BA5677A892542406B9F8EC70C964940
51062	1	8	817	16179	37622	\N	51.172265000000003	Курская область, Обоянский район, Афанасьевский сельсовет, село Афанасьево, здание № 1 муниципального общеобразовательного учреждения "Афанасьевская СОШ", Центральная, 36А		0101000020E61000002BA5677A892542406B9F8EC70C964940
51061	1	8	760	16139	\N	\N	51.451107	Курская область, Медвенский район, Чермошнянский сельсовет, село Чермошное, (здание Вышнедубовецого центрального СДК)	Россия, Курская область, Медвенский район, поселок Чермошное	0101000020E6100000705B5B785E18424093FFC9DFBDB94940
51048	1	8	760	15544	\N	\N	51.462180073442099	Курская область, Медвенский район, Гостомлянский сельсовет, село Тарасово, (здание Тарасовского СДК)	Россия, Курская область, Медвенский район, поселок Тарасово	0101000020E6100000C9AEB48CD4DF4140C16ED8B628BB4940
51044	1	8	760	15335	\N	\N	51.447144000000002	Курская область, Медвенский район, Высокский сельсовет, деревня Спасское, (здание Спасской СОШ)	Россия, Курская область, Медвенский район, поселок Спасское	0101000020E6100000D3C08F6AD8F34140234DBC033CB94940
51056	1	8	760	15905	\N	\N	51.370750000000001	Курская область, Медвенский район, Паникинский сельсовет, село Паники, (здание Паникинского СДК)	Россия, Курская область, Медвенский район, поселок Паники	0101000020E61000007D259012BB1A4240FA7E6ABC74AF4940
51055	1	8	760	15867	\N	\N	51.368614000000001	Курская область, Медвенский район, Нижнереутчанский сельсовет, село Нижний Реутец, (здание Нижнереутчанского СДК)	Россия, Курская область, Медвенский район, поселок Нижний Реутец	0101000020E610000086E7A56263044240836C59BE2EAF4940
51060	1	8	760	16081	\N	\N	51.415962999999998	Курская область, Медвенский район, Чермошнянский сельсовет, деревня Нижний Дубовец, (здание Чермошнянской центральной сельской библиотеки)	Россия, Курская область, Медвенский район, поселок Нижний Дубовец	0101000020E6100000FB928D075B2C42404BAC8C463EB54940
51041	1	8	760	15111	37404	\N	51.420338000000001	Курская область, Медвенский район, поселок Медвенка, улица Советская, дом 30		0101000020E6100000F3E505D8470F42400EA2B5A2CDB54940
51040	1	8	760	15111	37383	\N	51.420338000000001	Курская область, Медвенский район, поселок Медвенка, улица Промышленная, дом 56		0101000020E6100000F3E505D8470F42400EA2B5A2CDB54940
51050	1	8	760	5343	\N	\N	51.532240000000002	Курская область, Медвенский район, Китаевский сельсовет, село Любицкое, (здание Любицкого СДК)	Россия, Курская область, Медвенский район, поселок Любицкое	0101000020E6100000FCE4284014344240C0CFB87020C44940
51053	1	8	760	15764	\N	\N	51.363720999999998	Курская область, Медвенский район, Любачанский сельсовет, поселок Любач, (здание Любачанской СОШ)	Россия, Курская область, Медвенский район, поселок Любач	0101000020E610000019E8DA17D0EF414028EFE3688EAE4940
51049	1	8	760	15556	\N	\N	51.520848000000001	Курская область, Медвенский район, Китаевский сельсовет, деревня Денисовка, (здание Лубянского СДК)	Россия, Курская область, Медвенский район, поселок Денисовка	0101000020E61000005DA9674128374240F017B325ABC24940
51052	1	8	760	15711	\N	\N	51.454839	Курская область, Медвенский район, Китаевский сельсовет, деревня Губановка, (здание 2-й Рождественской СОШ)	Россия, Курская область, Медвенский район, поселок Губановка	0101000020E6100000766EDA8CD324424001F9122A38BA4940
51059	1	8	760	16039	\N	\N	51.411963	Курская область, Медвенский район, Чермошнянский сельсовет, село Вышний Дубовец, (здание Вышнедубовецкой ООШ)	Россия, Курская область, Медвенский район, поселок Вышний Дубовец	0101000020E610000062F88898122F4240BE141E34BBB44940
51058	1	8	760	15987	\N	\N	51.485062999999997	Курская область, Медвенский район, Панинский сельсовет, хутор Высоконские Дворы, (здание Высоконодворского СДК)	Россия, Курская область, Медвенский район, поселок Высоконские Дворы	0101000020E61000006EA7AD11C1084240F4BF5C8B16BE4940
51043	1	8	760	15257	\N	\N	51.430897049384697	Курская область, Медвенский район, Высокский сельсовет, село Высокое, (здание Коммунарского СДК)	Россия, Курская область, Медвенский район, поселок Высокое	0101000020E61000009E7AA4C16DFF4140E67805A227B74940
50659	1	8	682	28592	37657	\N	51.408743999999999	Курская область, Глушковский район, Марковский сельсовет, с.Марково, ул.Школьная, д.22		0101000020E61000003F90BC7328334140D63730B951B44940
51046	1	8	760	15428	\N	\N	51.343268999999999	Курская область, Медвенский район, Вышнереутчанский сельсовет, село Верхний Реутец, (здание Вышнереутчанского СДК)	Россия, Курская область, Медвенский район, поселок Верхний Реутец	0101000020E6100000FCFF3861C2004240855D143DF0AB4940
51042	1	8	760	15243	\N	\N	51.513331999999998	Курская область, Медвенский район, Амосовский сельсовет, деревня Амосовка, (здание Амосовского СДК)	Россия, Курская область, Медвенский район, поселок Амосовка	0101000020E61000009F56D11F9A174240C1FEEBDCB4C14940
51051	1	8	760	6193	\N	\N	51.490518999999999	Курская область, Медвенский район, Китаевский сельсовет, деревня 2-я Китаевка, (здание Китаевского СДК)	Россия, Курская область, Медвенский район, поселок 2-я Китаевка	0101000020E6100000478D0931972A424087889B53C9BE4940
51057	1	8	760	15944	\N	\N	51.537959999999998	Курская область, Медвенский район, Панинский сельсовет, село 2-е Панино, (здание Панинского СДК)	Россия, Курская область, Медвенский район, поселок 2-е Панино	0101000020E610000005323B8BDE0F424030478FDFDBC44940
51047	1	8	760	15475	\N	\N	51.446056140533898	Курская область, Медвенский район, Гостомлянский сельсовет, село 1-я Гостомля, (здание Гостомлянского СДК)	Россия, Курская область, Медвенский район, поселок 1-я Гостомля	0101000020E6100000BF9EAF592EED4140A017EE5C18B94940
51054	1	8	760	15811	\N	\N	51.3326279434743	Курская область, Медвенский район, Любачанский сельсовет, село 1-й Липовец, (здание Любачанской центральной сельской библиотеки)	Россия, Курская область, Медвенский район, поселок 1-й Липовец	0101000020E61000009BFEEC478AF24140F0DDE68D93AA4940
51039	1	8	786	5564	37607	\N	51.449523999999997	Курская область, Мантуровский район, Ястребовский сельсовет, село Ястребовка, "адрес помещения для голосования", Мира (здание МОУ  "Ястребовская средняя общеобразовательная школа") 95, "адрес УИК", Центральная (здание Администрации с/с), 37		0101000020E61000003C69E1B20AC7424030629F008AB94940
51038	1	8	786	15038	37710	\N	51.486997000000002	Курская область, Мантуровский район, Ястребовский сельсовет, село Стужень, Центральная (бывшее здание Стуженского с/с), 53		0101000020E6100000CDAD105663C142400420EEEA55BE4940
51037	1	8	786	14978	37310	\N	51.344276000000001	Курская область, Мантуровский район, Сеймский сельсовет, село Сейм, "адрес помещения для голосования", Мира ( здание МУК "Сеймский СДК") 7 "а", "адрес УИК", Заводская (здание Администрации с/с), 1		0101000020E6100000EACBD24ECD8542401B66683C11AC4940
51036	1	8	786	14963	\N	\N	51.439306999999999	Курская область, Мантуровский район, Мантуровский сельсовет, село Свинец, "адрес помещения для голосования", Центральная (здание МОУ "Свинецкая основная общеобразовательная школа") 28, "адрес УИК", Центральная (бывшее здание Свинецкого с/с), 11		0101000020E61000005FEFFE78AF844240B2F336363BB84940
51035	1	8	786	14903	37688	\N	51.52899	Курская область, Мантуровский район, Куськинский сельсовет, село Роговое, "адрес помещения для голосования", Центральная (здание МУК  "Роговский сельский ДК") 24, "адрес УИК", Центральная (бывшее здание Роговского с/с), 8		0101000020E61000001844A4A65D9442409DF4BEF1B5C34940
51032	1	8	786	14765	37675	\N	51.472272618753401	Курская область, Мантуровский район, Останинский сельсовет, село Репецкая Плата, "адрес помещения для голосования", Центральная (здание МОУ "Репецкоплатавская начальная общеобразовательная школа") 25, "адрес УИК", Центральная (бывшее зд. Репецкоплатавского с/с), 24	Россия, Курская область, Мантуровский район, поселок Репецкая Плата	0101000020E610000052103CBEBDA5424054E4107173BC4940
51031	1	8	786	14676	\N	\N	51.501761999999999	Курская область, Мантуровский район, Куськинский сельсовет, село Пузачи, Центральная (здание СДК), 1	Россия, Курская область, Мантуровский район, поселок Пузачи	0101000020E6100000ACFD9DEDD19742401230BABC39C04940
51030	1	8	786	14670	37827	\N	51.414271999999997	Курская область, Мантуровский район, Останинский сельсовет, село Останино, "адрес помещения для голосования", Центральная (здание МОУ "Останинская основная общеобразовательная школа") 96, "адрес УИК", Центральная (здание Администрации с/с), 30		0101000020E610000067D7BD15899F424002D369DD06B54940
51029	1	8	786	14608	37801	\N	51.405602999999999	Курская область, Мантуровский район, 2-й Засеймский сельсовет, село Мяснянка, "адрес помещения для голосования", Центральная (здание МОУ "Мяснянская основная общеобразовательная школа") 37, "адрес УИК", Центральная (бывшее здание Мяснянского с/с), 19		0101000020E61000007520EBA9D59342406A1492CCEAB34940
51028	1	8	786	14548	37332	\N	51.453324000000002	Курская область, Мантуровский район, Мантуровский сельсовет, село Мантурово, "адрес помещения для голосования", Маяковского (здание МУК "Мантуровский районный центр досуга") 2"а", "адрес УИК", Школьная (здание Администрации с/с), 1		0101000020E61000005874EB353D904240F73E558506BA4940
51027	1	8	786	14517	37709	\N	51.535265000000003	Курская область, Мантуровский район, Куськинский сельсовет, село Куськино, "адрес помещения для голосования", Центральная (здание МУК Куськинский СДК") 58, "адрес УИК", Молодёжная (здание Администрации с/с), 1		0101000020E610000009151C5E109F4240C3D8429083C44940
44188	1	7	405	2149	32252	\N	58.145198999999998	Костромская область, Сусанинский район, п. Сусанино, Крупской, 15		0101000020E6100000E2E7BF07AFCB4440B9347EE195124D40
51024	1	8	786	14371	37687	\N	51.373533000000002	Курская область, Мантуровский район, 2-й Засеймский сельсовет, село 2-е Засеймье, "адрес помещения для голосования",  Центральная (здание МОУ "2-Засеймская средняя общеобразовательная школа") 63 "а", "адрес УИК", Центральная (здание Администрации с/с), 67 "а"		0101000020E6100000ABB4C5353E8B4240077DE9EDCFAF4940
51023	1	8	786	14321	37707	\N	51.484917000000003	Курская область, Мантуровский район, Мантуровский сельсовет, село 1-е Засеймье, "адрес помещения для голосования",  Школьная (здание МОУ "1-Засеймская средняя общеобразовательная школа") 52, "адрес УИК", Школьная (здание СДК), 50		0101000020E6100000B7F1272A1B8E42402123A0C211BE4940
51022	1	8	786	54544	37786	\N	51.551485705239401	Курская область, Мантуровский район, Репецкий сельсовет, село Заречье, "адрес помещения для голосования",  Центральная (здание МОУ "Зареченская основная общеобразовательная школа") 88, "адрес УИК",  Центральная (бывшее здание Зареченского с/с), 124	Россия, Курская область, Мантуровский район, поселок Заречное	0101000020E6100000408A3A730FAB4240D619DF1797C64940
51033	1	8	786	14808	37775	\N	51.513596	Курская область, Мантуровский район, Репецкий сельсовет, хутор Заосколье, "адрес помещения для голосования", Центральная (здание МОУ "Репецкая средняя общеобразовательная школа") 39, "адрес УИК", Центральная (здание Администрации с/с), 39		0101000020E61000006F29E78BBDB942409FAD8383BDC14940
51021	1	8	786	14239	37826	\N	51.3364713491926	Курская область, Мантуровский район, 2-й Засеймский сельсовет, село Гущино, "адрес помещения для голосования", ул. Школьная (здание МОУ "Гущинская основная общеобразовательная школа") 8, "адрес УИК", Почтовая (бывшее здание Гущинского с/с), 33	Россия, Курская область, Мантуровский район, поселок Гущино	0101000020E6100000EAEBF99AE59C4240B686527B11AB4940
51020	1	8	786	14175	37825	\N	51.479044000000002	Курская область, Мантуровский район, Останинский сельсовет, село Большие Бутырки, "адрес помещения для голосования", ул. Центральная (МОУ "Большебутырская основная общеобразовательная школа"), 6, "адрес УИК", Центральная(бывшее здание Большебутырского с/с), 2		0101000020E61000009964E42CECB142402AAC545051BD4940
51034	1	8	786	14841	37691	\N	51.555525000000003	Курская область, Мантуровский район, Репецкий сельсовет, село Безлепкино, Садовая (здание школы), 6		0101000020E61000008D429259BDB74240228E75711BC74940
50978	1	8	811	12229	\N	\N	51.558273999999997	Курская область, Льговский район, Большеугонский сельсовет,  д.Эммануйловка, (здание Эммануйловского ФАП)	Россия, Курская область, Льговский район, поселок Эммануиловка	0101000020E6100000F8FC304278B84140821ABE8575C74940
51017	1	8	811	14040	\N	\N	51.662367000000003	Курская область, Льговский район, Селекционный сельсовет,  д.Шерекино, (здание МБОУ "Шерекинская СОШ")	Россия, Курская область, Льговский район, поселок Шерекино	0101000020E6100000FD4AE7C3B39C41408E791D71C8D44940
50984	1	8	811	12493	\N	\N	51.517978999999997	Курская область, Льговский район, Вышнедеревенский сельсовет, с.Черемошки, (здание МБОУ "Черемошанская НОШ")	Россия, Курская область, Льговский район, поселок Черемошки	0101000020E610000072C45A7C0AA24140E481C8224DC24940
50985	1	8	811	12581	\N	\N	51.486969000000002	Курская область, Льговский район, Вышнедеревенский сельсовет, с.Цуканово-Бобрик, (здание МБОУ "Цуканово-Бобрикская ООШ")	Россия, Курская область, Льговский район, поселок Цуканово Бобрик	0101000020E6100000C8EA56CF49AF41403A950C0055BE4940
51016	1	8	811	13983	\N	\N	51.676085999999998	Курская область, Льговский район, Селекционный сельсовет,  с.Фитиж, (здание МБОУ "Фитижская СОШ")	Россия, Курская область, Льговский район, поселок Фитиж	0101000020E61000002D431CEBE290414048A46DFC89D64940
51007	1	8	811	13540	\N	\N	51.741816999999998	Курская область, Льговский район, Иванчиковский сельсовет, с.Телятниково, (здание Телятниковского СК)	Россия, Курская область, Льговский район, поселок Телятниково	0101000020E6100000B2F2CB608CA64140F44E05DCF3DE4940
50980	1	8	811	12320	\N	\N	51.636001999999998	Курская область, Льговский район, Большеугонский сельсовет, с.Сугрово, (здание МБОУ "Сугровская ООШ")	Россия, Курская область, Льговский район, поселок Сугрово	0101000020E610000095D5743DD1A941406518778368D14940
50986	1	8	811	12595	\N	\N	51.506695000000001	Курская область, Льговский район, Вышнедеревенский сельсовет, с.Стремоухово-Бобрик, (здание МБОУ "Стрем-Бобрикская ООШ")	Россия, Курская область, Льговский район, поселок Стремоухово-Бобрик	0101000020E6100000BD1B0B0A83BA4140FB05BB61DBC04940
51002	1	8	811	13342	\N	\N	51.607232000000003	Курская область, Льговский район, Густомойский сельсовет,  д.Стремоуховка, (здание Стремоуховского ФАП)	Россия, Курская область, Льговский район, поселок Стремоуховка	0101000020E6100000FF2268CC248A4140D78A36C7B9CD4940
51010	1	8	811	13691	\N	\N	51.698163000000001	Курская область, Льговский район, Кудинцевский сельсовет, д.Сергеевка, (здание Сергеевского СК)	Россия, Курская область, Льговский район, поселок Сергеевка	0101000020E6100000327216F6B49941407D23BA675DD94940
51015	1	8	811	13955	\N	\N	51.634279999999997	Курская область, Льговский район, Селекционный сельсовет,  п. Селекционный, (здание МБОУ "Селекционная СОШ")	Россия, Курская область, Льговский район, поселок Селекционный	0101000020E6100000EE3F321D3A954140E140481630D14940
50996	1	8	811	13060	\N	\N	51.696896000000002	Курская область, Льговский район, Городенский сельсовет, с.Речица, (здание Речицкого СК)	Россия, Курская область, Льговский район, поселок Речица	0101000020E6100000FBCA83F414B741404B5B5CE333D94940
50995	1	8	811	54511	\N	\N	51.692112750569201	Курская область, Льговский район, Городенский сельсовет, с.Пригородная Слободка, (здание Пригороднеслободского ФАП)	Россия, Курская область, Льговский район, поселок Пригородная Слобода	0101000020E6100000D55B035B25A841407711A62897D84940
51006	1	8	811	13532	\N	\N	51.772931	Курская область, Льговский район, Иванчиковский сельсовет, д.Полячково, (здание МБОУ "Иванчиковская СОШ")	Россия, Курская область, Льговский район, поселок Полячково	0101000020E61000002C9B3924B5AE414044882B67EFE24940
50998	1	8	811	13132	\N	\N	51.648482000000001	Курская область, Льговский район, Городенский сельсовет, д.Погореловка, (здание Погореловского ФАП)	Россия, Курская область, Льговский район, поселок Погореловка	0101000020E61000003A3FC571E0BB4140B8054B7501D34940
51008	1	8	811	13617	\N	\N	51.773342999999997	Курская область, Льговский район, Иванчиковский сельсовет, с.Ольшанка, (здание Ольшанского СДК)	Россия, Курская область, Льговский район, поселок Ольшанка	0101000020E6100000B933130CE7B6414096CB46E7FCE24940
50979	1	8	811	12261	\N	\N	51.654696000000001	Курская область, Льговский район, Большеугонский сельсовет,  с.Нижние Деревеньки, (здание Нижнедеревенского СДК)	Россия, Курская область, Льговский район, поселок Нижние Деревеньки	0101000020E61000008D7A884677A4414038691A14CDD34940
51012	1	8	811	13811	\N	\N	51.754435999999998	Курская область, Льговский район, Марицкий сельсовет, с.Марица, (здание Марицкого ЦСДК)	Россия, Курская область, Льговский район, поселок Марица	0101000020E61000009D9CA1B8E39F41406876DD5B91E04940
50977	1	8	811	12175	\N	\N	51.619520000000001	Курская область, Льговский район, Большеугонский сельсовет, с.Малые Угоны, (здание Малоугонского ФАП)	Россия, Курская область, Льговский район, поселок Малые Угоны	0101000020E61000008D9B1A683EB34140E59B6D6E4CCF4940
50992	1	8	811	12876	\N	\N	51.579374000000001	Курская область, Льговский район, Вышнедеревенский сельсовет, с.Малеевка, (здание МБОУ "Малеевская ООШ")	Россия, Курская область, Льговский район, поселок Малеевка	0101000020E61000005EBA490C029D41408C135FED28CA4940
50857	1	8	811	5951	37285	\N	51.660612999999998	Курсая область, город Льгов, Советская, 2	Россия, Курская область, Льговский район, Льгов	0101000020E6100000679C86A8C2A14140FE277FF78ED44940
50430	1	8	811	5951	37299	\N	51.660612999999998	Курсая область, город Льгов, Свердлова, 8		0101000020E6100000679C86A8C2A14140FE277FF78ED44940
50970	1	8	811	5951	37487	\N	51.660612999999998	Курсая область, город Льгов, М. Горького, 9	Россия, Курская область, Льговский район, Льгов	0101000020E6100000679C86A8C2A14140FE277FF78ED44940
50544	1	8	811	5951	37422	\N	51.647372652030299	Курсая область, город Льгов, Литейная, 15	Россия, Курская область, Льговский район, поселок Нижние Деревеньки	0101000020E6100000F19D98F562A241401EA8531EDDD24940
50947	1	8	811	5951	37330	\N	51.658050608523197	Курсая область, город Льгов, Гагарина, 14	Россия, Курская область, Льговский район, Льгов	0101000020E610000045BB0A293FA14140D00CE2033BD44940
50991	1	8	811	12743	\N	\N	51.4559	Курская область, Льговский район, Вышнедеревенский сельсовет, с.Лёвшинка, (здание МБОУ "Лёвшинская ООШ")	Россия, Курская область, Льговский район, поселок Левшинка	0101000020E6100000B519A721AAA041408A1F63EE5ABA4940
50989	1	8	811	12743	\N	\N	51.4559	Курская область, Льговский район, Вышнедеревенский сельсовет, д.Лёвшинка, (здание Анастасьевского ФАП)	Россия, Курская область, Льговский район, поселок Левшинка	0101000020E6100000B519A721AAA041408A1F63EE5ABA4940
51009	1	8	811	13672	\N	\N	51.726205	Курская область, Льговский район, Кудинцевский сельсовет, с.Кудинцево, (здание МБОУ Кудинцевская СОШ")	Россия, Курская область, Льговский район, поселок Кудинцево	0101000020E6100000996725ADF896414089981249F4DC4940
50988	1	8	811	5776	\N	\N	51.487642000000001	Курская область, Льговский район, Вышнедеревенский сельсовет, с.Кромские Быки, (здание Кромбыковского СДК)	Россия, Курская область, Льговский район, поселок Кромские Быки	0101000020E61000007C0BEBC6BBA34140F913950D6BBE4940
51013	1	8	811	54528	\N	\N	51.791384000000001	Курская область, Льговский район, Марицкий сельсовет, х.Красная Дубрава, (здание Краснодубравского ФАП)	Россия, Курская область, Льговский район, поселок Красная Дубрава	0101000020E6100000EA7AA2EBC2A74140F14927124CE54940
51001	1	8	811	13266	\N	\N	51.564694156880201	Курская область, Льговский район, Густомойский сельсовет, п.Колонтаевка, (здание МБОУ Колонтаевская СОШ")	Россия, Курская область, Льговский район, поселок Колонтаевка	0101000020E61000000FD07D39B38F4140AC1F9BE447C84940
50976	1	8	811	12126	\N	\N	51.617775000000002	Курская область, Льговский район, Большеугонский сельсовет, д.Клишино, (здание Клишинского сельского клуба)	Россия, Курская область, Льговский район, поселок Клишино	0101000020E6100000335019FF3EAD4140A9A44E4013CF4940
51000	1	8	811	13253	\N	\N	51.578505999999997	Курская область, Льговский район, Густомойский сельсовет, с. Износково, (здание Износковской амбулатории)	Россия, Курская область, Льговский район, поселок Износково	0101000020E61000001B834E081D8C414017450F7C0CCA4940
38478	1	6	1252	13180	35632	\N	54.547021000000001	д. Путогино, ул. Дружбы, д. 1		0101000020E61000002E3718EAB08A4140D49CBCC804464B40
51005	1	8	811	13468	\N	\N	51.760601999999999	Курская область, Льговский район, Иванчиковский сельсовет, с. Иванчиково, (здание Иванчиковского ЦСДК)	Россия, Курская область, Льговский район, поселок Иванчиково	0101000020E6100000B686527B11AB4140D7A205685BE14940
50987	1	8	811	54543	\N	\N	51.519542000000001	Курская область, Льговский район, Вышнедеревенский сельсовет, ст.Деревеньки, (здание МБОУ "Вышнедеревенская НОШ")		0101000020E6100000A81DFE9AACAB414000732D5A80C24940
50999	1	8	811	13182	\N	\N	51.636155677005199	Курская область, Льговский район, Густомойский сельсовет, с. Густомой, (здание Густомойского ФАП)	Россия, Курская область, Льговский район, поселок Густомой	0101000020E6100000529B38B9DF854140BC934F8F6DD14940
50993	1	8	811	12900	\N	\N	51.670540000000003	Курская область, Льговский район, Городенский сельсовет, с. Городенск, (здание Городенского сельского клуба)	Россия, Курская область, Льговский район, поселок Городенск	0101000020E6100000CE37A27BD6AF414076543541D4D54940
51014	1	8	811	13897	\N	\N	51.602035999999998	Курская область, Льговский район, Селекционный сельсовет, с.Глиница, (здание МБОУ "Глиницкая НОШ")	Россия, Курская область, Льговский район, поселок Глиница	0101000020E6100000043A933655954140E08101840FCD4940
50981	1	8	811	12384	\N	\N	51.548603	Курская область, Льговский район, Вышнедеревенский сельсовет, с.Вышние Деревеньки, (здание Администрации Вышнедеревенского сельсовета)	Россия, Курская область, Льговский район, поселок Вышние Деревеньки	0101000020E6100000EE42739D46A6414066BE839F38C64940
51011	1	8	811	13753	\N	\N	51.691392	Курская область, Льговский район, Кудинцевский сельсовет, д.Воронино, (здание администрации МСО)	Россия, Курская область, Льговский район, поселок Воронино	0101000020E61000006EDC627E6E9E4140A75B76887FD84940
50997	1	8	811	13106	\N	\N	51.668596000000001	Курская область, Льговский район, Городенский сельсовет, с.Борисовка, (здание МБОУ "Борисовская ООШ")	Россия, Курская область, Льговский район, поселок Борисовка	0101000020E6100000377007EA94B94140431EC18D94D54940
50975	1	8	811	12010	\N	\N	51.594192	Курская область, Льговский район, Большеугонский сельсовет, с.Большие Угоны, (здание амбулатории)	Россия, Курская область, Льговский район, поселок Большие Угоны	0101000020E610000000C45DBD8AB44140BDC5C37B0ECC4940
50974	1	8	811	12010	\N	\N	51.594192	Курская область, Льговский район, Большеугонский сельсовет, с.Большие Угоны, (здание МБОУ "Большеугонская СОШ")	Россия, Курская область, Льговский район, поселок Большие Угоны	0101000020E610000000C45DBD8AB44140BDC5C37B0ECC4940
50983	1	8	811	6047	\N	\N	51.577621999999998	Курская область, Льговский район, Вышнедеревенский сельсовет, д.Большая Орловка, (здание Орловского ФАП)	Россия, Курская область, Льговский район, поселок Большая Орловка	0101000020E61000006B0BCF4BC5A441409DB98784EFC94940
51004	1	8	811	13393	\N	\N	51.692011000000001	Курская область, Льговский район, Густомойский сельсовет, с.Банищи, (здание Банищанского СДК)	Россия, Курская область, Льговский район, поселок Банищи	0101000020E6100000BF823463D188414073BC02D193D84940
51003	1	8	811	13393	\N	\N	51.692011000000001	Курская область, Льговский район, Густомойский сельсовет, с.Банищи, (здание МБОУ "Банищанская СОШ")	Россия, Курская область, Льговский район, поселок Банищи	0101000020E6100000BF823463D188414073BC02D193D84940
50990	1	8	811	12783	\N	\N	51.608127000000003	Курская область, Льговский район, Вышнедеревенский сельсовет, д.Арсеньевка, (здание Арсеньевского ФАП)	Россия, Курская область, Льговский район, поселок Арсеньевка	0101000020E61000003E247CEF6F9E41404568041BD7CD4940
50972	1	8	770	11938	\N	\N	51.604804999999999	Курская область, Курчатовский район, Чаплинский сельсовет, село Чапли, (здание администрации Чаплинского сельсовета)	Россия, Курская область, Курчатовский район, поселок Чапли	0101000020E6100000684128EFE3C4414088BA0F406ACD4940
50960	1	8	770	11372	\N	\N	51.538761000000001	Курская область, Курчатовский район, Колпаковский сельсовет, деревня Сопеловка, (административное здание Колпаковского сельсовета)	Россия, Курская область, Курчатовский район, поселок Сопеловка	0101000020E6100000581B6327BCCA41401DAED51EF6C44940
50961	1	8	770	11392	\N	\N	51.493245000000002	Курская область, Курчатовский район, Колпаковский сельсовет, деревня Новосергеевка, (здание МКОУ "Новосергеевская СОШ")	Россия, Курская область, Курчатовский район, поселок Новосергеевка	0101000020E6100000024BAE62F1C3414030F5F3A622BF4940
50962	1	8	770	11447	\N	\N	51.503320000000002	Курская область, Курчатовский район, Колпаковский сельсовет, поселок Никольский, (здание МКОУ "Никольская СОШ")	Россия, Курская область, Курчатовский район, поселок Никольский	0101000020E6100000A5F8F884ECCE41401CB62DCA6CC04940
50963	1	8	770	11487	\N	\N	51.854461000000001	Курская область, Курчатовский район, деревня Николаевка, (здание МКОУ "Николаевская СОШ")	Россия, Курская область, Курчатовский район, поселок Николаевка	0101000020E610000075E5B33C0FD241408E5A61FA5EED4940
50967	1	8	770	11711	\N	\N	51.761923000000003	Курская область, Курчатовский район, Костельцевский сельсовет, деревня Нижнее Сосково, (здание МКОУ "Берноломненская ООШ")	Россия, Курская область, Курчатовский район, поселок Нижнее Сосково	0101000020E6100000691EC022BFDA4140FD885FB186E14940
50971	1	8	770	11889	\N	\N	51.696047999999998	Курская область, Курчатовский район, Макаровский сельсовет, деревня Мосолово, (здание МКОУ "Мосоловская ООШ")	Россия, Курская область, Курчатовский район, поселок Мосолово	0101000020E61000001650A8A78FD641401D39D21918D94940
50965	1	8	770	11581	\N	\N	51.805404000000003	Курская область, Курчатовский район, Костельцевский сельсовет, село Мармыжи, (здание бывшего МОУ "Мармыжская ООШ")	Россия, Курская область, Курчатовский район, поселок Мармыжи	0101000020E6100000E60819C8B3BF4140A708707A17E74940
50968	1	8	770	5993	\N	\N	51.694574000000003	Курская область, Курчатовский район, Макаровский сельсовет, село Макаровка, (здание МКОУ "Макаровская СОШ")	Россия, Курская область, Курчатовский район, поселок Макаровка	0101000020E6100000E6E61BD13DC34140725303CDE7D84940
50959	1	8	770	11307	\N	\N	51.577885000000002	Курская область, Курчатовский район, Дружненский сельсовет, деревня Любицкое, (здание МКУ "Любицкий СДК")	Россия, Курская область, Курчатовский район, поселок Любицкое	0101000020E61000007E384888F2C94140ABECBB22F8C94940
50964	1	8	770	11558	\N	\N	51.825436000000003	Курская область, Курчатовский район, Костельцевский сельсовет, село Костельцево, (здание МКОУ Костельцевская ООШ")	Россия, Курская область, Курчатовский район, поселок Костельцево	0101000020E6100000649291B3B0C74140757808E3A7E94940
50953	1	8	770	10785	37596	\N	51.620005999999997	Курская область, Курчатовский район, поселок им. К. Либкнехта, ул. Свободы (административное здание СПК "Иванинский"), д. 166		0101000020E6100000EC4E779E78BC414071A94A5B5CCF4940
50951	1	8	770	10785	37399	\N	51.620005999999997	Курская область, Курчатовский район, поселок им. К. Либкнехта, ул. Пушкина (здание ПУ №2), д. 6		0101000020E6100000EC4E779E78BC414071A94A5B5CCF4940
50952	1	8	770	10785	37595	\N	51.620005999999997	Курская область, Курчатовский район, поселок им. К. Либкнехта, ул. Красная Площадь (здание поликлиники), д. 44		0101000020E6100000EC4E779E78BC414071A94A5B5CCF4940
50948	1	8	770	10785	37380	\N	51.620005999999997	Курская область, Курчатовский район, поселок им. К. Либкнехта, ул. Кирова (здание МКОУ ДОД "ДЮСШ"), д. 26 А		0101000020E6100000EC4E779E78BC414071A94A5B5CCF4940
50950	1	8	770	10785	37610	\N	51.620005999999997	Курская область, Курчатовский район, поселок им. К. Либкнехта, ул. Захара Суворова (здание РЦДТ), д. 4		0101000020E6100000EC4E779E78BC414071A94A5B5CCF4940
50955	1	8	770	11067	37648	\N	51.642614000000002	Курская область, Курчатовский район, поселок Иванино, площадь Антипова (здание районного ДК), д. 1		0101000020E61000003A2009FB76CA4140D3F9F02C41D24940
50954	1	8	770	11067	37628	\N	51.642614000000002	Курская область, Курчатовский район, поселок Иванино, ул. Октябрьская (здание администрации), д. 33		0101000020E61000003A2009FB76CA4140D3F9F02C41D24940
50966	1	8	770	11641	\N	\N	51.775500000000001	Курская область, Курчатовский район, Костельцевский сельсовет, деревня Жмакино, (административное здание Костельцевского сельсовета)	Россия, Курская область, Курчатовский район, поселок Жмакино	0101000020E6100000B7D5AC33BECD41402506819543E34940
50958	1	8	770	11259	\N	\N	51.615029	Курская область, Курчатовский район, Дружненский сельсовет, деревня Дружная, (здание МКУ "Дружненский клуб досуга")	Россия, Курская область, Курчатовский район, поселок Дружная	0101000020E6100000FB3C4679E6C94140B98B3045B9CE4940
50969	1	8	770	5414	\N	\N	51.711201000000003	Курская область, Курчатовский район, Макаровский сельсовет, село Дроняево, (здание МКОУ "Дроняевская СОШ")	Россия, Курская область, Курчатовский район, поселок Дроняево	0101000020E61000008D4468041BCF4140F6F065A208DB4940
50957	1	8	770	5463	\N	\N	51.660891999999997	Курская область, Курчатовский район, Дичнянский сельсовет, село Дичня, (здание МСНУ "Центр Культуры и Досуга")	Россия, Курская область, Курчатовский район, поселок Дичня	0101000020E6100000ACCABE2B82DD41401118EB1B98D44940
50956	1	8	770	5463	\N	\N	51.660891999999997	Курская область, Курчатовский район, Дичнянский сельсовет, село Дичня, (здание МКОУ "Дичнянская СОШ")	Россия, Курская область, Курчатовский район, поселок Дичня	0101000020E6100000ACCABE2B82DD41401118EB1B98D44940
50973	1	8	770	11991	\N	\N	51.662495999999997	Курская область, Курчатовский район, Чаплинский сельсовет, село Быки, (здание МКУК "Быковский сельский Дом культуры")	Россия, Курская область, Курчатовский район, поселок Быки	0101000020E61000008CD651D504C141408BDD3EABCCD44940
50949	1	8	7322	54506	37602	\N	51.618670314208103	Курская область, Курчатовский район, поселок им. К. Либкнехта, ул. Кирова (здание школы № 2), д. 15	Россия, Курская область, Курчатовский район, поселок Имени Карла Либкнехта	0101000020E6100000C80A7E1B62BC414017821C9430CF4940
51435	1	8	395	2066	\N	\N	51.660753	Курская область, Черемисиновский район, Ниженский сельсовет, д. Мяснянкино, здание администрации Ниженского сельсовета	Россия, Курская область, Курчатов городской округ, поселок Мяснянкино	0101000020E6100000740D33349ED44140F0DDE68D93D44940
50895	1	8	269	54527	\N	\N	51.818790214884402	Курская область, Курский район, Брежневский сельсовет, х.Шумаков, Брежневский сельский клуб	Россия, Курская область, Курский район, поселок Шумаков	0101000020E6100000F355F2B1BBFA41405B25581CCEE84940
50892	1	8	269	8125	\N	\N	51.720692999999997	Курская область, Курский район, Бесединский сельсовет, д.Шеховцово, Шеховцовский СДК		0101000020E6100000C6A69542203D424062BA10AB3FDC4940
50944	1	8	269	54472	\N	\N	51.806793605307703	Курская область, Курский район, Щетинский сельсовет, д.Ушаково, клуб ОБОУ НПО ПУ - 36	Россия, Курская область, деревня Ушаково, улица Ушакова	0101000020E6100000E754320054214240F44D9A0645E74940
50894	1	8	269	40320	\N	\N	51.756323180803498	Курская область, Курский район, Бесединский сельсовет, с.Троица, здание Троицкой школы	Россия, Курская область, Курский район, поселок Троица	0101000020E61000009EEE3CF19C494240371B2B31CFE04940
50925	1	8	269	9637	\N	\N	51.580376000000001	Курская область, Курский район, Новопоселеновский сельсовет, с.Селиховы Дворы, Селиховская средняя школа		0101000020E61000002E8F3523830A424010B1C1C249CA4940
50910	1	8	269	54504	\N	\N	51.692720670496101	Курская область, Курский район, Клюквинский сельсовет, п.Сахаровка, Клюквинская средняя школа	Россия, Курская область, поселок Сахаровка	0101000020E6100000B16B7BBB252742404F20EC14ABD84940
50929	1	8	269	54521	\N	\N	51.842242158708402	Курская область, Курский район, Пашковский сельсовет, д.Сапогово, Сапоговская средняя школа	Россия, Курская область	0101000020E61000009DD7D825AA1B4240A8A8FA95CEEB4940
50939	1	8	269	54464	\N	\N	51.660814000000002	Курская область, Курский район, Рышковский сельсовет, с.Рышково, детская школа искусств		0101000020E610000099654F029B174240965E9B8D95D44940
50896	1	8	269	54540	\N	\N	51.849256701949201	Курская область, Курский район, Брежневский сельсовет, д.Разиньково, Гнездиловская школа	Россия, Курская область, Курский район, поселок Разиньково	0101000020E610000059C2DA183BF5414015731074B4EC4940
50936	1	8	269	10229	\N	\N	51.745403000000003	Курская область, Курский район, Полянский сельсовет, с.Полянское, Полянская средняя школа		0101000020E61000003B55BE6724FE41408FAB915D69DF4940
50935	1	8	269	10140	\N	\N	51.605252884027301	Курская область, Курский район, Полевской сельсовет, д.Полевая, администрация сельсовета	Россия, Курская область, Курский район, поселок Полевая	0101000020E61000006C5A290472414240276728EE78CD4940
50815	1	8	269	54547	\N	\N	51.7528889912438	Курская область, Курский район, Клюквинский сельсовет,  п.Подлесный, СХПК "Подлесное"	Россия, Курская область, поселок Подлесный	0101000020E610000042D13C80452842405342B0AA5EE04940
50893	1	8	269	8177	\N	\N	51.738365000000002	Курская область, Курский район, Бесединский сельсовет, д.Петровское, КФХ "Дружба"		0101000020E6100000DEAD2CD1594842406AC18BBE82DE4940
50916	1	8	269	9261	\N	\N	51.583902000000002	Курская область, Курский район, Лебяженский сельсовет, п.Петрин, Петринский детский сад		0101000020E6100000B4E908E0661D4240D508FD4CBDCA4940
50923	1	8	269	9543	\N	\N	51.822313000000001	Курская область, Курский район, Ноздрачевский сельсовет, с.Ноздрачево, Ноздрачевская школа		0101000020E610000098158A743F2D4240AF09698D41E94940
50635	1	8	269	54520	\N	\N	51.810794000000001	Курская область, Курский район, Щетинский сельсовет, д.Михайлово, Михайловский ФАП	Россия, Курская область, деревня Михайлово	0101000020E6100000E21DE0490B29424082E50819C8E74940
50900	1	8	269	8523	\N	\N	51.800078999999997	Курская область, Курский район, Винниковский сельсовет, п.Малиновый, Отрешковская школа		0101000020E61000001DC87A6AF5374240B29B19FD68E64940
50930	1	8	269	52648	\N	\N	51.599474000000001	Курская область, Курский район, Полевской сельсовет, д.Лисово, Лисовская основная школа		0101000020E6100000399A232BBF4C4240B2666490BBCC4940
50914	1	8	269	54532	\N	\N	51.672912428444498	Курская область, Курский район, Лебяженский сельсовет, с.Лебяжье, Лебяженский сельский клуб	Россия, Курская область, село Лебяжье	0101000020E610000051C1E10511234240008BFCFA21D64940
50934	1	8	269	10125	\N	\N	51.636572000000001	Курская область, Курский район, Полевской сельсовет, с.Колодное, Колодненская начальная школа		0101000020E6100000EFAD484C5037424050C6F8307BD14940
50907	1	8	269	8840	\N	\N	51.713166273548602	Курская область, Курский район, Клюквинский сельсовет,  с.Клюква, Клюквинский Дом культуры	Россия, Курская область, Курский район, поселок Клюква	0101000020E61000005D16139B8F2D4240404F030649DB4940
50933	1	8	269	10079	\N	\N	51.569735000000001	Курская область, Курский район, Полевской сельсовет, с.Кизилово, магазин ПО "Бесединское"		0101000020E6100000AB4203B16C4242407B319413EDC84940
50921	1	8	269	54505	\N	\N	51.803342697133502	Курская область, Курский район, Нижнемедведицкий сельсовет, п.Касиновский, Косиновская средняя школа	Россия, Курская область, поселок Касиновский	0101000020E6100000C97553CA6B1142403A3C84F1D3E64940
50906	1	8	269	54473	\N	\N	51.814870390100403	Курская область, Курский район, Камышинский сельсовет, п.Камыши, Камышинский районный Дом культуры	Россия, Курская область, поселок Камыши	0101000020E61000002672C119FC234240EA3E00A94DE84940
50945	1	8	269	54487	\N	\N	51.819725756912398	Курская область, Курский район, Щетинский сельсовет, п.Искра, Сапоговская средняя школа	Россия, Курская область, поселок Искра, улица Выгонная	0101000020E6100000C669882AFC19424028D714C8ECE84940
50940	1	8	269	54495	\N	\N	51.671523748206603	Курская область, Курский район, Рышковский сельсовет, д.Зорино, Зоринский СДК		0101000020E6100000B6BC72BD6D1A4240533D997FF4D54940
50938	1	8	269	10293	\N	\N	51.710303000000003	Курская область, Курский район, Полянский сельсовет, д.Жеребцово, Жеребцовский Дом досуга		0101000020E61000006EFAB31F29FE414017A06D35EBDA4940
50898	1	8	269	8441	\N	\N	51.866669999999999	Курская область, Курский район, Брежневский сельсовет, д.Дроняево, Нижнекасиновский ФАП		0101000020E6100000029B73F04C0042405036E50AEFEE4940
44189	1	7	405	2255	32472	\N	58.204472000000003	Костромская область, Сусанинский район, с. Сумароково, Новая, 3		0101000020E6100000DC80CF0F23E644404F7974232C1A4D40
50760	1	8	269	1129	\N	\N	51.808861999999998	Курская область, Железногорский район, Троицкий сельсовет, д. Гнездилово, здание бывшего Гнездиловского фельдшерско-акушерского пункта	Россия, Курская область, Курский район, поселок Гнездилово	0101000020E6100000B7B3AF3C48FD4140137D3ECA88E74940
50927	1	8	269	9776	\N	\N	51.865195999999997	Курская область, Курский район, Пашковский сельсовет, с.Глебово, Глебовская средняя школа		0101000020E61000004AB54FC763184240A45016BEBEEE4940
50903	1	8	269	54479	\N	\N	51.6522689758159	Курская область, Курский район, Ворошневский сельсовет, д.Ворошнево, кабинет главврача амбулатории	Россия, Курская область, поселок Ворошнево	0101000020E6100000BE2D58AA0B064240E998F38C7DD34940
50902	1	8	269	54479	\N	\N	51.652147179013802	Курская область, Курский район, Ворошневский сельсовет, д.Ворошнево, администрация сельсовета	Россия, Курская область, поселок Ворошнево	0101000020E6100000B29C84D2170642409E978A8D79D34940
50901	1	8	269	54479	\N	\N	51.654225396143197	Курская область, Курский район, Ворошневский сельсовет, д.Ворошнево, Ворошневская амбулатория		0101000020E61000008368AD6873064240E09C11A5BDD34940
50905	1	8	269	52592	\N	\N	51.877454024702502	Курская область, Курский район, Камышинский сельсовет, д.Волобуево, бывшая Волобуевская школа	Россия, Курская область, Курский район, поселок Волобуево	0101000020E6100000499D8026C222424048DFA46950F04940
50911	1	8	269	54501	\N	\N	51.755673999999999	Курская область, Курский район, Клюквинский сельсовет, Военный городок 26, Дом культуры		0101000020E61000000D1B65FD661E42400038F6ECB9E04940
50924	1	8	269	9616	\N	\N	51.857864999999997	Курская область, Курский район, Ноздрачевский сельсовет, с.Виногробль, Виногробльский Дом досуга		0101000020E6100000B517D1764C37424007B13385CEED4940
50920	1	8	269	9428	\N	\N	51.847701999999998	Курская область, Курский район, Нижнемедведицкий сельсовет, д.Верхняя Медведица, здание Администрации сельсовета	Россия, Курская область, Курский район, поселок Верхняя Медведица	0101000020E6100000213F1BB96E0C42407C60C77F81EC4940
50897	1	8	269	8408	\N	\N	51.831848000000001	Курская область, Курский район, Брежневский сельсовет, с.Верхнекасиново, Верхнекасиновская библиотека		0101000020E610000008759142590642401B9FC9FE79EA4940
50932	1	8	269	10005	\N	\N	51.584780000000002	Курская область, Курский район, Полевской сельсовет, с.Верхнее Гуторово, Верхнегуторовский дом досуга		0101000020E6100000F9DA334B024A42406DAD2F12DACA4940
50942	1	8	269	10525	\N	\N	51.675494	Курская область, Курский район, Шумаковский сельсовет, с.Введенское, Коноревская основная школа		0101000020E6100000A1100187502D424076525F9676D64940
50891	1	8	269	8075	\N	\N	51.678699999999999	Курская область, Курский район, Бесединский сельсовет, д.Букреево, здание бывшей Букреевской школы	Россия, Курская область, Курский район, поселок Букреево	0101000020E6100000A6B5696CAF2B4240C9E53FA4DFD64940
50913	1	8	269	9139	\N	\N	51.847034000000001	Курская область, Курский район, Лебяженский сельсовет, с.Букреевка, Лебяженская школа		0101000020E61000004B3ACAC16C204240CF4C309C6BEC4940
50904	1	8	269	9139	\N	\N	51.848578117452099	Курская область, Курский район, Камышинский сельсовет, д.Букреевка, Букреевская школа	Россия, Курская область, Курский район, поселок Букреевка	0101000020E6100000357BA01518224240740D33349EEC4940
50941	1	8	269	10449	\N	\N	51.669650113283097	Курская область, Курский район, Шумаковский сельсовет, д.Большое Шумаково, Шумаковский СДК	Россия, Курская область, Курский район, поселок Большое Шумаково	0101000020E6100000A6B8AAECBB2E424019E25817B7D54940
50937	1	8	269	5879	\N	\N	51.7866651437025	Курская область, Курский район, Полянский сельсовет, д.Большое Лукино, Полянская средняя школа	Россия, Курская область, Курский район, поселок Большое Лукино	0101000020E6100000B8955E9B8DFD414034F44F70B1E44940
50890	1	8	269	8021	\N	\N	51.708734999999997	Курская область, Курский район, Бесединский сельсовет, с.Беседино, здание Бесединской школы	Россия, Курская область, Курский район, поселок Беседино	0101000020E6100000E1CE85915E3C4240E94317D4B7DA4940
50912	1	8	269	54556	\N	\N	51.595573849359297	Курская область, Курский район, Лебяженский сельсовет, д.2-е Безлесное, Безлесенский сельский клуб	Россия, Курская область, Курский район, поселок Безлесное 2-е	0101000020E610000081971936CA244240882CD2C43BCC4940
50931	1	8	269	9986	\N	\N	51.628051999999997	Курская область, Курский район, Полевской сельсовет, д.Барышниково, Барышниковский СДК		0101000020E61000002E8ECA4DD4424240FC17080264D04940
50889	1	8	269	7969	\N	\N	51.875571117316397	Курская область, Курский район, Бесединский сельсовет, д.Алябьево, здание бывшей Алябьевской общеобра	Россия, Курская область, Курский район, поселок Алябьево	0101000020E6100000E1B54B1B0E194240BB29E5B512F04940
50928	1	8	269	9834	\N	\N	51.900286000000001	Курская область, Курский район, Пашковский сельсовет, д.1-е Курасово, Курасовская основная школа		0101000020E61000004227840EBA124240F98557923CF34940
50899	1	8	269	40205	\N	\N	51.813736602373901	Курская область, Курский район, Винниковский сельсовет, с.1-е Винниково, Винниковский СДК	Россия, Курская область, Курский район, поселок 1-е Винниково	0101000020E6100000382D78D1573E4240C845B58828E84940
50888	1	8	752	7932	\N	\N	51.437044	Курская область, Кореневский район, село Шептуховка, (здание СПК "Авангард", помещение администрации сельсовета)	Россия, Курская область, Кореневский район, поселок Шептуховка	0101000020E610000030815B77F3944140DE74CB0EF1B74940
50868	1	8	752	6998	\N	\N	51.192748000000002	Курская область, Кореневский район, село Троицкое, (здание Троицкой школы)	Россия, Курская область, Кореневский район, поселок Троицкое	0101000020E61000006E15C440D7684140492F6AF7AB984940
50884	1	8	752	7736	\N	\N	51.446632999999999	Курская область, Кореневский район, село Толпино, адрес помещения для голосования: (здание Толпинской школы), адрес УИК: здание администрации с/с	Россия, Курская область, Кореневский район, поселок Толпино	0101000020E6100000520E6613607241403D2828452BB94940
50881	1	8	752	7609	\N	\N	51.314352999999997	Курская область, Кореневский район, село Снагость, (здание администрации Снагостского сельсовета)	Россия, Курская область, Кореневский район, поселок Снагость	0101000020E6100000D8D64FFF59734140223317B83CA84940
50887	1	8	752	7876	\N	\N	51.489364000000002	Курская область, Кореневский район, село Сафоновка, (здание Сафоновской школы)	Россия, Курская область, Кореневский район, поселок Сафоновка	0101000020E61000009CA73AE4669241407DEBC37AA3BE4940
50880	1	8	752	7568	\N	\N	51.491253999999998	Курская область, Кореневский район, село Пушкарное, (здание администрации Пушкарского сельсовета)	Россия, Курская область, Кореневский район, поселок Пушкарное	0101000020E6100000EAEC647094684140BC033C69E1BE4940
50878	1	8	752	7476	\N	\N	51.402816999999999	Курская область, Кореневский район, село Ольговка, (здание ООО агрофирма "Ветреное")	Россия, Курская область, Кореневский район, поселок Ольговка	0101000020E6100000CBF8F71917824140ECA2E8818FB34940
50875	1	8	752	7333	\N	\N	51.280371000000002	Курская область, Кореневский район, село Обуховка, (здание Обуховской школы)	Россия, Курская область, Кореневский район, поселок Обуховка	0101000020E61000002AE3DF675C7A414098DF6932E3A34940
50883	1	8	752	7688	\N	\N	51.534492	Курская область, Кореневский район, село Нижняя Груня, (здание ФАП)	Россия, Курская область, Кореневский район, поселок Нижняя Груня	0101000020E6100000618E1EBFB77B4140A0FCDD3B6AC44940
50874	1	8	752	7293	\N	\N	51.308920000000001	Курская область, Кореневский район, село Любимовка, (здание администрации Любимовского сельсовета)	Россия, Курская область, Кореневский район, поселок Любимовка	0101000020E6100000212235ED62844140488AC8B08AA74940
50876	1	8	752	7405	\N	\N	51.392583999999999	Курская область, Кореневский район, село Кремяное, (здание СПК "Большевик", помещение администрации сельсовета)	Россия, Курская область, Кореневский район, поселок Кремяное	0101000020E610000012A0A696AD8941406877483140B24940
50669	1	8	752	29051	\N	\N	51.348905999999999	Курская область, Кореневский район, село Краснооктябрьское, (здание сельского клуба)	Россия, Курская область, Кореневский район, поселок Краснооктябрьское	0101000020E6100000ECA694D74A68414068B0A9F3A8AC4940
50650	1	8	752	29051	\N	\N	51.347120324510598	Курская область, Глушковский район, Веселовский сельсовет, п.Краснооктябрьский, д.27	Россия, Курская область, Кореневский район, поселок Краснооктябрьское	0101000020E61000003C9F01F566684140CDE49B6D6EAC4940
50872	1	8	752	6769	\N	\N	51.413766000000003	Курская область, Кореневский район, село Коренево, (здание Кореневской школы № 2)	Россия, Курская область, Кореневский район, поселок Коренево	0101000020E61000001D058882197341402F19C748F6B44940
50871	1	8	752	6769	\N	\N	51.413766000000003	Курская область, Кореневский район, село Коренево, (здание сельского дома культуры)	Россия, Курская область, Кореневский район, поселок Коренево	0101000020E61000001D058882197341402F19C748F6B44940
50873	1	8	752	6769	37706	\N	51.413766000000003	Курская область, Кореневский район, поселок Коренево, ул. Юбилейная, д. 24		0101000020E61000001D058882197341402F19C748F6B44940
50863	1	8	752	6769	37484	\N	51.413766000000003	Курская область, Кореневский район, поселок Коренево, ул.  Октябрьская, д. 49		0101000020E61000001D058882197341402F19C748F6B44940
50865	1	8	752	6769	37286	\N	51.413766000000003	Курская область, Кореневский район, поселок Коренево, ул. Ленина, д. 50		0101000020E61000001D058882197341402F19C748F6B44940
50864	1	8	752	6769	37309	\N	51.413766000000003	Курская область, Кореневский район, поселок Коренево, ул.70 лет Октября, д. 12	Россия, Курская область, Кореневский район, поселок Коренево	0101000020E61000001D058882197341402F19C748F6B44940
50869	1	8	752	7050	\N	\N	51.317292000000002	Курская область, Кореневский район, село Комаровка, адрес помещения для голосования: (здание Комаровской школы), адрес УИК: здание администрации с/с	Россия, Курская область, Кореневский район, поселок Комаровка	0101000020E6100000986E1283C064414027A435069DA84940
50886	1	8	752	7821	\N	\N	51.467644999999997	Курская область, Кореневский район, поселок Каучук, (здание МУП ЖКХ)	Россия, Курская область, Кореневский район, поселок Каучук	0101000020E6100000CB9E0436E7984140A79196CADBBB4940
50877	1	8	752	54537	\N	\N	51.415732586074903	Курская область, Кореневский район, деревня Журавля, (здание ФАП)	Россия, Курская область, Кореневский район, поселок Журавли	0101000020E61000000DC2DCEEE58C41401A6F2BBD36B54940
50867	1	8	752	6950	\N	\N	51.208139000000003	Курская область, Кореневский район, село Гордеевка, (здание администрации бывшего Гордеевского сельсовета)	Россия, Курская область, Кореневский район, поселок Гордеевка	0101000020E6100000E9D1544FE66F4140D6027B4CA49A4940
50652	1	8	682	28275	37755	\N	51.410598	Курская область, Глушковский район, Званновский сельсовет, д.Лещиновка, ул.Школьная, Лещиновская СОШ		0101000020E6100000D1ADD7F4A0444140C9E6AA798EB44940
50866	1	8	752	6905	\N	\N	51.247424000000002	Курская область, Кореневский район, деревня Внезапное, (здание сельского дома культуры)	Россия, Курская область, Кореневский район, поселок Внезапное	0101000020E61000002C634337FB6F41406D1FF296AB9F4940
50882	1	8	752	7666	\N	\N	51.533208999999999	Курская область, Кореневский район, село Верхняя Груня, (здание администрации бывшего Верхнегрунского сельсовета)	Россия, Курская область, Кореневский район, поселок Верхняя Груня	0101000020E6100000834F73F2228341406877483140C44940
50879	1	8	752	7526	\N	\N	51.525072999999999	Курская область, Кореневский район, село Благодатное, (здание сельского дома культуры)	Россия, Курская область, Кореневский район, поселок Благодатное	0101000020E61000009626A5A0DB7141409D81919735C34940
50870	1	8	752	7111	\N	\N	51.290528000000002	Курская область, Кореневский район, село Апанасовка, (здание сельского клуба досуга)	Россия, Курская область, Кореневский район, поселок Апанасовка	0101000020E6100000E7DF2EFB756D41404149810530A54940
50885	1	8	752	7786	\N	\N	51.466892999999999	Курская область, Кореневский район, село Александровка, (здание ФАП)	Россия, Курская область, Кореневский район, поселок Александровка	0101000020E61000005D16139B8F7D41409CDD5A26C3BB4940
50845	1	8	721	5840	\N	\N	51.934016	Курская область, Конышевский район, Машкинский сельсовет, с.Яцено, (здание бывшей Яценской основной общеобразовательной школы, кабинет)	Россия, Курская область, Конышевский район, поселок Яцено	0101000020E6100000753BFBCA83AC41406AF816D68DF74940
50846	1	8	721	5886	\N	\N	51.998922	Курская область, Конышевский район, Машкинский сельсовет, с.Яндовище (здание  МКОУ "Яндовищенская основная общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Яндовище	0101000020E6100000BDE47FF277AB4140A1A014ADDCFF4940
50856	1	8	721	6405	\N	\N	51.790241999999999	Курская область, Конышевский район, Платавский сельсовет, с.Шустово, (здание МУ "Шустовский сельский Дом культуры", зрительный зал)	Россия, Курская область, Конышевский район, поселок Шустово	0101000020E61000005BECF659658841407BF65CA626E54940
50860	1	8	721	6617	\N	\N	51.776926000000003	Курская область, Конышевский район, Прилепский сельсовет, с.Ширково (здание  МКОУ "Ширковская основная общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Ширково	0101000020E6100000DDEF5014E89B4140C0B4A84F72E34940
50835	1	8	721	5304	\N	\N	51.86365	Курская область, Конышевский район, Беляевский сельсовет, с.Черничено (здание МКОУ "Черниченская основная общеобразовательная школа", спортивный зал)	Россия, Курская область, Конышевский район, поселок Черничено	0101000020E6100000172CD505BC9641405F984C158CEE4940
50859	1	8	721	6593	\N	\N	51.823059000000001	Курская область, Конышевский район, Прилепский сельсовет, с.Толкачевка здание  МКОУ "Толкачевская основная общеобразовательная школа", классная комната)		0101000020E6100000DE04DF347D9E4140D8D64FFF59E94940
50861	1	8	721	6677	\N	\N	51.988867999999997	Курская область, Конышевский район, Старобелицкий сельсовет, с.Старая Белица (здание  МКОУ "Старобелицкая средняя общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Старая Белица	0101000020E610000012312592E8974140CC07043A93FE4940
50841	1	8	721	5621	\N	\N	51.888703999999997	Курская область, Конышевский район, Захарковский сельсовет, д.Севенки, (административное здание ОАО "Севенское", кабинет)	Россия, Курская область, Конышевский район, поселок Севенки	0101000020E6100000DD99098673AB414085E97B0DC1F14940
50837	1	8	721	5403	\N	\N	51.967576999999999	Курская область, Конышевский район, Ваблинский сельсовет, с.Рыжково (здание МКОУ "Рыжковская основная общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Рыжково	0101000020E6100000B4C70BE9F0BE41404FAE2990D9FB4940
50858	1	8	721	6533	\N	\N	51.849609999999998	Курская область, Конышевский район, Прилепский сельсовет, д.Прилепы (административное здание администрации Прилепского сельсовета, зал заседаний)	Россия, Курская область, Конышевский район, поселок Прилепы	0101000020E6100000986A662D05A24140622D3E05C0EC4940
50854	1	8	721	6306	\N	\N	51.810588000000003	Курская область, Конышевский район, Платавский сельсовет, с.Платава, (здание МУ "Платавский сельский Дом культуры", зрительный зал)	Россия, Курская область, Конышевский район, поселок Платава	0101000020E6100000284701A2608E4140D943FB58C1E74940
50834	1	8	721	5240	\N	\N	51.878335999999997	Курская область, Конышевский район, Беляевский сельсовет, с.Нижнее Песочное (здание МКОУ "Нижнепесоченская основная общеобразовательная школа, классная комната)	Россия, Курская область, Конышевский район, поселок Нижнее Песочное	0101000020E610000036751E15FF794140217365506DF04940
50849	1	8	721	6035	\N	\N	51.938631023930498	Курская область, Конышевский район, Наумовский сельсовет, с.Наумовка (административное здание ООО "Агропромкомплектация-Курск", кабинет администрации Наумовского с/совета)	Россия, Курская область, Конышевский район, поселок Наумовка	0101000020E610000037C64E78099641408201840F25F84940
38475	1	6	1252	13033	35564	\N	54.475631	д. Посконь, ул Центральная, д. 1		0101000020E6100000AD31E884D05F41405DFB027AE13C4B40
50844	1	8	721	5777	\N	\N	51.955973	Курская область, Конышевский район, Машкинский сельсовет, с.Машкино (здание  МКОУ "Машкинская основная общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Машкино	0101000020E61000002BDF3312A1A74140F46DC1525DFA4940
50848	1	8	721	5983	\N	\N	52.034483000000002	Курская область, Конышевский район, Машкинский сельсовет, д.Мармыжи (здание бывшей Мармыжанской основной общеобразовательной школы, кабинет)	Россия, Курская область, Конышевский район, поселок Мармыжи	0101000020E610000007F0164850AC41404DA25EF069044A40
50842	1	8	721	5693	\N	\N	51.900103000000001	Курская область, Конышевский район, Малогородьковский сельсовет, с.Малое Городьково (здание МКОУ "Малогородьковская основная общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Малое Городьково	0101000020E6100000E92CB308C5C4414008043A9336F34940
50833	1	8	721	5186	\N	\N	51.892600000000002	Курская область, Конышевский район, Беляевский сельсовет, с.Малахово, (здание Малаховского ФАПа, кабинет)	Россия, Курская область, Конышевский район, поселок Малахово	0101000020E610000056293DD34B8C41406E3480B740F24940
50852	1	8	721	54531	\N	\N	51.954764920177702	Курская область, Конышевский район, Наумовский сельсовет, с.Макаро-Петровское, (здание МУ "Макаропетровский сельский Дом культуры", зрительный зал)	Россия, Курская область, Конышевский район, поселок Макарово-Петровское	0101000020E61000004B1E4FCB0F884140C72E51BD35FA4940
50831	1	8	721	54461	37306	\N	51.839500000000001	Курская область, Конышевский район, поселок Конышевка (административное здание администрации поселка Конышевка, актовый зал)  50 лет Советской власти, 6	Россия, Курская область, Конышевский район, поселок Конышевка	0101000020E6100000687A89B14CA54140FA7E6ABC74EB4940
50830	1	8	721	54461	37306	\N	51.842711504343399	Курская область, Конышевский район, поселок Конышевка (здание районного Дома культуры, фойе) 50 лет Советской власти, 7	Россия, Курская область, Конышевский район, поселок Конышевка	0101000020E6100000C1E270E657A541402FF99FFCDDEB4940
50853	1	8	721	6257	\N	\N	51.837870000000002	Курская область, Конышевский район, Платавский сельсовет, д.Кашара (здание  МКОУ Кашарская  средняя общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Кашара	0101000020E6100000A583F57F0E8B41405726FC523FEB4940
50839	1	8	721	5512	\N	\N	51.808588999999998	Курская область, Конышевский район, Захарковский сельсовет, с.Захарково (административное здание администрации Захарковского сельсовета, кабинет)		0101000020E61000002046088F36AE4140E27327D87FE74940
50838	1	8	721	5452	\N	\N	52.039802000000002	Курская область, Конышевский район, Ваблинский сельсовет, с.Жигаево (здание МКОУ "Жигаевская средняя общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Жигаево	0101000020E6100000B493C151F2BA41405F28603B18054A40
50840	1	8	721	5575	\N	\N	51.847228999999999	Курская область, Конышевский район, Захарковский сельсовет, д.Дремово-Черемошки (здание бывшей  Дремово-Черемошанской основной общеобразовательной школы, кабинет)	Россия, Курская область, Конышевский район, поселок Дремово-Черемошки	0101000020E6100000EFC7ED974FAE4140849CF7FF71EC4940
50855	1	8	721	6370	\N	\N	51.809947999999999	Курская область, Конышевский район, Платавский сельсовет, д.Гряды, (здание Грядского сельского клуба, зрительный зал)	Россия, Курская область, Конышевский район, поселок Гряды	0101000020E610000036E9B6442E7E4140F5BA4560ACE74940
50843	1	8	721	5736	\N	\N	51.902898	Курская область, Конышевский район, Малогородьковский сельсовет, с.Глазово (здание МКОУ "Глазовская средняя общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Глазово	0101000020E61000008B70935165BA4140D9CF622992F34940
50851	1	8	721	54548	\N	\N	51.934008750596703	Курская область, Конышевский район, Наумовский сельсовет, с.Верхняя Соковнинка (здание бывшей Верхнесоковнинской средней общеобразовательной школы, кабинет)	Россия, Курская область, Конышевский район, поселок Верхняя Соковинка	0101000020E61000007E552E54FE9D4140B8955E9B8DF74940
50850	1	8	721	6108	\N	\N	51.926203000000001	Курская область, Конышевский район, Наумовский сельсовет, д.Васильевка (здание  МКОУ "Васильевская средняя общеобразовательная школа", классная комната)	Россия, Курская область, Конышевский район, поселок Васильевка	0101000020E6100000BFF2203D458E4140823AE5D18DF64940
50836	1	8	721	5352	\N	\N	51.944665999999998	Курская область, Конышевский район, Ваблинский сельсовет, с.Вабля (здание МКОУ "Ваблинская основная общеобразовательная школа", фойе)	Россия, Курская область, Конышевский район, поселок Вабля	0101000020E61000006A85E97B0DB9414052D2C3D0EAF84940
50832	1	8	721	5144	\N	\N	51.867693000000003	Курская область, Конышевский район, Беляевский сельсовет, с.Беляево, (здание МКОУ "Беляевская средняя общеобразовательная школа", спортивный зал)	Россия, Курская область, Конышевский район, поселок Беляево	0101000020E6100000BC3C9D2B4A8D4140ECFB709010EF4940
50862	1	8	721	6732	\N	\N	52.020313999999999	Курская область, Конышевский район, Старобелицкий сельсовет, ж.д.ст.Арбузово (здание ОАО Конышевское хлебоприемное-приемный пункт ст.Арбузово, кабинет)	Россия, Курская область, Конышевский район, поселок Арбузово	0101000020E610000012C0CDE2C58E414052D32EA699024A40
50820	1	8	231	4493	\N	\N	51.827461999999997	Курская область, Касторенский район, Лачиновский сельсовет, д.Успено-Раевка, (здание ФАПа), 58		0101000020E6100000D00B772E8CF6424064575A46EAE94940
50829	1	8	231	4978	\N	\N	51.814174000000001	Курская область, Касторенский район, Успенский сельсовет, с.Успенка, Комсомольская (здание администрации сельсовета), 8		0101000020E6100000C7293A92CB1D434073A087DA36E84940
50818	1	8	231	4392	37667	\N	51.673169999999999	Курская область, Касторенский район, Краснознаменский сельсовет, д.Суковкино, пер.Училищный (здание ПУ-33), 2		0101000020E61000005FB35C363A114340FC523F6F2AD64940
50805	1	8	231	3721	37686	\N	51.934544000000002	Курская область, Касторенский район, Андреевский сельсовет, п.Семеновский, Заречная (здание администрации), 22		0101000020E61000002140868E1D264340265646239FF74940
50825	1	8	231	4799	\N	\N	51.866888817352702	Курская область, Касторенский район, Семеновский сельсовет, с.Семеновка, Весна Свободы (здание администарции сельсовета), 3	Россия, Курская область, Касторенский район, поселок Семеновка	0101000020E6100000FF774485EA2443408E210038F6EE4940
50756	1	8	231	899	37815	\N	51.751347000000003	Курская область, Касторенский район, Алексеевский сельсовет, с.Раздолье, Центральная (здание школы), 78		0101000020E61000003FFF3D78EDFE42404F7974232CE04940
50811	1	8	231	4023	\N	\N	51.738644000000001	Курская область, Касторенский район, Котовский сельсовет, с.Погожево, (здание Погожевского дома культуры)	Россия, Курская область, Касторенский район, поселок Погожево	0101000020E6100000FB58C16F432243407DB1F7E28BDE4940
50823	1	8	231	4667	37625	\N	51.757435000000001	Курская область, Касторенский район, Ореховский сельсовет, с.Орехово, Центральная (здание школы), 47		0101000020E6100000E7E3DA503130434042EC4CA1F3E04940
50801	1	8	231	3515	37305	\N	51.775844999999997	Курская область, Касторенский район, поселок Олымский, Садовая (здание Олымской школы), 37		0101000020E61000002272FA7ABE124340EFE192E34EE34940
50802	1	8	231	3515	37327	\N	51.775844999999997	Курская область, Касторенский район, поселок Олымский, 20 лет Победы (здание дома культуры), 4		0101000020E61000002272FA7ABE124340EFE192E34EE34940
50817	1	8	231	4331	\N	\N	51.680889000000001	Курская область, Касторенский район, Краснознаменский сельсовет, с.Олым, Знаменская (здание администрации сельсовета), 16		0101000020E6100000847EA65EB7184340639AE95E27D74940
50799	1	8	231	3410	37605	\N	51.77657	Курская область, Касторенский район, поселок Новокасторное, пер.Сварочный (здание РСП-27), 7		0101000020E6100000105839B4C80E4340018750A566E34940
50800	1	8	231	3410	37331	\N	51.77657	Курская область, Касторенский район, поселок Новокасторное, Железнодорожная (здание культурного центра досуга "Эдельвейс, 42	Россия, Курская область, Касторенский район, поселок Новокасторное	0101000020E6100000105839B4C80E4340018750A566E34940
50816	1	8	231	4272	37749	\N	51.755305999999997	Курская область, Касторенский район, Краснодолинский сельсовет, п.Новодворский, Школьная (здание Олымского дома культуры), 31		0101000020E610000020EF552B130C43407D3CF4DDADE04940
50822	1	8	231	4632	\N	\N	51.818550000000002	Курская область, Касторенский район, Ленинский сельсовет, д..Никольско-Ключевская, (здание домовладения Муковниной Н.Н.), 8		0101000020E610000080B6D5AC330A43400612143FC6E84940
50828	1	8	231	4946	37800	\N	51.847835000000003	Курская область, Касторенский район, Семеновский сельсовет, с.Мелавка, Молодежная (здание аминистрации), 1		0101000020E6100000331AF9BCE2294340BCB376DB85EC4940
51204	1	8	231	6107	67735	\N	51.866892	Курская область, Рыльский район, Ивановский сельсовет, пос.Марьино (здание Марьинского, Дома культуры) ул.Кооперативная, д.2	Россия, Курская область, Касторенский район, поселок Марьино	0101000020E61000004BADF71BEDF44240FF942A51F6EE4940
50821	1	8	231	4562	\N	\N	51.839778000000003	Курская область, Касторенский район, Ленинский сельсовет, п.Ленинский, Нижняя (здание администарции сельсовета), 44	Россия, Курская область, Касторенский район, поселок Ленинский	0101000020E6100000A986FD9E580F43403DF372D87DEB4940
50819	1	8	231	4439	\N	\N	51.803165	Курская область, Касторенский район, Лачиновский сельсовет, п.Лачиново, Школьная (здание администрации сельсовета), 17		0101000020E61000006667D13B15F642405B25581CCEE64940
50813	1	8	231	4135	\N	\N	51.720492	Курская область, Касторенский район, Краснодолинский сельсовет, с.Красная Долина, Советская (здание администрации сельсовета), 23		0101000020E61000006A2FA2ED980A4340CB83F41439DC4940
50810	1	8	231	3940	\N	\N	51.759169	Курская область, Касторенский район, Котовский сельсовет, с.Котовка, пер.Садовый (здание администрации сельсовета), 15		0101000020E6100000942EFD4B521743408A9125732CE14940
50796	1	8	231	3231	37642	\N	51.827757417182198	Курская область, Касторенский район, поселок Касторное, Ленина (здание Касторенского дома детского творчества), 138	Россия, Курская область, Касторенский район, поселок Касторное	0101000020E6100000ACC77DAB751043407D04FEF0F3E94940
50798	1	8	231	3231	37643	\N	51.827706999999997	Курская область, Касторенский район, поселок Касторное, Буденного (здание школы № 2), 36		0101000020E610000072E0D57267104340CBD58F4DF2E94940
50797	1	8	231	3231	37374	\N	51.827706999999997	Курская область, Касторенский район, поселок Касторное, 50 лет Октября (здание Касторенского дома культуры), 4		0101000020E610000072E0D57267104340CBD58F4DF2E94940
50809	1	8	231	3915	\N	\N	51.688025000000003	Курская область, Касторенский район, Жерновецкий сельсовет, с.Жерновец, Центральная (здание администрации сельсовета), 8		0101000020E6100000923CD7F7E1EE42404BEA043411D84940
50807	1	8	231	3820	37732	\N	51.828859000000001	Курская область, Касторенский район, Егорьевский сельсовет, д.Егорьевка, Заречная (здание дома культуры), 6		0101000020E61000007DE71725E801434065FF3C0D18EA4940
50824	1	8	231	54564	37898	\N	51.8531255584018	Курская область, Касторенский район, Ореховский сельсовет, с.Горяйново, Центральная (здание администрации), 30	Россия, Курская область, Касторенский район, поселок Горяиново	0101000020E6100000ABB35A608F33434004AF963B33ED4940
50808	1	8	231	3843	37747	\N	51.861491999999998	Курская область, Касторенский район, Егорьевский сельсовет, с.Вознесеновка, Центральная (здание школы), 20		0101000020E6100000F2EF332E1CFE424000E2AE5E45EE4940
50826	1	8	231	4832	37746	\N	51.908881999999998	Курская область, Касторенский район, Семеновский сельсовет, с.Верхотопье, Центральная (здание администрации), 2		0101000020E6100000B058C345EE33434027F6D03E56F44940
50806	1	8	231	3755	\N	\N	51.682737000000003	Курская область, Касторенский район, Верхнеграйворонский сельсовет, с.Верхняя Грайворонка, Центральная (здание школы), 9А	Россия, Курская область, Касторенский район, поселок Верхняя Грайворонка	0101000020E610000071033E3F8CE4424074620FED63D74940
50814	1	8	231	4170	37759	\N	51.665432978417797	Курская область, Касторенский район, Краснодолинский сельсовет, с.Бычок, Школьная (здание школы), 4	Россия, Курская область, Касторенский район, поселок Бычок	0101000020E61000002D5DC136E2FD4240EF5696E82CD54940
50812	1	8	231	4055	\N	\N	51.733814000000002	Курская область, Касторенский район, Котовский сельсовет, п.Белогорье, (здание школы)	Россия, Курская область, Касторенский район, поселок Белогорье	0101000020E61000005F5CAAD2161D434069ACFD9DEDDD4940
50792	1	8	231	2978	\N	\N	51.856363000000002	Курская область, Касторенский район, Андреевский сельсовет, д.Андреевка, (здание сельсовета), 73		0101000020E61000009C508880431643409240834D9DED4940
50804	1	8	231	2978	37774	\N	51.856363000000002	Курская область, Касторенский район, Андреевский сельсовет, д.Андреевка, Центральная (здание администрации), 25А		0101000020E61000009C508880431643409240834D9DED4940
50803	1	8	231	3619	\N	\N	51.743239000000003	Курская область, Касторенский район, Алексеевский сельсовет, п.Александровский, Парковая (здание администрации сельсовета), 15		0101000020E610000080D4264EEEF142404E0E9F7422DF4940
50782	1	8	302	2419	\N	\N	52.140245999999998	Курская область, Золотухинский район, Донской сельсовет, село Фентисово (здание МКОУ "Фентисовская основная общеобразовательная школа"), д.61		0101000020E61000007EE4D6A4DB32424089B2B794F3114A40
50794	1	8	302	3095	37728	\N	51.930523000000001	Курская область, Золотухинский район, Тазовский сельсовет, село Тазово, ул.Мирная (здание МКОУ "Тазовская начальная общеобразовательная школа"), д.79		0101000020E6100000D6A9F23D232742408196AE601BF74940
50790	1	8	302	2868	\N	\N	52.024365000000003	Курская область, Золотухинский район, Солнечный сельсовет, поселок Солнечный, 3-й Лесной переулок (здание администрации МО "Солнечный сельсовет"), д.3	Россия, Курская область, Золотухинский район, поселок Солнечный	0101000020E6100000D5CF9B8A542C424062156F641E034A40
50791	1	8	302	2868	37614	\N	52.024365000000003	Курская область, Золотухинский район, Солнечный сельсовет, поселок Солнечный, ул.Молодежная (здание МБОУ "Солнечная средняя общобразовательная школа"), д.3		0101000020E6100000D5CF9B8A542C424062156F641E034A40
50776	1	8	302	54525	\N	\N	52.061180562505498	Курская область, Золотухинский район, Дмитриевский сельсовет, село Сергиевское (здание МБОУ "Сергиевская основная общеобразовательная школа")	Россия, Курская область, Золотухинский район, поселок Сергеевское	0101000020E6100000F0517FBDC21642407B116DC7D4074A40
50765	1	8	302	1443	37681	\N	52.067968	Курская область, Золотухинский район, Ануфриевский сельсовет, деревня Сергеевка, ул.Луговая (здание бывшей МОУ "Сергиевская начальная общеобразовательная школа"), д.12		0101000020E6100000B9E177D32D3D42405796E82CB3084A40
50767	1	8	302	1564	37795	\N	52.180807999999999	Курская область, Золотухинский район, Ануфриевский сельсовет, деревня Седмиховка, ул.Шевелева С.Н. (здание МКОУ "Седмиховская средняя общеобразовательная школа"), д.4		0101000020E61000002C2CB81FF04A4240766D6FB724174A40
50787	1	8	302	54509	37626	\N	51.973297000000002	Курская область, Золотухинский район, Свободинский сельсовет, местечко Свобода, ул.Советская (здание ПУ-26), д.42		0101000020E6100000FF05820019284240C02500FF94FC4940
50788	1	8	302	2708	\N	\N	51.973297000000002	Курская область, Золотухинский район, Свободинский сельсовет, местечко Свобода, ул.Гагарина (административное здание Свободинского сельсовета), д.2		0101000020E6100000FF05820019284240C02500FF94FC4940
50781	1	8	302	2379	\N	\N	52.110045	Курская область, Золотухинский район, Донской сельсовет, деревня Революционное (здание МКОУ "Революционная основная общеобразовательная школа"), д.45		0101000020E610000010C99063EB3D42404E0B5EF4150E4A40
38210	1	6	\N	40	35400	\N	54.515492000000002	г. Калуга, Ленинский округ, ул. Ленина, д.74		0101000020E61000007EFE7BF0DA214240C1AC50A4FB414B40
50789	1	8	302	2832	\N	\N	52.024908000000003	Курская область, Золотухинский район, Свободинский сельсовет, деревня Никулино (здание МКУК "Никулинский сельский Дом культуры"), д.182		0101000020E61000001BD47E6B272E424053B4722F30034A40
50795	1	8	302	3184	\N	\N	51.896552	Курская область, Золотухинский район, Тазовский сельсовет, село Никольское (здание Никольской сельской библиотеки), д.77а		0101000020E610000030629F008A214240EA944737C2F24940
50770	1	8	302	1715	\N	\N	51.974894999999997	Курская область, Золотухинский район, Будановский сельсовет, деревня Кузьминка (здание бывшей МОУ Кузьминская начальная общеобразовательная школа"), д.25		0101000020E6100000D2AC6C1FF23042405704FF5BC9FC4940
50777	1	8	302	2146	\N	\N	52.045574000000002	Курская область, Золотухинский район, Дмитриевский сельсовет, деревня 2-е Конево (здание МКОУ Коневская основная общеобразовательная школа")	Россия, Курская область, Золотухинский район, поселок Конево 2-е	0101000020E61000007BF65CA62613424022C66B5ED5054A40
50763	1	8	302	1333	37799	\N	52.152022000000002	Курская область, Золотухинский район, Ануфриевский сельсовет, село 2-я Казанка, ул.Школьная (здание МКОУ Казанская средняя общеобразовательная школа"), д.19		0101000020E6100000F33D23111A534240E222F77475134A40
50784	1	8	302	2258	37477	\N	52.084595999999998	Курская область, Золотухинский район, поселок Золотухино, ул.Ленина (здание МБОУ "Золотухинская средняя общеобразовательная школа"), д.15		0101000020E6100000524832AB77304240ABAFAE0AD40A4A40
50783	1	8	302	2258	37477	\N	52.084595999999998	Курская область, Золотухинский район, поселок Золотухино, ул.Ленина (здание МКУК "Золотухинский РДК"), д.14		0101000020E6100000524832AB77304240ABAFAE0AD40A4A40
50779	1	8	302	2258	37333	\N	52.084595999999998	Курская область, Золотухинский район, поселок Золотухино, ул.Железнодорожная (здание МКОУ "Золотухинская основная общеобразовательная школа"), д.68		0101000020E6100000524832AB77304240ABAFAE0AD40A4A40
50775	1	8	302	2033	37683	\N	51.948251999999997	Курская область, Золотухинский район, Дмитриевский сельсовет, деревня Зиборово, ул.Садовая (здание МКУК "Зиборовский СДК"), д.21		0101000020E610000092770E65A8124240EC2E505260F94940
50793	1	8	302	3059	\N	\N	51.903565	Курская область, Золотухинский район, Тазовский сельсовет, деревня Жерновец (здание МБОУ "Жерновецкая средняя общеобразовательная школа"), д.49		0101000020E6100000E4BED53A71274240B6679604A8F34940
50780	1	8	302	2297	\N	\N	52.041159	Курская область, Золотухинский район, Донской сельсовет, село Донское (здание МКУК "Донской центральный сельский Дом культуры"), д.47		0101000020E610000039B69E211C2D4240D177B7B244054A40
50774	1	8	302	1941	\N	\N	52.016190000000002	Курская область, Золотухинский район, Дмитриевский сельсовет, село Дмитриевка (здание МКОУ "Дмитриевская основная общеобразовательная школа"), д.69		0101000020E61000006F9D7FBBEC194240D942908312024A40
50786	1	8	302	2648	\N	\N	52.080063000000003	Курская область, Золотухинский район, Новоспасский сельсовет, деревня Дерлово (здание бывшей МОУ "Дерловская основная общеобразовательная школа"), д.38	Россия, Курская область, Золотухинский район, поселок Дерлово	0101000020E6100000A0E1CD1ABC254240514F1F813F0A4A40
50773	1	8	302	1908	\N	\N	51.978910999999997	Курская область, Золотухинский район, Будановский сельсовет, деревня Демякино (здание МКОУ "Шестопаловская основная общеобразовательная школа"), д.49	Россия, Курская область, Золотухинский район, поселок Демякино	0101000020E6100000A321E3512A474240EA58A5F44CFD4940
50772	1	8	302	1820	\N	\N	51.880336999999997	Курская область, Золотухинский район, Будановский сельсовет, село Гремячка (здание МКОУ "Гремяченская средняя общеобразовательная школа"), д.11		0101000020E61000004AEEB089CC444240B83A00E2AEF04940
50771	1	8	302	1794	\N	\N	51.980353999999998	Курская область, Золотухинский район, Будановский сельсовет, деревня 1-я Воробьевка (административное здание МО "Будановский сельсовет"), д.68а	Россия, Курская область, Золотухинский район, поселок Воробьевка 1-я	0101000020E610000069E388B5F83E42405B40683D7CFD4940
50766	1	8	302	54542	\N	\N	52.064722048574197	Курская область, Золотухинский район, Ануфриевский сельсовет, деревня 1-е Вереитиново (здание МКОУ "Вереитиновская основная общеобразовательная школа"), д.2	Россия, Курская область, Золотухинский район, поселок Верентиново 1-е	0101000020E61000001538D906EE4E424076AA7CCF48084A40
50769	1	8	302	1672	37619	\N	51.948418719875697	Курская область, Золотухинский район, Будановский сельсовет, деревня Будановка, ул.Советская (здание МБОУ "Будановская средняя общеобразовательная школа"), д.21	Россия, Курская область, Золотухинский район, поселок Будановка	0101000020E61000004FCDE506432F4240D8F335CB65F94940
50778	1	8	302	2190	\N	\N	52.112013876926603	Курская область, Золотухинский район, Донской сельсовет, село Боево (здание бывшей МОУ "Боевская начальная общеобразовательная школа"), д.92	Россия, Курская область, Золотухинский район, поселок Боево	0101000020E6100000F8E3F6CB27334240DA588979560E4A40
50764	1	8	302	1356	\N	\N	52.054363000000002	Курская область, Золотухинский район, Ануфриевский сельсовет, село Белый Колодезь (здание бывшей МОУ "Белоколодезская основная общеобразовательная школа")	Россия, Курская область, Золотухинский район, поселок Белый Колодезь	0101000020E6100000C9E4D4CE30474240658EE55DF5064A40
50768	1	8	302	1590	\N	\N	51.973030999999999	Курская область, Золотухинский район, Апальковский сельсовет, деревня Апальково (здание МКОУ "Апальковская начальная общеобразовательная школа"), д.115		0101000020E6100000ADC266800B224240417FA1478CFC4940
50785	1	8	302	2601	37606	\N	52.110897000000001	Курская область, Золотухинский район, Новоспасский сельсовет, село 1-е Новоспасское, ул.Молодежная (здание МКОУ "Новоспасская средняя общеобразовательная школа"), д.2		0101000020E61000008CF678211D284240BD1C76DF310E4A40
50714	1	8	84	31169	\N	\N	52.146535	Курская область, Железногорский район, Рышковский сельсовет, д. Фоминка, здание Фоминского сельского клуба	Россия, Курская область, Железногорский район, поселок Фоминка	0101000020E610000082E15CC30CC14140145CACA8C1124A40
50762	1	8	84	1265	\N	\N	52.357385000000001	Курская область, Железногорский район, Трояновский сельсовет, с. Трояново, здание МОУ "Трояновская основная общеобразовательная школа"	Россия, Курская область, Железногорский район, поселок Трояново	0101000020E6100000BAD8B452089E41405D8AABCABE2D4A40
50759	1	8	84	1092	\N	\N	52.200164000000001	Курская область, Железногорский район, Троицкий сельсовет, с. Троицкое, здание МОУ "Троицкая средняя общеобразовательная школа"	Россия, Курская область, Железногорский район, поселок Троицкое	0101000020E6100000ED0BE8853BCD414014EB54F99E194A40
50753	1	8	84	54512	\N	\N	52.2966343263586	Курская область, Железногорский район, Разветьевский сельсовет, п. Тепличный, здание МОУ "Разветьевская средняя общеобразовательная школа"	Россия, Курская область, Железногорский район	0101000020E61000004757E9EE3AA94140DA70581AF8254A40
50758	1	8	84	1011	\N	\N	52.353645	Курская область, Железногорский район, Студенокский сельсовет, п. Студенок, здание МКУК "Железногорский районный дом культуры"	Россия, Курская область, Железногорский район, поселок Студенок	0101000020E6100000CEC64ACCB3A641406CB2463D442D4A40
50761	1	8	84	1220	\N	\N	52.200209000000001	Курская область, Железногорский район, Троицкий сельсовет, д. Старый Бузец, здание Старобузского сельского клуба	Россия, Курская область, Железногорский район, поселок Старый Бузец	0101000020E61000009031772D21C54140B4AED172A0194A40
50757	1	8	84	976	\N	\N	52.111604999999997	Курская область, Железногорский район, Снецкой сельсовет, д. Снецкое, здание Администрации Снецкого сельсовета	Россия, Курская область, Железногорский район, поселок Снецкое	0101000020E61000002BA391CF2BA64140F8889812490E4A40
50755	1	8	84	873	\N	\N	52.154707999999999	Курская область, Железногорский район, Рышковский сельсовет, с. Рышково, здание МОУ "Рышковская средняя общеобразовательная школа"	Россия, Курская область, Железногорский район, поселок Рышково	0101000020E61000000BD5CDC5DFBA4140FC36C478CD134A40
50752	1	8	84	650	\N	\N	52.316130999999999	Курская область, Железногорский район, Разветьевский сельсовет, с. Разветье, здание МКУ "Разветьевский центральный дом культуры"	Россия, Курская область, Железногорский район, поселок Разветье	0101000020E6100000FF5C34643CAA41403A2009FB76284A40
50743	1	8	84	54533	\N	\N	52.380857505206698	Курская область, Железногорский район, Волковский сельсовет, д. Пасерково МК-76, здание МКУ "Пасерковский сельский дом культуры"	Россия, Курская область, Железногорский район, поселок Пасерково	0101000020E6100000040473F4F8BD4140C23577F4BF304A40
50739	1	8	84	32350	\N	\N	52.264741999999998	Курская область, Железногорский район, Андросовский сельсовет, д. Остапово, здание Остаповского хлебоприёмного пункта	Россия, Курская область, Железногорский район, поселок Остапово	0101000020E61000009D11A5BDC1B7414056F0DB10E3214A40
50751	1	8	84	54510	\N	\N	52.235548000000001	Курская область, Железногорский район, Новоандросовский сельсовет, п. Новоандросово, здание Администрации Новоандросовского сельсовета		0101000020E6100000A16AF46A80B44140B151D66F261E4A40
50750	1	8	84	535	\N	\N	52.116244999999999	Курская область, Железногорский район, Нижнеждановский сельсовет, д. Нижнее Жданово, здание Администрации Нижнеждановского сельсовета	Россия, Курская область, Железногорский район, поселок Нижнее Жданово	0101000020E61000008C852172FAD2414069A9BC1DE10E4A40
50749	1	8	84	52364	\N	\N	52.232978000000003	Курская область, Железногорский район, Михайловский сельсовет, сл. Михайловка, здание МОУ "Михайловская средняя общеобразовательная школа"	Россия, Курская область, Железногорский район, поселок Михайловка	0101000020E6100000C9C7EE0225AF414000581D39D21D4A40
50737	1	8	84	32254	\N	\N	52.435581999999997	Курская область, Железногорский район, п. Магнитный, здание МКУ "Магнитный центральный дом культуры"	Россия, Курская область, Железногорский район, поселок Магнитный	0101000020E6100000DFA63FFB91C64140F65CA626C1374A40
50748	1	8	84	395	\N	\N	52.090113000000002	Курская область, Железногорский район, Линецкий сельсовет, с. Линец, здание Администрации Линецкого сельсовета	Россия, Курская область, Железногорский район, поселок Линец	0101000020E61000002B1895D409C44140E4F8A1D2880B4A40
50601	1	8	1772	25957	\N	\N	50.973784000000002	Курская область, Беловский район, Ильковский сельсовет, село Мокрушено, Мокрушанская средняя общеобразовательная школа		0101000020E6100000CBBC55D7A1D241401DAF40F4A47C4940
50747	1	8	84	360	\N	\N	52.252290000000002	Курская область, Железногорский район, Копенский сельсовет, д. Копенки, здание МКУ Копенский центральный дом культуры"	Россия, Курская область, Железногорский район, поселок Копенки	0101000020E6100000759483D904CE4140CE8DE9094B204A40
50754	1	8	84	781	\N	\N	52.265338	Курская область, Железногорский район, Разветьевский сельсовет, д. Клишино, здание МОУ Клишинская средняя общеобразовательная школа"	Россия, Курская область, Железногорский район, поселок Клишино	0101000020E6100000F86D88F19A9B41406A317898F6214A40
50745	1	8	84	235	\N	\N	52.146712000000001	Курская область, Железногорский район, Кармановский сельсовет, с. Карманово, здание Администрации Кармановского сельсовета	Россия, Курская область, Железногорский район, поселок Карманово	0101000020E610000067D2A6EA1EAD414023F77475C7124A40
50746	1	8	84	275	\N	\N	52.120094000000002	Курская область, Железногорский район, Кармановский сельсовет, с. Злобино, здание Злобинского сельского клуба	Россия, Курская область, Железногорский район, поселок Злобино	0101000020E61000004DBB9866BAB7414011397D3D5F0F4A40
50563	1	8	84	54357	36729	\N	52.353798364037303	Курская область, город Железногорск, Мира (здание МУП "Гортеплосеть"), 50	Россия, Курская область, Железногорский район	0101000020E61000001EA33CF372AE4140F2B1BB40492D4A40
50744	1	8	84	133	\N	\N	52.347593000000003	Курская область, Железногорский район, Городновский сельсовет, д. Городное, здание МКУ "Городновский сельский дом культуры"	Россия, Курская область, Железногорский район, поселок Городное	0101000020E610000007D15AD1E6D04140C6A86BED7D2C4A40
50742	1	8	84	32468	\N	\N	52.399934999999999	Курская область, Железногорский район, Волковский сельсовет, с. Волково, здание Администрации Волковского сельсовета	Россия, Курская область, Железногорский район, поселок Волково	0101000020E61000007B319413EDBE41404CC3F01131334A40
50741	1	8	84	32446	\N	\N	52.292749999999998	Курская область, Железногорский район, Веретенинский сельсовет, с. Веретенино, здание Администрации Веретенинского сельсовета	Россия, Курская область, Железногорский район, поселок Веретенино	0101000020E61000000F7EE200FAB14140B6F3FDD478254A40
50740	1	8	84	32385	\N	\N	52.142522999999997	Курская область, Железногорский район, Басовский сельсовет, д. Басово-Заречье, здание Администрации Басовского сельсовета	Россия, Курская область, Железногорский район, поселок Басово Заречье	0101000020E6100000D061BEBC00CB4140C2F693313E124A40
50738	1	8	84	32317	\N	\N	52.288111000000001	Курская область, Железногорский район, Андросовский сельсовет, с. Андросово, здание Андросовского фельдшерско-акушерского пункта	Россия, Курская область, Железногорский район, поселок Андросово	0101000020E610000097AE601BF1C04140164F3DD2E0244A40
50725	1	8	1902	31725	\N	\N	52.300829	Курская область, Дмитриевский район, Первоавгустовский сельсовет, село Черневка, (здание Черневского фельдшерско-акушерского пункта)	Россия, Курская область, Дмитриевский район, поселок Черневка	0101000020E6100000A88DEA74208B41401D588E9081264A40
50736	1	8	1902	32210	\N	\N	52.011823	Курская область, Дмитриевский район, Старогородский сельсовет, деревня Харасея, (здание МОУ "Харасейская основная общеобразовательная, школа")	Россия, Курская область, Дмитриевский район, поселок Харасея	0101000020E61000007DE9EDCF45814140992B836A83014A40
50715	1	8	1902	31249	\N	\N	52.140023999999997	Курская область, Дмитриевский район, Крупецкой сельсовет, деревня Фокино, (здание Фокинской сельской библиотеки)	Россия, Курская область, Дмитриевский район, поселок Фокино	0101000020E6100000519FE40E9B864140DA53724EEC114A40
50732	1	8	1902	32048	\N	\N	52.058034999999997	Курская область, Дмитриевский район, Почепский сельсовет, село Фатеевка, (здание Фатеевского сельского Дома культуры)	Россия, Курская область, Дмитриевский район, поселок Фатеевка	0101000020E61000006D59BE2EC3714140FD82DDB06D074A40
50733	1	8	1902	32084	\N	\N	52.100653000000001	Курская область, Дмитриевский район, Старогородский сельсовет, село Старый Город, (здание МКОУ "Старогородская основная общеобразовательная, школа")	Россия, Курская область, Дмитриевский район, поселок Старый Город	0101000020E6100000B2135E8253894140459F8F32E20C4A40
50720	1	8	1902	31485	\N	\N	52.118738999999998	Курская область, Дмитриевский район, Новопершинский сельсовет, село Снижа, (здание МКОУ "Снижанская средняя общеобразовательная школа")	Россия, Курская область, Дмитриевский район, поселок Снижа	0101000020E61000008927BB99D19741403FE1ECD6320F4A40
50731	1	8	1902	31999	\N	\N	52.018042000000001	Курская область, Дмитриевский район, Почепский сельсовет, село Селино, (здание МКОУ "Селинская средняя общеобразовательная школа")	Россия, Курская область, Дмитриевский район, поселок Селино	0101000020E61000001763601DC75F41402BFA43334F024A40
50730	1	8	1902	31952	\N	\N	52.007559999999998	Курская область, Дмитриевский район, Почепский сельсовет, село Почепное, (здание МКУК "Почепской центральный сельский Дом культуры")	Россия, Курская область, Дмитриевский район, поселок Почепное	0101000020E61000001E8A027D226B4140FE60E0B9F7004A40
44138	1	7	\N	31594	32242	\N	58.365634	Костромская область, город Шарья, ул. Ивана Шатрова, д. 10		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
50726	1	8	1902	31787	\N	\N	52.123069000000001	Курская область, Дмитриевский район, Поповкинский сельсовет, село Поповкино, (здание МКОУ "Поповкинская основная общеобразовательная, школа")	Россия, Курская область, Дмитриевский район, поселок Поповкино	0101000020E61000003A57941282674140621399B9C00F4A40
50729	1	8	1902	31933	\N	\N	52.178697999999997	Курская область, Дмитриевский район, Поповкинский сельсовет, село Погодино, (здание МКОУ "Погодинская основная общеобразовательная, школа")	Россия, Курская область, Дмитриевский район, поселок Погодино	0101000020E6100000D4D51D8B6D6E414028EE7893DF164A40
50719	1	8	1902	31473	\N	\N	52.055078000000002	Курская область, Дмитриевский район, Новопершинский сельсовет, село Петраковка, (здание Петраковского сельского Дома культуры)	Россия, Курская область, Дмитриевский район, поселок Петраковка	0101000020E6100000A54FABE80FAD4140535DC0CB0C074A40
50722	1	8	1902	31560	37630	\N	52.226646000000002	Курская область, Дмитриевский район, Первоавгустовский сельсовет, поселок Первоавгустовский, ул. Рабочая (здание МКУК "Первоавгустовский центральный, сельский Дом культуры"), д. 11		0101000020E6100000E9D66B7A5088414076E272BC021D4A40
50721	1	8	1902	31560	37635	\N	52.226646000000002	Курская область, Дмитриевский район, Первоавгустовский сельсовет, поселок Первоавгустовский, ул. Комсомольская (здание администрации Первоавгустовского, сельсовета), д. 38		0101000020E6100000E9D66B7A5088414076E272BC021D4A40
50712	1	8	1902	31093	\N	\N	52.204479174869597	Курская область, Дмитриевский район, Дерюгинский сельсовет, село Пальцево, (здание отделения почтовой связи с. Пальцево)	Россия, Курская область, Дмитриевский район, поселок Пальцево	0101000020E6100000F3CCCB61F799414001DC2C5E2C1A4A40
50724	1	8	1902	31705	\N	\N	52.322598999999997	Курская область, Дмитриевский район, Первоавгустовский сельсовет, село Неварь, (здание МКОУ "Неварская основная общеобразовательная школа")	Россия, Курская область, Дмитриевский район, поселок Неварь	0101000020E610000027F8A6E9B37B4140745C8DEC4A294A40
50711	1	8	1902	31073	\N	\N	52.164769	Курская область, Дмитриевский район, Дерюгинский сельсовет, деревня Моршнево, (здание Моршневской сельской библиотеки)	Россия, Курская область, Дмитриевский район, поселок Моршнево	0101000020E610000070EB6E9EEA9A414083328D2617154A40
50728	1	8	1902	31877	\N	\N	52.128720000000001	Курская область, Дмитриевский район, Поповкинский сельсовет, село Меловое, (здание МКОУ "Меловская основная общеобразовательная школа")	Россия, Курская область, Дмитриевский район, поселок Меловое	0101000020E61000004F05DCF3FC754140AA2B9FE579104A40
50716	1	8	1902	31265	\N	\N	52.064109000000002	Курская область, Дмитриевский район, Новопершинский сельсовет, село Куток, (здание МКОУ "Новопершинская основная общеобразовательная, школа)	Россия, Курская область, Дмитриевский район, поселок Куток	0101000020E61000004240BE840A9641408C3045B934084A40
50713	1	8	1902	31161	\N	\N	52.139471999999998	Курская область, Дмитриевский район, Крупецкой сельсовет, село Крупец, (здание МКУК Крупецкой сельский Дом культуры")	Россия, Курская область, Дмитриевский район, поселок Крупец	0101000020E61000005BB56B425A894140965AEF37DA114A40
50718	1	8	1902	31372	\N	\N	52.105974000000003	Курская область, Дмитриевский район, Новопершинский сельсовет, поселок Красная Дубрава, (здание МКОУ Краснодубравская основная общеобразовательная, школа)	Россия, Курская область, Дмитриевский район, поселок Красная Дубрава	0101000020E61000009529E620E88C4140F81C588E900D4A40
50727	1	8	1902	31814	\N	\N	52.180067999999999	Курская область, Дмитриевский район, Поповкинский сельсовет, село Коробкино, (здание правления СПК Коробкино")	Россия, Курская область, Дмитриевский район, поселок Коробкино	0101000020E6100000A94A5B5CE35F41402F87DD770C174A40
50709	1	8	1902	30785	37502	\N	52.125101952510903	Курская область, Дмитриевский район, город Дмитриев, ул.Промышленная (здание заводоуправления ООО "СпецМашЗавод"), д. 2	Россия, Курская область, Дмитриевский район, Дмитриев-Льговский	0101000020E61000008DD5E6FF558941400455A35703104A40
50708	1	8	1902	30785	37462	\N	52.124468	Курская область, Дмитриевский район, город Дмитриев, ул.Ленина (здание МБУК "Дмитриевский районный Дом культуры", д. 64		0101000020E6100000C7A013420789414003B34291EE0F4A40
50707	1	8	1902	30785	37501	\N	52.124468	Курская область, Дмитриевский район, город Дмитриев, ул. Володарского (здание МБОУ "Средняя общеобразовательная, школа №2", д. 37		0101000020E6100000C7A013420789414003B34291EE0F4A40
50706	1	8	1902	54483	37381	\N	52.127309356043	Курская область, Дмитриевский район, город Дмитриев, просп. Советских Космонавтов (здание МБОУ "Средняя, общеобразовательная школа №1", д. 2	Россия, Курская область, Дмитриевский район, Дмитриев-Льговский	0101000020E61000009624CFF57D88414044BE4BA94B104A40
50710	1	8	1902	30982	\N	\N	52.214061000000001	Курская область, Дмитриевский район, Дерюгинский сельсовет, село Дерюгино, (здание МКОУ "Дерюгинская основная общеобразовательная, школа")	Россия, Курская область, Дмитриевский район, поселок Дерюгино	0101000020E610000015AA9B8BBF894140AE2CD159661B4A40
44134	1	7	7281	\N	32240	\N	58.370352841552801	Костромская область, город Шарья, ул. Адмирала Виноградова, д. 21Б	Россия, Костромская область, Шарья городской округ	0101000020E610000048DE3994A1C04640DD7C23BA672F4D40
50717	1	8	1902	31360	\N	\N	52.078591000000003	Курская область, Дмитриевский район, Новопершинский сельсовет, село Генеральшино, (здание МКОУ "Генеральшинская средняя общеобразовательная, школа)	Россия, Курская область, Дмитриевский район, поселок Генеральшино	0101000020E6100000C9CA2F8331A44140466117450F0A4A40
50723	1	8	1902	31627	\N	\N	52.231631999999998	Курская область, Дмитриевский район, Первоавгустовский сельсовет, село Бычки, (здание Бычковского сельского клуба)	Россия, Курская область, Дмитриевский район, поселок Бычки	0101000020E610000056F31C91EF804140815A0C1EA61D4A40
50734	1	8	1902	32145	\N	\N	51.957382000000003	Курская область, Дмитриевский район, Старогородский сельсовет, село Береза, (здание Березовского сельского Дома культуры)	Россия, Курская область, Дмитриевский район, поселок Береза	0101000020E610000094895B05317C4140B9E34D7E8BFA4940
50704	1	8	688	30697	\N	\N	51.537517000000001	Курская область, Горшеченский район, Ясеновский сельсовет, село Ясенки, В. Третьякевича (здание  Ясеновского сельсовета), 128		0101000020E610000067614F3BFC1B4340A305685BCDC44940
50702	1	8	688	54529	37723	\N	51.593772653816899	Курская область, Горшеченский район, Удобенский сельсовет, село Удобное, Новая (здание Удобенской СОШ), 6	Россия, Курская область, Горшеченский район, поселок Улобное	0101000020E61000004D10751F800C4340B81FF0C000CC4940
50689	1	8	688	29975	37705	\N	51.375411	Курская область, Горшеченский район, Новомелавский сельсовет, село Старомеловое, Колхозная (здание Старомелавского ФАП), 151		0101000020E6100000221B48179B1E434082C7B7770DB04940
50698	1	8	688	30388	37731	\N	51.511651000000001	Курская область, Горшеченский район, Среднеапоченский сельсовет, село Средние Апочки, Советская (здание Среднеапоченской СОШ), 6а		0101000020E610000061376C5B94D942409CFBABC77DC14940
50696	1	8	688	4798	37665	\N	51.49606	Курская область, Горшеченский район, Среднеапоченский сельсовет, село Среднедорожное, Центральная, здание бывшего сельсовета		0101000020E6100000BB7EC16ED8CA4240486DE2E47EBF4940
50690	1	8	688	29984	37621	\N	51.451219000000002	Курская область, Горшеченский район, Сосновский сельсовет, село Сосновка, переулок Школьный (здание Сосновской СОШ), 14		0101000020E61000007B4B395FEC154340BB2A508BC1B94940
50692	1	8	688	30083	37780	\N	51.478600999999998	Курская область, Горшеченский район, Солдатский сельсовет, село Солдатское, переулок Парковый, здание Солдатского ЦСДК		0101000020E610000012A27C410BF342409C6A2DCC42BD4940
50682	1	8	688	29609	37777	\N	51.432136999999997	Курская область, Горшеченский район, Куньевский сельсовет, деревня Ржавец, Первомайская (здание Ржавецкого Дома досуга), 2		0101000020E6100000540262122ECE42401E32E54350B74940
50691	1	8	688	30065	37684	\N	51.431688000000001	Курская область, Горшеченский район, Сосновский сельсовет, деревня Петровка, переулок Школьный (здание Березовской ООШ), 1		0101000020E6100000F183F3A9631D4340AF09698D41B74940
50676	1	8	688	29345	37776	\N	51.621186000000002	Курская область, Горшеченский район, Быковский сельсовет, село Отрада, Комсомольская, здание Отрадовской начальной школы		0101000020E610000040BFEFDFBCEE4240D55DD90583CF4940
50688	1	8	688	29903	37634	\N	51.369289445494097	Курская область, Горшеченский район, Новомелавский сельсовет, село Новомеловое, Центральная (здание Новомелавской СОШ), 61	Россия, Курская область, Горшеченский район, поселок Новомеловое	0101000020E6100000774B72C0AE1C4340E3E2A8DC44AF4940
50687	1	8	688	29865	37773	\N	51.439245	Курская область, Горшеченский район, Никольский сельсовет, село Никольское, Школьная (здание Администрации, Никольского сельсовета		0101000020E6100000A1681EC022D342403CF71E2E39B84940
50683	1	8	688	29682	\N	\N	51.409452000000002	Курская область, Горшеченский район, Нижнеборковский сельсовет, село Нижние Борки, Центральная (здание Нижнеборковского ЦСДК), 1	Россия, Курская область, Горшеченский район, поселок Нижние Борки	0101000020E610000039EFFFE3840D434012A452EC68B44940
50684	1	8	688	29726	37702	\N	51.361837000000001	Курская область, Горшеченский район, Нижнеборковский сельсовет, село Мокрец, Школьная (здание Мокрецкого  ФАП), 15		0101000020E610000005C24EB16A104340CBBDC0AC50AE4940
50694	1	8	688	30210	37778	\N	51.490222000000003	Курская область, Горшеченский район, Солдатский сельсовет, деревня Максимовка, Молодежная, здание Немчиновского СДК		0101000020E61000008F519E7939F04240CEE33098BFBE4940
50679	1	8	688	29507	37810	\N	51.416215000000001	Курская область, Горшеченский район, Куньевский сельсовет, село Кунье, Советская (здание Куньевской сельской библиотеки), 51		0101000020E61000005FB35C363AD54240658D7A8846B54940
50705	1	8	688	30773	37821	\N	51.566135000000003	Курская область, Горшеченский район, Ясеновский сельсовет, село Кулевка, Школьная (здание Кулевской ООШ), 34		0101000020E61000000A849D62D51843407C0F971C77C84940
50678	1	8	688	29435	37819	\N	51.538643	Курская область, Горшеченский район, Ключевский сельсовет, село Ключ, Центральная (здание Ключевской ООШ), 17б		0101000020E610000013622EA9DAF84240139CFA40F2C44940
50703	1	8	688	30642	37730	\N	51.617747000000001	Курская область, Горшеченский район, Удобенский сельсовет, деревня Ивановка, Юбилейная ( здание Ивановского  ФАП), 103		0101000020E6100000BB7CEBC37A0F4340DF196D5512CF4940
50677	1	8	688	29410	37664	\N	51.473450999999997	Курская область, Горшеченский район, Знаменский сельсовет, село Знаменка, Полевая (здание Знаменского СДК), 19		0101000020E6100000D1E80E6267E0424016A1D80A9ABC4940
50701	1	8	688	30552	37685	\N	51.4347671650618	Курская область, Горшеченский район, Старороговский сельсовет, деревня Залесье, Центральная, здание Старороговской СОШ	Россия, Курская область, Горшеченский район, поселок Залесье	0101000020E610000080B56AD784FC4240A530EF71A6B74940
50672	1	8	688	28986	37482	\N	51.525522000000002	Курская область, Горшеченский район, Поселок Горшечное, переулок Больничный (здание поликлиники), 3		0101000020E610000031B610E4A00443400DAA0D4E44C34940
50670	1	8	688	28986	37448	\N	51.525522000000002	Курская область, Горшеченский район, Поселок Горшечное, Центральная (здание средней общеобразовательной школы №2), 24		0101000020E610000031B610E4A00443400DAA0D4E44C34940
50671	1	8	688	28986	37449	\N	51.525522000000002	Курская область, Горшеченский район, Поселок Горшечное, Октябрьская (здание ОАО "ДЭП-99), 9		0101000020E610000031B610E4A00443400DAA0D4E44C34940
50668	1	8	688	28986	37498	\N	51.525522000000002	Курская область, Горшеченский район, Поселок Горшечное, Кирова (здание районного Дома творчества), 7		0101000020E610000031B610E4A00443400DAA0D4E44C34940
50697	1	8	688	30326	37757	\N	51.540638000000001	Курская область, Горшеченский район, Среднеапоченский сельсовет, село Головище, Почтовая (здание Головищенской СОШ), 1а		0101000020E61000008D0B0742B2C84240C87C40A033C54940
50686	1	8	688	29820	37756	\N	51.377406999999998	Курская область, Горшеченский район, Нижнеборковский сельсовет, село Вислое, Светлая ( здание Висловского ФАП), 2		0101000020E6100000F697DD9387074340072461DF4EB04940
50675	1	8	688	29304	37818	\N	51.594433000000002	Курская область, Горшеченский район, Быковский сельсовет, село Быково, Школьная (здание Быковской СОШ), 33		0101000020E6100000978C63247BF04240E3546B6116CC4940
50695	1	8	688	30224	37797	\N	51.531058000000002	Курская область, Горшеченский район, Солдатский сельсовет, деревня Боровка, Советская, здание Боровского Дома досуга		0101000020E61000007DAEB6627FE54240BC2363B5F9C34940
50685	1	8	688	29762	37704	\N	51.402721	Курская область, Горшеченский район, Нижнеборковский сельсовет, село Болото, Раздольная (здание Болотской СОШ), 1		0101000020E610000082A966D652104340CA349A5C8CB34940
50673	1	8	688	29234	37822	\N	51.477687000000003	Курская область, Горшеченский район, село Богородицкое, Маяковского (здание Богородицкой СОШ), 1		0101000020E6100000904946CEC20E4340B85CFDD824BD4940
50674	1	8	688	29283	\N	\N	51.577818000000001	Курская область, Горшеченский район, Богатыревский сельсовет, село Богатырево, Степная (здание Богатыревской СОШ), 18	Россия, Курская область, Горшеченский район, поселок Богатырево	0101000020E6100000116DC7D45DE542402385B2F0F5C94940
50699	1	8	688	30456	37820	\N	51.537405	Курская область, Горшеченский район, Среднеапоченский сельсовет, деревня Белгородка, Полевая, здание Нижнеклещенской НОШ		0101000020E6100000FA9CBB5D2FDF42407BDAE1AFC9C44940
50693	1	8	688	30156	37666	\N	51.453508999999997	Курская область, Горшеченский район, Солдатский сельсовет, поселок Бекетовский, Заводская, здание ОАО "Спиртзавод Бекетовский"		0101000020E610000022FB20CB82ED424088B839950CBA4940
50680	1	8	688	29545	37760	\N	51.397091000000003	Курская область, Горшеченский район, Куньевский сельсовет, село Бараново, Лихачева (здание Барановской СОШ), 32		0101000020E6100000F165A208A9DD42409A44BDE0D3B24940
50667	1	8	682	28984	\N	\N	51.343122999999999	Курская область, Глушковский район, Сухиновский сельсовет, д.Ходяковка, бывший Ходяковский филиал МОУ "Сухиновская СОШ"		0101000020E610000086014BAE623F4140B1C05774EBAB4940
50647	1	8	682	26971	37451	\N	51.268386	Курская область, Глушковский район, Поселок Теткино, ул.Урицкого, д.114		0101000020E61000004223D8B8FE234140255AF2785AA24940
50623	1	8	682	26971	37495	\N	51.268386	Курская область, Глушковский район, Поселок Теткино, ул.Ленина, д.112		0101000020E61000004223D8B8FE234140255AF2785AA24940
50646	1	8	682	26971	37497	\N	51.268386	Курская область, Глушковский район, Поселок Теткино, ул.Коммунальная, д.3		0101000020E61000004223D8B8FE234140255AF2785AA24940
50666	1	8	682	28930	37623	\N	51.317793000000002	Курская область, Глушковский район, Сухиновский сельсовет, с.Сухиновка, адрес помещения для голосования: ул.Советская, д.2, адрес УИК: ул.Советская, д.69		0101000020E6100000DB5207793D444140E9F2E670ADA84940
50663	1	8	682	4739	37699	\N	51.403922999999999	Курская область, Глушковский район, Нижнемордокский сельсовет, с.Ржава, ул.Первомайская, д.17г		0101000020E6100000A48D23D6E2534140158DB5BFB3B34940
50665	1	8	682	28869	37631	\N	51.290432000000003	Курская область, Глушковский район, Попово-Лежачанский сельсовет, с.Попово-Лежачи, адрес помещения для голосования: ул.Осипенко, д.137, адрес УИК: ул.Первомайская, д.2а		0101000020E61000002B6A300DC32741401FDB32E02CA54940
50657	1	8	682	54554	\N	\N	51.235983406717203	Курская область, Глушковский район, Кульбакинский сельсовет, п.Политотдельский, Политотдельский филиал №2 МКОУ Кульбакинская СОШ", д.1	Россия, Курская область, Глушковский район, поселок Политотдельческий	0101000020E61000006AD95A5F24584140BBB4E1B0349E4940
50662	1	8	682	28688	\N	\N	51.378188000000002	Курская область, Глушковский район, Нижнемордокский сельсовет, с.Нижний Мордок, Кекинская сельская библиотека, д.42а		0101000020E6100000E4F38AA71E5B4140ADDEE17668B04940
50661	1	8	682	28688	37729	\N	51.378188000000002	Курская область, Глушковский район, Нижнемордокский сельсовет, с.Нижний Мордок, адрес помещения для голосования: пер.Школьный, д.2, адрес УИК: ул.Советская, д.1		0101000020E6100000E4F38AA71E5B4140ADDEE17668B04940
38206	1	6	\N	40	35400	\N	54.508723000000003	г. Калуга, Ленинский округ, ул. Ленина, д.103		0101000020E6100000E4857478082142408CDCD3D51D414B40
50656	1	8	682	28438	\N	\N	51.242558000000002	Курская область, Глушковский район, Кульбакинский сельсовет, с.Кульбаки, адрес помещения для голосования: МКОУ Кульбакинская СОШ", д.339, адрес УИК: администрация Кульбакинского с/с, д.322		0101000020E6100000DE1D19ABCD6341400CB1FA230C9F4940
50655	1	8	682	28421	37598	\N	51.333253999999997	Курская область, Глушковский район, Коровяковский сельсовет, с.Коровяковка, ул.Ленина, д.58		0101000020E610000098A3C7EF6D3041406EA12B11A8AA4940
50654	1	8	682	28360	37646	\N	51.324069000000001	Курская область, Глушковский район, Кобыльской сельсовет, с.Кобылки, ул.Средняя, д.39		0101000020E6100000B5DE6FB4E3564140DF52CE177BA94940
50653	1	8	682	28297	37594	\N	51.376609000000002	Курская область, Глушковский район, Карыжский сельсовет, с.Карыж, адрес помещения для голосования: ул.Сеймовая, д.39, адрес УИК: ул.Средняя, д.52		0101000020E610000019AA622AFD3841408C3045B934B04940
50651	1	8	682	28221	37483	\N	51.375805	Курская область, Глушковский район, Званновский сельсовет, с.Званное, ул.Центральная, д.71а		0101000020E610000071ADF6B0174641402E56D4601AB04940
50658	1	8	682	28517	\N	\N	51.197364999999998	Курская область, Глушковский район, Кульбакинский сельсовет, д.Елизаветовка, Елизаветовский филиал №1 МКОУ Кульбакинская СОШ", д.80		0101000020E61000001EC2F869DC5D414001309E4143994940
50660	1	8	682	28617	\N	\N	51.4241149075294	Курская область, Глушковский район, Марковский сельсовет, с.Дроновка, Дроновский филиал МКОУ "Марковская СОШ", д.29б	Россия, Курская область, Глушковский район, поселок Дроновка	0101000020E61000006D37C1374D2741401C5F7B6649B64940
50645	1	8	682	27888	37354	\N	51.335858999999999	Курская область, Глушковский район, Поселок Глушково, ул.Советская, д.59		0101000020E6100000DC7EF964C55041409C887E6DFDAA4940
50643	1	8	682	27888	37308	\N	51.335858999999999	Курская область, Глушковский район, Поселок Глушково, ул.М.Горького, д.11		0101000020E6100000DC7EF964C55041409C887E6DFDAA4940
50644	1	8	682	27888	37304	\N	51.335858999999999	Курская область, Глушковский район, Поселок Глушково, ул.Ленина, д.88		0101000020E6100000DC7EF964C55041409C887E6DFDAA4940
50664	1	8	682	28840	\N	\N	51.402006999999998	Курская область, Глушковский район, Нижнемордокский сельсовет, с.Высокое, Высокинский филиал МКОУ "Нижнемордокская СОШ", д.59а		0101000020E61000003E40F7E5CC5E4140ACE122F774B34940
50649	1	8	682	28124	37629	\N	51.288122999999999	Курская область, Глушковский район, Веселовский сельсовет, село Веселое, ул.Советская, д.2		0101000020E6100000E202D0285D464140DA1CE736E1A44940
50648	1	8	682	5737	37671	\N	51.388064999999997	Курская область, Глушковский район, Алексеевский сельсовет, с.Алексеевка, адрес помещения для голосования: ул.Ленина, д.82, адрес УИК: ул.Октябрьская, д.1		0101000020E610000009FCE1E7BF2B414072DC291DACB14940
50624	1	8	713	54555	\N	\N	51.398500230856001	Курская область, Большесолдатский район, Большесолдатский сельсовет, деревня Щербащевка, здание Щербачевского ФАПа	Россия, Курская область, Большесолдатский район, поселок Шербачевка	0101000020E6100000A9C29FE1CDBC41405EBA490C02B34940
50642	1	8	713	27805	\N	\N	51.245479000000003	Курская область, Большесолдатский район, Сторожевский сельсовет, деревня Шелеповка, здание Шелеповской начальной ОШ	Россия, Курская область, Большесолдатский район, поселок Шелеповка	0101000020E61000000C79043752DA41406A6D1ADB6B9F4940
50640	1	8	713	27742	\N	\N	51.283047000000003	Курская область, Большесолдатский район, Сторожевский сельсовет,село Сторожевое, здание МКУК "Сторожевский ЦСДК"	Россия, Курская область, Большесолдатский район, поселок Сторожевое	0101000020E6100000A9BD88B663D241408F1D54E23AA44940
50633	1	8	713	27423	\N	\N	51.356544999999997	Курская область, Большесолдатский район, Любостанский сельсовет, село Скородное, здание МКУК "Скороднянский ЦСДК"	Россия, Курская область, Большесолдатский район, поселок Скородное	0101000020E61000004B57B08D78CE4140B2463D44A3AD4940
50637	1	8	713	27602	\N	\N	51.236417000000003	Курская область, Большесолдатский район, Саморядовский сельсовет, деревня Саморядово, здание МКУК "Саморядовский ЦСДК"	Россия, Курская область, Большесолдатский район, поселок Саморядово	0101000020E6100000C2FBAA5CA8C64140F69B89E9429E4940
50622	1	8	713	4983	37754	\N	51.356050000000003	Курская область, Большесолдатский район, Большесолдатский сельсовет, деревня Первомайская, здание филиала МКУК "Ржавский ЦСДК"		0101000020E6100000BD344580D3BB4140D3DEE00B93AD4940
50634	1	8	713	27432	\N	\N	51.406362000000001	Курская область, Большесолдатский район, Нижнегридинский сельсовет, деревня Нижнее Гридино, здание МКУК "Нижнегридинский ЦСДК"	Россия, Курская область, Большесолдатский район, поселок Нижнее Гридино	0101000020E6100000FDBFEAC891DA4140282B86AB03B44940
50619	1	8	713	26775	\N	\N	51.277306000000003	Курская область, Большесолдатский район, Большесолдатский сельсовет, село Махов Колодезь, здание МКОУ "Маховоколодезьская основная ОШ"	Россия, Курская область, Большесолдатский район, поселок Махов Колодезь	0101000020E610000048FB1F60ADC64140077E54C37EA34940
50641	1	8	713	27796	\N	\N	51.232080000000003	Курская область, Большесолдатский район, Сторожевский сельсовет, деревня Малый Каменец, здание МКУК "Малокаменский Дом досуга"	Россия, Курская область, Большесолдатский район, поселок Малый Каменец	0101000020E61000002A91442FA3D44140210725CCB49D4940
50631	1	8	713	27311	37817	\N	51.323512000000001	Курская область, Большесолдатский район, Любостанский сельсовет, село Любостань, Мира, 9		0101000020E6100000975643E21EDF414089EE59D768A94940
50628	1	8	713	27166	\N	\N	51.503005999999999	Курская область, Большесолдатский район, Любимовский сельсовет, село Любимовка, здание МКУК "Любимовский ЦСДК"	Россия, Курская область, Большесолдатский район, поселок Любимовка	0101000020E6100000739EB12FD9D241408CD8278062C04940
50632	1	8	713	27348	\N	\N	51.278973999999998	Курская область, Большесолдатский район, Любостанский сельсовет, деревня Леоновка, Школьная, 1	Россия, Курская область, Большесолдатский район, поселок Леоновка	0101000020E6100000CA6B257497E441409737876BB5A34940
50636	1	8	713	27565	\N	\N	51.385094674176699	Курская область, Большесолдатский район, Нижнегридинский сельсовет, деревня Извеково, МКОУ "Извековская основная ОШ"	Россия, Курская область, Большесолдатский район, поселок Извеково	0101000020E6100000FF243E7782D54140336DFFCA4AB14940
50630	1	8	713	27243	\N	\N	51.562221999999998	Курская область, Большесолдатский район, Любимовский сельсовет,  поселок Долгий, здание ФАПа п. Долгий	Россия, Курская область, Большесолдатский район, поселок Долгий	0101000020E61000005262D7F676D34140BD8BF7E3F6C74940
51069	1	8	713	16547	37752	\N	51.290325000000003	Курская область, Обоянский район,Бабинский сельсовет,село Вышнее Бабино,здание муниципального общеобразовательного учреждения "В-Бабинская  ООШ", Бугряновка, 21		0101000020E610000098A7734529E34140091B9E5E29A54940
50625	1	8	713	27035	\N	\N	51.434472999999997	Курская область, Большесолдатский район, Волоконский сельсовет, село Волоконск, здание МКУК "Волоконский ЦСДК"	Россия, Курская область, Большесолдатский район, поселок Волоконск	0101000020E6100000ACAB02B518B641405CFFAECF9CB74940
50639	1	8	713	27693	\N	\N	51.215581	Курская область, Большесолдатский район, Саморядовский сельсовет, деревня Будище, здание "МКОУ Будищанская основная ОШ"	Россия, Курская область, Большесолдатский район, поселок Будище	0101000020E6100000CBBE2B82FFC34140CA518028989B4940
50626	1	8	713	27097	\N	\N	51.464748999999998	Курская область, Большесолдатский район, Волоконский сельсовет, село Борщень, здание МКУК "Борщенский ЦСДК"	Россия, Курская область, Большесолдатский район, поселок Борщень	0101000020E610000070B6B9313DC94140A2EC2DE57CBB4940
50627	1	8	713	27097	37814	\N	51.464748999999998	Курская область, Большесолдатский район, Волоконский сельсовет, село Борщень, Школьная, 1		0101000020E610000070B6B9313DC94140A2EC2DE57CBB4940
50617	1	8	713	26678	37281	\N	51.331560000000003	Курская область, Большесолдатский район, Большесолдатский сельсовет, село Большое Солдатское, Советская, 49		0101000020E6100000D2E0B6B6F0C24140B554DE8E70AA4940
50618	1	8	713	26678	37636	\N	51.331560000000003	Курская область, Большесолдатский район, Большесолдатский сельсовет, село Большое Солдатское, Кооперативная, 136		0101000020E6100000D2E0B6B6F0C24140B554DE8E70AA4940
50621	1	8	713	40243	\N	\N	51.371353393005798	Курская область, Большесолдатский район, Большесолдатский сельсовет, деревня Ржава, здание МКОУ "Ржавская основная ОШ"		0101000020E610000054008C67D0B64140C022BF7E88AF4940
50638	1	8	713	27651	\N	\N	51.270674	Курская область, Большесолдатский район, Саморядовский сельсовет, деревня Бирюковка, здание МКОУ "Бирюковская основная ОШ"	Россия, Курская область, Большесолдатский район, поселок Бирюковка	0101000020E6100000CD58349D9DBE414052F01472A5A24940
50629	1	8	713	54524	\N	\N	51.493272031713602	Курская область, Большесолдатский район, Любимовский сельсовет, село Любимовка, деревня 1-я Касторная, здание МКОУ Косторнянская основная ОШ"	Россия, Курская область, Большесолдатский район, поселок 1-я Касторная	0101000020E610000057B3CEF8BED641402904728923BF4940
50616	1	8	1772	26628	\N	\N	51.182806999999997	Курская область, Беловский район, Щеголянский сельсовет, село Щеголек, Щеголянский дом культуры		0101000020E6100000901150E108D041406C3D433866974940
50591	1	8	1772	25502	\N	\N	51.096162	Курская область, Беловский район, Беличанский сельсовет, деревня Суходол, Суходольский дом досуга		0101000020E61000009BFEEC478AD24140198F52094F8C4940
50612	1	8	1772	26452	\N	\N	51.133949999999999	Курская область, Беловский район, Корочанский сельсовет, село Слободка Корочка, Слободко-Корочкинский дом досуга	Россия, Курская область, Беловский район, поселок Слободка-Корочка	0101000020E6100000128942CBBADB41404CA60A4625914940
50603	1	8	1772	26057	\N	\N	51.190925	Курская область, Беловский район, Коммунаровский сельсовет, село Петровы Буды, Петровобудский сельский дом культуры		0101000020E6100000293DD34B8CDB4140917EFB3A70984940
50615	1	8	1772	26573	\N	\N	51.073140000000002	Курская область, Беловский район, Песчанский сельсовет, село Песчаное, Песчанский сельский дом культуры		0101000020E6100000C3633F8BA5D44140C503CAA65C894940
50614	1	8	1772	26557	\N	\N	51.063676999999998	Курская область, Беловский район, Пенский сельсовет, село Пены, Пенский сельский дом культуры		0101000020E6100000A7E8482EFFF54140F240649126884940
50589	1	8	1772	25398	\N	\N	51.003408999999998	Курская область, Беловский район, Беловский сельсовет, хутор Пенский, Октябрьский сельский дом культуры		0101000020E610000076543541D4E941408BC1C3B46F804940
50607	1	8	1772	26203	\N	\N	51.022925000000001	Курская область, Беловский район, Кондратовский сельсовет, село Озерки, Здание Администрации Кондратовского сельсовета	Россия, Курская область, Беловский район, поселок Озерки	0101000020E61000006B4606B98BC2414062A1D634EF824940
50613	1	8	1772	54516	\N	\N	51.036565328682698	Курская область, Беловский район, Малосолдатский сельсовет, село Малосолдатское, Малосолдатский сельский дом культуры	Россия, Курская область, Беловский район, поселок Малое Солдатское	0101000020E610000068AED3484BD74140D1967329AE844940
50588	1	8	1772	25328	\N	\N	51.075890000000001	Курская область Беловский район, Беловский сельсовет, деревня Лошаковка, Лошаковский дом досуга		0101000020E6100000CF2D742502DD4140F60B76C3B6894940
50606	1	8	1772	54538	\N	\N	51.015085262007403	Курская область, Беловский район, Кондратовский сельсовет, хутор Кучеров, Учебный корпус Кучеровского сельскохозяйственного техникума	Россия, Курская область, Беловский район, поселок Кучеров	0101000020E61000004704E3E0D2B3414080D4264EEE814940
50597	1	8	1772	25754	\N	\N	51.085844000000002	Курская область, Беловский район, Гирьянский сельсовет, село Крупец, Крупецкая неполная средняя школа		0101000020E610000036035C902DBF41406747AAEFFC8A4940
50599	1	8	1772	25868	\N	\N	51.209713000000001	Курская область, Беловский район, Долгобудский сельсовет, село Кривицкие Буды, Кривицко-Будская основная общеобразовательная школа		0101000020E6100000BEF90D130DE44140E54526E0D79A4940
50609	1	8	1772	26284	\N	\N	51.090465999999999	Курская область, Беловский район, Корочанский сельсовет, деревня Корочка, Корочанский сельский дом культуры		0101000020E61000005E0F26C5C7DB414031B3CF63948B4940
50604	1	8	1772	26103	\N	\N	50.999668	Курская область, Беловский район, Кондратовский сельсовет, село Кондратовка, Кондратовский дом культуры		0101000020E6100000B07092E68FB94140CA6DFB1EF57F4940
50602	1	8	1772	26016	\N	\N	51.157319999999999	Курская область, Беловский район, Коммунаровский сельсовет, поселок Коммунар, Коммунаровский сельский дом культуры		0101000020E610000090BE49D3A0DA4140DC80CF0F23944940
50596	1	8	1772	25744	\N	\N	51.091204173551802	Курская область, Беловский район, Гирьянский сельсовет, село Камышное, Камышанский сельский дом культуры	Россия, Курская область, Беловский район, поселок Камышное	0101000020E610000090DC9A745BC44140D7A19A92AC8B4940
50600	1	8	1772	25925	\N	\N	50.952261	Курская область, Беловский район, Ильковский сельсовет, село Илек, Ильковская средняя общеобразовательная школа		0101000020E610000052D50451F7CD4140CD203EB0E3794940
50608	1	8	1772	26257	\N	\N	50.966155999999998	Курская область, Беловский район, Кондратовский сельсовет, село Забужевка, Забужанский дом досуга		0101000020E61000008099EFE027BE4140C66AF3FFAA7B4940
50610	1	8	1772	26346	\N	\N	51.098447999999998	Курская область, Беловский район, Корочанский сельсовет, село Долгий Колодезь, Долго-Колодезьская начальная школа		0101000020E6100000F1D93A38D8E14140A52DAEF1998C4940
50598	1	8	1772	25822	\N	\N	51.164341	Курская область, Беловский район, Долгобудский сельсовет, село Долгие Буды, Долгобудский дом культуры		0101000020E6100000B9382A3751DF41402B323A2009954940
50593	1	8	1772	25607	\N	\N	51.121129000000003	Курская область, Беловский район, Бобравский сельсовет, село Гочево, Гочевский дом досуга		0101000020E6100000081F4AB4E4EF414071CCB227818F4940
50605	1	8	1772	54519	\N	\N	50.978670593006598	Курская область, Беловский район, Кондратовский сельсовет, село Гоптпровка, Гоптаровская основная общеобразовательная школа		0101000020E6100000AD855968E7B2414095456117457D4940
50595	1	8	1772	25698	\N	\N	51.086889999999997	Курская область, Беловский район, Гирьянский сельсовет, деревня Гирьи, Гирьянская средняя общеобразовательная школа		0101000020E61000001651137D3ECA4140BA2C26361F8B4940
50594	1	8	1772	25610	\N	\N	51.005245000000002	Курская область, Беловский район, Вишневский сельсовет, село Вишнево, Вишневский дом культуры		0101000020E610000027F911BF62D14140D8BB3FDEAB804940
50592	1	8	1772	25507	\N	\N	51.080157	Курская область, Беловский район, Бобравский сельсовет, село Бобрава, Бобравский сельский дом культуры		0101000020E610000077F52A323AE84140D2C5A695428A4940
50590	1	8	1772	25438	\N	\N	51.121342265309202	Курская область, Беловский район, Беличанский сельсовет, село Белица, Беличанский сельский дом культуры	Россия, Курская область, Беловский район, поселок Белица	0101000020E6100000AD4F39268BC74140CCD07822888F4940
50586	1	8	1772	25234	37318	\N	51.056497999999998	Курская область, Беловский район, Беловский сельсовет, слобода Белая, площадь Советская, Беловский центр культуры и досуга	Россия, Курская область, Беловский район, поселок Белая	0101000020E61000001FBB0B9414DC41400B2593533B874940
44142	1	7	\N	31594	32244	\N	58.365634	Костромская область, город Шарья, ул. имени хирурга Крылова В.М, д. 9		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
44141	1	7	\N	31594	32244	\N	58.365634	Костромская область, город Шарья, ул. имени хирурга Крылова В.М, д. 5		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
44147	1	7	\N	31594	32145	\N	58.365634	Костромская область, город Шарья, ул. Фурманова, д. 64		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
44133	1	7	\N	31594	32308	\N	58.364433582269001	Костромская область, город Шарья, ул. С. Громова, д. 44		0101000020E61000007E8CB96B09BF464076C6F7C5A52E4D40
44137	1	7	\N	31594	32337	\N	58.365634	Костромская область, город Шарья, ул. Полярников, д. 4		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
44135	1	7	\N	31594	32243	\N	58.365634	Костромская область, город Шарья, ул. П. Морозова, д. 15		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
44136	1	7	\N	31594	32398	\N	58.365634	Костромская область, город Шарья, ул. Октябрьская, д. 17		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
44132	1	7	\N	31594	32256	\N	58.365634	Костромская область, город Шарья, ул. Куйбышева, д. 43		0101000020E61000007C0DC17119C1464020274C18CD2E4D40
44020	1	7	\N	53332	32352	\N	58.284759485784498	Костромская область, Нейский район, город Нея, ул. П. Морозова, д. 1	Россия, Костромская область, Нея городской округ	0101000020E61000001AE1ED4108F24540EF1EA0FB72244D40
44037	1	7	\N	26418	32537	\N	57.457189	Костромская область, город Нерехта, пл. 30-лет Победы, 5 (ДК фойе)		0101000020E6100000F584251E50484440A48B4D2B85BA4C40
44030	1	7	\N	26418	32443	\N	57.452229829139903	Костромская область, город Нерехта, ул. Школьная, 1	Россия, Костромская область, Нерехта	0101000020E6100000CCB8A981E6494440922232ACE2B94C40
44032	1	7	\N	26418	32312	\N	57.457189	Костромская область,  город Нерехта, ул. Чкалова, 12		0101000020E6100000F584251E50484440A48B4D2B85BA4C40
44053	1	7	\N	26418	32356	\N	57.461886829340699	Костромская область, город Нерехта, ул. ПМК-1, 10	Россия, Костромская область, Нерехта	0101000020E6100000463F1A4E9947444049B9FB1C1FBB4C40
44035	1	7	\N	26418	32269	\N	57.460502045571197	Костромская область, город Нерехта, ул. Октябрьская, 2а	Россия, Костромская область, Нерехта	0101000020E61000000E828E56B54844400DDFC2BAF1BA4C40
44029	1	7	\N	26418	32530	\N	57.462129666996198	Костромская область, город Нерехта, ул. Ленина, 28а	Россия, Костромская область, Нерехта	0101000020E61000009E5DBEF56149444010406A1327BB4C40
44031	1	7	\N	26418	32371	\N	57.457189	Костромская область, город Нерехта, ул. Красноармейская, 101		0101000020E6100000F584251E50484440A48B4D2B85BA4C40
44033	1	7	\N	26418	32273	\N	57.457189	Костромская область, город Нерехта, ул. К. Маркса, 5		0101000020E6100000F584251E50484440A48B4D2B85BA4C40
44022	1	7	\N	26418	32538	\N	57.457189	Костромская область, город Нерехта, ул. Дружбы, 13а		0101000020E6100000F584251E50484440A48B4D2B85BA4C40
44036	1	7	\N	26418	32315	\N	57.457324649548099	Костромская область, город Нерехта, пл. 30-лет Победы, 5 (ДК конференцзал)	Россия, Костромская область, Нерехта	0101000020E6100000C4978922A4484440545227A089BA4C40
44034	1	7	\N	26418	32374	\N	57.458394413468604	Костромская область, город Нерехта, ул. К. Либкнехта, 2	Россия, Костромская область, Нерехта	0101000020E6100000B876A22424484440605793A7ACBA4C40
43980	1	7	\N	53334	32509	\N	58.327810342026197	Костромская область, Мантуровский район, Мантурово город, Гвардейская, 5		0101000020E610000018CE35CCD0604640A0A696ADF5294D40
94351	1	7	\N	4664	32469	\N	58.327275	Костромская область, Мантуровский район,, г.Мантурово ул.Юбилейная д.16А, Центр детского творчества		0101000020E6100000F8DF4A766C62464032E6AE25E4294D40
43989	1	7	\N	4664	32353	\N	58.327275	Костромская область, Мантуровский район, Мантурово город, Советская, 141		0101000020E6100000F8DF4A766C62464032E6AE25E4294D40
43982	1	7	\N	4664	32353	\N	58.338977521476103	Костромская область, Мантуровский район, .Мантурово город, ул. Советская, д.9	Россия, Костромская область, Мантурово городской округ	0101000020E610000056664AEB6F634640200890A1632B4D40
43981	1	7	\N	4664	32353	\N	58.338717991061898	Костромская область, город Мантурово, ул. Советская, д. 100		0101000020E6100000739CDB847B6346408448861C5B2B4D40
43985	1	7	\N	4664	32378	\N	58.327275	Костромская область,  город Мантурово, ул. Нагорная, д. 18		0101000020E6100000F8DF4A766C62464032E6AE25E4294D40
43984	1	7	\N	4664	32540	\N	58.314223253116701	"Костромская область,  город Мантурово, ул. Ленина, д. 2""Б"""	Россия, Костромская область, Мантурово городской округ	0101000020E61000008E226B0DA56246405453927538284D40
43988	1	7	\N	4664	32276	\N	58.324474737036198	Костромская область, Мантуровский район, .Мантурово город, Вокзальная, 100	Россия, Костромская область, Мантурово	0101000020E610000083A3E4D5396246404FAF946588294D40
43942	1	7	\N	53324	32340	\N	57.880229	Костромская область, Макарьевский район, г. Макарьев, пер. Полевой, д.14 а		0101000020E6100000FA42C879FFE54540D2FE0758ABF04C40
44048	1	7	\N	53341	32446	\N	57.453295495647502	Костромская область, Нерехтский район, д. Лаврово, ул. Школьная, 2		0101000020E61000007F6B274A424A44405C38109205BA4C40
43830	1	7	\N	886	4731	\N	57.777273000000001	Костромская область, город Кострома, Юных Пионеров, 2	Россия, Костромская область, Кострома, улица Юных Пионеров, 4	0101000020E6100000469A7807787644402B8881AE7DE34C40
43868	1	7	\N	886	4987	\N	57.773764	Костромская область, Городской округ город Кострома, Шагова, 201	Россия, Костромская область, Кострома, улица Шагова, 201	0101000020E610000053927538BA7C44403C69E1B20AE34C40
44166	1	7	\N	886	232	\N	57.785319999999999	Костромская область, Островский район, д. Гуляевка адрес помещения для голосования: ул. Совхозная, д. 31, адрес УИК: п. Островское ул. Советская, 97	Россия, Костромская область, Кострома, улица Совхозная, 27	0101000020E6100000D940BAD8B47844408672A25D85E44C40
43843	1	7	\N	886	4737	\N	57.792395999999997	Костромская область, город Кострома, Ленина, 161	Россия, Костромская область, Кострома, улица Ленина, 161	0101000020E61000005F79909E2279444098BD6C3B6DE54C40
43839	1	7	\N	886	4737	\N	57.781216999999998	Костромская область, город Кострома, Ленина, 84	Россия, Костромская область, Кострома, улица Ленина, 84	0101000020E610000050E1085229784440240A2DEBFEE34C40
43767	1	7	\N	886	3953	\N	57.779426999999998	Костромская область, Кадыйский район, п.Новый Березовец, Клубная, 1Б		0101000020E6100000CC086F0F42724440484F9143C4E34C40
43840	1	7	\N	886	4842	\N	57.784101	Костромская область, город Кострома, Задорина, 57	Россия, Костромская область, Кострома, улица Задорина, 57	0101000020E6100000B9FFC874E876444065E1EB6B5DE44C40
43908	1	7	\N	886	5668	\N	57.750472900587297	Костромская область, город Кострома, Голубкова, 15	Россия, Костромская область, Кострома, улица Голубкова, 15	0101000020E61000003C855CA967754440F8C3CF7F0FE04C40
43588	1	7	\N	886	1488	\N	57.782470000000004	Костромская область, город Кострома, Борьбы, 50	Россия, Костромская область, Кострома, улица Борьбы, 50	0101000020E610000097FE25A94C754440F20C1AFA27E44C40
42954	1	7	\N	886	1814	\N	57.776682000000001	Костромская область, город Кострома, Беговая, 4а	Россия, Костромская область, Кострома, улица Беговая, 4а	0101000020E610000005C4245CC879444029B2D6506AE34C40
43832	1	7	\N	886	32632	\N	57.777429322003002	Костромская область, город Кострома, пр. Текстильщиков, 73	Россия, Костромская область, Кострома, проспект Текстильщиков, 73	0101000020E610000055C1A8A44E74444022FB20CB82E34C40
43910	1	7	\N	886	32611	\N	57.758363929400403	Костромская область, город Кострома, Библиотечный проезд, 17	Россия, Костромская область, Кострома, проезд Библиотечный, 17	0101000020E6100000B2D47ABFD17044405C3B511212E14C40
43902	1	7	\N	886	32615	\N	57.7339137297352	Костромская область, город Кострома, Березовый проезд, 2	Россия, Костромская область, Кострома, проезд Березовый, 2	0101000020E61000007383A10E2B764440CC09DAE4F0DD4C40
43847	1	7	\N	886	32490	\N	57.798214177190502	Костромская область, город Кострома, пос. Новый, 9	Россия, Костромская область, Кострома, микрорайон Новый, 9	0101000020E6100000DC114E0B5E804440CC9A58E02BE64C40
43903	1	7	\N	886	32232	\N	57.739089999999997	Костромская область, город Кострома, м/н Паново, 9	Россия, Костромская область, Кострома, микрорайон Паново, 9	0101000020E6100000AEF545425B7444407B6649809ADE4C40
43841	1	7	\N	886	32504	\N	57.790635999999999	Костромская область, город Кострома, м/н Якиманиха, 19	Россия, Костромская область, Кострома, микрорайон Якиманиха, 19	0101000020E61000004AD3A0681E7844402785798F33E54C40
43885	1	7	\N	886	32329	\N	57.736317999999997	Костромская область, город Кострома, м/н Юбилейный, 24А	Россия, Костромская область, Кострома, микрорайон Юбилейный, 24а	0101000020E6100000321F10E84C7E444062BA10AB3FDE4C40
43883	1	7	\N	886	32329	\N	57.736885000000001	Костромская область, город Кострома, м/н Юбилейный, 12	Россия, Костромская область, Кострома, микрорайон Юбилейный, 12	0101000020E6100000FF06EDD5C77D4440DCF4673F52DE4C40
43887	1	7	\N	886	32330	\N	57.745830226703603	Костромская область, город Кострома, м/н Черноречье, 23	Россия, Костромская область, Кострома, микрорайон Черноречье, 23	0101000020E61000007AE3A430EF7B44401630815B77DF4C40
43886	1	7	\N	886	32330	\N	57.748413999999997	Костромская область, город Кострома, м/н Черноречье, 2	Россия, Костромская область, Кострома, микрорайон Черноречье, 2	0101000020E6100000F25B74B2D47C44402CEFAA07CCDF4C40
43905	1	7	\N	886	32671	\N	57.739542060740398	Костромская область, город Кострома, м/н Паново, 12	Россия, Костромская область, Кострома, 1-й Силикатный проезд	0101000020E6100000F777B6476F7444405C02F04FA9DE4C40
43879	1	7	\N	886	32568	\N	57.734265999999998	Костромская область, город Кострома, м/н Давыдовский-2, 19	Россия, Костромская область, Кострома, 2-й Давыдовский микрорайон, 19	0101000020E6100000BC934F8F6D8144404948A46DFCDD4C40
43882	1	7	\N	886	32328	\N	57.76728	Костромская область, город Кострома, м/н Давыдовский-1, 32		0101000020E61000000740DCD5AB764440FC6F253B36E24C40
43884	1	7	\N	886	32598	\N	57.736447237517702	Костромская область, город Кострома, м-н Юбилейный, 10	Россия, Костромская область, Кострома, микрорайон Юбилейный, 10	0101000020E6100000BD35B055827D4440601E32E543DE4C40
43838	1	7	\N	886	32521	\N	57.76728	Костромская область, город Кострома, пос. Волжский, квартал 3, 27		0101000020E61000000740DCD5AB764440FC6F253B36E24C40
43913	1	7	\N	886	32654	\N	57.7529414357573	Костромская область, город Кострома, Беленогова, 23А	Россия, Костромская область, Кострома, улица Юрия Беленогова, 23а	0101000020E6100000A9DA6E826F744440A568E55E60E04C40
43889	1	7	\N	886	32640	\N	57.756660498940903	Костромская область, город Кострома, Юношеская, 35	Россия, Костромская область, Кострома, Юношеская улица, 35	0101000020E61000009ACC785BE97944407E18213CDAE04C40
43861	1	7	\N	886	32630	\N	57.773936499669603	Костромская область, город Кострома, Шагова, 201	Россия, Костромская область, Кострома, улица Шагова, 201	0101000020E61000002DB29DEFA77C44403999B85510E34C40
43855	1	7	\N	886	32630	\N	57.770411718281103	Костромская область, город Кострома, Шагова, 61А	Россия, Костромская область, Кострома, улица Шагова, 61а	0101000020E6100000A7203F1BB9784440153944DC9CE24C40
43853	1	7	\N	886	32630	\N	57.768619189007403	Костромская область, город Кострома, Шагова, 9		0101000020E61000008DCF64FF3C774440C80A7E1B62E24C40
43852	1	7	\N	886	32630	\N	57.770411718281103	Костромская область, город Кострома, ул. Шагова, 61А		0101000020E61000006E8AC745B5784440153944DC9CE24C40
43873	1	7	\N	886	32651	\N	57.739553984427197	Костромская область, город Кострома, Центральная, 50		0101000020E6100000D3DB9F8B867E444020D099B4A9DE4C40
43650	1	7	\N	886	32651	\N	57.746850899043899	Костромская область, Буйский муниципальный район, д. Большой Дор, ул. Центральная, д. 2	Россия, Костромская область, Кострома, улица Центральная, 2	0101000020E6100000D13B1570CF7F444011FE45D098DF4C40
43906	1	7	\N	886	32648	\N	57.756041562925297	Костромская область, город Кострома, Фрунзе, 5	Россия, Костромская область, Кострома, улица Фрунзе, 5	0101000020E6100000EFC9C342AD7344408333F8FBC5E04C40
43867	1	7	\N	886	32644	\N	57.754151354110803	Костромская область, город Кострома, Фестивальная, 31	Россия, Костромская область, Кострома, улица Фестивальная, 31	0101000020E610000092E86514CB814440739F1C0588E04C40
43900	1	7	\N	886	32656	\N	57.735852162529099	Костромская область, город Кострома, Суслова, 6	Россия, Костромская область, Кострома, улица Суслова, 6	0101000020E61000008B16A06D357544401D59F96530DE4C40
43912	1	7	\N	886	32629	\N	57.755161305930898	Костромская область, город Кострома, Строительная, 8а	Россия, Костромская область, Кострома, улица Строительная, 8	0101000020E6100000790261A7587344407A1B9B1DA9E04C40
44200	1	7	405	2849	32196	\N	58.144739000000001	Костромская область, Сусанинский район, д. Сокирино, Южная, 13		0101000020E6100000AF5C6F9BA9D0444056BABBCE86124D40
43829	1	7	\N	886	32655	\N	57.774887859172601	Костромская область, город Кострома, Спасокукоцкого, 40	Россия, Костромская область, Кострома, Спасокукоцкого улица	0101000020E6100000A2CF4719717544400B08AD872FE34C40
43844	1	7	\N	886	32634	\N	57.784845888316902	Костромская область, город Кострома, Совхозная, 21	Россия, Костромская область, Кострома, улица Совхозная, 21	0101000020E610000056D636C5E3784440BE326FD575E44C40
43898	1	7	\N	886	32451	\N	57.763096641525102	Костромская область, город Кострома, Советская, 55а	Россия, Костромская область, Кострома, Советская улица	0101000020E6100000F1D6F9B7CB7844407E569929ADE14C40
43896	1	7	\N	886	32635	\N	57.760986000000003	Костромская область, город Кострома, Советская, 52		0101000020E6100000B9E177D32D794440605B3FFD67E14C40
43893	1	7	\N	886	32635	\N	57.759716580363097	Костромская область, город Кострома, Советская, 111В	Россия, Костромская область, Кострома, Советская улица, 111в	0101000020E61000006551D845D17B44408D9B1A683EE14C40
43892	1	7	\N	886	32635	\N	57.758767149432003	Костромская область, город Кострома, Советская, 115	Россия, Костромская область, Кострома, Советская улица, 115	0101000020E6100000A3EA573A1F7C44405B24ED461FE14C40
43890	1	7	\N	886	32635	\N	57.756555835251397	Костромская область, город Кострома, Советская, 118Б	Россия, Костромская область, Кострома, Советская улица, 118	0101000020E6100000FB78E8BB5B7B4440DACBB6D3D6E04C40
43897	1	7	\N	886	32652	\N	57.764506810453298	Костромская область, город Кострома, Смоленская, 28А	Россия, Костромская область, Кострома, Смоленская улица, 28а	0101000020E6100000B665C0594A7844401348895DDBE14C40
43860	1	7	\N	886	32609	\N	57.766770999999999	Костромская область, город Кострома, Свердлова, 120		0101000020E610000098BED7101C7B4440B742588D25E24C40
43911	1	7	\N	886	32672	\N	57.756567753306797	Костромская область, город Кострома, Садовая, 7	Россия, Костромская область, Кострома, улица Садовая, 7	0101000020E61000006AA164726A7344409E996038D7E04C40
43837	1	7	\N	886	4805	\N	57.804656000000001	Костромская область, город Кострома, Речной проспект, 72	Россия, Костромская область, Кострома, Речной проспект, 72	0101000020E6100000FDBCA94885734440DD43C2F7FEE64C40
43849	1	7	\N	886	32669	\N	57.7824018373922	Костромская область, город Кострома, Пушкина, 2А	Россия, Костромская область, Кострома, улица Пушкина, 2а	0101000020E61000008E91EC116A7A44409929ADBF25E44C40
43877	1	7	\N	886	32643	\N	57.731423355418897	Костромская область, город Кострома, Профсоюзная, 36		0101000020E6100000E19524CFF58144406745D4449FDD4C40
43876	1	7	\N	886	32643	\N	57.729505489394398	Костромская область, город Кострома, Профсоюзная, 20	Россия, Костромская область, Кострома, улица Профсоюзная, 20	0101000020E610000006BB61DBA28044405EA27A6B60DD4C40
43834	1	7	\N	886	32617	\N	57.778727000000003	Костромская область, город Кострома, Просвещения, 22		0101000020E6100000AC0320EEEA71444090C18A53ADE34C40
43833	1	7	\N	886	32617	\N	57.778656865656998	Костромская область, город Кострома, Просвещения, 24	Россия, Костромская область, Кострома, улица Просвещения, 24	0101000020E6100000E8A4F78DAF71444097E65608ABE34C40
43846	1	7	\N	886	32647	\N	57.799683205008698	Костромская область, город Кострома, Партизанская, 37	Россия, Костромская область, Кострома, Партизанская улица, 35	0101000020E61000007D59DAA9B97C4440661536035CE64C40
43871	1	7	\N	886	32624	\N	57.745535681121297	Костромская область, город Кострома, Новоселов, 11	Россия, Костромская область, Кострома, улица Новоселов, 11	0101000020E61000000454388254804440CEFE40B96DDF4C40
43894	1	7	\N	886	32627	\N	57.763164821865601	Костромская область, Городской округ город Кострома, ул. Никитская, 70	Россия, Костромская область, Кострома, Никитская улица, 70	0101000020E6100000A0A86C58537B4440D6390664AFE14C40
43891	1	7	\N	886	32627	\N	57.758647000000003	Костромская область, город Кострома, Никитская, 106Б		0101000020E6100000D9243FE2577C4440B11A4B581BE14C40
43863	1	7	\N	886	32627	\N	57.7618617576315	Костромская область, город Кострома, Никитская, 106б	Россия, Костромская область, Кострома, Никитская улица, 106б	0101000020E610000055FB743C667C44405708ABB184E14C40
43862	1	7	\N	886	32627	\N	57.763141886049297	Костромская область, город Кострома, Никитская, 70	Россия, Костромская область, Кострома, Никитская улица, 70	0101000020E6100000A852B3075A7B44401E1A16A3AEE14C40
43904	1	7	\N	886	32608	\N	57.735696062430598	Костромская область, Городской округ город Кострома, Малышковская, 4	Россия, Костромская область, Кострома, Малышковская улица, 4	0101000020E6100000D0EFFB372F76444025E659492BDE4C40
43899	1	7	\N	886	32608	\N	57.7353995510761	Костромская область, город Кострома, Малышковская, 55	Россия, Костромская область, Кострома, Малышковская улица, 55	0101000020E61000004E266E15C47644403CBD529621DE4C40
43901	1	7	\N	886	32668	\N	57.735719015732698	Костромская область, город Кострома, Малышковская, 4		0101000020E6100000B9FB1C1F2D764440DE054A0A2CDE4C40
42896	1	7	\N	886	32667	\N	57.804360727350698	Костромская область, город Кострома, Линейная, 11	Россия, Костромская область, Кострома, улица Линейная, 11	0101000020E6100000A33A1DC87A744440C4961E4DF5E64C40
43845	1	7	\N	886	32636	\N	57.789312000000002	Костромская область, Городской округ город Кострома, ул. Ленина, 149	Россия, Костромская область, Кострома, улица Ленина, 149	0101000020E61000005B09DD2571784440912BF52C08E54C40
43842	1	7	\N	886	32636	\N	57.789085999999998	Костромская область, город Кострома, Ленина, 149		0101000020E61000006EDC627E6E784440A0DD21C500E54C40
43878	1	7	\N	886	5149	\N	57.730070179583699	Костромская область, город Кострома, Кинешемское шоссе, 86	Россия, Костромская область, Кострома, Кинешемское шоссе, 86	0101000020E61000001E882CD2C483444036E50AEF72DD4C40
44098	1	7	1877	29912	\N	\N	59.115586999999998	Костромская область, Павинский муниципальный район, деревня Березовка, 30		0101000020E6100000DDCD531D722D4740DF6B088ECB8E4D40
43875	1	7	\N	886	5149	\N	57.7465076006945	Костромская область, город Кострома, Кинешемское шоссе, 45/51	Россия, Костромская область, Кострома, Кинешемское шоссе, 45	0101000020E610000060CAC0012D814440E719FB928DDF4C40
43874	1	7	\N	886	5149	\N	57.754004474108598	Костромская область, город Кострома, Кинешемское шоссе, 4		0101000020E610000090847D3B897E4440CF86FC3383E04C40
43872	1	7	\N	886	5149	\N	57.751334	Костромская область, город Кострома, Кинешемское шоссе, 23	Россия, Костромская область, Кострома, Кинешемское шоссе, 23	0101000020E61000008B16A06D357F4440BA2F67B62BE04C40
43869	1	7	\N	886	5149	\N	57.752521302017101	Костромская область, город Кострома, Кинешемское шоссе, 25	Россия, Костромская область, Кострома, Кинешемское шоссе, 25	0101000020E61000002A0307B4747F4440D046AE9B52E04C40
43865	1	7	\N	886	5149	\N	57.754337484894101	Костромская область, город Кострома, Кинешемское шоссе, 15	Россия, Костромская область, Кострома, Кинешемское шоссе, 15	0101000020E610000033A9A10DC07E4440D594641D8EE04C40
43859	1	7	\N	886	32633	\N	57.765557861039703	Костромская область, город Кострома, Ивана Сусанина, 52	Россия, Костромская область, Кострома, улица Ивана Сусанина, 50	0101000020E610000028603B18B17944407898F6CDFDE14C40
43858	1	7	\N	886	32633	\N	57.767721950279203	Костромская область, город Кострома, Ивана Сусанина, 31А	Россия, Костромская область, Кострома, улица Ивана Сусанина, 31а	0101000020E61000000438BD8BF7794440B935E9B644E24C40
43593	1	7	\N	886	32665	\N	57.793276432531897	Костромская область, город Кострома, Запрудня, 10	Россия, Костромская область, Кострома, улица Запрудня, 10	0101000020E6100000F5BBB0355B754440D15966118AE54C40
43895	1	7	\N	886	32663	\N	57.765497210557498	Костромская область, город Кострома, Долматова, 25	Россия, Костромская область, Кострома, улица Долматова, 25	0101000020E6100000A9F92AF9D8774440D31742CEFBE14C40
43888	1	7	\N	886	32621	\N	57.7599094920621	Костромская область, город Кострома, Дзержинского, 17		0101000020E6100000D53C47E4BB784440D177B7B244E14C40
43836	1	7	\N	886	32642	\N	57.778265331514199	Костромская область, Городской округ город Кострома, ул. Депутатская, 47	Россия, Костромская область, Кострома, Депутатская улица, 47	0101000020E61000000002D6AA5D7544408B4F01309EE34C40
43835	1	7	\N	886	32642	\N	57.778204433780601	Костромская область, город Кострома, Депутатская, 47	Россия, Костромская область, Кострома, Депутатская улица, 47	0101000020E6100000D219187959754440E6CE4C309CE34C40
43851	1	7	\N	886	32660	\N	57.77752273035	Костромская область, город Кострома, Горького, 7	Россия, Костромская область, Кострома, улица Горького, 7	0101000020E6100000BB7F2C4487764440A471A8DF85E34C40
43909	1	7	\N	886	32639	\N	57.749875368470903	Костромская область, город Кострома, Голубкова, 12	Россия, Костромская область, Кострома, улица Голубкова, 12	0101000020E61000005B087250C2744440448B6CE7FBDF4C40
43856	1	7	\N	886	32607	\N	57.773874999999997	Костромская область, город Кострома, Галичская, 47А		0101000020E6100000A12DE7525C794440931804560EE34C40
43854	1	7	\N	886	32607	\N	57.775651920031201	Костромская область, город Кострома, Галичская, 47а	Россия, Костромская область, Кострома, Галичская улица, 47а	0101000020E610000086C77E164B794440DB89929048E34C40
43857	1	7	\N	886	32625	\N	57.765185983284802	Костромская область, город Кострома, Войкова, 23	Россия, Костромская область, Кострома, улица Войкова, 23	0101000020E6100000A6423C122F794440B4AD669DF1E14C40
43881	1	7	\N	886	32670	\N	57.728557145087898	Костромская область, город Кострома, Бульварная, 21	Россия, Костромская область, Кострома, улица Бульварная, 19	0101000020E6100000FBE59315C37F4440CD22145B41DD4C40
43764	1	7	\N	886	32626	\N	57.800153087908797	Костромская область, город Кострома, Боровая, 6	Россия, Костромская область, Кострома, улица Боровая, 6	0101000020E6100000F0366F9C14764440ED65DB696BE64C40
43720	1	7	\N	886	32626	\N	57.796436101538298	Костромская область, город Кострома, Боровая, 2		0101000020E610000050FF59F3E3754440B4AD669DF1E54C40
43848	1	7	\N	886	32661	\N	57.7809536846095	Костромская область, город Кострома, Боевая, 64	Россия, Костромская область, Кострома, улица Боевая, 64	0101000020E6100000E9633E20D079444017D7F84CF6E34C40
43850	1	7	\N	886	32653	\N	57.7770989428831	Костромская область, город Кострома, Беговая, 4А	Россия, Костромская область, Кострома, улица Беговая, 4а	0101000020E6100000EFE6A90EB97944408D60E3FA77E34C40
43870	1	7	\N	886	32605	\N	57.748413895961299	Костромская область, город Кострома, 2-я Глазковская, 27А	Россия, Костромская область, Кострома, 2-я Глазковская улица, 27	0101000020E6100000596B28B5178144402CEFAA07CCDF4C40
94340	1	7	\N	886	5342	\N	57.740965075576	Костромская область, город Кострома, м/н Давыдовский-2, ул. Бульварная, 21, Муниципальное общеобразовательное учреждение лицей № 17 города Костромы	Россия, Костромская область, Кострома, 2-й Давыдовский проезд, 21	0101000020E610000059198D7C5E7F4440863DEDF0D7DE4C40
43828	1	7	\N	886	32646	\N	57.766981102320401	Костромская область, город Кострома, 1 Мая, 14	Россия, Костромская область, Кострома, улица 1 Мая, 14	0101000020E6100000DDB6EF517F754440A2D3F36E2CE24C40
43864	1	7	\N	886	32658	\N	57.766398088149302	Костромская область, город Кострома, Юрия Смирнова, 47	Россия, Костромская область, Кострома, улица Юрия Смирнова, 47	0101000020E610000068CBB914577D444023DC645419E24C40
43907	1	7	\N	886	32641	\N	57.748800108340497	Костромская область, город Кострома, Машиностроителей, 3	Россия, Костромская область, Кострома, улица Машиностроителей, 3	0101000020E6100000DD5CFC6D4F744440569FABADD8DF4C40
43831	1	7	\N	886	32638	\N	57.769218559963697	Костромская область, город Кострома, Ленина, 3	Россия, Костромская область, Кострома, улица Ленина, 3	0101000020E6100000C093162EAB7644401D3BA8C475E24C40
44130	1	7	\N	29631	32362	\N	57.432678946737397	Костромская область, город Волгореченск, Парковая, 31	Россия, Костромская область, Волгореченск городской округ	0101000020E6100000C1A8A44E409544403F55850662B74C40
44127	1	7	\N	29631	32467	\N	57.441451498738999	Костромская область, город Волгореченск, Набережная, 20	Россия, Костромская область, Волгореченск городской округ	0101000020E610000055A4C2D842944440ACE4637781B84C40
44131	1	7	\N	29631	32339	\N	57.446192000000003	Костромская область, город Волгореченск, Имени 50-летия Ленинского Комсомола, 19		0101000020E6100000ED7F80B56A95444051DEC7D11CB94C40
44129	1	7	\N	29631	32339	\N	57.446192000000003	Костромская область, город Волгореченск, Имени 50-летия Ленинского Комсомола, 43		0101000020E6100000ED7F80B56A95444051DEC7D11CB94C40
44128	1	7	\N	29631	32339	\N	57.445514000000003	Костромская область, город Волгореченск, Имени 50-летия Ленинского Комсомола, 21		0101000020E61000001B118C834B95444080F44D9A06B94C40
44092	1	7	\N	29631	32388	\N	57.445514000000003	Костромская область, город Волгореченск, Зеленова, 4	Россия, Костромская область, поселок Волгореченск	0101000020E61000001B118C834B95444080F44D9A06B94C40
43665	1	7	\N	3522	32205	\N	58.471983999999999	Костромская область, город Буй, площадь Хазова, 1		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43666	1	7	\N	3522	32487	\N	58.471983999999999	Костромская область, город Буй, ул. Республиканская, 4		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43669	1	7	\N	3522	32207	\N	58.471983999999999	Костромская область, город Буй, ул. Октябрьской революции, 130		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43670	1	7	\N	3522	32590	\N	58.471983999999999	Костромская область, город Буй, ул. Овражная, 19		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43672	1	7	\N	3522	32272	\N	58.471983999999999	Костромская область, город Буй, ул. Лизы Чайкиной, 25-А		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43663	1	7	\N	3522	32377	\N	58.471983999999999	Костромская область, город Буй, ул. Клубная, 16		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43664	1	7	\N	3522	32303	\N	58.4783684344427	Костромская область, город Буй, ул. Карла Маркса, 5	Россия, Костромская область, Буй	0101000020E6100000965984622BC44440FAB9A1293B3D4D40
43668	1	7	\N	3522	32317	\N	58.471983999999999	Костромская область, город Буй, ул. Ивана Сусанина, 7		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43667	1	7	\N	3522	32181	\N	58.471983999999999	Костромская область, город Буй, ул. Заря революции, 28		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
43671	1	7	\N	3522	32432	\N	58.471983999999999	Костромская область, город Буй, ул. 3 Интернационала, 10		0101000020E610000081785DBF60C544401D1EC2F8693C4D40
44139	1	7	7281	53317	32468	\N	58.381185323658897	Костромская область, город Шарья, 1-й микрорайон, д. 7	Россия, Костромская область, Шарья городской округ	0101000020E61000001650A8A78FC04640E65C8AABCA304D40
43998	1	7	1104	25316	32153	\N	58.341368000000003	Костромская область, Шарьинский район, поселок Шекшема, ул.Вокзальная, д.7, здание администрации		0101000020E610000033C170AE6196464052F355F2B12B4D40
44006	1	7	1104	25716	32263	\N	58.207031999999998	Костромская область, Шарьинский район, село Троицкое, ул.Советская, д.26, здание администрации		0101000020E6100000B66AD784B4E04640DC9C4A06801A4D40
44002	1	7	1104	25516	32479	\N	58.111482913230297	Костромская область, Шарьинский район, деревня Сергеево, ул.Центральная, д.6, здание школы	Россия, Костромская область, Шарьинский район, поселок Сергеево	0101000020E6100000591822A7AFD34640AD872F13450E4D40
43999	1	7	1104	25381	32262	\N	58.151060000000001	Костромская область, Шарьинский район, село Рождественское, ул.Коммунальная, д.4, здание администрации		0101000020E610000006651A4D2ECA4640ECDD1FEF55134D40
43991	1	7	1104	25014	32452	\N	58.586506999999997	Костромская область, Шарьинский район, деревня Пищевка, ул.Центральная, д.27, здание школы	Россия, Костромская область, Шарьинский район, поселок Пищевка	0101000020E61000003AB01C2103BB464002F04FA9124B4D40
44005	1	7	1104	25694	32408	\N	57.951917999999999	Костромская область, Шарьинский район, село Печенкино, ул.Школьная, 5, здание школы		0101000020E61000002C4A09C1AAD64640A33CF372D8F94C40
44008	1	7	1104	25802	32570	\N	58.161392999999997	Костромская область, Шарьинский район, село Одоевское, ул.Советская, д.11, здание администрации		0101000020E610000038876BB587EF4640D3669C86A8144D40
43990	1	7	1104	24955	32357	\N	58.452862000000003	Костромская область, Шарьинский район, село Николо-Шанга, ул.Юрия Смирнова, 19, здание администрации		0101000020E6100000A227655243C54640F3CCCB61F7394D40
43975	1	7	1104	46262	\N	\N	58.195023999999997	деревня Медведица	Россия, Костромская область, Шарьинский район, поселок Медведица	0101000020E61000002E3C2F151BDF4640B1F7E28BF6184D40
44001	1	7	1104	25489	32354	\N	58.061297000000003	Костромская область, Шарьинский район, деревня Майтиха, ул.Центральная, д.7, здание администрации		0101000020E61000002AE3DF675CBC4640E52B8194D8074D40
43992	1	7	1104	25071	32358	\N	58.662666000000002	Костромская область, Шарьинский район, деревня Кривячка, пер.Школьный, д.1, административное здание		0101000020E6100000BB5F05F86EB94640E8154F3DD2544D40
44009	1	7	1104	25878	32666	\N	58.087497999999997	Костромская область, Шарьинский район, село Конево, ул.Школьная, д.1, здание администрации		0101000020E6100000118DEE2076F64640923B6C22330B4D40
44004	1	7	1104	25620	32527	\N	58.014369000000002	"Костромская область, Шарьинский район, деревня Катунино, ул.Центральная, д.17, здание СПОК ""Победа АГРО"""		0101000020E6100000AE9CBD33DAD04640C289E8D7D6014D40
43996	1	7	1104	25228	32309	\N	58.373299000000003	Костромская область, Шарьинский район, поселок Зебляки, ул.Октябрьская, д.74, здание администрации		0101000020E6100000FC8C0B0742E046409450FA42C82F4D40
43995	1	7	1104	25167	32335	\N	58.284601000000002	Костромская область, Шарьинский район, село Заболотье, ул.Молодежная, д.1-А, здание администрации		0101000020E610000071ADF6B017EA464057B439CE6D244D40
44146	1	7	1104	53298	32507	\N	58.390412333306003	Костромская область, город Шарья, пос. Ветлужский, ул. Чайковского, д. 3	Россия, Костромская область, Шарьинский район, поселок Ветлужский	0101000020E610000073F4F8BD4DBB4640A4FB3905F9314D40
44144	1	7	1104	53298	32344	\N	58.390430994928799	Костромская область, город Шарья, пос. Ветлужский, ул. Центральная, д. 26	Россия, Костромская область, Шарьинский район, поселок Ветлужский	0101000020E6100000BE874B8E3BBB46401B2C9CA4F9314D40
44143	1	7	1104	53298	32344	\N	58.3888985962096	Костромская область, город Шарья, пос. Ветлужский, ул. Центральная, д. 18	Россия, Костромская область, Шарьинский район, поселок Ветлужский	0101000020E6100000543882548ABB46403B394371C7314D40
44145	1	7	1104	53298	32143	\N	58.390863026330898	Костромская область, город Шарья, пос. Ветлужский, ул. Рабочая, д. 46	Россия, Костромская область, Шарьинский район, поселок Ветлужский	0101000020E6100000170FEF39B0BA4640B51B7DCC07324D40
43997	1	7	1104	25287	32519	\N	58.365568000000003	Костромская область, Шарьинский район, поселок Варакинский, ул.Центральная, д.1, здание детского сада		0101000020E6100000187AC4E8B9AB4640693BA6EECA2E4D40
44003	1	7	1104	25584	32422	\N	58.056787999999997	Костромская область, Шарьинский район, деревня Быниха, ул.Молодежная, д.2, здание школы		0101000020E61000005AB9179815CA4640126745D444074D40
43680	1	7	1104	9862	32539	\N	58.497152	Костромская область, Пыщугский район, поселок Боровской, улица Свободы, дом 5		0101000020E61000002B51F69672D046400C923EADA23F4D40
44000	1	7	1104	25412	32582	\N	58.108077999999999	Костромская область, Шарьинский район, деревня Берзиха, ул.Центральная, д.28-А, здание школы		0101000020E6100000CB9D996038C1464063B5F97FD50D4D40
44208	1	7	494	3313	32369	\N	58.760680999999998	Костромская область, Чухломский муниципальный район, пос. Якша, ул. Зеленая, д. 18		0101000020E6100000A30392B06F85454023D8B8FE5D614D40
44215	1	7	494	3724	32198	\N	59.070186	Костромская область, Чухломский муниципальный район, с. Шартаново, ул. Береговая, д. 1		0101000020E610000089B48D3F51A345408B51D7DAFB884D40
44201	1	7	494	2951	32192	\N	58.755532000000002	Костромская область, Чухломский муниципальный район, город Чухлома, ул. Советская, д. 6		0101000020E610000070067FBF985745406E8AC745B5604D40
44202	1	7	494	2951	32587	\N	58.7532152388886	Костромская область, Чухломский муниципальный район, город Чухлома, ул. Октября, д. 6	Россия, Костромская область, Чухломский район, Чухлома	0101000020E61000005AF10D85CF564540A6ED5F5969604D40
44204	1	7	494	3077	32586	\N	58.823332999999998	Костромская область, Чухломский муниципальный район, д. Федоровское, пер. Ветеранов, д. 5		0101000020E6100000D751D50451454540D95BCAF962694D40
43675	1	7	494	9597	32433	\N	58.742972999999999	Костромская область, Чухломский муниципальный район, д. Тимофеевское, ул. Центральная, д. 1		0101000020E6100000BAA0BE654E554540CF6740BD195F4D40
44212	1	7	494	3525	32318	\N	58.974412000000001	Костромская область, Чухломский муниципальный район, с. Судай, ул. Советская, д. 29		0101000020E61000005AD427B9C39045403C6A4C88B97C4D40
44213	1	7	494	3525	32266	\N	58.974412000000001	Костромская область, Чухломский муниципальный район, с. Судай, ул. Пионерская, д. 1		0101000020E61000005AD427B9C39045403C6A4C88B97C4D40
43983	1	7	494	53364	32631	\N	58.776445583241703	Костромская область, Городской округ город Мантурово, ул. Сенная, д. 1А	Россия, Костромская область, Чухломский район, поселок Сенная	0101000020E610000001DC2C5E2C3C4540158E209562634D40
44209	1	7	494	3404	32373	\N	58.890582000000002	Костромская область, Чухломский муниципальный район, д. Повалихино, ул. Центральная, д. 18		0101000020E6100000E36F7B82C46C454001344A97FE714D40
44205	1	7	494	3198	32528	\N	59.165503999999999	Костромская область, Чухломский муниципальный район, д. Панкратово, ул. Центральная, д. 7		0101000020E61000000953944BE3BD4540B8AD2D3C2F954D40
44203	1	7	494	3061	32314	\N	58.818171	Костромская область, Чухломский муниципальный район, с. Ножкино, ул. Приозерная, д. 25		0101000020E61000008849B890474E45408FC4CBD3B9684D40
43795	1	7	494	15295	32349	\N	58.678038000000001	Костромская область, Костромской район, дер. Некрасово, Школьная, 5		0101000020E61000008B6B7C26FB454540FEB8FDF2C9564D40
44214	1	7	494	3643	32270	\N	59.119107	Костромская область, Чухломский муниципальный район, д. Куливертово, ул. Школьная, д. 38		0101000020E610000016DC0F7860764540C2DCEEE53E8F4D40
44206	1	7	494	3201	32199	\N	58.684587000000001	Костромская область, Чухломский муниципальный район, с. Коровье, ул. Центральная, д. 11		0101000020E610000085CFD6C1C16E45402522FC8BA0574D40
44210	1	7	494	3427	32431	\N	59.020722999999997	Костромская область, Чухломский муниципальный район, с. Георгий, ул. Кооперативная, д. 12		0101000020E61000008B6EBDA60767454033A31F0DA7824D40
44216	1	7	494	3745	32313	\N	59.089224000000002	Костромская область, Чухломский муниципальный район, пос. Вига, ул. Школьная, д. 15А		0101000020E6100000A9FB00A436A54540580229B16B8B4D40
44207	1	7	494	3296	32367	\N	58.754458999999997	Костромская область, Чухломский муниципальный район, с. Введенское, ул. Сельская, д. 14		0101000020E6100000F78E1A13628445402096CD1C92604D40
43673	1	7	494	9508	32274	\N	58.762056999999999	Костромская область, Чухломский муниципальный район, д. Белово, ул. Молодежная, д. 7		0101000020E610000010B056ED9A4245400C5872158B614D40
43674	1	7	494	9572	32455	\N	58.727331	Костромская область, Чухломский муниципальный район, пос. Анфимово, ул. Центральная, д. 7В		0101000020E61000003B8908FF225A4540F92EA52E195D4D40
44190	1	7	405	2283	32259	\N	58.107393999999999	Костромская область, Сусанинский район, д. Ченцово, Центральная, 9		0101000020E61000006AA510C825CA4440B0E42A16BF0D4D40
44187	1	7	405	2149	32383	\N	58.145198999999998	Костромская область, Сусанинский район, п. Сусанино, Леонова, 11		0101000020E6100000E2E7BF07AFCB4440B9347EE195124D40
44198	1	7	405	2723	32305	\N	58.180218000000004	Костромская область, Сусанинский район, д. Попадьино, адрес помещения для голосования: Школьная, 11, адрес УИК: 70 лет Октября, 18		0101000020E61000002592E86514F344404513286211174D40
44197	1	7	405	2710	32556	\N	58.103147	Костромская область, Сусанинский район, д. Меленки, адрес помещения для голосования: Молодежная, 10, адрес УИК: Молодежная, 2		0101000020E6100000FB1F60ADDAE544401BD7BFEB330D4D40
44196	1	7	405	2626	32360	\N	58.075259000000003	Костромская область, Сусанинский район, д. Медведки, Садовая, 2		0101000020E61000000344C18C29C0444066DD3F16A2094D40
43631	1	7	405	7592	32473	\N	58.172041	Костромская область, Антроповский район, поселок Малинино, улица Октябрьская, дом 2		0101000020E61000009E996038D7C044401B49827005164D40
44195	1	7	405	2603	32412	\N	58.138368	Костромская область, Сусанинский район, д. Ломышки, Центральная, 22		0101000020E6100000C45A7C0A80B344400E68E90AB6114D40
44199	1	7	405	2836	32222	\N	58.028630999999997	Костромская область, Сусанинский район, д. Запрудня, Дорожная, 2		0101000020E61000004A0B9755D8B644406D533C2EAA034D40
44194	1	7	405	53345	32470	\N	58.167803220841598	Костромская область, Сусанинский район, д. Григорово, Свободы, 2	Россия, Костромская область, Сусанинский район	0101000020E610000050E1085229BE4440D99596917A154D40
44193	1	7	405	2488	32260	\N	58.245750000000001	Костромская область, Сусанинский район, с. Головинское, адрес помещения для голосования: Северная, 3, адрес УИК: Северная, 2		0101000020E6100000486C770FD0D54440FA7E6ABC741F4D40
44192	1	7	405	2392	32247	\N	58.212384999999998	Костромская область, Сусанинский район, с. Буяково, Правды, 23		0101000020E61000001344DD0720A944409A94826E2F1B4D40
44191	1	7	405	2382	32581	\N	58.162903	Костромская область, Сусанинский район, с. Андреевское, Советская, 9		0101000020E6100000DB19A6B6D4A54440CCB56801DA144D40
44126	1	7	247	31296	32283	\N	57.944358000000001	Костромская область, Судиславский район, село Шахово, Корякова, 1		0101000020E61000000B7DB08C0DC34440A5DB12B9E0F84C40
44186	1	7	247	2051	32363	\N	57.908130999999997	Костромская область, Судиславский район, деревня Фадеево, Зелёная, 2		0101000020E6100000088ECBB8A9CB4440ECBDF8A23DF44C40
44167	1	7	247	978	32304	\N	57.879936999999998	Костромская область, Судиславский район, поселок Судиславль, Юрьева, 2а		0101000020E61000003FFF3D78EDD844402AC58EC6A1F04C40
44169	1	7	247	978	32251	\N	57.879936999999998	Костромская область, Судиславский район, поселок Судиславль, Шаховское шоссе, 3		0101000020E61000003FFF3D78EDD844402AC58EC6A1F04C40
44168	1	7	247	978	32140	\N	57.879936999999998	Костромская область, Судиславский район, поселок Судиславль, Октябрьская, 23		0101000020E61000003FFF3D78EDD844402AC58EC6A1F04C40
44185	1	7	247	2036	32261	\N	57.832377000000001	Костромская область, Судиславский район, деревня Сорож, Новая, 5		0101000020E6100000E33785950AF24440A7785C548BEA4C40
44173	1	7	247	1334	32563	\N	58.072746000000002	Костромская область, Судиславский район, деревня Свозово, Центральная, 17		0101000020E61000002B16BF29ACF844401975ADBD4F094D40
44178	1	7	247	1599	32520	\N	57.823304999999998	Костромская область, Судиславский район, поселок Раслово, площадь Октября, 1		0101000020E6100000091A33897AB744400FD1E80E62E94C40
44172	1	7	247	1242	32301	\N	58.041871	Костромская область, Судиславский район, поселок Первушино, Центральная, 7		0101000020E6100000931ADA006CF844404ED367075C054D40
44177	1	7	247	1541	32464	\N	57.895453000000003	Костромская область, Судиславский район, деревня Михайловское, Центральная, 1		0101000020E61000001B81785DBFB04440740D33349EF24C40
44184	1	7	247	1917	32218	\N	57.897471000000003	Костромская область, Судиславский район, поселок Мирный, Заводская, д.2, кв.1		0101000020E6100000FAB7CB7EDDD14440E10D6954E0F24C40
44175	1	7	247	1432	32508	\N	57.750340000000001	Костромская область, Судиславский район, деревня Кобякино, Королёва, 2		0101000020E610000085CFD6C1C1BA4440B97020240BE04C40
44176	1	7	247	1495	32562	\N	57.802905000000003	Костромская область, Судиславский район, деревня Калинки, Центральная, 43		0101000020E6100000CCD3B9A294A64440BF654E97C5E64C40
44183	1	7	247	1900	32471	\N	57.871605000000002	Костромская область, Судиславский район, поселок Западный, Молодежная, 1		0101000020E610000013D55B035BD34440DA03ADC090EF4C40
44171	1	7	247	1231	32406	\N	57.944643999999997	Костромская область, Судиславский район, деревня Завражье, Центральная, 28		0101000020E6100000C05B2041F1F144406A2E3718EAF84C40
44182	1	7	247	1801	32466	\N	57.839467999999997	Костромская область, Судиславский район, деревня Жвалово, Кашинцева, 15		0101000020E610000083A6255646DF4440EE04FBAF73EB4C40
44181	1	7	247	1793	32462	\N	57.893352999999998	Костромская область, Судиславский район, поселок Дружба, Цветочная, 4		0101000020E61000009CFBABC77DDD444049641F6459F24C40
44174	1	7	247	1384	32166	\N	57.825778	Костромская область, Судиславский район, деревня Грудки, Центральная, 21		0101000020E610000079CDAB3AABC54440CEE0EF17B3E94C40
44180	1	7	247	1699	32421	\N	57.919384999999998	Костромская область, Судиславский район, поселок Глебово, Школьная		0101000020E61000006E179AEB34D844406BB75D68AEF54C40
44170	1	7	247	1157	32250	\N	58.001131999999998	Костромская область, Судиславский район, село Воронье, Полевая, 3		0101000020E6100000D3F9F02C41004540527DE71725004D40
44179	1	7	247	1680	\N	\N	57.821148000000001	Костромская область, Судиславский район, поселок Березовая роща	Россия, Костромская область, Судиславский район, поселок Березовая Роща	0101000020E6100000E4326E6AA0B344408196AE601BE94C40
44150	1	7	90	53329	\N	\N	59.301925581216999	Костромская область, Солигаличский район, д. Прокошево, адрес помещения для голосования: д. Великово, д. 66, адрес УИК: д. Прокошево, 15		0101000020E6100000B7B6F0BC54104540F3E7DB82A5A64D40
44118	1	7	805	30916	32230	\N	58.405738999999997	Костромская область, Поназыревский муниципальный район, Хмелёвское сельское поселение, с. Хмелевка, ул. Строителей, д. 1		0101000020E6100000DF3312A1113447401ADB6B41EF334D40
44164	1	7	90	770	32249	\N	59.077933000000002	Костромская область, Солигаличский район, город Солигалич, адрес помещения для голосования: ул. В.Серогодского, д. 10, адрес УИК: ул. В.Серогодского, 10		0101000020E61000001135D1E7A3244540BC2363B5F9894D40
44163	1	7	90	770	32436	\N	59.077490712483197	МОУ Солигаличская вечерняя общеобразовательная школа, г. Солигалич, ул. Красноармейская, д.7а	Россия, Костромская область, Солигаличский район, Солигалич	0101000020E6100000998235CEA6254540FF5D9F39EB894D40
44165	1	7	90	770	32300	\N	59.077933000000002	Костромская область, Солигаличский район, город Солигалич, адрес помещения для голосования: ул. В.Серогодского, д. 10, адрес УИК: ул. Коммунистическая, 1		0101000020E61000001135D1E7A3244540BC2363B5F9894D40
44155	1	7	90	52355	\N	\N	58.856506000000003	Костромская область, Солигаличский район, адрес помещения для голосования: д. Песлиново, д. 15, адрес УИК: д. Песлиново, 15		0101000020E6100000371C96067E0C4540F56915FDA16D4D40
44157	1	7	90	52358	\N	\N	58.926676999999998	Костромская область, Солигаличский район, адрес помещения для голосования: с. Лосево, д. 90, адрес УИК: с. Лосево, 41		0101000020E61000000723F609A02A45404A7A185A9D764D40
44152	1	7	90	52348	\N	\N	59.225473999999998	Костромская область, Солигаличский район, адрес помещения для голосования: д. Куземино, д. 61, адрес УИК: д. Куземино, 27		0101000020E6100000624B8FA67A404540950C0055DC9C4D40
44154	1	7	90	112	32405	\N	58.866674000000003	Костромская область, Солигаличский район, с. Корцово, адрес помещения для голосования: ул. Центральная, д. 50, адрес УИК: ул. Центральная, 25		0101000020E61000003C889D29741A45409225732CEF6E4D40
44158	1	7	90	52361	\N	\N	58.974105999999999	Костромская область, Солигаличский район, адрес помещения для голосования: д. Коровново, д. 85, адрес УИК: д. Коровново, 81		0101000020E6100000ACC43C2B692F45402F6B6281AF7C4D40
44160	1	7	90	52363	\N	\N	58.987490000000001	Костромская область, Солигаличский район, адрес помещения для голосования: д. Калинино, д. 15, адрес УИК: д. Калинино, 15		0101000020E61000004C50C3B7B0F0444043908312667E4D40
44162	1	7	90	40330	\N	\N	59.087072515225401	"Костромская область, Солигаличский район, адрес помещения для голосования: д. Заяцкое, д. 1 ""А"", адрес УИК: д. Заяцкое, 1"		0101000020E61000004B2025766D194540ABAE4335258B4D40
44151	1	7	90	52347	\N	\N	59.162906999999997	Костромская область, Солигаличский район, адрес помещения для голосования: с. Зашугомье, д. 10, адрес УИК: с. Зашугомье, 10		0101000020E610000071766B990C4745400DA5F622DA944D40
44156	1	7	90	52357	\N	\N	58.898099999999999	Костромская область, Солигаличский район, адрес помещения для голосования: с. Жилино, д. 21, адрес УИК: с. Жилино, 21		0101000020E6100000C85EEFFE78FF4440D044D8F0F4724D40
44161	1	7	90	606	32411	\N	59.061692999999998	"Костромская область, Солигаличский район, с. Гнездниково, адрес помещения для голосования: ул. Новая, д. 1""Б"", адрес УИК: ул. Новая, 1""Б"""		0101000020E610000053EBFD463B26454031B2648EE5874D40
44149	1	7	90	32327	32246	\N	59.080472	Костромская область, Солигаличский район, п. Высоковский, адрес помещения для голосования: ул. Школьная, д. 2, адрес УИК: ул. Школьная, 1		0101000020E61000009CF86A47715A4540321F10E84C8A4D40
44148	1	7	90	32312	32214	\N	59.067771	Костромская область, Солигаличский район, д. Бурдуково, адрес помещения для голосования: ул. Ветеранов, д. 17, адрес УИК: ул. Ветеранов, 17		0101000020E6100000CD76853E584A4540014F5AB8AC884D40
44153	1	7	90	52350	\N	\N	58.919212000000002	Костромская область, Солигаличский район, адрес помещения для голосования: д. Большой Починок, д. 48, адрес УИК: д. Большой Починок, 48		0101000020E61000006C425A63D01B45409E0B23BDA8754D40
43678	1	7	643	9785	32481	\N	58.869833	Костромская область, Пыщугский  район, деревня Сергеевица, улица Новая, дом 9		0101000020E61000006D73637AC2EE4640A4FD0FB0566F4D40
43676	1	7	643	4230	32434	\N	58.886904000000001	Районный центр культуры и досуга, с. Пыщуг, ул. Чапаева, д.5		0101000020E6100000D2C8E7154FDB46408658FD1186714D40
43677	1	7	643	4230	32209	\N	58.886904000000001	Костромская область, Пыщугский район, село Пыщуг, улица Советская, дом 22		0101000020E6100000D2C8E7154FDB46408658FD1186714D40
43685	1	7	643	10110	32279	\N	59.069958999999997	Костромская область, Пыщугский район, деревня Носково, улица Октябрьская, дом 3		0101000020E610000040FCFCF7E0CD4640CA87A06AF4884D40
43679	1	7	643	9820	32591	\N	58.768870999999997	Костромская область, Пыщугский район, село Михайловица, улица Гагарина, дом 26		0101000020E61000001DE90C8CBCD44640E1EB6B5D6A624D40
43684	1	7	643	10068	32484	\N	58.732970000000002	"Костромская область, Пыщугский  район, деревня Крутая, улица Победы, дом 1""а"""		0101000020E6100000D40E7F4DD6B646407D7901F6D15D4D40
43682	1	7	643	9962	32482	\N	58.861536999999998	Колпашницкий сельский клубный филиал РЦКиД, д. Колпашница, ул. Советская, д.10		0101000020E61000002B323A2009C94640A0A52BD8466E4D40
43681	1	7	643	9928	32517	\N	58.79383	Костромская область, Пыщугский район, деревня Головино, улица Шистерова, дом 23		0101000020E6100000FCFD62B664C34640B64AB0389C654D40
43683	1	7	643	10037	32440	\N	58.718760022319103	Костромская область, Пыщугский район, село Верхнеспасское, улица Первомайская, дом 12	Россия, Костромская область, Пыщугский район, поселок Верхнеспасское	0101000020E6100000994BAAB69BBE464024D6E253005C4D40
44125	1	7	805	31217	32310	\N	58.356074	Костромская область, Поназыревский муниципальный район, Якшангское сельское поселение, п. Якшанга, ул. Ленина, д. 38		0101000020E610000002BB9A3C65F546405B7A34D5932D4D40
44103	1	7	1877	30274	32225	\N	59.188249999999996	Костромская область, Павинский муниципальный район,поселок Доброумово, Дзержинского, 11		0101000020E610000089B14CBF442047406ABC749318984D40
44122	1	7	805	5704	32239	\N	58.357953000000002	Костромская область, Поназыревский муниципальный район, Городское поселение поселок Поназырево, п. Поназырево, пл.50 лет ВЛКСМ, д.6		0101000020E6100000AFCC5B751D284740A7406667D12D4D40
44123	1	7	805	5704	32235	\N	58.355742974144803	Костромская область, Поназыревский муниципальный район, Городское поселение поселок Поназырево, п. Поназырево, ул. Пушкина, д.38	Россия, Костромская область, Поназыревский район, поселок Поназырево	0101000020E6100000223999B855284740F56393FC882D4D40
44121	1	7	805	5704	32235	\N	58.359515170785599	МБОУ Поназыревская средняя общеобразовательная школа, п. Поназырево, ул. Пушкина, д.38	Россия, Костромская область, Поназыревский район, поселок Поназырево	0101000020E610000032CC09DAE4284740F2B56796042E4D40
43745	1	7	805	12953	32551	\N	58.614474999999999	Костромская область, Поназыревский муниципальный район, Полдневицкое сельское поселение, п. Полдневица, ул. Ленина, д.19		0101000020E6100000AEBCE47FF24D4740D49AE61DA74E4D40
44120	1	7	805	31020	32555	\N	58.558298999999998	Костромская область, Поназыревский муниципальный район, Хмелёвское сельское поселение, д. Клюкино, ул. Центральная, д. 5		0101000020E610000030F65E7CD1404740DB31755776474D40
44124	1	7	805	31193	32550	\N	58.478740999999999	Костромская область, Поназыревский муниципальный район, Хмелёвское сельское поселение, д. Гудково, ул. Северная, д. 15		0101000020E6100000DE585018943B47408E209562473D4D40
44119	1	7	805	30943	\N	\N	58.419136999999999	Костромская область, Поназыревский муниципальный район, Хмелёвское сельское поселение, д. Горлово	Россия, Костромская область, Поназыревский район, поселок Горлово	0101000020E610000087A8C29FE139474093C5FD47A6354D40
44106	1	7	638	30309	32332	\N	58.452311000000002	Костромская область, Парфеньевский район, село Успенье, улица Центральная, дом 1		0101000020E6100000761A69A9BCB945407F4FAC53E5394D40
44011	1	7	638	25978	32525	\N	58.438907999999998	Костромская область, Нейский район, поселок Тотомица, ул. Ленина, д. 22		0101000020E610000011A7936C75E54540F4F928232E384D40
44108	1	7	638	30395	\N	\N	58.615605000000002	"Костромская область, Парфеньевский район, деревня Савино, помещение МОУ ""Савинская основная общеобразовательная школа"", дом 52"		0101000020E6100000BA85AE44A0C4454086200725CC4E4D40
44107	1	7	638	30317	\N	\N	58.446984999999998	Костромская область, Парфеньевский район, село Потрусово, помещение администрации Потрусовского сельского поселения, дом 35		0101000020E6100000645930F147D74540BA66F2CD36394D40
44117	1	7	638	30775	32552	\N	58.483939999999997	Костромская область, Парфеньевский район, село Парфеньево, улица Песочная, дом 21		0101000020E6100000DF8B2FDAE3B34540F59CF4BEF13D4D40
44116	1	7	638	30775	32391	\N	58.483939999999997	Костромская область, Парфеньевский район, село Парфеньево, улица Ленина, дом 41		0101000020E6100000DF8B2FDAE3B34540F59CF4BEF13D4D40
44109	1	7	638	30444	\N	\N	58.574402999999997	Костромская область, Парфеньевский район, село Николо-Ширь, помещение  Ширской сельской библиотеки, дом 41		0101000020E61000001D554D1075C54540B5DC990986494D40
44111	1	7	638	4182	\N	\N	58.348235000000003	Костромская область, Парфеньевский район, село Николо-Полома, помещение Задоринской сельской библиотеки, дом 18		0101000020E6100000AC39403047A945404A29E8F6922C4D40
44112	1	7	638	4182	32536	\N	58.348235000000003	Николо-Поломская сельский Дом культуры .п. Николо-Полома, ул. Полевая, д.34		0101000020E6100000AC39403047A945404A29E8F6922C4D40
44115	1	7	638	30752	\N	\N	58.643521999999997	Костромская область, Парфеньевский район, село Матвеево, помещение  администрации Матвеевского сельского поселения, дом 125 А		0101000020E61000001B66683C11BE4540D520CCED5E524D40
44114	1	7	638	30715	32404	\N	58.700271000000001	Костромская область, Парфеньевский район, поселок Вохтома, улица Школьная, дом 16		0101000020E6100000EC14AB0661B845402AABE97AA2594D40
44113	1	7	638	30624	32288	\N	58.269226000000003	Костромская область, Парфеньевский район, поселок Бор, улица Набережная, дом 2		0101000020E6100000AAB8718BF9AF4540D09D60FF75224D40
44110	1	7	638	30471	\N	\N	58.526657999999998	Костромская область, Парфеньевский район, деревня Аносово, помещение Аносовского сельского Дома культуры, дом 74		0101000020E610000031EBC5504EA04540A016838769434D40
44102	1	7	1877	30103	\N	\N	59.112312000000003	Костромская область, Павинский муниципальный район, деревня Шумково, 52		0101000020E6100000CD8FBFB4A82547406479573D608E4D40
44097	1	7	1877	29846	32287	\N	59.103957999999999	Костромская область, Павинский муниципальный район, деревня Фурово, Чапаева, 15		0101000020E6100000FEB7921D1B1547402B14E97E4E8D4D40
44101	1	7	1877	29822	32217	\N	59.109927999999996	Костромская область, Павинский муниципальный район, село Павино, улица Октябрьская, 55		0101000020E6100000AA44D95BCA1347401475E61E128E4D40
44100	1	7	1877	29822	32217	\N	59.111594459705998	Костромская область,Павинский муниципальный район, село Павино, Октябрьская, 14		0101000020E610000094861A8524134740043752B6488E4D40
44096	1	7	1877	29822	32396	\N	59.109927999999996	Костромская область, Павинский муниципальный район, село Павино, Больничная, 7		0101000020E6100000AA44D95BCA1347401475E61E128E4D40
44104	1	7	1877	30173	\N	\N	59.134881	Костромская область, Павинский муниципальный район, село Медведица, 32		0101000020E6100000CAC51858C7F9464007EDD5C743914D40
44105	1	7	1877	30246	32387	\N	58.933430000000001	Костромская область, Павинский  муниципальный район,село Леденгск, Советская, 19		0101000020E6100000F530B43A39FD46407A8D5DA27A774D40
44099	1	7	1877	29928	\N	\N	59.110791999999996	Костромская область, Павинский муниципальный район, деревня Карпово, 6		0101000020E6100000B80721205F3847404754A86E2E8E4D40
38333	1	6	764	45938	35312	\N	54.076022000000002	г. Киров, пер. Куракина, 6		0101000020E6100000A583F57F0E29414065E3C116BB094B40
44076	1	7	1847	53312	\N	\N	57.608495721468998	Костромская область, Островский район, с. Щелыково адрес помещения для голосования: д. 30, адрес УИК: с. Адищево, ул. Комарова, 50	Россия, Костромская область, Островский район, поселок Щелыково	0101000020E61000006B9F8EC70C16454098DF6932E3CD4C40
44091	1	7	1847	52247	\N	\N	57.880462999999999	Костромская область, Островский район, с. Хомутово адрес помещения для голосования: д. 1, адрес УИК: с. Хомутово		0101000020E61000004DD6A88768224540452BF702B3F04C40
44089	1	7	1847	53354	\N	\N	57.815455829078502	"Костромская область, Островский район, д. Парфеньево адрес помещения для голосования: ОАО ""Островскоеавтотранс"", адрес УИК: п. Островское, ул. Советская, 97"		0101000020E61000007102D369DD204540DAA9B9DC60E84C40
44070	1	7	1847	28678	32241	\N	57.797283999999998	Костромская область, Островский район, п. Островское адрес помещения для голосования: пер. Школьный, д. 3, адрес УИК: ул. Советская, 97		0101000020E610000090BC7328431F4540E1CFF0660DE64C40
44088	1	7	1847	28678	32223	\N	57.797283999999998	Костромская область, Островский район, п. Островское, Советская, 97		0101000020E610000090BC7328431F4540E1CFF0660DE64C40
44072	1	7	1847	28678	32223	\N	57.797283999999998	Костромская область, Островский район, п. Островское, адрес помещения для голосования: ул. Советская, д. 51А, адрес УИК: ул. Советская, 97		0101000020E610000090BC7328431F4540E1CFF0660DE64C40
44071	1	7	1847	28678	32597	\N	57.797283999999998	Костромская область, Островский район, п. Островское, адрес помещения для голосования: ул. Сахарова, д. 3, адрес УИК: ул. Советская, 97		0101000020E610000090BC7328431F4540E1CFF0660DE64C40
44073	1	7	1847	28678	32620	\N	57.801912364432702	Костромская область, Островский район, п. Островское адрес помещения для голосования: ул. Заречная, д. 8, адрес УИК: ул. Советская, 97		0101000020E610000092240857401F45408E226B0DA5E64C40
44075	1	7	1847	53316	\N	\N	57.6159971021033	Костромская область, Островский район, д. Марково адрес помещения для голосования: Марковский селшьский Дом культуры, адрес УИК: с. Адищево, ул. Комарова, 50	Россия, Костромская область, Островский район, поселок Марково	0101000020E6100000A67D737FF510454091B75CFDD8CE4C40
44080	1	7	1847	53336	\N	\N	57.712069993048203	Костромская область, Островский район, д. Малое Березово адрес помещения для голосования: Малобеоезовский сельский клуб, адрес УИК: д. Ивашево, 70		0101000020E61000009770E82D1E2045403A3B191C25DB4C40
44087	1	7	1847	53350	32506	\N	57.950321169353501	Костромская область, Островский район, д. Ломки адрес помещения для голосования: ул. Школьная, д. 1, адрес УИК: ул. Лесная, 3	Россия, Костромская область, Островский район, поселок Ломки	0101000020E61000002D793C2D3F484540DCD9571EA4F94C40
44069	1	7	1847	28589	32444	\N	57.869962999999998	Костромская область, Островский район, п. Красная Поляна, адрес помещения для голосования: ул. Луговая, д. 15, адрес УИК: Костромская область, Островский район, с. Юрьево, 24		0101000020E6100000134548DDCE14454072DD94F25AEF4C40
44086	1	7	1847	53369	32675	\N	57.810297480320997	"Костромская область, Островский район, д. Козловка адрес помещения для голосования: ГУ ""Островский психоневрологический интернат"", адрес УИК: д. Клеванцово, ул. Колхозная, 24"		0101000020E61000001407D0EFFB2D45400186E5CFB7E74C40
44093	1	7	1847	53359	32578	\N	57.973857211909802	Костромская область, Островский район, д. Климово адрес помещения для голосования: ул. Школьная, д. 5, адрес УИК: с. Хомутово		0101000020E6100000206118B0E420454087FD9E58A7FC4C40
44084	1	7	1847	53342	32456	\N	57.857889	Костромская область, Островский район, д. Клеванцово, Колхозная, 13		0101000020E6100000B51666A19D234540904C874ECFED4C40
44081	1	7	1847	29128	32327	\N	58.014136000000001	Костромская область, Островский район, с. Игодово, Пушкина, 16		0101000020E61000005DBF60376C2D45401FD95C35CF014D40
44079	1	7	1847	29029	\N	\N	57.641775000000003	Костромская область, Островский район, д. Ивашево, 70		0101000020E6100000AFB0E07EC01B4540F931E6AE25D24C40
44077	1	7	1847	28964	32447	\N	57.686951000000001	Костромская область, Островский район, с. Заборье, Совхозная, 20		0101000020E61000009CC1DF2F663545402D7AA702EED74C40
44083	1	7	1847	29204	32219	\N	57.809542	Костромская область, Островский район, п. Дымница, Школьная, 1		0101000020E6100000BA84436FF1584540855E7F129FE74C40
44082	1	7	1847	53363	32622	\N	58.077581827383902	Костромская область, Островский район, с. Дубяны адрес помещения для голосования: ул. Лесная, д. 3, адрес УИК: с. Игодово, ул. Пушкина, 16	Россия, Костромская область, Островский район, поселок Дубяны	0101000020E6100000FA635A9BC62C45400F61FC34EE094D40
44090	1	7	1847	28528	32612	\N	57.821604708074197	Костромская область, Островский район, д. Гуляевка адрес помещения для голосования: ул. Транспортная, д. 4, адрес УИК: п. Островское, ул. Советская, 97	Россия, Костромская область, Островский район, поселок Гуляевка	0101000020E6100000A5F622DA8E174540739D465A2AE94C40
44085	1	7	1847	53346	32474	\N	57.777643274224701	Костромская область, Островский район, с. Воскресенское адрес помещения для голосования: ул. Заовражная, д. 23, адрес УИК: д. Клеванцово, ул. Колхозная, 24		0101000020E6100000BA9EE8BAF03545404E7B4ACE89E34C40
44078	1	7	1847	53366	32650	\N	57.673450021034398	Костромская область, Островский район, п. Александровское адрес помещения для голосования: ул. Советская, д. 16, адрес УИК: ул. Н. Гурова, 12	Россия, Костромская область, Островский район, поселок Александровское	0101000020E6100000BB9A3C6535294540E0BE0E9C33D64C40
44074	1	7	1847	28815	32543	\N	57.663387999999998	Костромская область, Островский район, с. Адищево, Комарова, 50		0101000020E610000011E0F42EDE1145408847E2E5E9D44C40
44062	1	7	630	28255	32319	\N	59.062140999999997	Костромская область, Октябрьский район, село Соловецкое, Центральная, 7		0101000020E6100000B7973446EBA44740D05E7D3CF4874D40
44059	1	7	630	28126	32280	\N	58.803075	Костромская область, Октябрьский район, село Луптюг, Советская, 58		0101000020E61000004B3CA06CCA8F47401B9E5E29CB664D40
94350	1	7	630	28165	\N	\N	58.886504000000002	Костроская область, Октябрьский район, дер.Лебеди д.102, Лебедевская начальная общеобразовательная школа,	Россия, Костромская область, Октябрьский район, поселок Лебеди	0101000020E610000029B4ACFBC79E4740F8E28BF678714D40
44061	1	7	630	28225	32544	\N	58.897640000000003	Костромская область, Октябрьский район, деревня Кузьмины, Молодёжная, 1		0101000020E6100000DA0418963F8D47406DCA15DEE5724D40
44065	1	7	630	28399	32417	\N	58.935251000000001	Костромская область, Октябрьский район, село Ильинское, Школьная, 2		0101000020E61000002E71E481C8B047409146054EB6774D40
44067	1	7	630	28485	\N	\N	58.874895000000002	Костромская область, Октябрьский район, деревня Забегаево, 84		0101000020E61000003E23111AC17A47408B37328FFC6F4D40
44066	1	7	630	28437	32486	\N	58.805998000000002	Костромская область, Октябрьский район, село Веденье, Интернатовский, 6		0101000020E6100000DFA815A6EF7147401A5245F12A674D40
44064	1	7	630	28340	32307	\N	58.976615000000002	Костромская область, Октябрьский район, село Боговарово, Победы, 44		0101000020E6100000B4AB90F2938247403BE466B8017D4D40
44063	1	7	630	28308	32297	\N	58.990656000000001	Костромская область, Октябрьский район, деревня Андреево, Молодёжная, 3		0101000020E61000000ABFD4CF9B7E474008CBD8D0CD7E4D40
44025	1	7	7283	53335	32445	\N	58.283697857341302	Костромская область, Нейский район, город Нея, ул. Махотина, д. 23		0101000020E61000009CC420B072F2454066F84F3750244D40
44023	1	7	7283	53335	32386	\N	58.284861903339198	Костромская область, Нейский район, город Нея, ул. Матросова, д. 7А	Россия, Костромская область, Нея городской округ	0101000020E610000050C3B7B06EF24540C3EFA65B76244D40
44007	1	7	7283	\N	32580	\N	58.2978107368208	Костромская область, Нейский район, город Нея, ул. Любимова, д. 45	Россия, Костромская область, Нея городской округ	0101000020E6100000CC9BC3B5DAED4540CDB1BCAB1E264D40
44021	1	7	7283	53335	32498	\N	58.3001943406314	Костромская область, Нейский район, город Нея, ул. Кирова, д. 62		0101000020E6100000B6A1629CBFED45404B3ACAC16C264D40
44024	1	7	7283	53335	32370	\N	58.2885685123575	Костромская область, Нейский район, город Нея, ул. Больничная, д. 8		0101000020E610000024B5503239EF4540D9D138D4EF244D40
44056	1	7	690	27993	32459	\N	57.484017000000001	Костромская область, Нерехтский район, п. Якушовка, ул. Мира, 19а		0101000020E6100000994528B6824E4440A1DAE044F4BD4C40
44057	1	7	690	28037	32338	\N	57.468657	Костромская область, Нерехтский район, д. Хомутово, ул. Победы, 1		0101000020E6100000D9429083126A44404F05DCF3FCBB4C40
44054	1	7	690	27901	32277	\N	57.414920000000002	Костромская область, Нерехтский район, с. Фёдоровское, пл. Мира, 3		0101000020E61000009AE95E27F5474440693A3B191CB54C40
44055	1	7	690	27969	32320	\N	57.503258000000002	Костромская область, Нерехтский район, с Тетеринское, ул. Мира, 6		0101000020E610000034BDC458A64B4440A6B915C26AC04C40
44052	1	7	690	4826	32179	\N	57.514952999999998	Костромская область, Нерехтский район, д Татарское, ул. Маршала Новикова, 13		0101000020E6100000895DDBDB2D73444011FDDAFAE9C14C40
44042	1	7	690	27333	32533	\N	57.452686	Костромская область, Нерехтский район, с. Спас, ул. Школьная, 1		0101000020E6100000BB48A12C7C834440B4AD669DF1B94C40
44058	1	7	690	28077	32453	\N	57.448501999999998	Костромская область, Нерехтский район, п. Рудино, ул. Школьная, 1		0101000020E6100000CBF44BC45B7344406518778368B94C40
44051	1	7	690	27785	\N	\N	57.478597000000001	Костромская область, Нерехтский район, с Марьинское, 91		0101000020E610000009E066F1625B44405B7B9FAA42BD4C40
94349	1	7	690	27725	32458	\N	57.365724999999998	Костромская область, Нерехтский район, п. Лужки, ул. Молодежная, д.18а, МОУ Ёмсненская СОШ		0101000020E61000008A592F86725E4440302AA913D0AE4C40
44047	1	7	690	27611	32211	\N	57.475798156781799	Костромская область, Нерехтский район, д. Лаврово, ул. Советская, 1б	Россия, Костромская область, Нерехтский район, поселок Лаврово	0101000020E6100000A855F4876644444048C0E8F2E6BC4C40
44028	1	7	690	26691	32365	\N	57.586354	Костромская область, Нерехский район, п. Космынино, ул. Техническая, 18		0101000020E610000013D731AEB86244407CF0DAA50DCB4C40
44027	1	7	690	26691	32426	\N	57.586354	Костромская область, Нерехтский район, п. Космынино, ул. Ленина, 31		0101000020E610000013D731AEB86244407CF0DAA50DCB4C40
44046	1	7	690	27536	32323	\N	57.3434661331058	Костромская область, Нерехтский район, д. Клементьево, ул. Октябрьская, 12	Россия, Костромская область, Нерехтский район, поселок Клементьево	0101000020E6100000209BE447FC684440DBA4A2B1F6AB4C40
44049	1	7	690	27700	\N	\N	57.442602999999998	Костромская область, Нерехтский район, д. Иголкино, 94		0101000020E6100000B95164ADA1424440450E1137A7B84C40
44045	1	7	690	27499	32480	\N	57.399759000000003	Костромская область, Нерехтский район, с. Ёмсна, ул. Центральная, 60		0101000020E61000005308E412475C44400EA48B4D2BB34C40
44044	1	7	690	27445	32416	\N	57.371034999999999	Костромская область, Нерехтский район, с. Григорцево, ул. Школьная, 12		0101000020E6100000BB4560AC6F3C4440EF552B137EAF4C40
44041	1	7	690	27310	32204	\N	57.433945999999999	Костромская область, Нерехтский район, с. Владычное, ул. Фролова, 6		0101000020E61000000F7D772B4B884440711DE38A8BB74C40
44043	1	7	690	27399	32589	\N	57.543613000000001	Костромская область, Нерехтский район, д. Бабаево, ул. Полевая, 20		0101000020E6100000E316F373435B444019575C1C95C54C40
44040	1	7	690	27247	32372	\N	57.360264000000001	Костромская область, Нерехтский район, с. Арменки, ул. Школьная, 8		0101000020E61000007D0569C6A27744408CF678211DAE4C40
44018	1	7	679	26230	32531	\N	58.183624999999999	Костромская область, Нейский район, село Солтаново, ул. Центральная, д. 2		0101000020E6100000A0FCDD3B6AE245402FDD240681174D40
38205	1	6	\N	40	35483	\N	54.503118999999998	г. Калуга, Ленинский округ, ул. Кутузова, д.22		0101000020E6100000CDCB61F71D214240847F113466404B40
44016	1	7	679	26152	32278	\N	58.306221000000001	Костромская область, Нейский район, поселок Номжа, ул. Молодежная, д. 9		0101000020E6100000E7E26F7B82CA4540992CEE3F32274D40
44015	1	7	679	26129	32425	\N	58.384520000000002	Костромская область, Нейский район, село Михали, ул. Советская, д. 7		0101000020E6100000D427B9C32604464037548CF337314D40
44013	1	7	679	26061	32584	\N	58.435130000000001	Костромская область, Нейский район, село Кужбал, ул. Советская, д. 33А		0101000020E610000076A4FACE2F10464016C1FF56B2374D40
44019	1	7	679	26299	32316	\N	58.258269801897697	Костромская область, Нейский район, село Коткишево, ул. Центральная, д. 14	Россия, Костромская область, Нейский район, поселок Коткишево	0101000020E61000006BF0BE2A17E24540DBC4C9FD0E214D40
44010	1	7	679	25897	32194	\N	58.302812000000003	Костромская область, Нейский район, поселок Еленский, ул. Советская, д. 22		0101000020E6100000B1E1E995B2DE45400E6B2A8BC2264D40
44017	1	7	679	26207	32529	\N	58.066254000000001	Костромская область, Нейский район, деревня Дьяконово, ул. Советская, д. 2		0101000020E6100000111D024702DB4540569DD5027B084D40
44012	1	7	679	25994	32478	\N	58.638280999999999	Костромская область, Нейский район, село Вожерово, ул. Центральная, д. 1		0101000020E6100000C4279D48300546403F541A31B3514D40
44014	1	7	679	26091	32427	\N	58.315879000000002	Костромская область, Нейский район, поселок Абросимово, ул. Вокзальная, д. 16		0101000020E6100000E3C62DE6E70E4640213F1BB96E284D40
43691	1	7	710	10416	32593	\N	59.01641	Костромская область, Межевской муниципальный район, поселок Центральный, Заречная, 8		0101000020E6100000EF3A1BF2CF884640E7A90EB919824D40
43692	1	7	710	10471	32592	\N	58.814326000000001	Костромская область, Межевской муниципальный район, деревня Середняя, Центральная, 1		0101000020E6100000E31934F44F7C4640292499D53B684D40
43690	1	7	710	10377	32448	\N	58.539413000000003	Костромская область, Межевской муниципальный район, деревня Петушиха, Советская, 3		0101000020E6100000A1BDFA78E8894640C504357C0B454D40
43689	1	7	710	10314	32281	\N	58.776367999999998	Костромская область, Межевской муниципальный район, поселок Первомайский, Марьинская, 13		0101000020E61000000E4C6E14597F464099D4D00660634D40
94326	1	7	710	10270	32257	\N	58.864072999999998	Костромская область, Межевской муниципальный район, с. Никола, ул. Новая д.1а, МОУ Никольская средняя общеобразовательная школа		0101000020E6100000CD599F724C764640A52DAEF1996E4D40
94325	1	7	710	10231	\N	\N	58.769151000000001	"Костромская область, Межевской муниципальный район, д. Козлиха, д.56, Козлихинский филиал МУК ""Георгиевский КДК"""		0101000020E610000044A33B889D874640C5573B8A73624D40
43686	1	7	710	10179	32483	\N	58.733730999999999	Костромская область, Межевской муниципальный район, село Георгиевское, Октябрьская, 43		0101000020E6100000FC6F253B36844640DB87BCE5EA5D4D40
43969	1	7	605	23927	\N	\N	58.134163999999998	Костромская область, Мантуровский район, деревня Угоры	Россия, Костромская область, Мантуровский район, поселок Угоры	0101000020E6100000B74604E3E02E4640782634492C114D40
43977	1	7	605	24350	\N	\N	58.247928999999999	Костромская область, Мантуровский район, деревня Самылово	Россия, Костромская область, Мантуровский район, поселок Самылово	0101000020E610000096E7C1DD59554640705D3123BC1F4D40
43968	1	7	605	23909	\N	\N	58.373317999999998	Костромская область, Мантуровский район, деревня Рогово	Россия, Костромская область, Мантуровский район, поселок Рогово	0101000020E6100000DE03745FCE4E46400A815CE2C82F4D40
43972	1	7	605	24084	\N	\N	58.452824999999997	Костромская область, Мантуровский район, деревня Подвигалиха	Россия, Костромская область, Мантуровский район, поселок Подвигалиха	0101000020E6100000D80DDB1665624640D5E76A2BF6394D40
94346	1	7	605	23852	32322	\N	58.318573999999998	Костромская область, Мантуровский район, п.Октябрьский, ул.Горького, д.14, здание МОУ Октябрьская СОШ		0101000020E6100000F5D6C056092A46408EAD6708C7284D40
94347	1	7	605	53325	32606	\N	58.3439154635414	Костромская область, Мантуровский район, п.Лесобаза, ул.Заречная, здание МОУ Лесобазовская НОШ	Россия, Костромская область, Мантуровский район, поселок Лесобазы	0101000020E610000005FA449E246946404BCD1E68052C4D40
43966	1	7	605	23792	\N	\N	58.173710999999997	Костромская область, Мантуровский район, деревня Леонтьево	Россия, Костромская область, Мантуровский район, поселок Леонтьево	0101000020E6100000187959130B4046404CFA7B293C164D40
43978	1	7	605	24391	\N	\N	58.204201789009602	Костромская область, Мантуровский район, поселок Карьково	Россия, Костромская область, Мантуровский район, поселок Карьково	0101000020E61000003FE603029D5146408FE3874A231A4D40
43970	1	7	605	24006	\N	\N	58.389775	Костромская область, Мантуровский район, деревня Знаменка	Россия, Костромская область, Мантуровский район, поселок Знаменка	0101000020E6100000B328ECA2E86B464032E6AE25E4314D40
43976	1	7	605	24286	\N	\N	58.305889999999998	Костромская область, Мантуровский район, деревня Ефимово	Россия, Костромская область, Мантуровский район, поселок Ефимово	0101000020E610000028D6A9F23D5F464033164D6727274D40
94348	1	7	605	33159	\N	\N	58.538887000000003	Костромская область, Мантуровский район, д.Елизарово, здание МОУ Елизаровская ООШ		0101000020E610000080B56AD784684640AA9ECC3FFA444D40
43973	1	7	605	24149	\N	\N	58.524383999999998	Костромская область, Мантуровский район, деревня Гусево	Россия, Костромская область, Мантуровский район, поселок Гусево	0101000020E61000002B6C06B8205B4640D845D1031F434D40
43987	1	7	7280	53352	32513	\N	58.340918296960901	Костромская область,  город Мантурово, ул.Советская, д.57	Россия, Костромская область, Мантурово городской округ	0101000020E610000056D3F544D7634640124F7633A32B4D40
38630	1	6	1649	49457	35625	\N	53.430587000000003	деревня Авдеевка, пер.Березовый, д.1		0101000020E610000010E6762FF75D4140988A8D791DB74A40
43986	1	7	7280	53352	32522	\N	58.318559046467001	Костромская область, Мантуровский район, Мантурово город, Больничная, 2	Россия, Костромская область, Мантурово городской округ	0101000020E6100000BFD18E1B7E614640596C938AC6284D40
43955	1	7	1697	23284	\N	\N	57.849958000000001	Костромская область, Макарьевский район, д. Якимово, д. 52		0101000020E6100000D8F2CAF5B6D145409E7C7A6CCBEC4C40
43959	1	7	1697	23489	\N	\N	57.505491999999997	Костромская область, Макарьевский район, с. Юрово, д. 227		0101000020E6100000A662635E47EA4540DF313CF6B3C04C40
43957	1	7	1697	23393	\N	\N	57.797283999999998	Костромская область, Макарьевский район, д. Юркино, д. 158		0101000020E6100000EDD5C743DFD74540E1CFF0660DE64C40
43948	1	7	1697	22963	\N	\N	58.072265999999999	Костромская область, Макарьевский район, д. Шемятино, д. 95		0101000020E6100000E0D57267261046406E4E250340094D40
43949	1	7	1697	23018	32457	\N	58.019213000000001	Костромская область, Макарьевский район, с. Унжа, ул. Советская, д.8		0101000020E61000009F73B7EBA50146403B54539275024D40
43950	1	7	1697	23046	\N	\N	57.832866000000003	Костромская область, Макарьевский район, д. Тимошино, д. 79		0101000020E6100000668522DDCF354640A5F9635A9BEA4C40
43953	1	7	1697	23217	\N	\N	57.984330999999997	Костромская область, Макарьевский район, д. Стариково, д. 3		0101000020E610000060CB2BD7DBD2454030B8E68EFEFD4C40
43964	1	7	1697	23704	\N	\N	57.578812999999997	Костромская область, Макарьевский район, д. Соловатово, д. 59 а		0101000020E61000004BB0389CF9B94540F4BF5C8B16CA4C40
43961	1	7	1697	23575	32414	\N	57.651595999999998	Костромская область, Макарьевский район, п. Первомайка, ул. Ленина, д.2		0101000020E6100000AEF36F97FDD445402A1A6B7F67D34C40
43947	1	7	1697	22937	\N	\N	58.093730000000001	Костромская область, Макарьевский район, д. Никулино, д. 30		0101000020E610000016C09481031E4640B9533A58FF0B4D40
43962	1	7	1697	23620	32393	\N	57.643360000000001	Костромская область, Макарьевский район, д. Николо-Макарово, ул. Коммунистическая, д.1		0101000020E61000007959130B7CC74540FCC6D79E59D24C40
43965	1	7	1697	23770	32559	\N	57.479193000000002	Костромская область, Макарьевский район, с. Нежитино, ул. Центральная, д. 65		0101000020E6100000CD3D247CEFA545406FBC3B3256BD4C40
43943	1	7	1697	22592	32376	\N	57.878637424413299	Костромская область, Макарьевский район, г. Макарьев, пл. Революции, д. 13	Россия, Костромская область, Макарьевский район, Макарьев	0101000020E6100000A9DDAF027CE745401C075E2D77F04C40
43941	1	7	1697	22592	32254	\N	57.880229	Костромская область, Макарьевский район, г. Макарьев, ул. Юрьевецкая, д. 25		0101000020E6100000FA42C879FFE54540D2FE0758ABF04C40
43945	1	7	1697	22592	32415	\N	57.880229	Костромская область, Макарьевский район, г. Макарьев, ул. М. Советская, д. 9		0101000020E6100000FA42C879FFE54540D2FE0758ABF04C40
43940	1	7	1697	22592	32554	\N	57.880229	Костромская область, Макарьевский район, г. Макарьев, ул. Дорожная, д. 1		0101000020E6100000FA42C879FFE54540D2FE0758ABF04C40
43939	1	7	1697	22592	32515	\N	57.880229	Костромская область, Макарьевский район, г. Макарьев, ул. Ветлужская, д.34		0101000020E6100000FA42C879FFE54540D2FE0758ABF04C40
43954	1	7	1697	23238	\N	\N	57.933728000000002	Костромская область, Макарьевский район,  п. Лопаты, ул. Молодежная, д. 10	Россия, Костромская область, Макарьевский район, поселок Лопаты	0101000020E6100000F224E99AC9CF454004AE2B6684F74C40
43952	1	7	1697	53355	\N	\N	57.801254999999998	Костромская область, Макарьевский район, д. Лопалово, д.1		0101000020E61000007AABAE4335054640D4601A868FE64C40
43944	1	7	1697	53320	\N	\N	57.851567756823499	Костромская область, Макарьевский район, п. Комсомолка	Россия, Костромская область, Макарьевский район, поселок Комсомольский	0101000020E6100000793F6EBF7CEE4540FA28232E00ED4C40
43951	1	7	1697	23123	\N	\N	57.914504000000001	Костромская область, Макарьевский район, д. Ильинское, д. 38		0101000020E61000008A3BDEE4B7EE4540D50792770EF54C40
43956	1	7	1697	23326	\N	\N	57.837820000000001	Костромская область, Макарьевский район, д. Заречье, д. 21		0101000020E6100000261DE56036DB4540A5F78DAF3DEB4C40
94344	1	7	1697	23409	32255	\N	57.748558000000003	Костромская область, Макарьевский район, д.Ефино, ул. Культурный центр, д.5  МУ Ефинский культурно-досуговый центр		0101000020E610000048C2BE9D44D645406094A0BFD0DF4C40
43963	1	7	1697	23680	32151	\N	57.594434	Костромская область, Макарьевский район, п. Дорогиня, ул. Горького, д. 1 а		0101000020E61000000A68226C78C64540B3D0CE6916CC4C40
94345	1	7	1697	23511	32289	\N	57.706484000000003	Костромская область, Макарьевский район, п. Горчуха, ул. 20 Партсъезда, д.9, МОУ Горчухинская средняя общеобразовательная школа		0101000020E6100000B22C98F8A3DC4540DA9255116EDA4C40
43946	1	7	1697	22872	\N	\N	58.036093000000001	Костромская область, Макарьевский район, п. Выгорки, д. 43		0101000020E61000005648F949B5214640A94E07B29E044D40
43921	1	7	1670	21744	32465	\N	57.552731000000001	Костромская область, Красносельский район, д. Шолохово Адрес помещения для голосования:: ул. Центральная, д.1, Адрес УИК: Зеленая, 11		0101000020E6100000AF95D05D129B4440213EB0E3BFC64C40
43926	1	7	1670	21987	32518	\N	57.672308000000001	Костромская область, Красносельский район, д. Ченцы Адрес помещения для голосования:: ул. Молодежная, д.5, Адрес УИК: Молодежная, 13		0101000020E6100000D2393FC571A844406A6B44300ED64C40
94343	1	7	1670	33158	\N	\N	57.622568000000001	Костромская область, Красносельский район, д.Харитоново д.44, Харитоновская начальная школа		0101000020E6100000266E15C4409D4440A0C4E74EB0CF4C40
43938	1	7	1670	22516	\N	\N	57.606090999999999	Костромская область, Красносельский район, д. Халипино, 1	Россия, Костромская область, Красносельский район, поселок Халипино	0101000020E610000040A374E95F96444031B3CF6394CD4C40
43918	1	7	1670	21574	\N	\N	57.488070999999998	Костромская область, Красносельский район,  д. Сухара, 31		0101000020E61000002461DF4E22B8444021904B1C79BE4C40
43922	1	7	1670	21813	32290	\N	57.576008999999999	Костромская область, Красносельский район, д. Сопырево, Речная, 2		0101000020E6100000008FA850DDAC4440D099B4A9BAC94C40
43928	1	7	1670	22073	32228	\N	57.691285000000001	Костромская область, Красносельский район,  д. Синцово, Центральная, 11 а		0101000020E6100000552FBFD364BE4440919BE1067CD84C40
43936	1	7	1670	22430	32413	\N	57.451340000000002	Костромская область, Красносельский район, с. Сидоровское, пл. Сыромятникова, 13		0101000020E610000078EFA831219C444036B05582C5B94C40
43935	1	7	1670	22403	\N	\N	57.444403999999999	Костромская область, Красносельский район, с. Светочева Гора, 56		0101000020E61000001807978E39AB4440151BF33AE2B84C40
43933	1	7	1670	22302	32347	\N	57.500680000000003	Костромская область, Красносельский район, с. Подольское, Центральная, 29		0101000020E6100000EACF7EA488AA444072E1404816C04C40
94342	1	7	1670	26611	32542	\N	57.513319000000003	Костромская область, Красносельский муниципальный район, п.Красное-на Волге ул. Советская, д.45, помещение Детской Художественной Школы		0101000020E6100000404B57B08D9E44402DB5DE6FB4C14C40
44026	1	7	1670	26611	32275	\N	57.513319000000003	Красносельский центр социального обслуживания населения, пос. Красное-на-Волге, ул. Луначарского, д.4		0101000020E6100000404B57B08D9E44402DB5DE6FB4C14C40
94341	1	7	1670	26611	32419	\N	57.513319000000003	"Костромская область, Красносельский муниципальный район, п.Красное-на Волге ул. Ленина, д. 9 Молодёжный Центр ""Волга"""		0101000020E6100000404B57B08D9E44402DB5DE6FB4C14C40
43920	1	7	1670	26611	32419	\N	57.514104425309696	Костромская область, Красносельский муниципальный район, городское поселение поселок Красное-на-Волге, Ленина, 44 а	Россия, Костромская область, Красносельский район, поселок Красное-на-Волге	0101000020E6100000C87C40A0339F4440145FED28CEC14C40
43927	1	7	1670	22041	32602	\N	57.647019999999998	Костромская область, Красносельский район, п. им. Чапаева, Советская, 13		0101000020E6100000DC4944F817B14440D0ED258DD1D24C40
43934	1	7	1670	22370	\N	\N	57.515596000000002	Костромская область, Красносельский район, с. Здемирово, 117		0101000020E61000009C33A2B437A4444066F9BA0CFFC14C40
43929	1	7	1670	22150	\N	\N	57.574961999999999	Костромская область, Красносельский район, д. Захарово, 73		0101000020E6100000F2ED5D83BEBA4440AC38D55A98C94C40
43937	1	7	1670	22496	\N	\N	57.509900999999999	Костромская область, Красносельский район, с. Густомесово, 166		0101000020E61000001329CDE6719044404E999B6F44C14C40
43925	1	7	1670	21927	32295	\N	57.715124000000003	Костромская область, Красносельский район, д. Гридино, Центральная, 9		0101000020E6100000D93D7958A8934440D84AE82E89DB4C40
43932	1	7	1670	53356	32535	\N	57.468846359061999	Костромская область, Красносельский район, п. Гравийный Карьер Адрес помещения для голосования:: ул. Нагорная , д.3, Адрес УИК: Новая, 50	Россия, Костромская область, Красносельский район, поселок Гравкарьера	0101000020E61000006F47382D78C34440226E4E2503BC4C40
43931	1	7	1670	22224	32595	\N	57.534038000000002	Костромская область, Красносельский район, д. Веселово, Центральная, 13		0101000020E6100000A0FCDD3B6ABC44401F69705B5BC44C40
43924	1	7	1670	21907	32549	\N	57.650497999999999	Костромская область, Красносельский район, д. Боровиково, Центральная, 64		0101000020E61000004089CF9D60914440840EBA8443D34C40
43930	1	7	1670	22172	\N	\N	57.590986000000001	Костромская область, Красносельский район, д. Афанасово, 92		0101000020E610000086C8E9EBF9C644406A32E36DA5CB4C40
43798	1	7	197	53331	\N	\N	57.769932668178399	Костромская область, Костромской район, п.Паточного завода, 27	Россия, Костромская область, Костромской район, поселок Борщино	0101000020E610000054E6E61BD15944403B8E1F2A8DE24C40
43794	1	7	197	15276	32409	\N	57.819052999999997	Костромская область, Костромской муниципальный район, с. Яковлевское, Просвещения, 27		0101000020E6100000EB556474406A444068588CBAD6E84C40
43812	1	7	197	16140	\N	\N	57.800843391931998	"Костромская область, Костромской район, д.Щетниково, ФСК ""Ника"""		0101000020E610000088653387A4844440821DFF0582E64C40
43826	1	7	197	16837	32348	\N	57.810090701479297	Костромская область, Костромской район, с.Шунга, Юбилейная, 10А	Россия, Костромская область, Костромской район, поселок Шунга	0101000020E6100000EFA83121E666444058E4D70FB1E74C40
43815	1	7	197	16282	32523	\N	57.901833000000003	Костромская область, Костромской район, п.Шувалово, Победы, 63		0101000020E610000068EA758BC08444400FBA84436FF34C40
43811	1	7	197	16096	32238	\N	57.787008999999998	Костромская область, Костромской район, п.Фанерник, Геофизиков, 24А		0101000020E6100000E8A221E3518444402E54FEB5BCE44C40
43819	1	7	197	16495	\N	\N	57.651479999999999	"Костромская область, Костромской район, п.Тихий уголок, Клуб санотория ""Волга"""		0101000020E6100000849D62D520824440C1FF56B263D34C40
94338	1	7	197	16164	32441	\N	57.922583000000003	Костромская область, Костромской район, с. Сущево,ул. Советская, д. 18Б, МОУ Сущевская средняя школа		0101000020E6100000C0CE4D9B717A44403C6C223317F64C40
43824	1	7	197	16757	32267	\N	57.586956999999998	Костромская область, Костромской район, п.Сухоногово, Советская, 4		0101000020E6100000E2033BFE0B86444042942F6821CB4C40
43821	1	7	197	16598	32573	\N	57.705233	Костромская область, Костромской район, дер. Середняя, Кузьмина, 13		0101000020E61000005EA10F96B17B4440AD872F1345DA4C40
43825	1	7	197	16813	32155	\N	57.805965	Костромская область, Костромской муниципальный район, с. Саметь, Малининой, 6		0101000020E6100000793E03EACD5C44403E5C72DC29E74C40
43816	1	7	197	16316	32564	\N	57.893492000000002	Костромская область, Костромской район, п.Прибрежный, Набережная, 5		0101000020E6100000E5805D4D9E7044406B9E23F25DF24C40
43808	1	7	197	15935	\N	\N	57.832847000000001	Костромская область, Костромской район, с.Петрилово, 35		0101000020E6100000B34291EEE75444402EC901BB9AEA4C40
43818	1	7	197	16420	32420	\N	57.669823999999998	Костромская область, Костромской район, д.Обломихино, Нерехтская, 7		0101000020E610000042B115342D694440B709F7CABCD54C40
43810	1	7	197	16028	32524	\N	57.815755000000003	Костромская область, Костромской район, п.Никольское, Школьная, 2		0101000020E6100000B2463D44A38F44403546EBA86AE84C40
94323	1	7	197	16028	32182	\N	57.814472440386702	Костромская область, Костромской район, п.Никольское, Зеленая, 1	Россия, Костромская область, Костромской район, поселок Никольское	0101000020E6100000B1DEA815A68F4440FDC0559E40E84C40
94339	1	7	197	33157	32439	\N	58.092202999999998	Костромская область, Костромской район, п.Мисково, ул.Некрасова, д.13а, Дом культуры		0101000020E6100000CC5EB69DB6884440EACBD24ECD0B4D40
43806	1	7	197	15825	32576	\N	57.693094000000002	Костромская область, Костромской район, с.Минское, Куколевского, 16		0101000020E61000000ABC934F8F834440E486DF4DB7D84C40
94337	1	7	197	15789	32375	\N	57.877377000000003	Костромская область, Костромской район, д. Кузьмищи,ул. Зеленая, д. 14, МОУ Кузьмищенская СОШ		0101000020E6100000CAE2FE23D39144409DA1B8E34DF04C40
43504	1	7	197	749	\N	\N	57.942369999999997	Костромская область, Костромской район, с.Кузнецово, 47		0101000020E61000008FAA2688BA9F4440A25D85949FF84C40
43814	1	7	197	16243	32224	\N	57.971656000000003	Костромская область, Костромской район, д.Крутик, Новая, 41		0101000020E61000000EF8FC3042804440297B4B395FFC4C40
43796	1	7	197	15386	\N	\N	57.739407	Костромская область, Костромской район, д.Коряково, 11		0101000020E61000007F69519FE46644407CB779E3A4DE4C40
43800	1	7	197	15521	32355	\N	57.737605000000002	Костромская область, Костромской район, п.Караваево, Штеймана, 58А		0101000020E610000009FF2268CC884440DC2E34D769DE4C40
43799	1	7	197	15521	32355	\N	57.737605000000002	Костромская область, Костромской район, п.Караваево, Штеймана, 1А		0101000020E610000009FF2268CC884440DC2E34D769DE4C40
43801	1	7	197	15521	32188	\N	57.737605000000002	Костромская область, Костромской район, п.Караваево, Учебный городок, 34		0101000020E610000009FF2268CC884440DC2E34D769DE4C40
43817	1	7	197	16395	32299	\N	57.649534000000003	Костромская область, Костромской район, с.Ильинское, Почтовая, 1		0101000020E6100000317DAF2138764440EED11BEE23D34C40
43797	1	7	197	15422	32428	\N	57.718243000000001	Костромская область, Костромской район, п.Зарубино, Центральная, 2		0101000020E6100000790778D2C25D44405CCAF962EFDB4C40
43807	1	7	197	15900	32579	\N	57.775910000000003	Костромская область, Костромской район, п.Губачево, Новая, 27		0101000020E6100000EA03C93B87884440D751D50451E34C40
43802	1	7	197	15652	32574	\N	58.019699000000003	Костромская область, Костромской район, п.Василево, переулок Школьный, 11		0101000020E61000005A47551344A14440C861307F85024D40
43803	1	7	197	15695	\N	\N	57.951326000000002	Костромская область, Костромской район, д.Бычиха, 68		0101000020E6100000AE65321CCF8F4440D1EAE40CC5F94C40
43822	1	7	197	16656	32311	\N	58.194512000000003	Костромская область, Костромской район, с.Сандогора, Центральная, 4		0101000020E6100000E146CA16497B4440FC56EBC4E5184D40
43792	1	7	197	15165	32346	\N	57.802354000000001	Костромская область, Костромской муниципальный район, д. Аферово, 1 Мая, 19		0101000020E610000043588D25AC6D44404BE82E89B3E64C40
43793	1	7	197	15218	32512	\N	57.841566	Костромская область, Костромской район, п.Апраксино, Молодежная, 4		0101000020E6100000D05FE811A37D444078B6476FB8EB4C40
94336	1	7	1137	14885	32351	\N	58.941384999999997	"Костромская область, Кологривский район, поселок Ужуга, ул. Дорожная, д.8б, администрация Ужугского сельского поселения "		0101000020E61000000B09185DDE164640F4F8BD4D7F784D40
94335	1	7	1137	14855	32253	\N	58.816795999999997	Костромская область, Кологривский район, д. Суховерхово, ул. 60 лет Октября, д.8, администрация Суховерховского сельского поселения		0101000020E61000005C5837DE1D23464076C075C58C684D40
43775	1	7	1137	14362	\N	\N	58.833781000000002	Костромская область, Кологривский район, деревня Судилово, Судиловский сельский клуб		0101000020E6100000E78C28ED0D2C46405A83F755B96A4D40
94327	1	7	1137	10537	32623	\N	58.917344999999997	Костромская область, Межевской муниципальный район, п. Советский, ул. Набережная, д.6, МОУ Советская основная общеобразовательная школа	Россия, Костромская область, Кологривский район, поселок Советский	0101000020E6100000D270CADC7C4B464016139B8F6B754D40
43791	1	7	1137	15128	\N	\N	59.046505000000003	Костромская область, Кологривский район, поселок Октябрьский, Октябрьский сельский клуб-библиотека	Россия, Костромская область, Кологривский район, поселок Октябрьский	0101000020E6100000A56950340F044640DD0C37E0F3854D40
43781	1	7	1137	53360	\N	\N	58.948309077007103	"Костромская область, Кологривский район, деревня Овсяниково, адрес помещения для голосования: МОУ ""Илешевская средняя общеобразовательная школа"", адрес УИК: администрация Илешевского сельского поселения"	Россия, Костромская область, Кологривский район, поселок Овсянниково	0101000020E61000006C41EF8D210E464051C0763062794D40
94334	1	7	1137	14729	32186	\N	58.779116000000002	Костромская область, Кологривский район, ул. Центральная, д.1, Маракинский сельский клуб, дер.Маракино		0101000020E610000055C03DCF9F4446402AE5B512BA634D40
94333	1	7	1137	53358	\N	\N	58.912098999999998	Костромская область, Кологривский район, д. Лисицино, д.33, Филиал МУ «Суховерховский дом культуры» Лисицинский клуб-библиотека		0101000020E61000007380608E1E1146406EDBF7A8BF744D40
94332	1	7	1137	14601	32402	\N	59.039501000000001	Костромская область, Кологривский район, п. Колохта, ул. Набережная, д. 14а, МОУ «Колохтская основная общеобразовательная школа»		0101000020E6100000BCC96FD1C90A46406494675E0E854D40
43774	1	7	1137	14309	32461	\N	58.827948915808697	Костромская область, Кологривский район, город Кологрив, адрес помещения для голосования: улица Набережная речки Киченки, д. 11, адрес УИК: улица Центральная, д.13		0101000020E61000005D50DF32A7274640C1E09A3BFA694D40
43787	1	7	1137	14309	32567	\N	58.821928817291102	Костромская область, Кологривский муниципальный район, город Кологрив, адрес помещения для голосования: улица Набережная реки Унжи, д. 10, адрес УИК: улица Центральная, д.13		0101000020E61000004432E4D87A28464026512FF834694D40
94331	1	7	1137	14532	\N	\N	58.767961	Костромская область, Кологривский район, с. Ильинское, д.99, МОУ «Ильинская средняя общеобразовательная школа»		0101000020E610000058207A52264B46403ECDC98B4C624D40
43784	1	7	1137	14802	\N	\N	59.140780999999997	Костромская область, Кологривский район, поселок Даравка, бывшая администрация Понговского сельского поселения		0101000020E6100000D74CBED9E6E04540F7729F1C05924D40
43778	1	7	1137	14512	\N	\N	58.623795999999999	Костромская область, Кологривский район, деревня Высоково, Высоковский клуб-библиотека		0101000020E6100000AD4CF8A57E58464014B01D8CD84F4D40
43777	1	7	1137	14466	\N	\N	58.732619	Костромская область, Кологривский район, поселок Воймас, Воймасский сельский клуб		0101000020E6100000F4A44C6A68534640D0B69A75C65D4D40
43789	1	7	1137	15012	\N	\N	58.841968000000001	Костромская область, Кологривский район, поселок Верхняя Унжа, филиал Костромского строительного техникума № 6		0101000020E61000007A8F334DD8244640A723809BC56B4D40
43776	1	7	1137	14396	\N	\N	58.885300000000001	Костромская область, Кологривский район, поселок Варзенга, Варзенгский сельский клуб-библиотека		0101000020E610000015E126A3CA1646400C93A98251714D40
94330	1	7	1137	14276	\N	\N	58.717356000000002	Костромская область, Кологривский район, д. Большая Чёжма, филиал МУ «Суховерховский дом культуры» Чёжемский клуб-библиотека		0101000020E610000044F98216123C464071CB4752D25B4D40
43766	1	7	1272	13931	32403	\N	57.539713999999996	Костромская область, Кадыйский район, с.Чернышево, адрес помещения для голосования: ул.Советская д.11, адрес УИК: Центральная, б/н		0101000020E610000090BFB4A84F924540BF982D5915C54C40
43765	1	7	1272	13896	32146	\N	57.640031	Костромская область, Кадыйский район, п.Текун, Клубная, 12		0101000020E61000005D8AABCABE9745408DB62A89ECD14C40
43771	1	7	1272	14181	32341	\N	57.380709778332601	Костромская область, Кадыйский район, с.Столпино, Набережная, 1	Россия, Костромская область, Кадыйский район, поселок Столпино	0101000020E610000006483481227045404DA1F31ABBB04C40
43760	1	7	1272	53368	32674	\N	57.807004999999997	Костромская область, Кадыйский район, д.Селище, Советская, 25	Россия, Костромская область, Кадыйский район, поселок Селище	0101000020E6100000043C69E1B2A24540AF5A99F04BE74C40
43763	1	7	1272	13790	32176	\N	57.719157000000003	Костромская область, Кадыйский район, д.Паньково, адрес помещения для голосования: ул.Садиковская, д.4А, адрес УИК: Центральная, 33А		0101000020E6100000684128EFE39E454041D829560DDC4C40
43772	1	7	1272	14215	32401	\N	57.464348999999999	Костромская область, Кадыйский район, п.Новый Курдюм, Советская, 16		0101000020E6100000029EB470596D45401477BCC96FBB4C40
43755	1	7	1272	13418	32265	\N	58.001061	Костромская область, Кадыйский район, с.Низкусь, Школьная, 1		0101000020E610000091EEE714E4834540892650C422004D40
43761	1	7	1272	13689	32505	\N	57.844358999999997	Костромская область, Кадыйский район, д.Марьино, Лесная, 4А		0101000020E610000066118AADA0A94540A88AA9F413EC4C40
43768	1	7	1272	14021	\N	\N	57.473381000000003	Костромская область, Кадыйский район, д.Лубяны, б/у, 26		0101000020E61000004D486B0C3A9745401EC6A4BF97BC4C40
43757	1	7	1272	13512	32557	\N	57.806828000000003	Костромская область, Кадыйский район, д.Котлово, Советская, 10А		0101000020E610000014AE47E17A724540A1BFD02346E74C40
43759	1	7	1272	13331	32336	\N	57.780241675672698	Костромская область, Кадыйский район, п. Кадый, Центральная, 17	Россия, Костромская область, Кадыйский район, поселок Кадый	0101000020E61000007976F9D6879745409A7B48F8DEE34C40
43753	1	7	1272	13331	32336	\N	57.779877382415499	Костромская область, Кадыйский район, п.Кадый, Центральная, 5	Россия, Костромская область, Кадыйский район, поселок Кадый	0101000020E610000068E90AB61197454088F37002D3E34C40
43756	1	7	1272	13449	\N	\N	57.978763000000001	Костромская область, Кадыйский район, д.Иваньково, б/у, 64		0101000020E6100000CA1B60E63B98454076C4211B48FD4C40
43769	1	7	1272	14086	32248	\N	57.412433	Костромская область, Кадыйский район, с.Завражье, адрес помещения для голосования: ул. Школьная д. 8, адрес УИК: Садовая, 1		0101000020E61000007BBB2539609345404565C39ACAB44C40
43758	1	7	1272	13554	32394	\N	57.930593000000002	Костромская область, Кадыйский район, д.Екатеринкино, Центральная, 8		0101000020E610000061527C7C429645407A71E2AB1DF74C40
43762	1	7	1272	13735	32245	\N	57.744335999999997	Костромская оласть, Кадыйский район, п. Дубки, Полевая, 21		0101000020E6100000CB2C42B115A24540239EEC6646DF4C40
43754	1	7	1272	13364	32395	\N	57.798530999999997	Костромская область, Кадыйский район, п.Вешка, адрес помещения для голосования: ул.Островская, д. 1А, адрес УИК: Островская, 1А		0101000020E6100000992EC4EA8F804540CCEB884336E64C40
43752	1	7	1272	13264	\N	\N	57.518935999999997	Костромская область, Кадыйский район, д.Ведрово, б/у, б/н		0101000020E6100000DF15C1FF566C4540C85BAE7E6CC24C40
43770	1	7	1272	14115	\N	\N	57.404738999999999	Костромская область, Кадыйский район, с.Борисоглебское, б/у, 45А		0101000020E6100000C03E3A75E58545403735D07CCEB34C40
43729	1	7	444	12225	32175	\N	58.368626999999996	Костромская область, Галичский район, деревня Чёлсма, улица Центральная, дом 27а		0101000020E6100000C45C52B5DD22454017B6662B2F2F4D40
43736	1	7	444	12575	32333	\N	58.475503000000003	Костромская область, Галичский район, село Унорож, улица Центральная, дом 16		0101000020E6100000FC89CA86350B454030134548DD3C4D40
43728	1	7	444	12164	32492	\N	58.181522999999999	Костромская область, Галичский район, село Углево, улица Школьная, дом 12		0101000020E61000009FE3A3C5190D4540643C4A253C174D40
43740	1	7	444	12736	\N	\N	58.441988000000002	Костромская область, Галичский район, деревня Толтуново, помещение административного здания Степановского с/п, дом 10		0101000020E610000040BE840A0E274540BB9C121093384D40
43737	1	7	444	12615	32571	\N	58.455281999999997	Костромская область, Галичский район, деревня Степаново, улица Советская, дом 3		0101000020E61000006A696E85B04045408E3A3AAE463A4D40
43734	1	7	444	12421	32390	\N	58.437249999999999	Костромская область, Галичский район, поселок Россолово, улица Кооперативная, дом 9		0101000020E6100000F14A92E7FA0045408716D9CEF7374D40
43733	1	7	444	12421	32566	\N	58.437249999999999	Костромская область, Галичский район, поселок Россолово, улица Зеленая, дом 27		0101000020E6100000F14A92E7FA0045408716D9CEF7374D40
43726	1	7	444	12070	32569	\N	58.198368000000002	Костромская область, Галичский район, деревня Пронино, улица Центральная, дом 19а		0101000020E61000000B28D4D3471845405649641F64194D40
43732	1	7	444	12385	32494	\N	58.453780000000002	Костромская область, Галичский район, село Орехово, улица 1-Мая, дом 32		0101000020E610000070EA03C93BFF444019CA8976153A4D40
43741	1	7	444	12785	\N	\N	58.525196999999999	Костромская область, Галичский район, село Олешь, помещение Олешского ФАП, дом 21		0101000020E6100000054F2157EA254540897AC1A739434D40
43730	1	7	444	12294	32331	\N	58.391793999999997	Костромская область, Галичский район, село Нагатино, улица Молодежная, дом 7		0101000020E6100000BA84436FF10C45406F62484E26324D40
43723	1	7	444	11904	32389	\N	58.377513	Костромская область, Галичский район, село Михайловское, улица Центральная, дом 9		0101000020E61000009ECF807A333445404D68925852304D40
43727	1	7	444	12148	32491	\N	58.148229999999998	Костромская область, Галичский район, село Митино, улица Молодежная, дом 1		0101000020E6100000ADC3D155BA1545409E245D33F9124D40
43738	1	7	444	12649	\N	\N	58.437418999999998	Костромская область, Галичский район, деревня Мелешино, помещение МУК Мелёшинского сельского клуба, дом 17		0101000020E610000022DE3AFF7645454013D38558FD374D40
43722	1	7	444	11869	32226	\N	58.295074	Костромская область, Галичский район, деревня Малышево, улица Школьная, дом 10		0101000020E61000000856D5CBEF2A454030F31DFCC4254D40
43731	1	7	444	12303	32601	\N	58.339053	Костромская область, Галичский район, поселок Лопарево, улица Совхозная, дом 8		0101000020E610000054008C67D05445402B4EB516662B4D40
43719	1	7	444	11735	32385	\N	58.591872000000002	Костромская область, Галичский район, деревня Ладыгино, улица Ленина, дом 1-а		0101000020E6100000BB4560AC6F16454085B53176C24B4D40
43739	1	7	444	12716	32302	\N	58.576777	Костромская область, Галичский район, поселок Курьяново, улица Комсомольская, дом 6		0101000020E6100000BC04A73E904E4540E10A28D4D3494D40
43724	1	7	444	11970	32171	\N	58.351427999999999	Костромская область, Галичский район, село Красильниково, улица Школьная, дом 21		0101000020E61000003FC571E0D54645400873BB97FB2C4D40
43735	1	7	444	12528	32495	\N	58.327784999999999	Костромская область, Галичский район, село Костома, улица Молодежная, дом 18		0101000020E610000027A25F5B3FF34440478FDFDBF4294D40
43725	1	7	444	53362	32662	\N	58.426484000000002	Костромская область, Галичский район, село Кабаново, улица Центральная, дом 12		0101000020E6100000344A97FE25E945403622180797364D40
43721	1	7	444	11817	32565	\N	58.340031000000003	Костромская область, Галичский район, деревня Дмитриевское, улица Центральная, дом 14		0101000020E610000032384A5E9D2D45402750C422862B4D40
43747	1	7	444	5814	\N	\N	58.386822000000002	Костромская область, город Галич, улица Леднева, 2	Россия, Костромская область, Галичский район, Галич	0101000020E6100000487023658B304540C9AF1F6283314D40
43744	1	7	444	5814	32499	\N	58.386822000000002	Костромская область, город Галич, улица Пушкина, 6		0101000020E6100000487023658B304540C9AF1F6283314D40
43751	1	7	444	5814	32435	\N	58.386822000000002	Костромская область, город Галич, улица Лисья Гора, 1		0101000020E6100000487023658B304540C9AF1F6283314D40
43748	1	7	444	5814	32294	\N	58.386822000000002	Костромская область, город Галич, улица Лермонтова, 39		0101000020E6100000487023658B304540C9AF1F6283314D40
43742	1	7	444	5814	32392	\N	58.386822000000002	Костромская область, город Галич, улица Заводская Набережная, 2		0101000020E6100000487023658B304540C9AF1F6283314D40
43743	1	7	444	5814	32233	\N	58.386822000000002	Костромская область, город Галич, улица Гладышева, 71		0101000020E6100000487023658B304540C9AF1F6283314D40
43746	1	7	444	5814	32583	\N	58.386822000000002	Костромская область, город Галич, улица Гагарина, 57 а		0101000020E6100000487023658B304540C9AF1F6283314D40
43718	1	7	444	11687	32306	\N	58.632627999999997	Костромская область, Галичский район, село Берёзовец, улица Советская, дом 11		0101000020E6100000D21BEE23B722454056444DF4F9504D40
43705	1	7	7282	53330	32503	\N	58.377865435280903	Костромская область, город Галич, улица Школьная, 7		0101000020E6100000575BB1BFEC2E4540CAA65CE15D304D40
43337	1	7	7282	53330	32603	\N	58.3779531360194	Костромская область, город Галич, улица Советская, 1		0101000020E610000071C971A7742C454069368FC360304D40
43750	1	7	7282	53330	32345	\N	58.378849200380998	Костромская область, город Галич, улица Свободы, 59 а		0101000020E61000002E1B9DF3532C4540A88FC01F7E304D40
43749	1	7	7282	53330	32585	\N	58.379170425438602	Костромская область, город Галич, улица Долматова, 13	Россия, Костромская область, Галич городской округ	0101000020E6100000C092AB58FC2C4540EACF7EA488304D40
44095	1	7	165	29768	32384	\N	58.868647000000003	Костромская область, Павинский муниципальный район,поселок Шайменский, Советская, 7		0101000020E610000095287B4B391D47405F622CD32F6F4D40
43708	1	7	165	11194	32545	\N	58.980172000000003	Костромская область, Вохомский муниципальный район, с. Троица, Набережная, 22		0101000020E61000007FA65EB7086C47403B3AAE46767D4D40
43717	1	7	165	11642	32282	\N	59.376756	Костромская область, Вохомский муниципальный район, с. Тихон, Больничная, 20		0101000020E6100000E3FA777DE65447403049658A39B04D40
43715	1	7	165	11551	32350	\N	59.40428	Костромская область, Вохомский муниципальный район, п. Талица, Строительная, 40		0101000020E6100000255D33F9665D4740A4367172BFB34D40
43712	1	7	165	11419	32450	\N	59.166896999999999	Костромская область, Вохомский муниципальный район, с. Спас, Школьная, 7		0101000020E61000002975C938465C4740776682E15C954D40
43706	1	7	165	11121	\N	\N	58.996358000000001	Костромская область, Вохомский муниципальный район, с. Согра, 14, кор. 2		0101000020E610000050A6D1E462444740D28DB0A8887F4D40
43709	1	7	165	11270	32489	\N	58.989043000000002	Костромская область, Вохомский муниципальный район, д. Поспехово, Школьная, 2		0101000020E61000009DBD33DAAA6247403BAB05F6987E4D40
43710	1	7	165	11285	32514	\N	59.047480999999998	Костромская область, Вохомский муниципальный район, с. Покров, Молодежная, 1		0101000020E61000005E9F39EB534E474037177FDB13864D40
43716	1	7	165	11578	32293	\N	59.325927999999998	Костромская область, Вохомский муниципальный район, п. Песочный, Центральная, 2		0101000020E61000005987A3AB74554740E36C3A02B8A94D40
43703	1	7	165	10989	\N	\N	58.945832000000003	Костромская область, Вохомский муниципальный район, д. Осипино, 23		0101000020E61000005187156EF952474051C1E10511794D40
44159	1	7	165	508	32212	\N	59.046272999999999	Костромская область, Солигаличский район, д. Оглоблино, адрес помещения для голосования: ул. Молодежная, д. 2, адрес УИК: ул. Майская, 1		0101000020E6100000A87004A9145B47400AD80E46EC854D40
43698	1	7	165	10756	32286	\N	58.822969000000001	Костромская область, Вохомский муниципальный район, с. Никола, Школьная, 1		0101000020E6100000D0D4EB1681594740984F560C57694D40
43701	1	7	165	10897	\N	\N	58.774857533449101	Костромская область, Вохомский муниципальный район, д. Марково, 40	Россия, Костромская область, Вохомский район, поселок Марково	0101000020E6100000DCF0BBE9963F4740A185048C2E634D40
43699	1	7	165	10813	32449	\N	58.758837	Костромская область, Вохомский муниципальный район, п. Малое Раменье, Школьная, 3		0101000020E610000036936FB6B947474054FF209221614D40
43707	1	7	165	11172	\N	\N	59.152157000000003	Костромская область, Вохомский муниципальный район, д. Макарята, 51		0101000020E610000038D73043E3514740C26D6DE179934D40
43697	1	7	165	10694	32380	\N	58.878821000000002	д. Латышово, ул. Чичерина, д. 6,  сельский клуб		0101000020E6100000F2EA1C03B2634740DE04DF347D704D40
43713	1	7	165	11437	32157	\N	59.206111999999997	Костромская область, Вохомский муниципальный район, п. Лажборовица, Центральная, 17		0101000020E61000005551BCCADA6E474015A8C5E0619A4D40
43702	1	7	165	10945	32296	\N	58.887754999999999	Костромская область, Вохомский муниципальный район, д. Конница, Новая, 1		0101000020E61000005E0EBBEF1840474024EEB1F4A1714D40
94329	1	7	165	10848	32485	\N	58.784447	Костромская область, Вохомский муниципальный район, с. Заветлужье, ул. Центральная, д. 32, отделение временного проживания		0101000020E610000017450F7C0C264740003961C268644D40
43695	1	7	165	10551	32292	\N	58.931299000000003	Костромская область, Вохомский муниципальный район, п. Вохма, Советская, 72		0101000020E61000006B2A8BC22E60474015E63DCE34774D40
43694	1	7	165	10551	32292	\N	58.931299000000003	Костромская область, Вохомский муниципальный район, п. Вохма, Советская, 37		0101000020E61000006B2A8BC22E60474015E63DCE34774D40
43714	1	7	165	11485	32547	\N	59.232362000000002	Костромская область, Вохомский муниципальный район, п. Воробьевица, Школьная, 17		0101000020E610000085CFD6C1C1584740A56ABB09BE9D4D40
94328	1	7	165	10672	32560	\N	58.939368999999999	Костромская область, Вохомский муниципальный район, п. Бережок, ул. Заводская, д. 15, детский сад		0101000020E6100000454B1E4FCB69474028F04E3E3D784D40
43704	1	7	165	11030	\N	\N	58.93676	Костромская область, Вохомский муниципальный район, д. Андрианово, 13		0101000020E6100000C0417BF5F1444740B9196EC0E7774D40
43711	1	7	6909	40368	\N	\N	59.072646154425797	Костромская область, Вохомский муниципальный район, с. Лапшино, 22	Россия, Костромская область, Вохомский район, поселок Лапшино	0101000020E61000008A027D224F624740B517D1764C894D40
43647	1	7	956	8341	32526	\N	58.653247	Костромская область, Буйский муниципальный район, с. Шушкодом, ул. Центральная, д. 3		0101000020E6100000B0E8D66B7AA64440E59A02999D534D40
43640	1	7	956	53339	32423	\N	58.3669593428559	Костромская область, Буйский муниципальный район, г.п. Чистые Боры, б-р Строителей, д. 2	Россия, Костромская область, Буйский район	0101000020E61000005D15A8C5E0D3444087FC3383F82E4D40
43639	1	7	956	53339	32423	\N	58.362629507515798	Костромская область, Буйский муниципальный район, г.п. Чистые Боры, б-р Строителей, д. 20	Россия, Костромская область, Буйский район, поселок Борок	0101000020E61000002FC214E5D2D044403546EBA86A2E4D40
43637	1	7	956	7855	32264	\N	58.72692	Костромская область, Буйский муниципальный район, пос. Талица, ул. Советская, д. 20		0101000020E61000005A0EF450DBC644407767EDB60B5D4D40
43662	1	7	956	9051	\N	\N	58.679174000000003	Костромская область, Буйский муниципальный район, с. Романцево, д. 52, кв. 8		0101000020E61000001686C8E9EBD744409225732CEF564D40
43643	1	7	956	53361	32614	\N	58.431246999999999	Костромская область, Буйский муниципальный район, р-д Махрово, ул. Железнодорожная, д. 24		0101000020E6100000A4367172BFD74440C2BF081A33374D40
43661	1	7	956	8971	32271	\N	58.347371000000003	Костромская область, Буйский муниципальный район, с. Лужок, ул. Молодежная, д. 10а		0101000020E6100000EED0B01875BF4440174A26A7762C4D40
43660	1	7	956	8942	32534	\N	58.583832999999998	Костромская область, Буйский муниципальный район, с. Ликурга, ул. Троицкая, д. 17		0101000020E61000007313B534B7EA4440ACA92C0ABB4A4D40
43659	1	7	956	8901	\N	\N	58.766714999999998	Костромская область, Буйский муниципальный район, д. Курилово, д. 10		0101000020E6100000276728EE78A94440232D95B723624D40
94324	1	7	956	33156	32430	\N	58.315114000000001	Костромская область, Буйский муниципальный район, д. Куребрино, ул. Клубная, д. 1, Куребринский сельский клуб		0101000020E6100000C554FA09679D44408141D2A755284D40
43658	1	7	956	8820	32366	\N	58.554116	Костромская область, Буйский муниципальный район, д. Кренёво, ул. Почтовая, д. 9		0101000020E6100000CFF9298E03AD44405D18E945ED464D40
43657	1	7	956	8807	32203	\N	58.467987999999998	Костромская область, Буйский муниципальный район, пос. Корёга, ул. Сплавная, д. 25		0101000020E610000061DEE34C13B84440D175E107E73B4D40
38373	1	6	1067	40421	\N	\N	54.326962999999999	д.Плюсково, МБОУ <<Средняя общеобразовательная школа>>		0101000020E61000000684D6C397694240430070ECD9294B40
43656	1	7	956	8764	32500	\N	58.437876000000003	Костромская область, Буйский муниципальный район, с. Контеево, ул. Верхняя, д. 7		0101000020E6100000A9BD88B663B2444006DA1D520C384D40
43645	1	7	956	8240	\N	\N	58.308779000000001	Костромская область, Буйский муниципальный район, д. Ильино, д. 47		0101000020E61000007F32C687D9DF44408658FD1186274D40
43648	1	7	956	8375	32364	\N	58.484136999999997	Костромская область, Буйский муниципальный район, д. Игумново, ул. Черемушки, д. 19, кв. 2		0101000020E6100000DC82A5BA80B744404BE48233F83D4D40
43654	1	7	956	8671	32200	\N	58.713776000000003	Костромская область, Буйский муниципальный район, д. Елегино, ул. Задняя, д. 11		0101000020E6100000377007EA94F54440B95510035D5B4D40
43653	1	7	956	8607	32368	\N	58.849375000000002	Костромская область, Буйский муниципальный район, д. Дьяконово, пер. Дъяконовский, д. 2		0101000020E61000009CA6CF0EB8B444401F85EB51B86C4D40
43652	1	7	956	53333	\N	\N	58.388929846965901	Костромская область, Буйский муниципальный район, с. Дор, д. 21	Россия, Костромская область, Буйский район, поселок Дор	0101000020E6100000DF878384289B444076374F75C8314D40
43649	1	7	956	8458	32476	\N	58.530510999999997	Костромская область, Буйский муниципальный район, д. Добрецово, ул. Новая, д. 7		0101000020E610000014AE47E17ABE44408995D1C8E7434D40
43651	1	7	956	8511	32477	\N	58.486748783395903	Костромская область, Буйский муниципальный район, пос. Гагарино, ул. Советская, д. 7, кв. 3		0101000020E6100000D09D60FF758C44402C2E8ECA4D3E4D40
43646	1	7	956	8270	32197	\N	58.500684	Костромская область, Буйский муниципальный район, с. Воскресенье, ул. Центральная, д. 5		0101000020E6100000F6B704E09FAA4440B3D0CE6916404D40
43644	1	7	956	8164	32437	\N	58.362806999999997	Костромская область, Буйский муниципальный район, с. Борок, ул. Молодежная, д. 7		0101000020E6100000B1C403CAA6CE444043E1B375702E4D40
43641	1	7	956	8030	32429	\N	58.486319999999999	Костромская область, Буйский муниципальный район, д. Бараново, ул. Главная, д. 4а		0101000020E610000009A7052FFACC444003B2D7BB3F3E4D40
43642	1	7	956	8055	32594	\N	58.511732000000002	Костромская область, Буйский муниципальный район, д. Афонино, ул. Гагаринская, д. 29		0101000020E610000029ED0DBE30CB44408928266F80414D40
43629	1	7	813	7477	\N	\N	58.088478000000002	Костромская область, Антроповский район, село Трифон, адрес помещения для голосования: здание Трифоновской основной школы, дом 1а, адрес УИК: адм. здание Котельниковского сельского поселения, дом 6		0101000020E6100000F96706F1814F45402F35423F530B4D40
43623	1	7	813	7199	32258	\N	58.030337000000003	Костромская область, Антроповский район, село Словинка, улица Садовая, дом 16		0101000020E6100000884CF910548F4540EC6D3315E2034D40
43625	1	7	813	7315	32510	\N	58.430371000000001	Костромская область, Антроповский район, деревня Просек, улица Центральная, дом 1а		0101000020E610000053B0C6D9747A4540CB129D6516374D40
43636	1	7	813	7770	\N	\N	58.315336000000002	Костромская область, Антроповский район, село Понизье, адрес помещения для голосования: здание Понизовской основной школы, дом 2, адрес УИК: адм. здание Курновского сельского поселения, дом 3		0101000020E6100000F59D5F94A095454030A017EE5C284D40
43633	1	7	813	7644	\N	\N	58.279136000000001	"Костромская область, Антроповский район, деревня Помчище, адрес помещения для голосования: здание Помчищской начальной школы-детского сада, дом 2, адрес УИК: административное здание СПК ""Восход"", дом 4"		0101000020E6100000C37DE4D6A47D454071917BBABA234D40
43635	1	7	813	7750	\N	\N	58.014373999999997	Костромская область, Антроповский район, село Пеньки, административное здание Котельниковского сельского поселения, дом 29		0101000020E6100000DBDE6E490E5C4540D3F4D901D7014D40
43632	1	7	813	7622	32148	\N	58.241146000000001	Костромская область, Антроповский район, село Палкино, ул. Советская, дом 31		0101000020E61000008CDB68006F774540D6C743DFDD1E4D40
43628	1	7	813	53348	\N	\N	58.112443331600801	Костромская область, Антроповский район, село Михайловское, административное здание Котельниковского сельского поселения, дом 4		0101000020E61000008BA71E697071454002D53F88640E4D40
43624	1	7	813	7233	\N	\N	58.368679	Костромская область, Антроповский район, деревня Курново, здание Курновского сельского дома культуры, дом 26		0101000020E610000002840F255A7E45406ADC9BDF302F4D40
43630	1	7	813	7509	32173	\N	58.124203000000001	Костромская область, Антроповский район, деревня Курилово, адрес помещения для голосования: улица Школьная, дом 5, адрес УИК: улица Школьная, дом 7		0101000020E61000001E4E603AAD854540558847E2E50F4D40
43627	1	7	813	7391	\N	\N	58.109727999999997	Костромская область, Антроповский район, деревня Котельниково, адрес помещения для голосования: здание Котельниковской основной школы, дом 32, адрес УИК: здание администрации Котельниковского с/п, дом 31		0101000020E6100000D6E429ABE97045404DBA2D910B0E4D40
43638	1	7	813	7888	\N	\N	58.110903	Костромская область, Буйский муниципальный район, д. Иваньково, д. 1		0101000020E610000047FFCBB5687945409F03CB11320E4D40
43626	1	7	813	7336	\N	\N	58.305408	Костромская область, Антроповский район, деревня Бедрино, здание Бедринской начальной школы, дом 87		0101000020E6100000E65C8AABCA724540E8F7FD9B17274D40
43622	1	7	813	7108	32561	\N	58.398708999999997	Костромская область, Антроповский район, поселок Антропово, адрес помещения для голосования: улица Лебедева, дом 6, адрес УИК: улица Октябрьская, дом 12		0101000020E6100000C2340C1F1181454078CF81E508334D40
43621	1	7	813	7108	32359	\N	58.398708999999997	Костромская область, Антроповский район, поселок Антропово, адрес помещения для голосования: улица Кирова, дом 8а, адрес УИК: улица Октябрьская, дом 12		0101000020E6100000C2340C1F1181454078CF81E508334D40
38246	1	6	\N	54204	35421	\N	54.495956	г. Калуга, Ленинский округ, д. Шопино, ул. Центральная, д.2	Россия, Калужская область, деревня Шопино	0101000020E610000094A0BFD023144240A320787C7B3F4B40
38071	1	6	\N	25542	35522	\N	55.140836999999998	Калужская область, Боровский район, д.Тимашово, Мира, 2		0101000020E6100000704221020E3D42408B8862F206924B40
38587	1	6	\N	54197	35491	\N	54.731440999999997	"Калужская область, муниципальный район ""Тарусский район"", городское поселение ""Город Таруса"", Пушкина, 1"		0101000020E61000009694BBCFF19542400DFAD2DB9F5D4B40
38590	1	6	\N	54197	35403	\N	54.731440999999997	"Калужская область, муниципальный район ""Тарусский район"", городское поселение ""Город Таруса"", Луначарского, 33а"		0101000020E61000009694BBCFF19542400DFAD2DB9F5D4B40
38443	1	6	\N	11545	\N	\N	55.051380999999999	Село Спас-Загорье, Помещение средней школы	Россия, Калужская область, село Спас-Загорье	0101000020E61000009CFA40F2CE4B4240615111A793864B40
38556	1	6	\N	54180	35239	\N	54.413921000000002	г.Спас-Деменск, пер.Пионерский, 3		0101000020E610000009A7052FFA0241405610035DFB344B40
38555	1	6	\N	54180	35216	\N	54.413921000000002	г.Спас-Деменск, Советская, 107		0101000020E610000009A7052FFA0241405610035DFB344B40
38521	1	6	\N	1634	4128	\N	55.118107000000002	город Обнинск, ул.Энгельса, 2А	Россия, Калужская область, Обнинск, улица Энгельса, 2а	0101000020E61000009DD843FB584F4240DF3653211E8F4B40
38509	1	6	\N	1634	4128	\N	55.117208789773997	город Обнинск, Энгельса, 13	Россия, Калужская область, Обнинск, улица Энгельса, 13	0101000020E61000008AE6012CF24D424000E65AB4008F4B40
38565	1	6	\N	1634	10007	\N	55.098661	д. Стрельна, ул. Победы, 21	Россия, Калужская область, Обнинск, улица Победы, 21	0101000020E6100000992842EA764E4240013274ECA08C4B40
38517	1	6	\N	1634	4210	\N	55.112520000000004	город Обнинск, ул.Курчатова, 33	Россия, Калужская область, Обнинск, улица Курчатова, 33	0101000020E61000005C9198A0864F4240AE122C0E678E4B40
38506	1	6	\N	1634	4047	\N	55.119897999999999	город Обнинск, Гагарина, 12	Россия, Калужская область, Обнинск, улица Гагарина, 12	0101000020E6100000CBBE2B82FF4B42408B6D52D1588F4B40
38507	1	6	\N	1634	4110	\N	55.117314	город Обнинск, пр.Маркса, 56		0101000020E6100000DE770C8FFD4C424075AE2825048F4B40
38525	1	6	\N	1634	3918	\N	55.089624000000001	город Обнинск, пр.Ленина, 36	Россия, Калужская область, Обнинск, проспект Ленина, 36	0101000020E610000065506D70224E4240E6779ACC788B4B40
38524	1	6	\N	1634	3918	\N	55.090026000000002	город Обнинск, пр.Ленина, 15	Россия, Калужская область, Обнинск, проспект Ленина, 15	0101000020E61000007FF5B86FB54C424015E5D2F8858B4B40
38503	1	6	\N	1634	3918	\N	55.118735000000001	город Обнинск, пр.Ленина, 194	Россия, Калужская область, Обнинск, проспект Ленина, 194	0101000020E610000029CC7B9C694A4240FEF15EB5328F4B40
38501	1	6	\N	1634	3918	\N	55.118504112469303	город Обнинск, пр.Ленина, 192	Россия, Калужская область, Обнинск, проспект Ленина, 194	0101000020E61000001002F225544A4240FC389A232B8F4B40
38497	1	6	\N	1634	3918	\N	55.109641000000003	город Обнинск, пр.Ленина, 126	Россия, Калужская область, Обнинск, проспект Ленина, 126	0101000020E61000005A63D009A14B42407FA65EB7088E4B40
38492	1	6	\N	1634	3918	\N	55.096327000000002	город Обнинск, Ленина, 71	Россия, Калужская область, Обнинск, проспект Ленина, 71	0101000020E61000006FF59CF4BE4D4240645C7171548C4B40
38514	1	6	\N	1634	35453	\N	55.138247999999997	город Обнинск, ул.Студгородок, 1	Россия, Калужская область, Обнинск, квартал Студенческий городок, 15/1	0101000020E6100000CA54C1A8A44C4240635E471CB2914B40
38515	1	6	\N	1634	35387	\N	55.118107000000002	город Обнинск, ул.Энгельса, д.2А, ул.Курчатова д.51А	Россия, Калужская область, Обнинск, улица Энгельса, 2а	0101000020E61000009DD843FB584F4240DF3653211E8F4B40
38511	1	6	\N	1634	35387	\N	55.119233999999999	город Обнинск, ул.Энгельса, 14		0101000020E6100000ECA529029C4E42401F49490F438F4B40
38510	1	6	\N	1634	35387	\N	55.119264999999999	город Обнинск, ул.Энгельса, 22		0101000020E6100000ADFBC742744E42405A475513448F4B40
38494	1	6	\N	1634	3928	\N	55.095565000000001	город Обнинск, пл.Треугольная, 1	Россия, Калужская область, Обнинск, Треугольная площадь, 1	0101000020E61000001E1840F8504E424035D252793B8C4B40
38493	1	6	\N	1634	3928	\N	55.095565000000001	город Обнинск, пл.Треугольная, 3	Россия, Калужская область, Обнинск, Треугольная площадь, 1	0101000020E61000001E1840F8504E424035D252793B8C4B40
38523	1	6	\N	1634	4298	\N	55.094301999999999	город Обнинск, Пионерский проезд, 23	Россия, Калужская область, Обнинск, Пионерский проезд, 23	0101000020E61000008B8BA372134B424044F98216128C4B40
38519	1	6	\N	1634	35415	\N	55.104841	город Обнинск, Мира, 14		0101000020E61000007A50508A564E4240D5230D6E6B8D4B40
38518	1	6	\N	1634	35415	\N	55.104841	город Обнинск, ул.Мира, 14		0101000020E61000007A50508A564E4240D5230D6E6B8D4B40
38498	1	6	\N	1634	35418	\N	55.101647999999997	город Обнинск, Любого, 10		0101000020E6100000FD135CACA84B424016DA39CD028D4B40
38520	1	6	\N	1634	35433	\N	55.101272000000002	город Обнинск, ул.Курчатова, 16		0101000020E61000009F5912A0A64E424011001C7BF68C4B40
38516	1	6	\N	1634	35433	\N	55.114677999999998	город Обнинск, ул.Курчатова, 39		0101000020E61000004ACE893DB44F42400CC9C9C4AD8E4B40
38491	1	6	\N	1634	35410	\N	55.093895000000003	город Обнинск, Кончаловского, 3		0101000020E6100000AAB8718BF94D4240042159C0048C4B40
38500	1	6	\N	1634	35369	\N	55.111094000000001	город Обнинск, ул.Комарова, 10		0101000020E6100000BAF59A1E144C424013640454388E4B40
38499	1	6	\N	1634	35369	\N	55.111094000000001	город Обнинск, ул.Комарова, 8		0101000020E6100000BAF59A1E144C424013640454388E4B40
38513	1	6	\N	1634	4161	\N	55.122647999999998	город Обнинск, ул.Калужская, 11	Россия, Калужская область, Обнинск, Калужская улица, 11	0101000020E6100000D331E719FB4E4240BC75FEEDB28F4B40
38512	1	6	\N	1634	4161	\N	55.121623	город Обнинск, ул.Калужская, 5	Россия, Калужская область, Обнинск, Калужская улица, 5	0101000020E610000003CDE7DCED4E424080B8AB57918F4B40
38508	1	6	\N	1634	426	\N	55.117030999999997	город Обнинск, Звездная, 3	Россия, Калужская область, Обнинск, Звездная улица, 3	0101000020E61000001250E108524D424020CF2EDFFA8E4B40
38496	1	6	\N	1634	35412	\N	55.107714999999999	город Обнинск, ул.Гурьянова, 15		0101000020E61000003C873254C54C4240F224E99AC98D4B40
38502	1	6	\N	1634	35357	\N	55.120490950603397	город Обнинск, Гагарина, 53	Россия, Калужская область, Обнинск	0101000020E6100000274D83A2794A42402E3BC43F6C8F4B40
38442	1	6	\N	45961	\N	\N	55.028672	Деревня Митинка, Помещение Фельдшерско-акушерского пункта		0101000020E6100000C4EA8F300C4C4240CC272B86AB834B40
38435	1	6	\N	10625	35288	\N	55.008814357408497	г.Малоярославец, площадь Жукова	Россия, Калужская область, Малоярославец	0101000020E610000057EA5910CA3B42409CDF30D120814B40
38424	1	6	\N	10625	35212	\N	55.018211000000001	Малоярославец, пл.Жукова, 3	Россия, Калужская область, Малоярославец, Интернациональный проезд	0101000020E6100000C100C287123B4240B7B6F0BC54824B40
38434	1	6	\N	10625	35349	\N	55.011251999999999	г.Малоярославец, Школьная, 3		0101000020E610000062156F641E3F4240DE019EB470814B40
38082	1	6	\N	10625	35349	\N	55.011251999999999	с.Совхоз Чкаловский, ул.Школьная, дом №6		0101000020E610000062156F641E3F4240DE019EB470814B40
38053	1	6	\N	10625	35349	\N	55.011251999999999	д. Студеное, Школьная, 6		0101000020E610000062156F641E3F4240DE019EB470814B40
38432	1	6	\N	10625	35343	\N	54.998135187192503	г.Малоярославец, Российских газовиков, 25	Россия, Калужская область, Малоярославец, улица Российских Газовиков	0101000020E61000008D0931975439424019FF3EE3C27F4B40
38431	1	6	\N	10625	35343	\N	55.000000999999997	г.Малоярославец, Российских газовиков, 1		0101000020E6100000D7DB662AC4394240D07B630800804B40
38426	1	6	\N	10625	35370	\N	55.005284000000003	г.Малоярославец, Радищева, 2		0101000020E6100000D5EB1681B138424096986725AD804B40
38430	1	6	\N	10625	35417	\N	55.014133000000001	г.Малоярославец, Московская, 60		0101000020E610000059FB3BDBA33D4240AE65321CCF814B40
38429	1	6	\N	10625	35417	\N	55.012326000000002	г.Малоярославец, Московская, 42		0101000020E610000016F71F990E3D4240FC71FBE593814B40
38428	1	6	\N	10625	35346	\N	55.012109000000002	г.Малоярославец, Кутузова, 76		0101000020E6100000151E34BBEE3B42405F7EA7C98C814B40
38425	1	6	\N	10625	35354	\N	55.0031882274846	г.Малоярославец, Кирова, 26	Россия, Калужская область, Малоярославец, улица Кирова	0101000020E61000003D65355D4F3C4240ADDEE17668804B40
38423	1	6	\N	10625	35439	\N	55.008253000000003	Малоярославец, Аузина, 1		0101000020E6100000D76D50FBAD3B4240058C2E6F0E814B40
38427	1	6	\N	10625	35386	\N	55.005709513614804	г.Малоярославец, Радищева, 12		0101000020E6100000C976BE9F1A3942404DA1F31ABB804B40
38412	1	6	\N	10054	\N	\N	54.991258000000002	"Село Маклино, Администрация сельского поселения ""Село Маклино"""		0101000020E6100000DBFAE93F6B3C4240FEF2C98AE17E4B40
38394	1	6	\N	54185	35235	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Щербакова, 1-б		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38383	1	6	\N	54185	35256	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Соколова, 2		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38393	1	6	\N	54185	35241	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Салтыкова-Щедрина, 9-а		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38389	1	6	\N	54185	35259	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Карла Маркса, 48		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38392	1	6	\N	54185	35484	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Дзержинского, 1		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38073	1	6	\N	25613	35524	\N	55.249397000000002	Калужская область, Боровский район, д.Коряково, Армейская, 32, кв.2		0101000020E61000006B7F677BF45642403A5CAB3DEC9F4B40
38109	1	6	\N	54183	35226	\N	54.795686000000003	г.Кондрово, ул.Орджоникидзе, дом № 20		0101000020E61000007008556AF6F641404AF1F109D9654B40
38410	1	6	\N	9958	\N	\N	55.032330000000002	"Село Коллонтай, Помещение администрации сельского помещения ""Село Коллонтай"""	Россия, Калужская область, село Коллонтай	0101000020E61000001F9E25C8084442400057B26323844B40
38355	1	6	\N	54187	35257	\N	54.030872000000002	г.Козельск, Чкалова, ДКРА		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38348	1	6	\N	54187	35447	\N	54.030872000000002	г.Козельск, Суворова, д.22, МБОУ <<ООШ №4>>		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38341	1	6	\N	36210	35275	\N	54.076022000000002	г. Киров, Пролетарская, 174		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38336	1	6	\N	36210	35230	\N	54.076022000000002	г. Киров, Ленина, 17		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38452	1	6	\N	60378	74926	\N	54.598365999999999	деревня Картышово, Центральная, 13		0101000020E6100000F10D85CFD6214240E884D041974C4B40
38313	1	6	\N	54193	\N	\N	54.593983999999999	Город  Калуга, д.Канищево, Канищевский СКДЦ	Россия, Калужская область, Калуга, деревня Канищево	0101000020E61000001F2DCE18E6244240732CEFAA074C4B40
38275	1	6	\N	40	\N	\N	54.563056000000003	"Калужская область, городской округ ""Город  Калуга"", Московский округ, с.Муратовский щебзавод, здание школы № 41"	Россия, Калужская область, Калуга, Московский округ	0101000020E61000001B67D311C01D424086E8103812484B40
38245	1	6	\N	40	\N	\N	54.483398999999999	г. Калуга, Ленинский округ, д. Тинино, здание школы №42	Россия, Калужская область, Калуга, деревня Тинино	0101000020E610000069AA27F38F284240A5F5B704E03D4B40
38451	1	6	\N	40	15642	\N	54.598892999999997	поселок Лесной, Центральная, 9	Россия, Калужская область, Калуга, Октябрьский округ, улица Центральная, 9	0101000020E6100000E144F46BEB214240D3669C86A84C4B40
38311	1	6	\N	40	15642	\N	54.597327999999997	Город  Калуга, ул.Центральная, 13а (средняя школа №29)	Россия, Калужская область, Калуга, Октябрьский округ, улица Центральная, 13а	0101000020E6100000CF4E0647C9214240177E703E754C4B40
38297	1	6	\N	40	1163	\N	54.520279000000002	Город  Калуга, ул.Хрустальная, 66 (ДПК Родник)	Россия, Калужская область, Калуга, улица Хрустальная, 66	0101000020E6100000FED2A23EC9274240D6E5948098424B40
38264	1	6	\N	40	657	\N	54.533712000000001	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Телевизионная, 5"	Россия, Калужская область, Калуга, улица Телевизионная, 5	0101000020E610000000C79E3D97214240CBBDC0AC50444B40
38221	1	6	\N	40	1067	\N	54.514806999999998	г. Калуга, Ленинский округ, ул. Суворова, д.179	Россия, Калужская область, Калуга, улица Суворова, 179	0101000020E61000008121AB5B3D2342403D601E32E5414B40
38270	1	6	\N	40	748	\N	54.518276999999998	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Рылеева, 18"	Россия, Калужская область, Калуга, улица Рылеева, 18	0101000020E6100000BD1C76DF312042406EA296E656424B40
38142	1	6	\N	40	891	\N	54.565499000000003	Город  Калуга, ул.Новослободская, 31 (машиностроительный колледж)	Россия, Калужская область, Калуга, улица Новослободская, 31	0101000020E610000038A0A52BD8264240DA756F4562484B40
38248	1	6	\N	40	427	\N	54.580373000000002	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Кибальчича, 19"	Россия, Калужская область, Калуга, улица Кибальчича, 19	0101000020E6100000840D4FAF941F42409F3D97A9494A4B40
38247	1	6	\N	40	35385	\N	54.590269999999997	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Звездная, 19а"	Россия, Калужская область, Калуга, улица Звездная, 19а	0101000020E610000094BC3AC780204240ABE7A4F78D4B4B40
94322	1	6	\N	40	1287	\N	54.544435999999997	г Калуга, ул.Дубрава, 3а.	Россия, Калужская область, Калуга, улица Дубрава, 3	0101000020E610000060014C19382A4240ED612F14B0454B40
38310	1	6	\N	40	1394	\N	54.596102000000002	Город  Калуга, ул.Дорожная, 17 (средняя школа №51)	Россия, Калужская область, Калуга, улица Дорожная, 17	0101000020E6100000B403AE2B66224240448A01124D4C4B40
38255	1	6	\N	40	537	\N	54.567701	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Гурьянова, 8 к.1"	Россия, Калужская область, Калуга, улица Гурьянова, 8к1	0101000020E6100000105839B4C81E42400874266DAA484B40
38288	1	6	\N	40	1033	\N	54.520901000000002	Город  Калуга, ул.Веры Андриановой, 3 (средняя школа №21)	Россия, Калужская область, Калуга, улица Веры Андриановой, 3	0101000020E6100000B680D07AF822424013BA4BE2AC424B40
38285	1	6	\N	40	986	\N	54.530405000000002	Город  Калуга, ул.Билибина, 31 (СДЮШ олимпийского резерва)	Россия, Калужская область, Калуга, улица Билибина, 33	0101000020E610000018778368AD2242404451A04FE4434B40
38677	1	6	\N	40	35586	\N	54.533684901662603	Город  Калуга, пл. Вокзальная, 3 (вокзал Калуга-1)	Россия, Калужская область, Калуга, улица Ленина	0101000020E6100000381268B0A9234240D1AE42CA4F444B40
38283	1	6	\N	40	955	\N	54.553077999999999	Город  Калуга, пер.Малинники, 20 (ДК Малинники)		0101000020E6100000EB909BE1062642408C118942CB464B40
38278	1	6	\N	40	861	\N	54.572702	город  Калуга, пер. Дорожный, 5 (средняя школа №16)	Россия, Калужская область, Калуга, переулок Дорожный, 5	0101000020E61000002028B7ED7B284240492D944C4E494B40
38277	1	6	\N	40	861	\N	54.572702	город  Калуга, пер.Дорожный, 5 (средняя школа №16)	Россия, Калужская область, Калуга, переулок Дорожный, 5	0101000020E61000002028B7ED7B284240492D944C4E494B40
38295	1	6	\N	40	35413	\N	54.521627000000002	Город  Калуга, ул.Маршала Жукова, 53 (коммунально-строит. техникум)	Россия, Калужская область, Калуга, улица маршала Жукова, 53	0101000020E6100000F9D687F546254240F5DA6CACC4424B40
38294	1	6	\N	40	35413	\N	54.520828000000002	Город  Калуга, ул.Маршала Жукова, 51 (средняя школа №10)		0101000020E61000008D9B1A683E254240A96BED7DAA424B40
38293	1	6	\N	40	35413	\N	54.517874999999997	Город  Калуга, ул.Маршала Жукова, 35 (техникум электронных приборов)		0101000020E610000038143E5B072542403F355EBA49424B40
38213	1	6	\N	40	35309	\N	54.503422	г. Калуга, Ленинский округ, ул. Вилонов, д.11		0101000020E6100000F1845E7F121B4240200BD12170404B40
38252	1	6	\N	40	490	\N	54.5676195806358	"Калужская область, городской округ ""Город  Калуга"", Московский округ, бульвар Моторостроителей, 16"	Россия, Калужская область, Калуга, бульвар Энтузиастов, 16	0101000020E6100000946C7539252242401B47ACC5A7484B40
38239	1	6	\N	40	35326	\N	54.503422	г. Калуга, Ленинский округ, ул. Школьная, 3А		0101000020E6100000F1845E7F121B4240200BD12170404B40
38258	1	6	\N	40	35377	\N	54.535890999999999	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Широкая, 51"		0101000020E610000013D55B035B1F4240419C871398444B40
38289	1	6	\N	40	35427	\N	54.517598	Город  Калуга, ул.Чижевского, 17 (ГосУниверситет Минфина России)		0101000020E6100000E10D6954E0224240CD3CB9A640424B40
38312	1	6	\N	40	35355	\N	54.598872	Город  Калуга, ул.Центральная, 12а (террит. представительство №28)		0101000020E61000007FDB1324B6214240BC3E73D6A74C4B40
38296	1	6	\N	40	35414	\N	54.520001999999998	Город  Калуга, ул.Хрустальная, 2 (средняя школа №22)		0101000020E6100000C687D9CBB625424063EDEF6C8F424B40
38292	1	6	\N	40	35366	\N	54.515099999999997	Город  Калуга, ул.Фридриха Энгельса, 14 (гимназия №24)		0101000020E61000008FE046CA16234240B515FBCBEE414B40
38291	1	6	\N	40	35366	\N	54.516207999999999	Город  Калуга, ул.Фридриха Энгельса, 12 (средняя школа №15)		0101000020E610000090BDDEFDF12242407FF78E1A13424B40
38226	1	6	\N	40	35366	\N	54.506005000000002	г. Калуга, Ленинский округ, ул. Ф.Энгельса, д.119		0101000020E61000001F645930F1234240664E97C5C4404B40
38224	1	6	\N	40	35366	\N	54.505529000000003	г. Калуга, Ленинский округ, ул. Ф.Энгельса, д.110		0101000020E610000031276893C3234240FD169D2CB5404B40
38307	1	6	\N	40	35437	\N	54.515642999999997	Город  Калуга, ул.Турынинская, 10а (КДЦ Турынино)		0101000020E610000081ECF5EE8F2B4240A6B4FE9600424B40
38223	1	6	\N	40	35	\N	54.511325999999997	г. Калуга, Ленинский округ, ул. Тульская, д.78А	Россия, Калужская область, Калуга, Тульская улица, 78а	0101000020E6100000A27C410B0924424018CC5F2173414B40
38229	1	6	\N	40	35396	\N	54.512099999999997	г. Калуга, Ленинский округ, ул. Тульская, д.102		0101000020E61000007381CB63CD2442400B24287E8C414B40
38305	1	6	\N	40	35364	\N	54.515446978032003	Город  Калуга, ул.Трудовая, 12 (средняя школа №28)	Россия, Калужская область, Калуга, улица Трудовая, 10	0101000020E6100000A11342075D28424021E9D32AFA414B40
38280	1	6	\N	40	897	\N	54.5545214743183	город Калуга, ул.Тарутинская, 70/1 (средняя школа №25)	Россия, Калужская область, Калуга, Тарутинская улица, 70	0101000020E6100000103FFF3D78254240FDF84B8BFA464B40
38290	1	6	\N	40	35408	\N	54.515658999999999	Город  Калуга, ул.Суворова, 143 (гидромелиоративный техникум)		0101000020E61000006971C63027224240AC71361D01424B40
38209	1	6	\N	40	35408	\N	54.515847000000001	г. Калуга, Ленинский округ, ул. Суворова, д.118		0101000020E6100000B20DDC813A214240AF5E454607424B40
38219	1	6	\N	40	35429	\N	54.509166999999998	г. Калуга, Ленинский округ, ул. Степана Разина, д.26		0101000020E61000007CF0DAA50D234240E9995E622C414B40
38242	1	6	\N	40	35479	\N	54.466343999999999	г. Калуга, Ленинский округ, ул. Секиотовская, д.13		0101000020E61000009276A38FF91E4240C9570229B13B4B40
38215	1	6	\N	40	35440	\N	54.500824000000001	г. Калуга, Ленинский округ, ул. Салтыкова-Щедрина, д.10		0101000020E6100000C5538F34B8214240A58636001B404B40
38217	1	6	\N	40	35324	\N	54.503422	г. Калуга, Ленинский округ, ул. С-Щедрина, д.66А		0101000020E6100000F1845E7F121B4240200BD12170404B40
38225	1	6	\N	40	35295	\N	54.503422	г. Калуга, Ленинский округ, ул. С-Щедрина, д.66		0101000020E6100000F1845E7F121B4240200BD12170404B40
38202	1	6	\N	40	35422	\N	54.516756999999998	г. Калуга, Ленинский округ, ул. Рылеева, д.39		0101000020E610000063EE5A423E204240527DE71725424B40
38241	1	6	\N	40	35232	\N	54.503422	г. Калуга, Ленинский округ, ул. Ромодановские Дворики, д.61		0101000020E6100000F1845E7F121B4240200BD12170404B40
38269	1	6	\N	40	35426	\N	54.526805000000003	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Пухова, 54"		0101000020E61000001A8BA6B393214240452FA3586E434B40
38268	1	6	\N	40	35426	\N	54.526555000000002	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Пухова, 52"		0101000020E6100000EBA9D55757214240CC457C2766434B40
38271	1	6	\N	40	779	\N	54.520091000000001	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Пролетарская, 40"	Россия, Калужская область, Калуга, Пролетарская улица, 40	0101000020E61000009085E81038204240D3F8855792424B40
38238	1	6	\N	40	35328	\N	54.537481116299801	г. Калуга, Ленинский округ, ул. Привокзальная, д.11А		0101000020E6100000CDB051D66F104240569C6A2DCC444B40
38259	1	6	\N	40	35424	\N	54.551825000000001	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Поселковая, 4"		0101000020E6100000611C5C3AE6224240BF0E9C33A2464B40
38272	1	6	\N	40	35407	\N	54.521746999999998	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Плеханова, 2"		0101000020E6100000EC8A19E1ED1F42409FE40E9BC8424B40
38263	1	6	\N	40	35482	\N	54.529688999999998	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Окружная, 4 к.3"		0101000020E610000018D1764CDD214240850662D9CC434B40
38279	1	6	\N	40	35441	\N	54.559939	Город  Калуга, ул.Новослободская, 25 (колледж молочной промышлен.)		0101000020E61000001955867137264240A260C614AC474B40
38218	1	6	\N	40	8145	\N	54.504677000000001	г. Калуга, Ленинский округ, ул. Николо-Козинская, д.68	Россия, Калужская область, Калуга, Николо-Козинская улица, 68	0101000020E61000002B6D718DCF2242408E05854199404B40
38232	1	6	\N	40	35397	\N	54.511875000000003	г. Калуга, Ленинский округ, ул. Никитина, д.121		0101000020E6100000709692E524264240EC51B81E85414B40
38230	1	6	\N	40	35397	\N	54.508806999999997	г. Калуга, Ленинский округ, ул. Никитина, д.74		0101000020E610000000C8091346254240E97C789620414B40
38309	1	6	\N	40	35406	\N	54.578707999999999	Город  Калуга, ул.Московская, 311 (управление Россельхознадзора)		0101000020E6100000FE261422E02042407FF78E1A134A4B40
38267	1	6	\N	40	35406	\N	54.520215999999998	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Московская, 79"		0101000020E610000022A98592C92142408F6D197096424B40
38266	1	6	\N	40	35406	\N	54.526606999999998	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Московская, 165"		0101000020E6100000D0D1AA96742242401E6CB1DB67434B40
38262	1	6	\N	40	35406	\N	54.530875000000002	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Московская, 212"		0101000020E6100000747CB43863224240CBA145B6F3434B40
38261	1	6	\N	40	35406	\N	54.535769999999999	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Московская, 221а"		0101000020E61000004E098849B8224240C616821C94444B40
38566	1	6	\N	40	35559	\N	54.498078999999997	д. Верховая, ул. Молодежная, 1		0101000020E6100000C8CF46AE9B18424085E97B0DC13F4B40
38302	1	6	\N	40	35379	\N	54.530431	Город  Калуга, ул.Молодежная, 19/14 (центр доп. образ. для детей)		0101000020E6100000EC134031B22642406DE4BA29E5434B40
38301	1	6	\N	40	35379	\N	54.530268999999997	Город  Калуга, ул.Молодежная, 5 (средняя школа №12)		0101000020E6100000B404190115264240938AC6DADF434B40
38228	1	6	\N	40	35416	\N	54.510019	г. Калуга, Ленинский округ, ул. Мичурина, д.45		0101000020E6100000AB77B81D1A24424058AB764D48414B40
38300	1	6	\N	40	35401	\N	54.527532000000001	Город  Калуга, ул.Маяковского, 35 (дом-интернат для престарелых)		0101000020E61000003AB01C2103274240F7CB272B86434B40
38299	1	6	\N	40	35401	\N	54.528984000000001	Город  Калуга, ул.Маяковского, 55 (областная психиатрич. больница)		0101000020E6100000ABEB504D49284240BB0D6ABFB5434B40
38222	1	6	\N	40	35320	\N	54.513154031017798	г. Калуга, Ленинский округ, ул. М.Жукова, д.12		0101000020E6100000D93D7958A8234240E2E7BF07AF414B40
38308	1	6	\N	40	35402	\N	54.512208999999999	Город  Калуга, ул.Льва Толстого, 51 (средняя школа №44)		0101000020E6100000892991442F2D4240C2DB831090414B40
38212	1	6	\N	40	35432	\N	54.507955000000003	г. Калуга, Ленинский округ, ул. Луначарского, д.16		0101000020E6100000978FA4A4872142407B6B60AB04414B40
38284	1	6	\N	40	35430	\N	54.552968999999997	Город  Калуга, ул.Луговая, 43 (средняя школа №1)		0101000020E6100000FE277FF78E244240D5592DB0C7464B40
38240	1	6	\N	40	35347	\N	54.517932604900899	г. Калуга, Ленинский округ, д. Мстихино, ул. Лесная, д.24, к.1	Россия, Калужская область, Калуга, Ленинский округ, улица Лесная	0101000020E61000008CDB68006F1D42407442E8A04B424B40
38286	1	6	\N	40	35400	\N	54.532541999999999	Город  Калуга, ул.Ленина, 14 (технологический колледж)		0101000020E61000003AAFB14B542342408BDF14562A444B40
38211	1	6	\N	40	35400	\N	54.511389000000001	г. Калуга, Ленинский округ, ул. Ленина, д.83		0101000020E61000004031B2648E2142405F44DB3175414B40
38251	1	6	\N	40	35399	\N	54.577698365534701	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Кубяка, 8"	Россия, Калужская область, Калуга, улица Кубяка, 8	0101000020E6100000B935E9B644204240787B1002F2494B40
38250	1	6	\N	40	35399	\N	54.575217000000002	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Кубяка, 1 к.1"		0101000020E6100000BC3FDEAB56204240378DEDB5A0494B40
38249	1	6	\N	40	35399	\N	54.577267999999997	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Кубяка, 4"		0101000020E61000002F6CCD565E2042407F83F6EAE3494B40
38200	1	6	\N	40	35375	\N	54.514303202895697	г. Калуга, Ленинский округ, ул. Королёва, д.39, стр.1	Россия, Калужская область, Калуга, улица академика Королева, 39	0101000020E6100000C5573B8A731E42400A9E42AED4414B40
38220	1	6	\N	40	35409	\N	54.513987	г. Калуга, Ленинский округ, ул. Кирова, д.31		0101000020E610000049490F43AB214240DAC87553CA414B40
38265	1	6	\N	40	35411	\N	54.526487000000003	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Карла Либкнехта, 1"		0101000020E6100000732CEFAA0722424074620FED63434B40
38234	1	6	\N	40	35394	\N	54.495114000000001	г.Калуги, Заречная, 72		0101000020E6100000EA793716141C424058E542E55F3F4B40
38207	1	6	\N	40	35263	\N	54.513052494239503	г. Калуга, Ленинский округ, ул. Дзержиского, д.49		0101000020E6100000062E8F3523214240DE921CB0AB414B40
38276	1	6	\N	40	35389	\N	54.565238000000001	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Гурьянова, 67"		0101000020E61000006B11514CDE1C42406D3A02B859484B40
38257	1	6	\N	40	35389	\N	54.565238000000001	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Гурьянова, 65"		0101000020E61000006B11514CDE1C42406D3A02B859484B40
38256	1	6	\N	40	35389	\N	54.566209000000001	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Гурьянова, 35"	Россия, Калужская область, Калуга, улица Гурьянова, 35	0101000020E610000022A81ABD1A1E4240B6D9588979484B40
38303	1	6	\N	40	1200	\N	54.533648999999997	Город  Калуга, Грабцевское шоссе, 126 (колледж информац. технологий)	Россия, Калужская область, Калуга, Грабцевское шоссе, 126	0101000020E61000005073F222132842408445459C4E444B40
38298	1	6	\N	40	1200	\N	54.523519	Город  Калуга, Грабцевское шоссе, 22а (проф. училище №3)	Россия, Калужская область, Калуга, Грабцевское шоссе, 22а	0101000020E610000019E25817B7254240D5EAABAB02434B40
38260	1	6	\N	40	35435	\N	54.535393999999997	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Глаголева, 10а"		0101000020E610000021787C7BD7224240C03C64CA87444B40
38208	1	6	\N	40	35395	\N	54.515669000000003	г. Калуга, Ленинский округ, ул. Герцена, д.34		0101000020E6100000F2EEC8586D204240D047197101424B40
38235	1	6	\N	40	35393	\N	54.489973999999997	г. Калуга, Ленинский округ, ул. Генерала Попова, д.17		0101000020E61000008F386403E91A4240F5F1D077B73E4B40
38201	1	6	\N	40	35423	\N	54.514336999999998	г. Калуга, Ленинский округ, ул. Гагарина, д.3		0101000020E6100000D4B7CCE9B21E4240B60F79CBD5414B40
38237	1	6	\N	40	35398	\N	54.536298000000002	г. Калуга, Ленинский округ, ул. Вишневского, 27		0101000020E6100000CCD24ECDE51442408274B169A5444B40
38236	1	6	\N	40	35398	\N	54.536481000000002	г. Калуга, Ленинский округ, ул. Вишневского, д.5		0101000020E61000006F29E78BBD15424073F6CE68AB444B40
38214	1	6	\N	40	35372	\N	54.503447999999999	г. Калуга, Ленинский округ, ул. Вилонова, д.16		0101000020E6100000A758350873214240499EEBFB70404B40
38287	1	6	\N	40	35428	\N	54.526966999999999	Город  Калуга, ул.Веры Андриановой, 68 (ДЮСШОР Шашки русские)		0101000020E6100000DB4FC6F8302342401E8997A773434B40
38231	1	6	\N	40	35392	\N	54.506051999999997	г. Калуга, Ленинский округ, ул. Болдина, д.15	Россия, Калужская область, Калуга, улица Болдина, 15	0101000020E6100000C173EFE192254240A609DB4FC6404B40
38227	1	6	\N	40	35392	\N	54.505952000000001	г. Калуга, Ленинский округ, ул. Болдина, д.18		0101000020E61000000DAA0D4E4425424043ACFE08C3404B40
38216	1	6	\N	40	35425	\N	54.501195000000003	г. Калуга, Ленинский округ, ул. Беляева, д.2		0101000020E6100000A13028D36822424099F5622827404B40
38203	1	6	\N	40	35434	\N	54.511467000000003	г. Калуга, Ленинский округ, ул. Баумана, д.29		0101000020E610000037FE4465C31E4240DBFD2AC077414B40
38204	1	6	\N	40	35339	\N	54.508555999999999	г. Калуга, Ленинский округ, ул. Баженова, 2		0101000020E6100000EF8E8CD5E61F4240A017EE5C18414B40
38096	1	6	\N	40	35633	\N	54.601094000000003	д.Галкино, ул.Архангельская, дом №1		0101000020E610000049F4328AE51E424032E9EFA5F04C4B40
38233	1	6	\N	40	208	\N	54.490873000000001	г. Калуга, Ленинский округ, ул. Академическая, д.6		0101000020E6100000E76F4221021C4240A5BE2CEDD43E4B40
38199	1	6	\N	40	35376	\N	54.513719999999999	г. Калуга, Ленинский округ, ул. Академика Королёва, д.14/25		0101000020E61000001FF46C567D1E42408BA6B393C1414B40
38254	1	6	\N	40	515	\N	54.565753999999998	"Калужская область, городской округ ""Город  Калуга"", Московский округ, Азаровская, 21"	Россия, Калужская область, Калуга, Азаровская улица, 21	0101000020E61000008386FE092E20424064CA87A06A484B40
38306	1	6	\N	40	1316	\N	54.514837999999997	Город  Калуга, ул. 5-я линия, 1 корп. 2 (школа искусств)		0101000020E6100000630B410E4A2A4240785E2A36E6414B40
38304	1	6	\N	40	35436	\N	54.543511000000002	Город  Калуга, ул.Дубрава, 1 (средняя школа №31)		0101000020E610000007B64AB0382A42401502B9C491454B40
38160	1	6	\N	54233	74928	\N	55.154063999999998	Калужская область Жуковский район с.Истье ул.Совхозная, 15, Администрация МО СП с.Истье		0101000020E6100000F7ADD689CB594240D7BE805EB8934B40
38439	1	6	\N	36109	\N	\N	54.659692999999997	"Деревня Захарово, Помещение администрации сельского поселения ""Деревня Захаров"		0101000020E6100000919DB7B1D90742403733FAD170544B40
38185	1	6	\N	30672	35348	\N	55.017834000000001	Калужская область, Жуковский район, г. Жуков ул.Ленина, 12, Жуковская школа №2	Россия, Калужская область, Жуков, улица Ленина, 12	0101000020E61000003411363CBD5A4240E1606F6248824B40
38184	1	6	\N	30672	35348	\N	55.025312	Калужская область, Жуковский район, г. Жуков ул.Ленина, 32, Жуковская  детская школа искусств №2		0101000020E61000009DDA19A6B65C42402219726C3D834B40
38183	1	6	\N	30672	35348	\N	55.017365520566699	Калужская область, Жуковский район, г. Жуков  ул.Ленина, 2, ГДК КНИРТИ		0101000020E61000007FF62345645A4240FB07910C39824B40
38186	1	6	\N	30672	35278	\N	55.024811999999997	Калужская область, Жуковский район, г.Жуков ул.Гурьянова, 4, Администрация ГП г.Жуков		0101000020E61000007940D9942B5E42403046240A2D834B40
38087	1	6	\N	26155	35264	\N	55.212488	Калужская область, Боровский район, г. Ермолино, Русиново, 143		0101000020E6100000355F251FBB4D42406F6589CE329B4B40
38088	1	6	\N	26155	35557	\N	55.212488	"Калужская область, Боровский район, г. Ермолино, ОПХ ""Ермолино"", ФГУП ""Ермолино"" Россельхозакадемии"	Россия, Калужская область, Ермолино, Московское Большое кольцо	0101000020E6100000355F251FBB4D42406F6589CE329B4B40
38085	1	6	\N	26155	35248	\N	55.212488	Калужская область, Боровский район, г. Ермолино, К. Маркса, 1		0101000020E6100000355F251FBB4D42406F6589CE329B4B40
38089	1	6	\N	26155	35342	\N	55.192348000000003	Калужская область, Боровский район, г. Ермолино, 1 Мая, 1		0101000020E6100000BE86E0B88C4B4240BBB9F8DB9E984B40
38086	1	6	\N	26155	35342	\N	55.192348000000003	Калужская область, Боровский район, г. Ермолино, 1Мая, 3		0101000020E6100000BE86E0B88C4B4240BBB9F8DB9E984B40
38138	1	6	\N	49017	74935	\N	55.007002999999997	деревня Дубровка, Центральная, 108		0101000020E61000007825C9737D554240A8FC6B79E5804B40
38619	1	6	\N	20188	35469	\N	54.567400024830903	Село Грабцево, Советская, 2	Россия, Калужская область, поселок Грабцево	0101000020E6100000F7730AF2B32F42400DE02D90A0484B40
38074	1	6	\N	25664	35304	\N	55.230840999999998	Калужская область, Боровский район, с.Ворсино, Школьная, 11		0101000020E6100000D2A755F487544240B8C9A8328C9D4B40
38062	1	6	\N	24875	\N	\N	55.206046000000001	Калужская область, Боровский район, г. Боровск, Институт, адм. здание ВНИИФБиП с/х животных	Россия, Калужская область, Боровск	0101000020E6100000151F9F909D3F42405EBC1FB75F9A4B40
38058	1	6	\N	24875	6499	\N	55.203904963465099	Калужская область, Боровский район, г. Боровск, Ленина, 19	Россия, Калужская область, Боровск, улица Ленина	0101000020E61000006C239EEC663E4240D53E1D8F199A4B40
38063	1	6	\N	24875	35261	\N	55.206046000000001	Калужская область, Боровский район, г. Боровск, Калинина, 1	Россия, Калужская область, Боровск	0101000020E6100000151F9F909D3F42405EBC1FB75F9A4B40
38057	1	6	\N	24875	35335	\N	55.202080000000002	Калужская область, Боровский район, г. Боровск, Ленина, 47		0101000020E6100000F67D3848883E42407D96E7C1DD994B40
38060	1	6	\N	24875	35477	\N	55.212349000000003	Калужская область, Боровский район, г. Боровск, Коммунистическая, 69		0101000020E6100000E2C96E66F43F42404E2B85402E9B4B40
38061	1	6	\N	24875	35553	\N	55.200548180573001	Калужская область, Боровский район, г. Боровск, Большая, 38	Россия, Калужская область, Боровск, улица Володарского	0101000020E6100000A088450C3B3E42409CA38E8EAB994B40
38059	1	6	\N	24875	35338	\N	55.202629999999999	Калужская область, Боровский район, г. Боровск, Берникова, 114		0101000020E6100000492D944C4E3B42402098A3C7EF994B40
38064	1	6	\N	24875	35465	\N	55.206046000000001	Калужская область, Боровский район, г. Боровск, 1 Мая, 51		0101000020E6100000151F9F909D3F42405EBC1FB75F9A4B40
38173	1	6	\N	30198	35334	\N	55.092886	Калужская область, Жуковский район, г. Белоусово ул.Московская, д.53, Белоусовская школа №1 актовый зал		0101000020E6100000D0D38041D2554240CD203EB0E38B4B40
38175	1	6	\N	30198	35250	\N	55.092886	"Калужская область, Жуковский район, г.Белоусово ул.Московская, 95, КДЦ ""Созвездие"" 2 этаж банкетный зал"	Россия, Калужская область, Белоусово	0101000020E6100000D0D38041D2554240CD203EB0E38B4B40
38174	1	6	\N	30198	35291	\N	55.092886	Калужская область, Жуковский район, г.Белоусово, ул.Мирная, 11, Администрация ГП г.Белоусово	Россия, Калужская область, Белоусово	0101000020E6100000D0D38041D2554240CD203EB0E38B4B40
38176	1	6	\N	30198	35249	\N	55.092886	Калужская область, Жуковский район, г.Белоусово ул.Гурьянова, 33, Белоусовская школа №2, актовый зал		0101000020E6100000D0D38041D2554240CD203EB0E38B4B40
38081	1	6	\N	25742	6717	\N	55.181751910426598	Калужская область, Боровский район, г. Балабаново, Гагарина, 13	Россия, Калужская область, Балабаново, улица Гагарина	0101000020E61000001FBFB7E9CF524240C6FD47A643974B40
38080	1	6	\N	25742	35345	\N	55.184550999999999	"Калужская область, Боровский район, г. Балабаново, Московская, 5""А"""		0101000020E6100000F1BBE9961D564240D8B8FE5D9F974B40
38076	1	6	\N	25742	35478	\N	55.173144000000001	Калужская область, Боровский район, г. Балабаново, Мичурина, 19		0101000020E610000032AB77B81D544240D3BF249529964B40
38075	1	6	\N	25742	35490	\N	55.179020000000001	Калужская область, Боровский район, г. Балабаново, Коммунальная, 12		0101000020E6100000D2510E66135442403BAA9A20EA964B40
38077	1	6	\N	25742	35319	\N	55.178788123517997	Калужская область, Боровский район, г. Балабаново, Кап. Королева, 1	Россия, Калужская область, Балабаново, улица Энергетиков	0101000020E610000084807C091554424068757286E2964B40
38084	1	6	\N	25742	35279	\N	55.179020000000001	"Калужская область, Боровский район, г. Балабаново, Дзержинского, МОУ ""Средняя школа №2"""	Россия, Калужская область, Балабаново, Лесная улица	0101000020E6100000D2510E66135442403BAA9A20EA964B40
38083	1	6	\N	25742	35279	\N	55.179020000000001	Калужская область, Боровский район, г. Балабаново, Дзержинского, клуб в/ч 42335		0101000020E6100000D2510E66135442403BAA9A20EA964B40
38079	1	6	\N	25742	35371	\N	55.182091009879599	Калужская область, Боровский район, г. Балабаново, Гагарина, 12		0101000020E61000005DFB027AE1524240AEF204C24E974B40
38078	1	6	\N	25742	6710	\N	55.184258	"Калужская область, Боровский район, г. Балабаново, Боровская, 2""А"""		0101000020E61000006133C005D9524240600322C495974B40
38629	1	6	\N	49452	\N	\N	55.222594999999998	Деревня Аристово, 17		0101000020E6100000295FD0420260424066A032FE7D9C4B40
34242	1	6	1067	49217	\N	\N	54.605949000000003	Деревня Ястребовка, 4	Россия, Калужская область, Ферзиковский район, поселок Ястребовка	0101000020E61000000344C18C293242409F05A1BC8F4D4B40
38605	1	6	7506	60388	\N	\N	55.098141743539003	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Заречье"", Здание Озеренского ФАП"		0101000020E610000029EB3713D3474240992EC4EA8F8C4B40
38648	1	6	1425	21631	35229	\N	54.741078000000002	гор.Юхнов, ул.К.Маркса, 6		0101000020E6100000AC1919E42E9E41407EE4D6A4DB5E4B40
38660	1	6	1425	45734	35646	\N	54.576599999999999	с.Щелканово, ул.Молодежная, 22		0101000020E6100000834D9D47C5B74140D26F5F07CE494B40
38659	1	6	1425	22207	35533	\N	54.631905000000003	д.Чемоданово, ул.Центральная, 20		0101000020E6100000799109F835C44140E6965643E2504B40
38658	1	6	1425	22187	35640	\N	54.661068	д.Упрямово, ул.Цветочная, 2		0101000020E6100000C5C6BC8E38BA4140503750E09D544B40
38657	1	6	1425	22127	35457	\N	54.708799999999997	д.Рыляки, ул.Новые Черемушки, 15		0101000020E610000001A777F17E8E4140D0B359F5B95A4B40
38656	1	6	1425	22103	35539	\N	54.580539999999999	д.Порослицы, ул.Зеленая, 20		0101000020E61000006F2EFEB627CC41408A027D224F4A4B40
38535	1	6	1425	15883	\N	\N	54.797781424136197	д.Погореловка, 55	Россия, Калужская область, Юхновский район, поселок Погореловка	0101000020E61000005D34643C4AB54140622F14B01D664B40
38652	1	6	1425	15883	74947	\N	54.796045767849101	д.Погореловка, ул.Цветочная, 2	Россия, Калужская область, Юхновский район, поселок Погореловка	0101000020E610000033FCA71B28B64140490ED8D5E4654B40
38655	1	6	1425	45634	35566	\N	54.646290999999998	д.Плоское, ул.Калужская, 2	Россия, Калужская область, Юхновский район, поселок Плоское	0101000020E6100000D1EAE40CC5AB41407D59DAA9B9524B40
38654	1	6	1425	54254	35737	\N	54.634897639014397	д.Озеро, ул.Молодежная, 6	Россия, Калужская область, Юхновский район, поселок Озеро	0101000020E6100000ED48F59D5F9A4140DD25715644514B40
38653	1	6	1425	45597	35604	\N	54.595033000000001	д.Куркино, ул.Школьная, 2		0101000020E61000000C8FFD2C96A441403885950A2A4C4B40
38441	1	6	1425	45954	\N	\N	54.615355000000001	"Село Кудиново, Помещение администрации сельского поселения ""Село Кудиново"""		0101000020E610000041BB438A01BA41400D37E0F3C34E4B40
38651	1	6	1425	21846	35567	\N	54.760584000000001	д.Колыхманово, ул.Центральная, 16	Россия, Калужская область, Юхновский район, поселок Колыхманово	0101000020E6100000F6CE68AB92A4414031EE06D15A614B40
38650	1	6	1425	21805	35513	\N	54.832391000000001	с.Климов Завод, ул.Генерала М.Г. Ефремова, 45		0101000020E610000024B55032397541400C3ECDC98B6A4B40
38661	1	6	1425	60398	74953	\N	54.559112726812202	д.Зубово, ул.Шоссейная, 6	Россия, Калужская область, Юхновский район, поселок Зубово	0101000020E6100000E6B0FB8EE1BD41405DE2C80391474B40
38663	1	6	1425	60395	74950	\N	54.695147414476203	д.Емельяновка, ул.Центральная, 15	Россия, Калужская область, Юхновский район, поселок Емельяновка	0101000020E6100000B0373124279D4140CD74AF93FA584B40
38316	1	6	1425	48068	\N	\N	54.593457999999998	д. Выползово, сельский дом культуры		0101000020E6100000759483D904CE414058C6866EF64B4B40
38649	1	6	1425	45510	35596	\N	54.802391	д.Беляево, ул.Центральная, 11		0101000020E610000015191D90848B414068CD8FBFB4664B40
38644	1	6	1649	21485	35299	\N	53.466988999999998	село Хвастовичи, ул.Ленина, д.28	Россия, Калужская область, Хвастовичский район, поселок Хвастовичи	0101000020E61000002BD9B111888B4140BE4BA94BC6BB4A40
38645	1	6	1649	21485	35258	\N	53.467324789174697	село Хвастовичи, ул.Павлова, д.7	Россия, Калужская область, Хвастовичский район, поселок Хвастовичи	0101000020E6100000EE3D5C72DC8B414036CD3B4ED1BB4A40
38581	1	6	1649	48721	\N	\N	53.573359000000004	д. Фролово, 10		0101000020E61000000A82C7B77789414003EFE4D363C94A40
38636	1	6	1649	49549	35601	\N	53.429788000000002	деревня Теребень, ул.Советская, д.7		0101000020E6100000006F8104C5A141404C1B0E4B03B74A40
38553	1	6	1649	54231	35649	\N	53.406438821908203	д.Стайки, Школьная, 1	Россия, Калужская область, Хвастовичский район, поселок Стайки	0101000020E6100000CC46E7FC148F4140D368723106B44A40
38641	1	6	1649	21368	35536	\N	53.499701000000002	село Подбужье, ул.Молодежная, д.4	Россия, Калужская область, Хвастовичский район, поселок Подбужье	0101000020E6100000A73CBA1116774140A663CE33F6BF4A40
38640	1	6	1649	21315	35588	\N	53.453152000000003	село Пеневичи, ул.Декабристов, д.2	Россия, Калужская область, Хвастовичский район, поселок Пеневичи	0101000020E61000002711E15F047D4140FA0E7EE200BA4A40
38639	1	6	1649	21258	35595	\N	53.422812999999998	деревня Нехочи, ул.Центральная, д.1		0101000020E61000004AB4E4F1B47641406DA983BC1EB64A40
37983	1	6	1649	21399	\N	\N	53.508719309063999	д. Милеево, 77	Россия, Калужская область, Хвастовичский район, поселок Милеево	0101000020E61000008D4468041B9941404AED45B41DC14A40
38638	1	6	1649	21399	35750	\N	53.503578390830398	село Милеево, ул.Гривская, д.1	Россия, Калужская область, Хвастовичский район, поселок Милеево	0101000020E6100000EC4FE27327984140177E703E75C04A40
38637	1	6	1649	21172	35531	\N	53.630029	село Ловать, ул.Волостная, д.20		0101000020E61000002F4FE78A528241400B444FCAA4D04A40
38635	1	6	1649	21086	35510	\N	53.396222000000002	село Кудрявец, ул.Советская, д.7		0101000020E6100000F0A7C64B37A3414055FA0967B7B24A40
38634	1	6	1649	60414	74982	\N	53.443060581398598	село Красное, ул.Комсомольская, д.107	Россия, Калужская область, Хвастовичский район, поселок Красное	0101000020E61000004D81CCCEA295414008910C39B6B84A40
38633	1	6	1649	20995	35638	\N	53.555929999999996	село Колодяссы, ул.Новостройка, д.14		0101000020E6100000D8497D59DA994140C16ED8B628C74A40
38646	1	6	1649	54195	35323	\N	53.482462487463998	"Калужская область, муниципальный район ""Хвастовичский район"", сельское поселение ""Поселок Еленский"", ул. Партизанский проспект"	Россия, Калужская область, Хвастовичский район, поселок Еленский	0101000020E61000001D76DF313CB0414008C89750C1BD4A40
38632	1	6	1649	20923	35535	\N	53.545428000000001	село Воткино, ул.Советская, д.4		0101000020E6100000A852B3075A7D41404E29AF95D0C54A40
38319	1	6	1649	48139	\N	\N	53.513078	д. Буда, сельский дом культуры	Россия, Калужская область, Хвастовичский район, поселок Буда	0101000020E6100000780AB952CF8841400726378AACC14A40
38631	1	6	1649	20895	35538	\N	53.412073999999997	село Бояновичи, ул.Коммунарская, д.27/А	Россия, Калужская область, Хвастовичский район, поселок Бояновичи	0101000020E61000000EBDC5C37B6C414015C440D7BEB44A40
38662	1	6	1649	45772	\N	\N	53.616683000000002	д.Барановка, ул.Пригородная, 46		0101000020E6100000BABA63B14D8A4140E57FF277EFCE4A40
38124	1	6	1067	40421	74966	\N	54.326962999999999	д.Плюсково, ул.Центральная, дом №42	Россия, Калужская область, Ферзиковский район, поселок Плюсково	0101000020E61000000684D6C397694240430070ECD9294B40
38611	1	6	1067	49213	\N	\N	54.353847999999999	"Поселок Октябрьский, 4 ""г"""	Россия, Калужская область, Ферзиковский район, поселок Октябрьский	0101000020E610000037C30DF8FC624240A4E029E44A2D4B40
38624	1	6	1067	41364	\N	\N	54.538173	"Деревня Красный Городок, Коммунаров, 2""в"""	Россия, Калужская область, Ферзиковский район, поселок Красный Городок	0101000020E61000000536E7E0993442408C4B55DAE2444B40
38623	1	6	1067	49356	74949	\N	54.450476000000002	Село Кольцово, Колхозная, 3		0101000020E61000005EDA70581A56424003D19332A9394B40
38622	1	6	1067	20393	35644	\N	54.383021999999997	Деревня Зудна, Лесная, 10		0101000020E610000067D311C0CD64424002D369DD06314B40
38612	1	6	1067	19816	35584	\N	54.594453999999999	Поселок Желябужский, Школьная, 12	Россия, Калужская область, Ферзиковский район, поселок Желябужский	0101000020E610000060AC6F6072434240FA7C9411174C4B40
38621	1	6	1067	20300	35443	\N	54.417101000000002	Поселок Дугна, Больничная, 11		0101000020E6100000DF6B088ECB6C42408010C99063354B40
38628	1	6	1067	20740	35496	\N	54.462341000000002	Деревня Бронцы, Центральная, 6	Россия, Калужская область, Ферзиковский район, поселок Бронцы	0101000020E610000099D87C5C1B644240CB4C69FD2D3B4B40
38620	1	6	1067	20279	\N	\N	54.401260000000001	Село Богданино, 88	Россия, Калужская область, Ферзиковский район, поселок Богданино	0101000020E6100000C5538F34B86D4240B398D87C5C334B40
38547	1	6	1067	16482	35456	\N	54.530248	Деревня Бебелево, Центральная, 30	Россия, Калужская область, Ферзиковский район, поселок Бебелево	0101000020E61000001288D7F50B4042407C629D2ADF434B40
34050	1	6	1067	22399	35448	\N	54.460979999999999	"Авчурино, Центральная, 23 ""а"""		0101000020E6100000DD9A745B22374240170E8464013B4B40
38617	1	6	1589	54181	\N	\N	53.717486000000001	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Ульяново"", Здание правления колхоза ""Красное Знамя"""	Россия, Калужская область, Ульяновский район, поселок Ульяново	0101000020E61000008CA03193A8C541403FABCC94D6DB4A40
38618	1	6	1589	54181	35221	\N	53.716917286827297	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Ульяново"", Большая Советская, 88"	Россия, Калужская область, Ульяновский район, поселок Ульяново	0101000020E6100000533D997FF4C541402579AEEFC3DB4A40
38616	1	6	1589	54217	\N	\N	53.677059999999997	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Поздняково"", Здание администрации сельского поселения ""Село Поздняково"""	Россия, Калужская область, Ульяновский район, поселок Поздняково	0101000020E6100000C9E369F981F1414002B7EEE6A9D64A40
38615	1	6	1589	54217	\N	\N	53.677059999999997	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Поздняково"", Здание Брежневского сельского дома культуры"	Россия, Калужская область, Ульяновский район, поселок Поздняково	0101000020E6100000C9E369F981F1414002B7EEE6A9D64A40
38614	1	6	1589	54217	\N	\N	53.677059999999997	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Поздняково"", Здание МОУ ""Кирейковская основная общеобразовательная школа"""	Россия, Калужская область, Ульяновский район, поселок Поздняково	0101000020E6100000C9E369F981F1414002B7EEE6A9D64A40
38613	1	6	1589	54217	\N	\N	53.677059999999997	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Поздняково"", Здание МОУ ""Касьяновская основная общеобразовательная школа"""	Россия, Калужская область, Ульяновский район, поселок Поздняково	0101000020E6100000C9E369F981F1414002B7EEE6A9D64A40
38136	1	6	1589	48973	\N	\N	53.686414999999997	поселок Новый, 125		0101000020E61000003B191C25AFEC4140EE3D5C72DCD74A40
38610	1	6	1589	54220	\N	\N	53.600977	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Деревня Мелихово"", Здание администрации сельского поселения ""Деревня Мелихово"""	Россия, Калужская область, Ульяновский район, поселок Мелехово	0101000020E6100000A43330F2B2CC4140F85278D0ECCC4A40
38609	1	6	1589	54220	\N	\N	53.600977	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Деревня Мелихово"", Здание Крапивенского ФАП"	Россия, Калужская область, Ульяновский район, поселок Мелехово	0101000020E6100000A43330F2B2CC4140F85278D0ECCC4A40
38606	1	6	1589	54250	\N	\N	55.098437052319902	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Заречье"", Здание МОУ ""Сорокинская основная общеобразовательная школа"""	Россия, Калужская область, поселок Заречье	0101000020E6100000E162450DA6474240B1DB6795998C4B40
38602	1	6	1589	54207	\N	\N	53.658095000000003	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Дудоровский"", Здание Дудоровского сельского дома культуры"	Россия, Калужская область, Ульяновский район, поселок Дудоровский	0101000020E6100000F5B86FB54EAE4140A054FB743CD44A40
38472	1	6	1589	60389	74938	\N	53.729643517148297	д. Долгое, ул Ани Морозовой, д. 7	Россия, Калужская область, Ульяновский район, поселок Долгое	0101000020E61000001ADEACC1FBCA41407FDC7EF964DD4A40
38030	1	6	1589	23567	\N	\N	53.767395	"Калужская область, Бабынинский район"" деревня Вязовна, Здание школы"	Россия, Калужская область, Ульяновский район, поселок Вязовна	0101000020E6100000397D3D5FB3AE4140950ED6FF39E24A40
38604	1	6	1589	54218	\N	\N	53.829835000000003	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Волосово - Дудино"", Здание МОУ ""Жильковская основная общеобразовательная школа"""	Россия, Калужская область, Ульяновский район, поселок Волосово-Дудино	0101000020E6100000280CCA349ACC4140C009850838EA4A40
38603	1	6	1589	54218	\N	\N	53.829835000000003	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Волосово - Дудино"", Здание администр сельского поселения ""Село Волосово-Дудино"""	Россия, Калужская область, Ульяновский район, поселок Волосово-Дудино	0101000020E6100000280CCA349ACC4140C009850838EA4A40
38433	1	6	7129	51921	\N	\N	56.912998999999999	п.Чуриково	Россия, Тверская область, Торжокский район, поселок Чуриково	0101000020E61000007B2E5393E0774140EE23B726DD744C40
38588	1	6	1547	54176	35337	\N	54.731440999999997	"Калужская область, муниципальный район ""Тарусский район"", городское поселение ""Город Таруса"", Шевякова, 10"		0101000020E61000009694BBCFF19542400DFAD2DB9F5D4B40
38586	1	6	1547	54176	35192	\N	54.731440999999997	"Калужская область, муниципальный район ""Тарусский район"", городское поселение ""Город Таруса"", Марины Цветаевой, 1"	Россия, Калужская область, Тарусский район, Таруса	0101000020E61000009694BBCFF19542400DFAD2DB9F5D4B40
38589	1	6	1547	54176	35405	\N	54.731440999999997	"Калужская область, муниципальный район ""Тарусский район"", городское поселение ""Город Таруса"", Ленина, 74"	Россия, Калужская область, Тарусский район, Таруса	0101000020E61000009694BBCFF19542400DFAD2DB9F5D4B40
38594	1	6	1547	54239	35663	\N	54.779172000000003	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Роща"", Центральная, 15"	Россия, Калужская область, Тарусский район, поселок Роща	0101000020E61000005793A7ACA66B4240BEFA78E8BB634B40
38601	1	6	1547	54238	35662	\N	54.738540999999998	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Деревня Похвиснево"", Центральная, 3"	Россия, Калужская область, Тарусский район, поселок Похвиснево	0101000020E6100000E50AEF72118B4240A8E0F082885E4B40
38595	1	6	1547	54236	35660	\N	54.617258	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Петрищево"", пер.Садовый, 1"	Россия, Калужская область, Тарусский район, поселок Петрищево	0101000020E6100000E197FA7953794240E198654F024F4B40
38593	1	6	1547	54225	35581	\N	54.828802000000003	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Некрасово"", Тарусская, 23/1"		0101000020E6100000677FA0DCB6914240016E162F166A4B40
38532	1	6	1547	47812	\N	\N	54.593040000000002	с.Макарово, 11		0101000020E61000000B9A965819874240249C16BCE84B4B40
38600	1	6	1547	54214	35495	\N	54.738529625584697	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Лопатино"", Центральная, 4б"	Россия, Калужская область, Тарусский район, поселок Лопатино	0101000020E6100000BD1C76DF31804240B48EAA26885E4B40
38591	1	6	1547	54213	35494	\N	54.765804000000003	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Кузьмищево"", Центральная, 10"	Россия, Калужская область, Тарусский район, поселок Кузьмищево	0101000020E6100000B340BB438A994240B0928FDD05624B40
38592	1	6	1547	54213	35508	\N	54.765804000000003	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Кузьмищево"", д.Игнатовское, Вишневая, 17"	Россия, Калужская область, Тарусский район, поселок Кузьмищево	0101000020E6100000B340BB438A994240B0928FDD05624B40
38133	1	6	1547	28356	\N	\N	54.769269000000001	деревня Кочуково, 15		0101000020E6100000CE88D2DEE0674240CF69166877624B40
38598	1	6	1547	54234	35658	\N	54.822516	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Волковское"", Полевая, 62"	Россия, Калужская область, Тарусский район, поселок Волковское	0101000020E6100000A33A1DC87A9A4240E7374C3448694B40
38599	1	6	1547	54242	35666	\N	54.603717000000003	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Вознесенье"", Центральная, 4"	Россия, Калужская область, Тарусский район, поселок Вознесение	0101000020E61000003946B247A889424006854199464D4B40
38597	1	6	1547	54240	35664	\N	54.729604999999999	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Село Барятино"", Советская, 15"	Россия, Калужская область, Тарусский район, поселок Барятино	0101000020E61000005039268BFB694240C1FF56B2635D4B40
38596	1	6	1547	54241	35665	\N	54.662906	"Калужская область, муниципальный район ""Тарусский район"", сельское поселение ""Деревня Алекино"", Садовая, 1"	Россия, Калужская область, Тарусский район, поселок Алекино	0101000020E61000004777103B539642403D29931ADA544B40
38582	1	6	1456	48733	\N	\N	54.174012053599398	д. Юрьево, 34	Россия, Калужская область, Сухиничский район, поселок Юрьево	0101000020E6100000BB9C121093BE4140478E740646164B40
38579	1	6	1456	40253	\N	\N	54.169728277337299	с. Шлиппово, 68		0101000020E6100000B28174B1698F4140959BA8A5B9154B40
38571	1	6	1456	17684	\N	\N	54.144699000000003	д. Хотень, 76	Россия, Калужская область, Сухиничский район, поселок Хотень	0101000020E6100000E525FF93BFB94140C861307F85124B40
38578	1	6	1456	40455	\N	\N	54.135731999999997	д. Уруга, 21	Россия, Калужская область, Сухиничский район, поселок Уруга	0101000020E6100000B685E7A562814140A5828AAA5F114B40
38576	1	6	1456	17941	35550	\N	54.083491000000002	д. Татаринцы, ул. Речная, 15	Россия, Калужская область, Сухиничский район, поселок Татаринцы	0101000020E6100000FB928D075BB44140534145D5AF0A4B40
38583	1	6	1456	17092	35277	\N	54.104391	г. Сухиничи, Ленина, 56	Россия, Калужская область, Сухиничский район, Сухиничи	0101000020E6100000B2BCAB1E30AB4140957F2DAF5C0D4B40
38585	1	6	1456	17092	35214	\N	54.104391	г. Сухиничи, Марченко, 53		0101000020E6100000B2BCAB1E30AB4140957F2DAF5C0D4B40
38559	1	6	1456	17092	35286	\N	54.104391	г. Сухиничи, Ленина, 49		0101000020E6100000B2BCAB1E30AB4140957F2DAF5C0D4B40
38584	1	6	1456	17092	35287	\N	54.104391	г. Сухиничи, Ленина, 92		0101000020E6100000B2BCAB1E30AB4140957F2DAF5C0D4B40
38561	1	6	1456	17092	35333	\N	54.104391	г. Сухиничи, Дзержинского, 11		0101000020E6100000B2BCAB1E30AB4140957F2DAF5C0D4B40
38575	1	6	1456	48621	\N	\N	53.982199999999999	д. Субботники, 64	Россия, Калужская область, Сухиничский район, поселок Субботники	0101000020E6100000D65757056AB74140CB10C7BAB8FD4A40
38574	1	6	1456	48590	\N	\N	54.233269	д. Соболевка, 42	Россия, Калужская область, Сухиничский район, поселок Соболевка	0101000020E6100000BF0E9C33A2744140D71533C2DB1D4B40
38562	1	6	1456	17250	35272	\N	54.050936999999998	пос. Середейский, Комсомольская, 11		0101000020E6100000FC36C478CD9D41400394861A85064B40
38573	1	6	1456	17775	\N	\N	54.022722000000002	д. Радождево, 75а		0101000020E61000002FF99FFCDDA741402A73F38DE8024B40
33276	1	6	1456	54219	\N	\N	54.060720314572499	д. Ермолово, 39	Россия, Калужская область, Сухиничский район, поселок Ермолово	0101000020E6100000AC1DC539EA9E4140481B47ACC5074B40
38569	1	6	1456	17572	\N	\N	54.225510999999997	пос. Дабужа, 123		0101000020E6100000310C587215674140B2F1608BDD1C4B40
38567	1	6	1456	48473	\N	\N	54.175155699056702	д. Глазково, 46	Россия, Калужская область, Сухиничский район, поселок Глазково	0101000020E61000009A27D714C8B041405ED905836B164B40
38577	1	6	1456	48656	\N	\N	54.216056999999999	д. Володино, 44		0101000020E6100000C328081EDF8A414033897AC1A71B4B40
38572	1	6	1456	17758	\N	\N	54.088054	д. Брынь, 102а		0101000020E610000055A357039496414018247D5A450B4B40
38131	1	6	1456	17758	35473	\N	54.088054	село Брынь, им. Т.П. Полянской, 16		0101000020E610000055A357039496414018247D5A450B4B40
38564	1	6	1456	48423	\N	\N	54.116129999999998	д. Бордуково, 59		0101000020E61000002A029CDEC5A74140D00A0C59DD0E4B40
38570	1	6	1456	17647	\N	\N	53.904491	д. Богданово-Колодези, 77		0101000020E610000086E7A56263B241405F43705CC6F34A40
38563	1	6	1456	17271	\N	\N	54.143084999999999	д. Алнеры, 1		0101000020E61000006F490ED8D5A841402AC6F99B50124B40
38558	1	6	1441	17044	35454	\N	54.388432999999999	с.Чипляево, Центральная, 7		0101000020E61000000E9E094D12194140F5D72B2CB8314B40
38459	1	6	1441	46366	35570	\N	54.382995999999999	село Терпилово, Мира, 1		0101000020E6100000863DEDF0D7DE4040D93F4F0306314B40
38552	1	6	1441	48200	35509	\N	54.416660999999998	д.Теплово, Центральная, 5		0101000020E6100000698F17D2E10941406342CC2555354B40
38643	1	6	1441	45416	35701	\N	54.295946999999998	"деревня Стайки"", ул.Молодежная, д.19"		0101000020E61000003BAC70CB47184140B62C5F97E1254B40
38554	1	6	1441	16847	35499	\N	54.356451	д.Снопот, Снопотская, 1		0101000020E61000008044132862E1404031D0B52FA02D4B40
38549	1	6	1441	48153	35636	\N	54.264412	д.Понизовье, Приозерная, 2	Россия, Калужская область, Спас-Деменский район, поселок Понизовье	0101000020E6100000FB07910C39084140C1559E40D8214B40
38551	1	6	1441	16693	35558	\N	54.480426191971603	с.Павлиново, Центральная, 10	Россия, Калужская область, Спас-Деменский район, поселок Павлиново	0101000020E61000008A7780272DE04040F51263997E3D4B40
38546	1	6	1441	54252	35722	\N	54.345275548662798	х. Новоалександровский, пер.Школьный, 5	Россия, Калужская область, Спас-Деменский район, поселок Новоалександровский	0101000020E6100000DA38622D3E094140FE0B0401322C4B40
38548	1	6	1441	16535	35506	\N	54.423602000000002	д.Нестеры, Бориса Кривельского, 8		0101000020E61000004A97FE25A9D840409642209738364B40
38544	1	6	1441	16335	35583	\N	54.331336999999998	с.Любунь, пер.Школьный, 6	Россия, Калужская область, Спас-Деменский район, поселок Любунь	0101000020E61000004087F9F202EC4040357A3540692A4B40
38557	1	6	1441	16985	35529	\N	54.308649047556202	с.Буднянский, Школьная, 16		0101000020E6100000E6CFB7054BF94040B87878CF81274B40
38543	1	6	1441	16268	74957	\N	54.400489999999998	д.Болва, Центральная, 11		0101000020E6100000F65E7CD11EFB404001309E4143334B40
38538	1	6	1412	16030	\N	\N	54.348621000000001	д.Сильково, 110	Россия, Калужская область, Перемышльский район, поселок Сильково	0101000020E6100000FC1A49827009424073D9E89C9F2C4B40
38534	1	6	1412	15835	35289	\N	54.263629000000002	с.Перемышль, Ленина, 54		0101000020E6100000111E6D1CB11442407BA35698BE214B40
38531	1	6	1412	15687	35481	\N	54.328439000000003	с.Корекозево, Центральная, 55		0101000020E61000007BC03C64CA17424090DD054A0A2A4B40
38526	1	6	1412	54199	35362	\N	54.420212895609801	с.Калужская опытная сельскохозяйственная станция, Центральная, здание Спортивного комплекса	Россия, Калужская область, Перемышльский район, поселок Калужской опытной сельскохозяйственой станции	0101000020E6100000697407B1330B4240512D228AC9354B40
38542	1	6	1412	16222	\N	\N	54.286287000000002	д. Григоровское, 57	Россия, Калужская область, Перемышльский район, поселок Григоровское	0101000020E6100000C8ED974F562C42408E226B0DA5244B40
38528	1	6	1412	47743	\N	\N	54.241283000000003	"с.Гремячево, 191 ""А"""	Россия, Калужская область, Перемышльский район, поселок Гремячево	0101000020E6100000CA1B60E63B204240570A815CE21E4B40
38541	1	6	1412	16167	\N	\N	54.376404999999998	с.Борищево, 90		0101000020E6100000016A6AD95A0142408386FE092E304B40
38530	1	6	1412	15649	\N	\N	54.416649999999997	"д.Большие Козлы, 17 ""Б"""		0101000020E61000001D3D7E6FD32942406FF085C954354B40
38540	1	6	1412	47960	35449	\N	54.441769000000001	с.Ахлебинино, Центральная, 64		0101000020E61000006D54A703593942407DB1F7E28B384B40
38198	1	6	7188	52455	\N	\N	56.371929000000002	д. Михали, помещение администрации МО СП д. Михали, 48		0101000020E61000002976340EF5F33D408DB7955E9B2F4C40
38471	1	6	1252	12873	35612	\N	54.633983999999998	пос. Шаховский, ул Центральная, д. 10	Россия, Калужская область, Мосальский район, колхоз Шаховский	0101000020E610000069AD68739C694140F817416326514B40
38490	1	6	1252	13740	35615	\N	54.456384999999997	д. Устоша, ул. Широкая, д. 8	Россия, Калужская область, Мосальский район, поселок Устоша	0101000020E6100000DC82A5BA8075414046B1DCD26A3A4B40
38481	1	6	1252	46809	35497	\N	54.480251000000003	д. Тарасково, ул. Молодежная, д. 16		0101000020E61000000E1478279F864140876F61DD783D4B40
38477	1	6	1252	54243	35667	\N	54.589410000000001	поселок Раменский, ул. Центральная, д. 10	Россия, Калужская область, Мосальский район, колхоз Раменский	0101000020E6100000B2A03028D3724140BAF770C9714B4B40
38476	1	6	1252	46704	35578	\N	54.568494999999999	"д. Передовик, ул Школьная, д. 1 ""Б"""	Россия, Калужская область, Мосальский район, поселок Передовик	0101000020E6100000ADA7565F5D7B41404278B471C4484B40
38485	1	6	1252	13454	35298	\N	54.489455999999997	г. Мосальск, ул. Кирова, д. 44		0101000020E6100000C39D0B23BD7C41405D6A847EA63E4B40
38484	1	6	1252	13454	35331	\N	54.489455999999997	г. Мосальск, ул. Революции, д. 10		0101000020E6100000C39D0B23BD7C41405D6A847EA63E4B40
38474	1	6	1252	12994	35616	\N	54.602694999999997	д. Людково, ул. Шоссейная, д. 11		0101000020E6100000817C09151C5C41403A3B191C254D4B40
38368	1	6	1252	40420	\N	\N	54.434438	д.Каменка, МБОУ <<Основная общеобразовательная школа>>	Россия, Калужская область, Мосальский район, поселок Каменка	0101000020E6100000E0F42EDE8F734140E01115AA9B374B40
38473	1	6	1252	54249	35708	\N	54.528144163388603	пос. Калуговский, ул Школьная, д. 7		0101000020E6100000758F6CAE9A35414010CAFB389A434B40
38489	1	6	1252	46975	35580	\N	54.429724999999998	с. Дашино, ул. Сельская, д. 30	Россия, Калужская область, Мосальский район, поселок Дашино	0101000020E610000070D05E7D3C6C414005A3923A01374B40
38488	1	6	1252	46958	\N	\N	54.530290000000001	д. Горбачи, ул. Зеленая, д. 26	Россия, Калужская область, Мосальский район, поселок Горбачи	0101000020E6100000D80C7041B6944140ABB2EF8AE0434B40
38487	1	6	1252	46929	35631	\N	54.504468000000003	д. Гачки, ул. Центральная, д. 32	Россия, Калужская область, Мосальский район, поселок Гачки	0101000020E6100000B1169F02607E414074F04C6892404B40
35456	1	6	1252	46061	\N	\N	54.533712000000001	деревня Высокое, Садовая, 2	Россия, Калужская область, Мосальский район, поселок Высокое	0101000020E610000095B6B8C6677C4140CBBDC0AC50444B40
38483	1	6	1252	13413	35634	\N	54.482233000000001	с. Боровенск, ул. Центральная, д. 1	Россия, Калужская область, Мосальский район, поселок Боровенск	0101000020E61000009CC0745AB7934140A7069ACFB93D4B40
38457	1	6	1215	12205	35609	\N	54.376724000000003	деревня Торкотино, Центральная, 8	Россия, Калужская область, Мещовский район, поселок Торкотино	0101000020E61000007592AD2EA7B6414025CFF57D38304B40
38458	1	6	1215	12283	35461	\N	54.336312999999997	село Серпейск, Пушкина, 7	Россия, Калужская область, Мещовский район, поселок Серпейск	0101000020E6100000D9E90775917E41401D1CEC4D0C2B4B40
38467	1	6	1215	12704	35614	\N	54.343708999999997	село Серебряно, Центральная, 3		0101000020E6100000FCFF3861C29E4140A12B11A8FE2B4B40
38465	1	6	1215	46483	35579	\N	54.314418000000003	деревня Растворово, Садовая, 9	Россия, Калужская область, Мещовский район, поселок Растворово	0101000020E61000004D4A41B7979841400AA359D93E284B40
38453	1	6	1215	12034	35444	\N	54.250669000000002	станция Кудринская, Козельская, 4		0101000020E6100000C30FCEA78EC541407E8FFAEB15204B40
38470	1	6	1215	46603	35527	\N	54.474972000000001	село  Подкопаево, Лесная, 4	Россия, Калужская область, Мещовский район, поселок Подкопаево	0101000020E610000045847F1134B641400342EBE1CB3C4B40
38466	1	6	1215	46514	74958	\N	54.310812163841398	деревня Нестеровка, Коммунарская, 16	Россия, Калужская область, Мещовский район, поселок Нестеровка	0101000020E61000007FDAA84E07B24140289A07B0C8274B40
38454	1	6	1215	12087	35525	\N	54.282550000000001	село Мошонки, Старая, 28	Россия, Калужская область, Мещовский район, поселок Мошонки	0101000020E61000003B8A73D4D1CF41400EBE30992A244B40
38463	1	6	1215	12501	35237	\N	54.319071000000001	город Мещовск, проспект Революции, 28		0101000020E610000000E48409A3A341400F0D8B51D7284B40
38464	1	6	1215	12501	35211	\N	54.319071000000001	город Мещовск, площадь Ленина, 3		0101000020E610000000E48409A3A341400F0D8B51D7284B40
38456	1	6	1215	46280	35526	\N	54.376766000000003	село Мармыжи, Школьная, 5	Россия, Калужская область, Мещовский район, поселок Мармыжи	0101000020E6100000E2900DA48BC14140541F48DE39304B40
38460	1	6	1215	46382	\N	\N	54.227980000000002	деревня Казаковка, Большая сторона, 7	Россия, Калужская область, Мещовский район, поселок Казаковка	0101000020E6100000CD3FFA264D9741403012DA722E1D4B40
38469	1	6	1215	46572	35501	\N	54.437978000000001	село Гаврики, Молодежная, 5		0101000020E6100000BF81C98D22AB41400A2FC1A90F384B40
38468	1	6	1215	46539	35507	\N	54.379457000000002	деревня Б.Алешино, Новая, 1		0101000020E6100000D9791B9B1DA54140809E060C92304B40
38197	1	6	1049	45666	74956	\N	55.064833999999998	д. Хвощи, Мира, 2		0101000020E6100000B2B96A9E23EC41409DD5027B4C884B40
33090	1	6	1049	49183	\N	\N	54.972954000000001	д.Романово, 23		0101000020E6100000CB845FEAE7DF41409641B5C1897C4B40
38097	1	6	1049	48304	\N	\N	55.039223	д.Редькино, дом № 15		0101000020E6100000BEDA519CA308424021205F4205854B40
32422	1	6	1049	49482	\N	\N	55.202542999999999	с. Передел, 85	Россия, Калужская область, Медынский район, поселок Передел	0101000020E610000045BA9F5390D741405184D4EDEC994B40
36896	1	6	1049	40292	\N	\N	54.997690818336601	д.Обухово, дом № 2а	Россия, Калужская область, Медынский район, поселок Обухово	0101000020E61000005DA45016BEDC4140BC41B456B47F4B40
32321	1	6	1049	47783	\N	\N	55.214891999999999	с. Никитское, 122		0101000020E6100000522B4CDF6BE441400516C094819B4B40
38450	1	6	1049	11861	\N	\N	54.947040999999999	д. Михальчуково, 3		0101000020E6100000F8FC304278DE41404E7CB5A338794B40
38446	1	6	1049	11707	35316	\N	54.966887	г. Медынь, проспект Ленина, 2		0101000020E61000006ABFB51325EF4140BAF605F4C27B4B40
38447	1	6	1049	11707	35307	\N	54.966887	г. Медынь, Володарского, 63		0101000020E61000006ABFB51325EF4140BAF605F4C27B4B40
38449	1	6	1049	11835	\N	\N	55.107072000000002	с. Кременское, 181	Россия, Калужская область, Медынский район, поселок Кременское	0101000020E6100000E5EFDE5163FA41409E280989B48D4B40
38445	1	6	1049	46040	\N	\N	55.059559	д. Гусево, 1	Россия, Калужская область, Медынский район, поселок Гусево	0101000020E61000005531957EC2D541405B971AA19F874B40
38444	1	6	1049	54224	\N	\N	55.051602000000003	"Калужская область, муниципальный район ""Медынский район"", сельское поселение ""Деревня Глухово"", 36"	Россия, Калужская область, Медынский район, поселок Глухово	0101000020E610000044FCC3961E0542404034F3E49A864B40
38448	1	6	1049	46099	\N	\N	55.018411999999998	д. Варваровка, 56		0101000020E6100000821FD5B0DFEF41404EED0C535B824B40
32516	1	6	1049	47124	\N	\N	55.191135000000003	д. Брюхово, 50	Россия, Калужская область, Медынский район, поселок Брюхово	0101000020E610000078CF81E508F341407C0F971C77984B40
33122	1	6	1049	9192	\N	\N	54.985714999999999	с. Адуево, 115		0101000020E61000000CE71A6668FE41409C16BCE82B7E4B40
38418	1	6	1120	45496	\N	\N	54.766385999999997	Поселок Юбилейный, Помещение Дома культуры	Россия, Калужская область, Малоярославецкий район, поселок Юбилейный	0101000020E610000066DCD440F32342405E0EBBEF18624B40
38419	1	6	1120	45508	\N	\N	54.991804999999999	Деревня Шумятино, Помещение Шумятинского Дома культуры	Россия, Калужская область, Малоярославецкий район, поселок Шумятино	0101000020E6100000C233A149622B424030815B77F37E4B40
38411	1	6	1120	60392	\N	\N	54.912661081800202	"Село Головтеево, Помещение администрации селького поселения ""Село Головтеево"""	Россия, Калужская область	0101000020E610000042791F4773304240D6AA5D13D2744B40
38417	1	6	1120	45478	\N	\N	54.851179000000002	Деревня Рябцево, Помещение бывшей школы	Россия, Калужская область, Малоярославецкий район, поселок Рябцево	0101000020E61000006EA7AD11C11842406005F86EF36C4B40
38415	1	6	1120	45443	\N	\N	54.871952999999998	"Село Поречье, Помещение администрации Пореченской фабрики ""Фи-Текс"""	Россия, Калужская область, Малоярославецкий район, поселок Поречье	0101000020E6100000D525E318C94842401553E9279C6F4B40
38420	1	6	1120	45530	\N	\N	55.033253999999999	Деревня Панское, Помещение Панской основной общеобразовательной школы	Россия, Калужская область, Малоярославецкий район, поселок Панское	0101000020E6100000EF2076A6D0314240083BC5AA41844B40
38414	1	6	1120	10160	\N	\N	54.838157000000002	Село Недельное, Помещение Дома культуры	Россия, Калужская область, Малоярославецкий район, поселок Недельное	0101000020E6100000EB19C231CB524240EDF483BA486B4B40
38413	1	6	1120	45412	\N	\N	54.837612	"Деревня Михеево, Помещение администрации сельского поселеният ""Деревня Михеев"	Россия, Калужская область, Малоярославецкий район, поселок Михеево	0101000020E6100000554CA59F702A42405B5EB9DE366B4B40
33106	1	6	1120	45412	\N	\N	54.837686279770601	д. Михеево, 137	Россия, Калужская область, Малоярославецкий район, поселок Михеево	0101000020E61000007C60C77F812A424095287B4B396B4B40
38438	1	6	1120	45883	\N	\N	54.920020000000001	"Деревня Ерденево, Помещение администрации сельского поселения ""Деревня Ерденев"	Россия, Калужская область, Малоярославецкий район, поселок Ерденево	0101000020E6100000841266DAFE3742403DD52137C3754B40
38422	1	6	1120	10558	\N	\N	54.811217999999997	Село Детчино, Помещение Дома культуры	Россия, Калужская область, Малоярославецкий район, поселок Детчино	0101000020E6100000E36E10AD1527424098F6CDFDD5674B40
38437	1	6	1120	54208	\N	\N	54.876112999999997	"Село Санаторий ""Воробьево"", Помещение клуба санатория ""Воробьево"""	Россия, Калужская область, Малоярославецкий район, санаторий Воробьево	0101000020E61000006CB2463D44314240DB4C857824704B40
38436	1	6	1120	45830	\N	\N	54.869092999999999	Деревня Воробьево, Помещение сельского Дома культуры	Россия, Калужская область, Малоярославецкий район, поселок Воробьево	0101000020E61000008884EFFD0D3042405D177E703E6F4B40
38480	1	6	1001	46791	74939	\N	53.887900000000002	д. Савино, ул. Центральная, д. 2		0101000020E6100000F705F4C29D2B4140280F0BB5A6F14A40
38406	1	6	1001	9758	35591	\N	53.975126000000003	Калужская область, Людиновский район, деревня Манино, Горчакова, 38		0101000020E610000048A643A7E72B41405ABDC3EDD0FC4A40
38384	1	6	1001	8615	35205	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Энгельса, 48		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38388	1	6	1001	8615	35206	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Фокина, 55		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38391	1	6	1001	8615	35207	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Сестер Хотеевых, 5		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38386	1	6	1001	8615	35254	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Попова, 33		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38397	1	6	1001	8615	35208	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Герцена, 24		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38396	1	6	1001	8615	35210	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Щербакова, 1		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38395	1	6	1001	8615	35210	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Щербакова, 3		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38387	1	6	1001	8615	35268	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Чугунова, 4		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38399	1	6	1001	8615	35270	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Черняховского, 17-б		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38390	1	6	1001	8615	35284	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Московская, 17		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38398	1	6	1001	8615	35240	\N	53.858692057471202	Калужская область, Людиновский район, город Людиново, Маяковского, 250а	Россия, Калужская область, Людиновский район, Людиново	0101000020E6100000D7C22CB4733841401DAB949EE9ED4A40
38381	1	6	1001	8615	35204	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Ленина, 3-а		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38385	1	6	1001	8615	35253	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Крупской, 66	Россия, Калужская область, Людиновский район, Людиново	0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38382	1	6	1001	8615	35318	\N	53.854289000000001	Калужская область, Людиновский район, город Людиново, Кропоткина, 1		0101000020E61000006D91B41B7D384140912A8A5759ED4A40
38404	1	6	1001	9673	\N	\N	53.752510999999998	Калужская область, Людиновский район, деревня Куява, Мальцевская, Сельский клуб д.Куява		0101000020E6100000378AAC3594304140AC70CB4752E04A40
38401	1	6	1001	54230	35607	\N	54.023235	Калужская область, Людиновский район, деревня Космачево, переулок Школьный, 8	Россия, Калужская область, Людиновский район, поселок Космачово	0101000020E61000001AA20A7F86514140B08F4E5DF9024B40
38405	1	6	1001	9700	35648	\N	53.907774000000003	Калужская область, Людиновский район, деревня Колчино, Новая, 1/2		0101000020E61000008A9125732C2541405E143DF031F44A40
38400	1	6	1001	9442	35608	\N	53.929907999999998	Калужская область, Людиновский район, деревня Игнатовка, Центральная, 20		0101000020E610000009FF2268CC464140F624B03907F74A40
38409	1	6	1001	9909	35661	\N	53.850534000000003	Калужская область, Людиновский район, деревня Заболотье, Центральная, 4		0101000020E61000005E143DF0315041406B11514CDEEC4A40
38408	1	6	1001	9859	35657	\N	53.814017	Калужская область, Людиновский район, деревня Войлово, Центральная, 1		0101000020E6100000F148BC3C9D454140ABB184B531E84A40
38403	1	6	1001	9606	\N	\N	53.857024000000003	Калужская область, Людиновский район, деревня Вербежичи, ФАП д.Вербежичи	Россия, Калужская область, Людиновский район, поселок Вербежичи	0101000020E6100000A0A86C58532F41408DF161F6B2ED4A40
38407	1	6	1001	9830	\N	\N	53.915103999999999	Калужская область, Людиновский район, село Букань, Сельский Дом Культуры с.Букань		0101000020E6100000793F6EBF7C5A41402A38BC2022F54A40
37818	1	6	241	13124	\N	\N	54.137452000000003	д. Суборово, 8		0101000020E6100000EC6AF294D5EE40408962F20698114B40
38580	1	6	241	48707	\N	\N	54.206404999999997	пос. Новосельский, 8		0101000020E610000046D3D9C9E0FE40408D5DA27A6B1A4B40
36825	1	6	241	54226	\N	\N	54.164665999999997	д. Ново-Дяглево, 14 А	Россия, Калужская область, Куйбышевский район, поселок Новодяглево	0101000020E61000006D0377A04EE34040AE6186C613154B40
37583	1	6	241	47253	35575	\N	54.058405999999998	с. Мокрое, Центральная, 40	Россия, Калужская область, Куйбышевский район, поселок Мокрое	0101000020E6100000FFB1101D02F34040F1F109D979074B40
38282	1	6	241	3592	\N	\N	53.943005999999997	д. Лужница, 121	Россия, Калужская область, Куйбышевский район, поселок Лужница	0101000020E6100000B29DEFA7C605414044F7AC6BB4F84A40
36843	1	6	241	29633	35645	\N	54.238779000000001	д. Кузьминичи, Центральная, 3	Россия, Калужская область, Куйбышевский район, поселок Кузьминичи	0101000020E610000032E884D041DB40405DFC6D4F901E4B40
38380	1	6	241	49191	\N	\N	53.975687000000001	д. Зимницы, 78		0101000020E6100000A14D0E9F74064140F110C64FE3FC4A40
37892	1	6	241	16691	\N	\N	54.154575999999999	с. Закрутое, 23		0101000020E6100000DEC7D11C59FB40408D5F7825C9134B40
38362	1	6	241	7705	\N	\N	54.193838999999997	с. Жерелёво, 52 А	Россия, Калужская область, Куйбышевский район, поселок Жерелево	0101000020E61000001D01DC2C5EDC40403CD862B7CF184B40
30184	1	6	241	46469	\N	\N	54.207911000000003	д. Желны, 54		0101000020E6100000D2C43BC093EC404045BDE0D39C1A4B40
32305	1	6	241	958	\N	\N	54.071885999999999	д. Емельяновичи, 32	Россия, Калужская область, Куйбышевский район, поселок Емельяновичи	0101000020E6100000679E5C5320CF40402785798F33094B40
32071	1	6	241	22323	\N	\N	54.238894999999999	д. Дегонка, Центральная, 3	Россия, Калужская область, Куйбышевский район, поселок Дегонка	0101000020E6100000679AB0FD64D04040C616821C941E4B40
37950	1	6	241	45364	\N	\N	54.036588999999999	д. Высокое, 15	Россия, Калужская область, Куйбышевский район, поселок Высокое	0101000020E61000002E76FBAC32E340405932C7F2AE044B40
38379	1	6	241	54247	\N	\N	53.953579724673602	д. Ветьмица, 91	Россия, Калужская область, Куйбышевский район, поселок Ветмица	0101000020E6100000999F1B9AB2F94040520FD1E80EFA4A40
38378	1	6	241	8489	35523	\N	53.913682000000001	с. Бутчино, Центральная, 47	Россия, Калужская область, Куйбышевский район, поселок Бутчино	0101000020E6100000D6C9198A3B064140D1782288F3F44A40
38377	1	6	241	8370	35466	\N	54.013263000000002	п. Бетлица, Ленина, 3 А		0101000020E610000054724EECA1F94040999F1B9AB2014B40
38376	1	6	241	8370	35300	\N	54.013263000000002	п. Бетлица, Калинина, 2		0101000020E610000054724EECA1F94040999F1B9AB2014B40
38347	1	6	893	28671	\N	\N	53.825429	с.Чернышино, администрация СП  <<Село Чернышено>>	Россия, Калужская область, Козельский район, поселок Чернышено	0101000020E6100000D1967329AEEE4140C21550A8A7E94A40
38361	1	6	893	7430	\N	\N	54.054139999999997	г.Сосенский, МДОУ д/с <<Колокольчик>>		0101000020E61000001D7233DC80FB4140E5B33C0FEE064B40
38360	1	6	893	7430	\N	\N	54.054139999999997	г.Сосенский, МБУК <<Сосенское городское КДО <<ДК <<Горняк>>		0101000020E61000001D7233DC80FB4140E5B33C0FEE064B40
38359	1	6	893	7430	\N	\N	54.054139999999997	г.Сосенский, МБОУ  <<Средняя общеобразовательная школа №1>>	Россия, Калужская область, Козельский район, Сосенский	0101000020E61000001D7233DC80FB4140E5B33C0FEE064B40
38358	1	6	893	7430	\N	\N	54.054139999999997	г.Сосенский, МБОУ  <<Средняя общеобразовательная школа №2>>		0101000020E61000001D7233DC80FB4140E5B33C0FEE064B40
38357	1	6	893	7430	\N	\N	54.054139999999997	г.Сосенский, МБУК <<Сосенское городское КДО <<ДК<<Прометей>>		0101000020E61000001D7233DC80FB4140E5B33C0FEE064B40
38356	1	6	893	7430	\N	\N	54.054139999999997	г.Сосенский, МДОУ д/с <<Рябинка>>		0101000020E61000001D7233DC80FB4140E5B33C0FEE064B40
38346	1	6	893	48630	\N	\N	53.986821999999997	д.Сенино, администрация СП <<Деревня Сенино-Первое>>		0101000020E61000003FE3C28190024240957CEC2E50FE4A40
38345	1	6	893	6903	\N	\N	54.095779999999998	с.Попелево, МБОУ <<Основная общеобразовательная школа>>	Россия, Калужская область, Козельский район, поселок Попелево	0101000020E61000002E1EDE7360DB414031CEDF84420C4B40
38375	1	6	893	49125	\N	\N	54.113016000000002	с.Покровск, МБОУ  <<Основная общеобразовательная школа>>		0101000020E61000002AFEEF880ACF41405EF6EB4E770E4B40
38374	1	6	893	40423	\N	\N	54.176410485035198	д.Подборки, МБОУ <<Основная общеобразовательная школа>>	Россия, Калужская область, Козельский район, поселок Подборки	0101000020E61000009563B2B8FFF64140FB57569A94164B40
38372	1	6	893	8153	\N	\N	54.085439999999998	с.Нижние Прыски, МБОУ <<Основная общеобразовательная школа>>		0101000020E610000014967840D9EC414097E2AAB2EF0A4B40
32260	1	6	893	46584	\N	\N	54.146428999999998	деревня Маслово, 52		0101000020E610000058C85C1954EB4140CE177B2FBE124B40
38371	1	6	893	8150	\N	\N	54.018071999999997	д.Лавровск, администрация СП <<Деревня Лавровск>>	Россия, Калужская область, Козельский район, поселок Лавровск	0101000020E61000008EE6C8CA2FD74140957CEC2E50024B40
38672	1	6	893	7036	\N	\N	54.030872000000002	г.Козельск, домоуправление		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38353	1	6	893	7036	\N	\N	54.030872000000002	г.Козельск, городской Дом Культуры №2		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38351	1	6	893	7036	35283	\N	54.030872000000002	г.Козельск, Чкалова, 27		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38354	1	6	893	7036	35329	\N	54.030872000000002	г.Козельск, Заводская, МБОУ <<ООШ №2>>		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38352	1	6	893	7036	35311	\N	54.030872000000002	г.Козельск, Генерала Бурмака, МБОУ  <<СОШ №3>>		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38350	1	6	893	7036	35266	\N	54.030872000000002	г.Козельск, Большая Советская, 47а	Россия, Калужская область, Козельский район, Козельск	0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38349	1	6	893	7036	35266	\N	54.030872000000002	г.Козельск, Большая Советская, 25		0101000020E610000090F8156BB8E441405A2E1B9DF3034B40
38370	1	6	893	8065	\N	\N	53.889995999999996	д.Киреевское-Первое, Слаговищенский сельский клуб		0101000020E61000007270E998F3F4414010C99063EBF14A40
38369	1	6	893	8065	\N	\N	53.889995999999996	д.Киреевское-Первое, МБОУ <<Средняя общеобразовательная школа>>		0101000020E61000007270E998F3F4414010C99063EBF14A40
38529	1	6	893	45920	\N	\N	54.239710000000002	с.Ильинское, 28		0101000020E6100000E350BF0B5BD74140184339D1AE1E4B40
38440	1	6	893	45920	\N	\N	54.239710000000002	Село Ильинское, Помещение Дома культуры	Россия, Калужская область, Козельский район, поселок Ильинское	0101000020E6100000E350BF0B5BD74140184339D1AE1E4B40
38608	1	6	893	54210	\N	\N	54.094688628501899	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Заречье"", Здание МОУ ""Заречная средняя общеобразовательная школа"""	Россия, Калужская область, Козельский район, поселок Заречье	0101000020E61000001C5F7B6649D441403E25E7C41E0C4B40
38607	1	6	893	54210	\N	\N	54.094991338537596	"Калужская область, муниципальный район ""Ульяновский район"", сельское поселение ""Село Заречье"", Здание МОУ ""Уколицкая основная общеобразовательная школа"""	Россия, Калужская область, Козельский район, поселок Заречье	0101000020E6100000A6EECA2E18D44140093543AA280C4B40
38366	1	6	893	40419	\N	\N	53.997318999999997	д.Дешовки, МБОУ <<Основная общеобразовательная школа>>		0101000020E61000006D1CB1169FE44140F7562426A8FF4A40
38365	1	6	893	7852	\N	\N	53.935803	с.Волконское, МБОУ <<Основная общеобразовательная школа>>	Россия, Калужская область, Козельский район, поселок Волконское	0101000020E6100000261DE56036D54140D53F8864C8F74A40
38364	1	6	893	48942	\N	\N	54.151997000000001	с.Бурнашево, администрация СП <<Село Бурнашево>>	Россия, Калужская область, Козельский район, поселок Бурнашево	0101000020E61000000AF5F411F8E54140890B40A374134B40
38367	1	6	893	7919	\N	\N	53.978116999999997	с.Березичи, Березичский сельский клуб		0101000020E61000001F2C634337E54140B05417F032FD4A40
38363	1	6	893	54191	\N	\N	53.966318000000001	с.Березичский стеклозавод, МБОУ <<Основная общеобразовательная школа>>	Россия, Калужская область, Козельский район, поселок Березический стеклозавод	0101000020E6100000253CA1D79FEC4140A0C4E74EB0FB4A40
38327	1	6	764	48306	\N	\N	54.193375000000003	д. Якимово, сельский дом культуры	Россия, Калужская область, Кировский район, поселок Якимово	0101000020E610000020ED7F80B52A4140986E1283C0184B40
38318	1	6	764	5440	\N	\N	54.243693	п. Шайковка, дом офицеров		0101000020E6100000B48EAA2688304140CFA10C55311F4B40
38317	1	6	764	5440	\N	\N	54.243693	"п. Шайковка, МКОУ ""Шайковская СОШ № 1"""		0101000020E6100000B48EAA2688304140CFA10C55311F4B40
38323	1	6	764	5761	\N	\N	54.115639999999999	с. Фоминичи, сельский дом культуры		0101000020E6100000B58AFED0CC574140020EA14ACD0E4B40
38315	1	6	764	5361	\N	\N	54.184781999999998	д. Тягаево, сельский дом культуры	Россия, Калужская область, Кировский район, поселок Тягаево	0101000020E6100000FD4E93196F0D4140DA71C3EFA6174B40
38416	1	6	764	45465	\N	\N	54.140179000000003	"Деревня Прудки, Помещение администрации сельского поселения ""Деревня Прудки"""		0101000020E61000007B6B60AB04414140024BAE62F1114B40
38332	1	6	764	6232	\N	\N	54.069412999999997	д. Малые Савки, сельский дом культуры		0101000020E61000008A39083A5A1D414068757286E2084B40
38324	1	6	764	52706	\N	\N	54.092225999999997	д. Малые Зимницы, помещение ФАП	Россия, Калужская область, Кировский район, поселок Малые Зимницы	0101000020E6100000B0045262D7604140A2EBC20FCE0B4B40
38330	1	6	764	6132	\N	\N	54.016168	д. Малая Песочня, сельский дом культуры		0101000020E6100000952710768A234140F19E03CB11024B40
38545	1	6	764	16379	74969	\N	54.227723112998703	с.Лазинки, Центральная, 5	Россия, Калужская область, Кировский район, поселок Лазинки	0101000020E6100000742502D53F1C414004C6FA06261D4B40
38343	1	6	764	45938	35220	\N	54.076022000000002	г. Киров, Строительная, 20		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38342	1	6	764	45938	35218	\N	54.076022000000002	г. Киров, Пролетарская, 259		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38340	1	6	764	45938	35218	\N	54.076022000000002	г. Киров, Пролетарская, 48		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38338	1	6	764	45938	35458	\N	54.076022000000002	г. Киров, Челюскина, 13-А		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38334	1	6	764	45938	35314	\N	54.076022000000002	г. Киров, Урицкого, 12		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38253	1	6	764	45938	35201	\N	54.076022000000002	г. Киров, Пушкина, 28	Россия, Калужская область, Кировский район, Киров	0101000020E6100000A583F57F0E29414065E3C116BB094B40
38337	1	6	764	45938	35228	\N	54.076022000000002	г. Киров, Плеханова, 42а		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38335	1	6	764	45938	35281	\N	54.076022000000002	г. Киров, Ленина, 14		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38339	1	6	764	45938	35303	\N	54.076022000000002	г. Киров, Кирова, 2		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38344	1	6	764	45938	35243	\N	54.076022000000002	г. Киров, Болдина, 7		0101000020E6100000A583F57F0E29414065E3C116BB094B40
38326	1	6	764	48285	\N	\N	54.201459999999997	д. Дуброво, сельский дом культуры		0101000020E610000006BEA25BAF214140E0B9F770C9194B40
38325	1	6	764	48251	\N	\N	54.066417000000001	д. Гавриловка, администрация сельского поселения		0101000020E6100000D7A3703D0A47414000732D5A80084B40
38320	1	6	764	48161	\N	\N	54.129117000000001	"с. Воскресенск, МКОУ ""Воскресенская СОШ"" им. М.В. Угарова"		0101000020E6100000E1B54B1B0E2B4140C72DE6E786104B40
38322	1	6	764	5755	\N	\N	54.143306000000003	с. Волое, администрация сельского поселения	Россия, Калужская область, Кировский район, поселок Волое	0101000020E6100000850838842A49414009A9DBD957124B40
38328	1	6	764	6022	\N	\N	54.141264999999997	д. Верхняя Песочня, сельский дом культуры		0101000020E6100000C860C5A9D6164140E388B5F814124B40
38331	1	6	764	6224	\N	\N	54.052374999999998	д. Большие Савки, сельский дом культуры	Россия, Калужская область, Кировский район, поселок Большие Савки	0101000020E61000002AAC54505119414062105839B4064B40
38321	1	6	764	48179	\N	\N	54.119560999999997	д. Бережки, сельский дом культуры	Россия, Калужская область, Кировский район, поселок Бережки	0101000020E6100000CF4A5AF10D39414043705CC64D0F4B40
38329	1	6	764	6113	\N	\N	54.130578	д. Анновка, сельский дом культуры	Россия, Калужская область, Кировский район, поселок Анновка	0101000020E6100000A33F34F3E4084140DEC9A7C7B6104B40
38273	1	6	508	3105	\N	\N	54.513767000000001	"Калужская область, городской округ ""Город  Калуга"", Московский округ, с.Росва, здание Дома культуры"	Россия, Калужская область, Калуга городской округ, поселок Росва	0101000020E61000003602F1BA7E074240CC61F71DC3414B40
38274	1	6	508	54196	\N	\N	54.628471110884099	"Калужская область, городской округ ""Город  Калуга"", Московский округ, с.Мирный, здание Дома культуры"	Россия, Калужская область, Калуга городской округ, поселок Мирный	0101000020E61000004434BA83D815424001BEDBBC71504B40
38054	1	6	508	54196	74945	\N	54.631854424919702	п. Мирный, Центральная, 6	Россия, Калужская область, Калуга городской округ, поселок Мирный	0101000020E610000092CEC0C8CB16424063EC8497E0504B40
38455	1	6	508	54222	74954	\N	54.634888206211301	село Молодежный, Юбилейная, 3	Россия, Калужская область, Калуга городской округ, поселок Лихун	0101000020E61000008544DAC69F224240B94F8E0244514B40
38141	1	6	508	54222	35565	\N	54.630966999999998	Город  Калуга, д.Лихун, ул.Успенская, 49	Россия, Калужская область, Калуга городской округ, поселок Лихун	0101000020E61000008BE07F2BD921424078EDD286C3504B40
38244	1	6	508	54206	\N	\N	54.433379977105197	г. Калуга, Ленинский округ, д. Колюпаново, здание школы №38	Россия, Калужская область, Калуга городской округ, поселок Колюпаново	0101000020E6100000889D29745E1D4240C85EEFFE78374B40
38314	1	6	508	54235	35659	\N	54.648567999999997	Город  Калуга, д.Ильинка, ул.Центральная, 39 (террит. представительство №29)	Россия, Калужская область, Калуга городской округ, поселок Ильинка	0101000020E6100000642310AFEB274240B69DB64604534B40
38243	1	6	508	54227	\N	\N	54.381785000000001	г. Калуга, Ленинский округ, д. Андреевское, здание клуба	Россия, Калужская область, Калуга городской округ, поселок Андреевское	0101000020E610000043705CC64D1942403B8DB454DE304B40
38191	1	6	1892	31097	35628	\N	55.102792000000001	с. Шанский Завод, Центральная, 7		0101000020E61000003D0CAD4ECECC41402D25CB49288D4B40
38189	1	6	1892	30979	35521	\N	55.084553999999997	д. Ореховня, Новая, 1	Россия, Калужская область, Износковский район, поселок Ореховня	0101000020E6100000C828CFBC1CA241407C5F5CAAD28A4B40
38179	1	6	1892	30473	35292	\N	54.897235999999999	п. Мятлево, Интернациональная, 61		0101000020E6100000D2FE0758ABD641409D6516A1D8724B40
38195	1	6	1892	45638	35574	\N	54.948427000000002	с. Льнозавод, Центральная, 8	Россия, Калужская область, Износковский район, поселок Льнозавод	0101000020E61000009C340D8AE6B741405BD2510E66794B40
38196	1	6	1892	31328	35308	\N	54.988815000000002	с. Износки, 40 лет Октября, 9	Россия, Калужская область, Износковский район, поселок Износки	0101000020E61000002236583849A94140AA656B7D917E4B40
38194	1	6	1892	31227	35576	\N	54.932571000000003	с. Извольск, Окружная, 5		0101000020E610000024F1F274AE9C414059198D7C5E774B40
38190	1	6	1892	60413	\N	\N	55.010545	д. Ивановское, помещение администрации МО СП д.Ивановское, 8	Россия, Калужская область, Износковский район, поселок Ивановское	0101000020E610000004029D499B9041407311DF8959814B40
38192	1	6	1892	53074	\N	\N	54.904608000000003	д. Алексеевка, помещение администрации МО СП д. Алексеевка	Россия, Калужская область, Износковский район, поселок Алексеевка	0101000020E6100000637FD93D79CC414099D9E731CA734B40
38164	1	6	1868	29740	\N	\N	55.196278999999997	Калужская область Жуковский район  д.Чубарово, 36, Администрация СП д.Чубарово	Россия, Калужская область, Жуковский район, поселок Чубарово	0101000020E6100000BAA0BE654E7542401FF296AB1F994B40
38172	1	6	1868	54215	\N	\N	54.843885999999998	Калужская область Жуковский район с.Совхоз Чаусово ул.Школьная, 10, Чаусовская школа	Россия, Калужская область, Жуковский район, поселок Чаусово	0101000020E6100000C9FFE4EFDE754240B0C6D974046C4B40
38168	1	6	1868	29951	\N	\N	54.976199000000001	Калужская область Жуковский район с. Трубино, 2, Администрация СП с.Трубино	Россия, Калужская область, Жуковский район, поселок Трубино	0101000020E6100000A1664815C5594240A7B1BD16F47C4B40
38171	1	6	1868	30109	\N	\N	55.014422000000003	Калужская область Жуковский район д.Тростье, 7, Администрация СП д.Тростье	Россия, Калужская область, Жуковский район, поселок Тростье	0101000020E61000005B5F24B4E5784240E52B8194D8814B40
37016	1	6	1868	29987	\N	\N	54.872818000000002	с. Троицкое, 100 А		0101000020E61000009355116E328E424019AE0E80B86F4B40
38162	1	6	1868	29650	\N	\N	55.120130000000003	Калужская область Жуковский район с.Тарутино, 13, Администрация СП с.Тарутино	Россия, Калужская область, Жуковский район, поселок Тарутино	0101000020E61000000D501A6A147842405EA27A6B608F4B40
38161	1	6	1868	54228	\N	\N	55.172295115240203	Калужская область Жуковский район с.Совхоз Победа ул.Старопрудная, 15, Администрация СП с.Совхоз Победа	Россия, Калужская область, Жуковский район, колхоз Победа	0101000020E6100000F46F97FDBA614240D52137C30D964B40
38163	1	6	1868	54223	\N	\N	55.092690442094202	Калужская область Жуковский район д.Маринки, 92, Куриловский СДК	Россия, Калужская область, Жуковский район, поселок Курилово	0101000020E6100000B8E9CF7EA482424047551344DD8B4B40
38178	1	6	1868	30439	35302	\N	54.882829999999998	Калужская область, Жуковский район, г.Кременки ул.Ленина, 5, Кременковская средняя школа  им.Е.Р.Дашковой, холл 2 этажа,	Россия, Калужская область, Жуковский район, поселок Кременки	0101000020E61000006E88F19A578F4240BEF6CC9200714B40
38182	1	6	1868	30439	35293	\N	54.882829999999998	Калужская область, Жуковский район, г. Кременки ул.Школьная, 9, Кременковская школа №2, холл 2 этажа		0101000020E61000006E88F19A578F4240BEF6CC9200714B40
38181	1	6	1868	30439	35285	\N	54.882829999999998	Калужская область, Жуковский район, г.Кременки ул.Мира, 11, Кременковский ГДК, каб.№1		0101000020E61000006E88F19A578F4240BEF6CC9200714B40
38180	1	6	1868	30439	35274	\N	54.882829999999998	Калужская область, Жуковский район, г.Кременки ул.Ленина, 5, Кременковская средняя школа  им.Е.Р.Дашковой, холл  2 этажа		0101000020E61000006E88F19A578F4240BEF6CC9200714B40
38165	1	6	1868	29811	\N	\N	55.153190000000002	Калужская область Жуковский район д.Корсаково ул.Садовая, 69, Администрация СП д.Корсаково		0101000020E61000003543AA285E7D42408109DCBA9B934B40
37638	1	6	1868	60400	\N	\N	54.937943539416601	д. Грибовка, 19	Россия, Калужская область, Жуковский район, поселок Грибовка	0101000020E61000004C6F7F2E1A6E42405EBD8A8C0E784B40
38158	1	6	1868	29504	35563	\N	55.100087000000002	Калужская обл, Жуковский, Административное здание ООО «СберСтройИнвест», д. Грачевка, ул. Дачная, 74	Россия, Калужская область, Жуковский район, поселок Грачевка	0101000020E61000000BB6114F766742409CE09BA6CF8C4B40
38167	1	6	1868	29871	\N	\N	54.913043999999999	Калужская область Жуковский район с. Высокиничи ул.Ленина, 1, Администрация СП с.Высокиничи	Россия, Калужская область, Жуковский район, поселок Высокиничи	0101000020E6100000D8B8FE5D9F7542408EE733A0DE744B40
38166	1	6	1868	29871	\N	\N	54.913043999999999	Калужская область Жуковский район с. Высокиничи ул.Ленина, 1, Администрация МО СП с.Высокиничи		0101000020E6100000D8B8FE5D9F7542408EE733A0DE744B40
38157	1	6	1868	29449	\N	\N	54.965496999999999	Калужская область Жуковский район с.Восход, 15, Восходовский СДК		0101000020E61000006956B60F796542406CB1DB67957B4B40
38159	1	6	1868	29520	35622	\N	55.147129	Калужская обл, Жуковский,  Воробьевский медпункт, д. Воробьи, ул. Московская, 9,		0101000020E610000044A67C08AA66424087A5811FD5924B40
38187	1	6	1868	54202	\N	\N	55.076731000000002	Калужская область, Жуковский район, д.Верховье, 99, Администрация СП д.Верховье		0101000020E6100000C310397D3D57424071CB4752D2894B40
38188	1	6	1868	30950	\N	\N	54.988024000000003	Калужская область, Жуковский район, д.Величково, Величковский  медпункт		0101000020E6100000B79BE09BA6614240E1D40792777E4B40
38177	1	6	1868	54186	35252	\N	55.092886	Калужская область, Жуковский район, г.Белоусово ул.Мирная, 11, Администрация ГП г.Белоусово	Россия, Калужская область, Белоусово	0101000020E6100000D0D38041D2554240CD203EB0E38B4B40
38092	1	6	1868	60396	74951	\N	55.057371190684499	д.Барсуки, ул.Центральная, 45	Россия, Калужская область, Жуковский район, поселок Барсуки	0101000020E610000007616EF7727B4240925ED4EE57874B40
38461	1	6	1868	46403	74959	\N	54.804628000000001	деревня Баранцево, Полевая, 5		0101000020E6100000AB05F6984879424013B9E00CFE664B40
38146	1	6	1852	28942	35562	\N	53.650475	д. Яровщина, ул. Центральная, д. 52	Россия, Калужская область, Жиздринский район, поселок Яровщина	0101000020E6100000F47002D369594140CCEEC9C342D34A40
38145	1	6	1852	28927	35518	\N	53.544668999999999	д. Улемец, ул. Центральная, д. 7		0101000020E61000006A15FDA1995141409012BBB6B7C54A40
35690	1	6	1852	46154	35597	\N	53.752389000000001	с. Студенец, ул. Школьная, д. 9	Россия, Калужская область, Жиздринский район, поселок Студенец	0101000020E61000003622180797744140616F62484EE04A40
38147	1	6	1852	60403	74964	\N	53.500881	ж/д станция Березовский, ул. Пристанционная, д. 28	Россия, Калужская область, Жиздринский район, поселок Разъезд Березовский	0101000020E61000000859164CFC5B414009185DDE1CC04A40
38537	1	6	1852	47907	\N	\N	53.634070999999999	д.Поляна, 33		0101000020E6100000680932022A764140C72B103D29D14A40
38154	1	6	1852	49248	35512	\N	53.763247999999997	с. Полюдово, ул. Молодежная, д. 2	Россия, Калужская область, Жиздринский район, поселок Полюдово	0101000020E6100000C4B29943527F4140635E471CB2E14A40
38533	1	6	1852	60402	\N	\N	53.670971522234801	д.Песочня, 54	Россия, Калужская область, Жиздринский район, поселок Песочня	0101000020E6100000895DDBDB2D5B41400F441669E2D54A40
38148	1	6	1852	29047	35555	\N	53.487867000000001	с. Огорь, ул. Центральная, д. 3	Россия, Калужская область, Жиздринский район, поселок Огорь	0101000020E6100000ACC95356D351414019E6046D72BE4A40
38144	1	6	1852	28850	35561	\N	53.569834999999998	с. Овсорок, ул. Центральная, д. 12	Россия, Калужская область, Жиздринский район, поселок Овсорок	0101000020E6100000109546CCEC594140DE8E705AF0C84A40
38153	1	6	1852	29247	35626	\N	53.760128999999999	д. Мужитино, ул. Молодежная, д. 21		0101000020E61000000B7A6F0C01564140DFDE35E84BE14A40
38143	1	6	1852	28832	35573	\N	53.607841999999998	д. Младенск, ул. Центральная, д. 42		0101000020E61000009DD9AED0076941404F9143C4CDCD4A40
38156	1	6	1852	49285	35572	\N	53.673855000000003	д. Коренево, ул. Заречная, д. 12	Россия, Калужская область, Жиздринский район, поселок Коренево	0101000020E610000003B4AD669D4D4140809F71E140D64A40
38155	1	6	1852	54244	35668	\N	53.724780000000003	с. совхоз Коллективизатор, ул. Центральная, д. 13 А	Россия, Калужская область, Жиздринский район, колхоз Коллективизатор	0101000020E6100000C5758C2B2E5A4140BF654E97C5DC4A40
35748	1	6	1852	47363	35605	\N	53.731693999999997	с. Зикеево, ул. Школьная, д. 3		0101000020E6100000C02154A9D96F4140F7562426A8DD4A40
38150	1	6	1852	29075	35199	\N	53.744098000000001	г. Жиздра, пл. Коммуны, 1		0101000020E61000003BC3D4963A5E41406F826F9A3EDF4A40
38149	1	6	1852	29075	35306	\N	53.744098000000001	г. Жиздра, ул. Коммунистическая, д. 20/2		0101000020E61000003BC3D4963A5E41406F826F9A3EDF4A40
38151	1	6	1852	29075	35459	\N	53.744098000000001	г. Жиздра, ул. Брянская, 11		0101000020E61000003BC3D4963A5E41406F826F9A3EDF4A40
38152	1	6	1852	29222	35511	\N	53.811661999999998	д. Верхняя Акимовка, ул. Центральная, д. 10		0101000020E61000004AB3791C065D4140F6B3588AE4E74A40
38421	1	6	1852	45556	\N	\N	53.498544000000003	"Деревня Березовка, Помещение администрации сельского поселения ""д. Березовка"""		0101000020E6100000B22C98F8A35E4140FBCE2F4AD0BF4A40
38140	1	6	324	49049	35685	\N	53.841774000000001	село Чернышено, Ленина, 7		0101000020E6100000B3CEF8BEB8A24140C24F1C40BFEB4A40
38139	1	6	324	49020	35547	\N	53.765739000000004	село Хотьково, Центральная, 54		0101000020E61000005C5A0D897B9C4140C9224DBC03E24A40
38539	1	6	324	16082	\N	\N	53.943117000000001	д.Хотисино, 73		0101000020E61000004E637B2DE88341409CA6CF0EB8F84A40
35609	1	6	324	1491	\N	\N	53.872104	деревня Пыренка, 60	Россия, Калужская область, Думиничский район, поселок Пыренка	0101000020E61000005B7A34D5936B4140FB5A971AA1EF4A40
38135	1	6	324	60464	\N	\N	53.826862082988796	село Паликского Кирпичного Завода, 44	Россия, Калужская область, Думиничский район, поселок Палики	0101000020E61000002DEDD45C6E7841400F27309DD6E94A40
35657	1	6	324	4190	\N	\N	53.967038000000002	село Новослободск, 16 А		0101000020E610000088669E5C53684140A0FEB3E6C7FB4A40
35673	1	6	324	45790	\N	\N	54.031289999999998	село Маклаки, 91	Россия, Калужская область, Думиничский район, поселок Маклаки	0101000020E6100000C7BC8E38646F41408E588B4F01044B40
38134	1	6	324	28379	35544	\N	54.043911999999999	село Которь, Центральная, 2	Россия, Калужская область, Думиничский район, поселок Которь	0101000020E6100000321F10E84C78414073F38DE89E054B40
38130	1	6	324	28093	35492	\N	53.918604000000002	деревня Думиничи, Центральная, 51		0101000020E61000004F93196F2B8F4140C6FCDCD094F54A40
38128	1	6	324	28093	35197	\N	53.918604000000002	поселок Думиничи, Ленина, 20		0101000020E61000004F93196F2B8F4140C6FCDCD094F54A40
38127	1	6	324	28093	35197	\N	53.918604000000002	поселок Думиничи, Ленина, 3		0101000020E61000004F93196F2B8F4140C6FCDCD094F54A40
38129	1	6	324	28093	35500	\N	53.933521994838003	ж\\д станция Думиничи, Белинского, 6	Россия, Калужская область, Думиничский район, поселок Думиничи	0101000020E61000008386FE092E8E41405B0C1EA67DF74A40
38132	1	6	324	28283	\N	\N	54.054805999999999	деревня Верхнее Гульцово, 82	Россия, Калужская область, Думиничский район, поселок Верхнее Гульцево	0101000020E610000085EFFD0DDA834140F2CF0CE203074B40
38137	1	6	324	28537	\N	\N	53.950879999999998	село Вертное, 1	Россия, Калужская область, Думиничский район, поселок Вертное	0101000020E6100000D636C5E3A2984140D235936FB6F94A40
38169	1	6	1701	27497	\N	\N	54.707352999999998	Калужская область Жуковский район с.Троицкое, 164, Правление к-за им.Ленина	Россия, Калужская область, Дзержинский район, колхоз имени Ленина	0101000020E6100000F2EEC8586D0A42401EDD088B8A5A4B40
38009	1	6	1701	22639	35610	\N	54.586857999999999	п.Якшуново, ул.Школьная, дом №2		0101000020E61000001BBD1AA034F84140AFB2B6291E4B4B40
38119	1	6	1701	54178	35341	\N	54.677354000000001	"Калужская область, муниципальный район ""Дзержинский район"", городское поселение ""Поселок Товарково"", Школьная, 1"	Россия, Калужская область, Дзержинский район, Товарково	0101000020E610000058AD4CF8A5F841404BE82E89B3564B40
38115	1	6	1701	54178	35203	\N	54.677354000000001	"Калужская область, муниципальный район ""Дзержинский район"", городское поселение ""Поселок Товарково"", Туркестанская, 1"	Россия, Калужская область, Дзержинский район, Товарково	0101000020E610000058AD4CF8A5F841404BE82E89B3564B40
38117	1	6	1701	54178	35196	\N	54.677272969337501	"Калужская область, муниципальный район ""Дзержинский район"", городское поселение ""Поселок Товарково"", Ленина, 32"	Россия, Калужская область, Дзержинский район, Товарково	0101000020E6100000978C63247BF841405EBBB4E1B0564B40
38114	1	6	1701	54178	35196	\N	54.677354000000001	"Калужская область, муниципальный район ""Дзержинский район"", городское поселение ""Поселок Товарково"", Ленина, 22"	Россия, Калужская область, Дзержинский район, Товарково	0101000020E610000058AD4CF8A5F841404BE82E89B3564B40
38113	1	6	1701	54178	35196	\N	54.677354000000001	"Калужская область, муниципальный район ""Дзержинский район"", городское поселение ""Поселок Товарково"", ул. Ленина, д. 2а"	Россия, Калужская область, Дзержинский район, Товарково	0101000020E610000058AD4CF8A5F841404BE82E89B3564B40
38118	1	6	1701	54178	35358	\N	54.677354000000001	"Калужская область, муниципальный район ""Дзержинский район"", городское поселение ""Поселок Товарково"", Дзержинского, 14"	Россия, Калужская область, Дзержинский район, Товарково	0101000020E610000058AD4CF8A5F841404BE82E89B3564B40
38098	1	6	1701	48315	\N	\N	54.752327999999999	д.Старки, дом № 65	Россия, Калужская область, Дзержинский район, поселок Старки	0101000020E6100000944F8F6D19004240BBEEAD484C604B40
38170	1	6	1701	54237	\N	\N	54.706681998366101	Калужская область Жуковский район д.Караулово, 44, Диспетчерская к-за иим.Ленина		0101000020E6100000F052EA92710A42400056478E745A4B40
38101	1	6	1701	54216	35505	\N	54.706581916110999	с.Совхоз им.Ленина, ул. Ленина, дом №8	Россия, Калужская область, Дзержинский район, колхоз имени Ленина	0101000020E6100000A6D6FB8D760A42409CF86A47715A4B40
38093	1	6	1701	48220	\N	\N	54.663724000000002	д.Рудня, дом №52		0101000020E61000006EBF7CB262F0414000C974E8F4544B40
38126	1	6	1701	28025	35327	\N	54.690944000000002	п.Пятовский, ул.Ленина, до №12	Россия, Калужская область, Дзержинский район, поселок Пятовский	0101000020E6100000A3ACDF4C4C09424008AF5DDA70584B40
38028	1	6	1269	23389	35541	\N	54.391652000000001	Калужская область, Бабынинский район, Село Бабынино, Центральная, 38		0101000020E610000011DF89592FE24140DDB419A721324B40
38116	1	6	1701	54205	35431	\N	54.677452973305698	"Калужская область, муниципальный район ""Дзержинский район"", городское поселение ""Поселок Товарково"", Советская, 4"	Россия, Калужская область, Дзержинский район, Товарково	0101000020E61000000CAD4ECE50F84140DEC9A7C7B6564B40
38112	1	6	1701	27349	35193	\N	54.729137999999999	п.Полотняный Завод, ул.Школьная, дом № 1		0101000020E610000045D7851F9CFD4140AB22DC64545D4B40
38111	1	6	1701	27349	35246	\N	54.729137999999999	п.Полотняный Завод, ул.Ленина, дом № 4		0101000020E610000045D7851F9CFD4140AB22DC64545D4B40
38462	1	6	1701	46425	74937	\N	54.720968999999997	село Покров, Новая, 5	Россия, Калужская область, Дзержинский район, поселок Покров	0101000020E6100000F9D687F546DB4140043752B6485C4B40
38122	1	6	1701	27865	35629	\N	54.804077999999997	с.Острожное, ул.Заводская, дом № 2		0101000020E610000016A243E048DE41406FB72407EC664B40
38121	1	6	1701	27818	35571	\N	54.848007000000003	с.Маковцы, ул.Центральная, дом №6/1	Россия, Калужская область, Дзержинский район, поселок Маковцы	0101000020E61000004F232D95B7014240B9E34D7E8B6C4B40
36467	1	6	1701	46550	35269	\N	54.607883999999999	с.Льва Толстого, ул.Советская, дом № 27	Россия, Калужская область, Дзержинский район, поселок Льва Толстого	0101000020E61000004D840D4FAF0442407EE19524CF4D4B40
36858	1	6	1701	46550	35194	\N	54.607883999999999	с.Льва Толстого, ул.Полевая, дом №10		0101000020E61000004D840D4FAF0442407EE19524CF4D4B40
38094	1	6	1701	48244	74946	\N	54.706265999999999	д.Лужное, ул.Центральная, дом 1		0101000020E6100000567F8461C0DE41406C239EEC665A4B40
38125	1	6	1701	28009	35227	\N	54.532567999999998	п.Куровской, ул.Мира, дом №6а		0101000020E610000051F69672BE024240B4722F302B444B40
38107	1	6	1701	26997	35474	\N	54.795686000000003	г.Кондрово, ул.Маяковского, дом № 1	Россия, Калужская область, Дзержинский район, Кондрово	0101000020E61000007008556AF6F641404AF1F109D9654B40
38108	1	6	1701	26997	35322	\N	54.795686000000003	г.Кондрово, ул. Южная, дом № 10		0101000020E61000007008556AF6F641404AF1F109D9654B40
38103	1	6	1701	26997	35191	\N	54.795686000000003	г.Кондрово, ул.Советская, дом №13		0101000020E61000007008556AF6F641404AF1F109D9654B40
38106	1	6	1701	26997	35223	\N	54.795686000000003	г.Кондрово, ул. Ленина, дом № 37		0101000020E61000007008556AF6F641404AF1F109D9654B40
38104	1	6	1701	26997	35251	\N	54.795686000000003	г.Кондрово, ул.Кооперативная, дом №9		0101000020E61000007008556AF6F641404AF1F109D9654B40
38110	1	6	1701	26997	35222	\N	54.795686000000003	г.Кондрово, ул.Интернациональная, дом № 6		0101000020E61000007008556AF6F641404AF1F109D9654B40
38105	1	6	1701	26997	35222	\N	54.795686000000003	г.Кондрово, ул.Интернациональная, дом № 30		0101000020E61000007008556AF6F641404AF1F109D9654B40
37098	1	6	1701	46736	35520	\N	54.568103000000001	д.Кожухово, ул.Центральная, дом №13	Россия, Калужская область, Дзержинский район, поселок Кожухово	0101000020E61000005B0C1EA67DF5414037E15E99B7484B40
38100	1	6	1701	26845	35462	\N	54.789374000000002	д.Карцово, ул.Центральная, дом № 3		0101000020E610000056293DD34B04424007280D350A654B40
38123	1	6	1701	27923	35546	\N	54.743583000000001	д.Звизжи, ул.Речная, дом №4		0101000020E6100000F7764B72C0D24140486E4DBA2D5F4B40
38102	1	6	1701	26935	35213	\N	54.696708395203302	д.Жилетово, ул.Садовая, дом № 2	Россия, Калужская область, Дзержинский район, поселок Жилетово	0101000020E6100000E31934F44F024240486E4DBA2D594B40
38095	1	6	1701	48256	35653	\N	54.773952999999999	д.Дубинино, пер.Светлый, дом № 4	Россия, Калужская область, Дзержинский район, поселок Дубинино	0101000020E6100000A8514832ABF141400FD253E410634B40
36865	1	6	1701	46673	35244	\N	54.615329000000003	с.Дворцы, ул.Федорова, дом №14		0101000020E61000001A88653387004240E4A3C519C34E4B40
38527	1	6	1701	47719	74927	\N	54.631738013280803	д.Горки, Кузнецова, 11	Россия, Калужская область, Дзержинский район, поселок Горки	0101000020E610000083DA6FED44D94140FAD170CADC504B40
38099	1	6	1701	48336	\N	\N	54.712929000000003	д.Бели, дом №75	Россия, Калужская область, Дзержинский район, поселок Бели	0101000020E6100000DB34B6D782F441405CAFE941415B4B40
38090	1	6	1770	26406	35475	\N	55.229013999999999	Калужская область, Боровский район, д.Совьяки, Центральная, 17		0101000020E6100000548B8862F2364240BF29AC54509D4B40
38072	1	6	1770	54201	35383	\N	55.173298000000003	"Калужская область, Боровский район, с. Совхоз ""Боровский"", Центральная, 3"		0101000020E6100000DDD26A48DC4F42402A3BFDA02E964B40
38066	1	6	1770	25278	35619	\N	55.157252999999997	Калужская область, Боровский район, д.Серединское, Центральная, 8	Россия, Калужская область, Боровский район, поселок Серединское	0101000020E61000006878B306EF1542405419C6DD20944B40
38091	1	6	1770	26415	\N	\N	55.276215999999998	Калужская область, Боровский район,  д.Митяево, Сельский Дом культуры, 24		0101000020E6100000651BB80375464240E350BF0B5BA34B40
38069	1	6	1770	54194	35321	\N	55.1353939013824	Калужская область, Боровский район, д.Кривское, Мигунова, 3	Россия, Калужская область, деревня Кривское	0101000020E6100000DC0E0D8B514542408D09319754914B40
38067	1	6	1770	25315	\N	\N	55.126049999999999	"Калужская область, Боровский район, д.Коростелево, МОУ ""Основная общеобразовательная школа д.Коростелево"", 63"		0101000020E61000004818062CB912424095D4096822904B40
38070	1	6	1770	54232	35654	\N	55.189546999999997	Калужская область, Боровский район, д.Комлево, Центральная, 1		0101000020E6100000B8E864A9F540424007077B1343984B40
38068	1	6	1770	25369	35556	\N	55.175590999999997	Калужская область, Боровский район, д.Борисово, Центральная, 3		0101000020E6100000492A53CC410A4240683C11C479964B40
38065	1	6	1770	25212	35470	\N	55.125653999999997	Калужская область, Боровский район, д.Асеньевское, Центральная, 5		0101000020E6100000A81E69705B274240484E266E15904B40
38056	1	6	514	47529	35650	\N	54.346432999999998	д. Шершнево, Озерная, 11		0101000020E6100000C32973F38D424140A9A0A2EA572C4B40
38055	1	6	514	47505	35621	\N	54.476922999999999	д. Цветовка, Центральная, 22		0101000020E6100000BF0D315EF3344140E8DA17D00B3D4B40
38052	1	6	514	47456	35606	\N	54.399206	д. Плетни, Молодежная, 23		0101000020E6100000BEF8A23D5E584140F92EA52E19334B40
38051	1	6	514	24613	35652	\N	54.257460000000002	д. Перенежье, Центральная, 36	Россия, Калужская область, Барятинский район, поселок Перенежье	0101000020E6100000677E3507083C41409B030473F4204B40
38050	1	6	514	24536	\N	\N	54.225790000000003	"с. Милотичи, Администрация СП "" с. Милотичи"", 41"		0101000020E6100000137F1475E63E4140C6E1CCAFE61C4B40
38049	1	6	514	24511	35517	\N	54.368017999999999	д. Крисаново-Пятница, Центральная, 13	Россия, Калужская область, Барятинский район, поселок Крисаново-Пятница	0101000020E6100000A3923A014D5041406F2BBD361B2F4B40
38402	1	6	514	9565	35519	\N	54.189909	Калужская область, Людиновский район, село Заречный, Школьная, 3		0101000020E6100000168733BF9A4D4140A81B28F04E184B40
38550	1	6	514	60401	74960	\N	54.271334261095397	д.Жданово, Центральная, 1	Россия, Калужская область, Барятинский район, поселок Жданово	0101000020E610000093AB58FCA65641407D259012BB224B40
32115	1	6	514	48262	35502	\N	54.427064000000001	д. Добрая, Советская, 4	Россия, Калужская область, Барятинский район, поселок Добрая	0101000020E6100000996379573D4C414044A67C08AA364B40
38568	1	6	514	60383	74932	\N	54.4460640900556	д. Глазово, 48а	Россия, Калужская область, Барятинский район, поселок Глазово	0101000020E6100000EE974F560C47414023F609A018394B40
38034	1	6	514	47084	35516	\N	54.348599999999998	д. Бахмутово, Центральная, 29		0101000020E61000007C6473D53C2741405BB1BFEC9E2C4B40
38024	1	6	514	46873	35419	\N	54.305472000000002	с. Барятино, 40 лет Победы, 18а		0101000020E61000008198840B79424140FFEBDCB419274B40
38048	1	6	514	47375	35548	\N	54.219952999999997	д. Асмолово, Мира, 13		0101000020E6100000481B47ACC55341401BD47E6B271C4B40
38041	1	6	1269	24083	\N	\N	54.515565000000002	Калужская область, Бабынинский район, Село Утешево, Здание Дома культуры	Россия, Калужская область, Бабынинский район, поселок Утешево	0101000020E610000033C4B12E6ED741402BFBAE08FE414B40
38642	1	6	1269	45391	\N	\N	54.390765999999999	село Слобода, ул.Молодежная, д.79	Россия, Калужская область, Бабынинский район, поселок Слобода	0101000020E6100000BD6E1118EBDB4140C231CB9E04324B40
38039	1	6	1269	23991	\N	\N	54.469850000000001	Калужская область, Бабынинский район, Поселок Садовый, Здание школы	Россия, Калужская область, Бабынинский район, поселок Садовый	0101000020E6100000884CF91054F141404703780B243C4B40
38038	1	6	1269	54229	\N	\N	54.427635000000002	Калужская область, Бабынинский район, Село Сабуровщино, Здание администрации с/с	Россия, Калужская область, Бабынинский район, поселок Сабуровщина	0101000020E61000003AAE4676A5D34140FFCF61BEBC364B40
38037	1	6	1269	23884	\N	\N	54.342706999999997	Калужская область, Бабынинский район, Село Пятницкое, Здание школы, 79		0101000020E61000009E060C923EF141401D8EAED2DD2B4B40
38042	1	6	1269	24140	\N	\N	54.433872999999998	Калужская область, Бабынинский район, Деревня Поповские Хутора, Здание Дома культуры	Россия, Калужская область, Бабынинский район, поселок Поповские Хутора	0101000020E6100000EC2FBB270FF7414007CF842689374B40
38036	1	6	1269	23850	\N	\N	54.291333000000002	Калужская область, Бабынинский район, Село Никольское, Здание Дома культуры, 11а		0101000020E61000003FA7203F1BF141406F9F55664A254B40
38120	1	6	1269	23850	74929	\N	54.293806561037798	д.Никольское, ул.Центральная, дом № 20а	Россия, Калужская область, Бабынинский район, поселок Никольское	0101000020E610000046B3B27DC8F14140FE2AC0779B254B40
38035	1	6	1269	23813	\N	\N	54.507624999999997	Калужская область,  Бабынинский район, Село Муромцево, Здание Дома культуры	Россия, Калужская область, Бабынинский район, поселок Муромцево	0101000020E61000002D7C7DAD4BF94140E5D022DBF9404B40
38479	1	6	1269	13224	35551	\N	54.437046000000002	с . Ленское, ул. Дачная, д. 2		0101000020E61000001BDA006C40F241407F6C921FF1374B40
38033	1	6	1269	23705	\N	\N	54.374122999999997	Калужская область,Бабынинский район, деревня Лапино, Здание Дома культуры, 40		0101000020E61000008E739B70AFEC414038D73043E32F4B40
38032	1	6	1269	23685	\N	\N	54.499876999999998	Калужская область, Бабынинский район, деревня Куракино, Здание администрации с/с	Россия, Калужская область, Бабынинский район, поселок Куракино	0101000020E61000003C139A2496E64140E48233F8FB3F4B40
38043	1	6	1269	24210	\N	\N	54.467956000000001	Калужская область, Бабынинский район, Село Кумовское, Здание Дома культуры	Россия, Калужская область, Бабынинский район, поселок Кумовское	0101000020E61000004F401361C3FB4140C6FB71FBE53B4B40
38031	1	6	1269	54209	\N	\N	54.439391999999998	Калужская область,Бабынинский район, поселок Газопровод, Здание Дома культуры	Россия, Калужская область, Бабынинский район, поселок Газопровода	0101000020E6100000583849F3C7CA4140E00F3FFF3D384B40
38045	1	6	1269	24227	35260	\N	54.470719000000003	Калужская область, Бабынинский район,Поселок Воротынск, Школьная, 21	Россия, Калужская область, Бабынинский район, поселок Воротынск	0101000020E610000066A19DD32C0642408C4D2B85403C4B40
38044	1	6	1269	24227	35219	\N	54.470719000000003	Калужская область, Бабынинский район, Поселок Воротынск, Центральная, 10		0101000020E610000066A19DD32C0642408C4D2B85403C4B40
38047	1	6	1269	24227	35245	\N	54.470719000000003	Калужская область, Бабынинский район, Поселок Воротынск, Школьная, 13		0101000020E610000066A19DD32C0642408C4D2B85403C4B40
38046	1	6	1269	24227	35280	\N	54.470719000000003	Калужская область, Бабынинский район, Поселок Воротынск, 50-лет Победы, 10		0101000020E610000066A19DD32C0642408C4D2B85403C4B40
38029	1	6	1269	23549	\N	\N	54.528523999999997	Калужская область, Бабынинский район деревня Воронино, Здание школы	Россия, Калужская область, Бабынинский район, поселок Воронино	0101000020E61000003E25E7C41ECE41405793A7ACA6434B40
38486	1	6	1269	23549	74942	\N	54.527622818716402	д. Воронино, ул. Центральная, д. 12	Россия, Калужская область, Бабынинский район, поселок Воронино	0101000020E61000007EACE0B721CE414007CF842689434B40
38040	1	6	1269	54221	\N	\N	54.395715779628802	Калужская область, Бабынинский район, Поселок Бабынинское отделение, Здание Дома культуры	Россия, Калужская область, Бабынинский район	0101000020E61000004EB4AB90F2E14140814067D2A6324B40
38027	1	6	1269	23389	35455	\N	54.391652000000001	Калужская область,Бабынинский район, Поселок Бабынино, Моторная, 4		0101000020E610000011DF89592FE24140DDB419A721324B40
38026	1	6	1269	23389	35247	\N	54.391652000000001	Калужская область, Бабынинский район, Поселок Бабынино, Новая, 2		0101000020E610000011DF89592FE24140DDB419A721324B40
38025	1	6	1269	23340	35488	\N	54.325744999999998	Калужская область, Бабынинский район,  село Антопьево, Центральная, 17		0101000020E61000009E0C8E9257E14140F2EA1C03B2294B40
34896	1	5	\N	54128	34462	\N	57.051272637246498	с. Пригородное, Вичугский проезд, 31	Россия, Ивановская область	0101000020E6100000F24410E7E1AC44407B15191D90864C40
34986	1	5	\N	54107	34226	\N	57.304786999999997	г. Юрьевец, Тарковского, 1а		0101000020E6100000317DAF21388C45407B9FAA4203A74C40
34588	1	5	\N	54083	34104	\N	56.851933000000002	Ивановская область, городской округ Шуя, площадь Сехская, 2		0101000020E6100000E78BBD175FB044400CB1FA230C6D4C40
34594	1	5	\N	54083	34041	\N	56.8412379696396	Ивановская область, городской округ Шуя, переулок Фабричный, 15	Россия, Ивановская область, Шуя городской округ	0101000020E610000040BD19355FAD44408313D1AFAD6B4C40
34585	1	5	\N	54083	34191	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Ярославская, 73	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34601	1	5	\N	54083	34200	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Советская, 46	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34600	1	5	\N	54083	34200	\N	56.8526906154869	Ивановская область, городской округ Шуя, улица Советская, 40	Россия, Ивановская область, Шуя	0101000020E610000048FC8A355CB04440F94B8BFA246D4C40
34597	1	5	\N	54083	34200	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Советская, 24	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34608	1	5	\N	54083	34190	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Свердлова, 127А	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
94413	1	5	\N	54083	34193	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Кооперативная,24	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34609	1	5	\N	54083	34193	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Кооперативная, 57	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34607	1	5	\N	54083	34193	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Кооперативная, 39	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34602	1	5	\N	54083	34132	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Зинаиды Касаткиной, 10		0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34612	1	5	\N	54083	34198	\N	56.852972771787996	Ивановская область, городской округ Шуя, улица Дуниловская, 33/2	Россия, Ивановская область, Шуя	0101000020E6100000E44C13B69FB044407DAF21382E6D4C40
34604	1	5	\N	54083	33984	\N	56.849586755183601	Ивановская область, городской округ Шуя, улица Вихрева, 65	Россия, Ивановская область, Шуя городской округ	0101000020E6100000083C3080F0B14440AA0D4E44BF6C4C40
34603	1	5	\N	54083	33984	\N	56.851933000000002	Ивановская область, городской округ Шуя, улица Вихрева, 81	Россия, Ивановская область, Шуя	0101000020E6100000E78BBD175FB044400CB1FA230C6D4C40
34586	1	5	\N	54083	34147	\N	56.8614834826897	Ивановская область, городской округ Шуя, улица Аникина, 21	Россия, Ивановская область, Шуя городской округ	0101000020E6100000D97BF1457BAE4440AD872F13456E4C40
34605	1	5	\N	54083	34224	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица 2-я Первомайская, 20	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34591	1	5	\N	54083	34098	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица 2-я Мичуринская, 2а		0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34599	1	5	\N	54083	33971	\N	56.841590773059799	Ивановская область, городской округ Шуя, улица 2-я Металлистов, 10	Россия, Ивановская область, Шуя городской округ	0101000020E6100000FE9E58A7CAAF4440D1CDFE40B96B4C40
34593	1	5	\N	54083	34144	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица 11-я Мичуринская, 6		0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34589	1	5	\N	54083	34093	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица 1-я Текстильная, 2 В		0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34587	1	5	\N	54083	34196	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица 1-я Нагорная, 14	Россия, Ивановская область, Шуя	0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34595	1	5	\N	54083	34173	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица 1-я Московская, 38		0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34571	1	5	\N	54100	34137	\N	57.252702999999997	Ивановская область, Фурмановский район, город Фурманов, Колосова, 25		0101000020E610000074D3669C868E4440F04C689258A04C40
34572	1	5	\N	54100	34421	\N	57.252702999999997	Ивановская область, Фурмановский район, город Фурманов, Демьяна бедного, 71		0101000020E610000074D3669C868E4440F04C689258A04C40
34551	1	5	\N	54076	33968	\N	56.8631380664022	Ивановская область, городской округ Тейково, пр. Красноармейский, 2	Россия, Ивановская область, Тейково городской округ	0101000020E610000036583849F3434440A9F7544E7B6E4C40
34543	1	5	\N	54076	34201	\N	56.8554532530448	Ивановская область, городской округ Тейково, пл.Ленина, 2	Россия, Ивановская область, Тейково	0101000020E61000002409C21550444440EE21E17B7F6D4C40
34549	1	5	\N	54076	33966	\N	56.85436	Ивановская область, городской округ Тейково, Шестагинская, 78	Россия, Ивановская область, Тейково	0101000020E61000000116F9F5434444405A8121AB5B6D4C40
34548	1	5	\N	54076	33966	\N	56.859047706993998	Ивановская область, городской округ Тейково, Шестагинская, 85	Россия, Ивановская область, Тейково городской округ	0101000020E6100000912BF52C08474440DCD8EC48F56D4C40
34508	1	5	\N	6105	33937	\N	57.441740000000003	город Кинешма, Социалистическая, 16		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34545	1	5	\N	54076	34195	\N	56.854719000000003	Ивановская область, городской округ Тейково, Чапаева, 24	Россия, Ивановская область, Тейково	0101000020E61000007F6ABC74934444408A22A46E676D4C40
34546	1	5	\N	54076	34203	\N	56.854719000000003	Ивановская область, городской округ Тейково, Октябрьская, 34	Россия, Ивановская область, Тейково	0101000020E61000007F6ABC74934444408A22A46E676D4C40
34544	1	5	\N	54076	34203	\N	56.855380106405498	Ивановская область, городской округ Тейково, Октябрьская, 3	Россия, Ивановская область, Тейково	0101000020E6100000C0594A969344444084D382177D6D4C40
34556	1	5	\N	54076	34209	\N	56.855616597449398	Ивановская область, городской округ Тейково, Молодежная, 24		0101000020E61000003A1F9E25C844444069739CDB846D4C40
34555	1	5	\N	54076	34209	\N	56.854719000000003	Ивановская область, городской округ Тейково, Молодежная, 10	Россия, Ивановская область, Тейково	0101000020E61000007F6ABC74934444408A22A46E676D4C40
34553	1	5	\N	54076	34029	\N	56.854719000000003	Ивановская область, городской округ Тейково, Ленинская, 3		0101000020E61000007F6ABC74934444408A22A46E676D4C40
34552	1	5	\N	54076	34029	\N	56.85436	Ивановская область, городской округ Тейково, Ленинская, 3а	Россия, Ивановская область, Тейково	0101000020E61000000116F9F5434444405A8121AB5B6D4C40
34547	1	5	1335	\N	33926	\N	56.862662687572303	Ивановская область, городской округ Тейково, Лежневская, 19	Россия, Ивановская область, Тейково городской округ	0101000020E61000005D6C5A2904444440103CBEBD6B6E4C40
34554	1	5	\N	54076	33941	\N	56.854719000000003	Ивановская область, городской округ Тейково, Гвардейская, 14	Россия, Ивановская область, Тейково	0101000020E61000007F6ABC74934444408A22A46E676D4C40
34877	1	5	\N	54104	34157	\N	57.108614000000003	город Родники, площадь Ленина, 10		0101000020E6100000F3FFAA2347DE4440A2F14410E78D4C40
34879	1	5	\N	54104	34180	\N	57.108614000000003	город Родники, мкр. Гагарина, 22		0101000020E6100000F3FFAA2347DE4440A2F14410E78D4C40
34852	1	5	\N	54105	34257	\N	56.978541	Ивановская область, Пучежский муниципальный район, Пучежское городское поселение, гПучеж, Радищева, 42		0101000020E61000008E20956247954540C765DCD4407D4C40
34854	1	5	\N	54105	34223	\N	56.978541	Ивановская область, Пучежский муниципальный район, Пучежское городское поселение, г.Пучеж, Калинина, 2		0101000020E61000008E20956247954540C765DCD4407D4C40
34829	1	5	\N	54094	34110	\N	57.3702696743686	Ивановская область, Приволжский муниципальный район, Социалистическая, 4	Россия, Ивановская область, Приволжский район, Приволжск	0101000020E6100000EC134031B2A444404F58E20165AF4C40
34827	1	5	\N	54094	34110	\N	57.382185999999997	Ивановская область, Приволжский муниципальный район, г.Приволжск, Социалистическая, 4		0101000020E6100000BCB1A03028A54440997E8978EBB04C40
34836	1	5	\N	54109	34279	\N	57.456932000000002	Ивановская область, Приволжский муниципальный район, г.Плес, Корнилова, 20		0101000020E6100000EB353D2828C14440793F6EBF7CBA4C40
34751	1	5	\N	54103	34154	\N	57.468119999999999	Ивановская область, Кинешемский муниципальный район, город Наволоки, улица Энгельса, дом 65		0101000020E6100000874D64E602FB4440404D2D5BEBBB4C40
34538	1	5	\N	54092	34140	\N	56.938883335489898	Ивановская область, городской округ Кохма, пер. Ивановский, д. 13	Россия, Ивановская область	0101000020E6100000F3C7B4368D8944409BE271512D784C40
34540	1	5	\N	54092	34146	\N	56.938972608838199	Ивановская область, городской округ Кохма, ул. Советская, д. 30	Россия, Ивановская область	0101000020E6100000B94F8E02448D4440DB696B4430784C40
34535	1	5	\N	54092	34138	\N	56.932262849036199	Ивановская область, городской округ Кохма, ул. Октябрьская, д. 38	Россия, Ивановская область	0101000020E610000093FDF334608C4440AB22DC6454774C40
34534	1	5	\N	54092	34138	\N	56.934337932787898	Ивановская область, городской округ Кохма, ул. Октябрьская, д. 64	Россия, Ивановская область	0101000020E6100000CF30B5A50E8C44407CB4386398774C40
34542	1	5	\N	54092	34058	\N	56.939006493501701	Ивановская область, городской округ Кохма, ул. Кочетовой, д. 36	Россия, Ивановская область	0101000020E610000030F488D1738D4440B75F3E5931784C40
34539	1	5	\N	54092	34100	\N	56.934878848609898	Ивановская область, городской округ Кохма, ул. Ивановская, д. 32	Россия, Ивановская область	0101000020E6100000DD26DC2BF38C4440CD5B751DAA774C40
34536	1	5	\N	54092	34123	\N	56.9210093662521	Ивановская область, городской округ Кохма, ул. 8 Марта, д. 1	Россия, Ивановская область	0101000020E6100000BA111615718C44402C29779FE3754C40
34755	1	5	\N	54095	34102	\N	57.028480999999999	город Комсомольск, Советская 5		0101000020E6100000390B7BDAE12F444058C7F143A5834C40
34685	1	5	\N	21279	33979	\N	56.950190818827302	д. Коляново, ул. Школьная, д. 81	Россия, Ивановская область, поселок Коляново	0101000020E61000008272DBBE477D44400DFAD2DB9F794C40
34084	1	5	\N	6105	34003	\N	57.442049710636397	город Кинешма, им. Юрия Горохова, 6А	Россия, Ивановская область, Кинешма	0101000020E6100000DA01D7153314454031992A1895B84C40
33798	1	5	\N	6105	34003	\N	57.4488580403778	город Кинешма, им. Юрия Горохова, 8		0101000020E610000021CB82893F0C45402446CF2D74B94C40
34400	1	5	\N	6105	34060	\N	57.441740000000003	город Кинешма, им. 50 лет Комсомола, 27		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34530	1	5	\N	6105	33945	\N	57.441740000000003	город Кинешма, Юрьевецкая 50/1		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34524	1	5	\N	6105	33945	\N	57.438046258489898	город Кинешма, Юрьевецкая, 46	Россия, Ивановская область, Кинешма городской округ	0101000020E61000000893E2E31318454062122EE411B84C40
34151	1	5	\N	6105	33996	\N	57.446631156636997	город Кинешма, ул. Щорса 32	Россия, Ивановская область, Кинешма городской округ	0101000020E61000000ABB287AE00D45409C3061342BB94C40
34510	1	5	\N	6105	33903	\N	57.461415513688799	город Кинешма, Фабричный двор, 12	Россия, Ивановская область, Кинешма городской округ	0101000020E6100000B3D2A414740F4540F2ECF2AD0FBB4C40
34525	1	5	\N	6105	34009	\N	57.432069188647702	город Кинешма, Спортиваная 21	Россия, Ивановская область, Кинешма городской округ	0101000020E6100000AFEE586C93144540C64E78094EB74C40
34507	1	5	\N	6105	33937	\N	57.443108353499198	город Кинешма, Социалистическая, 27а	Россия, Ивановская область, Кинешма	0101000020E610000029594E42E9134540494C50C3B7B84C40
95176	1	5	\N	6105	33925	\N	57.455264723385298	Ивановская область, городской округ Кинешма , ул. Правды д.4	Россия, Ивановская область, Кинешма городской округ	0101000020E6100000A986FD9E580F4540B8019F1F46BA4C40
34516	1	5	\N	6105	33925	\N	57.441740000000003	город Кинешма, ул. Правды д.4		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34506	1	5	\N	6105	33969	\N	57.468147512288297	город Кинешма, Наволокская, 18	Россия, Ивановская область, Кинешма городской округ	0101000020E6100000D5777E51820C45400AD80E46ECBB4C40
34528	1	5	\N	6105	34077	\N	57.441740000000003	город Кинешма, Межевая 18		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34531	1	5	\N	6105	34115	\N	57.441740000000003	город Кинешма, Ломоносова, 21-б		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34529	1	5	\N	6105	34115	\N	57.441740000000003	город Кинешма, Ломоносова, 20		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34519	1	5	\N	6105	33940	\N	57.441740000000003	город Кинешма, Ленина 42		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34522	1	5	\N	6105	33995	\N	57.441740000000003	город Кинешма, Котовского 19		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34521	1	5	\N	6105	33995	\N	57.441740000000003	город Кинешма, Котовского, 19		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34505	1	5	\N	6105	34086	\N	57.441740000000003	город Кинешма, Королева, 10		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34426	1	5	\N	6105	34016	\N	57.418129493320698	город Кинешма, Ивана Виноградова, 16	Россия, Ивановская область, Кинешма городской округ	0101000020E610000010EB8D5A610E45402D41464085B54C40
34377	1	5	\N	6105	34016	\N	57.4416158317254	город Кинешма, Ивана Виноградова, 18	Россия, Ивановская область, Кинешма	0101000020E6100000689599D2FA134540F7B182DF86B84C40
34520	1	5	\N	6105	34085	\N	57.441740000000003	город Кинешма, Волжский бульвар, 4		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34512	1	5	\N	6105	34076	\N	57.441740000000003	Ивановская область, город Кинешма, Воеводы Боборыкина, 18а		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34511	1	5	\N	6105	34076	\N	57.441740000000003	город Кинешма, Воеводы Боборыкина, 18а		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34509	1	5	\N	6105	34076	\N	57.441740000000003	город Кинешма, Воеводы Боборыкина, 53		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34376	1	5	\N	6105	34118	\N	57.441740000000003	город Кинешма, Вичугская 146		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34394	1	5	\N	6105	33934	\N	57.438352896821797	город Кинешма, Вичугская 104 А	Россия, Ивановская область, Кинешма городской округ	0101000020E610000010255AF2781045403F8D7BF31BB84C40
34219	1	5	\N	6105	33934	\N	57.4435942776297	город Кинешма, Вичугская, 176А	Россия, Ивановская область, Кинешма городской округ	0101000020E6100000B6D9588979124540D5592DB0C7B84C40
34533	1	5	\N	6105	33915	\N	57.441740000000003	город Кинешма, Веснина 7А	Россия, Ивановская область, Кинешма	0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34514	1	5	7296	\N	33900	\N	57.442617090538199	город Кинешма, 50-летия Комсомола, 22	Россия, Ивановская область, Кинешма городской округ	0101000020E610000062DBA2CC06154540AAD381ACA7B84C40
34513	1	5	\N	6105	33900	\N	57.441740000000003	город Кинешма, 50-летия Комсомола, 24		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
34517	1	5	\N	6105	33936	\N	57.441740000000003	город Кинешма, 3 Трудовой пер .д.4		0101000020E610000075E5B33C0F144540E3AAB2EF8AB84C40
33742	1	5	\N	429	\N	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Голубева, 2	Россия, Ивановская область, Иваново, станция Иваново	0101000020E6100000B85B9203767D44407442E8A04B824C40
34454	1	5	\N	429	33899	\N	56.975474720068803	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Ташкентская, 81	Россия, Ивановская область, Иваново, улица Ташкентская	0101000020E6100000454B1E4FCB7B44406688635DDC7C4C40
34458	1	5	\N	429	34090	\N	56.978674090079501	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Нефедова, 10	Россия, Ивановская область, Иваново, улица Нефедова	0101000020E610000033E202D0287B444006B98B30457D4C40
34473	1	5	\N	429	3353	\N	57.001394836024197	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Ленинградская, 13	Россия, Ивановская область, Иваново, улица Ленинградская	0101000020E61000008CF84ECC7A79444060B01BB62D804C40
34414	1	5	\N	429	34012	\N	57.013496132664301	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. 9 Января, д.39	Россия, Ивановская область, Иваново, улица 9 Января	0101000020E61000000BD5CDC5DF7C44403C50A73CBA814C40
34478	1	5	\N	429	33901	\N	57.004333851559203	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Талицкая 1, 4	Россия, Ивановская область, Иваново, улица 1-я Талицкая, 4	0101000020E6100000C669882AFC71444064213A048E804C40
34441	1	5	\N	429	33963	\N	56.977143461678601	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Жаворонкова Маршала, 5	Россия, Ивановская область, Иваново, улица маршала Жаворонкова, 5	0101000020E6100000D6027B4CA4864440F6419605137D4C40
34399	1	5	\N	429	34000	\N	56.960420521641602	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Маршала Василевского, 6	Россия, Ивановская область, Иваново, улица маршала Василевского, 6	0101000020E610000072C0AE264F7F444020B24813EF7A4C40
34391	1	5	\N	429	34117	\N	56.969838000000003	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Генерала Хлебникова, 32	Россия, Ивановская область, Иваново, улица генерала Хлебникова, 32	0101000020E6100000CA6ABA9EE87E44408335CEA6237C4C40
34382	1	5	\N	429	34015	\N	56.997790042742601	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Сакко, 45	Россия, Ивановская область, Иваново, улица Сакко, 43	0101000020E61000006C257497C47F44404F232D95B77F4C40
34420	1	5	\N	429	33929	\N	57.020595102078097	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. академика Мальцева, д.36	Россия, Ивановская область, Иваново, улица академика Мальцева, 34	0101000020E6100000B3412619397B444006BB61DBA2824C40
34449	1	5	\N	429	33988	\N	57.025474000000003	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Шувандиной, 84	Россия, Ивановская область, Иваново, улица Шувандиной, 84	0101000020E6100000C3B7B06EBC814440FC7266BB42834C40
34448	1	5	\N	429	33988	\N	57.023542631298803	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Шувандиной, 95	Россия, Ивановская область, Иваново, улица Шувандиной, 95	0101000020E61000008CF2CCCB618144405D86FF7403834C40
34444	1	5	\N	429	34024	\N	57.008009000000001	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Шошина, 15-Б	Россия, Ивановская область, Иваново, улица Шошина, 15б	0101000020E61000008E3D7B2E537F44406E895C7006814C40
34445	1	5	\N	429	34162	\N	57.015639974272098	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Чайковского, 38	Россия, Ивановская область, Иваново, улица 1-я Чайковского, 38	0101000020E6100000D3DEE00B938144403541D47D00824C40
34450	1	5	\N	429	34131	\N	57.033335999999998	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Хвойная, 2	Россия, Ивановская область, Иваново, улица Хвойная, 4	0101000020E6100000DA01D71533824440C5E3A25A44844C40
34427	1	5	\N	429	34017	\N	57.031528000000002	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Фрунзе, д.15/25	Россия, Ивановская область, Иваново, улица Фрунзе, 15	0101000020E6100000BC2363B5F97B44404374081C09844C40
34380	1	5	\N	429	33935	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Фридриха Энгельса проспект, 21		0101000020E6100000B85B9203767D44407442E8A04B824C40
34379	1	5	\N	429	33935	\N	56.998126999999997	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Фридриха Энгельса проспект, 10	Россия, Ивановская область, Иваново, Фридриха Энгельса проспект, 10	0101000020E6100000F75B3B51127E4440962023A0C27F4C40
34378	1	5	\N	429	33935	\N	56.997844936831001	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Фридриха Энгельса проспект, 8	Россия, Ивановская область, Иваново, Фридриха Энгельса проспект, 8	0101000020E6100000BA6A9E23F27D444012BD8C62B97F4C40
34387	1	5	\N	429	34114	\N	56.985073999999997	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Типографская, 25/55		0101000020E6100000B1DD3D40F77D4440E811A3E7167E4C40
34456	1	5	\N	429	33897	\N	56.985671830027897	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Ташкентская, 15	Россия, Ивановская область, Иваново, улица Ташкентская, 15	0101000020E610000006F69848697C44409D4A06802A7E4C40
34455	1	5	\N	429	33958	\N	56.985598247773197	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Танкиста Белороссова, 15	Россия, Ивановская область, Иваново, 2-й Летный переулок, 15	0101000020E610000061360186E57B444063804413287E4C40
34384	1	5	\N	429	33994	\N	56.993479871096298	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Суворова, 72	Россия, Ивановская область, Иваново, улица Суворова, 72	0101000020E61000005B7B9FAA42814440739D465A2A7F4C40
34402	1	5	\N	429	33921	\N	56.963752965497797	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Строителей проспект, 94-А	Россия, Ивановская область, Иваново, Строителей проспект, 94а	0101000020E6100000A7CD380D51814440003620425C7B4C40
34401	1	5	\N	429	33921	\N	56.969106649143598	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Строителей проспект, 124	Россия, Ивановская область, Иваново, Строителей проспект, 124	0101000020E610000025ADF886C28144408FA9BBB20B7C4C40
34397	1	5	\N	429	33921	\N	56.962938999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Строителей проспект, 4-А	Россия, Ивановская область, Иваново, Строителей проспект, 4а	0101000020E6100000D57954FCDF7D44407F85CC95417B4C40
34396	1	5	\N	429	33921	\N	56.963714000000003	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Строителей проспект, 31	Россия, Ивановская область, Иваново, Строителей проспект, 31	0101000020E6100000D4B5F63E557F44404359F8FA5A7B4C40
34395	1	5	\N	429	33921	\N	56.969386999999998	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Строителей проспект, 63	Россия, Ивановская область, Иваново, Строителей проспект, 63	0101000020E610000056664AEB6F81444072158BDF147C4C40
34464	1	5	\N	429	33905	\N	56.996111891227599	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Степанова, 9	Россия, Ивановская область, Иваново, улица Степанова, 9	0101000020E61000001E8B6D52D17C44409A931799807F4C40
34386	1	5	\N	429	34112	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Смирнова, 103		0101000020E6100000B85B9203767D44407442E8A04B824C40
34446	1	5	\N	429	34091	\N	57.015179000000003	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Свободы, 1		0101000020E610000044DB317557844440024BAE62F1814C40
34932	1	5	\N	429	67225	\N	57.031880999999998	Ивановская область, Тейковский муниципальный район, с.Светлый, Светлая, 7		0101000020E61000008D7E349C327D4440902E36AD14844C40
34893	1	5	1849	48575	34342	\N	56.999304000000002	д. Котиха, Молодежная, 7		0101000020E610000078F17EDC7EDF444089618731E97F4C40
34479	1	5	\N	429	33932	\N	57.006331499733697	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Рабфаковская, 14	Россия, Ивановская область, Иваново, улица Рабфаковская, 14	0101000020E6100000D1CE691668794440BAF94674CF804C40
34475	1	5	\N	429	33932	\N	57.001308999999999	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Рабфаковская, 34	Россия, Ивановская область, Иваново, улица Рабфаковская, 34	0101000020E6100000E622BE13B37844406118B0E42A804C40
34474	1	5	\N	429	33932	\N	57.010329491147097	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Рабфаковская, 2-а	Россия, Ивановская область, Иваново, улица Рабфаковская, 2	0101000020E6100000B4226AA2CF794440A699EE7552814C40
34404	1	5	\N	429	33902	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Профессиональная, 39		0101000020E6100000B85B9203767D44407442E8A04B824C40
34466	1	5	\N	429	33959	\N	56.997530575584399	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Почтовая, 3	Россия, Ивановская область, Иваново, улица Почтовая, 3	0101000020E6100000D95E0B7A6F7C444083DF8618AF7F4C40
34898	1	5	\N	429	34455	\N	56.994798903616001	д. Мальчиха, Почтовая, 29	Россия, Ивановская область, Иваново, улица Почтовая, 31	0101000020E61000003337DF88EE7B4440F88BD992557F4C40
34430	1	5	\N	429	33933	\N	57.029115762450303	"Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Полка ""Нормандия - Неман"", д.80"	Россия, Ивановская область, Иваново, улица Полка Нормандия-Неман, 80	0101000020E61000004A60730E9E7D44402AE5B512BA834C40
34390	1	5	\N	429	34164	\N	56.965839000000003	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Полевой проезд, 4	Россия, Ивановская область, Иваново, Полевой проезд, 4	0101000020E6100000D95A5F24B47D4440C619C39CA07B4C40
34477	1	5	\N	429	34048	\N	57.000608	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Парижской Коммуны, 60	Россия, Ивановская область, Иваново, улица Парижской Коммуны, 60	0101000020E610000039B4C876BE774440D80E46EC13804C40
34467	1	5	\N	429	34048	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Парижской Коммуны, 44		0101000020E6100000B85B9203767D44407442E8A04B824C40
34393	1	5	\N	429	33895	\N	56.971125056662302	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Панина, 21	Россия, Ивановская область, Иваново, улица Панина, 21	0101000020E61000002E02637D03814440FCA9F1D24D7C4C40
34437	1	5	\N	429	33892	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Окуловой, 59		0101000020E6100000B85B9203767D44407442E8A04B824C40
34436	1	5	\N	429	33892	\N	56.994840280835298	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Окуловой, 1	Россия, Ивановская область, Иваново, улица Окуловой, 1	0101000020E610000039605793A78244405760C8EA567F4C40
34431	1	5	\N	429	34066	\N	57.019936999999999	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Носова, д.49	Россия, Ивановская область, Иваново, улица Носова, 49	0101000020E6100000AA0B7899617F44407C7DAD4B8D824C40
34406	1	5	\N	429	34150	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Новосельская, 4-А		0101000020E6100000B85B9203767D44407442E8A04B824C40
34459	1	5	\N	429	34128	\N	56.979233000000001	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Некрасова, 51	Россия, Ивановская область, Иваново, улица Некрасова, 51	0101000020E6100000F83768AF3E7A4440FD14C781577D4C40
34457	1	5	\N	429	34128	\N	56.971938000000002	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Некрасова, 61	Россия, Ивановская область, Иваново, улица Некрасова, 61	0101000020E610000055336B29207B4440ADDEE176687C4C40
34463	1	5	\N	429	34133	\N	56.988644000000001	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Московская, 48	Россия, Ивановская область, Иваново, улица Московская, 48	0101000020E61000007FA2B2614D7D44407DB1F7E28B7E4C40
34425	1	5	\N	429	33893	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Минская, д.53		0101000020E6100000B85B9203767D44407442E8A04B824C40
34422	1	5	\N	429	33893	\N	57.033336419923501	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Минская, д.5		0101000020E6100000D49E927362794440C5E3A25A44844C40
34443	1	5	\N	429	33938	\N	56.951768086385499	Ивановская область, городской округ Иваново, Иваново, Советский район, Микрорайон ТЭЦ № 3, 14	Россия, Ивановская область, Иваново, Советский район	0101000020E610000063601DC70F8D44408EB0A888D3794C40
34403	1	5	\N	429	33998	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Маршала Василевского, 7		0101000020E6100000B85B9203767D44407442E8A04B824C40
34398	1	5	\N	429	33998	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Маршала Василевского, 6-А		0101000020E6100000B85B9203767D44407442E8A04B824C40
34469	1	5	\N	429	34135	\N	57.000529	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Мархлевского, 34/45	Россия, Ивановская область, Иваново, улица Мархлевского, 34	0101000020E6100000999B6F44F77A44408CD9925511804C40
34408	1	5	\N	429	34018	\N	56.959287629549998	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Любимова, 20-А	Россия, Ивановская область, Иваново, улица Любимова, 20а	0101000020E610000045D5AF743E824440FEB8FDF2C97A4C40
34407	1	5	\N	429	34018	\N	56.958321392724201	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Любимова, 16-А	Россия, Ивановская область, Иваново, улица Любимова, 16	0101000020E61000004930D5CC5A824440F6083543AA7A4C40
34471	1	5	\N	429	34139	\N	56.989575232515001	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Линия 19, 1-а	Россия, Ивановская область, Иваново, 20-я линия, 1а	0101000020E61000005516855D1477444038F8C264AA7E4C40
34196	1	5	\N	429	34049	\N	56.9769698076637	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Летчика Лазарева, 1/2	Россия, Ивановская область, Иваново, улица Летчика Лазарева	0101000020E61000007714E7A8A37D444029965B5A0D7D4C40
34499	1	5	\N	429	34186	\N	56.998263755722697	Ивановская область, городской округ Вичуга, Ленинградская, здание школы №17, 48	Россия, Ивановская область, Иваново, улица Ленинградская	0101000020E610000059130B7C457944401763601DC77F4C40
34417	1	5	\N	429	33987	\N	57.015882206826603	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, пр. Ленина, 53	Россия, Ивановская область, Иваново, Ленина проспект, 53	0101000020E610000012143FC6DC7B44402B4CDF6B08824C40
34416	1	5	\N	429	33987	\N	57.019727000000003	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, пр. Ленина, д.114	Россия, Ивановская область, Иваново, Ленина проспект, 114	0101000020E6100000E1ECD632197C444092EC116A86824C40
34413	1	5	\N	429	33987	\N	57.010925999999998	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, пр. Ленина, д.41	Россия, Ивановская область, Иваново, Ленина проспект, 41	0101000020E6100000268E3C10597C44408A56EE0566814C40
34596	1	5	\N	429	3983	\N	57.011136	Ивановская область, городской округ Шуя, площадь Ленина, 15		0101000020E6100000FC00A436717C444075E789E76C814C40
34410	1	5	\N	429	34019	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Лежневская, 203		0101000020E6100000B85B9203767D44407442E8A04B824C40
34452	1	5	\N	429	34025	\N	56.968695354816298	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Куликова, 19	Россия, Ивановская область, Иваново, улица Куликова, 19	0101000020E61000000E4A9869FB7B44403C66A032FE7B4C40
34451	1	5	\N	429	34025	\N	56.966557777821997	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Куликова, 27	Россия, Ивановская область, Иваново, улица Кирякиных, 27	0101000020E6100000C90567F0F77B4440F5D72B2CB87B4C40
34482	1	5	\N	429	34167	\N	57.010171632128603	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Кузнецова, 116	Россия, Ивановская область, Иваново, улица Кузнецова	0101000020E610000017B83CD68C784440DEAAEB504D814C40
34389	1	5	\N	429	34013	\N	56.968618625761799	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Кудряшова, 82	Россия, Ивановская область, Иваново, улица Кудряшова, 82	0101000020E610000090A339B2F27D444061A417B5FB7B4C40
34409	1	5	\N	429	34125	\N	56.950301480741601	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Кохомское шоссе, 29	Россия, Ивановская область, Иваново, Ленинский район	0101000020E6100000BAA1293BFD864440952D9276A3794C40
34933	1	5	\N	429	34020	\N	57.007648265926903	Ивановская область, Тейковский муниципальный район, с.Новое Горяново, Комсомольская, 14		0101000020E61000004698A25C1A7D44409EF0129CFA804C40
34411	1	5	\N	429	34020	\N	57.007941000000002	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Комсомольская, д.52	Россия, Ивановская область, Иваново, улица Комсомольская, 52	0101000020E6100000EE3D5C72DC7D444016A6EF3504814C40
34383	1	5	\N	429	34063	\N	56.997083000000003	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Колотилова, 43	Россия, Ивановская область, Иваново, улица Колотилова, 43	0101000020E61000002F8A1EF818804440E4326E6AA07F4C40
33730	1	5	\N	429	33985	\N	56.9844566058756	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Колесанова, 11	Россия, Ивановская область, Иваново, улица Колесанова	0101000020E61000002BDEC83CF27F4440BDA8DDAF027E4C40
34415	1	5	\N	429	34111	\N	57.015954000000001	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Карла Маркса, д.62/107	Россия, Ивановская область, Иваново, улица Карла Маркса, 62	0101000020E61000004C8DD0CFD47D4440C51EDAC70A824C40
34419	1	5	\N	429	34120	\N	57.019672522389499	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Ермака, д.41	Россия, Ивановская область, Иваново, улица Ермака, 41	0101000020E610000087C43D963E7A44409ECE15A584824C40
34418	1	5	\N	429	34120	\N	57.019069999999999	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Ермака, д.37/7	Россия, Ивановская область, Иваново, улица Ермака, 37	0101000020E610000045F12A6B9B7A4440D82AC1E270824C40
34412	1	5	\N	429	34061	\N	57.007490852814698	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Дунаева, д.13	Россия, Ивановская область, Иваново, улица Дунаева	0101000020E61000002A8E03AF967D4440D6011077F5804C40
34481	1	5	\N	429	34084	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Героя Советского Союза Сахарова П.И, 56		0101000020E6100000B85B9203767D44407442E8A04B824C40
34421	1	5	\N	429	34004	\N	57.023808000000002	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, пер. 1 Северный, д.21	Россия, Ивановская область, Иваново, 1-й Северный переулок, 21	0101000020E61000006269E047357A44400CB1FA230C834C40
34480	1	5	\N	429	34182	\N	57.008763999999999	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Сахарова П.И., Героя Советского Союза, 56	Россия, Ивановская область, Иваново, улица Героя Советского Союза Сахарова, 56	0101000020E6100000DDEBA4BE2C774440EAB0C22D1F814C40
34453	1	5	\N	429	33894	\N	57.017932999999999	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Воронина, 8		0101000020E6100000B85B9203767D44407442E8A04B824C40
34460	1	5	\N	429	34046	\N	56.985869000000001	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Володиной, 9	Россия, Ивановская область, Иваново, улица Володиной, 9	0101000020E61000003EB48F15FC784440F39194F4307E4C40
34462	1	5	\N	429	34134	\N	56.989385510448599	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Большая Воробьевская, 80		0101000020E6100000F584251E507A4440658F5033A47E4C40
34472	1	5	\N	429	33990	\N	56.988861443805099	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Бакинский проезд, 55-а	Россия, Ивановская область, Иваново, Бакинский проезд, 55а	0101000020E610000008944DB9C27744401AA54BFF927E4C40
33764	1	5	\N	429	34080	\N	56.995594487024803	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Багаева, 38/17	Россия, Ивановская область, Иваново, улица Багаева, 38	0101000020E610000082583673487C4440020CCB9F6F7F4C40
34381	1	5	\N	429	34052	\N	56.998162406047399	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Арсения, 33/16	Россия, Ивановская область, Иваново, улица Арсения, 33	0101000020E61000001EDD088B8A7E4440130EBDC5C37F4C40
34424	1	5	\N	429	34064	\N	57.035274999999999	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. Апрельская, д.3	Россия, Ивановская область, Иваново, улица Апрельская, 5	0101000020E6100000425F7AFB73774440E6AE25E483844C40
34447	1	5	\N	429	34126	\N	57.019182999999998	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Академическая, 5	Россия, Ивановская область, Иваново, улица Академическая, 5	0101000020E61000008F52094FE8814440D0D1AA9674824C40
34470	1	5	\N	429	33907	\N	56.994719595441097	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Линия 9, 1/26	Россия, Ивановская область, Иваново, 9-я линия, 3	0101000020E6100000C556D0B4C4784440AC5626FC527F4C40
34405	1	5	\N	429	34181	\N	56.955120999999998	Ивановская область, городской округ Иваново, Иваново, Ленинский район, 5-я Коляновская, 72	Россия, Ивановская область, Иваново, улица 5-я Коляновская, 72	0101000020E6100000B874CC79C67E4440855CA967417A4C40
34435	1	5	\N	429	33931	\N	56.9968799784005	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Сосневская 4, 57/15	Россия, Ивановская область, Иваново, улица 4-я Сосневская, 57	0101000020E6100000FF1F274C18834440AB048BC3997F4C40
34429	1	5	\N	429	34065	\N	57.036983999999997	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. 4 Деревенская, д.27	Россия, Ивановская область, Иваново, улица 4-я Деревенская, 27	0101000020E6100000774D486B0C7E4440D53C47E4BB844C40
34434	1	5	\N	429	34021	\N	57.0062686502052	Ивановская область, городской округ Иваново, Иваново, Советский район, Котельницкий переулок 4, 1-Б	Россия, Ивановская область, Иваново, 4-й Котельницкий переулок	0101000020E610000099B855100383444044FD2E6CCD804C40
34392	1	5	\N	429	34166	\N	56.969009	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Микрорайон № 30, 17	Россия, Ивановская область, Иваново, 30 микрорайон, 17	0101000020E6100000683D7C9928804440CC43A67C087C4C40
34440	1	5	\N	429	9738	\N	56.987723837523902	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Сосневская 3, 139	Россия, Ивановская область, Иваново, улица 3-я Сосневская, 139	0101000020E6100000EC4CA1F31A834440B6BC72BD6D7E4C40
34442	1	5	\N	429	33957	\N	56.985102387428398	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Ягодная 2, 31	Россия, Ивановская область, Иваново, улица 2-я Ягодная, 31	0101000020E6100000718DCF64FF884440B29C84D2177E4C40
34423	1	5	\N	429	34160	\N	57.033378739234898	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. 2 Ключевая, д.20	Россия, Ивановская область, Иваново, улица 2-я Ключевая	0101000020E6100000E126A3CA30764440C4AF58C345844C40
34461	1	5	\N	429	34130	\N	56.977246000000001	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, 13 Березниковская, 1	Россия, Ивановская область, Иваново, улица 13-я Березниковская, 1	0101000020E610000091D26C1E87774440CB129D65167D4C40
34438	1	5	\N	429	34083	\N	56.989611379141699	Ивановская область, городской округ Иваново, Иваново, Советский район, Проезд 10, 24/2		0101000020E610000033880FECF88344408461C092AB7E4C40
34385	1	5	\N	429	34163	\N	56.994216445655802	Ивановская область, городской округ Иваново, Иваново, Ленинский район, Десятого Августа, 85		0101000020E6100000BB44F5D6C07E444079944A78427F4C40
34428	1	5	\N	429	34023	\N	57.034383237411603	Ивановская область, городской округ Иваново, Иваново, Октябрьский район, ул. 1 Минеевская, д.25/2	Россия, Ивановская область, Иваново, улица 1-я Минеевская, 25	0101000020E6100000DB334B02D47C4440E94482A966844C40
34439	1	5	\N	429	34027	\N	56.988154504903697	Ивановская область, городской округ Иваново, Иваново, Советский район, ул. Меланжевая 1, 5		0101000020E61000008DD31055F88344407F30F0DC7B7E4C40
30125	1	4	\N	19	36271	\N	51.703276000000002	г.Воронеж, Хользунова, 44		0101000020E61000008944A165DD974340E607AEF204DA4940
34656	1	5	\N	54096	34107	\N	57.478301999999999	Ивановская область, Заволжский муниципальный район, Заволжское городское поселение, г. Заволжск, пер. Парковский 6		0101000020E610000078094E7D2013454042CEFBFF38BD4C40
34658	1	5	\N	54096	34238	\N	57.478301999999999	Ивановская область, Заволжский муниципальный район, Заволжское городское поселение, г. Заволжск, Почтовая, 2		0101000020E610000078094E7D2013454042CEFBFF38BD4C40
34711	1	5	\N	54123	34437	\N	56.958538729780997	"с. Железнодорожный(ФГУ комбинат ""зеленый"" Росрезерва)  ул. Садовая д.19"	Россия, Ивановская область	0101000020E6100000C47B0E2C479044406478EC67B17A4C40
34489	1	5	\N	54075	34205	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Ульяновская,  здание Детской школы искусств, 9	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34486	1	5	\N	54075	34205	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Ульяновская,  здание школы № 10, 11	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34493	1	5	\N	54075	34055	\N	57.2070689300186	Ивановская область, городской округ Вичуга, Покровская, здание филиала ИГТА, 6	Россия, Ивановская область, Вичуга	0101000020E610000044A51133FBF64440F981AB3C819A4C40
34492	1	5	\N	54075	34050	\N	57.211528000000001	Ивановская область, городской округ Вичуга, Парковая, здание школы №11, 8	Россия, Ивановская область, Вичуга	0101000020E61000000F2A711DE3F444401A187959139B4C40
34490	1	5	\N	54075	34050	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Парковая, здание Центра детского творчества, 1		0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34488	1	5	\N	54075	33973	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Н.П. Куликовой, здание школы № 9, 13	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34484	1	5	\N	54075	33923	\N	57.220122706607697	"Ивановская область, городской округ Вичуга, Металлистов, здание Дома культуры ""Машиностроитель"", 9"		0101000020E61000009D2E8B89CDF54440780C8FFD2C9C4C40
34503	1	5	\N	54075	33981	\N	57.215673243224103	Ивановская область, городской округ Вичуга, Ленинская, здание клуба имени Шагова, 26	Россия, Ивановская область, Вичуга	0101000020E61000009700FC53AAF64440ABD0402C9B9B4C40
34498	1	5	\N	54075	34184	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Ленинградская, здание Социального приюта для детей, 72	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34497	1	5	\N	54075	34184	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Ленинградская, здание клуба им.Фрунзе, 107	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34496	1	5	\N	54075	34184	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Ленинградская, здание спорткомплекса Текстильщик, 86	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34501	1	5	\N	54075	34051	\N	57.208245010442198	Ивановская область, городской округ Вичуга, Желябова, здание школы №6, 6	Россия, Ивановская область, Вичуга	0101000020E6100000850B790437F644401B47ACC5A79A4C40
34495	1	5	\N	54075	34202	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Дачная, здание школы №12, 1/16	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34483	1	5	\N	54075	34188	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Володарского, здание школы №13, 14	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34491	1	5	\N	54075	34207	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Б.Хмельницкого, здание Межшкольного учебного комбината, 52	Россия, Ивановская область, Вичуга	0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34487	1	5	\N	54075	33962	\N	57.213682437782403	Ивановская область, городской округ Вичуга, Б-Пролетарская,  здание Культурного центра, 1	Россия, Ивановская область, Вичуга	0101000020E6100000D655815A0CF8444037DF88EE599B4C40
34494	1	5	\N	54075	34211	\N	57.209085999999999	Ивановская область, городской округ Вичуга, Абрамовой, здание Комбината детского питания, 18		0101000020E61000007C48F8DEDFF4444096067E54C39A4C40
34485	1	5	\N	54075	34142	\N	57.211528000000001	Ивановская область, городской округ Вичуга, 50-лет Октября, здание филиала школы №13, 16	Россия, Ивановская область, Вичуга	0101000020E61000000F2A711DE3F444401A187959139B4C40
34500	1	5	\N	54075	34033	\N	57.214392620515397	Ивановская область, городской округ Вичуга, 1-Ломоносова, здание Вичугской школы VIII вида, 28	Россия, Ивановская область, Вичуга	0101000020E61000006745D4449FF34440E4BED53A719B4C40
35000	1	5	557	46088	34347	\N	57.296672000000001	д. Ямская ул. Молодежная 28		0101000020E61000003B8C497F2F8B4540C8D11C59F9A54C40
34984	1	5	557	3460	33986	\N	57.311300304133702	г. Юрьевец, Школьная, 3	Россия, Ивановская область, Юрьевецкий район, Юрьевец	0101000020E6100000CB9F6F0B968C4540569FABADD8A74C40
34987	1	5	557	3460	34269	\N	57.304786999999997	г. Юрьевец, Чкалова, 4а		0101000020E6100000317DAF21388C45407B9FAA4203A74C40
34991	1	5	557	3460	33980	\N	57.304786999999997	г.Юрьевец, Титова, 4	Россия, Ивановская область, Юрьевецкий район, Юрьевец	0101000020E6100000317DAF21388C45407B9FAA4203A74C40
34990	1	5	557	3460	33980	\N	57.304786999999997	г. Юрьевец, Титова, 2		0101000020E6100000317DAF21388C45407B9FAA4203A74C40
34989	1	5	557	3460	33954	\N	57.304786999999997	г. Юрьевец, Советская, 143	Россия, Ивановская область, Юрьевецкий район, Юрьевец	0101000020E6100000317DAF21388C45407B9FAA4203A74C40
34988	1	5	557	3460	33954	\N	57.304786999999997	г. Юрьевец, Советская, 97		0101000020E6100000317DAF21388C45407B9FAA4203A74C40
34985	1	5	557	3460	34284	\N	57.304786999999997	г. Юрьевец, Промышленная, 10а		0101000020E6100000317DAF21388C45407B9FAA4203A74C40
94417	1	5	557	4328	34314	\N	57.240470000000002	"""Ивановская область, Юревецкий район,д. Щекотиха, Школьная, 2а"		0101000020E61000003E92921E867C4540A6D590B8C79E4C40
34992	1	5	557	3862	34375	\N	57.302964000000003	с. Тихон-Воля, Школьная, 1		0101000020E61000005E4D9EB29A824540C4EE3B86C7A64C40
94416	1	5	557	47709	34327	\N	57.262599999999999	с. Соболево, ул. Молодежная (здание школы), д.5		0101000020E61000004C70EA03C9834540FDF675E09CA14C40
34994	1	5	557	46012	34397	\N	57.319322	д. Пелевино, Советская, 8		0101000020E6100000378C82E0F17945405872158BDFA84C40
94419	1	5	557	4452	34321	\N	57.178337999999997	"""Ивановская область, Юревецкий район, с. Обжериха, ул. Реформатовского (здание школы), д.24"		0101000020E6100000B58CD47B2A7B454028D192C7D3964C40
94420	1	5	557	37443	34313	\N	57.144601000000002	"""Ивановская область, Юревецкий район, с. Новленское, ул. Нагорная (здание Дома культуры), д.6"		0101000020E610000092240857407F454005FC1A4982924C40
34997	1	5	557	46076	34297	\N	57.338082	с. Михайлово, Советская, 14-а		0101000020E610000056EF703B34624540E2AE5E4546AB4C40
34993	1	5	557	3887	34376	\N	57.345663999999999	д. Лобаны, Волжская, 2а		0101000020E6100000CB49287D21864540C8B3CBB73EAC4C40
94418	1	5	557	4388	34396	\N	57.259498999999998	"""Ивановская область, Юревецкий район,д. Костяево Большое, ул. Набережная (здание школы), д.1"		0101000020E6100000B517D1764C5D45401F2C634337A14C40
35005	1	5	557	46264	34417	\N	57.223390000000002	с. Жуковка ул. Сиреневая 6		0101000020E6100000BBEF181EFB7145407120240B989C4C40
34996	1	5	557	4081	34285	\N	57.338115999999999	с Елнать, Сиротина, 6		0101000020E61000003929CC7B9C6945408E20956247AB4C40
34995	1	5	557	46028	34506	\N	57.288642000000003	с. Дорки, Школьная, 1		0101000020E610000093567C43E16B454043209738F2A44C40
34999	1	5	557	46128	34412	\N	57.276076000000003	д. Ваньково ул. Солнечеая 22		0101000020E6100000CD936B0A645A4540F29A577556A34C40
34961	1	5	399	2087	\N	\N	56.584957000000003	Ивановская область, Южский муниципальный район, город Южа, ул.Черняховского, д.11	Россия, Ивановская область, Южский район, Южа	0101000020E610000044183F8D7B0145407C48F8DEDF4A4C40
34965	1	5	399	2087	33920	\N	56.5847676777666	Ивановская область, Южский муниципальный район, город Южа, ул. Советская, д.20	Россия, Ивановская область, Южский район, Южа	0101000020E6100000C05C8B16A0014540A8DF85ADD94A4C40
34964	1	5	399	2087	33920	\N	56.584957000000003	Ивановская область, Южский муниципальный район, город Южа, ул. Советская, д.9		0101000020E610000044183F8D7B0145407C48F8DEDF4A4C40
34962	1	5	399	2087	34174	\N	56.584957000000003	Ивановская область, Южский муниципальный район, город Южа, ул. Речная, д.1		0101000020E610000044183F8D7B0145407C48F8DEDF4A4C40
34960	1	5	399	2087	33949	\N	56.584957000000003	Ивановская область, Южский муниципальный район, город Южа, ул.Пушкина, д.2		0101000020E610000044183F8D7B0145407C48F8DEDF4A4C40
34966	1	5	399	2087	34044	\N	56.584957000000003	Ивановская область, Южский муниципальный район, город Южа, ул.Новая, д.3а		0101000020E610000044183F8D7B0145407C48F8DEDF4A4C40
34963	1	5	399	2087	33952	\N	56.584957000000003	Ивановская область, Южский муниципальный район, город Южа, Глушицкий проезд, д.4а		0101000020E610000044183F8D7B0145407C48F8DEDF4A4C40
34982	1	5	399	3347	34354	\N	56.655544999999996	Ивановская область, Южский муниципальный район, село Хотимль, ул. Юбилейная 10		0101000020E61000005CE674594CDA4440350708E6E8534C40
34976	1	5	399	54111	34307	\N	56.577328000000001	Ивановская область, Южский муниципальный район, село Холуй, ул.Полевая, д. 1а	Россия, Ивановская область, Южский район, Холуй	0101000020E6100000E469F981ABEE4440558847E2E5494C40
34970	1	5	399	2656	34178	\N	56.527757999999999	Ивановская область, Южский муниципальный район, село Талицы, ул. Ленина, д.12		0101000020E6100000DF4F8D976E2A4540E719FB928D434C40
34977	1	5	399	3027	\N	\N	56.603022000000003	Ивановская область, Южский муниципальный район, деревня Селищи, д.98		0101000020E6100000F3AE7AC03CEA44405F622CD32F4D4C40
34981	1	5	399	3277	34411	\N	56.650053	Ивановская область, Южский муниципальный район, село Преображенское, ул. Преображенская, д.67		0101000020E6100000BB4560AC6FEA444056D5CBEF34534C40
34974	1	5	399	2892	34428	\N	56.43045	Ивановская область, Южский муниципальный район, село Новоклязьминское, ул. Придорожная, д.3		0101000020E6100000969526A5A0014540174850FC18374C40
34967	1	5	399	2464	34371	\N	56.602674999999998	Ивановская область, Южский муниципальный район, деревня Нефёдово, ул.Центральная, д.43		0101000020E6100000A4FE7A8505014540F38E5374244D4C40
34971	1	5	399	2688	34291	\N	56.597779000000003	Ивановская область, Южский муниципальный район, село Мугреевский, ул. Школьная, д.7а		0101000020E61000006BD44334BA2D4540289EB305844C4C40
34969	1	5	399	2568	34429	\N	56.631371999999999	Ивановская область, Южский муниципальный район, село Мугреево-Никольское, ул.Центральная, д.40		0101000020E61000007DCA3159DC1D454018CE35CCD0504C40
34973	1	5	399	2768	34346	\N	56.530254999999997	Ивановская область, Южский муниципальный район, село Моста, ул. Восточная 5		0101000020E6100000865451BCCA1445402EC55565DF434C40
34979	1	5	399	3157	\N	\N	56.553953	Ивановская область, Южский муниципальный район, село Мордовское, д.38а		0101000020E6100000CDAFE600C1EE4440B34291EEE7464C40
34980	1	5	399	3238	34345	\N	56.547468000000002	Ивановская область, Южский муниципальный район, деревня Изотино, ул.Центральная, д.24а		0101000020E610000083E0F1ED5DD94440A3CD716E13464C40
34968	1	5	399	2544	34344	\N	56.704906999999999	Ивановская область, Южский муниципальный район, село Груздево, ул. Центральная, д.12		0101000020E610000098FBE4284008454059DC7F643A5A4C40
34606	1	5	1438	54093	34148	\N	56.852032000000001	Ивановская область, городской округ Шуя, улица Горелова, 12		0101000020E6100000B0FF3A376DB044409F9273620F6D4C40
34944	1	5	177	1164	34365	\N	56.886474	Ивановская область, Шуйский муниципальный район, Васильевское сельское поселение, д. Чижово, Арсения, 9		0101000020E610000065DF15C1FFBC44408D60E3FA77714C40
34899	1	5	1849	31226	\N	\N	57.049602999999998	д. Куделино	Россия, Ивановская область, Родниковский район, поселок Куделино	0101000020E61000001409A69A59FD444049641F6459864C40
34942	1	5	177	1039	\N	\N	56.981234000000001	Ивановская область, Шуйский муниципальный район, Васильевское сельское поселение, д. Чечкино-Богородское, Здание клуба	Россия, Ивановская область, Шуйский район, поселок Чечкино-Богородское	0101000020E61000008D43FD2E6CD1444094DC6113997D4C40
34682	1	5	177	1039	34152	\N	56.981234000000001	с. Богородское, ул. 5-я Клинцевская, д. 26		0101000020E61000008D43FD2E6CD1444094DC6113997D4C40
34678	1	5	177	1039	34253	\N	56.981234000000001	с. Богородское, ул. Большая Клинцевская, д. 4 А		0101000020E61000008D43FD2E6CD1444094DC6113997D4C40
34947	1	5	177	1305	34410	\N	56.939253999999998	Ивановская область, Шуйский муниципальный район, Введенское сельское поселение, с. Чернцы, Школьная, 11		0101000020E6100000EDD5C743DFAB44408F519E7939784C40
34935	1	5	177	585	\N	\N	56.742521000000004	"Ивановская область, Шуйский муниципальный район, Колобовское городское поселение, село Центральный, Дом культуры ""Юбилейный"""		0101000020E61000004AD235936FB04440EFCB99ED0A5F4C40
34953	1	5	177	1664	\N	\N	56.792808999999998	Ивановская область, Шуйский муниципальный район, Остаповское сельское поселение, д. Харитоново, Здание представительства администрации Остаповского с/п	Россия, Ивановская область, Шуйский район, поселок Харитоново	0101000020E61000000F29064834CB4440BB7CEBC37A654C40
34957	1	5	177	1876	34043	\N	56.828260999999998	Ивановская область, Шуйский муниципальный район, Семейкинское сельское поселение, д. Филино, Набережная, 9		0101000020E6100000E02A4F20ECAA4440B0C6D974046A4C40
34951	1	5	177	1531	\N	\N	56.761634999999998	"Ивановская область, Шуйский муниципальный район, Остаповское сельское поселение, с. Сергеево, ФГОУ СПО ""Сельскохозяйственный техникум"""		0101000020E6100000B2A03028D3B44440963E74417D614C40
34959	1	5	177	2009	34309	\N	56.807718000000001	Ивановская область, Шуйский муниципальный район, Семейкинское сельское поселение, д. Семейкино, Колхозная, 16		0101000020E6100000BFBB95253AAB4440FD31AD4D63674C40
34937	1	5	177	712	34306	\N	56.847759000000003	Ивановская область, Шуйский муниципальный район, Афанасьевское сельское поселение, с. Пустошь, Квартал 2, 1		0101000020E61000006D75392520D04440E1F1ED5D836C4C40
34954	1	5	177	1734	34270	\N	56.878822	Ивановская область, Шуйский муниципальный район, Перемиловское сельское поселение, д. Прилив, Центральная, 12		0101000020E61000000BF0DDE68DB34440AE80423D7D704C40
34949	1	5	177	1416	34268	\N	56.823700000000002	Ивановская область, Шуйский муниципальный район, Остаповское сельское поселение, д. Остапово, Зеленая, 72		0101000020E610000058923CD7F7B344408CDB68006F694C40
34940	1	5	177	54115	\N	\N	56.967579194465998	Ивановская область, Шуйский муниципальный район, Васильевское сельское поселение, д. Никитинское, Клуб, 44	Россия, Ивановская область, Шуйский район, поселок Никитское	0101000020E61000006A6803B001DB4440F0A5F0A0D97B4C40
34943	1	5	177	1065	34392	\N	56.893196000000003	Ивановская область, Шуйский муниципальный район, Васильевское сельское поселение, д. Михалково, Центральная, 7		0101000020E61000004DF4F92823C4444082751C3F54724C40
34941	1	5	177	951	\N	\N	56.766494000000002	Ивановская область, Шуйский муниципальный район, Васильевское сельское поселение, д. Михалево, Здание администрации	Россия, Ивановская область, Шуйский район, поселок Михалево	0101000020E610000027F911BF629B4440454AB3791C624C40
34958	1	5	177	951	34373	\N	56.766494000000002	Ивановская область, Шуйский муниципальный район, Семейкинское сельское поселение, д. Михалево, Зеленая		0101000020E610000027F911BF629B4440454AB3791C624C40
34950	1	5	177	1492	\N	\N	56.795554000000003	Ивановская область, Шуйский муниципальный район, Остаповское сельское поселение, д. Милюковка, Милюковская МСОШ		0101000020E610000082C64CA25EBE4440DB19A6B6D4654C40
34934	1	5	177	556	34177	\N	56.709339	Ивановская область, Шуйский муниципальный район, Колобовское городское поселение, п. Колобово, Садовая, 2, Колобовская МСОШ		0101000020E6100000DD5CFC6D4FAC44408063CF9ECB5A4C40
34952	1	5	177	1624	\N	\N	56.717188999999998	Ивановская область, Шуйский муниципальный район, Остаповское сельское поселение, д. Клочково, Дом культуры		0101000020E610000037FE4465C3C24440850662D9CC5B4C40
34948	1	5	177	1386	34158	\N	56.866926999999997	Ивановская область, Шуйский муниципальный район, Китовское сельское поселение, с. Китово, Центральная, 94		0101000020E61000000A48FB1F60A544407B82C476F76E4C40
34956	1	5	177	1846	34308	\N	56.941046	Ивановская область, Шуйский муниципальный район, Перемиловское сельское поселение, д. Качалово, Северная, 8		0101000020E6100000AFEDED96E4B844400C04013274784C40
34676	1	5	177	48810	34266	\N	56.865918999999998	д. Иванцево, ул. Ивановская, д. 20		0101000020E6100000D07EA4880CBB444015FE0C6FD66E4C40
34801	1	5	177	46808	34281	\N	56.715746000000003	д.Запрудново, Половинская, 2		0101000020E6100000543882548AA34440151F9F909D5B4C40
34946	1	5	177	1283	34225	\N	56.996949999999998	Ивановская область, Шуйский муниципальный район, Введенское сельское поселение, с. Дунилово, Советская, 19		0101000020E61000004E7D2079E7B44440A4DFBE0E9C7F4C40
34945	1	5	177	1187	34374	\N	56.965893000000001	Ивановская область, Шуйский муниципальный район, Введенское сельское поселение, с. Введенье, Мира, 28		0101000020E6100000522AE109BDAA4440B937BF61A27B4C40
34939	1	5	177	839	34256	\N	56.933287	Ивановская область, Шуйский муниципальный район, Васильевское сельское поселение, с. Васильевское, Советская, 1		0101000020E6100000C767B27F9ED444401764CBF275774C40
34936	1	5	177	677	\N	\N	56.853247000000003	Ивановская область, Шуйский муниципальный район, Афанасьевское сельское поселение, с. Афанасьевское, Дом культуры, 20А		0101000020E61000000AF5F411F8C544407F349C32376D4C40
34938	1	5	177	804	\N	\N	56.825522999999997	Ивановская область, Шуйский муниципальный район, Афанасьевское сельское поселение, д. Арефино, Дом культуры		0101000020E61000002DAF5C6F9BC34440438CD7BCAA694C40
34583	1	5	1365	15936	\N	\N	57.198788999999998	Ивановская область, Фурмановский район, село Широково, 40		0101000020E6100000B056ED9A908E4440FBE6FEEA71994C40
34579	1	5	1365	15784	\N	\N	57.219057999999997	Ивановская область, Фурмановский район, село Хромцово, 9 А		0101000020E610000053793BC2697B4440ADF6B0170A9C4C40
34570	1	5	1365	14742	33912	\N	57.265273376112503	Ивановская область, Фурмановский район, город Фурманов, Тимирязева, 32	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E6100000492D944C4E8F444083C13577F4A14C40
34569	1	5	1365	14742	33912	\N	57.252702999999997	Ивановская область, Фурмановский район, город Фурманов,  Тимирязева 10		0101000020E610000074D3669C868E4440F04C689258A04C40
34567	1	5	1365	14742	33912	\N	57.264677172434098	Ивановская область, Фурмановский район, город Фурманов, Тимирязева, 10	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E61000008202EFE4D38F44406F8099EFE0A14C40
34566	1	5	1365	14742	33912	\N	57.265715165564799	Ивановская область, Фурмановский район, город Фурманов, Тимирязева, 43	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E610000028806264C98E44404087F9F202A24C40
34565	1	5	1365	14742	33912	\N	57.252702999999997	Ивановская область, Фурмановский район, город Фурманов, Тимирязева, 42		0101000020E610000074D3669C868E4440F04C689258A04C40
34560	1	5	1365	14742	34089	\N	57.252702999999997	Ивановская область, Фурмановский район, город Фурманов, Социалистическая, 15		0101000020E610000074D3669C868E4440F04C689258A04C40
34559	1	5	1365	14742	34032	\N	57.251089328805797	Ивановская область, Фурмановский район, город Фурманов, Советская, 7	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E61000007D789620238E444053B131AF23A04C40
34561	1	5	1365	14742	33919	\N	57.2527524647817	Ивановская область, Фурмановский район, город Фурманов, Пролетарская, 7	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E610000067F16261888E4440D2FF722D5AA04C40
34558	1	5	1365	14742	33993	\N	57.258442401696101	Ивановская область, Фурмановский район, город Фурманов, Нижний Двор, 72	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E610000047C8409E5D8C4440D8F4A0A014A14C40
34557	1	5	1365	14742	34035	\N	57.256299469010202	Ивановская область, Фурмановский район, город Фурманов, Наримановская, 18	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E6100000A7936C75398B4440AE7FD767CEA04C40
34563	1	5	1365	14742	34092	\N	57.252702999999997	Ивановская область, Фурмановский район, город Фурманов, Карла Либкнехта, 76		0101000020E610000074D3669C868E4440F04C689258A04C40
34564	1	5	1365	14742	33951	\N	57.256058528344902	Ивановская область, Фурмановский район, город Фурманов, Возрождения, 40	Россия, Ивановская область, Фурмановский район, Фурманов	0101000020E6100000740CC85EEF8E4440596C938AC6A04C40
34577	1	5	1365	15691	\N	\N	57.159022999999998	Ивановская область, Фурмановский район, деревня Снетиново, 53		0101000020E610000084D4EDEC2BA74440E9279CDD5A944C40
34576	1	5	1365	54118	\N	\N	57.224657000000001	Ивановская область, Фурмановский район, село Погост, 64		0101000020E6100000A7EA1ED95C854440A3E8818FC19C4C40
34578	1	5	1365	15752	\N	\N	57.288102000000002	Ивановская область, Фурмановский район, деревня Панино, 74		0101000020E610000059198D7C5E8D4440C3F4BD86E0A44C40
34889	1	5	1365	48509	\N	\N	57.132933000000001	с. Никульское	Россия, Ивановская область, Фурмановский район, поселок Никульское	0101000020E610000020990E9D9EA9444093C7D3F203914C40
34891	1	5	1365	48547	\N	\N	57.317703000000002	с. Михайловское, 60		0101000020E6100000C9CA2F8331944440A96BED7DAAA84C40
34581	1	5	1365	15913	\N	\N	57.312089	Ивановская область, Фурмановский район, село Марьинское, 17		0101000020E6100000EC67B114C97144407E384888F2A74C40
34798	1	5	1365	54116	34389	\N	57.1701162406438	д.Котово Школьная 17	Россия, Ивановская область, Фурмановский район, поселок Котово	0101000020E61000003CD9CD8C7E9E44405F43705CC6954C40
34724	1	5	1365	49529	\N	\N	57.299877000000002	село Игрищи, дом 124		0101000020E610000087FC3383F86844404BE9995E62A64C40
34575	1	5	1365	15605	\N	\N	57.234459999999999	Ивановская область, Фурмановский район, деревня Иванково, 54		0101000020E610000086562767289444402E1C08C9029E4C40
34584	1	5	1365	16033	\N	\N	57.266610999999997	Ивановская область, Фурмановский район, деревня Земляничный, 20		0101000020E610000048FAB48AFE8644407EE02A4F20A24C40
30277	1	5	1365	40387	\N	\N	57.158251999999997	д. Захарьино, д. 22		0101000020E6100000412B306475A944406743FE9941944C40
34574	1	5	1365	15510	34355	\N	57.254052000000001	Ивановская область, Фурмановский район, село Дуляпино, Текстильная, 10б		0101000020E61000009A232BBF0C684440E0BDA3C684A04C40
34573	1	5	1365	15510	34271	\N	57.254052000000001	Ивановская область, Фурмановский район, село Дуляпино, Советская, 12		0101000020E61000009A232BBF0C684440E0BDA3C684A04C40
34468	1	5	7311	54081	33964	\N	56.999763342659001	Ивановская область, городской округ Иваново, Иваново, Фрунзенский район, Строительная, 5	Россия, Ивановская область, Иваново, Строительный переулок, 7	0101000020E61000008908FF22687A44401C60E63BF87F4C40
34731	1	5	4	45376	34521	\N	56.623514	деревня Хлебницы, улица Центральная, дом 29		0101000020E61000004E98309A952F4440904C874ECF4F4C40
34921	1	5	4	54108	\N	\N	56.664583999999998	Ивановская область, Тейковский муниципальный район, д.Харино, школа	Россия, Ивановская область, Тейковский район, поселок Харино	0101000020E61000006C94F59B89334440F1B8A81611554C40
34930	1	5	4	296	34326	\N	56.596643999999998	Ивановская область, Тейковский муниципальный район, д.Сокатово, Зеленая, 1/2		0101000020E61000008FFAEB15163E444064ADA1D45E4C4C40
34926	1	5	4	32484	34372	\N	56.794657000000001	Ивановская область, Тейковский муниципальный район, с.Сахтыш, Постышева, 28		0101000020E61000004276DEC666354440CC441152B7654C40
34931	1	5	4	333	34075	\N	56.808363999999997	Ивановская область, Тейковский муниципальный район, с.Новое Лушино, площадь Ленина, 12	Россия, Ивановская область, Тейковский район, поселок Новое Леушино	0101000020E6100000102043C70E424440C2A1B77878674C40
34920	1	5	4	32166	34265	\N	56.660823999999998	Ивановская область, Тейковский муниципальный район, п.Нерль, Пограничная, 11А		0101000020E61000008F8EAB915D314440B9347EE195544C40
34919	1	5	4	32166	34263	\N	56.660823999999998	Ивановская область, Тейковский муниципальный район, п.Нерль, Ленина, 4		0101000020E61000008F8EAB915D314440B9347EE195544C40
34918	1	5	4	32128	\N	\N	56.752994999999999	Ивановская область, Тейковский муниципальный район, д.Москвино, 81		0101000020E61000001FD95C35CF1B44409886E12362604C40
34928	1	5	4	7	34264	\N	56.727699000000001	Ивановская область, Тейковский муниципальный район, с.Морозово, Школьная, 16А		0101000020E610000054742497FF4244407C2AA73D255D4C40
34927	1	5	4	7	34246	\N	56.727699000000001	Ивановская область, Тейковский муниципальный район, с.Морозово, Молодежная, 1А		0101000020E610000054742497FF4244407C2AA73D255D4C40
34639	1	5	4	7	67227	\N	56.727699000000001	с. Морозово, ул. Гусева, д.2		0101000020E610000054742497FF4244407C2AA73D255D4C40
34925	1	5	4	32426	34267	\N	56.862980999999998	Ивановская область, Тейковский муниципальный район, с.Крапивново, Центральная, 38		0101000020E6100000EE4108C8971A4440E1085229766E4C40
34929	1	5	4	200	34324	\N	56.624217000000002	Ивановская область, Тейковский муниципальный район, с.Елховка, Школьная, 2А		0101000020E6100000715AF0A2AF404440BA4DB857E64F4C40
34550	1	5	4	54079	\N	\N	56.872816	Ивановская область, городской округ Тейково, п. Грозилово, ОГБОУ ПЛ №19	Россия, Ивановская область, Тейковский район, поселок Грозилово	0101000020E61000009AB67F65A547444078B6476FB86F4C40
94320	1	5	4	60371	74899	\N	56.737824320921398	д.Быково Речная 5	Россия, Ивановская область, Тейковский район, поселок Быково	0101000020E61000009A97C3EE3B4644401A1A4F04715E4C40
34923	1	5	4	32294	34233	\N	56.883853000000002	"""Ивановская область, Тейковский муниципальный район, д. Большое Клочково ул. Центральная 53 А"		0101000020E6100000E945ED7E154E44405ABC581822714C40
34922	1	5	4	32294	34233	\N	56.883853000000002	Ивановская область, Тейковский муниципальный район, д.Большое Клочково, Центральная, 50		0101000020E6100000E945ED7E154E44405ABC581822714C40
34675	1	5	4490	36659	\N	\N	57.696173000000002	д. Беляницы, д. 29 В		0101000020E61000003293A8177C7C4240DAAD65321CD94C40
34914	1	5	1916	31947	34370	\N	56.602888	д.Шестуниха, Молодежная, 12		0101000020E6100000ACE63922DF9D44404F93196F2B4D4C40
34916	1	5	1916	31291	34473	\N	56.593680999999997	д.Савино, Полевая, 1Б		0101000020E610000023128596759B4440D7A02FBDFD4B4C40
34903	1	5	1916	31291	33975	\N	56.593680999999997	п.Савино, Первомайская, 39		0101000020E610000023128596759B4440D7A02FBDFD4B4C40
34902	1	5	1916	31291	33975	\N	56.593680999999997	п.Савино, Первомайская, 9	Россия, Ивановская область, Савинский район, поселок Савино	0101000020E610000023128596759B4440D7A02FBDFD4B4C40
34901	1	5	1916	31291	33975	\N	56.593680999999997	п.Савино, Первомайская, 24		0101000020E610000023128596759B4440D7A02FBDFD4B4C40
34909	1	5	1916	48853	34503	\N	56.583609000000003	с.Польки, Центральная, 23		0101000020E6100000A9F57EA31D8944405D5320B3B34A4C40
34915	1	5	1916	48963	34323	\N	56.565778000000002	д.Полома, Советская, 46		0101000020E6100000E82E89B322964440ED65DB696B484C40
34911	1	5	1916	48889	34409	\N	56.603794999999998	д.Покровское, Фабричная, 6		0101000020E61000005DA9674128AF4440813E9127494D4C40
34917	1	5	1916	48992	34399	\N	56.669944999999998	с.Панфилово, Первомайская, 1А		0101000020E61000004F24986A66934440328FFCC1C0554C40
34702	1	5	1916	49190	\N	\N	56.643168000000003	с. Михалево д.25		0101000020E610000009DFFB1BB4CF4440B8EA3A5453524C40
34648	1	5	1916	48317	\N	\N	56.501744000000002	с. Лычево, Административное здание сельского поселения		0101000020E6100000029CDEC5FBB744406C7BBB2539404C40
34912	1	5	1916	48921	34393	\N	56.547741000000002	д.Горячево, Бреховская, 5		0101000020E610000015191D9084C74440D4D688601C464C40
34906	1	5	1916	48799	34388	\N	56.595505000000003	с.Вознесенье, Центральная, 52		0101000020E61000009FE8BAF08381444060CD0182394C4C40
34905	1	5	1916	48786	34074	\N	56.660393999999997	с.Архиповка, 1-я Кооперативная, 6		0101000020E6100000CE548847E29F4440C03C64CA87544C40
34908	1	5	1916	31687	34286	\N	56.576459999999997	с.Агрофенино, Центральная, 4		0101000020E6100000FB743C66A0804440E0B9F770C9494C40
34888	1	5	1849	30684	34426	\N	57.116942000000002	д. Тайманиха, Молодежный, 21		0101000020E61000009BA9108FC4C54440B1C398F4F78E4C40
34895	1	5	1849	48589	34369	\N	56.954900000000002	с. Сосновец, Центральная, 13		0101000020E610000013D55B035BE34440A779C7293A7A4C40
34890	1	5	1849	48523	\N	\N	57.093702	д. Ситьково	Россия, Ивановская область, Родниковский район, поселок Ситьково	0101000020E6100000CEC4742156B54440EFC8586DFE8B4C40
34885	1	5	1849	28577	34073	\N	57.108614000000003	город Родники, пр.Северный, 1		0101000020E6100000F3FFAA2347DE4440A2F14410E78D4C40
34876	1	5	1849	28577	34072	\N	57.108614000000003	город Родники, площадь Ленина, 10/6		0101000020E6100000F3FFAA2347DE4440A2F14410E78D4C40
34881	1	5	1849	28577	34109	\N	57.108614000000003	город Родники, мкр. Южный, 22		0101000020E6100000F3FFAA2347DE4440A2F14410E78D4C40
34884	1	5	1849	28577	34047	\N	57.108614000000003	город Родники, мкр. Машиностроитель, 7		0101000020E6100000F3FFAA2347DE4440A2F14410E78D4C40
34843	1	5	1849	28577	34040	\N	57.105883839780802	город Родники, Советская, 2	Россия, Ивановская область, Родниковский район, Родники	0101000020E61000005793A7ACA6DD4440B8955E9B8D8D4C40
34880	1	5	1849	28577	34042	\N	57.103989611715903	город Родники, Народная, 7	Россия, Ивановская область, Родниковский район, Родники	0101000020E6100000F3E32F2DEADD4440378E588B4F8D4C40
34882	1	5	1849	28577	33917	\N	57.108614000000003	город Родники, 60 лет Октября д.6		0101000020E6100000F3FFAA2347DE4440A2F14410E78D4C40
34878	1	5	1849	28577	33950	\N	57.096258513960898	город Родники, 3-я Куликовская, 49	Россия, Ивановская область, Родниковский район, Родники	0101000020E6100000C51D6FF25BE044400C790437528C4C40
34897	1	5	1849	31139	34255	\N	57.138829000000001	с. Постнинский, Школьная, 24		0101000020E61000008D26176360D74440425E0F26C5914C40
34892	1	5	1849	30897	34283	\N	57.011318000000003	с. Парское, Светлая, 8		0101000020E6100000F7E5CC7685DA444096ED43DE72814C40
34887	1	5	1849	48468	34243	\N	57.203747999999997	с. Острецово, Центральная, 6		0101000020E6100000C64FE3DEFCC644400D501A6A149A4C40
34886	1	5	1849	54106	34216	\N	57.154693000000002	с. Каминское, Каминского, 13	Россия, Ивановская область, Родниковский район, поселок Каминский	0101000020E610000038A27BD635BC4440C7F5EFFACC934C40
34857	1	5	1849	29212	\N	\N	56.963607000000003	с. Болотново	Россия, Ивановская область, Родниковский район, поселок Болотново	0101000020E61000003D47E4BB94F044402D996379577B4C40
34872	1	5	1857	29914	34304	\N	57.086323	Ивановская область, Пучежский муниципальный район, Сеготское сельское поселение, с.Сеготь, Советская, 32		0101000020E61000004BE48233F881454041F2CEA10C8B4C40
34851	1	5	1857	28910	33976	\N	56.981868333077003	Ивановская область, Пучежский муниципальный район, Пучежское городское поселение, г.Пучеж, Ленина, 41	Россия, Ивановская область, Пучежский район, Пучеж	0101000020E61000000FD4298F6E964540957EC2D9AD7D4C40
34850	1	5	1857	28910	33976	\N	56.978541	Ивановская область, Пучежский муниципальный район, Пучежское городское поселение, г.Пучеж, Ленина, 48		0101000020E61000008E20956247954540C765DCD4407D4C40
34855	1	5	1857	28910	34156	\N	56.978541	Ивановская область, Пучежский муниципальный район, Пучежское городское поселение, г.Пучеж, Кирова, 1/2		0101000020E61000008E20956247954540C765DCD4407D4C40
34858	1	5	1857	28910	33924	\N	56.978541	Ивановская область, Пучежский муниципальный район, Пучежское городское поселение, г.Пучеж, Заводская, 8/1	Россия, Ивановская область, Пучежский район, Пучеж	0101000020E61000008E20956247954540C765DCD4407D4C40
34853	1	5	1857	28910	34175	\N	56.978541	Ивановская область, Пучежский муниципальный район, Пучежское городское поселение, г.Пучеж, 60 лет Октября, 20		0101000020E61000008E20956247954540C765DCD4407D4C40
34867	1	5	1857	29664	34339	\N	56.868653999999999	Ивановская область, Пучежский муниципальный район, Мортковское сельское поселение, д.Привалово, Центральная, 7		0101000020E6100000BBB4E1B0347A454011C5E40D306F4C40
34873	1	5	1857	29931	34352	\N	57.084454000000001	Ивановская область, Пучежский муниципальный район, Сеготское сельское поселение, с.Петрово, Центральная, 30		0101000020E610000057AF22A30378454019028063CF8A4C40
34869	1	5	1857	29778	34330	\N	56.860850999999997	Ивановская область, Пучежский муниципальный район, Мортковское сельское поселение, с.Мортки, Школьная, 9		0101000020E61000008B87F71C588E45404CDD955D306E4C40
34874	1	5	1857	30004	34386	\N	57.082816000000001	Ивановская область, Пучежский муниципальный район, Сеготское сельское поселение, д.Марищи, Школьная, 5		0101000020E6100000E753C72AA5614540F3CAF5B6998A4C40
34861	1	5	1857	29380	34322	\N	56.917420999999997	Ивановская область, Пучежский муниципальный район, Илья-Высоковское сельское поселение, с.Лужинки, Школьная, 7		0101000020E61000007A1C06F357764540F1D4230D6E754C40
34871	1	5	1857	29857	34408	\N	57.026463	Ивановская область, Пучежский муниципальный район, Сеготское сельское поселение, д.Летнево, Школьная, 20		0101000020E61000005299620E82864540EBC6BB2363834C40
34866	1	5	1857	29572	34343	\N	56.925089999999997	Ивановская область, Пучежский муниципальный район, Илья-Высоковское сельское поселение, д.Кораблево, Садовая, 3-1		0101000020E61000004242942F687D4540A6ED5F5969764C40
34868	1	5	1857	29716	34398	\N	56.887166999999998	Ивановская область, Пучежский муниципальный район, Мортковское сельское поселение, с.Кандаурово, Центральная, 18		0101000020E61000007F2F8507CD824540938B31B08E714C40
34862	1	5	1857	52400	34229	\N	56.936411	Ивановская область, Пучежский муниципальный район, Илья-Высоковское сельское поселение, с.Иля-Высоково, Шкрльная, 3		0101000020E610000086AE44A0FA854540AD4ECE50DC774C40
34859	1	5	1857	29303	34219	\N	56.956505	Ивановская область, Пучежский муниципальный район, Затеихинское сельское поселение, д.Затеиха, Школьная, 8		0101000020E61000005ABBED42736F4540F1BA7EC16E7A4C40
34860	1	5	1857	29350	34351	\N	56.977868999999998	Ивановская область, Пучежский муниципальный район, Затеихинское сельское поселение, с.Зарайское, Клубная, 3		0101000020E61000006EDC627E6E784540D862B7CF2A7D4C40
34863	1	5	1857	29481	34282	\N	56.944346000000003	Ивановская область, Пучежский муниципальный район, Илья-Высоковское сельское поселение, д.Дубново, Советская, 1		0101000020E6100000DA1F28B7ED954540E10D6954E0784C40
34875	1	5	1857	30059	34341	\N	57.125171000000002	Ивановская область, Пучежский муниципальный район, Сеготское сельское поселение, д.Дроздиха, Садовая, 23		0101000020E6100000D5CE30B5A58045402DB4739A05904C40
34864	1	5	1857	29536	\N	\N	56.930891000000003	Ивановская область, Пучежский муниципальный район, Илья-Высоковское сельское поселение, д.Губинская, здание ФАпа МУЗ Пучежская ЦРБ, 29		0101000020E610000051853FC39B8145400492B06F27774C40
34870	1	5	1857	29802	34395	\N	56.893835000000003	Ивановская область, Пучежский муниципальный район, Мортковское сельское поселение, д.Дмитриево-Большое, Центральная, 3		0101000020E610000090BC73284397454095826E2F69724C40
31317	1	5	1826	28347	34357	\N	57.405253000000002	с. Филисово, Школьная, 1		0101000020E61000008D96033DD4B044408ECD8E54DFB34C40
34838	1	5	1826	28347	34385	\N	57.405253000000002	Ивановская область, Приволжский муниципальный район, д.Филисово, Зеленая, 2		0101000020E61000008D96033DD4B044408ECD8E54DFB34C40
34849	1	5	1826	28853	\N	\N	57.322344999999999	Ивановская область, Приволжский муниципальный район, д.Федорище, 88		0101000020E6100000FBE8D495CFAA4440BA83D89942A94C40
34839	1	5	1826	28387	\N	\N	57.429203000000001	Ивановская область, Приволжский муниципальный район, с.Утес, 26		0101000020E6100000207EFE7BF0CC44402C2CB81FF0B64C40
34841	1	5	1826	28497	34232	\N	57.328758999999998	Ивановская область, Приволжский муниципальный район, с.Толпыгино, Центральная, 8		0101000020E61000003DB83B6BB79D444001A260C614AA4C40
30124	1	4	\N	19	36271	\N	51.703639000000003	г.Воронеж, Хользунова, 38		0101000020E61000005AD6FD63219843405798BED710DA4940
34837	1	5	1826	28290	34231	\N	57.451906000000001	Ивановская область, Приволжский муниципальный район, с.Северцево, Гагарина, 6		0101000020E6100000B77BB94F8EBE4440DF6E490ED8B94C40
34848	1	5	1826	28835	34302	\N	57.25262	Ивановская область, Приволжский муниципальный район, с.Рождествено, Центральная, 27		0101000020E61000002E3BC43F6CAF4440632827DA55A04C40
34833	1	5	1826	27821	33914	\N	57.382185999999997	Ивановская область, Приволжский муниципальный район, г.Приволжск, Коминтерновская, 32		0101000020E6100000BCB1A03028A54440997E8978EBB04C40
34832	1	5	1826	27821	33914	\N	57.378416523704701	Ивановская область, Приволжский муниципальный район, г.Приволжск, Коминтерновская, 36	Россия, Ивановская область, Приволжский район, Приволжск	0101000020E61000001343723271A544400EA0DFF76FB04C40
34830	1	5	1826	27821	34071	\N	57.382185999999997	Ивановская область, Приволжский муниципальный район, г.Приволжск, Дружбы, 5		0101000020E6100000BCB1A03028A54440997E8978EBB04C40
34834	1	5	1826	27821	33948	\N	57.382185999999997	Ивановская область, Приволжский муниципальный район, г.Приволжск, 1 Мая, 10		0101000020E6100000BCB1A03028A54440997E8978EBB04C40
34835	1	5	1826	28215	34248	\N	57.456932000000002	Ивановская область, Приволжский муниципальный район, г.Плес, Советская, 37		0101000020E6100000EB353D2828C14440793F6EBF7CBA4C40
34846	1	5	1826	28719	\N	\N	57.383336	Ивановская область, Приволжский муниципальный район, д.Парушево, 38		0101000020E61000003EB48F15FCAE444092B06F2711B14C40
34845	1	5	1826	54113	34300	\N	57.360166999999997	Ивановская область, Приволжский муниципальный район, с.Новое, Советская, 24	Россия, Ивановская область, Приволжский район, поселок Новое	0101000020E610000066F7E461A1BA4440990CC7F319AE4C40
34842	1	5	1826	28515	\N	\N	57.378494000000003	Ивановская область, Приволжский муниципальный район, с.Кунестино, 72		0101000020E6100000D498107349954440BADDCB7D72B04C40
34844	1	5	1826	28644	\N	\N	57.350130999999998	Ивановская область, Приволжский муниципальный район, с.Красинское, 108	Россия, Ивановская область, Приволжский район, поселок Красинское	0101000020E61000007976F9D687AB44406B28B517D1AC4C40
34840	1	5	1826	28452	34179	\N	57.395598	Ивановская область, Приволжский муниципальный район, с.Ингарь, Спортивная, 15		0101000020E6100000309DD66D50A74440772E8CF4A2B24C40
34847	1	5	1826	28747	\N	\N	57.312522000000001	Ивановская область, Приволжский муниципальный район, с.Горки-Чириковы, 6		0101000020E61000002CB81FF0C0BE4440E8A38CB800A84C40
34823	1	5	1816	27687	34368	\N	56.682713999999997	д.Шалаево, ул. Центральная, д.5		0101000020E61000008C683BA6EE604540BB421F2C63574C40
34822	1	5	1816	47237	34338	\N	56.726345999999999	д.Филята, ул. Центральная, д.57		0101000020E61000008ACBF10A444B45404BCADDE7F85C4C40
34824	1	5	1816	27747	34172	\N	56.704324	п.Пестяки, ул. Социалистическая, д.15		0101000020E61000007FA65EB708564540DAE4F049275A4C40
34825	1	5	1816	27747	33977	\N	56.710720810249001	п.Пестяки, ул. Гагарина, д.27	Россия, Ивановская область, Пестяковский район, поселок Пестяки	0101000020E61000007D3ECA880B5645404BCADDE7F85A4C40
34819	1	5	1816	27473	34290	\N	56.659711000000001	с.Нижний Ландех, ул.Советская, д.24		0101000020E61000002D95B7239C364540DEE7F86871544C40
34817	1	5	1816	27387	34336	\N	56.580554999999997	д.Неверово-Слобода, ул.Зелёная, д.5		0101000020E61000009A97C3EE3B564540BF4351A04F4A4C40
34820	1	5	1816	27554	34367	\N	56.685937000000003	д.Галашово, ул.Галашовская, д.7		0101000020E61000004E9A0645F34C4540E50E9BC8CC574C40
34821	1	5	1816	27617	34340	\N	56.633381999999997	д.Вербино, ул.Школьная, д.12		0101000020E61000006534F279C55D454002F04FA912514C40
34816	1	5	1816	27362	34301	\N	56.774864999999998	с.Беклемищи, ул.Молодежная, д.21		0101000020E6100000728A8EE4F25B454053E8BCC62E634C40
34813	1	5	1816	47061	34406	\N	56.613584000000003	д. Алехино, ул.Центральная, д.54		0101000020E6100000C64E78094E4B4540A8ACA6EB894E4C40
34807	1	5	1810	46931	\N	\N	56.746420999999998	с.Тименка, здание библиотеки, 16		0101000020E61000003D7C992842E8444018062CB98A5F4C40
94321	1	5	1810	45754	\N	\N	56.800311000000001	с.Сакулино, здание администрации Сакулинского сельского поселения, 2Б		0101000020E61000003F1BB96E4A0B454085D0419770664C40
34805	1	5	1810	46900	\N	\N	56.825597000000002	с.Подолино, здание сельского клуба, 16 а		0101000020E6100000404CC2853CF444407E569929AD694C40
34803	1	5	1810	46845	34335	\N	56.821148999999998	д.Пеньки, 40 лет Победы, 48 а		0101000020E6100000881057CEDE1B4540511212691B694C40
34804	1	5	1810	46853	34407	\N	56.850053000000003	д.Паново, Центральная, 21		0101000020E6100000A14D0E9F740C4540F06E6589CE6C4C40
34812	1	5	1810	27113	34106	\N	56.798127000000001	п.Палех, Ленина, 1		0101000020E6100000F2785A7EE0EE4440FD86890629664C40
34811	1	5	1810	27113	33946	\N	56.798127000000001	п.Палех, Баканова, 19		0101000020E6100000F2785A7EE0EE4440FD86890629664C40
34810	1	5	1810	27084	34081	\N	56.897388999999997	с.Майдаково, Северная, 21		0101000020E6100000F085C954C1E8444023658BA4DD724C40
34806	1	5	1810	26900	34382	\N	56.788908999999997	д.Клетино, Центральная, 8		0101000020E61000002577D84466D44440914259F8FA644C40
34800	1	5	1789	26606	34425	\N	56.962321000000003	с.Худынское, Набережная, 56		0101000020E6100000A4E4D5390622454084A0A3552D7B4C40
30708	1	5	1789	47737	34234	\N	57.046366999999996	с.Тимирязево, Центральная, 62		0101000020E61000005B0BB3D0CE1D45408B4E965AEF854C40
94319	1	5	1789	33155	34358	\N	56.922845000000002	д.Слободки Центральная 1		0101000020E610000098FA7953912A45407923F3C81F764C40
34796	1	5	1789	46700	34467	\N	56.923105	с.Рябово, Школьная, 21		0101000020E61000001DACFF73981B454015E3FC4D28764C40
34794	1	5	1789	26323	34424	\N	57.005833000000003	с.Порздни, Советская, 17		0101000020E610000048C0E8F2E6464540691EC022BF804C40
34788	1	5	1789	26052	33947	\N	57.010621999999998	пос.Лух, Красноармейская, 4А		0101000020E6100000FBAC32535A2145401E4FCB0F5C814C40
34793	1	5	1789	26292	\N	\N	57.069116999999999	с.Воскресенское Новое, 9		0101000020E6100000E62329E9614045407F4C6BD3D8884C40
94317	1	5	1789	45673	34384	\N	57.016370000000002	с.Благовещенье ул. Центральная 43		0101000020E610000035EECD6F983445405951836918824C40
34785	1	5	1331	25951	\N	\N	56.921385999999998	Ивановская область, Лежневский муниципальный район, Шилыковское сельское поселение, с. Шилыково, Клуб, 38		0101000020E6100000C43F6CE9D15E4440027FF8F9EF754C40
34786	1	5	1331	25951	34217	\N	56.921385999999998	Ивановская область, Лежневский муниципальный район, Шилыковское сельское поселение, с. Шилыково, ул. Зеленая, д. 31		0101000020E6100000C43F6CE9D15E4440027FF8F9EF754C40
34784	1	5	1331	25922	34262	\N	56.862617	Ивановская область, Лежневский муниципальный район, Чернское сельское поселение, с. Чернцы, ул. Центральная, д. 27		0101000020E61000002DD2C43BC0614440A0FCDD3B6A6E4C40
34783	1	5	1331	25866	34218	\N	56.805219999999998	Ивановская область, Лежневский муниципальный район, Хозниковское сельское поселение, с. Хозниково, ул. Лежневская, д. 25		0101000020E6100000344C6DA9838E4440E50AEF7211674C40
34777	1	5	1331	60490	75528	\N	56.761856346984501	Ивановская область, Лежневский муниципальный район, Лежневское сельское поселение, с. Ухтохма, ул. Московская, д. 7		0101000020E6100000B8CB7EDDE97444407521567F84614C40
34778	1	5	1331	25643	\N	\N	56.795929000000001	Ивановская область, Лежневский муниципальный район, Лежневское сельское поселение, д. Телегино, Клуб		0101000020E610000077A04E797463444010786000E1654C40
34782	1	5	1331	25806	34250	\N	56.823321	Ивановская область, Лежневский муниципальный район, Сабиновское сельское поселение, д. Сабиново, ул. Мичурина, д. 1А		0101000020E61000004128EFE368784440158E209562694C40
34779	1	5	1331	25660	34235	\N	56.731031999999999	Ивановская область, Лежневский муниципальный район, Ново-Горкинское сельское поселение, с. Новые Горки, ул. Советская, д. 11		0101000020E6100000B7442E38838944402C2AE274925D4C40
34780	1	5	1331	25660	34261	\N	56.731031999999999	Ивановская область, Лежневский муниципальный район, Ново-Горкинское сельское поселение, с. Новые Горки, ул. Московская, д. 8		0101000020E6100000B7442E38838944402C2AE274925D4C40
34781	1	5	1331	25660	34277	\N	56.731031999999999	Ивановская область, Лежневский муниципальный район, Ново-Горкинское сельское поселение, с. Новые Горки, ул. Большая Шуйская, д. 13Б		0101000020E6100000B7442E38838944402C2AE274925D4C40
34775	1	5	1331	25491	\N	\N	56.620007999999999	"Ивановская область, Лежневский муниципальный район, Воскресенское сельское поселение, д. Растилково Малое, ДОУ ""Ивушка"""		0101000020E6100000BD38F1D58E7E444012A1116C5C4F4C40
34771	1	5	1331	25190	34260	\N	56.776018999999998	Ивановская область, Лежневский муниципальный район, Лежневское городское поселение, п. Лежнево, пл. Советская, д.15		0101000020E6100000B7088CF50D7244408D09319754634C40
34770	1	5	1331	25190	34260	\N	56.776018999999998	Ивановская область, Лежневский муниципальный район, Лежневское городское поселение, п. Лежнево, ул. Советская, д. 8		0101000020E6100000B7088CF50D7244408D09319754634C40
34774	1	5	1331	25190	34215	\N	56.776018999999998	Ивановская область, Лежневский муниципальный район, Лежневское городское поселение, п. Лежнево, ул. Островского, д. 17		0101000020E6100000B7088CF50D7244408D09319754634C40
34773	1	5	1331	25190	34245	\N	56.776018999999998	Ивановская область, Лежневский муниципальный район, Лежневское городское поселение, п. Лежнево, ул. Ивановская, д. 30		0101000020E6100000B7088CF50D7244408D09319754634C40
34772	1	5	1331	25190	34244	\N	56.776018999999998	Ивановская область, Лежневский муниципальный район, Лежневское городское поселение, п. Лежнево, 1-я Луначарского, д. 9		0101000020E6100000B7088CF50D7244408D09319754634C40
34769	1	5	1331	25190	34249	\N	56.776018999999998	Ивановская область, Лежневский муниципальный район, Лежневское городское поселение, п. Лежнево, ул. 1-я Комсомольская, д. 6		0101000020E6100000B7088CF50D7244408D09319754634C40
34776	1	5	1331	25515	34247	\N	56.700142999999997	Ивановская область, Лежневский муниципальный район, Воскресенское сельское поселение, с. Воскресенское, ул. Молодежная, д. 6		0101000020E6100000438D4292597B4440FCC22B499E594C40
34766	1	5	1019	25059	\N	\N	57.141143999999997	село Седельницы, 57		0101000020E61000006A8995D1C84544406803B00111924C40
30479	1	5	1019	8878	\N	\N	57.006425999999998	село Светиково, 7а		0101000020E61000000E65A88AA91844400BEC3191D2804C40
34904	1	5	1019	48762	34295	\N	57.019618999999999	п.Савино, Советская, 13		0101000020E6100000CC7A3194130D4440ABB019E082824C40
34768	1	5	1019	25131	34153	\N	57.215657	село Подозерский, ул.Ленина, 22а		0101000020E61000007B884677102B4440A51309A69A9B4C40
34763	1	5	1019	24900	33997	\N	57.180002000000002	село Писцово, ул. Советская 4А	Россия, Ивановская область, Комсомольский район, поселок Писцово	0101000020E610000045BB0A293F434440789B374E0A974C40
34762	1	5	1019	24900	34070	\N	57.180002000000002	село Писцово, ул.Советская, 43		0101000020E610000045BB0A293F434440789B374E0A974C40
34761	1	5	1019	45955	34273	\N	57.139048000000003	село Октябрьский, ул.Техническая, 5		0101000020E610000052651877832A444080492A53CC914C40
34759	1	5	1019	24759	34403	\N	57.018628999999997	село Новая Усадьба, ул.Зои Космодемьянской, 6		0101000020E6100000C91F0C3CF72E4440EBE0606F62824C40
34818	1	5	1019	47162	67299	\N	57.172922999999997	с.Никулино, ул.Центральная, д.6		0101000020E61000002CB7B41A12494440F4DC425722964C40
34767	1	5	1019	46068	\N	\N	57.162712999999997	деревня Михеево, 15		0101000020E61000002EE57CB1F74C444028D192C7D3944C40
34758	1	5	1019	54084	33982	\N	57.020667000000003	село Марково, ул.Центральная, 10	Россия, Ивановская область, Комсомольский район, поселок Марково	0101000020E6100000BC5AEECC043F4440A08D5C37A5824C40
34757	1	5	1019	24523	34105	\N	57.028480999999999	город Комсомольск, ул.Первомайская, 15		0101000020E6100000390B7BDAE12F444058C7F143A5834C40
34754	1	5	1019	24523	33974	\N	57.031146443773601	город Комсомольск, ул.Колганова, 19	Россия, Ивановская область, Комсомольский район, Комсомольск	0101000020E6100000AE8383BD892F44405BB39597FC834C40
95175	1	5	7296	54071	33906	\N	57.4568925788939	Ивановская область, городской округ Кинешма , ул. 50 летия Комсомола, д.27	Россия, Ивановская область, Кинешма городской округ	0101000020E61000000EDC813AE50F4540BB6246787BBA4C40
34737	1	5	1639	23654	34423	\N	57.180484999999997	Ивановская область, Кинешемский муниципальный район, деревня Шумовская, улица Новая, дом 1		0101000020E610000010E6762FF73745409335EA211A974C40
34738	1	5	1639	23720	34318	\N	57.177787000000002	Ивановская область, Кинешемский муниципальный район, село Шилекша, улица Центральная, дом 37		0101000020E61000002315C61682444540B55373B9C1964C40
34742	1	5	1639	23878	\N	\N	57.435065000000002	Ивановская область, Кинешемский муниципальный район, деревня Стиберское, дом 15-А		0101000020E61000005B9A5B21AC6045402F51BD35B0B74C40
34673	1	5	1639	20655	\N	\N	57.452424000000001	"""Ивановская область, Кинешемский муниципальный район, село Станко, здание дет. Сада"	Россия, Ивановская область, Кинешемский район, поселок Станко	0101000020E6100000A6D425E318F7444077F69507E9B94C40
34744	1	5	1639	24012	34252	\N	57.406751999999997	Ивановская область, Кинешемский муниципальный район, село Решма, улица Ленина, дом 12		0101000020E6100000DCD440F33947454092CA147310B44C40
34747	1	5	1639	24135	34103	\N	57.481969999999997	Ивановская область, Кинешемский муниципальный район, село Первомайский, улица Садовая, дом 4		0101000020E610000040D9942BBC09454099D36531B1BD4C40
34748	1	5	1639	20632	33944	\N	57.468119999999999	Ивановская область, Кинешемский муниципальный район, город Наволоки, улица Юбилейная, дом 18		0101000020E6100000874D64E602FB4440404D2D5BEBBB4C40
34672	1	5	1639	20632	33927	\N	57.462073665535797	Ивановская область, Кинешемский муниципальный район, город Наволоки, ул. Энгельса д.25	Россия, Ивановская область, Кинешемский район, Наволоки	0101000020E6100000B5DFDA8992FA44407C2AA73D25BB4C40
34750	1	5	1639	20632	34037	\N	57.468119999999999	Ивановская область, Кинешемский муниципальный район, город Наволоки, улица Ульянова, дом 6-А		0101000020E6100000874D64E602FB4440404D2D5BEBBB4C40
34749	1	5	1639	20632	34037	\N	57.468119999999999	Ивановская область, Кинешемский муниципальный район, город Наволоки, улица Ульянова, дом 6		0101000020E6100000874D64E602FB4440404D2D5BEBBB4C40
34752	1	5	1639	20632	34069	\N	57.468119999999999	Ивановская область, Кинешемский муниципальный район, город Наволоки, улица Спортивная, дом 23		0101000020E6100000874D64E602FB4440404D2D5BEBBB4C40
34743	1	5	1639	23960	34068	\N	57.419849999999997	Ивановская область, Кинешемский муниципальный район, деревня Луговое, улица Школьная, дом 15		0101000020E6100000D7F6764B721C4540E09C11A5BDB54C40
34735	1	5	1639	23592	34317	\N	57.218971000000003	Ивановская область, Кинешемский муниципальный район, деревня Лагуниха, улица Торговая, дом 8		0101000020E61000001B13622EA9244540DFE2E13D079C4C40
34741	1	5	1639	23842	34350	\N	57.512414999999997	Ивановская область, Кинешемский муниципальный район, село Красногорский, улица Красногорская, дом 12		0101000020E6100000E5F1B4FCC06945406B7D91D096C14C40
34740	1	5	1639	23794	34404	\N	57.434972999999999	Ивановская область, Кинешемский муниципальный район, село Ильинское, улица Школьная, дом 2		0101000020E61000004AB3791C064D45404ED2FC31ADB74C40
34739	1	5	1639	23763	34319	\N	57.200974000000002	Ивановская область, Кинешемский муниципальный район, село Зобнино, улица Совхозная, дом 10		0101000020E6100000849F38807E4D454054AC1A84B9994C40
34734	1	5	1639	23512	34366	\N	57.297538000000003	Ивановская область, Кинешемский муниципальный район, деревня Закусихино, улица Фабричная, дом 5		0101000020E61000008A01124DA03045409CA8A5B915A64C40
34746	1	5	1639	24106	34337	\N	57.257289	Ивановская область, Кинешемский муниципальный район, село Журихино, улица Урожайная, дом 7		0101000020E6100000A0A696ADF54345406E4F90D8EEA04C40
34745	1	5	1639	24030	33911	\N	57.408827000000002	"Ивановская область, Кинешемский муниципальный район, деревня Дьячево, микрорайон санатория ""Решма"", дом 11"	Россия, Ивановская область, Кинешемский район, поселок Дьячево	0101000020E61000002F4FE78A523C4540645C717154B44C40
34736	1	5	1639	23648	34251	\N	57.36956	Ивановская область, Кинешемский муниципальный район, деревня Горки, улица Завражная, дом 52		0101000020E6100000F6B6990AF10E454073F4F8BD4DAF4C40
34733	1	5	1639	23485	34349	\N	57.263393999999998	Ивановская область, Кинешемский муниципальный район, деревня Горки Большие, улица Большегорковская, дом 4		0101000020E6100000D097DEFE5C1E454037FB03E5B6A14C40
34732	1	5	1639	23438	34363	\N	57.263953000000001	Ивановская область, Кинешемский муниципальный район, село Батманы, улица Центральная, дом 4		0101000020E61000007E350708E62645402E573F36C9A14C40
34730	1	5	234	23341	34380	\N	56.857838999999998	деревня Щенниково, улица Советская, дом 2		0101000020E61000009F758D9603CD4340DE1D19ABCD6D4C40
14672	1	5	234	48915	34242	\N	56.940117999999998	п.Савино, Малиновского, 20		0101000020E610000086032159C0104440C23060C955784C40
34649	1	5	234	48337	\N	\N	56.950972999999998	с. Новосёлка, здвние Дома культуры		0101000020E6100000AEEFC34142FC43408330B77BB9794C40
34760	1	5	234	45935	\N	\N	56.842689	село Никольское, 84		0101000020E6100000C11A67D311DE434077D9AF3BDD6B4C40
34729	1	5	234	23272	34361	\N	57.112938999999997	село Нажерово, улица Советская, дом 22		0101000020E61000006CE8667FA0F64340B2B8FFC8748E4C40
34727	1	5	234	49565	34320	\N	56.977192000000002	село Кулачево, улица Школьная, дом 21		0101000020E61000008C2B2E8ECAD34340D8F4A0A0147D4C40
34722	1	5	234	23001	34381	\N	56.981836999999999	село Коварчино ул. Советская д.24		0101000020E610000020425C397B0744405A80B6D5AC7D4C40
34726	1	5	234	49555	34333	\N	57.014007999999997	село Исаевское, Советская улица, дом 26		0101000020E610000057EC2FBB27D94340F1F09E03CB814C40
34718	1	5	234	22722	34348	\N	56.972771999999999	поселок Ильинское-Хованское, улица Школьная, дом 10		0101000020E6100000451152B7B3E14340753BFBCA837C4C40
34716	1	5	234	22722	34096	\N	56.972771999999999	поселок Ильинское-Хованское, улица Советская, дом 44		0101000020E6100000451152B7B3E14340753BFBCA837C4C40
94315	1	5	234	22722	34079	\N	56.972771999999999	поселок Ильинское-Хованское, улица Революционная, дом 7		0101000020E6100000451152B7B3E14340753BFBCA837C4C40
34910	1	5	234	48873	74886	\N	56.922845000000002	с.Воскресенское, Советская, 16		0101000020E61000002810768A55F143407923F3C81F764C40
34720	1	5	234	22918	34228	\N	56.938881000000002	с. Аньково, улица Строительная, дом 3		0101000020E61000002B357BA015FA4340FBEAAA402D784C40
94316	1	5	234	22918	34276	\N	56.938881000000002	село Аньково, улица Полевая, дом 23А		0101000020E61000002B357BA015FA4340FBEAAA402D784C40
30121	1	4	\N	19	36271	\N	51.704749999999997	г.Воронеж, ул. Хользунова, 40		0101000020E6100000CEDF84420498434091ED7C3F35DA4940
34681	1	5	1299	54082	33965	\N	57.045300072446103	153506 Ивановская обл., Ивановский муниципальный район, Богородское сельское поселение, с. Богородское ул. Парковская д.58	Россия, Ивановская область	0101000020E6100000C748F608358144402041F163CC854C40
34537	1	5	1299	54098	34119	\N	56.951031999999998	Ивановская область, городской округ Кохма, ул. Ивановская, д. 19		0101000020E6100000DFE2E13D0792444088B9A46ABB794C40
34715	1	5	1299	49352	34214	\N	56.975985000000001	с. Черноречинский ул. Победы д.1 А	Россия, Ивановская область, Ивановский район, поселок Чернореченский	0101000020E6100000069E7B0F976E44407B319413ED7C4C40
34809	1	5	1299	46985	34526	\N	56.911017999999999	д.Теплово, Зеленая, 45		0101000020E610000067D13B15709944409E08E23C9C744C40
34635	1	5	1299	18584	\N	\N	56.866110999999997	с. Стромихино, д. 36, кв.6		0101000020E610000033A9A10DC088444059DAA9B9DC6E4C40
34679	1	5	1299	54117	\N	\N	57.006928513933701	д. Светлый Луч, д. 20, кв. 7	Россия, Ивановская область	0101000020E6100000959BA8A5B98744406E32AA0CE3804C40
34708	1	5	1299	22262	\N	\N	56.967982999999997	с. Подвязновский (здание администрации Подвязновского с/п)  д.25		0101000020E6100000BBF1EEC8588F4440BF0AF0DDE67B4C40
34688	1	5	1299	21400	\N	\N	56.887417999999997	с. Панеево, д. 52		0101000020E61000007590D78349734440DCF0BBE996714C40
34705	1	5	1299	49204	34240	\N	57.156871000000002	с. Озерный ул. Школьная 8		0101000020E61000004C8DD0CFD47D44406D58535914944C40
34697	1	5	1299	54099	34204	\N	57.009318	с. Ново-Талицы, ул. Школьная, д. 20		0101000020E610000030664B56456C4440CFA10C5531814C40
34693	1	5	1299	54099	34122	\N	57.008463492694901	с. Ново-Талицы, ул. Радужная 5	Россия, Ивановская область, Ивановский район, поселок Новоталицы	0101000020E6100000EB724A404C6C4440EF1CCA5015814C40
34695	1	5	1299	54099	34212	\N	57.009318	с. Ново-Талицы, ул. Радужная, д. 5	Россия, Ивановская область, Ивановский район, поселок Новоталицы	0101000020E610000030664B56456C4440CFA10C5531814C40
34696	1	5	1299	54099	34220	\N	57.008970838752298	с. Ново-Талицы, ул. Новинская, д. 2	Россия, Ивановская область, Ивановский район, поселок Новоталицы	0101000020E6100000399B8E006E6C444064CE33F625814C40
34704	1	5	1299	54099	34379	\N	57.009318	с. Ново-Талицы, ул. 2 Шиймановская 6	Россия, Ивановская область, Ивановский район, поселок Новоталицы	0101000020E610000030664B56456C4440CFA10C5531814C40
34699	1	5	1299	54099	34434	\N	57.008872425027597	с. Ново-Талицы, ул. 1-я Яковлевская, д. 29	Россия, Ивановская область, Ивановский район, поселок Новоталицы	0101000020E6100000EE42739D466C4440D0ECBAB722814C40
34700	1	5	1299	54102	\N	\N	56.990833205908402	с. Михалево, д. 25	Россия, Ивановская область, Ивановский район, поселок Михалево	0101000020E6100000996725ADF86444401766A19DD37E4C40
34689	1	5	1299	49037	\N	\N	56.997598000000004	д. Куликово, д. 60		0101000020E6100000C362D4B5F69A44400B47904AB17F4C40
34677	1	5	1299	20887	34272	\N	56.921729999999997	д. Кочорский, ул. Спортивная, д. 13		0101000020E61000005C72DC291D8A4440FCDEA63FFB754C40
34691	1	5	1299	21532	34422	\N	57.038263000000001	с. Котцыно, ул. Школьная, д. 18		0101000020E6100000C959D8D30E9B4440CCD24ECDE5844C40
34714	1	5	1299	22441	34364	\N	57.043889	с. Колбацкое, ул. Троицкая д.26 А		0101000020E6100000126A865451B44440BBD39D279E854C40
34690	1	5	1299	49040	\N	\N	57.000216000000002	д. Кожевниково, д. 12	Россия, Ивановская область, Ивановский район, поселок Кожевниково	0101000020E6100000454772F90FA74440CD77F01307804C40
34692	1	5	1299	49087	\N	\N	57.06438	с. Калачево, д. 41		0101000020E6100000E2E47E87A29A44401C42959A3D884C40
34698	1	5	1299	49170	34405	\N	57.022514000000001	д. Залесье, ул. Запрудная, д. 10		0101000020E610000060AE450BD0604440E0D91EBDE1824C40
34713	1	5	1299	54114	34305	\N	57.095092627429104	дер. Железнодорожной станции Ермолино ул. Колхозная д.30	Россия, Ивановская область, Ивановский район, поселок Ермолино	0101000020E61000005C035B2558A044400D8AE6012C8C4C40
34686	1	5	1299	21306	\N	\N	56.922693000000002	153 Ивановская обл, Ивановский муниципальный район,  Коляновское сельское поселение, д.Дегтярево, д.64		0101000020E61000009BFF571D39744440C39FE1CD1A764C40
34684	1	5	1299	21239	34387	\N	57.063724999999998	153506 Ивановская обл., Ивановский муниципальный район, Богородское сельское поселение, д. Бяково , ул. Озерная д.6А	Россия, Ивановская область, Ивановский район, поселок Бяково	0101000020E61000006F2C280CCA88444003780B2428884C40
34674	1	5	1299	48779	34334	\N	57.065178000000003	с. Буньково, ул. Лесная, д. 16		0101000020E6100000272F3201BF5A44409835B1C057884C40
30212	1	5	1299	47035	\N	\N	56.916659000000003	д. Богданиха, д. 93		0101000020E610000058CA32C4B1904440C34A051555754C40
34703	1	5	1299	49239	34236	\N	57.138047	с. Бибирево, ул. Садовая, д. 4		0101000020E610000029D027F224854440CC272B86AB914C40
34671	1	5	1299	20565	34401	\N	57.092782999999997	д. Балахонки, ул. Центральная, д. 41		0101000020E610000085EAE6E26F614440F84F3750E08B4C40
34662	1	5	1597	19994	34315	\N	57.455015000000003	Ивановская область, Заволжский муниципальный район, Волжское сельское поселение, с. Новлянское, Центральная, 27		0101000020E6100000E3DD91B1DADC4440401878EE3DBA4C40
34664	1	5	1597	20085	34259	\N	57.455362999999998	Ивановская область, Заволжский муниципальный район, Междуреченское сельское поселение, д. Коротиха, Центральная, 6		0101000020E6100000F9BB77D4981C45407B67B45549BA4C40
34663	1	5	1597	20085	34259	\N	57.455362999999998	Ивановская область, Заволжский муниципальный район, Междуреченское сельское поселение, д. Коротиха, Центральная, 3		0101000020E6100000F9BB77D4981C45407B67B45549BA4C40
34668	1	5	1597	20383	34316	\N	57.580145000000002	Ивановская область, Заволжский муниципальный район, Дмитриевское сельское поселение, д. Корнилово, Зеленая, 14		0101000020E61000000647C9AB73F244400EF8FC3042CA4C40
34666	1	5	1597	20265	34418	\N	57.676817	Ивановская область, Заволжский муниципальный район, Дмитриевское сельское поселение, с. Колшево, Школьная, 12		0101000020E6100000505436ACA9D444403C3080F0A1D64C40
34665	1	5	1597	20173	34275	\N	57.467785999999997	Ивановская область, Заволжский муниципальный район, Междуреченское сельское поселение, с. Заречный, Фабричная, 18		0101000020E610000018B325AB2224454069C36169E0BB4C40
34657	1	5	1597	19473	33978	\N	57.4780040132216	Ивановская область, Заволжский муниципальный район, Заволжское городское поселение, г. Заволжск, Школьная, 1	Россия, Ивановская область, Заволжский район, Заволжск	0101000020E6100000C6E061DA37134540B8AD2D3C2FBD4C40
34653	1	5	1597	19473	33910	\N	57.476741573549603	Ивановская область, Заволжский муниципальный район, Заволжское городское поселение, г. Заволжск, Мира, 20	Россия, Ивановская область, Заволжский район, Заволжск	0101000020E61000007BF5F1D0771345409850C1E105BD4C40
34652	1	5	1597	19473	33910	\N	57.478301999999999	Ивановская область, Заволжский муниципальный район, Заволжское городское поселение, г. Заволжск, Мира, 5		0101000020E610000078094E7D2013454042CEFBFF38BD4C40
94414	1	5	1597	20468	34287	\N	57.458069999999999	Ивановская область, Заволжский муниципальный район, Дмитриевское сельское поселение, с. Жажлево, Школная, 10		0101000020E61000008ACBF10A44354540ADA3AA09A2BA4C40
34660	1	5	1597	19892	34213	\N	57.531308000000003	Ивановская область, Заволжский муниципальный район, Волжское сельское поселение, с. Есиплево, Административная, 1		0101000020E6100000C426327381EB4440350D8AE601C44C40
94415	1	5	1597	20494	\N	\N	57.500675000000001	"""Ивановская область, Заволжский муниципальный район, Сосневское сельское поселение, с. Долматовский, здание начальной школы"		0101000020E6100000124BCADDE72A454060764F1E16C04C40
34661	1	5	1597	19962	34400	\N	57.474862000000002	Ивановская область, Заволжский муниципальный район, Волжское сельское поселение, д. Гольцовка, Центральная, 19		0101000020E6100000F33CB83B6BF344407C0E2C47C8BC4C40
34659	1	5	1597	19866	34239	\N	57.498997000000003	Ивановская область, Заволжский муниципальный район, Волжское сельское поселение, с. Воздвиженье, Центральная, 13		0101000020E6100000C45F9335EA014540ACE63922DFBF4C40
34641	1	5	1548	18913	34377	\N	56.527569999999997	с. Шекшово, ул. Конец, д.7		0101000020E61000009605137F14174440E42CEC6987434C40
34646	1	5	1548	19163	\N	\N	56.608293000000003	с. Скомово, здание Дома культуры	Россия, Ивановская область, Гаврилово-Посадский район, поселок Скомово	0101000020E6100000C11DA8531EEF434060B1868BDC4D4C40
34644	1	5	1548	19071	\N	\N	56.516660999999999	с. Ратницкое, Здание школы	Россия, Ивановская область, Гаврилово-Посадский район, поселок Ратницкое	0101000020E610000099805F2349204440300F99F221424C40
94313	1	5	1548	45589	34149	\N	56.64199	п. Петровский, ул. Чкалова, д.2		0101000020E61000001B683EE76E274440F52D73BA2C524C40
34645	1	5	1548	19130	\N	\N	56.562306	с. Осановец, Здание администрации сельского поселения		0101000020E6100000E621533E04FD43401B2C9CA4F9474C40
34642	1	5	1548	60367	74887	\N	56.474941425277699	с. Непотягово, ул. Старая, д. 22А	Россия, Ивановская область, Гаврилово-Посадский район, поселок Непотягово	0101000020E6100000FC36C478CD114440C843DFDDCA3C4C40
34640	1	5	1548	18851	\N	\N	56.752372999999999	с. Лобцово, здание Дома культуры	Россия, Ивановская область, Гаврилово-Посадский район, поселок Лобцово	0101000020E6100000B6847CD0B30B44405BB22AC24D604C40
34637	1	5	1548	60466	75051	\N	56.5966602179844	с. Липовая Роща, пл. 70 лет Октября, д.7	Россия, Ивановская область, Гаврилово-Посадский район	0101000020E6100000F0C16B97360C44406A6AD95A5F4C4C40
34651	1	5	1548	48376	\N	\N	56.676948000000003	с. Иваньковский, здание Дома культуры	Россия, Ивановская область, Гаврилово-Посадский район, поселок Иваньковский	0101000020E6100000D15790662C0E4440DB8B683BA6564C40
34647	1	5	1548	48303	\N	\N	56.504094000000002	с. Загорье, Здание ФАП	Россия, Ивановская область, Гаврилово-Посадский район, поселок Загорье	0101000020E61000006B6281AFE8FA43400F0EF62686404C40
34634	1	5	1548	18475	33989	\N	56.559722000000001	г. Гаврилов Посад, пос. 9 Января, д.23		0101000020E61000005C3AE63C630F4440056D72F8A4474C40
34633	1	5	1548	18475	34095	\N	56.559722000000001	г. Гаврилов Посад, пл. Советская, д.9		0101000020E61000005C3AE63C630F4440056D72F8A4474C40
34636	1	5	1548	18475	33939	\N	56.559722000000001	г. Гаврилов Посад, ул. Советская, д. 16		0101000020E61000005C3AE63C630F4440056D72F8A4474C40
34643	1	5	1548	48212	\N	\N	56.551675000000003	с. Бородино, Здание  школы	Россия, Ивановская область, Гаврилово-Посадский район, поселок Бородино	0101000020E6100000069FE6E445204440AA8251499D464C40
34650	1	5	1548	48361	\N	\N	56.654600000000002	с. Бережок, здание Дома культуры	Россия, Ивановская область, Гаврилово-Посадский район, поселок Бережок	0101000020E61000005070B1A206F7434016FBCBEEC9534C40
34630	1	5	1515	18334	33956	\N	57.300528	д. Чертовищи, Парковая, 2		0101000020E6100000B9FB1C1F2DF0444022C495B377A64C40
34623	1	5	1515	17870	34171	\N	57.271234	п.Старая Вичуга, Школьная, 2		0101000020E6100000B66455849BF0444019C8B3CBB7A24C40
34622	1	5	1515	17870	33970	\N	57.271234	п. Старая Вичуга, Советская, 6		0101000020E6100000B66455849BF0444019C8B3CBB7A24C40
34621	1	5	1515	17870	34094	\N	57.271234	п. Старая Вичуга, Клубная, 7		0101000020E6100000B66455849BF0444019C8B3CBB7A24C40
34627	1	5	1515	47896	34289	\N	57.231318000000002	д. Сошники, 1 Школьная, 4		0101000020E610000092955F0663004540F27C06D49B9D4C40
94318	1	5	1515	46779	34481	\N	57.123798999999998	д.Сорокино Центральная 3	Россия, Ивановская область, Вичугский район, поселок Сорокино	0101000020E610000014ECBFCE4D074540852348A5D88F4C40
34632	1	5	1515	18356	\N	\N	57.388579999999997	д. Семигорье, 109		0101000020E6100000DE02098A1FE9444099F04BFDBCB14C40
34631	1	5	1515	18356	\N	\N	57.388579999999997	д. Семигорье, 111		0101000020E6100000DE02098A1FE9444099F04BFDBCB14C40
34628	1	5	1515	40307	\N	\N	57.1937919321633	с. Семеновское, 44	Россия, Ивановская область, Вичугский район, поселок Семеновское	0101000020E61000006FB9FAB1491A4540FC1C1F2DCE984C40
34808	1	5	1515	46959	\N	\N	57.362462999999998	д.Раменье, здание администрации Раменского сельского поселения, 24	Россия, Ивановская область, Вичугский район, поселок Раменье	0101000020E6100000D9CF622992D144404981053065AE4C40
34629	1	5	1515	47945	\N	\N	57.148111999999998	с. Раздолье, 9		0101000020E610000012DE1E84800A454094128255F5924C40
30103	1	4	\N	19	36271	\N	51.702406000000003	г.Воронеж, ул.Хользунова, 106		0101000020E610000037A79201A0924340D1419770E8D94940
34913	1	5	1515	48930	67300	\N	57.135942	д.Панино, Центральная, 22	Россия, Ивановская область, Вичугский район, поселок Панино	0101000020E61000005001309E41F544409013268C66914C40
34620	1	5	1515	17769	34038	\N	57.322029000000001	п.Новописцово, пер.Почтовый, 5		0101000020E61000008D0DDDEC0FEC44408AAE0B3F38A94C40
34619	1	5	1515	17769	34067	\N	57.322029000000001	п.Новописцово, Аптечная, 11		0101000020E61000008D0DDDEC0FEC44408AAE0B3F38A94C40
30725	1	5	1515	48049	34487	\N	57.166905999999997	д. Малышево, Центральная, 11		0101000020E6100000E23C9CC0741A4540CAC0012D5D954C40
34626	1	5	1515	47887	\N	\N	57.186191999999998	с Красный Октябрь, 7		0101000020E61000001FD7868A71EE44406F63B323D5974C40
34618	1	5	1515	47723	33909	\N	57.386008151643999	п.Каменка, Николаева, 4	Россия, Ивановская область, Вичугский район, поселок Каменка	0101000020E6100000FD2D01F8A7E6444047FFCBB568B14C40
34617	1	5	1515	47723	34036	\N	57.391033999999998	п. Каменка, 1 Мая, 11		0101000020E61000004E8061F9F3E54440E1CFF0660DB24C40
34728	1	5	1515	49584	34241	\N	57.312376	село Ивашево, улица Совхозная, дом 2		0101000020E6100000EBABAB02B5E244401407D0EFFBA74C40
34624	1	5	1515	47843	\N	\N	57.321465000000003	с.Золотилово, 66		0101000020E6100000F984ECBC8DD1444082E7DEC325A94C40
34815	1	5	1515	47076	34356	\N	57.275181000000003	с.Демидово, ул.Клубная, д.12		0101000020E610000076A565A4DEED444084BD892139A34C40
34719	1	5	1515	49446	67312	\N	57.291564999999999	село Гари, улица Школьная, дом 13		0101000020E6100000F25CDF8783D2444041D47D0052A54C40
34625	1	5	1515	47866	\N	\N	57.255862999999998	д.Гаврилково, 108		0101000020E6100000899AE8F351DA4440D3A0681EC0A04C40
94312	1	5	1222	45582	34360	\N	56.876382	д.Симаково, ул.Советская, д.24		0101000020E610000034BDC458A6614540CB660E492D704C40
34062	1	5	1222	12285	34331	\N	56.814818000000002	с.Мыт, ул.Торговая, д.9		0101000020E6100000BF0E9C33A22845409818CBF44B684C40
33845	1	5	1222	12285	34362	\N	56.814818000000002	с.Мыт, ул.Восточная, д.42		0101000020E6100000BF0E9C33A22845409818CBF44B684C40
34465	1	5	1222	49118	34332	\N	56.880696	с.Кромы, ул.Черемушки, д.15		0101000020E61000000BD3F71A82414540E8DB82A5BA704C40
30562	1	5	1222	49215	\N	\N	56.884369	деревня Иваньково, 46		0101000020E6100000199128B4AC274540514CDE0033714C40
34616	1	5	1222	47705	34419	\N	56.840567	д.Засека, ул.Школьная, д.33		0101000020E610000011C8258E3C664540658C0FB3976B4C40
34614	1	5	1222	17545	34230	\N	56.838532999999998	п.Верхний Ландех, пер.Школьный, д.1		0101000020E6100000333674B33F4C4540F2CEA10C556B4C40
34598	1	5	1222	47364	34359	\N	56.904845999999999	д.Бараново, ул.Колхозная, д.13		0101000020E610000004AF963B335145404DF564FED1734C40
31220	1	4	\N	60404	74968	\N	51.535118020390698	с.Новогремяченское, ул.Чапаева, д.12	Россия, Воронежская область	0101000020E61000009FC893A46B8643401EC022BF7EC44940
31264	1	4	\N	54257	36555	\N	51.847067000000003	г. Эртиль, пл.Ленина, д.8		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31266	1	4	\N	54257	36113	\N	51.847067000000003	г.Эртиль, ул.Труда, д.7		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31263	1	4	\N	54257	36013	\N	51.847067000000003	г.Эртиль, ул.Советская, д.2		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31273	1	4	\N	54257	36618	\N	51.847067000000003	г.Эртиль, ул.Лермонтова, д.20		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31276	1	4	\N	54257	35774	\N	51.847067000000003	г.Эртиль, ул.Горная, д.12		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31082	1	4	\N	54284	36217	\N	51.693087397999797	городское поселение - город Семилуки, Гагарина, 27	Россия, Воронежская область	0101000020E610000078280AF48982434031242713B7D84940
31083	1	4	\N	54284	36272	\N	51.6943306028489	городское поселение - город Семилуки, Чапаева, 62	Россия, Воронежская область	0101000020E6100000663387A416824340ABCC94D6DFD84940
31076	1	4	\N	54284	36331	\N	51.689522304995698	городское поселение - город Семилуки, Чайковского, 3	Россия, Воронежская область	0101000020E610000007793D9814834340AEEFC34142D84940
31084	1	4	\N	54284	36332	\N	51.692454478633401	городское поселение - город Семилуки, Транспортная, 16	Россия, Воронежская область	0101000020E610000043C5387F1382434000FE2955A2D84940
31080	1	4	\N	54284	36118	\N	51.6904844015612	городское поселение - город Семилуки, пер.Крупской, 3	Россия, Воронежская область	0101000020E61000009E25C808A8824340A4349BC761D84940
31081	1	4	\N	54284	36301	\N	51.697398305915101	городское поселение - город Семилуки, Дзержинского, 10	Россия, Воронежская область	0101000020E61000004F05DCF3FC814340DD25715644D94940
31078	1	4	\N	54284	36672	\N	51.691807172637397	городское поселение - город Семилуки, Башкирцева переулок, 8	Россия, Воронежская область	0101000020E610000057B439CE6D8243406A12BC218DD84940
31114	1	4	\N	54284	36233	\N	51.690268728679897	с.Семилуки, ул.8 Марта, д.34	Россия, Воронежская область	0101000020E6100000D53DB2B96A824340A8380EBC5AD84940
31086	1	4	\N	54284	36232	\N	51.692834022952503	городское поселение - город Семилуки, 25 Лет Октября, 132а	Россия, Воронежская область	0101000020E6100000E7A8A3E36A84434047C7D5C8AED84940
31079	1	4	\N	54284	36232	\N	51.6997946505047	городское поселение - город Семилуки, 25 лет Октября, 26	Россия, Воронежская область	0101000020E6100000C7BDF90D13834340C173EFE192D94940
31018	1	4	\N	2019	36010	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, проспект Труда, 14		0101000020E6100000C76471FF91C94340BD73284355184940
31017	1	4	\N	2019	36010	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, проспект Труда, 20		0101000020E6100000C76471FF91C94340BD73284355184940
31011	1	4	\N	2019	35869	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Пролетарская, 67	Россия, Воронежская область, Россошь	0101000020E6100000C76471FF91C94340BD73284355184940
31075	1	4	\N	2019	36956	\N	50.190102000000003	Воронежская область, Россошанский муниципальный район, город Россошь, площадь Танкистов, 5С		0101000020E6100000C76471FF91C94340BD73284355184940
31014	1	4	\N	2019	35810	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, переулок Школьный, 3		0101000020E6100000C76471FF91C94340BD73284355184940
31021	1	4	\N	2019	35935	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Луговая, 1	Россия, Воронежская область, Россошь	0101000020E6100000C76471FF91C94340BD73284355184940
31023	1	4	\N	2019	35761	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Элеваторная, 2		0101000020E6100000C76471FF91C94340BD73284355184940
30993	1	4	\N	2019	36635	\N	50.190102000000003	с.Россошь, ул.Центральная, д.31 (здание администрации с/посел)		0101000020E6100000C76471FF91C94340BD73284355184940
31016	1	4	\N	2019	36175	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Фурманова, 6А/1		0101000020E6100000C76471FF91C94340BD73284355184940
31007	1	4	\N	2019	36008	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Урицкого, 14		0101000020E6100000C76471FF91C94340BD73284355184940
31031	1	4	\N	2019	35977	\N	50.190102000000003	Воронежская область, Россошанский муниципальный район, город Россошь, Толбухина, 43		0101000020E6100000C76471FF91C94340BD73284355184940
31025	1	4	\N	2019	36107	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Свердлова, 47		0101000020E6100000C76471FF91C94340BD73284355184940
31032	1	4	\N	2019	36171	\N	50.190102000000003	Воронежская область, Россошанский муниципальный район, город Россошь, Розы Люксембург, 151	Россия, Воронежская область, Россошь	0101000020E6100000C76471FF91C94340BD73284355184940
31015	1	4	\N	2019	35934	\N	50.196325746838902	Воронежская область, Россошанский район, город Россошь, Простеева, 5	Россия, Воронежская область, Россошь городской округ	0101000020E61000008FA7E507AECA434060ADDA3521194940
31022	1	4	\N	2019	35822	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Пролетарская, 146		0101000020E6100000C76471FF91C94340BD73284355184940
31019	1	4	\N	2019	35822	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Пролетарская, 113		0101000020E6100000C76471FF91C94340BD73284355184940
31013	1	4	\N	2019	35822	\N	50.193818765496999	Воронежская область, Россошанский район, город Россошь, Пролетарская, 87А	Россия, Воронежская область, Россошь	0101000020E6100000A2EC2DE57CC94340F52B9D0FCF184940
31012	1	4	\N	2019	35822	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Пролетарская, 73		0101000020E6100000C76471FF91C94340BD73284355184940
31010	1	4	\N	2019	35822	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Пролетарская, 61		0101000020E6100000C76471FF91C94340BD73284355184940
31009	1	4	\N	2019	35822	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Пролетарская, 13		0101000020E6100000C76471FF91C94340BD73284355184940
31006	1	4	\N	2019	35812	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Пески, 2	Россия, Воронежская область, Россошь	0101000020E6100000C76471FF91C94340BD73284355184940
31005	1	4	\N	2019	35786	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Октябрьская, 152		0101000020E6100000C76471FF91C94340BD73284355184940
31028	1	4	\N	2019	35768	\N	50.190102000000003	Воронежская область, Россошанский муниципальный район, город Россошь, Маршака, 61		0101000020E6100000C76471FF91C94340BD73284355184940
31008	1	4	\N	2019	36023	\N	50.204754845129898	Воронежская область, Россошанский муниципальный район, город Россошь, Ленина, 2	Россия, Воронежская область, Россошь городской округ	0101000020E6100000C74961DEE3C44340A3586E69351A4940
31024	1	4	\N	2019	35811	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Крупской, 66		0101000020E6100000C76471FF91C94340BD73284355184940
31029	1	4	\N	2019	36108	\N	50.190102000000003	Воронежская область, Россошанский муниципальный район, город Россошь, Заводская, 19		0101000020E6100000C76471FF91C94340BD73284355184940
31026	1	4	\N	2019	35890	\N	50.190102000000003	Воронежская область, Россошанский район, город Россошь, Дзержинского, 66		0101000020E6100000C76471FF91C94340BD73284355184940
31030	1	4	\N	2019	35793	\N	50.190102000000003	Воронежская область, Россошанский муниципальный район, город Россошь, Деповская, 10		0101000020E6100000C76471FF91C94340BD73284355184940
31020	1	4	\N	2019	35940	\N	50.195430411554	Воронежская область, Россошанский район, город Россошь, Белинского, 20	Россия, Воронежская область, Россошь городской округ	0101000020E6100000BB438A0112C943402254A9D903194940
30905	1	4	\N	54278	36088	\N	51.186301999999998	г.Поворино, ул.Советская, д.33		0101000020E6100000274EEE7728204540F69672BED8974940
30907	1	4	\N	54278	36001	\N	51.186301999999998	г.Поворино, ул.Садовая, д.14		0101000020E6100000274EEE7728204540F69672BED8974940
30908	1	4	\N	54278	36003	\N	51.186301999999998	г.Поворино, ул.Народная, д.64		0101000020E6100000274EEE7728204540F69672BED8974940
30906	1	4	\N	54278	36077	\N	51.186301999999998	г.Поворино, ул.Линейная, д.23		0101000020E6100000274EEE7728204540F69672BED8974940
30798	1	4	\N	54255	36089	\N	50.455176606475298	г.Павловск, просп.Революции, 102		0101000020E61000002A560DC2DC0E444019726C3D433A4940
30799	1	4	\N	54255	36184	\N	50.449730000000002	г.Павловск, м/р-н Гранитный, 9		0101000020E61000008463963D09104440DA03ADC090394940
30797	1	4	\N	54255	35746	\N	50.449730000000002	г.Павловск, Ю.Фучика, 13		0101000020E61000008463963D09104440DA03ADC090394940
30793	1	4	\N	54255	36102	\N	50.449730000000002	г.Павловск, Покровская, 9		0101000020E61000008463963D09104440DA03ADC090394940
30792	1	4	\N	54255	35939	\N	50.449730000000002	г.Павловск, К.Готвальда, 25		0101000020E61000008463963D09104440DA03ADC090394940
30741	1	4	\N	54258	36071	\N	50.858927999999999	г.Острогожск, Энгельса, 60		0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30745	1	4	\N	54258	35944	\N	50.858314312438402	г.Острогожск, Комсомольская, 71		0101000020E61000004EB6813B5089434077D9AF3BDD6D4940
30747	1	4	\N	54258	35785	\N	50.858927999999999	г.Острогожск, Карла Маркса, 67		0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30743	1	4	\N	54258	35785	\N	50.858927999999999	г.Острогожск, Карла Маркса, 31		0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30753	1	4	\N	54258	36047	\N	50.8472306307902	г.Острогожск, 50 лет Октября, 153	Россия, Воронежская область, Острогожский район, Острогожск	0101000020E61000007D5EF1D4238543402594BE10726C4940
30752	1	4	\N	54258	36047	\N	50.854117494500002	г.Острогожск, 50 лет Октября, 103	Россия, Воронежская область, Острогожский район, Острогожск	0101000020E61000007E5182FE4287434094FAB2B4536D4940
30306	1	4	\N	19	36311	\N	51.670589999999997	г.Воронеж, ул.Фридриха Энгельса, д.23		0101000020E610000043E1B375709A43402783A3E4D5D54940
30671	1	4	\N	54270	36079	\N	51.091125840197599	г.Новохоперск, ул.Советская, д.142	Россия, Воронежская область, Новохоперский район, поселок Новохоперск	0101000020E610000001DBC1887DCC44405CE84A04AA8B4940
30672	1	4	\N	54270	35968	\N	51.094909125503698	г.Новохоперск, ул.Плотникова, д.1		0101000020E6100000EACF7EA488CE44404C8C65FA258C4940
30673	1	4	\N	54270	35999	\N	51.0866933485825	г.Новохоперск, ул.Ленина, д.42	Россия, Воронежская область, Новохоперский район, поселок Новохоперск	0101000020E610000050A912656FCD444064E597C1188B4940
30622	1	4	\N	54253	35990	\N	51.316228000000002	г.Нововоронеж, Победы, 3 А		0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30623	1	4	\N	54253	35919	\N	51.316228000000002	г.Нововоронеж, Первомайская, 1		0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30616	1	4	\N	54253	35817	\N	51.316228000000002	г.Нововоронеж, Октябрьская, 9		0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30619	1	4	\N	54253	35723	\N	51.316228000000002	г.Нововоронеж, Набережная, 14		0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30620	1	4	\N	54253	35725	\N	51.316228000000002	г.Нововоронеж, Космонавтов, 20		0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30561	1	4	\N	54281	36038	\N	50.944533367372898	с.Лиски, Советская, 100-а, сельский клуб		0101000020E61000000BED9C6681BE4340137F1475E6784940
30532	1	4	\N	54251	36094	\N	50.994197999999997	город Лиски, проспект Ленина, 47, здание ВоронежОблРемСтрой		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30527	1	4	\N	54251	36060	\N	50.994197999999997	город Лиски, площадь Революции, 10, здание филиала ВГУ		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30525	1	4	\N	54251	36092	\N	50.994197999999997	город Лиски, Энтузиастов, 9, здание начальной школы		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30517	1	4	\N	54251	35715	\N	50.994197999999997	город Лиски, Чернышевского, 19, здание школы №15		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30508	1	4	\N	54251	35897	\N	50.978757372311897	город Лиски, Советская, 29, здание школы №9	Россия, Воронежская область, Лиски городской округ	0101000020E61000000E6B2A8BC2BE434094DDCCE8477D4940
30518	1	4	\N	54251	36054	\N	50.994197999999997	город Лиски, Первомайская, 46, здание школы №11		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30513	1	4	\N	54251	35859	\N	50.994197999999997	город Лиски, Ломоносова, 44, здание школы №41		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30528	1	4	\N	54251	35717	\N	50.994197999999997	город Лиски, 40 лет Победы, 6, здание СК Восточный		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30520	1	4	\N	54251	35717	\N	50.994197999999997	город Лиски, 40 лет Победы, 62, здание СК Восточный		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30523	1	4	\N	54251	36056	\N	50.994197999999997	город Лиски, 40 лет Октября, 43а, здание МЦ Озарение		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30529	1	4	\N	54251	35719	\N	50.994197999999997	город Лиски, 19 Партсъезда, 5, здание школы №2		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30377	1	4	\N	54271	36143	\N	50.428601	г.Калач, Пугачева (ДК Чапаевское), 11		0101000020E6100000A81ABD1AA08044403604C765DC364940
30378	1	4	\N	54271	36150	\N	50.428601	г.Калач, Комсомольская (здание бывшего Калачеевского райпо), 49		0101000020E6100000A81ABD1AA08044403604C765DC364940
30371	1	4	\N	54277	36139	\N	51.440463999999999	пгт.Грибановский, ул.Советская, д.295		0101000020E6100000C367EBE060F944405D88D51F61B84940
30334	1	4	\N	54277	35984	\N	51.440463999999999	пгт.Грибановский, ул.Мебельная, д.3		0101000020E6100000C367EBE060F944405D88D51F61B84940
30076	1	4	\N	19	35889	\N	51.662495999999997	г.Воронеж, ул.Фёдора Тютчева, д.6	Россия, Воронежская область, Воронеж, Центральный район, площадь Ленина	0101000020E6100000499F56D11F9A43408BDD3EABCCD44940
30316	1	4	\N	19	45	\N	51.712322999999998	г.Воронеж, ул.Шишкова, д.105а	Россия, Воронежская область, Воронеж, улица Шишкова, 105	0101000020E6100000A99F3715A998434024986A662DDB4940
30264	1	4	\N	19	7687	\N	51.657176999999997	г.Воронеж, ул.Шендрикова, д.6	Россия, Воронежская область, Воронеж, улица Шендрикова, 4	0101000020E6100000CAC4AD82188E434079573D601ED44940
30293	1	4	\N	19	16214	\N	51.551133999999998	г.Воронеж, ул.Теплоэнергетиков, д.8а	Россия, Воронежская область, Воронеж, Шилово микрорайон, улица Теплоэнергетиков, 8	0101000020E6100000861E317A6E8B434059DB148F8BC64940
30166	1	4	\N	19	6658	\N	51.612243999999997	г.Воронеж, ул.Танеева, д.4	Россия, Воронежская область, Воронеж, улица Танеева, 4	0101000020E6100000E78C28ED0D9E43400B96EA025ECE4940
30223	1	4	\N	19	7231	\N	51.632441	г.Воронеж, ул.Матросова, д.2/А	Россия, Воронежская область, Воронеж, улица Матросова, 2а	0101000020E610000088F4DBD78197434024D3A1D3F3D04940
30247	1	4	\N	19	7476	\N	51.654740399618099	г.Воронеж, ул.Ворошилова, д.1/А	Россия, Воронежская область, Воронеж, улица Ворошилова	0101000020E6100000B01BB62DCA96434007B13385CED34940
30246	1	4	\N	19	7476	\N	51.656148999999999	г.Воронеж, ул.Ворошилова, д.14	Россия, Воронежская область, Воронеж, улица Ворошилова, 14	0101000020E6100000F38FBE49D3964340CC26C0B0FCD34940
30069	1	4	\N	19	5629	\N	51.720587000000002	г.Воронеж, ул.Богдана  Хмельницкого, д.34	Россия, Воронежская область, Воронеж, улица Богдана Хмельницкого, 34	0101000020E610000002F2255470A243401D76DF313CDC4940
30105	1	4	\N	19	6008	\N	51.696590016076897	г.Воронеж, ул. Беговая, 96	Россия, Воронежская область, Воронеж, улица Беговая	0101000020E6100000B3075A81219343403E5C72DC29D94940
30244	1	4	\N	19	7448	\N	51.673757000000002	г.Воронеж, ул.3 Интернационала, д.33		0101000020E6100000363AE7A738984340BD395CAB3DD64940
30087	1	4	\N	19	4345	\N	51.713996999999999	г.Воронеж, ул. 60-летия ВЛКСМ,27		0101000020E610000021E9D32AFA9343409738F24064DB4940
30089	1	4	\N	19	5898	\N	51.674505000000003	г.Воронеж, просп. Труда, 70	Россия, Воронежская область, Воронеж, проспект Труда, 70	0101000020E6100000882F13454895434087FE092E56D64940
30315	1	4	\N	19	42	\N	51.669378000000002	г.Воронеж, просп.Революции, д.29	Россия, Воронежская область, Воронеж, проспект Революции, 29	0101000020E6100000F2D077B7B29A4340B954A52DAED54940
30311	1	4	\N	19	42	\N	51.675303999999997	г.Воронеж, просп.Революции, д.19	Россия, Воронежская область, Воронеж, проспект Революции, 19	0101000020E61000008D261763609B4340D26D895C70D64940
30310	1	4	\N	19	42	\N	51.673884999999999	г.Воронеж, просп.Революции, д.18	Россия, Воронежская область, Воронеж, проспект Революции, 18	0101000020E6100000268C6665FB9A4340EA211ADD41D64940
30296	1	4	\N	19	7817	\N	51.647035000000002	г.Воронеж, просп.Патриотов, д.53	Россия, Воронежская область, Воронеж, проспект Патриотов, 53	0101000020E6100000FBC9181F668D4340062FFA0AD2D24940
30283	1	4	\N	19	7817	\N	51.643490999999997	г.Воронеж, просп.Патриотов, д.1	Россия, Воронежская область, Воронеж, проспект Патриотов, 1	0101000020E6100000CD751A69A99243409A22C0E95DD24940
30279	1	4	\N	19	7817	\N	51.647784000000001	г.Воронеж, просп.Патриотов, д.8	Россия, Воронежская область, Воронеж, проспект Патриотов, 8	0101000020E6100000069D103AE8904340A06F0B96EAD24940
30153	1	4	\N	19	36213	\N	51.733825000000003	г.Воронеж, пл.Советов, 28/А		0101000020E6100000350708E6E89143405DFE43FAEDDD4940
30304	1	4	\N	19	15775	\N	51.662875999999997	г.Воронеж, пл.Ленина, д.10а	Россия, Воронежская область, Воронеж, Центральный район, площадь Ленина, 10	0101000020E61000005858703FE0994340D2A6EA1ED9D44940
30237	1	4	\N	19	36048	\N	51.659792000000003	г.Воронеж, ул.Ленина площадь, д.2	Россия, Воронежская область, Воронеж, Центральный район, площадь Ленина, 2	0101000020E61000003F7100FDBE994340CB14731074D44940
30208	1	4	\N	19	15841	\N	51.551341000000001	г.Воронеж, пер.Звездный, д.2		0101000020E6100000BA4BE2AC889E4340D3F8855792C64940
30182	1	4	\N	19	6835	\N	51.645476000000002	г.Воронеж, Авиастроителей наб, д.30а		0101000020E610000047E6913F189E43402C2D23F59ED24940
30142	1	4	\N	19	36293	\N	51.707166999999998	г.Воронеж, ул.Генерала Лизюкова, 2		0101000020E610000055A3570394964340BCE7C07284DA4940
30141	1	4	\N	19	36293	\N	51.709505	г.Воронеж, ул.Генерала Лизюкова, 26		0101000020E6100000C3D50110779543409BAC510FD1DA4940
30138	1	4	\N	19	36293	\N	51.70787	г.Воронеж, ул.Генерала Лизюкова, 52/А		0101000020E610000092CB7F48BF934340E6E8F17B9BDA4940
30135	1	4	\N	19	36293	\N	51.703415999999997	г.Воронеж, Генерала Лизюкова, 81		0101000020E6100000FBC9181F66934340D7BD158909DA4940
30145	1	4	\N	19	6465	\N	51.714371	г.Воронеж, бульв.Победы, 32	Россия, Воронежская область, Воронеж, бульвар Победы, 32	0101000020E6100000687A89B14C954340FC1A498270DB4940
30258	1	4	\N	19	5120	\N	51.656433999999997	г.Воронеж, бульв.Пионеров, д.14	Россия, Воронежская область, Воронеж, бульвар Пионеров, 14	0101000020E6100000541B9C887E934340C1FD800706D44940
30285	1	4	\N	19	36320	\N	51.648314999999997	г.Воронеж, ул.Юлюса Янониса, д.10/2		0101000020E61000008D614ED026934340CC4065FCFBD24940
30284	1	4	\N	19	36320	\N	51.648330999999999	г.Воронеж, ул.Юлюса Янониса, д.6		0101000020E6100000CD751A69A9924340D2FD9C82FCD24940
30282	1	4	\N	19	36320	\N	51.648918000000002	г.Воронеж, ул.Юлюса Янониса, д.4		0101000020E6100000F9F6AE415F92434093E4B9BE0FD34940
30271	1	4	\N	19	36264	\N	51.655757999999999	г.Воронеж, ул.Южно-Моравская, д.18		0101000020E6100000637FD93D79904340910BCEE0EFD34940
30270	1	4	\N	19	36264	\N	51.653483000000001	г.Воронеж, ул.Южно-Моравская, д.3		0101000020E610000013437232718F4340F9BEB854A5D34940
30265	1	4	\N	19	36264	\N	51.655109000000003	г.Воронеж, ул.Южно-Моравская, д.74		0101000020E61000004833164D678D43405B28999CDAD34940
30108	1	4	\N	19	36256	\N	51.685525852181499	г.Воронеж, ул. Электросигнальная, 1	Россия, Воронежская область, Воронеж, улица Электросигнальная	0101000020E61000009E245D33F99643406347E350BFD74940
30074	1	4	\N	19	36329	\N	51.735799999999998	г.Воронеж, ул.Электровозная, д.12		0101000020E6100000C7D9740470A54340CA32C4B12EDE4940
30119	1	4	\N	19	36361	\N	51.698442	г.Воронеж, Шишкова, 60		0101000020E6100000FF76D9AF3B9943409013268C66D94940
30268	1	4	\N	19	36334	\N	51.657372000000002	г.Воронеж, ул.Шендрикова, д.7		0101000020E6100000A9328CBB418E43402FA704C424D44940
30216	1	4	\N	19	36367	\N	51.646059943943698	г.Воронеж, ул.Черняховского, д.2	Россия, Воронежская область, Воронеж, улица Черняховского	0101000020E610000051853FC39B9543407BA01518B2D24940
30200	1	4	\N	19	36246	\N	51.631258021172201	г.Воронеж, ул.Черепанова, д.18	Россия, Воронежская область, Воронеж, улица Черепанова	0101000020E6100000D192C7D3F2A1434050ABE80FCDD04940
30230	1	4	\N	19	36350	\N	51.647151999999998	г.Воронеж, ул.Челюскинцев, д.84		0101000020E6100000E17B7F83F69843403FC571E0D5D24940
30161	1	4	\N	19	36221	\N	51.602187000000001	г.Воронеж, ул.Чебышева, д.2б		0101000020E6100000DB519CA38EA24340C689AF7614CD4940
30225	1	4	\N	19	36279	\N	51.635266694107401	г.Воронеж, ул.Чапаева, д.115	Россия, Воронежская область, Воронеж, улица Чапаева	0101000020E610000089601C5C3A984340309DD66D50D14940
30206	1	4	\N	19	36269	\N	51.633318000000003	г.Воронеж, ул.Циолковского, д.129а		0101000020E610000032E36DA5D7A24340ECFB709010D14940
30175	1	4	\N	19	36269	\N	51.636935000000001	г.Воронеж, ул.Циолковского, д.20		0101000020E61000008C4AEA04349F4340C156091687D14940
30174	1	4	\N	19	36269	\N	51.638075000000001	г.Воронеж, ул.Циолковского, д.12а		0101000020E6100000323CF6B3589E434096B20C71ACD14940
30173	1	4	\N	19	36269	\N	51.637075000000003	г.Воронеж, ул.Циолковского, д.28		0101000020E61000003128D368729F4340B30C71AC8BD14940
30171	1	4	\N	19	36269	\N	51.640388999999999	г.Воронеж, ул.Циолковского, д.5		0101000020E61000001C0934D8D49D4340ECDB4944F8D14940
30156	1	4	\N	19	6574	\N	51.618825999999999	г.Воронеж, пер.Цимлянский, д.2	Россия, Воронежская область, Воронеж, Цимлянский переулок, 2	0101000020E61000003EE76ED74B9F43400EF5BBB035CF4940
30167	1	4	\N	19	36338	\N	51.616584000000003	г.Воронеж, ул.Цимлянская, д.6		0101000020E6100000B4006DAB599F4340529E7939ECCE4940
30291	1	4	\N	19	36210	\N	51.655752767313999	г.Воронеж, ул.Центральная (Первомайская), д.44		0101000020E61000009CA56439098B43407FA0DCB6EFD34940
31250	1	4	\N	19	67147	\N	51.655298999999999	с.Старый Эртиль, ул.Центральная, д.64		0101000020E6100000D845D1031F8B4340FE0C6FD6E0D34940
30133	1	4	\N	19	36271	\N	51.702333000000003	г.Воронеж, ул.Хользунова, 78		0101000020E6100000BA2EFCE07C94434067F3380CE6D94940
30132	1	4	\N	19	36271	\N	51.702579	г.Воронеж, ул. Хользунова, 70		0101000020E6100000836BEEE87F9543409EEDD11BEED94940
30131	1	4	\N	19	36271	\N	51.702579	г.Воронеж, ул.Хользунова, 70		0101000020E6100000836BEEE87F9543409EEDD11BEED94940
30130	1	4	\N	19	36271	\N	51.702756999999998	г.Воронеж, ул.Хользунова, 68		0101000020E61000003D49BA66F29543407D04FEF0F3D94940
30129	1	4	\N	19	36271	\N	51.703387999999997	г.Воронеж, ул.Хользунова, 64		0101000020E610000071218FE0469643400D33349E08DA4940
30126	1	4	\N	19	36271	\N	51.705196000000001	г.Воронеж, Хользунова, 40/А		0101000020E6100000C9CB9A58E097434090A2CEDC43DA4940
30303	1	4	\N	19	36311	\N	51.664563000000001	г.Воронеж, ул.Фридриха Энгельса, д.56		0101000020E610000072A3C85A43994340DA907F6610D54940
30235	1	4	\N	19	36311	\N	51.660468000000002	г.Воронеж, ул.Фридриха Энгельса, д.76		0101000020E61000002A58E36C3A984340FB0626378AD44940
30122	1	4	\N	19	6252	\N	51.700982000000003	г.Воронеж, пер.Ученический, 1	Россия, Воронежская область, Воронеж, Ученический переулок, 1	0101000020E6100000062CB98AC5974340D78A36C7B9D94940
30113	1	4	\N	19	36286	\N	51.683351000000002	г.Воронеж, ул. Урицкого, 66		0101000020E61000000BEF7211DF9943402E58AA0B78D74940
30112	1	4	\N	19	36286	\N	51.681826999999998	г.Воронеж, ул. Урицкого, 86		0101000020E6100000725303CDE7984340D0436D1B46D74940
30086	1	4	\N	19	36286	\N	51.680363999999997	г.Воронеж, ул.Урицкого, 75/А		0101000020E610000029AE2AFBAE98434018B0E42A16D74940
30312	1	4	\N	19	16302	\N	51.656002999999998	г.Воронеж, Университетская пл, д.1	Россия, Воронежская область, Воронеж, Центральный район, Университетская площадь, 1	0101000020E6100000174A26A7769A4340F88903E8F7D34940
30218	1	4	\N	19	7185	\N	51.638165000000001	г.Воронеж, пер.Туркменский, д.14/А	Россия, Воронежская область, Воронеж, Туркменский переулок, 14а	0101000020E61000009694BBCFF1954340D6390664AFD14940
30205	1	4	\N	19	36248	\N	51.637571999999999	г.Воронеж, ул.Туполева, д.25		0101000020E61000003293A8177CA24340336C94F59BD14940
30203	1	4	\N	19	36248	\N	51.639327999999999	г.Воронеж, ул.Туполева, д.13а		0101000020E610000043ACFE08C3A2434063B5F97FD5D14940
30201	1	4	\N	19	36248	\N	51.640095803029403	г.Воронеж, ул.Туполева, д.15в	Россия, Воронежская область, Воронеж, улица Туполева	0101000020E61000007AA52C431CA3434074266DAAEED14940
30199	1	4	\N	19	36248	\N	51.641071993172901	г.Воронеж, ул.Туполева, д.18		0101000020E6100000394371C79BA24340CF30B5A50ED24940
30197	1	4	\N	19	36248	\N	51.635817000000003	г.Воронеж, ул.Туполева, д.40		0101000020E61000007CF2B0506BA24340D49E927362D14940
30115	1	4	\N	19	36196	\N	51.6900270071216	г.Воронеж, ул. Транспортная, 51	Россия, Воронежская область, Воронеж, улица Транспортная	0101000020E610000071E5EC9DD19A4340B22D03CE52D84940
30114	1	4	\N	19	36196	\N	51.689979000000001	г.Воронеж, ул. Транспортная, 49		0101000020E6100000A48AE255D69A4340A1F65B3B51D84940
30326	1	4	\N	19	36368	\N	51.718735000000002	г.Воронеж, ул.Тимирязева, д.8		0101000020E610000013D21A834E9C4340CBBE2B82FFDB4940
30289	1	4	\N	19	36365	\N	51.550395000000002	г.Воронеж, ул.Теплоэнергетиков, д.15а		0101000020E610000003232F6B628B4340E370E65773C64940
30287	1	4	\N	19	36283	\N	51.625855000000001	г.Воронеж, ул.Тепличная, д.20б		0101000020E610000057957D5704894340E08442041CD04940
30209	1	4	\N	19	36690	\N	51.553998389694002	г.Воронеж, ул.Тавровская, д.57	Россия, Воронежская область, Воронеж, Таврово микрорайон, Тавровская улица	0101000020E61000001CD0D2156C99434053060E68E9C64940
30078	1	4	\N	19	36235	\N	51.746975999999997	г.Воронеж, ул.Сухумская, д.1		0101000020E61000006E1805C1E3AF4340CD72D9E89CDF4940
30309	1	4	\N	19	36308	\N	51.677213999999999	г.Воронеж, ул.Студенческая, д.10		0101000020E6100000BBD1C77C409A43405932C7F2AED64940
30308	1	4	\N	19	36308	\N	51.674193000000002	г.Воронеж, ул.Студенческая, д.18		0101000020E61000009AEFE0270E9A43409818CBF44BD64940
30307	1	4	\N	19	36308	\N	51.67069	г.Воронеж, ул.Студенческая, д.29		0101000020E6100000388600E0D89943408BE07F2BD9D54940
30210	1	4	\N	19	36429	\N	51.684053988721701	г.Воронеж, ул.Степная, д.2в	Россия, Воронежская область, Воронеж, проспект Труда, 16	0101000020E610000066D993C0E69843405859DB148FD74940
30322	1	4	\N	19	164	\N	51.692278926582802	г.Воронеж, пер.Советский, д.2	Россия, Воронежская область, Воронеж, Советский переулок	0101000020E6100000BF29AC54509B4340925A28999CD84940
30318	1	4	\N	19	101	\N	51.679867000000002	г.Воронеж, ул.Смоленская, д.33	Россия, Воронежская область, Воронеж, Смоленская улица, 33	0101000020E6100000279F1EDB329C43409850C1E105D74940
30249	1	4	\N	19	36319	\N	51.683967915784102	г.Воронеж, ул.Силикатная, д.14	Россия, Воронежская область, Воронеж, Придонской микрорайон, улица Силикатная, 14	0101000020E61000003F373465A789434059C16F438CD74940
30188	1	4	\N	19	36340	\N	51.667222000000002	г.Воронеж, ул.Серова, д.4		0101000020E61000009BE271512DA04340FB95CE8767D54940
30245	1	4	\N	19	36359	\N	51.664321999999999	г.Воронеж, ул.Свободы, д.77		0101000020E610000004A9143B1A974340B401D88008D54940
30239	1	4	\N	19	36359	\N	51.661563000000001	г.Воронеж, ул.Свободы, д.59		0101000020E6100000B43EE5982C984340309FAC18AED44940
30317	1	4	\N	19	36346	\N	51.677007000000003	г.Воронеж, ул.Сакко и Ванцетти, д.80		0101000020E6100000E9D1544FE69B4340E014562AA8D64940
30169	1	4	\N	19	36214	\N	51.610539966263097	г.Воронеж, ул.Саврасова, д.16		0101000020E61000007EFFE6C5899D43402E73BA2C26CE4940
30168	1	4	\N	19	36214	\N	51.610247000000001	г.Воронеж, ул.Саврасова, д.2а		0101000020E6100000D5EAABAB029D4340B6BDDD921CCE4940
30165	1	4	\N	19	36282	\N	51.593448449788703	г.Воронеж, ул.Ростовская, д.61	Россия, Воронежская область, Воронеж, Ростовская улица, 61	0101000020E6100000F2B1BB40499F434035F0A31AF6CB4940
30164	1	4	\N	19	36282	\N	51.595596	г.Воронеж, ул.Ростовская, д.55		0101000020E6100000D4D2DC0A619F434070D05E7D3CCC4940
30160	1	4	\N	19	36282	\N	51.607629000000003	г.Воронеж, ул.Ростовская, д.48/4		0101000020E610000047AF06280D9F4340F48C7DC9C6CD4940
30159	1	4	\N	19	36282	\N	51.612791999999999	г.Воронеж, ул.Ростовская, д.36		0101000020E61000000491459A789F43400EA0DFF76FCE4940
30158	1	4	\N	19	36282	\N	51.612439999999999	г.Воронеж, ул.Ростовская, д.39		0101000020E6100000959BA8A5B99F43409161156F64CE4940
30192	1	4	\N	19	36281	\N	51.6650116080571	г.Воронеж, ул.Рижская, д.8а	Россия, Воронежская область, Воронеж, Рижская улица	0101000020E6100000800BB265F9A4434049B9FB1C1FD54940
30053	1	4	\N	19	36207	\N	51.685029956796299	г.Воронеж, ул.Репненская, д.82		0101000020E6100000DDB5847CD0A94340B2632310AFD74940
30314	1	4	\N	19	36299	\N	51.667332999999999	г.Воронеж, ул.Пятницкого, д.67		0101000020E6100000473B6EF8DD9A43405245F12A6BD54940
30234	1	4	\N	19	36358	\N	51.658226999999997	г.Воронеж, ул.Пушкинская, д.39		0101000020E6100000A585CB2A6C9843400E2C47C840D44940
30109	1	4	\N	19	6107	\N	51.685183342125697	г.Воронеж, пер.Политехнический, 16	Россия, Воронежская область, Воронеж, Политехнический переулок	0101000020E61000006500A8E2C697434039639813B4D74940
30178	1	4	\N	19	36318	\N	51.642496999999999	г.Воронеж, ул.Полины Осипенко, д.4		0101000020E6100000BD55D7A19A9E4340996379573DD24940
30242	1	4	\N	19	36343	\N	51.670205000000003	г.Воронеж, ул.Плехановская, д.39		0101000020E6100000809F71E140984340CF4E0647C9D54940
30236	1	4	\N	19	36342	\N	51.658696999999997	г.Воронеж, ул.Платонова, д.25		0101000020E61000003A4030478F994340957CEC2E50D44940
30280	1	4	\N	19	36355	\N	51.658293999999998	г.Воронеж, ул.Пеше-Стрелецкая, д.90		0101000020E610000081936DE00E924340969350FA42D44940
30257	1	4	\N	19	36355	\N	51.662506999999998	г.Воронеж, ул.Пеше-стрелецкая, д.95		0101000020E6100000D2C5A695429443407F2F8507CDD44940
30061	1	4	\N	19	36261	\N	51.695098999999999	г.Воронеж, ул.Переверткина, д.49		0101000020E61000006956B60F79A14340BC3D0801F9D84940
30059	1	4	\N	19	36261	\N	51.691191000000003	г.Воронеж, ул.Переверткина, д.42 корп.б		0101000020E610000024287E8CB9A1434010255AF278D84940
30057	1	4	\N	19	36261	\N	51.690559999999998	г.Воронеж, ул.Переверткина, д.25		0101000020E61000006138D73043A143407FF6234564D84940
30056	1	4	\N	19	36261	\N	51.689855999999999	г.Воронеж, ул.Переверткина, д.19		0101000020E6100000FAB48AFED0A0434085798F334DD84940
30055	1	4	\N	19	36261	\N	51.689075000000003	г.Воронеж, ул.Переверткина, д.34		0101000020E6100000280F0BB5A6A14340E0BE0E9C33D84940
30052	1	4	\N	19	36261	\N	51.681564000000002	г.Воронеж, ул.Переверткина, д.5		0101000020E610000014799274CDA04340C310397D3DD74940
30050	1	4	\N	19	36261	\N	51.682887999999998	г.Воронеж, ул.Переверткина, д.16		0101000020E6100000486E4DBA2DA14340596ABDDF68D74940
30369	1	4	\N	19	67151	\N	51.661954000000001	пос.Первомайского отделения, ул.Первомайская, д.12		0101000020E6100000A3906456EF9A43406BBA9EE8BAD44940
30073	1	4	\N	19	36218	\N	51.732520000000001	г.Воронеж, ул.Паровозная, д.62		0101000020E6100000BD56427749A243403DD52137C3DD4940
30058	1	4	\N	19	36327	\N	51.689605	г.Воронеж, ул.Остужева, д.1		0101000020E6100000A019C40776A043403C1405FA44D84940
30048	1	4	\N	19	36327	\N	51.683188999999999	г.Воронеж, ул.Остужева, д.26		0101000020E610000061DEE34C13A2434054FEB5BC72D74940
30221	1	4	\N	19	4698	\N	51.633222968462697	г.Воронеж, пер.Острогожский, д.1/а	Россия, Воронежская область, Воронеж, Острогожская улица, 1а	0101000020E61000001A8A3BDEE49543409A0986730DD14940
30222	1	4	\N	19	36262	\N	51.6233144222685	г.Воронеж, ул.Острогожская, д.83	Россия, Воронежская область, Воронеж, Острогожская улица	0101000020E61000004489963C9E964340C991CEC0C8CF4940
30273	1	4	\N	19	36364	\N	51.651293000000003	г.Воронеж, ул.Олеко Дундича, д.25		0101000020E610000099654F029B8F43408F8EAB915DD34940
30290	1	4	\N	19	36197	\N	51.565894	г.Воронеж, ул.Октябрьская, д.236		0101000020E6100000B3B27DC85B8643405680EF366FC84940
30193	1	4	\N	19	36306	\N	51.663902999999998	г.Воронеж, ул.Окружная, д.3		0101000020E610000099D9E731CAA34340AF5B04C6FAD44940
30163	1	4	\N	19	36339	\N	51.596581	г.Воронеж, ул.Новосибирская, д.67		0101000020E61000006150A6D1E49E43401E3526C45CCC4940
30162	1	4	\N	19	36339	\N	51.599015000000001	г.Воронеж, ул.Новосибирская, д.31а		0101000020E6100000C34659BF999E43401F680586ACCC4940
30302	1	4	\N	19	36321	\N	51.669730000000001	г.Воронеж, ул.Никитинская, д.1		0101000020E61000001CEBE2361A9A434036936FB6B9D54940
30301	1	4	\N	19	36321	\N	51.666792000000001	г.Воронеж, ул.Никитинская, д.26		0101000020E61000009485AFAF75994340029EB47059D54940
30300	1	4	\N	19	36321	\N	51.665970000000002	г.Воронеж, ул.Никитинская, д.32		0101000020E6100000C3F352B131994340FE0E45813ED54940
30083	1	4	\N	19	35795	\N	51.662495999999997	г.Воронеж, ул.Никитина, д.149		0101000020E6100000499F56D11F9A43408BDD3EABCCD44940
30045	1	4	\N	19	36313	\N	51.676476999999998	г.Воронеж, ул.Набережная, д.15	Россия, Воронежская область, Воронеж, Железнодорожный район, улица Весенняя	0101000020E6100000A514747B499F434083BF5FCC96D64940
30154	1	4	\N	19	4365	\N	51.727694999999997	г.Воронеж, Московский проспект, 129	Россия, Воронежская область, Воронеж, Московский проспект, 129	0101000020E6100000B0FECF61BE9643403A3B191C25DD4940
30150	1	4	\N	19	4365	\N	51.734011141020297	г.Воронеж, Московский просп, 179	Россия, Воронежская область, Воронеж, Московский проспект, 149а	0101000020E6100000CA367007EA964340BFF38B12F4DD4940
30148	1	4	\N	19	4365	\N	51.720252000000002	г.Воронеж, Московский просп, 131	Россия, Воронежская область, Воронеж, Московский проспект, 131	0101000020E6100000815D4D9EB29643407670B03731DC4940
30144	1	4	\N	19	4365	\N	51.714928999999998	г.Воронеж, Московский просп, 121	Россия, Воронежская область, Воронеж, Московский проспект, 121	0101000020E6100000F4893C49BA96434022FB20CB82DB4940
30123	1	4	\N	19	4365	\N	51.700156	г.Воронеж, Московский просп, 74	Россия, Воронежская область, Воронеж, Московский проспект, 74	0101000020E6100000FE2AC0779B974340910C39B69ED94940
30116	1	4	\N	19	4365	\N	51.691403000000001	г.Воронеж, Московский просп, 38	Россия, Воронежская область, Воронеж, Московский проспект, 38	0101000020E610000094F947DFA49743409BADBCE47FD84940
30110	1	4	\N	19	4365	\N	51.684446000000001	г.Воронеж, Московский просп, 14	Россия, Воронежская область, Воронеж, Московский проспект, 14	0101000020E61000001C261AA4E097434063F030ED9BD74940
30278	1	4	\N	19	36298	\N	51.650947000000002	г.Воронеж, ул.Молодогвардейцев, д.7		0101000020E6100000FC6EBA6587904340F436363B52D34940
30276	1	4	\N	19	36298	\N	51.648705999999997	г.Воронеж, ул.Молодогвардейцев, д.17		0101000020E6100000B6D9588979904340075C57CC08D34940
30274	1	4	\N	19	36298	\N	51.64884	г.Воронеж, ул.Молодогвардейцев, д.18		0101000020E61000009BE271512D904340172B6A300DD34940
30325	1	4	\N	19	36336	\N	51.713383	г.Воронеж, ул.Мичурина, д.1		0101000020E6100000058C2E6F0E9D4340DD42572250DB4940
29863	1	4	\N	19	36193	\N	51.677086000000003	Воронежская область, Богучарский муниципальный район, Подколодновское сельское поселение, ул.Мира, д.21		0101000020E6100000FF959526A59A43402C4A09C1AAD64940
30084	1	4	\N	19	36245	\N	51.687846	г.Воронеж, ул.Минская, д.69 корп.а		0101000020E61000001DACFF7398A343409B5775560BD84940
30054	1	4	\N	19	36245	\N	51.6739397125789	г.Воронеж, ул.Минская, д.14	Россия, Воронежская область, Воронеж, Минская улица	0101000020E6100000BFD364C6DBA24340AEBB79AA43D64940
30049	1	4	\N	19	36245	\N	51.680608999999997	г.Воронеж, ул.Минская, д.23		0101000020E6100000A933F790F0A143407F2E1A321ED74940
30047	1	4	\N	19	36245	\N	51.679938999999997	г.Воронеж, ул.Минская, д.17/2		0101000020E6100000D28DB0A888A143403123BC3D08D74940
30155	1	4	\N	19	36348	\N	51.619856613328501	г.Воронеж, ул.Менделеева, д.38	Россия, Воронежская область, Воронеж, улица Менделеева	0101000020E610000045D61A4AED9F43402D99637957CF4940
30261	1	4	\N	19	36303	\N	51.654417000000002	г.Воронеж, ул.Космонавтов, д.36		0101000020E61000005ED905836B9443402579AEEFC3D34940
30256	1	4	\N	19	36263	\N	51.674440811107701	г.Воронеж, ул.Машиностроителей, д.88	Россия, Воронежская область, Воронеж, улица Машиностроителей, 80	0101000020E6100000EE5A423EE8934340700A2B1554D64940
30092	1	4	\N	19	36263	\N	51.678012853109003	г.Воронеж, ул.Машиностроителей, 13/Б	Россия, Воронежская область, Воронеж, улица Машиностроителей, 13к2	0101000020E6100000CA37DBDC98944340A5A14621C9D64940
30065	1	4	\N	19	36335	\N	51.710509000000002	г.Воронеж, ул.Маршала Одинцова, д.17		0101000020E6100000CCB56801DAA24340C0417BF5F1DA4940
30143	1	4	\N	19	36280	\N	51.709985000000003	г.Воронеж, ул.Маршала Жукова, 6/А		0101000020E6100000862172FA7A96434046D3D9C9E0DA4940
30127	1	4	\N	19	36280	\N	51.704649000000003	г.Воронеж, Маршала Жукова, 2		0101000020E6100000083A5AD5929643405E143DF031DA4940
30319	1	4	\N	19	36259	\N	51.684723601381897	г.Воронеж, ул.Мало-Терновая, д.9	Россия, Воронежская область, Воронеж, улица Мало-Терновая	0101000020E6100000E4F4F57CCD9C4340A6643909A5D74940
30267	1	4	\N	19	36305	\N	51.658718999999998	г.Воронеж, ул.Любы Шевцовой, д.3		0101000020E610000067D47C957C8E43407D2079E750D44940
30332	1	4	\N	19	36353	\N	51.727649999999997	г.Воронеж, ул.Ломоносова, д.114А		0101000020E610000081B22957789943409A779CA223DD4940
30328	1	4	\N	19	36353	\N	51.727649999999997	г.Воронеж, ул.Ломоносова, д.114а		0101000020E610000081B22957789943409A779CA223DD4940
30327	1	4	\N	19	36353	\N	51.725172999999998	г.Воронеж, ул.Ломоносова, д.105		0101000020E6100000484F9143C49943409A780778D2DC4940
30080	1	4	\N	19	36244	\N	51.732976999999998	г.Воронеж, ул.Липецкая, д.2		0101000020E610000057B3CEF8BEAC43402FDCB930D2DD4940
30111	1	4	\N	19	36294	\N	51.686774	г.Воронеж, ул. Лидии Рябцевой, 51		0101000020E61000008AC745B5889843401EDFDE35E8D74940
30329	1	4	\N	19	37252	\N	51.718696000000001	г.Воронеж, ул.Лесной поселок, д.1		0101000020E610000011AAD4EC819E43400DE2033BFEDB4940
30734	1	4	\N	19	74970	\N	51.642966000000001	пос.Загирянка, ул.Лесная, д.2ж (контора маслоцеха)		0101000020E6100000B763EAAEEC8A43405038BBB54CD24940
30191	1	4	\N	19	5475	\N	51.670209999999997	г.Воронеж, Ленинский просп, д.116/2		0101000020E61000007E37DDB243A04340E0B9F770C9D54940
30190	1	4	\N	19	5475	\N	51.669769000000002	г.Воронеж, Ленинский просп, д.109	Россия, Воронежская область, Воронеж, Ленинский проспект, 109	0101000020E610000029B000A60CA04340F46F97FDBAD54940
30189	1	4	\N	19	5475	\N	51.669561999999999	г.Воронеж, Ленинский просп, д.115а	Россия, Воронежская область, Воронеж, Ленинский проспект, 115а	0101000020E61000009D9CA1B8E39F43407A522635B4D54940
30187	1	4	\N	19	5475	\N	51.665239	г.Воронеж, Ленинский просп, д.102	Россия, Воронежская область, Воронеж, Ленинский проспект, 102	0101000020E6100000406A1327F79F43400A83328D26D54940
30185	1	4	\N	19	5475	\N	51.656294000000003	г.Воронеж, Ленинский просп, д.91	Россия, Воронежская область, Воронеж, Ленинский проспект, 91	0101000020E6100000EC866D8B329F4340D047197101D44940
30181	1	4	\N	19	5475	\N	51.649755999999996	г.Воронеж, Ленинский просп, д.47	Россия, Воронежская область, Воронеж, Ленинский проспект, 47	0101000020E6100000B073D3669C9E43409C3061342BD34940
30177	1	4	\N	19	5475	\N	51.636660999999997	г.Воронеж, Ленинский просп, д.14	Россия, Воронежская область, Воронеж, Ленинский проспект, 14	0101000020E6100000AD1397E3159E4340BFD18E1B7ED14940
30176	1	4	\N	19	5475	\N	51.6387906020325	г.Воронеж, Ленинский просп, д.9/4	Россия, Воронежская область, Воронеж, Ленинский проспект, 9к4	0101000020E6100000077DE9EDCF9D434054FD4AE7C3D14940
30063	1	4	\N	19	5475	\N	51.700597000000002	г.Воронеж, Ленинский просп, д.207	Россия, Воронежская область, Воронеж, Ленинский проспект, 207	0101000020E6100000F65FE7A6CDA243407E569929ADD94940
30062	1	4	\N	19	5475	\N	51.696589000000003	г.Воронеж, Ленинский просп, д.197 корп.а	Россия, Воронежская область, Воронеж, Ленинский проспект, 197а	0101000020E6100000B16EBC3B32A243406EE00ED429D94940
30051	1	4	\N	19	5475	\N	51.67727	г.Воронеж, Ленинский просп, д.119 корп.а	Россия, Воронежская область, Воронеж, Ленинский проспект, 119а	0101000020E6100000266F8099EFA04340ED478AC8B0D64940
30186	1	4	\N	19	36326	\N	51.665655963266701	г.Воронеж, ул.Ленинградская, д.26а	Россия, Воронежская область, Воронеж, Ленинградская улица, 26а	0101000020E61000009BE271512DA043406E313F3734D54940
30179	1	4	\N	19	36326	\N	51.647213999999998	г.Воронеж, ул.Ленинградская, д.33		0101000020E610000058C85C19549F4340B5C189E8D7D24940
30046	1	4	\N	19	36326	\N	51.673611999999999	г.Воронеж, ул.Ленинградская, д.1		0101000020E6100000FCC401F4FBA04340B91803EB38D64940
30610	1	4	\N	19	36267	\N	51.691178999999998	х.Дмитриевка, ул.Ленина, д.4		0101000020E61000006495D233BD9C43404B57B08D78D84940
30321	1	4	\N	19	36267	\N	51.685496000000001	г.Воронеж, ул.Ленина, д.88		0101000020E6100000E59A02999D9B4340F8C43A55BED74940
30320	1	4	\N	19	36267	\N	51.686635000000003	г.Воронеж, ул.Ленина, д.86		0101000020E610000064AF777FBC9B4340FDA4DAA7E3D74940
30170	1	4	\N	19	36215	\N	51.627313999999998	г.Воронеж, ул.Лебедева, д.2		0101000020E6100000A1BE654E979D434056293DD34BD04940
30288	1	4	\N	19	36249	\N	51.559011009839097	г.Воронеж, ул.Курчатова, д.12	Россия, Воронежская область, Воронеж, улица Курчатова	0101000020E6100000EBC726F9118F4340588D25AC8DC74940
30172	1	4	\N	19	36347	\N	51.631272000000003	г.Воронеж, ул.Кулибина, д.4		0101000020E61000002864E76D6C9E4340B5705985CDD04940
30072	1	4	\N	19	36194	\N	51.735878	г.Воронеж, ул.Куйбышева, д.23 корп.а		0101000020E6100000EAE74D452AA2434046EC134031DE4940
30071	1	4	\N	19	36194	\N	51.735878	г.Воронеж, ул.Куйбышева, д.23		0101000020E6100000EAE74D452AA2434046EC134031DE4940
30220	1	4	\N	19	36333	\N	51.641579999999998	г.Воронеж, ул.Кривошеина, д.13		0101000020E61000000F80B8AB5793434043E21E4B1FD24940
30248	1	4	\N	19	36352	\N	51.653013999999999	г.Воронеж, ул.Краснознаменная, д.14		0101000020E6100000577C43E1B397434042EA76F695D34940
30217	1	4	\N	19	36352	\N	51.640400999999997	г.Воронеж, ул.Краснознаменная, д.105		0101000020E6100000E59D4319AA964340B0A9F3A8F8D14940
30214	1	4	\N	19	36352	\N	51.645961999999997	г.Воронеж, ул.Краснознаменная, д.74		0101000020E610000086E464E256974340B83A00E2AED24940
30269	1	4	\N	19	36345	\N	51.659258288893803	г.Воронеж, ул.Краснозвездная, д.2	Россия, Воронежская область, Воронеж, улица Краснозвездная	0101000020E61000003F8BA548BE8E43402DD0EE9062D44940
30262	1	4	\N	19	36303	\N	51.652237	г.Воронеж, ул.Космонавтов, д.46		0101000020E61000009294F430B4944340DE1E84807CD34940
30260	1	4	\N	19	36303	\N	51.653075999999999	г.Воронеж, ул.Космонавтов, д.34		0101000020E610000098FC4FFEEE934340B8E68EFE97D34940
30259	1	4	\N	19	36303	\N	51.658729999999998	г.Воронеж, ул.Космонавтов, д.23		0101000020E61000008D2AC3B81B9443407172BF4351D44940
30241	1	4	\N	19	36288	\N	51.666294000000001	г.Воронеж, ул.Кольцовская, д.56/2		0101000020E61000005C035B2558984340B1C22D1F49D54940
30252	1	4	\N	19	36302	\N	51.682274	г.Воронеж, ул.Киселева, д.2		0101000020E61000005396218E758B43409F7422C154D74940
30305	1	4	\N	19	36307	\N	51.665785999999997	г.Воронеж, ул.Карла Маркса, д.57		0101000020E61000003A90F5D4EA9943403C11C47938D54940
30299	1	4	\N	19	36307	\N	51.674082686867997	г.Воронеж, ул.Карла Маркса, д.116	Россия, Воронежская область, Воронеж, улица Карла Маркса, 116	0101000020E610000072193735D098434011E50B5A48D64940
30298	1	4	\N	19	36307	\N	51.672669131448302	г.Воронеж, ул.Карла Маркса, д.69	Россия, Воронежская область, Воронеж, улица Карла Маркса, 69	0101000020E610000070CE88D2DE9843403A048E041AD64940
30215	1	4	\N	19	36356	\N	51.647235999999999	г.Воронеж, ул.Карла Либкнехта, д.50		0101000020E6100000C47B0E2C479643409D6516A1D8D24940
30075	1	4	\N	19	36315	\N	51.736753	г.Воронеж, ул.Калининградская, д.110		0101000020E6100000E3C4573B8AA543406D1D1CEC4DDE4940
30196	1	4	\N	19	36349	\N	51.634011999999998	г.Воронеж, ул.Иркутская, д.25		0101000020E61000006FF25B74B2A44340C2A2224E27D14940
30250	1	4	\N	19	36369	\N	51.682842999999998	г.Воронеж, ул.Защитников Родины, д.2		0101000020E610000097C80567F0894340B9A6406667D74940
30251	1	4	\N	19	36304	\N	51.681749000000003	г.Воронеж, ул.Заполярная, д.1		0101000020E610000046EBA86A828A4340558A1D8D43D74940
30091	1	4	\N	19	36290	\N	51.678811000000003	г.Воронеж, ул. Загородная, 66		0101000020E610000045D5AF743E94434021956247E3D64940
30079	1	4	\N	19	36241	\N	51.744829000000003	г.Воронеж, ул.Дубовая, д.12		0101000020E61000004582A966D6AE4340630E828E56DF4940
30866	1	4	\N	19	36716	\N	51.657908999999997	пос.Tимирязевский, ул.Дорожная, д.2	Россия, Воронежская область, Воронеж, улица Дорожная	0101000020E61000009510ACAA979143403D5FB35C36D44940
30272	1	4	\N	19	36716	\N	51.663769000000002	г.Воронеж, ул.Дорожная, д.15а		0101000020E6100000242A543717934340A08CF161F6D44940
30243	1	4	\N	19	36310	\N	51.671646000000003	г.Воронеж, ул.Донбасская, д.15		0101000020E61000003C122F4FE79643409F3E027FF8D54940
30152	1	4	\N	19	36211	\N	51.724989000000001	г.Воронеж, ул.Дмитрия Горина, 2/Б		0101000020E6100000CF656A12BC934340D97A8670CCDC4940
30151	1	4	\N	19	36211	\N	51.724989000000001	г.Воронеж, ул.Дмитрия Горина, 61		0101000020E6100000CF656A12BC934340D97A8670CCDC4940
30194	1	4	\N	19	36309	\N	51.657706221324098	г.Воронеж, ул.Димитрова, д.128	Россия, Воронежская область, Воронеж, улица Димитрова	0101000020E6100000282A1BD654A443400531D0B52FD44940
30044	1	4	\N	19	36309	\N	51.670344	г.Воронеж, ул.Димитрова, д.81		0101000020E6100000F5F6E7A221A14340F0880AD5CDD54940
30227	1	4	\N	19	36351	\N	51.634607485375497	г.Воронеж, ул.Державина, д.65	Россия, Воронежская область, Воронеж, улица Державина, 65	0101000020E6100000C32D1F494999434006685BCD3AD14940
30064	1	4	\N	19	36270	\N	51.701020999999997	г.Воронеж, ул.Грибоедова, д.5		0101000020E610000017F2086EA4A2434094675E0EBBD94940
30224	1	4	\N	19	36287	\N	51.632763740766102	г.Воронеж, ул.Грамши, д.73/А	Россия, Воронежская область, Воронеж, улица Грамши, 73б	0101000020E6100000CD9541B5C1974340070B2769FED04940
29795	1	4	\N	19	36205	\N	51.586531999999998	г.Воронеж, ул.Глинки, д.19		0101000020E6100000A5A2B1F677A843405B07077B13CB4940
30281	1	4	\N	19	36322	\N	51.653947000000002	г.Воронеж, ул.Героев Сибиряков, д.5		0101000020E61000004EEE77280A9243409E280989B4D34940
30077	1	4	\N	19	35689	\N	51.662495999999997	г.Воронеж, ул.Героев России, д.1	Россия, Воронежская область, Воронеж, Центральный район, площадь Ленина	0101000020E6100000499F56D11F9A43408BDD3EABCCD44940
30081	1	4	\N	19	35989	\N	51.662495999999997	г.Воронеж, ул.Генерала Лохматикова, д.43		0101000020E6100000499F56D11F9A43408BDD3EABCCD44940
30140	1	4	\N	19	36325	\N	51.706620000000001	г.Воронеж, ул.Генерала Лизюкова, 42		0101000020E6100000838593347F9443408A592F8672DA4940
30139	1	4	\N	19	36325	\N	51.70787	г.Воронеж, ул.Генерала Лизюкова, 52		0101000020E610000092CB7F48BF934340E6E8F17B9BDA4940
30136	1	4	\N	19	36325	\N	51.705447999999997	г.Воронеж, ул.Генерала Лизюкова, 87		0101000020E61000005F24B4E55C924340A983BC1E4CDA4940
30134	1	4	\N	19	36325	\N	51.7033146391651	г.Воронеж, ул.Генерала Лизюкова, 81	Россия, Воронежская область, Воронеж, улица генерала Лизюкова, 81	0101000020E6100000FCFD62B664934340A4E4D53906DA4940
30128	1	4	\N	19	36325	\N	51.707239000000001	г.Воронеж, Генерала Лизюкова, 24		0101000020E6100000DFA3FE7A8595434056BABBCE86DA4940
30180	1	4	\N	19	6815	\N	51.649723000000002	г.Воронеж, пер.Гвардейский, д.50	Россия, Воронежская область, Воронеж, Гвардейский переулок, 50	0101000020E61000009605137F149F4340C13A8E1F2AD34940
30093	1	4	\N	19	36360	\N	51.679670999999999	г.Воронеж, ул. Газовая, 24		0101000020E6100000AC8DB1135E92434012859675FFD64940
30286	1	4	\N	19	36297	\N	51.650163999999997	г.Воронеж, ул.Ворошилова, д.19		0101000020E6100000BBB7223141954340AD84EE9238D34940
30313	1	4	\N	19	36323	\N	51.658797	г.Воронеж, ул.Володарского, д.60		0101000020E6100000E3C116BB7D9A4340F9D9C87553D44940
30157	1	4	\N	19	36363	\N	51.613428999999996	г.Воронеж, ул.Волго-Донская, д.26		0101000020E6100000A5DDE8633EA0434080B56AD784CE4940
30195	1	4	\N	19	36247	\N	51.657283840334998	г.Воронеж, ул.Волгоградская, д.28		0101000020E61000009A6038D730A343408F17D2E121D44940
30149	1	4	\N	19	36284	\N	51.721820000000001	г.Воронеж, ул.Владимира Невского, 75		0101000020E61000003CBCE7C072964340A3CC069964DC4940
30147	1	4	\N	19	36284	\N	51.720647999999997	г.Воронеж, ул.Владимира Невского, 65/Б	Россия, Воронежская область, Воронеж, улица Владимира Невского, 65б	0101000020E61000009A7B48F8DE954340C2F693313EDC4940
30146	1	4	\N	19	36284	\N	51.716023	г.Воронеж, ул.Владимира невского, 42		0101000020E61000005280289831954340871744A4A6DB4940
30137	1	4	\N	19	36284	\N	51.710320000000003	г.Воронеж, ул.Владимира Невского, 17/А		0101000020E6100000392A37514B934340EDD808C4EBDA4940
14623	1	4	\N	19	36284	\N	51.716023	г.Воронеж, ул.Владимира Невского, 42		0101000020E61000005280289831954340871744A4A6DB4940
30231	1	4	\N	19	36236	\N	51.644535373325397	г.Воронеж, ул.Веры Фигнер, д.77	Россия, Воронежская область, Воронеж, улица Веры Фигнер	0101000020E6100000ECDADE6E499A43404D10751F80D24940
30219	1	4	\N	19	36344	\N	51.638522999999999	г.Воронеж, ул.Броневая, д.12		0101000020E6100000F73E558506944340355F251FBBD14940
30211	1	4	\N	19	36199	\N	51.5227454038207	г.Воронеж, ул.Большая Советская, д.35б	Россия, Воронежская область, Воронеж, Семилукские Выселки микрорайон, Большая Советская улица	0101000020E610000011E335AFEA924340E292E34EE9C24940
30070	1	4	\N	19	36295	\N	51.720587000000002	г.Воронеж, ул.Богдана Хмельницкого, д.34		0101000020E610000002F2255470A243401D76DF313CDC4940
30068	1	4	\N	19	36295	\N	51.720514999999999	г.Воронеж, ул.Богдана  Хмельницкого, д.35		0101000020E61000000038F6ECB9A2434083A3E4D539DC4940
30066	1	4	\N	19	36295	\N	51.713940999999998	г.Воронеж, ул.Богдана Хмельницкого, д.58		0101000020E610000057EC2FBB27A3434003232F6B62DB4940
30324	1	4	\N	19	36362	\N	51.702126999999997	г.Воронеж, ул.Березовая Роща, д.54		0101000020E6100000C0401020439D4340BD512B4CDFD94940
30323	1	4	\N	19	36362	\N	51.700803999999998	г.Воронеж, ул.Березовая Роща, д.32		0101000020E6100000C5FEB27BF29C4340F7730AF2B3D94940
30120	1	4	\N	19	36195	\N	51.699916000000002	г.Воронеж, Беговая, 2		0101000020E6100000D1950854FF9843403CF9F4D896D94940
30117	1	4	\N	19	36195	\N	51.699916000000002	г.Воронеж, ул.Беговая, 2		0101000020E6100000D1950854FF9843403CF9F4D896D94940
30106	1	4	\N	19	36195	\N	51.696856704365601	г.Воронеж, ул.Беговая, 96		0101000020E610000021CEC3094C9343408D7E349C32D94940
30104	1	4	\N	19	36195	\N	51.696997000000003	г.Воронеж, ул. Беговая, 120		0101000020E6100000E8667FA0DC9243407F349C3237D94940
30101	1	4	\N	19	36195	\N	51.699899000000002	г.Воронеж, ул.Беговая, 146		0101000020E61000006E3315E29192434066C0594A96D94940
30100	1	4	\N	19	36195	\N	51.699899000000002	г.Воронеж, ул. Беговая, 146		0101000020E61000006E3315E29192434066C0594A96D94940
30099	1	4	\N	19	36195	\N	51.697488	г.Воронеж, ул. Беговая, 176		0101000020E6100000CC79C6BE649143401DAD6A4947D94940
30204	1	4	\N	19	36273	\N	51.636556662854801	г.Воронеж, ул.Баррикадная, д.9а	Россия, Воронежская область, Воронеж, улица Баррикадная	0101000020E610000001F73C7FDAA243401B8524B37AD14940
30202	1	4	\N	19	36273	\N	51.636498142509403	г.Воронеж, ул.Баррикадная, д.43а	Россия, Воронежская область, Воронеж, улица Баррикадная, 41	0101000020E6100000363AE7A738A2434016FC36C478D14940
30067	1	4	\N	19	36337	\N	51.716084000000002	г.Воронеж, ул.Артамонова, д.38		0101000020E61000006E3315E291A243402D98F8A3A8DB4940
30183	1	4	\N	19	36296	\N	51.656796999999997	г.Воронеж, ул.Арзамасская, д.4		0101000020E610000021E692AAED9E4340328E91EC11D44940
30292	1	4	\N	19	36238	\N	51.710040999999997	г.Воронеж, ул.Арбатская (9 Января), д.66		0101000020E6100000F7AE415F7A894340D9E89C9FE2DA4940
30930	1	4	\N	19	37017	\N	51.673124536502101	сл.Подгорное, ул.3 Интернационала, д.83	Россия, Воронежская область, Воронеж, улица III Интернационала	0101000020E61000009EB29AAE279843405C8FC2F528D64940
31278	1	4	\N	19	36285	\N	51.685321999999999	г.Воронеж, ул.9 января, 290		0101000020E6100000FE28EACC3D9043405A9D9CA1B8D74940
30297	1	4	\N	19	36285	\N	51.679274999999997	г.Воронеж, ул.9 Января, д.221д		0101000020E6100000DBBFB2D2A4904340C5FEB27BF2D64940
30255	1	4	\N	19	36285	\N	51.670065000000001	г.Воронеж, ул.9 Января, д.103		0101000020E61000001D588E9081944340DD989EB0C4D54940
30254	1	4	\N	19	36285	\N	51.674661999999998	г.Воронеж, ул.9 Января, д.161		0101000020E610000088F71C588E9243404EED0C535BD64940
30253	1	4	\N	19	36285	\N	51.676935	г.Воронеж, ул.9 Января, д.205		0101000020E61000007638BA4A7791434046425BCEA5D64940
30240	1	4	\N	19	36285	\N	51.663915000000003	г.Воронеж, ул.9 Января, д.46		0101000020E6100000EC67B114C99743407429AE2AFBD44940
30238	1	4	\N	19	36285	\N	51.661842	г.Воронеж, ул.9 Января, д.36		0101000020E6100000ED0DBE3099984340438F183DB7D44940
30096	1	4	\N	19	36285	\N	51.687030999999998	г.Воронеж, ул. 9 Января, 296		0101000020E6100000F433F5BA45904340492BBEA1F0D74940
30095	1	4	\N	19	36285	\N	51.681736999999998	г.Воронеж, ул. 9 Января, 270		0101000020E61000000647C9AB7390434090BC732843D74940
30094	1	4	\N	19	36285	\N	51.677700000000002	г.Воронеж, ул. 9 Января, 220/А		0101000020E6100000EC8497E0D4914340E63FA4DFBED64940
30090	1	4	\N	19	36285	\N	51.672992000000001	г.Воронеж, ул. 9 Января, 134		0101000020E6100000C974E8F4BC9343401D3C139A24D64940
30088	1	4	\N	19	36285	\N	51.670293999999998	г.Воронеж, 9 Января, 108		0101000020E6100000467BBC900E9543403E5A9C31CCD54940
31277	1	4	\N	19	36252	\N	51.714142212373602	г.Воронеж, ул.60-летия ВЛКСМ, 27	Россия, Воронежская область, Воронеж, улица 60 лет ВЛКСМ, 29	0101000020E61000003B1BF2CF0C9443409B594B0169DB4940
30118	1	4	\N	19	36278	\N	51.695869000000002	г.Воронеж, 45 стрелковой дивизии, 102		0101000020E6100000F0C16B97369843406EA6423C12D94940
30098	1	4	\N	19	36278	\N	51.694099000000001	г.Воронеж, ул. 45 стрелковой дивизии, 230/А		0101000020E61000009510ACAA97914340D9976C3CD8D84940
30097	1	4	\N	19	36278	\N	51.689872999999999	г.Воронеж, ул. 45 стрелковой дивизии, 275/А		0101000020E6100000206118B0E49043405BB22AC24DD84940
30493	1	4	\N	19	36289	\N	51.670617999999997	пос.Колодезный, ул.40 лет Октября, д.10а		0101000020E61000006612F5824F974340F10D85CFD6D54940
30107	1	4	\N	19	36253	\N	51.691664830523301	г.Воронеж, ул. 303 стрелковой дивизии, 2/А	Россия, Воронежская область, Воронеж, улица 303 Стрелковой Дивизии	0101000020E6100000D50968226C964340D8648D7A88D84940
30060	1	4	\N	19	36328	\N	51.695132000000001	г.Воронеж, ул.25 Января, д.40		0101000020E6100000C93CF20703A143409833DB15FAD84940
30207	1	4	\N	19	36203	\N	51.551856999999998	г.Воронеж, ул.206 Стрелковой Дивизии, д.308		0101000020E6100000E3C281902C9E4340CA880B40A3C64940
30233	1	4	\N	19	36274	\N	51.646951000000001	г.Воронеж, ул.20-летия Октября, д.84/А		0101000020E6100000AEF36F97FD984340A88E554ACFD24940
30232	1	4	\N	19	36274	\N	51.644855	г.Воронеж, ул.20-летия Октября, д.38/в		0101000020E61000003C670B08AD994340BFD4CF9B8AD24940
30229	1	4	\N	19	36274	\N	51.649912999999998	г.Воронеж, ул.20-летия Октября, д.93		0101000020E6100000C07630629F984340641F645930D34940
30228	1	4	\N	19	36274	\N	51.648671999999998	г.Воронеж, ул.20-летия Октября, д.95		0101000020E6100000685E0EBBEF9843405BEA20AF07D34940
30102	1	4	\N	19	36366	\N	51.702406000000003	г.Воронеж, ул. Хользунова, 106		0101000020E610000037A79201A0924340D1419770E8D94940
29937	1	4	\N	54256	36144	\N	50.829456	г.Бутурлиновка, ул.Маяковского, д.73		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29934	1	4	\N	54256	35747	\N	50.829456	г.Бутурлиновка, ул.Ленина, д.254		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29933	1	4	\N	54256	35747	\N	50.829456	г.Бутурлиновка, ул.Ленина, д.153		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29932	1	4	\N	54256	35747	\N	50.829456	г.Бутурлиновка, ул.Ленина, д.28		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29927	1	4	\N	54256	35747	\N	50.830359885488399	г.Бутурлиновка, ул.Ленина, д.12		0101000020E6100000F1F44A59864C44400AF4893C496A4940
29938	1	4	\N	54256	36125	\N	50.829456	г.Бутурлиновка, ул.Заводская, д.54		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29939	1	4	\N	54256	36036	\N	50.829456	г.Бутурлиновка, ул.Дорожная, д.14		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29894	1	4	\N	11742	35776	\N	51.365285	г.Борисоглебск, ул.Чкалова, д.55	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29910	1	4	\N	11742	36044	\N	51.365285	г.Борисоглебск, ул.Рубежная, д.24	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29908	1	4	\N	11742	36379	\N	51.365285	г.Борисоглебск, пос.Водострой, д.10		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29882	1	4	\N	11742	36148	\N	51.365285	г.Борисоглебск, пер.Сенной, д.30	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29905	1	4	\N	11742	35791	\N	51.365285	г.Борисоглебск, пер.Куйбышева, д.1		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29901	1	4	\N	11742	36059	\N	51.365285	г.Борисоглебск, пер.Гражданский, д.9		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29888	1	4	\N	11742	36533	\N	51.365285	г.Борисоглебск, пер.Суровикина, д.1/48	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29890	1	4	\N	11742	35985	\N	51.365285	г.Борисоглебск, ул.Народная, д.43	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29880	1	4	\N	11742	36040	\N	51.365285	г.Борисоглебск, ул.Бланская, д.117	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29907	1	4	\N	11742	35986	\N	51.365285	г.Борисоглебск, Юго-восточный м/р-н, д.19		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29906	1	4	\N	11742	35986	\N	51.365285	г.Борисоглебск, Юго-восточный м/р-н, здание учебного корпуса  ПУ 34	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29898	1	4	\N	11742	35790	\N	51.365285	г.Борисоглебск, ул.Чкалова, д.3		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29895	1	4	\N	11742	35789	\N	51.365285	г.Борисоглебск, ул.Третьяковская, д.14		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29899	1	4	\N	11742	35788	\N	51.365285	г.Борисоглебск, ул.Советская, д.123		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29893	1	4	\N	11742	35788	\N	51.365285	г.Борисоглебск, ул.Советская, д.58		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29892	1	4	\N	11742	35788	\N	51.367758685230299	г.Борисоглебск, ул.Советская, д.47	Россия, Воронежская область, Борисоглебск городской округ	0101000020E610000007280D350A094540A3E716BA12AF4940
29891	1	4	\N	11742	35788	\N	51.370095728749398	г.Борисоглебск, ул.Советская, д.13	Россия, Воронежская область, Борисоглебск	0101000020E6100000D7BD1589090E4540B130444E5FAF4940
29889	1	4	\N	11742	35788	\N	51.365285	г.Борисоглебск, ул.Советская, д.15		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29886	1	4	\N	11742	35787	\N	51.365285	г.Борисоглебск, Северный м/р-н, д.10		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29881	1	4	\N	11742	35787	\N	51.365285	г.Борисоглебск, Северный м/р-н, д.30	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29885	1	4	\N	11742	35826	\N	51.365285	г.Борисоглебск, Северный м/р-н, д.41		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29904	1	4	\N	11742	35949	\N	51.365285	г.Борисоглебск, ул.Проходная, д.4а	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29897	1	4	\N	11742	36478	\N	51.359210859417402	г.Борисоглебск, ул.Первомайская, д.65	Россия, Воронежская область, Борисоглебск	0101000020E61000001938A0A52B0E454086AE44A0FAAD4940
29902	1	4	\N	11742	35903	\N	51.353478625772397	г.Борисоглебск, ул.Металлистов, д.4	Россия, Воронежская область, Борисоглебск городской округ	0101000020E61000004F948444DA0A45405169C4CC3EAD4940
29884	1	4	\N	11742	35898	\N	51.3804531634255	г.Борисоглебск, ул.Матросовская, д.115а	Россия, Воронежская область, Борисоглебск городской округ	0101000020E61000007AE40F069E0F4540225514AFB2B04940
29883	1	4	\N	11742	35898	\N	51.365285	г.Борисоглебск, ул.Матросовская, д.117		0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
30340	1	4	\N	11742	36816	\N	51.364975000000001	пос.Теллермановский, ул.Корнаковского, д.9		0101000020E61000004205871744064540C66D3480B7AE4940
29887	1	4	\N	11742	35848	\N	51.372889278607801	г.Борисоглебск, ул.Дубровинская, д.127	Россия, Воронежская область, Борисоглебск городской округ	0101000020E610000068CEFA9463084540E204A6D3BAAF4940
29896	1	4	\N	11742	36556	\N	51.365285	г.Борисоглебск, ул.Бланская, д.54	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29900	1	4	\N	11742	36179	\N	51.374527723323503	г.Борисоглебск, ул.Аэродромная, д.15а		0101000020E61000008E0244C18C0D4540D8B79388F0AF4940
29911	1	4	\N	11742	35683	\N	51.365995330037499	г.Борисоглебск, ул.40 лет Октября, д.309	Россия, Воронежская область, Борисоглебск	0101000020E61000003BC780ECF50C4540F0BF95ECD8AE4940
29903	1	4	\N	11742	35683	\N	51.365285	г.Борисоглебск, ул.40 лет Октября, д.27а	Россия, Воронежская область, Борисоглебск	0101000020E610000092B1DAFCBF0C4540145CACA8C1AE4940
29836	1	4	\N	54328	36665	\N	49.934590999999998	г.Богучар, ул.Дзержинского, д.174		0101000020E610000022A7AFE76B46444066118AADA0F74840
30638	1	4	\N	54290	36219	\N	51.685312135381999	с.Бабяково, ул.Советская, д.5		0101000020E6100000401361C3D3AF434037C7B94DB8D74940
29796	1	4	\N	54259	35825	\N	51.093232	Воронежская область, г.Бобров, ул.Революционная, д.149		0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29794	1	4	\N	54259	35824	\N	51.093232	Воронежская область, г.Бобров, ул.60 лет Октября, д.20		0101000020E6100000A7052FFA0A0644406878B306EF8B4940
31257	1	4	1280	14491	36966	\N	51.845447999999998	с.Ячейка, ул.Ф.Усова, д.1А		0101000020E610000018EB1B98DC4C4440FB3BDBA337EC4940
31267	1	4	1280	14627	36012	\N	51.847067000000003	г.Эртиль, ул.Степная, д.1	Россия, Воронежская область, Эртильский район, Эртиль	0101000020E610000007EC6AF294674440AB4203B16CEC4940
31265	1	4	1280	14627	36550	\N	51.847067000000003	г. Эртиль, пл.Ленина, д.2		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31275	1	4	1280	14627	37025	\N	51.847067000000003	г.Эртиль, ул.Пионерская, д.117		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31261	1	4	1280	14627	36583	\N	51.847067000000003	г.Эртиль, ул.Первомайская, д.19 (второй этаж)		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31260	1	4	1280	14627	36583	\N	51.847067000000003	г. Эртиль, ул.Первомайская, д.19 (первый этаж)	Россия, Воронежская область, Эртильский район, Эртиль	0101000020E610000007EC6AF294674440AB4203B16CEC4940
31268	1	4	1280	14627	36580	\N	51.847067000000003	г.Эртиль, ул.Лесная, д.1б		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31274	1	4	1280	14627	36415	\N	51.847067000000003	г.Эртиль, ул.Комарова, д.19		0101000020E610000007EC6AF294674440AB4203B16CEC4940
31262	1	4	1280	14627	36532	\N	51.839943436279498	г.Эртиль, ул.9 Мая, д.48	Россия, Воронежская область, Эртильский район, Эртиль	0101000020E6100000E3FDB8FDF267444087C0914083EB4940
31248	1	4	1280	49160	35794	\N	51.759498000000001	с.Щучье, ул.Ленина, д.38		0101000020E610000081ECF5EE8F4144404FB0FF3A37E14940
31246	1	4	1280	54345	36706	\N	51.760311996605402	с. Щучинские Пески, ул.Советская, д.68 А	Россия, Воронежская область, Эртильский район, поселок Щученские Пески	0101000020E61000003221E692AA434440D06053E751E14940
30952	1	4	1280	48004	\N	\N	51.660539999999997	с.Сергеевка, здание дома культуры	Россия, Воронежская область, Эртильский район, поселок Сергеевка	0101000020E610000022533E04555D444094D920938CD44940
31235	1	4	1280	48949	37077	\N	51.597616000000002	с. Ростоши, ул.Ленинская, д.126		0101000020E61000006D3CD862B77744407EC85BAE7ECC4940
31234	1	4	1280	48949	36189	\N	51.597616000000002	с. Ростоши, ул.Ленинская, д.5		0101000020E61000006D3CD862B77744407EC85BAE7ECC4940
31238	1	4	1280	54433	37230	\N	51.731996000000002	пос.Перво-Эртиль, ул.Центральная, д.35	Россия, Воронежская область, Эртильский район, поселок Первоэртиль	0101000020E610000029E78BBD17694440C366800BB2DD4940
31269	1	4	1280	49453	36884	\N	51.816195	пос.Мичуринский, ул.Докучаева, д.12		0101000020E6100000B3D30FEA226944405114E81379E84940
31258	1	4	1280	46394	37413	\N	51.911382000000003	пос.Марьевка, ул.Советская, д.21	Россия, Воронежская область, Эртильский район, поселок Марьевка	0101000020E610000080F3E2C4575B4440E014562AA8F44940
31272	1	4	1280	15180	\N	\N	51.839382999999998	"""пос.МТФ """"Восход"""", здание поселкового клуба"""	Россия, Воронежская область, Эртильский район, поселок МТФ	0101000020E610000075AE282504614440C0E8F2E670EB4940
31270	1	4	1280	46183	36546	\N	51.823577	пос.Красноармейский, ул.Гагарина, д.10	Россия, Воронежская область, Эртильский район, поселок Красноармейский	0101000020E61000006BD784B4C6644440705E9CF86AE94940
31233	1	4	1280	13384	37022	\N	51.653629000000002	с.Копыл, ул.Ленина, д.31		0101000020E6100000098B8A389D844440CD5B751DAAD34940
29954	1	4	1280	15226	37274	\N	51.878619	с.Колодеевка, ул.Советская, д.118		0101000020E6100000CDE49B6D6E38444076525F9676F04940
31240	1	4	1280	49052	67127	\N	51.735616	пос.Дмитриевка, ул.Фрунзе, д.56		0101000020E6100000E48233F8FB674440093543AA28DE4940
31239	1	4	1280	13671	37023	\N	51.693368	пос.Дзержинский, ул.Школьная, здание бывшей начальной школы		0101000020E6100000E8DEC325C76F4440E50B5A48C0D84940
31255	1	4	1280	49262	37130	\N	51.862054000000001	дер.Грязцы, ул.Рабочая, д.9		0101000020E610000041EF8D210036444068B114C957EE4940
31253	1	4	1280	14325	37117	\N	51.929796000000003	с.Вязковка, ул.Советская, д.48		0101000020E610000018B14F00C5424440CFF9298E03F74940
31140	1	4	1280	47185	37336	\N	51.788303999999997	пос.Вознесеновка, ул.Центральная, д.44		0101000020E6100000FF23D3A1D36744402AA73D25E7E44940
30542	1	4	1280	54406	37187	\N	51.777029395223202	с.Владимировка, Молодежная-1, 19, Владимирский сельский клуб	Россия, Воронежская область, Эртильский район, поселок Владимировка	0101000020E61000007BBC900E0F5F44409485AFAF75E34940
31237	1	4	1280	48998	37180	\N	51.717027000000002	пос.Введенка, ул.Восточная, д.34 А		0101000020E610000031ED9BFBAB6B4440ACAC6D8AC7DB4940
31236	1	4	1280	13491	37079	\N	51.686886000000001	дер.Буравцовка, ул.Молодежная, д.14		0101000020E6100000AFD2DD75367A4440460A65E1EBD74940
31247	1	4	1280	14041	36375	\N	51.702333000000003	с.Борщевские Пески, ул.Центральная, д.74		0101000020E6100000637B2DE8BD45444067F3380CE6D94940
31254	1	4	1280	49243	36581	\N	51.905532000000001	с.Большой Самовец, ул.Школьная, д.15	Россия, Воронежская область, Эртильский район, поселок Большой Самовец	0101000020E61000006DFFCA4A933C4440A1BDFA78E8F34940
31259	1	4	1280	14615	36787	\N	51.878753000000003	с.Большая Добринка, ул.Центральная, д.42		0101000020E610000079CBD58F4D6C4440862172FA7AF04940
31252	1	4	1280	14253	36784	\N	51.864195000000002	с.Битюг-Матреновка, ул.Центральная, д.8		0101000020E6100000EE5F5969523E4440F12E17F19DEE4940
31232	1	4	1280	47160	37357	\N	51.686171000000002	с.Александровка, ул.Центральная, д.31		0101000020E610000018080264E8824440583B8A73D4D74940
29988	1	4	1280	47160	37282	\N	51.686171000000002	с.Александровка, ул.Ленина, д.40а		0101000020E610000018080264E8824440583B8A73D4D74940
31226	1	4	986	13032	36542	\N	51.300834000000002	с.Яблочное, пер.Школьный, д.5	Россия, Воронежская область, Хохольский район, поселок Яблочное	0101000020E6100000247B849A218143402FC37FBA81A64940
31202	1	4	986	11827	36412	\N	51.576076999999998	р.п.Хохольский, ул.Мира, д.26		0101000020E61000007973B8567B644340287D21E4BCC94940
31200	1	4	986	11827	35957	\N	51.576076999999998	р.п.Хохольский, ул.Ленина, д.6		0101000020E61000007973B8567B644340287D21E4BCC94940
31201	1	4	986	11827	35821	\N	51.576076999999998	р.п.Хохольский, ул.Заводская, д.88		0101000020E61000007973B8567B644340287D21E4BCC94940
31203	1	4	986	11827	35765	\N	51.576076999999998	р.п.Хохольский, ул.Дружбы, д.30		0101000020E61000007973B8567B644340287D21E4BCC94940
31207	1	4	986	12028	\N	\N	51.574308000000002	"с.Хохол, Здание дома животноводов МТФ2 СПК ""Восход"""	Россия, Воронежская область, Хохольский район, поселок Хохол	0101000020E61000005A83F755B966434064EAAEEC82C94940
31204	1	4	986	12028	35820	\N	51.574308000000002	с.Хохол, пер.Советский, д.3		0101000020E61000005A83F755B966434064EAAEEC82C94940
31208	1	4	986	12028	36544	\N	51.571420936663202	с.Хохол, пер.Сосновый, д.3	Россия, Воронежская область, Хохольский район, поселок Хохол	0101000020E6100000CE6F986890604340B29FC55224C94940
31205	1	4	986	12028	36918	\N	51.572062763841799	с.Хохол, ул.Красноармейская, д.37	Россия, Воронежская область, Хохольский район, поселок Хохол	0101000020E6100000D40FEA22856043403620425C39C94940
31206	1	4	986	12028	35720	\N	51.574308000000002	с.Хохол, ул.Верхняя Слобода, д.4	Россия, Воронежская область, Хохольский район, поселок Хохол	0101000020E61000005A83F755B966434064EAAEEC82C94940
31214	1	4	986	48564	36416	\N	51.454411999999998	с.Староникольское, ул.Веры Чуркиной, д.3		0101000020E6100000A04FE449D25F43407974232C2ABA4940
31213	1	4	986	48564	36416	\N	51.454411999999998	с.Староникольское, ул.Веры Чуркиной, д.63		0101000020E6100000A04FE449D25F43407974232C2ABA4940
31212	1	4	986	48564	36416	\N	51.454411999999998	с.Староникольское, ул.Веры Чуркиной, д.115а		0101000020E6100000A04FE449D25F43407974232C2ABA4940
31216	1	4	986	12629	36783	\N	51.323118000000001	с.Семидесятное, ул.Бабенко, д.18		0101000020E61000007F677BF4865F4340DD5F3DEE5BA94940
31224	1	4	986	12938	36460	\N	51.432485	с.Рудкино, ул.Школьная, д.1а	Россия, Воронежская область, Хохольский район, поселок Рудкино	0101000020E6100000D462F030ED8343405A8121AB5BB74940
31218	1	4	986	54408	37192	\N	51.595390924422603	с.Петино, ул.Советская, д.1 А	Россия, Воронежская область	0101000020E6100000F183F3A9637F434097AAB4C535CC4940
31227	1	4	986	48828	36543	\N	51.246189000000001	с.Оськино, ул.Советская, д.79	Россия, Воронежская область, Хохольский район, поселок Оськино	0101000020E61000009702D2FE0784434046D1031F839F4940
31231	1	4	986	54318	36545	\N	51.603703000000003	пос.Опытная Станция, ул.Чаянова, д.13	Россия, Воронежская область, Хохольский район, поселок Опытная станция ВНИИК	0101000020E61000001F662FDB4E7D4340A1BFD02346CD4940
31211	1	4	986	12356	37128	\N	51.469400999999998	с.Никольское-на-Еманче, ул.Центральная, д.170а		0101000020E6100000D50627A25F6D4340D7DAFB5415BC4940
31215	1	4	986	48610	36920	\N	51.353586	с.Кочетовка, ул.Центральная, д.100		0101000020E6100000B58828266F6643406729594E42AD4940
31225	1	4	986	12995	36046	\N	51.383298000000003	с.Костёнки, ул.Набережная, д.136		0101000020E61000008177F2E9B1854340A54FABE80FB14940
31210	1	4	986	12309	37127	\N	51.556201999999999	с.Еманча 1-я, ул.Центральная, д.18		0101000020E6100000DE3AFF76D973434022FC8BA031C74940
31223	1	4	986	48758	37133	\N	51.502631000000001	с.Дмитриевка, ул.Советская, д.25	Россия, Воронежская область, Хохольский район, поселок Дмитриевка	0101000020E61000000AA0185932774340577A6D3656C04940
31222	1	4	986	48729	36220	\N	51.476250999999998	с.Гремячье, ул.Чехова, д.9а	Россия, Воронежская область, Хохольский район, поселок Гремячье	0101000020E6100000435376FA41814340F9D7F2CAF5BC4940
31221	1	4	986	48729	37075	\N	51.476250999999998	с.Гремячье, ул.Ленина, д.59		0101000020E6100000435376FA41814340F9D7F2CAF5BC4940
31209	1	4	986	45990	37015	\N	51.500517000000002	"""с.Верхненикольское, ул. Свердлова, д.41б, Здание Верхненикольского филиала МОУ """"Хохольская СОШ"""""""		0101000020E6100000D32D3BC43F504340C80BE9F010C04940
31228	1	4	986	45878	37373	\N	51.341479999999997	с.Борщёво, ул.Архипова, д.35		0101000020E6100000DF878384288F4340791EDC9DB5AB4940
30848	1	4	986	45878	37344	\N	51.341479999999997	с.Борщево, ул.Гагарина, д.11		0101000020E6100000DF878384288F4340791EDC9DB5AB4940
31126	1	4	986	8349	36849	\N	51.588121000000001	пос.Бахчеево, пер.Школьный, д.3		0101000020E6100000147B681F2B6C4340A08B868C47CB4940
31229	1	4	986	48858	37312	\N	51.262158999999997	с.Архангельское, ул.Центральная, д.2		0101000020E610000033FD12F1D691434010AD156D8EA14940
31175	1	4	1131	10639	\N	\N	51.750900999999999	дер.Чубровка, здание ФАП	Россия, Воронежская область, Терновский район, поселок Чубровка	0101000020E6100000AD50A4FB39C9444050C422861DE04940
31194	1	4	1131	45846	36208	\N	51.682758193854099	с.Терновка, ул.Советская, д.51	Россия, Воронежская область, Терновский район, поселок Терновка	0101000020E6100000BB6246787BCC44408B8A389D64D74940
31195	1	4	1131	45846	36055	\N	51.680807788096701	с.Терновка, ул.Первомайская, д.110	Россия, Воронежская область, Терновский район, поселок Терновка	0101000020E610000060C8EA56CFC94440766D6FB724D74940
31199	1	4	1131	45846	36085	\N	51.686015600114303	с.Терновка, ул.Октябрьская, д.22	Россия, Воронежская область, Терновский район, поселок Терновка	0101000020E6100000338B506C05CB444031444E5FCFD74940
31196	1	4	1131	45846	37064	\N	51.674327435510797	с.Терновка, ул.Звездная, д.15	Россия, Воронежская область, Терновский район, поселок Терновка	0101000020E6100000CB694FC939D14440A7E7DD5850D64940
31193	1	4	1131	48217	37283	\N	51.688740000000003	с.Тамбовка, ул.Школьная, д.3		0101000020E61000004AB4E4F1B48C444039B9DFA128D84940
31190	1	4	1131	45490	36430	\N	51.712122000000001	с.Русаново, ул.Советская, д.7		0101000020E6100000166C239EECBC44408D614ED026DB4940
31191	1	4	1131	45490	37242	\N	51.712122000000001	"с.Русаново, ул.Проезжая, д. 110, здание магазина ""Наш"""		0101000020E6100000166C239EECBC44408D614ED026DB4940
31187	1	4	1131	47846	37085	\N	51.520394000000003	с.Ржавец, ул.Проезжая, д. 7  здание медицинского пункта		0101000020E61000000CB265F9BAD044406F8445459CC24940
31192	1	4	1131	54394	37170	\N	51.748719086161501	с.Поляна, ул.Школьная,  д 8, здание школы		0101000020E61000000C5A48C0E8BA444069723106D6DF4940
31188	1	4	1131	46835	37176	\N	51.660088000000002	с.Новотроицкое, ул.Паринского, д.55	Россия, Воронежская область, Терновский район, поселок Новотроицкое	0101000020E6100000643C4A253CB74440B43D7AC37DD44940
31186	1	4	1131	11179	36788	\N	51.558239999999998	с.Новокирсановка, ул.Центральная, д.65		0101000020E61000004548DDCEBED04440D6A8876874C74940
31185	1	4	1131	49564	37131	\N	51.726317382814102	с.Николаевка, ул.Октябрьская, д.164	Россия, Воронежская область, Терновский район, поселок Николаевка	0101000020E6100000A1496249B99D4440B1C398F4F7DC4940
31171	1	4	1131	10479	37178	\N	51.689822999999997	дер.Никитская, ул.Центральная, д.1б		0101000020E6100000B3614D6551E44440A983BC1E4CD84940
31183	1	4	1131	11031	36499	\N	51.581007999999997	с.Народное, ул.Центральная, д.42	Россия, Воронежская область, Терновский район, поселок Народное	0101000020E610000096CFF23CB8E54440705B5B785ECA4940
31178	1	4	1131	10822	\N	\N	51.592725999999999	пос.Луначаровка,  д 4 а, здание ФАП		0101000020E6100000E3FE23D3A189444094BE1072DECB4940
31184	1	4	1131	48039	36498	\N	51.573417999999997	с.Липяги, ул.Набережная, д.43	Россия, Воронежская область, Терновский район, поселок Липяги	0101000020E610000014048F6FEFEA44400778D2C265C94940
31181	1	4	1131	10949	36043	\N	51.538530999999999	с.Костино-Отделец, ул.Лениская, д.11		0101000020E6100000768D96033DBA4440EB707495EEC44940
31108	1	4	867	46535	36778	\N	51.838293	с.Меловатка, ул.Центральная, д.29		0101000020E6100000E0F60489ED5443409DBB5D2F4DEB4940
31179	1	4	1131	47946	36191	\N	51.667698740857603	с.Козловка, ул.Советская, д.71	Россия, Воронежская область, Терновский район, поселок Козловка	0101000020E6100000C38366D7BDA3444034492C2977D54940
31180	1	4	1131	47946	36781	\N	51.670930575167603	с.Козловка, ул.Горького, д.62	Россия, Воронежская область, Терновский район, поселок Козловка	0101000020E61000001A53B0C6D9A64440B16F2711E1D54940
31177	1	4	1131	47407	36818	\N	51.584204	с.Кисельное, ул.Советская,  172 здание школы		0101000020E6100000FA298E03AF924440A0185932C7CA4940
31174	1	4	1131	47739	35883	\N	51.760373000000001	с.Есипово, ул.Молодежная, д.11		0101000020E61000002618CE35CCC2444076E107E753E14940
29769	1	4	1131	47403	37387	\N	51.617640999999999	пос.Дубровка, ул.Солнечная, д.26а		0101000020E6100000E57FF277EF92444099D53BDC0ECF4940
31176	1	4	1131	47403	36599	\N	51.617640999999999	с.Дубровка, ул.Лесная, 7  здание школы	Россия, Воронежская область, Терновский район, поселок Дубровка	0101000020E6100000E57FF277EF92444099D53BDC0ECF4940
31198	1	4	1131	16029	37166	\N	51.629790999999997	дер.Долина,  ул. Садовая, здание отделения связи		0101000020E6100000F7AFAC3429C944405628D2FD9CD04940
31173	1	4	1131	10570	36616	\N	51.592261999999998	с.Братки, ул.Ленинская, д.3 а		0101000020E6100000BCCFF1D1E2BE4440EF54C03DCFCB4940
31197	1	4	1131	45871	37021	\N	51.613579999999999	дер.Бабино, ул.Комарова, здание отделения связи		0101000020E6100000BF7FF3E2C4CF444066BD18CA89CE4940
31172	1	4	1131	10441	37124	\N	51.622270999999998	с.Алешки, ул.Фруктовая, д.14		0101000020E61000002315C61682E24440E61F7D93A6CF4940
31170	1	4	1131	10441	36615	\N	51.622270999999998	с.Алешки, ул.Советская, д.1	Россия, Воронежская область, Терновский район, поселок Алешки	0101000020E61000002315C61682E24440E61F7D93A6CF4940
31169	1	4	1131	54367	36822	\N	51.628824000000002	с.Александровка, ул.Свободы, д.1	Россия, Воронежская область, Терновский район, поселок Александровка	0101000020E61000007347FFCBB5F444404F78094E7DD04940
31155	1	4	1006	60397	74952	\N	51.151423808356903	пос.Участок 4, ул.Центральная, д.26	Россия, Воронежская область, Таловский район, поселок Участок N4	0101000020E61000003B342C465D7544402DEA93DC61934940
31156	1	4	1006	54338	36698	\N	51.205018000000003	пос.Участок 26, ул.Проезжая, д.3	Россия, Воронежская область, Таловский район, поселок Участок N26	0101000020E610000088484DBB98704440B18BA2073E9A4940
31136	1	4	1006	60382	74931	\N	51.034469999999999	пос.2-го участка института им.Докучаева, кв-л 4, д.78	Россия, Воронежская область, Таловский район, поселок Участок N2 сельскохозяйственного НИИ имени Докучаева	0101000020E6100000A228D027F25E4440B858518369844940
31154	1	4	1006	54451	37255	\N	51.187679000000003	пос.Участок 12, ул.Мира, д.2а	Россия, Воронежская область, Таловский район, поселок Участок N12	0101000020E610000088BA0F406A674440B0928FDD05984940
31153	1	4	1006	9542	9962	\N	51.058259	пос.Утиновка, ул.Свободы, д.57		0101000020E6100000D76B7A50507044404DD9E90775874940
31151	1	4	1006	40379	36612	\N	50.970619999999997	пос.Терехово, ул.Центральная, д.33		0101000020E6100000F4FA93F8DC634440F86BB2463D7C4940
31161	1	4	1006	46932	\N	\N	51.117092	р.п.Таловая, ул.Чапаева, д.129	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E61000001ADB6B41EF5D4440C64FE3DEFC8E4940
31130	1	4	1006	46932	36153	\N	51.114808744869201	р.п.Таловая, пр-д Свободы, д.23	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E6100000317E1AF7E65D4440AB24B20FB28E4940
31167	1	4	1006	46932	35838	\N	51.120156849265598	р.п.Таловая, ул.Советская, д.6	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E6100000FF756EDA8C5F444057B1F84D618F4940
31131	1	4	1006	46932	35838	\N	51.119844755592901	р.п.Таловая, ул.Советская, д.182	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E6100000F69A1E14945C444068CBB914578F4940
31129	1	4	1006	46932	35838	\N	51.120573998490002	р.п.Таловая, ул.Советская, д.134	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E6100000F6402B30645D4440BB5F05F86E8F4940
31127	1	4	1006	46932	35838	\N	51.119930015080001	р.п.Таловая, ул.Советская, д.147	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E6100000A20914B1885F444096E7C1DD598F4940
31128	1	4	1006	46932	36183	\N	51.116375424037798	р.п.Таловая, ул.Садовая, д.39	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E610000033DC80CF0F5D444037894160E58E4940
31168	1	4	1006	46932	35958	\N	51.110822793852499	р.п.Таловая, ул.Пролетарская, д.180	Россия, Воронежская область, Таловский район, поселок Таловая	0101000020E61000001D554D10755D44408352B4722F8E4940
31163	1	4	1006	10050	36614	\N	51.259273	с.Синявка, ул.Советская, д.6	Россия, Воронежская область, Таловский район, поселок Синявка	0101000020E610000015747B49637E44402FDE8FDB2FA14940
31217	1	4	\N	\N	37034	\N	51.607665403440897	"""пос.Орловка, ул.Центральная, д.16 Здание МОУ """"Орловская СОШ"""""""	Россия, Воронежская область	0101000020E61000007A1B9B1DA980434040F67AF7C7CD4940
31137	1	4	1006	46021	37034	\N	51.022590752985998	с.Орловка, ул.Центральная, д.133	Россия, Воронежская область, Таловский район, поселок Орловка	0101000020E610000022C2BF081A4544408B170B43E4824940
31138	1	4	1006	46021	37165	\N	51.022103999999999	с.Орловка, ул.Заречная, д.114		0101000020E6100000A05225CADE4444402E8ECA4DD4824940
31148	1	4	1006	9326	36639	\N	51.1821284676411	пос.Новотроицкий, ул.Центральная, д.1а	Россия, Воронежская область, Таловский район, поселок Новотроицкий	0101000020E6100000BC218D0A9C5C4440CBD765F84F974940
31132	1	4	1006	54490	37417	\N	51.1454854820172	хут.Новенький, ул.Солнечная, д.25	Россия, Воронежская область, Таловский район, поселок Новенький	0101000020E6100000BC22F8DF4A6044407F87A2409F924940
31142	1	4	1006	9021	36176	\N	51.221075999999996	с.Новая Чигла, ул.Ленинская, д.66	Россия, Воронежская область, Таловский район, поселок Новая Чигла	0101000020E61000002CF180B2293D44401AF7E6374C9C4940
31141	1	4	1006	9021	36588	\N	51.221075999999996	с.Новая Чигла, ул.Садовая, д.20		0101000020E61000002CF180B2293D44401AF7E6374C9C4940
31107	1	4	867	46533	37238	\N	51.851590999999999	с.Медвежье, ул.Центральная, д.64		0101000020E6100000BE4C1421757D4340B24813EF00ED4940
31139	1	4	1006	47182	36682	\N	51.110323999999999	с.Никольское, просп.Революции, д.92а	Россия, Воронежская область, Таловский район, поселок Никольское	0101000020E61000003882548A1D39444061FBC9181F8E4940
31152	1	4	1006	47448	36459	\N	51.125442999999997	пос.Нижняя Каменка, ул.Центральная, д.62	Россия, Воронежская область, Таловский район, поселок Нижняя Каменка	0101000020E610000058CA32C4B16A44408D4127840E904940
31149	1	4	1006	47391	37125	\N	50.998114999999999	пос.Михинский, ул.Центральная, д.88		0101000020E610000052B648DA8D5A4440D252793BC27F4940
30865	1	4	1006	46251	37057	\N	51.113348999999999	пос.Михайловский, пер.Цветочный, д.5		0101000020E6100000E4F8A1D28847444064045438828E4940
31133	1	4	1006	47059	36960	\N	51.119410999999999	пос.Коминтерн, ул.Молодежная, д.4		0101000020E6100000755AB741ED5144402EE411DC488F4940
31166	1	4	1006	47695	37263	\N	51.130637	пос.Козловский, ул.Набережная, д.11	Россия, Воронежская область, Таловский район, поселок Козловский	0101000020E6100000E6797077D67C4440E35295B6B8904940
31157	1	4	1006	9780	36472	\N	51.249374000000003	пос.Казанка, ул.Центральная, д.37	Россия, Воронежская область, Таловский район, поселок Казанка	0101000020E61000001E1A16A3AE654440823CBB7CEB9F4940
31160	1	4	1006	54387	37029	\N	51.296988146666799	пос.Еланка, ул.Мира, д.17	Россия, Воронежская область, Таловский район, поселок Еланка	0101000020E610000038A1100187884440F8A6E9B303A64940
31164	1	4	1006	47656	36962	\N	51.317309000000002	с.Вязовка, ул.Центральная, д.119		0101000020E610000053211E8997834440FDDCD0949DA84940
31135	1	4	1006	54302	36275	\N	51.071226326902298	пос.Высокий, ул.Гагарина, д.23а	Россия, Воронежская область, Таловский район, поселок Высокий	0101000020E610000089B14CBF445C4440FD4FFEEE1D894940
31134	1	4	1006	8728	36401	\N	51.069738999999998	пос.Вознесенский, ул.Дужнова, д.36		0101000020E6100000FB5A971AA1554440BC202235ED884940
31143	1	4	1006	9098	36466	\N	51.324058000000001	с.Верхняя Тишанка, ул.Школьная, д.34	Россия, Воронежская область, Таловский район, поселок Верхняя Тишанка	0101000020E6100000ADF71BEDB8454440EB0088BB7AA94940
31144	1	4	1006	9098	36540	\N	51.324058000000001	с.Верхняя Тишанка, ул.Чеснокова, д.82	Россия, Воронежская область, Таловский район, поселок Верхняя Тишанка	0101000020E6100000ADF71BEDB8454440EB0088BB7AA94940
31145	1	4	1006	9098	36683	\N	51.324058000000001	с.Верхняя Тишанка, ул.Гагарина, д.2а		0101000020E6100000ADF71BEDB8454440EB0088BB7AA94940
31150	1	4	1006	9434	36850	\N	51.039493999999998	пос.Верхнеозерский, ул.Мичурина, д.3		0101000020E610000014CB2DAD865C4440B131AF230E854940
31146	1	4	1006	47309	36780	\N	51.345351000000001	с.Бирюч, ул.Колхозная, д.78		0101000020E61000004580D3BB785B44400952297634AC4940
29746	1	4	1006	46904	37223	\N	51.097254	с.Березовка, ул.Комсомольская, д.7		0101000020E610000026A60BB1FA634440DDB3AED1728C4940
31165	1	4	1006	10176	36917	\N	51.03349	пос.Анохинка, ул.Центральная, д.31		0101000020E610000086376BF0BE7C44401C5F7B6649844940
31147	1	4	1006	47352	36539	\N	51.217109999999998	с.Александровка, ул.Пятницкого, д.41	Россия, Воронежская область, Таловский район, поселок Александровка	0101000020E610000040F850A22557444039D1AE42CA9B4940
31159	1	4	1006	47623	36173	\N	51.210094197909697	пос.Абрамовка, ул.Ломоносова, д.112а	Россия, Воронежская область, Таловский район, поселок Абрамовка	0101000020E6100000613255302A894440FC8A355CE49A4940
31162	1	4	1006	47623	37401	\N	51.210276999999998	с.Абрамовка, ул.Ленина, д.83а		0101000020E610000041B8020AF5884440ED0C535BEA9A4940
31158	1	4	1006	47623	36068	\N	51.208692457391997	пос.Абрамовка, ул.Ленина, д.14а	Россия, Воронежская область, Таловский район, поселок Абрамовка	0101000020E6100000C8B1F50CE1884440EA77616BB69A4940
31219	1	4	867	48696	36684	\N	51.793562999999999	с.Устье, ул.Ленина, д.19		0101000020E61000006FF085C9545143406728EE7893E54940
30942	1	4	867	46179	\N	\N	51.745671000000002	пос.Терновое, здание школы	Россия, Воронежская область, Семилукский район, поселок Терновое	0101000020E610000043E55FCB2B834340AE49B72572DF4940
31100	1	4	867	46387	36161	\N	51.611728999999997	пос. Стрелица, ул.Победы, д. 18, МУК Стрелицкий городской Дом культуры		0101000020E6100000A818E76F42734340E481C8224DCE4940
31118	1	4	867	46387	35938	\N	51.611728999999997	пос.Стрелица, ул.Центральная, д.1		0101000020E6100000A818E76F42734340E481C8224DCE4940
31121	1	4	867	8079	37123	\N	51.841042000000002	с.Старая Ольшанка, ул.Ольшанская, д.4		0101000020E6100000F44D9A0645494340FE47A643A7EB4940
31120	1	4	867	7990	36913	\N	51.812821	с.Старая Ведуга, ул.Победы, д.132		0101000020E6100000D734EF38454543404240BE840AE84940
31119	1	4	867	7990	36681	\N	51.812821	с.Старая Ведуга, ул.Ленина, д.13		0101000020E6100000D734EF38454543404240BE840AE84940
31117	1	4	867	46728	37019	\N	51.813641460166899	с.Стадница, ул.Новая, л.1	Россия, Воронежская область, Семилукский район, поселок Стадница	0101000020E610000049641F6459604340A5D7666325E84940
31097	1	4	867	46305	37016	\N	51.858255	с.Серебрянка, ул.Школьная, д.27		0101000020E6100000FAD170CADC5E43407250C24CDBED4940
31090	1	4	867	54425	37215	\N	51.801917000000003	поселок совхоза Раздолье, ул.Школьная, д.9	Россия, Воронежская область, Семилукский район, поселок Раздолье	0101000020E6100000516C054D4B804340A08D5C37A5E64940
31112	1	4	867	46634	36959	\N	51.845453999999997	с.Перлевка, ул.Центральная, д.54		0101000020E6100000D52137C30D704340DD2230D637EC4940
31113	1	4	867	46634	36637	\N	51.845453999999997	с.Перлевка, ул.Транспортная, д.11		0101000020E6100000D52137C30D704340DD2230D637EC4940
31105	1	4	867	7363	36854	\N	52.077809999999999	с.Перекоповка, ул.Мира, д.40Е		0101000020E6100000CEA78E554A594340A0A696ADF5094A40
31094	1	4	867	6828	36576	\N	51.648885	пос.Орлов Лог, пер.Школьный, д.1	Россия, Воронежская область, Семилукский район, поселок Орлов Лог	0101000020E61000002AA73D25E77E4340B7EEE6A90ED34940
31111	1	4	867	7604	36575	\N	51.927686000000001	"с.Новосильское, ул.Струковская, д. 6, здание МУК ""Новосильский СДК"		0101000020E61000008ACA863595414340817A336ABEF64940
30003	1	4	867	47285	37126	\N	51.823604228358398	с.Никольское, ул.Станиславского, д.18	Россия, Воронежская область, Семилукский район, поселок Никольское	0101000020E61000007CD5CA845F4E43406A6D1ADB6BE94940
31110	1	4	867	7534	36413	\N	51.731521000000001	с.Нижняя Ведуга, ул.Ленина, д.68		0101000020E61000000F4240BE845443402AABE97AA2DD4940
31109	1	4	867	7534	36413	\N	51.731521000000001	с.Нижняя Ведуга, ул.Ленина, д.18		0101000020E61000000F4240BE845443402AABE97AA2DD4940
31104	1	4	867	7296	37175	\N	52.009034	с.Малая Покровка, Набережная, 58Е		0101000020E610000018CE35CCD0524340AA46AF0628014A40
30825	1	4	867	45426	\N	\N	51.735030000000002	с.Лосево, пл.Первомайская, 10А	Россия, Воронежская область, Семилукский район, поселок Лосево	0101000020E61000003C2F151BF36A434019CA897615DE4940
31102	1	4	867	45426	37353	\N	51.735030000000002	с.Лосево, ул.Школьная, д.6		0101000020E61000003C2F151BF36A434019CA897615DE4940
30827	1	4	867	45426	37393	\N	51.735030000000002	с.Лосево, Кахиповка, 29		0101000020E61000003C2F151BF36A434019CA897615DE4940
31099	1	4	867	7051	36111	\N	51.698303000000003	с.Латное, ул.Октябрьская, 53/1		0101000020E610000074EB353D287643406FD921FE61D94940
31125	1	4	867	8196	35716	\N	51.660657999999998	пос.Латная, пер.Заводской, д.1а	Россия, Воронежская область, Семилукский район, поселок Латная	0101000020E6100000E4BCFF8F137243409EEBFB7090D44940
31124	1	4	867	8196	35941	\N	51.660657999999998	пос.Латная, ул.Школьная, д.18		0101000020E6100000E4BCFF8F137243409EEBFB7090D44940
31123	1	4	867	8196	35941	\N	51.660657999999998	пос.Латная, ул.Школьная, д.16		0101000020E6100000E4BCFF8F137243409EEBFB7090D44940
31116	1	4	867	54444	37244	\N	51.781323	с.Кондрашовка, ул.Садовая, д.17	Россия, Воронежская область, Семилукский район, поселок Кондрашевка	0101000020E610000015E0BBCD1B5F43406A4E5E6402E44940
31098	1	4	867	46345	36912	\N	51.918720999999998	с.Казинка, ул.Молодежная, д.23		0101000020E61000004AD235936F4E4340FF9254A698F54940
31242	1	4	867	49091	37358	\N	52.044145	пос.Ивановка, ул.Центральная, д.26		0101000020E610000023A0C211A44C434016A4198BA6054A40
31096	1	4	867	6846	\N	\N	51.903376000000002	с.Землянск, пл.Леженина, 10	Россия, Воронежская область, Семилукский район, поселок Землянск	0101000020E610000086C613419C5D4340E3FE23D3A1F34940
31095	1	4	867	6846	35882	\N	51.903376000000002	с.Землянск, Садовая, 11		0101000020E610000086C613419C5D4340E3FE23D3A1F34940
31115	1	4	867	7784	35837	\N	51.713991999999998	с.Ендовище, ул.Калинина, д.16а		0101000020E610000010B22C98F87F434085CD001764DB4940
30355	1	4	867	45956	37324	\N	52.011074000000001	с.Дмитриевка, ул.Центральная, д.20		0101000020E61000007E022846965C4340FFEA71DF6A014A40
31092	1	4	867	46198	\N	\N	51.631456999999997	с.Девица, пер.Ровенки, 48	Россия, Воронежская область, Семилукский район, поселок Девица	0101000020E6100000802898310579434046EA3D95D3D04940
31093	1	4	867	46198	35835	\N	51.633379659806003	с.Девица, ул.Танкистов, д.108	Россия, Воронежская область, Семилукский район, поселок Девица	0101000020E610000056444DF4F978434062F8889812D14940
30998	1	4	867	48844	36634	\N	51.768104000000001	с.Губарево, ул.Вислевского, д.47		0101000020E61000009D9FE238F0844340A1F65B3B51E24940
31101	1	4	867	46407	36541	\N	51.747872999999998	с.Гремячий Колодезь, ул.Школьная, д.1а	Россия, Воронежская область, Семилукский район, поселок Гремячий Колодезь	0101000020E6100000C30FCEA78E634340DC476E4DBADF4940
31088	1	4	867	6535	36908	\N	52.015315000000001	с.Голосновка, ул.Молодежная, д.1		0101000020E6100000CAFD0E4581484340B21188D7F5014A40
31087	1	4	867	49210	37163	\N	51.743493776684197	с.Гнилуша, ул.Центральная, д.7		0101000020E6100000785F950B95474340D862B7CF2ADF4940
31251	1	4	867	49210	37264	\N	51.741655999999999	с.Гнилуша, ул.Луговая, д.18		0101000020E61000003A90F5D4EA474340EB707495EEDE4940
14670	1	4	867	54397	37154	\N	51.968958822524698	с.Березовка, Ольшанка, д.79	Россия, Воронежская область, Семилукский район, поселок Березовка	0101000020E6100000E97E4E417E2A43401A1538D906FC4940
31064	1	4	538	54404	\N	\N	50.118194006992802	Воронежская область, Россошанский муниципальный район, п. Опытной Плодово-ягодной станции, 14	Россия, Воронежская область, Россошанский район	0101000020E6100000E6046D72F8D84340AE4A22FB200F4940
31073	1	4	538	5730	37055	\N	49.920724999999997	Воронежская область, Россошанский район, с.Шрамовка, Советская, 1		0101000020E610000065E256410CC8434007CE1951DAF54840
31072	1	4	538	5689	36636	\N	50.046019000000001	Воронежская область, Россошанский район, с.Шекаловка, Центральная, 21		0101000020E61000003ECF9F36AAA7434050FF59F3E3054940
31047	1	4	538	54423	37212	\N	50.141835719087702	Воронежская область, Россошанский район, х.Чернышовка, Зеленая, 141	Россия, Воронежская область, Россошанский район, поселок Чернышовка	0101000020E61000001B62BCE655C543409EB29AAE27124940
31048	1	4	538	54459	37272	\N	50.056286	Воронежская область, Россошанский район, х.Чагари, Мира, 8В	Россия, Воронежская область, Россошанский район, поселок Чагары	0101000020E61000004A29E8F692BA4340809C306134074940
31058	1	4	538	4915	37120	\N	50.027133999999997	Воронежская область, Россошанский район, с.Цапково, Центральная, 11		0101000020E610000029AF95D05D144440094E7D2079034940
31034	1	4	538	54390	37052	\N	50.225504646606304	Воронежская область, Россошанский район, х.Украинский, Садовая, 1	Россия, Воронежская область, Россошанский район, поселок Украинский	0101000020E6100000054F2157EADB4340D00A0C59DD1C4940
31070	1	4	538	5577	36906	\N	50.131377999999998	Воронежская область, Россошанский район, с.Терновка, Школьная, 9		0101000020E6100000EEB3CA4C69EB4340FAB48AFED0104940
31057	1	4	538	4889	36907	\N	49.96031	Воронежская область, Россошанский район, с.Стеценково, Мира, 10		0101000020E61000001F1329CDE60F4440C9022670EBFA4840
31069	1	4	538	5472	36453	\N	50.142128999999997	Воронежская область, Россошанский муниципальный район, с.Старая Калитва, Школьная, 32		0101000020E6100000A9177C9A93FD43401668774831124940
31068	1	4	538	5472	36497	\N	50.142128999999997	Воронежская область, Россошанский район, с.Старая Калитва, Центральная, 1	Россия, Воронежская область, Россошанский район, поселок Старая Калитва	0101000020E6100000A9177C9A93FD43401668774831124940
31038	1	4	538	54436	37234	\N	50.199571626140603	"Воронежская область, Россошанский район, п. совхоза ""Россошанский"", Молодежная, 18"	Россия, Воронежская область, Россошанский район, поселок Совхоз Россошанский	0101000020E6100000B37C5D86FFBA4340429946938B194940
30949	1	4	538	47939	\N	\N	50.034367000000003	сл.Сагуны, здание администрации с/п	Россия, Воронежская область, Россошанский район, поселок Сагуны	0101000020E6100000E773EE76BDB24340E4874A2366044940
31066	1	4	538	5369	35813	\N	50.309795000000001	Воронежская область, Россошанский район, с.Поповка, Ленина, 53А	Россия, Воронежская область, Россошанский район, поселок Поповка	0101000020E61000001D76DF313CCE43406FBBD05CA7274940
31041	1	4	538	3997	36847	\N	49.894345000000001	Воронежская область, Россошанский район, с.Поддубное, Молодежная, 8		0101000020E610000083A5BA8097AF4340AA2B9FE579F24840
31065	1	4	538	5279	35881	\N	50.180630999999998	Воронежская область, Россошанский район, с.Подгорное, Луначарского, 2А		0101000020E6100000D6C743DFDDC2434067D2A6EA1E174940
30929	1	4	538	5279	36229	\N	50.184467750088899	сл. Подгорное, ул.Ленина, д.128	Россия, Воронежская область, Россошанский район, поселок Подгорное	0101000020E6100000FCA71B28F0C043404B94BDA59C174940
30928	1	4	538	5279	36260	\N	50.1805547224699	сл.Подгорное, ул.Вокзальная, д.188	Россия, Воронежская область, Россошанский район, поселок Подгорное	0101000020E610000000AC8E1CE9C243408C101E6D1C174940
31045	1	4	538	4204	36776	\N	49.966667000000001	Воронежская область, Россошанский район, с.Первомайское, Центральная, 39		0101000020E610000054E57B4622FA4340AC8F87BEBBFB4840
31062	1	4	538	54393	37121	\N	50.333179999999999	Воронежская область, Россошанский район, х.Новопостояловка, Ленинская, 31	Россия, Воронежская область, Россошанский район, поселок Новопостояловка	0101000020E610000054AD855968BB434034D769A4A52A4940
31053	1	4	538	4645	36177	\N	50.078073000000003	Воронежская область, Россошанский район, с.Новая Калитва, переулок Советский, 2		0101000020E61000005EB9DE3653014440AED9CA4BFE094940
31035	1	4	538	3691	37013	\N	50.265881	Воронежская область, Россошанский район, с.Нижний Карабут, Центральная, 26		0101000020E61000002D5E2C0C91FB43405BD07B6308224940
31059	1	4	538	5008	35815	\N	50.231222000000002	Воронежская область, Россошанский район, п.Начало, Рябцева, 1		0101000020E6100000D673D2FBC6C94340D00EB8AE981D4940
31050	1	4	538	4475	36110	\N	50.138393000000001	Воронежская область, Россошанский район, с.Морозовка, Дзержинского, 2		0101000020E61000000667F0F78BD14340677FA0DCB6114940
31063	1	4	538	54455	37265	\N	50.216741802711503	Воронежская область, Россошанский район, х.Молодежный, Юбилейная, 2	Россия, Воронежская область, Россошанский район, поселок Молодежный	0101000020E610000071AC8BDB68D04340B7D5AC33BE1B4940
31071	1	4	538	54422	37211	\N	50.138524912054002	Воронежская область, Россошанский район, х.Лощина, Школьная, 14	Россия, Воронежская область, Россошанский район, поселок Лощина	0101000020E610000029ED0DBE30F34340D656EC2FBB114940
31046	1	4	538	4277	36496	\N	50.121797000000001	Воронежская область, Россошанский район, с.Лизиновка, Ленина, 163	Россия, Воронежская область, Россошанский район, поселок Лизиновка	0101000020E6100000566133C005BB43401EE0490B970F4940
31052	1	4	538	4623	37058	\N	50.062908	Воронежская область, Россошанский район, с.Лебедь-Сергеевка, Лебедь-Сергеевка, 3		0101000020E6100000751F80D426E2434011548D5E0D084940
31044	1	4	538	4199	36536	\N	50.015483000000003	Воронежская область, Россошанский район, с.Криничное, Центральная, 39	Россия, Воронежская область, Россошанский район, поселок Криничное	0101000020E6100000001DE6CB0BEC43406E52D158FB014940
31043	1	4	538	4109	36680	\N	49.922336999999999	Воронежская область, Россошанский район, с.Кривоносово, Мира, 36		0101000020E610000090F63FC05AA14340047289230FF64840
31042	1	4	538	4058	36957	\N	50.054209999999998	Воронежская область, Россошанский район, п.Копенкина, Веселова, 3		0101000020E61000002A560DC2DCC64340DE8E705AF0064940
31061	1	4	538	54400	37173	\N	50.284810893789697	Воронежская область, Россошанский район, х.Копанки, Озерная, 3	Россия, Воронежская область, Россошанский район, поселок Копанки	0101000020E61000008196AE601BC143404145D5AF74244940
31067	1	4	538	54450	37254	\N	50.303564000000001	Воронежская область, Россошанский район, х.Комарово, Центральная, 65	Россия, Воронежская область, Россошанский район, поселок Комаровка	0101000020E6100000AE7FD767CEE04340191F662FDB264940
31060	1	4	538	54424	37218	\N	50.258282679541203	Воронежская область, Россошанский район, х.Кокаревка, Гагарина, 43		0101000020E6100000E02A4F20ECCA43406F0ED76A0F214940
31056	1	4	538	4845	36747	\N	50.005474	Воронежская область, Россошанский район, с.Ивановка, площадь Имени 172-ой Стрелковой дивизии, 1		0101000020E6100000B60F79CBD5034440397D3D5FB3004940
31040	1	4	538	3964	36407	\N	49.902735999999997	Воронежская область, Россошанский район, с.Жилино, Центральная, 11		0101000020E6100000A647533D99B54340FF756EDA8CF34840
31074	1	4	538	5793	36777	\N	49.955801999999998	Воронежская область, Россошанский район, с.Еленовка, Центральная, 21		0101000020E6100000F20698F90EBC4340C7B94DB857FA4840
31049	1	4	538	4466	37118	\N	50.111942999999997	Воронежская область, Россошанский район, с.Екатериновка, Победы, 77		0101000020E6100000F3C64961DEAB43401002F225540E4940
31039	1	4	538	3884	35937	\N	50.131459	Воронежская область, Россошанский район, с.Евстратовка, Пролетарская, 1		0101000020E6100000A3C9C51858DD4340E7E104A6D3104940
31054	1	4	538	54449	37253	\N	50.073321	Воронежская область, Россошанский район, х.Голубая Криница, Мира, 6а	Россия, Воронежская область, Россошанский район, поселок Голубая Криница	0101000020E610000031242713B7F24340158E209562094940
31027	1	4	538	3271	37054	\N	50.041865999999999	Воронежская область, Россошанский район, п.Ворошиловский, Верхняя, 4		0101000020E6100000228AC91B60CE43403C6876DD5B054940
31037	1	4	538	3788	35714	\N	50.213960999999998	Воронежская область, Россошанский район, с.Архиповка, Октябрьская, 42Б	Россия, Воронежская область, Россошанский район, поселок Архиповка	0101000020E610000030A182C30BB643404ACFF412631B4940
31051	1	4	538	54326	36641	\N	50.144356999999999	Воронежская область, Россошанский район, с.Анцелович, Кутузова, 2	Россия, Воронежская область, Россошанский район, поселок Анцеловича	0101000020E6100000AC8E1CE90CCC43406EF9484A7A124940
31036	1	4	538	3778	36574	\N	49.984521999999998	Воронежская область, Россошанский район, с.Александровка, Ленина, 48		0101000020E6100000B4226AA2CFB14340A41820D104FE4840
31033	1	4	538	3595	37051	\N	50.241287999999997	Воронежская область, Россошанский район, с.Алейниково, Кирова, 48		0101000020E6100000CF11F92EA5E6434068757286E21E4940
31002	1	4	332	1847	37116	\N	51.097949999999997	с.Фабрицкое, ул.Трушова, д.3 (здание Фабрицкого ДК)		0101000020E610000054AA44D95B644340545227A0898C4940
31001	1	4	332	1750	36858	\N	51.049421000000002	с.Усть-Муравлянка, ул.Первомайская, д.53 (здание У-Муравлянской школы)		0101000020E6100000B9C5FCDCD06C4340295E656D53864940
31000	1	4	332	1737	36976	\N	51.233438999999997	с.Россошки, ул.Школьная, д.1		0101000020E6100000040473F4F8734340334E4354E19D4940
30991	1	4	332	48699	37008	\N	51.075510999999999	с.Репьевка, ул.Спортивная, д.11		0101000020E6100000A0504F1F815343407FBE2D58AA894940
30990	1	4	332	48699	36106	\N	51.075510999999999	"с.Репьевка, ул.Октябрьская, д.49 (здание ООО ""Авангард-Агро"")"		0101000020E6100000A0504F1F815343407FBE2D58AA894940
30989	1	4	332	48699	35784	\N	51.075510999999999	с.Репьевка, ул.Воронежская, д.24 (здание районного ДК)		0101000020E6100000A0504F1F815343407FBE2D58AA894940
31004	1	4	332	48939	36435	\N	51.180345000000003	с.Платава, ул.Советская, д.56Г (здание Платавской школы)		0101000020E6100000A3409FC893744340A27F828B15974940
30994	1	4	332	48772	36774	\N	51.096252999999997	с.Одинцовка, ул.Школьная, д.3 (здание детского сада)		0101000020E61000000E2C47C8403843402992AF04528C4940
30999	1	4	332	45442	36648	\N	51.245427999999997	с.Новосолдатка, ул.Воронежская, д.2 (здание администрации с/посел)		0101000020E610000046D3D9C9E0664340E7C2482F6A9F4940
30997	1	4	332	1559	35709	\N	51.206964999999997	с.Краснолипье, пл.Ленина, д.2 (здание Краснолипьевского ДК)	Россия, Воронежская область, Репьевский район, поселок Краснолипье	0101000020E61000008813984EEB624340543541D47D9A4940
31003	1	4	332	47276	36586	\N	51.040145000000003	с.Колбино, ул.Советская, д.17 (здание Колбинского ДК)		0101000020E61000009E7C7A6CCB744340890CAB7823854940
30996	1	4	332	47157	36495	\N	51.262011999999999	с.Истобное, ул.Терешковой, д.34 (здание администрации с/посел)		0101000020E610000037C5E3A25A5443406C94F59B89A14940
31182	1	4	332	47808	\N	\N	51.051301000000002	дер.Заречье, д.58а, здание школы		0101000020E6100000A855F4876668434045A0FA0791864940
30992	1	4	332	48746	36528	\N	51.064362000000003	с.Бутырки, пер.Школьный, д.2 (здание Бутырской школы)		0101000020E6100000DB300A82C74D4340768D96033D884940
30986	1	4	17	54295	36237	\N	51.795725565853999	с. Ямное, Советская, 2а	Россия, Воронежская область	0101000020E610000087191A4F04934340D8497D59DAE54940
30985	1	4	17	858	36904	\N	51.887647999999999	с. Чистая Поляна, Школьная, 6		0101000020E610000088653387A46A43400E2E1D739EF14940
30965	1	4	17	54298	36255	\N	51.823785085299001	с.Чертовицы, Школьная, 79	Россия, Воронежская область	0101000020E610000074D190F128A34340BAF770C971E94940
30984	1	4	17	54378	36928	\N	51.962394000000003	с. Ступино, Зубарева, 10	Россия, Воронежская область, Рамонский район, поселок Ступино	0101000020E6100000F913950D6BB24340EEEE01BA2FFB4940
30983	1	4	17	48568	37011	\N	51.941234999999999	с. Сомово, мира, 30		0101000020E6100000780B24287E664340DF6C73637AF84940
29853	1	4	17	46600	36823	\N	51.965905999999997	пос.Дубрава, ул.Центральная, д.4		0101000020E61000001286014BAE9A43404D81CCCEA2FB4940
30982	1	4	17	687	36573	\N	51.954456999999998	с. Скляево, Центральная, 1	Россия, Воронежская область, Рамонский район, поселок Скляево	0101000020E6100000B2F336363B8443401938A0A52BFA4940
30981	1	4	17	609	36457	\N	51.815950000000001	с. Русская Гвоздевка, Ленина, 45	Россия, Воронежская область, Рамонский район, поселок Русская Гвоздевка	0101000020E6100000B0592E1B9D894340EA95B20C71E84940
30959	1	4	17	1023	\N	\N	51.904654000000001	пос.Рамонь, Советская, 11	Россия, Воронежская область, Рамонский район, поселок Рамонь	0101000020E61000001F9E25C808AC43400919C8B3CBF34940
30988	1	4	17	1023	37012	\N	51.904654000000001	пос. Рамонь, Школьная, 1	Россия, Воронежская область, Рамонский район, поселок Рамонь	0101000020E61000001F9E25C808AC43400919C8B3CBF34940
30960	1	4	17	1023	36006	\N	51.904654000000001	пос.Рамонь, Советская, 40		0101000020E61000001F9E25C808AC43400919C8B3CBF34940
30958	1	4	17	1023	35809	\N	51.904654000000001	пос.Рамонь, Мосина, 9		0101000020E61000001F9E25C808AC43400919C8B3CBF34940
30961	1	4	17	1023	37169	\N	51.904654000000001	пос.Рамонь, Лесная, 1а		0101000020E61000001F9E25C808AC43400919C8B3CBF34940
30979	1	4	17	490	\N	\N	51.883651	с. Новоживотинное, Дом культуры		0101000020E6100000D0D03FC1C5964340F209D9791BF14940
31103	1	4	17	7268	37370	\N	52.002941	с.Малая Верейка, ул.Колхозная, д.1		0101000020E610000012C2A38D23704340A568E55E60004A40
30967	1	4	17	48289	36955	\N	51.986006000000003	с.Лопатки, Садовая, 20		0101000020E61000005D35CF11F9AA434074D4D17135FE4940
30978	1	4	17	48485	36903	\N	52.056097000000001	с. Ломово, Центральная, 1		0101000020E61000003D7FDAA84E6B4340AD33BE2F2E074A40
30953	1	4	17	48021	\N	\N	51.924835999999999	с.Кулешовка, здание школы	Россия, Воронежская область, Рамонский район, поселок Кулешовка	0101000020E6100000A5660FB402974340EC14AB0661F64940
30972	1	4	17	32485	36902	\N	52.040953999999999	д Кривоборье, Песчаная, 14а		0101000020E610000031CF4A5AF1934340F8510DFB3D054A40
30976	1	4	17	54386	37024	\N	51.984256176749803	пос. Комсомольский, Центральная, 1а	Россия, Воронежская область, Рамонский район, поселок Комсомольский	0101000020E610000004763579CA9C43402672C119FCFD4940
30977	1	4	17	45960	36846	\N	52.065471000000002	с. Князево, Школьная, 54		0101000020E610000050FEEE1D3598434010EB8D5A61084A40
30973	1	4	17	21	36842	\N	52.012188000000002	с. Карачун, Солнечная, 74		0101000020E6100000377172BF43AD4340ABB35A608F014A40
31106	1	4	17	46498	37231	\N	51.960512999999999	с.Каверье, ул.Транспортная, д.29а		0101000020E61000002E8D5F78257B434001310917F2FA4940
30918	1	4	17	47378	37161	\N	51.976819999999996	с. Гремячье, Центральная, 19		0101000020E61000006AF6402B30664340130A117008FD4940
30971	1	4	17	32434	36845	\N	51.997103000000003	с. Горожанка, Центральная, 12		0101000020E6100000DE5A26C3F18E43402BDF3312A1FF4940
30975	1	4	17	176	36844	\N	52.045053000000003	с.Глушицы, Центральная, 10		0101000020E6100000D74E948444AC434019CBF44BC4054A40
30964	1	4	17	32114	\N	\N	51.915832000000002	пос.ВНИИСС, Дом культуры	Россия, Воронежская область, Рамонский район, Вниисс	0101000020E61000005B5B785E2AA64340AD50A4FB39F54940
30962	1	4	17	48192	36638	\N	51.904008200660897	пос.Бор, Пристанционная, 26	Россия, Воронежская область, Рамонский район, поселок Бор	0101000020E6100000A6F10BAF24BB434043A9BD88B6F34940
30969	1	4	17	32352	36679	\N	52.026715000000003	Большая Верейка, Советская, 3		0101000020E6100000508C2C996375434005A8A9656B034A40
30970	1	4	17	48356	36458	\N	51.938558	с. Богданово, Почтовая, 15		0101000020E6100000DA53724EEC99434018B325AB22F84940
30966	1	4	17	47673	35843	\N	51.921655229531503	с.Березово, Ленина, 95	Россия, Воронежская область, Рамонский район, поселок Рамонь	0101000020E6100000C632FD12F1AA4340F29881CAF8F54940
30935	1	4	17	47673	37111	\N	51.933965999999998	с.Березово, ул.Центральная, д.61		0101000020E610000020274C18CDAC4340B8C9A8328CF74940
29742	1	4	17	40341	9882	\N	52.010862340551299	с.Архангельское, ул.Мира, д.37	Россия, Воронежская область, Рамонский район, поселок Архангельское	0101000020E6100000E869C020E975434074620FED63014A40
30963	1	4	17	48228	35759	\N	51.902791999999998	с.Айдарово, Центральная, 85		0101000020E6100000F5F75278D0A44340938B31B08EF34940
30987	1	4	4439	54369	\N	\N	51.785892039364697	"пос. Солнечный, ТРК ""Град"""	Россия, Воронежская область	0101000020E6100000F984ECBC8D9943401118EB1B98E44940
30956	1	4	1436	48080	\N	\N	50.693477000000001	с.Юдино, помещение администрации с/п	Россия, Воронежская область, Подгоренский район, поселок Юдино	0101000020E61000005C92037635DB43409CC3B5DAC3584940
31091	1	4	1436	54314	37213	\N	50.522981228611499	с.Терновое, ул.Терновская, д.2	Россия, Воронежская область, Подгоренский район, поселок Терновое	0101000020E6100000D9B45208E4A84340F6B6990AF1424940
94925	1	4	1436	54343	36704	\N	50.348954999999997	хут.  Суд-Николаевка, ул. Зеленая, 1-а	Россия, Воронежская область, Подгоренский район, поселок Суд-Николаевка	0101000020E6100000F1845E7F12CF43404963B48EAA2C4940
95197	1	4	1436	47901	37004	\N	50.532451999999999	пос Пробуждение, ул. Центральная,11-а	Россия, Воронежская область, Подгоренский район, поселок Совхоз Пробуждение	0101000020E6100000C84274081CCD43404B581B6327444940
30941	1	4	1436	31033	\N	\N	50.435606	пос.Опыт, помещение администрации с/п	Россия, Воронежская область, Подгоренский район, поселок Совхоз Опыт	0101000020E610000042CD902A8AC743407FF8F9EFC1374940
30875	1	4	1436	46477	37221	\N	50.422162	с.Сергеевка, ул.Советская, д.30		0101000020E610000050C6F8307BE7434096CE876709364940
30951	1	4	1436	47973	\N	\N	50.331392000000001	с.Семейка, здание дома культуры	Россия, Воронежская область, Подгоренский район, поселок Семейка	0101000020E61000006D1CB1169FFA4340F913950D6B2A4940
30939	1	4	1436	30961	37171	\N	50.380144999999999	с.Саприно, ул.Школьная, д.30		0101000020E6100000DDCD531D72F14340745E6397A8304940
30924	1	4	1436	16435	35868	\N	50.412950000000002	пгт.Подгоренский, ул.Калинина, д.18	Россия, Воронежская область, Подгоренский район, поселок Подгоренский	0101000020E61000002BA391CF2BD243400D71AC8BDB344940
30925	1	4	1436	16435	36024	\N	50.412950000000002	пгт.Подгоренский, ул.Цемзавода поселок, д.14	Россия, Воронежская область, Подгоренский район, поселок Подгоренский	0101000020E61000002BA391CF2BD243400D71AC8BDB344940
30931	1	4	1436	16435	37049	\N	50.412950000000002	пгт.Подгоренский, ул.Северная, д.1		0101000020E61000002BA391CF2BD243400D71AC8BDB344940
30923	1	4	1436	16435	35998	\N	50.412950000000002	пгт.Подгоренский, ул.Первомайская, д.205	Россия, Воронежская область, Подгоренский район, поселок Подгоренский	0101000020E61000002BA391CF2BD243400D71AC8BDB344940
30926	1	4	1436	16435	36570	\N	50.412950000000002	пгт.Подгоренский, ул.Ленина, д.19в	Россия, Воронежская область, Подгоренский район, поселок Подгоренский	0101000020E61000002BA391CF2BD243400D71AC8BDB344940
30948	1	4	1436	54458	37270	\N	50.543902000000003	с.Перевальное, ул.Школьная, д.13	Россия, Воронежская область, Подгоренский район, поселок Перевальная	0101000020E610000034DB15FA60C14340501DAB949E454940
30944	1	4	1436	47839	37003	\N	50.545121000000002	с.Лыково, ул.Центральная, д.3		0101000020E61000000ADAE4F049E3434071AE6186C6454940
30937	1	4	1436	54414	37202	\N	50.510459599213398	хут.Красюковский, ул.Центральная, д.75г	Россия, Воронежская область, Подгоренский район, поселок Красюковский	0101000020E61000008A39083A5AD3434045F5D6C056414940
30936	1	4	1436	30815	36534	\N	50.602634999999999	пос.Красный Восход, ул.Челябинская, д.29	Россия, Воронежская область, Подгоренский район, поселок Красный Восход	0101000020E610000037FDD98F14CF43406536C824234D4940
30957	1	4	1436	48104	37006	\N	50.698850999999998	с.Костомарово, ул.Донская, д.107		0101000020E610000098DEFE5C34E2434071E316F373594940
30943	1	4	1436	31150	\N	\N	50.633296999999999	с.Колодежное, здание администрации с/п	Россия, Воронежская область, Подгоренский район, поселок Колодежное	0101000020E6100000E0A0BDFA78EC4340D4D347E00F514940
30940	1	4	1436	47770	\N	\N	50.516801000000001	с.Гончаровка, здание администрации с/п	Россия, Воронежская область, Подгоренский район, поселок Гончаровка	0101000020E61000003BC6151747BB434022C5008926424940
30938	1	4	1436	54447	37247	\N	50.425066463032302	хут.Витебск, ул.Центральная, д.4	Россия, Воронежская область, Подгоренский район, поселок Витебск	0101000020E6100000D9EC48F59DF743401E520C9068364940
30934	1	4	1436	30710	\N	\N	50.553432000000001	с.Верхний Карабут, здание сельского клуба	Россия, Воронежская область, Подгоренский район, поселок Верхний Карабут	0101000020E61000009088299144F54340AA471ADCD6464940
30954	1	4	1436	54399	\N	\N	50.404713488449602	хут.Большой Скорорыб, здание клуба	Россия, Воронежская область, Подгоренский район, поселок Большой Скорорыб	0101000020E6100000450E1137A7BE43400EA2B5A2CD334940
30950	1	4	1436	54398	\N	\N	50.646651196304802	хут.Большая Хвощеватка, здание школы	Россия, Воронежская область, Подгоренский район, поселок Большая Хвощеватка	0101000020E61000003719558671DD43407D76C075C5524940
30830	1	4	1436	45525	37395	\N	50.605122000000001	с.Березово, Богучарская, 23		0101000020E6100000B954A52DAEC54340890B40A3744D4940
30885	1	4	1845	28393	36105	\N	50.177059999999997	с.Красноселовка, ул.Ленина, д.28 (Здание дома культуры)		0101000020E6100000E42F2DEA936C444002B7EEE6A9164940
30933	1	4	1436	47625	\N	\N	50.492222703250597	с.Белогорье, здание администрации с/п	Россия, Воронежская область, Подгоренский район, поселок Белогорье	0101000020E61000005587DC0C3700444065ABCB29013F4940
30932	1	4	1436	47625	\N	\N	50.494358020272401	с.Белогорье, здание дома культуры	Россия, Воронежская область, Подгоренский район, поселок Белогорье	0101000020E61000002E73BA2C260044400B42791F473F4940
30945	1	4	1436	45369	\N	\N	50.505052999999997	с.Андреевка, здание дома культуры	Россия, Воронежская область, Подгоренский район, поселок Андреевка	0101000020E6100000EEE9EA8EC5E6434093DFA293A5404940
30591	1	4	1436	45369	37326	\N	50.505052999999997	с. Андреевка, пл.им.Н Зацепина, д.1		0101000020E6100000EEE9EA8EC5E6434093DFA293A5404940
30911	1	4	1294	29590	36632	\N	51.199306999999997	с.Самодуровка, ул.Молодежная, д.2		0101000020E61000009641B5C1892E4540936E4BE482994940
30910	1	4	1294	47203	35819	\N	51.238272000000002	с.Рожденственское, ул.18 Партсъезда, д.48	Россия, Воронежская область, Поворинский район, поселок Рождественское	0101000020E6100000075F984C15164540B9C667B27F9E4940
30903	1	4	1294	29206	37002	\N	51.186301999999998	г.Поворино, ул.Центральная, д.2		0101000020E6100000274EEE7728204540F69672BED8974940
30904	1	4	1294	29206	36168	\N	51.186301999999998	г.Поворино, ул.Советская, д.1А		0101000020E6100000274EEE7728204540F69672BED8974940
30912	1	4	1294	45522	36565	\N	51.248736999999998	с.Пески, пл.Свободы, д.18	Россия, Воронежская область, Поворинский район, поселок Пески	0101000020E61000000305DEC9A73B45400F27309DD69F4940
30913	1	4	1294	45522	36488	\N	51.248736999999998	с.Пески, пл.Революции, д.3А	Россия, Воронежская область, Поворинский район, поселок Пески	0101000020E61000000305DEC9A73B45400F27309DD69F4940
30914	1	4	1294	45522	36127	\N	51.253789980354199	с.Пески, ул.Советская, д.2	Россия, Воронежская область, Поворинский район, поселок Пески	0101000020E610000084622B685A3C4540A306D3307CA04940
30909	1	4	1294	47167	36678	\N	51.233365999999997	с.Октябрьское, ул.Ленинская, д.21		0101000020E610000077F86BB246F94440C9FFE4EFDE9D4940
30921	1	4	1294	47441	37351	\N	51.375653	пос.Октябрьский, ул.Садовая, д.27		0101000020E6100000158DB5BFB369454078D2C26515B04940
31244	1	4	1294	47441	37376	\N	51.375653	пос.Октябрьский, ул.Молодежная, д.5	Россия, Воронежская область, Поворинский район, поселок Октябрьский	0101000020E6100000158DB5BFB369454078D2C26515B04940
30916	1	4	1294	29826	37112	\N	51.280185000000003	с.Мазурка, пл.Революции, д.25		0101000020E6100000A6423C122F47454036EA211ADDA34940
30899	1	4	1294	29057	36772	\N	51.244774	с. Кардаиловка, ул.Горская, д.5		0101000020E610000044A67C08AA5645409F7422C1549F4940
30917	1	4	1294	47336	36529	\N	51.305075000000002	с.Ильмень, ул.Садовая, д.24А	Россия, Воронежская область, Поворинский район, поселок Ильмень	0101000020E61000007A34D593F9474540E2E995B20CA74940
30922	1	4	1294	47451	36898	\N	51.264532000000003	с.Вихляевка, ул.Советская, д.48		0101000020E610000052EE3EC7476D45406C5F402FDCA14940
30919	1	4	1294	29959	36002	\N	51.341306000000003	с.Байчурово, ул.Октябрьская, д.19		0101000020E6100000E719FB928D574540DCF63DEAAFAB4940
30894	1	4	1845	46878	37001	\N	50.089744000000003	с.Фоменково, ул.Советская, д.47 (Здание школы)		0101000020E61000005C7171546E86444091813CBB7C0B4940
30882	1	4	1845	54377	36925	\N	50.278964942421503	с.Старая Меловая, ул.Первомайская, д.22 (Здание администрации с\\с)	Россия, Воронежская область, Петропавловский район, поселок Старомеловая	0101000020E6100000BE88B663EA6E444044DD0720B5234940
30881	1	4	1845	54377	36914	\N	50.279459949617298	с.Старая Меловая, ул.Мира, д.32 (Здание дома культуры)	Россия, Воронежская область, Петропавловский район, поселок Старомеловая	0101000020E61000006AC020E9D36E444024456458C5234940
30902	1	4	1845	29088	36631	\N	50.194848	с.Старая Криуша, ул.Садовая, д.34б (Здание школы)		0101000020E610000089247A19C592444073D87DC7F0184940
30900	1	4	1845	29088	36445	\N	50.194848	"с.Старая Криуша, ул.Молодежная, д.32б (Здание столовой СХА ""Стар.)"		0101000020E610000089247A19C592444073D87DC7F0184940
30901	1	4	1845	29088	37115	\N	50.194848	с.Старая Криуша, ул.Ленина, д.26 (Здание школы)		0101000020E610000089247A19C592444073D87DC7F0184940
30887	1	4	1845	54283	36109	\N	50.091443660862602	с.Петропавловка, ул.Победы, д.30 (Здание дома культуры)	Россия, Воронежская область, Петропавловский район, поселок Петропавловка	0101000020E6100000F51263997E7144402DB5DE6FB40B4940
30884	1	4	1845	46662	36292	\N	50.264488217268102	с.Пески, ул.Центральная, д.76 (Здание дома культуры)	Россия, Воронежская область, Петропавловский район, поселок Пески	0101000020E61000002079E750867044409C1727BEDA214940
30915	1	4	1845	46662	35962	\N	50.265771999999998	с.Пески, ул.Международная, д.1		0101000020E610000045BDE0D39C704440A41820D104224940
30898	1	4	1845	54448	37250	\N	50.105708999999997	"хут.Огарево, ул.Октября, д.7а (Здание ЗАО ""Маяк"""	Россия, Воронежская область, Петропавловский район, поселок Огарев	0101000020E61000003D61890794A9444049F25CDF870D4940
30890	1	4	1845	54336	36696	\N	49.950212772632803	с.Новый Лиман, ул.Советская, д.76 (Здание школы)	Россия, Воронежская область, Петропавловский район, поселок Новый Лиман	0101000020E6100000CB2E185C73754440F59D5F94A0F94840
30893	1	4	1845	54362	36771	\N	50.126079474943197	с.Новотроицкое, ул.Степная, д.26а (Здание школы)	Россия, Воронежская область, Петропавловский район, поселок Новотроицкое	0101000020E610000024438EAD678C44402FDB4E5B23104940
30892	1	4	1845	28720	36494	\N	50.036583	с.Новобогородицкое, ул.Ленина, д.41 (Здание дома культуры)	Россия, Воронежская область, Петропавловский район, поселок Новобогородицкое	0101000020E6100000EFE714E4677D4440774B72C0AE044940
30896	1	4	1845	46917	36611	\N	50.067782000000001	с.Краснофлотское, ул.Ленина, д.55б  (Здание дома культуры)		0101000020E610000045A0FA07919C4440F5A0A014AD084940
30897	1	4	1845	46917	36995	\N	50.066431512449597	"с.Краснофлотское, ул.Космонавтов, д.82б (Здание дома культуры ""Маяк"")"	Россия, Воронежская область, Петропавловский район, поселок Краснофлотское	0101000020E61000006CB41CE8A19C444035B401D880084940
30883	1	4	1845	54420	37209	\N	50.241581765113096	хут.Индычий, ул.Школьная, д.27а (Здание школы)	Россия, Воронежская область, Петропавловский район, поселок Индычий	0101000020E61000000F80B8AB576B4440B1A6B228EC1E4940
30888	1	4	1845	46756	37000	\N	50.018839999999997	с.Замостье, ул.Пионерская, д.10 (Здание школы)		0101000020E61000005FCFD72C97694440A6ED5F5969024940
30891	1	4	1845	46801	36411	\N	49.891100999999999	с.Глубокое, ул.Шестакова, д.22 (Здание школы)		0101000020E6100000A0FA07910C7944406937FA980FF24840
30889	1	4	1845	28567	36444	\N	50.028297000000002	"с.Бычок, ул.Ленина, д.26б (Здание правления ООО ""Бычок)"		0101000020E61000004B2366F67962444097C9703C9F034940
30858	1	4	1484	27179	36808	\N	51.752589999999998	пос.Щербачевка, ул.Колхозная, д.1		0101000020E61000000264E8D841274440F8A57EDE54E04940
30877	1	4	1484	46595	37189	\N	51.6931324052604	с.Чернавка, ул.Пролетарская, д.3А	Россия, Воронежская область, Панинский район, поселок Чернавка	0101000020E61000002592E86514314440D1E7A38CB8D84940
29960	1	4	1484	46595	37315	\N	51.693345999999998	д.Чернавка, ул.Народная, д.80		0101000020E610000064B14D2A1A314440FD67CD8FBFD84940
30874	1	4	1484	17078	36694	\N	51.583027999999999	пос.Тойда-1, ул.Школьная, д.14	Россия, Воронежская область, Панинский район, поселок Тойда	0101000020E6100000696E85B01A1744407E5358A9A0CA4940
30876	1	4	1484	17078	36998	\N	51.583027999999999	пос.Тойда, ул.Заводская, д.24		0101000020E6100000696E85B01A1744407E5358A9A0CA4940
29749	1	4	1484	46972	37379	\N	51.616627999999999	с.Софьинка, ул.Придача, д.15		0101000020E61000001B12F758FA10444021E692AAEDCE4940
31243	1	4	1484	49096	37314	\N	51.557921	пос.Сергеевка, ул.Тверская, д.29		0101000020E6100000D66EBBD05C194440356090F469C74940
30844	1	4	1484	26554	35818	\N	51.718372000000002	р.п. Перелешинский, ул.Брянская, д.17	Россия, Воронежская область, Панинский район, поселок Перелешинский	0101000020E610000044F7AC6BB41844405A2E1B9DF3DB4940
30880	1	4	1484	26554	37047	\N	51.718372000000002	р.п.Перелешинский, ул.Майская, д.33		0101000020E610000044F7AC6BB41844405A2E1B9DF3DB4940
30845	1	4	1484	26554	35932	\N	51.718372000000002	р.п.Перелешинский, ул.Ленина, д.5		0101000020E610000044F7AC6BB41844405A2E1B9DF3DB4940
30846	1	4	1484	26554	36838	\N	51.718372000000002	р.п.Перелешинский, ул.Брянская, д.17		0101000020E610000044F7AC6BB41844405A2E1B9DF3DB4940
30855	1	4	1484	27028	36080	\N	51.739057000000003	пос.Перелешино, ул.50 лет Октября, д.5Б	Россия, Воронежская область, Панинский район, поселок Перелешино	0101000020E6100000766D6FB724114440A070766B99DE4940
30879	1	4	1484	26296	35929	\N	51.650539000000002	р.п.Панино, ул.Советская, д.17	Россия, Воронежская область, Панинский район, поселок Панино	0101000020E6100000AAEFFCA204114440E3E2A8DC44D34940
30839	1	4	1484	26296	35808	\N	51.650539000000002	р.п.Панино, ул.Красная площадь, д.13		0101000020E6100000AAEFFCA204114440E3E2A8DC44D34940
30842	1	4	1484	26296	36492	\N	51.650539000000002	р.п. Панино, ул.Железнодорожная, д.2	Россия, Воронежская область, Панинский район, поселок Панино	0101000020E6100000AAEFFCA204114440E3E2A8DC44D34940
30841	1	4	1484	26296	36492	\N	51.650539000000002	р.п.Панино, ул.Железнодорожная, д.52	Россия, Воронежская область, Панинский район, поселок Панино	0101000020E6100000AAEFFCA204114440E3E2A8DC44D34940
30840	1	4	1484	26296	36078	\N	51.650539000000002	р.п.Панино, ул.9-е Января, д.6А	Россия, Воронежская область, Панинский район, поселок Панино	0101000020E6100000AAEFFCA204114440E3E2A8DC44D34940
30843	1	4	1484	26296	36527	\N	51.650539000000002	р.п.Панино, ул.9-Января, д.91	Россия, Воронежская область, Панинский район, поселок Панино	0101000020E6100000AAEFFCA204114440E3E2A8DC44D34940
95196	1	4	1484	45902	37167	\N	51.65925	с. Пады, ул. Верхняя, д.47, здание фельдшерско-акушерского пункта		0101000020E6100000DBC2F352B1394440AAF1D24D62D44940
30860	1	4	1484	46147	37159	\N	51.481411000000001	пос.Павловка, ул.Школьная, д.6А		0101000020E6100000B0389CF9D5E24340A3772AE09EBD4940
30878	1	4	1484	54416	37210	\N	51.730266	пос.Первомайского отделения конезавода №11, ул.Кольцевая, д.39		0101000020E61000004AD1CABDC0F84340BCB0355B79DD4940
30867	1	4	1484	46311	37168	\N	51.530597999999998	пос.Октябрьский, ул.50 лет Октября, д.136	Россия, Воронежская область, Панинский район, поселок Октябрьский	0101000020E6100000CD069964E408444058A9A0A2EAC34940
30869	1	4	1484	27631	37046	\N	51.564197999999998	с.НовоХреновое, ул.Школьная, д.51		0101000020E6100000B492567C43F34340FB3BDBA337C84940
30868	1	4	1484	27631	36770	\N	51.564197999999998	с.НовоХреновое, ул.Совхозная, д.76		0101000020E6100000B492567C43F34340FB3BDBA337C84940
30850	1	4	1484	45932	36999	\N	51.739319000000002	с.2-я Михайловка, ул.Школьная, д.1		0101000020E6100000F38FBE49D3FE4340DD274701A2DE4940
30870	1	4	1484	46386	36629	\N	51.63888	с.Михайловка 1-я, ул.Центральная, д.2		0101000020E6100000713D0AD7A3304440C408E1D1C6D14940
30871	1	4	1484	54475	37342	\N	51.620767000000001	с.Марьевка, ул.Мира, д.48	Россия, Воронежская область, Панинский район, поселок Марьевка	0101000020E6100000643C4A253C294440D0B7054B75CF4940
30862	1	4	1484	46184	36628	\N	51.465260000000001	с.Криуша, ул.Молодежная, д.47		0101000020E610000044A2D0B2EE0544408811C2A38DBB4940
30859	1	4	1484	54321	36613	\N	51.524014000000001	с.Красный Лиман 1, ул.Советская, д.50	Россия, Воронежская область, Панинский район, поселок Красный Лиман	0101000020E6100000DCF5D21401EE4340B55208E412C34940
30861	1	4	1484	54321	36578	\N	51.523157645273699	с.Красный Лиман 2, ул.Партизанская, д.122	Россия, Воронежская область, Панинский район, поселок Красный Лиман	0101000020E6100000B5E1B034F0ED4340055262D7F6C24940
30854	1	4	1484	46020	36768	\N	51.622281999999998	с.Красные Холмы, ул.Пролетарская, д.1		0101000020E6100000B2101D0247F64340DA71C3EFA6CF4940
30857	1	4	1484	40462	37268	\N	51.743797000000001	с.Красное, ул.Ломоносова, д.70А		0101000020E61000001C5C3AE63C1B444074EE76BD34DF4940
30852	1	4	1484	26899	37114	\N	51.645459000000002	с.Ивановка 1-я, ул.Проспект революции, д.1		0101000020E6100000A30227DBC0F9434056F487669ED24940
30851	1	4	1484	46138	37346	\N	51.744204000000003	с.Дмитриевка, ул.Бевз, д.11	Россия, Воронежская область, Панинский район, поселок Дмитриевка	0101000020E6100000F0DAA50D870B4440B5C6A01342DF4940
30853	1	4	1484	26943	36896	\N	51.672114999999998	с.Верхняя Катуховка, ул.Дзержинского, д.63		0101000020E6100000E6ADBA0ED5F84340551344DD07D64940
30863	1	4	1484	27385	36447	\N	51.400125000000003	с.Большой Мартын, ул.Советская, д.2		0101000020E6100000E831CA332F034440F0A7C64B37B34940
30895	1	4	1484	54385	37009	\N	51.648258789212903	с.Березняги, ул.Центральная, д.68а (Здание школы)	Россия, Воронежская область, Панинский район, поселок Березняги	0101000020E6100000B5FCC0559E064440392BA226FAD24940
30872	1	4	1484	27826	36630	\N	51.610090999999997	пос.Алое Поле, ул.Школьная, д.31		0101000020E61000001C98DC28B2064440BE4A3E7617CE4940
30873	1	4	1484	27826	36862	\N	51.610090999999997	пос.Алое Поле, ул.Центральная, д.57		0101000020E61000001C98DC28B2064440BE4A3E7617CE4940
30348	1	4	1484	49431	37323	\N	51.763767999999999	с.Алексеевка, ул.Центральная, д.52		0101000020E6100000ACE122F7742944409CDD5A26C3E14940
30828	1	4	1757	54383	36996	\N	50.683676979733299	с.Лосево, Герино, 340А	Россия, Воронежская область, Павловский район	0101000020E610000018D1764CDD09444082035ABA82574940
30821	1	4	1757	25490	36442	\N	50.514367	с.Шувалов, Молодежная, 14		0101000020E61000006B64575A463E4440219221C7D6414940
30837	1	4	1757	54441	37240	\N	50.364460000000001	пос.Шкурлат-3-й, Мира, 13	Россия, Воронежская область, Павловский район, поселок Шкурлат	0101000020E610000026529ACDE31E44409F5912A0A62E4940
30835	1	4	1757	45645	37113	\N	50.665388999999998	с.Черкасское, Мира, 52		0101000020E61000007CD45FAFB0F643401F0F7D772B554940
30838	1	4	1757	26183	35928	\N	50.365414000000001	с.Русская Буйловка, Советская, 1	Россия, Воронежская область, Павловский район, поселок Русская Буйловка	0101000020E6100000931ADA006C08444012C0CDE2C52E4940
30836	1	4	1757	26183	35928	\N	50.361893327334698	с.Русская Буйловка, Советская, 5	Россия, Воронежская область, Павловский район, поселок Русская Буйловка	0101000020E61000005303CDE7DC0744405FD38382522E4940
30834	1	4	1757	49073	36916	\N	50.669773999999997	с.Покровка, Советская, 63	Россия, Воронежская область, Павловский район, поселок Покровка	0101000020E610000050C3B7B06EEC434005DB8827BB554940
30831	1	4	1757	54317	36530	\N	50.525860999999999	с.Петровка, просп.Революции, 108А	Россия, Воронежская область, Павловский район, поселок Петровка	0101000020E6100000AB251DE560224440F59ECA694F434940
30829	1	4	1757	54325	36633	\N	50.694565529916197	с.Пески, Скрынникова, 20	Россия, Воронежская область, Павловский район, поселок Пески	0101000020E6100000B0AC342905FD4340EF74E789E7584940
30820	1	4	1757	54419	37208	\N	50.561122678375298	хут.Переездной, Новоселов, 25	Россия, Воронежская область, Павловский район, поселок Переездной	0101000020E61000003E59315C1D5244404704E3E0D2474940
30796	1	4	1757	40402	35874	\N	50.449730000000002	г.Павловск, просп.Революции, 102А		0101000020E61000008463963D09104440DA03ADC090394940
30795	1	4	1757	40402	35874	\N	50.449730000000002	г.Павловск, просп.Революции, 15	Россия, Воронежская область, Павловский район, Павловск	0101000020E61000008463963D09104440DA03ADC090394940
30800	1	4	1757	40402	35865	\N	50.449580220013502	г.Павловск, м/р-н Гранитный, 25	Россия, Воронежская область, Павловский район, Павловск	0101000020E61000007D410B0918114440C47762D68B394940
30802	1	4	1757	40402	36145	\N	50.4582930325329	г.Павловск, м/р-н Черемушки, 1	Россия, Воронежская область, Павловский район, Павловск	0101000020E6100000D908C4EBFA0F44402C7E5358A93A4940
30804	1	4	1757	40402	35924	\N	50.449730000000002	г.Павловск, Восточная, 4	Россия, Воронежская область, Павловский район, Павловск	0101000020E61000008463963D09104440DA03ADC090394940
30794	1	4	1757	40402	35875	\N	50.457669763835902	г.Павловск, Советская, 1	Россия, Воронежская область, Павловский район, Павловск	0101000020E6100000BB97FBE4280C44401F2E39EE943A4940
30801	1	4	1757	40402	36952	\N	50.449730000000002	г.Павловск, Садовая, 31		0101000020E61000008463963D09104440DA03ADC090394940
30803	1	4	1757	40402	36164	\N	50.449730000000002	г.Павловск, Гагарина, 41		0101000020E61000008463963D09104440DA03ADC090394940
30817	1	4	1757	54381	36978	\N	50.279716000000001	с.Николаевка, Победы, 2	Россия, Воронежская область, Павловский район, поселок Николаевка	0101000020E6100000FC36C478CDFF43407F15E0BBCD234940
30819	1	4	1757	25357	36899	\N	50.540031999999997	с.Момотов, Мира, 1		0101000020E6100000BB97FBE4284444409065C1C41F454940
30832	1	4	1757	45568	37367	\N	50.533361999999997	с.Михайловка, 60 лет Октября, 1Б		0101000020E61000000553CDACA51E4440EE76BD3445444940
30826	1	4	1757	54389	37288	\N	50.675984682297504	с.Лосево, пл.Первомайская, 1		0101000020E6100000543882548A09444014CB2DAD86564940
30824	1	4	1757	54389	37045	\N	50.676659805126	с.Лосево, Буденного, 46	Россия, Воронежская область, Павловский район, поселок Лосево	0101000020E6100000FCA6B0524107444074417DCB9C564940
30823	1	4	1757	45423	36617	\N	50.732477976134597	с.Ливенка, Ленина, 2	Россия, Воронежская область, Павловский район, поселок Ливенка	0101000020E610000096CB46E7FC1C44400E85CFD6C15D4940
30814	1	4	1757	49517	37164	\N	50.459749000000002	пос.Каменск, Центральная, 19		0101000020E610000062F888981235444032AF230ED93A4940
30816	1	4	1757	49561	36405	\N	50.691012000000001	с.Ерышевка, просп.Революции, 1А		0101000020E6100000B6D8EDB3CA1A44406092CA1473584940
30815	1	4	1757	49540	36135	\N	50.462592999999998	с.Елизаветовка, просп.Революции, 67		0101000020E6100000F1B913ECBF184440E42D573F363B4940
30822	1	4	1757	54331	36689	\N	50.584802760670598	хут.Данило, Центральная, 32	Россия, Воронежская область, Павловский район, поселок Данило	0101000020E610000058AD4CF8A53A444025CD1FD3DA4A4940
30833	1	4	1757	26058	37160	\N	50.731000999999999	с.Грань, Первомайская, 107		0101000020E61000007BF8325184E44340F12BD670915D4940
30813	1	4	1757	25101	36423	\N	50.428652	с.Гаврильск, Советская, 148		0101000020E61000000F9C33A2B42D4440B8AE9811DE364940
30809	1	4	1757	49449	35867	\N	50.614736999999998	с.Воронцовка, Пролетарская, 49А	Россия, Воронежская область, Павловский район, поселок Воронцовка	0101000020E6100000761A69A9BC2B44401152B7B3AF4E4940
30812	1	4	1757	49449	36165	\N	50.614736999999998	с.Воронцовка, Советская, 85	Россия, Воронежская область, Павловский район, поселок Воронцовка	0101000020E6100000761A69A9BC2B44401152B7B3AF4E4940
30811	1	4	1757	49449	36441	\N	50.614736999999998	с.Воронцовка, Почтовая, 6		0101000020E6100000761A69A9BC2B44401152B7B3AF4E4940
30810	1	4	1757	49449	36568	\N	50.614736999999998	с.Воронцовка, Мостовая, 50А	Россия, Воронежская область, Павловский район, поселок Воронцовка	0101000020E6100000761A69A9BC2B44401152B7B3AF4E4940
30818	1	4	1757	25343	35727	\N	50.252122999999997	с.Большая Казинка, Почтовая, 8		0101000020E6100000AB933314770A4440E2C8039145204940
30807	1	4	1757	49419	36836	\N	50.589593000000001	с.Березки, Центральная, 14Б		0101000020E6100000F452B131AF0F4440AB798EC8774B4940
30806	1	4	1757	49406	36437	\N	50.560951000000003	с.Бабка, Центральная, 44		0101000020E61000004FE61F7D93FC43404AD40B3ECD474940
30805	1	4	1757	24761	35930	\N	50.518965999999999	с.Александровка-Донская, Садовая, 115А		0101000020E6100000431A1538D908444033DE567A6D424940
30761	1	4	887	22669	36589	\N	50.857188999999998	с.Шубное, Мира, 11		0101000020E61000004167D2A6EA6E4340D7BE805EB86D4940
30765	1	4	887	60384	74933	\N	50.711799999999997	х.Шинкин, Заречная, 6	Россия, Воронежская область, Острогожский район, поселок Шинкин	0101000020E6100000D767CEFA947143407AA52C431C5B4940
30758	1	4	887	22543	36807	\N	50.813569000000001	с.Хохол-Тростянка, пер.Мира, 7Б		0101000020E610000000000000006443400C056C0723684940
30790	1	4	887	24009	35861	\N	51.118963999999998	с.Урыв-Покровка, Центральная, 91	Россия, Воронежская область, Острогожский район, поселок Урыв-Покровка	0101000020E61000002E1B9DF3539443405FB35C363A8F4940
30783	1	4	887	49099	36670	\N	50.971027999999997	с.Терновое, Советская, 51А	Россия, Воронежская область, Острогожский район, поселок Терновое	0101000020E6100000118E59F6247C434009C03FA54A7C4940
30791	1	4	887	49201	36608	\N	51.209363000000003	с.Сторожевое 1-е, Советская, 96		0101000020E6100000BE840A0E2F96434009FF2268CC9A4940
30785	1	4	887	45762	36491	\N	51.047818999999997	с.Солдатское, Ленина, 24а	Россия, Воронежская область, Острогожский район, поселок Солдатское	0101000020E610000060E97C78967E43404F90D8EE1E864940
30769	1	4	887	48861	36436	\N	50.839081	п.Сельхозтехника, Советская, 14		0101000020E610000086AA984A3F8D4340F5D89601676B4940
30776	1	4	887	48977	36951	\N	50.891677999999999	с.Рыбное, пер.Школьный, 2		0101000020E6100000959EE925C69443400648348122724940
30759	1	4	887	22587	36989	\N	50.87659	с.Русская Тростянка, Победы, 13		0101000020E610000068EBE0606F6243401500E31934704940
30779	1	4	887	54355	36726	\N	51.003878999999998	с.Петропавловка, Молодежная, 6	Россия, Воронежская область, Острогожский район, поселок Петропавловка	0101000020E61000006286C613419A43401212691B7F804940
30774	1	4	887	23247	36895	\N	50.787210999999999	с.Петренково, Мира, 39		0101000020E6100000B8239C16BC90434096067E54C3644940
30768	1	4	887	54354	36723	\N	50.8638949445496	"п.1-го отделения совхоза ""Победа"", Школьная, 4"	Россия, Воронежская область, Острогожский район, поселок Отдел N1 совхоза Острогожский	0101000020E610000006A1BC8FA35D4340C616821C946E4940
30760	1	4	887	54372	36868	\N	50.886961835415903	"п.Центральное отделение совхоза ""Острогожский"", Садовая, 29"	Россия, Воронежская область, Острогожский район, поселок Острогожский	0101000020E6100000718E3A3AAE6E4340BA6587F887714940
30750	1	4	887	20882	35744	\N	50.858927999999999	г.Острогожск, Федосеенко, 67	Россия, Воронежская область, Острогожский район, Острогожск	0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30749	1	4	887	20882	36073	\N	50.858927999999999	г.Острогожск, Комсомольская, 16	Россия, Воронежская область, Острогожский район, Острогожск	0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30744	1	4	887	20882	36190	\N	50.858927999999999	г.Острогожск, Нарского, 24		0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30748	1	4	887	20882	35724	\N	50.858927999999999	г.Острогожск, Милицейская, 52		0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30742	1	4	887	20882	35850	\N	50.858927999999999	г.Острогожск, Ленина, 8	Россия, Воронежская область, Острогожский район, Острогожск	0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30746	1	4	887	20882	35948	\N	50.863942158107498	г.Острогожск, Комсомольская, 60	Россия, Воронежская область, Острогожский район, Острогожск	0101000020E6100000E8F86871C688434007D2C5A6956E4940
30740	1	4	887	20882	36763	\N	50.858927999999999	г.Острогожск, Вокзальная, 12		0101000020E610000071FF91E9D089434031CF4A5AF16D4940
30751	1	4	887	20882	35945	\N	50.852888257486498	г.Острогожск, 50 лет Октября, 51	Россия, Воронежская область, Острогожский район, Острогожск	0101000020E61000008B8D791D718643404F93196F2B6D4940
30789	1	4	887	54431	37227	\N	51.173122999999997	х.Ново-Успенка, Воронежская, 105	Россия, Воронежская область, Острогожский район, поселок Новоуспенка	0101000020E61000005F28603B188B4340BB97FBE428964940
30756	1	4	887	48625	36927	\N	50.787495	с.Новая Осиновка, Подгорная, 39		0101000020E61000002D5BEB8B84784340BB61DBA2CC644940
30755	1	4	887	48601	37390	\N	50.806185999999997	с.Новая Мельница, 60 лет Октября, 36		0101000020E6100000580229B16B8343401C3F541A31674940
30764	1	4	887	22793	36409	\N	50.754832	с.Нижний Ольшан, Почтовая, 32		0101000020E6100000CBB9145795754340B5FCC0559E604940
30788	1	4	887	23885	36403	\N	51.198053999999999	с.Мастюгино, Куркина, 31А		0101000020E6100000564ACFF412854340C66B5ED559994940
30778	1	4	887	49012	36489	\N	50.940696000000003	п.Луки, Садовая, 1	Россия, Воронежская область, Острогожский район, поселок Луки	0101000020E6100000F35A09DD259F434030BDFDB968784940
30777	1	4	887	46738	37097	\N	50.882757217233802	с.Криница, пер.Рабочий, 1А		0101000020E6100000AED689CBF19E434054A86E2EFE704940
29870	1	4	887	46738	37179	\N	50.882811513851998	с.Криница, ул.Мира, д.4	Россия, Воронежская область, Острогожский район, поселок Криница	0101000020E6100000AF3E1EFAEE9E43401842CEFBFF704940
30772	1	4	887	23137	36834	\N	50.647807	с.Кривая Поляна, Школьная, 3		0101000020E610000006BCCCB051924340588FFB56EB524940
30780	1	4	887	23514	35873	\N	50.988397999999997	с.Коротояк, Свободы, 51		0101000020E6100000BE6BD097DE94434045B75ED3837E4940
30784	1	4	887	23718	36762	\N	51.027558999999997	с.Ездочное, Верхняя, 31А		0101000020E61000008A01124DA07C4340F0DAA50D87834940
30775	1	4	887	60406	74972	\N	50.827699770003903	х.Должик, Центральная, 14	Россия, Воронежская область, Острогожский район, поселок Должик	0101000020E61000004AEB6F09C09B43401973D712F2694940
30786	1	4	887	6788	36577	\N	51.078007344996401	с.Девица, Ленина, 11Б	Россия, Воронежская область, Острогожский район, поселок Девица	0101000020E61000007A7077D66E8F4340F6ED2422FC894940
30770	1	4	887	23081	36832	\N	50.726382999999998	с.Дальняя Полубянка, Молодежная, 14А		0101000020E610000038A3E6ABE483434068AF3E1EFA5C4940
30762	1	4	887	22723	36743	\N	50.841788999999999	п.Грушевая Поляна, Садовая, 3		0101000020E6100000A2410A9E42784340F790F0BDBF6B4940
30766	1	4	887	48812	36606	\N	50.810256000000003	с.Гнилое, Ленина, 18		0101000020E6100000E94999D4D0884340A3B1F677B6674940
30754	1	4	887	48582	36734	\N	50.871634	с.Волошино, Октябрьской революции, 1В		0101000020E61000007250C24CDB774340740AF2B3916F4940
30771	1	4	887	60425	74996	\N	50.677582000000001	х.Владимировка, пер.Южный, 1	Россия, Воронежская область, Острогожский район, поселок Владимировка	0101000020E61000004C5299620E7E4340DC2DC901BB564940
30757	1	4	887	47480	36605	\N	50.778849999999998	с.Веретье, Центральная, 66		0101000020E610000084B7072120714340AB3E575BB1634940
30787	1	4	887	49154	36567	\N	51.130122999999998	с.Болдыревка, Мостовая, 1	Россия, Воронежская область, Острогожский район, поселок Болдыревка	0101000020E6100000E99AC937DB8643408CBAD6DEA7904940
30767	1	4	887	54339	36699	\N	50.814306101564803	х.Ближнее Стояново, Луговая, 2	Россия, Воронежская область, Острогожский район, поселок Ближняя Стояново	0101000020E61000001FF296AB1F8B4340E277D32D3B684940
30773	1	4	887	23195	36950	\N	50.749749000000001	с.Ближняя Полубянка, Центральная, 5		0101000020E6100000554E7B4ACE994340B79A75C6F75F4940
30782	1	4	887	49081	37363	\N	50.944645999999999	с.Березово, Клубная, 1		0101000020E610000097C80567F07343400B26FE28EA784940
30727	1	4	1636	54352	36721	\N	50.489381000000002	сл.Юрасовка, ул.Площадь Победы, д.1 (здание администрации)	Россия, Воронежская область, Ольховатский район, поселок Юрасовка	0101000020E610000067EF8CB62A97434053245F09A43E4940
30718	1	4	1636	54299	36257	\N	50.239263818731999	сл.Шапошниковка, ул.Шевченко, д.1в (дом культуры)	Россия, Воронежская область, Ольховатский район, поселок Шапошниковка	0101000020E6100000880D164ED2AE4340198EE733A01E4940
30733	1	4	1636	54452	37256	\N	50.410269252143699	хут.Постоялый, ул.Денисова, д.11 (дом культуры)	Россия, Воронежская область, Ольховатский район, поселок Постоялый	0101000020E61000009CFA40F2CEB3434004C8D0B183344940
30736	1	4	1636	21517	36703	\N	50.282156999999998	р.п.Ольховатка, ул.Степана Разина, д.1а (актовый зал Ольховаткарайгаз)	Россия, Воронежская область, Ольховатский район, поселок Ольховатка	0101000020E61000007FA2B2614DA3434032AB77B81D244940
30711	1	4	1636	21517	37251	\N	50.282322014263997	"р.п.Ольховатка, ул.Пролетарская, д.2 (дом культуры ""Слобода"")"		0101000020E61000007D78962023A443407D78962023244940
30735	1	4	1636	21517	37014	\N	50.282156999999998	р.п.Ольховатка, ул.Октябрьская, д.56 (Ольховатская школа)	Россия, Воронежская область, Ольховатский район, поселок Ольховатка	0101000020E61000007FA2B2614DA3434032AB77B81D244940
30712	1	4	1636	21517	36268	\N	50.282970912172303	р.п.Ольховатка, ул.50 лет ВЛКСМ, д.1 (спортзал ДЮСШ Гора)	Россия, Воронежская область, Ольховатский район, поселок Ольховатка	0101000020E6100000F04C689258A44340B45BCB6438244940
30730	1	4	1636	54330	36688	\N	50.378731693131101	сл.Новохарьковка, ул.Октябрьская, д.162а (Новохарьковская школа)	Россия, Воронежская область, Ольховатский район, поселок Новохарьковка	0101000020E6100000689599D2FAA143406EF9484A7A304940
30731	1	4	1636	21278	\N	\N	50.353726000000002	пос.Новокулишовка, д.8б (сельский клуб)		0101000020E6100000A051BAF42FA3434059DFC0E4462D4940
30729	1	4	1636	54443	37243	\N	50.400497999999999	сл.Новокараяшник, ул.Асфальтная, д.54б (здание почты)	Россия, Воронежская область, Ольховатский район, поселок Новокараяшник	0101000020E6100000419B1C3EE99E4340840EBA8443334940
30720	1	4	1636	54418	37207	\N	50.149010426504297	сл.Неровновка, ул.Тополиная, д.2 (дом культуры)	Россия, Воронежская область, Ольховатский район, поселок Неровновка	0101000020E6100000221ADD41EC9E434073637AC212134940
30723	1	4	1636	54344	36707	\N	50.298679	хут.Назаровка, ул.Гагарина, д.171	Россия, Воронежская область, Ольховатский район, поселок Назаровка	0101000020E610000049BA66F2CD8C434041800C1D3B264940
30722	1	4	1636	47681	37162	\N	50.312728999999997	сл.Марьевка, ул.Школьная, д.211 (Марьевская школа)	Россия, Воронежская область, Ольховатский район, поселок Марьевка	0101000020E61000009CC0745AB793434061C1FD8007284940
30015	1	4	1636	47681	37259	\N	50.312728999999997	с.Марьевка, ул.Трудовая, д.46б		0101000020E61000009CC0745AB793434061C1FD8007284940
30721	1	4	1636	54427	37217	\N	50.271236000000002	сл.Марченковка, ул.Мичурина, д.43 (Марченковская школа)	Россия, Воронежская область, Ольховатский район, поселок Марченковка	0101000020E61000009C35785F959B4340BABF7ADCB7224940
30717	1	4	1636	20568	36069	\N	50.260675999999997	"пос.Малые Базы, ул.Юбилейная, д.3 (МСО ""Ольховатское"")"		0101000020E6100000B4E4F1B4FCA84340116DC7D45D214940
30724	1	4	1636	54403	37185	\N	50.389919999999996	хут.Лимарев, ул.Школьная, д.104а (здание администрации)	Россия, Воронежская область, Ольховатский район, поселок Лимарев	0101000020E61000002619390B7B8A4340350708E6E8314940
30719	1	4	1636	20658	36593	\N	50.187050999999997	с.Костово, ул.38 Стрелковой Дивизии, д.5 (Степнянская школа)		0101000020E610000055849B8C2A95434090D78349F1174940
30726	1	4	1636	54347	36711	\N	50.452419999999996	сл.Копаная 1-я, ул.Молодежная, д.112а (здание администрации)	Россия, Воронежская область, Ольховатский район, поселок Копаная 1-я	0101000020E6100000ED45B41D538B4340350708E6E8394940
30728	1	4	1636	54333	36692	\N	50.422668930127799	сл.Караяшник, ул.Школьная, д.18 (Караяшниковская школа)	Россия, Воронежская область, Ольховатский район, поселок Караяшник	0101000020E6100000054D4BAC8C9C43403A048E041A364940
30714	1	4	1636	47833	35863	\N	50.273716999999998	пос.Заболотовка, ул.Зеленая, д.15 (новое здание школы)		0101000020E6100000B8E4B8533AAA4340FBAD9D2809234940
30713	1	4	1636	47833	35863	\N	50.273716999999998	пос.Заболотовка, ул.Зеленая, д.15 (старое здание школы)		0101000020E6100000B8E4B8533AAA4340FBAD9D2809234940
30732	1	4	1636	54428	37219	\N	50.335184080498799	хут.Дроздово, ул.Ленина, д.7 (Дроздовская школа)	Россия, Воронежская область, Ольховатский район, поселок Дроздово	0101000020E6100000BE688F17D2B143403C122F4FE72A4940
30738	1	4	1636	54430	37226	\N	50.297460000000001	"х.Гвоздовка, ул.Молодежная, д.169в (адм. здание ООО ""ЮНИ"")"	Россия, Воронежская область, Ольховатский район, поселок Гвоздовка	0101000020E6100000D6C56D348095434020EF552B13264940
30534	1	4	1011	10206	36158	\N	50.994197999999997	город Лиски, Громовой, 37, здание поликлиники		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30715	1	4	1636	47145	36204	\N	50.298393180020902	пос.Бугаевка, ул.Победы, д.38 (Бугаевская школа)	Россия, Воронежская область, Ольховатский район, поселок Бугаевка	0101000020E61000001F477364E5A743407B2DE8BD31264940
30737	1	4	1636	54287	36209	\N	50.266987	пос.Большие Базы, ул.Школьная, д.11 (школьная столовая)	Россия, Воронежская область, Ольховатский район, поселок Болшие Базы	0101000020E61000007B2E5393E0A3434084BA48A12C224940
30716	1	4	1636	54287	36209	\N	50.266987	пос.Большие Базы, ул.Школьная, д.9 (администрация Базовского с/п)	Россия, Воронежская область, Ольховатский район, поселок Болшие Базы	0101000020E61000007B2E5393E0A3434084BA48A12C224940
30382	1	4	5817	38561	35803	\N	56.084479999999999	с.Заброды, Дерезовская (культурно-оздоровительный центр), 94		0101000020E6100000A14ACD1E68D5404042959A3DD00A4C40
14669	1	4	1046	9177	37048	\N	51.343820999999998	с.Ярки, ул.Свобода, д.53		0101000020E6100000C03DCF9F36924440C956975302AC4940
30680	1	4	1046	15793	36505	\N	50.927339000000003	пос.Централь, ул.Советская, д.26		0101000020E610000046088F368EAA444016A75A0BB3764940
30709	1	4	1046	20083	37043	\N	50.911667000000001	пос.Тулучеевка, ул.Лесная, д.7		0101000020E61000007E198C11898C4440D5EB1681B1744940
30688	1	4	1046	46830	36504	\N	51.274174075121202	с.Троицкое, ул.Советская, д.12	Россия, Воронежская область, Новохоперский район, поселок Троицкое	0101000020E6100000988A8D791DBB4440EEB4352218A34940
30687	1	4	1046	46830	36504	\N	51.276492154236003	с.Троицкое, ул.Советская, д.22		0101000020E6100000CEA78E554ABB444085CD001764A34940
31122	1	4	1046	46830	37191	\N	51.276546000000003	с.Троицкое, Сельская, д.64		0101000020E6100000CEA78E554ABB444079EBFCDB65A34940
30707	1	4	1046	19958	36402	\N	51.078980000000001	пос.Терновский, ул.Центральная, д.1		0101000020E6100000DEAF027CB78B4440E08442041C8A4940
30704	1	4	1046	61069	77122	\N	50.980558000000002	пос.Долиновский, ул.Административная, д.5	Россия, Воронежская область, Новохоперский район, поселок Совхоз имени ХХII Партсъезда	0101000020E610000008E6E8F17B8B444064EAAEEC827D4940
30679	1	4	1046	47173	37155	\N	51.099227999999997	с.Русаново, ул.Верхняя, д.53		0101000020E6100000C5387F130ABD44407A6CCB80B38C4940
30681	1	4	1046	18594	36627	\N	51.023978999999997	с.Пыховка, ул.Советская, д.136		0101000020E61000001363997E89C0444038656EBE11834940
30685	1	4	1046	18816	36449	\N	51.078057999999999	пос.Половцево, пер.Приозерный, д.31		0101000020E61000004A79AD84EEE044407898F6CDFD894940
30703	1	4	1046	19731	\N	\N	50.880535000000002	пос.Полежаевский, здание Полежаевского СДК	Россия, Воронежская область, Новохоперский район, поселок Полежаевский	0101000020E6100000FDBFEAC891944440DFFDF15EB5704940
30695	1	4	1046	47500	37110	\N	51.136260999999998	с.Подосиновка, ул.Центральная, д.5		0101000020E61000001971016894AA4440315C1D0071914940
30395	1	4	1046	54282	36098	\N	51.375626002265903	с.Подгорное, Школьная (МОУ Подгоренская СОШ), 12	Россия, Воронежская область, Новохоперский район, поселок Подгорное	0101000020E6100000A9674128EF9144407EC3448314B04940
30694	1	4	1046	54282	36969	\N	51.376002	с.Подгорное, ул.Октябрьская, д.40	Россия, Воронежская область, Новохоперский район, поселок Подгорное	0101000020E6100000D2E3F736FD914440849D62D520B04940
30683	1	4	1046	47263	36893	\N	51.189926	пос.Озерный, ул.Проезжая, д.17		0101000020E61000002E76FBAC32E944407E54C37E4F984940
30675	1	4	1046	18049	36097	\N	51.079931000000002	р.п.Новохоперский, пер.Пушкина, д.21		0101000020E610000012FB04508CC84440E277D32D3B8A4940
30677	1	4	1046	18049	36070	\N	51.095066834809998	р.п.Новохоперский, ул.Железнодорожная, д.8	Россия, Воронежская область, Новохоперский район, поселок Новохоперск	0101000020E6100000BCC96FD1C9CE4440E4F6CB272B8C4940
30678	1	4	1046	18049	36099	\N	51.079931000000002	р.п.Новохоперский, ул.Шолохова, д.59		0101000020E610000012FB04508CC84440E277D32D3B8A4940
30710	1	4	1046	18049	36443	\N	51.087558000000001	г.Новохоперск, ул.Клиническая, д.2		0101000020E61000000BCF4BC5C6CA44406840BD19358B4940
30676	1	4	1046	18049	9858	\N	51.079931000000002	р.п.Новохоперский, ул.Железнодорожная, д.27		0101000020E610000012FB04508CC84440E277D32D3B8A4940
30670	1	4	1046	18049	35807	\N	51.087558000000001	г.Новохоперск, ул.25 Октября, д.32	Россия, Воронежская область, Новохоперский район, поселок Новохоперск	0101000020E61000000BCF4BC5C6CA44406840BD19358B4940
30691	1	4	1046	47428	36760	\N	51.248697999999997	пос.Новопокровский, ул.Калинина, д.1		0101000020E610000019C6DD205AA74440514A0856D59F4940
30690	1	4	1046	19076	36676	\N	51.129094000000002	пос.Некрылово, ул.Курортная, д.2б		0101000020E6100000D498107349BB44400F0EF62686904940
30692	1	4	1046	47446	37108	\N	51.284005000000001	пос.Ленинский, ул.Центральная, д.44		0101000020E61000009E78CE1610A2444043739D465AA44940
30689	1	4	1046	47385	36090	\N	51.1712188649757	с.Красное, ул.Советская, д.36а	Россия, Воронежская область, Новохоперский район, поселок Красное	0101000020E6100000266E15C440BF444017BA1281EA954940
30682	1	4	1046	54360	36737	\N	51.027063881533103	с.Каменка-Садовка, ул.Онысюка, д.4	Россия, Воронежская область, Новохоперский район, поселок Камено-Садовка	0101000020E610000004560E2DB2D14440117349D576834940
30674	1	4	1046	54392	\N	\N	51.111951163531103	хут.Замельничный, здание Новохоперского участкового лесничества	Россия, Воронежская область, Новохоперский район, поселок Замельничный	0101000020E610000086048C2E6FD4444093E00D69548E4940
30705	1	4	1046	19864	36440	\N	51.156874000000002	р.п.Елань-Коленовский, просп. Кольцова, д.10		0101000020E610000015527E52ED914440DECB7D7214944940
30706	1	4	1046	19864	36087	\N	51.156874000000002	р.п.Елань-Коленовский, ул.Центральная, д.4		0101000020E610000015527E52ED914440DECB7D7214944940
30696	1	4	1046	19376	36535	\N	51.138556000000001	с.Елань-Колено, просп.Революции, д.10	Россия, Воронежская область, Новохоперский район, поселок Елань-Колено	0101000020E610000027C286A7579C44401155F833BC914940
30697	1	4	1046	19376	35854	\N	51.138556000000001	с.Елань-Колено, ул.Крейзера, д.9	Россия, Воронежская область, Новохоперский район, поселок Елань-Колено	0101000020E610000027C286A7579C44401155F833BC914940
30698	1	4	1046	19376	36433	\N	51.138556000000001	с.Елань-Колено, ул.Мостовая, д.130		0101000020E610000027C286A7579C44401155F833BC914940
30463	1	4	872	47463	36982	\N	49.841897000000003	с.Куликовка, Центральная, 28		0101000020E610000017B9A7AB3BC24340DECCE847C3EB4840
30699	1	4	1046	19555	\N	\N	51.119241000000002	пос.Димитровский, здание фельдшерско-акушерского пункта	Россия, Воронежская область, Новохоперский район, поселок Димитровский	0101000020E610000059F78F85E8904440D2AB014A438F4940
30684	1	4	1046	47266	36826	\N	51.208240000000004	пос.Варварино, ул.Лесная, д.59		0101000020E610000079793A5794DC44400ADCBA9BA79A4940
30701	1	4	1046	19653	36827	\N	51.002099999999999	с.Бурляевка, пер.Школьный, д.10		0101000020E61000000E6B2A8BC2A644402AA913D044804940
30693	1	4	1046	19256	36948	\N	51.216704	пос.Бороздиновский, ул.Спортивная, д.7		0101000020E61000001D9430D3F6AB4440C974E8F4BC9B4940
30700	1	4	1046	54462	37311	\N	51.038656000000003	пос.Березовка, ул.Центральная, д.7	Россия, Воронежская область, Новохоперский район, поселок Березовка	0101000020E6100000A8A78FC01F964440A8E507AEF2844940
30686	1	4	1046	47330	36399	\N	51.203555999999999	с.Алферовка, ул.Центральная, д.134		0101000020E6100000C8940F41D5D44440C9737D1F0E9A4940
30665	1	4	1427	54371	36866	\N	51.7539470127426	п.Шуберское, ул.Подлесная, д.19		0101000020E61000004D10751F80B643406AF5D55581E04940
30664	1	4	1427	54371	36866	\N	51.753600133904797	п.Шуберское, ул.Подлесная, д.20	Россия, Воронежская область, Воронеж, Железнодорожный район	0101000020E6100000207F69519FB64340FF21FDF675E04940
30662	1	4	1427	54337	36697	\N	51.656807999999998	с.Хреновое, ул.Молодежная, д.16А	Россия, Воронежская область, Новоусманский район, поселок Хреновое	0101000020E6100000FE9C82FC6CCA434026E0D74812D44940
30661	1	4	1427	17575	36626	\N	51.612630000000003	с.Хлебное, ул.Буденного, д.4	Россия, Воронежская область, Новоусманский район, поселок Хлебное	0101000020E61000008658FD1186E743403546EBA86ACE4940
30660	1	4	1427	46794	36424	\N	51.764426	п.Трудовое, ул.Центральная, д.1А		0101000020E610000083BEF4F6E7DC4340261B0FB6D8E14940
30657	1	4	1427	46726	36964	\N	51.576563999999998	п.Тимирязево, ул.Тимирязева, д.14	Россия, Воронежская область, Новоусманский район, поселок Тимирязево	0101000020E61000005ABDC3EDD0D24340850662D9CCC94940
30655	1	4	1427	54401	\N	\N	51.499913691692399	п.Лекарственный, д.47	Россия, Воронежская область, Новоусманский район, поселок Совхоз Лекраспром	0101000020E61000007808E3A771CD43400168942EFDBF4940
30656	1	4	1427	54305	36316	\N	51.504458999999997	"п.совхоза ""Воронежский"", ул.Воронежская, д.1"		0101000020E6100000A56ABB09BEA543402096CD1C92C04940
30663	1	4	1427	17706	36397	\N	51.618547	с.Рыкань, ул.Центральная, д.23		0101000020E61000006C41EF8D21C64340FB04508C2CCF4940
30651	1	4	1427	17023	36398	\N	51.647190999999999	с.Рождественская Хава, ул.Советская, д.35		0101000020E61000001FD7868A71D84340FDA19927D7D24940
30652	1	4	1427	17023	36510	\N	51.647190999999999	с.Рождественская Хава, ул.Механизаторов, д.18	Россия, Воронежская область, Новоусманский район, поселок Рождественская Хава	0101000020E61000001FD7868A71D84340FDA19927D7D24940
30650	1	4	1427	17023	36395	\N	51.647190999999999	с.Рождественская Хава, ул.Карла Маркса, д.82		0101000020E61000001FD7868A71D84340FDA19927D7D24940
30653	1	4	1427	19575	36625	\N	51.515911000000003	с.Рогачевка, ул.Ворошилова, д.8	Россия, Воронежская область, Новоусманский район, поселок Рогачевка	0101000020E6100000884B8E3BA5C74340C652245F09C24940
30635	1	4	1427	46249	36624	\N	51.585759000000003	с.Парусное, ул.Центральная, д.1	Россия, Воронежская область, Новоусманский район, поселок Парусное	0101000020E6100000164F3DD2E0C24340392BA226FACA4940
30644	1	4	1427	54446	37246	\N	51.500808999999997	"п.2 отделения совхоза ""Масловский"", ул.Молодежная, д.25"	Россия, Воронежская область, Новоусманский район, поселок Отдел N2 совхоза Масловский	0101000020E6100000C2C073EFE1B843406F4562821AC04940
30640	1	4	1427	54294	36234	\N	51.716982999999999	"п.1 отделения совхоза ""Новоусманский"", ул.Ленина, д.1"	Россия, Воронежская область, Новоусманский район, поселок Отдел N1 совхоза Новоусманский	0101000020E6100000DE3EABCC94BE4340DC645419C6DB4940
30643	1	4	1427	54303	36276	\N	51.539780999999998	"п.1 отделения совхоза ""Масловский"", ул.Ленина, д.43"	Россия, Воронежская область, Новоусманский район, поселок Отдел N1 совхоза Масловский	0101000020E6100000D862B7CF2AAB43404700378B17C54940
30647	1	4	1427	46497	35980	\N	51.755133000000001	с.Орлово, ул.Свободы, д.68	Россия, Воронежская область, Новоусманский район, поселок Орлово	0101000020E6100000E7012CF2EBCB4340B090B932A8E04940
94924	1	4	1427	46497	36154	\N	51.755133000000001	с.Орлово, ул.Мира, 14-а;		0101000020E6100000E7012CF2EBCB4340B090B932A8E04940
30648	1	4	1427	46497	36949	\N	51.755133000000001	с.Орлово, ул.Анатолия Гуцало, д.60		0101000020E6100000E7012CF2EBCB4340B090B932A8E04940
30633	1	4	1427	15894	35942	\N	51.632272999999998	с.Новая Усмань, ул.Школьная, д.1		0101000020E6100000BF0F070951B4434068925852EED04940
30629	1	4	1427	15894	35858	\N	51.632272999999998	с.Новая Усмань, ул.Советская, д.1	Россия, Воронежская область, Новоусманский район, поселок Новая Усмань	0101000020E6100000BF0F070951B4434068925852EED04940
30637	1	4	1427	15894	35925	\N	51.632272999999998	с.Новая Усмань, ул.Полевая, д.1А, корп.1		0101000020E6100000BF0F070951B4434068925852EED04940
30636	1	4	1427	15894	35925	\N	51.629635088589602	с.Новая Усмань, ул.Полевая, д.1П	Россия, Воронежская область, Новоусманский район, поселок Новая Усмань	0101000020E6100000A81B28F04EB443405FB532E197D04940
30631	1	4	1427	15894	35726	\N	51.632272999999998	с.Новая Усмань, ул.Песоцкая, д.69		0101000020E6100000BF0F070951B4434068925852EED04940
30669	1	4	1427	15894	35738	\N	51.632272999999998	с.Новая Усмань, ул.Ленина, д.310		0101000020E6100000BF0F070951B4434068925852EED04940
30634	1	4	1427	15894	35738	\N	51.632272999999998	с.Новая Усмань, ул.Ленина, д.141		0101000020E6100000BF0F070951B4434068925852EED04940
30632	1	4	1427	15894	35738	\N	51.632272999999998	с.Новая Усмань, ул.Ленина, д.60В		0101000020E6100000BF0F070951B4434068925852EED04940
30627	1	4	1427	15894	35738	\N	51.632272999999998	с.Новая Усмань, ул.Ленина, д.301	Россия, Воронежская область, Новоусманский район, поселок Новая Усмань	0101000020E6100000BF0F070951B4434068925852EED04940
30630	1	4	1427	15894	36169	\N	51.632272999999998	с.Новая Усмань, ул.Заречная, д.1		0101000020E6100000BF0F070951B4434068925852EED04940
30467	1	4	872	47547	36731	\N	49.700367999999997	пос.Кузнецовский, Центральная, 40		0101000020E610000074F04C68922644401C959BA8A5D94840
30645	1	4	1427	16795	36566	\N	51.684652	с.Нижняя Катуховка, ул.Ленина, д.116	Россия, Воронежская область, Новоусманский район, поселок Нижняя Катуховка	0101000020E61000004E4700378BEF43400C923EADA2D74940
30649	1	4	1427	46563	37107	\N	51.775382999999998	с.Макарье, ул.Буденного, д.21А		0101000020E6100000B51B7DCC07D44340EB6F09C03FE34940
30659	1	4	1427	46761	36607	\N	51.517749000000002	с.Крыловка, ул.Центральная, д.2	Россия, Воронежская область, Новоусманский район, поселок Крыловка	0101000020E6100000C2A38D23D6D44340B344679945C24940
30658	1	4	1427	17420	37040	\N	51.550091999999999	с.Горенские Выселки, ул.70 Лет Октября, д.18		0101000020E61000004FCE50DCF1DE434047E5266A69C64940
30668	1	4	1427	17851	36129	\N	51.758946000000002	п.Воля, ул.Школьная, д.2А		0101000020E6100000B6D617096DC143400BB77C2425E14940
30667	1	4	1427	17851	36128	\N	51.758946000000002	п.Воля, ул.Садовая, д.61А		0101000020E6100000B6D617096DC143400BB77C2425E14940
30666	1	4	1427	17851	36052	\N	51.758946000000002	п.Воля, ул.Студенческая, д.86А		0101000020E6100000B6D617096DC143400BB77C2425E14940
30605	1	4	1307	54454	37261	\N	51.430143999999999	х.Сычевка, ул.Полевая, д.2	Россия, Воронежская область, Нижнедевицкий район, поселок Сычевка	0101000020E6100000B726DD96C83343400A4966F50EB74940
30604	1	4	1307	54342	36713	\N	51.422505999999998	"""пос. с-за """"Кучугуровский"""", ул.Садовая, д.10"	Россия, Воронежская область, Нижнедевицкий район, поселок Совхоз Кучугуровский	0101000020E6100000A1BFD02346294340902E36AD14B64940
30611	1	4	1307	15103	36997	\N	51.242676000000003	с.Скупая Потудань, ул.Ленина, д.37		0101000020E6100000C00644882B41434016C3D501109F4940
30607	1	4	1307	14899	36421	\N	51.380448000000001	с.Синие Липяги, пер.Школьный, д.10а		0101000020E61000002CF180B2293D434010EA2285B2B04940
30606	1	4	1307	14899	37104	\N	51.380448000000001	с.Синие Липяги, ул.Первомайская, д.5в		0101000020E61000002CF180B2293D434010EA2285B2B04940
30608	1	4	1307	14899	36994	\N	51.380448000000001	с.Синие Липяги, ул.Автоматчиков, д.31а		0101000020E61000002CF180B2293D434010EA2285B2B04940
30600	1	4	1307	45521	36393	\N	51.498016999999997	с.Першино, ул.Меркулова, 10		0101000020E61000000E4C6E14592D43400FED6305BFBF4940
30599	1	4	1307	45521	36393	\N	51.498016999999997	с.Першино, ул.Меркулова, д.10		0101000020E61000000E4C6E14592D43400FED6305BFBF4940
30609	1	4	1307	15021	36891	\N	51.293512999999997	с.Острянка, ул.Центральная, д.40		0101000020E6100000944DB9C2BB344340B5F97FD591A54940
30593	1	4	1307	14249	36748	\N	51.636839999999999	с.Новая Ольшанка, ул.Советская, д.1		0101000020E6100000C425C79DD23343406F641EF983D14940
30602	1	4	1307	14629	36945	\N	51.543534000000001	с.Нижнее Турово, ул.Чапаева, д.21		0101000020E61000002864E76D6C4C4340CD21A98592C54940
30601	1	4	1307	14629	37038	\N	51.543534000000001	с.Нижнее Турово, ул.Проспект Труда, д.31		0101000020E61000002864E76D6C4C4340CD21A98592C54940
30598	1	4	1307	54329	36741	\N	51.627245966376698	"пос. с-за ""Нижнедевицкий"", ул.Чагадаева, д.16"	Россия, Воронежская область, Нижнедевицкий район, поселок Нижнедевицкий	0101000020E610000095B7239C16224340FE45D09849D04940
30597	1	4	1307	54329	36687	\N	51.631519358356897	"""пос. с-за """"Нижнедевицкий"""", ул.Мира, д.17"	Россия, Воронежская область, Нижнедевицкий район, поселок Нижнедевицкий	0101000020E6100000F3C64961DE214340BCE6559DD5D04940
30584	1	4	1307	13762	35992	\N	51.562109999999997	c.Нижнедевицк, пл.Ленина, д.1а		0101000020E6100000D55B035B252E434095607138F3C74940
30582	1	4	1307	13762	35992	\N	51.562109999999997	c.Нижнедевицк, пл.Ленина, д.3		0101000020E6100000D55B035B252E434095607138F3C74940
30612	1	4	1307	13762	36942	\N	51.546251290488399	пос.Нижнедевицк, ул.Центральная, д.22	Россия, Воронежская область, Нижнедевицкий район, поселок Нижнедевицк	0101000020E6100000CBBE2B82FF2B43402234828DEBC54940
30592	1	4	1307	13762	36942	\N	51.562109999999997	пос. Нижнедевицк, ул.Центральная, д.22	Россия, Воронежская область, Нижнедевицкий район, поселок Нижнедевицк	0101000020E6100000D55B035B252E434095607138F3C74940
30583	1	4	1307	13762	35721	\N	51.557417863005298	с.Нижнедевицк, ул.Луговая, д.1	Россия, Воронежская область, Нижнедевицкий район, поселок Нижнедевицк	0101000020E6100000BB253960572F4340D219187959C74940
30614	1	4	1307	13762	37156	\N	51.562109999999997	с.Нижнедевицк, ул.Заводская, д.27		0101000020E6100000D55B035B252E434095607138F3C74940
30603	1	4	1307	45587	36946	\N	51.470965999999997	с.Михнево, ул.Садовая, д.31		0101000020E6100000F16778B30647434093C3279D48BC4940
30980	1	4	1307	46263	37271	\N	51.333354999999997	с.Лебяжье, Чапаева, 80		0101000020E61000000C5C1E6B462C4340A27A6B60ABAA4940
30596	1	4	1307	19644	36944	\N	51.597465	с.Кучугуры, ул.Заречная, д.45		0101000020E61000008A5A9A5B2126434098C0ADBB79CC4940
30613	1	4	1307	45349	36388	\N	51.646386	пос.Курбатово, ул.Школьная, д.114		0101000020E6100000FF21FDF6754A4340CF4BC5C6BCD24940
30590	1	4	1307	45349	36509	\N	51.646386	пос.Курбатово, ул.Гагарина, д.29		0101000020E6100000FF21FDF6754A4340CF4BC5C6BCD24940
30595	1	4	1307	45431	36941	\N	51.503253000000001	с.Глазово, ул.Октября, д.36		0101000020E6100000287E8CB96B414340944E24986AC04940
30594	1	4	1307	45431	37035	\N	51.503253000000001	с.Глазово, ул.Мира, д.98		0101000020E6100000287E8CB96B414340944E24986AC04940
30585	1	4	1307	13870	37032	\N	51.567076	с.Вязноватовка, ул.Мира, д.112		0101000020E610000019AF7955673B43405A2C45F295C84940
30586	1	4	1307	13870	36993	\N	51.567076	с.Вязноватовска, ул.Загорского, д.2		0101000020E610000019AF7955673B43405A2C45F295C84940
30589	1	4	1307	54412	37248	\N	51.614776999999997	с.Верхнее Турово, ул.Молодежная, д.17		0101000020E61000005890662C9A4A43409FAA4203B1CE4940
30587	1	4	1307	54412	37197	\N	51.615085034480302	с.Верхнее Турово, ул.Мира, д.106	Россия, Воронежская область, Нижнедевицкий район, поселок Верхнетурово	0101000020E6100000D235936FB64B43404DA1F31ABBCE4940
30588	1	4	1307	54412	37260	\N	51.614776999999997	с.Верхнее Турово, ул.Кирова, д.10	Россия, Воронежская область, Нижнедевицкий район, поселок Верхнетурово	0101000020E61000005890662C9A4A43409FAA4203B1CE4940
30546	1	4	1011	48978	36572	\N	50.937955244867901	с.Щучье, Советская, 74-а, здание Дома культуры	Россия, Воронежская область, Лискинский район, поселок Щучье	0101000020E61000003D47E4BB94DE4340520FD1E80E784940
30568	1	4	1011	54388	37041	\N	51.082386999999997	с.Троицкое, Буденного, 118б, ДК	Россия, Воронежская область, Лискинский район, поселок Троицкое	0101000020E61000006281AFE8D69D4340CA4E3FA88B8A4940
30448	1	4	872	7431	37099	\N	49.581133000000001	с.Колещатовка, Ленина, 26		0101000020E6100000662D05A4FDF143402DD0EE9062CA4840
30577	1	4	1011	13499	36508	\N	51.210712000000001	с.Тресоруково, Советская, 31а, здание Дома культуры	Россия, Воронежская область, Лискинский район, поселок Тресоруково	0101000020E6100000287CB60E0EC24340F86F5E9CF89A4940
30557	1	4	1011	12624	37030	\N	51.115231999999999	с.Второе Сторожевое, Центральная, 2б, Дом культуры		0101000020E610000097A949F086D44340F1B913ECBF8E4940
30569	1	4	1011	13118	36462	\N	51.180362000000002	с.Старая Хворостань, переулок Советский, 3, здание Дома культуры	Россия, Воронежская область, Лискинский район, поселок Старая Хворостань	0101000020E6100000228E75711BA7434078B81D1A16974940
30556	1	4	1011	12427	\N	\N	51.085209999999996	с.Средний Икорец, санаторий им Цюрупы, здание клуба		0101000020E6100000B0C91AF510E1434065A54929E88A4940
30553	1	4	1011	12427	36065	\N	51.085209999999996	с.Средний Икорец, площадь Кирова, 9, Дом культуры	Россия, Воронежская область, Лискинский район, поселок Средний Икорец	0101000020E6100000B0C91AF510E1434065A54929E88A4940
30554	1	4	1011	12427	35783	\N	51.085209999999996	с.Средний Икорец, площадь Революции, 78, здание сельской администрации		0101000020E6100000B0C91AF510E1434065A54929E88A4940
30555	1	4	1011	12427	35978	\N	51.085209999999996	с.Средний Икорец, Зеленая, 60а, здание сельского клуба		0101000020E6100000B0C91AF510E1434065A54929E88A4940
30506	1	4	1011	48282	37181	\N	51.016159999999999	с.Солонцы, ул.Путь Ленина, д.70		0101000020E610000029E9616875E243406EC0E78711824940
30572	1	4	1011	11685	37201	\N	51.130847000000003	с.Селявное-2, площадь Победы, 27а, здание сельского клуба	Россия, Воронежская область, Лискинский район, поселок Селявное	0101000020E6100000F1457BBC909C4340CEE33098BF904940
30538	1	4	1011	11685	36390	\N	51.1409988581444	с.Селявное, 9 мая, 23, здание Дома культуры	Россия, Воронежская область, Лискинский район, поселок Селявное	0101000020E61000001B2AC6F99B9C434065E256410C924940
30552	1	4	1011	49078	36991	\N	50.856437999999997	с. Пухово, Центральная, 43, сельский клуб		0101000020E61000008F56B5A4A3B643409C86A8C29F6D4940
30543	1	4	1011	54429	37224	\N	50.787826000000003	х.Прияр, Мичурина, 62, Приярский сельский клуб	Россия, Воронежская область, Лискинский район, поселок Прияр	0101000020E610000048C49448A2ED434021787C7BD7644940
30576	1	4	1011	13467	36564	\N	51.190468000000003	с.Почепское, Садовая, 6, здание Дома культуры		0101000020E610000092E9D0E979BD43409F77634161984940
30886	1	4	1011	46694	\N	\N	50.862726000000002	с.Петропавловка, ул.50 лет Октября, д.73 (Здание школы)	Россия, Воронежская область, Лискинский район, поселок Петропавловка	0101000020E61000006B64575A46EC434057B439CE6D6E4940
30541	1	4	1011	46694	37377	\N	50.862726000000002	с.Петропавловка, Административная, 4, Петропавловский Дом культуры		0101000020E61000006B64575A46EC434057B439CE6D6E4940
30535	1	4	1011	54327	36654	\N	50.853553815272001	с.Петровское, 40 лет Октября, 20а, здание сельской администарции	Россия, Воронежская область, Лискинский район, поселок Петровская	0101000020E6100000DB15FA6019CF43405CAFE941416D4940
30547	1	4	1011	12120	36795	\N	50.915227999999999	с.Переезжее, Коммунистическая, 23, сельский клуб		0101000020E6100000DDD3D51D8BE143401631EC3026754940
30573	1	4	1011	54426	37216	\N	51.121922729743098	х.Новозадонский, Центральная, 16а, сельский клуб	Россия, Воронежская область, Лискинский район, поселок Новозадонский	0101000020E61000004FAE2990D9A74340ABD0402C9B8F4940
30560	1	4	1011	54437	37235	\N	50.945689959804596	х.Никольский, Кирова, 138а, здание сельского клуба	Россия, Воронежская область, Лискинский район, поселок Никольский	0101000020E6100000888384285FC84340BE13B35E0C794940
30540	1	4	1011	11784	36160	\N	50.989282000000003	с.Нижний Икорец, Победы, 59, Нижнеикорецкий Дом культуры		0101000020E6100000D6FF39CC97DB4340C042E6CAA07E4940
30579	1	4	1011	54334	36693	\N	51.228245000000001	с.Нижне Марьино, Школьная, 2а, МОУ Нижнемарьинская СОШ	Россия, Воронежская область, Лискинский район, поселок Нижнемарьино	0101000020E61000004B033FAA61BF4340DE3CD521379D4940
30524	1	4	1011	10206	\N	\N	50.994197999999997	город Лиски, клуб досуга хутор Калач		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30516	1	4	1011	10206	\N	\N	50.967296013226097	город Лиски, красный уголок ПТО вагонного депо	Россия, Воронежская область, Лискинский район	0101000020E61000007A8D5DA27AC143409BC6F65AD07B4940
30531	1	4	7318	\N	36063	\N	50.9871686879004	город Лиски, Титова, 16, здание филиала МГУПС	Россия, Воронежская область, Лиски городской округ	0101000020E6100000F86C1D1CECBD43400150C58D5B7E4940
30509	1	4	1011	10206	35806	\N	50.994197999999997	город Лиски, Советская, 116, здание школы №4	Россия, Воронежская область, Лискинский район, Лиски	0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30514	1	4	1011	10206	35918	\N	50.994197999999997	город Лиски, проспект Ленина, 32а, здание гродского ДК		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30507	1	4	1011	10206	36020	\N	50.994197999999997	город Лиски, площадь Революции, 10-а, здание музея	Россия, Воронежская область, Лискинский район, Лиски	0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30515	1	4	1011	10206	35912	\N	50.994197999999997	город Лиски, Лысенко, 1, здание ЛПТТ им.Лысенко	Россия, Воронежская область, Лискинский район, Лиски	0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30533	1	4	1011	10206	36119	\N	50.994197999999997	город Лиски, Трудовые резервы, 62, здание школы №12	Россия, Воронежская область, Лискинский район, Лиски	0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30511	1	4	1011	10206	35710	\N	50.994197999999997	город Лиски, Трудовые Резервы, 60, здани е школы №10		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30510	1	4	1011	10206	35710	\N	50.994197999999997	город Лиски, Трудовые Резервы, 62, здание школы №12		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30526	1	4	1011	10206	35916	\N	50.994197999999997	город Лиски, Свердлова, 66, здание детской поликлиники	Россия, Воронежская область, Лискинский район, Лиски	0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30512	1	4	1011	10206	35713	\N	50.994197999999997	город Лиски, Маршала Жукова, 3, здание ПУ-20		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
95192	1	4	1011	10206	35696	\N	50.972942798349102	с.Лискинское, дом культуры, ул. 40лет Победы,10	Россия, Воронежская область, Лискинский район, Лиски	0101000020E61000005C74B2D47AC94340A2EF6E65897C4940
30530	1	4	1011	10206	35909	\N	50.994197999999997	город Лиски, 40 лет Октября, 64, здание КЦсоцобслуживания нас-я	Россия, Воронежская область, Лискинский район, Лиски	0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30521	1	4	1011	10206	35909	\N	50.994197999999997	город Лиски, 40 лет Октября, 62, здание Столовой ОАО МЭЗ	Россия, Воронежская область, Лискинский район, Лиски	0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30519	1	4	1011	10206	35909	\N	50.994197999999997	город Лиски, 40 лет Октября, 78, здание ПУ-40		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30522	1	4	1011	10206	35697	\N	50.994197999999997	город Лиски, 19 партсьезда, 5, здание школы №2		0101000020E6100000A0C37C7901C64340D2DF4BE1417F4940
30550	1	4	1011	12272	36563	\N	51.006821000000002	с.Копанище, Советская, 1, здание сельской администрации	Россия, Воронежская область, Лискинский район, поселок Копанище	0101000020E6100000ACA8C1340CAB434088F6B182DF804940
30545	1	4	1011	12026	35913	\N	50.837032999999998	с.Колыбелка, Садовая, 63, здание сельской администрации		0101000020E61000006553AEF02EE743401D56B8E5236B4940
30563	1	4	1011	49237	36647	\N	50.876874999999998	с.Коломыцево, Солнечная, 4, Дом культуры		0101000020E61000002BC24D4695C343400AD7A3703D704940
30551	1	4	1011	49068	35849	\N	50.886183000000003	с.Ковалево, Юбилейная, 25, Дом культуры		0101000020E6100000E0826C59BEB24340B6A2CD716E714940
30559	1	4	1011	12714	36093	\N	50.948425	с.Залужное, Школьная, 27а, здание школы		0101000020E61000001268B0A9F3C24340BADA8AFD65794940
30575	1	4	1011	49389	36463	\N	51.186877000000003	с.Ермоловка, Колхозная, 22, здание Дома культуры	Россия, Воронежская область, Лискинский район, поселок Ермоловка	0101000020E61000003C4CFBE6FEB64340F3AFE595EB974940
30536	1	4	1011	54276	35965	\N	51.138595871304403	с.Дракино, Молодежная, 9, МОУ Дракинская СОШ	Россия, Воронежская область, Лискинский район, поселок Дракино	0101000020E6100000BEBED6A546B443409FAD8383BD914940
30537	1	4	1011	54276	36123	\N	51.141552077806303	с.Дракино, Ленина, 110а, здание сельской администраци	Россия, Воронежская область, Лискинский район, поселок Дракино	0101000020E610000067D13B1570B5434079573D601E924940
30578	1	4	1011	49426	36623	\N	51.231358	с.Добрино, Придорожная, 7, МОУ Добринская СОШ		0101000020E61000005B40683D7CC3434080D591239D9D4940
30539	1	4	1011	54440	37239	\N	50.952116514056002	х.Дивногорье, Центральная, 11, начальная школа х.Дивногорье	Россия, Воронежская область, Лискинский район, поселок Дивногорье	0101000020E610000051FA42C879A543409A7B48F8DE794940
95193	1	4	1011	45408	35851	\N	51.154812	п.Давыдовка, здание школы,ул.Ленина,32	Россия, Воронежская область, Лискинский район, поселок Давыдовка	0101000020E6100000E41071732AB74340A1832EE1D0934940
95194	1	4	1011	45408	36657	\N	51.154812	Давыдовский лесхоз, ул.Филипченко,29		0101000020E6100000E41071732AB74340A1832EE1D0934940
95195	1	4	1011	45408	36095	\N	51.154812	п.Давыдовка, дом культуры, ул.Октябрьская,16		0101000020E6100000E41071732AB74340A1832EE1D0934940
30567	1	4	1011	45408	35852	\N	51.154812	п.Давыдовка, Ленина, 34а, культурно-досуговый Центр		0101000020E6100000E41071732AB74340A1832EE1D0934940
30566	1	4	1011	45408	36419	\N	51.154812	п.Давыдовка, Заводская, 10, МОУ Вознесеновская СОШ		0101000020E6100000E41071732AB74340A1832EE1D0934940
30574	1	4	1011	13386	36603	\N	51.118828000000001	с.Бодеевка, Советская, 40, здание Дома культуры		0101000020E6100000BB0B941458A44340AFEC82C1358F4940
30571	1	4	1011	13183	36745	\N	51.207754999999999	с.Аношкино, Центральная, 58, здание клуба		0101000020E6100000EECF4543C6A543404D4A41B7979A4940
30544	1	4	7318	54315	36517	\N	50.979824000000001	с.Лиски, Советская, 304, МОУ Лисянская СОШ	Россия, Воронежская область, Лиски городской округ	0101000020E61000000A2B155454C14340FFEA71DF6A7D4940
30505	1	4	1039	48252	36939	\N	51.299072000000002	с.Старина, ул.Пришкольная, д.9	Россия, Воронежская область, Каширский район, поселок Старина	0101000020E6100000A27BD6355ABE43401D93C5FD47A64940
30504	1	4	1039	45728	\N	\N	51.279881000000003	пос.Степной, ул.Ленина, д.1	Россия, Воронежская область, Каширский район, поселок Отдел N1 совхоза Степной	0101000020E610000090F63FC05ADD4340CAE2FE23D3A34940
30494	1	4	1039	9546	36471	\N	51.370322999999999	с.Олень-Колодезь, ул.Проспект Революции, д.30	Россия, Воронежская область, Каширский район, поселок Олень-Колодезь	0101000020E6100000E695EB6D339F434072FA7ABE66AF4940
30618	1	4	1039	15316	35967	\N	51.316228000000002	г.Нововоронеж, площадь имени Ленина, 1	Россия, Воронежская область, Каширский район, Нововоронеж	0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30625	1	4	1039	15316	35816	\N	51.316228000000002	г.Нововоронеж, Коммунальная, 5		0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30621	1	4	1039	15316	35917	\N	51.316228000000002	г.Нововоронеж, Первомайская, 9 В		0101000020E6100000CCB392567C9B43402D0ABB287AA84940
30615	1	4	1039	15316	35923	\N	51.305159906019902	г.Нововоронеж, Октябрьская, 1	Россия, Воронежская область, Каширский район, Нововоронеж	0101000020E61000001ADCD6169E9B434010069E7B0FA74940
30617	1	4	1039	15316	35871	\N	51.309070769310303	г.Нововоронеж, Ленина, 10 А		0101000020E610000080272D5C569B43402E9276A38FA74940
30624	1	4	1039	15316	35757	\N	51.315187311134899	г.Нововоронеж, Космонавтов, 27 А	Россия, Воронежская область, Каширский район, Нововоронеж	0101000020E61000000DFE7E315B9A4340EB8F300C58A84940
30626	1	4	1039	15316	35960	\N	51.324198304730501	г.Нововоронеж, Воронежское шоссе, 13	Россия, Воронежская область, Каширский район, Нововоронеж	0101000020E610000060EAE74D459E4340DDB6EF517FA94940
30501	1	4	1039	48183	37103	\N	51.340366000000003	с.Мосальское, ул.Советская, д.37а		0101000020E6100000F3583332C8C34340CE55F31C91AB4940
30502	1	4	1039	48186	36562	\N	51.317404000000003	с.Можайское, ул.Ленина, д.17		0101000020E610000088DA368C82D443404FCFBBB1A0A84940
30702	1	4	1039	27475	\N	\N	51.299166999999997	пос.Михайловский, здание МОУ Михайловской ООШ	Россия, Воронежская область, Каширский район, поселок Михайловский	0101000020E6100000821ABE8575DD43406E85B01A4BA64940
30500	1	4	1039	9875	36454	\N	51.336005	с.Левая Россошь, ул.Пролетарская, д.6	Россия, Воронежская область, Каширский район, поселок Левая Россошь	0101000020E6100000C7D79E5912B4434070253B3602AB4940
30498	1	4	1039	48117	36668	\N	51.322634000000001	с.Круглое, ул.Карла Маркса, д.52		0101000020E6100000ADDEE17668A64340F14927124CA94940
30497	1	4	1039	9694	35899	\N	51.3909295903103	с.Красный Лог, ул.Степная, д.3	Россия, Воронежская область, Каширский район, поселок Красный Лог	0101000020E61000002A1A6B7F67E343403C8386FE09B24940
30495	1	4	1039	9626	36561	\N	51.392932000000002	с.Кондрашкино, ул.Молодежная, д.2	Россия, Воронежская область, Каширский район, поселок Кондрашкино	0101000020E61000008D09319754D74340A4C684984BB24940
30496	1	4	1039	9656	37102	\N	51.438085117657003	с.Коломенское, ул.Первомайская, д.61	Россия, Воронежская область, Каширский район, поселок Коломенское	0101000020E61000004E0D349F73D5434020EF552B13B84940
30492	1	4	1039	54308	36354	\N	51.348568611708302	пос.Колодезный, ул.Ленина, д.42а	Россия, Воронежская область, Каширский район, поселок Колодезная	0101000020E61000008313D1AFADA5434020B3B3E89DAC4940
30491	1	4	1039	54300	36265	\N	51.350003000000001	пос.Колодезный, ул.Центральная, д.18а	Россия, Воронежская область, Каширский район, поселок Колодезная	0101000020E610000056478E7406A643403E40F7E5CCAC4940
30481	1	4	1039	47797	35983	\N	51.414479999999998	с.Каширское, ул.Олимпийская, д.3		0101000020E610000020240B98C0CD43404C6C3EAE0DB54940
30482	1	4	1039	47797	36091	\N	51.414479999999998	с.Каширское, ул.Мира, д.1		0101000020E610000020240B98C0CD43404C6C3EAE0DB54940
30483	1	4	1039	47797	36461	\N	51.414479999999998	с.Каширское, ул.3 Интернационала, д.92	Россия, Воронежская область, Каширский район, поселок Каширское	0101000020E610000020240B98C0CD43404C6C3EAE0DB54940
30490	1	4	1039	54439	37237	\N	51.360340999999998	с.Каменно-Верховка, ул.Мира, д.15	Россия, Воронежская область, Каширский район, поселок Камено-Верховка	0101000020E6100000D6E3BED53A934340373465A71FAE4940
30488	1	4	1039	47934	35706	\N	51.448529999999998	пос.им.Дзержинского, ул.Школьная, д.60		0101000020E6100000D2FF722D5A9E43402FA3586E69B94940
30503	1	4	1039	48224	37027	\N	51.215124000000003	пос.Ильича, ул.Новая, д.8		0101000020E61000002C82FFAD64D94340D84AE82E899B4940
30489	1	4	1039	9332	36503	\N	51.349249999999998	с.Запрудское, ул.Ленина, д.19а		0101000020E610000096067E54C3DE434062105839B4AC4940
30486	1	4	1039	9185	36644	\N	51.298260999999997	с.Данково, ул.Мира, д.23		0101000020E6100000E886A6ECF4C343400C569C6A2DA64940
30487	1	4	1039	9185	36620	\N	51.298260999999997	с.Данково, ул.Кольцовская, д.1а		0101000020E6100000E886A6ECF4C343400C569C6A2DA64940
30485	1	4	1039	47857	36156	\N	51.406390000000002	с.Боево, ул.Школьная, д.9		0101000020E6100000840CE4D9E5A94340F2B5679604B44940
30484	1	4	1039	9105	36887	\N	51.421557	с.Бирюченское, ул.Пушкинская, д.48		0101000020E6100000785E2A36E6C343402F336C94F5B54940
30470	1	4	872	8490	36938	\N	49.860855000000001	с.Шевченково, Советская, 47		0101000020E6100000DA8EA9BBB2E343408ECC237F30EE4840
30477	1	4	872	8791	37091	\N	49.899701	с.Фисенково, Советская, 69, а		0101000020E610000075CDE49B6DEA4340D996016729F34840
30475	1	4	872	8727	36667	\N	49.739350000000002	с.Титаревка, Победы, 51	Россия, Воронежская область, Кантемировский район, поселок Титаревка	0101000020E610000074EB353D2814444018265305A3DE4840
30473	1	4	872	8633	35771	\N	49.862045999999999	с.Талы, Центральная, 163		0101000020E61000004C8E3BA583094440E5D2F88557EE4840
14667	1	4	872	48832	37093	\N	49.960495999999999	с.Софиевка, Луговая, 45		0101000020E61000006729594E42CD43402BF86D88F1FA4840
30469	1	4	872	54402	37184	\N	49.834105099804198	хут.Соленый, Школьная, 60	Россия, Воронежская область, Кантемировский район, поселок Соленый	0101000020E6100000070ABC934FD343400D37E0F3C3EA4840
30471	1	4	872	8517	36502	\N	49.800981	с.Смаглеевка,  50 лет Октября, 16		0101000020E61000000A2E56D460F24340D3DB9F8B86E64840
30472	1	4	872	8584	36732	\N	49.811976344251903	с.Скнаровка, Широкая, 2	Россия, Воронежская область, Кантемировский район, поселок Скнаровка	0101000020E61000008B6CE7FBA9F7434086915ED4EEE74840
30476	1	4	872	8765	36733	\N	49.772255000000001	с.Рудаевка, Центральная, 17		0101000020E610000082FE428F180D444014967840D9E24840
14668	1	4	872	54316	36519	\N	49.888573198484998	с.Писаревка, Ленина, 8, б	Россия, Воронежская область, Кантемировский район, поселок Писаревка	0101000020E6100000BB7B80EECB194440E78D93C2BCF14840
30451	1	4	872	7593	37153	\N	49.814450999999998	с.Пасюковка, Колхозная, 26		0101000020E61000008446B071FDD94340E5982CEE3FE84840
30468	1	4	872	47565	37101	\N	49.864496000000003	с.Пасеково, Мира, 55		0101000020E610000003603C8386DC4340ECC20FCEA7EE4840
30449	1	4	872	54346	36708	\N	49.770933999999997	пос.Охразовад, Школьная, 13	Россия, Воронежская область, Кантемировский район, поселок Охровый Завод	0101000020E6100000A5BE2CEDD4EA4340EEAF1EF7ADE24840
30466	1	4	872	6561	37056	\N	49.668714000000001	с.Осиковка, Центральная, 18		0101000020E610000089997D1EA32244404D309C6B98D54840
30455	1	4	872	47296	37096	\N	49.738965	с.Новопавловка, Мира, 29		0101000020E61000004A404CC285004440BFF1B56796DE4840
30462	1	4	872	47296	37198	\N	49.738965	хут.Новопавловка, Луговая, 11	Россия, Воронежская область, Кантемировский район, поселок Новопавловка	0101000020E61000004A404CC285004440BFF1B56796DE4840
30465	1	4	872	8255	36051	\N	49.722504000000001	с.Новомарковка, Советская, 14		0101000020E61000008A01124DA0DE4340569DD5027BDC4840
30464	1	4	872	54293	36228	\N	49.831102000000001	с.Новобелое, Советская, 27	Россия, Воронежская область, Кантемировский район, поселок Новобелая	0101000020E6100000D32EA699EEA54340F2D1E28C61EA4840
30461	1	4	872	54376	36910	\N	49.891351	с.Михайловка, Юбилейная, 19	Россия, Воронежская область, Кантемировский район, поселок Михайловка	0101000020E610000029B16B7BBBCF4340E22021CA17F24840
30456	1	4	872	47324	36958	\N	49.968110000000003	с.Митрофановка, пр.Строителей, 16		0101000020E61000005950189469D843401D774A07EBFB4840
30459	1	4	872	47324	36083	\N	49.968110000000003	с.Митрофановка, Элеваторская, 5		0101000020E61000005950189469D843401D774A07EBFB4840
29842	1	4	872	47324	37036	\N	49.968110000000003	с.Митрофановка, Ленина, 105	Россия, Воронежская область, Кантемировский район, поселок Митрофановка	0101000020E61000005950189469D843401D774A07EBFB4840
30458	1	4	872	47324	36427	\N	49.968110000000003	с.Митрофановка, Большевик, 32		0101000020E61000005950189469D843401D774A07EBFB4840
30452	1	4	872	47234	36598	\N	49.743658000000003	с.Касьяновка, Театральная, 14	Россия, Воронежская область, Кантемировский район, поселок Касьяновка	0101000020E61000004CA8E0F082E2434053B4722F30DF4840
30438	1	4	872	6847	35691	\N	49.701690999999997	р.п.Кантемировка, Победы, 30	Россия, Воронежская область, Кантемировский район, поселок Кантемировка	0101000020E61000008B87F71C58F04340E272BC02D1D94840
30436	1	4	872	6847	35805	\N	49.701690999999997	р.п.Кантемировка, Первомайская, 14	Россия, Воронежская область, Кантемировский район, поселок Кантемировка	0101000020E61000008B87F71C58F04340E272BC02D1D94840
30442	1	4	872	6847	35892	\N	49.704029027431702	р.п.Кантемировка, Шевченко, 96	Россия, Воронежская область, Кантемировский район, поселок Кантемировка	0101000020E6100000F2608BDD3EEF4340C1374D9F1DDA4840
30439	1	4	872	6847	36619	\N	49.701690999999997	р.п.Кантемировка, Строителей, 1, а		0101000020E61000008B87F71C58F04340E272BC02D1D94840
30437	1	4	872	6847	35702	\N	49.701690999999997	р.п.Кантемировка, Победы, 11		0101000020E61000008B87F71C58F04340E272BC02D1D94840
30440	1	4	872	6847	36666	\N	49.701690999999997	р.п.Кантемировка, Кирпичная, 3	Россия, Воронежская область, Кантемировский район, поселок Кантемировка	0101000020E61000008B87F71C58F04340E272BC02D1D94840
30441	1	4	872	6847	36391	\N	49.701690999999997	р.п.Кантемировка, Дунай, 16, а		0101000020E61000008B87F71C58F04340E272BC02D1D94840
30453	1	4	872	47126	36984	\N	49.686435000000003	с.Зайцевка, Центральная, 42		0101000020E6100000E0F599B33EFF434036EA211ADDD74840
30460	1	4	872	7995	36885	\N	49.967855	с.Евдокиевка, Центральная, 25		0101000020E6100000CC96AC8A70DD4340922232ACE2FB4840
30443	1	4	872	54374	36889	\N	49.603486640359101	ст.Гартмашевка, Вокзальная, 14	Россия, Воронежская область, Кантемировский район, поселок Гартмашевка	0101000020E61000000BD5CDC5DFFC4340D447E00F3FCD4840
30454	1	4	872	7710	36856	\N	49.653809000000003	с.Гармашевка, Победы, 18		0101000020E6100000CDACA580B40944404D6A6803B0D34840
30446	1	4	872	47117	37098	\N	49.846074000000002	с.Волоконовка, Школьная, 1 а		0101000020E6100000D06394675EB243407AFF1F274CEC4840
30478	1	4	872	46887	36796	\N	49.932938	с.Валентиновка, Победы, 15, а		0101000020E6100000BC1FB75F3EDF43400B992B836AF74840
30474	1	4	872	7399	37266	\N	49.642032999999998	с. Бугаевка, Советская, 54		0101000020E610000075B169A510E44340F4F928232ED24840
30447	1	4	872	7399	36905	\N	49.642032999999998	с.Бугаевка, Лесная, 50	Россия, Воронежская область, Кантемировский район, поселок Бугаевка	0101000020E610000075B169A510E44340F4F928232ED24840
30445	1	4	872	47106	36467	\N	49.788826999999998	с.Бондарево, Базарная, 2, а		0101000020E610000014E8137992B84340D4997B48F8E44840
30429	1	4	801	6545	36791	\N	50.737282999999998	Воронежская область, Каменский район, с.Ярки, ул.Школьная, д.72/1		0101000020E61000006D8D08C6C1A14340C972124A5F5E4940
30417	1	4	801	5908	37076	\N	50.806488000000002	Воронежская область, Каменский район, с.Щербаково, ул. Молодежная 12		0101000020E6100000378B170B43AC4340E84EB0FF3A674940
30428	1	4	801	6485	36981	\N	50.705423000000003	Воронежская область, Каменский район, с.Тхоревка, ул.Центральная, д.29		0101000020E6100000F0C000C287AA4340516C054D4B5A4940
30426	1	4	801	6371	36811	\N	50.657521000000003	Воронежская область, Каменский район, с.Трехстенки, ул.Центральная, д.23		0101000020E610000093C9A99D61B8434074B7EBA529544940
30430	1	4	801	6551	36500	\N	50.717350000000003	Воронежская область, Каменский район, с.Тимирязево, ул.Центральная, д.26		0101000020E610000053CDACA580B043408FE4F21FD25B4940
30425	1	4	801	6324	36448	\N	50.585709999999999	Воронежская область, Каменский район, с.Татарино, ул.Центральная, д.27		0101000020E610000025CFF57D389043405778978BF84A4940
30423	1	4	801	6228	36396	\N	50.691343000000003	Воронежская область, Каменский район, с.Сончино, ул.Ленина, д.10		0101000020E6100000255987A3ABC04340C6A86BED7D584940
30427	1	4	801	6425	36793	\N	50.641717999999997	Воронежская область, Каменский район, с.Пилипы, ул.Механизаторов, д.26		0101000020E610000053944BE317C0434094A0BFD023524940
30419	1	4	801	6013	36883	\N	50.571975999999999	Воронежская область, Каменский район, с.Ольхов-Лог, ул.Центральная, д.47		0101000020E610000072512D228AA14340670C738236494940
30424	1	4	801	54456	37267	\N	50.697836000000002	Воронежская область, Каменский район, хут.Новиковский, ул.Новая, д.9	Россия, Воронежская область, Каменский район, поселок Новиковское	0101000020E61000002ECA6C9049CC434059FCA6B052594940
30421	1	4	801	6092	36656	\N	50.778286999999999	Воронежская область, Каменский район, с.Марки, ул.Центральная, д.1		0101000020E6100000AE2B6684B7D7434073F38DE89E634940
30414	1	4	801	54379	36935	\N	50.794943000000004	Воронежская область, Каменский район, хут.Крутец, ул.Железнодорожная, д.38а	Россия, Воронежская область, Каменский район, поселок Крутец	0101000020E61000005CE49EAEEEBC4340929735B1C0654940
30420	1	4	801	6063	36655	\N	50.600696999999997	Воронежская область, Каменский район, с.Коденцово, ул.Красная, д.42		0101000020E61000001E166A4DF3B8434014E7A8A3E34C4940
30418	1	4	801	5933	36560	\N	50.615983	Воронежская область, Каменский район, с.Карпенково, ул.Дружбы, д.35	Россия, Воронежская область, Каменский район, поселок Карпенково	0101000020E6100000827170E998AB43402CF2EB87D84E4940
30432	1	4	801	47411	36291	\N	50.711008	Воронежская область, Каменский район, пгт.Каменка, ул.Солнечная, 1	Россия, Воронежская область, Каменский район, поселок Каменка	0101000020E6100000AF05BD3786B64340E198654F025B4940
30433	1	4	801	47411	36225	\N	50.711008	Воронежская область, Каменский район, пгт.Каменка, ул.Советская, д.31	Россия, Воронежская область, Каменский район, поселок Каменка	0101000020E6100000AF05BD3786B64340E198654F025B4940
30431	1	4	801	47411	36152	\N	50.711770195415703	Воронежская область, Каменский район, пгт.Каменка, ул.Привокзальная, 3	Россия, Воронежская область, Каменский район, поселок Каменка	0101000020E610000050508A56EEB54340102384471B5B4940
30434	1	4	801	47411	36222	\N	50.713586434282298	Воронежская область, Каменский район, пгт.Каменка, ул.Полевая, 30	Россия, Воронежская область, Каменский район, поселок Каменка	0101000020E61000006269E04735B6434015713AC9565B4940
30920	1	4	801	47411	37345	\N	50.711008	с.Каменка, ул.Народная, д.23Б		0101000020E6100000AF05BD3786B64340E198654F025B4940
30435	1	4	801	47411	36226	\N	50.711008	Воронежская область, Каменский район, пгт.Каменка, ул.Гагарина, д.18 Б	Россия, Воронежская область, Каменский район, поселок Каменка	0101000020E6100000AF05BD3786B64340E198654F025B4940
30416	1	4	801	5815	36767	\N	50.751162000000001	Воронежская область, Каменский район, с.Евдаково, ул.Садовая, д.3	Россия, Воронежская область, Каменский район, поселок Евдаково	0101000020E6100000A19FA9D72DB24340BDFF8F1326604940
30415	1	4	801	5787	36431	\N	50.643306000000003	Воронежская область, Каменский район, с.Дегтярное, ул.Мира, д.20		0101000020E61000000CCA349A5CA2434009A9DBD957524940
30413	1	4	801	5677	37152	\N	50.775649999999999	Воронежская область, Каменский район, с.Волчанское, ул.Центральная, д.26		0101000020E61000006DA983BC1EC443403A92CB7F48634940
30422	1	4	801	6166	37078	\N	50.767868	Воронежская область, Каменский район, с.Верхние Марки, ул.Новая Жизнь, д.116		0101000020E610000006668522DDCD43408DD2A57F49624940
30411	1	4	561	46395	36487	\N	50.528238000000002	с.Ясеновка, Центральная (МОУ Ясеновская СОШ), 54	Россия, Воронежская область, Калачеевский район, поселок Ясеновка	0101000020E61000005D876A4AB26644409240834D9D434940
30393	1	4	561	4619	36821	\N	50.507413	с.Юнаково, Комсомольская (МОУ Юнаковская ООШ), 51		0101000020E61000001C261AA4E04B44405A48C0E8F2404940
30410	1	4	561	46359	36547	\N	50.327136000000003	с.Ширяево, Ленина площадь (здание администрации Ширяевского поселения), 1	Россия, Воронежская область, Калачеевский район, поселок Ширяево	0101000020E61000009CBF0985087A444011ACAA97DF294940
30409	1	4	561	46359	35994	\N	50.327136000000003	с.Ширяево, Ленина (МОУ Ширяевская СОШ), 37		0101000020E61000009CBF0985087A444011ACAA97DF294940
30408	1	4	561	46339	36766	\N	50.367114999999998	с.Четвериково, Кирова (МОУ Четвериковская ООШ), 37		0101000020E6100000DB4C8578246A44407E6FD39FFD2E4940
30405	1	4	561	5263	36653	\N	50.358611000000003	с.Хрещатое, Восточная (МОУ Хрещатовская СОШ), 11		0101000020E6100000CB10C7BAB8594440317E1AF7E62D4940
30412	1	4	561	54407	37188	\N	50.562721825772798	хут.Хвощеватое, Гагарина (МОУ Хвощеватовская ООШ), 48	Россия, Воронежская область, Калачеевский район, поселок Хвощеватое	0101000020E6100000E066F16261604440AF5E454607484940
30404	1	4	561	54368	36829	\N	50.353834999999997	с.Советское, Советская (МОУ Советская ООШ), 47	Россия, Воронежская область, Калачеевский район, поселок Советское	0101000020E6100000698CD651D5B244400F971C774A2D4940
30403	1	4	561	5148	37151	\N	50.262518	с.Скрипниково, Ленина (здание администрации Скрипнянского поселения), 39		0101000020E6100000AD31E884D0B14440404E98309A214940
30009	1	4	561	46173	37225	\N	50.422046999999999	с.Семеновка, ул.Свердлова, д.28		0101000020E6100000130EBDC5C34B4440FD2FD7A205364940
30401	1	4	561	46173	36622	\N	50.422046999999999	с.Семеновка, Ленина (Семеновский СДК), 45	Россия, Воронежская область, Калачеевский район, поселок Семеновка	0101000020E6100000130EBDC5C34B4440FD2FD7A205364940
30388	1	4	561	45868	35801	\N	50.459577000000003	с.Пришиб, Щербакова (МОУ Краснобратская ООШ), 16		0101000020E610000009A7052FFA804440357F4C6BD33A4940
30398	1	4	561	46084	35802	\N	50.369746999999997	пос.Пригородный, Космонавтов (МОУ Заводская СОШ), 24		0101000020E6100000E7E3DA5031824440A565A4DE532F4940
30397	1	4	561	46084	35802	\N	50.369746999999997	пос.Пригородный, Космонавтов (ДК), 46		0101000020E6100000E7E3DA5031824440A565A4DE532F4940
30392	1	4	561	54467	37321	\N	50.486669999999997	с.Попасное, Октябрьская (помещение бывшей МОУ Попаснянская ООШ), 82	Россия, Воронежская область, Калачеевский район, поселок Попасное	0101000020E6100000D15AD1E638554440DFF8DA334B3E4940
30402	1	4	561	46192	36824	\N	50.449254000000003	с.Пирогово, Красный Флот (МОУ Пироговская ООШ), 18		0101000020E6100000800EF3E5054E444071CCB22781394940
30407	1	4	561	54434	37232	\N	50.309806999999999	с.Переволочное, Первомайская (МОУ Переволочанская ООШ), 2	Россия, Воронежская область, Калачеевский район, поселок Перевалочное	0101000020E6100000B16B7BBB255B444033897AC1A7274940
30384	1	4	561	54285	36455	\N	50.400938742905502	с.Заброды, Кирова (здание Калачеевских электических сетей), 63	Россия, Воронежская область, Калачеевский район, поселок Отдел N1 совозах Забродненский	0101000020E61000003485CE6BEC84444071581AF851334940
30381	1	4	561	54285	36126	\N	50.400060986534797	с.Заброды, Заброденская (ДК Заброденский), 46	Россия, Воронежская область, Калачеевский район, поселок Отдел N1 совозах Забродненский	0101000020E610000036AFEAAC16844440D9B3E73235334940
30391	1	4	561	4488	35906	\N	50.448869999999999	с.Новомеловатка, Ленина (Новомеловатский СДК), 31 А		0101000020E6100000E481C8224D644440E813799274394940
30394	1	4	561	4661	36138	\N	50.256160999999999	с.Новая Криуша, Советская (МОУ Новокриушанская СОШ), 76	Россия, Воронежская область, Калачеевский район, поселок Новая Криуша	0101000020E6100000978E39CFD8A544405DC136E2C9204940
30400	1	4	561	46140	37385	\N	50.550964999999998	с.Медвежье, Победы (МОУ Медвеженская ООШ), 19		0101000020E610000057B1F84D61594440CD1E680586464940
30390	1	4	561	45895	36434	\N	50.496447000000003	с.Манино, Щербинина площадь (здание СДК №2), 2		0101000020E61000005EF58079C8B04440429946938B3F4940
30389	1	4	561	45895	36062	\N	50.496447000000003	с.Манино, Федота Щербинина (здание СДК №1), 22	Россия, Воронежская область, Калачеевский район, поселок Манино	0101000020E61000005EF58079C8B04440429946938B3F4940
30406	1	4	561	54348	36714	\N	50.370068000000003	с.Лесково, Садовая (МОУ Лесковская СОШ), 3	Россия, Воронежская область, Калачеевский район, поселок Лесково	0101000020E6100000FA62EFC5175D4440E8A562635E2F4940
30387	1	4	561	4295	36387	\N	50.573205999999999	с.Коренное, Школьная (МОУ Коренновская СОШ), 3		0101000020E61000000CCA349A5CB844407CEF6FD05E494940
30385	1	4	561	4202	36432	\N	50.340274999999998	пос.Калачеевский, Ленина (МОУ Поселковая СОШ), 21		0101000020E610000062DA37F757934440BD5296218E2B4940
30016	1	4	1102	18289	36426	\N	51.877102000000001	с.Шукавка, ул.Мира, д.49		0101000020E61000007AAA436E86174440CBA0DAE044F04940
30379	1	4	561	3503	36116	\N	50.428601	г.Калач, Селянская (МДОУ Калачеевский детский сад №6), 55		0101000020E6100000A81ABD1AA08044403604C765DC364940
30375	1	4	561	3503	35751	\N	50.428601	г.Калач, Северная, 52		0101000020E6100000A81ABD1AA08044403604C765DC364940
30373	1	4	561	3503	36185	\N	50.428601	г.Калач, Луначарского, 6		0101000020E6100000A81ABD1AA08044403604C765DC364940
30372	1	4	561	3503	35678	\N	50.428601	г.Калач, Ленина площадь (РДК Юбилейный), 1	Россия, Воронежская область, Калачеевский район, Калач	0101000020E6100000A81ABD1AA08044403604C765DC364940
30374	1	4	561	3503	36019	\N	50.428601	г.Калач, Коммунистическая (МОУ Калачеевская СОШ №1), 11	Россия, Воронежская область, Калачеевский район, Калач	0101000020E6100000A81ABD1AA08044403604C765DC364940
30376	1	4	561	3503	35907	\N	50.428601	г.Калач, 1 Мая (МОУ Калачеевская СОШ №6), 86	Россия, Воронежская область, Калачеевский район, Калач	0101000020E6100000A81ABD1AA08044403604C765DC364940
95191	1	4	561	53581	37177	\N	50.451273	с.Ильинка, ул. Первомайская,47		0101000020E61000002AE3DF675C904440AE484C50C3394940
30380	1	4	561	54411	37196	\N	50.4123770120054	хут.Залесный, Центральная (Клуб), 17 А	Россия, Воронежская область, Калачеевский район, поселок Залесный	0101000020E6100000D905836BEE744440B14F00C5C8344940
30383	1	4	561	54307	36521	\N	50.387493843233699	с.Заброды, Магистральная (здание ФГОУ СПО Калачеевский аграрный техник), 1	Россия, Воронежская область, Калачеевский район	0101000020E610000007280D350A8D4440B7B2446799314940
30368	1	4	297	45488	37089	\N	51.544950999999998	с.Хомутовка, ул.Садовая, д.3		0101000020E610000024B5503239A14440147651F4C0C54940
30363	1	4	297	45421	36880	\N	51.365913999999997	с.Тихвинка, ул.Степная, д.9		0101000020E6100000F834272F32C1444003931B45D6AE4940
30357	1	4	297	2642	36936	\N	51.468631999999999	с.Старогольское, ул.Центральная, д.17		0101000020E610000021AD31E884BE4440F6ED2422FCBB4940
30351	1	4	297	2304	36559	\N	51.376918000000003	с.Средний Карачан, ул.Мира, 12		0101000020E61000005F0B7A6F0CE344400AA359D93EB04940
30354	1	4	297	2455	9824	\N	51.440173081280399	пос.Савельевский, ул.Центральная, д.46		0101000020E6100000A4DE5339EDCB444086CABF9657B84940
30347	1	4	297	2097	37138	\N	51.664724999999997	с.Посевкино, ул.Максима Горького, д.1		0101000020E6100000E9D495CFF21E4540B3EA73B515D54940
30361	1	4	297	54477	37365	\N	51.403743851349901	с.Поляна, ул.Школьная, д.60	Россия, Воронежская область, Грибановский район	0101000020E6100000672AC423F1BE444066FA25E2ADB34940
30366	1	4	297	3166	36553	\N	51.456387999999997	с.Новомакарово, ул.Советская, д.56	Россия, Воронежская область, Грибановский район, поселок Новомакарово	0101000020E6100000D9EA724A409E4440B72407EC6ABA4940
30356	1	4	297	54457	37269	\N	51.490278000000004	с.Новогольское, ул.Советская, д.69	Россия, Воронежская область, Грибановский район, поселок Новогольско	0101000020E61000009274CDE49BBB444062F9F36DC1BE4940
30367	1	4	297	54335	36695	\N	51.514160893890804	с.Новогольелань, ул.Октябрьская, д.39а	Россия, Воронежская область, Грибановский район, поселок Новоголь-Елань	0101000020E6100000581AF8510DA1444078F01307D0C14940
29768	1	4	297	47371	37329	\N	51.424253	с.Новая Жизнь, ул.Центральная, д.17а		0101000020E6100000473B6EF8DD9A44406D1D1CEC4DB64940
30352	1	4	297	2368	35796	\N	51.342441999999998	с.Нижний Карачан, ул.Ленинская, д.2	Россия, Воронежская область, Грибановский район, поселок Нижний Карачан	0101000020E6100000B6BA9C1210E144406F63B323D5AB4940
30343	1	4	297	54373	36878	\N	51.5576447371649	с.Малые Алабухи 2-е, ул.Свободы, д.2	Россия, Воронежская область, Грибановский район, поселок Малые Алабухи 2-е	0101000020E6100000DD26DC2BF318454093E34EE960C74940
30342	1	4	297	1754	36526	\N	51.551223999999998	с.Малые Алабухи 1-е, ул.Первомайская, д.1	Россия, Воронежская область, Грибановский район, поселок Малые Алабухи 1-е	0101000020E6100000F0C2D66CE513454099620E828EC64940
30341	1	4	297	1741	36600	\N	51.510961000000002	с.Малая Грибановка, ул.Советская, д.6		0101000020E6100000B9895A9A5B0945400744882B67C14940
30358	1	4	297	45350	36067	\N	51.425780000000003	с.Листопадовка, ул.Пионерская, д.2		0101000020E610000061C43E0114B944403CA583F57FB64940
30360	1	4	297	45350	36602	\N	51.425780000000003	с.Листопадовка, ул.Глотова, д.13		0101000020E610000061C43E0114B944403CA583F57FB64940
30362	1	4	297	45388	36819	\N	51.391717999999997	с.Лавровка, ул.Центральная, д.16		0101000020E6100000CB129D6516C3444094A0BFD023B24940
30364	1	4	297	3025	37139	\N	51.347506000000003	с.Кутки, ул.Административная, д.7		0101000020E6100000F1F09E03CBC54440F7949C137BAC4940
30359	1	4	297	49604	36764	\N	51.438802000000003	с.Красовка, ул.Заречная, д.98		0101000020E6100000ACC612D6C6BE4440AFB5F7A92AB84940
30365	1	4	297	3131	36924	\N	51.380082999999999	с.Краснореченка, ул.Ленинская, д.3		0101000020E610000062F71DC363A34440FE614B8FA6B04940
30349	1	4	297	49451	36486	\N	51.456527999999999	с.Кирсановка, ул.Свободы, д.2		0101000020E6100000487023658BE44440A9DA6E826FBA4940
30333	1	4	297	1289	36018	\N	51.440463999999999	пгт.Грибановский, ул.Машзаводская, д.8	Россия, Воронежская область, Грибановский район, поселок Грибановский	0101000020E6100000C367EBE060F944405D88D51F61B84940
30339	1	4	297	1289	36479	\N	51.440463999999999	пгт.Грибановский, ул.Совхозная, д.13	Россия, Воронежская область, Грибановский район, поселок Грибановский	0101000020E6100000C367EBE060F944405D88D51F61B84940
30338	1	4	297	1289	35888	\N	51.466988316676101	пгт.Грибановский, ул.Советская, д.55	Россия, Воронежская область, Грибановский район, поселок Грибановский	0101000020E6100000AA7F10C990FD4440EECF4543C6BB4940
30336	1	4	297	1289	36124	\N	51.440463999999999	пгт.Грибановский, ул.Сахзаводская, д.18	Россия, Воронежская область, Грибановский район, поселок Грибановский	0101000020E6100000C367EBE060F944405D88D51F61B84940
30337	1	4	297	1289	36041	\N	51.440463999999999	пгт.Грибановский, ул.Ленинская, д.78		0101000020E6100000C367EBE060F944405D88D51F61B84940
30335	1	4	297	1289	35782	\N	51.440463999999999	пгт.Грибановский, ул.Красная Поляна, д.24		0101000020E6100000C367EBE060F944405D88D51F61B84940
30345	1	4	297	48003	36980	\N	51.562714	с.Власовка, ул.Пролетарская, д.61		0101000020E61000002009FB76122745402C80290307C84940
30350	1	4	297	2249	35904	\N	51.409132	с.Верхний Карачан, пл.Революции, д.1	Россия, Воронежская область, Грибановский район, поселок Верхний Карачан	0101000020E61000008F334DD87EE24440A0DFF76F5EB44940
30344	1	4	297	54351	36720	\N	51.581926000000003	с.Большие Алабухи, пл.Революции, д.10/2	Россия, Воронежская область, Грибановский район, поселок Болшие Алабухи	0101000020E61000006A8995D1C81F45409758198D7CCA4940
31077	1	4	7319	54309	36357	\N	51.688673134030203	городское поселение - город Семилуки, 25 лет Октября, 24	Россия, Воронежская область	0101000020E61000005551BCCADA824340B151D66F26D84940
30041	1	4	1550	19578	36652	\N	50.617553999999998	Воронежская область, Воробьевский район, с.Солонцы, Садовая, 41		0101000020E61000009738F24064594440CAC16C020C4F4940
30031	1	4	1550	54323	36597	\N	50.648779487851201	"Воронежская область, Воробьевский район, пос. с-за ""Краснопольский"", Садовая, 1"	Россия, Воронежская область, Воробьевский район, поселок Совхоз Краснопольский	0101000020E6100000C9C6832D769F444071AAB5300B534940
30027	1	4	1550	54324	36610	\N	50.689975560416798	"Воронежская область, Воробьевский район, пос.ц.у.с-за ""Воробьевский"", Садовая, 14 А"	Россия, Воронежская область, Воробьевский район, поселок Совхоз Воробьевский	0101000020E610000015E63DCE346944403083312251584940
30038	1	4	1550	19453	36651	\N	50.549173000000003	Воронежская область, Воробьевский район, с.Рудня, 40 лет Октября, 66		0101000020E61000008010C990637B4440516C054D4B464940
30856	1	4	1550	18987	37222	\N	50.647103999999999	пос.Первомайский, ул.Центральная, д.2А		0101000020E6100000B2101D02476E44402E8ECA4DD4524940
30029	1	4	1550	18987	37149	\N	50.647103999999999	Воронежская область, Воробьевский район, пос.Первомайский, Первомайская, 19		0101000020E6100000B2101D02476E44402E8ECA4DD4524940
31241	1	4	1550	18987	37026	\N	50.646610053496097	пос.Первомайский, ул.Памяти, д.6	Россия, Воронежская область, Воробьевский район, поселок Первомайский	0101000020E6100000B378B130446E44401FA2D11DC4524940
30039	1	4	1550	54350	36719	\N	50.570529000000001	Воронежская область, Воробьевский район, с.Новотолучеево, Пролетарская, 57	Россия, Воронежская область, Воробьевский район, поселок Новотулучеево	0101000020E6100000022D5DC1367A4440B535221807494940
30037	1	4	1550	19294	36825	\N	50.587322999999998	Воронежская область, Воробьевский район, с.Никольское 2-е, Школьная площадь, 3		0101000020E6100000F69848693693444024986A662D4B4940
30036	1	4	1550	19294	36769	\N	50.587055519240501	Воронежская область, Воробьевский район, с.Никольское 1-е, Советская, 27	Россия, Воронежская область, Воробьевский район, поселок Никольское	0101000020E6100000B587BD50C0924440D575A8A6244B4940
30035	1	4	1550	19294	37033	\N	50.587322999999998	Воронежская область, Воробьевский район, с.Никольское 1-е, Борцов Революции площадь, 3		0101000020E6100000F69848693693444024986A662D4B4940
30024	1	4	1550	18685	37137	\N	50.690463999999999	Воронежская область, Воробьевский район, с.Нижний Бык, Горького, 15		0101000020E6100000D1747632389044405D88D51F61584940
30033	1	4	1550	19162	36383	\N	50.749065000000002	Воронежская область, Воробьевский район, с.Мужичье, Школьный второй переулок, 4		0101000020E6100000F78F85E81088444004CAA65CE15F4940
30032	1	4	1550	19128	36525	\N	50.598312999999997	Воронежская область, Воробьевский район, с.Лещаное, Первомайская, 35	Россия, Воронежская область, Воробьевский район, поселок Лещаное	0101000020E61000008D7BF31B26724440C5E23785954C4940
30030	1	4	1550	19008	36428	\N	50.622326000000001	Воронежская область, Воробьевский район, с.Краснополье, 50 лет Октября, 6		0101000020E6100000EE79FEB451A54440AAB9DC60A84F4940
30028	1	4	1550	18922	36812	\N	50.652163999999999	Воронежская область, Воробьевский район, с.Квашино, ул.Калинина, 2 А		0101000020E610000086E81038126A444074D0251C7A534940
30042	1	4	1550	19659	37074	\N	50.621057999999998	Воронежская область, Воробьевский район, с.Каменка, Комсомольская, 10		0101000020E6100000AC55BB26A4534440A7751BD47E4F4940
30040	1	4	1550	54332	36691	\N	50.655853999999998	Воронежская область, Воробьевский район, с.Затон, Кирова, 121	Россия, Воронежская область, Воробьевский район, поселок Затон	0101000020E61000007BBDFBE3BD5E4440B3791C06F3534940
30022	1	4	1550	18591	36992	\N	50.752671999999997	Воронежская область, Воробьевский район, с.Елизаветовка, Октябрьская, 18		0101000020E61000004A95287B4B754440B54E5C8E57604940
30043	1	4	1550	54438	37236	\N	50.611879000000002	Воронежская область, Воробьевский район, хут.Гринев, Кирова, 36	Россия, Воронежская область, Воробьевский район, поселок Гринев	0101000020E610000047C7D5C8AE604440FA0D130D524E4940
30548	1	4	1550	49004	36669	\N	50.780388000000002	с.Высокое, Советская, 33, здание сельской администарции		0101000020E61000005B5B785E2A9044406E1805C1E3634940
30549	1	4	1550	49004	36392	\N	50.780388000000002	с.Высокое, Полевая, 2б, здание Дома культуры		0101000020E61000005B5B785E2A9044406E1805C1E3634940
30026	1	4	1550	18777	35804	\N	50.645095418665697	Воронежская область, Воробьевский район, с.Воробьевка, Чкалова, 3 А	Россия, Воронежская область, Воробьевский район, поселок Воробьевка	0101000020E6100000AE0CAA0D4E76444014E8137992524940
30025	1	4	1550	18777	35749	\N	50.644460000000002	Воронежская область, Воробьевский район, с.Воробьевка, Калинина улица, 24 Б		0101000020E6100000247D5A457F78444043CA4FAA7D524940
30023	1	4	1550	18672	36933	\N	50.719721999999997	Воронежская область, Воробьевский район, с.Верхний Бык, Ленина, 5		0101000020E610000034DAAA24B2974440191BBAD91F5C4940
30021	1	4	1550	18531	36986	\N	50.755391000000003	Воронежская область, Воробьевский район, с.Верхнетолучеево, Свободы, 47		0101000020E610000032022A1C41844440AC58FCA6B0604940
30020	1	4	1550	18489	36074	\N	50.710026999999997	Воронежская область, Воробьевский район, с.Березовка, Центральная, 11		0101000020E6100000F792C6681D7D444074232C2AE25A4940
30034	1	4	1550	19253	36814	\N	50.804558999999998	Воронежская область, Воробьевский район, с.Банное, Ленина, 26		0101000020E6100000622EA9DA6E924440EA5910CAFB664940
30019	1	4	1102	18321	35797	\N	51.820464999999999	с.Углянец, ул.Ломоносова, д.167г	Россия, Воронежская область, Верхнехавский район, поселок Углянец	0101000020E6100000AFB5F7A92ACC43409E4143FF04E94940
30017	1	4	1102	18321	35797	\N	51.820464999999999	с.Углянец, ул.Ломоносова, д.167в	Россия, Воронежская область, Верхнехавский район, поселок Углянец	0101000020E6100000AFB5F7A92ACC43409E4143FF04E94940
94923	1	4	1102	18164	36813	\N	51.771610000000003	с. Сухие Гаи, ул. Ленина, д.5г здание МКОУ "Сухогаевская СОШ"		0101000020E61000004301DBC188F143401FA2D11DC4E24940
30012	1	4	1102	18069	36524	\N	51.723165000000002	с.Правая Хава, ул.Леваневского, д.23	Россия, Воронежская область, Верхнехавский район, поселок Правая Хава	0101000020E6100000E2395B4068E34340514EB4AB90DC4940
30781	1	4	1102	45616	35839	\N	51.917232929346	с.Покровка, Молодежная, 37	Россия, Воронежская область, Верхнехавский район, поселок Покровка	0101000020E6100000603AADDBA00C4440EFE714E467F54940
30018	1	4	1102	47235	36025	\N	51.810332000000002	пос.Подлесный, ул.Школьная, д.1а (здание ООШ 2-й этаж)		0101000020E6100000AF97A60870C843407E737FF5B8E74940
29992	1	4	1102	47235	36025	\N	51.810332000000002	пос.Подлесный, ул.Школьная, д.1а (здание ООШ 1-й этаж)		0101000020E6100000AF97A60870C843407E737FF5B8E74940
30008	1	4	1102	17866	37135	\N	51.895062000000003	с.Плясоватка, ул.Заречная, д.35		0101000020E6100000D311C0CDE20D444039F2406491F24940
30006	1	4	1102	45581	36481	\N	51.800942999999997	с.Парижская Коммуна, ул.Совхозная, д.42	Россия, Воронежская область, Верхнехавский район, поселок Парижская Коммуна	0101000020E6100000BB61DBA2CCD04340E57ADB4C85E64940
30007	1	4	1102	47550	37148	\N	51.796030000000002	с.Никоново, ул.Некрасова, д.82		0101000020E6100000F86EF3C649CB43404451A04FE4E54940
29994	1	4	1102	47279	36931	\N	51.810298000000003	с.Нижняя Маза, ул.Комсомольская, д.3а		0101000020E6100000FEF3346090204440D20149D8B7E74940
29989	1	4	1102	16938	37070	\N	51.943550000000002	с.Нижняя Байгора, ул.Московская, д.28б		0101000020E6100000DDED7A698AF643400612143FC6F84940
30005	1	4	1102	17732	36874	\N	51.928967999999998	пос.Малый Самовец, ул.Ленина, д.41		0101000020E61000006EDDCD531D2A4440E883656CE8F64940
30002	1	4	1102	17579	37072	\N	51.861224999999997	с.Малая Приваловка, ул.Ленина, д.41		0101000020E61000007940D9942BD64340B1BFEC9E3CEE4940
30082	1	4	1102	54279	36022	\N	51.878050620141003	г.Воронеж, ул.Генерала Лохматикова, д.13	Россия, Воронежская область, Верхнехавский район, поселок Краснолесный	0101000020E6100000A708707A17CB43402C9CA4F963F04940
30013	1	4	1102	47638	35914	\N	51.838694805797203	пос.Вишневка, ул.Комарова, д.61	Россия, Воронежская область, Верхнехавский район, поселок Вишневка	0101000020E6100000E8D84125AEEB4340CC28965B5AEB4940
29999	1	4	1102	17272	35748	\N	51.843494999999997	с.Верхняя Хава, ул.Школьная, д.1		0101000020E61000008E20956247F7434075ABE7A4F7EB4940
29998	1	4	1102	17272	35902	\N	51.843494999999997	с.Верхняя Хава, ул.Октябрьская, д.22		0101000020E61000008E20956247F7434075ABE7A4F7EB4940
30010	1	4	1102	17272	36021	\N	51.843494999999997	с.Верхняя Хава, ул.Ленина, д.13 (здание старой школы)		0101000020E61000008E20956247F7434075ABE7A4F7EB4940
29996	1	4	1102	17272	36021	\N	51.843494999999997	с.Верхняя Хава, ул.Ленина, д.13 (здание новой школы)		0101000020E61000008E20956247F7434075ABE7A4F7EB4940
29997	1	4	1102	17272	36132	\N	51.843494999999997	с.Верхняя Хава, ул.50 лет Октября, д.14	Россия, Воронежская область, Верхнехавский район, поселок Верхняя Хава	0101000020E61000008E20956247F7434075ABE7A4F7EB4940
29995	1	4	1102	17251	36932	\N	51.938074999999998	с.Верхняя Плавица, ул.Ленина, д.56		0101000020E6100000637E6E68CA1A4440FC1873D712F84940
29993	1	4	1102	17148	36761	\N	51.814847	пос.Верхняя Маза, ул.50 лет Октября, д.25а		0101000020E6100000209BE447FC124440321F10E84CE84940
30011	1	4	1102	18054	37073	\N	51.951988	с.Верхняя Луговатка, ул.Харина, д.30а		0101000020E6100000D1CB28965B0C44409C1727BEDAF94940
29990	1	4	1102	47189	37146	\N	51.921931999999998	с.Верхняя Байгора, ул.50 лет Октября, д.74		0101000020E6100000F4FBFECD8BEF4340649126DE01F64940
30001	1	4	1102	17557	36806	\N	51.780275000000003	с.Васильевка-1-я, ул.Кольцова, д.43б		0101000020E6100000EBAC16D8630C444076711B0DE0E34940
29991	1	4	1102	17029	36595	\N	51.899479999999997	с.Большая Приваловка, ул.Гагарина, д.1		0101000020E61000008C2FDAE385E24340FAB31F2922F34940
30000	1	4	1102	47408	37320	\N	51.826416000000002	с.Богословка, ул.Гагарина, д.5		0101000020E61000004679E6E5B00544401172DEFFC7E94940
29986	1	4	1430	16793	35900	\N	50.357340000000001	с.Русская Журавка, ул.Центральная, д.165/1	Россия, Воронежская область, Верхнемамонский район, поселок Русская Журавка	0101000020E61000006C3F19E3C3464440BDC62E51BD2D4940
29982	1	4	1430	47034	36386	\N	50.213949999999997	с.Приречное, ул.имени Ленина, д.81		0101000020E610000071732A19003C4440567DAEB6621B4940
29975	1	4	1430	46903	36385	\N	50.141891999999999	с.Осетровка, ул.Алпеева, д.23		0101000020E6100000CD72D9E89C3B444032C85D8429124940
29977	1	4	1430	54410	37194	\N	50.038297598904997	хут.Оробинский, ул.Школьная, д.1	Россия, Воронежская область, Верхнемамонский район, поселок Оробинский	0101000020E6100000BB61DBA2CC1C444048C0E8F2E6044940
29979	1	4	1430	46976	36389	\N	50.179398362835002	с.Ольховатка, ул.Дьячкова, д.17	Россия, Воронежская область, Верхнемамонский район, поселок Ольховатка	0101000020E6100000E0A293A5D60D4440E17B7F83F6164940
29984	1	4	1430	16629	36382	\N	50.179737000000003	с.Нижний Мамон, ул.Ленина, д.19		0101000020E6100000CA1AF5108D424440CA703C9F01174940
29985	1	4	1430	16629	36558	\N	50.179737000000003	с.Нижний Мамон, ул.50 лет Победы, д.1А	Россия, Воронежская область, Верхнемамонский район, поселок Нижний Мамон	0101000020E6100000CA1AF5108D424440CA703C9F01174940
29983	1	4	1430	16629	36045	\N	50.179737000000003	с.Нижний Мамон, ул.40 лет Победы, д.7	Россия, Воронежская область, Верхнемамонский район, поселок Нижний Мамон	0101000020E6100000CA1AF5108D424440CA703C9F01174940
29987	1	4	1430	47130	36802	\N	50.395381	с.Мамоновка, ул.Первомайская, д.1/1		0101000020E610000071E7C2482F404440DA3A38D89B324940
29980	1	4	1430	47004	36485	\N	50.278903999999997	с.Лозовое, ул.Октябрьская, д.69	Россия, Воронежская область, Верхнемамонский район, поселок Лозовое	0101000020E6100000C3D84290832E44409E5C5320B3234940
29981	1	4	1430	47004	36594	\N	50.278903999999997	с.Лозовое, ул.Авдеева, д.6		0101000020E6100000C3D84290832E44409E5C5320B3234940
29976	1	4	1430	37645	36645	\N	50.078628000000002	с.Дерезовка, ул.Центральная, д.111		0101000020E6100000BB4560AC6F2644406346787B100A4940
31249	1	4	1430	46954	67103	\N	50.106997999999997	с.Гороховка, ул.Центральная, д.5		0101000020E61000009E23F25D4A174440635E471CB20D4940
29978	1	4	1430	46954	36202	\N	50.105400610033399	с.Гороховка, ул.Советская, д.170	Россия, Воронежская область, Верхнемамонский район, поселок Гороховка	0101000020E6100000996725ADF81844409CFBABC77D0D4940
29974	1	4	1430	15955	36557	\N	50.169375005521204	с.Верхний Мамон, ул.Прогресс, д.1	Россия, Воронежская область, Верхнемамонский район, поселок Верхний Мамон	0101000020E610000006D50627A231444048E17A14AE154940
29972	1	4	1430	15955	36425	\N	50.160454999999999	с.Верхний Мамон, ул.Правды, д.21		0101000020E6100000AC1F9BE44732444066BD18CA89144940
29969	1	4	1430	15955	36483	\N	50.160454999999999	с.Верхний Мамон, ул.Первомайская, д.3/1	Россия, Воронежская область, Верхнемамонский район, поселок Верхний Мамон	0101000020E6100000AC1F9BE44732444066BD18CA89144940
29970	1	4	1430	15955	36134	\N	50.160454999999999	с.Верхний Мамон, ул.Братская Площадь, д.2		0101000020E6100000AC1F9BE44732444066BD18CA89144940
29973	1	4	1430	15955	35686	\N	50.160454999999999	с.Верхний Мамон, ул.60 лет Октября, д.11/1	Россия, Воронежская область, Верхнемамонский район, поселок Верхний Мамон	0101000020E6100000AC1F9BE44732444066BD18CA89144940
29971	1	4	1430	15955	36181	\N	50.160454999999999	с.Верхний Мамон, ул.22-го Партсъезда, д.83		0101000020E6100000AC1F9BE44732444066BD18CA89144940
30955	1	4	1313	54471	\N	\N	50.777731593462597	хут.Петропавловка, здание дома культуры	Россия, Воронежская область, Бутурлиновский район	0101000020E610000096438B6CE74D4440BE86E0B88C634940
30927	1	4	1313	54421	\N	\N	50.847116647653102	хут.Луговой, Здание библиотеки	Россия, Воронежская область, Бутурлиновский район	0101000020E61000009F1C0588824544405C7171546E6C4940
29849	1	4	1313	54485	37384	\N	50.847225324318899	х.Варваровка, ул.1-е Мая, д.13	Россия, Воронежская область, Бутурлиновский район	0101000020E61000009D4CDC2A8845444043AD69DE716C4940
30399	1	4	1313	54417	37205	\N	50.847662575519202	пос.Черноземный, Молодежная площадь (ДК), 2	Россия, Воронежская область, Бутурлиновский район	0101000020E6100000662FDB4E5B454440BE839F38806C4940
30386	1	4	1313	54413	37199	\N	50.848257739949403	пос.Колос, 40 лет Победы (МОУ Колосовская СОШ), 2	Россия, Воронежская область, Бутурлиновский район	0101000020E6100000B3075A81214544400249D8B7936C4940
29967	1	4	1313	15820	36876	\N	50.937393	с.Чулок, ул.Советская, д.1		0101000020E61000006A4B1DE4F5524440EA3F6B7EFC774940
29963	1	4	1313	15669	36484	\N	50.744477000000003	с.Филиппенково, ул.Комарова, д.14	Россия, Воронежская область, Бутурлиновский район, поселок Филиппенково	0101000020E6100000F6B3588AE45F4440E6CFB7054B5F4940
29968	1	4	1313	46755	37069	\N	50.922604	с.Ударник, ул.Ленина, д.31а		0101000020E610000060EAE74D455C444053944BE317764940
29961	1	4	1313	15562	37067	\N	50.953702999999997	с.Сериково, ул.Советская, д.51		0101000020E6100000CB80B3942C6F44406D8C9DF0127A4940
29958	1	4	1313	46540	36380	\N	50.669367999999999	с.Пузево, ул.Пески, д.99а		0101000020E6100000C2DF2F664B324440957EC2D9AD554940
29959	1	4	1313	46540	36182	\N	50.669367999999999	с.Пузево, ул.Ленина, д.103		0101000020E6100000C2DF2F664B324440957EC2D9AD554940
29964	1	4	1313	46659	36800	\N	50.801381999999997	с.Патокино, ул.Школьная, д.34		0101000020E6100000EFA99CF69464444031CD74AF93664940
30642	1	4	1313	46397	35931	\N	50.884824999999999	с.Отрадное, ул.Советская, д.41Д		0101000020E610000006F4C29D0B49444073D712F241714940
30641	1	4	1313	46397	36064	\N	50.884824999999999	с.Отрадное, ул.50 Лет Октября, д.26	Россия, Воронежская область, Бутурлиновский район, поселок Отрадное	0101000020E610000006F4C29D0B49444073D712F241714940
29956	1	4	1313	46507	36477	\N	50.984520000000003	с.Озерки, ул.Октябрьская, д.5	Россия, Воронежская область, Бутурлиновский район, поселок Озерки	0101000020E6100000D1950854FF3C4440042159C0047E4940
29947	1	4	1313	14904	35792	\N	50.843381000000001	р.п.Нижний Кисляй, ул.Советская, д.6		0101000020E61000006C5B94D920174440AD889AE8F36B4940
29948	1	4	1313	14904	36157	\N	50.843381000000001	р.п.Нижний Кисляй, ул.Заводская, д.22		0101000020E61000006C5B94D920174440AD889AE8F36B4940
29962	1	4	1313	15615	36990	\N	50.929887999999998	с.Макогоново, ул.Зеленая, д.2б		0101000020E6100000E6AF90B932684440AF78EA9106774940
29955	1	4	1313	15256	36520	\N	50.882818999999998	с.Кучеряевка, ул.Ленина, д.93	Россия, Воронежская область, Бутурлиновский район, поселок Кучеряевка	0101000020E6100000B16CE690D4744440CAA4863600714940
31245	1	4	1313	48455	37249	\N	50.845002000000001	пос.Комсомольский, ул.Дальняя, д.12		0101000020E61000004696CCB1BC254440FD868906296C4940
29952	1	4	1313	46429	36198	\N	50.863442999999997	с.Козловка, ул.Октябрьская, д.21		0101000020E61000002D095053CB3A4440E57ADB4C856E4940
29953	1	4	1313	46429	36015	\N	50.863442999999997	с.Козловка, ул.Дзержинского, д.28		0101000020E61000002D095053CB3A4440E57ADB4C856E4940
29950	1	4	1313	15022	36523	\N	50.723998999999999	с.Клеповка, ул.Советская, д.80	Россия, Воронежская область, Бутурлиновский район, поселок Клеповка	0101000020E6100000D717096D393B444019ABCDFFAB5C4940
29951	1	4	1313	15022	36482	\N	50.723998999999999	с.Клеповка, ул.Ленинская, д.100а	Россия, Воронежская область, Бутурлиновский район, поселок Клеповка	0101000020E6100000D717096D393B444019ABCDFFAB5C4940
29949	1	4	1313	14981	36422	\N	50.886040999999999	с.Карайчевка, ул.50 лет Октября, д.4		0101000020E6100000C2C1DEC49024444023F59ECA69714940
29941	1	4	1313	14609	36756	\N	50.810972999999997	пос.Зеленый Гай, ул.Набережная, д.50		0101000020E61000009B1F7F6951434440317898F6CD674940
29942	1	4	1313	46203	36480	\N	50.794915000000003	пос.Зеленый, ул.Ленина, д.10		0101000020E61000002619390B7B544440C80C54C6BF654940
29965	1	4	1313	46676	37183	\N	50.763401999999999	с.Елизаветино, ул.Советская, д.62		0101000020E61000002F6F0ED76A674440BAD91F28B7614940
29940	1	4	1313	54465	37316	\N	50.780656	с.Дмитриевка, ул.Пролетарская, д.17	Россия, Воронежская область, Бутурлиновский район, поселок Дмитриевка	0101000020E6100000B3B6291E174344408DB62A89EC634940
29945	1	4	1313	14807	36522	\N	50.740577999999999	с.Гвазда, ул.Ленина, д.79	Россия, Воронежская область, Бутурлиновский район, поселок Гвазда	0101000020E6100000C91CCBBBEA3944408C118942CB5E4940
26730	1	3	\N	54132	34559	\N	56.003100000000003	Владимирская область, ЗАТО город Радужный, 1 квартал, 51		0101000020E610000035971B0C752A44400E4FAF9465004C40
29946	1	4	1313	14807	35878	\N	50.740577999999999	с.Гвазда, ул.Ивана Бочарникова, д.41	Россия, Воронежская область, Бутурлиновский район, поселок Гвазда	0101000020E6100000C91CCBBBEA3944408C118942CB5E4940
29943	1	4	1313	14706	36475	\N	50.850149000000002	с.Великоархангельское, ул.Октябрьская, д.63	Россия, Воронежская область, Бутурлиновский район, поселок Великоархангельское	0101000020E6100000AA6395D23361444012DDB3AED16C4940
29944	1	4	1313	14706	37065	\N	50.850149000000002	с.Великоархангельское, ул.Ленина, д.48		0101000020E6100000AA6395D23361444012DDB3AED16C4940
30353	1	4	1313	46950	37200	\N	50.921758981365301	с.Васильевка, ул.Советская, д.2	Россия, Воронежская область, Бутурлиновский район, поселок Васильевка	0101000020E61000005CE49EAEEE7C444097E5EB32FC754940
29966	1	4	1313	46950	36954	\N	50.920509000000003	с.Васильевка, ул.Ленина, д.46	Россия, Воронежская область, Бутурлиновский район, поселок Васильевка	0101000020E6100000856055BDFC7C44403B56293DD3754940
29928	1	4	1313	13865	36537	\N	50.829456	г.Бутурлиновка, пл.Воли, д.21	Россия, Воронежская область, Бутурлиновский район, Бутурлиновка	0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29930	1	4	1313	13865	36016	\N	50.829456	г.Бутурлиновка, пер.Связистов, д.4	Россия, Воронежская область, Бутурлиновский район, Бутурлиновка	0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29935	1	4	1313	13865	35780	\N	50.829456	г.Бутурлиновка, ул.Чехова, д.16		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29936	1	4	1313	13865	35781	\N	50.829456	г.Бутурлиновка, ул.Победы, д.76		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29929	1	4	1313	13865	36147	\N	50.829456	г.Бутурлиновка, ул.Красная, д.216		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29926	1	4	1313	13865	36029	\N	50.847902849667399	г.Бутурлиновка, ул.Кирова, д.11	Россия, Воронежская область, Бутурлиновский район, Бутурлиновка	0101000020E6100000D02A33A5F54944401497E315886C4940
29931	1	4	1313	13865	36031	\N	50.829456	г.Бутурлиновка, ул.Блинова, д.2		0101000020E61000008BA4DDE8634C444049BC3C9D2B6A4940
29913	1	4	1273	13280	35778	\N	51.427807999999999	с.Чигорак, пер.Первомайский, д.7		0101000020E6100000A777F17EDC124540CC7B9C69C2B64940
29914	1	4	1273	13280	36551	\N	51.427807999999999	с.Чигорак, ул.Красная, д.106	Россия, Воронежская область, Борисоглебский район, поселок Чигорак	0101000020E6100000A777F17EDC124540CC7B9C69C2B64940
29915	1	4	1273	45640	37010	\N	51.284641000000001	с.Ульяновка, ул.Ворошилова, д.36	Россия, Воронежская область, Борисоглебский район, поселок Ульяновка	0101000020E6100000916456EF70014540E50CC51D6FA44940
29923	1	4	1273	13747	37086	\N	51.441991000000002	с.Тюковка, ул.Молодежная, д.10		0101000020E61000003B8C497F2F4F45402C103D2993B84940
29921	1	4	1273	45737	36674	\N	51.361657000000001	с.Третьяки, ул.Народная, д.44		0101000020E6100000FE2C9622F93C45404BAFCDC64AAE4940
29925	1	4	1273	13830	36592	\N	51.334873999999999	с.Танцырей, ул.Московская, д.4		0101000020E610000044A7E7DD582E4540EE23B726DDAA4940
29922	1	4	1273	54453	37257	\N	51.402231999999998	с.Старовоскресеновка, ул.Борисоглебская, д.3	Россия, Воронежская область, Борисоглебский район, поселок Старая Воскресеновка	0101000020E61000002AAC545051454540CCB392567CB34940
29924	1	4	1273	45809	36394	\N	51.280163000000002	с.Петровское, ул.Первомайская, д.2		0101000020E61000009FAEEE586C2545404E469561DCA34940
29916	1	4	1273	13404	36469	\N	51.494013000000002	пос.Миролюбие, ул.Свободы, д.7		0101000020E61000004D86E3F90C284540416667D13BBF4940
29917	1	4	1273	13469	36922	\N	51.544300999999997	с.Махровка, ул.Свободы, д.1		0101000020E6100000D8B628B3413245400D17B9A7ABC54940
29919	1	4	1273	54380	36940	\N	51.490541999999998	с.Макашевка, ул.Коммуны, д.3	Россия, Воронежская область, Борисоглебский район, поселок Макашевка	0101000020E6100000ACE5CE4C304E45403FA88B14CABE4940
29918	1	4	1273	45695	36646	\N	51.508803	с.Губари, ул.Советская, д.128		0101000020E61000004489963C9E464540A88DEA7420C14940
29920	1	4	1273	13586	37088	\N	51.426864000000002	с.Горелка, ул.Советская, д.87		0101000020E6100000A1BAB9F8DB5245407DEBC37AA3B64940
29593	1	4	1273	29588	36468	\N	51.477552000000003	с.Богана, ул.Советская, д.259	Россия, Воронежская область, Борисоглебский район, поселок Богана	0101000020E6100000062E8F3523174540D811876C20BD4940
29850	1	4	1073	10327	37122	\N	49.737335000000002	с.Шуриновка, ул.Октябрьская, д.31		0101000020E6100000AF93FAB2B43144401C9947FE60DE4840
29879	1	4	1073	49319	36873	\N	50.042768000000002	с.Филоново, ул.Молодёжная, д.38		0101000020E6100000ABCE6A813D3E44405DA8FC6B79054940
29872	1	4	1073	60412	74980	\N	49.810062825801801	с.Травкино, ул.Парковая, д.7	Россия, Воронежская область, Богучарский район, поселок Отдел N3 совхоза Богучарский	0101000020E6100000191F662FDB3044408E59F624B0E74840
29843	1	4	1073	9974	36869	\N	49.921895999999997	с.Терешково, ул.Ленина, д.16а		0101000020E610000049D8B79388544440172829B000F64840
29876	1	4	1073	11552	36587	\N	49.939929999999997	с.Твердохлебовка, ул.Калинина, д.62		0101000020E6100000E8DCED7A692C4440BF4351A04FF84840
29874	1	4	1073	11459	36664	\N	49.803772000000002	с.Сухой Донец, ул.Советская, д.1		0101000020E61000006A317898F673444063B83A00E2E64840
29864	1	4	1073	10972	36755	\N	49.968887000000002	с.Старотолучеево, ул.Героя Бондарева, д.21		0101000020E6100000E81379927461444081423D7D04FC4840
29854	1	4	1073	48943	37136	\N	49.754018000000002	пос.Южный, ул.Садовая, д.19		0101000020E6100000B85A272EC7634440344C6DA983E04840
29878	1	4	1073	49304	37322	\N	50.029252	с.Свобода, ул.Центральная, д.21а		0101000020E6100000B4CC22145B394440DAAB8F87BE034940
29871	1	4	1073	11312	36549	\N	49.797702000000001	с.Радченское, ул.Воробьёва, д.65	Россия, Воронежская область, Богучарский район, поселок Радченское	0101000020E610000029ECA2E8813F444016FA60191BE64840
29868	1	4	1073	48133	37090	\N	49.913310611497501	с.Поповка, ул.Калинина, д.67а	Россия, Воронежская область, Богучарский район, поселок Поповка	0101000020E610000054556820963F4440DD09F65FE7F44840
31189	1	4	1073	48133	37355	\N	49.913034000000003	с.Поповка, ул.Крупской, д,25		0101000020E61000007B698A00A73F44406B11514CDEF44840
29841	1	4	1073	48726	36987	\N	49.873193999999998	с.Полтавка, ул.Мира, д.60		0101000020E6100000AB933314774644401E882CD2C4EF4840
29862	1	4	1073	10906	36753	\N	49.646408000000001	с.Плесновка, ул.Советская, д.14		0101000020E61000000229B16B7B3F4440B7EF517FBDD24840
26929	1	3	\N	8940	34817	\N	56.347329999999999	Владимирская область, город Ковров, ул. Московская, дом 10		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
29877	1	4	1073	54435	37233	\N	49.994385000000001	х.Перещепное, ул.Садовая, д.15а	Россия, Воронежская область, Богучарский район, поселок Перещепное	0101000020E61000000F971C774A4144400551F70148FF4840
29875	1	4	1073	49259	37063	\N	49.979430999999998	пос.Вишневый, ул.Школьная, д.10		0101000020E6100000BBD408FD4C33444023D8B8FE5DFD4840
29860	1	4	1073	60385	74934	\N	49.628281000000001	с.Новоникольское, ул.Кирова, д.5а	Россия, Воронежская область, Богучарский район, поселок Новоникольск	0101000020E61000007C65DEAAEB3044405ED905836BD04840
29858	1	4	1073	49016	36649	\N	49.825540193896799	с.Монастырщина, ул.Центральная, д.22	Россия, Воронежская область, Богучарский район, поселок Монастырщина	0101000020E6100000EA059FE6E473444019C5724BABE94840
29857	1	4	1073	48991	36870	\N	49.748664059936097	с.Медово, ул.Низовая, д.2а	Россия, Воронежская область, Богучарский район, поселок Медово	0101000020E6100000C959D8D30E5B4440A5D8D138D4DF4840
29856	1	4	1073	54409	37193	\N	49.799346999999997	х.Малеванный, ул.Российская, д.3	Россия, Воронежская область, Богучарский район, поселок Малеваный	0101000020E61000002E8F3523835C4440EE93A30051E64840
29851	1	4	1073	48896	36585	\N	49.911043999999997	с.Луговое, ул.Мира, д.18		0101000020E6100000FC5069C4CC2A4440C79BFC169DF44840
29867	1	4	1073	11114	36663	\N	49.902979999999999	с.Лофицкое, ул.Ленина, д.65		0101000020E61000001973D712F2394440967840D994F34840
29848	1	4	1073	10209	36516	\N	49.782911504659602	с.Липчанка, ул.Кирова, д.62	Россия, Воронежская область, Богучарский район, поселок Липчанка	0101000020E61000000551F701483B4440AFD2DD7536E44840
29861	1	4	1073	10836	36515	\N	49.653483000000001	с.Лебединка, ул.Первомайская, д.10	Россия, Воронежская область, Богучарский район, поселок Лебединка	0101000020E6100000D00CE2033B364440F9BEB854A5D34840
29866	1	4	1073	11083	36650	\N	49.898772999999998	с.Купянка, ул.Октябрьская, д.1а		0101000020E6100000F37519FED34544408FC360FE0AF34840
29840	1	4	1073	46558	36751	\N	49.922755000000002	с.Красногоровка, ул.Западная, д.11		0101000020E61000006C5F402FDC614440399CF9D51CF64840
29855	1	4	1073	10567	\N	\N	49.701743	с.Каразеево, ул.Ленина, д.3	Россия, Воронежская область, Богучарский район, поселок Каразеево	0101000020E61000006B64575A466444403599F1B6D2D94840
29847	1	4	1073	10174	35682	\N	49.948144999999997	с.Залиман, ул.Малаховского, д.51б	Россия, Воронежская область, Богучарский район, поселок Залиман	0101000020E6100000D367075C574A4440D66EBBD05CF94840
30450	1	4	1073	47193	37391	\N	50.051074999999997	с.Журавка, Пролетарская, 29		0101000020E6100000BB99D18F864B4440545227A089064940
29535	1	4	1073	47193	37273	\N	50.051074999999997	с.Журавка, ул.Ленина, д.15		0101000020E6100000BB99D18F864B4440545227A089064940
29869	1	4	1073	54405	37186	\N	49.829788190944903	х.Дядин, пер.Рабочий, д.15	Россия, Воронежская область, Богучарский район, поселок Дядин	0101000020E6100000B9C5FCDCD04244407F4E417E36EA4840
29839	1	4	1073	9770	35884	\N	49.908299999999997	с.Дьяченково, ул.Школьная, д.33		0101000020E61000003082C64CA24C4440787AA52C43F44840
29852	1	4	1073	10438	36420	\N	49.906483999999999	с.Данцевка, ул.Центральная, д.14 Б		0101000020E6100000D5CA845FEA1F4440732CEFAA07F44840
29846	1	4	1073	10130	36930	\N	50.012230000000002	с.Грушовое, ул.Центральная, д.3а		0101000020E610000049D6E1E82A4D4440DA03ADC090014940
29845	1	4	1073	52290	37147	\N	49.983148999999997	х.Галиевка, ул.1-е Мая, д.11	Россия, Воронежская область, Богучарский район, поселок Галиевка	0101000020E610000027F56569A75044402C0C91D3D7FD4840
29865	1	4	1073	11026	37061	\N	49.923996000000002	с.Вервековка, ул.Пролетарская, д.174		0101000020E6100000C9AA0837193D444042D13C8045F64840
29859	1	4	1073	54460	37275	\N	49.600099999999998	х.Батовка, ул.Авиаторов, д.11/2	Россия, Воронежская область, Богучарский район, поселок Ботовка	0101000020E61000001893FE5E0A454440302AA913D0CC4840
29834	1	4	1073	9513	36039	\N	49.934590999999998	г.Богучар, ул.Урицкого, д.1	Россия, Воронежская область, Богучарский район, Богучар	0101000020E610000022A7AFE76B46444066118AADA0F74840
29838	1	4	1073	9513	36140	\N	49.934590999999998	г.Богучар, Военный городок, д.60	Россия, Воронежская область, Богучарский район, Богучар	0101000020E610000022A7AFE76B46444066118AADA0F74840
29837	1	4	1073	9513	35988	\N	49.934590999999998	г.Богучар, ул.Советская, д.56		0101000020E610000022A7AFE76B46444066118AADA0F74840
29835	1	4	1073	9513	35893	\N	49.934590999999998	г.Богучар, ул.Карла Маркса, д.2		0101000020E610000022A7AFE76B46444066118AADA0F74840
29873	1	4	1073	11416	36739	\N	49.794038	с.1-я Белая Горка, ул.Коммунаров, д.3		0101000020E61000009F7763416178444000E48409A3E54840
29826	1	4	922	9176	36146	\N	51.046821999999999	Воронежская область, Бобровский район, п.Ясенки, ул.Свободы, д.1б		0101000020E6100000FD2FD7A205FC4340DD5D6743FE854940
29830	1	4	922	9176	36439	\N	51.046821999999999	Воронежская область, Бобровский район, п.Ясенки, ул.Микрорайон Юбилейный, д.1а		0101000020E6100000FD2FD7A205FC4340DD5D6743FE854940
29814	1	4	922	8636	36590	\N	51.275554	Воронежская область, Бобровский район, с.Юдановка, ул.Советская, д.2	Россия, Воронежская область, Бобровский район, поселок Юдановка	0101000020E61000009545611745EB434018247D5A45A34940
29821	1	4	922	8943	36378	\N	51.244937	Воронежская область, Бобровский район, с.Шишовка, ул.Большая Советская, д.163		0101000020E610000016A6EF3504194440494A7A185A9F4940
29802	1	4	922	7994	36661	\N	50.797595999999999	Воронежская область, Бобровский район, с.Шестаково, ул.Чибисовка, д.14		0101000020E61000008E5C37A5BC084440D0B52FA017664940
29801	1	4	922	7994	36373	\N	50.797595999999999	Воронежская область, Бобровский район, с.Шестаково, ул.Советская, д.42	Россия, Воронежская область, Бобровский район, поселок Шестаково	0101000020E61000008E5C37A5BC084440D0B52FA017664940
29820	1	4	922	8884	36473	\N	51.291429000000001	Воронежская область, Бобровский район, с.Чесменка, ул.Советская, д.66	Россия, Воронежская область, Бобровский район, поселок Чесменка	0101000020E61000004A7D59DAA9154440910DA48B4DA54940
29816	1	4	922	8735	35970	\N	51.119987000000002	Воронежская область, Бобровский район, с.Хреновое, ул.Пушкина, д.147	Россия, Воронежская область, Бобровский район, поселок Хреновое	0101000020E6100000E563778192244440FB78E8BB5B8F4940
29819	1	4	922	8735	36673	\N	51.119987000000002	Воронежская область, Бобровский район, с.Хреновое, ул.Сахарного завода, д.9		0101000020E6100000E563778192244440FB78E8BB5B8F4940
29817	1	4	922	8735	36017	\N	51.119987000000002	Воронежская область, Бобровский район, с.Хреновое, ул.Базарная площадь, д.13а		0101000020E6100000E563778192244440FB78E8BB5B8F4940
29818	1	4	922	8735	36671	\N	51.119987000000002	Воронежская область, Бобровский район, с.Хреновое, ул.40 лет Октября, д.55а		0101000020E6100000E563778192244440FB78E8BB5B8F4940
29809	1	4	922	8391	36738	\N	51.040412000000003	Воронежская область, Бобровский район, с.Тройня, ул.Гагарина, д.123		0101000020E61000005645B8C9A8364440D82E6D382C854940
29813	1	4	922	8578	36372	\N	51.177059	Воронежская область, Бобровский район, с.Сухая Березовка, ул.Карла Маркса, д.65		0101000020E61000008D4127840E004440323B8BDEA9964940
29811	1	4	922	54275	35961	\N	51.144438000000001	Воронежская область, Бобровский район, с.Слобода, ул.Рубежная, д.10		0101000020E61000005E4A5D328E2544405B26C3F17C924940
29831	1	4	922	54275	36717	\N	51.144438000000001	Воронежская область, Бобровский район, с.Слобода, ул.Ленина, д.36	Россия, Воронежская область, Бобровский район, поселок Слобода	0101000020E61000005E4A5D328E2544405B26C3F17C924940
29810	1	4	922	54275	36240	\N	51.144438000000001	Воронежская область, Бобровский район, с.Слобода, ул.Большая, д.44		0101000020E61000005E4A5D328E2544405B26C3F17C924940
29808	1	4	922	8351	35672	\N	51.038451999999999	Воронежская область, Бобровский район, с.Семено-Александровка, ул.Проспект Революции, д.126б	Россия, Воронежская область, Бобровский район, поселок Семено-Александровка	0101000020E6100000B5DE6FB4E31A44409F3BC1FEEB844940
30558	1	4	922	54358	36730	\N	51.330750000000002	п.с-за 2-я Пятилетка, Центральная, 7, Дом культуры	Россия, Воронежская область, Бобровский район, поселок Пятилетка 2-я	0101000020E610000000E5EFDE51F943407593180456AA4940
29799	1	4	922	7862	36621	\N	50.941195	Воронежская область, Бобровский район, с.Пчелиновка, ул.Школьная, д.1		0101000020E61000000BF0DDE68DFF43405114E81379784940
29815	1	4	922	8646	36804	\N	51.263528000000001	Воронежская область, Бобровский район, с.Песковатка, ул.Центральная, д.40		0101000020E61000003CBCE7C072F8434047CA1649BBA14940
30346	1	4	922	46653	37228	\N	50.978349999999999	с.Павловка, ул.Строительная, д.2 А		0101000020E61000008F8EAB915D0B44405305A3923A7D4940
29807	1	4	922	8279	\N	\N	50.967613	Воронежская область, Бобровский район, с.Новый Буравль, д.51		0101000020E610000008B0C8AF1F1A44409C1727BEDA7B4940
29825	1	4	922	54340	36700	\N	51.124882857711903	Воронежская область, Бобровский район, с.2-Никольское, ул.Школьная, д.1а	Россия, Воронежская область, Бобровский район, поселок Никольское 2-е	0101000020E6100000AB92C83EC8E84340C669882AFC8F4940
29800	1	4	922	7936	36513	\N	51.003771999999998	Воронежская область, Бобровский район, с.Николо-Варваринка, ул.Микрорайон, д.7	Россия, Воронежская область, Бобровский район, поселок Николо-Варваринка	0101000020E61000006F8104C58FFD4340FC51D4997B804940
29823	1	4	922	9025	\N	\N	51.138362999999998	Воронежская область, Бобровский район, п.Нескучный, д.29		0101000020E6100000D9243FE257E44340FCFCF7E0B5914940
30457	1	4	922	8128	\N	\N	51.002178999999998	с.Митрофановка, Победы, 3	Россия, Воронежская область, Бобровский район, поселок Митрофановка	0101000020E6100000A06F0B96EA2E444076DEC66647804940
29804	1	4	922	8128	36799	\N	51.002178999999998	Воронежская область, Бобровский район, п.Митрофановка, ул.Молодежная, д.51а		0101000020E6100000A06F0B96EA2E444076DEC66647804940
29805	1	4	922	8192	36591	\N	50.923915999999998	Воронежская область, Бобровский район, с.Мечетка, ул.Ленинская, д.75		0101000020E61000001EFE9AAC510D4440252026E142764940
29798	1	4	922	7856	36538	\N	50.859315000000002	Воронежская область, Бобровский район, с.Липовка, ул.Мира, д.6	Россия, Воронежская область, Бобровский район, поселок Липовка	0101000020E610000041834D9D470344402BFBAE08FE6D4940
29806	1	4	922	8254	36863	\N	50.902988999999998	Воронежская область, Бобровский район, п.Красный, ул.Центральная, д.72		0101000020E6100000F73C7FDAA81A4440E9D2BF2495734940
29812	1	4	922	8507	35959	\N	51.186008000000001	Воронежская область, Бобровский район, с.Коршево, ул.Советская, д.142а	Россия, Воронежская область, Бобровский район, поселок Коршево	0101000020E6100000D15D1267450E4440AE65321CCF974940
29822	1	4	922	8994	36474	\N	51.194329000000003	Воронежская область, Бобровский район, с.Верхний Икорец, ул.Центральная, д.7	Россия, Воронежская область, Бобровский район, поселок Верхний Икорец	0101000020E6100000E08442041CE643400BD5CDC5DF984940
29824	1	4	922	8994	36805	\N	51.194329000000003	Воронежская область, Бобровский район, с.Верхний Икорец, ул.Ранняя Весна, д.44/2		0101000020E6100000E08442041CE643400BD5CDC5DF984940
29789	1	4	922	7352	36452	\N	51.093232	Воронежская область, г.Бобров, ул.Центральная, д.4		0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29790	1	4	922	7352	35730	\N	51.093232	Воронежская область, г.Бобров, ул.Красная Печать, д.22		0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29787	1	4	922	7352	35964	\N	51.091583592250402	Воронежская область, г.Бобров, ул.Комсомольская, д.1	Россия, Воронежская область, Бобровский район, Бобров	0101000020E6100000EA40D653AB0344401E6B4606B98B4940
29788	1	4	922	7352	36096	\N	51.0977079103073	Воронежская область, г.Бобров, ул.Кирова, д.57	Россия, Воронежская область, Бобровский район, Бобров	0101000020E610000027C0B0FCF90444405E471CB2818C4940
29829	1	4	922	7352	36120	\N	51.093232	Воронежская область, г.Бобров, ул.им. Калинина, д.268		0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29793	1	4	922	7352	35681	\N	51.096940408833497	Воронежская область, г.Бобров, ул.Зои Космодемьянской, д.150	Россия, Воронежская область, Бобровский район, Бобров	0101000020E6100000C898BB96900344404DD6A887688C4940
29797	1	4	922	7352	35729	\N	51.093232	Воронежская область, г.Бобров, ул.Гоголя, д.49		0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29827	1	4	922	7352	36026	\N	51.093232	Воронежская область, г.Бобров, ул.3 Интернационала, д.25	Россия, Воронежская область, Бобровский район, Бобров	0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29828	1	4	922	7352	35745	\N	51.093232	Воронежская область, г.Бобров, ул. 22 Января, д.17	Россия, Воронежская область, Бобровский район, Бобров	0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29791	1	4	922	7352	35745	\N	51.1003154805015	Воронежская область, г.Бобров, ул.22 Января, д.17	Россия, Воронежская область, Бобровский район, Бобров	0101000020E6100000B4E55C8AAB0244402D26361FD78C4940
29792	1	4	922	7352	35971	\N	51.093232	Воронежская область, г.Бобров, ул.22 Января, д.136	Россия, Воронежская область, Бобровский район, Бобров	0101000020E6100000A7052FFA0A0644406878B306EF8B4940
29803	1	4	922	8067	37059	\N	50.98715	Воронежская область, Бобровский район, с.Анновка, ул.Советская, д.95б		0101000020E61000008F1D54E23A2844408A1F63EE5A7E4940
29786	1	4	485	7283	36451	\N	51.468525	с.Хлебородное, ул.Советская, д.3		0101000020E610000058ACE122F7564440E02D90A0F8BB4940
29773	1	4	485	6681	36797	\N	51.388812000000001	пос.Суровский, ул.Лесная, д.98		0101000020E6100000841266DAFE8344406C257497C4B14940
29760	1	4	485	47198	37144	\N	51.402873	с.Студеное, ул.Советская, д.14		0101000020E6100000802DAF5C6F19444080B8AB5791B34940
29766	1	4	485	47317	37084	\N	51.413558000000002	с.Старый Курлак, ул.Ленина, д.4		0101000020E6100000CFF753E3A5434440E57FF277EFB44940
29785	1	4	485	7204	36725	\N	51.288527999999999	с.Старая Чигла, ул.Труда, д.121		0101000020E6100000C87E164B913044407AFD497CEEA44940
29784	1	4	485	7204	37062	\N	51.288527999999999	с.Старая Чигла, ул.Ленина, д.1		0101000020E6100000C87E164B913044407AFD497CEEA44940
29783	1	4	485	7148	36548	\N	51.373505000000002	с.Старая Тойда, ул.Октябрьская, д.13а	Россия, Воронежская область, Аннинский район, поселок Старая Тойда	0101000020E61000003D9D2B4A093344403DF20703CFAF4940
29782	1	4	485	53058	36709	\N	51.528872999999997	с.Садовое, ул.Мира, д.81	Россия, Воронежская область, Аннинский район, поселок Садовое	0101000020E6100000F0BF95ECD83E4440635E471CB2C34940
29780	1	4	485	53058	35671	\N	51.528872999999997	с.Садовое, ул.Малая Советская, д.39	Россия, Воронежская область, Аннинский район, поселок Садовое	0101000020E6100000F0BF95ECD83E4440635E471CB2C34940
29781	1	4	485	53058	36377	\N	51.528872999999997	с.Садовое, ул.Красная Площадь, д.47		0101000020E6100000F0BF95ECD83E4440635E471CB2C34940
29779	1	4	485	53058	36377	\N	51.528872999999997	с.Садовое, ул.Красная Площадь, д.41	Россия, Воронежская область, Аннинский район, поселок Садовое	0101000020E6100000F0BF95ECD83E4440635E471CB2C34940
29757	1	4	485	47128	36792	\N	51.585765000000002	с.Сабуровка, ул.Молодежная, д.40		0101000020E610000032CA332F872F44401B12F758FACA4940
29777	1	4	485	6844	36660	\N	51.617752000000003	с.Рубашевка, ул.Советская, д.24		0101000020E61000001B65FD6662524440F1845E7F12CF4940
29761	1	4	485	47222	37094	\N	51.359127000000001	с.Романовка, ул.Школьная, д.2		0101000020E6100000938B31B08E114440280EA0DFF7AD4940
29776	1	4	485	6832	36659	\N	51.404311	с.Рамонье, ул.Центральная, д.24		0101000020E610000023DDCF29C88D4440DF347D76C0B34940
29775	1	4	485	6792	36370	\N	51.568705000000001	пос.Пугачевский, ул.Паркова, д.2		0101000020E61000001FF7ADD6895544402D095053CBC84940
29771	1	4	485	47439	\N	\N	51.294251000000003	пос.Петровка, ул.Дорожная, д.2	Россия, Воронежская область, Аннинский район, поселок Петровка	0101000020E610000052EE3EC7476D44405CE84A04AAA54940
29772	1	4	485	47450	36554	\N	51.423960999999998	с.Островки, ул.Ленинская, д.47Б	Россия, Воронежская область, Аннинский район, поселок Островки	0101000020E61000007D224F92AE774440C5E3A25A44B64940
29765	1	4	485	54370	36865	\N	51.439184063354297	с.Новый Курлак, ул.Ленина, д.23	Россия, Воронежская область, Аннинский район, поселок Новый Курлак	0101000020E61000000BD5CDC5DF46444096766A2E37B84940
29750	1	4	485	5470	36658	\N	51.445654534703003	пос.Новонадеждинский, ул.Плошадь Мира, д.10	Россия, Воронежская область, Аннинский район, поселок Новонадеждинский	0101000020E6100000BCCCB051D61B4440422619390BB94940
29764	1	4	485	54312	36601	\N	51.471617000000002	с.Никольское, ул.50 лет Октября, д.59	Россия, Воронежская область, Аннинский район, поселок Никольское	0101000020E6100000698D4127847A44406B9E23F25DBC4940
29762	1	4	485	54322	36596	\N	51.521833999999998	с.Николаевка, ул.Юбилейная, д.31	Россия, Воронежская область, Аннинский район, поселок Николаевка	0101000020E6100000944E24986A2244406EF8DD74CBC24940
29759	1	4	485	47172	36794	\N	51.400399999999998	с.Нащекино, ул.Школьная, д.2		0101000020E61000007BA4C16D6D114440C1A8A44E40B34940
29767	1	4	485	47354	36750	\N	51.418731999999999	с.Моховое, ул.Советская, д.21		0101000020E610000074F04C68924C4440F3E49A0299B54940
29755	1	4	485	47104	37142	\N	51.570602999999998	с.Мосоловка, ул.Центральная, д.1а		0101000020E61000007026A60BB1364440EFFFE38409C94940
29752	1	4	485	54445	37245	\N	51.481853999999998	"с.Левашовка, ул.Школьная. Здание правления СХА ""Левашовка"""	Россия, Воронежская область, Аннинский район, поселок Левашевка	0101000020E610000050ABE80FCD2A444030B95164ADBD4940
29763	1	4	485	6164	37143	\N	51.532425000000003	с.Круглоподпольное, ул.Школьная, д.23		0101000020E61000000E828E56B528444052499D8026C44940
29774	1	4	485	6709	16742	\N	51.426043999999997	пос.Кругловский, ул.Школьная, д.67а	Россия, Воронежская область, Аннинский район, поселок Кругловский	0101000020E6100000A67C08AA4687444019541B9C88B64940
29754	1	4	485	5675	37100	\N	51.530374000000002	с.Красный Лог, ул.Коммунальная, д.19		0101000020E6100000878C47A9848944400953944BE3C34940
29758	1	4	485	46327	36789	\N	51.531421999999999	с.Желанное, ул.Коммунистическая, д.86		0101000020E610000002B859BC58364440FD2FD7A205C44940
29753	1	4	485	47055	37141	\N	51.531495	с.Дерябкино, ул.Центральная площадь, д.1		0101000020E61000002EE23B31EB774440677E350708C44940
29770	1	4	485	47406	37157	\N	51.435904999999998	пос.Гусевка, ул.Центральная, д.10		0101000020E6100000E4326E6AA08D4440D9942BBCCBB74940
29751	1	4	485	5516	36512	\N	51.422147000000002	с.Верхняя Тойда, ул.Ленина, д.19а	Россия, Воронежская область, Аннинский район, поселок Верхняя Тойда	0101000020E6100000AAEFFCA204274440618DB3E908B64940
26944	1	3	\N	8940	34875	\N	56.347329999999999	г.Ковров, КМКТС, ул.Малеева, 2		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
29748	1	4	485	54468	37325	\N	51.487271999999997	с.Васильевка, ул.Молодежная, д.13	Россия, Воронежская область, Аннинский район, поселок Васильевка	0101000020E6100000FE648C0FB3194440D520CCED5EBE4940
29747	1	4	485	46942	35762	\N	51.486015999999999	с.Бродовое, ул.Школьная, д.12	Россия, Воронежская область, Аннинский район, поселок Бродовое	0101000020E610000053927538BA40444097AAB4C535BE4940
29743	1	4	485	46840	36983	\N	51.540678435186599	с.Б. Алексеевка, ул.Центральная, д.1	Россия, Воронежская область, Аннинский район, поселок Большая Алексеевка	0101000020E610000039605793A762444056D5CBEF34C54940
30847	1	4	485	54382	74974	\N	51.619375230928803	пос.Большие Ясырки, ул.Садовая, д.42	Россия, Воронежская область, Аннинский район, поселок Болшие Ясырки	0101000020E6100000484E266E153E4440E17A14AE47CF4940
29778	1	4	485	54382	67095	\N	51.613325946538197	с.Большие Ясырки, ул.Жданова, д.11		0101000020E61000004ED2FC31AD3D4440ACE4637781CE4940
30639	1	4	485	54353	36722	\N	51.517966999999999	с.Бабяково, ул.Совхозная, д.72	Россия, Воронежская область, Аннинский район, поселок Бобяково	0101000020E61000009A7D1EA33C67444020B41EBE4CC24940
29745	1	4	485	48878	36609	\N	51.322797000000001	с.Березовка, ул.Советская, д.9	Россия, Воронежская область, Аннинский район, поселок Березовка	0101000020E6100000C1374D9F1D1A44409B1F7F6951A94940
29741	1	4	485	54273	35946	\N	51.455971923198703	с.Архангельское, ул.Мира, д.10а		0101000020E6100000A77686A92D77444024F25D4A5DBA4940
29744	1	4	485	46872	36867	\N	51.355061613070603	с.Артюшкино, ул.Свободы, д.19	Россия, Воронежская область, Аннинский район, поселок Артюшкино	0101000020E6100000BB0D6ABFB5794440B306EFAB72AD4940
29740	1	4	485	2900	35823	\N	51.487490999999999	пгт.Анна, ул.Чехова, д.1А		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29738	1	4	485	2900	35670	\N	51.487490999999999	пгт.Анна, ул.Фридриха Энгельса, д.1А	Россия, Воронежская область, Аннинский район, поселок Анна	0101000020E610000027DBC01DA8354440130CE71A66BE4940
29631	1	4	485	2900	35887	\N	51.487490999999999	пгт. Анна, ул.Советская, д.17		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29737	1	4	485	2900	35763	\N	51.487490999999999	пгт.Анна, ул.М.Горького, д.40	Россия, Воронежская область, Аннинский район, поселок Анна	0101000020E610000027DBC01DA8354440130CE71A66BE4940
29487	1	4	485	2900	36115	\N	51.487490999999999	пгт.Анна, ул.Ленина, д.24		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29465	1	4	485	2900	36114	\N	51.487490999999999	пгт. Анна, ул.Красноармейская, д.199		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29645	1	4	485	2900	35736	\N	51.487490999999999	пгт.Анна, ул.Коммунальная, д.104		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29702	1	4	485	2900	36141	\N	51.487490999999999	пгт.Анна, ул.К.Маркса, д.11		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29739	1	4	485	2900	36050	\N	51.487490999999999	пгт.Анна, ул.Гнездилова, д.18		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29545	1	4	485	2900	35735	\N	51.487490999999999	пгт.Анна, ул.Ватутина, д.186		0101000020E610000027DBC01DA8354440130CE71A66BE4940
29352	1	4	485	2900	35735	\N	51.487490999999999	пгт.Анна, ул.Ватутина, д.37		0101000020E610000027DBC01DA8354440130CE71A66BE4940
30864	1	4	485	46242	37397	\N	51.336967999999999	с.Александровка, ул.Школьная, д.21		0101000020E61000005E9D6340F66C444036E675C421AB4940
30808	1	4	485	46242	36053	\N	51.336265010638101	с.Александровка, Первомайская, 3	Россия, Воронежская область, Аннинский район, поселок Александровка	0101000020E61000008E041A6CEA6C44400CE544BB0AAB4940
30763	1	4	5947	38741	36765	\N	50.769981999999999	с.Верхний Ольшан, Ольшанская, 18		0101000020E610000073124A5F086F43401C412AC58E624940
26481	1	3	\N	60374	\N	\N	55.930671890735901	Владимирская область, Петушинский район, Пекшинское сельское поселение, п. Сушнево-2, Административное здание, б/н	Россия, Владимирская область	0101000020E61000007EFE7BF0DADB4340C6A6954220F74B40
26825	1	3	\N	54153	34831	\N	56.133719709711599	поселок имени Воровского, Воровского, 24		0101000020E610000038BEF6CC923444401A69A9BC1D114C40
26554	1	3	\N	54133	34789	\N	56.499234999999999	город Юрьев-Польский, Шибанкова, 46		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26556	1	3	\N	54133	34560	\N	56.499234999999999	город Юрьев-Польский, Авангардский переулок, 1		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26625	1	3	\N	54130	34469	\N	56.426647000000003	город Суздаль, Ленина, 50		0101000020E610000052B9895A9A394440E0F76F5E9C364C40
26387	1	3	\N	54145	34773	\N	56.374366999999999	"Владимирская область, Александровский район, город Струнино, Клубный переулок (МКДУ ""Струнинский Дом культуры"", 1 этаж), 1"		0101000020E6100000E3E0D231E7494340CFD90242EB2F4C40
26544	1	3	\N	54136	34660	\N	55.991314000000003	г.Собинка, Владимирская область, Собинский район, Чайковского, 3а		0101000020E61000003755F7C8E602444092088D60E3FE4B40
26548	1	3	\N	54136	34624	\N	55.994393300675398	г.Лакинск, Владимирская область, Собинский район, Центральная площадь, 6	Россия, Владимирская область, Собинский район, Собинка	0101000020E6100000FFB3E6C75F024440882F134548FF4B40
26540	1	3	\N	54136	34856	\N	55.991314000000003	г.Собинка, Владимирская область, Собинский район, Ленина, 5		0101000020E61000003755F7C8E602444092088D60E3FE4B40
26543	1	3	\N	54136	34584	\N	55.987445018077402	г.Собинка, Владимирская область, Собинский район, Димитрова, 24а	Россия, Владимирская область, Собинский район, Собинка	0101000020E6100000D0D03FC1C5024440A3CC069964FE4B40
26542	1	3	\N	54136	34584	\N	55.991314000000003	г.Собинка, Владимирская область, Собинский район, Димитрова, 7		0101000020E61000003755F7C8E602444092088D60E3FE4B40
26600	1	3	\N	54157	34862	\N	56.175064539729703	село Сновицы, Школьная, 1	Россия, Владимирская область	0101000020E61000000531D0B52F2E44404DD6A88768164C40
26524	1	3	\N	60372	\N	\N	55.966906999999999	д.Рукав, Собинский район, Владимирская область, Здание администрации, 2а		0101000020E6100000FCAA5CA8FC4F444001A3CB9BC3FB4B40
26733	1	3	\N	54142	34754	\N	55.991435350677101	Владимирская область, ЗАТО город Радужный, 3 квартал, 36		0101000020E61000006AF6402B302A44400D8E9257E7FE4B40
26732	1	3	\N	54142	34666	\N	56.003100000000003	Владимирская область, ЗАТО город Радужный, 1 квартал, 56		0101000020E610000035971B0C752A44400E4FAF9465004C40
26641	1	3	\N	54142	34666	\N	56.003100000000003	Владимирская область, ЗАТО город Радужный, 1 квартал, 41		0101000020E610000035971B0C752A44400E4FAF9465004C40
26575	1	3	\N	60428	\N	\N	55.966906999999999	с. Пригородный, 44	Россия, Владимирская область, Судогодский район, поселок Кострово	0101000020E6100000FCAA5CA8FC4F444001A3CB9BC3FB4B40
26494	1	3	\N	54134	34567	\N	55.918256999999997	Владимирская область, Петушинский район, город Покров, Пролетарская, 1А		0101000020E61000002A7288B8399743405A29047289F54B40
26453	1	3	\N	54138	34605	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Советская площадь, 3		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26457	1	3	\N	54138	34710	\N	55.924788999999997	"Владимирская область, Петушинский район, г. Петушки, Полевой проезд, д.4 (административное здание МП ""Тепловык сети"")"		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26456	1	3	\N	54138	34959	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Ленина, 96		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26463	1	3	\N	54138	34913	\N	55.927345756673702	Владимирская область, Петушинский район, город Петушки, Клязьменская, 2		0101000020E6100000ED9C668176BB4340C8091346B3F64B40
27182	1	3	\N	41177	34634	\N	55.56053	Владимирская область, город Муром, Тихомирова, 15	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27184	1	3	\N	41177	74890	\N	55.56053	г. Муром, ул. Привокзальная площадь им. Гастелло , 5, "Ж/Д вокзал",		0101000020E61000002237C30DF8044540A4367172BFC74B40
27181	1	3	\N	41177	74892	\N	55.56053	г. Муром, ул. Московская, 110, МОУ СО Школа № 20		0101000020E61000002237C30DF8044540A4367172BFC74B40
27036	1	3	\N	41177	34815	\N	55.56053	Владимирская область, город Муром, Мичуринская, 2		0101000020E61000002237C30DF8044540A4367172BFC74B40
27075	1	3	\N	41177	34640	\N	55.56053	Владимирская область, город Муром, Ленинградская, 13		0101000020E61000002237C30DF8044540A4367172BFC74B40
27073	1	3	\N	41177	34640	\N	55.56053	Владимирская область, город Муром, Ленинградская, 28		0101000020E61000002237C30DF8044540A4367172BFC74B40
27038	1	3	\N	41177	13369	\N	55.56053	Владимирская область, город Муром, Красногвардейская, 40/А		0101000020E61000002237C30DF8044540A4367172BFC74B40
27044	1	3	\N	41177	34619	\N	55.571268185050599	Владимирская область, город Муром, Комсомольская, 55	Россия, Владимирская область, Муромский район, Муром	0101000020E61000000CEA5BE6740345402CA0504F1FC94B40
27047	1	3	\N	41177	34769	\N	55.56053	Владимирская область, город Муром, Воровского, 103		0101000020E61000002237C30DF8044540A4367172BFC74B40
27129	1	3	\N	54140	34629	\N	55.336477000000002	город Меленки, Королева, 2А		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27134	1	3	\N	54140	34778	\N	55.336477000000002	город Меленки, Дзержинского, 28		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
26435	1	3	\N	54127	34460	\N	56.302532999999997	Владимирская область, город Кольчугино, Шмелева, 3		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26437	1	3	\N	54127	34736	\N	56.302532999999997	Владимирская область, город Кольчугино, Мира, 4		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26432	1	3	\N	54127	34749	\N	56.302532999999997	Владимирская область, город Кольчугино, ул. Ленина, 17		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26431	1	3	\N	54127	34604	\N	56.298428701007303	Владимирская область, город Кольчугино, Дружбы, 14	Россия, Владимирская область, Кольчугинский район, Кольчугино	0101000020E61000005C04C6FA06B04340C896E5EB32264C40
26414	1	3	\N	54127	34604	\N	56.302532999999997	Владимирская область, город Кольчугино, Дружбы, 13		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26918	1	3	\N	8940	34501	\N	56.347329999999999	Владимирская область, город Ковров, ул. Чернышевского, дом 8		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26910	1	3	\N	8940	34706	\N	56.347329999999999	Владимирская область, город Ковров, ул. Свердлова, дом 13		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26919	1	3	\N	8940	34522	\N	56.347329999999999	Владимирская область, город Ковров, проспект Ленина, дом 59		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26916	1	3	\N	8940	34708	\N	56.347329999999999	Владимирская область, город Ковров, ул. Подлесная, дом 1		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26923	1	3	\N	8940	34670	\N	56.347329999999999	Владимирская область, город Ковров, ул. Моховая, дом 1/2, школа № 8		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26909	1	3	\N	8940	34885	\N	56.347329999999999	Владимирская область, город Ковров, микрорайон Заречная Слободка, Школа № 12		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26904	1	3	\N	8940	34874	\N	56.347329999999999	Владимирская область, город Ковров, Элеваторная, дом 1		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26942	1	3	\N	8940	34671	\N	56.347329999999999	Владимирская область, город Ковров, ул. Шмидта, дом 48		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26940	1	3	\N	8940	34574	\N	56.347329999999999	Владимирская область, город Ковров, ул. Циолковского, дом 26		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26843	1	3	\N	8940	34664	\N	56.347329999999999	Владимирская область, город Ковров, ул. Труда, дом 6		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26926	1	3	\N	8940	34757	\N	56.347329999999999	Владимирская область, город Ковров, ул. Строителей, дом 20, корп. 1		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26914	1	3	\N	8940	34756	\N	56.347329999999999	Владимирская область, город Ковров, ул. Сосновая, дом 13, корп. А		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26915	1	3	\N	8940	34573	\N	56.347329999999999	Владимирская область, город Ковров, ул. Пионерская, дом 8		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26912	1	3	\N	8940	34480	\N	56.347329999999999	Владимирская область, город Ковров, ул. Первомайская, дом 32	Россия, Владимирская область, Ковров	0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26949	1	3	\N	8940	74915	\N	56.347329999999999	г. Ковров, ул. Октябрьская, д. 10 / железнодорожный вокзал г. Коврова		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26913	1	3	\N	8940	34669	\N	56.347329999999999	Владимирская область, город Ковров, ул. Муромская, дом 5		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26943	1	3	\N	8940	34520	\N	56.347329999999999	Владимирская область, город Ковров, ул. Лопатина, дом 4		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26941	1	3	\N	8940	34520	\N	56.347329999999999	Владимирская область, город Ковров, ул. Лопатина, дом 44, корп. А		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26939	1	3	\N	8940	34520	\N	56.347329999999999	Владимирская область, город Ковров, ул. Лопатина, дом 55		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26922	1	3	\N	8940	34575	\N	56.347329999999999	Владимирская область, город Ковров, ул. Олега Кошевого, дом 1, корп. 4		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26917	1	3	\N	8940	34752	\N	56.347329999999999	Владимирская область, город Ковров, ул. Колхозная, дом 30		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26903	1	3	\N	8940	34667	\N	56.347329999999999	Владимирская область, город Ковров, Ковров-8, Гарнизонный Дом Офицеров		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26902	1	3	\N	8940	34704	\N	56.347329999999999	Владимирская область, город Ковров, Клязьминская, дом 14		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26924	1	3	\N	8940	34637	\N	56.347329999999999	Владимирская область, город Ковров, ул. Зои Космодемьянской, дом 2, корп. 1		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26934	1	3	\N	8940	34608	\N	56.347329999999999	Владимирская область, город Ковров, ул. Запольная, дом 7		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26933	1	3	\N	8940	34608	\N	56.347329999999999	Владимирская область, город Ковров, ул. Запольная, дом 37		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26932	1	3	\N	8940	34758	\N	56.347329999999999	Владимирская область, город Ковров, ул. Жуковского, дом 5		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26928	1	3	\N	8940	34801	\N	56.347329999999999	Владимирская область, город Ковров, ул. Еловая, дом 5		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26925	1	3	\N	8940	34801	\N	56.347329999999999	Владимирская область, город Ковров, ул. Еловая, дом 19		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26907	1	3	\N	8940	34572	\N	56.347329999999999	Владимирская область, город Ковров, ул. Дегтярева, дом 65		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26906	1	3	\N	8940	34572	\N	56.347329999999999	Владимирская область, город Ковров, Дегтярева, дом 192		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26905	1	3	\N	8940	34572	\N	56.347329999999999	Владимирская область, город Ковров, ул. Дегтярева, дом 192		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26921	1	3	\N	8940	34478	\N	56.347329999999999	Владимирская область, город Ковров, ул. Грибоедова, дом 76		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26920	1	3	\N	8940	34478	\N	56.347329999999999	Владимирская область, город Ковров, ул. Грибоедова, дом 9, корп. В		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26896	1	3	\N	8940	34478	\N	56.351217065372701	Владимирская область, город Ковров, ул. Грибоедова, дом 24	Россия, Владимирская область, Ковров городской округ	0101000020E6100000F373435376AA44404D66BCADF42C4C40
26938	1	3	\N	8940	34712	\N	56.347329999999999	Владимирская область, город Ковров, ул. Волго-Донская, дом 9, корп. А		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26937	1	3	\N	8940	34712	\N	56.347329999999999	Владимирская область, город Ковров, ул. Волго-Донская, дом 1, корп. Б		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26936	1	3	\N	8940	34712	\N	56.347329999999999	Владимирская область, город Ковров, ул. Волго-Донская, дом 1, корп. А		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26930	1	3	\N	8940	34709	\N	56.347329999999999	Владимирская область, город Ковров, ул. Владимирская, дом 53, корп. А		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26901	1	3	\N	8940	34542	\N	56.347329999999999	Владимирская область, город Ковров, Белинского, дом 4, к.А		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26911	1	3	\N	8940	34482	\N	56.375140070798302	Владимирская область, город Ковров, ул. Абельмана, дом 15	Россия, Владимирская область, Ковров городской округ	0101000020E610000073F4F8BD4DA74440F2B5679604304C40
26908	1	3	\N	8940	34482	\N	56.347329999999999	Владимирская область, город Ковров, ул.  Абельмана, дом 75		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26935	1	3	\N	8940	34802	\N	56.347329999999999	Владимирская область, город Ковров, ул. 19 Партсъезда, дом 8		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26927	1	3	\N	8940	34799	\N	56.347329999999999	Владимирская область, город Ковров, ул. Строителей, дом 7		0101000020E610000000FDBE7FF3AA4440B875374F752C4C40
26423	1	3	\N	54126	34638	\N	56.158059999999999	г. Киржач, мк-н Красный  Октябрь,  ул. Пушкина, 27,    средняя  школа  № 6, 1й  этаж, холл		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26391	1	3	\N	54126	35107	\N	56.158059999999999	Владимирская область, г. Киржач, Гагарина, 25		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26347	1	3	\N	54126	34458	\N	56.158059999999999	Владимирская область, г. Киржач, 50 Лет Октября, 14		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26360	1	3	\N	54125	34448	\N	56.311466000000003	Владимирская область, Александровский район, город Карабаново, Мира, 11		0101000020E61000001C615111A759434071E82D1EDE274C40
26382	1	3	\N	54125	34681	\N	56.311466000000003	Владимирская область, Александровский район, город Карабаново, Лермонтова, 15		0101000020E61000001C615111A759434071E82D1EDE274C40
27186	1	3	\N	54144	34730	\N	56.350717000000003	г. Камешково, ул. Ленина, д. 1, Муниципальное учреждение культуры районный Дом культуры "13 Октябрь"		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
26838	1	3	\N	54144	34730	\N	56.350717000000003	Владимирская область, Камешковский район, город Камешково, Ленина, 2		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
26837	1	3	\N	54144	34730	\N	56.350717000000003	Владимирская область, Камешковский район, город Камешково, Ленина, 1		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
26698	1	3	\N	54156	34860	\N	56.121410629188603	Владимирская область, город Владимир, Октябрьский район, поселок Заклязьменский, Центральная, 11а		0101000020E61000001E34BBEEAD3A4440F52F49658A0F4C40
26775	1	3	\N	11724	34468	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Торфяная, дом 9		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26773	1	3	\N	11724	34500	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, проспект 50-летия Советской власти, дом 13		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26778	1	3	\N	11724	34895	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Писарева, дом 17		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26776	1	3	\N	11724	34472	\N	55.617744000000002	г.Гусь-Хрустальный, ул.Торфяная, д.9, средняя школа № 4		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26793	1	3	\N	11724	34516	\N	55.617744000000002	г. Гусь-Хрустальный, ул.Рылеева, д. 3 средняя школа № 3		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26772	1	3	\N	11724	34603	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Мира, дом 2		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26789	1	3	\N	11724	34662	\N	55.617744000000002	г.Гусь-Хрустальный, Микрорайон, д.53, средняя школа № 2		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26788	1	3	\N	11724	34662	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, Микрорайон, дом 53		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26777	1	3	\N	11724	34563	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Менжинского, дом 2		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26791	1	3	\N	11724	9878	\N	55.618812557454298	г. Гусь-Хрустальный, ул.Менделеева, д.20 средняя школа № 1	Россия, Владимирская область, Гусь-Хрустальный городской округ	0101000020E6100000111AC1C6F55344407AABAE4335CF4B40
26790	1	3	\N	11724	9878	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Менделеева, дом 20		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26774	1	3	\N	11724	34747	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Лесная, дом 18		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26780	1	3	\N	11724	34457	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Курская, дом 18а		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26779	1	3	\N	11724	34565	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Кирова, дом 4		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26787	1	3	\N	11724	34441	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Интернациональная, дом 49		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26784	1	3	\N	11724	34441	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Интернациональная, дом 11		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26786	1	3	\N	11724	34697	\N	55.617744000000002	г.Гусь-Хрустальный, ул.Димитрова, д.17, школа № 9		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26785	1	3	\N	11724	34697	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Димитрова, дом 38		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26781	1	3	\N	11724	34791	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица Александра Невского, дом 39а		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26782	1	3	\N	11724	34470	\N	55.617744000000002	Владимирская область, город Гусь-Хрустальный, улица 2-я Народная, дом 5		0101000020E6100000EC134031B25244406EA6423C12CF4B40
26783	1	3	\N	11724	34471	\N	55.617744000000002	г.Гусь-Хрустальный, 2-ая Народная, д.5, школа № 7		0101000020E6100000EC134031B25244406EA6423C12CF4B40
27012	1	3	\N	54137	74906	\N	56.20167	г. Гороховец, ул.Ленина, д.64, (здание МОУ СОШ № 1)		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27018	1	3	\N	54137	34678	\N	56.20167	Владимирская область, Гороховецкий район, город Гороховец, Гагарина, 30		0101000020E6100000971B0C7558594540CB4A9352D0194C40
26963	1	3	\N	54135	34675	\N	56.242089	г. Вязники, Физкультурная, 12		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26954	1	3	\N	54135	34676	\N	56.242089	г. Вязники, Советский переулок, 6/9		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26962	1	3	\N	54135	34580	\N	56.242089	г. Вязники, Ленина, 48		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26965	1	3	\N	54135	34810	\N	56.242089	г. Вязники, Железнодорожная, 11		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26950	1	3	\N	54135	34674	\N	56.242089	город Вязники, Горького, 102		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26727	1	3	\N	3510	\N	\N	56.134450000000001	г. Владимир, помещение территориального сектора мкр. Лесной		0101000020E61000007958A835CD3544403E7958A835114C40
26700	1	3	\N	3510	\N	\N	56.140048	Владимирская область, город Владимир, Октябрьский район, деревня Шепелево, Дом культуры		0101000020E6100000139ED0EB4F30444063EFC517ED114C40
26634	1	3	\N	3510	16314	\N	56.114330000000002	Владимирская область, город Владимир, Ленинский район, Завадского, 7	Россия, Владимирская область, Владимир, Ленинский район, улица Завадского, 7	0101000020E6100000D105F52D732C4440D1798D5DA20E4C40
26708	1	3	\N	3510	15554	\N	56.168039999999998	г. Владимир, театр фольклора «Разгуляй», ул. Добросельская, д. № 194а	Россия, Владимирская область, Владимир, Фрунзенский район, улица Добросельская, 194а	0101000020E6100000CBA0DAE0443E4440BD35B05582154C40
27086	1	3	\N	3510	16273	\N	56.141613	деревня Петроково, Дачная, 7	Россия, Владимирская область, Владимир, Октябрьский район, улица Дачная, 7/45	0101000020E61000008A1F63EE5A2E44401FD8F15F20124C40
26680	1	3	\N	3510	15340	\N	56.144751999999997	Владимирская область, город Владимир, Октябрьский район, Горького, 83	Россия, Владимирская область, Владимир, Октябрьский район, улица Горького, 83	0101000020E6100000BBF2599E07314440EA03C93B87124C40
26701	1	3	\N	3510	15502	\N	56.131490999999997	г. Владимир, ул. Вокзальная, д. 2 / железнодорожный вокзал Владимир	Россия, Владимирская область, Владимир, Октябрьский район, улица Вокзальная, 12а	0101000020E61000009A5DF75624364440F25B74B2D4104C40
26671	1	3	\N	3510	34864	\N	56.135398000000002	Владимирская область, город Владимир, Октябрьский район, проспект Строителей, 44в	Россия, Владимирская область, Владимир, проспект Строителей, 44в	0101000020E6100000C21550A8A72D4440CFF8BEB854114C40
26728	1	3	\N	3510	74897	\N	56.139848431165298	г. Владимир, школа  № 47, мкр. Оргтруд		0101000020E61000005B441493373444409C340D8AE6114C40
26716	1	3	\N	3510	74903	\N	56.167656000000001	г. Владимир, СДЮСШОР № 2 по шахматам, ул. Юбилейная, д. № 56	Россия, Владимирская область, Владимир, улица Юбилейная	0101000020E6100000B0045262D73C4440357D76C075154C40
26712	1	3	\N	3510	74917	\N	56.164135000000002	г. Владимир, химико-механический колледж, ул. Юбилейная, д.№ 11		0101000020E6100000280EA0DFF73B444082902C6002154C40
26655	1	3	\N	3510	34865	\N	56.096538000000002	Владимирская область, город Владимир, Ленинский район, Энергетиков, 1	Россия, Владимирская область, Владимир, Энергетик микрорайон, улица Энергетиков, 1	0101000020E610000099F1B6D26B1944401F69705B5B0C4C40
26697	1	3	\N	3510	34845	\N	56.108812999999998	Владимирская область, город Владимир, Октябрьский район, микрорайон Коммунар, Школьная, 1		0101000020E61000004C1C7920B238444098309A95ED0D4C40
26657	1	3	\N	3510	34845	\N	56.0561282361368	Владимирская область, город Владимир, Ленинский район, Школьная, 10	Россия, Владимирская область, Владимир, улица Школьная	0101000020E61000006DCA15DEE52E4440E831CA332F074C40
26673	1	3	\N	3510	34839	\N	56.139721999999999	Владимирская область, город Владимир, Октябрьский район, Чернышевского, 76		0101000020E61000000116F9F5432E44400F441669E2114C40
26631	1	3	\N	3510	34847	\N	56.129077000000002	Владимирская область, город Владимир, Ленинский район, Чайковского, 25		0101000020E610000020B58993FB2D444039D55A9885104C40
26660	1	3	\N	3510	35181	\N	56.1205482610549	Владимирская область, город Владимир, Ленинский район, Центральная, 40		0101000020E610000059DE550F9821444092CCEA1D6E0F4C40
26691	1	3	\N	3510	34858	\N	56.148338000000003	Владимирская область, город Владимир, Октябрьский район, Усти-на-Лабе, 28	Россия, Владимирская область, Владимир, улица Усти-На-Лабе, 28	0101000020E610000067D5E76A2B364440856055BDFC124C40
26662	1	3	\N	3510	34848	\N	56.138368057663499	Владимирская область, город Владимир, Ленинский район, Университетская, 1	Россия, Владимирская область, Владимир, Университетская улица, 1	0101000020E6100000A52C431CEB2E44400E68E90AB6114C40
26678	1	3	\N	3510	34863	\N	56.154024	Владимирская область, город Владимир, Октябрьский район, Тракторная, 1а	Россия, Владимирская область, Владимир, улица Тракторная, 1а	0101000020E6100000091A33897A2F44404966F50EB7134C40
26667	1	3	\N	3510	34866	\N	56.104832999999999	г.Владимир, ул.Тихонравова, д.1, ВЗФЭИ		0101000020E610000053E751F17F2D44405245F12A6B0D4C40
26666	1	3	\N	3510	34866	\N	56.104832999999999	Владимирская область, город Владимир, Ленинский район, Тихонравова, 1	Россия, Владимирская область, Владимир, улица Тихонравова, 1	0101000020E610000053E751F17F2D44405245F12A6B0D4C40
26713	1	3	\N	3510	74901	\N	56.134450000000001	г. Владимир, детская школа искусств № 3, Суздальский проспект, д. № 11		0101000020E61000007958A835CD3544403E7958A835114C40
26682	1	3	\N	3510	34835	\N	56.141446999999999	Владимирская область, город Владимир, Октябрьский район, Студенческая, 10а		0101000020E6100000DBA7E33103314440048F6FEF1A124C40
26675	1	3	\N	3510	16290	\N	56.148392999999999	Владимирская область, город Владимир, Октябрьский район, проспект Строителей, 2б	Россия, Владимирская область, Владимир, Ленинский район, Строителей проспект, 2б	0101000020E6100000813D26529A2F444048FAB48AFE124C40
26674	1	3	\N	3510	16290	\N	56.144917999999997	Владимирская область, город Владимир, Октябрьский район, проспект Строителей, 10а	Россия, Владимирская область, Владимир, Ленинский район, Строителей проспект, 10а	0101000020E610000098A1F144102F4440054D4BAC8C124C40
26629	1	3	\N	3510	16290	\N	56.137686000000002	Владимирская область, город Владимир, Ленинский район, проспект Строителей, 11	Россия, Владимирская область, Владимир, Ленинский район, Строителей проспект, 11	0101000020E61000006893C3279D2E4440FC8EE1B19F114C40
26722	1	3	\N	3510	67594	\N	56.169446874875803	г. Владимир, школа № 10, ул. Соколова-Соколенка, д. № 18а		0101000020E61000009885764EB33A4440E1B37570B0154C40
26711	1	3	\N	3510	67594	\N	56.134450000000001	г. Владимир, школа № 38, ул. Соколова-Соколенка, д. № 7б		0101000020E61000007958A835CD3544403E7958A835114C40
26706	1	3	\N	3510	74925	\N	56.151342496795003	г. Владимир, АНО «Центр организации культурного досуга «Артдворец», ул. Северная, д. № 2а	Россия, Владимирская область, Владимир, Октябрьский район, улица Северная, 2а	0101000020E610000087DEE2E13D3744407041B62C5F134C40
26707	1	3	\N	3510	74895	\N	56.134450000000001	г. Владимир, АНО «Центр организации культурного досуга «Артдворец» ул. Северная, д. № 2а		0101000020E61000007958A835CD3544403E7958A835114C40
26718	1	3	\N	3510	74904	\N	56.134450000000001	г. Владимир, школа № 5, ул. Растопчина, д. № 31а		0101000020E61000007958A835CD3544403E7958A835114C40
26644	1	3	\N	3510	34859	\N	56.119669000000002	Владимирская область, город Владимир, Ленинский район, Разина, 2а	Россия, Владимирская область, Владимир, улица Разина, 2а	0101000020E6100000B56B425A633044402AAC5450510F4C40
26690	1	3	\N	3510	34841	\N	56.149371000000002	Владимирская область, город Владимир, Октябрьский район, Полины Осипенко, 33а	Россия, Владимирская область, Владимир, улица Полины Осипенко, 33а	0101000020E61000000586AC6EF534444044FCC3961E134C40
26689	1	3	\N	3510	34841	\N	56.143188000000002	Владимирская область, город Владимир, Октябрьский район, Полины Осипенко, 6	Россия, Владимирская область, Владимир, улица Полины Осипенко, 6	0101000020E61000009DF4BEF1B5354440FF9600FC53124C40
26688	1	3	\N	3510	34841	\N	56.142876999999999	Владимирская область, город Владимир, Октябрьский район, Полины Осипенко, 13	Россия, Владимирская область, Владимир, улица Полины Осипенко, 13	0101000020E61000003C855CA967354440E02C25CB49124C40
26665	1	3	\N	3510	34834	\N	56.116146000000001	Владимирская область, город Владимир, Ленинский район, Парижской Коммунны, 45а	Россия, Владимирская область, Владимир, улица Парижской Коммуны, 45а	0101000020E6100000021077F52A2E4440D6C743DFDD0E4C40
26642	1	3	\N	3510	34834	\N	56.115814999999998	Владимирская область, город Владимир, Ленинский район, Парижской Коммуны, 45б	Россия, Владимирская область, Владимир, улица Парижской Коммуны, 45б	0101000020E61000003C66A032FE2D444070B1A206D30E4C40
26640	1	3	\N	3510	34834	\N	56.116146000000001	Владимирская область, город Владимир, Ленинский район, Парижской Коммуны, 45-а		0101000020E6100000021077F52A2E4440D6C743DFDD0E4C40
26649	1	3	\N	3510	34694	\N	56.130462000000001	Владимирская область, город Владимир, Ленинский район, проспкт Октябрьский, 11	Россия, Владимирская область, Владимир, Октябрьский проспект, 11	0101000020E6100000F374AE282532444075AF93FAB2104C40
26653	1	3	\N	3510	34849	\N	56.101298	Владимирская область, город Владимир, Ленинский район, Ноябрьская, 3	Россия, Владимирская область, Владимир, Юрьевец микрорайон, Ноябрьская улица, 3	0101000020E610000006BD3786002444403A933655F70C4C40
26639	1	3	\N	3510	34832	\N	56.107261999999999	Владимирская область, город Владимир, Ленинский район, Нижняя Дуброва, 28-а	Россия, Владимирская область, Владимир, улица Нижняя Дуброва, 28а	0101000020E6100000C16F438CD72C4440410DDFC2BA0D4C40
26638	1	3	\N	3510	34832	\N	56.107261999999999	г.Владимир, ул.Нижняя Дуброва, д.28-а, школа № 39		0101000020E6100000C16F438CD72C4440410DDFC2BA0D4C40
26532	1	3	\N	3510	34474	\N	56.1497193065643	д.Толпухово, Собинский район, Владимирская область, Молодежная, 15		0101000020E61000003F6EBF7CB23044407F4B00FE29134C40
26521	1	3	\N	3510	34474	\N	56.14911	с.Ворша, Собинский район, Владимирская область, Молодежная, 19	Россия, Владимирская область, Владимир, улица Молодежная	0101000020E610000017F2086EA4304440D7C0560916134C40
26705	1	3	\N	3510	34842	\N	56.146352560413497	г. Владимир, Дом культуры молодежи, ул. Мира, д. № 55	Россия, Владимирская область, Владимир, улица Мира, 55	0101000020E6100000488787307E364440F355F2B1BB124C40
26704	1	3	\N	3510	34842	\N	56.140991	г.  Владимир, Дом культуры молодежи, ул. Мира, д. № 55		0101000020E610000069FD2D01F8334440E2033BFE0B124C40
26686	1	3	\N	3510	34842	\N	56.141050999999997	Владимирская область, город Владимир, Октябрьский район, Мира, 31		0101000020E61000006EC1525DC0334440B7088CF50D124C40
26658	1	3	\N	3510	34842	\N	56.134329999999999	Владимирская область, город Владимир, Ленинский район, Мира, 8		0101000020E61000008410902FA1304440936FB6B931114C40
26699	1	3	\N	3510	35150	\N	56.140048	Владимирская область, город Владимир, Октябрьский район, Луневская, 1а		0101000020E6100000139ED0EB4F30444063EFC517ED114C40
26687	1	3	\N	3510	34840	\N	56.137068999999997	Владимирская область, город Владимир, Октябрьский район, Луначарского, 15		0101000020E6100000F870C971A7344440D0251C7A8B114C40
26685	1	3	\N	3510	34840	\N	56.135463999999999	Владимирская область, город Владимир, Октябрьский район, Луначарского, 1		0101000020E61000008AAC3594DA33444086E464E256114C40
26646	1	3	\N	3510	16311	\N	56.122329000000001	Владимирская область, город Владимир, Ленинский район, проспект Ленина, 8	Россия, Владимирская область, Владимир, Ленинский район, Ленина проспект, 8	0101000020E6100000C7A17E17B63044401B2D077AA80F4C40
26633	1	3	\N	3510	16311	\N	56.117069999999998	Владимирская область, город Владимир, Ленинский район, проспект Ленина, 53	Россия, Владимирская область, Владимир, Ленинский район, Ленина проспект, 53	0101000020E610000049A297512C2D4440DEAB5626FC0E4C40
26672	1	3	\N	3510	34846	\N	56.139184999999998	Владимирская область, город Владимир, Октябрьский район, Лакина, 139	Россия, Владимирская область, Владимир, улица Лакина, 139	0101000020E6100000E0BA6246782D4440008C67D0D0114C40
26670	1	3	\N	3510	34846	\N	56.128093999999997	Владимирская область, город Владимир, Октябрьский район, Лакина, 183		0101000020E61000005A0F5F268A2C44402B685A6265104C40
26726	1	3	\N	3510	67460	\N	56.171050991547801	г. Владимир, школа № 20, ул. Куйбышева, д. № 56	Россия, Владимирская область, Владимир, улица Куйбышева, 56	0101000020E61000003E247CEF6F3844405B79C9FFE4154C40
26630	1	3	\N	3510	34843	\N	56.130487000000002	Владимирская область, город Владимир, Ленинский район, Красноармейская, 40	Россия, Владимирская область, Владимир, Красноармейская улица, 40	0101000020E61000006479573D602E4440CEC64ACCB3104C40
26720	1	3	\N	3510	74916	\N	56.170907	г. Владимир, гимназия № 35, ул. Комиссарова, д. № 39, т.	Россия, Владимирская область, Владимир, улица Комиссарова, 39	0101000020E610000045A165DD3F3C444028D4D347E0154C40
26719	1	3	\N	3510	74916	\N	56.170895371236	г. Владимир, гимназия № 35, ул. Комиссарова, д. № 39, т. 21-18-08.	Россия, Владимирская область, Владимир, улица Комиссарова, 39	0101000020E61000005B61FA5E433C444064062AE3DF154C40
26721	1	3	\N	3510	67502	\N	56.139927999999998	г. Владимир, школа № 34, ул. Комиссарова, д. № 27	Россия, Владимирская область, Владимир, Михайловская улица, 2	0101000020E6100000672618CE35344440B8E52329E9114C40
26547	1	3	\N	3510	34479	\N	56.138058027277602	г.Лакинск, Владимирская область, Собинский район, Кирова, 2		0101000020E61000007172BF4351324440C07971E2AB114C40
26684	1	3	\N	3510	34853	\N	56.140926	Владимирская область, город Владимир, Октябрьский район, Кирова, 15	Россия, Владимирская область, Владимир, улица Кирова, 15	0101000020E61000009CDF30D120334440FB93F8DC09124C40
26692	1	3	\N	3510	34822	\N	56.142721000000002	Владимирская область, город Владимир, Октябрьский район, Каманина, 16, школа №29	Россия, Владимирская область, Владимир, улица Каманина, 16	0101000020E6100000F0C16B9736364440E9B985AE44124C40
26626	1	3	1017	8829	34657	\N	56.426647000000003	город Суздаль, Лоунская, 7А		0101000020E610000052B9895A9A394440E0F76F5E9C364C40
26652	1	3	\N	3510	16408	\N	56.108491999999998	Владимирская область, город Владимир, Ленинский район, Институтский городок, 20	Россия, Владимирская область, Владимир, Юрьевец поселок, Институтский городок, 20	0101000020E61000004240BE840A24444056F0DB10E30D4C40
26651	1	3	\N	3510	16408	\N	56.104756999999999	Владимирская область, город Владимир, Ленинский район, Институтский городок, 7	Россия, Владимирская область, Владимир, Юрьевец поселок, Институтский городок, 7	0101000020E6100000B18BA2073E244440778368AD680D4C40
26661	1	3	\N	3510	74924	\N	56.104756999999999	г.Владимир, микрорайон Юрьевец, Институтский городок, д.7, школа № 44		0101000020E6100000B18BA2073E244440778368AD680D4C40
26710	1	3	\N	3510	67609	\N	56.157497679978299	г. Владимир, школа № 13, ул. Жуковского, д.№ 14		0101000020E6100000E107E753C73A4440BB97FBE428144C40
26709	1	3	\N	3510	67609	\N	56.134450000000001	г. Владимир, школа № 13, ул. Жуковского, д.№ 14 .		0101000020E61000007958A835CD3544403E7958A835114C40
26717	1	3	\N	3510	67548	\N	56.134450000000001	г. Владимир, школа № 28, ул. Добросельская, д. № 205а		0101000020E61000007958A835CD3544403E7958A835114C40
26715	1	3	\N	3510	67548	\N	56.164334800492497	г. Владимир, школа № 36, ул. Добросельская, д. № 179а		0101000020E61000003352EFA99C3C4440494BE5ED08154C40
26643	1	3	\N	3510	34658	\N	56.111890000000002	г.Владимир, школа № 43, ул.Диктора Левитана, д.37-а	Россия, Владимирская область, Владимир, улица Диктора Левитана, 37а	0101000020E6100000C0ED0912DB2F4440EE5F5969520E4C40
26659	1	3	\N	3510	34833	\N	56.111890000000002	г.Владимир, ул.Диктора Левитана, д.37-а, школа № 43	Россия, Владимирская область, Владимир, улица Диктора Левитана, 37а	0101000020E6100000C0ED0912DB2F4440EE5F5969520E4C40
26645	1	3	\N	3510	34833	\N	56.117828000000003	Владимирская область, город Владимир, Ленинский район, Диктора Левитана, 4	Россия, Владимирская область, Владимир, улица Диктора Левитана, 4	0101000020E6100000ACCABE2B822F4440CC46E7FC140F4C40
26668	1	3	\N	3510	34861	\N	56.126950000000001	г.Владимир, ул.Дворянская, д.1, школа № 1		0101000020E61000003F3A75E5B3324440151DC9E53F104C40
26648	1	3	\N	3510	34861	\N	56.126950000000001	Владимирская область, город Владимир, Ленинский район, Дворянская, 1	Россия, Владимирская область, Владимир, Дворянская улица, 1	0101000020E61000003F3A75E5B3324440151DC9E53F104C40
26647	1	3	\N	3510	34861	\N	56.125971999999997	г. Владимирж, ул. Дворянская, д. 27, Владимирский авиамеханический колледж		0101000020E6100000BA6B09F9A0314440191BBAD91F104C40
26683	1	3	\N	3510	34821	\N	56.143383	Владимирская область, город Владимир, Октябрьский район, Горького, 54		0101000020E6100000E4486760E4314440B4E6C75F5A124C40
26681	1	3	\N	3510	34821	\N	56.141717999999997	Владимирская область, город Владимир, Октябрьский район, Горького, 77б		0101000020E6100000384D9F1D7031444094A0BFD023124C40
26679	1	3	\N	3510	34821	\N	56.148955000000001	Владимирская область, город Владимир, Октябрьский район, Горького, 97	Россия, Владимирская область, Владимир, улица Горького, 97	0101000020E6100000EFAB72A1F22F4440B0C91AF510134C40
26677	1	3	\N	3510	34821	\N	56.136172830372999	Владимирская область, город Владимир, Октябрьский район, Горького, 07а	Россия, Владимирская область, Владимир, улица Горького	0101000020E6100000527FBDC28233444092CCEA1D6E114C40
26676	1	3	\N	3510	34821	\N	56.150103000000001	Владимирская область, город Владимир, Октябрьский район, Горького, 107а	Россия, Владимирская область, Владимир, улица Горького, 107а	0101000020E61000005D34643C4A2F444008043A9336134C40
26693	1	3	\N	3510	34820	\N	56.134841999999999	Владимирская область, город Владимир, Октябрьский район, Герцена, 35		0101000020E610000091EF52EA923544404910AE8042114C40
26695	1	3	\N	3510	34517	\N	56.135021281555296	г. Владимир, школа №14, ул.Герцена, 35, школа №14	Россия, Владимирская область, Владимир, улица Герцена	0101000020E6100000A7E9B303AE354440F9A23D5E48114C40
26664	1	3	\N	3510	34829	\N	56.111789999999999	г.Владимир, ул.Верхняя Дуброва, д.2-а, школа № 32,		0101000020E6100000C76471FF912B44408A027D224F0E4C40
26656	1	3	\N	3510	34829	\N	56.107121999999997	Владимирская область, город Владимир, Ленинский район, Верхняя Дуброва, 32б	Россия, Владимирская область, Владимир, улица Верхняя Дуброва, 32б	0101000020E6100000B6A1629CBF2B44404F57772CB60D4C40
26637	1	3	\N	3510	34829	\N	56.107121999999997	Владимирская область, город Владимир, Ленинский район, Верхняя Дуброва, 32-б		0101000020E6100000B6A1629CBF2B44404F57772CB60D4C40
26635	1	3	\N	3510	34829	\N	56.111789999999999	Владимирская область, город Владимир, Ленинский район, Верхняя Дуброва, 2а	Россия, Владимирская область, Владимир, улица Верхняя Дуброва, 2а	0101000020E6100000C76471FF912B44408A027D224F0E4C40
26636	1	3	\N	3510	34838	\N	56.110359000000003	Владимирская область, город Владимир, Ленинский район, Василисина, 22б		0101000020E61000008FC4CBD3B92C4440DEE8633E200E4C40
26694	1	3	\N	3510	34826	\N	56.129514761182698	Владимирская область, город Владимир, Октябрьский район, Большая Московская, 33	Россия, Владимирская область, Владимир, Большая Московская улица, 35с1	0101000020E6100000BB46CB811E344440B4AB90F293104C40
26725	1	3	\N	3510	67576	\N	56.1688004207764	г. Владимир, школа № 40, ул. Безыменского, д. № 14б		0101000020E6100000EDD632198E3944404BC8073D9B154C40
26724	1	3	\N	3510	67576	\N	56.1692792767142	г.  Владимир, школа № 40, ул. Безыменского, д. № 14б		0101000020E6100000F33D23111A39444026732CEFAA154C40
26723	1	3	\N	3510	67576	\N	56.168728591868501	г. Владимир, школа № 40, ул. Безыменского, д.№ 14б		0101000020E610000004FF5BC98E394440827170E998154C40
26669	1	3	\N	3510	34855	\N	56.129434000000003	Владимирская область, город Владимир, Октябрьский район, Балакирева, 41	Россия, Владимирская область, Владимир, улица Балакирева, 41	0101000020E61000004BC972124A2D4440C87E164B91104C40
26628	1	3	1017	8829	34798	\N	56.428108988476097	город Суздаль, Промышленная, 3	Россия, Владимирская область, Суздальский район, Суздаль	0101000020E610000011FE45D098394440C70F9546CC364C40
26663	1	3	\N	3510	34855	\N	56.129384000000002	Владимирская область, город Владимир, Ленинский район, Балакирева, 32	Россия, Владимирская область, Владимир, улица Балакирева, 32	0101000020E6100000B83D4162BB2D44401650A8A78F104C40
26632	1	3	\N	3510	34855	\N	56.123192000000003	Владимирская область, город Владимир, Ленинский район, Балакирева, 21	Россия, Владимирская область, Владимир, улица Балакирева, 21	0101000020E610000032E884D0412D44407E9065C1C40F4C40
26714	1	3	\N	3510	74913	\N	56.167866634451201	г. Владимир, детская школа искусств № 6, ул. Соколова-Соколенка, д. № 6г	Россия, Владимирская область, Владимир, улица Соколова-Соколенка	0101000020E61000007974232C2A3A4440F08975AA7C154C40
26337	1	3	\N	54129	34733	\N	56.392387999999997	г.Александров, ул.Советская, д.3,  муниципальное бюджетное учреждение культуры «Социально-культурный центр»		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26352	1	3	\N	54129	34463	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Маяковского, 50		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26348	1	3	\N	54129	34550	\N	56.397645625271799	Владимирская область, Александровский район, город Александров, Ленина, 24	Россия, Владимирская область, Александровский район, Александров	0101000020E61000001C261AA4E05B43404FB16A10E6324C40
26340	1	3	\N	54129	34772	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Королева, 6		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26560	1	3	1118	10146	35000	\N	56.499234999999999	город Юрьев - Польский, Перфильева, 69		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26557	1	3	1118	10146	34558	\N	56.499234999999999	город Юрьев-Польский, Набережная, 20		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26562	1	3	1118	10146	34976	\N	56.499234999999999	город Юрьев-Польский, Чехова, 15/Б		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26559	1	3	1118	10146	34600	\N	56.499234999999999	город Юрьев - Польский, Набережная, 80		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26561	1	3	1118	10146	35100	\N	56.499234999999999	город Юрьев - Польский, Железнодорожная, 23		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26553	1	3	1118	10146	34687	\N	56.499234999999999	город Юрьев-Польский, Горького, 5		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26558	1	3	1118	10146	34741	\N	56.499234999999999	город Юрьев - Польский, Артиллерийская, 30		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26555	1	3	1118	10146	34555	\N	56.499234999999999	город Юрьев-Польский, Авангардский переулок, 31		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26552	1	3	1118	10146	34785	\N	56.499234999999999	город Юрьев-Польский, 1 Мая, 74		0101000020E6100000C0B4A84F72D743406002B7EEE63F4C40
26569	1	3	1118	47757	35001	\N	56.584634999999999	с. Энтузиаст, Жевлаковича, 9/А		0101000020E61000002AAC545051E34340698CD651D54A4C40
26583	1	3	1118	11622	\N	\N	56.428049999999999	с. Шихобалово, 79		0101000020E61000004D4D8237A40B4440C286A757CA364C40
26574	1	3	1118	11214	\N	\N	56.523021999999997	с. Шипилово, 24		0101000020E61000000D51853FC3F34340548B8862F2424C40
26584	1	3	1118	48036	35072	\N	56.292748000000003	с. Чеково, VII улица, 4		0101000020E610000099F38C7DC9FA434016FC36C478254C40
26572	1	3	1118	54166	35020	\N	56.444858823275098	с. Сосновый Бор, Школьная, 6	Россия, Владимирская область, Юрьев-Польский район, поселок Сосновый Бор	0101000020E61000002E5393E00DD54340672AC423F1384C40
26563	1	3	1118	10708	34745	\N	56.682239000000003	с. Сима, Советская, 47		0101000020E6100000B519A721AAC643402387889B53574C40
26568	1	3	1118	10708	35055	\N	56.682239000000003	с. Сима, Богомолова, 41		0101000020E6100000B519A721AAC643402387889B53574C40
26582	1	3	1118	11606	\N	\N	56.365059000000002	с. Семьинское, 13/А		0101000020E6100000D384ED2763E24340240ED940BA2E4C40
26570	1	3	1118	47772	35172	\N	56.688073000000003	с. Подолец, Школьная, 7		0101000020E6100000ED629AE95EE743405C21ACC612584C40
26606	1	3	1118	48457	34578	\N	56.281806000000003	село Павловское, Школьная, 16		0101000020E6100000D5963AC8EBFF434086E8103812244C40
26577	1	3	1118	47902	\N	\N	56.549973000000001	с. Ополье, 41		0101000020E61000005F7F129F3BD143406D57E88365464C40
26585	1	3	1118	11730	34507	\N	56.366723999999998	с. Небылое, Первомайская, 2		0101000020E6100000CB129D6516FF43404354E1CFF02E4C40
26564	1	3	1118	10768	35087	\N	56.657300999999997	с. Матвейщево, Школьный переулок, 3		0101000020E6100000E59D4319AABC434065506D7022544C40
26566	1	3	1118	54170	\N	\N	56.766292	м. Лучки, 45	Россия, Владимирская область, Юрьев-Польский район, поселок Лучки	0101000020E61000000D6D003620C44340DD9733DB15624C40
26573	1	3	1118	11167	\N	\N	56.480102000000002	с. Кузьмадино, Здание детского сада № 13	Россия, Владимирская область, Юрьев-Польский район, поселок Кузьмадино	0101000020E6100000FB04508C2CD74340425F7AFB733D4C40
26588	1	3	1118	48123	\N	\N	56.330036	с. Красное Заречье, 78/А		0101000020E6100000CEA5B8AAECEF43405740A19E3E2A4C40
26620	1	3	1118	40411	35363	\N	56.526451999999999	село Красное, Центральная, 58		0101000020E6100000224F92AE99D64340F77475C762434C40
26579	1	3	1118	47949	34871	\N	56.509915999999997	с. Косинское, Школьная, 1/А		0101000020E610000072874D64E6C8434083DA6FED44414C40
26591	1	3	1118	48177	34930	\N	56.622810999999999	село Добрынское, Огурцова, 27		0101000020E6100000910E0F61FCC44340664B5645B84F4C40
26576	1	3	1118	47880	35460	\N	56.598354	с. Городище, Школьная, 6		0101000020E610000091F12895F0DA434024B726DD964C4C40
26580	1	3	1118	47955	35209	\N	56.582656999999998	с. Горки, Механическая, 11		0101000020E6100000C16ED8B628B143408AE42B81944A4C40
26567	1	3	1118	10893	\N	\N	56.634445999999997	д. Веска, 2		0101000020E610000037C1374D9FD34340FC89CA8635514C40
26621	1	3	1017	13424	35060	\N	56.370413999999997	село Черниж, Центральная, 44		0101000020E6100000639AE95E2737444082FDD7B9692F4C40
26605	1	3	1017	48444	35026	\N	56.343243999999999	село Цибеево, Центральная, 2		0101000020E61000001D740987DE1844402C465D6BEF2B4C40
26587	1	3	1017	48097	\N	\N	56.329652000000003	с. Федоровское, 104		0101000020E610000024F25D4A5D2E4440CF876709322A4C40
26623	1	3	1017	13494	35027	\N	56.342775000000003	село Туртино, Совхозная, 1		0101000020E6100000F1457BBC902A444076711B0DE02B4C40
26622	1	3	1017	12619	34926	\N	56.556055999999998	село Торчино, ул.Центральная, 47, школа		0101000020E61000006FF3C649614644404E5FCFD72C474C40
26612	1	3	1017	48561	35134	\N	56.195073999999998	село Суходол, Александрова, 33		0101000020E61000005A626534F23744406326512FF8184C40
26595	1	3	1017	12222	35173	\N	56.190652	село Суромна, Школьная, 11А		0101000020E6100000C37E4FAC533F44406075E44867184C40
26624	1	3	1017	8829	34894	\N	56.426647000000003	город Суздаль, Колхозная, 1		0101000020E610000052B9895A9A394440E0F76F5E9C364C40
26627	1	3	1017	8829	34743	\N	56.426647000000003	город Суздаль, Красная площадь, 5		0101000020E610000052B9895A9A394440E0F76F5E9C364C40
14662	1	3	1017	8829	34508	\N	56.426647000000003	город Суздаль, Гоголя, 37		0101000020E610000052B9895A9A394440E0F76F5E9C364C40
26604	1	3	1017	48425	34949	\N	56.284483999999999	село Старый Двор, Красная, 3		0101000020E6100000D1CE6916681744401D1EC2F869244C40
26607	1	3	1017	12796	35058	\N	56.362591000000002	село Спасское-Городище, Школьная, 24Б		0101000020E6100000DBA6785C544344407769C361692E4C40
26565	1	3	1017	47678	35059	\N	56.133713	с. Спасское, Центральная, 29/А		0101000020E61000007C9A9317992244406806F1811D114C40
26539	1	3	1017	47168	\N	\N	56.252422000000003	поселок Сокол, здание школы	Россия, Владимирская область, Суздальский район, поселок Сокол	0101000020E610000060ADDA35214744403D65355D4F204C40
26603	1	3	1017	12617	34906	\N	56.19258	поселок Содышка, Прибольничная, 10		0101000020E6100000DBF7A8BF5E3144408DEE2076A6184C40
26611	1	3	1017	48534	34693	\N	56.221594000000003	поселок Садовый, Центральная, 1А		0101000020E6100000F6D03E56F0334440B37E33315D1C4C40
26593	1	3	1017	48213	35489	\N	56.290719000000003	деревня Раменье, Западная, 1Б		0101000020E6100000CCB22781CD4B4440B5A9BA4736254C40
26608	1	3	1017	48490	34887	\N	56.268501000000001	село Порецкое, Молодежная, 6		0101000020E6100000B8CA13083B434440BEF8A23D5E224C40
26596	1	3	1017	12277	35054	\N	56.230097000000001	с. Ославское, Центральная, д.24А		0101000020E6100000952A51F69644444030F488D1731D4C40
26617	1	3	1017	13214	35073	\N	56.486902000000001	село Омутское, Молодежная, 3		0101000020E610000050C763062A374440B22D03CE523E4C40
26618	1	3	1017	54154	34852	\N	56.212931152198799	поселок Новый, Центральная, 3		0101000020E610000058569A9482424440FCA6B052411B4C40
26594	1	3	1017	54154	34836	\N	56.212010868768701	село Новое, Молодежная, 4А	Россия, Владимирская область, Суздальский район, поселок Новое Село	0101000020E61000005BD07B630842444035B22B2D231B4C40
26598	1	3	1017	48311	34924	\N	56.223841999999998	село Новоалександрово, Школьная, 8		0101000020E6100000328FFCC1C021444051BCCADAA61C4C40
26610	1	3	1017	12917	34931	\N	56.309499000000002	село Мордыш, Центральная, 13		0101000020E61000005B9544F6414E44408692C9A99D274C40
26615	1	3	1017	13135	35047	\N	56.413463	село Ляховицы, Центральная, 37		0101000020E6100000C231CB9E04504440938D075BEC344C40
26592	1	3	1017	12063	35155	\N	56.207557999999999	село Лемешки, Вокзальная, 1		0101000020E6100000780C8FFD2C4A4440F702B342911A4C40
26599	1	3	1017	48333	35056	\N	56.259847999999998	село Кутуково, Садовая, 9		0101000020E6100000B857E6ADBA1C44402BF702B342214C40
26578	1	3	1017	47921	\N	\N	56.433829000000003	с. Красное, 72		0101000020E6100000F69672BED83F444038876BB587374C40
26614	1	3	1017	48595	34654	\N	56.501570000000001	поселок Красногвардейский, Октябрьская, 1		0101000020E610000021B1DD3D40454440CE531D7233404C40
26597	1	3	1017	48305	35215	\N	56.274603999999997	село Клементьево, Новая, 1		0101000020E61000006BEF535568104440E6AC4F3926234C40
26602	1	3	1017	48391	35036	\N	56.202601000000001	деревня Зелени, Полевая, 1, кв.2		0101000020E6100000BBB4E1B03428444086915ED4EE194C40
26815	1	3	1017	48046	35175	\N	56.467350000000003	деревня Гридино, Молодежная, 13		0101000020E6100000462234828D4D44408FE4F21FD23B4C40
26619	1	3	1017	48697	35048	\N	56.409185000000001	село Глебовское, Западная, 1		0101000020E61000003A5B40683D404440C381902C60344C40
26613	1	3	1017	48567	35002	\N	56.394421000000001	село Гавриловское, Школьная, 32		0101000020E610000012A5BDC11724444085ED27637C324C40
26616	1	3	1017	13199	34950	\N	56.487110000000001	село Весь, Набережная, 5		0101000020E610000038D906EE402D4440FCC6D79E593E4C40
26609	1	3	1017	48499	34907	\N	56.269855999999997	село Борисовское, Большая Дорога, 47		0101000020E610000052BAF42F493D44408F5033A48A224C40
26601	1	3	1017	48370	35078	\N	56.157983506850002	село Богослово, Совхозная, 3	Россия, Владимирская область, Суздальский район, поселок Богослово	0101000020E6100000F816D68D7729444048A5D8D138144C40
26589	1	3	1017	11927	34444	\N	56.195410000000003	поселок Боголюбово, Ленина, 26		0101000020E6100000FEB5BC72BD434440DBA7E33103194C40
26590	1	3	1017	11927	34511	\N	56.195410000000003	поселок Боголюбово, Ленина, 48		0101000020E6100000FEB5BC72BD434440DBA7E33103194C40
26824	1	3	1045	23432	34934	\N	56.069118000000003	село Чамерево, Судогодская, 14		0101000020E6100000CFA0A17F8265444050C8CEDBD8084C40
26816	1	3	1045	48081	35161	\N	56.020350999999998	поселок Улыбышево, Школьная, 4		0101000020E61000006405BF0D312A44406FB88FDC9A024C40
26806	1	3	1045	9169	34965	\N	55.927306000000002	поселок Тюрмеровка, ул.Муромская, здание сельского клуба		0101000020E610000059FB3BDBA38F44403AB187F6B1F64B40
26803	1	3	1045	22285	34568	\N	55.957877000000003	город Судогда, Чапаева, 31		0101000020E610000062C092AB586E4440994BAAB69BFA4B40
26802	1	3	1045	22285	34566	\N	55.957877000000003	город Судогда, Химиков, 2		0101000020E610000062C092AB586E4440994BAAB69BFA4B40
26799	1	3	1045	22285	34703	\N	55.957877000000003	город Судогда, Ошмарина, 1		0101000020E610000062C092AB586E4440994BAAB69BFA4B40
26798	1	3	1045	22285	34793	\N	55.957877000000003	город Судогда, Ленина, 44		0101000020E610000062C092AB586E4440994BAAB69BFA4B40
26801	1	3	1045	22285	34794	\N	55.957877000000003	город Судогда, Коммунистическая, 1		0101000020E610000062C092AB586E4440994BAAB69BFA4B40
26800	1	3	1045	22285	34748	\N	55.957877000000003	город Судогда, Халтурина, 66		0101000020E610000062C092AB586E4440994BAAB69BFA4B40
26977	1	3	1045	46719	35012	\N	56.052672999999999	с. Станки, Рябиновая, д. 4, Станковская основная общеобразовательная школа		0101000020E61000003B014D840D574440EC3026FDBD064C40
26821	1	3	1045	23295	35130	\N	55.973883999999998	деревня Сойма, Лесная, 33		0101000020E61000004DBD6E11185D4440800C1D3BA8FC4B40
26833	1	3	1045	23829	35162	\N	55.909165999999999	поселок Передел, Северная, 22		0101000020E6100000BED87BF1457F44404C512E8D5FF44B40
26448	1	3	1045	49580	35367	\N	55.894086000000001	д. Павловка, Вторая, 9		0101000020E6100000A67B9DD497AF4440DEE7F86871F24B40
26822	1	3	1045	54172	35183	\N	56.001331686810303	деревня Овцыно, Центральная, 13	Россия, Владимирская область, Судогодский район, поселок Овцино	0101000020E6100000CF842689256344401938A0A52B004C40
26819	1	3	1045	48135	\N	\N	55.839249000000002	деревня Овсянниково, 1	Россия, Владимирская область, Судогодский район, поселок Овсянниково	0101000020E6100000CFF4126399744440B119E0826CEB4B40
26812	1	3	1045	54171	35182	\N	56.0346217417856	деревня Ново-Петрово, Школьная, 2	Россия, Владимирская область, Судогодский район, поселок Новопетрово	0101000020E610000069519FE40E5744406EDC627E6E044C40
26832	1	3	1045	23812	34606	\N	55.929828000000001	поселок Муромцево, Шкурина, 17		0101000020E610000093FE5E0A0F744440DA73999A04F74B40
26831	1	3	1045	23812	34610	\N	55.929828000000001	поселок Муромцево, Школьная, 15		0101000020E610000093FE5E0A0F744440DA73999A04F74B40
26826	1	3	1045	23541	34476	\N	55.802309999999999	село Мошок, Заводская, 4		0101000020E61000008FC2F5285C9D44407BA01518B2E64B40
26828	1	3	1045	48320	35177	\N	55.861393	поселок Красный Куст, Советская, 24		0101000020E6100000DA37F7578FA344406D00362042EE4B40
26807	1	3	1045	47915	34908	\N	56.017045000000003	поселок Красный Богатырь, Парковая, 22		0101000020E6100000B806B64AB0904440B9C7D2872E024C40
26827	1	3	1045	23559	35176	\N	55.827641	деревня Кондряево, Колхозная, 19		0101000020E610000087A4164A2687444014EAE923F0E94B40
26809	1	3	1045	47953	35128	\N	56.063454	село Картмазово, Полевая, 1А		0101000020E6100000A06EA0C03B8D44407366BB421F084C40
26753	1	3	1045	46836	35273	\N	55.915841	д. Ильино, Школьная, 5		0101000020E610000090A4A487A14D444000AB23473AF54B40
26834	1	3	1045	23912	\N	\N	55.850757000000002	деревня Дворишнево, 18А		0101000020E6100000F390291F82744440EAEBF99AE5EC4B40
26829	1	3	1045	23660	35083	\N	55.812823000000002	деревня Гонобилово, Центральная, 29		0101000020E6100000B0E3BF4010AA4440E33785950AE84B40
26818	1	3	1045	46523	34857	\N	55.951467000000001	поселок Головино, ул. Юбилейная, д. 1а, здание Дома культуры		0101000020E6100000AEEFC34142384440931CB0ABC9F94B40
26817	1	3	1045	46523	34767	\N	55.951467000000001	поселок Головино, Советская, 54А		0101000020E6100000AEEFC34142384440931CB0ABC9F94B40
26813	1	3	1045	48020	34722	\N	56.066932000000001	"деревня Вяткино, Докучаева, здание МОУ ""Вяткинская средняя общеобраз. школа"""		0101000020E610000093E1783E033E444027874F3A91084C40
26836	1	3	1045	24002	\N	\N	55.850656000000001	"деревня Вольная Артемовка, здание МОУ ""В.Артемовская основная общеобразоват. школа"""	Россия, Владимирская область, Судогодский район, поселок Вольная Артемовка	0101000020E6100000514A0856D5634440B612BA4BE2EC4B40
26830	1	3	1045	23715	\N	\N	55.892097	деревня Вежки, 6		0101000020E6100000C443183F8DA944400BEE073C30F24B40
26835	1	3	1045	23922	34952	\N	55.937845000000003	поселок Бег, Спортивная, 21		0101000020E610000028D53E1D8F6B4440CBDB114E0BF84B40
26814	1	3	1045	48043	34979	\N	56.043909999999997	деревня Бараки, Красноармейская, 1		0101000020E6100000D447E00F3F454440D2FBC6D79E054C40
26805	1	3	1045	22522	34547	\N	55.944192999999999	поселок Андреево, Первомайская, 15А		0101000020E6100000107A36AB3E9344405A0EF450DBF84B40
26804	1	3	1045	22522	34518	\N	55.944192999999999	поселок Андреево, Красная Слобода, 15А		0101000020E6100000107A36AB3E9344405A0EF450DBF84B40
26536	1	3	858	9372	67331	\N	56.190451000000003	с.Черкутино, Собинский район, Владимирская область, Первомайская, 30		0101000020E6100000F67AF7C77BE14340C93EC8B260184C40
26538	1	3	858	9472	74908	\N	56.278497999999999	с.Фетинино, Собинский район, Владимирская область, Суворова, 26		0101000020E61000007445292158ED43402E008DD2A5234C40
27089	1	3	858	48849	35065	\N	56.078166000000003	деревня Степаньково, Школьная, 2А		0101000020E6100000336FD575A8F043405FD4EE57010A4C40
26531	1	3	858	9085	34688	\N	56.130121000000003	поселок Ставрово, Собинский район, Владимирская область, Школьная, 6		0101000020E61000000F0F61FC34024440ECC20FCEA7104C40
26529	1	3	858	9085	34686	\N	56.130121000000003	поселок Ставрово, Собинский район, Владимирская область, Советская, 22		0101000020E61000000F0F61FC34024440ECC20FCEA7104C40
26473	1	3	858	6413	34705	\N	55.9959814537239	г.Собинка, Владимирская область, Собинский район, Ленина, 32	Россия, Владимирская область, Собинский район, Собинка	0101000020E6100000D2E4620CAC034440FC372F4E7CFF4B40
26545	1	3	858	6413	34652	\N	55.991314000000003	г.Собинка, Владимирская область, Собинский район, Красная звезда, 16		0101000020E61000003755F7C8E602444092088D60E3FE4B40
26541	1	3	858	6413	34786	\N	55.991314000000003	г.Собинка, Владимирская область, Собинский район, Димитрова, 8		0101000020E61000003755F7C8E602444092088D60E3FE4B40
26534	1	3	858	9282	74896	\N	56.193762	с.Рождествено, Собинский район, Владимирская область, Порошина, 10		0101000020E6100000D89C836742F14340919A7631CD184C40
26731	1	3	858	46392	35136	\N	55.997743999999997	д. Никулино, Зеленая, 8		0101000020E6100000F2EB87D860154440DEE34C13B6FF4B40
26549	1	3	858	9853	34556	\N	56.018368000000002	г. Лакинск, Центральная площадь, д.6, городской Дом культуры		0101000020E6100000FE43FAEDEBFA43407FA5F3E159024C40
26546	1	3	858	9853	34779	\N	56.018368000000002	г.Лакинск, Владимирская область, Собинский район, Карла Маркса, 5		0101000020E6100000FE43FAEDEBFA43407FA5F3E159024C40
26526	1	3	858	8922	67328	\N	56.093003000000003	д.Курилово, Собинский район, Владимирская область, Юбилейная, 40		0101000020E6100000A794D74AE8FC434007B7B585E70B4C40
26519	1	3	858	8618	35122	\N	55.900934999999997	д.Копнино, Собинский район, Владимирская область, Молодежная, 18		0101000020E610000098158A743FF143402F698CD651F34B40
26523	1	3	858	8741	34925	\N	56.078874999999996	Владимирская область, Собинский район, п.Колокша, ул.Советская, д.20 а, (здание спортзала Устьевской школы)		0101000020E6100000E3C798BB961244406ABC7493180A4C40
26537	1	3	858	9412	35133	\N	56.238411999999997	с.Кишлеево, Собинский район, Владимирская область, Строителей, 19а		0101000020E6100000DB4FC6F830034440AA7CCF48841E4C40
26520	1	3	858	8648	67318	\N	55.931800000000003	с.Заречное, Собинский район, Владимирская область, Парковая, 14		0101000020E61000007B116DC7D4F54340D734EF3845F74B40
26535	1	3	858	9338	74909	\N	56.235039999999998	с.Ельтесуново, Собинский район, Владимирская область, Первомайская, 4		0101000020E6100000B5334C6DA9F143403CA06CCA151E4C40
26738	1	3	858	46553	67324	\N	56.031351999999998	д. Демидово, Зеленая, 46		0101000020E6100000CAC342AD690244400455A35703044C40
26528	1	3	858	9030	74902	\N	56.129268000000003	д.Глухово, Собинский район, Владимирская область, Новая, 7		0101000020E6100000459BE3DC26EC4340AD3594DA8B104C40
26518	1	3	858	8561	74920	\N	55.995331999999998	д.Вышманово, Собинский район, Владимирская область, Сысоевская, 2		0101000020E61000005BED612F141A4440C554FA0967FF4B40
26533	1	3	858	9253	35344	\N	56.171211999999997	с.Волосово, Собинский район, Владимирская область, Мичуринская, 9а		0101000020E61000003CD862B7CF14444064575A46EA154C40
26527	1	3	858	8998	67334	\N	56.041384999999998	д.Васильевка, Собинский район, Владимирская область, Механизаторов, 19		0101000020E61000009B728577B9FC4340C1C58A1A4C054C40
26516	1	3	858	8485	35011	\N	55.871738000000001	с.Березники Собинский район, Владимирская область, ул.Владимирская, 1а		0101000020E6100000E78EFE976B0D444019575C1C95EF4B40
26525	1	3	858	8910	34995	\N	56.102277000000001	с.Бабаево, Собинский район, Владимирская область, Полевая, 10а		0101000020E610000087342A70B20944400611A969170D4C40
26517	1	3	858	8540	67325	\N	55.945624000000002	п.Асерхово Собинский район, Владимирская область, Лесной пр-т, 3а		0101000020E6100000ACFD9DEDD11F444007280D350AF94B40
27122	1	3	707	5906	35046	\N	55.933639999999997	Владимирская область, Селивановский район, д.Чертково, Советская, 47-а		0101000020E610000013F06B2409024540641EF98381F74B40
27107	1	3	707	5082	35169	\N	55.747743	д.Переложниково, ул.Свободы, д.17, МОУ детский сад №19		0101000020E61000006D567DAEB6CE44400E68E90AB6DF4B40
27115	1	3	707	5506	35115	\N	55.675336000000001	Владимирская область, Селивановский район, п.Первомайский, Школьная, 9		0101000020E61000008C4AEA0434AF4440DEE7F86871D64B40
27118	1	3	707	5683	34724	\N	55.976896000000004	Владимирская область, Селивановский район, п.Новый Быт, Молодежная, 1		0101000020E61000000762D9CC21CF4440EFCB99ED0AFD4B40
27105	1	3	707	5013	34641	\N	55.803933999999998	Владимирская область, Селивановский район, п.Новлянка, Совхозная, д. 16		0101000020E61000008F6FEF1AF4DD44403C122F4FE7E64B40
27106	1	3	707	5013	34940	\N	55.803933999999998	Владимирская область, Селивановский район, д.Новлянка, Совхозная, 16		0101000020E61000008F6FEF1AF4DD44403C122F4FE7E64B40
26760	1	3	707	46994	35378	\N	55.738906	д. Неклюдово, Школьная, 2		0101000020E6100000B6BDDD921CC64440BA68C87894DE4B40
27121	1	3	707	5813	35041	\N	55.944526000000003	Владимирская область, Селивановский район, д.Надеждино, Школьная, 7		0101000020E6100000DB15FA6019F34440611C5C3AE6F84B40
27108	1	3	707	5152	34969	\N	55.725529000000002	Владимирская область, Селивановский район, с.Малышево, Ленина, 2		0101000020E610000005FBAF73D3C4444059A65F22DEDC4B40
27110	1	3	707	5269	34886	\N	55.79851	Владимирская область, Селивановский район, п.Красная Ушна, Заводская, 10		0101000020E61000005EA10F96B1C74440B5C35F9335E64B40
27125	1	3	707	5925	34538	\N	55.877223000000001	Владимирская область, Селивановский район, поселок Красная Горбатка, Красноармейская, 21		0101000020E610000097C5C4E6E3E044404626E0D748F04B40
27127	1	3	707	5925	34504	\N	55.877223000000001	Владимирская область, Селивановский район, поселок Красная Горбатка, Школьная, 41		0101000020E610000097C5C4E6E3E044404626E0D748F04B40
27124	1	3	707	5925	34776	\N	55.864035798665299	Владимирская область, Селивановский район, поселок Красная Горбатка, Пролетарская, 4	Россия, Владимирская область, Селивановский район, поселок Красная Горбатка	0101000020E610000029CDE67118E2444088484DBB98EE4B40
27123	1	3	707	5925	34776	\N	55.877223000000001	Владимирская область, Селивановский район, поселок Красная Горбатка, Пролетарская, 3		0101000020E610000097C5C4E6E3E044404626E0D748F04B40
27126	1	3	707	5925	34541	\N	55.877223000000001	Владимирская область, Селивановский район, поселок Красная Горбатка, Механизаторов, 24		0101000020E610000097C5C4E6E3E044404626E0D748F04B40
27114	1	3	707	5464	35154	\N	55.705153000000003	Владимирская область, Селивановский район, д.Кочергино, Центральная, 68		0101000020E6100000DE3B6A4C88B3444091D6187442DA4B40
27109	1	3	707	5167	\N	\N	55.803660999999998	Владимирская область, Селивановский район, п.Костенец, 29	Россия, Владимирская область, Селивановский район, поселок Костенец	0101000020E61000007D3D5FB35CB644400B09185DDEE64B40
27117	1	3	707	5612	35040	\N	55.926034999999999	Владимирская область, Селивановский район, д.Копнино, Молодежная, 12		0101000020E61000002D25CB4928CF4440C6F99B5088F64B40
27119	1	3	707	5731	\N	\N	55.987931000000003	Владимирская область, Селивановский район, с.Ильинское, 2		0101000020E610000036E675C421DB444030DAE38574FE4B40
27116	1	3	707	54167	35110	\N	55.634838848481898	Владимирская область, Селивановский район, д.Ивановская, Центральная, 96	Россия, Владимирская область, Селивановский район, поселок Ивановское	0101000020E6100000651D8EAED2AB4440D89C836742D14B40
27111	1	3	707	5272	34888	\N	55.697087000000003	Владимирская область, Селивановский район, с. Драчево, Кирпичная, 2		0101000020E610000072FC5069C4D04440BFBB95253AD94B40
27113	1	3	707	5389	34917	\N	55.688578	Владимирская область, Селивановский район, д.Губино, Школьная, 1		0101000020E61000003672DD94F2D644405F5FEB5223D84B40
27104	1	3	707	4919	34937	\N	55.838971000000001	Владимирская область, Селивановский район, д.Высоково, Зеленая, 1		0101000020E61000009B38B9DFA1E244406EA5D76663EB4B40
27120	1	3	707	5780	\N	\N	55.918821999999999	Владимирская область, Селивановский район, д.Вощиха, 34		0101000020E6100000E5982CEE3FE64440336C94F59BF54B40
26729	1	3	1338	54143	34677	\N	56.003100000000003	Владимирская область, ЗАТО город Радужный, 1 квартал, 40		0101000020E610000035971B0C752A44400E4FAF9465004C40
26480	1	3	751	60377	\N	\N	55.939536667374298	Владимирская область, Петушинский район, Пекшинское сельское поселение, п. Сушнево-1, Здание детского сада, б/н	Россия, Владимирская область	0101000020E6100000EAEC647094DE4340E43098BF42F84B40
26476	1	3	751	6554	34904	\N	55.965989999999998	Владимирская область, Петушинский район, Пекшинское сельское поселение, п. Труд, Профсоюзная, 3		0101000020E6100000FF06EDD5C7CF4340AB21718FA5FB4B40
26466	1	3	751	6054	34958	\N	55.941313999999998	Владимирская область, Петушинский район, Петушинское сельское поселение, д. Старые Петушки, Шоссейная, 156А		0101000020E610000044FD2E6CCDBC43402BA226FA7CF84B40
26468	1	3	751	6167	35127	\N	55.903866999999998	Владимирская область, Петушинский район, Петушинское сельское поселение, д. Старые Омутищи, Артельная, 4А		0101000020E6100000FBAC32535AA943408177F2E9B1F34B40
26506	1	3	751	7998	35092	\N	55.892798999999997	Владимирская область, Петушинский район, Нагорное сельское поселение, д. Перепечино, ул.Вокзальная, д.1, (Магазин продукты)		0101000020E61000003C139A24969A43406473D53C47F24B40
26511	1	3	751	8249	34998	\N	56.005172999999999	Владимирская область, Петушинский район, Нагорное сельское поселение, п. Санинского ДОКа, Клубная, 4		0101000020E61000002E3718EAB07443403EE94482A9004C40
26495	1	3	751	7350	34495	\N	55.918256999999997	Владимирская область, Петушинский район, город Покров, Советская, 40		0101000020E61000002A7288B8399743405A29047289F54B40
26497	1	3	751	7350	34553	\N	55.918256999999997	Владимирская область, Петушинский район, город Покров, Советская, 21А		0101000020E61000002A7288B8399743405A29047289F54B40
26492	1	3	751	7350	34597	\N	55.918256999999997	Владимирская область, Петушинский район, город Покров, Ленина, 107		0101000020E61000002A7288B8399743405A29047289F54B40
26493	1	3	751	7350	34554	\N	55.918256999999997	Владимирская область, Петушинский район, город Покров, Больничный проезд, 2		0101000020E61000002A7288B8399743405A29047289F54B40
26498	1	3	751	7350	34497	\N	55.918256999999997	Владимирская область, Петушинский район, город Покров, 3 Интернационала, 52		0101000020E61000002A7288B8399743405A29047289F54B40
26496	1	3	751	7350	34497	\N	55.918256999999997	Владимирская область, Петушинский район, город Покров, 3 Интернационала, 39		0101000020E61000002A7288B8399743405A29047289F54B40
26469	1	3	751	5290	\N	\N	55.926563999999999	Владимирская область, Петушинский район, Петушинское сельское поселение, п. Березка, Клуб, б/н	Россия, Владимирская область, Петушинский район, Петушки	0101000020E61000003BFE0B0401BE434052D32EA699F64B40
26461	1	3	751	5290	34872	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Пушкина, 2		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26462	1	3	751	5290	34883	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Покровка, 2		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26464	1	3	751	5290	35019	\N	55.924788999999997	Владимирская область, Петушинский район, г. Петушки, ул. Ленина, д.4 А		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26452	1	3	751	5290	34740	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Школьная, 2		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26460	1	3	751	5290	34596	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Чкалова, 12		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26455	1	3	751	5290	35167	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Профсоюзная, 6		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26459	1	3	751	5290	34551	\N	55.924788999999997	Владимирская область, Петушинский район, город Петушки, Московская, 22А		0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26454	1	3	751	5290	9728	\N	55.925610956055799	Владимирская область, Петушинский район, город Петушки, Кирова, 2		0101000020E61000008B89CDC7B5BB4340B0E8D66B7AF64B40
26514	1	3	751	5290	74918	\N	55.924788999999997	г. Петушки, ул. Вокзальная, д. 42 / Железнодорожный вокзал г. Петушки	Россия, Владимирская область, Петушинский район, Петушки	0101000020E6100000AD156D8E73BB4340AB59677C5FF64B40
26477	1	3	751	6652	34993	\N	55.962947	Владимирская область, Петушинский район, Пекшинское сельское поселение, д. Пекша, Центральная, 8		0101000020E61000008DF161F6B2D943400264E8D841FB4B40
26483	1	3	751	6908	35075	\N	56.063198	Владимирская область, Петушинский район, Пекшинское сельское поселение, д. Пахомово, Начальная школа, 50		0101000020E61000002A1E17D522DA434018963FDF16084C40
26510	1	3	751	8172	35108	\N	56.000008999999999	Владимирская область, Петушинский район, Нагорное сельское поселение, д. Панфилово, Верхняя, 4		0101000020E61000000FB56D18058B4340535A7F4B00004C40
26470	1	3	751	6245	34960	\N	55.934775000000002	Владимирская область, Петушинский район, Петушинское сельское поселение, д. Новое Аннино, Центральная, 14		0101000020E6100000F2D24D6210B24340280F0BB5A6F74B40
26811	1	3	751	60380	74930	\N	55.927534000000001	деревня Новая, Муромская, здание ФАП	Россия, Владимирская область, Петушинский район, поселок Новая	0101000020E610000090DB2F9FACCC4340CBF6216FB9F64B40
26479	1	3	751	6725	35099	\N	55.916092999999996	Владимирская область, Петушинский район, Пекшинское сельское поселение, п. Метенино, Центральная, 15		0101000020E6100000D5E76A2BF6DD4340198C118942F54B40
26508	1	3	751	8093	35076	\N	55.864556	Владимирская область, Петушинский район, Нагорное сельское поселение, с. Марково, Советская, 25		0101000020E6100000A9DE1AD82AA54340C1C760C5A9EE4B40
26475	1	3	751	6540	\N	\N	55.950453000000003	Владимирская область, Петушинский район, Пекшинское сельское поселение, д. Липна, Сельский Дом культуры, 127А		0101000020E6100000D13E56F0DBD043404BB1A371A8F94B40
26482	1	3	751	6839	35105	\N	56.026408000000004	Владимирская область, Петушинский район, Пекшинское сельское поселение, д. Ларионово, Совхозная, д. 2, СДК		0101000020E61000002EE411DC48D14340282D5C5661034C40
26472	1	3	751	6373	\N	\N	55.895125999999998	Владимирская область, Петушинский район, Петушинское сельское поселение, д. Крутово, Библиотека, 61		0101000020E6100000BA83D89942B743404FE61F7D93F24B40
26471	1	3	751	6318	34961	\N	55.986808000000003	Владимирская область, Петушинский район, Петушинское сельское поселение, д. Костино, Спортивная, 6		0101000020E6100000C9022670EBAC434031B77BB94FFE4B40
26491	1	3	751	54141	\N	\N	55.9286993213505	Владимирская область, Петушинский район, город Костерево-1, Средняя школа № 3, б/н		0101000020E61000000E2F88484DCF4340F969DC9BDFF64B40
26489	1	3	751	7053	34650	\N	55.933216999999999	Владимирская область, Петушинский район, город Костерево, Южная, 8		0101000020E6100000F75B3B5112D043401E8997A773F74B40
26486	1	3	751	7053	34459	\N	55.933216999999999	Владимирская область, Петушинский район, город Костерево, Писцова, 26		0101000020E6100000F75B3B5112D043401E8997A773F74B40
26488	1	3	751	7053	34649	\N	55.933216999999999	Владимирская область, Петушинский район, город Костерево, Пионерская, 7		0101000020E6100000F75B3B5112D043401E8997A773F74B40
26487	1	3	751	7053	34999	\N	55.933216999999999	Владимирская область, Петушинский район, город Костерево, Заречная, Контора лесозаготовительного участк		0101000020E6100000F75B3B5112D043401E8997A773F74B40
26490	1	3	751	7053	34784	\N	55.933216999999999	Владимирская область, Петушинский район, город Костерево, Горького, 2		0101000020E6100000F75B3B5112D043401E8997A773F74B40
26467	1	3	751	6087	35125	\N	55.960976000000002	Владимирская область, Петушинский район, Петушинское сельское поселение, д. Кибирево, им. Н.К. Погодина, 55А		0101000020E610000009FCE1E7BFB94340D61EF64201FB4B40
26485	1	3	751	6992	35086	\N	56.132148000000001	Владимирская область, Петушинский район, Пекшинское сельское поселение, д. Караваево, Каргополова, 28		0101000020E6100000D1402C9B39C24340AC1DC539EA104C40
26512	1	3	751	8290	34655	\N	55.870187999999999	Владимирская область, Петушинский район, поселок Городищи, Ленина, 4		0101000020E6100000DE1E84807C8D434092AF045262EF4B40
26513	1	3	751	8290	34738	\N	55.870187999999999	Владимирская область, Петушинский район, поселок Городищи, К. Соловьева, 4		0101000020E6100000DE1E84807C8D434092AF045262EF4B40
26509	1	3	751	8156	\N	\N	56.021377000000001	Владимирская область, Петушинский район, Нагорное сельское поселение, д. Головино, Сельский Дом культуры, 1		0101000020E61000002DCC423BA79743407CF1457BBC024C40
26504	1	3	751	7891	35077	\N	55.886155000000002	Владимирская область, Петушинский район, Нагорное сельское поселение, д. Глубоково, Школьная, 20		0101000020E6100000D4484BE5ED944340EC17EC866DF14B40
26474	1	3	751	6479	34933	\N	56.074393000000001	Владимирская область, Петушинский район, Петушинское сельское поселение, д. Воспушка, Круглова, 1А		0101000020E6100000487023658BB843409206B7B585094C40
26501	1	3	751	7711	34499	\N	55.952579999999998	Владимирская область, Петушинский район, поселок Вольгинский, Старовская, 23		0101000020E61000008A9125732C9D43406E693524EEF94B40
26500	1	3	751	7711	34598	\N	55.952579999999998	Владимирская область, Петушинский район, поселок Вольгинский, Старовская, 9		0101000020E61000008A9125732C9D43406E693524EEF94B40
26499	1	3	751	54169	\N	\N	55.9266909802515	Владимирская область, Петушинский район, город Покров, п. Введенский, Детский сад № 6, б/н		0101000020E610000029B16B7BBB8F4340AF3F89CF9DF64B40
26478	1	3	751	6689	35051	\N	55.958739000000001	Владимирская область, Петушинский район, Пекшинское сельское поселение, п. Болдино, Лесхозная, 6		0101000020E6100000EA060ABC93DF43402B33A5F5B7FA4B40
26484	1	3	751	6986	35157	\N	56.081271000000001	Владимирская область, Петушинский район, Пекшинское сельское поселение, д. Анкудиново, Арханинская, 48		0101000020E6100000CA1AF5108DCA43407E8E8F16670A4C40
27054	1	3	190	54146	34777	\N	55.597952249330099	Владимирская область, Муромский район, с. Якиманская Слобода, Клубная, 1	Россия, Владимирская область, Муромский район, поселок Якиманская Слобода	0101000020E6100000A4198BA6B3054540F549EEB089CC4B40
27088	1	3	190	48841	34985	\N	55.667945000000003	село Чаадаево, Муромская, 43А		0101000020E610000073A1F2AFE50345406C43C5387FD54B40
27080	1	3	190	48712	35111	\N	55.889628999999999	село Татарово, Мира, 40		0101000020E61000008DB7955E9B1145405E49F25CDFF14B40
27082	1	3	190	48737	35022	\N	55.775807999999998	деревня Талызино, Сельская, 6		0101000020E6100000BE326FD575F04440D2FC31AD4DE34B40
27098	1	3	190	49002	35143	\N	55.558008999999998	село Стригино, Первая, 54		0101000020E6100000D53C47E4BBF04440D4EFC2D66CC74B40
27101	1	3	190	4771	35034	\N	55.512602000000001	деревня Старое Ратово, Совхозная, 68А		0101000020E610000088A1D5C919F444409EEE3CF19CC14B40
27076	1	3	190	3469	35168	\N	55.649636999999998	деревня Саксино, Заречная, 35		0101000020E61000004DA25EF069F84440C2A2224E27D34B40
27084	1	3	190	48765	35152	\N	55.731450000000002	деревня Прудищи, Молодежная, 2		0101000020E61000002B14E97E4EF1444061545227A0DD4B40
27079	1	3	190	48694	35063	\N	55.77037	село Польцо, Юбилейная, 2		0101000020E6100000581B6327BC1C4540E6E8F17B9BE24B40
27096	1	3	190	4478	34918	\N	55.608612000000001	деревня Пестенькино, Центральная, 50		0101000020E61000003A1E335019EF444001FA7DFFE6CD4B40
27057	1	3	190	2360	\N	\N	55.540917999999998	Владимирская область, Муромский район, д. Орлово, Дом Культуры		0101000020E6100000613255302A034540ABE80FCD3CC54B40
27058	1	3	190	2441	35010	\N	55.557443999999997	Владимирская область, Муромский район, п. Муромский, Центральная, 37		0101000020E610000039D2191879034540FBAC32535AC74B40
27037	1	3	190	701	\N	\N	55.56053	Владимирская область, город Муром, Лакина, 2	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27068	1	3	190	701	34533	\N	55.56053	Владимирская область, город Муром, Пионеров, 2		0101000020E61000002237C30DF8044540A4367172BFC74B40
27033	1	3	190	701	34723	\N	55.56053	Владимирская область, город Муром, Орловская, 23/А		0101000020E61000002237C30DF8044540A4367172BFC74B40
27069	1	3	190	701	34766	\N	55.56053	Владимирская область, город Муром, Московская, 126		0101000020E61000002237C30DF8044540A4367172BFC74B40
27180	1	3	190	701	34719	\N	55.56053	Владимирская область, город Муром, Лакина, 65		0101000020E61000002237C30DF8044540A4367172BFC74B40
27064	1	3	190	701	34532	\N	55.56053	Владимирская область, город Муром, Куйбышева, 24/А		0101000020E61000002237C30DF8044540A4367172BFC74B40
27061	1	3	190	701	34715	\N	55.56053	Владимирская область, город Муром, Филатова, 8		0101000020E61000002237C30DF8044540A4367172BFC74B40
27060	1	3	190	701	34491	\N	55.56053	Владимирская область, город Муром, Привокзальная, 4	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27039	1	3	190	701	34579	\N	55.56053	Владимирская область, город Муром, Первомайская, 36		0101000020E61000002237C30DF8044540A4367172BFC74B40
27035	1	3	190	701	34576	\N	55.56053	Владимирская область, город Муром, Орловская, 16	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27032	1	3	190	701	34576	\N	55.56053	Владимирская область, город Муром, Орловская, 23		0101000020E61000002237C30DF8044540A4367172BFC74B40
27074	1	3	190	701	34540	\N	55.56053	Владимирская область, город Муром, Муромская, 15/А		0101000020E61000002237C30DF8044540A4367172BFC74B40
26571	1	3	5097	37527	35185	\N	55.832853999999998	с. Беляницино, Успенская, 26		0101000020E61000001A34F44F70A54240E02BBAF59AEA4B40
27072	1	3	190	701	34540	\N	55.56053	г. Муром, ул. Муромская, 15-а, МОУ СО Школа № 2		0101000020E61000002237C30DF8044540A4367172BFC74B40
27070	1	3	190	701	34530	\N	55.56053	г. Муром, ул.  Московская, 126, МОУ СО Школа № 1		0101000020E61000002237C30DF8044540A4367172BFC74B40
27063	1	3	190	701	34530	\N	55.56053	Владимирская область, город Муром, Московская, 110		0101000020E61000002237C30DF8044540A4367172BFC74B40
27062	1	3	190	701	34530	\N	55.56053	Владимирская область, город Муром, Московская, 91		0101000020E61000002237C30DF8044540A4367172BFC74B40
27043	1	3	190	701	34763	\N	55.56053	Владимирская область, город Муром, Мечникова, 20		0101000020E61000002237C30DF8044540A4367172BFC74B40
27049	1	3	190	701	34588	\N	55.56053	Владимирская область, город Муром, Льва Толстого, 23	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27046	1	3	190	701	34588	\N	55.56053	Владимирская область, город Муром, Льва Толстого, 40		0101000020E61000002237C30DF8044540A4367172BFC74B40
27183	1	3	190	701	34490	\N	55.56053	Владимирская область, город Муром, Ленинградская, 6	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27077	1	3	190	701	34490	\N	55.56053	г. Муром, ул. Ленинградская, 13, ДК «Вербовский»		0101000020E61000002237C30DF8044540A4367172BFC74B40
27050	1	3	190	701	34631	\N	55.56053	Владимирская область, город Муром, Ленина, 18		0101000020E61000002237C30DF8044540A4367172BFC74B40
27040	1	3	190	701	34631	\N	55.56053	Владимирская область, город Муром, Ленина, 95		0101000020E61000002237C30DF8044540A4367172BFC74B40
27042	1	3	190	701	34581	\N	55.56053	Владимирская область, город Муром, Лакина, 69		0101000020E61000002237C30DF8044540A4367172BFC74B40
27029	1	3	190	701	34531	\N	55.56053	Владимирская область, город Муром, Красина, 1		0101000020E61000002237C30DF8044540A4367172BFC74B40
27066	1	3	190	701	34623	\N	55.56053	г. Муром, ул. Кооперативная, 7-а, МОУ СО Школа № 8		0101000020E61000002237C30DF8044540A4367172BFC74B40
27065	1	3	190	701	34623	\N	55.56053	Владимирская область, город Муром, Кооперативная, 7/А		0101000020E61000002237C30DF8044540A4367172BFC74B40
27041	1	3	190	701	34617	\N	55.56053	Владимирская область, город Муром, Комсомольская, 60		0101000020E61000002237C30DF8044540A4367172BFC74B40
27053	1	3	190	701	34620	\N	55.56053	Владимирская область, город Муром, Колхозная, 15		0101000020E61000002237C30DF8044540A4367172BFC74B40
27051	1	3	190	701	34620	\N	55.56053	Владимирская область, город Муром, Колхозная, 35		0101000020E61000002237C30DF8044540A4367172BFC74B40
27052	1	3	190	701	34485	\N	55.56053	Владимирская область, город Муром, Ковровская, 18	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27031	1	3	190	701	34762	\N	55.56053	г. Муром, ул.  Кирова, 13, МОУ СО Школа № 10		0101000020E61000002237C30DF8044540A4367172BFC74B40
27030	1	3	190	701	34762	\N	55.56053	Владимирская область, город Муром, Кирова, 13		0101000020E61000002237C30DF8044540A4367172BFC74B40
27048	1	3	190	701	34618	\N	55.561659570460201	Владимирская область, город Муром, Карла Маркса, 23	Россия, Владимирская область, Муромский район, Муром	0101000020E610000004C6FA062605454056BC9179E4C74B40
27034	1	3	190	701	34616	\N	55.56053	Владимирская область, город Муром, Карачаровское шоссе, 9		0101000020E61000002237C30DF8044540A4367172BFC74B40
27067	1	3	190	701	34720	\N	55.56053	Владимирская область, город Муром, Гоголева, 1		0101000020E61000002237C30DF8044540A4367172BFC74B40
27045	1	3	190	701	34813	\N	55.56053	Владимирская область, город Муром, Артема, 39		0101000020E61000002237C30DF8044540A4367172BFC74B40
27059	1	3	190	701	34488	\N	55.56053	Владимирская область, город Муром, Амосова, 41	Россия, Владимирская область, Муромский район, Муром	0101000020E61000002237C30DF8044540A4367172BFC74B40
27083	1	3	190	3790	34916	\N	55.750905000000003	село Молотицы, Гагарина, 24		0101000020E61000000A302C7FBEF9444092B3B0A71DE04B40
27102	1	3	190	49084	35091	\N	55.504409000000003	деревня Мишино, Комсомольская, 71Б		0101000020E6100000DF4F8D976EFE44406F675F7990C04B40
27094	1	3	190	48952	35446	\N	55.667949999999998	деревня Михалево, Кооперативная, 18		0101000020E61000005EBA490C02EF44407DAEB6627FD54B40
27090	1	3	190	4196	35066	\N	55.704920000000001	деревня Межищи, Полевая, 45		0101000020E6100000C23577F4BFE64440EE258DD13ADA4B40
27097	1	3	190	49001	35114	\N	55.584085000000002	деревня Макаровка, Центральная, 10		0101000020E61000004DF8A57EDEF84440C68A1A4CC3CA4B40
26758	1	3	190	46962	35080	\N	55.680762999999999	д. Лесниково, Центральная, 43		0101000020E6100000ADF886C267F74440D6A9F23D23D74B40
27100	1	3	190	49041	35064	\N	55.556747000000001	село Лазарево, Школьная, 9А		0101000020E61000003049658A39FA4440B492567C43C74B40
27081	1	3	190	48730	35032	\N	55.799698999999997	поселок Кондраково, Муромская, 13		0101000020E6100000F9F6AE415FF444406BD26D895CE64B40
27095	1	3	190	4464	34816	\N	55.615670000000001	село Ковардицы, Школьная, 9		0101000020E610000065A88AA9F4F944406D904946CECE4B40
27056	1	3	190	54147	\N	\N	55.616351000000002	Владимирская область, Муромский район, п. имени П.Л. Войкова, Дом Культуры	Россия, Владимирская область, Муромский район, поселок Имени Войкова	0101000020E6100000FAF02C4146044540AFEDED96E4CE4B40
27099	1	3	190	49032	35062	\N	55.548996000000002	деревня Иваньково, Школьная, 132		0101000020E610000029B16B7BBBF5444042D13C8045C64B40
26759	1	3	190	46979	34668	\N	55.715463999999997	пос. Иванищи, Молодёжная, 1		0101000020E61000002EC896E5EBEA444090BB085394DB4B40
27055	1	3	190	54155	\N	\N	55.610112000000001	Владимирская область, Муромский район, с. Дмитриевская Слобода, Средняя школа	Россия, Владимирская область, Муромский район, поселок Дмитриева Слобода	0101000020E6100000DD787764AC044540D672672618CE4B40
27091	1	3	190	48898	34982	\N	55.686405999999998	село Булатниково, Мира, 1		0101000020E6100000F641960513E144409BE3DC26DCD74B40
27078	1	3	190	48660	35120	\N	55.804122	село Боровицы, Приокская, 15		0101000020E61000005CAB3DEC852E45403FFF3D78EDE64B40
27085	1	3	190	48790	34968	\N	55.713065	село Борисоглеб, Коминтерна, 16		0101000020E6100000F5F411F8C30145400C76C3B645DB4B40
26110	1	3	539	47766	34892	\N	56.274664000000001	поселок Раздолье, Первомайская, 1		0101000020E6100000E0F76F5E9CBA4340BCB1A03028234C40
27071	1	3	190	3180	\N	\N	55.575989	Владимирская область, Муромский район, д. Александровка, Библиотека		0101000020E6100000AA9ECC3FFAFC444089EDEE01BAC94B40
27175	1	3	649	46024	35147	\N	55.417383000000001	деревня Усад, Центральная, 26		0101000020E61000004145D5AF7400454004745FCE6CB54B40
27174	1	3	649	46023	35023	\N	55.434691000000001	село Урваново, Центральная, 76, здание сельской администрации		0101000020E610000029232E008D024540CA6E66F4A3B74B40
27179	1	3	649	46129	35361	\N	55.443930000000002	деревня Тургенево, Совхозная, 9		0101000020E6100000F8325184D4EF44404DDBBFB2D2B84B40
27150	1	3	649	45529	34938	\N	55.409595000000003	деревня Софроново, Молодежная, 1		0101000020E610000014967840D9B0444075CDE49B6DB44B40
27143	1	3	649	45419	35042	\N	55.601213000000001	деревня Скрипино, Новая, 1		0101000020E6100000BBEEAD484CC044400C772E8CF4CC4B40
27149	1	3	649	7262	35093	\N	55.435141000000002	село Синжаны, Комсомольская, 5		0101000020E6100000944BE3175EB544400A1346B3B2B74B40
27177	1	3	649	46069	35097	\N	55.423161999999998	деревня Селино, Советская, 44А		0101000020E61000009C53C90050EB44407974232C2AB64B40
27093	1	3	649	4319	35359	\N	55.398901000000002	деревня Савково, Советская, 2		0101000020E61000006F8099EFE0E94440BDAB1E300FB34B40
27154	1	3	649	45610	35094	\N	55.433782000000001	деревня Прудня, Зеленая, 28А		0101000020E610000093718C648FD64440F7CB272B86B74B40
27153	1	3	649	45600	34921	\N	55.561776999999999	деревня Папулино, Советская, 1		0101000020E6100000D7D9907F66E044408F52094FE8C74B40
27172	1	3	649	45964	35096	\N	55.337522	деревня Паново, Центральная, 67		0101000020E610000044A4A65D4CE744401BD7BFEB33AB4B40
27166	1	3	649	45835	\N	\N	55.234681000000002	деревня Осинки, Лесничества, здание лесничества		0101000020E6100000C79DD2C1FACF44400DFFE9060A9E4B40
27159	1	3	649	7708	35095	\N	55.138573000000001	деревня Окшово, Центральная, 72А		0101000020E6100000747D1F0E12DA4440E78D93C2BC914B40
27142	1	3	649	45396	35442	\N	55.558025000000001	деревня Новониколаевское, Центральная, 12		0101000020E61000003E78EDD286B34440DAACFA5C6DC74B40
27132	1	3	649	5375	34543	\N	55.336477000000002	город Меленки, Комсомольская, 189		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27148	1	3	649	5375	35170	\N	55.336477000000002	город Меленки, Свердлова, 70А		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27133	1	3	649	5375	34941	\N	55.336477000000002	город Меленки, Пушкина, 6А		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27136	1	3	649	5375	34891	\N	55.336477000000002	город Меленки, Мичурина, 46		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27130	1	3	649	5375	34986	\N	55.336477000000002	город Меленки, Ленина, 41		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27131	1	3	649	5375	34651	\N	55.336477000000002	город Меленки, Комсомольская, 108		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27112	1	3	649	5375	34651	\N	55.336477000000002	город Меленки, Комсомольская, 40		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27135	1	3	649	5375	34514	\N	55.336477000000002	город Меленки, Дзержинского, 29		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27128	1	3	649	5375	34889	\N	55.336477000000002	город Меленки, 1 Мая, 27		0101000020E610000055DE8E705AD04440986DA7AD11AB4B40
27158	1	3	649	7665	35043	\N	55.175046000000002	деревня Малый Санчур, Центральная, 52А		0101000020E61000007156444DF4DF4440D7A546E867964B40
27147	1	3	649	7157	35145	\N	55.335832000000003	деревня Малый Приклон, Центральная, здание Меленковского ФОТ		0101000020E6100000471FF30181CA4440A379008BFCAA4B40
27141	1	3	649	45385	35144	\N	55.496205000000003	деревня Максимово, Каманина, 1Б		0101000020E6100000FE7C5BB054B544404C8E3BA583BF4B40
27170	1	3	649	8247	34881	\N	55.330148000000001	село Ляхи, Советская, 114		0101000020E61000003A2009FB76F644407F6B274A42AA4B40
27171	1	3	649	8247	34919	\N	55.330148000000001	село Ляхи, Горького, 2		0101000020E61000003A2009FB76F644407F6B274A42AA4B40
27165	1	3	649	7987	35138	\N	55.299562999999999	деревня Лехтово, Центральная, 124А		0101000020E61000007193516518CF4440BB0B941458A64B40
27152	1	3	649	45558	35202	\N	55.527661999999999	деревня Левино, Школьная, 19А		0101000020E6100000F9156BB8C8CF4440C5ABAC6D8AC34B40
27169	1	3	649	8185	35171	\N	55.317666000000003	деревня Левенда, Новая, д. 11, здание сельского клуба		0101000020E6100000E90C8CBCACE544408C868C47A9A84B40
27164	1	3	649	7947	35137	\N	55.202038999999999	деревня Кулаки, Центральная, 103		0101000020E61000005C751DAA29D144401EC2F869DC994B40
27163	1	3	649	45779	35038	\N	55.265835000000003	деревня Крутцы, Новая, 116А		0101000020E61000007E39B35DA1CD4440EB909BE106A24B40
27146	1	3	649	45459	67411	\N	55.379956	село Коровино, Зеленая, здание Дома культуры		0101000020E610000077A38FF980C04440A1F5F065A2B04B40
27157	1	3	649	45671	35119	\N	55.243586999999998	деревня Кононово, Клубная, 16		0101000020E610000065A88AA9F4E34440895DDBDB2D9F4B40
27162	1	3	649	45775	35021	\N	55.221634999999999	село Илькино, Центральная, 167		0101000020E61000000C01C0B167CD4440115322895E9C4B40
27145	1	3	649	45448	35068	\N	55.373004000000002	деревня Иватино, Центральная, 80А		0101000020E61000007A1A3048FACA44407BA35698BEAF4B40
27140	1	3	649	45352	35156	\N	55.409829999999999	деревня Злобино, Центральная, 34А		0101000020E6100000008C67D0D0C74440B875374F75B44B40
27168	1	3	649	45874	35118	\N	55.423586	деревня Елино, Новая, 5		0101000020E61000009C51F355F20945409085E81038B64B40
27156	1	3	649	7589	34942	\N	55.206457	село Дмитриевы Горы, Первомайская, 67А		0101000020E6100000BFB67EFACFE44440E083D72E6D9A4B40
26735	1	3	649	46475	\N	\N	55.274707999999997	д. Дмитриево, Дмитриевский сельский клуб		0101000020E61000002D3F7095279844408BF9B9A129A34B40
27151	1	3	649	7366	34920	\N	55.505688999999997	село Денятино, Советская, 89		0101000020E61000002463B5F97FD544403579CA6ABAC04B40
27161	1	3	649	7780	35069	\N	55.199351999999998	деревня Двойново, Школьная, 2А		0101000020E610000047904AB1A3C344403332C85D84994B40
27167	1	3	649	45856	35195	\N	55.355935000000002	деревня Высоково, Центральная, 57		0101000020E6100000A27A6B60ABF644403A4030478FAD4B40
27155	1	3	649	45649	35146	\N	55.247897999999999	село Воютино, Центральная, 108А		0101000020E61000005645B8C9A8EA4440355F251FBB9F4B40
27160	1	3	649	45729	35117	\N	55.272185	село Войново, Центральная, 41А		0101000020E61000000A85083884D044401BBB44F5D6A24B40
27139	1	3	649	6783	35037	\N	55.452947000000002	деревня Верхоунжа, Центральная, 114		0101000020E61000005A0D897B2CC3444021E9D32AFAB94B40
27138	1	3	649	6719	34635	\N	55.515099999999997	село Бутылицы, Садовая, 2 а		0101000020E6100000E7525C55F6BF4440B515FBCBEEC14B40
27144	1	3	649	6990	35067	\N	55.351824999999998	деревня Большой Приклон, Центральная, 69		0101000020E610000043C9E4D4CEC844402575029A08AD4B40
27137	1	3	649	49568	34870	\N	55.452292999999997	село Архангел, Центральная, 44А		0101000020E610000036785F950BC74440D89AADBCE4B94B40
27176	1	3	649	8509	35044	\N	55.385142000000002	деревня Адино, Центральная, здание клуба		0101000020E61000007024D06053E34440742843554CB14B40
26450	1	3	539	5177	35126	\N	56.286183000000001	с. Новобусино, ул. Четвертая, 1, Дом культуры		0101000020E6100000828B153598D64340E9D500A5A1244C40
26451	1	3	539	5256	34955	\N	56.363284	поселок Металлист, Школьная, 1		0101000020E610000023DDCF29C89D43407D941117802E4C40
26440	1	3	539	4657	\N	\N	56.320087999999998	Кольчугинский район, д. Литвиново, 158а		0101000020E6100000656EBE11DDB34340C8EBC1A4F8284C40
26823	1	3	539	54160	34980	\N	56.147802960797797	деревня Лаврово, Молодежная, 4	Россия, Владимирская область, Кольчугинский район, поселок Лаврово	0101000020E6100000473D44A33BCC434017A06D35EB124C40
26434	1	3	539	3272	34438	\N	56.302532999999997	Владимирская область, город Кольчугино, Шмелева, 7		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26424	1	3	539	3272	34648	\N	56.302532999999997	Владимирская область, город Кольчугино, ул. Темкина, 6		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26428	1	3	539	3272	34456	\N	56.302532999999997	Владимирская область, город Кольчугино, Луговая, 1-а		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26436	1	3	539	3272	34440	\N	56.302532999999997	Владимирская область, город Кольчугино, Алексеева, 1		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26433	1	3	539	3272	34685	\N	56.302532999999997	Владимирская область, город Кольчугино, Садовая, 46		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26429	1	3	539	3272	34548	\N	56.302532999999997	Владимирская область, город Кольчугино, Молодежная, 2		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26438	1	3	539	3272	34739	\N	56.302532999999997	Владимирская область, г. Кольчугино, Мира, 4		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26427	1	3	539	3272	34494	\N	56.302532999999997	Владимирская область, город Кольчугино, 3 Интернационала, 57/7		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26430	1	3	539	3272	34549	\N	56.302532999999997	Владимирская область, город Кольчугино, Гагарина, 8		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26426	1	3	539	3272	34732	\N	56.302532999999997	Владимирская область, город Кольчугино, 50 лет СССР, 3		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26425	1	3	539	3272	34454	\N	56.302532999999997	Владимирская область, город Кольчугино, 3 Интернационала, 73		0101000020E6100000DE54A4C2D8AE4340FA7ABE66B9264C40
26444	1	3	539	49518	35340	\N	56.393698000000001	село Ильинское, Первая, 6		0101000020E6100000E085ADD9CAAD4340144031B264324C40
26445	1	3	539	49536	35050	\N	56.425924999999999	поселок Золотуха, Тринадцатая, 2		0101000020E610000028452BF702AD43403FC6DCB584364C40
26449	1	3	539	5155	35104	\N	56.302487999999997	село Есиплево, Коллективная, 2		0101000020E6100000698B6B7C26C543405AB741EDB7264C40
26447	1	3	539	5044	35166	\N	56.208373999999999	село Ельцино, Школьная, 13		0101000020E610000013EE9579ABCE434019ABCDFFAB1A4C40
26331	1	3	539	47607	35102	\N	56.202106000000001	поселок Вишневый, Первая, 13		0101000020E610000051C0763062BB4340A629029CDE194C40
26446	1	3	539	49550	35018	\N	56.131551000000002	село Ваулово, Первая, 3		0101000020E610000048FC8A355CA44340C860C5A9D6104C40
26442	1	3	539	4762	34929	\N	56.418064000000001	с. Большое Кузьминское, Молодежная, 1в		0101000020E6100000A0A4C00298C4434046D1031F83354C40
26443	1	3	539	49506	35158	\N	56.390135999999998	поселок Большевик, Спортивная, 12		0101000020E6100000E44BA8E0F0B44340027FF8F9EF314C40
26153	1	3	539	22885	\N	\N	56.262251999999997	село Беречино, 107		0101000020E61000006EC328081EB34340C1A7397991214C40
26439	1	3	539	54151	34851	\N	56.2814521433477	п. Белая Речка, Школьная, 1	Россия, Владимирская область, Кольчугинский район, поселок Белая Речка	0101000020E61000002655DB4DF0B3434068B27F9E06244C40
26441	1	3	539	4743	34552	\N	56.396678000000001	п. Бавлены, пл. Мира, 1а		0101000020E610000091B932A836C8434077853E58C6324C40
26581	1	3	539	47978	\N	\N	56.268650999999998	с. Авдотьино, 23/А		0101000020E6100000EB8EC536A9A64340D384ED2763224C40
26872	1	3	1063	25712	\N	\N	56.489362	Владимирская область, Ковровский район, Клязьминское сельское поселение, д.Юдиха, 57		0101000020E61000004F75C8CD70E34440DCF3FC69A33E4C40
26895	1	3	1063	26761	35163	\N	56.031014999999996	Владимирская область, Ковровский район, Ивановское сельское поселение, д.Шевинская, Советская, 33		0101000020E610000031EA5A7B9FD24440BC57AD4CF8034C40
26879	1	3	1063	9337	\N	\N	56.373998	Владимирская область, Ковровский район, Клязьминское сельское поселение, п.Филино, 12		0101000020E61000001ADEACC1FBCA44407C629D2ADF2F4C40
26875	1	3	1063	25847	35029	\N	56.404349000000003	Владимирская область, Ковровский район, Клязьминское сельское поселение, д.Старая, Совхозная, 31		0101000020E6100000C5E40D30F3BD4440CD9541B5C1334C40
26891	1	3	1063	26591	35149	\N	56.075715000000002	Владимирская область, Ковровский район, Ивановское сельское поселение, с.Смолино, Дорожная, 3		0101000020E610000026378AAC35B4444088687407B1094C40
27001	1	3	1063	54162	34996	\N	56.199045125903098	д. Серково-1, Старое Серково, 25 А	Россия, Владимирская область, Ковровский район, поселок Серково	0101000020E61000007F33315D88D1444056B77A4E7A194C40
26873	1	3	1063	25787	35030	\N	56.406315999999997	Владимирская область, Ковровский район, Клязьминское сельское поселение, с.Санниково, Центральная, 35		0101000020E6100000B1C1C2499AD34440B7EBA52902344C40
26869	1	3	1063	54152	34828	\N	56.392158999999999	Владимирская область, Ковровский район, Малыгинское сельское поселение, д.Ручьи, Центральная, 8-Б	Россия, Владимирская область, Ковровский район, поселок Ручей	0101000020E61000003AC9569753A0444081EA1F4432324C40
26884	1	3	1063	26228	\N	\N	56.301803	Владимирская область, Ковровский район, Новосельское сельское поселение, п.Первомайский, 20		0101000020E6100000876F61DD78A54440D76A0F7BA1264C40
26871	1	3	1063	25676	35131	\N	56.459974000000003	Владимирская область, Ковровский район, Клязьминское сельское поселение, с.Пантелеево, Подгородица, 5		0101000020E6100000E1D1C6116BEB44405281936DE03A4C40
26870	1	3	1063	10849	34486	\N	56.364829999999998	Владимирская область, Ковровский район, Малыгинское сельское поселение, п.Пакино, Школьная, 20-Г		0101000020E6100000EDF0D7648D9E4440C24CDBBFB22E4C40
26888	1	3	1063	26450	35082	\N	56.219047000000003	Владимирская область, Ковровский район, Ивановское сельское поселение, с.Павловское, Советская, 9		0101000020E6100000E54350357ABD4440BAA46ABB091C4C40
26881	1	3	1063	54165	35016	\N	56.295651225026297	Владимирская область, Ковровский район, Новосельское сельское поселение, п.Новый, Школьная, 3	Россия, Владимирская область, Ковровский район, поселок Новый	0101000020E610000005E10A28D49F4440CD0358E4D7254C40
26886	1	3	1063	26356	35178	\N	56.203682999999998	Владимирская область, Ковровский район, Новосельское сельское поселение, п.Нерехта, Школьная, 2		0101000020E61000003A765089EBAA444026E0D748121A4C40
26898	1	3	1063	26839	34701	\N	56.268107000000001	Владимирская область, Ковровский район, поселок Мелехово, Школьный перулок, 25-А		0101000020E610000043209738F2A64440126A865451224C40
26897	1	3	1063	26839	34571	\N	56.268107000000001	Владимирская область, Ковровский район, поселок Мелехово, Первомайская, 48		0101000020E610000043209738F2A64440126A865451224C40
26899	1	3	1063	26839	34707	\N	56.268107000000001	Владимирская область, Ковровский район, поселок Мелехово, Парковая, 2-А		0101000020E610000043209738F2A64440126A865451224C40
26868	1	3	1063	25537	34570	\N	56.410111000000001	Владимирская область, Ковровский район, Малыгинское сельское поселение,п. Малыгино, Школьная, 62		0101000020E6100000923EADA23F9444406C5D6A847E344C40
26887	1	3	1063	26384	34981	\N	56.188322999999997	Владимирская область, Ковровский район, Новосельское сельское поселение, с.Крутово, Танеева, 2		0101000020E61000008EE9094B3CAC4440D40AD3F71A184C40
26880	1	3	1063	26099	35132	\N	56.324745999999998	Владимирская область, Ковровский район, Клязьминское сельское поселение, п.Крестниково, Школьная, 9		0101000020E6100000CF15A58460CF4440DFC0E44691294C40
26892	1	3	1063	9355	34973	\N	56.103251	Владимирская область, Ковровский район, Ивановское сельское поселение, п.Красный Октябрь, Комсомольская, д. 2а		0101000020E6100000315EF3AACEB04440C0232A54370D4C40
26893	1	3	1063	26663	34867	\N	56.048977999999998	Владимирская область, Ковровский район, Ивановское сельское поселение, п.Красный Маяк, Маяковского, 2		0101000020E6100000A5DB12B9E0AE44409B1C3EE944064C40
26874	1	3	1063	54164	35014	\N	56.445882490945799	Владимирская область, Ковровский район, Клязьминское сельское поселение, с.Клязьминский городок, Фабричный поселок, 35	Россия, Владимирская область, Ковровский район, поселок Клязьминский Городок	0101000020E6100000209BE447FCC0444002F04FA912394C40
26867	1	3	1063	25473	35153	\N	56.473385999999998	Владимирская область, Ковровский район, Малыгинское сельское поселение, д.Ильино, Центральная, 29		0101000020E61000006C3EAE0D15BB44402F3196E9973C4C40
26820	1	3	1063	25473	35081	\N	56.473385999999998	деревня Ильино, Молодежная, 8		0101000020E61000006C3EAE0D15BB44402F3196E9973C4C40
26890	1	3	1063	26491	34700	\N	56.18168	Владимирская область, Ковровский район, Ивановское сельское поселение, с.Иваново, Коммунистическая, 24		0101000020E610000029E9616875BC44402C2B4D4A41174C40
26889	1	3	1063	26491	34911	\N	56.18168	Владимирская область, Ковровский район, Ивановское сельское поселение, с.Иваново, Гагарина, 9-А		0101000020E610000029E9616875BC44402C2B4D4A41174C40
26878	1	3	1063	25996	34750	\N	56.383338999999999	Владимирская область, Ковровский район, Клязьминское сельское поселение, п. Достижение, Фабричная, 40		0101000020E6100000D84812842BBC444003249A4011314C40
26876	1	3	1063	9619	35140	\N	56.422902999999998	Владимирская область, Ковровский район, Клязьминское сельское поселение, д.Глебово, Школьная, 22		0101000020E6100000BAF770C971BB4440AD307DAF21364C40
26865	1	3	1063	25388	34912	\N	56.444786999999998	Владимирская область, Ковровский район, Малыгинское сельское поселение, п.Гигант, Юбилейная, 66		0101000020E61000002BC0779B37A64440CD57C9C7EE384C40
26894	1	3	1063	26739	35031	\N	56.091718	Владимирская область, Ковровский район, Ивановское сельское поселение, п.Восход, Советская, 51-А		0101000020E610000019726C3D43C444402E3A596ABD0B4C40
26885	1	3	1063	26288	\N	\N	56.243704999999999	Владимирская область, Ковровский район, Новосельское сельское поселение, с.Великово, 79		0101000020E6100000E27492AD2EA54440936FB6B9311F4C40
26808	1	3	1063	47917	35079	\N	56.003185000000002	поселок Болотский, Школьная, 11		0101000020E61000006325E65949A744403C6BB75D68004C40
26866	1	3	1063	25416	35024	\N	56.445836999999997	Владимирская область, Ковровский район, Малыгинское сельское поселение, село Большие Всегодичи, Центральная, 61-А		0101000020E61000005A626534F2A94440622CD32F11394C40
26882	1	3	1063	26178	\N	\N	56.300899000000001	Владимирская область, Ковровский район, Новосельское сельское поселение, д.Бельково, 105-А		0101000020E610000022FFCC203E9A44401633C2DB83264C40
26420	1	3	378	3604	34948	\N	56.101002000000001	Владимирская область, Киржачский район, с. Филипповское, Сельская Новь, 24		0101000020E61000006B64575A464E4340516A2FA2ED0C4C40
26416	1	3	378	3368	34884	\N	56.112617999999998	Владимирская область, Киржачский район, д. Фёдоровское, Советская, 6а		0101000020E61000002D7B12D89C6D4340707841446A0E4C40
26421	1	3	378	3683	35151	\N	56.021754000000001	Владимирская область, Киржачский район, д. Песьяне, Советская, 27а		0101000020E6100000B2A19BFD816643405247C7D5C8024C40
26418	1	3	378	54149	34823	\N	56.137108154944698	Владимирская область, Киржачский район, п. Пешино, Школьная, 4а	Россия, Владимирская область, Киржачский район, поселок Першино	0101000020E61000008C9E5BE84A5E43408E0244C18C114C40
26415	1	3	378	3358	34902	\N	56.064404000000003	Владимирская область, Киржачский район, д. Новосёлово, Школьная, 6		0101000020E6100000427C60C77F874340A5DDE8633E084C40
26407	1	3	378	1947	34992	\N	56.158059999999999	Владимирская область, город Киржач, м-н Красный Октябрь, Пионерская, 1		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26398	1	3	378	1947	34647	\N	56.158059999999999	Владимирская область, г. Киржач, Набережная, 9	Россия, Владимирская область, Киржачский район, Киржач	0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26395	1	3	378	1947	34721	\N	56.158059999999999	Владимирская область, г. Киржач, Заводская, 14а		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26394	1	3	378	1947	34453	\N	56.158059999999999	Владимирская область, г. Киржач, Гастелло, 9		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26399	1	3	378	1947	34493	\N	56.158059999999999	Владимирская область, г. Киржач, Вокзальная, 26		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26400	1	3	378	1947	34988	\N	56.158059999999999	Владимирская область, г. Киржач, Шелковиков, 10		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26397	1	3	378	1947	34492	\N	56.158059999999999	Владимирская область, г. Киржач, Чехова, 10а		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26392	1	3	378	1947	34953	\N	56.158059999999999	Владимирская область, г. Киржач, Фрунзе, 2а		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26396	1	3	378	1947	34535	\N	56.158059999999999	Владимирская область, г. Киржач, Серёгина, 24		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26403	1	3	378	1947	34505	\N	56.158059999999999	Владимирская область, город Киржач, м-н Красный Октябрь, Садовая, 51		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26405	1	3	378	1947	34539	\N	56.158059999999999	Владимирская область, город Киржач, м-н Красный Октябрь, Пушкина, 27		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26404	1	3	378	1947	34539	\N	56.158059999999999	Владимирская область, город Киржач, м-н Красный Октябрь, Пушкина, 29		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26406	1	3	378	1947	34775	\N	56.158059999999999	Владимирская область, город Киржач, м-н Красный Октябрь, Октябрьская, 14		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26393	1	3	378	1947	34534	\N	56.158059999999999	Владимирская область, г. Киржач, Ленинградская, 55		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26402	1	3	378	1947	34537	\N	56.158059999999999	Владимирская область, город Киржач, 40 лет Октября, 17		0101000020E610000025CCB4FD2B6F43402367614F3B144C40
26401	1	3	378	1947	34633	\N	56.158060033609203	Владимирская область, город Киржач, 40 лет Октября, 25а	Россия, Владимирская область, Киржачский район, Киржач	0101000020E61000009DD843FB586F43402367614F3B144C40
26412	1	3	378	3170	34928	\N	56.238787000000002	Владимирская область, Киржачский район,  д. Кипрево, Центральная, 8д		0101000020E6100000F06AB933137E4340E0DA8992901E4C40
26410	1	3	378	3018	35103	\N	56.218781999999997	Владимирская область, Киржачский район, д. Илькино, Центральная, 40		0101000020E6100000BEBC00FBE86C43400B7A6F0C011C4C40
26422	1	3	378	3686	35124	\N	56.000793999999999	Владимирская область, Киржачский район, с. Заречье, Центральная, 17		0101000020E61000009818CBF44B4E43403A048E041A004C40
26411	1	3	378	3127	34946	\N	56.221549000000003	Владимирская область, Киржачский район, д. Ефремово, Восточная, 9		0101000020E61000006ADE718A8E7E434013BBB6B75B1C4C40
26408	1	3	378	2939	35123	\N	56.173637999999997	Владимирская область, Киржачский район, д. Ельцы, Молодежная, 15		0101000020E6100000EBA9D55757634340E2AB1DC539164C40
26409	1	3	378	3014	34945	\N	56.243113999999998	Владимирская область, Киржачский район, п. Горка, Школьный переулок, 3		0101000020E6100000ECA529029C64434091990B5C1E1F4C40
26413	1	3	378	3222	35017	\N	56.271380999999998	Владимирская область, Киржачский район, д. Афанасово, Центральная, 19		0101000020E6100000081EDFDE358A4340BDE0D39CBC224C40
26419	1	3	378	3550	34947	\N	56.116086000000003	Владимирская область, Киржачский район, д. Аленино, Центральная, 73		0101000020E61000005AA0DD21C550434001C3F2E7DB0E4C40
26857	1	3	788	24921	67622	\N	56.413263999999998	д. Сергеиха, ул. Центральная, 1, Администрация муниципального образования Сергеихинское		0101000020E61000002FC37FBA816044409C4EB2D5E5344C40
26855	1	3	788	24921	34964	\N	56.413263999999998	Владимирская область, Камешковский район, деревня Сергеиха, Карла Либкнехта, 91		0101000020E61000002FC37FBA816044409C4EB2D5E5344C40
26863	1	3	788	25258	35098	\N	56.187286	Владимирская область, Камешковский район, деревня Пенкино, Лесная, 1		0101000020E6100000F7949C137B744440D47FD6FCF8174C40
26844	1	3	788	9512	34699	\N	56.362566000000001	Владимирская область, Камешковский район, поселок Новки, Ильича, 14		0101000020E6100000A79196CADB8944401E520C90682E4C40
26845	1	3	788	9512	34569	\N	56.362566000000001	Владимирская область, Камешковский район, поселок Новки, Фрунзе, 17		0101000020E6100000A79196CADB8944401E520C90682E4C40
26859	1	3	788	25102	34900	\N	56.288606000000001	Владимирская область, Камешковский район, поселок Мирный, Школьная, 8		0101000020E6100000581EA4A7C8634440F6B6990AF1244C40
26856	1	3	788	24976	\N	\N	56.405817999999996	Владимирская область, Камешковский район, деревня Лубенцы, 45		0101000020E61000002AE09EE74F5F444066101FD8F1334C40
26852	1	3	788	48744	74910	\N	56.456204	пос. Краснознаменский, ул. Шоссейная, Муниципальное учреждение культуры Дом культуры поселка Краснознаменский	Россия, Владимирская область, Камешковский район, поселок Краснознаменский	0101000020E6100000ED48F59D5F804440F62686E4643A4C40
26854	1	3	788	24896	9876	\N	56.360886000000001	Владимирская область, Камешковский район, село Коверино, Садовая, 18		0101000020E6100000C634D3BD4E724440C9CA2F83312E4C40
26841	1	3	788	8993	34795	\N	56.350717000000003	Владимирская область, Камешковский район, город Камешково, Гоголя, 4		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
26840	1	3	788	8993	34607	\N	56.350717000000003	Владимирская область, Камешковский район, город Камешково, Школьная, 3		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
27187	1	3	788	8993	34796	\N	56.350717000000003	г. Камешково, ул. Гоголя, д. 5а, МОУ средняя общеобразовательная школа № 1		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
26842	1	3	788	8993	34796	\N	56.350717000000003	Владимирская область, Камешковский район, город Камешково, Гоголя, 5А		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
26839	1	3	788	8993	35005	\N	56.350717000000003	Владимирская область, Камешковский район, город Камешково, Герцена, 10		0101000020E6100000B22FD978B07F44405C936E4BE42C4C40
26851	1	3	788	24745	34896	\N	56.443364000000003	Владимирская область, Камешковский район, поселок имени Красина, Рабочая, 1		0101000020E61000000FB9196EC0734440A41CCC26C0384C40
26736	1	3	1145	19095	35159	\N	55.522025999999997	с Заколпье, Молодёжная, 21		0101000020E61000006F7F2E1A327E4440B2D47ABFD1C24B40
26848	1	3	788	24587	\N	\N	56.455064999999998	Владимирская область, Камешковский район, поселок имени Кирова, Шоссейная, 39/1	Россия, Владимирская область, Камешковский район, поселок Имени Кирова	0101000020E6100000C6F7C5A52A834440F146E6913F3A4C40
26846	1	3	788	24498	34753	\N	56.414318999999999	Владимирская область, Камешковский район, поселок имени Карла Маркса, Шоссейная, 14		0101000020E610000006F69848698C4440438EAD6708354C40
26847	1	3	788	24498	67611	\N	56.414318999999999	пос. им. Карла Маркса, ул. Карла Маркса, д. 9, МОУ Брызгаловская общеобразовательная школа		0101000020E610000006F69848698C4440438EAD6708354C40
26850	1	3	788	24659	34609	\N	56.472009	Владимирская область, Камешковский район, поселок имени Максима Горького, Морозова, 2		0101000020E61000008578245E9E7A4440763579CA6A3C4C40
26849	1	3	788	24659	34609	\N	56.472009	Владимирская область, Камешковский район, поселок имени Максима Горького, Морозова, 2-а		0101000020E61000008578245E9E7A4440763579CA6A3C4C40
26853	1	3	788	48753	74905	\N	56.353614	пос. им. Артема, ул. Центральная, 15, Здание администрации МО Сергеихинское		0101000020E61000002655DB4DF075444031B43A39432D4C40
26862	1	3	788	25245	\N	\N	56.174388999999998	Владимирская область, Камешковский район, село Давыдово, 53	Россия, Владимирская область, Камешковский район, поселок Давыдово	0101000020E61000009293895B055B44401DE4F56052164C40
26861	1	3	788	25176	\N	\N	56.290809000000003	Владимирская область, Камешковский район, село Горки, 20а		0101000020E6100000A4703D0AD77F4440F530B43A39254C40
26864	1	3	788	25348	34873	\N	56.213164999999996	Владимирская область, Камешковский район, село Гатиха, Новая, 2		0101000020E6100000E36BCF2C096E44406FD39FFD481B4C40
26858	1	3	788	9094	34989	\N	56.264777000000002	Владимирская область, Камешковский район, село Второво, Советская, 28а		0101000020E6100000430070ECD9654440D3DD7536E4214C40
27188	1	3	788	9094	74907	\N	56.264777000000002	с.Второво, ул. Советская, 22А, Администрация муниципального образования Второвское		0101000020E6100000430070ECD9654440D3DD7536E4214C40
26860	1	3	788	25130	\N	\N	56.322873999999999	Владимирская область, Камешковский район, деревня Волковойно, 39		0101000020E6100000FD4D2844C0814440465D6BEF53294C40
26769	1	3	1145	10803	34546	\N	55.675184000000002	пос. Уршельский, Театральная, 1		0101000020E6100000A48E8EAB911B44402864E76D6CD64B40
26768	1	3	1145	10803	34513	\N	55.675184000000002	пос. Уршельский, Весёлкина, 36		0101000020E6100000A48E8EAB911B44402864E76D6CD64B40
26748	1	3	1145	19682	34966	\N	55.334470000000003	д. Уляхино, Колхозная, 127		0101000020E61000001536035C905F44401FBFB7E9CFAA4B40
27173	1	3	1145	59043	67346	\N	55.751378314213802	деревня Толстиково, Центральная, 21	Россия, Владимирская область, Гусь-Хрустальный район, поселок Толстиково	0101000020E610000043588D25AC7D44408A7780272DE04B40
26744	1	3	1145	12818	35174	\N	55.347490000000001	д. Тащилово, Центральная, 3		0101000020E61000004A46CEC29E8E4440F1D7648D7AAC4B40
26770	1	3	1145	20951	35129	\N	55.611652999999997	пос. Тасинский Бор, Центральная, 8		0101000020E610000027327381CB13444009C03FA54ACE4B40
26771	1	3	1145	21002	35004	\N	55.574533000000002	пос. Тасинский, Новая, 1		0101000020E61000003128D3687217444084BC1E4C8AC94B40
26746	1	3	1145	32997	35189	\N	55.261775870604801	д.Таланово, Центральная, 156	Россия, Владимирская область, Гусь-Хрустальный район, поселок Таланово	0101000020E61000006AA67B9DD485444058703FE081A14B40
26737	1	3	1145	19105	\N	\N	55.498897999999997	ст. Вековка, МОУ Вековская СОШ		0101000020E61000004CA4349BC76144401805C1E3DBBF4B40
26973	1	3	1145	46578	35180	\N	55.435105	д. Перово, Школьная, 6 А		0101000020E6100000D25625917D304440BDA94885B1B74B40
26739	1	3	1145	46578	35180	\N	55.435105	д. Перово, Школьная, 2		0101000020E6100000D25625917D304440BDA94885B1B74B40
26749	1	3	1145	46758	\N	\N	55.257385999999997	д. Парахино, Парахинский сельский дом культуры		0101000020E6100000B16EBC3B3266444060394206F2A04B40
27103	1	3	1145	49089	34661	\N	55.721564000000001	село Панфилово, Октябрьская, 4		0101000020E610000050E09D7C7A48444048FC8A355CDC4B40
26747	1	3	1145	54168	\N	\N	55.288100999999997	д. Ново-Дурово, Ново-Дуровский СДК	Россия, Владимирская область, Гусь-Хрустальный район, поселок Новодурово	0101000020E6100000D0D2156C238E4440F2785A7EE0A44B40
26766	1	3	1145	47120	35003	\N	55.506988999999997	д. Нечаевская, Стрельцова, 28а		0101000020E6100000FD497CEE044D44404337FB03E5C04B40
26502	1	3	1145	54163	34997	\N	55.404328503226601	Владимирская область, Петушинский район, Нагорное сельское поселение, п. Нагорный, Владимирская, 1А	Россия, Владимирская область, Гусь-Хрустальный район, поселок Нагорный Поселок	0101000020E61000008CD7BCAAB360444085E97B0DC1B34B40
26740	1	3	1145	46602	\N	\N	55.456408000000003	д. Мокрое, здание администрации МО Демидовское	Россия, Владимирская область, Гусь-Хрустальный район, поселок Мокрое	0101000020E6100000C05C8B16A0214440FFD0CC936BBA4B40
26765	1	3	1145	20657	34561	\N	55.484551000000003	пос. Мезиновский, Строительная, 14		0101000020E610000010E9B7AF033344403F1F65C405BE4B40
26764	1	3	1145	20640	34790	\N	55.432969999999997	город Курлово, Советская, 1а		0101000020E6100000C32CB4739A3D444016139B8F6BB74B40
26743	1	3	1145	19448	34977	\N	55.331130999999999	д.Купреево, Школьная, 5		0101000020E61000008F8EAB915D8344408CD8278062AA4B40
26742	1	3	1145	46632	35267	\N	55.405346999999999	пос. Красный Октябрь, Октябрьская, 11		0101000020E61000009A22C0E95D7444400F441669E2B34B40
26761	1	3	1145	20433	34746	\N	55.791308999999998	пос. Красное Эхо, Почтовая, 1		0101000020E610000070EEAF1EF7594440E603029D49E54B40
26745	1	3	1145	19521	34951	\N	55.240189000000001	с. Колпь, Центральная, 6		0101000020E610000074B2D47ABF854440F2ED5D83BE9E4B40
26757	1	3	1145	20194	\N	\N	55.438986999999997	д. Икшево, здание администрации МО пос. Золотково	Россия, Владимирская область, Гусь-Хрустальный район, поселок Икшево	0101000020E610000098BF42E6CA8E4440402FDCB930B84B40
26756	1	3	1145	20117	35160	\N	55.512475000000002	разъезд Золотковский, Дачная, 22		0101000020E61000002F8B89CDC78944404182E2C798C14B40
26755	1	3	1145	46877	34602	\N	55.529761000000001	пос. Золотково, Социалистическая, 29		0101000020E610000013286211C38C44401FD95C35CFC34B40
26754	1	3	1145	46877	34562	\N	55.529761000000001	пос. Золотково, Гагарина, 19		0101000020E610000013286211C38C44401FD95C35CFC34B40
26763	1	3	1145	47064	\N	\N	55.780642999999998	с. Дубасово, Дубасовский сельский клуб		0101000020E610000013D55B035B6B4440F86C1D1CECE34B40
26752	1	3	1145	19917	34564	\N	55.506072000000003	пос. Добрятино, 60 лет Октября, 5		0101000020E6100000D4B6611404A94440EEB5A0F7C6C04B40
26797	1	3	1145	47657	34475	\N	55.664430664996203	п.Гусевский, ул.Мира, д.10 клуб Центрального поселка	Россия, Владимирская область, Гусь-Хрустальный район, поселок Гусевский	0101000020E6100000663046240A4944406BB933130CD54B40
26794	1	3	1145	47657	34475	\N	55.643174999999999	п.Гусевский, ул.Мира, д.12 средняя школа № 14		0101000020E61000001C5C3AE63C4744406A4DF38E53D24B40
26734	1	3	1145	46472	34932	\N	55.507662000000003	с. Григорьево, Черёмушки, 3		0101000020E6100000232E008DD27B444003B68311FBC04B40
26751	1	3	1145	19865	34663	\N	55.243875000000003	пос. Великодворский, Ленина, 3		0101000020E610000004AC55BB26564440F0A7C64B379F4B40
26654	1	3	1145	47928	34962	\N	55.704590000000003	д. Вашутино, ул.Центральная, д. 2 а		0101000020E6100000F8FE06EDD55D4440598B4F0130DA4B40
27087	1	3	1145	48824	35438	\N	55.582599000000002	село Борисово, Куйбышева, 73		0101000020E610000079E57ADB4C9D444056D7A19A92CA4B40
26750	1	3	1145	19789	34696	\N	55.700054999999999	пос. Анопино, Мира, 6		0101000020E6100000B806B64AB05444405D33F9669BD94B40
26767	1	3	1145	54177	\N	\N	55.639530686361802	д. Аббакумово, МОУ Аббакумовская ООШ	Россия, Владимирская область, Гусь-Хрустальный район, поселок Аббакумово	0101000020E6100000D66F26A60B3144409BE3DC26DCD14B40
27028	1	3	14	689	34899	\N	56.124009999999998	Владимирская область, Гороховецкий район, п.Чулково, Центральная, д. 14		0101000020E6100000A2B5A2CD714045404030478FDF0F4C40
27027	1	3	14	600	13338	\N	55.958173453508699	Владимирская область, Гороховецкий район,  с.Фоминки, Советская, 2	Россия, Владимирская область, Гороховецкий район, поселок Фоминки	0101000020E610000052802898312F45408274B169A5FA4B40
26762	1	3	14	47025	35013	\N	56.164506000000003	д. Семеновка, Сельская Новь, 44		0101000020E6100000A583F57F0E6B454076FF58880E154C40
27023	1	3	14	355	34527	\N	56.100409999999997	Владимирская область, Гороховецкий район, п.Пролетарский, Советская, 16		0101000020E6100000D0ECBAB7222B45407E18213CDA0C4C40
26984	1	3	14	46860	35464	\N	55.908071	д. Осинки, Шоссейная, 13		0101000020E6100000C634D3BD4E36454017B9A7AB3BF44B40
27024	1	3	14	421	35090	\N	56.172925999999997	Владимирская область, Гороховецкий район,  д.Крутово, Колхозная, д. 8, ФАП ГБУЗ ВО		0101000020E61000001A6CEA3C2A36454065506D7022164C40
27092	1	3	14	4284	35025	\N	55.870919999999998	поселок Зименки, Кооперативная, 21		0101000020E6100000ABB4C5353E29454056B77A4E7AEF4B40
27022	1	3	14	308	35089	\N	56.006340999999999	Владимирская область, Гороховецкий район,  с.Гришино, Ленина, 33, Дом культуры		0101000020E61000000A1346B3B2254540DDCF29C8CF004C40
27016	1	3	14	32092	34679	\N	56.20167	Владимирская область, Гороховецкий район, город Гороховец, Революции, 1		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27015	1	3	14	32092	74912	\N	56.20167	г. Гороховец, ул.Революции, д.1, (здание МОУ СОШ № 3)		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27009	1	3	14	32092	34583	\N	56.192056913950204	Владимирская область, Гороховецкий район, город Гороховец, Парковая, 60		0101000020E6100000D313967840554540E3FBE25295184C40
27017	1	3	14	32092	35007	\N	56.20167	Владимирская область, Гороховецкий район, город Гороховец, Московская, 43		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27014	1	3	14	32092	34484	\N	56.20167	Владимирская область, Гороховецкий район, город Гороховец, Мира, 15		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27013	1	3	14	32092	34614	\N	56.20167	Владимирская область, Гороховецкий район, город Гороховец, Ленина, 48		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27010	1	3	14	32092	34613	\N	56.20167	Владимирская область, Гороховецкий район, город Гороховец, Кутузова, 7		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27011	1	3	14	32092	34893	\N	56.20167	Владимирская область, Гороховецкий район, город Гороховец, Комсомольская, 23		0101000020E6100000971B0C7558594540CB4A9352D0194C40
27021	1	3	14	181	34936	\N	56.179270000000002	Владимирская область, Гороховецкий район,  п.Галицы, Железнодорожная, 1		0101000020E6100000AD6A4947396C4540B493C151F2164C40
27025	1	3	14	54158	34897	\N	56.168265815930802	Владимирская область, Гороховецкий район, д.Выезд, Полевая, 15	Россия, Владимирская область, Гороховецкий район, поселок Выезд	0101000020E6100000CB9C2E8B89594540AE8383BD89154C40
27020	1	3	14	171	34915	\N	56.156700999999998	Владимирская область, Гороховецкий район, д.Великово, Школьная, 47		0101000020E6100000755AB741ED674540102043C70E144C40
27026	1	3	14	533	35033	\N	55.966437999999997	Владимирская область, Гороховецкий район, д.Быкасово, Садовая, 16		0101000020E61000008925E5EE734A45404ACE893DB4FB4B40
27019	1	3	14	18	34880	\N	56.175401999999998	Владимирская область, Гороховецкий район, д.Арефино, Центральная, 4		0101000020E61000008C4B55DAE250454095D39E9273164C40
26985	1	3	1160	54173	35187	\N	56.298676999999998	поселок станции Сарыево, Шоссейная, 12	Россия, Владимирская область, Вязниковский район, поселок Сарыево	0101000020E6100000572250FD83DA4440A088450C3B264C40
26989	1	3	1160	31148	35006	\N	56.093842000000002	д. Эдон, Советская, 12		0101000020E6100000109370218FE04440E17EC003030C4C40
26992	1	3	1160	31300	34967	\N	56.094344	д. Шатнево, Заречная, 11		0101000020E61000006CB1DB6795F744407349D576130C4C40
26967	1	3	1160	46519	34808	\N	56.241298999999998	д. Чудиново, Центральная, 11		0101000020E6100000787FBC57AD0845405CC7B8E2E21E4C40
27008	1	3	1160	54159	34943	\N	56.201148345504897	п. Центральный, Главная, 19	Россия, Владимирская область, Вязниковский район, поселок Центральный	0101000020E6100000B75D68AED3104540F2D3B837BF194C40
26988	1	3	1160	46943	35164	\N	56.131444999999999	п. Степанцево, Совхозная, сельский клуб		0101000020E6100000EBE0606F62DA4440821C9430D3104C40
26987	1	3	1160	46943	34717	\N	56.131444999999999	п. Степанцево, Первомайская, 16-А		0101000020E6100000EBE0606F62DA4440821C9430D3104C40
27003	1	3	1160	31819	34879	\N	55.985518999999996	с. Сергиевы Горки, Муромская, 90		0101000020E61000003DD68C0C720D4540164B917C25FE4B40
26388	1	3	12	1608	34682	\N	56.374366999999999	г.Струнино, ул.Воронина, д.3,  МУ « Дом спорта», 1-й этаж		0101000020E6100000E3E0D231E7494340CFD90242EB2F4C40
27007	1	3	1160	54175	35190	\N	56.189449095835002	д. Сергеево, Центральная, 2 А	Россия, Владимирская область, Вязниковский район, поселок Сергеево	0101000020E6100000F775E09C1111454045A165DD3F184C40
26986	1	3	1160	31009	35116	\N	56.277997999999997	с. Сарыево, Советская, 22 Г		0101000020E61000007233DC80CFDF44403C2D3F7095234C40
26994	1	3	1160	47075	34927	\N	56.141517999999998	п. Приозерный, Советская, 74		0101000020E6100000B9718BF9B9FB4440CDE506431D124C40
26974	1	3	1160	12752	34890	\N	56.228906000000002	д. Пировы-Городищи, Центральная, 5, «Пирово-Городищенская основная общеобразовательная школа»		0101000020E610000017D522A298204540D9EDB3CA4C1D4C40
26972	1	3	1160	54161	34983	\N	56.191433843983397	д. Пески, Новая, 15	Россия, Владимирская область, Вязниковский район, поселок Пески	0101000020E6100000C231CB9E04204540D6ABC8E880184C40
27005	1	3	1160	31913	34914	\N	56.119574	д. Паустово, Центральная, 56 А		0101000020E61000008787307E1A154540D8B969334E0F4C40
27002	1	3	1160	54150	34824	\N	56.219617999999997	п. Октябрьский, Советская, 1		0101000020E6100000B75F3E593104454074CE4F711C1C4C40
26530	1	3	1160	54139	\N	\N	56.072629999999997	поселок Ставрово, Собинский район, Владимирская область, Октябрьская, 118в	Россия, Владимирская область, Вязниковский район, поселок Октябрьская	0101000020E6100000CF49EF1B5F0F4540AF5A99F04B094C40
27004	1	3	1160	54139	34819	\N	56.070807030128798	д. Октябрьская, Советская, 34	Россия, Владимирская область, Вязниковский район, поселок Октябрьская	0101000020E6100000F38DE89E750F4540F8A92A3410094C40
26997	1	3	1160	31447	34760	\N	56.139355999999999	п. Никологоры, Пушкинский переулок, 10		0101000020E6100000DC2BF3565DFF44402D40DB6AD6114C40
26996	1	3	1160	31447	34615	\N	56.139355999999999	п. Никологоры, Базарная, 23		0101000020E6100000DC2BF3565DFF44402D40DB6AD6114C40
26995	1	3	1160	31447	34639	\N	56.139355999999999	п. Никологоры, 2 Пролетарская, 57		0101000020E6100000DC2BF3565DFF44402D40DB6AD6114C40
26980	1	3	1160	30700	34525	\N	56.377930999999997	п. Мстера, площадь Ленина, 9		0101000020E610000035B22B2D23F744408192020B60304C40
26983	1	3	1160	30700	34850	\N	56.2632869991793	поселок станции Мстера, Шоссейная, 12 А	Россия, Владимирская область, Вязниковский район	0101000020E610000065C405A051EE4440213B6F63B3214C40
26981	1	3	1160	30700	34612	\N	56.377930999999997	п. Мстера, Школьная, 4		0101000020E610000035B22B2D23F744408192020B60304C40
26982	1	3	1160	30700	34876	\N	56.377930999999997	п. Мстера, ул. Дзержинского, 8		0101000020E610000035B22B2D23F744408192020B60304C40
26975	1	3	1160	46675	\N	\N	56.270820999999998	д. Малые Удолы, 67		0101000020E6100000AFEE586C931E4540F6083543AA224C40
26993	1	3	1160	47048	35112	\N	56.115985999999999	д. Маловская, Заречная, 1 А		0101000020E610000024D6E25300FC44409D6516A1D80E4C40
26998	1	3	1160	31575	34809	\N	56.184365	п. Лукново, Советская, 2 А		0101000020E61000006FF607CA6D05454076C3B64599174C40
26999	1	3	1160	31575	34877	\N	56.184365	п. Лукново, Центральная, 27		0101000020E61000006FF607CA6D05454076C3B64599174C40
26966	1	3	1160	29990	35109	\N	56.237932000000001	д. Коурково, Школьная, 18		0101000020E61000004209336DFFFE44400056478E741E4C40
26976	1	3	1160	46701	\N	\N	56.329517000000003	д. Козлово, 61		0101000020E610000002D6AA5D130E4540EF3CF19C2D2A4C40
26978	1	3	1160	46742	\N	\N	56.360456999999997	п. Заречный, 41		0101000020E6100000371B2B31CFF84440A04E7974232E4C40
26991	1	3	1160	47011	35148	\N	56.117286	д. Галкино, Советская, 1		0101000020E6100000D099B4A9BAE94440AB23473A030F4C40
26969	1	3	1160	11032	34954	\N	56.242089	г. Вязники, мк-н Нововязники, Южная, 13		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26959	1	3	1160	11032	34714	\N	56.242089	г. Вязники, Стахановская, 23		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26953	1	3	1160	11032	34805	\N	56.242089	г. Вязники, Сенькова, 1/2		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26961	1	3	1160	11032	35084	\N	56.242089	г. Вязники, мк-н Ефимьево, 2 А		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26971	1	3	1160	11032	34807	\N	56.242089	г. Вязники, мк-н Нововязники, Механизаторов, 90		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26883	1	3	1160	11032	34806	\N	56.242089	г. Вязники, Железнодорожная, 33		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26960	1	3	1160	11032	34627	\N	56.242089	г. Вязники, Южная, 41	Россия, Владимирская область, Вязниковский район, Вязники	0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26951	1	3	1160	11032	34711	\N	56.242089	г. Вязники, Чапаевская, 14		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26968	1	3	1160	11032	34582	\N	56.242089	г. Вязники, мк-н Нововязники, Текстильная, 4		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26956	1	3	1160	11032	34483	\N	56.242089	г. Вязники, Свердлова, 15		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26964	1	3	1160	11032	34611	\N	56.242089	г. Вязники, Металлистов, 18		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26958	1	3	1160	11032	34502	\N	56.242089	г. Вязники, Комсомольская, 4 А		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26952	1	3	1160	11032	34804	\N	56.242089	г. Вязники, Киселева, 87		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26931	1	3	1160	11032	34524	\N	56.242089	г. Вязники, мк-к Ефимьево, 1		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26957	1	3	1160	11032	34713	\N	56.242089	г. Вязники, Владимирская, 5		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26955	1	3	1160	11032	34529	\N	56.242089	г. Вязники, Благовещенская, 16		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
26970	1	3	1160	11032	34759	\N	56.242089	г. Вязники, мк-н Нововязники, 1 Шоссейная, 1 А		0101000020E61000008481E7DEC313454055DCB8C5FC1E4C40
27006	1	3	1160	47333	35179	\N	56.158295000000003	д. Воробьевка, Главная, 8		0101000020E61000004AB8904770134540670FB40243144C40
26990	1	3	1160	31173	35008	\N	56.043990000000001	д. Буторлино, Фабричный переулок, 9 А		0101000020E6100000E6762FF7C9E94440EFACDD76A1054C40
27000	1	3	1160	31703	35165	\N	56.170445000000001	д. Большевысоково, Центральная, 32		0101000020E610000065C8B1F50CEF444024624A24D1154C40
26979	1	3	1160	30649	34718	\N	56.388741000000003	с. Барское Татарово, Шибанова, 122		0101000020E6100000D89DEE3CF1F44440A3CEDC43C2314C40
26741	1	3	1160	46611	35217	\N	56.197718999999999	д. Аксёново, Школьная		0101000020E61000002CF3565D873445401F662FDB4E194C40
27178	1	3	12	46091	35242	\N	56.514431000000002	деревня Тургенево, Школьная, 9		0101000020E6100000A2427573F12F4340388600E0D8414C40
26386	1	3	12	1608	34645	\N	56.374366999999999	Владимирская область, Александровский район, город Струнино, Шувалова, 14а		0101000020E6100000E3E0D231E7494340CFD90242EB2F4C40
26389	1	3	12	1608	34646	\N	56.374366999999999	Владимирская область, Александровский район, город Струнино, Заречная, 9		0101000020E6100000E3E0D231E7494340CFD90242EB2F4C40
26385	1	3	12	1608	34593	\N	56.374366999999999	Владимирская область, Александровский район, город Струнино, Фрунзе, 1		0101000020E6100000E3E0D231E7494340CFD90242EB2F4C40
26361	1	3	12	177	34972	\N	56.416823999999998	Владимирская область, Александровский район, Следневское сельское поселение, д.Следнево, Октябрьский квартал, 8		0101000020E61000003F912749D74C43400D18247D5A354C40
26371	1	3	12	812	\N	\N	56.412481999999997	Владимирская область, Александровский район, Андреевское сельское поселение, п.Светлый, сельский клуб		0101000020E61000005EB9DE36536343402618CE35CC344C40
26367	1	3	12	541	\N	\N	56.625678000000001	Владимирская область, Александровский район, Краснопламенское сельское поселение, д.Обашево, здание администрации Краснопламенского сельского поселения	Россия, Владимирская область, Александровский район, поселок Обашево	0101000020E6100000CBA0DAE0443E4340D1E9793716504C40
26358	1	3	12	32443	35101	\N	56.4617	Владимирская область, Александровский район, Следневское сельское поселение, с.Мошнино, Владимирская, 31		0101000020E6100000A4DFBE0E9C6B4340174850FC183B4C40
26375	1	3	12	1026	35121	\N	56.378065999999997	Владимирская область, Александровский район, Андреевское сельское поселение, п.Маяк, Лесная, 1		0101000020E6100000A2410A9E4268434061DD787764304C40
26379	1	3	12	1288	35085	\N	56.268205999999999	Владимирская область, Александровский район, Каринское сельское поселение, с.Махра, Монастырская, 11а		0101000020E6100000CCB56801DA564340A54BFF9254224C40
26370	1	3	12	698	34974	\N	56.425328	Владимирская область, Александровский район, Андреевское сельское поселение, п.Майский, Первомайская, 16		0101000020E610000057B3CEF8BE7043405B09DD2571364C40
26365	1	3	12	409	35061	\N	56.496184999999997	Владимирская область, Александровский район, Краснопламенское сельское поселение, д.Лобково, Кирпичная, 5		0101000020E6100000826F9A3E3B2C434004E275FD823F4C40
26363	1	3	12	310	\N	\N	56.546062999999997	Владимирская область, Александровский район, Краснопламенское сельское поселение, д.Лисавы, здание бывшего детского сада №42	Россия, Владимирская область, Александровский район, поселок Лисавы	0101000020E61000009911DE1E844443401F477364E5454C40
26380	1	3	12	1300	34944	\N	56.295755	Владимирская область, Александровский район, Каринское сельское поселение, д.Лизуново, Мусатова, 54		0101000020E610000022AB5B3D273F43407250C24CDB254C40
26373	1	3	12	909	34869	\N	56.393698000000001	Владимирская область, Александровский район, Андреевское сельское поселение, д.Легково, Весенняя, 3		0101000020E6100000EC67B114C9714340144031B264324C40
26364	1	3	12	340	34905	\N	56.560054000000001	Владимирская область, Александровский район, Краснопламенское сельское поселение, п.Красное Пламя, Клубная, 74		0101000020E6100000206118B0E44443403BFF76D9AF474C40
26383	1	3	12	15	34452	\N	56.311466000000003	Владимирская область, Александровский район, город Карабаново, Вокзальная, 11		0101000020E61000001C615111A759434071E82D1EDE274C40
26381	1	3	12	15	34782	\N	56.311466000000003	Владимирская область, Александровский район, город Карабаново, Торговая площадь, 3		0101000020E61000001C615111A759434071E82D1EDE274C40
26384	1	3	12	15	34684	\N	56.311466000000003	Владимирская область, Александровский район, город Карабаново, Победы, 7		0101000020E61000001C615111A759434071E82D1EDE274C40
26366	1	3	12	488	35015	\N	56.527287000000001	Владимирская область, Александровский район, Краснопламенское сельское поселение, п.Искра, Кооперативная, 1		0101000020E61000001344DD0720314340904DF2237E434C40
26378	1	3	12	1198	\N	\N	56.286872000000002	Владимирская область, Александровский район, Каринское сельское поселение, д.Зеленцино, фельдшерско-акушерский пункт		0101000020E6100000F2D077B7B25E4340AE11C138B8244C40
26372	1	3	12	846	\N	\N	56.391953999999998	Владимирская область, Александровский район, Андреевское сельское поселение, д.Елькино, здание администрации Андреевского сельского поселения	Россия, Владимирская область, Александровский район, поселок Елькино	0101000020E6100000016A6AD95A694340A8C4758C2B324C40
26368	1	3	12	601	\N	\N	56.531937999999997	Владимирская область, Александровский район, Андреевское сельское поселение, с.Долгополье, здание бывшего филиала МОУ Андреевская средняя школа №30	Россия, Владимирская область, Александровский район, поселок Долгополье	0101000020E61000003FFF3D78ED9C4340F4BF5C8B16444C40
26369	1	3	12	693	34991	\N	56.485480000000003	Владимирская область, Александровский район, Андреевское сельское поселение, с.Годуново, Новлянская, 19		0101000020E61000008DB3E908E0844340596E6935243E4C40
26377	1	3	12	1151	34975	\N	56.368734000000003	Владимирская область, Александровский район, Каринское сельское поселение, с.Большое Каринское, Деревенская, 56		0101000020E61000003DBA1116155343402E76FBAC322F4C40
26357	1	3	12	32289	34644	\N	56.504561000000002	Владимирская область, Александровский район, поселок Балакирево, Юго-Западный квартал, 1а		0101000020E6100000DD989EB0C46B434025EB707495404C40
26356	1	3	12	32289	34589	\N	56.504561000000002	Владимирская область, Александровский район, поселок Балакирево, Октябрьская, 2		0101000020E6100000DD989EB0C46B434025EB707495404C40
26355	1	3	12	32289	34498	\N	56.504561000000002	Владимирская область, Александровский район, поселок Балакирево, Вокзальная, 15		0101000020E6100000DD989EB0C46B434025EB707495404C40
26359	1	3	12	32488	34987	\N	56.450324000000002	Владимирская область, Александровский район, Следневское сельское поселение, с.Бакшеево, Центральная, 12		0101000020E610000089CF9D60FF5943404D4D8237A4394C40
26376	1	3	12	1091	35049	\N	56.332380999999998	Владимирская область, Александровский район, Андреевское сельское поселение, д.Бакино, Центральная, 10		0101000020E61000006DACC43C2B7D4340E867EA758B2A4C40
26362	1	3	12	197	\N	\N	56.3839906309762	Владимирская область, Александровский район, Следневское сельское поселение, д.Арсаки, здание администрации Следневского сельского поселения, 110	Россия, Владимирская область, Александровский район, поселок Арсаки	0101000020E61000008864C8B1F53C4340AB7AF99D26314C40
26374	1	3	12	969	34882	\N	56.404179999999997	Владимирская область, Александровский район, Андреевское сельское поселение, с.Андреевское, Советская, 13		0101000020E6100000D5B14AE99980434040D9942BBC334C40
26586	1	3	12	969	35231	\N	56.404179999999997	с. Андреевское, Хивинская, 24		0101000020E6100000D5B14AE99980434040D9942BBC334C40
26354	1	3	12	9113	34512	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Советская, 25а		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26335	1	3	12	9113	34868	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Парковая, 1		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26345	1	3	12	9113	34509	\N	56.392387999999997	г.Александров, ул. Ленина, д.24, (Центр детского творчества, 1 этаж)		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26339	1	3	12	9113	34643	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Кубасова, 10		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26343	1	3	12	9113	34729	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Ческа-Липа, 5		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26341	1	3	12	9113	34731	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Терешковой, 5		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26336	1	3	12	9113	34587	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Стрелецкая набережная, 1		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26350	1	3	12	9113	34601	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Перфильева, 3а		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26349	1	3	12	9113	34592	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Первомайская, 89		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26353	1	3	12	9113	34781	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Маяковского, 30		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26351	1	3	12	9113	34728	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Ленина, 5		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26344	1	3	12	9113	34461	\N	56.393625902693699	Владимирская область, Александровский район, город Александров, Красный переулок, 8	Россия, Владимирская область, Александровский район, Александров	0101000020E61000002BBD361B2B5D43407A6D365662324C40
26333	1	3	12	9113	34585	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Двориковское шоссе, 1		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26332	1	3	12	9113	34496	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Геологов, 1		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26342	1	3	12	9113	34590	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Гагарина, 19		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26334	1	3	12	9113	34449	\N	56.392387999999997	Владимирская область, Александровский район, город Александров, Восстания 1905 года, 3		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
26390	1	3	12	9113	74922	\N	56.391171999999997	г. Александров, ул. Вокзальная, д. 10 / железнодорожный вокзал г. Александров		0101000020E6100000CCD3B9A2945C4340328E91EC11324C40
26338	1	3	12	9113	34510	\N	56.392387999999997	"Владимирская область, Александровский район, город Александров, Базунова, стадион ""Рекорд"""		0101000020E6100000B4E4F1B4FC5C4340E2AB1DC539324C40
24621	1	2	\N	12390	24509	\N	53.213779000000002	Брянская область, Брянский муниципальный район, Супоневское сельское поселение, с.Супонево, ул.Чувиной, д.35		0101000020E61000002DCF83BBB32A41402AC93A1C5D9B4A40
24624	1	2	\N	12390	24888	\N	53.213779000000002	"Брянская область, Брянский муниципальный район, Супоневское сельское поселение, с.Супонево, ул.Советская, д.10 ""а"""		0101000020E61000002DCF83BBB32A41402AC93A1C5D9B4A40
25256	1	2	\N	10879	25057	\N	53.371693	Брянская область, город Сельцо, ул.Школьная, 25		0101000020E610000036E49F19C40941407993DFA293AF4A40
25254	1	2	\N	10879	24452	\N	53.371693	Брянская область, город Сельцо, ул.Мейпариани, 15		0101000020E610000036E49F19C40941407993DFA293AF4A40
25251	1	2	\N	10879	24452	\N	53.371693	Брянская область, город Сельцо, ул.Мейпариани, 17		0101000020E610000036E49F19C40941407993DFA293AF4A40
25249	1	2	\N	10879	24452	\N	53.371693	Брянская область, город Сельцо, пер.Мейпариани, 2		0101000020E610000036E49F19C40941407993DFA293AF4A40
24736	1	2	\N	10879	75041	\N	53.366395891958803	деревня Сельцо, Ленина, 6 (здание Дома культуры)	Россия, Брянская область, Сельцо	0101000020E610000095641D8EAE0C41404FB16A10E6AE4A40
25252	1	2	\N	10879	24908	\N	53.371693	Брянская область, город Сельцо, ул.Куйбышева, 19		0101000020E610000036E49F19C40941407993DFA293AF4A40
25250	1	2	\N	10879	24908	\N	53.371693	Брянская область, город Сельцо, ул.Куйбышева, 30		0101000020E610000036E49F19C40941407993DFA293AF4A40
25253	1	2	\N	10879	24829	\N	53.371693	Брянская область, город Сельцо, ул.Горького, 14		0101000020E610000036E49F19C40941407993DFA293AF4A40
25255	1	2	\N	10879	24579	\N	53.3679819261462	Брянская область, город Сельцо, ул.Брянская, 2	Россия, Брянская область, Сельцо	0101000020E6100000707D586FD40C414022C2BF081AAF4A40
25158	1	2	\N	51076	24890	\N	52.941981456514199	г.Почеп, Мира, 62	Россия, Брянская область, Почепский район, Почеп	0101000020E61000009B560A815CBA4040083A5AD592784A40
24610	1	2	\N	51030	\N	\N	53.382547843017399	п. Новые дарковичи, Новодарковичская средняя школа	Россия, Брянская область	0101000020E610000015E126A3CA2841403A933655F7B04A40
25507	1	2	\N	1088	\N	\N	52.533774537513203	(48343)91-5-10	Россия, Брянская область, Новозыбков	0101000020E6100000999F1B9AB2EF3F4011363CBD52444A40
25099	1	2	\N	1088	24758	\N	52.543153105389003	Брянская область, город Новозыбков, ул. Синицына, 67		0101000020E610000054E23AC615EF3F40B5DC990986454A40
25091	1	2	\N	1088	25154	\N	52.530397527089697	Брянская область, городНовозыбков, ул. Садовая, 58	Россия, Брянская область, Новозыбков городской округ	0101000020E610000040F850A225EF3F4091EEE714E4434A40
25088	1	2	\N	1088	24550	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Садовая, 30		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25096	1	2	\N	1088	24602	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Рошаля, 25		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25098	1	2	\N	1088	24721	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Наримановская, 136		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25083	1	2	\N	1088	24792	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Мичурина, 59		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25084	1	2	\N	1088	24834	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Ломоносова, 39-А		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25089	1	2	\N	1088	25064	\N	52.534351096625201	Брянская область, город Новозыбков, ул. Ленина, 13	Россия, Брянская область, Новозыбков	0101000020E61000009FE6E44526F03F40DECA129D65444A40
25087	1	2	\N	1088	25064	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Ленина, 59		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25097	1	2	\N	1088	24931	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Красногвардейская, 70		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25094	1	2	\N	1088	24506	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Красная, 136-А		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25090	1	2	\N	1088	24506	\N	52.543506326249997	Брянская область, город Новозыбков, ул. Красная, 2	Россия, Брянская область, Новозыбков городской округ	0101000020E610000078EE3D5C72E83F400397C79A91454A40
25092	1	2	\N	1088	24818	\N	52.534925999999999	Брянская область, город Новозыбков, ул. Коммунистическая, 20		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25085	1	2	\N	1088	24612	\N	52.525004176389999	Брянская область, город Новозыбков, ул. Голодеда, 22	Россия, Брянская область, Новозыбков городской округ	0101000020E61000009AEB34D252F13F407522C15433434A40
25093	1	2	\N	1088	24656	\N	52.535682469306998	Брянская область, город Новозыбков, ул. Воровского, 16	Россия, Брянская область, Новозыбков городской округ	0101000020E6100000EE26F8A6E9EB3F4027874F3A91444A40
25086	1	2	\N	1088	25075	\N	52.534925999999999	Брянская область, город Новозыбков, Вокзальная, 24-А		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25100	1	2	\N	1088	24932	\N	52.534925999999999	Брянская область, город Новозыбков, 114 квартал, здание филиала НГЦБС № 3		0101000020E61000008FAB915D69F13F40DAE3857478444A40
25049	1	2	\N	51061	24707	\N	53.050721000000003	г. Мглин, пл. Советская, д. 4		0101000020E61000006CE9D1544F6C4040371C96067E864A40
24950	1	2	\N	22579	24450	\N	52.755476000000002	город Клинцы, пр. Ленина, 70		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24945	1	2	\N	22579	24450	\N	52.755476000000002	город Клинцы, пр-т Ленина, 29		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24943	1	2	\N	22579	24450	\N	52.755476000000002	город Клинцы, пр-т Ленина, 23		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24963	1	2	1279	\N	24832	\N	52.736129625835602	город Клинцы, Станционная, 3	Россия, Брянская область, Клинцовский район	0101000020E610000059C0046EDD1D404060CD0182395E4A40
24923	1	2	\N	22579	24514	\N	52.755476000000002	город Клинцы, Свердлова, 152		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24946	1	2	7100	\N	24652	\N	52.754527622475599	город Клинцы, Пушкина, 24	Россия, Брянская область, Клинцы городской округ	0101000020E610000038F581E49D1D404049F59D5F94604A40
24828	1	2	\N	22579	24679	\N	52.760071696592199	город Клинцы, Площадь Свободы, 26	Россия, Брянская область, Клинцы городской округ	0101000020E6100000B340BB438A1D40407B4D0F0A4A614A40
24887	1	2	\N	22579	24608	\N	52.752247625741802	город Клинцы, Первомайская, 57	Россия, Брянская область, Клинцы	0101000020E6100000DD425722501F40409F3D97A949604A40
24948	1	2	\N	22579	24533	\N	52.755521930393499	город Клинцы, Октябрьская, 66	Россия, Брянская область, Клинцы городской округ	0101000020E6100000EE9579ABAE1D40404AB4E4F1B4604A40
24947	1	2	\N	22579	24533	\N	52.762623001667897	город Клинцы, Октябрьская, 29	Россия, Брянская область, Клинцы городской округ	0101000020E6100000857D3B89081D4040B51666A19D614A40
24944	1	2	\N	22579	24533	\N	52.747898862684799	город Клинцы, Октябрьская, 27	Россия, Брянская область, Клинцы городской округ	0101000020E6100000DDD0949D7E1E404005DB8827BB5F4A40
24955	1	2	\N	22579	24499	\N	52.755476000000002	город Клинцы, Мира, 95		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24954	1	2	\N	22579	24499	\N	52.755476000000002	город Клинцы, Мира, 111		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24957	1	2	\N	22579	24412	\N	52.755476000000002	город Клинцы, Калинина, 155		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24951	1	2	\N	22579	24412	\N	52.762479820157097	город Клинцы, Калинина, 139	Россия, Брянская область, Клинцы городской округ	0101000020E61000007427D87F9D1F404052EDD3F198614A40
24949	1	2	\N	22579	24412	\N	52.759180006082801	город Клинцы, Калинина, 137	Россия, Брянская область, Клинцы	0101000020E61000009BADBCE47F2040407EE36BCF2C614A40
24874	1	2	\N	22579	25074	\N	52.755476000000002	город Клинцы, Декабристов, 20а		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24956	1	2	\N	22579	24921	\N	52.755476000000002	город Клинцы, Ворошилова, 3		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24952	1	2	\N	22579	24921	\N	52.755476000000002	город Клинцы, Ворошилова, 44а		0101000020E6100000CA8B4CC0AF1F4040DA740470B3604A40
24469	1	2	\N	1655	25280	\N	53.334069999999997	Брянская область, город Брянск, Шоссейная, 63		0101000020E6100000302B14E97E1C4140904946CEC2AA4A40
24823	1	2	\N	51057	24681	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Советская, 45		0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24505	1	2	\N	1655	\N	\N	53.250060375877197	"Брянская область, город Брянск, п. Снежка ""Центр детского и юношеского туризма и экскурсий"""	Россия, Брянская область, Брянск, Володарский район	0101000020E6100000B3D2A41474334140D50451F701A04A40
24453	1	2	\N	1655	1106	\N	53.307918000000001	Брянская область, город Брянск, 22 съезда КПСС, 98	Россия, Брянская область, Брянск, улица ХХII Съезда КПСС, 98	0101000020E61000009964E42CEC234140C4EC65DB69A74A40
24540	1	2	\N	1655	992	\N	53.218384	Брянская область, город Брянск, ул.Фрунзе, 80а		0101000020E61000002BF697DD932941401EFCC401F49B4A40
24498	1	2	\N	1655	1764	\N	53.249575	Брянская область, город Брянск, ул. Фосфоритная, 9	Россия, Брянская область, Брянск, улица Фосфоритная, 9	0101000020E61000007BF65CA6263941401973D712F29F4A40
24518	1	2	\N	1655	1997	\N	53.245302000000002	Брянская область, город Брянск, ул.Фокина, 56	Россия, Брянская область, Брянск, улица Фокина, 56	0101000020E610000026396057932D41405BD2510E669F4A40
24472	1	2	\N	1655	1403	\N	53.282924000000001	Брянская область, город Брянск, Федюнинского, 15	Россия, Брянская область, Брянск, улица Федюнинского, 15	0101000020E6100000ACAA97DF6924414073A087DA36A44A40
24451	1	2	\N	1655	1071	\N	53.313011130431903	Брянская область, город Брянск, Ульянова, 118	Россия, Брянская область, Брянск, улица Ульянова, 116	0101000020E610000012A27C410B254140E62494BE10A84A40
24501	1	2	\N	1655	1754	\N	53.251837999999999	Брянская область, городской округ Брянск, ул. Тельмана, 109В	Россия, Брянская область, Брянск, улица Тельмана, 109в	0101000020E61000006B2DCC423B394140EDF1423A3CA04A40
24484	1	2	\N	1655	1543	\N	53.271325312403	Брянская область, город Брянск, ул. Пушкина, 59	Россия, Брянская область, Брянск, улица Пушкина, 57	0101000020E610000080D591239D33414029CB10C7BAA24A40
24549	1	2	\N	1655	2474	\N	53.215564000000001	Брянская область, город Брянск, Фокинский район, улица Полесская, дом 83		0101000020E6100000FDBCA94885314140F418E599979B4A40
24449	1	2	\N	1655	1040	\N	53.327471000000003	Брянская область, город Брянск, Отрадная, 23	Россия, Брянская область, Брянск, улица Отрадная, 23	0101000020E6100000DECA129D651C4140B8B1D991EAA94A40
24468	1	2	\N	1655	1326	\N	53.303710000000002	Брянская область, город Брянск, Орловская, 26А	Россия, Брянская область, Брянск, улица Орловская, 26	0101000020E6100000DFC2BAF1EE244140EDBB22F8DFA64A40
24546	1	2	\N	1655	2442	\N	53.218933999999997	Брянская область, город Брянск, Фокинский район, улица Олега Кошевого, дом 36	Россия, Брянская область, Брянск, улица Олега Кошевого, 30	0101000020E61000003E03EACDA8334140C1FD8007069C4A40
25348	1	2	\N	1655	3400	\N	53.303941000000002	Брянская область, Суражский район, с.Косичи, ул.Молодежная, д.8	Россия, Брянская область, Брянск, улица Молодежная, 10	0101000020E61000002F51BD35B0274140EF74E789E7A64A40
24459	1	2	\N	1655	1203	\N	53.3001564011862	Брянская область, город Брянск, Ленинградская, 24	Россия, Брянская область, Брянск, улица Ленинградская, 16	0101000020E61000004E7E8B4E962641405ED905836BA64A40
24450	1	2	\N	1655	1063	\N	53.318005594765403	Брянская область, город Брянск, Кромская, 48А	Россия, Брянская область, Брянск, улица Кромская	0101000020E61000004DA3C9C51824414044F7AC6BB4A84A40
24480	1	2	\N	1655	24692	\N	53.277508837937603	Брянская область, город Брянск, ул. Академика Королева, 1А	Россия, Брянская область, Брянск, улица Королева, 1а	0101000020E6100000ECBDF8A23D3241403FAC376A85A34A40
24442	1	2	\N	1655	919	\N	53.323551000000002	Брянская область, город Брянск, Коммунистическая, 136	Россия, Брянская область, Брянск, улица Коммунистическая, 134	0101000020E6100000325A47551324414047CB811E6AA94A40
24443	1	2	\N	1655	931	\N	53.328848000000001	Брянская область, город Брянск, Клинцовская, 61	Россия, Брянская область, Брянск, улица Клинцовская, 61	0101000020E61000006BB933130C25414071ADF6B017AA4A40
24542	1	2	\N	1655	2385	\N	53.225199000000003	Брянская область, город Брянск, ул.Карачижская, 2б	Россия, Брянская область, Брянск, улица Карачижская, 2б	0101000020E610000090A16307952C4140C40B2252D39C4A40
24461	1	2	\N	1655	1122	\N	53.30498	Брянская область, город Брянск, Институтская, 16	Россия, Брянская область, Брянск, улица Институтская, 16	0101000020E610000087FA5DD89A25414090F7AA9509A74A40
24510	1	2	\N	1655	1893	\N	53.254494000000001	Брянская область, город Брянск, ул.Дуки, 2	Россия, Брянская область, Брянск, улица Дуки, 2	0101000020E610000032207BBDFB2F41409D83674293A04A40
24555	1	2	\N	1655	2577	\N	53.203851	Брянская область, город Брянск, Фокинский район, улица Дзержинского, дом 47	Россия, Брянская область, Брянск, улица Дзержинского, 47	0101000020E61000009A94826E2F354140E22021CA179A4A40
24474	1	2	\N	1655	1440	\N	53.299066000000003	Брянская область, город Брянск, Делегатская, 72	Россия, Брянская область, Брянск, улица Делегатская, 74	0101000020E6100000E3DF675C382041403BAC70CB47A64A40
24448	1	2	\N	1655	1026	\N	53.335726000000001	Брянская область, город Брянск, Вокзальная, 162	Россия, Брянская область, Брянск, улица Вокзальная, 162	0101000020E6100000B7D5AC33BE1F41405D35CF11F9AA4A40
24506	1	2	\N	1655	1396	\N	53.272112	Брянская область, город Брянск, ул.Бежицкая, 14	Россия, Брянская область, Брянск, улица Бежицкая, 14	0101000020E6100000D9791B9B1D2D4140B16CE690D4A24A40
24479	1	2	\N	1655	1511	\N	53.279257000000001	Брянская область, город Брянск, ул. Афанасьева, 26	Россия, Брянская область, Брянск, улица Афанасьева, 26	0101000020E61000002FA4C34318334140EC1681B1BEA34A40
24513	1	2	\N	1655	25275	\N	53.251497999999998	Брянская область, город Брянск, ул.Ямская, 21		0101000020E61000003370404B573041403481221631A04A40
24496	1	2	\N	1655	25235	\N	53.255555000000001	Брянская область, город Брянск, ул. Чернышевского, 23		0101000020E6100000555051F52B39414026AAB706B6A04A40
24560	1	2	\N	1655	25171	\N	53.211683309982	Брянская область, город Брянск, Фокинский район, улица Челюскинцев, дом 2	Россия, Брянская область, Брянск, улица Жилстроя	0101000020E6100000B8CCE9B298364140410FB56D189B4A40
25398	1	2	\N	1655	25195	\N	53.237273000000002	ул.Центральная д.69		0101000020E610000004AC55BB26404140A69C2FF65E9E4A40
24503	1	2	\N	1655	25195	\N	53.237529966766601	Брянская область, город Брянск, ул. Центральная, 72		0101000020E61000001FBC7669C33F4140D1E80E62679E4A40
24463	1	2	\N	1655	25254	\N	53.305798000000003	Брянская область, город Брянск, 22 съезда КПСС, 6		0101000020E61000004DF6CFD38027414053978C6324A74A40
24458	1	2	\N	1655	25254	\N	53.306319999999999	Брянская область, город Брянск, 22 съезда КПСС, 25		0101000020E6100000B2D7BB3FDE2541402C0E677E35A74A40
24515	1	2	\N	1655	25288	\N	53.253072000000003	Брянская область, город Брянск, ул.Фокина, 108а		0101000020E61000007B849A21552C414044C4CDA964A04A40
24473	1	2	\N	1655	25192	\N	53.289249796807297	Брянская область, город Брянск, Федюнинского, 1		0101000020E6100000F086342A702441401B2FDD2406A54A40
24554	1	2	\N	1655	2567	\N	53.204024040128097	Брянская область, город Брянск, Фокинский район, проезд Трофименко, дом 12	Россия, Брянская область, Брянск, Трофименко проезд, 10	0101000020E6100000D1915CFE43324140AFCC5B751D9A4A40
24500	1	2	\N	1655	25218	\N	53.252128999999996	Брянская область, город Брянск, ул. Тельмана, 78		0101000020E61000001CCD91955F3A4140C4AF58C345A04A40
24497	1	2	\N	1655	25218	\N	53.251837999999999	Брянская область, город Брянск, ул. Тельмана, 109В		0101000020E61000006B2DCC423B394140EDF1423A3CA04A40
24493	1	2	\N	1655	25241	\N	53.255873000000001	Брянская область, город Брянск, ул. Суворова, 2Б		0101000020E610000014AE47E17A364140F7764B72C0A04A40
24539	1	2	\N	1655	24433	\N	53.223476335862699	Брянская область, город Брянск, пр.Ст.Димитрова, 73	Россия, Брянская область, Брянск, Станке Димитрова проспект, 73	0101000020E61000003C86C77E162941406FB88FDC9A9C4A40
24538	1	2	\N	1655	24433	\N	53.238289490447997	Брянская область, город Брянск, пр.Ст.Димитрова, 39	Россия, Брянская область, Брянск, Станке Димитрова проспект, 39	0101000020E610000076FC1708022A41408FFF0241809E4A40
24532	1	2	\N	1655	24433	\N	53.249153058669002	Брянская область, город Брянск, пр.Ст.Димитрова, 3	Россия, Брянская область, Брянск, Станке Димитрова проспект, 3	0101000020E61000009450FA42C82B4140A359D93EE49F4A40
24541	1	2	\N	1655	25260	\N	53.229036999999998	Брянская область, город Брянск, ул.Спартаковская, 112		0101000020E61000005C3D27BD6F2A414077499C15519D4A40
24517	1	2	\N	1655	25194	\N	53.246375787738302	Брянская область, город Брянск, ул.Советская, 2а	Россия, Брянская область, Брянск, Трудовой переулок	0101000020E610000014083BC5AA2D41407842AF3F899F4A40
24516	1	2	\N	1655	25194	\N	53.249645000000001	Брянская область, городской округ Брянск, ул.Советская, 35		0101000020E61000005A48C0E8F22C4140124E0B5EF49F4A40
24514	1	2	\N	1655	25194	\N	53.257553999999999	Брянская область, город Брянск, ул.Советская, 79		0101000020E6100000CBA145B6F32B41401C7A8B87F7A04A40
24444	1	2	\N	1655	948	\N	53.332929999999998	Брянская область, город Брянск, Северный, 58	Россия, Брянская область, Брянск, Северный переулок, 58	0101000020E610000008E6E8F17B254140BBED42739DAA4A40
24488	1	2	\N	1655	25255	\N	53.264727999999998	Брянская область, город Брянск, ул. Пушкина, 23		0101000020E61000005F7B664980344140F12A6B9BE2A14A40
24482	1	2	\N	1655	25255	\N	53.277168000000003	Брянская область, город Брянск, ул. Пушкина, 74		0101000020E61000001F85EB51B8324140B6BFB33D7AA34A40
24485	1	2	\N	1655	25269	\N	53.272790000000001	Брянская область, город Брянск, ул. Профсоюзов, 24		0101000020E6100000F12F82C64C344140825660C8EAA24A40
24464	1	2	\N	1655	25271	\N	53.298586999999998	Брянская область, город Брянск, Протасова, 1		0101000020E6100000FC1873D71228414060014C1938A64A40
24477	1	2	\N	1655	24968	\N	53.343032000000001	Брянская область, город Брянск, Почтовая, 110		0101000020E6100000E5F1B4FCC0274140A1BDFA78E8AB4A40
24437	1	2	\N	1655	24968	\N	53.311613999999999	Брянская область, город Брянск, Почтовая, 4		0101000020E6100000B492567C43294140E57CB1F7E2A74A40
24436	1	2	\N	1655	24968	\N	53.314562000000002	Брянская область, город Брянск, Почтовая, 26		0101000020E61000005DA5BBEB6C2841403D484F9143A84A40
24434	1	2	\N	1655	24968	\N	53.340242000000003	Брянская область, город Брянск, Почтовая, 100		0101000020E610000002BA2F67B6274140E25CC30C8DAB4A40
24433	1	2	\N	1655	24968	\N	53.344698999999999	Брянская область, город Брянск, Почтовая, 67		0101000020E61000004628B682A627414061FBC9181FAC4A40
24432	1	2	\N	1655	24968	\N	53.345570000000002	Брянская область, город Брянск, Почтовая, 71		0101000020E6100000D3F544D785274140473D44A33BAC4A40
24556	1	2	\N	1655	25251	\N	53.200964999999997	Брянская область, город Брянск, Фокинский район, улица Победы, дом 5		0101000020E610000074F04C689236414000529B38B9994A40
24508	1	2	\N	1655	25287	\N	53.257511000000001	Брянская область, город Брянск, ул.Петрова, 4		0101000020E61000008925E5EE732E41401DAED51EF6A04A40
24529	1	2	\N	1655	25237	\N	53.237887000000001	Брянская область, город Брянск, ул.Пересвета, 3		0101000020E610000017618A72692C41406092CA14739E4A40
24528	1	2	\N	1655	2162	\N	53.233871999999998	Брянская область, город Брянск, пл.Партизан, 6	Россия, Брянская область, Брянск, Партизан площадь, 4	0101000020E6100000D89C8367422D41409DB98784EF9D4A40
24530	1	2	\N	1655	2180	\N	53.243341000000001	Брянская область, город Брянск, пер.Осоавиахима, 3а	Россия, Брянская область, Брянск, Осоавиахима переулок, 3а	0101000020E6100000DA8D3EE6032C4140526342CC259F4A40
24502	1	2	\N	1655	25230	\N	53.358572000000002	Брянская область, город Брянск, ул. Орджоникидзе, 2А		0101000020E61000008ECD8E54DF27414073A1F2AFE5AD4A40
24553	1	2	\N	1655	25183	\N	53.215397000000003	Брянская область, город Брянск, Фокинский район, улица Олега Кошевого, дом 69		0101000020E6100000CBD6FA22A13341400954FF20929B4A40
24526	1	2	\N	1655	25265	\N	53.236722999999998	Брянская область, город Брянск, ул.Октябрьская, 14		0101000020E6100000C2BF081A332D4140029B73F04C9E4A40
24511	1	2	\N	1655	25265	\N	53.253458999999999	Брянская область, город Брянск, ул.Октябрьская, 135		0101000020E6100000F52F49658A2F41403DF0315871A04A40
24439	1	2	\N	1655	25261	\N	53.322954000000003	Брянская область, город Брянск, Окружная, 13		0101000020E6100000B81E85EB51264140630E828E56A94A40
24567	1	2	\N	1655	25189	\N	53.209007	Брянская область, город Брянск, Фокинский район, улица Новозыбковская, дом 20		0101000020E61000005C9198A0863941404AD1CABDC09A4A40
24565	1	2	\N	1655	25189	\N	53.209119999999999	Брянская область, город Брянск, Фокинский район, улица Новозыбковская, дом 7Б		0101000020E6100000A93121E6923841404278B471C49A4A40
24440	1	2	\N	1655	25253	\N	53.324432999999999	Брянская область, город Брянск, Ново-Советская, 82		0101000020E610000031EC3026FD254140205F420587A94A40
24435	1	2	\N	1655	25253	\N	53.321969000000003	Брянская область, город Брянск, Ново-Советская, 48		0101000020E6100000C4EC65DB69274140B5A9BA4736A94A40
24491	1	2	\N	1655	25157	\N	53.265918999999997	Брянская область, город Брянск, ул. Никитина, 19		0101000020E61000005F9A22C0E9354140483140A209A24A40
24447	1	2	\N	1655	25268	\N	53.326197000000001	Брянская область, город Брянск, Нахимова, 124		0101000020E6100000BB9A3C6535234140D386C3D2C0A94A40
24568	1	2	\N	1655	2445	\N	53.2087269704802	Брянская область, город Брянск, Фокинский район, проспект Московский, дом 103	Россия, Брянская область, Брянск, Московский проспект, 101	0101000020E61000000E6ABFB5133B41406765FB90B79A4A40
24564	1	2	\N	1655	2445	\N	53.210920999999999	Брянская область, город Брянск, Фокинский район, проспект Московский, дом 88А		0101000020E61000005891D1014938414012859675FF9A4A40
24562	1	2	\N	1655	2445	\N	53.213154000000003	Брянская область, город Брянск, Фокинский район, проспект Московский, дом 64	Россия, Брянская область, Брянск, Московский проспект, 64	0101000020E6100000452C62D8613641407C8159A1489B4A40
24552	1	2	\N	1655	2445	\N	53.215626990908802	Брянская область, город Брянск, Фокинский район, проспект Московский, дом 46А		0101000020E6100000723271AB203441403A9160AA999B4A40
24547	1	2	\N	1655	2445	\N	53.219047000000003	Брянская область, город Брянск, Фокинский район, проспект Московский, дом 3	Россия, Брянская область, Брянск, Московский проспект, 3	0101000020E6100000E9D500A5A1324140BAA46ABB099C4A40
24465	1	2	\N	1655	24690	\N	53.2465545697656	Брянская область, город Брянск, Московский м/район, 56	Россия, Брянская область, Брянск, Володарский район	0101000020E6100000309E4143FF34414028D53E1D8F9F4A40
24478	1	2	\N	1655	25149	\N	53.295054479481799	Брянская область, город Брянск, Московский м/р-н, 56	Россия, Брянская область, Брянск, Бежицкий район	0101000020E6100000B075A911FA274140E9465854C4A54A40
24409	1	2	\N	1655	25243	\N	53.330983000000003	Брянская область, город Брянск, Молодой Гвардии, 73А		0101000020E610000020D3DA34B62541401844A4A65DAA4A40
24489	1	2	\N	1655	25226	\N	53.2693845354991	Брянская область, город Брянск, ул. Мичурина, 27А		0101000020E61000000B992B836A35414038842A357BA24A40
24563	1	2	\N	1655	25236	\N	53.210889000000002	ул.Менжинского д.6		0101000020E61000008CF4A276BF364140070B2769FE9A4A40
24561	1	2	\N	1655	25236	\N	53.210889000000002	Брянская область, город Брянск, Фокинский район, улица Менжинского, дом 6		0101000020E61000008CF4A276BF364140070B2769FE9A4A40
24456	1	2	\N	1655	25234	\N	53.311011000000001	Брянская область, город Брянск, Медведева, 20		0101000020E6100000DB87BCE5EA2541401FD95C35CFA74A40
24446	1	2	\N	1655	25262	\N	53.330342999999999	Брянская область, город Брянск, Марии Ульяновой, 1		0101000020E61000002EAA45443123414034BBEEAD48AA4A40
24462	1	2	\N	1655	25219	\N	53.310675875604304	Брянская область, город Брянск, Майской Стачки, 6	Россия, Брянская область, Брянск, улица Майской Стачки, 5	0101000020E61000002D23F59ECA27414078D32D3BC4A74A40
24476	1	2	\N	1655	754	\N	53.359904	Брянская область, город Брянск, Магистральный, 1		0101000020E61000006B47718E3A2841408CD9925511AE4A40
24431	1	2	\N	1655	754	\N	53.359904	Брянская область, город Брянск, пер.Магистральный, 1	Россия, Брянская область, Брянск, Магистральный переулок	0101000020E61000006B47718E3A2841408CD9925511AE4A40
24527	1	2	\N	1655	25249	\N	53.232109000000001	Брянская область, город Брянск, ул.Луначарского, 7		0101000020E6100000EFC9C342AD2D4140BB0D6ABFB59D4A40
24521	1	2	\N	1655	25249	\N	53.239826999999998	Брянская область, город Брянск, ул.Луначарского, 41		0101000020E610000067994528B62E414051D9B0A6B29E4A40
24445	1	2	\N	1655	25201	\N	53.328225997186202	Брянская область, город Брянск, Литейная, 29	Россия, Брянская область, Брянск, улица Литейная	0101000020E6100000B0C56E9F5524414034D93F4F03AA4A40
24524	1	2	\N	1655	964	\N	53.237245999999999	Брянская область, город Брянск, пр.Ленина, 7	Россия, Брянская область, Брянск, Ленина проспект, 7	0101000020E6100000F3936A9F8E2D4140AC8DB1135E9E4A40
24512	1	2	\N	1655	964	\N	53.251105000000003	Брянская область, город Брянск, пр.Ленина, 72	Россия, Брянская область, Брянск, Ленина проспект, 72	0101000020E6100000B30B06D7DC2F4140596E693524A04A40
24455	1	2	\N	1655	25167	\N	53.309369643129997	Брянская область, город Брянск, Куйбышева, 101А	Россия, Брянская область, Брянск, улица Куйбышева, 103	0101000020E610000033E02C25CB234140882EA86F99A74A40
24558	1	2	\N	1655	25216	\N	53.203836725402503	Брянская область, город Брянск, Фокинский район, улица Красных Партизан, дом 35	Россия, Брянская область, Брянск, улица Красных Партизан	0101000020E61000000072C284D13441407D5BB054179A4A40
24531	1	2	\N	1655	25258	\N	53.240636000000002	Брянская область, город Брянск, ул.Красноармейская, 79		0101000020E61000000742B280092C4140C11E1329CD9E4A40
24523	1	2	\N	1655	25258	\N	53.232275999999999	Брянская область, город Брянск, ул.Красноармейская, 13		0101000020E610000012BC218D0A2E4140A6D24F38BB9D4A40
24536	1	2	\N	1655	25240	\N	53.263576	Брянская область, город Брянск, ул.Костычева, 57		0101000020E61000000DA7CCCD372A41405801BEDBBCA14A40
24467	1	2	\N	1655	25272	\N	53.307755999999998	Брянская область, город Брянск, пос.Р-Крыловка, Комсомольская, 2		0101000020E6100000D882DE1B43284140EA92718C64A74A40
24438	1	2	\N	1655	24951	\N	53.313530973217397	Брянская область, город Брянск, Клубная, 5		0101000020E61000009752978C632841401EA4A7C821A84A40
25426	1	2	1139	16687	24574	\N	52.845708000000002	г. Унеча, Первомайская, 22		0101000020E6100000F92F1004C856404098FBE428406C4A40
24379	1	2	\N	1655	25250	\N	53.330584999999999	Брянская область, город Брянск, Клинцовская, 60		0101000020E6100000C84109336D2541402AC6F99B50AA4A40
24441	1	2	\N	1655	25187	\N	53.323769113738201	Брянская область, город Брянск, Кирова, 118А	Россия, Брянская область, Брянск, улица Кирова	0101000020E6100000804A95287B254140B43A394371A94A40
24551	1	2	\N	1655	25273	\N	53.215769000000002	Брянская область, город Брянск, Фокинский район, улица Киевская, дом 20		0101000020E61000008E03AF963B334140CD3E8F519E9B4A40
24550	1	2	\N	1655	25273	\N	53.216939000000004	Брянская область, город Брянск, Фокинский район, улица Киевская, дом 38		0101000020E6100000B8E4B8533A3241400D1D3BA8C49B4A40
24522	1	2	\N	1655	25233	\N	53.23724	Брянская область, город Брянск, ул.Калинина, 66		0101000020E61000009CC1DF2F662F4140CAA65CE15D9E4A40
24454	1	2	\N	1655	25165	\N	53.304377000000002	Брянская область, город Брянск, Институтская, 141		0101000020E61000006F6589CE32274140CA5356D3F5A64A40
24504	1	2	\N	1655	24672	\N	53.247016604205903	Брянская область, город Брянск, ул. Инженерная, 12	Россия, Брянская область, Брянск, поселок Большое Полпино	0101000020E6100000B665C0594A4241402C47C8409E9F4A40
24475	1	2	\N	1655	25220	\N	53.305274379169497	Брянская область, город Брянск, Ильича, 4		0101000020E6100000D253E410711B4140D828EB3713A74A40
24495	1	2	\N	1655	25190	\N	53.259391000000001	Брянская область, город Брянск, Есенина, 20	Россия, Брянская область, Брянск, улица Есенина, 18	0101000020E6100000D9AF3BDD7938414039F06AB933A14A40
24494	1	2	\N	1655	25190	\N	53.259391000000001	Брянская область, город Брянск, ул. Есенина, 20		0101000020E6100000D9AF3BDD7938414039F06AB933A14A40
24548	1	2	\N	1655	24879	\N	53.219464157248701	Брянская область, город Брянск, Фокинский район, улица Ермакова, дом 30		0101000020E6100000E21DE0490B3341401E537765179C4A40
24507	1	2	\N	1655	25274	\N	53.266764000000002	Брянская область, город Брянск, ул.Дуки, 74		0101000020E6100000DC7F643A742E414005E09F5225A24A40
24492	1	2	\N	1655	25231	\N	53.258732999999999	Брянская область, город Брянск, ул. Димитрова, 46		0101000020E6100000F9F36DC152354140AFB2B6291EA14A40
24486	1	2	\N	1655	25231	\N	53.268757000000001	Брянская область, город Брянск, ул. Димитрова, 112		0101000020E6100000C712D6C6D833414019C91EA166A24A40
24559	1	2	\N	1655	25224	\N	53.211163999999997	Брянская область, город Брянск, Фокинский район, улица Дзержинского, дом 2А		0101000020E610000022C7D63384354140D80B056C079B4A40
24557	1	2	\N	1655	25224	\N	53.204002000000003	Брянская область, город Брянск, Фокинский район, улица Дзержинского, дом 32		0101000020E6100000B14E95EF19354140C828CFBC1C9A4A40
24520	1	2	\N	1655	25259	\N	53.244121999999997	Брянская область, город Брянск, ул.Горького, 20		0101000020E61000005A2A6F47382F4140F71DC3633F9F4A40
24466	1	2	\N	1655	1295	\N	53.328879999999998	Брянская область, город Брянск, пос.Р-Крыловка, Гончарова, 19	Россия, Брянская область, Брянск, Гончарова переулок, 19	0101000020E6100000751DAA29C92641407C2766BD18AA4A40
24519	1	2	\N	1655	917	\N	53.243496999999998	Брянская область, город Брянск, б-р Гагарина, 18	Россия, Брянская область, Брянск, Гагарина бульвар, 18	0101000020E610000051BCCADAA62E414049D6E1E82A9F4A40
24460	1	2	\N	1655	25217	\N	53.301369000000001	Брянская область, город Брянск, Брянской Пролетарской Дивизии, 13		0101000020E61000005F79909E222741409D83674293A64A40
24537	1	2	\N	1655	25284	\N	53.260145000000001	Брянская область, город Брянск, ул.Брянского Фронта, 16		0101000020E6100000D7FB8D76DC284140E59B6D6E4CA14A40
24452	1	2	\N	1655	25277	\N	53.315514	Брянская область, город Брянск, Болховская, 59		0101000020E610000049641F64592441400FB743C362A84A40
24566	1	2	\N	1655	25222	\N	53.204942685660001	Брянская область, город Брянск, Фокинский район, улица  Богдана Хмельницкого, дом 81А	Россия, Брянская область, Брянск, улица Богдана Хмельницкого, 81	0101000020E61000000E66136058384140A6457D923B9A4A40
24471	1	2	\N	1655	25270	\N	53.280268999999997	Брянская область, город Брянск, Бежицкая, 187		0101000020E61000001BBAD91F28294140938AC6DADFA34A40
24481	1	2	\N	1655	25276	\N	53.279257000000001	Брянская область, городской округ Брянск, ул. Афанасьева, 26		0101000020E61000002FA4C34318334140EC1681B1BEA34A40
24483	1	2	\N	1655	24696	\N	53.278882263306102	Брянская область, город Брянск, ул. Академика Королева, 7		0101000020E61000009752978C63324140B7B8C667B2A34A40
24535	1	2	\N	1655	25176	\N	53.262326000000002	Брянская область, город Брянск, ул.Авиационная, 24		0101000020E61000009B012EC896294140FC71FBE593A14A40
24487	1	2	\N	1655	25256	\N	53.268174999999999	Брянская область, город Брянск, ул. Абашева, 3А		0101000020E6100000ABEAE5779A3441406A4DF38E53A24A40
24457	1	2	\N	1655	1165	\N	53.308692999999998	Брянская область, город Брянск, Бульвар 50 лет Октября, 4	Россия, Брянская область, Брянск, 50 Лет Октября бульвар, 4	0101000020E610000043C879FF1F27414087C0914083A74A40
24490	1	2	\N	1655	25223	\N	53.264502354554899	Брянская область, город Брянск, ул. 2-я Мичурина, 1		0101000020E6100000213F1BB96E36414001DD9733DBA14A40
24534	1	2	\N	1655	25252	\N	53.251969459363401	Брянская область, город Брянск, проезд 2-й Ст.Димитрова, 4	Россия, Брянская область, Брянск, 2-й Станке Димитрова проезд, 2	0101000020E6100000459E245D332B41408C4D2B8540A04A40
24533	1	2	\N	1655	25266	\N	53.251455	Брянская область, город Брянск, проезд 1-й Ст.Димитрова, 2	Россия, Брянская область, Брянск, 1-й Станке Димитрова проезд, 4	0101000020E61000009B374E0AF32A414035B56CAD2FA04A40
24499	1	2	\N	1655	25211	\N	53.252128999999996	Тельмана 78		0101000020E61000001CCD91955F3A4140C4AF58C345A04A40
24509	1	2	\N	1655	25247	\N	53.258243	Брянская область, город Брянск, ул.Калинина, 223		0101000020E6100000B77BB94F8E304140E1B54B1B0EA14A40
25454	1	2	1139	51135	25200	\N	52.888512127714499	д. Шулаковка, Советская, 36	Россия, Брянская область, Унечский район, поселок Шулаковка	0101000020E61000007E384888F2634040410DDFC2BA714A40
25428	1	2	1139	16687	24591	\N	52.845708000000002	г. Унеча, Чапаева, 46		0101000020E6100000F92F1004C856404098FBE428406C4A40
25425	1	2	1139	16687	24576	\N	52.845708000000002	г. Унеча, Совхозная, 1		0101000020E6100000F92F1004C856404098FBE428406C4A40
25427	1	2	1139	16687	24578	\N	52.845708000000002	г. Унеча, Попова, 8		0101000020E6100000F92F1004C856404098FBE428406C4A40
25430	1	2	1139	16687	24991	\N	52.848114561966398	г. Унеча, Октябрьская, 26	Россия, Брянская область, Унечский район, Унеча	0101000020E61000004D6A6803B05540409F1F46088F6C4A40
25431	1	2	1139	16687	24910	\N	52.845708000000002	г. Унеча, Луначарского, 38		0101000020E6100000F92F1004C856404098FBE428406C4A40
25429	1	2	1139	16687	24402	\N	52.845708000000002	г. Унеча, Ленина, 98Б		0101000020E6100000F92F1004C856404098FBE428406C4A40
25424	1	2	1139	16687	24671	\N	52.830632333741796	г. Унеча, Комсомольская, 18	Россия, Брянская область, Унечский район, Унеча	0101000020E61000005B7C0A80F15640406B813D26526A4A40
25423	1	2	1139	16687	24671	\N	52.845708000000002	г. Унеча, Комсомольская, 3		0101000020E6100000F92F1004C856404098FBE428406C4A40
25422	1	2	1139	16687	24671	\N	52.832987188068103	г. Унеча, Комсомольская, 10	Россия, Брянская область, Унечский район, Унеча	0101000020E6100000B282DF8618574040207F69519F6A4A40
25371	1	2	1139	16687	24427	\N	52.845708000000002	г. Унеча, Иванова, 26		0101000020E6100000F92F1004C856404098FBE428406C4A40
25433	1	2	1139	16687	24406	\N	52.845708000000002	г. Унеча, Гомельская, 10		0101000020E6100000F92F1004C856404098FBE428406C4A40
25432	1	2	1139	16687	25067	\N	52.845708000000002	г. Унеча, Володарского, 113	Россия, Брянская область, Унечский район, Унеча	0101000020E6100000F92F1004C856404098FBE428406C4A40
25458	1	2	1139	21250	25015	\N	52.860939999999999	с. Староселье, Новоселов, 2	Россия, Брянская область, Унечский район, поселок Староселье	0101000020E6100000A7203F1BB9904040BCE82B48336E4A40
25455	1	2	1139	21095	25079	\N	52.815441	с. Старая Гута, Садовая, 7		0101000020E61000000490DAC4C9434040A568E55E60684A40
25434	1	2	1139	19911	24581	\N	52.818440000000002	д. Слобода-Селецкая, Октябрьская, 19		0101000020E6100000562DE928074F40407FDE54A4C2684A40
25437	1	2	1139	51153	25285	\N	52.768694560579597	с. Рюхов, Октябрьская, 58	Россия, Брянская область, Унечский район, поселок Рюхово	0101000020E6100000765089EB18634040A3CC069964624A40
25439	1	2	1139	20209	24410	\N	52.751486	с. Рохманово, Центральная, 2		0101000020E61000005436ACA92C70404070B378B130604A40
25456	1	2	1139	21133	24913	\N	52.792074999999997	с. Робчик, пер. Щорса, 21		0101000020E61000004A7EC4AF583F4040567DAEB662654A40
25460	1	2	1139	48521	25001	\N	52.891213	д. Пучковка, Луговая, 5		0101000020E610000080F0A1444B8640409162804413724A40
25444	1	2	1139	48234	24720	\N	52.925058	с. Писаревка, Школьная, 24		0101000020E61000000ABDFE243E5B40409B73F04C68764A40
25441	1	2	1139	20328	24994	\N	52.780785000000002	д. Новые Ивайтенки, Зеленая, 4А		0101000020E6100000CCF10A444F8840408B1A4CC3F0634A40
25446	1	2	1139	20634	24719	\N	52.758637	с. Найтоповичи, Октябрьская, 18		0101000020E6100000745C8DEC4A5340408D4468041B614A40
25448	1	2	1139	51130	25185	\N	52.740242710449401	с. Лыщичи, Щорса, 9		0101000020E6100000E21DE0490B494040E50B5A48C05E4A40
25459	1	2	1139	21256	24611	\N	52.915497000000002	с. Лизогубовка, Советская, 11		0101000020E6100000DB6FED4449904040064B75012F754A40
25443	1	2	1139	20430	24417	\N	52.905758705795101	с. Красновичи, Школьная, 2	Россия, Брянская область, Унечский район, поселок Красновичи	0101000020E61000004AEB6F09C04D4040628731E9EF734A40
25451	1	2	1139	20858	25078	\N	52.871088999999998	д. Коробоничи, Центральная, 29Б		0101000020E6100000878C47A984734040E27327D87F6F4A40
25452	1	2	1139	20858	25227	\N	52.856596306897103	ж. д. разъезд Коробоничи, пер. Сосновый, 1А	Россия, Брянская область, Унечский район, поселок Коробоничи	0101000020E6100000306475ABE76A404035F10EF0A46D4A40
24960	1	2	1139	47777	24593	\N	52.798032182754099	село Займище, Школьная, 2	Россия, Брянская область, Унечский район, поселок Займище	0101000020E610000007978E39CF544040AB949EE925664A40
24962	1	2	1139	47777	75042	\N	52.797814000000002	село Займище, Буденного, 72а		0101000020E61000006B2A8BC22E5440403E25E7C41E664A40
25442	1	2	1139	20400	24899	\N	52.799185999999999	с. Задубенье, Школьная, 63		0101000020E6100000034015376E854040E5B512BA4B664A40
24584	1	2	1139	10615	\N	\N	52.899273999999998	с. Добрик, Здание сельской администрации		0101000020E6100000A41AF67B623D4040511212691B734A40
25445	1	2	1139	10615	24694	\N	52.898602242508503	д. Добрик, Центральная, 61	Россия, Брянская область, Унечский район, поселок Добрик	0101000020E61000008CA19C68573D4040620FED6305734A40
25023	1	2	1139	48936	75044	\N	52.754232999999999	с. Высокое, ул. Цветочная, д. 33		0101000020E6100000D74B5304387540403048FAB48A604A40
25447	1	2	1139	20649	24416	\N	52.700831000000001	с. Брянкустичи, Первомайская, 1А		0101000020E6100000B477465B954C4040F18288D4B4594A40
25383	1	2	1139	51137	25203	\N	52.784191023248198	п. Бороденка, ул. Лесная д.14, СДК	Россия, Брянская область, Унечский район, поселок Бородинка	0101000020E61000009B20EA3E007F4040A568E55E60644A40
25453	1	2	1139	51111	25143	\N	52.901331695257099	д. Белогорщь, Мглинская, 49	Россия, Брянская область, Унечский район, поселок Белогорщ	0101000020E6100000F015DD7A4D5D40404C6BD3D85E734A40
25436	1	2	1139	20020	24992	\N	52.820535	д. Аленовка, пер. Совхозный, 4А		0101000020E61000009869FB5756624040971C774A07694A40
25388	1	2	1482	47165	24476	\N	52.735633	с. Юрово, ул.Центральная д.6, СДК		0101000020E6100000DDD3D51D8BF14040DF6DDE38295E4A40
25407	1	2	1482	18502	\N	\N	52.546494000000003	д. Хотьяновка, СДК		0101000020E6100000B6A0F7C610C64040E9BAF083F3454A40
25399	1	2	1482	47382	24481	\N	52.578190999999997	д. Филипповичи, ул.Новая д.1, Филиповичская СОШ		0101000020E6100000C23060C955D44040B7EBA529024A4A40
25412	1	2	1482	47637	\N	\N	52.603909000000002	с. Усох, СДК		0101000020E61000008BC3995FCDEB40404A61DEE34C4D4A40
25376	1	2	1482	16980	25212	\N	52.586038000000002	Брянская область, Трубчевский муниципальный район, Советская, 56	Россия, Брянская область, Трубчевский район, Трубчевск	0101000020E6100000790261A758E340404C1B0E4B034B4A40
25378	1	2	1482	16980	24805	\N	52.582238824256301	г. Трубчевск, Луначарского, 60	Россия, Брянская область, Трубчевский район, Трубчевск	0101000020E6100000C4EA8F300CE2404056BABBCE864A4A40
25381	1	2	1482	16980	24802	\N	52.566079000000002	г. Трубчевск, Ленина, 79		0101000020E610000057EA5910CAE14040E8F9D34675484A40
25377	1	2	1482	16980	24802	\N	52.574670291799798	г. Трубчевск, Ленина, 85	Россия, Брянская область, Трубчевский район, Трубчевск	0101000020E6100000EACF7EA488E2404004FF5BC98E494A40
25382	1	2	1482	16980	24960	\N	52.5675434662231	г. Трубчевск, Комсомольская, 2	Россия, Брянская область, Трубчевский район, Трубчевск	0101000020E610000056444DF4F9E040407009C03FA5484A40
25380	1	2	1482	16980	9810	\N	52.5835066537798	г. Трубчевск, Володарского, 3	Россия, Брянская область, Трубчевский район, Трубчевск	0101000020E6100000D53E1D8F19E2404058FE7C5BB04A4A40
25379	1	2	1482	16980	9810	\N	52.5773370748201	г. Трубчевск, Володарского, 4	Россия, Брянская область, Трубчевский район, Трубчевск	0101000020E6100000124C35B396E24040A8E2C62DE6494A40
25396	1	2	1482	17930	24892	\N	52.569724000000001	д. Телец,  ул. Трубчевская д.25, здание администрации		0101000020E6100000B247A81952DF404087DF4DB7EC484A40
25417	1	2	1482	47725	\N	\N	52.649335000000001	с. Семячки, здание администрвации		0101000020E61000004F5AB8ACC2D44040F792C6681D534A40
25402	1	2	1482	18219	\N	\N	52.5116752443205	с. Селец, Селецкая СОШ	Россия, Брянская область, Трубчевский район, поселок Селец	0101000020E6100000B33F506EDBC940402497FF907E414A40
25404	1	2	1482	18336	\N	\N	52.436312000000001	д. Сагутьево, здание магазина		0101000020E61000004AB20E4757BB40401A6D5512D9374A40
25395	1	2	1482	17879	25130	\N	52.808380999999997	д. Рябчевск, ул. Строительная д.2, здание администрации		0101000020E61000007095271076FC404098DA520779674A40
25415	1	2	1482	18897	\N	\N	52.627535000000002	с. Радутино, СДК		0101000020E610000021AE9CBD33F84040350C1F1153504A40
25414	1	2	1482	51035	\N	\N	52.633523911228302	д. Радинск, здание ФАП	Россия, Брянская область, Трубчевский район, поселок Радинская	0101000020E6100000C39E76F86BEC4040959D7E5017514A40
25391	1	2	1482	47210	25133	\N	52.769049818553299	с. Плюсково, ул.Молодежная д.20, Плюсковская СОШ	Россия, Брянская область, Трубчевский район, поселок Плюсково	0101000020E61000005FB2F1608BE94040917EFB3A70624A40
25285	1	2	1482	49396	24853	\N	52.637613999999999	д. Острая Лука, ул. Октябрьская д.33, здание магазина		0101000020E61000002C2E8ECA4D00414062BCE6559D514A40
25420	1	2	1482	51032	\N	\N	52.6750662991643	д. Молчановао, СДК	Россия, Брянская область, Трубчевский район, поселок Молчаново	0101000020E6100000B62DCA6C90D940401E520C9068564A40
25393	1	2	1482	47265	24564	\N	52.801560000000002	д. Манцурово, ул. Молодежная д.15, СДК		0101000020E61000007B8670CCB2FD404011E4A08499664A40
25400	1	2	1482	18140	\N	\N	52.559120999999998	д. Макарзно, СДК		0101000020E610000081AFE8D66BD44040DFC0E44691474A40
25390	1	2	1482	17634	25127	\N	52.724043999999999	д. Любожичи, ул.Центральная д.4, ЛюбожичскийСДК		0101000020E6100000D8B969334E014140B96E4A79AD5C4A40
25403	1	2	1482	47474	\N	\N	52.455463000000002	с. Любец, СДК		0101000020E610000029CC7B9C69BC4040DFC4909C4C3A4A40
25392	1	2	1482	45579	24563	\N	52.769638999999998	с. Ложки, ул.Ложковская д.18, контора ООО "Арсеналец"		0101000020E610000001DF6DDE38DD4040F25CDF8783624A40
25401	1	2	1482	18188	\N	\N	52.550628000000003	д. Кветунь, СДК		0101000020E6100000D3F8855792D04040862172FA7A464A40
25411	1	2	1482	47576	\N	\N	52.588937999999999	д. Городцы, Дом крестьянского быта	Россия, Брянская область, Трубчевский район, поселок Городцы	0101000020E6100000AA44D95BCAE7404092AF0452624B4A40
25410	1	2	1482	47576	\N	\N	52.588937999999999	д.Городцы, здание администрации		0101000020E6100000AA44D95BCAE7404092AF0452624B4A40
25409	1	2	1482	47576	\N	\N	52.588937999999999	д.Городцы, СДК		0101000020E6100000AA44D95BCAE7404092AF0452624B4A40
25394	1	2	1482	51097	25007	\N	52.7539350545579	д. Голубча, ул.Деснянская д.62,  СДК	Россия, Брянская область, Трубчевский район, поселок Голубичи	0101000020E6100000DEC9A7C7B6FE4040A6272CF180604A40
25389	1	2	1482	47169	24677	\N	52.653263000000003	д. Гнилево, ул.Центральная д.6, СДК		0101000020E6100000CF4BC5C6BC004140EB573A1F9E534A40
25406	1	2	1482	18453	\N	\N	52.515596000000002	д. Глыбочка, Глыбоченская ООШ		0101000020E61000002463B5F97FBF404066F9BA0CFF414A40
25421	1	2	1482	19263	\N	\N	52.662309	"д. Бобовня, здание конторы МУП ""Бобовня"""		0101000020E610000090F7AA9509CB4040596C938AC6544A40
25385	1	2	1482	51116	25161	\N	52.381294514630099	п. Б.Березка, ул. Ленина д.6А, кинотеатр	Россия, Брянская область, Трубчевский район, поселок Белая Березка	0101000020E6100000A8902BF52CBE40406D904946CE304A40
25384	1	2	1482	51116	25161	\N	52.383664548235402	п. Б.Березка, ул.Ленина д.12, Центр ДТ "Юность"	Россия, Брянская область, Трубчевский район, поселок Белая Березка	0101000020E610000017D68D7747BE404057CF49EF1B314A40
25386	1	2	1482	51116	25228	\N	52.382503836688102	п. Б.Березка, ул. Дзержинского д.4,  здание поселковой администрации	Россия, Брянская область, Трубчевский район, поселок Белая Березка	0101000020E6100000BA13ECBFCEBD40406A4B1DE4F5304A40
25387	1	2	1482	51116	25292	\N	52.382639983953901	п.Б.Березка, ул. Калинина д.11, СДК	Россия, Брянская область, Трубчевский район, поселок Белая Березка	0101000020E610000044FAEDEBC0BD40401B12F758FA304A40
25405	1	2	1482	18355	\N	\N	52.479849999999999	с. Алешенка, Алешенская СОШ		0101000020E6100000F98557923CBF4040287E8CB96B3D4A40
25418	1	2	1482	47736	\N	\N	52.613239	"д. Алладьино, здание  ООО ""Молочное"""		0101000020E6100000D3F6AFAC34D94040DDD0949D7E4E4A40
25344	1	2	1345	14985	24706	\N	53.016210000000001	Брянская область, г.Сураж, ул.Октябрьская, д.81		0101000020E610000038A3E6ABE431404020EF552B13824A40
25343	1	2	1345	14985	24783	\N	53.016210000000001	Брянская область, г.Сураж, ул.Ленина, д.52		0101000020E610000038A3E6ABE431404020EF552B13824A40
25336	1	2	1345	14985	24783	\N	53.016210000000001	Брянская область, г.Сураж, ул.Ленина, д.84		0101000020E610000038A3E6ABE431404020EF552B13824A40
25337	1	2	1345	14985	25123	\N	53.0226273180782	Брянская область, г.Сураж, ул.Комсомольская, д.46	Россия, Брянская область, Суражский район, Сураж	0101000020E61000005A7F4B00FE334040D8800871E5824A40
25338	1	2	1345	14985	24542	\N	53.016210000000001	Брянская область, г.Сураж, ул.Ворошилова, д.76		0101000020E610000038A3E6ABE431404020EF552B13824A40
25342	1	2	1345	14985	24541	\N	53.016210000000001	Брянская область, г.Сураж, ул.Белорусская, д.60		0101000020E610000038A3E6ABE431404020EF552B13824A40
25341	1	2	1345	14985	24541	\N	53.016210000000001	Брянская область, г.Сураж, ул.Белорусская, д.66		0101000020E610000038A3E6ABE431404020EF552B13824A40
25339	1	2	1345	14985	24541	\N	53.016210000000001	Брянская область, г.Сураж, ул.Белорусская, д.150а		0101000020E610000038A3E6ABE431404020EF552B13824A40
25340	1	2	1345	14985	24867	\N	53.016210000000001	"Брянская область, г.Сураж, 29 квартал, здание детского сада ""Солнышко"""		0101000020E610000038A3E6ABE431404020EF552B13824A40
25356	1	2	1345	15951	24799	\N	53.232104	Брянская область, Суражский район, д.Струженка, ул.Новая, д.8		0101000020E61000007C9E3F6D54414040A9A27895B59D4A40
25372	1	2	1345	16750	\N	\N	53.038924000000002	Брянская область, Суражский район, д.Старая Кашовка, здание начальной общеобразовательной школы		0101000020E610000061FC34EECD2D4040C7832D76FB844A40
25324	1	2	1345	14429	24429	\N	53.151586999999999	Брянская область, Суражский район, д.Слище, ул.Советская, д.71а		0101000020E610000041D3122BA3394040D7BFEB3367934A40
25279	1	2	1345	51118	25155	\N	52.929813985084998	Брянская область, Стародубский муниципальный район, Запольскохалеевичское сельское поселение, с.Селище, Клинцовская, 12-А	Россия, Брянская область, Суражский район, поселок Селище	0101000020E6100000D95A5F24B42D404075AE282504774A40
25349	1	2	1345	15600	24791	\N	53.028987000000001	Брянская область, Суражский район, с.Октябрьское, ул.Ковалевка, д.1		0101000020E61000001FBB0B94141840402C8194D8B5834A40
25369	1	2	1345	16566	25125	\N	53.045653999999999	Брянская область, Суражский район, с.Овчинец, ул.Молодежная, д.1а		0101000020E6100000643DB5FAEA3C40403E7782FDD7854A40
25368	1	2	1345	16541	25044	\N	53.092737	Брянская область, Суражский район, д.Новый Дроков, пер.Молодежный, д.10		0101000020E6100000E2934E2498444040881057CEDE8B4A40
25366	1	2	1345	16453	24877	\N	53.181584999999998	Брянская область, Суражский район, с.Нивное, ул.Ленина  д.57		0101000020E6100000FF21FDF6754A4040DA38622D3E974A40
25365	1	2	1345	16370	25042	\N	53.004317	Брянская область, Суражский район, с.Ляличи, ул.Мичурина, д.10		0101000020E61000008BFED0CC934540408EE89E758D804A40
25363	1	2	1345	16260	24952	\N	53.029144000000002	Брянская область, Суражский район, с.Лопазна, ул.Дубиновка, д.61		0101000020E6100000D4D347E00F514040F46F97FDBA834A40
25359	1	2	1345	16070	24793	\N	52.963852000000003	Брянская область, Суражский район, пос.Лесное, ул.Школьная, д.6		0101000020E6100000EF586C938A344040941799805F7B4A40
25357	1	2	1345	15963	25040	\N	52.910099000000002	Брянская область, Суражский район, с.Кулаги, ул.Октябрьская, д.23		0101000020E610000040170D198F324040A88FC01F7E744A40
25360	1	2	1345	16138	\N	\N	53.003314000000003	"Брянская область, Суражский район, д.Красный Завод, здание МАУ ""Детский санаторий ""Ипуть"""		0101000020E610000091813CBB7C3740403ACFD8976C804A40
25346	1	2	1345	15473	24669	\N	53.005958999999997	Брянская область, Суражский район, д.Красная Слобода, ул.Гагарина, д.8а		0101000020E6100000A4C684984B2E4040F50EB743C3804A40
25364	1	2	1345	16350	24798	\N	53.058466000000003	Брянская область, Суражский район, с.Костеничи, ул.Заречье, д.17а		0101000020E6100000CC988235CE564040C7F65AD07B874A40
25361	1	2	1345	16155	24548	\N	52.989401999999998	Брянская область, Суражский район, д.Каменск, ул.Новая, д.1а		0101000020E6100000A7AFE76B963B40406A4C88B9A47E4A40
25370	1	2	1345	16652	24674	\N	53.036363000000001	Брянская область, Суражский район, д.Калинки, ул.Садовая, д.2		0101000020E6100000CA6C90494634404069E4F38AA7844A40
25358	1	2	1345	16038	\N	\N	52.914763999999998	Брянская область, Суражский район, д.Жемердеевка, здание сельского клуба		0101000020E6100000EA78CC406528404071C79BFC16754A40
25351	1	2	1345	15679	25034	\N	53.274303000000003	Брянская область, Суражский район, д.Жастково, ул.Центральная, д.26		0101000020E61000006077BAF3C44B4040EC18575C1CA34A40
25373	1	2	1345	51049	24610	\N	53.068179000000001	Брянская область, Суражский район, с.Душатин, ул.Школьная, д.1	Россия, Брянская область, Суражский район, поселок Душатино	0101000020E61000004277499C1523404012A3E716BA884A40
25354	1	2	1345	15850	25035	\N	53.090665999999999	Брянская область, Суражский район, с.Дубровка, ул. Центральная д.3		0101000020E6100000E109BDFE243A4040F86D88F19A8B4A40
25350	1	2	1345	15667	24790	\N	53.256357999999999	Брянская область, Суражский район, с.Дегтяревка, пер.Садовый, д.4		0101000020E6100000942EFD4B52534040B308C556D0A04A40
25355	1	2	1345	15874	24457	\N	53.142454000000001	Брянская область, Суражский район, с.Далисичи, ул.Октябрьская, д.5		0101000020E6100000EF5701BEDB3040409A97C3EE3B924A40
25374	1	2	1345	16856	\N	\N	53.067670999999997	Брянская область, Суражский район, д.Гудовка, здание основной общеобразовательной школы		0101000020E61000009DDA19A6B61A40409DF17D71A9884A40
25362	1	2	1345	16229	25041	\N	52.942225999999998	Брянская область, Суражский район, д.Глуховка, ул.Садовая, д.28		0101000020E6100000F33977BB5E4440406FB88FDC9A784A40
25353	1	2	1345	15758	25092	\N	53.289841000000003	Брянская область, Суражский район, д.Вьюково, пер.Сентябрьский, д.1		0101000020E6100000AFD007CBD85640401D05888219A54A40
25367	1	2	1345	16471	24955	\N	53.130564	Брянская область, Суражский район, с.Высокоселище, ул.Молодежная, д.1		0101000020E610000049111956F144404079043752B6904A40
25345	1	2	1345	15427	24544	\N	53.010081748949801	Брянская область, Суражский район, с.Влазовичи, ул.Ленина, д.24	Россия, Брянская область, Суражский район, поселок Влазовичи	0101000020E61000005C55F65D112640409E23F25D4A814A40
24987	1	2	1345	51089	\N	\N	53.259267000000001	п. Владимировка, здание Владимировского сельского клуба	Россия, Брянская область, Суражский район, поселок Владимировка	0101000020E61000004CA59F70765F40404DF73AA92FA14A40
25026	1	2	1345	31812	24894	\N	52.962744999999998	п. Беловодка, ул. 60 лет Октября, д. 39		0101000020E6100000FC709010E52F40409AB1683A3B7B4A40
25347	1	2	1345	15502	25008	\N	53.004274000000002	Брянская область, Суражский район, д.Андреевка, ул.Октябрьская, д.16		0101000020E6100000E257ACE1221D40408F1CE90C8C804A40
25332	1	2	1308	14794	25006	\N	52.406027999999999	Брянская область, Суземский муниципальный район, с. Ямное, ул. Заречная, д.22		0101000020E6100000F81BEDB8E1F5404051A1BAB9F8334A40
25326	1	2	1308	14521	25005	\N	52.249875000000003	Брянская область, Суземский муниципальный район, д. Щепетлево, ул. Молодёжная, д.1		0101000020E610000086014BAE62194140448B6CE7FB1F4A40
25334	1	2	1308	14886	24536	\N	52.503580999999997	Брянская область, Суземский муниципальный район,  пос. Холмечи, ул. Будённого, д.77		0101000020E61000000DFD135CAC1A414088F19A5775404A40
25313	1	2	1308	13774	24547	\N	52.318657999999999	Брянская область, Суземский муниципальный район, пгт. Суземка, пер. 1-й Трубчевский, д.14		0101000020E6100000AFB14B546F094140EC4D0CC9C9284A40
25311	1	2	1308	13774	25032	\N	52.318657999999999	Брянская область, Суземский муниципальный район, пгт. Суземка, пл. Ленина, д.6	Россия, Брянская область, Суземский район, поселок Суземка	0101000020E6100000AFB14B546F094140EC4D0CC9C9284A40
25312	1	2	1308	13774	25116	\N	52.316317301036499	Брянская область, Суземский муниципальный район, пгт. Суземка, пер. Интернациональный, д.5	Россия, Брянская область, Суземский район, поселок Суземка	0101000020E610000029AF95D05D0841409C1551137D284A40
25314	1	2	1308	13774	24501	\N	52.318657999999999	Брянская область, Суземский муниципальный район, пгт. Суземка, ул. Первомайская, д.59		0101000020E6100000AFB14B546F094140EC4D0CC9C9284A40
25325	1	2	1308	14453	24743	\N	52.147872	Брянская область, Суземский муниципальный район, с. Страчово, ул. им. Мореева, д.19		0101000020E6100000F75AD07B631241403FFF3D78ED124A40
25329	1	2	1308	14655	24445	\N	52.297640999999999	Брянская область, Суземский муниципальный район, с. Семеновск, ул. Центральная, д.1		0101000020E6100000F7CB272B863141407079AC1919264A40
25333	1	2	1308	51063	24732	\N	52.381715106448802	Брянская область, Суземский муниципальный район, с. Селечня, ул. Школьная, д.6	Россия, Брянская область, Суземский район, поселок Селичня	0101000020E610000032755776C12E414042B28009DC304A40
25323	1	2	1308	14341	24776	\N	52.18882	Брянская область, Суземский муниципальный район, с. Полевые Новоселки, ул. Молодёжная, д.6		0101000020E6100000A9F7544E7B184140556AF6402B184A40
25322	1	2	1308	14329	24655	\N	52.203817999999998	Брянская область, Суземский муниципальный район, с. Павловичи, ул. Молодёжная, д.24		0101000020E610000085B69C4B711B4140062B4EB5161A4A40
25331	1	2	1308	14752	24657	\N	52.389400000000002	Брянская область, Суземский муниципальный район, пос. Новенькое, ул. Школьная, д.2		0101000020E61000000D1D3BA8C4E94040FD87F4DBD7314A40
25330	1	2	1308	14686	24844	\N	52.333711000000001	Брянская область, Суземский муниципальный район, с. Новая Погощь, ул. Центральная, д.11		0101000020E61000002B6C06B820F3404061A8C30AB72A4A40
25335	1	2	1308	14137	24454	\N	52.430717000000001	Брянская область, Суземский муниципальный район, ж.д.ст.Нерусса, ул. Лесная, д.24		0101000020E610000035289A07B0124140666A12BC21374A40
25318	1	2	1308	14137	24860	\N	52.385800000000003	Брянская область, Суземский муниципальный район, пос. Нерусса, ул. Центральная, д.21		0101000020E61000000F0A4AD1CA0F4140FE65F7E461314A40
25328	1	2	1308	14603	25027	\N	52.313533	Брянская область, Суземский муниципальный район, с. Негино, ул. Центральная, д.83		0101000020E6100000897AC1A7391B4140BF9B6ED921284A40
25327	1	2	1308	14541	25109	\N	52.302354999999999	Брянская область, Суземский муниципальный район,  с. Невдольск, ул. Центральная, д.68		0101000020E61000004A5E9D63402441401B649291B3264A40
25317	1	2	1308	51087	24953	\N	52.451320000000003	Брянская область, Суземский муниципальный район, с. Красная Слобода, ул. Школьная, д.12	Россия, Брянская область, Суземский район, поселок Красная Слобода	0101000020E6100000B933130CE7024140EF0390DAC4394A40
25319	1	2	1308	14176	24770	\N	52.591355999999998	Брянская область, Суземский муниципальный район, пгт. Кокоревка, ул.Гагарина1		0101000020E61000001EE1B4E0452341408D25AC8DB14B4A40
25321	1	2	1308	14278	24528	\N	52.195366999999997	Брянская область, Суземский муниципальный район, с. Зерново, ул. Молодёжная, д.15		0101000020E6100000CC2555DB4D0A4140DBDB2DC901194A40
25316	1	2	1308	14051	24919	\N	52.406528000000002	Брянская область, Суземский муниципальный район, с. Денисовка, пер. Речной, д.1		0101000020E61000008B34F10EF00441404374081C09344A40
25315	1	2	1308	13991	24918	\N	52.301146508536704	Брянская область, Суземский муниципальный район, с. Горожанка, ул. Лесная,1	Россия, Брянская область, Суземский район, поселок Горожанка	0101000020E6100000FFB1101D02FD4040EE2422FC8B264A40
25320	1	2	1308	14214	24653	\N	52.229326999999998	Брянская область, Суземский муниципальный район, с. Алешковичи,пер. Советский,1		0101000020E6100000EB56CF49EF1541407E8B4E965A1D4A40
25296	1	2	1182	13083	24519	\N	52.590359999999997	Брянская область, Стародубский муниципальный район, Мохоновское сельское поселение, с.Шкрябино, Садовая, 3		0101000020E6100000145CACA8C1544040EB6E9EEA904B4A40
25281	1	2	1182	12399	25014	\N	52.532746000000003	Брянская область, Стародубский муниципальный район, Каменское сельское поселение, с.Чубковичи, Зеленая Дубрава, 48		0101000020E610000027A089B0E14D404094895B0531444A40
25290	1	2	1182	12828	25096	\N	52.454957999999998	Брянская область, Стародубский муниципальный район, Мишковское сельское поселение, с.Тарасовка, Новая, 25		0101000020E6100000B4E89D0AB87B4040DB8651103C3A4A40
25309	1	2	1182	12053	24780	\N	52.585053000000002	Брянская область, городской округ Стародуб, Урицкого, 24-А		0101000020E610000092AF0452626140409EB64604E34A4A40
25304	1	2	1182	12053	24911	\N	52.585053000000002	Брянская область, городской округ Стародуб, Совхозная, 49		0101000020E610000092AF0452626140409EB64604E34A4A40
25307	1	2	1182	12053	24540	\N	52.585053000000002	Брянская область, городской округ Стародуб, Семашко, 11		0101000020E610000092AF0452626140409EB64604E34A4A40
25310	1	2	1182	12053	24733	\N	52.585053000000002	Брянская область, городской округ Стародуб, Ленина, 2		0101000020E610000092AF0452626140409EB64604E34A4A40
25273	1	2	1182	12053	24733	\N	52.585053000000002	Брянская область, городской округ Стародуб, Ленина, 14		0101000020E610000092AF0452626140409EB64604E34A4A40
25297	1	2	1182	12053	24744	\N	52.585053000000002	Брянская область, городской округ Стародуб, ул. Красных Партизан,д.21-а,		0101000020E610000092AF0452626140409EB64604E34A4A40
25308	1	2	1182	12053	24524	\N	52.585053000000002	Брянская область, городской округ Стародуб, Краснооктябрьская, 79-А		0101000020E610000092AF0452626140409EB64604E34A4A40
25306	1	2	1182	12053	24524	\N	52.585053000000002	Брянская область, городской округ Стародуб, Краснооктябрьская, 12		0101000020E610000092AF0452626140409EB64604E34A4A40
25305	1	2	1182	12053	24524	\N	52.585053000000002	Брянская область, городской округ Стародуб, Краснооктябрьская, 9		0101000020E610000092AF0452626140409EB64604E34A4A40
25263	1	2	1182	11528	24606	\N	52.419480999999998	Брянская область, Стародубский муниципальный район, Воронокское сельское поселение, с.Солова, Пролетарская, 64-А		0101000020E6100000F488D1730B5140408D25AC8DB1354A40
25292	1	2	1182	12918	24763	\N	52.518653999999998	Брянская область, Стародубский муниципальный район, Мишковское сельское поселение, д.Случок, пер. Коммунистический д. 5		0101000020E61000003A5CAB3DEC79404044F8174163424A40
25298	1	2	1182	13204	24859	\N	52.661746000000001	Брянская область, Стародубский муниципальный район, Мохоновское сельское поселение, с.Пятовск, Стародубская, 16		0101000020E6100000747B4963B45A40402121CA17B4544A40
25274	1	2	1182	51144	25221	\N	52.603099999999998	Брянская область, Стародубский муниципальный район, Десятуховское сельское поселение, с.Пролетарск, Молодежная, 1	Россия, Брянская область, Стародубский район, поселок Пролетарское	0101000020E6100000CB845FEAE77D4040DA1B7C61324D4A40
25300	1	2	1182	13291	25099	\N	52.365094999999997	Брянская область, Стародубский муниципальный район, Понуровское сельское поселение, с.Понуровка, Бриггена, 76-А		0101000020E6100000B685E7A5626B40407077D66EBB2E4A40
25266	1	2	1182	11708	24835	\N	52.669331999999997	Брянская область, Стародубский муниципальный район, Гарцевское сельское поселение, д.Пестриково, Центральная, 26		0101000020E61000004E97C5C4E68740404815C5ABAC554A40
25272	1	2	1182	51080	24917	\N	52.634686728582203	Брянская область, Стародубский муниципальный район, Десятуховское сельское поселение, с.Пантусов, Школьная, 7-А	Россия, Брянская область, Стародубский район, поселок Пантусово	0101000020E61000001502B9C4916540402219726C3D514A40
25295	1	2	1182	13043	24736	\N	52.613183999999997	Брянская область, Стародубский муниципальный район, Мохоновское сельское поселение, с. Остроглядово, Мацкевича, 12-А		0101000020E61000009563B2B8FF5A4040193735D07C4E4A40
25038	1	2	1182	49164	24928	\N	52.660561000000001	с. Осколково, ул. Советская, д. 10	Россия, Брянская область, Стародубский район, поселок Осколково	0101000020E61000007100FDBE7F614040AC014A438D544A40
25299	1	2	1182	13217	24651	\N	52.680045	Брянская область, Стародубский муниципальный район, Мохоновское сельское поселение, п.Новополье, Садовая, 1-А		0101000020E610000006BAF605F45E40407767EDB60B574A40
25277	1	2	1182	12233	24926	\N	52.444046999999998	Брянская область, Стародубский муниципальный район, Занковское сельское поселение, с.Новомлынка, пер.Школьный, 1		0101000020E6100000F3FFAA234760404086713788D6384A40
25287	1	2	1182	51149	25263	\N	52.694800000000001	Брянская область, Стародубский муниципальный район, Меленское сельское поселение, с.Новое Село, Озерная, 20	Россия, Брянская область, Стародубский район, поселок Новое Село	0101000020E610000017BB7D569967404062A1D634EF584A40
25284	1	2	1182	51041	24516	\N	52.537859049500597	Брянская область, Стародубский муниципальный район, Каменское сельское поселение,с.Нижнее, Школьная, 24	Россия, Брянская область, Стародубский район, поселок Нижнее	0101000020E6100000849B8C2AC3424040FC6D4F90D8444A40
25293	1	2	1182	12940	24648	\N	52.632263999999999	Брянская область, Стародубский муниципальный район, Мохоновское сельское поселение, с.Мохоновка, Пролетарская, 46		0101000020E6100000ECD973999A5240401538D906EE504A40
25289	1	2	1182	12802	25095	\N	52.489825000000003	Брянская область, Стародубский муниципальный район, Мишковское сельское поселение, с.Мишковка, Центральная, 11-Г		0101000020E610000026E2ADF36F754040B1E1E995B23E4A40
25268	1	2	1182	51064	24738	\N	52.713265999999997	Брянская область, Стародубский муниципальный район, Гарцевское сельское поселение, с.Михайловск, Садовая, 11-А		0101000020E610000042D2A755F4874040A3ACDF4C4C5B4A40
25271	1	2	1182	51120	25159	\N	52.570968675526203	Брянская область, Стародубский муниципальный район, Десятуховское сельское поселение, с.Мереновка, Первомайская, 97-А	Россия, Брянская область, Стародубский район, поселок Мереневка	0101000020E6100000C68A1A4CC36A4040D1031F8315494A40
25286	1	2	1182	12668	25091	\N	52.633203999999999	Брянская область, Стародубский муниципальный район, Меленское сельское поселение, с.Меленск, Комсомольская, 1		0101000020E61000009546CCECF376404023D923D40C514A40
25288	1	2	1182	12763	24855	\N	52.701070999999999	Брянская область, Стародубский муниципальный район, Меленское сельское поселение, д.Меженики, Садовая, 29		0101000020E61000006EDE3829CC6340404696CCB1BC594A40
25258	1	2	1182	11318	25076	\N	52.358969000000002	Брянская область, Стародубский муниципальный район, Воронокское сельское поселение, с.Лужки, Советская, 11		0101000020E610000043AA285E6549404090A339B2F22D4A40
25261	1	2	1182	11434	24500	\N	52.302514000000002	Брянская область, Стародубский муниципальный район, Воронокское сельское поселение, с.Ломаковка, Семеновская, 24-А		0101000020E6100000AD6BB41CE8534040844A5CC7B8264A40
25283	1	2	1182	12504	24849	\N	52.595233999999998	Брянская область, Стародубский муниципальный район, Каменское сельское поселение, с.Логоватое, Трудовая, 82		0101000020E6100000B1355B79C9494040CFBBB1A0304C4A40
25269	1	2	1182	51088	25182	\N	52.583837798736297	Брянская область, Стародубский муниципальный район, Десятуховское сельское поселение, с.Левенка, ул. Садовая,  д. 26	Россия, Брянская область, Стародубский район, поселок Левенки	0101000020E61000002AC423F1F2704040BE141E34BB4A4A40
25303	1	2	1182	13422	24596	\N	52.297348999999997	Брянская область, Стародубский муниципальный район, Понуровское сельское поселение, с.Курковичи, Луговая, 1		0101000020E6100000E0D8B3E732674040C83F33880F264A40
25282	1	2	1182	12466	24930	\N	52.579127	Брянская область, Стародубский муниципальный район, Каменское сельское поселение, д.Крюков, ул.Советская, д. 14		0101000020E6100000FBEB1516DC4D4040849D62D5204A4A40
25187	1	2	861	51110	25141	\N	52.900784999999999	с.Первомайское, Советская, 2	Россия, Брянская область, Почепский район, поселок Первомайское	0101000020E6100000A94D9CDCEFCC40401ADD41EC4C734A40
25260	1	2	1182	11430	24723	\N	52.333018000000003	Брянская область, Стародубский муниципальный район, Воронокское сельское поселение, с.Крутая Буда, Набережная, 33		0101000020E61000006C787AA52C5D40405B7D7555A02A4A40
25275	1	2	1182	12147	25089	\N	52.532653000000003	Брянская область, Стародубский муниципальный район, Занковское сельское поселение, п.Красный, Культуры, 5		0101000020E610000051BF0B5BB35F4040E38E37F92D444A40
25267	1	2	1182	11723	24420	\N	52.698402000000002	Брянская область, Стародубский муниципальный район, Гарцевское сельское поселение, с.Ковалево, Новая, 11		0101000020E61000007C0C569C6A91404002BB9A3C65594A40
25276	1	2	1182	51151	25282	\N	52.490050538949802	Брянская область, Стародубский муниципальный район, Занковское сельское поселение, с.Картушин, Советская, 63	Россия, Брянская область, Стародубский район, поселок Картушино	0101000020E61000009291B3B0A7654040A12FBDFDB93E4A40
25280	1	2	1182	12394	24754	\N	52.540776000000001	Брянская область, Стародубский муниципальный район, Каменское сельское поселение, д.Камень, Центральная, 62		0101000020E61000005DFC6D4F90524040193BE12538454A40
25265	1	2	1182	11617	24418	\N	52.702554999999997	Брянская область, Стародубский муниципальный район, Гарцевское сельское поселение, д.Ильбово, Центральная, 84		0101000020E6100000E48409A3597F404015527E52ED594A40
25278	1	2	1182	12279	24634	\N	52.662866000000001	Брянская область, Стародубский муниципальный район, Запольскохалеевичское сельское поселение, с.Запольские  Халеевичи, Комсомольская, 10		0101000020E61000009548A29751424040AFD007CBD8544A40
25262	1	2	1182	11509	25077	\N	52.433512	Брянская область, Стародубский муниципальный район, Воронокское сельское поселение, с.Елионка, Магистральная, 2		0101000020E610000003CE52B29C4C404037363B527D374A40
25291	1	2	1182	12887	24645	\N	52.517310999999999	Брянская область, Стародубский муниципальный район, Мишковское сельское поселение, с.Дохновичи, Магистральная, 24		0101000020E6100000D49AE61DA7704040376E313F37424A40
25270	1	2	1182	11891	24836	\N	52.584358047606401	Брянская область, Стародубский муниципальный район, Десятуховское сельское поселение, п.Десятуха, пл.Ленина, 7	Россия, Брянская область, Стародубский район, поселок Десятуха	0101000020E61000003145B9347E6B4040F793313ECC4A4A40
25302	1	2	1182	13359	24493	\N	52.331229	Брянская область, Стародубский муниципальный район, Понуровское сельское поселение, с.Демьянки, Садовая, 1-А		0101000020E6100000B4722F302B7040404F3E3DB6652A4A40
25294	1	2	1182	13007	24615	\N	52.632432999999999	Брянская область, Стародубский муниципальный район, Мохоновское сельское поселение, Дареевичи, Садовая, 10		0101000020E6100000F8F9EFC16B4B4040A1F48590F3504A40
25264	1	2	1182	11603	24419	\N	52.742398999999999	Брянская область, Стародубский муниципальный район, Гарцевское сельское поселение, с.Гарцево, Школьная, 4		0101000020E61000000E12A27C417F4040A3CA30EE065F4A40
25257	1	2	1182	11258	24718	\N	52.363796999999998	Брянская область, Стародубский муниципальный район, Воронокское сельское поселение, с.Воронок, Площадь 1 Мая, 2		0101000020E6100000204432E4D854404003B16CE6902E4A40
25259	1	2	1182	11354	25138	\N	52.331563282982799	Брянская область, Стародубский муниципальный район, Воронокское сельское поселение, с.Алейниково, Центральная, 9-А	Россия, Брянская область, Стародубский район, поселок Алейниково	0101000020E6100000465B9544F655404026C808A8702A4A40
25301	1	2	1182	13332	25137	\N	52.304870999999999	Брянская область, Стародубский муниципальный район, Понуровское сельское поселение, с.Азаровка, Комсомольская, 8		0101000020E6100000F22213F06B704040D93F4F0306274A40
25235	1	2	1072	10233	24700	\N	52.227755000000002	с. Шведчики, ул. Центральная, д.76		0101000020E6100000B2F50CE19849414010406A13271D4A40
25231	1	2	1072	10012	24582	\N	52.249654020107201	с. Чемлыж, ул. Лушникова, д.30	Россия, Брянская область, Севский район, поселок Чемлыж	0101000020E6100000047289230F36414065A88AA9F41F4A40
25225	1	2	1072	9711	24447	\N	51.976404000000002	с. Хинель, ул. Парковая, д.17		0101000020E6100000249D8191971B414080D767CEFAFC4940
25239	1	2	1072	51125	25172	\N	51.890590667049899	с. Троебортное, ул. Новая, д.5	Россия, Брянская область, Севский район, поселок Треобортное	0101000020E6100000CD3FFA264D314140548EC9E2FEF14940
25243	1	2	1072	51108	25135	\N	52.093587999999997	с. Сенное, ул. Молодежная, д.32	Россия, Брянская область, Севский район, поселок Сенное	0101000020E6100000849A2155144B414026A60BB1FA0B4A40
25247	1	2	1072	10705	25071	\N	52.139284000000004	г. Севск, ул. Советская, д.6		0101000020E610000045D4449F8F3E4140946DE00ED4114A40
25246	1	2	1072	10705	24905	\N	52.139284000000004	г. Севск, ул. С.Щедрина, д.23		0101000020E610000045D4449F8F3E4140946DE00ED4114A40
25245	1	2	1072	10705	24904	\N	52.139284000000004	г. Севск, ул. Ленина, д.49		0101000020E610000045D4449F8F3E4140946DE00ED4114A40
25224	1	2	1072	48412	24813	\N	51.994463000000003	п. Рабочий, ул. Садовая, д.10		0101000020E6100000813E9127491D4140810A47904AFF4940
25227	1	2	1072	9840	24747	\N	51.979466000000002	с. Поздняшовка, ул. Центральная, д.14		0101000020E610000050FC1873D72E4140A0C552245FFD4940
25221	1	2	1072	9503	24809	\N	52.055593000000002	с. Подывотье, ул. Молодежная, д.32		0101000020E61000006D1E87C1FC1141407A71E2AB1D074A40
25222	1	2	1072	9567	24811	\N	52.085785000000001	д. Подлесные Новоселки, ул. Центральная, д.22		0101000020E61000004AD1CABDC01E414062BEBC00FB0A4A40
24583	1	2	1072	10575	\N	\N	52.059984	п. Погребы, Здание Дома культуры		0101000020E61000008196AE601B4B41404224438EAD074A40
25223	1	2	1072	47727	24577	\N	52.095799275251998	с. Первомайское, ул. 65-й Армии, д. 4а	Россия, Брянская область, Севский район, поселок Первомайское	0101000020E61000008B87F71C582C4140A8FE4124430C4A40
25174	1	2	1072	47495	75039	\N	52.106870999999998	п.Первомаский, Школьная, 9 А		0101000020E61000006092CA147328414006F2ECF2AD0D4A40
25234	1	2	1072	48583	24824	\N	52.218347999999999	с. Новоямское, ул. Молодежная, д.17		0101000020E61000005CE84A04AA3D4140D192C7D3F21B4A40
25238	1	2	1072	10370	25107	\N	51.869166999999997	с. Некислица, ул. 8 Марта, д.58		0101000020E6100000A27F828B152F414097E13FDD40EF4940
25230	1	2	1072	51065	24785	\N	52.153393319644401	с. Марицкий Хутор, ул. Тихая Долина, д.3	Россия, Брянская область, Севский район, поселок Марицкий Хутор	0101000020E61000007B4963B48E364140B937BF61A2134A40
25240	1	2	1072	10476	24594	\N	51.927785999999998	с. Лемешовка, ул. Центральная, д.4		0101000020E610000093E1783E03224140E4D70FB1C1F64940
25237	1	2	1072	48645	24814	\N	52.172230999999996	д. Кривцово, ул. Провинциальная, д.1а		0101000020E61000008ACC5CE0F2484140BE2D58AA0B164A40
25226	1	2	1072	9739	24659	\N	52.060730999999997	п. Косицы, пер. Школьный, д.3		0101000020E61000008869DFDC5F3D41403B6D8D08C6074A40
25233	1	2	1072	10127	24986	\N	52.244608999999997	с. Заулье, ул. Копылова, д.1		0101000020E6100000C9772975C926414054A703594F1F4A40
25244	1	2	1072	48778	24983	\N	52.195252000000004	п. Заречный, ул. Молодежная, д.6		0101000020E6100000AFEC82C1353D4140433D7D04FE184A40
25248	1	2	1072	62084	81115	\N	52.1123880170924	п. Дубрава, Миловидова, д.27	Россия, Брянская область, Севский район, Севск	0101000020E61000009F573CF5483D41403F3BE0BA620E4A40
25241	1	2	1072	10515	24401	\N	52.107053000000001	с. Доброводье, ул. Ульянова, д.63		0101000020E6100000177FDB132456414027F8A6E9B30D4A40
25236	1	2	1072	51121	25163	\N	52.310341181454497	с. Голышина, ул. Центральная, д.22	Россия, Брянская область, Севский район, поселок Голышино	0101000020E61000009D7FBBECD7454140D1CDFE40B9274A40
25242	1	2	1072	51119	25156	\N	52.1498099211246	с. Гапонова, ул. Центральная, д.69	Россия, Брянская область, Севский район, поселок Гапоново	0101000020E61000003C86C77E16554140904E5DF92C134A40
25215	1	2	1023	9248	24486	\N	53.962705142548799	с.Шаровичи, Центральная, 28	Россия, Брянская область, Рогнединский район, поселок Шаровичи	0101000020E61000009A93179980DF40400C59DDEA39FB4A40
25220	1	2	1023	9462	24893	\N	53.846656000000003	с.Хариново, Школьная, 8		0101000020E6100000C7F5EFFACCB14040297B4B395FEC4A40
25219	1	2	1023	48334	24490	\N	53.890208000000001	с.Тюнино, Специалистов, 11		0101000020E61000003946B247A8AF40409C51F355F2F14A40
25214	1	2	1023	9203	24686	\N	53.846539	д.Старое Хотмирово, Школьная, 1		0101000020E61000004F90D8EE1EE64040EFE4D3635BEC4A40
25213	1	2	1023	48209	24786	\N	53.890521	с.Снопот, Центральная, 2		0101000020E610000035289A07B0D640405BB39597FCF14A40
25208	1	2	1023	8912	24479	\N	53.803654000000002	п.Рогнедино, Ленина, 40		0101000020E6100000A35698BED7C6404059A65F22DEE64A40
14697	1	2	1023	10524	24552	\N	53.878191999999999	с.Пацынь, Молодежная, 11		0101000020E610000064B14D2A1AC94040EECD6F9868F04A40
25218	1	2	1023	48323	24488	\N	53.984349999999999	с.Осовик, Школьная, 19		0101000020E6100000A4367172BFC14040A7E8482EFFFD4A40
25211	1	2	1023	9081	24685	\N	53.707079485132503	д.Лутовиновка, Набережная, 36	Россия, Брянская область, Рогнединский район, поселок Лутовиновка	0101000020E6100000CBF44BC45BD340401D588E9081DA4A40
24795	1	2	1023	51104	\N	\N	53.832470999999998	д. Летошники, Здание поселенческого Дома культуры	Россия, Брянская область, Рогнединский район, поселок Летошники	0101000020E6100000AF43352559B9404028EFE3688EEA4A40
25232	1	2	1023	48551	25090	\N	53.831806	с. Княгинино, ул. Молодежная, д.22	Россия, Брянская область, Рогнединский район, поселок Княгинино	0101000020E61000008D98D9E731CE4040EC4E779E78EA4A40
25217	1	2	1023	9341	24487	\N	53.942602999999998	п.Гобики, Советская, 3		0101000020E61000000B47904AB1C74040450E1137A7F84A40
25209	1	2	1023	48137	24485	\N	53.759138999999998	с.Вороново, им.Старостина, 15		0101000020E61000007F15E0BBCDD940401F0F7D772BE14A40
25182	1	2	861	7714	24729	\N	53.090108999999998	с.Шуморово, Тупицина, 1		0101000020E6100000677FA0DCB6B74040A20914B1888B4A40
25203	1	2	861	8725	24560	\N	52.966845999999997	с.Чопово, Школьная, 3		0101000020E61000002426A8E15BAA40405B22179CC17B4A40
14695	1	2	861	10430	24851	\N	52.874322999999997	с.Тубольцы, Лесная, 5	Россия, Брянская область, Почепский район, поселок Тубольцы	0101000020E6100000B40584D6C3A14040FF91E9D0E96F4A40
25180	1	2	861	47588	24842	\N	53.046742000000002	с.Третьяки, Клубная, 8		0101000020E6100000C287122D79B24040C1AC50A4FB854A40
25190	1	2	861	8073	25120	\N	53.045853999999999	с.Супрягино, Молодежная, 5		0101000020E6100000A9A10DC006A0404005323B8BDE854A40
25205	1	2	861	51139	25205	\N	52.983974794171402	с.Старопочепье, Центральная, 10 А	Россия, Брянская область, Почепский район, поселок Старопочелье	0101000020E61000000B630B410EA44040728A8EE4F27D4A40
25200	1	2	861	51136	25202	\N	52.8198950456988	с.Старокрасная Слобода, Школьный переулок, 14 Б	Россия, Брянская область, Почепский район, поселок Старокрасная Слобода	0101000020E610000095BBCFF1D1CC4040B493C151F2684A40
25175	1	2	861	47507	24551	\N	52.901904000000002	д.Сотниково, Колхозная, 13		0101000020E6100000B3B5BE4868A14040D8101C9771734A40
25199	1	2	861	8534	25049	\N	52.816991999999999	с.Семцы, Щемелинина, 34		0101000020E610000001DA56B3CEBA4040FC8BA03193684A40
25196	1	2	861	51150	25267	\N	52.992981111736	с.Сетолово, Советская, 11	Россия, Брянская область, Почепский район, поселок Светолово	0101000020E6100000F8DF4A766CC0404052465C001A7F4A40
25202	1	2	861	47994	24965	\N	52.858156000000001	с.Рогово, Центральная, 32		0101000020E6100000D7DCD1FF72AF4040DF6E490ED86D4A40
25164	1	2	861	51126	25177	\N	52.737294788424201	гпт. Рамасуха, Почепская, 1		0101000020E610000067EE21E17BC540408E40BCAE5F5E4A40
25397	1	2	861	47334	24689	\N	52.700034000000002	п.Прогресс, ул.Володарского д.2, здание Трубчевской метеостанции		0101000020E6100000857D3B8908B34040460BD0B69A594A40
25163	1	2	861	6463	24546	\N	52.939051821909899	г.Почеп, Усиевича, 8	Россия, Брянская область, Почепский район, Почеп	0101000020E610000033A31F0DA7BA4040279F1EDB32784A40
25161	1	2	861	6463	25068	\N	52.921281781298703	г.Почеп, Стародубская, 82	Россия, Брянская область, Почепский район, Почеп	0101000020E6100000105A0F5F26B840405D328E91EC754A40
25160	1	2	861	6463	24768	\N	52.924270999999997	г.Почеп, Октябрьская площадь, 1		0101000020E61000004E2A1A6B7FB9404013D21A834E764A40
25156	1	2	861	6463	24768	\N	52.924270999999997	г.Почеп, Октябрьская площадь, 2 А		0101000020E61000004E2A1A6B7FB9404013D21A834E764A40
25162	1	2	861	6463	24778	\N	52.924270999999997	г.Почеп, Ново-Полянская, 1		0101000020E61000004E2A1A6B7FB9404013D21A834E764A40
25159	1	2	861	6463	24741	\N	52.924270999999997	г.Почеп, Ново-Затинская, 48		0101000020E61000004E2A1A6B7FB9404013D21A834E764A40
25157	1	2	861	6463	24825	\N	52.924270999999997	г.Почеп, Колхозная, 5		0101000020E61000004E2A1A6B7FB9404013D21A834E764A40
25188	1	2	861	8002	24801	\N	53.010829999999999	д.Польники, Польниковская, 42		0101000020E6100000508D976E129F404068E89FE062814A40
25176	1	2	861	7451	24600	\N	52.948244000000003	с.Подбелово, Школьная, 5		0101000020E61000005AF0A2AF209740406A50340F60794A40
25178	1	2	861	7539	24999	\N	53.044176	д.Папсуевка, Центральная, 24		0101000020E61000008EACFC3218CD404051A2258FA7854A40
25168	1	2	861	47365	24460	\N	52.742072	п.Октябрьский, Школьная, 1		0101000020E6100000F701486DE2A440407FA31D37FC5E4A40
25185	1	2	861	7837	24614	\N	52.877261529651904	с.Милечь, Центральная, 58 Г	Россия, Брянская область, Почепский район, поселок Милечь	0101000020E6100000B459F5B9DAE040400403081F4A704A40
25183	1	2	861	7729	24923	\N	52.947201999999997	с.Красный Рог, 2-й переулок Толстого, 7 А		0101000020E6100000917F66101FDE4040575A46EA3D794A40
25416	1	2	861	47312	\N	\N	52.786580000000001	д. Котляково, здание администрации	Россия, Брянская область, Почепский район, поселок Котляково	0101000020E610000000AC8E1CE9A0404006D847A7AE644A40
25166	1	2	861	47312	24959	\N	52.786580000000001	с.Котляково, Гагарина, 17 А		0101000020E610000000AC8E1CE9A0404006D847A7AE644A40
25193	1	2	861	8245	24804	\N	52.882213999999998	д.Козорезовка, Набережная, 42		0101000020E6100000C38366D7BDB3404063096B63EC704A40
25167	1	2	861	47356	25038	\N	52.776057000000002	д.Кожемяки, Школьная, 8		0101000020E6100000E1455F419A9740407B6AF5D555634A40
25172	1	2	861	47458	24466	\N	52.794677999999998	с.Калачево ул. Набережная 2-а		0101000020E6100000C45E28603BAC4040E36C3A02B8654A40
25206	1	2	861	48074	24478	\N	52.951185000000002	п.Житня, Школьная, 6		0101000020E610000092955F0663AE40400FB9196EC0794A40
25179	1	2	861	51123	25169	\N	53.005093721264203	сДоманичи, Почепская, 1 А	Россия, Брянская область, Почепский район, поселок Доманичи	0101000020E6100000392A37514BB54040F2B391EBA6804A40
25177	1	2	861	47549	24876	\N	53.066755999999998	с.Дмитрово, Дмитировская, 55		0101000020E6100000A0FB7266BBC84040E867EA758B884A40
25197	1	2	861	8440	24806	\N	52.969557000000002	п.Громыки, Клубный, 1 В		0101000020E6100000C367EBE060BD4040CF4D9B711A7C4A40
25191	1	2	861	47788	24875	\N	53.059964999999998	с.Глазово, Центральная, 45		0101000020E610000037DE1D19ABA14040CBF3E0EEAC874A40
25039	1	2	861	32366	24820	\N	52.897862000000003	с. Вормино, ул. им. Новикова, д. 3		0101000020E61000007E3B8908FF9840401C295B24ED724A40
25198	1	2	861	51075	24884	\N	53.041944531637803	д.Волжино, Громышева, 4	Россия, Брянская область, Почепский район, поселок Воложино	0101000020E6100000310A82C7B7C14040889D29745E854A40
25173	1	2	861	7289	24714	\N	52.921128000000003	с.Витовка, Почепская, 94 А		0101000020E61000007A1D71C806C0404007B7B585E7754A40
25192	1	2	861	8161	24553	\N	52.894624	д.Верхняя Злобинка, Советская, 14		0101000020E6100000124BCADDE7AC4040BD1B0B0A83724A40
25204	1	2	861	8745	24567	\N	52.951678999999999	с. Васьковичи, Садовая, 10 А		0101000020E61000006D718DCF64A540401EA5129ED0794A40
25171	1	2	861	7179	24864	\N	52.747044154136297	с.Валуец, Клубная, 12	Россия, Брянская область, Почепский район, поселок Валуец	0101000020E6100000FF5BC98E8DB24040265646239F5F4A40
25169	1	2	861	47389	24464	\N	53.108536000000001	с.Бельково, Центральная, 52		0101000020E6100000CDAB3AAB059E40402638F581E48D4A40
25170	1	2	861	47412	24795	\N	53.089908999999999	с.Балыки, Мира, 41		0101000020E61000006631B1F9B8984040DB4E5B23828B4A40
25165	1	2	861	6897	24826	\N	52.742300999999998	с.Баклань, проспект Ленина, 14		0101000020E61000002FF7C95180A04040E0641BB8035F4A40
25181	1	2	861	7636	24432	\N	53.039118999999999	с.Алексеевск, Заречная, 42		0101000020E6100000E08096AE60AB40407CD3F4D901854A40
25152	1	2	578	6268	25062	\N	52.665804000000001	Брянская область, Погарский муниципальный район, Юдиновское сельское поселение, с.Юдиново, Бойня, 1		0101000020E6100000F819170E84A24040E3C5C21039554A40
25145	1	2	578	5875	24650	\N	52.634405999999998	Брянская область, Погарский муниципальный район, Стеченское сельское поселение, с.Чеховка, Советская, 53-а		0101000020E6100000ED0F94DBF6AF40406E313F3734514A40
25150	1	2	578	6162	24902	\N	52.402627000000003	Брянская область, Погарский муниципальный район, Чаусовское сельское поселение, с.Чаусы, Кооперативная, 11		0101000020E6100000B6F3FDD478A5404049BE124889334A40
25119	1	2	578	4492	24658	\N	52.542490000000001	Брянская область, Погарский муниципальный район, Гетуновское сельское поселение, п.Чайкино, Светлая		0101000020E6100000EDD286C3D29A40401A34F44F70454A40
25147	1	2	578	5995	24985	\N	52.509995000000004	Брянская область, Погарский муниципальный район, Суворовское сельское поселение, с.Суворово, Первомайская, 35-а		0101000020E61000004AED45B41DA34040D00F238447414A40
25141	1	2	578	5665	24934	\N	52.584272684331197	Брянская область, Погарский муниципальный район, Стеченское сельское поселение, с.Стечна, Новая, 3-а	Россия, Брянская область, Погарский район, поселок Стечна	0101000020E6100000DCF4673F52B04040C9772975C94A4A40
25151	1	2	578	6212	24586	\N	52.371540000000003	Брянская область, Погарский муниципальный район, Чаусовское сельское поселение, с.Сопычи, Садовя, 3		0101000020E61000002DEA93DC61AB4040F3936A9F8E2F4A40
25120	1	2	578	51082	24920	\N	52.553156143009701	Брянская область, Погарский муниципальный район, Гетуновское сельское поселение, х.Синицкий, Козина, 11	Россия, Брянская область, Погарский район, поселок Синицкий	0101000020E6100000C00985083894404008CBD8D0CD464A40
25128	1	2	578	5012	25024	\N	52.713357999999999	Брянская область, Погарский муниципальный район, Долботовское сельское поселение, с.Савостьяны, Воробьевка, 1-а		0101000020E61000009FC728CFBC984040842BA0504F5B4A40
25144	1	2	578	5858	24817	\N	52.584313999999999	Брянская область, Погарский муниципальный район, Стеченское сельское поселение, д.Романовка, Заречная, 34		0101000020E6100000F1B73D4162B94040274C18CDCA4A4A40
25440	1	2	578	20238	24815	\N	52.638674000000002	с. Рассуха, пер. Брянский, 2		0101000020E61000002AC93A1C5D8B40401B67D311C0514A40
25450	1	2	578	20238	24724	\N	52.638674000000002	пос. Рассуха, Линейная, 39	Россия, Брянская область, Погарский район, поселок Рассуха	0101000020E61000002AC93A1C5D8B40401B67D311C0514A40
25138	1	2	578	51078	24901	\N	52.633807045478498	Брянская область, Погарский муниципальный район, Прирубкинское сельское поселение, д.Прирубк, Новая, 6	Россия, Брянская область, Погарский район, поселок Прирубки	0101000020E61000007104A9143B904040E97C789620514A40
25113	1	2	578	4178	24525	\N	52.400165999999999	Брянская область, Погарский муниципальный район, Витемлянское сельское поселение, с.Евдоколье, Советская, 41		0101000020E610000072DC291DACAF40404E7CB5A338334A40
25136	1	2	578	5419	\N	\N	52.623429999999999	Брянская область, Погарский муниципальный район, Посудичское сельское поселение, с.Посудичи, Советская, 65	Россия, Брянская область, Погарский район, поселок Посудичи	0101000020E6100000666A12BC219F404032ACE28DCC4F4A40
25105	1	2	578	51098	25160	\N	52.5520744297352	Брянская область, Погарский муниципальный район, п.г.т.Погар, Фрунзе, 24	Россия, Брянская область, Погарский район, поселок Погар	0101000020E610000018EC866D8BA24040677C5F5CAA464A40
25107	1	2	578	51098	25206	\N	52.554396707274897	Брянская область, Погарский муниципальный район, п.г.т.Погар, Урицкого, 90	Россия, Брянская область, Погарский район, поселок Погар	0101000020E61000005532005471A1404011001C7BF6464A40
25102	1	2	578	51098	25011	\N	52.554392120385899	Брянская область, Погарский муниципальный район, п.г.т.Погар, площадь Советская, 1	Россия, Брянская область, Погарский район, поселок Погар	0101000020E6100000C7F5EFFACCA14040FF942A51F6464A40
25103	1	2	578	51098	25181	\N	52.552953617586901	Брянская область, Погарский муниципальный район, п.г.тПогар, Чехова, 9	Россия, Брянская область, Погарский район, поселок Погар	0101000020E6100000F871344756A04040A0185932C7464A40
25106	1	2	578	51098	25197	\N	52.558415752775801	Брянская область, Погарский муниципальный район, п.г.т.Погар, Октябрьская, 112	Россия, Брянская область, Погарский район, поселок Погар	0101000020E6100000261C7A8B87A1404015C8EC2C7A474A40
25104	1	2	578	51098	25151	\N	52.569070763012	Брянская область, Погарский муниципальный район, п.г.т.Погар, Ленина, 115	Россия, Брянская область, Погарский район, поселок Погар	0101000020E6100000E0DA899290A040400F0D8B51D7484A40
25101	1	2	578	51098	25281	\N	52.548266250628501	Брянская область, Погарский муниципальный район, п.г.т.Погар, Гагарина, 26	Россия, Брянская область, Погарский район, поселок Погар	0101000020E6100000581D39D219A240401EC18D942D464A40
25110	1	2	578	4017	24646	\N	52.482148000000002	Брянская область, Погарский муниципальный район, Борщовское сельское поселение, п.Песчанки, Кизеевская, 45		0101000020E610000017A06D35EB84404079EA9106B73D4A40
25122	1	2	578	4675	25112	\N	52.475489000000003	Брянская область, Погарский муниципальный район, Городищенское сельское поселение, д.Перегон, Пушкина, 113	Россия, Брянская область, Погарский район, поселок Перегон	0101000020E6100000BDFF8F13269E4040CB4DD4D2DC3C4A40
25130	1	2	578	5099	25105	\N	52.691122	Брянская область, Погарский муниципальный район, Долботовское сельское поселение, д.Михновка, Советская, 26-а		0101000020E61000001F48DE3994A54040E7C589AF76584A40
25137	1	2	578	5471	24687	\N	52.575307000000002	Брянская область, Погарский муниципальный район, Посудичское сельское поселение, д.Мадеевка, Полевая, 1		0101000020E610000010CEA78E559C40407714E7A8A3494A40
25124	1	2	578	4788	24924	\N	52.444491999999997	Брянская область, Погарский муниципальный район, Городищенское сельское поселение, д.Лукин, Центральная, 20-б		0101000020E610000031B5A50EF29E4040B4AA251DE5384A40
25109	1	2	578	3955	24642	\N	52.494250000000001	Брянская область, Погарский муниципальный район, Борщовское сельское поселение, с.Лобки, Пушкина, 22		0101000020E610000078B306EFAB94404025068195433F4A40
25148	1	2	578	6055	24847	\N	52.533748000000003	Брянская область, Погарский муниципальный район, Суворовское сельское поселение, с.Курово, Первомайская, 25-б		0101000020E61000002AE44A3D0BA440401827BEDA51444A40
25117	1	2	578	4381	25022	\N	52.450353999999997	Брянская область, Погарский муниципальный район, Витемлянское сельское поселение, п.Красный Угол, Мичурина, 6		0101000020E61000001763601DC7AB4040B7CF2A33A5394A40
25132	1	2	578	5123	24531	\N	52.406296111624499	Брянская область, Погарский муниципальный район, Кистерское сельское поселение, с.Кистер, Центральная, 11	Россия, Брянская область, Погарский район, поселок Кистер	0101000020E61000003B394371C78D4040703FE08101344A40
25131	1	2	578	5123	24527	\N	52.405718684359499	Брянская область, Погарский муниципальный район, Кистерское сельское поселение, с.Кистер, Центральная, 43	Россия, Брянская область, Погарский район, поселок Кистер	0101000020E61000003B394371C78D4040D32EA699EE334A40
25146	1	2	578	5953	25009	\N	52.647678999999997	Брянская область, Погарский муниципальный район, Стеченское сельское поселение, д.Карбовка, Партизанская, 50		0101000020E61000004489963C9EB840402AA73D25E7524A40
25155	1	2	578	6431	24400	\N	52.657229000000001	Брянская область, Погарский муниципальный район, Юдиновское сельское поселение, д.Казиловка, Зеленая, 15		0101000020E6100000FDF84B8BFAAA4040CC7D721420544A40
25116	1	2	578	4346	24573	\N	52.488751000000001	Брянская область, Погарский муниципальный район, Витемлянское сельское поселение, д.Исаевка, Первомайская, 19		0101000020E61000000875914259B4404093718C648F3E4A40
25153	1	2	578	6300	24861	\N	52.649635000000004	Брянская область, Погарский муниципальный район, Юдиновское сельское поселение,с.Заречное, Центральная, 67-б		0101000020E6100000E3FF8EA8509D404022AB5B3D27534A40
25114	1	2	578	51117	25153	\N	52.375087239637701	Брянская область, Погарский муниципальный район, Витемлянское сельское поселение, п.Запесочье, Центральная, 14-а	Россия, Брянская область, Погарский район, поселок Запесонье	0101000020E6100000346953758FB44040CF13CFD902304A40
25140	1	2	578	5627	25010	\N	52.622489999999999	Брянская область, Погарский муниципальный район, Прирубкинское сельское поселение, д.Жигалки, Луговая, 22		0101000020E6100000A4C519C39C924040240B98C0AD4F4A40
25509	1	2	1218	23561	25025	\N	52.541969999999999	Брянская область, Новозыбковский район, с. Новое Место, Луговая, 25		0101000020E61000001E6D1CB116CF3F40E1B4E0455F454A40
25127	1	2	578	4925	24444	\N	52.692442999999997	Брянская область, Погарский муниципальный район, Долботовское сельское поселение, д.Долботово, Новая, 19-а		0101000020E610000008E8BE9CD99E40400CACE3F8A1584A40
25123	1	2	578	4723	24543	\N	52.424275999999999	Брянская область, Погарский муниципальный район, Городищенское сельское поселение, с.Дареевск, Ленина, 27		0101000020E6100000B7F0BC546C9A4040253D0CAD4E364A40
25133	1	2	578	5243	24863	\N	52.369548999999999	Брянская область, Погарский муниципальный район, Кистерское сельское поселение, с.Гудовка, Центральная, 12		0101000020E61000009D9E7763419140407FA2B2614D2F4A40
25142	1	2	578	5760	24936	\N	52.538173999999998	Брянская область, Погарский муниципальный район, Стеченское сельское поселение, с.Грязивец, Центральная, 37		0101000020E6100000F8510DFB3DB540405CC7B8E2E2444A40
25125	1	2	578	4830	25118	\N	52.551214000000002	Брянская область, Погарский муниципальный район, Гриневское сельское поселение, с.Гринево, Новая, 7-а		0101000020E6100000E8A04B38F4864040768C2B2E8E464A40
25121	1	2	578	4597	24782	\N	52.475521999999998	Брянская область, Погарский муниципальный район, Городищенское сельское поселение, с.Городище, Чапаева, 2		0101000020E61000009E7C7A6CCB9A4040A643A7E7DD3C4A40
25118	1	2	578	4481	25026	\N	52.526161000000002	Брянская область, Погарский муниципальный район, Гетуновское сельское поселение, п.Гетуновка, Центральная, 18		0101000020E610000071CB4752D28F404020B75F3E59434A40
25112	1	2	578	4126	24759	\N	52.393225000000001	Брянская область, Погарский муниципальный район, Витемлянское сельское поселение, с.Витемля, Школьная, 8		0101000020E61000007098689082B540401C7C613255324A40
25115	1	2	578	4265	24436	\N	52.472318999999999	Брянская область, Погарский муниципальный район, Витемлянское сельское поселение, д.Василевка, Советская, 7		0101000020E61000005F9A22C0E9AD4040C423F1F2743C4A40
25111	1	2	578	4061	24757	\N	52.558683000000002	Брянская область, Погарский муниципальный район, Вадьковское сельское поселение, п.Вадьковка, Советская, 3		0101000020E6100000E38920CEC3A7404064EAAEEC82474A40
25143	1	2	578	5767	25101	\N	52.557166000000002	Брянская область, Погарский муниципальный район, Стеченское сельское поселение, д.Бугаевка, Светлая, 32		0101000020E6100000B39AAE27BAAE4040B9382A3751474A40
25126	1	2	578	4907	25084	\N	52.593527999999999	Брянская область, Погарский муниципальный район, Гриневское сельское поселение, с.Бобрик, Школьная, 5		0101000020E61000006269E047358A404051A1BAB9F84B4A40
25154	1	2	578	6368	24590	\N	52.685809999999996	Брянская область, Погарский муниципальный район, Юдиновское сельское поселение, с.Березовка, Новая, 1-а		0101000020E6100000823B50A73CAA404087A2409FC8574A40
25149	1	2	578	6086	24756	\N	52.512121	Брянская область, Погарский муниципальный район, Суворовское сельское поселение, п.Белевица, Советская, 55-а		0101000020E6100000361E6CB1DB9B4040234C512E8D414A40
25139	1	2	578	5562	25100	\N	52.654125999999998	Брянская область, Погарский муниципальный район, Прирубкинское сельское поселение, с.Балыкино, Центральная, 11		0101000020E6100000E4A1EF6E658F40404DBB9866BA534A40
25135	1	2	578	5311	24946	\N	52.384799999999998	Брянская область, Погарский муниципальный район, Кистерское сельское поселение, с.Андрейковичи, Слободская, 20		0101000020E61000004DDBBFB2D28040401AC05B2041314A40
25134	1	2	578	5311	24775	\N	52.384799999999998	Брянская область, Погарский муниципальный район, Кистерское сельское поселение, с.Андрейковичи, Зеленая, 4		0101000020E61000004DDBBFB2D28040401AC05B2041314A40
25129	1	2	578	51084	24943	\N	52.678798407274897	Брянская область, Погарский муниципальный район, Долботовское сельское поселение, д.Абаринки, Хуторская, 11	Россия, Брянская область, Погарский район, поселок Абарники	0101000020E6100000A4C684984B9640408C4B55DAE2564A40
25508	1	2	1218	23550	25023	\N	52.572783999999999	Брянская область, Новозыбковский район, с. Шеломы, Центральная, 91-А		0101000020E61000001F4DF564FED93F4006D671FC50494A40
25506	1	2	1218	51106	25119	\N	52.586492	Брянская область, Новозыбковский район, д. Халеевичи, Набережная, 21	Россия, Брянская область, Новозыбковский район	0101000020E61000003C50A73CBAE13F40CDAE7B2B124B4A40
25503	1	2	1218	23296	24539	\N	52.526434999999999	Брянская область, Новозыбковский район, д. Тростань, Хутор Сибирский, 30		0101000020E610000098DEFE5C34024040213CDA3862434A40
25501	1	2	1218	23186	24976	\N	52.531371	Брянская область, Новозыбковский район, с. Старый Кривец, Школьная, 1-А		0101000020E6100000321CCF67401B40407B8505F703444A40
25500	1	2	1218	23164	24545	\N	52.588844000000002	Брянская область, Новозыбковский район, с. Старый Вышков, 1 Мая, 2		0101000020E61000004982700514A63F4011397D3D5F4B4A40
25498	1	2	1218	23051	25108	\N	52.586863999999998	Брянская область, Новозыбковский район, с. Старые Бобовичи, Ленина, 29		0101000020E61000002CF015DD7ABD3F4091990B5C1E4B4A40
25505	1	2	1218	23385	25020	\N	52.488027000000002	Брянская область, Новозыбковский район, с.Сновское, Новая, 28-Б		0101000020E61000003D433866D9074040524832AB773E4A40
25497	1	2	1218	23024	24866	\N	52.621625999999999	Брянская область, Новозыбковский район, с. Синий Колодец, Центральный переулок, 3		0101000020E61000004A0A2C8029FB3F40F12BD670914F4A40
24616	1	2	1218	12145	24625	\N	52.577019999999997	Брянская область, Брянский муниципальный район, Отрадненское сельское поселение, с.Отрадное, ул.Советская, д.2		0101000020E610000048FE60E0B91D4040A79196CADB494A40
25492	1	2	1218	51083	\N	\N	52.512862484743899	Брянская область, Новозыбковский район, п. Опытная станция, 1д	Россия, Брянская область, Новозыбковский район, поселок Опытная станция	0101000020E6100000DAC70A7E1BDA3F403AAE4676A5414A40
25499	1	2	1218	23107	24781	\N	52.624178999999998	Брянская область, Новозыбковский район, с. Новые Бобовичи, Советская, 48		0101000020E610000023A46E675FB93F40CCECF318E54F4A40
25496	1	2	1218	22978	24480	\N	52.5807140307246	Брянская область, Новозыбковский район, с. Манюки, Первомайская, 52	Россия, Брянская область, Новозыбковский район, поселок Манюки	0101000020E610000034F279C553094040282A1BD6544A4A40
25504	1	2	1218	23328	25104	\N	52.507067999999997	Брянская область, Новозыбковский район, п. Мамай, ул. Молодежная, д.5/2		0101000020E61000005B24ED461FFF3F408F6CAE9AE7404A40
25494	1	2	1218	22894	24483	\N	52.583291000000003	Брянская область, Новозыбковский район, с. Белый Колодец, Лесная, 6	Россия, Брянская область, Новозыбковский район, поселок Лесная Поляна	0101000020E6100000643DB5FAEAC63F408C868C47A94A4A40
25495	1	2	1218	22909	25102	\N	52.573763	Брянская область, Новозыбковский район, д. Крутоберезка, Восточная, 1		0101000020E610000096B1A19BFDFD3F40D253E41071494A40
25490	1	2	1218	22728	24933	\N	52.669671000000001	Брянская область, Новозыбковский район, с. Катичи, Ленина, 106		0101000020E610000088F71C588EC43F40310A82C7B7554A40
25502	1	2	1218	23250	24977	\N	52.598609000000003	Брянская область, Новозыбковский район, с. Каташин, Молодежная, 14		0101000020E6100000FBC9181F66154040AF0B3F389F4C4A40
25493	1	2	1218	22829	25086	\N	52.542780999999998	Брянская область, Новозыбковский район, с. Замишево, Манюковская, 23		0101000020E6100000C2BF081A33014040F1F109D979454A40
24580	1	2	1218	51085	\N	\N	52.445864	с. Дубровка, Здание школы	Россия, Брянская область, Новозыбковский район, поселок Дубровка	0101000020E610000068CEFA94630040405C3B511212394A40
25491	1	2	1218	22758	24857	\N	52.492353000000001	Брянская область, Новозыбковский район, с. Деменка, Гагарина, 2а		0101000020E6100000C493DDCCE8DB3F40338B506C053F4A40
25489	1	2	1218	22662	24850	\N	52.731549000000001	Брянская область, Новозыбковский район, с. Верещаки, Коммунистическая, 64		0101000020E6100000ECC20FCEA7A63F40F435CB65A35D4A40
25058	1	2	7102	51055	24915	\N	52.5134093531681	Брянская область, город Новозыбков, ул. РОС, 5	Россия, Брянская область, Новозыбков городской округ	0101000020E6100000286211C30EFB3F406D3CD862B7414A40
25095	1	2	7102	51055	25115	\N	52.546188095167601	Брянская область, город Новозыбков, ул. Красногвардейская, 25		0101000020E6100000800BB265F9F23F40DCBB067DE9454A40
25082	1	2	209	2476	24428	\N	52.797308000000001	Брянская область, Навлинский муниципальный район, Щегловское сельское поселение, д. Щегловка, Школьная, 1		0101000020E61000002A3A92CB7F5841406A6B44300E664A40
25073	1	2	209	1964	25002	\N	52.998030999999997	Брянская область, Навлинский муниципальный район, Чичковское сельское поселение, с. Чичково, Л. Мирошина, 14/2		0101000020E610000081936DE00E40414074B2D47ABF7F4A40
25080	1	2	209	2352	25083	\N	52.893380000000001	Брянская область, Навлинский муниципальный район, Соколовское сельское поселение, с. Соколово, Северная, 5		0101000020E6100000A1478C9E5B52414043739D465A724A40
25079	1	2	209	2301	24507	\N	53.026452999999997	Брянская область, Навлинский муниципальный район, Синезерское сельское поселение, п. Синезерки, Школьная, 13		0101000020E61000009DB98784EF374140C7F0D8CF62834A40
25065	1	2	209	60442	75023	\N	52.839582999999998	Брянская область, Навлинский муниципальный район, Бяковское сельское поселение, д. Селище, Центральная, 6	Россия, Брянская область, Навлинский район, поселок Селище	0101000020E6100000B3CEF8BEB846414087A3AB74776B4A40
25078	1	2	209	2186	25082	\N	52.767938999999998	Брянская область, Навлинский муниципальный район, Салтановское сельское поселение, с. Салтановка, Школьная, 1А		0101000020E6100000F418E5999725414056293DD34B624A40
25077	1	2	209	2186	25000	\N	52.767938999999998	Брянская область, Навлинский муниципальный район, Салтановское сельское поселение, с. Салтановка, Молодежная, 35		0101000020E6100000F418E5999725414056293DD34B624A40
25075	1	2	209	2084	24737	\N	52.990779000000003	Брянская область, Навлинский муниципальный район, Ревенское сельское поселение, с. Ревны, Центральная, 34		0101000020E6100000E3E0D231E72341402448A5D8D17E4A40
25074	1	2	209	2013	24854	\N	52.873524000000003	Брянская область, Навлинский муниципальный район, Пролысовское сельское поселение, с. Пролысово, Центральная, 100		0101000020E610000083FB010F0C124140B4226AA2CF6F4A40
25063	1	2	209	1374	24414	\N	53.017330999999999	Брянская область, Навлинский муниципальный район, Чичковское сельское поселение, д. Прилепы, Центральная, 8		0101000020E610000054E6E61BD14941407E1AF7E637824A40
25072	1	2	209	1891	24617	\N	52.988480000000003	Брянская область, Навлинский муниципальный район, Чичковское сельское поселение, с. Приволье, Полевая, 49/1		0101000020E61000009B374E0AF33A414003603C83867E4A40
25081	1	2	209	2420	24837	\N	52.888876000000003	Брянская область, Навлинский муниципальный район, Соколовское сельское поселение, д. Пластовое, Слободская, 2		0101000020E61000009C89E942AC584140831953B0C6714A40
25057	1	2	209	798	24598	\N	52.828392999999998	Брянская область, Навлинский муниципальный район, Навлинское городское поселение, п. Навля, Филиппа Стрельца, 47		0101000020E6100000969350FA424041401F9E25C8086A4A40
25054	1	2	209	798	24709	\N	52.828756694983802	Брянская область, Навлинский муниципальный район, Навлинское городское поселение, п. Навля, Леонардо Гарсиа, 12	Россия, Брянская область, Навлинский район, поселок Навля	0101000020E61000006F7F2E1A3240414061AA99B5146A4A40
25056	1	2	209	798	24711	\N	52.8292767591957	Брянская область, Навлинский муниципальный район, Навлинское городское поселение, п. Навля, Ленина, 15	Россия, Брянская область, Навлинский район, поселок Навля	0101000020E6100000AC1A84B9DD3F41409929ADBF256A4A40
25053	1	2	209	798	24711	\N	52.828392999999998	Брянская область, Навлинский муниципальный район, Навлинское городское поселение, п. Навля, Ленина, 56		0101000020E6100000969350FA424041401F9E25C8086A4A40
25032	1	2	104	32102	24895	\N	53.273823999999998	с. Католино, ул. Ипутьская, д.56		0101000020E610000091D442C9E4684040116E32AA0CA34A40
25055	1	2	209	798	24710	\N	52.829192079115899	Брянская область, Навлинский муниципальный район, Навлинское городское поселение, п. Навля, Красных Партизан, 23	Россия, Брянская область, Навлинский район, поселок Навля	0101000020E61000001711C5E40D4041406B0DA5F6226A4A40
25070	1	2	209	1771	24734	\N	52.748123	Брянская область, Навлинский муниципальный район, Щегловское сельское поселение, с. Литовня, микрорайон Молодежный, 35		0101000020E6100000680586AC6E5141405531957EC25F4A40
25069	1	2	209	1719	24498	\N	52.822592	Брянская область, Навлинский муниципальный район, Щегловское сельское поселение, с. Лески, Молодежная, 23		0101000020E61000002670EB6E9E684140C2F9D4B14A694A40
25068	1	2	209	1666	24996	\N	52.926589	Брянская область, Навлинский муниципальный район, Клюковенское сельское поселение, п. Клюковники, Школьная, 8		0101000020E6100000325A4755133A4140ABEAE5779A764A40
25076	1	2	209	2143	24503	\N	53.016491000000002	Брянская область, Навлинский муниципальный район, Ревенское сельское поселение, д. Зубовка, Советская, 4		0101000020E610000084D558C2DA324140D4D688601C824A40
25067	1	2	209	1609	24833	\N	52.890794	Брянская область, Навлинский муниципальный район, Соколовское сельское поселение, с. Гремячее, Молодежная, 9		0101000020E6100000C89750C1E16741408CBCAC8905724A40
14694	1	2	209	49258	24641	\N	52.690663000000001	с. Глинное, Зеленая, 10		0101000020E6100000AED7F4A0A014414054C72AA567584A40
25066	1	2	209	1558	24716	\N	52.771054999999997	Брянская область, Навлинский муниципальный район, Вздруженское сельское поселение, с. Вздружное, Центральная, 19		0101000020E61000001DE38A8BA3044140693524EEB1624A40
25064	1	2	209	1439	24909	\N	52.871986	Брянская область, Навлинский муниципальный район, Бяковское сельское поселение, с. Бяково, Клубная, 6		0101000020E6100000BA85AE44A0464140F148BC3C9D6F4A40
25062	1	2	209	1321	24496	\N	52.982380999999997	Брянская область, Навлинский муниципальный район, Чичковское сельское поселение, с. Бутре, Садовая, 19		0101000020E6100000A1BAB9F8DB5241401B9B1DA9BE7D4A40
25071	1	2	209	1825	25081	\N	52.732519000000003	Брянская область, Навлинский муниципальный район, Навлинское городское поселение, с. Борщево, Центральная, 45		0101000020E6100000A33D5E48873D41406D59BE2EC35D4A40
25108	1	2	209	1825	24882	\N	52.730340183065799	Брянская область, Погарский муниципальный район, Борщовское сельское поселение,с.Борщово, Александра Яковца, 42	Россия, Брянская область, Навлинский район, поселок Борщево	0101000020E610000094162EABB03D4140F67AF7C77B5D4A40
25059	1	2	209	1155	24907	\N	52.681170000000002	Брянская область, Навлинский муниципальный район, Алтуховское городское поселение, п. Алтухово, Вяльцевой, 1А		0101000020E610000053E9279CDD2E414017821C9430574A40
25061	1	2	209	51079	24914	\N	52.851537600099498	Брянская область, Навлинский муниципальный район, Алешенское сельское поселение, с. Алешенка, Лесная, 28	Россия, Брянская область, Навлинский район, поселок Алешинка	0101000020E610000076887FD8D23141408FA67A32FF6C4A40
25060	1	2	209	1212	24828	\N	52.820062	Брянская область, Навлинский муниципальный район, Навлинское городское поселение, д. Алексеевка, переулок Дорожный, 1		0101000020E6100000143FC6DCB53441409F58A7CAF7684A40
25036	1	2	104	49131	24819	\N	53.110264999999998	с. Шумарово, пер. Афанасьева, д. 5		0101000020E610000092CD55F31C7540405C72DC291D8E4A40
25024	1	2	104	31741	24572	\N	53.049421000000002	с. Шеверды, ул. Центральная, д. 3		0101000020E6100000713AC956975B4040295E656D53864A40
25035	1	2	104	51152	25283	\N	53.167271057995301	д. Черновицы, ул. Советская, д. 11	Россия, Брянская область, Мглинский район, поселок Черновица	0101000020E6100000412B306475694040DC48D92269954A40
25033	1	2	104	32112	25055	\N	53.195915999999997	д, Цинка, ул. Суворова, д.14		0101000020E6100000A20914B1885F4040AE6186C613994A40
25046	1	2	104	350	24588	\N	52.971623000000001	д. Старая Романовка, ул. Молодёжная, д. 3		0101000020E6100000A6B6D4415E7B40404D8578245E7C4A40
25021	1	2	104	48902	24997	\N	52.991152999999997	с. Соколовка, ул. Партизан, д. 16	Россия, Брянская область, Мглинский район, поселок Соколовка	0101000020E61000009F211CB3EC6B4040882AFC19DE7E4A40
25022	1	2	104	31638	24812	\N	53.040666999999999	с. Симонтовка, ул. Цветочная, д. 1		0101000020E6100000CA6ABA9EE86240406283859334854A40
25044	1	2	104	220	75047	\N	53.0063876508584	с. Семки, ул. Колхозная, д.24	Россия, Брянская область, Мглинский район, поселок Семки	0101000020E610000019C6DD205A7F40401E8B6D52D1804A40
25045	1	2	104	49265	24701	\N	52.976594337602997	д. Попелёвка, ул. Молодёжная, д.2	Россия, Брянская область, Мглинский район, поселок Попелевка	0101000020E61000002C2CB81FF082404023BC3D08017D4A40
25030	1	2	104	31993	24810	\N	53.116729999999997	с. Новые Чешуйки, ул. Молодёжная, д. 7А		0101000020E61000004E0B5EF415664040253B3602F18E4A40
25043	1	2	104	148	24774	\N	53.006397999999997	с. Новая Романовка, ул. Школьная, д. 3		0101000020E61000008DEDB5A0F7784040416150A6D1804A40
25027	1	2	104	31848	24979	\N	53.075839999999999	с. Нетяговка, ул. Школьная, д. 8		0101000020E61000004660AC6F6066404044DD0720B5894A40
25034	1	2	104	32180	24575	\N	53.199286999999998	с. Молодьково, ул. Молодёжная, д. 14		0101000020E610000020EEEA55646A40404CC2853C82994A40
25050	1	2	104	441	24704	\N	53.050721000000003	г. Мглин, пл. Советская, д. 6А		0101000020E61000006CE9D1544F6C4040371C96067E864A40
25051	1	2	104	441	24708	\N	53.050721000000003	г. Мглин, ул. Первомайская, д. 57		0101000020E61000006CE9D1544F6C4040371C96067E864A40
25052	1	2	104	441	25066	\N	53.050721000000003	г. Мглин, ул. Октябрьская, д. 148		0101000020E61000006CE9D1544F6C4040371C96067E864A40
25047	1	2	104	441	24903	\N	53.060986035024499	г. Мглин, ул. Кирова, д. 13	Россия, Брянская область, Мглинский район, Мглин	0101000020E610000062BEBC00FB6A4040C6C1A563CE874A40
25048	1	2	104	441	25122	\N	53.050721000000003	г. Мглин, ул. Будённого, д. 7		0101000020E61000006CE9D1544F6C4040371C96067E864A40
25028	1	2	104	31906	24530	\N	53.139802000000003	с. Луговец, ул. Прудная, д. 10		0101000020E61000004C7155D9775540402CF52C08E5914A40
25029	1	2	104	31969	24489	\N	53.157732000000003	д. Красные Косары, ул. Садовая, д. 12		0101000020E6100000508C2C99635F40402FC4EA8F30944A40
25042	1	2	104	49225	25139	\N	53.034581000000003	с. Дивовка, ул. Молодёжная, д. 2		0101000020E6100000456458C51B854040100874266D844A40
25041	1	2	104	32464	25121	\N	53.057416000000003	д. Деремна, ул. Советская, д. 1	Россия, Брянская область, Мглинский район, поселок Деремна	0101000020E6100000FE2AC0779B9140403222516859874A40
25037	1	2	104	32292	25051	\N	53.060938999999998	д. Ветлевка, ул. Октябрьская, д. 33		0101000020E61000002C616D8C9D784040850662D9CC874A40
25040	1	2	104	32429	24585	\N	53.087085999999999	с. Вельжичи, ул. Пролетарская, д. 5		0101000020E6100000CAC4AD82188E404040F850A2258B4A40
25025	1	2	104	31764	24891	\N	52.995125999999999	с. Великая Дуброва, ул. Советская, д. 12		0101000020E6100000A31F0DA7CC5540401CB3EC49607F4A40
25031	1	2	104	49057	25056	\N	53.105265000000003	д. Быковка, ул. Советская, д. 2А		0101000020E6100000573F36C98F6C4040EC34D252798D4A40
25020	1	2	104	31534	25052	\N	52.939757	д. Бурчак, ул. Лесная, д. 25		0101000020E6100000B7D100DE02734040F29716F549784A40
25017	1	2	1899	31408	24565	\N	52.828626999999997	с.Яловка, ул.Луговая, д.7		0101000020E6100000CDACA580B4A33F4092CA1473106A4A40
25006	1	2	1899	30861	25039	\N	53.064450999999998	д.Фошное, ул.Центральная, д.1		0101000020E61000008350DEC7D15C3F40E5982CEE3F884A40
25018	1	2	1899	31426	24695	\N	52.783774999999999	с.Увелье, ул.Советская, д.54		0101000020E61000002BF697DD93A73F4011363CBD52644A40
25003	1	2	1899	48576	24469	\N	52.960878999999998	д.Селец, ул.Советская, д.52		0101000020E610000063B48EAA26B03F40E3344415FE7A4A40
25015	1	2	1899	48785	24970	\N	53.037526999999997	с.Перелазы, ул.Советская, д.39		0101000020E61000007D06D49B51773F40C6DB4AAFCD844A40
25013	1	2	1899	31172	24477	\N	53.070402999999999	д.Палужская Рудня, ул.Центральная, д.1		0101000020E6100000342E1C08C9963F4028452BF702894A40
25014	1	2	1899	48776	24966	\N	53.180911000000002	с.Медведи, ул.Центральная, д.8		0101000020E61000007847C66AF3AF3F404B3E761728974A40
25012	1	2	1899	31146	24561	\N	53.088692000000002	д.Макаричи, ул.Центральная, д.14		0101000020E6100000931CB0ABC9A33F405BB56B425A8B4A40
25010	1	2	1899	51146	25245	\N	52.984876826043198	д.Любовшо, ул.Советская, д.2	Россия, Брянская область, Краснорский район, поселок Любовша	0101000020E6100000685DA3E5408B3F4092CA1473107E4A40
25007	1	2	1899	30889	24803	\N	53.131411999999997	с.Лотаки, ул.Центральная, д.8		0101000020E6100000F16261889C923F40A626C11BD2904A40
25016	1	2	1899	31320	24916	\N	52.989960000000004	с.Летяхи, ул.Коммунистическая, д.8		0101000020E61000000D8B51D7DA6B3F40912C6002B77E4A40
25009	1	2	1899	31015	24472	\N	53.149312999999999	д.Ларневск, ул.Центральная, д.31		0101000020E6100000C173EFE192833F400FEF39B01C934A40
25005	1	2	1899	48607	24962	\N	53.127429999999997	д.Кургановка, ул.Центральная, д.94		0101000020E6100000392BA226FA6C3F40BF4351A04F904A40
24581	1	2	1899	51102	\N	\N	53.055526999999998	п. Красное, Здание Дома культуры	Россия, Брянская область, Краснорский район, поселок Красное	0101000020E61000004A44F81741573F40C2853C821B874A40
25000	1	2	1899	51031	24558	\N	53.008200967534599	пгт Красная Гора, пер.Московский, д.24	Россия, Брянская область, Краснорский район, поселок Красная Гора	0101000020E6100000BD18CA8976953F40B265F9BA0C814A40
24999	1	2	1899	51031	25246	\N	53.004631000000003	пгт Красная Гора, ул.Центральная, д.1	Россия, Брянская область, Краснорский район, поселок Красная Гора	0101000020E6100000AA29C93A1C993F401EC6A4BF97804A40
24998	1	2	1899	51031	25158	\N	52.989222015411997	пгт Красная Гора, ул.Куйбышева, 123	Россия, Брянская область, Краснорский район, поселок Красная Гора	0101000020E6100000774B72C0AE9E3F40EA3D95D39E7E4A40
24997	1	2	1899	51031	24874	\N	53.004631000000003	пгт Красная Гора, ул.Буйневича, д.66	Россия, Брянская область, Краснорский район, поселок Красная Гора	0101000020E6100000AA29C93A1C993F401EC6A4BF97804A40
24995	1	2	1899	51031	24874	\N	53.001265702287597	пгт Красная Гора, ул.Буйневича, д.44	Россия, Брянская область, Краснорский район, поселок Красная Гора	0101000020E610000026A94C3107993F40624CFA7B29804A40
24994	1	2	1899	51031	24874	\N	52.989791737601898	пгт Красная Гора, ул.Буйневича, д.14	Россия, Брянская область, Краснорский район, поселок Красная Гора	0101000020E6100000F4A44C6A689F3F40D5EB1681B17E4A40
24996	1	2	1899	51031	24455	\N	53.0106631253906	пгт Красная Гора, ул.Больничная, д.55	Россия, Брянская область, Краснорский район, поселок Красная Гора	0101000020E6100000C0CDE2C5C29C3F407D23BA675D814A40
25004	1	2	1899	30723	25129	\N	53.083576000000001	с.Колюды, ул.Центральная, д.10		0101000020E61000007C48F8DEDF683F40815D4D9EB28A4A40
25008	1	2	1899	30959	24471	\N	53.185302999999998	д.Кибирщина, ул.Центральная, д.2		0101000020E61000004B04AA7F10993F40E36C3A02B8974A40
25002	1	2	1899	30648	24675	\N	53.007980000000003	д.Дубенец, ул.Центральная, д.31		0101000020E61000008B33863941B73F40D482177D05814A40
25019	1	2	1899	31512	24969	\N	52.910527999999999	с.Городечня, ул.Совхозная, д.28		0101000020E61000007380608E1E9F3F40D00B772E8C744A40
25011	1	2	1899	31116	24554	\N	52.916246000000001	с.Верхличи, ул.Молодежная, д.8		0101000020E6100000E02A4F20EC803F40A08B868C47754A40
25001	1	2	1899	48539	\N	\N	53.062178000000003	д.Батуровка, ул.Садовая, д.6	Россия, Брянская область, Краснорский район, поселок Батуровка	0101000020E610000070CFF3A78DB63F40EE43DE72F5874A40
24978	1	2	1855	29478	\N	\N	52.406215000000003	"с. Шарово, здание МОУ ""Шаровская основная общеобразовательная школа"""		0101000020E610000001E0D8B3E7484140841266DAFE334A40
24986	1	2	1855	29840	\N	\N	52.321862000000003	с. Хлебтово, здание Хлебтовского сельского клуба		0101000020E610000066F50EB7437141409FE925C632294A40
24990	1	2	1855	30060	\N	\N	52.290022999999998	д. Усожа, здание Усожской сельской администрации		0101000020E61000004963B48EAA5C41403D0B42791F254A40
24992	1	2	1855	30146	\N	\N	52.331890000000001	"с. Угревище, здание МОУ ""Угревищская основная общеобразовательная школа"""		0101000020E6100000CF108E59F65441404AEF1B5F7B2A4A40
24993	1	2	1855	30171	\N	\N	52.225679999999997	"п. Тростенчик, здание МОУ ""Лукинская средняя общеобразовательная школа"""		0101000020E6100000EE3EC7478B5541403EAE0D15E31C4A40
24972	1	2	1855	29203	\N	\N	52.501657000000002	"с. Радогощь, здание МОУ ""Радогощская средняя общеобразовательная школа"""		0101000020E6100000C2F869DC9B6941409D67EC4B36404A40
24989	1	2	1855	51038	\N	\N	52.4047831155343	п. Марьинка, здание сельского Дома культуры	Россия, Брянская область, Комаричский район, поселок Пигарево	0101000020E610000073F56393FC604140077DE9EDCF334A40
24971	1	2	1855	29189	24794	\N	52.455621999999998	п. Лопандино, ул. Горького, д. 12		0101000020E6100000A088450C3B66414047AB5AD2513A4A40
24984	1	2	1855	29735	\N	\N	52.308824999999999	с. Литиж, здание Литижской сельской библиотеки		0101000020E61000000475CAA31B674140F697DD9387274A40
24982	1	2	1855	48188	\N	\N	52.445436000000001	"д. Лагеревка, здание МОУ ""Лагерёвская начальная общеобразовательная школа"""		0101000020E610000046B1DCD26A3E4140043BFE0B04394A40
24969	1	2	1855	28876	24666	\N	52.409744851161797	п. Комаричи, ул. Советская, д. 91	Россия, Брянская область, Комаричский район, поселок Комаричи	0101000020E61000005F0839EFFF6541408A592F8672344A40
24965	1	2	1855	28876	24666	\N	52.414696999999997	п. Комаричи, ул. Советская, 17		0101000020E61000001348895DDB654140E95F92CA14354A40
24964	1	2	1855	28876	24666	\N	52.414696999999997	п. Комаричи, ул. Советская, 28		0101000020E61000001348895DDB654140E95F92CA14354A40
24970	1	2	1855	28876	24990	\N	52.419363703230196	п. Комаричи, ул. Рабочая, д. 28	Россия, Брянская область, Комаричский район, поселок Комаричи	0101000020E6100000C2A4F8F884644140548F34B8AD354A40
24968	1	2	1855	28876	25070	\N	52.414696999999997	п. Комаричи, пер. Кирова, д. 7		0101000020E61000001348895DDB654140E95F92CA14354A40
24966	1	2	1855	28876	25037	\N	52.414696999999997	п. Комаричи, ул. Ленина, д. 37		0101000020E61000001348895DDB654140E95F92CA14354A40
24967	1	2	1855	28876	24456	\N	52.414696999999997	п. Комаричи, ул. Комсомольская, д. 55-В		0101000020E61000001348895DDB654140E95F92CA14354A40
24991	1	2	1855	30079	\N	\N	52.288050315836401	с. Избичня, здание Избичёнского сельского клуба	Россия, Брянская область, Комаричский район, поселок Избичня	0101000020E6100000D7DEA7AAD052414070CE88D2DE244A40
24980	1	2	1855	29584	\N	\N	52.388624999999998	"с. Игрицкое, здание МОУ ""Луганская средняя общеобразовательная школа"""		0101000020E61000000DFFE9060A38414039B4C876BE314A40
24985	1	2	1855	48259	\N	\N	52.221316999999999	"с. Евдокимовка, здание МОУ ""Евдокимовская средняя общеобразовательная школа"""		0101000020E6100000618907944D69414040868E1D541C4A40
24975	1	2	1855	48057	\N	\N	52.485636	"д. Добровольская, здание МОУ ""Лубошевская основная общеобразовательная школа"""		0101000020E6100000766EDA8CD34A414050E10852293E4A40
24988	1	2	1855	48322	\N	\N	52.369867999999997	"д. Дерюгино, здание МОУ ""Дерюгинская основная общеобразовательная школа"""		0101000020E61000003F0114234B68414020EBA9D5572F4A40
24976	1	2	1855	29394	\N	\N	52.424979	"с. Быхово, здание МОУ ""Быховская основная общеобразовательная школа"""		0101000020E61000006C938AC6DA5541404F3E3DB665364A40
24983	1	2	1855	48222	\N	\N	52.447121000000003	"с. Бобрик, здание МОУ ""Бобриковская средняя общеобразовательная школа"""	Россия, Брянская область, Комаричский район, поселок Бобрик	0101000020E6100000054EB6813B4241406B2DCC423B394A40
24981	1	2	1855	51074	\N	\N	52.329088658234902	"с. Асовица, здание МОУ ""Асовицкая основная общеобразовательная школа"""	Россия, Брянская область, Комаричский район, поселок Асовицы	0101000020E61000004B3D0B4279434140973C9E961F2A4A40
24974	1	2	1855	29313	\N	\N	52.496065000000002	с. Аркино, здание Аркинской сельской администрации		0101000020E6100000622F14B01D5441405AD8D30E7F3F4A40
24979	1	2	1855	29546	\N	\N	52.372788	"д. Апажа, здание МОУ ""Апажская основная общеобразовательная школа"""		0101000020E610000052103CBEBD534140AE2B6684B72F4A40
24958	1	2	7100	51036	24474	\N	52.744690514644702	город Клинцы, Школьная, 19	Россия, Брянская область, Клинцы городской округ	0101000020E61000000B96EA025E2240401250E108525F4A40
24953	1	2	7100	51036	24643	\N	52.759954541221802	город Клинцы, Ворошилова, 39	Россия, Брянская область, Клинцы городской округ	0101000020E6100000FF5C34643C20404041B7973446614A40
25487	1	2	1279	22570	24633	\N	52.795031999999999	Брянская область, Клинцовский муниципальный район, Смолевичское сельское поселение,п.Чемерна, Школьная, 4		0101000020E610000019028063CF1A404001A3CB9BC3654A40
25485	1	2	1279	22501	24628	\N	52.716445999999998	Брянская область, Клинцовский муниципальный район, Рожновское сельское поселение, с.Ущерпье, Школьная, 17		0101000020E6100000D97C5C1B2AE23F40CDACA580B45B4A40
25464	1	2	1279	21495	24788	\N	52.661057999999997	Брянская область, Клинцовский муниципальный район, Гулевское сельское поселение, с.Туросна, Центральная, 11		0101000020E6100000C64D0D349F1B40402C616D8C9D544A40
25408	1	2	1279	21978	\N	\N	52.827756000000001	д. Сосновка, Сосновская ООШ		0101000020E61000003E20D099B42D4040AD889AE8F3694A40
25474	1	2	1279	21978	24435	\N	52.827756000000001	Брянская область, Клинцовский муниципальный район, Коржовоголубовское сельское поселение, с.Сосновка, Школьная, 3		0101000020E61000003E20D099B42D4040AD889AE8F3694A40
25476	1	2	1279	22080	25094	\N	52.674613000000001	Брянская область, Клинцовский муниципальный район, Смотровобудское сельское поселение, с.Смотрова Буда, Советская, 73		0101000020E6100000AF7D01BD702540406D3A02B859564A40
25486	1	2	1279	22521	25018	\N	52.829748000000002	Брянская область, Клинцовский муниципальный район, Смолевичское сельское поселение, с.Смолевичи, Ленина, 4		0101000020E6100000F30181CEA41B4040F1F5B52E356A4A40
25481	1	2	1279	22303	24762	\N	52.699041000000001	Брянская область, Клинцовский муниципальный район, Первомайское сельское поселение, д.Рудня-Голубовка, Клинцовская, 10		0101000020E61000000EA14ACD1E14404015C8EC2C7A594A40
25483	1	2	1279	22388	24856	\N	52.739308000000001	Брянская область, Клинцовский муниципальный район, Рожновское сельское поселение, с.Рожны, Зеленая, 42		0101000020E6100000C1FD8007060A4040E9D500A5A15E4A40
25457	1	2	1279	22651	24954	\N	52.896557999999999	д. Песчанка, Мира, 69	Россия, Брянская область, Клинцовский район, поселок Песчанка	0101000020E6100000FE2AC0779B194040CC7B9C69C2724A40
25488	1	2	1279	22651	24940	\N	52.896557999999999	Брянская область, Клинцовский муниципальный район, Смолевичское сельское поселение, с.Песчанка, Зеленая, 14		0101000020E6100000FE2AC0779B194040CC7B9C69C2724A40
25479	1	2	1279	22210	24760	\N	52.745424999999997	Брянская область, Клинцовский муниципальный район, Первомайское сельское поселение, с.Первое Мая, Центральная, 1		0101000020E610000083C0CAA1451A4040764F1E166A5F4A40
25478	1	2	1279	22184	24935	\N	52.715786000000001	Брянская область, Клинцовский муниципальный район, Смотровобудское сельское поселение, с.Павличи, Центральная, 8		0101000020E6100000739D465A2A414040A3772AE09E5B4A40
25480	1	2	1279	22282	24730	\N	52.738396999999999	Брянская область, Клинцовский муниципальный район, Первомайское сельское поселение, с.Ольховка, Молодежная, 7		0101000020E61000002A37514B73114040753BFBCA835E4A40
25470	1	2	1279	21818	24437	\N	52.630766000000001	Брянская область, Клинцовский муниципальный район, Медведовское сельское поселение, п.Оболешево, Октябрьская, 2		0101000020E6100000CA198A3BDE284040E1B6B6F0BC504A40
25467	1	2	1279	21642	24511	\N	52.581418023860998	Брянская область, Клинцовский муниципальный район, Медведовское сельское поселение, с.Медведово, Центральная, 82	Россия, Брянская область, Клинцовский район, поселок Медведово	0101000020E6100000048D9944BD3C404022A7AFE76B4A4A40
25477	1	2	1279	22133	24439	\N	52.711035679426402	Брянская область, Клинцовский муниципальный район, Смотровобудское сельское поселение, с.Мартьяновка, Центральная, 94	Россия, Брянская область, Клинцовский район, поселок Мартьяновка	0101000020E6100000E23AC615172B4040AB23473A035B4A40
25462	1	2	1279	21424	24840	\N	52.542994	Брянская область, Клинцовский муниципальный район, Великотопальское сельское поселение, с.Малая Топаль, Школьная, 8а		0101000020E610000085CE6BEC122940404DF6CFD380454A40
25465	1	2	1279	21556	25013	\N	52.824475	Брянская область, Клинцовский муниципальный район, Лопатенское сельское поселение, с.Лопатни, Совхозная, 3		0101000020E6100000B74604E3E01240404FAF946588694A40
25472	1	2	1279	51154	25286	\N	52.768049415225299	Брянская область, Клинцовский муниципальный район, Коржовоголубовское сельское поселение, с.Коржовка-Голубовка, Советская, 7	Россия, Брянская область, Клинцовский район, поселок Коржово-Голубовка	0101000020E6100000B6662B2FF92D4040DD5CFC6D4F624A40
25469	1	2	1279	21731	24755	\N	52.604171999999998	Брянская область, Клинцовский муниципальный район, Медведовское сельское поселение, с.Киваи, Буденного, 56		0101000020E610000073BB97FBE42E404057941282554D4A40
25482	1	2	1279	22368	24937	\N	52.704045000000001	Брянская область, Клинцовский муниципальный район, Первомайское сельское поселение, п.Ивановщина, Займищенская, 25		0101000020E6100000A070766B991C4040C7F484251E5A4A40
25475	1	2	1279	22044	\N	\N	52.825890000000001	Брянская область, Клинцовский муниципальный район, Коржовоголубовское сельское поселение, п.Затишье, клуб, клуб		0101000020E6100000B1BFEC9E3C284040F60B76C3B6694A40
24961	1	2	1279	47779	24702	\N	52.722287999999999	село Займище, Клинцовская, 99		0101000020E61000009E2633DE561C40408925E5EE735C4A40
25468	1	2	1279	21697	24927	\N	52.625627999999999	Брянская область, Клинцовский муниципальный район, Медведовское сельское поселение, с.Душкино, Центральная, 33		0101000020E61000004963B48EAA3640401FBB0B9414504A40
25466	1	2	1279	21580	24512	\N	52.845587999999999	Брянская область, Клинцовский муниципальный район, Лопатенское сельское поселение, с.Гута-Корецкая, Свердлова, 50		0101000020E610000018B2BAD573044040EDF1423A3C6C4A40
25463	1	2	1279	21461	24605	\N	52.610877000000002	Брянская область, Клинцовский муниципальный район, Гулевское сельское поселение,с.Гулевка, Заводская, 7		0101000020E6100000558A1D8D431D40407670B037314E4A40
25473	1	2	1279	21948	24517	\N	52.798788999999999	Брянская область, Клинцовский муниципальный район, Коржовоголубовское сельское поселение, д.Вьюнка, пер.1 Центральный, 5		0101000020E61000007D96E7C1DD234040C8B3CBB73E664A40
25484	1	2	1279	51054	24649	\N	52.695491459660602	Брянская область, Клинцовский муниципальный район, Рожновское сельское поселение, д.Веприн, Песчаная, 29	Россия, Брянская область, Клинцовский район, поселок Веприно	0101000020E61000008D7A884677F43F40C7D45DD905594A40
25461	1	2	1279	21347	24748	\N	52.538688999999998	Брянская область, Клинцовский муниципальный район, Великотопальское сельское поселение, с.Великая Топаль, Октябрьская, 14а		0101000020E61000000DFE7E315B2E404083DBDAC2F3444A40
25471	1	2	1279	21833	24636	\N	52.58079	Брянская область, Клинцовский муниципальный район, Медведовское сельское поселение, д.Бутовск, Ленина, медпункт		0101000020E6100000C2DB83109033404003ECA353574A4A40
24959	1	2	1279	28639	24735	\N	52.734875000000002	село Ардонь, Зеленая, 21		0101000020E6100000315BB22AC2274040F2D24D62105E4A40
24935	1	2	1784	27563	24549	\N	52.130445000000002	Брянская область, Климовский муниципальный район, Кирилловское сельское поселение, с. Шумиловка, ул. Октябрьская, д.50		0101000020E6100000A643A7E7DD1840409F76F86BB2104A40
24939	1	2	1784	27728	24529	\N	52.169431000000003	Брянская область, Климовский муниципальный район, Чуровичское сельское поселение, с. Чуровичи, ул. Советская, д.1		0101000020E61000008B87F71C58004040DCF63DEAAF154A40
24940	1	2	1784	27728	25103	\N	52.167955639355696	Брянская область, Климовский муниципальный район, Чуровичское сельское поселение, с. Чуровичи, ул. Ленинская, д.106	Россия, Брянская область, Климовский район, поселок Чуровичи	0101000020E6100000C7478B3386FD3F405F950B957F154A40
24930	1	2	1784	51124	25170	\N	52.247332121310599	Брянская область, Климовский муниципальный район, Челховское сельское поселение, с. Челхов, ул.Набережная, д.90	Россия, Брянская область, Климовский район, поселок Чолхов	0101000020E6100000F64201DBC10840408CA03193A81F4A40
24916	1	2	1784	26673	24630	\N	52.400528000000001	Брянская область, Климовский муниципальный район, Истопское сельское поселение, с. Чернооково, ул. Молодежная, д.1-а		0101000020E61000001BD82AC1E2364040EF90628044334A40
24907	1	2	1784	26241	25017	\N	52.434472999999997	Брянская область, Климовский муниципальный район, Митьковское сельское поселение, с. Хохловка, ул. Школьная, д.1		0101000020E6100000226C787AA51C40405CFFAECF9C374A40
24938	1	2	1784	27696	24942	\N	52.070447999999999	Брянская область, Климовский муниципальный район, Хороменское сельское поселение, с. Хоромное, ул. Октябрьская, д.149		0101000020E610000088A1D5C919044040C808A87004094A40
24929	1	2	1784	27277	24698	\N	52.241874000000003	Брянская область, Климовский муниципальный район, Челховское сельское поселение, с. Фоевичи, ул. Советская, д.19		0101000020E610000049F59D5F94F83F4059E02BBAF51E4A40
24909	1	2	1784	26361	24431	\N	52.483634000000002	Брянская область, Климовский муниципальный район, Сытобудское сельское поселение, с. Сытая Буда, ул. Школьная, д.11		0101000020E6100000E4DBBB067D214040E99D0AB8E73D4A40
24924	1	2	1784	27055	24441	\N	52.194887000000001	Брянская область, Климовский муниципальный район, Новоропское сельское поселение, с. Сушаны, ул. Октябрьская, д.37		0101000020E6100000D9092FC1A927404031B5A50EF2184A40
24922	1	2	1784	26967	25016	\N	52.310724999999998	Брянская область, Климовский муниципальный район, Новоропское сельское поселение, с. Старый Ропск, ул. Ленина, д.64		0101000020E6100000A4FE7A8505214040598638D6C5274A40
24941	1	2	1784	27835	24945	\N	52.166831111098602	Брянская область, Климовский муниципальный район, Новоюрковичское сельское поселение, с. Старые Юрковичи, ул.Пролетарская, д.7	Россия, Брянская область, Климовский район, поселок Старые Юрковичи	0101000020E6100000C6E061DA37DB3F40C07ADCB75A154A40
24934	1	2	1784	27480	25033	\N	52.195847999999998	Брянская область, Климовский муниципальный район, Каменскохуторское сельское поселение, с. Соловьевка, ул. Мичурина, д.34		0101000020E6100000E6B1666490174040567E198C11194A40
24925	1	2	1784	27095	24443	\N	52.344006	Брянская область, Климовский муниципальный район, Сачковичское сельское поселение, с. Сачковичи, ул. Ленина, 34		0101000020E6100000E4BB94BA641C40405BD07B63082C4A40
24910	1	2	1784	26389	24515	\N	52.483524000000003	Брянская область, Климовский муниципальный район, Сытобудское сельское поселение, с. Рубежное, ул. Мира, д.1		0101000020E6100000823CBB7CEB254040626A4B1DE43D4A40
24914	1	2	1784	26595	\N	\N	52.494650999999998	Брянская область, Климовский муниципальный район, Плавенское сельское поселение, д. Пруска, здание сельского клуба, 84-а		0101000020E6100000952A51F6962E404083F755B9503F4A40
24911	1	2	1784	26454	24518	\N	52.457719495829501	Брянская область, Климовский муниципальный район, Плавенское сельское поселение, с. Плавна, Центральная площадь, д.8	Россия, Брянская область, Климовский район, поселок Плавна	0101000020E6100000D9E907759136404000E14389963A4A40
24921	1	2	1784	26922	25019	\N	52.301715999999999	Брянская область, Климовский муниципальный район, Новоропское сельское поселение, с. Новый Ропск, ул. Ленина, д.148		0101000020E61000003719558671274040085740A19E264A40
24942	1	2	1784	27859	24446	\N	52.115853000000001	Брянская область, Климовский муниципальный район, Новоюрковичское сельское поселение, с. Новые Юрковичи, ул. Советская, д.41		0101000020E610000074B680D07ADC3F405E126745D40E4A40
24918	1	2	1784	26762	24938	\N	52.378973000000002	Брянская область, Климовский муниципальный район, Сачковичское сельское поселение, с. Могилевцы, ул. Школьная, д.21		0101000020E6100000234BE658DE2340409488F02F82304A40
24906	1	2	1784	26212	24982	\N	52.431705000000001	Брянская область, Климовский муниципальный район, Митьковское сельское поселение, с. Митьковка, ул. Школьная, д. 2		0101000020E6100000382EE3A6061440408542041C42374A40
24920	1	2	1784	26843	24520	\N	52.334201	Брянская область, Климовский муниципальный район, Брахловское сельское поселение, с. Любечане, ул. Коммунистическая, д.48		0101000020E61000006CB1DB67952D40402FA52E19C72A4A40
24917	1	2	1784	26744	24858	\N	52.409638000000001	Брянская область, Климовский муниципальный район, Истопское сельское поселение, с. Лобановка, ул. Садовая, д.14		0101000020E6100000202A8D98D929404074999A046F344A40
24908	1	2	1784	26291	24640	\N	52.487605199241102	Брянская область, Климовский муниципальный район, Лакомобудское сельское поселение, с. Лакомая Буда, ул. Заречная, 19-б	Россия, Брянская область, Климовский район, поселок Лакомая Буда	0101000020E61000003D65355D4F124040DC2E34D7693E4A40
24931	1	2	1784	27339	24566	\N	52.177295999999998	Брянская область, Климовский муниципальный район, Челховское сельское поселение, с. Куршановичи, ул. Советская, д.5		0101000020E610000038BEF6CC920E404016DBA4A2B1164A40
24912	1	2	1784	26509	24883	\N	52.460748000000002	Брянская область, Климовский муниципальный район, Плавенское сельское поселение, с. Курозново, ул. Гагарина, д.2-а		0101000020E6100000C19140834D39404045D95BCAF93A4A40
24786	1	2	1784	51077	\N	\N	52.148457999999998	п. Красный Бор, Здание начальной общеобразовательной школы	Россия, Брянская область, Климовский район, поселок Красный Бор	0101000020E6100000D190F128952440402F6AF7AB00134A40
24927	1	2	1784	51141	25208	\N	52.255841346730897	Брянская область, Климовский муниципальный район, Челховское сельское поселение, с. Крапивное, ул. Заречная, д.5	Россия, Брянская область, Климовский район, поселок Крапивна	0101000020E6100000FB3F87F9F2124040EBFCDB65BF204A40
24899	1	2	1784	25913	24415	\N	52.386655732999102	Брянская область, Климовский муниципальный район, пгт Климово, пл. Ленина, 1-а		0101000020E6100000B0389CF9D5184040AE669DF17D314A40
24900	1	2	1784	25913	24841	\N	52.385080000000002	Брянская область, Климовский муниципальный район, пгт Климово, ул. Советская, д.61		0101000020E61000008692C9A99D174040FE2B2B4D4A314A40
24901	1	2	1784	25913	24753	\N	52.385080000000002	Брянская область, Климовский муниципальный район, пгт Климово, ул. Полевая, д.39		0101000020E61000008692C9A99D174040FE2B2B4D4A314A40
24905	1	2	1784	25913	24881	\N	52.379039971260603	Брянская область, Климовский муниципальный район, пгт Климово, ул. Октябрьская, д.70	Россия, Брянская область, Климовский район	0101000020E61000007F30F0DC7B1840401CF0F96184304A40
24904	1	2	1784	25913	24639	\N	52.385080000000002	Брянская область, Климовский муниципальный район, пгт Климово, ул. Лесная, д.30		0101000020E61000008692C9A99D174040FE2B2B4D4A314A40
24902	1	2	1784	25913	24898	\N	52.385080000000002	Брянская область, Климовский муниципальный район, пгт Климово, ул. Коммунистическая, 37		0101000020E61000008692C9A99D174040FE2B2B4D4A314A40
24903	1	2	1784	25913	24878	\N	52.385080000000002	Брянская область, Климовский муниципальный район, пгт Климово, ул. Брянская, д.45		0101000020E61000008692C9A99D174040FE2B2B4D4A314A40
24936	1	2	1784	27585	24767	\N	52.105383000000003	Брянская область, Климовский муниципальный район, Кирилловское сельское поселение, с. Кирилловка, ул. Советская, д.40		0101000020E61000001405FA449E144040F646AD307D0D4A40
24933	1	2	1784	51048	24603	\N	52.138911205534903	Брянская область, Климовский муниципальный район, Каменскохуторское сельское поселение, с. Каменский Хутор, ул. Ленина, д.99	Россия, Брянская область, Климовский район, поселок Каменский Хутор	0101000020E61000008B8C0E48C2204040FF06EDD5C7114A40
24913	1	2	1784	26523	\N	\N	52.463458000000003	Брянская область, Климовский муниципальный район, Плавенское сельское поселение, с. Каменка, здание ФАП, д.75-а		0101000020E610000024624A24D12D4040E8887C97523B4A40
24601	1	2	1784	26523	\N	\N	52.463458000000003	п. Каменка, Административное здание ФКУ ИК-4		0101000020E610000024624A24D12D4040E8887C97523B4A40
24915	1	2	1784	26651	25098	\N	52.418509	Брянская область, Климовский муниципальный район, Истопское сельское поселение, с. Истопки, ул. Октябрьская, д.25-а		0101000020E61000002191B6F1273A4040740AF2B391354A40
24932	1	2	1784	27410	24451	\N	52.136896	Брянская область, Климовский муниципальный район, Каменскохуторское сельское поселение, п. Забрама, ул. Набережная, д.76		0101000020E6100000397D3D5FB3264040037AE1CE85114A40
24928	1	2	1784	51052	24638	\N	52.292749530914897	Брянская область, Климовский муниципальный район, Челховское сельское поселение, с. Гетманова Буда, ул. Первомайская, д.83	Россия, Брянская область, Климовский район, поселок Гетманская Буда	0101000020E6100000B2B8FFC8740C4040B6F3FDD478254A40
24926	1	2	1784	27114	24848	\N	52.328285000000001	Брянская область, Климовский муниципальный район, Сачковичское сельское поселение, п. Воробьевка, ул. Озерная, д.13		0101000020E610000041446ADAC506404039622D3E052A4A40
24937	1	2	1784	27646	24941	\N	52.135767999999999	Брянская область, Климовский муниципальный район, Кирилловское сельское поселение, п. Вишневый, ул. Комсомольская, д.34		0101000020E6100000EC8497E0D4094040F2EB87D860114A40
24919	1	2	1784	26826	24746	\N	52.360183999999997	Брянская область, Климовский муниципальный район, Брахловское сельское поселение, с. Брахлов, ул. Цветная, 2		0101000020E61000008FFF0241803A40406F4562821A2E4A40
24883	1	2	1746	25133	\N	\N	53.321485000000003	Брянская область, Клетнянский муниципальный район, Мирнинское сельское поселение, д.Ширковка	Россия, Брянская область, Клетнянский район, поселок Ширковка	0101000020E6100000946C7539256C4040C993A46B26A94A40
24890	1	2	1746	25474	\N	\N	53.400253999999997	Брянская область, Клетнянский муниципальный район, Мирнинское сельское поселение, д.Харитоновка	Россия, Брянская область, Клетнянский район, поселок Харитоновка	0101000020E61000006AA33A1DC8804040ED0BE8853BB34A40
24877	1	2	1746	24907	\N	\N	53.163545999999997	Брянская область, Клетнянский муниципальный район, Акуличское сельское поселение, д.Строительная Слобода	Россия, Брянская область, Клетнянский район, поселок Строительная Слобода	0101000020E61000003830B9516493404020B24813EF944A40
24881	1	2	1746	25048	\N	\N	53.484668999999997	Брянская область, Клетнянский муниципальный район, Лутенское сельское поселение, д.Старая Мармазовка	Россия, Брянская область, Клетнянский район, поселок Старая Мармазовка	0101000020E6100000A0C37C79018A4040483140A209BE4A40
24896	1	2	1746	25786	\N	\N	53.467632000000002	Брянская область, Клетнянский муниципальный район, Надвинское сельское поселение, д.Синицкое	Россия, Брянская область, Клетнянский район, поселок Синицкое	0101000020E6100000068200193AAE40401348895DDBBB4A40
24884	1	2	1746	25181	\N	\N	53.405773000000003	Брянская область, Клетнянский муниципальный район, Мирнинское сельское поселение, д.Семиричи	Россия, Брянская область, Клетнянский район, поселок Семиричи	0101000020E61000003354C554FA6F4040C74CA25EF0B34A40
25228	1	2	1746	48489	24584	\N	53.351745999999999	с. Пушкино, ул. Понизовка, д.4		0101000020E6100000BD378600E0B04040D93F4F0306AD4A40
24897	1	2	1746	25831	\N	\N	53.488954999999997	Брянская область, Клетнянский муниципальный район, Надвинское сельское поселение, д.Павлинки	Россия, Брянская область, Клетнянский район, поселок Павлинки	0101000020E61000001A69A9BC1D9D40409B1BD31396BE4A40
24894	1	2	1746	25692	\N	\N	53.318919000000001	Брянская область, Клетнянский муниципальный район, Мужиновское сельское поселение, д.Новотроицкое	Россия, Брянская область, Клетнянский район, поселок Новотроицкое	0101000020E61000003599F1B6D2A3404059897956D2A84A40
24835	1	2	1689	22361	24570	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Федюнинского, 82		0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24898	1	2	1746	25846	\N	\N	53.400635000000001	Брянская область, Клетнянский муниципальный район, Надвинское сельское поселение, д.Новая Осиновка	Россия, Брянская область, Клетнянский район, поселок Новая Осиновка	0101000020E6100000E86C01A1F5A840400551F70148B34A40
24895	1	2	1746	25714	\N	\N	53.341999999999999	Брянская область, Клетнянский муниципальный район, Мужиновское сельское поселение, д.Николаевка	Россия, Брянская область, Клетнянский район, поселок Николаевка	0101000020E6100000A9DE1AD82AA54040B29DEFA7C6AB4A40
24893	1	2	1746	25647	\N	\N	53.264378000000001	Брянская область, Клетнянский муниципальный район, Мужиновское сельское поселение, д.Неделька	Россия, Брянская область, Клетнянский район, поселок Неделька	0101000020E6100000768A558330A9404015E46723D7A14A40
24892	1	2	1746	25562	\N	\N	53.258319	Брянская область, Клетнянский муниципальный район, Мужиновское сельское поселение, с.Мужиново	Россия, Брянская область, Клетнянский район, поселок Мужиново	0101000020E61000009F3C2CD49AA04040BC77D49810A14A40
24880	1	2	1746	25021	\N	\N	53.447702999999997	Брянская область, Клетнянский муниципальный район, Лутенское сельское поселение, с.Лутна	Россия, Брянская область, Клетнянский район, поселок Лутна	0101000020E61000003524EEB1F48B404019A9F7544EB94A40
24879	1	2	1746	24971	\N	\N	53.219484000000001	Брянская область, Клетнянский муниципальный район, Акуличское сельское поселение, д.Коршево	Россия, Брянская область, Клетнянский район, поселок Коршево	0101000020E6100000B5A679C729A0404065FF3C0D189C4A40
24525	1	2	1746	51100	\N	\N	53.277588000000002	п. Коммуна, Здание медпункта	Россия, Брянская область, Клетнянский район, поселок Коммуна	0101000020E610000017838769DF7440408BE1EA0088A34A40
24870	1	2	1746	51024	25162	\N	53.390975206154202	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Лесная, 71	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E610000093E2E313B29B4040DC4603780BB24A40
24876	1	2	1746	51024	24771	\N	53.393453546953197	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Первомайская	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E61000004B57B08D789C40407D3D5FB35CB24A40
24868	1	2	1746	51024	24497	\N	53.391701427854002	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Орджоникидзе	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E610000088F71C588E9C4040BE67244223B24A40
24872	1	2	1746	51024	25174	\N	53.390888223097903	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Медведева, 8	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E61000003198BF42E69C40400D33349E08B24A40
24867	1	2	1746	51024	25166	\N	53.394019999999998	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Ленина, 84	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E61000001DC9E53FA49D404026FC523F6FB24A40
24865	1	2	1746	51024	25166	\N	53.3841425840846	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Ленина, 128а	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E610000014EAE923F09B404061FE0A992BB14A40
24871	1	2	1746	51024	25184	\N	53.380768409585698	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Красных Партизан, 14	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E6100000C1559E40D89B404082AE7D01BDB04A40
24875	1	2	1746	51024	25180	\N	53.3952107041396	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Кирова, 40	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E610000004CB1132909B40407E02284696B24A40
24873	1	2	1746	51024	24409	\N	53.392984084602297	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Карла Маркса	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E610000044882B67EF9C4040F6ECB94C4DB24A40
24869	1	2	1746	51024	25229	\N	53.387272756678101	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Гоголя, 14а	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E61000000F62670A9D9D4040D9CF622992B14A40
24866	1	2	1746	51024	24712	\N	53.391196070163097	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Вокзальная	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E610000013109370219B4040BB29E5B512B24A40
24864	1	2	1746	51024	24712	\N	53.394851583049899	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, Вокзальная, 26	Россия, Брянская область, Клетнянский район, поселок Клетня	0101000020E61000008FE21C75749A40404E61A5828AB24A40
24886	1	2	1746	25266	\N	\N	53.352085000000002	Брянская область, Клетнянский муниципальный район, Мирнинское сельское поселение, д.Добрая Корна	Россия, Брянская область, Клетнянский район, поселок Добрая Корна	0101000020E6100000371B2B31CF7A4040C2340C1F11AD4A40
24888	1	2	1746	25379	\N	\N	53.311393000000002	Брянская область, Клетнянский муниципальный район, Клетнянское городское поселение, п.Быстрянка	Россия, Брянская область, Клетнянский район, поселок Быстрянка	0101000020E6100000D07CCEDDAE874040079ACFB9DBA74A40
24794	1	2	1016	21005	\N	\N	53.401628000000002	д. Белоголовль, Здание сельского клуба		0101000020E610000066F84F3750CE40403694DA8B68B34A40
24885	1	2	1746	25241	\N	\N	53.302241000000002	Брянская область, Клетнянский муниципальный район, Мирнинское сельское поселение, д.Болотня	Россия, Брянская область, Клетнянский район, поселок Болотня	0101000020E61000002D41464085734040534145D5AFA64A40
24891	1	2	1746	25552	\N	\N	53.264980999999999	Брянская область, Клетнянский муниципальный район, Мужиновское сельское поселение, д.Алень	Россия, Брянская область, Клетнянский район, поселок Алень	0101000020E6100000020D36751E954040DB87BCE5EAA14A40
24882	1	2	1746	25111	\N	\N	53.507531	Брянская область, Клетнянский муниципальный район, Лутенское сельское поселение, д.Алексеевка	Россия, Брянская область, Клетнянский район, поселок Алексеевка	0101000020E61000006BBB09BE69784040645A9BC6F6C04A40
24878	1	2	1746	51053	\N	\N	53.187014603359003	Брянская область, Клетнянский муниципальный район, Акуличское сельское поселение, с.1Акуличи	Россия, Брянская область, Клетнянский район, поселок Акуличи	0101000020E6100000ABCE6A813D9C4040446E861BF0974A40
24846	1	2	1689	23388	\N	\N	53.080044000000001	Брянская область, Карачевский муниципальный район, Бошинское сельское поселение, с.Юрасово, здание библиотеки		0101000020E61000009F3E027FF8814140DA1EBDE13E8A4A40
24840	1	2	1689	23053	\N	\N	53.126438771483699	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, , с.Рясники, зд-е нач. школы с.Рясники	Россия, Брянская область, Карачевский район, поселок Трыковка	0101000020E61000003AEAE8B81A7941402FF834272F904A40
24839	1	2	1689	23053	\N	\N	53.117097000000001	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, с.Трыковка, Адм. зд-е Карачевской гор. адм. № 5		0101000020E6100000C11E1329CD744140D8BAD408FD8E4A40
24853	1	2	1689	23721	\N	\N	53.036611999999998	Брянская область, Карачевский муниципальный район, Верхопольское сельское поселение, п.Теплое, зд-е Клуба		0101000020E61000000ABABDA4315041401152B7B3AF844A40
24842	1	2	1689	23196	\N	\N	53.095317000000001	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, п.Согласие, зд-е сельского клуба		0101000020E610000006A1BC8FA37941405DE0F258338C4A40
25212	1	2	1689	48187	24684	\N	53.067573000000003	д.Семеновка, Молодежная, 17		0101000020E6100000F6B52E3542A34140DB8B683BA6884A40
24863	1	2	1689	24192	\N	\N	52.962192000000002	Брянская область, Карачевский муниципальный район, Ревенское сельское поселение, с.Ружное, зд-е Ревенской с/а		0101000020E6100000126A865451624140863C821B297B4A40
24859	1	2	1689	23997	\N	\N	53.171287	Брянская область, Карачевский муниципальный район, Песоченское сельское поселение, д.Песочня, зд-е Песоченской с/а		0101000020E61000007520EBA9D57D41406F9D7FBBEC954A40
24860	1	2	1689	24035	\N	\N	53.223489999999998	Брянская область, Карачевский муниципальный район, Песоченское сельское поселение, п.Новгородский, зд-е Новгородской с/а		0101000020E61000009126DE019E804140D47D00529B9C4A40
24858	1	2	1689	23933	\N	\N	53.174368999999999	Брянская область, Карачевский муниципальный район, Мылинское сельское поселение, д.Мылинка, здание сельской библиотеки		0101000020E610000037177FDB136C4140D63730B951964A40
25186	1	2	1689	47700	24470	\N	53.311587000000003	п.Московский, Школьная, 2 А		0101000020E6100000C426327381834140EC6D3315E2A74A40
24838	1	2	1689	22980	\N	\N	53.123468961735298	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, д.Масловка, Адм. зд-е Карачевской гор. адм. № 2	Россия, Брянская область, Карачевский район, поселок Масловка	0101000020E61000005BB6D61709834140F0880AD5CD8F4A40
24837	1	2	1689	22980	\N	\N	53.123139000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, д.Масловка, зд-е Первомайской  школы		0101000020E610000084622B685A8441405BEECC04C38F4A40
24845	1	2	1689	51081	\N	\N	53.1425436063967	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, д.Мальтина, Адм. зд-е Карачевской гор. адм. № 4	Россия, Брянская область, Карачевский район, поселок Мальтино	0101000020E6100000849B8C2AC37E4140DA1EBDE13E924A40
24843	1	2	1689	51043	\N	\N	53.077891436511301	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, д.Мазнева, зд-е средней школы	Россия, Брянская область, Карачевский район, поселок Мазнево	0101000020E61000006FBBD05CA77941408DD31055F8894A40
24861	1	2	1689	24108	\N	\N	53.011392999999998	Брянская область, Карачевский муниципальный район, Ревенское сельское поселение, д.Лужецкая, зд-е Ревенской с/а		0101000020E610000095641D8EAE644140A033695375814A40
24862	1	2	1689	51072	\N	\N	52.9258091656856	"Брянская область, Карачевский муниципальный район, Ревенское сельское поселение, д.Куприна, зд-е к-ры СПК ""Восход"""	Россия, Брянская область, Карачевский район, поселок Куприно	0101000020E6100000F5D901D7156D4140D6ABC8E880764A40
24841	1	2	1689	51066	\N	\N	53.0890756121102	"Брянская область, Карачевский муниципальный район, Карачевское городское поселение, д.Коптилова, ТНВ ""Авангард"""	Россия, Брянская область, Карачевский район, поселок Коптилово	0101000020E61000004F93196F2B654140E36DA5D7668B4A40
24836	1	2	1689	22361	\N	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Федюнинского, 2	Россия, Брянская область, Карачевский район, Карачев	0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24792	1	2	1016	20857	\N	\N	53.356825000000001	д. Быковичи, Здание сельского Дома культуры		0101000020E61000008C118942CBCE404096B20C71ACAD4A40
24832	1	2	1689	22361	24571	\N	53.123333833957801	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Советская, 66-А	Россия, Брянская область, Карачевский район, Карачев	0101000020E61000008FE4F21FD27D4140103E9468C98F4A40
24831	1	2	1689	22361	24973	\N	53.117594482018902	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Свердлова, 2	Россия, Брянская область, Карачевский район, Карачев	0101000020E61000009DA1B8E34D7E4140581AF8510D8F4A40
24844	1	2	1689	22361	24502	\N	53.117981768694399	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г. Карачев, Первомайская, 45	Россия, Брянская область, Карачевский район, Карачев	0101000020E6100000EB1D6E87867D414022C2BF081A8F4A40
24834	1	2	1689	22361	24502	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Первомайская, 26		0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24827	1	2	1689	22361	24502	\N	53.118087767639601	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Первомайская, 227	Россия, Брянская область, Карачевский район, Карачев	0101000020E6100000B1868BDCD37D41406806F1811D8F4A40
24824	1	2	1689	22361	24680	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Кольцова, 36-А		0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24833	1	2	1689	22361	24929	\N	53.126113979068002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, К.Либкнехта, 34	Россия, Брянская область, Карачевский район, Карачев	0101000020E610000022E010AAD47C4140ACC8E88024904A40
24825	1	2	1689	22361	25048	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Заводская, 2		0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24830	1	2	1689	22361	24482	\N	53.120524864100503	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Дзержинского, 28	Россия, Брянская область, Карачевский район, Карачев	0101000020E610000070B378B1307E4140DAACFA5C6D8F4A40
24826	1	2	1689	22361	24975	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Горького, 1		0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24829	1	2	1689	22361	24484	\N	53.123561000000002	Брянская область, Карачевский муниципальный район, Карачевское городское поселение, г.Карачев, Володарского, 80-А		0101000020E6100000C2DF2F664B7E4140D107CBD8D08F4A40
24856	1	2	1689	23841	\N	\N	53.047390999999998	Брянская область, Карачевский муниципальный район, Дроновское сельское поселение, п.Дунаевский, зд-ние школы		0101000020E6100000F6419605139F4140F78F85E810864A40
24855	1	2	1689	51107	\N	\N	53.057098157020803	Брянская область, Карачевский муниципальный район, Дроновское сельское поселение, с.Дронова, зд-ние клуба	Россия, Брянская область, Карачевский район, поселок Дроново	0101000020E6100000F7B0170AD89841406155BDFC4E874A40
24852	1	2	1689	51068	\N	\N	53.018555820971898	"Брянская область, Карачевский муниципальный район, Верхопольское сельское поселение, д.Гощь, пом. к-ры СХП ""Железнодорожник"""	Россия, Брянская область, Карачевский район, поселок Гощь	0101000020E6100000A9D898D7115341408192020B60824A40
24851	1	2	1689	23640	\N	\N	53.074212000000003	Брянская область, Карачевский муниципальный район, Верхопольское сельское поселение, с.Верхополье, зд-е Библиотеки		0101000020E6100000A22424D236524140427C60C77F894A40
24850	1	2	1689	51037	\N	\N	53.042564778608401	Брянская область, Карачевский муниципальный район, Вельяминовское сельское поселениес.Вельяминова, зд-е сельсовета	Россия, Брянская область, Карачевский район, поселок Вельяминово	0101000020E610000027F911BF628B4140257A19C572854A40
24849	1	2	1689	51037	\N	\N	53.040805957539703	Брянская область, Карачевский муниципальный район, Вельяминовское сельское поселение, с. Вельяминова, д\\сад	Россия, Брянская область, Карачевский район, поселок Вельяминово	0101000020E61000007BC1A739798B414084BD892139854A40
24847	1	2	1689	23454	\N	\N	53.019601000000002	Брянская область, Карачевский муниципальный район, Бошинское сельское поселение, с.Бошино, зд-е средней школы		0101000020E6100000CF488446B07D414005FC1A4982824A40
24857	1	2	1689	23918	\N	\N	53.154719	"Брянская область, Карачевский муниципальный район, Мылинское сельское поселение, п.Березовка, зд-е СДК ""Березовсий"""		0101000020E6100000CF6A813D266A4140F0880AD5CD934A40
24854	1	2	1689	51090	\N	\N	53.102050399875502	Брянская область, Карачевский муниципальный район, Дроновское сельское поселение, д.Алымова, зд-е клуба	Россия, Брянская область, Карачевский район, поселок Алымово	0101000020E6100000B29DEFA7C6974140454772F90F8D4A40
24848	1	2	1689	51028	\N	\N	52.954068850747603	Брянская область, Карачевский муниципальный район, Бошинское сельское поселение, д.Алексеева, здание Библиотеки		0101000020E610000091D5AD9E937A41404F90D8EE1E7A4A40
24816	1	2	1672	22038	25046	\N	52.281593999999998	с.Спиридонова Буда, ул.Ленина, д.4		0101000020E6100000C1C58A1A4CC73F40FA5FAE450B244A40
24822	1	2	1672	49354	24556	\N	52.373353999999999	п.Софиевка, ул.Ленина, д.34		0101000020E61000009AB33EE598F03F4057EA5910CA2F4A40
24821	1	2	1672	22292	24557	\N	52.318883999999997	с.Рогов, ул.Ленина, д.2		0101000020E61000003CF71E2E39F23F40DC9BDF30D1284A40
24818	1	2	1672	22137	24961	\N	52.248722999999998	д.Петрятинка, ул.Первомайская, д.10		0101000020E61000000A83328D26DB3F40AA61BF27D61F4A40
24819	1	2	1672	22182	24887	\N	52.297508000000001	с.Малые Щербиничи, ул.Молодежная, д.16	Россия, Брянская область, Злынковский район, поселок Малые Щербиничи	0101000020E61000006808C72C7BE63F403126FDBD14264A40
24813	1	2	1672	21895	24967	\N	52.339087999999997	с.Лысые, ул.Молодежная, д.11		0101000020E61000008C31B08EE3A33F40A73B4F3C672B4A40
24817	1	2	1672	49297	24886	\N	52.213653000000001	д.Кожановка, ул.Школьная, д.12		0101000020E610000074CE4F711CD43F409DD843FB581B4A40
24815	1	2	1672	51131	25186	\N	52.326039836068702	д.Карпиловка, ул.Молодежная, д.11	Россия, Брянская область, Злынковский район, поселок Кириловка	0101000020E6100000D9976C3CD8C23F400B98C0ADBB294A40
24810	1	2	1672	21722	24958	\N	52.425901000000003	г.Злынка, пл.Свободы, д.30		0101000020E6100000282D5C5661BB3F40B72A89EC83364A40
24812	1	2	1672	21722	24742	\N	52.425901000000003	г.Злынка, ул.Республиканская, д.134 А		0101000020E6100000282D5C5661BB3F40B72A89EC83364A40
24811	1	2	1672	21722	24468	\N	52.425901000000003	г.Злынка, ул.Коммунальная, д.17		0101000020E6100000282D5C5661BB3F40B72A89EC83364A40
24807	1	2	1672	21583	25128	\N	52.480097000000001	с.Добродеевка, ул.Школьная, д.1		0101000020E61000001CEDB8E177A33F4030F488D1733D4A40
24814	1	2	1672	21945	25045	\N	52.308484	с.Денисковичи, ул.Злынковская, д.1		0101000020E610000012DE1E8480B43F406DAB59677C274A40
24809	1	2	1672	21640	24885	\N	52.477001245450403	р.п.Вышков, ул.Школьная, д.5	Россия, Брянская область, Злынковский район, поселок Вышков	0101000020E61000002A73F38DE8AE3F406494675E0E3D4A40
24808	1	2	1672	21640	24673	\N	52.476486999999999	р.п.Вышков, ул.Клубная площадь, 5		0101000020E610000047CA1649BBAD3F400DFCA886FD3C4A40
24820	1	2	1672	22206	24475	\N	52.316471999999997	с.Большие Щербиничи, ул.Центральная, д.9		0101000020E610000034F8FBC56CDD3F40C30C8D2782284A40
24790	1	2	1016	48881	\N	\N	53.386448999999999	д. Шамордино, Здание поселенческого Дома культуры		0101000020E6100000D717096D39E3404034492C2977B14A40
24798	1	2	1016	49018	\N	\N	53.479942999999999	п. Тросна, Здание поселенческого Дома культуры		0101000020E610000008228B34F1E44040D978B0C56EBD4A40
25201	1	2	1016	51091	24972	\N	53.625298000000001	с.Титовка, Школьная, 5 А	Россия, Брянская область, Жуковский район, поселок Титовка	0101000020E6100000EF53556820E640408A20CEC309D04A40
24785	1	2	1016	20516	\N	\N	53.430979000000001	с. Ржаница, Здание Ржаницкой средней школы		0101000020E61000003A5D16139BF54040A321E3512AB74A40
24788	1	2	1016	47848	\N	\N	53.372010000000003	с. Речица, Здание сельского Дома культуры		0101000020E610000091EEE714E4F540407AE40F069EAF4A40
25195	1	2	1016	47848	24473	\N	53.372010000000003	п.Речица, 70 лет Октября, 12		0101000020E610000091EEE714E4F540407AE40F069EAF4A40
25194	1	2	1016	47848	24473	\N	53.372010000000003	п.Речица, 70 лет Октября, 9	Россия, Брянская область, Жуковский район, поселок Речица	0101000020E610000091EEE714E4F540407AE40F069EAF4A40
24799	1	2	1016	49023	\N	\N	53.503363999999998	хутор Поляковка, Здание бывшей школы		0101000020E61000001B2D077AA8E74040EBFD463B6EC04A40
24803	1	2	1016	49100	\N	\N	53.619737999999998	д. Петуховка, Здание поселенческого Дома культуры		0101000020E6100000D122DBF97EEA4040520B259353CF4A40
24801	1	2	1016	21333	\N	\N	53.603627000000003	п. Олсуфьево, Здание сельского Дома культуры		0101000020E610000044149337C0D64040C6FD47A643CD4A40
24787	1	2	1016	20626	\N	\N	53.376882999999999	с. Овстуг, Здание поселенческого Дома культуры		0101000020E61000000875914259F040408DB5BFB33DB04A40
24797	1	2	1016	48988	\N	\N	53.503256999999998	"д. Никольская Слобода, Здание центр ""Юнеско"""		0101000020E6100000F9C08EFF02CD4040D53DB2B96AC04A40
24793	1	2	1016	20955	\N	\N	53.414774000000001	д. Леденево, Здание сельского клуба		0101000020E610000035D252793BD64040959D7E5017B54A40
24784	1	2	1016	48768	\N	\N	53.548473000000001	п. Латыши, Здание сельского Дома культуры		0101000020E610000024B891B245E2404098DEFE5C34C64A40
24791	1	2	1016	20844	\N	\N	53.369507423349603	с. Крыжино, Здание поселенческого Дома культуры	Россия, Брянская область, Жуковский район, поселок Крыжино	0101000020E61000000821205F42D94040505260014CAF4A40
24802	1	2	1016	21348	\N	\N	53.707253999999999	д. Касилово, Здание сельского Дома культуры		0101000020E610000063F19BC24AEF40408BFB8F4C87DA4A40
24789	1	2	1016	20737	\N	\N	53.422249000000001	д. Задубравье, Здание сельского клуба		0101000020E610000017D9CEF753DD404065E256410CB64A40
24783	1	2	1016	8782	\N	\N	53.529701000000003	г.Жуковка, Дом интернат для престарелых и инвалидов		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24778	1	2	1016	8782	24750	\N	53.529701000000003	г.Жуковка, пер. Школьный, 1		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24780	1	2	1016	8782	25113	\N	53.529701000000003	г.Жуковка, пер. Первомайский, 19		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24779	1	2	1016	8782	25030	\N	53.529701000000003	г.Жуковка, ул. Смоленская, 4А		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24775	1	2	1016	8782	24988	\N	53.529701000000003	г.Жуковка, пер. Первомайский, 43		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24773	1	2	1016	8782	24663	\N	53.5314217629738	г.Жуковка, ул. Ленина, 44А	Россия, Брянская область, Жуковский район, Жуковка	0101000020E61000000E130D52F0DC4040FD2FD7A205C44A40
24782	1	2	1016	8782	24715	\N	53.529701000000003	г.Жуковка, ул. Краснофокинская, 106Г		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24777	1	2	1016	8782	24784	\N	53.529701000000003	г.Жуковка, ул. Карла Маркса, 78А		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24776	1	2	1016	8782	24784	\N	53.529701000000003	г.Жуковка, ул. Карла Маркса, 80		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24774	1	2	1016	8782	25073	\N	53.530598453376101	г.Жуковка, ул. Карла Либкнехта, 2	Россия, Брянская область, Жуковский район, Жуковка	0101000020E61000000D39B69E21DC404058A9A0A2EAC34A40
14661	1	2	1016	8782	24897	\N	53.529701000000003	г.Жуковка, ул. Калинина, 1		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24772	1	2	1016	8782	24947	\N	53.529701000000003	г.Жуковка, ул.Калина, 38		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24781	1	2	1016	8782	24717	\N	53.530214911592601	г.Жуковка, ул. Заречная, 2А	Россия, Брянская область, Жуковский район, Жуковка	0101000020E6100000BD8C62B9A5DD4040A06CCA15DEC34A40
24760	1	2	1016	8782	24559	\N	53.529701000000003	г.Жуковка, ул.Дзержинского, 2		0101000020E61000000A4D124BCADD40404AD40B3ECDC34A40
24800	1	2	1016	40348	\N	\N	53.582683000000003	д. Гришина Слобода, Здание поселенческого дома культуры		0101000020E6100000AFEB17EC86E74040B477465B95CA4A40
24796	1	2	1016	48968	\N	\N	53.483828000000003	п. Гостиловка, Здание сельского клуба		0101000020E6100000BE2D58AA0BD84040CE716E13EEBD4A40
24756	1	2	1569	18895	24944	\N	53.265084000000002	Брянская область, Жирятинский муниципальный район, Жирятинское сельское поселение,с. Страшевичи, Школьная, 22		0101000020E610000092CA147310F24040B058C345EEA14A40
24765	1	2	1569	19364	24535	\N	53.183757273442502	Брянская область, Жирятинский муниципальный район, Жирятинское сельское поселение, с.Савлуково, Юбилейная, 1а	Россия, Брянская область, Жирятинский район, поселок Савлуково	0101000020E6100000664E97C5C4D840409EB4705985974A40
24769	1	2	1569	19603	24661	\N	53.132880999999998	Брянская область, Жирятинский муниципальный район, Воробейнское сельское поселение, с.Норино, Набережная, 56		0101000020E610000039B4C876BEAD404040A19E3E02914A40
24762	1	2	1569	19261	24458	\N	53.302236000000001	Брянская область, Жирятинский муниципальный район, Морачевское сельское поселение, с.Морачево, Пролетарская, 10		0101000020E6100000A2CF471971CD404041D653ABAFA64A40
24770	1	2	1569	19655	24662	\N	53.196416999999997	Брянская область, Жирятинский муниципальный район, Воробейнское сельское поселение, с.Кульнево, Клубная, 19		0101000020E6100000D33252EFA9C4404070B0373124994A40
25413	1	2	1569	18978	\N	\N	53.215445000000003	д. Комягино, СДК	Россия, Брянская область, Жирятинский район, поселок Комягино	0101000020E61000007ADE8D0585DF40401A8BA6B3939B4A40
24757	1	2	1569	18978	25106	\N	53.215445000000003	Брянская область, Жирятинский муниципальный район, Жирятинское сельское поселение, д.Комягино, Полевая, 3		0101000020E61000007ADE8D0585DF40401A8BA6B3939B4A40
24766	1	2	1569	19447	24537	\N	53.123165999999998	Брянская область, Жирятинский муниципальный район, Воробейнское сельское поселение, д.Колодня, Центральная, 19		0101000020E6100000CB4DD4D2DCCA404054FD4AE7C38F4A40
24761	1	2	1569	19193	24777	\N	53.294103999999997	Брянская область, Жирятинский муниципальный район, Морачевское сельское поселение, с.Княвичи, Пришкольная, 16		0101000020E6100000E36DA5D766D74040B7CF2A33A5A54A40
24977	1	2	1569	51143	\N	\N	53.244235000000003	"д. Заречная, здание МОУ ""Зареченская основная общеобразовательная школа"""	Россия, Брянская область, Жирятинский район, поселок Заречная	0101000020E6100000A0185932C7E84040F0C4AC17439F4A40
24764	1	2	1569	19002	25028	\N	53.226466000000002	Брянская область, Жирятинский муниципальный район, Жирятинское сельское поселение, с.Жирятино, Молодежная, 25		0101000020E610000076887FD8D2DD4040F6D37FD6FC9C4A40
24758	1	2	1569	19002	24534	\N	53.226466000000002	Брянская область, Жирятинский муниципальный район, Жирятинское сельское поселение, с.Жирятино, Мира, 10		0101000020E610000076887FD8D2DD4040F6D37FD6FC9C4A40
24759	1	2	1569	19002	25278	\N	53.220946709187501	Брянская область, Жирятинский муниципальный район, Жирятинское сельское поселение, с.Жирятинро, Ленина, 55	Россия, Брянская область, Жирятинский район, поселок Жирятино	0101000020E610000028603B18B1DB40401D93C5FD479C4A40
24763	1	2	1569	19278	24862	\N	53.254353999999999	Брянская область, Жирятинский муниципальный район, Морачевское сельское поселение, с.Высокое, Центральная, 6а		0101000020E61000007193516518C94040ABCDFFAB8EA04A40
25438	1	2	1569	19278	24939	\N	53.254353999999999	с. Высокое, Дружбы, 10А	Россия, Брянская область, Жирятинский район, поселок Высокое	0101000020E61000007193516518C94040ABCDFFAB8EA04A40
24767	1	2	1569	19486	24796	\N	53.153477000000002	Брянская область, Жирятинский муниципальный район, Воробейнское сельское поселение, с.Воробейня, Центральная, 2		0101000020E610000018778368ADC0404017D86322A5934A40
24768	1	2	1569	19527	24865	\N	53.16827	Брянская область, Жирятинский муниципальный район, Воробейнское сельское поселение, д.Буда, Молодежная, 12		0101000020E6100000A375543541B84040EF7211DF89954A40
24749	1	2	1458	18533	24769	\N	53.575620000000001	деревня Чернятичи, переулок Мира, 1а (здание сельской библиотеки)		0101000020E6100000F96706F181234140367689EAADC94A40
24751	1	2	1458	48156	24896	\N	53.447526000000003	"город Фокино, площадь Ленина, 2 (здание МУК ""Культурно-досуговый"		0101000020E610000083C13577F43341400B0E2F8848B94A40
24755	1	2	1458	48156	24773	\N	53.4592675525357	город Фокино, К.Маркса, 3а (СОШ №2)	Россия, Брянская область, Дятьковский район, Фокино	0101000020E6100000AEF4DA6CAC344140B70C384BC9BA4A40
24754	1	2	1458	48156	24773	\N	53.447526000000003	город Фокино, К.Маркса, 13 (ФИТ)		0101000020E610000083C13577F43341400B0E2F8848B94A40
24753	1	2	1458	48156	24773	\N	53.459344390231898	город Фокино, К.Маркса, 42а (здание СОШ №3)	Россия, Брянская область, Дятьковский район, Фокино	0101000020E6100000C2137AFD4934414092CEC0C8CBBA4A40
24752	1	2	1458	48156	24773	\N	53.447526000000003	город Фокино, К.Маркса, 17а (профессиональный лицей №13)		0101000020E610000083C13577F43341400B0E2F8848B94A40
24750	1	2	1458	48156	25021	\N	53.450276577597798	город Фокино, Гайдара, 7 (Центр детского творчества)	Россия, Брянская область, Дятьковский район, Фокино	0101000020E6100000DB368C82E03341400C923EADA2B94A40
24740	1	2	1458	18024	24538	\N	53.623539908060501	поселок Старь, Ленина, 5 (здание поселковой администрации)		0101000020E6100000A167B3EA73134140B9DFA128D0CF4A40
24739	1	2	1458	18024	24772	\N	53.626103999999998	поселок Старь, площадь 30 лет Победы, 11 (Здание Дома культуры)		0101000020E61000008DB454DE8E10414088F2052D24D04A40
24771	1	2	1458	19689	24664	\N	53.872990000000001	Брянская область, Жирятинский муниципальный район, Воробейнское сельское поселение, с.Рубча, Пролетарская, 15		0101000020E610000080F0A1444B0E414016DEE522BEEF4A40
24743	1	2	1458	48010	24665	\N	53.543897999999999	деревня Сосновка, Советская, 14 (здание сельского клуба)		0101000020E6100000AFEE586C932E41400E2E1D739EC54A40
24748	1	2	1458	48120	\N	\N	53.514400999999999	село Слободище, Садовая, 16 (здание Дома культуры)		0101000020E6100000365B79C9FF284140CD0358E4D7C14A40
24742	1	2	1458	18179	25029	\N	53.513496000000004	деревня Пупково, Советская, 1 (здание магазина №29, РАЙПО)		0101000020E610000024D236FE443941403C50A73CBAC14A40
24729	1	2	1458	17526	\N	\N	53.675075999999997	деревня ПСУРЬ, здание сельского клуба		0101000020E6100000894160E5D03A41404128EFE368D64A40
24747	1	2	1458	18447	24453	\N	53.850709000000002	село Немеричи, Школьная, 8 (здание ОШ)		0101000020E6100000232D95B723004140D9B45208E4EC4A40
24744	1	2	1458	18280	25031	\N	53.527918	деревня Неверь, Озерная, 24б (здание сельского клуба)		0101000020E6100000AE122C0E67324140207C28D192C34A40
24737	1	2	1458	17937	24438	\N	53.505710000000001	"поселок Любохна, Пушкина, 10 (здание Дома культуры ""Литейщик"""		0101000020E61000009770E82D1E3041404DA1F31ABBC04A40
24738	1	2	1458	17937	24766	\N	53.505710000000001	поселок Любохна, Брянская, 1 (здание администрации поселка)		0101000020E61000009770E82D1E3041404DA1F31ABBC04A40
24734	1	2	1458	17733	24765	\N	53.681348	поселок Ивот, Пролетарская, 9 (здание ДК)		0101000020E610000095607138F3194140F698486936D74A40
24733	1	2	1458	17733	24523	\N	53.681348	поселок Ивот, Горохова, 17 (здание СОШ)		0101000020E610000095607138F3194140F698486936D74A40
24721	1	2	1458	16658	24697	\N	53.605369000000003	город Дятьково, пл. Ленина, 1 (ДК МУК МКЦД)		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24718	1	2	1458	16658	24873	\N	53.604485309269201	"город Дятьково, Орджоникидзе, 2а (здание ДЮСШ ""Электрон"")"	Россия, Брянская область, Дятьковский район, Дятьково	0101000020E6100000E4486760E427414016F6B4C35FCD4A40
24725	1	2	1458	16658	24822	\N	53.6063868409382	город Дятьково, Ленина, 176 (здание МОО)	Россия, Брянская область, Дятьковский район, Дятьково	0101000020E6100000C9772975C92A41401ADCD6169ECD4A40
24724	1	2	1458	16658	24822	\N	53.610087561982901	город Дятьково, Ленина, 170	Россия, Брянская область, Дятьковский район, Дятьково	0101000020E6100000B05417F0322B41404DD7135D17CE4A40
24720	1	2	1458	16658	24822	\N	53.605369000000003	"город Дятьково, Ленина, 161 (здание МУК ""Дятьковский Дом Ку"		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24715	1	2	1458	16658	24822	\N	53.603323928824899	город Дятьково, Ленина, 224 ( ПУ №14)	Россия, Брянская область, Дятьковский район, Дятьково	0101000020E61000004E9B711AA22A41402A7288B839CD4A40
24716	1	2	1458	16658	24513	\N	53.605369000000003	город Дятьково, Крупской, 5 (здание ДСОШ №2)		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24726	1	2	1458	16658	24440	\N	53.605369000000003	город Дятьково, Краснофлотская, 2 (здание ДСОШ №5)		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24719	1	2	1458	16658	24495	\N	53.590646244431802	город Дятьково, Красина, 22 (здание ДСОШ №3)	Россия, Брянская область, Дятьковский район, Дятьково	0101000020E6100000C05DF6EB4E2D4140B1C1C2499ACB4A40
24717	1	2	1458	16658	25093	\N	53.605369000000003	город Дятьково, Киевская, 36а (здание нач. школы-детского сад		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24722	1	2	1458	16658	24609	\N	53.592040277504601	город Дятьково, К. Маркса, 7а (здание ДИТ)	Россия, Брянская область, Дятьковский район, Дятьково	0101000020E6100000658A39083A2A414040F67AF7C7CB4A40
24723	1	2	1458	16658	24667	\N	53.605369000000003	город Дятьково, В.Рябка, 2а (здание МУП г. Дятьково ВКХ)		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24728	1	2	1458	16658	24521	\N	53.605369000000003	город Дятьково, 13 микрорайон, 2а (здание ДСОШ №4 г. Дятьково)		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24711	1	2	1458	16658	24521	\N	53.605369000000003	город Дятьково, 13 микрорайон, 2а (здание ДСОШ №4) г. Дятьково)		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24727	1	2	1458	16658	24676	\N	53.605369000000003	город Дятьково, 12 микрорайон, 2 (общ. ООО ЖЭУ №1)		0101000020E6100000D656EC2FBB2B414091813CBB7CCD4A40
24745	1	2	1458	48050	25060	\N	53.571530000000003	поселок Дружба, Октябрьская, 9 (здание СОШ)	Россия, Брянская область, Дятьковский район, поселок Дружба	0101000020E6100000B1DEA815A62F4140695721E527C94A40
24746	1	2	1458	48072	24978	\N	53.436734999999999	деревня Верхи, Рябка, 2а (здание ОШ)		0101000020E61000009F1F46088F3E41406002B7EEE6B74A40
24730	1	2	1458	17602	25087	\N	53.798996000000002	поселок Бытошь, Ленина, 61 (здание СОШ п. Бытошь)	Россия, Брянская область, Дятьковский район, поселок Бытошь	0101000020E6100000295E656D5310414042D13C8045E64A40
24731	1	2	1458	17602	25012	\N	53.798996000000002	поселок Бытошь, Алексеева, 1а		0101000020E6100000295E656D5310414042D13C8045E64A40
24732	1	2	1458	17707	24644	\N	53.840223000000002	деревня Будочка, Центральная, 9 (здание СОШ)		0101000020E6100000615111A7931441406B2C616D8CEB4A40
24741	1	2	1458	47982	25043	\N	53.486136999999999	"деревня Березино, Керамическая, 11 (здание конторы СПК ""Фокинский"")"	Россия, Брянская область, Дятьковский район, поселок Березино	0101000020E6100000E6046D72F83841401230BABC39BE4A40
24735	1	2	1458	17827	24964	\N	53.730747129704703	село Бацкино, Приозерная, 33 (здание отделения связи)	Россия, Брянская область, Дятьковский район, поселок Бацкино	0101000020E6100000BE839F3880FC40403753211E89DD4A40
24712	1	2	1110	16689	24925	\N	53.678905999999998	Брянская область, Дубровский муниципальный район, Сещинское сельское поселение, д.Старое Колышкино, ул.Центральная, д.27		0101000020E6100000BD0166BE83A5404072874D64E6D64A40
24708	1	2	1110	16449	24752	\N	53.717703999999998	Брянская область, Дубровский муниципальный район, Сещинское сельское поселение, п.Сеща, ул.Центральная, д.1		0101000020E610000019C91EA166B24040AC1A84B9DDDB4A40
24707	1	2	1110	16449	24752	\N	53.717703999999998	Брянская область, Дубровский муниципальный район, Сещинское сельское поселение, п.Сеща, ул.Центральная, д.14		0101000020E610000019C91EA166B24040AC1A84B9DDDB4A40
24706	1	2	1110	16374	25085	\N	53.579635000000003	Брянская область, Дубровский муниципальный район, Рябчинское сельское поселение, п.Серпеевский, ул.Центральная, д.14		0101000020E610000013BA4BE2ACAE4040F94ECC7A31CA4A40
24705	1	2	1110	16354	24616	\N	53.566192999999998	Брянская область, Дубровский муниципальный район, Рябчинское сельское поселение, с.Рябчи, ул.Центральная, д.39		0101000020E610000008944DB9C2BB4040B01C210379C84A40
24703	1	2	1110	51026	24423	\N	53.659017375407302	Брянская область, Дубровский муниципальный район, Рековичское сельское поселение, сРековичи, ул.Журавлева, д.19	Россия, Брянская область, Дубровский район, поселок Рековичи	0101000020E6100000315F5E807DCC4040074147AB5AD44A40
24710	1	2	1110	16574	24580	\N	53.765825877788103	Брянская область, Дубровский муниципальный район, Сещинское сельское поселение, д.Радичи, ул.Центральная, д.3а	Россия, Брянская область, Дубровский район, поселок Радичи	0101000020E6100000209738F240AE404097361C9606E24A40
24701	1	2	1110	16152	24607	\N	53.554426999999997	Брянская область, Дубровский муниципальный район, Пеклинское сельское поселение, д.Пеклино, ул.Калинина, д.32		0101000020E6100000F06E6589CEC240407B82C476F7C64A40
24702	1	2	1110	16165	24731	\N	53.592357	Брянская область, Дубровский муниципальный район, Пеклинское сельское поселение, д.Новая Салынь, ул.Центральная, д.29		0101000020E6100000B72A89EC83CA40404147AB5AD2CB4A40
24698	1	2	1110	15970	24728	\N	53.718173	Брянская область, Дубровский муниципальный район, Дубровское городское поселение, д.Немерь, пер.Садовый, д.7		0101000020E61000005A9F724C16BF404063EFC517EDDB4A40
24700	1	2	1110	16068	25080	\N	53.503048	Брянская область, Дубровский муниципальный район, Пеклинское сельское поселение, д.Мареевка, ул.Клубная, д.1		0101000020E61000009EB30584D6BF4040BB287AE063C04A40
24704	1	2	1110	16265	24838	\N	53.698650999999998	Брянская область, Дубровский муниципальный район, Рековичское сельское поселение, д.Зимницкая Слобода, ул.Совхозная, д.6		0101000020E6100000C6A70018CFC84040AA285E656DD94A40
24696	1	2	1110	15779	24421	\N	53.689785000000001	Брянская область, Дубровский муниципальный район, Дубровское городское поселение, п.Дубровка, пер.Матросова, 8		0101000020E6100000FA2B64AE0CC04040BC22F8DF4AD84A40
24695	1	2	1110	15779	24726	\N	53.693452329330199	Брянская область, Дубровский муниципальный район, Дубровское городское поселение, п.Дубровка, ул.Ленина, д.84	Россия, Брянская область, Дубровский район, поселок Дубровка	0101000020E6100000AB4198DBBDC0404043ACFE08C3D84A40
24694	1	2	1110	15779	24725	\N	53.689785000000001	Брянская область, Дубровский муниципальный район, Дубровское городское поселение, п.Дубровка, ул.60 лет Октября, 16-а		0101000020E6100000FA2B64AE0CC04040BC22F8DF4AD84A40
24693	1	2	1110	15779	24839	\N	53.689347209059903	Брянская область, Дубровский муниципальный район, Дубровское городское поселение, 1-ый Микрорайон, школа №2	Россия, Брянская область, Дубровский район, поселок Дубровка	0101000020E61000003BC8EBC1A4C04040404CC2853CD84A40
24697	1	2	1110	51113	25145	\N	53.675595238680202	Брянская область, Дубровский муниципальный район, Дубровское городское поселение, д.Давыдчи, ул.Центральная, д.21	Россия, Брянская область, Дубровский район, поселок Давыдчичи	0101000020E610000042EC4CA1F3BE4040AA2B9FE579D64A40
24709	1	2	1110	16565	24635	\N	53.742235000000001	Брянская область, Дубровский муниципальный район, Сещинское сельское поселение, д.Большая Островня, ул, Центральная, д.11		0101000020E6100000F9A3A833F7A640402979758E01DF4A40
25229	1	2	1110	9932	24587	\N	53.600468999999997	с. Бересток, ул. Центральная, д.20		0101000020E6100000E9995E622CCF404083A10E2BDCCC4A40
24714	1	2	1110	16789	24761	\N	53.670478000000003	Брянская область, Дубровский муниципальный район, Сергеевское сельское поселение, д.Афонино, ул.Школьная, д.5		0101000020E6100000FCFD62B66491404000581D39D2D54A40
24699	1	2	1110	16044	24727	\N	53.637895448634197	Брянская область, Дубровский муниципальный район, Алешинское сельское поселение, с.Алешня, ул.Административная, д.7	Россия, Брянская область, Дубровский район, поселок Алешня	0101000020E61000009B3924B550BA404016A4198BA6D14A40
24713	1	2	1110	16754	25058	\N	53.641406000000003	Брянская область, Дубровский муниципальный район, Сергеевское сельское поселение, д.Алёшинка, ул.Лесная, д.3а		0101000020E6100000F9307BD976964040A6BA809719D24A40
24691	1	2	1179	47024	24948	\N	52.984777999999999	д. Ямное, Центральная, 4	Россия, Брянская область, Гордеевский район, поселок Ямное	0101000020E6100000751DAA29C9D63F40FFE89B340D7E4A40
24622	1	2	1179	45572	25069	\N	53.064911000000002	д. Ширяевка, Дорожная, 15/2	Россия, Брянская область, Гордеевский район, поселок Ширяевка	0101000020E61000001AF7E6374CE83F404913EF004F884A40
24681	1	2	1179	46807	24713	\N	52.957630000000002	д. Черный Ручей, Совхозная, 10		0101000020E6100000874F3A91600C404091D5AD9E937A4A40
24690	1	2	1179	51148	25257	\N	53.048517844716699	д. Хармынка, Центральная, 34 помещение медпункта	Россия, Брянская область, Гордеевский район, поселок Хаминка	0101000020E6100000A8FDD64E94CC3F4038A27BD635864A40
24689	1	2	1179	15575	24422	\N	53.002659000000001	с. Уношево, Красногорская, 15		0101000020E6100000E4F90CA837CF3F4021054F2157804A40
24680	1	2	1179	15122	24827	\N	52.935040999999998	с. Творишино, Школьная, 1		0101000020E610000068CBB91457054040A6B5696CAF774A40
24657	1	2	1179	51109	25142	\N	53.033149578070201	с. Стругова Буда, Юбилейная, 7		0101000020E61000009D0FCF126402404063EE5A423E844A40
24130	1	2	1179	20747	24670	\N	53.015673	д. Струговка, Цветочная, 27/1		0101000020E61000008D25AC8DB10940401137A79201824A40
24597	1	2	1179	11217	24949	\N	53.011881000000002	д. Староновицкая, Школьная, 1		0101000020E6100000A12E52280BEB3F40CE380D5185814A40
24684	1	2	1179	15324	25072	\N	52.943426000000002	д. Старая Полона, Школьная, 8		0101000020E61000008DB62A89ECD73F401A19E42EC2784A40
24688	1	2	1179	15494	24830	\N	52.801935999999998	с. Смяльч, Советская, 59 В		0101000020E6100000B7D3D68860D83F4016BEBED6A5664A40
24682	1	2	1179	15198	24411	\N	52.993603	д. Рудня -Воробьевка, Центральная, 28		0101000020E610000088BB7A1519F53F408F1A13622E7F4A40
24683	1	2	1179	51096	25003	\N	52.982322000000003	д. Поповка, Первомайская, 48	Россия, Брянская область, Гордеевский район, поселок Поповка	0101000020E6100000234BE658DEE93F40171230BABC7D4A40
24679	1	2	1179	46762	24405	\N	52.902495999999999	д. Поконь, Красноармейская, 12		0101000020E610000017B9A7AB3BFA3F40AA622AFD84734A40
24685	1	2	1179	15366	74991	\N	52.859085	Брянская область, с.Петрова Буда ул. Красногорская, д.27, помещение сел. админ		0101000020E61000009AD024B1A4C43F40F9BD4D7FF66D4A40
24686	1	2	1179	15420	24599	\N	52.884338999999997	с. Перетин, Гордеевская, 17		0101000020E6100000C03E3A75E5D73F40E6C9350532714A40
24687	1	2	1179	15482	24912	\N	52.881920999999998	д. Малоудебное, Школьная, 2/1		0101000020E61000005186AA984AB73F40EB538EC9E2704A40
24692	1	2	1179	47041	24668	\N	52.949199	с. Кузнецы, Недоливко, 3		0101000020E61000002E20B41EBEB83F40AD32535A7F794A40
25419	1	2	1179	49234	\N	\N	52.7901035630316	д. Кжжа, СДК	Россия, Брянская область, Гордеевский район, поселок Кожаны	0101000020E6100000793C2D3F70B93F402A38BC2022654A40
24353	1	2	1179	49234	24491	\N	52.790517999999999	с. Кожаны, Садовая, 14		0101000020E6100000750470B378B93F401D739EB12F654A40
24678	1	2	1179	51094	24998	\N	52.889462500916203	с. Завод-Корецкий, Школьная, 7	Россия, Брянская область, Гордеевский район, поселок Заводокорецкий	0101000020E6100000BE30992A18F13F40430070ECD9714A40
24677	1	2	1179	46715	24403	\N	52.959707741078098	с. Гордеевка, Ленина, 46	Россия, Брянская область, Гордеевский район, поселок Гордеевка	0101000020E61000008A3BDEE4B7F83F40D3DA34B6D77A4A40
25435	1	2	1179	51112	25144	\N	53.039476000000001	д. Березина, Буденного, 29А	Россия, Брянская область, Гордеевский район, поселок Березина	0101000020E61000004609FA0B3DF63F400B7DB08C0D854A40
24676	1	2	1297	14942	24592	\N	53.1099192702831	Брянская область, Выгоничский муниципальный район, Хутор-Борское сельское поселение, п. Хутор-Бор, Луговая, 1-б	Россия, Брянская область, Выгоничский район, поселок Хутор Бор	0101000020E610000095B9F946741D4140C11A67D3118E4A40
24675	1	2	1297	14879	24989	\N	53.031343	Брянская область, Выгоничский муниципальный район, Хмелевское сельское поселение, д. Хмелево, Молодежная, 40		0101000020E610000054C6BFCFB8F24040B1FA230C03844A40
24670	1	2	1297	14651	24703	\N	52.917217999999998	Брянская область, Выгоничский муниципальный район, Утынское сельское поселение, с. Уручье, Центральная, 69		0101000020E6100000AA9B8BBFEDFB4040B9A6406667754A40
24674	1	2	1297	51025	24413	\N	52.9277730760396	Брянская область, Выгоничский муниципальный район, Хмелевское сельское поселение, с. Сосновое Болото, Партизанская, 6	Россия, Брянская область, Выгоничский район, поселок Сосновое Болото	0101000020E610000086E464E256ED4040508E0244C1764A40
24669	1	2	1297	14602	24987	\N	53.004593	Брянская область, Выгоничский муниципальный район, Сосновское сельское поселение, с. Сосновка, Салова, 4		0101000020E6100000DA1D520C900041403065E08096804A40
24654	1	2	1297	13888	24922	\N	53.164464000000002	Брянская область, Выгоничский муниципальный район, Кокинское сельское поселение, с. Скуратово, Ольховая, 27		0101000020E610000066C1C41F450B414047AF06280D954A40
24667	1	2	1297	14516	25063	\N	53.138289	Брянская область, Выгоничский муниципальный район, Скрябинское сельское поселение, д. Скрябино, Школьная, 1-а		0101000020E610000018D2E1218C0F4140C2323674B3914A40
24666	1	2	1297	51093	24995	\N	53.147578449309798	Брянская область, Выгоничский муниципальный район, Скрябинское сельское поселение, с. Палужье, Школьная, 7	Россия, Брянская область, Выгоничский район, поселок Полужье	0101000020E6100000E8305F5E80174140F7CDFDD5E3924A40
24656	1	2	1297	13990	24691	\N	53.109032999999997	Брянская область, Выгоничский муниципальный район, Красносельское сельское поселение, п. Пильшино, Садовая, 2		0101000020E61000009F03CB1132F64040A69718CBF48D4A40
25449	1	2	1297	48343	24722	\N	52.881720000000001	с. Павловка, Школьная, 1		0101000020E61000009BFF571D39FC4040541D7233DC704A40
24665	1	2	1297	14432	24583	\N	53.152850000000001	Брянская область, Выгоничский муниципальный район, Орменское сельское поселение, д. Орменка, Парковая, 3		0101000020E61000005D16139B8FF54040C898BB9690934A40
24660	1	2	1297	14187	24494	\N	53.033148668572302	Брянская область, Выгоничский муниципальный район, Лопушское сельское поселение, д. Мякишево, Молодежная, 14	Россия, Брянская область, Выгоничский район, поселок Мякишево	0101000020E61000003B8C497F2F0141409372F7393E844A40
24664	1	2	1297	14353	24984	\N	53.114362999999997	Брянская область, Выгоничский муниципальный район, Орменское сельское поселение, д. Малфа, Больничная, 6		0101000020E61000001B6327BC04E34040AC6F6072A38E4A40
24659	1	2	1297	14148	25117	\N	53.057524000000001	Брянская область, Выгоничский муниципальный район, Лопушское сельское поселение, с. Лопушь, Деснянская, 6		0101000020E6100000A16AF46A80064140185E49F25C874A40
24673	1	2	1297	14788	25065	\N	53.005974999999999	Брянская область, Выгоничский муниципальный район, Хмелевское сельское поселение, п. Красный Рог, Заводской пер, 3-а		0101000020E610000058ACE122F7DE4040FBCBEEC9C3804A40
24655	1	2	1297	13925	24492	\N	53.067946999999997	Брянская область, Выгоничский муниципальный район, Красносельское сельское поселение, с. Красное, Школьная, 4		0101000020E610000059164CFC51F440403F6EBF7CB2884A40
24973	1	2	1297	51095	\N	\N	53.160204	"д. Кокино, здание МОУ ""Кокинская средняя общеобразовательная школа"""	Россия, Брянская область, Выгоничский район, поселок Кокино	0101000020E610000006465ED6C40E41401D588E9081944A40
24653	1	2	1297	51095	25214	\N	53.159661949886697	Брянская область, Выгоничский муниципальный район, Кокинское сельское поселение. с. Кокино, Советская, 6-а		0101000020E610000053EA92718C0E4140FC34EECD6F944A40
24652	1	2	1297	51095	25214	\N	53.159861146343601	Брянская область, Выгоничский муниципальный район, Кокинское сельское поселение с. Кокино, Советская, 2-а	Россия, Брянская область, Выгоничский район, поселок Кокино	0101000020E61000007F2F8507CD0E4140F373435376944A40
24662	1	2	1297	14288	24900	\N	53.188864000000002	Брянская область, Выгоничский муниципальный район, Орменское сельское поселение, п. Евтиховский, Соловьиная, 10		0101000020E61000008A1D8D43FDFA404025B20FB22C984A40
24671	1	2	1297	14685	24399	\N	52.872356000000003	Брянская область, Выгоничский муниципальный район, Утынское сельское поселение, п. Деснянский, Школьная, 3		0101000020E61000004359F8FA5AF94040153C855CA96F4A40
24668	1	2	1297	14536	24595	\N	52.971932940403597	Брянская область, Выгоничский муниципальный район, Сосновское сельское поселение, п. Десна, Заречная, 5-а	Россия, Брянская область, Выгоничский район, поселок Десна	0101000020E6100000CB2DAD86C40141409B73F04C687C4A40
24651	1	2	1297	13755	24981	\N	53.130204912847397	Брянская область, Выгоничский муниципальный район, Выгоничское городское поселение, с. Городец, ул. Центральная д. 15, здание МОУ "Городецкая ООШ"	Россия, Брянская область, Выгоничский район, поселок Городец	0101000020E6100000B82231410D0741404963B48EAA904A40
24650	1	2	1297	13604	24980	\N	53.093651000000001	Брянская область, Выгоничский муниципальный район, Выгоничское городское поселение, п. Выгоничи, Свердлова, 10		0101000020E61000002BC1E270E60541406D1E87C1FC8B4A40
24649	1	2	1297	13604	24808	\N	53.093651000000001	Брянская область, Выгоничский муниципальный район, Выгоничское городское поселение, п. Выгоничи, Ленина, 27		0101000020E61000002BC1E270E60541406D1E87C1FC8B4A40
24648	1	2	1297	13604	24808	\N	53.093651000000001	Брянская область, Выгоничский муниципальный район, Выгоничское городское поселение, п. Выгоничи, Ленина, 25		0101000020E61000002BC1E270E60541406D1E87C1FC8B4A40
24661	1	2	1297	14217	25059	\N	53.129413	Брянская область, Выгоничский муниципальный район, Орменское сельское поселение, д. Большой Крупец, Школьная, 30		0101000020E6100000AFB2B6291EE14040B056ED9A90904A40
24672	1	2	1297	14747	24705	\N	53.004430999999997	Брянская область, Выгоничский муниципальный район, Хмелевское сельское поселение, п. Алексеевский, Молодежная, 2		0101000020E61000006C5B94D920F14040560BEC3191804A40
24634	1	2	1191	51134	25198	\N	53.2724026907797	Брянская область, Брянский муниципальный район, Снежское сельское поселение, п.Путевка, ул.Центральная, д.14		0101000020E61000007097FDBAD31D4140882AFC19DEA24A40
24615	1	2	1191	12066	24621	\N	53.338026999999997	Брянская область, Брянский муниципальный район, Глинищевское сельское поселение, с.Хотылево, ул.Школьная, д.2		0101000020E61000002D228AC91B1041401E15FF7744AB4A40
24635	1	2	1191	13008	24562	\N	53.250841000000001	"Брянская область, Брянский муниципальный район, Снежское сельское поселение, с.Толмачево, ул.Трудовая, д.6 ""а"""		0101000020E610000030815B77F32241407BBFD18E1BA04A40
24645	1	2	1191	13478	24430	\N	53.377318000000002	"Брянская область, Брянский муниципальный район, Нетьинское сельское поселение, д.Толвинка, ул.Толвинская, д.49 ""а"""		0101000020E6100000BCCFF1D1E21A41409818CBF44BB04A40
24613	1	2	1191	11950	24956	\N	53.257828085894502	Брянская область, Брянский муниципальный район, Глинищевское сельское поселение, д.Титовка, пл.им.К.Маркса, д.8	Россия, Брянская область, Брянский район, поселок Титовка	0101000020E6100000EB1D6E87860741401EFF058200A14A40
24640	1	2	1191	13219	25134	\N	53.200015999999998	"Брянская область, Брянский муниципальный район, Добрунское сельское поселение, д.Тиганово, ул.Садовая, д.54 ""а"""		0101000020E61000000762D9CC211B41409F56D11F9A994A40
24641	1	2	1191	13295	24683	\N	53.220793999999998	"Брянская область, Брянский муниципальный район, Добрунское сельское поселение, с.Теменичи, ул.Светлая, д.8 ""а"""		0101000020E6100000AB048BC399134140969350FA429C4A40
24623	1	2	1191	51105	25088	\N	53.213779000000002	Брянская область, Брянский муниципальный район, Супоневское сельское поселение, с.Супонево, ул.Свенская, д.10		0101000020E61000002DCF83BBB32A41402AC93A1C5D9B4A40
24631	1	2	1191	12830	25047	\N	53.114480999999998	Брянская область, Брянский муниципальный район, Свенское сельское поселение, п.Стяжное, ул.Киевская, д.30		0101000020E6100000BBB88D06F0364140B6813B50A78E4A40
24602	1	2	1191	11431	24462	\N	53.373767000000001	Брянская область, Брянский муниципальный район, Стекляннорадицкое сельское поселение, п.Стеклянная Радица, ул.Комсомольская, д.58		0101000020E6100000419DF2E8463E41407AA9D898D7AF4A40
24617	1	2	1191	12153	24504	\N	53.303834000000002	Брянская область, Брянский муниципальный район, Отрадненское сельское поселение, д.Староселье, ул.Центральная, здание Старосельского клуба		0101000020E61000007286E28E37114140D9B45208E4A64A40
24629	1	2	1191	51140	25207	\N	53.142765259610101	Брянская область, Брянский муниципальный район, Свенское сельское поселение, п.Свень-Транспортная, ул.Деповская, д.12	Россия, Брянская область, Брянский район, поселок Свень	0101000020E6100000E5B4A7E49C2E4140B8019F1F46924A40
24632	1	2	1191	12689	\N	\N	53.140713245140603	"Брянская область, Брянский муниципальный район, Свенское сельское поселение, санаторий ""Снежка"", здание Дома культуры санатория"	Россия, Брянская область, Брянский район, поселок Свень	0101000020E610000090A16307952E41409F8F32E202924A40
24628	1	2	1191	12689	25004	\N	53.140000999999998	Брянская область, Брянский муниципальный район, Свенское сельское поселение, п.Свень, ул.Клубная, д.6		0101000020E61000008F39CFD8972E41402234828DEB914A40
24630	1	2	1191	12791	24846	\N	53.150787000000001	"Брянская область, Брянский муниципальный район, Свенское сельское поселение, п.Пятилетка, ул.Школьная, д.1 ""а"""		0101000020E61000009D465A2A6F274140BBD408FD4C934A40
24633	1	2	1191	51129	74987	\N	53.270396037821698	"Брянская область, Брянский муниципальный район, Снежское сельское поселение, п.Путевка, ул.Центральная, д.14 ""а"""		0101000020E61000006F63B323D51D41400F7C0C569CA24A40
24647	1	2	1191	13575	25061	\N	53.286417	Брянская область, Брянский муниципальный район, Пальцовское сельское поселение, п.Пальцо, ул.Ленина, здание Пальцовского ПКЦ		0101000020E61000009DBE9EAF597641405C02F04FA9A44A40
24317	1	1	\N	28629	33458	\N	50.408489000000003	Белгородская область, г. Шебекино, Нежеголдьское шоссе, 13		0101000020E61000003563D174767242404CE3175E49344940
24609	1	2	1191	51067	\N	\N	53.387486023343001	"Брянская область, Брянский муниципальный район, Новодарковичское сельское поселение, п.Новые Дарковичи, здание Новодарковичского СДК, д.2 ""а"""		0101000020E6100000E89FE0624529414035D4282499B14A40
24626	1	2	1191	45658	24740	\N	53.319710000000001	с. Новоселки. ул. Резцова 13 здание Новосельской средней школы		0101000020E61000006F8099EFE0E34040221ADD41ECA84A40
24643	1	2	1191	13340	24823	\N	53.348019435483899	"Брянская область, Брянский муниципальный район, Нетьинское сельское поселение, п.Ивановка, ул.Школьная, д.28 ""а"""	Россия, Брянская область	0101000020E6100000BAF42F49651C41407DB1F7E28BAC4A40
24642	1	2	1191	13340	24971	\N	53.348806000000003	Брянская область, Брянский муниципальный район, Нетьинское сельское поселение, п.Нетьинка, ул.Мира, д.30		0101000020E6100000CCD3B9A2941841400553CDACA5AC4A40
24627	1	2	1191	12669	25126	\N	53.337375999999999	Брянская область, Брянский муниципальный район, Новосельское сельское поселение, д.Молотино, ул.Школьная, д.34		0101000020E6100000849CF7FF71F04040473A03232FAB4A40
24636	1	2	1191	13046	24629	\N	53.275930000000002	Брянская область, Брянский муниципальный район,  п.Мичуринский, ул Березовая д. 7 Мичуринская средняя школа		0101000020E61000000FB8AE98111E41401EFE9AAC51A34A40
24889	1	2	1191	11715	\N	\N	53.319823999744102	Брянская область, Клетнянский муниципальный район, Мирнинское сельское поселение, п.Мирный	Россия, Брянская область, Брянский район, поселок Мирный	0101000020E61000007974232C2A684140EA3C2AFEEFA84A40
24607	1	2	1191	11715	24797	\N	53.319673000000002	"Брянская область, Брянский муниципальный район, Журиничское сельское поселение, п.Мирный, ул.Школьная, д.16 ""а"""		0101000020E6100000EEB089CC5C68414005357C0BEBA84A40
24638	1	2	1191	13127	24889	\N	53.274836999999998	Брянская область, Брянский муниципальный район, Мичуринское сельское поселение, д.Меркульево, ул.Воинская, д.7		0101000020E6100000F7E6374C34144140895DDBDB2DA34A40
24606	1	2	1191	11628	25124	\N	53.274503000000003	Брянская область, Брянский муниципальный район, Журиничское сельское поселение, с.Малое Полпино, ул.Молодежная, д.8		0101000020E6100000CB9C2E8B894F4140B3D30FEA22A34A40
24637	1	2	1191	13079	24678	\N	53.270302000000001	Брянская область, Брянский муниципальный район, Мичуринское сельское поселение, д.Колтово, ул.Тамбовская, д.11		0101000020E610000043E6CAA0DA0E41408E05854199A24A40
24604	1	2	1191	11537	24463	\N	53.329729999999998	"Брянская область, Брянский муниципальный район, Стекляннорадицкое сельское поселение, п.Козелкино, ул.Лесная, д.49 ""а"""		0101000020E61000006D1ADB6B413F41404A41B79734AA4A40
24614	1	2	1191	12039	24623	\N	53.317478000000001	"Брянская область, Брянский муниципальный район, Глинищевское сельское поселение, с.Кабаличи, ул.Советская, д.8 ""а"""		0101000020E61000003145B9347E0B414089997D1EA3A84A40
24605	1	2	1191	11602	24467	\N	53.316161914635202	"Брянская область, Брянский муниципальный район, Журиничское сельское поселение, с.Журиничи, ул.Песочная, д.1 ""а"""	Россия, Брянская область, Брянский район, поселок Журиничи	0101000020E6100000CC9A58E02B5A4140751E15FF77A84A40
24646	1	2	1191	13505	25053	\N	53.461210000000001	Брянская область, Брянский муниципальный район, Домашовское сельское поселение, д.Домашово, ул.Советская, д.20		0101000020E6100000672AC423F1064140494BE5ED08BB4A40
24639	1	2	1191	13190	25131	\N	53.183404000000003	Брянская область, Брянский муниципальный район, Добрунское сельское поселение, д.Добрунь, ул.Юбилейная, д.31		0101000020E6100000F6EFFACC591F414051FA42C879974A40
24620	1	2	1191	12328	24626	\N	53.298372000000001	Брянская область, Брянский муниципальный район, Чернетовское сельское поселение, с.Госома, ул.Сельская, д.58		0101000020E6100000CF81E50819FC40406405BF0D31A64A40
24619	1	2	1191	12280	24624	\N	53.347456999999999	Брянская область, Брянский муниципальный район, Чернетовское сельское поселение, д.Городец, ул.Школьная, д.6		0101000020E610000001A260C61404414015E2917879AC4A40
24611	1	2	1191	11894	24800	\N	53.303446000000001	Брянская область, Брянский муниципальный район, Глинищевское сельское поселение, с.Глинищево, ул.П.М.Яшенина, д.39		0101000020E6100000C45DBD8A8C0A41400F0D8B51D7A64A40
24612	1	2	1191	11894	24618	\N	53.303446000000001	Брянская область, Брянский муниципальный район, Глинищевское сельское поселение, с.Глинищево, ул.Клубная, д.1		0101000020E6100000C45DBD8A8C0A41400F0D8B51D7A64A40
24644	1	2	1191	13428	24569	\N	53.373218999999999	"Брянская область, Брянский муниципальный район, Нетьинское сельское поселение, д.Глаженка, ул.Набережная, д.2 ""а"""		0101000020E6100000B7B585E7A5144140779FE3A3C5AF4A40
24618	1	2	1191	12228	24845	\N	53.347521	Брянская область, Брянский муниципальный район, Чернетовское сельское поселение, д.Бетово, ул.Молодежная, д.49		0101000020E6100000EE79FEB4510141402CD670917BAC4A40
24570	1	2	1191	51069	25168	\N	53.204397056685401	Брянская область, город Брянск, Фокинский район, поселок Белые Берега, улица Ленина, дом 1	Россия, Брянская область, Брянский район, поселок Белые Берега	0101000020E6100000C72E51BD3556414044334FAE299A4A40
24569	1	2	1191	51069	25196	\N	53.210231029789	Брянская область, город Брянск, Фокинский район, поселок Белые Берега, улица Ромашина, дом 7	Россия, Брянская область, Брянский район, поселок Белые Берега	0101000020E6100000B804E09F525541407DCD72D9E89A4A40
24571	1	2	1191	51069	24868	\N	53.206267726780901	Брянская область, город Брянск, Фокинский район, поселок Белые Берега, улица Коминтерна, дом 34	Россия, Брянская область, Брянский район, поселок Белые Берега	0101000020E61000007BF7C77BD55441400D1B65FD669A4A40
24313	1	1	\N	28629	33407	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Мочалина, 7		0101000020E61000003563D174767242404CE3175E49344940
24572	1	2	1191	51069	25199	\N	53.211985212203601	Брянская область, город Брянск, Фокинский район, поселок Белые Берега, улица Карла Маркса, дом 6	Россия, Брянская область, Брянский район, поселок Белые Берега	0101000020E610000044300E2E1D5541400C1F1153229B4A40
24608	1	2	1191	51092	24993	\N	53.217722860059602	Брянская область, Брянский муниципальный район, Журиничское сельское поселение, п.Белобережский санаторий, турбаза, ул.Центральная, здание почты	Россия, Брянская область, Брянский район, поселок Белобережская	0101000020E610000052F355F2B14B4140234BE658DE9B4A40
24603	1	2	1191	11514	24660	\N	53.400081999999998	"Брянская область, Брянский муниципальный район, Стекляннорадицкое сельское поселение, п.Батагово, ул.Центральная, д.1""а"""		0101000020E6100000588D25AC8D4F4140F0DB10E335B34A40
24625	1	2	1191	12570	24852	\N	53.218077000000001	"Брянская область, Брянский муниципальный район, Супоневское сельское поселение, д.Антоновка, пер.Школьный, д.6 ""а"""		0101000020E610000098874CF910244140418177F2E99B4A40
24591	1	2	1116	10954	\N	\N	52.722560999999999	с. Чаянка, Здание школы		0101000020E6100000062D246074754140BA2EFCE07C5C4A40
24585	1	2	1116	51045	\N	\N	52.952981000000001	с. Хотеева, Здание школы		0101000020E6100000B6F3FDD478A54040CD5A0A48FB794A40
24586	1	2	1116	49275	\N	\N	52.602651000000002	с. Столбово, Здание сельской администрации		0101000020E6100000FA0E7EE2006441406BF3FFAA234D4A40
24578	1	2	1116	10304	\N	\N	52.598937999999997	с. Сныткино, Здание сельской администрации		0101000020E610000031242713B7544140732A1900AA4C4A40
24579	1	2	1116	10378	\N	\N	52.654125999999998	д. Осотское, Здание школы		0101000020E61000006094A0BFD05B41404DBB9866BA534A40
24588	1	2	1116	51070	\N	\N	52.592784000000002	д. Новое, Здание школы	Россия, Брянская область, Брасовский район, поселок Новое	0101000020E61000004AB3791C066D4140C9CB9A58E04B4A40
24600	1	2	1116	10977	\N	\N	52.571181331373303	"п. Локоть, Здание ОАО ""Брасовское ХПП"""	Россия, Брянская область, Брасовский район, поселок Локоть	0101000020E6100000A88FC01F7E4841405D8C81751C494A40
24599	1	2	1116	10977	\N	\N	52.569884380396097	"п. Локоть, Здание десткого сада ""Гномик"""		0101000020E61000005A0D897B2C494140C0417BF5F1484A40
24598	1	2	1116	10977	\N	\N	52.571908000000001	п. Локоть, Здание Локотской средней школы №2		0101000020E6100000B4AD669DF14741400F29064834494A40
24596	1	2	1116	10977	\N	\N	52.573900620064997	п. Локоть, Здание Локотской средней школы №3	Россия, Брянская область, Брасовский район, поселок Локоть	0101000020E6100000B91CAF40F44841402312859675494A40
24595	1	2	1116	10977	\N	\N	52.571908000000001	п. Локоть, Здание Брасовского техникума		0101000020E6100000B4AD669DF14741400F29064834494A40
24594	1	2	1116	10977	\N	\N	52.571908000000001	п.Локоть, Здание Локотского Дома культуры		0101000020E6100000B4AD669DF14741400F29064834494A40
24593	1	2	1116	10977	\N	\N	52.571908000000001	п.Локоть, Здание Локотской средней школы №1	Россия, Брянская область, Брасовский район, поселок Локоть	0101000020E6100000B4AD669DF14741400F29064834494A40
24592	1	2	1116	10977	\N	\N	52.571908000000001	"п. Локоть, Административное здание СПК ""Столбовский им. Столярова"""		0101000020E6100000B4AD669DF14741400F29064834494A40
24587	1	2	1116	10771	\N	\N	52.605687000000003	п. Летча, Здание сельской администрации		0101000020E6100000A6B5696CAF774140624ED026874D4A40
24577	1	2	1116	49155	\N	\N	52.512774	с. Крупец, Здание сельской администрации	Россия, Брянская область, Брасовский район, поселок Крупец	0101000020E61000003DEFC682C23441409B1E1494A2414A40
24575	1	2	1116	10134	\N	\N	52.596439145747702	п. Красный Колодец, Здание Дома культуры	Россия, Брянская область, Брасовский район, поселок Красный Колодец	0101000020E6100000EE98BA2BBB4041408B87F71C584C4A40
24582	1	2	1116	10513	\N	\N	52.711208999999997	с. Калошичье, Здание магазина РАЙПО		0101000020E6100000CDAD10566359414078CF81E5085B4A40
24576	1	2	1116	51040	\N	\N	52.532209000000002	д. Городище 1-ое, Здание медпункта	Россия, Брянская область, Брасовский район, поселок Городище 1-е	0101000020E610000059349D9D0C44414085D1AC6C1F444A40
24589	1	2	1116	49314	\N	\N	52.643673999999997	с. Глоднево, Здание Дома культуры		0101000020E61000005393E00D696A41408BA4DDE863524A40
24574	1	2	1116	10128	\N	\N	52.543985999999997	п.Воронов-Лог, Здание сельской администрации		0101000020E6100000D21A834E083F4140ADBD4F55A1454A40
24590	1	2	1116	51073	\N	\N	52.666218999999998	с. Веребск, Здание Дома культуры	Россия, Брянская область, Брасовский район, поселок Веребское	0101000020E6100000FAD2DB9F8B784140A67C08AA46554A40
24573	1	2	1116	10065	\N	\N	52.586781999999999	с. Брасово, Здание Брасовской средней школы		0101000020E6100000EF3CF19C2D4E4140D4F02DAC1B4B4A40
24314	1	1	\N	28629	33408	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Чкалова, 40		0101000020E61000003563D174767242404CE3175E49344940
24318	1	1	\N	28629	33410	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Харьковская, 51	Россия, Белгородская область, Шебекино	0101000020E61000003563D174767242404CE3175E49344940
24312	1	1	\N	28629	9901	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Фрунзе, 8		0101000020E61000003563D174767242404CE3175E49344940
24319	1	1	\N	28629	33555	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Садовая, 7		0101000020E61000003563D174767242404CE3175E49344940
24321	1	1	\N	28629	33459	\N	50.408489000000003	Белгородская область, г. Шебекино, Ржевское шоссе, 233		0101000020E61000003563D174767242404CE3175E49344940
24320	1	1	\N	28629	33459	\N	50.407008444605097	Белгородская область, г. Шебекино, Ржевское шоссе, 13	Россия, Белгородская область, Шебекино	0101000020E61000003509DE9046714240ED9A90D618344940
24303	1	1	\N	28629	33319	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Октябрьская, 17	Россия, Белгородская область, Шебекино	0101000020E61000003563D174767242404CE3175E49344940
24302	1	1	\N	28629	33319	\N	50.408489000000003	город Шебекино, ул. Октябрьская, д.3		0101000020E61000003563D174767242404CE3175E49344940
24301	1	1	\N	28629	33319	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Октябрьская, 13	Россия, Белгородская область, Шебекино	0101000020E61000003563D174767242404CE3175E49344940
24304	1	1	\N	28629	33406	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Московская, 19		0101000020E61000003563D174767242404CE3175E49344940
24310	1	1	\N	28629	33275	\N	50.402016630208301	Белгородская область, г. Шебекино, ул. Мичурина, 2А	Россия, Белгородская область, Шебекино	0101000020E6100000BDE0D39CBC724240D0B7054B75334940
24309	1	1	\N	28629	33275	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Мичурина, 2		0101000020E61000003563D174767242404CE3175E49344940
24311	1	1	\N	28629	33391	\N	50.409750974732297	Белгородская область, г. Шебекино, ул. Ленина, 70	Россия, Белгородская область, Шебекино	0101000020E61000003509DE90467142406C4084B872344940
24308	1	1	\N	28629	33391	\N	50.395049148326898	Белгородская область, г. Шебекино, ул. Ленина, 58	Россия, Белгородская область, Шебекино	0101000020E610000024D6E25300704240A4A833F790324940
24306	1	1	\N	28629	33391	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Ленина, 1	Россия, Белгородская область, Шебекино	0101000020E61000003563D174767242404CE3175E49344940
24305	1	1	\N	28629	33391	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Ленина, 19		0101000020E61000003563D174767242404CE3175E49344940
24316	1	1	\N	28629	33340	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Дзержинского, 18		0101000020E61000003563D174767242404CE3175E49344940
24315	1	1	\N	28629	33340	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Дзержинского, 13		0101000020E61000003563D174767242404CE3175E49344940
24322	1	1	\N	28629	33842	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Дачная, 2		0101000020E61000003563D174767242404CE3175E49344940
24300	1	1	\N	28629	33317	\N	50.408489000000003	Белгородская область, г. Шебекино, ул. Белгородская, 8		0101000020E61000003563D174767242404CE3175E49344940
24147	1	1	\N	21346	33400	\N	51.301262000000001	город Старый Оскол, м-н Юность, д.9, СОШ №21		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24197	1	1	7305	\N	33196	\N	51.307092940031602	город Старый Оскол, м-н Юбилейный, 10, СОШ №33	Россия, Белгородская область, Старый Оскол городской округ	0101000020E6100000C093162EABF042404FEACBD24EA74940
24195	1	1	\N	21346	33196	\N	51.301262000000001	город Старый Оскол, м-н Юбилейный,10, СОШ №33		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24175	1	1	\N	21346	33243	\N	51.276694031637703	город Старый Оскол, м-н Углы,17, школа №2	Россия, Белгородская область, Старый Оскол	0101000020E6100000A3073E062BE84240ED7F80B56AA34940
24159	1	1	7305	\N	33256	\N	51.2754558362019	город Старый Оскол, м-н Студенческий,4, техникум технологий и дизайна	Россия, Белгородская область, Старый Оскол городской округ	0101000020E61000005FD3838252E6424055BE672442A34940
24158	1	1	\N	21346	33256	\N	51.301262000000001	город Старый Оскол, м-н Студенческий,5а, техникум строительства,транспорта		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24204	1	1	\N	21346	33404	\N	51.301262000000001	город Старый Оскол, м-н Солнечный, 19, школа №26		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24203	1	1	\N	21346	33404	\N	51.301262000000001	город Старый Оскол, м-н Солнечный, 18, педагогический  колледж		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24198	1	1	\N	21346	33290	\N	51.301262000000001	"город Старый Оскол, м-н Северный,7а, ЗАО ""Витязь"""		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24154	1	1	\N	21346	33453	\N	51.282534631632302	город Старый Оскол, м-н Рудничный,22, СОШ №19		0101000020E6100000AD8905BEA2E54240D97C5C1B2AA44940
24153	1	1	\N	21346	33453	\N	51.301262000000001	город Старый Оскол, м-н Рудничный,1а, библиотека - филиал №11 ЦБС	Россия, Белгородская область, Старый Оскол	0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24146	1	1	7305	\N	33254	\N	51.295612714315702	город Старый Оскол, м-н Приборостроитель, д.16, СОШ №14	Россия, Белгородская область, Старый Оскол городской округ	0101000020E6100000A2D288997DEE4240E0A293A5D6A54940
24145	1	1	7305	\N	33254	\N	51.299137235899998	город Старый Оскол, м-н Приборостроитель,16, СОШ №14	Россия, Белгородская область, Старый Оскол городской округ	0101000020E610000088855AD3BCEF42400403081F4AA64940
24144	1	1	\N	21346	33254	\N	51.301262000000001	город Старый Оскол, м-н Приборостроитель, д.30, юношеская библиотека-филиал №1 ЦБС		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24160	1	1	\N	21346	33287	\N	51.301262000000001	город Старый Оскол, м-н Парковый,27а, СОШ №13		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24192	1	1	\N	21346	33403	\N	51.301262000000001	город Старый Оскол, м-н Ольминского, 12		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24219	1	1	\N	21346	33426	\N	51.301262000000001	город Старый Оскол, м-н Олимпийский, 18, детская школа искусств №2		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24218	1	1	\N	21346	33426	\N	51.301262000000001	"город Старый Оскол, м-н Олимпийский, 49а, спортклуб ""Невский"" ОАО ""ОЭМК"""		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24217	1	1	\N	21346	33426	\N	51.301262000000001	город Старый Оскол, м-н Олимпийский, 54, школа №20		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24216	1	1	\N	21346	33426	\N	51.301262000000001	город Старый Оскол, м-н Олимпийский, 34, школа №22		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24215	1	1	\N	21346	33426	\N	51.301262000000001	город Старый Оскол, м-н Олимпийский, 8, гимназия №18		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24148	1	1	\N	21346	33294	\N	51.301262000000001	город Старый Оскол, м-н Молодогвардеец, д.15, СОШ №15	Россия, Белгородская область, Старый Оскол	0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24202	1	1	\N	21346	33372	\N	51.301262000000001	город Старый Оскол, м-н Макаренко,36а, СОШ №28		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24201	1	1	\N	21346	33372	\N	51.301262000000001	город Старый Оскол, м-н Макаренко,39, ПУ №9		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24200	1	1	\N	21346	33372	\N	51.301262000000001	город Старый Оскол, м-н Макаренко, 3а, индустриальный техникум		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24199	1	1	\N	21346	33372	\N	51.301262000000001	"город Старый Оскол, м-н Макаренко,7а, Д/К ""Молодежный"""		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24156	1	1	\N	21346	33221	\N	51.283160365926797	город Старый Оскол, м-н Лебединец, 28, СОШ №12		0101000020E6100000C5C551B989E6424087C43D963EA44940
24155	1	1	\N	21346	33221	\N	51.301262000000001	город Старый Оскол, м-н Лебединец, 28, СОШ № 12		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24221	1	1	\N	21346	33513	\N	51.301388158191699	"город  Старый Оскол, м-н Космос, 6, Детский санаторий ""Надежда"""		0101000020E6100000F2785A7EE0F2424014B4C9E193A64940
24206	1	1	7305	\N	33405	\N	51.2987635718696	город Старый Оскол, м-н Королева,16, СОШ №34	Россия, Белгородская область, Старый Оскол городской округ	0101000020E6100000EB73B515FBE942406F9C14E63DA64940
24191	1	1	\N	21346	33449	\N	51.301262000000001	город Старый Оскол, м-н Конева, 15а, СОШ №24		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24162	1	1	7305	\N	33241	\N	51.283153637646599	город Старый Оскол, м-н Интернациональный,1, лицей №3	Россия, Белгородская область, Старый Оскол городской округ	0101000020E61000008CF2CCCB61E94240A5DDE8633EA44940
24161	1	1	\N	21346	33241	\N	51.301262000000001	город Старый Оскол, м-н Интернациональный,23, СОШ №11		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24194	1	1	\N	21346	33268	\N	51.301262000000001	город Старый Оскол, м-н Зеленый Лог, 5		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24143	1	1	\N	21346	33324	\N	51.301262000000001	город Старый Оскол, м-н Звездный, д.13, ФОК	Россия, Белгородская область, Старый Оскол	0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24214	1	1	\N	21346	33200	\N	51.301262000000001	город Старый Оскол, м-н Жукова,24а, пункт охраны общественного порядка		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24213	1	1	\N	21346	33200	\N	51.301262000000001	город Старый Оскол, м-н Жукова, 54, школа №16		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24211	1	1	\N	21346	33200	\N	51.301262000000001	город Старый Оскол, м-н Жукова,57, школа №17		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24210	1	1	\N	21346	33200	\N	51.301262000000001	город Старый Оскол, м-н Жукова,37, центр развития творчества детей		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24209	1	1	\N	21346	33200	\N	51.301343286558101	город Старый Оскол, м-н Жукова,36, школа №6	Россия, Белгородская область, Старый Оскол	0101000020E6100000FC7266BB42EB424074F04C6892A64940
24205	1	1	\N	21346	33200	\N	51.301262000000001	город Старый Оскол, м-н Жукова,30б, детская музыкальная школа №5		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24222	1	1	\N	21346	33514	\N	51.282507718137097	город  Старый Оскол, м-н Дубрава, 2 квартал, 5		0101000020E6100000048D9944BDE84240DF6DDE3829A44940
24164	1	1	\N	21346	33223	\N	51.285252812990002	город Старый Оскол, м-н Горняк,7, Центр культуры и искусств		0101000020E610000066A032FE7DE84240FE0A992B83A44940
24163	1	1	\N	21346	33223	\N	51.301262000000001	город Старый Оскол, м-н Горняк,35, СОШ №1		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24208	1	1	\N	21346	33270	\N	51.291065410594797	город Старый Оскол, м-н Восточный,51, СОШ №40		0101000020E6100000DA8CD31055EA42405001309E41A54940
24151	1	1	\N	21346	33289	\N	51.309171215872503	"город Старый Оскол, м-н Весенний,11, АПК ""Стойленская Нива"""	Россия, Белгородская область, Старый Оскол городской округ	0101000020E61000009CA4F9635AEF424091EF52EA92A74940
24193	1	1	\N	21346	33269	\N	51.301262000000001	город Старый Оскол, м-н Буденного, 2, школа №25		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24157	1	1	7305	\N	33455	\N	51.282830679033303	"город Старый Оскол, бульвар Дружбы, 1, ДК ""Комсомолец"""	Россия, Белгородская область, Старый Оскол городской округ	0101000020E61000002FC1A90F24E74240C2A563CE33A44940
24182	1	1	\N	21346	33627	\N	51.2898545137515	город Старый Оскол, Южная, дом 68		0101000020E61000000A647616BDEB424082CAF8F719A54940
24189	1	1	\N	21346	33328	\N	51.301262000000001	"город Старый Оскол, Стадионная, 13, городской д/к ""Железнодорожник"""	Россия, Белгородская область, Старый Оскол	0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24188	1	1	7305	\N	33328	\N	51.316675083707501	город Старый Оскол, Стадионная, 14, школа № 36	Россия, Белгородская область, Старый Оскол городской округ	0101000020E61000003F575BB1BFEE4240FB3A70CE88A84940
24190	1	1	\N	21346	33288	\N	51.301262000000001	город Старый Оскол, Советская, 11а, межшкольный учкомбинат		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24165	1	1	\N	21346	33421	\N	51.290099008234399	город Старый Оскол, ул. Свердлова, ЦТП №12	Россия, Белгородская область, Старый Оскол городской округ	0101000020E6100000C5E3A25A44EA424018CDCAF621A54940
24183	1	1	\N	21346	33420	\N	51.301262000000001	город Старый Оскол, Революционная,15, театр для детей и молодежи		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24184	1	1	\N	21346	33326	\N	51.301262000000001	город Старый Оскол, Пролетарская,72а, СОШ №8		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24176	1	1	\N	21346	33326	\N	51.300751429769697	город Старый Оскол, Пролетарская,108, медицинский колледж	Россия, Белгородская область, Старый Оскол	0101000020E610000089997D1EA3EA4240A19E3E027FA64940
24174	1	1	\N	21346	33508	\N	51.301262000000001	город Старый Оскол, Первой Конной Армии,26а, школа №9		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24168	1	1	\N	21346	33242	\N	51.295801054409502	город Старый Оскол, Октябрьская,10, СОШ №5		0101000020E6100000D2FBC6D79EEB4240E28FA2CEDCA54940
24179	1	1	\N	21346	33401	\N	51.301262000000001	город Старый Оскол, Мира,22, бывшая школа №10		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24178	1	1	\N	21346	33401	\N	51.301262000000001	город Старый Оскол, Мира,4, автошкола РОСТО (ДОСААФ)		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24171	1	1	\N	21346	33402	\N	51.300724527006203	город Старый Оскол, ул.Ленина,17, спорт зал техникума ГРТ	Россия, Белгородская область, Старый Оскол	0101000020E610000065506D7022EA4240780B24287EA64940
24173	1	1	\N	21346	33818	\N	51.301262000000001	город Старый Оскол, Комсомольская, 33/36, школа №35	Россия, Белгородская область, Старый Оскол	0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24170	1	1	\N	21346	33430	\N	51.298572254564597	город Старый Оскол, ул. Зои Космодемьянской, 42, СОШ №7	Россия, Белгородская область, Старый Оскол городской округ	0101000020E6100000B56E83DA6FE942402BC0779B37A64940
24186	1	1	\N	21346	33552	\N	51.301262000000001	город Старый Оскол, Заречная, 32, бывшая школа № 37		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24185	1	1	\N	21346	33552	\N	51.301262000000001	город Старый Оскол, Заречная,32, бывшая школа №37		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24212	1	1	\N	21346	33409	\N	51.301262000000001	город Старый Оскол, м-н Жукова, 54, СОШ №16		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
24166	1	1	\N	21346	33418	\N	51.281727219880203	"город Старый Оскол, ул. Ватутина, 27а, МУП ""Водоканал"""	Россия, Белгородская область, Старый Оскол городской округ	0101000020E6100000FB3E1C2444EB424039B35DA10FA44940
24181	1	1	7305	\N	33671	\N	51.3020158417781	город Старый Оскол, Большевистская,14, библиотека филиал №2 ЦБС	Россия, Белгородская область, Старый Оскол городской округ	0101000020E6100000810706103EF24240336FD575A8A64940
24187	1	1	\N	21346	33356	\N	51.301262000000001	город Старый Оскол, 19 Партсъезда, 45, Красный уголок ЮЖВД		0101000020E61000004E7D2079E7EA424087C3D2C08FA64940
23768	1	1	\N	930	33339	\N	51.278838082843201	город Губкин, проспект Горняков, 1	Россия, Белгородская область, Губкин	0101000020E610000070B1A206D3C64240E770ADF6B0A34940
23742	1	1	\N	930	33358	\N	51.282026999999999	город Губкин, Школьная, 21а		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23454	1	1	\N	930	33438	\N	51.2808223326141	город Губкин, Чайковского, 18	Россия, Белгородская область, Губкин	0101000020E61000005E11FC6F25C54240A8FFACF9F1A34940
23744	1	1	\N	930	33605	\N	51.287436828545196	город Губкин, Фрунзе, 6а	Россия, Белгородская область, Губкин	0101000020E6100000DC7F643A74C44240865451BCCAA44940
23771	1	1	\N	930	33368	\N	51.282026999999999	город Губкин, Ударников, 12	Россия, Белгородская область, Губкин	0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23750	1	1	\N	930	33388	\N	51.282026999999999	город Губкин, Спортивный проезд, 3		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23678	1	1	\N	930	33381	\N	51.280789426863002	город Губкин, Советская, 27	Россия, Белгородская область, Губкин	0101000020E6100000EE409DF2E8C44240CC09DAE4F0A34940
23517	1	1	\N	930	33381	\N	51.282026999999999	город Губкин, Советская, 29		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23737	1	1	\N	930	33813	\N	51.293168426669197	город Губкин, Революционная, 8	Россия, Белгородская область, Губкин	0101000020E6100000111D024702C54240EB1D6E8786A54940
23749	1	1	\N	930	33213	\N	51.292071206964899	город Губкин, Раевского, 15а	Россия, Белгородская область, Губкин	0101000020E610000019A9F7544EC34240158E209562A54940
23748	1	1	\N	930	33213	\N	51.290935072545601	город Губкин, Раевского, 9	Россия, Белгородская область, Губкин	0101000020E6100000967B8159A1C242408121AB5B3DA54940
23746	1	1	\N	930	33213	\N	51.282026999999999	город Губкин, Раевского, 3а		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23761	1	1	\N	930	33493	\N	51.282026999999999	город Губкин, Преображенская, 6г		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23739	1	1	\N	930	33320	\N	51.2820274777919	город Губкин, Победы, 24	Россия, Белгородская область, Губкин	0101000020E6100000C2A4F8F884C6424064CBF27519A44940
23738	1	1	\N	930	33320	\N	51.275029357588302	город Губкин, Победы, 1	Россия, Белгородская область, Губкин	0101000020E610000013B9E00CFEC44240CE39782634A34940
23770	1	1	\N	930	33205	\N	51.279013034328301	город Губкин, Павлика Морозова, 8	Россия, Белгородская область, Губкин	0101000020E6100000274A42226DC542405514AFB2B6A34940
23756	1	1	\N	930	33202	\N	51.279873798496801	город Губкин, Осколецкая, 21	Россия, Белгородская область, Губкин	0101000020E61000003483F8C08EC54240178046E9D2A34940
23767	1	1	\N	930	33599	\N	51.281246971331498	город Губкин, Народная, 4а	Россия, Белгородская область, Губкин	0101000020E610000040BFEFDFBCCC42408F8CD5E6FFA34940
23766	1	1	\N	930	33675	\N	51.282026999999999	город Губкин, Народная, 2а	Россия, Белгородская область, Губкин	0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23753	1	1	\N	930	33255	\N	51.286333480636799	город Губкин, Мичурина, 21	Россия, Белгородская область, Губкин	0101000020E61000005FEB5223F4C54240FE614B8FA6A44940
23642	1	1	\N	930	33263	\N	51.284826425804098	город Губкин, Мира, 22	Россия, Белгородская область, Губкин	0101000020E6100000C3F4BD86E0C442407786A92D75A44940
23546	1	1	\N	930	33263	\N	51.285559038355899	город Губкин, Мира, 18	Россия, Белгородская область, Губкин	0101000020E61000001555BFD2F9C442400B0A83328DA44940
23751	1	1	\N	930	33354	\N	51.290450716278201	город Губкин, Лазарева, 23/92	Россия, Белгородская область, Губкин	0101000020E61000002D060FD3BEC34240950B957F2DA54940
23747	1	1	\N	930	33354	\N	51.282026999999999	город Губкин, Лазарева, 17а	Россия, Белгородская область, Губкин	0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23745	1	1	\N	930	33354	\N	51.282026999999999	город Губкин, Лазарева, 15		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23743	1	1	6958	\N	33354	\N	51.277081063100098	город Губкин, Лазарева, 13	Россия, Белгородская область, Губкин городской округ	0101000020E61000001840F850A2C94240E7ABE46377A34940
23763	1	1	\N	930	33203	\N	51.278797709328501	город Губкин, Королева, 30	Россия, Белгородская область, Губкин	0101000020E6100000D921FE614BC54240591822A7AFA34940
23760	1	1	\N	930	33203	\N	51.280627939486202	город Губкин, Королева, 12а	Россия, Белгородская область, Губкин	0101000020E61000001DAF40F4A4CC4240C32B499EEBA34940
23759	1	1	\N	930	33203	\N	51.2810585712229	город Губкин, Королева, 3а	Россия, Белгородская область, Губкин	0101000020E6100000A9DA6E826FCC42408C9FC6BDF9A34940
23741	1	1	\N	930	33266	\N	51.278582383314003	город Губкин, Комсомольская, 16	Россия, Белгородская область, Губкин	0101000020E610000022AAF06778C542408CA03193A8A34940
23757	1	1	\N	930	33298	\N	51.2813546281876	город Губкин, Карла Маркса, 21а	Россия, Белгородская область, Губкин	0101000020E61000003579CA6ABAC6424075C8CD7003A44940
23764	1	1	\N	930	33556	\N	51.281596855186599	город Губкин, Добролюбова, 13а	Россия, Белгородская область, Губкин	0101000020E6100000CA4E3FA88BCC42406BD3D85E0BA44940
23754	1	1	\N	930	33416	\N	51.282026999999999	город Губкин, Дзержинского, 17	Россия, Белгородская область, Губкин	0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23765	1	1	\N	930	33370	\N	51.282026999999999	город Губкин, Гастелло, 14		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23758	1	1	\N	930	33470	\N	51.282026999999999	город Губкин, Воинов-интернационалистов, 1		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23773	1	1	\N	930	33260	\N	51.277290405920198	город Губкин, Белгородская, 349	Россия, Белгородская область, Губкин	0101000020E6100000274A42226DC5424001C11C3D7EA34940
23772	1	1	\N	930	33260	\N	51.282026999999999	город Губкин, Белгородская, 97		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23740	1	1	\N	930	33640	\N	51.282026999999999	город Губкин, Артема, 18/3		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23762	1	1	\N	930	33369	\N	51.282026999999999	город Губкин, Агошкова, 1а		0101000020E6100000B9E34D7E8BCC424064CBF27519A44940
23752	1	1	\N	930	33641	\N	51.284072879745104	город Губкин, 9 Января, 2	Россия, Белгородская область, Губкин	0101000020E6100000431B800D88C242409B560A815CA44940
23755	1	1	\N	930	33261	\N	51.278797709328501	город Губкин, 2-я Академическая, 34	Россия, Белгородская область, Губкин	0101000020E6100000D921FE614BC54240591822A7AFA34940
23424	1	1	7303	\N	33427	\N	50.575620324279299	город Белгород, Персого салюта бульвар, 8	Россия, Белгородская область, Белгород городской округ	0101000020E610000039639813B44B4240367689EAAD494940
23338	1	1	\N	11717	33329	\N	50.600485999999997	город Белгород, Юности бульвар, 14		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23330	1	1	7308	\N	33329	\N	50.563536434571702	город Белгород, Юности бульвар, 4	Россия, Белгородская область, Белгород городской округ	0101000020E6100000FAEFC16B97484240300F99F221484940
23344	1	1	\N	11717	33283	\N	50.600485999999997	город Белгород, Щорса, 18	Россия, Белгородская область, Белгород	0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23343	1	1	\N	11717	33283	\N	50.572746646516798	город Белгород, Щорса, 14	Россия, Белгородская область, Белгород городской округ	0101000020E61000004E266E15C4484240E9F010C64F494940
23342	1	1	\N	11717	33283	\N	50.579524630091797	город Белгород, Щорса, 11	Россия, Белгородская область, Белгород	0101000020E6100000BD546CCCEB484240711B0DE02D4A4940
23340	1	1	\N	11717	33283	\N	50.600485999999997	город Белгород, Щорса, 46		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23331	1	1	\N	11717	33283	\N	50.582482531397403	город Белгород, Щорса, 8	Россия, Белгородская область, Белгород	0101000020E6100000CFA3E2FF8E484240EDBC8DCD8E4A4940
23329	1	1	\N	11717	33283	\N	50.600485999999997	город Белгород, Щорса, 55В		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23328	1	1	\N	11717	33283	\N	50.600485999999997	город Белгород, Щорса, 43		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23429	1	1	\N	11717	33569	\N	50.600485999999997	город Белгород, Шумилова, 12А		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23411	1	1	\N	11717	33636	\N	50.600485999999997	город Белгород, Широкая, 1	Россия, Белгородская область, Белгород	0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23376	1	1	\N	11717	33341	\N	50.615095859842398	город Белгород, Шершнева, 26	Россия, Белгородская область, Белгород	0101000020E61000003F58C6866E4A424041F33977BB4E4940
23346	1	1	7303	\N	33236	\N	50.5704584897139	город Белгород, Шаландина, 5	Россия, Белгородская область, Белгород городской округ	0101000020E61000002385B2F0F5494240ECDE8AC404494940
23327	1	1	\N	11717	33291	\N	50.569413072106997	город Белгород, Шаландина, 13	Россия, Белгородская область, Белгород городской округ	0101000020E61000004AD235936F4A424068757286E2484940
23404	1	1	\N	11717	33380	\N	50.591184372550998	город Белгород, Чумичева, 51	Россия, Белгородская область, Белгород	0101000020E61000000876FC17084C424090F5D4EAAB4B4940
23403	1	1	\N	11717	33380	\N	50.590569695875999	город Белгород, Чумичева, 53А	Россия, Белгородская область, Белгород	0101000020E6100000CA349A5C8C4B4240D6FF39CC974B4940
23366	1	1	\N	11717	33425	\N	50.600485999999997	город Белгород, Чапаева, 22		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23356	1	1	\N	11717	33425	\N	50.596210759005601	город Белгород, Чапаева, 14	Россия, Белгородская область, Белгород	0101000020E6100000DA56B3CEF8484240FA415DA4504C4940
23395	1	1	\N	11717	33367	\N	50.600485999999997	город Белгород, Хихлушки, 4		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23364	1	1	\N	11717	33299	\N	50.625074711159797	город Белгород, Сумская, 378	Россия, Белгородская область, Белгородский район, поселок Стрелецкое	0101000020E61000007E384888F23F42400B46257502504940
23363	1	1	\N	11717	33299	\N	50.598360552509199	город Белгород, Сумская, 72	Россия, Белгородская область, Белгород	0101000020E610000059897956D24C4240D619DF17974C4940
23361	1	1	\N	11717	33299	\N	50.607395263852197	город Белгород, Сумская, 64	Россия, Белгородская область, Белгород	0101000020E6100000DF6C73637A46424080608E1EBF4D4940
23391	1	1	\N	11717	33435	\N	50.621341423004097	город Белгород, Студенческая, 14	Россия, Белгородская область, Белгород	0101000020E6100000F9A067B3EA494240FC54151A884F4940
23377	1	1	\N	11717	33435	\N	50.619713986595897	город Белгород, Студенческая, 17А	Россия, Белгородская область, Белгород	0101000020E610000061545227A0494240CA6FD1C9524F4940
23318	1	1	7308	\N	33431	\N	50.5674724965533	город Белгород, Спортивная, 6А	Россия, Белгородская область, Белгород городской округ	0101000020E61000005D876A4AB2464240A7B228ECA2484940
23354	1	1	\N	11717	33519	\N	50.598778378620601	город Белгород, Славы пр, 69	Россия, Белгородская область, Белгород	0101000020E610000097546D37C14942403BC8EBC1A44C4940
23394	1	1	\N	11717	33303	\N	50.608630994493403	город Белгород, Садовая, 116А	Россия, Белгородская область, Белгород	0101000020E6100000335019FF3E4B4240782AE09EE74D4940
23373	1	1	\N	11717	33303	\N	50.610979475494098	город Белгород, Садовая, 3	Россия, Белгородская область, Белгород	0101000020E61000003080F0A1444B42407AC5538F344E4940
23393	1	1	\N	11717	33308	\N	50.623245641948003	Город Белгород, Садовая, 116А	Россия, Белгородская область, Белгород городской округ	0101000020E6100000C4211B48174B424071AE6186C64F4940
23398	1	1	\N	11717	33188	\N	50.600198703439801	город Белгород, Репина, 3	Россия, Белгородская область, Белгород городской округ	0101000020E6100000CCB4FD2B2B534240C40B2252D34C4940
23422	1	1	\N	11717	33464	\N	50.600485999999997	город Белгород, Пугачева, 5		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23378	1	1	\N	11717	33198	\N	50.632888398994901	город Белгород, Привольная, 16	Россия, Белгородская область, Белгород	0101000020E6100000593332C85D484240F303577902514940
23371	1	1	\N	11717	33198	\N	50.631366708896401	город Белгород, Привольная, 2	Россия, Белгородская область, Белгород	0101000020E6100000C7F484251E484240066344A2D0504940
23417	1	1	\N	11717	33240	\N	50.596871456498498	город Белгород, Преображенская, 19	Россия, Белгородская область, Белгород	0101000020E61000008D7F9F71E14C42402577D844664C4940
23409	1	1	\N	11717	33240	\N	50.600485999999997	город Белгород, Преображенская, 14		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23359	1	1	\N	11717	33240	\N	50.600485999999997	город Белгород, Преображенсская, 98		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23358	1	1	\N	11717	33240	\N	50.599106149711702	город Белгород, Преображенская, 78	Россия, Белгородская область, Белгород	0101000020E61000005CCCCF0D4D4B42402F6B6281AF4C4940
23415	1	1	\N	11717	33345	\N	50.600485999999997	город Белгород, Попова, 26/45		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23399	1	1	\N	11717	33345	\N	50.600485999999997	город Белгород, Попова, 98		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23421	1	1	\N	11717	33377	\N	50.5928917654225	город Белгород, Победы, 40А	Россия, Белгородская область, Белгород	0101000020E6100000E161DA37F74B4240AF0793E2E34B4940
23357	1	1	\N	11717	33377	\N	50.600485999999997	город Белгород, Победы, 78	Россия, Белгородская область, Белгород	0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23353	1	1	\N	11717	33377	\N	50.594653729586	город Белгород, Победы, 85А	Россия, Белгородская область, Белгород	0101000020E610000038D89B1892494240C1374D9F1D4C4940
23407	1	1	\N	11717	33436	\N	50.602762690323203	город Белгород, Первомайская, 2А	Россия, Белгородская область, Белгород	0101000020E6100000A4552DE9284D4240931E8656274D4940
23426	1	1	\N	11717	33347	\N	50.600485999999997	город Белгород, Первого салюта бульвар, 6		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23425	1	1	\N	11717	33347	\N	50.600485999999997	город Белгород, Первого салюта бульвар, 8		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23406	1	1	\N	11717	33349	\N	50.603315755629197	город Белгород, Октябрьская, 59А	Россия, Белгородская область, Белгород	0101000020E61000000AA1832EE14C4240A7936C75394D4940
23402	1	1	\N	11717	33349	\N	50.609006486290298	город Белгород, Октябрьская, 26А	Россия, Белгородская область, Белгород	0101000020E61000000518963FDF4C4240AD889AE8F34D4940
23401	1	1	\N	11717	33349	\N	50.603810777675399	город Белгород, Октябрьская, 58	Россия, Белгородская область, Белгород	0101000020E61000006EA6423C124D424087FBC8AD494D4940
23355	1	1	\N	11717	33180	\N	50.5988322600545	город Белгород, Озембловского, 34	Россия, Белгородская область, Белгород	0101000020E61000002E8D5F78254942402EE6E786A64C4940
23390	1	1	\N	11717	33352	\N	50.630070162564799	город Белгород, Некрасова, 38А	Россия, Белгородская область, Белгород городской округ	0101000020E6100000C4AF58C3454A42406A183E22A6504940
23392	1	1	\N	11717	33304	\N	50.624634936201801	город Белгород, Некрасова, 19	Россия, Белгородская область, Белгород	0101000020E61000005D8940F50F4A4240EE77280AF44F4940
23389	1	1	\N	11717	33304	\N	50.6001031060066	город Белгород, Некрасова, 20	Россия, Белгородская область, Белгород	0101000020E6100000A8716F7EC34C4240A19DD32CD04C4940
23388	1	1	\N	11717	33304	\N	50.623081841215402	город Белгород, Некрасова, 17Б	Россия, Белгородская область, Белгород	0101000020E6100000D15D1267454A4240F65CA626C14F4940
23375	1	1	\N	11717	33304	\N	50.615498604366003	город Белгород, Некрасова, 5Б/8	Россия, Белгородская область, Белгород	0101000020E6100000965E9B8D954A424040DCD5ABC84E4940
23414	1	1	\N	11717	33182	\N	50.600485999999997	город Белгород, Народный бульвар, 55		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23405	1	1	\N	11717	33182	\N	50.600485999999997	город Белгород, Народный бульвар, 74		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23368	1	1	\N	11717	33182	\N	50.6031689549813	город Белгород, Народный бульвар, 118	Россия, Белгородская область, Белгород	0101000020E6100000064A0A2C80494240037B4CA4344D4940
23367	1	1	\N	11717	33182	\N	50.600485999999997	Город Белгород, Народный бульвар, 118	Россия, Белгородская область, Белгород	0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23319	1	1	\N	11717	33433	\N	50.5652629864678	город Белгород, Молодежная, 2А	Россия, Белгородская область, Белгород городской округ	0101000020E61000009700FC53AA444240C651B9895A484940
23325	1	1	\N	11717	33204	\N	50.5749132104729	город Белгород, Мокроусова, 3А	Россия, Белгородская область, Белгород городской округ	0101000020E610000088635DDC46494240CB85CABF96494940
23374	1	1	\N	11717	33179	\N	50.613054779204703	город Белгород, Мичурина, 39	Россия, Белгородская область, Белгород	0101000020E6100000239EEC66464B42401CD31396784E4940
23369	1	1	\N	11717	33179	\N	50.612092232021503	город Белгород, Мичурина, 43	Россия, Белгородская область, Белгород	0101000020E6100000575BB1BFEC4A42405512D907594E4940
23385	1	1	\N	11717	33434	\N	50.638360615053102	город Белгород, Менделеева, 14	Россия, Белгородская область, Белгород	0101000020E6100000011764CBF24942405C0531D0B5514940
23383	1	1	\N	11717	33434	\N	50.635181076203402	город Белгород, Менделеева, 4	Россия, Белгородская область, Белгород городской округ	0101000020E6100000A19FA9D72D4A424032056B9C4D514940
23384	1	1	\N	11717	33237	\N	50.634942260906499	город Белгород, Менделеева, 6		0101000020E61000007CF31B261A4A4240AD6D8AC745514940
23412	1	1	\N	11717	33343	\N	50.582236616006099	город Белгород, Макаренко, 3	Россия, Белгородская область, Белгород	0101000020E610000094A3005130554240B5C2F4BD864A4940
23382	1	1	\N	11717	33496	\N	50.645107889821404	город Белгород, Кутузова, 19	Россия, Белгородская область, Белгород	0101000020E610000001C0B167CF474240A93121E692524940
23370	1	1	\N	11717	33346	\N	50.600485999999997	город Белгород, Курская, 8	Россия, Белгородская область, Белгород	0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23379	1	1	\N	11717	33342	\N	50.600485999999997	город Белгород, Куйбышева, 33А		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23380	1	1	\N	11717	33666	\N	50.641130594942602	город Белгород, Крупской, 9	Россия, Белгородская область, Белгород	0101000020E61000009CDCEF5014484240D4B9A29410524940
23326	1	1	\N	11717	33503	\N	50.575767211315799	город Белгород, Костюкова, 11А	Россия, Белгородская область, Белгород городской округ	0101000020E6100000E09D7C7A6C494240DA8EA9BBB2494940
23420	1	1	\N	11717	33185	\N	50.582113657826298	город Белгород, Костюкова, 46	Россия, Белгородская область, Белгород	0101000020E6100000DF32A7CB624C4240994528B6824A4940
23352	1	1	\N	11717	33185	\N	50.578308625726699	город Белгород, Костюкова, 13		0101000020E610000061545227A0494240C1FD8007064A4940
23351	1	1	\N	11717	33185	\N	50.579217216239201	город Белгород, Костюкова, 20		0101000020E61000008E76DCF0BB494240C4245CC8234A4940
23397	1	1	\N	11717	33497	\N	50.6144405393092	город Белгород, Корочанская, 318	Россия, Белгородская область, Белгород	0101000020E610000085EE92382B5242402829B000A64E4940
23427	1	1	\N	11717	33386	\N	50.573601434859398	город Белгород, Королепа, 22	Россия, Белгородская область, Белгород городской округ	0101000020E610000074620FED634B4240F8F9EFC16B494940
23428	1	1	\N	11717	33284	\N	50.600485999999997	город Белгород, Королева, 22		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23349	1	1	\N	11717	33284	\N	50.573225659036098	город Белгород, Королева, 7	Россия, Белгородская область, Белгород городской округ	0101000020E61000004128EFE3684A4240C39B35785F494940
23348	1	1	\N	11717	33284	\N	50.600485999999997	город Белгород, Королева, 5		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23347	1	1	\N	11717	33284	\N	50.573020689134999	город Белгород, Королева, 8	Россия, Белгородская область, Белгород городской округ	0101000020E61000004145D5AF744A4240EA758BC058494940
23289	1	1	\N	11717	33253	\N	50.560003264092003	город Белгород, Конева, 11	Россия, Белгородская область, Белгород городской округ	0101000020E610000027DE019EB4484240B954A52DAE474940
23396	1	1	\N	11717	33740	\N	50.600594747868897	город Белгород, Индустриальная, 85	Россия, Белгородская область, Белгород	0101000020E61000005D50DF32A74942401092054CE04C4940
23387	1	1	\N	11717	33302	\N	50.600485999999997	город Белгород, Железнякова, 2		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23386	1	1	\N	11717	33302	\N	50.633064734134798	город Белгород, Железнякова, 4	Россия, Белгородская область, Белгород городской округ	0101000020E6100000A11342075D4A4240029F1F4608514940
23324	1	1	1588	\N	33201	\N	50.556326297146597	город Белгород, Есенина, 48Б	Россия, Белгородская область, Белгородский район	0101000020E610000018096D39974642400EF5BBB035474940
23323	1	1	\N	11717	33201	\N	50.557614635301803	город Белгород, Есенина, 40А		0101000020E61000009F3A56293D4742402861A6ED5F474940
23322	1	1	\N	11717	33201	\N	50.557392510559502	город Белгород, Есенина, 38А	Россия, Белгородская область, Белгород городской округ	0101000020E61000002CD32F116F474240790261A758474940
23419	1	1	\N	11717	33184	\N	50.582946287230698	город Белгород, Донецкая, 84	Россия, Белгородская область, Белгород	0101000020E61000003DB9A640664D4240C1AA7AF99D4A4940
23350	1	1	\N	11717	33461	\N	50.584217564411702	город Белгород, Дегтярева, 1	Россия, Белгородская область, Белгород	0101000020E61000003DD7F7E12049424005DEC9A7C74A4940
23337	1	1	\N	11717	33325	\N	50.565279002789701	город Белгород, Губкина, 27	Россия, Белгородская область, Белгород городской округ	0101000020E6100000656F29E78B474240CB0EF10F5B484940
23336	1	1	\N	11717	33325	\N	50.566495345345302	город Белгород, Губкина, 48	Россия, Белгородская область, Белгород городской округ	0101000020E6100000CD5B751DAA4742407C2C7DE882484940
23423	1	1	\N	11717	33189	\N	50.593858122195599	город Белгород, Гражданский пр, 33	Россия, Белгородская область, Белгород	0101000020E610000004E621533E4C4240E63BF889034C4940
23416	1	1	\N	11717	33189	\N	50.594748590842002	город Белгород, Гражданский пр, 50	Россия, Белгородская область, Белгород	0101000020E6100000D47FD6FCF84B4240132A38BC204C4940
23418	1	1	\N	11717	33183	\N	50.600485999999997	город Белгород, Гражданский пр, 55		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23345	1	1	\N	11717	33364	\N	50.598546206042599	город Белгород, Горького, 71	Россия, Белгородская область, Белгород	0101000020E6100000DF6B088ECB4C42406893C3279D4C4940
23333	1	1	\N	11717	33364	\N	50.576751000990903	город Белгород, Горького, 26А	Россия, Белгородская область, Белгород	0101000020E6100000AEB8382A37474240B8770DFAD2494940
23410	1	1	\N	11717	33581	\N	50.586048159483703	город Белгород, Волчанская, 22	Россия, Белгородская область, Белгород	0101000020E6100000888384285F4E42406FF1F09E034B4940
23362	1	1	\N	11717	33762	\N	50.602629543995697	город Белгород, Везельская, 95	Россия, Белгородская область, Белгород	0101000020E6100000223658384945424053CBD6FA224D4940
23430	1	1	\N	11717	33465	\N	50.600485999999997	город Белгород, Ватутина пр, 23		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23413	1	1	\N	11717	33344	\N	50.582480289706702	город Белгород, Ватутина, 2А	Россия, Белгородская область, Белгород	0101000020E61000001092054CE05242407B4963B48E4A4940
23339	1	1	\N	11717	33178	\N	50.600485999999997	город Белгород, Буденного, 1		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23321	1	1	\N	11717	33178	\N	50.600485999999997	город Белгород, Буденного, 4		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23408	1	1	\N	11717	33498	\N	50.602339775767597	город Белгород, Белгородского полка, 56А	Россия, Белгородская область, Белгород	0101000020E6100000EB8CEF8B4B4D42404C89247A194D4940
23360	1	1	\N	11717	33247	\N	50.600485999999997	город Белгород, Белгородский пр, 116	Россия, Белгородская область, Белгород	0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23372	1	1	\N	11717	33469	\N	50.600485999999997	город Белгород, Б.Хмельницкого, 58		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23332	1	1	\N	11717	33257	\N	50.600485999999997	город Белгород, Апанасенко, 51А		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23334	1	1	\N	11717	33366	\N	50.580837433885399	город Белгород, 8 Марта, 172		0101000020E6100000C76647AAEF44424044A7E7DD584A4940
23317	1	1	\N	11717	33176	\N	50.600485999999997	город Белгород, 60 лет Октября, 4	Россия, Белгородская область, Белгород	0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23316	1	1	\N	11717	33176	\N	50.563105907737302	город Белгород, 60 лет Октября, 7	Россия, Белгородская область, Белгород городской округ	0101000020E6100000B85851836946424037177FDB13484940
23341	1	1	\N	11717	33333	\N	50.581444213184703	город Белгород, 5 Августа, 2	Россия, Белгородская область, Белгород	0101000020E6100000664E97C5C44842404B3ACAC16C4A4940
23400	1	1	\N	11717	33248	\N	50.606500874911298	город Белгород, 2 Карьерный пер, 10		0101000020E6100000195932C7F24C4240E3FE23D3A14D4940
23365	1	1	\N	11717	33494	\N	50.6327792210854	город Белгород, 2 Декабристов пер, 8	Россия, Белгородская область, Белгородский район, поселок Стрелецкое	0101000020E6100000B9E177D32D3F42403C4CFBE6FE504940
23381	1	1	\N	11717	33495	\N	50.600485999999997	город Белгород, 1 Центральная, 20		0101000020E61000002D78D157904C424059DAA9B9DC4C4940
23261	1	1	\N	10381	33313	\N	50.630436205972998	Белгородская область, г. Алексеевка, пл.3 Интернационала, 5	Россия, Белгородская область, Алексеевка	0101000020E6100000139CFA40F25843404C1C7920B2504940
23268	1	1	\N	10381	33375	\N	50.626812000000001	Белгородская область, г. Алексеевка, Чкалова, 62		0101000020E6100000C2DF2F664B584340C45E28603B504940
23266	1	1	\N	10381	33474	\N	50.626283212742003	Белгородская область, г. Алексеевка, Фрунзе, 2	Россия, Белгородская область, Алексеевка	0101000020E6100000EE06D15AD15643403885950A2A504940
23262	1	1	\N	10381	33335	\N	50.6374780119326	Белгородская область, г. Алексеевка, Ф.Энгельса, 6	Россия, Белгородская область, Алексеевка	0101000020E61000007558E1968F564340B2F50CE198514940
23265	1	1	\N	10381	33473	\N	50.626812000000001	Белгородская область, г. Алексеевка, Урицкого, 91		0101000020E6100000C2DF2F664B584340C45E28603B504940
23272	1	1	\N	10381	33258	\N	50.615619021745403	Белгородская область, г. Алексеевка, Тимирязева, 10	Россия, Белгородская область, Алексеевка	0101000020E61000003430F2B226584340EBE5779ACC4E4940
23275	1	1	\N	10381	33376	\N	50.626812000000001	Белгородская область, г. Алексеевка, Спортивная, 54		0101000020E6100000C2DF2F664B584340C45E28603B504940
23269	1	1	\N	10381	33432	\N	50.612864181856601	Белгородская область, г. Алексеевка, Свердлова, 10Г	Россия, Белгородская область, Алексеевка	0101000020E61000008A7269FCC2554340A872DA53724E4940
23270	1	1	\N	10381	33373	\N	50.626812000000001	Белгородская область, г. Алексеевка, Привокзальная, 5		0101000020E6100000C2DF2F664B584340C45E28603B504940
23263	1	1	\N	10381	33472	\N	50.626812000000001	Белгородская область, г. Алексеевка, Ленина, 119		0101000020E6100000C2DF2F664B584340C45E28603B504940
23264	1	1	\N	10381	33374	\N	50.626812000000001	Белгородская область, г. Алексеевка, Л.Толстого, 8		0101000020E6100000C2DF2F664B584340C45E28603B504940
23271	1	1	\N	10381	33300	\N	50.625979941725397	Белгородская область, г. Алексеевка, Комсомольская, 51	Россия, Белгородская область, Алексеевка	0101000020E6100000B9E34D7E8B5443409CF9D51C20504940
23273	1	1	\N	10381	33297	\N	50.626812000000001	Белгородская область, г. Алексеевка, Кирова, 6		0101000020E6100000C2DF2F664B584340C45E28603B504940
23267	1	1	\N	10381	33475	\N	50.626812000000001	Белгородская область, г. Алексеевка, В.Собины, 10		0101000020E6100000C2DF2F664B584340C45E28603B504940
24388	1	1	46	344	9885	\N	50.861288000000002	Белгородская область,  Яковлевский район, п. Яковлево, Шаландина, 80Б		0101000020E610000005871744A4384240F83768AF3E6E4940
24387	1	1	46	344	33228	\N	50.861288000000002	Белгородская область,  Яковлевский район, п. Яковлево, Октябрьская, 11		0101000020E610000005871744A4384240F83768AF3E6E4940
24427	1	1	46	2690	33653	\N	50.699871889706102	Белгородская область,  Яковлевский район, с. Шопино, Школьный пер, 5	Россия, Белгородская область, Яковлевский район, поселок Шопино	0101000020E61000006B4AB20E474B42406CB1DB6795594940
24398	1	1	46	1044	33739	\N	50.806693000000003	Белгородская область,  Яковлевский район, с. Черкасское, Озерная, 1А		0101000020E610000033DDEBA4BE144240C1745AB741674940
24408	1	1	46	1604	9843	\N	50.786108057766597	Белгородская область,  Яковлевский район, с. Триречное, Школьная, 3	Россия, Белгородская область, Яковлевский район, поселок Триречное	0101000020E6100000A33A1DC87A244240DE8FDB2F9F644940
24393	1	1	46	561	33276	\N	50.683712999999997	Белгородская область,  Яковлевский район, п. Томаровка, Ватутина, 5		0101000020E610000034D593F9471D4240CE6C57E883574940
24391	1	1	46	561	33276	\N	50.685067772234099	"Белгородская область,  Яковлевский район, п.Томаровка"", Ватутина, 3"	Россия, Белгородская область, Яковлевский район, поселок Томаровка	0101000020E610000040F67AF7C71D4240A0C4E74EB0574940
24390	1	1	46	561	33276	\N	50.683712999999997	Белгородская область,  Яковлевский район, п. Томаровка, Ватутина, 1		0101000020E610000034D593F9471D4240CE6C57E883574940
24394	1	1	46	561	33278	\N	50.683712999999997	Белгородская область,  Яковлевский район, п.Томаровка, 32-го Гвардейского Корпуса, 15А		0101000020E610000034D593F9471D4240CE6C57E883574940
24426	1	1	46	2646	33280	\N	50.731782000000003	Белгородская область,  Яковлевский район, с. Терновка, Центральная, 5		0101000020E61000000D6D0036204C424097E65608AB5D4940
24385	1	1	46	54	33321	\N	50.784022	Белгородская область,  Яковлевский район, г. Строитель, Юбилейная, 1		0101000020E6100000BA4BE2AC883C424019AC38D55A644940
24384	1	1	46	54	33279	\N	50.7995539440507	Белгородская область,  Яковлевский район, г. Строитель, Победы, 7	Россия, Белгородская область, Яковлевский район	0101000020E6100000C6504EB4AB3E424068B114C957664940
24381	1	1	46	54	33518	\N	50.783913016492797	Белгородская область,  Яковлевский район, г. Строитель, Октябрьская, 2	Россия, Белгородская область, Яковлевский район, Строитель	0101000020E6100000A3C9C518583D424062F4DC4257644940
24383	1	1	46	54	33230	\N	50.7821717878196	Белгородская область,  Яковлевский район, г. Строитель, Ленина, здание столовой ПУ № 16	Россия, Белгородская область, Яковлевский район, Строитель	0101000020E61000004EB6813B503F424068EC4B361E644940
24382	1	1	46	54	33230	\N	50.782338431665998	Белгородская область,  Яковлевский район, г. Строитель, Ленина, 24	Россия, Белгородская область, Яковлевский район, Строитель	0101000020E6100000A9A44E40133F42408335CEA623644940
24380	1	1	46	54	33230	\N	50.7840218411203	Белгородская область,  Яковлевский район, город Строитель, Ленина, 9	Россия, Белгородская область, Яковлевский район, Строитель	0101000020E6100000EBFCDB65BF3E424019AC38D55A644940
24377	1	1	46	54	33230	\N	50.785953435883798	Белгородская область,  Яковлевский район, г. Строитель, Ленина, 14	Россия, Белгородская область, Яковлевский район, Строитель	0101000020E6100000A30227DBC03D4240B7989F1B9A644940
24265	1	1	1807	26758	33532	\N	50.949657000000002	п. Чернянка, переулок Оскольский, дом 1		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24378	1	1	46	54	33452	\N	50.788673855812299	Белгородская область,  Яковлевский район, г. Строитель, 5-Августа, 10	Россия, Белгородская область, Яковлевский район, Строитель	0101000020E6100000791EDC9DB53D42404E9A0645F3644940
24386	1	1	46	53995	33521	\N	50.772212883898803	Белгородская область,  Яковлевский район, г. Строитель, Магистральная, 2	Россия, Белгородская область, Яковлевский район	0101000020E6100000F56569A7E6404240E54526E0D7624940
24424	1	1	46	2536	33578	\N	50.735345000000002	Белгородская область,  Яковлевский район, с. Стрелецкое, Школьная, 3А		0101000020E61000008F006E162F2842407923F3C81F5E4940
24389	1	1	46	455	33598	\N	50.812680999999998	Белгородская область,  Яковлевский район, с. Смородино, Советская, 41		0101000020E61000000917F2086E444240508A56EE05684940
24416	1	1	46	54019	33658	\N	50.644964204850901	Белгородская область,  Яковлевский район, с. Серетино, Калинина, 110	Россия, Белгородская область, Яковлевский район, поселок Серетено	0101000020E61000007FD93D7958144240768C2B2E8E524940
24414	1	1	46	1953	14688	\N	50.797138975593299	Белгородская область,  Яковлевский район, с. Сажное, Центральная, 20	Россия, Белгородская область, Яковлевский район, поселок Сажное	0101000020E6100000FEEDB25F775A4240DEAE97A608664940
24402	1	1	46	1953	14688	\N	50.809145999999998	Белгородская область,  Яковлевский район, п. станция Сажное, Центральная, 14	Россия, Белгородская область, Яковлевский район, поселок Сажное	0101000020E6100000CADE52CE1757424038D89B1892674940
24412	1	1	46	1830	33833	\N	50.764741000000001	Белгородская область,  Яковлевский район, с. Сабынино, Центральная, 13		0101000020E6100000530438BD8B5D424086747808E3614940
24422	1	1	46	2428	33845	\N	50.717173000000003	Белгородская область,  Яковлевский район, с. Пушкарное, Школьный пер, 3А		0101000020E6100000C504357C0B25424080492A53CC5B4940
24406	1	1	46	1494	33711	\N	50.874015999999997	Белгородская область,  Яковлевский район, с. Подымовка, Центральная, 41		0101000020E6100000E78A5242B00E424022179CC1DF6F4940
24413	1	1	46	1883	33713	\N	50.825968000000003	Белгородская область,  Яковлевский район, с. Озерово, Центральная, 32		0101000020E61000001E1A16A3AE55424072C5C551B9694940
24418	1	1	46	2192	33753	\N	50.699478999999997	Белгородская область,  Яковлевский район, с. Новая Глинка, Центральная, 48	Россия, Белгородская область, Яковлевский район, поселок Новая Глинка	0101000020E6100000B58D3F51D9164240909E228788594940
24420	1	1	46	2305	33795	\N	50.686982999999998	Белгородская область,  Яковлевский район, с. Мощеное, Садовая, 2А		0101000020E6100000E04A766C0412424038F4160FEF574940
24423	1	1	46	2305	33887	\N	50.686982999999998	Белгородская область,  Яковлевский район, с. Мощеное, Набережная, 23		0101000020E6100000E04A766C0412424038F4160FEF574940
24396	1	1	46	934	33757	\N	50.861316000000002	Белгородская область,  Яковлевский район, с. Луханино, Новая, 18		0101000020E61000005A492BBEA1204240C2C2499A3F6E4940
24419	1	1	46	2243	33727	\N	50.712381999999998	Белгородская область,  Яковлевский район, с. Локня, Лесная, 17		0101000020E6100000DFC14F1C400B4240292158552F5B4940
24417	1	1	46	2137	33323	\N	50.659759000000001	Белгородская область,  Яковлевский район, с. Кустовое, Проворова, 41		0101000020E6100000C39CA04D0E174240EF1EA0FB72544940
24401	1	1	46	1211	\N	\N	50.808383999999997	Белгородская область,  Яковлевский район, с. Крюково, здание сельского клуба		0101000020E61000009A6038D730514240094E7D2079674940
24410	1	1	46	1716	33537	\N	50.800215000000001	Белгородская область,  Яковлевский район, с. Кривцово, Центральная, 18		0101000020E610000007F01648506042406362F3716D664940
24392	1	1	46	54007	33575	\N	50.668045143591399	Белгородская область,  Яковлевский район, п.Томаровка, Малиновского, 35	Россия, Белгородская область, Яковлевский район, поселок Красная Поляна	0101000020E6100000C30E63D2DF1B4240CFA0A17F82554940
24415	1	1	46	2011	\N	\N	50.618177000000003	Белгородская область,  Яковлевский район, с. Калинино, Зеленая, 58	Россия, Белгородская область, Яковлевский район, поселок Калинино	0101000020E6100000FB5B02F04F1D4240D811876C204F4940
24407	1	1	46	1553	\N	\N	50.733851000000001	Белгородская область,  Яковлевский район, с. Казацкое, Центральная, 3	Россия, Белгородская область, Яковлевский район, поселок Казацкое	0101000020E61000003A58FFE7301F424086915ED4EE5D4940
24405	1	1	46	1433	33554	\N	50.859468999999997	Белгородская область,  Яковлевский район, с. Завидовка, Школьная, 1		0101000020E610000056D7A19A9212424081768714036E4940
24421	1	1	46	2354	33875	\N	50.744706093556097	Белгородская область,  Яковлевский район, с. Драгунское, Центральная, 67	Россия, Белгородская область, Яковлевский район, поселок Драгунское	0101000020E6100000EA77616BB62442404791B586525F4940
24404	1	1	46	1366	33630	\N	50.826149999999998	Белгородская область,  Яковлевский район, с.Дмитриевка, Центральная, 59		0101000020E61000001CEE23B7262D424092CB7F48BF694940
24403	1	1	46	1141	33322	\N	50.775519000000003	Белгородская область,  Яковлевский район, с. Гостищево, Советская, 5		0101000020E6100000F146E6913F5442409C36E33444634940
24400	1	1	46	1141	33322	\N	50.775519000000003	Белгородская область,  Яковлевский район, с. Гостищево, Советская, 15		0101000020E6100000F146E6913F5442409C36E33444634940
24425	1	1	46	2594	33831	\N	50.759276999999997	Белгородская область,  Яковлевский район, с. Вислое, Школьная, 13		0101000020E610000055682096CD4C424070CD1DFD2F614940
24411	1	1	46	1772	33760	\N	50.781641	Белгородская область,  Яковлевский район, с. Верхний Ольшанец, Школьная, 1		0101000020E61000000ABB287AE06942403B1BF2CF0C644940
24399	1	1	46	1078	33175	\N	50.807814	Белгородская область,  Яковлевский район, с. Быковка, Центральная, 64		0101000020E6100000FA08FCE1E73742401FA0FB7266674940
24397	1	1	46	938	14703	\N	50.764170999999997	Белгородская область,  Яковлевский район, с. Бутово, Речная, 3	Россия, Белгородская область, Яковлевский район, поселок Бутово	0101000020E6100000F27D71A94A1742409BC6F65AD0614940
24395	1	1	46	860	33680	\N	50.863795000000003	Белгородская область,  Яковлевский район, с. Алексеевка, Центральная, 36		0101000020E6100000F3E84658541A424063B9A5D5906E4940
24376	1	1	1249	54038	33768	\N	50.456715000000003	Белгородская область, Шебекинский район, поселок Шебекинский, ул. Подлесная, 1		0101000020E6100000AAD216D7F8884240DC4B1AA3753A4940
24371	1	1	1249	31987	33580	\N	50.486801999999997	Белгородская область, Шебекинский район, село Чураево, ул. Гагарина, сельский дом культуры		0101000020E610000088855AD3BC6F42404ED026874F3E4940
24355	1	1	1249	54027	33731	\N	50.524116381254998	Белгородская область, Шебекинский район, село Червонодибровка, ул. Центральная, здание общежития БГК	Россия, Белгородская область, Шебекинский район, поселок Червона Дибровка	0101000020E610000074CE4F711CA44240B9A7AB3B16434940
24369	1	1	1249	31916	33645	\N	50.500445999999997	Белгородская область, Шебекинский район, село Первое Цепляево, ул. Ленина, сельский дом культуры		0101000020E610000050560C5707A04240FEB4519D0E404940
24370	1	1	1249	31959	33679	\N	50.488715999999997	Белгородская область, Шебекинский район, село Сурково, ул. Фрунзе, сельский дом культуры		0101000020E6100000680932022A9C42401684F23E8E3E4940
24336	1	1	1249	30293	33839	\N	50.658028999999999	Белгородская область, Шебекинский район, село Вторая Стрелица, ул. Больничная, д. 19, амбулатория		0101000020E61000009D64ABCB298D4240E868554B3A544940
24326	1	1	1249	29806	33868	\N	50.650587999999999	Белгородская область, Шебекинский район, село Первая стрелица, ул. Октябрьская, сельский клуб		0101000020E61000001A6EC0E787AF4240C495B37746534940
24337	1	1	1249	30320	33637	\N	50.583851000000003	Белгородская область, Шебекинский район, село Стариково, ул. Ленина, сельский клуб		0101000020E6100000D0B7054B75854240535E2BA1BB4A4940
24364	1	1	1249	31681	33721	\N	50.241956000000002	Белгородская область, Шебекинский район, село Середа, ул. Октябрьская, здание школы		0101000020E6100000029CDEC5FB4F42401689096AF81E4940
24344	1	1	1249	30693	33596	\N	50.431595999999999	Белгородская область, Шебекинский район, село Ржевка, ул. Пионерская, д.49, здание школы		0101000020E610000064575A46EA7D4240CE8AA8893E374940
24345	1	1	1249	30693	33412	\N	50.431595999999999	Белгородская область, Шебекинский район, село Ржевка, ул. Ленина, д.1А, дом культуры	Россия, Белгородская область, Шебекинский район, поселок Ржевка	0101000020E610000064575A46EA7D4240CE8AA8893E374940
24351	1	1	1249	31038	33724	\N	50.549128000000003	Белгородская область, Шебекинский район, село Репное, ул. 1 Мая, здание сельской библиотеки		0101000020E61000003F8BA548BE824240B1A888D349464940
24333	1	1	1249	30142	33756	\N	50.565294000000002	Белгородская область, Шебекинский район, село Попопвка, ул.Центральная, сельский дом культуры		0101000020E6100000CCB6D3D688BC42400150C58D5B484940
24360	1	1	1249	31517	33843	\N	50.506833999999998	Белгородская область, Шебекинский район, село Поляна, ул. Центральная, 16		0101000020E6100000D93D7958A86742401C40BFEFDF404940
24365	1	1	1249	31730	33517	\N	50.343291557996501	Белгородская область, Шебекинский район, село Новая Таволжанка, ул. Харьковская, 22	Россия, Белгородская область, Шебекинский район, поселок Новая Таволжанка	0101000020E610000047551344DD6942403D7D04FEF02B4940
24367	1	1	1249	31730	33613	\N	50.343069	Белгородская область, Шебекинский район, село Новая Таволжанка, ул. Колхозная, 13		0101000020E61000004A253CA1D7694240BEA25BAFE92B4940
24366	1	1	1249	31730	33334	\N	50.343069	Белгородская область, Шебекинский район, село Новая Таволжанка, ул. Кирова, 1Г		0101000020E61000004A253CA1D7694240BEA25BAFE92B4940
24374	1	1	1249	32113	33846	\N	50.570672000000002	Белгородская область, Шебекинский район, село Никольское, ул. Ленина, здание школы		0101000020E610000095EF1989D0724240185FB4C70B494940
24328	1	1	1249	29905	33761	\N	50.441761999999997	Белгородская область, Шебекинский район, село Нижнее березово второе, ул. Октябрьская, сельский клуб		0101000020E6100000AC00DF6DDE8C4240CA4E3FA88B384940
24375	1	1	1249	32175	33830	\N	50.588397999999998	Белгородская область, Шебекинский район, село Неклюдово, ул. Советская, здание ФАП		0101000020E6100000C26856B60F75424012842BA0504B4940
24343	1	1	1249	30628	33673	\N	50.433891000000003	Белгородская область, Шебекинский район, село Нежеголь, ул. Ленина, сельский дом культуры		0101000020E61000009A5DF75624824240AE8383BD89374940
24362	1	1	1249	31593	33541	\N	50.309778000000001	Белгородская область, Шебекинский район, село Муром, ул. Гагарина, здание школы		0101000020E610000058535914765B4240998235CEA6274940
24356	1	1	1249	31292	33676	\N	50.482658000000001	Белгородская область, Шебекинский район, село Мешковое, ул. Молодежная, здание школы		0101000020E6100000A306D3307CB642408E93C2BCC73D4940
24357	1	1	1249	31314	33277	\N	50.454433000000002	Белгородская область, Шебекинский район, поселок Маслова Пристань, ул. Шумилова, 1		0101000020E6100000FE62B664555E4240919C4CDC2A3A4940
24359	1	1	1249	31314	33413	\N	50.454433000000002	Белгородская область, Шебекинский район, поселок Маслова Пристань, ул.1 Мая, 4		0101000020E6100000FE62B664555E4240919C4CDC2A3A4940
24358	1	1	1249	31314	33413	\N	50.454433000000002	Белгородская область, Шебекинский район, поселок Маслова Пристань, ул. 1 Мая, 156		0101000020E6100000FE62B664555E4240919C4CDC2A3A4940
24341	1	1	1249	30521	33644	\N	50.430311000000003	Белгородская область, Шебекинский район, село Маломихайловка, ул. Садовая, сельский дом культуры		0101000020E6100000F8A41309A68A4240F60D4C6E14374940
24354	1	1	1249	31187	33570	\N	50.524842	Белгородская область, Шебекинский район, село Максимовка, ул. Коммунистическая, здание сельского дома культуры		0101000020E61000001E54E23AC6AB42409BC8CC052E434940
24348	1	1	1249	30906	33274	\N	50.525478	Белгородская область, Шебекинский район, село Купино, ул. Ленина, 61		0101000020E610000016DF50F86C8142403D62F4DC42434940
24342	1	1	1249	30593	33672	\N	50.368316	Белгородская область, Шебекинский район, село Красное, ул. Школьная, д. 10		0101000020E610000051C1E10511934240F94B8BFA242F4940
24350	1	1	1249	31008	33534	\N	50.549785999999997	Белгородская область, Шебекинский район, село Красная Поляна, ул. Гагарина, здание школы		0101000020E61000006C938AC6DA9142403AE63C635F464940
24373	1	1	1249	32103	33646	\N	50.455173000000002	Белгородская область, Шебекинский район, село Крапивное, ул. Победы, сельский дом культуры		0101000020E6100000D311C0CDE26F4240D882DE1B433A4940
24372	1	1	1249	32038	33597	\N	50.521760999999998	Белгородская область, Шебекинский район, село Кошлаково, ул. Молодежная, здание школы		0101000020E610000057EA5910CA6F424004AA7F10C9424940
24330	1	1	1249	29994	33565	\N	50.45176	Белгородская область, Шебекинский район, село Козьмодемьяновка, ул. Прилужная, сельский клуб		0101000020E6100000E46A64575A9042400BD28C45D3394940
24324	1	1	1249	29711	33812	\N	50.613314000000003	Белгородская область, Шебекинский район, село Караичное, ул. Гагарина, сельский клуб		0101000020E61000009FCC3FFA269B4240E816BA12814E4940
23777	1	1	1249	54030	33737	\N	50.432029829243703	село Ивановка, Центральная, 7	Россия, Белгородская область, Шебекинский район, поселок Ивановка	0101000020E61000000C5872158B5D4240087250C24C374940
24352	1	1	1249	31108	33829	\N	50.540174999999998	Белгородская область, Шебекинский район, село Зимовное, ул. Серпа и молота, здание сельского клуба		0101000020E6100000C74961DEE39A4240F38E537424454940
24329	1	1	1249	29936	33801	\N	50.481346000000002	Белгородская область, Шебекинский район, село Зимовенька, ул. Базарная, сельский клуб		0101000020E610000033C170AE61964240BC07E8BE9C3D4940
24363	1	1	1249	31634	33688	\N	50.372664999999998	Белгородская область, Шебекинский район, село Зиборовка, ул. Зеленая, здание сельского дома культуры		0101000020E6100000DE7536E49F55424092AE997CB32F4940
24349	1	1	1249	30939	33674	\N	50.488420747546598	Белгородская область, Шебекинский район, село Дмитриевка, ул. Победы, 38	Россия, Белгородская область, Шебекинский район, поселок Дмитриевка	0101000020E6100000E868554B3A804240FED64E94843E4940
24346	1	1	1249	12823	33460	\N	50.399625	Белгородская область, Шебекинский район, село Графовка, ул. Центральная, 1А		0101000020E61000009C6C0377A05E4240FED478E926334940
23972	1	1	1249	12823	33460	\N	50.398802291359303	село Графовка, Центральная, 1	Россия, Белгородская область, Шебекинский район, поселок Графовка	0101000020E6100000C9207711A65E42402ACAA5F10B334940
24340	1	1	1249	30495	33429	\N	50.416147000000002	Белгородская область, Шебекинский район, село Вознесеновка, ул. Административная, здание администрации		0101000020E61000008B34F10EF08242400DAA0D4E44354940
24339	1	1	1249	54021	33677	\N	50.5694563113491	Белгородская область, Шебекинский район, село Верхнее березово, ул. Кооперативная, здание школы	Россия, Белгородская область, Шебекинский район, поселок Верхнеберезово	0101000020E6100000AD8A7093519D4240684128EFE3484940
24334	1	1	1249	30203	33668	\N	50.605631000000002	Белгородская область, Шебекинский район, село Булановка, ул.Ленина, здание школы		0101000020E610000095D5743DD1B94240CE380D51854D4940
24335	1	1	1249	30221	33595	\N	50.630549000000002	Белгородская область, Шебекинский район, село Большое городище, ул. Советская, здание администрации		0101000020E6100000111956F1468A424044C362D4B5504940
24338	1	1	1249	30386	33411	\N	50.545957000000001	Белгородская область, Шебекинский район, село Большетроицкое, пер. Чапаева, Дом культуры		0101000020E6100000FF9254A698A54240DA0242EBE1454940
24331	1	1	1249	30040	33579	\N	50.548149000000002	"Белгородская область, Шебекинский район, село Бершаково, ул. Калинина, адм.здание АО""Восход"""		0101000020E6100000D09CF529C7B84240E52A16BF29464940
24327	1	1	1249	29854	33515	\N	50.464350637114997	Белгородская область, Шебекинский район, село Белянка, ул. Школьная, дом культуры	Россия, Белгородская область, Шебекинский район, поселок Белянка	0101000020E61000001DCC26C0B0984240B56E83DA6F3B4940
23629	1	1	1249	29647	\N	\N	50.627417999999999	село Белый Колодезь, помещение сельского Дома культуры		0101000020E610000065FED13769A84240FB75A73B4F504940
24323	1	1	1249	29647	33755	\N	50.627417999999999	Белгородская область, Шебекинский район, село Белый Колодезь, ул. Кирова, Дом культуры		0101000020E610000065FED13769A84240FB75A73B4F504940
24347	1	1	1249	30833	33568	\N	50.396115999999999	Белгородская область, Шебекинский район, село Безлюдовка, пер. Садовый, 19		0101000020E61000006FD8B628B36342400FB6D8EDB3324940
24361	1	1	1249	31533	33886	\N	50.567920000000001	Белгородская область, Шебекинский район, село Батрацкая Дача, ул. Центральная, Здание сельского клуба		0101000020E610000068CA4E3FA8694240465F419AB1484940
24368	1	1	1249	31855	33678	\N	50.355116000000002	Белгородская область, Шебекинский район, село Архангельское, ул. Ушакова, сельский дом культуры		0101000020E6100000A52DAEF199644240A724EB70742D4940
24325	1	1	1249	29750	33758	\N	50.606465999999998	Белгородская область, Шебекинский район, село Артельное, ул. Пролетарская, администрация		0101000020E61000007FBC57AD4CA8424066118AADA04D4940
24266	1	1	1249	54073	33918	\N	51.033200999999998	село Андреевка, улица Центральная, дом 36		0101000020E61000004F0647C9AB8F4240E5982CEE3F844940
24332	1	1	1249	30094	33719	\N	50.529519999999998	Белгородская область, Шебекинский район, село Александровка, ул.Степная, здание школы		0101000020E610000081CD397826C24240F949B54FC7434940
23625	1	1	1807	54065	\N	\N	51.0133503759061	с. Яблоново, здание Яблоновского сельского Дома культуры		0101000020E61000005858703FE0EB424068B3EA73B5814940
24263	1	1	1807	26758	33450	\N	50.949657000000002	п. Чернянка, пл.  Октябрьская, дом 4		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24257	1	1	1807	26758	33450	\N	50.949657000000002	п. Чернянка, пл. Октябрьская, дом 12		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24261	1	1	1807	26758	33227	\N	50.949657000000002	п. Чернянка, улица Строительная, дом 14		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24259	1	1	1807	26758	33456	\N	50.949657000000002	п. Чернянка, улица Советская, дом 59		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24258	1	1	1807	26758	33331	\N	50.949168989938201	п. Чернянка, улица Революции, дом 22	Россия, Белгородская область, Чернянский район, поселок Чернянка	0101000020E610000069FD2D01F8E7424042B0AA5E7E794940
24264	1	1	1807	26758	33451	\N	50.949657000000002	п. Чернянка, улица Первомайская, дом 154		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24262	1	1	1807	26758	33292	\N	50.949657000000002	п. Чернянка, улица Крупская, дом 12		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24260	1	1	1807	26758	33422	\N	50.949657000000002	п. Чернянка, улица Кольцова, дом 38		0101000020E6100000319A95ED43E8424070B54E5C8E794940
24277	1	1	1807	27606	33710	\N	50.849716999999998	село Холки, улица Школьная, дом 10		0101000020E61000007F33315D88DD424078EDD286C36C4940
24283	1	1	1807	48014	33720	\N	50.980142000000001	село Хитрово, улица Центральная, дом 24		0101000020E61000006C3D433866034340D0B7054B757D4940
24282	1	1	1807	48002	33867	\N	51.054993000000003	село Славянка, улица Центральная, дом 71 кв. 1		0101000020E61000005FB87361A4FD42402541B8020A874940
24298	1	1	1807	28548	33631	\N	50.944737000000003	село Русская Халань, пер. Пятый Центральный, дом 8		0101000020E61000002C836A8313DD42401C295B24ED784940
24294	1	1	1807	48247	33728	\N	50.931078079425497	село Прилепы, им. Ивлева Д.Д, дом 5 кв. 2	Россия, Белгородская область, Чернянский район, поселок Прилепы	0101000020E6100000D3A414747BCD424036035C902D774940
24291	1	1	1807	48182	33628	\N	51.062747999999999	село Орлик, улица Центральная, дом 8		0101000020E610000075560BEC31DB4240D8F15F2008884940
24289	1	1	1807	48148	33535	\N	51.008004999999997	село Ольшанка, улица Школьная, дом 2		0101000020E6100000C422861DC6D642402C9ACE4E06814940
24273	1	1	1807	47836	33826	\N	51.021791999999998	село Окуни, улица Центральная, дом 24		0101000020E6100000F8AA9509BFEC42403FA88B14CA824940
24287	1	1	1807	48087	33794	\N	51.063291999999997	село Огибное, улица Центральная, дом 76		0101000020E610000032005471E3C84240990CC7F319884940
24285	1	1	1807	27971	33836	\N	51.018828999999997	село Новоречье, улица Центральная, дом 61		0101000020E61000003447567E191A4340B29B19FD68824940
24276	1	1	1807	27569	33791	\N	50.888672	село Новая Масловка, улица Парковая, дом 14		0101000020E6100000293FA9F6E9F842407A6F0C01C0714940
24270	1	1	1807	54059	33844	\N	50.930916000000003	хутор Малый, улица Молодежная, дом 2	Россия, Белгородская область, Чернянский район, поселок Малый	0101000020E6100000EBE3A1EF6EF542405DA9674128774940
24281	1	1	1807	27767	33536	\N	51.037624999999998	село Малотроицкое, улица Садовая, дом 16		0101000020E610000034BA83D899044340894160E5D0844940
23699	1	1	1807	31398	\N	\N	50.903276488442103	поселок Малиново, Здание сельского клуба	Россия, Белгородская область, Чернянский район, поселок Малиново	0101000020E61000002C47C8409E0143407FA1478C9E734940
24280	1	1	1807	27746	33810	\N	50.954917000000002	село Лубяное-Первое, улица Школьная, дом 3		0101000020E6100000FB2477D8441E43407DB262B83A7A4940
24279	1	1	1807	47938	33793	\N	50.880296000000001	село Лозное, улица Магистральная, дом 7		0101000020E610000039D2191879C142405A66118AAD704940
24286	1	1	1807	27996	33891	\N	51.038944999999998	село Ларисовка, улица Зеленая, дом 25		0101000020E6100000401361C3D3234340DEAB5626FC844940
24299	1	1	1807	54022	33697	\N	50.943449000000001	п. Красный Остров, улица Воровского, дом 45	Россия, Белгородская область, Чернянский район, поселок Красный Остров	0101000020E610000001857AFA08E44240D238D4EFC2784940
24278	1	1	1807	27654	33594	\N	51.016092	село Кочегуры, улица Центральная, дом 37		0101000020E61000008F56B5A4A3CC424016DD7A4D0F824940
24292	1	1	1807	28268	33709	\N	51.093435999999997	село Комаревцево, улица Новая, дом 2		0101000020E6100000BAD8B45208E042407022FAB5F58B4940
24295	1	1	1807	48253	33716	\N	50.938561999999997	село Ковылино, улица Центральная, дом 2		0101000020E61000006518778368D3424059A2B3CC22784940
24290	1	1	1807	48155	33706	\N	50.993834999999997	село Захарово, улица Покровская, дом 2		0101000020E61000000EA2B5A2CDDB4240614F3BFC357F4940
24272	1	1	1807	27338	33751	\N	51.044670000000004	село Завалищено, улица Садовая, дом 1		0101000020E61000007B12D89C83E94240618E1EBFB7854940
24275	1	1	1807	47870	33332	\N	50.884774	село Ездочное, улица Центральная, дом 16		0101000020E610000005DF347D76E44240F12C414640714940
24293	1	1	1807	48211	33717	\N	51.041114	село Воскресеновка, улица Полевая, дом 4		0101000020E6100000A75B76887FE0424031B43A3943854940
24274	1	1	1807	47852	33559	\N	50.937654000000002	село Волотово, улица Центральная, дом 41		0101000020E61000004354E1CFF0124340577BD80B05784940
24271	1	1	1807	27307	33647	\N	51.054228000000002	село Волоконовка, пл. Покровская, дом 2		0101000020E6100000BC2363B5F9ED424085436FF1F0864940
23666	1	1	1807	27307	33505	\N	51.054228000000002	поселок Волоконовка, Курочкина, 30		0101000020E6100000BC2363B5F9ED424085436FF1F0864940
23668	1	1	1807	27307	33506	\N	51.054228000000002	поселок Волоконовка, Коммунистическая, 2		0101000020E6100000BC2363B5F9ED424085436FF1F0864940
24288	1	1	1807	54056	33835	\N	51.086133027759502	село Волково, улица Хуторская, дом 3	Россия, Белгородская область, Чернянский район, поселок Волково	0101000020E6100000E3A6069ACFCD42409D0DF967068B4940
24297	1	1	1807	28474	33708	\N	50.963075000000003	хутор Водяное, улица Дачная, дом 25		0101000020E6100000EAD0E97937BE4240304CA60A467B4940
24296	1	1	1807	28463	33718	\N	50.909424000000001	село Верхнее Кузькино, улица Центральная, дом 1		0101000020E61000008FC360FE0AC742404819710168744940
24269	1	1	1807	27198	33790	\N	50.988523000000001	хутор Бородин, улица Верхняя, дом 30		0101000020E61000006AA33A1DC8F84240022CF2EB877E4940
24268	1	1	1807	54025	33714	\N	50.946935481245902	село Большое, улица Красовка, дом 3	Россия, Белгородская область, Чернянский район, поселок Большое	0101000020E61000001494A2957BFB42400938842A35794940
24284	1	1	1807	48038	33827	\N	51.016404000000001	село Баклановка, улица Центральная, дом 32		0101000020E6100000C7F0D8CF6211434005C3B98619824940
24267	1	1	1807	54078	33930	\N	50.529519999999998	село Александровка, улица Школьная, дом 5		0101000020E610000081CD397826C24240F949B54FC7434940
24177	1	1	7305	53986	33667	\N	51.303737537999602	город Старый Оскол, Ленина,82, кооперативный техникум	Россия, Белгородская область, Старый Оскол городской округ	0101000020E610000052F355F2B1E94240B74604E3E0A64940
24169	1	1	7305	53986	33423	\N	51.281727219880203	"город Старый Оскол, ул. Ватутина, 54, спорткомплекс ЗАО ""СОАТЭ"""		0101000020E6100000E94999D4D0EA424039B35DA10FA44940
24231	1	1	1473	54070	33904	\N	51.119040591516701	с.Верхне-Чуфичево, Центральная, 8, сельский клуб	Россия, Белгородская область, Старооскольский район	0101000020E6100000A0FD481119FC42400BF148BC3C8F4940
24207	1	1	1473	53988	33445	\N	51.309843655784299	город Старый Оскол, м-н Королева,17, СОШ №30	Россия, Белгородская область, Старооскольский район	0101000020E61000000473F4F8BDF34240506EDBF7A8A74940
24233	1	1	1473	47069	33792	\N	51.122242999999997	с.Шмарное, Центральная, 4, сельский клуб		0101000020E6100000BA69334E43EE42401C959BA8A58F4940
24256	1	1	1473	47534	33271	\N	51.140267999999999	с. Шаталовка, Центральная, 38, сельский дом культуры		0101000020E6100000E59A02999D2343407156444DF4914940
24242	1	1	1473	25999	33889	\N	51.224798620642702	с. Черниково, Мельничная, 44, сельский клуб	Россия, Белгородская область, Старооскольский район, поселок Черниково	0101000020E61000005322895E460143403596B036C69C4940
24243	1	1	1473	47258	33870	\N	51.268870999999997	с. Хорошилово, Центральная, 74, сельский клуб		0101000020E61000006B662D05A4094340E1EB6B5D6AA24940
24254	1	1	1473	26495	33330	\N	51.350982000000002	с. Федосеевка, Натальи Лихачевой, 48, детская школа искусств		0101000020E61000003753211E89E542400ABE69FAECAC4940
24253	1	1	1473	26495	33330	\N	51.350982000000002	с. Федосеевка, Натальи Лихачевой, 17, управление сельской территории		0101000020E61000003753211E89E542400ABE69FAECAC4940
24220	1	1	1473	40476	33837	\N	51.343392999999999	с. Терехово, Парковая, 1, дом культуры		0101000020E61000002079E750860643407156444DF4AB4940
24152	1	1	1473	54015	33707	\N	51.281108194541098	город Старый Оскол, пр.Губкина,103, современная гуманитарная Академия	Россия, Белгородская область, Старооскольский район	0101000020E61000000E66136058E242406E52D158FBA34940
24248	1	1	1473	26232	33638	\N	51.2229144628418	с. Роговатое, Владимира Ленина, 1, школа	Россия, Белгородская область, Старооскольский район, поселок Роговатое	0101000020E61000003A9160AA992F434008E92972889C4940
24249	1	1	1473	26232	33557	\N	51.224905999999997	с. Роговатое, Владимира Ленина,1, школа		0101000020E61000004562821ABE3143404B5645B8C99C4940
24247	1	1	1473	26232	33557	\N	51.224905999999997	с. Роговатое, Владимира Ленина,7, управление сельской территории		0101000020E61000004562821ABE3143404B5645B8C99C4940
24250	1	1	1473	47416	33803	\N	51.174320000000002	с. Преображенка, Центральная, 43, сельский клуб		0101000020E610000016DD7A4D0F3E4340F584251E50964940
24246	1	1	1473	26175	33828	\N	51.267564	с. Потудань, Центральная, 6, дом культуры		0101000020E610000012DBDD03741F434021CB82893FA24940
24245	1	1	1473	54004	33562	\N	51.300184997143504	с. Песчанка, Заводская, 10, завод сухих кормовых дрожжей		0101000020E6100000F44D9A0645DD4240F8DF4A766CA64940
24241	1	1	1473	47217	33592	\N	51.248246999999999	с. Озерки, Парковая, 8, управление сельской территории		0101000020E61000006F7EC34483024340412AC58EC69F4940
24240	1	1	1473	47196	33226	\N	51.178837999999999	с. Обуховка, пер. Школьный, 2, школа		0101000020E6100000520DFB3DB1FC42401AA4E029E4964940
24238	1	1	1473	25823	33841	\N	51.382579	с. Новокладовое, Городок, 47, бывшая школа		0101000020E610000067614F3BFCF5424075914259F8B04940
24013	1	1	1473	47251	\N	\N	51.301909999999999	село Николаевка, сельский Дом культуры		0101000020E6100000DF196D5512DD4240ED2AA4FCA4A64940
23657	1	1	1473	47251	\N	\N	51.305461901328101	село Николаевка, помещение средней школы	Россия, Белгородская область, Старооскольский район, поселок Николаевка	0101000020E6100000E2B034F0A3DC4240DB15FA6019A74940
23656	1	1	1473	47251	\N	\N	51.301909999999999	село Николаевка, помещение сельского Дома культуры		0101000020E6100000DF196D5512DD4240ED2AA4FCA4A64940
24239	1	1	1473	25842	33224	\N	51.271151437119698	с. Незнамово, Центральная, 3, дом культуры	Россия, Белгородская область, Старооскольский район, поселок Незнамово	0101000020E6100000715AF0A2AFF842408CA37213B5A24940
24232	1	1	1473	47029	33272	\N	51.15484	с. Монаково, Южная, 4, сельский дом культуры		0101000020E61000007A522635B4E342406B0E10CCD1934940
24056	1	1	1473	16865	33233	\N	51.36159	с Лапыгино, Центральная, 101, школа		0101000020E6100000978FA4A487FB4240C347C49448AE4940
24228	1	1	1473	46955	33566	\N	51.082917999999999	с. Крутое, Центральная,12, администрация		0101000020E6100000F9484A7A181C4340F71F990E9D8A4940
24237	1	1	1473	47133	33551	\N	51.308183	с. Котово, Котовская,11, школа		0101000020E6100000C7A01342070143407217618A72A74940
24255	1	1	1473	47498	33593	\N	51.350020000000001	с. Каплино, Московская, 5, сельский клуб		0101000020E61000000932022A1CEB424014799274CDAC4940
24235	1	1	1473	25684	33840	\N	51.114756999999997	с. Казачок, Центральная, 64, дом культуры		0101000020E610000097AB1F9BE4F1424058FE7C5BB08E4940
24236	1	1	1473	47142	33619	\N	51.096936999999997	с Ивановка, Молодежная, 9, школа		0101000020E610000001BF469220EE4240DC627E6E688C4940
24234	1	1	1473	47083	33669	\N	51.196615000000001	с. Знаменка, Центральная, 27, дом культуры		0101000020E610000074620FED63234340977329AE2A994940
24230	1	1	1473	46990	33629	\N	51.153151000000001	с.Долгая Поляна, Центральная, 6, управление сельской территории		0101000020E6100000B00111E2CADD4240C32CB4739A934940
24229	1	1	1473	54001	33548	\N	51.222727999999996	с. Дмитриевка, Садовая, 84, управление сельской территории	Россия, Белгородская область, Старооскольский район, поселок Дмитриевка	0101000020E610000038A45181930F4340A5F3E159829C4940
24226	1	1	1473	46915	33419	\N	51.113982999999998	с. Городище, ул. Гагарина, 3, дом культуры	Россия, Белгородская область, Старооскольский район, поселок Городище	0101000020E61000004B02D4D4B207434065A6B4FE968E4940
23673	1	1	1473	49369	\N	\N	51.130965000000003	село Голофеевка, Здание сельского Дома культуры	Россия, Белгородская область, Старооскольский район, поселок Голофеевка	0101000020E610000026C5C72764F34240D8F50B76C3904940
24224	1	1	1473	46859	33561	\N	51.256431999999997	с.Архангельское, Центральная, 35, школа		0101000020E6100000A7B393C1510E4340EDD286C3D2A04940
23782	1	1	1473	46859	33561	\N	51.256431999999997	село Архангельское, Центральная, 6		0101000020E6100000A7B393C1510E4340EDD286C3D2A04940
23998	1	1	1288	14048	\N	\N	50.642415	село Макешкино, сельский Дом культуры		0101000020E610000032772D211FE84240DCBA9BA73A524940
24136	1	1	474	21023	\N	\N	49.873913999999999	Белгородская область, Ровеньский район, хутор Шияны, здание Шияновского ФАП	Россия, Белгородская область, Ровеньский район, поселок Шияны	0101000020E610000021037976F96C43401EC2F869DCEF4840
24141	1	1	474	21255	\N	\N	50.204546999999998	Белгородская область, Ровеньский район, село Харьковское, здание Харьковского Дома культуры		0101000020E610000088B839950C86434059BF99982E1A4940
24140	1	1	474	21243	\N	\N	50.084963999999999	Белгородская область, Ровеньский район, село Свистовка, здание Свистовского Дома культуры		0101000020E61000006BBA9EE8BA7A43402EABB019E00A4940
23649	1	1	474	49028	\N	\N	50.072974000000002	село Саловка, Помещение сельского клуба		0101000020E61000006552431B806B4340AABA473657094940
24127	1	1	474	20522	33396	\N	49.910938999999999	Белгородская область, Ровеньский район, поселок Ровеньки, Шевченко, 8		0101000020E61000008FDFDBF46771434052D32EA699F44840
24132	1	1	474	20522	33545	\N	49.910938999999999	Белгородская область, Ровеньский район, поселок Ровеньки, Чапаева, 13		0101000020E61000008FDFDBF46771434052D32EA699F44840
24133	1	1	474	20522	33338	\N	49.920807201469103	Белгородская область, Ровеньский район, поселок Ровеньки, Пролетарская, 41	Россия, Белгородская область, Ровеньский район, поселок Ровеньки	0101000020E6100000466117450F724340C576F700DDF54840
24131	1	1	474	20522	33399	\N	49.910938999999999	Белгородская область, Ровеньский район, поселок Ровеньки, Московская, 29		0101000020E61000008FDFDBF46771434052D32EA699F44840
24126	1	1	474	20522	33219	\N	49.910938999999999	Белгородская область, Ровеньский район, поселок Ровеньки, Ленина, 61		0101000020E61000008FDFDBF46771434052D32EA699F44840
24129	1	1	474	20522	33397	\N	49.910938999999999	Белгородская область, Ровеньский район, поселок Ровеньки, Докучаева, 112		0101000020E61000008FDFDBF46771434052D32EA699F44840
24128	1	1	474	20522	33225	\N	49.923688752970897	Белгородская область, Ровеньский район, поселок Ровеньки, М.Горького, 29 А	Россия, Белгородская область, Ровеньский район, поселок Ровеньки	0101000020E6100000357D76C0757543406556EF703BF64840
24137	1	1	474	21087	\N	\N	50.061183999999997	Белгородская область, Ровеньский район, село Ржевка, здание Администрации Ржевского сельского поселения		0101000020E610000050E1085229884340EC8497E0D4074940
24111	1	1	474	19646	\N	\N	50.097175	Белгородская область, Ровеньский район, село Пристень, здание Пристеньского Дома культуры		0101000020E610000018946934B96E4340917EFB3A700C4940
23628	1	1	474	19646	\N	\N	50.097175	с. Пристень, здание Пристенского сельского Дома культуры		0101000020E610000018946934B96E4340917EFB3A700C4940
24124	1	1	474	20410	\N	\N	50.150284999999997	"Белгородская область, Ровеньский район, село Новоалександровка, здание правления колхоза ""Советская Россия"""		0101000020E61000008449F1F109734340280AF4893C134940
24113	1	1	474	19752	\N	\N	49.828068999999999	Белгородская область, Ровеньский район, село Нижняя Серебрянка, здание Нижнесеребрянского Дома культуры		0101000020E6100000D218ADA3AA7943406CEA3C2AFEE94840
24120	1	1	474	20121	\N	\N	50.034227999999999	Белгородская область, Ровеньский район, село Нагорье, здание Нагорьевской средней школы		0101000020E61000000805A568E5884340C24D469561044940
24118	1	1	474	20029	\N	\N	49.978133	Белгородская область, Ровеньский район, село Нагольное, здание Наголенского Дома культуры		0101000020E6100000D1B1834A5C7F4340B6114F7633FD4840
24142	1	1	474	21328	\N	\N	50.249606	Белгородская область, Ровеньский район, село Масловка, здание Масловского Дома культуры	Россия, Белгородская область, Ровеньский район, поселок Масловка	0101000020E61000004D13B69F8C8943405471E316F31F4940
24139	1	1	474	21180	\N	\N	50.106471999999997	Белгородская область, Ровеньский район, село Мартынцы, здание Мартынцовского сельского клуба	Россия, Белгородская область, Ровеньский район, поселок Мартынцы	0101000020E6100000FA9AE5B2D18B434048F8DEDFA00D4940
24115	1	1	474	19862	\N	\N	49.922545999999997	Белгородская область, Ровеньский район, село Лозовое, здание Администрации Лозовского сельского поселения		0101000020E610000089D4B48B699243401E87C1FC15F64840
24114	1	1	474	19791	\N	\N	49.966824000000003	Белгородская область, Ровеньский район, село Лозная, здание администрации Лознянского сельского поселения		0101000020E6100000BFD6A546E8614340747E8AE3C0FB4840
24134	1	1	474	20950	\N	\N	50.002782000000003	Белгородская область, Ровеньский район, хутор Лихолобов, здание Лихолобовской начальной школы		0101000020E6100000EB025E66D86E43403D821B295B004940
24116	1	1	474	19913	\N	\N	50.275041000000002	Белгородская область, Ровеньский район, село Ладомировка, здание Ладомировского Дома культуры		0101000020E610000043E21E4B1F7843409207228B34234940
24138	1	1	474	21132	\N	\N	50.152577000000001	Белгородская область, Ровеньский район, село Копанки, здание Копанского сельского клуба		0101000020E6100000F3FFAA23478C4340978FA4A487134940
24119	1	1	474	20094	\N	\N	49.977322000000001	Белгородская область, Ровеньский район, село Клименково, здание Клименковского сельского клуба	Россия, Белгородская область, Ровеньский район, поселок Клименково	0101000020E6100000BF9A030473864340A6D425E318FD4840
24125	1	1	474	20438	\N	\N	50.186815000000003	Белгородская область, Ровеньский район, село Калиниченково, здание Калиниченковсой начальной школы		0101000020E6100000D789CBF10A7E43407DB3CD8DE9174940
24135	1	1	474	21001	\N	\N	49.897984000000001	Белгородская область, Ровеньский район, село Ивановка, здание Ивановского сельского клуба	Россия, Белгородская область, Ровеньский район, поселок Ивановка	0101000020E6100000CA17B49080894340672AC423F1F24840
23781	1	1	522	3452	33736	\N	51.276974000000003	село Осколец, Центральная, 9		0101000020E6100000DC9BDF30D1B24240D1EB4FE273A34940
24117	1	1	474	19928	\N	\N	50.220146	Белгородская область, Ровеньский район, село Жабское, здание Жабского Дома культуры		0101000020E610000052B7B3AF3C6E4340302C7FBE2D1C4940
24121	1	1	474	20193	\N	\N	50.090598999999997	Белгородская область, Ровеньский район, село Еремовка, здание Еремовского сельского клуба		0101000020E61000005A2BDA1CE794434070067FBF980B4940
24122	1	1	474	20247	\N	\N	50.011251999999999	Белгородская область, Ровеньский район, село Всесвятка, здание Всесвятского сельского клуба		0101000020E6100000429605137F8C4340DE019EB470014940
24112	1	1	474	19691	\N	\N	49.844627000000003	Белгородская область, Ровеньский район, село Верхняя Серебрянка, Здание администрации Верхнесеребрянского сельского поселения		0101000020E61000000B0E2F8848854340C828CFBC1CEC4840
24123	1	1	474	20331	\N	\N	49.992792999999999	Белгородская область, Ровеньский район, село Барсучье, здание Барсучанской начальной школы	Россия, Белгородская область, Ровеньский район, поселок Барсучье	0101000020E610000057056A31789E43404F594DD713FF4840
24110	1	1	474	19598	\N	\N	50.049166	Белгородская область, Ровеньский район, село Айдар, здание Айдарского Дома культуры		0101000020E6100000C5909C4CDC7243409E094D124B064940
24109	1	1	1531	54005	33567	\N	50.843307000000003	Белгородская область, Ракитянский район, село Центральное, Совхозная, 5		0101000020E6100000F2ECF2AD0FED414073BED87BF16B4940
24098	1	1	1531	18977	33695	\N	50.717669000000001	Белгородская область, Ракитянский район, село Трефиловка, Почтовая, 3		0101000020E6100000A9A10DC006F24140302DEA93DC5B4940
24251	1	1	1531	18873	33296	\N	50.727859000000002	с. Солдатское, Центральная, 12, управление сельской территории		0101000020E610000096766A2E37E44140B58CD47B2A5D4940
24096	1	1	1531	18873	33664	\N	50.727859000000002	Белгородская область, Ракитянский район, село Солдатское, Третьяковка, 23		0101000020E610000096766A2E37E44140B58CD47B2A5D4940
24092	1	1	1531	18639	\N	\N	50.876949000000003	Белгородская область, Ракитянский район, село Святославка, Шоссейная, 27	Россия, Белгородская область, Ракитянский район, поселок Святославка	0101000020E61000008F19A88C7FD7414045A165DD3F704940
24095	1	1	1531	18790	33696	\N	50.670150999999997	Белгородская область, Ракитянский район, село Русская Березовка, Новостроевка, 13		0101000020E6100000DA01D71533DE4140DB300A82C7554940
24107	1	1	1531	19262	33218	\N	50.839115	Белгородская область, поселок Ракитное, Федутенко, 2		0101000020E61000007F50172994ED4140A14ACD1E686B4940
24105	1	1	1531	19262	33394	\N	50.834337836003698	Белгородская область, поселок Ракитное, Пролетарская, 20Б	Россия, Белгородская область, Ракитянский район, поселок Ракитное	0101000020E61000001558005306EA4140B0E76B96CB6A4940
24106	1	1	1531	19262	33285	\N	50.844389140831602	Белгородская область, поселок Ракитное, Новосадовая, 31	Россия, Белгородская область, Ракитянский район, поселок Ракитное	0101000020E61000004A9BAA7B64EB4140130D52F0146C4940
24104	1	1	1531	19262	33286	\N	50.839115	Белгородская область, поселок Ракитное, Коммунаров, 30А	Россия, Белгородская область, Ракитянский район, поселок Ракитное	0101000020E61000007F50172994ED4140A14ACD1E686B4940
24085	1	1	1531	18269	33749	\N	50.906810999999998	Белгородская область, Ракитянский район, село Псковское, Центральная, 6А		0101000020E610000012178046E9FA41409753026212744940
24102	1	1	1531	19092	33424	\N	50.793775701742497	Белгородская область, Ракитянский район, поселок Пролетарский, Пролетарская, 32	Россия, Белгородская область, Ракитянский район, поселок Пролетарский	0101000020E610000082E673EE76E34140C32CB4739A654940
24101	1	1	1531	19092	33281	\N	50.794384999999998	Белгородская область, Ракитянский район, поселок Пролетарский, Почтовый, 4А		0101000020E610000055A3570394E241406BB75D68AE654940
24100	1	1	1531	19092	33511	\N	50.787398259637598	Белгородская область, Ракитянский район, поселок Пролетарский, Ватутина, 2А	Россия, Белгородская область, Ракитянский район, поселок Пролетарский	0101000020E6100000CF2EDFFAB0E24140C9772975C9644940
24093	1	1	1531	18705	\N	\N	51.002797000000001	Белгородская область, Ракитянский район, село Нижние Пены, Курочкина, 1А	Россия, Белгородская область, Ракитянский район, поселок Нижние Пены	0101000020E61000003A58FFE730F9414072C3EFA65B804940
24086	1	1	1531	18344	33874	\N	50.912894000000001	Белгородская область, Ракитянский район, село Меловое, Центральная, 20		0101000020E6100000C40B2252D3084240795BE9B5D9744940
24099	1	1	1531	19006	33834	\N	50.724404	Белгородская область, Ракитянский район, село Лаптевка, Центральная, 131		0101000020E610000055BE672442EB4140B98B3045B95C4940
24103	1	1	1531	19248	\N	\N	50.808064999999999	Белгородская область, Ракитянский район, село Криничное, здание администрации производства		0101000020E6100000960854FF20E64140680586AC6E674940
24091	1	1	1531	18603	33564	\N	50.901130999999999	Белгородская область, Ракитянский район, село Илек-Кошары, Советская, 25		0101000020E6100000205D6C5A29CE4140B534B74258734940
24090	1	1	1531	18536	\N	\N	50.884580999999997	Белгородская область, Ракитянский район, село Зинаидино, Школьная, 3	Россия, Белгородская область, Ракитянский район, поселок Зинаидино	0101000020E6100000E0D91EBDE1F24140DCD440F339714940
24089	1	1	1531	18450	33884	\N	50.778230000000001	Белгородская область, Ракитянский район, село Дмитриевка, Шатилова, 9		0101000020E6100000F0879FFF1E0042400F62670A9D634940
24088	1	1	1531	18450	33591	\N	50.778230000000001	Белгородская область, Ракитянский район, село Дмитриевка, Выгон, 78		0101000020E6100000F0879FFF1E0042400F62670A9D634940
24094	1	1	1531	18776	33665	\N	50.964244000000001	Белгородская область, Ракитянский район, село Вышние Пены, Центральная, 13		0101000020E6100000EF004F5AB80042409FAEEE586C7B4940
24084	1	1	1531	18218	33590	\N	50.929763000000001	Белгородская область, Ракитянский район, село Венгеровка, Центральная, 47А		0101000020E6100000F9BA0CFFE9024240F303577902774940
24097	1	1	1531	18896	33754	\N	50.735391	Белгородская область, Ракитянский район, село Введенская Готня, Гордеевка, 2		0101000020E6100000137F1475E6F24140E962D34A215E4940
24108	1	1	1531	19493	33883	\N	50.839768999999997	Белгородская область, Ракитянский район, село Васильевка, Ленина, 1В		0101000020E6100000412C9B3924FF4140E998F38C7D6B4940
24082	1	1	1531	18123	33876	\N	50.879063000000002	Белгородская область, Ракитянский район, село Борисполье, Молодежная, 2		0101000020E6100000E7012CF2EBE14140D40FEA2285704940
24083	1	1	1531	18182	\N	\N	50.935741	Белгородская область, Ракитянский район, село Бобрава, Центральная, 58	Россия, Белгородская область, Ракитянский район, поселок Бобрава	0101000020E61000002A1C412AC5E241405F43705CC6774940
24087	1	1	1531	18360	33824	\N	50.885905000000001	Белгородская область, Ракитянский район, село Александровка, Центральная, 32		0101000020E61000000ED8D5E429034240732EC55565714940
24081	1	1	627	18098	\N	\N	50.870702000000001	Белгородская область, Прохоровский район, село Шахово, Здание СДК		0101000020E61000007BFA08FCE15D4240E947C329736F4940
24080	1	1	627	18026	\N	\N	51.009529999999998	Белгородская область, Прохоровский район, село Холодное, Здание СДК		0101000020E6100000AED3484BE58D42405A2A6F4738814940
24034	1	1	627	15756	\N	\N	50.871498000000003	Белгородская область, Прохоровский район, село Тетеревино, Здание сельского ДК	Россия, Белгородская область, Прохоровский район, поселок Тетеревино	0101000020E6100000E3AAB2EF8A4E4240C443183F8D6F4940
95183	1	1	627	53580	\N	\N	51.086443000000003	Белгородская область, Прохоровский район, хутор Средняя Ольшанка, помещение ФАПа		0101000020E61000006170CD1DFD574240ECFB7090108B4940
23978	1	1	627	4051	33543	\N	51.151907999999999	село Сергиевка, Центральная, 2	Россия, Белгородская область, Прохоровский район, поселок Сергиевка	0101000020E61000004B732B84D57242401900AAB871934940
23793	1	1	627	4051	33682	\N	51.151907999999999	село Сергиевка, Белгородская, 129		0101000020E61000004B732B84D57242401900AAB871934940
24042	1	1	627	16142	\N	\N	51.152161999999997	Белгородская область, Прохоровский район, село Сеймица, Здание библиотеки	Россия, Белгородская область, Прохоровский район, поселок Сеймица	0101000020E61000006EA46C91B46F4240D3D85E0B7A934940
24061	1	1	627	17067	\N	\N	51.042462	Белгородская область, Прохоровский район, село Сагайдачное, Здание СДК		0101000020E610000046274BADF775424050A912656F854940
24077	1	1	627	17873	\N	\N	50.874316999999998	Белгородская область, Прохоровский район, село Ржавец, Здание СДК		0101000020E6100000DD257156446B42401DAB949EE96F4940
24075	1	1	627	17728	\N	\N	51.096235999999998	Белгородская область, Прохоровский район, село Радьковка, Здание СДК	Россия, Белгородская область, Прохоровский район, поселок Радьковка	0101000020E6100000624D6551D87D424053591476518C4940
24074	1	1	627	17728	\N	\N	51.096235999999998	"Белгородская область, Прохоровский район, село Радьковка, Здание конторы ИП ""Маматов"""		0101000020E6100000624D6551D87D424053591476518C4940
24066	1	1	627	17324	33234	\N	51.031756446906698	Белгородская область, п.Прохоровка, переулок 1-й Советский, 1	Россия, Белгородская область, Прохоровский район, поселок Прохоровка	0101000020E610000055A52DAEF15D4240D4B9A29410844940
24071	1	1	627	17324	33239	\N	51.034719000000003	Белгородская область, п.Прохоровка, Советская, 256А		0101000020E610000002F4FBFECD5D424061C614AC71844940
24070	1	1	627	17324	33239	\N	51.034719000000003	Белгородская область, п.Прохоровка, Советская, 178		0101000020E610000002F4FBFECD5D424061C614AC71844940
24067	1	1	627	17324	33239	\N	51.034719000000003	Белгородская область, п.Прохоровка, Советская, 130		0101000020E610000002F4FBFECD5D424061C614AC71844940
24069	1	1	627	17324	33512	\N	51.034719000000003	Белгородская область, п.Прохоровка, Первомайская, 1		0101000020E610000002F4FBFECD5D424061C614AC71844940
24072	1	1	627	17324	33486	\N	51.040019024248501	Белгородская область, п.Прохоровка, Парковая, 48	Россия, Белгородская область, Прохоровский район, поселок Прохоровка	0101000020E61000002F17F19D985F4240FC1BB4571F854940
24068	1	1	627	17324	33454	\N	51.034719000000003	Белгородская область, п.Прохоровка, Мичурина, 38		0101000020E610000002F4FBFECD5D424061C614AC71844940
24065	1	1	627	17289	\N	\N	51.030963999999997	Белгородская область, Прохоровский район, село Призначное, Здание СДК		0101000020E610000044DFDDCA126D42403AADDBA0F6834940
24059	1	1	627	16977	\N	\N	51.040512999999997	Белгородская область, Прохоровский район, село Прелестное, Здание СДК		0101000020E6100000D40AD3F71A5042400B08AD872F854940
24038	1	1	627	15950	\N	\N	51.024290999999998	Белгородская область, Прохоровский район, поселок Политотдельский, Здание Досугового центра		0101000020E6100000213EB0E3BF544240274BADF71B834940
23482	1	1	627	15950	33602	\N	51.023316357540999	Белгородская область, Белгородский район, поселок Политотдельский, Центральная, 1А	Россия, Белгородская область, Прохоровский район, поселок Политотдельский	0101000020E6100000AFEDED96E45442409DBCC804FC824940
24057	1	1	627	16878	\N	\N	50.974040000000002	Белгородская область, Прохоровский район, село Подольхи, Здание СДК		0101000020E61000006682E15CC3764240787FBC57AD7C4940
24079	1	1	627	17995	\N	\N	50.997740999999998	Белгородская область, Прохоровский район, село Плющины, Здание Плющинского ФАПа		0101000020E6100000F5DBD781738842406D7022FAB57F4940
24053	1	1	627	16681	\N	\N	50.921616	Белгородская область, Прохоровский район, село Плота, Здание СДК		0101000020E610000097AAB4C53560424034BC5983F7754940
24051	1	1	627	16571	\N	\N	51.135702000000002	Белгородская область, Прохоровский район, село Петровка, Здание СДК		0101000020E610000084F57F0EF37342403B00E2AE5E914940
24073	1	1	627	17704	\N	\N	51.108621999999997	Белгородская область, Прохоровский район, хутор Нижняя Гусынка, Здание магазина райпо		0101000020E61000003677F4BF5C71424024D06053E78D4940
24048	1	1	627	16454	\N	\N	51.082420999999997	Белгородская область, Прохоровский район, село Масловка, Здание сельского клуба		0101000020E61000005F29CB10C78E424076C075C58C8A4940
24050	1	1	627	54034	\N	\N	50.968631878732403	Белгородская область, Прохоровский район, село Малые Маячки, Здание СДК	Россия, Белгородская область, Прохоровский район, поселок Малые Маяки	0101000020E610000039D55A9885404240F6ED2422FC7B4940
24052	1	1	627	16655	\N	\N	50.926442000000002	Белгородская область, Прохоровский район, село Малояблоново, Здание медпункта		0101000020E610000050A8A78FC05B424007D2C5A695764940
24049	1	1	627	16465	\N	\N	50.875135	Белгородская область, Прохоровский район, село Лучки, Здание Лучковской СОШ	Россия, Белгородская область, Прохоровский район, поселок Лучки	0101000020E610000012DBDD0374454240E04A766C04704940
24046	1	1	627	16337	\N	\N	51.039602000000002	Белгородская область, Прохоровский район, село Кривые Балки, Здание сельского клуба		0101000020E610000042E90B21E7814240986DA7AD11854940
24047	1	1	627	16375	\N	\N	51.070039000000001	Белгородская область, Прохоровский район, село Кривошеевка, Здание СДК		0101000020E61000008C31B08EE3874240E738B709F7884940
24064	1	1	627	17221	\N	\N	51.008000000000003	Белгородская область, Прохоровский район, село Красное, Здание медпункта		0101000020E6100000E065868DB26642401B2FDD2406814940
24045	1	1	627	16256	\N	\N	51.090206000000002	Белгородская область, Прохоровский район, село Кондровка, Здание сельского клуба	Россия, Белгородская область, Прохоровский район, поселок Кондровка	0101000020E6100000861C5BCF1084424095F3C5DE8B8B4940
23473	1	1	627	20833	33446	\N	50.985087	Белгородская область, Белгородский район, поселок Комсомольский, Гайдара, 1		0101000020E610000029B000A60C4E42407D5BB054177E4940
24044	1	1	627	16231	\N	\N	50.941161000000001	Белгородская область, Прохоровский район, село Коломыцево, Здание Коломыцевского СДК	Россия, Белгородская область, Прохоровский район, поселок Коломыцево	0101000020E6100000E0D8B3E7328D4240A5A2B1F677784940
24060	1	1	627	17057	\N	\N	51.100563000000001	Белгородская область, Прохоровский район, село Карташевка, Здание СДК		0101000020E6100000FD12F1D6F94742400518963FDF8C4940
24035	1	1	627	54035	\N	\N	50.922376717471103	Белгородская область, Прохоровский район, хутор Калинин, Здание медпункта	Россия, Белгородская область, Прохоровский район, поселок Калинин	0101000020E6100000302FC03E3A4B424092CA147310764940
24076	1	1	627	54026	\N	\N	50.883005263180202	Белгородская область, Прохоровский район, село Казачье, Здание сельского клуба	Россия, Белгородская область, Прохоровский район, поселок Редкодуб	0101000020E610000041D5E8D5006B42402C9ACE4E06714940
24041	1	1	627	16069	\N	\N	51.123384999999999	Белгородская область, Прохоровский район, село Журавка, Здание Журавского СДК		0101000020E6100000DEC7D11C5973424092E86514CB8F4940
24043	1	1	627	16154	\N	\N	50.962105000000001	Белгородская область, Прохоровский район, село Донец, Здание Донецкого СДК		0101000020E6100000144031B264844240B728B341267B4940
24063	1	1	627	17188	\N	\N	51.046726	Белгородская область, Прохоровский район, село Гусек-Погореловка, Здание библиотеки		0101000020E610000087A8C29FE16F4240BBEF181EFB854940
24055	1	1	627	16783	\N	\N	50.915585999999998	Белгородская область, Прохоровский район, село Гнездиловка, Здание СДК		0101000020E6100000E38E37F92D6E424075560BEC31754940
24039	1	1	627	15966	\N	\N	51.157128	Белгородская область, Прохоровский район, село Вязовое, Здание Вязовского СДК		0101000020E61000005B61FA5E4380424098A432C51C944940
24058	1	1	627	54055	\N	\N	51.064194384131198	Белгородская область, Прохоровский район, хутор Веселый, Здание сельского клуба	Россия, Белгородская область, Прохоровский район, поселок Веселый	0101000020E6100000CB129D6516454240BA4C4D8237884940
24040	1	1	627	16050	\N	\N	51.114412000000002	Белгородская область, Прохоровский район, хутор Верхняя Гусынка, Здание медпункта	Россия, Белгородская область, Прохоровский район, поселок Верхняя Гусынка	0101000020E6100000279F1EDB327042408E226B0DA58E4940
24054	1	1	627	52724	\N	\N	50.94014	Белгородская область, Прохоровский район, село Большое, Здание СДК		0101000020E610000019C5724BAB7D4240AAD4EC8156784940
24062	1	1	627	17155	\N	\N	51.054442999999999	Белгородская область, Прохоровский район, хутор Бехтеевка, Здание медпункта	Россия, Белгородская область, Прохоровский район, поселок Бехтеевка	0101000020E61000007BC1A739796D4240813FFCFCF7864940
24036	1	1	627	15848	\N	\N	51.077632999999999	Белгородская область, Прохоровский район, село Береговое, Здание администрации с/п	Россия, Белгородская область, Прохоровский район, поселок Береговое 1-е	0101000020E61000005471E316F3574240910BCEE0EF894940
24033	1	1	627	15682	\N	\N	50.943375000000003	Белгородская область, Прохоровский район, село Беленихино, Здание Беленихинского ДК	Россия, Белгородская область, Прохоровский район, поселок Беленихино	0101000020E610000006836BEEE84F4240986E1283C0784940
24078	1	1	627	17924	\N	\N	51.033200999999998	Белгородская область, Прохоровский район, село Андреевка, Здание Андреевской ООШ		0101000020E61000004F0647C9AB8F4240E5982CEE3F844940
24029	1	1	1288	15500	\N	\N	50.657680999999997	Белгородская область, Новооскольский район, село Ярское, сельский Дом культуры		0101000020E6100000F73C7FDAA8C84240AC1919E42E544940
24027	1	1	1288	15417	\N	\N	50.717742999999999	Белгородская область, Новооскольский район, село Яковлевка, сельский Дом культуры		0101000020E6100000A180ED60C4FC42406AF7AB00DF5B4940
23667	1	1	1875	29645	33393	\N	50.485398000000004	поселок Волоконовка, 60 лет Октября, 147		0101000020E61000000E130D52F0EA42409CC58B85213E4940
24026	1	1	1288	15352	\N	\N	50.757179999999998	Белгородская область, Новооскольский район, село Шараповка, сельский Дом культуры	Россия, Белгородская область, Новооскольский район, поселок Шараповка	0101000020E6100000B6696CAF05034340B7973446EB604940
24025	1	1	1288	15325	\N	\N	50.842027000000002	Белгородская область, Новооскольский район, село Тростенец, сельский Дом культуры		0101000020E61000001268B0A9F3D24240ACAC6D8AC76B4940
24024	1	1	1288	15267	\N	\N	50.849983999999999	Белгородская область, Новооскольский район, село Старая Безгинка, сельский Дом культуры		0101000020E61000009850C1E105154340C70F9546CC6C4940
24022	1	1	1288	15185	\N	\N	50.784261000000001	Белгородская область, Новооскольский район, село Солонец-Поляна, сельский клуб	Россия, Белгородская область, Новооскольский район, поселок Солонец Поляна	0101000020E610000049A12C7C7DDD42409E4319AA62644940
23997	1	1	1288	13999	\N	\N	50.657868999999998	Белгородская область, Новооскольский район, село Слоновка, сельский Дом культуры		0101000020E61000003CA3AD4A22E14240AF06280D35544940
24005	1	1	1288	54064	\N	\N	50.590079000000003	Белгородская область, Новооскольский район, хутор Скрынниково, сельский клуб	Россия, Белгородская область, Новооскольский район, поселок Скрынников	0101000020E61000000FF27A3029CC424038876BB5874B4940
24014	1	1	1288	47273	\N	\N	50.683176000000003	село Серебрянка, сельский клуб		0101000020E61000004F57772CB6F54240C0B4A84F72574940
24012	1	1	1288	14690	\N	\N	50.859014000000002	хутор Севальный, сельский клуб		0101000020E61000000B5F5FEB520143403067B62BF46D4940
24016	1	1	1288	14880	\N	\N	50.752006000000002	Белгородская область, Новооскольский район, поселок Прибрежный, сельский Дом культуры		0101000020E6100000A036AAD381EC4240A9328CBB41604940
24000	1	1	1288	14136	\N	\N	50.727345999999997	Белгородская область, Новооскольский район, пос. Полевой, сельский клуб		0101000020E6100000D74E948444C242402E7079AC195D4940
24009	1	1	1288	14543	\N	\N	50.774071999999997	"село Покровомихайловка, адм. здание мехотряда ООО ""Михайловское"""		0101000020E6100000F032C34659C74240E95F92CA14634940
24010	1	1	1288	14606	\N	\N	50.792523000000003	село Подвислое, медицинский пункт		0101000020E6100000B75D68AED3D04240F629C76471654940
23677	1	1	1288	53997	\N	\N	50.822088000000001	село Погромец, Здание сельского Дома культуры	Россия, Белгородская область, Новооскольский район, поселок Погромец	0101000020E6100000A7CD380D51ED42408F37F92D3A694940
24017	1	1	1288	14936	\N	\N	50.707414	Белгородская область, Новооскольский район, село Песчанка, сельский клуб		0101000020E6100000E694809884E74240C45DBD8A8C5A4940
24031	1	1	1288	15592	\N	\N	50.651941999999998	Белгородская область, Новооскольский район, село Остаповка, сельская библиотека		0101000020E610000080F0A1444BC24240C571E0D572534940
24020	1	1	1288	15061	\N	\N	50.845388999999997	Белгородская область, Новооскольский район, село Оскольское, сельский Дом культуры		0101000020E6100000C9CC052E8FE74240F6B2EDB4356C4940
23996	1	1	1288	13922	\N	\N	50.729962999999998	Белгородская область, Новооскольский район, село Ольховатка, сельский Дом культуры		0101000020E61000002B3410CB66E042402025766D6F5D4940
23809	1	1	1288	13922	33744	\N	50.731378724432297	село Ольховатка, Александра Адонина, 10	Россия, Белгородская область, Новооскольский район, поселок Ольховатка	0101000020E61000008EEBDFF599E1424097FDBAD39D5D4940
23987	1	1	1288	13498	33509	\N	50.762729	Белгородская область, город Новый Оскол, площадь Центральная, 6	Россия, Белгородская область, Новооскольский район, Новый Оскол	0101000020E6100000B8CEBF5DF6EF4240FB5A971AA1614940
23991	1	1	1288	13498	33362	\N	50.7574594871082	Белгородская область, город Новый Оскол, Сушкова, 28	Россия, Белгородская область, Новооскольский район, Новый Оскол	0101000020E6100000C45C52B5DDF04240CA87A06AF4604940
23988	1	1	1288	13498	33448	\N	50.759650779257903	Белгородская область, город Новый Оскол, Оскольская, 7	Россия, Белгородская область, Новооскольский район, Новый Оскол	0101000020E6100000D788601C5CEE4240D5AF743E3C614940
23994	1	1	1288	13498	33315	\N	50.773469875169297	Белгородская область, город Новый Оскол, Ливенская, 94	Россия, Белгородская область, Новооскольский район, Новый Оскол	0101000020E610000024B6BB07E8EE4240F437A11001634940
23992	1	1	1288	13498	33315	\N	50.779653458793	Белгородская область, город Новый Оскол, Ливенская, 132А		0101000020E610000021787C7BD7EE4240399D64ABCB634940
23989	1	1	1288	13498	33389	\N	50.7496734409361	Белгородская область, город Новый Оскол, Кооперативная, 12	Россия, Белгородская область, Новооскольский район, Новый Оскол	0101000020E610000068B0A9F3A8F04240DCD8EC48F55F4940
23993	1	1	1288	13498	33489	\N	50.775571977660803	Белгородская область, город Новый Оскол, Дорожная, 1/1	Россия, Белгородская область, Новооскольский район, Новый Оскол	0101000020E61000007B2E5393E0EF4240BED87BF145634940
23990	1	1	1288	13498	33267	\N	50.762729	Белгородская область, город Новый Оскол, Авиационная, 1		0101000020E6100000B8CEBF5DF6EF4240FB5A971AA1614940
24019	1	1	1288	15026	\N	\N	50.888019	Белгородская область, Новооскольский район, село Новая Безгинка, сельский Дом культуры		0101000020E610000072F8A413090E4340029D499BAA714940
24015	1	1	1288	14856	\N	\N	50.732568999999998	Белгородская область, Новооскольский район, село Ниновка, сельский клуб		0101000020E6100000E603029D49E942401E882CD2C45D4940
24004	1	1	1288	54049	\N	\N	50.600010175725401	Белгородская область, Новооскольский район, село Немцево, сельский Дом культуры	Россия, Белгородская область, Новооскольский район, поселок Немцев	0101000020E6100000EBA7FFACF9D74240F0A2AF20CD4C4940
24007	1	1	1288	14448	\N	\N	50.816060999999998	Белгородская область, Новооскольский район, село Малое Городище, сельский клуб		0101000020E610000090F5D4EAABC342404145D5AF74684940
23595	1	1	1288	52944	\N	\N	50.827345000000001	х. Леоновка, здание Леоновского сельского клуба	Россия, Белгородская область, Новооскольский район, поселок Леоновка	0101000020E6100000B6BE4868CBE942402BC1E270E6694940
24028	1	1	1288	15485	\N	\N	50.67998	Белгородская область, Новооскольский район, село Крюк, сельский клуб	Россия, Белгородская область, Новооскольский район, поселок Крюк	0101000020E610000016342DB13206434090F7AA9509574940
24018	1	1	1288	54045	\N	\N	50.697955999999998	Белгородская область, Новооскольский район, село Косицино, сельский клуб	Россия, Белгородская область, Новооскольский район, поселок Косицыно	0101000020E610000039D384ED27F142400306499F56594940
24023	1	1	1288	15195	\N	\N	50.823008999999999	Белгородская область, Новооскольский район, село Киселевка, сельский клуб	Россия, Белгородская область, Новооскольский район, поселок Киселевка	0101000020E610000012BEF73768D9424026A8E15B58694940
24003	1	1	1288	54036	\N	\N	50.743377000000002	Белгородская область, Новооскольский район, село Гринево, сельский Дом культуры		0101000020E6100000894160E5D0EE42409FCC3FFA265F4940
24021	1	1	1288	15125	\N	\N	50.823008999999999	Белгородская область, Новооскольский район, село Голубино, сельский Дом культуры		0101000020E61000008F52094FE8E3424026A8E15B58694940
24011	1	1	1288	47225	\N	\N	50.836072000000001	село Глинное, сельский Дом культуры		0101000020E6100000E1B20A9B01FA4240F88C4468046B4940
24008	1	1	1288	14506	\N	\N	50.771292000000003	село Великомихайловка, сельский Дом культуры		0101000020E6100000828E56B5A4CB42404ED53DB2B9624940
24006	1	1	1288	54016	\N	\N	50.826735999999997	Белгородская область, Новооскольский район, село Васильдол, сельский Дом культуры		0101000020E61000004E97C5C4E6C942408236397CD2694940
24032	1	1	1288	54042	\N	\N	50.701427120713298	Белгородская область, Новооскольский район, село Барсук, сельский Дом культуры	Россия, Белгородская область, Новооскольский район, поселок Борсук	0101000020E6100000C45E28603BC6424005C4245CC8594940
24002	1	1	1288	14209	\N	\N	50.848488000000003	Белгородская область, Новооскольский район, село Боровое, сельский Дом культуры		0101000020E61000008B6B7C26FB1F4340348639419B6C4940
24001	1	1	1288	14168	\N	\N	50.863613000000001	Белгородская область, Новооскольский район, село Большая Ивановка, сельский Дом культуры		0101000020E6100000A6643909A517434042B3EBDE8A6E4940
23999	1	1	1288	14073	\N	\N	50.732683000000002	Белгородская область, Новооскольский район, село Богородское, сельский Дом культуры		0101000020E61000001ADF1797AACE4240E7AA798EC85D4940
24030	1	1	1288	15578	\N	\N	50.631115000000001	Белгородская область, Новооскольский район, село Богдановка, сельский клуб	Россия, Белгородская область, Новооскольский район, поселок Богдановка	0101000020E6100000145AD6FD63C54240ED815660C8504940
23653	1	1	2913	34518	\N	\N	47.413290000000003	хутор Колесников, Помещение сельского Дома культуры	Россия, Ростовская область, Матвеево-Курганский район, хутор Колесников	0101000020E6100000F67F0EF3E52F4340C6E1CCAFE6B44740
23980	1	1	1134	13194	33750	\N	50.720196000000001	село Теребрено, Новостроевка, 38		0101000020E610000027DC2BF356C14140E25AED612F5C4940
23981	1	1	1134	46617	33880	\N	50.704937999999999	село Староселье, Подлесье, 4		0101000020E6100000A9DA6E826FBC414094DA8B683B5A4940
23977	1	1	1134	46532	33662	\N	50.865250000000003	село Репяховка, Садовая, 1		0101000020E6100000320395F1EFBD4140986E1283C06E4940
23979	1	1	1134	13140	\N	\N	50.742961000000001	поселок Отрадовский, здание сельского клуба досуга		0101000020E61000000F4757E9EED841400B9A9658195F4940
23984	1	1	1134	10482	33610	\N	50.801096925378097	поселок Красная Яруга, Центральная, 79А	Россия, Белгородская область, Краснояружский район, поселок Красная Яруга	0101000020E6100000E1B88C9B1AD441403CF6B3588A664940
23985	1	1	1134	10482	33314	\N	50.799629000000003	поселок Красная Яруга, Театральная, 1		0101000020E6100000E108522976D4414073F7393E5A664940
23982	1	1	1134	10482	33316	\N	50.799629000000003	поселок Красная Яруга, Мира, 1		0101000020E6100000E108522976D4414073F7393E5A664940
23922	1	1	1134	10482	33316	\N	50.799629000000003	поселок Красная Яруга, Мира, 31		0101000020E6100000E108522976D4414073F7393E5A664940
23986	1	1	1134	10482	33588	\N	50.799629000000003	поселок Красная Яруга, Крыловка, 8		0101000020E6100000E108522976D4414073F7393E5A664940
23983	1	1	1134	10482	33363	\N	50.799629000000003	поселок Красная Яруга, Парковая, 36		0101000020E6100000E108522976D4414073F7393E5A664940
23975	1	1	1134	46492	33864	\N	50.813392	село Колотоловка, Центральная, 36		0101000020E6100000F0880AD5CDB74140FD69A33A1D684940
23974	1	1	1134	12921	\N	\N	50.762079999999997	село Илек-Пеньковка, здание культурно-досугового центра		0101000020E61000004EECA17DACC64140C47762D68B614940
23973	1	1	1134	46438	33888	\N	50.945990999999999	село Демидовка, Школьная, 1		0101000020E61000002E56D4601AB24140B9A7AB3B16794940
23976	1	1	1134	54029	\N	\N	50.832926	хутор Вязовской, здание Хуторского СДК	Россия, Белгородская область, Краснояружский район, поселок Вязовское	0101000020E61000002F34D769A4CB41407AFEB4519D6A4940
23971	1	1	1134	46411	\N	\N	50.788240999999999	село Вязовое, Советская, 37	Россия, Белгородская область, Краснояружский район, поселок Вязовое	0101000020E6100000C4CC3E8F51C04140E42EC214E5644940
23936	1	1	468	11128	33861	\N	50.648172000000002	Белгородская область, Красногвардейский район, село Хуторцы, Горького, 9		0101000020E61000000D6E6B0BCF3943406A17D34CF7524940
23967	1	1	468	12614	33823	\N	50.832248999999997	Белгородская область, Красногвардейский район, село Уточка, Советская, 13		0101000020E6100000E564E2564128434079909E22876A4940
23970	1	1	468	12750	33777	\N	50.811166999999998	Белгородская область, Красногвардейский район, хутор Ураково, Садовая, 1		0101000020E610000023C0E95DBC2B4340164CFC51D4674940
23963	1	1	468	12398	33626	\N	50.680259999999997	Белгородская область, Красногвардейский район, село Стрелецкое, Победы, 16		0101000020E6100000A872DA53723C434073637AC212574940
10998	6	58	\N	3348	42759	\N	55.706898000000002	город Кыштым, ул. Ленина, 31		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
23925	1	1	468	10627	33622	\N	50.754278999999997	Белгородская область, Красногвардейский район, село Сорокино, пер. Первомайский, 1		0101000020E610000010ECF82F103E4340A087DA368C604940
24252	1	1	468	10627	33611	\N	50.754278999999997	с. Сорокино, Центральная, 8, сельский клуб		0101000020E610000010ECF82F103E4340A087DA368C604940
23955	1	1	468	12044	33624	\N	50.327441	Белгородская область, Красногвардейский район, село Самарино, Октябрьская, 58		0101000020E61000009548A297513243404D2F3196E9294940
23917	1	1	468	10235	33733	\N	50.642916999999997	Белгородская область, Красногвардейский район, село Садки, Лесная, 25		0101000020E6100000103CBEBD6B2843406E85B01A4B524940
23965	1	1	468	12500	33863	\N	50.720058999999999	Белгородская область, Красногвардейский район, село Репенка, Подлесная, 10		0101000020E61000004EB7EC10FF3043406118B0E42A5C4940
23934	1	1	468	11041	33574	\N	50.63156	Белгородская область, Красногвардейский район, село Раздорное, Школьная, 7 А		0101000020E6100000055262D7F61A43401BBB44F5D6504940
23923	1	1	468	10508	33878	\N	50.809198000000002	Белгородская область, Красногвардейский район, село Прудки, Коммунистическая, 1 В		0101000020E61000003A05F9D9C83F43408BFED0CC93674940
23966	1	1	468	12572	33746	\N	50.752980000000001	Белгородская область, Красногвардейский район, село Прилепы, Мира, 1		0101000020E61000005B971AA19F29434063450DA661604940
23943	1	1	468	11443	33701	\N	50.504444999999997	Белгородская область, Красногвардейский район, хутор Попасное, Гагарина, 23 А		0101000020E6100000BCE7C072843E4340BBD05CA791404940
23969	1	1	468	12700	33734	\N	50.825479000000001	Белгородская область, Красногвардейский район, село Плюхино, Заречная, 12		0101000020E6100000B612BA4BE22443407444BE4BA9694940
23921	1	1	468	10420	33781	\N	50.765588999999999	Белгородская область, Красногвардейский район, хутор Петров, Цветочная, 36 Б		0101000020E61000001AA4E029E4384340B39602D2FE614940
23959	1	1	468	12232	33577	\N	50.419901000000003	Белгородская область, Красногвардейский район, село Палатово, Набережная, 4		0101000020E61000008864C8B1F51443406347E350BF354940
23944	1	1	468	11496	33702	\N	50.436019999999999	Белгородская область, Красногвардейский район, село Палатовка-Вторая, Чапаева, 54		0101000020E61000006A6803B0013743407233DC80CF374940
23928	1	1	468	10776	33785	\N	50.681938000000002	Белгородская область, Красногвардейский район, село Остроухово, Октябрьская, 6 А		0101000020E610000070253B36021D434028F38FBE49574940
23957	1	1	468	12140	33703	\N	50.564824999999999	Белгородская область, Красногвардейский район, село Новохуторное, Молодежная, 69 Г		0101000020E610000040FCFCF7E01943404A7B832F4C484940
23932	1	1	468	10957	33745	\N	50.623384000000001	Белгородская область, Красногвардейский район, поселок Николаевский, Народная, 34		0101000020E61000000989B48D3F054340C26C020CCB4F4940
23954	1	1	468	11932	33531	\N	50.356875000000002	Белгородская область, Красногвардейский район, село Никитовка, Калинина, 23		0101000020E6100000A25EF0694E36434048E17A14AE2D4940
23953	1	1	468	11932	33392	\N	50.365662726878902	Белгородская область, Красногвардейский район, село Никитовка, 1 Мая, 15 А	Россия, Белгородская область, Красногвардейский район, поселок Никитовка	0101000020E6100000BEBD6BD097344340BA2D910BCE2E4940
23924	1	1	468	54060	33850	\N	50.769866976294601	Белгородская область, Красногвардейский район, село Нижняя Покровка, Мирная, 93 Б	Россия, Белгородская область, Красногвардейский район, поселок Верхняя Покровка	0101000020E61000001553E9279C3B434083A279008B624940
23964	1	1	468	12475	33822	\N	50.732899000000003	Белгородская область, Красногвардейский район, село Марьевка, Молодежная, 2		0101000020E610000087889B53C92E4340B4226AA2CF5D4940
23962	1	1	468	12380	33589	\N	50.661929000000001	Белгородская область, Красногвардейский район, село Малобыково, Пушкарная, 7		0101000020E61000008CF2CCCB613F434012A3E716BA544940
23951	1	1	468	11719	33558	\N	50.448324999999997	Белгородская область, Красногвардейский район, село Ливенка, Учительская, 1		0101000020E61000007522C15433234340567DAEB662394940
23949	1	1	468	11719	33195	\N	50.448324999999997	Белгородская область, Красногвардейский район, село Ливенка, Транспортная, 9		0101000020E61000007522C15433234340567DAEB662394940
23952	1	1	468	11719	33538	\N	50.448324999999997	Белгородская область, Красногвардейский район, село Ливенка, Советская, 62		0101000020E61000007522C15433234340567DAEB662394940
23950	1	1	468	11719	33538	\N	50.448324999999997	Белгородская область, Красногвардейский район, село Ливенка, Советская, 15		0101000020E61000007522C15433234340567DAEB662394940
23960	1	1	468	12270	33847	\N	50.468246999999998	Белгородская область, Красногвардейский район, село Лазареново, Московская, 2		0101000020E6100000CF126404541043409DB98784EF3B4940
23919	1	1	468	10296	33802	\N	50.390523000000002	Белгородская область, Красногвардейский район, село Кулешовка, Молодежная, 83		0101000020E6100000F0C4AC17432B4340FCAA5CA8FC314940
23933	1	1	468	10986	33820	\N	50.689692999999998	Белгородская область, Красногвардейский район, село Красное, Пролетарская, 79		0101000020E610000043739D465A144340DBA337DC47584940
23945	1	1	468	11521	33686	\N	50.544376999999997	Белгородская область, Красногвардейский район, село Коломыцево, Советская, 7		0101000020E61000001FF7ADD6892F4340E8D84125AE454940
23948	1	1	468	11710	33821	\N	50.555273999999997	Белгородская область, Красногвардейский район, хутор Ковалев, Пушкина, 4		0101000020E6100000045ABA826D284340D828EB3713474940
23942	1	1	468	11426	33776	\N	50.496968000000003	Белгородская область, Красногвардейский район, село Калиново, Мира, 49 А		0101000020E610000076E09C11A53743404B94BDA59C3F4940
23961	1	1	468	12324	33337	\N	50.693505000000002	Белгородская область, Красногвардейский район, село Казацкое, площадь Ленина, 31		0101000020E61000003A05F9D9C83F4340664E97C5C4584940
23897	1	1	396	9262	\N	\N	50.988987000000002	Белгородская область, Красненский район, село Свистовка, помещение сельского клуба		0101000020E6100000E6400FB56D604340A7954220977E4940
23940	1	1	468	11156	33608	\N	50.6291757805404	Белгородская область, Красногвардейский район, село Засосна, имени Чапаева, 67	Россия, Белгородская область, Красногвардейский район, поселок Засосна	0101000020E61000005E2EE23B31334340CCB6D3D688504940
23937	1	1	468	11156	33576	\N	50.628818000000003	Белгородская область, Красногвардейский район, село Засосна, Пролетарская, 53 Б		0101000020E6100000280D350A493243406D91B41B7D504940
23938	1	1	468	11156	33661	\N	50.628818000000003	Белгородская область, Красногвардейский район, село Засосна, имени Ленина, 111 А/1		0101000020E6100000280D350A493243406D91B41B7D504940
23939	1	1	468	11156	33507	\N	50.628818000000003	Белгородская область, Красногвардейский район, село Засосна, 60 лет Октября, 2 А		0101000020E6100000280D350A493243406D91B41B7D504940
23927	1	1	468	10692	33879	\N	50.698925000000003	Белгородская область, Красногвардейский район, село Завальское, Садовая, 99		0101000020E61000001570CFF3A71D4340ACADD85F76594940
23941	1	1	468	54041	33789	\N	50.580358800225198	Белгородская область, Красногвардейский район, хутор Ендовицкий, Народная, 47 В	Россия, Белгородская область, Красногвардейский район, поселок Ендовицкое	0101000020E6100000F581E49D433F43403A782634494A4940
23935	1	1	468	11070	33704	\N	50.625041000000003	Белгородская область, Красногвардейский район, село Гредякино, Трудовая, 105 А		0101000020E61000009A94826E2F1F43405FD4EE5701504940
23958	1	1	468	12162	33866	\N	50.581929000000002	Белгородская область, Красногвардейский район, село Горовое, Мира, 31 В		0101000020E6100000A5129ED0EB1F434008CC43A67C4A4940
23929	1	1	468	10807	33615	\N	50.628143999999999	Белгородская область, Красногвардейский район, село Веселое, Свободы, 102 А		0101000020E61000005837DE1D19134340DD96C80567504940
23930	1	1	468	10807	33660	\N	50.628143999999999	Белгородская область, Красногвардейский район, село Веселое, Мира, 186 А		0101000020E61000005837DE1D19134340DD96C80567504940
23931	1	1	468	10807	33726	\N	50.628143999999999	Белгородская область, Красногвардейский район, село Веселое, Куйбышева, 118 А		0101000020E61000005837DE1D19134340DD96C80567504940
23926	1	1	468	10667	33573	\N	50.728890999999997	Белгородская область, Красногвардейский район, село Верхососна, Центральная, 17		0101000020E61000000F48C2BE9D1E4340A3ACDF4C4C5D4940
23920	1	1	468	10395	33530	\N	50.783287000000001	Белгородская область, Красногвардейский район, село Верхняя Покровка, Советская, 148 А		0101000020E6100000A5A0DB4B1A394340E43098BF42644940
23918	1	1	468	10284	33609	\N	50.393985999999998	Белгородская область, Красногвардейский район, село Валуйчик, Черняховского, 6		0101000020E610000044C2F7FE062143407A8A1C226E324940
23947	1	1	468	11616	33778	\N	50.511221999999997	Белгородская область, Красногвардейский район, село Валуй, Железнодорожная, 4		0101000020E610000007B29E5A7D314340737FF5B86F414940
23968	1	1	468	54008	33587	\N	50.855562740142702	Белгородская область, Красногвардейский район, село Большебыково, Центральная, 36	Россия, Белгородская область, Красногвардейский район, поселок Большое Быково	0101000020E61000007B832F4CA63243407555A016836D4940
23916	1	1	468	9918	\N	\N	50.529411000000003	Белгородская область, г. Бирюч, Коммунистическая, 44 А	Россия, Белгородская область, Красногвардейский район, поселок Бирюч	0101000020E61000004703780B24364340439259BDC3434940
23582	1	1	468	9918	\N	\N	50.529411000000003	с. Бирюч, здание Бирючанского сельского Дома культуры		0101000020E61000004703780B24364340439259BDC3434940
23914	1	1	468	9918	33491	\N	50.528317126302397	Белгородская область, г. Бирюч, имени Ольминского, 24	Россия, Белгородская область, Красногвардейский район, поселок Бирюч	0101000020E61000005890662C9A364340DE7536E49F434940
23915	1	1	468	9918	33563	\N	50.529411000000003	Белгородская область, г. Бирюч, Ямская, 154	Россия, Белгородская область, Красногвардейский район, поселок Бирюч	0101000020E61000004703780B24364340439259BDC3434940
23911	1	1	468	9918	33282	\N	50.529411000000003	Белгородская область, г. Бирюч, Соборная площадь, 3	Россия, Белгородская область, Красногвардейский район, поселок Бирюч	0101000020E61000004703780B24364340439259BDC3434940
23946	1	1	468	9918	33862	\N	50.529411000000003	Белгородская область, Красногвардейский район, поселок Бирюч, Привокзальная, 8		0101000020E61000004703780B24364340439259BDC3434940
23956	1	1	468	12059	33787	\N	50.398339	Белгородская область, Красногвардейский район, село Арнаутово, Заречная, 56		0101000020E61000003080F0A14435434055DCB8C5FC324940
23906	1	1	396	9653	\N	\N	51.015236999999999	Булгородская область, Красненский район, село Широкое, помещение дома культуры		0101000020E61000002E1F49490F41434036583849F3814940
23909	1	1	396	9846	\N	\N	50.946109999999997	Белгородская область, Красненский район, село Черемухово, помещение Дома досуга		0101000020E6100000FEB8FDF2C93843409335EA211A794940
23908	1	1	396	9741	\N	\N	50.902773000000003	Белгородская область, Красненский район, село Хмелевое, помещение Дома культуры		0101000020E61000009B5775560B4643401D5BCF108E734940
23905	1	1	396	9618	\N	\N	51.015338	Белгородская область, Красненский район,село Флюговка, помещение сельского клуба		0101000020E61000006E1805C1E32743406A317898F6814940
23894	1	1	396	9121	\N	\N	50.863630000000001	Белгородская область, Красненский район, село Ураково, помещение Дома культуры		0101000020E6100000984EEB36A849434018EC866D8B6E4940
23904	1	1	396	9561	\N	\N	51.021174999999999	Белгородская область, Красненский район, село Староуколово, помещение Дома досуга		0101000020E610000068226C787A3B4340143FC6DCB5824940
23910	1	1	396	9850	\N	\N	50.945757999999998	Белгородская область, Красненский район, село Сетище, помещение Дома культуры		0101000020E6100000103D29931A52434016F71F990E794940
23792	1	1	522	4003	33854	\N	51.168576999999999	село Присынки, Светлая, 13		0101000020E610000005323B8BDEB34240CCED5EEE93954940
23907	1	1	396	9708	\N	\N	50.907902	Белгородская область, Красненский район, село Расховец, помещение Дома культуры	Россия, Белгородская область, Красненский район, поселок Расховец	0101000020E6100000A41820D1043C43408BFCFA2136744940
23896	1	1	396	9207	\N	\N	50.908287999999999	Белгородская область, Красненский район, село Польниково, помещение сельского клуба		0101000020E61000002A3927F6D05A4340B4ACFBC742744940
23902	1	1	396	9467	\N	\N	51.022047000000001	Белгородская область, Красненский район, село Новоуколово, помещение Дома культуры		0101000020E610000001FA7DFFE6374340CAFCA36FD2824940
23900	1	1	396	9362	\N	\N	50.952765999999997	Белгородская область, Красненский район,село Новосолдатка, помещение Дома досуга		0101000020E610000090696D1ADB3F4340D05E7D3CF4794940
23901	1	1	396	54006	\N	\N	50.907850743595503	Белгородская область, Красненский район, село Лесноуколово, помещение Дома культуры	Россия, Белгородская область, Красненский район, поселок Лесное-Уколово	0101000020E6100000C85BAE7E6C6A43400952297634744940
23898	1	1	396	9283	\N	\N	50.949793	Белгородская область, Красненский район, село Круглое, помещение Дома культуры		0101000020E61000009C4D470037474340207C28D192794940
23895	1	1	396	9156	\N	\N	50.932828999999998	Белгородская область, Красненский район, село Красное, помещение районного Дворца культуры		0101000020E6100000A4880CAB7857434054E1CFF066774940
23892	1	1	396	9018	\N	\N	50.875788999999997	Белгородская область, Красненский район, село Камышенка, помещение Дома досуга		0101000020E6100000A56950340F50434028999CDA19704940
23893	1	1	396	9076	\N	\N	50.844211999999999	Белгородская область, Красненский район, село Камызино, помещение Дома культуры		0101000020E610000055DB4DF04D4D4340047289230F6C4940
23903	1	1	396	9495	\N	\N	51.094991	Белгородская область, Красненский район, село Каменка, помещение сельского клуба		0101000020E6100000D8614CFA7B2F4340093543AA288C4940
23899	1	1	396	9342	\N	\N	50.937097000000001	Белгородская область, Красненский район, село Заломное, помещение Дома досуга		0101000020E61000001C2785798F494340011764CBF2774940
23891	1	1	396	8989	\N	\N	50.840907000000001	Белгородская область, Красненский район, село Готовье, помещение администрации готовского с/п		0101000020E61000009E98F562285543401EFD2FD7A26B4940
23889	1	1	396	8906	\N	\N	51.039687000000001	Белгородская область, Красненский район, село Горки, помещение Дома культуры		0101000020E61000009A081B9E5E5F4340C689AF7614854940
23888	1	1	396	52406	\N	\N	50.927050000000001	Белгородская область, Красненский район, село Большое, помещение  Дома культуры		0101000020E61000000C569C6A2D2C4340DFE00B93A9764940
23890	1	1	396	8918	\N	\N	51.031899000000003	Белгородская область, Красненский район, село Богословка, помещение сельского клуба		0101000020E6100000A0DD21C50069434037E3344415844940
23886	1	1	483	8747	33216	\N	50.855352000000003	Белгородская область, Корочанский район, село Яблоново, улица Центральная, дом 36		0101000020E610000061545227A0AD4240BB48A12C7C6D4940
23885	1	1	483	8722	33773	\N	50.716574000000001	Белгородская область, Корочанский район, село Шляхово, улица Административная, дом 35		0101000020E6100000EDB60BCD75684240FB9463B2B85B4940
23883	1	1	483	8626	33586	\N	50.680624999999999	Белгородская область, Корочанский район, село Шеино, улица Школьная, дом 29		0101000020E6100000D921FE614B71424085EB51B81E574940
23861	1	1	483	7573	33784	\N	50.868980000000001	Белгородская область, Корочанский район, село Хмелевое, улица Интернациональна, дом 8		0101000020E61000005C936E4BE4B84240657094BC3A6F4940
23882	1	1	483	8551	33799	\N	50.745930000000001	Белгородская область, Корочанский район, село Фощеватое, улица Центральная, дом 13		0101000020E61000002594BE1072A842407A8D5DA27A5F4940
23881	1	1	483	8541	33550	\N	50.718992	Белгородская область, Корочанский район, село Соколовка, улица Зеленая, дом 2		0101000020E6100000C3F5285C8FA04240F60A0BEE075C4940
23855	1	1	483	7295	33859	\N	50.754849	Белгородская область, Корочанский район, село Сетное, улица Центральная, дом 20		0101000020E6100000B058C345EE9542408B355CE49E604940
23871	1	1	483	8012	33774	\N	50.839587000000002	Белгородская область, Корочанский район, село Самойловка, улица Самойловская, дом 27		0101000020E61000009FE6E445268A4240C9923996776B4940
23879	1	1	483	8448	33659	\N	50.761955	Белгородская область, Корочанский район, село Проходное, улица Центральная, дом 90		0101000020E61000001C06F357C88C42400803CFBD87614940
23877	1	1	483	8334	33361	\N	50.871833000000002	Белгородская область, Корочанский район, село Поповка, улица Бельгия, дом 2		0101000020E6100000D38558FD119A42406B494739986F4940
23876	1	1	483	8251	33360	\N	50.811160999999998	Белгородская область, Корочанский район, село Погореловка, улица Шевченко, дом 40		0101000020E6100000B5C6A013429542403465A71FD4674940
23875	1	1	483	8251	33215	\N	50.811160999999998	Белгородская область, Корочанский район, село Погореловка, улица Центральная, дом16/А		0101000020E6100000B5C6A013429542403465A71FD4674940
23874	1	1	483	8165	33796	\N	50.910344000000002	Белгородская область, Корочанский район, село Плотавец, улица Центральная, дом 5		0101000020E610000083312251689B42400F0EF62686744940
23872	1	1	483	8090	33748	\N	50.726039999999998	Белгородская область, Корочанский район, село Плоское, улица Центральная, дом 80		0101000020E61000002A1C412AC58042403ECBF3E0EE5C4940
23866	1	1	483	7792	33860	\N	50.925369000000003	Белгородская область, Корочанский район, село Пестуново, улица Садовая, дом 3		0101000020E61000001D3A3DEFC6804240BADDCB7D72764940
23870	1	1	483	7996	33572	\N	50.834695000000004	Белгородская область, Корочанский район, село Новая Слободка, улица Сытник, дом 28		0101000020E6100000F5A276BF0A8242403F912749D76A4940
23854	1	1	483	7263	33816	\N	50.695507999999997	Белгородская область, Корочанский район, село Нечаево, улица Центральная, дом 16		0101000020E6100000C765DCD4409142409D0DF96706594940
23869	1	1	483	7917	33571	\N	50.696021000000002	Белгородская область, Корочанский район, село Мелихово, улица Центральная, дом 6		0101000020E6100000732EC55565654240242A543717594940
23852	1	1	483	7171	33811	\N	50.787278999999998	Белгородская область, Корочанский район, село Мальцевка, улица Центральная, дом 14		0101000020E61000007A008BFCFAB54240EEE9EA8EC5644940
23884	1	1	483	8655	33819	\N	50.730128999999998	Белгородская область, Корочанский район, село Мазикино, улица Лисовенька, дом 6		0101000020E6100000FDF49F353F7042403B6EF8DD745D4940
23867	1	1	483	7839	33487	\N	50.753231	Белгородская область, Корочанский район, село Ломово, улица Мозгового, дом 8		0101000020E61000005378D0ECBA774240ACAA97DF69604940
23865	1	1	483	7721	33663	\N	50.894053	Белгородская область, Корочанский район, село Кощеево, улица Центральная, дом 17		0101000020E61000000ABFD4CF9B8E424002F2255470724940
23848	1	1	483	6804	33584	\N	50.811810000000001	Белгородская область, город Короча, площадь Васильева, дом 30		0101000020E6100000A7954220979842406B48DC63E9674940
23846	1	1	483	6804	33265	\N	50.811810000000001	Белгородская область, город Короча, улица Советская, дом 18		0101000020E6100000A7954220979842406B48DC63E9674940
23847	1	1	483	6804	33264	\N	50.811810000000001	Белгородская область, город Короча, Пролетарская, 26		0101000020E6100000A7954220979842406B48DC63E9674940
23845	1	1	483	6804	33264	\N	50.811810000000001	Белгородская область, город Короча, улица Пролетарская, дом 39		0101000020E6100000A7954220979842406B48DC63E9674940
23864	1	1	483	7712	33632	\N	50.894916000000002	Белгородская область, Корочанский район, село Короткое, улица Центральная, дом 3		0101000020E61000002497FF907EA342406555849B8C724940
23858	1	1	483	7448	33747	\N	50.787540999999997	Белгородская область, Корочанский район, село Клиновец, улица Кожанова, дом 27		0101000020E6100000E90FCD3CB9A442402BA1BB24CE644940
23880	1	1	483	8471	33817	\N	50.699877999999998	Белгородская область, Корочанский район, село Ивица, улица Центральная, дом 42		0101000020E6100000DEAF027CB79B42404E98309A95594940
23863	1	1	483	7643	33585	\N	50.772688000000002	Белгородская область, Корочанский район, село Заячье, улица Выгон, дом 56		0101000020E6100000CB2E185C737D42407E01BD70E7624940
23862	1	1	483	7623	33529	\N	50.713768000000002	Белгородская область, Корочанский район, село Жигайловка, улица Базарная, дом 42		0101000020E61000002D0ABB287AB042403677F4BF5C5B4940
23868	1	1	483	54010	33612	\N	50.6944522369512	Белгородская область, Корочанский район, село Дальняя Игуменка, улица Центральная, дом 78	Россия, Белгородская область, Корочанский район	0101000020E610000084622B685A60424026529ACDE3584940
23878	1	1	483	8395	33869	\N	50.750284999999998	Белгородская область, Корочанский район, село Городище, улица Вершина, дом 71		0101000020E6100000452C62D861884240F5D6C05609604940
23860	1	1	483	7550	33858	\N	50.845450999999997	Белгородская область, Корочанский район, село Бубново, улица Маркашовой А.И, дом 17		0101000020E6100000D8D7BAD408C342406CAF05BD376C4940
23887	1	1	483	8806	33705	\N	50.915636999999997	Белгородская область, Корочанский район, село Большое Песчаное, улица Песчаная, дом 20		0101000020E6100000C9E53FA4DFAC4240F700DD9733754940
23859	1	1	483	7463	33528	\N	50.925243999999999	Белгородская область, Корочанский район, село Большая Халань, улица Базарная, 39		0101000020E6100000518369183EB64240FD6838656E764940
23857	1	1	483	7358	33447	\N	50.802663000000003	Белгородская область, Корочанский район, село Бехтеевка, улица Ленина, дом 130/1		0101000020E6100000401361C3D39B4240C95A43A9BD664940
23856	1	1	483	7358	33447	\N	50.802663000000003	Белгородская область, Корочанский район, село Бехтеевка, улица Ленина, дом 126		0101000020E6100000401361C3D39B4240C95A43A9BD664940
23873	1	1	483	8155	33881	\N	50.941184	Белгородская область, Корочанский район, село Белый Колодец, улица Выгон, дом 5		0101000020E6100000884B8E3BA5A142405DC2A1B778784940
23853	1	1	483	7181	33607	\N	50.729826000000003	Белгородская область, Корочанский район, село Афанасово, улица Центральная, дом 1		0101000020E6100000D789CBF10A944240A0E238F06A5D4940
23851	1	1	483	7082	33657	\N	50.773268999999999	Белгородская область, Корочанский район, село Анновка, улица Центральная, дом 2		0101000020E6100000A96BED7DAABA42405C01857AFA624940
23850	1	1	483	6995	33815	\N	50.765805999999998	Белгородская область, Корочанский район, село Алексеевка, улица Мирошникова, дом 1/в		0101000020E6100000B4CC22145B854240508A56EE05624940
23849	1	1	483	6995	33359	\N	50.765805999999998	Белгородская область, Корочанский район, село Алексеевка, улица Богомазова, дом 1/А		0101000020E6100000B4CC22145B854240508A56EE05624940
23838	1	1	797	6466	\N	\N	51.142336	Белгородская область, Ивнянский район, село Череново, здание администрации Череновского сельского поселения	Россия, Белгородская область, Ивнянский район, поселок Череново	0101000020E610000062C092AB580642409085E81038924940
23844	1	1	797	6772	\N	\N	51.121129000000003	Белгородская область, Ивнянский район, село Хомутцы, здание сельского Дома культуры		0101000020E61000007077D66EBBF8414071CCB227818F4940
23833	1	1	797	6209	\N	\N	51.061943999999997	Белгородская область, Ивнянский район, село Федчевка, здание сельского Дома культуры		0101000020E6100000292504ABEA0942407A17EFC7ED874940
23842	1	1	797	6686	\N	\N	50.902284000000002	Белгородская область, Ивнянский район, село Сырцево, здание сельского Дома культуры	Россия, Белгородская область, Ивнянский район, поселок Сырцево	0101000020E6100000BDA8DDAF022242401FDAC70A7E734940
23841	1	1	797	6635	\N	\N	50.988265808878097	Белгородская область, Ивнянский район, село Сухосолотино, здание сельского Дома культуры	Россия, Белгородская область, Ивнянский район, поселок Сухосолотино	0101000020E6100000D8D30E7F4D324240D7DF12807F7E4940
23790	1	1	522	3905	33730	\N	51.289783999999997	село Петровки, Юбилейная, 8		0101000020E61000000322C495B3AD4240B87361A417A54940
23840	1	1	797	6571	\N	\N	51.092632999999999	Белгородская область, Ивнянский район, село Сафоновка, здание фельдшерско-акушерского пункта		0101000020E61000004912842BA0324240E3C3EC65DB8B4940
23839	1	1	797	6521	\N	\N	50.891739999999999	Белгородская область, Ивнянский район, село Покровка, здание культурно-спортивного комплекса		0101000020E610000017D7F84CF63742407C444C8924724940
23681	1	1	797	6521	\N	\N	50.891739999999999	село Покровка, Здание сельского Дома культуры		0101000020E610000017D7F84CF63742407C444C8924724940
23837	1	1	797	6415	\N	\N	51.140664000000001	Белгородская область, Ивнянский район, село Песчаное, здание сельского Дома культуры		0101000020E61000005F0B7A6F0C034240BEDC274701924940
23836	1	1	797	6356	\N	\N	50.971294999999998	Белгородская область, Ивнянский район, село Новенькое, здание сельского Дома культуры		0101000020E6100000111956F14612424058E20165537C4940
23835	1	1	797	6290	\N	\N	51.057822999999999	Белгородская область, Ивнянский район, село Курасовка, здание сельского Дома культуры	Россия, Белгородская область, Ивнянский район, поселок Курасовка	0101000020E6100000A88E554ACF1C424072FA7ABE66874940
23834	1	1	797	6253	\N	\N	51.036062000000001	Белгородская область, Ивнянский район, село Кочетовка, здание сельского Дома культуры		0101000020E610000079AF5A99F03942406E50FBAD9D844940
23832	1	1	797	6145	\N	\N	51.019213999999998	Белгородская область, Ивнянский район, поселок Кировский, здание сельского клуба		0101000020E610000012312592E80F42400BD0B69A75824940
23829	1	1	797	5946	33457	\N	51.058623414738001	Белгородская область, поселок Ивня, Советская, 42	Россия, Белгородская область, Ивнянский район, поселок Ивня	0101000020E6100000AA66D652401242408EE55DF580874940
23831	1	1	797	5946	33318	\N	51.052808334711997	Белгородская область, поселок Ивня, Садовая, 5А	Россия, Белгородская область, Ивнянский район, поселок Ивня	0101000020E6100000637E6E68CA124240CC7B9C69C2864940
23828	1	1	797	5946	33485	\N	51.067830999999998	Белгородская область, поселок Ивня, Ленина, 20		0101000020E61000000E2C47C840124240D653ABAFAE884940
23830	1	1	797	5946	33390	\N	51.067830999999998	Белгородская область, поселок Ивня, Заречная, 17А		0101000020E61000000E2C47C840124240D653ABAFAE884940
23827	1	1	797	5874	\N	\N	51.023066999999998	Белгородская область, Ивнянский район, село Драгунка, здание сельского Дома культуры	Россия, Белгородская область, Ивнянский район, поселок Драгунка	0101000020E610000037C30DF8FCFA4140F44E05DCF3824940
23826	1	1	797	5845	\N	\N	51.081442000000003	Белгородская область, Ивнянский район, село Вознесеновка, здание школы		0101000020E61000009B8F6B43C51C4240AB4203B16C8A4940
23825	1	1	797	5764	\N	\N	51.057924999999997	Белгородская область, Ивнянский район, село Владимировка, здание школы		0101000020E61000002BC3B81B44234240764F1E166A874940
23824	1	1	797	5656	\N	\N	50.947648000000001	Белгородская область, Ивнянский район, село Верхопенье, здание школы	Россия, Белгородская область, Ивнянский район, поселок Верхопенье	0101000020E6100000B6813B50A7264240560F98874C794940
23823	1	1	797	5656	\N	\N	50.947648000000001	Белгородская область, Ивнянский район, село Верхопенье, здание сельского Дома культуры		0101000020E6100000B6813B50A7264240560F98874C794940
23822	1	1	797	5631	\N	\N	50.975026999999997	Белгородская область, Ивнянский район, село Богатое, здание сельского клуба		0101000020E61000000B7E1B62BC024240C6DB4AAFCD7C4940
23843	1	1	797	6706	\N	\N	50.903858	Белгородская область, Ивнянский район, село Березовка, здание сельского клуба		0101000020E6100000C93846B2471A42402E1D739EB1734940
23801	1	1	522	47613	33855	\N	51.197495000000004	село Юшково, Троицкая, 57		0101000020E6100000D503E62153AE4240D00F238447994940
23821	1	1	522	47970	33732	\N	51.056283000000001	село Юрьевка, Мира, 6		0101000020E6100000CF30B5A50EAC42400F29064834874940
23807	1	1	522	4811	33621	\N	51.136713	село Чуево, Центральная, 41		0101000020E6100000DB6AD619DF8D424012F8C3CF7F914940
23787	1	1	522	3768	33722	\N	51.237685999999997	село Чапкино, Садовая, 4		0101000020E610000016F6B4C35FA14240C85BAE7E6C9E4940
23794	1	1	522	47478	\N	\N	51.110154999999999	село Хворостянка, Центральная, 21	Россия, Белгородская область, Губкинский район, поселок Хворостянка	0101000020E6100000605AD427B9C34240D53E1D8F198E4940
23683	1	1	522	47520	\N	\N	51.121022000000004	село Успенка, Здание сельского Дома культуры		0101000020E61000003E97A949F0DA42405B0C1EA67D8F4940
23796	1	1	522	47520	33694	\N	51.121022000000004	село Успенка, Заречная, 32		0101000020E61000003E97A949F0DA42405B0C1EA67D8F4940
23806	1	1	522	4781	33742	\N	51.216653000000001	село Уколово, Центральная, 13		0101000020E6100000AAD216D7F888424047CA1649BB9B4940
23775	1	1	522	47086	33471	\N	51.358575000000002	поселок Троицкий, Центральная, 9		0101000020E61000000C3B8C497FC14240E4141DC9E5AD4940
23774	1	1	522	47086	33471	\N	51.358575000000002	поселок Троицкий, Центральная, 11		0101000020E61000000C3B8C497FC14240E4141DC9E5AD4940
23815	1	1	522	47855	33618	\N	50.99888	село Толстое, Центральная, 46		0101000020E61000000E881057CEA042407250C24CDB7F4940
23778	1	1	522	3291	33633	\N	51.314601000000003	село Теплый Колодезь, Центральная, 4		0101000020E6100000ABAE433525C14240FB2477D844A84940
23813	1	1	522	47819	33771	\N	51.044840000000001	село Телешовка, Григория Найдина, 68		0101000020E61000007347FFCBB5A24240BDC62E51BD854940
23786	1	1	522	47308	33693	\N	51.318986000000002	село Строкино, Ракитная, 1		0101000020E6100000022D5DC136A04240E1F08288D4A84940
23820	1	1	522	47967	33698	\N	51.008209999999998	поселок Степное, Народная, 1		0101000020E6100000E4F90CA837AD424005C078060D814940
23800	1	1	522	47593	33738	\N	51.194442000000002	село Солнцево, Медовая, 1		0101000020E61000001AC05B2041A14240037CB779E3984940
23810	1	1	522	47773	33603	\N	51.074821	село Скородное, Красноармейская, 1		0101000020E6100000C85EEFFE789D4240EA060ABC93894940
23812	1	1	522	47773	33395	\N	51.074821	село Скородное, 1 Мая, 39		0101000020E6100000C85EEFFE789D4240EA060ABC93894940
23811	1	1	522	47773	33395	\N	51.074821	село Скородное, 1 Мая, 26		0101000020E6100000C85EEFFE789D4240EA060ABC93894940
23795	1	1	522	47512	33643	\N	51.128326000000001	село Сапрыкино, Центральная, 49		0101000020E61000009C35785F95D14240FE9C82FC6C904940
23808	1	1	522	54057	\N	\N	51.146337898374597	"село Новоселовка, Производственный участок №1 ЗАО ""Чуевское поле"", зал заседаний"	Россия, Белгородская область, Губкинский район, поселок Новоселовка	0101000020E6100000DA8CD31055944240BE141E34BB924940
23803	1	1	522	47652	33648	\N	51.199424999999998	село Никаноровка, Владимира Уколова, 3		0101000020E610000000FDBE7FF39442409D8026C286994940
23805	1	1	522	47686	33849	\N	51.170316	село Морозово, Сиреневая, 8		0101000020E61000001B649291B39A424026FE28EACC954940
23802	1	1	522	4567	33877	\N	51.122413000000002	село Мелавое, Школьная, 6		0101000020E610000008C9022670B3424079CDAB3AAB8F4940
23814	1	1	522	5196	33772	\N	51.015309999999999	село Корочка, Троицкая, 77		0101000020E61000000DA837A3E6A54240A0A696ADF5814940
23819	1	1	522	47944	33650	\N	51.043089999999999	село Коньшино, Тихая, 2		0101000020E61000005CE49EAEEEBC42406F641EF983854940
23799	1	1	522	4366	33692	\N	51.228363000000002	село Кладовое, Народная, 10		0101000020E6100000E3FDB8FDF2AB4240E84EB0FF3A9D4940
23804	1	1	522	54067	33882	\N	51.1365867824655	хутор Калинин, Мира, 1а	Россия, Белгородская область, Губкинский район, поселок Калинин	0101000020E61000003F912749D79C42408507CDAE7B914940
23776	1	1	522	3175	33735	\N	51.351528000000002	поселок Казацкая Степь, Школьная, 2		0101000020E6100000F29881CAF8CD42406CD097DEFEAC4940
23817	1	1	522	5346	33549	\N	51.121231000000002	село Истобное, Центральная, 1		0101000020E6100000B1A371A8DFA942407521567F848F4940
23818	1	1	522	5346	33769	\N	51.121231000000002	село Истобное, Солнечная, 3		0101000020E6100000B1A371A8DFA942407521567F848F4940
23791	1	1	522	47424	33775	\N	51.208047999999998	поселок Заповедный, Центральная, 14		0101000020E6100000423EE8D9ACCA4240C5FF1D51A19A4940
23789	1	1	522	47397	33856	\N	51.269778000000002	село Заломное, Урожайная, 27		0101000020E6100000832F4CA60AAA42401497E31588A24940
23643	1	1	522	48162	\N	\N	51.309494999999998	село Долгое, помещение сельского Дома культуры	Россия, Белгородская область, Губкинский район, поселок Долгое	0101000020E6100000C5E40D30F3A7424044A33B889DA74940
23600	1	1	522	48162	\N	\N	51.309494999999998	с. Долгое, здание Должанского сельского клуба	Россия, Белгородская область, Губкинский район, поселок Долгое	0101000020E6100000C5E40D30F3A7424044A33B889DA74940
23784	1	1	522	47287	33814	\N	51.330682000000003	село Гущино, Железнодорожная, 34		0101000020E61000003659A31EA29942401DB0ABC953AA4940
23785	1	1	522	47290	33759	\N	51.282105999999999	село Вислая Дубрава, Каштановая, 3		0101000020E610000039471D1D57A34240B000A60C1CA44940
23798	1	1	522	47561	33741	\N	51.160263	село Богородицкое, Центральная, 5		0101000020E6100000A6D0798D5DAC424022E17B7F83944940
23797	1	1	522	4257	33606	\N	51.188876	село Бобровы Дворы, Белгородская, 91		0101000020E610000098BED7101CB14240E97FB9162D984940
23783	1	1	522	47264	33872	\N	51.267378000000001	село Архангельское, Мичурина, 3		0101000020E6100000EB5223F433954240BFD53A7139A24940
23779	1	1	522	47166	33625	\N	51.289440999999997	село Аверино, Центральная, 27		0101000020E610000081069B3A8FB842408E8F16670CA54940
23769	1	1	6958	54009	33685	\N	51.301993247568603	город Губкин, Павлика Морозова, 2	Россия, Белгородская область, Губкин городской округ, поселок Лебеди	0101000020E6100000F2CF0CE203CD42407B4FE5B4A7A64940
23780	1	1	6958	47186	33767	\N	51.261392000000001	село Зареченка, Заречная, 40а		0101000020E61000008A592F8672C04240D0B7054B75A14940
23712	1	1	59	54051	\N	\N	50.516199999999998	"Белгородская область, муниципальный район ""Грайворонский район"", Головчинское сельское поселение, ООО ""Хотмыжское ХПП"""		0101000020E61000002B1895D409EA4140FC1873D712424940
23721	1	1	59	54048	\N	\N	50.597267000000002	"Белгородская область, муниципальный район ""Грайворонский район"", Дорогощанское сельское поселение, Санковский сельский клуб"	Россия, Белгородская область, Грайворонский район, поселок Санково	0101000020E61000007C9DD497A5CB414072FDBB3E734C4940
23608	1	1	59	48310	\N	\N	50.558461713580598	с. Подгорное, здание Подгоренского сельского Дома культуры	Россия, Белгородская область, Грайворонский район, поселок Подгорное	0101000020E6100000BADA8AFD65C341408507CDAE7B474940
23733	1	1	59	54039	\N	\N	50.448698017738799	"Белгородская область, муниципальный район ""Грайворонский район"", Новостроевское сельское поселение, Ремесленно промысловый двор"	Россия, Белгородская область, Грайворонский район, поселок Новостроевка 1-я	0101000020E610000030293E3E21DF4140EBE3A1EF6E394940
23723	1	1	59	54053	\N	\N	50.560459000000002	"Белгородская область, муниципальный район ""Грайворонский район"", Дунайское сельское поселение, Мощенская начальная школа"	Россия, Белгородская область, Грайворонский район, поселок Мощеное	0101000020E61000000938842A35C54140DBDFD91EBD474940
23731	1	1	59	54028	\N	\N	50.518239000000001	"Белгородская область, муниципальный район ""Грайворонский район"", Мокроорловское сельское поселение, М-Орловская средняя школа"	Россия, Белгородская область, Грайворонский район, поселок Мокрая Орловка	0101000020E61000004791B58652C141408141D2A755424940
23730	1	1	59	54028	\N	\N	50.518239000000001	"Белгородская область, муниципальный район ""Грайворонский район"", Мокроорловское сельское поселение, М-Орловский СМДК"	Россия, Белгородская область, Грайворонский район, поселок Мокрая Орловка	0101000020E61000004791B58652C141408141D2A755424940
23705	1	1	59	31688	\N	\N	50.509922000000003	"Белгородская область, муниципальный район ""Грайворонский район"", городское поселение ""Город Грайворон"", Дет.сад с.Луговка"	Россия, Белгородская область, Грайворонский район, поселок Луговка	0101000020E61000007D9752978CDB414066C1C41F45414940
23726	1	1	59	54063	\N	\N	50.574248893803102	"Белгородская область, муниципальный район ""Грайворонский район"", Ивано-Лисичанское сельское поселение, Ломненский сельский клуб"	Россия, Белгородская область, Грайворонский район, поселок Ломное	0101000020E61000006760E4654DE441405F61C1FD80494940
23728	1	1	59	54002	\N	\N	50.652113	"Белгородская область, муниципальный район ""Грайворонский район"", Ивано-Лисичанское сельское поселение, Косиловский сельский ДК"	Россия, Белгородская область, Грайворонский район, поселок Косилово	0101000020E6100000EE3F321D3AD14140F225547078534940
23729	1	1	59	53982	\N	\N	50.4506700520148	"Белгородская область, муниципальный район ""Грайворонский район"", Козинское сельское поселение, Козинский СМДК"	Россия, Белгородская область, Грайворонский район, поселок Козинка	0101000020E6100000239EEC6646CD4140E8A4F78DAF394940
23727	1	1	59	54033	\N	\N	50.621726197508103	"Белгородская область, муниципальный район ""Грайворонский район"", Ивано-Лисичанское сельское поселение, Казачье Лисичанский сельский клуб"	Россия, Белгородская область, Грайворонский район, поселок Казачья Лисица	0101000020E61000000FEF39B01CDF41405589B2B7944F4940
23725	1	1	59	54014	\N	\N	50.592720999999997	"Белгородская область, муниципальный район ""Грайворонский район"", Ивано-Лисичанское сельское поселение, И-Лисичанскай сельский ДК"	Россия, Белгородская область, Грайворонский район, поселок Ивановская Лисица	0101000020E61000001BF2CF0CE2D9414082531F48DE4B4940
23722	1	1	59	54050	\N	\N	50.546529	"Белгородская область, муниципальный район ""Грайворонский район"", Дунайское сельское поселение, Дунайский СМДК"	Россия, Белгородская область, Грайворонский район, поселок Дунайка	0101000020E61000008A1D8D43FDC4414065A88AA9F4454940
23735	1	1	59	54032	\N	\N	50.635497000000001	"Белгородская область, муниципальный район ""Грайворонский район"", Смородинское сельское поселение, Дроновский сельский клуб"	Россия, Белгородская область, Грайворонский район, поселок Дроновка	0101000020E6100000FCFB8C0B07B6414062DA37F757514940
23720	1	1	59	54011	\N	\N	50.585068999999997	"Белгородская область, муниципальный район ""Грайворонский район"", Дорогощанское сельское поселение, Дорогощанский СМДК"	Россия, Белгородская область, Грайворонский район, поселок Дорогощь	0101000020E61000006DACC43C2BC94140A3737E8AE34A4940
23719	1	1	59	54020	\N	\N	50.540130306897602	"Белгородская область, муниципальный район ""Грайворонский район"", Доброивановское сельское поселение, Замостянская ОШ"	Россия, Белгородская область, Грайворонский район, поселок Добро-Ивановка	0101000020E610000082C64CA25EDE414053CBD6FA22454940
23718	1	1	59	54020	\N	\N	50.538440000000001	"Белгородская область, муниципальный район ""Грайворонский район"", Доброивановское сельское поселение, Добосельский СМДК"	Россия, Белгородская область, Грайворонский район, поселок Добро-Ивановка	0101000020E6100000B438639813DE4140DB6D179AEB444940
23717	1	1	59	54020	\N	\N	50.537285970439299	"Белгородская область, муниципальный район ""Грайворонский район"", Доброивановское сельское поселение, Доброивановский сельский клуб"	Россия, Белгородская область, Грайворонский район, поселок Добро-Ивановка	0101000020E6100000E675C4211BDE4140A14CA3C9C5444940
23715	1	1	59	53964	\N	\N	50.473051086035703	"Белгородская область, муниципальный район ""Грайворонский район"", Гора-Подольское сельское поселение, Гора Подольская средняя школа"	Россия, Белгородская область, Грайворонский район, Грайворон	0101000020E6100000505436ACA9D64140882B67EF8C3C4940
23704	1	1	59	53964	\N	\N	50.476857815224498	"Белгородская область, муниципальный район ""Грайворонский район"", городское поселение ""Город Грайворон"", Средняя школа им.Шухова"	Россия, Белгородская область, Грайворонский район, Грайворон	0101000020E6100000EFA83121E6D64140016BD5AE093D4940
23703	1	1	59	53964	\N	\N	50.480991000000003	"Белгородская область, муниципальный район ""Грайворонский район"", городское поселение ""Город Грайворон"", ОГУЗ ""Детский санаторий г.Грайв-н"""	Россия, Белгородская область, Грайворонский район, Грайворон	0101000020E61000007BF65CA626D74140CE55F31C913D4940
23702	1	1	59	53964	\N	\N	50.481045353391899	"Белгородская область, муниципальный район ""Грайворонский район"", городское поселение ""Город Грайворон"", Грайворонская средняя школа с УИОП"	Россия, Белгородская область, Грайворонский район, Грайворон	0101000020E610000042EDB776A2D64140C173EFE1923D4940
23714	1	1	59	54031	\N	\N	50.534444000000001	"Белгородская область, муниципальный район ""Грайворонский район"", Горьковское сельское поселение, Чапаевская начальная школа"		0101000020E6100000CE6C57E883D341408FC536A968444940
23713	1	1	59	54037	\N	\N	50.447251999999999	"Белгородская область, муниципальный район ""Грайворонский район"", Горьковское сельское поселение, Горьковская средняя школа"	Россия, Белгородская область, Грайворонский район, поселок Горьковский	0101000020E6100000E9F17B9BFEEC41400989B48D3F394940
23716	1	1	59	54013	\N	\N	50.469627505206297	"Белгородская область, муниципальный район ""Грайворонский район"", Гора-Подольское сельское поселение, Глотовский сельский клуб"	Россия, Белгородская область, Грайворонский район, поселок Подол	0101000020E61000009A417C60C7D3414098A432C51C3C4940
24225	1	1	1875	46891	33670	\N	50.349845999999999	с. Владимировка, Школьная, 19, дом культуры		0101000020E61000008274B169A5F242407651F4C0C72C4940
23502	1	1	1588	22212	33652	\N	50.711993999999997	Белгородская область, Белгородский район, село Хохлово, Центральная, 17		0101000020E6100000E161DA37F75742405F79909E225B4940
23711	1	1	59	53985	\N	\N	50.536568000000003	"Белгородская область, муниципальный район ""Грайворонский район"", Головчинское сельское поселение, Головчинская начальная школа"	Россия, Белгородская область, Грайворонский район, поселок Головчино	0101000020E61000001F0E12A27CE74140420A9E42AE444940
23710	1	1	59	53985	\N	\N	50.536568000000003	"Белгородская область, муниципальный район ""Грайворонский район"", Головчинское сельское поселение, Головчинская школа с УИОП"	Россия, Белгородская область, Грайворонский район, поселок Головчино	0101000020E61000001F0E12A27CE74140420A9E42AE444940
23709	1	1	59	53985	\N	\N	50.534988495860503	"Белгородская область, муниципальный район ""Грайворонский район"", Головчинское сельское поселение, Головчинская библиотека"	Россия, Белгородская область, Грайворонский район, поселок Головчино	0101000020E610000024473A0323E7414050E09D7C7A444940
23707	1	1	59	53985	\N	\N	50.536094713425101	"Белгородская область, муниципальный район ""Грайворонский район"", Головчинское сельское поселение, Антоновский СМДК"		0101000020E6100000A96A82A8FBE641404A46CEC29E444940
23706	1	1	59	54003	\N	\N	50.390081000000002	"Белгородская область, муниципальный район ""Грайворонский район"", Безыменское сельское поселение, Безыменский СМДК"	Россия, Белгородская область, Грайворонский район, поселок Безымено	0101000020E6100000BAD8B45208DA41403FE5982CEE314940
23708	1	1	59	53991	\N	\N	50.551594000000001	"Белгородская область, муниципальный район ""Грайворонский район"", Головчинское сельское поселение, Антоновская ОШ"	Россия, Белгородская область, Грайворонский район, поселок Антоновка	0101000020E6100000CCD0782288E14140BD55D7A19A464940
23697	1	1	1875	31294	\N	\N	50.491433000000001	село Ютановка, Здание сельского Дома культуры		0101000020E6100000042159C004E642406C96CB46E73E4940
23696	1	1	1875	31221	\N	\N	50.524349000000001	село Шидловка, Здание сельского Дома культуры		0101000020E61000002C4487C091D042405C5837DE1D434940
23687	1	1	1875	30799	\N	\N	50.569608000000002	село Шеншиновка, Здание сельского клуба		0101000020E610000085EE92382B0843401EC539EAE8484940
23693	1	1	1875	45410	\N	\N	50.407001999999999	хутор Шаховка, Здание сельского клуба	Россия, Белгородская область, Волоконовский район, поселок Шаховка	0101000020E610000014E7A8A3E3C442400BB43BA418344940
23698	1	1	1875	31322	\N	\N	50.516331000000001	село Чапельное, Здание сельского клуба	Россия, Белгородская область, Волоконовский район, поселок Чапельное	0101000020E6100000E7E26F7B82DA42409B745B2217424940
23695	1	1	1875	31132	\N	\N	50.428525999999998	село Фощеватово, Здание сельского клуба		0101000020E6100000967A1684F20843402BBEA1F0D9364940
23694	1	1	1875	31132	\N	\N	50.428525999999998	село Фощеватово, Здание администрации сельского поселения		0101000020E6100000967A1684F20843402BBEA1F0D9364940
23692	1	1	1875	45392	\N	\N	50.395772000000001	село Тишанка, Здание сельского Дома культуры		0101000020E6100000B14F00C5C8C0424015562AA8A8324940
23688	1	1	1875	49582	\N	\N	50.575505999999997	село Староивановка, Здание администрации сельского поселения		0101000020E61000002FDCB930D2E942406D533C2EAA494940
23686	1	1	1875	49552	\N	\N	50.572623	село Репьевка, Здание сельского Дома культуры		0101000020E6100000BCB376DB85FE4240FDF7E0B54B494940
23685	1	1	1875	49527	33212	\N	50.426350999999997	поселок Пятницкое, проспект Маресевой, 16		0101000020E6100000E8DCED7A69EA4240F6CE68AB92364940
23684	1	1	1875	49527	33212	\N	50.426350999999997	поселок Пятницкое, проспект Маресевой, 14		0101000020E6100000E8DCED7A69EA4240F6CE68AB92364940
23676	1	1	1875	30214	\N	\N	50.397523	село Осколище, Здание сельского клуба		0101000020E61000000ABDFE243EE9424033349E08E2324940
23689	1	1	1875	30901	\N	\N	50.548011000000002	село Новорождественка, Здание сельского Дома культуры	Россия, Белгородская область, Волоконовский район, поселок Новорождественка	0101000020E610000056B950F9D7E84240946C753925464940
23701	1	1	1875	31505	\N	\N	50.462237999999999	село Нижние Лубянки, Здание сельского клуба		0101000020E61000008A0453CDACE94240F67B629D2A3B4940
23682	1	1	1875	30523	\N	\N	50.493758999999997	село Лазурное, Здание сельского клуба		0101000020E6100000698F17D2E1094340868DB27E333F4940
23690	1	1	1875	45344	\N	\N	50.583331000000001	село Коровино, Здание сельского клуба		0101000020E6100000C45DBD8A8CE442401ADF1797AA4A4940
23680	1	1	1875	49463	\N	\N	50.304847000000002	село Коновалово, Здание сельского клуба		0101000020E61000007E8CB96B09D9424051A4FB3905274940
23679	1	1	1875	30381	\N	\N	50.352454999999999	хутор Давыдкин, Здание фельдшерско-акушерского пункта		0101000020E61000004ED367075CDB4240E527D53E1D2D4940
23675	1	1	1875	49395	\N	\N	50.412714000000001	село Грушевка, Здание сельского Дома культуры	Россия, Белгородская область, Волоконовский район, поселок Грушевка	0101000020E61000006F2D93E178D84240F94CF6CFD3344940
23672	1	1	1875	30000	\N	\N	50.477912000000003	село Волчья Александровка, Здание бывшего селького библиотечного филиала		0101000020E6100000FBC9181F66C94240D82E6D382C3D4940
23671	1	1	1875	30000	\N	\N	50.477912000000003	село Волчья Александровка, Здание администрации сельского поселения		0101000020E6100000FBC9181F66C94240D82E6D382C3D4940
23670	1	1	1875	29645	33229	\N	50.485398000000004	поселок Волоконовка, Чехова, 1		0101000020E61000000E130D52F0EA42409CC58B85213E4940
23664	1	1	1875	29645	33217	\N	50.485398000000004	поселок Волоконовка, Пионерская, 20	Россия, Белгородская область, Волоконовский район, поселок Волоконовка	0101000020E61000000E130D52F0EA42409CC58B85213E4940
23665	1	1	1875	29645	33398	\N	50.485398000000004	поселок Волоконовка, Ленина, 18 А	Россия, Белгородская область, Волоконовский район, поселок Волоконовка	0101000020E61000000E130D52F0EA42409CC58B85213E4940
23669	1	1	1875	29645	33222	\N	50.485398000000004	поселок Волоконовка, Гагарина, 55	Россия, Белгородская область, Волоконовский район, поселок Волоконовка	0101000020E61000000E130D52F0EA42409CC58B85213E4940
23674	1	1	1875	30134	\N	\N	50.361541000000003	село Ветчининово, Здание сельского клуба	Россия, Белгородская область, Волоконовский район, поселок Ветчининово	0101000020E610000003ECA35357EE4240E294B9F9462E4940
23700	1	1	1875	31422	\N	\N	50.451118000000001	село Верхние Лубянки, Здание сельского клуба	Россия, Белгородская область, Волоконовский район, поселок Верхние Лубянки	0101000020E610000007B64AB038DE42408751103CBE394940
23691	1	1	1875	31002	\N	\N	50.566431999999999	село Афоньевка, Здание сельского Дома культуры		0101000020E610000029AE2AFBAEE4424035B401D880484940
23661	1	1	1836	49212	\N	\N	49.994714999999999	село Солонцы, помещение сельского Дома культуры	Россия, Белгородская область, Вейделевский район, поселок Солонцы	0101000020E61000004E61A5828A4643409AEB34D252FF4840
23644	1	1	1836	28771	\N	\N	50.370320999999997	хутор Ромахово, помещение детского сада	Россия, Белгородская область, Вейделевский район, поселок Ромахово	0101000020E610000043209738F2444340D102B4AD662F4940
23660	1	1	1836	29467	\N	\N	50.146822	село Ровны, помещение основной школы		0101000020E6100000A7936C75396B4340AA2A3410CB124940
23662	1	1	1836	54040	\N	\N	50.033496725324802	хутор Попов, помещение сельского клуба	Россия, Белгородская область, Вейделевский район, поселок Попов	0101000020E6100000ACC43C2B69434340CEC133A149044940
23659	1	1	1836	29436	\N	\N	50.193741000000003	хутор Попасный, помещение сельского клуба		0101000020E6100000A37895B54D6143407A724D81CC184940
23641	1	1	1836	48886	\N	\N	50.102353000000001	поселок Опытный, помещение сельского клуба		0101000020E6100000BA68C878943C4340E1D231E7190D4940
23640	1	1	1836	28562	\N	\N	50.079397	село Олейники, помещение сельского клуба		0101000020E61000001B0DE02D904A434044334FAE290A4940
23658	1	1	1836	29371	\N	\N	50.240228000000002	хутор Ногин, помещение сельского клуба		0101000020E610000002452C62D85B4340B0CA85CABF1E4940
23654	1	1	1836	29221	\N	\N	50.317703999999999	село Малакеево, Помещение сельского Дома культуры	Россия, Белгородская область, Вейделевский район, поселок Малакеево	0101000020E61000006B662D05A455434079E75086AA284940
23651	1	1	1836	29100	\N	\N	50.1648	село Кубраки, Помещение сельского Дома культуры	Россия, Белгородская область, Вейделевский район, поселок Кубраки	0101000020E61000005776C1E09A5B4340BE30992A18154940
23650	1	1	1836	49045	\N	\N	50.055095000000001	село Клименки, помещение сельского Дома культуры		0101000020E6100000B0ABC953562F434029965B5A0D074940
23648	1	1	1836	49003	\N	\N	50.172572000000002	село Зенино, Здание сельского Дома культуры		0101000020E6100000AB59677C5F264340481ADCD616164940
23646	1	1	1836	28867	\N	\N	50.159900999999998	село Закутское, Здание Дома культуры		0101000020E61000008527F4FA9350434081CCCEA277144940
23655	1	1	1836	42949	\N	\N	50.276342999999997	село Дегтярное, помещение сельского Дома культуры	Россия, Белгородская область, Вейделевский район, поселок Дегтярное	0101000020E6100000A54C6A680356434040BD19355F234940
23639	1	1	1836	28542	\N	\N	50.081045000000003	поселок Викторополь, помещение сельского Дома культуры		0101000020E610000053B4722F303D43408E40BCAE5F0A4940
23635	1	1	1836	28182	33654	\N	50.147542999999999	поселок Вейделевка, ул.Центральная, д.30		0101000020E6100000639AE95E273743407AE063B0E2124940
23636	1	1	1836	28182	33583	\N	50.147542999999999	поселок Вейделевка, ул.Пролетарская, д.32а		0101000020E6100000639AE95E273743407AE063B0E2124940
23637	1	1	1836	28182	33783	\N	50.147542999999999	поселок Вейделевка, ул.Октябрьская, д.34		0101000020E6100000639AE95E273743407AE063B0E2124940
23631	1	1	1836	28182	33620	\N	50.147542999999999	поселок Вейделевка, ул.Мира, д.83		0101000020E6100000639AE95E273743407AE063B0E2124940
23634	1	1	1836	28182	33655	\N	50.147542999999999	поселок Вейделевка, ул.Комсомольская, д.17		0101000020E6100000639AE95E273743407AE063B0E2124940
23633	1	1	1836	28182	33483	\N	50.146495346187599	поселок Вейделевка, ул.Гайдара, д.22а	Россия, Белгородская область, Вейделевский район, поселок Вейделевка	0101000020E6100000371614066538434086032159C0124940
23632	1	1	1836	28182	33483	\N	50.147542999999999	поселок Вейделевка, ул.Гайдара, д.1		0101000020E6100000639AE95E273743407AE063B0E2124940
23647	1	1	1836	28923	\N	\N	50.157125000000001	хутор Брянские Липяги, помещение сельского клуба		0101000020E61000009CDEC5FB712F4340273108AC1C144940
23630	1	1	1836	28118	\N	\N	50.201479999999997	село Большие Липяги, помещение сельского Дома культуры		0101000020E6100000F702B342913643402766BD18CA194940
23645	1	1	1836	28811	\N	\N	50.203982000000003	село Белый Плес, помещение начальной школы	Россия, Белгородская область, Вейделевский район, поселок Белый Плес	0101000020E610000061FA5E43704C4340817C09151C1A4940
23652	1	1	1836	29135	\N	\N	50.114362999999997	село Банкино, Помещение сельского Дома культуры	Россия, Белгородская область, Вейделевский район, поселок Банкино	0101000020E610000049F59D5F945E4340AC6F6072A30E4940
23616	1	1	1112	48458	\N	\N	50.290697999999999	с. Шушпаново, здание Шушпановского сельского Дома культуры		0101000020E61000007A1A3048FA1643409D81919735254940
23622	1	1	1112	48563	\N	\N	50.121566000000001	с. Шелаево, здание Шелаевского сельского Дома культуры		0101000020E61000003BC5AA41980943401C2785798F0F4940
23627	1	1	1112	48644	\N	\N	50.15249	с. Храпово, здание Храповского сельского клуба	Россия, Белгородская область, Валуйский район, поселок Храпово	0101000020E610000036936FB6B9054340C87BD5CA84134940
23611	1	1	1112	48381	\N	\N	50.276446	с. Хохлово, здание Хохловского сельского клуба	Россия, Белгородская область, Валуйский район, поселок Хохлово	0101000020E61000000C03965CC5FA4240158E209562234940
23621	1	1	1112	27737	\N	\N	50.3790613241827	с. Хмелевец, здание Хмелевского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Хмелевец	0101000020E610000011FFB0A5470543403318231285304940
23617	1	1	1112	48470	\N	\N	50.350552999999998	с. Филиппово, здание бывшей начальной школы		0101000020E61000005AF5B9DA8A114340E141B3EBDE2C4940
23504	1	1	1588	22300	33614	\N	50.448014999999998	Белгородская область, Белгородский район, село Щетиновка, Молодежная, 1		0101000020E61000001D1F2DCE18164240088F368E58394940
23577	1	1	1112	53979	33681	\N	50.084408372000901	"городское поселение ""Поселок Уразово"", Рабочая, 37"	Россия, Белгородская область, Валуйский район, поселок Уразово	0101000020E6100000C66AF3FFAA054340A9C29FE1CD0A4940
23578	1	1	1112	53979	33444	\N	50.081308667053797	"городское поселение ""Поселок Уразово"", Ленина, 7Б"	Россия, Белгородская область, Валуйский район, поселок Уразово	0101000020E610000075ABE7A4F70543406BEF5355680A4940
23579	1	1	1112	53979	33301	\N	50.084923963169601	"городское поселение ""Поселок Уразово"", Калинина, 45"	Россия, Белгородская область, Валуйский район, поселок Уразово	0101000020E6100000C64D0D349F054340A05225CADE0A4940
23576	1	1	1112	53979	33520	\N	50.084958	"городское поселение ""Поселок Уразово"", 2-я Пролетарская, 17"	Россия, Белгородская область, Валуйский район, поселок Уразово	0101000020E6100000650113B8750543404CC45BE7DF0A4940
23624	1	1	1112	27860	\N	\N	50.101744168916198	с. Ураево, здание Ураевского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Ураево	0101000020E61000002C7FBE2D581C4340384888F2050D4940
23610	1	1	1112	48349	\N	\N	50.320459	с. Углово, здание Угловского сельского клуба		0101000020E6100000FE0DDAAB8FFF4240BC5AEECC04294940
23603	1	1	1112	26929	\N	\N	50.243102999999998	"с. Тулянка, здание МОУ ""Тулянская основная общеобразовательная школа"""		0101000020E610000026C632FD12F742409D47C5FF1D1F4940
23618	1	1	1112	48495	\N	\N	50.326135999999998	с. Тимоново, здание Тимоновского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Тимоново	0101000020E610000039605793A70643402D060FD3BE294940
23586	1	1	1112	47881	\N	\N	50.1402	с. Сухарево, здание Сухаревского сельского клуба		0101000020E610000083BEF4F6E7FC42401973D712F2114940
23583	1	1	1112	54066	\N	\N	50.231342166458298	с. Старый Хутор, здание Старохуторского сельского клуба	Россия, Белгородская область, Валуйский район, поселок Старый Хутор	0101000020E6100000A164726A67D442407A185A9D9C1D4940
23620	1	1	1112	48531	\N	\N	50.283262000000001	с. Солоти, здание Солотянского сельского Дома культуры		0101000020E6100000BF0F0709510643408B19E1ED41244940
23581	1	1	1112	47782	\N	\N	50.074530000000003	с. Соболевка, здание Соболевского сельского Дома культуры		0101000020E610000022718FA50F0943401349F4328A094940
23615	1	1	1112	48435	\N	\N	50.304836000000002	с. Селиваново, здание Селивановского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Селиваново	0101000020E6100000B7B3AF3C481343405D52B5DD04274940
23596	1	1	1112	52945	\N	\N	50.191170988634703	"х. Рябики, здание конторы участка №1 ООО ""Русагро-Валуйки"""	Россия, Белгородская область, Валуйский район, поселок Рябики	0101000020E61000008B4E965AEFE34240C878944A78184940
23607	1	1	1112	48297	\N	\N	50.202095999999997	пос. Рощино, здание Рощинского сельского клуба		0101000020E61000003A05F9D9C829434082531F48DE194940
23612	1	1	1112	48382	\N	\N	50.228831	с. Рождествено, здание Рождественского сельского Дома культуры		0101000020E6100000FB78E8BB5B174340CEA78E554A1D4940
23614	1	1	1112	48424	\N	\N	50.17098	"пос. Ровное, здание МДОУ ""Детский сад"""		0101000020E6100000FCDF1115AA214340922232ACE2154940
23609	1	1	1112	27158	\N	\N	50.306106999999997	с. Принцевка, здание Принцевского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Принцевка	0101000020E6100000DE74CB0EF1F54240D009A1832E274940
23604	1	1	1112	48233	\N	\N	50.258493000000001	с. Посохово, здание Посоховского сельского клуба		0101000020E6100000C4B5DAC35EF242405A9F724C16214940
24244	1	1	1112	40306	9772	\N	50.0646757014188	с. Песчанка, Центральная, 22, дом культуры	Россия, Белгородская область, Валуйский район, поселок Песчанка	0101000020E610000053094FE8F5F34240056B9C4D47084940
23626	1	1	1112	48635	\N	\N	50.203623999999998	с. Орехово, здание Ореховского сельского клуба		0101000020E61000000C1EA67D73FD42402157EA59101A4940
23587	1	1	1112	47905	\N	\N	50.131596999999999	с. Новопетровка, здание Новопетровского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Новопетровка	0101000020E6100000410B09185DE0424038A0A52BD8104940
23613	1	1	1112	27356	\N	\N	50.211320999999998	"с. Новоказацкое, здание ""Новоказацкая начальная общеобразовательная школа"""	Россия, Белгородская область, Валуйский район, поселок Новоказацкое	0101000020E61000000E4FAF9465124340A0FA07910C1B4940
23606	1	1	1112	48276	\N	\N	50.254485000000003	с. Насоново, здание Насоновского сельского Дома культуры		0101000020E6100000F19D98F5621C43404A29E8F692204940
23605	1	1	1112	27015	\N	\N	50.296273999999997	с. Мандрово, здание Мандровского сельского Дома культуры		0101000020E6100000A2EE0390DA204340DA53724EEC254940
23591	1	1	1112	47976	\N	\N	50.011581999999997	с. Логачевка, здание Логачевского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Логачевка	0101000020E6100000412B306475FB4240739CDB847B014940
23602	1	1	1112	48201	\N	\N	50.236322000000001	с. Лавы, здание Лавинского сельского клуба	Россия, Белгородская область, Валуйский район, поселок Лавы	0101000020E6100000D158FB3BDBFB4240A4A99ECC3F1E4940
23599	1	1	1112	48141	\N	\N	50.10163	с. Кукуевка, здание Кукуевского сельского Дома культуры	Россия, Белгородская область, Валуйский район, поселок Кукуевка	0101000020E61000009C16BCE82BF6424070253B36020D4940
23597	1	1	1112	48083	\N	\N	50.319009999999999	с. Конопляновка, здание Конопляновского сельского Дома культуры		0101000020E61000000D37E0F3C3EE4240698CD651D5284940
23623	1	1	1112	27833	\N	\N	50.142809999999997	"с. Колыхалино, здание МДОУ ""Детский сад"""	Россия, Белгородская область, Валуйский район, поселок Колыхалино	0101000020E61000009B7631CD740B434058C51B9947124940
23601	1	1	1112	48172	\N	\N	50.245021000000001	с. Колосково, здание Колосковского сельского Дома культуры		0101000020E6100000FC36C478CDFF4240A7EA1ED95C1F4940
23588	1	1	1112	47926	\N	\N	50.132745999999997	с. Карабаново, здание Карабановского сельского клуба	Россия, Белгородская область, Валуйский район, поселок Карабаново	0101000020E6100000FE0DDAAB8FE94240605628D2FD104940
23594	1	1	1112	48026	\N	\N	50.258884999999999	"с. Казначеевка, здание МОУ ""Казначеевская средняя общеобразовательная школа"""	Россия, Белгородская область, Валуйский район, поселок Казначеевка	0101000020E61000009301A08A1BE142406536C82423214940
23593	1	1	1112	48006	\N	\N	50.241610999999999	с. Казинка, здание Казинского сельского Дома культуры		0101000020E610000099B9C0E5B1EA42404BADF71BED1E4940
23580	1	1	1112	47776	\N	\N	50.113439	с. Знаменка, здание Знаменского сельского Дома культуры		0101000020E610000076E272BC02034340A48B4D2B850E4940
23788	1	1	1112	47361	74898	\N	50.090021	село Долгое, Центральная, 48		0101000020E61000006ADFDC5F3DF44240037AE1CE850B4940
23590	1	1	1112	26274	\N	\N	50.045389	с. Двулучное, здание Двулученского сельского Дома культуры		0101000020E6100000518369183E024340904C874ECF054940
23592	1	1	1112	48005	\N	\N	49.947477999999997	п. Дальний, здание Дальненского сельского клуба	Россия, Белгородская область, Валуйский район, поселок Дальний	0101000020E6100000EE5C18E9450D4340F9D687F546F94840
23589	1	1	1112	47952	\N	\N	50.041784999999997	с. Герасимовка, здание Герасимовского сельского Дома культуры		0101000020E61000007636E49F191243404F3BFC3559054940
23575	1	1	1112	24814	33442	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Фурманова, 22"		0101000020E6100000B4024356B70E43402426A8E15B184940
23571	1	1	1112	24814	33385	\N	50.196750702353697	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Суржикова, 78"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E6100000AE2AFBAE08124340473A03232F194940
23570	1	1	1112	24814	33385	\N	50.1973567604633	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Суржикова, 30"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E61000009D9D0C8E921143407E5182FE42194940
23562	1	1	1112	24814	33350	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Ст. Разина, 10"		0101000020E6100000B4024356B70E43402426A8E15B184940
23574	1	1	1112	24814	33484	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Соколова, 48"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E6100000B4024356B70E43402426A8E15B184940
23565	1	1	1112	24814	33414	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Свердлова, 91"		0101000020E6100000B4024356B70E43402426A8E15B184940
23557	1	1	1112	24814	33782	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", с. Новая Симоновка, Речная, 2"		0101000020E6100000B4024356B70E43402426A8E15B184940
23569	1	1	1112	24814	33353	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Привокзальная площадь, 4"		0101000020E6100000B4024356B70E43402426A8E15B184940
23568	1	1	1112	24814	33232	\N	50.198190077732797	"Белгородская область, муниципальный район ""Город Валуйки и Валуйский район"", Никольская, 191"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E61000002785798F330D43407632384A5E194940
23566	1	1	1112	24814	33211	\N	50.2080882601485	"Белгородская область, муниципальный район ""Город Валуйки и Валуйский район"", Никольская, 1"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E6100000DF32A7CB620E43405358A9A0A21A4940
23573	1	1	1112	24814	33492	\N	50.190524384758199	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Курячего, 3"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E6100000062FFA0AD20E4340338D261763184940
23572	1	1	1112	24814	33355	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Котовского, 16"		0101000020E6100000B4024356B70E43402426A8E15B184940
23567	1	1	1112	24814	33312	\N	50.190303999999998	"Белгородская область, муниципальный район ""Город Валуйки и Валуйский район"", Комсомольская, 28"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E6100000B4024356B70E43402426A8E15B184940
23559	1	1	1112	24814	33209	\N	50.224525006758398	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Горького, 86"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E61000002F8B89CDC70943403411363CBD1C4940
23558	1	1	1112	24814	33209	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, Горького, 41"		0101000020E6100000B4024356B70E43402426A8E15B184940
23561	1	1	1112	24814	33259	\N	50.212774204865703	"муниципальный район ""Город Валуйки и Валуйский район"", 9 Января, 1"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E61000000611A969170D434035B8AD2D3C1B4940
23560	1	1	1112	24814	33259	\N	50.190303999999998	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, 9 Января, 43"		0101000020E6100000B4024356B70E43402426A8E15B184940
23564	1	1	1112	24814	33357	\N	50.2098825245086	"муниципальный район ""Город Валуйки и Валуйский район"", город Валуйки, 1 Мая, 51"	Россия, Белгородская область, Валуйский район, Валуйки	0101000020E61000003A950C00550C4340417E3672DD1A4940
23584	1	1	1112	47853	\N	\N	50.177591	"с. Бутырки, здание МОУ ""Бутырская основная общеобразовательная школа"""		0101000020E6100000EA07759142D342402F88484DBB164940
23585	1	1	1112	47869	\N	\N	50.149425000000001	с. Борки, здание Борчанского сельского Дома культуры		0101000020E6100000B91AD99596F14240371AC05B20134940
23506	1	1	1588	22380	33873	\N	50.383814999999998	Белгородская область, Белгородский район, село Черемошное, Мира, 6		0101000020E61000007DB08C0DDD3E42406C5B94D920314940
23913	1	1	1112	9972	33510	\N	50.255982000000003	Белгородская область, г. Бирюч, Красная, 22	Россия, Белгородская область, Валуйский район, поселок Бирюч	0101000020E6100000BBB4E1B034DC4240AE2EA704C4204940
23912	1	1	1112	9972	33510	\N	50.255982000000003	Белгородская область, г. Бирюч, Красная, 2		0101000020E6100000BBB4E1B034DC4240AE2EA704C4204940
23619	1	1	1112	48500	\N	\N	50.346178999999999	с. Басово, здание Басовского сельского клуба		0101000020E6100000E55FCB2BD7054340EFC7ED974F2C4940
23598	1	1	1112	48116	\N	\N	50.290531000000001	"с. Аркатово, здание МОУ ""Аркатовская начальная общеобразовательная школа"""	Россия, Белгородская область, Валуйский район, поселок Аркатово	0101000020E6100000404CC2853CEE4240B2BCAB1E30254940
23549	1	1	1727	24411	33689	\N	50.682913999999997	Белгородская обл., Борисовский район, с. Чуланово, ул. Мирная, 142		0101000020E6100000E67805A22701424082FDD7B969574940
23556	1	1	1727	24730	33384	\N	50.590587999999997	Белгородская обл., Борисовский район, с. Хотмыжск, ул. Данкова, 10		0101000020E6100000048E041A6CF041407CB43863984B4940
23553	1	1	1727	24595	33527	\N	50.624184	Белгородская обл., Борисовский район, с. Стригуны, ул. Набережная, 50а		0101000020E610000055A4C2D8420C4240DE57E542E54F4940
23554	1	1	1727	24595	33488	\N	50.624184	Белгородская обл., Борисовский район, с. Стригуны, ул. Комсомольская, 8а		0101000020E610000055A4C2D8420C4240DE57E542E54F4940
23551	1	1	1727	24489	33687	\N	50.659131000000002	Белгородская обл., Борисовский район, с. Октябрьская Готня, ул. Советская, 70		0101000020E61000006DCA15DEE5F24140D06394675E544940
23555	1	1	1727	54044	33798	\N	50.5521462162258	Белгородская обл., Борисовский район, с. Новоалександровка, ул. Новоалександровская, здание сельского клуба	Россия, Белгородская область, Борисовский район, поселок Ново-Александровка	0101000020E610000093533BC3D40C4240014F5AB8AC464940
23531	1	1	1727	23551	33691	\N	50.640757999999998	Белгородская обл., Борисовский район, с. Никитское, ул. Подлесовка, 13		0101000020E610000032CC09DAE4E441403F53AF5B04524940
23548	1	1	1727	24330	33526	\N	50.670014000000002	Белгородская обл., Борисовский район, с. Крюково, ул. Ленина, 55		0101000020E6100000F2785A7EE0FE41405BEECC04C3554940
23552	1	1	1727	24561	33765	\N	50.631880000000002	Белгородская обл., Борисовский район, с. Красный Куток, ул. Середенко, 6		0101000020E6100000F81BEDB8E1F541408D7F9F71E1504940
23550	1	1	1727	24452	33852	\N	50.698480000000004	Белгородская обл., Борисовский район, с. Зыбино, ул. Центральная, 2		0101000020E6100000236AA2CF470542407E74EACA67594940
23533	1	1	1727	23646	33547	\N	50.561763999999997	Белгородская обл., Борисовский район, с. Зозули, ул. Колхозная, 41а		0101000020E610000097A8DE1AD8F64140FA08FCE1E7474940
23545	1	1	1727	24217	33525	\N	50.504725999999998	Белгородская обл., Борисовский район, с. Грузское, ул. Центральная, 22		0101000020E6100000D236FE4465FF41406FB88FDC9A404940
23663	1	1	1727	23752	\N	\N	50.610353000000003	"село Борисовка, Здание ООО ""Русагро-Инвест"" Филиал ""Белогорье"""	Россия, Белгородская область, Борисовский район, поселок Борисовка	0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23543	1	1	1727	23752	33504	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, пл. Ушакова, 5а		0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23541	1	1	1727	23752	33382	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, пер. Дегтярева, 1		0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23544	1	1	1727	23752	33441	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, ул. Совхозная, 11		0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23539	1	1	1727	23752	33481	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, ул. Советская, 98		0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23538	1	1	1727	23752	33481	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, ул. Советская, 67		0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23536	1	1	1727	23752	33604	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, ул. Республиканская, 40	Россия, Белгородская область, Борисовский район, поселок Борисовка	0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23542	1	1	1727	23752	33383	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, ул. Первомайская, 13		0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23540	1	1	1727	23752	33502	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, ул. Грайворонская, 221а	Россия, Белгородская область, Борисовский район, поселок Борисовка	0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23537	1	1	1727	23752	33440	\N	50.610353000000003	Белгородская обл., Борисовский район, п. Борисовка, ул. Белгородская, 35		0101000020E61000003F6EBF7CB2004240FC010F0C204E4940
23534	1	1	1727	23663	33560	\N	50.501139999999999	Белгородская обл., Борисовский район, с. Березовка, ул. Садовая, 14		0101000020E6100000E9D495CFF2F24140D55B035B25404940
23535	1	1	1727	23663	33617	\N	50.501139999999999	Белгородская обл., Борисовский район, с. Березовка, ул. Колхозная, 28		0101000020E6100000E9D495CFF2F24140D55B035B25404940
23532	1	1	1727	23564	33310	\N	50.587842999999999	Белгородская обл., Борисовский район, с. Беленькое, ул. Первомайская, 66а		0101000020E6100000876C205D6CF641405D177E703E4B4940
23547	1	1	1727	24300	33853	\N	50.524755999999996	Белгородская обл., Борисовский район, с. Байцуры, ул. Молодежная, 67		0101000020E6100000D8BB3FDEAB0842409C3061342B434940
23530	1	1	1727	23462	33806	\N	50.649822999999998	Белгородская обл., Борисовский район, с. Акулиновка, ул. Центральная, 32		0101000020E610000073F56393FCEC414024986A662D534940
23447	1	1	1588	19374	33766	\N	50.600160000000002	Белгородская область, Белгородский район, село Ястребово, Кидалова, 41		0101000020E6100000F7CC920035614240062FFA0AD24C4940
23505	1	1	1588	22354	33251	\N	50.367552000000003	Белгородская область, Белгородский район, село Ясные Зори, Кирова, 31		0101000020E61000006688635DDC4042402ACAA5F10B2F4940
10354	6	58	135	45437	42623	\N	54.045064000000004	село Бобровка, Водопроводная, 2		0101000020E6100000944DB9C2BBDE4E400D1D3BA8C4054B40
23510	1	1	1588	22572	33804	\N	50.338974999999998	Белгородская область, Белгородский район, село Устинка, Центральная, 1		0101000020E6100000B933130CE73E4240AF946588632B4940
23499	1	1	1588	22045	33351	\N	50.504485000000003	Белгородская область, Белгородский район, село Таврово, Садовая, 41А		0101000020E61000007880272D5C4842404A29E8F692404940
23500	1	1	1588	22045	33477	\N	50.504485000000003	Белгородская область, Белгородский район, село Таврово, Комсомольская, 26Б		0101000020E61000007880272D5C4842404A29E8F692404940
23498	1	1	1588	22045	33477	\N	50.504485000000003	Белгородская область, Белгородский район, село Таврово, Комсомольская, 3		0101000020E61000007880272D5C4842404A29E8F692404940
23496	1	1	1588	21897	33501	\N	50.628424000000003	Белгородская область, Белгородский район, село Стрелецкое, Чапаева, 88		0101000020E6100000D82E6D382C3F4240C102983270504940
23497	1	1	1588	21897	33365	\N	50.628424000000003	Белгородская область, Белгородский район, село Стрелецкое, Краснооктябрьская, 148	Россия, Белгородская область, Белгородский район, поселок Стрелецкое	0101000020E6100000D82E6D382C3F4240C102983270504940
23495	1	1	1588	21897	33327	\N	50.628424000000003	Белгородская область, Белгородский район, село Стрелецкое, Королева, 36		0101000020E6100000D82E6D382C3F4240C102983270504940
23458	1	1	1588	19937	33851	\N	50.534691000000002	Белгородская область, Белгородский район, село Солохи, Школьная, 1А		0101000020E610000095F0845E7F144240973B33C170444940
23527	1	1	1588	23298	33415	\N	50.679080826436604	Белгородская область, Белгородский район, поселок Северный, Школьная, 52	Россия, Белгородская область, Белгородский район, поселок Северный	0101000020E61000009F3C2CD49A464240E02A4F20EC564940
23529	1	1	1588	23298	33193	\N	50.677075000000002	Белгородская область, Белгородский район, поселок Северный, Олимпийская, 14		0101000020E6100000B1A371A8DF47424038F8C264AA564940
23528	1	1	1588	23298	33193	\N	50.677225098475802	Белгородская область, Белгородский район, поселок Северный, Олимпийская, 12	Россия, Белгородская область, Белгородский район, поселок Северный	0101000020E6100000D00D4DD9E94742404D840D4FAF564940
23469	1	1	1588	20630	\N	\N	50.527240999999997	Белгородская область, Белгородский район, село Репное, Павлова, 1	Россия, Белгородская область, Белгородский район, поселок Репное	0101000020E610000077BB5E9A224042401F0E12A27C434940
23521	1	1	1588	22834	33479	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Школьная, 1		0101000020E610000072C0AE264F57424083A279008B444940
23522	1	1	1588	22834	33480	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Чехова, 1		0101000020E610000072C0AE264F57424083A279008B444940
23524	1	1	1588	22834	33417	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Филиппова, 5	Россия, Белгородская область, Белгородский район, поселок Разумное	0101000020E610000072C0AE264F57424083A279008B444940
23520	1	1	1588	22834	33417	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Филиппова, 2		0101000020E610000072C0AE264F57424083A279008B444940
23525	1	1	1588	22834	33600	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Станционная, ПМС-59		0101000020E610000072C0AE264F57424083A279008B444940
23519	1	1	1588	22834	33252	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Сиреневый бульвар, 1		0101000020E610000072C0AE264F57424083A279008B444940
23523	1	1	1588	22834	33208	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Ленина, 141		0101000020E610000072C0AE264F57424083A279008B444940
23516	1	1	1588	22834	33336	\N	50.535491999999998	Белгородская область, Белгородский район, поселок Разумное, Железнодорожная, 17		0101000020E610000072C0AE264F57424083A279008B444940
23518	1	1	1588	22834	33207	\N	50.536227526424298	Белгородская область, Белгородский район, поселок Разумное, Бельгина, 14	Россия, Белгородская область, Белгородский район, поселок Разумное	0101000020E610000020B58993FB57424089997D1EA3444940
23492	1	1	1588	21724	33439	\N	50.623189000000004	Белгородская область, Белгородский район, село Пушкарное, Центральная, 11		0101000020E6100000357C0BEBC63742400D1D3BA8C44F4940
23493	1	1	1588	21724	33249	\N	50.623189000000004	Белгородская область, Белгородский район, село Пушкарное, Пушкарская, 140А		0101000020E6100000357C0BEBC63742400D1D3BA8C44F4940
23450	1	1	1588	19525	33715	\N	50.696481353213798	Белгородская область, Белгородский район, село Петропавловка, Гагарина, 51	Россия, Белгородская область, Белгородский район, поселок Петропавловка	0101000020E6100000AE9D28098954424087A4164A26594940
23487	1	1	1588	21501	33683	\N	50.378025000000001	Белгородская область, Белгородский район, село Петровка, Трудовая, 23		0101000020E61000003B8F8AFF3B34424003098A1F63304940
23457	1	1	1588	19923	33797	\N	50.541857999999998	Белгородская область, Белгородский район, село Орловка, переулок Лесной, 9А		0101000020E6100000CB85CABF961F4240B9895A9A5B454940
23511	1	1	1588	22649	33306	\N	50.443930999999999	Белгородская область, Белгородский район, поселок Октябрьский, Чернышевского, 2		0101000020E6100000B8B06EBC3B2E42401D5723BBD2384940
23513	1	1	1588	22649	33309	\N	50.443930999999999	Белгородская область, Белгородский район, поселок Октябрьский, Привокзальная, 5		0101000020E6100000B8B06EBC3B2E42401D5723BBD2384940
23514	1	1	1588	22649	33307	\N	50.443930999999999	Белгородская область, Белгородский район, поселок Октябрьский, Матросова, 2		0101000020E6100000B8B06EBC3B2E42401D5723BBD2384940
23515	1	1	1588	22649	33546	\N	50.443930999999999	Белгородская область, Белгородский район, поселок Октябрьский, Кутузова, 4А		0101000020E6100000B8B06EBC3B2E42401D5723BBD2384940
23462	1	1	1588	20199	33582	\N	50.475091999999997	Белгородская область, Белгородский район, село Головино, Катульского, 47		0101000020E61000000A4B3CA06C384240AD4B8DD0CF3C4940
23512	1	1	1588	\N	33478	\N	50.453711751443997	Белгородская область, Белгородский район, поселок Октябрьский, Коммунистическая, 1	Россия, Белгородская область, Белгородский район	0101000020E61000009E279EB3052E4240C1E61C3C133A4940
23490	1	1	1588	21635	33379	\N	50.652062000000001	Белгородская область, Белгородский район, поселок Новосадовый, Лейтенанта Павлова, 1		0101000020E61000006138D73043554240707B82C476534940
23463	1	1	1588	20256	33684	\N	50.447980000000001	Белгородская область, Белгородский район, село Новая Нелидовка, Зеленая, 93		0101000020E61000006E15C440D74242408CA19C6857394940
23489	1	1	1588	21560	33462	\N	50.433151000000002	Белгородская область, Белгородский район, село Никольское, Школьная, 3		0101000020E610000088855AD3BC494240679DF17D71374940
23488	1	1	1588	21560	33206	\N	50.433151000000002	Белгородская область, Белгородский район, село Никольское, Советская, 26Б		0101000020E610000088855AD3BC494240679DF17D71374940
23456	1	1	1588	19859	33725	\N	50.479585999999998	Белгородская область, Белгородский район, село Николаевка, Николаевка, 57	Россия, Белгородская область, Белгородский район, поселок Николаевка	0101000020E6100000AD4D637B2D2042404ACFF412633D4940
23478	1	1	1588	21099	33779	\N	50.488939999999999	Белгородская область, Белгородский район, село Нижний Ольшанец, Придорожная, 8		0101000020E6100000F1D4230D6E57424066DAFE95953E4940
23508	1	1	1588	22488	33805	\N	50.356909000000002	Белгородская область, Белгородский район, село Нечаевка, Мира, 61		0101000020E6100000FA9B5088804D4240F452B131AF2D4940
23472	1	1	1588	20759	33871	\N	50.342551	Белгородская область, Белгородский район, село Нехотеевка, Зеленая, 35	Россия, Белгородская область, Белгородский район, поселок Нехотеевка	0101000020E6100000EAB303AE2B264240261B0FB6D82B4940
23446	1	1	1588	19340	33542	\N	50.631875000000001	Белгородская область, Белгородский район, село Мясоедово, Трунова, 86		0101000020E6100000DB519CA38E6642407B14AE47E1504940
23486	1	1	1588	53989	33500	\N	50.370826999999998	Белгородская область, Белгородский район, поселок Малиновка, Мирная, 9	Россия, Белгородская область, Белгородский район, поселок Малиновский	0101000020E610000019ADA3AA09344240A5BC5642772F4940
23483	1	1	1588	21127	33476	\N	50.519046000000003	Белгородская область, Белгородский район, поселок Майский, Садовая, 12Б		0101000020E61000004F78094E7D3A4240508F6D1970424940
23484	1	1	1588	21127	33634	\N	50.519046000000003	Белгородская область, Белгородский район, поселок Майский, Пионерская, 2		0101000020E61000004F78094E7D3A4240508F6D1970424940
23485	1	1	1588	21127	33192	\N	50.519046000000003	Белгородская область, Белгородский район, поселок Майский, Кирова, 6		0101000020E61000004F78094E7D3A4240508F6D1970424940
23480	1	1	1588	21127	33192	\N	50.519046000000003	Белгородская область, Белгородский район, поселок Майский, Кирова, 16А		0101000020E61000004F78094E7D3A4240508F6D1970424940
23481	1	1	1588	21127	33246	\N	50.519046000000003	Белгородская область, Белгородский район, поселок Майский, Вавилова, 16		0101000020E61000004F78094E7D3A4240508F6D1970424940
23479	1	1	1588	21127	33246	\N	50.519046000000003	Белгородская область, Белгородский район, поселок Майский, Вавилова, 1		0101000020E61000004F78094E7D3A4240508F6D1970424940
23477	1	1	1588	21032	33305	\N	50.524709999999999	Белгородская область, Белгородский район, село Крутой Лог, Октябрьская, 21		0101000020E61000004E637B2DE85D42402CF180B229434940
23476	1	1	1588	20997	33540	\N	50.372297000000003	Белгородская область, Белгородский район, село Красный Хутор, Калинина, 3		0101000020E61000002BDB87BCE520424010B3976DA72F4940
23474	1	1	1588	20865	33616	\N	50.461320000000001	Белгородская область, Белгородский район, село Красный Октябрь, Победы, 3		0101000020E61000002655DB4DF0294240D07EA4880C3B4940
23475	1	1	1588	20865	33244	\N	50.461320000000001	Белгородская область, Белгородский район, село Красный Октябрь, Гагарина, 2А		0101000020E61000002655DB4DF0294240D07EA4880C3B4940
23320	1	1	1588	53984	33482	\N	50.568326633018501	город Белгород, Ворошилова, 2Б	Россия, Белгородская область, Белгородский район, поселок Красное	0101000020E6100000520ABABDA443424086376BF0BE484940
23503	1	1	1588	22284	33800	\N	50.739106999999997	Белгородская область, Белгородский район, село Киселево, Центральная, 14А		0101000020E61000009D853DEDF0594240519FE40E9B5E4940
23449	1	1	1588	19502	33649	\N	50.632691999999999	Белгородская область, Белгородский район, село Зеленая Поляна, Донецкая, 3		0101000020E61000009B374E0AF35042406D382C0DFC504940
23471	1	1	1588	20745	33522	\N	50.313206000000001	Белгородская область, Белгородский район, село Журавлевка, Коммунистическая, 7		0101000020E6100000438D4292592942409B745B2217284940
23470	1	1	1588	20650	33544	\N	50.718342	Белгородская область, Белгородский район, село Ерик, Советская, 2А		0101000020E61000002711E15F04414240EFAB72A1F25B4940
23468	1	1	1588	53971	33190	\N	50.535136999999999	Белгородская область, Белгородский район, Поселок Дубовое, Ягодная, 3А	Россия, Белгородская область, Белгородский район, колхоз Дубовое	0101000020E610000044C362D4B54A424095F0845E7F444940
23466	1	1	1588	53971	33250	\N	50.537111508610799	Белгородская область, Белгородский район, Поселок Дубовое, Лесная, 2	Россия, Белгородская область, Белгородский район, колхоз Дубовое	0101000020E6100000E4857478084B424003250516C0444940
23465	1	1	1588	53971	33250	\N	50.535136999999999	Белгородская область, Белгородский район, поселок Дубовое, Лесная, 2	Россия, Белгородская область, Белгородский район, колхоз Дубовое	0101000020E610000044C362D4B54A424095F0845E7F444940
23494	1	1	1588	21829	33524	\N	50.647629999999999	Белгородская область, Белгородский район, село Драгунское, Драгунская, 193А		0101000020E610000029ECA2E88139424049F4328AE5524940
23461	1	1	1588	20123	33788	\N	50.515512000000001	Белгородская область, Белгородский район, село Долбино, Школьная, 21А		0101000020E6100000EBA86A82A83342400859164CFC414940
10369	6	58	135	24420	43848	\N	54.006422000000001	поселок Берлин, Школьная, 27		0101000020E6100000675F79909E984E40CAFCA36FD2004B40
23509	1	1	1588	22524	33809	\N	50.309466999999998	Белгородская область, Белгородский район, село Вергилевка, Центральная, 24		0101000020E6100000ED2B0FD2534A42407A185A9D9C274940
23459	1	1	1588	20025	33651	\N	50.493105999999997	Белгородская область, Белгородский район, село Веселая Лопань, Заводская, 1А		0101000020E610000038DA71C3EF3042400EBBEF181E3F4940
23460	1	1	1588	20025	33499	\N	50.493105999999997	Белгородская область, Белгородский район, село Веселая Лопань, Гагарина, 7Б		0101000020E610000038DA71C3EF3042400EBBEF181E3F4940
23464	1	1	1588	20318	33848	\N	50.423493000000001	Белгородская область, Белгородский район, село Варваровка, Зеленая, 55		0101000020E610000098A432C51C344240DF8AC40435364940
23507	1	1	1588	22435	33723	\N	50.369073999999998	Белгородская область, Белгородский район, село Бочковка, Советская, 69		0101000020E61000004B22FB20CB484240E6E61BD13D2F4940
23491	1	1	1588	21699	33523	\N	50.615988000000002	Белгородская область, Белгородский район, село Ближняя Игуменка, Центральная, 10		0101000020E61000007DCC07043A5B42403E5DDDB1D84E4940
23455	1	1	1588	54046	33808	\N	50.578560000000003	Белгородская область, Белгородский район, село Ближнее, Луговой переулок, 9а	Россия, Белгородская область, Белгородский район, поселок Ближний	0101000020E6100000FC3905F9D93042400B630B410E4A4940
23452	1	1	1588	19656	\N	\N	50.529038999999997	Белгородская область, Белгородский район, село Бессоновка, Партизанская, 8А	Россия, Белгородская область, Белгородский район, поселок Бессоновка	0101000020E6100000BF823463D12642407EA7C98CB7434940
23453	1	1	1588	19656	33187	\N	50.529038999999997	Белгородская область, Белгородский район, село Бессоновка, Партизанская, 4А		0101000020E6100000BF823463D12642407EA7C98CB7434940
23995	1	1	1588	19450	\N	\N	50.678738904803502	Белгородская область, Новооскольский район, село Беломестное, сельский Дом культуры	Россия, Белгородская область, Белгородский район, поселок Беломестное	0101000020E6100000E06932E36D51424087C267EBE0564940
23451	1	1	1588	19450	33437	\N	50.679541	Белгородская область, Белгородский район, село Беломестное, Центральная, 64		0101000020E61000004419AA622A51424044A51133FB564940
23448	1	1	1588	19450	33437	\N	50.679541	Белгородская область, Белгородский район, село Беломестное, Центральная, 13		0101000020E61000004419AA622A51424044A51133FB564940
23445	1	1	1588	19265	33186	\N	50.579160999999999	Белгородская область, Белгородский район, село Беловское, Центральная, 1Б		0101000020E610000046088F368E5E4240300F99F2214A4940
23526	1	1	7306	53978	33262	\N	50.677075000000002	Белгородская область, Белгородский район, поселок Северный, Школьная, 35		0101000020E6100000B1A371A8DF47424038F8C264AA564940
23297	1	1	1165	12069	\N	\N	50.527734000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Щербаково, Здание дома культуры		0101000020E61000009E0AB8E7F95143405F7EA7C98C434940
23315	1	1	1165	12920	\N	\N	50.439076999999997	Белгородская область, Алексеевский район и г. Алексеевка, хутор Хрещатый, Здание дома культуры		0101000020E6100000F0A31AF67B48434080B6D5AC33384940
23313	1	1	1165	12831	\N	\N	50.555784000000003	Белгородская область, Алексеевский район и г. Алексеевка, село Хлевище, Здание школы	Россия, Белгородская область, Алексеевский район, поселок Хлевище	0101000020E6100000465D6BEF53454340EED11BEE23474940
23288	1	1	1165	54043	\N	\N	50.519992531738403	Белгородская область, Алексеевский район и г. Алексеевка, село Тютюниково, Здание администрации сельского поселения	Россия, Белгородская область, Алексеевский район, поселок Тютюнниково	0101000020E6100000FD135CACA8874340109370218F424940
23296	1	1	1165	12049	\N	\N	50.494562000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Теплинка, Здание школы		0101000020E61000000DE36E10AD51434014ECBFCE4D3F4940
23310	1	1	1165	12695	\N	\N	50.785907000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Студеный колодец, Здание клуба		0101000020E6100000ABE80FCD3C6943404759BF9998644940
23312	1	1	1165	12801	\N	\N	50.332949999999997	Белгородская область, Алексеевский район и г. Алексеевка, село Советское, Здание дома культуры		0101000020E61000005776C1E09A814340029A081B9E2A4940
23277	1	1	1165	11125	\N	\N	50.474747999999998	Белгородская область, Алексеевский район и г. Алексеевка, село Славгородское, Здание дома культуры	Россия, Белгородская область, Алексеевский район, поселок Славгородское	0101000020E6100000693BA6EECA724340B3EBDE8AC43C4940
23293	1	1	1165	11882	\N	\N	50.598067	Белгородская область, Алексеевский район и г. Алексеевка, хутор Сидоркин, Здание клуба	Россия, Белгородская область, Алексеевский район, поселок Сидоркин	0101000020E6100000261DE560364D43408EE89E758D4C4940
23309	1	1	1165	12671	\N	\N	50.779192000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Репенка, Здание дома культуры		0101000020E61000004CC3F0113163434005A73E90BC634940
23308	1	1	1165	12606	\N	\N	50.712719	Белгородская область, Алексеевский район и г. Алексеевка, село Подсереднее, Здание администрации сельского поселения		0101000020E61000009ED0EB4FE2474340711E4E603A5B4940
23287	1	1	1165	11605	\N	\N	50.611336000000001	Белгородская область, Алексеевский район и г. Алексеевка, село Пирогово, Здание клуба		0101000020E610000024B726DD96824340096F0F42404E4940
23307	1	1	1165	12563	\N	\N	50.676059000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Мухоудеровка, Здание дома культуры		0101000020E61000004E0CC9C9C46F43404F95EF1989564940
23304	1	1	1165	12404	\N	\N	50.523232999999998	Белгородская область, Алексеевский район и г. Алексеевка, село Меняйлово, Здание дома культуры		0101000020E61000000EBE30992A6043400F98874CF9424940
23302	1	1	1165	12327	\N	\N	50.608535000000003	Белгородская область, Алексеевский район и г. Алексеевка, село Матрено-Гезово, Здание дома культуры		0101000020E61000005FB87361A46F434056BC9179E44D4940
23299	1	1	1165	12157	\N	\N	50.477837999999998	Белгородская область, Алексеевский район и г. Алексеевка, село Луценково, Здание школы		0101000020E61000003201BF46927A43409D64ABCB293D4940
23295	1	1	1165	11926	\N	\N	50.329805	Белгородская область, Алексеевский район и г. Алексеевка, село Красное, Здание клуба		0101000020E610000043E21E4B1F6843405587DC0C372A4940
23294	1	1	1165	11926	\N	\N	50.329805	Белгородская область, Алексеевский район и г. Алексеевка, село Красное, Здание дома культуры		0101000020E610000043E21E4B1F6843405587DC0C372A4940
23298	1	1	1165	12144	\N	\N	50.495781999999998	Белгородская область, Алексеевский район и г. Алексеевка, хутор Копанец, Здание клуба		0101000020E6100000EC681CEA7775434005F9D9C8753F4940
23306	1	1	1165	12517	\N	\N	50.647384000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Колтуновка, Здание клуба		0101000020E6100000CCF09F6EA064434012FA997ADD524940
23282	1	1	1165	11345	\N	\N	50.416519999999998	Белгородская область, Алексеевский район и г. Алексеевка, село Ковалево, Здание дома культуры		0101000020E61000007555A01683654340A110018750354940
23314	1	1	1165	12894	\N	\N	50.480697999999997	Белгородская область, Алексеевский район и г. Алексеевка, село Камышеватое, Здание дома культуры	Россия, Белгородская область, Алексеевский район, поселок Камышеватое	0101000020E61000003562669FC748434055A01683873D4940
23280	1	1	1165	11247	\N	\N	50.336773000000001	Белгородская область, Алексеевский район и г. Алексеевка, село Калитва, Здание дома культуры		0101000020E61000002C82FFAD647743408196AE601B2B4940
23292	1	1	1165	11810	\N	\N	50.647247	Белгородская область, Алексеевский район и г. Алексеевка, село Ильинка, Здание дома культуры		0101000020E6100000C3633F8BA54C434091B75CFDD8524940
23291	1	1	1165	11728	\N	\N	50.713112000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Иловка, Здание администрации сельского поеселения		0101000020E610000033333333335143404D310741475B4940
23290	1	1	1165	11728	\N	\N	50.713112000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Иловка, Здание дома культуры		0101000020E610000033333333335143404D310741475B4940
23286	1	1	1165	11532	\N	\N	50.572611000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Иващенково, Здание дома культуры		0101000020E6100000DB166536C8844340392A37514B494940
23311	1	1	1165	12753	\N	\N	50.372917999999999	Белгородская область, Алексеевский район и г. Алексеевка, село Запольное, Здание ФАП		0101000020E61000004FE960FD9F7F43407C0BEBC6BB2F4940
23285	1	1	1165	11499	\N	\N	50.424720999999998	Белгородская область, Алексеевский район и г. Алексеевка, село Жуково, Здание дома культуры		0101000020E61000005051F52B9D5143405376FA415D364940
24227	1	1	1165	46930	33490	\N	50.748756999999998	с. Городище, Революционная,52, Петровский дом культуры		0101000020E610000094C2BCC7995C434056D3F544D75F4940
23283	1	1	1165	11427	\N	\N	50.729546999999997	Белгородская область, Алексеевский район и г. Алексеевка, село Глуховка, Здание школы		0101000020E61000003ED00A0C595943408CF2CCCB615D4940
23281	1	1	1165	11303	\N	\N	50.454611	Белгородская область, Алексеевский район и г. Алексеевка, село Гарбузово, Здание дома культуры		0101000020E6100000BE86E0B88C61434070B378B1303A4940
23301	1	1	1165	12274	\N	\N	50.589072999999999	Белгородская область, Алексеевский район и г. Алексеевка, село Воробьево, Здание клуба		0101000020E6100000C85F5AD4277B434072FA7ABE664B4940
23279	1	1	1165	11209	\N	\N	50.374428999999999	Белгородская область, Алексеевский район и г. Алексеевка, село Варваровка, Здание дома культуры		0101000020E6100000F0A2AF20CD6A434045D61A4AED2F4940
23284	1	1	1165	11436	\N	\N	50.411911000000003	Белгородская область, Алексеевский район и г. Алексеевка, село Бубликово, Здание клуба		0101000020E61000008C153598865543406CEEE87FB9344940
23300	1	1	1165	12220	\N	\N	50.533647999999999	Белгородская область, Алексеевский район и г. Алексеевка, село Божково, Здание школы	Россия, Белгородская область, Алексеевский район, поселок Божково	0101000020E6100000DD4598A25C764340B4C9E1934E444940
23305	1	1	1165	12467	\N	\N	50.695678999999998	Белгородская область, Алексеевский район и г. Алексеевка, село Ближнее Чесночное, Здание клуба		0101000020E6100000AEF36F97FD6C4340CAC16C020C594940
23278	1	1	1165	11161	\N	\N	50.788907999999999	Белгородская область, Алексеевский район и г. Алексеевка, село Афанасьевка, здание дома культуры		0101000020E610000092EBA694D74C4340C1C6F5EFFA644940
23303	1	1	1165	12396	\N	\N	50.520524000000002	Белгородская область, Алексеевский район и г. Алексеевка, село Алексеенково, Здание клуба	Россия, Белгородская область, Алексеевский район, поселок Алексеенково	0101000020E610000030849CF7FF6943403D64CA87A0424940
23274	1	1	1165	54024	33700	\N	50.661249916282998	Белгородская область, г. Алексеевка, поселок Опытная станция	Россия, Белгородская область, Алексеевский район	0101000020E6100000B58AFED0CC554340713D0AD7A3544940
23276	1	1	1165	11060	\N	\N	50.470241999999999	Белгородская область, Алексеевский район и г. Алексеевка, село  Алейниково, Здание дома культуры		0101000020E61000009757AEB7CD6A4340529ACDE3303C4940
57402	1	\N	\N	1	\N	\N	55.742904000000003	город Москва, ЗАО, район Дорогомилово, Киевский вокзал	Россия, Москва, площадь Киевского Вокзала, 1	0101000020E6100000F913950D6BC84240A708707A17DF4B40
57369	1	\N	\N	1	\N	\N	55.976992000000003	город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 818	Россия, Москва, Зеленоград, к818	0101000020E6100000F8DF4A766C984240113AE8120EFD4B40
57367	1	\N	\N	1	\N	\N	55.985106000000002	город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 912	Россия, Москва, Зеленоград, к912	0101000020E61000004F04711E4E984240F48B12F417FE4B40
57366	1	\N	\N	1	\N	\N	55.978543000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 844, адрес УИК: Зеленоград, корп. 828	Россия, Москва, Зеленоград, к844	0101000020E6100000F2086EA46C974240685DA3E540FD4B40
57365	1	\N	\N	1	\N	\N	55.984385000000003	Адрес помещения для голосования: город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 921А, адрес УИК: Зеленоград, корп. 904	Россия, Москва, Зеленоград, к921а	0101000020E610000059A31EA2D197424024D6E25300FE4B40
57364	1	\N	\N	1	\N	\N	55.984385000000003	Адрес помещения для голосования: город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 921А, адрес УИК: Зеленоград, корп. 901	Россия, Москва, Зеленоград, к921а	0101000020E610000059A31EA2D197424024D6E25300FE4B40
57363	1	\N	\N	1	\N	\N	55.982405999999997	Адрес помещения для голосования: город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 913А, адрес УИК: Зеленоград, корп. 909	Россия, Москва, Зеленоград, к913а	0101000020E61000002B1213D4F097424074B2D47ABFFD4B40
57362	1	\N	\N	1	\N	\N	55.982405999999997	Адрес помещения для голосования: город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 913А, адрес УИК: Зеленоград, корп. 904	Россия, Москва, Зеленоград, к913а	0101000020E61000002B1213D4F097424074B2D47ABFFD4B40
57361	1	\N	\N	1	\N	\N	55.978543000000002	город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 844	Россия, Москва, Зеленоград, к844	0101000020E6100000F2086EA46C974240685DA3E540FD4B40
57360	1	\N	\N	1	\N	\N	55.976992000000003	Адрес помещения для голосования: город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 818, адрес УИК: Зеленоград, корп. 802	Россия, Москва, Зеленоград, к818	0101000020E6100000F8DF4A766C984240113AE8120EFD4B40
57359	1	\N	\N	1	\N	\N	55.993223	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп 1214, адрес УИК: Зеленоград, корп. 1209	Россия, Москва, Зеленоград, к1214	0101000020E6100000FDF9B660A9984240485167EE21FF4B40
57358	1	\N	\N	1	\N	\N	55.993223	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1214, адрес УИК: Зеленоград, корп. 1209	Россия, Москва, Зеленоград, к1214	0101000020E6100000FDF9B660A9984240485167EE21FF4B40
57357	1	\N	\N	1	\N	\N	55.994013000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, адрес УИК: Зеленоград, корп. 1140	Россия, Москва, Зеленоград, к1140	0101000020E610000010B22C98F8954240416667D13BFF4B40
57355	1	\N	\N	1	\N	\N	55.998685000000002	город Москва, ЗелАО, район Силино, Зеленоград, корп. 1128	Россия, Москва, Зеленоград, к1128	0101000020E6100000EA944737C2964240BD00FBE8D4FF4B40
57354	1	\N	\N	1	\N	\N	55.998685000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1128, адрес УИК: Зеленоград, корп. 1124	Россия, Москва, Зеленоград, к1128	0101000020E6100000EA944737C2964240BD00FBE8D4FF4B40
57353	1	\N	\N	1	\N	\N	55.998685000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1128, адрес УИК: Зеленоград, корп. 1116	Россия, Москва, Зеленоград, к1128	0101000020E6100000EA944737C2964240BD00FBE8D4FF4B40
57352	1	\N	\N	1	\N	\N	55.997185000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1115, адрес УИК: Зеленоград, корп. 1102	Россия, Москва, Зеленоград, к1115	0101000020E610000053B29C84D2974240E88711C2A3FF4B40
57351	1	\N	\N	1	\N	\N	55.997185000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1115, сдрес УИК: Зеленоград, корп. 1108	Россия, Москва, Зеленоград, к1115	0101000020E610000053B29C84D2974240E88711C2A3FF4B40
57350	1	\N	\N	1	\N	\N	55.997185000000002	город Москва, ЗелАО, район Силино, Зеленоград, корп. 1115	Россия, Москва, Зеленоград, к1115	0101000020E610000053B29C84D2974240E88711C2A3FF4B40
57349	1	\N	\N	1	\N	\N	55.997185000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1115, адрес УИК: Зеленоград, корп. 1105	Россия, Москва, Зеленоград, к1115	0101000020E610000053B29C84D2974240E88711C2A3FF4B40
57348	1	\N	\N	1	\N	\N	55.987437	город Москва, ЗелАО, район Силино, Зеленоград, корп. 1017	Россия, Москва, Зеленоград, к1017	0101000020E6100000F052EA927196424020EEEA5564FE4B40
57347	1	\N	\N	1	\N	\N	55.987437	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1017, адрес УИК: Зеленоград, корп. 1003	Россия, Москва, Зеленоград, к1017	0101000020E6100000F052EA927196424020EEEA5564FE4B40
57346	1	\N	\N	1	\N	\N	55.987352000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1016, адрес УИК: Зеленоград, корп. 1014А	Россия, Москва, Зеленоград, к1016	0101000020E6100000E2934E2498964240F2D1E28C61FE4B40
57345	1	\N	\N	1	\N	\N	55.987352000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1016, адрес УИК: Зеленоград, корп. 1003	Россия, Москва, Зеленоград, к1016	0101000020E6100000E2934E2498964240F2D1E28C61FE4B40
57344	1	\N	\N	1	\N	\N	55.987352000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1016, адрес УИК: Зеленоград, корп. 1011	Россия, Москва, Зеленоград, к1016	0101000020E6100000E2934E2498964240F2D1E28C61FE4B40
57343	1	\N	\N	1	\N	\N	55.991430000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 621А, адрес УИК: Зеленоград, корп. 704	Россия, Москва, Зеленоград, к621а	0101000020E610000085402E71E49D4240FB22A12DE7FE4B40
56256	1	\N	\N	1	12521	\N	55.702181000000003	город Москва, ЮВАО, район Кузьминки, Юных ленинцев ул, дом 45, корп. 2		0101000020E610000057EE056685E04240B16F2711E1D94B40
57342	1	\N	\N	1	\N	\N	55.991430000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 621А, адрес УИК: Зеленоград, корп. 613	Россия, Москва, Зеленоград, к621а	0101000020E610000085402E71E49D4240FB22A12DE7FE4B40
57341	1	\N	\N	1	\N	\N	55.991565999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 603А, адрес УИК: Зеленоград, корп. 613	Россия, Москва, Зеленоград, к603а	0101000020E6100000EAEA8EC5369D4240ABE97AA2EBFE4B40
57340	1	\N	\N	1	\N	\N	55.990056000000003	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 529, адрес УИК: Зеленоград, корп. 528	Россия, Москва, Зеленоград, к529	0101000020E610000095641D8EAEA04240B39AAE27BAFE4B40
57339	1	\N	\N	1	\N	\N	55.998055999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 509, адрес УИК: Зеленоград, корп. 514А	Россия, Москва, Зеленоград, к509	0101000020E610000010E7E104A69D4240CDC98B4CC0FF4B40
57338	1	\N	\N	1	\N	\N	55.994280000000003	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 344А, адрес УИК: Зеленоград, корп. 301Б	Россия, Москва, Зеленоград, к344а	0101000020E610000099D711876C9C42409088299144FF4B40
57337	1	\N	\N	1	\N	\N	55.997985	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 314, адрес УИК: Зеленоград, корп. 302А	Россия, Москва, Зеленоград, к314	0101000020E6100000F3FFAA23479C42400473F4F8BDFF4B40
57336	1	\N	\N	1	\N	\N	55.997985	Адрес помещения для голосования: город Москва, ЗелАО, район Савелки, Зеленоград, корп. 314, адрес УИК: Зеленоград, корп. 301Б	Россия, Москва, Зеленоград, к314	0101000020E6100000F3FFAA23479C42400473F4F8BDFF4B40
57335	1	\N	\N	1	\N	\N	55.993876999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Матушкино, Зеленоград, корп. 429А, адрес УИК: Зеленоград, корп. 410	Россия, Москва, Зеленоград, к429а	0101000020E610000049F59D5F949A4240909F8D5C37FF4B40
57334	1	\N	\N	1	\N	\N	55.993876999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Матушкино, Зеленоград, корп. 429А, адрес УИК: Зеленоград, корп. 441	Россия, Москва, Зеленоград, к429а	0101000020E610000049F59D5F949A4240909F8D5C37FF4B40
57331	1	\N	\N	1	\N	\N	56.002671999999997	Адрес помещения для голосования: город Москва, ЗелАО, район Матушкино, Зеленоград, корп. 222А, адрес УИК: Зеленоград, корп. 250	Россия, Москва, Зеленоград, к222а	0101000020E61000006CEBA7FFAC994240B54E5C8E57004C40
57330	1	\N	\N	1	\N	\N	56.006301000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Матушкино, Зеленоград, корп. 163, адрес УИК: Зеленоград, корп. 107Б	Россия, Москва, Зеленоград, к163	0101000020E610000066136058FE9A42404F779E78CE004C40
57329	1	\N	\N	1	\N	\N	56.005903000000004	Адрес помещения для голосования: город Москва, ЗелАО, район Матушкино, Зеленоград, корп. 142, адрес УИК: Зеленоград, корп. 119	Россия, Москва, Зеленоград, к142	0101000020E610000092CD55F31C9B424062F9F36DC1004C40
57328	1	\N	\N	1	\N	\N	55.973453319205298	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 2031, адрес УИК: Зеленоград, корпус 2034		0101000020E6100000EBFF1CE6CB954240B7989F1B9AFC4B40
57327	1	\N	\N	1	\N	\N	55.973112999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 2011, адрес УИК: Зеленоград, корпус 2034	Россия, Москва, Зеленоград, к2011	0101000020E61000002BDA1CE736954240FE277FF78EFC4B40
57323	1	\N	\N	1	\N	\N	55.982199999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1816, адрес УИК: Зеленоград, корпус 1807	Россия, Москва, Зеленоград, к1816	0101000020E6100000B5A338471D954240CB10C7BAB8FD4B40
57320	1	\N	\N	1	\N	\N	55.975183999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1642, адрес УИК: Зеленоград, корпус 1619	Россия, Москва, Зеленоград, к1642	0101000020E61000005EBC1FB75F9442408ECA4DD4D2FC4B40
57319	1	\N	\N	1	\N	\N	55.972442999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1632, адрес УИК: Зеленоград, корпус 1620	Россия, Москва, Зеленоград, к1632	0101000020E610000048895DDBDB934240B01C210379FC4B40
57318	1	\N	\N	1	\N	\N	55.972442999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1632, адрес УИК: Зеленоград, корпус 1604	Россия, Москва, Зеленоград, к1632	0101000020E610000048895DDBDB934240B01C210379FC4B40
57317	1	\N	\N	1	\N	\N	55.975515999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1609, адрес УИК: Зеленоград, корпус 1615	Россия, Москва, Зеленоград, к1609	0101000020E61000009AB67F65A5934240C45C52B5DDFC4B40
57316	1	\N	\N	1	\N	\N	55.975515999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1609, адрес УИК: Зеленоград, корпус 1623	Россия, Москва, Зеленоград, к1609	0101000020E61000009AB67F65A5934240C45C52B5DDFC4B40
57315	1	\N	\N	1	\N	\N	55.975515999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1609, адрес УИК: Зеленоград, корпус 1602	Россия, Москва, Зеленоград, к1609	0101000020E61000009AB67F65A5934240C45C52B5DDFC4B40
57314	1	\N	\N	1	\N	\N	55.981952999999997	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1530, адрес УИК: Зеленоград, корпус 1507	Россия, Москва, Зеленоград, к1530	0101000020E61000001DE5603601944240C39ACAA2B0FD4B40
57313	1	\N	\N	1	\N	\N	55.981006000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1555, адрес УИК: Зеленоград, корпус 1524	Россия, Москва, Зеленоград, к1555	0101000020E6100000F0FD0DDAAB9342400397C79A91FD4B40
57312	1	\N	\N	1	\N	\N	55.981006000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1555, адрес УИК: Зеленоград, корпус 1557	Россия, Москва, Зеленоград, к1555	0101000020E6100000F0FD0DDAAB9342400397C79A91FD4B40
57311	1	\N	\N	1	\N	\N	55.981952999999997	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1530, адрес УИК: Зеленоград, корпус 1529	Россия, Москва, Зеленоград, к1530	0101000020E61000001DE5603601944240C39ACAA2B0FD4B40
57310	1	\N	\N	1	\N	\N	55.981952999999997	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1530, адрес УИК: Зеленоград, корпус 1520	Россия, Москва, Зеленоград, к1530	0101000020E61000001DE5603601944240C39ACAA2B0FD4B40
57309	1	\N	\N	1	\N	\N	55.981006000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1555, адрес УИК: Зеленоград, корпус 1552	Россия, Москва, Зеленоград, к1555	0101000020E6100000F0FD0DDAAB9342400397C79A91FD4B40
57308	1	\N	\N	1	\N	\N	55.981006000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1555, адрес УИК: Зеленоград, корпус 1505	Россия, Москва, Зеленоград, к1555	0101000020E6100000F0FD0DDAAB9342400397C79A91FD4B40
57307	1	\N	\N	1	\N	\N	55.979903	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1556, адрес УИК: Зеленоград, корпус 1529	Россия, Москва, Зеленоград, к1556	0101000020E610000043588D25AC9342404B2025766DFD4B40
57306	1	\N	\N	1	\N	\N	55.979903	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1556, адрес УИК: Зеленоград, корпус 1557	Россия, Москва, Зеленоград, к1556	0101000020E610000043588D25AC9342404B2025766DFD4B40
57305	1	\N	\N	1	\N	\N	55.979903	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1556, адрес УИК: Зеленоград, корпус 1505	Россия, Москва, Зеленоград, к1556	0101000020E610000043588D25AC9342404B2025766DFD4B40
57304	1	\N	\N	1	\N	\N	55.979903	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1556, адрес УИК: Зеленоград, корпус 1506		0101000020E610000043588D25AC9342404B2025766DFD4B40
57303	1	\N	\N	1	\N	\N	55.982199999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1816, адрес УИК: Зеленоград, корпус 1810		0101000020E6100000B5A338471D954240CB10C7BAB8FD4B40
57302	1	\N	\N	1	\N	\N	55.982199999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1816, адрес УИК: Зеленоград, корпус 1820	Россия, Москва, Зеленоград, к1816	0101000020E6100000B5A338471D954240CB10C7BAB8FD4B40
57301	1	\N	\N	1	\N	\N	55.985967000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1464, адрес УИК: Зеленоград, корпус 1447	Россия, Москва, Зеленоград, к1464	0101000020E6100000F3AD0FEB8D944240B6F7A92A34FE4B40
57300	1	\N	\N	1	\N	\N	55.985967000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1464, адрес УИК: Зеленоград, корпус 1451	Россия, Москва, Зеленоград, к1464	0101000020E6100000F3AD0FEB8D944240B6F7A92A34FE4B40
57299	1	\N	\N	1	\N	\N	55.985967000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1464, адрес УИК: Зеленоград, корпус 1455	Россия, Москва, Зеленоград, к1464	0101000020E6100000F3AD0FEB8D944240B6F7A92A34FE4B40
57298	1	\N	\N	1	\N	\N	55.985967000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1464, адрес УИК: Зеленоград, корпус 1471	Россия, Москва, Зеленоград, к1464	0101000020E6100000F3AD0FEB8D944240B6F7A92A34FE4B40
57297	1	\N	\N	1	\N	\N	55.980659000000003	город Москва, ЗелАО, район Старое Крюково, Зеленоград, корп. 828	Россия, Москва, Зеленоград, к828	0101000020E6100000602173655097424098C3EE3B86FD4B40
57296	1	\N	\N	1	\N	\N	55.987442000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1469, адрес УИК: Зеленоград, корпус 1424	Россия, Москва, Зеленоград, к1469	0101000020E61000000B0C59DDEA9342403259DC7F64FE4B40
57295	1	\N	\N	1	\N	\N	55.987442000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1469, адрес УИК: Зеленоград, корпус 1453	Россия, Москва, Зеленоград, к1469	0101000020E61000000B0C59DDEA9342403259DC7F64FE4B40
57294	1	\N	\N	1	\N	\N	55.987442000000001	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1469, адрес УИК: Зеленоград, корпус 1425	Россия, Москва, Зеленоград, к1469	0101000020E61000000B0C59DDEA9342403259DC7F64FE4B40
57293	1	\N	\N	1	\N	\N	55.986525999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1468, адрес УИК: Зеленоград, корпус 1424	Россия, Москва, Зеленоград, к1468	0101000020E6100000080264E8D8934240AC53E57B46FE4B40
57292	1	\N	\N	1	\N	\N	55.986525999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1468, адрес УИК: Зеленоград, корпус 1444	Россия, Москва, Зеленоград, к1468	0101000020E6100000080264E8D8934240AC53E57B46FE4B40
55616	1	\N	\N	1	12872	\N	55.862099999999998	город Москва, САО, Головинский район, Фестивальная ул, дом 42		0101000020E610000040A0336953C14240D8F0F44A59EE4B40
57163	1	\N	\N	1	\N	\N	55.827483999999998	город Москва, СЗАО, район Митино, Фабричная ул.Ново-Братцево, дом 6	Россия, Москва, Северо-Западный административный округ	0101000020E61000008274B169A5B642404CFBE6FEEAE94B40
57113	1	\N	\N	1	\N	\N	55.752121000000002	город Москва, ЗАО, район Филевский парк, Новозаводская ул, дом 19	Россия, Москва, район Филевский парк, Новозаводская улица, 19	0101000020E6100000A053909F8DC0424042D13C8045E04B40
57083	1	\N	\N	1	\N	\N	55.700901999999999	город Москва, ЗАО, район Солнцево, Нарофоминская ул, дом 1	Россия, Москва, Западный административный округ	0101000020E610000044A67C08AAB24240BAD91F28B7D94B40
57050	1	\N	\N	1	\N	\N	55.702942	Адрес помещения для голосования: город Москва, ЗАО, район Раменки, Ленинские горы, дом 1, адрес УИК: Ленинские горы, дом 1, корп. Ж	Россия, Москва, микрорайон Ленинские Горы, 1	0101000020E6100000BBD23252EFC342400F7EE200FAD94B40
57049	1	\N	\N	1	\N	\N	55.709271999999999	город Москва, ЗАО, район Раменки, Дружбы ул, дом 8	Россия, Москва, район Раменки, улица Дружбы, 8	0101000020E61000001155F833BCC14240F8FBC56CC9DA4B40
56912	1	\N	\N	1	\N	\N	55.613733000000003	город Москва, ЗАО, район Внуково, Интернациональная ул, дом 10	Россия, Москва, поселок Внуково, Интернациональная улица, 10	0101000020E6100000E4874A2366A04240EDBC8DCD8ECE4B40
56660	1	\N	\N	1	\N	\N	55.636142999999997	город Москва, ЮАО, район Чертаново Южное, Дорожная ул, дом 22А	Россия, Москва, микрорайон Северное Чертаново	0101000020E6100000DB4C857824CC4240274A42226DD14B40
56625	1	\N	\N	1	\N	\N	55.634185923928598	город Москва, ЮАО, район Чертаново Северное, Чертаново Северное, корп. 810	Россия, Москва, микрорайон Северное Чертаново, к810	0101000020E6100000577BD80B05CC424060CAC0012DD14B40
56624	1	\N	\N	1	\N	\N	55.635161813758401	город Москва, ЮАО, район Чертаново Северное, Чертаново Северное, корп. 809	Россия, Москва, микрорайон Северное Чертаново, к809	0101000020E6100000984C158C4ACC4240BBD408FD4CD14B40
56233	1	\N	\N	1	\N	\N	55.635759606529703	город Москва, ЮВАО, район Капотня, Капотня 3-й квартал, дом 24	Россия, Москва, 3-й квартал Капотни, 24	0101000020E6100000E675C4211BE642406F0D6C9560D14B40
56232	1	\N	\N	1	\N	\N	55.638187097259298	город Москва, ЮВАО, район Капотня, Капотня 2-й квартал, дом 20А	Россия, Москва, 2-й квартал Капотни, 20а	0101000020E61000006A300DC347E64240BEDD921CB0D14B40
56181	1	\N	\N	1	\N	\N	55.768532	город Москва, ВАО, район Соколиная гора, Соколиной горы 8-я ул, дом 5	Россия, Москва, 8-я улица Соколиной Горы, 5а	0101000020E61000001348895DDBDD4240F9F6AE415FE24B40
56180	1	\N	\N	1	\N	\N	55.773094	город Москва, ВАО, район Соколиная гора, Соколиной горы 9-я ул, дом 17	Россия, Москва, 9-я улица Соколиной Горы, 17	0101000020E6100000C03DCF9F36DE4240EE5D83BEF4E24B40
56161	1	\N	\N	1	\N	\N	55.809076098193401	город Москва, ВАО, район Северное Измайлово, Парковая 15-я ул, дом 52	Россия, Москва, 15-я Парковая улица, 52а	0101000020E61000007B88467710E942403FFD67CD8FE74B40
56003	1	\N	\N	1	\N	\N	55.819544999999998	Адрес помещения для голосования: город Москва, ВАО, район Восточный, Главная ул., дом 13, адрес УИК: Девятого мая ул, дом 12А	Россия, Москва, поселок Восточный, Главная улица, 13	0101000020E6100000221ADD41ECEE4240D74CBED9E6E84B40
56002	1	\N	\N	1	\N	\N	55.819766999999999	Адрес помещения для голосования: город Москва, ВАО, район Восточный, Главная ул., дом 9А, адрес УИК: Девятого мая ул, дом 12	Россия, Москва, поселок Восточный, Главная улица, 9а	0101000020E6100000D8648D7A88EE424086AB0320EEE84B40
56000	1	\N	\N	1	\N	\N	55.797173999999998	город Москва, ВАО, район Восточное Измайлово, Парковая 16-я ул, дом 11	Россия, Москва, стадион Измайлово	0101000020E6100000BA2EFCE07CE042405A9C31CC09E64B40
55999	1	\N	\N	1	\N	\N	55.793905000000002	город Москва, ВАО, район Восточное Измайлово, Первомайская ул, дом 111	Россия, Москва, район Измайлово, Первомайская улица, 111	0101000020E6100000B7990AF148E84240C190D5AD9EE54B40
55995	1	\N	\N	1	\N	\N	55.797173999999998	город Москва, ВАО, район Восточное Измайлово, Парковая 13-я ул, дом 18А	Россия, Москва, стадион Измайлово	0101000020E6100000BA2EFCE07CE042405A9C31CC09E64B40
55889	1	\N	\N	1	\N	\N	55.850721999999998	город Москва, СВАО, район Отрадное, Березовая аллея, дом 15Б	Россия, Москва, район Отрадное, Березовая аллея, 15б	0101000020E6100000793E03EACDCE42406DFE5F75E4EC4B40
55715	1	\N	\N	1	\N	\N	55.855061999999997	город Москва, САО, район Ховрино, Флотская ул, дом 11	Россия, Москва, Левобережный район, Флотская улица, 11	0101000020E61000003EEAAF5758C04240B306EFAB72ED4B40
55706	1	\N	\N	1	\N	\N	55.847210765962103	Адрес помещения для голосования: город Москва, САО, Тимирязевский район, Лихоборский нижн. 1-й пр., дом 15, адрес УИК: Дмитровское шоссе, дом 57, корп. 1		0101000020E61000007C9C69C2F6C74240DEE7F86871EC4B40
55662	1	\N	\N	1	\N	\N	55.856093000000001	город Москва, САО, Левобережный район, Ленинградское шоссе, дом 94А	Россия, Москва, Левобережный район, Ленинградское шоссе, 94а	0101000020E610000055A3570394BC4240D2AA967494ED4B40
55615	1	\N	\N	1	\N	\N	55.86159	город Москва, САО, Головинский район, Флотская ул, дом 25	Россия, Москва, Левобережный район, Флотская улица, 25	0101000020E61000008E59F624B0C14240C347C49448EE4B40
55610	1	\N	\N	1	\N	\N	55.853572	город Москва, САО, Головинский район, Флотская ул, дом 60	Россия, Москва, Левобережный район, Флотская улица, 60	0101000020E61000005340DAFF00C142400264E8D841ED4B40
55575	1	\N	\N	1	\N	\N	55.837803000000001	город Москва, САО, Войковский район, Ленинградское шоссе, дом 54	Россия, Москва, Левобережный район, Ленинградское шоссе, 54	0101000020E61000003BFE0B0401BE4240CFBEF2203DEB4B40
56262	1	\N	\N	1	203	\N	55.748725999999998	город Москва, ЮВАО, район Лефортово, Энтузиастов шоссе, дом 12	Россия, Москва, шоссе Энтузиастов, 12	0101000020E61000005CE674594CDA42401BD5E940D6DF4B40
56258	1	\N	\N	1	203	\N	55.750135	город Москва, ЮВАО, район Лефортово, Энтузиастов шоссе, дом 16	Россия, Москва, шоссе Энтузиастов, 16	0101000020E610000095287B4B39DB4240E04A766C04E04B40
56126	1	\N	\N	1	203	\N	55.763314999999999	город Москва, ВАО, район Перово, Энтузиастов шоссе, дом 72	Россия, Москва, шоссе Энтузиастов, 72	0101000020E61000007B8505F703E44240EBC5504EB4E14B40
56027	1	\N	\N	1	203	\N	55.773190999999997	город Москва, ВАО, район Ивановское, Энтузиастов шоссе, дом 100А	Россия, Москва, шоссе Энтузиастов, 100а	0101000020E6100000548B8862F2EA4240E04735ECF7E24B40
56026	1	\N	\N	1	203	\N	55.769930000000002	город Москва, ВАО, район Ивановское, Энтузиастов шоссе, дом 96Г	Россия, Москва, шоссе Энтузиастов, 96г	0101000020E610000054E57B4622EA4240CA1AF5108DE24B40
57372	1	\N	\N	1	609	\N	55.824612000000002	город Москва, СВАО, Бутырский район, Яблочкова ул., 35Г,  СОШ № 963	Россия, Москва, улица Яблочкова, 35г	0101000020E6100000F01472A59EC94240D0F1D1E28CE94B40
55808	1	\N	\N	1	609	\N	55.814031999999997	город Москва, СВАО, Бутырский район, Яблочкова ул, дом 3	Россия, Москва, улица Яблочкова, 3	0101000020E61000004415FE0C6FCA4240E0F2583332E84B40
56252	1	\N	\N	1	3442	\N	55.697509018827901	город Москва, ЮВАО, район Кузьминки, Юных ленинцев ул, дом 68, корп. 2	Россия, Москва, район Кузьминки	0101000020E610000019761893FEE2424034D593F947D94B40
57071	1	\N	\N	1	5485	\N	55.645715000000003	город Москва, ЗАО, район Солнцево, Щорса ул, дом 5, корп. 1	Россия, Москва, улица Щорса, 5к1	0101000020E61000004EED0C535BB44240B1C403CAA6D24B40
55417	1	\N	\N	1	945	\N	55.787320000000001	город Москва, ЦАО, Мещанский район, Щепкина ул, дом 68	Россия, Москва, улица Щепкина, 68	0101000020E610000009A87004A9D042404DBED9E6C6E44B40
56241	1	\N	\N	1	3332	\N	55.708364000000003	город Москва, ЮВАО, район Кузьминки, Шумилова ул, дом 9	Россия, Москва, улица Шумилова, 9	0101000020E61000000ADAE4F049E34240F6D4EAABABDA4B40
57008	1	\N	\N	1	4524	\N	55.640985000000001	Адрес помещения для голосования: город Москва, ЗАО, район Ново-Переделкино, Шолохова ул., дом 20, адрес УИК: Чоботовская ул., дом 5, корп. 1, Чоботовская ул, дом 5, корп. 1	Россия, Москва, улица Шолохова, 20	0101000020E61000002C2CB81FF0AC4240001DE6CB0BD24B40
56486	1	\N	\N	1	6290	\N	55.717148000000002	город Москва, ЮАО, Донской район, Шаболовка ул, дом 39	Россия, Москва, улица Шаболовка, 39	0101000020E6100000213A048E04CE424027327381CBDB4B40
56214	1	\N	\N	1	2975	\N	55.695011999999998	город Москва, ЮВАО, район Выхино-Жулебино, Чугунные ворота ул, дом 11	Россия, Москва, улица Чугунные Ворота, 11	0101000020E61000007A6D365662E64240ED293927F6D84B40
56399	1	\N	\N	1	5314	\N	55.697249999999997	город Москва, ЮВАО, район Текстильщики, Чистова ул, дом 15/15	Россия, Москва, улица Чистова, 15/15	0101000020E6100000F5BBB0355BDF42406891ED7C3FD94B40
56838	1	\N	\N	1	2165	\N	55.669848000000002	город Москва, ЮЗАО, район Черемушки, Цюрупы ул, дом 10	Россия, Москва, улица Цюрупы, 10	0101000020E6100000AFB0E07EC0C9424040A54A94BDD54B40
55864	1	\N	\N	1	6630	\N	55.818989000000002	город Москва, СВАО, Останкинский район, Цандера ул, дом 7, корп. 2	Россия, Москва, улица Цандера, 7к2	0101000020E61000002D3E05C078D042405264ADA1D4E84B40
57193	1	\N	\N	1	6753	\N	55.856755	Адрес помещения для голосования: город Москва, СЗАО, район Северное Тушино, Фомичевой ул., дом 5, адрес УИК: Героев Панфиловцев ул, дом 8, корп. 1	Россия, Москва, улица Фомичевой, 5	0101000020E6100000863DEDF0D7B842409DD7D825AAED4B40
55535	1	\N	\N	1	2668	\N	55.807763999999999	город Москва, САО, район Аэропорт, Усиевича ул, дом 31А	Россия, Москва, улица Усиевича, 31а	0101000020E6100000AF5E454607C242406D718DCF64E74B40
55913	1	\N	\N	1	7121	\N	55.884757	город Москва, СВАО, район Северное Медведково, Тихомирова ул, дом 10	Россия, Москва, улица Тихомирова, 10	0101000020E610000098BD6C3B6DD342401BF4A5B73FF14B40
57064	1	\N	\N	1	5389	\N	55.703175000000002	город Москва, ЗАО, район Раменки, Столетова ул, дом 3	Россия, Москва, улица Столетова, 3	0101000020E61000003D0D18247DC04240B22E6EA301DA4B40
56485	1	\N	\N	1	6280	\N	55.713724999999997	город Москва, ЮАО, Донской район, Стасовой ул, дом 8	Россия, Москва, улица Стасовой, 8	0101000020E610000045847F1134CC424036AB3E575BDB4B40
56198	1	\N	\N	1	2754	\N	55.791071000000002	город Москва, ВАО, район Сокольники, Сокольнический вал ул, дом 28	Россия, Москва, улица Сокольнический Вал, 28	0101000020E610000091813CBB7CD5424032E884D041E54B40
57273	1	\N	\N	1	6787	\N	55.839571999999997	город Москва, СЗАО, район Южное Тушино, Свободы ул, дом 26	Россия, Москва, улица Свободы, 26	0101000020E6100000AB251DE560BA42409351651877EB4B40
55685	1	\N	\N	1	4641	\N	55.795974999999999	Адрес помещения для голосования: город Москва, САО, район Сокол, Сальвадора Альенде ул., дом 6, адрес УИК: Зорге ул, дом 36	Россия, Москва, улица Сальвадора Альенде, 6	0101000020E61000004818062CB9C0424080B74082E2E54B40
56898	1	\N	\N	1	3304	\N	55.610224000000002	город Москва, ЮЗАО, район Ясенево, Рокотова ул, дом 5	Россия, Москва, улица Рокотова, 5	0101000020E6100000390F27309DC64240FE9DEDD11BCE4B40
55730	1	\N	\N	1	5188	\N	55.771970000000003	город Москва, САО, Хорошевский район, Розанова ул, дом 8	Россия, Москва, улица Розанова, 8с1	0101000020E610000024F0879FFFC442401FBFB7E9CFE24B40
57291	1	\N	\N	1	42612	\N	55.9865306773684	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1468, адрес УИК: Зеленоград, корпус 1416	Россия, Москва, Зеленоград, к1468	0101000020E6100000F0A5F0A0D9934240BEBED6A546FE4B40
57045	1	\N	\N	1	5153	\N	55.727348999999997	город Москва, ЗАО, район Раменки, Пудовкина ул, дом 4А	Россия, Москва, улица Пудовкина, 4а	0101000020E610000053EBFD463BC442409FE3A3C519DD4B40
55496	1	\N	\N	1	2074	\N	55.741996999999998	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Пречистенка ул., дом 22, адрес УИК: Левшинский Б. пер, дом 8/1, стр. 2	Россия, Москва, улица Пречистенка, 22/2	0101000020E6100000466117450FCC4240745DF8C1F9DE4B40
56865	1	\N	\N	1	2880	\N	55.550305000000002	город Москва, ЮЗАО, район Южное Бутово, Поляны ул, дом 31А	Россия, Москва, улица Поляны, 31а	0101000020E6100000C0CE4D9B71C64240A3E9EC6470C64B40
55500	1	\N	\N	1	2152	\N	55.740161999999998	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Плющиха ул., дом 39, адрес УИК: Плющиха ул, дом 43/47	Россия, Москва, улица Плющиха, 39	0101000020E610000015014EEFE2C94240F8DEDFA0BDDE4B40
56116	1	\N	\N	1	1576	\N	55.742600000000003	город Москва, ВАО, район Перово, Плющева ул, дом  11А	Россия, Москва, улица Плющева, 11а	0101000020E610000055DAE21A9FE142403B014D840DDF4B40
56125	1	\N	\N	1	1700	\N	55.756948000000001	город Москва, ВАО, район Перово, Плеханова ул, дом 5Б	Россия, Москва, улица Плеханова, 5б	0101000020E61000000E2F88484DE14240E5620CACE3E04B40
55880	1	\N	\N	1	6804	\N	55.865110999999999	город Москва, СВАО, район Отрадное, Пестеля ул, дом 8Г	Россия, Москва, улица Пестеля, 8г	0101000020E61000002C4833164DCF424076340EF5BBEE4B40
56319	1	\N	\N	1	4330	\N	55.651516000000001	город Москва, ЮВАО, район Марьино, Перерва ул, дом 44	Россия, Москва, улица Перерва, 44	0101000020E61000005706D50627DE42400E6954E064D34B40
56318	1	\N	\N	1	4330	\N	55.650460000000002	город Москва, ЮВАО, район Марьино, Перерва ул, дом 36	Россия, Москва, улица Перерва, 36	0101000020E61000007EC9C6832DDE424097ADF54542D34B40
57248	1	\N	\N	1	7282	\N	55.789603	город Москва, СЗАО, район Хорошево-Мневники, Паршина ул, дом 8	Россия, Москва, улица Паршина, 8	0101000020E61000001FA2D11DC4BA424068E90AB611E54B40
56773	1	\N	\N	1	1555	\N	55.681204000000001	город Москва, ЮЗАО, Ломоносовский район, Панферова ул, дом 8, корп. 1	Россия, Москва, улица Панферова, 8к1	0101000020E6100000DCA0F65B3BC54240C3F352B131D74B40
55750	1	\N	\N	1	5405	\N	55.818522999999999	город Москва, СВАО, Алексеевский район, Корчагина Павла ул, дом 13А	Россия, Москва, улица Павла Корчагина, 13	0101000020E6100000CA54C1A8A4D442400C03965CC5E84B40
56752	1	\N	\N	1	981	\N	55.638525999999999	город Москва, ЮЗАО, район Коньково, Островитянова ул, дом 19/22	Россия, Москва, улица Островитянова, 19/22	0101000020E6100000D49E927362C14240A6D24F38BBD14B40
56792	1	\N	\N	1	1784	\N	55.657361999999999	город Москва, ЮЗАО, Обручевский район, Обручева ул, дом 28А	Россия, Москва, улица Обручева, 28а	0101000020E6100000A20914B188C142400BD1217024D44B40
55356	1	\N	\N	1	20	\N	55.753266000000004	Адрес помещения для голосования: город Москва, ЦАО, район Арбат, Новый Арбат ул., дом 36/9, адрес УИК: Новинский бульв, дом 13, стр. 6	Россия, Москва, улица Новый Арбат, 36/9	0101000020E61000005B79C9FFE4C94240299831056BE04B40
56791	1	\N	\N	1	1747	\N	55.663167000000001	город Москва, ЮЗАО, Обручевский район, Новаторов ул, дом 34, корп. 2	Россия, Москва, улица Новаторов, 34к2	0101000020E6100000058C2E6F0EC34240AA6400A8E2D44B40
56787	1	\N	\N	1	1747	\N	55.663563000000003	Адрес помещения для голосования: город Москва, ЮЗАО, Обручевский район, Новаторов ул., дом 34, корп. 1, адрес УИК: Новаторов ул, дом 34, корп. 2	Россия, Москва, улица Новаторов, 34к1	0101000020E610000004AF963B33C34240F7EAE3A1EFD44B40
95181	1	\N	\N	1	3893	\N	55.788874	город Москва, СЗАО, район Щукино, ул.Народного ополчения, д.38, к.2, Российский заочный институт текстильной и легкой промышленности		0101000020E61000006117450F7CBE42401555BFD2F9E44B40
57238	1	\N	\N	1	3893	\N	55.784405	город Москва, СЗАО, район Хорошево-Мневники, Народного Ополчения ул, дом 31	Россия, Москва, улица Народного Ополчения, 31	0101000020E6100000E25CC30C8DBD4240D1E80E6267E44B40
56031	1	\N	\N	1	233	\N	55.759866000000002	город Москва, ВАО, район Ивановское, Молостовых ул, дом 10Б	Россия, Москва, улица Молостовых, 10б	0101000020E6100000F27B9BFEECE94240D2AB014A43E14B40
55983	1	\N	\N	1	7852	\N	55.723875999999997	город Москва, ВАО, район Вешняки, Молдагуловой ул, дом 3, стр. 4	Россия, Москва, улица Молдагуловой, 3к1	0101000020E6100000FAB31F2922E94240FD2D01F8A7DC4B40
57227	1	\N	\N	1	7007	\N	55.774619000000001	город Москва, СЗАО, район Хорошево-Мневники, Мневники ул, дом 4	Россия, Москва, улица Мневники, 4	0101000020E610000011E0F42EDEBF42401CEE23B726E34B40
56793	1	\N	\N	1	1815	\N	55.651577000000003	город Москва, ЮЗАО, Обручевский район, Миклухо-Маклая ул, дом 21а	Россия, Москва, улица Миклухо-Маклая, 21а	0101000020E61000005053CBD6FAC04240B4E908E066D34B40
56082	1	\N	\N	1	12490	\N	55.717365504773802	город Москва, ВАО, район Косино - Ухтомский, Медведева ул, дом 6	Россия, Москва, улица Медведева, 6	0101000020E6100000215A2BDA1CF1424094A12AA6D2DB4B40
57249	1	\N	\N	1	7143	\N	55.785573999999997	город Москва, СЗАО, район Хорошево-Мневники, Тухачевского маршала ул, дом 58, корп. 2	Россия, Москва, улица Маршала Тухачевского, 58к2	0101000020E61000002062838593BA4240404B57B08DE44B40
57253	1	\N	\N	1	7333	\N	55.793692999999998	город Москва, СЗАО, район Щукино, Соколовского маршала ул, дом 10	Россия, Москва, улица Маршала Соколовского, 10	0101000020E610000083A3E4D539BE4240350873BB97E54B40
57254	1	\N	\N	1	7214	\N	55.794623999999999	город Москва, СЗАО, район Щукино, Конева маршала ул, дом 11	Россия, Москва, улица Маршала Конева, 11	0101000020E6100000D9EA724A40BE4240F04E3E3DB6E54B40
57240	1	\N	\N	1	7214	\N	55.797193999999998	город Москва, СЗАО, район Щукино, Конева маршала ул, дом 10	Россия, Москва, улица Маршала Конева, 10	0101000020E6100000D44334BA83BE4240A148F7730AE64B40
56768	1	\N	\N	1	1487	\N	55.678077000000002	Адрес помещения для голосования: город Москва, ЮЗАО, Ломоносовский район, Ульяновой Марии ул., дом 5, адрес УИК: Ульяновой Марии ул, дом 8	Россия, Москва, улица Марии Ульяновой, 5а	0101000020E6100000994A3FE1ECC24240BC95253ACBD64B40
56369	1	\N	\N	1	4944	\N	55.728368000000003	город Москва, ЮВАО, Рязанский район, Маевок ул, дом 4	Россия, Москва, улица Маевок, 4	0101000020E61000006F675F7990E24240FAB9A1293BDD4B40
56250	1	\N	\N	1	12521	\N	55.700668999999998	город Москва, ЮВАО, район Кузьминки, Юных ленинцев ул, дом 79, корп. 2		0101000020E61000008A58C4B0C3E2424017299485AFD94B40
57033	1	\N	\N	1	3514	\N	55.672756999999997	город Москва, ЗАО, район Проспект Вернадского, Лобачевского ул, дом 54	Россия, Москва, улица Лобачевского, 54	0101000020E61000001327F73B14BF4240D993C0E61CD64B40
56483	1	\N	\N	1	6263	\N	55.701627999999999	город Москва, ЮАО, Даниловский район, Лобанова ул, дом 3	Россия, Москва, улица Лобанова, 3	0101000020E61000006AF5D55581D442409CFA40F2CED94B40
55740	1	\N	\N	1	5278	\N	55.783706000000002	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Куусинена ул., дом 13, адрес УИК: Куусинена ул, дом 17, корп. 3	Россия, Москва, улица Куусинена, 13	0101000020E610000061C26856B6C14240E9D66B7A50E44B40
55737	1	\N	\N	1	5278	\N	55.781447999999997	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Куусинена ул., дом 6, корп. 6, адрес УИК: Куусинена ул, дом 4А, корп. 5	Россия, Москва, улица Куусинена, 6к6	0101000020E610000074081C0934C2424026C3F17C06E44B40
57390	1	\N	\N	1	887	\N	55.807636582541001	город Москва, СЗАО, район Строгино, ул. Кулакова, 17/2, СОШ №129	Россия, Москва, улица Кулакова, 17к2	0101000020E6100000D9B45208E4B24240100533A660E74B40
57213	1	\N	\N	1	887	\N	55.810284000000003	город Москва, СЗАО, район Строгино, Кулакова ул, дом 12, корп. 2	Россия, Москва, улица Кулакова, 12к2	0101000020E6100000DE550F9887B242406D3CD862B7E74B40
57203	1	\N	\N	1	887	\N	55.815781999999999	город Москва, СЗАО, район Строгино, Кулакова ул, дом 2, корп. 2	Россия, Москва, улица Кулакова, 2к2	0101000020E610000011514CDE00B342402E55698B6BE84B40
56764	1	\N	\N	1	1424	\N	55.685056000000003	Адрес помещения для голосования: город Москва, ЮЗАО, Ломоносовский район, Крупской ул., дом 12, адрес УИК: Вернадского просп, дом 13	Россия, Москва, улица Крупской, 12	0101000020E61000003881E9B46EC34240DCF63DEAAFD74B40
55429	1	\N	\N	1	1146	\N	55.768177000000001	город Москва, ЦАО, Пресненский район, Красина ул, дом 20	Россия, Москва, улица Красина, 20с1	0101000020E61000005E9CF86A47CB42400B45BA9F53E24B40
55643	1	\N	\N	1	3356	\N	55.815848000000003	Адрес помещения для голосования: город Москва, САО, район Коптево, Волкова космонавта ул., дом 20, адрес УИК: Академическая Б. ул, дом 6	Россия, Москва, улица Космонавта Волкова, 20	0101000020E61000003196E99788C34240E6400FB56DE84B40
55788	1	\N	\N	1	5875	\N	55.895111	город Москва, СВАО, район Бибирево, Корнейчука ул, дом 52А	Россия, Москва, улица Корнейчука, 52а	0101000020E6100000FD2FD7A205D042401AA54BFF92F24B40
55769	1	\N	\N	1	5661	\N	55.861969000000002	Адрес помещения для голосования: город Москва, СВАО, Бабушкинский район, Коминтерна ул., дом 8, адрес УИК: Коминтерна ул, дом 4Б	Россия, Москва, улица Коминтерна, 8	0101000020E6100000BF0E9C33A2D642403A950C0055EE4B40
56707	1	\N	\N	1	525	\N	55.65596	город Москва, ЮЗАО, район Зюзино, Каховка ул, дом 12, корп. 2	Россия, Москва, улица Каховка, 12к2	0101000020E6100000172EABB019CA4240F9BD4D7FF6D34B40
55758	1	\N	\N	1	1701	\N	55.824283000000001	город Москва, СВАО, Алексеевский район, Касаткина ул, дом 13, корп. 5	Россия, Москва, улица Касаткина, 13с5	0101000020E6100000CCD1E3F736D542400BD3F71A82E94B40
56950	1	\N	\N	1	3989	\N	55.728491639249803	город Москва, ЗАО, район Кунцево, Франко Ивана ул, дом 28, корп. 2	Россия, Москва, улица Ивана Франко, 28к1	0101000020E6100000F6D4EAABABB64240E6B2D1393FDD4B40
56682	1	\N	\N	1	166	\N	55.684117000000001	город Москва, ЮЗАО, Академический район, Бабушкина Ивана ул, дом 15, корп. 5	Россия, Москва, улица Ивана Бабушкина, 15к5	0101000020E6100000404CC2853CC842409ED1562591D74B40
56949	1	\N	\N	1	12313	\N	55.729753221431999	город Москва, ЗАО, район Кунцево, Будановой Екат. ул, дом 18	Россия, Москва, улица Екатерины Будановой, 18	0101000020E6100000BDE47FF277B742403694DA8B68DD4B40
57046	1	\N	\N	1	5167	\N	55.720579999999998	город Москва, ЗАО, район Раменки, Довженко ул, дом 10	Россия, Москва, улица Довженко, 10	0101000020E6100000B3EF8AE07FC142406A1327F73BDC4B40
55516	1	\N	\N	1	2272	\N	55.723891000000002	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Доватора ул., дом 5/9, адрес УИК: Доватора ул, дом 3	Россия, Москва, улица Доватора, 5/9	0101000020E61000003BFBCA83F4C84240336FD575A8DC4B40
56675	1	\N	\N	1	38	\N	55.684883999999997	город Москва, ЮЗАО, Академический район, Ульянова Дмитрия ул, дом 26	Россия, Москва, улица Дмитрия Ульянова, 26ас1	0101000020E61000006938656EBEC94240DEC66647AAD74B40
55887	1	\N	\N	1	6711	\N	55.858517999999997	город Москва, СВАО, район Отрадное, Декабристов ул, дом 40	Россия, Москва, улица Декабристов, 40	0101000020E610000079944A7842CF42407F83F6EAE3ED4B40
55851	1	\N	\N	1	3552	\N	55.795555	город Москва, СВАО, район Марьина роща, Двинцев ул, дом 10	Россия, Москва, улица Двинцев, 10	0101000020E6100000B933130CE7CC4240AB9509BFD4E54B40
56365	1	\N	\N	1	4793	\N	55.677442999999997	город Москва, ЮВАО, район Печатники, Гурьянова ул, дом 71	Россия, Москва, улица Гурьянова, 71	0101000020E61000004F7974232CDC4240BAF3C473B6D64B40
56806	1	\N	\N	1	1972	\N	55.565784000000001	город Москва, ЮЗАО, район Северное Бутово, Грина ул, дом 18, корп. 3, стр. 1	Россия, Москва, улица Грина, 18к3с1	0101000020E610000083A279008BCA4240CF4C309C6BC84B40
95179	1	\N	\N	1	5490	\N	55.657535000000003	город Москва, ЗАО, район Солнцево, ул. Главмосстроя, дом 28	Россия, Москва, улица Главмосстроя, 28	0101000020E6100000B4E7323509B44240D97C5C1B2AD44B40
57181	1	\N	\N	1	6608	\N	55.854886	город Москва, СЗАО, район Северное Тушино, Героев Панфиловцев ул, дом 35, корп. 2	Россия, Москва, улица Героев Панфиловцев, 35к2	0101000020E6100000643DB5FAEAB4424075E789E76CED4B40
57243	1	\N	\N	1	7245	\N	55.781185000000001	город Москва, СЗАО, район Хорошево-Мневники, Глаголева генерала ул, дом 10, корп. 2	Россия, Москва, улица Генерала Глаголева, 10к2	0101000020E61000001630815B77BB42401990BDDEFDE34B40
55669	1	\N	\N	1	12872	\N	55.856740000000002	город Москва, САО, Левобережный район, Фестивальная ул, дом 4, корп. 2		0101000020E61000001381EA1F44BE4240689604A8A9ED4B40
55691	1	\N	\N	1	4672	\N	55.805517999999999	Адрес помещения для голосования: город Москва, САО, район Сокол, Врубеля ул., дом 6, адрес УИК: Волоколамское шоссе, дом 1	Россия, Москва, улица Врубеля, 6	0101000020E610000019FED30D14C042406F2BBD361BE74B40
55370	1	\N	\N	1	256	\N	55.753630000000001	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Воронцово поле ул., дом 5 А, адрес УИК: Лялин пер, дом 7/2	Россия, Москва, улица Воронцово Поле, 5а	0101000020E61000001CB3EC4960D342406AA4A5F276E04B40
57202	1	\N	\N	1	851	\N	55.866712999999997	город Москва, СЗАО, район Северное Тушино, Лациса Вилиса ул, дом 2	Россия, Москва, улица Вилиса Лациса, 2к1	0101000020E61000009DD843FB58B742404F029B73F0EE4B40
56305	1	\N	\N	1	2972	\N	55.666853000000003	город Москва, ЮВАО, район Люблино, Верхние поля ул, дом 47, корп. 1	Россия, Москва, улица Верхние Поля, 47к1	0101000020E6100000012F336C94E34240A81E69705BD54B40
56743	1	\N	\N	1	1012	\N	55.635176999999999	город Москва, ЮЗАО, район Коньково, Введенского ул, дом 32 А	Россия, Москва, улица Введенского, 32а	0101000020E6100000B4AED172A0C34240F015DD7A4DD14B40
56742	1	\N	\N	1	1012	\N	55.636361000000001	Адрес помещения для голосования: город Москва, ЮЗАО, район Коньково, Введенского ул., дом 28, адрес УИК: Введенского ул, дом 30, корп. 1	Россия, Москва, улица Введенского, 28	0101000020E6100000D0D2156C23C4424095B9F94674D14B40
57134	1	\N	\N	1	6180	\N	55.722624000000003	город Москва, ЗАО, район Фили-Давыдково, Ватутина ул, дом 8	Россия, Москва, улица Ватутина, 8	0101000020E610000073BC02D193BA424001A777F17EDC4B40
56776	1	\N	\N	1	190	\N	55.676879	город Москва, ЮЗАО, Ломоносовский район, Вавилова ул, дом 91	Россия, Москва, улица Вавилова, 91	0101000020E61000004D13B69F8CC54240B22C98F8A3D64B40
56736	1	\N	\N	1	792	\N	55.641675999999997	город Москва, ЮЗАО, район Коньково, Бутлерова ул, дом 38 А	Россия, Москва, улица Бутлерова, 38а	0101000020E6100000732CEFAA07C6424065506D7022D24B40
56729	1	\N	\N	1	792	\N	55.647077000000003	город Москва, ЮЗАО, район Коньково, Бутлерова ул, дом 24 А	Россия, Москва, улица Бутлерова, 24а	0101000020E610000013D731AEB8C44240357F4C6BD3D24B40
55640	1	\N	\N	1	4096	\N	55.882429000000002	город Москва, САО, район Западное Дегунино, Бусиновская горка ул, дом 7, корп. 2	Россия, Москва, улица Бусиновская Горка, 7к2	0101000020E61000003DD175E107BF42406005F86EF3F04B40
56185	1	\N	\N	1	12306	\N	55.765948999999999	город Москва, ВАО, район Соколиная гора, Жигуленкова Бориса ул, дом 27	Россия, Москва, улица Бориса Жигуленкова, 27	0101000020E6100000516B9A779CDE4240B3B3E89D0AE24B40
56612	1	\N	\N	1	2721	\N	55.632224999999998	город Москва, ЮАО, район Царицыно, Бехтерева ул, дом 17А	Россия, Москва, улица Бехтерева, 17а	0101000020E61000008CDB68006FD34240575BB1BFECD04B40
56609	1	\N	\N	1	2721	\N	55.615420999999998	город Москва, ЮАО, район Царицыно, Бехтерева ул, дом 51	Россия, Москва, улица Бехтерева, 51	0101000020E6100000B70C384BC9D24240C422861DC6CE4B40
55362	1	\N	\N	1	146	\N	55.732773000000002	город Москва, ЦАО, район Замоскворечье, Бахрушина ул, дом 24	Россия, Москва, улица Бахрушина, 24с1	0101000020E61000008D43FD2E6CD1424027327381CBDD4B40
57154	1	\N	\N	1	6332	\N	55.849094999999998	город Москва, СЗАО, район Митино, Барышиха ул, дом 32	Россия, Москва, улица Барышиха, 32	0101000020E6100000E50D30F31DAC42403B191C25AFEC4B40
57109	1	\N	\N	1	5853	\N	55.745372000000003	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Барклая ул., дом 15, Адрес УИК: Филёвская Б. ул, дом 31		0101000020E6100000BB25396057BF424054AD855968DF4B40
55446	1	\N	\N	1	1423	\N	55.757268000000003	город Москва, ЦАО, Пресненский район, Антонова-Овсеенко ул, дом 6	Россия, Москва, улица Антонова-Овсеенко, 6с1	0101000020E61000000CC9C9C4ADC4424057276728EEE04B40
55900	1	\N	\N	1	6967	\N	55.850247000000003	город Москва, СВАО, район Свиблово, Амундсена ул, дом 2	Россия, Москва, улица Амундсена, 2с1	0101000020E6100000601DC70F95D44240D542C9E4D4EC4B40
56781	1	\N	\N	1	1645	\N	55.668543999999997	Адрес места голосования: город Москва, ЮЗАО, Ломоносовский район, Пилюгина академика ул., дом 16, корп. 2, адрес УИК: Пилюгина академика ул, дом 16, корп. 1		0101000020E6100000BE4F55A181C44240F0F78BD992D54B40
56780	1	\N	\N	1	1645	\N	55.672108000000001	город Москва, ЮЗАО, Ломоносовский район, Пилюгина академика ул, дом 14А	Россия, Москва, улица Академика Пилюгина, 14а	0101000020E61000009886E12362C44240A3B08BA207D64B40
56881	1	\N	\N	1	3085	\N	55.540031999999997	город Москва, ЮЗАО, район Южное Бутово, Адмирала Лазарева ул, дом 68, корп. 3	Россия, Москва, улица Адмирала Лазарева, 68к3	0101000020E61000000B9B012EC8C042409065C1C41FC54B40
57080	1	\N	\N	1	5552	\N	55.646583999999997	город Москва, ЗАО, район Солнцево, Авиаторов ул, дом 8, корп. 2	Россия, Москва, улица Авиаторов, 8к2	0101000020E6100000E6C9350532B34240F50EB743C3D24B40
57077	1	\N	\N	1	5552	\N	55.642372000000002	город Москва, ЗАО, район Солнцево, Авиаторов ул, дом 28	Россия, Москва, улица Авиаторов, 28	0101000020E6100000027E8D2441B44240DDEEE53E39D24B40
56231	1	\N	\N	1	3210	\N	55.680396999999999	город Москва, ЮВАО, район Выхино-Жулебино, Миля авиаконструктора ул, дом 18, корп. 2	Россия, Москва, улица Авиаконструктора Миля, 18к2	0101000020E6100000FC372F4E7CED4240F4A5B73F17D74B40
95180	1	\N	\N	1	5436	\N	55.655304999999998	город Москва, ЗАО, район Солнцево, 50 лет Октября, дом 6	Россия, Москва, улица 50 лет Октября, 6	0101000020E6100000D68C0C7217B54240E0F3C308E1D34B40
57325	1	\N	\N	1	76467	\N	55.979193000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Пятилетка 2-я ул. Зеленоград, дом 18а, адрес УИК: Зеленоград, корпус 1824	Россия, Москва, Зеленоград, улица 2-я Пятилетка, 18а	0101000020E610000062BCE6559D9542406FBC3B3256FD4B40
56189	1	\N	\N	1	12312	\N	55.754517	город Москва, ВАО, район Соколиная гора, Энтузиастов пр, дом 19А	Россия, Москва, проезд Энтузиастов, 19а	0101000020E61000007619FED30DDC424055A3570394E04B40
57324	1	\N	\N	1	76467	\N	55.979193000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Пятилетка 2-я ул. Зеленоград, дом 18а, адрес УИК: Зеленоград, корпус 1807	Россия, Москва, Зеленоград, улица 2-я Пятилетка, 18а	0101000020E610000062BCE6559D9542406FBC3B3256FD4B40
57322	1	\N	\N	1	75071	\N	55.979193000000002	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Пятилетка 2-я ул. Зеленоград, дом 18а, адрес УИК: Зеленоград, корпус 1820	Россия, Москва, Зеленоград, улица 2-я Пятилетка, 18а	0101000020E610000062BCE6559D9542406FBC3B3256FD4B40
57356	1	\N	\N	1	74879	\N	55.992462000000003	Адрес помещения для голосования: город Москва, ЗелАО, район Силино, корп. 1140, адрес УИК: Зеленоград, корп. 1137		0101000020E6100000382EE3A606964240EA42ACFE08FF4B40
57321	1	\N	\N	1	76444	\N	55.975183999999999	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 1642, адрес УИК: Зеленоград, корпус 1639	Россия, Москва, Зеленоград, к1642	0101000020E61000005EBC1FB75F9442408ECA4DD4D2FC4B40
55860	1	\N	\N	1	6576	\N	55.814143000000001	Адрес помещения для голосования: город Москва, СВАО, Останкинский район, Мира просп., дом 105, адрес УИК: Ольминского пр, дом 3		0101000020E61000005F622CD32FD1424038A27BD635E84B40
55859	1	\N	\N	1	6576	\N	55.81212	город Москва, СВАО, Останкинский район, Мира просп, дом 101	Россия, Москва, проспект Мира, 101а	0101000020E6100000C2853C821BD14240B936548CF3E74B40
55857	1	\N	\N	1	6576	\N	55.803761999999999	город Москва, СВАО, Останкинский район, Мира просп, дом 87	Россия, Москва, проспект Мира, 87	0101000020E6100000488B338639D142403FE257ACE1E64B40
57225	1	\N	\N	1	7049	\N	55.774557999999999	город Москва, СЗАО, район Хорошево-Мневники, Жукова маршала просп, дом 37, корп. 2	Россия, Москва, проспект Маршала Жукова, 37к2	0101000020E6100000833463D174BC4240766D6FB724E34B40
57098	1	\N	\N	1	1452	\N	55.657037000000003	город Москва, ЗАО, район Тропарево-Никулино, Вернадского просп, дом 88	Россия, Москва, проспект Вернадского, 88	0101000020E6100000AF3E1EFAEEBC424088A1D5C919D44B40
57096	1	\N	\N	1	1452	\N	55.653100999999999	город Москва, ЗАО, район Тропарево-Никулино, Вернадского просп, дом 127, корп.2	Россия, Москва, проспект Вернадского, 127к2	0101000020E610000042E90B21E7BD424011FE45D098D34B40
57090	1	\N	\N	1	1452	\N	55.664299	город Москва, ЗАО, район Тропарево-Никулино, Вернадского просп, дом 101, корп.5	Россия, Москва, проспект Вернадского, 101к5	0101000020E61000004BADF71BEDBE4240FCE1E7BF07D54B40
57089	1	\N	\N	1	1452	\N	55.663201999999998	город Москва, ЗАО, район Тропарево-Никулино, Вернадского просп, дом 101, корп.6	Россия, Москва, проспект Вернадского, 101к6	0101000020E610000013F4177AC4BE424026529ACDE3D44B40
57041	1	\N	\N	1	1452	\N	55.672168999999997	город Москва, ЗАО, район Проспект Вернадского, Вернадского просп, дом 57	Россия, Москва, проспект Вернадского, 57	0101000020E6100000F6B704E09FC04240483140A209D64B40
57038	1	\N	\N	1	1452	\N	55.672812999999998	город Москва, ЗАО, район Проспект Вернадского, Вернадского просп, дом 55	Россия, Москва, проспект Вернадского, 55	0101000020E610000099620E828EC042406DA983BC1ED64B40
57037	1	\N	\N	1	1452	\N	55.676985999999999	город Москва, ЗАО, район Проспект Вернадского, Вернадского просп, дом 37, корп. 2	Россия, Москва, проспект Вернадского, 37к2	0101000020E61000003BA92F4B3BC14240C8EC2C7AA7D64B40
57035	1	\N	\N	1	1452	\N	55.675472999999997	город Москва, ЗАО, район Проспект Вернадского, Вернадского просп, дом 62А	Россия, Москва, проспект Вернадского, 62а	0101000020E610000058E542E55FBF42405E2A36E675D64B40
56766	1	\N	\N	1	1452	\N	55.680768	город Москва, ЮЗАО, Ломоносовский район, Вернадского просп, дом 29А	Россия, Москва, проспект Вернадского, 29а	0101000020E6100000771211FE45C24240E814E46723D74B40
56190	1	\N	\N	1	12311	\N	55.760793	город Москва, ВАО, район Соколиная гора, Буденного просп, дом 32		0101000020E61000002E56D4601ADE42404B033FAA61E14B40
56187	1	\N	3637	1	12311	\N	55.760793	город ВАО, район Соколиная гора, Буденного просп, дом 32	Россия, Москва, проспект Буденного, 32	0101000020E61000002E56D4601ADE42404B033FAA61E14B40
56184	1	\N	\N	1	12311	\N	55.765455679441999	город Москва, ВАО, район Соколиная гора, Буденного просп, дом 35	Россия, Москва, проспект Буденного, 35	0101000020E61000002F1686C8E9DD424074435376FAE14B40
56182	1	\N	\N	1	12311	\N	55.766860999999999	город Москва, ВАО, район Соколиная гора, Буденного просп, дом 31		0101000020E61000004BB1A371A8DD4240F7C9518028E24B40
56179	1	\N	\N	1	12311	\N	55.771780711812298	город Москва, ВАО, район Соколиная гора, Буденного просп, дом 21	Россия, Москва, проспект Буденного, 21	0101000020E61000007A71E2AB1DDD42404B5645B8C9E24B40
56532	1	\N	\N	1	6686	\N	55.681939999999997	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Андропова просп., дом 17, корп. 3, адрес УИК: Кленовый бульв, дом 7	Россия, Москва, проспект Андропова, 17к3	0101000020E6100000C713419C87D54240C8EA56CF49D74B40
56531	1	\N	\N	1	6686	\N	55.681939999999997	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Андропова просп., дом 17, корп. 3, адрес УИК: Кленовый бульв, дом 8, корп. 1	Россия, Москва, проспект Андропова, 17к3	0101000020E6100000C713419C87D54240C8EA56CF49D74B40
56529	1	\N	\N	1	6686	\N	55.682558999999998	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Андропова просп., дом 17, корп. 5, адрес УИК: Кленовый бульв, дом 8, корп. 1	Россия, Москва, проспект Андропова, 17к5	0101000020E61000005CFFAECF9CD54240944BE3175ED74B40
56528	1	\N	\N	1	6686	\N	55.682558999999998	город Москва, ЮАО, район Нагатинский затон, Андропова просп, дом 17, корп. 5		0101000020E61000005CFFAECF9CD54240944BE3175ED74B40
9154	6	58	339	55196	44027	\N	55.407784999999997	деревня Малая Ультракова, Школьная, 4		0101000020E6100000B05758703F624E405166834C32B44B40
55935	1	\N	\N	1	7206	\N	55.874510999999998	город Москва, СВАО, район Южное Медведково, Шокальского пр, дом 7, корп. 2	Россия, Москва, проезд Шокальского, 7к2	0101000020E61000000403081F4AD24240027FF8F9EFEF4B40
55933	1	\N	\N	1	7206	\N	55.875656999999997	город Москва, СВАО, район Южное Медведково, Шокальского пр, дом 11/2	Россия, Москва, проезд Шокальского, 11	0101000020E6100000793F6EBF7CD24240B9C1508715F04B40
55932	1	\N	\N	1	7206	\N	55.875656999999997	город Москва, СВАО, район Южное Медведково, Шокальского пр, дом 11/3		0101000020E6100000793F6EBF7CD24240B9C1508715F04B40
55921	1	\N	\N	1	7206	\N	55.885443000000002	город Москва, СВАО, район Северное Медведково, Шокальского пр, дом 63А	Россия, Москва, проезд Шокальского, 63а	0101000020E6100000D4EFC2D66CD542406FBC3B3256F14B40
55650	1	\N	\N	1	4175	\N	55.842565	город Москва, САО, район Коптево, Черепановых пр, дом 44	Россия, Москва, проезд Черепановых, 44	0101000020E6100000897D022846C442408BE07F2BD9EB4B40
55647	1	\N	\N	1	4175	\N	55.838597	город Москва, САО, район Коптево, Черепановых пр, дом 22	Россия, Москва, проезд Черепановых, 22	0101000020E6100000E27668588CC2424009C3802557EB4B40
57176	1	\N	\N	1	6586	\N	55.827874000000001	Адрес помещения для голосования: город Москва, СЗАО, район Покровское-Стрешнево, Стратонавтов пр., дом 15, адрес УИК: Волоколамское шоссе, дом 96/2	Россия, Москва, проезд Стратонавтов, 15	0101000020E6100000E200FA7DFFB64240B79A75C6F7E94B40
56910	1	\N	\N	1	3435	\N	55.592083000000002	город Москва, ЮЗАО, район Ясенево, Карамзина пр, дом 13, корп. 3	Россия, Москва, проезд Карамзина, 13к3	0101000020E6100000CCB4FD2B2BC5424040C23060C9CB4B40
56908	1	\N	\N	1	3435	\N	55.592534999999998	город Москва, ЮЗАО, район Ясенево, Карамзина пр, дом 9, корп. 3	Россия, Москва, проезд Карамзина, 9к3	0101000020E6100000BBB88D06F0C44240205ED72FD8CB4B40
55497	1	\N	\N	1	2113	\N	55.737867000000001	город Москва, ЦАО, район Хамовники, Девичьего Поля пр, дом 4	Россия, Москва, проезд Девичьего Поля, 2	0101000020E6100000888384285FCA424019E6046D72DE4B40
55741	1	\N	\N	1	5332	\N	55.796596999999998	город Москва, САО, Хорошевский район, Аэропорта пр, дом 10	Россия, Москва, проезд Аэропорта, 10	0101000020E6100000F853E3A59BC24240BD8BF7E3F6E54B40
56004	1	\N	\N	1	12377	\N	56.005590148103501	город Москва, ВАО, район Восточный, Акуловского гидроузла пос, дом 25	Россия, Москва, поселок Акулово, 25	0101000020E6100000F627F1B913E64240A297512CB7004C40
57400	1	\N	\N	1	1054	\N	55.776375000000002	город Москва, ЦАО, Тверской район, Тверская застава пл, дом 7	Россия, Москва, площадь Тверская Застава, 7с1	0101000020E61000000B9C6C0377CA42404C37894160E34B40
55505	1	\N	\N	1	2221	\N	55.729872999999998	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Хользунова пер., дом 8, адрес УИК: Толстого Льва ул, дом 7		0101000020E6100000B2101D0247CA4240E09D7C7A6CDD4B40
55366	1	\N	\N	1	185	\N	55.765138999999998	город Москва, ЦАО, Басманный район, Огородная слобода пер, дом 6	Россия, Москва, переулок Огородная Слобода, 6с1	0101000020E61000008EE9094B3CD2424073F22213F0E14B40
55361	1	\N	\N	1	120	\N	55.750596000000002	город Москва, ЦАО, район Арбат, Каменная Слобода пер, дом 4	Россия, Москва, переулок Каменная Слобода, 4	0101000020E6100000FA28232E00CB424014419C8713E04B40
57392	1	\N	\N	1	920	\N	55.782770636931197	город Москва, СЗАО, район Хорошево-Мневники, наб. Новикова-Прибоя, 6 к.4,РЭУ 18 ОАО «АПРЭО»	Россия, Москва, набережная Новикова-Прибоя, 6к4	0101000020E6100000779FE3A3C5B94240ECA012D731E44B40
57288	1	\N	\N	1	6727	\N	55.848694999999999	город Москва, СЗАО, район Южное Тушино, Яна Райниса бульв, дом 43, корп. 2	Россия, Москва, бульвар Яна Райниса, 43к2	0101000020E6100000F1D7648D7AB44240ADA3AA09A2EC4B40
57191	1	\N	\N	1	6727	\N	55.852378999999999	Адрес помещения для голосования: город Москва, СЗАО, район Северное Тушино, Яна Райниса бульв., дом 4, корп. 2, адрес УИК: Героев Панфиловцев ул, дом 1, корп. 5		0101000020E6100000D237691A14B742400A664CC11AED4B40
57190	1	\N	\N	1	6727	\N	55.852378999999999	город Москва, СЗАО, район Северное Тушино, Яна Райниса бульв, дом 4, корп. 2	Россия, Москва, бульвар Яна Райниса, 4к2	0101000020E6100000D237691A14B742400A664CC11AED4B40
55657	1	\N	\N	1	4159	\N	55.833202999999997	город Москва, САО, район Коптево, Железняка матроса бульв, дом 22, корп. 1	Россия, Москва, бульвар Матроса Железняка, 22к1	0101000020E6100000B0C7444AB3C34240ECF65965A6EA4B40
55646	1	\N	\N	1	4159	\N	55.828758000000001	город Москва, САО, район Коптево, Железняка матроса бульв, дом 12	Россия, Москва, бульвар Матроса Железняка, 12	0101000020E610000002D8800871C342403126FDBD14EA4B40
55960	1	\N	\N	1	7633	\N	55.817765000000001	город Москва, ВАО, район Богородское, Рокоссовского маршала бульв, дом 34/2	Россия, Москва, бульвар Маршала Рокоссовского, 34	0101000020E6100000265646239FDB42401F680586ACE84B40
56800	1	\N	\N	1	1888	\N	55.565376000000001	город Москва, ЮЗАО, район Северное Бутово, Донского Дмитрия бульв, дом 14А	Россия, Москва, бульвар Дмитрия Донского, 14а	0101000020E6100000016BD5AE09C94240BEF8A23D5EC84B40
56799	1	\N	\N	1	1888	\N	55.569386999999999	город Москва, ЮЗАО, район Северное Бутово, Донского Дмитрия бульв, дом 6, корп. 1	Россия, Москва, бульвар Дмитрия Донского, 6к1	0101000020E61000006FD39FFD48C942403FE257ACE1C84B40
56798	1	\N	\N	1	1888	\N	55.568812000000001	город Москва, ЮЗАО, район Северное Бутово, Донского Дмитрия бульв, дом 6В	Россия, Москва, бульвар Дмитрия Донского, 6	0101000020E6100000C173EFE192C9424043C9E4D4CEC84B40
57244	1	\N	\N	1	7177	\N	55.782228000000003	город Москва, СЗАО, район Хорошево-Мневники, Карбышева генерала бульв, дом 15, корп. 3	Россия, Москва, бульвар Генерала Карбышева, 15к3	0101000020E61000002B4D4A41B7BB4240FC010F0C20E44B40
56257	1	\N	\N	1	12521	\N	55.698655000000002	город Москва, ЮВАО, район Кузьминки, Юных ленинцев ул, дом 40, корп. 4		0101000020E6100000CA8D226B0DE14240EC17EC866DD94B40
57242	1	\N	\N	1	7177	\N	55.780749999999998	город Москва, СЗАО, район Хорошево-Мневники, Карбышева генерала бульв, дом 9, корп. 2	Россия, Москва, бульвар Генерала Карбышева, 9к2	0101000020E6100000DDE9CE13CFBB42400E2DB29DEFE34B40
57236	1	\N	\N	1	7177	\N	55.778678999999997	город Москва, СЗАО, район Хорошево-Мневники, Карбышева генерала бульв, дом 10, корп. 4	Россия, Москва, бульвар Генерала Карбышева, 10к4	0101000020E61000004ED53DB2B9BC42407E8AE3C0ABE34B40
55976	1	\N	\N	1	7814	\N	55.732880323238	город Москва, ВАО, район Вешняки, Жемчуговой аллея, дом 7А	Россия, Москва, аллея Жемчуговой, 7	0101000020E610000042B5C189E8E942403DF20703CFDD4B40
56875	1	\N	\N	1	12352	\N	55.549419	город Москва, ЮЗАО, район Южное Бутово, Аллея Витте ул, дом 2, стр. 1	Россия, Москва, аллея Витте, 2с1	0101000020E6100000D47C957CECC4424088669E5C53C64B40
55956	1	\N	\N	1	7585	\N	55.829208999999999	город Москва, ВАО, район Богородское, Яузская аллея, дом 2	Россия, Москва, Яузская аллея, 2ас1	0101000020E61000004B7842AF3FD742404146408523EA4B40
55931	1	\N	\N	1	7271	\N	55.87594	город Москва, СВАО, район Южное Медведково, Ясный пр, дом 10А	Россия, Москва, Ясный проезд, 10а	0101000020E61000005C02F04FA9D042400EA14ACD1EF04B40
55930	1	\N	\N	1	7271	\N	55.876328999999998	город Москва, СВАО, район Южное Медведково, Ясный пр, дом 10, корп. 3	Россия, Москва, Ясный проезд, 10к3	0101000020E61000003D2AFEEF88D04240A8C4758C2BF04B40
55929	1	\N	\N	1	7271	\N	55.876035999999999	город Москва, СВАО, район Южное Медведково, Ясный пр, дом 24А	Россия, Москва, Ясный проезд, 24а	0101000020E610000018D1764CDDCF4240300F99F221F04B40
55928	1	\N	\N	1	7271	\N	55.877602000000003	город Москва, СВАО, район Южное Медведково, Ясный пр, дом 21	Россия, Москва, Ясный проезд, 21	0101000020E6100000FA7FD59123CF4240BD73284355F04B40
56595	1	\N	\N	1	12442	\N	55.607811917378299	город Москва, ЮАО, район Орехово-Борисово Южное, Ясеневая ул, дом 35, корп. 2	Россия, Москва, Ясеневая улица, 35к2	0101000020E6100000A8ACA6EB89DE4240E50E9BC8CCCD4B40
56592	1	\N	\N	1	12426	\N	55.605525999999998	город Москва, ЮАО, район Орехово-Борисово Южное, Ясеневая ул, дом 21, корп. 3	Россия, Москва, Ясеневая улица, 21к3	0101000020E6100000890B40A374DD424058703FE081CD4B40
56594	1	\N	\N	1	12428	\N	55.607824000000001	Адрес помещения для голосования: город Москва, ЮАО, район Орехово-Борисово Южное, Ясеневая ул., дом 35, корп. 2, адрес УИК: Ясеневая ул, дом 41, корп. 1		0101000020E6100000850A0E2F88DE4240A9DC442DCDCD4B40
56586	1	\N	\N	1	12428	\N	55.598954999999997	город Москва, ЮАО, район Орехово-Борисово Южное, Ясеневая ул, дом 8, корп. 2	Россия, Москва, Ясеневая улица, 8к2	0101000020E6100000C669882AFCDB42404963B48EAACC4B40
56966	1	\N	\N	1	4188	\N	55.742381999999999	город Москва, ЗАО, район Кунцево, Ярцевская ул, дом 36, корп. 2	Россия, Москва, Ярцевская улица, 36к2	0101000020E610000010C99063EBB54240CD91955F06DF4B40
55948	1	\N	\N	1	7381	\N	55.851160999999998	Адрес помещения для голосования: город Москва, СВАО, Ярославский район, Ярославское шоссе, дом 8, корп. 7, адрес УИК: Ярославское шоссе, дом 4, корп 1	Россия, Москва, Ярославское шоссе, 8к7	0101000020E61000001E87C1FC15D84240B950F9D7F2EC4B40
55947	1	\N	\N	1	7381	\N	55.851160999999998	город Москва, СВАО, Ярославский район, Ярославское шоссе, дом 8, корп. 7	Россия, Москва, Ярославское шоссе, 8к7	0101000020E61000001E87C1FC15D84240B950F9D7F2EC4B40
55946	1	\N	\N	1	7381	\N	55.852789000000001	Адрес помещения для голосования: город Москва, СВАО, Ярославский район, Ярославское шоссе, дом 8, корп. 6, адрес УИК: Ярославское шоссе, дом 2, корп. 2	Россия, Москва, Ярославское шоссе, 8к6	0101000020E6100000702711E15FD84240BCB1A03028ED4B40
55945	1	\N	\N	1	7381	\N	55.858887000000003	город Москва, СВАО, Ярославский район, Ярославское шоссе, дом 26	Россия, Москва, Ярославское шоссе, 26	0101000020E6100000C3D7D7BAD4D84240D3FA5B02F0ED4B40
55944	1	\N	\N	1	7381	\N	55.866652000000002	город Москва, СВАО, Ярославский район, Ярославское шоссе, дом 116, корп. 1	Россия, Москва, Ярославское шоссе, 116к1	0101000020E6100000691EC022BFDA4240AA81E673EEEE4B40
55943	1	\N	\N	1	7381	\N	55.871409999999997	город Москва, СВАО, Ярославский район, Ярославское шоссе, дом 126А	Россия, Москва, Ярославское шоссе, 126а	0101000020E6100000CD04C3B986DB424024B4E55C8AEF4B40
55939	1	\N	\N	1	7381	\N	55.880884000000002	город Москва, СВАО, Ярославский район, Ярославское шоссе, дом 147	Россия, Москва, Ярославское шоссе, 147	0101000020E61000001500E31934DC4240EBC891CEC0F04B40
55757	1	\N	\N	1	5520	\N	55.827151000000001	город Москва, СВАО, Алексеевский район, Ярославская ул, дом 27	Россия, Москва, Ярославская улица, 27	0101000020E6100000D1764CDD95D3424046ED7E15E0E94B40
55756	1	\N	\N	1	12503	\N	55.822502142071599	город Москва, СВАО, Алексеевский район, Ярославская ул, дом 17/21		0101000020E6100000F19BC24A05D342408272DBBE47E94B40
55830	1	\N	\N	1	6316	\N	55.872793999999999	город Москва, СВАО, Лосиноостровский район, Янтарный пр, дом 2	Россия, Москва, Янтарный проезд, 2	0101000020E610000032B08EE387D842409012BBB6B7EF4B40
56533	1	\N	\N	1	12901	\N	55.687010000000001	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Якорная ул., дом 6, адрес УИК: Судостроительная ул, дом 27, корп. 2		0101000020E61000006155BDFC4ED74240320395F1EFD74B40
57373	1	\N	\N	1	13098	\N	55.828622000000003	город Москва, СВАО, Бутырский район, Яблочкова ул., 43, , Библиотека № 82		0101000020E61000004BB0389CF9C94240815F234910EA4B40
55814	1	\N	\N	1	13098	\N	55.828622000000003	город Москва, СВАО, Бутырский район, Яблочкова ул, дом 43		0101000020E61000004BB0389CF9C94240815F234910EA4B40
55813	1	\N	\N	1	13098	\N	55.824612000000002	город Москва, СВАО, Бутырский район, Яблочкова ул, дом 35Г		0101000020E6100000F01472A59EC94240D0F1D1E28CE94B40
55809	1	\N	\N	1	13098	\N	55.817425999999998	город Москва, СВАО, Бутырский район, Яблочкова ул, дом 10		0101000020E6100000D00B772E8CCA42403673486AA1E84B40
57140	1	\N	\N	1	12823	\N	55.900128000000002	город Москва, СЗАО, район Куркино, Юровская ул, дом 97		0101000020E6100000139CFA40F2B04240611BF16437F34B40
56874	1	\N	\N	1	2955	\N	55.535677	город Москва, ЮЗАО, район Южное Бутово, Южнобутовская ул, дом 76, корп. 1	Россия, Москва, Южнобутовская улица, 76к1	0101000020E610000063450DA661C24240151C5E1091C44B40
56873	1	\N	\N	1	12967	\N	55.530667999999999	город Москва, ЮЗАО, район Южное Бутово, Южнобутовская ул, дом 135А		0101000020E61000004D124BCADDC142405184D4EDECC34B40
56871	1	\N	\N	1	12967	\N	55.539048999999999	город Москва, ЮЗАО, район Южное Бутово, Южнобутовская ул, дом 52, корп. 2		0101000020E6100000BCAFCA85CAC3424083F8C08EFFC44B40
56270	1	\N	\N	1	3711	\N	55.756791	город Москва, ЮВАО, район Лефортово, Энергетический пр, дом 3А	Россия, Москва, Энергетический проезд, 3	0101000020E61000007FFB3A70CEDA42401D740987DEE04B40
56273	1	\N	\N	1	13018	\N	55.758802000000003	город Москва, ЮВАО, район Лефортово, Энергетическая ул, дом 5		0101000020E61000000932022A1CDB4240D811876C20E14B40
56423	1	\N	\N	1	5604	\N	55.600501000000001	город Москва, ЮАО, район Бирюлево Восточное, Элеваторная ул, дом 4, корп. 2	Россия, Москва, Элеваторная улица, 4к2	0101000020E6100000FF5D9F39EBD342408F1B7E37DDCC4B40
57260	1	\N	\N	1	12596	\N	55.808134000000003	город Москва, СЗАО, район Щукино, Щукинская ул, дом 5		0101000020E6100000511212691BBD4240916456EF70E74B40
57078	1	\N	\N	1	12892	\N	55.646061000000003	город Москва, ЗАО, район Солнцево, Щорса ул, дом 6, корп. 1		0101000020E610000082C98D226BB342404C1C7920B2D24B40
56174	1	\N	\N	1	12330	\N	55.781923333806098	город Москва, ВАО, район Соколиная гора, Щербаковская ул, дом 36	Россия, Москва, Щербаковская улица, 36а	0101000020E6100000C974E8F4BCDD4240BF7E880D16E44B40
56173	1	\N	\N	1	12330	\N	55.780678999999999	город Москва, ВАО, район Соколиная гора, Щербаковская ул, дом 38		0101000020E61000002D060FD3BEDD424045D61A4AEDE34B40
56160	1	\N	\N	1	2044	\N	55.808380999999997	город Москва, ВАО, район Северное Измайлово, Щелковское шоссе, дом 82Б	Россия, Москва, Щелковское шоссе, 82б	0101000020E6100000643F8BA548E8424098DA520779E74B40
56156	1	\N	\N	1	2044	\N	55.808720000000001	город Москва, ВАО, район Северное Измайлово, Щелковское шоссе, дом 58А		0101000020E6100000B32616F88AE6424081CF0F2384E74B40
56151	1	\N	\N	1	2044	\N	55.808093	город Москва, ВАО, район Северное Измайлово, Щелковское шоссе, дом 26А	Россия, Москва, Щелковское шоссе, 26а	0101000020E6100000E085ADD9CAE34240329067976FE74B40
56013	1	\N	\N	1	2044	\N	55.813592	город Москва, ВАО, район Гольяново, Щелковское шоссе, дом 79А	Россия, Москва, Щелковское шоссе, 79а	0101000020E6100000BDE47FF277E74240C4245CC823E84B40
56012	1	\N	\N	1	2044	\N	55.811107999999997	город Москва, ВАО, район Гольяново, Щелковское шоссе, дом 77/79	Россия, Москва, Щелковское шоссе, 77	0101000020E61000007AE063B0E2E6424011C30E63D2E74B40
56011	1	\N	\N	1	2044	\N	55.811107999999997	город Москва, ВАО, район Гольяново, Щелковское шоссе, дом 77	Россия, Москва, Щелковское шоссе, 77	0101000020E61000007AE063B0E2E6424011C30E63D2E74B40
56006	1	\N	\N	1	2044	\N	55.810262185686803	город Москва, ВАО, район Гольяново, Щелковское шоссе, дом 29, стр. 1	Россия, Москва, Щелковское шоссе, 29	0101000020E610000084F57F0EF3E3424085984BAAB6E74B40
55354	1	\N	\N	1	8161	\N	55.746613000000004	город Москва, ЦАО, район Арбат, Шубинский пер, дом 6	Россия, Москва, Шубинский переулок, 6с1	0101000020E6100000EB73B515FBC942405DE2C80391DF4B40
57278	1	\N	\N	1	7635	\N	55.848239999999997	город Москва, СЗАО, район Южное Тушино, Штурвальная ул, дом 7, корп. 2	Россия, Москва, Штурвальная улица, 7к2	0101000020E6100000726A6798DAB842405B94D92093EC4B40
56359	1	\N	\N	1	12834	\N	55.689559533765099	город Москва, ЮВАО, район Печатники, Шоссейная ул, дом 7	Россия, Москва, район Печатники, Шоссейная улица, 7	0101000020E6100000A648BE1248DD42409C50888043D84B40
57007	1	\N	\N	1	13022	\N	55.640985000000001	Адрес помещения для голосования: город Москва, ЗАО, район Ново-Переделкино, Шолохова ул., дом 20, адрес УИК: Чоботовская ул., дом 3, корп. 1, Чоботовская ул, дом 3, корп. 1		0101000020E61000002C2CB81FF0AC4240001DE6CB0BD24B40
57005	1	\N	\N	1	13022	\N	55.640985000000001	город Москва, ЗАО, район Ново-Переделкино, Шолохова ул, дом 20		0101000020E61000002C2CB81FF0AC4240001DE6CB0BD24B40
56992	1	\N	\N	1	13022	\N	55.638866	город Москва, ЗАО, район Ново-Переделкино, Шолохова ул, дом 9		0101000020E61000000C21E7FD7FAC42405F43705CC6D14B40
56991	1	\N	\N	1	13022	\N	55.642636000000003	город Москва, ЗАО, район Ново-Переделкино, Шолохова ул, дом 19		0101000020E6100000282CF180B2AB4240BB9D7DE541D24B40
55445	1	\N	\N	1	1409	\N	55.756604000000003	город Москва, ЦАО, Пресненский район, Шмитовский пр, дом 26	Россия, Москва, Шмитовский проезд, 26	0101000020E6100000CAA4863600C54240EB025E66D8E04B40
56402	1	\N	\N	1	12550	\N	55.693717999999997	город Москва, ЮВАО, район Текстильщики, Шкулева ул, дом 13/25, корп. 2		0101000020E61000006FD921FE61DF4240C1525DC0CBD84B40
55918	1	\N	\N	1	13030	\N	55.889279999999999	город Москва, СВАО, район Северное Медведково, Широкая ул, дом 21А		0101000020E610000081EB8A19E1D54240527E52EDD3F14B40
57382	1	\N	\N	1	12943	\N	55.889760000000003	город Москва, СВАО, район Северное Медведково, ул. Широкая, 1А, гимназия № 1506		0101000020E6100000B37BF2B050D34240FDA4DAA7E3F14B40
55916	1	\N	\N	1	12943	\N	55.889760000000003	город Москва, СВАО, район Северное Медведково, Широкая ул, дом 1А		0101000020E6100000B37BF2B050D34240FDA4DAA7E3F14B40
56587	1	\N	\N	1	12423	\N	55.596136999999999	город Москва, ЮАО, район Орехово-Борисово Южное, Шипиловский пр, дом 73	Россия, Москва, Шипиловский проезд, 73	0101000020E61000005F42058717DC4240C0779B374ECC4B40
56583	1	\N	\N	1	12423	\N	55.605223862564998	город Москва, ЮАО, район Орехово-Борисово Южное, Шипиловский пр, дом 57	Россия, Москва, Шипиловский проезд, 57	0101000020E6100000938FDD054ADA42408D60E3FA77CD4B40
56581	1	\N	\N	1	12423	\N	55.613721134412401	город Москва, ЮАО, район Орехово-Борисово Северное, Шипиловский пр, дом 37, корп. 2	Россия, Москва, Шипиловский проезд, 37к2	0101000020E6100000EA58A5F44CD9424028EFE3688ECE4B40
56578	1	\N	\N	1	6380	\N	55.617114000000001	город Москва, ЮАО, район Орехово-Борисово Северное, Шипиловская ул, дом 18, корп. 2	Россия, Москва, Шипиловская улица, 18к2	0101000020E6100000DD0A613596DA4240AEF36F97FDCE4B40
56496	1	\N	\N	1	6380	\N	55.619512999999998	город Москва, ЮАО, район Зябликово, Шипиловская ул, дом 46, корп. 3	Россия, Москва, Шипиловская улица, 46к3	0101000020E61000005A10CAFB38DE42403239B5334CCF4B40
56573	1	\N	\N	1	12497	\N	55.622441000000002	город Москва, ЮАО, район Орехово-Борисово Северное, Шипиловская ул, дом 27, корп. 2	Россия, Москва, Шипиловская улица, 27к2	0101000020E610000051D9B0A6B2DC424043588D25ACCF4B40
56261	1	\N	\N	1	12582	\N	55.745144000000003	город Москва, ЮВАО, район Лефортово, Шепелюгинская ул, дом 21		0101000020E6100000D4B9A29410DA4240C367EBE060DF4B40
55802	1	\N	\N	1	5990	\N	55.896014000000001	город Москва, СВАО, район Бибирево, Шенкурский пр, дом 15	Россия, Москва, Шенкурский проезд, 15	0101000020E610000007616EF772CB42400B613596B0F24B40
55801	1	\N	\N	1	5990	\N	55.896014000000001	Адрес помещения для голосования: город Москва, СВАО, район Бибирево, Шенкурский пр., дом 15, адрес УИК: Шенкурский пр, дом 9	Россия, Москва, Шенкурский проезд, 15	0101000020E610000007616EF772CB42400B613596B0F24B40
55799	1	\N	\N	1	5990	\N	55.893999999999998	город Москва, СВАО, район Бибирево, Шенкурский пр, дом 8В	Россия, Москва, Шенкурский проезд, 8	0101000020E6100000226FB9FAB1CB4240DF4F8D976EF24B40
55798	1	\N	\N	1	5990	\N	55.891359999999999	город Москва, СВАО, район Бибирево, Шенкурский пр, дом 4А	Россия, Москва, Шенкурский проезд, 4а	0101000020E6100000C442AD69DECB4240357BA01518F24B40
56668	1	\N	\N	1	12689	\N	55.690004000000002	город Москва, ЮЗАО, Академический район, Шверника ул, дом 19, корп. 2		0101000020E61000001AF7E6374CCC4240FA0D130D52D84B40
56667	1	\N	\N	1	12689	\N	55.691968000000003	город Москва, ЮЗАО, Академический район, Шверника ул, дом 17, корп. 2		0101000020E610000013B69F8CF1CB424074F04C6892D84B40
56666	1	\N	\N	1	12689	\N	55.691272925354802	город Москва, ЮЗАО, Академический район, Шверника ул, дом 10		0101000020E610000052D2C3D0EACA4240CDCD37A27BD84B40
56368	1	\N	\N	1	12988	\N	55.730080999999998	город Москва, ЮВАО, Рязанский район, Шатурская ул, дом 1		0101000020E61000003067B62BF4E142402A37514B73DD4B40
56562	1	\N	\N	1	7010	\N	55.653776000000001	город Москва, ЮАО, Нагорный район, Чонгарский бульв, дом 12	Россия, Москва, Чонгарский бульвар, 12	0101000020E610000086CABF9657CE4240717495EEAED34B40
57009	1	\N	\N	1	4503	\N	55.641238999999999	город Москва, ЗАО, район Ново-Переделкино, Чоботовская ул, дом 3, корп. 1	Россия, Москва, Чоботовская улица, 3к1	0101000020E6100000CF2C095053AD4240BAF59A1E14D24B40
56990	1	\N	\N	1	4503	\N	55.645206999999999	город Москва, ЗАО, район Ново-Переделкино, Чоботовская ул, дом 19	Россия, Москва, Чоботовская улица, 19	0101000020E6100000B77C24253DAC42403C139A2496D24B40
57011	1	\N	\N	1	12634	\N	55.645364999999998	город Москва, ЗАО, район Ново-Переделкино, Чоботовская ул, дом 17А		0101000020E6100000CBBC55D7A1AC4240D47D00529BD24B40
57010	1	\N	\N	1	12634	\N	55.645206999999999	Адрес помещения для голосования: город Москва, ЗАО, район Ново-Переделкино, Чоботовская ул., дом 19, адрес УИК: Мухиной скульптора ул., дом 2, Мухиной скульптора ул, дом 2		0101000020E6100000B77C24253DAC42403C139A2496D24B40
56040	1	\N	\N	1	12748	\N	55.781018000000003	город Москва, ВАО, район Ивановское, Чечулина ул, дом 28		0101000020E6100000005471E316EB42402ECBD765F8E34B40
56038	1	\N	\N	1	12748	\N	55.780264000000003	город Москва, ВАО, район Ивановское, Чечулина ул, дом 3, корп. 1		0101000020E61000002995F0845EE94240821FD5B0DFE34B40
56872	1	\N	\N	1	2913	\N	55.532003000000003	город Москва, ЮЗАО, район Южное Бутово, Чечерский пр, дом 80	Россия, Москва, Чечерский проезд, 80	0101000020E6100000B612BA4BE2C24240DC2F9FAC18C44B40
56870	1	\N	\N	1	2913	\N	55.534560999999997	город Москва, ЮЗАО, район Южное Бутово, Чечерский пр, дом 42	Россия, Москва, Чечерский проезд, 42	0101000020E6100000A03715A930C44240C85BAE7E6CC44B40
56869	1	\N	\N	1	2913	\N	55.5383	город Москва, ЮЗАО, район Южное Бутово, Чечерский пр, дом 22, корп. 1	Россия, Москва, Чечерский проезд, 22к1	0101000020E610000043C879FF1FC54240E9B7AF03E7C44B40
56868	1	\N	\N	1	2913	\N	55.542797999999998	город Москва, ЮЗАО, район Южное Бутово, Чечерский пр, дом 6	Россия, Москва, Чечерский проезд, 6	0101000020E6100000FFAF3A72A4C54240C72AA5677AC54B40
56650	1	\N	\N	1	12348	\N	55.601518181623703	город Москва, ЮАО, район Чертаново Южное, Чертановская ул, дом 60А	Россия, Москва, Чертановская улица, 60а	0101000020E6100000416150A6D1CA424048FAB48AFECC4B40
56634	1	\N	\N	1	12348	\N	55.609607758839303	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Чертановская ул., дом 44А, адрес УИК: Чертановская ул, дом 42, корп. 3	Россия, Москва, Чертановская улица, 44а	0101000020E610000003EFE4D363CB4240A3B08BA207CE4B40
56649	1	\N	\N	1	12319	\N	55.599046000000001	город Москва, ЮАО, район Чертаново Южное, Чертановская ул, дом 62А	Россия, Москва, Чертановская улица, 62а	0101000020E6100000E738B709F7CA42405A66118AADCC4B40
56637	1	\N	\N	1	12319	\N	55.6169971212557	город Москва, ЮАО, район Чертаново Центральное, Чертановская ул, дом 27		0101000020E6100000DE1CAED51ECC4240745DF8C1F9CE4B40
56636	1	\N	\N	1	12319	\N	55.616571900804303	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Чертановская ул., дом 27, адрес УИК: Чертановская ул, дом 21, корп. 1		0101000020E6100000C2A563CE33CC42408DD0CFD4EBCE4B40
56633	1	\N	\N	1	12319	\N	55.609462000000001	город Москва, ЮАО, район Чертаново Центральное, Чертановская ул, дом 44А		0101000020E61000000457790261CB4240CF13CFD902CE4B40
56620	1	\N	\N	1	12319	\N	55.634126000000002	город Москва, ЮАО, район Чертаново Северное, Чертановская ул, дом 9А		0101000020E61000001366DAFE95CB42408BC56F0A2BD14B40
56615	1	\N	\N	1	12319	\N	55.638128118611	город Москва, ЮАО, район Чертаново Северное, Чертановская ул, дом 1А, корп. 3	Россия, Москва, Чертановская улица, 1ак3	0101000020E6100000C8D11C59F9CD4240B954A52DAED14B40
56614	1	\N	\N	1	12319	\N	55.637790269748002	город Москва, ЮАО, район Чертаново Северное, Чертановская ул, дом 1А, копр. 3		0101000020E61000003524EEB1F4CD4240A1DB4B1AA3D14B40
56565	1	\N	\N	1	7036	\N	55.646045000000001	город Москва, ЮАО, Нагорный район, Черноморский бульв, дом 8	Россия, Москва, Черноморский бульвар, 8	0101000020E610000075E4486760CE4240465F419AB1D24B40
55828	1	\N	\N	1	13223	\N	55.896917999999999	город Москва, СВАО, район Лианозово, Череповецкая ул, дом 10А		0101000020E61000000A664CC11AC94240CC988235CEF24B40
56042	1	\N	\N	1	404	\N	55.776781	город Москва, ВАО, район Ивановское, Челябинская ул, дом 20	Россия, Москва, Челябинская улица, 20	0101000020E610000068EBE0606FEA4240BC934F8F6DE34B40
56039	1	\N	\N	1	13165	\N	55.777641000000003	город Москва, ВАО, район Ивановское, Челябинская ул, дом 9		0101000020E6100000C571E0D572E94240AE8383BD89E34B40
55923	1	\N	\N	1	12692	\N	55.914480193258399	город Москва, СВАО, район Северный, Челобитьевское шоссе, дом 2	Россия, Москва, Челобитьевское шоссе, 2к1	0101000020E610000015A930B610C642404C6C3EAE0DF54B40
55537	1	\N	\N	1	1140	\N	55.809933999999998	город Москва, САО, район Аэропорт, Часовая ул, дом 22	Россия, Москва, Часовая улица, 22/2с1	0101000020E6100000BB7CEBC37AC3424090F5D4EAABE74B40
55367	1	\N	\N	1	13191	\N	55.763097999999999	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Чаплыгина ул., дом 9, стр. 3, адрес УИК: Фурманный пер, дом 13, стр. 8		0101000020E610000068CC24EA05D342404ED2FC31ADE14B40
55694	1	\N	\N	1	4747	\N	55.801212	Адрес помещения для голосования: город Москва, САО, район Сокол, Чапаевский пер., дом 6, адрес УИК: Новопесчаная ул, дом 2А	Россия, Москва, Чапаевский переулок, 6/1	0101000020E6100000C68B852172C24240D594641D8EE64B40
56843	1	\N	\N	1	12767	\N	55.669727227109298	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Цюрупы ул., дом 10, адрес УИК: Цюрупы ул, дом 3	Россия, Москва, улица Цюрупы, 10к1	0101000020E6100000CA1649BBD1C94240C51F459DB9D54B40
56837	1	\N	\N	1	12767	\N	55.670397000000001	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Цюрупы ул., дом 14Б, адрес УИК: Новочеремушкинская ул, дом 49		0101000020E61000004F1E166A4DC94240132BA391CFD54B40
56836	1	\N	\N	1	12767	\N	55.670397000000001	город Москва, ЮЗАО, район Черемушки, Цюрупы ул, дом 14Б		0101000020E61000004F1E166A4DC94240132BA391CFD54B40
56819	1	\N	\N	1	12767	\N	55.669274999999999	город Москва, ЮЗАО, район Черемушки, Цюрупы ул, дом 14А		0101000020E6100000B037312427C94240E4839ECDAAD54B40
56913	1	\N	\N	1	13202	\N	55.6129131248221	город Москва, ЗАО, район Внуково, Центральная ул, дом 15а	Россия, Москва, поселок Внуково, Центральная улица, 15а	0101000020E610000027C0B0FCF9A442408925E5EE73CE4B40
55736	1	\N	\N	1	3488	\N	55.780121999999999	город Москва, САО, Хорошевский район, Хорошевское шоссе, дом 82, корп. 7	Россия, Москва, Хорошевское шоссе, 82к7	0101000020E6100000FE4465C39AC24240EF71A609DBE34B40
55735	1	\N	\N	1	3488	\N	55.777945000000003	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Хорошевское шоссе, дом 64А, стр. 2, адрес УИК: Хорошевское шоссе, дом 66		0101000020E6100000802C4487C0C342401A8BA6B393E34B40
55734	1	\N	\N	1	3488	\N	55.777945000000003	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Хорошевское шоссе, дом 64А, стр. 2, адрес УИК: Хорошевское шоссе, дом 52, корп. 2	Россия, Москва, Хорошевское шоссе, 64ас2	0101000020E6100000802C4487C0C342401A8BA6B393E34B40
55733	1	\N	\N	1	3488	\N	55.777084000000002	город Москва, САО, Хорошевский район, Хорошевское шоссе, дом 52, корп. 2	Россия, Москва, Хорошевское шоссе, 52к2	0101000020E610000047E6913F18C44240581F0F7D77E34B40
55729	1	\N	\N	1	3488	\N	55.773727000000001	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Хорошевское шоссе, дом 3, адрес УИК: Магистральная 5-я ул, дом 8		0101000020E61000000E6954E064C542401F84807C09E34B40
55745	1	\N	\N	1	5355	\N	55.790452999999999	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Ходынский бульв., дом 21А, адрес УИК: Ходынский бульв, дом 15	Россия, Москва, Ходынский бульвар, 21а	0101000020E6100000A4FFE55AB4C2424036035C902DE54B40
55744	1	\N	\N	1	5355	\N	55.784368999999998	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Ходынский бульв., дом 7, адрес УИК: Полины Осипенко ул, дом 18, корп. 2		0101000020E6100000E19BA6CF0EC44240847F113466E44B40
55743	1	\N	\N	1	5355	\N	55.784368999999998	город Москва, САО, Хорошевский район, Ходынский бульв, дом 7	Россия, Москва, Ходынский бульвар, 7	0101000020E6100000E19BA6CF0EC44240847F113466E44B40
56203	1	\N	\N	1	13157	\N	55.717441999999998	город Москва, ЮВАО, район Выхино-Жулебино, Хлобыстова ул, дом 14, корп. 3		0101000020E6100000465ED6C402E742406F63B323D5DB4B40
57384	1	\N	\N	1	801	\N	55.856068	город Москва, СВАО, Ярославский район, Хибинский пр., 10, (ГОУ СПО Строительный колледж № 12)		0101000020E61000008CDCD3D51DD742407993DFA293ED4B40
56849	1	\N	\N	1	2593	\N	55.652090000000001	город Москва, ЮЗАО, район Черемушки, Херсонская ул, дом 27, корп. 2	Россия, Москва, Херсонская улица, 27а	0101000020E61000008E3C1059A4C742403A0664AF77D34B40
56847	1	\N	\N	1	2593	\N	55.655121999999999	город Москва, ЮЗАО, район Черемушки, Херсонская ул, дом 30, корп. 3	Россия, Москва, Херсонская улица, 30к3	0101000020E6100000F8A6E9B303C84240EF71A609DBD34B40
56850	1	\N	\N	1	12663	\N	55.652090000000001	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Херсонская ул., дом 27, корп. 2, адрес УИК: Обручева ул, дом 55А		0101000020E61000008E3C1059A4C742403A0664AF77D34B40
56223	1	\N	\N	1	3097	\N	55.700100999999997	город Москва, ЮВАО, район Выхино-Жулебино, Хвалынский бульв, дом 4, корп. 4	Россия, Москва, Хвалынский бульвар, 4к4	0101000020E610000075AF93FAB2EC4240CD72D9E89CD94B40
56447	1	\N	\N	1	5852	\N	55.591014000000001	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Харьковский пр., дом 9Б, адрес УИК: Булатниковский пр, дом 6, корп. 1	Россия, Москва, Харьковский проезд, 9б	0101000020E61000003A3FC571E0D1424034BDC458A6CB4B40
56446	1	\N	\N	1	5852	\N	55.590175000000002	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Харьковский пр., дом 9А, адрес УИК: Медынская ул, дом 1, корп. 3		0101000020E61000006002B7EEE6D142405AF5B9DA8ACB4B40
56444	1	\N	\N	1	5852	\N	55.590175000000002	город Москва, ЮАО, район Бирюлево Западное, Харьковский пр, дом 9А	Россия, Москва, Харьковский проезд, 9а	0101000020E61000006002B7EEE6D142405AF5B9DA8ACB4B40
55515	1	\N	\N	1	12770	\N	55.720367000000003	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Хамовнический Вал ул., дом 26, адрес УИК: Хамовнический Вал ул, дом 24		0101000020E6100000E6797077D6C842400F0F61FC34DC4B40
55514	1	\N	\N	1	12770	\N	55.720367000000003	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Хамовнический Вал ул., дом 26, адрес УИК: Доватора ул, дом 3		0101000020E6100000E6797077D6C842400F0F61FC34DC4B40
56143	1	\N	\N	1	1934	\N	55.803555000000003	город Москва, ВАО, район Преображенское, Халтуринская ул, дом 16	Россия, Москва, Халтуринская улица, 16	0101000020E610000095BA641C23DD4240C6C4E6E3DAE64B40
56144	1	\N	\N	1	12951	\N	55.804810000000003	Адрес помещения для голосования: город Москва, ВАО, район Преображенское, Халтуринская ул., дом 18, адрес УИК: Знаменская ул, дом 23		0101000020E61000006FD40AD3F7DC424034BF9A0304E74B40
56469	1	\N	\N	1	6104	\N	55.713202000000003	город Москва, ЮАО, Даниловский район, Хавская ул, дом 15	Россия, Москва, Хавская улица, 15с2	0101000020E610000031992A1895CE42408DB800344ADB4B40
56470	1	\N	\N	1	13077	\N	55.717568	Адрес помещения для голосования: город Москва, ЮАО, Даниловский район, Хавская ул., дом 5, адрес УИК: Лестева ул, дом 21, корп. 1		0101000020E61000006344A2D0B2CE4240FC53AA44D9DB4B40
56024	1	\N	\N	1	12539	\N	55.816519999999997	город Москва, ВАО, район Гольяново, Хабаровская ул, дом 4А		0101000020E61000002E724F5777EA4240D44334BA83E84B40
56023	1	\N	\N	1	12539	\N	55.818644999999997	город Москва, ВАО, район Гольяново, Хабаровская ул, дом 8А		0101000020E610000054E57B4622EA42405704FF5BC9E84B40
56022	1	\N	\N	1	12539	\N	55.823677000000004	город Москва, ВАО, район Гольяново, Хабаровская ул, дом 18, стр. 2		0101000020E6100000B1170AD80EEA4240D4BB783F6EE94B40
56101	1	\N	\N	1	1357	\N	55.746228000000002	город Москва, ВАО, район Новогиреево, Фрязевская ул, дом 5А	Россия, Москва, Фрязевская улица, 5	0101000020E6100000D0D6C1C1DEE8424004AE2B6684DF4B40
56102	1	\N	\N	1	13186	\N	55.746198	город Москва, ВАО, район Новогиреево, Фрязевская ул, дом 7		0101000020E6100000917C259012E94240992B836A83DF4B40
55508	1	\N	\N	1	2252	\N	55.723460000000003	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Фрунзенская наб., дом 30, адрес УИК: Фрунзенская наб, дом 24/1		0101000020E61000004A79AD84EECA42406AFB57569ADC4B40
55507	1	\N	\N	1	2252	\N	55.723460000000003	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Фрунзенская наб., дом 30, адрес УИК: Комсомольский пр, дом 15	Россия, Москва, Фрунзенская набережная, 30с	0101000020E61000004A79AD84EECA42406AFB57569ADC4B40
56145	1	\N	\N	1	1975	\N	55.658448999999997	город Москва, ЮАО, Нагорный район, Фруктовая ул, дом 9	Россия, Москва, Фруктовая улица, 9	0101000020E61000009599D2FA5BCE4240BD8A8C0E48D44B40
56691	1	\N	\N	1	13034	\N	55.699071000000004	город Москва, ЮЗАО, Гагаринский район, Фотиевой ул, дом 14, корп. 1		0101000020E6100000003CA24275C74240804A95287BD94B40
57195	1	\N	\N	1	12851	\N	55.857456999999997	город Москва, СЗАО, район Северное Тушино, Фомичевой ул, дом 1, корп. 1		0101000020E6100000B6114F7633B94240F65CA626C1ED4B40
57194	1	\N	\N	1	12851	\N	55.856755	Адрес помещения для голосования: город Москва, СЗАО, район Северное Тушино, Фомичевой ул., дом 5, адрес УИК: Фомичевой ул, дом 7, корп. 2		0101000020E6100000863DEDF0D7B842409DD7D825AAED4B40
57192	1	\N	\N	1	12851	\N	55.856088	Адрес помещения для голосования: город Москва, СЗАО, район Северное Тушино, Фомичевой ул., дом 5, корп. 1, адрес УИК: Героев Панфиловцев ул, дом 8, корп. 1		0101000020E610000035D07CCEDDB84240C03FA54A94ED4B40
55611	1	\N	\N	1	13054	\N	55.854734000000001	город Москва, САО, Головинский район, Флотская ул, дом 64		0101000020E6100000D93F4F0306C14240BF6378EC67ED4B40
55714	1	\N	\N	1	13182	\N	55.857644000000001	город Москва, САО, район Ховрино, Флотская ул, дом 15, корп. 1	Россия, Москва, Левобережный район, Флотская улица, 15к1	0101000020E610000062F9F36DC1C0424029CE5147C7ED4B40
57120	1	\N	\N	1	6004	\N	55.765740999999998	город Москва, ЗАО, район Филевский парк, Филёвский бульв, дом 11а	Россия, Москва, Филевский бульвар, 11а	0101000020E61000006B9F8EC70CBE4240691A14CD03E24B40
57119	1	\N	\N	1	6004	\N	55.763938000000003	город Москва, ЗАО, район Филевский парк, Филёвский бульв, дом 13	Россия, Москва, Филевский бульвар, 13к1	0101000020E6100000FE80070610BE4240F9156BB8C8E14B40
57118	1	\N	\N	1	6004	\N	55.764049999999997	город Москва, ЗАО, район Филевский парк, Филёвский бульв, дом 3	Россия, Москва, Филевский бульвар, 3	0101000020E6100000B2BD16F4DEBE42402041F163CCE14B40
55716	1	\N	\N	1	3771	\N	55.859499	город Москва, САО, район Ховрино, Фестивальная ул, дом 16	Россия, Москва, Фестивальная улица, 16	0101000020E610000003D19332A9BF4240ECF82F1004EE4B40
55722	1	\N	\N	1	12872	\N	55.862029999999997	город Москва, САО, район Ховрино, Фестивальная ул, дом 67		0101000020E6100000CC9A58E02BC04240DF15C1FF56EE4B40
55720	1	\N	\N	1	12872	\N	55.86063	Адрес помещения для голосования: город Москва, САО, район Ховрино, Фестивальная ул., дом 51, адрес УИК: Лавочкина ул, дом 46, корп. 1		0101000020E6100000C8B7770DFABE42406EFAB31F29EE4B40
55718	1	\N	\N	1	12872	\N	55.862195999999997	город Москва, САО, район Ховрино, Фестивальная ул, дом 69		0101000020E6100000C1E5B16664C04240FA5E43705CEE4B40
55717	1	\N	\N	1	12872	\N	55.859499	Адрес помещения для голосования: город Москва, САО, район Ховрино, Фестивальная ул., дом 16, адрес УИК: Фестивальная ул, дом 14		0101000020E610000003D19332A9BF4240ECF82F1004EE4B40
56220	1	\N	\N	1	3040	\N	55.694921000000001	город Москва, ЮВАО, район Выхино-Жулебино, Ферганский пр, дом 5, корп. 2	Россия, Москва, Ферганский проезд, 5к2	0101000020E6100000C9586DFE5FE94240DD26DC2BF3D84B40
56219	1	\N	\N	1	3040	\N	55.697274999999998	город Москва, ЮВАО, район Выхино-Жулебино, Ферганский пр, дом 10, корп. 4	Россия, Москва, Ферганский проезд, 10к4	0101000020E6100000904946CEC2E84240C1A8A44E40D94B40
56218	1	\N	\N	1	3040	\N	55.697681000000003	город Москва, ЮВАО, район Выхино-Жулебино, Ферганский пр, дом 10, корп. 5	Россия, Москва, Ферганский проезд, 10к5	0101000020E61000009F58A7CAF7E8424032056B9C4DD94B40
56206	1	\N	\N	1	13232	\N	55.711340999999997	город Москва, ЮВАО, район Выхино-Жулебино, Ферганская ул, дом 7		0101000020E6100000E63E390A10E74240E7A6CD380DDB4B40
56807	1	\N	\N	1	12857	\N	55.563600000000001	город Москва, ЮЗАО, район Северное Бутово, Феодосийская ул, дом 11А		0101000020E6100000603DEE5BADC942404703780B24C84B40
56995	1	\N	\N	1	12948	\N	55.639502	город Москва, ЗАО, район Ново-Переделкино, Федосьино ул, дом 16, корп. 3		0101000020E61000005F622CD32FAB424001DD9733DBD14B40
56994	1	\N	\N	1	12948	\N	55.636336	город Москва, ЗАО, район Ново-Переделкино, Федосьино ул, дом 4, корп. 2		0101000020E61000007DD0B359F5AB42403CA2427573D14B40
56993	1	\N	\N	1	12948	\N	55.636336	Адрес помещения для голосования: город Москва, ЗАО, район Ново-Переделкино, Федосьино ул., дом 4, корп. 2, адрес УИК: Боровское шоссе, дом 48, корп. 1, Боровское шоссе, дом 48, корп. 1		0101000020E61000007DD0B359F5AB42403CA2427573D14B40
55952	1	\N	\N	1	13072	\N	55.868772999999997	город Москва, СВАО, Ярославский район, Федоскинская ул, дом 4		0101000020E6100000BAF59A1E14DA4240EB5223F433EF4B40
56244	1	\N	\N	1	13115	\N	55.713090999999999	город Москва, ЮВАО, район Кузьминки, Полетаева Федора ул, дом 2, корп. 8		0101000020E6100000B806B64AB0E242403509DE9046DB4B40
56133	1	\N	\N	1	381	\N	55.756962436559803	город Москва, ВАО, район Перово, Федеративный просп, дом 11/10	Россия, Москва, Федеративный проспект, 11	0101000020E610000011C64FE3DEE642404A287D21E4E04B40
56132	1	\N	\N	1	381	\N	55.758499	город Москва, ВАО, район Перово, Федеративный просп, дом 1А	Россия, Москва, Федеративный проспект, 1а	0101000020E6100000AAD5575705E642403C86C77E16E14B40
56100	1	\N	\N	1	381	\N	55.754855999999997	город Москва, ВАО, район Новогиреево, Федеративный просп, дом 27А	Россия, Москва, Федеративный проспект, 27	0101000020E6100000AF27BA2EFCE842403D98141F9FE04B40
56099	1	\N	\N	1	381	\N	55.754840999999999	город Москва, ВАО, район Новогиреево, Федеративный просп, дом 29А	Россия, Москва, Федеративный проспект, 29а	0101000020E6100000CD3FFA264DE94240085740A19EE04B40
56037	1	\N	\N	1	381	\N	55.754370000000002	город Москва, ВАО, район Ивановское, Федеративный просп, дом 37А	Россия, Москва, Федеративный проспект, 37а	0101000020E6100000B2F4A10BEAE94240B18A37328FE04B40
55477	1	\N	\N	1	13011	\N	55.774472000000003	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Фадеева ул., дом 4, адрес УИК: Долгоруковская ул, дом 5		0101000020E6100000A14CA3C9C5CC424078D503E621E34B40
57281	1	\N	\N	1	12530	\N	55.842815096513299	город Москва, СЗАО, район Южное Тушино, Фабрициуса ул, дом 21		0101000020E6100000C76471FF91B7424004CAA65CE1EB4B40
57279	1	\N	\N	1	12530	\N	55.843969999999999	Адрес помещения для голосования: город Москва, СЗАО, район Южное Тушино, Фабрициуса ул., дом 26, адрес УИК: Лодочная ул, дом 3		0101000020E61000009CA73AE466B842400E677E3507EC4B40
57277	1	\N	\N	1	12530	\N	55.845889999999997	город Москва, СЗАО, район Южное Тушино, Фабрициуса ул, дом 6		0101000020E61000007CEE04FBAFB94240B8019F1F46EC4B40
57276	1	\N	\N	1	12530	\N	55.844470000000001	город Москва, СЗАО, район Южное Тушино, Фабрициуса ул, дом 10		0101000020E6100000249D819197B94240003ACC9717EC4B40
55630	1	\N	\N	1	3968	\N	55.885181000000003	город Москва, САО, Дмитровский район, Учинская ул, дом 10	Россия, Москва, Учинская улица, 10	0101000020E6100000B587BD50C0C4424032056B9C4DF14B40
56277	1	\N	\N	1	13234	\N	55.767423000000001	город Москва, ЮВАО, район Лефортово, Ухтомская ул, дом 21		0101000020E610000099654F029BDB42405F99B7EA3AE24B40
56093	1	\N	\N	1	13129	\N	55.74747	город Москва, ВАО, район Новогиреево, Утренняя ул, дом 12		0101000020E6100000276728EE78E54240DD5ED218ADDF4B40
56018	1	\N	\N	1	83	\N	55.822083999999997	город Москва, ВАО, район Гольяново, Уссурийская ул, дом 12	Россия, Москва, Уссурийская улица, 12	0101000020E610000047C7D5C8AEE842404D486B0C3AE94B40
55540	1	\N	\N	1	12782	\N	55.804845	Адрес помещения для голосования: город Москва, САО, район Аэропорт, Усиевича ул., дом 6, адрес УИК: Усиевича ул, дом 12/14		0101000020E6100000E7A90EB919C44240B0AC342905E74B40
55534	1	\N	\N	1	12782	\N	55.807384999999996	город Москва, САО, район Аэропорт, Усиевича ул, дом 31, корп. 3		0101000020E610000001DC2C5E2CC24240F623456458E74B40
55517	1	\N	\N	1	2405	\N	55.723905999999999	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Усачева ул., дом 66, адрес УИК: Доватора ул, дом 14	Россия, Москва, Усачева улица, 66а	0101000020E6100000D1CDFE40B9C7424068B0A9F3A8DC4B40
55519	1	\N	\N	1	12933	\N	55.725791000000001	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Усачева ул., дом 52, адрес УИК: Пироговская Б. ул, дом 37/43	Россия, Москва, Усачева улица, 50	0101000020E610000091F3FE3F4EC84240965D30B8E6DC4B40
56009	1	\N	\N	1	13218	\N	55.820990999999999	город Москва, ВАО, район Гольяново, Уральская ул, дом 19		0101000020E610000016C1FF56B2E54240B9A7AB3B16E94B40
56694	1	\N	\N	1	12670	\N	55.695073000000001	город Москва, ЮЗАО, Гагаринский район, Университетский просп, дом 7	Россия, Москва, микрорайон Ленинские Горы, Университетский проспект, 7	0101000020E610000031CEDF8442C6424093AAED26F8D84B40
56693	1	\N	\N	1	12670	\N	55.694322	город Москва, ЮЗАО, Гагаринский район, Университетский просп, дом 3		0101000020E6100000C6BFCFB870C642405872158BDFD84B40
55836	1	\N	\N	1	12995	\N	55.884155999999997	город Москва, СВАО, Лосиноостровский район, Таймырская ул, дом 3		0101000020E61000005532005471D94240F54718062CF14B40
56692	1	\N	\N	1	12670	\N	55.6985786609971	Адрес помещения для голосования: город Москва, ЮЗАО, Гагаринский район, Университетский просп., дом 4-а, адрес УИК: Университетский просп, дом 4	Россия, Москва, микрорайон Ленинские Горы, Университетский проспект, 4а	0101000020E610000027FA7C9411C74240115663096BD94B40
56929	1	\N	\N	1	3705	\N	55.747585999999998	город Москва, ЗАО, район Дорогомилово, Украинский бульв, дом 9	Россия, Москва, Украинский бульвар, 9	0101000020E61000008D0B0742B2C842404679E6E5B0DF4B40
57061	1	\N	\N	1	12869	\N	55.684365999999997	город Москва, ЗАО, район Раменки, Удальцова ул, дом 87, корп. 1		0101000020E6100000EDB776A224BE4240463F1A4E99D74B40
57060	1	\N	\N	1	12869	\N	55.684365999999997	город Москва, ЗАО, район Раменки, Удальцова ул, дом 87, корп.1		0101000020E6100000EDB776A224BE4240463F1A4E99D74B40
57042	1	\N	\N	1	12869	\N	55.684046000000002	город Москва, ЗАО, район Проспект Вернадского, Удальцова ул, дом 40		0101000020E6100000963FDF162CBF4240D57ABFD18ED74B40
57039	1	\N	\N	1	12869	\N	55.672421999999997	город Москва, ЗАО, район Проспект Вернадского, Удальцова ул, дом 21		0101000020E610000040BD19355FC14240328E91EC11D64B40
57032	1	\N	\N	1	12869	\N	55.678193999999998	город Москва, ЗАО, район Проспект Вернадского, Удальцова ул, дом 67		0101000020E6100000793A579412C04240F52B9D0FCFD64B40
55819	1	\N	\N	1	12993	\N	55.905099	город Москва, СВАО, район Лианозово, Угличская ул, дом 17		0101000020E61000001A19E42EC2C842403752B648DAF34B40
55827	1	\N	\N	1	12923	\N	55.894635999999998	город Москва, СВАО, район Лианозово, Угличская ул, дом 6А		0101000020E6100000914259F8FAC8424081E9B46E83F24B40
57142	1	\N	\N	1	6262	\N	55.828282999999999	город Москва, СЗАО, район Митино, Уваровский пер, дом 8	Россия, Москва, Уваровский переулок, 8	0101000020E6100000B4E55C8AABAC4240986A662D05EA4B40
57174	1	\N	\N	1	6535	\N	55.826999000000001	город Москва, СЗАО, район Покровское-Стрешнево, Тушинская ул, дом 2	Россия, Москва, Тушинская улица, 2	0101000020E61000004FCAA48636BA424090696D1ADBE94B40
57171	1	\N	\N	1	12653	\N	55.825896999999998	Адрес помещения для голосования: город Москва, СЗАО, район Покровское-Стрешнево, Тушинская ул., дом 7А, адрес УИК: Свободы ул, дом 5/5		0101000020E6100000D042024697B94240A86E2EFEB6E94B40
57285	1	\N	\N	1	6598	\N	55.847442000000001	город Москва, СЗАО, район Южное Тушино, Туристская ул, дом  11, корп. 2	Россия, Москва, Туристская улица, 11к2	0101000020E61000005A2E1B9DF3B54240E0A0BDFA78EC4B40
57286	1	\N	\N	1	13198	\N	55.847442000000001	город Москва, СЗАО, район Южное Тушино, Туристская ул, дом 11, корп. 2		0101000020E61000005A2E1B9DF3B54240E0A0BDFA78EC4B40
57189	1	\N	\N	1	12942	\N	55.854779000000001	город Москва, СЗАО, район Северное Тушино, Туристская ул, дом 16, корп. 2		0101000020E6100000E751F17F47B642405F27F56569ED4B40
57180	1	\N	\N	1	12942	\N	55.857315999999997	город Москва, СЗАО, район Северное Тушино, Туристская ул, дом 31, корп. 1		0101000020E610000062F6B2EDB4B54240342BDB87BCED4B40
57178	1	\N	\N	1	12942	\N	55.852359	город Москва, СЗАО, район Северное Тушино, Туристская ул, дом 19, корп. 5		0101000020E6100000CFA10C5531B54240C3B986191AED4B40
56420	1	\N	\N	1	12615	\N	55.704078000000003	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Трофимова ул., дом 15А, адрес УИК: Кожуховская 6-я ул, дом 16		0101000020E610000024D6E25300D64240A3EA573A1FDA4B40
56419	1	\N	\N	1	12615	\N	55.704078000000003	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Трофимова ул., дом 15А, адрес УИК: Трофимова ул, дом 11		0101000020E610000024D6E25300D64240A3EA573A1FDA4B40
56415	1	\N	\N	1	12615	\N	55.703859999999999	город Москва, ЮВАО, Южнопортовый район, Трофимова ул, дом 27, корп. 2		0101000020E6100000E030D12005D74240357BA01518DA4B40
56412	1	\N	\N	1	12615	\N	55.704134000000003	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Трофимова ул., дом 13А, адрес УИК: Сайкина ул, дом 1/2		0101000020E6100000682101A3CBD5424037001B1021DA4B40
56411	1	\N	\N	1	12615	\N	55.704134000000003	город Москва, ЮВАО, Южнопортовый район, Трофимова ул, дом 13А		0101000020E6100000682101A3CBD5424037001B1021DA4B40
55419	1	\N	\N	1	12693	\N	55.789906999999999	город Москва, ЦАО, Мещанский район, Трифоновская ул, дом 57		0101000020E6100000AE7FD767CED04240D4F02DAC1BE54B40
56978	1	\N	\N	1	12931	\N	55.719931000000003	город Москва, ЗАО, Можайский район, Толбухина ул, дом 10, корп. 4	Россия, Москва, улица Толбухина, 10к4	0101000020E6100000BBD23252EFB342403430F2B226DC4B40
56977	1	\N	\N	1	12931	\N	55.71949	город Москва, ЗАО, Можайский район, Толбухина ул, дом 7, корп. 3		0101000020E6100000026553AEF0B2424047E6913F18DC4B40
55376	1	\N	\N	1	353	\N	55.766309	город Москва, ЦАО, Басманный район, Токмаков пер, дом 8	Россия, Москва, Токмаков переулок, 8	0101000020E610000010B3976DA7D54240B3D0CE6916E24B40
55453	1	\N	\N	1	1521	\N	55.743796000000003	Адрес помещения для голосования: город Москва, ЦАО, Таганский район, Товарищеский пер., дом 21, адрес УИК: Рогожский Б. пер, дом 10, корп. 2		0101000020E610000047CCECF318D54240A47213B534DF4B40
56168	1	\N	\N	1	12374	\N	55.786298000000002	Адрес помещения для голосования: город Москва, ВАО, район Соколиная гора, Ткацкая ул., дом 28/14, адрес УИК: Мироновская ул, дом 18	Россия, Москва, Ткацкая улица, 28/14	0101000020E61000004206F2ECF2DD42408274B169A5E44B40
56169	1	\N	\N	1	12395	\N	55.787123000000001	город Москва, ВАО, район Соколиная гора, Ткацкая ул, дом 47	Россия, Москва, Ткацкая улица, 47	0101000020E6100000B6D8EDB3CADE4240F7764B72C0E44B40
56291	1	\N	\N	1	3959	\N	55.678894999999997	город Москва, ЮВАО, район Люблино, Тихорецкий бульв, дом 8А	Россия, Москва, Тихорецкий бульвар, 8а	0101000020E61000007A89B14CBFE242407E350708E6D64B40
56288	1	\N	\N	1	3959	\N	55.678711999999997	город Москва, ЮВАО, район Люблино, Тихорецкий бульв, дом 10	Россия, Москва, Тихорецкий бульвар, 10	0101000020E6100000A9F7544E7BE242408DB3E908E0D64B40
55914	1	\N	\N	1	13029	\N	55.883560000000003	город Москва, СВАО, район Северное Медведково, Тихомирова ул, дом 6		0101000020E61000009F58A7CAF7D24240E2067C7E18F14B40
55490	1	\N	\N	1	2018	\N	55.787705000000003	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Тихвинский пер.,  дом 3, адрес УИК: Тихвинский пер, дом 7, стр. 2		0101000020E6100000BB9D7DE541CC4240A6F27684D3E44B40
56279	1	\N	\N	1	3831	\N	55.686492000000001	город Москва, ЮВАО, район Люблино, Тихая ул, дом 23	Россия, Москва, Тихая улица, 23	0101000020E610000011346612F5DE42409A7B48F8DED74B40
56855	1	\N	\N	1	12600	\N	55.507886971934603	город Москва, ЮЗАО, район Южное Бутово, Типографская ул, дом 10	Россия, Москва, поселок Милицейский, Типографская улица, 10с1	0101000020E610000013B70A62A0CB42402288F37002C14B40
55506	1	\N	\N	1	12682	\N	55.732523999999998	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Фрунзе Тимура ул., дом 3, адрес УИК: Фрунзенская наб, дом 10а		0101000020E6100000E5D4CE30B5CB42407EC4AF58C3DD4B40
55504	1	\N	\N	1	12682	\N	55.732523999999998	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Фрунзе Тимура ул., дом 3, адрес УИК: Зубовский пр, дом 2, стр. 1		0101000020E6100000E5D4CE30B5CB42407EC4AF58C3DD4B40
55703	1	\N	\N	1	4840	\N	55.819823	город Москва, САО, Тимирязевский район, Тимирязевская ул, дом 28	Россия, Москва, Тимирязевская улица, 28	0101000020E610000049F7730AF2C742401AC1C6F5EFE84B40
55702	1	\N	\N	1	13176	\N	55.813333999999998	город Москва, САО, Тимирязевский район, Тимирязевская ул, дом 14А		0101000020E61000007C5F5CAAD2C84240C85C19541BE84B40
56825	1	\N	\N	1	12700	\N	55.620220000000003	город Москва, ЮЗАО, район Теплый Стан, Бакулева академика ул, дом 3		0101000020E6100000FC3559A31EC042409E29745E63CF4B40
56821	1	\N	\N	1	12700	\N	55.628439	город Москва, ЮЗАО, район Теплый Стан, Теплый стан ул, дом 25А		0101000020E61000007444BE4BA9BD4240F6436CB070D04B40
56820	1	\N	\N	1	12700	\N	55.628439	Адрес помещения для голосования: город Москва, ЮЗАО, район Теплый Стан, Теплый стан ул., дом 25А, адрес УИК: Варги академика ул, дом 3		0101000020E61000007444BE4BA9BD4240F6436CB070D04B40
56816	1	\N	\N	1	12700	\N	55.622207000000003	город Москва, ЮЗАО, район Теплый Стан, Теплый стан ул, дом 13, корп. 3		0101000020E6100000ABE97AA2EBBE4240D02B9E7AA4CF4B40
56815	1	\N	\N	1	12700	\N	55.620189000000003	город Москва, ЮЗАО, район Теплый Стан, Теплый стан ул, дом 13, корп. 4		0101000020E6100000E485747808BF4240632B685A62CF4B40
56812	1	\N	\N	1	12700	\N	55.627681000000003	город Москва, ЮЗАО, район Теплый Стан, Теплый стан ул, дом 4		0101000020E6100000B77BB94F8EBE424009A9DBD957D04B40
55909	1	\N	\N	1	7067	\N	55.861105000000002	город Москва, СВАО, район Свиблово, Тенистый пр, дом 8А	Россия, Москва, Тенистый проезд, 8	0101000020E610000089B2B794F3D1424007B64AB038EE4B40
57391	1	\N	\N	1	12958	\N	55.799121999999997	город Москва, СЗАО, район Строгино, ул. Твардовского, 20, СОШ № 1295		0101000020E610000048FC8A355CB44240CEC133A149E64B40
57216	1	\N	\N	1	12958	\N	55.799121999999997	город Москва, СЗАО, район Строгино, Твардовского ул, дом 20		0101000020E610000048FC8A355CB44240CEC133A149E64B40
56210	1	\N	\N	1	2932	\N	55.706401	город Москва, ЮВАО, район Выхино-Жулебино, Ташкентский пер, дом 7, корп. 3	Россия, Москва, Ташкентский переулок, 7к3	0101000020E61000002C82FFAD64E942404C6E14596BDA4B40
56207	1	\N	\N	1	2890	\N	55.708759000000001	город Москва, ЮВАО, район Выхино-Жулебино, Ташкентская ул, дом 6	Россия, Москва, Ташкентская улица, 6	0101000020E61000007F30F0DC7BE8424072DF6A9DB8DA4B40
56211	1	\N	\N	1	13158	\N	55.703600999999999	город Москва, ЮВАО, район Выхино-Жулебино, Ташкентская ул, дом 18, корп. 3		0101000020E61000008A8F4FC8CEE742406937FA980FDA4B40
56216	1	\N	\N	1	12551	\N	55.700795999999997	город Москва, ЮВАО, район Выхино-Жулебино, Ташкентская ул, дом 21, корп. 2		0101000020E61000006D1D1CEC4DE842407495EEAEB3D94B40
56215	1	\N	\N	1	12551	\N	55.700358999999999	город Москва, ЮВАО, район Выхино-Жулебино, Ташкентская ул, дом 23, корп. 4, стр. 1		0101000020E6100000D6FECEF6E8E74240C93A1C5DA5D94B40
56212	1	\N	\N	1	12551	\N	55.700615519985199	город Москва, ЮВАО, район Выхино-Жулебино, Ташкентская ул, дом 26, корп. 2	Россия, Москва, Ташкентская улица, 26к2с1	0101000020E6100000F564FED137E74240F486FBC8ADD94B40
56076	1	\N	\N	1	12863	\N	55.710484000000001	город Москва, ВАО, район Косино - Ухтомский, Татьяны Макаровой ул, дом 2		0101000020E6100000897956D28AF14240672AC423F1DA4B40
56267	1	\N	\N	1	3661	\N	55.755871900236599	город Москва, ЮВАО, район Лефортово, Танковый пр, дом 6	Россия, Москва, Танковый проезд, 6	0101000020E610000087E123624AD8424026FBE769C0E04B40
56597	1	\N	\N	1	12446	\N	55.6028370290285	город Москва, ЮАО, район Орехово-Борисово Южное, Тамбовская ул, дом 10	Россия, Москва, Московская кольцевая автодорога	0101000020E610000082E673EE76DF4240CDE847C329CD4B40
57218	1	\N	\N	1	6966	\N	55.796810000000001	город Москва, СЗАО, район Строгино, Таллинская ул, дом 16, корп. 4	Россия, Москва, Таллинская улица, 16к4	0101000020E6100000FCC3961E4DB342401990BDDEFDE54B40
57219	1	\N	\N	1	12959	\N	55.797063000000001	город Москва, СЗАО, район Строгино, Таллинская ул, дом 20, корп. 4		0101000020E6100000B2BAD573D2B3424003ED0E2906E64B40
57217	1	\N	\N	1	12959	\N	55.796815000000002	город Москва, СЗАО, район Строгино, Таллинская ул, дом 12, корп. 4		0101000020E61000000D37E0F3C3B242402BFBAE08FEE54B40
55636	1	\N	\N	1	12922	\N	55.874535999999999	город Москва, САО, район Западное Дегунино, Талдомская ул, дом 13А		0101000020E61000004E9B711AA2C242405B96AFCBF0EF4B40
55463	1	\N	\N	1	12620	\N	55.734177000000003	город Москва, ЦАО, Таганский район, Талалихина ул, дом 20		0101000020E6100000354580D3BBD64240DA3C0E83F9DD4B40
55462	1	\N	\N	1	12620	\N	55.730324000000003	Адрес помещения для голосования: город Москва, ЦАО, Таганский район, Талалихина ул., дом 33, адрес УИК: Талалихина ул, дом 39		0101000020E61000008104C58F31D74240F1BDBF417BDD4B40
55834	1	\N	\N	1	12996	\N	55.884822	город Москва, СВАО, Лосиноостровский район, Тайнинская ул, дом 15, корп. 3		0101000020E6100000003CA24275D742400264E8D841F14B40
57376	1	\N	\N	1	12995	\N	55.884155999999997	город Москва, СВАО, район Лосиноостровский, Таймырская ул., 3, , СОШ № 751		0101000020E61000005532005471D94240F54718062CF14B40
55838	1	\N	\N	1	12927	\N	55.885201000000002	город Москва, СВАО, Лосиноостровский район, Таймырская ул, дом 4		0101000020E61000008AB0E1E995DA424079B130444EF14B40
55837	1	\N	\N	1	12927	\N	55.884478999999999	город Москва, СВАО, Лосиноостровский район, Таймырская ул, дом 5		0101000020E61000005709168733D94240D87F9D9B36F14B40
57280	1	\N	\N	1	7648	\N	55.841164999999997	город Москва, СЗАО, район Южное Тушино, Сходненская ул, дом 15	Россия, Москва, Сходненская улица, 15	0101000020E610000081B053AC1AB8424019C5724BABEB4B40
57283	1	\N	\N	1	13143	\N	55.848517999999999	город Москва, СЗАО, район Южное Тушино, Сходненская ул, дом 35		0101000020E61000009566F3380CB842409E08E23C9CEC4B40
55936	1	\N	\N	1	7099	\N	55.874516	город Москва, СВАО, район Южное Медведково, Сухонская ул, дом 3	Россия, Москва, Сухонская улица, 3	0101000020E6100000AF777FBC57D3424014EAE923F0EF4B40
55912	1	\N	\N	1	7099	\N	55.878667	город Москва, СВАО, район Северное Медведково, Сухонская ул, дом 13	Россия, Москва, Сухонская улица, 13	0101000020E610000088F4DBD781D342408789062978F04B40
56623	1	\N	\N	1	12654	\N	55.6312320275796	город Москва, ЮАО, район Чертаново Северное, Сумской пр, дом 19А	Россия, Москва, Сумской проезд, 19а	0101000020E61000001BBD1AA034CC42402618CE35CCD04B40
56616	1	\N	\N	1	12654	\N	55.6361708682238	город Москва, ЮАО, район Чертаново Северное, Сумской пр, дом 12, корп. 6	Россия, Москва, Сумской проезд, 12к6	0101000020E610000001DD9733DBCD4240F1D4230D6ED14B40
56107	1	\N	\N	1	1406	\N	55.741906	город Москва, ВАО, район Новокосино, Суздальская ул, дом 24Б	Россия, Москва, Суздальская улица, 24б	0101000020E6100000098D60E3FAED4240645A9BC6F6DE4B40
56106	1	\N	\N	1	1406	\N	55.741160999999998	город Москва, ВАО, район Новокосино, Суздальская ул, дом 22Б	Россия, Москва, Суздальская улица, 22б	0101000020E61000001A33897AC1ED42400B09185DDEDE4B40
56104	1	\N	\N	1	12573	\N	55.738987000000002	город Москва, ВАО, район Новокосино, Суздальская ул, дом 12В		0101000020E6100000541D7233DCEC4240A795422097DE4B40
56553	1	\N	\N	1	2671	\N	55.679219000000003	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Судостроительная ул., дом 10, корп. 1, адрес УИК: Новинки ул, дом 21, корп. 2	Россия, Москва, Судостроительная улица, 10к1	0101000020E6100000A6B4FE9600D6424032E9EFA5F0D64B40
56545	1	\N	\N	1	2671	\N	55.682133	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Судостроительная ул., дом 32, корп. 3, адрес УИК: Речников ул, дом 18, корп. 2	Россия, Москва, Судостроительная улица, 32к3	0101000020E610000062F5471806D84240DD42572250D74B40
56544	1	\N	\N	1	2671	\N	55.682133	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Судостроительная ул., дом 32, корп. 3, адрес УИК: Судостроительная ул, дом 32, корп. 2	Россия, Москва, Судостроительная улица, 32к3	0101000020E610000062F5471806D84240DD42572250D74B40
56543	1	\N	\N	1	2671	\N	55.686745999999999	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Судостроительная ул., дом 46, адрес УИК: Судостроительная ул, дом 44	Россия, Москва, Судостроительная улица, 46к2	0101000020E61000000492B06F27D942405454FD4AE7D74B40
56552	1	\N	\N	1	12514	\N	55.679219000000003	город Москва, ЮАО, район Нагатинский затон, Судостроительная ул, дом 10, корп. 1		0101000020E6100000A6B4FE9600D6424032E9EFA5F0D64B40
56542	1	\N	\N	1	12514	\N	55.685873000000001	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Судостроительная ул., дом 44, адрес УИК: Речников ул, дом 18, корп. 2		0101000020E61000008D28ED0DBED84240CE1ABCAFCAD74B40
56540	1	\N	\N	1	12514	\N	55.686036000000001	город Москва, ЮАО, район Нагатинский затон, Судостроительная ул, дом 43, корп. 2		0101000020E610000088BEBB9525D8424078F01307D0D74B40
56535	1	\N	\N	1	12514	\N	55.684142999999999	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Судостроительная ул., дом 31, корп. 2, адрес УИК: Судостроительная ул, дом 27, корп. 2		0101000020E61000007B13437232D74240C76471FF91D74B40
56534	1	\N	\N	1	12514	\N	55.684142999999999	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Судостроительная ул., дом 31, корп. 2, адрес УИК: Кленовый бульв, дом 7		0101000020E61000007B13437232D74240C76471FF91D74B40
56303	1	\N	\N	1	12786	\N	55.672702000000001	город Москва, ЮВАО, район Люблино, Судакова ул, дом 18А		0101000020E610000059A2B3CC22E0424016FA60191BD64B40
56296	1	\N	\N	1	12786	\N	55.673488999999996	город Москва, ЮВАО, район Люблино, Судакова ул, дом 25		0101000020E61000006CCB80B394E042409D9B36E334D64B40
56295	1	\N	\N	1	12786	\N	55.673777999999999	город Москва, ЮВАО, район Люблино, Судакова ул, дом 29		0101000020E6100000B7973446EBE04240D461855B3ED64B40
56919	1	\N	\N	1	13145	\N	55.740299	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Студенческая ул., дом 29, адрес УИК: Кутузовский просп, дом 35/30		0101000020E6100000581EA4A7C8C5424079211D1EC2DE4B40
56920	1	\N	\N	1	13075	\N	55.740299	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Студенческая ул., дом 29, адрес УИК: Студенческая ул, дом 25		0101000020E6100000581EA4A7C8C5424079211D1EC2DE4B40
56917	1	\N	\N	1	13075	\N	55.742924000000002	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Студенческая ул., дом 24, адрес УИК: Студенческая ул, дом 22		0101000020E6100000662D05A4FDC54240EEB4352218DF4B40
56202	1	\N	\N	1	12710	\N	55.794775999999999	город Москва, ВАО, район Сокольники, Стромынка ул, дом 17		0101000020E61000003D2828452BD94240A6D24F38BBE54B40
56763	1	\N	3877	1	12439	\N	55.686979999999998	город Москва, ЮЗАО, Ломоносовский район, Строителей ул, дом 15		0101000020E61000000919C8B3CBC34240C780ECF5EED74B40
57215	1	\N	\N	1	6907	\N	55.801698000000002	город Москва, СЗАО, район Строгино, Строгинский бульв, дом 14, корп. 5	Россия, Москва, Строгинский бульвар, 14к5	0101000020E6100000B8054B7501B3424062A2410A9EE64B40
57210	1	\N	\N	1	6907	\N	55.806261999999997	город Москва, СЗАО, район Строгино, Строгинский бульв, дом 7, корп. 3		0101000020E610000016889E9449B34240F700DD9733E74B40
55401	1	\N	\N	1	711	\N	55.727393999999997	город Москва, ЦАО, район Замоскворечье, Стремянный пер, дом 28	Россия, Москва, Стремянный переулок, 28	0101000020E6100000394371C79BD042403FA7203F1BDD4B40
56278	1	\N	\N	1	12866	\N	55.765594999999998	город Москва, ЮВАО, район Лефортово, Сторожевая ул, дом 22, корп. 1		0101000020E61000009DF6949C13DB4240957D5704FFE14B40
55437	1	\N	\N	1	1271	\N	55.764161000000001	город Москва, ЦАО, Пресненский район, Столярный пер, дом 16	Россия, Москва, Столярный переулок, 16с1	0101000020E6100000BC96900F7AC8424078F01307D0E14B40
55426	1	\N	\N	1	1107	\N	55.756743877988903	город Москва, ЦАО, Пресненский район, Столовый пер, дом 10/2	Россия, Москва, Столовый переулок, 10/2с1	0101000020E6100000A58636001BCC4240DCB8C5FCDCE04B40
56308	1	\N	\N	1	13188	\N	55.674255000000002	город Москва, ЮВАО, район Люблино, Степана Шутова ул, дом 8, корп. 3		0101000020E6100000B80375CAA3E742400E15E3FC4DD64B40
55835	1	\N	\N	1	13224	\N	55.884180999999998	город Москва, СВАО, Лосиноостровский район, Стартовая ул, дом 27, корп. 3		0101000020E61000001A19E42EC2D842404E5FCFD72CF14B40
56195	1	\N	\N	1	12856	\N	55.789836000000001	город Москва, ВАО, район Сокольники, Старослободская ул, дом 8		0101000020E6100000BF620D17B9D542400B9A965819E54B40
55483	1	\N	\N	1	1928	\N	55.769347000000003	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Старопименовский пер., дом 5, адрес УИК Старопименовский пер, дом 16	Россия, Москва, Старопименовский переулок, 5	0101000020E6100000D3F71A82E3CC42404B2366F679E24B40
55854	1	\N	\N	1	6539	\N	55.803058999999998	город Москва, СВАО, район Марьина роща, Старомарьинское шоссе, дом 5	Россия, Москва, Старомарьинское шоссе, 5	0101000020E6100000177FDB1324CE424015E126A3CAE64B40
56525	1	\N	\N	1	6653	\N	55.659993	город Москва, ЮАО, район Нагатино-Садовники, Старокаширское шоссе, дом 2, корп. 11	Россия, Москва, Старокаширское шоссе, 2к11	0101000020E6100000D99942E735D04240624B8FA67AD44B40
56803	1	\N	\N	1	13016	\N	55.570472000000002	город Москва, ЮЗАО, район Северное Бутово, Старокачаловская ул, дом 22		0101000020E61000001BBB44F5D6CA424051A4FB3905C94B40
55782	1	\N	\N	1	5800	\N	55.877262999999999	город Москва, СВАО, Бабушкинский район, Староватутинский пр, дом 8, стр. 1	Россия, Москва, Староватутинский проезд, 8к1	0101000020E6100000841266DAFED54240D47E6B274AF04B40
55780	1	\N	\N	1	5800	\N	55.874459999999999	город Москва, СВАО, Бабушкинский район, Староватутинский пр, дом 6,  стр. 1	Россия, Москва, Староватутинский проезд, 6с2	0101000020E6100000BBD1C77C40D6424080D4264EEEEF4B40
55753	1	\N	\N	1	12494	\N	55.810364	город Москва, СВАО, Алексеевский район, Староалексеевская ул, дом 1	Россия, Москва, Староалексеевская улица, 3	0101000020E6100000F12F82C64CD2424089EDEE01BAE74B40
55375	1	\N	\N	1	12891	\N	55.769058999999999	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Басманная Стар. ул., дом 35, адрес УИК: Басманный 1-й пер, дом 12		0101000020E61000002750C42286D54240E4D87A8670E24B40
55763	1	\N	\N	1	5587	\N	55.882494999999999	город Москва, СВАО, Алтуфьевский район, Стандартная ул, дом 2	Россия, Москва, Стандартная улица, 2	0101000020E6100000F792C6681DC9424017F19D98F5F04B40
55764	1	\N	\N	1	12535	\N	55.882860640650598	город Москва, СВАО, Алтуфьевский район, Стандартная ул, дом 4		0101000020E610000088122D793CC94240F9F4D89601F14B40
56035	1	\N	\N	1	12835	\N	55.755398	город Москва, ВАО, район Ивановское, Сталеваров ул, дом 20А		0101000020E61000000F46EC1340EB42405EBBB4E1B0E04B40
56034	1	\N	\N	1	12835	\N	55.757055000000001	город Москва, ВАО, район Ивановское, Сталеваров ул, дом 16А		0101000020E6100000A818E76F42EB4240FB22A12DE7E04B40
56032	1	\N	\N	1	12835	\N	55.762044000000003	город Москва, ВАО, район Ивановское, Сталеваров ул, дом 10А		0101000020E61000009C36E33444EB4240780E65A88AE14B40
56281	1	\N	\N	1	13078	\N	55.680047000000002	город Москва, ЮВАО, район Люблино, Ставропольская ул, дом 16		0101000020E61000005665DF15C1DF4240185FB4C70BD74B40
56290	1	\N	\N	1	12687	\N	55.680199000000002	город Москва, ЮВАО, район Люблино, Ставропольская ул, дом 54, корп. 3		0101000020E6100000C5CBD3B9A2E24240CEE2C5C210D74B40
56286	1	\N	\N	1	12687	\N	55.679259999999999	город Москва, ЮВАО, район Люблино, Ставропольская ул, дом 20		0101000020E610000032022A1C41E0424090BDDEFDF1D64B40
55403	1	\N	\N	1	13148	\N	55.769165000000001	город Москва, ЦАО, Красносельский район, Сретенка ул, дом 20		0101000020E6100000B69DB64604D142402A1DACFF73E24B40
56068	1	\N	\N	1	12519	\N	55.795347	город Москва, ВАО, район Измайлово, Первомайская ср. ул, дом 8/10		0101000020E6100000CFF4126399E6424061FC34EECDE54B40
55461	1	\N	\N	1	12515	\N	55.735413999999999	город Москва, ЦАО, Таганский район, Калитниковская Ср. ул, дом 22/3		0101000020E6100000F56393FC88D74240A182C30B22DE4B40
55433	1	\N	\N	1	1209	\N	55.770006000000002	город Москва, ЦАО, Пресненский район, Тишинский Ср. пер, дом 5/7	Россия, Москва, Средний Тишинский переулок, 5/7с1	0101000020E610000092054CE0D6C94240A5DC7D8E8FE24B40
56283	1	\N	\N	1	2968	\N	55.6836615100949	город Москва, ЮВАО, район Люблино, Спортивный пр, дом 3, корп. 2	Россия, Москва, Спортивный проезд	0101000020E6100000425C397B67E042404CC2853C82D74B40
56095	1	\N	\N	1	1251	\N	55.750458999999999	город Москва, ВАО, район Новогиреево, Союзный просп, дом 2/21	Россия, Москва, Союзный проспект, 2	0101000020E61000005721E527D5E6424093FE5E0A0FE04B40
55631	1	\N	\N	1	12739	\N	55.882489999999997	город Москва, САО, Дмитровский район, Ковалевской Софьи ул, дом 8А		0101000020E610000055FB743C66C442400586AC6EF5F04B40
55628	1	\N	\N	1	12739	\N	55.887290999999998	город Москва, САО, Дмитровский район, Ковалевской Софьи ул, дом 18А		0101000020E6100000C286A757CAC442407F8461C092F14B40
56903	1	\N	\N	1	3264	\N	55.605871	город Москва, ЮЗАО, район Ясенево, Соловьиный пр, дом 16, корп. 2	Россия, Москва, Соловьиный проезд, 16к2	0101000020E6100000335184D4EDC64240234C512E8DCD4B40
57272	1	\N	\N	1	12346	\N	55.840724999999999	город Москва, СЗАО, район Южное Тушино, Свобды ул, дом 37		0101000020E6100000D993C0E61CBA4240FDF675E09CEB4B40
56896	1	\N	\N	1	3264	\N	55.614286999999997	город Москва, ЮЗАО, район Ясенево, Соловьиный пр, дом 4, корп. 3	Россия, Москва, Соловьиный проезд, 4к3	0101000020E610000026C3F17C06C64240D1ADD7F4A0CE4B40
56895	1	\N	\N	1	3264	\N	55.614865999999999	город Москва, ЮЗАО, район Ясенево, Соловьиный пр, дом 4, корп. 2	Россия, Москва, Соловьиный проезд, 4к2	0101000020E6100000B9AAECBB22C642400FB6D8EDB3CE4B40
57076	1	\N	\N	1	5511	\N	55.648859999999999	город Москва, ЗАО, район Солнцево, Солнцевский просп, дом 7А	Россия, Москва, Солнцевский проспект, 7а	0101000020E610000071AAB5300BB342405ED72FD80DD34B40
57074	1	\N	\N	1	5511	\N	55.652867000000001	город Москва, ЗАО, район Солнцево, Солнцевский просп, дом 16А		0101000020E6100000A3C85A43A9B342409ED1562591D34B40
57073	1	\N	\N	1	5511	\N	55.652883000000003	город Москва, ЗАО, район Солнцево, Солнцевский просп, дом 12А	Россия, Москва, Солнцевский проспект, 12а	0101000020E61000008BC404357CB34240A48E8EAB91D34B40
55614	1	\N	\N	1	3743	\N	55.859160000000003	город Москва, САО, Головинский район, Солнечногорский пр, дом 7А	Россия, Москва, Солнечногорский проезд, 7а	0101000020E61000003D2828452BC34240040473F4F8ED4B40
55619	1	\N	\N	1	12649	\N	55.856850999999999	город Москва, САО, Головинский район, Солнечногорская ул, дом 4		0101000020E6100000BE67244223C24240BF45274BADED4B40
56274	1	\N	\N	1	13236	\N	55.763193999999999	город Москва, ЮВАО, район Лефортово, Солдатская ул, дом 14		0101000020E6100000AC36FFAF3ADA424070404B57B0E14B40
56196	1	\N	\N	1	2727	\N	55.791623000000001	город Москва, ВАО, район Сокольники, Сокольническая пл, дом 7	Россия, Москва, Сокольническая площадь, 7	0101000020E6100000494BE5ED08D7424076E107E753E54B40
57141	1	\N	\N	1	6253	\N	55.903903	город Москва, СЗАО, район Куркино, Соколово-Мещерская ул, дом 27	Россия, Москва, Соколово-Мещерская улица, 27к1	0101000020E6100000FAB48AFED0B04240CEE0EF17B3F34B40
56300	1	\N	\N	1	4114	\N	55.669376	город Москва, ЮВАО, район Люблино, Совхозная ул, дом 2	Россия, Москва, Совхозная улица, 2а	0101000020E6100000E9B6442E38DF4240185DDE1CAED54B40
55846	1	\N	\N	1	13163	\N	55.788905	город Москва, СВАО, район Марьина роща, Советской армии ул, дом 9		0101000020E610000046B6F3FDD4CE42405053CBD6FAE44B40
56946	1	\N	\N	1	12501	\N	55.784266999528903	город Москва, ЗАО, район Кунцево, Советская ул, дом 11А	Россия, Москва, поселок Рублево, Советская улица, 11а	0101000020E61000003A9160AA99AD4240802A6EDC62E44B40
56911	1	\N	\N	1	12501	\N	55.606999999999999	город Москва, ЗАО, район Внуково, Советская ул. д. Толстопальцево, дом 1	Россия, Москва, Советская улица, 1с1	0101000020E6100000FB761211FE97424004560E2DB2CD4B40
55648	1	\N	\N	1	4183	\N	55.834167999999998	город Москва, САО, район Коптево, Соболевский пр, дом 17А	Россия, Москва, Соболевский проезд, 17а	0101000020E6100000B35E0CE544C3424053AF5B04C6EA4B40
55904	1	\N	\N	1	13128	\N	55.848129	город Москва, СВАО, район Свиблово, Снежная ул, дом 4		0101000020E610000098A432C51CD2424004E5B67D8FEC4B40
55986	1	\N	\N	1	7901	\N	55.723748999999998	город Москва, ВАО, район Вешняки, Снайперская ул, дом 4А	Россия, Москва, Снайперская улица, 4а	0101000020E61000005DE15D2EE2E74240A0C1A6CEA3DC4B40
55985	1	\N	\N	1	13207	\N	55.719810000000003	город Москва, ВАО, район Вешняки, Снайперская ул, дом 11А		0101000020E61000006A1327F73BE84240B9AAECBB22DC4B40
55609	1	\N	\N	1	3469	\N	55.848235000000003	город Москва, САО, Головинский район, Смольная ул, дом 10	Россия, Москва, Смольная улица, 10	0101000020E6100000F10D85CFD6BF42404A29E8F692EC4B40
55667	1	\N	\N	1	12813	\N	55.860171000000001	город Москва, САО, Левобережный район, Смольная ул, дом 37А		0101000020E61000002D99637957BD4240DBFB54151AEE4B40
55608	1	\N	\N	1	12813	\N	55.849781999999998	город Москва, САО, Головинский район, Смольная ул, дом 25		0101000020E6100000A835CD3B4EBF42405F5D15A8C5EC4B40
55668	1	\N	\N	1	12850	\N	55.860171000000001	Адрес помещения для голосования: город Москва, САО, Левобережный район, Смольная ул., дом 37А, адрес УИК: Смольная ул, дом 39		0101000020E61000002D99637957BD4240DBFB54151AEE4B40
57131	1	\N	\N	1	6144	\N	55.723896000000003	город Москва, ЗАО, район Фили-Давыдково, Славянский бульв, дом 11, корп. 3	Россия, Москва, Славянский бульвар, 11к3	0101000020E6100000F8A75489B2BB424045DAC69FA8DC4B40
55405	1	\N	\N	1	769	\N	55.773358000000002	город Москва, ЦАО, Красносельский район, Скорняжный пер, дом 3	Россия, Москва, Скорняжный переулок, 3с1	0101000020E6100000C171193735D24240CC0C1B65FDE24B40
56864	1	\N	\N	1	12785	\N	55.544204000000001	город Москва, ЮЗАО, район Южное Бутово, Скобелевская ул, дом 30		0101000020E610000081971936CAC642401B2D077AA8C54B40
56863	1	\N	\N	1	12785	\N	55.544800000000002	город Москва, ЮЗАО, район Южное Бутово, Скобелевская ул, дом 28		0101000020E61000005DFB027AE1C642402F6EA301BCC54B40
55549	1	\N	\N	1	2887	\N	55.780071	город Москва, САО, район Беговой, Скаковая ул, дом 20	Россия, Москва, Скаковая улица, 20с1	0101000020E6100000637E6E68CAC842406DC7D45DD9E34B40
55548	1	\N	\N	1	12652	\N	55.780071	Адрес помещения для голосования: город Москва, САО, район Беговой, Скаковая ул., дом 20, адрес УИК: Скаковая ул, дом 17		0101000020E6100000637E6E68CAC842406DC7D45DD9E34B40
56163	1	\N	\N	1	472	\N	55.804855000000003	город Москва, ВАО, район Северное Измайлово, Сиреневый бульв, дом 73, корп. 3	Россия, Москва, Сиреневый бульвар, 73к3	0101000020E6100000DBA4A2B1F6E94240D482177D05E74B40
56159	1	\N	\N	1	472	\N	55.803894	город Москва, ВАО, район Северное Измайлово, Сиреневый бульв, дом 55	Россия, Москва, Сиреневый бульвар, 55	0101000020E6100000B3B27DC85BE84240AEB9A3FFE5E64B40
56150	1	\N	\N	1	472	\N	55.803094000000002	город Москва, ВАО, район Северное Измайлово, Сиреневый бульв, дом 9	Россия, Москва, Сиреневый бульвар, 9	0101000020E610000012DBDD0374E3424092CEC0C8CBE64B40
56149	1	\N	\N	1	472	\N	55.803255999999998	город Москва, ВАО, район Северное Измайлово, Сиреневый бульв, дом 3	Россия, Москва, Сиреневый бульвар, 3	0101000020E61000000116F9F543E242406B28B517D1E64B40
57201	1	\N	\N	1	12346	\N	55.866647	город Москва, СЗАО, район Северное Тушино, Свободы ул, дом 91		0101000020E6100000016BD5AE09B942409816F549EEEE4B40
56065	1	\N	\N	1	472	\N	55.802083000000003	город Москва, ВАО, район Измайлово, Сиреневый бульв, дом 30, корп. 1	Россия, Москва, Сиреневый бульвар, 30с1	0101000020E6100000D508FD4CBDE64240BBD6DEA7AAE64B40
56063	1	\N	\N	1	472	\N	55.801673000000001	город Москва, ВАО, район Измайлово, Сиреневый бульв, дом 20	Россия, Москва, Сиреневый бульвар, 20	0101000020E610000050E449D235E54240098B8A389DE64B40
56044	1	\N	\N	1	472	\N	55.801799000000003	город Москва, ВАО, район Измайлово, Сиреневый бульв, дом 4Г	Россия, Москва, Сиреневый бульвар, 4г	0101000020E6100000E4C0ABE5CEE24240967B8159A1E64B40
56043	1	\N	\N	1	472	\N	55.801081000000003	город Москва, ВАО, район Измайлово, Сиреневый бульв, дом 4	Россия, Москва, Сиреневый бульвар, 4	0101000020E61000007B4D0F0A4AE1424037397CD289E64B40
55994	1	\N	\N	1	472	\N	55.802593999999999	город Москва, ВАО, район Восточное Измайлово, Сиреневый бульв, дом 68	Россия, Москва, Сиреневый бульвар, 68	0101000020E6100000A69BC420B0EA4240A0FB7266BBE64B40
55993	1	\N	\N	1	472	\N	55.801383999999999	город Москва, ВАО, район Восточное Измайлово, Сиреневый бульв, дом 58А	Россия, Москва, Сиреневый бульвар, 58а	0101000020E6100000EE21E17B7FE94240D2C43BC093E64B40
56563	1	\N	\N	1	7017	\N	55.650210999999999	город Москва, ЮАО, Нагорный район, Симферопольский бульв, дом 23, корп. А	Россия, Москва, Симферопольский бульвар, 23а	0101000020E61000002F1686C8E9CD4240EE3F321D3AD34B40
56477	1	\N	\N	1	13183	\N	55.721539	город Москва, ЮАО, Даниловский район, Симоновский вал ул, дом 18А		0101000020E6100000D940BAD8B4D44240EFE4D3635BDC4B40
56717	1	\N	\N	1	12603	\N	55.660281314817198	город Москва, ЮЗАО, район Зюзино, Сивашская ул, дом 2, корп. 1а	Россия, Москва, Сивашская улица	0101000020E6100000D1764CDD95CD4240C8957A1684D44B40
56716	1	\N	\N	1	12603	\N	55.660760360032398	Адрес помещения для голосования: город Москва, ЮЗАО, район Зюзино, Сивашская ул., дом 2, корп. 1а, адрес УИК: Фруктовая ул, дом 18	Россия, Москва, Сивашская улица, 2к1	0101000020E6100000AA622AFD84CD4240A3409FC893D44B40
55521	1	\N	\N	1	12882	\N	55.744341027500802	город Москва, ЦАО, район Якиманка, Серафимовича ул, дом 2	Россия, Москва, улица Серафимовича	0101000020E61000000F9A5DF756CE42403509DE9046DF4B40
55386	1	\N	\N	1	497	\N	55.779034000000003	город Москва, ЦАО, Басманный район, Семеновская наб, дом 3/1, корп. 5	Россия, Москва, Семеновская набережная, 3/1к5	0101000020E6100000C009850838DA42406D3CD862B7E34B40
57381	1	\N	\N	1	12657	\N	55.836993999999997	город Москва, СВАО, район Ростокино, Сельскохозяйственная ул., 15/1, Гостиница «Байкал»		0101000020E61000005BD1E638B7D142405F79909E22EB4B40
55892	1	\N	\N	1	12657	\N	55.837045000000003	город Москва, СВАО, район Ростокино, Сельскохозяйственная ул, дом 20, корп. 1		0101000020E610000071218FE046D24240E223624A24EB4B40
55907	1	\N	\N	1	12778	\N	55.852798999999997	город Москва, СВАО, район Свиблово, Седова ул, дом 4, корп.1		0101000020E61000007BF99D2633D24240DF87838428ED4B40
55906	1	\N	\N	1	12778	\N	55.852915000000003	город Москва, СВАО, район Свиблово, Седова ул, дом 12		0101000020E61000000E85CFD6C1D1424049A297512CED4B40
55903	1	\N	\N	1	12778	\N	55.852798999999997	город Москва, СВАО, район Свиблово, Седова ул, дом 4, корп. 1		0101000020E61000007BF99D2633D24240DF87838428ED4B40
56621	1	\N	\N	1	6754	\N	55.870097000000001	город Москва, ЮАО, район Чертаново Северное, Сумской пр, дом 21А	Россия, Москва, Северный бульвар, 21а	0101000020E61000000C76C3B645CF424082ACA7565FEF4B40
55884	1	\N	\N	1	6754	\N	55.865206999999998	город Москва, СВАО, район Отрадное, Северный бульв, дом 4А	Россия, Москва, Северный бульвар, 4а	0101000020E61000002B357BA015CE424098A25C1ABFEE4B40
55878	1	\N	\N	1	6754	\N	55.868662	город Москва, СВАО, район Отрадное, Северный бульв, дом 11	Россия, Москва, Северный бульвар, 11	0101000020E6100000758E01D9EBCD424094A3005130EF4B40
55874	1	\N	\N	1	6754	\N	55.866531000000002	город Москва, СВАО, район Отрадное, Северный бульв, дом 1А	Россия, Москва, Северный бульвар, 1а	0101000020E610000063F20698F9CC42402FFCE07CEAEE4B40
56762	1	\N	\N	1	1268	\N	55.668025999999998	город Москва, ЮЗАО, район Котловка, Севастопольский просп, дом 51, корп. 5	Россия, Москва, Севастопольский проспект, 51к5	0101000020E6100000FD15325706CB424058703FE081D54B40
56761	1	\N	\N	1	1268	\N	55.671563999999996	город Москва, ЮЗАО, район Котловка, Севастопольский просп, дом 43А	Россия, Москва, Севастопольский проспект, 43а	0101000020E610000050E3DEFC86CB4240E19524CFF5D54B40
56756	1	\N	\N	1	1268	\N	55.684559	город Москва, ЮЗАО, район Котловка, Севастопольский просп, дом 11А	Россия, Москва, Севастопольский проспект, 11а	0101000020E61000009F9273620FCD42405B971AA19FD74B40
56755	1	\N	\N	1	1268	\N	55.682167999999997	город Москва, ЮЗАО, район Котловка, Севастопольский просп, дом 20А	Россия, Москва, Севастопольский проспект, 20а	0101000020E6100000A6ED5F5969CC42405930F14751D74B40
56490	1	\N	\N	1	1268	\N	55.691150999999998	Адрес помещения для голосования: город Москва, ЮАО, Донской район, Севастопольский просп., дом 5А, адрес УИК: Севастопольский просп, дом 1, корп. 5	Россия, Москва, Севастопольский проспект, 5а	0101000020E610000083C0CAA145CE424081CCCEA277D84B40
56610	1	\N	\N	1	7499	\N	55.621378999999997	город Москва, ЮАО, район Царицыно, Севанская ул, дом 13, корп. 2	Россия, Москва, Севанская улица, 13к2	0101000020E61000000118CFA0A1D34240E9B5D95889CF4B40
56608	1	\N	\N	1	13227	\N	55.621510999999998	город Москва, ЮАО, район Царицыно, Севанская ул, дом 6		0101000020E6100000C2A38D23D6D44240588D25AC8DCF4B40
56079	1	\N	\N	1	12452	\N	55.713287999999999	город Москва, ВАО, район Косино - Ухтомский, Святоозерская ул, дом 17	Россия, Москва, Святоозерская улица, 17	0101000020E6100000FB743C66A0F242408B506C054DDB4B40
57275	1	\N	\N	1	12346	\N	55.846234000000003	город Москва, СЗАО, район Южное Тушино, Свободы ул, дом 45		0101000020E61000003ACAC16C02BA4240B3614D6551EC4B40
57274	1	\N	\N	1	12346	\N	55.846617999999999	город Москва, СЗАО, район Южное Тушино, Свободы ул, дом 42, корп. 2		0101000020E6100000AB251DE560BA42403B1A87FA5DEC4B40
57200	1	\N	\N	1	12346	\N	55.861877999999997	Адрес помещения для голосования: город Москва, СЗАО, район Северное Тушино, Свободы ул.,  дом 81, корп. 1, адрес УИК: Свободы ул, дом 81, корп. 2		0101000020E610000047C66AF3FFB842402992AF0452EE4B40
57199	1	\N	\N	1	12346	\N	55.862690999999998	город Москва, СЗАО, район Северное Тушино, Свободы ул, дом 81, корп. 6		0101000020E61000006E3315E291B84240DAC69FA86CEE4B40
57196	1	\N	\N	1	12346	\N	55.861877999999997	город Москва, СЗАО, район Северное Тушино, Свободы ул, дом 81, корп. 1		0101000020E610000047C66AF3FFB842402992AF0452EE4B40
55688	1	\N	\N	1	4682	\N	55.812063999999999	город Москва, САО, район Сокол, Светлый пр, дом 2А	Россия, Москва, Светлый проезд, 2а	0101000020E6100000B9A81611C5BE4240252191B6F1E74B40
57289	1	\N	\N	1	7754	\N	55.844920000000002	город Москва, СЗАО, район Южное Тушино, Светлогорский пр, дом 7	Россия, Москва, Светлогорский проезд, 7	0101000020E610000090D8EE1EA0B3424040DEAB5626EC4B40
56025	1	\N	\N	1	187	\N	55.768694000000004	город Москва, ВАО, район Ивановское, Саянская ул, дом 3А	Россия, Москва, Саянская улица, 3а	0101000020E6100000AAB9DC60A8E94240D350A39064E24B40
56029	1	\N	\N	1	12833	\N	55.767077999999998	город Москва, ВАО, район Ивановское, Саянская ул, дом 6Б		0101000020E610000042D2A755F4E9424094BDA59C2FE24B40
56390	1	\N	\N	1	5187	\N	55.714987000000001	город Москва, ЮВАО, район Текстильщики, Саратовская ул, дом 16А	Россия, Москва, Саратовская улица, 16	0101000020E6100000FA4674CFBADE42405708ABB184DB4B40
56391	1	\N	\N	1	12629	\N	55.716898999999998	город Москва, ЮВАО, район Текстильщики, Саратовская ул, дом 21		0101000020E6100000F355F2B1BBDE42407EC4AF58C3DB4B40
56388	1	\N	\N	1	12629	\N	55.713704	город Москва, ЮВАО, район Текстильщики, Саратовская ул, дом 1/2		0101000020E61000006B60AB048BDD42401F8315A75ADB4B40
55870	1	\N	\N	1	13014	\N	55.859493999999998	город Москва, СВАО, район Отрадное, Санникова ул, дом 3, корп. 3		0101000020E6100000EA059FE6E4CB4240DA8D3EE603EE4B40
56794	1	\N	\N	1	13230	\N	55.645887999999999	город Москва, ЮЗАО, Обручевский район, Машела Саморы ул, дом 6, корп. 3		0101000020E6100000C85D8429CABF42407E703E75ACD24B40
56217	1	\N	\N	1	13161	\N	55.699741000000003	город Москва, ЮВАО, район Выхино-Жулебино, Самаркандский бульв, дом 28, корп. 2	Россия, Москва, Самаркандский Бульвар квартал 137А, Самаркандский бульвар, 28к2	0101000020E610000024B891B245E84240CE55F31C91D94B40
55684	1	\N	\N	1	12947	\N	55.795974999999999	Адрес помещения для голосования: город Москва, САО, район Сокол, Сальвадора Альенде ул., дом 6, адрес УИК: Алабяна ул, дом 15		0101000020E61000004818062CB9C0424080B74082E2E54B40
55683	1	\N	\N	1	12947	\N	55.794142999999998	Адрес помещения для голосования: город Москва, САО, район Сокол, Сальвадора Альенде ул., дом 9, адрес УИК: Новопесчаная ул, дом 24		0101000020E61000009A95ED43DEC0424075AC527AA6E54B40
56114	1	\N	\N	1	1525	\N	55.733162999999998	город Москва, ВАО, район Новокосино, Салтыковская ул, дом 5А	Россия, Москва, Салтыковская улица, 5а	0101000020E61000008EAF3DB324EE424091D10149D8DD4B40
56113	1	\N	\N	1	12877	\N	55.736412000000001	город Москва, ВАО, район Новокосино, Салтыковская ул, дом 13А		0101000020E61000004F5B238271EE4240E43098BF42DE4B40
56112	1	\N	\N	1	12877	\N	55.737364999999997	город Москва, ВАО, район Новокосино, Салтыковская ул, дом 13Б		0101000020E61000002BBF0CC688EE4240861BF0F961DE4B40
55396	1	\N	\N	1	12644	\N	55.739566925036698	город Москва, ЦАО, район Замоскворечье, Садовническая ул, дом 68	Россия, Москва, Садовническая улица, 68	0101000020E6100000334E4354E1D14240B519A721AADE4B40
55395	1	\N	\N	1	12644	\N	55.745604999999998	город Москва, ЦАО, район Замоскворечье, Садовническая ул, дом 33		0101000020E6100000BC07E8BE9CD14240F65D11FC6FDF4B40
56520	1	\N	\N	1	12896	\N	55.672508999999998	город Москва, ЮАО, район Нагатино-Садовники, Садовники ул, дом 13		0101000020E6100000DAE4F04927D4424001A260C614D64B40
56514	1	\N	\N	1	12896	\N	55.66863	город Москва, ЮАО, район Нагатино-Садовники, Садовники ул, дом 12		0101000020E6100000A7E9B303AED34240EF8FF7AA95D54B40
55412	1	\N	\N	1	12630	\N	55.772359400481001	город Москва, ЦАО, Мещанский район, Садовая-Сухаревская ул, дом 12		0101000020E6100000124DA08845D04240B9E2E2A8DCE24B40
55404	1	\N	\N	1	757	\N	55.770719999999997	Адрес помещения для голосования: город Москва, ЦАО, Красносельский район, Садовая-Спасская ул., дом 8, адрес УИК: Уланский пер, дом 11, кв. 2	Россия, Москва, Садовая-Спасская улица, 8с1	0101000020E6100000D02A33A5F5D14240C22FF5F3A6E24B40
56370	1	\N	\N	1	2849	\N	55.728231000000001	город Москва, ЮВАО, Рязанский район, Рязанский просп, дом 39, стр. 4	Россия, Москва, Рязанский проспект, 39с4	0101000020E6100000F243A51133E14240797764AC36DD4B40
56208	1	\N	\N	1	2849	\N	55.707588000000001	город Москва, ЮВАО, район Выхино-Жулебино, Рязанский просп, дом 82, корп. 4	Россия, Москва, Рязанский проспект, 82к4	0101000020E61000002C9FE57970E9424062855B3E92DA4B40
56205	1	\N	\N	1	2849	\N	55.712761	город Москва, ЮВАО, район Выхино-Жулебино, Рязанский просп, дом 68, корп. 2	Россия, Москва, Рязанский проспект, 68к2	0101000020E610000008043A9336E74240A06EA0C03BDB4B40
56204	1	\N	\N	1	2849	\N	55.714087724480002	город Москва, ЮВАО, район Выхино-Жулебино, Рязанский просп, дом 99, корп. 1	Россия, Москва, Рязанский проспект, 99	0101000020E61000009E25C808A8E84240A73B4F3C67DB4B40
56429	1	\N	\N	1	13006	\N	55.591050000000003	город Москва, ЮАО, район Бирюлево Восточное, Ряжская ул, дом 13, корп. 2		0101000020E6100000750305DEC9D542408126C286A7CB4B40
56970	1	\N	4266	1	12487	\N	55.717279108993601	город Москва, ЗАО, Можайский район, Рябиновая ул, дом 8, корп. 2	Россия, Москва, Рябиновая улица, 8к2	0101000020E610000030B95164ADB54240C58D5BCCCFDB4B40
55807	1	\N	\N	1	13217	\N	55.811532999999997	город Москва, СВАО, Бутырский район, Руставели ул, дом 2		0101000020E610000004013274ECCA4240F84F3750E0E74B40
55407	1	\N	\N	1	800	\N	55.782465999999999	город Москва, ЦАО, Красносельский район, Русаковская ул, дом 10	Россия, Москва, Русаковская улица, 10с1	0101000020E6100000FA5E43705CD64240B01D8CD827E44B40
55774	1	\N	\N	1	13044	\N	55.866585999999998	город Москва, СВАО, Бабушкинский район, Рудневой ул, дом 10		0101000020E61000008C868C47A9D64240F295404AECEE4B40
56078	1	\N	\N	1	12471	\N	55.7150192186784	город Москва, ВАО, район Косино - Ухтомский, Рудневка ул, дом 10	Россия, Москва, улица Рудневка, 10	0101000020E610000085402E71E4F1424062821ABE85DB4B40
55384	1	\N	\N	1	470	\N	55.772841	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Рубцов пер., дом 10/14, адрес УИК: Почтовая Б. ул, дом 18/20, корп. 12	Россия, Москва, Рубцов переулок, 10/14	0101000020E6100000C59107228BD8424004013274ECE24B40
56948	1	\N	\N	1	12673	\N	55.744982	город Москва, ЗАО, район Кунцево, Рублевское шоссе, дом 24, корп. 4	Россия, Москва, район Крылатское, Рублевское шоссе, 24к4	0101000020E6100000454772F90FB74240E90DF7915BDF4B40
56942	1	\N	\N	1	12673	\N	55.745183477533402	город Москва, ЗАО, район Кунцево, Рублевское шоссе, дом 24, корп. 3	Россия, Москва, район Крылатское, Рублевское шоссе, 24к3	0101000020E6100000A33F34F3E4B642408044132862DF4B40
55941	1	\N	\N	1	12800	\N	55.874136999999997	город Москва, СВАО, Ярославский район, Ротерта ул, дом 5		0101000020E61000004BE82E89B3DC42409D9CA1B8E3EF4B40
55896	1	\N	\N	1	13073	\N	55.833708000000001	город Москва, СВАО, район Ростокино, Ростокинская ул, дом 7		0101000020E6100000D7A3703D0AD54240F03499F1B6EA4B40
55895	1	\N	\N	1	13073	\N	55.835442	город Москва, СВАО, район Ростокино, Ростокинская ул, дом 3		0101000020E610000080EF366F9CD4424038DA71C3EFEA4B40
56657	1	\N	\N	1	12622	\N	55.600323000000003	город Москва, ЮАО, район Чертаново Южное, Россошанский пр, дом 3А	Россия, Москва, Россошанский проезд, 3а	0101000020E61000003D484F9143CE4240B0045262D7CC4B40
57081	1	\N	\N	1	13092	\N	55.634278000000002	город Москва, ЗАО, район Солнцево, Родниковая ул, дом 20, корп. 1		0101000020E6100000D1048A58C4B042404149810530D14B40
57139	1	\N	\N	1	5570	\N	55.894191999999997	город Москва, СЗАО, район Куркино, Родионовская ул, дом 8	Россия, Москва, Родионовская улица, 8	0101000020E6100000F73C7FDAA8B24240232C2AE274F24B40
57079	1	\N	\N	1	12798	\N	55.894514999999998	город Москва, СЗАО, район Куркино, Родионовская ул, дом 6/7		0101000020E6100000865AD3BCE3B242400664AF777FF24B40
57265	1	\N	\N	1	13242	\N	55.795226	город Москва, СЗАО, район Щукино, Рогова ул, дом 1		0101000020E61000003AE97DE36BBB4240E6762FF7C9E54B40
55977	1	\N	\N	1	13048	\N	55.734765000000003	город Москва, ВАО, район Вешняки, Реутовская ул, дом 16А		0101000020E61000006781768714EB42406B9F8EC70CDE4B40
55974	1	\N	\N	1	13048	\N	55.740907	город Москва, ВАО, район Вешняки, Реутовская ул, дом 2А		0101000020E6100000E71C3C139AEA42405130630AD6DE4B40
56758	1	\N	\N	1	12820	\N	55.675255	город Москва, ЮЗАО, район Котловка, Ремизова ул, дом 12		0101000020E61000008CA2073E06CD4240F1BA7EC16ED64B40
56918	1	\N	\N	1	3550	\N	55.741084999999998	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Резервный пр.,  дом 10, адрес УИК: Студенческая ул, дом 25		0101000020E6100000045ABA826DC6424030478FDFDBDE4B40
56987	1	\N	\N	1	12752	\N	55.724595999999998	город Москва, ЗАО, Можайский район, Ращупкина ул, дом 3		0101000020E6100000F94CF6CFD3B84240FD67CD8FBFDC4B40
56802	1	\N	\N	1	1858	\N	55.573683000000003	город Москва, ЮЗАО, район Северное Бутово, Ратная ул, дом 6А	Россия, Москва, Ратная улица, 6а	0101000020E61000005F7F129F3BCB4240B6A2CD716EC94B40
56796	1	\N	\N	1	1858	\N	55.575296999999999	город Москва, ЮЗАО, район Северное Бутово, Ратная ул, дом 14А	Россия, Москва, Ратная улица, 14а	0101000020E6100000CB4BFE277FC94240533E0455A3C94B40
56801	1	\N	\N	1	12754	\N	55.573948000000001	город Москва, ЮЗАО, район Северное Бутово, Ратная ул, дом 6Б		0101000020E6100000A6D425E318CB424064CDC82077C94B40
56797	1	\N	\N	1	12754	\N	55.575296999999999	Адрес помещения для голосования: город Москва, ЮЗАО, район Северное Бутово, Ратная ул., дом 14А, адрес УИК: Ратная ул, дом 8В		0101000020E6100000CB4BFE277FC94240533E0455A3C94B40
55552	1	\N	\N	1	12665	\N	55.786189230650599	город Москва, САО, район Беговой, Расковой ул, дом 14/16	Россия, Москва, улица Расковой, 14	0101000020E6100000F9D687F546C94240CBBC55D7A1E44B40
55539	1	\N	\N	1	12665	\N	55.785198999999999	город Москва, САО, район Беговой, Расковой ул, дом 4		0101000020E6100000EACDA8F92AC942400BED9C6681E44B40
57059	1	\N	\N	1	12965	\N	55.690460999999999	город Москва, ЗАО, район Раменки, Раменки ул, дом 15, корп.1		0101000020E6100000A0E062450DC04240EC14AB0661D84B40
57058	1	\N	\N	1	12965	\N	55.688806	город Москва, ЗАО, район Раменки, Раменки ул, дом 15, корп.2		0101000020E6100000A98592C9A9BF4240F0A485CB2AD84B40
57057	1	\N	\N	1	12965	\N	55.693581000000002	город Москва, ЗАО, район Раменки, Раменки ул, дом 4		0101000020E6100000925852EE3EBF424041102043C7D84B40
55770	1	\N	\N	1	5675	\N	55.859265999999998	город Москва, СВАО, Бабушкинский район, Радужная ул, дом 7	Россия, Москва, Радужная улица, 7	0101000020E6100000E6E5B0FB8ED542404948A46DFCED4B40
55771	1	\N	\N	1	12722	\N	55.859302	город Москва, СВАО, Бабушкинский район, Радужная ул, дом 13		0101000020E6100000931804560ED5424096B1A19BFDED4B40
55372	1	\N	\N	1	13038	\N	55.763188999999997	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Радио ул., дом 6/4, стр. 1, адрес УИК: Сыромятнический 4-й пер, дом 3/5, стр.4		0101000020E6100000BCAE5FB01BD642405ED5592DB0E14B40
55457	1	\N	\N	1	12580	\N	55.743684000000002	город Москва, ЦАО, Таганский район, Рабочая ул, дом 12		0101000020E610000037A5BC5642D742407C478D0931DF4B40
57387	1	\N	\N	1	843	\N	55.844324	город Москва, СЗАО, район Митино, Пятницкое ш., 18, ТК «Митинский радиорынок»	Россия, Москва, Пятницкое шоссе, 18	0101000020E61000009FAF592E1BB142402C9D0FCF12EC4B40
57164	1	\N	\N	1	843	\N	55.841664999999999	город Москва, СЗАО, район Митино, Пятницкое шоссе, дом 16, корп. 5	Россия, Москва, Пятницкое шоссе, 16к5	0101000020E610000051BF0B5BB3B142400B98C0ADBBEB4B40
57162	1	\N	\N	1	843	\N	55.847493	город Москва, СЗАО, район Митино, Пятницкое шоссе, дом 25, корп. 3	Россия, Москва, Пятницкое шоссе, 25к3	0101000020E6100000B39AAE27BAAE4240624B8FA67AEC4B40
57159	1	\N	\N	1	843	\N	55.856892000000002	город Москва, СЗАО, район Митино, Пятницкое шоссе, дом 42, корп. 2	Россия, Москва, Пятницкое шоссе, 42к2	0101000020E6100000C0266BD443AE42401E1A16A3AEED4B40
57158	1	\N	\N	1	843	\N	55.856492000000003	город Москва, СЗАО, район Митино, Пятницкое шоссе, дом 45, корп. 2	Россия, Москва, Пятницкое шоссе, 45к2	0101000020E6100000A3CC069964AC424090A4A487A1ED4B40
55393	1	\N	\N	1	13197	\N	55.736868000000001	город Москва, ЦАО, район Замоскворечье, Пятницкая ул, дом 46, стр. 3		0101000020E61000008849B89047D0424006BCCCB051DE4B40
57044	1	\N	\N	1	13131	\N	55.727628000000003	город Москва, ЗАО, район Раменки, Пырьева ул, дом 11		0101000020E61000000873BB97FBC24240B3D30FEA22DD4B40
55761	1	\N	\N	1	5560	\N	55.875450000000001	город Москва, СВАО, Алтуфьевский район, Путевой пр, дом  10А	Россия, Москва, Путевой проезд, 10а	0101000020E610000069AB92C83ECA424040A4DFBE0EF04B40
55760	1	\N	\N	1	5560	\N	55.875450000000001	город Москва, СВАО, Алтуфьевский район, Путевой пр, дом 10А	Россия, Москва, Путевой проезд, 10а	0101000020E610000069AB92C83ECA424040A4DFBE0EF04B40
55605	1	\N	\N	1	3623	\N	55.843843	город Москва, САО, Головинский район, Пулковская ул, дом 6А	Россия, Москва, Пулковская улица, 6ас3	0101000020E6100000DE21C50089BE4240B1FA230C03EC4B40
55817	1	\N	\N	1	12917	\N	55.906582	город Москва, СВАО, район Лианозово, Псковская ул, дом 11		0101000020E6100000B84082E2C7C64240369204E10AF44B40
55818	1	\N	\N	1	12742	\N	55.903604999999999	город Москва, СВАО, район Лианозово, Псковская ул, дом 12, корп. 3		0101000020E6100000620FED6305C7424044C02154A9F34B40
55942	1	\N	\N	1	13039	\N	55.874257999999998	город Москва, СВАО, Ярославский район, Проходчиков ул, дом 9		0101000020E61000007619FED30DDC42401822A7AFE7EF4B40
55940	1	\N	\N	1	13039	\N	55.876218000000001	город Москва, СВАО, Ярославский район, Проходчиков ул, дом 12		0101000020E61000002B33A5F5B7DC4240511553E927F04B40
56814	1	\N	\N	1	82	\N	55.617719283350802	город Москва, ЮЗАО, район Теплый Стан, Профсоюзная ул, дом 156, корп. 6	Россия, Москва, Профсоюзная улица, 156к6	0101000020E61000003D2828452BBF4240158F8B6A11CF4B40
56727	1	\N	\N	1	13093	\N	55.647168000000001	Адрес помещения для голосования: город Москва, ЮЗАО, район Коньково, Профсоюзная ул., дом 98 А, адрес УИК: Профсоюзная ул, дом 98, корп. 1		0101000020E6100000058C2E6F0EC342404582A966D6D24B40
56894	1	\N	\N	1	12427	\N	55.623936800538203	город Москва, ЮЗАО, район Ясенево, Профсоюзная ул, дом 123а	Россия, Москва, Профсоюзная улица, 123ас1	0101000020E6100000B3B112F3ACC44240D6E1E82ADDCF4B40
56834	1	\N	\N	1	12427	\N	55.673321000000001	город Москва, ЮЗАО, район Черемушки, Профсоюзная ул, дом 25, корп. 4		0101000020E6100000D32D3BC43FC84240E25AED612FD64B40
56830	1	\N	\N	1	12427	\N	55.676093000000002	город Москва, ЮЗАО, район Черемушки, Профсоюзная ул, дом 40, корп. 2		0101000020E6100000FE0E45813EC74240FB0626378AD64B40
56811	1	\N	\N	1	12427	\N	55.626537463167999	город Москва, ЮЗАО, район Теплый Стан, Профсоюзная ул, дом 142, корп. 5	Россия, Москва, Профсоюзная улица, 142к5	0101000020E610000091B8C7D287C04240F25D4A5D32D04B40
56810	1	\N	\N	1	12427	\N	55.630924	Адрес помещения для голосования: город Москва, ЮЗАО, район Теплый Стан, Профсоюзная ул., дом 132, корп. 9, адрес УИК: Профсоюзная ул, дом 128	Россия, Москва, Профсоюзная улица, 132к9	0101000020E61000000ABE69FAECC0424079211D1EC2D04B40
56809	1	\N	\N	1	12427	\N	55.630850777712602	город Москва, ЮЗАО, район Теплый Стан, Профсоюзная ул, дом 132, корп. 9	Россия, Москва, Профсоюзная улица, 132к9	0101000020E6100000F3C98AE1EAC042400FD3BEB9BFD04B40
56783	1	\N	\N	1	12427	\N	55.6669908230784	город Москва, ЮЗАО, Обручевский район, Профсоюзная ул, дом 62, корп. 2	Россия, Москва, Профсоюзная улица, 62	0101000020E61000008E7406465EC64240F9DC09F65FD54B40
56751	1	\N	\N	1	12427	\N	55.637540000000001	город Москва, ЮЗАО, район Коньково, Профсоюзная ул, дом 118 Б		0101000020E6100000454AB3791CC2424028F224E99AD14B40
56744	1	\N	\N	1	12427	\N	55.630090000000003	город Москва, ЮЗАО, район Коньково, Профсоюзная ул, дом 115, корп. 1		0101000020E6100000A8C30AB77CC24240B1C403CAA6D04B40
56740	1	\N	\N	1	12427	\N	55.637967000000003	Адрес помещения для голосования: город Москва, ЮЗАО, район Коньково, Профсоюзная ул., дом 97, корп. 1, адрес УИК: Введенского ул, дом 30, корпус 1		0101000020E61000004E0E9F7422C34240B07614E7A8D14B40
56734	1	\N	\N	1	12427	\N	55.644779999999997	Адрес помещения для голосования: город Москва, ЮЗАО, район Коньково, Профсоюзная ул., дом 83 Б, адрес УИК: Профсоюзная ул, дом 83, корп. 3		0101000020E61000001805C1E3DBC34240B48EAA2688D24B40
56728	1	\N	\N	1	12427	\N	55.647168000000001	город Москва, ЮЗАО, район Коньково, Профсоюзная ул, дом 98 А		0101000020E6100000058C2E6F0EC342404582A966D6D24B40
56726	1	\N	\N	1	12427	\N	55.649844999999999	город Москва, ЮЗАО, район Коньково, Профсоюзная ул, дом 96 Б		0101000020E610000004AF963B33C342400C3CF71E2ED34B40
56680	1	\N	\N	1	12427	\N	55.679813000000003	город Москва, ЮЗАО, Академический район, Профсоюзная ул, дом 24а		0101000020E61000004450357A35C84240A532C51C04D74B40
56679	1	\N	\N	1	12427	\N	55.678148	город Москва, ЮЗАО, Академический район, Профсоюзная ул, дом 15а		0101000020E6100000C6BE64E3C1C8424085ECBC8DCDD64B40
56677	1	\N	\N	1	12427	\N	55.682107999999999	город Москва, ЮЗАО, Академический район, Профсоюзная ул, дом 9а		0101000020E610000061C43E0114C94240842BA0504FD74B40
55415	1	\N	\N	1	924	\N	55.780541999999997	город Москва, ЦАО, Мещанский район, Протопоповский пер, дом 5	Россия, Москва, Протопоповский переулок, 5	0101000020E610000036E50AEF72D14240C493DDCCE8E34B40
56221	1	\N	\N	1	13107	\N	55.701673	город Москва, ЮВАО, район Выхино-Жулебино, Пронская ул, дом 4, корп. 1		0101000020E6100000F931E6AE25EC42403CBEBD6BD0D94B40
56506	1	\N	\N	1	6474	\N	55.648159	город Москва, ЮАО, район Москворечье-Сабурово, Пролетарский просп, дом 6, корп. 3	Россия, Москва, Пролетарский проспект, 6к3	0101000020E610000068226C787AD34240D5CDC5DFF6D24B40
57082	1	\N	\N	1	5602	\N	55.648935999999999	город Москва, ЗАО, район Солнцево, Производственная ул, дом 3, корп. 2	Россия, Москва, Производственная улица, 3к2	0101000020E61000000FD253E410B142403999B85510D34B40
55449	1	\N	\N	1	1468	\N	55.759126999999999	город Москва, ЦАО, Пресненский район, Причальный пр, дом 7	Россия, Москва, Причальный проезд, 7с1	0101000020E61000002D9622F94AC242405B41D3122BE14B40
56997	1	\N	\N	1	13071	\N	55.642707999999999	город Москва, ЗАО, район Ново-Переделкино, Приречная ул, дом 3		0101000020E61000003A4030478FAF42405470784144D24B40
56998	1	\N	\N	1	13170	\N	55.641646000000001	город Москва, ЗАО, район Ново-Переделкино, Приречная ул, дом 1		0101000020E610000086A92D7590AF4240FBCDC47421D24B40
56228	1	\N	\N	1	3088	\N	55.687350000000002	город Москва, ЮВАО, район Выхино-Жулебино, Привольная ул, дом 45	Россия, Москва, Привольная улица, 45	0101000020E61000002713B70A62EC4240EB73B515FBD74B40
56227	1	\N	\N	1	3088	\N	55.689162000000003	город Москва, ЮВАО, район Выхино-Жулебино, Привольная ул, дом 41	Россия, Москва, Привольная улица, 41	0101000020E610000078B988EFC4EC4240AFD2DD7536D84B40
56225	1	\N	\N	1	3088	\N	55.691541999999998	город Москва, ЮВАО, район Выхино-Жулебино, Привольная ул, дом 37	Россия, Москва, Привольная улица, 37	0101000020E6100000A67D737FF5EC4240BCE7C07284D84B40
56222	1	\N	\N	1	13162	\N	55.698512999999998	город Москва, ЮВАО, район Выхино-Жулебино, Привольная ул, дом 17, корп. 1		0101000020E61000002D5E2C0C91EB4240596ABDDF68D94B40
57401	1	\N	\N	1	12392	\N	55.979670453746998	"город Москва, ЗАО, район Внуково, привокзальная площадь, штаб строительства ОАО ""Трансстрой"""	Россия, Москва, Зеленоград, Привокзальная площадь, с2	0101000020E6100000E3A59BC420964240A86F99D365FD4B40
55665	1	\N	\N	1	4413	\N	55.873370000000001	город Москва, САО, Левобережный район, Прибрежный пр, дом 12	Россия, Москва, Прибрежный проезд, 12	0101000020E6100000FF756EDA8CBB42405DA79196CAEF4B40
55494	1	\N	\N	1	12962	\N	55.743487000000002	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Пречистенка ул., дом 16, адрес УИК: Нащокинский пер, дом 6		0101000020E6100000D17AF83251CC42402600FF942ADF4B40
55555	1	\N	\N	1	12522	\N	55.784692999999997	город Москва, САО, район Беговой, Правды ул, дом 1А		0101000020E6100000D4298F6E84C942403733FAD170E44B40
55554	1	\N	\N	1	12522	\N	55.788590999999997	город Москва, САО, район Беговой, Правды ул, дом 21		0101000020E610000065C405A051CA4240C075C58CF0E44B40
55553	1	\N	\N	1	12522	\N	55.784692999999997	Адрес помещения для голосования: город Москва, САО, район Беговой, Правды ул., дом 1А, адрес УИК: Ленинградский просп, дом 26		0101000020E6100000D4298F6E84C942403733FAD170E44B40
57287	1	\N	\N	1	7731	\N	55.842843000000002	Адрес помещения для голосования: город Москва, СЗАО, район Южное Тушино, Походный пр., дом 23, адрес УИК: Донелайтиса пр, дом 12, корп. 2		0101000020E6100000F5108DEE20B64240CE548847E2EB4B40
55365	1	\N	\N	1	180	\N	55.759046243792604	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Потаповский пер., дом 16, адрес УИК: Чистопрудный бульв, дом 12/7	Россия, Москва, Потаповский переулок, 16с3	0101000020E610000065E256410CD242406E14596B28E14B40
56866	1	\N	\N	1	12886	\N	55.549759999999999	город Москва, ЮЗАО, район Южное Бутово, Поляны ул, дом 53		0101000020E6100000FA0E7EE200C64240115322895EC64B40
55681	1	\N	\N	1	13122	\N	55.793677000000002	город Москва, САО, Савеловский район, Полтавская ул, дом 3		0101000020E610000072DD94F25AC94240304B3B3597E54B40
56951	1	\N	\N	1	12506	\N	55.732351999999999	город Москва, ЗАО, район Кунцево, Полоцкая ул, дом 21, корп. 1		0101000020E6100000E547FC8A35B642408194D8B5BDDD4B40
56094	1	\N	\N	1	12773	\N	55.747580999999997	город Москва, ВАО, район Новогиреево, Полимерная ул, дом 7А		0101000020E6100000757632384AE64240340EF5BBB0DF4B40
55731	1	\N	\N	1	12787	\N	55.775930000000002	город Москва, САО, Хорошевский район, Поликарпова ул, дом 3А		0101000020E61000008578245E9EC642401EFE9AAC51E34B40
56366	1	\N	\N	1	12651	\N	55.670000999999999	город Москва, ЮВАО, район Печатники, Полбина ул, дом 68		0101000020E61000007973B8567BDC4240C6A4BF97C2D54B40
56364	1	\N	\N	1	12651	\N	55.680264999999999	город Москва, ЮВАО, район Печатники, Полбина ул, дом 44		0101000020E61000004C38F4160FDD424085CE6BEC12D74B40
56363	1	\N	\N	1	12651	\N	55.681859000000003	город Москва, ЮВАО, район Печатники, Полбина ул, дом 38		0101000020E6100000613255302ADD4240DCBDDC2747D74B40
56360	1	\N	\N	1	12651	\N	55.688000000000002	город Москва, ЮВАО, район Печатники, Полбина ул, дом 18		0101000020E61000008A05BEA25BDD4240F2D24D6210D84B40
56922	1	\N	\N	1	3590	\N	55.734298000000003	город Москва, ЗАО, район Дорогомилово, Поклонная ул, дом 16	Россия, Москва, Поклонная улица, 16	0101000020E6100000AA0D4E44BFC2424055C2137AFDDD4B40
56921	1	\N	\N	1	13206	\N	55.737603	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Поклонная ул., дом 2, адрес УИК: Кутузовский просп, дом 43		0101000020E6100000242713B70AC442403B376DC669DE4B40
56356	1	\N	\N	1	12726	\N	55.741227000000002	город Москва, ЮВАО, Нижегородский район, Подъемная ул, дом 15		0101000020E61000003F1EFAEE56DA4240C3F4BD86E0DE4B40
56656	1	\N	\N	1	12464	\N	55.605601999999998	город Москва, ЮАО, район Чертаново Южное, Подольских курсантов ул, дом 16А	Россия, Москва, улица Подольских Курсантов, 16ак1	0101000020E6100000C216BB7D56CF42403332C85D84CD4B40
56654	1	\N	\N	1	12464	\N	55.604803069183703	город Москва, ЮАО, район Чертаново Южное, Подольских курсантов ул, дом 18Б	Россия, Москва, улица Подольских Курсантов, 18б	0101000020E6100000AC5791D101CF4240E7C2482F6ACD4B40
56310	1	\N	\N	1	12794	\N	55.651780000000002	город Москва, ЮВАО, район Марьино, Подольская ул, дом 15		0101000020E610000065AA605452DB4240EC17EC866DD34B40
55447	1	\N	\N	1	13111	\N	55.758951149599099	город Москва, ЦАО, Пресненский район, Подвойского ул, дом 2	Россия, Москва, улица Подвойского, 2	0101000020E61000009F5912A0A6C442401D226E4E25E14B40
56118	1	\N	\N	1	12791	\N	55.742600000000003	город Москва, ВАО, район Перово, Плющева ул, дом 11А		0101000020E610000055DAE21A9FE142403B014D840DDF4B40
56117	1	\N	\N	1	12791	\N	55.741261999999999	город Москва, ВАО, район Перово, Плющева ул, дом 13А		0101000020E6100000B91AD99596E142403FE257ACE1DE4B40
56115	1	\N	\N	1	12791	\N	55.742933999999998	город Москва, ВАО, район Перово, Плющева ул, дом 14А		0101000020E6100000459E245D33E14240118B187618DF4B40
55791	1	\N	\N	1	12811	\N	55.888123999999998	город Москва, СВАО, район Бибирево, Плещеева ул, дом 26А		0101000020E610000072A3C85A43CF42407765170CAEF14B40
55843	1	\N	\N	1	12837	\N	55.832439000000001	город Москва, СВАО, район Марфино, Ботаническая М. ул, дом 24Б		0101000020E610000079E75086AACA42401D75745C8DEA4B40
55545	1	\N	\N	1	12878	\N	55.800995	Адрес помещения для голосования: город Москва, САО, район Аэропорт, Планетная ул., дом 23, адрес УИК: Планетная ул, дом 11		0101000020E610000086E28E37F9C5424038A1100187E64B40
57389	1	\N	\N	1	875	\N	55.861722	город Москва, СЗАО, район Северное Тушино, ул. Планерная, 5 (к.2), школа № 883	Россия, Москва, Планерная улица, 5	0101000020E61000002BD9B11188B74240321F10E84CEE4B40
57198	1	\N	\N	1	875	\N	55.859872000000003	город Москва, СЗАО, район Северное Тушино, Планерная ул, дом 12, корп. 2	Россия, Москва, Планерная улица, 12к2	0101000020E6100000F1D8CF6229B84240815F234910EE4B40
57197	1	\N	\N	1	13008	\N	55.859872000000003	Адрес помещения для голосования: город Москва, СЗАО, район Северное Тушино, Планерная ул., дом 12, корп. 2, адрес УИК: Фомичевой ул, дом 16, корп. 2		0101000020E6100000F1D8CF6229B84240815F234910EE4B40
57186	1	\N	\N	1	13008	\N	55.860438000000002	город Москва, СЗАО, район Северное Тушино, Планерная ул, дом 5, корп. 2		0101000020E610000094C0E61C3CB742402A1E17D522EE4B40
55679	1	\N	\N	1	12941	\N	55.797356000000001	город Москва, САО, Савеловский район, Писцовая ул, дом 7А		0101000020E6100000CE380D5185C942407BA2EBC20FE64B40
55674	1	\N	\N	1	12941	\N	55.797953999999997	Адрес помещения для голосования: город Москва, САО, Савеловский район, Писцовая ул., дом 14А, адрес УИК: Полтавская ул, дом 18		0101000020E610000071E316F373C942402FDB4E5B23E64B40
55773	1	\N	\N	1	13089	\N	55.865859	город Москва, СВАО, Бабушкинский район, Печорская ул, дом 18		0101000020E61000005AD6FD6321D4424040F9BB77D4EE4B40
55721	1	\N	\N	1	13238	\N	55.866081000000001	город Москва, САО, район Ховрино, Петрозаводская ул, дом 19А		0101000020E6100000C3802557B1BE4240EF5701BEDBEE4B40
55682	1	\N	\N	1	4499	\N	55.796284	город Москва, САО, Савеловский район, Петровско-Разумовский пр, дом 9	Россия, Москва, Петровско-Разумовский проезд, 9	0101000020E6100000200A664CC1C84240FE2955A2ECE54B40
55672	1	\N	\N	1	4499	\N	55.802396000000002	город Москва, САО, Савеловский район, Петровско-Разумовский пр, дом 27	Россия, Москва, Петровско-Разумовский проезд, 27	0101000020E6100000C3F17C06D4C742407A3881E9B4E64B40
55529	1	\N	\N	1	2594	\N	55.794234000000003	город Москва, САО, район Аэропорт, Петровско-разумовская аллея, дом 12А, стр. 1	Россия, Москва, Петровско-Разумовская аллея, 12ас1	0101000020E6100000DAAB8F87BEC7424086AFAF75A9E54B40
55482	1	\N	\N	1	12702	\N	55.765245	город Москва, ЦАО, Тверской район, Петровка ул, дом 23/10, стр. 21		0101000020E6100000ADA3AA09A2CE4240B936548CF3E14B40
56414	1	\N	\N	1	12746	\N	55.708308000000002	город Москва, ЮВАО, Южнопортовый район, Романова Петра ул, дом 6		0101000020E610000025AFCE3120D7424062BF27D6A9DA4B40
55692	1	\N	\N	1	4727	\N	55.799683999999999	Адрес помещения для голосования: город Москва, САО, район Сокол, Песчаный пер., дом 6, адрес УИК: Песчаная ул, дом 12		0101000020E61000004F594DD713C142403691990B5CE64B40
55693	1	\N	\N	1	13042	\N	55.802508000000003	Адрес помещения для голосования: город Москва, САО, район Сокол, Песчаная ул., дом 5, адрес УИК: Ленинградский просп, дом 75, корп.1А		0101000020E610000079CC4065FCC14240A2630795B8E64B40
55883	1	\N	\N	1	12950	\N	55.864438999999997	город Москва, СВАО, район Отрадное, Пестеля ул, дом 5		0101000020E610000014CB2DAD86CE42408731E9EFA5EE4B40
56349	1	\N	\N	1	4706	\N	55.735109000000001	город Москва, ЮВАО, Нижегородский район, Перовское шоссе, дом 8	Россия, Москва, Перовское шоссе, 8	0101000020E6100000C53D963E74DF424065FF3C0D18DE4B40
56120	1	\N	\N	1	12870	\N	55.746633000000003	город Москва, ВАО, район Перово, Перовская ул, дом 37		0101000020E610000044A33B889DE34240A48E8EAB91DF4B40
56119	1	\N	\N	1	12870	\N	55.745548999999997	город Москва, ВАО, район Перово, Перовская ул, дом 24А		0101000020E6100000A20C553195E2424062484E266EDF4B40
56092	1	\N	\N	1	12870	\N	55.746319	город Москва, ВАО, район Новогиреево, Перовская ул, дом 57А		0101000020E6100000187B2FBE68E5424014B1886187DF4B40
56091	1	\N	\N	1	12870	\N	55.741916000000003	город Москва, ВАО, район Новогиреево, Перовская ул, дом 44Б		0101000020E6100000F1BBE9961DE4424088307E1AF7DE4B40
56339	1	\N	\N	1	4551	\N	55.663679000000002	город Москва, ЮВАО, район Марьино, Перервинский бульв, дом 5, корп. 3	Россия, Москва, Перервинский бульвар, 5к3	0101000020E610000087F8872D3DE242406005F86EF3D44B40
56337	1	\N	\N	1	4551	\N	55.660139999999998	город Москва, ЮВАО, район Марьино, Перервинский бульв, дом 10, корп. 1	Россия, Москва, Перервинский бульвар, 10к1	0101000020E6100000B760A92EE0E142400664AF777FD44B40
56336	1	\N	\N	1	4551	\N	55.659804999999999	город Москва, ЮВАО, район Марьино, Перервинский бульв, дом 10, корп. 2	Россия, Москва, Перервинский бульвар, 10к2	0101000020E6100000C51F459DB9E142405F5E807D74D44B40
56335	1	\N	\N	1	4551	\N	55.655427000000003	город Москва, ЮВАО, район Марьино, Перервинский бульв, дом 16, корп. 1	Россия, Москва, Перервинский бульвар, 16к1	0101000020E61000001F11532289E242402CF52C08E5D34B40
56334	1	\N	\N	1	4551	\N	55.654437000000001	город Москва, ЮВАО, район Марьино, Перервинский бульв, дом 20, корп. 1	Россия, Москва, Перервинский бульвар, 20к1	0101000020E6100000E1B6B6F0BCE242406C257497C4D34B40
56329	1	\N	\N	1	12797	\N	55.660176	город Москва, ЮВАО, район Марьино, Перерва ул, дом 41, корп. 2		0101000020E6100000EFE714E467DF424053CDACA580D44B40
56846	1	\N	\N	1	12836	\N	55.659905999999999	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Перекопская ул., дом 21, адрес УИК: Севастопольский просп, дом 30	Россия, Москва, Новые Черемушки квартал 32А, Перекопская улица, 21	0101000020E61000002C0FD253E4C842409337C0CC77D44B40
56845	1	\N	\N	1	12836	\N	55.659912100085698	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Перекопская ул, дом 21, адрес УИК: Севастопольский просп, дом 30	Россия, Москва, Новые Черемушки квартал 32А, Перекопская улица, 21	0101000020E61000001F2DCE18E6C84240751E15FF77D44B40
57396	1	\N	\N	1	983	\N	55.729757667547602	город Москва, ЦАО, район Замоскворечье, Павелецкая пл, дом 1А, стр. 1		0101000020E6100000B77D8FFAEBD1424047FFCBB568DD4B40
56844	1	\N	\N	1	12836	\N	55.661566999999998	город Москва, ЮЗАО, район Черемушки, Перекопская ул, дом 28	Россия, Москва, Новые Черемушки квартал 32А, Перекопская улица, 28	0101000020E61000000B60CAC001C94240718E3A3AAED44B40
56709	1	\N	\N	1	12836	\N	55.656936000000002	город Москва, ЮЗАО, район Зюзино, Перекопская ул, дом 7, корп. 3	Россия, Москва, Новые Черемушки квартал 32А, Перекопская улица, 7к3	0101000020E610000065A71FD445CA424054C8957A16D44B40
56708	1	\N	\N	1	12836	\N	55.656936000000002	Адрес помещения для голосования: город Москва, ЮЗАО, район Зюзино, Перекопская ул., дом 7, корп. 3, адрес УИК: Севастопольский просп, дом 71	Россия, Москва, Новые Черемушки квартал 32А, Перекопская улица, 7к3	0101000020E610000065A71FD445CA424054C8957A16D44B40
55382	1	\N	\N	1	445	\N	55.778613	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Переведеновский пер., дом 11, адрес УИК: Бакунинская ул, дом 55		0101000020E6100000A359D93EE4D74240C79E3D97A9E34B40
56058	1	\N	\N	1	13173	\N	55.7937351615384	город Москва, ВАО, район Измайлово, Первомайская ул, дом 59	Россия, Москва, район Измайлово, Первомайская улица, 59	0101000020E61000000246973787E542406458C51B99E54B40
56067	1	\N	\N	1	13040	\N	55.793768	город Москва, ВАО, район Измайлово, Первомайская ул, дом 65		0101000020E610000098C28366D7E54240404E98309AE54B40
56050	1	\N	\N	1	13040	\N	55.791572000000002	город Москва, ВАО, район Измайлово, Первомайская ул, дом 3, корп. 1		0101000020E610000077853E58C6E24240F436363B52E54B40
56049	1	\N	\N	1	13040	\N	55.793475000000001	город Москва, ВАО, район Измайлово, Первомайская ул, дом 27А	Россия, Москва, район Измайлово, Первомайская улица, 27а	0101000020E6100000A12B11A8FEE34240C898BB9690E54B40
55988	1	\N	\N	1	13040	\N	55.791986999999999	город Москва, ВАО, район Восточное Измайлово, Первомайская ул, дом 78		0101000020E610000075CC79C6BEE64240B7ED7BD45FE54B40
57145	1	\N	\N	1	12994	\N	55.836058999999999	город Москва, СЗАО, район Митино, Пенягинская ул, дом 14		0101000020E610000051BEA08504AE4240634337FB03EB4B40
56427	1	\N	\N	1	13007	\N	55.596122000000001	город Москва, ЮАО, район Бирюлево Восточное, Педагогическая ул, дом 3		0101000020E6100000CFDBD8EC48D542408B36C7B94DCC4B40
56907	1	\N	\N	1	12719	\N	55.599376999999997	город Москва, ЮЗАО, район Ясенево, Паустовского ул, дом 5, корп. 2		0101000020E61000007D91D09673C54240BF7CB262B8CC4B40
56906	1	\N	\N	1	12719	\N	55.599325999999998	город Москва, ЮЗАО, район Ясенево, Паустовского ул, дом 5, корп. 3		0101000020E61000005FECBDF8A2C542403DD2E0B6B6CC4B40
56904	1	\N	\N	1	12719	\N	55.600470000000001	город Москва, ЮЗАО, район Ясенево, Паустовского ул, дом 6, корп. 2		0101000020E6100000A9A5B915C2C44240541D7233DCCC4B40
57252	1	\N	\N	1	12879	\N	55.787922999999999	город Москва, СЗАО, район Хорошево-Мневники, Паршина ул, дом 39		0101000020E61000000AD9791B9BB9424013622EA9DAE44B40
57247	1	\N	\N	1	12879	\N	55.789729999999999	город Москва, СЗАО, район Хорошево-Мневники, Паршина ул, дом 4		0101000020E6100000E65B1FD61BBB4240C55565DF15E54B40
56959	1	\N	\N	1	4036	\N	55.737025000000003	город Москва, ЗАО, район Кунцево, Партизанская ул, дом 30, корп.2, стр. 1	Россия, Москва, Партизанская улица, 30к2с2	0101000020E61000002DCE18E604B54240CEAACFD556DE4B40
56955	1	\N	\N	1	4036	\N	55.72963	город Москва, ЗАО, район Кунцево, Партизанская ул, дом 7, корп. 3	Россия, Москва, Партизанская улица, 7к3	0101000020E6100000EBE6E26F7BB442401A170E8464DD4B40
56953	1	\N	\N	1	13059	\N	55.730735000000003	город Москва, ЗАО, район Кунцево, Партизанская ул, дом 11		0101000020E6100000F6CE68AB92B44240738577B988DD4B40
56961	1	\N	\N	1	12632	\N	55.739438	город Москва, ЗАО, район Кунцево, Партизанская ул, дом 45		0101000020E6100000B87878CF81B34240B7B585E7A5DE4B40
56960	1	\N	\N	1	12632	\N	55.738428999999996	город Москва, ЗАО, район Кунцево, Партизанская ул, дом 39		0101000020E6100000CF8250DEC7B3424080B56AD784DE4B40
56958	1	\N	\N	1	12632	\N	55.736628189959198	город Москва, ЗАО, район Кунцево, Партизанская ул, дом 30, корп. 2, стр. 1	Россия, Москва, Партизанская улица, 30к2	0101000020E61000000282397AFCB44240B1A888D349DE4B40
56956	1	\N	\N	1	12632	\N	55.737025000000003	город Москва, ЗАО, район Кунцево, Партизанская ул, дом 30, корп. 2, стр. 2		0101000020E61000002DCE18E604B54240CEAACFD556DE4B40
56465	1	\N	\N	1	6063	\N	55.639313999999999	город Москва, ЮАО, район Братеево, Паромная ул, дом 5, корп. 3	Россия, Москва, Паромная улица, 5к3	0101000020E61000003B394371C7E14240FEEF880AD5D14B40
55686	1	\N	\N	1	12507	\N	55.802295000000001	Адрес помещения для голосования: город Москва, САО, район Сокол, Панфилова ул., дом 6, адрес УИК: Панфилова ул, дом 4, корп.3		0101000020E61000000CCC0A45BABF4240465F419AB1E64B40
55953	1	\N	\N	1	7500	\N	55.877082000000001	город Москва, СВАО, Ярославский район, Палехская ул, дом 137	Россия, Москва, Палехская улица, 137	0101000020E610000069519FE40EDB424084F4143944F04B40
55950	1	\N	\N	1	7500	\N	55.866312999999998	Адрес помещения для голосования: город Москва, СВАО, Ярославский район, Палехская ул., дом 10, адрес УИК: Хибинский  пр, дом 3	Россия, Москва, Палехская улица, 10	0101000020E610000079EBFCDB65D94240C18C2958E3EE4B40
55951	1	\N	\N	1	13142	\N	55.866312999999998	город Москва, СВАО, Ярославский район, Палехская ул, дом 10		0101000020E610000079EBFCDB65D94240C18C2958E3EE4B40
55949	1	\N	\N	1	13041	\N	55.864671999999999	город Москва, СВАО, Ярославский район, Палехская ул, дом 8		0101000020E6100000B41EBE4C14D942402AE27492ADEE4B40
56472	1	\N	\N	1	12776	\N	55.714328000000002	город Москва, ЮАО, Даниловский район, Павловская ул, дом 8А		0101000020E61000006667D13B15D04240FD4E93196FDB4B40
55751	1	\N	\N	1	12528	\N	55.812908999999998	город Москва, СВАО, Алексеевский район, Корчагина Павла ул, дом 1А		0101000020E61000002FF99FFCDDD34240E1CFF0660DE84B40
55748	1	\N	\N	1	12528	\N	55.819287000000003	город Москва, СВАО, Алексеевский район, Корчагина Павла ул, дом 22		0101000020E6100000912BF52C08D54240DC847B65DEE84B40
55747	1	\N	\N	1	12528	\N	55.810308999999997	город Москва, СВАО, Алексеевский район, Корчагина Павла ул, дом 2		0101000020E6100000C8D11C59F9D34240C5538F34B8E74B40
55600	1	\N	\N	1	12989	\N	55.843790948998901	город Москва, САО, Головинский район, Онежская ул, дом 2		0101000020E61000001F4AB4E4F1C242405FD4EE5701EC4B40
57024	1	\N	\N	1	4869	\N	55.695442999999997	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Очаковское шоссе, дом 10, адрес УИК: Очаковское шоссе, дом 2, корп. 3	Россия, Москва, Очаковское шоссе, 10к1	0101000020E610000037397CD289BA4240B69DB64604D94B40
57022	1	\N	\N	1	4869	\N	55.695442999999997	город Москва, ЗАО, район Очаково-Матвеевское, Очаковское шоссе, дом 10	Россия, Москва, Очаковское шоссе, 10к1	0101000020E610000037397CD289BA4240B69DB64604D94B40
55885	1	\N	\N	1	6848	\N	55.860427999999999	город Москва, СВАО, район Отрадное, Отрадная ул, дом 1А	Россия, Москва, Отрадная улица, 1а	0101000020E6100000B6A2CD716ECD42400648348122EE4B40
55888	1	\N	\N	1	12765	\N	55.857047999999999	город Москва, СВАО, район Отрадное, Отрадная ул, дом 11Б		0101000020E61000003D98141F9FCE4240158DB5BFB3ED4B40
55886	1	\N	\N	1	12765	\N	55.857456999999997	город Москва, СВАО, район Отрадное, Отрадная ул, дом 11А		0101000020E610000012C138B874CE4240F65CA626C1ED4B40
56089	1	\N	\N	1	1092	\N	55.825006999999999	город Москва, ВАО, район Метрогородок, Открытое шоссе, дом 24, корп. 35	Россия, Москва, Открытое шоссе, 24к35	0101000020E6100000E4A1EF6E65E142404CFC51D499E94B40
56088	1	\N	\N	1	1092	\N	55.829067000000002	город Москва, ВАО, район Метрогородок, Открытое шоссе, дом 29А	Россия, Москва, Открытое шоссе, 29а	0101000020E6100000679DF17D71E14240AF9811DE1EEA4B40
56087	1	\N	\N	1	1092	\N	55.8288344892201	город Москва, ВАО, район Метрогородок, Открытое шоссе, дом 25	Россия, Москва, Открытое шоссе, 25	0101000020E6100000711FB935E9E042400CE8853B17EA4B40
56086	1	\N	\N	1	1092	\N	55.827084999999997	город Москва, ВАО, район Метрогородок, Открытое шоссе, дом 23А	Россия, Москва, Открытое шоссе, 23а	0101000020E610000051DA1B7C61E042408E01D9EBDDE94B40
56085	1	\N	\N	1	1092	\N	55.820115999999999	город Москва, ВАО, район Метрогородок, Открытое шоссе, дом 24, корп. 7	Россия, Москва, Открытое шоссе, 24к7	0101000020E6100000E7E26F7B82E042409276A38FF9E84B40
56084	1	\N	\N	1	1092	\N	55.823019000000002	город Москва, ВАО, район Метрогородок, Открытое шоссе, дом 24, корп. 27	Россия, Москва, Открытое шоссе, 24к27	0101000020E610000029ED0DBE30E142404A7EC4AF58E94B40
55966	1	\N	\N	1	1092	\N	55.809403000000003	город Москва, ВАО, район Богородское, Открытое шоссе, дом 6, корп. 12	Россия, Москва, Открытое шоссе, 6к12	0101000020E610000074CE4F711CDE424064247B849AE74B40
55742	1	\N	\N	1	12884	\N	55.798672000000003	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Острякова ул., дом 15А, адрес УИК: Ленинградский просп, дом 57		0101000020E6100000FB90B75CFDC242408F1D54E23AE64B40
56808	1	\N	\N	1	12470	\N	55.632713000000003	город Москва, ЮЗАО, район Теплый Стан, Островитянова ул, дом 18, корп. 5	Россия, Москва, улица Островитянова, 18к5	0101000020E61000007B13437232C14240856055BDFCD04B40
56737	1	\N	\N	1	12470	\N	55.637103000000003	город Москва, ЮЗАО, район Коньково, Островитянова ул, дом 53, корп. 4		0101000020E6100000DD7D8E8F16C542407D9752978CD14B40
55781	1	\N	\N	1	5803	\N	55.876762999999997	город Москва, СВАО, Бабушкинский район, Осташковская ул, дом 7, корп. 6	Россия, Москва, Осташковская улица, 7к6	0101000020E6100000889FFF1EBCD64240E2AB1DC539F04B40
55920	1	\N	\N	1	13134	\N	55.891576999999998	город Москва, СВАО, район Северное Медведково, Осташковская ул, дом 30, корп. 2		0101000020E61000008C868C47A9D64240D26EF4311FF24B40
56939	1	\N	\N	1	3845	\N	55.759922000000003	город Москва, ЗАО, район Крылатское, Осенняя ул, дом 8	Россия, Москва, Осенняя улица, 8к1	0101000020E6100000B9A5D590B8B3424066C1C41F45E14B40
56936	1	\N	\N	1	3800	\N	55.757536000000002	город Москва, ЗАО, район Крылатское, Осенний бульв, дом 10, корп. 3	Россия, Москва, Осенний бульвар, 10к3	0101000020E6100000ABAFAE0AD4B4424076C58CF0F6E04B40
56965	1	\N	\N	1	2326	\N	55.742296000000003	город Москва, ЗАО, район Кунцево, Оршанская, дом 10, корп. 2	Россия, Москва, Оршанская улица, 10к2	0101000020E6100000EDF0D7648DB44240CFF9298E03DF4B40
56964	1	\N	\N	1	13063	\N	55.742939	город Москва, ЗАО, район Кунцево, Оршанская ул, дом 10, корп. 1		0101000020E610000094A5D6FB8DB4424023F609A018DF4B40
56481	1	\N	\N	1	6241	\N	55.623697	город Москва, ЮАО, район Зябликово, Ореховый пр, дом 17, корп. 2	Россия, Москва, Ореховый проезд, 17к2	0101000020E61000002942EA76F6DD424081CEA44DD5CF4B40
56579	1	\N	\N	1	2515	\N	55.609947464870402	город Москва, ЮАО, район Орехово-Борисово Северное, Ореховый бульв, дом 3	Россия, Москва, Ореховый бульвар, 3	0101000020E61000001FD95C35CFD942408BA548BE12CE4B40
56577	1	\N	\N	1	2515	\N	55.868662	город Москва, ЮАО, район Орехово-Борисово Северное, Ореховый бульв, дом 11, корп. 3		0101000020E6100000758E01D9EBCD424094A3005130EF4B40
56576	1	\N	\N	1	2515	\N	55.613478809195897	город Москва, ЮАО, район Орехово-Борисово Северное, Ореховый бульв, дом 21, корп. 2	Россия, Москва, Ореховый бульвар, 21к2	0101000020E61000000E315EF3AADC424032E4D87A86CE4B40
56495	1	\N	\N	1	2515	\N	55.617210488719699	город Москва, ЮАО, район Зябликово, Ореховый бульв, дом 35, корп. 3	Россия, Москва, Ореховый бульвар, 35к3	0101000020E61000004754A86E2EDE4240D061BEBC00CF4B40
56493	1	\N	\N	1	2515	\N	55.615150999999997	город Москва, ЮАО, район Зябликово, Ореховый бульв, дом 37, корп. 4	Россия, Москва, Ореховый бульвар, 37к4	0101000020E610000083DDB06D51DE4240048D9944BDCE4B40
56350	1	\N	\N	1	4721	\N	55.731206	город Москва, ЮВАО, Нижегородский район, Орехово-Зуевский пр, дом 4	Россия, Москва, Орехово-Зуевский проезд, 4	0101000020E61000004242942F68DF4240CA51802898DD4B40
56072	1	\N	\N	1	12434	\N	55.713135999999999	город Москва, ВАО, район Косино - Ухтомский, Оренбургская ул, дом 15	Россия, Москва, Оренбургская улица, 15	0101000020E6100000486AA16472EE4240D5CC5A0A48DB4B40
56487	1	\N	\N	1	13031	\N	55.709499999999998	город Москва, ЮАО, Донской район, Орджоникидзе ул, дом 15		0101000020E6100000B4006DAB59CB4240894160E5D0DA4B40
55601	1	\N	\N	1	3551	\N	55.845086999999999	город Москва, САО, Головинский район, Онежская ул, дом 3	Россия, Москва, Онежская улица, 3	0101000020E610000041D653ABAFC242402BA391CF2BEC4B40
55613	1	\N	\N	1	12505	\N	55.85436	город Москва, САО, Головинский район, Онежская ул, дом 24, корп. 1		0101000020E61000004E452A8C2DC242405A8121AB5BED4B40
55779	1	\N	\N	1	5792	\N	55.874279000000001	город Москва, СВАО, Бабушкинский район, Олонецкий пр, дом 6	Россия, Москва, Олонецкий проезд, 6	0101000020E6100000CB811E6ADBD44240304AD05FE8EF4B40
55890	1	\N	\N	1	13126	\N	55.851505000000003	город Москва, СВАО, район Отрадное, Олонецкая ул, дом 13		0101000020E6100000151BF33AE2CE4240B4B0A71DFEEC4B40
55418	1	\N	\N	1	969	\N	55.790641000000001	город Москва, ЦАО, Мещанский район, Олимпийский просп, дом 11, корпус 2	Россия, Москва, Олимпийский проспект, 11с2	0101000020E6100000A67B9DD497CF424039F06AB933E54B40
57086	1	\N	\N	1	12830	\N	55.669358954568601	город Москва, ЗАО, район Тропарево-Никулино, Мичуринский просп. Олимп. дер, дом 24		0101000020E610000040A19E3E02BB42404224438EADD54B40
56201	1	\N	\N	1	13159	\N	55.800159999999998	город Москва, ВАО, район Сокольники, Олений вал ул, дом 22		0101000020E610000053AF5B04C6D842409FC893A46BE64B40
57104	1	\N	\N	1	13149	\N	55.738875	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Дундича Олеко ул., дом 23, Адрес УИК: Кастанаевская ул, дом 7		0101000020E61000002577D84466BE42407F6ABC7493DE4B40
55847	1	\N	\N	1	6473	\N	55.786515999999999	город Москва, СВАО, район Марьина роща, Октябрьский пер, дом 11	Россия, Москва, Октябрьский переулок, 11	0101000020E61000002B357BA015CE4240EFE3688EACE44B40
55853	1	\N	\N	1	12956	\N	55.795938999999997	город Москва, СВАО, район Марьина роща, Октябрьская ул, дом 81		0101000020E61000003F52448655CE4240334E4354E1E54B40
56235	1	\N	\N	1	12937	\N	55.710853999999998	город Москва, ЮВАО, район Кузьминки, Окская ул, дом 16, корп. 3		0101000020E61000007AFD497CEEE042408A1D8D43FDDA4B40
57028	1	\N	\N	1	4942	\N	55.674168999999999	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Озерная ул., дом 27, корп. 2, адрес УИК: Озерная ул, дом 27	Россия, Москва, Озерная улица, 27к2	0101000020E610000042E8A04B38BA42400F7D772B4BD64B40
57220	1	\N	\N	1	13025	\N	55.790452999999999	город Москва, СЗАО, район Строгино, Одинцовская ул, дом 24		0101000020E6100000D192C7D3F2B3424036035C902DE54B40
56714	1	\N	\N	1	12899	\N	55.660170999999998	город Москва, ЮЗАО, район Зюзино, Одесская ул, дом 13		0101000020E6100000B3CF639467CC42404162BB7B80D44B40
55397	1	\N	\N	1	649	\N	55.743496999999998	город Москва, ЦАО, район Замоскворечье, Овчинниковская наб, дом 22/24	Россия, Москва, Овчинниковская набережная, 22/24с1	0101000020E6100000AFB2B6291ED1424049D6E1E82ADF4B40
56790	1	\N	\N	1	12672	\N	55.660384000000001	город Москва, ЮЗАО, Обручевский район, Обручева ул, дом 11, корп. 1		0101000020E6100000C30E63D2DFC142409D66817687D44B40
57377	1	\N	\N	1	12743	\N	55.875844000000001	город Москва, СВАО, район Лосиноостровский, Норильская ул., 4, СОШ № 762		0101000020E6100000BD19355F25D94240EC32FCA71BF04B40
55832	1	\N	\N	1	12743	\N	55.875844000000001	город Москва, СВАО, Лосиноостровский район, Норильская ул, дом 4		0101000020E6100000BD19355F25D94240EC32FCA71BF04B40
55546	1	\N	\N	1	1161	\N	55.800624999999997	Адрес помещения для голосования: город Москва, САО, район Аэропорт, Зыковский нов. пр., дом 4А, адрес УИК: Планетная ул, дом 11		0101000020E610000062BF27D6A9C6424014AE47E17AE64B40
56891	1	\N	\N	1	3220	\N	55.603659	город Москва, ЮЗАО, район Ясенево, Новоясеневский просп, дом 24, корп. 3	Россия, Москва, Новоясеневский проспект, 24к3	0101000020E6100000BD8C62B9A5C34240D177B7B244CD4B40
56313	1	\N	\N	1	4227	\N	55.649048000000001	город Москва, ЮВАО, район Марьино, Новочеркасский бульв, дом 19	Россия, Москва, Новочеркасский бульвар, 19	0101000020E610000080643A747ADC424061C43E0114D34B40
56311	1	\N	\N	1	4227	\N	55.649006999999997	город Москва, ЮВАО, район Марьино, Новочеркасский бульв, дом 17	Россия, Москва, Новочеркасский бульвар, 17	0101000020E61000007155D97745DC424002F04FA912D34B40
56840	1	\N	\N	1	2301	\N	55.665142000000003	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Новочеремушкинская ул., дом 62, корп. 2, адрес УИК: Профсоюзная ул, дом 43, корп. 2	Россия, Москва, Новочеремушкинская улица, 62к2	0101000020E6100000CA8CB7955EC742401899805F23D54B40
56833	1	\N	\N	1	2301	\N	55.672609999999999	город Москва, ЮЗАО, район Черемушки, Новочеремушкинская ул, дом 48	Россия, Москва, Новочеремушкинская улица, 48	0101000020E61000006E3315E291C84240357BA01518D64B40
56670	1	\N	\N	1	2301	\N	55.689405000000001	город Москва, ЮЗАО, Академический район, Новочеремушкинская  ул, дом 3	Россия, Москва, Новочеремушкинская улица, 3	0101000020E6100000C1E270E657CB424075594C6C3ED84B40
56842	1	\N	\N	1	12572	\N	55.664507	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Новочеремушкинская ул., дом 64, корп. 6, адрес УИК: Профсоюзная ул, дом 45, корп. 1		0101000020E610000053793BC269C74240467BBC900ED54B40
56841	1	\N	\N	1	12572	\N	55.664634	город Москва, ЮЗАО, район Черемушки, Новочеремушкинская ул, дом 64, корп. 2		0101000020E6100000A5F622DA8EC74240A3E716BA12D54B40
56835	1	\N	\N	1	12572	\N	55.668975000000003	город Москва, ЮЗАО, район Черемушки, Новочеремушкинская ул, дом 56		0101000020E6100000601E32E543C84240BA6B09F9A0D54B40
56828	1	\N	\N	1	12572	\N	55.665142000000003	город Москва, ЮЗАО, район Черемушки, Новочеремушкинская ул, дом 62, корп. 2		0101000020E6100000CA8CB7955EC742401899805F23D54B40
56671	1	\N	\N	1	12572	\N	55.685858000000003	город Москва, ЮЗАО, Академический район, Новочеремушкинская  ул, дом 11а		0101000020E6100000D66F26A60BCB424099D9E731CAD74B40
57231	1	\N	\N	1	7091	\N	55.779656000000003	город Москва, СЗАО, район Хорошево-Мневники, Новохорошевский пр, дом 12	Россия, Москва, Новохорошевский проезд, 12	0101000020E61000007DAEB6627FBF4240AA108FC4CBE34B40
57230	1	\N	\N	1	7091	\N	55.777934999999999	город Москва, СЗАО, район Хорошево-Мневники, Новохорошевский пр, дом 26	Россия, Москва, Новохорошевский проезд, 26	0101000020E61000000B09185DDEBE4240F6B4C35F93E34B40
9324	6	58	339	5617	43555	\N	55.335996000000002	деревня Мавлютова, Полевая, 32		0101000020E61000004EB340BB43444E401DCBBBEA01AB4B40
57229	1	\N	\N	1	7091	\N	55.778061000000001	город Москва, СЗАО, район Хорошево-Мневники, Новохорошевский пр, дом 1	Россия, Москва, Новохорошевский проезд, 1	0101000020E6100000E658DE550FC0424083A5BA8097E34B40
57166	1	\N	\N	1	6475	\N	55.839728999999998	город Москва, СЗАО, район Митино, Новотушинский пр, дом 8	Россия, Москва, Новотушинский проезд, 8	0101000020E61000003A3C84F1D3B042405B40683D7CEB4B40
57165	1	\N	\N	1	6475	\N	55.839283999999999	город Москва, СЗАО, район Митино, Новотушинский пр, дом 8, корп. 2	Россия, Москва, Новотушинский проезд, 8к2	0101000020E610000066F6798CF2B042402D077AA86DEB4B40
55848	1	\N	\N	1	12697	\N	55.787269999999999	город Москва, СВАО, район Марьина роща, Новосущевская ул, дом 7А		0101000020E6100000386BF0BE2ACD42409B8F6B43C5E44B40
55489	1	\N	\N	1	1787	\N	55.785224999999997	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Новослободская ул., дом 38, адрес УИК: Новослободская ул, дом 14/19, корп. 8		0101000020E6100000E083D72E6DCC42403480B74082E44B40
55473	1	\N	\N	1	1787	\N	55.787942999999999	город Москва, ЦАО, Тверской район, Новослободская ул, дом 57	Россия, Москва, Новослободская улица, 57/65	0101000020E61000002766BD18CACB42405A0EF450DBE44B40
55474	1	\N	\N	1	12482	\N	55.783366999999998	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Новослободская ул., дом 43/3, адрес УИК: Лесная ул, дом 61, стр.1		0101000020E6100000062AE3DF67CC424000E2AE5E45E44B40
56014	1	\N	\N	1	36	\N	55.813080999999997	город Москва, ВАО, район Гольяново, Новосибирская ул, дом 3А	Россия, Москва, Новосибирская улица, 3а	0101000020E61000006495D233BDE84240DEFFC70913E84B40
56016	1	\N	\N	1	12826	\N	55.815676000000003	город Москва, ВАО, район Гольяново, Новосибирская ул, дом 8А		0101000020E6100000C05DF6EB4EE94240E910381268E84B40
56947	1	\N	\N	1	12819	\N	55.786996000000002	Адрес помещения для голосования: город Москва, ЗАО, район Кунцево, Новорублевская ул., дом 1, адрес УИК: Советская ул, дом 11А		0101000020E6100000A94F72874DAE42409A0AF148BCE44B40
56304	1	\N	\N	1	13185	\N	55.669341000000003	город Москва, ЮВАО, район Люблино, Новороссийская ул, дом 36		0101000020E6100000912A8A5759E142409C6F44F7ACD54B40
55460	1	\N	\N	1	1592	\N	55.739635775085702	город Москва, ЦАО, Таганский район, Новорогожская ул, дом 18	Россия, Москва, Новорогожская улица, 18с1	0101000020E6100000A453573ECBD74240DD787764ACDE4B40
55458	1	\N	\N	1	12928	\N	55.742559	город Москва, ЦАО, Таганский район, Новорогожская ул, дом 9		0101000020E61000005854C4E924D74240DC2C5E2C0CDF4B40
55645	1	\N	\N	1	13225	\N	55.827660999999999	город Москва, САО, район Коптево, Новопетровская ул, дом 1А		0101000020E6100000FF21FDF675C242405B96AFCBF0E94B40
55695	1	\N	\N	1	13021	\N	55.798271999999997	город Москва, САО, район Сокол, Новопесчаная ул, дом 15		0101000020E610000086AE44A0FAC1424000A8E2C62DE64B40
57001	1	\N	\N	1	12756	\N	55.639090000000003	город Москва, ЗАО, район Ново-Переделкино, Новопеределкинская ул, дом 9, корп. 1		0101000020E610000091B8C7D287AE4240AF997CB3CDD14B40
57003	1	\N	\N	1	12849	\N	55.639775999999998	город Москва, ЗАО, район Ново-Переделкино, Новопеределкинская ул, дом 13, корп. 1		0101000020E61000005FF0694E5EAE42400262122EE4D14B40
57002	1	\N	\N	1	12849	\N	55.640121000000001	город Москва, ЗАО, район Ново-Переделкино, Новопеределкинская ул, дом 9		0101000020E61000008FE1B19FC5AE4240CD3D247CEFD14B40
57000	1	\N	\N	1	12849	\N	55.639090000000003	Адрес помещения для голосования: город Москва, ЗАО, район Ново-Переделкино, Новопеределкинская ул., дом 9, корп. 1, адрес УИК: Боровское шоссе, дом 33, корп. 1, Боровское шоссе, дом 33, корп. 1		0101000020E610000091B8C7D287AE4240AF997CB3CDD14B40
56407	1	\N	\N	1	13164	\N	55.717508000000002	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Новоостаповская ул., дом 10, адрес УИК: Шарикоподшипниковская ул, дом 24		0101000020E610000012BD8C62B9D54240274F594DD7DB4B40
55862	1	\N	\N	1	6612	\N	55.816662000000001	город Москва, СВАО, Останкинский район, Новомосковская ул, дом 10/16	Россия, Москва, Новомосковская улица, 10	0101000020E6100000BA15C26A2CCF424067F1626188E84B40
56325	1	\N	\N	1	13140	\N	55.653385	город Москва, ЮВАО, район Марьино, Новомарьинская ул, дом 7, корп. 2		0101000020E6100000782AE09EE7DF42403659A31EA2D34B40
56110	1	\N	\N	1	1389	\N	55.741809000000003	город Москва, ВАО, район Новокосино, Новокосинская ул, дом 40А	Россия, Москва, Новокосинская улица, 40а	0101000020E61000004A7D59DAA9EF42407270E998F3DE4B40
56108	1	\N	\N	1	1389	\N	55.743715000000002	город Москва, ВАО, район Новокосино, Новокосинская ул, дом 41	Россия, Москва, Новокосинская улица, 41	0101000020E610000059FCA6B052EF4240B745990D32DF4B40
56103	1	\N	\N	1	1389	\N	55.735398000000004	город Москва, ВАО, район Новокосино, Новокосинская ул, дом 13А	Россия, Москва, Новокосинская улица, 13а	0101000020E6100000289CDD5A26ED42409CC58B8521DE4B40
56109	1	\N	\N	1	12875	\N	55.741565999999999	город Москва, ВАО, район Новокосино, Новокосинская ул, дом 42А		0101000020E6100000910BCEE0EFEF4240ABE97AA2EBDE4B40
57116	1	\N	\N	1	13208	\N	55.747277466866798	город Москва, ЗАО, район Филевский парк, Новозаводская ул, дом 2, корп. 5	Россия, Москва, район Филевский парк, Новозаводская улица, 2к5	0101000020E610000058E36C3A02C24240C806D2C5A6DF4B40
56130	1	\N	\N	1	1769	\N	55.757288000000003	город Москва, ВАО, район Перово, Новогиреевская ул, дом 22А	Россия, Москва, Новогиреевская улица, 22а	0101000020E6100000AE669DF17DE542409ED32CD0EEE04B40
55752	1	\N	\N	1	12801	\N	55.807004999999997	город Москва, СВАО, Алексеевский район, Новоалексеевская ул, дом 6		0101000020E610000085EE92382BD24240AF5A99F04BE74B40
55357	1	\N	\N	1	34	\N	55.756176300592102	Адрес помещения для голосования: город Москва, ЦАО, район Арбат, Новинский бульв., дом 20, адрес УИК: Трубниковский пер, дом 21	Россия, Москва, Новинский бульвар, 20с1	0101000020E61000004033880FECCA424093020B60CAE04B40
57056	1	\N	\N	1	3529	\N	55.694124000000002	город Москва, ЗАО, район Раменки, Мичуринский просп, дом 23	Россия, Москва, Мичуринский проспект, 23	0101000020E6100000611C5C3AE6C0424032AF230ED9D84B40
55355	1	\N	\N	1	34	\N	55.751057000000003	Адрес помещения для голосования: город Москва, ЦАО, район Арбат, Новинский бульв., дом 3, адрес УИК: Шубинский пер, дом 6	Россия, Москва, Новинский бульвар, 3с1	0101000020E6100000D00B772E8CCA42404837C2A222E04B40
56556	1	\N	\N	1	12987	\N	55.676285999999998	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Новинки ул., дом 8, адрес УИК: Андропова просп, дом 29, корп. 2		0101000020E6100000FEEF880AD5D542400F5F268A90D64B40
56555	1	\N	\N	1	12987	\N	55.676285999999998	город Москва, ЮАО, район Нагатинский затон, Новинки ул, дом 8		0101000020E6100000FEEF880AD5D542400F5F268A90D64B40
56554	1	\N	\N	1	12987	\N	55.677259999999997	город Москва, ЮАО, район Нагатинский затон, Новинки ул, дом 21, корп. 2		0101000020E6100000D1AE42CA4FD64240C971A774B0D64B40
55826	1	\N	\N	1	6219	\N	55.892601999999997	город Москва, СВАО, район Лианозово, Новгородская ул, дом 6	Россия, Москва, Новгородская улица, 6	0101000020E6100000B81E85EB51CA42400E2C47C840F24B40
55825	1	\N	\N	1	6219	\N	55.893445	город Москва, СВАО, район Лианозово, Новгородская ул, дом 8	Россия, Москва, Новгородская улица, 8	0101000020E6100000B72407EC6ACA42402AE3DF675CF24B40
55824	1	\N	\N	1	12921	\N	55.893455000000003	город Москва, СВАО, район Лианозово, Новгородская ул, дом 7А		0101000020E6100000FA5FAE450BCA42404EB9C2BB5CF24B40
55823	1	\N	\N	1	12821	\N	55.894948999999997	город Москва, СВАО, район Лианозово, Новгородская ул, дом 12		0101000020E610000024438EAD67CA4240404B57B08DF24B40
55822	1	\N	\N	1	12821	\N	55.900692999999997	город Москва, СВАО, район Лианозово, Новгородская ул, дом 24, корп. 1		0101000020E6100000D4F2035779CA4240395E81E849F34B40
55820	1	\N	\N	1	12821	\N	55.900567000000002	город Москва, СВАО, район Лианозово, Новгородская ул, дом 21А		0101000020E6100000DE91B1DAFCC94240AD6D8AC745F34B40
55374	1	\N	\N	1	12525	\N	55.768315108421	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Басманная Нов. ул., дом 6, адрес УИК: Садовая-Черногрязская ул, дом 11/2	Россия, Москва, Новая Басманная улица, 4-6с4	0101000020E610000064062AE3DFD342405C035B2558E24B40
55638	1	\N	\N	1	13221	\N	55.872900000000001	город Москва, САО, район Западное Дегунино, Новая ул, дом 2		0101000020E61000008735954561C14240D656EC2FBBEF4B40
56789	1	\N	\N	1	12655	\N	55.665115999999998	Адрес помещения для голосования: город Москва, ЮЗАО, Обручевский район, Новаторов ул., дом 4, корп. 8, адрес УИК: Новаторов ул, дом 16, корп. 2		0101000020E61000000EBE30992AC24240EE05668522D54B40
57100	1	\N	\N	1	13087	\N	55.668934999999998	город Москва, ЗАО, район Тропарево-Никулино, Никулинская ул, дом 10		0101000020E61000008C497F2F85BB42402B137EA99FD54B40
57084	1	\N	\N	1	13087	\N	55.666442000000004	город Москва, ЗАО, район Тропарево-Никулино, Никулинская ул, дом 5	Россия, Москва, Никулинская улица, 5	0101000020E6100000FB75A73B4FBA42402657B1F84DD54B40
55451	1	\N	\N	1	12548	\N	55.747580999999997	Адрес помещения для голосования: город Москва, ЦАО, Таганский район, Николоямская ул., дом 33, адрес УИК: Мартыновский пер, дом 8		0101000020E6100000AC53E57B46D44240340EF5BBB0DF4B40
55439	1	\N	\N	1	13222	\N	55.756523000000001	город Москва, ЦАО, Пресненский район, Николаева ул, дом 5		0101000020E6100000B3CEF8BEB8C84240FED5E3BED5E04B40
55481	1	\N	\N	1	1901	\N	55.757491000000002	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Никитский пер., дом 7, стр. 1, адрес УИК: Тверская ул, дом 6, стр. 6		0101000020E61000001762F54718CE4240D6011077F5E04B40
56047	1	\N	\N	1	12753	\N	55.797134	город Москва, ВАО, район Измайлово, Никитинская ул, дом 7		0101000020E6100000F9C08EFF02E34240CC43A67C08E64B40
56048	1	\N	\N	1	13169	\N	55.796542000000002	город Москва, ВАО, район Измайлово, Никитинская ул, дом 4А		0101000020E61000005930F14751E34240FAF19716F5E54B40
56070	1	\N	\N	1	12345	\N	55.790671000000003	город Москва, ВАО, район Измайлово, Первомайская нижн. ул, дом 14		0101000020E6100000AEBCE47FF2E54240A47213B534E54B40
56069	1	\N	\N	1	12345	\N	55.791114672557399	город Москва, ВАО, район Измайлово, Парковая 8-я ул, дом 9/15	Россия, Москва, Нижняя Первомайская улица	0101000020E6100000419E5DBEF5E5424001309E4143E54B40
55990	1	\N	\N	1	12345	\N	55.791491000000001	город Москва, ВАО, район Восточное Измайлово, Первомайская нижн. ул, дом 51	Россия, Москва, Нижняя Первомайская улица, 51	0101000020E61000005DFE43FAEDE74240070ABC934FE54B40
55989	1	\N	\N	1	12345	\N	55.791491000000001	город Москва, ВАО, район Восточное Измайлово, Первомайская нижн.ул, дом 51		0101000020E61000005DFE43FAEDE74240070ABC934FE54B40
55680	1	\N	\N	1	13172	\N	55.792335999999999	город Москва, САО, Савеловский район, Масловка Нижн. ул, дом 16		0101000020E6100000EFE714E467C94240C3B81B446BE54B40
55678	1	\N	\N	1	13172	\N	55.792937999999999	город Москва, САО, Савеловский район, Масловка Нижн. ул, дом 8		0101000020E6100000F965304624CA4240B9E00CFE7EE54B40
56352	1	\N	\N	1	1608	\N	55.732351999999999	город Москва, ЮВАО, Нижегородский район, Нижегородская ул, дом 67	Россия, Москва, Нижегородская улица, 67	0101000020E61000000801F9122ADC42408194D8B5BDDD4B40
55459	1	\N	\N	1	1608	\N	55.740319	город Москва, ЦАО, Таганский район, Нижегородская ул, дом 3Б	Россия, Москва, Нижегородская улица, 3бс1	0101000020E610000061FF756EDAD64240C0CDE2C5C2DE4B40
56354	1	\N	\N	1	12981	\N	55.733452	город Москва, ЮВАО, Нижегородский район, Нижегородская ул, дом 70, корп. 1		0101000020E61000003C873254C5DA4240C89750C1E1DD4B40
56353	1	\N	\N	1	12981	\N	55.729644999999998	город Москва, ЮВАО, Нижегородский район, Нижегородская ул, дом 98		0101000020E6100000321EA5129EDC42404F58E20165DD4B40
56355	1	\N	\N	1	12647	\N	55.732813	город Москва, ЮВАО, Нижегородский район, Нижегородская ул, дом 64, стр. 1		0101000020E6100000E1EB6B5D6ADA4240B58AFED0CCDD4B40
55712	1	\N	\N	1	13026	\N	55.823954999999998	город Москва, САО, Тимирязевский район, Немчинова ул, 8		0101000020E61000001DE38A8BA3C842401630815B77E94B40
55711	1	\N	\N	1	13026	\N	55.823954999999998	город Москва, САО, Тимирязевский район, Немчинова ул, дом 8		0101000020E61000001DE38A8BA3C842401630815B77E94B40
9251	6	58	339	1622	43625	\N	55.453778999999997	деревня Курманова, Школьная, 18		0101000020E6100000963FDF162C694E40484E266E15BA4B40
57282	1	\N	\N	1	7676	\N	55.845097000000003	Адрес помещения для голосования: город Москва, СЗАО, район Южное Тушино, Нелидовская ул., дом 21, корп. 1, адрес УИК: Нелидовская ул, дом 19	Россия, Москва, Нелидовская улица, 21к1	0101000020E6100000261B0FB6D8B742404F7974232CEC4B40
57029	1	\N	\N	1	12658	\N	55.717528000000001	город Москва, ЗАО, район Очаково-Матвеевское, Нежинская ул, дом 2		0101000020E61000004BCB48BDA7BC42406EFB1EF5D7DB4B40
57014	1	\N	\N	1	12658	\N	55.712031000000003	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Нежинская ул., дом 7, корп. 3, адрес УИК: Веерная ул, дом 32, корп. 1		0101000020E61000006BF3FFAA23BD42407D5EF1D423DB4B40
57013	1	\N	\N	1	12658	\N	55.712031000000003	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Нежинская ул., дом 7, корп. 3, адрес УИК: Веерная ул, дом 32, корп.1		0101000020E61000006BF3FFAA23BD42407D5EF1D423DB4B40
56760	1	\N	\N	1	1360	\N	55.667735999999998	город Москва, ЮЗАО, район Котловка, Нахимовский просп, дом 10	Россия, Москва, Нахимовский проспект, 10	0101000020E6100000F12900C633CC4240512E8D5F78D54B40
56558	1	\N	\N	1	1360	\N	55.664116	Адрес помещения для голосования: город Москва, ЮАО, Нагорный район, Нахимовский просп., дом 4, корп. А, адрес УИК: Симферопольский пр, дом 5	Россия, Москва, Нахимовский проспект, 4а	0101000020E6100000423F53AF5BCE42400B60CAC001D54B40
57235	1	\N	\N	1	12569	\N	55.780461000000003	город Москва, СЗАО, район Хорошево-Мневники, Народного Ополчения ул, дом 27, корп. 2		0101000020E61000000B9A965819BD4240D8666325E6E34B40
57234	1	\N	\N	1	12569	\N	55.784348999999999	город Москва, СЗАО, район Хорошево-Мневники, Народного Ополчения ул, дом 32		0101000020E6100000D6A71C93C5BD42403DD34B8C65E44B40
57232	1	\N	\N	1	12569	\N	55.778593000000001	город Москва, СЗАО, район Хорошево-Мневники, Народного Ополчения ул, дом 22, корп. 4		0101000020E61000003AAE4676A5BD424080F277EFA8E34B40
57222	1	\N	\N	1	12569	\N	55.772846000000001	город Москва, СЗАО, район Хорошево-Мневники, Народного Ополчения ул, дом 16, корп. 4		0101000020E610000030D63730B9BD4240166C239EECE24B40
55470	1	\N	\N	1	12749	\N	55.737613000000003	Адрес помещения для голосования: город Москва, ЦАО, Таганский район, Народная ул., дом 11/2, адрес УИК: Каменщики М. ул, дом 16, стр.2	Россия, Москва, Народная улица, 11/2	0101000020E610000065355D4F74D342405F0D501A6ADE4B40
55469	1	\N	\N	1	12749	\N	55.737613000000003	город Москва, ЦАО, Таганский район, Народная ул, дом 11/2		0101000020E610000065355D4F74D342405F0D501A6ADE4B40
55578	1	\N	\N	1	12804	\N	55.835977999999997	Адрес помещения для голосования: город Москва, САО, Войковский район, Нарвская ул., дом 12, адрес УИК: Нарвская ул, дом 9А		0101000020E610000064E60297C7C042407616BD5301EB4B40
56036	1	\N	\N	1	315	\N	55.758204999999997	город Москва, ВАО, район Ивановское, Напольный пр, дом 7	Россия, Москва, Напольный проезд, 7	0101000020E6100000F48B12F417EA4240F35487DC0CE14B40
56033	1	\N	\N	1	315	\N	55.758605000000003	город Москва, ВАО, район Ивановское, Напольный пр, дом 9	Россия, Москва, Напольный проезд, 9	0101000020E6100000166EF9484AEA424082CAF8F719E14B40
56757	1	\N	\N	1	1160	\N	55.680000999999997	город Москва, ЮЗАО, район Котловка, Нагорная ул, дом 11, корп. 1	Россия, Москва, Нагорная улица, 11к1	0101000020E6100000AF0793E2E3CD4240A71FD4450AD74B40
56580	1	\N	\N	1	1160	\N	55.680128000000003	город Москва, ЮЗАО, район Котловка, Нагорная ул, дом 16	Россия, Москва, Нагорная улица, 16к1	0101000020E6100000CB9C2E8B89CD4240058C2E6F0ED74B40
56759	1	\N	\N	1	13156	\N	55.675362	город Москва, ЮЗАО, район Котловка, Нагорная ул, дом 32, корп. 3		0101000020E61000004E7FF62345CC4240077B134372D64B40
56748	1	\N	\N	1	13156	\N	55.678767999999998	город Москва, ЮЗАО, район Котловка, Нагорная ул, дом 22, корп. 1		0101000020E6100000BF47FDF50ACD424021C9ACDEE1D64B40
56541	1	\N	\N	1	6445	\N	55.689537000000001	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Нагатинская наб., дом 56, адрес УИК: Судостроительная ул, дом 44		0101000020E6100000E109BDFE24D84240E43098BF42D84B40
56518	1	\N	\N	1	6445	\N	55.681086999999998	город Москва, ЮАО, район Нагатино-Садовники, Нагатинская наб, дом 24	Россия, Москва, Нагатинская набережная, 24	0101000020E6100000778192020BD44240895DDBDB2DD74B40
56517	1	\N	\N	1	6445	\N	55.681548999999997	город Москва, ЮАО, район Нагатино-Садовники, Нагатинская наб, дом 12, корп. 1	Россия, Москва, Нагатинская набережная, 12к1	0101000020E6100000C98FF8156BD242408DCF64FF3CD74B40
56503	1	\N	\N	1	6445	\N	55.689537000000001	город Москва, ЮАО, район Нагатинский затон, Нагатинская наб, дом 56	Россия, Москва, Нагатинская набережная, 56	0101000020E6100000E109BDFE24D84240E43098BF42D84B40
56515	1	\N	\N	1	12897	\N	55.679676000000001	город Москва, ЮАО, район Нагатино-Садовники, Нагатинская ул, дом 4, корп.2		0101000020E6100000F7E461A1D6D0424024F0879FFFD64B40
56333	1	\N	\N	1	4386	\N	55.650688000000002	город Москва, ЮВАО, район Марьино, Мячковский бульв, дом 25	Россия, Москва, Мячковский бульвар, 25	0101000020E6100000F0A65B7688E1424028F38FBE49D34B40
56332	1	\N	\N	1	4386	\N	55.652282999999997	город Москва, ЮВАО, район Марьино, Мячковский бульв, дом 21	Россия, Москва, Мячковский бульвар, 21	0101000020E6100000813E912749E142404E5E64027ED34B40
56331	1	\N	\N	1	4386	\N	55.656986000000003	город Москва, ЮВАО, район Марьино, Мячковский бульв, дом 7, корп. 2	Россия, Москва, Мячковский бульвар, 7к2	0101000020E6100000BF654E97C5E0424006F7031E18D44B40
56328	1	\N	\N	1	4386	\N	55.656579999999998	город Москва, ЮВАО, район Марьино, Мячковский бульв, дом 7, корп. 1	Россия, Москва, Мячковский бульвар, 7к1	0101000020E61000005915E126A3E04240959A3DD00AD44B40
56327	1	\N	\N	1	4386	\N	55.655076999999999	город Москва, ЮВАО, район Марьино, Мячковский  бульв, дом 10, корп. 2	Россия, Москва, Мячковский бульвар, 10к2	0101000020E61000005D8940F50FE042404FAE2990D9D34B40
55424	1	\N	\N	1	13151	\N	55.789406	город Москва, ЦАО, Мещанский район, Переяславская М. ул, дом 6/8		0101000020E6100000AF25E4839ED1424012A27C410BE54B40
56326	1	\N	\N	1	4386	\N	55.655076999999999	город Москва, ЮВАО, район Марьино, Мячковский бульв, дом 10, корп. 2	Россия, Москва, Мячковский бульвар, 10к2	0101000020E61000005D8940F50FE042404FAE2990D9D34B40
56323	1	\N	\N	1	4386	\N	55.651069	город Москва, ЮВАО, район Марьино, Мячковский бульв, дом 14, корп. 3	Россия, Москва, Мячковский бульвар, 14к3	0101000020E6100000069E7B0F97E042403F389F3A56D34B40
56322	1	\N	\N	1	4386	\N	55.647919999999999	город Москва, ЮВАО, район Марьино, Мячковский бульв, дом 18, корп. 3	Россия, Москва, Мячковский бульвар, 18к3	0101000020E6100000E42EC214E5E042405036E50AEFD24B40
56471	1	\N	\N	1	6128	\N	55.718406686579797	Адрес помещения для голосования: город Москва, ЮАО, Даниловский район, Мытная ул., дом 50 корп. Б, адрес УИК: Шухова ул, дом 4	Россия, Москва, Мытная улица	0101000020E61000000C1F115322CF4240D61BB5C2F4DB4B40
56502	1	\N	\N	1	12880	\N	55.617607	город Москва, ЮАО, район Зябликово, Джалиля Мусы ул, дом 29, корп. 2		0101000020E610000090BB085394DF4240ED6305BF0DCF4B40
56500	1	\N	\N	1	12880	\N	55.624448999999998	город Москва, ЮАО, район Зябликово, Джалиля Мусы ул, дом 17, корп. 3		0101000020E61000002F52280B5FDF42408C82E0F1EDCF4B40
56499	1	\N	\N	1	12880	\N	55.628342000000004	город Москва, ЮАО, район Зябликово, Джалиля Мусы ул, дом 7, корп. 5		0101000020E6100000543882548ADF4240045ABA826DD04B40
56498	1	\N	\N	1	12880	\N	55.628107999999997	город Москва, ЮАО, район Зябликово, Джалиля Мусы ул, дом 6, корп. 3		0101000020E61000008FC536A968DE4240902DCBD765D04B40
56497	1	\N	\N	1	12880	\N	55.625430000000001	город Москва, ЮАО, район Зябликово, Джалиля Мусы ул, дом 12, корп. 2		0101000020E6100000575C1C959BDE4240F9F719170ED04B40
56494	1	\N	\N	1	12880	\N	55.617153999999999	город Москва, ЮАО, район Зябликово, Джалиля Мусы ул, дом 36, корп. 2		0101000020E61000001BD9959691DE42403C4CFBE6FECE4B40
55882	1	\N	\N	1	12683	\N	55.862585000000003	город Москва, СВАО, район Отрадное, Мусоргского ул, дом 3		0101000020E6100000A648BE1248CF424095826E2F69EE4B40
55881	1	\N	\N	1	12683	\N	55.863936625241898	город Москва, СВАО, район Отрадное, Мусоргского ул, дом 11В		0101000020E61000000262122EE4CF4240F566D47C95EE4B40
95178	1	\N	\N	1	12481	\N	55.713380000000001	город Москва, ВАО, район Косино-Ухтомский, Муромская ул., д. 1А	Россия, Москва, Муромская улица, 1а	0101000020E6100000C5724BAB21ED42406CCF2C0950DB4B40
56073	1	\N	\N	1	12488	\N	55.713331099698998	город Москва, ВАО, район Косино - Ухтомский, Муромская ул, дом 1А		0101000020E6100000DDCEBEF220ED42408A1C226E4EDB4B40
55855	1	\N	\N	1	6551	\N	55.804344	город Москва, СВАО, Останкинский район, Мурманский пр, дом 12	Россия, Москва, Мурманский проезд, 12	0101000020E6100000EE76BD3445D04240EE5D83BEF4E64B40
55797	1	\N	\N	1	5958	\N	55.895045000000003	город Москва, СВАО, район Бибирево, Мурановская ул, дом 10В	Россия, Москва, Мурановская улица, 10вс2	0101000020E6100000DE7536E49FCD424063B9A5D590F24B40
55796	1	\N	\N	1	12912	\N	55.89293	город Москва, СВАО, район Бибирево, Мурановская ул, дом 8Б		0101000020E6100000FDF7E0B54BCD424003CFBD874BF24B40
55795	1	\N	\N	1	12912	\N	55.890976999999999	город Москва, СВАО, район Бибирево, Мурановская ул, дом 4А		0101000020E6100000452A8C2D04CD42407D3ECA880BF24B40
55448	1	\N	\N	1	1453	\N	55.751026000000003	город Москва, ЦАО, Пресненский район, Мукомольный пр, дом 3	Россия, Москва, Мукомольный проезд, 3с1	0101000020E610000071AAB5300BC342400D39B69E21E04B40
57048	1	\N	\N	1	13081	\N	55.714084999999997	город Москва, ЗАО, район Раменки, Мосфильмовская ул, дом 21		0101000020E610000000A94D9CDCC1424036C8242367DB4B40
56030	1	\N	\N	1	13147	\N	55.763153000000003	город Москва, ВАО, район Ивановское, Молостовых ул, дом 6А		0101000020E61000005C902DCBD7E94240126C5CFFAEE14B40
56028	1	\N	\N	1	13147	\N	55.760281999999997	город Москва, ВАО, район Ивановское, Молостовых ул, дом 10А		0101000020E61000001381EA1F44EA424065DEAAEB50E14B40
55911	1	\N	\N	1	12780	\N	55.879218000000002	город Москва, СВАО, район Северное Медведково, Молодцова ул, дом 4А		0101000020E610000078EFA83121D24240FB0626378AF04B40
56954	1	\N	\N	1	4019	\N	55.732154000000001	город Москва, ЗАО, район Кунцево, Молодогвардейская ул, дом 47	Россия, Москва, Молодогвардейская улица, 47	0101000020E6100000185B087250B442405BD1E638B7DD4B40
56952	1	\N	\N	1	13100	\N	55.732098999999998	город Москва, ЗАО, район Кунцево, Молодогвардейская ул, дом 19, корп. 2		0101000020E6100000D047197101B642409737876BB5DD4B40
55984	1	\N	\N	1	12986	\N	55.720894999999999	город Москва, ВАО, район Вешняки, Молдагуловой ул, дом 20А		0101000020E61000004303B16CE6E84240CA6C904946DC4B40
56944	1	\N	\N	1	12750	\N	55.731997	город Москва, ЗАО, район Кунцево, Молдавская ул, дом 6, корп. 2		0101000020E610000070ED444948B8424093E2E313B2DD4B40
56985	1	\N	\N	1	2380	\N	55.721549000000003	город Москва, ЗАО, Можайский район, Можайское шоссе, дом 18, корп. 2	Россия, Москва, Можайское шоссе, 18к2	0101000020E610000026529ACDE3B6424013BBB6B75BDC4B40
56981	1	\N	\N	1	2380	\N	55.721086999999997	город Москва, ЗАО, Можайский район, Можайское шоссе, дом 38, корп. 7	Россия, Москва, Можайское шоссе, 38к7	0101000020E610000086C954C1A8B442400E492D944CDC4B40
56979	1	\N	\N	1	2380	\N	55.717224000000002	город Москва, ЗАО, Можайский район, Можайское шоссе, дом 50	Россия, Москва, Можайское шоссе, 50	0101000020E6100000852348A5D8B3424002F4FBFECDDB4B40
57228	1	\N	\N	1	12771	\N	55.774304999999998	город Москва, СЗАО, район Хорошево-Мневники, Мневники ул, дом 14, корп. 1		0101000020E61000006DC669882ABE42408C101E6D1CE34B40
57221	1	\N	\N	1	12771	\N	55.770426	город Москва, СЗАО, район Хорошево-Мневники, Мневники ул, дом 7, корп. 5		0101000020E610000053AEF02E17BF42407AFEB4519DE24B40
57085	1	\N	\N	1	3529	\N	55.694124000000002	город Москва, ЗАО, район Тропарево-Никулино, Мичуринский просп. Олимп. дер, дом 23	Россия, Москва, Мичуринский проспект, 23	0101000020E6100000611C5C3AE6C0424032AF230ED9D84B40
57063	1	\N	\N	1	3529	\N	55.696812999999999	город Москва, ЗАО, район Раменки, Мичуринский просп, дом 42	Россия, Москва, Мичуринский проспект, 42	0101000020E610000030BC92E4B9BE4240BD361B2B31D94B40
57062	1	\N	\N	1	3529	\N	55.694378	город Москва, ЗАО, район Раменки, Мичуринский просп, дом 54, корп.3	Россия, Москва, Мичуринский проспект, 54к3	0101000020E61000008BC1C3B46FBE4240EC87D860E1D84B40
57055	1	\N	\N	1	3529	\N	55.694124000000002	Адрес помещения для голосования: город Москва, ЗАО, район Раменки, Мичуринский просп., дом 23, адрес УИК: Мичуринский просп, дом 25, корп.5		0101000020E6100000611C5C3AE6C0424032AF230ED9D84B40
57054	1	\N	\N	1	3529	\N	55.697091999999998	город Москва, ЗАО, район Раменки, Мичуринский просп, дом 15, корп. 1	Россия, Москва, Мичуринский проспект, 15к1	0101000020E61000007E1D386744C14240D026874F3AD94B40
57053	1	\N	\N	1	3529	\N	55.697091999999998	город Москва, ЗАО, район Раменки, Мичуринский просп, дом 15, корп.1	Россия, Москва, Мичуринский проспект, 15к1	0101000020E61000007E1D386744C14240D026874F3AD94B40
57052	1	\N	\N	1	3529	\N	55.701819999999998	город Москва, ЗАО, район Раменки, Мичуринский просп, дом 9Б	Россия, Москва, Мичуринский проспект, 9б	0101000020E6100000691D554D10C14240E0D6DD3CD5D94B40
57051	1	\N	\N	1	3529	\N	55.702494999999999	город Москва, ЗАО, район Раменки, Мичуринский просп, дом 5, корп. 1	Россия, Москва, Мичуринский проспект, 5к1	0101000020E6100000DFA9807B9EC14240404D2D5BEBD94B40
55654	1	\N	\N	1	4200	\N	55.838540999999999	город Москва, САО, район Коптево, Михалковская ул, дом 14	Россия, Москва, Михалковская улица, 14	0101000020E610000042226DE34FC4424075ADBD4F55EB4B40
55649	1	\N	\N	1	13064	\N	55.838459999999998	город Москва, САО, район Коптево, Михалковская ул, дом 13А		0101000020E61000005B40683D7CC34240888043A852EB4B40
55655	1	\N	\N	1	13000	\N	55.836888000000002	город Москва, САО, район Коптево, Михалковская ул, дом 3		0101000020E6100000AD69DE718AC442401A355F251FEB4B40
56375	1	\N	\N	1	12542	\N	55.725239999999999	город Москва, ЮВАО, Рязанский район, Михайлова ул, дом 24, корп. 2		0101000020E61000006D57E88365E2424022E010AAD4DC4B40
57160	1	\N	\N	1	12925	\N	55.849918000000002	город Москва, СЗАО, район Митино, Митинская ул, дом 46, корп. 2		0101000020E6100000EC8A19E1EDAD42401024EF1CCAEC4B40
57161	1	\N	\N	1	12829	\N	55.850737000000002	город Москва, СЗАО, район Митино, Митинская ул, дом 48, корп. 2		0101000020E610000040C23060C9AD4240A33F34F3E4EC4B40
57153	1	\N	\N	1	12829	\N	55.849944000000001	город Москва, СЗАО, район Митино, Митинская ул, дом 45, корп. 3		0101000020E6100000BDE0D39CBCAC424039B709F7CAEC4B40
55673	1	\N	\N	1	4523	\N	55.796394999999997	город Москва, САО, Савеловский район, Мирской пер, дом 5, стр. 2	Россия, Москва, Мирской переулок, 5к2	0101000020E6100000C66E9F5566C8424055D97745F0E54B40
55955	1	\N	\N	1	12691	\N	55.816251999999999	город Москва, ВАО, район Богородское, Миллионная ул, дом 5/7		0101000020E6100000B66801DA56D94240B5A50EF27AE84B40
57374	1	\N	\N	1	12627	\N	55.826994385039299	город Москва, СВАО, Бутырский район, Милашенкова ул., 10В, , СОШ № 968	Россия, Москва, улица Милашенкова, 10б	0101000020E61000009885764EB3CA42407EFE7BF0DAE94B40
55815	1	\N	\N	1	12627	\N	55.823236999999999	город Москва, СВАО, Бутырский район, Милашенкова ул, дом 9Б		0101000020E6100000DD0A613596CA4240B7ED7BD45FE94B40
55812	1	\N	\N	1	12627	\N	55.826619999999998	город Москва, СВАО, Бутырский район, Милашенкова ул, дом 10В		0101000020E6100000560BEC3191CA4240191C25AFCEE94B40
55777	1	\N	\N	1	13045	\N	55.870238000000001	город Москва, СВАО, Бабушкинский район, Менжинского ул, дом 30		0101000020E610000065170CAEB9D5424044DE72F563EF4B40
56449	1	\N	\N	1	5861	\N	55.581927	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Медынская ул., дом 9А, адрес УИК: Харьковская ул, дом 1, корп. 3		0101000020E61000000FD1E80E62D3424067D47C957CCA4B40
56445	1	\N	\N	1	12944	\N	55.593257999999999	город Москва, ЮАО, район Бирюлево Западное, Медынская ул, дом 6А		0101000020E6100000FF21FDF675D24240910BCEE0EFCB4B40
56448	1	\N	\N	1	13019	\N	55.583373000000002	город Москва, ЮАО, район Бирюлево Западное, Медынская ул, дом 7А		0101000020E6100000D811876C20D34240492F6AF7ABCA4B40
57066	1	\N	\N	1	12795	\N	55.662739999999999	город Москва, ЗАО, район Солнцево, Матросова ул, дом 31		0101000020E610000094FB1D8A02B5424022E010AAD4D44B40
57020	1	\N	\N	1	4823	\N	55.705624999999998	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Матвеевская ул., дом 34, корп. 2, адрес УИК: Нежинская ул, дом 21	Россия, Москва, Матвеевская улица, 34к2	0101000020E61000005A9E077767BB4240B81E85EB51DA4B40
57019	1	\N	\N	1	13175	\N	55.705624999999998	город Москва, ЗАО, район Очаково-Матвеевское, Матвеевская ул, дом 34, корп. 2		0101000020E61000005A9E077767BB4240B81E85EB51DA4B40
57018	1	\N	\N	1	13175	\N	55.704605000000001	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Матвеевская ул., дом 20, корп. 2, адрес УИК: Нежинская ул, дом 21		0101000020E61000007AC6BE64E3BB42408ECC237F30DA4B40
56307	1	\N	\N	1	13241	\N	55.671722000000003	город Москва, ЮВАО, район Люблино, Марьинский парк ул, дом 43		0101000020E6100000D3122BA391E542407A008BFCFAD54B40
56253	1	\N	\N	1	12566	\N	55.697853829684199	город Москва, ЮВАО, район Кузьминки, Чуйкова маршала ул, дом 26, корп. 1		0101000020E6100000FB3F87F9F2E04240FFB0A54753D94B40
57241	1	\N	\N	1	12684	\N	55.786307999999998	город Москва, СЗАО, район Хорошево-Мневники, Тухачевского маршала ул, дом 46		0101000020E6100000CFF753E3A5BB4240A54A94BDA5E44B40
57237	1	\N	\N	1	12684	\N	55.783630000000002	город Москва, СЗАО, район Хорошево-Мневники, Тухачевского маршала ул, дом 20		0101000020E61000000FEECEDA6DBD42400E15E3FC4DE44B40
57233	1	\N	\N	1	12684	\N	55.780441146517397	город Москва, СЗАО, район Хорошево-Мневники, Тухачевского маршала ул, дом 17, корп. 5	Россия, Москва, улица Маршала Тухачевского, 17к3	0101000020E61000007DB3CD8DE9BD424091BA9D7DE5E34B40
56963	1	\N	\N	1	12924	\N	55.747343000000001	город Москва, ЗАО, район Кунцево, Тимошенко Маршала ул, дом 36, корп. 2		0101000020E610000082C98D226BB3424080F277EFA8DF4B40
56854	1	\N	\N	1	12964	\N	55.502406000000001	город Москва, ЮЗАО, район Южное Бутово, Маршала Савицкого ул, дом 26, корп. 4		0101000020E6100000577A6D3656CC424037A8FDD64EC04B40
56851	1	\N	\N	1	12964	\N	55.503058000000003	город Москва, ЮЗАО, район Южное Бутово, Маршала Савицкого ул, дом 6, корп. 4		0101000020E6100000F46E2C280CCA4240DFFE5C3464C04B40
55428	1	\N	\N	1	12463	\N	55.759010000000004	город Москва, ЦАО, Пресненский район, Бронная М. ул, дом 7		0101000020E6100000B3CF639467CC424022AB5B3D27E14B40
57262	1	\N	\N	1	12666	\N	55.799100916357098	город Москва, СЗАО, район Щукино, Рыбалко маршала ул, дом 14, корп. 1	Россия, Москва, улица Маршала Рыбалко, 14	0101000020E610000013BBB6B75BBE4240B7990AF148E64B40
56230	1	\N	\N	1	12845	\N	55.682589999999998	город Москва, ЮВАО, район Выхино-Жулебино, Полубоярова маршала ул, дом 22		0101000020E61000002578431A15EE4240CF49EF1B5FD74B40
56226	1	\N	\N	1	12845	\N	55.686461999999999	город Москва, ЮВАО, район Выхино-Жулебино, Полубоярова маршала ул, дом 12		0101000020E6100000F9F6AE415FEE42402FF99FFCDDD74B40
57267	1	\N	\N	1	12894	\N	55.803018999999999	город Москва,СЗАО, район Щукино, Новикова маршала ул, дом 13		0101000020E6100000A80183A44FBB424087889B53C9E64B40
57211	1	\N	\N	1	13020	\N	55.807319	город Москва, СЗАО, район Строгино, Катукова маршала ул, дом 12, корп. 3		0101000020E61000004165FCFB8CB342403F389F3A56E74B40
57208	1	\N	\N	1	13020	\N	55.807389999999998	город Москва, СЗАО, район Строгино, Катукова маршала ул, дом 21, корп. 2		0101000020E61000008BDD3EABCCB44240088F368E58E74B40
56570	1	\N	\N	1	12473	\N	55.6234463942993	город Москва, ЮАО, район Орехово-Борисово Северное, Захарова маршала ул, дом 8, корп. 1		0101000020E6100000643A747ADED9424038691A14CDCF4B40
56569	1	\N	\N	1	12473	\N	55.619244000000002	город Москва, ЮАО, район Орехово-Борисово Северное, Захарова маршала ул, дом 25, корп. 2	Россия, Москва, улица Маршала Захарова, 25к2	0101000020E61000008D0E48C2BED94240431F2C6343CF4B40
56316	1	\N	\N	1	13192	\N	55.648626	город Москва, ЮВАО, район Марьино, Голованова маршала  ул, дом 9		0101000020E61000004DBB9866BADD4240EBAA402D06D34B40
57268	1	\N	\N	1	12971	\N	55.805205295944397	адрес помещения для голосования: город Москва, СЗАО, район Щукино, Василевского маршала ул., дом 11, корп. 2, адрес УИК: Новикова маршала ул, дом 13	Россия, Москва, улица Маршала Василевского, 11к2	0101000020E6100000C5591135D1BB4240B0C91AF510E74B40
57266	1	\N	\N	1	12971	\N	55.805062999999997	город Москва, СЗАО, район Щукино, Василевского маршала ул, дом 9, корп. 1		0101000020E61000008BDF14562ABC42401D1CEC4D0CE74B40
57263	1	\N	\N	1	12971	\N	55.802356000000003	город Москва, СЗАО, район Щукино, Василевского маршала ул, дом 3, корп. 2		0101000020E610000020D1048A58BC4240ECDFF599B3E64B40
95182	1	\N	\N	1	12793	\N	55.790246000000003	город Москва, СЗАО, район Щукино, ул.Маршала Бирюзова, д.5, ДМТ «Домисолька"		0101000020E6100000B6679604A8BF4240BDE5EAC726E54B40
57258	1	\N	\N	1	12793	\N	55.791542	город Москва, СЗАО, район Щукино, Бирюзова маршала ул, дом 6		0101000020E6100000D53F8864C8BF424089B48D3F51E54B40
57257	1	\N	\N	1	12793	\N	55.790246000000003	город Москва, СЗАО, район Щукино, Бирюзова маршала ул, дом 5		0101000020E6100000B6679604A8BF4240BDE5EAC726E54B40
55466	1	\N	\N	1	1698	\N	55.738439	город Москва, ЦАО, Таганский район, Марксистский пер, дом 3	Россия, Москва, Марксистский переулок, 3	0101000020E61000009A0986730DD54240A48B4D2B85DE4B40
55464	1	\N	\N	1	1676	\N	55.736265000000003	город Москва, ЦАО, Таганский район, Марксистская ул, дом 9, корп. 2	Россия, Москва, Марксистская улица, 9к2	0101000020E610000077BD344580D54240401878EE3DDE4B40
95177	1	\N	\N	1	74862	\N	55.734805000000001	город Москва, ЦАО, Таганский район, ул.Марксистская, 9 (к.2) ГОУ СОШ №622		0101000020E61000002750C42286D54240F9F719170EDE4B40
56299	1	\N	\N	1	13184	\N	55.674965999999998	город Москва, ЮВАО, район Люблино, Мариупольская ул, дом 3		0101000020E6100000AFEDED96E4DE4240BAF42F4965D64B40
56769	1	\N	\N	1	12695	\N	55.678077000000002	Адрес помещения для голосования: город Москва, ЮЗАО, Ломоносовский район, Ульяновой Марии ул., дом 5, адрес УИК: Ленинский просп, дом 88, корп. 2		0101000020E6100000994A3FE1ECC24240BC95253ACBD64B40
55411	1	\N	\N	1	854	\N	55.770167999999998	город Москва, ЦАО, Мещанский район, Сухаревский М. пер, дом 6	Россия, Москва, Малый Сухаревский переулок, 6	0101000020E6100000B894F3C5DECF42407E3672DD94E24B40
55520	1	\N	\N	1	2451	\N	55.731059000000002	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Саввинский М. пер., дом 8а, адрес УИК: Пироговская Б. ул, дом 37/43	Россия, Москва, Малый Саввинский переулок, 8	0101000020E6100000D9EBDD1FEFC742402639605793DD4B40
55480	1	\N	\N	1	1889	\N	55.765416999999999	город Москва, ЦАО, Тверской район, Палашевский М. пер, дом 3	Россия, Москва, Малый Палашевский переулок, 3	0101000020E6100000967A1684F2CC4240B6662B2FF9E14B40
55541	1	\N	\N	1	2778	\N	55.809731999999997	Адрес помещения для голосования: город Москва, САО, район Аэропорт, Коптевский м. пр., дом 3/5, адрес УИК: Коптевский м. пр, дом 4/6		0101000020E610000097361C9606C442402843554CA5E74B40
55425	1	\N	\N	1	1086	\N	55.756442	город Москва, ЦАО, Пресненский район, Кисловский М. пер, дом 12/8	Россия, Москва, Малый Кисловский переулок, 12/8с1	0101000020E61000006B10E6762FCD424011A96917D3E04B40
55754	1	\N	\N	1	13195	\N	55.813875000000003	город Москва, СВАО, Алексеевский район, Маломосковская ул, дом 7		0101000020E61000007F30F0DC7BD242401904560E2DE84B40
56194	1	\N	\N	1	12597	\N	55.787770999999999	город Москва, ВАО, район Сокольники, Маленковская ул, дом 17/19		0101000020E610000043E1B37570D642405DDE1CAED5E44B40
56713	1	\N	\N	1	12979	\N	55.654361000000002	город Москва, ЮЗАО, район Зюзино, Юшуньская М. ул, дом 4		0101000020E6100000B5A679C729CC42409163EB19C2D34B40
56712	1	\N	\N	1	12979	\N	55.654361000000002	Адрес помещения для голосования: город Москва, ЮЗАО, район Зюзино, Юшуньская М. ул., дом 4, адрес УИК: Одесская ул, дом 27/14		0101000020E6100000B5A679C729CC42409163EB19C2D34B40
57123	1	\N	\N	1	12625	\N	55.736432000000001	город Москва, ЗАО, район Фили-Давыдково, Филевская М. ул, дом 26		0101000020E6100000A016838769BB42402BDD5D6743DE4B40
57111	1	\N	\N	1	13150	\N	55.734003999999999	город Москва, ЗАО, район Фили-Давыдково, Филевская М. ул, дом 50		0101000020E61000001FBC7669C3B942400C91D3D7F3DD4B40
56467	1	\N	\N	1	12526	\N	55.708883040866297	город Москва, ЮАО, Даниловский район, Тульская М. ул, дом 15А	Россия, Москва, Малая Тульская улица, 15	0101000020E6100000776682E15CCF42405ED89AADBCDA4B40
9955	6	58	339	4107	42842	\N	55.222425999999999	село Кулуево, Чапаева, 19		0101000020E61000009D47C5FF1D4D4E40DAE38574789C4B40
55898	1	\N	\N	1	3589	\N	55.828328999999997	город Москва, СВАО, район Ростокино, Малахитовая ул, дом 18	Россия, Москва, Малахитовая улица, 18	0101000020E610000069E1B20A9BD5424008AA46AF06EA4B40
55897	1	\N	\N	1	3589	\N	55.831423000000001	город Москва, СВАО, район Ростокино, Малахитовая ул, дом 15	Россия, Москва, Малахитовая улица, 15	0101000020E610000034D6FECEF6D442403412A1116CEA4B40
56166	1	\N	\N	1	12327	\N	55.782727370033001	город Москва, ВАО, район Соколиная гора, Мажоров пер, дом 8	Россия, Москва, Мажоров переулок, 8	0101000020E61000008E95986725DB42401D59F96530E44B40
56041	1	\N	\N	1	12936	\N	55.775753000000002	город Москва, ВАО, район Ивановское, Магнитогорская ул, дом 15		0101000020E61000005682C5E1CCE942400F63D2DF4BE34B40
55369	1	\N	\N	1	231	\N	55.758909000000003	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Лялин пер., дом 12, адрес УИК: Покровка ул, дом 20	Россия, Москва, Лялин переулок, 12с1	0101000020E6100000A2B2614D65D34240EED11BEE23E14B40
55402	1	\N	\N	1	728	\N	55.724210999999997	город Москва, ЦАО, район Замоскворечье, Люсиновская ул, дом 31	Россия, Москва, Люсиновская улица, 31с1	0101000020E610000062307F85CCCF4240A43330F2B2DC4B40
56324	1	\N	\N	1	2912	\N	55.650353000000003	город Москва, ЮВАО, район Марьино, Люблинская ул, дом 167	Россия, Москва, Люблинская улица, 167	0101000020E610000066118AADA0DF424081ED60C43ED34B40
56321	1	\N	\N	1	2912	\N	55.646878000000001	город Москва, ЮВАО, район Марьино, Люблинская ул, дом 173	Россия, Москва, Люблинская улица, 173	0101000020E61000006551D845D1DF42403E40F7E5CCD24B40
56401	1	\N	\N	1	12553	\N	55.694571000000003	город Москва, ЮВАО, район Текстильщики, Люблинская ул, дом 45		0101000020E6100000E00F3FFF3DDE424001E0D8B3E7D84B40
56389	1	\N	\N	1	12553	\N	55.710864000000001	город Москва, ЮВАО, район Текстильщики, Люблинская ул, дом 11		0101000020E610000028F224E99ADD4240AEF36F97FDDA4B40
56284	1	\N	\N	1	12553	\N	55.675523531787299	город Москва, ЮВАО, район Люблино, Люблинская ул, дом 56/2	Россия, Москва, Люблинская улица, 56/2с1	0101000020E6100000B9A981E673DE4240E1D4079277D64B40
56209	1	\N	\N	1	12553	\N	55.673377000000002	город Москва, ЮВАО, район Люблино, Люблинская ул, дом 125А		0101000020E610000062A1D634EFDE42407670B03731D64B40
56083	1	\N	\N	1	12441	\N	55.720692	город Москва, ВАО, район Косино - Ухтомский, Лухмановская ул, дом 13Б	Россия, Москва, Лухмановская улица, 13б	0101000020E61000001920D1048AF24240923EADA23FDC4B40
56081	1	\N	\N	1	12441	\N	55.720757999999996	город Москва, ВАО, район Косино - Ухтомский, Лухмановская ул, дом 26А	Россия, Москва, Лухмановская улица, 26а	0101000020E610000001A260C614F44240492A53CC41DC4B40
56080	1	\N	\N	1	12441	\N	55.715995999999997	город Москва, ВАО, район Косино - Ухтомский, Лухмановская ул, дом 10	Россия, Москва, Лухмановская улица, 10а	0101000020E61000006729594E42F342408D08C6C1A5DB4B40
57012	1	\N	\N	1	12759	\N	55.648580000000003	город Москва, ЗАО, район Ново-Переделкино, Лукинская ул, дом 12, корп. 1		0101000020E6100000CBF3E0EEACAB42407B6B60AB04D34B40
56996	1	\N	\N	1	12759	\N	55.643022999999999	город Москва, ЗАО, район Ново-Переделкино, Лукинская ул, дом 9, корп. 1		0101000020E61000009EEFA7C64BAB4240B4C9E1934ED24B40
56988	1	\N	\N	1	12759	\N	55.646447000000002	город Москва, ЗАО, район Ново-Переделкино, Лукинская ул, дом 1, корп. 1		0101000020E6100000E607AEF204AC424075CC79C6BED24B40
56090	1	\N	\N	1	12554	\N	55.825789999999998	город Москва, ВАО, район Метрогородок, Лосиноостровская ул, дом 24, корп. 1		0101000020E61000007619FED30DDC424092AE997CB3E94B40
55954	1	\N	\N	1	12669	\N	55.8774188611415	город Москва, СВАО, Ярославский район, Лосевская ул, дом 9, корп. 1	Россия, Москва, Лосевская улица, 9	0101000020E610000056D4601A86DB4240CCF10A444FF04B40
56276	1	\N	\N	1	3785	\N	55.767310999999999	город Москва, ЮВАО, район Лефортово, Лонгиновская ул, дом 6	Россия, Москва, Лонгиновская улица, 6	0101000020E6100000705F07CE19DB4240376E313F37E24B40
57065	1	\N	\N	1	356	\N	55.706817000000001	город Москва, ЗАО, район Раменки, Ломоносовский просп, дом 31, корп. 2	Россия, Москва, Ломоносовский проспект, 31к2	0101000020E6100000EA58A5F44CC14240E0A0BDFA78DA4B40
56700	1	\N	\N	1	356	\N	55.688279000000001	город Москва, ЮЗАО, Гагаринский район, Ломоносовский просп, дом 4, корп. 4	Россия, Москва, Ломоносовский проспект, 4к4	0101000020E6100000E5B4A7E49CC6424005C3B98619D84B40
56699	1	\N	\N	1	356	\N	55.683979999999998	город Москва, ЮЗАО, Гагаринский район, Ломоносовский просп, дом 3а	Россия, Москва, Ломоносовский проспект, 3а	0101000020E61000003D601E32E5C542401D8F19A88CD74B40
56698	1	\N	\N	1	356	\N	55.688192000000001	город Москва, ЮЗАО, Гагаринский район, Ломоносовский просп, дом 13	Россия, Москва, Ломоносовский проспект, 13	0101000020E610000080457EFD10C5424036AFEAAC16D84B40
56697	1	\N	\N	1	356	\N	55.689162000000003	город Москва, ЮЗАО, Гагаринский район, Ломоносовский просп, дом 21	Россия, Москва, Ломоносовский проспект, 21	0101000020E610000058552FBFD3C44240AFD2DD7536D84B40
56696	1	\N	\N	1	356	\N	55.691825999999999	город Москва, ЮЗАО, Гагаринский район, Ломоносовский просп, дом 18	Россия, Москва, Ломоносовский проспект, 18	0101000020E61000009C19FD6838C54240E1421EC18DD84B40
56695	1	\N	\N	1	356	\N	55.691552000000001	город Москва, ЮЗАО, Гагаринский район, Ломоносовский просп, дом 12	Россия, Москва, Ломоносовский проспект, 12	0101000020E61000002579AEEFC3C54240E0BDA3C684D84B40
57394	1	\N	\N	1	12520	\N	55.837823	город Москва, СЗАО, район Южное Тушино, ул. Лодочная, 3, кв.1		0101000020E6100000999D45EF54B84240166BB8C83DEB4B40
57036	1	\N	\N	1	12774	\N	55.677163999999998	город Москва, ЗАО, район Проспект Вернадского, Лобачевского ул, дом 66Б		0101000020E61000000E863AAC70BF4240A703594FADD64B40
57034	1	\N	\N	1	12774	\N	55.672756999999997	Адрес помещения для голосования: город Москва, ЗАО, район Проспект Вернадского, Лобачевского ул, дом 54, Адрес УИК: Вернадского просп, дом 62А		0101000020E61000001327F73B14BF4240D993C0E61CD64B40
57031	1	\N	\N	1	12774	\N	55.680722000000003	город Москва, ЗАО, район Проспект Вернадского, Лобачевского ул, дом 92		0101000020E6100000C1FD800706BE424078D503E621D74B40
57030	1	\N	\N	1	12774	\N	55.675758000000002	Адрес помещения для голосования: город Москва, ЗАО, район Проспект Вернадского, Лобачевского ул., дом 90, Адрес УИК: Вернадского просп, дом 62А		0101000020E6100000E6E95C514ABE42405401F73C7FD64B40
56902	1	\N	\N	1	2905	\N	55.606065000000001	город Москва, ЮЗАО, район Ясенево, Литовский бульв, дом 17, корп. 4	Россия, Москва, Литовский бульвар, 17к4	0101000020E610000008910C39B6C642400820B58993CD4B40
56901	1	\N	\N	1	2905	\N	55.606304000000002	город Москва, ЮЗАО, район Ясенево, Литовский бульв, дом 17, корп. 3	Россия, Москва, Литовский бульвар, 17к3	0101000020E61000007D5A457F68C642408DB7955E9BCD4B40
56900	1	\N	\N	1	2905	\N	55.607117000000002	город Москва, ЮЗАО, район Ясенево, Литовский бульв, дом 44, корп. 2	Россия, Москва, Литовский бульвар, 44к2	0101000020E6100000AE2CD15966C542403EEC8502B6CD4B40
56899	1	\N	\N	1	2905	\N	55.607967000000002	город Москва, ЮЗАО, район Ясенево, Литовский бульв, дом 42, корп. 2	Россия, Москва, Литовский бульвар, 42к2	0101000020E6100000056EDDCD53C542400C06D7DCD1CD4B40
56897	1	\N	\N	1	2905	\N	55.612594000000001	город Москва, ЮЗАО, район Ясенево, Литовский бульв, дом 11, корп. 6	Россия, Москва, Литовский бульвар, 11к6	0101000020E6100000226FB9FAB1C54240E8DCED7A69CE4B40
56893	1	\N	\N	1	2905	\N	55.614953	город Москва, ЮЗАО, район Ясенево, Литовский бульв, дом 3, корп. 3	Россия, Москва, Литовский бульвар, 3к3	0101000020E6100000DCD7817346C44240DEC9A7C7B6CE4B40
56892	1	\N	\N	1	2905	\N	55.610050999999999	город Москва, ЮЗАО, район Ясенево, Литовский бульв, дом 6, корп. 2	Россия, Москва, Литовский бульвар, 6к2	0101000020E6100000AAB9DC60A8C3424030F2B22616CE4B40
55705	1	\N	\N	1	4879	\N	55.835599000000002	город Москва, САО, Тимирязевский район, Лиственничная аллея, дом 12	Россия, Москва, Лиственничная аллея, 12	0101000020E6100000475A2A6F47C8424000C974E8F4EA4B40
56441	1	\N	\N	1	13017	\N	55.581062000000003	город Москва, ЮАО, район Бирюлево Восточное, Липецкая ул, дом 15, корп. 2		0101000020E6100000680932022AD842406479573D60CA4B40
56440	1	\N	\N	1	13017	\N	55.581062000000003	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Восточное, Липецкая ул., дом 15, корп. 2, адрес УИК: Липецкая ул, дом 17, корп. 1		0101000020E6100000680932022AD842406479573D60CA4B40
56437	1	\N	\N	1	13017	\N	55.582523000000002	город Москва, ЮАО, район Бирюлево Восточное, Липецкая ул, дом 44		0101000020E610000065E08096AED642407B15191D90CA4B40
55709	1	\N	\N	1	4920	\N	55.842236	город Москва, САО, Тимирязевский район, Линейный пр, дом 11	Россия, Москва, Линейный проезд, 11	0101000020E610000002D8800871C94240C6C1A563CEEB4B40
55708	1	\N	\N	1	4920	\N	55.842078999999998	город Москва, САО, Тимирязевский район, Линейный пр, дом 9	Россия, Москва, Линейный проезд, 9	0101000020E6100000BA32A83638C94240FED2A23EC9EB4B40
56170	1	\N	\N	1	12368	\N	55.789790000000004	город Москва, ВАО, район Соколиная гора, Лечебная ул, дом 20		0101000020E610000059897956D2DE42409B5AB6D617E54B40
55378	1	\N	\N	1	380	\N	55.769722000000002	город Москва, ЦАО, Басманный район, Лефортовский пер, дом 8/10	Россия, Москва, Лефортовский переулок, 8с7	0101000020E6100000FF959526A5D642408081204086E24B40
56269	1	\N	\N	1	13023	\N	55.760378000000003	город Москва, ЮВАО, район Лефортово, Лефортовский вал ул, дом 14		0101000020E6100000527E52EDD3D94240884CF91054E14B40
55475	1	\N	\N	1	12694	\N	55.778694000000002	город Москва, ЦАО, Тверской район, Лесная ул, дом 18	Россия, Москва, Тверской район, Лесная улица, 18/5с3	0101000020E6100000460BD0B69ACB4240B4CBB73EACE34B40
55804	1	\N	\N	1	12731	\N	55.899450999999999	город Москва, СВАО, район Бибирево, Лескова ул, дом 3, корп. 3		0101000020E6100000234C512E8DCB424060ADDA3521F34B40
55803	1	\N	\N	1	12731	\N	55.899223999999997	город Москва, СВАО, район Бибирево, Лескова ул, дом 7		0101000020E6100000C79C67EC4BCC42409FE3A3C519F34B40
55800	1	\N	\N	1	12731	\N	55.896473999999998	город Москва, СВАО, район Бибирево, Лескова ул, дом 8А		0101000020E6100000E1606F6248CC42406EDBF7A8BFF24B40
55787	1	\N	\N	1	12731	\N	55.893172	город Москва, СВАО, район Бибирево, Лескова ул, дом 25А		0101000020E6100000FDD98F1491CF4240F9D9C87553F24B40
55786	1	\N	\N	1	12731	\N	55.893172	Адрес помещения для голосования: город Москва, СВАО, район Бибирево, Лескова ул., дом 25А, адрес УИК: Белозерская ул, дом 13		0101000020E6100000FDD98F1491CF4240F9D9C87553F24B40
56224	1	\N	\N	1	3113	\N	55.697198999999998	город Москва, ЮВАО, район Выхино-Жулебино, Лермонтовский просп, дом 14, корп. 2	Россия, Москва, Лермонтовский проспект, 14к2	0101000020E61000001900AAB871ED4240E6E61BD13DD94B40
55776	1	\N	\N	1	12900	\N	55.868273000000002	город Москва, СВАО, Бабушкинский район, Ленская ул, дом 24		0101000020E61000007EE5417A8AD44240FA7FD59123EF4B40
55775	1	\N	\N	1	12900	\N	55.868273000000002	Адрес помещения для голосования: город Москва, СВАО, Бабушкинский район, Ленская ул., дом 24, адрес УИК: Ленская ул, дом 23		0101000020E61000007EE5417A8AD44240FA7FD59123EF4B40
55772	1	\N	\N	1	12900	\N	55.866394	город Москва, СВАО, Бабушкинский район, Ленская ул, дом 6		0101000020E61000005454FD4AE7D54240AEB9A3FFE5EE4B40
57095	1	\N	\N	1	234	\N	55.651181000000001	город Москва, ЗАО, район Тропарево-Никулино, Ленинский просп, дом 158	Россия, Москва, Ленинский проспект, 158	0101000020E610000039EE940ED6BD4240676325E659D34B40
57091	1	\N	\N	1	234	\N	55.656925000000001	город Москва, ЗАО, район Тропарево-Никулино, Ленинский просп, дом 146	Россия, Москва, Ленинский проспект, 146	0101000020E6100000B153AC1A84BF424060764F1E16D44B40
57040	1	\N	\N	1	234	\N	55.666908999999997	город Москва, ЗАО, район Проспект Вернадского, Ленинский просп, дом 132	Россия, Москва, Ленинский проспект, 132	0101000020E61000007235B22B2DC142403B342C465DD54B40
56827	1	\N	\N	1	234	\N	55.643988	Адрес помещения для голосования: город Москва, ЮЗАО, район Теплый Стан, Ленинский просп., дом 125, корп. 4, адрес УИК: Ленинский просп, дом 123, корп. 2	Россия, Москва, Ленинский проспект, 125к4	0101000020E6100000834D9D47C5BD42401B82E3326ED24B40
9960	6	58	339	4107	42979	\N	55.222425999999999	село Кулуево, Салавата Юлаева, 31		0101000020E61000009D47C5FF1D4D4E40DAE38574789C4B40
56826	1	\N	\N	1	234	\N	55.643988	город Москва, ЮЗАО, район Теплый Стан, Ленинский просп, дом 125, корп. 4	Россия, Москва, Ленинский проспект, 125к4	0101000020E6100000834D9D47C5BD42401B82E3326ED24B40
56824	1	\N	\N	1	234	\N	55.642399383390703	Адрес помещения для голосования: город Москва, ЮЗАО, район Теплый Стан, Ленинский просп., дом 131, корп. 4, адрес УИК: Ленинский просп, дом 129, корп. 1	Россия, Москва, Ленинский проспект, 131к4	0101000020E61000004A7EC4AF58BD4240D6FD63213AD24B40
56795	1	\N	\N	1	234	\N	55.651012999999999	город Москва, ЮЗАО, Обручевский район, Ленинский просп, дом 119, корп. 1	Россия, Москва, Ленинский проспект, 119к1	0101000020E610000027A435069DBE4240AB22DC6454D34B40
56786	1	\N	\N	1	234	\N	55.671360999999997	город Москва, ЮЗАО, Обручевский район, Ленинский просп, дом 97, корп. 2	Россия, Москва, Ленинский проспект, 97к2	0101000020E6100000DD088B8A38C34240A9674128EFD54B40
56785	1	\N	\N	1	234	\N	55.67127	Адрес помещения для голосования: город Москва, ЮЗАО, Обручевский район, Ленинский просп., дом 97, корп. 1, адрес УИК: Новаторов ул, дом 16, корп. 2		0101000020E61000001555BFD2F9C242409964E42CECD54B40
56778	1	\N	\N	1	234	\N	55.674697000000002	Адрес места голосования: город Москва, ЮЗАО, Ломоносовский район, Ленинский просп., дом 93Б, адрес УИК: Ленинский просп, дом 93	Россия, Москва, Ленинский проспект, 93б	0101000020E6100000635E471CB2C34240CBDAA6785CD64B40
56777	1	\N	\N	1	234	\N	55.674697000000002	город Москва, ЮЗАО, Ломоносовский район, Ленинский просп, дом 93Б	Россия, Москва, Ленинский проспект, 93б	0101000020E6100000635E471CB2C34240CBDAA6785CD64B40
56774	1	\N	\N	1	234	\N	55.680087	город Москва, ЮЗАО, Ломоносовский район, Ленинский просп, дом 83А	Россия, Москва, Ленинский проспект, 83а	0101000020E6100000130A117008C54240A6B73F170DD74B40
56771	1	\N	\N	1	234	\N	55.683534000000002	город Москва, ЮЗАО, Ломоносовский район, Ленинский просп, дом 76А	Россия, Москва, Ленинский проспект, 76а	0101000020E61000004A46CEC29EC442401FDAC70A7ED74B40
56704	1	\N	\N	1	234	\N	55.704737000000002	город Москва, ЮЗАО, Гагаринский район, Ленинский просп, дом 43а	Россия, Москва, Ленинский проспект, 43а	0101000020E6100000EB73B515FBC94240FDA36FD234DA4B40
56702	1	\N	\N	1	234	\N	55.692044000000003	Адрес помещения для голосования: город Москва, ЮЗАО, Гагаринский район, Ленинский просп., дом 65, адрес УИК: Ломоносовский просп, дом 4, корп. 4	Россия, Москва, Ленинский проспект, 65к1	0101000020E6100000DF196D5512C742404FB2D5E594D84B40
56690	1	\N	\N	1	234	\N	55.704225000000001	город Москва, ЮЗАО, Гагаринский район, Ленинский просп, дом 42, корп. 5	Россия, Москва, Ленинский проспект, 42к5	0101000020E6100000B1C403CAA6C842404703780B24DA4B40
56689	1	\N	\N	1	234	\N	55.710205000000002	город Москва, ЮЗАО, Гагаринский район, Ленинский просп, дом 32а	Россия, Москва, Ленинский проспект, 32а	0101000020E610000044BFB67EFAC94240543A58FFE7DA4B40
56688	1	\N	\N	1	234	\N	55.706741000000001	город Москва, ЮЗАО, Гагаринский район, Ленинский просп, дом 34а	Россия, Москва, Ленинский проспект, 34а	0101000020E610000061376C5B94C9424005DF347D76DA4B40
56687	1	\N	\N	1	234	\N	55.706533	город Москва, ЮЗАО, Гагаринский район, Ленинский просп, дом 39а	Россия, Москва, Ленинский проспект, 39а	0101000020E6100000FCE25295B6CA4240BB4560AC6FDA4B40
56484	1	\N	\N	1	234	\N	55.718044999999996	город Москва, ЮАО, Донской район, Ленинский просп, дом 18А	Россия, Москва, Ленинский проспект, 18а	0101000020E61000003A5CAB3DECCB4240350708E6E8DB4B40
55528	1	\N	\N	1	234	\N	55.721933999999997	город Москва, ЦАО, район Якиманка, Ленинский просп, дом 13А	Россия, Москва, Ленинский проспект, 13а	0101000020E6100000C1745AB741CD42406BEF535568DC4B40
57386	1	\N	\N	1	12571	\N	55.696108000000002	город Москва, ЗАО, район Раменки, Ленинские горы, 1, к. Ж, комн. 130, Главное здание МГУ		0101000020E61000000B96EA025EC44240F33D23111AD94B40
55670	1	\N	\N	1	12454	\N	55.923538999999998	Адрес помещения для голосования: город Москва, САО, Молжаниновский район, Ленинградское шоссе, дом 95, адрес УИК: Новоселки 4-я ул, дом 2		0101000020E6100000BFD7101C97B142404FCAA48636F64B40
55661	1	\N	\N	1	12454	\N	55.856141289019	Адрес помещения для голосования: город Москва, САО, Левобережный район, Ленинградское шоссе, дом 94А, адрес УИК: Фестивальная ул, дом 9		0101000020E610000059A7CAF78CBC4240E3E13D0796ED4B40
55660	1	\N	\N	1	12454	\N	55.857978000000003	город Москва, САО, Левобережный район, Ленинградское шоссе, дом 59	Россия, Москва, Левобережный район, Ленинградское шоссе, 59	0101000020E6100000E8BB5B59A2BB424000581D39D2ED4B40
55579	1	\N	\N	1	12454	\N	55.829101999999999	Адрес помещения для голосования: город Москва, САО, Войковский район, Ленинградское шоссе, дом 30, адрес УИК: Макарова адмирала ул, дом 37, корп. 2		0101000020E6100000950C0055DCBE42402B86AB0320EA4B40
55577	1	\N	\N	1	12454	\N	55.837803000000001	Адрес помещения для голосования: город Москва, САО, Войковский район, Ленинградское шоссе, дом 54, адрес УИК: Макарова адмирала ул, дом 37, корп. 2		0101000020E61000003BFE0B0401BE4240CFBEF2203DEB4B40
55574	1	\N	\N	1	12454	\N	55.829101999999999	город Москва, САО, Войковский район, Ленинградское шоссе, дом 30		0101000020E6100000950C0055DCBE42402B86AB0320EA4B40
55570	1	\N	\N	1	12454	\N	55.818230989583903	город Москва, САО, Войковский район, Ленинградское шоссе, дом 13А	Россия, Москва, Левобережный район, Ленинградское шоссе, 13а	0101000020E610000027840EBA84BF424064C91CCBBBE84B40
55547	1	\N	\N	1	2609	\N	55.779483999999997	город Москва, САО, район Беговой, Ленинградский просп, дом 5	Россия, Москва, Ленинградский проспект, 5с1	0101000020E6100000B5C4CA68E4C94240ACE0B721C6E34B40
55533	1	\N	\N	1	2609	\N	55.802340999999998	город Москва, САО, район Аэропорт, Ленинградский просп, дом 64	Россия, Москва, Ленинградский проспект, 64	0101000020E6100000A6D24F38BBC34240B69E211CB3E64B40
55530	1	\N	\N	1	2609	\N	55.795904	город Москва, САО, район Аэропорт, Ленинградский просп, дом 46	Россия, Москва, Ленинградский проспект, 46	0101000020E61000005E0F26C5C7C54240B760A92EE0E54B40
56439	1	\N	\N	1	5693	\N	55.582949999999997	город Москва, ЮАО, район Бирюлево Восточное, Лебедянская ул, дом 26, корп. 4	Россия, Москва, Лебедянская улица, 26к4	0101000020E6100000E109BDFE24D84240029A081B9ECA4B40
56430	1	\N	\N	1	5693	\N	55.587620999999999	город Москва, ЮАО, район Бирюлево Восточное, Лебедянская ул, дом 9	Россия, Москва, Лебедянская улица, 9	0101000020E61000004EF04DD367D54240AEB8382A37CB4B40
56436	1	\N	\N	1	12755	\N	55.584136000000001	город Москва, ЮАО, район Бирюлево Восточное, Лебедянская ул, дом 14, корп. 3		0101000020E6100000E55E605628D642404835ECF7C4CA4B40
56435	1	\N	\N	1	13119	\N	55.584511999999997	город Москва, ЮАО, район Бирюлево Восточное, Лебедянская ул, дом 16		0101000020E610000044DB317557D642404D0F0A4AD1CA4B40
57138	1	\N	\N	1	13102	\N	55.887023999999997	город Москва, СЗАО, район Куркино, Ландышевая ул, дом 8		0101000020E61000000ABABDA431B2424030629F008AF14B40
55371	1	\N	\N	1	266	\N	55.771352999999998	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Ладожская ул., дом 4/6, адрес УИК: Бауманская ул, дом 39	Россия, Москва, Ладожская улица, 4/6с3	0101000020E6100000E44A3D0B42D74240F355F2B1BBE24B40
55468	1	\N	\N	1	1734	\N	55.732996	город Москва, ЦАО, Таганский район, Лавров пер, дом 9	Россия, Москва, Лавров переулок, 9	0101000020E610000020B3B3E89DD44240A60C1CD0D2DD4B40
55746	1	\N	\N	1	5387	\N	55.804268	город Москва, СВАО, Алексеевский район, Кучин пер, дом 14	Россия, Москва, Кучин переулок, 14	0101000020E6100000E2033BFE0BD24240139CFA40F2E64B40
57130	1	\N	\N	1	3650	\N	55.725721	город Москва, ЗАО, район Фили-Давыдково, Кутузовский просп, дом 80	Россия, Москва, Кутузовский проспект, 80	0101000020E6100000FB75A73B4FBA42409D82FC6CE4DC4B40
56927	1	\N	\N	1	3650	\N	55.750033000000002	город Москва, ЗАО, район Дорогомилово, Кутузовский просп, дом 6	Россия, Москва, Кутузовский проспект, 6	0101000020E610000056D3F544D7C74240DCF5D21401E04B40
56926	1	\N	\N	1	3650	\N	55.744526	город Москва, ЗАО, район Дорогомилово, Кутузовский просп, дом 24	Россия, Москва, Кутузовский проспект, 24	0101000020E6100000454B1E4FCBC54240C782C2A04CDF4B40
56925	1	\N	\N	1	3650	\N	55.743051000000001	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Кутузовский просп., дом 28, адрес УИК: Кутузовский просп, дом 30/32		0101000020E61000005778978BF8C442404B21904B1CDF4B40
56924	1	\N	\N	1	3650	\N	55.748593999999997	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Кутузовский пр., дом 10, адрес УИК: Давыдова Дениса ул, дом 7	Россия, Москва, Кутузовский проспект, 10	0101000020E61000003CBF28417FC74240ACFD9DEDD1DF4B40
56982	1	\N	4266	1	12840	\N	55.504134000000001	город Москва, ЗАО, Можайский район, Кутузова ул, дом 20		0101000020E61000004E417E3672FF41409D66817687C04B40
56501	1	\N	\N	1	12970	\N	55.617693000000003	город Москва, ЮАО, район Зябликово, Кустанайская ул, дом 10, корп. 2		0101000020E6100000BCE82B4833E04240ECFB709010CF4B40
56788	1	\N	\N	1	13228	\N	55.570365000000002	город Москва, ЮЗАО, район Северное Бутово, Куликовская ул, дом 3Б		0101000020E6100000FA4674CFBAC842403BE466B801C94B40
57214	1	\N	\N	1	12616	\N	55.802304999999997	город Москва, СЗАО, район Строгино, Кулакова ул, дом 25, корп. 2		0101000020E61000000B0A83328DB24240693524EEB1E64B40
57212	1	\N	\N	1	12616	\N	55.807313999999998	город Москва, СЗАО, район Строгино, Кулакова ул, дом 17, корп. 2		0101000020E6100000A228D027F2B242402DCDAD1056E74B40
57205	1	\N	\N	1	12616	\N	55.814183999999997	город Москва, СЗАО, район Строгино, Кулакова ул, дом 3, корп. 1		0101000020E6100000C25087156EB3424096766A2E37E84B40
57204	1	\N	\N	1	12616	\N	55.815781999999999	город Москва, СЗАО, район Строгино, Кулакова ул, дом 2, корп.2		0101000020E610000011514CDE00B342402E55698B6BE84B40
56980	1	\N	\N	1	12674	\N	55.722974000000001	город Москва, ЗАО, Можайский район, Кубинка ул, дом 20		0101000020E6100000E9B985AE44B44240DDED7A698ADC4B40
56280	1	\N	\N	1	13235	\N	55.684356000000001	город Москва, ЮВАО, район Люблино, Кубанская ул, дом 27		0101000020E61000002507EC6AF2DE4240236937FA98D74B40
55524	1	\N	\N	1	13074	\N	55.731901000000001	Адрес помещения для голосования: город Москва, ЦАО, район Якиманка, Крымский вал ул., дом 8, корп. 2, адрес УИК: Крымский вал ул, дом 8		0101000020E6100000035C902DCBCD4240717495EEAEDD4B40
56941	1	\N	\N	1	12738	\N	55.750165000000003	город Москва, ЗАО, район Крылатское, Крылатские холмы, дом 13		0101000020E6100000957EC2D9ADB542404BCD1E6805E04B40
56940	1	\N	\N	1	12738	\N	55.750869000000002	город Москва, ЗАО, район Крылатское, Крылатские холмы, дом 15, корп. 1		0101000020E6100000D3D85E0B7AB54240454AB3791CE04B40
56938	1	\N	\N	1	12738	\N	55.755899999999997	город Москва, ЗАО, район Крылатское, Крылатские холмы, дом 23		0101000020E610000015CAC2D7D7B44240F085C954C1E04B40
56937	1	\N	\N	1	12738	\N	55.755899999999997	Адрес помещения для голосования: город Москва, ЗАО, район Крылатское, Крылатские холмы, дом 23, адрес УИК: Крылатские холмы, дом 27, корп. 3		0101000020E610000015CAC2D7D7B44240F085C954C1E04B40
56935	1	\N	\N	1	12738	\N	55.762166000000001	город Москва, ЗАО, район Крылатское, Крылатские холмы, дом 45, корп. 2		0101000020E6100000772D211FF4B44240C30FCEA78EE14B40
56934	1	\N	\N	1	12738	\N	55.762090000000001	город Москва, ЗАО, район Крылатское, Крылатские холмы, дом 45, корп. 1		0101000020E6100000D53C47E4BBB44240E84D452A8CE14B40
56932	1	\N	\N	1	12738	\N	55.764648000000001	город Москва, ЗАО, район Крылатское, Крылатские холмы, дом 28, корп. 1		0101000020E6100000F05014E813B54240D57954FCDFE14B40
56931	1	\N	\N	1	12913	\N	55.770516999999998	Адрес помещения для голосования: город Москва, ЗАО, район Крылатское, Крылатская ул., дом 25, адрес УИК: Крылатская ул, дом 30, корп. 3		0101000020E61000002AC423F1F2B442408A01124DA0E24B40
56930	1	\N	\N	1	12913	\N	55.770516999999998	город Москва, ЗАО, район Крылатское, Крылатская ул, дом 25		0101000020E61000002AC423F1F2B442408A01124DA0E24B40
86324	6	56	\N	1810	18312	\N	58.612037999999998	город Нижняя Тура, Декабристов, 2А		0101000020E6100000A2ED98BA2BED4D4062F4DC42574E4D40
56403	1	\N	\N	1	12489	\N	55.729258375052503	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Крутицкий вал ул., дом 5, адрес УИК: Дубровская 1-я ул, дом 8А	Россия, Москва, улица Симоновский Вал	0101000020E61000007B88467710D54240562C7E5358DD4B40
56404	1	\N	\N	1	12456	\N	55.729610000000001	город Москва, ЮВАО, Южнопортовый район, Крутицкий вал ул, дом 5		0101000020E6100000A708707A17D54240D36A48DC63DD4B40
56772	1	\N	\N	1	13103	\N	55.682015999999997	Адрес места голосования: город Москва, ЮЗАО, Ломоносовский район, Крупской ул., дом 9, адрес УИК: Ульяновой Марии ул, дом 8	Россия, Москва, улица Крупской, 9	0101000020E6100000CC457C2766C34240A3ACDF4C4CD74B40
56765	1	\N	\N	1	13103	\N	55.683259999999997	город Москва, ЮЗАО, Ломоносовский район, Крупской ул, дом 17		0101000020E6100000E4D6A4DB12C342401D554D1075D74B40
55612	1	\N	\N	1	3594	\N	55.851484999999997	город Москва, САО, Головинский район, Кронштадтский бульв, дом 43А	Россия, Москва, Кронштадтский бульвар, 43а	0101000020E610000032AEB8382AC142406C04E275FDEC4B40
55603	1	\N	\N	1	3594	\N	55.844172	город Москва, САО, Головинский район, Кронштадтский бульв, дом 33	Россия, Москва, Кронштадтский бульвар, 33	0101000020E61000008A03E8F7FDBF42407619FED30DEC4B40
56557	1	\N	\N	1	6961	\N	55.668579000000001	город Москва, ЮАО, Нагорный район, Криворожская ул, дом 27, корп. А	Россия, Москва, Криворожская улица, 27а	0101000020E610000059C0046EDDCD42406DE525FF93D54B40
56681	1	\N	\N	1	12876	\N	55.681426999999999	город Москва, ЮЗАО, Академический район, Кржижановского ул, дом 4а		0101000020E61000002D060FD3BEC7424042CEFBFF38D74B40
56678	1	\N	\N	1	12876	\N	55.675016999999997	город Москва, ЮЗАО, Академический район, Кржижановского ул, дом 30		0101000020E6100000AA0F24EF1CCA42403C9F01F566D64B40
57137	1	\N	\N	1	6213	\N	55.711914	город Москва, ЗАО, район Фили-Давыдково, Кременчугская ул, дом 46	Россия, Москва, Кременчугская улица, 46	0101000020E6100000779D0DF967BA424043C879FF1FDB4B40
56986	1	\N	\N	1	12842	\N	55.724713000000001	город Москва, ЗАО, Можайский район, Красных зорь ул, дом 61		0101000020E61000002E1A321EA5B6424037FE4465C3DC4B40
55987	1	\N	\N	1	13052	\N	55.724231000000003	город Москва, ВАО, район Вешняки, Красный Казанец ул, дом 3А		0101000020E6100000FF25A94C31E74240ECDFF599B3DC4B40
56268	1	\N	\N	1	12862	\N	55.760317000000001	город Москва, ЮВАО, район Лефортово, Красноказарменная ул, дом 3, корп. 1		0101000020E6100000753BFBCA83D84240E2CB441152E14B40
56263	1	\N	\N	1	12862	\N	55.753867999999997	город Москва, ЮВАО, район Лефортово, Красноказарменная ул, дом 21		0101000020E6100000A7EB89AE0BDB42401EC022BF7EE04B40
56264	1	\N	\N	1	12953	\N	55.757393999999998	город Москва, ЮВАО, район Лефортово, Красноказарменная ул, дом 11		0101000020E61000005378D0ECBAD94240E3175E49F2E04B40
56301	1	\N	\N	1	3875	\N	55.668325000000003	город Москва, ЮВАО, район Люблино, Краснодонская ул, дом 40	Россия, Москва, Краснодонская улица, 40	0101000020E6100000AE669DF17DDF4240B30C71AC8BD54B40
56282	1	\N	\N	1	3875	\N	55.686329999999998	город Москва, ЮВАО, район Люблино, Краснодонская ул, дом 2, корп. 4	Россия, Москва, Краснодонская улица, 2к4	0101000020E6100000ADFC321823E04240C02154A9D9D74B40
56298	1	\N	\N	1	12590	\N	55.677366999999997	город Москва, ЮВАО, район Люблино, Краснодарская ул, дом 11		0101000020E6100000FD8348861CDF4240DF313CF6B3D64B40
56287	1	\N	\N	1	12590	\N	55.677301	город Москва, ЮВАО, район Люблино, Краснодарская ул, дом 45/11		0101000020E61000000744882B67E14240284696CCB1D64B40
56285	1	\N	\N	1	12590	\N	55.678262178273201	город Москва, ЮВАО, район Люблино, Краснодарская ул, дом 9А	Россия, Москва, Краснодарская улица, 9	0101000020E61000008CBFED0912DF42404D0F0A4AD1D64B40
56644	1	\N	\N	1	12465	\N	55.609701000000001	город Москва, ЮАО, район Чертаново Центральное, Красного Маяка ул, дом 3Г		0101000020E610000034BBEEAD48CC424054ABAFAE0ACE4B40
56635	1	\N	\N	1	12465	\N	55.610471820948298	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Красного Маяка ул., дом 13А, адрес УИК: Красного Маяка ул, дом 13А, корп. 4		0101000020E61000007FF6234564CA4240D68F4DF223CE4B40
55958	1	\N	\N	1	7612	\N	55.812342000000001	город Москва, ВАО, район Богородское, Краснобогатырская ул, дом 21А	Россия, Москва, Краснобогатырская улица, 21а	0101000020E6100000588CBAD6DED94240689599D2FAE74B40
55959	1	\N	\N	1	12510	\N	55.810346203561203	город Москва, ВАО, район Богородское, Краснобогатырская ул, дом 38, стр. 1		0101000020E6100000FDF50A0BEED94240E338F06AB9E74B40
55430	1	\N	\N	1	13065	\N	55.768617999999996	город Москва, ЦАО, Пресненский район, Красина ул, дом 27		0101000020E61000003198BF42E6CA4240F78E1A1362E24B40
56770	1	\N	\N	1	12478	\N	55.679178999999998	Адрес места голосования: город Москва, ЮЗАО, Ломоносовкий район, Кравченко ул., дом 14, адрес УИК: Ленинский просп, дом 88, корп. 2		0101000020E610000087E123624AC24240A3906456EFD64B40
56767	1	\N	\N	1	12478	\N	55.678829	город Москва, ЮЗАО, Ломоносовский район, Кравченко ул, дом 14, корп. 1		0101000020E61000000C04013274C24240C74961DEE3D64B40
55543	1	\N	\N	1	2821	\N	55.806646000000001	город Москва, САО, район Аэропорт, Кочновский пр, дом 4, корп. 1	Россия, Москва, Кочновский проезд, 4к1	0101000020E6100000008DD2A57FC5424080B9162D40E74B40
55472	1	\N	\N	1	1780	\N	55.747145000000003	город Москва, ЦАО, Таганский район, Котельническая наб, дом 1/15, корп. Б	Россия, Москва, Котельническая набережная, 1/15кб	0101000020E61000008AE5965643D242405A2F8672A2DF4B40
55768	1	\N	\N	1	12604	\N	55.884186	город Москва, СВАО, Алтуфьевский район, Костромская ул, дом 14Г		0101000020E6100000051A6CEA3CCC424060CAC0012DF14B40
55767	1	\N	\N	1	12626	\N	55.884079917866003	город Москва, СВАО, Алтуфьевский район, Костромская ул, дом 14В		0101000020E61000008E75711B0DCC42401A868F8829F14B40
55749	1	\N	\N	1	13139	\N	55.821719999999999	город Москва, СВАО, Алексеевский район, Космонавтов ул, дом 5		0101000020E6100000448655BC91D342400C3CF71E2EE94B40
55584	1	\N	\N	1	13144	\N	55.816651999999998	город Москва, САО, Войковский район, Волкова космонавта ул, дом 23		0101000020E61000005586713788C24240431B800D88E84B40
55981	1	\N	\N	1	3643	\N	55.718187	город Москва, ВАО, район Вешняки, Косинская ул, дом 24А	Россия, Москва, Косинская улица, 24а	0101000020E6100000D3F9F02C41EA4240C8B4368DEDDB4B40
55982	1	\N	\N	1	12907	\N	55.715752999999999	город Москва, ВАО, район Вешняки, Косинская ул, дом 28А		0101000020E61000009F211CB3ECE94240C78157CB9DDB4B40
55978	1	\N	\N	1	12907	\N	55.723981999999999	город Москва, ВАО, район Вешняки, Косинская ул, дом 10А		0101000020E6100000CB811E6ADBEA424043723271ABDC4B40
55632	1	\N	\N	1	3832	\N	55.873950000000001	Адрес помещения для голосования: город Москва, САО, Дмитровский район, Коровинское шоссе, дом 14А, адрес УИК: 800-летия Москвы ул, дом 2, корп. 1		0101000020E610000028F1B913ECC342406B2BF697DDEF4B40
55622	1	\N	\N	1	3832	\N	55.886063999999998	город Москва, САО, Дмитровский район, Коровинское шоссе, дом 28	Россия, Москва, Коровинское шоссе, 28	0101000020E610000013D21A834EC24240DB148F8B6AF14B40
55620	1	\N	\N	1	3832	\N	55.881898999999997	город Москва, САО, Дмитровский район, Коровинское шоссе, дом 24А		0101000020E6100000C9C859D8D3C2424003B00111E2F04B40
55790	1	\N	\N	1	13049	\N	55.891623000000003	город Москва, СВАО, район Бибирево, Корнейчука ул, дом 55А		0101000020E6100000C9CA2F8331D0424043AED4B320F24B40
55789	1	\N	\N	1	13049	\N	55.894948999999997	город Москва, СВАО, район Бибирево, Корнейчука ул, дом 37А		0101000020E61000008735954561D14240404B57B08DF24B40
55794	1	\N	\N	1	12911	\N	55.891002	город Москва, СВАО, район Бибирево, Коненкова ул, дом 10А		0101000020E610000095B6B8C667CE4240D655815A0CF24B40
55793	1	\N	\N	1	12911	\N	55.889648999999999	город Москва, СВАО, район Бибирево, Коненкова ул, дом 8А		0101000020E610000057E9EE3A1BCE4240A5F5B704E0F14B40
55792	1	\N	\N	1	12911	\N	55.888033	город Москва, СВАО, район Бибирево, Коненкова ул, дом 4А		0101000020E610000000581D39D2CD42406762BA10ABF14B40
55865	1	\N	\N	1	13010	\N	55.818441999999997	город Москва, СВАО, Останкинский район, Кондратюка ул, дом 5		0101000020E610000095EEAEB321D142401FD61BB5C2E84B40
55606	1	\N	\N	1	3635	\N	55.845894999999999	город Москва, САО, Головинский район, Конаковский пр, дом 5	Россия, Москва, Конаковский проезд, 5	0101000020E610000024D1CB2896BD4240CA6C904946EC4B40
55512	1	\N	\N	1	2333	\N	55.719358	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Комсомольский просп., дом 43, адрес УИК: Хамовнический Вал ул, дом 16		0101000020E610000004E8F7FD9BC94240D80E46EC13DC4B40
57399	1	\N	\N	1	794	\N	55.776719999999997	город Москва, ЦАО, Красносельский район, Комсомольская пл, дом 5	Россия, Москва, Комсомольская площадь, 5	0101000020E6100000E7C6F48425D4424016139B8F6BE34B40
57398	1	\N	\N	1	794	\N	55.776623999999998	город Москва, ЦАО, Красносельский район, Комсомольская пл, дом 3	Россия, Москва, Комсомольская площадь, 3	0101000020E61000000936AE7FD7D34240F4A44C6A68E34B40
57397	1	\N	\N	1	794	\N	55.773555000000002	город Москва, ЦАО, Красносельский район, Комсомольская пл, дом 2	Россия, Москва, Комсомольская площадь, 2	0101000020E610000044DC9C4A06D442402254A9D903E34B40
55406	1	\N	\N	1	794	\N	55.775475798664999	Адрес помещения для голосования: город Москва, ЦАО, Красносельский район, Комсомольская пл., дом 4, адрес УИК: Красносельская Верх. ул, дом 34	Россия, Москва, Комсомольская площадь, 4с1	0101000020E610000003CFBD874BD442409C6A2DCC42E34B40
55831	1	\N	\N	1	12745	\N	55.873798999999998	город Москва, СВАО, Лосиноостровский район, Коминтерна ул, дом 52		0101000020E61000004E0E9F7422D94240852348A5D8EF4B40
55910	1	\N	\N	1	13082	\N	55.857472999999999	город Москва, СВАО, район Свиблово, Кольская ул, дом 1		0101000020E61000002C9FE57970D34240FC19DEACC1ED4B40
56524	1	\N	\N	1	2624	\N	55.665405999999997	город Москва, ЮАО, район Нагатино-Садовники, Коломенский пр, дом 16	Россия, Москва, Коломенский проезд, 16	0101000020E61000003DB83B6BB7D34240F54718062CD54B40
56551	1	\N	\N	1	6869	\N	55.680731999999999	город Москва, ЮАО, район Нагатинский затон, Коломенская наб, дом 8	Россия, Москва, Коломенская набережная, 8	0101000020E6100000CEFBFF3861DA42409BABE63922D74B40
56549	1	\N	\N	1	6869	\N	55.680731999999999	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Коломенская наб., дом 8, адрес УИК: Коломенская ул, дом 5, корп. 3		0101000020E6100000CEFBFF3861DA42409BABE63922D74B40
56548	1	\N	\N	1	6869	\N	55.677168999999999	город Москва, ЮАО, район Нагатинский затон, Коломенская наб, дом 16	Россия, Москва, Коломенская набережная, 16	0101000020E61000005455682096D94240B96E4A79ADD64B40
56547	1	\N	\N	1	6869	\N	55.675924999999999	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Коломенская наб., дом 20, адрес УИК: Коломенская ул, дом 27	Россия, Москва, Коломенская набережная, 20	0101000020E610000065ABCB2901D942403FC6DCB584D64B40
55621	1	\N	\N	1	3850	\N	55.884115000000001	город Москва, САО, Дмитровский район, Клязьминская ул, дом 8А	Россия, Москва, Клязьминская улица, 8а	0101000020E610000072A43330F2C24240977329AE2AF14B40
55623	1	\N	\N	1	13060	\N	55.889395999999998	город Москва, САО, Дмитровский район, Клязьминская ул, дом 7, корп. 4		0101000020E610000017821C9430C34240BB9866BAD7F14B40
56461	1	\N	\N	1	12768	\N	55.636955999999998	город Москва, ЮАО, район Братеево, Ключевая ул, дом 6, корп. 2		0101000020E61000005F0CE544BBE04240D87E32C687D14B40
55728	1	\N	\N	1	12605	\N	55.869985999999997	город Москва, САО, район Ховрино, Клинская ул, дом 20А		0101000020E61000000E130D52F0BE42402AFD84B35BEF4B40
55727	1	\N	\N	1	12605	\N	55.871333999999997	город Москва, САО, район Ховрино, Клинская ул, д.22		0101000020E6100000020EA14ACDBE424049F25CDF87EF4B40
55726	1	\N	\N	1	12605	\N	55.870728	город Москва, САО, район Ховрино, Клинская ул, дом 16А		0101000020E6100000D0B8702024BF424012DBDD0374EF4B40
55725	1	\N	\N	1	12605	\N	55.87189	город Москва, САО, район Ховрино, Клинская ул, дом 24		0101000020E6100000438F183DB7BE4240CFDA6D179AEF4B40
55724	1	\N	\N	1	12605	\N	55.871333999999997	город Москва, САО, район Ховрино, Клинская ул, дом 22		0101000020E6100000020EA14ACDBE424049F25CDF87EF4B40
55723	1	\N	\N	1	12605	\N	55.869329	город Москва, САО, район Ховрино, Клинская ул, дом 20		0101000020E6100000BDC282FB01BF4240713B342C46EF4B40
55434	1	\N	\N	1	12546	\N	55.767473000000003	город Москва, ЦАО, Пресненский район, Климашкина ул, дом 13Б		0101000020E61000008F386403E9C8424011C8258E3CE24B40
57385	1	\N	\N	1	821	\N	55.683883999999999	город Москва, ЮАО, район Нагатинский затон, Кленовый бульв., ,д.7, к.2,Частная школа «Самсон»		0101000020E610000072A59E05A1D64240FB20CB8289D74B40
56539	1	\N	\N	1	821	\N	55.676631	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Кленовый бульв., дом 21, адрес УИК: Коломенская ул, дом 27		0101000020E610000015E63DCE34D74240DA3A38D89BD64B40
56538	1	\N	\N	1	821	\N	55.676631	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Кленовый бульв., дом 21, адрес УИК: Кленовый бульв, дом 23, копр. 2		0101000020E610000015E63DCE34D74240DA3A38D89BD64B40
56536	1	\N	\N	1	821	\N	55.676631	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Кленовый бульв., дом 21, адрес УИК: Судостроительная ул, дом 20/2, корп. 1		0101000020E610000015E63DCE34D74240DA3A38D89BD64B40
56530	1	\N	\N	1	821	\N	55.683883999999999	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Кленовый бульв., дом 7, корп. 2, адрес УИК: Кленовый бульв, дом 7		0101000020E610000072A59E05A1D64240FB20CB8289D74B40
55583	1	\N	\N	1	12978	\N	55.822938000000001	город Москва, САО, Войковский район, Цеткин Клары ул, дом 23		0101000020E6100000CE531D7233C242405D514A0856E94B40
55582	1	\N	\N	1	12978	\N	55.824722999999999	Адрес помещения для голосования: город Москва, САО, Войковский район, Клары Цеткин ул., дом 27, адрес УИК: Новоподмосковный 5-й пер, дом 4		0101000020E6100000A9674128EFC1424027A1F48590E94B40
55581	1	\N	\N	1	12978	\N	55.824722999999999	город Москва, САО, Войковский район, Цеткин Клары ул, дом 27		0101000020E6100000A9674128EFC1424027A1F48590E94B40
56652	1	\N	\N	1	12385	\N	55.599591650484101	город Москва, ЮАО, район Чертаново Южное, Кировоградская ул, дом 42, корп. 2	Россия, Москва, Кировоградская улица, 42к2	0101000020E6100000CA6DFB1EF5CB4240BC783F6EBFCC4B40
56651	1	\N	\N	1	12385	\N	55.599096002759303	город Москва, ЮАО, район Чертаново Южное, Кировоградская ул, дом 42Б, стр. 1	Россия, Москва, Кировоградская улица, 42б	0101000020E6100000C59272F739CC42400C957F2DAFCC4B40
56645	1	\N	\N	1	12385	\N	55.603063570945601	город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул, дом 21	Россия, Москва, Кировоградская улица, 21	0101000020E6100000931804560ECD42408EB27E3331CD4B40
56618	1	\N	\N	1	12385	\N	55.629513813108296	город Москва, ЮАО, район Чертаново Северное, Кировоградская ул, дом 6Б	Россия, Москва, Кировоградская улица, 6б	0101000020E61000009FCA694FC9CD4240E42F2DEA93D04B40
56641	1	\N	\N	1	12419	\N	55.615388146921603	город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул, дом 22А		0101000020E6100000A9F57EA31DCD4240E92CB308C5CE4B40
56647	1	\N	\N	1	12362	\N	55.608433188229803	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул., дом 30А, адрес УИК: Красного Маяка ул, дом 5, корп. 1		0101000020E610000057E883656CCC42405167EE21E1CD4B40
56646	1	\N	\N	1	12362	\N	55.6083132430159	город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул, дом 30А	Россия, Москва, район Чертаново Центральное	0101000020E61000009C3237DF88CC4240A75D4C33DDCD4B40
56643	1	\N	\N	1	12362	\N	55.615338999999999	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул., дом 22А, адрес УИК: Красного Маяка ул, дом 4, корп. 1		0101000020E6100000A88DEA7420CD4240077AA86DC3CE4B40
56642	1	\N	\N	1	12362	\N	55.615351619521803	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул., дом 22А, адрес УИК: Красного Маяка ул, дом 4, корп. 5	Россия, Москва, Кировоградская улица, 22а	0101000020E610000030293E3E21CD42409CC3B5DAC3CE4B40
56640	1	\N	\N	1	12362	\N	55.617938433945604	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул., дом 18, корп. 4, адрес УИК: Кировоградская ул, дом 16, корп. 3	Россия, Москва, Кировоградская улица, 18к4	0101000020E610000045D95BCAF9CC4240537AA69718CF4B40
56639	1	\N	\N	1	12362	\N	55.617659135310099	город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул, дом 18, корп. 4	Россия, Москва, Кировоградская улица, 18к4	0101000020E61000003BC780ECF5CC4240408A3A730FCF4B40
56638	1	\N	\N	1	12362	\N	55.617938433945604	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Кировоградская ул., дом 18, корп. 4, адрес УИК: Днепропетровская ул, дом 5, корп. 5		0101000020E6100000392BA226FACC4240537AA69718CF4B40
56619	1	\N	\N	1	12362	\N	55.627711109796898	город Москва, ЮАО, район Чертаново Северное, Кировградская ул, дом 8Г	Россия, Москва, Кировоградская улица, 8г	0101000020E6100000AAB9DC60A8CD4240732B84D558D04B40
56613	1	\N	\N	1	12362	\N	55.6277490483264	город Москва, ЮАО, район Чертаново Северное, Кировоградская ул, дом 8Г		0101000020E610000010B3976DA7CD4240618C48145AD04B40
55755	1	\N	\N	1	12974	\N	55.817092000000002	город Москва, СВАО, Алексеевский район, Кибальчича ул, дом 1		0101000020E61000002B86AB0320D2424060E97C7896E84B40
55973	1	\N	\N	1	7761	\N	55.742508999999998	город Москва, ВАО, район Вешняки, Кетчерская ул, дом 10А	Россия, Москва, Кетчерская улица, 10а	0101000020E6100000B5E1B034F0E942402AFEEF880ADF4B40
55972	1	\N	\N	1	12723	\N	55.742731999999997	город Москва, ВАО, район Вешняки, Кетчерская ул, дом 8А		0101000020E6100000FD135CACA8E94240A9D898D711DF4B40
55595	1	\N	\N	1	3482	\N	55.877344000000001	город Москва, САО, район Восточное Дегунино, Керамический пр, дом 55, корп. 3	Россия, Москва, Керамический проезд, 55к3	0101000020E6100000E5D3635B06C84240C1ABE5CE4CF04B40
55544	1	\N	\N	1	13135	\N	55.803852999999997	город Москва, САО, район Аэропорт, Ильюшина академика ул, дом 8		0101000020E610000038F6ECB94CC542404FE5B4A7E4E64B40
55594	1	\N	\N	1	3482	\N	55.872481000000001	город Москва, САО, район Восточное Дегунино, Керамический пр, дом 47а	Россия, Москва, Керамический проезд, 47а	0101000020E6100000CB65A3737EC84240D1B01875ADEF4B40
56683	1	\N	\N	1	13033	\N	55.687066000000002	город Москва, ЮЗАО, Академический район, Кедрова ул, дом 5, корп. 1		0101000020E610000014E8137992C84240C61858C7F1D74B40
56676	1	\N	\N	1	13033	\N	55.685091999999997	город Москва, ЮЗАО, Академический район, Кедрова ул, дом 11		0101000020E6100000DA1A118C83C9424028603B18B1D74B40
56589	1	\N	\N	1	2561	\N	55.606760999999999	город Москва, ЮАО, район Орехово-Борисово Южное, Каширское шоссе, дом 116, корп. 3	Россия, Москва, Каширское шоссе, 116к3	0101000020E6100000077E54C37EDB42407FBE2D58AACD4B40
56527	1	\N	\N	1	2561	\N	55.666147000000002	город Москва, ЮАО, район Нагатино-Садовники, Каширское шоссе, дом 15	Россия, Москва, Каширское шоссе, 15	0101000020E61000009885764EB3D042400DAA0D4E44D54B40
56526	1	\N	\N	1	2561	\N	55.667706000000003	город Москва, ЮАО, район Нагатино-Садовники, Каширское шоссе, дом 6, корп. 2	Россия, Москва, Каширское шоссе, 6к2	0101000020E61000007F6B274A42D04240E7ABE46377D54B40
56512	1	\N	\N	1	2561	\N	55.639800999999999	город Москва, ЮАО, район Москворечье-Сабурово, Каширское шоссе, дом 55, корп. 7	Россия, Москва, Каширское шоссе, 55к7	0101000020E6100000F9D687F546D942405B79C9FFE4D14B40
56507	1	\N	\N	1	2561	\N	55.645963999999999	город Москва, ЮАО, район Москворечье-Сабурово, Каширское шоссе, дом 52	Россия, Москва, Каширское шоссе, 52	0101000020E61000001781B1BE81D542405932C7F2AED24B40
56720	1	\N	\N	1	12721	\N	55.649129000000002	город Москва, ЮЗАО, район Зюзино, Каховка ул, дом 11, корп. 2		0101000020E6100000B5DD04DF34CB42404EF1B8A816D34B40
56711	1	\N	\N	1	12721	\N	55.651739999999997	город Москва, ЮЗАО, район Зюзино, Каховка ул, дом 19, корп. 3		0101000020E6100000CC7EDDE9CEC942405DBF60376CD34B40
56710	1	\N	\N	1	12721	\N	55.652343999999999	город Москва, ЮЗАО, район Зюзино, Каховка ул, дом 19, корп. 2		0101000020E6100000FB1F60ADDAC94240F4DE180280D34B40
57129	1	\N	\N	1	5838	\N	55.731135999999999	город Москва, ЗАО, район Фили-Давыдково, Кастанаевская ул, дом 59	Россия, Москва, Кастанаевская улица, 59к1	0101000020E6100000D1E80E6267BA4240D1764CDD95DD4B40
57128	1	\N	\N	1	5838	\N	55.731734000000003	город Москва, ЗАО, район Фили-Давыдково, Кастанаевская ул, дом 45, корп. 1	Россия, Москва, Кастанаевская улица, 45к1	0101000020E61000006F9EEA909BBB424086AFAF75A9DD4B40
57107	1	\N	\N	1	5838	\N	55.740445999999999	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Кастанаевская  ул., дом 10, Адрес УИК: Дундича Олеко ул, дом 5	Россия, Москва, Кастанаевская улица, 10	0101000020E61000009468C9E369BF42401D3A3DEFC6DE4B40
57106	1	\N	\N	1	5838	\N	55.740445999999999	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Кастанаевская ул., дом 10, Адрес УИК: Кастанаевская ул, дом 7	Россия, Москва, Кастанаевская улица, 10	0101000020E61000009468C9E369BF42401D3A3DEFC6DE4B40
57105	1	\N	\N	1	12902	\N	55.738813999999998	город Москва, ЗАО, район Филевский парк, Кастанаевская ул, дом 7		0101000020E6100000E4DBBB067DBF4240D9E9077591DE4B40
57127	1	\N	\N	1	12623	\N	55.732731999999999	город Москва, ЗАО, район Фили-Давыдково, Кастанаевская ул, дом 43		0101000020E6100000D107CBD8D0BB4240C85D8429CADD4B40
57125	1	\N	\N	1	12623	\N	55.734988000000001	город Москва, ЗАО, район Фили-Давыдково, Кастанаевская ул, дом 29, корп. 1		0101000020E61000005F44DB3175BD4240EA79371614DE4B40
57102	1	\N	\N	1	12623	\N	55.737704000000001	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Кастанаевская ул., дом 9, Адрес УИК: Минская ул, дом 8, корп. 1		0101000020E6100000313F373465BF42406F10AD156DDE4B40
55759	1	\N	\N	1	12885	\N	55.823327999999997	Адрес помещения для голосования: город Москва, СВАО, Алексеевский район, Касаткина ул., дом 15, адрес УИК: Касаткина ул, дом 13, корп. 5		0101000020E6100000124A5F0839D54240C7F0D8CF62E94B40
55627	1	\N	\N	1	3904	\N	55.895454000000001	город Москва, САО, Дмитровский район, Карельский бульв, дом 20	Россия, Москва, Карельский бульвар, 20	0101000020E6100000655419C6DDC442404489963C9EF24B40
55625	1	\N	\N	1	3904	\N	55.893127	город Москва, САО, Дмитровский район, Карельский бульв, дом 5	Россия, Москва, Карельский бульвар, 5	0101000020E6100000A2410A9E42C4424059164CFC51F24B40
55873	1	\N	\N	1	13069	\N	55.86448	город Москва, СВАО, район Отрадное, Каргопольская ул, дом 13, корп. 2		0101000020E6100000D9CF622992CB4240E605D847A7EE4B40
57226	1	\N	\N	1	7034	\N	55.775049000000003	город Москва, СЗАО, район Хорошево-Мневники, Карамышевская наб, дом 54, корп. 2	Россия, Москва, Карамышевская набережная, 54к2	0101000020E6100000A1F31ABB44BB424015E63DCE34E34B40
57224	1	\N	\N	1	7034	\N	55.769523999999997	город Москва, СЗАО, район Хорошево-Мневники, Карамышевская наб, дом 38	Россия, Москва, Карамышевская набережная, 38	0101000020E6100000060DFD135CBC424059BE2EC37FE24B40
57223	1	\N	\N	1	7034	\N	55.770871	город Москва, СЗАО, район Хорошево-Мневники, Карамышевская наб, дом 22, корп. 2	Россия, Москва, Карамышевская набережная, 22к2	0101000020E6100000B08EE3874ABD4240A837A3E6ABE24B40
56509	1	\N	\N	1	6493	\N	55.642220000000002	город Москва, ЮАО, район Москворечье-Сабурово, Кантемировская ул, дом 22, корп. 6	Россия, Москва, Кантемировская улица, 22к6	0101000020E61000001B9FC9FE79D44240276BD44334D24B40
56508	1	\N	\N	1	6493	\N	55.641112	город Москва, ЮАО, район Москворечье-Сабурово, Кантемировская ул, дом 22, корп. 4	Россия, Москва, Кантемировская улица, 22к4	0101000020E610000008CC43A67CD442405D8940F50FD24B40
56604	1	\N	\N	1	12838	\N	55.634582999999999	город Москва, ЮАО, район Царицыно, Кантемировская ул, дом 1А		0101000020E6100000742843554CD742407DCC07043AD14B40
56510	1	\N	\N	1	12838	\N	55.641787999999998	город Москва, ЮАО, район Москворечье-Сабурово, Кантемировская ул, дом 22, корп. 5		0101000020E6100000740D33349ED442408D7BF31B26D24B40
88466	6	56	\N	7561	19172	\N	56.613148000000002	город Красноуфимск, Березовая, 8		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
56019	1	\N	\N	1	97	\N	55.827948999999997	город Москва, ВАО, район Гольяново, Камчатская ул, дом 6	Россия, Москва, Камчатская улица, 6	0101000020E610000087DBA16131E84240C1E09A3BFAE94B40
56021	1	\N	\N	1	12985	\N	55.828020000000002	город Москва, ВАО, район Гольяново, Камчатская ул, дом 10		0101000020E610000064E597C118E942408B37328FFCE94B40
56020	1	\N	\N	1	12985	\N	55.828046000000001	город Москва, ВАО, район Гольяново, Камчатская ул, дом 8		0101000020E6100000677C5F5CAAE84240B4CA4C69FDE94B40
55526	1	\N	\N	1	2555	\N	55.728388000000002	город Москва, ЦАО, район Якиманка, Калужская пл, дом 1	Россия, Москва, Калужская площадь, 1к1	0101000020E61000007CF2B0506BCE4240416667D13BDD4B40
56882	1	\N	\N	1	13189	\N	55.537179000000002	город Москва, ЮЗАО, район Южное Бутово, Кадырова ул, дом 10		0101000020E61000006840BD1935C142408B8C0E48C2C44B40
56611	1	\N	\N	1	7425	\N	55.625923	город Москва, ЮАО, район Царицыно, Кавказский бульв, дом 37, корп. 2	Россия, Москва, Кавказский бульвар, 37к2	0101000020E6100000A7CCCD37A2D342403868AF3E1ED04B40
56603	1	\N	\N	1	7425	\N	55.634075000000003	город Москва, ЮАО, район Царицыно, Кавказский бульв, дом 12, корп. 3	Россия, Москва, Кавказский бульвар, 12к3	0101000020E6100000087250C24CD54240091B9E5E29D14B40
56602	1	\N	\N	1	7425	\N	55.633414000000002	город Москва, ЮАО, район Царицыно, Кавказский бульв, дом 16, корп. 2	Россия, Москва, Кавказский бульвар, 16к2	0101000020E6100000B3F0F5B52ED542400E6ABFB513D14B40
57209	1	\N	\N	1	12764	\N	55.806615999999998	город Москва, СЗАО, район Строгино, Исаковского ул, дом 29, корп. 1		0101000020E6100000EFC9C342ADB5424015376E313FE74B40
57207	1	\N	\N	1	12764	\N	55.809246000000002	город Москва, СЗАО, район Строгино, Исаковского ул, дом 22, корп. 3		0101000020E61000003D47E4BB94B442409C35785F95E74B40
57206	1	\N	\N	1	12764	\N	55.812105000000003	город Москва, СЗАО, район Строгино, Исаковского ул, дом 14, корп. 3		0101000020E6100000BAD8B45208B4424084F57F0EF3E74B40
57136	1	\N	\N	1	12816	\N	55.716594999999998	город Москва, ЗАО, район Фили-Давыдково, Инициативная ул, дом 1	Россия, Москва, район Фили-Давыдково, Инициативная улица, 1	0101000020E6100000B0AC342905BB424012BD8C62B9DB4B40
55762	1	\N	\N	1	12716	\N	55.880071000000001	город Москва, СВАО, Алтуфьевский район, Инженерная ул, дом 16		0101000020E61000007383A10E2BCA42403A94A12AA6F04B40
55629	1	\N	\N	1	13099	\N	55.886327000000001	город Москва, САО, Дмитровский район, Икшинская ул, дом 12		0101000020E61000004278B471C4C44240E947C32973F14B40
56862	1	\N	\N	1	2780	\N	55.546678999999997	город Москва, ЮЗАО, район Южное Бутово, Изюмская ул, дом 38/1	Россия, Москва, Изюмская улица, 38	0101000020E61000004D2EC6C03AC842407A34D593F9C54B40
56861	1	\N	\N	1	12642	\N	55.549083000000003	город Москва, ЮЗАО, район Южное Бутово, Изюмская ул, дом 34, корп. 3		0101000020E61000002F50526001C8424011E50B5A48C64B40
56860	1	\N	\N	1	12642	\N	55.549757867798299	город Москва, ЮЗАО, район Южное Бутово, Изюмская ул, дом 28/3		0101000020E6100000F357C85C19C84240705B5B785EC64B40
56859	1	\N	\N	1	12642	\N	55.551726000000002	город Москва, ЮЗАО, район Южное Бутово, Изюмская ул, дом 35А		0101000020E61000002905DD5ED2C842402C2D23F59EC64B40
55829	1	\N	\N	1	12827	\N	55.872414999999997	город Москва, СВАО, Лосиноостровский район, Изумрудная ул, дом 13, корп. 3		0101000020E61000008CDCD3D51DD7424019C5724BABEF4B40
56177	1	\N	\N	1	12305	\N	55.778072000000002	город Москва, ВАО, район Соколиная гора, Измайловское шоссе, дом 24, корп.3	Россия, Москва, Измайловское шоссе, 24к3	0101000020E6100000C55565DF15DD424077F700DD97E34B40
56176	1	\N	\N	1	12305	\N	55.780112000000003	город Москва, ВАО, район Соколиная гора, Измайловское шоссе, дом 60/62	Россия, Москва, Измайловское шоссе, 60	0101000020E61000000BED9C6681DE4240CC9BC3B5DAE34B40
56175	1	\N	\N	1	12305	\N	55.781229719905198	город Москва, ВАО, район Соколиная гора, Измайловское шоссе, дом 57	Россия, Москва, Измайловское шоссе, 57	0101000020E6100000240ED940BADE4240B9533A58FFE34B40
56052	1	\N	\N	1	589	\N	55.788716999999998	город Москва, ВАО, район Измайлово, Измайловский просп, дом 53/2	Россия, Москва, Измайловский проспект, 53	0101000020E6100000707A17EFC7E342404D66BCADF4E44B40
55992	1	\N	\N	1	589	\N	55.789664000000002	город Москва, ВАО, район Восточное Измайлово, Измайловский просп, дом 115	Россия, Москва, Измайловский проспект, 115	0101000020E6100000E607AEF204E842400E6ABFB513E54B40
55991	1	\N	\N	1	589	\N	55.788944999999998	город Москва, ВАО, район Восточное Измайлово, Измайловский просп, дом 87	Россия, Москва, Измайловский проспект, 87	0101000020E6100000414AECDADEE64240DEAB5626FCE44B40
56046	1	\N	\N	1	510	\N	55.794922	город Москва, ВАО, район Измайлово, Измайловский пр, дом 12	Россия, Москва, Измайловский проезд, 12	0101000020E6100000FB57569A94E242407A6F0C01C0E54B40
56055	1	\N	\N	1	611	\N	55.797716000000001	город Москва, ВАО, район Измайлово, Измайловский бульв, дом 19	Россия, Москва, Измайловский бульвар, 19	0101000020E6100000DCB75A272EE542407BBFD18E1BE64B40
56054	1	\N	\N	1	611	\N	55.797573999999997	город Москва, ВАО, район Измайлово, Измайловский бульв, дом 7	Россия, Москва, Измайловский бульвар, 7	0101000020E6100000BB7F2C4487E44240E811A3E716E64B40
55998	1	\N	\N	1	611	\N	55.795878999999999	город Москва, ВАО, район Восточное Измайлово, Измайловский бульв, дом 52		0101000020E6100000CCD0782288E742405E49F25CDFE54B40
55908	1	\N	\N	1	12662	\N	55.858927999999999	Адрес помещения для голосования: город Москва, СВАО, район Свиблово, Ивовая ул., дом 1, адрес УИК: Тенистый пр, дом 8А		0101000020E61000000BD1217024D2424031CF4A5AF1ED4B40
55965	1	\N	\N	1	12671	\N	55.813505999999997	город Москва, ВАО, район Богородское, Ивантеевская ул, дом 32А, стр. 1		0101000020E61000006729594E42DD4240C58CF0F620E84B40
56167	1	\N	\N	1	12408	\N	55.783498999999999	Адрес помещения для голосования: город Москва, ВАО, район Соколиная гора, Ибрагимова ул., дом 12, адрес УИК: Щербаковская ул, дом 54	Россия, Москва, улица Ибрагимова, 12	0101000020E6100000EB6E9EEA90DD42406FB9FAB149E44B40
55556	1	\N	\N	1	2995	\N	55.857801000000002	город Москва, САО, Бескудниковский район, Дубнинская ул, дом 7	Россия, Москва, Дубнинская улица, 7	0101000020E6100000B8921D1B81C84240F1BC546CCCED4B40
55738	1	\N	\N	1	13083	\N	55.778846000000001	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Зорге ул., дом  4, адрес УИК: Куусинена ул, дом 4, корп. 2		0101000020E6100000077DE9EDCFC142406A4FC939B1E34B40
55658	1	\N	\N	1	12534	\N	55.824921000000003	город Москва, САО, район Коптево, Космодемьянских З. и А. ул, дом 33		0101000020E6100000F8A92A3410C342404E64E60297E94B40
55644	1	\N	\N	1	12534	\N	55.824921000000003	Адрес помещения для голосования: город Москва, САО, район Коптево, Космодемьянских З. и А. ул., дом 33, адрес УИК: Космодемьянских З. и А. ул, дом 42		0101000020E6100000F8A92A3410C342404E64E60297E94B40
55588	1	\N	\N	1	12534	\N	55.817470999999998	город Москва, САО, Войковский район, Космодемьянских З. и А. ул, дом 4А		0101000020E6100000F6B704E09FC04240D636C5E3A2E84B40
55587	1	\N	\N	1	12534	\N	55.818012000000003	город Москва, САО, Войковский район, Космодемьянских З. и А. ул, дом 6А		0101000020E6100000C158DFC0E4C0424027DE019EB4E84B40
55580	1	\N	\N	1	12534	\N	55.820162000000003	город Москва, САО, Войковский район, Космодемьянских З. и А. ул, дом 3		0101000020E61000003F1D8F19A8C0424003B68311FBE84B40
56148	1	\N	\N	1	13123	\N	55.801926000000002	город Москва, ВАО, район Преображенское, Знаменская ул, дом 6		0101000020E6100000F2D3B837BFDB4240F3E7DB82A5E64B40
56147	1	\N	\N	1	13123	\N	55.801485	город Москва, ВАО, район Преображенское, Знаменская ул, дом 12/4		0101000020E61000000E15E3FC4DDC4240069E7B0F97E64B40
56074	1	\N	\N	1	12492	\N	55.7034995072529	город Москва, ВАО, район Косино - Ухтомский, Златоустовская ул, дом 3	Россия, Москва, Златоустовская улица, 3с3	0101000020E61000005A2C45F295EE4240355EBA490CDA4B40
57395	1	\N	\N	1	12583	\N	55.7587452689272	город Москва, ЦАО, Басманный район, Земляной вал ул, дом 29		0101000020E61000001EDD088B8AD442407380608E1EE14B40
55450	1	\N	\N	1	12583	\N	55.753570000000003	город Москва, ЦАО, Таганский район, Земляной Вал ул, дом 44А		0101000020E610000085402E71E4D34240959F54FB74E04B40
55499	1	\N	\N	1	2140	\N	55.742119000000002	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Земледельческий пер., дом 20, адрес УИК: Смоленский бульв, дом 17	Россия, Москва, Земледельческий переулок, 20а	0101000020E6100000096F0F4240CA4240C05E61C1FDDE4B40
56146	1	\N	\N	1	1977	\N	55.803919	Адрес помещения для голосования: город Москва, ВАО, район Преображенское, Зельев пер., дом 11, адрес УИК: Знаменская ул, дом 23		0101000020E6100000A1A014ADDCDB424007D15AD1E6E64B40
56134	1	\N	\N	1	1272	\N	55.753903999999999	город Москва, ВАО, район Перово, Зеленый просп, дом 59	Россия, Москва, Зеленый проспект, 59	0101000020E61000006326512FF8E642406B2920ED7FE04B40
56121	1	\N	\N	1	1272	\N	55.749688999999996	город Москва, ВАО, район Перово, Зеленый просп, дом 14	Россия, Москва, Зеленый проспект, 14	0101000020E6100000B134F0A31AE44240E19524CFF5DF4B40
56096	1	\N	\N	1	1272	\N	55.752631999999998	город Москва, ВАО, район Новогиреево, Зеленый просп, дом 75	Россия, Москва, Зеленый проспект, 75	0101000020E6100000F2EF332E1CE8424027F6D03E56E04B40
56249	1	\N	\N	1	3308	\N	55.702556000000001	город Москва, ЮВАО, район Кузьминки, Зеленодольская ул, дом 41, корп. 3	Россия, Москва, Зеленодольская улица, 41к3	0101000020E61000009CF86A4771E24240E6CDE15AEDD94B40
56382	1	\N	\N	1	12757	\N	55.713273000000001	город Москва, ЮВАО, Рязанский район, Зеленодольская ул, дом 7, корп. 4		0101000020E610000022E010AAD4E44240560F98874CDB4B40
56242	1	\N	\N	1	12757	\N	55.711584000000002	город Москва, ЮВАО, район Кузьминки, Зеленодольская ул, дом 32, корп. 6		0101000020E6100000DB4C857824E24240AE2D3C2F15DB4B40
56240	1	\N	\N	1	12757	\N	55.707182000000003	город Москва, ЮВАО, район Кузьминки, Зеленодольская ул, дом 33, корп. 2		0101000020E6100000AB24B20FB2E24240F22895F084DA4B40
56239	1	\N	\N	1	12757	\N	55.707765000000002	город Москва, ЮВАО, район Кузьминки, Зеленодольская ул, дом 33, корп. 3		0101000020E610000061A8C30AB7E242407120240B98DA4B40
55618	1	\N	\N	1	3784	\N	55.864635999999997	город Москва, САО, Головинский район, Зеленоградская ул, дом 9	Россия, Москва, Зеленоградская улица, 9	0101000020E6100000B936548CF3C14240DD787764ACEE4B40
55617	1	\N	\N	1	12511	\N	55.865354535919799	город Москва, САО, Головинский район, Зеленоградская ул, дом 11/52	Россия, Москва, Зеленоградская улица, 11	0101000020E61000001BD5E940D6C142400D37E0F3C3EE4B40
56171	1	\N	\N	1	12399	\N	55.784802615295803	город Москва, ВАО, район Соколиная гора, Зверинецкая ул, дом 25	Россия, Москва, Зверинецкая улица, 25	0101000020E6100000FEB4519D0EDE4240BE66B96C74E44B40
56546	1	\N	\N	1	6784	\N	55.68092	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Затонная ул., дом 7, корп. 3, адрес УИК: Речников ул, дом 18, корп. 2	Россия, Москва, Затонная улица, 7к3	0101000020E61000003541D47D00D842409E98F56228D74B40
56537	1	\N	\N	1	12982	\N	55.68092	Адрес помещения для голосования: город Москва, ЮАО, район Нагатинский затон, Затонная ул., дом 7, корп. 3, адрес УИК: Судостроительная ул, дом 20/2, корп. 1		0101000020E61000003541D47D00D842409E98F56228D74B40
56374	1	\N	\N	1	12733	\N	55.727252	город Москва, ЮВАО, Рязанский район, Зарайская ул, дом 55		0101000020E6100000F148BC3C9DE34240ADF9F19716DD4B40
55938	1	\N	\N	1	13193	\N	55.867050999999996	город Москва, СВАО, район Южное Медведково, Заповедная ул, дом 12		0101000020E6100000B7D0950854D14240677BF486FBEE4B40
55937	1	\N	\N	1	13193	\N	55.867465000000003	город Москва, СВАО, район Южное Медведково, Заповедная ул, дом 22		0101000020E61000003D7C992842D242405BB6D61709EF4B40
56001	1	\N	\N	1	12998	\N	55.819540000000003	Адрес помещения для голосования: город Москва, ВАО, район Восточный, Западная ул., дом 1, адрес УИК: Девятого мая ул, дом 12А		0101000020E61000000C74ED0BE8ED4240C6E1CCAFE6E84B40
56505	1	\N	\N	1	6459	\N	55.620376999999998	город Москва, ЮАО, район Зябликово, Задонский пр, дом 34, корп. 2	Россия, Москва, Задонский проезд, 34к2	0101000020E6100000CB4DD4D2DCE042406518778368CF4B40
56504	1	\N	\N	1	6459	\N	55.620336999999999	город Москва, ЮАО, район Зябликово, Задонский пр, дом 34, корп. 3	Россия, Москва, Задонский проезд, 34к3	0101000020E610000006BB61DBA2E04240D7BFEB3367CF4B40
56438	1	\N	\N	1	5748	\N	55.577989000000002	город Москва, ЮАО, район Бирюлево Восточное, Загорьевский пр, дом 13	Россия, Москва, Загорьевский проезд, 13	0101000020E610000082E15CC30CD742405039268BFBC94B40
56434	1	\N	\N	1	5748	\N	55.574843999999999	город Москва, ЮАО, район Бирюлево Восточное, Загорьевский пр, дом 7, корп. 3	Россия, Москва, Загорьевский проезд, 7к3	0101000020E6100000BB0ED59464D54240A226FA7C94C94B40
56442	1	\N	\N	1	5836	\N	55.583438999999998	город Москва, ЮАО, район Бирюлево Восточное, Загорьевская ул, дом 31	Россия, Москва, Загорьевская улица, 29	0101000020E6100000DDEBA4BE2CD94240001B1021AECA4B40
56474	1	\N	\N	1	2482	\N	55.693804618365	город Москва, ЮАО, Донской район, Загородное шоссе, дом 8А	Россия, Москва, Загородное шоссе, 8кб	0101000020E6100000782634492CCD424090662C9ACED84B40
57326	1	\N	\N	1	76471	\N	55.973112999999998	Адрес помещения для голосования: город Москва, ЗелАО, район Крюково, Зеленоград, корпус 2011, адрес УИК: Зеленоград, корпус 2010	Россия, Москва, Зеленоград, к2011	0101000020E61000002BDA1CE736954240FE277FF78EFC4B40
56229	1	\N	\N	1	3188	\N	55.683894000000002	город Москва, ЮВАО, район Выхино-Жулебино, Жулебинский бульв, дом 38	Россия, Москва, Жулебинский бульвар, 38	0101000020E6100000D9CC21A985EC42401FF7ADD689D74B40
55513	1	\N	\N	1	2349	\N	55.730482000000002	город Москва, ЦАО, район Якиманка, Житная ул, дом 6	Россия, Москва, Житная улица, 6	0101000020E6100000988922A46ECF42408928266F80DD4B40
57250	1	\N	\N	1	7263	\N	55.785077999999999	город Москва, СЗАО, район Хорошево-Мневники, Живописная ул, дом 11, корп. 1	Россия, Москва, Живописная улица, 11к1	0101000020E6100000EE60C43E01BA42409067976F7DE44B40
57264	1	\N	\N	1	12790	\N	55.793013999999999	город Москва, СЗАО, район Щукино, Живописная ул, дом 32, корп. 1		0101000020E6100000342F87DD77BA424094A2957B81E54B40
57251	1	\N	\N	1	12790	\N	55.784972000000003	город Москва, СЗАО, район Хорошево-Мневники, Живописная ул, дом 11, корп. 2		0101000020E610000088F37002D3B942404B2366F679E44B40
57245	1	\N	\N	1	12790	\N	55.780405000000002	город Москва, СЗАО, район Хорошево-Мневники, Живописная ул, дом 2, корп. 2		0101000020E6100000234910AE80BA42404451A04FE4E34B40
56191	1	\N	\N	1	12545	\N	55.784424999999999	город Москва, ВАО, район Сокольники, Жебрунова ул, дом 6		0101000020E6100000E44A3D0B42D742401895D40968E44B40
56251	1	\N	\N	1	3281	\N	55.700547	город Москва, ЮВАО, район Кузьминки, Есенинский бульв, дом 14, корп. 2	Россия, Москва, Есенинский бульвар, 14к2	0101000020E610000001C287122DE34240CC272B86ABD94B40
56237	1	\N	\N	1	3281	\N	55.701034	город Москва, ЮВАО, район Кузьминки, Есенинский бульв, дом 9, корп. 2	Россия, Москва, Есенинский бульвар, 9к2	0101000020E6100000124E0B5EF4E3424029B16B7BBBD94B40
56605	1	\N	\N	1	7465	\N	55.630654999999997	город Москва, ЮАО, район Царицыно, Ереванская ул, дом 21	Россия, Москва, Ереванская улица, 21	0101000020E61000007C7DAD4B8DD642408907944DB9D04B40
56606	1	\N	\N	1	12846	\N	55.628784000000003	город Москва, ЮАО, район Царицыно, Ереванская ул, дом 20, корп. 2		0101000020E61000000B28D4D347D64240C11F7EFE7BD04B40
55778	1	\N	\N	1	12983	\N	55.872193000000003	город Москва, СВАО, Бабушкинский район, Енисейская ул, дом 32, корп. 3	Россия, Москва, Енисейская улица, 32к3	0101000020E610000011C30E63D2D542406B662D05A4EF4B40
56957	1	\N	\N	1	12825	\N	55.740085999999998	город Москва, ЗАО, район Кунцево, Ельнинская ул, дом 24		0101000020E6100000C7293A92CBB542401D1D5723BBDE4B40
56943	1	\N	\N	1	12825	\N	55.736691	город Москва, ЗАО, район Кунцево, Ельнинская ул, дом 10		0101000020E6100000F88DAF3DB3B64240F72004E44BDE4B40
55380	1	\N	\N	1	402	\N	55.772998000000001	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Елоховский пр., дом 1, стр. 5, адрес УИК: Красносельская Нижн, дом 42	Россия, Москва, Елоховский проезд, 1с5	0101000020E6100000C99063EB19D64240CCEF3499F1E24B40
56596	1	\N	\N	1	12430	\N	55.602420480784197	город Москва, ЮАО, район Орехово-Борисово Южное, Елецкая ул, дом 31, корп. 2		0101000020E6100000821DFF0582DE4240693A3B191CCD4B40
56591	1	\N	\N	1	12430	\N	55.606883000000003	город Москва, ЮАО, район Орехово-Борисово Южное, Елецкая ул, дом 12, корп. 3	Россия, Москва, Елецкая улица, 12к3	0101000020E61000002AC93A1C5DDD4240CBBF9657AECD4B40
56199	1	\N	\N	1	2773	\N	55.793140999999999	город Москва, ВАО, район Сокольники, Егерская ул, дом 4	Россия, Москва, Егерская улица, 4	0101000020E6100000280F0BB5A6D74240F10EF0A485E54B40
57148	1	\N	\N	1	13101	\N	55.841458000000003	город Москва, СЗАО, район Митино, Дубравная ул, дом 41, корп. 4		0101000020E6100000DB17D00B77AE4240927A4FE5B4EB4B40
57146	1	\N	\N	1	13101	\N	55.841397000000001	город Москва, СЗАО, район Митино, Дубравная ул, дом 41, корп. 3		0101000020E61000004CFA7B293CAE4240ECF99AE5B2EB4B40
55690	1	\N	\N	1	12667	\N	55.810602000000003	Адрес помещения для голосования: город Москва, САО, район Сокол, Дубосековская ул., дом 4, стр. 1, адрес УИК: Волоколамское шоссе, дом 10		0101000020E61000005167EE21E1BF42403E096CCEC1E74B40
55689	1	\N	\N	1	12667	\N	55.809975000000001	Адрес помещения для голосования: город Москва, САО, район Сокол, Дубосековская ул., дом 3, адрес УИК: Дубосековская ул, дом 5		0101000020E61000009A7CB3CD8DBF4240EFC9C342ADE74B40
55597	1	\N	\N	1	2995	\N	55.881258000000003	город Москва, САО, район Восточное Дегунино, Дубнинская ул, дом 73, корп. 5	Россия, Москва, Дубнинская улица, 73к5с2	0101000020E610000069006F8104C7424050ABE80FCDF04B40
55593	1	\N	\N	1	2995	\N	55.870072	город Москва, САО, район Восточное Дегунино, Дубнинская ул, 18б	Россия, Москва, Дубнинская улица, 18б	0101000020E6100000DD787764ACC842402995F0845EEF4B40
55590	1	\N	\N	1	2995	\N	55.861165999999997	город Москва, САО, район Восточное Дегунино, Дубнинская ул, дом 8а	Россия, Москва, Дубнинская улица, 8а	0101000020E6100000944C4EED0CC94240AC36FFAF3AEE4B40
55566	1	\N	\N	1	2995	\N	55.873677999999998	город Москва, САО, Бескудниковский район, Дубнинская ул, дом 59	Россия, Москва, Дубнинская улица, 59	0101000020E6100000613255302AC742400A9E42AED4EF4B40
88464	6	56	\N	7561	19172	\N	56.613148000000002	город Красноуфимск, Березовая, 6		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
55598	1	\N	\N	1	12807	\N	55.885953000000001	город Москва, САО, район Восточное Дегунино, Дубнинская ул, дом 36а		0101000020E6100000CDE67118CCC7424084656CE866F14B40
55599	1	\N	\N	1	12717	\N	55.891451000000004	город Москва, САО, район Восточное Дегунино, Дубнинская ул, дом 46, корп. 2		0101000020E610000047E7FC14C7C74240467EFD101BF24B40
55592	1	\N	\N	1	12717	\N	55.869309000000001	город Москва, САО, район Восточное Дегунино, Дубнинская ул, дом 18а		0101000020E610000066321CCF67C842402A8F6E8445EF4B40
55591	1	\N	\N	1	12717	\N	55.862175999999998	город Москва, САО, район Восточное Дегунино, Дубнинская ул, дом 21		0101000020E61000007EFCA5457DC84240B3B27DC85BEE4B40
55568	1	\N	\N	1	12717	\N	55.868262999999999	Адрес помещения для голосования: город Москва, САО, Бескудниковский район, Дубнинская ул., дом 41, адрес УИК: Дубнинская ул, дом 31		0101000020E6100000D6E1E82ADDC74240D6A9F23D23EF4B40
55567	1	\N	\N	1	12717	\N	55.868262999999999	город Москва, САО, Бескудниковский район, Дубнинская ул, дом 41		0101000020E6100000D6E1E82ADDC74240D6A9F23D23EF4B40
55399	1	\N	\N	1	12602	\N	55.724235999999998	город Москва, ЦАО, район Замоскворечье, Дубининская ул, дом 42		0101000020E6100000AAEE91CD55D14240FD4AE7C3B3DC4B40
55398	1	\N	\N	1	12602	\N	55.726430999999998	город Москва, ЦАО, район Замоскворечье, Дубининская ул, дом 25		0101000020E61000006B9A779CA2D1424079E6E5B0FBDC4B40
55488	1	\N	\N	1	12540	\N	55.783770674543703	город Москва, ЦАО, Тверской район, Достоевского ул, дом 25	Россия, Москва, улица Достоевского, 25с1	0101000020E61000002E008DD2A5CD4240D046AE9B52E44B40
56655	1	\N	\N	1	12363	\N	55.602446390613103	город Москва, ЮАО, район Чертаново Южное, Дорожная ул, дом 20А		0101000020E61000007842AF3F89CF424092CD55F31CCD4B40
56971	1	\N	\N	1	12930	\N	55.716102999999997	город Москва, ЗАО, Можайский район, Дорогобужская ул, дом 13		0101000020E6100000A5F78DAF3DB54240A3C85A43A9DB4B40
55527	1	\N	\N	1	12908	\N	55.722279	город Москва, ЦАО, район Якиманка, Донская ул, дом 21		0101000020E6100000668522DDCFCD424036CB65A373DC4B40
56312	1	\N	\N	1	13137	\N	55.650728999999998	город Москва, ЮВАО, район Марьино, Донецкая ул, дом 14		0101000020E6100000AF09698D41DB424086C77E164BD34B40
56588	1	\N	\N	1	12422	\N	55.601807751028403	Адрес помещения для голосования: город Москва, ЮАО, район Орехово-Борисово Южное, Домодедовская ул., дом 35, адрес УИК: Каширское шоссе, дом 124, корп. 2	Россия, Москва, Домодедовская улица, 35к2	0101000020E610000069723106D6DB42404F3C670B08CD4B40
56585	1	\N	\N	1	12422	\N	55.600923000000002	город Москва, ЮАО, район Орехово-Борисово Южное, Домодедовская ул, дом 44, корп. 2		0101000020E610000038F6ECB94CDB424005357C0BEBCC4B40
56584	1	\N	\N	1	12422	\N	55.605460000000001	Адрес помещения для голосования: город Москва, ЮАО, район Орехово-Борисово Южное, Домодедовская ул., дом 24, корп. 7, адрес УИК: Домодедовская ул, дом 24, корп. 1	Россия, Москва, Домодедовская улица, 24к7	0101000020E6100000AB92C83EC8DA4240A18499B67FCD4B40
55485	1	\N	\N	1	12589	\N	55.775914999999998	город Москва, ЦАО, Тверской район, Долгоруковская ул, дом 26		0101000020E61000000FEECEDA6DCD4240E8BCC62E51E34B40
57173	1	\N	\N	1	13168	\N	55.830401999999999	город Москва, СЗАО, район Покровское-Стрешнево, Долгова ул, дом 12		0101000020E61000007901F6D1A9B942403944DC9C4AEA4B40
55894	1	\N	\N	1	13233	\N	55.837338000000003	город Москва, СВАО, район Ростокино, Докукина ул, дом 5		0101000020E6100000F435CB65A3D342405AD93EE42DEB4B40
55518	1	\N	\N	1	12704	\N	55.723891000000002	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Доватора ул., дом 5/9, адрес УИК: Пироговская М. ул, дом 25		0101000020E61000003BFBCA83F4C84240336FD575A8DC4B40
55811	1	\N	\N	1	12991	\N	55.814830999999998	город Москва, СВАО, Бутырский район, Добролюбова ул, дом 14		0101000020E610000079060DFD13CC42402C62D8614CE84B40
56630	1	\N	\N	1	12318	\N	55.616747606023502	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Днепропетровская ул., дом 33А, адрес УИК: Чертановская ул, дом 36, корп. 1	Россия, Москва, Днепропетровская улица, 33а	0101000020E610000001E0D8B3E7CA4240CCEF3499F1CE4B40
56629	1	\N	\N	1	12318	\N	55.616741913642201	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Днепропетровская ул., дом 33А, адрес УИК: Чертановская ул, дом 30А	Россия, Москва, Днепропетровская улица, 33а	0101000020E6100000F5824F73F2CA4240EA08E066F1CE4B40
56628	1	\N	\N	1	12318	\N	55.620627814363601	Адрес помещения для голосования: город Москва, ЮАО, район Чертаново Центральное, Днепропетровская ул., дом 25А, адрес УИК: Чертановская ул, дом 30А	Россия, Москва, Днепропетровская улица, 25а	0101000020E6100000684128EFE3CA4240AF7D01BD70CF4B40
56627	1	\N	\N	1	12318	\N	55.620627814363601	город Москва, ЮАО, район Чертаново Центральное, Днепропетровская ул, дом 25А	Россия, Москва, Днепропетровская улица, 25а	0101000020E610000068757286E2CA4240AF7D01BD70CF4B40
56631	1	\N	\N	1	12370	\N	55.616729485273403	город Москва, ЮАО, район Чертаново Центральное, Днепропетровская ул, дом 33А		0101000020E610000017D4B7CCE9CA424055BFD2F9F0CE4B40
57383	1	\N	\N	1	3011	\N	55.926923452094499	город Москва, СВАО, район Северный, Дмитровское ш., 165Е, (к.8), школа №2044	Россия, Москва, Северный район	0101000020E61000006ABE4A3E76C542408274B169A5F64B40
55924	1	\N	\N	1	3011	\N	55.926976158066601	город Москва, СВАО, район Северный, Дмитровское шоссе, дом 165Е, корп. 8	Россия, Москва, Северный район	0101000020E61000000BB6114F76C54240A5164A26A7F64B40
55713	1	\N	\N	1	3011	\N	55.816302999999998	город Москва, САО, Тимирязевский район, Дмитровское шоссе, дом 11	Россия, Москва, Дмитровское шоссе, 11	0101000020E610000027840EBA84C942403750E09D7CE84B40
55710	1	\N	\N	1	3011	\N	55.834238999999997	город Москва, САО, Тимирязевский район, Дмитровское шоссе, дом 45А	Россия, Москва, Дмитровское шоссе, 45к1	0101000020E61000006B9C4D4700C942401C06F357C8EA4B40
56392	1	\N	\N	1	12920	\N	55.712111999999998	город Москва, ЮВАО, район Текстильщики, Волжский бульв, дом 16, корп. 2		0101000020E61000000E4DD9E907DF4240698B6B7C26DB4B40
55704	1	\N	\N	1	3011	\N	55.834238999999997	Адрес помещения для голосования: город Москва, САО, Тимирязевский район, Дмитровское шоссе, дом 45А, адрес УИК: Дмитровское шоссе, дом 33, корп. 1	Россия, Москва, Дмитровское шоссе, 45к1	0101000020E61000006B9C4D4700C942401C06F357C8EA4B40
55624	1	\N	\N	1	3011	\N	55.892308999999997	город Москва, САО, Дмитровский район, Дмитровское шоссе, дом 137А	Россия, Москва, Дмитровское шоссе, 137а	0101000020E6100000F65E7CD11EC5424096766A2E37F24B40
55557	1	\N	\N	1	3011	\N	55.858027999999997	город Москва, САО, Бескудниковский район, Дмитровское шоссе, дом 66	Россия, Москва, Дмитровское шоссе, 66	0101000020E61000008D5F7825C9C74240B1868BDCD3ED4B40
55697	1	\N	\N	1	4784	\N	55.809054000000003	город Москва, САО, Тимирязевский район, Дмитровский пр, дом 10	Россия, Москва, Дмитровский проезд, 10с1	0101000020E61000009C6A2DCC42C942405859DB148FE74B40
56685	1	\N	\N	1	12574	\N	55.690080000000002	город Москва, ЮЗАО, Академический район, Ульянова Дмитрия ул, дом 15		0101000020E61000004A0A2C8029C94240D5CF9B8A54D84B40
56672	1	\N	\N	1	12574	\N	55.684716000000002	город Москва, ЮЗАО, Академический район, Ульянова Дмитрия ул, дом 35		0101000020E610000052BAF42F49CB424023861DC6A4D74B40
56077	1	\N	\N	1	12457	\N	55.710066135224999	город Москва, ВАО, район Косино - Ухтомский, Дмитриевского ул, дом 13	Россия, Москва, улица Дмитриевского, 13	0101000020E6100000F5A276BF0AF2424032005471E3DA4B40
56075	1	\N	\N	1	12457	\N	55.709879999999998	город Москва, ВАО, район Косино - Ухтомский, Дмитриевского ул, дом 5	Россия, Москва, улица Дмитриевского, 5	0101000020E61000002FFB75A73BF14240D00A0C59DDDA4B40
56856	1	\N	\N	1	12873	\N	55.540531000000001	город Москва, ЮЗАО, район Южное Бутово, Джанкойская ул, дом 7		0101000020E610000064744012F6C94240B2BCAB1E30C54B40
56475	1	\N	\N	1	12966	\N	55.720965999999997	город Москва, ЮАО, Даниловский район, Дербеневская ул, дом 13		0101000020E6100000245E9ECE15D3424093C3279D48DC4B40
56923	1	\N	\N	1	13051	\N	55.738717999999999	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Давыдова Дениса ул., дом 5, адрес УИК: Давыдова Дениса ул, дом 7		0101000020E610000087FE092E56C24240B77BB94F8EDE4B40
55486	1	\N	\N	1	12677	\N	55.774749999999997	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Делегатская ул.,  дом 3, адрес УИК: Делегатская ул, дом 14		0101000020E6100000EACA67791ECE4240BA490C022BE34B40
55871	1	\N	\N	1	12853	\N	55.863267	город Москва, СВАО, район Отрадное, Декабристов ул, дом 8, корп. 4		0101000020E6100000AAD4EC8156CC4240A75B76887FEE4B40
55635	1	\N	\N	1	12631	\N	55.867041	город Москва, САО, район Западное Дегунино, Дегунинская ул, дом 17А		0101000020E61000006F46CD57C9C3424044A51133FBEE4B40
55634	1	\N	\N	1	12631	\N	55.866809000000003	город Москва, САО, район Западное Дегунино, Дегунинская ул, дом 18А		0101000020E6100000DFFE5C3464C442407270E998F3EE4B40
55633	1	\N	\N	1	12631	\N	55.864111000000001	город Москва, САО, район Западное Дегунино, Дегунинская ул, дом 2		0101000020E610000053B4722F30C54240938E72309BEE4B40
56137	1	\N	\N	1	12848	\N	55.789487000000001	город Москва, ВАО, район Преображенское, Девятая Рота ул, дом 4		0101000020E6100000B3F0F5B52EDB4240FFCEF6E80DE54B40
56136	1	\N	\N	1	12848	\N	55.791936	Адрес помещения для голосования: город Москва, ВАО, район Преображенское, Девятая Рота ул., дом 14А, адрес УИК: Буженинова ул, дом 22	Россия, Москва, улица Девятая Рота, 14а	0101000020E6100000FE5F75E448DB42403543AA285EE54B40
56476	1	\N	\N	1	6187	\N	55.709246	город Москва, ЮАО, Даниловский район, Даниловская наб, дом 6	Россия, Москва, Даниловская набережная, 6	0101000020E610000063EFC517EDD14240CF68AB92C8DA4B40
57132	1	\N	\N	1	6154	\N	55.725554000000002	город Москва, ЗАО, район Фили-Давыдково, Давыдковская ул, дом 2, корп. 6	Россия, Москва, Давыдковская улица, 2к6	0101000020E61000001E17D522A2BC4240B2BD16F4DEDC4B40
57133	1	\N	\N	1	12990	\N	55.721260000000001	город Москва, ЗАО, район Фили-Давыдково, Давыдковская ул, дом 14, корп. 1		0101000020E610000084BBB376DBBB4240DCF4673F52DC4B40
56362	1	\N	\N	1	12737	\N	55.683945000000001	город Москва, ЮВАО, район Печатники, Гурьянова ул, дом 33		0101000020E6100000DF50F86C1DDC4240A1A17F828BD74B40
56358	1	\N	\N	1	12737	\N	55.688927999999997	город Москва, ЮВАО, район Печатники, Гурьянова ул, дом 15		0101000020E6100000DD96C80567DC42403BA6EECA2ED84B40
56357	1	\N	\N	1	12737	\N	55.693002999999997	город Москва, ЮВАО, район Печатники, Гурьянова ул, дом 2, корп. 6		0101000020E610000018EDF1423ADC4240D3838252B4D84B40
56968	1	\N	\N	1	4209	\N	55.717533000000003	город Москва, ЗАО, Можайский район, Гродненская ул, дом 5	Россия, Москва, Гродненская улица, 5	0101000020E61000001442075DC2B742408066101FD8DB4B40
56983	1	\N	\N	1	13167	\N	55.721680999999997	город Москва, ЗАО, Можайский район, Гришина ул, дом 8, корп. 3		0101000020E610000087C5A86BEDB542408192020B60DC4B40
56804	1	\N	\N	1	12760	\N	55.566985000000003	город Москва, ЮЗАО, район Северное Бутово, Грина ул, дом 18Б		0101000020E6100000B537F8C264CA42404A29E8F692C84B40
56673	1	\N	\N	1	12592	\N	55.687385999999996	город Москва, ЮЗАО, Академический район, Гримау  ул, дом 11а		0101000020E61000008E7406465ECA424037DDB243FCD74B40
56669	1	\N	\N	1	12592	\N	55.690654000000002	город Москва, ЮЗАО, Академический район, Гримау ул, дом 8		0101000020E6100000AF06280D35CA4240016DAB5967D84B40
55922	1	\N	\N	1	12788	\N	55.884590000000003	город Москва, СВАО, район Северное Медведково, Грекова ул, дом 3, корп. 1		0101000020E61000007FC2D9AD65D44240302FC03E3AF14B40
55919	1	\N	\N	1	12788	\N	55.891182999999998	город Москва, СВАО, район Северное Медведково, Грекова ул, дом 20		0101000020E6100000B7D100DE02D5424026E0D74812F24B40
55917	1	\N	\N	1	12788	\N	55.890618000000003	город Москва, СВАО, район Северное Медведково, Грекова ул, дом 11А		0101000020E61000004012F6ED24D442404E9D47C5FFF14B40
55915	1	\N	\N	1	12788	\N	55.890563	город Москва, СВАО, район Северное Медведково, Грекова ул, дом 11Б		0101000020E6100000B54E5C8E57D442408A03E8F7FDF14B40
56385	1	\N	\N	1	12390	\N	55.721727816333399	город Москва, ЮВАО, район Текстильщики, Грайвороново квартал 90А, корп. 12	Россия, Москва, Грайвороново квартал 90А, к12	0101000020E610000094D920938CDE4240C24D469561DC4B40
57378	1	\N	\N	1	6460	\N	55.845217426384799	город Москва, СВАО, район Марфино, улица Гостиничная, дом№8, , в помещении школы №278	Россия, Москва, Гостиничная улица, 8к1	0101000020E6100000AD2F12DA72CA4240F982161230EC4B40
55845	1	\N	\N	1	13178	\N	55.846972000000001	город Москва, СВАО, район Марфино, Гостиничная ул, дом 8		0101000020E6100000F241CF66D5C942405950189469EC4B40
55388	1	\N	\N	1	12599	\N	55.774780999999997	город Москва, ЦАО, Басманный район, Госпитальный вал ул, дом 5, корп. 18		0101000020E6100000768D96033DDA4240F54718062CE34B40
55387	1	\N	\N	1	12599	\N	55.773763000000002	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Госпитальный вал ул., дом 5, корп.19, адрес УИК: Госпитальный вал ул, дом 5, корп.1		0101000020E6100000E7E26F7B82DA42406CED7DAA0AE34B40
55389	1	\N	\N	1	526	\N	55.771701999999998	город Москва, ЦАО, Басманный район, Госпитальная наб, дом 4/2	Россия, Москва, Госпитальная набережная, 4с2	0101000020E61000003737A6272CD94240FF209221C7E24B40
56877	1	\N	\N	1	13037	\N	55.544749000000003	город Москва, ЮЗАО, район Южное Бутово, Горчакова ул, дом 9, корп. 1		0101000020E6100000ECA012D731C44240ADC3D155BAC54B40
55373	1	\N	\N	1	306	\N	55.763416999999997	город Москва, ЦАО, Басманный район, Гороховский пер, дом 4	Россия, Москва, Гороховский переулок, 4	0101000020E61000004C6DA983BCD44240EF1AF4A5B7E14B40
56975	1	\N	\N	1	12636	\N	55.723764125946097	город Москва, ЗАО, Можайский район, Горбунова ул, дом 10		0101000020E6100000CC28965B5AB14240D6027B4CA4DC4B40
55810	1	\N	\N	1	12915	\N	55.817667999999998	город Москва, СВАО, Бутырский район, Гончарова ул, дом 15Б		0101000020E610000033C51C041DCB42402C7E5358A9E84B40
56890	1	\N	\N	1	12973	\N	55.601410999999999	город Москва, ЮЗАО, район Ясенево, Голубинская ул, дом 21, корп. 3		0101000020E6100000357D76C075C34240323A2009FBCC4B40
56888	1	\N	\N	1	12973	\N	55.605536000000001	город Москва, ЮЗАО, район Ясенево, Голубинская ул, дом 5, корп. 3		0101000020E6100000B77C24253DC242407C46223482CD4B40
56909	1	\N	\N	1	12713	\N	55.594025999999999	город Москва, ЮЗАО, район Ясенево, Голубинская ул, дом 28, корп. 2		0101000020E6100000F564FED137C54240A27C410B09CC4B40
56905	1	\N	\N	1	12713	\N	55.600088999999997	город Москва, ЮЗАО, район Ясенево, Голубинская ул, дом 23, корп. 3		0101000020E6100000C2137AFD49C442403CD862B7CFCC4B40
56889	1	\N	\N	1	12713	\N	55.606543000000002	город Москва, ЮЗАО, район Ясенево, Голубинская ул, дом 5, корп. 2		0101000020E61000004450357A35C24240124F7633A3CD4B40
56887	1	\N	\N	1	12713	\N	55.604579999999999	город Москва, ЮЗАО, район Ясенево, Голубинская ул, дом 5, корп. 4		0101000020E61000001DC70F9546C2424068E89FE062CD4B40
55858	1	\N	\N	1	12552	\N	55.808655000000002	город Москва, СВАО, Останкинский район, Годовикова ул, дом 16А		0101000020E610000074EFE192E3D042409A5FCD0182E74B40
55856	1	\N	\N	1	12552	\N	55.803591319484902	город Москва, СВАО, Останкинский район, Годовикова ул, дом 4	Россия, Москва, улица Годовикова, 4с1	0101000020E6100000CCD24ECDE5D04240122EE411DCE64B40
56848	1	\N	4266	1	13127	\N	55.718374986918001	город Москва, ЗАО, Можайский район, Говорова ул, дом 7	Россия, Москва, улица Говорова, 7	0101000020E61000006092CA1473B24240CBA145B6F3DB4B40
55423	1	\N	\N	1	1060	\N	55.787508000000003	город Москва, ЦАО, Мещанский район, Глинистый пер, дом 7	Россия, Москва, Глинистый переулок, 7с1	0101000020E61000000954FF2092D1424050ABE80FCDE44B40
55964	1	\N	\N	1	7677	\N	55.813288	город Москва, ВАО, район Богородское, Глебовская ул, дом 10, стр. 1	Россия, Москва, Глебовская улица, 10	0101000020E6100000F9A1D28899DB4240581D39D219E84B40
55414	1	\N	\N	1	13203	\N	55.777459	город Москва, ЦАО, Мещанский район, Гиляровского ул, дом 21		0101000020E6100000F6B704E09FD042408D7DC9C683E34B40
56967	1	\N	4266	1	12926	\N	55.517209999999999	город Москва, ЗАО, Можайский район, Гжатская ул, дом 6		0101000020E6100000CD3CB9A6400442400395F1EF33C24B40
57188	1	\N	\N	1	13009	\N	55.855511999999997	город Москва, СЗАО, район Северное Тушино, Героев Панфиловцев ул, дом 13, корп. 2		0101000020E6100000E8F7FD9B17B74240F3AACE6A81ED4B40
57187	1	\N	\N	1	13009	\N	55.856693999999997	город Москва, СЗАО, район Северное Тушино, Героев Панфиловцев ул, дом 15		0101000020E61000003BFC3559A3B64240F7562426A8ED4B40
57179	1	\N	\N	1	13009	\N	55.852798999999997	город Москва, СЗАО, район Северное Тушино, Героев Панфиловцев ул, дом 45, корп. 3		0101000020E61000005264ADA1D4B44240DF87838428ED4B40
57126	1	\N	\N	1	13062	\N	55.732675999999998	город Москва, ЗАО, район Фили-Давыдково, Курина Герасима ул, дом 10		0101000020E6100000910C39B69EBD42403448C153C8DD4B40
56818	1	\N	\N	1	12467	\N	55.621149181145597	город Москва, ЮЗАО, район Теплый Стан, Тюленева генерала ул, дом 19, корп. 2	Россия, Москва, улица Генерала Тюленева, 19	0101000020E6100000D7DAFB5415BE4240B87878CF81CF4B40
56817	1	\N	\N	1	12467	\N	55.621118825191999	Город Москва, ЮЗАО, район Теплый Стан, Тюленева генерала ул, дом 19,  корп. 2	Россия, Москва, улица Генерала Тюленева, 19	0101000020E6100000CF30B5A50EBE42404DF6CFD380CF4B40
57246	1	\N	\N	1	13179	\N	55.781939000000001	город Москва, СЗАО, район Хорошево-Мневники, Глаголева генерала ул, дом 9, корп. 2		0101000020E61000008AE3C0ABE5BA4240C53BC09316E44B40
57144	1	\N	\N	1	13220	\N	55.832171000000002	город Москва, СЗАО, район Митино, Белобородова генерала ул, дом 22		0101000020E610000076E107E753AD4240FED64E9484EA4B40
56733	1	\N	\N	1	12727	\N	55.643444000000002	город Москва, ЮЗАО, район Коньково, Антонова генерала ул, дом 4 А		0101000020E610000078B471C45AC442405A677C5F5CD24B40
56732	1	\N	\N	1	12727	\N	55.645705	Адрес помещения для голосования: город Москва, ЮЗАО, район Коньково, Антонова генерала ул., дом 5 А, адрес УИК: Антонова генерала ул, дом 5, корп. 3, кв. 75		0101000020E610000094A5D6FB8DC442408DEE2076A6D24B40
56731	1	\N	\N	1	12727	\N	55.645705	город Москва, ЮЗАО, район Коньково, Антонова генерала ул, дом 5 А		0101000020E610000094A5D6FB8DC442408DEE2076A6D24B40
56984	1	\N	\N	1	13166	\N	55.724747999999998	город Москва, ЗАО, Можайский район, Гвардейская ул, дом 15, корп. 2		0101000020E610000050560C5707B64240B3EBDE8AC4DC4B40
56193	1	\N	\N	1	12740	\N	55.785953999999997	город Москва, ВАО, район Сокольники, Гастелло ул, дом 3		0101000020E61000003E096CCEC1D74240871403249AE44B40
56832	1	\N	\N	1	12934	\N	55.672600000000003	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Гарибальди ул., дом 19, адрес УИК: Власова архитектора ул, дом 25, корп. 2		0101000020E6100000101FD8F15FC6424012A5BDC117D64B40
56782	1	\N	\N	1	12934	\N	55.66995	город Москва, ЮЗАО, Обручевский район, Гарибальди ул, дом 28, корп. 3		0101000020E6100000B1DCD26A48C6424044FAEDEBC0D54B40
56779	1	\N	\N	1	12934	\N	55.674585	город Москва, ЮЗАО, Ломоносовский район, Гарибальди ул, дом 8, корп. 1		0101000020E6100000C269C18BBEC44240A3AF20CD58D64B40
57269	1	\N	\N	1	12715	\N	55.799228999999997	город Москва, СЗАО, район Щукино, Гамалеи ул, дом 17		0101000020E61000008B70935165BA4240E481C8224DE64B40
56661	1	\N	\N	1	12476	\N	55.590848363632901	город Москва, ЮАО, район Чертаново Южное, Газопровод ул, дом 9А	Россия, Москва, улица Газопровод, 9а	0101000020E610000096B20C71ACCD4240197442E8A0CB4B40
57169	1	\N	\N	1	12633	\N	55.815833875511103	город Москва, СЗАО, район Покровское-Стрешнево, Габричевского ул, дом 8, корп. 1	Россия, Москва, улица Габричевского, 8	0101000020E6100000C4EE3B86C7BA4240817B9E3F6DE84B40
55677	1	\N	\N	1	4574	\N	55.797801999999997	город Москва, САО, Савеловский район, Вятская ул, дом 29/31	Россия, Москва, Вятская улица, 29	0101000020E610000068CEFA9463CA424079573D601EE64B40
56972	1	\N	\N	1	13226	\N	55.712694999999997	город Москва, ЗАО, Можайский район, Вяземская ул, дом 7		0101000020E610000042B5C189E8B34240E882FA9639DB4B40
56519	1	\N	\N	1	13043	\N	55.679051999999999	город Москва, ЮАО, район Нагатино-Садовники, Высокая ул, дом 6		0101000020E610000019FF3EE3C2D3424046240A2DEBD64B40
55699	1	\N	\N	1	12864	\N	55.808447000000001	город Москва, САО, Тимирязевский район, Вучетича ул, дом 6		0101000020E6100000F48C7DC9C6C7424050C6F8307BE74B40
55698	1	\N	\N	1	12864	\N	55.806190999999998	город Москва, САО, Тимирязевский район, Вучетича ул, дом 3/1		0101000020E61000008D429259BDC742402EAA454431E74B40
55687	1	\N	\N	1	12854	\N	55.804763999999999	город Москва, САО, район Сокол, Врубеля ул, дом 12		0101000020E6100000B9718BF9B9BF4240C37FBA8102E74B40
57170	1	\N	\N	1	6494	\N	55.813642000000002	Адрес помещения для голосования: город Москва, СЗАО, район Покровское-Стрешнево, Врачебный пр., дом 12, адрес УИК: Габричевского ул, дом 8, корп. 1	Россия, Москва, Врачебный проезд, 12	0101000020E610000092B1DAFCBFBA42407653CA6B25E84B40
57168	1	\N	\N	1	6494	\N	55.813642000000002	город Москва, СЗАО, район Покровское-Стрешнево, Врачебный пр, дом 12	Россия, Москва, Врачебный проезд, 12	0101000020E610000092B1DAFCBFBA42407653CA6B25E84B40
57167	1	\N	\N	1	6494	\N	55.813642000000002	Адрес помещения для голосования: город Москва, СЗАО, район Покровское-Стрешнево, Врачебный пр., дом 12, адрес УИК: Полесский пр, дом 4, корп. 2		0101000020E610000092B1DAFCBFBA42407653CA6B25E84B40
56457	1	\N	\N	1	5931	\N	55.583500000000001	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Востряковский пр., дом 5Б, адрес УИК: Востряковский пр, дом 3А		0101000020E61000005376FA415DD24240A69BC420B0CA4B40
56456	1	\N	\N	1	5931	\N	55.583500000000001	город Москва, ЮАО, район Бирюлево Западное, Востряковский пр, дом 5Б	Россия, Москва, Востряковский проезд, 5б	0101000020E61000005376FA415DD24240A69BC420B0CA4B40
56455	1	\N	\N	1	5931	\N	55.583500000000001	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Востряковский пр., дом 5Б, адрес УИК: Востряковский пр, дом 5, корп. 1		0101000020E61000005376FA415DD24240A69BC420B0CA4B40
56453	1	\N	\N	1	5931	\N	55.577739000000001	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Востряковский пр., дом 13А, адрес УИК: Булатниковская ул, дом 5, корп. 2	Россия, Москва, Востряковский проезд, 13а	0101000020E610000065726A6798D24240D74FFF59F3C94B40
56452	1	\N	\N	1	5931	\N	55.577739000000001	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Востряковский пр., дом 13А, адрес УИК: Востряковский пр, дом 25, корп. 2	Россия, Москва, Востряковский проезд, 13а	0101000020E610000065726A6798D24240D74FFF59F3C94B40
56479	1	\N	\N	1	12783	\N	55.713892000000001	Адрес помещения для голосования: город Москва, ЮАО, Даниловский район, Восточная ул., дом 4, адрес УИК: Ленинская слобода ул, дом 4		0101000020E6100000749A05DA1DD44240227024D060DB4B40
56478	1	\N	\N	1	12783	\N	55.713892000000001	Адрес помещения для голосования: город Москва, ЮАО, Даниловский район, Восточная ул., дом 4, адрес УИК: Восточная ул, дом 7		0101000020E6100000749A05DA1DD44240227024D060DB4B40
56601	1	\N	\N	1	12424	\N	55.608811000000003	город Москва, ЮАО, район Орехово-Борисово Южное, Воронежская ул, дом 46, корп. 3	Россия, Москва, Воронежская улица, 46к3	0101000020E61000000798F90E7EE04240F838D384EDCD4B40
56600	1	\N	\N	1	12424	\N	55.608750000000001	город Москва, ЮАО, район Орехово-Борисово Южное, Воронежская ул, дом 46, корп. 2		0101000020E610000032022A1C41E0424052B81E85EBCD4B40
56598	1	\N	\N	1	12424	\N	55.609445999999998	город Москва, ЮАО, район Орехово-Борисово Южное, Воронежская ул, дом 44, корп. 2	Россия, Москва, Воронежская улица, 44к2	0101000020E61000003F8EE6C8CADF4240C956975302CE4B40
56593	1	\N	\N	1	12424	\N	55.6083053668536	город Москва, ЮАО, район Орехово-Борисово Южное, Воронежская ул, дом 26, корп. 4		0101000020E61000009161156F64DE4240247F30F0DCCD4B40
56590	1	\N	\N	1	12424	\N	55.610631327797499	город Москва, ЮАО, район Орехово-Борисово Южное, Воронежская ул, дом 7, корп. 2	Россия, Москва, Воронежская улица, 7к2	0101000020E6100000E4F90CA837DD42403E76172829CE4B40
56266	1	\N	\N	1	12952	\N	55.755986	город Москва, ЮВАО, район Лефортово, Волочаевская ул, дом 14А		0101000020E610000057276728EED64240EF1D3526C4E04B40
57143	1	\N	\N	1	6268	\N	55.832551000000002	город Москва, СЗАО, район Митино, Волоцкой пер, дом 15, корп. 2	Россия, Москва, Волоцкой переулок, 15к2	0101000020E6100000EBC726F911AD424045A0FA0791EA4B40
56061	1	\N	\N	1	13121	\N	55.791997000000002	город Москва, ВАО, район Измайлово, Парковая 6-я ул, дом 19		0101000020E6100000FA62EFC517E54240DBC35E2860E54B40
56387	1	\N	\N	1	12920	\N	55.717517572235998	город Москва, ЮВАО, район Текстильщики, Волжский бульв, дом 6, корп. 3	Россия, Москва, Волжский Бульвар квартал 114А, Волжский бульвар, 6к3	0101000020E6100000BEF8A23D5EDE42404A253CA1D7DB4B40
56386	1	\N	\N	1	12920	\N	55.717174270918598	город Москва, ЮВАО, район Текстильщики, Волжский бульв, дом 6, корп. 4	Россия, Москва, Волжский Бульвар квартал 114А, Волжский бульвар, 6к4	0101000020E61000002BA391CF2BDE424050C58D5BCCDB4B40
56255	1	\N	\N	1	1529	\N	55.703966000000001	город Москва, ЮВАО, район Кузьминки, Волгоградский просп, дом 74, корп. 4	Россия, Москва, Волгоградский проспект, 74к4	0101000020E6100000AAEE91CD55E142407BBFD18E1BDA4B40
56254	1	\N	\N	1	1529	\N	55.704889000000001	город Москва, ЮВАО, район Кузьминки, Волгоградский просп, дом 58, корп. 4	Россия, Москва, Волгоградский проспект, 58к4	0101000020E6100000A45181936DE04240B32781CD39DA4B40
56246	1	\N	\N	1	1529	\N	55.705168	город Москва, ЮВАО, район Кузьминки, Волгоградский просп, дом 157, корп. 3	Россия, Москва, Волгоградский проспект, 157к3	0101000020E6100000D449B6BA9CE44240C617EDF142DA4B40
56245	1	\N	\N	1	1529	\N	55.705387000000002	город Москва, ЮВАО, район Кузьминки, Волгоградский просп, дом 157, корп. 4	Россия, Москва, Волгоградский проспект, 157к4	0101000020E61000002CB81FF0C0E442400403081F4ADA4B40
56238	1	\N	\N	1	1529	\N	55.709038	город Москва, ЮВАО, район Кузьминки, Волгоградский просп, дом 109, корп. 6	Россия, Москва, Волгоградский проспект, 109к6	0101000020E6100000776682E15CE1424085CFD6C1C1DA4B40
56236	1	\N	\N	1	1529	\N	55.709541000000002	город Москва, ЮВАО, район Кузьминки, Волгоградский просп, дом 103, корп. 6	Россия, Москва, Волгоградский проспект, 103к6	0101000020E6100000711FB935E9E04240E8154F3DD2DA4B40
57172	1	\N	\N	1	12999	\N	55.829738999999996	город Москва, СЗАО, район Покровское-Стрешнево, Вишневая ул, дом 7		0101000020E61000008179C8940FB942409D9B36E334EA4B40
56753	1	\N	\N	1	13152	\N	55.684828000000003	город Москва, ЮЗАО, район Котловка, Винокурова ул, дом 19		0101000020E6100000221B48179BCC42404BB1A371A8D74B40
56886	1	\N	\N	1	12796	\N	55.597943000000001	город Москва, ЮЗАО, район Ясенево, Вильнюсская ул, дом 14		0101000020E610000097AAB4C535C24240A2EF6E6589CC4B40
56884	1	\N	\N	1	12796	\N	55.599077000000001	город Москва, ЮЗАО, район Ясенево, Вильнюсская ул, дом 12		0101000020E6100000AA9A20EA3EC2424095641D8EAECC4B40
57388	1	\N	\N	1	12564	\N	55.859784594114998	город Москва, СЗАО, район Северное Тушино, ул. Вилиса Лациса, 33 (к.2), школа № 1399	Россия, Москва, улица Вилиса Лациса, 31к2	0101000020E6100000294014CC98B44240B24B546F0DEE4B40
57185	1	\N	\N	1	12564	\N	55.862473999999999	город Москва, СЗАО, район Северное Тушино, Лациса Вилиса ул, дом 11, корп. 2		0101000020E6100000C2FBAA5CA8B642403DD34B8C65EE4B40
57184	1	\N	\N	1	12564	\N	55.861125000000001	город Москва, СЗАО, район Северное Тушино, Лациса Вилиса ул, дом 23, корп. 3		0101000020E61000005951836918B642404E62105839EE4B40
57183	1	\N	\N	1	12564	\N	55.863191999999998	город Москва, СЗАО, район Северное Тушино, Лациса Вилиса ул, дом 21		0101000020E610000066101FD8F1B542409C1551137DEE4B40
57182	1	\N	\N	1	12564	\N	55.858589000000002	город Москва, СЗАО, район Северное Тушино, Лациса Вилиса ул, дом 33, корп. 2		0101000020E6100000B43D7AC37DB4424049DA8D3EE6ED4B40
55979	1	\N	\N	1	12729	\N	55.722816000000002	город Москва, ВАО, район Вешняки, Вешняковская ул, дом 29Д		0101000020E6100000AE635C7171EA42404583143C85DC4B40
55975	1	\N	\N	1	12729	\N	55.736649999999997	город Москва, ВАО, район Вешняки, Вешняковская ул, дом 2А		0101000020E6100000FC8A355CE4E84240984C158C4ADE4B40
56607	1	\N	\N	1	12841	\N	55.624178999999998	город Москва, ЮАО, район Царицыно, Веселая ул, дом 12		0101000020E6100000419B1C3EE9D44240CCECF318E5CF4B40
56066	1	\N	\N	1	500	\N	55.798656999999999	город Москва, ВАО, район Измайлово, Первомайская верх. ул, дом 32	Россия, Москва, Верхняя Первомайская улица, 32	0101000020E6100000B0C6D97404E6424059DC7F643AE64B40
56064	1	\N	\N	1	12852	\N	55.800524602155598	город Москва, ВАО, район Измайлово, Первомайская верх. ул, дом 47	Россия, Москва, Верхняя Первомайская улица, 47	0101000020E6100000BD3AC780ECE54240B1506B9A77E64B40
56053	1	\N	\N	1	12852	\N	55.800403000000003	город Москва, ВАО, район Измайлово, Первомайская верх. ул, дом 23А		0101000020E6100000F4F8BD4D7FE44240664F029B73E64B40
56045	1	\N	\N	1	12852	\N	55.799401000000003	город Москва, ВАО, район Измайлово, Первомайская верх. ул, дом 7		0101000020E61000006F8099EFE0E34240E2B19FC552E64B40
55671	1	\N	\N	1	12939	\N	55.798023999999998	город Москва, САО, Савеловский район, Масловка Верх. ул, дом 26		0101000020E6100000D7A19A92ACC7424028B682A625E64B40
55408	1	\N	\N	1	820	\N	55.783315999999999	город Москва, ЦАО, Красносельский район, Красносельская Верх. ул, дом 14А	Россия, Москва, Верхняя Красносельская улица, 14а	0101000020E6100000DA3A38D89BD442407E37DDB243E44B40
55409	1	\N	\N	1	12646	\N	55.785417000000002	город Москва, ЦАО, Красносельский район, Красносельская Верх. ул, дом 7А		0101000020E6100000467C2766BDD44240795C548B88E44B40
56265	1	\N	\N	1	3634	\N	55.750388000000001	город Москва, ЮВАО, район Лефортово, Золоторожский верх. пер, дом 2	Россия, Москва, Верхний Золоторожский переулок, 2	0101000020E61000002A90D959F4D64240CAA7C7B60CE04B40
56343	1	\N	\N	1	12645	\N	55.665345000000002	город Москва, ЮВАО, район Марьино, Верхние поля ул, дом 40, корп. 2		0101000020E6100000BE4D7FF623E3424050C763062AD54B40
56338	1	\N	\N	1	12645	\N	55.666547999999999	город Москва, ЮВАО, район Марьино, Верхние поля ул, дом 30		0101000020E6100000DA56B3CEF8E042406B9BE27151D54B40
56302	1	\N	\N	1	12645	\N	55.667310000000001	город Москва, ЮВАО, район Люблино, Верхние поля ул, дом 15, корп. 2		0101000020E61000006534F279C5DF42409A25016A6AD54B40
57017	1	\N	\N	1	4681	\N	55.707698999999998	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Веерная ул., дом 5, корп. 3, адрес УИК: Нежинская ул, дом 13	Россия, Москва, Веерная улица, 5к3	0101000020E61000003C122F4FE7BC4240B9347EE195DA4B40
55641	1	\N	\N	1	12555	\N	55.883600000000001	город Москва, САО, район Западное Дегунино, Бусиновская  горка ул, дом 7А		0101000020E61000001421753BFBBE4240705F07CE19F14B40
57016	1	\N	\N	1	12699	\N	55.707698999999998	Адрес помещения для голосования: город Москва, ЗАО, район Очаково-Матвеевское, Веерная ул., дом 5, корп. 3, адрес УИК: Веерная ул, дом 3, корп.2		0101000020E61000003C122F4FE7BC4240B9347EE195DA4B40
57015	1	\N	\N	1	12699	\N	55.714171	город Москва, ЗАО, район Очаково-Матвеевское, Веерная ул, дом 38, корп. 2		0101000020E6100000569929ADBFBD4240356090F469DB4B40
57006	1	\N	\N	1	12699	\N	55.708942	город Москва, ЗАО, район Очаково-Матвеевское, Веерная ул, дом 5А		0101000020E61000003D0CAD4ECEBC42406361889CBEDA4B40
56741	1	\N	\N	1	12909	\N	55.636361000000001	город Москва, ЮЗАО, район Коньково, Введенского ул, дом 28		0101000020E6100000D0D2156C23C4424095B9F94674D14B40
56738	1	\N	\N	1	12909	\N	55.634065	город Москва, ЮЗАО, район Коньково, Введенского ул, дом 27 А		0101000020E61000004819710168C44240E544BB0A29D14B40
56371	1	\N	\N	1	4963	\N	55.716346000000001	город Москва, ЮВАО, Рязанский район, Васильцовский пер, дом 1	Россия, Москва, Васильцовский переулок, 1	0101000020E6100000DB6AD619DFDF42406A4FC939B1DB4B40
56373	1	\N	\N	1	12734	\N	55.713248	город Москва, ЮВАО, Рязанский район, Васильцовский стан ул, дом 4		0101000020E61000007E8E8F1667E04240FDF7E0B54BDB4B40
56372	1	\N	\N	1	12734	\N	55.714652999999998	город Москва, ЮВАО, Рязанский район, Васильцовский стан ул, дом 6		0101000020E6100000056B9C4D47E04240807EDFBF79DB4B40
55431	1	\N	\N	1	13212	\N	55.771873999999997	Адрес помещения для голосования: город Москва, ЦАО, Пресненский район, Васильевская ул., дом 13, адрес УИК: Васильевская ул, дом 2, стр. 6		0101000020E6100000657094BC3ACB4240FC5069C4CCE24B40
57290	1	\N	\N	1	13199	\N	55.839289000000001	город Москва, СЗАО, район Южное Тушино, Василия Петушкова ул, дом 23, корп. 1		0101000020E61000001DC9E53FA4B342403F726BD26DEB4B40
56945	1	\N	\N	1	12919	\N	55.786199243497599	Адрес помещения для голосования: город Москва, ЗАО, район Кунцево, Ботылева Василия ул., дом 31, адрес УИК: Советская ул, дом 11А	Россия, Москва, поселок Рублево, улица Василия Ботылева, 31	0101000020E61000003D0B42791FAD4240EF92382BA2E44B40
56663	1	\N	\N	1	6344	\N	55.587645999999999	город Москва, ЮАО, район Чертаново Южное, Варшавское шоссе, дом 156Б	Россия, Москва, Варшавское шоссе, 156б	0101000020E6100000CC608C4814CC424007D0EFFB37CB4B40
56662	1	\N	\N	1	6344	\N	55.636142999999997	город Москва, ЮАО, район Чертаново Южное, Варшавское шоссе, дом 143, корп. 6		0101000020E6100000DB4C857824CC4240274A42226DD14B40
56653	1	\N	\N	1	6344	\N	55.591670999999998	город Москва, ЮАО, район Чертаново Южное, Варшавское шоссе, дом 152, корп. 10	Россия, Москва, Варшавское шоссе, 152к10	0101000020E6100000645C717154CC4240ED7E15E0BBCB4B40
56617	1	\N	\N	1	6344	\N	55.624754446755098	город Москва, ЮАО, район Чертаново Северное, Варшавское шоссе, дом 126А	Россия, Москва, Варшавское шоссе, 126а	0101000020E6100000F2B391EBA6CE4240C90567F0F7CF4B40
56561	1	\N	\N	1	6344	\N	55.656539000000002	город Москва, ЮАО, Нагорный район, Варшавское шоссе, дом 81, корп. 2	Россия, Москва, Варшавское шоссе, 81к2	0101000020E6100000DA1A118C83CF424037C64E7809D44B40
56559	1	\N	\N	1	6344	\N	55.657899999999998	город Москва, ЮАО, Нагорный район, Варшавское шоссе, дом 70, корп. 1	Россия, Москва, Варшавское шоссе, 70к1	0101000020E61000000762D9CC21CF4240EA04341136D44B40
56492	1	\N	\N	1	6344	\N	55.697184	город Москва, ЮАО, Донской район, Варшавское шоссе, дом 12	Россия, Москва, Варшавское шоссе, 12	0101000020E610000052EE3EC747CF4240B1A547533DD94B40
55664	1	\N	\N	1	4385	\N	55.868181999999997	Адрес помещения для голосования: город Москва, САО, Левобережный район, Валдайский пр., дом 14, адрес УИК: Валдайский пр, дом 10, корп. 1		0101000020E610000009C1AA7AF9BB4240E97C789620EF4B40
55663	1	\N	\N	1	4385	\N	55.865918999999998	город Москва, САО, Левобережный район, Валдайский пр, дом 8	Россия, Москва, Валдайский проезд, 8	0101000020E6100000CD203EB0E3BB424015FE0C6FD6EE4B40
55491	1	\N	\N	1	2028	\N	55.790539000000003	город Москва, ЦАО, Тверской район, Вадковский пер, дом 3	Россия, Москва, Вадковский переулок, 3	0101000020E61000004FAC53E57BCC4240359BC76130E54B40
55626	1	\N	\N	1	3914	\N	55.896402999999999	город Москва, САО, Дмитровский район, Вагоноремонтная ул, дом 15А	Россия, Москва, Вагоноремонтная улица, 15а	0101000020E610000073A087DA36C44240A5846055BDF24B40
56775	1	\N	\N	1	12509	\N	55.677798000000003	Адрес места голосования: город Москва, ЮЗАО, Ломоносовский район, Вавилова ул., дом 84, корп. 2, адрес УИК: Панферова ул, дом 20		0101000020E61000000A0F9A5DF7C44240A9A5B915C2D64B40
56703	1	\N	\N	1	12509	\N	55.693972000000002	город Москва, ЮЗАО, Гагаринский район, Вавилова ул, дом 44, корп. 2		0101000020E6100000E5D3635B06C842407C2B1213D4D84B40
56686	1	\N	\N	1	12509	\N	55.695864999999998	Адрес помещения для голосования: город Москва, ЮЗАО, Академический район, Вавилова ул., дом 25, корп. 1, адрес УИК: Вавилова ул, дом 37а		0101000020E6100000A06EA0C03BC942402CB7B41A12D94B40
56684	1	\N	\N	1	12509	\N	55.695864999999998	Адрес помещения для голосования: город Москва, ЮЗАО, Академический район, Вавилова ул., дом 25, корп. 1, адрес УИК: Вавилова ул, дом 51		0101000020E6100000A06EA0C03BC942402CB7B41A12D94B40
56665	1	\N	\N	1	12509	\N	55.701855999999999	город Москва, ЮЗАО, Академический район, Вавилова ул, дом 17		0101000020E6100000AC3C81B053CA42402D40DB6AD6D94B40
56488	1	\N	\N	1	12509	\N	55.704498999999998	город Москва, ЮАО, Донской район, Вавилова ул, дом 5А		0101000020E61000001F48DE3994CB42404888F2052DDA4B40
56735	1	\N	\N	1	13146	\N	55.641675999999997	Адрес помещения для голосования: город Москва, ЮЗАО, район Коньково, Бутлерова ул., дом 38 А, адрес УИК: Бутлерова ул, дом 40, корп. 1		0101000020E6100000732CEFAA07C6424065506D7022D24B40
56724	1	\N	\N	1	13146	\N	55.654599702320702	город Москва, ЮЗАО, район Коньково, Бутлерова ул, дом 3	Россия, Москва, улица Бутлерова, 3	0101000020E6100000710168942EC3424016FBCBEEC9D34B40
55642	1	\N	\N	1	12555	\N	55.883134385140899	город Москва, САО, район Западное Дегунино, Бусиновская горка ул, дом 7А		0101000020E610000013B9E00CFEBE42402AFEEF880AF14B40
56451	1	\N	\N	1	5912	\N	55.577139000000003	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Западное, Булатниковская ул., дом 1А, адрес УИК: Востряковский пр, дом 25, корп. 2	Россия, Москва, Булатниковская улица, 1а	0101000020E6100000003B376DC6D34240821FD5B0DFC94B40
56450	1	\N	\N	1	12859	\N	55.577139000000003	город Москва, ЮАО, район Бирюлево Западное, Булатниковская ул, дом 1А		0101000020E6100000003B376DC6D34240821FD5B0DFC94B40
56178	1	\N	\N	1	12367	\N	55.775170888180398	город Москва, ВАО, район Соколиная гора, Буденного просп, дом 15А	Россия, Москва, Вольная улица, 4с3	0101000020E61000003CA41820D1DC424060E7A6CD38E34B40
56916	1	\N	\N	1	12806	\N	55.745199	город Москва, ЗАО, район Дорогомилово, Брянская ул, дом 10		0101000020E6100000B5FF01D6AAC7424086014BAE62DF4B40
56853	1	\N	\N	1	12961	\N	55.501976999999997	город Москва, ЮЗАО, район Южное Бутово, Брусилова ул, дом 29, корп. 1		0101000020E610000064062AE3DFCB42400E2C47C840C04B40
56852	1	\N	\N	1	12961	\N	55.501976999999997	город Москва, ЮЗАО, район Южное Бутово, Брусилова ул, дом 29, корп.1		0101000020E610000064062AE3DFCB42400E2C47C840C04B40
55465	1	\N	\N	1	1688	\N	55.734917000000003	город Москва, ЦАО, Таганский район, Брошевский пер, дом 21	Россия, Москва, Брошевский переулок, 23с3	0101000020E610000013F06B2409D642402123A0C211DE4B40
55523	1	\N	\N	1	2506	\N	55.736806999999999	Адрес помещения для голосования: город Москва, ЦАО, район Якиманка, Бродников пер., дом 3, адрес УИК: Якиманка Б. ул, дом 25-27	Россия, Москва, Бродников переулок, 3	0101000020E61000005DC0CB0C1BCF4240603B18B14FDE4B40
56330	1	\N	\N	1	12977	\N	55.662984000000002	город Москва, ЮВАО, район Марьино, Братиславская ул, дом 8, корп. 1		0101000020E6100000D7A6B1BD16E04240B9E2E2A8DCD44B40
56463	1	\N	\N	1	6019	\N	55.635278999999997	город Москва, ЮАО, район Братеево, Братеевская ул, дом 18	Россия, Москва, Братеевская улица, 18	0101000020E61000004A7B832F4CE24240F46A80D250D14B40
56460	1	\N	\N	1	6019	\N	55.632662000000003	город Москва, ЮАО, район Братеево, Братеевская ул, дом 23, корп. 4	Россия, Москва, Братеевская улица, 23к4	0101000020E6100000446B459BE3E0424003B68311FBD04B40
56462	1	\N	\N	1	13130	\N	55.631340999999999	город Москва, ЮАО, район Братеево, Братеевская ул, дом 8, корп. 2		0101000020E610000082380F2730E14240DDCF29C8CFD04B40
55840	1	\N	\N	1	6407	\N	55.82394	город Москва, СВАО, район Марфино, Ботаническая ул, дом 9А	Россия, Москва, Ботаническая улица, 9а	0101000020E61000005DDE1CAED5CC4240E1EEACDD76E94B40
55844	1	\N	\N	1	13003	\N	55.844197000000001	город Москва, СВАО, район Марфино, Ботаническая ул, дом 4		0101000020E6100000105CE50984CB4240CF30B5A50EEC4B40
57004	1	\N	\N	1	12769	\N	55.650852449919803	город Москва, ЗАО, район Ново-Переделкино, Боровское шоссе, дом 18, корп. 4	Россия, Москва, район Солнцево, Боровское шоссе, 18к4	0101000020E610000073F56393FCAE4240A2444B1E4FD34B40
56999	1	\N	\N	1	12769	\N	55.640608999999998	город Москва, ЗАО, район Ново-Переделкино, Боровское шоссе, дом 35, корп. 1	Россия, Москва, район Солнцево, Боровское шоссе, 35к1	0101000020E610000056EF703B34AE4240FA42C879FFD14B40
56575	1	\N	\N	1	12436	\N	55.616332534376198	город Москва, ЮАО, район Орехово-Борисово Северное, Борисовский пр, дом 40, корп. 2	Россия, Москва, Борисовский проезд, 40к2	0101000020E6100000F0DC7BB8E4DC42400839EFFFE3CE4B40
56574	1	\N	\N	1	12436	\N	55.616389458748998	город Москва, ЮАО, район Орехово-Борисово Северное, Борисовский пр, дом 40, корп. 3	Россия, Москва, Борисовский проезд, 40к3	0101000020E6100000B5368DEDB5DC42409C4EB2D5E5CE4B40
56572	1	\N	\N	1	12436	\N	55.624491490738798	город Москва, ЮАО, район Орехово-Борисово Северное, Борисовский пр, дом 10, корп. 2	Россия, Москва, Борисовский проезд, 10к2	0101000020E610000050C422861DDC4240BBD23252EFCF4B40
56571	1	\N	\N	1	12436	\N	55.626613999999996	город Москва, ЮАО, район Орехово-Борисово Северное, Борисовский пр, дом 13	Россия, Москва, Борисовский проезд, 13	0101000020E610000065A6B4FE96DC42409D9B36E334D04B40
56464	1	\N	\N	1	13024	\N	55.639932999999999	город Москва, ЮАО, район Братеево, Борисовские пруды ул, дом 36, корп. 2		0101000020E6100000DF3312A111E24240CA501553E9D14B40
56459	1	\N	\N	1	13024	\N	55.636549000000002	город Москва, ЮАО, район Братеево, Борисовские пруды ул, дом 20, корп. 3		0101000020E61000003048FAB48AE0424098A608707AD14B40
56458	1	\N	\N	1	13024	\N	55.635401000000002	город Москва, ЮАО, район Братеево, Борисовские пруды ул, дом 12, корп. 2		0101000020E6100000176536C824DF4240406CE9D154D14B40
55456	1	\N	\N	1	1556	\N	55.742032000000002	город Москва, ЦАО, Таганский район, Факельный Б. пер, дом 3	Россия, Москва, Большой Факельный переулок, 3	0101000020E6100000971C774A07D54240F14A92E7FADE4B40
55455	1	\N	\N	1	1556	\N	55.74109	город Москва, ЦАО, Таганский район, Факельный Б. пер, дом 23	Россия, Москва, Большой Факельный переулок, 23	0101000020E61000000A9FAD8383D5424042B28009DCDE4B40
55364	1	\N	\N	1	168	\N	55.754978000000001	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Трехсвятительский Б. пер., дом 4, адрес УИК: Старосадский пер, дом 10, стр. 1		0101000020E6100000874ECFBBB1D2424089997D1EA3E04B40
55440	1	\N	\N	1	1317	\N	55.759906999999998	город Москва, ЦАО, Пресненский район, Трехгорный Б. пер, дом 3	Россия, Москва, Большой Трехгорный переулок, 3	0101000020E610000004AC55BB26C842403080F0A144E14B40
55495	1	\N	\N	1	2091	\N	55.743872000000003	город Москва, ЦАО, район Хамовники, Могильцевский Б. пер, дом 4	Россия, Москва, Большой Могильцевский переулок, 4-6	0101000020E61000002920ED7F80CB42407F349C3237DF4B40
55432	1	\N	\N	1	1196	\N	55.772573000000001	город Москва, ЦАО, Пресненский район, Кондратьевский Б. пер, дом 3	Россия, Москва, Большой Кондратьевский переулок, 3	0101000020E61000006DE2E47E87CA4240E5620CACE3E24B40
55427	1	\N	\N	1	1119	\N	55.762008999999999	город Москва, ЦАО, Пресненский район, Козихинский Б. пер, дом 5	Россия, Москва, Большой Козихинский переулок, 5	0101000020E610000032E4D87A86CC4240FB20CB8289E14B40
55484	1	\N	\N	1	1935	\N	55.772401000000002	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Каретный Б. пер., дом 22, адрес УИК: Колобовский 2-й пер, дом 9/2	Россия, Москва, Большой Каретный переулок, 22с1	0101000020E61000006B6281AFE8CE4240E8323509DEE24B40
55368	1	\N	\N	1	222	\N	55.760373000000001	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Казенный Б. пер., дом  9, адрес УИК: Лялин пер, дом 7/2	Россия, Москва, Большой Казенный переулок, 9	0101000020E6100000A5129ED0EBD3424076E107E753E14B40
55359	1	\N	\N	1	81	\N	55.748533999999999	Адрес помещения для голосования: город Москва, ЦАО, район Арбат, Афанасьевский Б. пер., дом 27, адрес УИК: Афанасьевский Б. пер, дом 35/37	Россия, Москва, Большой Афанасьевский переулок, 27с1	0101000020E61000001AFD683865CC4240D7F84CF6CFDF4B40
56721	1	\N	\N	1	13204	\N	55.647950000000002	город Москва, ЮЗАО, район Зюзино, Юшуньская Б. ул, дом 14		0101000020E6100000CCED5EEE93CB4240BBB88D06F0D24B40
56142	1	\N	\N	1	12637	\N	55.796996500263397	город Москва, ВАО, район Преображенское, Черкизовская Б. ул, дом 26А	Россия, Москва, Большая Черкизовская улица, 26	0101000020E6100000C45DBD8A8CDE42404B0169FF03E64B40
56138	1	\N	\N	1	12637	\N	55.795752	Адрес помещения для голосования: город Москва, ВАО, район Преображенское, Черкизовская Б. ул., дом 4, корп. 1, адрес УИК: Черкизовская Б. ул, дом 10, корп. 1		0101000020E610000001DD9733DBDB424001DD9733DBE54B40
56754	1	\N	\N	1	12992	\N	55.683889000000001	город Москва, ЮЗАО, район Котловка, Черемушкинская Б. ул, дом 17А		0101000020E610000091BA9D7DE5CB42400D8CBCAC89D74B40
56674	1	\N	\N	1	12992	\N	55.678868999999999	город Москва, ЮЗАО, Академический район, Черемушкинская Б. ул, дом 38		0101000020E6100000253D0CAD4ECA424055A2EC2DE5D64B40
57124	1	\N	\N	1	12728	\N	55.741647	город Москва, ЗАО, район Фили-Давыдково, Филевская Б. ул, дом 39		0101000020E6100000BE4D7FF623BD42409816F549EEDE4B40
57112	1	\N	\N	1	12728	\N	55.747453999999998	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Филёвская Б. ул., дом 15, Адрес УИК: Физкультурный пр, дом 5		0101000020E6100000BE688F17D2BF4240D7A19A92ACDF4B40
57108	1	\N	\N	1	12728	\N	55.744075000000002	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Филёвская Б. ул., дом 29, Адрес УИК: Филёвская Б. ул, дом 31		0101000020E6100000A96C585359BE4240B7627FD93DDF4B40
55392	1	\N	\N	1	13201	\N	55.738328000000003	город Москва, ЦАО, район Замоскворечье, Татарская Б. ул, дом 32		0101000020E610000013D6C6D809D142404DDC2A8881DE4B40
55385	1	\N	\N	1	12537	\N	55.776331935192196	город Москва, ЦАО, Басманный район, Почтовая Б. ул, дом 35/37		0101000020E610000058E1968FA4D842404C6BD3D85EE34B40
55383	1	\N	\N	1	12537	\N	55.774639000000001	город Москва, ЦАО, Басманный район, Почтовая Б. ул, дом 18/20, корп. 18		0101000020E61000002C9CA4F963D84240639AE95E27E34B40
55420	1	\N	\N	1	1013	\N	55.780076000000001	город Москва, ЦАО, Мещанский район, Переяславская Б. ул, дом 1	Россия, Москва, Большая Переяславская улица, 1	0101000020E610000097C79A9141D242407F32C687D9E34B40
55421	1	\N	\N	1	13096	\N	55.786430000000003	город Москва, ЦАО, Мещанский район, Переяславская Б. ул, дом 15		0101000020E6100000433A3C84F1D14240F14BFDBCA9E44B40
57027	1	\N	\N	1	4878	\N	55.675260000000002	город Москва, ЗАО, район Очаково-Матвеевское, Очаковская б. ул, дом 39, корп. 2, 3	Россия, Москва, Большая Очаковская улица, 39к2	0101000020E6100000957F2DAF5CB94240032670EB6ED64B40
57026	1	\N	\N	1	12955	\N	55.680047000000002	город Москва, ЗАО, район Очаково-Матвеевское, Очаковская б. ул, дом 25		0101000020E6100000774D486B0CBA4240185FB4C70BD74B40
57025	1	\N	\N	1	12955	\N	55.683767000000003	город Москва, ЗАО, район Очаково-Матвеевское, Очаковская б. ул, дом 18		0101000020E61000000798F90E7EBA4240C28A53AD85D74B40
57023	1	\N	\N	1	12955	\N	55.677509000000001	город Москва, ЗАО, район Очаково-Матвеевское, Очаковская б. ул, дом 42, корп. 2		0101000020E6100000242A543717B9424072DF6A9DB8D64B40
56200	1	\N	\N	1	12579	\N	55.795555	город Москва, ВАО, район Сокольники, Остроумовская б. ул, дом 12, стр. 1		0101000020E610000011AB3FC230D84240AB9509BFD4E54B40
55394	1	\N	\N	1	12541	\N	55.743103843895	город Москва, ЦАО, район Замоскворечье, Ордынка Б. ул, дом 15, стр. 1	Россия, Москва, улица Большая Ордынка, 15	0101000020E6100000359886E123D042406EC328081EDF4B40
55806	1	\N	\N	1	13209	\N	55.804921	город Москва, СВАО, Бутырский район, Новодмитровская Б. ул, дом 63		0101000020E6100000E21E4B1FBACA42408B6EBDA607E74B40
57175	1	\N	\N	1	6575	\N	55.830719999999999	город Москва, СЗАО, район Покровское-Стрешнево, Набережная б. ул, дом 15	Россия, Москва, Большая Набережная улица, 15	0101000020E6100000D6FCF84B8BBA42400A11700855EA4B40
55358	1	\N	\N	1	12593	\N	55.753463000000004	Адрес помещения для голосования: город Москва, ЦАО, район Арбат, Молчановка Б. ул., дом 26/28, адрес УИК: Трубниковский пер, дом 21		0101000020E6100000965B5A0D89CB42407FDFBF7971E04B40
55842	1	\N	\N	1	6417	\N	55.831505354575299	город Москва, СВАО, район Марфино, Марфинская Б. ул, дом 7	Россия, Москва, Большая Марфинская улица, 1	0101000020E6100000F90FE9B7AFCB4240F1BA7EC16EEA4B40
55841	1	\N	\N	1	12628	\N	55.831505354575299	город Москва, СВАО, район Марфино, Марфинская Б. ул, дом 1, вл. 5		0101000020E6100000E31B0A9FADCB4240F1BA7EC16EEA4B40
56928	1	\N	\N	1	12910	\N	55.746786342177501	город Москва, ЗАО, район Дорогомилово, Дорогомиловская Б. ул, дом 10, корп. 2		0101000020E61000001D1F2DCE18C842402A8E03AF96DF4B40
55436	1	\N	\N	1	13211	\N	55.765791999999998	город Москва, ЦАО, Пресненский район, Грузинская Б. ул, дом 13, стр. 1		0101000020E610000032ACE28DCCC94240EBC4E57805E24B40
56914	1	\N	\N	1	12730	\N	55.613456512164198	город Москва, ЗАО, район Внуково, Внуковская Б. ул, дом 6	Россия, Москва, поселок Внуково, Большая Внуковская улица, 6	0101000020E610000099BC0166BEA542404A404CC285CE4B40
56857	1	\N	\N	1	12779	\N	55.543301999999997	город Москва, ЮЗАО, район Южное Бутово, Бутовская Б. ул, дом 9		0101000020E61000007AA702EE79CA4240FAEC80EB8AC54B40
88454	6	56	\N	7561	18619	\N	56.613148000000002	город Красноуфимск, 8 Марта, 93		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
56858	1	\N	\N	1	12874	\N	55.543301999999997	Адрес помещения для голосования: город Москва, ЮЗАО, район Южное Бутово, Бутовская Б. ул., дом 9, адрес УИК: Старонародная ул, дом 2		0101000020E61000007AA702EE79CA4240FAEC80EB8AC54B40
55653	1	\N	\N	1	4228	\N	55.844540601298696	город Москва, САО, район Коптево, Академическая Б. ул, дом 77А, стр. 2	Россия, Москва, Большая Академическая улица, 77ас1	0101000020E61000000ADCBA9BA7C64240C99063EB19EC4B40
55652	1	\N	\N	1	4228	\N	55.844450000000002	город Москва, САО, район Коптево, Академическая Б. ул, дом 77А, стр. 1	Россия, Москва, Большая Академическая улица, 77ас1	0101000020E6100000D2E1218C9FC64240B98D06F016EC4B40
55659	1	\N	\N	1	12839	\N	55.822882999999997	Адрес помещения для голосования: город Москва, САО, район Коптево, Академическая Б. ул., дом 22А, адрес УИК: Академическая Б. ул, дом 6		0101000020E6100000734A404CC2C3424099B7EA3A54E94B40
55416	1	\N	\N	1	935	\N	55.785573999999997	город Москва, ЦАО, Мещанский район, Больничный пер, дом 4	Россия, Москва, Больничный переулок, 4	0101000020E6100000A794D74AE8D04240404B57B08DE44B40
56706	1	\N	\N	1	13055	\N	55.661186000000001	город Москва, ЮЗАО, район Зюзино, Болотниковская ул, дом 47, корп. 2		0101000020E6100000DEE7F86871CA42405A492BBEA1D44B40
56705	1	\N	\N	1	13055	\N	55.663913000000001	город Москва, ЮЗАО, район Зюзино, Болотниковская ул, дом 52, корп. 3		0101000020E61000002B84D558C2CA4240D331E719FBD44B40
56560	1	\N	\N	1	13055	\N	55.657865000000001	город Москва, ЮАО, Нагорный район, Болотниковская ул, дом 6		0101000020E6100000386744696FCE42406E179AEB34D44B40
55969	1	\N	\N	1	7707	\N	55.809393	город Москва, ВАО, район Богородское, Бойцовая ул, дом 6, корп. 8А	Россия, Москва, Бойцовая улица, 6к8а	0101000020E610000022E2E65432DC4240404E98309AE74B40
55968	1	\N	\N	1	13046	\N	55.80997	город Москва, ВАО, район Богородское, Бойцовая ул, дом 6, корп. 8Б		0101000020E610000027D9EA724ADC4240DD5ED218ADE74B40
55967	1	\N	\N	1	13046	\N	55.814452000000003	город Москва, ВАО, район Богородское, Бойцовая ул, дом 20		0101000020E61000009F3C2CD49ADC4240B61490F63FE84B40
57075	1	\N	\N	1	13194	\N	55.650433999999997	город Москва, ЗАО, район Солнцево, Богданова ул, дом 50		0101000020E610000055698B6B7CB242406D1ADB6B41D34B40
56172	1	\N	\N	1	12414	\N	55.780532000000001	город Москва, ВАО, район Соколиная гора, Благуша ул, дом 6		0101000020E6100000A2293BFDA0DC4240A1BDFA78E8E34B40
56432	1	\N	\N	1	5616	\N	55.584670000000003	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Восточное, Бирюлевская ул., дом 50, адрес УИК: Бирюлевская ул, дом 52, корп. 1	Россия, Москва, Бирюлевская улица, 50	0101000020E610000056B8E52329D54240E6797077D6CA4B40
56426	1	\N	\N	1	5616	\N	55.598950000000002	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Восточное, Бирюлевская ул., дом 7А, адрес УИК: Бирюлевская ул, дом 21, корп. 1	Россия, Москва, Бирюлевская улица, 7а	0101000020E6100000569BFF571DD5424038F8C264AACC4B40
56433	1	\N	\N	1	12594	\N	55.584670000000003	город Москва, ЮАО, район Бирюлево Восточное, Бирюлевская ул, дом 50		0101000020E610000056B8E52329D54240E6797077D6CA4B40
56431	1	\N	\N	1	12594	\N	55.584670000000003	Адрес помещения для голосования:город Москва, ЮАО, район Бирюлево Восточное, Бирюлевская ул., дом 50, адрес УИК: Бирюлевская ул, дом 52, корп. 1		0101000020E610000056B8E52329D54240E6797077D6CA4B40
56428	1	\N	\N	1	12594	\N	55.593446	город Москва, ЮАО, район Бирюлево Восточное, Бирюлевская ул, дом 23А		0101000020E610000066A4DE5339D5424094F8DC09F6CB4B40
56425	1	\N	\N	1	12594	\N	55.593482000000002	Адрес помещения для голосования: город Москва, ЮАО, район Бирюлево Восточное, Бирюлевская ул., дом 28, адрес УИК: Бирюлевская ул, дом 21, корп. 1		0101000020E610000076FA415DA4D44240E161DA37F7CB4B40
56424	1	\N	\N	1	12594	\N	55.593482000000002	город Москва, ЮАО, район Бирюлево Восточное, Бирюлевская ул, дом 28		0101000020E610000076FA415DA4D44240E161DA37F7CB4B40
55454	1	\N	\N	1	13160	\N	55.745189000000003	Адрес помещения для голосования: город Москва, ЦАО, Таганский район, Библиотечная ул., дом 29, адрес УИК: Библиотечная ул, дом 6		0101000020E6100000185A9D9CA1D64240632B685A62DF4B40
57370	1	\N	\N	1	586	\N	55.879171999999997	город Москва, СВАО, Алтуфьевский район, Бибиревская ул., 6 (к. 2), Политехнический колледж № 13	Россия, Москва, Бибиревская улица, 6г	0101000020E610000050DF32A7CBCC42408AC745B588F04B40
55765	1	\N	\N	1	13141	\N	55.881045999999998	город Москва, СВАО, Алтуфьевский район, Бибиревская ул, дом 5		0101000020E6100000E90B21E7FDCB4240C422861DC6F04B40
55879	1	\N	\N	1	13070	\N	55.871693	город Москва, СВАО, район Отрадное, Бестужевых ул, дом 25Б		0101000020E61000003B8E1F2A8DCE42407993DFA293EF4B40
55877	1	\N	\N	1	13070	\N	55.872011000000001	город Москва, СВАО, район Отрадное, Бестужевых ул, дом 23		0101000020E61000009566F3380CCE42404A60730E9EEF4B40
55875	1	\N	\N	1	13070	\N	55.868687999999999	город Москва, СВАО, район Отрадное, Бестужевых ул, дом 1		0101000020E61000005089EB1857CC4240BD361B2B31EF4B40
55565	1	\N	\N	1	3100	\N	55.875177999999998	город Москва, САО, Бескудниковский район, Бескудниковский пр, дом 4Б	Россия, Москва, Бескудниковский проезд, 4б	0101000020E610000092CD55F31CC74240DF162CD505F04B40
55564	1	\N	\N	1	3100	\N	55.874904999999998	город Москва, САО, Бескудниковский район, Бескудниковский пр, дом 4А	Россия, Москва, Бескудниковский проезд, 4а	0101000020E61000002C7DE882FAC64240AE0D15E3FCEF4B40
55558	1	\N	\N	1	3022	\N	55.862867999999999	город Москва, САО, Бескудниковский район, Бескудниковский пер, дом 4А	Россия, Москва, Бескудниковский переулок, 4а	0101000020E610000094DDCCE847C74240E961687572EE4B40
55569	1	\N	\N	1	1249	\N	55.861801999999997	город Москва, САО, Бескудниковский район, Бескудниковский бульв, дом 12	Россия, Москва, Бескудниковский бульвар, 12	0101000020E6100000520FD1E80EC842404ED026874FEE4B40
55563	1	\N	\N	1	1249	\N	55.875359000000003	город Москва, САО, Бескудниковский район, Бескудниковский бульв, дом 50Б	Россия, Москва, Бескудниковский бульвар, 50б	0101000020E61000004BE658DE55C5424030A182C30BF04B40
55562	1	\N	\N	1	1249	\N	55.875343999999998	город Москва, САО, Бескудниковский район, Бескудниковский бульв, дом 50А	Россия, Москва, Бескудниковский бульвар, 50а	0101000020E61000003DBA111615C54240FA5FAE450BF04B40
55561	1	\N	\N	1	1249	\N	55.871819000000002	город Москва, САО, Бескудниковский район, Бескудниковский бульв, дом 53	Россия, Москва, Бескудниковский бульвар, 53	0101000020E6100000F4A44C6A68C542400684D6C397EF4B40
55560	1	\N	\N	1	1249	\N	55.870798999999998	город Москва, САО, Бескудниковский район, Бескудниковский бульв, дом 29	Россия, Москва, Бескудниковский бульвар, 29	0101000020E61000008B8C0E48C2C64240DB31755776EF4B40
55559	1	\N	\N	1	1249	\N	55.871156999999997	город Москва, САО, Бескудниковский район, Бескудниковский бульв, дом 53А	Россия, Москва, Бескудниковский бульвар, 53а	0101000020E6100000B119E0826CC542403A57941282EF4B40
55452	1	\N	\N	1	1509	\N	55.748696000000002	город Москва, ЦАО, Таганский район, Берниковская наб, дом 9	Россия, Москва, Берниковская набережная, 12с1	0101000020E6100000406CE9D154D34240B1524145D5DF4B40
57255	1	\N	\N	1	12963	\N	55.789319999999996	город Москва, СЗАО, район Щукино, Берзарина ул, дом 26		0101000020E610000022718FA50FBD4240130A117008E54B40
57239	1	\N	\N	1	12963	\N	55.786571000000002	город Москва, СЗАО, район Хорошево-Мневники, Берзарина ул, дом 19, корп. 2		0101000020E6100000996725ADF8BC4240B37DC85BAEE44B40
57333	1	\N	\N	1	76495	\N	55.995649	Адрес помещения для голосования: город Москва, ЗелАО, район Матушкино, Березовая ал., д.7А, адрес УИК: Зеленоград, корп. 417	Россия, Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	0101000020E610000027A089B0E1994240C6A52A6D71FF4B40
57332	1	\N	\N	1	76495	\N	55.995649	Адрес помещения для голосования: город Москва, ЗелАО, район Матушкино, Березовая ал., д.7А, адрес УИК: Зеленоград, корп. 414	Россия, Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	0101000020E610000027A089B0E1994240C6A52A6D71FF4B40
56915	1	\N	\N	1	3516	\N	55.740116999999998	Адрес помещения для голосования: город Москва, ЗАО, район Дорогомилово, Бережковская наб., дом 6, адрес УИК: Бережковская наб, дом 12		0101000020E6100000BC79AA436EC84240581B6327BCDE4B40
57114	1	\N	\N	1	5964	\N	55.754260999153999	Адрес помещения для голосования: город Москва, ЗАО, район Филевский парк, Береговой пр., дом 8, корп. 1, Адрес УИК: Новозаводская ул, дом 25, корп. 1	Россия, Москва, Береговой проезд, 8	0101000020E6100000A3CC069964C04240FAD2DB9F8BE04B40
56342	1	\N	\N	1	4010	\N	55.663719999999998	город Москва, ЮВАО, район Марьино, Белореченская ул, дом 45, корп. 2	Россия, Москва, Белореченская улица, 45к2	0101000020E6100000691CEA7761E34240BED9E6C6F4D44B40
56341	1	\N	\N	1	4010	\N	55.660541000000002	город Москва, ЮВАО, район Марьино, Белореченская ул, дом 36, корп. 1	Россия, Москва, Белореченская улица, 36к1	0101000020E610000006F357C85CE342406555849B8CD44B40
56294	1	\N	\N	1	4010	\N	55.672528999999997	город Москва, ЮВАО, район Люблино, Белореченская ул, дом 8	Россия, Москва, Белореченская улица, 8	0101000020E6100000118FC4CBD3E14240484E266E15D64B40
56293	1	\N	\N	1	4010	\N	55.671519000000004	город Москва, ЮВАО, район Люблино, Белореченская ул, дом 23А	Россия, Москва, Белореченская улица, 23а	0101000020E6100000A6ED5F5969E2424042D2A755F4D54B40
56340	1	\N	\N	1	13080	\N	55.659719000000003	город Москва, ЮВАО, район Марьино, Белореченская ул, дом 36, корп. 2		0101000020E610000003E962D34AE3424061C614AC71D44B40
56292	1	\N	\N	1	13080	\N	55.672061999999997	город Москва, ЮВАО, район Люблино, Белореченская ул, дом 11		0101000020E6100000EC6B5D6A84E242403271AB2006D64B40
55666	1	\N	\N	1	12516	\N	55.867086	Адрес помещения для голосования: город Москва, САО, Левобережный район, Беломорская ул., дом 19, адрес УИК: Беломорская ул, дом 26		0101000020E61000003C2F151BF3BC4240E4688EACFCEE4B40
55784	1	\N	\N	1	5835	\N	55.89714	город Москва, СВАО, район Бибирево, Белозерская ул, дом 13	Россия, Москва, Белозерская улица, 13	0101000020E610000028EE7893DFCE42407BF7C77BD5F24B40
55785	1	\N	\N	1	12724	\N	55.896841999999999	город Москва, СВАО, район Бибирево, Белозерская ул, дом 15		0101000020E6100000172B6A300DCF4240F1D6F9B7CBF24B40
55783	1	\N	\N	1	12724	\N	55.898623999999998	город Москва, СВАО, район Бибирево, Белозерская ул, дом 7		0101000020E610000086ADD9CA4BCE42404AB3791C06F34B40
56974	1	\N	\N	1	13104	\N	55.708415000000002	город Москва, ЗАО, Можайский район, Беловежская ул, дом 67		0101000020E6100000A60F5D50DFB24240787FBC57ADDA4B40
56973	1	\N	\N	1	12747	\N	55.711787000000001	город Москва, ЗАО, Можайский район, Беловежская ул, дом 7		0101000020E6100000BD19355F25B34240E65B1FD61BDB4B40
55550	1	\N	\N	1	12969	\N	55.782364999999999	Адрес помещения для голосования: город Москва, САО, район Беговой, Беговая ул., дом 19, адрес УИК: Ленинградский просп, дом 33, корп. 6		0101000020E6100000C8D2872EA8C742407C444C8924E44B40
55676	1	\N	\N	1	12479	\N	55.803226000000002	город Москва, САО, Савеловский район, Башиловская ул, дом 22	Россия, Москва, Башиловская улица, 24	0101000020E610000023BA675DA3C9424001A60C1CD0E64B40
55379	1	\N	\N	1	12547	\N	55.770811000000002	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Бауманская ул., дом 40, адрес УИК: Бауманская ул, дом 39		0101000020E6100000D508FD4CBDD64240D33252EFA9E24B40
56320	1	\N	\N	1	4269	\N	55.643591999999998	город Москва, ЮВАО, район Марьино, Батайский пр, дом 47	Россия, Москва, Батайский проезд, 47	0101000020E610000093C9A99D61DE4240CEFBFF3861D24B40
56317	1	\N	\N	1	4269	\N	55.643917000000002	город Москва, ЮВАО, район Марьино, Батайский пр, дом 45	Россия, Москва, Батайский проезд, 45	0101000020E61000001A89D00836DE4240522B4CDF6BD24B40
56315	1	\N	\N	1	4269	\N	55.643343000000002	город Москва, ЮВАО, район Марьино, Батайский пр, дом 23	Россия, Москва, Батайский проезд, 23	0101000020E6100000D865F84F37DC4240268E3C1059D24B40
56314	1	\N	\N	1	4269	\N	55.643301999999998	город Москва, ЮВАО, район Марьино, Батайский пр, дом 21	Россия, Москва, Батайский проезд, 21	0101000020E6100000F31DFCC401DC4240C7B94DB857D24B40
56348	1	\N	\N	1	4700	\N	55.737501999999999	город Москва, ЮВАО, Нижегородский район, Басовская ул, дом 12, стр. 1	Россия, Москва, Басовская улица, 12с2	0101000020E6100000E6797077D6DE4240075E2D7766DE4B40
57157	1	\N	\N	1	12832	\N	55.855390999999997	город Москва, СЗАО, район Митино, Барышиха ул, дом 42, корп. 2		0101000020E6100000DD3F16A243AC42407825C9737DED4B40
57149	1	\N	\N	1	12832	\N	55.842267	город Москва, СЗАО, район Митино, Барышиха ул, дом 17, корп. 1		0101000020E61000008A58C4B0C3AC424001C0B167CFEB4B40
56878	1	\N	\N	1	13136	\N	55.544907000000002	город Москва, ЮЗАО, район Южное Бутово, Бартеневская ул, дом 49, корп. 4		0101000020E6100000E84A04AA7FC24240452E3883BFC54B40
56876	1	\N	\N	1	13136	\N	55.549321999999997	город Москва, ЮЗАО, район Южное Бутово, Бартеневская ул, дом 27		0101000020E61000007F32C687D9C34240957CEC2E50C64B40
55438	1	\N	\N	1	13061	\N	55.759557000000001	Адрес помещения для голосования: город Москва, ЦАО, Пресненский район, Баррикадная ул., дом 2/1, адрес УИК: Кудринская пл, дом 1		0101000020E610000060066344A2CA42405439ED2939E14B40
57110	1	\N	\N	1	12608	\N	55.745372000000003	город Москва, ЗАО, район Филевский парк, Барклая ул, дом 15		0101000020E6100000BB25396057BF424054AD855968DF4B40
57103	1	\N	\N	1	12608	\N	55.739260000000002	город Москва, ЗАО, район Филевский парк, Барклая ул, дом 5, корп. 6		0101000020E61000003AE63C635FC04240D89E5912A0DE4B40
56976	1	\N	\N	1	4309	\N	55.719957000000001	город Москва, ЗАО, Можайский район, Барвихинская ул, дом 16, корп. 1	Россия, Москва, Барвихинская улица, 16к1	0101000020E6100000A4198BA6B3B142405DC30C8D27DC4B40
56164	1	\N	\N	1	12708	\N	55.789726627571497	город Москва, ВАО, район Сокольники, Барболина ул, дом 1		0101000020E6100000D34CF73AA9D7424054E23AC615E54B40
56719	1	\N	\N	1	700	\N	55.646374999999999	город Москва, ЮЗАО, район Зюзино, Балаклавский просп, дом 32а	Россия, Москва, Балаклавский проспект, 32а	0101000020E61000002593533BC3CA4240DBF97E6ABCD24B40
56718	1	\N	\N	1	700	\N	55.647010000000002	город Москва, ЮЗАО, район Зюзино, Балаклавский просп, дом 32, корп. 4	Россия, Москва, Балаклавский проспект, 32к4	0101000020E61000002BA1BB24CECA4240AD174339D1D24B40
56567	1	\N	\N	1	700	\N	55.641523999999997	город Москва, ЮАО, Нагорный район, Балаклавский просп, дом 6, корп. А	Россия, Москва, Балаклавский проспект, 6а	0101000020E6100000FEEDB25F77CE4240AFCC5B751DD24B40
56566	1	\N	\N	1	700	\N	55.642555000000002	город Москва, ЮАО, Нагорный район, Балаклавский просп, дом 6	Россия, Москва, Балаклавский проспект, 6	0101000020E61000006B0C3A2174CE4240CE70033E3FD24B40
55381	1	\N	\N	1	408	\N	55.774355	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Бакунинская ул., дом 7, корп. 1, адрес УИК: Красносельская Нижн, дом 42		0101000020E6100000B5A9BA4736D742403E3F8C101EE34B40
56015	1	\N	\N	1	13066	\N	55.815078999999997	город Москва, ВАО, район Гольяново, Байкальская ул, дом 44		0101000020E6100000D34A21904BE842400454388254E84B40
55639	1	\N	\N	1	12741	\N	55.878501	город Москва, САО, район Западное Дегунино, Базовская ул, дом 20А		0101000020E6100000008C67D0D0C142406C4084B872F04B40
57117	1	\N	\N	1	5979	\N	55.742208674487003	город Москва, ЗАО, район Филевский парк, Багратионовский пр, дом 7	Россия, Москва, Багратионовский проезд, 7	0101000020E61000005723BBD232C0424000E65AB400DF4B40
57115	1	\N	\N	1	5979	\N	55.745731999999997	город Москва, ЗАО, район Филевский парк, Багратионовский пр, дом 10	Россия, Москва, Багратионовский проезд, 10	0101000020E61000008E03AF963BC1424053CA6B2574DF4B40
57284	1	\N	\N	1	12803	\N	55.846739999999997	город Москва, СЗАО, район Южное Тушино, Аэродромная ул, дом 9		0101000020E6100000F8DD74CB0EB74240861BF0F961EC4B40
55701	1	\N	\N	1	4820	\N	55.812631000000003	город Москва, САО, Тимирязевский район, Астрадамский пр, дом 5А	Россия, Москва, Астрадамский проезд, 5	0101000020E6100000C4EBFA05BBC742409F5BE84A04E84B40
55700	1	\N	\N	1	4820	\N	55.812631000000003	Адрес помещения для голосования: город Москва, САО, Тимирязевский район, Астрадамский пр., дом 5А, адрес УИК: Вучетича ул, дом 20	Россия, Москва, Астрадамский проезд, 5	0101000020E6100000C4EBFA05BBC742409F5BE84A04E84B40
56831	1	\N	\N	1	12570	\N	55.676844000000003	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Власова архитектора ул., дом 19, адрес УИК: Гарибальди ул, дом 19, корп. 1		0101000020E6100000F9D7F2CAF5C64240363FFED2A2D64B40
56829	1	\N	\N	1	12570	\N	55.676844000000003	Адрес помещения для голосования: город Москва, ЮЗАО, район Черемушки, Власова архитектора ул., дом 19, адрес УИК: Профсоюзная ул, дом 30, корп. 3		0101000020E6100000F9D7F2CAF5C64240363FFED2A2D64B40
56398	1	\N	\N	1	12744	\N	55.697488	Адрес помещения для голосования: город Москва, ЮВАО, район Текстильщики, Артюхиной ул., дом 17, адрес УИК: Чистова ул, дом 13А		0101000020E610000080290307B4DE42401DAD6A4947D94B40
56564	1	\N	\N	1	7031	\N	55.650956999999998	город Москва, ЮАО, Нагорный район, Артековская ул, дом 3	Россия, Москва, Артековская улица, 3	0101000020E61000005E4D9EB29ACE4240170D198F52D34B40
57135	1	\N	\N	1	13213	\N	55.720053	город Москва, ЗАО, район Фили-Давыдково, Артамонова ул, дом 2		0101000020E61000006D1B4641F0BA42407F315BB22ADC4B40
55363	1	\N	\N	1	150	\N	55.759318999999998	Адрес помещения для голосования: город Москва, ЦАО, Басманный район, Армянский пер., дом  4, адрес УИК: Покровка ул, дом 3/7, стр. 1 Г	Россия, Москва, Армянский переулок, 4	0101000020E6100000193A765089D142409F1D705D31E14B40
56297	1	\N	\N	1	13239	\N	55.675280000000001	город Москва, ЮВАО, район Люблино, Армавирская ул, дом 4		0101000020E6100000976F7D586FE042404AD235936FD64B40
55863	1	\N	\N	1	12613	\N	55.817633000000001	город Москва, СВАО, Останкинский район, Аргуновская ул, дом 12, корп. 2		0101000020E6100000F4DE180280CF4240B090B932A8E84B40
55360	1	\N	\N	1	13187	\N	55.748852999999997	город Москва, ЦАО, район Арбат, Арбат ул, дом 35		0101000020E61000002B4D4A41B7CB42407841446ADADF4B40
55377	1	\N	\N	1	361	\N	55.767994999999999	город Москва, ЦАО, Басманный район, Аптекарский пер, дом 8/2	Россия, Москва, Аптекарский переулок, 8/2	0101000020E6100000FC8BA03193D64240EA3E00A94DE24B40
57379	1	\N	\N	1	729	\N	55.802128000000003	город Москва, СВАО, район Марьина Роща, пр. Анненский, 1, ЗАО «Оливеста»		0101000020E6100000766B990CC7CD42405B9A5B21ACE64B40
55963	1	\N	\N	1	12980	\N	55.81561	город Москва, ВАО, район Богородское, Андреево-Забелинская ул, дом 28		0101000020E6100000041E1840F8DA4240312592E865E84B40
55637	1	\N	\N	1	12675	\N	55.874338999999999	город Москва, САО, район Западное Дегунино, Ангарская ул, дом 22		0101000020E6100000EC4E779E78C24240054F2157EAEF4B40
55839	1	\N	\N	1	6397	\N	55.879010999999998	город Москва, СВАО, Лосиноостровский район, Анадырский пр, дом 51	Россия, Москва, Анадырский проезд, 51	0101000020E6100000232D95B723DA424081E9B46E83F04B40
56008	1	\N	\N	1	8082	\N	55.814734999999999	город Москва, ВАО, район Гольяново, Амурская ул, дом 25А	Россия, Москва, Амурская улица, 25а	0101000020E6100000C11C3D7E6FE542400AF4893C49E84B40
56007	1	\N	\N	1	8082	\N	55.812204651250397	город Москва, ВАО, район Гольяново, Амурская ул, дом 60	Россия, Москва, Амурская улица, 60	0101000020E6100000E08101840FE54240E7525C55F6E74B40
56005	1	\N	\N	1	13214	\N	55.806651000000002	город Москва, ВАО, район Гольяново, Амурская ул, дом 6		0101000020E61000008B33863941E142409224085740E74B40
55902	1	\N	\N	1	12685	\N	55.852020000000003	город Москва, СВАО, район Свиблово, Амундсена ул, дом 11, корп. 3		0101000020E6100000200DA7CCCDD34240DBC4C9FD0EED4B40
55901	1	\N	\N	1	12685	\N	55.850175999999998	город Москва, СВАО, район Свиблово, Амундсена ул, дом 5, корп. 2		0101000020E6100000BCCCB051D6D342400BEC3191D2EC4B40
55899	1	\N	\N	1	12685	\N	55.853000999999999	город Москва, СВАО, район Свиблово, Амундсена ул, дом 10А		0101000020E6100000145E82531FD44240473A03232FED4B40
57021	1	\N	\N	1	4856	\N	55.703083999999997	город Москва, ЗАО, район Очаково-Матвеевское, Аминьевское шоссе, дом 5	Россия, Москва, Аминьевское шоссе, 5	0101000020E6100000609335EA21BA4240A12B11A8FED94B40
55971	1	\N	\N	1	7751	\N	55.807192999999998	город Москва, ВАО, район Богородское, Алымов пер, дом 15	Россия, Москва, Алымов переулок, 15	0101000020E610000075560BEC31DB4240B247A81952E74B40
57380	1	\N	\N	1	605	\N	55.855387901121297	город Москва, СВАО, район Отрадное, Алтуфьевское шоссе, 12в, центр образования №14860	Россия, Москва, Алтуфьевское шоссе, 12вс2	0101000020E6100000A2ED98BA2BCB424007B29E5A7DED4B40
57371	1	\N	\N	1	605	\N	55.901395000000001	город Москва, СВАО, район Бибирево, Алтуфьевское ш., 94, в помещении школы № 241	Россия, Москва, Алтуфьевское шоссе, 94	0101000020E61000002639605793CB424093E34EE960F34B40
55876	1	\N	\N	1	605	\N	55.872804000000002	город Москва, СВАО, район Отрадное, Алтуфьевское шоссе, дом 42Б	Россия, Москва, Алтуфьевское шоссе, 42б	0101000020E61000007E74EACA67CB4240B4E89D0AB8EF4B40
55872	1	\N	\N	1	605	\N	55.865848999999997	город Москва, СВАО, район Отрадное, Алтуфьевское шоссе, дом 30А	Россия, Москва, Алтуфьевское шоссе, 30а	0101000020E6100000B8CA13083BCB42401C23D923D4EE4B40
55869	1	\N	\N	1	605	\N	55.861736999999998	город Москва, СВАО, район Отрадное, Алтуфьевское шоссе, дом 24А	Россия, Москва, Алтуфьевское шоссе, 24а	0101000020E61000000247020D36CB42406760E4654DEE4B40
55868	1	\N	\N	1	605	\N	55.855406000000002	город Москва, СВАО, район Отрадное, Алтуфьевское шоссе, дом 12В	Россия, Москва, Алтуфьевское шоссе, 12вс2	0101000020E6100000A2ED98BA2BCB4240AE669DF17DED4B40
55867	1	\N	\N	1	605	\N	55.854613000000001	город Москва, СВАО, район Отрадное, Алтуфьевское шоссе, дом 13, корп. 2	Россия, Москва, Алтуфьевское шоссе, 13к2	0101000020E61000003C4D66BCADCA424044DE72F563ED4B40
55821	1	\N	\N	1	605	\N	55.903565	город Москва, СВАО, район Лианозово, Алтуфьевское шоссе, дом 97, корп. 3	Россия, Москва, Алтуфьевское шоссе, 97к3	0101000020E61000008BC058DFC0CA4240B6679604A8F34B40
55805	1	\N	\N	1	605	\N	55.901395000000001	город Москва, СВАО, район Бибирево, Алтуфьевское шоссе, дом 94	Россия, Москва, Алтуфьевское шоссе, 94	0101000020E61000002639605793CB424093E34EE960F34B40
55766	1	\N	\N	1	605	\N	55.883237000000001	город Москва, СВАО, Алтуфьевский район, Алтуфьевское шоссе, дом 60Б	Россия, Москва, Алтуфьевское шоссе, 60б	0101000020E610000032384A5E9DCB4240FFCEF6E80DF14B40
56017	1	\N	\N	1	13105	\N	55.818821999999997	город Москва, ВАО, район Гольяново, Алтайская ул, дом 26А		0101000020E6100000FEB7921D1BE94240669FC728CFE84B40
56010	1	\N	\N	1	13155	\N	55.818886999999997	город Москва, ВАО, район Гольяново, Алтайская ул, дом 10А		0101000020E61000006A6D1ADB6BE742404D0F0A4AD1E84B40
56466	1	\N	\N	1	13076	\N	55.639491	город Москва, ЮАО, район Братеево, Алма-Атинская ул, дом 9, корп. 3		0101000020E6100000E2067C7E18E342400D8B51D7DAD14B40
56098	1	\N	\N	1	12903	\N	55.746375	город Москва, ВАО, район Новогиреево, Дикого Алексея ул, дом 18А		0101000020E61000009E45EF54C0E74240A8C64B3789DF4B40
55478	1	\N	\N	1	13117	\N	55.776867000000003	город Москва, ЦАО, Тверской район, Невского Александра ул, дом 4		0101000020E6100000247F30F0DCCB4240BB2BBB6070E34B40
56784	1	\N	\N	1	13113	\N	55.662886999999998	город Москва, ЮЗАО, Обручевский район, Челомея Академика ул, дом 6А		0101000020E6100000DDB419A721C44240C6F8307BD9D44B40
56248	1	\N	\N	1	12559	\N	55.700206999999999	город Москва, ЮВАО, район Кузьминки, Скрябина академика ул, дом 36, корп. 3		0101000020E6100000B9A81611C5E4424013B70A62A0D94B40
56213	1	\N	\N	1	12559	\N	55.698152999999998	город Москва, ЮВАО, район Выхино-Жулебино, Скрябина академика ул, дом 23		0101000020E6100000C03FA54A94E54240594DD7135DD94B40
56883	1	\N	\N	1	13085	\N	55.533506000000003	город Москва, ЮЗАО, район Южное Бутово, Понтрягина академика ул, дом 17, корп. 1		0101000020E6100000D1CB28965BC04240221CB3EC49C44B40
56962	1	\N	\N	1	12707	\N	55.743107000000002	город Москва, ЗАО, район Кунцево, Павлова Акад. ул, дом 9, корп. 2		0101000020E61000002905DD5ED2B24240DF3653211EDF4B40
56523	1	\N	\N	1	12718	\N	55.666182999999997	город Москва, ЮАО, район Нагатино-Садовники, Миллионщикова акад. ул, дом 20		0101000020E610000026E5EE737CD2424059130B7C45D54B40
56746	1	\N	\N	1	12735	\N	55.628047000000002	город Москва, ЮЗАО, район Коньково, Капицы академика ул, дом 14 А		0101000020E61000003FFF3D78EDC24240EBAC16D863D04B40
56745	1	\N	\N	1	12735	\N	55.628971999999997	город Москва, ЮЗАО, район Коньково, Капицы академика ул, дом 12		0101000020E610000063B83A00E2C24240C30C8D2782D04B40
56747	1	\N	\N	1	12814	\N	55.640309000000002	город Москва, ЮЗАО, район Коньково, Волгина академика ул, дом 41		0101000020E610000056F487669EC04240D02A33A5F5D14B40
56725	1	\N	\N	1	12814	\N	55.650866000000001	город Москва, ЮЗАО, район Коньково, Волгина академика ул, дом 11		0101000020E61000009203763579C24240070ABC934FD34B40
56813	1	\N	\N	1	12960	\N	55.634053999999999	Адрес помещения для голосования: город Москва, ЮЗАО, район Теплый Стан, Виноградова академика ул., дом 7, адрес УИК: Теплый стан ул, дом 4	Россия, Москва, улица Академика Виноградова, 7	0101000020E61000009C340D8AE6BD4240F1F274AE28D14B40
56823	1	\N	\N	1	12431	\N	55.633326559275503	город Москва, ЮЗАО, район Теплый Стан, Варги академика ул, дом 32	Россия, Москва, улица Академика Варги, 32	0101000020E61000001EFF058200BD42403F56F0DB10D14B40
56822	1	\N	\N	1	12431	\N	55.633296999999999	город Москва, ЮЗАО, район Теплый Стан, Варги академика ул, дом 34	Россия, Москва, улица Академика Варги, 34	0101000020E6100000CB2F833122BD4240D4D347E00FD14B40
56750	1	\N	\N	1	12736	\N	55.642158999999999	город Москва, ЮЗАО, район Коньково, Арцимовича академика ул, дом 7		0101000020E6100000D3FA5B02F0C1424081EA1F4432D24B40
56749	1	\N	\N	1	12736	\N	55.642158999999999	Адрес помещения для голосования: город Москва, ЮЗАО, район Коньково, Арцимовича академика ул., дом 7, адрес УИК: Миклухо-Маклая ул, дом 20		0101000020E6100000D3FA5B02F0C1424081EA1F4432D24B40
57101	1	\N	\N	1	12799	\N	55.673437999999997	город Москва, ЗАО, район Тропарево-Никулино, Анохина Академика ул, дом 2, корп.5		0101000020E61000004FB2D5E594BC42401BF1643733D64B40
57097	1	\N	\N	1	12799	\N	55.653303999999999	город Москва, ЗАО, район Тропарево-Никулино, Анохина Академика ул, дом 48		0101000020E6100000B58993FB1DBC4240492C29779FD34B40
57088	1	\N	\N	1	12799	\N	55.661982999999999	город Москва, ЗАО, район Тропарево-Никулино, Анохина Академика ул, дом 32		0101000020E6100000A83462669FBB424005C1E3DBBBD44B40
57087	1	\N	\N	1	12799	\N	55.671534000000001	город Москва, ЗАО, район Тропарево-Никулино, Анохина Академика ул, дом 4, корп.5		0101000020E6100000C18EFF0241BC424077137CD3F4D54B40
56723	1	\N	\N	1	650	\N	55.643866000000003	город Москва, ЮЗАО, район Зюзино, Азовская ул, дом 41	Россия, Москва, Азовская улица, 41	0101000020E6100000782975C938CC4240D0807A336AD24B40
56715	1	\N	\N	1	650	\N	55.662973999999998	город Москва, ЮЗАО, район Зюзино, Азовская ул, дом 2 , корп. 2	Россия, Москва, Азовская улица, 2к2	0101000020E61000007007EA9447CD4240950C0055DCD44B40
56722	1	\N	\N	1	13091	\N	55.649524999999997	город Москва, ЮЗАО, район Зюзино, Азовская ул, дом 31		0101000020E6100000FA97A432C5CC42409A779CA223D34B40
56880	1	\N	\N	1	12792	\N	55.540500999999999	город Москва, ЮЗАО, район Южное Бутово, Адмирала Руднева ул, дом 16, корп. 1		0101000020E6100000A6D6FB8D76C24240473A03232FC54B40
56879	1	\N	\N	1	12792	\N	55.540500999999999	Город Москва, ЮЗАО, район Южное Бутово, Адмирала Руднева ул, дом 16, корп. 1		0101000020E6100000A6D6FB8D76C24240473A03232FC54B40
55531	1	\N	\N	1	2617	\N	55.799978000000003	Адрес помещения для голосования: город Москва, САО, район Аэропорт, Авиационный пер., дом 6, адрес УИК: Красноармейская ул, дом 9	Россия, Москва, Авиационный переулок, 6	0101000020E6100000C7BDF90D13C542407FC2D9AD65E64B40
57271	1	\N	\N	1	13094	\N	55.807161999999998	город Москва, СЗАО, район Щукино, Авиационная ул, дом 71, корп. 3		0101000020E61000002BC1E270E6B9424077499C1551E74B40
56260	1	\N	\N	1	3549	\N	55.740623999999997	город Москва, ЮВАО, район Лефортово, Авиамоторная ул, дом 42	Россия, Москва, Авиамоторная улица, 42	0101000020E6100000821E6ADB30DC4240FC5069C4CCDE4B40
56275	1	\N	\N	1	12865	\N	55.763548	город Москва, ЮВАО, район Лефортово, Авиамоторная ул, дом 1		0101000020E6100000CA37DBDC98DA42408E76DCF0BBE14B40
56271	1	\N	\N	1	12865	\N	55.755195999999998	город Москва, ЮВАО, район Лефортово, Авиамоторная ул, дом 8А		0101000020E61000007369FCC22BDB4240F6083543AAE04B40
56272	1	\N	\N	1	12949	\N	55.762600999999997	город Москва, ЮВАО, район Лефортово, Авиамоторная ул, дом 7		0101000020E6100000744694F606DB4240CD72D9E89CE14B40
56259	1	\N	\N	1	12949	\N	55.747297000000003	город Москва, ЮВАО, район Лефортово, Авиамоторная ул, дом 51Б		0101000020E6100000C1C8CB9A58DC424010B3976DA7DF4B40
55607	1	\N	\N	1	3606	\N	55.847937000000002	город Москва, САО, Головинский район, Авангардная ул, дом 11А	Россия, Москва, Авангардная улица, 11а	0101000020E6100000B03A72A433BE4240C0081A3389EC4B40
55604	1	\N	\N	1	3606	\N	55.844217999999998	город Москва, САО, Головинский район, Авангардная ул, дом 5	Россия, Москва, Авангардная улица, 5	0101000020E61000007F129F3BC1BE4240E658DE550FEC4B40
57375	1	\N	\N	1	12440	\N	55.891793884557899	"город Москва, СВАО, район Лианозово, Абрамцевская ул., 1, ГУП ДЭЗ района Лианозово"""	Россия, Москва, Абрамцевская улица, 1	0101000020E610000059198D7C5EC942406F62484E26F24B40
55927	1	\N	\N	1	12575	\N	55.935113000000001	город Москва, СВАО, район Северный, 9-я Северная линия, дом 1, корп. 2	Россия, Москва, 9-я Северная линия, 1к2	0101000020E610000097C4591135C74240408864C8B1F74B40
55596	1	\N	\N	1	12868	\N	55.881661999999999	город Москва, САО, район Восточное Дегунино, 800-летия Москвы ул, дом 7а		0101000020E61000002942EA76F6C742401F10E84CDAF04B40
56396	1	\N	\N	1	12831	\N	55.701917000000002	город Москва, ЮВАО, район Текстильщики, Текстильщиков 8-я ул, дом 14		0101000020E6100000D4298F6E84DF4240D3C08F6AD8D94B40
55542	1	\N	\N	1	12668	\N	55.805810865976397	город Москва, САО, район Аэропорт, Восьмого марта ул, дом 17	Россия, Москва, Савеловский район, улица 8 Марта, 17	0101000020E61000001BBD1AA034C64240E7E099D024E74B40
56400	1	\N	\N	1	5330	\N	55.696159000000002	город Москва, ЮВАО, район Текстильщики, Текстильщиков 7-я ул, дом 9А	Россия, Москва, 7-я улица Текстильщиков, 9	0101000020E610000012DA722EC5DF424075E8F4BC1BD94B40
56989	1	\N	\N	1	4489	\N	55.661613000000003	город Москва, ЗАО, район Ново-Переделкино, Лазенки 7-я ул, дом 12, корп. 3	Россия, Москва, 7-я улица Лазенки, 12с3	0101000020E610000023DBF97E6AAC4240E2CD1ABCAFD44B40
56060	1	\N	\N	1	13118	\N	55.790073999999997	город Москва, ВАО, район Измайлово, Парковая 7-я ул, дом 1А		0101000020E6100000F4C1323674E54240BFB5132521E54B40
56410	1	\N	\N	1	12932	\N	55.706482000000001	город Москва, ЮВАО, Южнопортовый район, Кожуховская 6-я ул, дом 8		0101000020E6100000605969520AD64240399B8E006EDA4B40
57070	1	\N	\N	1	12888	\N	55.652430000000003	город Москва, ЗАО, район Солнцево, 50 лет Октября ул, дом 13А		0101000020E610000011001C7BF6B44240F37684D382D34B40
57067	1	\N	\N	1	12888	\N	55.657580000000003	город Москва, ЗАО, район Солнцево, 50 лет Октября ул, дом 14А		0101000020E6100000284701A260B442407940D9942BD44B40
56188	1	\N	\N	1	12307	\N	55.762971	город Москва, ВАО, район Соколиная гора, Соколиной горы 5-я ул, дом 14	Россия, Москва, 5-я улица Соколиной Горы, 14	0101000020E61000001CB62DCA6CDE4240F165A208A9E14B40
56186	1	\N	\N	1	12307	\N	55.7661299172944	город Москва, ВАО, район Соколиная гора, Соколиной горы 5-я ул, дом 25А	Россия, Москва, 5-я улица Соколиной Горы, 25а	0101000020E610000073124A5F08DF4240033E3F8C10E24B40
56183	1	\N	\N	1	12307	\N	55.762900000000002	город Москва, ВАО, район Соколиная гора, Соколиной горы 5-я ул, дом 5	Россия, Москва, 5-я улица Соколиной Горы, 5	0101000020E6100000717495EEAEDD4240280F0BB5A6E14B40
56155	1	\N	\N	1	663	\N	55.8075438731817	город Москва, ВАО, район Северное Измайлово, Парковая 5-я ул, дом 62	Россия, Москва, 5-я Парковая улица, 62	0101000020E610000017D4B7CCE9E442405F0A0F9A5DE74B40
56152	1	\N	\N	1	663	\N	55.805579000000002	город Москва, ВАО, район Северное Измайлово, Парковая 5-я ул, дом 49	Россия, Москва, 5-я Парковая улица, 49	0101000020E61000007A1B9B1DA9E4424015AC71361DE74B40
56057	1	\N	\N	1	663	\N	55.793849000000002	город Москва, ВАО, район Измайлово, Парковая 5-я ул, дом 21	Россия, Москва, 5-я Парковая улица, 21	0101000020E6100000438F183DB7E442402D7B12D89CE54B40
56154	1	\N	\N	1	12387	\N	55.805968	город Москва, ВАО, район Северное Измайлово, Парковая 5-я ул, дом 60	Россия, Москва, 5-я Парковая улица, 60	0101000020E6100000B1FD648C0FE54240AFCF9CF529E74B40
56153	1	\N	\N	1	12387	\N	55.804779000000003	город Москва, ВАО, район Северное Измайлово, Парковая 5-я ул, дом 58	Россия, Москва, 5-я Парковая улица, 58	0101000020E6100000F261F6B2EDE44240F9C08EFF02E74B40
56482	1	\N	\N	1	5551	\N	55.705179000000001	Адрес помещения для голосования: город Москва, ЮАО, Даниловский район, Кожуховская 5-я ул., дом 8/2, адрес УИК: Сайкина ул, дом 6/5		0101000020E610000027FA7C9411D54240BA69334E43DA4B40
56418	1	\N	\N	1	12935	\N	55.705392000000003	город Москва, ЮВАО, Южнопортовый район, Кожуховская 5-я ул, дом 15		0101000020E6100000ADC266800BD64240166EF9484ADA4B40
55961	1	\N	\N	1	7647	\N	55.816904999999998	город Москва, ВАО, район Богородское, Подбельского 5-й пр, дом 2, стр. 1	Россия, Москва, 5-й проезд Подбельского, 2с2	0101000020E610000087FBC8AD49DD42402D78D15790E84B40
55850	1	\N	\N	1	6503	\N	55.798206999999998	город Москва, СВАО, район Марьина роща, Марьиной рощи 5-й пр, дом 15А	Россия, Москва, 5-й проезд Марьиной Рощи, 15а	0101000020E610000082ACA7565FCF42401938A0A52BE64B40
56234	1	\N	\N	1	12432	\N	55.6313522817399	город Москва, ЮВАО, район Капотня, Капотня 5-й квартал, дом 28	Россия, Москва, 5-й квартал Капотни, 28	0101000020E610000072A774B0FEE54240D1217024D0D04B40
56468	1	\N	\N	1	6099	\N	55.710625999999998	город Москва, ЮАО, Даниловский район, Рощинский 5-й пр, дом 4	Россия, Москва, 5-й Рощинский проезд, 4	0101000020E6100000423F53AF5BCE4240F9D7F2CAF5DA4B40
55390	1	\N	\N	1	547	\N	55.732123999999999	город Москва, ЦАО, район Замоскворечье, Монетчиковский 5-й пер, дом 7	Россия, Москва, 5-й Монетчиковский переулок, 7	0101000020E61000005534D6FECED04240F04E3E3DB6DD4B40
55471	1	\N	\N	1	1770	\N	55.742139000000002	Адрес помещения для голосования: город Москва, ЦАО, Таганский район, Котельнический 5-й пер., дом 8, стр.1, адрес УИК: Гончарный 1-й пер, дом 7	Россия, Москва, 5-й Котельнический переулок, 8	0101000020E6100000CE16105A0FD34240070B2769FEDE4B40
56059	1	\N	\N	1	13231	\N	55.790965	город Москва, ВАО, район Измайлово, Парковая 4-я ул, дом 12, корп. 1		0101000020E6100000A0C1A6CEA3E44240ECA353573EE54B40
56383	1	\N	\N	1	12824	\N	55.708951999999996	город Москва, ЮВАО, Рязанский район, Новокузьминская 4-я ул, дом 3		0101000020E6100000CE1B278579E5424086376BF0BEDA4B40
55651	1	\N	\N	1	4221	\N	55.841740999999999	город Москва, САО, район Коптево, Новомихалковский 4-й пр, дом 9А	Россия, Москва, 4-й Новомихалковский проезд, 9а	0101000020E610000048E2E5E95CC54240E659492BBEEB4B40
56378	1	\N	\N	1	5058	\N	55.718283	город Москва, ЮВАО, Рязанский район, Вешняковский 4-й пр, дом 1	Россия, Москва, 4-й Вешняковский проезд, 1к1	0101000020E6100000D0251C7A8BE54240EA2285B2F0DB4B40
55510	1	\N	\N	1	12861	\N	55.720027999999999	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Фрунзенская 3-я ул., дом 5, адрес УИК: Фрунзенская наб, дом 42		0101000020E6100000834C327216CA4240261AA4E029DC4B40
55926	1	\N	\N	1	12477	\N	55.939775836058097	город Москва, СВАО, район Северный, 3-я Северная линия, дом 17	Россия, Москва, 3-я Северная линия, 17	0101000020E61000003FC571E0D5C6424069C878944AF84B40
56197	1	\N	\N	1	2735	\N	55.789628	Адрес помещения для голосования: город Москва, ВАО, район Сокольники, Рыбинская 3-я ул., дом 18, стр. 1, адрес УИК: Рыбинский пер, дом 6	Россия, Москва, 3-я Рыбинская улица, 18с1	0101000020E610000085B35BCB64D44240C100C28712E54B40
56443	1	\N	\N	1	13248	\N	55.6065063338676	ород Москва, ЮАО, район Бирюлево Восточное, Радиальная 3-я ул, дом 8		0101000020E6100000DD787764ACD64240F56915FDA1CD4B40
56056	1	\N	\N	1	13013	\N	55.794285000000002	город Москва, ВАО, район Измайлово, Парковая 3-я ул, дом 22А		0101000020E610000012A452EC68E44240085A8121ABE54B40
55861	1	\N	\N	1	6609	\N	55.819629339889197	город Москва, СВАО, Останкинский район, Новоостанкинская 3-я ул, дом 18/28	Россия, Москва, 3-я Новоостанкинская улица, 17	0101000020E61000001C5F7B6649D0424035ED629AE9E84B40
56128	1	\N	\N	1	13067	\N	55.754992999999999	город Москва, ВАО, район Перово, Владимирская 3-я ул, дом 26А		0101000020E61000004776A565A4E44240BEDA519CA3E04B40
56131	1	\N	\N	1	13035	\N	55.762247000000002	город Москва, ВАО, район Перово, Владимирская 3-я ул, дом 5		0101000020E6100000B0AD9FFEB3E44240B03C484F91E14B40
56129	1	\N	\N	1	13035	\N	55.753909	город Москва, ВАО, район Перово, Владимирская 3-я ул, дом 30А		0101000020E610000023BDA8DDAFE442407D94111780E04B40
56127	1	\N	\N	1	13035	\N	55.759526999999999	город Москва, ВАО, район Перово, Владимирская 3-я ул, дом 12А		0101000020E61000001F80D4264EE44240E9B6442E38E14B40
55852	1	\N	\N	1	6523	\N	55.795864000000002	город Москва, СВАО, район Марьина роща, Марьиной рощи 3-й пр, дом 41	Россия, Москва, 3-й проезд Марьиной Рощи, 41	0101000020E6100000BA4C4D8237CE424029081EDFDEE54B40
55487	1	\N	\N	1	1984	\N	55.779756999999996	Адрес помещения для голосования: город Москва, ЦАО, Тверской район, Самотечный 3-й пер., дом 14, адрес УИК: Самотечная ул, дом 11	Россия, Москва, 3-й Самотечный переулок, 14	0101000020E6100000A4C519C39CCE4240DDE9CE13CFE34B40
56473	1	\N	\N	1	6153	\N	55.718344000000002	Адрес помещения для голосования: город Москва, ЮАО, Даниловский район, Павловский 3-й пер., дом 14, адрес УИК: Павловский 2-й пер, дом 3	Россия, Москва, 3-й Павловский переулок, 14	0101000020E6100000B64DF1B8A8D0424090A339B2F2DB4B40
55586	1	\N	\N	1	3371	\N	55.819600000000001	город Москва, САО, Войковский район, Новоподмосковный 3-й пер, дом 7	Россия, Москва, 3-й Новоподмосковный переулок, 7	0101000020E6100000DD99098673C142409BE61DA7E8E84B40
55585	1	\N	\N	1	3371	\N	55.819600000000001	Адрес помещения для голосования: город Москва, САО, Войковский район, Новоподмосковный 3-й пер., дом 7, адрес УИК: Новоподмосковный 3-й пер, дом 6	Россия, Москва, 3-й Новоподмосковный переулок, 7	0101000020E6100000DD99098673C142409BE61DA7E8E84B40
55707	1	\N	\N	1	12397	\N	55.847645448429901	город Москва, САО, Тимирязевский район, Лихоборский нижн. 3-й пр, дом 1, стр. 16	Россия, Москва, 3-й Нижнелихоборский проезд, 1с16	0101000020E610000031B1F9B836C8424018CFA0A17FEC4B40
55656	1	\N	\N	1	4281	\N	55.836134999999999	город Москва, САО, район Коптево, Михалковский 3-й пер, дом 16	Россия, Москва, 3-й Михалковский переулок, 16	0101000020E6100000C26D6DE179C342403E05C07806EB4B40
57152	1	\N	\N	1	6346	\N	55.846062000000003	город Москва, СЗАО, район Митино, Митинский 3-й пер, дом 12	Россия, Москва, 3-й Митинский проезд, 12	0101000020E61000007381CB63CDAC4240B63176C24BEC4B40
57151	1	\N	\N	1	6346	\N	55.846249	город Москва, СЗАО, район Митино, Митинский 3-й пер, дом 12, корп. 1	Россия, Москва, 3-й Митинский проезд, 12к1	0101000020E6100000580394861AAD4240E8A221E351EC4B40
55602	1	\N	\N	1	3579	\N	55.846851000000001	город Москва, САО, Головинский район, Лихачевский 3-й пер, дом 2А	Россия, Москва, 3-й Лихачевский переулок, 2а	0101000020E61000002191B6F127C24240DECA129D65EC4B40
56413	1	\N	\N	1	5491	\N	55.707769999999996	город Москва, ЮВАО, Южнопортовый район, Кожуховский 3-й пр, дом 3А	Россия, Москва, 3-й Кожуховский проезд, 3а	0101000020E61000009D2CB5DE6FD64240828B153598DA4B40
55522	1	\N	\N	1	2479	\N	55.741754	город Москва, ЦАО, район Якиманка, Кадашевский 3-й пер, дом 9	Россия, Москва, 3-й Кадашевский переулок, 9	0101000020E61000005C397B67B4CF4240AED689CBF1DE4B40
56658	1	\N	\N	1	13079	\N	55.599713000000001	город Москва, ЮАО, район Чертаново Южное, Дорожный 3-й пр, дом 6А		0101000020E61000005A66118AADCE424037FE4465C3CC4B40
57093	1	\N	\N	1	12720	\N	55.657113000000003	город Москва, ЗАО, район Тропарево-Никулино, Двадцати Шести Бакинских Комиссаров ул, дом 3, корп.4		0101000020E6100000A585CB2A6CBE424063635E471CD44B40
57092	1	\N	\N	1	12720	\N	55.656016000000001	город Москва, ЗАО, район Тропарево-Никулино, Двадцати Шести Бакинских Комиссаров ул, дом 3, корп.5		0101000020E61000002A58E36C3ABE42408DD31055F8D34B40
55443	1	\N	\N	1	12508	\N	55.762817684565199	город Москва, ЦАО, Пресненский район, Черногрязская 2-я ул, дом 7	Россия, Москва, 2-я Черногрязская улица, 7с1	0101000020E61000009415C3D501C642406B662D05A4E14B40
55675	1	\N	\N	1	4550	\N	55.805948000000001	город Москва, САО, Савеловский район, Хуторская 2-я ул, дом 15/17	Россия, Москва, 2-я Хуторская улица, 15	0101000020E61000005665DF15C1C942406823D74D29E74B40
55509	1	\N	\N	1	12858	\N	55.722141999999998	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Фрунзенская 2-я ул., дом 7а, адрес УИК: Фрунзенская 2-я ул, дом 7		0101000020E6100000D9B0A6B228CA4240B58828266FDC4B40
55479	1	\N	\N	1	13012	\N	55.774441000000003	город Москва, ЦАО, Тверской район, Тверская-Ямская 2-я ул, дом 46		0101000020E61000008C834BC79CCB42403DD7F7E120E34B40
55571	1	\N	\N	1	12461	\N	55.819735516559703	город Москва, САО, Войковский район, Радиаторская 2-я ул, дом 3		0101000020E610000095D8B5BDDDBE42404BADF71BEDE84B40
55573	1	\N	\N	1	12895	\N	55.819808000000002	Адрес помещения для голосования: город Москва, САО, Войковский район, Радиаторская 2-я ул., дом 9, адрес УИК: Войковский 4-й пр, дом 9		0101000020E6100000A2EE0390DABE4240E57FF277EFE84B40
55572	1	\N	\N	1	12895	\N	55.819807999666402	город Москва, САО, Войковский район, Радиаторская 2-я ул, дом 9	Россия, Москва, 2-я Радиаторская улица, 9	0101000020E61000009F1EDB32E0BE4240E57FF277EFE84B40
56139	1	\N	\N	1	13171	\N	55.792316	город Москва, ВАО, район Преображенское, Пугачевская 2-я ул, дом 10		0101000020E610000090831266DADC42407C0C569C6AE54B40
56141	1	\N	\N	1	12679	\N	55.795585000000003	город Москва, ВАО, район Преображенское, Пугачевская 2-я ул, дом 7		0101000020E61000003FC91D3691DD42401618B2BAD5E54B40
56140	1	\N	\N	1	12679	\N	55.795569999999998	город Москва, ВАО, район Преображенское, Пугачевская 2-я ул, дом 6		0101000020E6100000BA83D89942DD4240E0D6DD3CD5E54B40
55696	1	\N	\N	1	4768	\N	55.794173000000001	Адрес помещения для голосования: город Москва, САО, район Сокол, Песчаная 2-я ул., дом 4А, адрес УИК: Новопесчаная ул, дом 23, корп.1	Россия, Москва, 2-я Песчаная улица, 4а	0101000020E6100000BE4A3E7617C24240E02EFB75A7E54B40
55833	1	\N	\N	1	13005	\N	55.879440000000002	город Москва, СВАО, Лосиноостровский район, Напрудная 2-я ул, дом 17		0101000020E6100000680932022AD84240AA656B7D91F04B40
56376	1	\N	\N	1	12680	\N	55.724429000000001	город Москва, ЮВАО, Рязанский район, Институтская 2-я ул, дом 6		0101000020E6100000384E0AF31EE3424012A3E716BADC4B40
55444	1	\N	\N	1	1335	\N	55.761375999999998	Адрес помещения для голосования: город Москва, ЦАО, Пресненский район, Звенигородская 2-я ул., дом 13, стр. 41, адрес УИК: Шмитовский пр, дом 2, стр. 3	Россия, Москва, 2-я Звенигородская улица, 13с41	0101000020E61000009E5F94A0BFC64240CAFACDC474E14B40
55442	1	\N	\N	1	13154	\N	55.759410000000003	Адрес помещения для голосования: город Москва, ЦАО, Пресненский район, Звенигородская 2-я ул., дом 8, адрес УИК: 1905 года ул, дом 5		0101000020E6100000485167EE21C74240B020CD5834E14B40
55441	1	\N	\N	1	13153	\N	55.759410000000003	Адрес помещения для голосования, город Москва, ЦАО, Пресненский район, Звенигородская 2-я ул., дом 8, адрес УИК: 1905 года ул, дом 5		0101000020E6100000485167EE21C74240B020CD5834E14B40
55467	1	\N	\N	1	12660	\N	55.728985999999999	Адрес помещения для голосования: город Москва, ЦАО, Таганский район, Дубровская 2-я ул., дом 3, адрес УИК: Дубровская 1-я ул, дом 5А		0101000020E6100000F01307D0EFD54240F59ECA694FDD4B40
55962	1	\N	\N	1	7650	\N	55.813592	город Москва, ВАО, район Богородское, Гражданская 2-я ул, дом 8	Россия, Москва, 2-я Гражданская улица, 8	0101000020E610000093FFC9DFBDD94240C4245CC823E84B40
56345	1	\N	\N	1	12805	\N	55.687993798738603	город Москва, ЮВАО, район Некрасовка, Вольская 2-я ул, дом 7, корп. 2	Россия, Москва, поселок Некрасовка, 2-я Вольская улица, 7к2	0101000020E61000001BF1643733F6424010ECF82F10D84B40
56123	1	\N	\N	1	13138	\N	55.755920000000003	город Москва, ВАО, район Перово, Владимирская 2-я ул, дом 22А		0101000020E6100000637B2DE8BDE3424038328FFCC1E04B40
56422	1	\N	\N	1	5578	\N	55.700206999999999	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Южнопортовый 2-й пр., дом 11, адрес УИК: Трофимова ул, дом 24, корп. 1	Россия, Москва, 2-й Южнопортовый проезд, 11с1	0101000020E610000030D7A20568D7424013B70A62A0D94B40
56421	1	\N	\N	1	5578	\N	55.700206999999999	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Южнопортовый 2-й пр., дом 11, адрес УИК: Южнопортовый 2-й пр, дом 19	Россия, Москва, 2-й Южнопортовый проезд, 11с1	0101000020E610000030D7A20568D7424013B70A62A0D94B40
56491	1	\N	\N	1	6335	\N	55.703935999999999	Адрес помещения для голосования: город Москва, ЮАО, Донской район, Тульский 2-й пер., дом 4/8, адрес УИК: Варшавское шоссе, дом 2		0101000020E6100000088F368E58CF4240103D29931ADA4B40
55413	1	\N	\N	1	884	\N	55.775647008584102	город Москва, ЦАО, Мещанский район, Троицкий 2-й пер, дом 6А	Россия, Москва, 2-й Троицкий переулок, 6	0101000020E61000003221E692AACF4240C91EA16648E34B40
57043	1	\N	\N	1	5127	\N	55.730699999999999	город Москва, ЗАО, район Раменки, Сетуньский 2-й пр, дом 9	Россия, Москва, 2-й Сетуньский проезд, 9	0101000020E6100000B32781CD39C44240F697DD9387DD4B40
55893	1	\N	\N	1	6918	\N	55.833601999999999	город Москва, СВАО, район Ростокино, Сельскохозяйственный 2-й пр, дом 4	Россия, Москва, 2-й Сельскохозяйственный проезд, 4	0101000020E6100000A6D0798D5DD24240AAF06778B3EA4B40
55493	1	\N	\N	1	2054	\N	55.741332999999997	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Обыденский 2-й пер., дом 9, адрес УИК: Сеченовский пер, дом 5	Россия, Москва, 2-й Обыденский переулок, 9	0101000020E61000007AFCDEA63FCD42400839EFFFE3DE4B40
55410	1	\N	\N	1	840	\N	55.784363999999997	город Москва, ЦАО, Красносельский район, Красносельский 2-й пер, дом 18	Россия, Москва, 2-й Красносельский переулок, 18	0101000020E61000002F6EA301BCD542407214200A66E44B40
56351	1	\N	\N	1	4726	\N	55.730151999999997	город Москва, ЮВАО, Нижегородский район, Карачаровский 2-й пр, дом 1/1	Россия, Москва, 2-й Карачаровский проезд, 1	0101000020E6100000D2E28C614EE04240F38DE89E75DD4B40
56489	1	\N	\N	1	6317	\N	55.708084999999997	город Москва, ЮАО, Донской район, Михайловский Верх. 2-й пр, дом 9А	Россия, Москва, 2-й Верхний Михайловский проезд, 9а	0101000020E6100000C15774EB35CD4240E2E47E87A2DA4B40
55536	1	\N	\N	1	2700	\N	55.808360999999998	город Москва, САО, район Аэропорт, Балтийский 2-й пер, дом 3	Россия, Москва, 2-й Балтийский переулок, 3	0101000020E610000055DCB8C5FCC24240512E8D5F78E74B40
56165	1	\N	\N	1	12353	\N	55.804237999999998	город Москва, ВАО, район Северное Измайлово, Парковая 16-я ул, дом 20		0101000020E610000058FFE7305FEA4240A8195245F1E64B40
56162	1	\N	\N	1	12405	\N	55.8079722980805	город Москва, ВАО, район Северное Измайлово, Парковая 15-я ул, дом 46	Россия, Москва, 15-я Парковая улица, 46а	0101000020E6100000A7936C7539E94240B70A62A06BE74B40
56158	1	\N	\N	1	12349	\N	55.807485999999997	город Москва, ВАО, район Северное Измайлово, Парковая 13-я ул, дом 33	Россия, Москва, 13-я Парковая улица, 33	0101000020E61000003B1C5DA5BBE742402AFD84B35BE74B40
56381	1	\N	\N	1	13210	\N	55.714556000000002	город Москва, ЮВАО, Рязанский район, Новокузьминская 12-я ул, дом 6, корп. 2		0101000020E6100000629E95B4E2E342408E942D9276DB4B40
56393	1	\N	\N	1	13219	\N	55.706009999999999	город Москва, ЮВАО, район Текстильщики, Текстильщиков 11-я ул, дом 6		0101000020E6100000D1C952EBFDDE4240115322895EDA4B40
56157	1	\N	\N	1	12338	\N	55.807293999999999	город Москва, ВАО, район Северное Измайлово, Парковая 11-я ул, дом 50	Россия, Москва, 11-я Парковая улица, 50	0101000020E610000015E63DCE34E74240E620E86855E74B40
55996	1	\N	\N	1	12359	\N	55.801116	город Москва, ВАО, район Восточное Измайлово, Парковая 11-я ул, дом 36	Россия, Москва, 11-я Парковая улица, 36	0101000020E6100000F52A323A20E74240B32616F88AE64B40
56394	1	\N	\N	1	5242	\N	55.701618000000003	город Москва, ЮВАО, район Текстильщики, Текстильщиков 1-я ул, дом 5/8	Россия, Москва, 1-я улица Текстильщиков, 5/8	0101000020E6100000E3FC4D2844DE424079245E9ECED94B40
56409	1	\N	\N	1	5434	\N	55.713309000000002	город Москва, ЮВАО, Южнопортовый район, Машиностроения 1-я ул, дом 12А	Россия, Москва, 1-я улица Машиностроения, 12к2	0101000020E61000004F90D8EE1ED64240A37895B54DDB4B40
13819	6	33	\N	1053	40587	\N	66.530936999999994	Ямало-Ненецкий автономный округ, город Салехард, Республики, 50		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
56408	1	\N	\N	1	5434	\N	55.715651999999999	город Москва, ЮВАО, Южнопортовый район, Машиностроения 1-я ул, дом 3/5	Россия, Москва, 1-я улица Машиностроения, 3/5а	0101000020E6100000CC9A58E02BD6424093A8177C9ADB4B40
56395	1	\N	\N	1	13112	\N	55.701227000000003	город Москва, ЮВАО, район Текстильщики, Текстильщиков 1-я ул, дом 16		0101000020E61000008C2E6F0ED7DE42403E096CCEC1D94B40
56051	1	\N	\N	1	13229	\N	55.790711999999999	город Москва, ВАО, район Измайлово, Парковая 1-я ул, дом 12		0101000020E61000005E8429CAA5E342400247020D36E54B40
55866	1	\N	\N	1	12847	\N	55.824683	город Москва, СВАО, Останкинский район, Останкинская 1-я ул, дом 29		0101000020E610000074435376FACF4240994869368FE94B40
56380	1	\N	\N	1	5080	\N	55.714388999999997	город Москва, ЮВАО, Рязанский район, Новокузьминская 1-я ул, дом 21	Россия, Москва, 1-я Новокузьминская улица, 21	0101000020E6100000CEFE40B96DE54240A2CF471971DB4B40
56384	1	\N	\N	1	13215	\N	55.712705	город Москва, ЮВАО, Рязанский район, Новокузьминская 1-я ул, дом 20, корп. 4		0101000020E6100000A1116C5CFFE442400C59DDEA39DB4B40
55957	1	\N	\N	1	12898	\N	55.816788000000003	город Москва, ВАО, район Богородское, Мясниковская 1-я ул, дом 16		0101000020E61000006AF5D55581DA4240F4E159828CE84B40
55476	1	\N	\N	1	1823	\N	55.779736999999997	город Москва, ЦАО, Тверской район, Миусская 1-я ул, дом 4	Россия, Москва, 1-я Миусская улица, 4	0101000020E6100000A6ED5F5969CC4240963D096CCEE34B40
56405	1	\N	\N	1	5390	\N	55.723267999999997	город Москва, ЮВАО, Южнопортовый район, Дубровская 1-я ул, дом 16	Россия, Москва, 1-я Дубровская улица, 16	0101000020E6100000B79A75C6F7D54240251FBB0B94DC4B40
56406	1	\N	\N	1	13110	\N	55.723267999999997	Адрес помещения для голосования: город Москва, ЮВАО, Южнопортовый район, Дубровская 1-я ул., дом 16, адрес УИК: Симоновский вал ул, дом 11/31		0101000020E6100000B79A75C6F7D54240251FBB0B94DC4B40
55970	1	\N	\N	1	12809	\N	55.807223	город Москва, ВАО, район Богородское, Гражданская 1-я ул, дом 96		0101000020E61000005C3CBCE7C0DA42401DCA501553E74B40
56346	1	\N	\N	1	12496	\N	55.6843399195836	город Москва, ЮВАО, район Некрасовка, Вольская 1-я ул, дом 9, корп. 3	Россия, Москва, поселок Некрасовка, 1-я Вольская улица, 9к3	0101000020E6100000881057CEDEF542401DACFF7398D74B40
56344	1	\N	\N	1	12496	\N	55.683548999999999	город Москва, ЮВАО, район Некрасовка, Вольская 1-я ул, дом 5		0101000020E6100000957F2DAF5CF54240541B9C887ED74B40
56122	1	\N	\N	1	1663	\N	55.754218000000002	город Москва, ВАО, район Перово, Владимирская 1-я ул, дом 20	Россия, Москва, 1-я Владимирская улица, 20	0101000020E61000000ABDFE243EE34240FB0626378AE04B40
56124	1	\N	\N	1	12524	\N	55.759841000000002	город Москва, ВАО, район Перово, Владимирская 1-я ул, дом 11/13		0101000020E6100000D65757056AE3424079944A7842E14B40
55532	1	\N	\N	1	12621	\N	55.800660999999998	город Москва, САО, район Аэропорт, Аэропортовская 1-я ул, дом 1/3		0101000020E6100000247D5A457FC442406117450F7CE64B40
55849	1	\N	\N	1	6491	\N	55.793748000000001	город Москва, СВАО, район Марьина роща, Марьиной рощи 1-й пр, дом 3А	Россия, Москва, 1-й проезд Марьиной Рощи, 3а	0101000020E6100000EA060ABC93CF4240F9A1D28899E54B40
55502	1	\N	\N	1	2173	\N	55.737076000000002	город Москва, ЦАО, район Хамовники, Тружеников 1-й пер, дом 18	Россия, Москва, 1-й переулок Тружеников, 18	0101000020E6100000176536C824C942405055A18158DE4B40
55400	1	\N	\N	1	703	\N	55.724839000000003	город Москва, ЦАО, район Замоскворечье, Щипковский 1-й пер, дом 23	Россия, Москва, 1-й Щипковский переулок, 23	0101000020E6100000CD3AE3FBE2D04240C4EE3B86C7DC4B40
55732	1	\N	\N	1	5218	\N	55.776330000000002	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Хорошевский 1-й пр., дом 8, адрес УИК: Хорошевский 1-й пр, дом 2/17		0101000020E6100000B6A0F7C610C64240AC730CC85EE34B40
57177	1	\N	\N	1	6596	\N	55.832706999999999	Адрес помещения для голосования: город Москва, СЗАО, район Покровское-Стрешнево, Тушинский 1-й пр., дом 13, адрес УИК: Тушинский 1-й пр, дом 7	Россия, Москва, 1-й Тушинский проезд, 13	0101000020E610000005C4245CC8B542403C139A2496EA4B40
55391	1	\N	\N	1	559	\N	55.735154999999999	город Москва, ЦАО, район Замоскворечье, Новокузнецкий 1-й пер, дом 12	Россия, Москва, 1-й Новокузнецкий переулок, 12	0101000020E6100000F9BB77D498D04240D53E1D8F19DE4B40
55498	1	\N	\N	1	2128	\N	55.740907	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Неопалимовский 1-й пер., дом 10а, адрес УИК: Смоленский бульв, дом 15		0101000020E6100000DFC4909C4CCA42405130630AD6DE4B40
56516	1	\N	\N	1	6577	\N	55.676585000000003	город Москва, ЮАО, район Нагатино-Садовники, Нагатинский 1-й пр, дом 16	Россия, Москва, 1-й Нагатинский проезд, 16	0101000020E610000097A8DE1AD8D042406AFB57569AD64B40
56367	1	\N	\N	1	4918	\N	55.657361999999999	город Москва, ЮВАО, район Печатники, Курьяновский 1-й пр, дом 14	Россия, Москва, 1-й Курьяновский проезд, 14	0101000020E61000007EFFE6C589D942400BD1217024D44B40
56480	1	\N	\N	1	13190	\N	55.708069999999999	Адрес помещения для голосования: город Москва, ЮАО, Даниловский район, Кожуховский 1-й пр., дом 17, адрес УИК: Кожуховский 1-й пр, дом 19, корп. 1		0101000020E610000097FF907EFBD44240ADA3AA09A2DA4B40
56135	1	\N	\N	1	1818	\N	55.799937	город Москва, ВАО, район Преображенское, Зборовский 1-й пер, дом 3	Россия, Москва, 1-й Зборовский переулок, 3	0101000020E61000008F6E844545DA424020EEEA5564E64B40
55501	1	\N	\N	1	2168	\N	55.739803000000002	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Вражский 1-й пер., дом 4, адрес УИК: Плющиха ул, дом 30		0101000020E61000006EFC89CA86C94240C93D5DDDB1DE4B40
57261	1	\N	\N	1	7426	\N	55.801268	город Москва, СЗАО, район Щукино, Волоколамский 1-й пр, дом 9, корп. 1	Россия, Москва, 1-й Волоколамский проезд, 9к1	0101000020E610000015FE0C6FD6BE424069AA27F38FE64B40
56377	1	\N	\N	1	5046	\N	55.723368999999998	город Москва, ЮВАО, Рязанский район, Вешняковский 1-й пр, дом 6/10	Россия, Москва, 1-й Вешняковский проезд, 6/10	0101000020E61000003A07CF8426E5424059F8FA5A97DC4B40
55551	1	\N	\N	1	2929	\N	55.784002967518902	город Москва, САО, район Беговой, Боткинский 1-й пр, дом 31А	Россия, Москва, 1-й Боткинский проезд	0101000020E6100000DA03ADC090C74240A27BD6355AE44B40
55905	1	\N	\N	1	7030	\N	55.850707	город Москва, СВАО, район Свиблово, Ботанический 1-й пр, дом 2	Россия, Москва, 1-й Ботанический проезд, 2	0101000020E6100000ADF886C267D1424038BD8BF7E3EC4B40
55538	1	\N	\N	1	2734	\N	55.811588999999998	город Москва, САО, район Аэропорт, Амбулаторный 1-й пр, дом 8	Россия, Москва, 1-й Амбулаторный проезд, 8с1	0101000020E6100000D9CD8C7E34C442408C65FA25E2E74B40
56347	1	\N	\N	1	13050	\N	55.682442000000002	город Москва, ЮВАО, район Некрасовка, Вольская 1-я ул, дом 22, корп. 2		0101000020E61000008D800A4790F642405BB56B425AD74B40
56397	1	\N	\N	1	12518	\N	55.700775	город Москва, ЮВАО, район Текстильщики, Юных ленинцев ул, дом 35, корп. 2		0101000020E610000012842BA050DF42405D6DC5FEB2D94B40
55511	1	\N	\N	1	13177	\N	55.7170786851852	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Хамовнический Вал ул., дом 6, адрес УИК: Фрунзенская 3-я ул, дом 3	Россия, Москва, улица Хамовнический Вал, 6	0101000020E6100000637B2DE8BDC94240FED2A23EC9DB4B40
56243	1	\N	\N	1	13120	\N	55.713293999999998	город Москва, ЮВАО, район Кузьминки, Полетаева Федора ул, дом 2, корп. 7		0101000020E610000055C03DCF9FE242406D37C1374DDB4B40
55503	1	\N	\N	1	12763	\N	55.736265000000003	Адрес помещения для голосования: город Москва, ЦАО, район Хамовники, Фрунзе Тимура ул., дом 28, адрес УИК: Зубовский пр, дом 2, стр. 2		0101000020E61000000C1F115322CB4240401878EE3DDE4B40
56416	1	\N	\N	1	12957	\N	55.703746101201503	город Москва, ЮВАО, Южнопортовый район, Романова Петра ул, дом 16	Россия, Москва, улица Петра Романова, 16	0101000020E6100000950B957F2DD742406D58535914DA4B40
55980	1	\N	\N	1	12906	\N	55.720854000000003	город Москва, ВАО, район Вешняки, Молдагуловой ул, дом 13А		0101000020E610000043FF04172BEA42406C98A1F144DC4B40
55816	1	\N	\N	1	12918	\N	55.822947999999997	город Москва, СВАО, Бутырский район, Милашенкова ул, дом 7А		0101000020E6100000B95164ADA1CA424080272D5C56E94B40
56306	1	\N	\N	1	12881	\N	55.667350999999996	город Москва, ЮВАО, район Люблино, Марьинский парк ул, дом 37		0101000020E6100000F775E09C11E54240F8F9EFC16BD54B40
57259	1	\N	\N	1	13084	\N	55.795115000000003	город Москва, СЗАО, район Щукино, Рыбалко маршала ул, дом 1		0101000020E61000003830B95164BF42408FC70C54C6E54B40
56568	1	\N	\N	1	12468	\N	55.618919568407897	город Москва, ЮАО, район Орехово-Борисово Северное, Захарова маршала ул, дом 25	Россия, Москва, улица Маршала Захарова, 25	0101000020E6100000E84D452A8CD94240906B43C538CF4B40
55739	1	\N	\N	1	13036	\N	55.783706000000002	Адрес помещения для голосования: город Москва, САО, Хорошевский район, Куусинена ул., дом 13, адрес УИК: Куусинена ул, дом 9, корп. 1		0101000020E610000061C26856B6C14240E9D66B7A50E44B40
56632	1	\N	\N	1	12485	\N	55.610453602397001	город Москва, ЮАО, район Чертаново Центральное, Красного Маяка ул, дом 13А	Россия, Москва, улица Красного Маяка, 13а	0101000020E61000007A1C06F357CA42402FDB4E5B23CE4B40
56511	1	\N	\N	1	12889	\N	55.640878000000001	город Москва, ЮАО, район Москворечье-Сабурово, Кошкина ул, дом 13, корп. 2		0101000020E610000054AA44D95BD64240EA5C514A08D24B40
56664	1	\N	\N	1	12711	\N	55.591203992068003	город Москва, ЮАО, район Чертаново Южное, Газопровод ул, дом 5А	Россия, Москва, улица Газопровод, 5а	0101000020E6100000DAC9E02879CD4240D7A19A92ACCB4B40
56513	1	\N	\N	1	12976	\N	55.636198999999998	город Москва, ЮАО, район Москворечье-Сабурово, Борисовские пруды ул, дом 11, корп. 1		0101000020E6100000F7E7A221E3DB4240BB5F05F86ED14B40
57155	1	\N	\N	1	13068	\N	55.854643000000003	город Москва, СЗАО, район Митино, Барышиха ул, дом 42, корп. 1		0101000020E6100000771211FE45AC4240AF601BF164ED4B40
57150	1	\N	\N	1	13068	\N	55.846366000000003	город Москва, СЗАО, район Митино, Барышиха ул, дом 29, корп. 1		0101000020E61000002976340EF5AB4240223999B855EC4B40
57270	1	\N	\N	1	12893	\N	55.807865	город Москва, СЗАО, район Щукино, Бочвара академика ул, дом 2, корп. 2		0101000020E6100000ACA8C1340CBB4240A14ACD1E68E74B40
57099	1	\N	\N	1	13200	\N	55.658413000000003	город Москва, ЗАО, район Тропарево-Никулино, Анохина Академика ул, дом 36		0101000020E6100000DDE9CE13CFBB424071218FE046D44B40
55435	1	\N	\N	1	12916	\N	55.7670116405125	город Москва, ЦАО, Пресненский район, 1905 года ул, дом 8А	Россия, Москва, улица 1905 Года, 8	0101000020E6100000CA8B4CC0AFC74240DDD1FF722DE24B40
13806	6	33	\N	54908	\N	\N	64.921073705147506	город ТаркоСале, здание МОУ ТС СОШ № 3	Россия, Ямало-Ненецкий автономный округ, Пуровский район, Тарко-Сале	0101000020E6100000959D7E50177253408ACC5CE0F23A5040
13804	6	33	\N	54908	40405	\N	64.917285243251001	ЯмалоНенецкий автономный округ, Пуровский район, Городское поселение город ТаркоСале, Ленина, 16	Россия, Ямало-Ненецкий автономный округ, Пуровский район, Тарко-Сале	0101000020E61000006D74CE4F71725340210725CCB43A5040
13807	6	33	\N	54908	40644	\N	64.917722363480095	ЯмалоНенецкий автономный округ, Пуровский район, Городское поселение город ТаркоСале, Губкина, 9	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E61000005A7F4B00FE71534076340EF5BB3A5040
13825	6	33	\N	1053	40308	\N	66.530936999999994	Ямало-Ненецкий автономный округ, город Салехард, Чкалова, 14		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13827	6	33	\N	1053	40448	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Титова, 19		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13854	6	33	\N	1053	40587	\N	66.527232246092296	ЯмалоНенецкий автономный округ, город Салехард, ул. Республики, д.54 (ГАУ ЯНАО «Ледовый Дворец»)	Россия, Ямало-Ненецкий автономный округ, Приуральский район	0101000020E61000009D853DEDF0A65040E659492BBEA15040
13822	6	33	\N	1053	40587	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Республики, 123		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13793	6	33	295	1281	40809	\N	66.801321323353307	МУ культуры «Дом культуры п. Харп», ул. Дзержинского, д. 7		0101000020E610000009A4C4AEED7350404626E0D748B35040
13818	6	33	\N	1053	40587	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Республики, 36а		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13799	6	33	\N	1053	40587	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Республики, 74		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13824	6	33	\N	1053	40594	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Маяковского, 36		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13811	6	33	\N	1053	40594	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Маяковского, 22		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13820	6	33	\N	1053	40824	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Матросова, 33		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13826	6	33	\N	1053	40440	\N	66.530936999999994	ЯмалоНенецкий автономный округ, город Салехард, Кооперативная, 22а		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13855	6	33	\N	1053	60208	\N	66.527724211891396	ЯмалоНенецкий автономный округ, город Салехард, ул.Комсомольская, д.17 (Средняя общеобразовательная школа №2)	Россия, Ямало-Ненецкий автономный округ, Приуральский район	0101000020E6100000C05AB56B42A850401E54E23AC6A15040
13821	6	33	\N	1053	40727	\N	66.530936999999994	Ямало-Ненецкий автономный округ, город Салехард, Артеева, 17		0101000020E6100000BD5296218EA6504020CF2EDFFAA15040
13786	6	33	\N	54907	\N	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, МОУ СОШ №10		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13785	6	33	\N	54907	\N	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, МОУ СОШ №10		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13738	6	33	\N	54907	\N	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, СМП329		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13773	6	33	\N	54907	40390	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Холмогорская, 66а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13772	6	33	\N	54907	40390	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Холмогорская, 29		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13771	6	33	\N	54907	40390	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Холмогорская, 29		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13788	6	33	\N	54907	40630	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Транспортная, 38		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13787	6	33	\N	54907	40630	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Транспортная, 38		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13780	6	33	\N	54907	40383	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Советская, 19а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13778	6	33	\N	54907	40383	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Советская, 51		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13761	6	33	\N	54907	40383	\N	63.175699999999999	г. Ноябрьск,СОВЕТСКАЯ 79		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13760	6	33	\N	54907	40383	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Советская, 82		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13763	6	33	\N	54907	40495	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Магистральная, 71		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13762	6	33	\N	54907	40495	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Магистральная, 71		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13782	6	33	\N	54907	40399	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Лиственная, 28		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13781	6	33	\N	54907	40399	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Лиственная, 28		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13783	6	33	\N	54907	40582	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, мкрн. Вынгапуровский, Ленина, 29		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13777	6	33	\N	54907	40582	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Ленина, 12		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13776	6	33	\N	54907	40582	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Ленина, 25		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13768	6	33	\N	54907	40582	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Ленина, 41		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13759	6	33	\N	54907	40582	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Ленина, 67а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13708	6	33	\N	54907	40582	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Ленина, 67а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13775	6	33	\N	54907	40502	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Космонавтов, 22а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13774	6	33	\N	54907	40502	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Космонавтов, 22а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13770	6	33	\N	54907	40800	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Изыскателей, 47		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13784	6	33	\N	54907	40804	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, мкрн. Вынгапуровский, Дружбы, 1		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13767	6	33	\N	54907	40386	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Дзержинского, 10в		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13766	6	33	\N	54907	40386	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Дзержинского, 10в		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13765	6	33	\N	54907	40386	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Дзержинского, 7		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13764	6	33	\N	54907	40386	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Дзержинского, 7		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13758	6	33	\N	54907	40424	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, ул. Высоцкого, 40а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13757	6	33	\N	54907	40424	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Высоцкого, 40а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13756	6	33	\N	54907	40424	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, Высоцкого, 40а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13779	6	33	\N	54907	40504	\N	63.175699999999999	Ямало-Ненецкий автономный округ, город Ноябрьск, 60 лет СССР, 7а		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13733	6	33	\N	54905	\N	\N	66.094159000000005	"""ЯмалоНенецкий автономный округ, город Новый Уренгой, ОАО """"Новоуренгойский объединенный авиаотряд"""""""		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13752	6	33	\N	54905	40687	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, р. Коротчаево пр. Мира, д. 53		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13725	6	33	\N	54905	40790	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, пр. Ленинградский, д. 9		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13754	6	33	\N	54905	40380	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Юбилейный, д.6 корп. 1		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13745	6	33	\N	54905	40380	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Юбилейный, д. 6 корп. 3		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13727	6	33	\N	54905	40896	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Энергетик		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13742	6	33	\N	54905	40683	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Советский, д. 3 корп. 3		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13741	6	33	\N	54905	40683	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Советский, д. 10 корп. 2		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13748	6	33	\N	54905	40370	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, р. Лимбяяха мкр. Приозерный, д. 10а		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13731	6	33	\N	54905	40571	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Оптимистов, д. 4 корп.3		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13744	6	33	\N	54905	40366	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Мирный, д. 5 корп. 4		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13743	6	33	\N	54905	40366	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Мирный, д. 5 корп. 6		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13739	6	33	\N	54905	40573	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Дружба, д. 2 корп. 10		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13737	6	33	\N	54905	40721	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Восточный, д. 7		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13730	6	33	\N	54905	40359	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Таежная, д. 51		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13751	6	33	\N	54905	40375	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, р. Коротчаево ул. Октябрьская, д. 22		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13728	6	33	\N	54905	40355	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Молодежная, д. 17а		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13718	6	33	\N	54905	40355	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Молодежная, д. 23		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13755	6	33	\N	54905	40796	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Звездная, д. 16		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13736	6	33	\N	54905	40681	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Губкина, д. 13		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13735	6	33	\N	54905	40681	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Губкина, д. 16а		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13734	6	33	\N	54905	40909	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Газовиков, д. 1		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13753	6	33	\N	54905	40798	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, р. Коротчаево ул. Гагарина, д. 1		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13724	6	33	\N	54905	40786	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. 26 съезда КПСС, д. 4г		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13699	6	33	\N	54904	40346	\N	65.535479736797697	ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, Школа искусств, бульвар Стрижова, 2	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E61000005AB8ACC26624524060EAE74D45625040
13697	6	33	\N	54904	40668	\N	65.542880596592497	"""ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, ДК """"Прометей"""" ООО """"Газпром добыча Надым"""",  Пионерская, 2"""	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E6100000EA758BC058235240AA27F38FBE625040
13693	6	33	\N	54904	40554	\N	65.541172892819205	ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, Дворец торжественных обрядов, Парковая, 4	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E61000001684F23E8E2252409B1E1494A2625040
13791	6	33	295	30219	40585	\N	66.866798000000003	ЯмалоНенецкий автономный округ, Приуральский район, село Белоярск, Новая, 14		0101000020E6100000DBBE47FDF50951403F8F519E79B75040
13704	6	33	\N	54904	40420	\N	65.541742139872795	Ямало-Ненецкий автономный округ, Надымский район, Городское поселение город Надым, МОУ СОШ №6, Набережная им.Оруджева, 55	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E610000060C77F8120235240A837A3E6AB625040
13698	6	33	\N	54904	40420	\N	65.540350617351805	Ямало-Ненецкий автономный округ, Надымский район, Городское поселение город Надым, МОУ СОШ №5, Набережная им.Оруджева, 13/1	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E6100000D7187442E822524019575C1C95625040
13694	6	33	\N	54904	40413	\N	65.541172892819205	Ямало-Ненецкий автономный округ, Надымский район, Городское поселение город Надым, МОУ СОШ №2, Комсомольская, 25-А	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E6100000129F3BC1FE2252409B1E1494A2625040
13692	6	33	\N	54904	40413	\N	65.539180429986402	Ямало-Ненецкий автономный округ, Надымский район, Городское поселение город Надым, МОУ СОШ №1, Комсомольская, 2	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E61000004E2503401523524011AAD4EC81625040
13703	6	33	\N	54904	40625	\N	65.5371878144758	Ямало-Ненецкий автономный округ, Надымский район, Городское поселение город Надым, Центр детского творчества, Зверева, 42-А	Россия, Ямало-Ненецкий автономный округ, Надым	0101000020E6100000774EB340BB2252406FF3C64961625040
13701	6	33	\N	54904	40416	\N	65.528005577836893	ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, МОУ СОШ №9, Заводская, 7А	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E61000006AA510C825235240E085ADD9CA615040
13700	6	33	\N	54904	40416	\N	65.538895779975604	Ямало-Ненецкий автономный округ, Надымский район, Городское поселение город Надым, МОУ СОШ №9, Заводская, 7-А	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E6100000EA758BC0582352407EFCA5457D625040
13695	6	33	\N	54904	40780	\N	65.540603633302894	ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, МОУ СОШ №3,  Геологоразведчиков, 5/1	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E610000089F02F82C62252408E05854199625040
13675	6	33	\N	24742	40513	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, площадь В.Нака, 2		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13676	6	33	\N	24742	40535	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, Школьная, 43		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13674	6	33	\N	24742	40535	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, Школьная, 18		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13682	6	33	\N	24742	40333	\N	66.653499999999994	г.Лабытнанги, ул.Революции, д.14, МОУ СОШ № 5 (корпус 2)		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13671	6	33	\N	24742	40607	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, Рабочая, 1		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13673	6	33	\N	24742	40328	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, Октябрьская, 17		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13672	6	33	\N	24742	40328	\N	66.653499999999994	Ямало-Ненецкий автономный округ, город Лабытнанги, Октябрьская, 17		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13681	6	33	\N	24742	40718	\N	66.653499999999994	Ямало-Ненецкий автономный округ, город Лабытнанги, Корчагинцев, 7		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13680	6	33	\N	24742	40715	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, Дзержинского, 45		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13677	6	33	\N	24742	40715	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, Дзержинского, 20		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13679	6	33	\N	24742	40407	\N	66.653499999999994	ЯмалоНенецкий автономный округ, город Лабытнанги, Гиршгорна, 53А		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13678	6	33	\N	24742	40407	\N	66.653499999999994	Ямало-Ненецкий автономный округ, город Лабытнанги, Гиршгорна, 53А		0101000020E61000000E6954E064995040E7FBA9F1D2A95040
13667	6	33	\N	54903	40326	\N	64.436010921921195	г. Губкинский, микрорайон № 5, МЦ «Факел»	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E61000004243FF04171E53408F6CAE9AE71B5040
13662	6	33	\N	54903	40894	\N	64.437345914787997	ЯмалоНенецкий автономный округ, город Губкинский, 4 микрорайон, МОУ СОШ № 5	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E61000004243FF04171E534055C2137AFD1B5040
13659	6	33	\N	54903	40855	\N	64.439340025870294	ЯмалоНенецкий автономный округ, город Губкинский, 2 микрорайон, МОУ СОШ № 1	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E61000006A6CAF05BD1D5340C7F484251E1C5040
13666	6	33	\N	54903	40512	\N	64.439340025870294	"""ЯмалоНенецкий автономный округ, город Губкинский, 14 микрорайон, СОК """"Ямал"""""""	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E6100000DE9387855A1E5340C7F484251E1C5040
13849	6	33	181	55011	41252	\N	66.872350826271401	ЯмалоНенецкий автономный округ, Ямальский район, ЯрСалинское сельское поселение, Худи Сэроко, 8	Россия, Ямало-Ненецкий автономный округ, Ямальский район	0101000020E6100000B03A72A433B5514081E84999D4B75040
13850	6	33	181	54999	41037	\N	66.906344835829202	ЯмалоНенецкий автономный округ, Ямальский район, СюнайСале, Анагуричи, 22	Россия, Ямало-Ненецкий автономный округ, Ямальский район, поселок Сюнэйсале	0101000020E610000033DDEBA4BECF51402979758E01BA5040
13853	6	33	181	52202	40707	\N	70.163289000000006	ЯмалоНенецкий автономный округ, Ямальский район, Сельское поселение село Сеяха, Вануйто, 9		0101000020E610000010EA2285B2205240FBB2B453738A5140
13847	6	33	181	52189	40893	\N	66.757926999999995	ЯмалоНенецкий автономный округ, Ямальский район, Сельское поселение село Салемал, Гагарина, 17		0101000020E6100000386BF0BE2A4A514058703FE081B05040
13848	6	33	181	686	40833	\N	66.751555999999994	с.Панаевск, ул. Обская, д. 6, МОШИ Панаевская ШколаИнтернат		0101000020E6100000D26D895C708651403447567E19B05040
13851	6	33	181	54939	40601	\N	67.693183825964994	ЯмалоНенецкий автономный округ, Ямальский район, Сельское поселение село Новый порт, Полярная, 1	Россия, Ямало-Ненецкий автономный округ, Ямальский район	0101000020E61000009E060C923E39524012876C205DEC5040
13852	6	33	181	61043	77037	\N	68.468509461082405	ЯмалоНенецкий автономный округ, Ямальский район, МысКаменское сельское поселение, Геологов, 5	Россия, Ямало-Ненецкий автономный округ, Ямальский район, поселок Мыс-Каменный	0101000020E610000033DE567A6D6652406D382C0DFC1D5140
13846	6	33	49	568	40891	\N	65.908147999999997	ЯмалоНенецкий автономный округ, Шурышкарский район, село Шурышкары, Центральная, 13а		0101000020E6100000F5F23B4D6656504061FBC9181F7A5040
13845	6	33	49	477	40920	\N	65.836477000000002	ЯмалоНенецкий автономный округ, Шурышкарский район, село Питляр, Советская, 19		0101000020E610000067614F3BFC7A5040CCB6D3D688755040
13844	6	33	49	412	40871	\N	64.834408999999994	ЯмалоНенецкий автономный округ, Шурышкарский район, село Овгорт, Кооперативная, 30		0101000020E6100000FC5580EF36FD4F403C9F01F566355040
13843	6	33	49	329	40829	\N	65.404264999999995	ЯмалоНенецкий автономный округ, Шурышкарский район, село Мужи, Комсомольская, 3		0101000020E6100000AE7FD767CE2C5040B77A4E7ADF595040
13842	6	33	49	281	40941	\N	64.994506999999999	ЯмалоНенецкий автономный округ, Шурышкарский район, село Лопхари, Советская, 8		0101000020E6100000C79E3D97A96E50402829B000A63F5040
13792	6	33	49	57607	60140	\N	66.323883550722798	ЯмалоНенецкий автономный округ, Приуральский район, село Катравож, Школьная, 1	Россия, Ямало-Ненецкий автономный округ, Шурышкарский район	0101000020E6100000AD32535A7F855040A7ECF483BA945040
13841	6	33	49	230	40481	\N	65.058744000000004	ЯмалоНенецкий автономный округ, Шурышкарский район, село Горки, Заводская, 8		0101000020E610000020B6F468AA51504085B53176C2435040
13840	6	33	49	168	40906	\N	65.573417000000006	ЯмалоНенецкий автономный округ, Шурышкарский район, село Восяхово, Советская, 17а		0101000020E610000049D576137C2550401C7E37DDB2645040
13839	6	33	49	57	40899	\N	64.8964	ЯмалоНенецкий автономный округ, Шурышкарский район, село Азовы, ул.Школьная, д.8		0101000020E6100000B7F0BC546C4350409A081B9E5E395040
13832	6	33	347	32450	40889	\N	67.475746476677699	ЯмалоНенецкий автономный округ, Тазовский район, Городское поселение поселок Тазовский, Пристанская, 23	Россия, Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский	0101000020E6100000F418E59997AD5340FBCC599F72DE5040
13837	6	33	347	32450	40881	\N	67.475271000000006	п. Тазовский ул. Почтовая, д. 31, МБУ «Тазовский районный краеведческий музей»		0101000020E6100000B8E52329E9AD53402F6F0ED76ADE5040
13831	6	33	347	32450	40886	\N	67.477114091291696	ЯмалоНенецкий автономный округ, Тазовский район, Городское поселение поселок Тазовский, Пиеттомина, 10	Россия, Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский	0101000020E6100000A4880CAB78AD5340AE9D280989DE5040
13830	6	33	347	32450	40828	\N	67.475680648942799	ЯмалоНенецкий автономный округ, Тазовский район, Городское поселение поселок Тазовский, Ленина, 30	Россия, Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский	0101000020E6100000E00ED4298FAD53400795B88E71DE5040
13829	6	33	347	32450	40703	\N	67.475417343207198	ЯмалоНенецкий автономный округ, Тазовский район, Городское поселение поселок Тазовский, Геофизиков, 28а	Россия, Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский	0101000020E6100000A4880CAB78AD534098BD6C3B6DDE5040
13838	6	33	347	57600	\N	\N	66.743989185037805	ЯмалоНенецкий автономный округ, Тазовский район, п. Новозаполярный, Культурноспортивный комплекс		0101000020E6100000BF4692205CE253405CE509849DAF5040
13834	6	33	347	52166	40860	\N	67.726669000000001	ЯмалоНенецкий автономный округ, Тазовский район, Сельское поселение село Находка, Подгорная, 2		0101000020E61000009B8E006E166353401781B1BE81EE5040
13836	6	33	347	52173	40725	\N	70.894789000000003	ЯмалоНенецкий автономный округ, Тазовский район, Сельское поселение село Гыда, Советская, 3		0101000020E6100000EB55647440A0534084F4143944B95140
13833	6	33	347	52165	40704	\N	67.367553000000001	ЯмалоНенецкий автономный округ, Тазовский район, Сельское поселение село ГазСале, Молодежная, 9		0101000020E610000005A73E90BCC05340FDA204FD85D75040
13835	6	33	347	52172	40428	\N	69.094223	ЯмалоНенецкий автономный округ, Тазовский район, Сельское поселение село Антипаюта, Ленина, 3		0101000020E61000009F3A56293D375340FCE1E7BF07465140
13816	6	33	279	52127	40903	\N	64.280726999999999	ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение деревня Харампур, Айваседо Энтак, 6		0101000020E610000057E883656C865340AB06616EF7115040
13814	6	33	279	52119	40699	\N	63.724558000000002	ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение посёлок Ханымей, Молодежная, 15		0101000020E6100000878BDCD3D5FD524010070951BEDC4F40
13815	6	33	279	52119	40317	\N	63.724558000000002	ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение посёлок Ханымей, Мира, 53		0101000020E6100000878BDCD3D5FD524010070951BEDC4F40
13817	6	33	279	52130	40901	\N	63.386459000000002	ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение село Халясавэй, Лесная, 3		0101000020E6100000C8073D9B55965340581F0F7D77B14F40
86880	6	56	1634	26266	19321	\N	57.018971999999998	город Талица, Калинина, 6		0101000020E6100000CBD93BA3ADDE4F4015C5ABAC6D824C40
13800	6	33	279	30595	40692	\N	65.957185431879594	ЯмалоНенецкий автономный округ, Пуровский район, Городское поселение посёлок Уренгой, Геологов, 43	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E6100000F722DA8EA999534031CEDF84427D5040
13798	6	33	279	30595	40690	\N	65.957449999999994	поселок городского типа Уренгой, 4 микрорайон, дом 39, здание МОУ УСОШ № 1		0101000020E610000087E0B88C9B98534088635DDC467D5040
13797	6	33	279	30595	40695	\N	65.957465518284593	ЯмалоНенецкий автономный округ, Пуровский район, Городское поселение посёлок Уренгой, 3 микрорайон, 20	Россия, Ямало-Ненецкий автономный округ, Пуровский район, поселок Уренгой	0101000020E6100000FD31AD4D639853400B42791F477D5040
13809	6	33	279	54910	40434	\N	64.921365101874301	ЯмалоНенецкий автономный округ, Пуровский район, Городское поселение город ТаркоСале, Мира, 7А	Россия, Ямало-Ненецкий автономный округ, Пуровский район, Тарко-Сале	0101000020E610000083FB010F0C72534075ABE7A4F73A5040
13808	6	33	279	54910	40434	\N	64.920490909952093	ЯмалоНенецкий автономный округ, Пуровский район, Городское поселение город ТаркоСале, Мира, 7	Россия, Ямало-Ненецкий автономный округ, Пуровский район, Тарко-Сале	0101000020E6100000A73FFB9122725340CA501553E93A5040
13801	6	33	279	1437	40939	\N	65.269306999999998	поселок Сывдарма, улица Железнодорожная, дом 10, здание МОУ ПСОШ № 3		0101000020E6100000679C86A8C27053405E656D533C515040
13796	6	33	279	52097	\N	\N	67.005010999999996	"""ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение село Самбург, МУ Дом культуры """"Полярная звезда"""", МУ Дом культуры """"Полярная звезда"""""""		0101000020E6100000A8531EDD088F5340B247A81952C05040
13810	6	33	279	57590	59752	\N	64.488800366907597	ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение посёлок Пурпе1, Прбеды, 3	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E610000093A641D13C2D53403A92CB7F481F5040
13813	6	33	279	52117	40697	\N	64.488438000000002	ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение посёлок Пурпе, Молодежная, 15		0101000020E6100000FF058200192B5340EA077591421F5040
13812	6	33	279	52117	40816	\N	64.488438000000002	ЯмалоНенецкий автономный округ, Пуровский район, Сельское поселение посёлок Пурпе, Железнодорожная, 5Б		0101000020E6100000FF058200192B5340EA077591421F5040
13802	6	33	279	30813	40799	\N	65.315031000000005	ЯмалоНенецкий автономный округ, Пуровский район, поселок Пуровск, переулок Школьный, дом 1, здание сельского дома культуры «Альянс		0101000020E6100000868DB27E337253407A8EC87729545040
13803	6	33	279	30813	40884	\N	65.315031000000005	ЯмалоНенецкий автономный округ, Пуровский район, поселок Пуровск, улица Новая, дом 9, здание МОУ ПСОШ № 1		0101000020E6100000868DB27E337253407A8EC87729545040
13769	6	33	279	1179	40637	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Ленина, 41		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13789	6	33	279	1179	60157	\N	63.175699999999999	ЯмалоНенецкий автономный округ, город Ноябрьск, Аэропорт, Аэропорт		0101000020E610000049A12C7C7DDA52401FF46C567D964F40
13683	6	33	279	25275	40336	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Школьная, 17		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13684	6	33	279	25275	40632	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Украинских строителей, 10		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13688	6	33	279	25275	40546	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Пионерская, 4		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13689	6	33	279	25275	40666	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Муравленко, 20		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13686	6	33	279	25275	40634	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Ленина, 61		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13690	6	33	279	25275	40548	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Дружбы народов, 104		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13687	6	33	279	25275	40545	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Губкина, 42		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13685	6	33	279	25275	40545	\N	63.775345999999999	ЯмалоНенецкий автономный округ, город Муравленко, Губкина, 14		0101000020E6100000E42D573F36A15240CE8AA8893EE34F40
13660	6	33	279	54902	40489	\N	64.433211947599503	Ямало-Ненецкий автономный округ, город Губкинский, 9 микрорайон, МОУ СОШ №4	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E6100000B6D782DE1B1F5340060FD3BEB91B5040
13663	6	33	279	54902	40323	\N	64.438944532218699	"""ЯмалоНенецкий автономный округ, город Губкинский, 7 микрорайон, ДЮСШ ГДК """"Олимп"""""""	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E61000008D4127840E1F534089EFC4AC171C5040
13664	6	33	279	54902	59708	\N	64.433406658051993	ЯмалоНенецкий автономный округ, город Губкинский, 6 микрорайон, МОУ СОШ № 3		0101000020E6100000ED0BE8853B1F5340E1B6B6F0BC1B5040
13661	6	33	279	54902	59487	\N	64.434383521483994	ЯмалоНенецкий автономный округ, город Губкинский, 3 микрорайон, 6	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E6100000D714C8EC2C1F5340F6798CF2CC1B5040
13665	6	33	279	54902	59526	\N	64.435029698261303	ЯмалоНенецкий автономный округ, город Губкинский, 14 микрорайон, МОУ СОШ № 7	Россия, Ямало-Ненецкий автономный округ, Пуровский район	0101000020E610000046CEC29E761E5340D9B11188D71B5040
13795	6	33	295	30445	40897	\N	66.594915	ЯмалоНенецкий автономный округ, Приуральский район, село Харсаим, Школьная, 2		0101000020E61000004EB6813B50D3504097395D1613A65040
13794	6	33	295	1281	40809	\N	66.801848000000007	Центр досуга молодежи, п. Харп, ул. Дзержинского, д. 11		0101000020E610000032207BBDFB7350403C17467A51B35040
13790	6	33	295	30192	40722	\N	66.561155999999997	ЯмалоНенецкий автономный округ, Приуральский район, село Аксарка, Первомайская, 28А		0101000020E6100000C1012D5DC1F2504011FDDAFAE9A35040
13717	6	33	276	26767	\N	\N	67.904872999999995	"""ЯмалоНенецкий автономный округ, Надымский район, п.Ямбург, Газопромысловое управление №2 ООО """"Газпром добыча Ямбург"""", Новый финский жилой комплекс"""		0101000020E6100000AB24B20FB2B6524023827170E9F95040
13716	6	33	276	26767	\N	\N	67.904872999999995	"""ЯмалоНенецкий автономный округ, Надымский район, п.Ямбург, Газопромысловое управление №6 ООО """"Газпром добыча Ямбург"""", Новый финский жилой комплекс"""		0101000020E6100000AB24B20FB2B6524023827170E9F95040
13715	6	33	276	26767	\N	\N	67.904872999999995	"""ЯмалоНенецкий автономный округ, Надымский район, п.Ямбург, Культурноспортивный комплекс ООО """"Газпром добыча Ямбург"""""""		0101000020E6100000AB24B20FB2B6524023827170E9F95040
13710	6	33	276	55022	\N	\N	64.678769482400298	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Ягельный, Дом культуры	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E61000007A6CCB80B3175240792288F3702B5040
13705	6	33	276	41055	\N	\N	65.598104000000006	ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, п.Старый Надым, Старонадымская средняя школа		0101000020E610000099B85510032E5240D6E6FF5547665040
13709	6	33	276	52935	\N	\N	64.283338999999998	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Приозерный, Дом культуры		0101000020E6100000F06B2409C2C551409BABE63922125040
13706	6	33	276	26339	\N	\N	65.445318999999998	п. Правохеттинский, МКУК «КДЦ»		0101000020E61000003CC1FEEBDC6152406552431B805C5040
13722	6	33	276	52952	40783	\N	65.848059000000006	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Пангоды, Клуб финского комплекса №1, Спортивная, 20		0101000020E6100000D50792770E9F52400685419946765040
13721	6	33	276	52952	40676	\N	65.848059000000006	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Пангоды, МОУ СОШ №1, Ленина, 43		0101000020E6100000D50792770E9F52400685419946765040
13720	6	33	276	52952	40676	\N	65.848059000000006	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Пангоды, МОУ СОШ №2, Ленина, 17		0101000020E6100000D50792770E9F52400685419946765040
13719	6	33	276	52952	40507	\N	65.848059000000006	"""ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Пангоды, МОУ ДОД """"Детская музыкальная школа п.Пангоды, Газодобытчиков, 24"""		0101000020E6100000D50792770E9F52400685419946765040
13713	6	33	276	52943	\N	\N	66.624510000000001	"""ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение село Ныда, МОУ """"Школаинтернат среднего (полного) общегообразования"""		0101000020E6100000F1845E7F123C52409981CAF8F7A75040
13711	6	33	276	52955	\N	\N	66.150619000000006	"""ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение село Нори, МОУ """"Норинская начальная школа"""""""		0101000020E61000007784D382171B524000CADFBDA3895040
13746	6	33	276	54906	40636	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Студенческий, д. 1		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13732	6	33	276	54906	41408	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Солнечный, квартал Армавирский		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13740	6	33	276	54906	59656	\N	66.121333990760405	ЯмалоНенецкий автономный округ, город Новый Уренгой, мкр. Советский, д. 10 корп. 1	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E6100000AC394030472B53402579AEEFC3875040
13749	6	33	276	54906	67863	\N	66.085208107728704	МУ «ОМК» молодёжный клуб «Оптимист», мкр. Оптимистов, д. 4	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E61000007C7F83F6EA295340E256410C74855040
13729	6	33	276	54906	40358	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. Юбилейная, д. 7		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13750	6	33	276	54906	60183	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, р. Коротчаево ул. Монтажников, д. 8		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13726	6	33	276	54906	40678	\N	66.094159000000005	ЯмалоНенецкий автономный округ, город Новый Уренгой, ул. 26 съезда КПСС, д. 10а		0101000020E6100000AC3AAB05F62C5340F16778B306865040
13702	6	33	276	54990	\N	\N	65.530671204384305	ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, п.Аэропорт, Спортивно оздоровительный комплекс		0101000020E61000008AABCABE2B235240E17B7F83F6615040
13696	6	33	276	54990	59668	\N	65.530453198187004	ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, Музей истории и археологии г.Надыма, Ленинградский проспект, 11	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E61000009A40118B182152402AC423F1F2615040
13707	6	33	276	52947	\N	\N	64.787214000000006	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Лонгъюган, Культурноспортивный комплекс		0101000020E61000009F02603C83BC5140043DD4B661325040
13691	6	33	276	59096	\N	\N	65.537504105124299	"""ЯмалоНенецкий автономный округ, Надымский район, Городское поселение город Надым, п.Лесной Административное здание, ООО """"Газтеплоэнергоремонт"""""""		0101000020E6100000CB85CABF96215240075E2D7766625040
13712	6	33	276	52942	\N	\N	66.327984999999998	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение село Кутопьюган, МОУ Средняя общеобразовательная школаинтернат		0101000020E6100000BD72BD6DA69851400725CCB4FD945040
13714	6	33	276	55018	\N	\N	66.450490746185395	ЯмалоНенецкий автономный округ, Надымский район, Сельское поселение посёлок Заполярный, Дом культуры	Россия, Ямало-Ненецкий автономный округ, Надымский район	0101000020E610000064EB19C2317752401C0934D8D49C5040
13669	6	33	358	24655	40310	\N	63.397199999999998	с. Толька, ул. Центральная, 30, спортивный комплекс «Снежинка»		0101000020E61000004565C39ACA06544050FC1873D7B24F40
13670	6	33	358	24708	40905	\N	63.584800000000001	с. Ратта, ул. Центральная, 2, сельский Дом культуры		0101000020E610000031EBC5504EF75440B459F5B9DACA4F40
13668	6	33	358	24608	40604	\N	65.706639999999993	с. Красноселькуп, ул. Советская, 5, муниципальное образовательное учреждение «Радуга»		0101000020E61000000CCD751A699D5440E882FA96396D5040
10763	6	58	\N	55159	43624	\N	56.115908894955503	Челябинская область,   город Верхний Уфалей , поселок Черемшанка, Строителей, 15		0101000020E6100000938FDD054A224E40F2272A1BD60E4C40
11949	6	58	\N	4212	42962	\N	54.440893852519103	Челябинская область, Южноуральский городской округ, Яблочкова, 23А	Россия, Челябинская область, Южноуральск	0101000020E61000000056478E74A24E405680EF366F384B40
11939	6	58	\N	4212	43482	\N	54.445314833638299	Челябинская область, Южноуральский городской округ, Энергетиков, 18	Россия, Челябинская область, Южноуральск	0101000020E6100000488B338639A14E4089B5F81400394B40
11940	6	58	\N	4212	42677	\N	54.444395659218799	Челябинская область, Южноуральский городской округ, Строителей, 3	Россия, Челябинская область, Южноуральск	0101000020E6100000A0DE8C9AAFA24E40923CD7F7E1384B40
11945	6	58	\N	4212	42669	\N	54.448727653995199	Челябинская область, Южноуральский городской округ, Спортивная, 21	Россия, Челябинская область, Южноуральск	0101000020E6100000ED2DE57CB1A14E4056664AEB6F394B40
11943	6	58	\N	4212	42669	\N	54.443037670053499	Челябинская область, Южноуральский городской округ, Спортивная, 42А	Россия, Челябинская область, Южноуральск	0101000020E6100000CEA5B8AAEC9F4E4050711C78B5384B40
11946	6	58	\N	4212	43148	\N	54.441572003733803	Челябинская область, Южноуральский городской округ, Советской Армии, 9А	Россия, Челябинская область, Южноуральск	0101000020E61000009F76F86BB2A24E40276A696E85384B40
11933	6	58	\N	4212	43304	\N	54.442294611292297	Челябинская область, Южноуральский городской округ, Советская 112	Россия, Челябинская область, Южноуральск	0101000020E61000008EE9094B3CA24E409817601F9D384B40
11895	6	58	\N	4212	43304	\N	54.444173331312399	Челябинская область, Южноуральский городской округ, Советская, 2	Россия, Челябинская область, Южноуральск	0101000020E610000016DD7A4D0FA24E4013622EA9DA384B40
11938	6	58	\N	4212	43369	\N	54.446796724264601	Челябинская область, Южноуральский городской округ, Парковая, 2	Россия, Челябинская область, Южноуральск	0101000020E6100000F7ADD689CBA54E40B779E3A430394B40
11947	6	58	\N	4212	43399	\N	54.442594767625401	Челябинская область, Южноуральский городской округ, Павлова, 26	Россия, Челябинская область, Южноуральск	0101000020E61000002A3A92CB7FA24E40C22FF5F3A6384B40
11942	6	58	\N	4212	43399	\N	54.439943310229097	Челябинская область, Южноуральский городской округ, Павлова, 41		0101000020E6100000A208A9DBD9A14E40548D5E0D50384B40
11937	6	58	\N	4212	43355	\N	54.445971374106399	Челябинская область, Южноуральский городской округ, Московская, 16	Россия, Челябинская область, Южноуральск	0101000020E6100000821DFF0582A04E4072FBE59315394B40
11935	6	58	\N	4212	42938	\N	54.448197280232698	Челябинская область, Южноуральский городской округ, Ленина, 38	Россия, Челябинская область, Южноуральск	0101000020E6100000399D64ABCBA34E402995F0845E394B40
11934	6	58	\N	4212	42938	\N	54.441556717579701	город Южноуральск, Ленина, 38	Россия, Челябинская область, Южноуральск	0101000020E6100000F5B86FB54EA04E40F22895F084384B40
11941	6	58	\N	4212	43398	\N	54.442894921748703	Челябинская область, Южноуральский городской округ, Куйбышева, 36Б	Россия, Челябинская область, Южноуральск	0101000020E61000004391EEE714A24E40ED478AC8B0384B40
11948	6	58	\N	4212	43263	\N	54.445596209419399	Челябинская область, Южноуральский городской округ, Космонавтов, 19	Россия, Челябинская область, Южноуральск	0101000020E61000004391EEE714A24E403D9D2B4A09394B40
11944	6	58	\N	4212	43263	\N	54.443995467961699	Челябинская область, Южноуральский городской округ, Космонавтов, 3В	Россия, Челябинская область, Южноуральск	0101000020E6100000DC114E0B5EA24E40344B02D4D4384B40
10564	6	58	\N	66	\N	\N	55.287351903872498	"""Челябинская область, Челябинский городской округ, Металлургический район, поселок Аэропорт, дом культуры """"Сокол"""""""	Россия, Челябинская область, Челябинск, поселок Аэропорт	0101000020E6100000F12F82C64CC24E40583849F3C7A44B40
10576	6	58	\N	66	521	\N	55.258335000000002	Челябинская область, город Челябинск, Металлургический район, Ярослава Гашека, 1	Россия, Челябинская область, Челябинск, улица Ярослава Гашека, 1	0101000020E610000065A88AA9F4B34E40C2340C1F11A14B40
10668	6	58	\N	66	42727	\N	55.152850000000001	Челябинская область, Челябинский городской округ, Центральный район, Энтузиастов, 15Б	Россия, Челябинская область, Челябинск, улица Энтузиастов, 15б	0101000020E6100000D2C5A69542B04E40C898BB9690934B40
10656	6	58	\N	66	43079	\N	55.166536000000001	Челябинская область, Челябинский городской округ, Центральный район, Энгельса, 39	Россия, Челябинская область, Челябинск, улица Энгельса, 39	0101000020E6100000EE23B726DDB04E40A7CD380D51954B40
11038	6	58	\N	66	6501	\N	55.119723	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение,Угольная, 15	Россия, Челябинская область, Челябинск, улица Угольная, 15	0101000020E6100000C6BFCFB870C24E401DCA5015538F4B40
10432	6	58	\N	27323	42626	\N	54.992517999999997	Челябинская область, город Чебаркуль, Советская, 45		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
11811	6	58	\N	66	16068	\N	55.147962999999997	Челябинская область, Челябинский городской округ, Советский район, Свободы, 100А	Россия, Челябинская область, Челябинск, улица Свободы, 100а	0101000020E61000002E02637D03B54E404F029B73F0924B40
10620	6	58	\N	66	1197	\N	55.171781000000003	Адрес УИК в день голосования: г.Челябинск, улица Салютная, д. 16, Адрес УИК: улица Первой Пятилетки, 21	Россия, Челябинская область, Челябинск, улица Салютная, 16	0101000020E610000002124DA088B94E407F8978EBFC954B40
11776	6	58	\N	66	43030	\N	55.141340999999997	Челябинская область, Челябинский городской округ, Ленинский район, Пограничная, 4	Россия, Челябинская область, Челябинск, улица Пограничная, 4	0101000020E61000005FD1ADD7F4B84E40BE4A3E7617924B40
11673	6	58	\N	66	6283	\N	55.245348	Челябинская область, г. Копейск, ул. Пекинская, 25	Россия, Челябинская область, Челябинск, улица Пекинская, 25	0101000020E61000006DFDF49F35B34E40CB113290679F4B40
11098	6	58	\N	66	1485	\N	55.181575000000002	Челябинская область, Озерский городской округ, Октябрьская, 11	Россия, Челябинская область, Челябинск, улица Октябрьская, 11	0101000020E6100000D2E5CDE15ABB4E40B7627FD93D974B40
10639	6	58	\N	66	1485	\N	55.180351533978502	Челябинская область, Челябинский городской округ, Тракторозаводский район, Октябрьская, 3	Россия, Челябинская область, Челябинск, улица Октябрьская, 3	0101000020E61000009E279EB305BC4E4054E23AC615974B40
11809	6	58	\N	66	43128	\N	55.143574000000001	Челябинская область, Челябинский городской округ, Советский район, Овчинникова, 4	Россия, Челябинская область, Челябинск, улица Овчинникова, 4	0101000020E61000007120240B98B44E40284701A260924B40
11781	6	58	\N	66	42692	\N	55.113793933222098	Челябинская область, Челябинский городской округ, Ленинский район, Новороссийская, 83	Россия, Челябинская область, Челябинск, улица Новороссийская, 83	0101000020E61000002655DB4DF0B94E40923D42CD908E4B40
11704	6	58	\N	66	6569	\N	55.116813999999998	Челябинская область, г. Копейск, ул. Масленникова, 9	Россия, Челябинская область, Челябинск, улица Масленникова, 9	0101000020E61000002463B5F97FBB4E4083DBDAC2F38E4B40
10629	6	58	\N	66	1362	\N	55.174661	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Кулибина, 58	Россия, Челябинская область, Челябинск, улица Кулибина, 58	0101000020E6100000ADC266800BBC4E407E71A94A5B964B40
11808	6	58	\N	66	6707	\N	55.162149758652397	Адрес УИК в день голосования: улица Красноармейская, дом 101, Адрес УИК: улица Евтеева, 1	Россия, Челябинская область, Челябинск, улица Красноармейская, 111	0101000020E61000004209336DFFB44E40F085C954C1944B40
11834	6	58	\N	66	43138	\N	55.11665	Челябинская область, Челябинский городской округ, Советский район, Короленко, 16		0101000020E6100000FCE25295B6B04E40098A1F63EE8E4B40
11845	6	58	\N	66	16016	\N	55.039800999999997	Челябинская область, Челябинский городской округ, Советский район, поселок Новосинеглазово, Кирова, 4	Россия, Челябинская область, Челябинск, поселок Новосинеглазово, улица Кирова, 6	0101000020E610000074ED0BE885AF4E408EACFC3218854B40
11982	6	58	\N	66	1824	\N	55.172829999999998	г.Челябинск, Каслинская, 64	Россия, Челябинская область, Челябинск, улица Каслинская, 64	0101000020E61000005857056A31B24E4043E21E4B1F964B40
10553	6	58	\N	66	162	\N	55.197384	Челябинская область, город Челябинск, Курчатовский район, Захаренко, 13	Россия, Челябинская область, Челябинск, улица Захаренко, 13	0101000020E61000004C1C7920B2A64E40786000E143994B40
10602	6	58	\N	66	562	\N	55.247779999999999	Челябинская область, город Челябинск, Металлургический район, Жукова, 47	Россия, Челябинская область, Челябинск, улица Жукова, 47	0101000020E610000045B75ED383B24E402B4D4A41B79F4B40
11817	6	58	\N	66	42837	\N	55.151327000000002	Челябинская область, Челябинский городской округ, Советский район, ул.Елькина,88,1 этаж,левый холл	Россия, Челябинская область, Челябинск, улица Елькина, 88	0101000020E610000010751F80D4B24E403B00E2AE5E934B40
11814	6	58	\N	66	42837	\N	55.155216794050901	Челябинская область, Челябинский городской округ, Советский район, Елькина, 78	Россия, Челябинская область, Челябинск, улица Елькина, 78	0101000020E6100000EDF5EE8FF7B24E4041649126DE934B40
10569	6	58	\N	66	423	\N	55.266086000000001	Челябинская область, город Челябинск, Металлургический район, Дегтярева, 33	Россия, Челябинская область, Челябинск, улица Дегтярева, 33	0101000020E6100000D3F71A82E3B24E4034F6251B0FA24B40
11706	6	58	\N	66	6595	\N	55.175199999999997	Челябинская область, г. Копейск, ул. Грибоедова, 15	Россия, Челябинская область, Челябинск, улица Грибоедова, 15	0101000020E6100000B212F3ACA4B74E402D211FF46C964B40
10616	6	58	\N	66	1009	\N	55.180433999999998	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Горького, 54	Россия, Челябинская область, Челябинск, улица Горького, 54	0101000020E6100000A75D4C33DDB74E40118B187618974B40
11774	6	58	\N	66	3752	\N	55.143179158348801	Челябинская область, Челябинский городской округ, Ленинский район, Гагарина, 7	Россия, Челябинская область, Челябинск, улица Гагарина	0101000020E61000001C5DA5BBEBB84E40AC3C81B053924B40
10723	6	58	\N	66	2695	\N	55.157356	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, 40 лет Октября, 33	Россия, Челябинская область, Челябинск, улица 40 Лет Октября, 33	0101000020E61000002BC24D4695B94E4029EACC3D24944B40
10540	6	58	\N	66	43457	\N	55.191884999999999	Челябинская область, город Челябинск, Курчатовский район, Пионерская, 10А		0101000020E610000030A182C30BAC4E40E6CB0BB08F984B40
10563	6	58	\N	66	340	\N	55.235101999999998	Челябинская область, город Челябинск, Металлургический район, 26 Бакинских комиссаров, 107А	Россия, Челябинская область, Челябинск, улица 26 Бакинских Комиссаров, 107а	0101000020E6100000DFF8DA334BB44E40B29C84D2179E4B40
11798	6	58	\N	66	42956	\N	55.118462466950596	Челябинская область, Челябинский городской округ, Ленинский район, Трубосварочная 1я, 4	Россия, Челябинская область, Челябинск, улица 1-я Трубосварочная	0101000020E6100000EACBD24ECDC14E40CDE847C3298F4B40
10514	6	58	\N	66	43411	\N	55.183647000000001	г.Челябинск, Победы проспект, 167		0101000020E6100000054D4BAC8CB24E401781B1BE81974B40
10507	6	58	\N	66	43411	\N	55.184669999999997	г.Челябинск, Победы проспект, 113А		0101000020E61000003067B62BF4B74E40B2463D44A3974B40
10409	6	58	\N	66	43411	\N	55.187578999999999	г.Челябинск, Победы проспект, 162В		0101000020E61000006E4DBA2D91B34E404C35B39602984B40
11790	6	58	\N	66	42946	\N	55.129617000000003	Челябинская область, Челябинский городской округ, Ленинский район, Энергетиков, 17	Россия, Челябинская область, Челябинск, улица Энергетиков, 17	0101000020E6100000CA17B49080BB4E40B900344A97904B40
11788	6	58	\N	66	42946	\N	55.126148000000001	Челябинская область, Челябинский городской округ, Ленинский район, Энергетиков, 2	Россия, Челябинская область, Челябинск, улица Энергетиков, 2	0101000020E61000009A780778D2BC4E40583A1F9E25904B40
11777	6	58	\N	66	42946	\N	55.137903238678703	Челябинская область, Челябинский городской округ, Ленинский район, Энергетиков, 63	Россия, Челябинская область, Челябинск, улица Энергетиков, 63	0101000020E6100000D690B8C7D2B94E40998235CEA6914B40
10670	6	58	\N	66	42882	\N	55.148764999999997	Челябинская область, Челябинский городской округ, Центральный район, Энгельса, 103		0101000020E61000005F29CB10C7B04E400CE544BB0A934B40
10667	6	58	\N	66	42882	\N	55.155129000000002	Челябинская область, Челябинский городской округ, Центральный район, Энгельса, 79	Россия, Челябинская область, Челябинск, улица Энгельса, 79	0101000020E6100000643DB5FAEAB04E40A2D45E44DB934B40
10587	6	58	\N	66	43425	\N	55.251905999999998	Челябинская область, город Челябинск, Металлургический район, Электростальская, 33		0101000020E6100000E1ED4108C8B14E4045D5AF743EA04B40
10631	6	58	\N	66	43402	\N	55.172649999999997	Адрес УИК в день голосования: г. Челябинск, ул. Шуменская, д. 20 А, Адрес УИК: г. Челябинск, ул. Комарова, 114		0101000020E610000010CD3CB9A6BA4E40C3D32B6519964B40
11813	6	58	\N	66	42823	\N	55.140097617171598	Челябинская область, Челябинский городской округ, Советский район, Ширшова, 9	Россия, Челябинская область, Челябинск, улица Ширшова, 9	0101000020E610000052B81E85EBB34E40151E34BBEE914B40
11812	6	58	\N	66	42823	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Советский район,ул.Ширшова,9,2 этаж правого холла		0101000020E6100000C5C9FD0E459B4E401F86562767824B40
6607	6	58	\N	66	43415	\N	55.190272	г.Челябинск, Шенкурская, 13		0101000020E61000009F02603C83B24E4019AC38D55A984B40
10560	6	58	\N	66	43068	\N	55.1900274739439	Челябинская область, Челябинский городской округ, Курчатовский район, Чичерина, 3	Россия, Челябинская область, Челябинск, улица Чичерина, 3	0101000020E6100000CE35CCD078A44E40B22D03CE52984B40
10559	6	58	\N	66	43068	\N	55.190137999999997	Челябинская область, город Челябинск, Курчатовский район, Чичерина, 3		0101000020E6100000D2393FC571A44E4009DD257156984B40
8027	6	58	\N	66	43068	\N	55.181066000000001	г.Челябинск, Чичерина, 27Б		0101000020E61000005B9544F641A64E407235B22B2D974B40
10599	6	58	\N	66	43430	\N	55.243699999999997	Челябинская область, город Челябинск, Металлургический район, Черкасская, 1А		0101000020E61000006B0BCF4BC5B04E408104C58F319F4B40
11843	6	58	\N	66	43481	\N	55.038066999999998	Челябинская область, Челябинский городской округ, Советский район, поселок Новосинеглазово, Челябинская, 7		0101000020E61000009E978A8D79AF4E4046072461DF844B40
10538	6	58	\N	66	43410	\N	55.195965999999999	Челябинская область, город Челябинск, Курчатовский район, Чайковского, 8А		0101000020E6100000EFC8586DFEAD4E406090F46915994B40
10537	6	58	\N	66	43410	\N	55.197302000000001	Челябинская область, город Челябинск, Курчатовский район, Чайковского, 1		0101000020E61000008EE89E758DAE4E40BBB7223141994B40
10536	6	58	\N	66	43410	\N	55.190246238234501	Челябинская область, город Челябинск, Курчатовский район, Чайковского, 20А	Россия, Челябинская область, Челябинск, Курчатовский район	0101000020E6100000572426A8E1AD4E40F0181EFB59984B40
11821	6	58	\N	66	43097	\N	55.140949999999997	Челябинская область, Челябинский городской округ, Советский район, Цеховая, 8А		0101000020E610000087C1FC1532B34E40832F4CA60A924B40
10675	6	58	\N	66	42738	\N	55.122937449292003	Челябинская область, Челябинский городской округ, Центральный район, микрорайон Шершни, Центральная, 3А		0101000020E610000078D32D3BC4AF4E40F33B4D66BC8F4B40
11807	6	58	\N	66	43037	\N	55.152360999999999	Челябинская область, Челябинский городской округ, Советский район, Цвиллинга, 54	Россия, Челябинская область, Челябинск, улица Цвиллинга, 54	0101000020E610000063EE5A423EB44E40CA17B49080934B40
11806	6	58	\N	66	43037	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Советский район, Цвиллинга, 56		0101000020E6100000C5C9FD0E459B4E401F86562767824B40
10676	6	58	\N	66	42880	\N	55.147720999999997	Челябинская область, Челябинский городской округ, Центральный район, Худякова, 16	Россия, Челябинская область, Челябинск, улица Худякова, 16	0101000020E61000005EBA490C02AF4E4059F78F85E8924B40
10646	6	58	\N	66	43427	\N	55.175314	Челябинская область, город Челябинск, Тракторозаводский район, Хохрякова, 26 А		0101000020E6100000B532E197FABD4E40F6436CB070964B40
11697	6	58	\N	55093	42664	\N	55.092314000000002	Челябинская область, г. Копейск, ул. Гольца, 18		0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
10604	6	58	\N	66	43071	\N	55.248480317048802	Челябинская область, Челябинский городской округ, Металлургический район, Хлебозаводская, 4	Россия, Челябинская область, Челябинск, улица Хлебозаводская, 4	0101000020E6100000642310AFEBB34E40E4DA5031CE9F4B40
11757	6	58	\N	66	42693	\N	55.148611000000002	Челябинская область, Челябинский городской округ, Ленинский район, ул.Харлова,10,1 этаж,коридор		0101000020E610000062122EE411B84E40B6696CAF05934B40
11826	6	58	\N	66	43583	\N	55.136050998320201	Челябинская область, Челябинский городской округ, Советский район, Учебная, 5А	Россия, Челябинская область, Челябинск, улица Учебная, 5а	0101000020E610000002F2255470B04E4047CB811E6A914B40
11796	6	58	\N	66	43032	\N	55.123965765156903	Челябинская область, Челябинский городской округ, Ленинский район, Уральская, 2	Россия, Челябинская область, Челябинск, улица Уральская, 2	0101000020E6100000AFCDC64ACCC14E4071E82D1EDE8F4B40
10520	6	58	\N	66	43412	\N	55.176028000000002	г.Челябинск, Университетская Набережная, 30а		0101000020E610000079793A5794AC4E401497E31588964B40
10519	6	58	\N	66	43412	\N	55.177112999999999	г.Челябинск, Университетская Набережная, 16а		0101000020E6100000E883656CE8AE4E40255987A3AB964B40
11759	6	58	\N	66	42826	\N	55.146017999999998	Челябинская область, Челябинский городской округ, Ленинский район, Тухачевского, 15		0101000020E610000073124A5F08B74E404C50C3B7B0924B40
11795	6	58	\N	66	42950	\N	55.1009621797538	Челябинская область, Челябинский городской округ, Ленинский район, Туруханская, 40	Россия, Челябинская область, Челябинск, улица Туруханская, 40	0101000020E61000004A07EBFF1CBE4E40C311A452EC8C4B40
10566	6	58	\N	66	43476	\N	55.268127999999997	Челябинская область, город Челябинск, Металлургический район, Трудовая, 16		0101000020E61000003AB2F2CB60B24E402992AF0452A24B40
11830	6	58	\N	66	43135	\N	55.113596000000001	Челябинская область, Челябинский городской округ, Советский район, Троицкий тракт, 46	Россия, Челябинская область, Челябинск, Троицкий тракт, 46	0101000020E6100000BF0B5BB395B14E406C7A50508A8E4B40
11841	6	58	\N	66	5927	\N	55.098475000000001	Челябинская область, Челябинский городской округ, Советский район, Троицкий тракт, 15		0101000020E6100000A724EB7074B14E409F3C2CD49A8C4B40
11838	6	58	\N	66	43686	\N	55.106205904483801	Челябинская область, Челябинский городской округ, Советский район, Трактовая, 19А	Россия, Челябинская область, Челябинск, улица Трактовая, 19а	0101000020E6100000EA3C2AFEEFAA4E40CA518028988D4B40
11799	6	58	\N	66	42708	\N	55.159206580802298	Челябинская область, Челябинский городской округ, Советский район, Тимирязева, 6	Россия, Челябинская область, Челябинск, улица Тимирязева, 6	0101000020E610000058E4D70FB1B54E40AB251DE560944B40
10581	6	58	\N	66	591	\N	55.256180000000001	Челябинская область, город Челябинск, Металлургический район, Театральный переулок, 16А	Россия, Челябинская область, Челябинск, Театральный переулок, 16а	0101000020E610000060394206F2B04E40D4F19881CAA04B40
10627	6	58	\N	66	42720	\N	55.170668819878699	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Танкистов, 144 Б	Россия, Челябинская область, Челябинск, улица Танкистов, 144б	0101000020E6100000C5C72764E7BB4E4073B8567BD8954B40
10583	6	58	\N	66	43424	\N	55.252049999999997	Челябинская область, город Челябинск, Металлургический район, Сурикова, 5		0101000020E6100000ECDD1FEF55AF4E40787AA52C43A04B40
11828	6	58	\N	66	44266	\N	55.124401042943497	Челябинская область, Челябинский городской округ, Советский район, Стрелковая, 37	Россия, Челябинская область, Челябинск, Советский район	0101000020E61000004704E3E0D2B34E407B4B395FEC8F4B40
11836	6	58	\N	66	42704	\N	55.113894999999999	Челябинская область, Челябинский городской округ, Советский район, Столбовая, 30	Россия, Челябинская область, Челябинск, улица Столбовая, 30	0101000020E61000005473B9C150AD4E40C616821C948E4B40
10969	6	58	\N	66	43734	\N	55.037514999999999	Кусинское городское поселение, ж/д вокзал, ул. Станционная, д.1		0101000020E6100000921FF12BD6AE4E40020EA14ACD844B40
10567	6	58	\N	66	43459	\N	55.266680999999998	Челябинская область, город Челябинск, Металлургический район, ул.Сталеваров, 1,1 этаж,		0101000020E6100000ABD0402C9BB34E4077BB5E9A22A24B40
10673	6	58	\N	66	42889	\N	55.157741101130902	Челябинская область, Челябинский городской округ, Центральный район, Сони Кривой, 54	Россия, Челябинская область, Челябинск, улица Сони Кривой, 54	0101000020E6100000C6C1A563CEAF4E40821E6ADB30944B40
10672	6	58	\N	66	42889	\N	55.157012000000002	Челябинская область, Челябинский городской округ, Центральный район, Сони Кривой, 79		0101000020E6100000D042024697AF4E402F8A1EF818944B40
10551	6	58	\N	66	43421	\N	55.203704000000002	Челябинская область, город Челябинск, Курчатовский район, Солнечная, 10В		0101000020E61000003A950C0055A84E403E0801F9129A4B40
10547	6	58	\N	66	43421	\N	55.192064999999999	Челябинская область, город Челябинск, Курчатовский район, Солнечная, 50А		0101000020E61000004069A85148A84E4066DAFE9595984B40
11218	6	58	\N	66	43299	\N	55.162430100199003	Челябинская область, Магнитогорский городской округ, Правобережный район, ул.Советская, 106	Россия, Челябинская область, Челябинск, улица Советская	0101000020E6100000AEBCE47FF2B34E40D4F19881CA944B40
10674	6	58	\N	66	42884	\N	55.151165240254102	Челябинская область, Челябинский городской округ, Центральный район, Смирных, 13А	Россия, Челябинская область, Челябинск, улица Смирных, 13а	0101000020E6100000384D9F1D70AF4E4061A6ED5F59934B40
10679	6	58	\N	66	43214	\N	55.066288697685401	Челябинская область, Челябинский городской округ, Центральный район, микрорайон Сосновка, Пионерская, 1А		0101000020E6100000B83D4162BBA14E40D28A6F287C884B40
11810	6	58	\N	66	42701	\N	55.147962999999997	Челябинская область, Челябинский городской округ, Советский район,ул.Свободы,100/А,1 этаж,16 кабинет	Россия, Челябинская область, Челябинск, улица Свободы, 100а	0101000020E61000002E02637D03B54E404F029B73F0924B40
11804	6	58	\N	66	42701	\N	55.152955455360399	Челябинская область, Челябинский городской округ, Советский район, Свободы, 155	Россия, Челябинская область, Челябинск, улица Свободы, 155	0101000020E61000004A0A2C8029B54E403D61890794934B40
11803	6	58	\N	66	42701	\N	55.156146999999997	Челябинская область, Челябинский городской округ, Советский район, Свободы, 82		0101000020E610000062670A9DD7B44E402B2FF99FFC934B40
10666	6	58	\N	66	1854	\N	55.154440000000001	Челябинская область, город Челябинск, Центральный район, Свердловский проспект, 84А	Россия, Челябинская область, Челябинск, Свердловский проспект, 84а	0101000020E61000003929CC7B9CB14E40DD989EB0C4934B40
10665	6	58	\N	66	1854	\N	55.1544579731395	Челябинская область, Челябинский городской округ, Центральный район, Свердловский проспект, 84А	Россия, Челябинская область, Челябинск, Свердловский проспект, 84а	0101000020E610000079CDAB3AABB14E40834D9D47C5934B40
10534	6	58	\N	66	1854	\N	55.185758999999997	Челябинская область, город Челябинск, Курчатовский район, Свердловский проспект, 24	Россия, Челябинская область, Челябинск, Свердловский проспект, 24	0101000020E6100000C4CF7F0F5EB14E4005F86EF3C6974B40
11956	6	58	\N	66	43209	\N	55.303234373316798	Челябинская область, Челябинский городской округ, Металлургический район, поселок Каштак, улица Санаторная, 10, филиал школы №94	Россия, Челябинская область, Челябинск, поселок Каштак	0101000020E6100000F834272F32AF4E408484285FD0A64B40
10621	6	58	\N	66	42698	\N	55.171756446465402	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Салютная, 16		0101000020E610000008E6E8F17BB94E402672C119FC954B40
10561	6	58	\N	66	42635	\N	55.187209325220898	Челябинская область, Челябинский городской округ, Курчатовский район, Салавата Юлаева, 3Б	Россия, Челябинская область, Челябинск, улица Салавата Юлаева, 3б	0101000020E610000037DE1D19ABA34E402942EA76F6974B40
9652	6	58	\N	66	42635	\N	55.173447000000003	г.Челябинск, Салавата Юлаева, 25А		0101000020E6100000645DDC4603A64E406F4BE48233964B40
8256	6	58	\N	66	42635	\N	55.178094999999999	г.Челябинск, Салавата Юлаева, 13		0101000020E610000096E99788B7A44E40624A24D1CB964B40
10623	6	58	\N	66	42879	\N	55.164549057398801	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Савина, 3	Россия, Челябинская область, Челябинск, улица Савина, 3	0101000020E61000005BEA20AF07B94E4075CB0EF10F954B40
11827	6	58	\N	66	43607	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Советский район, Рылеева, 8		0101000020E6100000C5C9FD0E459B4E401F86562767824B40
6119	6	58	\N	66	43465	\N	55.181570000000001	г.Челябинск, Российская, 49А		0101000020E61000003012DA722EB54E40A5F78DAF3D974B40
5723	6	58	\N	66	43465	\N	55.191834	г.Челябинск, Российская, 23		0101000020E61000005F5D15A8C5B44E4064213A048E984B40
10535	6	58	\N	66	43452	\N	55.186509999999998	Челябинская область, город Челябинск, Курчатовский район, Речная, 1А		0101000020E6100000E869C020E9AF4E404030478FDF974B40
11802	6	58	\N	66	42699	\N	55.157132452369503	Челябинская область, Челябинский городской округ, Советский район, площадь Революции, 5	Россия, Челябинская область, Челябинск, Революции площадь, 5	0101000020E610000009FCE1E7BFB34E40D993C0E61C944B40
10558	6	58	\N	66	43065	\N	55.235430999999998	Челябинская область, город Челябинск, Курчатовский район, РабочеКрестьянская, 2А		0101000020E61000008F8CD5E6FFAD4E4077BB5E9A229E4B40
10513	6	58	\N	66	43446	\N	55.177241000000002	г.Челябинск, Работниц, 58		0101000020E61000004BCB48BDA7B24E40534145D5AF964B40
11962	6	58	\N	66	44108	\N	55.140167642965103	Челябинская область, Челябинский городской округ, Советский район, Привокзальная площадь, 1	Россия, Челябинская область, Челябинск, Привокзальная площадь	0101000020E610000096E82CB308B54E400EF96706F1914B40
11775	6	58	\N	66	42695	\N	55.139926000000003	Челябинская область, Челябинский городской округ, Ленинский район, Пограничная, 1	Россия, Челябинская область, Челябинск, улица Пограничная, 1	0101000020E610000004A9143B1AB94E4018EE5C18E9914B40
11760	6	58	\N	66	42695	\N	55.1432108451679	Челябинская область, Челябинский городской округ, Ленинский район, Пограничная, 21	Россия, Челябинская область, Челябинск, улица Пограничная, 21	0101000020E61000008BE255D636B74E40B7B6F0BC54924B40
11751	6	58	\N	66	1463	\N	55.192230000000002	раб. пос. Первомайский, Победы, 6А	Россия, Челябинская область, Челябинск, Победы проспект, 6	0101000020E61000006090F46915BB4E40B1A71DFE9A984B40
10525	6	58	\N	66	1463	\N	55.188069858668698	Помещение для голосования: г.Челябинск, проспект Победы, д.303, Адрес УИК: ул.Молодогвардейцев, 56Б	Россия, Челябинская область, Челябинск, Победы проспект, 303/1	0101000020E6100000551344DD07A84E40EBAD81AD12984B40
10524	6	58	\N	66	1463	\N	55.187866999999997	г.Челябинск, Победы проспект, 287	Россия, Челябинская область, Челябинск, Победы проспект, 287	0101000020E6100000C4094CA775AB4E40B27F9E060C984B40
10506	6	58	\N	66	1463	\N	55.184669999999997	г.Челябинск, пр.Победы,113/А,1 этаж,фойе,школа № 21	Россия, Челябинская область, Челябинск, Победы проспект, 113а	0101000020E61000003067B62BF4B74E40B2463D44A3974B40
10505	6	58	\N	66	1463	\N	55.189712	г.Челябинск, Победы проспект, 60	Россия, Челябинская область, Челябинск, Победы проспект, 60	0101000020E61000006E30D46185B94E4052D4997B48984B40
4705	6	58	\N	66	1463	\N	55.185847000000003	г.Челябинск, Победы проспект, 144	Россия, Челябинская область, Челябинск, Победы проспект, 144	0101000020E610000017F4DE1802B64E40A587A1D5C9974B40
10622	6	58	\N	66	42734	\N	55.166768567539599	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Первой Пятилетки, 21	Россия, Челябинская область, Челябинск, улица 1 Пятилетки, 21	0101000020E610000008E6E8F17BB94E404A7EC4AF58954B40
10603	6	58	\N	66	42875	\N	55.246038111468103	Челябинская область, Челябинский городской округ, Металлургический район, Пекинская, 20	Россия, Челябинская область, Челябинск, улица Пекинская, 20	0101000020E6100000AD6D8AC745B34E4060C9552C7E9F4B40
11153	6	58	\N	66	42812	\N	55.106133999999997	Челябинская область, Магнитогорский городской округ, Ленинский район, Панькова, 32		0101000020E61000006478EC67B1BE4E40307F85CC958D4B40
11765	6	58	\N	66	43123	\N	55.136871922052698	Челябинская область, Челябинский городской округ, Ленинский район, Отечественная, 6	Россия, Челябинская область, Челябинск, улица Отечественная, 6	0101000020E6100000E6CC76853EB64E407ADE8D0585914B40
10533	6	58	\N	66	8074	\N	55.187187999999999	Челябинская область, город Челябинск, Курчатовский район, переулок Островского, 8	Россия, Челябинская область, Челябинск, Островского переулок, 8	0101000020E6100000BC57AD4CF8B14E40111AC1C6F5974B40
11805	6	58	\N	66	43127	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Советский район, Орджоникидзе, 1		0101000020E6100000C5C9FD0E459B4E401F86562767824B40
10641	6	58	\N	66	43395	\N	55.181279654059203	Челябинская область, город Челябинск, Тракторозаводский район, Октябрьская, 30	Россия, Челябинская область, Челябинск, улица Октябрьская	0101000020E610000065FF3C0D18BC4E409EB5DB2E34974B40
10638	6	58	\N	66	43395	\N	55.180131000000003	Челябинская область, город Челябинск, Тракторозаводский район, Октябрьская, 3		0101000020E610000077137CD3F4BB4E4076FF58880E974B40
10677	6	58	\N	66	42739	\N	55.145329675811197	Челябинская область, Челябинский городской округ, Центральный район, Образцова, 7	Россия, Челябинская область, Челябинск, улица Образцова, 7/1	0101000020E610000025CFF57D38B04E405890662C9A924B40
11793	6	58	\N	66	42694	\N	55.106850000000001	Челябинская область, Челябинский городской округ, Ленинский район, Новороссийская, 27		0101000020E6100000B45549641FBE4E40EFC9C342AD8D4B40
11792	6	58	\N	66	42694	\N	55.109321999999999	Челябинская область, Челябинский городской округ, Ленинский район, Новороссийская, 63	Россия, Челябинская область, Челябинск, улица Новороссийская, 63	0101000020E6100000FEB8FDF2C9BC4E40DD5D6743FE8D4B40
11791	6	58	\N	66	42694	\N	55.100982173271298	Челябинская область, Челябинский городской округ, Ленинский район, Новороссийская, 8	Россия, Челябинская область, Челябинск, улица Новороссийская, 8	0101000020E6100000A3CA30EE06BF4E400ABE69FAEC8C4B40
11782	6	58	\N	66	42694	\N	55.110979595855198	Челябинская область, Челябинский городской округ, Ленинский район, Новороссийская, 77А	Россия, Челябинская область, Челябинск, улица Новороссийская, 77а	0101000020E6100000DCF63DEAAFBB4E404A41B797348E4B40
11773	6	58	\N	66	42694	\N	55.117079749482897	Челябинская область, Челябинский городской округ, Ленинский район, Новороссийская, 136	Россия, Челябинская область, Челябинск, улица Новороссийская, 136	0101000020E610000043739D465AB64E400282397AFC8E4B40
11771	6	58	\N	66	42694	\N	55.117024999999998	Челябинская область, Челябинский городской округ, Ленинский район, Новороссийская, 126		0101000020E6100000A70705A568B74E403EE8D9ACFA8E4B40
11162	6	58	\N	66	43292	\N	55.131259	Челябинская область, Магнитогорский городской округ, Ленинский район, Московская, 26/2		0101000020E6100000143DF03158B14E4020274C18CD904B40
10544	6	58	\N	66	43419	\N	55.198509000000001	Челябинская область, город Челябинск, Курчатовский район, Молодогвардейцев, 12А		0101000020E61000000936AE7FD7A94E40187B2FBE68994B40
10543	6	58	\N	66	43419	\N	55.197958999999997	Челябинская область, город Челябинск, Курчатовский район, Молодогвардейцев, 18		0101000020E61000008159A148F7A94E40747973B856994B40
10528	6	58	\N	66	43419	\N	55.180022999999998	г.Челябинск, Молодогвардейцев, 70Б		0101000020E6100000B7EBA52902AA4E408FC360FE0A974B40
10527	6	58	\N	66	43419	\N	55.183039999999998	г.Челябинск, Молодогвардейцев, 62В		0101000020E61000002B1895D409AA4E400FEECEDA6D974B40
10526	6	58	\N	66	43419	\N	55.186447999999999	г.Челябинск, Молодогвардейцев, 56Б		0101000020E61000002B1895D409AA4E40CA332F87DD974B40
10523	6	58	\N	66	43419	\N	55.182788000000002	г.Челябинск, Молодогвардейцев, 43		0101000020E6100000FCFF3861C2AA4E40F60CE19865974B40
10522	6	58	\N	66	43419	\N	55.176048999999999	г.Челябинск, Молодогвардейцев, 61А		0101000020E6100000D996016729AB4E402BBF0CC688964B40
10562	6	58	\N	66	42646	\N	55.2380115111336	Челябинская область, Челябинский городской округ, Курчатовский район, Героя России Молодова, 18	Россия, Челябинская область, Челябинск, улица Молодова, 18	0101000020E6100000E63E390A10A74E401C075E2D779E4B40
10549	6	58	\N	66	42871	\N	55.1915915018036	Челябинская область, Челябинский городской округ, Курчатовский район, Молдавская, 23Б	Россия, Челябинская область, Челябинск, улица Молдавская, 23б	0101000020E61000008D25AC8DB1A74E406E162F1686984B40
10548	6	58	\N	66	42871	\N	55.191504999999999	Челябинская область, город Челябинск, Курчатовский район, Молдавская, 23Б		0101000020E610000065A9F57EA3A74E409F02603C83984B40
11709	6	58	\N	66	42643	\N	55.254297000000001	Челябинская область, г. Копейск, ул. Мира, 43		0101000020E61000009F39EB538EB14E40473CD9CD8CA04B40
10591	6	58	\N	66	42643	\N	55.2477502856594	Челябинская область, Челябинский городской округ, Металлургический район, Мира, 96А	Россия, Челябинская область, Челябинск, улица Мира, 96а	0101000020E61000004A7F2F8507AF4E40C1CAA145B69F4B40
11692	6	58	\N	55093	43116	\N	55.1179030827684	Челябинская область, г. Копейск, ул. Борьбы, 14А	Россия	0101000020E61000004A0C022B87CE4E40D68C0C72178F4B40
10589	6	58	\N	66	42643	\N	55.250909999999998	Челябинская область, город Челябинск, Металлургический район, Мира, 67А		0101000020E61000004910AE8042AF4E40A31EA2D11DA04B40
10586	6	58	\N	66	42643	\N	55.255195000000001	Челябинская область, город Челябинск, Металлургический район, Мира, д.46, здание школы № 96,(2эт)		0101000020E610000014D044D8F0B04E40268DD13AAAA04B40
10582	6	58	\N	66	42643	\N	55.255195000000001	Челябинская область, город Челябинск, Металлургический район, Мира, 46		0101000020E610000014D044D8F0B04E40268DD13AAAA04B40
10594	6	58	\N	66	3855	\N	55.243932412992798	Челябинская область, Челябинский городской округ, Металлургический район, Шоссе Металлургов, 53	Россия, Челябинская область, Челябинск, Металлургов шоссе, 53	0101000020E6100000EB1ED95C35AF4E405439ED29399F4B40
10592	6	58	\N	66	3855	\N	55.245435000000001	Челябинская область, Челябинский городской округ, Металлургический район, Шоссе Металлургов, 47	Россия, Челябинская область, Челябинск, Металлургов шоссе, 47	0101000020E6100000FB1F60ADDAAF4E409A25016A6A9F4B40
10590	6	58	\N	66	3855	\N	55.247805999999997	Челябинская область, Челябинский городской округ, Металлургический район, Шоссе Металлургов, 70Б	Россия, Челябинская область, Челябинск, Металлургов шоссе, 70б	0101000020E610000058C51B9947B04E4054E0641BB89F4B40
11783	6	58	\N	66	42703	\N	55.113334000000002	Челябинская область, Челябинский городской округ, Ленинский район, Машиностроителей, 31	Россия, Челябинская область, Челябинск, улица Машиностроителей, 31	0101000020E6100000001DE6CB0BBC4E402FC37FBA818E4B40
11099	6	58	\N	66	43241	\N	55.230040000000002	Челябинская область, Озерский городской округ, Матросова, 12а		0101000020E610000048C32973F3A94E40CC6262F3719D4B40
11785	6	58	\N	66	43051	\N	55.1195337492859	Челябинская область, Челябинский городской округ, Ленинский район, Масленникова, 21	Россия, Челябинская область, Челябинск, улица Масленникова, 21	0101000020E610000033535A7F4BBA4E404A61DEE34C8F4B40
10628	6	58	\N	66	42644	\N	55.171005000000001	Адрес УИК в день голосования: г.Челябинск, улица Марченко, д. 16 А, Адрес УИК: улица Танкистов, 144 Б		0101000020E6100000639AE95E27BB4E40EB39E97DE3954B40
10626	6	58	\N	66	42644	\N	55.166261684121899	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Марченко, 23 Г	Россия, Челябинская область, Челябинск, улица Марченко, 23г	0101000020E6100000B1FCF9B660BB4E40A648BE1248954B40
10625	6	58	\N	66	42644	\N	55.163466	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Марченко, 33	Россия, Челябинская область, Челябинск, улица Марченко, 33	0101000020E6100000C767B27F9EBA4E4004013274EC944B40
11825	6	58	\N	66	43677	\N	55.1269520918921	Челябинская область, Челябинский городской округ, Советский район, Марата, 8	Россия, Челябинская область, Челябинск, улица Марата, 8	0101000020E61000002B8881AE7DB14E40B61490F63F904B40
10645	6	58	\N	66	43432	\N	55.190781000000001	Челябинская область, город Челябинск, Тракторозаводский район, ул. Мамина, 21		0101000020E6100000CC09DAE4F0BD4E405ED905836B984B40
10644	6	58	\N	66	43432	\N	55.197080999999997	Челябинская область, город Челябинск, Тракторозаводский район, ул. Мамина, 9		0101000020E610000026FF93BF7BBD4E40DCD440F339994B40
10585	6	58	\N	66	43462	\N	55.252434000000001	Челябинская область, город Челябинск, Металлургический район, Липецкая, 27		0101000020E6100000DEB06D5166B14E400133DFC14FA04B40
11842	6	58	\N	66	42718	\N	55.182557882091203	Челябинская область, Челябинский городской округ, Советский район, Лермонтова, 17		0101000020E61000008E40BCAE5FB84E40C4CF7F0F5E974B40
11936	6	58	\N	66	125	\N	55.161552999999998	Челябинская область, Южноуральский городской округ, Ленина, 26	Россия, Челябинская область, Челябинск, Ленина проспект, 26	0101000020E6100000925D6919A9B74E400CC9C9C4AD944B40
11800	6	58	\N	66	125	\N	55.1600607151152	Челябинская область, Челябинский городской округ, Советский район, проспект Ленина, 41А	Россия, Челябинская область, Челябинск, Ленина проспект, 41	0101000020E61000004A4563EDEFB44E40BA2EFCE07C944B40
11189	6	58	\N	66	125	\N	55.15981	Челябинская область, Магнитогорский городской округ, Ленинский район, пр. ленина, 59	Россия, Челябинская область, Челябинск, Ленина проспект, 59	0101000020E6100000C1012D5DC1B24E4071C971A774944B40
10671	6	58	\N	66	125	\N	55.158802000000001	Челябинская область, Челябинский городской округ, Центральный район, проспект Ленина, 79	Россия, Челябинская область, Челябинск, Ленина проспект, 79	0101000020E6100000685BCD3AE3AF4E400B45BA9F53944B40
10664	6	58	\N	66	125	\N	55.158785999999999	Челябинская область, Челябинский городской округ, Центральный район, проспект Ленина, 69	Россия, Челябинская область, Челябинск, Ленина проспект, 69	0101000020E6100000B01F628385B14E400588821953944B40
10662	6	58	\N	66	125	\N	55.159968999999997	Челябинская область, город Челябинск, Центральный район, проспект Ленина, 80	Россия, Челябинская область, Челябинск, Ленина проспект, 80	0101000020E61000007F4C6BD3D8AE4E40D9AF3BDD79944B40
10624	6	58	\N	66	125	\N	55.15945	Челябинская область, Челябинский городской округ, Тракторозаводский район, проспект Ленина, 7	Россия, Челябинская область, Челябинск, Ленина проспект, 7	0101000020E610000073672618CEB94E4071AC8BDB68944B40
10607	6	58	\N	66	125	\N	55.160004999999998	Адрес УИК в день голосования: г.Челябинск, проспект Ленина, д. 13, Адрес УИК: переулок Артиллерийский, 2	Россия, Челябинская область, Челябинск, Ленина проспект, 13	0101000020E6100000E73A8DB454B84E402619390B7B944B40
86782	6	56	611	46823	\N	\N	56.635064999999997	поселок Колос, поселок Колос, 104		0101000020E6100000FA7B293C68804E40C8EA56CF49514C40
10565	6	58	\N	66	43739	\N	55.288838235745999	Челябинская область, город Челябинск, Металлургический район, Лазурная, 12	Россия, Челябинская область, Челябинск, улица Лазурная	0101000020E6100000ABCB290131B14E40C8EBC1A4F8A44B40
11818	6	58	\N	66	43130	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Советский район, Курчатова, 7		0101000020E6100000C5C9FD0E459B4E401F86562767824B40
11815	6	58	\N	66	43130	\N	55.147834000000003	Челябинская область, Челябинский городской округ, Советский район, Курчатова, 9		0101000020E61000000BEE073C30B24E40529E7939EC924B40
10640	6	58	\N	66	43428	\N	55.174661	Челябинская область, город Челябинск, Тракторозаводский район, Кулибина, 58		0101000020E6100000ADC266800BBC4E407E71A94A5B964B40
10630	6	58	\N	66	43428	\N	55.175359999999998	Челябинская область, город Челябинск, Тракторозаводский район, Кулибина, 60		0101000020E6100000E6EB32FCA7BB4E4066834C3272964B40
10542	6	58	\N	66	43420	\N	55.198051999999997	Челябинская область, город Челябинск, Курчатовский район, Куйбышева, 53		0101000020E6100000F5D72B2CB8AB4E40257497C459994B40
10541	6	58	\N	66	43420	\N	55.198051999999997	Челябинская область, город Челябинск, Курчатовский район, Куйбышева, 39		0101000020E6100000240F441669AC4E40257497C459994B40
11837	6	58	\N	66	42700	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Советский район, Кузнецова, 33		0101000020E6100000C5C9FD0E459B4E401F86562767824B40
11835	6	58	\N	66	42700	\N	55.116233000000001	Челябинская область, Челябинский городской округ, Советский район, Кузнецова, 7	Россия, Челябинская область, Челябинск, улица Кузнецова, 7	0101000020E610000001FC53AA44AD4E40A5DB12B9E08E4B40
10611	6	58	\N	66	42989	\N	55.1740036658842	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Кудрявцева, 79	Россия, Челябинская область, Челябинск, улица Кудрявцева, 79	0101000020E6100000BB9BA73AE4B64E40C4AF58C345964B40
10469	6	58	\N	66	42989	\N	55.181466999999998	г.Челябинск, Кудрявцева, 18		0101000020E610000067614F3BFCB54E40D026874F3A974B40
11789	6	58	\N	66	42949	\N	55.128097205647002	Челябинская область, Челябинский городской округ, Ленинский район, Кронштадтская, 10		0101000020E6100000C24D469561BC4E409CDB847B65904B40
10588	6	58	\N	66	43455	\N	55.250889999999998	Челябинская область, город Челябинск, Металлургический район, Краснооктябрьская, 26		0101000020E6100000A7CEA3E2FFB04E405C72DC291DA04B40
10539	6	58	\N	66	43484	\N	55.191685	Челябинская область, город Челябинск, Курчатовский район, Красного Урала, 16		0101000020E61000009EB5DB2E34AD4E401F11532289984B40
10654	6	58	\N	66	42726	\N	55.164272569603199	Челябинская область, Челябинский городской округ, Центральный район, Красноармейская, 140	Россия, Челябинская область, Челябинск, улица Красноармейская, 140	0101000020E61000003B70CE88D2B44E40D34ECDE506954B40
10653	6	58	\N	66	42726	\N	55.164099	Челябинская область, Челябинский городской округ, Центральный район, Красноармейская, 93А		0101000020E61000000458E4D70FB54E4035272F3201954B40
10652	6	58	\N	66	42726	\N	55.167526001675199	Челябинская область, Челябинский городской округ, Центральный район, Красноармейская, 88	Россия, Челябинская область, Челябинск, улица Красноармейская, 88	0101000020E6100000C573B680D0B44E40679DF17D71954B40
10663	6	58	\N	66	43223	\N	55.159083243786803	Челябинская область, Челябинский городской округ, Центральный район, Красная, 38	Россия, Челябинская область, Челябинск, улица Красная, 38	0101000020E61000003C1405FA44B24E40BF2CEDD45C944B40
10634	6	58	\N	66	42874	\N	55.179240999999998	Челябинская область, город Челябинск, Тракторозаводский район, Котина, 22		0101000020E6100000361D01DC2CBA4E40198D7C5EF1964B40
10618	6	58	\N	66	42874	\N	55.176405392951999	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Котина, 48	Россия, Челябинская область, Челябинск, улица Котина, 48	0101000020E610000066834C3272B84E40EAEC647094964B40
11797	6	58	\N	66	42821	\N	55.121257038798703	Челябинская область, Челябинский городской округ, Ленинский район, Копейское шоссе, 5	Россия, Челябинская область, Челябинск, Копейское шоссе, 5	0101000020E610000005357C0BEBC04E409EB47059858F4B40
10545	6	58	\N	66	32	\N	55.192399000000002	Челябинская область, город Челябинск, Курчатовский район, Комсомольский проспект, 55А	Россия, Челябинская область, Челябинск, Комсомольский проспект, 55а	0101000020E61000008927BB99D1A94E403D64CA87A0984B40
10660	6	58	\N	66	42990	\N	55.161226373885	Челябинская область, Челябинский городской округ, Центральный район, Коммуны, 147	Россия, Челябинская область, Челябинск, улица Коммуны, 147	0101000020E610000045F0BF95ECAE4E40E8A1B60DA3944B40
10659	6	58	\N	66	42990	\N	55.161929975638103	Челябинская область, Челябинский городской округ, Центральный район, Коммуны, 133	Россия, Челябинская область, Челябинск, улица Коммуны, 133	0101000020E61000007863416150B04E40E21E4B1FBA944B40
10572	6	58	\N	66	43302	\N	55.260745999999997	Челябинская область, город Челябинск, Металлургический район, Коммунистическая, 7		0101000020E6100000BE6A65C22FB34E400A48FB1F60A14B40
11762	6	58	\N	66	42839	\N	55.136889208519001	Челябинская область, Челябинский городской округ, Ленинский район, Коммунаров, 28	Россия, Челябинская область, Челябинск, улица Коммунаров, 28	0101000020E6100000257A19C572B74E405017299485914B40
11758	6	58	\N	66	42839	\N	55.143629684928698	Челябинская область, Челябинский городской округ, Ленинский район, Коммунаров, 4	Россия, Челябинская область, Челябинск, улица Коммунаров	0101000020E61000003B1BF2CF0CB84E40BC5CC47762924B40
11682	6	58	\N	55093	43116	\N	55.098417538168	Челябинская область, г. Копейск, ул. Борьбы, 59	Россия	0101000020E6100000BC783F6EBFCE4E403BAB05F6988C4B40
11756	6	58	\N	66	42839	\N	55.143728000000003	Челябинская область, Челябинский городской округ, Ленинский район, ул.Коммунаров,4,1 этаж,спортзал		0101000020E61000002F6D382C0DB84E407FC2D9AD65924B40
10517	6	58	\N	66	43414	\N	55.182855000000004	г.Челябинск, Коммунальная, 48		0101000020E61000006AF6402B30AE4E407E74EACA67974B40
10597	6	58	\N	66	43069	\N	55.238911000000002	Челябинская область, город Челябинск, Металлургический район, Комаровского, 7Б		0101000020E6100000FD69A33A1DB04E40CCD3B9A2949E4B40
10596	6	58	\N	66	43069	\N	55.240451	Челябинская область, город Челябинск, Металлургический район, Комаровского, 11Б		0101000020E6100000ED2DE57CB1AF4E402FA52E19C79E4B40
10595	6	58	\N	66	43069	\N	55.240451	Челябинская область, Челябинский городской округ, Металлургический район, Комаровского, 11Б		0101000020E6100000ED2DE57CB1AF4E402FA52E19C79E4B40
10643	6	58	\N	66	43045	\N	55.189237284590298	Челябинская область, Челябинский городской округ,Тракторозаводской район,ул.Комарова,41,2 этаж,холл	Россия, Челябинская область, Челябинск, улица Комарова, 41	0101000020E6100000D6AC33BE2FBC4E40B91803EB38984B40
10642	6	58	\N	66	43077	\N	55.1891076149223	Челябинская область, город Челябинск, Тракторозаводский район, Проспект Комарова, 41	Россия, Челябинская область, Челябинск, улица Комарова, 41	0101000020E610000035D252793BBC4E40BBB4E1B034984B40
10632	6	58	\N	66	43077	\N	55.173511554806801	Челябинская область, город Челябинск, Тракторозаводский район, Проспект Комарова, 114	Россия, Челябинская область, Челябинск, улица Комарова, 114	0101000020E6100000ADFC321823BA4E4056BB26A435964B40
11844	6	58	\N	66	43454	\N	55.0403920949853	Челябинская область, Челябинский городской округ, Советский район, поселок Новосинеглазово, Кирова, 1	Россия, Челябинская область, Челябинск, поселок Новосинеглазово, улица Кирова, 1	0101000020E6100000BC07E8BE9CAF4E409082A7902B854B40
10512	6	58	\N	66	43444	\N	55.178151	г.Челябинск, Кирова, 44		0101000020E61000008CA2073E06B34E40F65FE7A6CD964B40
10510	6	58	\N	66	43444	\N	55.176568000000003	г.Челябинск, Кирова, 13Б		0101000020E61000004DBB9866BAB34E4094C2BCC799964B40
10508	6	58	\N	66	43444	\N	55.181755000000003	г.Челябинск, Кирова, 3А		0101000020E6100000617138F3ABB34E40377172BF43974B40
11829	6	58	\N	66	43140	\N	55.120572048937397	Челябинская область, Челябинский городской округ, Советский район, Карабанова, 10А		0101000020E610000056444DF4F9B24E401B683EE76E8F4B40
11840	6	58	\N	66	43149	\N	55.084011657483998	Челябинская область, Челябинский городской округ, Советский район, Капитанская, 10А	Россия, Челябинская область, Челябинск, улица Капитанская, 10а	0101000020E610000085251E5036AB4E405C3CBCE7C08A4B40
10515	6	58	\N	66	43449	\N	55.179837999999997	г.Челябинск, Калинина, 28		0101000020E6100000397F130A11B24E40FD497CEE04974B40
11839	6	58	\N	66	42707	\N	55.073180000000001	Челябинская область, Челябинский городской округ, Советский район, Зои Космодемьянской, 1	Россия, Челябинская область, Челябинск, Советский район	0101000020E61000007B32FFE89BAE4E40535C55F65D894B40
10552	6	58	\N	66	43423	\N	55.197434999999999	Челябинская область, город Челябинск, Курчатовский район, Захаренко, 3А		0101000020E6100000BE4A3E7617A84E40FA0AD28C45994B40
11470	6	58	\N	66	43306	\N	55.153536041419699	"""Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Заводская, 34 """"Г"""""""	Россия, Челябинская область, Челябинск, поселок Шершни, улица Заводская	0101000020E6100000B2DAFCBFEAA64E401C615111A7934B40
10580	6	58	\N	66	43460	\N	55.256000999999998	Челябинская область, город Челябинск, Металлургический район, Жукова, 16		0101000020E610000013B69F8CF1B14E40245F09A4C4A04B40
10579	6	58	\N	66	43460	\N	55.252476000000001	Челябинская область, город Челябинск, Металлургический район, Жукова, 27		0101000020E61000000BEE073C30B24E403083312251A04B40
11784	6	58	\N	66	42666	\N	55.115659029512997	Челябинская область, Челябинский городской округ, Ленинский район, Ереванская, 16	Россия, Челябинская область, Челябинск, улица Ереванская, 16	0101000020E6100000F19C2D20B4BA4E40793E03EACD8E4B40
11816	6	58	\N	66	42728	\N	55.151376176100101	Челябинская область, Челябинский городской округ, Советский район, Елькина, 88	Россия, Челябинская область, Челябинск, улица Елькина, 88	0101000020E6100000FA804067D2B24E401CB3EC4960934B40
10655	6	58	\N	66	42728	\N	55.167122999999997	Челябинская область, Челябинский городской округ, Центральный район, Елькина, 10	Россия, Челябинская область, Челябинск, улица Елькина, 10	0101000020E61000005DDE1CAED5B24E4067B4554964954B40
11847	6	58	\N	66	43742	\N	55.042437	Челябинская область, Челябинский городской округ, Советский район, поселок Исаково, Дорожная, 3		0101000020E610000025B20FB22CB84E40F7915B936E854B40
11823	6	58	\N	66	42705	\N	55.140020047685702	Челябинская область, Челябинский городской округ, Советский район, Доватора, 15	Россия, Челябинская область, Челябинск, улица Доватора, 15	0101000020E6100000F7949C137BB24E409964E42CEC914B40
11820	6	58	\N	66	43136	\N	55.143203999999997	Челябинская область, Челябинский городской округ, Советский район, Доватора, 34		0101000020E61000004948A46DFCB14E400454388254924B40
11819	6	58	\N	66	43131	\N	55.144351	Челябинская область, Челябинский городской округ, Советский район, Доватора, 38		0101000020E6100000A83462669FB14E408C12F4177A924B40
11779	6	58	\N	66	42729	\N	55.128145000000004	Челябинская область, Челябинский городской округ, Ленинский район, Дзержинского, 83А	Россия, Челябинская область, Челябинск, улица Дзержинского, 83а	0101000020E6100000A7B393C151B84E40AE122C0E67904B40
10456	6	58	\N	27323	43078	\N	54.992517999999997	Челябинская область, город Чебаркуль, Фрунзе, 18 (МОУСОШ №9)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
11778	6	58	\N	66	42729	\N	55.131596317488103	Челябинская область, Челябинский городской округ, Ленинский район, Дзержинского, 94	Россия, Челябинская область, Челябинск, улица Дзержинского, 94	0101000020E61000000057B26323B84E4068244223D8904B40
10578	6	58	\N	66	43456	\N	55.252603999999998	Челябинская область, город Челябинск, Металлургический район, Дегтярева, 72А		0101000020E6100000FA97A432C5B24E405D6BEF5355A04B40
11983	6	58	\N	66	42675	\N	55.181729940362303	Челябинская область, Челябинский городской округ, ул.Двинская, 7, школа № 54	Россия, Челябинская область, Челябинск, улица Двинская	0101000020E6100000F86F5E9CF8AC4E40DE59BBED42974B40
10518	6	58	\N	66	42675	\N	55.181416831723098	г.Челябинск, Двинская, 7	Россия, Челябинская область, Челябинск, улица Двинская	0101000020E61000001E17D522A2AC4E401FF818AC38974B40
11846	6	58	\N	66	43101	\N	55.071694999999998	Челябинская область, Челябинский городской округ, Советский район, поселок Смолинский, переулок Дачный, 22	Россия, Челябинская область, Челябинск, поселок Смолино, Дачный переулок, 22	0101000020E61000000E6B2A8BC2B24E40B324404D2D894B40
10516	6	58	\N	66	43468	\N	55.181483	г.Челябинск, Дальневосточная, 2		0101000020E6100000925B936E4BB04E40D6E3BED53A974B40
10614	6	58	\N	66	42670	\N	55.179678000000003	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Грибоедова, 2	Россия, Челябинская область, Челябинск, улица Грибоедова, 2	0101000020E6100000F530B43A39B74E40C5E74EB0FF964B40
10609	6	58	\N	66	42670	\N	55.170953419180798	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Грибоедова, 35	Россия, Челябинская область, Челябинск, улица Грибоедова, 35	0101000020E6100000047289230FB84E409813B4C9E1954B40
10617	6	58	\N	66	43072	\N	55.178645000000003	Адрес УИК в день голосования: г.Челябинск, улица Горького, д. 38, Адрес УИК: улица Культуры, 102		0101000020E61000008BC22E8A1EB84E40064CE0D6DD964B40
10612	6	58	\N	66	43072	\N	55.176084588316201	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Горького, 47 Б	Россия, Челябинская область, Челябинск, улица Горького, 47б	0101000020E61000000725CCB4FDB74E4078280AF489964B40
10608	6	58	\N	66	43072	\N	55.164802702787497	Челябинская область, город Челябинск, Тракторозаводский район, улица Горького, 11	Россия, Челябинская область, Челябинск, улица Горького, 11	0101000020E6100000FFD0CC936BB84E402FA4C34318954B40
10458	6	58	\N	66	43072	\N	55.182628999999999	г.Челябинск, Горького, 79		0101000020E6100000E77118CC5FB74E408D26176360974B40
94446	6	58	\N	66	43208	\N	55.237019578886702	Челябинская область, Челябинский городской округ,Городок 11,новое здание,2 -й этаж, рекриация,МОУ СОШ № 28	Россия, Челябинская область, Челябинск, городок 11-й, 7	0101000020E6100000A8AAD0402CA74E40BC3FDEAB569E4B40
11768	6	58	\N	66	42691	\N	55.125889270785599	Челябинская область, Челябинский городской округ, Ленинский район, Гончаренко, 90	Россия, Челябинская область, Челябинск, улица Гончаренко, 90	0101000020E61000001763601DC7B54E408CF678211D904B40
10557	6	58	\N	66	43205	\N	55.238046762348702	Челябинская область, город Челябинск, Курчатовский район, Героя России Молодова, 18		0101000020E61000007A71E2AB1DA74E4099F4F752789E4B40
11907	6	58	\N	66	42648	\N	55.188510476794001	г.Челябинск, Героев Танкограда, 23		0101000020E610000008910C39B6B84E40077C7E1821984B40
10633	6	58	\N	66	42648	\N	55.175648000000002	Челябинская область, город Челябинск, Тракторозаводский район, Героев Танкограда, 104		0101000020E610000085EAE6E26FB94E40CDCD37A27B964B40
10619	6	58	\N	66	42648	\N	55.175648000000002	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Героев Танкограда, 104	Россия, Челябинская область, Челябинск, улица Героев Танкограда, 104	0101000020E610000085EAE6E26FB94E40CDCD37A27B964B40
11981	6	58	\N	66	42995	\N	55.2148490868938	Челябинская область, Челябинский городской округ, Курчатовский район, Генерала Мартынова, 7 офис 3	Россия, Челябинская область, Челябинск, Курчатовский район	0101000020E6100000DFF94509FAAB4E40064A0A2C809B4B40
11715	6	58	\N	\N	43406	\N	55.108104897394099	Челябинская область, г. Копейск, ул. Гагарина, 7	Россия	0101000020E6100000BC218D0A9CCE4E405DC47762D68D4B40
10546	6	58	\N	66	43458	\N	55.191504999999999	Челябинская область, город Челябинск, Курчатовский район, Ворошилова, 16		0101000020E61000008577B988EFA84E409F02603C83984B40
10678	6	58	\N	66	42878	\N	55.139845563814802	Челябинская область, Челябинский городской округ, Центральный район, Воровского, 64	Россия, Челябинская область, Челябинск, улица Воровского, 64	0101000020E6100000F37519FED3AF4E40FB3C4679E6914B40
10669	6	58	\N	66	42878	\N	55.149734046914901	Челябинская область, Челябинский городской округ, Центральный район, Воровского, 36А		0101000020E6100000132D793C2DB14E40B58CD47B2A934B40
10658	6	58	\N	66	42724	\N	55.163549000000003	Челябинская область, Челябинский городской округ, Центральный район, Володарского, 20		0101000020E61000002EE411DC48B14E409225732CEF944B40
10657	6	58	\N	66	42724	\N	55.164448999999998	Челябинская область, Челябинский городской округ, Центральный район, Володарского, 18	Россия, Челябинская область, Челябинск, улица Володарского, 18	0101000020E6100000121615713AB14E40116E32AA0C954B40
11794	6	58	\N	66	42964	\N	55.101099827228403	Челябинская область, Челябинский городской округ, Ленинский район, Василевского, 75	Россия, Челябинская область, Челябинск, улица Васильевского, 75	0101000020E610000006F2ECF2ADBD4E4014D044D8F08C4B40
10461	6	58	\N	27323	43558	\N	54.992517999999997	Челябинская область, город Чебаркуль, Станционная, 10, (МОУ СОШ № 76)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
11766	6	58	\N	66	42948	\N	55.1298066019015	Челябинская область, Челябинский городской округ, Ленинский район, Вагнера, 90	Россия, Челябинская область, Челябинск, улица Вагнера, 90	0101000020E61000000EDC813AE5B54E405CE509849D904B40
11761	6	58	\N	66	42948	\N	55.1379880361266	Челябинская область, Челябинский городской округ, Ленинский район, Вагнера, 70А		0101000020E6100000F017B325ABB64E40C79E3D97A9914B40
11780	6	58	\N	66	42722	\N	55.122449893005097	Челябинская область, Челябинский городской округ, Ленинский район, Брестская, 17	Россия, Челябинская область, Челябинск, улица Брестская, 14	0101000020E610000049145AD6FDB94E4096B20C71AC8F4B40
10577	6	58	\N	66	42642	\N	55.257947287360501	Челябинская область, город Челябинск, Металлургический район, Богдана Хмельницкого, 7		0101000020E6100000DB6B41EF8DAF4E40F88C446804A14B40
10575	6	58	\N	66	42642	\N	55.256268299882699	Челябинская область, город Челябинск, Металлургический район, Богдана Хмельницкого, 24	Россия, Челябинская область, Челябинск, улица Богдана Хмельницкого	0101000020E610000043E6CAA0DAAE4E407381CB63CDA04B40
10574	6	58	\N	66	42642	\N	55.256785999999998	Челябинская область, Челябинский городской округ, Металлургический район, Богдана Хмельницкого, 24	Россия, Челябинская область, Челябинск, улица Богдана Хмельницкого	0101000020E6100000DCA16131EAAE4E400B09185DDEA04B40
10573	6	58	\N	66	42642	\N	55.257211973146802	Челябинская область, город Челябинск, Металлургический район, Богдана Хмельницкого, 12		0101000020E6100000910E0F61FCAE4E40C311A452ECA04B40
11832	6	58	\N	66	42954	\N	55.121462999999999	Челябинская область, Челябинский городской округ, Советский район, Блюхера, 91		0101000020E61000006D567DAEB6AE4E4047567E198C8F4B40
11831	6	58	\N	66	42954	\N	55.128340999999999	Челябинская область, Челябинский городской округ, Советский район, Блюхера, 69		0101000020E61000004FCE50DCF1AE4E4033DE567A6D904B40
11822	6	58	\N	66	42954	\N	55.143585995980601	Челябинская область, Челябинский городской округ, Советский район, Блюхера, 6		0101000020E61000008C2D043928B14E40EC14AB0661924B40
10511	6	58	\N	66	43448	\N	55.175122999999999	г.Челябинск, Береговая, 99		0101000020E610000034DAAA24B2B34E4082E3326E6A964B40
11154	6	58	\N	66	43282	\N	55.106299707769899	Челябинская область, Челябинский городской округ, Ленинский район, Бахметьева, 11	Россия, Челябинская область, Челябинск, улица Бугурусланская	0101000020E61000000E828E56B5BE4E404BC8073D9B8D4B40
11787	6	58	\N	66	42943	\N	55.120114999999998	Челябинская область, Челябинский городской округ, Ленинский район, Батумская, 10	Россия, Челябинская область, Челябинск, улица Батумская, 10	0101000020E610000071FF91E9D0BB4E402861A6ED5F8F4B40
11786	6	58	\N	66	42943	\N	55.122044664333799	Челябинская область, Челябинский городской округ, Ленинский район, Батумская, 3	Россия, Челябинская область, Челябинск, улица Батумская, 3	0101000020E610000091D0967329BC4E40F6D1A92B9F8F4B40
11769	6	58	\N	66	42819	\N	55.129159000000001	Челябинская область, Челябинский городской округ, Ленинский район, Барбюса, 65А		0101000020E6100000B189CC5CE0B64E40F67D384888904B40
11767	6	58	\N	66	42819	\N	55.129463957970998	Челябинская область, Челябинский городской округ, Ленинский район, Барбюса, 140Б	Россия, Челябинская область, Челябинск, улица Барбюса, 140б	0101000020E61000001A89D00836B64E403201BF4692904B40
10637	6	58	\N	66	43403	\N	55.185569000000001	Челябинская область, город Челябинск, Тракторозаводский район, Бажова, 32		0101000020E6100000C3633F8BA5BA4E40621399B9C0974B40
10635	6	58	\N	66	43403	\N	55.182232999999997	Адрес УИК в день голосования: г. Челябинск, ул. Бажова, д. 48, Адрес УИК: г. Челябинск, ул. Бажова, 46 А		0101000020E61000005E6743FE99B94E4040A0336953974B40
10615	6	58	\N	66	42645	\N	55.180118996926097	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Артиллерийская, 55 А	Россия, Челябинская область, Челябинск, улица Артиллерийская, 55а	0101000020E61000000E87A5811FB74E40B131AF230E974B40
10613	6	58	\N	66	42645	\N	55.178465000000003	Челябинская область, Челябинский городской округ, Тракторозаводский район, улица Артиллерийская, 100	Россия, Челябинская область, Челябинск, улица Артиллерийская, 100	0101000020E6100000C1525DC0CBB64E40863DEDF0D7964B40
11985	6	58	\N	66	42828	\N	55.165618905951803	Челябинская область, Челябинский городской округ,ул.Ак.Макеева,5/А,2 ЭТАЖ,ХОЛЛ		0101000020E610000058CB9D9960A64E40514CDE0033954B40
10680	6	58	\N	66	42828	\N	55.165539000000003	Челябинская область, Челябинский городской округ, Центральный район, Академика Макеева, 5А		0101000020E610000047E5266A69A64E40359BC76130954B40
11764	6	58	\N	66	43029	\N	55.132845000000003	Челябинская область, Челябинский городской округ, Ленинский район, Агалакова, 46	Россия, Челябинская область, Челябинск, улица Агалакова, 46	0101000020E6100000204432E4D8B84E40F437A11001914B40
11763	6	58	\N	66	43029	\N	55.135660000000001	Челябинская область, Челябинский городской округ, Ленинский район, Агалакова, 19		0101000020E61000001E54E23AC6B74E400CB08F4E5D914B40
10571	6	58	\N	66	43422	\N	55.262593000000003	Челябинская область, город Челябинск, Металлургический район, 60 лет Октября, 46		0101000020E6100000AABBB20B06B14E404B94BDA59CA14B40
10570	6	58	\N	66	43422	\N	55.264434999999999	Челябинская область, город Челябинск, Металлургический район, 60 лет Октября, 26		0101000020E610000064062AE3DFB14E4079758E01D9A14B40
10568	6	58	\N	66	43422	\N	55.263905999999999	Челябинская область, город Челябинск, Металлургический район, 60 лет Октября, 5		0101000020E6100000EB01F39029B34E40ED9BFBABC7A14B40
10444	6	58	\N	27323	42626	\N	54.968660351265903	Челябинская область, город Чебаркуль, Советская, 269 А	Россия, Челябинская область, Чебаркуль	0101000020E610000014B18861872D4E40C078060DFD7B4B40
10601	6	58	\N	66	43391	\N	55.247677789350199	Челябинская область, город Челябинск, Металлургический район, 50 лет ВЛКСМ, 1	Россия, Челябинская область, Челябинск, улица 50 Лет ВЛКСМ, 1	0101000020E6100000849D62D520B24E4027F8A6E9B39F4B40
10600	6	58	\N	66	43391	\N	55.244382999999999	Челябинская область, город Челябинск, Металлургический район, 50 лет ВЛКСМ, 7Б		0101000020E610000012D9075916B24E40645930F1479F4B40
10598	6	58	\N	66	43391	\N	55.242468000000002	Челябинская область, город Челябинск, Металлургический район, 50 лет ВЛКСМ, 16		0101000020E6100000C689AF7614B14E40CC290131099F4B40
10556	6	58	\N	66	43125	\N	55.193352733562797	Челябинская область, город Челябинск, Курчатовский район, 40летия  Победы, 14А		0101000020E6100000DA9255116EA44E40B0CA85CABF984B40
10555	6	58	\N	66	43058	\N	55.1906337003037	Челябинская область, город Челябинск, Курчатовский район, 40летия Победы, 17		0101000020E61000000CC85EEFFEA44E40BAC0E5B166984B40
10554	6	58	\N	66	43133	\N	55.188565146093801	Челябинская область, город Челябинск, Курчатовский район, 40летия  Победы, 17	Россия, Челябинская область, Челябинск, улица 40 Лет Победы, 17	0101000020E610000089EC832C0BA64E40CA15DEE522984B40
7839	6	58	\N	66	43172	\N	55.184174961407699	г.Челябинск, 40летия Победы, 24А	Россия, Челябинская область, Челябинск, улица 40 Лет Победы, 24	0101000020E610000063D009A183A64E40D3DEE00B93974B40
10605	6	58	\N	66	42638	\N	55.238815959036302	Челябинская область, Челябинский городской округ, Металлургический район, 32 годовщины Октября, 18А	Россия, Челябинская область, Челябинск, улица 32-й Годовщины Октября, 18а	0101000020E61000004AB54FC763B24E407AE1CE85919E4B40
10651	6	58	\N	66	42723	\N	55.162318999999997	Челябинская область, Челябинский городской округ, Центральный район, 3 Интернационала, 113	Россия, Челябинская область, Челябинск, улица 3 Интернационала, 113	0101000020E6100000C0B2D2A414B64E407C4276DEC6944B40
10650	6	58	\N	66	42723	\N	55.1724071850605	Челябинская область, Челябинский городской округ, Центральный район, 3 Интернационала, 61	Россия, Челябинская область, Челябинск, улица 3 Интернационала, 61	0101000020E6100000BD8BF7E3F6B54E40FD4CBD6E11964B40
10649	6	58	\N	66	42723	\N	55.172511	Челябинская область, город Челябинск, Центральный район, 3 Интернационала, 61		0101000020E6100000B4AD669DF1B54E40A29927D714964B40
10606	6	58	\N	66	42649	\N	55.235994955274798	Челябинская область, Челябинский городской округ, Металлургический район, 26 Бакинских комиссаров, 63	Россия, Челябинская область, Челябинск, улица 26 Бакинских Комиссаров, 63	0101000020E61000002060ADDA35B34E4080828B15359E4B40
10529	6	58	\N	66	43413	\N	55.180804000000002	г.Челябинск, 250летия Челябинска, 7		0101000020E610000033315D88D5A74E40357EE19524974B40
6736	6	58	\N	66	43413	\N	55.178311000000001	г.Челябинск, 250летия Челябинска, 15		0101000020E610000068EA758BC0A64E402FC214E5D2964B40
10647	6	58	\N	66	43472	\N	55.167282	Челябинская область, город Челябинск, Тракторозаводский район, Эльтонская 2я, 16 А		0101000020E610000074CE4F711CC44E40D09A1F7F69954B40
10661	6	58	\N	66	43082	\N	55.168842576470901	Челябинская область, Челябинский городской округ, Центральный район, поселок Мелькомбинат2 участок 1, 26	Россия, Челябинская область, Челябинск, улица 2-й Мелькомбинат, 26	0101000020E6100000A54BFF9254AC4E404B94BDA59C954B40
10509	6	58	\N	66	43450	\N	55.181755000000003	г.Челябинск, Кирова, 3а		0101000020E6100000617138F3ABB34E40377172BF43974B40
10521	6	58	\N	66	43470	\N	55.176012999999998	г.Челябинск, Братьев Кашириных, 103Б		0101000020E6100000DE1D19ABCDAB4E40DE550F9887964B40
11770	6	58	\N	66	43124	\N	55.123131029095703	Челябинская область, Челябинский городской округ, Ленинский район, Барбюса, 79Б		0101000020E6100000EFA83121E6B64E40D80FB1C1C28F4B40
10636	6	58	\N	66	43442	\N	55.183002302496902	Адрес УИК в день голосования: г. Челябинск, ул. Бажова, д. 46 А, Адрес УИК: г. Челябинск, ул. Бажова, 32		0101000020E6100000651D8EAED2B94E40228D0A9C6C974B40
11963	6	58	\N	27323	\N	\N	54.999250857933497	Чебаркульский городской округ, в/ч 89547, 1 этаж, фойе клуба в/ч 89547	Россия, Челябинская область, Чебаркуль	0101000020E610000089B663EAAE304E4066BFEE74E77F4B40
10437	6	58	\N	27323	\N	\N	54.992517999999997	"""Челябинская область, город Чебаркуль, санаторий """"Каменный цветок"""", спортзал санатория""""Каменный цветок"""""""		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10436	6	58	\N	27323	\N	\N	54.992517999999997	"""Челябинская область, город Чебаркуль, санаторий """"УралВО"""", помещение клуба военного санатория"""		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10435	6	58	\N	27323	\N	\N	54.992517999999997	"""Челябинская область, город Чебаркуль, санаторий """"Еловое"""", помещение клуба санатория """"Еловое"""""""		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10434	6	58	\N	27323	\N	\N	54.978744601625301	"""Челябинская область, город Чебаркуль, санаторий """"Кисегач"""", клуб ООО """"Санаторий Кисегач"""""""	Россия, Челябинская область, Чебаркуль	0101000020E6100000EB39E97DE32D4E40D00F2384477D4B40
10454	6	58	\N	27323	42636	\N	54.992517999999997	Челябинская область, город Чебаркуль, Электростальская, 32 Б (МОУСОШ №6 помещение спортзал)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10453	6	58	\N	27323	42636	\N	54.975461636569797	Челябинская область, город Чебаркуль, Электростальская, 32 Б(МОУ СОШ №6 помещение столовой)	Россия, Челябинская область, Чебаркуль	0101000020E61000004AD3A0681E304E40D13E56F0DB7C4B40
10452	6	58	\N	27323	42636	\N	54.980869977159799	Челябинская область, город Чебаркуль, Электростальская, 1 А (спорткомплекс)	Россия, Челябинская область, Чебаркуль	0101000020E6100000996379573D2E4E4053D0ED258D7D4B40
10439	6	58	\N	27323	43687	\N	54.988653571309001	Челябинская область, город Чебаркуль, Шоссейная, 9, (ДЮСШ)	Россия, Челябинская область, Чебаркуль	0101000020E6100000D61F6118B02E4E40A087DA368C7E4B40
10455	6	58	\N	27323	42869	\N	54.992517999999997	Челябинская область, город Чебаркуль, Мира, 21Б (школа №10 помещение столовой)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10451	6	58	\N	27323	42869	\N	54.992517999999997	Челябинская область, город Чебаркуль, Мира, 19 А (центр детского творчества)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10438	6	58	\N	27323	43952	\N	54.992517999999997	Челябинская область, город Чебаркуль, Миасское шоссе, 5		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10446	6	58	\N	27323	42628	\N	54.992517999999997	"""Челябинская область, город Чебаркуль, Ленина, 32 Б (кинотеатр """"Волна"""")"""		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10445	6	58	\N	27323	42628	\N	54.981314243883702	Челябинская область, город Чебаркуль, Ленина, 42 (МОУСОШ №2)	Россия, Челябинская область, Чебаркуль	0101000020E61000005E30B8E68E2E4E40B08D78B29B7D4B40
10443	6	58	\N	27323	42627	\N	54.992517999999997	Челябинская область, город Чебаркуль, Комсомольская, 7А(МОУСОШ №7 большой спортзал)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10442	6	58	\N	27323	42627	\N	54.968759107786802	Челябинская область, город Чебаркуль, Комсомольская, 7А(школа №7 помещение столовой)	Россия, Челябинская область, Чебаркуль	0101000020E6100000B709F7CABC2D4E40535A7F4B007C4B40
10441	6	58	\N	27323	42627	\N	54.968512216027399	Челябинская область, город Чебаркуль, Комсомольская, 7А (школа №7,правое крыло здания)	Россия, Челябинская область, Чебаркуль	0101000020E6100000A0E1CD1ABC2D4E404BE48233F87B4B40
10460	6	58	\N	27323	42681	\N	54.978303006066	Челябинская область, город Чебаркуль, Каширина, 58 (школа №11)		0101000020E6100000C77F8120402E4E40124A5F08397D4B40
10459	6	58	\N	27323	42681	\N	54.992517999999997	Челябинская область, город Чебаркуль, Каширина, 3 (большой спортзал школы №4)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10457	6	58	\N	27323	42681	\N	54.992517999999997	Челябинская область, город Чебаркуль, Каширина, 3 (малый спортзал школа №4)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10448	6	58	\N	27323	43204	\N	54.992517999999997	"""Челябинская область, город Чебаркуль, Карпенко, 11 (клуб """"Нептун"""")"""		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10450	6	58	\N	27323	42631	\N	54.992517999999997	Челябинская область, город Чебаркуль, 9 Мая, 9 (МОУСОШ №1 большой зал)		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
10449	6	58	\N	27323	42631	\N	54.975424609110597	"""Челябинская область, город Чебаркуль, 9 мая, 11 (клуб """"Дебют"""")"""	Россия, Челябинская область, Чебаркуль	0101000020E61000009D836742932E4E40B459F5B9DA7C4B40
10447	6	58	\N	27323	42631	\N	54.975538391297803	Челябинская область, город Чебаркуль, 9 мая, 9 (МОУСОШ №1 малый спортзал)	Россия, Челябинская область, Чебаркуль	0101000020E6100000A92EE065862F4E40AC00DF6DDE7C4B40
10440	6	58	\N	27323	43495	\N	54.992517999999997	Челябинская область, город Чебаркуль, 1 мая, 20		0101000020E61000000BB43BA418304E407D586FD40A7F4B40
11139	6	58	\N	29076	\N	\N	54.928897999999997	Челябинская область, город УстьКатав, поселок Паранино, д.5		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11147	6	58	\N	29076	42927	\N	54.904867000000003	Челябинская область, город УстьКатав, поселок Вязовая, ул. Советская, д. 19		0101000020E61000002FE1D05B3C2E4D40651D8EAED2734B40
11136	6	58	\N	29076	42772	\N	54.928897999999997	Челябинская область, город УстьКатав, ул. Революционная, д. 10		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11142	6	58	\N	29076	43272	\N	54.931211071827398	Челябинская область, город УстьКатав, ул. Рабочая, д. 39	Россия, Челябинская область, Усть-Катав	0101000020E610000018B5FB5580154D4075560BEC31774B40
11145	6	58	\N	29076	43287	\N	54.925434160426597	Челябинская область, город УстьКатав, ул. Первомайская, д. 6	Россия, Челябинская область, Усть-Катав	0101000020E61000007FA4880CAB124D40A14D0E9F74764B40
11135	6	58	\N	29076	42905	\N	54.928897999999997	Челябинская область, город УстьКатав, МКР3, д.8а		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11133	6	58	\N	29076	42998	\N	54.928897999999997	Челябинская область, город УстьКатав, МКР2, д. 39		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11132	6	58	\N	29076	42998	\N	54.928897999999997	Челябинская область, город УстьКатав, МКР2, д. 18		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11131	6	58	\N	29076	42998	\N	54.928897999999997	Челябинская область, город УстьКатав, МКР2, д. 40		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11130	6	58	\N	29076	42771	\N	54.928897999999997	Челябинская область, город УстьКатав, МКР1, д. 11		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11144	6	58	\N	29076	43280	\N	54.9269974069244	Челябинская область, город УстьКатав, ул. Ломоносова, д. 96а	Россия, Челябинская область, Усть-Катав	0101000020E61000007A6CCB80B3124D40BC3E73D6A7764B40
11141	6	58	\N	29076	43341	\N	54.930778604644701	Челябинская область, город УстьКатав, ул. Ленина, д. 40	Россия, Челябинская область, Усть-Катав	0101000020E6100000BA2EFCE07C144D40DC662AC423774B40
11138	6	58	\N	29076	43706	\N	54.928999261954701	Челябинская область, город УстьКатав, ул. Крупской, д.158а	Россия, Челябинская область, Усть-Катав	0101000020E6100000CF31207BBD154D4023827170E9764B40
11143	6	58	\N	29076	43271	\N	54.927961275541001	Челябинская область, город УстьКатав, ул. Комсомольская, д. 40	Россия, Челябинская область, Усть-Катав	0101000020E6100000D177B7B244134D40537B116DC7764B40
11140	6	58	\N	29076	43271	\N	54.930086647437697	Челябинская область, город УстьКатав, ул. Комсомольская, д. 38	Россия, Челябинская область, Усть-Катав	0101000020E6100000BDFE243E77144D40A6B73F170D774B40
11148	6	58	\N	29076	44290	\N	54.928897999999997	Челябинская область, город УстьКатав, поселок ж/д станция Минка, ул. Железнодорожный переулок, д.16		0101000020E6100000473EAF78EA134D40EFA83121E6764B40
11137	6	58	\N	29076	43741	\N	54.931272852472198	Челябинская область, город УстьКатав, ул. 40 лет Октября, д. 37	Россия, Челябинская область, Усть-Катав	0101000020E610000019E42EC214154D40EB5223F433774B40
11684	6	58	\N	55093	43120	\N	55.092314000000002	Челябинская область, г. Копейск, ул. 4 Пятилетка, 63		0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
10333	6	58	\N	55144	\N	\N	54.0863554467292	Троицкий городской округ, Здание ПУ №135	Россия, Челябинская область, Троицк	0101000020E6100000446CB07092C84E404C6C3EAE0D0B4B40
10314	6	58	\N	55144	\N	\N	54.089584890948103	"""Троицкий городской округ, здание санатория """"Степные зори"""""""	Россия, Челябинская область, Троицк	0101000020E6100000A19DD32CD0CA4E40289B7285770B4B40
10321	6	58	\N	55144	43338	\N	54.087206590627503	Троицкий городской округ, Челябинская, 2	Россия, Челябинская область, Троицк	0101000020E6100000A5129ED0EBC74E40BB7D5699290B4B40
10315	6	58	\N	55144	43321	\N	54.097052013604298	Троицкий городской округ, Циолковского, 12	Россия, Челябинская область, Троицк	0101000020E61000009CFD8172DBCA4E4075012F336C0C4B40
10334	6	58	\N	55144	43489	\N	54.100787925805001	Троицкий городской округ, Троицкая, 62	Россия, Челябинская область, Троицк	0101000020E61000002A1DACFF73CA4E4025EA059FE60C4B40
10328	6	58	\N	55144	43375	\N	54.096288571744502	Троицкий городской округ, Субботина, 56	Россия, Челябинская область, Троицк	0101000020E610000077DA1A118CC94E4076FBAC32530C4B40
10339	6	58	\N	55144	43340	\N	54.083542092267301	Троицкий городской округ, Строителей, 24	Россия, Челябинская область, Троицк	0101000020E6100000ECDADE6E49C64E40D5EB1681B10A4B40
10309	6	58	\N	55144	43370	\N	54.099069923085999	Троицкий городской округ, Советская, 33	Россия, Челябинская область, Троицк	0101000020E6100000AF5A99F04BCB4E40E2016553AE0C4B40
10308	6	58	\N	55144	43370	\N	54.098306518538301	Троицкий городской округ, Советская, 31	Россия, Челябинская область, Троицк	0101000020E610000099F4F75278CA4E40E3FBE252950C4B40
10331	6	58	\N	55144	43356	\N	54.096850217231697	Троицкий городской округ, Серафимовича, 7	Россия, Челябинская область, Троицк	0101000020E6100000645C717154CA4E400E4FAF94650C4B40
10327	6	58	\N	55144	43326	\N	54.096814999999999	Троицкий городской округ, Путевая, 49	Россия, Челябинская область, Троицк	0101000020E6100000FBAD9D2809C94E409161156F640C4B40
10340	6	58	\N	55144	43600	\N	54.098464560597101	"""Троицкий городской округ, Новая, здание МБДОУ """"Детский сад №10 """"Сказка"""""""	Россия, Челябинская область, Троицк	0101000020E6100000645C717154CA4E407B6649809A0C4B40
10319	6	58	\N	55144	43365	\N	54.096850217231697	Адрес УИК в день голосования: Троицкий городской округ, ул.Малышева, 31, Адрес УИК: ул.Ловчикова, 72	Россия, Челябинская область, Троицк	0101000020E61000002A91442FA3CA4E400E4FAF94650C4B40
10318	6	58	\N	55144	43365	\N	54.098464560597101	Троицкий городской округ, Малышева, 37	Россия, Челябинская область, Троицк	0101000020E610000053758F6CAECA4E407B6649809A0C4B40
10313	6	58	\N	55144	43346	\N	54.098868136575902	Троицкий городской округ, Ленина, 135	Россия, Челябинская область, Троицк	0101000020E6100000A19DD32CD0CA4E407B4FE5B4A70C4B40
10338	6	58	\N	55144	43335	\N	54.093261466627197	Троицкий городской округ, Культуры, 6	Россия, Челябинская область, Троицк	0101000020E6100000FFCD8B135FC94E40027FF8F9EF0B4B40
10335	6	58	\N	55144	43335	\N	54.103348294055301	Троицкий городской округ, Культуры, здание Дома культуры энергетиков	Россия, Челябинская область, Троицк	0101000020E6100000785E2A36E6C94E40B20DDC813A0D4B40
10336	6	58	\N	55144	43393	\N	54.102039460108898	Троицкий городской округ, Крупской, 5	Россия, Челябинская область, Троицк	0101000020E61000006D718DCF64C74E4051F52B9D0F0D4B40
10323	6	58	\N	55144	43309	\N	54.100604079185601	Троицкий городской округ, Крахмалева, 77	Россия, Челябинская область, Троицк	0101000020E61000006FBBD05CA7C94E4063EC8497E00C4B40
10322	6	58	\N	55144	43309	\N	54.095034005496302	Троицкий городской округ, Крахмалева, 14	Россия, Челябинская область, Троицк	0101000020E6100000EFC517EDF1CA4E400801F9122A0C4B40
10310	6	58	\N	55144	43371	\N	54.084380678027003	Троицкий городской округ, Красноармейская, 28	Россия, Челябинская область, Троицк	0101000020E61000009F724C16F7C74E40AFB321FFCC0A4B40
10311	6	58	\N	55144	43301	\N	54.0878270000062	Троицкий городской округ, Климова, 2	Россия, Челябинская область, Троицк	0101000020E61000005C92037635C94E40575A46EA3D0B4B40
10326	6	58	\N	55144	43381	\N	54.084380678027003	Троицкий городской округ, г.Троицк, ул. Кирова д. 30	Россия, Челябинская область, Троицк	0101000020E61000000798F90E7EC84E40AFB321FFCC0A4B40
10324	6	58	\N	55144	43319	\N	54.088546000000001	Троицкий городской округ, Качинского, 2	Россия, Челябинская область, Троицк	0101000020E6100000249A40118BCA4E408718AF79550B4B40
10329	6	58	\N	55144	43331	\N	54.100526146099902	Троицкий городской округ, Инженерная, 149	Россия, Челябинская область, Троицк	0101000020E6100000132BA391CFC94E40E8323509DE0C4B40
10312	6	58	\N	55144	43376	\N	54.097859189231997	Адрес УИК в день голосования: Троицкий городской округ, ул.Иванова, 19, Адрес УИК: ул.Малышева, 34	Россия, Челябинская область, Троицк	0101000020E61000004ED53DB2B9CA4E40444FCAA4860C4B40
10320	6	58	\N	55144	43324	\N	54.082059248044303	Троицкий городской округ, Жиркомбинат, 16	Россия, Челябинская область, Троицк	0101000020E61000000726378AACC74E40D6ABC8E8800A4B40
10330	6	58	\N	55144	43359	\N	54.0940249644567	Троицкий городской округ, Дерибаса, 30	Россия, Челябинская область, Троицк	0101000020E61000009D499BAA7BCC4E40D200DE02090C4B40
10332	6	58	\N	55144	43358	\N	54.087206590627503	Троицкий городской округ, Гастелло, 60	Россия, Челябинская область, Троицк	0101000020E610000054742497FFC64E40BB7D5699290B4B40
10341	6	58	\N	55144	43290	\N	54.099428652395297	Троицкий городской округ, Гагарина, 1	Россия, Челябинская область, Троицк	0101000020E6100000FD82DDB06DCB4E4012A3E716BA0C4B40
10317	6	58	\N	55144	43290	\N	54.086399206755203	Троицкий городской округ, Гагарина, 25	Россия, Челябинская область, Троицк	0101000020E61000007E198C1189CC4E401CB4571F0F0B4B40
10316	6	58	\N	55144	43290	\N	54.089628647552601	Троицкий городской округ, Гагарина, 13	Россия, Челябинская область, Троицк	0101000020E610000037FA980F08C64E40F8E28BF6780B4B40
10307	6	58	\N	55144	43290	\N	54.100280621435402	Троицкий городской округ, Гагарина, 20	Россия, Челябинская область, Троицк	0101000020E610000019AA622AFDCA4E4081B4FF01D60C4B40
10325	6	58	\N	55144	43327	\N	54.0841350573507	Троицкий городской округ, Автодромная, 2	Россия, Челябинская область, Троицк	0101000020E61000002EE57CB1F7C84E4078B988EFC40A4B40
10306	6	58	\N	55144	43352	\N	54.086759141065798	"""Троицкий городской округ, 5 микрорайон, здание профилактория ОАО """"ТДЗ"""""""	Россия, Челябинская область, Троицк	0101000020E610000058C9C7EE02C94E401CD13DEB1A0B4B40
10305	6	58	\N	55144	43352	\N	54.093665093464701	"""Троицкий городской округ, 5 микрорайон, здание МБОУ """"Лицей №16"""""""	Россия, Челябинская область, Троицк	0101000020E610000087C1FC1532C94E40D2E3F736FD0B4B40
10304	6	58	\N	55144	43373	\N	54.083731337367603	Троицкий городской округ, 2й микрорайон, 13	Россия, Челябинская область, Троицк	0101000020E6100000BC783F6EBFC84E40A85489B2B70A4B40
10337	6	58	\N	55144	43332	\N	54.097657396804401	"""Троицкий городской округ, 10 квартал, здание МОУ """"СОШ №6"""""""	Россия, Челябинская область, Троицк	0101000020E6100000F2EF332E1CCA4E40DC9C4A06800C4B40
10778	6	58	\N	55116	42890	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, Мира, 23		0101000020E610000015FDA19927394D40F168E388B5684B40
11115	6	58	\N	55123	42996	\N	56.083475810116902	Челябинская область, город Снежинск, Свердлова, 8		0101000020E610000083A44FABE85D4E401D007157AF0A4C40
11120	6	58	\N	55123	43440	\N	56.072003843919802	Челябинская область, Снежинский городской округ, Дзержинского, 25		0101000020E61000001AFB928D075F4E403197546D37094C40
11719	6	58	\N	25916	44194	\N	55.017276000000003	Челябинская область, г. Копейск, село Синеглазово, ул. Шоссейная, 9		0101000020E6100000C64E78094EB94E40BB80971936824B40
10722	6	58	\N	48194	43215	\N	55.053648726421102	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Симская, 22	Россия, Челябинская область, Сим	0101000020E6100000293C6876DDD94C40473B6EF8DD864B40
10719	6	58	\N	48194	43276	\N	54.996425722959003	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Нагорная, 79	Россия, Челябинская область, Сим	0101000020E6100000F19D98F562D84C402A711DE38A7F4B40
10713	6	58	\N	48194	43722	\N	55.015615939689603	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Лесная, 7	Россия, Челябинская область, Сим	0101000020E610000014200A664CD94C40ADA580B4FF814B40
10721	6	58	\N	48194	43474	\N	54.993084356276803	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Курчатова, 8	Россия, Челябинская область, Сим	0101000020E61000005706D50627D64C40271763601D7F4B40
10718	6	58	\N	48194	43475	\N	55.013731223062997	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Кирова, 11	Россия, Челябинская область, Сим	0101000020E6100000E2AB1DC539DA4C407FF8F9EFC1814B40
10717	6	58	\N	48194	43475	\N	54.998092880329402	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Кирова, 9		0101000020E61000009F77634161D84C40EAAEEC82C17F4B40
10715	6	58	\N	48194	43475	\N	54.989358396628802	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Кирова, 3	Россия, Челябинская область, Сим	0101000020E6100000D4EE5701BED94C409B046F48A37E4B40
10724	6	58	\N	48194	43361	\N	54.993109030348201	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Заводская, 1	Россия, Челябинская область, Сим	0101000020E61000003BC8EBC1A4D84C407F2E1A321E7F4B40
11034	6	58	\N	55105	42763	\N	55.044297824291199	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, пл. Ленина, 2	Россия, Челябинская область, Сатка	0101000020E61000006150A6D1E47C4D409CA38E8EAB854B40
11053	6	58	\N	55105	43000	\N	55.042819250447401	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Западный микрорайон, 1	Россия, Челябинская область, Сатка	0101000020E6100000CD237F30F07A4D40DF52CE177B854B40
11041	6	58	\N	55105	43354	\N	55.050130532875897	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Солнечная, 34	Россия, Челябинская область, Сатка	0101000020E61000004583143C857E4D4005C24EB16A864B40
11039	6	58	\N	55105	43354	\N	55.0469766371234	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Солнечная, 4	Россия, Челябинская область, Сатка	0101000020E6100000D76A0F7BA17C4D400455A35703864B40
11045	6	58	\N	55105	43384	\N	55.037397343976998	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Пролетарская, 24	Россия, Челябинская область, Сатка	0101000020E610000026DF6C73637C4D40F8FBC56CC9844B40
11044	6	58	\N	55105	43384	\N	55.036608641631702	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Пролетарская, 14	Россия, Челябинская область, Сатка	0101000020E61000005E807D74EA7C4D40A0DE8C9AAF844B40
11052	6	58	\N	55105	43342	\N	55.046466300097002	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Матросова, 8	Россия, Челябинская область, Сатка	0101000020E6100000AFD2DD75367C4D401F300F99F2854B40
11047	6	58	\N	55105	43388	\N	55.050130532875897	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Ленина, 2а	Россия, Челябинская область, Сатка	0101000020E61000005B0A48FB1F7E4D4005C24EB16A864B40
11046	6	58	\N	55105	43388	\N	55.052692889476603	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Ленина, 4	Россия, Челябинская область, Сатка	0101000020E6100000CD76853E587E4D4033DDEBA4BE864B40
11049	6	58	\N	55105	43745	\N	55.048749999999998	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Куйбышева, 2		0101000020E610000073D6A71C937F4D400AD7A3703D864B40
11050	6	58	\N	55105	43480	\N	55.050524752303303	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Кирова, 7	Россия, Челябинская область, Сатка	0101000020E6100000F75AD07B637E4D40B1506B9A77864B40
11035	6	58	\N	55105	43728	\N	55.047631345108996	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Карла Маркса, 45		0101000020E61000009FB0C403CA7C4D404DA3C9C518864B40
11042	6	58	\N	55105	43725	\N	55.049342082326802	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, 50 лет ВЛКСМ, 26	Россия, Челябинская область, Сатка	0101000020E61000001B9FC9FE797E4D40DD28B2D650864B40
11043	6	58	\N	55105	43394	\N	55.046860555755799	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, 50 лет ВЛКСМ, 24а	Россия, Челябинская область, Сатка	0101000020E61000007383A10E2B7E4D409B3A8F8AFF854B40
11054	6	58	\N	55105	43453	\N	55.047451931934702	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, 40 лет Победы, 15		0101000020E6100000B2BD16F4DE804D409D103AE812864B40
11051	6	58	\N	55105	43645	\N	55.045283509730801	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, 4 квартал, 90	Россия, Челябинская область, Сатка	0101000020E61000007407B133857C4D401B84B9DDCB854B40
11048	6	58	\N	55105	42767	\N	55.039023993312	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, 100летия Комбината Магнезит, 1	Россия, Челябинская область, Сатка	0101000020E61000003CA41820D17C4D402AE109BDFE844B40
11721	6	58	\N	55097	43040	\N	54.908196462623401	раб. пос. Роза, Проходчиков, 4	Россия, Челябинская область, городской округ Коркино, поселок Роза	0101000020E6100000E754320054B94E40D32D3BC43F744B40
10283	6	58	\N	13165	42865	\N	54.362766999999998	Челябинская область, город Пласт, Учебный городок, 1		0101000020E61000008B36C7B94D6A4E40B58828266F2E4B40
10284	6	58	\N	13165	43827	\N	54.362766999999998	Челябинская область, город Пласт, Строителей, 8		0101000020E61000008B36C7B94D6A4E40B58828266F2E4B40
10282	6	58	\N	13165	43200	\N	54.360160484279	Челябинская область, город Пласт, Приисковый, 40	Россия, Челябинская область, Пласт	0101000020E610000055BFD2F9F0684E40E7A90EB9192E4B40
10281	6	58	\N	13165	42621	\N	54.362766999999998	Челябинская область, город Пласт, Октябрьская, 26		0101000020E61000008B36C7B94D6A4E40B58828266F2E4B40
10280	6	58	\N	13165	42621	\N	54.358845119686201	Челябинская область, город Пласт, Октябрьская, 43	Россия, Челябинская область, Пласт	0101000020E61000008D9AAF928F694E40A4AA09A2EE2D4B40
10279	6	58	\N	13165	42621	\N	54.358243572275001	Челябинская область, город Пласт, Октябрьская, 54	Россия, Челябинская область, Пласт	0101000020E6100000C765DCD440694E407EFE7BF0DA2D4B40
10278	6	58	\N	13165	42625	\N	54.363356443234899	Челябинская область, город Пласт, МаминаСибиряка, 2а		0101000020E61000004F594DD713694E4017670C73822E4B40
10226	6	58	\N	13165	43594	\N	54.362165513918697	Челябинская область, город Пласт, Красноармейская, 16	Россия, Челябинская область, Пласт	0101000020E610000018247D5A45694E4090DC9A745B2E4B40
10277	6	58	\N	13165	42870	\N	54.346423877540502	Челябинская область, город Пласт, 9 Января, 2а	Россия, Челябинская область, городской округ Пласт	0101000020E61000008F52094FE8674E405646239F572C4B40
10141	6	58	\N	13165	43059	\N	54.362766999999998	Челябинская область, город Пласт, Володарского, 2		0101000020E61000008B36C7B94D6A4E40B58828266F2E4B40
11752	6	58	\N	55153	43443	\N	55.075469871173702	раб. пос. Первомайский, Нечепуренко, 3		0101000020E61000001BBD1AA034944C4021EA3E00A9894B40
11096	6	58	\N	55134	43255	\N	54.857284	Челябинская область, Озерский городской округ, Цветочная, 12		0101000020E6100000A10F96B1A13F434029B16B7BBB6D4B40
11106	6	58	\N	55108	42774	\N	55.765969912090597	Челябинская область, Озерский городской округ, Южная, 15	Россия, Челябинская область, Озерск	0101000020E61000009013268C66594E40CBDB114E0BE24B40
11086	6	58	\N	55108	43417	\N	55.764026547574602	Челябинская область, Озерский городской округ, Уральская, 15	Россия, Челябинская область, Озерск	0101000020E61000002312859675594E40682101A3CBE14B40
11960	6	58	\N	55108	43152	\N	55.769152785958397	Челябинская область, Озерский городской округ, Театральная, 1	Россия, Челябинская область, Озерск	0101000020E610000027BC04A73E5A4E40664F029B73E24B40
11091	6	58	\N	55108	42909	\N	55.761120014417003	Челябинская область, Озерский городской округ, Студенческая, 7	Россия, Челябинская область, Озерск	0101000020E610000097546D37C1594E406F2A52616CE14B40
11085	6	58	\N	55108	43357	\N	55.765816994510402	Челябинская область, Озерский городской округ, Советская, 43	Россия, Челябинская область, Озерск	0101000020E610000021E868554B5A4E4044DC9C4A06E24B40
11104	6	58	\N	55108	43266	\N	55.759841301539801	Челябинская область, Озерский городской округ, Семенова, 5	Россия, Челябинская область, Озерск	0101000020E61000009966BAD749594E4079944A7842E14B40
11092	6	58	\N	55108	43378	\N	55.765381487990403	Челябинская область, Озерский городской округ, Победы, 15а	Россия, Челябинская область, Озерск	0101000020E610000011C30E63D2594E4069FD2D01F8E14B40
11103	6	58	\N	55108	43264	\N	55.761513790520098	Челябинская область, Озерский городской округ, Матросова, 44	Россия, Челябинская область, Озерск	0101000020E61000008EB1135E825B4E401BB96E4A79E14B40
11102	6	58	\N	55108	43264	\N	55.764074939117997	Челябинская область, Озерский городской округ, Матросова, 49	Россия, Челябинская область, Озерск	0101000020E610000033DDEBA4BE5A4E407958A835CDE14B40
11089	6	58	\N	55108	43467	\N	55.766494439386697	Челябинская область, Озерский городской округ, Лермонтова, 19	Россия, Челябинская область, Озерск	0101000020E610000049641F64595A4E40454AB3791CE24B40
11097	6	58	\N	55108	43161	\N	55.7640157939312	Челябинская область, Озерский городской округ, Красная, 1а	Россия, Челябинская область, Озерск	0101000020E6100000AB05F69848594E4074CFBA46CBE14B40
11093	6	58	\N	55108	43258	\N	55.758687323435801	Челябинская область, Озерский городской округ, Космонавтов, 27	Россия, Челябинская область, Озерск	0101000020E610000010E6762FF7594E403F73D6A71CE14B40
11095	6	58	\N	55108	43318	\N	55.765962162264799	Челябинская область, Озерский городской округ, Карла Маркса, 14	Россия, Челябинская область, Озерск	0101000020E6100000FB3BDBA3375A4E4048FDF50A0BE24B40
11100	6	58	\N	55108	43426	\N	55.759931194691902	Челябинская область, Озерский городской округ, Калинина, 8	Россия, Челябинская область, Озерск	0101000020E610000019E76F4221584E40B91B446B45E14B40
11101	6	58	\N	55108	43316	\N	55.7671718724417	Челябинская область, Озерский городской округ, Иртяшская, 1	Россия, Челябинская область, Озерск	0101000020E61000003337DF88EE594E4016342DB132E24B40
11105	6	58	\N	55108	42770	\N	55.767422977087499	Челябинская область, Озерский городской округ, Ермолаева, 26	Россия, Челябинская область, Озерск	0101000020E61000005723BBD232584E405F99B7EA3AE24B40
11090	6	58	\N	55108	43312	\N	55.768139613442798	Челябинская область, Озерский городской округ, Герцена, 12	Россия, Челябинская область, Озерск	0101000020E6100000EA08E066F1584E40EE5F596952E24B40
11094	6	58	\N	55108	43245	\N	55.762236018068201	Челябинская область, Озерский городской округ, Гайдара, 8	Россия, Челябинская область, Озерск	0101000020E6100000757286E28E594E40BCEA01F390E14B40
11084	6	58	\N	55108	43466	\N	55.770141929062099	Челябинская область, Озерский городской округ, Блюхера, 22	Россия, Челябинская область, Озерск	0101000020E61000002618CE35CC584E4055A3570394E24B40
11088	6	58	\N	55108	43364	\N	55.761364919803299	Челябинская область, Озерский городской округ, Бажова, 14	Россия, Челябинская область, Озерск	0101000020E61000003B014D840D594E40D6A8876874E14B40
11087	6	58	\N	55108	43364	\N	55.759591282162397	Челябинская область, Озерский городской округ, Бажова, 28		0101000020E6100000EE77280AF4574E4000AB23473AE14B40
11109	6	58	\N	55108	43313	\N	55.762381199212399	Челябинская область, Озерский городской округ, 8 Марта, 6	Россия, Челябинская область, Озерск	0101000020E61000003561FBC918594E40BF0B5BB395E14B40
11601	6	58	\N	20261	44051	\N	53.9528690034387	п. Огнеупорный, Строительная, 10	Россия, Челябинская область, поселок Огнеупорный	0101000020E610000037514B732B8A4E40A52F849CF7F94A40
11018	6	58	\N	7310	43650	\N	56.0171254336244	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, Южная, 1	Россия, Челябинская область, Нязепетровск	0101000020E61000009F5A7D7555CA4D40D578E92631024C40
11017	6	58	\N	7310	43793	\N	56.028469614606699	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, Свободы, 38	Россия, Челябинская область, Нязепетровск	0101000020E61000005B5D4E0988CB4D406475ABE7A4034C40
11013	6	58	\N	7310	42761	\N	56.047019682081803	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, Свердлова, 23	Россия, Челябинская область, Нязепетровск	0101000020E6100000CAF962EFC5CD4D40042159C004064C40
11012	6	58	\N	7310	42761	\N	56.032026000000002	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, Свердлова, 1		0101000020E610000034492C2977CB4D40944F8F6D19044C40
11015	6	58	\N	7310	44284	\N	56.032026000000002	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, Ленина, 97		0101000020E610000034492C2977CB4D40944F8F6D19044C40
11014	6	58	\N	7310	42762	\N	56.0290491640162	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, Колина, 96	Россия, Челябинская область, Нязепетровск	0101000020E61000000FB9196EC0CB4D40A27DACE0B7034C40
11016	6	58	\N	7310	43156	\N	56.032026000000002	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, ул. Клубная, д.19 (клуб, 1 этаж 1 этажного здания)		0101000020E610000034492C2977CB4D40944F8F6D19044C40
11011	6	58	\N	7310	42760	\N	56.025970336774002	Челябинская область, Нязепетровский муниципальный район,г.Нязепетровск, Бархатовой, 15	Россия, Челябинская область, Нязепетровск	0101000020E6100000AA2B9FE579CC4D40AC5626FC52034C40
11880	6	58	\N	1180	43719	\N	55.3133722337626	Челябинская область, Сосновский муниципальный район, Рощинское сельское поселение, деревня Новое Поле, Садовая, 6		0101000020E6100000DE9387855AAB4E40B6BDDD921CA84B40
10712	6	58	\N	55140	43277	\N	55.067456722981298	Челябинская область, Ашинский  муниципальный район, Миньярское городское поселение, Чертова, 22	Россия, Челябинская область, Миньяр	0101000020E6100000B7B585E7A5C64C407171546EA2884B40
10706	6	58	\N	55140	43479	\N	55.065289388837698	Челябинская область, Ашинский  муниципальный район, Миньярское городское поселение, Центральная, 7	Россия, Челябинская область, Миньяр	0101000020E61000000AD80E46ECC54C40EFE4D3635B884B40
10705	6	58	\N	55140	43325	\N	55.067653747512097	Челябинская область, Ашинский  муниципальный район, Миньярское городское поселение, Советская, 97	Россия, Челябинская область, Миньяр	0101000020E61000006F2D93E178C64C40C7B8E2E2A8884B40
10708	6	58	\N	55140	43737	\N	55.0520858075554	Челябинская область, Ашинский  муниципальный район, Миньярское городское поселение, Куйбышева, 20	Россия, Челябинская область, Миньяр	0101000020E6100000F2B1BB4049C34C402C4A09C1AA864B40
10710	6	58	\N	55140	43723	\N	55.069417785553199	Челябинская область, Ашинский  муниципальный район, Миньярское городское поселение, Кирова, 70	Россия, Челябинская область, Миньяр	0101000020E610000017D68D7747C64C407AE063B0E2884B40
10162	6	58	\N	7529	\N	\N	55.065257000000003	"""Челябинская область, город Миасс, Дом отдыха """"Золотой пляж"""""""		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10172	6	58	\N	7529	42605	\N	55.134306719188899	Челябинская область, город Миасс, пр.Октября, 71	Россия, Челябинская область, Миасс	0101000020E6100000FDDAFAE93F134E40DB4FC6F830914B40
10171	6	58	\N	7529	42605	\N	55.062301318390404	Челябинская область, город Миасс, пр.Октября, 25	Россия, Челябинская область, Миасс	0101000020E6100000651D8EAED20B4E4009C1AA7AF9874B40
10168	6	58	\N	7529	42605	\N	55.062005741527798	Челябинская область, город Миасс, пр.Октября, 4	Россия, Челябинская область, Миасс	0101000020E6100000F148BC3C9D0B4E40F01307D0EF874B40
10154	6	58	\N	7529	42603	\N	55.065257000000003	Челябинская область, город Миасс, пр.Макеева, 23		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10188	6	58	\N	7529	42613	\N	55.060921267405597	Челябинская область, город Миасс, пр.Автозаводцев, 37А	Россия, Челябинская область, Миасс	0101000020E61000005DDDB1D8260F4E40DF516342CC874B40
10185	6	58	\N	7529	42613	\N	55.063138774262399	Челябинская область, город Миасс, пр.Автозаводцев, 5А	Россия, Челябинская область, Миасс	0101000020E6100000B1DD3D40F70B4E40130D52F014884B40
10189	6	58	\N	7529	42607	\N	55.051916519417702	Челябинская область, город Миасс, пр.Автозаводцев, 43		0101000020E61000002BA4FCA4DA0D4E40A08D5C37A5864B40
10166	6	58	\N	7529	42604	\N	55.065257000000003	Челябинская область, город Миасс, пр.Макеева, 14		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10173	6	58	\N	7529	43216	\N	55.065257000000003	Челябинская область, город Миасс, г.Миасс, пр. Макеева д.39,  ДДТ «Остров» (1й этаж, холл)		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10184	6	58	\N	7529	42853	\N	55.065257000000003	Челябинская область, город Миасс, пл.Предзаводская, 1		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10160	6	58	\N	7529	43487	\N	55.059098445371397	Челябинская область, город Миасс, п.Новотагилка, ул.Школьная, 47В	Россия, Челябинская область, Миасс	0101000020E6100000D8D5E429AB0D4E4027A1F48590874B40
10164	6	58	\N	7529	43190	\N	55.062399843524098	Челябинская область, город Миасс, ул.Циолковского, 14	Россия, Челябинская область, Миасс	0101000020E61000003CA1D79FC40B4E409CA223B9FC874B40
10197	6	58	\N	7529	42857	\N	55.063335146650097	Челябинская область, город Миасс, ул.Ст.Разина, 4	Россия, Челябинская область, Миасс	0101000020E61000008D9944BDE00B4E4099D87C5C1B884B40
10220	6	58	\N	7529	42866	\N	54.923476000000001	Челябинская область, город Миасс, с.Смородинка, ул.Советская, 33	Россия, Челябинская область, городской округ Миасс, поселок Смородинка	0101000020E61000008EB1135E82014E400952297634764B40
10191	6	58	\N	7529	43198	\N	55.049145352244501	Челябинская область, город Миасс, ул.Романенко, 89	Россия, Челябинская область, Миасс	0101000020E6100000AE635C71710E4E4087E123624A864B40
10179	6	58	\N	7529	43198	\N	55.061513108551502	Челябинская область, город Миасс, ул.Романенко, 3	Россия, Челябинская область, Миасс	0101000020E6100000A0504F1F810B4E40B1A371A8DF874B40
10208	6	58	\N	7529	43203	\N	55.065257000000003	Челябинская область, город Миасс, ул.Ровная, 15		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10215	6	58	\N	7529	42617	\N	55.062891792036197	Челябинская область, город Миасс, ул.Пушкина, 53	Россия, Челябинская область, Миасс	0101000020E6100000A81ABD1AA00A4E400B9755D80C884B40
10214	6	58	\N	7529	42617	\N	55.065257000000003	Челябинская область, город Миасс, ул.Пушкина, 8		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10210	6	58	\N	7529	42616	\N	55.065257000000003	Челябинская область, город Миасс, ул.Пролетарская, 12		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10211	6	58	\N	7529	42861	\N	55.0621042673923	Челябинская область, город Миасс, ул.Первомайская, 10	Россия, Челябинская область, Миасс	0101000020E610000063B5F97FD50B4E40B3791C06F3874B40
10209	6	58	\N	7529	42861	\N	55.065257000000003	Челябинская область, город Миасс, ул.Первомайская, 5		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10201	6	58	\N	7529	42864	\N	55.065257000000003	Челябинская область, город Миасс, ул.Осипенко, 1		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10183	6	58	\N	7529	42970	\N	55.061044428049598	Челябинская область, город Миасс, ул.Орловская, д.7, школа № 4, (1й этаж, холл)	Россия, Челябинская область, Миасс	0101000020E61000003927F6D03E0E4E40FBCE2F4AD0874B40
10181	6	58	\N	7529	42970	\N	55.065257000000003	Челябинская область, город Миасс, ул.Орловская, д.7, школа № 4, (2й этаж, холл)		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10180	6	58	\N	7529	42970	\N	55.061192220320002	Челябинская область, город Миасс, ул.Орловская, 48	Россия, Челябинская область, Миасс	0101000020E61000006D904946CE0E4E406F63B323D5874B40
10223	6	58	\N	7529	43485	\N	55.065257000000003	"""Челябинская область, город Миасс, клуб """"Урал"""", ул.Озерная"""		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10175	6	58	\N	7529	42609	\N	55.065257000000003	Челябинская область, город Миасс, ул.Нахимова, 8		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10161	6	58	\N	7529	43483	\N	55.065257000000003	Челябинская область, город Миасс, ул.Нагорная, 1А	Россия, Челябинская область, Миасс	0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10159	6	58	\N	7529	43192	\N	55.330955110063897	Челябинская область, город Миасс, с.Новоандреевка, ул.Макурина, 154	Россия, Челябинская область, городской округ Миасс, поселок Новоандреевка	0101000020E610000010069E7B0F1D4E404EB9C2BB5CAA4B40
10167	6	58	\N	7529	42976	\N	55.065257000000003	Челябинская область, город Миасс, пр.Макеева, 8Б		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10165	6	58	\N	7529	42976	\N	55.065257000000003	Челябинская область, город Миасс, пр.Макеева, 39		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10194	6	58	\N	7529	42614	\N	55.065257000000003	Челябинская область, город Миасс, ул.Лихачева, 33А		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10190	6	58	\N	7529	42614	\N	55.0625968930607	Челябинская область, город Миасс, ул.Лихачева, 15	Россия, Челябинская область, Миасс	0101000020E610000060E5D022DB0B4E40F2E9B12D03884B40
10221	6	58	\N	7529	42974	\N	55.065453328389701	Челябинская область, город Миасс, с.Черновское, ул. Ленина, д.1,  школа № 32  (1й этаж, холл)	Россия, Челябинская область, Миасс	0101000020E610000027C0B0FCF90C4E4069368FC360884B40
11242	6	58	\N	2116	43171	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Рубинштейна, 2а		0101000020E61000001CB1169F02864D402FDD240681B34A40
10217	6	58	1318	\N	42974	\N	55.072242000000003	Челябинская область, город Миасс, с.Сыростан, ДК, ул.Ленина, 17	Россия, Челябинская область, городской округ Миасс	0101000020E610000066DB696B44F64D40E6B2D1393F894B40
10213	6	58	\N	7529	42974	\N	55.062301318390404	Челябинская область, город Миасс, ул.Ленина, 121	Россия, Челябинская область, Миасс	0101000020E610000063B5F97FD50B4E4009C1AA7AF9874B40
10163	6	58	\N	7529	42849	\N	55.065257000000003	Челябинская область, город Миасс, п.Тургояк, ул.Курортная, 2		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10203	6	58	\N	7529	42860	\N	55.065257000000003	Челябинская область, город Миасс, ул.Кирова, 85	Россия, Челябинская область, Миасс	0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10202	6	58	\N	7529	42860	\N	55.061611635633902	Челябинская область, город Миасс, ул.Кирова, 53	Россия, Челябинская область, Миасс	0101000020E61000008AC91B60E60B4E404485EAE6E2874B40
10178	6	58	\N	7529	42852	\N	55.061118997785798	Челябинская область, город Миасс, ул.Керченская, 1	Россия, Челябинская область, Миасс	0101000020E61000008CF337A1100B4E40051555BFD2874B40
10176	6	58	\N	7529	42852	\N	55.059935968551002	Челябинская область, город Миасс, ул.Керченская, 15	Россия, Челябинская область, Миасс	0101000020E610000072FC5069C40E4E4031ED9BFBAB874B40
10186	6	58	\N	7529	42606	\N	55.065257000000003	Челябинская область, город Миасс, ул.Калинина, 37		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10204	6	58	\N	7529	42991	\N	55.065257000000003	Челябинская область, город Миасс, ул.Зеленая, 16		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10177	6	58	\N	7529	42851	\N	55.050352666763203	Челябинская область, город Миасс, ул.Донская, 15	Россия, Челябинская область, Миасс	0101000020E61000001D3EE944820F4E40B42094F771864B40
10200	6	58	\N	7529	42650	\N	55.065257000000003	Челябинская область, город Миасс, ул.Готвальда, 48		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10199	6	58	\N	7529	42650	\N	55.065257000000003	Челябинская область, город Миасс, ул.Готвальда, 38		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10198	6	58	\N	7529	42650	\N	55.051264288194098	Челябинская область, город Миасс, ул.Готвальда, 7	Россия, Челябинская область, Миасс	0101000020E6100000AB05F698480F4E4028BB99D18F864B40
10205	6	58	\N	7529	42862	\N	55.065257000000003	Челябинская область, город Миасс, ул.Герцена, 1		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10170	6	58	\N	7529	43195	\N	55.053062831504	Челябинская область, город Миасс, ул.Вернадского, 1А	Россия, Челябинская область, Миасс	0101000020E6100000C0B2D2A4140E4E4057D0B4C4CA864B40
10212	6	58	\N	7529	43070	\N	55.065257000000003	Челябинская область, город Миасс, ул.Березовская, 147	Россия, Челябинская область, Миасс	0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10193	6	58	\N	7529	42611	\N	55.065257000000003	Челябинская область, город Миасс, ул.Ак.Павлова, 17		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10187	6	58	\N	7529	42854	\N	55.065257000000003	Челябинская область, город Миасс, пр.Автозаводцев, 21		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10196	6	58	\N	7529	42629	\N	55.063335820145198	Челябинская область, город Миасс, ул.8 Марта, 131	Россия, Челябинская область, Миасс	0101000020E6100000B345D26EF40B4E406954E0641B884B40
10195	6	58	\N	7529	42629	\N	55.061907215419701	Челябинская область, город Миасс, ул.8 Марта, 134	Россия, Челябинская область, Миасс	0101000020E6100000766C04E2750B4E405D328E91EC874B40
10192	6	58	\N	7529	42859	\N	55.060010540361198	Челябинская область, город Миасс, ул.8 Июля, 45	Россия, Челябинская область, Миасс	0101000020E6100000228D0A9C6C0D4E403C33C170AE874B40
10207	6	58	\N	7529	42618	\N	55.060724209583398	"""Челябинская область, город Миасс, ООО""""Миасстрансплюс"""", ул.60 лет Октября, 11"""	Россия, Челябинская область, Миасс	0101000020E610000097A8DE1AD80E4E40890AD5CDC5874B40
10206	6	58	\N	7529	42615	\N	55.065257000000003	Челябинская область, город Миасс, ул.60 лет Октября, 12		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10218	6	58	\N	7529	43508	\N	55.065257000000003	Челябинская область, город Миасс, п.Хребет, школа №23, 40 лет Октября, 14А		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10169	6	58	\N	7529	42850	\N	55.065257000000003	Челябинская область, город Миасс, пр.Октября, 14		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
10216	6	58	\N	7529	42619	\N	55.065257000000003	"""Челябинская область, город Миасс, п.Ленинск, ДК""""Комсомолец"""", ул.Нефтянников, 14"""		0101000020E610000024F0879FFF0C4E40E46A64575A884B40
11889	6	58	\N	52522	\N	\N	55.060631999999998	"""Челябинская область, Сосновский муниципальный район, Саргазинское сельское поселение, поселок Малая Сосновка, контора ОАО """"Челябинское по племенной работе"""", Административный корпус"""		0101000020E6100000535E2BA1BBA44E40A88B14CAC2874B40
11249	6	58	\N	2116	42786	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, проспект Пушкина, 17		0101000020E61000001CB1169F02864D402FDD240681B34A40
11241	6	58	\N	2116	42786	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, проспект Пушкина, 19		0101000020E61000001CB1169F02864D402FDD240681B34A40
11180	6	58	\N	2116	43390	\N	53.419605870178799	Челябинская область, Магнитогорский городской округ, Ленинский район, пр. Ленина, 38	Россия, Челябинская область, Магнитогорск	0101000020E61000009432A9A10D8A4D404A9A3FA6B5B54A40
11257	6	58	\N	2116	42788	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, проспект Ленина, 135		0101000020E61000001CB1169F02864D402FDD240681B34A40
11233	6	58	\N	2116	42788	\N	53.399502386370699	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Ленина, 114	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D40E257ACE122B34A40
11208	6	58	\N	2116	42788	\N	53.378977975366404	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Ленина, 86/1	Россия, Челябинская область, Магнитогорск	0101000020E610000075CDE49B6D844D40A5F3E15982B04A40
11191	6	58	\N	2116	42788	\N	53.395808397528299	Челябинская область, Магнитогорский городской округ, Ленинский район, пр. Ленина, 58/2	Россия, Челябинская область, Магнитогорск	0101000020E6100000E8FA3E1C248A4D4062BF27D6A9B24A40
11193	6	58	\N	2116	42634	\N	53.423152788457102	Челябинская область, Магнитогорский городской округ, Ленинский район, пр. К.Маркса, 47	Россия, Челябинская область, Магнитогорск	0101000020E6100000408864C8B17D4D40261AA4E029B64A40
11234	6	58	\N	2116	42683	\N	53.438610655328802	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Карла Маркса, 141/1	Россия, Челябинская область, Магнитогорск	0101000020E61000007157AF22A3854D403B55BE6724B84A40
11267	6	58	\N	2116	42911	\N	53.398373824198799	Челябинская область, город Магнитогорск,  Орджоникидзевский район, проезд Сиреневый, 34	Россия, Челябинская область, Магнитогорск	0101000020E61000001F813FFCFC854D40D1C952EBFDB24A40
11224	6	58	\N	2116	42672	\N	53.4410705940669	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Карла Маркса, 111	Россия, Челябинская область, Магнитогорск	0101000020E6100000EF5696E82C874D40651BB80375B84A40
11228	6	58	\N	2116	42787	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Правобережный район, пр.Карла Маркса, 158	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11202	6	58	\N	2116	42779	\N	53.442024000000004	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Карла Маркса, 106	Россия, Челябинская область, Магнитогорск	0101000020E6100000616BB6F292874D400806103E94B84A40
11200	6	58	\N	2116	42779	\N	53.396000278864598	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Карла Маркса, 79	Россия, Челябинская область, Магнитогорск	0101000020E6100000A0C6BDF90D874D40A69BC420B0B24A40
11168	6	58	\N	2116	43256	\N	53.398989006526101	Челябинская область, Магнитогорский городской округ, Ленинский район, пр. К. Маркса, 52	Россия, Челябинская область, Магнитогорск	0101000020E61000003F8D7BF31B864D405C3B511212B34A40
11219	6	58	\N	2116	43269	\N	53.392935384096702	Челябинская область, Магнитогорский городской округ, Правобережный район, пер.Советский, 11		0101000020E61000001CB1169F02864D40153AAFB14BB24A40
11220	6	58	\N	2116	43011	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Правобережный район, пер. Советский, 11	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11196	6	58	\N	2116	43246	\N	53.408939691755997	"""Челябинская область, Магнитогорский городской округ, Правобережный район, ул. имени газеты """"Правда"""", 79"""	Россия, Челябинская область, Магнитогорск	0101000020E610000059A65F22DE844D405C035B2558B44A40
11255	6	58	\N	2116	43166	\N	53.397553032820802	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Ярославского, 2	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D409EB64604E3B24A40
11240	6	58	\N	2116	43631	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, Шоссейная, 13		0101000020E61000001CB1169F02864D402FDD240681B34A40
11238	6	58	\N	2116	42780	\N	53.3985790195579	Челябинская область, город Магнитогорск,  Орджоникидзевский район, переулок Школьный, 3	Россия, Челябинская область, Магнитогорск	0101000020E6100000B8019F1F46864D40AAEFFCA204B34A40
11247	6	58	\N	2116	43546	\N	53.404836599727602	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Чкалова 16А	Россия, Челябинская область, Магнитогорск	0101000020E61000002A38BC20227D4D40FA9AE5B2D1B34A40
11254	6	58	\N	2116	42804	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Чкалова, 104		0101000020E61000001CB1169F02864D402FDD240681B34A40
11253	6	58	\N	2116	42804	\N	53.396219212904498	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Чкалова, 60а	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D40E486DF4DB7B24A40
11245	6	58	\N	2116	42804	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Чкалова, 17		0101000020E61000001CB1169F02864D402FDD240681B34A40
11166	6	58	\N	2116	43247	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Ленинский район, Урицкого, 11	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11165	6	58	\N	2116	43344	\N	53.393345826517702	Челябинская область, Магнитогорский городской округ, Ленинский район, Уральская, 162	Россия, Челябинская область, Магнитогорск	0101000020E6100000F9872D3D9A8A4D409701672959B24A40
11284	6	58	\N	2116	42914	\N	53.399604981440497	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Труда, 49	Россия, Челябинская область, Магнитогорск	0101000020E6100000469561DC0D864D40B728B34126B34A40
11283	6	58	\N	2116	42914	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Труда, 47/1		0101000020E61000001CB1169F02864D402FDD240681B34A40
11279	6	58	\N	2116	42914	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Труда, 31/1		0101000020E61000001CB1169F02864D402FDD240681B34A40
11274	6	58	\N	2116	42914	\N	53.3945775307281	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Труда, 36	Россия, Челябинская область, Магнитогорск	0101000020E610000080608E1EBF854D404DDC2A8881B24A40
11001	6	58	\N	3348	42759	\N	55.7027299915597	город Кыштым, ул. Ленина, 28	Россия, Челябинская область, Кыштым	0101000020E6100000C03DCF9F36464E4084F57F0EF3D94B40
11269	6	58	\N	2116	42914	\N	53.397655632613002	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Труда, 19/1	Россия, Челябинская область, Магнитогорск	0101000020E6100000E2E5E95C51864D4072874D64E6B24A40
11268	6	58	\N	2116	42914	\N	53.405797796719902	Челябинская область, Магнитогорский городской округ, Орджоникидзевский район, улица Труда, 19/1	Россия, Челябинская область, Магнитогорск	0101000020E61000009AB0FD648C894D401F645930F1B34A40
11252	6	58	\N	2116	42785	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, переулок Тихвинский, 2	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11287	6	58	\N	2116	42794	\N	53.3935514470556	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Тевосяна, 27/3	Россия, Челябинская область, Магнитогорск	0101000020E6100000AA9ECC3FFA844D40702711E15FB24A40
11285	6	58	\N	2116	42794	\N	53.399399791052303	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Тевосяна, 9/1	Россия, Челябинская область, Магнитогорск	0101000020E61000006DA983BC1E864D40DE02098A1FB34A40
11223	6	58	\N	2116	43283	\N	53.406477884255402	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Суворова, 135	Россия, Челябинская область, Магнитогорск	0101000020E6100000D49D279EB3894D4091459A7807B44A40
11222	6	58	\N	2116	43283	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Суворова, 136/4	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11221	6	58	\N	2116	43283	\N	53.418785490338898	Челябинская область, Магнитогорский городской округ, Правобережный район, ул.Суворова, 136/4	Россия, Челябинская область, Магнитогорск	0101000020E6100000E40F069E7B854D40168733BF9AB54A40
11217	6	58	\N	2116	43283	\N	53.4000566372479	Челябинская область, Магнитогорский городской округ, Правобережный район, ул.Суворова, 134/1	Россия, Челябинская область, Магнитогорск	0101000020E610000019CA8976158E4D4097C4591135B34A40
11216	6	58	\N	2116	43283	\N	53.415093584253	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Суворова, 134/1	Россия, Челябинская область, Магнитогорск	0101000020E6100000889FFF1EBC884D400762D9CC21B54A40
11205	6	58	\N	2116	43283	\N	53.414888468916502	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Суворова, 117	Россия, Челябинская область, Магнитогорск	0101000020E6100000C2340C1F117F4D405DC0CB0C1BB54A40
11204	6	58	\N	2116	43283	\N	53.398658772954903	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Суворова, 117/2	Россия, Челябинская область, Магнитогорск	0101000020E6100000C37DE4D6A4894D40C7A0134207B34A40
11169	6	58	\N	2116	43283	\N	53.391970187414401	Челябинская область, Магнитогорский городской округ, Ленинский район, Суворова, 76а	Россия, Челябинская область, Магнитогорск	0101000020E6100000E31934F44F864D40AE81AD122CB24A40
11167	6	58	\N	2116	43283	\N	53.415503811944099	Челябинская область, Магнитогорский городской округ, Ленинский район, Суворова, 25а	Россия, Челябинская область, Магнитогорск	0101000020E61000009886E12362884D40B8AD2D3C2FB54A40
11185	6	58	\N	2116	41580	\N	53.423566542846103	Челябинская область, Магнитогорский городской округ, Ленинский район, Строителей, 56	Россия, Челябинская область, Магнитогорск	0101000020E61000009F0436E7E07F4D401955867137B64A40
11232	6	58	\N	2116	43363	\N	53.420426234115503	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Сталеваров, 13	Россия, Челябинская область, Магнитогорск	0101000020E6100000F5F6E7A221854D40AD31E884D0B54A40
11230	6	58	\N	2116	43363	\N	53.407093349550699	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Сталеваров, 11	Россия, Челябинская область, Магнитогорск	0101000020E61000004A5E9D6340884D401CB7989F1BB44A40
11229	6	58	\N	2116	43363	\N	53.413862877323702	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Сталеваров, 8	Россия, Челябинская область, Магнитогорск	0101000020E6100000ACE3F8A1D2884D4021037976F9B44A40
11248	6	58	\N	2116	42810	\N	53.396834827316198	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Сосновая, 17а	Россия, Челябинская область, Магнитогорск	0101000020E6100000CC5EB69DB6864D403F74417DCBB24A40
11227	6	58	\N	2116	42781	\N	53.450499033645499	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Советской Армии, 51а	Россия, Челябинская область, Магнитогорск	0101000020E6100000406A1327F78B4D40BBF083F3A9B94A40
11286	6	58	\N	2116	42916	\N	53.399964062227497	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Советская, 211	Россия, Челябинская область, Магнитогорск	0101000020E6100000F4346090F4854D40E6C9350532B34A40
11281	6	58	\N	2116	42916	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Советская, 199/1		0101000020E61000001CB1169F02864D402FDD240681B34A40
11215	6	58	\N	2116	42916	\N	53.4072985026609	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Советская, 145/3	Россия, Челябинская область, Магнитогорск	0101000020E61000005C9198A086894D40C558A65F22B44A40
11213	6	58	\N	2116	42916	\N	53.414251082690498	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Советская, 70	Россия, Челябинская область, Магнитогорск	0101000020E6100000205D6C5A29844D40EBAA402D06B54A40
11246	6	58	\N	2116	43170	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, переулок Ржевского, 4		0101000020E61000001CB1169F02864D402FDD240681B34A40
11250	6	58	\N	2116	43507	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, проспект Пушкина, 38		0101000020E61000001CB1169F02864D402FDD240681B34A40
11278	6	58	\N	2116	42799	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, Проспект Карла Маркса, 198/4	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11277	6	58	\N	2116	42799	\N	53.397758232156598	Челябинская область, город Магнитогорск,  Орджоникидзевский район, Проспект Карла Маркса, 194/3	Россия, Челябинская область, Магнитогорск	0101000020E61000007E9065C1C4854D4077DCF0BBE9B24A40
11207	6	58	\N	2116	42799	\N	53.395538559797203	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Карла Маркса, 97/1	Россия, Челябинская область, Магнитогорск	0101000020E61000005BD07B6308864D4072A59E05A1B24A40
11199	6	58	\N	2116	42799	\N	53.396769799458703	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Карла Маркса, 86	Россия, Челябинская область, Магнитогорск	0101000020E6100000A9F8BF232A864D405704FF5BC9B24A40
11266	6	58	\N	2116	42971	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, Проезд Сереневый 34		0101000020E61000001CB1169F02864D402FDD240681B34A40
11251	6	58	\N	2116	43006	\N	53.398476422002602	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Полевая, 3	Россия, Челябинская область, Магнитогорск	0101000020E6100000680932022A864D40D61EF64201B34A40
11256	6	58	\N	2116	43502	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Покровская, 13	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11244	6	58	\N	2116	42782	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Планерная, 2а	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11164	6	58	\N	2116	43007	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Ленинский район, Писарева, 2	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11152	6	58	\N	2116	42999	\N	53.402374999999999	Челябинская область, город Магнитогорск, Ленинский район, Панькова, 32		0101000020E61000001CB1169F02864D402FDD240681B34A40
11188	6	58	\N	2116	43368	\N	53.416734471161597	Челябинская область, Магнитогорский городской округ, Ленинский район, Набережная, 24/1	Россия, Челябинская область, Магнитогорск	0101000020E6100000853FC39B35804D40CD902A8A57B54A40
11186	6	58	\N	2116	43368	\N	53.385033592334203	Челябинская область, Магнитогорский городской округ, Ленинский район, Набережная, 1	Россия, Челябинская область, Магнитогорск	0101000020E61000008869DFDC5F7F4D408DEC4ACB48B14A40
11175	6	58	\N	2116	42784	\N	53.399501985608197	Челябинская область, Магнитогорский городской округ, Ленинский район, Н.Шишка, 10	Россия, Челябинская область, Магнитогорск	0101000020E61000007D03931B45864D40E257ACE122B34A40
11161	6	58	\N	2116	43281	\N	53.394166699428801	Челябинская область, Магнитогорский городской округ, Ленинский район, Московская, 45	Россия, Челябинская область, Магнитогорск	0101000020E6100000871403249A8C4D40CB14731074B24A40
11160	6	58	\N	2116	43281	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Ленинский район, Московская, 14	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11158	6	58	\N	2116	43281	\N	53.406037917248703	Челябинская область, Магнитогорский городской округ, Ленинский район, Московская, 15	Россия, Челябинская область, Магнитогорск	0101000020E6100000003961C2687C4D4075779D0DF9B34A40
11157	6	58	\N	2116	43281	\N	53.462704702187601	Челябинская область, Магнитогорский городской округ, Ленинский район, Московская, 7		0101000020E6100000DDEBA4BE2C874D400C59DDEA39BB4A40
11176	6	58	\N	2116	43259	\N	53.417555291351803	Челябинская область, Магнитогорский городской округ, Ленинский район, Менделеева, 8	Россия, Челябинская область, Магнитогорск	0101000020E610000012876C205D7E4D4001A4367172B54A40
11243	6	58	\N	2116	42789	\N	53.396834827316198	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Маяковского, 28	Россия, Челябинская область, Магнитогорск	0101000020E6100000E2E5E95C51864D403F74417DCBB24A40
11178	6	58	\N	2116	43372	\N	53.395397978968703	Челябинская область, Магнитогорский городской округ, Ленинский район, Ломоносова, 21	Россия, Челябинская область, Магнитогорск	0101000020E6100000F8E12021CA894D40B073D3669CB24A40
11194	6	58	\N	2116	43260	\N	53.401482106731997	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Лесопарковая, 99	Россия, Челябинская область, Магнитогорск	0101000020E6100000F86BB2463D864D4062F71DC363B34A40
11192	6	58	\N	2116	43379	\N	53.408529400446703	Челябинская область, Магнитогорский городской округ, Ленинский район, Ленинградская, 24	Россия, Челябинская область, Магнитогорск	0101000020E61000009CFC169D2C894D40DA3BA3AD4AB44A40
11187	6	58	\N	2116	43379	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Ленинский район, Ленинградская, 3	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
10999	6	58	\N	3348	42759	\N	55.706898000000002	город Кыштым, ул. Ленина, 13		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
11183	6	58	\N	2116	43379	\N	53.3839046446287	Челябинская область, Магнитогорский городской округ, Ленинский район, Ленинградская, 10А	Россия, Челябинская область, Магнитогорск	0101000020E61000003A419B1C3E7F4D40ACE28DCC23B14A40
11181	6	58	\N	2116	43379	\N	53.406067569088101	Челябинская область, Магнитогорский городской округ, Ленинский район, Ленинградская, 21А	Россия, Челябинская область, Магнитогорск	0101000020E61000001D7233DC808B4D40DFF94509FAB34A40
11236	6	58	\N	2116	43300	\N	53.408119105161099	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Ленина, 124/3	Россия, Челябинская область, Магнитогорск	0101000020E610000059A65F22DE844D4028F04E3E3DB44A40
11226	6	58	\N	2116	43300	\N	53.415504212555199	Челябинская область, Магнитогорский городской округ, Правобережный район, пр. Ленина, 96	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D40B8AD2D3C2FB54A40
11179	6	58	\N	2116	43300	\N	53.477300168686902	Челябинская область, Магнитогорский городской округ, Ленинский район, пр. Ленина, 26	Россия, Челябинская область, Магнитогорск	0101000020E6100000CFA3E2FF8E8A4D40BE30992A18BD4A40
11172	6	58	\N	2116	43300	\N	53.412221879086196	Челябинская область, Магнитогорский городской округ, Ленинский район, пр. Ленина, 12	Россия, Челябинская область, Магнитогорск	0101000020E6100000889FFF1EBC884D408A58C4B0C3B44A40
11177	6	58	\N	2116	43397	\N	53.390883112336702	Челябинская область, Магнитогорский городской округ, Ленинский район, Комсомольская, 6	Россия, Челябинская область, Магнитогорск	0101000020E61000000C3F389F3A8A4D40FCC7427408B24A40
11239	6	58	\N	2116	42653	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, Коммунаров, 51/1		0101000020E61000001CB1169F02864D402FDD240681B34A40
11237	6	58	\N	2116	43005	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, Коммунальная, 7		0101000020E61000001CB1169F02864D402FDD240681B34A40
11282	6	58	\N	2116	43185	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, Просрект Карла Маркса, 198/4		0101000020E61000001CB1169F02864D402FDD240681B34A40
11203	6	58	\N	2116	43351	\N	53.421656750202203	Челябинская область, Магнитогорский городской округ, Правобережный район, К Маркса, 106	Россия, Челябинская область, Магнитогорск	0101000020E610000070EEAF1EF7894D40939048DBF8B54A40
11265	6	58	\N	2116	42809	\N	53.396424418702601	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Калмыкова, 8	Россия, Челябинская область, Магнитогорск	0101000020E61000008F1D54E23A864D40BDAC8905BEB24A40
11263	6	58	\N	2116	42809	\N	53.382326633228502	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Калмыкова, 5	Россия, Челябинская область, Магнитогорск	0101000020E6100000035E66D8287F4D405BB05417F0B04A40
11184	6	58	\N	2116	43429	\N	53.419195682246801	Челябинская область, Магнитогорский городской округ, Ленинский район, Калинина, 6	Россия, Челябинская область, Магнитогорск	0101000020E610000080608E1EBF854D40984EEB36A8B54A40
11182	6	58	\N	2116	43429	\N	53.386367764480099	Челябинская область, Магнитогорский городской округ, Ленинский район, Калинина, 18	Россия, Челябинская область, Магнитогорск	0101000020E61000006B9A779CA28B4D40471CB28174B14A40
11173	6	58	\N	2116	43243	\N	53.3982708253724	Челябинская область, Магнитогорский городской округ, Ленинский район, Казакова, 11	Россия, Челябинская область, Магнитогорск	0101000020E61000006AD95A5F24864D40FDF84B8BFAB24A40
11171	6	58	\N	2116	43243	\N	53.4007331100538	Челябинская область, Магнитогорский городской округ, Ленинский район, Казакова, 14	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D40C8B60C384BB34A40
11212	6	58	\N	2116	43343	\N	53.421656750202203	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Индустриальная, 4	Россия, Челябинская область, Магнитогорск	0101000020E61000000400C79E3D874D40939048DBF8B54A40
11197	6	58	\N	2116	43343	\N	53.404836599727602	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Индустриальная, 26	Россия, Челябинская область, Магнитогорск	0101000020E61000009886E12362884D40FA9AE5B2D1B34A40
11988	6	58	\N	2116	42915	\N	53.402374999999999	Челябинская область, г. Магнитогорск, ул. Жукова, 9, детский клуб.		0101000020E61000001CB1169F02864D402FDD240681B34A40
11280	6	58	\N	2116	42915	\N	53.399194599669997	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Жукова, 4/1	Россия, Челябинская область, Магнитогорск	0101000020E61000001E19ABCDFF854D4005DD5ED218B34A40
11270	6	58	\N	2116	42915	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Жукова, 7/2		0101000020E61000001CB1169F02864D402FDD240681B34A40
11264	6	58	\N	2116	43009	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Жемчужная, 11		0101000020E61000001CB1169F02864D402FDD240681B34A40
11195	6	58	\N	2116	43004	\N	53.397039629345898	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Енисейская, 135	Россия, Челябинская область, Магнитогорск	0101000020E610000041F50F2219864D40179AEB34D2B24A40
11210	6	58	\N	2116	43315	\N	53.413452633728397	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Дружбы, 33	Россия, Челябинская область, Магнитогорск	0101000020E610000024F0879FFF884D406FB72407ECB44A40
11201	6	58	\N	2116	43315	\N	53.405246926824198	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Дружбы, 36	Россия, Челябинская область, Магнитогорск	0101000020E61000009886E12362884D40ACE63922DFB34A40
11273	6	58	\N	2116	42792	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Доменщиков, 22	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11225	6	58	\N	2116	42777	\N	53.3938968512389	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Грязнова, 36	Россия, Челябинская область, Магнитогорск	0101000020E61000001D8F19A88C854D400B7F86376BB24A40
11211	6	58	\N	2116	42777	\N	53.442710473727999	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Грязнова, 11	Россия, Челябинская область, Магнитогорск	0101000020E6100000A9F8BF232A864D405BCEA5B8AAB84A40
11209	6	58	\N	2116	42777	\N	53.395948976994497	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Грязнова, 51	Россия, Челябинская область, Магнитогорск	0101000020E6100000F72004E44B864D4024F1F274AEB24A40
11276	6	58	\N	2116	42791	\N	53.396014006112203	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Галиуллина, 33/3	Россия, Челябинская область, Магнитогорск	0101000020E6100000F86C1D1CEC854D400B613596B0B24A40
11275	6	58	\N	2116	42791	\N	53.397963430498201	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Галиуллина, 19/1	Россия, Челябинская область, Магнитогорск	0101000020E6100000300E2E1D73864D404F029B73F0B24A40
11272	6	58	\N	2116	42791	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Галиуллина, 22/1		0101000020E61000001CB1169F02864D402FDD240681B34A40
11271	6	58	\N	2116	42791	\N	53.397450432779998	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Галиуллина, 20	Россия, Челябинская область, Магнитогорск	0101000020E610000043C5387F13864D40C9E53FA4DFB24A40
11231	6	58	\N	2116	42791	\N	53.402374999999999	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Галиуллина, 11/3	Россия, Челябинская область, Магнитогорск	0101000020E61000001CB1169F02864D402FDD240681B34A40
11198	6	58	\N	2116	43437	\N	53.427808793924001	Челябинская область, Магнитогорский городской округ, Правобережный район, ул. Гагарина, 33	Россия, Челябинская область, Магнитогорск	0101000020E61000008CF337A110874D409DF7FF71C2B64A40
11190	6	58	\N	2116	43437	\N	53.3982708253724	Челябинская область, Магнитогорский городской округ, Ленинский район, Гагарина, 12	Россия, Челябинская область, Магнитогорск	0101000020E6100000EC4E779E78884D40FDF84B8BFAB24A40
11262	6	58	\N	2116	42656	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Ворошилова, 27		0101000020E61000001CB1169F02864D402FDD240681B34A40
11260	6	58	\N	2116	42656	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Ворошилова, 16/1		0101000020E61000001CB1169F02864D402FDD240681B34A40
11259	6	58	\N	2116	42656	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Ворошилова, 3		0101000020E61000001CB1169F02864D402FDD240681B34A40
11258	6	58	\N	2116	42656	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Ворошилова, 11/1		0101000020E61000001CB1169F02864D402FDD240681B34A40
11159	6	58	\N	2116	43286	\N	53.401143476915699	Челябинская область, Магнитогорский городской округ, Ленинский район, Вокзальная, 144		0101000020E6100000DF6FB4E386854D40790261A758B34A40
11156	6	58	\N	2116	43297	\N	53.393345826517702	Челябинская область, Магнитогорский городской округ, Ленинский район, Войкова, 60	Россия, Челябинская область, Магнитогорск	0101000020E61000009147702365854D409701672959B24A40
11261	6	58	\N	2116	42806	\N	53.402374999999999	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица Бориса Ручьева, 10		0101000020E61000001CB1169F02864D402FDD240681B34A40
11170	6	58	\N	2116	42910	\N	53.396013605316703	Челябинская область, Магнитогорский городской округ, Ленинский район, Белинского, 82	Россия, Челябинская область, Магнитогорск	0101000020E61000002D98F8A3A8854D400B613596B0B24A40
11155	6	58	\N	2116	43674	\N	53.451793218284202	Челябинская область, Магнитогорский городской округ, Ленинский район, Бахметьева, 11	Россия, Челябинская область, Магнитогорск	0101000020E6100000CEFDD5E3BE894D40E7C75F5AD4B94A40
11288	6	58	\N	2116	42797	\N	53.399092003606	Челябинская область, город Магнитогорск,  Орджоникидзевский район, улица 50 летия  Магнитки, 48	Россия, Челябинская область, Магнитогорск	0101000020E6100000469561DC0D864D40310C587215B34A40
11163	6	58	\N	2116	43310	\N	53.396433236116998	Челябинская область, Магнитогорский городской округ, Ленинский район, Вокзальная, 88	Россия, Челябинская область, Магнитогорск	0101000020E6100000438EAD6708874D4010070951BEB24A40
11009	6	58	\N	55110	42783	\N	55.6245212011641	город Кыштым, пос. Тайгинка, ул. Мира, 13		0101000020E61000004EB6813B50414E402655DB4DF0CF4B40
11005	6	58	\N	3348	43565	\N	55.718527334309897	город Кыштым, ул. Школьная, 1	Россия, Челябинская область, Кыштым	0101000020E61000002CB7B41A12454E40812557B1F8DB4B40
11002	6	58	\N	3348	43235	\N	55.707334173999499	город Кыштым, ул. Челюскинцев, 57	Россия, Челябинская область, Кыштым	0101000020E6100000C03DCF9F36464E40A8ACA6EB89DA4B40
10996	6	58	\N	3348	44095	\N	55.703408536883401	город Кыштым, ул. Станционная, 1а	Россия, Челябинская область, Кыштым	0101000020E6100000C03DCF9F36464E40255B5D4E09DA4B40
11003	6	58	\N	3348	43547	\N	55.704280934913903	город Кыштым, ул. Садовая, д.19              (2 этаж) МОУ СОШ №3	Россия, Челябинская область, Кыштым	0101000020E61000009FC9FE791A464E40DB183BE125DA4B40
10997	6	58	\N	3348	42657	\N	55.703311602561499	город Кыштым, ул. Республики, 12	Россия, Челябинская область, Кыштым	0101000020E610000088DA368C82464E403271AB2006DA4B40
10993	6	58	\N	3348	42673	\N	55.704184002765302	город Кыштым, ул. Кирова, 72                  (1 этаж) МОУ ОШ №4	Россия, Челябинская область, Кыштым	0101000020E6100000EC89AE0B3F464E40E82E89B322DA4B40
10992	6	58	\N	3348	42757	\N	55.706898000000002	город  Кыштым, ул. Интернационала, 103		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
10991	6	58	\N	3348	42757	\N	55.706898000000002	город Кыштым, ул. Интернационала, 83		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
10990	6	58	\N	3348	42757	\N	55.706898000000002	город Кыштым, ул. Интернационала, 103б		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
10988	6	58	\N	3348	42757	\N	55.706898000000002	город Кыштым, ул. Интернационала, 103	Россия, Челябинская область, Кыштым	0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
11006	6	58	\N	3348	43520	\N	55.706898000000002	"""город Кыштым, ул. Дальняя, клуб санатория """"Дальняя Дача"""""""		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
11008	6	58	\N	3348	43232	\N	55.706898000000002	город Кыштым, ул. Гагарина, д. 1, МОУ ОШ №11		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
11957	6	58	\N	3348	42678	\N	55.706898000000002	город Кыштым, ул. Вокзальная, 14		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
11004	6	58	\N	3348	43233	\N	55.706898000000002	город Кыштым, ул. В. Сергеевой, 77		0101000020E6100000EA211ADD41464E40CDCD37A27BDA4B40
10989	6	58	\N	3348	42721	\N	55.7085457104113	город Кыштым, ул. Бажова, 4	Россия, Челябинская область, Кыштым	0101000020E6100000942F682101474E4016DBA4A2B1DA4B40
11007	6	58	\N	3348	43234	\N	55.707673407997703	город Кыштым, ул. 2 Южная, 1	Россия, Челябинская область, Кыштым	0101000020E610000078B5DC9909464E4090A1630795DA4B40
11000	6	58	\N	3348	42903	\N	55.704184002765302	город Кыштым, ул. Ветеранов, 26	Россия, Челябинская область, Кыштым	0101000020E61000009CF9D51C20464E40E82E89B322DA4B40
11040	6	58	\N	55092	43307	\N	55.337867490579697	"""Кусинское городское поселение, Стадион """"Труд"""", ул. Спартака, д.1"	Россия, Челябинская область, Куса	0101000020E61000007E71A94A5BB84D40E6B2D1393FAB4B40
10972	6	58	\N	55092	43307	\N	55.338454543253903	"Кусинское городское поселение, Стадион ""Труд"", ул. Спартака, д.1"""	Россия, Челябинская область, Куса	0101000020E61000008141D2A755B84D407715527E52AB4B40
10965	6	58	\N	55092	42661	\N	55.338421292456999	Кусинское городское поселение, Школа №8, ул. Советская, д.5		0101000020E6100000130CE71A66B84D40CAA31B6151AB4B40
10974	6	58	\N	55092	42904	\N	55.338746	Кусинское городское поселение, Школа №1, ул.Свободы, д.13	Россия, Челябинская область, Куса	0101000020E6100000200890A163B74D404ED367075CAB4B40
10968	6	58	\N	55092	43721	\N	55.339824298850502	Кусинское городское поселение, Детская музыкальная школа, ул.Свердлова, д.18	Россия, Челябинская область, Куса	0101000020E61000008411FB0450B84D40AD32535A7FAB4B40
10971	6	58	\N	55092	42667	\N	55.347284217494902	Кусинское городское поселение, Школа №9 (правое крыло), ул.Правды, д.25	Россия, Челябинская область, Куса	0101000020E6100000D4F36E2C28B84D40483657CD73AC4B40
10970	6	58	\N	55092	42667	\N	55.336131219699197	Кусинское городское поселение, Школа №9 (левое крыло), ул.Правды, д.25	Россия, Челябинская область, Куса	0101000020E6100000325A475513B84D40FD15325706AB4B40
10967	6	58	\N	55092	42997	\N	55.344022891930997	Кусинское городское поселение, Школа №7, ул.Ленинградская, д.23	Россия, Челябинская область, Куса	0101000020E6100000D6E5948098B84D40310917F208AC4B40
10966	6	58	\N	55092	43033	\N	55.343958214860201	"""Кусинское городское поселение, Стадион """"Рубин"""", ул.Есенина, д.8"""		0101000020E6100000AA285E656DB74D404A99D4D006AC4B40
10964	6	58	\N	55092	43305	\N	55.338943747141798	Кусинское городское поселение, Дворец культуры, ул.Бубнова, д.4	Россия, Челябинская область, Куса	0101000020E6100000BEDC274701B84D407496598462AB4B40
10973	6	58	\N	55092	43716	\N	55.343737624171197	Кусинское городское поселение, Машиностроительный техникум, ул.3 Интернационала, д.3	Россия, Челябинская область, Куса	0101000020E6100000D2393FC571B84D403C32569BFFAB4B40
10878	6	58	\N	16949	43980	\N	55.245756062020497	Челябинская область, Красноармейский муниципальный район, Баландинское сельское поселение, деревня Круглое, Озерная, 13	Россия, Челябинская область, поселок Круглое	0101000020E6100000028063CF9EC34E40DC65BFEE749F4B40
11864	6	58	\N	55152	43407	\N	55.236838432419603	Челябинская область, Сосновский муниципальный район, Краснопольское сельское поселение, поселок Красное Поле, Солнечная, 1	Россия	0101000020E6100000412B3064759F4E409B3924B5509E4B40
11627	6	58	\N	55122	42934	\N	54.602038	п.Красногорский, Победы, 16		0101000020E6100000D2890453CD9E4E408179C8940F4D4B40
11624	6	58	\N	55122	42925	\N	54.602038	п.Красногорский, Ленина, 4		0101000020E6100000D2890453CD9E4E408179C8940F4D4B40
11729	6	58	\N	26226	\N	\N	54.894202	г. Коркино, Цвиллинга, 3	Россия, Челябинская область, Коркино	0101000020E61000008B70935165B04E4047020D3675724B40
11733	6	58	\N	26226	43118	\N	54.8832655814549	г. Коркино, Энгельса, 73	Россия, Челябинская область, Коркино	0101000020E61000008484285FD0B04E4099D53BDC0E714B40
11745	6	58	\N	26226	42941	\N	54.894202	г. Коркино, Чкалова, 115		0101000020E61000008B70935165B04E4047020D3675724B40
11735	6	58	\N	26226	42937	\N	54.891332645236602	г. Коркино, Цвиллинга, 38	Россия, Челябинская область, Коркино	0101000020E61000007E52EDD3F1B24E403C6C223317724B40
11728	6	58	\N	26226	42937	\N	54.894202	г. Коркино, Цвиллинга, 1Б		0101000020E61000008B70935165B04E4047020D3675724B40
11740	6	58	\N	26226	42689	\N	54.896500291262299	г. Коркино, Сони Кривой, 8	Россия, Челябинская область, Коркино	0101000020E6100000931B45D61AB24E40986E1283C0724B40
11738	6	58	\N	26226	42689	\N	54.891233697588902	г. Коркино, Сони Кривой, 10	Россия, Челябинская область, Коркино	0101000020E6100000F92EA52E19B34E40A88AA9F413724B40
11743	6	58	\N	26226	42940	\N	54.8903411285266	г. Коркино, Пушкова, 7А	Россия, Челябинская область, Коркино	0101000020E61000005F402FDCB9B04E40DBA4A2B1F6714B40
11747	6	58	\N	26226	43588	\N	54.894202	г. Коркино, Пролетарская, 39		0101000020E61000008B70935165B04E4047020D3675724B40
11748	6	58	\N	26226	43024	\N	54.894202	г. Коркино, Новый, 1		0101000020E61000008B70935165B04E4047020D3675724B40
11578	6	58	840	19040	44161	\N	53.796353000000003	п. Бускульский, Центральная 8		0101000020E6100000E3C281902C944E40278925E5EEE54A40
11739	6	58	\N	26226	42942	\N	54.889254693366702	г. Коркино, Моргунова, 7	Россия, Челябинская область, Коркино	0101000020E6100000EA25C632FDB04E40F9669B1BD3714B40
11737	6	58	\N	26226	43023	\N	54.894202	г. Коркино, Мира, 45		0101000020E61000008B70935165B04E4047020D3675724B40
11736	6	58	\N	26226	43023	\N	54.896203485839401	г. Коркино, Мира, 52	Россия, Челябинская область, Коркино	0101000020E61000001D1D5723BBB24E40DEC9A7C7B6724B40
11734	6	58	\N	26226	43672	\N	54.894202	г. Коркино, Ленина, 18		0101000020E61000008B70935165B04E4047020D3675724B40
11746	6	58	\N	26226	44009	\N	54.894202	г. Коркино, Керамиков, 1		0101000020E61000008B70935165B04E4047020D3675724B40
11742	6	58	\N	26226	43580	\N	54.894202	г. Коркино, Заводская, 1А		0101000020E61000008B70935165B04E4047020D3675724B40
11730	6	58	\N	26226	42687	\N	54.891431592640103	г. Коркино, Горняков, 12	Россия, Челябинская область, Коркино	0101000020E610000036CAFACDC4B24E40CF4D9B711A724B40
11727	6	58	\N	26226	42933	\N	54.891033772348898	г. Коркино, 9 Января, 34А	Россия, Челябинская область, Коркино	0101000020E6100000DF196D5512B34E40E1CFF0660D724B40
11744	6	58	\N	26226	43122	\N	54.894202	г. Коркино, 30 лет ВЛКСМ, 171		0101000020E61000008B70935165B04E4047020D3675724B40
11741	6	58	\N	26226	43122	\N	54.892915774396101	г. Коркино, 30 лет ВЛКСМ, 27	Россия, Челябинская область, Коркино	0101000020E61000007BA4C16D6DB54E409E094D124B724B40
11732	6	58	\N	26226	42939	\N	54.894202	г. Коркино, 1 Мая, 44		0101000020E61000008B70935165B04E4047020D3675724B40
11731	6	58	\N	26226	42939	\N	54.894202	г. Коркино, 1 Мая, 24		0101000020E61000008B70935165B04E4047020D3675724B40
11679	6	58	\N	55095	42680	\N	55.111802574942601	Челябинская область, г. Копейск, ул. Меховова, 12, 1 этаж, фойе	Россия	0101000020E6100000E4326E6AA0CF4E401F4C8A8F4F8E4B40
11702	6	58	\N	55093	43039	\N	55.099008149445702	Челябинская область, г. Копейск, пр. Славы, 13	Россия	0101000020E6100000BC783F6EBFCE4E406C054D4BAC8C4B40
11687	6	58	\N	55093	43478	\N	55.111647570958198	Челябинская область, г. Копейск, пр. Победы, 42	Россия	0101000020E61000000820B58993CF4E40F8544E7B4A8E4B40
11686	6	58	\N	55093	43392	\N	55.117846490560403	Челябинская область, г. Копейск, пр. Победы, 34А	Россия	0101000020E6100000711E4E603ACD4E4072FBE593158F4B40
11701	6	58	\N	55093	42920	\N	55.092314000000002	Челябинская область, г. Копейск, пр. Ильича, 14		0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
11690	6	58	\N	55093	43350	\N	55.114402765614102	Челябинская область, г. Копейск, ул. Электровозная, 18	Россия	0101000020E610000040C1C58A1AD04E403BC8EBC1A48E4B40
11689	6	58	\N	55093	43350	\N	55.114009178061998	Челябинская область, г. Копейск, ул. Электровозная, 11	Россия	0101000020E6100000B22D03CE52D04E408F39CFD8978E4B40
11675	6	58	\N	55093	43323	\N	55.111647570958198	Челябинская область, г. Копейск, ул. Черняховского, 8	Россия	0101000020E61000000A65E1EB6BD34E40F8544E7B4A8E4B40
11677	6	58	\N	55093	43347	\N	55.109679457928301	Челябинская область, г. Копейск, ул. Чернышевского, 47	Россия	0101000020E6100000CB9F6F0B96D44E406C0723F6098E4B40
11676	6	58	\N	55093	43347	\N	55.103971379473897	Челябинская область, г. Копейск, ул. Чернышевского, 45	Россия	0101000020E610000095287B4B39D34E40C05DF6EB4E8D4B40
11714	6	58	\N	55093	43383	\N	55.099935864404699	Челябинская область, г. Копейск, ул. Троицкая, 3	Россия	0101000020E610000069FF03AC55CF4E40B6D8EDB3CA8C4B40
11681	6	58	\N	55093	42929	\N	55.092314000000002	Челябинская область, г. Копейск, ул. Театральная, 6		0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
11680	6	58	\N	55093	42929	\N	55.096055005405198	Челябинская область, г. Копейск, ул. Театральная, 14	Россия	0101000020E61000007120240B98CE4E4003CFBD874B8C4B40
11695	6	58	\N	55093	43022	\N	55.092314000000002	Челябинская область, г. Копейск, пер. Свободы, 2А	Россия	0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
11672	6	58	\N	55093	43714	\N	55.110356007765503	Челябинская область, г. Копейск, ул. Саратовская, 3Б	Россия	0101000020E610000068CBB91457CF4E406D753925208E4B40
11716	6	58	\N	55093	43436	\N	55.106923936095001	Челябинская область, г. Копейск, ул. Российская, 25		0101000020E6100000802C4487C0CF4E40299485AFAF8D4B40
11685	6	58	\N	55093	43382	\N	55.1012154622737	Челябинская область, г. Копейск, пр. Победы, 34Б	Россия	0101000020E6100000C630276893D14E40AD6EF59CF48C4B40
11693	6	58	\N	55093	43418	\N	55.108892185451303	Челябинская область, г. Копейск, ул. Пионерская, 17		0101000020E6100000A4703D0AD7CF4E40E4654D2CF08D4B40
11711	6	58	\N	55093	43746	\N	55.109788810940401	Челябинская область, г. Копейск, ул. Орджоникидзе, 32	Россия	0101000020E6100000662FDB4E5BCF4E40F33AE2900D8E4B40
11703	6	58	\N	55093	43189	\N	55.100090914023497	Челябинская область, г. Копейск, ул. Новосибирская, 21	Россия	0101000020E61000009294F430B4CE4E40DDCF29C8CF8C4B40
11678	6	58	\N	55093	42930	\N	55.091863606423701	Челябинская область, г. Копейск, ул. Меховова, 10	Россия	0101000020E6100000B88FDC9A74CF4E4002D71533C28B4B40
11683	6	58	\N	55093	42688	\N	55.122937737500898	Челябинская область, г. Копейск, ул. Лихачева, 4	Россия	0101000020E61000006B2920ED7FCE4E40C3B7B06EBC8F4B40
11708	6	58	\N	55093	43021	\N	55.092314000000002	Челябинская область, г. Копейск, ул. Лизы Чайкиной, 33		0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
11718	6	58	\N	55093	43333	\N	55.106136609086398	Челябинская область, г. Копейск, ул. Ленина, 12		0101000020E610000098DD938785CE4E40A1F2AFE5958D4B40
11696	6	58	\N	55093	43333	\N	55.103774534575301	Челябинская область, г. Копейск, ул. Ленина, 40	Россия	0101000020E61000005B5D4E0988D34E403A92CB7F488D4B40
11691	6	58	\N	55093	43385	\N	55.118363023584003	Челябинская область, г. Копейск, ул. Кузнецова, 18	Россия	0101000020E6100000AE6708C72CD14E403A07CF84268F4B40
11698	6	58	\N	55093	42686	\N	55.097236289317102	Челябинская область, г. Копейск, пр. Коммунистический, 3Б	Россия	0101000020E61000009294F430B4CE4E4037FFAF3A728C4B40
11713	6	58	\N	55093	43330	\N	55.111942779514202	Челябинская область, г. Копейск, ул. Коммунистическая, 27		0101000020E6100000A8DF85ADD9D24E401002F225548E4B40
11712	6	58	\N	55093	43330	\N	55.095112394907098	Челябинская область, г. Копейск, ул. Коммунистическая, 12	Россия	0101000020E610000023BC3D0801D34E4084BA48A12C8C4B40
11705	6	58	\N	55093	43469	\N	55.1096376536902	Челябинская область, г. Копейск, ул. Калинина, 18		0101000020E61000001EFE9AAC51CF4E400D33349E088E4B40
11688	6	58	\N	55093	43720	\N	55.092314000000002	Челябинская область, г. Копейск, ул. Ильфа, 8	Россия	0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
11707	6	58	\N	55093	43036	\N	55.101862647060003	Челябинская область, г. Копейск, ул. Забойщиков, 51	Россия	0101000020E6100000BF4868CBB9CE4E4013D6C6D8098D4B40
11710	6	58	\N	55093	42932	\N	55.092314000000002	Челябинская область, г. Копейск, ул. 21 Партсъезда, 1		0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
11674	6	58	\N	55093	43114	\N	55.0997956175149	Челябинская область, г. Копейск, ул. 16 лет Октября, 24	Россия	0101000020E61000005B99F04BFDCE4E40C422861DC68C4B40
11671	6	58	\N	55126	43322	\N	55.095063172817497	Челябинская область, г. Копейск, ул. Октябрьская, 29	Россия	0101000020E61000008EE9094B3CD04E40A3073E062B8C4B40
11694	6	58	\N	55126	43121	\N	55.120067554176998	Челябинская область, г. Копейск, ул. Жданова, 25	Россия	0101000020E6100000C6E1CCAFE6D04E40E8A562635E8F4B40
11700	6	58	\N	55151	43389	\N	55.106685298462899	Челябинская область, г. Копейск, ул. Карла Маркса, 7		0101000020E6100000C45DBD8A8CD24E40A4FCA4DAA78D4B40
10272	6	58	\N	35919	8834	\N	58.578226999999998	Красный уголок зернотока: деревня Аминево, ул. Приозерная, д.5	Россия, Кировская область, Киров, улица Приозерная, 5	0101000020E61000003694DA8B68D948400455A357034A4D40
10841	6	58	\N	55117	43531	\N	54.756992806741899	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Цементников, 9/3	Россия, Челябинская область, Катав-Ивановск	0101000020E6100000C0EB33677D1A4D4085268925E5604B40
10838	6	58	\N	55117	43525	\N	54.759378237104897	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Учительская, д.1а	Россия, Челябинская область, Катав-Ивановск	0101000020E61000009A5B21ACC61A4D40A4A65D4C33614B40
10833	6	58	\N	55117	42901	\N	54.749248322345601	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Степана Разина, д.25	Россия, Челябинская область, Катав-Ивановск	0101000020E6100000EE23B726DD184D40F54BC45BE75F4B40
10830	6	58	\N	55117	42891	\N	54.756341284854301	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Остров, д.7	Россия, Челябинская область, Катав-Ивановск	0101000020E61000004FE61F7D931A4D40DDCF29C8CF604B40
10845	6	58	\N	55117	43585	\N	54.757383714818801	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Лесная, д.9а	Россия, Челябинская область, Катав-Ивановск	0101000020E6100000130D52F0141A4D40C0417BF5F1604B40
10831	6	58	\N	55117	43160	\N	54.751581753110898	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Ленина, д.19	Россия, Челябинская область, Катав-Ивановск	0101000020E6100000F67EA31D371A4D409221C7D633604B40
10828	6	58	\N	55117	43160	\N	54.753220038681597	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Ленина, 16	Россия, Челябинская область, Катав-Ивановск	0101000020E610000072DF6A9DB8184D40B858518369604B40
10839	6	58	\N	55117	43094	\N	54.747411271189698	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Коммунальная, д.10	Россия, Челябинская область, Катав-Ивановск	0101000020E6100000EB538EC9E2184D40D8D5E429AB5F4B40
10827	6	58	\N	55117	43093	\N	54.7516313991065	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Дмитрия Тараканова, д.6	Россия, Челябинская область, Катав-Ивановск	0101000020E6100000BEDD921CB0194D4074D4D17135604B40
10836	6	58	\N	55117	42907	\N	54.755553239544902	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Гагарина, д.8	Россия, Челябинская область, Катав-Ивановск	0101000020E610000011A62897C6194D4085B2F0F5B5604B40
10783	6	58	\N	12375	43610	\N	55.888995184666697	Челябинская область, Каслинский муниципальный район, город Касли, ул.Стадионная, д.89	Россия, Челябинская область, Касли	0101000020E6100000F3AACE6A81634E405DA79196CAF14B40
10788	6	58	\N	12375	43609	\N	55.887740999999998	Челябинская область, Каслинский муниципальный район, город Касли, ул.Ретнева, д.22		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
10793	6	58	\N	12375	43515	\N	55.887740999999998	Челябинская область, Каслинский муниципальный район, город Касли, ул.Луначарского, д.118		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
10784	6	58	\N	12375	43689	\N	55.887740999999998	Челябинская область, Каслинский муниципальный район, город Касли, ул.Лобашова, д.137		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
10790	6	58	\N	12375	43511	\N	55.888898713142297	Челябинская область, Каслинский муниципальный район, город Касли, ул.Ленина, д.42	Россия, Челябинская область, Касли	0101000020E6100000EE0A7DB08C634E403B394371C7F14B40
10787	6	58	\N	12375	43511	\N	55.887740999999998	Челябинская область, Каслинский муниципальный район, город Касли, ул.Ленина, д.59		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
10786	6	58	\N	12375	43511	\N	55.887740999999998	Челябинская область, Каслинский муниципальный район, город Касли, ул.Ленина, д.16		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
10785	6	58	\N	12375	43511	\N	55.887644561409601	Челябинская область, Каслинский муниципальный район, город Касли, ул.Ленина, д.29	Россия, Челябинская область, Касли	0101000020E6100000700B96EA02624E409DBAF2599EF14B40
10789	6	58	\N	12375	43154	\N	55.887740999999998	Челябинская область, Каслинский муниципальный район, город Касли, ул.Куйбышева, д.43		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
10792	6	58	\N	12375	43514	\N	55.891406894508499	Адрес УИК для голосования : Челябинская область, Каслинский район, г.Касли, ул.Калинина, д.28, адрес УИК: г.Касли, ул.Луначарского, д.118	Россия, Челябинская область, Касли	0101000020E61000003A94A12AA6604E407636E49F19F24B40
89184	6	56	1189	49931	18756	\N	56.885396999999998	город Сухой Лог, Гоголя, 12		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
10791	6	58	\N	12375	43514	\N	55.887740999999998	Адрес УИК в день голосования :Челябинская область, Каслинский район, город Касли, ул.Калинина, д.28, Адрес УИК: г.Касли, ул.Луначарского, д.118		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
10782	6	58	\N	12375	43506	\N	55.887740999999998	Челябинская область, Каслинский муниципальный район, город Касли, ул.8е марта, д.50		0101000020E6100000BD8DCD8E54614E40BF28417FA1F14B40
11466	6	58	\N	55111	43575	\N	53.046113320078497	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Хладопункт, 7	Россия, Челябинская область, Карталы	0101000020E6100000D32EA699EE514E40D175E107E7854A40
11472	6	58	\N	55111	43367	\N	53.0570775532371	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, пер.Учебный, 4	Россия, Челябинская область, Карталы	0101000020E61000005AF3E32F2D524E4019A9F7544E874A40
11469	6	58	\N	55111	43206	\N	53.050457974172502	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Славы, 4	Россия, Челябинская область, Карталы	0101000020E6100000658BA4DDE8534E4029E9616875864A40
11462	6	58	\N	55111	42935	\N	53.0506648514855	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Свердлова, 12	Россия, Челябинская область, Карталы	0101000020E6100000BB7D569929534E40A306D3307C864A40
11460	6	58	\N	55111	42816	\N	53.055123526718099	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Просвещения, 53	Россия, Челябинская область, Карталы	0101000020E610000096B20C71AC534E40C39CA04D0E874A40
11438	6	58	\N	55111	43293	\N	53.055818784662101	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Орджоникидзе, 6	Россия, Челябинская область, Карталы	0101000020E6100000DFE00B93A9544E406ABFB51325874A40
11463	6	58	\N	55111	42834	\N	53.049630454941301	"""Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Лобырина, 44""""А"""""""		0101000020E6100000CFDA6D179A534E4043739D465A864A40
11468	6	58	\N	55111	43401	\N	53.057077553237001	"""Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Ленина, 7 """"А"""""""	Россия, Челябинская область, Карталы	0101000020E61000007973B8567B504E4019A9F7544E874A40
11467	6	58	\N	55111	43401	\N	53.060904031262503	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Ленина, 22		0101000020E6100000A8E2C62DE6514E400919C8B3CB874A40
11464	6	58	\N	55111	42924	\N	53.066591408033297	"""Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Карташева, 12 """"А"""""""	Россия, Челябинская область, Карталы	0101000020E6100000AAD55757054E4E409E9ACB0D86884A40
11461	6	58	\N	55111	43345	\N	53.0653505901847	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Гагарина, 142	Россия, Челябинская область, Карталы	0101000020E61000003A083A5AD5504E4065E1EB6B5D884A40
11471	6	58	\N	55111	43353	\N	53.060800617427702	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Братьев Кашириных, 12	Россия, Челябинская область, Карталы	0101000020E61000004D6551D845514E403448C153C8874A40
11465	6	58	\N	55111	43018	\N	53.058525449949499	Челябинская область, Карталинский муниципальный район, Карталинское городское поселение, Акмолинская, 66	Россия, Челябинская область, Карталы	0101000020E6100000E1EB6B5D6A524E40CC7F48BF7D874A40
10148	6	58	\N	13447	43157	\N	55.455730809703297	Челябинская область, Карабашский городской округ, Ремесленная, 3	Россия, Челябинская область, Карабаш	0101000020E6100000C2BF081A331B4E40FE62B66455BA4B40
10156	6	58	\N	13447	43717	\N	55.458218263227501	Челябинская область, Карабашский городской округ, Пролетарская, 101	Россия, Челябинская область, Карабаш	0101000020E61000001A36CAFACD184E4022382EE3A6BA4B40
10149	6	58	\N	13447	42855	\N	55.467613761090703	Челябинская область, Карабашский городской округ, Подлесная, 6	Россия, Челябинская область, Карабаш	0101000020E61000003D4679E6E5184E406C938AC6DABB4B40
10155	6	58	\N	13447	43560	\N	55.458023174527398	Челябинская область, Карабашский городской округ, Освобождение Урала, 154		0101000020E6100000C6F7C5A52A1B4E406CE8667FA0BA4B40
10153	6	58	\N	13447	43560	\N	55.465955873015801	Челябинская область, Карабашский городской округ, Освобождение Урала, 64	Россия, Челябинская область, Карабаш	0101000020E6100000BA4C4D8237184E40FFAF3A72A4BB4B40
10151	6	58	\N	13447	43409	\N	55.458998608336302	Челябинская область, Карабашский городской округ, Металлургов, 9	Россия, Челябинская область, Карабаш	0101000020E6100000355D4F745D184E40C7F2AE7AC0BA4B40
10150	6	58	\N	13447	43409	\N	55.462509969434002	Челябинская область, Карабашский городской округ, Металлургов, 15/1	Россия, Челябинская область, Карабаш	0101000020E610000070287CB60E184E405709168733BB4B40
10152	6	58	\N	13447	43718	\N	55.454706518339897	Челябинская область, Карабашский городской округ, Комсомольская, 2	Россия, Челябинская область, Карабаш	0101000020E61000004FEB36A8FD1A4E409221C7D633BA4B40
10158	6	58	\N	13447	43464	\N	55.483717764109699	Челябинская область, Карабашский городской округ, Военный городок №1, Клубная, 1	Россия, Челябинская область, Карабаш	0101000020E61000006A6CAF05BD194E40473EAF78EABD4B40
10147	6	58	\N	13447	43630	\N	55.456622000000003	Челябинская область, г. Карабаш, Декабристов, 2		0101000020E6100000BA490C022B1B4E402B51F69672BA4B40
10101	6	58	\N	7465	43061	\N	55.141824999999997	г. Златоуст, прт Гагарина, 3 мр, МОУ СОШ № 9		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10114	6	58	\N	7465	42592	\N	55.158537292925502	"""г. Златоуст, прт Мира, 2а: Дворец """"Победа"""" ОАО """"Златмаш"""""""	Россия, Челябинская область, Златоуст	0101000020E610000064213A048ED64D405D1ABFF04A944B40
10099	6	58	\N	7465	42641	\N	55.136372339929203	г. Златоуст, прт Гагарина, 5 линия, 7: МОУ СОШ № 10	Россия, Челябинская область, Златоуст	0101000020E61000005F24B4E55CDC4D40890B40A374914B40
10098	6	58	\N	7465	42641	\N	55.158537292925502	г. Златоуст, прт Гагарина, 5 линия, 4: Центр образования		0101000020E610000016F9F5436CD64D405D1ABFF04A944B40
10102	6	58	\N	7465	42589	\N	55.1410924776781	г.Златоуст, прт Гагарина, 3 мр, МОУ СОШ № 9	Россия, Челябинская область, Златоуст	0101000020E6100000DE54A4C2D8DA4D4016DD7A4D0F924B40
10100	6	58	\N	7465	42589	\N	55.156964666778002	г. Златоуст, прт Гагарина, 5 линия, 8: МОУ СОШ № 34	Россия, Челябинская область, Златоуст	0101000020E61000003D0D18247DD64D40EECEDA6D17944B40
10097	6	58	\N	7465	42589	\N	55.157161248452397	г. Златоуст, прт Гагарина, 5 линия, 2: МОУ СОШ № 35		0101000020E6100000376DC66988D64D40749A05DA1D944B40
10131	6	58	\N	7465	43187	\N	55.141824999999997	г. Златоуст, пос. Строителей, МОУ СОШ №38		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10110	6	58	\N	7465	43049	\N	55.156178330348901	г. Златоуст, ул. Шишкина, 20: МОУ СОШ № 4	Россия, Челябинская область, Златоуст	0101000020E61000009B1C3EE944D64D40662D05A4FD934B40
10118	6	58	\N	7465	43053	\N	55.157947565418702	г. Златоуст, ул. Чкалова, 30: СПЦО № 2 МОУ СО № 1	Россия, Челябинская область, Златоуст	0101000020E6100000EFE4D3635BD64D40FB3BDBA337944B40
10112	6	58	\N	7465	43177	\N	55.141824999999997	г. Златоуст, ул. Тургенева, 16: ГОУ ВПО ЮУрГУ в г. Златоусте		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10142	6	58	\N	7465	43680	\N	55.156257041483698	г. Златоуст, село Куваши, ул. Тихомирова, 1: МУК СЦКС Клуб с. Куваши	Россия, Челябинская область, городской округ Златоуст, поселок Куваши	0101000020E61000002600FF942AB54D40B262B83A00944B40
10079	6	58	\N	7465	43168	\N	55.141824999999997	город Златоуст, ул. Тельмана, 1: МОУ СОШ № 45		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10084	6	58	\N	7465	42844	\N	55.140354993112503	"""город Златоуст, ул. Румянцева, 93а: МОУ ДОД """"Музыкальная школа №3"""""""		0101000020E6100000DDEC0F94DBDA4D40406A1327F7914B40
10083	6	58	\N	7465	42844	\N	55.141824999999997	"""город Златоуст, ул. Румянцева, 43: ООО """"ЗП """"Электроизделия"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10082	6	58	\N	7465	42844	\N	55.156964666778002	город Златоуст, ул. Румянцева, 19: МУК ЦБС филиал № 1	Россия, Челябинская область, Златоуст	0101000020E61000003D0D18247DD64D40EECEDA6D17944B40
10080	6	58	\N	7465	42844	\N	55.141824999999997	"""город Златоуст, ул. Румянцева, 113а: ДОД """"Дом детства и юношества"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10094	6	58	\N	7465	42595	\N	55.141824999999997	г. Златоуст, ул. Профсоюзная, 7: МОУ СОШ № 1		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10093	6	58	\N	7465	42595	\N	55.150825991183197	г. Златоуст, ул. Профсоюзная, 7:МОУ СОШ № 1	Россия, Челябинская область, Златоуст	0101000020E6100000A227655243D54D4079B130444E934B40
10115	6	58	\N	7465	42602	\N	55.141824999999997	г. Златоуст, ул. Просвещения, 6: МОУ СОШ № 21		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10123	6	58	\N	7465	42640	\N	55.141824999999997	"""г. Златоуст, ул. Октябрьская, 4: """"Златоустовское мед. училище"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10089	6	58	\N	7465	43048	\N	55.141824999999997	"""г. Златоуст, ул. 5я Н.Вокзальная, 1б: ООО """"АТП"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10113	6	58	\N	7465	42847	\N	55.141824999999997	"""г. Златоуст, прт Мира, 1: ГБО УСПО """"Златоустовский ПГТ"""""""	Россия, Челябинская область, Златоуст	0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10126	6	58	\N	7465	43063	\N	55.141824999999997	г. Златоуст, ул. Металлургов, 8: МОУ СОШ №25		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10095	6	58	\N	7465	42639	\N	55.141824999999997	г. Златоуст, ул. Машиностроителей, 2а: ГОУ НПО ПУ4		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10143	6	58	\N	7465	43523	\N	55.162468585823397	г.Златоуст, поселок Центральный, ул. Ленина, 38: МУК СЦКС ДК пос. Центральный	Россия, Челябинская область, Златоуст	0101000020E61000001AA721AAF0D34D4092CEC0C8CB944B40
10122	6	58	\N	7465	43057	\N	55.141824999999997	г. Златоуст, ул. Ленина, 30: МОУ СОШ №3		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10091	6	58	\N	7465	43057	\N	55.166699281698897	"""г. Златоуст, ул. Ленина, 1: МУК ДК """"Булат"""""""	Россия, Челябинская область, Златоуст	0101000020E6100000F644D7851FD44D4051A3906456954B40
10134	6	58	\N	7465	42598	\N	55.156964666778002	г. Златоуст, ул. Кусинское шоссе, 21: ГОУ НПО ПУ28	Россия, Челябинская область, Златоуст	0101000020E61000001329CDE671D64D40EECEDA6D17944B40
10133	6	58	\N	7465	42598	\N	55.141824999999997	г. Златоуст, ул. Кусинское шоссе, 1а: Ресурсный центр проф. обучения		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10096	6	58	\N	7465	43046	\N	55.157357829153703	г. Златоуст, ул. Космонавтов, 1: МУК ЦБС (Централь. библиотека)	Россия, Челябинская область, Златоуст	0101000020E61000004DF4F92823D64D40CAE1934E24944B40
10140	6	58	\N	7465	43054	\N	55.141824999999997	"""г. Златоуст, ул. Копровая, 2: МУК ДК""""Булат РЦНТ клуб""""Радуга"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10092	6	58	\N	7465	43173	\N	55.157161248452397	"""г. Златоуст, ул. Ковшова, 7:  ГОУ СПО """"ЗТЭТ"""""""	Россия, Челябинская область, Златоуст	0101000020E61000009B1C3EE944D64D40749A05DA1D944B40
10132	6	58	\N	7465	43042	\N	55.140453325178797	"""г. Златоуст, ул. Кирова, 6: Торговый дом ОАО """"ЗМЗ"""""""	Россия, Челябинская область, Златоуст	0101000020E6100000DE54A4C2D8DA4D4003D0285DFA914B40
10125	6	58	\N	7465	42610	\N	55.158050845152403	"""г. Златоуст, ул. К. Маркса, 26: МУК ДК """"Металлург"""""""	Россия, Челябинская область, Златоуст	0101000020E6100000054EB6813BD64D40D00CE2033B944B40
10124	6	58	\N	7465	42610	\N	55.157652698381	г. Златоуст, ул. К. Маркса, 10: МОУ СОШ №18	Россия, Челябинская область, Златоуст	0101000020E6100000EFE4D3635BD64D40E38E37F92D944B40
10088	6	58	\N	7465	42975	\N	55.141824999999997	г. Златоуст, ул. К. Заслонова, 1: ООШ № 77	Россия, Челябинская область, Златоуст	0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10104	6	58	\N	7465	42846	\N	55.156768084130398	г. Златоуст, ул. Зеленая, МОУ СОШ № 15	Россия, Челябинская область, Златоуст	0101000020E610000077D844662ED64D4098874CF910944B40
10111	6	58	\N	7465	43062	\N	55.141824999999997	г. Златоуст, ул. Дворцовая, 18: МОУ СОШ № 2		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10116	6	58	\N	7465	42858	\N	55.158733866814899	г. Златоуст, ул. Горького, 1а: МУК ЦБС филиал № 21	Россия, Челябинская область, Златоуст	0101000020E6100000C500892650D64D40B3614D6551944B40
10120	6	58	\N	7465	43155	\N	55.141824999999997	г. Златоуст, ул. Веселовская, 50: ООШ №29		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10119	6	58	\N	7465	43155	\N	55.119793254682499	г. Златоуст, ул.Веселовская, 50: ООШ №29	Россия, Челябинская область, Златоуст	0101000020E610000088BEBB9525DC4D4016A58460558F4B40
10137	6	58	\N	7465	42856	\N	55.141824999999997	г. Златоуст, ул. В. Рязанова, 31: ООШ №12		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10129	6	58	\N	7465	43075	\N	55.141824999999997	г. Златоуст, ул. Б. Кирпичная, 50: Центр эстет. воспитания детей		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10090	6	58	\N	7465	42843	\N	55.141824999999997	г. Златоуст, ул. Аносова, 129: ООШ № 17	Россия, Челябинская область, Златоуст	0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10085	6	58	\N	7465	42843	\N	55.175493202583901	город Златоуст, ул. Аносова, 239: МОУ СОШ № 90	Россия, Челябинская область, Златоуст	0101000020E6100000EA3E00A94DD84D40A6D6FB8D76964B40
10081	6	58	\N	7465	42843	\N	55.182222429159303	город Златоуст, ул. Аносова, 202: ГОУ НПО ПУ35	Россия, Челябинская область, Златоуст	0101000020E6100000EF3B86C77EDA4D404D4EED0C53974B40
10086	6	58	\N	7465	43169	\N	55.141824999999997	г. Златоуст, ул. 8го Марта, 66: ООШ № 41		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10107	6	58	\N	7465	42590	\N	55.141824999999997	г. Златоуст, ул. 40летия Победы, 38а: МОУ СОШ № 36		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10106	6	58	\N	7465	42590	\N	55.119995016315997	город Златоуст, ул. 40летия Победы, 38а: МОУ СОШ № 36	Россия, Челябинская область, Златоуст	0101000020E6100000D95A5F24B4DB4D407E5704FF5B8F4B40
10105	6	58	\N	7465	42590	\N	55.141824999999997	"""город Златоуст, ул. 40летия Победы, 19: МОУ ДОД """"Музыкальная школа № 2"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10108	6	58	\N	7465	42597	\N	55.158099989318004	г. Златоуст, ул.40летия Победы, 38а: МОУ СОШ № 36	Россия, Челябинская область, Златоуст	0101000020E61000004F3E3DB665D64D40B1BFEC9E3C944B40
10109	6	58	\N	7465	42591	\N	55.123635004649998	г. Златоуст, ул. 40 лет Победы, 20: Опорный пункт правопорядка	Россия, Челябинская область, Златоуст	0101000020E6100000C00303081FDC4D400BD28C45D38F4B40
10087	6	58	\N	7465	42845	\N	55.141824999999997	"""г. Златоуст, ул. 3я Тесьминская, 125: Техническая школа ОАО """"РЖД"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10127	6	58	\N	7465	42600	\N	55.141824999999997	г. Златоуст, ул. 3я Н.Заводская, 6: ГОУ НПО ПЛ111		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10117	6	58	\N	7465	42599	\N	55.156748502602497	г. Златоуст, ул. 30 лет ВЛКСМ, 8: МОУ ООШ № 5	Россия, Челябинская область, Златоуст	0101000020E610000054AA44D95BD64D402157EA5910944B40
10130	6	58	\N	7465	42601	\N	55.141824999999997	г. Златоуст, СевероЗападный рон, 2 квартал, 28: МОУ СОШ №37		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10121	6	58	\N	7465	43052	\N	55.141824999999997	г. Златоуст, ул. 1я Нагорная, 61: ООШ №20		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10128	6	58	\N	7465	43186	\N	55.156964666778002	г. Златоуст, ул. 1я Н.Заводская, 87: МОУ СОШ №8	Россия, Челябинская область, Златоуст	0101000020E61000008B355CE49ED64D40EECEDA6D17944B40
10103	6	58	\N	7465	42593	\N	55.141824999999997	"""г. Златоуст, прт Гагарина, 3 мр, 40: ГОУ СПО """"ЗПК"""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
10138	6	58	\N	7465	43043	\N	55.141824999999997	"""""""г. Златоуст, ул. 2я Закаменская, 23: Админ.здание №2 ОАО """"""""ЗЗМК"""""""""""""""		0101000020E6100000B48EAA2688DA4D40AA60545227924B40
11605	6	58	\N	20314	43013	\N	54.755742302016898	г.Еманжелинск, Школенко, 34	Россия, Челябинская область, Еманжелинск	0101000020E6100000C3D5011077A94E40581B6327BC604B40
11612	6	58	\N	20314	42836	\N	54.771127999999997	г.Еманжелинск, Чкалова, 10	Россия, Челябинская область, Еманжелинск	0101000020E6100000CF68AB92C8AA4E40D3838252B4624B40
11611	6	58	\N	20314	42836	\N	54.752649710315602	г.Еманжелинск, Чкалова, 20	Россия, Челябинская область, Еманжелинск	0101000020E6100000446D1B4641A84E40CEAACFD556604B40
11610	6	58	\N	20314	42836	\N	54.7515078657933	г.Еманжелинск, Чкалова, 26	Россия, Челябинская область, Еманжелинск	0101000020E61000007C6308008EA74E405857056A31604B40
11613	6	58	\N	20314	43119	\N	54.771127999999997	г.Еманжелинск, Чайковского, 12		0101000020E6100000CF68AB92C8AA4E40D3838252B4624B40
11616	6	58	\N	20314	43111	\N	54.760889889906103	г.Еманжелинск, Фрунзе, 58	Россия, Челябинская область, Еманжелинск	0101000020E61000002D24607479A94E403EEDF0D764614B40
11617	6	58	\N	20314	43016	\N	54.768632137604001	г.Еманжелинск, Титова, 1	Россия, Челябинская область, Еманжелинск	0101000020E610000015731074B4AA4E405C548B8862624B40
11602	6	58	\N	20314	42684	\N	54.760606816803303	г. Еманжелинск, Спартака, 67	Россия, Челябинская область, Еманжелинск	0101000020E61000005EBEF561BDA94E40E90DF7915B614B40
11603	6	58	\N	20314	43387	\N	54.762974487566296	Челябинская область, Еманжелинский муниципальный район, Еманжелинское городское поселение, Советская, 14	Россия, Челябинская область, Еманжелинск	0101000020E61000004F3E3DB665AA4E4062D9CC21A9614B40
11615	6	58	\N	20314	43109	\N	54.7567203710434	г.Еманжелинск, Матросова, 9	Россия, Челябинская область, Еманжелинск	0101000020E61000002D24607479A94E40541D7233DC604B40
11614	6	58	\N	20314	43109	\N	54.755826846589201	г.Еманжелинск, Матросова, 6	Россия, Челябинская область, Еманжелинск	0101000020E61000000070ECD973A94E4086376BF0BE604B40
11609	6	58	\N	20314	42835	\N	54.771127999999997	г.Еманжелинск, Горького, 70	Россия, Челябинская область, Еманжелинск	0101000020E6100000CF68AB92C8AA4E40D3838252B4624B40
11606	6	58	\N	20314	42830	\N	54.771127999999997	г.Еманжелинск, Гагарина, 5а	Россия, Челябинская область, Еманжелинск	0101000020E6100000CF68AB92C8AA4E40D3838252B4624B40
88847	6	56	1035	49928	20294	\N	57.243898365395403	город Новоуральск, С.Дудина, 7		0101000020E6100000D9B0A6B228084E40A8C7B60C389F4C40
11604	6	58	\N	20314	43108	\N	54.769376506094602	г.Еманжелинск, ООО Коркинский эксковаторно вагонноремонтный завод, промплощадка, ул. Восточная, д. 2	Россия, Челябинская область, Еманжелинск	0101000020E61000005C936E4BE4AA4E40B5A50EF27A624B40
11607	6	58	\N	20314	43107	\N	54.755146606792501	г.Еманжелинск, Вахрушева, 1	Россия, Челябинская область, Еманжелинск	0101000020E6100000C3D5011077A94E4015562AA8A8604B40
10740	6	58	\N	55099	43084	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Халтурина, 2а		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10753	6	58	\N	55099	43226	\N	56.042375999999997	Челябинская область,город Верхний Уфалей, Суворова, 2а		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10745	6	58	\N	55099	43219	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Прямицына, 47		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10738	6	58	\N	55099	42754	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Окишева, 9		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10744	6	58	\N	55099	42732	\N	56.045642685155102	Челябинская область, город Верхний Уфалей, Ленина, 157а	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E61000003FADA23F341D4E404A253CA1D7054C40
10742	6	58	\N	55099	42732	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Ленина, 164		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10739	6	58	\N	55099	42732	\N	56.0444897078198	Челябинская область , город Верхний Уфалей, Ленина, 24	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E61000003CDD79E2391D4E40E17F2BD9B1054C40
10748	6	58	\N	55099	43220	\N	56.042375999999997	Челябинская область,город Верхний Уфалей, Бабикова, 62		0101000020E6100000B56D1805C11D4E405111A7936C054C40
11293	6	58	\N	55147	43336	\N	53.877465398714001	Верхнеуральское городское поселение, Советская, 110		0101000020E6100000A4A833F7909C4D403C31EBC550F04A40
10037	6	58	\N	34229	43756	\N	55.252223999999998	деревня Березовка, Новая, 1		0101000020E6100000AB251DE560544E4016A243E048A04B40
10876	6	58	\N	55177	43805	\N	55.294430517724997	Челябинская область, Красноармейский муниципальный район, Баландинское сельское поселение, поселок Баландино, ж.д. станция, Железнодорожная, 25	Россия, Челябинская область, поселок Баландино	0101000020E61000004776A565A4C64E40DCF63DEAAFA54B40
10707	6	58	\N	55100	43400	\N	54.997244902568099	Челябинская область, Ашинский  муниципальный район, Миньярское городское поселение, Центральная, 11	Россия, Челябинская область, Аша	0101000020E61000006919A9F754A24C40BD8C62B9A57F4B40
10698	6	58	\N	55100	43339	\N	55.003766804010198	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Фрунзе, 34	Россия, Челябинская область, Аша	0101000020E6100000EAAEEC82C1A14C40EBE6E26F7B804B40
10699	6	58	\N	55100	43212	\N	55.002780092573801	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Узкоколейная, 1А	Россия, Челябинская область, Аша	0101000020E6100000670FB40243A04C409C8A54185B804B40
10704	6	58	\N	55100	43712	\N	55.003329242894203	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Тополиная, 2		0101000020E61000005B79C9FFE49F4C406F10AD156D804B40
10694	6	58	\N	55100	43730	\N	54.998034383066603	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Толстого, 16	Россия, Челябинская область, Аша	0101000020E6100000D731AEB838A44C40E525FF93BF7F4B40
10701	6	58	\N	55100	43360	\N	54.992507691903	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Танкистов, 15	Россия, Челябинская область, Аша	0101000020E6100000A98427F4FAA14C405A828C800A7F4B40
10685	6	58	\N	55100	43736	\N	54.984413657458397	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Советская, 26	Россия, Челябинская область, Аша	0101000020E610000075AC527AA6A34C40BEDC2747017E4B40
10696	6	58	\N	55100	42747	\N	55.002780092573801	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Симская, 1а		0101000020E6100000BEA085048CA24C409C8A54185B804B40
10688	6	58	\N	55100	42743	\N	55.002681420089402	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Озимина, 1	Россия, Челябинская область, Аша	0101000020E6100000A4AA09A2EE9F4C4009A9DBD957804B40
10687	6	58	\N	55100	42743	\N	54.998438272635198	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Озимина, 36	Россия, Челябинская область, Аша	0101000020E61000006C2409C215A44C40B58AFED0CC7F4B40
10703	6	58	\N	55100	43593	\N	55.006717638782	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Некрасова, 19	Россия, Челябинская область, Аша	0101000020E6100000E34F5436ACA14C40B325AB22DC804B40
10702	6	58	\N	55100	44319	\N	55.001389501115298	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Мира, 23	Россия, Челябинская область, Аша	0101000020E61000001BF1643733A24C404E452A8C2D804B40
10692	6	58	\N	55100	43377	\N	55.000008016049797	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Ленина, 47	Россия, Челябинская область, Аша	0101000020E6100000E12538F581A24C4083DE1B4300804B40
10690	6	58	\N	55100	43377	\N	55.002385401173399	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Ленина, 39	Россия, Челябинская область, Аша	0101000020E61000009FB0C403CAA04C401F80D4264E804B40
10684	6	58	\N	55100	43377	\N	54.998833003042101	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Ленина, 11	Россия, Челябинская область, Аша	0101000020E610000016BD5301F7A04C4031957EC2D97F4B40
88844	6	56	1035	49928	18800	\N	57.244922000000003	город Новоуральск, Победы, 18		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
10697	6	58	\N	55100	42736	\N	54.998833003042101	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Лебедева, 9		0101000020E610000086FF740305A24C4031957EC2D97F4B40
10720	6	58	\N	55100	43747	\N	54.99725405801	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Курчатова, 3	Россия, Челябинская область, городской округ Аша	0101000020E610000077F69507E99F4C4010E7E104A67F4B40
10700	6	58	\N	55100	43261	\N	54.990888302898902	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Коммунистическая, 25	Россия, Челябинская область, Аша	0101000020E610000051888043A8A04C40DAFF006BD57E4B40
10695	6	58	\N	55100	43396	\N	54.987094999999997	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Декабристов, 2	Россия, Челябинская область, Аша	0101000020E6100000D42B6519E2A04C40C6850321597E4B40
10714	6	58	\N	55100	43083	\N	54.998438272635198	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Давыдова, 10	Россия, Челябинская область, Аша	0101000020E610000054ABAFAE0AA44C40B58AFED0CC7F4B40
10693	6	58	\N	55100	43473	\N	54.999021211748001	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, 40 лет Победы, 21	Россия, Челябинская область, Аша	0101000020E610000045D5AF743EA24C4034828DEBDF7F4B40
10691	6	58	\N	55100	43473	\N	55.003174780073799	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, 40 лет Победы, 10	Россия, Челябинская область, Аша	0101000020E6100000DF1B430070A04C401895D40968804B40
10689	6	58	\N	55100	43087	\N	54.999079611196898	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, 22 Партсъезда, 8	Россия, Челябинская область, Аша	0101000020E6100000577BD80B05A44C40390B7BDAE17F4B40
11950	6	58	731	5091	44228	\N	54.403691999999999	Челябинская область, Южноуральский городской округ, поселок Летягино, ул. Нижняя 1		0101000020E6100000876C205D6C904E4013D4F02DAC334B40
11149	6	58	1876	29960	44107	\N	54.980435999999997	Челябинская область, город УстьКатав, село Тюбеляс, ул. Школьная, д. 46а		0101000020E61000003599F1B6D23D4D4018E945ED7E7D4B40
11150	6	58	1876	30008	43979	\N	55.004286999999998	Челябинская область, город УстьКатав, село Минка, ул. Долгая, д. 34	Россия, Челябинская область, городской округ Усть-Катав, поселок Минка	0101000020E610000075C8CD7003204D402366F6798C804B40
11146	6	58	1876	29816	44019	\N	54.919156000000001	Челябинская область, город УстьКатав, поселок Малый Бердяш, ул. Центральная, 2а	Россия, Челябинская область, городской округ Усть-Катав, поселок Малый Бердяш	0101000020E610000076DD5B91980C4D400AF65FE7A6754B40
11151	6	58	1876	30050	43978	\N	55.114302000000002	Челябинская область, город УстьКатав,  деревня Вергаза, ул. Нижняя, д. 3		0101000020E610000032E6AE25E41B4D4007EFAB72A18E4B40
10288	6	58	1626	20590	44215	\N	54.498204000000001	Челябинская область, Пластовский район, село Чукса, Новоселов, 7	Россия, Челябинская область, городской округ Пласт, поселок Чукса	0101000020E6100000CF83BBB376614E40425E0F26C53F4B40
10294	6	58	1626	20902	44054	\N	54.470002000000001	Челябинская область, Пластовский район, село Новый Кумляк, Нагорная, 51а	Россия, Челябинская область, городской округ Пласт, поселок Новый Кумляк	0101000020E6100000DE8D058541394E40FD868906293C4B40
10287	6	58	1626	20486	44056	\N	54.4400580252873	Челябинская область, Пластовский район, село Кочкарь, Советская, 76	Россия, Челябинская область, городской округ Пласт, поселок Кочкарь	0101000020E6100000D5B32094F7654E40ED2B0FD253384B40
10291	6	58	1626	20703	44175	\N	54.485692315549002	Челябинская область, Пластовский район, поселок Котлик, Окружная, 36а	Россия, Челябинская область, городской округ Пласт, поселок Котлик	0101000020E6100000E2B19FC5524A4E40E4F6CB272B3E4B40
10289	6	58	1626	20614	44176	\N	54.455720146419601	Челябинская область, Пластовский район, село Демарино, Школьная, 4	Россия, Челябинская область, городской округ Пласт, поселок Демарино	0101000020E610000067F1626188544E400A117008553A4B40
10290	6	58	1626	20614	43830	\N	54.454819999999998	Челябинская область, Пластовский район, село Демарино, Центральная, 1		0101000020E6100000B2497EC4AF544E408AC8B08A373A4B40
10297	6	58	1626	21060	43488	\N	54.202029000000003	Челябинская область, Пластовский район, село Верхняя Санарка, Ленина, 71		0101000020E6100000895E46B1DC464E40FBEB1516DC194B40
10926	6	58	1626	21010	\N	\N	54.269266000000002	деревня Борисовка, помещение школы	Россия, Челябинская область, городской округ Пласт, поселок Борисовка	0101000020E61000001553E9279C554E405EF6EB4E77224B40
10296	6	58	1626	21010	43490	\N	54.268210986830603	Челябинская область, Пластовский район, село Борисовка, Школьная, 25	Россия, Челябинская область, городской округ Пласт, поселок Борисовка	0101000020E6100000DA1F28B7ED554E40B7B6F0BC54224B40
11608	6	58	1626	21010	43669	\N	54.269266000000002	п.Борисовка, Садовая, 26а		0101000020E61000001553E9279C554E405EF6EB4E77224B40
10222	6	58	1318	55207	44154	\N	54.827605963310603	Челябинская область, город Миасс, с.Устиново, Школа, ул.Зеленая, 6	Россия, Челябинская область, городской округ Миасс, поселок Устиново	0101000020E6100000D9EDB3CA4CFD4D4098FC4FFEEE694B40
10219	6	58	1318	55131	\N	\N	54.992286970760802	Челябинская область, город Миасс, п.Нижний Атлян, ул.Городок	Россия, Челябинская область, городской округ Миасс, поселок Нижний Атлян	0101000020E6100000AD6BB41CE8EF4D407B9FAA42037F4B40
10157	6	58	1318	13929	43895	\N	55.4094443380691	Челябинская область, Карабашский городской округ, поселок Мухаметово, Центральная, клуб поселка	Россия, Челябинская область, городской округ Миасс, поселок Мухаметово	0101000020E6100000382D78D157224E408FC536A968B44B40
11010	6	58	1912	31201	\N	\N	55.580176999999999	"""город Кыштым, пос. Увильды, клуб санатория """"Лесное озеро"""""""	Россия, Челябинская область, городской округ Кыштым, поселок Увильды	0101000020E6100000D00CE2033B3C4E4019726C3D43CA4B40
9856	6	58	1912	31201	43550	\N	55.580176999999999	поселок Увильды, Солнечный переулок, 4	Россия, Челябинская область, городской округ Кыштым, поселок Увильды	0101000020E6100000D00CE2033B3C4E4019726C3D43CA4B40
10995	6	58	1912	55175	43800	\N	55.670436949630002	город Кыштым, пос. Слюдорудник, ул.Школьная, 1	Россия, Челябинская область, городской округ Кыштым, поселок Слюдорудник	0101000020E610000023C0E95DBC2D4E40A1832EE1D0D54B40
10994	6	58	1912	55203	\N	\N	55.849081214536902	город Кыштым, пос. Северный, МОУ ДОУ детский сад №10	Россия, Челябинская область, городской округ Кыштым, поселок Северный	0101000020E61000006022DE3AFF3C4E40D653ABAFAEEC4B40
11750	6	58	6956	45733	44191	\N	54.872382999999999	д. Шумаки, Школьная, 11		0101000020E610000084F23E8EE6A04E400E4B033FAA6F4B40
11726	6	58	6956	55098	43743	\N	54.918777998047702	раб. пос. Роза, Средняя, 35	Россия, Челябинская область, городской округ Коркино, поселок Роза	0101000020E610000007077B1343BA4E4064247B849A754B40
11722	6	58	6956	55098	42713	\N	54.916898272183097	раб. пос. Роза, Проходчиков, 17	Россия, Челябинская область, городской округ Коркино, поселок Роза	0101000020E6100000FC6EBA6587BA4E4048E2E5E95C754B40
11699	6	58	6956	55098	43431	\N	54.917453000000002	раб. пос. Роза, Котельный, 2	Россия, Челябинская область, городской округ Коркино, поселок Роза	0101000020E61000009563B2B8FFB84E40FD4E93196F754B40
11723	6	58	6956	55098	43303	\N	54.9162070408332	раб. пос. Роза, Борьбы, 1	Россия, Челябинская область, городской округ Коркино, поселок Роза	0101000020E6100000D00B772E8CBA4E40E2AE5E4546754B40
11725	6	58	6956	55098	43477	\N	54.917453000000002	раб. пос. Роза, 50 лет Октября, 6	Россия, Челябинская область, городской округ Коркино, поселок Роза	0101000020E61000009563B2B8FFB84E40FD4E93196F754B40
11724	6	58	6956	55098	43320	\N	54.915218167204898	раб. пос. Роза, 50 лет ВЛКСМ, 78	Россия, Челябинская область, городской округ Коркино, поселок Роза	0101000020E610000060C9552C7EB94E40F35A09DD25754B40
11749	6	58	6956	45715	43581	\N	54.942001256735097	пос. ДубровкаЧелябинская, ж.д. станция, Пришкольная, здание школы	Россия, Челябинская область, городской округ Коркино, поселок Дубровка-Челябинская	0101000020E610000060394206F2A84E404FE61F7D93784B40
10146	6	58	1282	13431	\N	\N	55.529465999999999	"""Челябинская область, Карабашский городской округ, пос. Красный Камень, помещение столовой базы отдыха """"Красный Камень"""""""	Россия, Челябинская область, городской округ Карабаш, поселок Красный Камень	0101000020E6100000543882548A374E40062CB98AC5C34B40
10144	6	58	7347	55200	44080	\N	54.967408417626302	г. Златоуст, село Веселовка, ул. Ленина, 58: МУК СЦКС Клуб села Веселовка	Россия, Челябинская область, городской округ Златоуст, поселок Веселовка	0101000020E61000007E5182FE42C74D40C3F17C06D47B4B40
11628	6	58	1659	47851	43113	\N	54.602038	п.Красногорский, Мира, 10а		0101000020E6100000D2890453CD9E4E408179C8940F4D4B40
11629	6	58	1659	47851	43461	\N	54.603529693478102	МО ЕМР, п.Красногорский, Лермонтова, 9	Россия, Челябинская область, городской округ Еманжелинск, поселок Красногорский	0101000020E61000004450357A359E4E40D3139678404D4B40
11626	6	58	1659	47851	42923	\N	54.602038	п.Красногорский, Ленина, 19		0101000020E6100000D2890453CD9E4E408179C8940F4D4B40
11625	6	58	1659	47851	42921	\N	54.602038	п.Красногорский, Западная, 24		0101000020E6100000D2890453CD9E4E408179C8940F4D4B40
11619	6	58	1659	21196	43671	\N	54.784067999999998	п.Зауральский, Пятилетки, 2		0101000020E61000002DB29DEFA79E4E4089EB18575C644B40
11618	6	58	1659	21196	43688	\N	54.7840209027596	п.Зауральский, Новолуговая, 31	Россия, Челябинская область, городской округ Еманжелинск, поселок Зауральский	0101000020E61000004EF2237EC5A04E404930D5CC5A644B40
11620	6	58	1659	21196	42838	\N	54.784067999999998	п.Зауральский, Заводская площадь, 1	Россия, Челябинская область, городской округ Еманжелинск, поселок Зауральский	0101000020E61000002DB29DEFA79E4E4089EB18575C644B40
11622	6	58	1659	21196	42893	\N	54.784067999999998	п.Зауральский, 3й квартал, Здание МОУ СОШ № 15		0101000020E61000002DB29DEFA79E4E4089EB18575C644B40
11621	6	58	1659	21196	43112	\N	54.784067999999998	"""п.Зауральский, 2й квартал, здание """"Детской школы искусств №3"""""""		0101000020E61000002DB29DEFA79E4E4089EB18575C644B40
10765	6	58	1031	55201	44090	\N	55.994157383330702	Челябинская область,  город Верхний Уфалей, поселок Силач, Путевая, 51	Россия, Челябинская область, городской округ Верхний Уфалей, поселок Силач	0101000020E610000029CFBC1C76374E40740B5D8940FF4B40
10760	6	58	1031	55103	43708	\N	55.911569962175598	Челябинская область,   город Верхний Уфалей , поселок Нижний Уфалей, переулок Пролетарский, 1	Россия, Челябинская область, городской округ Верхний Уфалей, поселок Нижний Уфалей	0101000020E61000008E3BA583F5FD4D40E2016553AEF44B40
10759	6	58	1031	55103	42753	\N	55.914076671889298	Челябинская область,  город Верхний Уфалей , поселок Нижний Уфалей, Энгельса, 1	Россия, Челябинская область, городской округ Верхний Уфалей, поселок Нижний Уфалей	0101000020E6100000D02A33A5F5FD4D404D83A27900F54B40
10761	6	58	1031	55103	44216	\N	55.916193999999997	Челябинская область,  город Верхний Уфалей , поселок Нижний Уфалей, Механизаторов, 11а	Россия, Челябинская область, городской округ Верхний Уфалей, поселок Нижний Уфалей	0101000020E6100000BC74931804FE4D404D6551D845F54B40
10741	6	58	1031	8980	\N	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, поселок Строителей, клуб поселка Строителей	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E6100000B56D1805C11D4E405111A7936C054C40
10764	6	58	1031	8980	43964	\N	56.042952538551198	Челябинская область,   город Верхний Уфалей , поселок Каркодин, переулок Школьный, 4	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E61000004031B2648E1D4E40EE21E17B7F054C40
10747	6	58	1031	8980	43086	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Якушева, 25	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E6100000B56D1805C11D4E405111A7936C054C40
10711	6	58	1031	8980	42735	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Шулина, 6		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10750	6	58	1031	8980	43572	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Хохрякова, 18		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10762	6	58	1031	8980	43780	\N	56.042375999999997	Челябинская область,  город Верхний Уфалей , поселок Уфимка, Советская, 1		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10751	6	58	1031	8980	43601	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Садовая, 12		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10758	6	58	1031	8980	44081	\N	56.042375999999997	Челябинская область,   город Верхний Уфалей , поселок Боровой, Полевая, 1		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10755	6	58	1031	8980	42886	\N	56.039108689407598	Челябинская область,  город Верхний Уфалей, Победы, 43	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E610000082C5E1CCAF204E4059FD118601054C40
10754	6	58	1031	8980	42886	\N	56.043144711531497	Челябинская область, город Верхний Уфалей, Победы, 42	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E61000006B7D91D0961D4E4033FE7DC685054C40
10752	6	58	1031	8980	42886	\N	56.043144711531497	Челябинская область, город Верхний Уфалей, Победы, 19	Россия, Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей	0101000020E6100000191D90847D1D4E4033FE7DC685054C40
10756	6	58	1031	8980	43894	\N	56.042375999999997	Челябинская область,  город Верхний Уфалей , поселок Октябрьский, Мира, 1		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10766	6	58	1031	8980	42741	\N	56.042375999999997	Челябинская область,   город Верхний Уфалей , поселок Иткуль, Ленина, 13		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10749	6	58	1031	8980	42741	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Ленина, 169		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10743	6	58	1031	8980	42741	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Ленина, 186		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10746	6	58	1031	8980	43085	\N	56.042375999999997	Челябинская область, город Верхний Уфалей, Карла Маркса, 135а		0101000020E6100000B56D1805C11D4E405111A7936C054C40
10757	6	58	1031	8980	43559	\N	56.042375999999997	Челябинская область,   город Верхний Уфалей , поселок Пригородный, Бакальская, 3		0101000020E6100000B56D1805C11D4E405111A7936C054C40
11581	6	58	840	6222	9784	\N	53.812000658781102	Помещение для голосования: с. Чесма, ул. Чапаева, 28 А, т. (35169) 21753, Адрес УИК: ул. Ленина, 67	Россия, Челябинская область, Чесменский район, поселок Чесма	0101000020E610000093A9825149534E40DFA815A6EFE74A40
14607	6	58	840	6222	42717	\N	53.805853315281396	с. Чесма, Ленина, 67	Россия, Челябинская область, Чесменский район, поселок Чесма	0101000020E610000044A33B889D534E401631EC3026E74A40
11580	6	58	840	19146	43105	\N	53.927745000000002	п. Черноборский, Советская 32		0101000020E61000002DB308C556404E4086032159C0F64A40
11577	6	58	840	46939	43923	\N	53.841413000000003	п. Цвиллинга, Мира 13, 1 этаж, кабинет главы		0101000020E6100000A93121E692964E40F2B6D26BB3EB4A40
11595	6	58	840	19907	43496	\N	53.819625000000002	п. Углицкий, Школьная, 10		0101000020E61000002D793C2D3F264E40F4FDD478E9E84A40
11600	6	58	840	47419	43633	\N	53.794491000000001	с. Тарутино, Школьная, 16		0101000020E61000005EA0A4C002844E40B1FB8EE1B1E54A40
11545	6	58	840	46248	43494	\N	53.896808999999998	п. Тарасовка, 30 лет Победы, 11	Россия, Челябинская область, Чесменский район, поселок Тарасовка	0101000020E6100000E6CFB7054B534E4015E126A3CAF24A40
11592	6	58	840	47242	43106	\N	53.692701	с. Светлое, Пушкина, 25		0101000020E610000050A912656F2F4E400874266DAAD84A40
11582	6	58	840	19240	44141	\N	53.675252	п. Редутово, Гагарина, 27		0101000020E61000007765170CAE614E40804754A86ED64A40
11583	6	58	840	55241	44321	\N	53.497992037702097	п. ПортАртур, Ленина, 19	Россия, Челябинская область, Чесменский район, поселок Порт-Артур	0101000020E6100000ACE122F774294E40B7D5AC33BEBF4A40
11586	6	58	840	47112	43753	\N	53.782507000000003	п. Новый Путь, Центральная, 21		0101000020E6100000FA415DA450344E400FF27A3029E44A40
11598	6	58	840	20071	44036	\N	53.754604861467399	п. Новоукраинский, Первомайская, 46А	Россия, Челябинская область, Чесменский район, поселок Новоукраинский	0101000020E6100000A33EC91D36714E40F4328AE596E04A40
11395	6	58	840	10141	44248	\N	53.682702999999997	п. Новотемирский, Ленина, 10		0101000020E6100000C24CDBBFB2124E40C7F0D8CF62D74A40
11597	6	58	840	20013	43535	\N	53.862695000000002	п. Новоеткульский, Комсомольская 21а		0101000020E6100000E27327D87F714E401CB62DCA6CEE4A40
11386	6	58	840	9687	44122	\N	53.562165999999998	п. Натальинский, Чапаева, 4		0101000020E61000000150C58D5B344E402976340EF5C74A40
11590	6	58	840	47197	43921	\N	53.527613000000002	п. Московский, Дружбы, 292		0101000020E6100000EC884336904A4E40E4F8A1D288C34A40
11599	6	58	840	47381	44192	\N	53.771886000000002	п. Луговой, Центральная, 21		0101000020E6100000F44E05DCF38E4E40C11E1329CDE24A40
11596	6	58	840	19944	43885	\N	53.680550360955699	п. Клубовка, Окружная, 21	Россия, Челябинская область, Чесменский район, поселок Клубовка	0101000020E6100000170FEF39B0764E407AA52C431CD74A40
11594	6	58	840	47270	44165	\N	53.794075999999997	п. Климовка, Ленина, 81		0101000020E6100000EEB5A0F7C60E4E40ED444948A4E54A40
11579	6	58	840	19054	44138	\N	53.872311000000003	п. Камышный, Набережная, 271		0101000020E61000004243FF04178D4E40757808E3A7EF4A40
11585	6	58	840	47103	43871	\N	53.777025999999999	п. Калиновский, Советская, 12		0101000020E61000009067976F7D3E4E402312859675E34A40
11593	6	58	840	47256	44139	\N	53.839548000000001	п. Зеленая Долина, Ленина, 20		0101000020E6100000D7D9907F66124E400BB6114F76EB4A40
10983	6	58	840	22327	43608	\N	53.655880923606901	п. Березинский, Кирова, 13	Россия, Челябинская область, Чесменский район, поселок Березинский	0101000020E6100000C216BB7D56274E40AD889AE8F3D34A40
11584	6	58	840	47077	43612	\N	53.755358999999999	п. Беловка, Центральная 17	Россия, Челябинская область, Чесменский район, поселок Беловка	0101000020E6100000E0D6DD3CD5454E40A0DE8C9AAFE04A40
11589	6	58	840	47171	44190	\N	53.710963	д. Баландино, Набережная, 5		0101000020E6100000333509DE90544E4041D5E8D500DB4A40
10648	6	58	7348	55114	\N	\N	55.217911389496201	Челябинская область, Челябинский городской округ, Тракторозаводский район, пос. Чурилово	Россия, Челябинская область, поселок Чурилово	0101000020E610000033E02C25CBC74E402638F581E49B4B40
10495	6	58	812	30195	\N	\N	54.884177000000001	"""Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, деревня Щапино, Здание конторы Ленинского отделения СПК """"Чебаркуль"""""""	Россия, Челябинская область, Чебаркульский район, поселок Щапино	0101000020E610000052EDD3F1984F4E400D7041B62C714B40
10502	6	58	812	30533	43595	\N	54.985048999999997	Челябинская область, Чебаркульский муниципальный район, Шахматовское сельское поселение, деревня Шахматово, Солнечная, 1А (Здание библиотеки)		0101000020E61000001DAD6A4947514E408FFAEB15167E4B40
11955	6	58	812	53076	43875	\N	54.599873000000002	Помещение для голосования: Челябинская область, Чебаркульский муниципальный район, Варламовское сельское поселение, деревня Шабунина, ул. Колхозная, д. 23 Здание магазина сельпо, УИК: д. Шабунина, Здание ФАП		0101000020E610000038F8C264AA504E40706072A3C84C4B40
10498	6	58	812	30350	\N	\N	54.715055999999997	Челябинская область, Чебаркульский муниципальный район, Филимоновское сельское поселение, село Филимоново, Здание администрации Филимоновского сельского поселения	Россия, Челябинская область, Чебаркульский район, поселок Филимоново	0101000020E61000000C91D3D7F3094E407F677BF4865B4B40
10478	6	58	812	29390	\N	\N	54.706364999999998	Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, деревня Уштаганка, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Уштаганка	0101000020E610000093E2E313B2214E40FF04172B6A5A4B40
10490	6	58	812	6977	\N	\N	54.908535999999998	Помещение для голосования: Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, село Травники, Здание Дома культуры, УИК: с. Травники, Здание библиотеки	Россия, Челябинская область, Чебаркульский район, поселок Травники	0101000020E61000004B5AF10D85474E408C9E5BE84A744B40
10486	6	58	812	53059	\N	\N	54.926678000000003	"""Помещение для голосования: Челябинская область, Чебаркульский муниципальный район, Тимирязевское сельское поселение, поселок Тимирязевский, Здание Дома культуры """"Радуга"""", УИК:п. Тимирязевский,Здание администрации Тимирязевского с/п"""		0101000020E61000001F10E84CDA624E401BF67B629D764B40
10499	6	58	812	30404	\N	\N	54.701397	Челябинская область, Чебаркульский муниципальный район, Филимоновское сельское поселение, деревня Темир, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Темир	0101000020E6100000B398D87C5C154E409A417C60C7594B40
10484	6	58	812	29672	\N	\N	54.828589000000001	Челябинская область, Чебаркульский муниципальный район, Сарафановское сельское поселение, деревня Ступино, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Ступино	0101000020E6100000C5E57805A22F4E40A56950340F6A4B40
94447	6	58	812	55187	43835	\N	54.898347739677902	Чебаркульский район, с. Травники, п. Спутник, ул. Ленина, д. 18-Б	Россия, Челябинская область, Чебаркульский район, поселок Спутник	0101000020E61000001E6FF25B74444E40A8363811FD724B40
10482	6	58	812	29585	\N	\N	54.891064	Челябинская область, Чебаркульский муниципальный район, Сарафановское сельское поселение, деревня Сарафаново, Здание Дома культуры	Россия, Челябинская область, Чебаркульский район, поселок Сарафаново	0101000020E6100000F46E2C280C224E404C5299620E724B40
10489	6	58	812	29888	\N	\N	54.913727000000002	Челябинская область, Чебаркульский муниципальный район, Тимирязевское сельское поселение, деревня Самарка, Здание библиотеки	Россия, Челябинская область, Чебаркульский район, поселок Самарка	0101000020E6100000826F9A3E3B744E40713C9F01F5744B40
10493	6	58	812	30108	\N	\N	54.926011000000003	Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, село Пустозерово, Здание начальной школы	Россия, Челябинская область, Чебаркульский район, поселок Пустозерово	0101000020E61000004C55DAE21A354E403E5E488787764B40
10467	6	58	812	28902	\N	\N	54.643253999999999	Челябинская область, Чебаркульский муниципальный район, Варламовское сельское поселение, деревня Попово, Здание Дома культуры	Россия, Челябинская область, Чебаркульский район, поселок Попово	0101000020E6100000B62C5F97E15B4E40B682A62556524B40
10473	6	58	812	53055	\N	\N	54.769689	Помещение для голосования: Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, деревня Половинка, Здание клуба, УИК: д. Половинка, Здание библиотеки	Россия, Челябинская область, Чебаркульский район, поселок Половинка	0101000020E610000010EB8D5A61304E40A48B4D2B85624B40
10481	6	58	812	29542	\N	\N	55.132510000000003	"""Челябинская область, Чебаркульский муниципальный район, Непряхинское сельское поселение, деревня Нижние Караси, Здание МОУ """"Начальная общеобразовательная школа"""""""	Россия, Челябинская область, Чебаркульский район, поселок Нижние Караси	0101000020E6100000BA69334E43464E404D327216F6904B40
10479	6	58	812	29444	\N	\N	55.080534999999998	Челябинская область, Чебаркульский муниципальный район, Непряхинское сельское поселение, село Непряхино, Здание сельского Дома культуры	Россия, Челябинская область, Чебаркульский район, поселок Непряхино	0101000020E61000004487C09140354E4078978BF84E8A4B40
10464	6	58	812	28764	\N	\N	55.009011999999998	Челябинская область, Чебаркульский муниципальный район, Бишкильское сельское поселение, поселок Мирный, Здание администрации ОСПНБ2	Россия, Челябинская область, Чебаркульский район, поселок Мирный	0101000020E61000007EAB75E272744E40C2A2224E27814B40
10497	6	58	812	30261	\N	\N	54.876609999999999	Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, деревня Мельниково, Здание начальной школы	Россия, Челябинская область, Чебаркульский район, поселок Мельниково	0101000020E6100000E738B709F7384E405CACA8C134704B40
10487	6	58	812	55205	\N	\N	54.9630983452858	Челябинская область, Чебаркульский муниципальный район, Тимирязевское сельское поселение, село Медведево, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Меведево	0101000020E61000001762F54718624E40E86B96CB467B4B40
10492	6	58	812	30049	\N	\N	54.792892999999999	"""Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, деревня Маскайка, Здание МОУ """"Маскайская основная общеобразовательная школа"""""""	Россия, Челябинская область, Чебаркульский район, поселок Маскайка	0101000020E6100000CC4065FCFB444E40191D90847D654B40
10494	6	58	812	53060	43638	\N	54.937525999999998	Помещение для голосования: Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, деревня Малково, ул. Куйбышева, д. 40 Здание кафе, УИК: д. Малково, Здание ФАП		0101000020E61000007EFE7BF0DA2D4E4029931ADA00784B40
10471	6	58	812	29096	\N	\N	54.831060155729602	"""Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, село Кундравы, Здание районного Дома культуры """"Мечта"""""""	Россия, Челябинская область, Чебаркульский район, поселок Кундравы	0101000020E6100000118B1876181D4E40C381902C606A4B40
10476	6	58	812	29317	\N	\N	54.716081000000003	Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, деревня Крыжановка, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Крыжановка	0101000020E610000020F0C000C2314E40BC24CE8AA85B4B40
10488	6	58	812	29879	\N	\N	54.846037000000003	Челябинская область, Чебаркульский муниципальный район, Тимирязевское сельское поселение, деревня Коротаново, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Коротаново	0101000020E6100000997FF44D9A644E405D1ABFF04A6C4B40
10468	6	58	812	29072	\N	\N	54.706251000000002	"""Челябинская область, Чебаркульский муниципальный район, Варламовское сельское поселение, деревня Колотовка, Здание конторы бригады СХПК """"Россия"""""""	Россия, Челябинская область, Чебаркульский район, поселок Колотовка	0101000020E610000032C85D84295A4E4037E2C96E665A4B40
11623	6	58	812	28821	\N	\N	55.012847000000001	п.Ключи, Здание библиотеки поселка Ключи	Россия, Челябинская область, Чебаркульский район, поселок Ключи	0101000020E61000000589EDEE01624E40056D72F8A4814B40
10465	6	58	812	28821	\N	\N	55.013981592538201	Челябинская область, Чебаркульский муниципальный район, Бишкильское сельское поселение, поселок Ключи, Здание ФАП	Россия, Челябинская область, Чебаркульский район, поселок Ключи	0101000020E61000009E094D124B624E40C85D8429CA814B40
10475	6	58	812	29272	\N	\N	54.712414000000003	Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, деревня Ключевка 2я, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Ключевка 2-я	0101000020E6100000A626C11BD2404E40359BC761305B4B40
10496	6	58	812	30257	\N	\N	54.850214999999999	Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, деревня Камбулат, Здание ФАП	Россия, Челябинская область, Чебаркульский район, поселок Камбулат	0101000020E61000000BEC3191D2484E40C9C859D8D36C4B40
10470	6	58	812	29053	\N	\N	54.743291999999997	Челябинская область, Чебаркульский муниципальный район, Варламовское сельское поселение, деревня Звягино, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Звягино	0101000020E6100000DC4603780B604E4070B03731245F4B40
10500	6	58	812	30453	\N	\N	54.655526999999999	Челябинская область, Чебаркульский муниципальный район, Филимоновское сельское поселение, деревня Зауралово, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Зауралово	0101000020E61000009AD18F86531A4E408F52094FE8534B40
10421	6	58	941	26812	43858	\N	54.556215999999999	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, село Соколовское, Партизанская, 28		0101000020E61000002BA6D24F38254E4087C1FC1532474B40
10504	6	58	812	30661	\N	\N	54.964922999999999	Челябинская область, Чебаркульский муниципальный район, Шахматовское сельское поселение, деревня Запивалово, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Запивалово	0101000020E6100000AE7FD767CE4E4E404014CC98827B4B40
10483	6	58	812	29626	\N	\N	54.906896000000003	Челябинская область, Чебаркульский муниципальный район, Сарафановское сельское поселение, деревня Десятилетие, Здание детского сада	Россия, Челябинская область, Чебаркульский район, поселок Десятилетие	0101000020E6100000F4328AE596264E40C66F0A2B15744B40
10480	6	58	812	29496	\N	\N	55.144927000000003	Челябинская область, Чебаркульский муниципальный район, Непряхинское сельское поселение, деревня Верхние Караси, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Верхние Караси	0101000020E61000001956F146E6354E4059A7CAF78C924B40
10466	6	58	812	28890	\N	\N	54.625473999999997	Челябинская область, Чебаркульский муниципальный район, Варламовское сельское поселение, село Варламово, Здание Дома культуры	Россия, Челябинская область, Чебаркульский район, поселок Варламово	0101000020E61000003271AB2006564E40C83F33880F504B40
10472	6	58	812	29147	\N	\N	54.847555999999997	Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, деревня Бутырки, Здание ФАП	Россия, Челябинская область, Чебаркульский район, поселок Бутырки	0101000020E61000002F6D382C0D1A4E40A8C30AB77C6C4B40
10485	6	58	812	29729	\N	\N	54.928137	"""Челябинская область, Чебаркульский муниципальный район, Сарафановское сельское поселение, деревня Боровое, Здание МОУ """"Боровская основная общеобразовательная школа"""""""	Россия, Челябинская область, Чебаркульский район, поселок Боровое	0101000020E61000002D5DC136E2294E40919A7631CD764B40
10474	6	58	812	53057	\N	\N	54.647651000000003	Помещение для голосования: Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, деревня Большаково, Здание клуба, УИК: д. Большаково, Здание библиотеки	Россия, Челябинская область, Чебаркульский район, поселок Большаково	0101000020E610000022C495B377364E40611C5C3AE6524B40
10477	6	58	812	29354	\N	\N	54.731710999999997	Челябинская область, Чебаркульский муниципальный район, Кундравинское сельское поселение, деревня Болотово, Здание библиотеки	Россия, Челябинская область, Чебаркульский район, поселок Болотово	0101000020E6100000C4EBFA05BB1F4E40CD8FBFB4A85D4B40
10462	6	58	812	53054	\N	\N	54.983044999999997	Помещение для голосования: Челябинская область, Чебаркульский муниципальный район, Бишкильское сельское поселение, поселок Бишкиль, Здание Дома культуры, УИК: п. Бишкиль, Здание администрации Бишкильского с/п	Россия, Челябинская область, Чебаркульский район, поселок Бишкиль, станция Бишкиль	0101000020E610000078EC67B114614E4087BF266BD47D4B40
10491	6	58	812	30021	\N	\N	54.845612000000003	Челябинская область, Чебаркульский муниципальный район, Травниковское сельское поселение, деревня Барсуки, Здание начальной школы	Россия, Челябинская область, Чебаркульский район, поселок Барсуки	0101000020E6100000147B681F2B524E40768D96033D6C4B40
10503	6	58	812	30592	\N	\N	55.010333000000003	Челябинская область, Чебаркульский муниципальный район, Шахматовское сельское поселение, деревня Барановка, Здание ФАП	Россия, Челябинская область, Чебаркульский район, поселок Барановка	0101000020E610000015E5D2F885414E40E8887C9752814B40
10501	6	58	812	30502	\N	\N	54.710641000000003	Челябинская область, Чебаркульский муниципальный район, Филимоновское сельское поселение, деревня АлтынТаш, Здание клуба	Россия, Челябинская область, Чебаркульский район, поселок Алтынташ	0101000020E6100000A6B8AAECBBF64D402F19C748F65A4B40
10433	6	58	941	27336	44031	\N	54.417509000000003	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, деревня Яринка, Строителей, 4		0101000020E61000006D7022FAB5FF4D40916456EF70354B40
10431	6	58	941	7670	44188	\N	54.354142000000003	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, поселок Фоминский, ул.Клубная 15 (1 этаж) актовый зал сельского клуба		0101000020E6100000C1A90F24EFE04D40ED116A86542D4B40
10423	6	58	941	26883	43210	\N	54.37771	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, село Уйское, Таращенко, 67		0101000020E61000002C0C91D3D7FF4D40A3AF20CD58304B40
10422	6	58	941	26883	43073	\N	54.37771	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, село Уйское, Пионерская, 41		0101000020E61000002C0C91D3D7FF4D40A3AF20CD58304B40
10425	6	58	941	26883	42872	\N	54.37771	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, село Уйское, Ленина, 86		0101000020E61000002C0C91D3D7FF4D40A3AF20CD58304B40
10424	6	58	941	26883	42872	\N	54.371897713415898	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, село Уйское, Ленина, 22	Россия, Челябинская область, Уйский район, поселок Уйское	0101000020E61000000ADAE4F049FF4D4052B9895A9A2F4B40
10394	6	58	941	25570	9736	\N	54.420127256635503	Челябинская область, Уйский муниципальный район, Беловское сельское поселение, поселок Токмасский, Ленина, 20	Россия, Челябинская область, Уйский район, поселок Токмасский	0101000020E6100000B2B96A9E23224E405395B6B8C6354B40
10404	6	58	941	26051	44185	\N	54.527923000000001	Челябинская область, Уйский муниципальный район, Ларинское сельское поселение, поселок Речной, Клубная, 6		0101000020E610000043705CC64DEF4D4032E719FB92434B40
10981	6	58	941	26306	42902	\N	54.171402999999998	Петрозаводское сельское поселение, село Петропавловка, Петропавловская средняя школа, ул.Лесная, д.1		0101000020E6100000B5503239B5E74D40D8B79388F0154B40
10410	6	58	941	26306	43634	\N	54.171402999999998	Челябинская область, Уйский муниципальный район, Сельское поселение Петропавловское, село Петропавловка, Ленина, 18		0101000020E6100000B5503239B5E74D40D8B79388F0154B40
10430	6	58	941	27229	43853	\N	54.446683298226901	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, поселок Октябрьский, Лесная, 2	Россия, Челябинская область, Уйский район, поселок Октябрьский	0101000020E6100000C7D8092FC1EF4D40EF5696E82C394B40
10420	6	58	941	26782	44075	\N	54.574762999999997	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, село Никольское, Центральная, 150		0101000020E61000009A07B0C8AF154E40B5F97FD591494B40
10406	6	58	941	26138	43685	\N	54.2761	Челябинская область, Уйский муниципальный район, Нижнеусцелемовское сельское поселение, село Нижнеусцелемово, Ленина, 13		0101000020E610000040DF162CD5FF4D407A36AB3E57234B40
10412	6	58	941	26330	43557	\N	54.574992999999999	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, поселок Мирный, Мира, 18		0101000020E610000026512FF834274E40E736E15E99494B40
10411	6	58	941	26330	43557	\N	54.574992999999999	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, поселок Мирный, Мира, 3		0101000020E610000026512FF834274E40E736E15E99494B40
10405	6	58	941	26080	43637	\N	54.467448971260502	Челябинская область, Уйский муниципальный район, Масловское сельское поселение, село Маслово, Ленина, 9	Россия, Челябинская область, Уйский район, поселок Маслово	0101000020E6100000A48AE255D6024E4022C66B5ED53B4B40
10392	6	58	941	7616	43886	\N	54.218110000000003	Челябинская область, Уйский муниципальный район, Аминевское сельское поселение, деревня Магадеево, Школьная, д. 1  (1 этаж) актовый.зал сельского клуба		0101000020E6100000EDD808C4EB244E401D774A07EB1B4B40
10419	6	58	941	26720	44184	\N	54.338979999999999	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, поселок Лесной, Механическая, 47		0101000020E6100000DAA84E07B2304E40C1FF56B2632B4B40
10418	6	58	941	26689	43944	\N	54.596963000000002	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, поселок Лебедевка, Зеленая, 137		0101000020E6100000B2D991EA3B294E4006F69848694C4B40
10400	6	58	941	25852	42867	\N	54.575572000000001	Челябинская область, Уйский муниципальный район, Ларинское сельское поселение, село Ларино, Дворцовая, 12		0101000020E61000001288D7F50BFA4D40253FE257AC494B40
10399	6	58	941	25812	43503	\N	54.3523	Челябинская область, Уйский муниципальный район, Кумлякское сельское поселение, село Кумляк, Нагорная, 33		0101000020E6100000F2B1BB4049274E40BE30992A182D4B40
10417	6	58	941	26634	43851	\N	54.603394000000002	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, деревня Краснокаменка, Ключевая, 42		0101000020E61000009BE61DA7E81C4E40234DBC033C4D4B40
10401	6	58	941	25908	44072	\N	54.530625000000001	Челябинская область, Уйский муниципальный район, Ларинское сельское поселение, деревня Кочнево, Центральная, 5А		0101000020E61000009D0E643DB5FA4D4052B81E85EB434B40
10396	6	58	941	25680	43553	\N	54.150351999999998	Челябинская область, Уйский муниципальный район, Кидышевское сельское поселение, село Кидыш, Ленина, 7А		0101000020E6100000E1455F419A0B4E40B071FDBB3E134B40
10416	6	58	941	26597	43948	\N	54.45035	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, поселок Зерновой, Садиковая, 28		0101000020E6100000E6ADBA0ED52A4E4076E09C11A5394B40
10415	6	58	941	26536	43888	\N	54.504133000000003	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, поселок Заозерный, Верхняя, 62		0101000020E6100000D32F116F9D2D4E40CDEA1D6E87404B40
10402	6	58	941	55206	44105	\N	54.481369814088801	Челябинская область, Уйский муниципальный район, Ларинское сельское поселение, деревня Замотохино, Верхняя, 15	Россия, Челябинская область, Уйский район	0101000020E6100000ED82C13577FA4D4044A33B889D3D4B40
10398	6	58	941	25761	43850	\N	54.179470999999999	Челябинская область, Уйский муниципальный район, Кидышевское сельское поселение, деревня Гусары, Советская		0101000020E610000066DD3F16A2234E404BCADDE7F8164B40
10429	6	58	941	27188	44187	\N	54.345730000000003	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, поселок Горки, Нагорная, 12А		0101000020E610000028B7ED7BD4014E40809F71E1402C4B40
10428	6	58	941	27141	43946	\N	54.324095999999997	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, поселок Глазуновка, Солнечная, 8		0101000020E610000004AF963B33F54D40D8614CFA7B294B40
10403	6	58	941	25988	43941	\N	54.483419067305398	Челябинская область, Уйский муниципальный район, Ларинское сельское поселение, село Выдрино, Школьная, 2	Россия, Челябинская область, Уйский район, поселок Выдрино	0101000020E61000002AC423F1F2EA4D40ECA17DACE03D4B40
10414	6	58	941	26513	44077	\N	54.586565999999998	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, поселок Восточный, Кировская, 7А		0101000020E61000007B4E7ADFF8424E4007793D98144B4B40
10350	6	58	135	23474	44173	\N	54.241098999999998	поселок Суналы, Мира, 11		0101000020E610000068041BD7BFE14E40950C0055DC1E4B40
10427	6	58	941	21195	44078	\N	54.369323999999999	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, село Воронино, Мира, 7		0101000020E6100000E0F2583332EA4D405FD04202462F4B40
10408	6	58	941	26219	43849	\N	54.245176999999998	Челябинская область, Уйский муниципальный район, Нижнеусцелемовское сельское поселение, поселок Вишневка, Молодежная, 8/2		0101000020E61000000E4A9869FB054E409E5DBEF5611F4B40
10395	6	58	941	25634	43590	\N	54.337798999999997	Челябинская область, Уйский муниципальный район, Вандышевское сельское поселение, деревня Вандышевка, Ленина, 20		0101000020E61000008E3BA583F50B4E408DCF64FF3C2B4B40
10413	6	58	941	26424	43950	\N	54.561736457789699	Челябинская область, Уйский муниципальный район, Соколовское сельское поселение, деревня Булатово, Кульмухаметова, 27	Россия, Челябинская область, Уйский район, поселок Булатово	0101000020E6100000A986FD9E58314E40317E1AF7E6474B40
10426	6	58	941	27064	44076	\N	54.303733000000001	Челябинская область, Уйский муниципальный район, Уйское сельское поселение, деревня Брюхово, Ленина, 11		0101000020E6100000742497FF90004E40A5DB12B9E0264B40
10397	6	58	941	25737	44071	\N	54.139809999999997	Челябинская область, Уйский муниципальный район, Кидышевское сельское поселение, поселок Бирюковский, Школьная, 2		0101000020E61000002CD32F116F1F4E40AED3484BE5114B40
10407	6	58	941	26146	43852	\N	54.249954000000002	Челябинская область, Уйский муниципальный район, Нижнеусцелемовское сельское поселение, поселок Березовка, Школьная, 28		0101000020E61000003E59315C1DF44D4090C01F7EFE1F4B40
10393	6	58	941	25544	43551	\N	54.420223	Челябинская область, Уйский муниципальный район, Беловское сельское поселение, село Белово, Космонавтов, 25		0101000020E6100000A35BAFE941114E40750305DEC9354B40
10391	6	58	941	25414	43486	\N	54.199331999999998	Челябинская область, Уйский муниципальный район, Аминевское сельское поселение, село Аминево, Молодежная, 11А		0101000020E6100000293C6876DD0F4E40EC8502B683194B40
11932	6	58	439	55164	43710	\N	54.372620228662697	Челябинская область, Увельский муниципальный район, Хуторское сельское поселение, село Хуторка, Лесная 1 А	Россия, Челябинская область, Увельский район, хутор Хуторка	0101000020E61000002BC24D4695C34E40F2EA1C03B22F4B40
11920	6	58	439	3476	43146	\N	54.543402	Челябинская область, Увельский муниципальный район, Хомутининское сельское поселение, село Хомутинино, Луначарского, 57		0101000020E61000004694F6065FB84E405E4A5D328E454B40
11919	6	58	439	55237	44316	\N	54.531186881011102	Челябинская область, Увельский муниципальный район, Кичигинское сельское поселение, Жд. станция Формачево, Станционная, 16	Россия, Челябинская область, Увельский район, поселок Формачево	0101000020E61000009A7D1EA33CA74E40BA8784EFFD434B40
11854	6	58	439	2418	43679	\N	54.436977217874897	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Увельский, Щербакова, 8	Россия, Челябинская область, Увельский район, поселок Увельский	0101000020E6100000029F1F4608AF4E40560DC2DCEE374B40
11905	6	58	439	2418	43145	\N	54.4410046564795	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Увельский, У. Громовой, 10	Россия, Челябинская область, Увельский район, поселок Увельский	0101000020E610000009C3802557AD4E40AD2F12DA72384B40
11904	6	58	439	2418	42712	\N	54.437277413354103	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Увельский, Советская, 7	Россия, Челябинская область, Увельский район, поселок Увельский	0101000020E6100000E108522976AC4E40812557B1F8374B40
11903	6	58	439	2418	42712	\N	54.435980068331702	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Увельский, Советская, 24	Россия, Челябинская область, Увельский район, поселок Увельский	0101000020E6100000C4B3041901AF4E40E4DA5031CE374B40
11901	6	58	439	2418	42712	\N	54.429274999999997	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Увельский, ул. Советская, 38		0101000020E6100000795BE9B5D9AE4E40C5FEB27BF2364B40
11906	6	58	439	2418	43681	\N	54.438281566807099	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Увельский, Сафонова, 2Б	Россия, Челябинская область, Увельский район, поселок Увельский	0101000020E6100000F16778B306AF4E407636E49F19384B40
11902	6	58	439	2418	43143	\N	54.429274999999997	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Увельский, Кирова, 12		0101000020E6100000795BE9B5D9AE4E40C5FEB27BF2364B40
11918	6	58	439	3370	43661	\N	54.545850999999999	Челябинская область, Увельский муниципальный район, Кичигинское сельское поселение, поселок Синий Бор, Центральная, 4		0101000020E6100000300F99F221AA4E4094BE1072DE454B40
11923	6	58	439	3675	42963	\N	54.440277000000002	Челябинская область, Увельский муниципальный район, Рождественское сельское поселение, село Рождественка, Свободы, 58А		0101000020E61000000D6FD6E07DD74E402B172AFF5A384B40
11921	6	58	439	3576	43660	\N	54.344144999999997	Челябинская область, Увельский муниципальный район, Половинское сельское поселение, село Половинка, пер. Колхозный, 1		0101000020E6100000CA87A06AF4AA4E407C0A80F10C2C4B40
11912	6	58	439	3021	43904	\N	54.609057	Челябинская область, Увельский муниципальный район, Каменское сельское поселение, поселок Подгорный, Гагарина, 3		0101000020E61000005A0F5F268A844E402F336C94F54D4B40
10390	6	58	135	25385	43937	\N	54.017628000000002	поселок Стрелецк, Центральная, 8		0101000020E61000004BC972124A494E4038BF61A241024B40
11929	6	58	439	3958	43664	\N	54.503365000000002	Челябинская область, Увельский муниципальный район, Петровское сельское поселение, село Петровское, Школьная, 30		0101000020E61000006075E44867EE4E40BC79AA436E404B40
11977	6	58	439	6526	43586	\N	54.378869000000002	Челябинская область, Увельский муниципальный район, Хуторское сельское поселение, село Песчаное, Центральная, 25Б		0101000020E6100000EC1681B1BEB54E40EF3B86C77E304B40
10346	6	58	439	6526	42868	\N	54.378869000000002	село Песчаное, Советская, 17		0101000020E6100000EC1681B1BEB54E40EF3B86C77E304B40
11916	6	58	439	3261	43505	\N	54.537776964747103	Челябинская область, Увельский муниципальный район, Кичигинское сельское поселение, поселок Нагорный, Школьная, 5	Россия, Челябинская область, Увельский район, поселок Нагорный	0101000020E6100000A48E8EAB91A54E403FC571E0D5444B40
11926	6	58	439	3818	44017	\N	54.348880360640301	Челябинская область, Увельский муниципальный район, Мордвиновское сельское поселение, село Мордвиновка, Школьная, 18А	Россия, Челябинская область, Увельский район, поселок Мордвиновка	0101000020E6100000B03BDD79E2EF4E403F1D8F19A82C4B40
11928	6	58	439	3896	43902	\N	54.639173999999997	Челябинская область, Увельский муниципальный район, Красносельское сельское поселение, поселок Михири, Мира, 34		0101000020E6100000AB24B20FB28C4E400C3A2174D0514B40
11978	6	58	439	6590	44202	\N	54.350211999999999	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, поселок Мирный, Первостроителей, 4		0101000020E61000006B6281AFE8B44E4058552FBFD32C4B40
11931	6	58	439	4082	44200	\N	54.452821	Челябинская область, Увельский муниципальный район, Петровское сельское поселение, село Малое Шумаково, Центральная, 15		0101000020E6100000BC0853944B074F4094F8DC09F6394B40
11927	6	58	439	3859	42665	\N	54.575272218584303	Челябинская область, Увельский муниципальный район, Красносельское сельское поселение, село Красносельское, Островского, 2	Россия, Челябинская область, Увельский район, поселок Красносельское	0101000020E6100000268BFB8F4C9B4E40FA264D83A2494B40
11908	6	58	439	2799	44201	\N	54.487515999999999	Челябинская область, Увельский муниципальный район, Хомутининское сельское поселение, деревня Копанцево, Набережная, 16 А		0101000020E6100000BDFDB968C8B24E406C239EEC663E4B40
11924	6	58	439	3685	44223	\N	54.483269	Челябинская область, Увельский муниципальный район, Рождественское сельское поселение, деревня Ключи, Рабочая, 21		0101000020E61000000D1B65FD66D84E40D71533C2DB3D4B40
11915	6	58	439	3148	43665	\N	54.509214	Челябинская область, Увельский муниципальный район, Кичигинское сельское поселение, село Кичигино, Мира, 60		0101000020E61000003B1C5DA5BBA14E402A55A2EC2D414B40
11914	6	58	439	3148	42714	\N	54.512260479159501	Челябинская область, Увельский муниципальный район, Кичигинское сельское поселение, село Кичигино, Комсомольская, 29	Россия, Челябинская область, Увельский район, поселок Кичигино	0101000020E610000011381268B0A14E40448655BC91414B40
11910	6	58	439	2908	44040	\N	54.455668000000003	Челябинская область, Увельский муниципальный район, Увельское сельское поселение, село Катаево, Увельская, 24		0101000020E6100000DD5CFC6D4FB24E40B8EA3A54533A4B40
11911	6	58	439	3007	42955	\N	54.522807999999998	Челябинская область, Увельский муниципальный район, Каменское сельское поселение, поселок Каменский, Советская, 26		0101000020E610000084471B47AC874E40280B5F5FEB424B40
11925	6	58	439	3771	43872	\N	54.536298000000002	Челябинская область, Увельский муниципальный район, Рождественское сельское поселение, село Дуванкуль, Молодежная, 7Б		0101000020E6100000F4DF83D72EC94E408274B169A5444B40
11922	6	58	439	3588	43663	\N	54.390714000000003	Челябинская область, Увельский муниципальный район, Половинское сельское поселение, деревня Водопойка, Западная, 31		0101000020E61000000BD0B69A759E4E40700B96EA02324B40
11930	6	58	439	3987	43908	\N	54.485776644857999	Челябинская область, Увельский муниципальный район, Петровское сельское поселение, деревня Большое Шумаково, Новая, 26	Россия, Челябинская область, Увельский район, поселок Большое Шумаково	0101000020E6100000520ABABDA4F14E401213D4F02D3E4B40
11913	6	58	439	3124	43629	\N	54.528958000000003	Челябинская область, Увельский муниципальный район, Каменское сельское поселение, поселок Березовка, Школьная 2 А		0101000020E61000004D327216F6964E40927A4FE5B4434B40
10365	6	58	135	24191	42624	\N	54.1897853125949	поселок Ясные Поляны, Ленина, 54	Россия, Челябинская область, Троицкий район, поселок Ясные Поляны	0101000020E6100000618A7269FCB24E40BC22F8DF4A184B40
8939	6	58	135	18859	43917	\N	54.115903000000003	поселок Шантарино, Школьная, 1а	Россия, Челябинская область, Троицкий район, поселок Шантарино	0101000020E6100000A5315A47551D4F401041D5E8D50E4B40
10368	6	58	135	45701	44180	\N	54.094470999999999	поселок Чкалова, Центральная, 19		0101000020E6100000B54E5C8E57A44E40D0B52FA0170C4B40
10389	6	58	135	46114	43943	\N	54.017929000000002	поселок Черноречье, Ленина, 1		0101000020E6100000BC94BA641C554E4033535A7F4B024B40
10378	6	58	135	45885	43619	\N	54.125407000000003	поселок Целинный, Садовая, 19		0101000020E610000064575A46EA794E4041D829560D104B40
10370	6	58	135	45732	43838	\N	54.044286999999997	поселок Херсонский, Центральная, 502		0101000020E610000052B648DA8D9C4E40A8514832AB054B40
10351	6	58	135	23528	43909	\N	54.162116112319502	село Травянка, Луговая, 41	Россия, Челябинская область, Троицкий район, поселок Травянка	0101000020E6100000A88DEA7420E94E4044149337C0144B40
11591	6	58	135	24701	43922	\N	54.265774	п. Тогузак, Спутника, 19		0101000020E610000091442FA358904E404510E7E104224B40
10375	6	58	135	24701	43938	\N	54.265774	поселок Тогузак, Левобережная, 15а		0101000020E610000091442FA358904E404510E7E104224B40
10302	6	58	135	21272	43958	\N	54.074073112308703	Челябинская область, Пластовский район, село Степное, Центральная, 21	Россия, Челябинская область, Троицкий район, поселок Степное	0101000020E6100000B5DFDA8992344E4020425C397B094B40
11324	6	58	135	21272	43571	\N	54.070741493189601	село Степное, Труда, 1	Россия, Челябинская область, Троицкий район, поселок Степное	0101000020E61000005FD1ADD7F4344E4040BE840A0E094B40
10303	6	58	135	21272	43602	\N	54.070791999999997	Адрес УИК в день голосования: Челябинская область, Пластовский район, село Степное, улица Комсомольская, дом 28, Адрес УИК: улица 50 лет Октября, 31		0101000020E6100000C2189128B4344E40C26856B60F094B40
10301	6	58	135	21237	43949	\N	53.981023999999998	Челябинская область, Пластовский район, село Степнинское, Центральная, 18а		0101000020E61000009964E42CEC354E40A94BC63192FD4A40
10353	6	58	135	23624	43840	\N	54.126974843679797	поселок Сливной, Центральная, 17	Россия, Челябинская область, Троицкий район, поселок Сливной	0101000020E610000040170D198FDA4E406E3480B740104B40
10385	6	58	135	25153	43683	\N	54.0891834909241	поселок Скалистый, Школьная, 11	Россия, Челябинская область, Троицкий район, поселок Скалистый	0101000020E61000001BA19FA9D7934E40F92D3A596A0B4B40
10343	6	58	135	23150	43932	\N	54.287039	деревня Сбитнево, Центральная, 18		0101000020E6100000FC54151A88094F4099D6A6B1BD244B40
10380	6	58	135	45916	43844	\N	54.203151371713801	поселок Репино, Первомайская, 2	Россия, Челябинская область, Троицкий район, поселок Репино	0101000020E610000091D26C1E87874E4029931ADA001A4B40
10377	6	58	135	45858	44182	\N	54.247549999999997	поселок Полесье, Заречная, 3		0101000020E6100000D672672618804E40F90FE9B7AF1F4B40
10383	6	58	135	46001	43787	\N	54.019347000000003	село Подгорное, Набережная, 3		0101000020E61000006403E962D36A4E404B2366F679024B40
10361	6	58	135	45539	43939	\N	54.091254999999997	поселок Плодовый, Набережная, 2а		0101000020E6100000EF92382BA2B24E40594C6C3EAE0B4B40
10371	6	58	135	24525	43936	\N	54.122669872534097	поселок Осиповка, Центральная, 12	Россия, Челябинская область, Троицкий район, поселок Осиповка	0101000020E6100000FE62B66455884E40A4198BA6B30F4B40
10366	6	58	135	23020	43556	\N	54.139957000000003	поселок Новый Мир, Южная, 19		0101000020E6100000E2AB1DC539B04E4053EC681CEA114B40
11588	6	58	135	23020	43757	\N	54.139957000000003	п. Новый Мир, 30 лет Победы, 11		0101000020E6100000E2AB1DC539B04E4053EC681CEA114B40
10367	6	58	135	24309	43202	\N	54.126430999999997	село Нижняя Санарка, Советская, 17		0101000020E6100000E78C28ED0D9A4E40AC1919E42E104B40
8570	6	58	135	312	44068	\N	54.108249999999998	поселок Морозкино, Школьная, 47		0101000020E610000055DD239BABD24E4060E5D022DB0D4B40
10349	6	58	135	23425	43843	\N	54.241067999999999	поселок Метличье, Северная, 1	Россия, Челябинская область, Троицкий район, поселок Метличье	0101000020E6100000E31A9FC9FED74E405A0EF450DB1E4B40
10386	6	58	135	46059	43945	\N	54.004564000000002	поселок Логовой, Школьная, 1а	Россия, Челябинская область, Троицкий район, поселок Логовой	0101000020E610000010070951BE884E40965E9B8D95004B40
11654	6	58	135	48418	44007	\N	54.156067999999998	село Лебедевка, Комсомольская, 6		0101000020E6100000C3D5011077C74E40DFF94509FA134B40
10374	6	58	135	24656	44062	\N	54.244408071108403	поселок Лагерный, Садовая, 1	Россия, Челябинская область, Троицкий район, поселок Лагерный	0101000020E6100000CADDE7F868A14E40BD70E7C2481F4B40
10360	6	58	135	23966	44057	\N	54.190335362968398	поселок Кумысное, Кольцевая, 6а	Россия, Челябинская область, Троицкий район, поселок Кумысное	0101000020E6100000C51F459DB9C14E405F24B4E55C184B40
10376	6	58	135	45838	44181	\N	54.305135999999997	поселок Краснооктябрьский, Центральная, 17		0101000020E6100000D28F8653E68E4E40876A4AB20E274B40
10381	6	58	135	24968	43842	\N	54.209328872953201	село Кособродка, Красногвардейская, 23	Россия, Челябинская область, Троицкий район, поселок Кособродка	0101000020E61000000492B06F27714E405C8DEC4ACB1A4B40
10358	6	58	135	23869	43552	\N	54.1162788401748	село Клястицкое, Школьная, 14	Россия, Челябинская область, Троицкий район, поселок Клястицкое	0101000020E61000004F78094E7DC04E40151BF33AE20E4B40
9183	6	58	135	40275	9694	\N	54.048543000000002	село Ключевка, Школьная, 11	Россия, Челябинская область, Троицкий район, поселок Ключевка	0101000020E6100000268E3C1059004F4091B932A836064B40
10356	6	58	135	23760	43627	\N	54.025729458812897	Троицкий район, поселок Кварцитный, ул. Собко 22, 1этаж	Россия, Челябинская область, Троицкий район, поселок Кварцитный	0101000020E61000007D76C075C5DE4E4086C77E164B034B40
10362	6	58	135	24050	43493	\N	54.250968999999998	село Карсы, переулок Кооперативный, 9а		0101000020E61000009A93179980B54E40A8A78FC01F204B40
10347	6	58	135	23333	43837	\N	54.176788999999999	Троицкий район, поселок Каракулька, Молодежная, 1а		0101000020E61000008C2C996379F94E4072A59E05A1164B40
10363	6	58	135	45584	43934	\N	54.337252999999997	поселок Карабаново, Центральная, 26а		0101000020E61000004815C5ABACB14E402BBD361B2B2B4B40
10382	6	58	135	25025	43845	\N	54.130297497568201	поселок Каменная Санарка, Школьная, 9а	Россия, Челябинская область, Троицкий район, поселок Каменная Санарка	0101000020E61000009A7ADD22305E4E402AE27492AD104B40
9612	6	58	135	19611	43554	\N	54.006273	поселок Каменная Речка, Школьная, 19		0101000020E610000026E1421EC1F54E4085ECBC8DCD004B40
10384	6	58	135	46013	44034	\N	54.050004528252003	поселок Каменка, Мира, 3	Россия, Челябинская область, Троицкий район, поселок Каменка	0101000020E6100000C3B81B446B714E4078D1579066064B40
10364	6	58	135	24162	43935	\N	54.288069	село Кадымцево, Рабочая, 12		0101000020E6100000B01D8CD827C04E40E7FEEA71DF244B40
9626	6	58	135	49134	44155	\N	53.970984000000001	поселок Искра, Мира, 15а		0101000020E61000002A5437177F694E403A78263449FC4A40
10345	6	58	135	23251	44061	\N	54.237873999999998	деревня Епанишниково, Набережная, 3		0101000020E6100000C8444AB3791C4F40CB48BDA7721E4B40
10348	6	58	135	49585	43930	\N	54.200769999999999	село Дробышево, Школьная, 1		0101000020E6100000C7D8092FC1D34E404B02D4D4B2194B40
10379	6	58	135	45888	44065	\N	54.168641000000001	поселок Дачный, Трудовая, 3а		0101000020E61000009544F641967B4E40E3E13D0796154B40
10344	6	58	135	23187	43931	\N	54.354509	деревня Бурханкуль, Центральная, 40		0101000020E61000006D382C0DFC124F409F91088D602D4B40
10355	6	58	135	45437	42622	\N	54.045064000000004	село Бобровка, Культуры, 1а		0101000020E6100000944DB9C2BBDE4E400D1D3BA8C4054B40
10357	6	58	135	23798	43933	\N	54.092353000000003	Троицкий район, поселок Березники, Новая, 51, 1 этаж		0101000020E6100000C2A38D23D6E04E4000581D39D20B4B40
10387	6	58	135	25225	43846	\N	54.033099	поселок Белоключевка, Школьная, 1а		0101000020E6100000736891ED7C814E40E14389963C044B40
10372	6	58	135	24554	43839	\N	54.187533000000002	поселок Белокаменка, Лассаля, 34		0101000020E6100000033E3F8C108A4E40DCF5D21401184B40
10342	6	58	135	49492	43549	\N	54.246375999999998	село Белозеры, Просвещения, 5		0101000020E61000004162BB7B80164F407842AF3F891F4B40
10823	6	58	135	45599	44066	\N	53.928477000000001	п. Безводный, Центральная, 19		0101000020E6100000A73B4F3C67594E404A0B9755D8F64A40
11772	6	58	56	428	\N	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Ленинский район, Гагарина, 56	Россия, Челябинская область, Сосновский район, поселок Южно-Челябинский Прииск	0101000020E6100000C5C9FD0E459B4E401F86562767824B40
11824	6	58	56	428	42824	\N	55.018773000000003	Челябинская область, Челябинский городской округ, Советский район, Федорова, 12		0101000020E6100000C5C9FD0E459B4E401F86562767824B40
11884	6	58	56	1423	43903	\N	55.550952000000002	Челябинская область, Сосновский муниципальный район, Саккуловское сельское поселение, деревня Чишма, Центральная, 32		0101000020E6100000D25625917DAE4E4039D55A9885C64B40
11898	6	58	56	2213	43544	\N	55.01708	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, село Чипышево, Советская, 9 А		0101000020E610000012C138B8748E4E4035B56CAD2F824B40
11877	6	58	56	1027	44011	\N	55.320313217584498	Челябинская область, Сосновский муниципальный район, Мирненское сельское поселение, деревня Ужевка, Трактовая, 1 Г	Россия, Челябинская область, Сосновский район, поселок Ужевка	0101000020E6100000D0EE906280A04E40E8BD310400A94B40
11852	6	58	56	32069	43534	\N	55.103966	Челябинская область, Сосновский муниципальный район, Алишевское сельское поселение, село Туктубаево, Плановая, 7 А		0101000020E610000054FCDF1115724E40AEF204C24E8D4B40
11855	6	58	56	32232	43620	\N	55.112746999999999	Челябинская область, Сосновский муниципальный район, Алишевское сельское поселение, поселок Трубный, Центральная, 14		0101000020E61000009694BBCFF17B4E406EDC627E6E8E4B40
11891	6	58	56	1852	42957	\N	54.957821000000003	Челябинская область, Сосновский муниципальный район, Томинское сельское поселение, поселок Томинский, Мира, 10		0101000020E6100000588D25AC8D974E400536E7E0997A4B40
11886	6	58	56	1520	42952	\N	55.513866	Челябинская область, Сосновский муниципальный район, Теченское сельское поселение, поселок Теченский, Центральная, 20 А		0101000020E610000077103B53E8C64E405F43705CC6C14B40
11882	6	58	56	1320	43770	\N	55.475152999999999	Челябинская область, Сосновский муниципальный район, Саккуловское сельское поселение, деревня Султаева, Школьная, 6		0101000020E610000017105A0F5FAC4E4053CC41D0D1BC4B40
11890	6	58	56	1759	42671	\N	55.324145999999999	Челябинская область, Сосновский муниципальный район, Солнечное сельское поселение, поселок Солнечный, Мира, 13		0101000020E610000022A7AFE76BC44E408A90BA9D7DA94B40
11883	6	58	56	1373	44150	\N	55.554267000000003	Челябинская область, Сосновский муниципальный район, Саккуловское сельское поселение, деревня Смольное, Школьная, 5		0101000020E6100000A8DF85ADD9A44E4043209738F2C64B40
11888	6	58	56	55165	43711	\N	55.0444188223411	Челябинская область, Сосновский муниципальный район, Саргазинское сельское поселение, поселок Смолино, ж.д. станция, Школьная, 1	Россия	0101000020E61000002158552FBF9F4E4017299485AF854B40
11870	6	58	56	587	44196	\N	55.131305288882999	Челябинская область, Сосновский муниципальный район, Кременкульское сельское поселение, поселок Северный, Клубная, 6	Россия, Челябинская область, Сосновский район, поселок Северный	0101000020E610000049F59D5F949A4E4090662C9ACE904B40
11887	6	58	56	1626	43104	\N	55.022386313825201	Челябинская область, Сосновский муниципальный район, Саргазинское сельское поселение, поселок Саргазы, Мичурина, 10	Россия, Челябинская область, Сосновский район, поселок Саргазы	0101000020E610000004E621533EA04E40B2F1608BDD824B40
11881	6	58	56	1291	42710	\N	55.484081000000003	Челябинская область, Сосновский муниципальный район, Саккуловское сельское поселение, поселок Саккулово, Мира, 7	Россия, Челябинская область, Сосновский район, поселок Саккулово	0101000020E61000005A84622B68B24E40B8CEBF5DF6BD4B40
10388	6	58	56	485	44153	\N	55.178151	поселок Садовый, Центральная, 11а		0101000020E6100000392861A6ED974E40F65FE7A6CD964B40
11868	6	58	56	485	43538	\N	55.178151	Челябинская область, Сосновский муниципальный район, Кременкульское сельское поселение, поселок Садовый, Трактовая, 14		0101000020E6100000392861A6ED974E40F65FE7A6CD964B40
11878	6	58	56	1069	43142	\N	55.311824999999999	Челябинская область, Сосновский муниципальный район, Рощинское сельское поселение, поселок Рощино, Ленина, 9		0101000020E61000001BBD1AA034A24E40A089B0E1E9A74B40
11893	6	58	56	55221	44297	\N	55.07752	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, деревня Полетаево IIе, Советская, 54	Россия, Челябинская область, Сосновский район, поселок Полетаево-II	0101000020E6100000B43A3943718F4E409964E42CEC894B40
11896	6	58	56	2018	42841	\N	55.035224999999997	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, поселок Полетаево, Почтовая, 32 Б		0101000020E610000040DF162CD58D4E403480B74082844B40
11894	6	58	56	2018	43163	\N	55.035224999999997	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, поселок Полетаево, Полетаевская, 48		0101000020E610000040DF162CD58D4E403480B74082844B40
11897	6	58	56	2018	43701	\N	55.036605175620203	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, поселок Полетаево, Новостройка, 1	Россия, Челябинская область, Сосновский район, поселок Полетаево	0101000020E61000002C0C91D3D78D4E405FEFFE78AF844B40
11857	6	58	56	55128	43150	\N	55.005876685131803	Челябинская область, Сосновский муниципальный район, Вознесенское сельское поселение, поселок Полевой, Центральная, 26		0101000020E6100000A7052FFA0AB04E403866D993C0804B40
11850	6	58	56	55235	44314	\N	55.188674580378098	Челябинская область, Сосновский муниципальный район, Сельское поселение Новый Кременкуль, Центральная, 1	Россия, Челябинская область, Сосновский район, поселок Новый Кременкуль	0101000020E61000002D5E2C0C91954E4052499D8026984B40
11876	6	58	56	968	43141	\N	55.318429000000002	Челябинская область, Сосновский муниципальный район, Мирненское сельское поселение, пос. Мирный, ул. Школьная, дом 6 (1 этаж)		0101000020E6100000CB845FEAE7894E408B8C0E48C2A84B40
11875	6	58	56	55189	43920	\N	55.298445000000001	Челябинская область, Сосновский муниципальный район, Мирненское сельское поселение, деревня Медиак, Медиакская, 26		0101000020E61000002BA1BB24CE844E40CE531D7233A64B40
9772	6	58	56	924	43799	\N	55.298445000000001	деревня Медиак, Центральная, 1		0101000020E61000002BA1BB24CE844E40CE531D7233A64B40
11872	6	58	56	711	44146	\N	55.198487430888903	Челябинская область, Сосновский муниципальный район, Кременкульское сельское поселение, деревня Мамаева, Лесная, 1 А	Россия, Челябинская область, Сосновский район, поселок Мамаева	0101000020E6100000736891ED7C734E4030D7A20568994B40
11871	6	58	56	657	44198	\N	55.097872000000002	Челябинская область, Сосновский муниципальный район, Кременкульское сельское поселение, деревня Малиновка, Школьная, 6		0101000020E610000080F0A1444B984E40D998D711878C4B40
11867	6	58	56	427	43099	\N	55.182715999999999	Челябинская область, Сосновский муниципальный район, Кременкульское сельское поселение, село Кременкуль, Ленина, 3 А		0101000020E6100000D84AE82E89934E405C3AE63C63974B40
11862	6	58	56	68	44010	\N	55.344884	"""Челябинская область, Сосновский муниципальный район, Долгодеревенское сельское поселение, деревня Ключевка, 1 Мая, контора ООО """"Заря"""""""	Россия, Челябинская область, Сосновский район, поселок Ключёвка	0101000020E610000089B7CEBF5DA44E40F374AE2825AC4B40
11865	6	58	56	311	44197	\N	55.250540999999998	Челябинская область, Сосновский муниципальный район, Краснопольское сельское поселение, деревня Ключи, Солнечная, 6		0101000020E61000005E66D828EB894E4050A73CBA11A04B40
11874	6	58	56	816	44149	\N	55.362140713050103	Челябинская область, Сосновский муниципальный район, Мирненское сельское поселение, поселок Кисегачинский, Больничная, 21	Россия, Челябинская область, Сосновский район, поселок Кисегачинский	0101000020E610000048F949B54F8D4E4037C5E3A25AAE4B40
11873	6	58	56	810	43667	\N	55.367876812495098	Челябинская область, Сосновский муниципальный район, Мирненское сельское поселение, деревня Касарги, Школьная, 14	Россия, Челябинская область, Сосновский район, поселок Касарги	0101000020E6100000F3C81F0C3C974E40ADF9F19716AF4B40
11853	6	58	56	32143	43769	\N	55.128830000000001	Челябинская область, Сосновский муниципальный район, Алишевское сельское поселение, село Кайгородово, Школьная, 63		0101000020E6100000F14BFDBCA9884E40315F5E807D904B40
11879	6	58	56	55171	43766	\N	55.2723853996469	Челябинская область, Сосновский муниципальный район, Рощинское сельское поселение, деревня Казанцево, Школьная, 5		0101000020E61000004641F0F8F6AC4E40E275FD82DDA24B40
11866	6	58	56	320	44008	\N	55.287871000000003	Челябинская область, Сосновский муниципальный район, Краснопольское сельское поселение, деревня Заварухино, Центральная, 1		0101000020E61000001A886533879A4E40C13BF9F4D8A44B40
11863	6	58	56	139	42968	\N	55.299798000000003	Челябинская область, Сосновский муниципальный район, Есаульское сельское поселение, поселок Есаульский, Трактористов, 6		0101000020E6100000F01989D0089C4E40FFB3E6C75FA64B40
11859	6	58	56	32340	42709	\N	55.345835999999998	Челябинская область, Сосновский муниципальный район, Долгодеревенское сельское поселение, село Долгодеревенское, Строительная, 6		0101000020E610000004AF963B33A94E40C5E3A25A44AC4B40
11860	6	58	56	32340	42959	\N	55.345835999999998	Челябинская область, Сосновский муниципальный район, Долгодеревенское сельское поселение, село Долгодеревенское, Свердловская, 15		0101000020E610000004AF963B33A94E40C5E3A25A44AC4B40
11858	6	58	56	32340	43139	\N	55.345835999999998	Челябинская область, Сосновский муниципальный район, Долгодеревенское сельское поселение, село Долгодеревенское, Набережная, 1		0101000020E610000004AF963B33A94E40C5E3A25A44AC4B40
11848	6	58	56	31903	44012	\N	55.055331000000002	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, поселок Высокий, Молодежная, 152		0101000020E61000009737876BB5714E403DBA111615874B40
11856	6	58	56	32274	43545	\N	54.990127000000001	Челябинская область, Сосновский муниципальный район, Вознесенское сельское поселение, село Вознесенка, Школьная, 6		0101000020E6100000AB23473A03AF4E407CF1457BBC7E4B40
11899	6	58	56	2313	43883	\N	54.9903588378072	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, поселок Витаминный, Лесная, 12	Россия, Челябинская область, Сосновский район, поселок Витаминный	0101000020E610000036936FB6B9834E404E266E15C47E4B40
88838	6	56	1035	49928	20018	\N	57.237965116776799	город Новоуральск, Первомайская, 11		0101000020E61000001A53B0C6D90A4E40DC4B1AA3759E4C40
11900	6	58	56	2370	44226	\N	55.011231000000002	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, деревня Верхние Малюки, Школьная, 1		0101000020E6100000B0AD9FFEB37E4E40C7D9740470814B40
11849	6	58	56	31955	43584	\N	55.036458000000003	Челябинская область, Сосновский муниципальный район, Полетаевское сельское поселение, деревня Бутаки, Ленина, 9		0101000020E61000003B191C25AF964E40BBD6DEA7AA844B40
11885	6	58	56	1513	43901	\N	55.637281000000002	Челябинская область, Сосновский муниципальный район, Саккуловское сельское поселение, деревня Большое Таскино, Победы, 56		0101000020E6100000B14F00C5C8A64E405CAE7E6C92D14B40
11861	6	58	56	32496	43539	\N	55.364783000000003	Челябинская область, Сосновский муниципальный район, Долгодеревенское сельское поселение, село Большое Баландино, Озерная, 20 А		0101000020E61000006DE525FF93BB4E4082919735B1AE4B40
11869	6	58	56	543	44195	\N	55.219145693803	Челябинская область, Сосновский муниципальный район, Кременкульское сельское поселение, село Большие Харлуши, Набережная, 19	Россия, Челябинская область, Сосновский район, поселок Большие Харлуши	0101000020E6100000649291B3B07D4E404D86E3F90C9C4B40
11892	6	58	56	1854	43537	\N	54.932254999999998	Челябинская область, Сосновский муниципальный район, Архангельское сельское поселение, село Архангельское, Центральная, 66		0101000020E61000009C1727BEDA7D4E402844C02154774B40
11976	6	58	56	6453	43905	\N	55.215411000000003	Челябинская область, Сосновский муниципальный район, Кременкульское сельское поселение, деревня Альмеева, 1 Мая, 20 А		0101000020E6100000397D3D5FB36E4E406E197096929B4B40
11851	6	58	56	32060	44018	\N	55.127733999999997	Челябинская область, Сосновский муниципальный район, Алишевское сельское поселение, деревня Алишева, Лесная, 13 А		0101000020E6100000A11342075D704E402B4B749659904B40
11057	6	58	1756	25755	44104	\N	55.030835389391299	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, поселок Черная Речка, Нагорная, 142	Россия, Челябинская область, Саткинский район, поселок Чёрная Речка	0101000020E6100000600322C495934D403D49BA66F2834B40
11067	6	58	1756	26208	43695	\N	55.202500999999998	Челябинская область, Саткинский муниципальный район, Романовское сельское поселение, поселок Чулковка, Центральная, 19		0101000020E610000051F69672BE804D402234828DEB994B40
11062	6	58	1756	55137	43268	\N	55.132689999999997	Челябинская область, Саткинский муниципальный район, Сулеинское городское поселение, Луговая, 36	Россия, Челябинская область, Саткинский район, поселок Сулея	0101000020E61000007288B83995704D40CC4065FCFB904B40
11063	6	58	1756	55137	43527	\N	55.131493545253697	Челябинская область, Саткинский муниципальный район, Сулеинское городское поселение, Кооперативная, 2а	Россия, Челябинская область, Саткинский район, поселок Сулея	0101000020E61000000EC0064488714D4064CF9ECBD4904B40
11081	6	58	1756	55120	42913	\N	54.972918811834703	Челябинская область, Саткинский муниципальный район, Бакальское городское поселение, поселок Рудничное. ж.д.раз, Нахимова, 1	Россия, Челябинская область, Саткинский район, поселок Рудничное	0101000020E6100000A8E0F08288744D4019541B9C887C4B40
11068	6	58	1756	26242	44291	\N	55.213520000000003	Челябинская область, Саткинский муниципальный район, Романовское сельское поселение, село Романовка, Школьная, 7		0101000020E61000004242942F68894D405E85949F549B4B40
11064	6	58	1756	55139	43273	\N	55.163561811507201	Челябинская область, Саткинский муниципальный район, Межевое городское поселение, Ширпышева, 2А	Россия, Челябинская область, Саткинский район, поселок Межевой	0101000020E6100000D40FEA2285664D40266F8099EF944B40
11066	6	58	1756	55139	43404	\N	55.162012994255903	Челябинская область, Саткинский муниципальный район, Межевое городское поселение, Советская, 14	Россия, Челябинская область, Саткинский район, поселок Межевой	0101000020E61000002CF180B229674D4070438CD7BC944B40
11065	6	58	1756	55139	43311	\N	55.1649613382965	Челябинская область, Саткинский муниципальный район, Межевое городское поселение, Карла Маркса, 7а	Россия, Челябинская область, Саткинский район, поселок Межевой	0101000020E61000005F7D3CF4DD634D40C70E2A711D954B40
11055	6	58	1756	25691	43831	\N	55.097033931565299	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, поселок Малый Бердяуш, Школьная, 27а	Россия, Челябинская область, Саткинский район, поселок Малый Бердяуш	0101000020E61000000B7C45B75E974D40CF4C309C6B8C4B40
10975	6	58	1756	55141	43278	\N	55.013003514642797	Магнитское городское поселение, Магнитская 8летняя школа, ул.Рабочая, д.9	Россия, Челябинская область, Саткинский район, поселок Магнитский	0101000020E61000006B4606B98BA04D40CD5B751DAA814B40
10977	6	58	1756	55141	43704	\N	55.012263654517	Магнитское городское поселение, Коррекционная школаинтернат, ул. КМаркса, д.20	Россия, Челябинская область, Саткинский район, поселок Магнитский	0101000020E6100000670E492D94A04D408675E3DD91814B40
10978	6	58	1756	55141	43649	\N	55.012510276082402	Магнитское городское поселение, Магнитская средняя школа, ул.Гагарина, д.16	Россия, Челябинская область, Саткинский район, поселок Магнитский	0101000020E6100000925A28999CA04D40BD6F7CED99814B40
11061	6	58	1756	25987	44287	\N	55.166500636028204	Челябинская область, Саткинский муниципальный район, Бердяушское городское поселение, поселок Жукатау, ж.д. станция, Наливная, 38а	Россия, Челябинская область, Саткинский район, поселок Жукатау	0101000020E6100000170D198F52994D402AE09EE74F954B40
11083	6	58	1756	55178	43807	\N	54.955361002010299	Челябинская область, Саткинский муниципальный район, город Бакал, п. Ельничный, Школьная, 1	Россия, Челябинская область, Саткинский район, поселок Ельничный	0101000020E6100000A0DFF76F5E704D40DB6FED44497A4B40
11071	6	58	1756	26397	43798	\N	55.232709999999997	Челябинская область, Саткинский муниципальный район, Айлинское сельское поселение, деревня Верхний Айск, Центральная, 58а		0101000020E61000009D66817687744D40E0B9F770C99D4B40
11056	6	58	1756	25735	44103	\N	55.032175000000002	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, п.Б.Запань, Речная, 11		0101000020E61000009DF2E846588C4D40D95F764F1E844B40
11058	6	58	1756	55142	43279	\N	55.157931151979	Челябинская область, Саткинский муниципальный район, Бердяушское городское поселение, Советская, 1А	Россия, Челябинская область, Саткинский район, поселок Бердяуш	0101000020E61000008925E5EE73924D402503401537944B40
11059	6	58	1756	55142	43732	\N	55.162157340664798	Челябинская область, Саткинский муниципальный район, Бердяушское городское поселение, Красноармейская, 2а	Россия, Челябинская область, Саткинский район, поселок Бердяуш	0101000020E610000013BA4BE2AC924D40A3E8818FC1944B40
11060	6	58	1756	55142	43408	\N	55.159602024525697	Челябинская область, Саткинский муниципальный район, Бердяушское городское поселение, Пушкина, 1А	Россия, Челябинская область, Саткинский район, поселок Бердяуш	0101000020E61000001BF1643733924D4027309DD66D944B40
11080	6	58	1756	24783	43611	\N	54.910881000000003	Челябинская область, Саткинский муниципальный район, город Бакал, Чкалова, 17		0101000020E6100000D520CCED5E684D401EC6A4BF97744B40
11074	6	58	1756	24783	42988	\N	54.910881000000003	Челябинская область, Саткинский муниципальный район, город Бакал, Титова, 2		0101000020E6100000D520CCED5E684D401EC6A4BF97744B40
11078	6	58	1756	24783	43522	\N	54.910881000000003	Челябинская область, Саткинский муниципальный район, город Бакал, Леонова, 12		0101000020E6100000D520CCED5E684D401EC6A4BF97744B40
11079	6	58	1756	24783	42831	\N	54.910881000000003	Челябинская область, Саткинский муниципальный район, город Бакал, Ленина, 69		0101000020E6100000D520CCED5E684D401EC6A4BF97744B40
11077	6	58	1756	24783	42831	\N	54.9083698373584	Челябинская область, Саткинский муниципальный район, город Бакал, Ленина, 9	Россия, Челябинская область, Саткинский район, Бакал	0101000020E61000004374081C09684D407155D97745744B40
11036	6	58	1756	24783	42831	\N	54.910881000000003	Челябинская область, Саткинский муниципальный район, город Бакал, Ленина, 29	Россия, Челябинская область, Саткинский район, Бакал	0101000020E6100000D520CCED5E684D401EC6A4BF97744B40
11082	6	58	1756	24783	44113	\N	54.910881000000003	Челябинская область, Саткинский муниципальный район, город Бакал, п. Катавка, ул. Кутузовых, 40		0101000020E6100000D520CCED5E684D401EC6A4BF97744B40
11073	6	58	1756	24783	42764	\N	54.906727045408402	Челябинская область, Саткинский муниципальный район, город Бакал, Калинина, 3	Россия, Челябинская область, Саткинский район, Бакал	0101000020E61000005281936DE0664D4039B35DA10F744B40
11076	6	58	1756	24783	43236	\N	54.942971809016001	Челябинская область, Саткинский муниципальный район, город Бакал, Андрея Костылева, 7	Россия, Челябинская область, Саткинский район, Бакал	0101000020E6100000CC29013109674D409885764EB3784B40
11075	6	58	1756	24783	42765	\N	54.907023772925903	Челябинская область, Саткинский муниципальный район, город Бакал, 50 лет ВЛКСМ, 2а	Россия, Челябинская область, Саткинский район, Бакал	0101000020E6100000289D4830D5664D40F357C85C19744B40
11072	6	58	1756	55232	44310	\N	55.162040923023604	Челябинская область, Саткинский муниципальный район, Айлинское сельское поселение, деревня Алексеевка, Центральная, 27а	Россия, Челябинская область, Саткинский район	0101000020E610000093382BA226564D403ACE6DC2BD944B40
11070	6	58	1756	26313	43592	\N	55.227617000000002	Челябинская область, Саткинский муниципальный район, Айлинское сельское поселение, село Айлино, Степана Разина, 2а1		0101000020E610000026E0D748126A4D40BF81C98D229D4B40
11069	6	58	1756	26313	43573	\N	55.227617000000002	Челябинская область, Саткинский муниципальный район, Айлинское сельское поселение, село Айлино, Пугачева, 32		0101000020E610000026E0D748126A4D40BF81C98D229D4B40
11037	6	58	6905	40358	9924	\N	55.046959119061398	Челябинская область, Саткинский муниципальный район, Саткинское городское поселение, Сергея Маринина, 4	Россия, Челябинская область, Сатка	0101000020E6100000DBFB54151A804D405EA0A4C002864B40
10293	6	58	6933	55186	43834	\N	54.502370999999997	Челябинская область, Пластовский район, село Старый Кумляк, Центральная, 21		0101000020E61000007007EA94473B4E40BABA63B14D404B40
10299	6	58	6933	55213	44186	\N	54.286062380217103	Челябинская область, Пластовский район, поселок Светлый, Школьный, 16		0101000020E6100000BA490C022B354E406E50FBAD9D244B40
10298	6	58	6933	55185	43833	\N	54.239120999999997	Челябинская область, Пластовский район, село Радиомайка, ул. Мира 50 1 этаж		0101000020E6100000DAFF006BD5344E40B66455849B1E4B40
10285	6	58	6933	55210	44172	\N	54.426991429714398	Челябинская область, Пластовский  район, село Поляновка, Библиотечная, 1а		0101000020E6100000A7751BD47E7D4E40DA571EA4A7364B40
10295	6	58	6933	41023	12130	\N	54.428474572794997	Челябинская область, Пластовский район, село Михайловка, Набережная, 51	Россия, Челябинская область, городской округ Пласт, поселок Михайловка	0101000020E6100000755776C1E04C4E40A913D044D8364B40
10292	6	58	6933	55211	44177	\N	54.554043999999998	Челябинская область, Пластовский район, село Кукушка, Холмистая, 12		0101000020E610000062DBA2CC06414E40C345EEE9EA464B40
10930	6	58	161	19595	42899	\N	55.586602999999997	поселок Муслюмово, ж.д. станция, Лесная, 2		0101000020E61000005D8B16A06DCD4E40245E9ECE15CB4B40
10300	6	58	6933	55193	43947	\N	54.368872935291002	Челябинская область, Пластовский район, поселок Воронино, Береговой, 1		0101000020E610000042D2A755F4E94D404FB0FF3A372F4B40
10286	6	58	6933	55156	43491	\N	54.442314000000003	Челябинская область, Пластовский район, село Верхняя Кабанка, ул. Школьная д. 9		0101000020E6100000698D412784764E400F48C2BE9D384B40
10249	6	58	1494	55244	44326	\N	54.258314943872399	Сельская библиотека: деревня Шишминка, ул. Центральная, д.46	Россия, Челябинская область, Октябрьский район, поселок Шишминка	0101000020E61000006B9A779CA2674F407B88467710214B40
10248	6	58	1494	55223	44300	\N	54.328072614688999	Сельский ДК: деревня Шипкино, ул. Победы, д.39	Россия, Челябинская область, Октябрьский район, поселок Шипкино	0101000020E6100000D97C5C1B2A4E4F40AED9CA4BFE294B40
10276	6	58	1494	55234	44312	\N	54.618769999999998	Сельский ДК: село Чудиново, ул. Ленина, д.36	Россия, Челябинская область, Октябрьский район, поселок Чудиново	0101000020E610000087FD9E58A7424F407ADFF8DA334F4B40
10236	6	58	1494	55240	44320	\N	54.412714999999999	Сельская библиотека: деревня Чернякино, ул. Центральная, д. 7,	Россия, Челябинская область, Октябрьский район, поселок Чернякино	0101000020E6100000ADA1D45E44874F40C9C859D8D3344B40
10266	6	58	1494	55182	\N	\N	54.187894144973598	Начальная школа: деревня Харлуши,  Здание начальной школы, Начальная  школа	Россия, Челябинская область, Октябрьский район, поселок Харлуши	0101000020E6100000A62A6D718D2F4F40AC8E1CE90C184B40
10273	6	58	1494	55167	43731	\N	54.096364443598802	Администрация УйскоЧебаркульского СП: деревня УйскоЧебаркульская, ул. Школьная, д.10		0101000020E6100000B6D782DE1B534F408141D2A7550C4B40
10268	6	58	1494	55183	\N	\N	54.290333119280099	Челябинская область, Октябрьский муниципальный район, Подовинное сельское поселение, Сельский  ДК: деревня Теренкуль, помещение СДК	Россия, Челябинская область, Октябрьский район, поселок Теренкуль	0101000020E6100000D15CA791962E4F408BF9B9A129254B40
10246	6	58	1494	55222	44299	\N	54.279218	Ветеринарный участок Маякского СП: деревня Сысоево, ул. Труда, д.46	Россия, Челябинская область, Октябрьский район, поселок Сысоево	0101000020E6100000F418E599975D4F402E3A596ABD234B40
10261	6	58	1494	48175	43814	\N	54.488515	Жилой дом: деревня Степановка, ул. Центральная, д.4		0101000020E61000009BABE63922614F407F4DD6A8873E4B40
10269	6	58	1494	55184	\N	\N	54.335409855629202	Челябинская область, Октябрьский муниципальный район, Подовинное сельское поселение, ФАП: деревня Спорное, помещение ФАП, 1 этаж фойе ФАП	Россия, Челябинская область, Октябрьский район, поселок Спорное	0101000020E6100000CB48BDA7723E4F402D6002B7EE2A4B40
10267	6	58	1494	55246	44328	\N	54.219285844067798	Челябинская область, Октябрьский муниципальный район, Подовинное сельское поселение, ФАП: деревня Сосновенькое, Помещение ФАП, ул. Молодежная 3		0101000020E6100000A8FDD64E94444F403E3C4B90111C4B40
10260	6	58	1494	48171	44045	\N	54.373237000000003	Жилой дом: деревня Семеновка, ул. Центральная, д.1		0101000020E61000006DAB59677C4F4F401E54E23AC62F4B40
10270	6	58	1494	55188	43841	\N	54.386894577127102	Средняя школа: поселок Свободный, ул. Лесная, д.5Б	Россия, Челябинская область, Октябрьский район, поселок Свободный	0101000020E6100000742843554C3B4F4033FE7DC685314B40
10265	6	58	1494	55146	43298	\N	54.2349610725716	Сельский ДК: село Подовинное, ул. Гагарина, д.10, ул. Гагарина, 10	Россия, Челябинская область, Октябрьский район, поселок Подовинное	0101000020E61000000858AB764D424F40F06AB933131E4B40
10232	6	58	1494	55191	43928	\N	54.615267000000003	Начальная школа: деревня Окунево, ул. Восточная, д.1,	Россия, Челябинская область, Октябрьский район, поселок Окунево	0101000020E61000008D0E48C2BE934F406EA7AD11C14E4B40
10255	6	58	1494	55125	43337	\N	54.411146760364801	Районный ДК: село Октябрьское, ул. Ленина, д.48	Россия, Челябинская область, Октябрьский район, поселок Октябрьское	0101000020E61000002AC8CF46AE5D4F409C6C0377A0344B40
10257	6	58	1494	55125	43288	\N	54.412848916225897	"""МУП """"Октябрьский жилкомцентр"""": село Октябрьское, ул. Комсомольская, д.54"""	Россия, Челябинская область, Октябрьский район, поселок Октябрьское	0101000020E610000030849CF7FF5D4F40D9976C3CD8344B40
10258	6	58	1494	55125	43067	\N	54.4122982265093	Октябрьский лесхоз: село Октябрьское, ул. Качалина, д.34	Россия, Челябинская область, Октябрьский район, поселок Октябрьское	0101000020E610000059C2DA183B5D4F40651A4D2EC6344B40
10259	6	58	1494	55125	43296	\N	54.411697465617202	"""МУ """"КЦСОН"""": село Октябрьское, ул. Восточная, д.88"""	Россия, Челябинская область, Октябрьский район, поселок Октябрьское	0101000020E61000008DB5BFB33D5E4F403F6EBF7CB2344B40
10256	6	58	1494	55125	43329	\N	54.413699967536999	ПУ116: село Октябрьское, ул. 1 Мая, д.18	Россия, Челябинская область, Октябрьский район, поселок Октябрьское	0101000020E61000002B306475AB5D4F40772D211FF4344B40
10264	6	58	1494	19219	43927	\N	54.350278305240103	Челябинская область, Октябрьский муниципальный район, Октябрьское сельское поселение, Сельский ДК: село Новомосковское, ул. Октябрьская, д.81	Россия, Челябинская область, Октябрьский район, поселок Новомосковское	0101000020E610000017BB7D5699874F401041D5E8D52C4B40
10271	6	58	1494	55242	44323	\N	54.387956618937899	Селький ДК: деревня Нововарламово, ул. Мира, д.46		0101000020E6100000B5A9BA47362B4F408CA03193A8314B40
10250	6	58	1494	55225	44302	\N	54.655758203568503	Администрация Мяконькского СП: село Мяконьки, ул. Советская, д.15		0101000020E61000009E4143FF046F4F40910BCEE0EF534B40
10243	6	58	1494	55230	44308	\N	54.577220527282002	Сельский ДК: деревня Могильное, ул. Могильская, д.10		0101000020E61000001233FB3C464B4F403FC8B260E2494B40
10935	6	58	161	19595	42796	\N	55.586602999999997	поселок Муслюмово, ж.д. станция, Вокзальная, Дом культуры		0101000020E61000005D8B16A06DCD4E40245E9ECE15CB4B40
10245	6	58	1494	55224	44301	\N	54.2624938695133	Администрация Маякского СП:село Маячное, ул. Центральная, д.12	Россия, Челябинская область, Октябрьский район, поселок Маячное	0101000020E61000001EE21FB6F4624F40B7B2446799214B40
10242	6	58	1494	18107	44020	\N	54.553329027792699	Челябинская область, Октябрьский муниципальный район, Лысковское сельское поселение, Администрация Лысковского СП: село Лысково, ул. Центральная, д.9		0101000020E6100000D89DEE3CF1564F40D576137CD3464B40
10262	6	58	1494	55199	44053	\N	54.459384076047598	Средняя школа: деревня Лебедки, ул. Школьная, д.2	Россия, Челябинская область, Октябрьский район, поселок Лебедки	0101000020E6100000B0E595EB6D6B4F4020274C18CD3A4B40
10233	6	58	1494	55198	44044	\N	54.516311999999999	Начальная школа: деревня Лафетное, ул. Рабочая, д.1А,	Россия, Челябинская область, Октябрьский район, поселок Лафетное	0101000020E61000001590F63FC0904F402444F98216424B40
10244	6	58	1494	55179	43810	\N	54.60769081638	Сельский ДК: деревня Кузнецово, ул. Кузнецовская, д.9	Россия, Челябинская область, Октябрьский район, поселок Кузнецово	0101000020E6100000C0594A9693564F406A8995D1C84D4B40
10237	6	58	1494	55160	43635	\N	54.1952425289643	Средняя школа: поселок Крутоярский, ул. Школьная, д.9	Россия, Челябинская область, Октябрьский район, поселок Крутоярский	0101000020E6100000487023658B944F40EFE2FDB8FD184B40
10231	6	58	1494	17530	43605	\N	54.573302292411597	"""Челябинская область, Октябрьский муниципальный район, Кочердыкское сельское поселение,  ""ДК "" ""Колос"": село Кочердык, ул. Школьная д. 1"""	Россия, Челябинская область, Октябрьский район, поселок Кочердык	0101000020E61000008CBFED09127D4F409E5DBEF561494B40
10263	6	58	1494	55236	44315	\N	54.3971355991171	ФАП: деревня Киевка, ул. Киевская, д.23	Россия, Челябинская область, Октябрьский район, поселок Киевка	0101000020E6100000855B3E9292704F403A083A5AD5324B40
10240	6	58	1494	55168	43733	\N	54.060145806164698	Администрация Каракульского СП: село Каракульское, ул. Школьная, д.21	Россия, Челябинская область, Октябрьский район, поселок Каракульское	0101000020E6100000573F36C98F364F401C7E37DDB2074B40
10275	6	58	1494	55209	44170	\N	54.118785000000003	Начальная школа: деревня Камышное, ул. Пионерская, д.2	Россия, Челябинская область, Октябрьский район, поселок Камышное	0101000020E6100000D78A36C7B9414F40B020CD58340F4B40
10228	6	58	1494	55217	44292	\N	54.6388957826683	Сельский ДК: деревня Зуевка, ул. Восточная, д.2,	Россия, Челябинская область, Октябрьский район, поселок Зуевка	0101000020E6100000C11BD2A8C02B4F40CAC51858C7514B40
10230	6	58	1494	55233	44311	\N	54.674949811373899	Сельский ДК: деревня Замериново, ул. Северная, д.23, ул. Северная, 23	Россия, Челябинская область, Октябрьский район, поселок Замериново	0101000020E610000038F92D3A59364F40B537F8C264564B40
10251	6	58	1494	55192	43940	\N	54.545329094990002	Начальная школа: деревня Журавлиное, ул. Советская, д.25	Россия, Челябинская область, Октябрьский район, поселок Журавлиное	0101000020E6100000098849B8906B4F40BB473657CD454B40
10247	6	58	1494	55239	44318	\N	54.264703483573001	Сельский ДК: деревня Деньгино, ул. Свободы, д.16	Россия, Челябинская область, Октябрьский район, поселок Деньгино	0101000020E6100000A1116C5CFF5A4F409813B4C9E1214B40
10235	6	58	1494	55174	43795	\N	54.502133909446201	Челябинская область, Октябрьский муниципальный район, Кочердыкское сельское поселение, Сельская библиотека: деревня Горелое, ул. Центральная д. 15	Россия, Челябинская область, Октябрьский район, поселок Горелое	0101000020E6100000D61EF64201814F40D61A4AED45404B40
10254	6	58	1494	55180	43819	\N	54.499485	Средняя школа: село Ваганово, ул. 1 Мая, д.63	Россия, Челябинская область, Октябрьский район, поселок Ваганово	0101000020E61000006901DA56B3284F40D9EBDD1FEF3F4B40
10239	6	58	1494	55228	44306	\N	54.288591040999201	Сельская библиотека: деревня Быково, ул. Школьная, д.4	Россия, Челябинская область, Октябрьский район, поселок Быково	0101000020E6100000AAB69BE09B7E4F40C075C58CF0244B40
10225	6	58	1494	55227	44305	\N	54.489916000000001	Сельский ДК: деревня Буланово, ул. Центральная, д. 24А,	Россия, Челябинская область, Октябрьский район, поселок Буланово	0101000020E6100000F3E8465854524F40C1E44691B53E4B40
10227	6	58	1494	17329	44021	\N	54.657076052705399	Челябинская область, Октябрьский муниципальный район, Боровое сельское поселение, Администрация Борового СП: село Боровое, ул. Калинина, д.11		0101000020E610000028BB99D18F264F40467EFD101B544B40
10252	6	58	1494	18616	44046	\N	54.547277000000001	Челябинская область, Октябрьский муниципальный район, Никольское сельское поселение, Сельский ДК: село Большеникольское, ул. Центральная, д10		0101000020E61000003E7B2E5393164F402F6D382C0D464B40
10274	6	58	1494	55231	44309	\N	54.116674560068503	Сельский ДК: поселок Березовский, ул. Советская, д.40	Россия, Челябинская область, Октябрьский район, поселок Березовский	0101000020E6100000D464C6DB4A694F4062A1D634EF0E4B40
10224	6	58	1494	55226	44304	\N	54.447079652953697	Администрация Барсучанского СП: деревня Барсучье, ул. Молодежная, д.17,	Россия, Челябинская область, Октябрьский район, поселок Барсучье	0101000020E6100000A663CE33F6514F400C59DDEA39394B40
10234	6	58	1494	55176	43801	\N	54.677062999999997	Начальная школа: деревня Банниково, ул. Трудовая, д.6, кв. 2	Россия, Челябинская область, Октябрьский район, поселок Банниково	0101000020E61000004A0C022B878A4F40732A1900AA564B40
10229	6	58	1494	55220	44296	\N	54.621310957898501	Сельский ДК: деревня Бакшан, ул. Южная, д.33А,	Россия, Челябинская область, Октябрьский район, поселок Бакшан	0101000020E6100000BFD4CF9B8A264F4091D26C1E874F4B40
9104	6	58	339	26875	43767	\N	55.299259999999997	деревня Левашева, Интернациональная, 22 А		0101000020E61000009C50888043744E401F80D4264EA64B40
10241	6	58	1494	55247	44334	\N	54.4777815667262	"""Челябинская область, Октябрьский муниципальный район, Каракульское сельское поселение, ""Контора отделения №2 ООО ""КаракульАгро"" : деревня Александровка, ул. Центральная 20"""		0101000020E610000055A18158361D4F40094FE8F5273D4B40
10253	6	58	1494	55247	44330	\N	54.476432000000003	Досуговый центр Никольского СП: деревня Александровка, ул. Береговая, д.31, ул. Береговая, 31	Россия, Челябинская область, Октябрьский район, поселок Александровка	0101000020E61000008E041A6CEA1C4F404A6249B9FB3C4B40
10987	6	58	5668	51931	42986	\N	54.460028000000001	Медведевское сельское поселение, село Медведевка, Медведевская сельская администрация, ул. Пономаренко, д.2		0101000020E61000006536C82423B73540459F8F32E23A4B40
11019	6	58	921	23965	43521	\N	56.242263999999999	Челябинская область, Нязепетровский муниципальный район,с.Шемаха, Октябрьская, 21		0101000020E6100000DA0242EBE1A14D40C37FBA81021F4C40
11026	6	58	921	24313	43705	\N	55.801870000000001	Челябинская область, Нязепетровский муниципальный район,с.Ункурда, Просвещенская, 62		0101000020E610000094895B0531B44D405FD218ADA3E64B40
11024	6	58	921	24177	43892	\N	56.157007	Челябинская область, Нязепетровский муниципальный район,д.Ташкинова, 27 съезда КПСС, 18		0101000020E610000016FBCBEEC9994D401D1F2DCE18144C40
11020	6	58	921	24018	44282	\N	56.286897731910301	Челябинская область, Нязепетровский муниципальный район,п.Сказ, Школьная, 13	Россия, Челябинская область, Нязепетровский район, поселок Сказ	0101000020E6100000EF91CD55F3A84D40D7A4DB12B9244C40
11031	6	58	921	7338	43603	\N	55.787568	Челябинская область, Нязепетровский муниципальный район,д.Ситцева, Ленина, 64 (клуб, 1 этаж 1 этажного здания)		0101000020E6100000D4EE5701BEDD4D4025B03907CFE44B40
11029	6	58	921	24455	44099	\N	55.852445000000003	Челябинская область, Нязепетровский муниципальный район,д.Нестерово, Советская, 32		0101000020E6100000A1F48590F3BA4D40C251F2EA1CED4B40
11023	6	58	921	24163	44218	\N	56.173341999999998	Челябинская область, Нязепетровский муниципальный район,д.Межевая, Мира, 33		0101000020E61000005682C5E1CC934D40F982161230164C40
11030	6	58	921	24520	44286	\N	55.860964000000003	Челябинская область, Нязепетровский муниципальный район,п.Котово, И.Никитина, 2		0101000020E610000082E15CC30CCD4D4045847F1134EE4B40
11025	6	58	921	24261	44101	\N	55.968840999999998	Челябинская область, Нязепетровский муниципальный район,п.Кедровый, Школьная, 1А		0101000020E61000006F9C14E63DB04D4010035DFB02FC4B40
11027	6	58	921	24356	43973	\N	55.823044000000003	Челябинская область, Нязепетровский муниципальный район,с.Калиновка, Гагарина, 7		0101000020E6100000C8EA56CF49A54D40A3957B8159E94B40
11033	6	58	921	24665	43797	\N	55.625109999999999	Челябинская область, Нязепетровский муниципальный район,д.Гривенка, Школьная, 26		0101000020E6100000AA44D95BCACD4D408733BF9A03D04B40
11028	6	58	921	24406	44283	\N	55.901743000000003	Челябинская область, Нязепетровский муниципальный район,п.Беляево, Молодежная, 29		0101000020E61000005587DC0C37A64D40CF328B506CF34B40
11021	6	58	921	24060	44097	\N	56.205745999999998	Челябинская область, Нязепетровский муниципальный район,п.Арасланово, Школьная, 17		0101000020E6100000CE548847E2A54D4033A48AE2551A4C40
11022	6	58	921	24060	43568	\N	56.205745999999998	Челябинская область, Нязепетровский муниципальный район,с.Арасланово, Гагарина, 5А		0101000020E6100000CE548847E2A54D4033A48AE2551A4C40
11032	6	58	921	24617	44100	\N	55.708460000000002	Челябинская область, Нязепетровский муниципальный район,д.Аптрякова, Победы, 43А		0101000020E61000008693347F4CDB4D40184339D1AEDA4B40
11576	6	58	1486	53078	42973	\N	53.530718	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Южное городское поселение, поселок Южный, ул.Пионерская, д. 1,		0101000020E61000008849B89047084E4003B34291EEC34A40
11548	6	58	1486	17495	44003	\N	53.729447	Челябинская область, Нагайбакский муниципальный район, Кассельское сельское поселение, поселок Чернореченский, Молодежная,3		0101000020E61000001366DAFE95C14D402995F0845EDD4A40
11571	6	58	1486	53077	43102	\N	53.519519000000003	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Фершампенуазское сельское поселение, село Фершампенуаз, ул. Советская, д.40		0101000020E610000024986A662DE94D4048533D997FC24A40
11570	6	58	1486	53077	42969	\N	53.519519000000003	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Фершампенуазское сельское поселение, село Фершампенуаз, ул. Мира, д.19		0101000020E610000024986A662DE94D4048533D997FC24A40
11543	6	58	1486	17223	44231	\N	53.41113	Челябинская область, Нагайбакский муниципальный район, Балканское сельское поселение, поселок Требиятский, Труда, 25		0101000020E61000008522DDCF29CC4D40C63368E89FB44A40
11556	6	58	1486	17875	43915	\N	53.542833000000002	Челябинская область, Нагайбакский муниципальный район, Нагайбакское сельское поселение, поселок Совхозный, пер. Школьный, 2/1		0101000020E6100000315D88D51FB34D4044183F8D7BC54A40
11575	6	58	1486	18869	44162	\N	53.403807999999998	Челябинская область, Нагайбакский муниципальный район, Фершампенуазское сельское поселение, деревня Слюда, Новая, 10		0101000020E6100000A648BE1248F14D407CEE04FBAFB34A40
11550	6	58	1486	17586	43659	\N	53.587066	Челябинская область, Нагайбакский муниципальный район, Куликовское сельское поселение, поселок Северный, Мира, 9		0101000020E6100000778192020B064E40F94B8BFA24CB4A40
11572	6	58	1486	18698	44132	\N	53.449086999999999	Челябинская область, Нагайбакский муниципальный район, Фершампенуазское сельское поселение, поселок Рассвет, Молодежная, 1		0101000020E6100000A3B08BA207E84D408507CDAE7BB94A40
11562	6	58	1486	18177	44157	\N	53.633400889601397	Челябинская область, Нагайбакский муниципальный район, Остроленское сельское поселение, поселок Придорожный, Центральная, 22	Россия, Челябинская область, Нагайбакский район, поселок Придорожный	0101000020E6100000AF264F594DD54D407920B24813D14A40
11549	6	58	1486	53072	43869	\N	53.718860999999997	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Кассельское сельское поселение, поселок Подгорный, ул. Центральная, д. 26,		0101000020E61000000744882B67B74D4057AF22A303DC4A40
11557	6	58	1486	17948	43749	\N	53.592773999999999	Челябинская область, Нагайбакский муниципальный район, Нагайбакское сельское поселение, поселок Петровский, Центральная, 25		0101000020E61000001DC70F9546C84D40A5F5B704E0CB4A40
11569	6	58	1486	18551	44074	\N	53.568776	Челябинская область, Нагайбакский муниципальный район, Переселенческое сельское поселение, поселок Переселенческий, Центральная, 27		0101000020E6100000CC61F71DC3DB4D40F65FE7A6CDC84A40
11563	6	58	1486	18234	43103	\N	53.303311999999998	Челябинская область, Нагайбакский муниципальный район, Парижское сельское поселение, село Париж, Пионерская, 43а		0101000020E61000002096CD1C920C4E40FF3D78EDD2A64A40
11560	6	58	1486	53075	42682	\N	53.683804388682503	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Остроленское сельское поселение, поселок Остроленский, ул. Васильева, д.49,	Россия, Челябинская область, Нагайбакский район, поселок Остроленский	0101000020E6100000925ED4EE57DD4D40DF6FB4E386D74A40
11566	6	58	1486	18367	44058	\N	53.250388999999998	Челябинская область, Нагайбакский муниципальный район, Парижское сельское поселение, поселок Новочерниговский, Молодежная, 20а		0101000020E6100000218FE046CAEC4D409A232BBF0CA04A40
11555	6	58	1486	53073	43621	\N	53.542700000000004	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Нагайбакское сельское поселение, поселок Нагайбакский, ул.Центральная, д.15		0101000020E61000006F47382D78C34D4005C58F3177C54A40
11553	6	58	1486	17747	44156	\N	53.541061999999997	Челябинская область, Нагайбакский муниципальный район, Куликовское сельское поселение, поселок Набережный, Целинная, 20		0101000020E6100000268DD13AAAFC4D40DE8D058541C54A40
11554	6	58	1486	17787	44159	\N	53.647933999999999	Челябинская область, Нагайбакский муниципальный район, Куликовское сельское поселение, поселок Лесные Поляны, Центральная, 12		0101000020E6100000B1FD648C0FF14D40B5FB5580EFD24A40
11564	6	58	1486	18274	44135	\N	53.262616999999999	Челябинская область, Нагайбакский муниципальный район, Парижское сельское поселение, село Лебединое, Новая, 1		0101000020E61000006D8FDE701FF14D40D32F116F9DA14A40
11561	6	58	1486	55243	44324	\N	53.756608178934101	Челябинская область, Нагайбакский муниципальный район, Остроленское сельское поселение, поселок Куропаткинский, Мира 7	Россия, Челябинская область, Нагайбакский район, поселок Куропатнинский	0101000020E61000008E3BA583F5D54D402CF2EB87D8E04A40
11574	6	58	1486	18799	44033	\N	53.459542999999996	Челябинская область, Нагайбакский муниципальный район, Фершампенуазское сельское поселение, поселок Курганный, Советская, 27		0101000020E6100000C76471FF91D54D40880D164ED2BA4A40
11551	6	58	1486	17661	43897	\N	53.599203000000003	Челябинская область, Нагайбакский муниципальный район, Куликовское сельское поселение, поселок Куликовский, Советская, 21		0101000020E610000029D027F224034E40225514AFB2CC4A40
11565	6	58	1486	18325	43907	\N	53.307831999999998	Челябинская область, Нагайбакский муниципальный район, Парижское сельское поселение, поселок Кужебаевский, Новая, 28		0101000020E6100000E141B3EBDE224E40C554FA0967A74A40
11568	6	58	1486	18490	43752	\N	53.609098000000003	Челябинская область, Нагайбакский муниципальный район, Переселенческое сельское поселение, село Крупское, Степная, 31		0101000020E61000003813D38558E14D408E075BECF6CD4A40
11547	6	58	1486	53071	43530	\N	53.801197999999999	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Кассельское сельское поселение, поселок Кассельский, ул.Труда, д.2		0101000020E6100000EDBB22F8DFC84D4070CFF3A78DE64A40
11541	6	58	1486	17123	44026	\N	53.683708056291202	Челябинская область, Нагайбакский муниципальный район, Арсинское сельское поселение, поселок Калининский, пер.Южный,1	Россия, Челябинская область, Нагайбакский район, поселок Калининский	0101000020E610000032E36DA5D7F84D40BD0166BE83D74A40
11573	6	58	1486	18758	43918	\N	53.533233000000003	Челябинская область, Нагайбакский муниципальный район, Фершампенуазское сельское поселение, поселок Знаменка, Школьная 19		0101000020E610000055FB743C66FC4D40F1129CFA40C44A40
11544	6	58	1486	17291	43847	\N	53.403469999999999	Челябинская область, Нагайбакский муниципальный район, Балканское сельское поселение, поселок Заречный, Комсомольская 11		0101000020E6100000E4A3C519C3DE4D406475ABE7A4B34A40
11567	6	58	1486	18433	43498	\N	53.569001	Челябинская область, Нагайбакский муниципальный район, Переселенческое сельское поселение, поселок Гумбейский, Придорожная, 1		0101000020E610000096D05D1267DF4D4016325706D5C84A40
11558	6	58	1486	17989	44055	\N	53.558401000000003	Челябинская область, Нагайбакский муниципальный район, Нагайбакское сельское поселение, поселок Березовая Роща, Березовая, 4		0101000020E6100000410FB56D18BF4D40E08618AF79C74A40
10777	6	58	954	40213	9574	\N	54.817841706323897	Челябинская область, Трехгорный городской округ, Строителей, 10		0101000020E6100000685DA3E540394D40CAA5F10BAF684B40
11542	6	58	1486	17192	44063	\N	53.440044999999998	Челябинская область, Нагайбакский муниципальный район, Балканское сельское поселение, поселок Балканы, Советская, 6		0101000020E61000007959130B7CCD4D4058E2016553B84A40
11552	6	58	1486	17677	43891	\N	53.474862000000002	Челябинская область, Нагайбакский муниципальный район, Куликовское сельское поселение, поселок Астафьевский, Советская, 10		0101000020E61000007218CC5F21094E407C0E2C47C8BC4A40
11540	6	58	1486	53070	43193	\N	53.750919000000003	Помещение для голосования: Челябинская область, Нагайбакский муниципальный район, Арсинское сельское поселение, поселок Арсинский, ул. Мира, д.47		0101000020E6100000AF43352559F14D40F778211D1EE04A40
11559	6	58	1486	18046	43919	\N	53.543550000000003	Челябинская область, Нагайбакский муниципальный район, Нагайбакское сельское поселение, поселок Арасламбаевский, Школьная, 8		0101000020E6100000840EBA8443CD4D40D3DEE00B93C54A40
11546	6	58	1486	17367	44133	\N	53.381034999999997	Челябинская область, Нагайбакский муниципальный район, Балканское сельское поселение, поселок АлександроНевский, Советская, 30		0101000020E6100000DD3F16A243DE4D40D0D03FC1C5B04A40
10986	6	58	1686	55204	44102	\N	55.405209311679698	Злоказовское сельское поселение, поселок Октябрьский, Октябрьская школа, ул.Школьная, д.2	Россия, Челябинская область, Кусинский район, поселок Октябрьский	0101000020E61000004FAC53E57BC24D40BE8575E3DDB34B40
10976	6	58	1686	55169	43735	\N	55.343859999999999	Магнитское городское поселение, Профессиональное училище № 36 , ул. КМаркса, д.18	Россия, Челябинская область, Кусинский район, поселок Магнитка	0101000020E61000006EA7AD11C1D84D408733BF9A03AC4B40
10979	6	58	1686	40400	44015	\N	55.337789521989201	Магнитское городское поселение, поселок Ковали, Контора лесхоза, ул.Чернышевского, д.95	Россия, Челябинская область, Кусинский район, поселок Ковали	0101000020E61000002975C93846D44D403A75E5B33CAB4B40
10982	6	58	1686	22271	44289	\N	55.461430999999997	Петрозаводское сельское поселение, деревня Каскиново, Каскиновская школа, ул.Школьная, д.14		0101000020E6100000E816BA1281B44D40272EC72B10BB4B40
10984	6	58	1686	40401	43564	\N	55.460113999999997	Злоказовское сельское поселение, село Злоказово, Злоказовская сельская администроация, ул.Трактовая, д.22		0101000020E61000001B82E3326EBA4D404337FB03E5BA4B40
10985	6	58	1686	55216	44227	\N	55.5356406127799	Злоказовское сельское поселение, село Вознесенка, Вознесенская школа, ул.Школьная, д.4	Россия, Челябинская область, Кусинский район, поселок Вознесенка	0101000020E610000018D1764CDDCF4D40C8B260E28FC44B40
10980	6	58	1686	55197	44038	\N	55.477454000000002	Магнитское городское поселение, поселок Александровка, Александровская школа, ул. Школьная, д.6	Россия, Челябинская область, Кусинский район, поселок Александровка	0101000020E61000007905A22765EA4D4015AC71361DBD4B40
10946	6	58	161	20493	43826	\N	55.897315999999996	МО Кунашакский муниципальный район, д.Юлдашева, Школьная, 1, 1 этаж		0101000020E6100000871403249AAE4E40B9162D40DBF24B40
10949	6	58	161	20693	44030	\N	56.112400082646502	поселок Элеваторный, Вокзальная, 3	Россия, Челябинская область, Кунашакский район, поселок Элеваторный	0101000020E61000003C50A73CBAF14E4003098A1F630E4C40
10953	6	58	161	20910	44280	\N	56.038705	деревня Чекурова, Центральная, 5		0101000020E6100000F46F97FDBAD94E4089981249F4044C40
10955	6	58	161	48266	42894	\N	55.865803	село Халитово, Целинная, 24а		0101000020E6100000FE0DDAAB8FDF4E40ACE3F8A1D2EE4B40
10947	6	58	161	48112	44294	\N	56.1345998482198	АМО УстьБагарякское с/п, с.УстьБагаряк, Ленина, 222, 1 этаж	Россия, Челябинская область, Кунашакский район, поселок Усть-Багаряк	0101000020E6100000263ACB2C42ED4E405305A3923A114C40
10948	6	58	161	48112	43644	\N	56.132489	село УстьБагаряк, Базарная, 1		0101000020E6100000A6ED5F5969EE4E40350A4966F5104C40
10610	6	58	161	45933	43763	\N	55.990786	поселок Трудовой, Мира, 25	Россия, Челябинская область, Кунашакский район, поселок Трудовой	0101000020E61000001E17D522A2DE4E40D6AA5D13D2FE4B40
10956	6	58	161	21051	43974	\N	55.888139000000002	деревня Тахталым, ж.д. станция, Станционная, 6	Россия, Челябинская область, Кунашакский район, поселок Тахталым	0101000020E610000021AE9CBD33DE4E40ADA6EB89AEF14B40
10943	6	58	161	20350	44206	\N	55.944262999999999	село Татарская Караболка, Школьная, 5		0101000020E610000045BA9F5390974E4053E9279CDDF84B40
10934	6	58	161	19817	43825	\N	55.489544000000002	деревня Сураково, Челябинская, 14а		0101000020E61000005721E527D5CC4E40FDF9B660A9BE4B40
10931	6	58	161	19636	43790	\N	55.631461913758699	деревня Султаново, Школьная, 3	Россия, Челябинская область, Кунашакский район, поселок Султаново	0101000020E6100000BDFE243E77E44E4058552FBFD3D04B40
10928	6	58	161	19506	44029	\N	55.888204999999999	МО Кунашакский муниципальный район, д.Сосновка, Озерная, б/н, 1 этаж		0101000020E6100000514B732B84E54E40649291B3B0F14B40
10950	6	58	161	48167	44281	\N	56.127301000000003	поселок Синарский, Станционная, 2а		0101000020E6100000E9995E622CF14E40C2DF2F664B104C40
10952	6	58	161	55195	43984	\N	56.008253419405897	деревня Серкино, Центральная, 1а	Россия, Челябинская область, Кунашакский район, поселок Серкино	0101000020E6100000F0694E5E64EA4E40058C2E6F0E014C40
10941	6	58	161	55215	44221	\N	55.783729581497703	деревня Сарыкульмяк, Ленина, 57	Россия, Челябинская область, Кунашакский район	0101000020E6100000E31934F44F884E407172BF4351E44B40
10929	6	58	161	61103	77216	\N	55.985689999999998	поселок Разъезд N2, Железнодорожников, красный уголок ЭЧ8		0101000020E6100000F2272A1BD6E64E4043FF04172BFE4B40
10933	6	58	161	19754	43598	\N	55.493017999999999	село Нугуманово, Школьная, 1		0101000020E610000099F04BFDBCE54E406F2BBD361BBF4B40
10932	6	58	161	19698	43789	\N	55.532975999999998	село Новое Курманово, Ленина, 1		0101000020E6100000342BDB87BCDD4E40C5C6BC8E38C44B40
10550	6	58	161	478	43047	\N	55.980204999999998	село Новобурино, Комсомольская, 1		0101000020E6100000D5415E0F26D34E401630815B77FD4B40
11107	6	58	161	28035	42811	\N	55.788981	"""Челябинская область, Озерский городской округ, поселок Метлино, ул.Центральная, 61, Дом культуры, МУ ДК ""Синегорье"", (1 этаж фойе)"""		0101000020E61000006F2C280CCA7E4E402B155454FDE44B40
10927	6	58	161	47716	44098	\N	55.850296999999998	поселок Маяк, Центральная, помещение средней школы		0101000020E6100000EA5BE67459D84E4086713788D6EC4B40
10957	6	58	161	21101	43976	\N	55.907255712988203	деревня Мансурова, Дальняя, 31	Россия, Челябинская область, Кунашакский район, поселок Мансурова	0101000020E61000001FBDE13E72D34E40C58CF0F620F44B40
10925	6	58	161	47680	\N	\N	55.674382000000001	поселок Лесной, клуб п.Лесной		0101000020E61000006404543882D04E406B813D2652D64B40
10923	6	58	161	19221	42985	\N	55.698309999999999	село Кунашак, Пионерская, 52		0101000020E610000018EE5C18E9C54E40213CDA3862D94B40
10924	6	58	161	19221	42756	\N	55.698746233713301	село Кунашак, Ленина, 95	Россия, Челябинская область, Кунашакский район, поселок Кунашак	0101000020E6100000632AFD84B3C74E40FC1A498270D94B40
10959	6	58	161	21181	43975	\N	55.958336000000003	деревня Кунакбаева, Школьная, 11		0101000020E6100000CC988235CEC44E402C4A09C1AAFA4B40
10951	6	58	161	20799	44285	\N	56.018735	поселок Кумкуль, Центральная, 1		0101000020E61000009599D2FA5B064F40312592E865024C40
10962	6	58	161	21336	44279	\N	55.833081	деревня Кубагушева, Галлямова, 27а		0101000020E6100000B48EAA2688F04E40A1F5F065A2EA4B40
10944	6	58	161	48033	43824	\N	55.773915000000002	деревня Карагайкуль, Молодежная, 30		0101000020E61000000EDAAB8F879E4E4022718FA50FE34B40
10938	6	58	161	20032	44203	\N	55.728976000000003	деревня Каинкуль, Школьная, 12		0101000020E61000007DB3CD8DE9A74E40D2C8E7154FDD4B40
10954	6	58	161	20924	43971	\N	56.069605000000003	деревня Иксанова, Центральная, 31		0101000020E6100000FE0B040132044F40AD510FD1E8084C40
10942	6	58	161	20246	44205	\N	55.744889999999998	деревня Ибрагимова, Школьная, 1		0101000020E6100000772CB64945974E40088F368E58DF4B40
10940	6	58	161	20125	43988	\N	55.832828999999997	деревня Голубинка, Береговая, 30		0101000020E610000006685BCD3A954E40871403249AEA4B40
10960	6	58	161	48360	43796	\N	55.932474595440198	деревня Бурино, Школьная, 1	Россия, Челябинская область, Кунашакский район, поселок Бурино	0101000020E6100000950C0055DCEA4E4036AB3E575BF74B40
10939	6	58	161	20080	43518	\N	55.834663513132	село Большой Куяш, Ленина, 155	Россия, Челябинская область, Кунашакский район, поселок Большой Куяш	0101000020E61000003108AC1C5A8C4E4003931B45D6EA4B40
10945	6	58	161	20465	43542	\N	55.870496000000003	деревня Большая Тюлякова, Центральная, 8		0101000020E6100000A6D3BA0D6AC34E4040A6B5696CEF4B40
10958	6	58	161	21153	43972	\N	55.920093000000001	деревня Большая Казакбаева, Зеленая, 36		0101000020E61000007120240B98CA4E40A723809BC5F54B40
10961	6	58	161	21271	43791	\N	55.902051	деревня Баязитова, Межозерная, 5а		0101000020E610000008228B34F1F64E407C293C6876F34B40
10963	6	58	161	21364	43794	\N	55.755367999999997	деревня Баракова, Молодежная, 12		0101000020E6100000CF87670932E84E40F3380CE6AFE04B40
10885	6	58	161	17283	\N	\N	55.931314999999998	село Аширово, помещение сельской администрации	Россия, Челябинская область, Кунашакский район, поселок Аширово	0101000020E6100000E00ED4298F0C4F401AA3755435F74B40
10937	6	58	161	19951	43567	\N	55.704925000000003	деревня Аминева, Школьная, 1а		0101000020E61000000D8E9257E7B24E4000917EFB3ADA4B40
10922	6	58	1449	19199	44096	\N	55.348047999999999	Челябинская область, Красноармейский муниципальный район, Шумовское сельское поселение, село Якупово, Центральная, 46		0101000020E610000078D32D3BC4134F4017B83CD68CAC4B40
10913	6	58	1449	18730	44276	\N	55.756831982197497	Челябинская область, Красноармейский муниципальный район, РусскоТеченское сельское поселение, деревня Шуранкуль, Комсомольская, 23	Россия, Челябинская область, Красноармейский район, поселок Шуранкуль	0101000020E6100000F31FD26F5F314F407C48F8DEDFE04B40
10918	6	58	1449	18963	43563	\N	55.380117823676699	Челябинская область, Красноармейский муниципальный район, Шумовское сельское поселение, село Шумово, Советская, 32А	Россия, Челябинская область, Красноармейский район, поселок Шумово	0101000020E61000000AB952CF82F24E407B4FE5B4A7B04B40
10874	6	58	1449	16733	43823	\N	55.293908999999999	Челябинская область, Красноармейский муниципальный район, Миасское сельское поселение, село Черкасово, Мира, 20		0101000020E61000008E75711B0DDA4E40028063CF9EA54B40
10896	6	58	1449	17832	43786	\N	55.276811000000002	Челябинская область, Красноармейский муниципальный район, Козыревское сельское поселение, деревня Худяково, Набережная, 10А		0101000020E61000008A01124DA0DA4E402716F88A6EA34B40
10906	6	58	1449	18305	44274	\N	55.349930999999998	Челябинская область, Красноармейский муниципальный район, Миасское сельское поселение, село Харино, Молодежная, 27		0101000020E610000098309A95EDDF4E40A46DFC89CAAC4B40
10872	6	58	1449	16624	44273	\N	55.074494000000001	Челябинская область, Красноармейский муниципальный район, Березовское сельское поселение, село Ханжино, Учительская, 2		0101000020E6100000B0A9F3A8F8F74E40C6DFF60489894B40
10873	6	58	1449	16705	43900	\N	55.109961419159397	Челябинская область, Красноармейский муниципальный район, Березовское сельское поселение, деревня Фроловка, Школьная, 10	Россия, Челябинская область, Красноармейский район, поселок Фроловка	0101000020E6100000FE48111956EF4E40F06AB933138E4B40
10869	6	58	1449	16466	44268	\N	55.528309	Челябинская область, Красноармейский муниципальный район, Алабугское сельское поселение, село Феклино, Солнечная, 14		0101000020E610000084807C0915424F405B971AA19FC34B40
11668	6	58	1449	19062	44158	\N	55.346538050307501	деревня Устьянцево, Солнечная, 1	Россия, Челябинская область, Красноармейский район, поселок Устьянцево	0101000020E61000007044F7AC6B044F401F69705B5BAC4B40
10920	6	58	1449	19062	44277	\N	55.347321000000001	Челябинская область, Красноармейский муниципальный район, Шумовское сельское поселение, село Устьянцево, Зеленая, 11		0101000020E6100000999EB0C403044F40651BB80375AC4B40
10916	6	58	1449	18849	44278	\N	55.626269000000001	Челябинская область, Красноармейский муниципальный район, Сугоякское сельское поселение, поселок Усольцево, Школьная, 4		0101000020E6100000B3CF639467044F40D3BF249529D04B40
10882	6	58	1449	17126	44270	\N	55.601294000000003	Челябинская область, Красноармейский муниципальный район, Бродокалмакское сельское поселение, деревня Тирикуль, Центральная, 22		0101000020E61000000B9A9658191B4F40F9A3A833F7CC4B40
10917	6	58	1449	18938	43596	\N	55.630619000000003	Челябинская область, Красноармейский муниципальный район, Теренкульское сельское поселение, деревня Теренкуль, Мира, 21		0101000020E61000001DACFF7398274F403D9E961FB8D04B40
10892	6	58	1449	17638	43965	\N	55.152382000000003	Челябинская область, Красноармейский муниципальный район, Канашевское сельское поселение, село Таукаево, Салавата Юлаева, 9		0101000020E6100000F4C0C760C5134F40E23FDD4081934B40
10881	6	58	1449	17086	43768	\N	55.461918382711303	Челябинская область, Красноармейский муниципальный район, Бродокалмакское сельское поселение, село Тавранкуль, Школьная, 8	Россия, Челябинская область, Красноармейский район, поселок Тавранкуль	0101000020E610000054A86E2EFE104F4084B7072120BB4B40
10909	6	58	1449	18509	43784	\N	55.303637000000002	Челябинская область, Красноармейский муниципальный район, Озерное сельское поселение, деревня Сычево, Мира, 61		0101000020E61000006A4B1DE4F5D04E40836DC493DDA64B40
10914	6	58	1449	18741	43684	\N	55.739832999999997	Челябинская область, Красноармейский муниципальный район, Сугоякское сельское поселение, село Сугояк, Казанцева, 109		0101000020E6100000E6E5B0FB8E074F4033C005D9B2DE4B40
10898	6	58	1449	17928	43962	\N	55.380727999999998	Челябинская область, Красноармейский муниципальный район, Лазурненское сельское поселение, поселок Слава, Ленина, 32		0101000020E6100000ECDE8AC404D94E40F355F2B1BBB04B40
10919	6	58	1449	19051	44049	\N	55.347678999999999	Челябинская область, Красноармейский муниципальный район, Шумовское сельское поселение, д.Сафоново, ул. 40 лет Победы, д.1		0101000020E61000000F48C2BE9DFE4E40C440D7BE80AC4B40
10910	6	58	1449	18535	43682	\N	55.759927980849902	Челябинская область, Красноармейский муниципальный район, РусскоТеченское сельское поселение, село Русская Теча, Советская, 32	Россия, Челябинская область, Красноармейский район, поселок Русская Теча	0101000020E6100000B796C9703C194F4048A8195245E14B40
10875	6	58	1449	16811	44089	\N	55.151671999999998	Челябинская область, Красноармейский муниципальный район, Березовское сельское поселение, поселок Родник, Школьная, 4		0101000020E6100000A3E6ABE463F94E4005DCF3FC69934B40
10921	6	58	1449	19151	43785	\N	55.333542999999999	Челябинская область, Красноармейский муниципальный район, Шумовское сельское поселение, деревня Пятково, Лесная, 13		0101000020E6100000842C0B26FE0C4F40A5677A89B1AA4B40
10883	6	58	1449	17186	44087	\N	55.483851999999999	Челябинская область, Красноармейский муниципальный район, Бродокалмакское сельское поселение, село Попово, Центральная, 20		0101000020E61000001172DEFFC7F34E40560DC2DCEEBD4B40
10901	6	58	1449	18105	43969	\N	55.016883999999997	Челябинская область, Красноармейский муниципальный район, Луговское сельское поселение, деревня Печенкино, Школьная, 13		0101000020E6100000E694809884F34E40AFE9414129824B40
10238	6	58	1449	18397	44332	\N	55.227739234644197	Сельский ДК: поселок Петровский, ул. Чкалова, д. 18	Россия, Челябинская область, Красноармейский район, поселок Петровский	0101000020E61000003F1F65C405D04E400A83328D269D4B40
10907	6	58	1449	18397	42984	\N	55.225630000000002	Челябинская область, Красноармейский муниципальный район, Озерное сельское поселение, поселок Петровский, Ленина, 27		0101000020E610000065A54929E8CE4E408D7F9F71E19C4B40
10899	6	58	1449	55219	44295	\N	55.390583754240403	Челябинская область, Красноармейский муниципальный район, Лазурненское сельское поселение, д.Пашнино1, ул. Ленина, д.32	Россия, Челябинская область, Красноармейский район, поселок Пашнино 1-е	0101000020E610000048FB1F60ADDE4E40A12B11A8FEB14B40
10889	6	58	1449	17509	44093	\N	55.117148161066901	Челябинская область, Красноармейский муниципальный район, Канашевское сельское поселение, село Пашнино, Лесная, 11	Россия, Челябинская область, Красноармейский район, поселок Пашнино	0101000020E61000008F6E844545064F405A65A6B4FE8E4B40
10870	6	58	1449	16533	42898	\N	55.080117000000001	Челябинская область, Красноармейский муниципальный район, Березовское сельское поселение, поселок Октябрьский, Школьная, 1		0101000020E610000039ECBE6378E84E40446D1B46418A4B40
10908	6	58	1449	18430	43963	\N	55.212798495462302	Челябинская область, Красноармейский муниципальный район, Озерное сельское поселение, поселок Озерный, Центральная, 23	Россия, Челябинская область, Красноармейский район, поселок Озерный	0101000020E6100000054D4BAC8CD84E40BD5301F73C9B4B40
10911	6	58	1449	18619	44092	\N	55.824176999999999	Челябинская область, Красноармейский муниципальный район, РусскоТеченское сельское поселение, село Нижнепетропавловское, Труда, 57А		0101000020E6100000B6D617096D1F4F40C58EC6A17EE94B40
10893	6	58	1449	37842	42981	\N	45.249716999999997	Челябинская область, Красноармейский муниципальный район, Козыревское сельское поселение, поселок Мирный, Пионерская, 2		0101000020E6100000D6E1E82ADD294340AB2006BAF69F4640
10905	6	58	1449	18134	42982	\N	55.283881999999998	Челябинская область, Красноармейский муниципальный район, Миасское сельское поселение, село Миасское, Школьная, 2А		0101000020E61000004FADBEBA2AF24E4027F6D03E56A44B40
11447	6	58	1235	12653	43184	\N	53.040726999999997	Челябинская область, поселок Локомотивный, Ленина, 88		0101000020E610000082ACA7565F4D4E403788D68A36854A40
10904	6	58	1449	18134	43230	\N	55.282706278036102	Челябинская область, Красноармейский муниципальный район, Миасское сельское поселение, село Миасское, Советская, 14	Россия, Челябинская область, Красноармейский район, поселок Миасское	0101000020E6100000B2F4A10BEAF14E400531D0B52FA44B40
10903	6	58	1449	18134	43230	\N	55.283881999999998	Челябинская область, Красноармейский муниципальный район, Миасское сельское поселение, село Миасское, Советская, 8		0101000020E61000004FADBEBA2AF24E4027F6D03E56A44B40
10902	6	58	1449	18134	42596	\N	55.283881999999998	Челябинская область, Красноармейский муниципальный район, Миасское сельское поселение, село Миасское, Пионера, 30		0101000020E61000004FADBEBA2AF24E4027F6D03E56A44B40
10900	6	58	1449	18030	43643	\N	55.024616000000002	Челябинская область, Красноармейский муниципальный район, Луговское сельское поселение, поселок Луговой, Советская, 4		0101000020E6100000F1F3DF83D7DC4E40AB7AF99D26834B40
10894	6	58	1449	17727	43754	\N	55.242913044596399	Челябинская область, Красноармейский муниципальный район, Козыревское сельское поселение, поселок Лесной, Северная, 14	Россия, Челябинская область, Красноармейский район, поселок Лесной	0101000020E610000096986725ADF64E40FA62EFC5179F4B40
10897	6	58	1449	17912	42647	\N	55.356062999999999	Челябинская область, Красноармейский муниципальный район, Лазурненское сельское поселение, поселок Лазурный, Космонавтов, 3А		0101000020E61000001C7E37DDB2D74E406728EE7893AD4B40
10895	6	58	1449	17811	44214	\N	55.271641000000002	Челябинская область, Красноармейский муниципальный район, Козыревское сельское поселение, поселок Курейное, Трактовая, 7		0101000020E610000056116E32AA024F405AA0DD21C5A24B40
10915	6	58	1449	18839	43893	\N	55.822225913089603	Челябинская область, Красноармейский муниципальный район, Сугоякское сельское поселение, село Кирды, Юбилейная, 51	Россия, Челябинская область, Красноармейский район, поселок Кирды	0101000020E6100000DD0720B589074F40E0F599B33EE94B40
10888	6	58	1449	17409	42900	\N	55.210675000000002	Челябинская область, Красноармейский муниципальный район, Канашевское сельское поселение, село Канашево, Солнечная, 2		0101000020E61000009A95ED43DE084F40DB8AFD65F79A4B40
10887	6	58	1449	17409	42807	\N	55.210675000000002	Челябинская область, Красноармейский муниципальный район, Канашевское сельское поселение, село Канашево, Механизаоров, 29		0101000020E61000009A95ED43DE084F40DB8AFD65F79A4B40
10890	6	58	1449	17540	43751	\N	55.080647999999997	Челябинская область, Красноармейский муниципальный район, Канашевское сельское поселение, село КалугаСоловьевка, Центральная, 6		0101000020E6100000A321E3512A1D4F40703E75AC528A4B40
10886	6	58	1449	17335	42803	\N	55.436188000000001	Челябинская область, Красноармейский муниципальный район, Дубровское сельское поселение, поселок Дубровка, Ленина, 1		0101000020E6100000359BC76130D34E402E742502D5B74B40
10879	6	58	1449	17010	42980	\N	55.573484999999998	Челябинская область, Красноармейский муниципальный район, Бродокалмакское сельское поселение, село Бродокалмак, Первая Краснознаменная, 5		0101000020E6100000705E9CF86A094F408FDFDBF467C94B40
10880	6	58	1449	17010	43678	\N	55.573484999999998	Челябинская область, Красноармейский муниципальный район, Бродокалмакское сельское поселение, село Бродокалмак, Могильникова, 51 Б		0101000020E6100000705E9CF86A094F408FDFDBF467C94B40
10884	6	58	1449	17227	44088	\N	55.440942999999997	Челябинская область, Красноармейский муниципальный район, Бродокалмакское сельское поселение, деревня Боровое, Центральная, 9		0101000020E6100000BD378600E0FE4E403733FAD170B84B40
10891	6	58	1449	17623	43959	\N	55.089391999999997	Челябинская область, Красноармейский муниципальный район, Канашевское сельское поселение, деревня Берсеневка, Школьная, 11		0101000020E6100000E4BA29E5B5144F4013437232718B4B40
10871	6	58	1449	16601	43956	\N	55.130245000000002	Челябинская область, Красноармейский муниципальный район, Березовское сельское поселение, поселок Березово, Школьная, 8		0101000020E61000005B23827170E54E40D8BB3FDEAB904B40
10877	6	58	1449	16879	43750	\N	55.311005999999999	Челябинская область, Красноармейский муниципальный район, Баландинское сельское поселение, поселок Береговой, Образцовая, 2		0101000020E6100000C6A2E9EC64C84E400D6E6B0BCFA74B40
10912	6	58	1449	18652	43961	\N	55.701946999999997	Челябинская область, Красноармейский муниципальный район, РусскоТеченское сельское поселение, село Беликуль, Центральная, 20		0101000020E610000016DEE522BE374F403D433866D9D94B40
10868	6	58	1449	16451	43792	\N	55.528813999999997	Челябинская область, Красноармейский муниципальный район, Алабугское сельское поселение, село Ачликуль, Школьная, 1		0101000020E610000026FBE769C0364F405ED5592DB0C34B40
10867	6	58	1449	16387	43668	\N	55.535263999999998	Челябинская область, Красноармейский муниципальный район, Алабугское сельское поселение, село Алабуга, Комсомольская, 20 А		0101000020E6100000014EEFE2FD2C4F40F25CDF8783C44B40
11670	6	58	1732	55096	\N	\N	55.092314000000002	Челябинская область, г. Копейск, ДК им. Вахрушева ул. Железняка, 2а, 1 этаж, зал		0101000020E6100000569FABADD8CF4E40427BF5F1D08B4B40
11720	6	58	1732	25974	42936	\N	54.936563045814403	Челябинская область, г. Копейск, село Калачево, ул. Зеленая, 9	Россия, Челябинская область, Копейск городской округ, поселок Калачево	0101000020E61000004C55DAE21AC54E4063D2DF4BE1774B40
11717	6	58	1732	25820	43911	\N	55.010410999999998	Челябинская область, г. Копейск, поселок Заозерный, ул. Проектная, 17А	Россия, Челябинская область, Копейск городской округ, поселок Заозерный	0101000020E6100000431B800D88C64E406342CC2555814B40
11969	6	58	835	6102	44047	\N	52.639482999999998	Челябинская область, Кизильский муниципальный район, Новопокровское сельское поселение, поселок Чернышевский, Российская, 5		0101000020E6100000651D8EAED2694D408AAC3594DA514A40
11526	6	58	835	16377	44219	\N	52.688682	Челябинская область, Кизильский муниципальный район, Полоцкое сельское поселение, поселок Черкасы, Береговая, 3		0101000020E61000001DE38A8BA3D44D4004AC55BB26584A40
11972	6	58	835	6249	44048	\N	52.829034999999998	Челябинская область, Кизильский муниципальный район, Полоцкое сельское поселение, поселок Чапаевский, Центральная, 4		0101000020E61000005F0B7A6F0CD94D40A31EA2D11D6A4A40
11530	6	58	835	16600	43882	\N	52.731363000000002	Челябинская область, Кизильский муниципальный район, Измайловское сельское поселение, поселок Целинный, Дружбы, 20		0101000020E61000009AB1683A3BB34D409240834D9D5D4A40
11519	6	58	835	16054	44256	\N	52.618563999999999	Челябинская область, Кизильский муниципальный район, Уральское сельское поселение, поселок Урал, Центральная, 23		0101000020E610000067B45549647F4D40D13DEB1A2D4F4A40
11533	6	58	835	16744	44262	\N	52.8114520078881	Челябинская область, Кизильский муниципальный район, Сыртинское сельское поселение, поселок Увальский, Молодежная, 8 Б	Россия, Челябинская область, Кизильский район, поселок Увальский	0101000020E610000083A44FABE8714D400C23BDA8DD674A40
11532	6	58	835	16707	42802	\N	52.908644000000002	Челябинская область, Кизильский муниципальный район, Сыртинское сельское поселение, поселок Сыртинский, 60 лет Октября, 16	Россия, Челябинская область, Кизильский район, поселок Сыртинский	0101000020E6100000D7BE805EB8714D4073DA53724E744A40
11521	6	58	835	16129	44130	\N	52.678118402494199	Челябинская область, Кизильский муниципальный район, Уральское сельское поселение, поселок Смородинка, Центральная, 18	Россия, Челябинская область, Кизильский район, поселок Смородинка	0101000020E6100000A05225CADE844D401A6A1492CC564A40
11516	6	58	835	15898	44000	\N	52.702910000000003	Челябинская область, Кизильский муниципальный район, Обручевское сельское поселение, поселок Симбирка, Центральная, 23		0101000020E6100000FD8348861C994D40040473F4F8594A40
11522	6	58	835	16186	43577	\N	52.886435394579102	Челябинская область, Кизильский муниципальный район, Сельское поселение Путь Октября, поселок Путь Октября, Октябрьская, 3	Россия, Челябинская область, Кизильский район, поселок Путь Октября	0101000020E6100000C6F8307BD9BC4D40CF83BBB376714A40
11525	6	58	835	16319	42820	\N	52.768658000000002	Челябинская область, Кизильский муниципальный район, Полоцкое сельское поселение, село Полоцкое, Мира, 16		0101000020E610000088DA368C82DA4D4086E7A56263624A40
11538	6	58	835	16999	44079	\N	52.967056999999997	Челябинская область, Кизильский муниципальный район, Гранитное сельское поселение, поселок Первомайка, Школьная, 1		0101000020E610000054A9D903AD924D40162F1686C87B4A40
10352	6	58	835	16999	44079	\N	52.9664857394161	поселок Первомайка, Школьная, 1	Россия, Челябинская область, Кизильский район, поселок Первомайка	0101000020E6100000AF22A30392924D405C0531D0B57B4A40
11537	6	58	835	16947	44005	\N	52.817923	Челябинская область, Кизильский муниципальный район, Гранитное сельское поселение, поселок Октябрьский, Школьная, 1		0101000020E6100000713D0AD7A3884D40B7D26BB3B1684A40
11515	6	58	835	15840	43657	\N	52.766615000000002	Челябинская область, Кизильский муниципальный район, Обручевское сельское поселение, село Обручевка, Школьная, 12		0101000020E6100000A647533D999B4D40C0CFB87020624A40
11531	6	58	835	16636	43867	\N	52.599556	Челябинская область, Кизильский муниципальный район, Измайловское сельское поселение, поселок Новый Кондуровский, Школьная, 1		0101000020E6100000FF76D9AF3BB54D406F0F4240BE4C4A40
11518	6	58	835	55245	44327	\N	52.845183111825698	Челябинская область, Кизильский муниципальный район, Карабулакское сельское поселение, поселок Новый, Пионерская, 16	Россия, Челябинская область, Кизильский район, поселок Новый	0101000020E6100000B47405DB88A94D404D11E0F42E6C4A40
11511	6	58	835	15639	44004	\N	52.659813	Челябинская область, Кизильский муниципальный район, Новопокровское сельское поселение, поселок Новопокровский, Ленина, 45		0101000020E6100000BE67244223664D40E23C9CC074544A40
11514	6	58	835	15776	43658	\N	52.451067000000002	Челябинская область, Кизильский муниципальный район, Новоершовское сельское поселение, поселок Новоершовский, Центральная, 13		0101000020E6100000FAD51C20988F4D4005A73E90BC394A40
11527	6	58	835	16447	43879	\N	52.703488	Челябинская область, Кизильский муниципальный район, Полоцкое сельское поселение, поселок Новинка, Центральная, 5		0101000020E6100000BA9EE8BAF0F14D40719010E50B5A4A40
11970	6	58	835	6163	43889	\N	52.887545000000003	Челябинская область, Кизильский муниципальный район, Гранитное сельское поселение, поселок Мартыновка, Школьная, 6		0101000020E61000005C397B67B4894D403A5D16139B714A40
11638	6	58	835	16212	43913	\N	52.899818000000003	поселок Лесной, Центральная, 39		0101000020E6100000AC1E300F99C24D40132D793C2D734A40
11523	6	58	835	16212	43913	\N	52.899818000000003	Челябинская область, Кизильский муниципальный район, Сельское поселение Путь Октября, поселок Лесной, Центральная, 23		0101000020E6100000AC1E300F99C24D40132D793C2D734A40
11971	6	58	835	6214	43151	\N	52.722276740937303	Челябинская область, Кизильский муниципальный район, Кизильское сельское поселение, с.Кизильское, Советская, 67 Б	Россия, Челябинская область, Кизильский район, поселок Кизильское	0101000020E6100000C367EBE060734D4095D39E92735C4A40
11498	6	58	835	6214	43151	\N	52.723520999999998	Челябинская область, Кизильский муниципальный район, Кизильское сельское поселение, село Кизильское, Советская, 67 Б		0101000020E6100000DB148F8B6A734D400F7C0C569C5C4A40
11510	6	58	835	6214	42966	\N	52.723520999999998	Челябинская область, Кизильский муниципальный район, Кизильское сельское поселение, село Кизильское, Комсомольская, 60		0101000020E6100000DB148F8B6A734D400F7C0C569C5C4A40
11528	6	58	835	16476	43543	\N	52.959766999999999	Челябинская область, Кизильский муниципальный район, Кацбахское сельское поселение, поселок Кацбахский, Труда, 18		0101000020E6100000925A28999CD24D40D86322A5D97A4A40
11517	6	58	835	15929	44253	\N	52.893397	Челябинская область, Кизильский муниципальный район, Карабулакское сельское поселение, поселок Карабулак, Центральная, 15		0101000020E61000008159A148F7934D4019AC38D55A724A40
11539	6	58	835	17037	44269	\N	52.844152000000001	Челябинская область, Кизильский муниципальный район, Гранитное сельское поселение, поселок Ильинка, Набережная, 12		0101000020E6100000696FF085C9724D402F6D382C0D6C4A40
11529	6	58	835	16536	42801	\N	52.661479	Челябинская область, Кизильский муниципальный район, Измайловское сельское поселение, поселок Измайловский, Школьная, 2		0101000020E61000007EC7F0D8CFA64D40D2FE0758AB544A40
11534	6	58	835	16810	43194	\N	52.992401721302897	Челябинская область, Кизильский муниципальный район, Зингейское сельское поселение, поселок Зингейский, Парковая, 16	Россия, Челябинская область, Кизильский район, поселок Зингейский	0101000020E6100000E98024ECDBC54D40143E5B07077F4A40
11520	6	58	835	16073	43864	\N	52.605922	Челябинская область, Кизильский муниципальный район, Уральское сельское поселение, поселок Ждановский, Центральная, 18		0101000020E6100000D9976C3CD8984D40A5F622DA8E4D4A40
11513	6	58	835	15760	43865	\N	52.548136999999997	Челябинская область, Кизильский муниципальный район, Богдановское сельское поселение, поселок Грязнушинский, Советская, 44		0101000020E61000005303CDE7DC7B4D40205D6C5A29464A40
11536	6	58	835	16875	43532	\N	52.974595000000001	Челябинская область, Кизильский муниципальный район, Гранитное сельское поселение, поселок Гранитный, переулок Школьный, 3		0101000020E6100000C1FEEBDCB47B4D402DEC6987BF7C4A40
11535	6	58	835	16863	44261	\N	53.021842999999997	Челябинская область, Кизильский муниципальный район, Зингейское сельское поселение, п.Браиловский, Центральная, 11		0101000020E610000031EE06D15AB14D40C1525DC0CB824A40
11512	6	58	835	15685	43536	\N	52.417954000000002	Челябинская область, Кизильский муниципальный район, Богдановское сельское поселение, село Богдановское, Мира, 5		0101000020E61000008F6FEF1AF4874D40BF9D44847F354A40
11524	6	58	835	16276	43868	\N	52.795653000000001	Челябинская область, Кизильский муниципальный район, Сельское поселение Путь Октября, поселок Амамбайка, Школьная, 1		0101000020E6100000F5A10BEA5BC04D406EFB1EF5D7654A40
10853	6	58	954	55107	43702	\N	54.856000749139703	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, переулок Мичурина, д.1	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E61000004512BD8C62354D40F12BD670916D4B40
10850	6	58	954	55107	42769	\N	54.855753161667799	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, ул.Советская, д.108	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E6100000A019C40776364D40193A7650896D4B40
10849	6	58	954	55107	42769	\N	54.855901714334202	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, ул.Советская, д.100	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E61000004BE9995E62364D405E4A5D328E6D4B40
10848	6	58	954	55107	42769	\N	54.859113999999998	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, ул.Советская, д.61	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E610000072C0AE264F374D4093C49272F76D4B40
10847	6	58	954	55107	42769	\N	54.857133345644797	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, ул.Советская, д.57	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E610000084F3A96395364D4043A9BD88B66D4B40
10846	6	58	954	55107	42769	\N	54.857826562891397	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, ул.Советская, д.22	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E610000072A43330F2364D401A506F46CD6D4B40
10852	6	58	954	55107	43095	\N	54.857090115880503	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, ул.Сахарова, д.8	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E6100000D8BAD408FD364D4044DD0720B56D4B40
10851	6	58	954	55107	43285	\N	54.859113999999998	Челябинская область, КатавИвановский муниципальный район, Юрюзанское городское поселение, ул.3 Интернационала, д.55	Россия, Челябинская область, Катав-Ивановский район, Юрюзань	0101000020E610000072C0AE264F374D4093C49272F76D4B40
10865	6	58	954	16275	43960	\N	54.964979999999997	Челябинская область, КатавИвановский муниципальный район, Серпиевское сельское поселение, поселок Шарлаш, ул.Уральская, д.15а		0101000020E61000006EFB1EF5D7F74C40A4A5F276847B4B40
10859	6	58	954	15977	43955	\N	54.611012000000002	Челябинская область, КатавИвановский муниципальный район, Тюлюкское сельское поселение, село Тюлюк, ул.Ленина, д.43		0101000020E61000002DCF83BBB3624D4056BB26A4354E4B40
10776	6	58	954	11614	42745	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, Островского, 16		0101000020E610000015FDA19927394D40F168E388B5684B40
10771	6	58	954	11614	42888	\N	54.814520755268198	Челябинская область, Трехгорный городской округ, Мира, 30	Россия, Челябинская область, Катав-Ивановский район, Трехгорный	0101000020E610000064CBF275193A4D40DE73603942684B40
10770	6	58	954	11614	42888	\N	54.815549288082401	Челябинская область, Трехгорный городской округ, Мира, 20	Россия, Челябинская область, Катав-Ивановский район, Трехгорный	0101000020E6100000F08975AA7C394D408BA4DDE863684B40
10769	6	58	954	11614	42888	\N	54.815313843133303	Челябинская область, Трехгорный городской округ, Мира, 17	Россия, Челябинская область, Катав-Ивановский район, Трехгорный	0101000020E61000002E54FEB5BC384D4048FC8A355C684B40
10767	6	58	954	11614	43088	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, Ленина, 6		0101000020E610000015FDA19927394D40F168E388B5684B40
10772	6	58	954	11614	43089	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, Космонавтов, 20а		0101000020E610000015FDA19927394D40F168E388B5684B40
10780	6	58	954	11614	42748	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, К.Маркса, 30а		0101000020E610000015FDA19927394D40F168E388B5684B40
10768	6	58	954	11614	42876	\N	54.814867733133603	Челябинская область, Трехгорный городской округ, Калинина, 3	Россия, Челябинская область, Катав-Ивановский район, Трехгорный	0101000020E610000050FC1873D7384D40494739984D684B40
10775	6	58	954	11614	42746	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, К.Маркса, 40а		0101000020E610000015FDA19927394D40F168E388B5684B40
10779	6	58	954	11614	42751	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, 60 лет Октября, 14		0101000020E610000015FDA19927394D40F168E388B5684B40
10773	6	58	954	11614	42751	\N	54.816503445605598	Челябинская область, Трехгорный городской округ, 60 лет Октября, 6	Россия, Челябинская область, Катав-Ивановский район, Трехгорный	0101000020E6100000DB31755776394D40FE0A992B83684B40
10774	6	58	954	11614	43227	\N	54.818040000000003	Челябинская область, Трехгорный городской округ, 50 лет Победы, 20		0101000020E610000015FDA19927394D40F168E388B5684B40
10858	6	58	954	15927	\N	\N	54.830373000000002	Челябинская область, КатавИвановский муниципальный район, Лесное сельское поселение, поселок Совхозный, помещение администрации поселка, д.34		0101000020E6100000AE2B6684B72F4D409F3D97A9496A4B40
10863	6	58	954	16183	43781	\N	54.858595000000001	Челябинская область, КатавИвановский муниципальный район, Серпиевское сельское поселение, село Серпиевка, ул.Карла Маркса, д.34А		0101000020E6100000349E08E23CEE4C402BC1E270E66D4B40
10842	6	58	954	15179	\N	\N	54.7958119521792	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, поселок Половинка, ул.Станционная, д.станция ПоловинкаКатавская	Россия, Челябинская область, Катав-Ивановский район, поселок Половинка	0101000020E6100000CB4A9352D0234D40D6E1E82ADD654B40
10862	6	58	954	16137	44271	\N	54.872930465768498	Челябинская область, КатавИвановский муниципальный район, Орловское сельское поселение, село Орловка, пер.1 Советский, д.1Б	Россия, Челябинская область, Катав-Ивановский район, поселок Орловка	0101000020E610000078431A15380B4D4040D9942BBC6F4B40
10860	6	58	954	7882	44091	\N	54.770853000000002	Челябинская область, КатавИвановский муниципальный район, Месединское сельское поселение, село Меседа, ул.Советская, д.51		0101000020E61000001E32E54350594D400283A44FAB624B40
10855	6	58	954	15781	43779	\N	54.623612999999999	Челябинская область, КатавИвановский муниципальный район, Бедярышское сельское поселение, поселок Лемеза, ул.Островная, д.2		0101000020E61000005BEECC04C3ED4C40232E008DD24F4B40
10866	6	58	954	16325	43782	\N	54.778092000000001	Челябинская область, КатавИвановский муниципальный район, Серпиевское сельское поселение, село Карауловка, ул.Ворошилова, д.2		0101000020E61000004A0B9755D8FE4C40BEA3C68498634B40
10832	6	58	954	14446	43540	\N	54.617915000000004	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.УстьКатавская, д.78а		0101000020E6100000E751F17F47244D409B5AB6D6174F4B40
10835	6	58	954	14446	42750	\N	54.617915000000004	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Свердловская, д.50а		0101000020E6100000E751F17F47244D409B5AB6D6174F4B40
10837	6	58	954	14446	44272	\N	54.617915000000004	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Олега Кошевого, д.15б		0101000020E6100000E751F17F47244D409B5AB6D6174F4B40
10856	6	58	954	14446	44043	\N	54.617915000000004	Челябинская область, КатавИвановский муниципальный район, ВерхКатавское сельское поселение, село ВерхКатавка, ул.Нагорнова, 7		0101000020E6100000E751F17F47244D409B5AB6D6174F4B40
10844	6	58	954	14446	43229	\N	54.617915000000004	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Ленинградская, д.32а		0101000020E6100000E751F17F47244D409B5AB6D6174F4B40
10843	6	58	954	14446	42752	\N	54.617915000000004	Челябинская область, КатавИвановский муниципальный район, КатавИвановское городское поселение, ул.Восточная, д.31а		0101000020E6100000E751F17F47244D409B5AB6D6174F4B40
10854	6	58	954	15762	43968	\N	54.653063083472503	Челябинская область, КатавИвановский муниципальный район, Бедярышское сельское поселение, село Бедярыш, ул.Центральная, д.45	Россия, Челябинская область, Катав-Ивановский район, поселок Бедярыш	0101000020E61000009CDEC5FB71D94C40249D819197534B40
10864	6	58	954	16215	44275	\N	54.8902914602481	Челябинская область, КатавИвановский муниципальный район, Серпиевское сельское поселение, село Аратское, ул.Пролетарская, д.21а	Россия, Челябинская область, Катав-Ивановский район, поселок Аратское	0101000020E61000002864E76D6CF24C402976340EF5714B40
10815	6	58	1255	13877	44264	\N	56.068212507462	Челябинская область, Каслинский муниципальный район, Огневское сельское поселение, село Юшково, ул.Ленина, д.37	Россия, Челябинская область, Каслинский район, поселок Юшково	0101000020E6100000ED82C13577AE4E40BE141E34BB084C40
10812	6	58	1255	13722	43776	\N	56.188322999999997	Челябинская область, Каслинский муниципальный район, Григорьевское сельское поселение, село Щербаковка, ул.Колхозная, д.2		0101000020E6100000EBFCDB65BF744E40D40AD3F71A184C40
10824	6	58	1255	14316	43690	\N	56.216628999999998	Челябинская область, Каслинский муниципальный район, Шабуровское сельское поселение, село Шабурово, ул.Парковая, д.2		0101000020E6100000B7B585E7A59E4E40BE2EC37FBA1B4C40
10808	6	58	1255	13572	44082	\N	56.184460000000001	Челябинская область, Каслинский муниципальный район, Воздвиженское сельское поселение, поселок Черкаскуль, ул.Ленина, д.23		0101000020E61000003D9B559FAB6D4E40C8B5A1629C174C40
10817	6	58	1255	55218	44293	\N	56.054415270152496	Челябинская область, Каслинский муниципальный район, Огневское сельское поселение, д.УстьКараболка, ул.Ленина, д.25	Россия, Челябинская область, Каслинский район, поселок Усть-Караболка	0101000020E61000004016A243E0D64E40B7B41A12F7064C40
10819	6	58	1255	14018	42749	\N	56.057058183041697	Челябинская область, Каслинский муниципальный район, Тюбукское сельское поселение, с. Тюбук, ул.Ленина, д.8	Россия, Челябинская область, Каслинский район, поселок Тюбук	0101000020E6100000EE42739D46784E40D2FC31AD4D074C40
10818	6	58	1255	14018	42755	\N	56.054944999999996	Челябинская область, Каслинский муниципальный район, Тюбукское сельское поселение, с.Тюбук, ул.Гагарина, д.2		0101000020E610000052F2EA1C03784E40130A117008074C40
10826	6	58	1255	14424	44267	\N	56.306969868105298	Челябинская область, Каслинский муниципальный район, Шабуровское сельское поселение, село Тимино, ул.Ленина, ДК с.Тимино	Россия, Челябинская область, Каслинский район, поселок Тимино	0101000020E6100000D4601A868F9A4E40336DFFCA4A274C40
11114	6	58	1255	28226	43439	\N	56.061529	Челябинская область, Снежинский городской округ, 40 лет Октября, 15	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000C6C37B0E2C5F4E40B760A92EE0074C40
11127	6	58	1255	28226	42778	\N	56.061921042709599	Челябинская область, Снежинский городской округ, Строителей, 20	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E61000008B5242B0AA5E4E40C2F7FE06ED074C40
11119	6	58	1255	28226	42994	\N	56.083499806451201	Челябинская область, Снежинский городской округ, Свердлова, 13	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E610000084D89942E75D4E40A69BC420B00A4C40
11111	6	58	1255	28226	42993	\N	56.072356018903598	Челябинская область, город Снежинск, Нечая, 5	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000C4995FCD01604E40AED51EF642094C40
11125	6	58	1255	28226	43447	\N	56.0597120755139	Челябинская область, Снежинский городской округ, Мира, 22	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E61000009885764EB35C4E40E1968FA4A4074C40
11124	6	58	1255	28226	43447	\N	56.072003843919802	Челябинская область, Снежинский городской округ, Мира, 15		0101000020E6100000B64B1B0E4B5F4E403197546D37094C40
11118	6	58	1255	28226	43434	\N	56.061440843259902	Челябинская область, Снежинский городской округ, Ленина, 50	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000D3F6AFAC345D4E4018D1764CDD074C40
11126	6	58	1255	28226	43274	\N	56.061921042709599	Челябинская область, Снежинский городской округ, Комсомольская, 8	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E61000002DB29DEFA75E4E40C2F7FE06ED074C40
11123	6	58	1255	28226	43274	\N	56.069507396976299	Челябинская область, Снежинский городской округ, Комсомольская, 6	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E61000003C1570CFF35F4E40EAEBF99AE5084C40
11122	6	58	1255	28226	43274	\N	56.068739226788502	Челябинская область, Снежинский городской округ, Комсомольская, 4	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E61000003FE5982CEE5F4E40D97A8670CC084C40
11112	6	58	1255	28226	43274	\N	56.060960637804598	Челябинская область, Снежинский городской округ, Комсомольская, 2	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000A5BE2CEDD45E4E406DAAEE91CD074C40
11128	6	58	1255	28226	44313	\N	56.058559520441598	Челябинская область, Снежинский городской округ, Кирова, 2а	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000A88E554ACF5E4E40486DE2E47E074C40
11121	6	58	1255	28226	43162	\N	56.069801458057398	Челябинская область, Снежинский городской округ, Забабахина, 1	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000710168942E5F4E40321D3A3DEF084C40
11108	6	58	1255	28226	43435	\N	56.082587935194297	Челябинская область, Снежинский городской округ, Дзержинского, 39	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000CFF753E3A55D4E4062855B3E920A4C40
11117	6	58	1255	28226	43001	\N	56.072284008946099	Челябинская область, Снежинский городской округ, Васильева, 35	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E61000000859164CFC5D4E401503249A40094C40
8228	6	58	339	16217	43914	\N	55.182032999999997	деревня Куянбаева, Колхозная, 14		0101000020E61000009B3924B5503E4E4079E57ADB4C974B40
11116	6	58	1255	28226	43001	\N	56.089642374314302	Челябинская область, Снежинский городской округ, Васильева, 54	Россия, Челябинская область, Каслинский район, Снежинск	0101000020E6100000605628D2FD5C4E408C2C9963790B4C40
11113	6	58	1255	28226	42906	\N	56.061529	Челябинская область, город Снежинск, 40 лет Октября, 7		0101000020E6100000C6C37B0E2C5F4E40B760A92EE0074C40
10803	6	58	1255	13315	43774	\N	56.179079000000002	Челябинская область, Каслинский муниципальный район, Багарякское сельское поселение, село Полднево, ул.Центральная, д.20		0101000020E6100000DF50F86C1DD24E404033880FEC164C40
10814	6	58	1255	13852	43641	\N	56.111948333552697	Адрес УИК для голосования: Челябинская область, Каслинский муниципальный район, Огневское сельское поселение, с.Огневское, ул.Школьная, д.1А, Адрес УИК: с. Огневское, ул.Ленина, д.67	Россия, Челябинская область, Каслинский район, поселок Огневское	0101000020E6100000807D74EACAC14E40226DE34F540E4C40
10813	6	58	1255	13782	43500	\N	55.907187999999998	Адрес УИК для голосования: Челябинская область, Каслинский муниципальный район, Маукское сельское поселение, п. Маук, ул.Школьная, д.15, Адрес УИК: п.Маук, ул.Железнодорожная, д.2		0101000020E6100000B9895A9A5B3B4E406DA983BC1EF44B40
10825	6	58	1255	14354	44086	\N	56.291569000000003	Челябинская область, Каслинский муниципальный район, Шабуровское сельское поселение, село Ларино, ул.Ленина, школа с.Ларино		0101000020E61000004C530438BDA54E4083C30B2252254C40
10816	6	58	1255	13942	43954	\N	56.007237000000003	Челябинская область, Каслинский муниципальный район, Огневское сельское поселение, деревня Кызылова, ул.Береговая, д.41		0101000020E61000001900AAB871D34E401C295B24ED004C40
10822	6	58	1255	14233	43778	\N	55.966850999999998	Челябинская область, Каслинский муниципальный район, Тюбукское сельское поселение, поселок Красный Партизан, ул.Победы, ДК п.Красный Партизан		0101000020E6100000DCBC7152987B4E406D8D08C6C1FB4B40
10802	6	58	1255	13303	44083	\N	56.146523815143297	Челябинская область, Каслинский муниципальный район, Багарякское сельское поселение, село Клепалово, ул.Береговая, д.32	Россия, Челябинская область, Каслинский район, поселок Клепалово	0101000020E61000009293895B05CD4E40200A664CC1124C40
10810	6	58	1255	13648	43777	\N	56.138879000000003	Челябинская область, Каслинский муниципальный район, Григорьевское сельское поселение, село Клеопино, ул.Новгородцева, д.10		0101000020E61000000D1B65FD66764E40F48C7DC9C6114C40
10801	6	58	1255	13231	43873	\N	56.194844000000003	Челябинская область, Каслинский муниципальный район, Багарякское сельское поселение, село Зотино, ул.Трактовая, д.22		0101000020E61000002D5F97E13FD54E4032E9EFA5F0184C40
10811	6	58	1255	13709	44085	\N	56.113430999999999	Челябинская область, Каслинский муниципальный район, Григорьевское сельское поселение, деревня Знаменка, ул.Ленина, д.32А		0101000020E6100000F25F200890714E4021AD31E8840E4C40
10809	6	58	1255	13587	44016	\N	56.158650999999999	Челябинская область, Каслинский муниципальный район, Григорьевское сельское поселение, деревня Григорьевка, ул.Ленина, д.6		0101000020E61000005C2041F163784E40253D0CAD4E144C40
10821	6	58	1255	14158	43967	\N	56.06861	Челябинская область, Каслинский муниципальный район, Тюбукское сельское поселение, село Воскресенское, ул.1е Мая, д.8		0101000020E6100000B5E0455F416A4E40DB166536C8084C40
10807	6	58	1255	13509	43890	\N	56.122103000000003	Челябинская область, Каслинский муниципальный район, Воздвиженское сельское поселение, поселок Воздвиженка, ул.Мира, д.55		0101000020E610000093382BA226644E402BDF3312A10F4C40
10795	6	58	1255	12947	44084	\N	55.998983489018599	Челябинская область, Каслинский муниципальный район, поселок Вишневогорск, ул.Школьная, д.5	Россия, Челябинская область, Каслинский район, поселок Вишневогорск	0101000020E61000009F573CF548534E404721C9ACDEFF4B40
10797	6	58	1255	12947	42895	\N	55.999223999999998	Челябинская область, Каслинский муниципальный район, поселок Вишневогорск, ул.Советская, д.79		0101000020E61000002A1BD65416534E406CB07092E6FF4B40
10796	6	58	1255	12947	43231	\N	55.999223999999998	Челябинская область, Каслинский муниципальный район, поселок Вишневогорск, ул.Пионерская, д.13		0101000020E61000002A1BD65416534E406CB07092E6FF4B40
10806	6	58	1255	13463	43639	\N	56.086438999999999	Адрес УИК для голосования: Челябинская область, Каслинский муниципальный район, Булзинское сельское поселение, с. Булзи, ул.Октябрьская, д.1, Адрес УИК: с.Булзи, ул.Ленина, д.56		0101000020E610000025E99AC9378B4E40AA0CE36E100B4C40
11129	6	58	1255	29049	44225	\N	56.011856999999999	поселок Ближний Береговой, Центральная, 11		0101000020E6100000BCE82B4833644E40459DB98784014C40
10805	6	58	1255	13370	42892	\N	55.989773999999997	Адрес УИК для голосования : Челябинская область, Каслинский муниципальный район, Береговое сельское поселение, п.Береговой, ул.Суворова, д.17, Адрес УИК: п.Береговой, ул.Ленина, д.13		0101000020E61000005AF3E32F2DA44E402E3718EAB0FE4B40
10804	6	58	1255	13370	43562	\N	55.989773999999997	Челябинская область, Каслинский муниципальный район, Береговое сельское поселение, поселок Береговой, ул.Ленина, д.13		0101000020E61000005AF3E32F2DA44E402E3718EAB0FE4B40
10800	6	58	1255	13144	43561	\N	56.202850732990697	Челябинская область, Каслинский муниципальный район, Багарякское сельское поселение, село Багаряк, ул.Свердлова, д.22	Россия, Челябинская область, Каслинский район, поселок Багаряк	0101000020E61000004C1B0E4B03C14E40FF7A8505F7194C40
11509	6	58	1235	15570	44131	\N	52.975343000000002	Челябинская область, Карталинский муниципальный район, Варшавское сельское поселение, поселок Красный Яр, Северная, 45		0101000020E61000006C06B8205B3C4E40F7B0170AD87C4A40
10799	6	58	1255	13144	43640	\N	56.203377000000003	Адрес УИК для голосования : Челябинская область, Каслинский муниципальный район, Багарякское сельское поселение, с.Багаряк, ул.Пионерская, д.18, Адрес УИК: с.Багаряк, ул.К.Маркса, д.15		0101000020E6100000C119FCFD62C04E401AE1ED41081A4C40
10798	6	58	1255	13090	44236	\N	56.007896000000002	Челябинская область, Каслинский муниципальный район, Вишневогорское городское поселение, п. Аракуль, ул.Пионерская, д.10/2		0101000020E61000001DC87A6AF5434E4076E272BC02014C40
10820	6	58	1255	14142	43775	\N	55.999510000000001	Челябинская область, Каслинский муниципальный район, Тюбукское сельское поселение, деревня Аллаки, ул.Советская, школа д.Аллаки		0101000020E6100000D7C1C1DEC47C4E40320395F1EFFF4B40
11483	6	58	1235	14312	43528	\N	52.821503999999997	Челябинская область, Карталинский муниципальный район, ЮжноСтепное сельское поселение, поселок ЮжноСтепной, Мира, 3		0101000020E610000001A5A14621574E403FC4060B27694A40
11475	6	58	1235	13937	42922	\N	53.059629519133097	Челябинская область, Карталинский муниципальный район, Полтавское сельское поселение, поселок Центральный, пер.Центральный, 24	Россия, Челябинская область, Карталинский район, поселок Центральный	0101000020E610000029B000A60C5C4E4024EEB1F4A1874A40
11501	6	58	1235	15173	43896	\N	53.358980000000003	Челябинская область, Карталинский муниципальный район, Великопетровское сельское поселение, село Татищево, Пушкина, 1		0101000020E61000008AE5965643304E4084F57F0EF3AD4A40
11479	6	58	1235	14141	44259	\N	52.938335000000002	Челябинская область, Карталинский муниципальный район, Сухореченское сельское поселение, поселок Сухореченский, Юбилейная, 32		0101000020E61000003509DE90466F4E4099D87C5C1B784A40
11486	6	58	1235	14440	43700	\N	52.861308999999999	Челябинская область, Карталинский муниципальный район, Снежненское сельское поселение, поселок Снежный, Черемушки, 7		0101000020E6100000CDE49B6D6E024E400F60915F3F6E4A40
11482	6	58	1235	14282	44255	\N	53.025320999999998	Челябинская область, Карталинский муниципальный район, Сухореченское сельское поселение, Поселок Сенной, Гагарина, 10		0101000020E6100000DEE34C13B6654E407573F1B73D834A40
11505	6	58	1235	15368	44260	\N	53.098965999999997	Челябинская область, Карталинский муниципальный район, Анненское сельское поселение, поселок Родники, Школьная, 10		0101000020E610000082AAD1AB01464E403DB5FAEAAA8C4A40
10373	6	58	1235	15368	43632	\N	53.098965999999997	поселок Родники, Просвещения, 2а		0101000020E610000082AAD1AB01464E403DB5FAEAAA8C4A40
11480	6	58	1235	14159	43999	\N	52.944429999999997	Челябинская область, Карталинский муниципальный район, Сухореченское сельское поселение, поселок Рассветный, Набережная, 5		0101000020E6100000209738F240724E403EAE0D15E3784A40
11488	6	58	1235	14563	44252	\N	52.967714539560497	Челябинская область, Карталинский муниципальный район, Снежненское сельское поселение, поселок Песчанка, Лесная, 3	Россия, Челябинская область, Карталинский район, поселок Песчанка	0101000020E61000004B74965984F64D40A06CCA15DE7B4A40
11477	6	58	1235	14020	43859	\N	53.049860000000002	Челябинская область, Карталинский муниципальный район, Полтавское сельское поселение, поселок Первомайка, Центральная, 7		0101000020E6100000C26A2C616D784E4075B0FECF61864A40
11500	6	58	1235	15107	44140	\N	53.212006144011703	Челябинская область, Карталинский муниципальный район, Великопетровское сельское поселение, поселок Ольховка, Пьянзина, 44	Россия, Челябинская область, Карталинский район, поселок Ольховка	0101000020E6100000255D33F9664D4E4024473A03239B4A40
11476	6	58	1235	13997	44127	\N	53.090789999999998	"""Челябинская область, Карталинский муниципальный район, Полтавское сельское поселение, поселок Озерный, Школьная, 2""""А"""""""		0101000020E6100000959BA8A5B96F4E40E466B8019F8B4A40
11474	6	58	1235	13866	44258	\N	53.150868000000003	"""Челябинская область, Карталинский муниципальный район, Мичуринское сельское поселение, село Новониколаевка, Центральная, 27 """"А"""""""		0101000020E6100000876D8B321B6E4E40A80183A44F934A40
11481	6	58	1235	14230	43874	\N	52.942812000000004	"""Челябинская область, Карталинский муниципальный район, Сухореченское сельское поселение, поселок Новокатенино, Центральная, 1""""А"""""""		0101000020E6100000E00F3FFF3D624E4060234910AE784A40
11495	6	58	1235	55094	42676	\N	53.086245015915502	Челябинская область, Карталинский муниципальный район, Новокаолиновое сельское поселение, поселок Новокаолиновый, Кирова,2	Россия, Челябинская область, Карталинский район, поселок Степной	0101000020E6100000FAB660A92EF84D40C5387F130A8B4A40
11489	6	58	1235	14591	43656	\N	52.901442000000003	Челябинская область, Карталинский муниципальный район, Неплюевское сельское поселение, село Неплюевка, Слонова, 8		0101000020E6100000DE3CD521370F4E40D49E927362734A40
11508	6	58	1235	15501	44002	\N	52.924537000000001	Челябинская область, Карталинский муниципальный район, Варшавское сельское поселение, поселок Некрасово, Центральная, 1		0101000020E6100000A98592C9A92D4E409278793A57764A40
11473	6	58	1235	13851	43655	\N	53.108828000000003	"""Челябинская область, Карталинский муниципальный район, Мичуринское сельское поселение, поселок Мичуринский, Садовая, 1""""А"""""""		0101000020E6100000FA0AD28C45614E40CE716E13EE8D4A40
11494	6	58	1235	14836	44251	\N	53.173684000000002	Челябинская область, Карталинский муниципальный район, Еленинское сельское поселение, деревня Михайловка, Центральная, 17		0101000020E6100000CCF10A444FE64D4053EBFD463B964A40
11478	6	58	1235	12653	43188	\N	53.040726999999997	Челябинская область, поселок Локомотивный, Школьная, 25		0101000020E610000082ACA7565F4D4E403788D68A36854A40
11506	6	58	1235	15402	43878	\N	53.070237314356099	"""Челябинская область, Карталинский муниципальный район, Анненское сельское поселение, поселок Краснотал, Центральная, 39""""А"""""""	Россия, Челябинская область, Карталинский район, поселок Краснотал	0101000020E6100000663387A416424E400DFCA886FD884A40
11490	6	58	1235	14645	44128	\N	52.844386	Челябинская область, Карталинский муниципальный район, Неплюевское сельское поселение, поселок Коноплянка, Терешковой, 24		0101000020E610000061FF756EDA1E4E40A29927D7146C4A40
11493	6	58	1235	14803	44129	\N	53.037959999999998	Челябинская область, Карталинский муниципальный район, Еленинское сельское поселение, село Кизилчилик, Октябрьская, 29		0101000020E61000000C569C6A2DFC4D4030478FDFDB844A40
11487	6	58	1235	14504	44263	\N	52.784439999999996	Челябинская область, Карталинский муниципальный район, Снежненское сельское поселение, поселок Каракуль, Черемушки, 8		0101000020E6100000BF27D6A9F2094E404DD6A88768644A40
11497	6	58	1235	14992	43877	\N	53.111203443099299	"""Челябинская область, Карталинский муниципальный район, Новокаолиновое сельское поселение, поселок Запасное, ж.д. станция, Вокзальная, 21 """"А"""""""	Россия, Челябинская область, Карталинский район, поселок Запасное	0101000020E6100000A6B8AAECBB044E40CA1B60E63B8E4A40
11484	6	58	1235	14358	44001	\N	52.834356	Челябинская область, Карталинский муниципальный район, ЮжноСтепное сельское поселение, село Елизаветопольское, Центральная, 34		0101000020E6100000D49CBCC8044E4E40569C6A2DCC6A4A40
11492	6	58	1235	14736	43576	\N	53.117659000000003	Челябинская область, Карталинский муниципальный район, Еленинское сельское поселение, село Еленинка, Будаковой, 21		0101000020E6100000CFBC1C76DFEF4D40408A3A730F8F4A40
11496	6	58	1235	14916	43574	\N	53.164681981555503	Челябинская область, Карталинский муниципальный район, Новокаолиновое сельское поселение, поселок Джабык, ж.д. станция, Вокзальная, 2	Россия, Челябинская область, Карталинский район, поселок Джабык	0101000020E61000005FD0420246FB4D40B41EBE4C14954A40
11502	6	58	1235	15205	44134	\N	53.339040226848802	Челябинская область, Карталинский муниципальный район, Великопетровское сельское поселение, деревня Горная, Пушкина, 15	Россия, Челябинская область, Карталинский район, поселок Горная	0101000020E610000013B534B7423C4E409604A8A965AB4A40
11485	6	58	1235	14427	44250	\N	52.940365	Челябинская область, Карталинский муниципальный район, ЮжноСтепное сельское поселение, поселок Вишневый, Центральная, 17/2		0101000020E6100000FD4CBD6E114E4E40CAA65CE15D784A40
11499	6	58	1235	15077	43529	\N	53.249364999999997	Челябинская область, Карталинский муниципальный район, Великопетровское сельское поселение, село Великопетровка, Мира, 34		0101000020E61000000344C18C293E4E402EE23B31EB9F4A40
11507	6	58	1235	15465	43578	\N	52.845131000000002	Челябинская область, Карталинский муниципальный район, Варшавское сельское поселение, поселок Варшавка, Центральная, 34		0101000020E610000065355D4F742B4E40FBEAAA402D6C4A40
11503	6	58	1235	15270	43699	\N	53.122101999999998	Челябинская область, Карталинский муниципальный район, Анненское сельское поселение, село Анненское, Переселенческая, 24		0101000020E61000009FE5797077304E405A63D009A18F4A40
11504	6	58	1235	15270	43694	\N	53.121843752923098	Челябинская область, Карталинский муниципальный район, Анненское сельское поселение, село Анненское, Ленина, 8	Россия, Челябинская область, Карталинский район, поселок Анненское	0101000020E6100000D9EE1EA0FB304E405F9B8D95988F4A40
11491	6	58	1235	14716	43861	\N	53.034820000000003	Челябинская область, Карталинский муниципальный район, Неплюевское сельское поселение, поселок Акмулла, Гагарина, 7		0101000020E61000006C5B94D920134E40959F54FB74844A40
11661	6	58	852	23146	44222	\N	54.907997999999999	село Шибаево, Халтурина, 11		0101000020E610000019726C3D43D04E40AD6A494739744B40
11660	6	58	852	23114	44224	\N	54.822214944817603	село Шеломенцево, Центральная, 19	Россия, Челябинская область, Еткульский район, поселок Шеломенцево	0101000020E610000062F9F36DC1DA4E40ECA353573E694B40
11669	6	58	852	48686	43760	\N	54.95505	деревня Шатрово, Советская, 12		0101000020E6100000268BFB8F4CDF4E40BC0512143F7A4B40
11643	6	58	852	55208	44160	\N	54.782531724375097	село Таянды, Школьная, 1	Россия, Челябинская область, Еткульский район, поселок Таянды	0101000020E6100000FF04172B6A864E40680932022A644B40
11650	6	58	852	48352	44174	\N	54.728921284362798	деревня Сухоруково, Центральная, 6	Россия, Челябинская область, Еткульский район, поселок Сухоруково	0101000020E6100000B77C24253DD84E400E2F88484D5D4B40
11635	6	58	852	48053	44220	\N	54.711078000000001	село Соколово, Банная, 9		0101000020E6100000ED478AC8B0C44E40DA73999A045B4B40
11667	6	58	852	23428	43019	\N	54.910457000000001	село Селезян, Советская, 56		0101000020E6100000E964A9F57EE94E4007B5DFDA89744B40
11634	6	58	852	21932	43880	\N	54.714599	деревня Сарыкуль, Школьная, 17		0101000020E610000085B2F0F5B5CC4E408D60E3FA775B4B40
9025	6	58	852	19910	44151	\N	54.819927999999997	деревня Сары, Центральная, 19		0101000020E6100000FCC7427408A84E408F899466F3684B40
10936	6	58	852	19910	43642	\N	54.819927999999997	село Сары, Свердлова, 18		0101000020E6100000FCC7427408A84E408F899466F3684B40
11633	6	58	852	48016	44037	\N	54.766007000000002	поселок Приозерный, Школьная, 11		0101000020E610000061C26856B6B74E40E8C072840C624B40
11659	6	58	852	48503	44144	\N	54.773449999999997	деревня Потапово, Центральная, 38		0101000020E6100000753FA7203FDD4E40AC8BDB6800634B40
11655	6	58	852	48430	44147	\N	54.758116000000001	деревня Погудино, Молодежная, 18		0101000020E610000085B69C4B71014F408449F1F109614B40
11653	6	58	852	48399	43764	\N	54.742444999999996	деревня Погорелка, Береговая, 31		0101000020E61000001A8A3BDEE47B4E40130A1170085F4B40
11330	6	58	134	7094	44112	\N	54.043145000000003	поселок Сурменевский, Советская, 51		0101000020E6100000AF42CA4FAAD74D4033FE7DC685054B40
11663	6	58	852	55214	44193	\N	54.577004724028498	Помещение для голосования: село Писклово, ул.Колхозная, д.1а, село Писклово, ул. Советская, 3	Россия, Челябинская область, Еткульский район, поселок Писклово	0101000020E6100000026729594E024F407250C24CDB494B40
11658	6	58	852	55173	43788	\N	54.844253999999999	деревня Печенкино, Набережная, 22	Россия, Челябинская область, Еткульский район, поселок Печенкино	0101000020E6100000AC55BB26A4D14E4033C2DB83106C4B40
11656	6	58	852	22923	43675	\N	54.851976999999998	поселок Новобатурино, Центральная, 1		0101000020E61000006155BDFC4EAD4E40DBF813950D6D4B40
11649	6	58	852	22629	43951	\N	54.591797832607497	деревня Новобаландино, Молодежная, 25	Россия, Челябинская область, Еткульский район, поселок Новобаландино	0101000020E6100000302AA913D0DE4E404AEB6F09C04B4B40
11648	6	58	852	48312	44199	\N	54.654454000000001	деревня Николаевка, Береговая, 35а		0101000020E61000002A745E6397EC4E40425E0F26C5534B40
11666	6	58	852	48628	43765	\N	54.830995999999999	деревня Назарово, Даровского, 39		0101000020E6100000809A5AB6D6E34E40AC8DB1135E6A4B40
10359	6	58	852	45505	44183	\N	54.7148196706869	поселок Лебедевка, Центральная, 5	Россия, Челябинская область, Еткульский район, поселок Лебедевка	0101000020E6100000D943FB58C1FB4E406C43C5387F5B4B40
11662	6	58	852	48562	43762	\N	54.928851000000002	деревня Кораблево, Школьный пер, 1	Россия, Челябинская область, Еткульский район, поселок Кораблево	0101000020E6100000410C74ED0BDA4E40AFEDED96E4764B40
11665	6	58	852	48562	44148	\N	54.928851000000002	деревня Кораблево, Октябрьская, 7		0101000020E6100000410C74ED0BDA4E40AFEDED96E4764B40
11637	6	58	852	48084	44142	\N	54.817874000000003	Копытово, Мира, 19		0101000020E61000009A5C8C8175024F40D61F6118B0684B40
11652	6	58	852	6443	43115	\N	54.651755999999999	село Коелга, Чапаева, 6		0101000020E6100000574277499C734E40637C98BD6C534B40
11975	6	58	852	6443	42679	\N	54.651755999999999	село Коелга, Заречная, 8а		0101000020E6100000574277499C734E40637C98BD6C534B40
11647	6	58	852	22540	42928	\N	54.680206501387403	село Каратабан, Набережная, 27б	Россия, Челябинская область, Еткульский район, поселок Каратабан	0101000020E6100000261DE56036D94E4051C1E10511574B40
11657	6	58	852	22965	44166	\N	54.855910999999999	Челябинская область, Еткульский район, деревня Журавлево, Набережная, 24		0101000020E610000028D4D347E0D54E40B1A4DC7D8E6D4B40
11973	6	58	852	6348	43153	\N	54.827414431403902	Помещение для голосования: село Еткуль, ул. Пионерская, д.40, село Еткуль, ул.Певомайская, 40		0101000020E610000079944A7842CB4E405320B3B3E8694B40
11974	6	58	852	6348	42685	\N	54.831627245134499	село Еткуль, Ленина, 2	Россия, Челябинская область, Еткульский район, поселок Еткуль	0101000020E61000000458E4D70FCB4E403CBCE7C0726A4B40
11645	6	58	852	6348	42685	\N	54.825978445336503	село Еткуль, Ленина, 37	Россия, Челябинская область, Еткульский район, поселок Еткуль	0101000020E610000007280D350ACB4E40959BA8A5B9694B40
11644	6	58	852	6348	42685	\N	54.826473999999997	село Еткуль, Ленина, 30		0101000020E6100000793A579412CC4E40457F68E6C9694B40
11641	6	58	852	22259	43015	\N	54.795955786751598	село Еманжелинка, Октябрьская, 17а	Россия, Челябинская область, Еткульский район, поселок Еманжелинка	0101000020E610000019AC38D55AA64E400987DEE2E1654B40
11642	6	58	852	22259	43017	\N	54.800865000000002	село Еманжелинка, Заречная, 21а	Россия, Челябинская область, Еткульский район, поселок Еманжелинка	0101000020E6100000802BD9B111A64E406AC18BBE82664B40
11651	6	58	852	48377	43957	\N	54.791476000000003	село Долговка, Новая, 4		0101000020E61000009BCAA2B08B784E40D2C8E7154F654B40
11640	6	58	852	22239	43758	\N	54.839323	поселок Депутатский, Центральная, 5а		0101000020E6100000E49EAEEE58904E40EBE3A1EF6E6B4B40
11646	6	58	852	22485	43924	\N	54.643624000000003	поселок Грознецкий, Труда, 17		0101000020E61000000F0C207C28C74E40DA756F4562524B40
11639	6	58	852	48149	44167	\N	54.810273000000002	поселок Березняки, Лесная, 14		0101000020E6100000DAC87553CA974E4079EA9106B7674B40
11636	6	58	852	61087	77168	\N	54.799015902854897	Челябинская область, Еткульский район, помещение для голосования: село Белоусово, ул.Октябрьская , д.1	Россия, Челябинская область, Еткульский район, поселок Белоусово	0101000020E61000002F6AF7AB00F94E40897D022846664B40
11632	6	58	852	21840	43533	\N	54.812297000000001	поселок Белоносово, Советская, 15		0101000020E6100000EEEE01BA2FB94E40C8D11C59F9674B40
11630	6	58	852	21750	43579	\N	54.861323123752399	поселок Бектыш, Комсомольская, 12	Россия, Челябинская область, Еткульский район, поселок Бектыш	0101000020E610000075AF93FAB2B84E40742502D53F6E4B40
11664	6	58	852	48594	44189	\N	54.886015	деревня Аткуль, Школьная, 10		0101000020E610000012DA722EC5F14E40FA6184F068714B40
11319	6	58	134	6583	43898	\N	54.029285999999999	Челябинская область, Верхнеуральский муниципальный район, Петропавловское сельское поселение, поселок Этовна, (здание ФАП, 1 этаж), Молодежная 92		0101000020E6100000C47C7901F6074E40861DC6A4BF034B40
11338	6	58	134	7467	43818	\N	53.903455999999998	поселок Эстонский, Центральная, 26		0101000020E61000002618CE35CCB84D40FFAF3A72A4F34A40
11331	6	58	134	7174	44114	\N	54.053348	поселок Шеметовский, Мира, 8		0101000020E6100000E3DF675C38CA4D404CA7751BD4064B40
11333	6	58	134	7256	43014	\N	53.890441000000003	село Форштадт, Советская, 13		0101000020E6100000F31E679AB0994D403F027FF8F9F14A40
11306	6	58	134	5896	43910	\N	53.810205000000003	Челябинская область, Верхнеуральский муниципальный район, Краснинское сельское поселение, поселок Уфимский, ул. Школьная (здание школы, 1 этаж), 4		0101000020E61000009ECE15A584EA4D40210725CCB4E74A40
11298	6	58	134	5443	44109	\N	54.026572000000002	поселок Урлядинский, Дружбы, 37		0101000020E61000001BD5E940D6B54D40A27E17B666034B40
11314	6	58	134	6295	44229	\N	53.936168000000002	Челябинская область, Верхнеуральский муниципальный район, Петропавловское сельское поселение, поселок Томинский, (здание клуба, 1 этаж),  ул.Мира 3		0101000020E6100000761893FE5E204E40E7C75F5AD4F74A40
11304	6	58	134	5786	43981	\N	53.700766999999999	поселок Тайсара, Школьная, 1		0101000020E6100000312592E865744D40DA8EA9BBB2D94A40
11317	6	58	134	6449	44238	\N	53.946440000000003	поселок Сухтелинский, Школьная, 12		0101000020E61000008AC8B08A370A4E4029D027F224F94A40
11321	6	58	134	46396	42800	\N	53.708782999999997	поселок Спасский, Ленина, 33	Россия, Челябинская область, Верхнеуральский район, поселок Спасский	0101000020E6100000A06EA0C03B994D40FA7ABE66B9DA4A40
11307	6	58	134	46085	44233	\N	53.815181000000003	поселок Смирновский, Российская, 26		0101000020E610000040DCD5ABC8E44D4009A9DBD957E84A40
11303	6	58	134	5753	43599	\N	53.595503218190103	поселок Смеловский, Братьев Каширинных, 6	Россия, Челябинская область, Верхнеуральский район, поселок Смеловский	0101000020E6100000B8E52329E96D4D40BFD53A7139CC4A40
11334	6	58	134	7317	44243	\N	53.890675000000002	поселок Сафроновский, Школьная, 7		0101000020E6100000C2DCEEE53EAB4D40B22E6EA301F24A40
11336	6	58	134	7388	43811	\N	54.002679999999998	поселок Самарский, Советская, 48		0101000020E6100000249D8191979F4D40382D78D157004B40
11235	6	58	134	2024	43802	\N	53.6215216480078	поселок Сабановский, Ветеранов, 11/2	Россия, Челябинская область, Верхнеуральский район, поселок Сабановский	0101000020E61000001077F52A32AC4D404CDF6B088ECF4A40
11320	6	58	134	6627	43809	\N	53.846029000000001	поселок Полосинский, Солнечная, 14А		0101000020E610000094DBF63DEAB54D40DA3BA3AD4AEC4A40
11309	6	58	134	46130	44234	\N	53.853976000000003	поселок Подольский, Российская, 31		0101000020E610000023D8B8FE5DD34D40D2C8E7154FED4A40
11310	6	58	134	46155	42919	\N	54.010978587927198	поселок Петропавловский, Клубная, 1	Россия, Челябинская область, Верхнеуральский район, поселок Петропавловский	0101000020E610000013B9E00CFE0C4E40ADF886C267014B40
11332	6	58	134	7180	43812	\N	53.984794000000001	поселок Новоурлядинский, Уральская, 7		0101000020E6100000D427B9C326BE4D4005A6D3BA0DFE4A40
11315	6	58	134	6343	43806	\N	53.885469000000001	поселок Новотоминский, Школьная, 1		0101000020E61000002310AFEB17224E40984F560C57F14A40
11134	6	58	134	47284	44288	\N	53.633868	поселок Новоозерный, Солнечная, 2		0101000020E6100000A9893E1F65B44D408FFD2C9622D14A40
11313	6	58	134	6270	44237	\N	53.969427000000003	поселок Новокопаловский, Степная, 10		0101000020E610000061545227A0F54D40016E162F16FC4A40
11323	6	58	134	6764	44110	\N	53.758138000000002	поселок Нововоронинский, Молодежная, 10		0101000020E6100000354580D3BBA64D406CED7DAA0AE14A40
11337	6	58	134	7450	43813	\N	53.951416000000002	село Новоахуново, Клубная, 11		0101000020E61000005EDBDB2DC9A14D401172DEFFC7F94A40
11174	6	58	134	55148	43362	\N	54.144180294996197	Межозерное городское поселение, Центральная, 9	Россия, Челябинская область, Верхнеуральский район, поселок Межозерный	0101000020E61000007C4276DEC6B04D405F5E807D74124B40
11294	6	58	134	55148	43441	\N	54.144853388277198	Межозерное городское поселение, Спортивная, 9		0101000020E610000079909E2287B04D401EDD088B8A124B40
11295	6	58	134	55148	43405	\N	54.145188110058399	Межозерное городское поселение, Ленина, 5А	Россия, Челябинская область, Верхнеуральский район, поселок Межозерный	0101000020E61000002DB29DEFA7B04D40C5E2378595124B40
11327	6	58	134	6974	44242	\N	53.816558000000001	поселок Малый Бугодак, Московская, 39		0101000020E610000025EB7074957C4D40C2A4F8F884E84A40
11299	6	58	134	45908	43985	\N	54.068562	деревня Ложкина, Школьная, 13		0101000020E6100000815A0C1EA6A74D40CADFBDA3C6084B40
11318	6	58	134	46334	44217	\N	53.996287000000002	поселок Линевка, Юбилейная, 17		0101000020E6100000E1EB6B5D6A224E400937195586FF4A40
11312	6	58	134	6208	44115	\N	54.031485236298899	поселок Крутой Лог, Школьная, 1	Россия, Челябинская область, Верхнеуральский район, поселок Крутой Лог	0101000020E6100000FB21365838F54D4044A852B307044B40
11305	6	58	134	5824	42917	\N	53.917177000000002	поселок Краснинский, Советская, 54		0101000020E61000004C1AA37554D54D405BD2510E66F54A40
11311	6	58	134	46174	44106	\N	54.075238701489198	село Комсомольское, Школьная, 10	Россия, Челябинская область, Верхнеуральский район, поселок Комсомольское	0101000020E6100000D600A5A1460F4E401F317A6EA1094B40
11329	6	58	134	46569	43998	\N	53.795919825781702	поселок Кожанов, Центральная, 152	Россия, Челябинская область, Верхнеуральский район, поселок Кожанов	0101000020E6100000E02D90A0F88D4D40BD1DE1B4E0E54A40
11301	6	58	134	5622	43509	\N	53.638806000000002	село Кирса, Юбилейная, 19		0101000020E6100000E6AC4F3926794D408A3E1F65C4D14A40
11316	6	58	134	6445	43808	\N	54.102353000000001	поселок Кидышевский, Центральная, 29		0101000020E610000064E597C118F54D40E1D231E7190D4B40
11297	6	58	134	5347	44240	\N	54.117170000000002	поселок Карагайский, микрорайон Карагайский Бор, Здание пансионата		0101000020E610000090DD054A0AC24D404209336DFF0E4B40
11296	6	58	134	5347	42795	\N	54.117170000000002	поселок Карагайский, Советская, 5		0101000020E610000090DD054A0AC24D404209336DFF0E4B40
11302	6	58	134	5657	43977	\N	53.676634	поселок Казанцевский, Молодежная, 1		0101000020E610000011C7BAB88D7E4D404BAE62F19BD64A40
11322	6	58	134	46414	43991	\N	53.615599000000003	поселок Ивановский, Ленина, 21	Россия, Челябинская область, Верхнеуральский район, поселок Ивановский	0101000020E6100000BEA1F0D93A9C4D40A439B2F2CBCE4A40
11335	6	58	134	46682	43987	\N	53.841007361542403	поселок Дзержинка, Набережная, 4	Россия, Челябинская область, Верхнеуральский район, поселок Дзержинка	0101000020E61000001844A4A65D964D40815A0C1EA6EB4A40
11308	6	58	134	6010	43804	\N	53.995773	поселок Горбуновский, Молодежная, 28		0101000020E61000008867093202E04D40B29E5A7D75FF4A40
11325	6	58	134	6864	44241	\N	53.902945616152003	поселок Вятский, Мира, 22/1		0101000020E6100000BC3B32569B7D4D40EA060ABC93F34A40
11328	6	58	134	7007	44111	\N	53.919150000000002	поселок Волковский, Школьная, 15		0101000020E6100000B3D0CE6916904D40280F0BB5A6F54A40
11291	6	58	134	55145	43334	\N	53.880406875554002	Верхнеуральское городское поселение, Советская, 20	Россия, Челябинская область, Верхнеуральский район, Верхнеуральск	0101000020E6100000C4B46FEEAF9C4D40B115342DB1F04A40
11292	6	58	134	55145	43380	\N	53.877008944019799	Верхнеуральское городское поселение, Розы Люксембург, 41	Россия, Челябинская область, Верхнеуральский район, Верхнеуральск	0101000020E61000007D941117809C4D401AA6B6D441F04A40
11289	6	58	134	55145	43348	\N	53.875129999999999	Верхнеуральское городское поселение, Мира, 115	Россия, Челябинская область, Верхнеуральский район, Верхнеуральск	0101000020E6100000A56ABB09BE9B4D40CEDF844204F04A40
9741	6	58	339	25865	44164	\N	55.351906999999997	деревня Метелева, им. Р.У. Кузыева, 9		0101000020E6100000ACFF73982F7F4E40E21DE0490BAD4B40
11290	6	58	134	55145	43291	\N	53.877465398714001	Верхнеуральское городское поселение, Еремина, 33	Россия, Челябинская область, Верхнеуральский район, Верхнеуральск	0101000020E6100000A1D80A9A969C4D403C31EBC550F04A40
11326	6	58	134	6890	43982	\N	53.861825000000003	село Большой Бугодак, Садовая, 1/2		0101000020E6100000320400C79E814D4007F0164850EE4A40
11206	6	58	134	309	44230	\N	53.546031515527297	поселок Бабарыкинский, Школьная, 4	Россия, Челябинская область, Верхнеуральский район, поселок Бабарыкинский	0101000020E6100000C3B986191AA74D40E4486760E4C54A40
11300	6	58	134	55181	43820	\N	54.125117000000003	поселок Александровский, Верхняя, 4	Россия, Челябинская область, Верхнеуральский район, поселок Александровский	0101000020E61000003B6EF8DD74A94D403A9677D503104B40
11459	6	58	834	13169	43526	\N	53.345725999999999	Челябинская область, Варненский муниципальный район, Толстинское сельское поселение, село Толсты, Уральская, 1А		0101000020E61000004AD3A0681E5E4E403EB0E3BF40AC4A40
11458	6	58	834	13147	43899	\N	53.333284999999997	Челябинская область, Варненский муниципальный район, Толстинское сельское поселение, поселок Солнце, Центральная, 17В		0101000020E610000063997E8978554E40A99F3715A9AA4A40
11454	6	58	834	12625	43995	\N	53.551934000000003	Челябинская область, Варненский муниципальный район, Новоуральское сельское поселение, поселок Саламат, Южная, 9		0101000020E6100000FBB2B453738F4E4076C6F7C5A5C64A40
11446	6	58	834	12625	43994	\N	53.551934000000003	Челябинская область, Варненский муниципальный район, Лейпцигское сельское поселение, поселок Саламат, ж.д. станция, Привокзальная, 14		0101000020E6100000FBB2B453738F4E4076C6F7C5A5C64A40
11440	6	58	834	12311	43836	\N	53.045951000000002	Челябинская область, Варненский муниципальный район, Краснооктябрьское сельское поселение, поселок Ракитный, Центральная, 19А		0101000020E6100000FA264D83A2A34E40F81BEDB8E1854A40
11453	6	58	834	12904	43862	\N	53.416626000000001	Челябинская область, Варненский муниципальный район, Новоуральское сельское поселение, поселок Правда, Уральская, 2А		0101000020E6100000D0B7054B756B4E40E754320054B54A40
11452	6	58	834	12890	43697	\N	53.411183000000001	Челябинская область, Варненский муниципальный район, Новоуральское сельское поселение, поселок Новый Урал, переулок Школьный, 2		0101000020E6100000AB3DEC8502624E40E9D500A5A1B44A40
11457	6	58	834	13094	43524	\N	53.306573005947797	Челябинская область, Варненский муниципальный район, Покровское сельское поселение, поселок Новопокровка, Советская, 89	Россия, Челябинская область, Варненский район, поселок Новопокровка	0101000020E610000048FC8A355C944E40166BB8C83DA74A40
11444	6	58	834	12522	44126	\N	53.241708000000003	Челябинская область, Варненский муниципальный район, Кулевчинское сельское поселение, поселок Новокулевчи, Школьная, 12А		0101000020E61000006493FC885FA14E403E97A949F09E4A40
11439	6	58	834	55238	44317	\N	53.048627854404003	Челябинская область, Варненский муниципальный район, Краснооктябрьское сельское поселение, поселок Нововладимировка, Набережная, 7	Россия, Челябинская область, Варненский район, поселок Нововладимировский	0101000020E6100000D7BD158909AC4E40BFD53A7139864A40
11448	6	58	834	12706	43541	\N	53.035680999999997	Челябинская область, Варненский муниципальный район, Николаевское сельское поселение, село Николаевка, Набережная, 23А		0101000020E6100000E6AC4F3926014F40560BEC3191844A40
11422	6	58	834	11462	43876	\N	53.009790000000002	Челябинская область, Варненский муниципальный район, Аятское сельское поселение, поселок Маслоковцы, Советская, 4А		0101000020E610000061545227A0CF4E40F7E978CC40814A40
11445	6	58	834	12545	43587	\N	53.568980000000003	Челябинская область, Варненский муниципальный район, Лейпцигское сельское поселение, село Лейпциг, Юбилейная, 20		0101000020E6100000A9BEF38B12864E40FF092E56D4C84A40
11428	6	58	834	11736	\N	\N	53.319263999999997	Челябинская область, Варненский муниципальный район, Варненское сельское поселение, поселок КызылМаяк, Помещение школы ул.Центральная 12А	Россия, Челябинская область, Варненский район, поселок Кызыл-Маяк	0101000020E61000002C0FD253E4724E4023658BA4DDA84A40
11443	6	58	834	12461	43654	\N	53.162422999999997	Челябинская область, Варненский муниципальный район, Кулевчинское сельское поселение, село Кулевчи, Завалищина, 39/2		0101000020E61000002C11A8FE41B64E40218FE046CA944A40
11437	6	58	834	12172	43696	\N	53.007080000000002	Челябинская область, Варненский муниципальный район, Краснооктябрьское сельское поселение, поселок Красный Октябрь, Гагарина 35Б		0101000020E61000000CE6AF90B9944E40543A58FFE7804A40
11433	6	58	834	11951	43992	\N	53.296681999999997	Челябинская область, Варненский муниципальный район, Катенинское сельское поселение, поселок Красноармейский, Озерная, 2А		0101000020E6100000DACA4BFE27794E40EBA7FFACF9A54A40
11451	6	58	834	12836	44249	\N	53.420715000000001	Челябинская область, Варненский муниципальный район, Новоуральское сельское поселение, поселок Красная Заря, переулок Школьный, 1		0101000020E61000003BAA9A20EA584E40E4F736FDD9B54A40
11432	6	58	834	11912	44213	\N	53.280844999999999	Челябинская область, Варненский муниципальный район, Катенинское сельское поселение, поселок Комсомольский, Труда, 8А		0101000020E6100000D06394675E824E40601F9DBAF2A34A40
11442	6	58	834	12414	43863	\N	53.197771000000003	Челябинская область, Варненский муниципальный район, Кулевчинское сельское поселение, поселок Кинжитай, Центральная, 81		0101000020E61000009641B5C189C24E40728C648F50994A40
9452	6	58	339	11778	43771	\N	55.387075000000003	поселок Маякский, Полевая, 1 А		0101000020E6100000876EF607CA454E40B30C71AC8BB14B40
11431	6	58	834	11871	\N	\N	53.178314999999998	Челябинская область, Варненский муниципальный район, Катенинское сельское поселение, село Катенино, Школьная, 16	Россия, Челябинская область, Варненский район, поселок Катенино	0101000020E6100000AABA473657874E4070B1A206D3964A40
11430	6	58	834	11826	44124	\N	53.172069999999998	Челябинская область, Варненский муниципальный район, Катенинское сельское поселение, поселок Караоба, Школьная, 2А		0101000020E610000022E3512AE1994E40B54FC76306964A40
11436	6	58	834	12133	44257	\N	53.114984	Челябинская область, Варненский муниципальный район, Краснооктябрьское сельское поселение, поселок Камышинка, Целинная, 151		0101000020E6100000124BCADDE7984E4019C8B3CBB78E4A40
11429	6	58	834	11806	43866	\N	53.504874999999998	Челябинская область, Варненский муниципальный район, Казановское сельское поселение, поселок Казановка, Центральная, 108А		0101000020E61000008942CBBA7F9C4E40B4C876BE9FC04A40
11456	6	58	834	13031	43870	\N	53.459714970076199	Челябинская область, Варненский муниципальный район, Покровское сельское поселение, поселок Заречье, Центральная, 21		0101000020E6100000122EE411DC8A4E40863DEDF0D7BA4A40
11450	6	58	834	12772	43673	\N	53.555442999999997	Челябинская область, Варненский муниципальный район, Новоуральское сельское поселение, поселок Дружный, Центральная, 3		0101000020E610000087BF266BD4754E4064E597C118C74A40
10834	6	58	834	12772	43673	\N	53.555442999999997	поселок Дружный, Центральная, 10		0101000020E610000087BF266BD4754E4064E597C118C74A40
11435	6	58	834	12080	43993	\N	52.996226	Челябинская область, Варненский муниципальный район, Краснооктябрьское сельское поселение, село Городище, Гоголя, 19		0101000020E6100000D862B7CF2A914E4063B66455847F4A40
11441	6	58	834	12364	44125	\N	53.047564999999999	Челябинская область, Варненский муниципальный район, Кулевчинское сельское поселение, село Владимировка, Школьная, 14		0101000020E610000040D9942BBCB34E4095B7239C16864A40
11968	6	58	834	6015	42961	\N	53.381872999999999	Челябинская область, Варненский муниципальный район, Варненское сельское поселение, село Варна, Спартак, 22А		0101000020E6100000C808A870047D4E40DA1CE736E1B04A40
11425	6	58	834	6015	42660	\N	53.381872999999999	Челябинская область, Варненский муниципальный район, Варненское сельское поселение, село Варна, Советская, 127		0101000020E6100000C808A870047D4E40DA1CE736E1B04A40
11967	6	58	834	6015	43582	\N	53.381872999999999	Челябинская область, Варненский муниципальный район, Варненское сельское поселение, село Варна, Пугачева, 14		0101000020E6100000C808A870047D4E40DA1CE736E1B04A40
11426	6	58	834	6015	42662	\N	53.381872999999999	Челябинская область, Варненский муниципальный район, Варненское сельское поселение, село Варна, Пролетарская, 155		0101000020E6100000C808A870047D4E40DA1CE736E1B04A40
11424	6	58	834	6015	43020	\N	53.381872999999999	Челябинская область, Варненский муниципальный район, Варненское сельское поселение, село Варна, Магнитогорская, 1		0101000020E6100000C808A870047D4E40DA1CE736E1B04A40
11427	6	58	834	6015	43183	\N	53.381872999999999	Челябинская область, Варненский муниципальный район, Варненское сельское поселение, село Варна, Ленина, 27А		0101000020E6100000C808A870047D4E40DA1CE736E1B04A40
11423	6	58	834	11507	43012	\N	53.540843000000002	Челябинская область, Варненский муниципальный район, Бородиновское сельское поселение, село Бородиновка, Школьная, 49		0101000020E61000007715527E52614E40A1A2EA573AC54A40
11449	6	58	834	12759	43996	\N	53.444989999999997	Челябинская область, Варненский муниципальный район, Новоуральское сельское поселение, поселок Большевик, Школьная, 1		0101000020E6100000E3C4573B8A754E400586AC6EF5B84A40
11434	6	58	834	12032	44123	\N	53.083927000000003	Челябинская область, Варненский муниципальный район, Краснооктябрьское сельское поселение, поселок Белоглинка, Центральная, 12А		0101000020E6100000CA8CB7955E874E402E20B41EBE8A4A40
11421	6	58	834	11409	43164	\N	53.074655999999997	Челябинская область, Варненский муниципальный район, Аятское сельское поселение, поселок АрчаглыАят, Центральная, 12		0101000020E61000005C1D007157E54E409F39EB538E894A40
11455	6	58	834	13013	44232	\N	53.385089999999998	Челябинская область, Варненский муниципальный район, Покровское сельское поселение, поселок Алтырка, Центральная 12		0101000020E6100000AF21382EE3924E4021020EA14AB14A40
11418	6	58	834	11251	43622	\N	53.552224461285903	Челябинская область, Варненский муниципальный район, Алексеевское сельское поселение, село Алексеевка, Школьная, 8	Россия, Челябинская область, Варненский район, поселок Алексеевка	0101000020E6100000BF654E97C5BA4E407D08AA46AFC64A40
11420	6	58	834	11369	44209	\N	53.136516999999998	Челябинская область, Варненский муниципальный район, Аятское сельское поселение, село Александровка, Советская, 13		0101000020E6100000E9D495CFF2D84E408C2C996379914A40
11631	6	58	834	11369	44298	\N	53.136516999999998	Александровка, Набережная, 11а		0101000020E6100000E9D495CFF2D84E408C2C996379914A40
11419	6	58	834	11302	44013	\N	53.214646999999999	Челябинская область, Варненский муниципальный район, Аятское сельское поселение, поселок Алакамыс, Пролетарская, 2		0101000020E61000007B88467710D54E409E978A8D799B4A40
11410	6	58	1076	10899	43828	\N	52.460127999999997	Челябинская область, Брединский район, село Ясная Поляна, ул. Садовая, 34		0101000020E61000004A438D4292534E40A8FC6B79E53A4A40
11417	6	58	1076	11206	43829	\N	52.567397999999997	Челябинская область, Брединский район, село Сосновка, ул. Школьная, 2		0101000020E6100000556AF6402B0E4E406CE8667FA0484A40
11415	6	58	1076	11113	44211	\N	52.017487000000003	Челябинская область, Брединский район, село Синий Шихан, ул. Центральная, 45		0101000020E6100000D74E948444044E40768D96033D024A40
11404	6	58	1076	10633	44014	\N	52.609039000000003	Челябинская область, Брединский район, поселок Светлые Озера, ул. Центральная, 14		0101000020E6100000C5C551B9892A4E40897E6DFDF44D4A40
11416	6	58	1076	11178	42659	\N	52.502924	Челябинская область, Брединский район, поселок Рымникский, ул. Гатьятуллина, 1а		0101000020E610000081E84999D4124E40CF2F4AD05F404A40
11413	6	58	1076	11020	42817	\N	52.087600999999999	Челябинская область, Брединский район, поселок Павловский, ул. Молодежная, 2		0101000020E6100000C3F2E7DB82034E40670C7382360B4A40
11398	6	58	1076	10316	44246	\N	52.38541	Челябинская область, Брединский район, поселок Октябрьский, ул. Школьная, 4		0101000020E6100000894336902E3E4E4093C6681D55314A40
11399	6	58	1076	10361	43990	\N	52.324229000000003	Челябинская область, Брединский район, поселок Новый, ул. Целинная, 40а		0101000020E61000002C0E677E35334E4018B5FB5580294A40
11403	6	58	1076	10559	44212	\N	52.675207999999998	Челябинская область, Брединский район, поселок Новогеоргиевский, ул. Школьная 3		0101000020E6100000FD6A0E10CC3B4E40B0FF3A376D564A40
11411	6	58	1076	10934	43038	\N	52.161636000000001	Челябинская область, Брединский район, поселок Наследницкий, ул. Новостройки, 5	Россия, Челябинская область, Брединский район, поселок Наследницкий	0101000020E6100000054D4BAC8C2A4E409AED0A7DB0144A40
11402	6	58	1076	10532	44039	\N	52.707908000000003	Челябинская область, Брединский район, поселок Могутовский, ул. Дорожная 18		0101000020E6100000DA54DD239B1B4E40D449B6BA9C5A4A40
11390	6	58	1076	9912	43703	\N	52.441862	Челябинская область, Брединский район, село Мирное, ул. Мира 24		0101000020E6100000664F029B73204E402EAC1BEF8E384A40
11396	6	58	1076	10220	42818	\N	52.391795999999999	Челябинская область, Брединский район, поселок Маяк, пер.Школьный 1		0101000020E61000006155BDFC4E354E40105A0F5F26324A40
11587	6	58	1076	10220	44136	\N	52.391795999999999	п. Маяк, Мира, 15 А		0101000020E61000006155BDFC4E354E40105A0F5F26324A40
11393	6	58	1076	10049	44239	\N	52.330123	Челябинская область, Брединский район, поселок Мариинский, ул. Комсомольская, 1		0101000020E61000008995D1C8E7814E4026547078412A4A40
11408	6	58	1076	10816	44060	\N	52.527782000000002	Челябинская область, Брединский район, поселок Лебяжий, ул. Центральная, 22		0101000020E6100000139CFA40F25A4E4070B54E5C8E434A40
11412	6	58	1076	10990	44059	\N	52.2834686282348	Челябинская область, Брединский район, поселок Коряжный, ул. Центральная, 30	Россия, Челябинская область, Брединский район, поселок Коряжный	0101000020E6100000D905836BEE184E40043752B648244A40
11409	6	58	1076	10833	43501	\N	52.383249999999997	Челябинская область, Брединский район, поселок Комсомольский, ул. Горького, 10		0101000020E61000001FDAC70A7E514E40931804560E314A40
11406	6	58	1076	10719	43591	\N	52.648510000000002	Челябинская область, Брединский район, поселок Княженский, ул. Генерала Григорьева, 36		0101000020E61000003849F3C7B4544E4082902C6002534A40
11405	6	58	1076	10640	42815	\N	52.512587000000003	Челябинская область, Брединский район, поселок Калининский, пер. Школьный 8		0101000020E61000007F4DD6A887D84D4069AD68739C414A40
11407	6	58	1076	10742	44064	\N	52.556037277061002	Челябинская область, Брединский район, поселок Заозерный, ул. Дорожная, 2а	Россия, Челябинская область, Брединский район, поселок Заозерный	0101000020E6100000BF7CB262B8444E40D82E6D382C474A40
11401	6	58	1076	10451	43997	\N	52.708399	Челябинская область, Брединский район, поселок Гогино, ул. Пристационная 12		0101000020E6100000A7AD11C138404E4072C284D1AC5A4A40
11397	6	58	1076	10267	44207	\N	52.380924	Челябинская область, Брединский район, поселок Восход, ул. Школьная, 3		0101000020E6100000AE450BD0B6444E4079211D1EC2304A40
11414	6	58	1076	11082	44210	\N	52.095779	Челябинская область, Брединский район, поселок Восточный, ул. Школьная, 1		0101000020E6100000D7DEA7AAD0144E4061527C7C420C4A40
11382	6	58	1076	9521	42674	\N	52.411971999999999	Челябинская область, Брединский район, поселок Бреды, мкр. Черемушки, 11		0101000020E6100000FCC6D79E592C4E40116F9D7FBB344A40
11388	6	58	1076	9521	43181	\N	52.411971999999999	Челябинская область, Брединский район, поселок Бреды, ул. Фрунзе, 31		0101000020E6100000FCC6D79E592C4E40116F9D7FBB344A40
11383	6	58	1076	9521	43626	\N	52.411971999999999	Челябинская область, Брединский район, поселок Бреды, ул. Пушкина 52		0101000020E6100000FCC6D79E592C4E40116F9D7FBB344A40
11387	6	58	1076	9521	43692	\N	52.411971999999999	Челябинская область, Брединский район, поселок Бреды, ул. Победы, 8а		0101000020E6100000FCC6D79E592C4E40116F9D7FBB344A40
11385	6	58	1076	9521	42668	\N	52.411971999999999	Челябинская область, Брединский район, поселок Бреды, ул. Мира 9		0101000020E6100000FCC6D79E592C4E40116F9D7FBB344A40
11389	6	58	1076	9521	43182	\N	52.411971999999999	Челябинская область, Брединский район, поселок Бреды, ул. Гербанова, 15		0101000020E6100000FCC6D79E592C4E40116F9D7FBB344A40
11384	6	58	1076	9521	43178	\N	52.411971999999999	Челябинская область, Брединский район, поселок Бреды, ул. Аэродромная, 42		0101000020E6100000FCC6D79E592C4E40116F9D7FBB344A40
11400	6	58	1076	10427	42658	\N	52.662495	Челябинская область, Брединский район, село Боровое, ул. Мира 11		0101000020E61000002E3C2F151B374E40BB61DBA2CC544A40
11394	6	58	1076	10123	43499	\N	52.229680000000002	Челябинская область, Брединский район, поселок Атамановский, ул. Школьная д 15		0101000020E6100000D2FE0758AB5A4E40CC457C27661D4A40
11392	6	58	1076	10035	43691	\N	52.371782000000003	Челябинская область, Брединский район, поселок Андреевский, ул. Садиковая, 1а		0101000020E6100000BFBB95253A654E40E99E758D962F4A40
11391	6	58	1076	9948	44035	\N	52.578305999999998	Челябинская область, Брединский район, поселок Амурский, ул. Центральная 1		0101000020E6100000C217265305CF4D40508A56EE054A4A40
10737	6	58	946	55172	\N	\N	54.838282786340002	Челябинская область, Ашинский  муниципальный район, Укское сельское поселение, поселок УстьКурышка, помещение бывшей школы	Россия, Челябинская область, Ашинский район, поселок Усть-Курышка	0101000020E610000057790261A7984C4079E57ADB4C6B4B40
10735	6	58	946	55132	\N	\N	54.942742225392202	Челябинская область, Ашинский  муниципальный район, Укское сельское поселение, поселок Ук, помещение Укского сельского Дома культуры	Россия, Челябинская область, Ашинский район, поселок Ук	0101000020E6100000D751D50451A14C40674815C5AB784B40
10734	6	58	946	10058	\N	\N	55.093184000000001	Челябинская область, Ашинский  муниципальный район, Точильнинское сельское поселение, поселок Точильный, помещение Точильнинского сельского Дома Культуры	Россия, Челябинская область, Ашинский район, поселок Точильный	0101000020E610000078B988EFC4964C4057410C74ED8B4B40
10736	6	58	946	10149	\N	\N	54.856122999999997	Челябинская область, Ашинский  муниципальный район, Укское сельское поселение, поселок Сухая Атя, помещение Сухоатинского сельского Дома культуры	Россия, Челябинская область, Ашинский район, поселок Сухая Атя	0101000020E6100000AF94658863B34C403C2D3F70956D4B40
10716	6	58	946	55170	43755	\N	55.012054121326003	Челябинская область, Ашинский  муниципальный район, Симское городское поселение, Кирова, 1		0101000020E6100000D0D2156C23DA4C409BE447FC8A814B40
11755	6	58	946	55149	43438	\N	55.0736230903251	раб. пос. Первомайский, Школьная, 12	Россия, Челябинская область, Ашинский район, поселок Первомайский	0101000020E61000004E29AF95D0934C40E09D7C7A6C894B40
11753	6	58	946	55149	43374	\N	55.074017077424301	раб. пос. Первомайский, Нечепуренко, 50	Россия, Челябинская область, Ашинский район, поселок Первомайский	0101000020E6100000D784B4C6A0934C408C2C996379894B40
11754	6	58	946	55149	43492	\N	55.0736230903251	раб. пос. Первомайский, Мира, 4	Россия, Челябинская область, Ашинский район, поселок Первомайский	0101000020E61000002E742502D5934C40E09D7C7A6C894B40
10730	6	58	946	9854	\N	\N	55.108395000000002	Челябинская область, Ашинский  муниципальный район, Еральское сельское поселение, село Муратовка, Муратовский сельский Дом культуры		0101000020E610000065DEAAEB50FB4C4064062AE3DF8D4B40
10709	6	58	946	55155	43471	\N	55.0678353786383	Челябинская область, Ашинский  муниципальный район, Миньярское городское поселение, Ленина, 54	Россия, Челябинская область, Миньяр	0101000020E6100000BF49D3A068C64C40184339D1AE884B40
10732	6	58	946	9946	\N	\N	55.204335999999998	Челябинская область, Ашинский  муниципальный район, Илекское сельское поселение, село Малояз, Малоязовский сельский клуб		0101000020E6100000AFCE31207B0F4D409EB29AAE279A4B40
10728	6	58	946	55133	43228	\N	55.013293289455298	Челябинская область, Ашинский  муниципальный район, Кропачевское городское поселение, Свердлова, 96	Россия, Челябинская область, Ашинский район, поселок Кропачево	0101000020E6100000541B9C887EFF4C400322C495B3814B40
10727	6	58	946	55133	43566	\N	55.012093999999998	Челябинская область, Ашинский  муниципальный район, Кропачевское городское поселение, Рокутова, 14	Россия, Челябинская область, Ашинский район, поселок Кропачево	0101000020E6100000E57ADB4C85FE4C40293DD34B8C814B40
10726	6	58	946	55133	43724	\N	55.012093999999998	Челябинская область, Ашинский  муниципальный район, Кропачевское городское поселение, Ленина, 161	Россия, Челябинская область, Ашинский район, поселок Кропачево	0101000020E6100000E57ADB4C85FE4C40293DD34B8C814B40
10725	6	58	946	55133	43724	\N	55.012833097555799	Челябинская область, Ашинский  муниципальный район, Кропачевское городское поселение, Ленина, 115	Россия, Челябинская область, Ашинский район, поселок Кропачево	0101000020E6100000B950F9D7F2FE4C40A0A70183A4814B40
10731	6	58	946	9926	\N	\N	55.228966999999997	Челябинская область, Ашинский  муниципальный район, Илекское сельское поселение, село Илек, администрация Илекского сельского поселения		0101000020E610000065C5707500004D407E6E68CA4E9D4B40
10729	6	58	946	9841	\N	\N	55.024439999999998	Челябинская область, Ашинский  муниципальный район, Еральское сельское поселение, село Ерал, филиал МОУ СОШ №26 пгт. Кропачево в с. Ерал		0101000020E610000076A4FACE2FF64C406C5B94D920834B40
10733	6	58	946	10033	\N	\N	55.178654999999999	Челябинская область, Ашинский  муниципальный район, Биянское сельское поселение, село Биянка, помещение Биянской муниципальной неполной школы	Россия, Челябинская область, Ашинский район, поселок Биянка	0101000020E6100000D8B628B341D64C402922C32ADE964B40
7030	6	58	339	22367	43617	\N	55.233378000000002	деревня Яраткулова, Центральная, 30		0101000020E6100000D1782288F3384E408ECD8E54DF9D4B40
11953	6	58	339	5250	43884	\N	55.247103000000003	деревня Ялтырова, Школьная, 7		0101000020E61000001BBE8575E3434E402BDF3312A19F4B40
8818	6	58	339	12961	43916	\N	55.244906	поселок Чубары, Советская, 4		0101000020E6100000F6251B0FB6684E400E4C6E14599F4B40
9789	6	58	339	47947	44073	\N	55.361584999999998	деревня Чапаевка, Центральная, 34		0101000020E6100000249A40118B684E40B1DCD26A48AE4B40
5978	6	58	339	2878	43615	\N	55.610132999999998	поселок Худайбердинский, Садовая, 7		0101000020E6100000A4703D0AD7754E40ED9A90D618CE4B40
11954	6	58	339	5306	44042	\N	55.31118	деревня Халитова, Озёрная, 6		0101000020E610000003B4AD669D334E40AB9509BFD4A74B40
8389	6	58	339	24265	43761	\N	55.183199000000002	деревня Уразбаева, Набережная, 30		0101000020E610000048A30227DB2C4E4078D4981073974B40
5543	6	58	339	13904	43912	\N	55.546607999999999	деревня Старая Соболева, Лесная, 14		0101000020E6100000EE5F596952864E40B1DD3D40F7C54B40
9783	6	58	339	27800	44069	\N	55.38194	деревня Селяева, Труда, 53		0101000020E6100000C5C72764E76D4E406284F068E3B04B40
4922	6	58	339	47231	44235	\N	55.505535999999999	деревня Норкино, Северная, 1		0101000020E6100000828E56B5A4754E40AF795567B5C04B40
11951	6	58	339	5150	43881	\N	55.315555000000003	деревня Новый Миасс, Луговая, 2 А		0101000020E6100000C9CB9A58E0414E406E8B321B64A84B40
5080	6	58	339	23601	43614	\N	55.504353000000002	деревня Новая Соболева, Родниковая, 5		0101000020E6100000ABD1AB014A814E40DB519CA38EC04B40
8692	6	58	339	55163	43698	\N	55.349869375552203	деревня Кузяшева, Школьная, 13 А	Россия, Челябинская область, Аргаяшский район, поселок Кузяшева	0101000020E6100000B29FC55224634E402E71E481C8AC4B40
9825	6	58	339	48615	43618	\N	55.490344999999998	село Кузнецкое, Октябрьская, 117 В		0101000020E61000000262122EE4514E40E960FD9FC3BE4B40
9839	6	58	339	48615	43676	\N	55.491270939000998	село Кузнецкое, Ленина, 49	Россия, Челябинская область, Аргаяшский район, поселок Кузнецкое	0101000020E6100000B169A510C8514E40923CD7F7E1BE4B40
8878	6	58	339	48115	44118	\N	55.230533000000001	поселок Кировский, Восточная, 10 А		0101000020E6100000F5D901D715774E400BD3F71A829D4B40
9699	6	58	339	46115	43516	\N	55.377383000000002	деревня Камышевка, Советская, 24  2		0101000020E610000007EDD5C743774E407F880D164EB04B40
9682	6	58	339	23084	42594	\N	55.411944354846902	поселок Ишалино, жд. станция, Школьная, 30		0101000020E610000080D591239D7F4E4047E4BB94BAB44B40
9560	6	58	339	23084	42594	\N	55.420195676326401	деревня Ишалина, Школьная, 27	Россия, Челябинская область, Аргаяшский район, поселок Ишалино	0101000020E61000006EC1525DC0854E407BF486FBC8B54B40
9550	6	58	339	16426	44163	\N	55.463338899737302	деревня Илимбетова, М. Усманова, 27	Россия, Челябинская область, Аргаяшский район, поселок Илимбетова	0101000020E6100000B151D66F269E4E400DFB3DB14EBB4B40
9544	6	58	339	16112	43165	\N	55.4636	деревня Дербишева, Набережная, 56		0101000020E61000007B4E7ADFF88E4E407A36AB3E57BB4B40
9910	6	58	339	1617	44168	\N	55.478530999999997	село Губернское, Братьев Кауровых, 10 А		0101000020E6100000FE60E0B9F74C4E40A38FF98040BD4B40
9934	6	58	339	1617	43773	\N	55.478530999999997	село Губернское, Архипова, 68 А		0101000020E6100000FE60E0B9F74C4E40A38FF98040BD4B40
10058	6	58	339	9245	43925	\N	55.328795999999997	деревня Буланцы, Ветеранов, 10 В		0101000020E6100000605969520A6A4E401E87C1FC15AA4B40
8618	6	58	339	55190	43926	\N	55.296992549522699	деревня Большая Усманова, Пионерская, 14	Россия, Челябинская область, Аргаяшский район, поселок Большая Усманова	0101000020E61000004B22FB20CB664E400A12DBDD03A64B40
9966	6	58	339	4742	43783	\N	55.150772000000003	деревня Большая Куйсарина, Школьная, 14		0101000020E6100000BBECD79DEE4C4E408693347F4C934B40
11952	6	58	339	5174	44041	\N	55.147258000000001	деревня Большая Исянгильдина, Центральная, 21		0101000020E6100000D6FECEF6E8554E408509A359D9924B40
7430	6	58	339	9601	44052	\N	55.279558999999999	деревня Биккулова, Колхозная, 34		0101000020E61000004BCADDE7F83C4E40B726DD96C8A34B40
11110	6	58	339	28153	44265	\N	55.593913999999998	Челябинская область, Озерский городской округ, поселок Бижеляк, ул.Омская, 13, фельдшерскоакушерский пункт, 1 этаж холл		0101000020E610000082734694F65C4E407A51BB5F05CC4B40
9777	6	58	339	27488	43772	\N	55.440978000000001	поселок Бигарды, Зеленая, 2		0101000020E6100000DB6FED4449764E40B42094F771B84B40
6373	6	58	339	22442	44152	\N	55.686253999999998	поселок Башакуль, Школьная, 2		0101000020E610000030F65E7CD1984E40E55FCB2BD7D74B40
9291	6	58	339	2553	43510	\N	55.376437000000003	село Байрамгулово, Титова, 1		0101000020E610000065C22FF5F3404E408F006E162FB04B40
9267	6	58	339	2553	43510	\N	55.376437000000003	село Байрамгулово, Титова, 31		0101000020E610000065C22FF5F3404E408F006E162FB04B40
4776	6	58	339	8784	43497	\N	55.156343	деревня Байгазина, Центральная, 25		0101000020E61000001503249A40654E40B1FA230C03944B40
4907	6	58	339	14977	43504	\N	55.46754	деревня Бажикаева, Школьная, 9		0101000020E610000008E412471E764E4032C9C859D8BB4B40
9120	6	58	339	27619	43548	\N	55.526454000000001	деревня Аязгулова, Школьная, 2		0101000020E6100000261DE56036694E40986C3CD862C34B40
10078	6	58	339	7088	42883	\N	55.490915564954499	село Аргаяш, площадь СПТУ, здание клуба Агротехникума	Россия, Челябинская область, Аргаяшский район, поселок Аргаяш	0101000020E61000006FD74B5304704E40A48AE255D6BE4B40
10012	6	58	339	7088	43628	\N	55.491410999999999	село Аргаяш, Октябрьская, 23		0101000020E6100000E84B6F7F2E704E4084F23E8EE6BE4B40
10077	6	58	339	7088	43167	\N	55.492631956866497	село Аргаяш, Ленина, 3	Россия, Челябинская область, Аргаяшский район, поселок Аргаяш	0101000020E610000097917A4FE5704E40467BBC900EBF4B40
10075	6	58	339	7088	43003	\N	55.4899978210778	село Аргаяш, 8 Марта, 17	Россия, Челябинская область, Аргаяшский район, поселок Аргаяш	0101000020E6100000492BBEA1F06F4E407E8D2441B8BE4B40
10076	6	58	339	7088	43002	\N	55.491410999999999	село Аргаяш, Чкалова, 20	Россия, Челябинская область, Аргаяшский район, поселок Аргаяш	0101000020E6100000E84B6F7F2E704E4084F23E8EE6BE4B40
9427	6	58	339	10624	43929	\N	55.357439999999997	поселок Аргази, Береговая, 4		0101000020E6100000B6D8EDB3CA364E4020240B98C0AD4B40
10049	6	58	339	32510	42978	\N	55.293483999999999	деревня Акбашева, 30 лет Победы, 22		0101000020E6100000416326512F6C4E401BF33AE290A54B40
4709	6	58	339	5514	43887	\N	55.215204999999997	деревня Айбатова, Центральная, 35		0101000020E6100000C1E5B16664544E40C47762D68B9B4B40
9604	6	58	339	19192	44070	\N	55.384216000000002	деревня Абдырова, Солнечная, 8		0101000020E61000002A1BD65416894E40CB4C69FD2DB14B40
11380	6	58	935	9409	43010	\N	53.125972707210302	Челябинская область, Агаповский муниципальный район, Янгельское сельское поселение, поселок Янгельский, Рабочая, 23а	Россия, Челябинская область, Агаповский район, поселок Янгельский	0101000020E610000091F3FE3F4E7E4D40EA961DE21F904A40
11360	6	58	935	8539	43821	\N	53.120545	Челябинская область, Агаповский муниципальный район, Магнитное сельское поселение, поселок Южный, Садовая, 8		0101000020E61000001F69705B5BBA4D402159C0046E8F4A40
11374	6	58	935	9180	43989	\N	53.160592999999999	Челябинская область, Агаповский муниципальный район, Светлогорское сельское поселение, поселок Черноотрог, пер. Мирный, 45		0101000020E6100000A83AE466B8914D40B77BB94F8E944A40
11378	6	58	935	9318	43653	\N	53.254919000000001	Челябинская область, Агаповский муниципальный район, Черниговское сельское поселение, поселок Черниговский, 1 Мая, 71		0101000020E6100000A20A7F8637D74D408410902FA1A04A40
11362	6	58	935	8617	44244	\N	53.220863999999999	Челябинская область, Агаповский муниципальный район, Наровчатское сельское поселение, поселок Харьковский, Центральная, 8		0101000020E610000015E5D2F8858D4D408F6E8445459C4A40
86216	6	56	932	27242	19110	\N	56.863098999999998	село Нижнеиргинское, Октябрьская, 10		0101000020E61000007E1D386744B74C40EB1A2D077A6E4C40
11377	6	58	935	9303	44121	\N	53.142735000000002	Челябинская область, Агаповский муниципальный район, Светлогорское сельское поселение, поселок Утарка, Школьная, 4		0101000020E6100000A54C6A6803AE4D404E7FF62345924A40
11347	6	58	935	7880	44023	\N	53.456513999999999	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, поселок Урожайный, Зеленая, 19/2		0101000020E6100000F4A8F8BF23A44D404415FE0C6FBA4A40
11379	6	58	935	9359	43857	\N	53.288139999999999	Челябинская область, Агаповский муниципальный район, Черниговское сельское поселение, поселок Требиат, Центральная, 1		0101000020E6100000E065868DB2D44D40B05582C5E1A44A40
11372	6	58	935	9068	43856	\N	53.036569	Челябинская область, Агаповский муниципальный район, Светлогорское сельское поселение, поселок Ташказган, Целинная, 74		0101000020E61000002DB4739A05804D401286014BAE844A40
11355	6	58	935	8287	43513	\N	53.237673685938397	Челябинская область, Агаповский муниципальный район, Магнитное сельское поселение, поселок Субутак, ж.д. станция, Школьная, 3	Россия, Челябинская область, Агаповский район, поселок Субутак	0101000020E6100000292158552FC94D40048E041A6C9E4A40
11356	6	58	935	8287	44050	\N	53.235408	Челябинская область, Агаповский муниципальный район, Магнитное сельское поселение, поселок Субутак, ж.д. станция, Северная, 7		0101000020E6100000B398D87C5CC94D40BF9B6ED9219E4A40
11349	6	58	935	7972	44117	\N	53.459327999999999	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, поселок Солодянка, пер.Сиреневый, 1		0101000020E610000027124C35B3B84D408C118942CBBA4A40
11371	6	58	935	9048	43652	\N	53.135733999999999	Челябинская область, Агаповский муниципальный район, Светлогорское сельское поселение, поселок Светлогорск, Степная, 14		0101000020E61000003F726BD26D934D40467A51BB5F914A40
11369	6	58	935	8915	43648	\N	53.602238	Челябинская область, Агаповский муниципальный район, Приморское сельское поселение, поселок Ржавка, Дружбы, 2		0101000020E61000003C4CFBE6FE864D404834812216CD4A40
11367	6	58	935	8828	42814	\N	53.543984000000002	Челябинская область, Агаповский муниципальный район, Приморское сельское поселение, поселок Приморский, Клубная, 11		0101000020E61000004AB3791C068F4D400DC68844A1C54A40
11370	6	58	935	8828	44245	\N	53.543984000000002	Челябинская область, Агаповский муниципальный район, Приморское сельское поселение, поселок Приморский, Калинина, 1		0101000020E61000004AB3791C068F4D400DC68844A1C54A40
11363	6	58	935	8675	43008	\N	53.316589564002001	Челябинская область, Агаповский муниципальный район, Первомайское сельское поселение, поселок Первомайский, Центральная, 29	Россия, Челябинская область, Агаповский район, поселок Первомайский	0101000020E61000001AA6B6D441B04D40CD1E680586A84A40
11346	6	58	935	7831	43662	\N	53.375259999999997	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, поселок Озерный, Набережная, 6		0101000020E61000005589B2B7949D4D409CBF098508B04A40
11381	6	58	935	9458	43512	\N	53.199185	Челябинская область, Агаповский муниципальный район, Янгельское сельское поселение, поселок Новоянгелька, Школьная, 12		0101000020E6100000C18EFF0241764D40486DE2E47E994A40
11351	6	58	935	8085	43569	\N	53.343581	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, село Новобурановка, Зеленая, 16		0101000020E6100000F2B4FCC055C04D4074435376FAAB4A40
11350	6	58	935	8029	43986	\N	53.356282	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, поселок Новобуранное, Зеленая, 3а		0101000020E6100000527DE71725BC4D40A51309A69AAD4A40
11361	6	58	935	8549	43179	\N	53.288446999999998	Челябинская область, Агаповский муниципальный район, Наровчатское сельское поселение, поселок Наровчатка, Кооперативная, 12		0101000020E610000001A3CB9BC38B4D408DD0CFD4EBA44A40
11364	6	58	935	8712	43666	\N	53.288587	Челябинская область, Агаповский муниципальный район, Первомайское сельское поселение, поселок Наваринка, Административная, 16		0101000020E61000000E30F31DFCB44D407F86376BF0A44A40
11353	6	58	935	8213	44006	\N	53.489801999999997	Челябинская область, Агаповский муниципальный район, Желтинское сельское поселение, поселок Муравейник, Новая, 2		0101000020E61000004208C89750A54D40F8C1F9D4B1BE4A40
11365	6	58	935	8754	44028	\N	53.310463828912297	Челябинская область, Агаповский муниципальный район, Первомайское сельское поселение, поселок Малиновка, Клубная, 2	Россия, Челябинская область, Агаповский район, поселок Малиновка	0101000020E6100000999CDA19A6A24D40ED4ACB48BDA74A40
11354	6	58	935	8228	43623	\N	53.204354279722899	Челябинская область, Агаповский муниципальный район, Магнитное сельское поселение, поселок Магнитный, Молодежная, 8а	Россия, Челябинская область, Агаповский район, поселок Магнитный	0101000020E6100000635E471CB2C34D4045679945289A4A40
11348	6	58	935	7943	43822	\N	53.481560999999999	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, поселок Красноярский, Зеленая, 24		0101000020E6100000007157AF22B54D40B80375CAA3BD4A40
11359	6	58	935	8469	44116	\N	53.211644	Челябинская область, Агаповский муниципальный район, Магнитное сельское поселение, поселок Кировский, 8 Марта, 1а		0101000020E61000002330D63730CB4D4083328D26179B4A40
11375	6	58	935	9187	44119	\N	53.108817000000002	Челябинская область, Агаповский муниципальный район, Светлогорское сельское поселение, поселок Зингейка, Студенческая, 15		0101000020E61000007217618A72A34D40DA1F28B7ED8D4A40
11352	6	58	935	8134	43570	\N	53.560220000000001	Челябинская область, Агаповский муниципальный район, Желтинское сельское поселение, поселок Желтинский, Советская, 51		0101000020E6100000A510C8258E9C4D405648F949B5C74A40
11342	6	58	935	7671	43815	\N	53.276242000000003	Челябинская область, Агаповский муниципальный район, Агаповское сельское поселение, поселок Гумбейский, Садовая, 18а		0101000020E6100000C6F7C5A52A9F4D400DE4D9E55BA34A40
11366	6	58	935	8787	44025	\N	53.327955000000003	Челябинская область, Агаповский муниципальный район, Первомайское сельское поселение, поселок Гумбейка, ж.д. станция, Привокзальная, 15		0101000020E6100000BC900E0F61B84D40A4C7EF6DFAA94A40
11358	6	58	935	8456	44120	\N	53.215212999999999	Челябинская область, Агаповский муниципальный район, Магнитное сельское поселение, поселок Вперед, Молодежная, 8а		0101000020E6100000CBF6216FB9C24D4047567E198C9B4A40
11373	6	58	935	9111	43855	\N	53.07432	Челябинская область, Агаповский муниципальный район, Светлогорское сельское поселение, поселок Воздвиженка, Школьная, 5		0101000020E6100000DC9F8B868C814D4028B8585183894A40
11368	6	58	935	8909	43647	\N	53.539071999999997	Челябинская область, Агаповский муниципальный район, Приморское сельское поселение, село Верхнекизильское, Школьная, 27/1		0101000020E61000008BA71E6970894D403B18B14F00C54A40
11344	6	58	935	7745	43176	\N	53.396943340452403	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, поселок Буранный, Волынцева, 1	Россия, Челябинская область, Агаповский район, поселок Буранный	0101000020E610000049D9226937AC4D4025B03907CFB24A40
11345	6	58	935	7802	43604	\N	53.3981186311226	Челябинская область, Агаповский муниципальный район, Буранное сельское поселение, поселок Буранная, ж.д. станция, Железнодорожная, 1/1	Россия, Челябинская область, Агаповский район, поселок Буранная	0101000020E610000088484DBB98A64D4047753A90F5B24A40
11376	6	58	935	9247	43854	\N	53.089961812877299	Челябинская область, Агаповский муниципальный район, Светлогорское сельское поселение, поселок Базарский, Октябрьская, 43	Россия, Челябинская область, Агаповский район, поселок Базарский	0101000020E610000010E7E104A6AB4D40FEF0F3DF838B4A40
11357	6	58	935	8380	43817	\N	53.133951000000003	Челябинская область, Агаповский муниципальный район, Магнитное сельское поселение, поселок Алексеевский, Мира, 1		0101000020E6100000ECD973999ADC4D401D226E4E25914A40
11339	6	58	935	7531	42813	\N	53.302455999999999	Челябинская область, Агаповский муниципальный район, Агаповское сельское поселение, село Агаповка, Школьная, 52		0101000020E6100000BABDA4315A914D404F3DD2E0B6A64A40
11340	6	58	935	7531	43175	\N	53.290680399739401	Челябинская область, Агаповский муниципальный район, Агаповское сельское поселение, село Агаповка, Пролетарская, 44	Россия, Челябинская область, Агаповский район, поселок Агаповка	0101000020E61000007E8AE3C0AB914D40F7CC920035A54A40
11341	6	58	935	7531	42798	\N	53.302455999999999	Челябинская область, Агаповский муниципальный район, Агаповское сельское поселение, село Агаповка, Правобережная, 3		0101000020E6100000BABDA4315A914D404F3DD2E0B6A64A40
11343	6	58	935	7698	44247	\N	53.219562760878603	Челябинская область, Агаповский муниципальный район, Агаповское сельское поселение, поселок Аблязово, Степная, 12	Россия, Челябинская область, Агаповский район, поселок Аблязово	0101000020E6100000A1698995D1964D40B134F0A31A9C4A40
10686	6	58	7349	55115	42887	\N	54.984867043074601	Челябинская область, Ашинский  муниципальный район, Ашинское городское поселение, Озимина, 34		0101000020E61000004510E7E104A44C406FF4311F107E4B40
9203	6	59	\N	61166	77418	\N	61.945452918351599	ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Унъюган, мкр. 40 лет Победы, 11	Россия	0101000020E6100000ADBF2500FF3B5040DA73999A04F94E40
9145	6	59	\N	61209	77595	\N	64.033520133846295	ХантыМансийский автономный округ  Югра, Белоярский район, сельское поселение Сосновка, Школьная, 1	Россия	0101000020E6100000B3B5BE4868615140C3F0113125025040
9096	6	59	\N	61050	77052	\N	60.342514558117898	ХантыМансийский автономный округ  Югра, Березовский район, пгт.Березово, ул.Ленина, 20, Здание начальной школы	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район	0101000020E6100000BBD39D279E155240D9B11188D72B4E40
9151	6	59	\N	61090	77181	\N	62.458489	"ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Октябрьское, Советская, 27, помещение ФОК ""Юбилейный"""	Россия	0101000020E6100000D3A57F492A825040B2497EC4AF3A4F40
9130	6	59	\N	61053	81169	\N	63.702528231638603	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, Набережная, 16	Россия	0101000020E61000001C5C3AE63CAB50401C430070ECD94F40
9128	6	59	\N	61053	81167	\N	63.705878721805099	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, 3 микрорайон, 34	Россия	0101000020E610000030134548DDAA504073F7393E5ADA4F40
9127	6	59	\N	61053	81167	\N	63.700365476036097	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, 3 микрорайон, 36	Россия	0101000020E6100000D107CBD8D0AA5040AB21718FA5D94F40
9241	6	59	\N	61140	77344	\N	59.508004121987298	Ямки, Лесная (начальная школадетский сад), 30	Россия	0101000020E6100000C18EFF02419250405C1E6B4606C14D40
9458	6	59	\N	61190	77515	\N	61.2464805769647	ХантыМансийский автономный округ  Югра, ХантыМансийский район, деревня Ягурьях, улица Центральная, 14		0101000020E6100000E8FA3E1C24EA5040EE0A7DB08C9F4E40
9254	6	59	\N	61270	78031	\N	59.747884943133002	Ягодный, Центральная (культурноспортивный комплекс), 20		0101000020E6100000A4552DE928455040A01518B2BADF4D40
9239	6	59	\N	61126	77307	\N	59.527864409082603	Юмас, Полевая (средняя школа), 16А	Россия	0101000020E61000006EA301BC059B50402D5E2C0C91C34D40
9307	6	59	\N	60780	76323	\N	61.0016684159337	ХантыМансийский автономный округ  Югра, город Югорск, Чкалова, 1	Россия, Ханты-Мансийский автономный округ, город Ханты-Мансийск	0101000020E610000062DC0DA2B544514091B932A836804E40
9310	6	59	\N	60780	76185	\N	61.001001604718603	ХантыМансийский автономный округ  Югра, город Югорск, Спортивная, 6	Россия, Ханты-Мансийский автономный округ, город Ханты-Мансийск	0101000020E6100000EACF7EA488445140849D62D520804E40
9308	6	59	\N	60780	77356	\N	61.322342999999996	ХантыМансийский автономный округ  Югра, город Югорск, Садовая, 1Б	Россия	0101000020E6100000E42CEC6987A54F40198C118942A94E40
9306	6	59	\N	60780	77356	\N	61.302691213633103	ХантыМансийский автономный округ  Югра, город Югорск, Садовая, 27	Россия	0101000020E610000082C8224DBCAF4F4093E52494BEA64E40
9313	6	59	\N	60780	77261	\N	61.306169936538303	ХантыМансийский автономный округ  Югра, город Югорск, Мира, 52	Россия	0101000020E61000007FA4880CABAA4F4017821C9430A74E40
9316	6	59	\N	60780	77675	\N	61.319869845428698	ХантыМансийский автономный округ  Югра, город Югорск, Микрорайон Югорск2, здание школы № 4.	Россия	0101000020E610000045D95BCAF9AA4F405B7C0A80F1A84E40
9311	6	59	\N	60780	77175	\N	61.271612961270797	ХантыМансийский автономный округ  Югра, город Югорск, Ленина, 18	Россия	0101000020E610000004CB1132909D4F409015FC36C4A24E40
9305	6	59	\N	60780	76306	\N	61.002001816274401	ХантыМансийский автономный округ  Югра, город Югорск, Ермака, 7	Россия, Ханты-Мансийский автономный округ, город Ханты-Мансийск	0101000020E6100000D82D02637D4451406743FE9941804E40
9312	6	59	\N	60780	76413	\N	61.0016684159337	ХантыМансийский автономный округ  Югра, город Югорск, Геологов, 13	Россия, Ханты-Мансийский автономный округ, город Ханты-Мансийск	0101000020E6100000265646239F44514091B932A836804E40
9235	6	59	\N	61262	77858	\N	60.214655	Шугур, Школьная, 8 (средняя школа)		0101000020E6100000AF7C96E7C19E50402176A6D0791B4E40
9173	6	59	\N	61240	77717	\N	63.034071253212502	"ХантыМансийский автономный округ  Югра, Октябрьский район, д. Чемаши, Школьная, 15, МОУ ""Чемашинская СОШ"""		0101000020E6100000323A2009FB4B5040FA5E43705C844F40
9260	6	59	\N	61294	78293	\N	60.307952999999998	Чантырья, Шаимская (Дом культуры), 11	Россия	0101000020E61000008544DAC69F0C504040DAFF006B274E40
9479	6	59	\N	55060	41825	\N	61.001262405113302	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Ямская, 6		0101000020E6100000577C43E1B3415140205D6C5A29804E40
9492	6	59	\N	55060	41790	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Чехова, 81		0101000020E61000005FD04202464451401A4F04711E804E40
9491	6	59	\N	55060	41790	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Чехова, 71		0101000020E61000005FD04202464451401A4F04711E804E40
9487	6	59	\N	55060	76535	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Уральская, 11		0101000020E61000005FD04202464451401A4F04711E804E40
9486	6	59	\N	55060	41789	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Студенческая, 21		0101000020E61000005FD04202464451401A4F04711E804E40
9494	6	59	\N	55060	41829	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Строителей, 10		0101000020E61000005FD04202464451401A4F04711E804E40
9483	6	59	\N	55060	76473	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Свердлова, 27		0101000020E61000005FD04202464451401A4F04711E804E40
9482	6	59	\N	55060	41834	\N	61.000428878209803	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Рознина, 104	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E6100000420A9E42AE415140287CB60E0E804E40
9480	6	59	\N	55060	41834	\N	61.001679160335399	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Рознина, 35	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E6100000577C43E1B3415140850B790437804E40
9489	6	59	\N	55060	41793	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Мира, 104		0101000020E61000005FD04202464451401A4F04711E804E40
9485	6	59	\N	55060	41793	\N	61.001262405113302	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Мира, 40	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E61000002D98F8A3A8415140205D6C5A29804E40
9477	6	59	\N	55060	41793	\N	61.000762291604701	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Мира, 14 А	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E6100000F549EEB0894151402F8A1EF818804E40
9279	6	59	\N	55060	41840	\N	61.000595585346197	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Луговая, 15	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E6100000691EC022BF41514014419C8713804E40
9472	6	59	\N	55060	76507	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Лермонтова, 19 А		0101000020E61000005FD04202464451401A4F04711E804E40
9309	6	59	\N	55060	76178	\N	61.002335213103798	ХантыМансийский автономный округ  Югра, город Югорск, Ленина, 24	Россия, Ханты-Мансийский автономный округ, город Ханты-Мансийск	0101000020E6100000D82D02637D4451406E5166834C804E40
9488	6	59	\N	55060	76767	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Кооперативная, 43		0101000020E61000005FD04202464451401A4F04711E804E40
9214	6	59	\N	55065	41862	\N	62.143306317172801	город Нягань, микрорайон №3, дом №24	Россия	0101000020E610000093A641D13C58504009A9DBD957124F40
9481	6	59	\N	55060	41848	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Комсомольская, 40		0101000020E61000005FD04202464451401A4F04711E804E40
9484	6	59	\N	55060	41856	\N	61.000428878209803	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Калинина, 24		0101000020E61000007BC03C64CA415140287CB60E0E804E40
9493	6	59	\N	55060	41801	\N	61.001095701488303	ХантыМансийский автономный округ  Югра, город ХантыМансийск, ДунинаГоркавича, 1	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E6100000F0A2AF20CD4251400514EAE923804E40
9478	6	59	\N	55060	41797	\N	60.999261903675603	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Дзержинского, 7	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E6100000B2F2CB608C4351405A1135D1E77F4E40
9490	6	59	\N	55060	77120	\N	61.000581910184501	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Горная, 21	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E6100000395E81E849435140AF7B2B1213804E40
9476	6	59	\N	55060	41796	\N	61.001595809729899	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Гагарина, 3	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E61000005182FE428F425140F7E6374C34804E40
9475	6	59	\N	55060	41796	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Гагарина, 101		0101000020E61000005FD04202464451401A4F04711E804E40
9474	6	59	\N	55060	41796	\N	61.000928996985401	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Гагарина, 133 А	Россия, Ханты-Мансийский автономный округ, городской округ Ханты-Мансийск	0101000020E61000007E9065C1C44151401A4F04711E804E40
9473	6	59	\N	3251	41780	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Сургутская, 27		0101000020E61000005FD04202464451401A4F04711E804E40
9471	6	59	\N	3251	41779	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, город ХантыМансийск, Бориса Щербины, 3		0101000020E61000005FD04202464451401A4F04711E804E40
9466	6	59	\N	61078	77148	\N	61.633082999999999	ХантыМансийский автономный округ  Югра, ХантыМансийский район, поселок Урманный, улица Клубная, 11	Россия	0101000020E610000077483140A2F35040A8531EDD08D14E40
9272	6	59	\N	40347	76532	\N	60.129341634918099	ХантыМансийский автономный округ  Югра, город Урай, микрорайон Западный, дом 16	Россия	0101000020E6100000FAB48AFED0355040E7FF55478E104E40
9281	6	59	\N	40347	76587	\N	61.001001604718603	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 3, дом 55А	Россия, Ханты-Мансийский автономный округ, город Ханты-Мансийск	0101000020E61000008A05BEA25B445140849D62D520804E40
9276	6	59	\N	40347	41894	\N	60.131514120240702	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 2, дом 87	Россия	0101000020E61000000D17B9A7AB2F5040AB7B6473D5104E40
9264	6	59	\N	40347	77128	\N	60.147703075416302	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 1Г, 65	Россия	0101000020E6100000E97E4E417E315040B34291EEE7124E40
9268	6	59	\N	40347	77096	\N	60.147703075416302	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 1А, 73	Россия	0101000020E6100000A06B5F402F355040B34291EEE7124E40
9265	6	59	\N	40347	77096	\N	60.1436013557366	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 1А, 69а	Россия	0101000020E6100000A45016BEBE34504021567F8461124E40
9283	6	59	\N	40347	76648	\N	60.134351815912197	ХантыМансийский автономный округ  Югра, город Урай, улица Парковая, дом 1	Россия	0101000020E6100000CEA8F92AF93250407B13437232114E40
9263	6	59	\N	40347	41873	\N	60.1140833528587	ХантыМансийский автономный округ  Югра, город Урай, Нагорная, 24	Россия	0101000020E6100000138255F5F2305040C90391459A0E4E40
9274	6	59	\N	40347	41888	\N	60.137679053557797	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 2, дом 82	Россия	0101000020E6100000D575A8A6242F5040492C29779F114E40
9273	6	59	\N	40347	41896	\N	60.125861913115102	ХантыМансийский автономный округ  Югра, город Урай, микрорайон Западный, дом 8	Россия	0101000020E610000012178046E933504092E7FA3E1C104E40
9266	6	59	\N	40347	77071	\N	60.137447816929502	ХантыМансийский автономный округ  Югра, город Урай, Маяковского, 17	Россия	0101000020E6100000FDDB65BFEE315040477364E597114E40
9277	6	59	\N	40347	9897	\N	60.128911770102	ХантыМансийский автономный округ  Югра, город Урай, улица Ленина, дом 4	Россия	0101000020E610000027124C35B3325040EE073C3080104E40
9271	6	59	\N	40347	9897	\N	60.1281006160808	ХантыМансийский автономный округ  Югра, город Урай, Ленина, 51		0101000020E6100000B5A9BA4736345040DECA129D65104E40
9282	6	59	\N	40347	41882	\N	60.1193306883224	ХантыМансийский автономный округ  Югра, город Урай, улица Авиаторов, дом 24	Россия	0101000020E6100000EF37DA71C33150401233FB3C460F4E40
9280	6	59	\N	40347	41879	\N	60.113440764320799	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 3, дом 46А	Россия	0101000020E61000007E737FF5B83050404583143C850E4E40
9278	6	59	\N	40347	41879	\N	60.114190449725101	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 3, дом 22	Россия	0101000020E61000000ABE69FAEC305040DFC325C79D0E4E40
9275	6	59	\N	40347	41831	\N	60.114725928814799	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 2, дом 91	Россия	0101000020E6100000698D4127843150401D007157AF0E4E40
9269	6	59	\N	40347	41878	\N	60.113376504774997	ХантыМансийский автономный округ  Югра, город Урай, микрорайон 1А, 74	Россия	0101000020E6100000917D9065C13050402E8F3523830E4E40
9270	6	59	\N	40347	76579	\N	60.125137285350398	ХантыМансийский автономный округ  Югра, город Урай, Ленина, 97	Россия	0101000020E61000007D96E7C1DD33504081423D7D04104E40
9576	6	59	\N	7010	77213	\N	61.268163646774298	ХантыМансийский автономный округ  Югра, город Сургут, Энергетиков, 49		0101000020E610000080828B15355C524076FBAC3253A24E40
9179	6	59	\N	55066	41827	\N	61.550693473954297	ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Талинка, мкр. Центральный, 37	Россия	0101000020E61000009F02603C839B50406D91B41B7DC64E40
9178	6	59	\N	55066	81176	\N	61.543403000207299	ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Талинка, 2 микрорайон, 6		0101000020E6100000C59272F7399C50402EC6C03A8EC54E40
9636	6	59	\N	7010	\N	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, поселок Дорожный, МОУ школа №22		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9606	6	59	\N	7010	77267	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проспект Пролетарский, 14а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9597	6	59	\N	7010	77267	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проспект Пролетарский, 10/3		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9542	6	59	\N	7010	77267	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проспект Пролетарский, 5/1		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9533	6	59	\N	7010	41803	\N	61.256070814828298	ХантыМансийский автономный округ  Югра, город Сургут, проспект Мира, 44/2		0101000020E6100000B1A4DC7D8E5952401D3A3DEFC6A04E40
9527	6	59	\N	7010	41803	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проспект Мира, 23		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9573	6	59	\N	7010	41791	\N	61.260559108105099	ХантыМансийский автономный округ  Югра, город Сургут, проспект Ленина, 33а		0101000020E610000006465ED6C4575240D8D64FFF59A14E40
9517	6	59	\N	7010	41791	\N	61.285408436410997	ХантыМансийский автономный округ  Югра, город Сургут, проспект Ленина, 46	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000F7CB272B865752402502D53F88A44E40
9497	6	59	7345	\N	41791	\N	61.2694240033128	ХантыМансийский автономный округ  Югра, город Сургут, проспект Ленина, 75	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E6100000D787F546AD575240F660527C7CA24E40
9495	6	59	7343	\N	41791	\N	61.2704983655521	ХантыМансийский автономный округ  Югра, город Сургут, проспект Ленина, 79	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E6100000D5EB1681B157524014D1AFAD9FA24E40
9613	6	59	\N	7010	77321	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проспект Комсомольский, 29		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9607	6	59	\N	7010	77321	\N	61.256342753040897	ХантыМансийский автономный округ  Югра, город Сургут, проспект Комсомольский, 10	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E610000089B14CBF445952407EC7F0D8CFA04E40
9603	6	59	\N	7010	77321	\N	61.239637103749502	ХантыМансийский автономный округ  Югра, город Сургут, проспект Комсомольский, 21/2	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000006D5512D9075D5240AEF4DA6CAC9E4E40
9610	6	59	\N	7010	77410	\N	61.255102540601797	ХантыМансийский автономный округ  Югра, город Сургут, проезд Первопроходцев, 12/1	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E6100000252191B6F1595240450E1137A7A04E40
9600	6	59	\N	7010	77410	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проезд Первопроходцев, 2		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9599	6	59	\N	7010	77410	\N	61.264072303820299	ХантыМансийский автономный округ  Югра, город Сургут, проезд Первопроходцев, 1а	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E61000003DF19C2D2059524008E57D1CCDA14E40
9558	6	59	\N	7010	77513	\N	61.244682817617701	ХантыМансийский автономный округ  Югра, город Сургут, проезд Дружбы, 12а		0101000020E610000010AFEB17EC5952408F71C5C5519F4E40
9619	6	59	\N	7010	77197	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проезд Взлетный, 4		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9616	6	59	\N	7010	77197	\N	61.269214162634697	ХантыМансийский автономный округ  Югра, город Сургут, проезд Взлетный, 6		0101000020E6100000F910548D5E5B52400BD0B69A75A24E40
9615	6	59	\N	7010	77197	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, проезд Взлетный, 3		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9570	6	59	\N	7010	77287	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, бульвар Свободы, 6		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9506	6	59	\N	7010	41795	\N	61.254348054016198	ХантыМансийский автономный округ  Югра, город Сургут, Энтузиастов, 1		0101000020E6100000CFBEF2203D575240C9E6AA798EA04E40
9504	6	59	\N	7010	41795	\N	61.285573640921498	ХантыМансийский автономный округ  Югра, город Сургут, Энтузиастов, 31	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000001B1021AE9C575240404B57B08DA44E40
9502	6	59	\N	7010	41795	\N	61.284912817646301	ХантыМансийский автономный округ  Югра, город Сургут, Энтузиастов, 49	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000F4FBFECD8B575240469A780778A44E40
9501	6	59	\N	7010	41795	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Энтузиастов, 54		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9500	6	59	\N	7010	41795	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Энтузиастов, 61/а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9584	6	59	\N	7010	77213	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Энергетиков, 5/1		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9582	6	59	\N	7010	77213	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Энергетиков, 8		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9575	6	59	\N	7010	77213	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Энергетиков, 51		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9578	6	59	\N	7010	77389	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Энгельса, 7		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9523	6	59	\N	7010	41800	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Чехова, 5/2		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9498	6	59	\N	7010	41837	\N	61.284895393406302	ХантыМансийский автономный округ  Югра, город Сургут, Флегонта Показаньева, 2	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000A4DFBE0E9C5752409FE5797077A44E40
9625	6	59	\N	7010	77338	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Федорова, 6		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9595	6	59	\N	7010	77338	\N	61.260889778619102	ХантыМансийский автономный округ  Югра, город Сургут, Федорова, 61/1		0101000020E610000026361FD7865952403EEDF0D764A14E40
9587	6	59	\N	7010	77338	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Федорова, 68а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9546	6	59	7345	\N	77617	\N	61.249975808303603	ХантыМансийский автономный округ  Югра, город Сургут, Университетская, 25/2	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E6100000B2F677B6475C52407764AC36FF9F4E40
9648	6	59	\N	7010	77274	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Толстого, 20а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9554	6	59	\N	7010	77342	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Сибирская, 2		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9556	6	59	\N	7010	77433	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Северная, 72а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9655	6	59	\N	7010	77549	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, поселок Юность ул. Саянская, 9а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9553	6	59	\N	7010	77490	\N	61.277749346470998	ХантыМансийский автономный округ  Югра, город Сургут, Рабочая, 43		0101000020E6100000EA40D653AB5A524094BF7B478DA34E40
9535	6	59	\N	7010	41838	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Пушкина, 10		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9531	6	59	\N	7010	41838	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Пушкина, 8/2		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9530	6	59	\N	7010	41838	\N	61.2845824007752	ХантыМансийский автономный округ  Югра, город Сургут, Пушкина, 15а	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000F4FBFECD8B575240E083D72E6DA44E40
9529	6	59	\N	7010	41838	\N	61.2842519804151	ХантыМансийский автономный округ  Югра, город Сургут, Пушкина, 15	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000F4FBFECD8B5752404BE9995E62A44E40
9585	6	59	\N	7010	77285	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Просвещения, 13		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9580	6	59	\N	7010	77285	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Просвещения, 50		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9659	6	59	\N	7010	77504	\N	61.264361608257602	ХантыМансийский автономный округ  Югра, город Сургут, Привокзальная, 23 здание ж/д вокзала		0101000020E61000004D4A41B7975952400F27309DD6A14E40
9641	6	59	\N	7010	77504	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Привокзальная, 16/2		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9528	6	59	7343	\N	41802	\N	61.260207766858997	ХантыМансийский автономный округ  Югра, город Сургут, Островского, 16/1	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E61000008B5242B0AA5952402B14E97E4EA14E40
9526	6	59	\N	7010	41802	\N	61.285738844559702	ХантыМансийский автономный округ  Югра, город Сургут, Островского, 21а	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000817A336ABE5752408B18761893A44E40
9516	6	59	\N	7010	41802	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Островского, 1а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9622	6	59	\N	7010	77260	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Нагорная, 7		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9505	6	59	\N	7010	41858	\N	61.284086768926699	ХантыМансийский автономный округ  Югра, город Сургут, проспект Набережный, 22	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000000806103E94575240001C7BF65CA44E40
9628	6	59	\N	7010	77020	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Мостостроителей, 1/а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9589	6	59	\N	7010	77536	\N	61.276096849018799	ХантыМансийский автономный округ  Югра, город Сургут, Московская, 33		0101000020E610000022E2E654325B524009C3802557A34E40
9650	6	59	\N	7010	77364	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Мечникова, 5а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9646	6	59	\N	7010	77364	\N	61.262543078825999	ХантыМансийский автономный округ  Югра, город Сургут, Мечникова, 5	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E6100000C66B5ED55959524099654F029BA14E40
9591	6	59	\N	7010	77560	\N	61.270808270885702	ХантыМансийский автономный округ  Югра, город Сургут, МеликКарамова, 74б		0101000020E6100000E65B1FD61B5B524062BF27D6A9A24E40
9621	6	59	\N	7010	77166	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Мелик Карамова, 57а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9534	6	59	\N	7010	41892	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Маяковского, 34а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9532	6	59	\N	7010	41892	\N	61.285680119928799	ХантыМансийский автономный округ  Югра, город Сургут, Маяковского, 41	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000007F677BF486575240868F882991A44E40
9525	6	59	\N	7010	41762	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Лермонтова, 8/2		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9524	6	59	\N	7010	41762	\N	61.285160628009898	ХантыМансийский автономный округ  Югра, город Сургут, Лермонтова, 7/2	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000001EE0490B975752401E8CD82780A44E40
9521	6	59	\N	7010	41762	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Лермонтова, 9		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9520	6	59	7343	\N	41762	\N	61.262780733556497	ХантыМансийский автономный округ  Югра, город Сургут, Лермонтова, 3/1	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E6100000B35C363AE75852404D81CCCEA2A14E40
9510	6	59	\N	7010	41890	\N	61.284912817646301	ХантыМансийский автономный округ  Югра, город Сургут, Ленинградская, 9	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000096EA46C91575240469A780778A44E40
9509	6	59	\N	7010	41890	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Ленинградская, 10а		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9639	6	59	\N	7010	77638	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Крылова, 29/1		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9496	6	59	7343	\N	41832	\N	61.269940528221497	ХантыМансийский автономный округ  Югра, город Сургут, Киртбая, 3/2	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E6100000524832AB77575240BE6C3B6D8DA24E40
9631	6	59	\N	7010	77343	\N	61.284110647203498	ХантыМансийский автономный округ  Югра, город Сургут, Индустриальная, 24		0101000020E61000001A506F46CD57524089B7CEBF5DA44E40
9538	6	59	\N	7010	77487	\N	61.263535017060597	ХантыМансийский автономный округ  Югра, город Сургут, Ивана Захарова, д.23/1, общежития УМВД	Россия, Ханты-Мансийский автономный округ, Сургутский район	0101000020E6100000292158552F5E5240F92CCF83BBA14E40
9657	6	59	\N	7010	77518	\N	61.260559108105099	ХантыМансийский автономный округ  Югра, город Сургут, поселок Снежный ул. Еловая, 8		0101000020E61000005A83F755B95B5240D8D64FFF59A14E40
9515	6	59	7345	\N	41777	\N	61.252539279308699	ХантыМансийский автономный округ  Югра, город Сургут, Декабристов, 5/1	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E61000009626A5A0DB58524076FBAC3253A04E40
9514	6	59	\N	7010	41777	\N	61.285656242849598	ХантыМансийский автономный округ  Югра, город Сургут, Декабристов, 8	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000BCADF4DA6C575240FEF3346090A44E40
9513	6	59	\N	7010	41777	\N	61.2549959575543	ХантыМансийский автономный округ  Югра, город Сургут, Декабристов, 16		0101000020E61000000135B56CAD5952402F4E7CB5A3A04E40
9512	6	59	\N	7010	41798	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Григория Кукуевицкого, 10/4		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9511	6	59	\N	7010	41798	\N	61.284688883155702	ХантыМансийский автономный округ  Югра, город Сургут, Григория Кукуевицкого, 12/3	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000A67B9DD497575240F6436CB070A44E40
9508	6	59	\N	7010	41798	\N	61.286564849667201	ХантыМансийский автономный округ  Югра, город Сургут, Григория Кукуевицкого, 9	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000E259828C80575240D1967329AEA44E40
9507	6	59	\N	7010	41798	\N	61.285408436410997	ХантыМансийский автономный округ  Югра, город Сургут, Григория Кукуевицкого, 3	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000001B1021AE9C5752402502D53F88A44E40
9644	6	59	\N	7010	77155	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Грибоедова, 12		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9593	6	59	\N	7010	77163	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Геологическая, 7/1		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9540	6	59	\N	7010	41839	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Быстринская, 18/4		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9537	6	59	\N	7010	41839	\N	61.284747851651403	ХантыМансийский автономный округ  Югра, город Сургут, Быстринская, 20	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000000C3ECDC98B575240FBCC599F72A44E40
9518	6	59	\N	7010	41836	\N	61.286399650390102	ХантыМансийский автономный округ  Югра, город Сургут, Бахилова, 5	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E6100000CDE7DCED7A57524086C954C1A8A44E40
9519	6	59	\N	7010	41891	\N	61.286069249219402	ХантыМансийский автономный округ  Югра, город Сургут, Бажова, 17	Россия, Ханты-Мансийский автономный округ, город Сургут	0101000020E61000001B1021AE9C57524020B3B3E89DA44E40
9637	6	59	\N	7010	77277	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, поселок Таежный, ул.Аэрофлотская, Спорткомплекс		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9633	6	59	\N	7010	77430	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Аэрофлотская, 22		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9503	6	59	\N	7010	76477	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, Артема, 9		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9568	6	59	\N	7010	77256	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, 50 лет ВЛКСМ, 10/2		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9566	6	59	\N	7010	77256	\N	61.254833821435298	ХантыМансийский автономный округ  Югра, город Сургут, 50 лет ВЛКСМ, 9а	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E61000008753E6E61B5A524056F487669EA04E40
9563	6	59	\N	7010	77256	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, 50 лет ВЛКСМ, 6в		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9562	6	59	\N	7010	77256	\N	61.261551109174398	ХантыМансийский автономный округ  Югра, город Сургут, 50 лет ВЛКСМ, 6/1		0101000020E6100000745E6397A8595240389ECF807AA14E40
9549	6	59	\N	7010	41804	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, 30 лет Победы, 26		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9548	6	59	\N	7010	41804	\N	61.285077999999999	ХантыМансийский автономный округ  Югра, город Сургут, 30 лет Победы, 54/1		0101000020E6100000BB4560AC6F5752409067976F7DA44E40
9536	6	59	7343	\N	41804	\N	61.255888014180499	ХантыМансийский автономный округ  Югра, город Сургут, 30 лет Победы, 39/1	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E61000001F84807C095C52402CB81FF0C0A04E40
9144	6	59	\N	61172	77439	\N	64.203982999999994	ХантыМансийский автономный округ  Югра, Белоярский район, сельское поселение Сорум, Центральная, 34	Россия	0101000020E6100000BF45274BAD495140287CB60E0E0D5040
9298	6	59	\N	55074	41899	\N	61.371962102561596	"ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, мкр. Хвойный, 53 ""а"""	Россия	0101000020E6100000F661BD512BC84F4069AD68739CAF4E40
9292	6	59	\N	55074	81178	\N	61.371281706106103	"ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Советская, 10 ""а"""	Россия	0101000020E6100000548CF337A1C84F40F7CB272B86AF4E40
9293	6	59	\N	55074	77236	\N	61.369963667234103	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Ленина, 12	Россия	0101000020E610000094F7713447C84F404359F8FA5AAF4E40
9295	6	59	\N	55074	81181	\N	61.375565000000002	"ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Киевская, 26 ""а"""		0101000020E61000001CEBE2361AC84F40D942908312B04E40
9294	6	59	\N	55074	77170	\N	61.366880000000002	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Гастелло, 24	Россия	0101000020E610000095D39E9273C84F403BC780ECF5AE4E40
9424	6	59	\N	61183	77477	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Сибирский, улица Центральная, 7		0101000020E61000005FD04202464451401A4F04711E804E40
9162	6	59	\N	61062	77105	\N	62.455258857742201	"ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Сергино, Центральная, 14, помещение МБУК КДЦ ""Овация"""	Россия	0101000020E6100000EA3F6B7EFC635040D61A4AED453A4F40
9117	6	59	\N	61223	77648	\N	62.730152021323399	ХантыМансийский автономный округ  Югра, Березовский район, п.Светлый, ул.Набережная, 21В. Здание спортивнооздоров. комп	Россия	0101000020E6100000677FA0DCB6175040F38DE89E755D4F40
9122	6	59	\N	61137	77333	\N	64.242252293493095	ХантыМансийский автономный округ  Югра, Березовский район, п.Саранпауль, ул.Н.Вокуева, 12. Здание средней школы	Россия	0101000020E610000092EBA694D7744E40FF58880E810F5040
9858	6	59	\N	61154	\N	\N	62.084359999999997	"ХантыМансийский автономный округ  Югра, город Радужный, Городской парк культуры и отдыха, строение 2, МУ СК ""Сибирь"""	Россия	0101000020E610000022179CC1DF5E5340978BF84ECC0A4F40
9870	6	59	\N	61154	77542	\N	62.106299746645497	"ХантыМансийский автономный округ  Югра, город Радужный, микрорайон ""Южный"", улица Ломоносова, дом 25, здание КСК ""Досуг"""	Россия	0101000020E6100000CEFDD5E3BE5E53404BC8073D9B0D4F40
9861	6	59	\N	61154	77424	\N	62.103210547143298	"ХантыМансийский автономный округ  Югра, город Радужный, 9 микрорайон, дом 10,  МУ ГПМЦ ""Альянс"""		0101000020E61000003F726BD26D5E534032CB9E04360D4F40
9869	6	59	\N	61154	77650	\N	62.106299746645497	ХантыМансийский автономный округ  Югра, город Радужный, 7 микрорайон, дом 25, МОУ СОШ №5	Россия	0101000020E6100000CEFDD5E3BE5E53404BC8073D9B0D4F40
9866	6	59	\N	61154	77435	\N	62.106299746645497	ХантыМансийский автономный округ  Югра, город Радужный, 6 микрорайон, дом 30,  МОУ СОШ №8	Россия	0101000020E6100000CEFDD5E3BE5E53404BC8073D9B0D4F40
9865	6	59	\N	61154	77435	\N	62.106299746645497	ХантыМансийский автономный округ  Югра, город Радужный, 6 микрорайон, дом 30, МОУ СОШ №8	Россия	0101000020E6100000CEFDD5E3BE5E53404BC8073D9B0D4F40
9873	6	59	\N	61154	77652	\N	62.106299746645497	ХантыМансийский автономный округ  Югра, город Радужный, 3 микрорайон, дом 12, МОУ СОШ №3	Россия	0101000020E6100000CEFDD5E3BE5E53404BC8073D9B0D4F40
9854	6	59	\N	\N	77603	\N	62.079738999999996	ХантыМансийский автономный округ  Югра, город Радужный, 2 микрорайон, дом 19, МОУ СОШ №4	Россия	0101000020E610000081B3942C275F53409D9B36E3340A4F40
9852	6	59	\N	61154	77658	\N	62.087184999999998	ХантыМансийский автономный округ  Югра, город Радужный, 1 микрорайон, дом 11, МОУ СОШ №2	Россия	0101000020E61000006DE7FBA9F15E5340D3D9C9E0280B4F40
9855	6	59	\N	61154	77677	\N	62.096208158766402	ХантыМансийский автономный округ  Югра, город Радужный, 5 микрорайон, дом 16,  МОУ СОШ №6	Россия	0101000020E61000003D433866D95E534089CE328B500C4F40
9366	6	59	\N	55056	41893	\N	60.725757999999999	"ХантыМансийский автономный округ  Югра, город ПытьЯх, 2А микрорайон, улица Советская, дом 1, КСК ""Россия"""		0101000020E6100000F03499F1B6335240BA675DA3E55C4E40
9218	6	59	\N	55065	41866	\N	62.143386645879097	город Нягань, микрорайон №4, дом №13	Россия	0101000020E6100000CEAACFD556585040F5D555815A124F40
9372	6	59	\N	55056	41855	\N	60.7488092153406	"ХантыМансийский автономный округ  Югра, город ПытьЯх, 6 микрорайон ""Пионерный"", улица Магистральная, дом 57, МОУ СОШ № 6"		0101000020E6100000D42CD0EE90325240A9F92AF9D85F4E40
9369	6	59	\N	55056	41854	\N	60.7498173852915	ХантыМансийский автономный округ  Югра, город ПытьЯх, 5 микрорайон, дом 5А, МОУ СОШ № 5 (3 этаж)		0101000020E61000007192E68F693252400F7EE200FA5F4E40
9371	6	59	\N	55056	41763	\N	60.725757999999999	ХантыМансийский автономный округ  Югра, город ПытьЯх, 3 микрорайон, дом 34А, МОУ СОШ № 4		0101000020E6100000F03499F1B6335240BA675DA3E55C4E40
9365	6	59	\N	55056	41812	\N	60.749710728189697	ХантыМансийский автономный округ  Югра, город ПытьЯх, 2 микрорайон, дом 5А, МОУ СОШ  № 1	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, город Пыть-Ях	0101000020E6100000446CB07092325240C939B187F65F4E40
9364	6	59	\N	55056	41812	\N	60.749626714960698	ХантыМансийский автономный округ  Югра, город ПытьЯх, 2 микрорайон, дом 5А,  МОУ СОШ №1		0101000020E6100000419C8713983252406B990CC7F35F4E40
9362	6	59	\N	55056	41852	\N	60.748977245872503	"ХантыМансийский автономный округ  Югра, город ПытьЯх, 1 микрорвйон, дом 11А ,ГДК ""Факел"" (зал Апельсин)"		0101000020E6100000E6CE4C309C325240643A747ADE5F4E40
9363	6	59	\N	55056	41853	\N	60.750237446725698	"ХантыМансийский автономный округ  Югра, город ПытьЯх, 1 микрорайон, дом 11А, ГДК ""Факел"" (фойе)"		0101000020E6100000849CF7FF71325240E49F19C407604E40
9160	6	59	\N	61059	81168	\N	62.552899147653697	ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Приобье, Югорская, 5, здание администрации поселения	Россия	0101000020E6100000B6F81400E3665040DC7EF964C5464F40
9161	6	59	\N	61059	77108	\N	62.5535321312232	ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Приобье, Школьная, 1	Россия	0101000020E6100000859675FF586950400DA5F622DA464F40
9801	6	59	\N	61160	77408	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Молодежная,д.9/1, ""СОШ №1"""		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9820	6	59	\N	61160	77403	\N	61.713330999999997	ХантыМансийский автономный округ  Югра, город Покачи, Аганская, 11		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9166	6	59	\N	62113	81171	\N	62.968007078369403	"ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Перегребное, Строителей, 50, МКОУ ДОД ""Дом юного техника"""	Россия	0101000020E6100000BF9EAF592E46504048A643A7E77B4F40
9198	6	59	\N	61248	77760	\N	61.640326890282203	ХантыМансийский автономный округ  Югра, Октябрьский район, с. Пальяново, Почтовая, 13/1, здание администрации	Россия	0101000020E6100000F180B22957B8504076DF313CF6D14E40
9152	6	59	\N	61077	77160	\N	62.455893917231698	ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Октябрьское, Светлая, 11	Россия	0101000020E610000010786000E1865040A8380EBC5A3A4F40
9211	6	59	\N	55069	77113	\N	62.144615999999999	город Нягань, проспект Нефтяников, дом №4	Россия	0101000020E61000009E5E29CB105850403A3DEFC682124F40
9221	6	59	\N	55069	41872	\N	62.148928810501701	город Нягань, микрорайон №1, дом №25	Россия	0101000020E610000082380F27305850408736001B10134F40
9219	6	59	\N	55069	41872	\N	62.135618169191197	город Нягань, микрорайон №1, дом №25А	Россия	0101000020E610000019C5724BAB5B5040DD5F3DEE5B114F40
9204	6	59	\N	55069	76904	\N	62.1234022184887	город Нягань, микрорайон Энергетиков, дом №55	Россия	0101000020E61000009D499BAA7B585040682101A3CB0F4F40
9212	6	59	\N	55069	41886	\N	62.143547302650497	город Нягань, улица Солнечная, дом №7		0101000020E61000006B63EC84975850402E3883BF5F124F40
9210	6	59	\N	55069	41885	\N	62.142021028806397	город Нягань, улица Сибирская, дом №32	Россия	0101000020E610000068B27F9E06595040302C7FBE2D124F40
9229	6	59	\N	55069	41875	\N	62.1435071385378	город Нягань, улица Речная, дом №191		0101000020E6100000BC41B456B4585040A0DFF76F5E124F40
9227	6	59	\N	55069	41875	\N	62.145821508362801	город Нягань, улица Речная, дом №57	Россия	0101000020E6100000925852EE3E585040C784984BAA124F40
9225	6	59	\N	55069	41874	\N	62.151440788416501	город Нягань, улица Пионерская, дом №2	Россия	0101000020E61000008B36C7B94D5D504003232F6B62134F40
9213	6	59	\N	55069	41884	\N	62.140253667964501	город Нягань, микрорайон №7, дом №2	Россия	0101000020E6100000F4A44C6A685850400C91D3D7F3114F40
9220	6	59	\N	55069	41881	\N	62.143145659119099	город Нягань, микрорайон №1, дом №52А	Россия	0101000020E6100000CF4BC5C6BC585040D046AE9B52124F40
9164	6	59	\N	55069	77123	\N	62.142045000000003	город Нягань, улица Лазарева, дом №15 корпус№1	Россия	0101000020E6100000DAE4F04927585040B9C7D2872E124F40
9223	6	59	7548	\N	77341	\N	62.142502999999998	город Нягань, улица Авиционная, дом №20	Россия	0101000020E6100000E3C4573B8A5850407B4ACE893D124F40
9209	6	59	\N	55069	76934	\N	62.143973000000003	город Нягань, улица 30 лет Победы, дом №13		0101000020E6100000DAE4F04927585040E6400FB56D124F40
9205	6	59	\N	55069	76934	\N	62.149113999999997	город Нягань, улица 30 лет Победы, дом №12	Россия	0101000020E6100000DAE4F0492758504018B0E42A16134F40
9216	6	59	\N	55069	41887	\N	62.142503018355498	город Нягань, микрорайон №2, дом №30 блок№1		0101000020E61000001D740987DE5850407B4ACE893D124F40
9217	6	59	\N	55065	41865	\N	62.150213804809603	город Нягань, микрорайон №2, дом №50А	Россия	0101000020E61000007E5358A9A05850405FB35C363A134F40
9215	6	59	\N	55065	41865	\N	62.148928810501701	город Нягань, микрорайон №2, дом №31		0101000020E61000003410CB660E5850408736001B10134F40
9208	6	59	\N	55065	41861	\N	62.140575013993697	город Нягань, улица Чернышова, дом №42	Россия	0101000020E6100000F65FE7A6CD5850404ED1915CFE114F40
9228	6	59	\N	55065	41871	\N	62.143085412128599	город Нягань, улица Уральская, дом №7	Россия	0101000020E61000006C97361C965850402AC6F99B50124F40
9226	6	59	\N	55065	41819	\N	62.142181692844296	город Нягань, улица Пионерская, дом №30	Россия	0101000020E6100000F65FE7A6CD585040390A100533124F40
9207	6	59	\N	55065	41860	\N	62.150103299331299	город Нягань, улица Комсомольская, дом №2Б	Россия	0101000020E61000002046088F3658504008043A9336134F40
9222	6	59	\N	55065	41868	\N	62.142101360932202	город Нягань, улица Загородных, дом №7А	Россия	0101000020E61000007FA65EB7085950404CDD955D30124F40
10072	6	59	\N	1172	\N	\N	60.923344310051597	ХантыМансийский автономный округ  Югра, город Нижневартовск6, ГПЗ1	Россия, Ханты-Мансийский автономный округ, город Нижневартовск	0101000020E610000069A9BC1DE12653409A7ADD2230764E40
10068	6	59	\N	1172	\N	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, поселок Дивный, 13		0101000020E610000081936DE00E25534094C2BCC799764E40
10056	6	59	\N	1172	\N	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, поселок Магистраль, 47		0101000020E610000081936DE00E25534094C2BCC799764E40
9961	6	59	\N	1172	77367	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, проспект Победы, 20В		0101000020E610000081936DE00E25534094C2BCC799764E40
9959	6	59	\N	1172	77367	\N	60.936255025328897	ХантыМансийский автономный округ  Югра, город Нижневартовск, проспект Победы, 21Б		0101000020E6100000B4E7323509275340B6DB2E34D7774E40
9952	6	59	\N	1172	77367	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, проспект Победы, 3Б		0101000020E610000081936DE00E25534094C2BCC799764E40
10014	6	59	\N	1172	77130	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, проезд Заозерный, 8Б		0101000020E610000081936DE00E25534094C2BCC799764E40
10048	6	59	\N	1172	77414	\N	60.943771178154499	ХантыМансийский автономный округ  Югра, город Нижневартовск, Энтузиастов, 25		0101000020E610000044A51133FB255340E4F4F57CCD784E40
10051	6	59	\N	1172	77312	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Школьная, 26		0101000020E610000081936DE00E25534094C2BCC799764E40
10020	6	59	\N	1172	77368	\N	60.931911547871898	ХантыМансийский автономный округ  Югра, город Нижневартовск, Чапаева, 15А		0101000020E61000002D095053CB265340FE5F75E448774E40
9985	6	59	\N	1172	77368	\N	60.936422070286099	ХантыМансийский автономный округ  Югра, город Нижневартовск, Чапаева, 30	Россия, Ханты-Мансийский автономный округ, город Нижневартовск	0101000020E6100000603B18B14F245340A1A014ADDC774E40
10026	6	59	\N	1172	77222	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, ХантыМансийская, 41Б		0101000020E610000081936DE00E25534094C2BCC799764E40
10023	6	59	\N	1172	77222	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, ХантыМансийская, 39Б		0101000020E610000081936DE00E25534094C2BCC799764E40
10021	6	59	\N	1172	77568	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, ХантыМансийская, 41А		0101000020E610000081936DE00E25534094C2BCC799764E40
10016	6	59	\N	1172	77198	\N	60.938092471509002	ХантыМансийский автономный округ  Югра, город Нижневартовск, Спортивная, 21		0101000020E6100000A85489B2B7255340D2510E6613784E40
9977	6	59	\N	1172	77198	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Спортивная, 6		0101000020E610000081936DE00E25534094C2BCC799764E40
9956	6	59	\N	1172	77485	\N	60.947278107014498	ХантыМансийский автономный округ  Югра, город Нижневартовск, Пионерская, 9А		0101000020E610000091B8C7D287265340321CCF6740794E40
10002	6	59	\N	1172	77387	\N	60.946610150447597	ХантыМансийский автономный округ  Югра, город Нижневартовск, Пермская, 25	Россия, Ханты-Мансийский автономный округ, городской округ Нижневартовск	0101000020E61000008DB800344A225340850838842A794E40
10000	6	59	\N	1172	77387	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Пермская, 19		0101000020E610000081936DE00E25534094C2BCC799764E40
10046	6	59	\N	1172	9869	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Первомайская, 63		0101000020E610000081936DE00E25534094C2BCC799764E40
10040	6	59	\N	1172	77153	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Омская, 66А		0101000020E610000081936DE00E25534094C2BCC799764E40
9954	6	59	\N	1172	77153	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Омская, 2А		0101000020E610000081936DE00E25534094C2BCC799764E40
9931	6	59	\N	1172	77153	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Омская, 16А		0101000020E610000081936DE00E25534094C2BCC799764E40
10007	6	59	\N	1172	77193	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Нефтяников, 93А		0101000020E610000081936DE00E25534094C2BCC799764E40
9988	6	59	\N	1172	77193	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Нефтяников, 66А		0101000020E610000081936DE00E25534094C2BCC799764E40
9994	6	59	\N	1172	77373	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Мусы Джалиля, 20		0101000020E610000081936DE00E25534094C2BCC799764E40
9990	6	59	\N	1172	77373	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Мусы Джалиля, 51А		0101000020E610000081936DE00E25534094C2BCC799764E40
10030	6	59	\N	1172	77259	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Мира, 76В		0101000020E610000081936DE00E25534094C2BCC799764E40
10028	6	59	\N	1172	77259	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Мира, 76Б		0101000020E610000081936DE00E25534094C2BCC799764E40
9993	6	59	\N	1172	77259	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Мира, 56Б		0101000020E610000081936DE00E25534094C2BCC799764E40
9987	6	59	\N	1172	77259	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Мира, 39		0101000020E610000081936DE00E25534094C2BCC799764E40
9973	6	59	\N	1172	77259	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Мира, 13А		0101000020E610000081936DE00E25534094C2BCC799764E40
9975	6	59	\N	1172	77382	\N	60.940263861680798	ХантыМансийский автономный округ  Югра, город Нижневартовск, Маршала Жукова, 40Б		0101000020E6100000416667D13B27534096CD1C925A784E40
9970	6	59	\N	1172	77382	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Маршала Жукова, 16А		0101000020E610000081936DE00E25534094C2BCC799764E40
10038	6	59	\N	1172	77172	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Ленина, 56		0101000020E610000081936DE00E25534094C2BCC799764E40
10017	6	59	7530	\N	77172	\N	60.934072919833703	ХантыМансийский автономный округ  Югра, город Нижневартовск, Ленина, 23А	Россия, Ханты-Мансийский автономный округ, городской округ Нижневартовск	0101000020E6100000EC89AE0B3F265340CE893DB48F774E40
9964	6	59	\N	1172	77172	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Ленина, 9А		0101000020E610000081936DE00E25534094C2BCC799764E40
9968	6	59	\N	1172	77478	\N	60.941892306821401	ХантыМансийский автономный округ  Югра, город Нижневартовск, Комсомольский бульвар, 10А		0101000020E61000005EF23FF9BB245340992EC4EA8F784E40
9967	6	59	\N	1172	77478	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Комсомольский бульвар, 3		0101000020E610000081936DE00E25534094C2BCC799764E40
10011	6	59	\N	1172	77642	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Интернациональная, 3		0101000020E610000081936DE00E25534094C2BCC799764E40
10009	6	59	\N	1172	77642	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Интернациональная, 7А		0101000020E610000081936DE00E25534094C2BCC799764E40
10067	6	59	\N	1172	77133	\N	60.9108539678898	ХантыМансийский автономный округ  Югра, город Нижневартовск, Индустриальная, 13		0101000020E61000008BA9F413CE27534024B726DD96744E40
10063	6	59	\N	1172	77133	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Индустриальная, 95		0101000020E610000081936DE00E25534094C2BCC799764E40
10054	6	59	\N	1172	77184	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Зырянова, 4		0101000020E610000081936DE00E25534094C2BCC799764E40
10061	6	59	\N	1172	77541	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, поселок Тепличный , ул.Заводская, 9		0101000020E610000081936DE00E25534094C2BCC799764E40
10057	6	59	\N	1172	77300	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, поселок Тепличный , ул. Заводская, 9		0101000020E610000081936DE00E25534094C2BCC799764E40
10043	6	59	\N	1172	77134	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дружбы Народов, 14		0101000020E610000081936DE00E25534094C2BCC799764E40
10035	6	59	\N	1172	77134	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дружбы Народов, 13Б		0101000020E610000081936DE00E25534094C2BCC799764E40
10034	6	59	\N	1172	77134	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дружбы Народов, 13А		0101000020E610000081936DE00E25534094C2BCC799764E40
10032	6	59	\N	1172	77134	\N	60.946547528798497	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дружбы Народов, 19А		0101000020E6100000CE001764CB2553400F0C207C28794E40
10005	6	59	\N	1172	77220	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дзержинского, 29А		0101000020E610000081936DE00E25534094C2BCC799764E40
9999	6	59	\N	1172	77220	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дзержинского, 27А		0101000020E610000081936DE00E25534094C2BCC799764E40
9983	6	59	\N	1172	77220	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дзержинского, 11		0101000020E610000081936DE00E25534094C2BCC799764E40
9980	6	59	\N	1172	77220	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дзержинского, 17А		0101000020E610000081936DE00E25534094C2BCC799764E40
9979	6	59	\N	1172	77220	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Дзержинского, 17В		0101000020E610000081936DE00E25534094C2BCC799764E40
10065	6	59	\N	1172	77385	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, Авиаторов, 4		0101000020E610000081936DE00E25534094C2BCC799764E40
10045	6	59	\N	1172	77258	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, 60 лет Октября, 82		0101000020E610000081936DE00E25534094C2BCC799764E40
9996	6	59	\N	1172	77258	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, 60 лет Октября, 11/2		0101000020E610000081936DE00E25534094C2BCC799764E40
9950	6	59	\N	1172	77258	\N	60.926568000000003	ХантыМансийский автономный округ  Югра, город Нижневартовск, 60 лет Октября, 6А		0101000020E610000081936DE00E25534094C2BCC799764E40
10070	6	59	\N	1172	77726	\N	60.925457880708898	ХантыМансийский автономный округ  Югра, город Нижневартовск, Югозападный промышленный узел, панель 25, ул. 2П2, 36		0101000020E6100000397D3D5FB321534029E9616875764E40
9378	6	59	\N	8178	\N	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, жилой городок СУ62, строение №24, СК ""Факел"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9394	6	59	\N	8178	41847	\N	61.097530693918898	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 10 микрорайон, ул. Мира, д.32, Нефтеюганский проф. лицей	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E6100000BB26A435062552404FAC53E57B8C4E40
9400	6	59	\N	8178	76279	\N	61.09778	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 11А микрорайон, ул. Магистральная, здание №20, Начальная школадетский сад №4		0101000020E6100000317898F6CD245240F819170E848C4E40
9396	6	59	\N	8178	41826	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, ул. Жилая, строение №8, корпус №1, ООО ""Югансктранстепплосервис"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9395	6	59	\N	8178	41826	\N	61.094570107025099	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, ул. Жилая, строение №8, корпус №1, ООО ""Югансктранстеплосервис"""	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E6100000840F255AF22752406397A8DE1A8C4E40
9391	6	59	\N	8178	76668	\N	61.090632723202802	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 9 микрорайон, здание №35, МОУ ""СОШ №3"""	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E610000039B709F7CA2752401C78B5DC998B4E40
9389	6	59	\N	8178	76633	\N	61.093022223208798	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 8А микрорайон, здание №17, МОУ ""СОШ №17"""		0101000020E610000074982F2FC02852407DE71725E88B4E40
9388	6	59	\N	8178	41821	\N	61.091796409592703	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 8 микрорайон, здание №28, Центр доп. образования для детей	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E6100000C58F31772D275240AAF3A8F8BF8B4E40
9387	6	59	\N	8178	41821	\N	61.0919626354058	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 8 микрорайон, здание №28, МОУ ""СОШ №6"""	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E61000000116F9F54327524095B88E71C58B4E40
9385	6	59	\N	8178	41820	\N	61.092004110557603	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 7 микрорайон, здание №31, МОУ ""СОШ №4"""	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E61000001FBC7669C3275240F48C7DC9C68B4E40
9384	6	59	\N	8178	41818	\N	61.094809035342301	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 5 микрорайон, здание №66, МОУ ""СОШ №2"""	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E6100000D865F84F37275240E82E89B3228C4E40
9383	6	59	\N	8178	41810	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 3 микрорайон, дом №17, ЦКиД ""Строитель"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9382	6	59	\N	8178	41810	\N	61.098444758831199	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 3 микрорайон, дом №17, Центр молодежных инициатив	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E61000001FD61BB5C224524034BA83D8998C4E40
9381	6	59	\N	8178	41773	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 2 микрорайон, здание №29, МОУ ""СОШ №5"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9412	6	59	\N	8178	41775	\N	61.078991711404797	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 16А микрорайон, здание №65, Начальная школадетский сад №15	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E6100000F8A75489B2275240A452EC681C8A4E40
9411	6	59	\N	8178	41775	\N	61.082985106593902	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 16А микрорайон, здание №84, Лицей №1	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E6100000363AE7A7382852407F87A2409F8A4E40
9410	6	59	\N	8178	41775	\N	61.097177444227697	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 16А микрорайон, здание №84		0101000020E61000008F8CD5E6FF2452403276C24B708C4E40
9413	6	59	\N	8178	41778	\N	61.09778	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 16 микрорайон, дом №33, НКИ		0101000020E6100000317898F6CD245240F819170E848C4E40
9409	6	59	\N	8178	41776	\N	61.099192610414903	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 14 микрорайон, здание №20, МОУ ""СОШ №13"""		0101000020E61000007C0E2C47C8255240FE7E315BB28C4E40
9408	6	59	\N	8178	41776	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 14 микрорайон, дом №1, СК ""Олимп"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9407	6	59	\N	8178	41774	\N	61.079025489800799	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 13 микрорайон, здание №68, МОУ ""СОШ №10"""		0101000020E6100000EBE40CC51D2852408048BF7D1D8A4E40
9406	6	59	\N	8178	41774	\N	61.09778	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 13 микрорайон, здание №51, Начальная школадетский сад №24		0101000020E6100000317898F6CD245240F819170E848C4E40
9405	6	59	\N	8178	41823	\N	61.084133406442497	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 12 микрорайон, здание №60	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E610000012F92EA52E285240D7C1C1DEC48A4E40
9404	6	59	\N	8178	41823	\N	61.081847157371897	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 12 микрорайон, здание №60, МОУ ""СОШ №9"""	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E6100000B37C5D86FF2752404B2366F6798A4E40
9403	6	59	\N	8178	41823	\N	61.09778	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 12 микрорайон, дом №26, Департамент градостроительства		0101000020E6100000317898F6CD245240F819170E848C4E40
9402	6	59	\N	8178	41823	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 12 микрорайон, дом №24, УСО ХМАОЮгры КЦСОН ""Защита"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9401	6	59	\N	8178	41823	\N	61.09778	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 12 микрорайон, дом №24		0101000020E6100000317898F6CD245240F819170E848C4E40
9398	6	59	\N	8178	41772	\N	61.09778	ХантыМансийский автономный округ  Югра, город Нефтеюганск, 11 микрорайон, строение №62, МУК «Центр национальных культур»		0101000020E6100000317898F6CD245240F819170E848C4E40
86248	6	56	932	28661	18592	\N	56.473376000000002	поселок Натальинск, Советская, 4		0101000020E61000007F164B917CEF4C400C5BB395973C4C40
9392	6	59	\N	8178	76510	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 10 микрорайон, здание №14, МЦ ""Юность"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9380	6	59	\N	8178	41845	\N	61.097115201108402	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 1 микрорайон, здание №28, МОУ ""СОШ №1"""	Россия, Ханты-Мансийский автономный округ, город Нефтеюганск	0101000020E61000007FA0DCB6EF245240BC79AA436E8C4E40
9390	6	59	\N	8178	41771	\N	61.09778	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 8А микрорайон, здание №17, МОУ ""СОШ №8"""		0101000020E6100000317898F6CD245240F819170E848C4E40
9258	6	59	\N	61128	77309	\N	60.617684460953498	Мулымья, Волгоградская (Дом культуры), 33	Россия	0101000020E61000009E4319AA622D504098A1F144104F4E40
9243	6	59	\N	55058	41765	\N	59.598370180869097	Междуреченский, Центральная (Междуреченский аграрный колледж), 54	Россия	0101000020E6100000AFB0E07EC07850402A745E6397CC4D40
9242	6	59	\N	55058	41883	\N	59.596629808668702	"Междуреченский, Первомайская (КДЦ ""Рондо""), 25"	Россия	0101000020E610000001FC53AA44785040FFE7305F5ECC4D40
9245	6	59	\N	55058	41824	\N	59.597935160031199	"Междуреченский, Волгоградская (РЦК ""Конда""), 11"	Россия	0101000020E6100000D6A88768747950401F11532289CC4D40
9244	6	59	\N	55058	41824	\N	59.590711577916103	"Междуреченский, Волгоградская (РЦК ""Конда"" детская школа искусств), 11"	Россия	0101000020E6100000382EE3A6067A504069AD68739CCB4D40
9882	6	59	\N	80	77291	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Сутормина, 16/1		0101000020E610000039B874CC7906534013B534B742844E40
9877	6	59	\N	80	77363	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Советская, 19		0101000020E610000039B874CC7906534013B534B742844E40
9892	6	59	\N	80	77288	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Свободы, 30		0101000020E610000039B874CC7906534013B534B742844E40
9891	6	59	\N	80	77288	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Свободы, 6		0101000020E610000039B874CC7906534013B534B742844E40
9889	6	59	\N	80	77288	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Свободы, 6/1		0101000020E610000039B874CC7906534013B534B742844E40
9884	6	59	\N	80	77398	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Проспект Победы, 6		0101000020E610000039B874CC7906534013B534B742844E40
9887	6	59	\N	80	77234	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Нефтяников, 12		0101000020E610000039B874CC7906534013B534B742844E40
9876	6	59	\N	80	77207	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Нефтеразведочная, 2а		0101000020E610000039B874CC7906534013B534B742844E40
9901	6	59	\N	80	77315	\N	61.033286010879998	ХантыМансийский автономный округ  Югра, город Мегион, пг.Высокий, Ленина, 48	Россия, Ханты-Мансийский автономный округ, город Мегион	0101000020E61000004B5AF10D8506534013B534B742844E40
9899	6	59	\N	80	77139	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, пгт.Высокий, Ленина, 20		0101000020E610000039B874CC7906534013B534B742844E40
9896	6	59	\N	80	77298	\N	61.033285999999997	"ХантыМансийский автономный округ  Югра, город Мегион, пгт.Высокий, Ленина, ж/д станция ""Мегион"""		0101000020E610000039B874CC7906534013B534B742844E40
9895	6	59	\N	80	77273	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Кузьмина, 3		0101000020E610000039B874CC7906534013B534B742844E40
9886	6	59	\N	80	77353	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Заречная, 16а		0101000020E610000039B874CC7906534013B534B742844E40
9880	6	59	\N	80	77586	\N	61.033285999999997	ХантыМансийский автономный округ  Югра, город Мегион, Геологов, 5		0101000020E610000039B874CC7906534013B534B742844E40
9905	6	59	\N	80	77534	\N	61.036533755311403	ХантыМансийский автономный округ  Югра, город Мегион, пгт.Высокий, Гагарина, 44	Россия, Ханты-Мансийский автономный округ, город Мегион	0101000020E61000009C14E63DCE06534096986725AD844E40
9257	6	59	\N	61089	77178	\N	59.721246000000001	Луговой, Первомайский (средняя школа), 1	Россия	0101000020E610000040A19E3E02795040772FF7C951DC4D40
9249	6	59	\N	61111	77243	\N	59.622955946100802	Леуши, Волгоградская (администрация поселения), 13	Россия	0101000020E610000069C4CC3E8F7350406A6CAF05BDCF4D40
9908	6	59	\N	61211	77598	\N	61.108818999999997	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Ларьяк, Гагарина, 14	Россия	0101000020E6100000A20914B1881054407A17EFC7ED8D4E40
9844	6	59	\N	61123	77301	\N	61.263058999999998	ХантыМансийский автономный округ  Югра, город Лангепас, Мира, 28, Гимназия № 6		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9842	6	59	\N	61123	77301	\N	61.263472295334203	ХантыМансийский автономный округ  Югра, город Лангепас, Мира, 28, СОШ № 4		0101000020E610000049145AD6FDCA5240B3B45373B9A14E40
9834	6	59	\N	61123	77301	\N	61.249500302720797	ХантыМансийский автономный округ  Югра, город Лангепас, Мира, 21,  СОШ № 3	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, город Лангепас	0101000020E610000057B5A4A31CCC52400E2DB29DEF9F4E40
9845	6	59	\N	61123	77509	\N	61.263058999999998	ХантыМансийский автономный округ  Югра, город Лангепас, Ленина, 52, Колледж		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9829	6	59	\N	61123	77509	\N	61.251981122031097	ХантыМансийский автономный округ  Югра, город Лангепас, Ленина, 23	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, город Лангепас	0101000020E6100000BB641C23D9CB5240501BD5E940A04E40
9847	6	59	\N	61123	77594	\N	61.245199750627002	ХантыМансийский автономный округ  Югра, город Лангепас, Дружбы народов, 7,  СОШ № 5	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, город Лангепас	0101000020E61000006B274A4222CC5240567DAEB6629F4E40
9248	6	59	\N	61099	77225	\N	58.805625696010097	Куминский (культурный центр), Почтовая, 43		0101000020E610000046CF2D74257E50405567B5C01E674D40
9470	6	59	\N	61167	77425	\N	61.630341052416298	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Красноленинский, улица Обская, 19		0101000020E610000007B64AB038F25040FA298E03AFD04E40
9906	6	59	\N	61162	77407	\N	61.100534982233697	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Ларьяк, село Корлики, Дружбы, 14	Россия	0101000020E61000007F4C6BD3D81054403B8DB454DE8C4E40
9238	6	59	\N	55072	41880	\N	59.6478484080559	Кондинское, Советская, 11	Россия	0101000020E6100000B8567BD80BDB5040B763EAAEECD24D40
9761	6	59	\N	61139	77604	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Янтарная, 11 (СОШ №8)	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9791	6	59	\N	61139	77664	\N	62.190553999999999	ХантыМансийский автономный округ  Югра, город Когалым, Широкая, 5а (ДК Сибирь)	Россия	0101000020E6100000E4F6CB272BA252409D0FCF1264184F40
9786	6	59	\N	61139	77669	\N	62.241113450123898	ХантыМансийский автономный округ  Югра, город Когалым, Степана Повха, 13 (СОШ №7)	Россия	0101000020E6100000D9EBDD1FEFA15240FAD170CADC1E4F40
9781	6	59	\N	61139	77659	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Сопочинского, 10 (СЦ Юбилейный)	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9784	6	59	\N	61139	77580	\N	62.241113450123898	ХантыМансийский автономный округ  Югра, город Когалым, Сибирская, 11 (МКЦ Феникс)	Россия	0101000020E6100000D9EBDD1FEFA15240FAD170CADC1E4F40
9770	6	59	\N	61139	77567	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Северная, 1 (СОШ №10)	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9795	6	59	\N	61139	77442	\N	62.224943859149498	ХантыМансийский автономный округ  Югра, город Когалым, Привокзальная, 27 (СОШ №9)	Россия	0101000020E61000004DBF44BC75A2524039B709F7CA1C4F40
9793	6	59	\N	61139	77442	\N	62.235754999999997	ХантыМансийский автономный округ  Югра, город Когалым, Привокзальная, 27 (СОШ№9)	Россия	0101000020E610000070CFF3A78DA152402A6F47382D1E4F40
9774	6	59	\N	61139	77377	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Прибалтийская, 19 (СОШ №5)	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9788	6	59	\N	61139	77605	\N	62.241113450123898	ХантыМансийский автономный округ  Югра, город Когалым, Набережная, 55а (СОШ №1)	Россия	0101000020E6100000D9EBDD1FEFA15240FAD170CADC1E4F40
9775	6	59	\N	61139	77666	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Мира, 17 (Школа искусств)	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9768	6	59	\N	61139	77340	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Дружбы Народов, 10/1	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9767	6	59	\N	61139	77340	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Дружбы Народов, 10/1 (СОШ №3)	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9764	6	59	\N	61139	77340	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Дружбы Народов, 24	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9762	6	59	\N	61139	77340	\N	62.235434450032898	ХантыМансийский автономный округ  Югра, город Когалым, Дружбы Народов, 24 (СОШ №8/2)	Россия	0101000020E6100000804754A86EA25240E82E89B3221E4F40
9779	6	59	\N	61139	77601	\N	62.240132699862897	ХантыМансийский автономный округ  Югра, город Когалым, Бакинская, 29 (СОШ №6)	Россия	0101000020E6100000D9EBDD1FEFA152405ED89AADBC1E4F40
9465	6	59	\N	61115	77264	\N	61.000928999999999	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Кедровый, улица Ленина, 6 В		0101000020E61000005FD04202464451401A4F04711E804E40
9189	6	59	\N	61205	77571	\N	62.2499339840167	ХантыМансийский автономный округ  Югра, Октябрьский район, п. Заречный, Промысловая, 9	Россия	0101000020E610000032C9C859D8B9504049145AD6FD1F4F40
9101	6	59	\N	55068	41863	\N	63.935338709090203	"ХантыМансийский автономный округ  Югра, Березовский район, пгт.Березово, ул.Авиаторов, 25, Здание ЦСП ""Виктория"""	Россия	0101000020E6100000C0EB33677D43504030D63730B9F74F40
9137	6	59	\N	55064	\N	\N	63.705282063819702	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, СУ966, 39		0101000020E61000000B410E4A98AA50408E3A3AAE46DA4F40
9136	6	59	\N	55064	77284	\N	63.707718999999997	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, микрорайон Мирный, 18	Россия	0101000020E6100000A79196CADBAA504000E1438996DA4F40
9131	6	59	\N	55064	77098	\N	63.711360484610502	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, Школьная, 7	Россия	0101000020E6100000BFBB95253AAA50405ED72FD80DDB4F40
9132	6	59	\N	55064	41817	\N	63.709663999999997	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, Центральная, 10	Россия	0101000020E610000064AC36FFAFAA504003931B45D6DA4F40
9129	6	59	\N	55064	41817	\N	63.713938094642003	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, Центральная, 3	Россия	0101000020E6100000899B53C900AB504092AF045262DB4F40
9126	6	59	\N	55064	77057	\N	63.709533348605902	ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, 3 микрорайон, 27а		0101000020E610000092AD2EA704AB5040653733FAD1DA4F40
9499	6	59	7345	55062	76734	\N	61.266252353589799	ХантыМансийский автономный округ  Югра, город Сургут, проспект Ленина, 68/1	Россия, Ханты-Мансийский автономный округ, городской округ Сургут	0101000020E610000083C13577F45752404F3FA88B14A24E40
86247	6	56	932	28661	78502	\N	56.473376000000002	Натальинск, Ленина, 31		0101000020E61000007F164B917CEF4C400C5BB395973C4C40
9397	6	59	7344	55059	41786	\N	61.102308386624401	"ХантыМансийский автономный округ  Югра, город Нефтеюганск, 11 микрорайон, здание №61, МОУ ""СОШ №7"""		0101000020E6100000F4C29D0B23255240410FB56D188D4E40
9434	6	59	1032	10910	77366	\N	60.965364000000001	ХантыМансийский автономный округ  Югра, ХантыМансийский район, деревня Ярки, улица Новая, 4		0101000020E6100000CBF78C44686051402D5E2C0C917B4E40
9444	6	59	1032	61068	77121	\N	61.090140759171	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Шапша, улица Молодежная, 1	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, деревня Шапша	0101000020E6100000EF92382BA25D5140AE8383BD898B4E40
9420	6	59	1032	52116	77279	\N	60.174700024779398	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Цингалы, улица Советская, 28	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Цингалы	0101000020E6100000E7E104A6D36C51403C4ED1915C164E40
9429	6	59	1032	10732	77383	\N	60.741768999999998	ХантыМансийский автономный округ  Югра, ХантыМансийский район, село Тюли, переулок Дружбы, 7		0101000020E6100000717500C45D695140E3175E49F25E4E40
9457	6	59	1032	11957	77336	\N	61.116447000000001	ХантыМансийский автономный округ  Югра, ХантыМансийский район, село Троица, улица Молодежная, 4 а		0101000020E6100000C85C19541B1B5140D15B3CBCE78E4E40
9447	6	59	1032	52178	77470	\N	60.508684445938002	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Согом, улица Молодежная, 2	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Согом	0101000020E61000001349F4328A045140CEFFAB8E1C414E40
9446	6	59	1032	61225	77663	\N	61.297574769953499	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Селиярово, улица Лесная, 8 а	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Селиярово	0101000020E6100000A25EF0694E965140B98D06F016A64E40
9426	6	59	1032	10543	77627	\N	60.654318000000004	ХантыМансийский автономный округ  Югра, ХантыМансийский район, село Реполово, улица Школьная, 4		0101000020E61000006823D74D29755140929735B1C0534E40
9438	6	59	1032	11095	77404	\N	61.400751	ХантыМансийский автономный округ  Югра, ХантыМансийский район, поселок Пырьях, улица Набережная, 7		0101000020E61000004391EEE7144E51406E6B0BCF4BB34E40
9440	6	59	1032	52159	77229	\N	61.290039882098803	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Нялинское, улица Мира, 71	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Нялинское	0101000020E610000015562AA8A86351401344DD0720A54E40
9454	6	59	1032	52184	77369	\N	61.062369736156903	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Луговской, улица Гагарина, 2	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Луговской	0101000020E6100000ED116A865420514032207BBDFB874E40
9436	6	59	1032	52152	77475	\N	61.449034828683097	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Кышик, улица Советская, 1	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Кышик	0101000020E6100000A7E7DD58503C514033E197FA79B94E40
9451	6	59	1032	11367	77218	\N	61.080441999999998	ХантыМансийский автономный округ  Югра, ХантыМансийский район, поселок Кирпичный, улица Комсомольская, 12 а		0101000020E610000027DBC01DA82A5140C79C67EC4B8A4E40
9630	6	59	1032	52206	81093	\N	61.482894080951802	ХантыМансийский автономный округ  Югра, город Сургут, поселок Кедровый2, 13а	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Кедровый	0101000020E610000071546EA2960F5140A2B77878CFBD4E40
9442	6	59	1032	11273	77645	\N	61.203150999999998	ХантыМансийский автономный округ  Югра, ХантыМансийский район, село Зенково, улица Набережная, 8		0101000020E6100000151F9F909D78514029931ADA009A4E40
9462	6	59	1032	12191	77185	\N	61.393782000000002	ХантыМансийский автономный округ  Югра, ХантыМансийский район, село Елизарово, переулок Школьный, 1		0101000020E610000055A52DAEF112514072E0D57267B24E40
9418	6	59	1032	52113	77615	\N	60.061833257524697	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Горноправдинск, улица Поспелова, 5 Б	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Горноправдинск	0101000020E610000037894160E57A51402368CC24EA074E40
9428	6	59	1032	52084	77257	\N	60.643294804909999	ХантыМансийский автономный округ  Югра, ХантыМансийский район, сельское поселение Выкатной, улица Школьная, 4	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Выкатной	0101000020E6100000EE76BD34456351401557957D57524E40
9415	6	59	1032	9980	77237	\N	59.96893	ХантыМансийский автономный округ  Югра, ХантыМансийский район, поселок Бобровский, улица Юбилейная, 14		0101000020E61000002DE8BD31047B5140800EF3E505FC4D40
9693	6	59	1032	61206	77581	\N	61.064990999999999	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Островского, 20/1	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Белый Яр	0101000020E6100000BF9CD9AED0B7514065C405A051884E40
9134	6	59	1032	61206	77575	\N	61.066903301547001	"ХантыМансийский автономный округ  Югра, Белоярский район, городское поселение Белоярский, 1 микрорайон, здание спортивного зала ""Олимп"" муниципального учреждения «Дворец спорта»"		0101000020E6100000E6B0FB8EE1B751408D800A4790884E40
9705	6	59	1032	61210	77724	\N	61.065115720876797	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Симонова, 1а	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Белый Яр	0101000020E61000004E266E15C4B75140223999B855884E40
9706	6	59	1032	61161	77406	\N	61.064782985428501	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Лесная, 17б	Россия, Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Белый Яр	0101000020E6100000ACC612D6C6B751401B2B31CF4A884E40
9450	6	59	1032	11650	77226	\N	61.054595999999997	ХантыМансийский автономный округ  Югра, ХантыМансийский район, деревня Белогорье, улица Мира, 12		0101000020E6100000B5FB5580EF275140073F7100FD864E40
9422	6	59	1032	10305	77629	\N	60.406080000000003	ХантыМансийский автономный округ  Югра, ХантыМансийский район, село Батово, улица Центральная, 50 а		0101000020E61000009AEB34D252755140A4C7EF6DFA334E40
9432	6	59	1032	10817	77232	\N	60.833199	ХантыМансийский автономный округ  Югра, ХантыМансийский район, село Базьяны, улица Центральная, 36		0101000020E61000008CBD175FB4655140AB07CC43A66A4E40
9725	6	59	676	61169	77437	\N	61.382498066274998	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Нижнесортымский, Северная, 34	Россия, Ханты-Мансийский автономный округ, Сургутский район	0101000020E6100000C6866EF6073D52408864C8B1F5B04E40
9718	6	59	676	61134	77444	\N	61.610140999999999	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Федоровский, переулок Тюменский, 14	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский	0101000020E61000009FAA4203B16D52407079AC1919CE4E40
9712	6	59	676	61134	81162	\N	61.608426999999999	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Федоровский, переулок Парковый, 1	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский	0101000020E61000009E42AED4B36D52406F8099EFE0CD4E40
9714	6	59	676	61134	81164	\N	61.608426990668001	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Федоровский, Строителей, 6	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский	0101000020E61000009FAA4203B16D52406F8099EFE0CD4E40
9716	6	59	676	61134	77569	\N	61.609116	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Федоровский, Савуйская, 13	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский	0101000020E61000005FD4EE57016E524034BC5983F7CD4E40
9710	6	59	676	61134	77322	\N	61.607965	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Федоровский, Ленина, 17	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский	0101000020E610000068EC4B361E6E52406B0E10CCD1CD4E40
9754	6	59	676	52646	77621	\N	61.505234999999999	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение УльтЯгун, 35 лет Победы, 1/1	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок Ульт-Ягун	0101000020E61000003D601E32E58D5240B4E55C8AABC04E40
9753	6	59	676	52634	77247	\N	60.505735000000001	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Угут, п.Малоюганский, переулок Угутский, 9		0101000020E6100000E8BF07AF5D835240A6B8AAECBB404E40
9750	6	59	676	52634	77624	\N	60.505735000000001	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Угут, Львовская, 26	Россия, Ханты-Мансийский автономный округ, Сургутский район, село Угут	0101000020E6100000E8BF07AF5D835240A6B8AAECBB404E40
9757	6	59	676	26648	77135	\N	61.679251000000001	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение УльтЯгун, п.ТромАган, Центральная, 2		0101000020E610000010786000E19352403D635FB2F1D64E40
9742	6	59	676	52607	77508	\N	61.300657999999999	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Сытомино, Центральная, 61		0101000020E6100000E7357689EAD25140F0A31AF67BA64E40
9739	6	59	676	52591	\N	\N	61.278840000000002	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Солнечный, Управление по переработке газа	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок Солнечный	0101000020E61000003DBB7CEBC34B524088687407B1A34E40
9730	6	59	676	52591	77337	\N	61.278840000000002	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Солнечный, Спортивная, 1а		0101000020E61000003DBB7CEBC34B524088687407B1A34E40
9734	6	59	676	52591	77436	\N	61.278840000000002	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Солнечный, Космонавтов, 17		0101000020E61000003DBB7CEBC34B524088687407B1A34E40
9733	6	59	676	52591	77600	\N	61.278840000000002	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Солнечный, Зои Космодемьянской, 19		0101000020E61000003DBB7CEBC34B524088687407B1A34E40
9737	6	59	676	52601	77405	\N	61.268948308617603	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Солнечный, д. Сайгатина, Центральная, 24	Россия, Ханты-Мансийский автономный округ, Сургутский район, деревня Сайгатина	0101000020E61000002FA699EE753852408D2958E36CA24E40
9746	6	59	676	61149	77361	\N	62.178664475218802	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Русскинская, Ветеранов, 16	Россия	0101000020E6100000613596B0366552407C7C4276DE164F40
9727	6	59	676	61093	77186	\N	60.375165000000003	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Нижнесортымский, Нефтяников, 7а		0101000020E6100000C07971E2AB5C52404BCD1E6805304E40
9729	6	59	676	61216	77631	\N	62.435600000000001	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Нижнесортымский, Хусаинова, 1		0101000020E61000001B4641F0F8F051409D11A5BDC1374F40
9686	6	59	676	56689	78436	\N	61.621110000000002	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон 7, Лянторская СОШ №4	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E610000030293E3E210B5240FA9B508880CF4E40
9688	6	59	676	56689	81163	\N	61.620865000000002	"ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №6, ГДМ ""Строитель, холл 1 этажа"		0101000020E61000008236397CD20A5240931D1B8178CF4E40
9672	6	59	676	56689	77152	\N	61.618495000000003	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №6а, Лянторская СОШ №6, холл 1 этажа	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E61000000C923EADA20A5240A9DE1AD82ACF4E40
9665	6	59	676	56689	78291	\N	61.622622	"ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №4, ДК ""Юбилейный"", холл 1 этажа"	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E6100000BF2B82FFAD09524093E2E313B2CF4E40
9666	6	59	676	56689	77370	\N	61.622622	"ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №4, ДК ""Юбилейный"", холл 2 этажа"	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E6100000BF2B82FFAD09524093E2E313B2CF4E40
9669	6	59	676	56689	78422	\N	61.622335999999997	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №3, Лянторская СОШ №3	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E61000000B2AAA7EA50A5240CD8FBFB4A8CF4E40
9678	6	59	676	56689	77164	\N	61.624704999999999	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №2, администрация г.Лянтор	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E6100000EA245B5D4E095240E7525C55F6CF4E40
9670	6	59	676	56689	77164	\N	61.622580999999997	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №2, Лянторская СОШ №7, холл 1 этажа	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E6100000116DC7D45D095240340EF5BBB0CF4E40
9675	6	59	676	56689	77199	\N	61.621028000000003	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №10, Лянторский нефтяной техникум	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E61000006B9A779CA20B52403DF372D87DCF4E40
9681	6	59	676	56689	78387	\N	61.629199	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон 1, Детскоюношеская спортивная школа	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E6100000844BC79C670A524084D6C39789D04E40
9676	6	59	676	56689	78387	\N	61.627074999999998	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, микрорайон №1, Лянторская СОШ №1, актовый зал	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E6100000F834272F320A5240D1915CFE43D04E40
9662	6	59	676	56689	77413	\N	61.625603201261598	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Лянтор, Набережная, 13	Россия, Ханты-Мансийский автономный округ, Сургутский район, город Лянтор	0101000020E61000007380608E1E095240C6A354C213D04E40
9749	6	59	676	52625	77446	\N	61.136597000000002	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Локосово, Центральная, 44		0101000020E61000008CBAD6DEA7B45240A9DDAF027C914E40
9745	6	59	676	5258	77427	\N	61.272463000000002	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Лямина, Центральная, 13	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок Лемпино	0101000020E6100000B056ED9A90EF51405E2F4D11E0A24E40
9318	6	59	676	5258	77538	\N	61.271940999999998	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, с. Лемпино, Солнечная, дом 1, ДК ""Праздник"""		0101000020E61000001A6D5512D9EF514084B872F6CEA24E40
9759	6	59	676	61131	77314	\N	61.226664	ХантыМансийский автономный округ  Югра, Сургутский район, сельское поселение Тундрино, п.Высокий Мыс, Советская, 30а	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок Высокий Мыс	0101000020E610000014799274CD0852401C977153039D4E40
9826	6	59	306	29500	77202	\N	61.263058999999998	ХантыМансийский автономный округ  Югра, город Лангепас, Парковая, 13 Б  СОШ № 2		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9696	6	59	676	40335	77471	\N	61.265804000000003	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, микрорайон №1, Центр дополнительного образования	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр	0101000020E610000029AF95D05D515240B0928FDD05A24E40
9708	6	59	676	40335	77566	\N	61.257742131715602	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Маяковского, 11а	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр	0101000020E6100000EDF1423A3C5052401F679AB0FDA04E40
9703	6	59	676	40335	77326	\N	61.263033	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Лесная, 9/1	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр	0101000020E61000006728EE78934F52406762BA10ABA14E40
9691	6	59	676	40335	77527	\N	61.2580721053357	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Ермака, 4б	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр	0101000020E61000007A1D71C806505240B401D88008A14E40
9694	6	59	676	55063	77553	\N	61.266258487994499	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Островского, 20		0101000020E610000064CDC820775152403126FDBD14A24E40
9700	6	59	676	55063	77401	\N	61.259726038666301	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Белый Яр, Лесная, 8б	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр	0101000020E610000006499F56D14F5240E0F599B33EA14E40
9723	6	59	676	61194	77519	\N	61.252979000000003	ХантыМансийский автономный округ  Югра, Сургутский район, городское поселение Барсово, Мостостроителей, 9	Россия, Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Барсово	0101000020E610000082E15CC30C4C524093C9A99D61A04E40
9303	6	59	7342	61076	77145	\N	61.216242573468001	"ХантыМансийский автономный округ  Югра, Советский район, сельское поселение Алябьевский, Ленина, 3 ""а"""	Россия	0101000020E6100000A3E5400FB5614F40957EC2D9AD9B4E40
9304	6	59	7342	62101	81142	\N	61.169848999999999	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Таежный, Железнодорожная, 15	Россия	0101000020E6100000DA0418963F574F401021AE9CBD954E40
9296	6	59	7342	61070	77127	\N	61.369634148810597	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Юности, 12		0101000020E6100000B83B6BB75DC84F40ADBEBA2A50AF4E40
9302	6	59	7342	62100	81141	\N	61.207631999999997	"ХантыМансийский автономный округ  Югра, Советский район, городское поселение Малиновский, Советская, 8 ""а"""	Россия	0101000020E6100000B2632310AF674F4031CD74AF939A4E40
9301	6	59	7342	62100	81140	\N	61.207259357508001	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Малиновский, Кузнецова, 18	Россия	0101000020E6100000616BB6F292674F409D668176879A4E40
9285	6	59	7342	62117	81180	\N	61.689264999999999	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Коммунистический, Матросова, 9	Россия	0101000020E6100000D20149D8B71E504083A3E4D539D84E40
9284	6	59	7342	61074	81179	\N	61.927396999999999	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Агириш, Дзержинского, 16	Россия	0101000020E6100000ECA17DACE0814F404AB4E4F1B4F64E40
9297	6	59	7342	61088	77173	\N	61.372810847768903	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Мира, 28		0101000020E61000007D224F92AEC94F40664B5645B8AF4E40
9290	6	59	7342	61100	77208	\N	61.375235000000004	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Ленина, 14	Россия	0101000020E61000000C04013274C84F4044A852B307B04E40
9289	6	59	7342	61100	77208	\N	61.373587979192202	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Советский, Ленина, 45	Россия	0101000020E61000003048FAB48AC84F40CA1649BBD1AF4E40
9299	6	59	7342	61085	77180	\N	61.192391000000001	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Пионерский, Ленина, 27	Россия	0101000020E61000008D093197546F4F40BA85AE44A0984E40
9300	6	59	\N	\N	77201	\N	61.204318999999998	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Пионерский, Комсомольская, 8	Россия	0101000020E610000055682096CD6E4F40C879FF1F279A4E40
9288	6	59	7342	55025	41430	\N	61.475580586100399	ХантыМансийский автономный округ  Югра, Советский район, городское поселение Зеленоборск, Политехническая, 18	Россия	0101000020E6100000874D64E602025040ABCC94D6DFBC4E40
9153	6	59	5247	61257	77808	\N	62.459239418876301	ХантыМансийский автономный округ  Югра, Октябрьский район, п. Кормужиханка, Гагарина, 6	Россия	0101000020E61000004D6551D8459050401C06F357C83A4F40
9192	6	59	5247	61186	77499	\N	62.266450682809499	ХантыМансийский автономный округ  Югра, Октябрьский район, п. Комсомольский, Октябрьская, 7 помещение сельского дома культуры	Россия	0101000020E6100000027E8D2441C15040467EFD101B224F40
9184	6	59	5247	61249	77767	\N	61.788986298549098	ХантыМансийский автономный округ  Югра, Октябрьский район, п. Горнореченск, Речная, 34	Россия	0101000020E61000008A39083A5AE550403D80457EFDE44E40
9165	6	59	5247	61245	77765	\N	62.760998000000001	ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Шеркалы, Мира, 34А, Сельский Дом Культуры Триумф		0101000020E6100000FCC74274085E50402429E96168614F40
9200	6	59	5247	61267	77915	\N	61.953763385665901	"ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Унъюган, 30 лет Победы, 14, МКУ ""Дом культуры "" ""Лесник"""		0101000020E61000004D6551D8453C50404391EEE714FA4E40
9159	6	59	5247	61065	77116	\N	62.538176531506103	"ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Приобье, ул. Газовиков, 25, помещение КСК ""ХАРД"""		0101000020E61000004DD6A88768675040CD3AE3FBE2444F40
9171	6	59	5247	61251	77785	\N	62.9628942945943	"ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Перегребное, Советская, 9, помещение КСК ""Феерия"""		0101000020E61000005D876A4AB2455040DFC14F1C407B4F40
9177	6	59	5247	61163	77409	\N	63.187691999999998	"ХантыМансийский автономный округ  Югра, Октябрьский район, д. НижниеНарыкары, пер. Клубный, 2 А, Дом культуры ""Родник"""	Россия	0101000020E6100000AB798EC8773C504044DC9C4A06984F40
9186	6	59	5247	61237	77706	\N	62.224193586521103	ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Малый Алтым, пер. Зеленый, 2	Россия	0101000020E6100000C4245CC823BD5040CEFA9463B21C4F40
9181	6	59	5247	61230	77681	\N	62.024669253035903	ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Карымкары, Ленина, 18, здание администрации поселения	Россия	0101000020E61000005439ED2939D65040CE1C925A28034F40
9196	6	59	5247	61252	77788	\N	61.5693396747047	ХантыМансийский автономный округ  Югра, Октябрьский район, сельское поселение Каменное, Центральная, 6, помещение сельского клуба	Россия	0101000020E61000008B54185B08E45040FE261422E0C84E40
9187	6	59	5247	61244	77735	\N	62.274897647253297	ХантыМансийский автономный округ  Югра, Октябрьский район, с. Большой Атлым, Школьная, 32	Россия	0101000020E610000029931ADA00A850402FDE8FDB2F234F40
9194	6	59	5247	61273	78049	\N	62.177003999999997	ХантыМансийский автономный округ  Югра, Октябрьский район, п. Большие Леуши, Центральная, 28	Россия	0101000020E6100000B83B6BB75DCC50406EA12B11A8164F40
9157	6	59	5247	61204	\N	\N	62.479581160985397	"ХантыМансийский автономный округ  Югра, Октябрьский район, городское поселение Андра, дом 18, КСК ""Прометей"""	Россия	0101000020E61000009ACFB9DBF5765040396403E9623D4F40
9922	6	59	306	52024	77263	\N	61.003332	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Покур, Центральная, 76		0101000020E610000056478E7406DF5240E083D72E6D804E40
9810	6	59	306	26519	77266	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Таежная,д.19, КСК ""Нефтяник"""		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9796	6	59	306	26519	77191	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Молодежная, д.16, Ледовый Дворец ""Кристалл"""		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9812	6	59	306	26519	77230	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Мира, д.7/1, ФОК ""Сибиряк"""		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9805	6	59	306	26519	77230	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Мира,9, МОУ ""СОШ №2"""		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9802	6	59	306	26519	77230	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Мира, д.9, МОУ ""СОШ №2"""		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9818	6	59	306	26519	77269	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Ленина, д.10, ""СОШ №4"" (правая часть здания)"		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9815	6	59	306	26519	77269	\N	61.713330999999997	"ХантыМансийский автономный округ  Югра, город Покачи, Ленина, д.10, ""СОШ №4"", левая часть здания"		0101000020E6100000D047197101D752408A1C226E4EDB4E40
9942	6	59	306	61117	77421	\N	61.940593999999997	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Новоаганск, Центральная, 15б	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск	0101000020E610000042B28009DC2953402B685A6265F84E40
9944	6	59	306	61117	77271	\N	61.947799000000003	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Новоаганск, МеликКарамова, 16	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск	0101000020E6100000C80C54C6BF2A53403C17467A51F94E40
9940	6	59	306	61117	77271	\N	61.947065000000002	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Новоаганск, МеликКарамова, 5а	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск	0101000020E6100000535E2BA1BB2A5340D717096D39F94E40
9945	6	59	306	61117	81177	\N	61.944337499341998	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Новоаганск, 70 лет Октября, 6а	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск	0101000020E610000083328D26172B53408DB3E908E0F84E40
9653	6	59	306	61203	\N	\N	60.920366484974998	ХантыМансийский автономный округ  Югра, город Сургут, поселок Мостоотряд94, общежитие Мостострой 11	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок Мостоотряд № 95	0101000020E61000005DFA97A432375340D82C978DCE754E40
9830	6	59	306	29500	77211	\N	61.263058999999998	"ХантыМансийский автономный округ  Югра, город Лангепас, Солнечная, 17 А   ""Фортуна"""		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
5411	6	57	\N	922	42174	\N	57.096787999999997	625053, Тюменская область, г. Тюмень, ул. Станционная, 26		0101000020E6100000B66801DA566950409752978C638C4C40
9824	6	59	306	29500	77202	\N	61.263058999999998	ХантыМансийский автономный округ  Югра, город Лангепас, Парковая, 13Б  СОШ № 2		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9822	6	59	306	29500	77202	\N	61.263058999999998	ХантыМансийский автономный округ  Югра, город Лангепас, Парковая, 3  СОШ № 1		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9840	6	59	306	29500	77219	\N	61.263058999999998	ХантыМансийский автономный округ  Югра, город Лангепас, Мира, 28,  СОШ № 4		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9850	6	59	306	29500	77498	\N	61.263058999999998	ХантыМансийский автономный округ  Югра, город Лангепас, Ленина, 45, Музейновыставочный центр		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9837	6	59	306	29500	77303	\N	61.263058999999998	"ХантыМансийский автономный округ  Югра, город Лангепас, Комсомольская, 3 Д,  ""Патриот"""		0101000020E61000000F5EBBB4E1CA524090F5D4EAABA14E40
9933	6	59	306	61108	77558	\N	60.949281999999997	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Излучинск, переулок Молодёжный, 3	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск	0101000020E610000037548CF3373853403A57941282794E40
9925	6	59	306	61108	77329	\N	60.948915999999997	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Излучинск, Энергетиков, 2	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск	0101000020E6100000F6D1A92B9F3853405853591476794E40
9930	6	59	306	61108	77238	\N	60.952191460761703	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Излучинск, Школьная, 7	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск	0101000020E61000007E18213CDA385340D4450A65E1794E40
9927	6	59	306	61108	77238	\N	60.949207000000001	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Излучинск, Школьная, 5	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск	0101000020E6100000919BE1067C38534030116F9D7F794E40
9937	6	59	306	61108	77612	\N	60.949373999999999	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Излучинск, село Большетархово, Лесная, 13	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск	0101000020E610000059198D7C5E3853401BD6541685794E40
9936	6	59	306	61113	77587	\N	60.953620384430998	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Излучинск, Савкинская, 29	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск	0101000020E61000004C4F58E201395340E0675C38107A4E40
9920	6	59	306	2120	77550	\N	60.644973	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Зайцева Речка, Центральная, 3		0101000020E610000068EC4B361E2A5340C9E6AA798E524E40
9913	6	59	306	61141	77349	\N	60.837356	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Ваховск, Таежная, 4		0101000020E61000003677F4BF5CF15240008E3D7B2E6B4E40
9912	6	59	306	61141	77347	\N	60.837356	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Ваховск, село Охтеурье, Летная, 20		0101000020E61000003677F4BF5CF15240008E3D7B2E6B4E40
9918	6	59	306	52013	77539	\N	61.086502000000003	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Вата, Центральная, 15	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, село Вата	0101000020E6100000CEFE40B96DF35240F1845E7F128B4E40
9948	6	59	306	3697	77196	\N	61.997334000000002	ХантыМансийский автономный округ  Югра, Нижневартовский район, городское поселение Новоаганск, село Варьёган, Центральная, 21		0101000020E61000003E5C72DC292F53402D98F8A3A8FF4E40
9924	6	59	306	2369	77551	\N	60.858460000000001	ХантыМансийский автономный округ  Югра, Нижневартовский район, деревня Вампугол, Зырянова, 13		0101000020E61000007782FDD7B92653404B766C04E26D4E40
9915	6	59	306	52010	77431	\N	61.638359000000001	ХантыМансийский автономный округ  Югра, Нижневартовский район, сельское поселение Аган, Новая, 16	Россия, Ханты-Мансийский автономный округ, Нижневартовский район, село Аган	0101000020E610000046EF54C03DC55240BB0D6ABFB5D14E40
9341	6	59	768	61202	\N	\N	60.616297933433898	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. КС5, дом 8, Спорткомплекс	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район	0101000020E6100000207F69519F2952408C4B55DAE24E4E40
9337	6	59	768	6207	77511	\N	61.061439999999997	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. Юганская Обь, ул. Тобольская, 25, ДК ""Гармония"""		0101000020E61000007880272D5C48524047551344DD874E40
9343	6	59	768	6582	9683	\N	61.119179866900602	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. Чеускино, ул. Центральная, дом 8, Здание администрации	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Чеускино	0101000020E610000030134548DD1B52402C2B4D4A418F4E40
9334	6	59	768	6019	\N	\N	60.931314999999998	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. УстьЮган, дом 5, Здание администрации		0101000020E61000007F87A2409F4652401AA3755435774E40
5488	6	57	\N	922	42166	\N	57.122551999999999	625062, Тюменская область, г. Тюмень, ул. Ставропольская, 1в		0101000020E61000004B051555BF6150409A07B0C8AF8F4C40
9332	6	59	768	6019	77506	\N	60.931314999999998	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п.  УстьЮган, квартал 21, дом 40, Средняя школа		0101000020E61000007F87A2409F4652401AA3755435774E40
9346	6	59	768	6680	77205	\N	61.153666000000001	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. Сингапай, ул. Центральная, дом 31, ДК ""Камертон"""		0101000020E61000009CC1DF2F662A5240EA40D653AB934E40
9356	6	59	768	7184	77625	\N	60.162176000000002	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. СивысЯх, ул. Новая, дом 2а, Начальная школа	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Сивыс-Ях	0101000020E6100000501BD5E940ED51401A19E42EC2144E40
9338	6	59	768	6353	\N	\N	60.493236000000003	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. Сентябрьский, Строение 65, Средняя школа		0101000020E61000005C035B25580D5240DD9A745B223F4E40
9350	6	59	768	6976	76431	\N	60.070267000000001	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. Салым, ул. Привокзальная, 16, Средняя школа N 2		0101000020E61000004AD1CABDC0DD5140787E5182FE084E40
9354	6	59	768	6976	76436	\N	60.070267000000001	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. Салым, ул. Новая, дом 13, Средняя школа N 1		0101000020E61000004AD1CABDC0DD5140787E5182FE084E40
9367	6	59	768	7528	76443	\N	60.725757999999999	ХантыМансийский автономный округ  Югра, город ПытьЯх, 2А микрорайон,  улица Советская, дом 34, МОУ СОШ № 3		0101000020E6100000F03499F1B6335240BA675DA3E55C4E40
9374	6	59	768	7528	76261	\N	60.725757999999999	"ХантыМансийский автономный округ  Югра, город ПытьЯх, 9 микрорайон ""Черемушки"" улица Обская, дом 19, Дворовый клуб ""Черемушки"""		0101000020E6100000F03499F1B6335240BA675DA3E55C4E40
9373	6	59	768	7528	41850	\N	60.725757999999999	"ХантыМансийский автономный округ  Югра, город ПытьЯх, улица Магистральная, дом 22, ООО УТТ ""Ространссервис"""		0101000020E6100000F03499F1B6335240BA675DA3E55C4E40
9370	6	59	768	7528	77101	\N	60.725757999999999	"ХантыМансийский автономный округ  Югра, город ПытьЯх, 7 микрорайон, Д/сад ""Аистенок"" ОАО ""ЮБ ГПК"""		0101000020E6100000F03499F1B6335240BA675DA3E55C4E40
9368	6	59	768	7528	41768	\N	60.743599831009902	ХантыМансийский автономный округ  Югра, город ПытьЯх, 5 микрорайон, дом 5А, МОУ СОШ № 5 (2 этаж)	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, город Пыть-Ях	0101000020E610000057CC086F0F3452401EA7E8482E5F4E40
9375	6	59	768	7528	41814	\N	60.733581723278	"ХантыМансийский автономный округ  Югра, город ПытьЯх, 10 микрорайон ""Мамонтово"", дом 50, МОУ ДОД ДЮСШ ""АйкидоРеал"""		0101000020E6100000960854FF203452409677D503E65D4E40
9320	6	59	768	5402	41759	\N	60.998434000000003	ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, Микрорайон 1, дом 37, Средняя школа N 2		0101000020E6100000C826F911BFF95140749B70AFCC7F4E40
9328	6	59	768	5402	76504	\N	60.998434000000003	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, ул. Байкальская, строение 15, ДК ""Байкал"""		0101000020E6100000C826F911BFF95140749B70AFCC7F4E40
9329	6	59	768	55057	77110	\N	60.998434000000003	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, ул. Шестая, дом 6, спортзал ""Сибиряк"" СОК ""Ермак"""		0101000020E6100000C826F911BFF95140749B70AFCC7F4E40
9330	6	59	768	55057	41808	\N	60.995182853010903	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, ул. Пятая, дом 5, ЛД ""Нефтяник"""	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, поселок городского типа Пойковский	0101000020E61000003E78EDD286F9514080441328627F4E40
9327	6	59	768	55057	41764	\N	60.998394378061597	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, Промзона, строение 13а, ООО ""Энергонефть"""		0101000020E6100000041C42959AF95140E542E55FCB7F4E40
9323	6	59	768	55057	41806	\N	60.998434000000003	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, Микрорайон 7, дом 93а, СОК ""Нептун"""		0101000020E6100000C826F911BFF95140749B70AFCC7F4E40
9321	6	59	768	55057	41895	\N	60.998434000000003	ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, Микрорайон 5, дом 1, Средняя школа N 4		0101000020E6100000C826F911BFF95140749B70AFCC7F4E40
9322	6	59	768	55057	41841	\N	60.998434000000003	ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, Микрорайон 4, дом 14, Средняя школа N 1		0101000020E6100000C826F911BFF95140749B70AFCC7F4E40
9325	6	59	768	55057	41807	\N	60.998434000000003	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, Микрорайон 1, дом 112, ЦКиД ""Родники"""		0101000020E6100000C826F911BFF95140749B70AFCC7F4E40
9326	6	59	768	55057	41769	\N	60.996850161102699	ХантыМансийский автономный округ  Югра, Нефтеюганский район, пгт Пойковский, Микрорайон 3, дом 13/14, Библиотека	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, поселок городского типа Пойковский	0101000020E61000002CD670917BF951404182E2C7987F4E40
9358	6	59	768	7386	\N	\N	60.329032303147102	ХантыМансийский автономный округ  Югра, Нефтеюганский район, ст. КутьЯх, дом 7в, Средняя школа	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Куть-Ях	0101000020E61000007C478D093102524032AB77B81D2A4E40
9360	6	59	768	7386	77429	\N	60.325484000000003	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. КутьЯх, ул. Молодежная, дом 17, СК ""Лидер"""		0101000020E6100000F9BCE2A94702524086AFAF75A9294E40
5549	6	57	\N	922	42168	\N	57.187201999999999	625031, Тюменская область, г. Тюмень, ул. Ватутина, 55		0101000020E6100000EB7420EBA965504076DF313CF6974C40
9347	6	59	768	61224	77649	\N	60.969127581205001	"ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. Каркатеевы, ул. Центральная, 17, КСК ""Ника"""	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Каркатеевский	0101000020E6100000304AD05FE81C5240A6D1E4620C7C4E40
9353	6	59	768	61208	\N	\N	59.946623383083299	ХантыМансийский автономный округ  Югра, Нефтеюганский район, п. КС6, Самсоновское ЛПУ, Клуб	Россия, Ханты-Мансийский автономный округ, Нефтеюганский район	0101000020E6100000E97DE36BCFD351401A5245F12AF94D40
9262	6	59	138	61135	77324	\N	60.228414743843103	Ушья, Мелитопольская (Дом культуры), 5А	Россия	0101000020E61000001FDAC70A7E1F50403A75E5B33C1D4E40
9247	6	59	138	62114	81172	\N	59.329097356212998	Мортка, Борисова (средняя школа), 5		0101000020E610000068B114C957815040191BBAD91FAA4D40
9246	6	59	138	62112	81170	\N	59.608344026891899	"Междуреченский, Строителей (ЦМИ ""Ориентир""), 17"		0101000020E6100000F04E3E3DB6795040E25B5837DECD4D40
9256	6	59	138	60957	76831	\N	59.933242994943001	Половинка, Комсомольская (Дом культуры), 9А	Россия, Ханты-Мансийский автономный округ, Кондинский район	0101000020E6100000EA4141295A335140471CB28174F74D40
9250	6	59	138	61116	77268	\N	59.6345512813471	Лиственичный, Центральная (Дом культуры), 1	Россия	0101000020E61000006EDE3829CC705040725298F738D14D40
9231	6	59	138	322	77415	\N	60.414028999999999	Кама, Ленина, 18 (Дом культуры)		0101000020E61000001DC87A6AF54251403C4CFBE6FE344E40
9255	6	59	138	61118	77280	\N	59.843216601963299	Дальний, Центральная (Дом культуры), 17	Россия	0101000020E6100000DAC9E028792D50403337DF88EEEB4D40
9111	6	59	138	590	77525	\N	59.814490999999997	Болчары, Ленина, 49 (Сельский центр культуры)		0101000020E6100000492BBEA1F033514073F1B73D41E84D40
9233	6	59	138	45965	77641	\N	60.330046000000003	Алтай, Ленина (Дом культуры), 23А		0101000020E6100000C0081A33893D51407B1684F23E2A4E40
9259	6	59	7529	61119	77282	\N	60.298561186875197	Назарово, Центральная (Дом культуры), 11	Россия	0101000020E610000078EE3D5C72115040376E313F37264E40
9098	6	59	7346	61133	77320	\N	64.306763741004104	ХантыМансийский автономный округ  Югра, Березовский район, с.Теги, ул.Таежная, 8, Здания средней школы	Россия	0101000020E610000092B06F2711595040C5E57805A2135040
9112	6	59	7346	61214	77619	\N	62.877573040745503	ХантыМансийский автономный округ  Югра, Березовский район, п.Хулимсунт, мкр.3, 23, Здание администрации поселения	Россия	0101000020E61000004EB7EC10FFDA4E40226DE34F54704F40
9118	6	59	7346	61265	77895	\N	63.204422999999998	ХантыМансийский автономный округ  Югра, Березовский район, п.Приполярный, мкр.4, 4А. Здание КСК	Россия	0101000020E61000009DB81CAF40E04D406DC669882A9A4F40
9124	6	59	7346	61235	77699	\N	63.669763871765298	ХантыМансийский автономный округ  Югра, Березовский район, п.Сосьва, ул.Школьная, 3, Здание средней школы	Россия	0101000020E6100000F6B3588AE40F4F40E204A6D3BAD54F40
9095	6	59	7346	62116	81174	\N	60.581220419204001	ХантыМансийский автономный округ  Югра, Березовский район, пгт.Березово, ул.Газопромысловая, 12, Здание администрации поселения		0101000020E6100000C0249529E6735140FCE3BD6A654A4E40
9114	6	59	7346	61147	77360	\N	62.424912994366899	ХантыМансийский автономный округ  Югра, Березовский район, п.Няксимволь, ул.Советская, 10. Здание Дома культуры	Россия	0101000020E6100000232E008DD26D4E409752978C63364F40
9103	6	59	7346	55071	81166	\N	63.187042572218999	ХантыМансийский автономный округ  Югра, Березовский район, п.Игрим, ул.Королева, 3, Здание Дома культуры	Россия	0101000020E6100000F25B74B2D41950400EF96706F1974F40
9106	6	59	7346	55071	41877	\N	63.190284493552802	ХантыМансийский автономный округ  Югра, Березовский район, п.Игрим, ул.Кооперативная 31, Здание средней школы №1		0101000020E61000000A9DD7D8251A5040DD79E2395B984F40
9102	6	59	7346	55071	41877	\N	63.188288774224397	ХантыМансийский автономный округ  Югра, Березовский район, п.Игрим, ул.Кооперативная, 15, Здание средней школы №2		0101000020E61000005D6C5A29041B504028999CDA19984F40
9109	6	59	7346	61168	77434	\N	63.534955700458703	ХантыМансийский автономный округ  Югра, Березовский район, п.Ванзетур, ул.Центральная, 28. Здание Дома культуры	Россия	0101000020E61000007ADE8D058534504045662E7079C44F40
9097	6	59	7346	61220	81165	\N	63.934140852468701	ХантыМансийский автономный округ  Югра, Березовский район, городское поселение Березово, ул.Собянина, 50, Здание средней школы	Россия	0101000020E6100000B9C667B27F425040266DAAEE91F74F40
9100	6	59	7550	\N	77636	\N	63.932298000000003	ХантыМансийский автономный округ  Югра, Березовский район, пгт.Березово, ул.Астраханцева, 102, Здание столовой аэропорта	Россия	0101000020E61000008B51D7DAFB4350402810768A55F74F40
9150	6	59	7524	61152	77375	\N	63.700408000000003	ХантыМансийский автономный округ  Югра, Белоярский район, сельское поселение Казым, Каксина, 10	Россия	0101000020E61000008DEF8B4B55CF5040ABED26F8A6D94F40
9147	6	59	7524	61241	77718	\N	63.791042633269498	ХантыМансийский автономный округ  Югра, Белоярский район, сельское поселение Полноват, Советская, 24		0101000020E6100000CC608C48147A5040685DA3E540E54F40
9140	6	59	7524	61236	77705	\N	63.213893893089597	ХантыМансийский автономный округ  Югра, Белоярский район, сельское поселение Лыхма, ЛПУ, 92/2		0101000020E610000000E31934F4C25040C367EBE0609B4F40
9142	6	59	7524	61222	77646	\N	63.819571534661002	ХантыМансийский автономный округ  Югра, Белоярский район, сельское поселение Верхнеказымский, 3 микрорайон, 15	Россия	0101000020E61000007F6B274A42F15040D15B3CBCE7E84F40
5726	6	57	\N	55075	42080	\N	56.652268999999997	627016, Тюменская область, г. Ялуторовск, ул. Свободы, 195		0101000020E61000000074982F2F935040E998F38C7D534C40
5725	6	57	\N	55075	42080	\N	56.652268999999997	627016, Тюменская область, г. Ялуторовск, ул. Свободы, 193		0101000020E61000000074982F2F935040E998F38C7D534C40
5487	6	57	\N	922	42166	\N	57.122580999999997	625062, Тюменская область, г. Тюмень, ул. Ставропольская, 11а корп. 1		0101000020E6100000D74D29AF95615040340EF5BBB08F4C40
5728	6	57	\N	55075	41966	\N	56.6581311571302	627016, Тюменская область, г. Ялуторовск, ул. Революции, 186	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E6100000B3B3E89D0A935040ECBDF8A23D544C40
5720	6	57	\N	55075	41966	\N	56.655956606788003	627010, Тюменская область, г. Ялуторовск, ул. Революции, 96	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E61000006153E751F1925040884A2366F6534C40
5677	6	57	\N	55075	41966	\N	56.643019251853602	627010, Тюменская область, г. Ялуторовск, ул. Революции, 44	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E6100000DF8783842893504073DA53724E524C40
5719	6	57	\N	55075	41926	\N	56.655578688263297	627014, Тюменская область, г. Ялуторовск, ул. О. Кошевого, 2	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E6100000F609A01859925040E2783E03EA534C40
5716	6	57	\N	55075	41993	\N	56.655531136554799	627010, Тюменская область, г. Ялуторовск, ул. Новикова, 19	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E6100000B1170AD80E935040D1419770E8534C40
5724	6	57	\N	55075	42081	\N	56.656712986409403	627010, Тюменская область, г. Ялуторовск, ул. Ленина, 48	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E61000009E4143FF04935040D5EDEC2B0F544C40
5717	6	57	\N	55075	42087	\N	56.657091170506099	627014, Тюменская область, г. Ялуторовск, ул. Красноармейская, 40	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E610000076C58CF0F69250407BBFD18E1B544C40
5713	6	57	\N	55075	41999	\N	56.656051155074003	627013, Тюменская область, г. Ялуторовск, ул. Комсомольская, 63 (здание общежития)	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E610000089CF9D60FF92504009C1AA7AF9534C40
5711	6	57	\N	55075	41999	\N	56.664181693959499	627013, Тюменская область, г. Ялуторовск, ул. Комсомольская, 13	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E6100000226FB9FAB1935040C24B70EA03554C40
5721	6	57	\N	55075	41997	\N	56.648888725374498	627014, Тюменская область, г. Ялуторовск, ул. Кармелюка, 11		0101000020E6100000D7A4DB12B9925040F8DD74CB0E534C40
5715	6	57	\N	55075	42095	\N	56.657374806078799	627017, Тюменская область, г. Ялуторовск, ул. Железнодорожная, 8	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E61000008C9FC6BDF9925040A01A2FDD24544C40
5730	6	57	\N	55075	42014	\N	56.628090225235901	627018, Тюменская область, г. Ялуторовск, ул. Ворошилова, 61	Россия, Тюменская область, Ялуторовский район	0101000020E61000000A48FB1F60925040EA78CC4065504C40
5718	6	57	\N	55075	42089	\N	56.652268999999997	627010, Тюменская область, г. Ялуторовск, ул. Вокзальная, 15		0101000020E61000000074982F2F935040E998F38C7D534C40
5729	6	57	\N	55075	41994	\N	56.657705711538703	627016, Тюменская область, г. Ялуторовск, ул. Бахтиярова, 60	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E6100000B3B3E89D0A9350400531D0B52F544C40
5727	6	57	\N	55075	41994	\N	56.655956606788003	627016, Тюменская область, г. Ялуторовск, ул. Бахтиярова, 53	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E61000009E4143FF04935040884A2366F6534C40
5722	6	57	\N	55075	41910	\N	56.652268999999997	627016, Тюменская область, г. Ялуторовск, ул. 50 лет Октября, 4 (здание общежития)		0101000020E61000000074982F2F935040E998F38C7D534C40
5424	6	57	\N	922	2175	\N	57.109845999999997	625046, Тюменская область, г. Тюмень, ул. Широтная, 115	Россия, Тюменская область, Тюмень, улица Широтная, 115	0101000020E61000007995B54DF165504057CC086F0F8E4C40
5584	6	57	\N	922	3380	\N	57.146540000000002	625048, Тюменская область, г. Тюмень, ул. Холодильная, 78	Россия, Тюменская область, Тюмень, улица Холодильная, 78	0101000020E6100000E40F069E7B64504026C79DD2C1924C40
5544	6	57	\N	922	15519	\N	57.189762999999999	625048, Тюменская область, г. Тюмень, ул. Строителей, 25 А	Россия, Тюменская область, Тюмень, поселок Матмасы, улица Строителей, 25	0101000020E61000003F027FF8F9685040D47E6B274A984C40
5430	6	57	\N	922	2339	\N	57.120099000000003	625016, Тюменская область, г. Тюмень, ул. Пермякова, 46	Россия, Тюменская область, Тюмень, улица Пермякова, 46	0101000020E61000002310AFEB1765504023A46E675F8F4C40
5583	6	57	\N	922	4441	\N	57.148511999999997	625048, Тюменская область, г. Тюмень, ул. Мельничная, 1	Россия, Тюменская область, Тюмень, улица Мельничная, 1	0101000020E61000007BDB4C85786450402288F37002934C40
5497	6	57	\N	922	16440	\N	57.139591000000003	625025, Тюменская область, г. Тюмень, д. Плеханова, ул. Ковалева, 9	Россия, Тюменская область, Тюмень, деревня Плеханово, улица Ковалева, 9	0101000020E6100000BBB88D06F05C504071E82D1EDE914C40
5366	6	57	\N	922	42044	\N	57.167019098772101	625511, Тюменская область, Тюменский район, с. Яр, ул. Источник, д. 93а	Россия, Тюменская область, Тюмень, улица Источник	0101000020E61000009BAF928FDD6C5040C367EBE060954C40
5439	6	57	\N	922	2499	\N	57.149445	625000, Тюменская область, г. Тюмень ул. Герцена, 80	Россия, Тюменская область, Тюмень, улица Герцена, 80	0101000020E61000008599B67F656250407EC6850321934C40
5506	6	57	\N	922	3424	\N	57.131497000000003	625035, Тюменская область, г. Тюмень, ул. Геологоразведчиков, 14	Россия, Тюменская область, Тюмень, улица Геологоразведчиков, 14	0101000020E61000007C0BEBC6BB645040D542C9E4D4904C40
5505	6	57	\N	922	3424	\N	57.133665999999998	625026, Тюменская область, г. Тюмень, пр. Геологоразведчиков, 6а	Россия, Тюменская область, Тюмень, улица Геологоразведчиков, 6а	0101000020E61000002881CD3978645040274BADF71B914C40
5579	6	57	\N	922	4391	\N	57.155479	625048, Тюменская область, г. Тюмень, пр. Борцов Октября, 2 А	Россия, Тюменская область, Тюмень, улица Борцов Октября, 3	0101000020E6100000DDEF5014E86450407E1B62BCE6934C40
86204	6	56	1800	48950	19108	\N	56.702959999999997	с.Захаровское, Бачурина, 2 А		0101000020E61000002444F98216524F40B532E197FA594C40
5533	6	57	\N	922	81131	\N	57.099559044787597	625014, Тюменская область, г. Тюмень, микрорайон Лесной, 12, корпус 2	Россия, Тюменская область, Тюмень, Ленинский район	0101000020E6100000B7B585E7A56D5040E0826C59BE8C4C40
5437	6	57	\N	922	42380	\N	57.148829999999997	625000, Тюменская область, г. Тюмень, ул. Ялуторовская, 13		0101000020E610000041834D9D47625040F35487DC0C934C40
5551	6	57	\N	922	4040	\N	57.183245999999997	625031, Тюменская область, г. Тюмень, пр. Юганский, 6	Россия, Тюменская область, Тюмень, Юганский проезд, 6	0101000020E610000035D4282499655040B88FDC9A74974C40
5410	6	57	\N	922	42214	\N	57.095292000000001	625053, Тюменская область, г. Тюмень, ул. Энергостороителей, 4		0101000020E610000085CFD6C1C168504004C93B87328C4C40
5516	6	57	\N	922	42158	\N	57.138609000000002	625013, Тюменская область, г. Тюмень, ул. Энергетиков, 36		0101000020E61000000AA2EE039065504034F790F0BD914C40
5515	6	57	\N	922	42158	\N	57.139029000000001	625013, Тюменская область, г. Тюмень, ул. Энергетиков, 45		0101000020E6100000C6DB4AAFCD6550400919C8B3CB914C40
5513	6	57	\N	922	42158	\N	57.13711	625013, Тюменская область, г. Тюмень, ул. Энергетиков, 44 1		0101000020E6100000BAF94674CF6550402FFA0AD28C914C40
5567	6	57	\N	922	42192	\N	57.175645000000003	625022, Тюменская область, г. Тюмень, ул. Щербакова, 94		0101000020E61000007D410B09186350405C5A0D897B964C40
5499	6	57	\N	922	42077	\N	57.158081000000003	625061, Тюменская область, г. Тюмень, с. Утёшево, ул. Школьная, 9а		0101000020E6100000240A2DEBFE5650403B8F8AFF3B944C40
5553	6	57	\N	922	42226	\N	57.187196999999998	625031, Тюменская область, г. Тюмень, ул. Шишкова, 15		0101000020E6100000D21918795964504064744012F6974C40
5422	6	57	\N	922	42164	\N	57.110813	625051, Тюменская область, г. Тюмень, ул. Широтная, 102		0101000020E61000006397A8DE1A6550405F7CD11E2F8E4C40
5419	6	57	\N	922	42164	\N	57.105260999999999	625046, Тюменская область, г. Тюмень, ул. Широтная, 116		0101000020E6100000381092054C655040AA454431798D4C40
5418	6	57	\N	922	42164	\N	57.106203999999998	625046, Тюменская область, г. Тюмень, ул. Широтная, 114 корпус 1		0101000020E6100000C11F7EFE7B655040295AB917988D4C40
5550	6	57	\N	922	4017	\N	57.182499999999997	625031, Тюменская область, г. Тюмень, пр. Шаимский, 8 А	Россия, Тюменская область, Тюмень, Шаимский проезд, 8а	0101000020E6100000B66AD784B46550408FC2F5285C974C40
5481	6	57	\N	922	81128	\N	57.125828948910602	625032, Тюменская область, г. Тюмень, ул. Червишевский тракт, 72а корп. 1	Россия, Тюменская область, Тюмень, Калининский район, Червишевский тракт, 72	0101000020E6100000FE65F7E461615040B7F1272A1B904C40
5483	6	57	\N	922	41989	\N	57.129232770601902	625008, Тюменская область, г. Тюмень, ул. Червишевский тракт, 15 корп. 1	Россия, Тюменская область, Тюмень, Калининский район, Червишевский тракт, 15/1	0101000020E6100000CA37DBDC986150403048FAB48A904C40
5479	6	57	\N	922	41989	\N	57.123127913443398	625062, Тюменская область, г. Тюмень, ул. Червишевский тракт, 29	Россия, Тюменская область, Тюмень, Калининский район, Червишевский тракт, 29	0101000020E61000002E3BC43F6C615040679C86A8C28F4C40
5482	6	57	\N	922	42132	\N	57.130479255665797	625008, Тюменская область, г. Тюмень, ул. Червишевский тракт, 13	Россия, Тюменская область, Тюмень, Калининский район, Червишевский тракт, 13	0101000020E6100000B66455849B6150404BE82E89B3904C40
5536	6	57	\N	922	42379	\N	57.121294134634603	625014, Тюменская область, г. Тюмень, ул. Чекистов, 42	Россия, Тюменская область, Тюмень, улица Чекистов, 42	0101000020E6100000C00644882B6A5040BB99D18F868F4C40
5581	6	57	\N	922	42212	\N	57.158799000000002	625002, Тюменская область, г. Тюмень, ул. Циолковского, 1		0101000020E6100000DD239BABE66350409AD18F8653944C40
5589	6	57	\N	922	42197	\N	57.150055000000002	625000, Тюменская область, г. Тюмень, ул. Хохрякова, 88		0101000020E610000077A38FF980635040F7CC920035934C40
5586	6	57	\N	922	42182	\N	57.142657999999997	625048, Тюменская область, г. Тюмень, ул. Холодильная, 120		0101000020E61000005EBD8A8C0E645040A2410A9E42924C40
5502	6	57	\N	922	42182	\N	57.138150000000003	625048, Тюменская область, г. Тюмень, ул. Холодильная, 81		0101000020E6100000452BF702B3635040A1F831E6AE914C40
5577	6	57	\N	922	42238	\N	57.153037243814701	625048, Тюменская область, г. Тюмень, ул. Харьковская, 48	Россия, Тюменская область, Тюмень, улица Харьковская, 48	0101000020E6100000A7406667D1645040FA0967B796934C40
5431	6	57	\N	922	42086	\N	57.122612374677097	625016, Тюменская область, г. Тюмень, ул. Н. Федорова, 3	Россия, Тюменская область, Тюмень, улица Федорова, 3	0101000020E610000071033E3F8C6450406F0C01C0B18F4C40
5447	6	57	\N	922	42219	\N	57.160916999999998	625001, Тюменская область, г. Тюмень, ул. Уральская, 60		0101000020E61000001C7DCC07046050406A2FA2ED98944C40
5474	6	57	\N	922	42162	\N	57.134583999999997	625049, Тюменская область, г. Тюмень, ул. Транспортная, 106 корп. 3		0101000020E6100000BFD2F9F02C6050404D486B0C3A914C40
5547	6	57	\N	922	42528	\N	57.171693987733299	625007, Тюменская область, г. Тюмень, пос. Дорожный, 24	Россия, Тюменская область, Тюмень, Тобольский тракт	0101000020E6100000D522A298BC6A5040B075A911FA954C40
5559	6	57	\N	922	42208	\N	57.188308999999997	625043, Тюменская область, г. Тюмень, ул. Тимуровцев, 32		0101000020E6100000FFB27BF2B06350406F4562821A984C40
5412	6	57	\N	922	42201	\N	57.097124999999998	625053, Тюменская область, г. Тюмень, ул. Таллинская, 1		0101000020E61000009B5434D6FE685040DF4F8D976E8C4C40
5454	6	57	\N	922	42170	\N	57.156528999999999	625037, Тюменская область, г. Тюмень, ул. Таврическая, 2 корп. 1		0101000020E6100000B534B742585F504013F06B2409944C40
5420	6	57	\N	922	42215	\N	57.105974000000003	625046, Тюменская область, г. Тюмень, ул. Суходольская, 15		0101000020E61000001D1F2DCE18655040F81C588E908D4C40
5527	6	57	\N	922	42175	\N	57.156148000000002	625034, Тюменская область, г. Тюмень, ул. Судостроителей, 19		0101000020E6100000A27C410B09685040FCAA5CA8FC934C40
5542	6	57	\N	922	42189	\N	57.178381999999999	625015, Тюменская область, г. Тюмень, ул. Судоремонтная, 25		0101000020E610000052D50451F7685040F818AC38D5964C40
5540	6	57	\N	922	42189	\N	57.170805000000001	625015, Тюменская область, г. Тюмень, ул. Судоремонтная, 1 А		0101000020E610000060B1868BDC685040247F30F0DC954C40
5413	6	57	\N	922	42174	\N	57.096235	625053, Тюменская область, г. Тюмень, ул. Станционная, 34		0101000020E6100000575C1C959B69504083DDB06D518C4C40
5486	6	57	\N	922	42166	\N	57.122171000000002	625062, Тюменская область, г. Тюмень, ул. Ставропольская, 5 корп. 2		0101000020E6100000618A7269FC61504083C2A04CA38F4C40
5493	6	57	\N	922	42157	\N	57.124186869836699	625007, Тюменская область, г. Тюмень, ул. Союзная, 135		0101000020E6100000A587A1D5C96250404FCB0F5CE58F4C40
5391	6	57	\N	922	78160	\N	57.158490999999998	625509, Тюменская область, Тюменский район, д. Решетниково, ул. Советская, д. 21а		0101000020E6100000CA349A5C8C625040ECDADE6E49944C40
5578	6	57	\N	922	42146	\N	57.155037254146499	625048, Тюменская область, г. Тюмень, ул. Северная, 1		0101000020E61000001C28F04E3E645040C1559E40D8934C40
5484	6	57	\N	922	42222	\N	57.121012999999998	625062, Тюменская область, г. Тюмень, ул. Самарцева, 28		0101000020E610000097715303CD61504007B29E5A7D8F4C40
5452	6	57	\N	922	42203	\N	57.162585999999997	625001, Тюменская область, г. Тюмень, ул. Садовая, 121		0101000020E61000007A8EC877295F5040CB64389ECF944C40
5451	6	57	\N	922	42203	\N	57.163122999999999	625001, Тюменская область, г. Тюмень, ул. Садовая, 109		0101000020E61000005987A3AB745F5040DA1CE736E1944C40
5450	6	57	\N	922	42203	\N	57.167285999999997	625001, Тюменская область, г. Тюмень, ул. Садовая, 64		0101000020E6100000967A1684F25F5040118AADA069954C40
5462	6	57	\N	922	42382	\N	57.180807000000001	625001, Тюменская область, г. Тюмень, ул. Рылеева, 34		0101000020E6100000F78E1A1362605040A6F10BAF24974C40
5443	6	57	\N	922	42220	\N	57.158594000000001	625003, Тюменская область, г. Тюмень, ул. Розы Люксембург, 12		0101000020E61000000EBF9B6ED9605040C1ABE5CE4C944C40
5512	6	57	\N	922	42136	\N	57.130076042003502	625013, Тюменская область, г. Тюмень, ул. Рижская, 71	Россия, Тюменская область, Тюмень, улица Рижская, 73	0101000020E61000006EDE3829CC6550404CFF9254A6904C40
5600	6	57	\N	922	42151	\N	57.158055148299397	625003, Тюменская область, г. Тюмень, ул. Республики, 19	Россия, Тюменская область, Тюмень, улица Республики	0101000020E6100000AC71361D0162504011FC6F253B944C40
5597	6	57	\N	922	42151	\N	57.152252715970597	625000, Тюменская область, г. Тюмень, ул. Республики, 47	Россия, Тюменская область, Тюмень, улица Республики, 47	0101000020E6100000BDAC8905BE625040E4DBBB067D934C40
5587	6	57	\N	922	42151	\N	57.146427000000003	625048, Тюменская область, г. Тюмень, ул. Республики, 83		0101000020E61000009D499BAA7B6350402E20B41EBE924C40
5585	6	57	\N	922	42151	\N	57.144337	625048, Тюменская область, г. Тюмень, ул. Республики, 129		0101000020E6100000F7E461A1D6635040274D83A279924C40
5535	6	57	\N	922	42151	\N	57.119591	625019, Тюменская область, г. Тюмень, ул. Республики, 206 А		0101000020E6100000F949B54FC7665040AEF204C24E8F4C40
5534	6	57	\N	922	42151	\N	57.118920215198401	625014, Тюменская область, г. Тюмень, ул. Республики, 237	Россия, Тюменская область, Тюмень, улица Республики, 237	0101000020E610000076A6D0798D675040906B43C5388F4C40
5494	6	57	\N	922	42233	\N	57.119933000000003	625062, Тюменская область, г. Тюмень, ул. Революции, 199		0101000020E610000080D8D2A3A9625040085BECF6598F4C40
5407	6	57	\N	922	78170	\N	57.182631000000001	625516, Тюменская область, г. Тюмень, ул. Ратная, здание «Военторга»		0101000020E61000006A6CAF05BD6350402E1EDE7360974C40
5596	6	57	\N	922	42199	\N	57.152979999999999	625002, Тюменская область, г. Тюмень, ул. Профсоюзная, 46		0101000020E61000007B12D89C83635040967840D994934C40
5517	6	57	\N	922	42139	\N	57.136177000000004	625023, Тюменская область, г. Тюмень, ул. Пржевальского, 60		0101000020E61000003CF4DDAD2C655040D4BB783F6E914C40
5560	6	57	\N	922	42239	\N	57.199573999999998	625043, Тюменская область, г. Тюмень, ул. Пирогова, 3		0101000020E6100000CD3CB9A640635040E2900DA48B994C40
5510	6	57	\N	922	42183	\N	57.130906000000003	625013, Тюменская область, г. Тюмень, ул. Пермякова, 3		0101000020E6100000494A7A185A665040D36C1E87C1904C40
5509	6	57	\N	922	42183	\N	57.125458999999999	625035, Тюменская область, г. Тюмень, ул. Пермякова, 40		0101000020E6100000C63027689365504093FE5E0A0F904C40
5429	6	57	\N	922	42183	\N	57.117255	625051, Тюменская область, г. Тюмень, ул. Пермякова, 37		0101000020E6100000A88DEA742065504070253B36028F4C40
5428	6	57	\N	922	42183	\N	57.115647000000003	625051, Тюменская область, г. Тюмень, ул. Пермякова, 39а		0101000020E61000006F9C14E63D655040B5705985CD8E4C40
5599	6	57	\N	922	42149	\N	57.155127999999998	625000, Тюменская область, г. Тюмень, ул. Первомайская, 1	Россия, Тюменская область, Тюмень, улица Первомайская, 3	0101000020E61000000533A6608D625040D158FB3BDB934C40
5442	6	57	\N	922	42149	\N	57.147984999999998	625000, Тюменская область, г. Тюмень, ул. Первомайская, 55		0101000020E6100000AE282504AB61504037A6272CF1924C40
5477	6	57	\N	922	42181	\N	57.131238000000003	625030, Тюменская область, г. Тюмень, ул. Пархоменко, 60		0101000020E610000093E1783E0361504009FF2268CC904C40
5580	6	57	\N	922	42213	\N	57.161025000000002	625002, Тюменская область, г. Тюмень, ул. Пароходская, 31		0101000020E6100000BB44F5D6C0635040516B9A779C944C40
5561	6	57	\N	922	42160	\N	57.187485000000002	625043, Тюменская область, г. Тюмень, ул. Павлова, 8 А		0101000020E6100000D4D51D8B6D635040CBBE2B82FF974C40
5598	6	57	\N	922	42210	\N	57.159515087025	625002, Тюменская область, г. Тюмень, ул. Осипенко, 2		0101000020E6100000BB270F0BB5625040581CCEFC6A944C40
5595	6	57	\N	922	42198	\N	57.152047000000003	625000, Тюменская область, г. Тюмень, ул. Орджоникидзе, 49		0101000020E61000001F6ADB300A6350403B3AAE4676934C40
5594	6	57	\N	922	42198	\N	57.150123999999998	625000, Тюменская область, г. Тюмень, ул. Орджоникидзе, 59		0101000020E6100000037976F9D66250401F2C634337934C40
5157	6	57	\N	922	42163	\N	57.112465	625046, Тюменская область, г. Тюмень, ул. Олимпийская, 20а		0101000020E610000017D7F84CF6655040EA78CC40658E4C40
5526	6	57	\N	922	42235	\N	57.145158000000002	625023, Тюменская область, г. Тюмень, ул. Одесская, 9		0101000020E610000059E02BBAF56550405B608F8994924C40
5518	6	57	\N	922	42235	\N	57.137329000000001	625023, Тюменская область, г. Тюмень, ул. Одесская, 54		0101000020E6100000CA198A3BDE6450406DE525FF93914C40
5464	6	57	\N	922	42140	\N	57.148019931523102	625025, Тюменская область, г. Тюмень, ул. Новоселов, 1а	Россия, Тюменская область, Тюмень, улица Новоселов	0101000020E6100000D5B48B69A65F5040B493C151F2924C40
5463	6	57	\N	922	42140	\N	57.146276	625025, Тюменская область, г. Тюмень, ул. Новоселов, 10		0101000020E6100000FA27B858515F50404818062CB9924C40
5471	6	57	\N	922	42207	\N	57.147691999999999	625025, Тюменская область, г. Тюмень, ул. Волгоградская, 70		0101000020E6100000D34D621058605040BFF04A92E7924C40
5554	6	57	\N	922	42200	\N	57.212327795301299	625054, Тюменская область, г. Тюмень, п. Березняковский, ул. Новая, 1А	Россия, Тюменская область, Тюмень, деревня Казарово, улица Новая, 1	0101000020E610000043ACFE08C362504036035C902D9B4C40
5421	6	57	\N	922	42142	\N	57.109124929755701	625051, Тюменская область, г. Тюмень, ул. Николая Гондатти, 13	Россия, Тюменская область, Тюмень, улица Николая Гондатти	0101000020E6100000DB334B02D46450408716D9CEF78D4C40
5562	6	57	\N	922	42383	\N	57.188743000000002	625043, Тюменская область, г. Тюмень, ул. Мусы Джалиля, 13		0101000020E6100000ECBE6378EC625040AA2C0ABB28984C40
5590	6	57	\N	922	42209	\N	57.144669	625048, Тюменская область, г. Тюмень, ул. Мурманская, 31		0101000020E6100000E49EAEEE586350405DDF878384924C40
5417	6	57	\N	922	42155	\N	57.107562999999999	625046, Тюменская область, г. Тюмень, ул. Моторостроителей, 6		0101000020E610000017F549EEB06650403CA1D79FC48D4C40
5416	6	57	\N	922	42155	\N	57.107562999999999	625046, Тюменская область, г. Тюмень, ул. Моторостроителей, 6 корпус 2	Россия, Тюменская область, Тюмень, улица Моторостроителей, 6	0101000020E610000017F549EEB06650403CA1D79FC48D4C40
5415	6	57	\N	922	42155	\N	57.108052000000001	625046, Тюменская область, г. Тюмень, ул. Моторостроителей, 2б		0101000020E610000057276728EE6650403A22DFA5D48D4C40
5476	6	57	\N	922	41955	\N	57.132388421157202	625049, Тюменская область, г. Тюмень, ул. Московский тракт, 137 корп. 2	Россия, Тюменская область, Тюмень, Московский тракт, 137	0101000020E61000003FE3C281905F504001310917F2904C40
5475	6	57	\N	922	41955	\N	57.131663527865499	625049, Тюменская область, г. Тюмень, ул. Московский тракт, 129 стр. 1	Россия, Тюменская область, Тюмень, Московский тракт, 129/1	0101000020E6100000FF3D78EDD25F5040C007AF5DDA904C40
5473	6	57	\N	922	41955	\N	57.139600387832203	625008, Тюменская область, г. Тюмень, ул. Московский тракт, 22	Россия, Тюменская область, Тюмень, Московский тракт, 22	0101000020E610000008E9297288615040C442AD69DE914C40
5467	6	57	\N	922	41955	\N	57.136825894113102	625049, Тюменская область, г. Тюмень, ул. Московский тракт, 104	Россия, Тюменская область, Тюмень, Московский тракт, 104	0101000020E6100000B5A9BA47366050400A9FAD8383914C40
5423	6	57	\N	922	42176	\N	57.109957999999999	625046, Тюменская область, г. Тюмень, ул. Монтажников, 10,		0101000020E6100000A5F44C2F316650407FF78E1A138E4C40
5489	6	57	\N	922	42134	\N	57.132710571122402	625007, Тюменская область, г. Тюмень, ул. Молодежная, 81	Россия, Тюменская область, Тюмень, улица Молодежная, 81	0101000020E610000097C4591135635040E4688EACFC904C40
5556	6	57	\N	922	42184	\N	57.223832345103098	625043, Тюменская область, г. Тюмень, пос. Верхний Бор, ул. Мира, 1		0101000020E610000008C90226705E50402EE6E786A69C4C40
5470	6	57	\N	922	42221	\N	57.143912999999998	625025, Тюменская область, г. Тюмень, ул. Мира, 14		0101000020E6100000A0C6BDF90D615040103CBEBD6B924C40
5575	6	57	\N	922	42195	\N	57.150773000000001	625048, Тюменская область, г. Тюмень, ул. Минская, 9 Б		0101000020E6100000F8A8BF5E61655040560F98874C934C40
5498	6	57	\N	922	42135	\N	57.213090487079803	625056, Тюменская область, г. Тюмень, д. Метелёва	Россия, Тюменская область, Тюмень, улица Метелева	0101000020E6100000BB6246787B5B5040658D7A88469B4C40
5591	6	57	\N	922	42229	\N	57.138632999999999	625048, Тюменская область, г. Тюмень, ул. Мельничная, 80		0101000020E6100000FE5F75E448635040BC92E4B9BE914C40
5576	6	57	\N	922	42138	\N	57.151735000000002	625048, Тюменская область, г. Тюмень, ул. Мельникайте, 42		0101000020E610000094DE37BEF66550404C546F0D6C934C40
5573	6	57	\N	922	42138	\N	57.150651000000003	625048, Тюменская область, г. Тюмень, ул. Мельникайте, 48		0101000020E610000081E84999D46550400B0E2F8848934C40
5525	6	57	\N	922	42138	\N	57.150230999999998	625039, Тюменская область, г. Тюмень, ул. Мельникайте, 61 Б		0101000020E6100000AC3AAB05F665504035ECF7C43A934C40
5521	6	57	\N	922	42138	\N	57.144019999999998	625027, Тюменская область, г. Тюмень, ул. Мельникайте, 76		0101000020E61000004D158C4AEA64504026FC523F6F924C40
5449	6	57	\N	922	42223	\N	57.175294000000001	625001, Тюменская область, г. Тюмень, ул. Мельзаводская, 19		0101000020E61000003082C64CA25F5040AF97A60870964C40
5557	6	57	\N	922	42150	\N	57.210710217843399	625059, Тюменская область, г. Тюмень, ул. Мелиораторов, 15		0101000020E61000006B662D05A46650405778978BF89A4C40
5569	6	57	\N	922	42144	\N	57.173757000000002	625005, Тюменская область, г. Тюмень, ул. Маяковского, 8		0101000020E61000001EF98381E7615040BD395CAB3D964C40
5546	6	57	\N	922	42211	\N	57.180885000000004	625029, Тюменская область, г. Тюмень, ул. Малышева, 26		0101000020E61000006072A3C85A67504022AB5B3D27974C40
5593	6	57	\N	922	42169	\N	57.143560999999998	625048, Тюменская область, г. Тюмень, ул. Малыгина, 8, корп. 1		0101000020E6100000AC3AAB05F662504093FDF33460924C40
5469	6	57	\N	922	42165	\N	57.137113999999997	625049, Тюменская область, г. Тюмень, ул. Магнитогорская, 11 корп. 1		0101000020E6100000A1D79FC4E75F504070E998F38C914C40
5468	6	57	\N	922	42165	\N	57.137113999999997	625049, Тюменская область, г. Тюмень, ул. Магнитогорская, 11		0101000020E6100000A1D79FC4E75F504070E998F38C914C40
5448	6	57	\N	922	42178	\N	57.161648999999997	625001, Тюменская область, г. Тюмень, ул. Луначарского, 40		0101000020E61000007D96E7C1DD5F50402E3718EAB0944C40
5446	6	57	\N	922	42178	\N	57.165036999999998	625001, Тюменская область, г. Тюмень, ул. Луначарского, 14		0101000020E61000009C69C2F693605040A2D0B2EE1F954C40
5445	6	57	\N	922	42178	\N	57.164636000000002	625001, Тюменская область, г. Тюмень, ул. Луначарского, 19		0101000020E6100000E6EB32FCA760504044DFDDCA12954C40
5444	6	57	\N	922	42178	\N	57.167198999999997	625001, Тюменская область, г. Тюмень, ул. Луначарского, 2		0101000020E61000007102D369DD6050404276DEC666954C40
5434	6	57	\N	922	41984	\N	57.1188703539421	625016, Тюменская область, г. Тюмень, ул. А. Логунова, 15	Россия, Тюменская область, Тюмень, улица Логунова, 15	0101000020E6100000A9BC1DE1B4645040DE3CD521378F4C40
5433	6	57	\N	922	41984	\N	57.119500661668802	625016, Тюменская область, г. Тюмень, ул. А. Логунова, 17	Россия, Тюменская область, Тюмень, улица Логунова, 17	0101000020E61000006F8445459C6450406E6B0BCF4B8F4C40
5552	6	57	\N	922	42168	\N	57.184080000000002	625031, Тюменская область, г. Тюмень, ул. Ватутина, 14/1		0101000020E6100000AE2990D95965504081ECF5EE8F974C40
5532	6	57	\N	922	42196	\N	57.107623770351999	625047, Тюменская область, г. Тюмень, с. Антипино, ул. Ленинградская, 10	Россия, Тюменская область, Тюмень, поселок Антипино, улица Ленинградская	0101000020E610000071FF91E9D06E5040E2218C9FC68D4C40
5440	6	57	\N	922	42217	\N	57.155050000000003	625000, Тюменская область, г. Тюмень, ул. Ленина, 38		0101000020E61000000458E4D70F625040569FABADD8934C40
5151	6	57	\N	922	42217	\N	57.157587999999997	627431, Тюменская область, Казанский район, д. НАлександровка, ул. Ленина, д. 26а		0101000020E6100000917D9065C1615040FB1EF5D72B944C40
5441	6	57	\N	922	42218	\N	57.151739999999997	625003, Тюменская область, г. Тюмень, Крупской, 21		0101000020E610000008944DB9C26150405DBF60376C934C40
5592	6	57	\N	922	42237	\N	57.141089999999998	625048, Тюменская область, г. Тюмень, ул. Красных Зорь, 39		0101000020E6100000FDDAFAE93F63504075E5B33C0F924C40
5504	6	57	\N	922	42224	\N	57.139859000000001	625023, Тюменская область, г. Тюмень, ул. Котовского, 56		0101000020E610000012A27C410B655040908653E6E6914C40
5574	6	57	\N	922	42194	\N	57.153488000000003	625048, Тюменская область, г. Тюмень, ул. Коммунаров, 25		0101000020E6100000E63C635FB26450400B2AAA7EA5934C40
5523	6	57	\N	922	42185	\N	57.141168	625027, Тюменская область, г. Тюмень, ул. Киевская, 78		0101000020E610000085B35BCB64645040F19E03CB11924C40
5522	6	57	\N	922	42185	\N	57.143659	625027, Тюменская область, г. Тюмень, ул. Киевская, 63		0101000020E6100000F241CF66D56450405663096B63924C40
5461	6	57	\N	922	42204	\N	57.183835999999999	625001, Тюменская область, г. Тюмень, ул. Кемеровская, 1б		0101000020E61000000C3CF71E2E605040EAE923F087974C40
5588	6	57	\N	922	42230	\N	57.141382999999998	625048, Тюменская область, г. Тюмень, ул. Карская, 38		0101000020E6100000F355F2B1BB635040ED9A90D618924C40
5466	6	57	\N	922	42225	\N	57.146759000000003	625025, Тюменская область, г. Тюмень, ул. Карла Маркса, 108		0101000020E610000089981249F45F504064B2B8FFC8924C40
5465	6	57	\N	922	42225	\N	57.148200000000003	625025, Тюменская область, г. Тюмень, ул. Карла Маркса, 110а		0101000020E6100000A7406667D15F504034A2B437F8924C40
5531	6	57	\N	922	42143	\N	57.151144000000002	625034, Тюменская область, г. Тюмень, ул. Камчатская, 154		0101000020E61000000C21E7FD7F6A50404A7EC4AF58934C40
5530	6	57	\N	922	42143	\N	57.159604000000002	625034, Тюменская область, г. Тюмень, ул. Камчатская, 1 А		0101000020E610000008E412471E6A5040C82764E76D944C40
5472	6	57	\N	922	42180	\N	57.143034	625008, Тюменская область, г. Тюмень, ул. Калинина, 5		0101000020E61000005587DC0C37615040A81B28F04E924C40
5529	6	57	\N	922	42148	\N	57.150753000000002	625034, Тюменская область, г. Тюмень, ул. Казачьи луга, 9 1		0101000020E6100000DF6B088ECB6950400F63D2DF4B934C40
5555	6	57	\N	922	42216	\N	57.216124000000001	625043, Тюменская область, г. Тюмень, д. Казарово, ул. Казаровская, 35		0101000020E61000003FC7478B33635040BBF083F3A99B4C40
5500	6	57	\N	922	42234	\N	57.167613000000003	625041, Тюменская область, г. Тюмень, Институтская, 4		0101000020E61000006B4AB20E475C504036B1C05774954C40
5582	6	57	\N	922	42161	\N	57.149639999999998	625048, Тюменская область, г. Тюмень, ул. Индустриальная, 49 А		0101000020E61000000647C9AB7364504033164D6727934C40
5548	6	57	\N	922	42190	\N	57.185212	625029, Тюменская область, г. Тюмень, ул. Игримская, 27		0101000020E61000006FD921FE61675040D369DD06B5974C40
5564	6	57	\N	922	4184	\N	57.178469999999997	625022, Тюменская область, г. Тюмень, пр. Заречный, 4 А	Россия, Тюменская область, Тюмень, Заречный проезд, 4а	0101000020E610000069C4CC3E8F63504097A8DE1AD8964C40
5571	6	57	\N	922	42154	\N	57.167124999999999	625005, Тюменская область, г. Тюмень, ул. Заозерная, 101		0101000020E61000009CFD8172DB61504008AC1C5A64954C40
5541	6	57	\N	922	42236	\N	57.174366999999997	625015, Тюменская область, г. Тюмень, ул. Ершова, 9		0101000020E610000051A5660FB4685040354069A851964C40
5528	6	57	\N	922	42205	\N	57.149605999999999	625034, Тюменская область, г. Тюмень, ул. Домостроителей, 2 А		0101000020E610000028F38FBE4969504087A4164A26934C40
5492	6	57	\N	922	42232	\N	57.127203000000002	625007, Тюменская область, г. Тюмень, ул. Демьяна Бедного, 100		0101000020E610000007B309302C635040FF791A3048904C40
5491	6	57	\N	922	42232	\N	57.127744999999997	625007, Тюменская область, г. Тюмень, ул. Демьяна Бедного, 109		0101000020E61000008AABCABE2B6350401F9DBAF259904C40
5436	6	57	\N	922	42101	\N	57.121963427504603	625007, Тюменская область, г. Тюмень, ул. В. Гнаровской, 1	Россия, Тюменская область, Тюмень, улица Гнаровской, 1	0101000020E6100000DD26DC2BF36350403929CC7B9C8F4C40
5435	6	57	\N	922	42101	\N	57.121624952846098	625007, Тюменская область, г. Тюмень, ул. В. Гнаровской, 3а	Россия, Тюменская область, Тюмень, улица Гнаровской, 3а	0101000020E6100000C328081EDF63504021B07268918F4C40
5285	6	57	\N	922	42101	\N	57.122488731836	625007, Тюменская область, г. Тюмень, ул. В. Гнаровской, 3	Россия, Тюменская область, Тюмень, улица Гнаровской, 3	0101000020E610000060C8EA56CF635040548F34B8AD8F4C40
5539	6	57	\N	922	42588	\N	57.126767999999998	625039, Тюменская область, г. Тюмень, ул. Гилевская роща, 4		0101000020E6100000221B48179B675040F4160FEF39904C40
5508	6	57	\N	922	42202	\N	57.128985999999998	625035, Тюменская область, г. Тюмень, ул. Геологоразведчиков, 39		0101000020E61000005456D3F54465504028D2FD9C82904C40
5507	6	57	\N	922	42202	\N	57.132367000000002	625035, Тюменская область, г. Тюмень, ул. Геологоразведчиков, 19		0101000020E610000003931B45D6645040EA08E066F1904C40
5568	6	57	\N	922	42191	\N	57.173347	625022, Тюменская область, г. Тюмень, ул. Газовиков, 30		0101000020E61000003108AC1C5A6350400BEE073C30964C40
5566	6	57	\N	922	42191	\N	57.176845999999998	625022, Тюменская область, г. Тюмень, ул. Газовиков, 6		0101000020E61000006B9E23F25D635040D636C5E3A2964C40
5565	6	57	\N	922	42191	\N	57.178314	625022, Тюменская область, г. Тюмень, ул. Газовиков, 11		0101000020E610000047E5266A69635040A0353FFED2964C40
5563	6	57	\N	922	42191	\N	57.180025999999998	625022, Тюменская область, г. Тюмень, ул. Газовиков, 3 А		0101000020E6100000897956D28A63504000378B170B974C40
5496	6	57	\N	922	42387	\N	57.1524760224844	625017, Тюменская область, г. Тюмень, п. Рощино, ул. Гагарина, 4	Россия, Тюменская область, Тюмень, поселок Рощино, улица Гагарина, 4	0101000020E6100000193BE125385B504063B6645584934C40
5537	6	57	\N	922	42186	\N	57.122785999999998	625019, Тюменская область, г. Тюмень, ул. Воровского, 11		0101000020E610000017450F7C0C6750400D349F73B78F4C40
5572	6	57	\N	922	42193	\N	57.163924000000002	625022, Тюменская область, г. Тюмень, ул. Береговая, 147		0101000020E6100000204432E4D8625040C7832D76FB944C40
5570	6	57	\N	922	42193	\N	57.172483	625005, Тюменская область, г. Тюмень, ул. Береговая, 24		0101000020E610000099D53BDC0E615040D80E46EC13964C40
5455	6	57	\N	922	42156	\N	57.153725527998702	625037, Тюменская область, г. Тюмень, ул. Белинского, 22 корп. 1	Россия, Тюменская область, Тюмень, улица Белинского, 22	0101000020E61000005166834C325F5040BF45274BAD934C40
5453	6	57	\N	922	42156	\N	57.158999000000001	625037, Тюменская область, г. Тюмень, ул. Белинского, 1а		0101000020E6100000A26131EA5A5F5040618C48145A944C40
5459	6	57	\N	922	42153	\N	57.1672321157737	625041, Тюменская область, г. Тюмень, ул. Барнаульская, 41	Россия, Тюменская область, Тюмень, улица Барнаульская, 40	0101000020E6100000AAD6C22CB45D50401E6CB1DB67954C40
5458	6	57	\N	922	42381	\N	57.161586	625041, Тюменская область, г. Тюмень, ул. Бакинских комиссаров, 8		0101000020E6100000F722DA8EA95E5040E8BE9CD9AE944C40
5460	6	57	\N	922	42179	\N	57.176805999999999	625001, Тюменская область, г. Тюмень, ул. Бабарынка, 20Б		0101000020E610000047938B31B05E504048DE3994A1964C40
5457	6	57	\N	922	42206	\N	57.158169000000001	625017, Тюменская область, г. Тюмень, ул. Авторемонтная, 24		0101000020E610000079CC4065FC5C5040DA1EBDE13E944C40
5432	6	57	\N	922	41908	\N	57.120321156081097	625007, Тюменская область, г. Тюмень, ул. Проезд 9 Мая, 5	Россия, Тюменская область, Тюмень, 9-го Мая проезд, 5	0101000020E6100000F58590F3FE635040D102B4AD668F4C40
5558	6	57	\N	922	42228	\N	57.208150000000003	625059, Тюменская область, г. Тюмень, ул. 70 лет Октября, 5		0101000020E610000093C7D3F203675040CA54C1A8A49A4C40
5538	6	57	\N	922	42171	\N	57.120376999999998	625014, Тюменская область, г. Тюмень, ул. 50 лет Октября, 207 А/1		0101000020E610000029AF95D05D68504065187783688F4C40
5524	6	57	\N	922	42171	\N	57.148088000000001	625039, Тюменская область, г. Тюмень, ул. 50 лет Октября, 41		0101000020E610000008C72C7B126550400C772E8CF4924C40
5514	6	57	\N	922	42171	\N	57.141115101643599	625023, Тюменская область, г. Тюмень, ул. 50 лет Октября, 62		0101000020E6100000A27A6B60AB655040CEFC6A0E10924C40
5511	6	57	\N	922	42171	\N	57.135283000000001	625013, Тюменская область, г. Тюмень, ул. 50 лет Октября, 84 2		0101000020E610000037FC6EBA65665040365A0EF450914C40
5426	6	57	\N	922	42231	\N	57.116101	625051, Тюменская область, г. Тюмень, ул. 30 лет Победы, 102		0101000020E6100000E605D847A76550403604C765DC8E4C40
5425	6	57	\N	922	42231	\N	57.114811000000003	625051, Тюменская область, г. Тюмень, ул. 30 лет Победы, 106		0101000020E6100000FFEC478AC86550404C1C7920B28E4C40
5427	6	57	\N	922	42173	\N	57.117265000000003	625051, Тюменская область, г. Тюмень, ул. 30 лет Победы, 95/2		0101000020E61000006A317898F665504094FB1D8A028F4C40
5414	6	57	\N	922	42173	\N	57.109239000000002	625046, Тюменская область, г. Тюмень, ул. 30 лет Победы, 142		0101000020E610000099B85510036750405039268BFB8D4C40
5330	6	57	\N	55078	41961	\N	58.203375700379198	"626150, Тюменская область, г. Тобольск, микрорайон ""Южный"", д. 5 "		0101000020E6100000268DD13AAA10514049658A39081A4D40
5339	6	57	\N	55078	42099	\N	58.194856526737098	626150, Тюменская область, г. Тобольск, микрорайон Менделеево, д. 6	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E61000001615713AC90F5140C632FD12F1184D40
5309	6	57	\N	55078	42029	\N	58.209336380082298	626150, Тюменская область, г. Тобольск, пер. Рощинский, д. 25		0101000020E6100000E2CB4411521151400FF0A485CB1A4D40
5310	6	57	\N	55078	41946	\N	58.198935110397301	626150, Тюменская область, г. Тобольск, ул. с. Ремезова, д. 26		0101000020E61000008881AE7D01105140CF83BBB376194D40
5308	6	57	\N	55078	41946	\N	58.208050921902	"626150, Тюменская область, г. Тобольск, ул. Ремезова, д. 72 ""а"" "		0101000020E610000096067E54C31051403673486AA11A4D40
5307	6	57	\N	55078	41946	\N	58.1944939632236	"626150, Тюменская область, г. Тобольск, ул. Ремезова, д. 27 ""а"" "	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E61000004FCB0F5CE50F514055A2EC2DE5184D40
5306	6	57	\N	55078	41946	\N	58.207031582655802	626150, Тюменская область, г. Тобольск, ул. Ремезова, д. 36		0101000020E61000009450FA42C8105140DC9C4A06801A4D40
5325	6	57	\N	55078	42337	\N	58.208594557492397	626150, Тюменская область, г. Тобольск, ул. Р. Люксембург, д. 7		0101000020E61000006FF25B74B2105140F88DAF3DB31A4D40
5328	6	57	\N	55078	42035	\N	58.182535961534299	626150, Тюменская область, г. Тобольск, ул. Пушкина, д. 22	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E610000029ED0DBE30105140DC2BF3565D174D40
5304	6	57	\N	55078	42378	\N	58.194312680074397	626150, Тюменская область, г. Тобольск, микрорайон Защитино, ул. Полевая, д. 2	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E610000028B7ED7BD40F51400518963FDF184D40
5302	6	57	\N	55078	42587	\N	58.206057519938298	626150, Тюменская область, г. Тобольск, Панин бугор Объединенный учебный центр УВД		0101000020E6100000E42EC214E5105140228AC91B601A4D40
5329	6	57	\N	55078	42022	\N	58.184440021483297	626150, Тюменская область, г. Тобольск, ул. Ленина, д. 72		0101000020E610000066F50EB7431051408109DCBA9B174D40
5316	6	57	\N	55078	42021	\N	58.216074361483201	626150, Тюменская область, г. Тобольск, ул. Знаменского, д. 85		0101000020E6100000D3F885579212514009C21550A81B4D40
5311	6	57	\N	55078	42021	\N	58.201019538345399	"626150, Тюменская область, г. Тобольск, ул. Знаменского, д. 52 ""а"" "	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E61000008A3C49BA66105140C4EBFA05BB194D40
5338	6	57	\N	55078	41970	\N	58.192862381459904	626150, Тюменская область, г. Тобольск, микрорайон Иртышский, ул. Заводская, д. 15	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E610000028B7ED7BD40F51401152B7B3AF184D40
5337	6	57	\N	55078	42026	\N	58.216702796831903	626150, Тюменская область, г. Тобольск, микрорайон Иртышский, ул. Железнодорожная, д. 5		0101000020E6100000DC8310902F125140F9F884ECBC1B4D40
5336	6	57	\N	55078	42026	\N	58.205188	626150, Тюменская область, г. Тобольск, микрорайон Иртышский, ул. Железнодорожная, д. 20		0101000020E6100000D9942BBCCB1451400DC4B299431A4D40
4847	6	57	657	4461	41907	\N	56.112282	627750, Тюменская область, г. Ишим, ул. К. Маркса, 56		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5327	6	57	\N	55078	41969	\N	58.1924997975227	626150, Тюменская область, г. Тобольск, ул. Декабристов, д. 21	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E61000003A596ABDDF0F5140713D0AD7A3184D40
5332	6	57	\N	55078	42515	\N	58.205188	626150, Тюменская область, г. Тобольск, Левобережье, ул. Береговая, д. 12		0101000020E6100000D9942BBCCB1451400DC4B299431A4D40
5322	6	57	\N	55078	42023	\N	58.1951284469353	626150, Тюменская область, г. Тобольск, 9 микрорайон, д. 12	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E61000003A596ABDDF0F514056444DF4F9184D40
5324	6	57	\N	55078	41962	\N	58.223600874292003	626150, Тюменская область, г. Тобольск, 8 микрорайон, д. 42		0101000020E6100000D55C6E30D41151402C2D23F59E1C4D40
5320	6	57	\N	55078	41949	\N	58.204426471162002	626150, Тюменская область, г. Тобольск, 7 микрорайон, д. 53		0101000020E6100000336C94F59B105140DE3994A12A1A4D40
5321	6	57	\N	55078	42094	\N	58.193587538194002	626150, Тюменская область, г. Тобольск, 7 микрорайон, д. 54	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E6100000643DB5FAEA0F5140F372D87DC7184D40
5319	6	57	\N	55078	41974	\N	58.205188	626150, Тюменская область, г. Тобольск , 6 микрорайон, д. 52		0101000020E6100000D9942BBCCB1451400DC4B299431A4D40
5318	6	57	\N	55078	41974	\N	58.193224961683697	626150, Тюменская область, г. Тобольск, 6 микрорайон, д. 60	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E610000028B7ED7BD40F514082E2C798BB184D40
5315	6	57	\N	55078	41967	\N	58.220065585437702	626150, Тюменская область, г. Тобольск, 4 микрорайон, д. 54		0101000020E610000038BD8BF7E3115140147B681F2B1C4D40
5314	6	57	\N	55078	41967	\N	58.193587538194002	626150, Тюменская область, г. Тобольск, 4 микрорайон, д. 47	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E6100000EC3026FDBD0F5140F372D87DC7184D40
5313	6	57	\N	55078	41967	\N	58.196125469791802	626150, Тюменская область, г. Тобольск, 4 микрорайон, д. 41	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E6100000616D8C9DF00F5140C976BE9F1A194D40
5331	6	57	\N	55078	41943	\N	58.201200787148103	626150, Тюменская область, г. Тобольск, ул. 2я Трудовая, д 3	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E6100000AE80423D7D105140147651F4C0194D40
5383	6	57	\N	9877	41988	\N	57.0876907939709	625501, Тюменская область, Тюменский район, д. Патрушева, у. Новая, д. 8	Россия, Тюменская область, деревня Патрушево, улица Новая	0101000020E61000008BFA2477D8615040A7936C75398B4C40
5379	6	57	\N	7814	42126	\N	57.111459509469803	625501, Тюменская область, Тюменский район, п. Московский, ул. Озерная, д. 2	Россия, Тюменская область, поселок Московский, улица Озерная, 2	0101000020E610000027BF45274B5B5040F5673F52448E4C40
4756	6	57	\N	7814	42585	\N	57.10989	627532, Тюменская область, Абатский район, д. Водолазова, ул. Новая, 12		0101000020E61000000D54C6BFCF5A5040271422E0108E4C40
5495	6	57	\N	62094	81130	\N	57.224262721577801	625038, Тюменская область, г. Тюмень, ул. Андрея Туполева, 2	Россия, Тюменская область, село Луговое	0101000020E6100000207F69519F565040F75965A6B49C4C40
4984	6	57	\N	55088	42289	\N	56.302312999999998	627115, Тюменская область, Заводоуковский район, с. Колесниково, ул. Советская, д. 61		0101000020E610000014B2F33636BA5040EC134031B2264C40
5113	6	57	\N	55076	41932	\N	56.1126656220816	627750, Тюменская область, г. Ишим, ул. Ялуторовская, 90		0101000020E610000000AC8E1CE95D514081AFE8D66B0E4C40
5131	6	57	\N	55076	42294	\N	56.1130492694585	627750, Тюменская область, г. Ишим, ул. Чернышевского, 11	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000551344DD0761514039ECBE63780E4C40
5128	6	57	\N	55076	42058	\N	56.112282	627750, Тюменская область, г. Ишим, ул. Свердлова, 112		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
4862	6	57	\N	55076	42058	\N	56.114008371097803	627750, Тюменская область, г. Ишим, ул. Свердлова, 75	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000CE3461FBC9605140BEBD6BD0970E4C40
5140	6	57	\N	55076	42115	\N	56.112857446250104	627750, Тюменская область, г. Ишим, ул. Республики, 95	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E61000001C5DA5BBEB605140F50F2219720E4C40
5125	6	57	\N	55076	42082	\N	56.112282	627750, Тюменская область, г. Ишим, ул. Ражева, 1		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5127	6	57	\N	55076	42354	\N	56.1133370024708	627750, Тюменская область, г. Ишим, ул. Пушкина, 10	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000577BD80B05615140A036AAD3810E4C40
5130	6	57	\N	55076	42008	\N	56.115159261379603	627750, Тюменская область, г. Ишим, ул. Путиловская, 4,	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000D09CF529C7605140876BB587BD0E4C40
5116	6	57	\N	55076	42069	\N	56.1130492694585	627750, Тюменская область, г. Ишим, ул. Петропавловская, 23	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000A60BB1FA2361514039ECBE63780E4C40
5118	6	57	\N	55076	42110	\N	56.113624733322602	627750, Тюменская область, г. Ишим, ул. Орджоникидзе, 41	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000F54883DBDA605140068195438B0E4C40
4689	6	57	\N	55076	42036	\N	56.114296096908802	627750, Тюменская область, г. Ишим, ул. Одоевского, 54	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000E3A6069ACF60514025085740A10E4C40
5138	6	57	\N	55076	42078	\N	56.1126656220816	627750, Тюменская область, г. Ишим, ул. Непомнящего, 146	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E61000007C2766BD1861514081AFE8D66B0E4C40
5120	6	57	\N	55076	78219	\N	56.112282	627750, Тюменская область, г. Ишим, ул. М. Садовая, 71		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5121	6	57	\N	55076	78220	\N	56.112282	627750, Тюменская область, г. Ишим, ул. Луначарского, 62		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5692	6	57	1641	21426	77179	\N	56.749609	627047, Тюменская область, Ялуторовский район, с. Петелино, ул. Ленина, 25		0101000020E61000009F94490D6D9D5040C5E40D30F35F4C40
5119	6	57	\N	55076	42037	\N	56.114487912915898	627750, Тюменская область, г. Ишим, ул. Луговая, 25	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E610000094162EABB060514069E4F38AA70E4C40
5123	6	57	\N	55076	42043	\N	56.111128652462803	627750, Тюменская область, г. Ишим, ул. Ленина, 56		0101000020E6100000861BF0F9615F51408F519E79390E4C40
5122	6	57	\N	55076	42043	\N	56.112282	627750, Тюменская область, г. Ишим, ул. Ленина, 1		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5137	6	57	\N	55076	41934	\N	56.114296096908802	627750, Тюменская область, г. Ишим, ул. Красина, 7		0101000020E6100000E0D6DD3CD560514025085740A10E4C40
5136	6	57	\N	55076	41934	\N	56.113864507382203	627750, Тюменская область, г. Ишим, ул. Красина, 3	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000F7B0170AD86051405B94D920930E4C40
5126	6	57	\N	55076	42072	\N	56.1167896301097	627750, Тюменская область, г. Ишим, ул. К. Маркса, 15	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000459BE3DC26605140FB3F87F9F20E4C40
5115	6	57	\N	55076	42112	\N	56.113370627379098	627750, Тюменская область, г. Ишим, ул. Казанская, 44	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E610000088D51F61186151404CA8E0F0820E4C40
5124	6	57	\N	55076	42098	\N	56.113912462014099	627750, Тюменская область, г. Ишим, ул. К. Маркса, 4	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E610000092AE997CB36051409C4F1DAB940E4C40
5110	6	57	\N	55076	42098	\N	56.114200188545198	627750, Тюменская область, г. Ишим, ул. К. Маркса, 36	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000A45016BEBE605140029A081B9E0E4C40
4877	6	57	\N	55076	42098	\N	56.114200188545198	627750, Тюменская область, г. Ишим, ул. К. Маркса, 68	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E61000001C5DA5BBEB605140029A081B9E0E4C40
5129	6	57	\N	55076	42066	\N	56.114200188545198	627750, Тюменская область, г. Ишим, ул. Ершова, 101	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E61000007FA4880CAB605140029A081B9E0E4C40
5134	6	57	\N	55076	42009	\N	56.1141042799416	627750, Тюменская область, г. Ишим, ул. Деповская, 17	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000B16EBC3B325E5140E02BBAF59A0E4C40
5132	6	57	\N	55076	42009	\N	56.114296096908802	627750, Тюменская область, г. Ишим, ул. Деповская, 1	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000D09CF529C760514025085740A10E4C40
5133	6	57	\N	55076	42013	\N	56.115063355176297	627750, Тюменская область, г. Ишим, ул. Большая, 190	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E61000009146054EB660514065FD6662BA0E4C40
5114	6	57	\N	55076	78196	\N	56.112282	627750, Тюменская область, г. Ишим, ул. 40 лет Победы, 19А		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
4973	6	57	\N	55086	42107	\N	56.505603999999998	627144, Тюменская область, г. Заводоуковск, ул. Дзержинского, д. 2		0101000020E6100000A2427573F1A15040075DC2A1B7404C40
4969	6	57	\N	55083	42057	\N	56.508736423917	627144, Тюменская область, г. Заводоуковск, ул. Энергетиков, д. 8	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E6100000DFDDCA129DA150402026E1421E414C40
4963	6	57	\N	55083	42304	\N	56.508261826821702	627142, Тюменская область, г. Заводоуковск, ул. Щорса, д. 13	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E61000004278B471C4A1504058E6ADBA0E414C40
4968	6	57	\N	55083	42064	\N	56.508791856275501	627140, Тюменская область, г. Заводоуковск, ул. Шоссейная, д. 115		0101000020E6100000D8D30E7F4DA25040B43BA41820414C40
4965	6	57	\N	55083	42064	\N	56.508261826821702	627141, Тюменская область, г. Заводоуковск, ул. Шоссейная, д. 171	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E6100000F44F70B1A2A1504058E6ADBA0E414C40
4971	6	57	\N	55083	42287	\N	56.508831342620198	627144, Тюменская область, г. Заводоуковск, ул. Школьная, д. 74	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E61000008EE55DF580A150407218CC5F21414C40
4975	6	57	\N	55083	42061	\N	56.508071986313197	627145, Тюменская область, г. Заводоуковск, ул. Сургутская, д. 13	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E61000004278B471C4A15040B401D88008414C40
4974	6	57	\N	55083	42446	\N	56.498511429698297	627144, Тюменская область, г. Заводоуковск, ул. Совхозная, д. 184	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E61000000D384BC972A350401FD95C35CF3F4C40
4972	6	57	\N	55083	42102	\N	56.500002882336901	627144, Тюменская область, г. Заводоуковск, ул. Республики, д. 1А	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E610000052F01472A5A2504071732A1900404C40
4950	6	57	\N	55083	42052	\N	56.508500053062498	627143, Тюменская область, г. Заводоуковск, ул. Революционная, д. 113		0101000020E6100000C5909C4CDCA150400C022B8716414C40
4962	6	57	\N	55083	42056	\N	56.509116097297898	627142, Тюменская область, г. Заводоуковск, ул. Механическая, д. 49	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E61000001A3048FAB4A1504067EF8CB62A414C40
4964	6	57	\N	55083	42257	\N	56.508071986313197	627142, Тюменская область, г. Заводоуковск, ул. Мелтораторов, д. 12Б	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E6100000DFDDCA129DA15040B401D88008414C40
4976	6	57	\N	55083	42060	\N	56.509211015046603	627145, Тюменская область, г. Заводоуковск, ул. Королева, д. 8	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E6100000DE7536E49FA15040B9E177D32D414C40
4970	6	57	\N	55083	42105	\N	56.505603999999998	627144, Тюменская область, г. Заводоуковск, ул. Заводская, д. 16		0101000020E6100000A2427573F1A15040075DC2A1B7404C40
4961	6	57	\N	55083	42051	\N	56.5006674619328	627142, Тюменская область, г. Заводоуковск, ул. Ермака, д. 4	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E6100000D921FE614BA35040DD9733DB15404C40
4966	6	57	\N	55083	42106	\N	56.496489910202698	627141, Тюменская область, г. Заводоуковск, ул. Екатерины Дружининой, д. 17	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E61000009C33A2B437A350404165FCFB8C3F4C40
5354	6	57	\N	55081	41978	\N	57.050258999999997	625504, Тюменская область, Тюменский район, п. Боровский, ул. Октябрьская, д. 3	Россия, Тюменская область, поселок Боровский, улица Октябрьская	0101000020E610000074D3669C866D504032AA0CE36E864C40
5759	6	57	1718	24526	41915	\N	57.401287000000004	626050, Тюменская область, Ярковский район, с. Ярково, ул. Полевая, 9		0101000020E61000004432E4D87AC45040ADA7565F5DB34C40
5758	6	57	1718	24526	42076	\N	57.401287000000004	626050, Тюменская область, Ярковский район, с. Ярково, ул. Пионерская, 96		0101000020E61000004432E4D87AC45040ADA7565F5DB34C40
5760	6	57	1718	24526	42090	\N	57.401287000000004	626050, Тюменская область, Ярковский район, с. Ярково, ул. Мира, 27		0101000020E61000004432E4D87AC45040ADA7565F5DB34C40
5756	6	57	1718	24407	42250	\N	57.457605000000001	626066, Тюменская область, Ярковский район, с. Щетково, ул. Береговая, 1а		0101000020E6100000DAC87553CAC4504038BEF6CC92BA4C40
5733	6	57	1718	23283	42573	\N	57.715733999999998	626068, Тюменская область, Ярковский район, д. Шатанова, ул. Зеленая, 11		0101000020E6100000C860C5A9D6D250405051F52B9DDB4C40
5751	6	57	1718	24169	42481	\N	57.140768000000001	626057, Тюменская область, Ярковский район, с. Чечкино, ул. Мира, 83		0101000020E6100000AF0793E2E3BA5040632992AF04924C40
5736	6	57	1718	23445	77911	\N	57.776058999999997	626076, Тюменская область, Ярковский район, п. УстьТавда, ул. Мира, 13		0101000020E6100000C3B645990DCA50401B62BCE655E34C40
5740	6	57	1718	23614	42478	\N	57.318480999999998	626054, Тюменская область, Ярковский район, с. Усалка, ул. Школьная, 2		0101000020E61000007A3881E9B4BD5040DDB243FCC3A84C40
5750	6	57	1718	24100	42480	\N	57.117097999999999	626057, Тюменская область, Ярковский район, с. Староалександровка, ул. Советская, 13		0101000020E61000007EAB75E272BC5040A8363811FD8E4C40
5754	6	57	1718	24316	42492	\N	57.828893000000001	626075, Тюменская область, Ярковский район, с. Сорокино, ул. Центральная, 2		0101000020E61000000150C58D5BDE50401171732A19EA4C40
5741	6	57	1718	23681	41900	\N	57.240499999999997	626053, Тюменская область, Ярковский район, с. Покровское, ул. Советская, 66		0101000020E610000070EA03C93BB25040105839B4C89E4C40
5734	6	57	1718	23344	42483	\N	57.788904000000002	626076, Тюменская область, Ярковский район, с. Плеханово, ул. Школьная, 8		0101000020E610000016DA39CD02C3504080D767CEFAE44C40
5757	6	57	1718	24449	77890	\N	57.501990999999997	626066, Тюменская область, Ярковский район, д. Петропавловка, ул. Гагарина, 19		0101000020E61000001A16A3AEB5B7504073F1B73D41C04C40
5743	6	57	1718	23766	42575	\N	57.536574000000002	626069, Тюменская область, Ярковский район, с. Новоселово, ул. Центральная, 12		0101000020E61000003673486AA1CC504024F1F274AEC44C40
5745	6	57	1718	23870	42484	\N	57.487533999999997	626063, Тюменская область, Ярковский район, с. Новоалександровка, ул. Центральная, 57		0101000020E6100000C8B60C384BF4504012D89C8367BE4C40
5753	6	57	1718	24268	42485	\N	57.131683000000002	626061, Тюменская область, Ярковский район, д. Мотуши, ул. Центральная, 16		0101000020E6100000FD321823129F5040373811FDDA904C40
5748	6	57	1718	24015	42392	\N	57.321105644776402	626060, Тюменская область, Ярковский район, с. Маранка, ул. Школьная, 19	Россия, Тюменская область, Ярковский район, село Маранка	0101000020E6100000B5368DEDB5CA504052465C001AA94C40
5749	6	57	1718	24049	42576	\N	57.228516748673997	626057, Тюменская область, Ярковский район, д. Карбаны, ул. Школьная, 8	Россия, Тюменская область, Ярковский район, село Карбаны	0101000020E610000089EDEE01BABF50403ECA880B409D4C40
5738	6	57	1718	23539	42479	\N	57.6541	626073, Тюменская область, Ярковский район, с. Караульнояр, ул. Советская, 24		0101000020E6100000BB7D569929CF504024287E8CB9D34C40
5742	6	57	1718	23727	42577	\N	57.575144999999999	626069, Тюменская область, Ярковский район, с. Иевлево, ул. Водопроводная, 7		0101000020E6100000C66D3480B7C950409DBAF2599EC94C40
5752	6	57	1718	24190	42372	\N	57.173625000000001	626061, Тюменская область, Ярковский район, с. Дубровное, ул. Центральная, 5		0101000020E6100000915F3FC406A550404E62105839964C40
5731	6	57	1718	23193	77046	\N	57.612040999999998	626077, Тюменская область, Ярковский район, с. Гилево, ул. Центральная, 31		0101000020E6100000546F0D6C95C55040D367075C57CE4C40
5744	6	57	1718	23810	42335	\N	57.444699999999997	626069, Тюменская область, Ярковский район, д. Варвара, ул. Школьная, 23		0101000020E610000091D0967329CF5040FE43FAEDEBB84C40
5735	6	57	1718	23395	77986	\N	57.742707000000003	626076, Тюменская область, Ярковский район, д. Большой Краснояр, ул. Краснознаменная, 15		0101000020E61000004DD9E90775C8504051C1E10511DF4C40
5732	6	57	1718	23249	42570	\N	57.740743000000002	626068, Тюменская область, Ярковский район, д. Аксарина, ул. Сосновая, 3		0101000020E610000065E08096AED05040D7DEA7AAD0DE4C40
5712	6	57	1641	20691	\N	\N	56.652268999999997	627013, Тюменская область, г. Ялуторовск, ул. Советская, 76	Россия, Тюменская область, Ялуторовский район, город Ялуторовск	0101000020E61000000074982F2F935040E998F38C7D534C40
5714	6	57	1641	20691	41991	\N	56.652268999999997	627013, Тюменская область, г. Ялуторовск, ул. Комсомольская, 63 (учебный корпус)		0101000020E61000000074982F2F935040E998F38C7D534C40
5702	6	57	1641	21912	77893	\N	56.641184000000003	627025, Тюменская область, Ялуторовский район, д. Южная, ул. Береговая, 16		0101000020E61000000514EAE9237F5040F75B3B5112524C40
5706	6	57	1641	22090	77982	\N	56.711300000000001	627032, Тюменская область, Ялуторовский район, д. Черемушки, ул. Центральная, 9		0101000020E610000088F37002D37D504089D2DEE00B5B4C40
5696	6	57	1641	21615	42488	\N	56.711696000000003	627040, Тюменская область, Ялуторовский район, с. Хохлово, ул. Мира, 36		0101000020E61000003410CB660E985040D658C2DA185B4C40
5694	6	57	1641	21506	77851	\N	56.770204	627037, Тюменская область, Ялуторовский район, с. Старый Кавдык, пер. Советский, 17		0101000020E6100000E5637781928E5040CB9F6F0B96624C40
5699	6	57	1641	21751	42477	\N	56.675924999999999	627036, Тюменская область, Ялуторовский район, д. Прогресс, пер. Луговой, 4		0101000020E6100000E49EAEEE588C50403FC6DCB584564C40
5698	6	57	1641	21693	42326	\N	56.604593455965897	627036, Тюменская область, Ялуторовский район, с. Памятное, ул. Ворошилова, 22	Россия, Тюменская область, Ялуторовский район, поселок Памятное	0101000020E6100000CFBF5DF6EB915040FD31AD4D634D4C40
5695	6	57	1641	21564	77850	\N	56.801977000000001	627037, Тюменская область, Ялуторовский район, д. Новый Кавдык, ул. Новая, 20		0101000020E61000002C67EF8CB69450407592AD2EA7664C40
5684	6	57	1641	21050	42324	\N	57.029015000000001	627050, Тюменская область, Ялуторовский район, с. Новоатьялово, ул. Школьная, 26		0101000020E61000004FAE2990D9AA5040F60B76C3B6834C40
5697	6	57	1641	21648	42571	\N	56.684629366709302	627040, Тюменская область, Ялуторовский район, д. Криволукская, ул. Гагарина, 2	Россия, Тюменская область, Ялуторовский район, село Криволукская	0101000020E6100000178046E9D29A504054724EECA1574C40
5709	6	57	1641	61256	77804	\N	56.785460628145401	627033, Тюменская область, Ялуторовский район, с. Киево, ул. Строителей, 1а		0101000020E6100000CF328B506C7D504048A46DFC89644C40
5708	6	57	1641	22193	78111	\N	56.799112999999998	627039, Тюменская область, Ялуторовский район, с. Карабаш, ул. Школьная, 1		0101000020E6100000B4C876BE9F8650407B67B45549664C40
5701	6	57	1641	21852	42482	\N	56.640258000000003	627045, Тюменская область, Ялуторовский район, с. Зиново, ул. Победы, 67б		0101000020E6100000A3E6ABE4638850404E8061F9F3514C40
5682	6	57	1641	20931	9939	\N	57.035995	627043, Тюменская область, Ялуторовский район, с. Большое Тихвино, ул. Русанова, 14		0101000020E6100000F870C971A7AE5040E6E8F17B9B844C40
5705	6	57	1641	22055	42247	\N	56.741883999999999	627032, Тюменская область, Ялуторовский район, с. Беркут, ул. Первомайская, 35		0101000020E6100000BEBD6BD0978350407CB60E0EF65E4C40
5693	6	57	1641	21462	77912	\N	56.812285049443297	627041, Тюменская область, Ялуторовский район, с. Бердюгино, ул. Набережная, 3	Россия, Тюменская область, Ялуторовский район, село Бердюгино	0101000020E6100000FF3F4E98309A5040040473F4F8674C40
5685	6	57	1641	21098	42370	\N	56.868689000000003	627042, Тюменская область, Ялуторовский район, с. Аслана, ул. Кирова, 33б		0101000020E610000021AE9CBD33A150408EB27E33316F4C40
5700	6	57	1641	21816	78110	\N	56.692289000000002	627036, Тюменская область, Ялуторовский район, д. Анисимовка, ул. Школьная, 3		0101000020E6100000B741EDB776935040B6300BED9C584C40
5676	6	57	1503	17510	42323	\N	56.819541129192999	627250, Тюменская область, Юргинский район, с. Юргинское, ул. Северная, д. 1	Россия, Тюменская область, Юргинский район, село Юргинское	0101000020E61000004D840D4FAFD85040965D30B8E6684C40
5678	6	57	1503	17510	77053	\N	56.820341277457203	627251, Тюменская область, Юргинский район, с. Юргинское, ул. Набережная, д. 29	Россия, Тюменская область, Юргинский район, село Юргинское	0101000020E6100000253CA1D79FD85040B24813EF00694C40
5675	6	57	1503	17510	41954	\N	56.820715	627250, Тюменская область, Юргинский район, с. Юргинское, ул. Ленина, д. 70		0101000020E61000007364E597C1D85040172B6A300D694C40
5617	6	57	1503	17510	42320	\N	56.820715	627250, Тюменская область, Юргинский район, с. Юргинское, ул. Жукова, д. 9		0101000020E61000007364E597C1D85040172B6A300D694C40
5674	6	57	1503	20485	42473	\N	56.8498478083146	627261, Тюменская область, Юргинский район, с. Шипаково, ул. Ленина,, д. 28	Россия, Тюменская область, Юргинский район, село Шипаково	0101000020E610000028BA2EFCE0E850401749BBD1C76C4C40
5673	6	57	1503	20471	77853	\N	56.839404999999999	627256, Тюменская область, Юргинский район, д. Соколова, ул. Дениса Бобова, д. 22		0101000020E61000007847C66AF3FA5040A88C7F9F716B4C40
5665	6	57	1503	19965	77976	\N	56.735095999999999	627258, Тюменская область, Юргинский район, д. Синьга, ул. 30 лет Победы, д. 1		0101000020E6100000F4893C49BAC45040D0B52FA0175E4C40
5671	6	57	1503	20362	42369	\N	56.866765699090401	627264, Тюменская область, Юргинский район, с. СевероПлетнево, ул. Ленина,, д. 36	Россия, Тюменская область, Юргинский район, поселок Северо-Плетнево	0101000020E610000033A7CB626204514072A43330F26E4C40
5679	6	57	1503	20802	78107	\N	56.807388000000003	627250, Тюменская область, Юргинский район, д. Палецкая, ул. Колхозная, д. 44		0101000020E6100000A8A624EB70DB504068976F7D58674C40
5669	6	57	1503	20224	78200	\N	57.045808999999998	627240, Тюменская область, Юргинский район, с. Новый Тап, ул. Центральная, д. 5		0101000020E610000020B8CA1308EF5040656EBE11DD854C40
5670	6	57	1503	20224	42474	\N	57.045808999999998	627241, Тюменская область, Юргинский район, с. Новый Тап, ул. Заречная, д. 38		0101000020E610000020B8CA1308EF5040656EBE11DD854C40
5668	6	57	1503	20137	42321	\N	56.931607999999997	627270, Тюменская область, Юргинский район, с. Лесное, ул. Лесная, д. 1		0101000020E6100000EE7BD45FAFCF5040925852EE3E774C40
5666	6	57	1503	20043	42572	\N	56.875039280100097	627262, Тюменская область, Юргинский район, с. Лабино, ул. Ленина, д. 5		0101000020E6100000C3D8429083F25040BEDC274701704C40
5680	6	57	1503	20823	\N	\N	56.835968000000001	627251, Тюменская область, Юргинский район, д. Заозерная, д. 63б		0101000020E6100000AB7AF99D26D550405340DAFF006B4C40
5664	6	57	1503	19922	42568	\N	56.737924835719902	627259, Тюменская область, Юргинский район, с. Володино, ул. Кирова, д. 24	Россия, Тюменская область, Юргинский район, село Володино	0101000020E610000024EF1CCA50E050404DF38E53745E4C40
5663	6	57	1503	19868	42567	\N	56.732601510200901	627268, Тюменская область, Юргинский район, с. Бушуево, ул. Береговая, д. 23	Россия, Тюменская область, Юргинский район, село Бушуево	0101000020E61000002D077AA86DD65040FA7DFFE6C55D4C40
5661	6	57	1503	19757	42471	\N	56.970151999999999	627263, Тюменская область, Юргинский район, с. Агарак, ул. Малахова, д. 66		0101000020E6100000B306EFAB72FC50401213D4F02D7C4C40
5658	6	57	1508	19597	77883	\N	56.370542999999998	627180, Тюменская область, Упоровский район, д. Шашова, ул. Речная, д. 24		0101000020E6100000F0879FFF1E9350408061F9F36D2F4C40
5657	6	57	1508	19546	42312	\N	56.336512999999997	627180, Тюменская область, Упоровский район, д. Черная. ул. Молодежная, д. 13		0101000020E610000016359886E1945040E4D6A4DB122B4C40
4708	6	57	657	4461	41906	\N	56.112282	627750, Тюменская область, г. Ишим, ул. 30 лет ВЛКСМ, 28		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5659	6	57	1508	19647	77886	\N	56.415196000000002	627180, Тюменская область, Упоровский район, д. Чащина, ул. Центральная, д. 3		0101000020E6100000D5AF743E3C9450400BB77C2425354C40
5655	6	57	1508	19388	41953	\N	56.314126999999999	627180, Тюменская область, Упоровский район, с. Упорово, ул. Строителей, 21		0101000020E6100000E259828C8091504032E5435035284C40
5654	6	57	1508	19388	42074	\N	56.314126999999999	627180, Тюменская область, Упоровский район, с. Упорово ул. Крупской, д. 29		0101000020E6100000E259828C8091504032E5435035284C40
5656	6	57	1508	19388	42244	\N	56.314126999999999	627180, Тюменская область, Упоровский район, с. Упорово, ул. Дзержинского, 1		0101000020E6100000E259828C8091504032E5435035284C40
5653	6	57	1508	19332	42566	\N	56.259393000000003	627182, Тюменская область, Упоровский район, д. Тютрина, ул. Школьная, д. 19		0101000020E6100000B329577897845040DAE731CA33214C40
5652	6	57	1508	19304	42309	\N	56.252525287247202	627182, Тюменская область, Упоровский район, с. Суерка, ул. 30 лет Победы, д. 4	Россия, Тюменская область, Упоровский район, поселок Суерка	0101000020E6100000EDF2AD0FEB81504011363CBD52204C40
5642	6	57	1508	18760	77975	\N	56.148136999999998	627190, Тюменская область, Упоровский район, с. Слободчики, ул. Садовая, 20А		0101000020E6100000DD7A4D0F0AA45040ED293927F6124C40
5650	6	57	1508	19189	77977	\N	56.255327000000001	627186, Тюменская область, Упоровский район, с. Скородум, ул. Цетральная, д. 11		0101000020E6100000ED0C535BEA89504095641D8EAE204C40
5648	6	57	1508	19078	42310	\N	56.150354	627191, Тюменская область, Упоровский район, с. Пятково, ул. Вишнякова, д. 6		0101000020E61000009CFBABC77DB150405169C4CC3E134C40
5634	6	57	1508	18309	77764	\N	56.111789999999999	627190, Тюменская область, Упоровский район, п. Октябрьский, ул. Новая, 10		0101000020E61000004F948444DA9D50408A027D224F0E4C40
5644	6	57	1508	18861	42565	\N	56.123878698351298	627189, Тюменская область, Упоровский район, с. Одино, ул. Северная, 45	Россия, Тюменская область, Упоровский район, село Одино	0101000020E6100000562AA8A8FA805040A2D45E44DB0F4C40
5641	6	57	1508	18726	78100	\N	56.426622000000002	627183, Тюменская область, Упоровский район, д. Нифаки, ул. Шоссейная, 14		0101000020E610000013622EA9DA75504087E0B88C9B364C40
5647	6	57	1508	19044	77950	\N	56.048817	627194, Тюменская область, Упоровский район, с. Нижнеманай, ул. Нижнеманайская, 65		0101000020E6100000C520B07268B15040923EADA23F064C40
5623	6	57	1508	17820	42470	\N	56.159143	627187, Тюменская область, Упоровский район, с. Морево, ул. Заречная, 8		0101000020E610000082751C3F5491504094313ECC5E144C40
5627	6	57	1508	18016	42243	\N	56.074471907435402	627196, Тюменская область, Упоровский район, с. Масали, пер. Новый, 5	Россия, Тюменская область, Упоровский район, село Масали	0101000020E6100000A514747B49A45040DE3B6A4C88094C40
5631	6	57	1508	18206	77846	\N	56.108196	627196, Тюменская область, Упоровский район, д. Маркова, ул. Набережная 15		0101000020E61000000DC1711937A450406DC7D45DD90D4C40
5640	6	57	1508	61281	78186	\N	56.374786678930803	627183, Тюменская область, Упоровский район, д. Лыкова, ул. Заречная, 16	Россия, Тюменская область, Упоровский район, село Лыково	0101000020E610000073F1B73D417A5040A4FB3905F92F4C40
5646	6	57	1508	18958	42468	\N	56.364235999999998	627184, Тюменская область, Упоровский район, с. Липиха, ул. Центральная, 3		0101000020E610000038BD8BF7E36F50404F0306499F2E4C40
5649	6	57	1508	19152	42469	\N	56.163930000000001	627191, Тюменская область, Упоровский район, с. Киселево, ул. Семкова, д. 27		0101000020E61000009AEB34D252B95040A96A82A8FB144C40
5630	6	57	1508	18139	78102	\N	56.051718000000001	627196, Тюменская область, Упоровский район, п. Кизак, ул. Кизакская, 16А		0101000020E61000006CB41CE8A1A55040A94E07B29E064C40
5636	6	57	1508	18438	78097	\N	56.199410442941698	627190, Тюменская область, Упоровский район, д. Кашаир, ул. Центральная, 26	Россия, Тюменская область, Упоровский район, село Кашаир	0101000020E6100000973C9E961F9E5040683F524486194C40
5639	6	57	1508	18624	42563	\N	56.424062999999997	627183, Тюменская область, Упоровский район, . Ингалинское, ул. Школьная, 8		0101000020E61000004A7A185A9D7C5040C93846B247364C40
5633	6	57	1508	18304	42365	\N	56.153046000000003	627190, Тюменская область, Упоровский район, п. Емуртлинский, ул. Нохрина, 6		0101000020E61000006281AFE8D69F50404E64E60297134C40
5632	6	57	1508	18229	42246	\N	56.1574667133346	627196, Тюменская область, Упоровский район, с. Емуртла, ул. Свободы, 17А	Россия, Тюменская область, Упоровский район, село Емуртла	0101000020E610000070B378B1309E50408099EFE027144C40
5635	6	57	1508	18229	42493	\N	56.1578978116667	627190, Тюменская область, Упоровский район, с. Емуртла, ул. Ленинградская, 15А	Россия, Тюменская область, Упоровский район, село Емуртла	0101000020E61000002384471B479E50404A0D6D0036144C40
5629	6	57	1508	18109	78059	\N	56.010775000000002	627196, Тюменская область, Упоровский район, п. Дубровинский, ул. Заречная, 4		0101000020E610000016FC36C478A15040A54E401361014C40
5628	6	57	1508	18033	78055	\N	56.034148999999999	627196, Тюменская область, Упоровский район, д. Видонова, ул. Советская, 17		0101000020E61000006F0F4240BEA65040761893FE5E044C40
5624	6	57	1508	17845	42518	\N	56.308418462814302	627181, Тюменская область, Упоровский район, с. Бызово, ул. Советская, 28	Россия, Тюменская область, Упоровский район, село Бызово	0101000020E61000005EF6EB4E778C5040B6BFB33D7A274C40
5620	6	57	1508	17643	42393	\N	56.172460000000001	627187, Тюменская область, Упоровский район, с. Буньково, ул. 50 лет Октября, 19		0101000020E6100000BE840A0E2F88504020EF552B13164C40
5606	6	57	1464	16942	41986	\N	59.143993000000002	626170, Тюменская область, Уватский район, с. Уват, ул. Ленина, д. 88		0101000020E6100000D3D9C9E0283951402DEDD45C6E924D40
5607	6	57	1464	16942	42467	\N	59.143993000000002	626170, Тюменская область, Уватский район, с. Уват, ул. Иртышская, д. 19		0101000020E6100000D3D9C9E0283951402DEDD45C6E924D40
5610	6	57	1464	17114	41950	\N	58.940246999999999	626191, Тюменская область, Уватский район, п. Туртас, ул. Школьная, д. 2		0101000020E61000001827BEDA51485140C09481035A784D40
5386	6	57	624	6474	42462	\N	56.954517000000003	625530, Тюменская область, Тюменский район, с. Богандинское, ул. Садовая, д. 1		0101000020E6100000E2CD1ABCAF745040EF3CF19C2D7A4C40
5611	6	57	1464	17114	42472	\N	58.931296380855201	626190, Тюменская область, Уватский район, п. Туртас, ст. ЮностьКомсомольская, д. 21	Россия, Тюменская область, Уватский район, поселок Туртас	0101000020E6100000876C205D6C485140A47213B534774D40
5614	6	57	1464	17321	42562	\N	59.432524000000001	626181, Тюменская область, Уватский район, д. Солянка, ул. Центральная, д. 12		0101000020E6100000EF8FF7AA953E5140185E49F25CB74D40
5613	6	57	1464	17307	42506	\N	59.350121999999999	626182, Тюменская область, Уватский район, п. Першино, ул. Мира, д. 6		0101000020E61000001A19E42EC23A514018CE35CCD0AC4D40
5612	6	57	1464	17224	42564	\N	59.270392999999999	626180, Тюменская область, Уватский район, с. Осинник, ул. Комсомольская, д. 8		0101000020E6100000F12E17F19D3551409E08E23C9CA24D40
5609	6	57	1464	55090	42586	\N	59.132812999999999	626178, Тюменская область, Уватский район, п. Нагорный, ул. Нефтяников, д. 9А/2	Россия, Тюменская область, Уватский район, поселок Нагорный	0101000020E6100000FA9AE5B2D1415140E8BD310400914D40
5619	6	57	1464	17610	\N	\N	59.806114999999998	626194, Тюменская область, Уватский район, п. Муген, д. 42		0101000020E61000007A354069A8B2514053E8BCC62EE74D40
5604	6	57	1464	16830	42465	\N	58.865506000000003	626174, Тюменская область, Уватский район, с. Красный Яр, ул. Стивы Дорониной, д. 3		0101000020E61000004AD235936F255140F33E8EE6C86E4D40
5608	6	57	1464	17031	42391	\N	59.084018	626195, Тюменская область, Уватский район, с. Ивановка, ул. Орджоникидзе, д. 9		0101000020E61000000A698D41273951403E23111AC18A4D40
5615	6	57	1464	17399	41987	\N	59.595841999999998	626184, Тюменская область, Уватский район, с. Демьянское, ул. НПС, д. 27		0101000020E6100000145E82531F545140A7CAF78C44CC4D40
5618	6	57	1464	17521	41992	\N	59.542517645954199	626194, Тюменская область, Уватский район, п. Демьянка, мкр. Железнодорожный, д. 15	Россия, Тюменская область, Уватский район, поселок Демьянка	0101000020E6100000E3E313B2F37F5140E4BED53A71C54D40
5602	6	57	1464	16729	42463	\N	58.761407597528503	626176, Тюменская область, Уватский район, c. Горнослинкино, ул. Северная, д. 5	Россия, Тюменская область, Уватский район, село Горнослинкино	0101000020E6100000CC4065FCFB325140D6743DD175614D40
5605	6	57	1464	16910	77984	\N	59.024766	626192, Тюменская область, Уватский район, с. Алымка, ул. Центральная, д. 12Б		0101000020E61000003F58C6866E335140C00644882B834D40
5370	6	57	624	5639	42396	\N	57.318539000000001	625512, Тюменская область, Тюменский район, д. Янтык, ул. Молодежная, д 8		0101000020E61000000186E5CFB777504012C0CDE2C5A84C40
5342	6	57	624	4147	77907	\N	57.129548	625537, Тюменская область, Тюменский район, д. Якуши, ул. Полевая, д. 1		0101000020E61000006458C51B9981504090A1630795904C40
5352	6	57	624	4693	77816	\N	57.154693000000002	625513, Тюменская область, Тюменский район, с. Щербак, ул. Трактовая, д. 17		0101000020E61000007CF0DAA50D905040C7F5EFFACC934C40
5341	6	57	624	4035	42024	\N	57.147413999999998	625537, Тюменская область, Тюменский район, с. Чикча, ул. Гагарина, д. 16		0101000020E6100000A8C30AB77C7E50407C7C4276DE924C40
5340	6	57	624	4026	41901	\N	56.942459999999997	625519, Тюменская область, Тюменский район, с. Червишево, ул. Юбилейный квартал, д. 2		0101000020E6100000A3957B81595B5040E2E47E87A2784C40
5401	6	57	624	7197	78150	\N	56.973022	625503, Тюменская область, Тюменский район, д. Чаплык, пер. Центральный, д. 11		0101000020E6100000A646E867EA445040EE2422FC8B7C4C40
5395	6	57	624	6900	42317	\N	57.082526999999999	625502, Тюменская область, Тюменский район, д. Ушакова, ул. Новая, д. 2		0101000020E6100000F910548D5E4A5040BC04A73E908A4C40
5399	6	57	624	7095	42130	\N	57.077720498261499	625503, Тюменская область, Тюменский район, с. Успенка, ул. Коммунаров, д. 3	Россия, Тюменская область, Тюменский район, село Успенка	0101000020E6100000BE1248895D455040601F9DBAF2894C40
5367	6	57	624	5477	77059	\N	57.151167999999998	625511, Тюменская область, Тюменский район, д. Тураева, ул. Аширбекова, д. 69		0101000020E610000054573ECBF3735040D219187959934C40
5501	6	57	624	55087	42133	\N	57.009225835820999	625058, Тюменская область, г. Тюмень, п. Тараскуль, ул. Санаторная, 6		0101000020E610000045F64196055D5040EE224C512E814C40
5378	6	57	624	6060	77818	\N	57.115763999999999	625517, Тюменская область, Тюменский район, д. Субботина, ул. Школьная, д. 5а		0101000020E610000087A3AB7477755040EE06D15AD18E4C40
5398	6	57	624	7061	42129	\N	57.142555000000002	625514, Тюменская область, Тюменский район, с. Созоново, ул. Молодежная, 2		0101000020E610000067EE21E17B935040CE70033E3F924C40
5397	6	57	624	7001	42284	\N	57.377256033289903	625550, Тюменская область, Тюменский район, с. Салаирка, ул. Новая, 35	Россия, Тюменская область, Тюменский район, поселок Салаирка	0101000020E61000005F268A90BA405040221CB3EC49B04C40
5387	6	57	624	6505	42490	\N	56.967948999999997	625530, Тюменская область, Тюменский район, д. Пышминка, ул. Береговая, д. 27		0101000020E6100000FD69A33A1D7850401399B9C0E57B4C40
5396	6	57	624	61279	78173	\N	57.127261537087598	625502, Тюменская область, Тюменский район, п. Подъем, ул. Лесная, д. 25 кв. 2	Россия, Тюменская область, Тюменский район, село Подъем	0101000020E610000041295AB9174C50400403081F4A904C40
5394	6	57	624	6863	42127	\N	57.083255999999999	625502, Тюменская область, Тюменский район, с. Перевалово, ул. Школьная, д. 13		0101000020E6100000FF23D3A1D34E50400F99F221A88A4C40
5382	6	57	624	6276	77743	\N	57.083309999999997	625501, Тюменская область, Тюменский район, д. Падерина, ул. Озерная, д. 8		0101000020E6100000CFBD874B8E5C504002B7EEE6A98A4C40
5393	6	57	624	6813	42124	\N	56.923645999999998	625547, Тюменская область, Тюменский район, с. Онохино, ул. Касьянова, д. 22а		0101000020E6100000CBBC55D7A1625040658A39083A764C40
5373	6	57	624	5790	\N	\N	57.173502999999997	625512, Тюменская область, Тюменский район, п. Новотуринский	Россия, Тюменская область, Тюменский район, село Новотуринский	0101000020E6100000EDD808C4EB7750400261A75835964C40
5390	6	57	624	6691	42034	\N	57.284496830773399	625509, Тюменская область, Тюменский район, п. Новотарманский, ул. Центральная, д. 56	Россия, Тюменская область, Тюменский район, поселок Новотарманский	0101000020E6100000077AA86DC34E5040B267CF656AA44C40
5384	6	57	624	6386	42308	\N	57.003060876656697	625531, Тюменская область, Тюменский район, с. Муллаши, ул. Советская, 2	Россия, Тюменская область, Тюменский район, село Муллаши	0101000020E61000007E5182FE428550405072874D64804C40
5380	6	57	624	6090	42122	\N	57.109859999999998	625501, Тюменская область, Тюменский район, п. Московский, ул. Озерная, д. 8		0101000020E6100000D1764CDD955B5040BC9179E40F8E4C40
5392	6	57	624	6780	42459	\N	57.285815999999997	625509, Тюменская область, Тюменский район, д. Молчанова, ул. Приозерная, д. 22		0101000020E6100000B4E386DF4D4B50403656629E95A44C40
5405	6	57	624	7402	42505	\N	56.955081247635597	625519, Тюменская область, Тюменский район, с. Мичурино, ул. Центральная, д. 64	Россия, Тюменская область, Тюменский район, село Мичурино	0101000020E61000008F6FEF1AF44B5040F7031E18407A4C40
5389	6	57	624	6613	78043	\N	56.855034000000003	625530, Тюменская область, Тюменский район, д. Марай, ул. Школьная, д. 31		0101000020E61000005D6A847EA6815040EA7B0DC1716D4C40
5377	6	57	624	5972	41905	\N	57.125053000000001	625517, Тюменская область, Тюменский район, с. Мальково, ул. Совхозная, д. 23		0101000020E610000093E52494BE77504023A298BC01904C40
5402	6	57	624	7272	78034	\N	57.105901000000003	625503, Тюменская область, Тюменский район, д. Малиновка, ул. Центральная, д. 13		0101000020E6100000D66EBBD05C4450408ECEF9298E8D4C40
5376	6	57	624	5966	42033	\N	57.218029999999999	625526, Тюменская область, Тюменский район, с. Луговое, ул. 60 лет Октября, д. 9		0101000020E61000001C446B459B56504000C63368E89B4C40
5406	6	57	624	7445	42560	\N	56.835963	625519, Тюменская область, Тюменский район, с. Леваши, ул. Рабочая, д. 32		0101000020E6100000936E4BE48258504041D5E8D5006B4C40
5369	6	57	624	5565	77843	\N	57.246397000000002	625525, Тюменская область, Тюменский район, с. Кулига, ул. Транспортная, д. 37		0101000020E6100000A20A7F8637455040906AD8EF899F4C40
5375	6	57	624	5891	41981	\N	57.225832148118698	625526, Тюменская область, Тюменский район, с. Кулаково, ул. Семеновых, д. 80	Россия, Тюменская область, Тюменский район, село Кулаково	0101000020E6100000A1D634EF38515040F4311F10E89C4C40
5343	6	57	624	4195	42245	\N	57.123905000000001	625537, Тюменская область, Тюменский район, д. Криводанова, ул. Центральная, д. 9		0101000020E610000074EFE192E38C5040CB67791EDC8F4C40
5374	6	57	624	5842	42501	\N	56.878841999999999	625056, Тюменская область, Тюменский район, с. Княжево, ул. Ленина, д. 1а		0101000020E610000054E3A59BC46F5040F52C08E57D704C40
5371	6	57	624	5703	41980	\N	57.178334	625512, Тюменская область, Тюменский район, с. Каскара, ул. Школьная, д. 12		0101000020E6100000BB0B9414587B5040E7E104A6D3964C40
5372	6	57	624	5703	42121	\N	57.178334	625512, Тюменская область, Тюменский район, с. Каскара, ул. Ленина, д. 5		0101000020E6100000BB0B9414587B5040E7E104A6D3964C40
5368	6	57	624	5526	41979	\N	57.258195000000001	625525, Тюменская область, Тюменский район, с. Каменка ул. Новая, 17		0101000020E6100000656D533C2E485040D07EA4880CA14C40
5400	6	57	624	7149	42242	\N	57.1366230920435	625503, Тюменская область, Тюменский район, д. Зырянка, ул. Гагарина, д. 11	Россия, Тюменская область, Тюменский район, село Зырянка	0101000020E6100000890AD5CDC5415040D270CADC7C914C40
5388	6	57	624	6599	42561	\N	56.977040000000002	625530, Тюменская область, Тюменский район, д. Железный Перебор, ул. Мира, д. 10		0101000020E610000076FBAC325381504022718FA50F7D4C40
5365	6	57	624	5359	42119	\N	57.150739000000002	625511, Тюменская область, Тюменский район, с. Ембаево, ул. М. Джалиля, д. 74		0101000020E61000006DE690D442715040AA9D616A4B934C40
5404	6	57	624	7346	77819	\N	56.962060999999999	625519, Тюменская область, Тюменский район, д. Друганова, ул. Школьная, д. 15		0101000020E61000000EBE30992A555040E7E099D0247B4C40
5381	6	57	624	6194	42489	\N	57.082163726640403	625501, Тюменская область, Тюменский район, с. Гусево, ул. Рабочая, д. 1а	Россия, Тюменская область, Тюменский район, село Гусево	0101000020E6100000645DDC46035450404B749659848A4C40
5364	6	57	624	5329	41977	\N	57.139291695740603	625535, Тюменская область, Тюменский район, с. Горьковка, ул. Сибирская, д. 12	Россия, Тюменская область, Тюменский район, поселок Горьковка	0101000020E610000014596B28B5505040164CFC51D4914C40
5359	6	57	624	55077	41942	\N	56.955686	625530, Тюменская область, Тюменский район, п. Винзили, ул. Первомайская, д. 3		0101000020E61000009738F240647150405E9F39EB537A4C40
5360	6	57	624	55077	42123	\N	56.968359229107797	625530, Тюменская область, Тюменский район, п. Винзили, ул. Комсомольская, д. 1		0101000020E6100000A5D7666325715040C5E40D30F37B4C40
5358	6	57	624	55077	41976	\N	56.955686	625530, Тюменская область, Тюменский район, п. Винзили, ул. Заводская, д. 18а		0101000020E61000009738F240647150405E9F39EB537A4C40
5361	6	57	624	55077	41948	\N	56.955686	625530, Тюменская область, Тюменский район, п. Винзили, ул. Вокзальная, д. 74		0101000020E61000009738F240647150405E9F39EB537A4C40
5362	6	57	624	55077	42118	\N	56.955686	625530, Тюменская область, Тюменский район, п. Винзили, ул. 60 лет Октября, д. 1		0101000020E61000009738F240647150405E9F39EB537A4C40
5355	6	57	624	55073	42125	\N	57.046201272455001	625504, Тюменская область, Тюменский район, п. Боровский, ул. Советская, д. 12		0101000020E6100000A05225CADE6D5040710514EAE9854C40
5353	6	57	624	55073	41941	\N	57.0503801486527	625504, Тюменская область, Тюменский район, п. Боровский, ул. Мира, д. 14		0101000020E61000006BF12900C66C5040AD2F12DA72864C40
5356	6	57	624	55073	42131	\N	57.045579398369398	625504, Тюменская область, Тюменский район, п. Боровский, ул. Ленинградская, д. 7	Россия, Тюменская область, поселок Боровский, улица Ленинградская	0101000020E61000006A6B44300E6E504033315D88D5854C40
5357	6	57	624	55073	41898	\N	57.045020000000001	625504, Тюменская область, Тюменский район, п. Боровский, ул. Герцена, д. 22а		0101000020E6100000A983BC1E4C6E50403DD52137C3854C40
5351	6	57	624	4633	42116	\N	57.174912999999997	625513, Тюменская область, Тюменский район, с. Борки, ул. Советская, 26		0101000020E61000004D2EC6C03A8450409752978C63964C40
5403	6	57	624	7281	77746	\N	56.951258000000003	625519, Тюменская область, Тюменский район, д. Большие Акияры, ул. Совхозная, д. 124		0101000020E6100000252367614F585040790778D2C2794C40
5349	6	57	624	55080	77146	\N	56.8875880242067	625521, Тюменская область, Тюменский район, п. Богандинский, п/о Сосновое, д. 2	Россия, Тюменская область, Тюменский район, поселок городского типа Богандинский	0101000020E6100000B3CF6394677850403929CC7B9C714C40
5346	6	57	624	55080	41971	\N	56.891268327503703	625521, Тюменская область, Тюменский район, п. Богандинский, ул. Юбилейная, д. 5б	Россия, Тюменская область, Тюменский район, поселок городского типа Богандинский	0101000020E6100000863DEDF0D778504054FCDF1115724C40
5345	6	57	624	55080	41971	\N	56.888950482633703	625521, Тюменская область, Тюменский район, п. Богандинский, ул. Юбилейная, д. 3а		0101000020E6100000CAA99D616A785040BDE3141DC9714C40
5347	6	57	624	55080	42025	\N	56.887603899043199	625521, Тюменская область, Тюменский район, п. Богандинский, п. Садовый, д. 1	Россия, Тюменская область, Тюменский район, поселок городского типа Богандинский	0101000020E61000000FB8AE98117950403FE603029D714C40
5344	6	57	624	4239	78210	\N	57.070417355094001	625516, Тюменская область, Тюменский район, п. Андреевский, пер. Лесной, д. 13	Россия, Тюменская область, Тюменский район, поселок Андреевский	0101000020E61000009D2FF65E7C7350408D0A9C6C03894C40
5333	6	57	54	1898	78204	\N	58.205188	626150, Тюменская область, г. Тобольск, Левобережье, ул. Раздольная, д. 1а		0101000020E6100000D9942BBCCB1451400DC4B299431A4D40
5334	6	57	54	1898	41975	\N	58.186661295376098	626150, Тюменская область, г. Тобольск, п. Сумкино, ул. Мира, д. 8		0101000020E6100000BF0B5BB3950F51402638F581E4174D40
5326	6	57	54	1898	41902	\N	58.195035151633903	626150, Тюменская область, г. Тобольск, ул. Ленина, д. 26	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E6100000AAD216D7F80F5140A54929E8F6184D40
5312	6	57	54	1898	9607	\N	58.213849270903403	"626150, Тюменская область, г. Тобольск, ул. Знаменского, д. 58 ""а"" "	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E610000042CF66D5E711514023A46E675F1B4D40
5335	6	57	54	1898	42018	\N	58.108152308831201	626150, Тюменская область, г. Тобольск, п. Сумкино, ул. Гагарина, д. 22	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E61000005F61C1FD801451409D7FBBECD70D4D40
5323	6	57	54	1898	41937	\N	58.222971146604898	626150, Тюменская область, г. Тобольск, 8 микрорайон, д. 8 а	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E610000078431A15381251406C7A50508A1C4D40
5303	6	57	54	1898	41982	\N	58.231429790357403	"626150, Тюменская область, г. Тобольск, 7 ""а"" микрорайон, д. 6 «а» "	Россия, Тюменская область, Тобольский район, город Тобольск	0101000020E610000040DD4081771151401AA88C7F9F1D4D40
5317	6	57	54	1898	41951	\N	58.178718855995498	"626150, Тюменская область, г. Тобольск, 10 ""б"" микрорайон, 53 "		0101000020E6100000AE80423D7D1051404016A243E0164D40
5270	6	57	54	32427	77812	\N	58.243751000000003	626159, Тюменская область, Тобольский район, д. Соколовка, ул. Тобольская, 13		0101000020E610000016F71F990E17514004AF963B331F4D40
5295	6	57	54	1466	77813	\N	58.148091999999998	626124, Тюменская область, Тобольский район, п. Сибиряк, ул. Советская, 3		0101000020E610000094675E0EBB1D51404D66BCADF4124D40
5297	6	57	54	1579	77817	\N	58.046787272115601	626104, Тюменская область, Тобольский район, с. Санниково, ул. Центральная, д. 27	Россия, Тюменская область, Тобольский район, село Санниково	0101000020E6100000077AA86DC32651406170CD1DFD054D40
5294	6	57	54	1449	41925	\N	58.171065695651102	626123, Тюменская область, Тобольский район, п. Прииртышский, ул. Советская 27	Россия, Тюменская область, Тобольский район, поселок Прииртышский	0101000020E6100000F7E5CC768516514091BA9D7DE5154D40
5267	6	57	54	32298	77932	\N	58.152214000000001	626125, Тюменская область, Тобольский район, с. Преображенка, ул. Береговая, д. 17		0101000020E610000058FFE7305F23514026FF93BF7B134D40
5296	6	57	54	1566	42557	\N	58.0353101532612	626127, Тюменская область, Тобольский район, д. Полуянова, ул. Первомайская, 10	Россия, Тюменская область, Тобольский район, село Полуянова	0101000020E61000007573F1B73D335140639CBF0985044D40
5273	6	57	54	162	77844	\N	58.269069999999999	626121, Тюменская область, Тобольский район, п. Октябрьский, ул. Зеленая, д. 14		0101000020E6100000D5CA845FEA2F5140D82AC1E270224D40
5289	6	57	54	1123	42303	\N	58.498958000000002	626136, Тюменская область, Тобольский район, д. Нижние Аремзяны, ул. Сибирская, 17		0101000020E6100000431EC18D94275140EE0912DBDD3F4D40
5290	6	57	54	1223	77972	\N	58.626069000000001	626139, Тюменская область, Тобольский район, п. Надцы, ул. Школьная, д. 3		0101000020E6100000B7CF2A33A52451400C056C0723504D40
5276	6	57	54	348	42388	\N	58.140177999999999	626102, Тюменская область, Тобольский район, д. Медянки Татарские, ул. Портовая, д. 10 А		0101000020E6100000B2BD16F4DE0D514031CF4A5AF1114D40
5298	6	57	54	1686	42390	\N	58.071390000000001	626104, Тюменская область, Тобольский район, д. Маслова, ул. Школьная, д. 1		0101000020E610000093AAED26F81A514077A1B94E23094D40
5288	6	57	54	1101	42241	\N	58.414530629972703	626142, Тюменская область, Тобольский район, с. Малая Зоркальцева, ул. Учителей, 16	Россия, Тюменская область, Тобольский район, село Малая Зоркальцева	0101000020E61000006DAB59677C195140CE16105A0F354D40
5283	6	57	54	805	42240	\N	57.833933999999999	626115, Тюменская область, Тобольский район, с. Кутарбитка, ул. Школьная, 27		0101000020E6100000D4D2DC0A61FE5040E0826C59BEEA4C40
5282	6	57	54	728	42460	\N	58.016314000000001	626113, Тюменская область, Тобольский район, д. Карачино, ул. Мира, 44 А		0101000020E610000067B796C970095140C53BC09316024D40
5291	6	57	54	1245	\N	\N	58.606820999999997	626139, Тюменская область, Тобольский район, п. Ингаир, д. 6		0101000020E61000006A85E97B0D31514054C37E4FAC4D4D40
5280	6	57	54	608	42499	\N	58.116969650573701	626126, Тюменская область, Тобольский район, д. Загваздина , ул. Молодежная, д. 23	Россия, Тюменская область, Тобольский район, село Загваздина	0101000020E6100000F487669E5C2B51407B4E7ADFF80E4D40
5281	6	57	54	665	77761	\N	58.097293000000001	626126, Тюменская область, Тобольский район, д. Епанчина, пер. Школьный, д. 9		0101000020E6100000709692E5242E51409B90D618740C4D40
5277	6	57	54	432	42306	\N	57.893710167418	626114, Тюменская область, Тобольский район, с. Дегтярево, ул. Цетральная, 41А	Россия, Тюменская область, Тобольский район, село Дегтярево	0101000020E61000005DDF878384055140D80DDB1665F24C40
5275	6	57	54	292	42458	\N	58.108254972453999	626102, Тюменская область, Тобольский район, с. Ворогушино, ул. Центральная 1	Россия, Тюменская область, Тобольский район, село Ворогушино	0101000020E61000006CED7DAA0A1251407250C24CDB0D4D40
5272	6	57	54	64	42559	\N	58.308349	626121, Тюменская область, Тобольский район, с. Верхние Аремзяны, ул. Школьная, д. 5		0101000020E6100000AAB9DC60A82551408D60E3FA77274D40
5271	6	57	54	32494	42455	\N	57.775041000000002	626117, Тюменская область, Тобольский район, с. Булашово, ул. Рабочая, 48		0101000020E6100000983270404BF650409207228B34E34C40
5274	6	57	54	217	42305	\N	58.141897999999998	626110, Тюменская область, Тобольский район, с. Бизино ул. Ленина, д. 7 А		0101000020E61000002A8C2D043911514014AFB2B629124D40
5269	6	57	54	32406	77176	\N	58.3001698946834	626159, Тюменская область, Тобольский район, д. Башкова, ул. Строителей, 10	Россия, Тюменская область, Тобольский район, село Башкова	0101000020E6100000A2D0B2EE1F135140C39E76F86B264D40
5268	6	57	54	32356	41929	\N	57.7741351569328	626118, Тюменская область, Тобольский район, с. Байкалово, ул. Советская д. 10	Россия, Тюменская область, Тобольский район, село Байкалово	0101000020E6100000390B7BDAE1E9504030D80DDB16E34C40
5266	6	57	54	32269	42302	\N	58.12773	626125, Тюменская область, Тобольский район, с. Абалак, ул. Советская, 36		0101000020E6100000D5963AC8EB255140EA5BE67459104D40
5263	6	57	1774	32133	78007	\N	56.493476999999999	627503, Тюменская область, Сорокинский район, д. Рядовичи, ул. Сидякина, д. 20/1		0101000020E6100000C7BB2363B5735140022A1C412A3F4C40
5264	6	57	1774	32155	42386	\N	56.792842999999998	627507, Тюменская область, Сорокинский район, с. Покровка, ул. Центральная, д. 14		0101000020E6100000535DC0CB0C64514067EE21E17B654C40
5252	6	57	1774	31644	42553	\N	56.586618000000001	627502, Тюменская область, Сорокинский район, с. Осиновка, ул. Советская, д. 35		0101000020E610000048C49448A27851405A9F724C164B4C40
5262	6	57	1774	32503	77754	\N	56.506936000000003	627503, Тюменская область, Сорокинский район, с. Нижнепинигино, ул. Центральная, д. 58а		0101000020E61000002F6CCD565E7F514021956247E3404C40
5256	6	57	1774	31828	42385	\N	56.720069000000002	627510, Тюменская область, Сорокинский район, п. Нефтяник, ул. Центральная, д. 2		0101000020E6100000429946938B6B514085EE92382B5C4C40
5261	6	57	1774	32063	42558	\N	56.845382372194102	627512, Тюменская область, Сорокинский район, с. Калиновка, ул. Зеленая, д. 10	Россия, Тюменская область, Сорокинский район, село Калиновка	0101000020E61000000893E2E3135B51404450357A356C4C40
5259	6	57	1774	31951	42556	\N	56.736976613885901	627505, Тюменская область, Сорокинский район, с. Жидоусово, ул. Молодежная, д. 8	Россия, Тюменская область, Сорокинский район, село Жидоусово	0101000020E6100000EC6987BF267F5140BD732843555E4C40
5258	6	57	1774	31919	42457	\N	56.697479000000001	627506, Тюменская область, Сорокинский район, д. Желнина, ул. Школьная, д. 11а		0101000020E610000034F3E49A02885140CA52EBFD46594C40
5257	6	57	1774	31860	42314	\N	56.773425000000003	627506, Тюменская область, Сорокинский район, с. Готопутово, ул. Центральная, д. 40		0101000020E61000009337C0CC778A514054742497FF624C40
5254	6	57	1774	31732	42583	\N	56.757604000000001	627510, Тюменская область, Сорокинский район, с. Ворсиха, ул. Новая, д. 21		0101000020E61000007024D06053705140CEA8F92AF9604C40
5251	6	57	1774	25745	41924	\N	56.634059999999998	627500, Тюменская область, Сорокинский район, с. Большое Сорокино, ул. Советская, д. 213		0101000020E6100000992A1895D4735140D3D9C9E028514C40
5250	6	57	1774	25745	41924	\N	56.634059999999998	627500, Тюменская область, Сорокинский район, с. Большое Сорокино, ул. Советская, д. 105		0101000020E6100000992A1895D4735140D3D9C9E028514C40
5249	6	57	1774	25745	42113	\N	56.634059999999998	627500, Тюменская область, Сорокинский район, с. Большое Сорокино, ул. Ленина, д. 160		0101000020E6100000992A1895D4735140D3D9C9E028514C40
5248	6	57	1774	25745	41958	\N	56.634059999999998	627500, Тюменская область, Сорокинский район, с. Большое Сорокино, ул. 40 лет Октября, д. 1а		0101000020E6100000992A1895D4735140D3D9C9E028514C40
5253	6	57	1774	31695	42554	\N	56.608159000000001	627511, Тюменская область, Сорокинский район, с. Александровка, ул. Школьная, д. 1		0101000020E610000099805F23496F514050E27327D84D4C40
5239	6	57	1780	31024	77898	\N	55.883857999999996	627600, Тюменская область, Сладковский район, д. Хантиновка, ул. Солнечная, д. 2		0101000020E610000059164CFC518751406B274A4222F14B40
5247	6	57	1780	31417	42366	\N	55.448402999999999	627624, Тюменская область, Сладковский район, с. Усово, ул. Ленина, д. 17		0101000020E61000004374081C097A5140D236FE4465B94B40
5170	6	57	1780	61264	77877	\N	55.7461697326749	627411, Тюменская область, Казанский район, д. ДТравное, ул. Приозерная, д. 31	Россия, Тюменская область, Сладковский район, село Травное	0101000020E6100000DEFFC709138F5140CFA0A17F82DF4B40
5246	6	57	1780	31331	42550	\N	55.604289999999999	627626, Тюменская область, Сладковский район, с. Степное, ул. Школьная д. 2		0101000020E6100000BA1457957D8C514061A6ED5F59CD4B40
5245	6	57	1780	25685	41956	\N	55.529288000000001	627610, Тюменская область, Сладковский район, с. Сладково, ул. Ленина, д. 104а		0101000020E61000000053060E6895514027158DB5BFC34B40
5244	6	57	1780	25685	41956	\N	55.526853730407701	627610, Тюменская область, Сладковский район, с. Сладково, ул. Ленина, д. 86	Россия, Тюменская область, Сладковский район, село Сладково	0101000020E6100000B0AD9FFEB395514026E2ADF36FC34B40
5243	6	57	1780	31205	42364	\N	55.851999265756497	627630, Тюменская область, Сладковский район, д. Новоандреевка, ул. Школьная, д. 5	Россия, Тюменская область, Сладковский район, село Новоандреевка	0101000020E6100000F81C588E909C5140C39CA04D0EED4B40
5242	6	57	1780	31152	77730	\N	55.551751000000003	627631, Тюменская область, Сладковский район, с. Никулино, ул. Центральная, д. 69		0101000020E6100000AFB2B6291EA851408544DAC69FC64B40
5240	6	57	1780	31061	77802	\N	55.773155000000003	627603, Тюменская область, Сладковский район, с. Менжинское, ул. Карла Маркса, д. 17		0101000020E6100000BD378600E077514094DE37BEF6E24B40
5238	6	57	1780	30942	41923	\N	55.927073999999998	627600, Тюменская область, Сладковский район, п. Маслянский, ул. Сенная, д. 2		0101000020E6100000D89B189293885140677C5F5CAAF64B40
5235	6	57	1780	30827	42422	\N	55.480082000000003	627620, Тюменская область, Сладковский район, с. Лопазное, ул. Центральная, д. 18		0101000020E61000004E5FCFD72C9B5140FBB2B45373BD4B40
5234	6	57	1780	30250	42363	\N	55.266066000000002	627623, Тюменская область, Сладковский район, с. Александровка, ул. Школьная, д. 22		0101000020E6100000390CE6AF907C5140ED4960730EA24B40
5233	6	57	1779	30692	42466	\N	56.412213000000001	627064, Тюменская область, Омутинский район, с. ЮжноПлетнево, ул. Строительная, д. 24		0101000020E6100000041E1840F8DF504037FE4465C3344C40
5232	6	57	1779	30664	42347	\N	56.485554999999998	627084, Тюменская область, Омутинский район, с. Шабаново, ул. Шабановская, д. 13		0101000020E61000005017299485F8504063B48EAA263E4C40
5227	6	57	1779	30391	42301	\N	56.367268000000003	627081, Тюменская область, Омутинский район, с. Ситниково, ул. Победы, д. 31		0101000020E6100000960A2AAA7EF55040056F48A3022F4C40
5229	6	57	1779	30391	42551	\N	56.367268000000003	627081, Тюменская область, Омутинский район, с. Ситниково, ул. МТС, д. 1		0101000020E6100000960A2AAA7EF55040056F48A3022F4C40
5231	6	57	1779	30391	78146	\N	56.367268000000003	627081, Тюменская область, Омутинский район, с. Ситниково, ул. Леонова, д. 2		0101000020E6100000960A2AAA7EF55040056F48A3022F4C40
5228	6	57	1779	30391	42345	\N	56.367268000000003	627081, Тюменская область, Омутинский район, с. Ситниково, ул. Заводская, д. 3		0101000020E6100000960A2AAA7EF55040056F48A3022F4C40
5224	6	57	1779	29904	42272	\N	56.475071	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Тимирязева, д. 1а		0101000020E61000000D501A6A14EA504096236420CF3C4C40
5222	6	57	1779	29904	42343	\N	56.475071	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Терешковой, д. 7		0101000020E61000000D501A6A14EA504096236420CF3C4C40
5220	6	57	1779	29904	41922	\N	56.472220824006698	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Советская, д. 128	Россия, Тюменская область, Омутинский район, село Омутинское	0101000020E6100000486E4DBA2DEA504001BEDBBC713C4C40
5217	6	57	1779	29904	41921	\N	56.471745768002101	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Лермонтова, д. 2	Россия, Тюменская область, Омутинский район, село Омутинское	0101000020E610000049D6E1E82AEA50406902452C623C4C40
5219	6	57	1779	29904	42281	\N	56.475071	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Зятькова, д. 36		0101000020E61000000D501A6A14EA504096236420CF3C4C40
5218	6	57	1779	29904	42271	\N	56.472743378717503	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Герцена, д. 26	Россия, Тюменская область, Омутинский район, село Омутинское	0101000020E6100000BF4692205CEA5040DB34B6D7823C4C40
5225	6	57	1779	29904	42419	\N	56.475071	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Вокзальная (здание табельного 2го линейного участка)		0101000020E61000000D501A6A14EA504096236420CF3C4C40
5223	6	57	1779	29904	42344	\N	56.4679451978717	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Водопроводная, д. 6	Россия, Тюменская область, Омутинский район, село Омутинское	0101000020E6100000A7CB6262F3EA5040D2A92B9FE53B4C40
5221	6	57	1779	29904	42298	\N	56.4726008645127	627070, Тюменская область, Омутинский район, с. Омутинское, ул. Вагайская, д. 21	Россия, Тюменская область, Омутинский район, село Омутинское	0101000020E610000070EA03C93BEA5040488787307E3C4C40
5216	6	57	1779	25649	42274	\N	56.563923966373501	627087, Тюменская область, Омутинский район, с. Окуневское, ул. Мира, д. 6	Россия, Тюменская область, Омутинский район, село Окуневское	0101000020E6100000D576137CD3DC5040FAB660A92E484C40
5214	6	57	1779	29769	42421	\N	56.448363999999998	627060, Тюменская область, Омутинский район, д. Крутинская, ул. Центральная, д. 1		0101000020E6100000AD1397E315D45040145AD6FD63394C40
5226	6	57	1779	30348	\N	\N	56.454349000000001	627070, Тюменская область, Омутинский район, д. Кашевская (здание сельского Дома культуры)		0101000020E6100000F0DFBC38F1EC504033FCA71B283A4C40
5215	6	57	1779	29809	42548	\N	56.269801000000001	627082, Тюменская область, Омутинский район, с. Журавлевское, ул. Школьная, д. 3		0101000020E6100000CC07043A93EB5040CCB6D3D688224C40
5211	6	57	1779	29594	42311	\N	56.471829999999997	627060, Тюменская область, Омутинский район, с. Вагай, ул. Школьный переулок, д. 2		0101000020E6100000CFF753E3A5D35040C6A2E9EC643C4C40
5212	6	57	1779	29594	77041	\N	56.471829999999997	627060, Тюменская область, Омутинский район, с. Вагай, ул. Совхозная, д. 38		0101000020E6100000CFF753E3A5D35040C6A2E9EC643C4C40
5210	6	57	1779	29594	42253	\N	56.476651547181604	627060, Тюменская область, Омутинский район, с. Вагай, ул. Ленина, д. 32а	Россия, Тюменская область, Омутинский район, село Вагай	0101000020E61000006F2D93E178D3504058C9C7EE023D4C40
5209	6	57	1779	29530	42342	\N	56.562747999999999	627085, Тюменская область, Омутинский район, с. Большой Краснояр, ул. Советская, д. 54		0101000020E6100000861C5BCF10EE5040D8F15F2008484C40
5213	6	57	1779	29714	42525	\N	56.450155000000002	627060, Тюменская область, Омутинский район, д. Большекрутинская, ул. Центральная, д. 27		0101000020E61000007C48F8DEDFD65040C190D5AD9E394C40
5207	6	57	854	29460	42270	\N	57.6476773231472	626021, Тюменская область, Нижнетавдинский район, п. Чугунаево, ул. Лесная, д. 27	Россия, Тюменская область, Нижнетавдинский район, село Чугунаево	0101000020E6100000124DA088456A50408AAF7614E7D24C40
5117	6	57	657	4461	41919	\N	56.112282	627750, Тюменская область, г. Ишим, ул. Курганская, 1		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5206	6	57	854	29397	42584	\N	57.7012503637633	626025, Тюменская область, Нижнетавдинский район, с. Черепаново, ул. Советская, д. 12	Россия, Тюменская область, Нижнетавдинский район, село Черепаново	0101000020E61000008C2C9963797F5040F6285C8FC2D94C40
5202	6	57	854	29209	42296	\N	57.389875000000004	626030, Тюменская область, Нижнетавдинский район, с. Тюнево, ул. Школьная д. 11		0101000020E610000033A6608DB36C504096438B6CE7B14C40
5196	6	57	854	28979	78033	\N	57.570782000000001	626042, Тюменская область, Нижнетавдинский район, п. Тукман, ул. Центральная, д. 8		0101000020E6100000FD304278B49F50409F9273620FC94C40
5186	6	57	854	28506	42547	\N	57.281846000000002	626034, Тюменская область, Нижнетавдинский район, п. Торгили, ул. Станционная, д. 6		0101000020E6100000C408E1D1C682504014419C8713A44C40
5203	6	57	854	27058	77739	\N	57.366278999999999	626035, Тюменская область, Нижнетавдинский район, с. Средние Тарманы, ул. Школьная, д. 41		0101000020E6100000F645425BCE565040151BF33AE2AE4C40
5201	6	57	854	28740	78123	\N	57.585534000000003	626020, Тюменская область, Нижнетавдинский район, с. Сартово, ул. Зеленая, д. 1		0101000020E6100000118E59F624845040195932C7F2CA4C40
5198	6	57	854	29056	78071	\N	57.671109000000001	626040, Тюменская область, Нижнетавдинский район, с. Паченка, ул. Хохлова, д. 30		0101000020E610000046B5882826945040908653E6E6D54C40
5180	6	57	854	28233	77891	\N	57.473536000000003	626036, Тюменская область, Нижнетавдинский район, д. Новопокровка, ул. Центральная, д. 14		0101000020E6100000340F60915F58504045BDE0D39CBC4C40
5193	6	57	854	28816	42454	\N	57.655295851526802	626039, Тюменская область, Нижнетавдинский район, с. Новоникольское, ул. Центральная, д. 6	Россия, Тюменская область, Нижнетавдинский район, село Новоникольское	0101000020E610000079CBD58F4D4F50408D9944BDE0D34C40
5192	6	57	854	28683	42114	\N	57.67624	626020, Тюменская область, Нижнетавдинский район, с. Нижняя Тавда, ул. Строителей, д. 2		0101000020E61000005E2EE23B318B50409F1F46088FD64C40
5191	6	57	854	28683	42017	\N	57.675504238787902	626020, Тюменская область, Нижнетавдинский район, с. Нижняя Тавда, ул. Новая, д. 50	Россия, Тюменская область, Нижнетавдинский район, село Нижняя Тавда	0101000020E61000001059A489778B5040992842EA76D64C40
5190	6	57	854	28683	42071	\N	57.67624	626020, Тюменская область, Нижнетавдинский район, с. Нижняя Тавда, ул. Мира, д. 10		0101000020E61000005E2EE23B318B50409F1F46088FD64C40
5385	6	57	854	6395	42318	\N	57.373359999999998	625551, Тюменская область, Тюменский район, д. Нариманова, ул. Центральная, д. 23а		0101000020E61000006249B9FB1C46504039D1AE42CAAF4C40
5188	6	57	854	28600	42453	\N	57.867143493652399	626028, Тюменская область, Нижнетавдинский район, с. Мияссы, ул. Центральная, д. 9	Россия, Тюменская область, Нижнетавдинский район, село Мияссы	0101000020E61000007C5F5CAAD27A504048FAB48AFEEE4C40
5205	6	57	854	29348	78069	\N	57.379100000000001	626030, Тюменская область, Нижнетавдинский район, п. Лесозаводский, ул. Мира, д. 11		0101000020E6100000FA997ADD22645040F1F44A5986B04C40
5187	6	57	854	28536	42452	\N	57.273299054248902	626034, Тюменская область, Нижнетавдинский район, п. Кунчур, ул. Лесная, д. 2	Россия, Тюменская область, Нижнетавдинский район, село Кунчур	0101000020E6100000F99FFCDD3B8C5040C7832D76FBA24C40
5183	6	57	854	28331	42552	\N	57.466818000000004	626014, Тюменская область, Нижнетавдинский район, д. Красный Яр, ул. 70 лет Октября, д. 2		0101000020E6100000772D211FF47D5040929735B1C0BB4C40
5200	6	57	854	29150	78141	\N	57.470477000000002	626044, Тюменская область, Нижнетавдинский район, с. Конченбург, ул. Новая, 8		0101000020E610000005A6D3BA0D9450409642209738BC4C40
5197	6	57	854	29000	42456	\N	57.636977000000002	626041, Тюменская область, Нижнетавдинский район, с. Киндер, ул. Центральная, д. 28		0101000020E610000032AF230ED9985040F0A65B7688D14C40
5199	6	57	854	29092	78044	\N	57.471232000000001	626044, Тюменская область, Нижнетавдинский район, п. Картымский, ул. Железнодорожников, д. 2		0101000020E610000033DC80CF0F995040126A865451BC4C40
5204	6	57	854	29321	42524	\N	57.421499422657597	626030, Тюменская область, Нижнетавдинский район, п. Карагандинский, ул. Водозабор, д. 1	Россия, Тюменская область, Нижнетавдинский район, поселок Карагандинский	0101000020E6100000A2EF6E65896D5040FA25E2ADF3B54C40
5184	6	57	854	28416	42451	\N	57.596117999999997	626033, Тюменская область, Нижнетавдинский район, с. Канаш, ул. Молодежная, д. 4		0101000020E610000089096AF816695040494739984DCC4C40
5182	6	57	854	28311	42295	\N	57.570362000000003	626032, Тюменская область, Нижнетавдинский район, с. Иска, ул. Береговая, д. 1		0101000020E6100000739D465A2A725040CA703C9F01C94C40
5195	6	57	854	28916	42546	\N	57.609181999999997	626038, Тюменская область, Нижнетавдинский район, д. Веселая Грива, ул. Центральная, д. 42		0101000020E61000000667F0F78B4E5040EBA7FFACF9CD4C40
5181	6	57	854	28258	41998	\N	57.550836092202999	626031, Тюменская область, Нижнетавдинский район, с. Велижаны, ул. Советская, д. 2	Россия, Тюменская область, Нижнетавдинский район, поселок Велижаны	0101000020E61000000D7041B62C715040CFBA46CB81C64C40
5179	6	57	854	28162	42268	\N	57.505530016606997	626036, Тюменская область, Нижнетавдинский район, с. Бухтал, ул. Чапаева, д. 4	Россия, Тюменская область, Нижнетавдинский район, село Бухтал	0101000020E6100000EC17EC866D4A5040CD920035B5C04C40
5178	6	57	854	28149	42450	\N	57.672226000000002	626024, Тюменская область, Нижнетавдинский район, п. Березовка, ул. Школьная, д. 27		0101000020E6100000488C9E5BE8725040ADC266800BD64C40
5176	6	57	854	28042	42362	\N	57.8199470287813	626049, Тюменская область, Нижнетавдинский район, с. Антипино, ул. Новопашина, д. 59	Россия, Тюменская область, Нижнетавдинский район, село Антипино	0101000020E6100000F816D68D77A4504006BAF605F4E84C40
5174	6	57	854	27977	42269	\N	57.758364646239997	626026, Тюменская область, Нижнетавдинский район, с. Андрюшино, ул. Полевая, д. 2	Россия, Тюменская область, Нижнетавдинский район, село Андрюшино	0101000020E6100000E1D40792777D50402CB7B41A12E14C40
5172	6	57	1799	27883	42300	\N	55.573743999999998	627430, Тюменская область, Казанский район, с. Яровское, ул. Ленина, д. 34		0101000020E610000029931ADA004951405B23827170C94B40
5169	6	57	1799	27736	42420	\N	55.753822999999997	627411, Тюменская область, Казанский район, с. Чирки, ул. Ельцова, д. 61		0101000020E61000004A5E9D63403F51407EFCA5457DE04B40
5171	6	57	1799	27834	42346	\N	55.762965999999999	627427, Тюменская область, Казанский район, п. Челюскинцев, ул. Гагарина, д. 14		0101000020E6100000F0C2D66CE5675140DFFAB0DEA8E14B40
5167	6	57	1799	27642	77892	\N	55.815472999999997	627412, Тюменская область, Казанский район, с. Смирное, ул. Молодежная, д. 5		0101000020E6100000E2033BFE0B3F5140B0E2546B61E84B40
5173	6	57	1799	27937	78065	\N	55.529012000000002	627430, Тюменская область, Казанский район, д. Сладчанка, ул. Центральная, д. 26		0101000020E6100000F54A5986384E514085984BAAB6C34B40
5165	6	57	1799	27544	42523	\N	55.556384999999999	627435, Тюменская область, Казанский район, с. Пешнево, пер. Школьный, д. 8		0101000020E610000085798F334D5A5140137EA99F37C74B40
5164	6	57	1799	27510	42549	\N	55.825482000000001	627425, Тюменская область, Казанский район, д. Песчаное, ул. Новая, д. 18		0101000020E6100000FCA9F1D24D545140E5B7E864A9E94B40
5163	6	57	1799	27462	42361	\N	55.774132000000002	627425, Тюменская область, Казанский район, с. Огнево, ул. Победы, д. 5		0101000020E61000003BE12538F5535140BF64E3C116E34B40
5162	6	57	1799	27344	42075	\N	55.679966	627429, Тюменская область, Казанский район, с. Новоселезнево, ул. Садова, д. 36		0101000020E6100000F661BD512B4D51402B323A2009D74B40
5161	6	57	1799	27344	41920	\N	55.679966	627429, Тюменская область, Казанский район, с. Новоселезнево, ул. Ленина, д. 271		0101000020E6100000F661BD512B4D51402B323A2009D74B40
5142	6	57	1799	26502	42520	\N	55.382722999999999	627433, Тюменская область, Казанский район, д. Новогеоргиевка, ул. Центральная, д. 25		0101000020E6100000BABDA4315A5C5140A8363811FDB04B40
5145	6	57	1799	26650	42545	\N	55.792364210579798	627426, Тюменская область, Казанский район, д. Малая Ченчерь, ул. Малая, д. 32	Россия, Тюменская область, Казанский район, село Малый Ченчерь	0101000020E61000001C98DC28B25751408D43FD2E6CE54B40
5147	6	57	1799	61259	77815	\N	55.611653826186199	627434, Тюменская область, Казанский район, д. МЯрки, ул. 60 лет Октября, д. 25	Россия, Тюменская область, Казанский район, село Малые Ярки	0101000020E61000008FFF024180545140DA3BA3AD4ACE4B40
5168	6	57	1799	27711	78142	\N	55.827803000000003	627412, Тюменская область, Казанский район, д. Коротаевка, ул. Зеленая, д. 18		0101000020E61000009561DC0DA2435140EE43DE72F5E94B40
5166	6	57	1799	27620	42487	\N	55.535310000000003	627435, Тюменская область, Казанский район, д. Копотилово, ул. Центральная, д. 24		0101000020E610000087A2409FC85E5140639CBF0985C44B40
5156	6	57	1799	27139	42011	\N	55.640609127293601	627420, Тюменская область, Казанский район, с. Казанское, ул. Луначарского, д. 22	Россия, Тюменская область, Казанский район, село Казанское	0101000020E6100000790261A7584E5140FA42C879FFD14B40
5158	6	57	1799	27139	42019	\N	55.645074999999999	627420, Тюменская область, Казанский район, с. Казанское, ул. Ленина, д. 64/1		0101000020E610000066F84F37504E5140CD3B4ED191D24B40
5160	6	57	1799	27139	42015	\N	55.645074999999999	627420, Тюменская область, Казанский район, с. Казанское, ул. Ишимская, д. 20		0101000020E610000066F84F37504E5140CD3B4ED191D24B40
5159	6	57	1799	27139	42015	\N	55.644104231538897	627420, Тюменская область, Казанский район, с. Казанское, ул. Ишимская, д. 42	Россия, Тюменская область, Казанский район, село Казанское	0101000020E6100000B4739A05DA4E5140849CF7FF71D24B40
5152	6	57	1799	26965	42070	\N	55.448377000000001	627432, Тюменская область, Казанский район. с. Ильинка, ул. Ленина, д. 26		0101000020E6100000BF7CB262B8545140A9A3E36A64B94B40
5155	6	57	1799	27078	42544	\N	55.397452101566003	627432, Тюменская область, Казанский район, д. Ельцово, ул. Пограничная, д. 5	Россия, Тюменская область, Казанский район, село Ельцово	0101000020E6100000F4C308E1D15551406ADD06B5DFB24B40
5149	6	57	1799	26793	42359	\N	55.484470472087899	627431, Тюменская область, Казанский район. с. Дубынка, ул. Ленина, д. 30	Россия, Тюменская область, Казанский район, село Дубынка	0101000020E610000087FD9E58A739514052F2EA1C03BE4B40
5150	6	57	1799	26867	42267	\N	55.561481337209003	627436, Тюменская область, Казанский район, д. Грачи, ул. Зеленая, д. 37	Россия, Тюменская область, Казанский район, село Грачи	0101000020E61000004162BB7B80365140A629029CDEC74B40
5148	6	57	1799	26790	42356	\N	55.740836000000002	627424 , Тюменская область, Казанский район, с. Гагарье, ул. Лугова, д. 14		0101000020E610000084F3A963954E514088D9CBB6D3DE4B40
5144	6	57	1799	26599	42417	\N	55.791999364749898	627426, Тюменская область, Казанский район, с. БЧенчерь, ул. Школьная, д. 45	Россия, Тюменская область, Казанский район, село Большой Ченчерь	0101000020E61000004701A260C65B51407BBB253960E54B40
5146	6	57	1799	26677	42355	\N	55.596455163122002	627343, Тюменская область, Казанский район, д. Большие Ярки, ул. Кирова, д. 1	Россия, Тюменская область, Казанский район, село Большие Ярки	0101000020E61000003C4B90115053514091442FA358CC4B40
5154	6	57	1799	27061	42522	\N	55.390138	627432, Тюменская область, Казанский район, д. Благодатное, ул. Мира, д. 40		0101000020E61000003140A209144B5140A376BF0AF0B14B40
5153	6	57	1799	26988	78030	\N	55.484774999999999	627432, Тюменская область, Казанский район. д. Баландина, ул. Центральная, д. 25		0101000020E6100000C6DE8B2FDA5551408E75711B0DBE4B40
5141	6	57	1799	26429	42340	\N	55.452905999999999	627433, Тюменская область, Казанский район, с. Афонькино, ул. Мира, д. 2		0101000020E61000004BC972124A5B5140C214E5D2F8B94B40
5109	6	57	657	24963	77040	\N	56.016300000000001	627750, Тюменская область, Ишимский район, с. Шаблыкино, ул. Ленина, д. 61		0101000020E6100000E2C96E66F470514060764F1E16024C40
5106	6	57	657	24857	42542	\N	56.219957999999998	627701, Тюменская область, Ишимский район с. Черемшанка, ул. Новая, д. 6		0101000020E6100000F8AA9509BF5951402D3F7095271C4C40
5102	6	57	657	24666	77132	\N	56.205150000000003	627750, Тюменская область, Ишимский район, с. Тоболово, ул. Школьная, д. 13		0101000020E6100000C158DFC0E44851402063EE5A421A4C40
5070	6	57	657	23117	77961	\N	56.150033000000001	627750, Тюменская область, Ишимский район, д. Таловка, ул. Интернатская, д. 15		0101000020E61000002844C021545A51400F29064834134C40
5098	6	57	657	24424	42007	\N	56.136098808026198	627750, Тюменская область, Ишимский район, с. Стрехнино, ул. Стаханова, д. 6	Россия, Тюменская область, Ишимский район, село Стрехнино	0101000020E6100000034356B77A625140580229B16B114C40
5097	6	57	657	24424	42002	\N	56.138542999999999	627750, Тюменская область, Ишимский район, с. Стрехнино, ул. Мелиоративная, д. 1а		0101000020E6100000DBFAE93F6B6251407C0BEBC6BB114C40
5076	6	57	657	23380	42266	\N	56.014192000000001	627750, Тюменская область, Ишимский район, д. Синицына, ул. Мира, д. 14		0101000020E610000075AC527AA65E5140B3EE1F0BD1014C40
5108	6	57	657	24949	77885	\N	56.239277999999999	627741, Тюменская область, Ишимский район д. Савина, ул. Димитрова, д. 20		0101000020E61000001A6EC0E7876051407E5358A9A01E4C40
5094	6	57	657	24256	42541	\N	56.1930192689303	627750, Тюменская область, Ишимский район, с. Равнец, ул. Школьная, д. 12	Россия, Тюменская область, Ишимский район, село Равнец	0101000020E6100000ED0F94DBF6725140D940BAD8B4184C40
5092	6	57	657	24161	42264	\N	56.311625999999997	627750, Тюменская область, Ишимский район, с. Прокуткино, ул. Центральная, д. 24		0101000020E6100000B515FBCBEE705140A94A5B5CE3274C40
5089	6	57	657	24021	77737	\N	56.080789000000003	627750, Тюменская область, Ишимский район, п. Плодопитомник, ул. Светлая, д. 1б		0101000020E6100000F1B73D41625A51403370404B570A4C40
5091	6	57	657	24090	77035	\N	56.076137000000003	627750, Тюменская область, Ишимский район, с. Плешково, ул. Советская, д. 57		0101000020E6100000124BCADDE76B5140FE8172DBBE094C40
5086	6	57	657	23865	42394	\N	56.055804000000002	627750, Тюменская область, Ишимский район, с. Пахомова, ул. Новая, д. 33		0101000020E6100000BCE7C07284595140357EE19524074C40
5082	6	57	657	61253	77792	\N	57.087257000000001	627750, Тюменская область, Ишимский район, с. Неволино, ул. Центральная, д. 5		0101000020E61000004D327216F66150406DACC43C2B8B4C40
5077	6	57	657	23433	77879	\N	55.953735000000002	627750, Тюменская область, Ишимский район, д. Орловка, ул. Центральная, д. 201		0101000020E610000015E46723D75F514079060DFD13FA4B40
5105	6	57	657	24802	77880	\N	56.235145000000003	627750, Тюменская область, Ишимский район, д. Опеновка, ул. Дорожная, д. 1		0101000020E610000086AC6EF59C4A5140B2683A3B191E4C40
5071	6	57	657	23158	42065	\N	56.288341000000003	627750, Тюменская область, Ишимский район, п. Октябрьский, ул. Ленина, д. 32		0101000020E6100000738577B9883B5140488C9E5BE8244C40
5081	6	57	657	23635	77884	\N	56.066082000000002	627750, Тюменская область, Ишимский район, д. Ожогино, ул. Школьная, д. 2/1		0101000020E6100000A296E65608315140596DFE5F75084C40
5085	6	57	657	23797	77731	\N	55.926327999999998	627750, Тюменская область, Ишимский район, с. Новотравное, ул. Центральная, д. 28		0101000020E6100000336FD575A84F51403EAF78EA91F64B40
5083	6	57	657	23717	77150	\N	56.017904999999999	627750, Тюменская область, Ишимский район, с. Новолокти, ул. Советская, д. 2		0101000020E61000002D0ABB287A435140AAB706B64A024C40
5074	6	57	657	23302	42540	\N	56.332026999999997	627750, Тюменская область, Ишимский район, п. Новокировский, ул. Животноводов, д. 20		0101000020E6100000666A12BC213D5140CA3159DC7F2A4C40
5069	6	57	657	23075	77875	\N	56.105665999999999	627750, Тюменская область, Ишимский район, д. Нерпино, ул. Центральная, д. 36А		0101000020E6100000836E2F698C4E51404A26A776860D4C40
5065	6	57	657	22895	77066	\N	56.0725316363716	627750, Тюменская область, Ишимский район, с. Мизоново, ул. Зелёная, д. 4	Россия, Тюменская область, Ишимский район, поселок Мизоново	0101000020E6100000B37C5D86FF445140EDF483BA48094C40
5064	6	57	657	22833	42578	\N	56.135061999999998	627750, Тюменская область, Ишимский район, д. Мезенка, ул. Центральная, д. 56А		0101000020E61000009CA38E8EAB5A514057772CB649114C40
5068	6	57	657	23017	78037	\N	56.156832000000001	627750, Тюменская область, Ишимский район, д. Малоудалово, ул. Центральная, д. 24/1		0101000020E6100000C39B35785F575140AF7B2B1213144C40
5095	6	57	657	24315	77962	\N	56.168259999999997	627750, Тюменская область, Ишимский район, д. Макарова, ул. Васильева, д. 38		0101000020E6100000AFE9414129765140CB9C2E8B89154C40
5084	6	57	657	23771	78129	\N	55.986173000000001	627750, Тюменская область, Ишимский район, д. Локти, ул. Центральная, д. 44		0101000020E61000006E5166834C3E51405F99B7EA3AFE4B40
5101	6	57	657	24616	77881	\N	56.161484000000002	627750, Тюменская область, Ишимский район, п. Лозовое, ул. Надежд, д. 1Б		0101000020E6100000AAB69BE09B5E5140E469F981AB144C40
5078	6	57	657	23472	42292	\N	55.869278999999999	627750, Тюменская область, Ишимский район, с. Лариха, ул. Советская, д. 14		0101000020E6100000A0185932C7555140BF0CC68844EF4B40
5103	6	57	657	24704	77801	\N	56.233885000000001	627750, Тюменская область, Ишимский район, д. Кукарцева, ул. Победы, д. 32а		0101000020E6100000CEA96400A83F5140320395F1EF1D4C40
5073	6	57	657	23252	78040	\N	56.274025000000002	627750, Тюменская область, Ишимский район, д. Крутые Озерки, ул Центральная 36		0101000020E6100000BD8BF7E3F63F5140A9A44E4013234C40
5096	6	57	657	24351	77966	\N	56.117972999999999	627750, Тюменская область, Ишимский район, д. Кошкарагай, ул. Ишимская, д. 64		0101000020E6100000FB93F8DC09745140CF6740BD190F4C40
5075	6	57	657	23327	42297	\N	55.963540999999999	627750, Тюменская область, Ишимский район, с. Клепиково, ул. Победы, д. 9		0101000020E6100000BF9CD9AED05C514075ADBD4F55FB4B40
5072	6	57	657	23204	77927	\N	56.306382999999997	627750, Тюменская область, Ишимский район, с. Карасуль, ул. Гагарина, д. 36а		0101000020E61000009F94490D6D3B51407286E28E37274C40
5093	6	57	657	24194	77799	\N	56.376007000000001	627750, Тюменская область, Ишимский район, д. Казанка, ул. Мира, д. 24		0101000020E610000050FC1873D76F5140960854FF20304C40
5135	6	57	657	4461	\N	\N	56.112282	627750, Тюменская область, г. Ишим, ул. Деповская, 21	Россия, Тюменская область, Ишимский район, город Ишим	0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5139	6	57	657	4461	41933	\N	56.114200188545198	627750, Тюменская область, г. Ишим, ул. Уральская, 26А		0101000020E61000000987DEE2E1605140029A081B9E0E4C40
4706	6	57	657	4461	42377	\N	56.112282	627750, Тюменская область, г. Ишим, ул. М. Садовая, 169		0101000020E6100000B2834A5CC75D5140F9F6AE415F0E4C40
5100	6	57	657	24552	77048	\N	56.135227999999998	627750, Тюменская область, Ишимский район, д. Зырянка, ул. Дзержинского, д. 9Б		0101000020E610000069C36169E05F514072C0AE264F114C40
5090	6	57	657	24061	42357	\N	56.324959999999997	627750, Тюменская область, Ишимский район, п. Заозерный, ул. Победы, д. 27		0101000020E6100000FBEB1516DC6051400B410E4A98294C40
5104	6	57	657	24777	77970	\N	56.174314000000003	627750, Тюменская область, Ишимский район, д. Завьялово, ул. Советская, д. 16		0101000020E6100000274EEE77284E5140139ED0EB4F164C40
5066	6	57	657	22932	42555	\N	56.179010630749701	627750, Тюменская область, Ишимский район, с. Ершово, ул. Школьная площадь, д. 24	Россия, Тюменская область, Ишимский район, село Ершово (Безруково)	0101000020E6100000E4F90CA837535140E84F1BD5E9164C40
5063	6	57	657	22790	42291	\N	56.259067999999999	627750, Тюменская область, Ишимский район, с. Десятова, ул. Центральная, д. 31		0101000020E610000075CB0EF10F3A514056B8E52329214C40
5111	6	57	657	25058	77828	\N	56.069062000000002	627750, Тюменская область, Ишимский район, д. Голдобино, пер. Школьный, д. 3		0101000020E6100000D07D39B35D805140BCB20B06D7084C40
5062	6	57	657	22760	42288	\N	56.009205000000001	627750, Тюменская область, Ишимский район, с. Гагарино, ул. Новая, д. 30		0101000020E6100000467D923B6C585140D7FA22A12D014C40
5061	6	57	657	22720	42416	\N	55.873939999999997	627750, Тюменская область, Ишимский район, с. Второпесьяново, ул. Советская, д. 10 а		0101000020E6100000508D976E1248514047551344DDEF4B40
5079	6	57	657	61274	78354	\N	55.899428138188902	627750, Тюменская область, Ишимский район, д. Воронино, ул. Центральная, д. 36	Россия, Тюменская область, Ишимский район, село Воронина	0101000020E6100000128942CBBA5B5140A88DEA7420F34B40
5088	6	57	657	23970	77047	\N	56.089427999999998	627750, Тюменская область, Ишимский район, д. Ваньковка, ул. Дорожная, д. 26		0101000020E61000004F05DCF3FC57514060AC6F60720B4C40
5087	6	57	657	23882	77750	\N	56.062649999999998	627750, Тюменская область, Ишимский район, д. Быкова, ул. Средняя, д. 14		0101000020E610000097749483D9515140158C4AEA04084C40
5059	6	57	657	22621	78035	\N	56.422828000000003	627750, Тюменская область, Ишимский район, с. Бутусово, ул. Центральная, д. 6		0101000020E6100000795C548B884C5140A3EA573A1F364C40
5057	6	57	657	22537	42290	\N	56.166325999999998	627750, Тюменская область, Ишимский район, с. Боровое, ул. Школьная д. 27		0101000020E61000006682E15CC36B5140BC3C9D2B4A154C40
5060	6	57	657	22676	42449	\N	56.348447	627750, Тюменская область, Ишимский район, д. Борисовка, ул. Центральная, д. 10		0101000020E6100000E3AAB2EF8A435140D5B14AE9992C4C40
5058	6	57	657	22593	42519	\N	56.109676999999998	627750, Тюменская область, Ишимский район, д. Большой остров, ул. Зеленая, д. 30		0101000020E61000006938656EBE675140CB0F5CE5090E4C40
5107	6	57	657	24880	78062	\N	56.175165999999997	627701, Тюменская область, Ишимский район д. Большеудалово, ул. Заречная, д. 5		0101000020E61000005B41D3122B57514081AFE8D66B164C40
5099	6	57	657	24515	77965	\N	56.210276999999998	627750, Тюменская область, Ишимский район, д. Бокаревка, ул. п. Чернова, д. 1		0101000020E6100000390EBC5AEE685140ED0C535BEA1A4C40
5055	6	57	1650	22439	41912	\N	56.660834000000001	626372, Тюменская область, Исетский район, с. Шорохово, ул. Калинина, 13		0101000020E61000007E6E68CA4E585040DD0A613596544C40
5025	6	57	1650	21059	77787	\N	56.443691999999999	626383, Тюменская область, Исетский район, д. Турушево, ул. Полевая, 1		0101000020E610000058E36C3A0248504098BF42E6CA384C40
5051	6	57	1650	22283	42448	\N	56.3378854076037	626380, Тюменская область, Исетский район, с. Станичное, ул. Кирова, 10	Россия, Тюменская область, Исетский район, село Станичное	0101000020E61000001A6CEA3C2A5B50408C67D0D03F2B4C40
5050	6	57	1650	22243	42339	\N	56.438876522157301	626396, Тюменская область, Исетский район, с. Солобоево, ул. Октябрьская, 33	Россия, Тюменская область, Исетский район, поселок Солобоево	0101000020E610000035B56CAD2F585040B9FB1C1F2D384C40
5049	6	57	1650	61032	77016	\N	56.5324706234004	626387, Тюменская область, Исетский район, с. СлободаБешкиль, ул. Им. Старцева, 44	Россия, Тюменская область, Исетский район, поселок Слобода-Бешкиль	0101000020E61000007F17B6662B765040C2887D0228444C40
5027	6	57	1650	21146	77789	\N	56.479723999999997	626383, Тюменская область, Исетский район, д. Сизикова, ул. Механизаторов, 7		0101000020E610000036E675C4214A50409B8D9598673D4C40
5038	6	57	1650	21644	77956	\N	56.624082999999999	626385, Тюменская область, Исетский район, д. Решетникова, ул. Свободы, 3		0101000020E6100000166D8E739B485040AA7EA5F3E14F4C40
5045	6	57	1650	55089	42349	\N	56.455952790331899	626386, Тюменская область, Исетский район, с. Рафайлово, ул. Исаковых, 55		0101000020E6100000C2340C1F11525040ADC1FBAA5C3A4C40
5044	6	57	1650	21942	9966	\N	56.541572000000002	626393, Тюменская область, Исетский район, с. Рассвет, ул. Ленина, 15		0101000020E6100000787E5182FE6E5040F436363B52454C40
5043	6	57	1650	21915	78032	\N	56.442638000000002	626399, Тюменская область, Исетский район, д. Онуфриево, ул. Школьная, 1		0101000020E61000008E06F016486F5040C2FBAA5CA8384C40
5040	6	57	1650	21763	42447	\N	56.535168639708502	626388, Тюменская область, Исетский район, п. Новикова, ул. Ишимская, 2а	Россия, Тюменская область, Исетский район, село Новикова	0101000020E6100000D09D60FF754F5040A16AF46A80444C40
5041	6	57	1650	21820	42332	\N	56.426751000000003	626399, Тюменская область, Исетский район, с. Минино, ул. Мира, 3а		0101000020E6100000AEF545425B6950408544DAC69F364C40
5054	6	57	1650	22402	78115	\N	56.467194999999997	626380, Тюменская область, Исетский район, д. Малыши, ул. Береговая, 25		0101000020E6100000D976DA1A115B504067EDB60BCD3B4C40
5042	6	57	1650	21860	77954	\N	56.437288000000002	626399, Тюменская область, Исетский район, д. Лога, ул. Школьная, 13		0101000020E6100000B5DE6FB4E366504075779D0DF9374C40
5036	6	57	1650	21561	42414	\N	56.627248000000002	626394, Тюменская область, Исетский район, д. Кукушки, ул. Северная, 2		0101000020E6100000740987DEE25D50409F3D97A949504C40
5052	6	57	1650	22320	77820	\N	56.488262057246502	626380, Тюменская область, Исетский район, с. Красногорское, ул. Центральная, 62		0101000020E6100000923B6C223364504095F0845E7F3E4C40
85919	6	56	743	12163	9825	\N	58.046573000000002	г.Верхняя Салда, Ленина, 16		0101000020E6100000F88C446804474E4035F0A31AF6054D40
5037	6	57	1650	21601	42415	\N	56.599136999999999	626385, Тюменская область, Исетский район, с. Красново, ул. Первомайская, 39		0101000020E6100000DEE8633E204B50406A696E85B04C4C40
5035	6	57	1650	21523	41917	\N	56.565446000000001	626391, Тюменская область, Исетский район, п. Коммунар, ул. Ленина, 40		0101000020E6100000C216BB7D56625040B7D3D68860484C40
5034	6	57	1650	21469	42277	\N	56.715789036726299	626389, Тюменская область, Исетский район, п. Кировский, ул. Центральная, 2а	Россия, Тюменская область, Исетский район, поселок Кировский	0101000020E6100000662FDB4E5B6F504014EB54F99E5B4C40
5033	6	57	1650	21319	41914	\N	56.480861811642399	626380, Тюменская область, Исетский район, с. Исетское, ул. Строителей, 9	Россия, Тюменская область, Исетский район, село Исетское	0101000020E6100000342F87DD77545040D0F1D1E28C3D4C40
5032	6	57	1650	21319	42003	\N	56.483189000000003	626380, Тюменская область, Исетский район, с. Исетское, ул. Свердлова, 71		0101000020E61000001EDC9DB5DB545040BB641C23D93D4C40
5031	6	57	1650	21319	42003	\N	56.481194271289503	626380, Тюменская область, Исетский район, с. Исетское, ул. Свердлова, 9	Россия, Тюменская область, Исетский район, село Исетское	0101000020E61000003563D174765450400684D6C3973D4C40
5056	6	57	1650	22492	77796	\N	56.605826	626372, Тюменская область, Исетский район, п. Зерновой, ул. Рабочая, 8		0101000020E6100000FB9463B2B85950408388D4B48B4D4C40
5030	6	57	1650	21270	42412	\N	56.656692999999997	626395, Тюменская область, Исетский район, с. Денисово, ул. Гагарина, 20		0101000020E6100000C11BD2A8C06950408D4127840E544C40
5024	6	57	1650	21009	77784	\N	56.455458	626383, Тюменская область, Исетский район, д. Гаева, ул. 60 лет Октября, 1а		0101000020E61000009294F430B44D5040CD599F724C3A4C40
5029	6	57	1650	21227	78064	\N	56.437263000000002	626399, Тюменская область, Исетский район, с. Верхний Ингал, ул. Янтимирова, 35		0101000020E610000005F86EF3C67250401C60E63BF8374C40
5028	6	57	1650	21200	42410	\N	56.519877999999999	626390, Тюменская область, Исетский район, с. Верхнебешкиль, ул. Революции, 8		0101000020E61000000667F0F78B61504077F4BF5C8B424C40
5053	6	57	1650	22364	78138	\N	56.477924999999999	626380, Тюменская область, Исетский район, д. Ботники, ул. Береговая, 11		0101000020E610000047CA1649BB5D50406C787AA52C3D4C40
5047	6	57	1650	22110	77794	\N	56.390070999999999	626386, Тюменская область, Исетский район, д. Битюки, ул. Пановых, 6		0101000020E610000068E6C935055550401B0FB6D8ED314C40
5023	6	57	1650	20919	77028	\N	56.473385999999998	626383, Тюменская область, Исетский район, с. Бархатово, ул. Гагрина, 52а		0101000020E6100000EC87D860E14D50402F3196E9973C4C40
5022	6	57	1650	20906	77061	\N	56.527678999999999	626392, Тюменская область, Исетский район, с. Архангельское, ул. Школьная, 1		0101000020E6100000211E8997A76A50409BE447FC8A434C40
4978	6	57	1485	18522	77987	\N	56.442850999999997	627103, Тюменская область, Заводоуковский район, с. Яковлево, ул. Набережная, д. 36		0101000020E6100000E27492AD2EAA50401D007157AF384C40
5009	6	57	1485	20133	42411	\N	56.636544999999998	627120, Тюменская область, Заводоуковский район, д. Щучье, ул. Приозерная, д. 6		0101000020E61000001233FB3C46AA504056B77A4E7A514C40
5013	6	57	1485	20368	77783	\N	56.448687999999997	627106, Тюменская область, Заводоуковский район, с. Шиликуль, ул. Приозерная, д. 29А		0101000020E610000041F4A44C6A8C5040C70DBF9B6E394C40
5000	6	57	1485	19652	77829	\N	56.694262000000002	627113, Тюменская область, Заводоуковский район, с. Шестаково, ул. Шоссейна, д. 19А		0101000020E61000002B155454FDBD5040836DC493DD584C40
4981	6	57	1485	18654	42444	\N	56.319171656705599	627101, Тюменская область, Заводоуковский район, п. Центральный, ул. Центральная, д. 28	Россия, Тюменская область, Заводоуковский район, поселок Центральный	0101000020E61000000C91D3D7F3A6504043E6CAA0DA284C40
5005	6	57	1485	19920	77791	\N	56.478833999999999	627105, Тюменская область, Заводоуковский район, п. Урожайный, ул. Молодежная, д. 1		0101000020E6100000D0EFFB372FAB50403F1BB96E4A3D4C40
5008	6	57	1485	20073	42517	\N	56.621200999999999	627120, Тюменская область, Заводоуковский район, с. Тумашово, ул. Школьная, д. 9		0101000020E610000043E4F4F57CB050400A9FAD83834F4C40
5012	6	57	1485	20356	77946	\N	56.480460000000001	627106, Тюменская область, Заводоуковский район, с. Сунгурово, ул. Клубная, д. 5а		0101000020E6100000A051BAF42F985040A18499B67F3D4C40
5006	6	57	1485	19968	77873	\N	56.465679000000002	627105, Тюменская область, Заводоуковский район, п. Степной, ул. Береговая, д. 2		0101000020E610000064027E8D24AF50408DB7955E9B3B4C40
4995	6	57	1485	19401	42261	\N	56.520513999999999	627104, Тюменская область, Заводоуковский район, с. Старая Заимка, ул. Клубная, д. 5А		0101000020E61000009A95ED43DEB55040198EE733A0424C40
4997	6	57	1485	19503	42283	\N	56.541170000000001	627121, Тюменская область, Заводоуковский район, с. Сосновка, ул. Центральна, д. 52		0101000020E61000003430F2B226BB5040C5C9FD0E45454C40
5007	6	57	1485	20038	77941	\N	56.515155999999998	627105, Тюменская область, Заводоуковский район, с. Семеново, ул. Центральная, д. 16		0101000020E6100000E99AC937DBAC5040492BBEA1F0414C40
5019	6	57	1485	20727	78238	\N	56.391092	627114, Тюменская область, Заводоуковский район, с. Сединкино, ул. Центральная, д. 4		0101000020E6100000B743C362D4B8504016DD7A4D0F324C40
5004	6	57	1485	19854	42537	\N	56.508375999999998	627105, Тюменская область, Заводоуковский район, п. Речной, ул. Шоссейная, д. 7		0101000020E6100000217711A628AA50402009FB7612414C40
5017	6	57	1485	20612	42461	\N	56.535387999999998	627118, Тюменская область, Заводоуковский район, д. Пономарево, ул. Луговая, д. 39		0101000020E61000001D2098A3C7995040DE550F9887444C40
5018	6	57	1485	20689	77823	\N	56.409543999999997	627114, Тюменская область, Заводоуковский район, с. Першино, ул. Центральная, д. 25		0101000020E610000024809BC58BB15040F22213F06B344C40
5003	6	57	1485	19743	9975	\N	56.511420999999999	627105, Тюменская область, Заводоуковский район, с. Падун, ул. Школьная, д. 3		0101000020E610000011AB3FC230A750406ABE4A3E76414C40
5002	6	57	1485	19743	42262	\N	56.508098960779598	627105, Тюменская область, Заводоуковский район, с. Падун, ул. Молодежная, д. 27	Россия, Тюменская область, Заводоуковский район, поселок Падун	0101000020E61000009A780778D2A75040AE10566309414C40
4983	6	57	1485	18759	77896	\N	56.434286999999998	627101, Тюменская область, Заводоуковский район, п. Озерки, ул. 1я Озерная, д. 4		0101000020E610000037DE1D19ABA15040FA0967B796374C40
5010	6	57	1485	20221	77019	\N	56.488666000000002	627106, Тюменская область, Заводоуковский район, с. Новолыбаево, ул. Первомайская, д. 4А		0101000020E61000003E247CEF6F9650406555849B8C3E4C40
4993	6	57	1485	61286	78229	\N	56.459469531675403	627110, Тюменская область, Заводоуковский район, д. Новозаимская, ул. Пионерская, д. 3		0101000020E61000005C7347FFCBC050401FBFB7E9CF3A4C40
4990	6	57	1485	19049	42259	\N	56.486739905116998	627110, Тюменская область, Заводоуковский район, с. Новая Заимка, ул. Мира, д. 13	Россия, Тюменская область, Заводоуковский район, село Новая Заимка	0101000020E6100000C84274081CBA5040D8D30E7F4D3E4C40
4991	6	57	1485	19049	42328	\N	56.484223	627110, Тюменская область, Заводоуковский район, с. Новая Заимка, ул. Ленина, д. 47		0101000020E6100000C823B891B2BA50404A7CEE04FB3D4C40
4989	6	57	1485	19049	42328	\N	56.485932616516401	627110, Тюменская область, Заводоуковский район, с. Новая Заимка, ул. Ленина, д. 180	Россия, Тюменская область, Заводоуковский район, село Новая Заимка	0101000020E610000019C91EA166BA50400A86730D333E4C40
4988	6	57	1485	19049	42256	\N	56.484223	627110, Тюменская область, Заводоуковский район, с. Новая Заимка, ул. Вокзальная, д. 1		0101000020E6100000C823B891B2BA50404A7CEE04FB3D4C40
4992	6	57	1485	19049	42331	\N	56.484223	627110, Тюменская область, Заводоуковский район, с. Новая Заимка, ул. Базарная, д. 2		0101000020E6100000C823B891B2BA50404A7CEE04FB3D4C40
5014	6	57	1485	20474	77957	\N	56.469149999999999	627106, Тюменская область, Заводоуковский район, д. Нижнеингал, ул. Северная, д. 2		0101000020E610000066118AADA08850408E75711B0D3C4C40
4982	6	57	1485	18731	42442	\N	56.407941407911203	627101, Тюменская область, Заводоуковский район, п. Мичуринский, ул. Лесная, д. 6	Россия, Тюменская область, Заводоуковский район, поселок Мичуринский	0101000020E6100000EA58A5F44CA4504049D9226937344C40
4996	6	57	1485	19436	77952	\N	56.521199000000003	627102, Тюменская область, Заводоуковский район, с. Марково, ул. Центральная, д. 23		0101000020E6100000BEA3C68498B250409DDA19A6B6424C40
4980	6	57	1485	18610	42445	\N	56.281750640071401	627101, Тюменская область, Заводоуковский район, п. Лесной, ул. Лесная, д. 26	Россия, Тюменская область, Заводоуковский район, село Лесной	0101000020E6100000F1D8CF62299D5040C24EB16A10244C40
5001	6	57	1485	19693	42062	\N	56.7877197729456	627130, Тюменская область, Заводоуковский район, п. Лебедевка, ул. Советская, д. 33	Россия, Тюменская область, Заводоуковский район, поселок Лебедевка	0101000020E610000011ACAA97DFBC5040DB334B02D4644C40
4987	6	57	1485	52043	78135	\N	56.329332000000001	627102, Тюменская область, Заводоуковский район, д. Красная, ул. Красная, д. 33		0101000020E610000002D71533C2AC50405DC30C8D272A4C40
4998	6	57	1485	19554	77905	\N	56.551183999999999	627121, Тюменская область, Заводоуковский район, д. Кошелева, ул. Береговая, д. 13А		0101000020E61000002157EA5910C050400B0A83328D464C40
5015	6	57	1485	20500	42260	\N	56.540734	627140, Тюменская область, Заводоуковский район, п. Комсомольский, ул. Дачная, д. 14		0101000020E6100000F8FD9B1727A65040EAEA8EC536454C40
4985	6	57	1485	18866	77777	\N	56.245154999999997	627115, Тюменская область, Заводоуковский район, с. Комиссарово, ул. Лесная, д. 17		0101000020E6100000E10B93A982B65040B6B9313D611F4C40
5011	6	57	1485	20251	77872	\N	56.455125000000002	627106, Тюменская область, Заводоуковский район, д. Комарова, ул. Притобольная, д. 22		0101000020E61000006A6AD95A5F955040C74B3789413A4C40
4999	6	57	1485	19615	78140	\N	56.670147999999998	627113, Тюменская область, Заводоуковский район, д. Каменка, ул. Первомайская, д. 16А		0101000020E610000008E6E8F17BB550406ABDDF68C7554C40
4967	6	57	1485	17108	9794	\N	56.505509973045001	627140, Тюменская область, г. Заводоуковск, ул. Вокзальная, д. 55	Россия, Тюменская область, Заводоуковский район, город Заводоуковск	0101000020E6100000145FED28CEA2504086E63A8DB4404C40
4986	6	57	1485	18942	77951	\N	56.355445000000003	627102, Тюменская область, Заводоуковский район, д. Дронова, ул. Новая, д. 1а		0101000020E61000000AD80E46ECAF50406C43C5387F2D4C40
4979	6	57	1485	61276	78154	\N	56.270141487574797	627101, Тюменская область, Заводоуковский район, с. Горюгово, ул. Октябрьская, д. 32	Россия, Тюменская область, Заводоуковский район, село Горюново	0101000020E61000001421753BFBA450408527F4FA93224C40
5016	6	57	1485	20589	42368	\N	56.520046999999998	627118, Тюменская область, Заводоуковский район, с. Гилево, ул. Советская, д. 29		0101000020E6100000AC8C463EAF9B504003B16CE690424C40
4994	6	57	1485	19339	42285	\N	56.628757999999998	627122, Тюменская область, Заводоуковский район, с. Боровинка, ул. Ленина, д. 40А		0101000020E6100000EA77616BB6C25040978C63247B504C40
4977	6	57	1485	18437	42409	\N	56.402785000000002	627103, Тюменская область, Заводоуковский район, с. Бигила, ул. Советская, д. 1		0101000020E6100000C4995FCD01AA5040E12879758E334C40
4934	6	57	1435	16300	78133	\N	56.529595	627320, Тюменская область, Голышмановский район, д. Шулындино, ул. Дзержинского, д. 2		0101000020E6100000EAB12D03CE2651400490DAC4C9434C40
4935	6	57	1435	16322	42535	\N	56.420374000000002	627320, Тюменская область, Голышмановский район, д. Черемшанка, ул. п. Лепустина, д. 7		0101000020E610000043024697372E51405B0BB3D0CE354C40
4959	6	57	1435	17516	42341	\N	56.500934000000001	627305, Тюменская область, Голышмановский район, с. УстьЛаменка, ул. Пищика, д. 1		0101000020E61000005E471CB2810451402CBAF59A1E404C40
4956	6	57	1435	17396	77039	\N	56.100825999999998	627309, Тюменская область, Голышмановский район, с. Средние Чирки, ул. Советская, д. 13		0101000020E6100000F982161230135140124BCADDE70C4C40
4955	6	57	1435	17313	77034	\N	56.153167000000003	627308, Тюменская область, Голышмановский район, с. Ражево, ул. Строительная, д. 1		0101000020E61000007EE36BCF2C195140C9E9EBF99A134C40
88812	6	56	\N	9945	18448	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Жуковского, 5а		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
4947	6	57	1435	16922	77989	\N	56.671429000000003	627314, Тюменская область, Голышмановский район, д. Оськина, ул. Центральная, д. 46		0101000020E61000007214200A66095140024BAE62F1554C40
4960	6	57	1435	17617	42464	\N	56.611612000000001	627319, Тюменская область, Голышмановский район, д. Новая Хмелевка, ул. Школьная, д. 7		0101000020E6100000C426327381345140ABEB504D494E4C40
4948	6	57	1435	17012	77837	\N	56.640816999999998	627314, Тюменская область, Голышмановский район, д. Никольск, ул. Мира, д. 30		0101000020E6100000FCE07CEA5804514044DC9C4A06524C40
4954	6	57	1435	17298	42352	\N	56.360984999999999	627306, Тюменская область, Голышмановский район, с. Медведево, ул. Молодежная, д. 9		0101000020E610000036CCD078221F51405CACA8C1342E4C40
4953	6	57	1435	17215	42330	\N	56.615981164390398	627311, Тюменская область, Голышмановский район, с. Малышенка, ул. 50 лет Октября, д. 1	Россия, Тюменская область, Голышмановский район, село Малышенка	0101000020E61000001F4DF564FE2551408BFA2477D84E4C40
4957	6	57	1435	17424	77917	\N	56.174759999999999	627309, Тюменская область, Голышмановский район, д. Лапушина, ул. Мельникайте, д. 16		0101000020E6100000043A9336550A5140115322895E164C40
4952	6	57	1435	17208	42279	\N	56.430131000000003	627330, Тюменская область, Голышмановский район, п. Ламенский, ул. Пролетарская, д. 2		0101000020E6100000DFF8DA334BFF504076FF58880E374C40
4951	6	57	1435	17132	42353	\N	56.554558	627310, Тюменская область, Голышмановский район, с. Королево, ул. Ленина, д. 12		0101000020E610000005A4FD0FB01F51401ADEACC1FB464C40
4949	6	57	1435	17027	77845	\N	56.213014999999999	627317, Тюменская область, Голышмановский район, д. Земляная, ул. Советская, д. 29		0101000020E6100000EAEBF99AE51D51405A475513441B4C40
4946	6	57	1435	16914	42538	\N	56.705168999999998	627314, Тюменская область, Голышмановский район, с. Евсино, ул. Подоляка, д. 8		0101000020E61000006F9EEA909B125140969350FA425A4C40
4944	6	57	1435	55079	41965	\N	56.396433000000002	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. Садовая, д. 128		0101000020E610000099BA2BBB6017514010070951BE324C40
4940	6	57	1435	55079	41965	\N	56.396433000000002	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. Садовая, д. 72		0101000020E610000099BA2BBB6017514010070951BE324C40
4938	6	57	1435	55079	41965	\N	56.396433000000002	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. Садовая, д. 1		0101000020E610000099BA2BBB6017514010070951BE324C40
4936	6	57	1435	55079	42265	\N	56.396433000000002	627300, Тюменская область, Голышмановский район, пгт. Голышманово, пер. Московский, д. 23		0101000020E610000099BA2BBB6017514010070951BE324C40
4937	6	57	1435	55079	42096	\N	56.396433000000002	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. Московская, д. 1А		0101000020E610000099BA2BBB6017514010070951BE324C40
4941	6	57	1435	55079	42374	\N	56.396433000000002	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. Комсомольская, д. 86		0101000020E610000099BA2BBB6017514010070951BE324C40
4943	6	57	1435	55079	41964	\N	56.396433000000002	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. К. Маркса, д. 160		0101000020E610000099BA2BBB6017514010070951BE324C40
4942	6	57	1435	55079	42360	\N	56.398004103285402	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. К. Маркса, д. 92		0101000020E6100000A87004A914195140AED689CBF1324C40
4945	6	57	1435	16408	42054	\N	56.405309771416199	627300, Тюменская область, Голышмановский район, пгт. Голышманово, ул. Молодежная, д. 18	Россия, Тюменская область, Голышмановский район, поселок городского типа Голышманово	0101000020E6100000C93846B247185140F25EB532E1334C40
4933	6	57	1435	16218	42521	\N	56.468865999999998	627320, Тюменская область, Голышмановский район, с. Голышманово, ул. Московская, д. 1		0101000020E610000084BC1E4C8A265140691A14CD033C4C40
4932	6	57	1435	16200	42255	\N	56.376261	627321, Тюменская область, Голышмановский район, с. Гладилово, ул. Кормильцева А. Е. , д. 15		0101000020E6100000D845D1031F23514050E1085229304C40
4931	6	57	1435	16113	42325	\N	56.526532288425599	627324, Тюменская область, Голышмановский район, д. Боровлянка, ул. 60 лет Октября, д. 10	Россия, Тюменская область, Голышмановский район, село Боровлянка	0101000020E61000000EA320787C11514014268C6665434C40
4930	6	57	1435	16108	42439	\N	56.693618289399303	627313, Тюменская область, Голышмановский район, с. Бескозобово, ул. Пролетарская, д. 13	Россия, Тюменская область, Голышмановский район, село Бескозобово	0101000020E6100000569E40D8292151405EF58079C8584C40
4921	6	57	1342	15630	77944	\N	57.043213000000002	627594, Тюменская область, Викуловский район, с. Шешуки, ул. Школьная, д. 1		0101000020E610000047CA1649BB9951408BE1EA0088854C40
4927	6	57	1342	15937	42408	\N	56.698827999999999	627583, Тюменская область, Викуловский район, с. Чуртан, ул. Фрунзенская, д. 33		0101000020E6100000193C4CFBE6A45140B9C3263273594C40
4903	6	57	1342	14793	42438	\N	56.775644	627571, Тюменская область, Викуловский район, с. Чебаклей, ул. Кузнецова, д. 4		0101000020E61000004B3E761728A4514058AB764D48634C40
4908	6	57	1342	15042	77990	\N	56.800699999999999	627596, Тюменская область, Викуловский район, с. УстьБарсук, ул. Садовая, 20		0101000020E61000008BA71E6970AE51401FF46C567D664C40
4925	6	57	1342	15833	77929	\N	57.078921999999999	627595, Тюменская область, Викуловский район, д. Староборовая, ул. Солнечная, д. 19		0101000020E610000017B7D100DEAF5140AB77B81D1A8A4C40
4923	6	57	1342	15729	42512	\N	56.879629474114203	627595, Тюменская область, Викуловский район, с. Сартам, ул. Молодежная, д. 23	Россия, Тюменская область, Викуловский район, село Сартам	0101000020E61000006E8B321B64AE51407DCEDDAE97704C40
4920	6	57	1342	15623	42418	\N	57.029868	627594, Тюменская область, Викуловский район, с. Рябово, ул. Советская, д. 4		0101000020E61000005D514A08569651403599F1B6D2834C40
4917	6	57	1342	15463	42574	\N	56.920504391224	627580, Тюменская область, Викуловский район, с. Поддубровное, ул. Школьная, д. 1	Россия, Тюменская область, Викуловский район, село Поддубровное	0101000020E61000005E0F26C5C7A5514029EB3713D3754C40
4915	6	57	1342	15344	77055	\N	56.803292312749903	627598, Тюменская область, Викуловский район, с. Озерное, ул. Советская, д. 58	Россия, Тюменская область, Викуловский район, село Озёрное	0101000020E61000009DA04D0E9FD05140B891B245D2664C40
4918	6	57	1342	15542	77902	\N	56.976201000000003	627580, Тюменская область, Викуловский район, с. Одино, ул. Зеленая, д. 34		0101000020E610000016A3AEB5F7A5514048A98427F47C4C40
4913	6	57	1342	15252	42407	\N	56.592312999999997	627576, Тюменская область, Викуловский район, с. Нововяткино, ул. Мира, д. 7		0101000020E6100000A304FD851E9C514071FF91E9D04B4C40
4919	6	57	1342	15555	77840	\N	56.994818000000002	627580, Тюменская область, Викуловский район, с. Малышево, ул. Пушкина, д. 20		0101000020E61000008E588B4F01AB51406FBC3B32567F4C40
4928	6	57	1342	16000	78130	\N	56.686861999999998	627583, Тюменская область, Викуловский район, с. Малахово, ул. Радищева, д. 28		0101000020E6100000E9263108AC985140BD6E1118EB574C40
4910	6	57	1342	15141	42254	\N	56.812398999999999	627597, Тюменская область, Викуловский район, с. Коточиги, ул. 8 Марта, д. 4		0101000020E6100000FEB968C878BC5140CC26C0B0FC674C40
4914	6	57	1342	15331	77947	\N	56.585611999999998	627576, Тюменская область, Викуловский район, д. Комиссаровка, ул. Школьная, д. 2		0101000020E6100000FB1F60ADDA98514094128255F54A4C40
4909	6	57	1342	15060	42351	\N	57.073447999999999	627591, Тюменская область, Викуловский район, с. Каргалы, ул. Советская, д. 13		0101000020E6100000776A2E3718AC514072FA7ABE66894C40
4905	6	57	1342	14881	42440	\N	56.826223917946599	627596, Тюменская область, Викуловский район, с. Калинино, ул. 60 лет СССР, д. 10/1	Россия, Тюменская область, Викуловский район, село Калинино	0101000020E6100000A3073E062BB55140CD9541B5C1694C40
4896	6	57	1342	14481	42486	\N	56.620348999999997	627574, Тюменская область, Викуловский район, д. Заборка, ул. Центральная, д. 4		0101000020E61000007157AF22A3AF51409B8D9598674F4C40
4904	6	57	1342	14860	42533	\N	57.254615410257898	627592, Тюменская область, Викуловский район, с. Ермаки, ул. Школьная, д. 3	Россия, Тюменская область, Викуловский район, село Ермаки	0101000020E6100000711FB935E9BB514018096D3997A04C40
4929	6	57	1342	16022	77751	\N	56.726790000000001	627583, Тюменская область, Викуловский район, с. Доставалово, ул. Ишимская, д. 2		0101000020E61000006D3B6D8D08A55140A9876874075D4C40
4924	6	57	1342	15808	77838	\N	56.907435999999997	627595, Тюменская область, Викуловский район, с. Долгушино, ул. Озерная, д. 26		0101000020E6100000A1DB4B1AA3AA5140459BE3DC26744C40
4902	6	57	1342	14583	42045	\N	56.813724000000001	627571, Тюменская область, Викуловский район, с. Викулово, ул. Солнечная, д. 9		0101000020E6100000FF5E0A0F9AA6514033FCA71B28684C40
4899	6	57	1342	14583	41903	\N	56.813112661153703	627570, Тюменская область, Викуловский район, с. Викулово, ул. Ленина, д. 6	Россия, Тюменская область, Викуловский район, село Викулово	0101000020E610000010CD3CB9A6A65140EA79371614684C40
4900	6	57	1342	14583	42042	\N	56.813724000000001	627570, Тюменская область, Викуловский район, с. Викулово, ул. Кузнецова, д. 51		0101000020E6100000FF5E0A0F9AA6514033FCA71B28684C40
4901	6	57	1342	14583	41911	\N	56.813724000000001	627571, Тюменская область, Викуловский район, с. Викулово, пер. Заводской, д. 6		0101000020E6100000FF5E0A0F9AA6514033FCA71B28684C40
4912	6	57	1342	15240	78126	\N	56.810172000000001	627597, Тюменская область, Викуловский район, с. Бородино, ул. Строителей, д. 2		0101000020E61000003ACAC16C02CA5140451152B7B3674C40
4906	6	57	1342	14955	78018	\N	56.844628	627596, Тюменская область, Викуловский район, д. Борки, ул. Молодежная, д. 1		0101000020E61000001364045438AE514098A432C51C6C4C40
4898	6	57	1342	14561	42514	\N	56.803432382510202	627581, Тюменская область, Викуловский район, с. Боково, ул. Школьная, д. 45/3	Россия, Тюменская область, Викуловский район, село Боково	0101000020E6100000DD611399B9905140AA471ADCD6664C40
4897	6	57	1342	14485	42513	\N	56.816325999999997	627581, Тюменская область, Викуловский район, с. Березино, ул. Новая, д. 3		0101000020E61000001041D5E8D59C5140EF6FD05E7D684C40
4894	6	57	1342	14386	42322	\N	56.657879999999999	627574, Тюменская область, Викуловский район, с. Балаганы, ул. Ленина, д. 11		0101000020E610000092B06F2711A95140A3586E6935544C40
4911	6	57	1342	15166	78015	\N	56.791936	627597, Тюменская область, Викуловский район, с. Базариха, пер. Строителей, д. 6		0101000020E6100000478FDFDBF4C451403543AA285E654C40
4916	6	57	1342	15442	77836	\N	56.802041000000003	627598, Тюменская область, Викуловский район, с. Ачимово, ул. Озерная, д. 38		0101000020E61000004084B872F6D551408C868C47A9664C40
4867	6	57	1123	13082	42406	\N	57.383325999999997	626254, Тюменская область, Вагайский район, д. Юрмы, переул. Дорожный, д. 2		0101000020E6100000857CD0B3590651406EDA8CD310B14C40
4864	6	57	1123	12968	42530	\N	57.509011999999998	626252, Тюменская область, Вагайский район, с. Шишкина, ул. Зеленая, д. 5а		0101000020E6100000E4D6A4DB122D5140C2A2224E27C14C40
4866	6	57	1123	13063	42510	\N	57.447349000000003	626254, Тюменская область, Вагайский район, с. Шестовое, ул. Совхозная, д. 18		0101000020E610000066BE839F38105140FC7266BB42B94C40
4856	6	57	1123	12636	42350	\N	57.650604000000001	626256, Тюменская область, Вагайский район, с. Черное, ул. Библиотечная, д. 1		0101000020E610000047CA1649BB4A5140CA52EBFD46D34C40
4888	6	57	1123	14101	77935	\N	58.046439999999997	626262, Тюменская область, Вагайский район, с. Фатеево, ул. Мира, д. 1		0101000020E61000003A048E041A545140F59CF4BEF1054D40
4865	6	57	1123	12992	42509	\N	57.4810092200252	626253, Тюменская область, Вагайский район, с. Ушаково, ул. Ленина, д. 67а	Россия, Тюменская область, Вагайский район, село Ушаково	0101000020E610000047CCECF3181A5140740AF2B391BD4C40
4872	6	57	1123	13346	42336	\N	57.650108000000003	626247, Тюменская область, Вагайский район, с. Тукуз, ул. Береговая, 25		0101000020E61000007D24253D0C7151401A6F2BBD36D34C40
4886	6	57	1123	14003	42511	\N	57.997546	626264, Тюменская область, Вагайский район, с. Супра, ул. Новая, д. 27		0101000020E610000084D558C2DA635140B8205B96AFFF4C40
4870	6	57	1123	13254	77923	\N	57.807330999999998	626276, Тюменская область, Вагайский район, д. Сулейменская, ул. Комсомольская, д. 13/2		0101000020E6100000501A6A14926551400306499F56E74C40
4852	6	57	1123	12434	77825	\N	57.948141	626240, Тюменская область, Вагайский район, д. Старый Погост, ул. Молодежная, д. 4		0101000020E61000000F62670A9D3B5140957F2DAF5CF94C40
4880	6	57	1123	13713	78003	\N	57.956215999999998	626244, Тюменская область, Вагайский район, д. Ренчики, ул. Ренченская, д. 21а		0101000020E610000015A930B610705140BAF42F4965FA4C40
4861	6	57	1123	12839	42435	\N	57.737960999999999	626251, Тюменская область, Вагайский район, с. Птицкое, ул. Школьная, д. 9		0101000020E61000006F8445459C3651409A5C8C8175DE4C40
4858	6	57	1123	12713	42516	\N	57.405087999999999	626279, Тюменская область, Вагайский район, п. Первомайский, ул. Советская, д. 23		0101000020E610000069520ABABD435140430070ECD9B34C40
4806	6	57	1123	10223	78004	\N	57.219667000000001	627368, Тюменская область, Аромашевский район, д. Новые Юрты, ул. Береговая, д. 5		0101000020E6100000E065868DB248514056815A0C1E9C4C40
4873	6	57	1123	13365	42436	\N	57.600650999999999	626247, Тюменская область, Вагайский район, д. Малый Уват, ул. Озерная, д. 16а		0101000020E610000099840B79047E5140A4A7C821E2CC4C40
4863	6	57	1123	12906	78029	\N	57.691358000000001	626251, Тюменская область, Вагайский район, д. Малые Конданы, ул. Школьная, д. 1		0101000020E6100000E0F42EDE8F2C5140FBE93F6B7ED84C40
4885	6	57	1123	13914	42534	\N	57.993972999999997	626266, Тюменская область, Вагайский район, п. Курья, ул. Школьная, д. 3		0101000020E6100000A359D93EE4725140B20DDC813AFF4C40
4849	6	57	1123	12282	77916	\N	57.980637999999999	626271, Тюменская область, Вагайский район, с. Куларовское, ул. Озерная, д. 28		0101000020E61000007407B13385305140809BC58B85FD4C40
4850	6	57	1123	12346	77871	\N	57.956927999999998	626271, Тюменская область, Вагайский район, с. Куларово, ул. Школьная, д. 1		0101000020E6100000D1764CDD953251403750E09D7CFA4C40
4893	6	57	1123	14297	78091	\N	58.038583217356397	626249, Тюменская область, Вагайский район, д. Кобякская, ул. Школьная, д. 4а	Россия, Тюменская область, Вагайский район, село Кобякская	0101000020E610000057B26323103B51403E97A949F0044D40
4878	6	57	1123	13625	78028	\N	58.016877000000001	626272, Тюменская область, Вагайский район, с. Касьяново, ул. Школьная, д. 11		0101000020E610000014B1886187495140FD86890629024D40
4871	6	57	1123	13275	42532	\N	57.791460999999998	626276, Тюменская область, Вагайский район, с. Казанское, ул. Школьная, д. 3		0101000020E61000008672A25D856951409C8713984EE54C40
4887	6	57	1123	14024	77924	\N	58.041061999999997	626263, Тюменская область, Вагайский район, п. Иртыш, ул. Кедровая, д. 2а		0101000020E610000008043A93365F5140DE8D058541054D40
4889	6	57	1123	14109	77833	\N	58.061934999999998	626261, Тюменская область, Вагайский район, п. Инжура, ул. Центральная, д. 18а		0101000020E61000008F368E588B4C514027BD6F7CED074D40
4868	6	57	1123	13151	76997	\N	57.880028000000003	626275, Тюменская область, Вагайский район, п. Заречный, ул. Школьная, д. 4а		0101000020E61000006E8B321B644851403BC8EBC1A4F04C40
4879	6	57	1123	13639	41913	\N	57.953690000000002	626244, Тюменская область, Вагайский район, с. Дубровное, ул. Запольная, д. 6		0101000020E6100000B4AD669DF15A5140D942908312FA4C40
4881	6	57	1123	13732	77870	\N	57.990986999999997	626267, Тюменская область, Вагайский район, д. Второсалинская, ул. Центральная, д. 28а		0101000020E61000006FF59CF4BE7B51406DE179A9D8FE4C40
4891	6	57	1123	14204	77938	\N	58.010731	626249, Тюменская область, Вагайский район, с. Второвагайское, ул. Центральная, д. 9		0101000020E610000082AE7D01BD3D5140D50627A25F014D40
4851	6	57	1123	12347	78192	\N	57.935021999999996	626240, Тюменская область, Вагайский район, c. Вагай, ул. Школьная, д. 28		0101000020E61000005E4A5D328E4051402F8507CDAEF74C40
4853	6	57	1123	12347	42038	\N	57.935021999999996	626240, Тюменская область, Вагайский район, с. Вагай, ул. Мира, д. 18		0101000020E61000005E4A5D328E4051402F8507CDAEF74C40
4855	6	57	1123	12347	42039	\N	57.935021999999996	626241, Тюменская область, Вагайский район, с. Вагай, пер. Дорожный, д. 5		0101000020E61000005E4A5D328E4051402F8507CDAEF74C40
4854	6	57	1123	12347	41909	\N	57.935021999999996	626240, Тюменская область, Вагайский район, с. Вагай, ул. Ленина, д. 6		0101000020E61000005E4A5D328E4051402F8507CDAEF74C40
4860	6	57	1123	12798	78026	\N	57.751877	626251, Тюменская область, Вагайский район, д. Бушмина, ул. Октябрьская, д. 12		0101000020E6100000D653ABAFAE3E5140ABCE6A813DE04C40
4883	6	57	1123	13826	42437	\N	57.948472544742003	626269, Тюменская область, Вагайский район, с. Большой Карагай, ул. Первомайская, д. 1	Россия, Тюменская область, Вагайский район, село Большой Карагай	0101000020E6100000827170E9988F5140CB11329067F94C40
4890	6	57	1123	14194	42539	\N	58.043824999999998	626260, Тюменская область, Вагайский район, с. Бегишево, переул. Школьный, д. 13		0101000020E61000004419AA622A465140A4DFBE0E9C054D40
4830	6	57	1146	11373	77868	\N	55.944122	627443, Тюменская область, Бердюжский район, д. Шабурова, ул. Мира, д. 7		0101000020E61000007A39ECBE6310514091B75CFDD8F84B40
4848	6	57	1146	12238	42494	\N	55.688257999999998	627444, Тюменская область, Бердюжский район, д. Старорямова, ул. Ленина, д. 34		0101000020E6100000651A4D2EC60E5140ED9A90D618D84B40
4828	6	57	1146	11280	42498	\N	55.881948999999999	627442, Тюменская область, Бердюжский район, с. Полозаозерье, площадь Волкова, д. 5		0101000020E61000003F73D6A71C135140B5DE6FB4E3F04B40
4835	6	57	1146	11579	42251	\N	55.862054999999998	627450, Тюменская область, Бердюжский район, с. Пеганово, ул. Ленина, д. 19		0101000020E6100000B1868BDCD32C5140382D78D157EE4B40
4836	6	57	1146	11657	77922	\N	55.878535999999997	627450, Тюменская область, Бердюжский район, д. Останино, ул. Марикова, д. 26		0101000020E6100000C0EC9E3C2C345140E82D1EDE73F04B40
4837	6	57	1146	11678	42327	\N	55.717457000000003	627453, Тюменская область, Бердюжский район, с. Окунево, ул. Ленина, д. 20		0101000020E61000001E4FCB0F5C2C5140A5A487A1D5DB4B40
4838	6	57	1146	11765	42507	\N	55.714823609586198	627453, Тюменская область, Бердюжский район, д. Одышка, ул. Береговая, д. 24	Россия, Тюменская область, Бердюжский район, село Одышка	0101000020E6100000C1A90F24EF355140AD32535A7FDB4B40
4833	6	57	1146	11489	42502	\N	56.051375999999998	627451, Тюменская область, Бердюжский район, с. Мелехино, ул. Ленина, д. 42		0101000020E6100000BFF04A92E72451404FE61F7D93064C40
4832	6	57	1146	11466	77773	\N	56.020465999999999	627443, Тюменская область, Бердюжский район, д. Луговая, ул. Чехова, д. 40		0101000020E61000007B6B60AB04105140085740A19E024C40
4827	6	57	1146	11191	42500	\N	55.889693999999999	627442, Тюменская область, Бердюжский район, д. Кутырева, ул. Центральная, д. 34		0101000020E610000094DDCCE8470B514045B9347EE1F14B40
4840	6	57	1146	11843	77848	\N	55.783048000000001	627453, Тюменская область, Бердюжский район, д. Карькова, ул. Центральная, д. 14		0101000020E61000001C2444F9822B51405F99B7EA3AE44B40
4829	6	57	1146	11287	42529	\N	55.957307999999998	627443, Тюменская область, Бердюжский район, с. Истошино, ул. Алексеева, д. 48		0101000020E61000008E959867250F51407E198C1189FA4B40
4842	6	57	1146	11942	42504	\N	55.478780999999998	627446, Тюменская область, Бердюжский район, с. Зарослое, ул. Новая, д. 16		0101000020E6100000AA7D3A1E332751401C7920B248BD4B40
4817	6	57	1146	10774	78217	\N	55.7918134932276	627440, Тюменская область, Бердюжский район, д. Гагарина, ул. Школьная, д. 25	Россия, Тюменская область, Бердюжский район, село Гагарина	0101000020E61000001363997E890F514019C6DD205AE54B40
4846	6	57	1146	12142	42434	\N	55.641930000000002	627444, Тюменская область, Бердюжский район, с. Воробьево, ул. Центральная, д. 22		0101000020E6100000139D6516A10E5140202922C32AD24B40
4831	6	57	1146	11398	77769	\N	55.974463	627443, Тюменская область, Бердюжский район, д. Босоногова, ул. Победы, д. 45		0101000020E6100000FC51D4997B105140BE141E34BBFC4B40
4826	6	57	1146	10823	42413	\N	55.802568680681702	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Чкалова, д. 91	Россия, Тюменская область, Бердюжский район, село Бердюжье	0101000020E610000075029A081B14514047E4BB94BAE64B40
4819	6	57	1146	10823	42413	\N	55.804257999999997	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Чкалова, д. 40		0101000020E6100000FF91E9D0E9135140EFC517EDF1E64B40
4821	6	57	1146	10823	42316	\N	55.799375232769101	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Молодежная, д. 7	Россия, Тюменская область, Бердюжский район, село Бердюжье	0101000020E6100000E9297288B8145140B81E85EB51E64B40
4825	6	57	1146	10823	42405	\N	55.804257999999997	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Кирова, д. 1		0101000020E6100000FF91E9D0E9135140EFC517EDF1E64B40
4824	6	57	1146	10823	42405	\N	55.799665316722503	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Кирова, д. 13	Россия, Тюменская область, Бердюжский район, село Бердюжье	0101000020E6100000FBCBEEC9C3145140BF60376C5BE64B40
4818	6	57	1146	10823	42496	\N	55.804257999999997	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Гнаровской, д. 1		0101000020E6100000FF91E9D0E9135140EFC517EDF1E64B40
4822	6	57	1146	10823	42319	\N	55.800052091951102	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Герцена, д. 2	Россия, Тюменская область, Бердюжский район, село Бердюжье	0101000020E61000000FD6FF39CC145140B98C9B1A68E64B40
4820	6	57	1146	10823	42404	\N	55.804257999999997	627440, Тюменская область, Бердюжский район, с. Бердюжье, ул. Аф. Калинина, д. 2		0101000020E6100000FF91E9D0E9135140EFC517EDF1E64B40
4816	6	57	1065	10738	42278	\N	56.7577226448308	627360, Тюменская область, Аромашевский район, д. Юрминка, ул. Молчанова, д. 19а	Россия, Тюменская область, Аромашевский район, село Юрминка	0101000020E6100000E259828C80275140A8363811FD604C40
4799	6	57	1065	61283	78201	\N	56.967473988891498	627365, Тюменская область, Аромашевский район, д. УстьЛотовка, ул. Центральная, д. 26	Россия, Тюменская область, Аромашевский район, село Усть-Лотовка	0101000020E610000029931ADA005751407BDD2230D67B4C40
4814	6	57	1065	10628	42441	\N	56.979429000000003	627355, Тюменская область, Аромашевский район, с. Сорочкино, ул. Советская, д. 95		0101000020E61000003C31EBC55036514083E0F1ED5D7D4C40
4796	6	57	1065	9702	77936	\N	56.787695999999997	627376, Тюменская область, Аромашевский район, д. Смородиновка, ул. Школьная, д. 27а		0101000020E610000067EDB60BCD2A51405298F738D3644C40
4811	6	57	1065	10472	42432	\N	56.933582000000001	627354, Тюменская область, Аромашевский район, с. Слободчики, ул. Береговая, д. 2		0101000020E6100000EB8B84B69C2E514030116F9D7F774C40
4810	6	57	1065	10422	\N	\N	56.983548999999996	627374, Тюменская область, Аромашевский район, с. Русаково, ул. Гагарина, д. 4	Россия, Тюменская область, Аромашевский район, село Русаково	0101000020E6100000A648BE1248395140BA8102EFE47D4C40
4802	6	57	1065	10009	42403	\N	56.861188718681099	627364, Тюменская область, Аромашевский район, д. Овсово, ул. Одина, д. 28	Россия, Тюменская область, Аромашевский район, село Овсово	0101000020E6100000B340BB438A4751406556EF703B6E4C40
4808	6	57	1065	10312	77939	\N	57.120871000000001	627368, Тюменская область, Аромашевский район, д. Новоуфимская, ул. Лесная, д. 17		0101000020E610000074081C09343F5140750470B3788F4C40
4805	6	57	1065	10172	77866	\N	57.188831	627368, Тюменская область, Аромашевский район, с. Новопетрово, ул. Школьная, д. 5		0101000020E610000028637C98BD48514049BC3C9D2B984C40
4807	6	57	1065	10172	77960	\N	57.188830685724596	"627368, Тюменская область, Аромашевский район, п. Нефтеперекачивающей станции ""Новопетрово"", ул. Поселковая, д. 9"	Россия, Тюменская область, Аромашевский район, село Новопетрово	0101000020E6100000FF40B96DDF48514049BC3C9D2B984C40
4803	6	57	1065	10090	77727	\N	57.104664	627366, Тюменская область, Аромашевский район, с. Новоберезовка, ул. Центральная, д. 33		0101000020E61000002C9B3924B5575140C68844A1658D4C40
4815	6	57	1065	10660	42527	\N	57.054009000000001	627356, Тюменская область, Аромашевский район, д. Новоаптула, ул. Салавата Юлаева, д. 77		0101000020E610000079CE16105A3B5140475854C4E9864C40
4812	6	57	1065	10549	77867	\N	56.872422999999998	627362, Тюменская область, Аромашевский район, д. Николаевка, ул. Центральная, д. 15		0101000020E610000067D2A6EA1E3851409CA38E8EAB6F4C40
4782	6	57	979	9080	78073	\N	55.880647000000003	627233, Тюменская область, Армизонский район, д. Бурлаки, ул. Центральная, д. 14		0101000020E6100000A8C4758C2BEF50400729780AB9F04B40
4800	6	57	1065	9908	42431	\N	57.149001817549497	627357, Тюменская область, Аромашевский район, с. Малиновка, ул. Советская, д. 21	Россия, Тюменская область, Аромашевский район, село Малиновка	0101000020E61000008E90813CBB385140F1845E7F12934C40
4797	6	57	1065	9779	42402	\N	56.914610000000003	627365, Тюменская область, Аромашевский район, с. Кротово, ул. Советская, д. 44		0101000020E6100000603DEE5BAD5151401B4CC3F011754C40
4795	6	57	1065	9671	42433	\N	56.742190000000001	627376, Тюменская область, Аромашевский район, д. Кармацкая, ул. Мира, д. 11		0101000020E61000004BAB21718F29514089B5F814005F4C40
4798	6	57	1065	9808	77864	\N	56.902495999999999	627365, Тюменская область, Аромашевский район, д. Вилкова, ул. Центральная, д. 13		0101000020E6100000F12C4146404C5140AA622AFD84734C40
4813	6	57	1065	10571	77983	\N	56.914493	627354, Тюменская область, Аромашевский район, д. Валгина, ул. Центральная, д. 9		0101000020E61000005C57CC086F2F5140E1B54B1B0E754C40
4804	6	57	1065	10107	78012	\N	57.060352999999999	627366, Тюменская область, Аромашевский район, д. Большой Кусеряк, ул. Школьная, д. 26		0101000020E6100000DCDAC2F3525A5140959BA8A5B9874C40
4793	6	57	1065	9574	78038	\N	56.821202999999997	627350, Тюменская область, Аромашевский район, д. Большескаредная, ул. Центральная, д. 1		0101000020E6100000DAAB8F87BE29514044300E2E1D694C40
4790	6	57	1065	9388	42028	\N	56.865662999999998	627350, Тюменская область, Аромашевский район, с. Аромашево, ул. Октябрьская, д. 35		0101000020E61000007D23BA675D295140BA2D910BCE6E4C40
4792	6	57	1065	9388	42252	\N	56.865662999999998	627350, Тюменская область, Аромашевский район, с. Аромашево, ул. Ленина, д. 348		0101000020E61000007D23BA675D295140BA2D910BCE6E4C40
4789	6	57	1065	9388	42252	\N	56.865662999999998	627350, Тюменская область, Аромашевский район, с. Аромашево, ул. Ленина, д. 158		0101000020E61000007D23BA675D295140BA2D910BCE6E4C40
4794	6	57	1065	9388	77042	\N	56.865662999999998	627350, Тюменская область, Аромашевский район, с. Аромашево, ул. Декабристов, д. 12		0101000020E61000007D23BA675D295140BA2D910BCE6E4C40
4791	6	57	1065	9388	42276	\N	56.865662999999998	627350, Тюменская область, Аромашевский район, с. Аромашево, ул. 1 Мая, д. 73		0101000020E61000007D23BA675D295140BA2D910BCE6E4C40
4769	6	57	979	8493	\N	\N	55.991506000000001	627220, Тюменская область, Армизонский район, с. Яровое, ул. Новая, д. 1	Россия, Тюменская область, Армизонский район, село Яровое	0101000020E61000002D08E57D1CE55040D6E429ABE9FE4B40
4787	6	57	979	9292	42401	\N	55.774552999999997	627234, Тюменская область, Армизонский район, с. ЮжноДубровное, ул. Береговая, д. 4		0101000020E6100000BDC62E51BDEB504064027E8D24E34B40
4768	6	57	979	8421	78016	\N	55.954526000000001	627220, Тюменская область, Армизонский район, д. Снегирева, ул. Снегиревская, д. 1Б		0101000020E6100000C3D32B6519F05040429770E82DFA4B40
4767	6	57	979	8413	77756	\N	55.972020000000001	627220, Тюменская область, Армизонский район, д. Семискуль, ул. Семискульская, д. 19		0101000020E610000019C6DD205AEB50406A87BF266BFC4B40
4786	6	57	979	9246	42429	\N	56.118881999999999	627222, Тюменская область, Армизонский район, с. Раздолье, ул. Школьная, д. 28		0101000020E6100000AB96749483CE5040A20A7F86370F4C40
4783	6	57	979	9130	42430	\N	55.919947000000001	627225, Тюменская область, Армизонский район, с. Прохорово, ул. Новая, д. 19		0101000020E61000002979758E01DA5040D386C3D2C0F54B40
4788	6	57	979	9325	77918	\N	55.744743	627234, Тюменская область, Армизонский район, д. Полое, ул. Центральная, д. 19А		0101000020E6100000780E65A88AF15040647616BD53DF4B40
4772	6	57	979	8605	42428	\N	56.025230000000001	627224, Тюменская область, Армизонский район,  д. Плоское, ул. Старина, д. 53		0101000020E610000039F06AB933F35040657094BC3A034C40
4781	6	57	979	9053	42427	\N	55.870906521436503	627233, Тюменская область, Армизонский район, с. Орлово, ул. Школьная, д. 8	Россия, Тюменская область, Армизонский район, село Орлово	0101000020E6100000C7F65AD07BF95040C26D6DE179EF4B40
4779	6	57	979	8937	78023	\N	55.873738000000003	627230, Тюменская область, Армизонский район, д. Няшино, ул. Центральная, д. 1		0101000020E6100000B96DDFA3FE045140E0A293A5D6EF4B40
4775	6	57	979	8771	77920	\N	55.781118999999997	627232, Тюменская область, Армизонский район, д. Новорямова, ул. Мира, д. 6		0101000020E6100000F1D6F9B7CB04514061A417B5FBE34B40
4770	6	57	979	61289	78240	\N	55.893945056544602	627220, Тюменская область, Армизонский район, д. Менщикова, ул. Школьная, д. 9	Россия, Тюменская область, Армизонский район, село Менщиково	0101000020E6100000B81E85EB51E850401CB62DCA6CF24B40
4773	6	57	979	8693	78020	\N	56.109279999999998	627224, Тюменская область, Армизонский район,  д. Крашенева, ул. Крашеневская, д. 26		0101000020E6100000B517D1764CF85040AE0D15E3FC0D4C40
4778	6	57	979	8861	42491	\N	55.963037	627230, Тюменская область, Армизонский район, с. Красноорловское, ул. Республики, д. 1/1		0101000020E61000002634492C29FD504042EBE1CB44FB4B40
4777	6	57	979	8852	42400	\N	56.169874	627223, Тюменская область, Армизонский район, с. Капралиха, ул. Первомайская, д. 11		0101000020E61000001079CBD58FD050406938656EBE154C40
4774	6	57	979	8710	42424	\N	55.759222999999999	627232, Тюменская область, Армизонский район, с. Калмакское, ул. Новая, д. 5		0101000020E610000022533E04550051407DAF21382EE14B40
4771	6	57	979	8592	42426	\N	56.085572339463198	627224, Тюменская область, Армизонский район,  с. Иваново, ул. 50 лет Октября, д. 49	Россия, Тюменская область, Армизонский район, село Иваново	0101000020E61000009082A7902BF1504006BAF605F40A4C40
4780	6	57	979	8976	77841	\N	55.902247000000003	627230, Тюменская область, Армизонский район, д. Забошное, ул. Набережная, д. 38		0101000020E6100000C119FCFD6200514002F566D47CF34B40
4784	6	57	979	9140	42497	\N	55.820359000000003	627225, Тюменская область, Армизонский район, д. Жиряково, ул. Центральная, д. 61		0101000020E6100000BD1DE1B4E0DF504059FD118601E94B40
4785	6	57	979	9211	77862	\N	55.944541000000001	627225, Тюменская область, Армизонский район, д. Вьялково, ул. Центральная, д. 2А		0101000020E6100000FDF675E09CDC5040965D30B8E6F84B40
89049	6	56	\N	4770	18948	\N	60.156219	г. Североуральск, Ленина, 44		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
4766	6	57	979	8204	42108	\N	55.943683999999998	627220, Тюменская область, Армизонский район, с. Армизонское, ул. Рабочая, д. 20		0101000020E610000022179CC1DFEB504015E126A3CAF84B40
4765	6	57	979	8204	42348	\N	55.947055564165403	627220, Тюменская область, Армизонский район, с. Армизонское, ул. Ленина, д. 72	Россия, Тюменская область, Армизонский район, село Армизонское	0101000020E6100000E466B8019FEC504084BD892139F94B40
4763	6	57	979	8204	42020	\N	55.943683999999998	627220, Тюменская область, Армизонский район, с. Армизонское, ул. Кирова, д. 1		0101000020E610000022179CC1DFEB504015E126A3CAF84B40
4764	6	57	979	8204	78207	\N	55.943683999999998	627220, Тюменская область, Армизонский район, с. Армизонское, ул. Карла Маркса, д. 5		0101000020E610000022179CC1DFEB504015E126A3CAF84B40
4731	6	57	784	61344	78633	\N	56.2885633944002	627543, Тюменская область, Абатский район, п. Нефтяников, ул. Лесная, 1	Россия, Тюменская область, Абатский район	0101000020E6100000E223624A249F5140F7EAE3A1EF244C40
4749	6	57	784	7553	42531	\N	56.553640000000001	627547, Тюменская область, Абатский район, д. Яузяк, пер. Школьный, 4		0101000020E61000009C6D6E4C4FAE5140F4E0EEACDD464C40
4720	6	57	784	6095	42580	\N	56.325403999999999	627549, Тюменская область, Абатский район, д. Шипунова, ул. Игнатенко, 20		0101000020E610000084D558C2DA94514069FE98D6A6294C40
4758	6	57	784	7933	42399	\N	56.181840000000001	627550, Тюменская область, Абатский район, с. Шевырино, ул. Маслова, 13		0101000020E61000000874266DAA9D5140658D7A8846174C40
4748	6	57	784	7473	78002	\N	56.505817999999998	627547, Тюменская область, Абатский район, д. Челнокова, ул. Погорельская, 3		0101000020E610000063601DC70FA2514033DDEBA4BE404C40
4755	6	57	784	7804	77876	\N	56.170541	627532, Тюменская область, Абатский район, д. Фирсова, ул. Механизаторов, 8		0101000020E61000005E4A5D328E84514046D09849D4154C40
4752	6	57	784	7661	42526	\N	56.211660630215697	627531, Тюменская область, Абатский район, с. Тушнолобово, ул. Советская, 44	Россия, Тюменская область, Абатский район, село Тушнолобово	0101000020E610000009C556D0B4885140596B28B5171B4C40
4747	6	57	784	7435	42508	\N	56.363911999999999	627544, Тюменская область, Абатский район, д. Тельцова, ул. Школьная, 12		0101000020E610000017BB7D5699AB51409C4F1DAB942E4C40
4760	6	57	784	61282	78195	\N	56.217530181642204	627550, Тюменская область, Абатский район, д. Татарск, ул. Совхозная, 58	Россия, Тюменская область, Абатский район, село Татарская	0101000020E6100000936E4BE4829E51400EF3E505D81B4C40
4723	6	57	784	6275	77859	\N	56.121712000000002	627551, Тюменская область, Абатский район, с. Сычево, ул. Лермонтова, д. 31		0101000020E61000008EAED2DD758D5140F0C34142940F4C40
4726	6	57	784	6408	42395	\N	56.323659050316103	627533, Тюменская область, Абатский район, с. Сысоева, ул. Первомайская, 11	Россия, Тюменская область, Абатский район, село Сысоева	0101000020E610000019ADA3AA098E51402D077AA86D294C40
4739	6	57	784	7056	42495	\N	56.083752891876202	627552, Тюменская область, Абатский район, с. СтараяМаслянка, ул. 60 лет СССР, 57	Россия, Тюменская область, Абатский район, село Старая Маслянка	0101000020E6100000EF8D21003887514090F8156BB80A4C40
4746	6	57	784	7398	42423	\N	56.457667000000001	627545, Тюменская область, Абатский район, д. Спирина, ул. Мира, 12		0101000020E61000009D2E8B89CDAC5140AEBA0ED5943A4C40
4761	6	57	784	8092	77860	\N	56.205561000000003	627562, Тюменская область, Абатский район, д. Смоленка, ул. Зеленая, 23		0101000020E61000006EA12B11A8A85140A22AA6D24F1A4C40
4754	6	57	784	7725	77889	\N	56.196536999999999	627531, Тюменская область, Абатский район, д. Репьева, ул . Аризонская, 15		0101000020E6100000DB317557768751401BBAD91F28194C40
4745	6	57	784	7362	42582	\N	56.518701999999998	627547, Тюменская область, Абатский район, д. Погорелка, ул. Центральная, 34		0101000020E610000004A9143B1AAA5140552FBFD364424C40
4750	6	57	784	7566	77926	\N	56.043543	627563, Тюменская область, Абатский район, п. Партизан, ул. 8 марта, 34		0101000020E610000011FFB0A547B65140207C28D192054C40
4738	6	57	784	6988	77856	\N	56.105319999999999	627552, Тюменская область, Абатский район, д. Пайкова, ул. Школьная, 6		0101000020E610000025581CCEFC885140AFCE31207B0D4C40
4743	6	57	784	7269	42275	\N	56.482374	627545, Тюменская область, Абатский район, с. Ощепково, ул. Пушкина, 12		0101000020E6100000FCE25295B6AC51406938656EBE3D4C40
4740	6	57	784	7110	42398	\N	56.568317	627546, Тюменская область, Абатский район, с. Назарово, ул. 1 Мая, 2		0101000020E61000004B1E4FCB0FB251406361889CBE484C40
4737	6	57	784	6975	77854	\N	56.084238999999997	627552, Тюменская область, Абатский район, д. Мешалкина, ул. Зеленая, 40		0101000020E610000003CFBD874B8451401C06F357C80A4C40
4735	6	57	784	6873	78005	\N	56.049861999999997	627554, Тюменская область, Абатский район, п. Марай, ул. Рабочая, 4		0101000020E6100000A4703D0AD792514015A8C5E061064C40
4736	6	57	784	6901	42425	\N	55.932299	627553, Тюменская область, Абатский район, п. Майский, ул. Юбилейная, 4	Россия, Тюменская область, Абатский район, поселок Майский	0101000020E6100000A437DC476E895140F88BD99255F74B40
4732	6	57	784	6713	42313	\N	56.053179999999998	627554, Тюменская область, Абатский район, п. Ленинка, ул. Ленина, 39		0101000020E61000003196E997889A514090662C9ACE064C40
4729	6	57	784	6601	42581	\N	56.255496999999998	627560, Тюменская область, Абатский район, д. Лапина, ул. Советская, 20		0101000020E61000008448861C5BA55140F19C2D20B4204C40
4725	6	57	784	6384	42397	\N	56.270045036815297	627533, Тюменская область, Абатский район, д. Костылева, ул. Армизонская, 23	Россия, Тюменская область, Абатский район, село Костылева	0101000020E610000046CD57C9C782514063B9A5D590224C40
4727	6	57	784	6487	42373	\N	56.289680321766497	627560, Тюменская область, Абатский район, с. Конево, ул. Советская, 42	Россия, Тюменская область, Абатский район, село Конево	0101000020E6100000815F234910AE51401327F73B14254C40
4751	6	57	784	7624	77997	\N	56.106223	627562, Тюменская область, Абатский район, д. Камышенская, ул. 8 марта, 13		0101000020E610000069723106D6AD5140A08A1BB7980D4C40
88538	6	56	\N	1810	20355	\N	58.6417	город Лесной, Коммунистический. прт, 36		0101000020E61000004D1421753BE54D40EEEBC03923524D40
4762	6	57	784	61284	78205	\N	56.1312841986759	627562, Тюменская область, Абатский район, д. Камышенка, ул. Энергетиков, 12	Россия, Тюменская область, Абатский район, село Камышинка	0101000020E61000007A56D28A6FAA5140793E03EACD104C40
4715	6	57	784	5860	77759	\N	56.343274000000001	627540, Тюменская область, Абатский район, д. Еремина, ул. Маслова, 17		0101000020E6100000B020CD58349E514097C80567F02B4C40
4734	6	57	784	6825	78061	\N	56.025058999999999	627555, Тюменская область, Абатский район, п. Восток, пер. Восточный, 7		0101000020E6100000E2E5E95C51A3514038BC202235034C40
4744	6	57	784	7294	42375	\N	56.425122999999999	627544, Тюменская область, Абатский район, с. Быструха, ул. Центральная, 58		0101000020E610000083F8C08EFFA7514082E3326E6A364C40
4724	6	57	784	6307	42579	\N	56.319297607550801	627533, Тюменская область, Абатский район, с. Болдырево, ул. Молодежная, 22	Россия, Тюменская область, Абатский район, село Болдырево	0101000020E610000081E9B46E83885140D0D6C1C1DE284C40
4714	6	57	784	5802	42475	\N	56.319574000000003	627540, Тюменская область, Абатский район, д. Бобыльск, ул. Зеленая, 10		0101000020E6100000EF53556820A25140725303CDE7284C40
4721	6	57	784	6179	42273	\N	56.116438986808099	627551, Тюменская область, Абатский район, с. Банниково, ул. Гагарина, д. 1	Россия, Тюменская область, Абатский район, село Банниково	0101000020E6100000AC5626FC529251404E7D2079E70E4C40
4712	6	57	784	5555	42046	\N	56.291812999999998	627540, Тюменская область, Абатский район, с. Абатское, ул. Ленина, 102		0101000020E6100000A1D79FC4E79B514019C6DD205A254C40
4710	6	57	784	5555	42046	\N	56.291812999999998	627540, Тюменская область, Абатский район, с. Абатское, ул. Ленина, 14		0101000020E6100000A1D79FC4E79B514019C6DD205A254C40
4713	6	57	784	5555	42249	\N	56.291812999999998	627540, Тюменская область, Абатский район, с. Абатское, ул. Дорожная, 50		0101000020E6100000A1D79FC4E79B514019C6DD205A254C40
4711	6	57	784	5555	42092	\N	56.291812999999998	627540, Тюменская область, Абатский район, с. Абатское, ул. 1 Мая, 56		0101000020E6100000A1D79FC4E79B514019C6DD205A254C40
88976	6	56	\N	50142	\N	\N	56.837738328050797	город Первоуральск, ст. Решеты, Здание семейного общежития, 14		0101000020E61000002CD49AE61D1D4E40E84EB0FF3A6B4C40
89164	6	56	\N	49962	18838	\N	60.182453000000002	Сосьвинский городской округ, п. Восточный, Парковая, 4а		0101000020E610000009FCE1E7BF994D404F07B29E5A174E40
89159	6	56	\N	49906	18265	\N	59.603196553122899	город Серов, село Филькино, Путилова, 4		0101000020E6100000CE70033E3F5A4E40CD052E8F35CD4D40
87000	6	56	\N	50103	78232	\N	58.0403533899918	Туринский городской округ, Горького, 46		0101000020E6100000EB1F4432E4D84F40D3A57F492A054D40
87961	6	56	\N	50169	20171	\N	59.126311000000001	поселок Торфяник, Агатовая, 3		0101000020E61000008FC536A968DA4E40021077F52A904D40
86761	6	56	\N	61096	77281	\N	56.477001113925603	"""""""Сысертский городской округ, микрорайон """"""""Новый"""""""", 29"""""""	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000F451465C006A4E406494675E0E3D4C40
86753	6	56	\N	61096	77272	\N	56.502547098218699	Сысертский городской округ, Энгельса, 23	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000E21E4B1FBA684E40F9D9C87553404C40
86768	6	56	\N	61096	77469	\N	56.497791735911903	Сысертский городской округ, Чапаева, 1		0101000020E6100000FAB31F2922694E40EF1AF4A5B73F4C40
86800	6	56	\N	61096	78235	\N	56.500936702346799	Сысертский городской округ, Трактовая, 15	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000D8101C9771694E409D2D20B41E404C40
86766	6	56	\N	61096	77289	\N	56.497562714270998	Сысертский городской округ, Тимерязева, 168	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000DCBC715298694E408E59F624B03F4C40
86763	6	56	\N	61096	77283	\N	56.495331395948703	Сысертский городской округ, Свердлова, 80	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000066344A2D0684E40F5D89601673F4C40
86707	6	56	\N	61096	77455	\N	56.5013045869715	Сысертский городской округ, Самстроя, 9		0101000020E6100000DD989EB0C4674E40202922C32A404C40
86719	6	56	\N	61096	77192	\N	56.501391458397798	Сысертский городской округ, Розы Люксембург, 56	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000F88BD99255694E401EC18D942D404C40
86756	6	56	\N	61096	77276	\N	56.501787615526403	Сысертский городской округ, Орджоникидзе, 48	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000F2272A1BD66A4E403BC3D4963A404C40
86759	6	56	\N	61096	77278	\N	56.499129305822002	Сысертский городской округ, Ленина, 32	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000E77283A10E674E401BBE8575E33F4C40
86754	6	56	\N	61096	77246	\N	56.5041969179034	Сысертский городской округ, Красноармейская, 32	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E6100000F8FF71C284694E40E3DEFC8689404C40
89195	6	56	\N	49883	19815	\N	56.885396999999998	город Сухой Лог, Юбилейная, 29а		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89208	6	56	\N	49883	77227	\N	56.910168957460797	город Сухой Лог, Октябрьская, 14а	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E6100000FB73D190F1024F40A16AF46A80744C40
89180	6	56	\N	49868	17942	\N	56.9915604079819	город Среднеуральск, Металлистов, 36а	Россия, Свердловская область, городской округ Верхняя Пышма, Среднеуральск	0101000020E6100000874F3A91603E4E40C9022670EB7E4C40
89175	6	56	\N	49868	20066	\N	56.988435177275697	город Среднеуральск, Калинина, 14	Россия, Свердловская область, городской округ Верхняя Пышма, Среднеуральск	0101000020E61000004A5D328E913C4E40639CBF09857E4C40
86877	6	56	\N	49854	17878	\N	56.428618	село Смолинское, Специалистов, 14		0101000020E6100000390F27309DD24E400C3D62F4DC364C40
86418	6	56	\N	49984	19178	\N	58.793835000000001	поселок Сигнальный, Клубная, 29А		0101000020E6100000AB77B81D1AE44D40C8B5A1629C654D40
89088	6	56	\N	6144	\N	\N	59.606825000000001	город Серов, Красногвардейская, 11	Россия, Свердловская область, Серов	0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89100	6	56	\N	6144	19980	\N	59.611935423704502	город Серов, пр.Серова, 67	Россия, Свердловская область, Серов	0101000020E610000055A18158364F4E408E23D6E253CE4D40
89094	6	56	\N	6144	19980	\N	59.611424380807897	город Серов, пр.Серова, 1а	Россия, Свердловская область, Серов	0101000020E610000079E75086AA4C4E40A8FE412443CE4D40
89137	6	56	\N	6144	20359	\N	59.607629371474502	город Серов, пер.Толмачева, 4а	Россия, Свердловская область, Серов	0101000020E6100000F29881CAF8434E40F48C7DC9C6CD4D40
89135	6	56	\N	6144	18910	\N	59.607601590339002	город Серов, Я.Свердлова, 54а	Россия, Свердловская область, Серов	0101000020E610000063EE5A423E4C4E40FA7DFFE6C5CD4D40
89113	6	56	\N	6144	20368	\N	59.601987713977103	город Серов, Ф.Революции, 7	Россия, Свердловская область, Серов	0101000020E6100000D6A9F23D234B4E40CF4A5AF10DCD4D40
89154	6	56	\N	6144	18348	\N	59.606825000000001	город Серов, Строителей, 17		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89149	6	56	\N	6144	18339	\N	59.606825000000001	город Серов, Республиканская, 30		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
87486	6	56	\N	6144	18344	\N	59.606825000000001	город Серов, Попова, 19		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89129	6	56	\N	6144	19828	\N	59.606825000000001	город Серов, Победы, 36		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89092	6	56	\N	6144	18608	\N	59.6205594551068	город Серов, Нансена, 60	Россия, Свердловская область, Серов	0101000020E6100000E5D4CE30B54D4E40861E317A6ECF4D40
89127	6	56	\N	6144	19042	\N	59.606887513794	город Серов, Луначарского, 100	Россия, Свердловская область, Серов	0101000020E61000007C613255304A4E40DC2A8881AECD4D40
89155	6	56	\N	6144	18088	\N	59.606825000000001	город Серов, Ломоносова, 1	Россия, Свердловская область, Серов	0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89145	6	56	\N	6144	18980	\N	59.606825000000001	город Серов, Лесозаводская, 34		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89115	6	56	\N	6144	18142	\N	59.606825000000001	город Серов, Ленина, 167		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89111	6	56	\N	6144	18142	\N	59.605095501182298	город Серов, Ленина, 156	Россия, Свердловская область, Серов	0101000020E6100000DD5D6743FE4B4E40607825C973CD4D40
89109	6	56	\N	6144	18142	\N	59.606337396852297	город Серов, Ленина, 185	Россия, Свердловская область, Серов	0101000020E6100000C1E09A3BFA4B4E4069AD68739CCD4D40
87417	6	56	\N	6144	18142	\N	59.606825000000001	город Серов, Ленина, 193/8		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89158	6	56	\N	6144	18310	\N	59.605795172361603	город Серов, Л.Чайкиной, 31	Россия, Свердловская область, Серов	0101000020E61000007B32FFE89B4A4E40488AC8B08ACD4D40
89102	6	56	\N	6144	18673	\N	59.603616415323202	город Серов, Крупской, 36	Россия, Свердловская область, Серов	0101000020E6100000A08B868C474F4E40D2AB014A43CD4D40
89097	6	56	\N	6144	18673	\N	59.606503834730603	город Серов, Крупской, 33	Россия, Свердловская область, Серов	0101000020E61000006729594E424F4E4054724EECA1CD4D40
89096	6	56	\N	6144	18673	\N	59.606825000000001	Свердловская область, город Серов, Крупской, 24		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89106	6	56	\N	6144	19999	\N	59.608466702774201	город Серов, Короленко, 16	Россия, Свердловская область, Серов	0101000020E6100000A359D93EE44B4E40FDD8243FE2CD4D40
89104	6	56	\N	6144	19999	\N	59.609256288218901	город Серов, Короленко, 35	Россия, Свердловская область, Серов	0101000020E61000008AC91B60E64B4E402672C119FCCD4D40
89143	6	56	\N	6144	18331	\N	59.606825000000001	город Серов, Киселевское шоссе, 10		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89138	6	56	\N	6144	19216	\N	59.597465545339702	город Серов, Кирова, 51	Россия, Свердловская область, Серов	0101000020E6100000111AC1C6F5494E40683C11C479CC4D40
89132	6	56	\N	6144	17992	\N	59.604714860327803	город Серов, Калинина, 22	Россия, Свердловская область, Серов	0101000020E61000002DEA93DC61454E404833164D67CD4D40
89122	6	56	\N	6144	19271	\N	59.596033715291902	город Серов, Каквинская, 3	Россия, Свердловская область, Серов	0101000020E6100000A6B4FE96004A4E40ECA694D74ACC4D40
89116	6	56	\N	6144	18277	\N	59.603014923105498	город Серов, К.Маркса, 24	Россия, Свердловская область, Серов	0101000020E610000065C22FF5F34A4E40ACFF73982FCD4D40
89123	6	56	\N	6144	18279	\N	59.606825000000001	Свердловская область, город Серов, Зеленая, 7		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89119	6	56	\N	6144	18279	\N	59.602333037906199	город Серов, Зеленая, 14	Россия, Свердловская область, Серов	0101000020E61000001EE0490B97494E409A266C3F19CD4D40
87451	6	56	\N	6144	18279	\N	59.606825000000001	город Серов, Зеленая, 1а		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89126	6	56	\N	6144	19820	\N	59.606743082421602	город Серов, Заславского, 34	Россия, Свердловская область, Серов	0101000020E61000006B9BE27151494E40D9092FC1A9CD4D40
89151	6	56	\N	6144	20111	\N	59.606825000000001	город Серов, Восточная, 10а		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89141	6	56	\N	6144	18627	\N	59.611688567853598	город Серов, 8 Марта, 16	Россия, Свердловская область, Серов	0101000020E6100000499C1551134D4E4056293DD34BCE4D40
89073	6	56	\N	6144	19833	\N	59.606825000000001	город Серов, 20 Партсъезда, 13		0101000020E610000017299485AF4B4E4096B20C71ACCD4D40
89146	6	56	\N	6144	18688	\N	59.6082514084002	город Серов, 1 Овощная ферма, 37	Россия, Свердловская область, Серов	0101000020E610000041295AB9174A4E403161342BDBCD4D40
89320	6	56	\N	4770	\N	\N	60.156219	г.Североуральск, очистные сооружения шахты 1616 бис		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89055	6	56	\N	4770	20028	\N	60.156219	г.Североуральск, Степана Разина, 1		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89066	6	56	\N	4770	18233	\N	60.156219	г.Североуральск, поселок ПокровскУральский, Советская, 28		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89047	6	56	\N	4770	18233	\N	60.1451573957685	г. Североуральск, Советская, 41		0101000020E610000094F8DC09F6F74D408AE42B8194124E40
89059	6	56	\N	4770	18400	\N	60.156219	г.Североуральск, Свердлова, 5		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89058	6	56	\N	4770	18400	\N	60.156219	г.Североуральск, Свердлова, 44		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89323	6	56	\N	4770	18308	\N	60.156219	г.Североуральск, Молодежная, 22		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89064	6	56	\N	4770	18308	\N	60.153534082245301	г.Североуральск, Молодежная, 4	Россия, Свердловская область, Североуральск	0101000020E6100000E3DF675C38FA4D407B698A00A7134E40
89084	6	56	\N	4770	18948	\N	60.156219	г.Североуральск, поселок Черемухово, Ленина, 7		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89053	6	56	\N	4770	18948	\N	60.156219	г. Североуральск, Ленина, 24		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89069	6	56	\N	4770	20182	\N	60.207636699551003	г.Североуральск, поселок Третий Северный, Комсомольская, 44		0101000020E6100000CAC16C020CFB4D40433866D9931A4E40
89072	6	56	\N	4770	20326	\N	60.156219	г.Североуральск, поселок Калья, Комарова, 13А		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89083	6	56	\N	4770	17899	\N	60.146345025638901	г.Североуральск, село ВсеволодоБлагодатское, Кирова, 21	Россия, Свердловская область, Североуральск	0101000020E61000001E54E23AC6F74D407077D66EBB124E40
89052	6	56	\N	4770	19362	\N	60.156219	г.Североуральск, Каржавина, 27		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89067	6	56	\N	4770	78523	\N	60.158343123225102	г. Североуральск, поселок Баяновка, Гагарина, 7	Россия, Свердловская область, городской округ Североуральск, поселок Баяновка	0101000020E6100000A19FA9D72DDE4D4078465B9544144E40
89061	6	56	\N	4770	18745	\N	60.156219	г.Североуральск, Ватутина, 17А		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89325	6	56	\N	4770	20393	\N	60.156219	г.Североуральск, поселок Каль, Больничный переулок, 5		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
89258	6	56	\N	4770	18725	\N	60.156219	г.Североуральск, Советская, 71		0101000020E61000008A3DB48F15FC4D40C501F4FBFE134E40
86614	6	56	\N	49895	20118	\N	57.352840999999998	Реж, Спортивная, 1а		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86618	6	56	\N	49895	77423	\N	57.368780872775403	Режевский район, Советская, 34	Россия, Свердловская область, Режевский район, Реж	0101000020E6100000C9AD49B725B44E406E313F3734AF4C40
86631	6	56	\N	49895	18188	\N	57.352840999999998	Реж, П.Морозова, 58		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86606	6	56	\N	6072	\N	\N	56.802100000000003	"""""""Ревда, Бытовые помещения участка подготовки материалов ЭСПЦ """"""""НСММЗ"""""""""""""""		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86604	6	56	\N	6072	\N	\N	56.802100000000003	Ревда, Дом культуры поселка Кирзавод		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86600	6	56	\N	6072	20089	\N	56.808462957342101	Ревда, Энгельса, 47	Россия, Свердловская область, Ревда	0101000020E6100000B0C7444AB3F54D40568330B77B674C40
83661	6	56	\N	6072	20396	\N	56.800326902091797	Ревда, Чехова, 15	Россия, Свердловская область, Ревда	0101000020E6100000F3E7DB82A5F64D408B8D791D71664C40
86597	6	56	\N	6072	77064	\N	56.802100000000003	Ревда, Чайковского, 27		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86596	6	56	\N	6072	18542	\N	56.802100000000003	Ревда, Цветников, 36		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86590	6	56	\N	6072	18542	\N	56.796239034787703	Ревда, Цветников, 46	Россия, Свердловская область, Ревда	0101000020E61000003274ECA012F54D405E66D828EB654C40
82541	6	56	\N	6072	20247	\N	56.800899641444502	Ревда, Толстого, 1	Россия, Свердловская область, Ревда	0101000020E6100000DBBFB2D2A4F64D40E6AE25E483664C40
86588	6	56	\N	6072	18504	\N	56.795601099620399	Ревда, Спортивная, 16	Россия, Свердловская область, Ревда	0101000020E6100000A9F57EA31DF34D401BD5E940D6654C40
82944	6	56	\N	6072	18504	\N	56.791469366082801	Ревда, Спортивная, 2	Россия, Свердловская область, Ревда	0101000020E610000004E44BA8E0F24D401F662FDB4E654C40
86610	6	56	\N	6072	78521	\N	56.802100000000003	Ревда, С.Разина, 20а		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86595	6	56	\N	6072	18135	\N	56.802100000000003	Ревда, Российская, 44		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86585	6	56	\N	6072	18135	\N	56.794482405051802	Ревда, Российская, 12	Россия, Свердловская область, Ревда	0101000020E61000009A6038D730F34D405EA10F96B1654C40
86592	6	56	\N	6072	78577	\N	56.802100000000003	Ревда, Павла Зыкина, 32		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86601	6	56	\N	6072	18985	\N	56.802100000000003	Ревда, П.Зыкина, 38		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86599	6	56	\N	6072	18985	\N	56.802100000000003	Ревда, П.Зыкина, 18		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
82059	6	56	\N	6072	20074	\N	56.802100000000003	Ревда, Нахимова, 1		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86594	6	56	\N	6072	18096	\N	56.796964345535798	Ревда, Мира, 42	Россия, Свердловская область, Ревда	0101000020E6100000CC61F71DC3F54D40700B96EA02664C40
86587	6	56	\N	6072	18096	\N	56.802100000000003	Ревда, Мира, 26а		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86603	6	56	\N	6072	18149	\N	56.802100000000003	Ревда, МаминаСибиряка, 94		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86611	6	56	\N	6072	19102	\N	56.802100000000003	Ревда, М.Горького, 40		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86591	6	56	\N	6072	19102	\N	56.802100000000003	Ревда, М.Горького, 5		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86607	6	56	\N	6072	18148	\N	56.801897380562501	Ревда, Лесная, 2	Россия, Свердловская область, Ревда	0101000020E61000004701A260C6F64D4058E1968FA4664C40
86602	6	56	\N	6072	18710	\N	56.803957524470903	Ревда, Ленина, 18		0101000020E6100000B3B5BE4868F74D40C5AD8218E8664C40
87299	6	56	\N	6072	20336	\N	56.702046000000003	город Дегтярск, Калинина, 31А		0101000020E6100000AB05F698480D4E40D124B1A4DC594C40
86598	6	56	\N	6072	18115	\N	56.802100000000003	Ревда, К.Либкнехта, 64		0101000020E61000004F232D95B7F74D40910F7A36AB664C40
86586	6	56	\N	6072	18094	\N	56.801901151465401	Ревда, Жуковского, 22	Россия, Свердловская область, Ревда	0101000020E6100000790778D2C2F74D409AD024B1A4664C40
83799	6	56	\N	6072	20262	\N	56.802551947304501	Ревда, Азина, 58	Россия, Свердловская область, Ревда	0101000020E6100000BC0853944BF54D4071AB2006BA664C40
89016	6	56	\N	1641	19831	\N	56.506451165570297	город Полевской, Зеленый Бор  1, 26	Россия, Свердловская область, Полевской	0101000020E6100000B47405DB88214E406403E962D3404C40
88995	6	56	\N	1641	19041	\N	56.457929999999998	город Полевской, Ялунина, 7, А		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
88993	6	56	\N	1641	19041	\N	56.457929999999998	город Полевской, Ялунина, 7,А		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89023	6	56	\N	1641	17868	\N	56.455489782821601	город Полевской, Челюскинцев, 1	Россия, Свердловская область, Полевской	0101000020E61000005C3D27BD6F184E40D8D30E7F4D3A4C40
89014	6	56	\N	1641	19215	\N	56.457929999999998	город Полевской, Ст. Разина, 51		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89011	6	56	\N	1641	19215	\N	56.457929999999998	город Полевской, Ст. Разина, 48		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89033	6	56	\N	1641	18814	\N	56.532901000000003	"""""""Свердловская область, город Полевской, поселок Красная Горка, Северская 1а """		0101000020E6100000F88C446804214E40BB80971936444C40
89008	6	56	\N	1641	18441	\N	56.448883047216	город Полевской, Р. Люксембург, 95	Россия, Свердловская область, Полевской	0101000020E6100000FC53AA44D9174E407D5D86FF74394C40
89002	6	56	\N	1641	18441	\N	56.492969470897798	город Полевской, Р. Люксембург, 4	Россия, Свердловская область, Полевской	0101000020E6100000F3203D450E1F4E408E78B29B193F4C40
89018	6	56	\N	1641	18456	\N	56.457929999999998	город Полевской, Победы, 26		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
88992	6	56	\N	1641	18425	\N	56.457929999999998	город Полевской, Партизанская, 38	Россия, Свердловская область, Полевской	0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89028	6	56	\N	1641	18790	\N	56.457929999999998	город Полевской, Микрорайон 2, 15		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89031	6	56	\N	1641	18726	\N	56.446316090581597	город Полевской, Малышева, 65	Россия, Свердловская область, Полевской	0101000020E6100000FB1F60ADDA174E403DD7F7E120394C40
89038	6	56	\N	1641	18774	\N	56.6302758135988	город Полевской, село Курганово, Ленина, 70	Россия, Свердловская область, городской округ Полевской, поселок Курганово	0101000020E61000003543AA285E314E4013BA4BE2AC504C40
88999	6	56	\N	1641	18774	\N	56.450515622004801	город Полевской, Ленина, 16	Россия, Свердловская область, Полевской	0101000020E6100000F38DE89E75194E4091291F82AA394C40
89010	6	56	\N	1641	18533	\N	56.457929999999998	город Полевской, Коммунистическая, 31		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89005	6	56	\N	1641	18533	\N	56.457929999999998	город Полевской, Коммунистическая, 14		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
88998	6	56	\N	1641	18533	\N	56.4573907879522	город Полевской, Коммунистическая, 3	Россия, Свердловская область, Полевской	0101000020E610000075CB0EF10F1B4E400C3ECDC98B3A4C40
89030	6	56	\N	1641	17741	\N	56.457929999999998	город Полевской, К. Маркса, 2, Б		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89025	6	56	\N	1641	17741	\N	56.458467950851002	город Полевской, К. Маркса, 2	Россия, Свердловская область, Полевской	0101000020E61000004F9143C4CD1B4E409B215514AF3A4C40
89022	6	56	\N	1641	17741	\N	56.440420938562802	город Полевской, К. Маркса, 11	Россия, Свердловская область, Полевской	0101000020E61000001A33897AC1154E405EBC1FB75F384C40
89004	6	56	\N	1641	18080	\N	56.457929999999998	город Полевской, Вершинина, 37		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
89039	6	56	\N	1641	78431	\N	56.543110206767899	город Полевской, село Мраморское, 1 Мая, 17		0101000020E610000069E55E6056344E40B610E4A084454C40
89019	6	56	\N	1641	19030	\N	56.457929999999998	город Полевской, К. Маркса, 12		0101000020E61000007995B54DF11A4E40BBED42739D3A4C40
88975	6	56	\N	16	\N	\N	56.852978190784498	город Первоуральск, ж/ст Хрустальная, Здание столовой (библиотеки)		0101000020E6100000501DAB949E174E408F1A13622E6D4C40
88888	6	56	\N	16	19234	\N	56.904985258743501	город Первоуральск, Ильича проспект, 6	Россия, Свердловская область, Первоуральск	0101000020E610000054E6E61BD1F74D406F2F698CD6734C40
88939	6	56	\N	16	20197	\N	56.905404504769002	город Первоуральск, пос. Магнитка, Энгельса, 13А	Россия, Свердловская область, городской округ Первоуральск	0101000020E610000097AAB4C535FC4D404451A04FE4734C40
88885	6	56	\N	16	18153	\N	56.893853999999997	город Первоуральск, Чкалова, 17		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88880	6	56	\N	16	18153	\N	56.893853999999997	город Первоуральск, Чкалова, 26		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88891	6	56	\N	16	18854	\N	56.9019117136368	город Первоуральск, Трубников, 64а	Россия, Свердловская область, Первоуральск	0101000020E6100000700B96EA02FA4D405BEF37DA71734C40
88878	6	56	\N	16	18854	\N	56.893853999999997	город Первоуральск, Трубников, 46а		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88905	6	56	\N	16	18487	\N	56.910270384601503	город Первоуральск, Строителей, 7	Россия, Свердловская область, Первоуральск	0101000020E6100000ACE4637781FA4D40D44334BA83744C40
88904	6	56	\N	16	18487	\N	56.893853999999997	Свердловская область, город Первоуральск, Строителей, 7		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88898	6	56	\N	16	18487	\N	56.909809007783103	город Первоуральск, Строителей, 9	Россия, Свердловская область, Первоуральск	0101000020E6100000779D0DF967FA4D40A14D0E9F74744C40
88969	6	56	\N	16	18027	\N	57.0262510647376	город Первоуральск, с. Слобода, Советская, 48	Россия, Свердловская область, городской округ Первоуральск, поселок Слобода	0101000020E610000099F5622827C64D40603E59315C834C40
88940	6	56	\N	16	18027	\N	56.909542597470001	город Первоуральск, с. Нижнее Село, Советская, 13	Россия, Свердловская область, Первоуральск	0101000020E61000001C7E37DDB2F74D4022A7AFE76B744C40
88865	6	56	\N	16	18027	\N	56.912365627697298	город Первоуральск, Советская, 20в	Россия, Свердловская область, Первоуральск	0101000020E61000005FB532E197F64D40BDFDB968C8744C40
88935	6	56	\N	16	18292	\N	56.896040737582801	город Первоуральск, пос. СТИ, Сантехизделий, 34	Россия, Свердловская область, Первоуральск	0101000020E6100000FC6D4F90D8F04D400470B378B1724C40
88925	6	56	\N	16	18676	\N	56.893853999999997	"""""""город Первоуральск, СХПК """"""""Первоуральский"""""""", 8"""""""		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88937	6	56	\N	16	18651	\N	56.896075966201899	город Первоуральск, пос. СТИ, СТИ, 34	Россия, Свердловская область, Первоуральск	0101000020E6100000CE5147C7D5F04D40815D4D9EB2724C40
88932	6	56	\N	16	17767	\N	56.893926959390598	город Первоуральск, Динас, Пушкина, 11а	Россия, Свердловская область, Первоуральск	0101000020E610000077D66EBBD0FA4D4075012F336C724C40
88929	6	56	\N	16	18278	\N	56.905152095564297	город Первоуральск, Динас, Ильича, 13	Россия, Свердловская область, Первоуральск	0101000020E61000003FC7478B33F84D405AF44E05DC734C40
88943	6	56	\N	16	17804	\N	56.920047175708703	город Первоуральск, Пролетарская, 70	Россия, Свердловская область, Первоуральск	0101000020E610000019AE0E80B8F74D4036E49F19C4754C40
88919	6	56	\N	16	19387	\N	56.893853999999997	Свердловская область, город Первоуральск, Пархоменко, 12		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88886	6	56	\N	16	18868	\N	56.893853999999997	город Первоуральск, Папанинцев, 8		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88962	6	56	\N	16	78537	\N	56.889383306003701	город Первоуральск, п. Перескачка, Новая, 4	Россия, Свердловская область, городской округ Первоуральск, поселок Перескачка	0101000020E6100000E1CE85915EBE4D40274F594DD7714C40
88942	6	56	\N	16	18303	\N	56.893809523747898	город Первоуральск, пос. Мгнитка, Набережная, 9	Россия, Свердловская область, Первоуральск	0101000020E610000086713788D6FA4D403C6BB75D68724C40
88897	6	56	\N	16	18523	\N	56.893853999999997	город Первоуральск, Ленина, 21б		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88964	6	56	\N	16	17910	\N	56.989982360459202	город Первоуральск, п. Новоуткинск, Крупской, 49		0101000020E610000051F4C0C760C74D4078D0ECBAB77E4C40
88861	6	56	\N	16	18119	\N	56.893853999999997	город Первоуральск, Красноармейская, 22		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88871	6	56	\N	16	18121	\N	56.907740676108503	город Первоуральск, Космонавтов, 12	Россия, Свердловская область, Первоуральск	0101000020E61000002B31CF4A5AF74D40821E6ADB30744C40
88868	6	56	\N	16	18121	\N	56.9056921317747	город Первоуральск, Космонавтов, 1	Россия, Свердловская область, Первоуральск	0101000020E6100000931804560EF74D40DA1F28B7ED734C40
88867	6	56	\N	16	18121	\N	56.910428852491798	город Первоуральск, Космонавтов, 15а	Россия, Свердловская область, Первоуральск	0101000020E610000006B98B3045F74D403D2AFEEF88744C40
88862	6	56	\N	16	18121	\N	56.893853999999997	город Первоуральск, Космонавтов, 19		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88911	6	56	\N	16	18213	\N	56.896580906078199	город Первоуральск, Комсомольская, 1В	Россия, Свердловская область, Первоуральск	0101000020E6100000F641960513FB4D40849B8C2AC3724C40
88877	6	56	\N	16	18213	\N	56.893853999999997	город Первоуральск, Комсомольская, 21б		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88948	6	56	\N	16	18969	\N	56.962359766027099	город Первоуральск, п. Билимбай, Коммуны, 2	Россия, Свердловская область, городской округ Первоуральск, поселок Билимбай	0101000020E61000001C615111A7E74D40417DCB9C2E7B4C40
88966	6	56	\N	16	18537	\N	56.893853999999997	город Первоуральск, п. Новоуткинск, Клубная, 32		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88913	6	56	\N	16	20234	\N	56.891873087083098	город Первоуральск, Карбышева, 1	Россия, Свердловская область, Первоуральск	0101000020E61000005839B4C876FC4D40BB97FBE428724C40
88915	6	56	\N	16	18852	\N	56.893853999999997	город Первоуральск, Калинина, 30		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88893	6	56	\N	16	17914	\N	56.902768798633304	город Первоуральск, Ильича проспект, 28а	Россия, Свердловская область, Первоуральск	0101000020E61000001FB935E9B6FA4D40DB6B41EF8D734C40
88931	6	56	\N	16	18276	\N	56.893853999999997	город Первоуральск, Динас, Ильича, 7		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88954	6	56	\N	16	18678	\N	56.893853999999997	город Первоуральск, п. Вересовка, Заводская, 17		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88923	6	56	\N	16	78264	\N	56.885691000000001	город Первоуральск, пос. НовоТалица, З.Космодемьянской, 20		0101000020E6100000AB3FC23060014E4047AE9B525E714C40
88882	6	56	\N	16	19133	\N	56.957911774130899	город Первоуральск, Гагарина, 77	Россия, Свердловская область, городской округ Первоуральск	0101000020E61000002098A3C7EFFB4D40153944DC9C7A4C40
88875	6	56	\N	16	18561	\N	56.906549129665301	город Первоуральск, Ватутина, 73б	Россия, Свердловская область, Первоуральск	0101000020E6100000C6C4E6E3DAF84D405A9C31CC09744C40
88873	6	56	\N	16	18561	\N	56.906621034412403	город Первоуральск, Ватутина, 45 а	Россия, Свердловская область, Первоуральск	0101000020E610000009E23C9CC0F84D40F46E2C280C744C40
88906	6	56	\N	16	18833	\N	56.893853999999997	Свердловская область, город Первоуральск, Вайнера, 21А		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88903	6	56	\N	16	18833	\N	56.893853999999997	город Первоуральск, Вайнера, 7		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88917	6	56	\N	16	18189	\N	56.920434438622998	город Первоуральск, Береговая, 48	Россия, Свердловская область, Первоуральск	0101000020E6100000A968ACFD9DF94D40301004C8D0754C40
88900	6	56	\N	16	18189	\N	56.893853999999997	город Первоуральск, Береговая, 58		0101000020E61000005C8DEC4ACBFA4D400BB3D0CE69724C40
88927	6	56	\N	16	18515	\N	56.890034944831598	город Первоуральск, Динас, 50 лет СССР, 11а	Россия, Свердловская область, Первоуральск	0101000020E6100000C00644882BF14D40CEA5B8AAEC714C40
88920	6	56	\N	16	17802	\N	56.921464644683397	город Первоуральск, п. Пильная, 1ая Пильная, 1А	Россия, Свердловская область, Первоуральск	0101000020E6100000A725564623054E404EB4AB90F2754C40
88894	6	56	\N	16	18180	\N	56.905903448157297	город Первоуральск, 1 Мая, 4А	Россия, Свердловская область, Первоуральск	0101000020E61000000FEECEDA6DF94D40952C27A1F4734C40
95007	6	56	\N	61334	78586	\N	61.017660999999997	Пелым Фестивальная, 12		0101000020E61000009A5B21ACC6FE4E4013B534B742824E40
88833	6	56	\N	49886	18089	\N	57.244922000000003	город Новоуральск, Чурина, 3		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88842	6	56	\N	49886	20079	\N	57.241727591987797	город Новоуральск, Ленина, 69	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E61000002DEE3F321D0C4E4085436FF1F09E4C40
88837	6	56	\N	49886	20389	\N	57.244922000000003	город Новоуральск, Гагарина, 11		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88526	6	56	\N	1810	19182	\N	58.6417	город Лесной, Энгельса, 1		0101000020E61000004D1421753BE54D40EEEBC03923524D40
86409	6	56	\N	1810	18832	\N	58.612037999999998	город Нижняя Тура, Чкалова, 11		0101000020E6100000A2ED98BA2BED4D4062F4DC42574E4D40
86413	6	56	\N	1810	18872	\N	58.612037999999998	город Нижняя Тура, Пархоменко, 2		0101000020E6100000A2ED98BA2BED4D4062F4DC42574E4D40
86422	6	56	\N	1810	20342	\N	58.644435000000001	поселок Платина, Набережная, 17		0101000020E6100000E49EAEEE58184E40EAB298D87C524D40
86411	6	56	\N	1810	17917	\N	58.633668003254598	город Нижняя Тура, Молодежная, 10	Россия, Свердловская область, Нижняя Тура	0101000020E6100000B779E3A430ED4D40C84274081C514D40
86412	6	56	\N	1810	18169	\N	58.620245006653001	город Нижняя Тура, Машиностроителей, 17А	Россия, Свердловская область, Нижняя Тура	0101000020E6100000FA298E03AFF04D40F6402B30644F4D40
86358	6	56	\N	1810	19088	\N	58.619461447147302	город Нижняя Тура, Малышева, 26	Россия, Свердловская область, Нижняя Тура	0101000020E610000019E42EC214EF4D40E012807F4A4F4D40
88563	6	56	\N	1810	20199	\N	58.6417	город Лесной, Ленина, 112		0101000020E61000004D1421753BE54D40EEEBC03923524D40
86417	6	56	\N	1810	20199	\N	58.797289854605097	поселок Косья, Ленина, 55		0101000020E6100000CF4BC5C6BCAC4D40C3B645990D664D40
86381	6	56	\N	1810	20094	\N	58.614071100116902	город Нижняя Тура, Гайдара, 4	Россия, Свердловская область, Нижняя Тура	0101000020E610000041B7973446F14D400536E7E0994E4D40
86410	6	56	\N	1810	77078	\N	58.612037999999998	город Нижняя Тура, 40 лет Октября, 1Д		0101000020E6100000A2ED98BA2BED4D4062F4DC42574E4D40
88584	6	56	\N	12051	18105	\N	58.072651870682101	город Нижняя Cалда, село Акинфиево, Центральная, 52	Россия, Свердловская область, Нижняя Салда	0101000020E61000009E3F6D54A75B4E4097FE25A94C094D40
88574	6	56	\N	12051	19355	\N	58.072470000000003	город Нижняя Cалда, Фрунзе, 11		0101000020E6100000D1E638B7095D4E4077F86BB246094D40
88569	6	56	\N	12051	18669	\N	58.072470000000003	город Нижняя Cалда, Строителей, 14		0101000020E6100000D1E638B7095D4E4077F86BB246094D40
88571	6	56	\N	12051	17807	\N	58.072470000000003	город Нижняя Cалда, Строителей, 21		0101000020E6100000D1E638B7095D4E4077F86BB246094D40
88537	6	56	\N	12051	17807	\N	58.073788766462499	город Нижняя Салда, Строителей, 21	Россия, Свердловская область, Нижняя Салда	0101000020E6100000E27327D87F5D4E40FBE6FEEA71094D40
88581	6	56	\N	12051	20407	\N	58.072742823681899	город Нижняя Cалда, Совхозная, 17 А	Россия, Свердловская область, Нижняя Салда	0101000020E61000005CAAD216D75C4E40A80183A44F094D40
88578	6	56	\N	12051	18332	\N	58.072470000000003	город Нижняя Cалда, Привокзальная, 21		0101000020E6100000D1E638B7095D4E4077F86BB246094D40
88585	6	56	\N	12051	20169	\N	58.072470000000003	город Нижняя Cалда, село  Медведево, Первая, 34		0101000020E6100000D1E638B7095D4E4077F86BB246094D40
88579	6	56	\N	12051	19992	\N	58.074470886487198	город Нижняя Cалда, К. Либкнехта, 79	Россия, Свердловская область, Нижняя Салда	0101000020E61000008194D8B5BD5D4E400EC0064488094D40
88576	6	56	\N	12051	18624	\N	58.072470000000003	город Нижняя Cалда, К.Маркса, 2		0101000020E6100000D1E638B7095D4E4077F86BB246094D40
88772	6	56	\N	9945	\N	\N	57.925403000000003	Свердловская область, город Нижний Тагил, Тагилстроевский район		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88750	6	56	\N	9945	\N	\N	57.922845687524003	"""""""город Нижний Тагил, Санаторий  """"""""Руш"""""""", клуб санатория """"""""Руш"""""""""""""""	Россия, Свердловская область, Нижний Тагил	0101000020E6100000A0A70183A4FF4D40499F56D11FF64C40
88672	6	56	\N	9945	17985	\N	57.914921421102498	город Нижний Тагил, пр. Мира, 27	Россия, Свердловская область, Нижний Тагил	0101000020E61000004AB20E4757FD4D4039B69E211CF54C40
88800	6	56	\N	9945	19347	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, проспект Мира, 67		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88798	6	56	\N	9945	17990	\N	57.923319489343903	город Нижний Тагил, Тагилстроевский район, проспект Мира, 58	Россия, Свердловская область, Нижний Тагил	0101000020E61000003672DD94F2FC4D40416326512FF64C40
88674	6	56	\N	9945	19876	\N	57.922480342076803	город Нижний Тагил, пр. Мира, 9	Россия, Свердловская область, Нижний Тагил	0101000020E610000082AD122C0EFD4D40679B1BD313F64C40
88603	6	56	\N	9945	20409	\N	57.905754927238803	город Нижний Тагил, Дзержинский район, Юности, 37	Россия, Свердловская область, Нижний Тагил	0101000020E61000000EDAAB8F870C4E402098A3C7EFF34C40
88599	6	56	\N	9945	17964	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Энтузиастов, 15	Россия, Свердловская область, Нижний Тагил	0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88593	6	56	\N	9945	17964	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Энтузиастов, 1А	Россия, Свердловская область, Нижний Тагил	0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88630	6	56	\N	9945	17959	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Энтузиастов, 35		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88665	6	56	\N	9945	18654	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Щорса, 8А		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88663	6	56	\N	9945	18654	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Щорса, 2		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88775	6	56	\N	9945	18690	\N	57.945444180311803	город Нижний Тагил, Тагилстроевский район, Черноморская, 98	Россия, Свердловская область, Нижний Тагил	0101000020E6100000624A24D1CB004E4087191A4F04F94C40
88770	6	56	\N	9945	18690	\N	57.945330082390299	город Нижний Тагил, Тагилстроевский район, Черноморская, 106	Россия, Свердловская область, Нижний Тагил	0101000020E6100000B1A6B228EC004E40BEF6CC9200F94C40
88749	6	56	\N	9945	19959	\N	57.801712428608298	город Нижний Тагил, ул. Черноисточинское шоссе, 82	Россия, Свердловская область, Пригородный район	0101000020E610000091D0967329F44D40C767B27F9EE64C40
88744	6	56	\N	9945	19959	\N	57.925403000000003	город Нижний Тагил, ул. Черноисточинчкое шоссе, 60		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88743	6	56	\N	9945	19959	\N	57.880486445196901	город Нижний Тагил, ул. Черноисточинское шоссе, 60	Россия, Свердловская область, Нижний Тагил	0101000020E610000047CCECF318F94D40FD4AE7C3B3F04C40
88813	6	56	\N	9945	18281	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Черноисточинское шоссе, 13		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88739	6	56	\N	9945	20064	\N	57.918461295898901	город Нижний Тагил, ул. Челюскинцев, 61	Россия, Свердловская область, Нижний Тагил	0101000020E6100000E36DA5D766F94D4063D34A2190F54C40
88670	6	56	\N	9945	20090	\N	57.916954037182599	город Нижний Тагил, ул. Циолковского, 41	Россия, Свердловская область, Нижний Тагил	0101000020E61000003EEB1A2D07FC4D40DBF7A8BF5EF54C40
88767	6	56	\N	9945	19334	\N	57.927389359745199	город Нижний Тагил, Тагилстроевский район, Хохрякова, 23	Россия, Свердловская область, Нижний Тагил	0101000020E61000002313F06B24014E40C7D5C8AEB4F64C40
88712	6	56	\N	9945	20135	\N	57.920755066659702	город Нижний Тагил, ул. Фрунзе, 58/33	Россия, Свердловская область, Нижний Тагил	0101000020E610000099F38C7DC9F84D407250C24CDBF54C40
88722	6	56	\N	9945	18613	\N	57.925403000000003	город Нижний Тагил, ул. Фрунзе, 25А		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88719	6	56	\N	9945	18613	\N	57.918883773691803	город Нижний Тагил, ул. Фрунзе, 39	Россия, Свердловская область, Нижний Тагил	0101000020E6100000AA471ADCD6F84D40A968ACFD9DF54C40
88825	6	56	\N	9945	20015	\N	57.947269697521698	город Нижний Тагил, Тагилстроевский район, Уральский проспект, 60а	Россия, Свердловская область, Нижний Тагил	0101000020E6100000C4D0EAE40CFB4D40B03DB32440F94C40
88827	6	56	\N	9945	18055	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Уральский проспект, 78		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88627	6	56	\N	9945	19860	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Тимирязева, 109		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88820	6	56	\N	9945	18023	\N	57.943253436582097	город Нижний Тагил, Тагилстроевский район, Тагилстроевская, 1а		0101000020E6100000000341800C014E404C6DA983BCF84C40
88817	6	56	\N	9945	20272	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Тагилстроевская, 1б		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88677	6	56	\N	9945	18134	\N	57.925403001185501	город Нижний Тагил, ул. Строителей, 7	Россия, Свердловская область, Нижний Тагил	0101000020E610000074999A046F004E40664F029B73F64C40
88747	6	56	\N	9945	20382	\N	57.886784098579597	город Нижний Тагил, ул. Совхозная, 7	Россия, Свердловская область, Нижний Тагил	0101000020E61000000AA359D93EFA4D40DB4E5B2382F14C40
88763	6	56	\N	9945	18326	\N	57.943869596827199	город Нижний Тагил, Тагилстроевский район, Сланцевая, 13а	Россия, Свердловская область, Нижний Тагил	0101000020E610000041800C1D3BFE4D4077D66EBBD0F84C40
88650	6	56	\N	9945	20072	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Свердлова, 23А	Россия, Свердловская область, Нижний Тагил	0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88785	6	56	\N	9945	18675	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Решетникова, 29		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88783	6	56	\N	9945	18317	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Проезжая, 21		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88777	6	56	\N	9945	19339	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Попова, 17		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88734	6	56	\N	9945	18633	\N	57.924124367207199	город Нижний Тагил, ул. Полуденская, 25	Россия, Свердловская область, городской округ Нижний Тагил	0101000020E61000005358A9A0A2F04D406FB9FAB149F64C40
86517	6	56	\N	9945	20253	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Покровское1, 65		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88810	6	56	\N	9945	18766	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Победы, 35		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88654	6	56	\N	9945	18801	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Пихтовая, 12А		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88657	6	56	\N	9945	18093	\N	57.906274549273398	город Нижний Тагил, Дзержинский район, Пихтовая, 16	Россия, Свердловская область, Нижний Тагил	0101000020E6100000A857CA32C4F34D405917B7D100F44C40
88765	6	56	\N	9945	18856	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Перова, 133		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88589	6	56	\N	9945	19005	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Патона, 7		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88802	6	56	\N	9945	18160	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Пархоменко, 109		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88698	6	56	\N	9945	18160	\N	57.926927027516101	город Нижний Тагил, ул. Пархоменко, 13	Россия, Свердловская область, Нижний Тагил	0101000020E6100000C5FEB27BF2004E40C3633F8BA5F64C40
88659	6	56	\N	9945	18728	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Парковая, 13		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88680	6	56	\N	9945	18550	\N	57.925403000000003	город Нижний Тагил, ул. Островского, 3		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88707	6	56	\N	9945	19915	\N	57.925403000000003	город Нижний Тагил, ул. Оплетина, 11а	Россия, Свердловская область, Нижний Тагил	0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88706	6	56	\N	9945	18593	\N	57.916773842837699	город Нижний Тагил, ул. Оплетина, 11А	Россия, Свердловская область, Нижний Тагил	0101000020E610000098DA520779FD4D405BE9B5D958F54C40
88703	6	56	\N	9945	18593	\N	57.925425833519697	город Нижний Тагил, ул. Оплетина, 10	Россия, Свердловская область, Нижний Тагил	0101000020E6100000B5A50EF27A004E401E6FF25B74F64C40
88601	6	56	\N	9945	18406	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Окунева, 45		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88667	6	56	\N	9945	19865	\N	57.908051923101901	город Нижний Тагил, ул. Октябрьской революции, 7	Россия, Свердловская область, Нижний Тагил	0101000020E6100000EBE6E26F7BFE4D40A088450C3BF44C40
88792	6	56	\N	9945	18912	\N	57.893012086085498	город Нижний Тагил, Тагилстроевский район, Октябрьской революции, 44	Россия, Свердловская область, Нижний Тагил	0101000020E6100000C2A6CEA3E2FB4D40C0779B374EF24C40
88790	6	56	\N	9945	18912	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Октябрьской революции, 2		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88815	6	56	\N	9945	18488	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Октябрьский проспект, 16а		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88803	6	56	\N	9945	20243	\N	57.8701975161093	город Нижний Тагил, Тагилстроевский район, Октябрьский проспект, 16	Россия, Свердловская область, Нижний Тагил	0101000020E6100000CBF44BC45BF94D40B685E7A562EF4C40
88797	6	56	\N	9945	18755	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Новострой, 11		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88796	6	56	\N	9945	18755	\N	57.942203657628198	Свердловская область, город Нижний Тагил, Тагилстроевский район, Новострой, 11	Россия, Свердловская область, Нижний Тагил	0101000020E6100000BE2F2E5569014E40871403249AF84C40
88731	6	56	\N	9945	18921	\N	57.925403000000003	город Нижний Тагил, ул. Некрасова, 1		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88794	6	56	\N	9945	17840	\N	57.925403000000003	Свердловская область, город Нижний Тагил, Тагилстроевский район, Мира, 54		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88780	6	56	\N	9945	20007	\N	57.938072706340499	город Нижний Тагил, Тагилстроевский район, Металлургов, 1	Россия, Свердловская область, Нижний Тагил	0101000020E6100000BEA1F0D93A024E405C21ACC612F84C40
88621	6	56	\N	9945	18444	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Максарева, 11А		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88710	6	56	\N	9945	18184	\N	57.925403000000003	город Нижний Тагил, ул. Липовый тракт, 11		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88679	6	56	\N	9945	20093	\N	57.925403000000003	город Нижний Тагил, ул. Ленина, 27		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88694	6	56	\N	9945	18859	\N	57.925403000000003	город Нижний Тагил, ул. Ленина, 38		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88684	6	56	\N	9945	18859	\N	57.925403000000003	город Нижний Тагил, ул. Ленина, 14		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88737	6	56	\N	9945	19950	\N	57.925403000000003	город Нижний Тагил, ул. Лайская, 19		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88661	6	56	\N	9945	19848	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Краснофлотская, 28		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88789	6	56	\N	9945	18730	\N	57.899227566258901	город Нижний Тагил, Тагилстроевский район, Красногвардейская, 59		0101000020E6100000DD42572250FF4D40E1D231E719F34C40
88829	6	56	\N	9945	20040	\N	57.925517180544297	город Нижний Тагил, Тагилстроевский район, Красногвардейская, 57а	Россия, Свердловская область, Нижний Тагил	0101000020E610000004AE2B6684FB4D402E724F5777F64C40
88787	6	56	\N	9945	17958	\N	57.901352464579801	город Нижний Тагил, Тагилстроевский район, Красногвардейская, 15	Россия, Свердловская область, Нижний Тагил	0101000020E610000029B3412619FF4D40941799805FF34C40
88723	6	56	\N	9945	19932	\N	57.925403000000003	город Нижний Тагил, ул. Красноармейская, 107а		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88729	6	56	\N	9945	18013	\N	57.925162011534098	город Нижний Тагил, ул. Космонавтов, 12	Россия, Свердловская область, Нижний Тагил	0101000020E610000044C362D4B5F84D4040C05AB56BF64C40
88620	6	56	\N	9945	18762	\N	57.902246012979099	город Нижний Тагил, Дзержинский район, Коровина, 1	Россия, Свердловская область, Нижний Тагил	0101000020E61000009624CFF57D0E4E40317903CC7CF34C40
88596	6	56	\N	9945	17809	\N	57.9175649413597	город Нижний Тагил, Дзержинский район, Коминтерна, 41	Россия, Свердловская область, Нижний Тагил	0101000020E610000012F758FAD00D4E40257A19C572F54C40
88632	6	56	\N	9945	20276	\N	57.917753348954797	город Нижний Тагил, Дзержинский район, Коминтерна, 59	Россия, Свердловская область, Нижний Тагил	0101000020E61000007764AC36FF0D4E40276728EE78F54C40
88761	6	56	\N	9945	18976	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Кольцова, 23		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88687	6	56	\N	9945	18521	\N	57.909038636762801	город Нижний Тагил, ул. Карла Маркса, 28	Россия, Свердловская область, Нижний Тагил	0101000020E61000002522FC8BA0FB4D40EFE4D3635BF44C40
88682	6	56	\N	9945	19884	\N	57.906664158694802	город Нижний Тагил, ул. Карла Маркса, 2	Россия, Свердловская область, Нижний Тагил	0101000020E6100000F33CB83B6BF94D40F33AE2900DF44C40
88806	6	56	\N	9945	18035	\N	57.939399341485903	город Нижний Тагил, Тагилстроевский район, Карла Либкнехта, 19	Россия, Свердловская область, Нижний Тагил	0101000020E6100000C3B81B446B014E409372F7393EF84C40
88807	6	56	\N	9945	20062	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Карла Либкнехта, 30		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88616	6	56	\N	9945	19376	\N	57.927024060701697	город Нижний Тагил, Дзержинский район, Калинина, 2А	Россия, Свердловская область, Нижний Тагил	0101000020E6100000740B5D8940014E40B64DF1B8A8F64C40
88645	6	56	\N	9945	18063	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Ильича, 12		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88643	6	56	\N	9945	18051	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Ильича, 22		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88642	6	56	\N	9945	18051	\N	57.906035934894398	город Нижний Тагил, Дзержинский район, Ильича, 37	Россия, Свердловская область, Нижний Тагил	0101000020E6100000DA3C0E83F9F54D40D47FD6FCF8F34C40
88728	6	56	\N	9945	19940	\N	57.931261301077299	город Нижний Тагил, ул. Известковая, 29	Россия, Свердловская область, Нижний Тагил	0101000020E610000052802898310F4E402785798F33F74C40
88725	6	56	\N	9945	19940	\N	57.934591838186002	город Нижний Тагил, ул. Известковая, 9	Россия, Свердловская область, Нижний Тагил	0101000020E610000044A7E7DD58FA4D40378DEDB5A0F74C40
88830	6	56	\N	9945	17919	\N	57.9406517540069	город Нижний Тагил, Тагилстроевский район, Захарова, 1	Россия, Свердловская область, Нижний Тагил	0101000020E6100000E3FDB8FDF2014E406075E44867F84C40
88625	6	56	\N	9945	20053	\N	57.917538709731502	город Нижний Тагил, Дзержинский район, зари, 8	Россия, Свердловская область, Нижний Тагил	0101000020E610000094BE1072DE114E40FBE6FEEA71F54C40
88624	6	56	\N	9945	20053	\N	57.907360903105896	город Нижний Тагил, Дзержинский район, Зари, 46Б	Россия, Свердловская область, Нижний Тагил	0101000020E610000083F8C08EFF104E403B55BE6724F44C40
88618	6	56	\N	9945	20053	\N	57.915012777112103	город Нижний Тагил, Дзержинский район, Зари, 32	Россия, Свердловская область, Нижний Тагил	0101000020E6100000FC71FBE593114E401A355F251FF54C40
88639	6	56	\N	9945	18454	\N	57.925334504095296	город Нижний Тагил, Дзержинский район, Зари, 21	Россия, Свердловская область, Нижний Тагил	0101000020E61000008BC1C3B46F004E400D6C956071F64C40
88633	6	56	\N	9945	18454	\N	57.911472561151598	город Нижний Тагил, Дзержинский район, Зари, 8	Россия, Свердловская область, Нижний Тагил	0101000020E610000038D906EE40114E40F017B325ABF44C40
88652	6	56	\N	9945	18468	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Зари, 75		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88638	6	56	\N	9945	18468	\N	57.926344822874903	город Нижний Тагил, Дзержинский район, Зари, 67А	Россия, Свердловская область, Нижний Тагил	0101000020E6100000CC0C1B65FD004E4014E8137992F64C40
88462	6	56	\N	7561	19099	\N	56.613148000000002	город Красноуфимск, Высокая, 14		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88822	6	56	\N	9945	77102	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Дружинина, 35		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88778	6	56	\N	9945	19923	\N	57.925403000000003	город Нижний Тагил, Тагилстроевский район, Гвардейская, 20		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88768	6	56	\N	9945	19923	\N	57.9425561416734	город Нижний Тагил, Тагилстроевский район, Гвардейская, 72		0101000020E6100000DB183BE125004E400553CDACA5F84C40
88699	6	56	\N	9945	19899	\N	57.913311233151703	город Нижний Тагил, ул. Газетная, 83А	Россия, Свердловская область, Нижний Тагил	0101000020E61000001EFE9AAC51FD4D40DD09F65FE7F44C40
88696	6	56	\N	9945	19899	\N	57.911158492824001	город Нижний Тагил, ул. Газетная, 27а	Россия, Свердловская область, Нижний Тагил	0101000020E61000009CDCEF5014FA4D4090BE49D3A0F44C40
88689	6	56	\N	9945	19899	\N	57.9122491546376	город Нижний Тагил, ул. Газетная, 27А	Россия, Свердловская область, Нижний Тагил	0101000020E6100000790261A758FB4D4084674293C4F44C40
88692	6	56	\N	9945	18520	\N	57.913447113402299	город Нижний Тагил, ул. Газетная, 71	Россия, Свердловская область, Нижний Тагил	0101000020E6100000191F662FDBFC4D408DD0CFD4EBF44C40
88668	6	56	\N	9945	18520	\N	57.914122046069203	город Нижний Тагил, Газетная, 109	Россия, Свердловская область, Нижний Тагил	0101000020E6100000616D8C9DF0FC4D40ED461FF301F54C40
88752	6	56	\N	9945	19969	\N	57.8541065711863	город Нижний Тагил, ул. Гагарина, 15	Россия, Свердловская область, Нижний Тагил	0101000020E61000007CF0DAA50D054E407024D06053ED4C40
88713	6	56	\N	9945	20341	\N	57.922971274159799	город Нижний Тагил, ул. Выйская, 68	Россия, Свердловская область, Нижний Тагил	0101000020E61000005F28603B18F74D400514EAE923F64C40
88715	6	56	\N	9945	18885	\N	57.925403000000003	город Нижний Тагил, ул. Верхняя Черепанова, 17А		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88717	6	56	\N	9945	19927	\N	57.923251622553202	город Нижний Тагил, ул. Верхняя Черепанова, 17а	Россия, Свердловская область, Нижний Тагил	0101000020E6100000A14D0E9F74004E40B9FB1C1F2DF64C40
88588	6	56	\N	9945	18707	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Вагоностроителей, 1		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88635	6	56	\N	9945	20026	\N	57.916103321468	город Нижний Тагил, Дзержинский район, Вагоностроителей, 64	Россия, Свердловская область, Нижний Тагил	0101000020E610000005DEC9A7C7104E403D62F4DC42F54C40
88591	6	56	\N	9945	20026	\N	57.911883700978699	город Нижний Тагил, Дзержинский район, Вагоностроителей, 14А	Россия, Свердловская область, Нижний Тагил	0101000020E6100000D9791B9B1DFB4D4072DF6A9DB8F44C40
88612	6	56	\N	9945	18759	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Бобкова, 3		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88609	6	56	\N	9945	17880	\N	57.907475122207302	город Нижний Тагил, Дзержинский район, Басова, 8	Россия, Свердловская область, Нижний Тагил	0101000020E6100000823CBB7CEB0B4E4003780B2428F44C40
88608	6	56	\N	9945	17880	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Басова, 11А		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88614	6	56	\N	9945	20027	\N	57.905533347915998	город Нижний Тагил, Дзержинский район, Алтайская, 35	Россия, Свердловская область, Нижний Тагил	0101000020E61000004C70EA03C90B4E4071395E81E8F34C40
88606	6	56	\N	9945	20027	\N	57.905444199282201	город Нижний Тагил, Дзержинский район, Алтайская, 51	Россия, Свердловская область, Нижний Тагил	0101000020E6100000E8F4BC1B0B0C4E40022EC896E5F34C40
88702	6	56	\N	9945	19957	\N	57.9158679781644	город Нижний Тагил, ул. Аганичева, 26	Россия, Свердловская область, Нижний Тагил	0101000020E61000001CEDB8E177F94D40FAB9A1293BF54C40
88648	6	56	\N	9945	19840	\N	57.925403000000003	город Нижний Тагил, Дзержинский район, Тельмана, 19		0101000020E6100000622EA9DA6E004E40664F029B73F64C40
88741	6	56	\N	9945	20187	\N	57.9255856594514	город Нижний Тагил, ул. Радищева, 3	Россия, Свердловская область, Нижний Тагил	0101000020E6100000F969DC9BDFFC4D4057D11F9A79F64C40
88598	6	56	\N	9945	19373	\N	57.916908361684897	город Нижний Тагил, Дзержинский район, Коминтерна, 47	Россия, Свердловская область, Нижний Тагил	0101000020E610000058E20165530E4E406BB8C83D5DF54C40
86309	6	56	\N	50124	19988	\N	56.663161076408599	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Нагорная, 20	Россия, Свердловская область, Нижнесергинский район, Нижние Серги	0101000020E6100000185A9D9CA1A64D40C87DAB75E2544C40
86273	6	56	\N	20037	18905	\N	57.490803999999997	Невьянск город, Октябрьский, 21		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86268	6	56	\N	20037	18540	\N	57.490803999999997	Невьянск город, Советская, 28		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86274	6	56	\N	20037	18920	\N	57.490803999999997	Невьянск город, Самойлова, 4		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86276	6	56	\N	20037	18238	\N	57.490803999999997	Невьянск город, Ракетная, 24		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86275	6	56	\N	20037	19092	\N	57.490009900881603	Невьянск город, Попова, 8	Россия, Свердловская область, Невьянск	0101000020E61000008A3F8A3A731B4E40425BCEA5B8BE4C40
86270	6	56	\N	20037	77073	\N	57.490803999999997	Невьянск город, Малышева, 1		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86272	6	56	\N	20037	77075	\N	57.490803999999997	Невьянск город, Красноармейская, 13		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86271	6	56	\N	20037	18235	\N	57.490803999999997	Невьянск город, Долгих, 9		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86269	6	56	\N	20037	18231	\N	57.491288630213297	Невьянск город, Долгих, 69	Россия, Свердловская область, Невьянск	0101000020E6100000A0C6BDF90D1B4E4039F1D58EE2BE4C40
86277	6	56	\N	20037	20112	\N	57.490803999999997	Невьянск город, ДБедного, 15		0101000020E610000076FEEDB25F1B4E407C5F5CAAD2BE4C40
86333	6	56	\N	50135	78423	\N	56.436725322115997	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Энгельса, 29	Россия, Свердловская область, Нижнесергинский район, Михайловск	0101000020E610000093FFC9DFBD8F4D403D2CD49AE6374C40
88456	6	56	\N	7561	77094	\N	56.613148000000002	город Красноуфимск, Буткинская, 14		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88521	6	56	\N	49991	19340	\N	58.637553090097299	город Лесной, Строителей, 22	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E61000001C45D61A4AE74D40BC3B32569B514D40
88544	6	56	\N	49991	77223	\N	58.640895354697001	город Лесной, МаминаСибиряка, 47а		0101000020E6100000FF91E9D0E9E54D40C095ECD808524D40
88488	6	56	\N	8815	\N	\N	58.285471000000001	город Кушва, ,дер.Мостовая, клуб		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88469	6	56	\N	8815	\N	\N	58.285471000000001	город Кушва, пос.Верхняя Баранча, клуб		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88492	6	56	\N	8815	18558	\N	58.285471000000001	город Кушва, пос.Строителей, 54б		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88478	6	56	\N	8815	20245	\N	58.285471000000001	город Кушва, пер.Свердлова, 5		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88497	6	56	\N	8815	18849	\N	58.285471000000001	город Кушва, Энергетиков, 6а		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88481	6	56	\N	8815	18827	\N	58.285471000000001	город Кушва, Строителей, 10		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88480	6	56	\N	8815	18827	\N	58.285471000000001	город Кушва, Строителей, 14		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88504	6	56	\N	8815	20260	\N	58.285471000000001	город Кушва, Станционная, 80		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88494	6	56	\N	8815	18836	\N	58.285471000000001	город Кушва, ул.Союзов, 14		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88484	6	56	\N	8815	18836	\N	58.285471000000001	город Кушва, Союзов, 14		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88473	6	56	\N	8815	18836	\N	58.285471000000001	Свердловская область, город Кушва, Союзов, 1а		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88499	6	56	\N	8815	18851	\N	58.285471000000001	Свердловская область, город Кушва, Прокофьева, 11		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88486	6	56	1359	\N	18825	\N	58.2927935927354	город Кушва, пл.Культуры, 1	Россия, Свердловская область, городской округ Кушва	0101000020E61000008E93C2BCC7E34D40863B17467A254D40
88471	6	56	\N	8815	19960	\N	58.285471000000001	город Кушва, Первомайская, 41		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88490	6	56	\N	8815	18546	\N	58.285267862410599	город Кушва, Маяковского, 13	Россия, Свердловская область, Кушва	0101000020E61000000F48C2BE9DE04D40344C6DA983244D40
88509	6	56	\N	8815	20327	\N	58.285471000000001	город Кушва, Луначарского, 5		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88505	6	56	\N	8815	19131	\N	58.285471000000001	город Кушва, Лесорубов, 15		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88495	6	56	\N	8815	18090	\N	58.285471000000001	город Кушва, Ленина, 176		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88476	6	56	\N	8815	18090	\N	58.285471000000001	город Кушва, Ленина, 48		0101000020E6100000363AE7A738E04D406C7A50508A244D40
88508	6	56	\N	8815	18586	\N	58.353717188805298	Свердловская область, город Кушва, поселок Азиатская, ул. Кушвинская,  управление поселком	Россия, Свердловская область, городской округ Кушва, поселок Азиатская	0101000020E61000006859F78F85C44D4006854199462D4D40
88512	6	56	\N	8815	18186	\N	58.285471000000001	город Кушва, .пос.Баранчинский, Коммуны, 4		0101000020E6100000363AE7A738E04D406C7A50508A244D40
87283	6	56	\N	8815	20364	\N	58.360681207228502	город Верхняя Тура, Иканина, 77		0101000020E61000003BC3D4963AEA4D40F0A485CB2A2E4D40
88501	6	56	\N	8815	19890	\N	58.284318292281498	город Кушва, Дзержинского, 1	Россия, Свердловская область, Кушва	0101000020E6100000952D9276A3E14D4002D53F8864244D40
86609	6	56	\N	49894	18159	\N	56.620384000000001	п.Крылатовский, Кунгурская, 42		0101000020E6100000FA449E245D194E40187B2FBE684F4C40
88465	6	56	\N	7561	19913	\N	56.620719695856302	город Красноуфимск, Ухтомского, 17	Россия, Свердловская область, Красноуфимск	0101000020E610000061360186E5E14C408FFCC1C0734F4C40
88444	6	56	\N	7561	18250	\N	56.613148000000002	город Красноуфимск, Трактовая, 1а	Россия, Свердловская область, Красноуфимск	0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88460	6	56	\N	7561	18785	\N	56.613148000000002	город Красноуфимск, Сухобского, 10		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88458	6	56	\N	7561	18785	\N	56.613148000000002	город Красноуфимск, Сухобского, 35		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88467	6	56	\N	7561	20377	\N	56.613148000000002	город Красноуфимск, Станционная, 3		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88452	6	56	\N	7561	19942	\N	56.613148000000002	город Красноуфимск, Советская, 56		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88450	6	56	\N	7561	19942	\N	56.613148000000002	город Красноуфимск, Советская, 2		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88446	6	56	\N	7561	18909	\N	56.613148000000002	город Красноуфимск, Селекционная, 22		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88449	6	56	\N	7561	19935	\N	56.613148000000002	город Красноуфимск, Свердлова, 18		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88455	6	56	\N	7561	20248	\N	56.612939927006003	город Красноуфимск, Саргинская, 12	Россия, Свердловская область, Красноуфимск	0101000020E61000007593180456E24C40833463D1744E4C40
88461	6	56	\N	7561	18526	\N	56.613148000000002	город Красноуфимск, Ремесленная, 7		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88445	6	56	\N	7561	18890	\N	56.613148000000002	город Красноуфимск, Р.Горбуновой, 13		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88447	6	56	\N	7561	19883	\N	56.613148000000002	город Красноуфимск, Пролетарская, 62		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88457	6	56	\N	7561	20069	\N	56.613148000000002	город Красноуфимск, Отдыха, 4		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88459	6	56	\N	7561	19073	\N	56.613148000000002	город Красноуфимск, Нефтяников, 12		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88468	6	56	\N	7561	78411	\N	56.613148000000002	город Красноуфимск, пос.Пудлинговый, Мира, 11		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88443	6	56	\N	7561	20304	\N	56.6431738692716	город Красноуфимск, Механизаторов, 24	Россия, Свердловская область, Красноуфимск	0101000020E6100000DD43C2F7FEE44C409AD18F8653524C40
88453	6	56	\N	7561	19830	\N	56.6132863429252	город Красноуфимск, Манчажская , 22	Россия, Свердловская область, Красноуфимск	0101000020E6100000CAA8328CBBE34C401E8CD827804E4C40
88463	6	56	\N	7561	78407	\N	56.614002170823397	город Красноуфимск, КирпичноЗаводская, 41	Россия, Свердловская область, Красноуфимск	0101000020E61000002541B8020AE34C40DCD6169E974E4C40
88448	6	56	\N	7561	18511	\N	56.613148000000002	город Красноуфимск, Докучаева, 3		0101000020E6100000ECF99AE5B2E14C40CDCD37A27B4E4C40
88451	6	56	\N	7561	18619	\N	56.6144304778608	город Красноуфимск, 8 Марта, 29	Россия, Свердловская область, Красноуфимск	0101000020E61000005111A7936CE14C4034D769A4A54E4C40
88442	6	56	\N	6272	\N	\N	58.449361916487597	город Красноуральск, пос.Чирок, клуб поселка Чирок	Россия, Свердловская область, городской округ Красноуральск, поселок Чирок	0101000020E61000002E01F8A754154E405708ABB184394D40
88434	6	56	\N	6272	18048	\N	58.349302999999999	город Красноуральск, Шахтеров, 9		0101000020E610000061A92EE065084E4085B2F0F5B52C4D40
88430	6	56	\N	6272	20233	\N	58.352306295665599	город Красноуральск, Челюскинцев, 14	Россия, Свердловская область, Красноуральск	0101000020E61000003CD862B7CF064E40A017EE5C182D4D40
88421	6	56	\N	6272	17989	\N	58.344677627984602	Свердловская область, город Красноуральск, Советская, 2в	Россия, Свердловская область, Красноуральск	0101000020E6100000C878944A78064E404AD3A0681E2C4D40
88418	6	56	\N	6272	17989	\N	58.349302999999999	город Красноуральск, Советская, 2		0101000020E610000061A92EE065084E4085B2F0F5B52C4D40
88431	6	56	\N	6272	18469	\N	58.349302999999999	город Красноуральск, Победы, 1а		0101000020E610000061A92EE065084E4085B2F0F5B52C4D40
88428	6	56	\N	6272	18420	\N	58.349302999999999	город Красноуральск, Парковая, 5	Россия, Свердловская область, Красноуральск	0101000020E610000061A92EE065084E4085B2F0F5B52C4D40
88423	6	56	\N	6272	20054	\N	58.359667355359399	город Красноуральск, Ленина, 6	Россия, Свердловская область, Красноуральск	0101000020E61000003ACC971760034E40A8397991092E4D40
88426	6	56	\N	6272	19096	\N	58.353812092271397	город Красноуральск, Каляева, 37	Россия, Свердловская область, Красноуральск	0101000020E610000039B69E211C054E4057772CB6492D4D40
88289	6	56	\N	6272	19096	\N	58.349302999999999	город Красноуральск, Каляева, 35а		0101000020E610000061A92EE065084E4085B2F0F5B52C4D40
88416	6	56	\N	6272	18683	\N	58.349302999999999	город Красноуральск, Воровского, 1		0101000020E610000061A92EE065084E4085B2F0F5B52C4D40
88389	6	56	\N	49845	20219	\N	59.759217295521204	городской округ Краснотурьинск, Бульвар Мира, 13	Россия, Свердловская область, Краснотурьинск	0101000020E61000007026A60BB1184E409BC8CC052EE14D40
88371	6	56	\N	49845	78378	\N	59.766807377019802	городской округ Краснотурьинск, Чкалова, 20	Россия, Свердловская область, Краснотурьинск	0101000020E61000005B79C9FFE4194E4004AC55BB26E24D40
88390	6	56	\N	49845	78486	\N	59.744719000000003	городской округ Краснотурьинск, Чернышевского, 3	Россия, Свердловская область, городской округ Краснотурьинск	0101000020E61000008578245E9E1E4E40DCDAC2F352DF4D40
88376	6	56	\N	49845	78366	\N	59.767586612393302	городской округ Краснотурьинск, Фрунзе, 60	Россия, Свердловская область, Краснотурьинск	0101000020E6100000DE72F563931A4E40D9EA724A40E24D40
88338	6	56	\N	49845	20148	\N	59.657235	городской округ Краснотурьинск, поселок Воронцовка, Серова, 29		0101000020E61000009BFF571D391E4E40AE64C74620D44D40
88407	6	56	\N	49845	18045	\N	59.757644581578703	городской округ Краснотурьинск, Рюмина, 16	Россия, Свердловская область, Краснотурьинск	0101000020E6100000236937FA98154E402C7DE882FAE04D40
88405	6	56	\N	49845	18045	\N	59.759663535799199	городской округ Краснотурьинск, Рюмина, 6	Россия, Свердловская область, Краснотурьинск	0101000020E61000003A765089EB164E406AF981AB3CE14D40
88402	6	56	383	\N	18045	\N	59.757554727153803	городской округ Краснотурьинск, Рюмина, 18	Россия, Свердловская область, городской округ Краснотурьинск	0101000020E61000009354A69883144E40EDF5EE8FF7E04D40
88379	6	56	\N	49845	77397	\N	59.771742226225001	городской округ Краснотурьинск, Попова, 46	Россия, Свердловская область, Краснотурьинск	0101000020E61000005F27F56569174E408E791D71C8E24D40
88353	6	56	\N	49845	77397	\N	59.764815914831303	городской округ Краснотурьинск, Попова, 76	Россия, Свердловская область, Краснотурьинск	0101000020E61000007F17B6662B194E4091BA9D7DE5E14D40
88401	6	56	\N	49845	18408	\N	59.744719000000003	городской округ Краснотурьинск, Парковая, 5		0101000020E61000008578245E9E1E4E40DCDAC2F352DF4D40
88360	6	56	\N	49845	77662	\N	59.7696644841837	городской округ Краснотурьинск, Октябрьская, 45	Россия, Свердловская область, Краснотурьинск	0101000020E6100000A6D1E4620C1A4E404B74965984E24D40
88358	6	56	\N	49845	77662	\N	59.762737740271703	городской округ Краснотурьинск, Октябрьская, 24	Россия, Свердловская область, Краснотурьинск	0101000020E61000007F17B6662B194E404EB51666A1E14D40
88357	6	56	\N	49845	77662	\N	59.766893959629002	городской округ Краснотурьинск, Октябрьская, 34	Россия, Свердловская область, Краснотурьинск	0101000020E61000004EB51666A11B4E40D3BF249529E24D40
88381	6	56	\N	49845	78487	\N	59.771742226225001	городской округ Краснотурьинск, Молодежная, 7	Россия, Свердловская область, Краснотурьинск	0101000020E610000066666666661A4E408E791D71C8E24D40
88386	6	56	\N	49845	18990	\N	59.762142405940502	городской округ Краснотурьинск, Микова, 33	Россия, Свердловская область, Краснотурьинск	0101000020E6100000C119FCFD62184E403A747ADE8DE14D40
88395	6	56	\N	49845	77399	\N	59.767586612393302	городской округ Краснотурьинск, Металлургов, 43	Россия, Свердловская область, Краснотурьинск	0101000020E6100000766F4562821C4E40D9EA724A40E24D40
88396	6	56	\N	49845	78478	\N	59.744719000000003	городской округ Краснотурьинск, Маркса, 35		0101000020E61000008578245E9E1E4E40DCDAC2F352DF4D40
88383	6	56	\N	49845	78457	\N	59.762002000000003	городской округ Краснотурьинск, Ленина, 23	Россия, Свердловская область, Краснотурьинск	0101000020E610000098C11891281A4E4049BE124889E14D40
88366	6	56	\N	49845	77667	\N	59.764123204396398	городской округ Краснотурьинск, Ленина, 78	Россия, Свердловская область, Краснотурьинск	0101000020E61000006E30D46185194E408A8F4FC8CEE14D40
88362	6	56	\N	49845	77667	\N	59.7655086108483	городской округ Краснотурьинск, Ленина, 80	Россия, Свердловская область, Краснотурьинск	0101000020E6100000A6D1E4620C1A4E4097E5EB32FCE14D40
88347	6	56	\N	49845	77394	\N	59.768106092505199	городской округ Краснотурьинск, Космодемьянской, 7	Россия, Свердловская область, Краснотурьинск	0101000020E6100000161406651A1B4E4042EE224C51E24D40
88375	6	56	\N	49845	19971	\N	59.7626950449501	городской округ Краснотурьинск, Колхозная, 11	Россия, Свердловская область, Краснотурьинск	0101000020E610000067B5C01E13194E404FE960FD9FE14D40
88354	6	56	\N	49845	20013	\N	59.760973354814297	городской округ Краснотурьинск, Клубная, 18	Россия, Свердловская область, Краснотурьинск	0101000020E61000009E45EF54C01B4E40CB11329067E14D40
88399	6	56	\N	49845	78444	\N	59.7658125063816	городской округ Краснотурьинск, Маркса, 31	Россия, Свердловская область, Краснотурьинск	0101000020E6100000C87DAB75E2184E4003ED0E2906E24D40
88392	6	56	\N	49845	78444	\N	59.764600289959702	городской округ Краснотурьинск, Маркса, 22 А	Россия, Свердловская область, Краснотурьинск	0101000020E6100000336C94F59B1B4E40C442AD69DEE14D40
88350	6	56	\N	49845	19213	\N	59.759039983626003	городской округ Краснотурьинск, Животноводов, 5	Россия, Свердловская область, Краснотурьинск	0101000020E61000002062838593184E408C2D043928E14D40
88415	6	56	\N	49845	78544	\N	59.767586612393302	городской округ Краснотурьинск, Восточная, 4	Россия, Свердловская область, Краснотурьинск	0101000020E6100000567F8461C01A4E40D9EA724A40E24D40
88384	6	56	\N	49845	20213	\N	59.766300879237399	городской округ Краснотурьинск, Базстроевская, 1	Россия, Свердловская область, Краснотурьинск	0101000020E610000047AF06280D194E4030F2B22616E24D40
88348	6	56	\N	49845	18376	\N	59.760610131898801	городской округ Краснотурьинск, Абоимова, 39	Россия, Свердловская область, Краснотурьинск	0101000020E610000081B22957781F4E405A8121AB5BE14D40
88324	6	56	1323	\N	18154	\N	57.442613926276799	город Кировград, Свердлова, 58	Россия, Свердловская область, городской округ Кировград	0101000020E6100000AA61BF27D6074E4039605793A7B84C40
88320	6	56	\N	450	18154	\N	57.430695	город Кировград, Свердлова, 47		0101000020E610000059DB148F8B084E407EC6850321B74C40
88317	6	56	\N	450	18154	\N	57.430695	город Кировград, Свердлова, 63		0101000020E610000059DB148F8B084E407EC6850321B74C40
88315	6	56	\N	450	18154	\N	57.428562791276299	город Кировград, Свердлова, 69	Россия, Свердловская область, Кировград	0101000020E610000096766A2E37084E4048A30227DBB64C40
88322	6	56	\N	450	19984	\N	57.430695	город Кировград, Набережная, 7		0101000020E610000059DB148F8B084E407EC6850321B74C40
88335	6	56	\N	450	18195	\N	57.430695	город Кировград, р.п. Левиха, Максима Горького, 1		0101000020E610000059DB148F8B084E407EC6850321B74C40
88318	6	56	\N	450	18155	\N	57.430695	город Кировград, Лермонтова, 67		0101000020E610000059DB148F8B084E407EC6850321B74C40
88328	6	56	\N	450	19157	\N	57.428543527130998	город Кировград, Ленина, 29	Россия, Свердловская область, Кировград	0101000020E6100000139B8F6B43094E40D272A087DAB64C40
88327	6	56	\N	450	18831	\N	57.428238708954197	город Кировград, Калинина, 4	Россия, Свердловская область, Кировград	0101000020E6100000A8C5E061DA074E4095EF1989D0B64C40
88312	6	56	\N	450	20119	\N	57.430695	город Кировград, Дзержинского, 12		0101000020E610000059DB148F8B084E407EC6850321B74C40
88303	6	56	\N	49875	\N	\N	58.695993503634398	Качканарский городской округ, 5 микрорайон, 72		0101000020E610000005DB8827BBBD4D402A1BD65416594D40
88280	6	56	\N	49875	\N	\N	58.700460911091	Качканарский городской округ, 7 микрорайон, 63	Россия, Свердловская область, Качканар	0101000020E6100000897AC1A739BF4D40CD8FBFB4A8594D40
88300	6	56	\N	49875	20100	\N	59.126311000000001	Качканарский городской округ, 5а микрорайон, 14а		0101000020E61000008FC536A968DA4E40021077F52A904D40
88305	6	56	\N	49875	77391	\N	58.700550166127599	Качканарский городской округ, Свердлова, 39а	Россия, Свердловская область, Качканар	0101000020E610000080F44D9A06BF4D403D9B559FAB594D40
88290	6	56	\N	49875	77391	\N	58.710555046918401	Качканарский городской округ, Свердлова, 20	Россия, Свердловская область, Качканар	0101000020E6100000F6B4C35F93BD4D4030815B77F35A4D40
88298	6	56	\N	49875	18598	\N	58.698495322642501	Качканарский городской округ, Гикалова, 5	Россия, Свердловская область, Качканар	0101000020E61000004FAF946588BF4D40B3B5BE4868594D40
88281	6	56	\N	49875	18816	\N	58.694385096201501	Качканарский городской округ, 8 микрорайон, 30	Россия, Свердловская область, Качканар	0101000020E6100000A12B11A8FEBD4D409EEA909BE1584D40
88292	6	56	\N	49875	20240	\N	58.695548476482301	Качканарский городской округ, 6а микрорайон, 26	Россия, Свердловская область, Качканар	0101000020E61000003882548A1DBF4D402C6684B707594D40
88286	6	56	\N	49875	20246	\N	58.697323839021003	Качканарский городской округ, 4 микрорайон, 62	Россия, Свердловская область, Качканар	0101000020E61000009961A3ACDFBE4D40A35BAFE941594D40
88295	6	56	\N	49875	18602	\N	58.697244435676502	Качканарский городской округ, 11 микрорайон, 14а	Россия, Свердловская область, Качканар	0101000020E610000040A6B5696CBD4D4086AA984A3F594D40
88297	6	56	\N	49875	78355	\N	58.701487999999998	Качканарский городской округ, 11 микрорайон, 11	Россия, Свердловская область, Качканар	0101000020E61000000BB8E7F9D3BE4D40AA44D95BCA594D40
88311	6	56	\N	49875	18740	\N	58.698405970296598	Свердловская область, Качканарский городской округ, 10 микрорайон, 61	Россия, Свердловская область, Качканар	0101000020E610000083E0F1ED5DBD4D4043AA285E65594D40
88308	6	56	\N	49875	18740	\N	58.696165422135699	Качканарский городской округ, 10 микрорайон, 5	Россия, Свердловская область, Качканар	0101000020E61000009372F7393EBE4D4057CF49EF1B594D40
88306	6	56	\N	49875	18740	\N	58.702515638218102	Качканарский городской округ, 10 микрорайон, 23	Россия, Свердловская область, Качканар	0101000020E61000008448861C5BBD4D405875560BEC594D40
88256	6	56	\N	29288	18440	\N	59.767135360547996	город Карпинск, проезд Декабристов, 8		0101000020E610000075E95F92CAFE4D40F94ECC7A31E24D40
88244	6	56	\N	29288	19069	\N	59.763295264599698	городской округ Карпинск, Школьный, 3	Россия, Свердловская область, Карпинск	0101000020E6100000FD4FFEEE1D014E40A4198BA6B3E14D40
88239	6	56	\N	29288	18419	\N	59.761898941575801	городской округ Карпинск, Шахтерский, 6	Россия, Свердловская область, Карпинск	0101000020E6100000371B2B31CF004E4074ED0BE885E14D40
87355	6	56	\N	13	78127	\N	56.828989999999997	город Екатеринбург, ВерхИсетский район, Заводская, 44		0101000020E61000009DBE9EAF59464E40035B25581C6A4C40
88259	6	56	\N	29288	77378	\N	59.764941314849402	городской округ Карпинск, Трудовая, 41	Россия, Свердловская область, Карпинск	0101000020E6100000CA89761552024E404D2F3196E9E14D40
88265	6	56	\N	29288	18465	\N	59.754653133640502	город Карпинск, Советская, 7	Россия, Свердловская область, Карпинск	0101000020E61000002B69C53714024E40056A317898E04D40
88237	6	56	\N	29288	19388	\N	59.767195000000001	город Карпинск, Почтамтская, 37		0101000020E610000061C5A9D6C2FE4D40CE531D7233E24D40
88250	6	56	\N	29288	78348	\N	59.767714453954298	городской округ Карпинск, Попова, 15	Россия, Свердловская область, Карпинск	0101000020E6100000A86F99D365014E403657CD7344E24D40
87289	6	56	\N	29288	78255	\N	59.934178173105501	Волчанский городской округ, Пионерская, 10,А		0101000020E6100000658EE55DF50A4E4044520B2593F74D40
88251	6	56	\N	29288	77376	\N	59.7648322346176	городской округ Карпинск, Мира, 61	Россия, Свердловская область, Карпинск	0101000020E6100000E3361AC05B024E409677D503E6E14D40
88263	6	56	\N	29288	18457	\N	59.760611062115899	город Карпинск, Малышева, 1	Россия, Свердловская область, Карпинск	0101000020E6100000492EFF21FD024E402AFD84B35BE14D40
88261	6	56	\N	29288	20277	\N	59.761434333219398	город Карпинск, Лесопильная, 71	Россия, Свердловская область, Карпинск	0101000020E6100000533F6F2A52014E40FF0758AB76E14D40
88253	6	56	\N	29288	77661	\N	59.762603368154998	городской округ Карпинск, Куйбышева, 27	Россия, Свердловская область, Карпинск	0101000020E61000000C1F115322014E406E6AA0F99CE14D40
88257	6	56	\N	29288	18016	\N	59.767083442854101	городской округ Карпинск, Колхозная, 43а	Россия, Свердловская область, Карпинск	0101000020E61000009F02603C83004E40A62897C62FE24D40
88274	6	56	\N	29288	19374	\N	59.765892919009197	городской округ Карпинск, Заречная, 38	Россия, Свердловская область, Карпинск	0101000020E6100000A0C4E74EB0FF4D401F9E25C808E24D40
88216	6	56	\N	23556	\N	\N	56.847872000000002	город Камышлов, Свердлова, 73	Россия, Свердловская область, Камышлов	0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88213	6	56	\N	23556	18661	\N	56.847872000000002	город Камышлов, Энгельса, 171		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88142	6	56	\N	23556	18661	\N	56.847872000000002	город Камышлов, Энгельса, 135		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
87990	6	56	\N	23556	78447	\N	56.848355132921903	Камышловский городской округ, Швельниса, 40	Россия, Свердловская область, Камышлов	0101000020E6100000B43C0FEECE5A4F40F4328AE5966C4C40
88210	6	56	\N	23556	18911	\N	56.847872000000002	город Камышлов, Фарфористов, 11		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88232	6	56	\N	23556	18418	\N	56.847872000000002	город Камышлов, Строителей, 15		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88229	6	56	\N	23556	19316	\N	56.847872000000002	город Камышлов, Северная, 63	Россия, Свердловская область, Камышлов	0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88227	6	56	\N	23556	19316	\N	56.847872000000002	город Камышлов, Северная, 72		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88225	6	56	\N	23556	18754	\N	56.847872000000002	город Камышлов, Молокова, 9		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88217	6	56	\N	23556	18737	\N	56.847872000000002	город Камышлов, Маяковского, 9		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88222	6	56	\N	23556	19987	\N	56.846884352874298	город Камышлов, Ленинградская, 24	Россия, Свердловская область, Камышлов	0101000020E6100000C45E28603B5C4F40BAC0E5B1666C4C40
88235	6	56	\N	23556	77374	\N	56.852211532707997	Камышловский городской округ, Куйбышева, 114	Россия, Свердловская область, Камышлов	0101000020E6100000AAD381ACA7584F401FA16648156D4C40
88168	6	56	\N	23556	20160	\N	56.847872000000002	город Камышлов, Красных Партизан, 2 а		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88233	6	56	\N	23556	18996	\N	56.847872000000002	город Камышлов, Карловарская, 2 А		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88223	6	56	\N	23556	18407	\N	56.847872000000002	город Камышлов, Карла Либкнехта, 14		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88220	6	56	\N	23556	19368	\N	56.847872000000002	город Камышлов, Вокзальная, 14а		0101000020E6100000C45E28603B5C4F40D998D711876C4C40
88141	6	56	\N	49945	18630	\N	56.390190820142401	город КаменскУральский, Красногорский район, Челябинская, 19, школа № 17		0101000020E610000071732A1900F84E40C61858C7F1314C40
88131	6	56	\N	20970	17786	\N	56.3889	город КаменскУральский, проспект Победы, 33, библиотека им.Пушкина		0101000020E6100000CF49EF1B5FF54E400BB5A679C7314C40
88128	6	56	\N	20970	17786	\N	56.3889	город КаменскУральский, проспект Победы, 79, школа № 1		0101000020E6100000CF49EF1B5FF54E400BB5A679C7314C40
88108	6	56	\N	20970	17786	\N	56.414149576288899	"""""""город КаменскУральский, проспект Победы, 2, ДК """"""""Юность"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000FAB7CB7EDDF54E40B7D100DE02354C40
88094	6	56	\N	20970	17786	\N	56.4264272340085	город КаменскУральский, проспект Победы, 58, школа № 31	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000ECF65965A6F24E40D190F12895364C40
88188	6	56	\N	20970	19294	\N	56.3865009955489	город КаменскУральский, Красногорский район, бульвар Комсомольский, 46, школа №34	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000DC4603780BF64E40876F61DD78314C40
88186	6	56	\N	20970	19294	\N	56.386655737339801	город КаменскУральский, Красногорский район, бульвар Комсомольский, 46, школа № 34	Россия, Свердловская область, Каменск-Уральский	0101000020E61000009F724C16F7F54E40AE669DF17D314C40
88195	6	56	\N	20970	78261	\N	56.397664590479899	город КаменскУральский, Красногорский район, Школьная, 10, школа № 7		0101000020E61000001893FE5E0AF14E40C6E1CCAFE6324C40
88147	6	56	\N	20970	18603	\N	56.3881436069572	город КаменскУральский, Красногорский район, Челябинская, 29, школа № 40	Россия, Свердловская область, Каменск-Уральский	0101000020E61000009C86A8C29FF74E40BE11DDB3AE314C40
88145	6	56	\N	20970	18603	\N	56.389341578557499	город КаменскУральский, Красногорский район, Челябинская, 19, школа №17	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000E88711C2A3F54E40C87A6AF5D5314C40
87354	6	56	\N	13	78127	\N	56.832628999999997	город Екатеринбург, ВерхИсетский район, Заводская, 36б		0101000020E61000007AFF1F274C464E40C0594A96936A4C40
88191	6	56	\N	20970	19200	\N	56.397605091756098	"""""""город КаменскУральский, Красногорский район, Центральная, 13, Дворец спорта ОАО """"""""КУМЗ"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000354580D3BBF84E40F0DC7BB8E4324C40
86176	6	56	\N	20970	19200	\N	56.355659000000003	Свердловская область, Каменский район, д.Черноскутова, Центральная, 271		0101000020E6100000BF654E97C5124F4098C3EE3B862D4C40
88178	6	56	\N	20970	18046	\N	56.385468375513	город КаменскУральский, Красногорский район, Уральская, 31, школа № 23	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000A437DC476EFB4E40C8D3F20357314C40
88175	6	56	\N	20970	18046	\N	56.385748201208301	город КаменскУральский, Красногорский район, Уральская, 43,Центр псих.мед.соц.сопровождения	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000FD885FB186FB4E40AB3FC23060314C40
88085	6	56	\N	20970	18474	\N	56.417225682248599	город КаменскУральский, Тевосяна, 2, школа № 10	Россия, Свердловская область, Каменск-Уральский	0101000020E610000059198D7C5EF54E403C855CA967354C40
88180	6	56	\N	20970	77620	\N	56.382406060321202	город КаменскУральский, Красногорский район, Строителей, 24, школа № 2	Россия, Свердловская область, Каменск-Уральский	0101000020E610000006B8205B96FB4E40A8E507AEF2304C40
88069	6	56	\N	20970	18018	\N	56.435165894983299	"""""""Свердловская область, город КаменскУральский, ул.Спиридонова, 25, центр """"""""Лада"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000A14ACD1E68ED4E40632AFD84B3374C40
88096	6	56	\N	20970	77422	\N	56.426546140887297	"""""""город КаменскУральский, ул.Пушкина, 1а, детский клубик """"""""Ровесник"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000FD8348861CF34E40AC1E300F99364C40
88089	6	56	\N	20970	18480	\N	56.426370102677602	Свердловская область, город КаменскУральский, пр.Победы, 93	Россия, Свердловская область, Каменск-Уральский	0101000020E61000000C23BDA8DDF14E406DFFCA4A93364C40
88086	6	56	\N	20970	19107	\N	56.423887554051099	город КаменскУральский, Прокопьева, 25, школа № 38	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000185A9D9CA1F04E405B9544F641364C40
88207	6	56	\N	20970	77742	\N	56.421641479660501	город КаменскУральский, Привокзальная, 15,  Автовокзал	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000FB57569A94F44E408DD31055F8354C40
88100	6	56	\N	20970	77742	\N	56.426424354227898	город КаменскУральский, Привокзальная, 15, Здание автовокзала	Россия, Свердловская область, Каменск-Уральский	0101000020E61000009372F7393EF64E40601DC70F95364C40
88119	6	56	\N	20970	19022	\N	56.434176539382797	город КаменскУральский, О.Кошевого, 2, город. Дом детского творчества	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000C80C54C6BFF14E4073D6A71C93374C40
88162	6	56	\N	20970	77381	\N	56.382650102278198	город КаменскУральский, Красногорский район, Октябрьская, 99, техникум строительства и ЖКХ	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000A3E8818FC1F64E403EE8D9ACFA304C40
88160	6	56	\N	20970	77381	\N	56.383751247682902	город КаменскУральский, Красногорский район, Октябрьская, 94а, школа № 25	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000855E7F129FF74E405567B5C01E314C40
88159	6	56	\N	20970	77381	\N	56.383632206477401	город КаменскУральский, Красногорский район, Октябрьская, 94а, школа №25	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000998235CEA6F74E407BD976DA1A314C40
88117	6	56	\N	20970	77520	\N	56.418938414178101	город КаменскУральский, Мусоргского, 9, школа № 19	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000BC22F8DF4AF64E409C86A8C29F354C40
88106	6	56	\N	20970	77520	\N	56.419066171417803	"""""""город КаменскУральский, ул.Мусоргского, 7, школа """"""""Альфа"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000B5FE9600FCF54E40CA6E66F4A3354C40
88115	6	56	\N	20970	77453	\N	56.425577038947601	город КаменскУральский, улица Мичурина, 61,  школа № 60		0101000020E610000035D07CCEDDF44E400377A04E79364C40
88098	6	56	\N	20970	77453	\N	56.425582984433802	город КаменскУральский, Мичурина, 61, школа № 60	Россия, Свердловская область, Каменск-Уральский	0101000020E61000000D54C6BFCFF44E40E65DF58079364C40
88090	6	56	\N	20970	77249	\N	56.4286478512496	город КаменскУральский, Мичурина, 10, школа № 15	Россия, Свердловская область, Каменск-Уральский	0101000020E61000003B56293DD3F14E4077BF0AF0DD364C40
88169	6	56	\N	20970	18267	\N	56.3889	город КаменскУральский, Красногорский район, Механизаторов, 20, Агропромышленный техникум		0101000020E6100000CF49EF1B5FF54E400BB5A679C7314C40
88165	6	56	\N	20970	18267	\N	56.3889	город КаменскУральский, Красногорский район, Механизаторов, 72, Детская юношеская спорт. школа	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000CF49EF1B5FF54E400BB5A679C7314C40
88110	6	56	\N	20970	77346	\N	56.419304309762602	город КаменскУральский, Машинистов, 51, домоуправление, п.Хозспособ	Россия, Свердловская область, городской округ Каменск-Уральский	0101000020E61000005F07CE1951F84E407E8AE3C0AB354C40
88121	6	56	\N	20970	77753	\N	56.436720307087903	город КаменскУральский, Лесная, 2а, ЖЭУ № 2	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000E012807F4AF14E402BC1E270E6374C40
88076	6	56	\N	20970	77318	\N	56.4237250674501	город КаменскУральский, Лермонтова, 101, школа № 4	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000FD135CACA8F74E40B1BFEC9E3C364C40
88074	6	56	\N	20970	77318	\N	56.429804044119003	город КаменскУральский, Лермонтова, 2, школа №24	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000711B0DE02DEE4E4051D845D103374C40
88072	6	56	\N	20970	77318	\N	56.421679664781301	"""""""город КаменскУральский, Лермонтова, 133, спорткомплекс ДК """"""""Современник"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E610000090D8EE1EA0F94E404BB0389CF9354C40
88070	6	56	\N	20970	77318	\N	56.421346681800102	"""""""город КаменскУральский, Лермонтова, 133, ДК """"""""Современник"""""""", агитпункт"""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E61000001A34F44F70F94E4044A2D0B2EE354C40
88067	6	56	\N	20970	77318	\N	56.423534802093698	город КаменскУральский, Лермонтова, 64, ЖЭУ № 10	Россия, Свердловская область, Каменск-Уральский	0101000020E61000008198840B79F44E400EDB166536364C40
88082	6	56	\N	20970	20216	\N	56.416116588251697	город КаменскУральский, Ленина, 34, УГТУУПИ	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000996725ADF8F24E40A227655243354C40
88081	6	56	\N	20970	20216	\N	56.419824436611101	"""""""город КаменскУральский, Ленина, 150,школа """"""""РОСТО"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E61000007C9E3F6D54F54E40B709F7CABC354C40
88079	6	56	\N	20970	20216	\N	56.419063291077499	город КаменскУральский, Ленина, 204, школа № 32	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000EE0A7DB08CF54E4059FB3BDBA3354C40
86156	6	56	\N	20970	20216	\N	56.522302000000003	Каменский район, с.Кисловское, Ленина, 57		0101000020E61000004034F3E49AC64E405551BCCADA424C40
86153	6	56	\N	20970	20216	\N	56.362895000000002	Каменский район, д.Походилова, Ленина, 40		0101000020E6100000749A05DA1DA44E40E370E657732E4C40
88152	6	56	\N	20970	78592	\N	56.4152245319885	Свердловская область, город КаменскУральский, Красногорский район, Кутузова, 39, школа №34	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000B24CBF44BCF14E40A5BDC11726354C40
88104	6	56	\N	20970	18112	\N	56.3889	город КаменскУральский, Кунавина, 7, школа №22, спортзал		0101000020E6100000CF49EF1B5FF54E400BB5A679C7314C40
88102	6	56	\N	20970	18112	\N	56.420234083767902	город КаменскУральский, Кунавина, 7, школа № 22, актовый зал	Россия, Свердловская область, Каменск-Уральский	0101000020E610000021ACC612D6F44E4069554B3ACA354C40
88125	6	56	\N	20970	78278	\N	56.450091354295601	город КаменскУральский, Кузнецова, 15, школа № 11	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000687A89B14CF54E40AA9CF6949C394C40
88129	6	56	\N	20970	18072	\N	56.388190999999999	Свердловская область, город КаменскУральский, Кирова, 45, филиал библиотеки им. Пушкина	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000F2D24D6210F64E40FFCC203EB0314C40
88123	6	56	\N	20970	77411	\N	56.435198679741603	"""""""город КаменскУральский, К.Маркса, 62, ЦКиНТ """"""""Орбита"""""""""""""""		0101000020E610000072FC5069C4F24E403E20D099B4374C40
88093	6	56	\N	20970	77411	\N	56.391190581768903	город КаменскУральский, ул. К.Маркса, 40а, библиотека профкома СинТЗ	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000B77C24253DFA4E40A9BEF38B12324C40
88166	6	56	\N	20970	77588	\N	56.380656054930498	город КаменскУральский, Красногорский район, Калинина, 67, школаинтернат № 27	Россия, Свердловская область, Каменск-Уральский	0101000020E610000086048C2E6FF84E405A83F755B9304C40
88183	6	56	\N	20970	77362	\N	56.380798915539302	город КаменскУральский, Красногорский район, Исетская, 12, школа №5	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000677C5F5CAAFC4E40BDAC8905BE304C40
88173	6	56	\N	20970	77362	\N	56.385953000000001	город КаменскУральский, Красногорский район, Исетская, 20, школа № 20	Россия, Свердловская область, Каменск-Уральский	0101000020E610000011AAD4EC81FC4E4084656CE866314C40
88172	6	56	\N	20970	77362	\N	56.386667640528302	город КаменскУральский, Красногорский район, Исетская, 36, Центр образования	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000E38A8BA372F94E40723447567E314C40
88157	6	56	\N	20970	77537	\N	56.429822435911298	город КаменскУральский, Красногорский район, Железнодорожная, 40, детский клуб	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000E5D022DBF9F44E40F88C446804374C40
88154	6	56	\N	20970	77537	\N	56.386400375848503	город КаменскУральский, Красногорский район, Железнодорожная, 22, школа № 35	Россия, Свердловская область, Каменск-Уральский	0101000020E61000004434BA83D8F94E405396218E75314C40
88151	6	56	\N	20970	77537	\N	56.387917454536897	город КаменскУральский, Красногорский район, ул.Железнодорожная, 10, МОУ ВСОШ №1	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000AA2C0ABB28FA4E40FE47A643A7314C40
88112	6	56	\N	20970	77352	\N	56.421789574536803	город КаменскУральский, Добролюбова, 35, школа № 51	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000257A19C572F74E40D2E3F736FD354C40
88139	6	56	\N	20970	77354	\N	56.3935232564044	город КаменскУральский, Красногорский район, Дзержинского, 89а, школа № 16	Россия, Свердловская область, Каменск-Уральский	0101000020E610000062C092AB58F84E40A69C2FF65E324C40
88134	6	56	\N	20970	78337	\N	56.423211218728703	город КаменскУральский, Красногорский район, Гоголя, 15, лицей №9	Россия, Свердловская область, Каменск-Уральский	0101000020E61000007094BC3AC7F44E405B272EC72B364C40
88182	6	56	\N	20970	17790	\N	56.378834535011897	город КаменскУральский, Красногорский район, Алюминиевая, 2, ДК УАЗа	Россия, Свердловская область, Каменск-Уральский	0101000020E61000005723BBD232FC4E4043CA4FAA7D304C40
88148	6	56	\N	20970	17790	\N	56.393344740456797	город КаменскУральский, Красногорский район, Алюминиевая, 47, театр Драмы	Россия, Свердловская область, Каменск-Уральский	0101000020E61000001AC40776FCF94E40C685032159324C40
88137	6	56	\N	20970	17790	\N	56.3889	Свердловская область, город КаменскУральский, Красногорский район, Алюминиевая, 77, Детская музыкальная школа №1		0101000020E6100000CF49EF1B5FF54E400BB5A679C7314C40
88135	6	56	\N	20970	17790	\N	56.393428048003599	город КаменскУральский, Красногорский район, Алюминиевая, 60, Политехнический колледж	Россия, Свердловская область, Каменск-Уральский	0101000020E61000001F645930F1F94E4054AA44D95B324C40
88198	6	56	\N	20970	17826	\N	56.3889	город КаменскУральский, Красногорский район, ул. 2я Рабочая, 99, библиотека		0101000020E6100000CF49EF1B5FF54E400BB5A679C7314C40
87974	6	56	6985	\N	18230	\N	57.6829069683358	город Ирбит, ул.Красноармейская, 1	Россия, Свердловская область, городской округ Ирбит	0101000020E61000005517F032C3864F40D09A1F7F69D74C40
88062	6	56	\N	16563	77092	\N	57.670015999999997	город Ирбит, ул.Южная, 12		0101000020E6100000DC0F786000874F40FBE59315C3D54C40
88046	6	56	\N	16563	18371	\N	57.670015999999997	город Ирбит, ул.Челюскинцев, 2		0101000020E6100000DC0F786000874F40FBE59315C3D54C40
88049	6	56	6985	\N	19023	\N	57.670975232942901	город Ирбит, ул.Советская, 96	Россия, Свердловская область, городской округ Ирбит	0101000020E61000004529215855894F4080B74082E2D54C40
88057	6	56	\N	16563	9896	\N	57.670015999999997	город Ирбит, ул.Свердлова, 17а		0101000020E6100000DC0F786000874F40FBE59315C3D54C40
88055	6	56	\N	16563	9896	\N	57.666254218235601	город Ирбит, ул.Свердлова, 17	Россия, Свердловская область, Ирбит	0101000020E61000006ADAC534D3894F40236AA2CF47D54C40
88053	6	56	\N	16563	9896	\N	57.670015999999997	город Ирбит, ул.Свердлова, 16		0101000020E6100000DC0F786000874F40FBE59315C3D54C40
89298	6	56	\N	16563	19245	\N	57.675575638536799	город Ирбит, ул.Пролетарская, 28		0101000020E6100000CC79C6BE64874F4033FB3C4679D64C40
88043	6	56	\N	16563	20230	\N	57.679113296873602	город Ирбит, ул.Первомайская, 39	Россия, Свердловская область, городской округ Ирбит	0101000020E6100000008DD2A57F874F40ECA4BE2CEDD64C40
88038	6	56	\N	16563	77076	\N	57.670015999999997	город Ирбит, ул.Орджоникидзе, 73		0101000020E6100000DC0F786000874F40FBE59315C3D54C40
88040	6	56	\N	16563	17782	\N	57.670015999999997	город Ирбит, ул.Мальгина, 53		0101000020E6100000DC0F786000874F40FBE59315C3D54C40
88059	6	56	\N	16563	77093	\N	57.670015999999997	город Ирбит, ул.МЖукова, 4		0101000020E6100000DC0F786000874F40FBE59315C3D54C40
89318	6	56	\N	16563	19967	\N	57.661721094156697	город Ирбит, ул.Логинова, 22	Россия, Свердловская область, Ирбит	0101000020E6100000357BA015188A4F40C8091346B3D44C40
88047	6	56	6985	\N	18165	\N	57.676810840883498	город Ирбит, ул.Кирова, 172	Россия, Свердловская область, городской округ Ирбит	0101000020E6100000C100C28712894F405A492BBEA1D64C40
88052	6	56	\N	16563	18432	\N	57.670505276820201	город Ирбит, ул.Горького, 3	Россия, Свердловская область, Ирбит	0101000020E6100000C0AE264F59874F40F9669B1BD3D54C40
88009	6	56	\N	49923	20179	\N	60.686736604987203	Ивдельский городской округ, г. Ивдель, Фестивальная, 15	Россия, Свердловская область, Ивдель	0101000020E6100000C66F0A2B15384E4001FA7DFFE6574E40
88011	6	56	\N	49923	19991	\N	60.676274999999997	Ивдельский городской округ, г. Ивдель, Советская, 8		0101000020E610000073F22213F0394E401B0DE02D90564E40
88004	6	56	\N	49923	18623	\N	60.676274999999997	Ивдельский городской округ, г. Ивдель, Данилова, 134		0101000020E610000073F22213F0394E401B0DE02D90564E40
88002	6	56	\N	49923	18665	\N	60.676274999999997	Ивдельский городской округ, г. Ивдель, Ворошилова, 5		0101000020E610000073F22213F0394E401B0DE02D90564E40
88014	6	56	\N	49923	18906	\N	60.676274999999997	Ивдельский городской округ, г. Ивдель, Вокзальная, 24		0101000020E610000073F22213F0394E401B0DE02D90564E40
88016	6	56	\N	17774	18342	\N	60.865737000000003	Ивдельский городской округ, п. Полуночное, Бабкина, 3		0101000020E6100000C9AB730CC8364E40F5F75278D06E4E40
88012	6	56	\N	17774	18335	\N	60.676274999999997	Ивдельский городской округ, г. Ивдель, 50 лет Октября, 17		0101000020E610000073F22213F0394E401B0DE02D90564E40
88001	6	56	\N	17774	17806	\N	60.686429335233598	Ивдельский городской округ, г. Ивдель, Фрунзе, 38	Россия, Свердловская область, Ивдель	0101000020E610000062F4DC4257384E405303CDE7DC574E40
87934	6	56	\N	13	4129	\N	56.764944999999997	город Екатеринбург, Эскадронная, 24	Россия, Свердловская область, Екатеринбург, улица Эскадронная, 24	0101000020E6100000D25625917D4C4E408E1EBFB7E9614C40
87488	6	56	\N	13	18462	\N	56.916692286850797	город Екатеринбург, Железнодорожный район, поселок Шувакиш, Школьная, 4	Россия, Свердловская область, Екатеринбург, улица Школьная, 4	0101000020E610000043E1B375703C4E409E40D82956754C40
87911	6	56	\N	13	3839	\N	56.906300999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Орджоникидзевский район, Фрезеровщиков, 84а"""""""	Россия, Свердловская область, Екатеринбург, улица Фрезеровщиков, 84а	0101000020E6100000B5C5353E93514E4082AAD1AB01744C40
87927	6	56	\N	13	4028	\N	56.778055999999999	город Екатеринбург, Титова, 28а	Россия, Свердловская область, Екатеринбург, улица Титова, 28а	0101000020E610000031CF4A5AF14D4E40713AC95697634C40
87471	6	56	\N	13	6389	\N	56.872137000000002	город Екатеринбург, Железнодорожный район, Соликамская, 4	Россия, Свердловская область, Екатеринбург, улица Соликамская, 4	0101000020E6100000C53A55BE67424E40D7506A2FA26F4C40
87657	6	56	\N	13	160	\N	56.810077999999997	город Екатеринбург, Ленинский район, Серова, 12	Россия, Свердловская область, Екатеринбург, улица Серова, 12	0101000020E610000090BFB4A84F4C4E40C39ACAA2B0674C40
87615	6	56	\N	13	18301	\N	56.838511072465302	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Ррассветная, 9"""""""	Россия, Свердловская область, Екатеринбург, улица Рассветная, 9	0101000020E61000008C9FC6BDF9574E400A2B1554546B4C40
87341	6	56	\N	13	4860	\N	56.820686000000002	город Екатеринбург, ВерхИсетский район, Посадская, 51	Россия, Свердловская область, Екатеринбург, улица Посадская, 51	0101000020E610000012D90759164A4E407D24253D0C694C40
87598	6	56	\N	13	7657	\N	56.832481999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Новгородцевой, 17а"""""""	Россия, Свердловская область, Екатеринбург, улица Новгородцевой, 17а	0101000020E61000000586AC6EF5564E401C412AC58E6A4C40
87931	6	56	\N	13	78388	\N	56.765586999999996	город Екатеринбург, Аптекарская, 46		0101000020E61000005A7F4B00FE4D4E40129F3BC1FE614C40
87955	6	56	\N	13	4403	\N	56.755496999999998	город Екатеринбург, Многостаночников, 21	Россия, Свердловская область, Екатеринбург, улица Многостаночников, 21	0101000020E610000007EBFF1CE6594E40F19C2D20B4604C40
87416	6	56	\N	13	20376	\N	56.852193162846902	город Екатеринбург, Железнодорожный район, МаминаСибиряка, 16	Россия, Свердловская область, Екатеринбург, улица Мамина-Сибиряка, 16	0101000020E6100000B3EC4960734E4E40A87004A9146D4C40
87746	6	56	\N	13	1562	\N	56.804732000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Луганская, 1"""""""	Россия, Свердловская область, Екатеринбург, улица Луганская, 1	0101000020E610000091B6F1272A514E40B8054B7501674C40
87921	6	56	\N	13	3946	\N	56.789200000000001	город Екатеринбург, Крестинского, 45	Россия, Свердловская область, Екатеринбург, улица Крестинского, 45	0101000020E6100000BBD05CA791504E4069006F8104654C40
87693	6	56	\N	13	689	\N	56.782898000000003	город Екатеринбург, Ленинский район, ул.Краснолесья, 22	Россия, Свердловская область, Екатеринбург, улица Краснолесья, 22	0101000020E61000000B5EF415A4454E404A0D6D0036644C40
87941	6	56	\N	13	4195	\N	56.753512999999998	город Екатеринбург, Колхозников, 78	Россия, Свердловская область, Екатеринбург, улица Колхозников, 78	0101000020E61000002A1A6B7F674F4E40300E2E1D73604C40
87837	6	56	\N	13	18391	\N	56.897406280869198	город Екатеринбург, Орджоникидзевский район, Кировоградская, 66	Россия, Свердловская область, Екатеринбург, улица Кировградская, 66	0101000020E6100000DCF4673F524A4E40F99D2633DE724C40
87831	6	56	\N	13	1346	\N	56.896135000000001	город Екатеринбург, Орджоникидзевский район, Калинина, 48	Россия, Свердловская область, Екатеринбург, улица Калинина, 48	0101000020E61000004DBB9866BA4B4E4086E63A8DB4724C40
87855	6	56	\N	13	3104	\N	56.905588000000002	город Екатеринбург, Орджоникидзевский район, Индустрии, 92	Россия, Свердловская область, Екатеринбург, улица Индустрии, 92	0101000020E61000000E10CCD1E34D4E4035D3BD4EEA734C40
87437	6	56	\N	13	6049	\N	56.851835000000001	город Екатеринбург, Железнодорожный район, Гражданская, 6	Россия, Свердловская область, Екатеринбург, улица Гражданская, 6	0101000020E610000096B4E21B0A4B4E40494BE5ED086D4C40
86892	6	56	\N	13	1492	\N	56.858055999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Железнодорожный район, Вокзальная, 15"""""""	Россия, Свердловская область, Екатеринбург, улица Вокзальная, 15	0101000020E61000007A3881E9B44C4E407B116DC7D46D4C40
87766	6	56	\N	13	1828	\N	56.795046999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Белоярская, 36"""""""	Россия, Свердловская область, Екатеринбург, улица Белоярская, 36	0101000020E61000002711E15F04634E4036E49F19C4654C40
87381	6	56	\N	13	19166	\N	56.851566377762801	город Екатеринбург, ВерхИсетский район, Августа Бебеля, 122б	Россия, Свердловская область, Екатеринбург, улица Бебеля, 122б	0101000020E6100000740987DEE2474E4059315C1D006D4C40
87711	6	56	\N	13	1035	\N	56.825955999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Байкальская, 55"""""""	Россия, Свердловская область, Екатеринбург, улица Байкальская, 55	0101000020E61000006B0DA5F622564E40ADF71BEDB8694C40
87634	6	56	\N	13	417	\N	56.815291000000002	город Екатеринбург, Ленинский район, Восьмого Марта, 89	Россия, Свердловская область, Екатеринбург, улица 8-го Марта, 89	0101000020E61000009BE3DC26DC4D4E4090DC9A745B684C40
87659	6	56	\N	13	77719	\N	56.815379999999998	город Екатеринбург, Ленинский район, ул.Ясная, 1/1		0101000020E6100000D447E00F3F4B4E40FFE7305F5E684C40
87366	6	56	\N	13	77719	\N	56.816921999999998	город Екатеринбург, ВерхИсетский район, Ясная, 20		0101000020E61000000A65E1EB6B494E4003B16CE690684C40
87362	6	56	\N	13	77719	\N	56.817089000000003	город Екатеринбург, ВерхИсетский район, Ясная, 16		0101000020E6100000572426A8E1494E40EF75525F96684C40
87430	6	56	\N	13	78174	\N	56.850785999999999	город Екатеринбург, Железнодорожный район, Свердлова, 11а		0101000020E6100000158E2095624D4E4084F23E8EE66C4C40
87317	6	56	\N	13	78078	\N	56.846322000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Юмашева, 20"""""""		0101000020E610000059FB3BDBA3494E4052F17F47546C4C40
87967	6	56	\N	13	19934	\N	56.7648498513527	город Екатеринбург, 32 Эскадронная, 24	Россия, Свердловская область, Екатеринбург, улица Эскадронная, 24	0101000020E61000000798F90E7E4C4E403D2CD49AE6614C40
87938	6	56	\N	13	78391	\N	56.746671999999997	город Екатеринбург, Энергетиков, 7		0101000020E610000076A73B4F3C4D4E40616BB6F2925F4C40
87653	6	56	\N	13	77914	\N	56.808112000000001	город Екатеринбург, Ленинский район, Щорса, 114		0101000020E6100000371AC05B204D4E40A9C0C93670674C40
87650	6	56	\N	13	77914	\N	56.809201000000002	город Екатеринбург, Ленинский район, Щорса, 80а		0101000020E61000007F880D164E4E4E40FC71FBE593674C40
87947	6	56	\N	13	78398	\N	56.772866999999998	город Екатеринбург, Щербакова, 118		0101000020E610000065C6DB4AAF554E402D944C4EED624C40
87898	6	56	\N	13	78380	\N	56.890830999999999	город Екатеринбург, Орджоникидзевский район, Шефская, 6		0101000020E61000004DBB9866BA514E40A9A10DC006724C40
87864	6	56	\N	13	78380	\N	56.904158000000002	город Екатеринбург, Орджоникидзевский район, Шефская, 87а		0101000020E61000005D6F9BA9104F4E4059350873BB734C40
87421	6	56	\N	13	78169	\N	56.848388999999997	город Екатеринбург, Железнодорожный район, Шевченко, 9		0101000020E61000001557957D574E4E40A0A4C002986C4C40
87662	6	56	\N	13	78209	\N	56.812531999999997	город Екатеринбург, Ленинский район, Шаумяна, 85		0101000020E61000002733DE567A494E400B7A6F0C01684C40
87512	6	56	\N	13	78209	\N	56.811695	город Екатеринбург, Ленинский район, ул.Шаумяна, 83		0101000020E61000008BC3995FCD494E40D2A92B9FE5674C40
87954	6	56	\N	13	77807	\N	56.752521000000002	город Екатеринбург, Черняховского, 32		0101000020E6100000BC9179E40F5A4E40D046AE9B52604C40
87895	6	56	\N	13	3598	\N	56.894827999999997	город Екатеринбург, Орджоникидзевский район, Черноморский, 8	Россия, Свердловская область, Екатеринбург, Черноморский переулок, 8	0101000020E61000006B990CC7F3514E40C5C551B989724C40
87806	6	56	\N	13	2375	\N	56.887590000000003	город Екатеринбург, Орджоникидзевский район, Черниговский, 8	Россия, Свердловская область, Екатеринбург, Черниговский переулок, 8	0101000020E61000004582A966D6484E40DA20938C9C714C40
87435	6	56	\N	13	77826	\N	56.851790999999999	город Екатеринбург, Железнодорожный район, Челюскинцев, 11		0101000020E6100000BAF605F4C24B4E407903CC7C076D4C40
87433	6	56	\N	13	77826	\N	56.855441999999996	город Екатеринбург, Железнодорожный район, Челюскинцев, 102		0101000020E6100000AD33BE2F2E4D4E40FACF9A1F7F6D4C40
87431	6	56	\N	13	77826	\N	56.855441999999996	город Екатеринбург, Челюскинцев, 102		0101000020E6100000AD33BE2F2E4D4E40FACF9A1F7F6D4C40
87422	6	56	\N	13	77826	\N	56.855713000000002	город Екатеринбург, Железнодорожный район, Челюскинцев, 110 а		0101000020E6100000BCE82B48334E4E408BE1EA00886D4C40
86808	6	56	\N	13	77888	\N	56.866047000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Чекистов, 21"""""""	Россия, Свердловская область, Екатеринбург, улица Чекистов, 21	0101000020E6100000603E59315C514E4043E6CAA0DA6E4C40
87302	6	56	\N	13	77463	\N	56.804780078749197	город Екатеринбург, Чайковского, 70	Россия, Свердловская область, Екатеринбург, улица Чайковского	0101000020E6100000809BC58B854F4E40C93CF20703674C40
87541	6	56	\N	13	78282	\N	56.806579999999997	город Екатеринбург, Циолковского, 70		0101000020E6100000890CAB78234F4E40C8CD70033E674C40
87745	6	56	\N	13	78345	\N	56.806564999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Цвиллинга, 53"""""""	Россия, Свердловская область, Екатеринбург, улица Цвиллинга, 53	0101000020E61000006075E44867504E40938C9C853D674C40
87627	6	56	\N	13	78311	\N	56.824685000000002	город Екатеринбург, Ленинский район, Хохрякова, 87		0101000020E610000089CE328B504C4E403A4030478F694C40
87620	6	56	\N	13	78311	\N	56.832417999999997	город Екатеринбург, Ленинский район, Хохрякова, 29а		0101000020E61000004223D8B8FE4B4E40054D4BAC8C6A4C40
87771	6	56	\N	13	78342	\N	56.790432000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Хвойная, 91"""""""		0101000020E6100000C861307F85624E401FDB32E02C654C40
87544	6	56	\N	13	7081	\N	56.837676999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Фонвизина, 4"""""""	Россия, Свердловская область, Екатеринбург, Фонвизина переулок, 4	0101000020E61000002FDB4E5B23544E4042CEFBFF386B4C40
87835	6	56	\N	13	78166	\N	56.894630999999997	город Екатеринбург, Орджоникидзевский район, Фестивальная, 6		0101000020E6100000253CA1D79F4A4E406F7EC34483724C40
87810	6	56	\N	13	78166	\N	56.889228000000003	город Екатеринбург, Орджоникидзевский район, Фестивальная, 25		0101000020E61000009DB98784EF494E4000581D39D2714C40
87808	6	56	\N	13	78166	\N	56.891567999999999	город Екатеринбург, Орджоникидзевский район, Фестивальная, 12		0101000020E61000000BB5A679C7494E407F1475E61E724C40
87929	6	56	\N	13	77771	\N	56.773508999999997	город Екатеринбург, Ферганская, 22а		0101000020E6100000D5230D6E6B4D4E40B114C95702634C40
87928	6	56	\N	13	77771	\N	56.771619000000001	город Екатеринбург, Ферганская, 22		0101000020E610000071935165184D4E4072FC5069C4624C40
87389	6	56	\N	13	78161	\N	56.796461000000001	город Екатеринбург, ВерхИсетский район, Феофанова, 10		0101000020E61000009161156F643E4E400DC51D6FF2654C40
87527	6	56	\N	13	78124	\N	56.860536000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Учителей, 2"""""""	Россия, Свердловская область, Екатеринбург, улица Учителей, 2	0101000020E610000025581CCEFC504E40ED832C0B266E4C40
87789	6	56	\N	13	2036	\N	56.753582000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, пер. Утренний, 2"""""""	Россия, Свердловская область, Екатеринбург, Утренний переулок, 2	0101000020E6100000DA8EA9BBB2674E40596DFE5F75604C40
87785	6	56	\N	13	2036	\N	56.753582000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Утренний, 2"""""""	Россия, Свердловская область, Екатеринбург, Утренний переулок, 2	0101000020E6100000DA8EA9BBB2674E40596DFE5F75604C40
87783	6	56	\N	13	2036	\N	56.756152999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Утренний, 1а"""""""	Россия, Свердловская область, Екатеринбург, Утренний переулок, 1а	0101000020E61000007958A835CD674E40DAE21A9FC9604C40
87519	6	56	\N	13	78226	\N	56.858581999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Уральская, 50а"""""""		0101000020E61000008AAC3594DA4F4E409677D503E66D4C40
87937	6	56	\N	13	78390	\N	56.763756000000001	город Екатеринбург, Умельцев, 1		0101000020E61000008E1F2A8D984B4E40D80FB1C1C2614C40
87870	6	56	\N	13	78372	\N	56.901651000000001	город Екатеринбург, Орджоникидзевский район, Ульяновская, 13		0101000020E6100000CEE33098BF504E40EEB3CA4C69734C40
87647	6	56	\N	13	78319	\N	56.815798999999998	город Екатеринбург, Ленинский район, Уктусская, 10		0101000020E6100000064CE0D6DD4C4E40048E041A6C684C40
87505	6	56	\N	13	78194	\N	56.841836999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Тургенева, 13"""""""		0101000020E6100000FDA204FD854E4E4008C89750C16B4C40
87764	6	56	\N	13	78164	\N	56.780985000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Трубачева, 76"""""""	Россия, Свердловская область, Екатеринбург, улица Трубачева, 76	0101000020E6100000FF092E56D45E4E4052D50451F7634C40
87762	6	56	\N	13	78164	\N	56.782178999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Трубачева, 72"""""""		0101000020E6100000E8BF07AF5D5E4E401A4F04711E644C40
87521	6	56	\N	13	6899	\N	56.860506000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Трамвайный, 15"""""""	Россия, Свердловская область, Екатеринбург, Трамвайный переулок, 15	0101000020E610000094111780464F4E408201840F256E4C40
87926	6	56	\N	13	78303	\N	56.778376000000002	город Екатеринбург, Титова, 19		0101000020E6100000E4D87A86704E4E40E3FE23D3A1634C40
87925	6	56	\N	13	78303	\N	56.781823000000003	город Екатеринбург, Титова, 11		0101000020E61000007974232C2A4E4E405C21ACC612644C40
87479	6	56	\N	13	77766	\N	56.879947999999999	город Екатеринбург, Железнодорожный район, Техническая, 138		0101000020E610000048179B560A414E401E17D522A2704C40
87474	6	56	\N	13	77766	\N	56.876795000000001	город Екатеринбург, Железнодорожный район, Техническая, 99		0101000020E6100000D48041D2A7414E40EE258DD13A704C40
87467	6	56	\N	13	77766	\N	56.868389000000001	город Екатеринбург, Железнодорожный район, Техническая, 42а		0101000020E610000018D1764CDD434E40639AE95E276F4C40
87460	6	56	\N	13	77766	\N	56.863256999999997	город Екатеринбург, Железнодорожный район, Техническая, 23		0101000020E610000010AFEB17EC444E40838593347F6E4C40
86887	6	56	\N	13	77766	\N	56.862332000000002	"""Екатеринбург, Железнодорожный,  Техническая 19. ТРК """"Таганский ряд"""""""		0101000020E6100000ADDBA0F65B454E40AB251DE5606E4C40
86505	6	56	\N	13	77766	\N	56.876795000000001	"""""""Свердловская область, муниципальное образование """"""""город Екатеринбург"""""""", Железнодорожный район, Техническая, 99 """""""		0101000020E6100000D48041D2A7414E40EE258DD13A704C40
85873	6	56	\N	13	77766	\N	56.873297999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Железнодорожный район, Техническая, 81"""""""		0101000020E6100000A96C585359424E40C3D4963AC86F4C40
87457	6	56	\N	13	3057	\N	56.870593	город Екатеринбург, Железнодорожный район, Теплоходный проезд, 6	Россия, Свердловская область, Екатеринбург, Теплоходный проезд, 6	0101000020E6100000DDEBA4BE2C474E40329067976F6F4C40
85876	6	56	\N	13	3057	\N	56.870593	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Железнодорожный район, Теплоходный проезд, 6"""""""	Россия, Свердловская область, Екатеринбург, Теплоходный проезд, 6	0101000020E6100000DDEBA4BE2C474E40329067976F6F4C40
87737	6	56	\N	13	78336	\N	56.823256999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Тверитина, 20"""""""		0101000020E61000004BE82E89B3504E40FE99417C60694C40
87351	6	56	\N	13	78120	\N	56.836815000000001	город Екатеринбург, ВерхИсетский район, Татищева, 78		0101000020E6100000A9A0A2EA57464E40B0E600C11C6B4C40
89329	6	56	\N	13	78251	\N	56.905819000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Орджоникидзевский район, Таганская, 75"""""""		0101000020E6100000F19C2D20B4504E40378C82E0F1734C40
87872	6	56	\N	13	78251	\N	56.905819000000001	город Екатеринбург, Орджоникидзевский район, Таганская, 75		0101000020E6100000F19C2D20B4504E40378C82E0F1734C40
87648	6	56	\N	13	78321	\N	56.813448999999999	город Екатеринбург, Ленинский район, Сурикова, 31		0101000020E6100000E38C614ED04C4E4061FBC9181F684C40
87350	6	56	\N	13	5028	\N	56.838258000000003	город Екатеринбург, ВерхИсетский район, Субботников, 1	Россия, Свердловская область, Екатеринбург, Субботников площадь, 1	0101000020E61000007B82C476F7464E4021CEC3094C6B4C40
87562	6	56	\N	13	78288	\N	56.851013000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Студенческая, 26"""""""	Россия, Свердловская область, Екатеринбург, улица Студенческая, 26	0101000020E61000002426A8E15B544E4045BC75FEED6C4C40
87554	6	56	\N	13	78288	\N	56.848399000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Студенческая, 19"""""""		0101000020E61000008BC6DADFD9544E40C47AA356986C4C40
87493	6	56	\N	13	77474	\N	56.865667999999999	город Екатеринбург, Железнодорожный район, поселок Северка, Строителей, 48		0101000020E6100000FCC6D79E59424E40CC988235CE6E4C40
87491	6	56	\N	13	78481	\N	56.856943000000001	город Екатеринбург, Железнодорожный район, поселок Северка, Стрелочников, 4 а		0101000020E6100000431A1538D94A4E40A0C4E74EB06D4C40
87644	6	56	\N	13	78198	\N	56.810886000000004	город Екатеринбург, Ленинский район, Степана Разина, 71		0101000020E61000000D897B2C7D4E4E406364C91CCB674C40
87643	6	56	\N	13	78198	\N	56.814843000000003	город Екатеринбург, Ленинский район, Степана Разина, 51		0101000020E61000000F60915F3F4E4E40F12F82C64C684C40
87886	6	56	\N	13	78374	\N	56.890166999999998	город Екатеринбург, Орджоникидзевский район, Стачек, 20		0101000020E61000002EAD86C43D504E403D7D04FEF0714C40
87869	6	56	\N	13	78374	\N	56.899051	город Екатеринбург, Орджоникидзевский район, Стачек, 70		0101000020E6100000B1A6B228EC4E4E40D237691A14734C40
87843	6	56	\N	13	78364	\N	56.897098999999997	город Екатеринбург, Орджоникидзевский район, Стахановская, 43		0101000020E6100000992D5915E14C4E401C23D923D4724C40
87888	6	56	\N	13	78384	\N	56.892688999999997	город Екатеринбург, Орджоникидзевский район, Старых большевиков, 22		0101000020E610000058CA32C4B1504E40DD3F16A243724C40
87867	6	56	\N	13	77723	\N	56.901277	город Екатеринбург, Орджоникидзевский район, Старых большевиков, 82/1		0101000020E61000007F349C32374F4E4089D1730B5D734C40
87917	6	56	\N	13	77757	\N	56.804026999999998	город Екатеринбург, Союзная, 26		0101000020E610000029B16B7BBB4D4E40ED0C535BEA664C40
87819	6	56	\N	13	77486	\N	56.8911548288619	город Екатеринбург, Орджоникидзевский район, Социалистическая, 2	Россия, Свердловская область, Екатеринбург, улица Социалистическая	0101000020E6100000789B374E0A4B4E405C55F65D11724C40
87447	6	56	\N	13	78180	\N	56.862361	город Екатеринбург, Железнодорожный район, С.Перовской, 111		0101000020E610000052D2C3D0EA464E40452C62D8616E4C40
87683	6	56	\N	13	516	\N	56.796230000000001	город Екатеринбург, Ленинский район, Решетникова, 20	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 20	0101000020E61000004E7D2079E7484E400B0C59DDEA654C40
87552	6	56	\N	13	78285	\N	56.845519000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Софьи Ковалевской, 10"""""""	Россия, Свердловская область, Екатеринбург, улица Софьи Ковалевской, 10	0101000020E6100000349F73B7EB534E40C59272F7396C4C40
87516	6	56	\N	13	78218	\N	56.853059999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Советская, 24а"""""""		0101000020E6100000533F6F2A52514E404CC3F011316D4C40
87569	6	56	\N	13	78298	\N	56.859079000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Советская, 51"""""""		0101000020E6100000070C923EAD524E4017D7F84CF66D4C40
86300	6	56	\N	13	7893	\N	56.832093	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Сиреневый бульвар, 6"""""""	Россия, Свердловская область, Екатеринбург, Сиреневый бульвар, 6	0101000020E6100000FDBD141E34574E40821DFF05826A4C40
87603	6	56	\N	13	18934	\N	56.829748075815999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Сиреневый бр, 15в"""""""	Россия, Свердловская область, Екатеринбург, Сиреневый бульвар, 15в	0101000020E61000003FE42D573F584E40F1F5B52E356A4C40
87599	6	56	\N	13	18934	\N	56.832093	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Сиреневый бр, 6"""""""	Россия, Свердловская область, Екатеринбург, Сиреневый бульвар, 6	0101000020E6100000FDBD141E34574E40821DFF05826A4C40
87752	6	56	\N	13	18177	\N	56.825584931073799	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Сбирский тракт, 1 км"""""""	Россия, Свердловская область, Екатеринбург, Сибирский тракт	0101000020E6100000F2EF332E1C524E40B988EFC4AC694C40
87750	6	56	\N	13	18177	\N	56.78738762199	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Сибирский тракт, 1 км"""""""	Россия, Свердловская область, Екатеринбург, Сибирский тракт	0101000020E6100000ACCABE2B825D4E40A5A14621C9644C40
87758	6	56	\N	13	1722	\N	56.822001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Сибирский тракт, 37"""""""	Россия, Свердловская область, Екатеринбург, Сибирский тракт, 37	0101000020E6100000D1217024D0544E40C0232A5437694C40
87656	6	56	\N	13	78320	\N	56.811202000000002	город Екатеринбург, Ленинский район, Серова, 10		0101000020E61000001DB0ABC9534C4E4093399677D5674C40
87665	6	56	\N	13	78134	\N	56.805371999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Ленинский район, Серафимы Дерябиной, 49а"""""""		0101000020E6100000680932022A464E409B8E006E16674C40
87663	6	56	\N	13	78134	\N	56.805371999999998	город Екатеринбург, Ленинский район, Серафимы Дерябиной, 49а		0101000020E6100000680932022A464E409B8E006E16674C40
87368	6	56	\N	13	78134	\N	56.815936999999998	город Екатеринбург, ВерхИсетский район, С.Дерябиной, 27а		0101000020E6100000EFFE78AF5A474E40554CA59F70684C40
87359	6	56	\N	13	78134	\N	56.820075000000003	город Екатеринбург, ВерхИсетский район, С.Дерябиной, 17а		0101000020E61000001E19ABCDFF474E4034A2B437F8684C40
87935	6	56	\N	13	77734	\N	56.756186999999997	город Екатеринбург, Селькоровская, 76/2 корп.1		0101000020E61000009A0645F3004E4E40865451BCCA604C40
87932	6	56	\N	13	77734	\N	56.765202000000002	город Екатеринбург, Селькоровская, 18		0101000020E61000005401F73C7F4E4E40BA6A9E23F2614C40
87466	6	56	\N	13	6304	\N	56.870012000000003	город Екатеринбург, Железнодорожный район, Седова, 46	Россия, Свердловская область, Екатеринбург, Седова проспект, 46	0101000020E61000008FFAEB1516444E4054909F8D5C6F4C40
87464	6	56	\N	13	6304	\N	56.867044999999997	город Екатеринбург, Железнодорожный район, Седова, 28	Россия, Свердловская область, Екатеринбург, Седова проспект, 28	0101000020E610000032AEB8382A454E4085949F54FB6E4C40
87462	6	56	\N	13	6304	\N	56.865771000000002	город Екатеринбург, Железнодорожный район, Седова, 21	Россия, Свердловская область, Екатеринбург, Седова проспект, 21	0101000020E6100000268C6665FB444E40A1698995D16E4C40
87588	6	56	\N	13	78304	\N	56.875453	"""""""Свердловская область, муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Севастопольская, 1"""""""		0101000020E6100000774EB340BB574E40B1170AD80E704C40
87587	6	56	\N	13	78304	\N	56.875453	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Севастопольская, 1"""""""	Россия, Свердловская область, Екатеринбург, улица Севастопольская, 1	0101000020E6100000774EB340BB574E40B1170AD80E704C40
87930	6	56	\N	13	78442	\N	56.768768000000001	город Екатеринбург, Санаторная, 20		0101000020E6100000A5D8D138D44D4E400D1B65FD66624C40
87313	6	56	\N	13	78076	\N	56.838002000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", ВерхИсетский район, Сакко и Ванцетти, 36"""""""	Россия, Свердловская область, Екатеринбург, улица Сакко и Ванцетти, 36	0101000020E6100000C251F2EA1C4B4E40C6FD47A6436B4C40
87577	6	56	\N	13	77316	\N	56.863227000000002	город Екатеринбург, Кировский район, Садовая, 18		0101000020E6100000423F53AF5B524E401903EB387E6E4C40
87574	6	56	\N	13	77316	\N	56.863227000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Садовая, 18"""""""	Россия, Свердловская область, Екатеринбург, улица Садовая, 18	0101000020E6100000423F53AF5B524E401903EB387E6E4C40
87748	6	56	\N	13	78155	\N	56.801479	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Саввы Белых, 7"""""""		0101000020E6100000C51B9947FE504E4024B726DD96664C40
87500	6	56	\N	13	78571	\N	56.893132000000001	город Екатеринбург, Железнодорожный район, Решетская, 55		0101000020E6100000E9D500A5A13E4E406B813D2652724C40
87357	6	56	\N	13	78127	\N	56.828754000000004	город Екатеринбург, ВерхИсетский район, Заводская, 45		0101000020E6100000EA77616BB6464E40F0366F9C146A4C40
87682	6	56	\N	13	516	\N	56.795687000000001	город Екатеринбург, Ленинский район, Решетникова, 5	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 5	0101000020E610000065AA605452494E401A6D5512D9654C40
87679	6	56	\N	13	516	\N	56.797998999999997	город Екатеринбург, Ленинский район, Решетникова, 10	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 10	0101000020E61000007A37161406494E40CF9ECBD424664C40
87839	6	56	\N	13	78368	\N	56.903700999999998	город Екатеринбург, Орджоникидзевский район, Республиканская, 1		0101000020E6100000001AA54BFF484E40662E7079AC734C40
87339	6	56	\N	13	78092	\N	56.828043999999998	город Екатеринбург, ВерхИсетский район, Репина, 15		0101000020E6100000F5BEF1B567484E4013D38558FD694C40
87333	6	56	\N	13	78092	\N	56.833063000000003	город Екатеринбург, ВерхИсетский район, Репина, 2а		0101000020E6100000D95F764F1E4A4E40FB40F2CEA16A4C40
87782	6	56	\N	13	78343	\N	56.774352	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Реактивная, 35"""""""		0101000020E610000031992A1895684E40CDCB61F71D634C40
87779	6	56	\N	13	78343	\N	56.774178999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Реактивная, 31"""""""		0101000020E61000003430F2B226684E40FF1F274C18634C40
87610	6	56	\N	13	77909	\N	56.838532999999998	город Екатеринбург, Кировский район, Рассветная, 9		0101000020E6100000EE940ED6FF574E40F2CEA10C556B4C40
87608	6	56	\N	13	77909	\N	56.838532999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Рассветная, 9"""""""	Россия, Свердловская область, Екатеринбург, улица Рассветная, 9	0101000020E6100000EE940ED6FF574E40F2CEA10C556B4C40
85755	6	56	\N	13	77834	\N	56.759793999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Ракетная, 6"""""""	Россия, Свердловская область, Екатеринбург, улица Ракетная, 6	0101000020E61000002594BE1072684E4038D906EE40614C40
87335	6	56	\N	13	78093	\N	56.828896	город Екатеринбург, ВерхИсетский район, Радищева, 51		0101000020E6100000D1048A58C44A4E4082E49D43196A4C40
87443	6	56	\N	13	6110	\N	56.862606999999997	город Екатеринбург, Железнодорожный район, переулок Пугачевский, 5	Россия, Свердловская область, Екатеринбург, Пугачевский переулок, 5а	0101000020E610000048BF7D1D38494E407C26FBE7696E4C40
87942	6	56	\N	13	77779	\N	56.771067000000002	город Екатеринбург, Походная, 84		0101000020E6100000D998D71187504E402E03CE52B2624C40
87337	6	56	\N	13	78096	\N	56.819015999999998	город Екатеринбург, ВерхИсетский район, Посадская, 75		0101000020E610000023658BA4DD4A4E404B732B84D5684C40
87877	6	56	\N	13	78375	\N	56.902628999999997	город Екатеринбург, Орджоникидзевский район, Ползунова, 36		0101000020E610000005C24EB16A524E40E9B5D95889734C40
86488	6	56	\N	13	78545	\N	56.901198999999998	д. Нижняя Шумиха, Победы, 64		0101000020E61000006BD3D85E0B4C4E400D18247D5A734C40
87518	6	56	\N	13	78223	\N	56.853876999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Пионеров, 10а"""""""		0101000020E61000009CF86A4771504E403EE76ED74B6D4C40
87454	6	56	\N	13	78149	\N	56.867936	город Екатеринбург, Железнодорожный район, Пехотинцев, 15		0101000020E6100000DD5ED218AD474E40B282DF86186F4C40
87452	6	56	\N	13	78149	\N	56.866007000000003	город Екатеринбург, Железнодорожный район, Пехотинцев, 14		0101000020E6100000C70E2A711D474E40B58D3F51D96E4C40
87376	6	56	\N	13	78149	\N	56.870750000000001	город Екатеринбург, Железнодорожный район, Пехотинцев, 4а		0101000020E6100000F0C2D66CE5454E40FA7E6ABC746F4C40
87314	6	56	\N	13	4633	\N	56.838341	"""""""муниципальное образование """"""""город Екатеринбург"""""""", ВерхИсетский район, Пестеревский, 3"""""""	Россия, Свердловская область, Екатеринбург, Пестеревский переулок, 3	0101000020E61000005FB532E1974A4E40AEF204C24E6B4C40
87532	6	56	\N	13	78241	\N	56.845500000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Первомайская, 73"""""""		0101000020E6100000F65CA626C1514E404E621058396C4C40
87511	6	56	\N	13	78241	\N	56.843870000000003	"""""""Свердловская область, муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Первомайская, 27"""""""		0101000020E6100000BEDEFDF15E4F4E40AB09A2EE036C4C40
87506	6	56	\N	13	78241	\N	56.844259000000001	"""""""Свердловская область, муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Первомайская, 59"""""""		0101000020E6100000C5C551B989504E40452DCDAD106C4C40
87933	6	56	\N	13	78393	\N	56.762390000000003	город Екатеринбург, Патриса Лумумбы, 79		0101000020E610000096CFF23CB84D4E401366DAFE95614C40
87344	6	56	\N	13	78099	\N	56.823774	"""""""муниципальное образование """"""""город Екатеринбург"""""""", ВерхИсетский район, Тольятти, 26а"""""""	Россия, Свердловская область, Екатеринбург, улица Пальмиро Тольятти, 26а	0101000020E61000007BD7A02FBD494E40C6A52A6D71694C40
87343	6	56	\N	13	78099	\N	56.823774	город Екатеринбург, ВерхИсетский район, Тольятти, 26а		0101000020E61000007BD7A02FBD494E40C6A52A6D71694C40
87944	6	56	\N	13	78395	\N	56.786423999999997	город Екатеринбург, Павлодарская, 40		0101000020E61000006E162F1686524E400E65A88AA9644C40
87617	6	56	\N	13	18309	\N	56.790464367724901	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Ленинский район, Павла Шаманова, 24"""""""	Россия, Свердловская область, Екатеринбург, Ленинский район	0101000020E610000083A279008B424E402A55A2EC2D654C40
87820	6	56	\N	13	2586	\N	56.890127999999997	город Екатеринбург, Орджоникидзевский район, Орджоникидзе, 10	Россия, Свердловская область, Екатеринбург, Орджоникидзе проспект, 10	0101000020E6100000341477BCC94B4E407FA0DCB6EF714C40
87914	6	56	\N	13	78385	\N	56.799128000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Онежская, 12"""""""		0101000020E61000001348895DDB514E40B1A888D349664C40
87936	6	56	\N	13	78389	\N	56.755732999999999	город Екатеринбург, Окружная, 1		0101000020E6100000BF7D1D38674C4E4005C1E3DBBB604C40
87596	6	56	\N	13	77937	\N	56.834668000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Новгородцевой, 9а"""""""		0101000020E6100000ADC1FBAA5C564E404582A966D66A4C40
86298	6	56	\N	13	77937	\N	56.837622000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Новгородцевой, 5а"""""""	Россия, Свердловская область, Екатеринбург, улица Новгородцевой, 5а	0101000020E6100000B77C24253D564E407F349C32376B4C40
87773	6	56	\N	13	78349	\N	56.787661999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Новая, 3"""""""	Россия, Свердловская область, Екатеринбург, Октябрьский район, улица Новая, 3	0101000020E6100000CA51802898634E40A626C11BD2644C40
87413	6	56	\N	13	78156	\N	56.818489	город Екатеринбург, ВерхИсетский район, Начдива Васильева, 1		0101000020E61000004513286211474E4060915F3FC4684C40
87628	6	56	\N	13	78317	\N	56.824162999999999	город Екатеринбург, Ленинский район, Народной воли, 21		0101000020E610000020240B98C04B4E4060C9552C7E694C40
86528	6	56	\N	13	77811	\N	56.872107999999997	город Екатеринбург, Железнодорожный район, Надеждинская, 24		0101000020E6100000ACE122F774454E403C4A253CA16F4C40
87592	6	56	\N	13	78306	\N	56.902988000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Мурзинская, 36"""""""		0101000020E61000007905A227655C4E4019575C1C95734C40
87696	6	56	\N	13	78324	\N	56.765295000000002	город Екатеринбург, Ленинский район, Мостовая, 57		0101000020E6100000B39597FC4F464E406B65C22FF5614C40
87394	6	56	\N	13	5564	\N	56.826715	город Екатеринбург, ВерхИсетский район, Московский тракт, 9км, 23а		0101000020E61000000475CAA31B3D4E406B0E10CCD1694C40
87734	6	56	\N	13	78334	\N	56.827005	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Мичурина, 181"""""""		0101000020E6100000309DD66D50514E407250C24CDB694C40
87740	6	56	\N	13	78335	\N	56.822257	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Мичурина, 229"""""""		0101000020E6100000753E3C4B90514E401BF4A5B73F694C40
88287	6	56	\N	13	78347	\N	56.836131000000002	Качканарский городской округ, Мира, 40		0101000020E61000004A26A77686534E40FD153257066B4C40
87538	6	56	\N	13	78263	\N	56.833658999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Мира, 46"""""""		0101000020E6100000562B137EA9534E400E828E56B56A4C40
87566	6	56	\N	13	78294	\N	56.846961999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Мира, 22"""""""		0101000020E61000007270E998F3524E40357A3540696C4C40
87395	6	56	\N	13	78499	\N	56.836756000000001	город Екатеринбург, ВерхИсетский район, Мира, 31		0101000020E6100000B07614E7A8534E40AB5D13D21A6B4C40
87469	6	56	\N	13	78058	\N	56.868575999999997	город Екатеринбург, Железнодорожный район, Минометчиков, 48		0101000020E61000006D8FDE701F434E40950B957F2D6F4C40
87378	6	56	\N	13	78151	\N	56.8277	город Екатеринбург, ВерхИсетский район, Металлургов, 46		0101000020E610000039B9DFA128444E401973D712F2694C40
87579	6	56	\N	13	78309	\N	56.862765000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Менделеева, 17"""""""	Россия, Свердловская область, Екатеринбург, улица Менделеева, 17	0101000020E6100000617138F3AB514E40159161156F6E4C40
87816	6	56	\N	13	78352	\N	56.886268000000001	город Екатеринбург, Орджоникидзевский район, Машиностроителей, 11		0101000020E6100000992D5915E14C4E40E4BED53A71714C40
87815	6	56	\N	13	78352	\N	56.885416999999997	город Екатеринбург, Орджоникидзевский район, Машиностроителей, 8		0101000020E6100000EE5F5969524A4E404529215855714C40
87803	6	56	\N	13	78352	\N	56.885140999999997	город Екатеринбург, Орджоникидзевский район, Машиностроителей, 16		0101000020E610000004745FCE6C494E40A3ACDF4C4C714C40
87540	6	56	\N	13	78249	\N	56.839582	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Малышева, 134"""""""		0101000020E610000003D19332A9534E40B727486C776B4C40
87537	6	56	\N	13	78249	\N	56.840389999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Малышева, 117"""""""		0101000020E6100000D1B2EE1F0B534E4056F146E6916B4C40
87729	6	56	\N	13	78331	\N	56.830540999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Луначарского, 200"""""""	Россия, Свердловская область, Екатеринбург, улица Луначарского, 200	0101000020E6100000BB2A508BC14F4E405A7EE02A4F6A4C40
87727	6	56	\N	13	78331	\N	56.832861000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Луначарского, 173"""""""		0101000020E61000006D01A1F5F04F4E40938E72309B6A4C40
87840	6	56	\N	13	78365	\N	56.903360999999997	город Екатеринбург, Орджоникидзевский район, Ломоносова, 57		0101000020E6100000360186E5CF4B4E40ADBD4F55A1734C40
87550	6	56	\N	13	78284	\N	56.843564999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Лодыгина, 8"""""""		0101000020E61000002E71E481C8544E406E861BF0F96B4C40
87424	6	56	\N	13	78171	\N	56.848236999999997	город Екатеринбург, Железнодорожный район, Лермонтова, 11		0101000020E61000006F29E78BBD4D4E40EA20AF07936C4C40
88373	6	56	\N	13	889	\N	56.838287000000001	городской округ Краснотурьинск, Ленина, 33	Россия, Свердловская область, Екатеринбург, Ленина проспект, 33	0101000020E6100000ACE3F8A1D24C4E40BBD408FD4C6B4C40
88364	6	56	\N	13	889	\N	56.839419999999997	городской округ Краснотурьинск, Ленина, 41	Россия, Свердловская область, Екатеринбург, Ленина проспект, 41	0101000020E610000037E33444154E4E40DDCD531D726B4C40
87719	6	56	\N	13	889	\N	56.840020000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Ленина, 50а"""""""	Россия, Свердловская область, Екатеринбург, Ленина проспект, 50а	0101000020E61000001B67D311C04F4E4033FE7DC6856B4C40
87619	6	56	\N	13	889	\N	56.837622000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Ленинский район, Ленина, 28"""""""	Россия, Свердловская область, Екатеринбург, Ленина проспект, 28	0101000020E6100000FF5A5EB9DE4C4E407F349C32376B4C40
87535	6	56	\N	13	889	\N	56.841358999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Ленина, 64а"""""""	Россия, Свердловская область, Екатеринбург, Ленина проспект, 64а	0101000020E61000007B8505F703524E40FE98D6A6B16B4C40
87531	6	56	\N	13	889	\N	56.843964	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Ленина, 101 корп.2"""""""	Россия, Свердловская область, Екатеринбург, Ленина проспект, 101к2	0101000020E61000007CD5CA845F524E402C802903076C4C40
87529	6	56	\N	13	889	\N	56.842466999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Ленина, 89"""""""	Россия, Свердловская область, Екатеринбург, Ленина проспект, 89	0101000020E6100000B77F65A549514E40C87A6AF5D56B4C40
87509	6	56	\N	13	889	\N	56.840857	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Ленина, дом 69, корп. 10"""""""	Россия, Свердловская область, Екатеринбург, Ленина проспект, 69к10	0101000020E6100000126C5CFFAE4F4E406CCEC133A16B4C40
87428	6	56	\N	13	889	\N	56.836126	город Екатеринбург, Ленинский район, Ленина, 8	Россия, Свердловская область, Екатеринбург, Ленина проспект, 8	0101000020E6100000433D7D04FE4A4E40EBAA402D066B4C40
87319	6	56	\N	13	889	\N	56.837888	город Екатеринбург, ВерхИсетский район, Ленина, 1	Россия, Свердловская область, Екатеринбург, Ленина проспект, 1	0101000020E610000085285FD0424A4E40FDDAFAE93F6B4C40
86910	6	56	\N	13	889	\N	56.835850000000001	село Яр, Ленина, 2в	Россия, Свердловская область, Екатеринбург, Ленина проспект, 2	0101000020E6100000350BB43BA44A4E40492EFF21FD6A4C40
87950	6	56	\N	13	78400	\N	56.745730000000002	город Екатеринбург, Кутузова, 15		0101000020E6100000EE21E17B7F574E40B3D2A414745F4C40
87482	6	56	\N	13	78011	\N	56.883203999999999	город Екатеринбург, Железнодорожный район, Кунарская, 28		0101000020E6100000B5DFDA8992404E4023D923D40C714C40
87754	6	56	\N	13	77805	\N	56.826636000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Куйбышева, 100а"""""""	Россия, Свердловская область, Екатеринбург, улица Куйбышева, 100а	0101000020E6100000B5C189E8D7524E401FD95C35CF694C40
87732	6	56	\N	13	77805	\N	56.830280000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Куйбышева, 111"""""""		0101000020E61000001616DC0F78504E40EE42739D466A4C40
87823	6	56	\N	13	78356	\N	56.888435999999999	город Екатеринбург, Орджоникидзевский район, Кузнецова, 5		0101000020E6100000B988EFC4AC4D4E40664B5645B8714C40
87924	6	56	\N	13	77493	\N	56.793168000000001	город Екатеринбург, Крестинского, 13а		0101000020E6100000609335EA214E4E40EB1D6E8786654C40
87923	6	56	\N	13	77493	\N	56.790515999999997	город Екатеринбург, Крестинского, 33		0101000020E61000002E8ECA4DD44E4E407C7BD7A02F654C40
87922	6	56	\N	13	77493	\N	56.788519000000001	город Екатеринбург, Крестинского, 43		0101000020E6100000B6662B2FF94F4E4027A3CA30EE644C40
87920	6	56	\N	13	77493	\N	56.7892000630006	город Екатеринбург, Крестинского, 47	Россия, Свердловская область, Екатеринбург, улица Крестинского	0101000020E610000057ED9A90D6504E4069006F8104654C40
87328	6	56	\N	13	78087	\N	56.830970000000001	город Екатеринбург, ВерхИсетский район, Крауля, 46		0101000020E61000009EB4705985474E4083FA96395D6A4C40
87327	6	56	\N	13	78087	\N	56.829881	город Екатеринбург, ВерхИсетский район, Крауля, 91		0101000020E610000048A5D8D138444E403049658A396A4C40
87325	6	56	\N	13	78087	\N	56.833393000000001	город Екатеринбург, ВерхИсетский район, Крауля, 82а		0101000020E610000003CDE7DCED444E4090DB2F9FAC6A4C40
87323	6	56	\N	13	78087	\N	56.833393000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", ВерхИсетский район, Крауля, 82а"""""""	Россия, Свердловская область, Екатеринбург, улица Крауля, 82а	0101000020E610000003CDE7DCED444E4090DB2F9FAC6A4C40
87813	6	56	\N	13	78357	\N	56.890368000000002	город Екатеринбург, Орджоникидзевский район, Красных партизан, 4		0101000020E6100000C6A52A6D714B4E40D5B32094F7714C40
87879	6	56	\N	13	78376	\N	56.895521000000002	город Екатеринбург, Орджоникидзевский район, Красных командиров, 11а		0101000020E61000004815C5ABAC4F4E40CCF09F6EA0724C40
87901	6	56	\N	13	78397	\N	56.887329999999999	город Екатеринбург, Орджоникидзевский район, Краснофлотцев, 3		0101000020E61000000971E5EC9D4F4E403D61890794714C40
87896	6	56	\N	13	78397	\N	56.890624000000003	город Екатеринбург, Орджоникидзевский район, Краснофлотцев, 28а		0101000020E6100000A7936C7539514E4030849CF7FF714C40
87691	6	56	\N	13	78153	\N	56.782898000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Ленинский район, Краснолесья, 22"""""""		0101000020E61000000B5EF415A4454E404A0D6D0036644C40
87716	6	56	\N	13	77126	\N	56.834471000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Красноармейская, 27"""""""	Россия, Свердловская область, Екатеринбург, улица Красноармейская, 27	0101000020E61000009CFC169D2C4F4E40EF3A1BF2CF6A4C40
87375	6	56	\N	13	78147	\N	56.824710000000003	город Екатеринбург, ВерхИсетский район, Котельникова, 5а		0101000020E610000079AF5A99F0454E409357E71890694C40
87902	6	56	\N	13	2645	\N	56.881585999999999	город Екатеринбург, Орджоникидзевский район, Космонавтов, 30/1	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 30к1	0101000020E6100000AC6F6072A34E4E40444E5FCFD7704C40
87882	6	56	\N	13	2645	\N	56.892069999999997	город Екатеринбург, Орджоникидзевский район, Космонавтов, 54а	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 54а	0101000020E610000011C64FE3DE4E4E4011DF89592F724C40
87862	6	56	\N	13	2645	\N	56.924298999999998	город Екатеринбург, Орджоникидзевский район, Космонавтов, 99а	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 99а	0101000020E6100000C0EC9E3C2C4E4E40DD5CFC6D4F764C40
87857	6	56	\N	13	2645	\N	56.909782596388197	город Екатеринбург, Орджоникидзевский район, Космонавтов, 65	Россия, Свердловская область, Екатеринбург, Космонавтов проспект	0101000020E6100000166EF9484A4E4E4077BAF3C473744C40
87854	6	56	\N	13	2645	\N	56.901792999999998	город Екатеринбург, Орджоникидзевский район, Космонавтов, 43в	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 43в	0101000020E61000001C42959A3D4E4E408061F9F36D734C40
87825	6	56	\N	13	2645	\N	56.890860000000004	город Екатеринбург, Орджоникидзевский район, Космонавтов, 23	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 23	0101000020E6100000048E041A6C4E4E4044A852B307724C40
87260	6	56	\N	13	2645	\N	56.881659999999997	город Екатеринбург, Орджоникидзевский район, Космонавтов, 30/2	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 30к2	0101000020E61000000BCF4BC5C64E4E407E18213CDA704C40
87952	6	56	\N	13	78402	\N	56.749895000000002	город Екатеринбург, Косарева, 9		0101000020E610000098A59D9ACB594E408B37328FFC5F4C40
87943	6	56	\N	13	4234	\N	56.779164999999999	город Екатеринбург, переулок Короткий, 7	Россия, Свердловская область, Екатеринбург, Короткий переулок, 7	0101000020E6100000459DB98784514E400B98C0ADBB634C40
87945	6	56	\N	13	4248	\N	56.790343999999997	город Екатеринбург, переулок Корейский, 6	Россия, Свердловская область, Екатеринбург, Корейский переулок, 6	0101000020E6100000D09849D40B544E407F4B00FE29654C40
87555	6	56	\N	13	78143	\N	56.850603999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Комсомольская, 21"""""""		0101000020E61000009CF9D51C20544E4063EC8497E06C4C40
87548	6	56	\N	13	78143	\N	56.838602000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Комсомольская, 63"""""""		0101000020E61000008F8AFF3BA2544E401B2E724F576B4C40
87546	6	56	\N	13	78143	\N	56.836267999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Комсомольская, 74"""""""		0101000020E610000053EA92718C544E407D586FD40A6B4C40
87860	6	56	\N	13	78371	\N	56.907057000000002	город Екатеринбург, Орджоникидзевский район, Коммунистическая, 81		0101000020E6100000DF32A7CB624C4E40CF4D9B711A744C40
87848	6	56	\N	13	78371	\N	56.905858000000002	город Екатеринбург, Орджоникидзевский район, Коммунистическая, 53		0101000020E610000026016A6AD94C4E40F568AA27F3734C40
87697	6	56	\N	13	78363	\N	56.760686999999997	город Екатеринбург, Ленинский район, Комбинатская, 7		0101000020E610000095D233BDC4484E4005BF0D315E614C40
87940	6	56	\N	13	78396	\N	56.752141000000002	город Екатеринбург, Колхозников, 52		0101000020E610000075560BEC314F4E40897D022846604C40
87590	6	56	\N	13	18224	\N	56.8771750587537	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Коломенски й, 3"""""""	Россия, Свердловская область, Екатеринбург, Коломенский переулок, 3	0101000020E6100000B3B27DC85B5E4E4035EF384547704C40
87439	6	56	\N	13	78177	\N	56.850633999999999	город Екатеринбург, Железнодорожный район, Колмогорова, 70		0101000020E610000057410C74ED494E40CE6E2D93E16C4C40
87321	6	56	\N	13	78083	\N	56.832166999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", ВерхИсетский район, Ключевская, 5А"""""""	Россия, Свердловская область, Екатеринбург, улица Ключевская, 5а	0101000020E610000029B4ACFBC7484E40BCE7C072846A4C40
87828	6	56	\N	13	78359	\N	56.892797000000002	город Екатеринбург, Орджоникидзевский район, Кировградская, 40а		0101000020E61000008978EBFCDB4B4E40C47B0E2C47724C40
87874	6	56	\N	13	78373	\N	56.904659000000002	город Екатеринбург, Орджоникидзевский район, Каширская, 73		0101000020E61000004293C49272514E401B84B9DDCB734C40
87724	6	56	\N	13	77482	\N	56.8325004262379	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Карла Маркса, 33"""""""	Россия, Свердловская область, Екатеринбург, улица Карла Маркса, 33	0101000020E61000002409C21550504E40C3F5285C8F6A4C40
87624	6	56	\N	13	77482	\N	56.830629999999999	город Екатеринбург, Ленинский район, Карла Маркса, 5		0101000020E6100000ADF6B0170A4E4E40CA897615526A4C40
87760	6	56	\N	13	78316	\N	56.807363000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Каменотесов, 9"""""""		0101000020E6100000B686527B115B4E400F80B8AB57674C40
87827	6	56	\N	13	78178	\N	56.893230000000003	город Екатеринбург, Орджоникидзевский район, Калинина, 26а		0101000020E610000023F77475C74C4E402EE7525C55724C40
87573	6	56	\N	13	78296	\N	56.859847000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Июльская, 20"""""""		0101000020E610000073DA53724E524E4028486C770F6E4C40
87567	6	56	\N	13	78296	\N	56.860107999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Июльская, 32"""""""		0101000020E6100000F52F49658A514E409483D904186E4C40
87958	6	56	\N	13	78403	\N	56.759089000000003	город Екатеринбург, Инженерная, 48		0101000020E6100000677DCA31595A4E406EE00ED429614C40
87845	6	56	\N	13	78353	\N	56.896937000000001	город Екатеринбург, Орджоникидзевский район, Ильича, 48а		0101000020E6100000BEBF417BF54D4E4043C9E4D4CE724C40
87804	6	56	\N	13	78353	\N	56.891326999999997	город Екатеринбург, Орджоникидзевский район, Ильича, 26		0101000020E6100000026553AEF04C4E405985CD0017724C40
87846	6	56	\N	13	78369	\N	56.903297999999999	город Екатеринбург, Орджоникидзевский район, Избирателей, 68		0101000020E61000006DE34F54364C4E406745D4449F734C40
87890	6	56	\N	13	78382	\N	56.898318000000003	город Екатеринбург, Орджоникидзевский район, Замятина, 11а		0101000020E61000002E39EE940E524E403EB48F15FC724C40
87441	6	56	\N	13	78570	\N	56.864373999999998	город Екатеринбург, Железнодорожный район, Завокзальная, 5		0101000020E6100000F0880AD5CD4B4E40A0C1A6CEA36E4C40
87968	6	56	\N	13	19232	\N	56.782071240708198	город Екатеринбург, улица Жуковского, 10	Россия, Свердловская область, Екатеринбург, Жуковского площадь, 10	0101000020E6100000BC02D19332534E4034130CE71A644C40
87525	6	56	\N	13	77476	\N	56.861394961905397	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Железнодорожников, 3"""""""	Россия, Свердловская область, Екатеринбург, улица Железнодорожников, 3	0101000020E610000066A4DE53394F4E400EF8FC30426E4C40
87427	6	56	\N	13	77906	\N	56.846986000000001	город Екатеринбург, Железнодорожный район, Еремина, 10		0101000020E6100000B58828266F4C4E40BE1589096A6C4C40
87689	6	56	\N	13	18772	\N	56.795115669243202	город Екатеринбург, Ленинский район, ул.ДенисоваУральского, 3	Россия, Свердловская область, Екатеринбург, Денисова-Уральского бульвар, 3	0101000020E6100000F12BD670914B4E405F43705CC6654C40
87687	6	56	\N	13	18772	\N	56.794971888672897	город Екатеринбург, Ленинский район, ДенисоваУральского, 9а	Россия, Свердловская область, Екатеринбург, Денисова-Уральского бульвар, 9а	0101000020E610000025EA059FE64A4E402C9E7AA4C1654C40
87730	6	56	\N	13	78332	\N	56.823946999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Декабристов, 49"""""""		0101000020E61000006A847EA65E4F4E409351651877694C40
87584	6	56	\N	13	78300	\N	56.868817	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Данилы Зверева, 30"""""""	Россия, Свердловская область, Екатеринбург, улица Данилы Зверева, 30	0101000020E6100000630D17B9A7534E40BB9A3C65356F4C40
87582	6	56	\N	13	78300	\N	56.860422999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Данилы Зверева, 8"""""""		0101000020E61000005B3FFD67CD534E40F4DC4257226E4C40
87580	6	56	\N	13	78300	\N	56.861333000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Данилы Зверева, 11"""""""		0101000020E61000003753211E89534E4098FBE428406E4C40
87892	6	56	\N	13	78381	\N	56.896681000000001	город Екатеринбург, Орджоникидзевский район, Даниловская, 1		0101000020E61000000AD6389B8E524E40E8F86871C6724C40
87669	6	56	\N	13	78323	\N	56.802326999999998	город Екатеринбург, Ленинский район, Громова, 138а		0101000020E610000005DCF3FC69474E4051D9B0A6B2664C40
87956	6	56	\N	13	78313	\N	56.753838000000002	город Екатеринбург, Грибоедова, 13		0101000020E610000032AF230ED9584E40B43D7AC37D604C40
87953	6	56	\N	13	78313	\N	56.752457	город Екатеринбург, Грибоедова, 11а		0101000020E610000093C83EC8B2584E40B952CF8250604C40
87412	6	56	\N	13	78022	\N	56.851858999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", ВерхИсетский район, Готвальда, 15а"""""""		0101000020E610000007B5DFDA89484E40D1E638B7096D4C40
87385	6	56	\N	13	78022	\N	56.851858999999997	город Екатеринбург, ВерхИсетский район, Готвальда, 15а		0101000020E610000007B5DFDA89484E40D1E638B7096D4C40
87379	6	56	\N	13	78022	\N	56.853276999999999	город Екатеринбург, ВерхИсетский район, Готвальда, 19а		0101000020E61000007FF5B86FB5484E40E9B6442E386D4C40
87700	6	56	\N	13	78327	\N	56.759686000000002	город Екатеринбург, Ленинский район, Городская, 2б		0101000020E6100000FA5FAE450B484E40529D0E643D614C40
87715	6	56	\N	13	1058	\N	56.767786999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Горнистов, 13"""""""	Россия, Свердловская область, Екатеринбург, Горнистов проезд, 13	0101000020E6100000139A249694694E40A0A52BD846624C40
87778	6	56	\N	13	18223	\N	56.787537999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Главная, 1а"""""""	Россия, Свердловская область, Екатеринбург, Карасье-Озерский лесопарк	0101000020E6100000C0CDE2C5C25C4E40BA2D910BCE644C40
87776	6	56	\N	13	18223	\N	56.787537999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Главная, 21"""""""	Россия, Свердловская область, Екатеринбург, Карасье-Озерский лесопарк	0101000020E6100000C0CDE2C5C25C4E40BA2D910BCE644C40
87946	6	56	\N	13	78305	\N	56.784269000000002	город Екатеринбург, Гаршина, 8б		0101000020E610000059F8FA5A97544E40212235ED62644C40
86005	6	56	\N	13	4670	\N	56.839990999999998	Свердловская область, Гаринский городской округ, Медиков, 6	Россия, Свердловская область, Екатеринбург, Гаринский переулок, 4	0101000020E61000009CDCEF50144A4E4098F738D3846B4C40
87612	6	56	\N	13	78308	\N	56.841521999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Высоцкого, 22"""""""		0101000020E6100000E57CB1F7E2574E40A86E2EFEB66B4C40
86870	6	56	\N	13	78308	\N	56.843344000000002	Екатеринбург, Кировский, ул. Высоцкого 45. ТК «КОР»		0101000020E6100000E4688EACFC584E4090A339B2F26B4C40
87419	6	56	\N	13	78167	\N	56.850555	город Екатеринбург, Железнодорожный район, Восточная, 26		0101000020E6100000876F61DD784F4E4082397AFCDE6C4C40
87851	6	56	\N	13	78383	\N	56.902619000000001	город Екатеринбург, Орджоникидзевский район, Восстания, 34		0101000020E6100000CB4BFE277F4D4E40C6DFF60489734C40
87678	6	56	\N	13	78322	\N	56.801287000000002	город Екатеринбург, Ленинский район, Волгоградская, 37б		0101000020E6100000527DE717254A4E40E0DA899290664C40
87676	6	56	\N	13	78322	\N	56.802815000000002	город Екатеринбург, Ленинский район, Волгоградская, 45а		0101000020E61000004C1938A0A5494E407FDE54A4C2664C40
87674	6	56	\N	13	78322	\N	56.803927999999999	город Екатеринбург, Ленинский район, Волгоградская, 47а		0101000020E6100000DFDDCA129D494E405A2BDA1CE7664C40
86424	6	56	\N	13	78562	\N	56.858440000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Железнодорожный район, Вокзальная, 22"""""""	Россия, Свердловская область, Екатеринбург, улица Вокзальная, 22	0101000020E6100000E40F069E7B4D4E4004CAA65CE16D4C40
87311	6	56	\N	13	77711	\N	56.840867000000003	город Екатеринбург, ВерхИсетский район, Антона Валека, 8А		0101000020E6100000670FB402434C4E4090A4A487A16B4C40
87347	6	56	\N	13	4994	\N	56.838788999999998	город Екатеринбург, ВерхИсетский район, ВерхИсетский, 23	Россия, Свердловская область, Екатеринбург, Верх-Исетский бульвар, 23	0101000020E6100000A304FD851E494E404D9F1D705D6B4C40
87906	6	56	\N	13	18582	\N	56.880210723087799	город Екатеринбург, Орджоникидзевский район, Верстовая, 14	Россия, Свердловская область, Екатеринбург, Орджоникидзевский район	0101000020E61000002BDEC83CF2554E402C4A09C1AA704C40
87522	6	56	\N	13	78228	\N	56.829005000000002	город Екатеринбург, Ленинский район, Вайнера, 54		0101000020E610000070ED4449484C4E40399CF9D51C6A4C40
87503	6	56	\N	13	78193	\N	56.851588999999997	город Екатеринбург, Железнодорожный район, Братьев Быковых, 34 а		0101000020E6100000A7CF0EB8AE4C4E4011514CDE006D4C40
87951	6	56	\N	13	78401	\N	56.750343999999998	город Екатеринбург, Бородина, 1		0101000020E6100000C426327381594E40FA5FAE450B604C40
87331	6	56	\N	13	78090	\N	56.847251999999997	город Екатеринбург, ВерхИсетский район, Большой Конный полуостров, 9		0101000020E6100000A06CCA15DE3F4E403CBCE7C0726C4C40
87738	6	56	\N	13	78314	\N	56.821306	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Большакова, 18"""""""		0101000020E6100000C6151747E5504E401901158E20694C40
87638	6	56	\N	13	78314	\N	56.818157999999997	город Екатеринбург, Ленинский район, Большакова, 65		0101000020E6100000E605D847A74E4E40FA7ABE66B9684C40
87513	6	56	\N	13	78214	\N	56.846429999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Блюхера, 5а"""""""	Россия, Свердловская область, Екатеринбург, улица Блюхера, 5а	0101000020E610000012859675FF504E40382D78D1576C4C40
87969	6	56	\N	13	78392	\N	56.742995000000001	город Екатеринбург, Чкаловский район, Бисертская, 14		0101000020E6100000FB928D075B4E4E40B70BCD751A5F4C40
87939	6	56	\N	13	78392	\N	56.745690000000003	город Екатеринбург, Бисертская, 30		0101000020E6100000BA84436FF14E4E40257A19C5725F4C40
87475	6	56	\N	13	77822	\N	56.884703999999999	город Екатеринбург, Железнодорожный район, Билимбаевская, 26		0101000020E61000008BFED0CC93414E40F8510DFB3D714C40
86530	6	56	\N	13	77822	\N	56.884132999999999	город Екатеринбург, Железнодорожный район, Билимбаевская, 33		0101000020E6100000EBE40CC51D414E403D2828452B714C40
87606	6	56	\N	13	77480	\N	56.834013953205499	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Бетонщиков, 3"""""""	Россия, Свердловская область, Екатеринбург, улица Бетонщиков, 3	0101000020E6100000F834272F32594E40FD3383F8C06A4C40
87769	6	56	\N	13	78341	\N	56.792980999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Белоярская, 20"""""""		0101000020E6100000ED9DD15625634E40B8ACC26680654C40
87364	6	56	\N	13	78118	\N	56.818710000000003	город Екатеринбург, ВерхИсетский район, Белореченская, 26		0101000020E6100000FCA9F1D24D484E403F74417DCB684C40
87348	6	56	\N	13	78118	\N	56.813251000000001	город Екатеринбург, ВерхИсетский район, Белореченская, 25		0101000020E61000002EE23B31EB474E403B38D89B18684C40
88275	6	56	\N	13	77721	\N	56.821809000000002	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Белинского, 91"""""""		0101000020E6100000AEF204C24E4F4E407C478D0931694C40
87919	6	56	\N	13	77721	\N	56.799537000000001	город Екатеринбург, Белинского, 226/3		0101000020E610000087156EF948504E409278793A57664C40
87742	6	56	\N	13	77721	\N	56.806747000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Белинского, 163"""""""		0101000020E6100000D53E1D8F19504E40B492567C43674C40
87641	6	56	\N	13	77721	\N	56.813316	город Екатеринбург, Ленинский район, Белинского, 123		0101000020E61000009C6F44F7AC4F4E4022A81ABD1A684C40
87387	6	56	\N	13	20141	\N	56.851989624180497	город Екатеринбург, ВерхИсетский район, Августа Бебеля, 122а	Россия, Свердловская область, Екатеринбург, улица Бебеля, 122а	0101000020E61000007B698A00A7474E40704221020E6D4C40
87383	6	56	\N	13	20141	\N	56.846204840426097	город Екатеринбург, ВерхИсетский район, Августа Бебеля, 16	Россия, Свердловская область, Екатеринбург, улица Бебеля, 16	0101000020E61000002942EA76F6474E40185B0872506C4C40
87450	6	56	\N	13	78182	\N	56.865445999999999	город Екатеринбург, Железнодорожный район, Бебеля, 150		0101000020E610000060915F3FC4464E401D3A3DEFC66E4C40
87915	6	56	\N	13	3882	\N	56.750152	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, пл. Бахчиванджи, 1"""""""	Россия, Свердловская область, Екатеринбург, Бахчиванджи площадь, 1	0101000020E61000001B2AC6F99B664E40B68311FB04604C40
87885	6	56	\N	13	78379	\N	56.888598000000002	город Екатеринбург, Орджоникидзевский район, Баумана, 7		0101000020E610000096E82CB3084F4E4040A54A94BD714C40
87881	6	56	\N	13	78379	\N	56.890481999999999	город Екатеринбург, Орджоникидзевский район, Баумана, 17		0101000020E610000058E4D70FB14F4E409DD66D50FB714C40
87833	6	56	\N	13	78362	\N	56.901935999999999	город Екатеринбург, Орджоникидзевский район, Бакинских комиссаров, 50		0101000020E61000001A6A1492CC4A4E40E38A8BA372734C40
87757	6	56	\N	13	78297	\N	56.826448999999997	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Байкальская, 41"""""""	Россия, Свердловская область, Екатеринбург, улица Байкальская, 41	0101000020E6100000DF162CD505564E40EC67B114C9694C40
87722	6	56	\N	13	78329	\N	56.835180000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Бажова, 139"""""""	Россия, Свердловская область, Екатеринбург, улица Бажова, 139	0101000020E6100000923D42CD90504E40FB22A12DE76A4C40
87721	6	56	\N	13	78329	\N	56.838183999999998	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Октябрьский район, Бажова, 124"""""""		0101000020E6100000DE3994A12A504E40E603029D496B4C40
87445	6	56	\N	13	78179	\N	56.867182999999997	город Екатеринбург, Железнодорожный район, Артинская, 26		0101000020E61000003CF6B3588A4A4E40D65240DAFF6E4C40
87497	6	56	\N	13	78006	\N	56.885156000000002	город Екатеринбург, Железнодорожный район, Ангарская, 54 а		0101000020E6100000C4EA8F300C424E40D9EDB3CA4C714C40
87477	6	56	\N	13	78006	\N	56.885156000000002	город Екатеринбург, Железнодорожный район, Ангарская, 54а		0101000020E6100000C4EA8F300C424E40D9EDB3CA4C714C40
87957	6	56	\N	13	77495	\N	56.756514877441603	город Екатеринбург, Альпинистов, 27	Россия, Свердловская область, Екатеринбург, улица Альпинистов	0101000020E61000000BD28C45D3594E407BF7C77BD5604C40
87483	6	56	\N	13	77679	\N	56.886735000000002	город Екатеринбург, Железнодорожный район, Акулова, 29а		0101000020E6100000D7DF12807F3E4E40FA9B508880714C40
87558	6	56	\N	13	78292	\N	56.850594000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Академическая, 16"""""""		0101000020E6100000F698486936534E404016A243E06C4C40
87686	6	56	\N	13	78330	\N	56.794074999999999	город Екатеринбург, Ленинский район, Академика Постовского, 8		0101000020E6100000193DB7D0954A4E401DC9E53FA4654C40
87672	6	56	\N	13	77933	\N	56.803825000000003	город Екатеринбург, Ленинский район, Академика Бардина, 28		0101000020E610000057056A3178484E40865AD3BCE3664C40
87668	6	56	\N	13	77933	\N	56.803390999999998	город Екатеринбург, Ленинский район, Академика Бардина, 21б		0101000020E61000001B4641F0F8464E404B732B84D5664C40
87371	6	56	\N	13	77933	\N	56.807082000000001	город Екатеринбург, ВерхИсетский район, Академика Бардина, 14		0101000020E61000006FF085C954474E405B9885764E674C40
86915	6	56	\N	13	77933	\N	56.804687000000001	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Ленинский район, Академика Бардина, 25/2"""""""	Россия, Свердловская область, Екатеринбург, улица Академика Бардина, 25к2	0101000020E6100000780E65A88A474E401842CEFBFF664C40
88989	6	56	\N	13	78172	\N	56.807920000000003	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Чкаловский район, 8 Марта, 145"""""""		0101000020E610000042E8A04B384E4E4065E42CEC69674C40
87918	6	56	\N	13	78172	\N	56.801982000000002	город Екатеринбург, 8 Марта, 177		0101000020E61000002D3E05C0784E4E4087FD9E58A7664C40
87637	6	56	\N	13	78172	\N	56.815291000000002	город Екатеринбург, Ленинский район, 8 Марта, 89		0101000020E61000009BE3DC26DC4D4E4090DC9A745B684C40
87633	6	56	\N	13	78172	\N	56.823650999999998	город Екатеринбург, Ленинский район, 8 Марта, 66		0101000020E6100000C32D1F49494D4E40AA285E656D694C40
87631	6	56	\N	13	78172	\N	56.817888000000004	город Екатеринбург, Ленинский район, 8 Марта, 84		0101000020E6100000CB2E185C734D4E403BE5D18DB0684C40
87602	6	56	\N	13	18655	\N	56.828288693536898	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, 40летия Комсомола, 22а"""""""	Россия, Свердловская область, Екатеринбург, улица 40 Лет ВЛКСМ, 22а	0101000020E61000006760E4654D584E407A51BB5F056A4C40
87801	6	56	\N	13	78350	\N	56.884571000000001	город Екатеринбург, Орджоникидзевский район, Машиностроителей, 26		0101000020E6100000EDF0D7648D484E40B9FE5D9F39714C40
87560	6	56	\N	13	78310	\N	56.851573999999999	"""""""муниципальное образование """"""""город Екатеринбург"""""""", Кировский район, Академическая, 21"""""""	Россия, Свердловская область, Екатеринбург, улица Академическая, 21	0101000020E61000000ABC934F8F534E40DC0F7860006D4C40
87303	6	56	\N	49870	17953	\N	56.7029219161547	городской округ Дегтярск, Уральских Танкистов, 12		0101000020E610000039471D1D570B4E40C8D11C59F9594C40
87309	6	56	\N	49870	19813	\N	56.702046000000003	город Дегтярск, Пролетарская, 40А		0101000020E6100000AB05F698480D4E40D124B1A4DC594C40
87307	6	56	\N	49870	18668	\N	56.707832000000003	городской округ Дегтярск, Почтовая, 3		0101000020E61000007F4B00FE290D4E40F9872D3D9A5A4C40
87294	6	56	\N	61129	78250	\N	59.934178173105501	Волчанский городской округ, Советская, 3		0101000020E610000028F38FBE490B4E4044520B2593F74D40
87291	6	56	\N	61129	77310	\N	59.936488158413702	Волчанский городской округ, Молодежная, 68	Россия, Свердловская область, городской округ Карпинск, Волчанск	0101000020E6100000041BD7BFEB094E40588CBAD6DEF74D40
87297	6	56	\N	61129	78070	\N	59.936325466164298	Волчанский городской округ, Карпинского, 12	Россия, Свердловская область, городской округ Карпинск, Волчанск	0101000020E6100000AF7C96E7C1094E40AEB6627FD9F74D40
85966	6	56	\N	50206	20261	\N	58.865934000000003	Верхотурский уезд, город Верхотурье, Сенянского, 12		0101000020E610000006DA1D520C664E404B3FE1ECD66E4D40
87279	6	56	\N	50137	20046	\N	58.360610999999999	город Верхняя Тура, Первомайская, 28		0101000020E61000003AB187F6B1EA4D40F7C95180282E4D40
87285	6	56	\N	50137	20175	\N	58.357929528268997	город Верхняя Тура, Машиностроителей, 16	Россия, Свердловская область, городской округ Кушва, Верхняя Тура	0101000020E61000004F92AE997CEB4D40EF2076A6D02D4D40
85922	6	56	\N	49904	18247	\N	58.051091404589599	Верхнесалдинский городской округ, Энгельса, 79	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E6100000CA89761552484E405A0F5F268A064D40
85908	6	56	\N	49904	20358	\N	58.048032720740501	г.Верхняя Салда, Строителей, 1		0101000020E610000061FE0A992B474E407B1002F225064D40
85927	6	56	\N	49904	20360	\N	58.046147500816701	г.Верхняя Салда, Пушкина, 23	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E61000004A5E9D6340464E404E637B2DE8054D40
87242	6	56	\N	11998	\N	\N	56.965789999999998	"""""""город Верхняя Пышма, профилакторий """"""""Селен"""""""", клубстоловая"""""""		0101000020E610000033880FECF8494E40E466B8019F7B4C40
86469	6	56	\N	11998	\N	\N	56.968719	с. Коптяки, Здание клуба		0101000020E6100000F9DC09F65F374E40C501F4FBFE7B4C40
87221	6	56	\N	11998	18259	\N	56.973619233666703	"""""""г. Верхняя Пышма, Щорса, 1А, (МУК """"""""Агат"""""""")"""""""	Россия, Свердловская область, Верхняя Пышма	0101000020E6100000ECC1A4F8F8484E40D2E1218C9F7C4C40
87236	6	56	\N	11998	19252	\N	56.978829702378597	г. Верхняя Пышма, Чкалова, 87, (Досуговый центр)	Россия, Свердловская область, Верхняя Пышма	0101000020E61000008C0FB3976D4B4E40FE2B2B4D4A7D4C40
87223	6	56	\N	11998	19223	\N	56.981554660106497	г. Верхняя Пышма, Чистова, 9, (Школа №33)	Россия, Свердловская область, Верхняя Пышма	0101000020E61000000C789961A3484E40D61C2098A37D4C40
87241	6	56	\N	11998	18961	\N	56.965789999999998	"""""""г. Верхняя Пышма, Советская, 9, (Магазин """"""""Продукты"""""""")"""""""		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87238	6	56	\N	11998	19257	\N	56.965789999999998	"""""""г. Верхняя Пышма, Петрова, 59, (ТВЦ """"""""Восток"""""""")"""""""		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87237	6	56	\N	11998	19257	\N	56.967110288502703	г. Верхняя Пышма, Петрова, 43, (Школа №25)	Россия, Свердловская область, Верхняя Пышма	0101000020E61000004AB89047704D4E4039D1AE42CA7B4C40
87259	6	56	\N	11998	18640	\N	56.978991723487802	г. Верхняя Пышма, Огнеупорщиков, 10А, (Колледж им. И.И.Ползунова)	Россия, Свердловская область, Верхняя Пышма	0101000020E61000001B4AED45B4454E40D7851F9C4F7D4C40
87231	6	56	\N	11998	18640	\N	56.965789999999998	г. Верхняя Пышма, Огнеупорщиков, 10А, (Колледж им. И.И. Ползунова)		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87244	6	56	\N	11998	19979	\N	56.978318007894998	г. Верхняя Пышма, Менделеева, 7, (Дом детского творчества)	Россия, Свердловская область, Верхняя Пышма	0101000020E61000001CB4571F0F494E40488B3386397D4C40
87230	6	56	\N	11998	18283	\N	56.965789999999998	г. Верхняя Пышма, Машиностроителей, 6, (Школа №3)		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87232	6	56	\N	11998	18648	\N	56.965789999999998	"""""""г. Верхняя Пышма, Лесная, 1, (Техникум """"""""Уралмашевец"""""""")"""""""		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87234	6	56	\N	11998	18652	\N	56.965789999999998	г. Верхняя Пышма, Ленина, 47, (Школа №22)		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87229	6	56	\N	11998	18652	\N	56.965789999999998	г. Верхняя Пышма, Ленина, 48		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87218	6	56	\N	11998	18652	\N	56.965789999999998	"""""""г. Верхняя Пышма, Ленина, 12, (АУ ДК """"""""Металлург"""""""")"""""""		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87226	6	56	\N	11998	17757	\N	56.978367441078802	"""""""г. Верхняя Пышма, Кривоусова, 53, (Техникум """"""""Юность"""""""")"""""""	Россия, Свердловская область, Верхняя Пышма	0101000020E61000006D73637AC2484E40293E3E213B7D4C40
87225	6	56	\N	11998	17757	\N	56.965789999999998	г. Верхняя Пышма, Кривоусова, 42, (Школа №2)		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87224	6	56	\N	11998	17757	\N	56.981206111131797	г. Верхняя Пышма, Кривоусова, 38	Россия, Свердловская область, Верхняя Пышма	0101000020E6100000C39FE1CD1A484E40CA518028987D4C40
87235	6	56	\N	11998	20191	\N	56.969908994186	г. Верхняя Пышма, Красноармейская, 6, (Школа №1)	Россия, Свердловская область, Верхняя Пышма	0101000020E6100000A25D85949F4A4E404C8C65FA257C4C40
87220	6	56	\N	11998	18243	\N	56.965789999999998	г. Верхняя Пышма, Калинина, 37Б, (Школа №4)		0101000020E610000033880FECF8494E40E466B8019F7B4C40
87247	6	56	\N	11998	20207	\N	56.977716999999998	п. Исеть, Дружбы, 1А, (Здание Администрации)		0101000020E61000000EF5BBB0352F4E4022DFA5D4257D4C40
87263	6	56	\N	61314	78533	\N	57.3320415819489	город Верхний Тагил, р.п. Белоречка, Горького, № 4		0101000020E6100000A0A4C00298044E4000732D5A80AA4C40
85890	6	56	\N	10875	\N	\N	56.775398000000003	Богданович	Россия, Свердловская область, Богданович	0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85886	6	56	\N	10875	19113	\N	56.775398000000003	город Богданович, Школьная, 5		0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85885	6	56	\N	10875	19113	\N	56.775398000000003	город Богданович, Школьная, 2		0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85884	6	56	\N	10875	19037	\N	56.775398000000003	город Богданович, Степана Разина, 43		0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85881	6	56	\N	10875	20343	\N	56.769631476085401	город Богданович, Спортивная, 16А	Россия, Свердловская область, Богданович	0101000020E6100000641F645930074F406F7EC34483624C40
85877	6	56	\N	10875	20338	\N	56.775398000000003	город Богданович, Советская, 2		0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85882	6	56	\N	10875	18203	\N	56.770119803254303	город Богданович, Рокицанская, 6А	Россия, Свердловская область, Богданович	0101000020E61000001CCF6740BD034F406DFFCA4A93624C40
85889	6	56	\N	10875	18893	\N	56.775398000000003	город Богданович, Пролетарская, 37		0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85888	6	56	\N	10875	18218	\N	56.775398000000003	город Богданович, Пищевиков, 1		0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85883	6	56	\N	10875	20149	\N	56.775398000000003	город Богданович, Некрасова, 1		0101000020E6100000D74D29AF95064F4021B1DD3D40634C40
85879	6	56	\N	10875	20405	\N	56.775189012121203	город Богданович, Кунавина, 31	Россия, Свердловская область, Богданович	0101000020E61000007F85CC9541074F40069CA56439634C40
85880	6	56	\N	10875	20313	\N	56.771513160932599	город Богданович, Декабристов, 2	Россия, Свердловская область, Богданович	0101000020E61000007573F1B73D074F402CB81FF0C0624C40
85878	6	56	\N	10875	19175	\N	56.773594588667699	город Богданович, Гагарина, 32	Россия, Свердловская область, Богданович	0101000020E6100000BD546CCCEB064F40B0AC342905634C40
86774	6	56	\N	50100	19877	\N	56.678290715038003	поселок Бобровский, Краснодеревцев, 37	Россия, Свердловская область, Сысертский район	0101000020E6100000FB95CE87677F4E40E8154F3DD2564C40
87149	6	56	\N	888	2391	\N	56.908983999999997	Березовский городской округ, Театральная, 7	Россия, Свердловская область, Березовский, улица Театральная, 7а	0101000020E61000008176871403684E402B4B749659744C40
87172	6	56	\N	888	999	\N	56.909813999999997	город Березовский, Ленина, 22А	Россия, Свердловская область, Березовский, улица Ленина, 22	0101000020E61000001684F23E8E644E40B2B8FFC874744C40
87216	6	56	\N	888	19134	\N	56.912750127932398	город Березовский, Брусницына, 4	Россия, Свердловская область, Березовский, улица Брусницина	0101000020E610000096EA025E66684E4046B6F3FDD4744C40
87207	6	56	\N	888	18132	\N	56.897511999999999	город Березовский, пос. Кедровка, Школьная, 3		0101000020E61000008F519E7939644E403FE257ACE1724C40
87154	6	56	\N	888	77988	\N	56.905729999999998	г.Березовский, Шиловская, 3		0101000020E6100000454948A46D684E40C780ECF5EE734C40
87174	6	56	\N	888	77700	\N	56.914507	город Березовский, Транспортников, 46		0101000020E6100000D53DB2B96A624E40467BBC900E754C40
87156	6	56	\N	888	77776	\N	56.909725999999999	город Березовский, Театральная, 28		0101000020E6100000094FE8F527694E401329CDE671744C40
87153	6	56	\N	888	77776	\N	56.910080000000001	город Березовский, Театральная, 13		0101000020E6100000E816BA1281684E40315F5E807D744C40
87151	6	56	\N	888	77776	\N	56.909348000000001	город Березовский, Театральная, 11		0101000020E610000006BCCCB051684E406D57E88365744C40
87204	6	56	\N	888	78053	\N	56.907696000000001	город Березовский, пос. Ключевск, Строителей, 1		0101000020E61000009F211CB3EC674E40E25AED612F744C40
87169	6	56	\N	888	77955	\N	56.914768000000002	город Березовский, Спортивная, 7 (СОК Лидер)		0101000020E6100000CB9E0436E7684E40B3B6291E17754C40
87187	6	56	\N	888	77993	\N	56.898589000000001	город Березовский, Смирнова, 1		0101000020E61000004B75012F33604E40CEC5DFF604734C40
87185	6	56	\N	888	77993	\N	56.897875999999997	город Березовский, Смирнова, 3А		0101000020E6100000FBCE2F4AD05F4E4080EECB99ED724C40
87176	6	56	\N	888	77702	\N	56.922162	город Березовский, Свободы, 108а		0101000020E61000003E5DDDB1D8644E4096CE876709764C40
86147	6	56	\N	888	78547	\N	56.900373000000002	Каменский район, Пионерская, 17		0101000020E6100000187C9A9317674E40C899266C3F734C40
87214	6	56	\N	888	20159	\N	56.895865000000001	город Березовский, пос. Становая, Первого Мая, 17а	Россия, Свердловская область, городской округ Березовский, поселок Становая	0101000020E61000001C78B5DC997F4E40C6504EB4AB724C40
87164	6	56	\N	888	18553	\N	56.897511999999999	город Березовский, п.Шиловка, Парковая, 10		0101000020E61000008F519E7939644E403FE257ACE1724C40
87255	6	56	\N	888	78556	\N	56.914211999999999	п. Зеленый Бор, Октябрьская, 26, (Фельдшерский пункт)		0101000020E6100000371B2B31CF664E402DCE18E604754C40
87163	6	56	\N	888	78001	\N	56.902197000000001	город Березовский, Мира, 5		0101000020E6100000342C465D6B694E4050C6F8307B734C40
87180	6	56	\N	888	77302	\N	56.896144405038697	город Березовский, М.Горького, 3а	Россия, Свердловская область, Березовский, улица Толбухина, 3а	0101000020E610000070D05E7D3C604E40D940BAD8B4724C40
86495	6	56	\N	888	78558	\N	56.894705000000002	д. Луговая, Школьная, 1		0101000020E610000061191BBAD95F4E40AA4885B185724C40
87166	6	56	\N	888	78475	\N	56.910645000000002	город Березовский, Ленина, 48		0101000020E6100000063065E080664E400AA2EE0390744C40
87213	6	56	\N	888	78600	\N	56.868617070510702	Свердловская область, город Березовский, пос. Сарапулка, Ленина, 58	Россия, Свердловская область, городской округ Березовский, поселок Сарапулка	0101000020E6100000B77F65A549874E40F4DF83D72E6F4C40
87193	6	56	\N	888	18874	\N	56.897511999999999	город Березовский, пос. Островное, Крылосова, 20		0101000020E61000008F519E7939644E403FE257ACE1724C40
95006	6	56	\N	888	77963	\N	56.907755000000002	город Березовский, Красных Героев, 7		0101000020E61000006876DD5B91664E40E7E3DA5031744C40
87171	6	56	\N	888	77963	\N	56.909765	город Березовский, Красных Героев, 1а		0101000020E61000007A1C06F357664E40D105F52D73744C40
87160	6	56	\N	888	77999	\N	56.904122999999998	город Березовский, Косых, 3		0101000020E6100000A702EE79FE684E40DC476E4DBA734C40
87190	6	56	\N	888	78014	\N	56.895698000000003	город Березовский, пос. Монетный, М.Горького, 2а		0101000020E6100000CF87670932604E40DB8B683BA6724C40
87189	6	56	\N	888	78014	\N	56.895698000000003	город Березовский, пос. Монетный, М.Горького, 2А		0101000020E6100000CF87670932604E40DB8B683BA6724C40
87211	6	56	\N	888	18254	\N	56.933975193022803	город Березовский, пос.Старопышминск, Волкова, 1	Россия, Свердловская область, городской округ Березовский, поселок Старопышминск	0101000020E6100000C00644882B734E400B24287E8C774C40
87178	6	56	\N	888	2856	\N	56.899346000000001	"""""""город Березовский, Березовский тракт  (Автоцентр """"""""Ландо""""""""), 9"""""""	Россия, Свердловская область, Березовский, Березовский тракт, 9	0101000020E610000041295AB917624E40EBE40CC51D734C40
87182	6	56	\N	888	77981	\N	56.902678000000002	город Березовский, Ак. Королева, 1		0101000020E61000003A234A7B835F4E40CB68E4F38A734C40
85854	6	56	\N	9344	\N	\N	56.751809999999999	"""""""р.п.Белоярский, санаторий """"""""Кристалл"""""""", санаторий """"""""Кристалл"""""""""""""""		0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85851	6	56	\N	9344	20116	\N	56.751809999999999	р.п.Белоярский, Химиков, 12		0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85852	6	56	\N	9344	18568	\N	56.751809999999999	р.п.Белоярский, Свердлова, 1		0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85861	6	56	\N	9344	18867	\N	56.751809999999999	р.п.Белоярский, Привокзальная, 1А		0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85848	6	56	\N	9344	18171	\N	56.751809999999999	р.п.Белоярский, переулок Светлый, 2		0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85850	6	56	\N	9344	77079	\N	56.751809999999999	р.п.Белоярский, Молодежная, 42 А		0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85846	6	56	\N	9344	18288	\N	56.751809999999999	р.п.Белоярский, Милицейская, 25		0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85847	6	56	\N	9344	19886	\N	56.751809999999999	р.п.Белоярский, Ленина, 257	Россия, Свердловская область, поселок Белоярский	0101000020E61000009B75C6F7C5B14E402367614F3B604C40
85849	6	56	\N	9344	20228	\N	56.754318484577702	р.п.Белоярский, Горем35		0101000020E61000007B849A2155B44E405E64027E8D604C40
85831	6	56	\N	49890	18127	\N	57.398654000000001	с.Байкалово, Свердлова, 3		0101000020E61000008B8A389D64E14F40B535221807B34C40
87147	6	56	\N	6503	\N	\N	57.019711999999998	город Асбест, поселок Лесозавод, медпункт		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87124	6	56	\N	6503	19818	\N	57.006903085916697	город Асбест, 101 квартал, Школьная, 30	Россия, Свердловская область, Асбест	0101000020E610000098F90E7EE2BA4E40459F8F32E2804C40
87128	6	56	\N	6503	18110	\N	57.011152798254201	город Асбест, Чапаева, 28	Россия, Свердловская область, Асбест	0101000020E61000001D9430D3F6BB4E404B2025766D814C40
87125	6	56	\N	6503	18110	\N	57.019105885470402	город Асбест, Чапаева, 2	Россия, Свердловская область, Асбест	0101000020E610000079E6E5B0FBBC4E402594BE1072824C40
87126	6	56	\N	6503	19322	\N	57.019711999999998	город Асбест, Физкультурников, 38		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
89267	6	56	\N	6503	77420	\N	57.115462931108297	Малышевский городской округ, Тимирязева, 1	Россия, Свердловская область, городской округ Асбест, поселок Малышева	0101000020E6100000B2A19BFD81B24E40F372D87DC78E4C40
87130	6	56	\N	6503	18703	\N	57.019711999999998	город Асбест, Советская, 2		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87123	6	56	\N	6503	18703	\N	57.019711999999998	город Асбест,поселок Белокаменный, Советская ул, 14		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87103	6	56	\N	6503	18703	\N	57.007003790621503	город Асбест, Советская, 10	Россия, Свердловская область, Асбест	0101000020E6100000096B63EC84BB4E407978CF81E5804C40
87146	6	56	\N	6503	20293	\N	57.019711999999998	город Асбест, Серова, 2		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
89265	6	56	\N	6503	20333	\N	57.075140199135298	Малышевский городской округ, поселок Изумруд, 4 Садовая, 19		0101000020E6100000E8BB5B59A2B34E408B4F01309E894C40
87142	6	56	\N	6503	18478	\N	57.019711999999998	город Асбест, Победы, 24		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87135	6	56	\N	6503	18727	\N	57.008661968396197	город Асбест, Плеханова, 3/2	Россия, Свердловская область, Асбест	0101000020E610000071AB2006BAB84E40E65B1FD61B814C40
87145	6	56	\N	6503	19082	\N	57.019711999999998	город Асбест, Папанина, 52		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87144	6	56	\N	6503	18482	\N	57.019711999999998	город Асбест, Осипенко, 32		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87136	6	56	\N	6503	18066	\N	57.019711999999998	город Асбест, поселок Черемша, Октябрьской революции, 16		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87134	6	56	\N	6503	19338	\N	57.019711999999998	город Асбест, Мира, 4/3		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87133	6	56	\N	6503	19338	\N	57.019711999999998	город Асбест, Мира, 10		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87127	6	56	\N	6503	18029	\N	57.015922257455699	город Асбест, Лесная, 36	Россия, Свердловская область, Асбест	0101000020E61000009109F83592BC4E40BAA46ABB09824C40
87141	6	56	\N	6503	18951	\N	57.019711999999998	город Асбест, Ленинградская, 10		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87137	6	56	\N	6503	18951	\N	57.012171251934902	город Асбест, Ленинградская, 29	Россия, Свердловская область, Асбест	0101000020E61000008200193A76BA4E40D57ABFD18E814C40
87140	6	56	\N	6503	19839	\N	57.019711999999998	город Асбест, Ленина, 14		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87138	6	56	\N	6503	19839	\N	57.019711999999998	город Асбест, Ленина, 26/3		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87132	6	56	\N	6503	19065	\N	57.019644908649099	город Асбест, Ладыженского, 17	Россия, Свердловская область, Асбест	0101000020E61000005036E50AEFBC4E40D44334BA83824C40
87131	6	56	\N	6503	19065	\N	57.019711999999998	город Асбест, Ладыженского, 7		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87129	6	56	\N	6503	20222	\N	57.001922241291098	город Асбест, Калинина, 40	Россия, Свердловская область, Асбест	0101000020E61000002B4CDF6B08BC4E404B92E7FA3E804C40
87139	6	56	\N	6503	18999	\N	57.019711999999998	город Асбест, Войкова, 71		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
87143	6	56	\N	6503	20081	\N	57.019711999999998	город Асбест, 8 Марта, 16		0101000020E610000063096B63ECBC4E405CAB3DEC85824C40
85642	6	56	\N	49978	20300	\N	57.3397891157936	г.Артемовский, пер. Заводской, 2А		0101000020E610000044A4A65D4CED4E403145B9347EAB4C40
81363	6	56	\N	49978	78412	\N	57.325383728736902	г.Артемовский, Пригородная, 2а	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E6100000A5828AAA5FF34E402252D32EA6A94C40
85655	6	56	\N	49978	77466	\N	57.318697455322003	Артемовский городской округ, Котовского, 4	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E6100000A12E52280BF54E40AA2A3410CBA84C40
87084	6	56	\N	49843	19010	\N	57.853907819462101	муниципальное образование город Алапаевск, ул.Николая Островского, д.8/3	Россия, Свердловская область, Алапаевск	0101000020E6100000806264C91CD94E4079E57ADB4CED4C40
87069	6	56	\N	49843	77456	\N	57.850924802706501	муниципальное образование город Алапаевск, ул.Фрунзе, д.46	Россия, Свердловская область, Алапаевск	0101000020E610000079AD84EE92D84E40A52C431CEBEC4C40
87067	6	56	\N	49843	77456	\N	57.851931502519598	муниципальное образование город Алапаевск, ул.Фрунзе, д.43	Россия, Свердловская область, Алапаевск	0101000020E6100000FFD0CC936BD84E403B35971B0CED4C40
87057	6	56	\N	49843	77295	\N	57.863323544793602	муниципальное образование город Алапаевск, ул.Урицкого, д.147	Россия, Свердловская область, Алапаевск	0101000020E61000004F07B29E5AD94E400BED9C6681EE4C40
87086	6	56	\N	49843	78440	\N	57.845618999999999	муниципальное образование город Алапаевск, ул.Советская, д.105	Россия, Свердловская область, Алапаевск	0101000020E61000000247020D36D74E4028F04E3E3DEC4C40
87058	6	56	\N	49843	77454	\N	57.851107841137498	муниципальное образование город Алапаевск, ул.Розы Люксембург, д.58	Россия, Свердловская область, Алапаевск	0101000020E61000002315C61682D84E4097AE601BF1EC4C40
87071	6	56	\N	49843	77297	\N	57.854293704221597	муниципальное образование город Алапаевск, ул.Павлова, д.41	Россия, Свердловская область, Алапаевск	0101000020E6100000C4EA8F300CDA4E40A3957B8159ED4C40
87062	6	56	\N	49843	77297	\N	57.851290878634501	муниципальное образование город Алапаевск, ул.Павлова, д.12	Россия, Свердловская область, Алапаевск	0101000020E610000026E5EE737CD84E4088307E1AF7EC4C40
87093	6	56	\N	49843	78424	\N	57.763723250726898	муниципальное образование город Алапаевск, поселок Зыряновский, ул.Октябрьская, д.8	Россия, Свердловская область, городской округ Алапаевск, поселок Зыряновский	0101000020E6100000689604A8A9D14E40FC19DEACC1E14C40
87082	6	56	\N	49843	78593	\N	57.845618999999999	Свердловская область, муниципальное образование город Алапаевск, ул.Мира, д.4	Россия, Свердловская область, Алапаевск	0101000020E61000000247020D36D74E4028F04E3E3DEC4C40
87081	6	56	\N	49843	77948	\N	57.85037568181	муниципальное образование город Алапаевск, ул.Мира, д.7	Россия, Свердловская область, Алапаевск	0101000020E61000002315C61682D84E40D2A6EA1ED9EC4C40
87064	6	56	\N	49843	77448	\N	57.845618999999999	муниципальное образование город Алапаевск, ул.Ленина, д.10	Россия, Свердловская область, Алапаевск	0101000020E61000000247020D36D74E4028F04E3E3DEC4C40
87061	6	56	\N	49843	77448	\N	57.851290878634501	муниципальное образование город Алапаевск, ул.Ленина, д.35	Россия, Свердловская область, Алапаевск	0101000020E6100000C7D5C8AEB4D84E4088307E1AF7EC4C40
87055	6	56	\N	49843	77448	\N	57.853212715968397	муниципальное образование город Алапаевск, ул.Ленина, д.77	Россия, Свердловская область, Алапаевск	0101000020E61000004FC939B187D84E40D2C2651536ED4C40
87076	6	56	\N	49843	77460	\N	57.850467202543101	муниципальное образование город Алапаевск, ул.Краснофлотцев, д.73	Россия, Свердловская область, Алапаевск	0101000020E61000001558005306D84E40E3A9471ADCEC4C40
87090	6	56	\N	49843	17967	\N	57.835961291769699	муниципальное образование город Алапаевск, ул.Клубная, д.22	Россия, Свердловская область, Алапаевск	0101000020E6100000C3D4963AC8DB4E40A0DD21C500EB4C40
87089	6	56	\N	49843	17967	\N	57.8347767455083	муниципальное образование город Алапаевск, ул.Клубная, д.24		0101000020E610000018B14F00C5DC4E40FC3905F9D9EA4C40
87079	6	56	\N	49843	77060	\N	57.845618999999999	муниципальное образование город Алапаевск, ул.Говырина, д.3		0101000020E61000000247020D36D74E4028F04E3E3DEC4C40
87073	6	56	\N	49843	17998	\N	57.845618999999999	муниципальное образование город Алапаевск, ул.Братьев Смольниковых, д.134		0101000020E61000000247020D36D74E4028F04E3E3DEC4C40
87074	6	56	\N	49843	77459	\N	57.851565433128997	муниципальное образование город Алапаевск, ул.3 Интернационала, д.10	Россия, Свердловская область, Алапаевск	0101000020E6100000FC00A43671D84E4089B5F81400ED4C40
89078	6	56	6986	49842	17813	\N	60.346203224857099	г.Североуральск, поселок Черемухово, Калинина, 38	Россия, Свердловская область, городской округ Североуральск, поселок Черёмухово	0101000020E6100000D97BF1457BFE4D4078634161502C4E40
89077	6	56	6986	49842	17813	\N	60.3452036257085	г.Североуральск, поселок Черемухово, Калинина, 19	Россия, Свердловская область, городской округ Североуральск, поселок Черёмухово	0101000020E6100000151C5E1091FE4D40653909A52F2C4E40
89080	6	56	6986	49912	18295	\N	60.404363098202701	Свердловская область, г.Североуральск, поселок Сосьва, 40 лет Октября, 21	Россия, Свердловская область, городской округ Североуральск, поселок Сосьва (Долгая Паберега)	0101000020E61000003E95D39E92F34D40315BB22AC2334E40
89075	6	56	6986	49967	18927	\N	60.241726999999997	г.Североуральск, поселок Калья, Ленина, 33	Россия, Свердловская область, городской округ Североуральск, поселок Калья	0101000020E61000006092CA1473FE4D40B4C70BE9F01E4E40
86608	6	56	1336	47936	20097	\N	56.615689821664901	с.Мариинск, Мичурина, 1	Россия, Свердловская область, городской округ Ревда, поселок Мариинск	0101000020E6100000B9895A9A5BEF4D40B43C0FEECE4E4C40
87298	6	56	1336	15768	18773	\N	56.702046000000003	город Дегтярск, Советская, 33		0101000020E6100000AB05F698480D4E40D124B1A4DC594C40
87300	6	56	1336	15768	19836	\N	56.702046000000003	город Дегтярск, Площадь Ленина, 1А		0101000020E6100000AB05F698480D4E40D124B1A4DC594C40
87305	6	56	1336	15768	77468	\N	56.702345924954599	городской округ Дегтярск, Культуры, 29	Россия, Свердловская область, городской округ Ревда, Дегтярск	0101000020E6100000800EF3E5050E4E40FB3C4679E6594C40
89046	6	56	7000	49940	18589	\N	56.298539061338701	город Полевской, село Полдневая, М. Горького, 10	Россия, Свердловская область, городской округ Полевской, поселок Полдневая	0101000020E6100000A6F27684D3244E404FCAA48636264C40
89041	6	56	7000	49964	18869	\N	56.479764000000003	город Полевской, село Косой Брод, Советская, 25	Россия, Свердловская область, городской округ Полевской, поселок Косой Брод	0101000020E610000077853E58C62A4E402AE620E8683D4C40
89035	6	56	7000	50129	20019	\N	56.487265000000001	город Полевской, поселок Зюзельский, Ленина, 4	Россия, Свердловская область, городской округ Полевской, поселок Зюзельский	0101000020E61000003FC571E0D5104E4023BE13B35E3E4C40
88978	6	56	6987	49975	19015	\N	56.848408502838701	город Первоуральск, д. Старые Решеты, Школьная, 1	Россия, Свердловская область, городской округ Первоуральск, поселок Старые Решёты	0101000020E6100000A7CCCD37A21F4E40E75086AA986C4C40
88968	6	56	6987	49851	19009	\N	56.990343821171898	город Первоуральск, п. Новоуткинск, Культуры, 11	Россия, Свердловская область, городской округ Первоуральск, поселок Новоуткинск	0101000020E6100000062D246074C74D4019E59997C37E4C40
88972	6	56	6987	49915	18321	\N	56.8488772546077	город Первоуральск, с. Новоалексеевское, Буденого, 38	Россия, Свердловская область, городской округ Первоуральск, поселок Новоалексеевское	0101000020E6100000A2ED98BA2B114E40CEA96400A86C4C40
88958	6	56	6987	49948	18693	\N	56.946342547155503	город Первоуральск, д. Крылосово, КИЗ, 13	Россия, Свердловская область, городской округ Первоуральск, поселок Крылосово	0101000020E610000035EF384547D84D4036E675C421794C40
88956	6	56	6987	49847	17829	\N	56.930281999999998	город Первоуральск, п. Битимка, Заречная, 8	Россия, Свердловская область, городской округ Первоуральск, поселок Битимка	0101000020E6100000F6083543AAE04D405B07077B13774C40
88952	6	56	6987	49957	19300	\N	56.959959034849497	город Первоуральск, п. Билимбай, Лермонтова, 5а	Россия, Свердловская область, городской округ Первоуральск, поселок Билимбай	0101000020E6100000C93EC8B260E84D401C40BFEFDF7A4C40
88946	6	56	6987	49957	19951	\N	56.958835999999998	город Первоуральск, п. Билимбай, Ленина, 84	Россия, Свердловская область, городской округ Первоуральск, поселок Билимбай	0101000020E610000078465B9544E84D401D1D5723BB7A4C40
88950	6	56	6987	49957	18796	\N	56.9590212071396	город Первоуральск, п. Билимбай, Красноармейская, 62	Россия, Свердловская область, городской округ Первоуральск, поселок Билимбай	0101000020E6100000B587BD50C0E84D40AF963B33C17A4C40
88566	6	56	728	49914	18320	\N	58.653101999999997	город Лесной, п. Таежный, Культуры, 6	Россия, Свердловская область, городской округ Нижняя Тура, поселок Таёжный	0101000020E61000008C84B69C4BEB4D40E179A9D898534D40
86421	6	56	728	5314	18883	\N	58.665174	деревня Новая Тура, Советская, 38		0101000020E61000004CA60A46250D4E402313F06B24554D40
88554	6	56	728	11234	17870	\N	58.6417	город Лесной, Юбилейная, 6		0101000020E61000004D1421753BE54D40EEEBC03923524D40
88550	6	56	728	11234	17870	\N	58.6270667492198	город Лесной, Юбилейная, 2	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E610000053D0ED258DE34D404EB340BB43504D40
88553	6	56	728	11234	18356	\N	58.6417	город Лесной, Мира, 30		0101000020E61000004D1421753BE54D40EEEBC03923524D40
88543	6	56	728	11234	19187	\N	58.6417579634372	город Лесной, МаминаСибиряка, 47	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E61000005018946934E54D4023F94A2025524D40
88541	6	56	728	11234	19187	\N	58.636656467379801	город Лесной, МаминаСибиряка, 37		0101000020E610000053CBD6FA22E34D40AE669DF17D514D40
88556	6	56	728	11234	17780	\N	58.630840847331399	город Лесной, Ленина, 94	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E610000050A73CBA11E24D40EBFCDB65BF504D40
88549	6	56	728	11234	17780	\N	58.6417	город Лесной, Ленина, 69		0101000020E61000004D1421753BE54D40EEEBC03923524D40
88533	6	56	728	11234	17780	\N	58.635452473324001	город Лесной, Ленина, 22	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E6100000DA1F28B7EDE54D40C216BB7D56514D40
88523	6	56	728	11234	17780	\N	58.637315343564303	город Лесной, Ленина, 10	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E6100000897B2C7DE8E44D400820B58993514D40
88546	6	56	728	11234	18751	\N	58.630764526640597	город Лесной, Кирова, 58	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E6100000D55B035B25E44D40103B53E8BC504D40
88530	6	56	728	11234	77099	\N	58.641790299924402	город Лесной, Дзержинского, 1а	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E6100000D6AD9E93DEE54D402E73BA2C26524D40
88560	6	56	728	11234	18296	\N	58.6417	город Лесной, Горького, 11		0101000020E61000004D1421753BE54D40EEEBC03923524D40
88536	6	56	728	11234	18201	\N	58.6417	город Лесной, Белинского, 49а		0101000020E61000004D1421753BE54D40EEEBC03923524D40
88527	6	56	728	11234	18201	\N	58.631821547726901	город Лесной, Белинского, 18	Россия, Свердловская область, городской округ Нижняя Тура, Лесной	0101000020E6100000C18EFF0241E64D405872158BDF504D40
88559	6	56	728	11234	18352	\N	58.6417	город Лесной, Бажова, 1а		0101000020E61000004D1421753BE54D40EEEBC03923524D40
86415	6	56	728	61255	77800	\N	58.791428915337001	поселок Ис, Ленина, 83	Россия, Свердловская область, городской округ Нижняя Тура, поселок Ис	0101000020E610000072FA7ABE66DB4D40910DA48B4D654D40
86416	6	56	728	61255	78473	\N	58.796950307567599	поселок Ис, Ленина, 92	Россия, Свердловская область, городской округ Нижняя Тура, поселок Ис	0101000020E61000008FFAEB1516DC4D400B46257502664D40
86420	6	56	728	5221	18882	\N	58.559102000000003	деревня Большая Именная, Советская, 12		0101000020E6100000350708E6E8EF4D40699082A790474D40
88565	6	56	728	49989	19283	\N	58.694385881574902	город Лесной, п. Елкино, Клубная, 16	Россия, Свердловская область, городской округ Нижняя Тура, поселок Ёлкино	0101000020E61000006EFC89CA86E94D406F66F4A3E1584D40
87280	6	56	1359	14675	9663	\N	58.360610999999999	город Верхняя Тура, Машиностроителей, 4		0101000020E61000003AB187F6B1EA4D40F7C95180282E4D40
87286	6	56	1359	14675	18716	\N	58.360568437730898	город Верхняя Тура, Гробова, 1а	Россия, Свердловская область, городской округ Кушва, Верхняя Тура	0101000020E610000078D0ECBAB7EA4D40F8FD9B17272E4D40
88516	6	56	1359	49897	20134	\N	58.169740138343997	город Кушва, .пос.Баранчинский, Победы, 9	Россия, Свердловская область, городской округ Кушва, поселок Баранчинский	0101000020E6100000B5334C6DA9D94D405969520ABA154D40
88514	6	56	1359	49897	19145	\N	58.170346000000002	город Кушва, .пос.Баранчинский, Ленина, 1	Россия, Свердловская область, городской округ Кушва, поселок Баранчинский	0101000020E6100000902FA182C3D94D409180D1E5CD154D40
88518	6	56	1359	49897	18192	\N	58.166173598254296	город Кушва, .пос.Баранчинский, Коммуны, 18	Россия, Свердловская область, городской округ Кушва, поселок Баранчинский	0101000020E610000067F1626188DA4D4006B98B3045154D40
86225	6	56	6965	49267	18842	\N	56.636164000000001	поселок Березовая Роща, Загородная, 4		0101000020E61000009BAE27BA2EDE4C403F726BD26D514C40
88438	6	56	6994	49889	18123	\N	58.371856896925699	город Красноуральск, пос.Краснодольск, Матросова, клуб поселка Краснодольск	Россия, Свердловская область, городской округ Красноуральск, поселок Краснодольский	0101000020E6100000ABB019E082FA4D40F3E49A02992F4D40
88439	6	56	6994	49981	19874	\N	58.405625999999998	город Красноуральск,пос.Дачный, Советская, клуб поселка Дачный		0101000020E61000009F1D705D31F74D402234828DEB334D40
88344	6	56	383	2105	18616	\N	59.699207999999999	городской округ Краснотурьинск, поселок Рудничный, Пушкина, 22		0101000020E6100000B7291E17D5244E40008DD2A57FD94D40
88342	6	56	383	2105	17893	\N	59.699207999999999	городской округ Краснотурьинск, поселок Рудничный, Первомайская, 1		0101000020E6100000B7291E17D5244E40008DD2A57FD94D40
88412	6	56	383	6077	\N	\N	59.850427000000003	Свердловская область, городской округ Краснотурьинск, пос. Прибрежный, 3		0101000020E6100000A6B4FE96001E4E405551BCCADAEC4D40
88411	6	56	383	49900	18547	\N	59.757801729460297	городской округ Краснотурьинск, Краснотурьинская, 2	Россия, Свердловская область, городской округ Краснотурьинск	0101000020E6100000029D499BAA134E40F46BEBA7FFE04D40
88330	6	56	1323	49881	18014	\N	57.344575583049199	город Кировград, р.п. НейвоРудянка, Ржанникова, 10	Россия, Свердловская область, городской округ Кировград, поселок Нейво-Рудянка	0101000020E6100000E7FEEA71DF104E40467EFD101BAC4C40
88333	6	56	1323	49974	19001	\N	57.589109000000001	город Кировград, р.п. Левиха, Малышева, 18	Россия, Свердловская область, городской округ Кировград, поселок Лёвиха	0101000020E61000002B137EA99FF34D40BF6378EC67CB4C40
88336	6	56	1323	49987	19189	\N	57.501671999999999	город Кировград, р.п. Карпушиха, Дарвина, 2Б	Россия, Свердловская область, городской округ Кировград, поселок Карпушиха	0101000020E61000004BCCB39256F24D40D2A8C0C936C04C40
87275	6	56	1323	14058	17955	\N	57.3738393630058	городской округ Верхний Тагил, Чапаева, 60	Россия, Свердловская область, городской округ Кировград, Верхний Тагил	0101000020E6100000060FD3BEB9F74D40137CD3F4D9AF4C40
86973	6	56	1628	31802	18133	\N	57.197150999999998	Тугулымский район, д. Щелконогова, Школьная, 1а		0101000020E6100000F2D24D62101C5040D5AF743E3C994C40
87264	6	56	1323	14058	17955	\N	57.368248999999999	город Верхний Тагил, Чапаева, № 54	Россия, Свердловская область, городской округ Кировград, Верхний Тагил	0101000020E6100000FAD170CADCF84D4071E481C822AF4C40
87272	6	56	1323	14058	18397	\N	57.368248999999999	город Верхний Тагил, п. Половинный, Центральная, № 3		0101000020E6100000FAD170CADCF84D4071E481C822AF4C40
87268	6	56	1323	14058	17924	\N	57.373517330108697	город Верхний Тагил, Островского, 60	Россия, Свердловская область, городской округ Кировград, Верхний Тагил	0101000020E61000000726378AACF74D4001C0B167CFAF4C40
87270	6	56	1323	14058	77089	\N	57.368248999999999	город Верхний Тагил, Ленина, № 1	Россия, Свердловская область, городской округ Кировград, Верхний Тагил	0101000020E6100000FAD170CADCF84D4071E481C822AF4C40
87267	6	56	1323	14058	77089	\N	57.368248999999999	город Верхний Тагил, Ленина, № 100	Россия, Свердловская область, городской округ Кировград, Верхний Тагил	0101000020E6100000FAD170CADCF84D4071E481C822AF4C40
88278	6	56	7002	61159	78272	\N	58.762720000000002	Качканарский городской округ, п. Валериановск, ул. Кирова, 49	Россия, Свердловская область, городской округ Качканар, поселок Валерьяновск	0101000020E610000048A30227DBC64D40A80018CFA0614D40
88245	6	56	1537	29638	\N	\N	59.933852000000002	городской округ Карпинск, поселок Сосновка	Россия, Свердловская область, городской округ Карпинск, поселок Сосновка	0101000020E61000007A008BFCFAE74D40F0A65B7688F74D40
88248	6	56	1537	29690	\N	\N	59.887493999999997	городской округ Карпинск, поселок Княсьпа	Россия, Свердловская область, городской округ Карпинск, поселок Новая Княсьпа	0101000020E6100000C4AF58C345D24D40B7B2446799F14D40
88271	6	56	1537	18260	\N	\N	59.501519258168301	город Карпинск, поселок Кытлым	Россия, Свердловская область, городской округ Карпинск, поселок Кытлым	0101000020E6100000A1832EE1D0994D404CA94BC631C04D40
88270	6	56	1537	30825	\N	\N	59.715639000000003	городской округ Карпинск, поселок Каквинские Печи	Россия, Свердловская область, городской округ Карпинск, поселок Каквинские Печи	0101000020E61000000B0E2F8848CD4D40FF5E0A0F9ADB4D40
87293	6	56	1537	61180	77465	\N	59.931981354270903	Волчанский городской округ, Мичурина, 9	Россия, Свердловская область, городской округ Карпинск, Волчанск	0101000020E61000008A3A730F090B4E4027BF45274BF74D40
88268	6	56	1537	30718	\N	\N	59.689208999999998	городской округ Карпинск, поселок Веселовка	Россия, Свердловская область, городской округ Карпинск, поселок Веселовка	0101000020E61000005D34643C4AFF4D40EF8D210038D84D40
86194	6	56	1596	26186	18792	\N	56.533670999999998	Каменский район, д.Черноусова, Кирова, 39а		0101000020E6100000E335AFEAACE04E406CE9D1544F444C40
86184	6	56	1596	25763	20077	\N	56.496701320847897	Каменский район, с.Черемхово, Ленина, 43	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Черемхово	0101000020E6100000817C09151CE44E40FC71FBE5933F4C40
86148	6	56	1596	24127	18410	\N	56.389333000000001	Каменский район, с.Троицкое, Ленина, 32	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Троицкое	0101000020E6100000E50CC51D6FB44E407520EBA9D5314C40
85001	6	56	1596	24127	19369	\N	56.389333000000001	село Троицкое, Ленина,194		0101000020E6100000E50CC51D6FB44E407520EBA9D5314C40
86171	6	56	1596	22021	19068	\N	56.438084000000003	Свердловская область, Каменский район, с.Травянское, Ворошилова, 9а		0101000020E6100000309E4143FF024F405073F22213384C40
86150	6	56	1596	24235	17980	\N	56.442926	Каменский район, с.Сосновское, Мира, 9а		0101000020E610000018EE5C18E99F4E40284696CCB1384C40
86166	6	56	1596	24997	19075	\N	56.350732000000001	Каменский район, д.Соколова, Ани Семянниковой, 5		0101000020E6100000637B2DE8BD1B4F4091D442C9E42C4C40
86163	6	56	1596	24820	18433	\N	56.345519000000003	Каменский район, с.Рыбниковское, Советская, 145		0101000020E61000002DCE18E604D74E40C59272F7392C4C40
86177	6	56	1596	25554	18770	\N	56.459139	Каменский район, с.Позариха, Лесная, 14	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Позариха	0101000020E610000035D07CCEDDF04E40B9A81611C53A4C40
86189	6	56	1596	26068	18931	\N	56.265622	Каменский район, с.Пирогово, Школьная, 20		0101000020E6100000F88C446804FB4E408F8CD5E6FF214C40
88064	6	56	1596	21344	\N	\N	56.492975000000001	"""""""город КаменскУральский, поселок Первомайский, 27, общежитие ОАО """"""""КУЗОЦМ"""""""""""""""	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Первомайский	0101000020E610000000C79E3D97CB4E40705F07CE193F4C40
86787	6	56	1596	21344	79425	\N	56.492975000000001	поселок Первомайский, Первомайская, 34Б		0101000020E610000000C79E3D97CB4E40705F07CE193F4C40
86493	6	56	1596	21344	19983	\N	56.492975000000001	п. Первомайский, Ленина, 40	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Первомайский	0101000020E610000000C79E3D97CB4E40705F07CE193F4C40
86138	6	56	1596	21344	17945	\N	56.492975000000001	Каменский район, п.Первомайский, Кирова, 30		0101000020E610000000C79E3D97CB4E40705F07CE193F4C40
88063	6	56	1596	49996	19392	\N	56.452108393793701	город КаменскУральский, Новый Завод, ул.Кленовая, 1, 1	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Новый Завод	0101000020E6100000B3EDB43522EE4E404721C9ACDE394C40
86185	6	56	1596	25931	19105	\N	56.189244000000002	Каменский район, п. Новый Быт, Ленина, 6		0101000020E6100000E09F5225CAF44E406C7BBB2539184C40
86175	6	56	1596	23558	18442	\N	56.366365000000002	Свердловская область, Каменский район, с.Новоисетское, Ленина, 24а	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Новоисетское	0101000020E61000002A745E6397124F4014B35E0CE52E4C40
88202	6	56	1596	27758	18686	\N	56.383493000000001	город КаменскУральский, деревня Монастырка, Комиссаров, 29, школа № 39		0101000020E61000007F4C6BD3D8004F405A9F724C16314C40
86927	6	56	1628	29557	20269	\N	57.054018999999997	Тугулымский район, д. Филина, Молодежная, 13		0101000020E6100000166D8E739B3250406A2E3718EA864C40
86132	6	56	1596	49919	18379	\N	56.397144533876897	Каменский городской округ, п. Мартюш, Титова, 3	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Мартюш	0101000020E61000003CC1FEEBDCF04E408D62B9A5D5324C40
86130	6	56	1596	49919	18986	\N	56.397385	Каменский городской округ, п. Мартюш, Ленина, 11	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Мартюш	0101000020E6100000B43A394371F14E40E275FD82DD324C40
86143	6	56	1596	61234	78257	\N	56.439933000000003	Каменский район, с.Ммаминское, Чапаева, 1в	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Маминское	0101000020E610000061C1FD8007B44E4031B77BB94F384C40
86154	6	56	1596	24429	19032	\N	56.412346999999997	Каменский район, п.Ленинский, Советская, 10б		0101000020E610000059A31EA2D1A34E4046CD57C9C7344C40
86159	6	56	1596	49878	17993	\N	56.544641014958103	Каменский район, п.Лебяжье, Советская, 10	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Лебяжье	0101000020E6100000751E15FF77D44E40C687D9CBB6454C40
86173	6	56	1596	53061	\N	\N	56.463655000000003	"""""""Каменский район, д.Кремлёвка, помещение базы ОАО """"""""СинТЗ"""""""""""""""		0101000020E61000006E693524EEFB4E403ED00A0C593B4C40
86165	6	56	1596	24888	19053	\N	56.363877000000002	Каменский район, с.Колчедан, Ленина, 38	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Колчедан	0101000020E610000070D1C952EB194F4020628385932E4C40
86180	6	56	1596	25645	18056	\N	56.580642288974801	Каменский район, с.Клевакинское, Уральская, 17	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Клевакинское	0101000020E6100000A54C6A6803DC4E408E57207A524A4C40
86140	6	56	1596	23755	19875	\N	56.433441000000002	Каменский район, п.Горный, Нагорная, 8а		0101000020E610000020990E9D9ECB4E406EDFA3FE7A374C40
86134	6	56	1596	23461	18381	\N	56.411127	Каменский район, д.Брод, Ворошилова, 2		0101000020E61000008192020B60EC4E4055C03DCF9F344C40
86169	6	56	1596	25075	18081	\N	56.427264000000001	Каменский район, с. Большая Грязнуха, 8е Марта, 26а		0101000020E6100000527C7C42760A4F400B613596B0364C40
86182	6	56	1596	25662	18455	\N	56.610463000000003	Каменский район, д.Белоносова, Куйбышева, 64		0101000020E610000063B83A00E2CE4E408335CEA6234E4C40
86191	6	56	1596	26139	20073	\N	56.301281282300899	Каменский район, с.Барабановское, Кирова, 32	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Барабановское	0101000020E61000005B5D4E0988EF4E40FEF3346090264C40
89315	6	56	6985	49839	17791	\N	57.671071879168601	город Ирбит, ул.Мальгина, 27	Россия, Свердловская область, городской округ Ирбит	0101000020E6100000FE62B66455884F4073A1F2AFE5D54C40
88022	6	56	1444	19003	18626	\N	61.281460000000003	Ивдельский городской округ, п. Хорпия, Титова, 13		0101000020E610000063B9A5D590444E40EB909BE106A44E40
88028	6	56	1444	19316	17940	\N	60.199874999999999	Ивдельский городской округ, п. Старая Сама, Горняков, 5		0101000020E6100000E411DC48D92E4E40DD24068195194E40
88020	6	56	1444	18998	17866	\N	60.982553807697201	Ивдельский горродской округ, п. Северный, Ленина, 16	Россия, Свердловская область, городской округ Ивдель, поселок Северный	0101000020E61000006CCB80B394324E40E9465854C47D4E40
89288	6	56	1444	16308	18891	\N	61.017660999999997	поселок Пелым, Фестивальная, 12		0101000020E61000009A5B21ACC6FE4E4013B534B742824E40
88032	6	56	1444	19514	19017	\N	60.906056	Свердловская область, Ивдельский городской округ, п. Оус, Молодежная, 51	Россия, Свердловская область, городской округ Ивдель, поселок Оус	0101000020E610000089963C9E96C14E401B2C9CA4F9734E40
88031	6	56	1444	19413	18399	\N	60.113930000000003	Ивдельский городской округ, п. Маслово, Ленина, 24		0101000020E61000008CF84ECC7A3B4E4043041C42950E4E40
88024	6	56	1444	19159	18380	\N	60.418449684516403	Ивдельский городской округ, п. Екатерининка, Красноармейская, 1	Россия, Свердловская область, городской округ Ивдель, поселок Екатерининка	0101000020E6100000B8E864A9F5364E406F8104C58F354E40
88026	6	56	1444	19218	19367	\N	60.214370000000002	Ивдельский городской округ, п. Денежкино, Станционная, 20		0101000020E6100000A019C40776344E402C9FE579701B4E40
89289	6	56	1444	16461	18102	\N	61.073497000000003	Свердловская область, поселок Атымья, Космонавтов, 5		0101000020E61000008CBFED0912254F4054AD855968894E40
87959	6	56	964	15815	18884	\N	56.636555000000001	поселок Шабровский, Ленина, 24		0101000020E6100000FE60E0B9F74C4E407A8D5DA27A514C40
86476	6	56	964	8040	18659	\N	56.867123999999997	п. Северка, Горная, 3		0101000020E6100000A088450C3B264E40D1C952EBFD6E4C40
87949	6	56	964	50101	19878	\N	56.722456017567801	поселок Рудный, Адмирала Ушакова, 24	Россия, Свердловская область, городской округ Екатеринбург	0101000020E6100000AC8F87BEBB514E4045662E70795C4C40
86851	6	56	964	48180	18900	\N	56.811675000000001	деревня Мостовка, Студенческая, 3		0101000020E61000002F19C748F66C4E408BFD65F7E4674C40
87391	6	56	964	49986	\N	\N	56.771133000449701	"""""""город Екатеринбург, ВерхИсетский район, Медный, Клуб по месту жительства """"""""Домовенок"""""""	Россия, Свердловская область, городской округ Екатеринбург, поселок Медный	0101000020E61000009AD024B1A4304E40E5EE737CB4624C40
87960	6	56	964	15884	19924	\N	56.683484999999997	село Горный Щит, Ленина, 12а		0101000020E6100000B39AAE27BA424E403D27BD6F7C574C40
89172	6	56	312	10550	17971	\N	56.9913424410204	город Среднеуральск, Уральская, 14	Россия, Свердловская область, городской округ Верхняя Пышма, Среднеуральск	0101000020E610000049D8B793883C4E405C936E4BE47E4C40
89169	6	56	312	10550	17971	\N	56.994739000000003	город Среднеуральск, Уральская, 18		0101000020E6100000DF6B088ECB3C4E402387889B537F4C40
89181	6	56	312	10550	18426	\N	56.994739000000003	городской округ Среднеуральск, Набережная, 8а		0101000020E6100000DF6B088ECB3C4E402387889B537F4C40
89165	6	56	312	10550	18426	\N	56.987088076939003	город Среднеуральск, Набережная, 8 а	Россия, Свердловская область, городской округ Верхняя Пышма, Среднеуральск	0101000020E61000006362F3716D3A4E4014234BE6587E4C40
86980	6	56	1628	20423	18843	\N	57.157412000000001	Свердловская обасть, Тугулымский район, д. Тямкина, Новая, 9		0101000020E61000009014916115275040BDFF8F1326944C40
89173	6	56	312	10550	18002	\N	56.994457910825901	город Среднеуральск, Лермонтова, 6	Россия, Свердловская область, городской округ Верхняя Пышма, Среднеуральск	0101000020E61000002AC423F1F23C4E406F9F55664A7F4C40
89167	6	56	312	10550	18749	\N	56.989793941946097	город Среднеуральск, Ленина, 27 а	Россия, Свердловская область, городской округ Верхняя Пышма, Среднеуральск	0101000020E61000006BB8C83D5D3B4E4076E3DD91B17E4C40
89178	6	56	312	10550	18351	\N	56.994739000000003	город Среднеуральск, Бахтеева, 23		0101000020E6100000DF6B088ECB3C4E402387889B537F4C40
87256	6	56	312	47122	20403	\N	57.080976999999997	п. Соколовка, Загородная, 12, (Фельдшерский пункт)	Россия, Свердловская область, городской округ Верхняя Пышма, поселок Соколовка	0101000020E61000005F984C158C504E40355D4F745D8A4C40
87252	6	56	312	47031	19306	\N	57.014822000000002	п. Санаторный, Огородная, 13А, (Фельдшерский пункт)		0101000020E61000008D9B1A683E474E4073A1F2AFE5814C40
87258	6	56	312	1406	19326	\N	57.163049999999998	с. Мостовское, Садовая, 1, (Здание Администрации)		0101000020E61000003BC780ECF5524E4070CE88D2DE944C40
87257	6	56	312	47129	20411	\N	57.054262999999999	п. Красный, Жданова, 23, (Школа № 16)		0101000020E61000003DB83B6BB7574E4001310917F2864C40
87245	6	56	312	13208	18968	\N	56.977716999999998	п. Исеть, Станционная, 1, (Управление щебзавода)		0101000020E61000000EF5BBB0352F4E4022DFA5D4257D4C40
87248	6	56	312	13208	18672	\N	56.977716999999998	п. Исеть, Мира, 18, (Школа № 7)		0101000020E61000000EF5BBB0352F4E4022DFA5D4257D4C40
87251	6	56	312	13497	18978	\N	56.995258999999997	с. Балтым, Первомайская, 38, (Школа № 9)		0101000020E6100000E6CFB7054B4D4E405B069CA5647F4C40
87199	6	56	136	49942	\N	\N	57.126308999999999	город Березовский, пос. Солнечный	Россия, Свердловская область, городской округ Березовский, поселок Солнечный	0101000020E6100000EA23F0879F994E406118B0E42A904C40
86206	6	56	136	48966	19090	\N	57.034477000000003	п.Октябрьский, Кабакова, 3		0101000020E6100000F1BA7EC16E5E4E406BBB09BE69844C40
87194	6	56	136	50105	19911	\N	57.048587066760298	город Березовский, пос. Монетный, Пушкина, 21	Россия, Свердловская область, городской округ Березовский, поселок Монетный	0101000020E61000005000C5C892714E4060014C1938864C40
87197	6	56	136	49941	18605	\N	57.112478852205001	город Березовский, пос. Лубяной, Школьная	Россия, Свердловская область, городской округ Березовский, поселок Лубяной	0101000020E61000007EC51A2E72914E404F3E3DB6658E4C40
87202	6	56	136	49938	\N	\N	57.143258000000003	город Березовский, пос. Лосиный	Россия, Свердловская область, городской округ Березовский, поселок Лосиный	0101000020E61000003083312251884E40F871344756924C40
87201	6	56	136	49943	\N	\N	57.077181000000003	город Березовский, пос. Безречный	Россия, Свердловская область, городской округ Березовский, поселок Безречный	0101000020E6100000272EC72B10894E40B16F2711E1894C40
89285	6	56	1393	15724	\N	\N	57.089320999999998	поселок Рефтинский, Юбилейная, 3/1	Россия, Свердловская область, городской округ Асбест, поселок Рефтинский	0101000020E610000072A609DB4FD64E404AECDADE6E8B4C40
89281	6	56	1393	15724	19168	\N	57.089320999999998	поселок Рефтинский, Молодежная, 6		0101000020E610000072A609DB4FD64E404AECDADE6E8B4C40
89278	6	56	1393	15724	19168	\N	57.089320999999998	поселок Рефтинский, Молодежная, 5		0101000020E610000072A609DB4FD64E404AECDADE6E8B4C40
89284	6	56	1393	15724	18599	\N	57.089320999999998	поселок Рефтинский, Гагарина, 10		0101000020E610000072A609DB4FD64E404AECDADE6E8B4C40
89276	6	56	1393	15724	18599	\N	57.089320999999998	поселок Рефтинский, Гагарина, 23		0101000020E610000072A609DB4FD64E404AECDADE6E8B4C40
89272	6	56	1393	61170	77438	\N	57.1148383000682	Малышевский городской округ, Свободы, 13	Россия, Свердловская область, городской округ Асбест, поселок Малышева	0101000020E610000001C3F2E7DBB24E40452BF702B38E4C40
89270	6	56	1393	61170	77438	\N	57.115912268580402	Малышевский городской округ, Свободы, 15 а	Россия, Свердловская область, городской округ Асбест, поселок Малышева	0101000020E61000003E5E488787B24E40639B5434D68E4C40
89273	6	56	1393	61170	78595	\N	57.117763459365499	Свердловская область, Малышевский городской округ, Мопра, 18	Россия, Свердловская область, городской округ Асбест, поселок Малышева	0101000020E6100000E3C3EC65DBB14E40E4D6A4DB128F4C40
87122	6	56	1393	50145	\N	\N	56.998548999999997	город Асбест, поселок Красноармейский, общественноторговый центр	Россия, Свердловская область, городской округ Асбест, поселок Красноармейский	0101000020E610000059A4897780A74E400C3A2174D07F4C40
87101	6	56	825	6564	78472	\N	57.7287414352257	муниципальное образование город Алапаевск, поселок НейвоШайтанский, ул.Уральских Рабочих, д.3	Россия, Свердловская область, городской округ Алапаевск, поселок Нейво-Шайтанский	0101000020E61000009F5BE84A04A04E408E20956247DD4C40
87102	6	56	825	6564	18731	\N	57.728558	муниципальное образование город Алапаевск, поселок НейвоШайтанский, ул.Спиридонова, д.38		0101000020E6100000D656EC2FBB9F4E409D9E776341DD4C40
87099	6	56	825	6271	20050	\N	57.748249999999999	муниципальное образование город Алапаевск, село Мелкозерово, ул.Школьная, д.10		0101000020E61000005DBF60376CC14E40B29DEFA7C6DF4C40
87095	6	56	825	6078	9669	\N	57.868249432149298	муниципальное образование город Алапаевск, поселок Западный, ул.Мира, д.5	Россия, Свердловская область, городской округ Алапаевск, поселок Западный	0101000020E6100000D50451F701CE4E4071E481C822EF4C40
87097	6	56	825	6141	18757	\N	57.755805000000002	муниципальное образование город Алапаевск, поселок Асбестовский, ул.Калинина, д.11		0101000020E61000006F8445459CB24E409F93DE37BEE04C40
87036	6	56	457	2905	18634	\N	57.341385000000002	п. Шамары, Первомайская, 31	Россия, Свердловская область, Шалинский район, поселок Шамары	0101000020E61000006745D4449F1B4D40282CF180B2AB4C40
87037	6	56	457	2905	20371	\N	57.341385000000002	п. Шамары, Кирова, 52		0101000020E61000006745D4449F1B4D40282CF180B2AB4C40
87034	6	56	457	2670	78435	\N	57.253365000000002	п. Шаля, Энгельса, 54		0101000020E6100000AC1919E42E5E4D40BC79AA436EA04C40
87033	6	56	457	2670	20363	\N	57.253365000000002	п. Шаля, Свердлова, 26		0101000020E6100000AC1919E42E5E4D40BC79AA436EA04C40
87032	6	56	457	2670	20177	\N	57.253365000000002	п. Шаля, Орджоникидзе, 5А	Россия, Свердловская область, Шалинский район, поселок Шаля	0101000020E6100000AC1919E42E5E4D40BC79AA436EA04C40
87049	6	56	457	3638	19970	\N	57.342069325751098	с. Чусовое, Малышева, 2	Россия, Свердловская область, Шалинский район, поселок Чусовое (Шайтанка)	0101000020E61000003255302AA99F4D40DBFCBFEAC8AB4C40
87045	6	56	457	47506	20381	\N	57.313684000000002	с. Сылва, Урицкого, 8		0101000020E610000059A2B3CC22644D40A5A31CCC26A84C40
89302	6	56	457	17069	18922	\N	57.229958000000003	городской округ Староуткинск, Советская, 1		0101000020E610000036C98FF815AB4D400FBA84436F9D4C40
87044	6	56	457	3365	18943	\N	57.197814000000001	п. Сарга, Советская, 12	Россия, Свердловская область, Шалинский район, поселок Сарга	0101000020E6100000A96C585359784D4071581AF851994C40
87042	6	56	457	61299	78465	\N	57.575334755494303	с. Роща, Первомайская, 24		0101000020E610000023BDA8DDAF1E4D40419FC893A4C94C40
87040	6	56	457	47405	18280	\N	57.473666000000001	с. Платоново, Советская, 1		0101000020E61000008FDFDBF467154D40139D6516A1BC4C40
87050	6	56	457	47595	17793	\N	57.395277999999998	д. Мартьяново, Центральная, 31		0101000020E61000000C01C0B167974D40056A317898B24C40
87041	6	56	457	3215	18639	\N	57.450124000000002	д. Коптелы, Школьная, 12		0101000020E6100000268A90BA9D274D408692C9A99DB94C40
87039	6	56	457	50147	20095	\N	57.389077927252799	д. КоптелоШамары, Кропанцева, 28	Россия, Свердловская область, Шалинский район	0101000020E61000009F8EC70C54244D40EACBD24ECDB14C40
87047	6	56	457	3542	20384	\N	57.454994999999997	п. Колпаковка, Школьная, 1а		0101000020E6100000BEF90D130D684D40F86BB2463DBA4C40
87046	6	56	457	3480	18949	\N	57.366579999999999	ст. Илим, Мира, 7		0101000020E610000077A38FF9807A4D4010AFEB17ECAE4C40
87038	6	56	457	47367	20372	\N	57.361581999306502	п. Гора, 8 Марта, 11	Россия, Свердловская область, Шалинский район, поселок Гора	0101000020E6100000E700C11C3D1C4D404069A85148AE4C40
82317	6	56	457	29739	18942	\N	57.334822000000003	деревня Вогулка, Луговая, 3		0101000020E6100000C66D3480B7424D409CFD8172DBAA4C40
87043	6	56	7043	50179	20188	\N	57.110999	п. Сабик, Комсомольская, 6а		0101000020E6100000F3052D2460984D40C1711937358E4C40
87048	6	56	7041	50203	20244	\N	57.585856999999997	п. Унь, Железнодорожная, 1		0101000020E610000044696FF085574D40FB90B75CFDCA4C40
87016	6	56	2	1743	19186	\N	58.088858999999999	Туринский район, с. Шухруповское, Мира, 10А		0101000020E6100000069CA56439BF4F40467A51BB5F0B4D40
87024	6	56	2	2212	19936	\N	58.065424999999998	Туринский район, с. Чукреевское, Победы, 5		0101000020E6100000E2E7BF07AF9B4F409FABADD85F084D40
87011	6	56	2	1405	18604	\N	58.075806999999998	Туринский район, с. Чекуново, Садовая, 1Б		0101000020E6100000CB4752D2C3DC4F4068E7340BB4094D40
87013	6	56	2	1516	18194	\N	58.095809000000003	Туринский район, пос. Фабричное, Клубная, 1		0101000020E61000002F8B89CDC7E14F40CCD42478430C4D40
87022	6	56	2	2104	19190	\N	58.079985000000001	Туринский район, с. Усениново, Пионерская, 37А		0101000020E61000009FC9FE791AB24F40D595CFF23C0A4D40
86995	6	56	2	4	18574	\N	58.041352000000003	г. Туринск, Спорта, 10		0101000020E6100000DA38622D3ED94F40E6CFB7054B054D40
86991	6	56	2	4	18574	\N	58.041352000000003	г. Туринск, Спорта, 16		0101000020E6100000DA38622D3ED94F40E6CFB7054B054D40
86996	6	56	2	4	19896	\N	58.039788946427301	г. Туринск, Путейцев, 12	Россия, Свердловская область, Туринский район, Туринск	0101000020E61000004A7B832F4CDA4F40CADE52CE17054D40
86987	6	56	2	4	19125	\N	58.041352000000003	г. Туринск, Косогорная, 7А		0101000020E6100000DA38622D3ED94F40E6CFB7054B054D40
86992	6	56	2	4	19116	\N	58.045798046256202	г. Туринск, Ивашева, 6	Россия, Свердловская область, Туринский район, Туринск	0101000020E61000007B116DC7D4D74F40711C78B5DC054D40
86998	6	56	2	4	19139	\N	58.041352000000003	г. Туринск, Горького, 38		0101000020E6100000DA38622D3ED94F40E6CFB7054B054D40
86985	6	56	2	4	18566	\N	58.041352000000003	г.Туринск, Гагарина, 17		0101000020E6100000DA38622D3ED94F40E6CFB7054B054D40
86988	6	56	2	4	18571	\N	58.041352000000003	г. Туринск, 8 Марта, 80		0101000020E6100000DA38622D3ED94F40E6CFB7054B054D40
87015	6	56	2	1642	78527	\N	58.053573999999998	Туринский район, пос. Смычка, Молодежная, 7		0101000020E6100000FAB7CB7EDDE34F403CF54883DB064D40
87020	6	56	2	1980	18889	\N	57.963655000000003	Туринский район, с. Назарово, Гагарина, 25		0101000020E61000000C569C6A2DB04F403ED00A0C59FB4C40
87006	6	56	2	1184	18877	\N	57.859183482155402	Туринский район, с. Липовское, Петереноко, 23	Россия, Свердловская область, Туринский район, поселок Липовское	0101000020E61000004F5C8E5720F04F40BC2363B5F9ED4C40
87019	6	56	2	1855	18888	\N	58.040080000000003	Туринский район, с. Леонтьевское, Советская, 15		0101000020E6100000219221C7D6C14F40A29C685721054D40
87030	6	56	2	2563	19944	\N	58.156656580016701	Туринский район, с. Ленское, Ленина, 9	Россия, Свердловская область, Туринский район, поселок Ленское	0101000020E610000091BA9D7DE5994F4041D829560D144D40
87004	6	56	2	1054	18178	\N	57.969755999999997	Туринский район, с. Коркинское, Школьная, 4		0101000020E61000000BEC3191D2E64F40C58CF0F620FC4C40
87002	6	56	2	946	19151	\N	58.004627999999997	Туринский район, с. Ерзовское, Кирова, 6		0101000020E61000008F34B8AD2DDC4F40AC527AA697004D40
87026	6	56	2	2334	19120	\N	58.068123999999997	Туринский район, с. Дымковское, Ленина, 37		0101000020E6100000BEF6CC9200894F404E098849B8084D40
87009	6	56	2	1290	19164	\N	57.968080999999998	Туринский район, с. Городище, Культуры, 1А		0101000020E61000009BFEEC478AF44F4082700514EAFB4C40
87028	6	56	2	2446	19039	\N	58.137138	Туринский район, с. Благовещенское, Свердлова, 53Б		0101000020E61000003C3080F0A17A4F40F984ECBC8D114D40
86925	6	56	1628	61340	78636	\N	57.068142640139797	Тугулымский район, п. ж/д станции Тугулым, Победы, 12		0101000020E6100000D235936FB6235040C539EAE8B8884C40
86957	6	56	1628	61331	78575	\N	56.969031999999999	Тугулымский район, с. Яр, Мира, 3	Россия, Свердловская область, Тугулымский район, поселок Яр	0101000020E6100000C8EA56CF491250408463963D097C4C40
86941	6	56	1628	30264	19864	\N	57.122312000000001	Тугулымский район, д. Юшкова, пер. Школьный, 1		0101000020E61000006DE179A9D82D504045F46BEBA78F4C40
86969	6	56	1628	31428	\N	\N	57.076676999999997	Тугулымский район, п. Юшала, Садовая, 21	Россия, Свердловская область, Тугулымский район, поселок Юшала	0101000020E61000008E041A6CEA1050407DAD4B8DD0894C40
86965	6	56	1628	31428	18097	\N	57.076676999999997	Тугулымский район, п. Юшала, Железнодорожная, 23		0101000020E61000008E041A6CEA1050407DAD4B8DD0894C40
86966	6	56	1628	31428	19858	\N	57.076676999999997	Тугулымский район, п. Юшала, Школьная, 5		0101000020E61000008E041A6CEA1050407DAD4B8DD0894C40
86920	6	56	1628	20436	19385	\N	57.058154999999999	Свердловская обасть, Тугулымский район, р.п. Тугулым, Школьная, 2		0101000020E6100000B1DD3D40F7285040A88C7F9F71874C40
86923	6	56	1628	20436	18781	\N	57.058154999999999	Тугулымский район, р.п. Тугулым, Войкова, 2		0101000020E6100000B1DD3D40F7285040A88C7F9F71874C40
86977	6	56	1628	32024	19879	\N	57.325352988168198	Тугулымский район, с. Трошково, Парковая, 7	Россия, Свердловская область, Тугулымский район, поселок Трошково	0101000020E610000061FC34EECD195040E753C72AA5A94C40
86960	6	56	1628	31216	19849	\N	56.840359999999997	Тугулымский район, д. Потаскуева, 8 Марта, 5		0101000020E6100000CF87670932125040EB6E9EEA906B4C40
86935	6	56	1628	29979	78526	\N	57.174112999999998	Тугулымский район, д. Полушина, Школьная, 2		0101000020E61000002CF2EB87D83D50407B67B45549964C40
86971	6	56	1628	31752	18120	\N	57.086449999999999	Тугулымский район, с. Ошкуково, Молодежная, 43		0101000020E6100000B24AE9995E2350409E5E29CB108B4C40
86929	6	56	1628	49960	18819	\N	56.981788000000002	Тугулымский район, д. Остров, Речная, 22	Россия, Свердловская область, Тугулымский район, поселок Остров	0101000020E61000007D5A457F6838504079CDAB3AAB7D4C40
86948	6	56	1628	30619	18791	\N	56.957050000000002	Тугулымский район, д. Нижняя Коркина, Центральная, 21		0101000020E6100000E08442041C1C50408351499D807A4C40
86905	6	56	1628	28609	17978	\N	57.066454999999998	Тугулымский район, с. Мальцево, Центральная, 2а		0101000020E61000005EF75624263D5040EDD3F19881884C40
86950	6	56	1628	30726	19000	\N	56.939813999999998	Тугулымский район, д. Луговая, Центральная, 64а		0101000020E610000060CAC0012D23504056293DD34B784C40
86983	6	56	1628	32281	20115	\N	57.083086026885098	Тугулымский район, д. Колобова, Центральная, 16	Россия, Свердловская область, Тугулымский район, поселок Колобова	0101000020E6100000DF32A7CB622E5040B360E28FA28A4C40
86931	6	56	1628	29835	18767	\N	57.095654000000003	Тугулымский район, п. Кармак, Привокзальная, 9		0101000020E61000000952297634375040A5DDE8633E8C4C40
86945	6	56	1628	30516	18821	\N	56.856776000000004	Тугулымский район, д. Калачики, Клубная, 1		0101000020E61000008ECBB8A981305040B5FF01D6AA6D4C40
86975	6	56	1628	31894	18721	\N	57.283256999999999	Тугулымский район, д. Ивановка, Школьная, 10		0101000020E610000010751F80D418504079AEEFC341A44C40
86979	6	56	1628	32107	19121	\N	57.363084999999998	Тугулымский район, с. Зубково, Школьная, 59		0101000020E61000006C938AC6DA0E50408655BC9179AE4C40
86943	6	56	1628	30410	17898	\N	56.861439314150402	Тугулымский район, п. Заводоуспенское, Победы, 2	Россия, Свердловская область, Тугулымский район, поселок Заводоуспенское	0101000020E6100000755AB741ED405040DD3F16A2436E4C40
86891	6	56	1628	48891	78524	\N	57.077846000000001	деревня Журавлева, Центральная, 2		0101000020E610000011C64FE3DE245040ED0F94DBF6894C40
86963	6	56	1628	31317	19354	\N	56.793503999999999	Тугулымский район, п. Ертарский, Кирова, 19		0101000020E6100000F03499F1B6125040629F008A91654C40
86955	6	56	1628	61323	78551	\N	56.961717855835502	Тугулымский район, д. Демина, Школьная, 33	Россия, Свердловская область, Тугулымский район, поселок Дёмино	0101000020E6100000AA45443179195040BDFC4E93197B4C40
86938	6	56	1628	30122	18628	\N	57.253656999999997	Тугулымский район, д. Дубровина, Центральная, 12		0101000020E6100000499EEBFB7039504063B323D577A04C40
86934	6	56	1628	20487	18769	\N	57.117376999999998	Свердловская обасть, Тугулымский район, с. Верховино, Филиппова, 6		0101000020E6100000889E94490D3A5040BB26A435068F4C40
86958	6	56	1628	31130	20295	\N	56.914442999999999	Тугулымский район, д. Большой Рамыл, 8 марта, 15		0101000020E6100000672AC423F11150402F87DD770C754C40
86952	6	56	7042	50177	20185	\N	56.957932999999997	Тугулымский район, п. Луговской, Клубная, 25		0101000020E6100000BD8BF7E3F62150402C616D8C9D7A4C40
86939	6	56	7061	50210	20281	\N	57.159331000000002	Тугулымский район, д. Ядрышникова, Юбилейная, 4		0101000020E6100000F6D214014E305040971E4DF564944C40
86906	6	56	1634	49141	20254	\N	57.094583	деревня Чупина, Совхозная, 8а		0101000020E61000003ECBF3E0EEF04F40F8E0B54B1B8C4C40
86868	6	56	1634	20551	18311	\N	57.060504000000002	поселок Троицкий, Мичурина, 2А		0101000020E61000000586AC6EF5DE4F407BA35698BE874C40
86866	6	56	1634	20551	17797	\N	57.052787050396297	поселок Троицкий, ул.Ленина, 22	Россия, Свердловская область, Талицкий район, поселок Троицкий	0101000020E6100000A8380EBC5ADE4F40B55373B9C1864C40
86865	6	56	1634	20551	17797	\N	57.060246665013899	поселок Троицкий, ул.Ленина, 16	Россия, Свердловская область, Талицкий район, поселок Троицкий	0101000020E6100000DD42572250DF4F404F57772CB6874C40
86864	6	56	1634	20551	77088	\N	57.060504000000002	поселок Троицкий, Комарова, 21		0101000020E61000000586AC6EF5DE4F407BA35698BE874C40
86867	6	56	1634	20551	19977	\N	57.059173674910397	поселок Троицкий, ул.Железнодорожная, 30	Россия, Свердловская область, Талицкий район, поселок Троицкий	0101000020E6100000EFFE78AF5ADF4F4002637D0393874C40
86886	6	56	1634	27765	18987	\N	56.631554999999999	деревня Трехозерная, Мира, 1		0101000020E6100000E77118CC5FCD4F40095053CBD6504C40
86863	6	56	1634	26266	18656	\N	57.018971999999998	город Талица, Советская, 65		0101000020E6100000CBD93BA3ADDE4F4015C5ABAC6D824C40
86855	6	56	1634	26266	18650	\N	57.018971999999998	город Талица, Рябиновая,8, школа №1		0101000020E6100000CBD93BA3ADDE4F4015C5ABAC6D824C40
86904	6	56	1634	26266	19142	\N	57.036430355033303	Талицкий, Талица, Нахимова 8и. Административное здание И.П.Байлиева		0101000020E61000001FA1664815E34F40F14BFDBCA9844C40
86862	6	56	1634	26266	19273	\N	57.012300111400897	город Талица, Луначарского, 57	Россия, Свердловская область, Талицкий район, Талица	0101000020E6100000BB5F05F86EDD4F40D3DEE00B93814C40
86861	6	56	1634	26266	18972	\N	57.018971999999998	город Талица, Лермонтова, 2		0101000020E6100000CBD93BA3ADDE4F4015C5ABAC6D824C40
86857	6	56	1634	26266	18797	\N	57.0151784288418	город Талица, Ленина, 105	Россия, Свердловская область, Талицкий район, Талица	0101000020E61000001FBAA0BE65DE4F4031CF4A5AF1814C40
86854	6	56	1634	26266	18797	\N	57.016724776546603	город Талица, Ленина, 71	Россия, Свердловская область, Талицкий район, Талица	0101000020E610000043705CC64DDF4F404703780B24824C40
86914	6	56	1634	26266	19904	\N	57.018971999999998	город Талица, Красноармейская, 55		0101000020E6100000CBD93BA3ADDE4F4015C5ABAC6D824C40
86858	6	56	1634	26266	19904	\N	57.014827255614101	город Талица, Красноармейская, 50	Россия, Свердловская область, Талицкий район, Талица	0101000020E6100000B4AD669DF1DF4F40840CE4D9E5814C40
86859	6	56	1634	26266	18653	\N	57.029155711127302	город Талица, Запышминская, 2а	Россия, Свердловская область, Талицкий район, Талица	0101000020E6100000EA3D95D39EDC4F40B83D4162BB834C40
86918	6	56	1634	26266	18179	\N	57.018971999999998	город Талица, ул.Заозерная, 76		0101000020E6100000CBD93BA3ADDE4F4015C5ABAC6D824C40
86853	6	56	1634	49835	17772	\N	57.009836984850899	город Талица, Урга, 2	Россия, Свердловская область, Талицкий район, поселок Белая Елань	0101000020E610000003B5183C4CD94F4037A5BC5642814C40
86902	6	56	1634	49076	20044	\N	57.101989568031598	поселок Пионерский, Советская, 5	Россия, Свердловская область, Талицкий район, поселок Пионерский	0101000020E6100000B404190115E04F40704221020E8D4C40
86900	6	56	1634	28389	19016	\N	57.103129000000003	деревня Первухина, Фестивальная, 16		0101000020E61000002AC58EC6A10450407522C154338D4C40
86875	6	56	1634	48616	17822	\N	56.687578000000002	село Пеньки, Советская, 17		0101000020E6100000AA436E861B0750407CB94F8E02584C40
86912	6	56	1634	49228	18998	\N	57.181983000000002	деревня Панова, Береговая, 3	Россия, Свердловская область, Талицкий район, поселок Панова	0101000020E61000005AB8ACC266BC4F40C8B60C384B974C40
86874	6	56	1634	27200	20395	\N	56.645940000000003	деревня Нижний Катарач, Победы, 11		0101000020E610000067B4554964065040D1967329AE524C40
86895	6	56	1634	28192	18674	\N	57.013435000000001	деревня Мохирева, Советская, 2		0101000020E61000005130630AD601504096CFF23CB8814C40
86898	6	56	1634	28285	18403	\N	56.951155	поселок Мака, Центральная, 14		0101000020E6100000179E978A8DDB4F40A4367172BF794C40
86909	6	56	1634	49175	\N	\N	57.055962000000001	деревня Луговая, Кузнецова, 22а	Россия, Свердловская область, Талицкий район, поселок Луговая (Большая Луговая)	0101000020E6100000513239B533D44F40CDE847C329874C40
86896	6	56	1634	48970	20399	\N	57.184762999999997	поселок Кузнецовский, Ленина, 6		0101000020E6100000DD5ED218AD04504063416150A6974C40
86882	6	56	1634	48736	17852	\N	56.6696483012133	деревня Красногорка, Центральная, 11	Россия, Свердловская область, Талицкий район, поселок Красногорка	0101000020E6100000A5F44C2F31F04F4079EA9106B7554C40
86899	6	56	1634	49024	19013	\N	57.117519000000001	поселок Комсомольский, 70 лет Октября, 18		0101000020E6100000CCF09F6EA0F84F404ED4D2DC0A8F4C40
86884	6	56	1634	27666	17854	\N	56.667742191227099	село Казаковское, Набережная, 1	Россия, Свердловская область, Талицкий район, поселок Казаковское	0101000020E6100000C58D5BCCCFDF4F403315E29178554C40
86879	6	56	1634	48687	19995	\N	56.603828999999998	деревня Зарубина, Уральская, 18		0101000020E61000001D21037976F34F402DB0C7444A4D4C40
86911	6	56	1634	28894	17994	\N	57.129201000000002	село Завьяловское, Ленина, 335		0101000020E6100000014D840D4FC74F4025CE8AA889904C40
86883	6	56	1634	27661	20223	\N	56.634748000000002	село Горскино, Новая, 1		0101000020E6100000963E74417DDD4F40C899266C3F514C40
86907	6	56	1634	28744	20045	\N	57.085109548157902	село ГорБуновское, Советская, 40	Россия, Свердловская область, Талицкий район, поселок Горбуновское	0101000020E610000053927538BAD04F4002486DE2E48A4C40
86917	6	56	1634	61266	77900	\N	57.203842248268302	село ВновьЮрмытское, Победы, 12	Россия, Свердловская область, Талицкий район, поселок Вновь-Юрмытское	0101000020E61000001E520C9068AC4F408FC6A17E179A4C40
86881	6	56	1634	27527	20413	\N	56.697850000000003	деревня Вихляева, Центральная, 11	Россия, Свердловская область, Талицкий район, поселок Вихляева	0101000020E6100000A3E716BA12FD4F40BEC1172653594C40
86878	6	56	1634	27380	19324	\N	56.541671999999998	деревня Буткинское Озеро, переулок Центральный, 2		0101000020E6100000BB9C1210930150405794128255454C40
86872	6	56	1634	26977	20211	\N	56.720878999999996	село Бутка, Строителей, 1		0101000020E6100000ACAA97DF69E44F40C4AF58C3455C4C40
86871	6	56	1634	26977	17808	\N	56.720878999999996	село Бутка, ул. Совхозная, 16		0101000020E6100000ACAA97DF69E44F40C4AF58C3455C4C40
86869	6	56	1634	26977	18971	\N	56.720878999999996	село Бутка, Карла Маркса, 3		0101000020E6100000ACAA97DF69E44F40C4AF58C3455C4C40
86873	6	56	1634	48569	17819	\N	56.810141999999999	поселок Боровской, Школьная, 8		0101000020E6100000F1457BBC90E44F40DA8EA9BBB2674C40
86903	6	56	1634	49097	19377	\N	57.053431000000003	деревня Бор, Победы, 10		0101000020E61000003830B95164BB4F40DACBB6D3D6864C40
86894	6	56	1634	48938	18977	\N	56.988197999999997	село Беляковское, Клубная, 10		0101000020E6100000315EF3AACE0C50407EFCA5457D7E4C40
86908	6	56	1634	28749	20000	\N	57.015208999999999	деревня Белая Елань, Буденного, 85		0101000020E610000025C9737D1FD84F406CCD565EF2814C40
86885	6	56	1634	27756	19337	\N	56.608297999999998	село Басмановское, Ленина, 42		0101000020E6100000BEA1F0D93AD84F40711C78B5DC4D4C40
86897	6	56	1634	40352	9908	\N	57.163216915977998	село Балаир, Жданова, 2	Россия, Свердловская область, Талицкий район, поселок Балаир	0101000020E610000024B891B2450250405C936E4BE4944C40
86919	6	56	7060	50207	20273	\N	57.031844244805001	город Талица, Вокзальная, 53		0101000020E61000002272FA7ABEDC4F407349D57613844C40
81451	6	56	1573	19987	\N	\N	57.806415000000001	деревня Увал	Россия, Свердловская область, Тавдинский район, поселок Увал	0101000020E610000068B3EA73B56450407E00529B38E74C40
86826	6	56	1573	24821	\N	\N	58.052683999999999	город Тавда, Транспортная, 2	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86828	6	56	1573	24821	19115	\N	58.057742810294897	город Тавда, Шоссейная, 5	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E61000002B508BC1C34F50405649641F64074D40
86823	6	56	1573	24821	18209	\N	58.052683999999999	город Тавда, Чехова, 30	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86821	6	56	1573	24821	19920	\N	58.048952646608399	Город Тавда, Строителей, 5	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E610000014B4C9E1935050404205871744064D40
86837	6	56	1573	24821	77086	\N	58.052683999999999	город Тавда, Свердлова, 83д		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86831	6	56	1573	24821	19201	\N	58.042685125421499	город Тавда, Рабочая, 44	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E6100000B79A75C6F74F5040CF83BBB376054D40
86833	6	56	1573	24821	77085	\N	58.052683999999999	город Тавда, Пушкина, 29		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86827	6	56	1573	24821	19926	\N	58.052683999999999	город Тавда, Омская, 1		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86825	6	56	1573	24821	78429	\N	58.052683999999999	город Тавда, Нахимова, 7		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86843	6	56	1573	24821	19946	\N	58.036847365228098	город Тавда, Матросова, 19	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E610000049A12C7C7D54504055FA0967B7044D40
86852	6	56	1573	24821	20164	\N	58.031420310874502	город Тавда, Ломоносова, 6	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E61000004BAE62F19B5350405C38109205044D40
86824	6	56	1573	24821	18199	\N	58.052683999999999	город Тавда, Лесопильщиков, 11		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86835	6	56	1573	24821	17997	\N	58.050035017833203	город Тавда, Ленина, 71	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E6100000F568AA27F3505040E353008C67064D40
86834	6	56	1573	24821	17997	\N	58.052683999999999	город Тавда, Ленина, 91а		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86832	6	56	1573	24821	17997	\N	58.051297772294703	город Тавда, Ленина, 53	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E6100000C6A52A6D71505040D42CD0EE90064D40
86829	6	56	1573	24821	19049	\N	58.050825666635298	город Тавда, Куйбышева, 7а	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E610000026529ACDE34E5040ACE4637781064D40
86836	6	56	1573	24821	19938	\N	58.041126207093903	город Тавда, Кирова, 126	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E61000006005F86EF3515040F581E49D43054D40
86822	6	56	1573	24821	20136	\N	58.052683999999999	город Тавда, Кардонская, 45		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86842	6	56	1573	24821	18151	\N	58.052683999999999	город Тавда, К. Маркса, 13		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86840	6	56	1573	24821	18151	\N	58.052683999999999	город Тавда, К. Маркса, 42а		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86839	6	56	1573	24821	18151	\N	58.052683999999999	город Тавда, К. Маркса, 18		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86830	6	56	1573	24821	20154	\N	58.051172636464699	город Тавда, 9е Января, 13	Россия, Свердловская область, Тавдинский район, Тавда	0101000020E6100000E0F76F5E9C4F504017B83CD68C064D40
86850	6	56	1573	48154	\N	\N	58.126432000000001	деревня Ленино	Россия, Свердловская область, Тавдинский район, поселок Ленино	0101000020E6100000B6A2CD716E5550407D957CEC2E104D40
86849	6	56	1573	48151	18903	\N	58.106225868976402	село Крутое, Центральная, 27	Россия, Свердловская область, Тавдинский район, поселок Крутое	0101000020E6100000223658384944504011FE45D0980D4D40
81431	6	56	1573	18946	\N	\N	57.962131999999997	село Кошуки	Россия, Свердловская область, Тавдинский район, поселок Кошуки	0101000020E61000002849D74CBE615040B037312427FB4C40
86847	6	56	1573	26018	\N	\N	58.046401000000003	поселок Карьер	Россия, Свердловская область, Тавдинский район, поселок Карьер	0101000020E6100000992B836A8346504038C0CC77F0054D40
86848	6	56	1573	26066	\N	\N	58.445436000000001	поселок Карабашка	Россия, Свердловская область, Тавдинский район, поселок Карабашка	0101000020E610000060E5D022DB6C5040043BFE0B04394D40
86846	6	56	1573	48079	\N	\N	58.000883999999999	поселок Земляное	Россия, Свердловская область, Тавдинский район, поселок Земляное	0101000020E6100000E0BE0E9C334450407A8B87F71C004D40
86804	6	56	1573	47275	\N	\N	58.093662999999999	деревня Герасимовка	Россия, Свердловская область, Тавдинский район, поселок Герасимовка	0101000020E61000002507EC6AF271504031EC3026FD0B4D40
86845	6	56	1573	25930	18412	\N	57.951726999999998	деревня Большая Пустынь, Советская, 18		0101000020E6100000338CBB41B44C50402FDCB930D2F94C40
86844	6	56	1573	25841	\N	\N	58.038127000000003	поселок Азанка	Россия, Свердловская область, Тавдинский район, поселок Азанка	0101000020E610000097ADF545423250401C0C7558E1044D40
86838	6	56	7049	50186	20203	\N	58.052683999999999	город Тавда, Герцена, 9		0101000020E6100000D656EC2FBB515040E0826C59BE064D40
86802	6	56	897	61320	78543	\N	58.8916729421965	Таборинский  район, д.УПавинская, Центральная ул, 23	Россия, Свердловская область, Таборинский район, поселок Унже-Павинская	0101000020E6100000BF2B82FFAD035040F4DC425722724D40
86819	6	56	897	24728	19914	\N	58.346677	Таборинский район, .д.Торомка, Лесная, 16	Россия, Свердловская область, Таборинский район, поселок Торомка	0101000020E610000087A6ECF48316504040A374E95F2C4D40
86810	6	56	897	6924	19900	\N	58.521414	Таборинский  район, с.Таборы, Октябрьская ул, 65		0101000020E610000062D7F6764B23504099D6A6B1BD424D40
82498	6	56	897	6924	17796	\N	58.5162499375515	деревня Таборы, Молодежная, 171	Россия, Свердловская область, Таборинский район, поселок Таборы	0101000020E61000003DD34B8C65225040AE47E17A14424D40
86801	6	56	897	6924	18857	\N	58.521414	"""Таборинский, Таборы, Красноармейская 5. Ф/х """"Шпуровых""""  """		0101000020E610000062D7F6764B23504099D6A6B1BD424D40
86813	6	56	897	24428	18590	\N	58.614986000000002	Таборинский  район, д.Пальмино, Центральная ул, 38		0101000020E6100000661536035C3D5040BABF7ADCB74E4D40
86806	6	56	897	23978	18156	\N	58.827464999999997	Таборинский  район, д.Озерки, Центральная ул, 27		0101000020E61000000E4DD9E907185040D5CA845FEA694D40
86816	6	56	897	24531	20331	\N	58.271057999999996	Таборинский район, д.Оверино, Советская ул, 13		0101000020E6100000263ACB2C42315040DAA84E07B2224D40
86812	6	56	897	24275	18166	\N	58.461793	Таборинский  район, д.Кузнецово, Южная ул, 19		0101000020E61000003621AD31E8315040C84274081C3B4D40
86817	6	56	897	24572	18595	\N	58.269570999999999	Таборинский район, д.Добрино, Центральная ул, 15		0101000020E6100000471D1D57231750409A79724D81224D40
86795	6	56	611	23524	20319	\N	56.30077	село Щелкун, Ленина, 178		0101000020E6100000921FF12BD6784E4018CFA0A17F264C40
86794	6	56	611	23456	78428	\N	56.600098000000003	село Черданцево, Ленина, 58		0101000020E610000096E99788B7784E409032E202D04C4C40
86750	6	56	611	61109	78446	\N	56.502820404415203	Сысертский городской округ, Энгельса, 153	Россия, Свердловская область, Сысертский район, Сысерть	0101000020E610000065E1EB6B5D684E402AE3DF675C404C40
95004	6	56	611	46984	78583	\N	56.691439000000003	село Патруши, Колхозная, 1		0101000020E6100000E066F16261664E40E816BA1281584C40
86790	6	56	611	50152	20109	\N	56.691439000000003	село Патруши, Колхозная, 23		0101000020E6100000E066F16261664E40E816BA1281584C40
86785	6	56	611	46892	20103	\N	56.243018999999997	село Новоипатово, Мира, 3		0101000020E610000052616C21C8894E403FA7203F1B1F4C40
86783	6	56	611	46842	18844	\N	56.259579238596302	село Никольское, 1Мая, 76Б	Россия, Свердловская область, Сысертский район, поселок Никольское	0101000020E6100000840D4FAF94754E403CDD79E239214C40
86676	6	56	611	50123	19982	\N	56.629945999999997	деревня Ключи, Ленина, 40	Россия, Свердловская область, Сысертский район, поселок Ключи	0101000020E610000090BFB4A84F884E407D1F0E12A2504C40
86781	6	56	611	46812	\N	\N	56.535387999999998	деревня Кашино, Ленина, 47	Россия, Свердловская область, Сысертский район, поселок Кашино	0101000020E610000029E78BBD176F4E40DE550F9887444C40
86780	6	56	611	22809	20306	\N	56.597099999999998	поселок Двуреченск, Озерная, 13	Россия, Свердловская область, Сысертский район, поселок Двуреченск	0101000020E61000009CC58B85218C4E408638D6C56D4C4C40
86779	6	56	611	22809	18387	\N	56.597099999999998	поселок Двуреченск, Клубная, 12		0101000020E61000009CC58B85218C4E408638D6C56D4C4C40
86778	6	56	611	22738	18733	\N	56.4368452182376	поселок Верхняя Сысерть, Ленина, 22	Россия, Свердловская область, Сысертский район, поселок Верхняя Сысерть	0101000020E6100000EE7BD45FAF604E40E7357689EA374C40
86784	6	56	611	46869	18131	\N	56.253162000000003	деревня Верхняя Боевка, Ленина, 2		0101000020E610000012BC218D0A7C4E40844BC79C67204C40
86791	6	56	611	47021	19122	\N	56.673614999999998	село Бородулино, Садовая, 2		0101000020E6100000CFBC1C76DF674E402A8C2D0439564C40
86777	6	56	611	46689	18530	\N	56.720148000000002	поселок Большой Исток, Трудова, 48		0101000020E610000051F86C1D1C624E40D12346CF2D5C4C40
86775	6	56	611	46689	19112	\N	56.720148000000002	поселок Большой Исток, Степана Разина, 11А		0101000020E610000051F86C1D1C624E40D12346CF2D5C4C40
95005	6	56	611	46689	78584	\N	56.720148000000002	поселок Большой Исток, Советская 38.		0101000020E610000051F86C1D1C624E40D12346CF2D5C4C40
86776	6	56	611	46689	20314	\N	56.713747907681601	поселок Большой Исток, Ленина, 119	Россия, Свердловская область, Сысертский район, поселок Большой Исток	0101000020E61000009A7ADD2230664E40EFCA2E185C5B4C40
86793	6	56	611	23366	19887	\N	56.653289000000001	деревня Большое Седельниково, Лесная, 318		0101000020E610000082E15CC30C5B4E4014EB54F99E534C40
86792	6	56	611	23366	77087	\N	56.653289000000001	деревня Большое Седельниково, 1 Мая, 3		0101000020E610000082E15CC30C5B4E4014EB54F99E534C40
86773	6	56	611	46623	18834	\N	56.674075000000002	поселок Бобровский, переулок Советский, 9		0101000020E61000009694BBCFF17B4E408E06F01648564C40
86772	6	56	611	46623	18681	\N	56.674075000000002	поселок Бобровский, Калинина, 1А		0101000020E61000009694BBCFF17B4E408E06F01648564C40
86771	6	56	611	22456	78510	\N	56.474639000000003	поселок Асбест, Пролетарская, 5		0101000020E6100000F67B629D2A434E40FD3383F8C03C4C40
87054	6	56	611	3879	19286	\N	56.713054	поселок Арамиль, Станционная, 1Е		0101000020E61000000D8E9257E7764E4018247D5A455B4C40
87118	6	56	611	3879	18473	\N	56.713054	поселок Арамиль, Свердлова, 8Б		0101000020E61000000D8E9257E7764E4018247D5A455B4C40
87116	6	56	611	3879	19181	\N	56.701822492682801	город Арамиль, Садовая, 10	Россия, Свердловская область, Сысертский район, Арамиль	0101000020E61000003317B83CD66C4E4081CEA44DD5594C40
87114	6	56	611	3879	19843	\N	56.6992288161345	город Арамиль, Рабочая, 120А	Россия, Свердловская область, Сысертский район, Арамиль	0101000020E61000009DD497A59D6C4E4018B5FB5580594C40
87111	6	56	611	3879	19063	\N	56.689432034595001	город Арамиль, Красноармейская, 118	Россия, Свердловская область, Сысертский район, Арамиль	0101000020E610000000E31934F46B4E406E68CA4E3F584C40
87107	6	56	611	3879	18642	\N	56.693451000000003	город Арамиль, Космонавтов, 9/4		0101000020E61000008908FF22686C4E4073309B00C3584C40
87109	6	56	611	3879	18955	\N	56.693451000000003	город Арамиль, 1 Мая, 60		0101000020E61000008908FF22686C4E4073309B00C3584C40
87105	6	56	611	3879	18955	\N	56.695118705657102	город Арамиль, 1 Мая, 12	Россия, Свердловская область, Сысертский район, Арамиль	0101000020E610000038328FFCC16A4E4003EACDA8F9584C40
86797	6	56	611	61293	78273	\N	56.323576000000003	село Аверино, Советская, 96	Россия, Свердловская область, Сысертский район, поселок Аверинское	0101000020E610000004029D499B844E40A0E238F06A294C40
86796	6	56	611	61337	78601	\N	56.376731549218498	село Абрамово, Ленина, 50А	Россия, Свердловская область, Сысертский район, поселок Абрамовское	0101000020E6100000EFC9C342AD814E40A7AD11C138304C40
89222	6	56	1189	49930	18483	\N	56.920542530463401	город Сухой Лог, деревня Шата, Ленина, 10	Россия, Свердловская область, Сухоложский район, поселок Шата	0101000020E61000008EAD6708C7FA4E40E7C75F5AD4754C40
89241	6	56	1189	49853	17874	\N	56.8459043517908	город Сухой Лог, село Филатовское, Ленина, 70А	Россия, Свердловская область, Сухоложский район, поселок Филатовское	0101000020E610000086AE44A0FA254F401DC70F95466C4C40
89213	6	56	1189	11383	\N	\N	56.885396999999998	город Сухой Лог, переулок Школьный, 2	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89204	6	56	1189	11383	18011	\N	56.885396999999998	город Сухой Лог, Юбилейная, 2		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89201	6	56	1189	11383	18011	\N	56.885396999999998	город Сухой Лог, Юбилейная, 5		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89211	6	56	1189	11383	18463	\N	56.885396999999998	город Сухой Лог, Кунарская, 2		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89189	6	56	1189	11383	17769	\N	56.909793326146897	город Сухой Лог, Горького, 11	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E6100000A087DA368C044F409B90D61874744C40
89187	6	56	1189	11383	18007	\N	56.8935714401943	город Сухой Лог, Артиллеристов, 36 б	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E61000009D47C5FF1D054F40B7D3D68860724C40
89245	6	56	1189	11383	18137	\N	56.885396999999998	Свердловская область, город Сухой Лог, село Талица, 8 Марта, 43		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89199	6	56	1189	49931	18494	\N	56.885396999999998	город Сухой Лог, Юбилейная, 8а		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89198	6	56	1189	49931	18494	\N	56.890433824555501	город Сухой Лог, Юбилейная, 23а	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E6100000DA907F6610054F408C9FC6BDF9714C40
89193	6	56	1189	49931	18494	\N	56.885396999999998	город Сухой Лог, Юбилейная, 10		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89209	6	56	1189	49931	18779	\N	56.885396999999998	город Сухой Лог, Победы, 4		0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89205	6	56	1189	49931	19057	\N	56.885396999999998	город Сухой Лог, Кирова, 7б	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89239	6	56	1189	49931	78525	\N	56.907539458583102	город Сухой Лог, деревня Сергуловка, Ворошилова, 18а	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E6100000CF656A12BC034F401A6CEA3C2A744C40
89191	6	56	1189	49931	18795	\N	56.885396999999998	город Сухой Лог, Белинского, 41	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E6100000DDB243FCC3044F40FE7C5BB054714C40
89185	6	56	1189	49931	19007	\N	56.893712363822701	город Сухой Лог, 93 Стрелковой бригады, 7	Россия, Свердловская область, Сухоложский район, Сухой Лог	0101000020E610000064B0E2546B054F407905A22765724C40
89229	6	56	1189	49959	18811	\N	56.927031954781597	город Сухой Лог, село Светлое, Ленина, 17	Россия, Свердловская область, Сухоложский район, поселок Светлое	0101000020E61000007C7F83F6EAE54E40382C0DFCA8764C40
89220	6	56	1189	49985	19185	\N	56.983362613815601	город Сухой Лог, село Рудянское, Калинина, 13	Россия, Свердловская область, Сухоложский район, поселок Рудянское	0101000020E6100000D9D138D4EFF84E40588CBAD6DE7D4C40
89237	6	56	1189	49935	18508	\N	56.887811999999997	город Сухой Лог, село Новопышминское, Ильича, 6	Россия, Свердловская область, Сухоложский район, поселок Новопышминское	0101000020E61000005837DE1D191F4F40887FD8D2A3714C40
89230	6	56	1189	49925	18810	\N	56.913765325161897	город Сухой Лог, село Курьи, Школьная, 3	Россия, Свердловская область, Сухоложский район, поселок Курьи	0101000020E610000031D28BDAFD104F405E9D6340F6744C40
89235	6	56	1189	49925	18817	\N	56.91292	город Сухой Лог, село Курьи, Свердлова, 20	Россия, Свердловская область, Сухоложский район, поселок Курьи	0101000020E6100000E6797077D6104F40A2EE0390DA744C40
89233	6	56	1189	49925	18427	\N	56.913483629278304	город Сухой Лог, село Курьи, Батенева, 46	Россия, Свердловская область, Сухоложский район, поселок Курьи	0101000020E610000034A2B437F8104F40AAB5300BED744C40
89225	6	56	1189	49836	17775	\N	56.939829000000003	город Сухой Лог, село Знаменское, Горького, 19	Россия, Свердловская область, Сухоложский район, поселок Знаменское	0101000020E6100000541D7233DCF84E408C6A11514C784C40
89243	6	56	1189	49949	18715	\N	56.8485146912926	город Сухой Лог, деревня Заимка, Щепеткина, 1	Россия, Свердловская область, Сухоложский район, поселок Заимка	0101000020E61000000CE9F010C6174F402D95B7239C6C4C40
89226	6	56	1189	49885	\N	\N	56.897771120598001	город Сухой Лог, поселок ГляденыСанаторий, Помещение Винокурского участкового лесничества	Россия, Свердловская область, Сухоложский район	0101000020E61000003FA88B14CA044F400B26FE28EA724C40
89217	6	56	1189	49956	19360	\N	57.071652	город Сухой Лог, поселок Алтынай, Вокзальная, 54	Россия, Свердловская область, Сухоложский район, поселок Алтынай	0101000020E6100000BC24CE8AA8FD4E40B4588AE42B894C40
89215	6	56	1189	49956	18789	\N	57.0718365726228	город Сухой Лог, поселок Алтынай, 1 Мая, 40	Россия, Свердловская область, Сухоложский район, поселок Алтынай	0101000020E6100000DE0033DFC1FD4E4046D26EF431894C40
86662	6	56	7022	50121	19975	\N	58.798910008860801	Сосьвинский городской округ, п. Восточный, пер. Парковый, 1		0101000020E61000003C84F1D3B8E74E404339D1AE42664D40
86654	6	56	7001	49944	18629	\N	59.173492021917099	Сосьвинский городской округ, р.п. Сосьва, Толмачева, 34	Россия, Свердловская область, Серовский район, поселок Сосьва	0101000020E61000003C6BB75D68EC4E400F0F61FC34964D40
86748	6	56	1580	49993	\N	\N	57.559852469263902	СлободоТуринский муниципальный район, Ницинское сельское поселение,д.Юрты, Школасад	Россия, Свердловская область, Слободо-Туринский район, поселок Юрты	0101000020E6100000C7D5C8AEB4065040D34CF73AA9C74C40
85843	6	56	1580	46447	78515	\N	57.422635999999997	с. Шадринка, Лаптева, 9		0101000020E6100000420A9E42AE3050405E0EBBEF18B64C40
86741	6	56	1580	20985	18525	\N	57.675989000000001	СлободоТуринский муниципальный район, СлободоТуринское сельское поселение, с.Храмцово, Новая, 2а		0101000020E61000002B4CDF6B0814504056BABBCE86D64C40
86709	6	56	1580	61300	78460	\N	57.478100003802801	СлободоТуринский муниципальный район, УстьНицинское сельское поселение, с. УстьНицинское, Школьная, 8	Россия, Свердловская область, Слободо-Туринский район, поселок Усть-Ницинское	0101000020E61000004DDC2A8881215040DA1B7C6132BD4C40
86744	6	56	1580	49950	77270	\N	57.615657685113803	СлободоТуринский муниципальный район, СлободоТуринское сельское поселение, с.Туринская Слобода, Советская, 96	Россия, Свердловская область, Слободо-Туринский район, поселок Туринская Слобода	0101000020E61000004016A243E0185040A9C29FE1CDCE4C40
86742	6	56	1580	49950	77443	\N	57.618467202667901	СлободоТуринский муниципальный район, СлободоТуринское сельское поселение, с.Туринская Слобода, Ленина, 3	Россия, Свердловская область, Слободо-Туринский район, поселок Туринская Слобода	0101000020E610000005F86EF3C6185040DF5339ED29CF4C40
86713	6	56	1580	19414	17836	\N	57.553110852692299	СлободоТуринский муниципальный район, СлободоТуринское сельское поселение, с. Тимофеево, Ленина, 1	Россия, Свердловская область, Слободо-Туринский район, поселок Тимофеево	0101000020E6100000280AF4893C20504068075C57CCC64C40
86734	6	56	1580	61302	78467	\N	57.753259	СлободоТуринский муниципальный район, Сладковское сельское поселение, Ленина, 13	Россия, Свердловская область, Слободо-Туринский район, поселок Сладковское	0101000020E610000097530262120E5040763579CA6AE04C40
86703	6	56	1580	18995	78542	\N	57.482487487346603	СлободоТуринский муниципальный район, СлободоТуринское сельское поселение, д.Решетникова, Школьная, 29	Россия, Свердловская область, Слободо-Туринский район, поселок Решетникова (Симахина)	0101000020E61000002A1DACFF7332504061DF4E22C2BD4C40
85829	6	56	836	46131	19106	\N	57.398654000000001	с.Байкалово, Кузнецова, 30		0101000020E61000008B8A389D64E14F40B535221807B34C40
86729	6	56	1580	50141	20061	\N	57.776999000000004	СлободоТуринский муниципальный район, Сладковское сельское поселение, с.Пушкарево, 45 лет Победы, 54		0101000020E6100000E9B5D958890150402A0307B474E34C40
86726	6	56	1580	20164	18761	\N	57.530723000000002	СлободоТуринский муниципальный район, Ницинское сельское поселение, с.Ницинское, Озерная, 27		0101000020E6100000A988D349B60B5040151E34BBEEC34C40
86737	6	56	1580	20852	17900	\N	57.7967508179361	СлободоТуринский муниципальный район, Сладковское сельское поселение, д.Макуй, Центральный, 1	Россия, Свердловская область, Слободо-Туринский район, поселок Макуй	0101000020E61000007FBDC282FB1050401407D0EFFBE54C40
86705	6	56	1580	19106	20038	\N	57.385092	СлободоТуринский муниципальный район, УстьНицинское сельское поселение, с.Липчинское, Ленина, 14		0101000020E6100000812381069B2F5040C2F9D4B14AB14C40
86733	6	56	1580	20548	18257	\N	57.792670000000001	СлободоТуринский муниципальный район, Сладковское сельское поселение, с. Куминовское, Советская, 5		0101000020E61000004DBED9E6C60650409A42E73576E54C40
86715	6	56	1580	19520	17885	\N	57.583204069269598	СлободоТуринский муниципальный район, СлободоТуринское сельское поселение, д. Красный Яр, Школа, 14	Россия, Свердловская область, Слободо-Туринский район, поселок Красный Яр	0101000020E61000004966F50EB71F5040BD72BD6DA6CA4C40
86722	6	56	1580	19883	19386	\N	57.513086999999999	СлободоТуринский муниципальный район, УстьНицинское сельское поселение, с.Краснослободское, Октябрьская, 40		0101000020E6100000787B1002F21450405A80B6D5ACC14C40
86727	6	56	1580	20232	19212	\N	57.623204999999999	Свердловская область, СлободоТуринский муниципальный район, Ницинское сельское поселение, п.Звезда,Новая, 1		0101000020E610000000AE64C7460A504012DA722EC5CF4C40
86711	6	56	1580	19412	\N	\N	57.500517170300398	СлободоТуринский муниципальный район, УстьНицинское сельское поселение, д. Жирякова, школасад, 31	Россия, Свердловская область, Слободо-Туринский район, поселок Жирякова	0101000020E6100000425E0F26C5235040C80BE9F010C04C40
86716	6	56	1580	19627	\N	\N	57.412258710698403	СлободоТуринский муниципальный район, УстьНицинское сельское поселение, д.Ермакова, дом Культуры	Россия, Свердловская область, Слободо-Туринский район, поселок Ермакова	0101000020E6100000BEDC274701135040A73D25E7C4B44C40
86720	6	56	1580	19838	\N	\N	57.444902999999996	СлободоТуринский муниципальный район, УстьНицинское сельское поселение, д. Голякова, дом Культуры, 35		0101000020E61000004FE61F7D931A50403672DD94F2B84C40
86723	6	56	1580	20052	19365	\N	57.501261	СлободоТуринский муниципальный район, Ницинское сельское поселение,с. Бобровское, Бобровская, 1		0101000020E61000008B19E1ED410A504050E1085229C04C40
86738	6	56	1580	20918	18436	\N	57.7306049098109	Свердловская область, СлободоТуринский муниципальный район, Сладковское сельское поселение, д.Андронова, Центральная, 39	Россия, Свердловская область, Слободо-Туринский район, поселок Андронова	0101000020E61000007BF7C77BD5115040A4A5F27684DD4C40
86747	6	56	7036	50217	20310	\N	57.621764653384403	СлободоТуринский муниципальный район, СлободоТуринское сельское поселение, с.Туринская Слобода, Дегтева, 1	Россия, Свердловская область, Слободо-Туринский район, поселок Туринская Слобода	0101000020E6100000685E0EBBEF1850401366DAFE95CF4C40
89161	6	56	1490	49916	18325	\N	59.6049823289516	город Серов, поселок Черноярский, Заводская, 1а	Россия, Свердловская область, Серовский район, поселок Черноярский	0101000020E61000005A2BDA1CE7624E409755D80C70CD4D40
86659	6	56	1490	49873	18111	\N	59.175117341948699	Сосьвинский городской округ, р.п. Ссоьва, Свободы, 75	Россия, Свердловская область, Серовский район, поселок Сосьва	0101000020E6100000713C9F01F5EC4E40A0FCDD3B6A964D40
86661	6	56	1490	49873	17961	\N	59.173492000000003	Сосьвинский городской округ, р.п. Ссоьва, Ленина, 100	Россия, Свердловская область, Серовский район, поселок Сосьва	0101000020E61000001557957D57EC4E400F0F61FC34964D40
86653	6	56	1490	49873	18393	\N	59.181521611315503	Сосьвинский городской округ, р.п. Сосьва, Ленина, 2а	Россия, Свердловская область, Серовский район, поселок Сосьва	0101000020E610000097715303CDED4E4094C0E61C3C974D40
86657	6	56	1490	49873	18925	\N	59.172610791813298	Сосьвинский городской округ, р.п. Сосьва, Балдина, 49	Россия, Свердловская область, Серовский район, поселок Сосьва	0101000020E610000066118AADA0EB4E4006F7031E18964D40
86695	6	56	1490	18528	19331	\N	59.371571000000003	Серовский район, д.Семенова, Зеленая, 41		0101000020E610000072C45A7C0A884E402E9276A38FAF4D40
86688	6	56	1490	49992	19346	\N	59.147113239796198	Сосьвинский городской округ, с. Романово, Центральная, 43	Россия, Свердловская область, Серовский район, поселок Романово	0101000020E6100000016A6AD95AC14E4081E84999D4924D40
86694	6	56	1490	18462	17847	\N	59.424545999999999	Серовский район, д.Поспелкова, Школьная, 10		0101000020E610000090149161156F4E40E5D2F88557B64D40
86682	6	56	1490	17859	18670	\N	59.489781000000001	Серовский район, пос.Первомайский, Советская, 20		0101000020E6100000C45BE7DF2EB34E40E199D024B1BE4D40
86690	6	56	1490	49971	18992	\N	59.274319495693398	Сосьвинский городской округ, п. Пасынок, Теплоухова, 1	Россия, Свердловская область, Серовский район, поселок Пасынок	0101000020E6100000DF6C73637ABA4E40F1D58EE21CA34D40
86692	6	56	1490	18352	20406	\N	59.395462000000002	Серовский район, д.Морозково, Советская, 9		0101000020E610000016C26A2C617D4E40C767B27F9EB24D40
86698	6	56	1490	49864	17921	\N	59.286850237665803	Сосьвинский городской округ, д. Маслова, Новая, 5	Россия, Свердловская область, Серовский район, поселок Маслова	0101000020E6100000CDE506431DA44E40C66D3480B7A44D40
86427	6	56	781	5504	19188	\N	59.053845000000003	Новолялинский район, г. Новая Ляля, Лермонтова, 22		0101000020E610000093A641D13C4C4E40CD069964E4864D40
86672	6	56	1490	17377	19964	\N	59.9218218611135	Серовский район, пос.Ларьковка, Вокзальная, 41	Россия, Свердловская область, Серовский район, поселок Ларьковка	0101000020E6100000C4EC65DB69494E40DD5D6743FEF54D40
86674	6	56	1490	17460	19279	\N	59.843403000000002	Серовский район, пос.Красный Яр, Октябрьская, 35		0101000020E61000001538D906EE5C4E40952C27A1F4EB4D40
86677	6	56	1490	17622	18964	\N	59.424089000000002	Серовский район, пос.Красноярка, Ленина, 14		0101000020E610000014AE47E17A424E40F3CB608C48B64D40
86680	6	56	1490	17767	18313	\N	59.388567000000002	Серовский район, пос.Красноглинный, Садовая, 15		0101000020E61000005AD93EE42D9F4E4005A73E90BCB14D40
86685	6	56	1490	50193	20214	\N	59.084195756107299	Сосьвинский городской округ, с. Кошай, Ворошилова, 50	Россия, Свердловская область, Серовский район, поселок Кошай	0101000020E6100000BDE13E726BEE4E401D3A3DEFC68A4D40
86701	6	56	1490	18840	19291	\N	59.642603999999999	Серовский район, пос.Ключевой, Колхозная, 19а		0101000020E6100000B66455849B324E40AF230ED940D24D40
86700	6	56	1490	18783	19004	\N	59.734430000000003	Серовский район, пос.Еловка Новая, Набережная, 9		0101000020E6100000FDF50A0BEE494E40C4995FCD01DE4D40
86195	6	56	1490	40380	\N	\N	58.795327	п.Восточный, Комарова, 17	Россия, Свердловская область, Серовский район, поселок Восточный	0101000020E610000032384A5E9DE74E401A506F46CD654D40
86664	6	56	1490	40380	18471	\N	58.795801638244001	Сосьвинский городской округ, п. Восточный, пер. Парковый, 2	Россия, Свердловская область, Серовский район, поселок Восточный	0101000020E61000007E9065C1C4E74E40B30B06D7DC654D40
86666	6	56	1490	40380	18435	\N	58.795327	Сосьвинский городской округ, п. Восточный, Пушкина, 1	Россия, Свердловская область, Серовский район, поселок Восточный	0101000020E610000032384A5E9DE74E401A506F46CD654D40
86669	6	56	1490	40380	18246	\N	58.795327	Сосьвинский городской округ, п. Восточный, Ленина, 11	Россия, Свердловская область, Серовский район, поселок Восточный	0101000020E610000032384A5E9DE74E401A506F46CD654D40
86684	6	56	1490	17918	18324	\N	59.545603999999997	Серовский район, пос.Боровой, Центральная, 14		0101000020E61000000ADAE4F049B34E408C48145AD6C54D40
86670	6	56	7046	50183	20196	\N	60.0453024331254	Серовский район, пос.Марсяты, Зеленая, 15		0101000020E61000002E1F49490F3D4E40C138B874CC054E40
86647	6	56	1347	48640	\N	\N	57.447164999999998	с.Черемисское, Дом культуры		0101000020E61000004B1E4FCB0F724E403A75E5B33CB94C40
86645	6	56	1347	48603	\N	\N	57.495055999999998	д.Фирсово, Клуб		0101000020E6100000ADA7565F5D8D4E4023D8B8FE5DBF4C40
86640	6	56	1347	48520	\N	\N	57.486808000000003	д.Сохарево, Клуб		0101000020E61000001406651A4DC24E4031B77BB94FBE4C40
86160	6	56	1347	24729	19033	\N	57.474173999999998	Каменский район, д.Соколово, Садовая, 1		0101000020E61000009FE8BAF0839D4E40874ECFBBB1BC4C40
86650	6	56	1347	14450	\N	\N	57.337620776562503	Реж, п. Первомайский	Россия, Свердловская область, Режевский район, Реж	0101000020E6100000C24F1C40BFB34E40AEB8382A37AB4C40
86624	6	56	1347	14450	\N	\N	57.352840999999998	Реж, Костоусова, 82	Россия, Свердловская область, Режевский район, Реж	0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86628	6	56	1347	14450	18600	\N	57.358577354197003	Реж, Строителей, 13	Россия, Свердловская область, Режевский район, Реж	0101000020E61000006B9E23F25DB44E40840CE4D9E5AD4C40
86615	6	56	1347	14450	77082	\N	57.352840999999998	Реж, Спортивная, 8		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86612	6	56	1347	14450	20323	\N	57.362489522795101	Реж, Пушкина, 2а	Россия, Свердловская область, Режевский район, Реж	0101000020E6100000D00CE2033BB44E404390831266AE4C40
86620	6	56	1347	14450	20307	\N	57.369023043215002	Реж, Пионерская, 13	Россия, Свердловская область, Режевский район, Реж	0101000020E6100000041F8315A7B44E40643C4A253CAF4C40
86630	6	56	1347	14450	20059	\N	57.352840999999998	Реж, П.Морозова, 56		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86626	6	56	1347	14450	77074	\N	57.352840999999998	Реж, О.Кошевого, 9		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86621	6	56	1347	14450	18587	\N	57.352840999999998	Реж, ул.Металлургов, 8		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86616	6	56	1347	14450	19129	\N	57.352840999999998	Реж, Ленина, 2		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86613	6	56	1347	14450	19129	\N	57.352840999999998	Реж, Ленина, 30		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86627	6	56	1347	14450	18876	\N	57.352840999999998	Реж, Калинина, 19б		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86625	6	56	1347	14450	18876	\N	57.359521009317199	Реж, Калинина, 47	Россия, Свердловская область, Режевский район, Реж	0101000020E6100000E2016553AEB44E40D49CBCC804AE4C40
86619	6	56	1347	14450	20102	\N	57.352840999999998	Реж, Зеленая, 90		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86623	6	56	1347	14450	77084	\N	57.352840999999998	Реж, Заводская, 3		0101000020E6100000D00CE2033BB44E400ED8D5E429AD4C40
86651	6	56	1347	48720	\N	\N	57.427478000000001	с. Першино, Клуб		0101000020E61000002F8B89CDC7BB4E4037E15E99B7B64C40
86638	6	56	1347	48480	\N	\N	57.483193999999997	д.Ощепково, Клуб		0101000020E610000064213A048EBA4E40CCCF0D4DD9BD4C40
86646	6	56	1347	46721	19943	\N	57.422220000000003	с.Останино, Школа №8	Россия, Свердловская область, Режевский район, поселок Останино	0101000020E6100000F03504C765A84E40CBDB114E0BB64C40
85627	6	56	1347	46721	18125	\N	57.422220000000003	село Останино, Ленина, 14		0101000020E6100000F03504C765A84E40CBDB114E0BB64C40
86649	6	56	1347	48685	\N	\N	57.403517000000001	с.Октябрьское, Дом культуры		0101000020E610000041446ADAC57A4E40A530EF71A6B34C40
86644	6	56	1347	50231	\N	\N	57.448340735853698	с.Липовское, Школа №9	Россия, Свердловская область, Режевский район, поселок Липовское	0101000020E610000058A835CD3B964E405C3AE63C63B94C40
86641	6	56	1347	15813	\N	\N	57.587310000000002	с.Леневское, Дом культуры		0101000020E610000069AB92C83EB04E40904E5DF92CCB4C40
86633	6	56	1347	15401	19169	\N	57.265939000000003	п.Костоусово, Советская, 3, Дом культуры	Россия, Свердловская область, Режевский район, поселок Костоусово	0101000020E610000053B0C6D9749C4E4090DD054A0AA24C40
86648	6	56	1347	16168	\N	\N	57.405850000000001	д.Колташи, Клуб		0101000020E6100000E7C8CA2F836F4E40728A8EE4F2B34C40
86642	6	56	1347	15888	\N	\N	57.522402	с.Клевакинское, Школа № 30		0101000020E610000085CE6BEC12AD4E40B8AE9811DEC24C40
86643	6	56	1347	40394	\N	\N	57.519452999999999	д.Каменка, Клуб		0101000020E610000037A79201A09E4E409067976F7DC24C40
86458	6	56	1347	40394	\N	\N	57.519452999999999	"""""""п. Каменка, Здание диспетчерской ЛЗУ ООО ЛПК """"""""УралЛобва"""""""""""""""		0101000020E610000037A79201A09E4E409067976F7DC24C40
86635	6	56	1347	49963	\N	\N	57.448805442664103	д.Голендухино, Школа № 23	Россия, Свердловская область, Режевский район, поселок Голендухино	0101000020E6100000FAB9A1293BB54E4001A4367172B94C40
86637	6	56	1347	48475	\N	\N	57.481515000000002	с.Глинское, Дом культуры		0101000020E61000005A12A0A696B54E4048C49448A2BD4C40
86639	6	56	1347	15770	\N	\N	57.528326	с.Арамашка, Школа №27		0101000020E6100000586FD40AD3BF4E4031D0B52FA0C34C40
86634	6	56	7058	50204	\N	\N	56.684953	пос. Озерный, Школа № 46		0101000020E610000028452BF702A94E400726378AAC574C40
86548	6	56	1142	11394	18812	\N	57.008799000000003	Пышминский район, с.Юрмытское, Кирова, 52		0101000020E61000003BA759A0DD894F40679E5C5320814C40
86556	6	56	1142	11773	18019	\N	57.008772740561902	Свердловская область, Пышминский район, с.Чупино, Павлика Морозова, 2а	Россия, Свердловская область, Пышминский район, поселок Чупино	0101000020E6100000454772F90FB14F403D0B42791F814C40
86570	6	56	1142	12485	19838	\N	56.734557360068003	Пышминский район, с.Четкарино, Советская, 26	Россия, Свердловская область, Пышминский район, поселок Четкарино	0101000020E61000004F0306499F904F402106BAF6055E4C40
86560	6	56	1142	11994	18028	\N	56.919887000000003	Пышминский район, с.Чернышово, Ленина, 2		0101000020E610000056293DD34B9E4F40FE8172DBBE754C40
86563	6	56	1142	12160	19350	\N	56.856737000000003	Пышминский район, с.Черемыш, Ленина, 56		0101000020E61000001FF7ADD689874F40F722DA8EA96D4C40
86544	6	56	1142	11229	18059	\N	57.064419999999998	Пышминский район, д.Холкина, Карла Маркса, 15а	Россия, Свердловская область, Пышминский район, поселок Холкина	0101000020E6100000CD3AE3FBE2804F40AA9A20EA3E884C40
86568	6	56	1142	12352	18062	\N	56.817942000000002	Пышминский район, с.Тупицино, Ленина, 16		0101000020E610000002D369DD06974F402E03CE52B2684C40
86550	6	56	1142	11560	19043	\N	56.986344000000003	Свердловская область, Пышминский район, с.Трифоново, Ленина, 93		0101000020E610000029EB3713D3934F408C4D2B85407E4C40
86562	6	56	1142	11479	18047	\N	56.899385000000002	Свердловская область, Пышминский район, с.Тимохинское, Халтурина, 2		0101000020E610000008556AF640954F40A9C1340C1F734C40
86542	6	56	1142	11142	18771	\N	57.110056	Пышминский район,д.Талица, Калинина, 38		0101000020E6100000473CD9CD8C844F40425DA450168E4C40
86582	6	56	1142	12974	19363	\N	56.752594999999999	Пышминский район, д.Речелга, Школьный переулок, 3		0101000020E610000076C075C58CB04F400A11700855604C40
86536	6	56	1142	10683	17986	\N	56.955925932792901	Пышминский район, р.п.Пышма, Куйбышева, 42	Россия, Свердловская область, Пышминский район, поселок Пышма	0101000020E61000006ADC9BDF309F4F40B3B27DC85B7A4C40
86534	6	56	1142	10683	17986	\N	56.955975000000002	Пышминский район, р.п.Пышма, Куйбышева, 46		0101000020E610000056D5CBEF349F4F40956588635D7A4C40
86532	6	56	1142	10683	17986	\N	56.955975000000002	Пышминский район, р.п.Пышма, Куйбышева, 39	Россия, Свердловская область, Пышминский район, поселок Пышма	0101000020E610000056D5CBEF349F4F40956588635D7A4C40
86537	6	56	1142	10683	19378	\N	56.955975000000002	Пышминский район, р.п.Пышма, Комарова, 19		0101000020E610000056D5CBEF349F4F40956588635D7A4C40
86540	6	56	1142	10683	17920	\N	56.955975000000002	Пышминский район, р.п.Пышма, Бабкина, 3А		0101000020E610000056D5CBEF349F4F40956588635D7A4C40
86557	6	56	1142	11853	18024	\N	56.984127999999998	Пышминский район, д.Пылаева, 50 лет Октября, 33		0101000020E6100000F8A57EDE54AA4F40F88903E8F77D4C40
86554	6	56	1142	11667	18443	\N	57.101852999999998	Пышминский район, с.Пульниково, Школьная, 6		0101000020E610000098A7734529A34F40EFFFE384098D4C40
86546	6	56	1142	11329	18914	\N	57.031494000000002	Пышминский район, с.Печеркино, Буденного, 5		0101000020E6100000E3A9471ADC824F409702D2FE07844C40
86574	6	56	1142	12641	18477	\N	56.730162999999997	Пышминский район, п.Первомайский, Ленина, 10		0101000020E610000027A5A0DB4B824F40E7DF2EFB755D4C40
86579	6	56	1142	12925	18077	\N	56.617041	Пышминский район, д.Мартынова, Молодежная, 1а		0101000020E61000004DBF44BC759C4F4044A51133FB4E4C40
86572	6	56	1142	12580	18372	\N	56.7545	Пышминский район, д.Комарова, Школьный переулок, 2		0101000020E6100000F38E5374248F4F407F6ABC7493604C40
86551	6	56	1142	11609	\N	\N	57.018825	Свердловская область, Пышминский район, д.Катарач, Центральная, 33	Россия, Свердловская область, Пышминский район, поселок Катарач	0101000020E6100000D0ED258DD19C4F4071AC8BDB68824C40
86876	6	56	1142	11609	18708	\N	57.018825	село Катарач, Центральная, 43		0101000020E6100000D0ED258DD19C4F4071AC8BDB68824C40
86566	6	56	1142	12259	20068	\N	56.834826	Пышминский район, д.Духовая, Механизаторов, 261		0101000020E610000093A9825149834F40DDEC0F94DB6A4C40
86577	6	56	1142	12851	19084	\N	56.641148999999999	Пышминский район, с.Боровлянское, Ленина, 27		0101000020E6100000A88B14CAC2954F407A6EA12B11524C40
86523	6	56	340	10250	\N	\N	57.621335000000002	с. Южаково, Советская, 11	Россия, Свердловская область, Пригородный район, поселок Южаково	0101000020E6100000DE3AFF76D97F4E401A6EC0E787CF4C40
86489	6	56	340	61341	78623	\N	57.637405000000001	д. Верхняя Шумиха, Гаражная, 7	Россия, Свердловская область, Пригородный район, поселок Шумиха	0101000020E6100000F436363B52454E4048A7AE7C96D14C40
86501	6	56	340	49338	78602	\N	57.770223252060703	с. Шиловка, Ленина, 34	Россия, Свердловская область, Пригородный район, поселок Шиловка	0101000020E610000071C806D2C5164E4042D0D1AA96E24C40
86231	6	56	340	49338	18570	\N	57.771690999999997	деревня Шиловка, 1 Мая, 1		0101000020E6100000F415A4198B164E400BCF4BC5C6E24C40
86479	6	56	340	8117	19249	\N	57.729346	п. Черноисточинск, Юбилейная, 7А	Россия, Свердловская область, Пригородный район, поселок Черноисточинск	0101000020E6100000E10CFE7E31EF4D40F5BBB0355BDD4C40
86478	6	56	340	8117	19028	\N	57.729346	п. Черноисточинск, Кирова, 2А		0101000020E6100000E10CFE7E31EF4D40F5BBB0355BDD4C40
86522	6	56	340	10196	19126	\N	57.619503000000002	Пригородный район, д. УстьУтка, Советская, 2		0101000020E61000003C4B901150834D400F63D2DF4BCF4C40
86477	6	56	340	8051	18649	\N	57.652861999999999	Пригородный район, п. Уралец, Ленина, 10		0101000020E6100000001FBC7669D34D408C6665FB90D34C40
86490	6	56	340	8707	20010	\N	57.532235999999997	Пригородный район, с. Сулем, Гагарина, 52		0101000020E6100000EE26F8A6E98F4D407EE02A4F20C44C40
88757	6	56	340	22811	17805	\N	57.752884999999999	Пригородный район, п. Студеный, Мичурина, 7б		0101000020E6100000D15790662CEE4D40115322895EE04C40
86475	6	56	340	49538	20378	\N	57.895674166853397	п. Синегорский, ул. Мира, 6	Россия, Свердловская область, Пригородный район, поселок Синегорский	0101000020E61000004DDC2A8881C24D4052F01472A5F24C40
85644	6	56	340	1643	18106	\N	57.967937999999997	с. Покровское, Юбилейная, 1		0101000020E610000067B5C01E13214E401F477364E5FB4C40
86514	6	56	340	1643	18973	\N	57.967937999999997	с. Покровское, Школьная, 11А		0101000020E610000067B5C01E13214E401F477364E5FB4C40
86512	6	56	340	9632	19364	\N	57.710858999999999	с. Петрокаменское, Почтовая, 1А		0101000020E6100000DCB75A272E534E409C887E6DFDDA4C40
86510	6	56	340	9533	17799	\N	57.566809999999997	с. Новопаньшино, Советская, б/н		0101000020E61000004D327216F6704E40DB85E63A8DC84C40
86525	6	56	340	10396	19379	\N	57.746637	п. Новоасбест, Пионерская, 8		0101000020E61000007DB08C0DDD244E40E57D1CCD91DF4C40
86485	6	56	340	8501	18991	\N	57.628216999999999	д. Новая Башкарка, Уральская, 5		0101000020E61000008F1B7E37DD684E4047E5266A69D04C40
86500	6	56	340	22910	19994	\N	57.787066000000003	с. НиколоПавловское, Юбилейная, 11А		0101000020E6100000BA85AE44A0064E4093E52494BEE44C40
86499	6	56	340	22910	78588	\N	57.787066000000003	с. НиколоПавловское, Совхозная, 4	Россия, Свердловская область, Пригородный район, поселок Николо-Павловское	0101000020E6100000BA85AE44A0064E4093E52494BEE44C40
86497	6	56	340	50114	19941	\N	57.690102000000003	с. Мурзинка, Декабристов, 5	Россия, Свердловская область, Пригородный район, поселок Мурзинка	0101000020E6100000723106D671824E40BD73284355D84C40
86484	6	56	340	8417	19345	\N	57.689028999999998	с. Мокроусское, Ленина, 3А		0101000020E610000060C77F8120684E406F7F2E1A32D84C40
86901	6	56	340	49069	20257	\N	57.517505	деревня Маркова, Мира, 46		0101000020E610000000C45DBD8A6E4E401C42959A3DC24C40
86496	6	56	340	9004	20397	\N	58.120192000000003	с. Малая Лая, Ленина, 60		0101000020E610000041D5E8D500F14D40D49E9273620F4D40
86506	6	56	340	9399	18274	\N	57.742942999999997	п. Леневка, Центральная, 201	Россия, Свердловская область, Пригородный район, поселок Ленёвка	0101000020E6100000170FEF39B00A4E4064E597C118DF4C40
86474	6	56	340	7901	18840	\N	58.058345000000003	п. Лая, Привокзальная, 3а		0101000020E61000000114234BE6F64D404C7155D977074D40
86494	6	56	340	7901	18631	\N	58.058345000000003	с. Лая, Ленина, 1а		0101000020E61000000114234BE6F64D404C7155D977074D40
86492	6	56	340	45566	18970	\N	57.716363999999999	с. Краснополье, Красногвардейская, 32		0101000020E61000008B6B7C26FB3B4E401004C8D0B1DB4C40
86491	6	56	340	8773	18357	\N	57.562286	с. Кайгородское, Ленина, 103А		0101000020E6100000938D075BEC864E40D47FD6FCF8C74C40
86518	6	56	340	46109	19012	\N	57.887161999999996	п. Зональный, Центральная, 8		0101000020E61000009F9273620F0F4E40812040868EF14C40
86508	6	56	340	7760	\N	\N	58.069423999999998	Горноуральский городской округ, Уральская, 50	Россия, Свердловская область, Пригородный район, поселок Горноуральский	0101000020E61000000C91D3D7F3F34D405CC7B8E2E2084D40
86471	6	56	340	7760	\N	\N	58.069423999999998	рп. Горноуральский, Территориальная администрация п. Горноуральский, 49		0101000020E61000000C91D3D7F3F34D405CC7B8E2E2084D40
86521	6	56	340	7760	19335	\N	58.069423999999998	Свердловская область, Горноуральский городской округ, Уральская, 35		0101000020E61000000C91D3D7F3F34D405CC7B8E2E2084D40
86472	6	56	340	7760	19330	\N	58.069423999999998	рп. Горноуральский, Теририториальная администрация р.п. Горноуральский, 49		0101000020E61000000C91D3D7F3F34D405CC7B8E2E2084D40
86440	6	56	340	6329	18638	\N	57.680656999999997	Пригородный район, п. ВисимоУткинск, Ленина, 1		0101000020E61000005C0531D0B5AB4D409065C1C41FD74C40
86519	6	56	340	6805	19371	\N	57.650545999999999	п. Висим, МаминаСибиряка, 4		0101000020E6100000180B43E4F4BF4D409545611745D34C40
86486	6	56	340	45462	18305	\N	57.534038000000002	с. Бызово, Ленина, 4А		0101000020E61000004337FB03E5704E401F69705B5BC44C40
86487	6	56	340	45479	18718	\N	57.674016000000002	с. Бродово, Новая, 23		0101000020E610000069C9E369F94B4E40897D022846D64C40
86513	6	56	340	9735	18697	\N	57.691333999999998	Пригородный, д. Беляковка, Совхозная, 7		0101000020E610000064CDC82077594E40724EECA17DD84C40
86482	6	56	340	8315	18712	\N	57.628197	с. Башкарка, Школьная, 2		0101000020E61000000F4240BE84704E40003961C268D04C40
86481	6	56	340	45381	20023	\N	58.052292999999999	с. Балакино, Ленина, 17		0101000020E61000005A9F724C16074E40A5677A89B1064D40
86503	6	56	340	9226	18908	\N	57.692025999999998	п. Анатольская, Привокзальная,13	Россия, Свердловская область, Пригородный район, поселок Анатольская	0101000020E6100000D1419770E80D4E40A8FDD64E94D84C40
86515	6	56	7053	50192	20212	\N	57.967937999999997	с. Покровское, Птицеводов, 24		0101000020E610000067B5C01E13214E401F477364E5FB4C40
89043	6	56	7031	50156	20125	\N	56.442512871799003	город Полевской, поселок Станционный  Полевской, Гагарина, 3		0101000020E61000009143C4CDA9284E4005871744A4384C40
88960	6	56	7016	50095	19855	\N	57.020939166299598	город Первоуральск, п. Кузино, Демьяна Бедного, 16		0101000020E610000012FA997ADDB84D40001B1021AE824C40
86456	6	56	781	40181	\N	\N	59.1569	"""""""п. Юрты, Административное здание ЦЛЗУ ООО """"""""Новолялинский ЦБК"""""""""""""""		0101000020E6100000B8C9A8328CD34D40075F984C15944D40
86463	6	56	781	7384	\N	\N	59.447260999999997	Новолялинский район, п. Шайтанка, Здание школы		0101000020E6100000AF93FAB2B4014E405CE333D93FB94D40
86461	6	56	781	7322	\N	\N	59.073996999999999	Новолялинский район, п. Старая Ляля, Здание школы		0101000020E61000003080F0A144EF4D404580D3BB78894D40
86467	6	56	781	7560	\N	\N	59.073844999999999	"""""""Новолялинский район, д. Салтаново, Здание детского сада """"""""Незабудка"""""""""""""""		0101000020E6100000CA3505323B574E408FFCC1C073894D40
86465	6	56	781	49908	\N	\N	59.020335336339102	Новолялинский район, д. Савиново, Здание Дома культуры	Россия, Свердловская область, Новолялинский район, поселок Савинова	0101000020E6100000210725CCB42B4E406AFB57569A824D40
86455	6	56	781	7022	\N	\N	59.248626999999999	Новолялинский район, п. Павда, Здание клуба		0101000020E6100000BD6E1118EBC14D4088F37002D39F4D40
86431	6	56	781	5504	18896	\N	59.053845000000003	Новолялинский район, г. Новая Ляля, Энгельса, 22		0101000020E610000093A641D13C4C4E40CD069964E4864D40
86429	6	56	781	5504	18227	\N	59.053845000000003	Новолялинский район, г. Новая Ляля, Челюскинцев, 1		0101000020E610000093A641D13C4C4E40CD069964E4864D40
86437	6	56	781	5504	18264	\N	59.049243874105699	Новолялинский район, г. Новая Ляля, Островского, 1	Россия, Свердловская область, Новолялинский район, Новая Ляля	0101000020E61000007D1F0E12A24C4E401AC39CA04D864D40
86426	6	56	781	5504	18211	\N	59.053845000000003	Новолялинский район, г. Новая Ляля, Клубный переулок, 1		0101000020E610000093A641D13C4C4E40CD069964E4864D40
86436	6	56	781	5504	18174	\N	59.053845000000003	Новолялинский район, г.Новая Ляля, Кирова, 2		0101000020E610000093A641D13C4C4E40CD069964E4864D40
86439	6	56	781	5504	18935	\N	59.053845000000003	Новолялинский район, г. Новая Ляля, Гайдара, 75		0101000020E610000093A641D13C4C4E40CD069964E4864D40
86434	6	56	781	5504	19087	\N	59.053845000000003	Новолялинский район, г. Новая Ляля, Гагарина, 12		0101000020E610000093A641D13C4C4E40CD069964E4864D40
86468	6	56	781	7631	\N	\N	59.232435000000002	с. Лопаево, Здание школы		0101000020E61000003D81B053AC324E400FB9196EC09D4D40
86453	6	56	781	6410	19972	\N	59.186208000000001	Новолялинский район, п. Лобва, Чкалова, 1		0101000020E6100000DF52CE177B414E407520EBA9D5974D40
86451	6	56	781	6410	18657	\N	59.186208000000001	Новолялинский район, п. Лобва, Чехова, 11		0101000020E6100000DF52CE177B414E407520EBA9D5974D40
86443	6	56	781	6410	18636	\N	59.186208000000001	Новолялинский район, п. Лобва, Советская, 40		0101000020E6100000DF52CE177B414E407520EBA9D5974D40
86447	6	56	781	6410	17784	\N	59.186208000000001	Новолялинский район, п.Лобва, 22 Партсъезда, 2	Россия, Свердловская область, Новолялинский район, поселок Лобва	0101000020E6100000DF52CE177B414E407520EBA9D5974D40
86444	6	56	781	6410	17766	\N	59.186208000000001	Новолялинский район, п. Лобва, Островского, 6		0101000020E6100000DF52CE177B414E407520EBA9D5974D40
86448	6	56	781	6410	19060	\N	59.186208000000001	Новолялинский район, п. Лобва, Кузнецова, 9		0101000020E6100000DF52CE177B414E407520EBA9D5974D40
88532	6	56	7034	50164	20153	\N	58.6417	город Лесной, Карла Маркса, 15		0101000020E61000004D1421753BE54D40EEEBC03923524D40
86414	6	56	7531	61322	78550	\N	58.7949945364443	поселок Ис, Молодежная, 1А	Россия, Свердловская область, городской округ Нижняя Тура, поселок Ис	0101000020E610000024D5777E51DA4D40E4BD6A65C2654D40
89330	6	56	6988	49846	17827	\N	58.627387451456798	"""Нижнетуринский, Нижняя Тура, Пирогова 6. МБОУ """"СОШ №3""""  """	Россия, Свердловская область, Нижняя Тура	0101000020E6100000566133C005ED4D40C0779B374E504D40
86392	6	56	1	3689	18078	\N	56.428469	Свердловская область, Нижнесергинский муниципальный район, Михайловское муниципальное образование, д. Шарама, Набережная, 19		0101000020E610000008CDAE7B2B824D40C72C7B12D8364C40
86388	6	56	1	3546	18545	\N	56.448282182733301	Нижнесергинский муниципальный район, Михайловское муниципальное образование, д. УфаШигири, Рассветная, 15	Россия, Свердловская область, Нижнесергинский район, поселок Уфа-Шигири	0101000020E6100000CAE0287975764D4057B1F84D61394C40
86385	6	56	1	3369	19077	\N	56.459268000000002	Нижнесергинский муниципальный район, Михайловское муниципальное образование, д. Урмикеево, Совхозная, 4		0101000020E610000080D3BB783F824D40B70C384BC93A4C40
86399	6	56	1	4098	20117	\N	56.260528000000001	Нижнесергинский муниципальный район, Михайловское муниципальное образование, с. Тюльгаш, Черемушки, 8 а		0101000020E61000007520EBA9D5894D409DD843FB58214C40
86370	6	56	1	2514	18108	\N	56.838996000000002	Свердловская область, Нижнесергинский муниципальный район, Кленовское сельское поселение, д. Талица, Клубный, 2		0101000020E6100000C9E88024EC614D40C7BC8E38646B4C40
86374	6	56	1	2735	19885	\N	56.915833999999997	Нижнесергинский муниципальный район, Кленовское сельское поселение, д. Старобухарово, Советская, 36 а		0101000020E6100000ABED26F8A6774D404D486B0C3A754C40
86379	6	56	1	2977	\N	\N	56.700246999999997	Нижнесергинский муниципальный район, Кленовское сельское поселение, д. Сосновый Бор, Центральная, 31	Россия, Свердловская область, Нижнесергинский район, поселок Сосновый Бор (Новоселы)	0101000020E61000005C59A2B3CC684D40A10F96B1A1594C40
86393	6	56	1	50237	20388	\N	56.315836509145299	Нижнесергинский муниципальный район, Михайловское муниципальное образование, с. Щокурово, Ленина, 93 а	Россия, Свердловская область, Нижнесергинский район	0101000020E61000001686C8E9EB8D4D40F2EEC8586D284C40
86407	6	56	1	4532	20121	\N	56.212209000000001	Нижнесергинский муниципальный район, Михайловское муниципальное образование, п. Рябиновка, лесная, 15		0101000020E61000009CFC169D2C8B4D405C751DAA291B4C40
86398	6	56	1	3968	18095	\N	56.338493999999997	Нижнесергинский муниципальный район, Михайловское муниципальное образование, д.Перепряжка, Мубаракшина, 59		0101000020E61000001D59F965307E4D4034F279C5532B4C40
86352	6	56	1	1471	20275	\N	56.821032292429699	Нижнесергинский муниципальный район, Дружининское городское поселение, с. Первомайское, Ленина, 52	Россия, Свердловская область, Нижнесергинский район, поселок Первомайское	0101000020E6100000C0EAC891CEC44D40187C9A9317694C40
86369	6	56	1	2405	19821	\N	56.851702000000003	Нижнесергинский муниципальный район, Кленовское сельское поселение, д. Отевка, Мира, 24		0101000020E61000006CB1DB67954F4D400AF83592046D4C40
86404	6	56	1	4361	\N	\N	56.658909000000001	Нижнесергинский муниципальный район, Дружининское городское поселение, город Нижние Серги 3, школа		0101000020E6100000A56950340FA84D4021054F2157544C40
86318	6	56	1	4361	\N	\N	56.658909000000001	"""""""Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Санаторий """"""""Курорт Нижние Серги"""""""", административный корпус"""""""		0101000020E6100000A56950340FA84D4021054F2157544C40
86312	6	56	1	4361	18337	\N	56.658909000000001	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, городок Солнечный, 3		0101000020E6100000A56950340FA84D4021054F2157544C40
86311	6	56	1	4361	17842	\N	56.658909000000001	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Титова, 39		0101000020E6100000A56950340FA84D4021054F2157544C40
88850	6	56	1035	49928	19845	\N	57.244922000000003	город Новоуральск, Свердлова, 1А		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
86320	6	56	1	4361	20003	\N	56.659570785673999	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Стахановцев, 10	Россия, Свердловская область, Нижнесергинский район, Нижние Серги	0101000020E61000006C223317B8A64D40EC3191D26C544C40
86302	6	56	1	4361	18975	\N	56.658909000000001	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Пролетарская, 13		0101000020E6100000A56950340FA84D4021054F2157544C40
86316	6	56	1	4361	18701	\N	56.658909000000001	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Мякутина, 19		0101000020E6100000A56950340FA84D4021054F2157544C40
86306	6	56	1	4361	18316	\N	56.658909000000001	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Ленина, 30		0101000020E6100000A56950340FA84D4021054F2157544C40
86304	6	56	1	4361	18316	\N	56.658909000000001	Нижнесергинский муниципальный район, Нижнесергинское городское поселение, город Нижние Серги, Ленина, 2		0101000020E6100000A56950340FA84D4021054F2157544C40
86377	6	56	1	2865	18930	\N	56.764032	Нижнесергинский муниципальный район, Кленовское сельское поселение, с. Накоряково, Победы, 17		0101000020E6100000A60F5D50DF724D407A8CF2CCCB614C40
86334	6	56	1	387	17969	\N	56.405793000000003	Нижнесергинский муниципальный район, Михайловское муниципальное образование, п. Михайловский завод, Чкалова, 19		0101000020E610000005F86EF3C69F4D400EF96706F1334C40
86401	6	56	1	3	19130	\N	56.437676000000003	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Уральская, 21		0101000020E61000003944DC9C4A8E4D403F1F65C405384C40
86331	6	56	1	3	18252	\N	56.441194748185602	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Кирова, 57	Россия, Свердловская область, Нижнесергинский район, Михайловск	0101000020E6100000580053060E904D405114E81379384C40
86328	6	56	1	3	18252	\N	56.442002992300097	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Кирова, 43 А	Россия, Свердловская область, Нижнесергинский район, Михайловск	0101000020E610000030B8E68EFE8F4D40F0DDE68D93384C40
86327	6	56	1	3	18252	\N	56.437676000000003	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Кирова, 26		0101000020E61000003944DC9C4A8E4D403F1F65C405384C40
86323	6	56	1	3	18252	\N	56.437676000000003	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Кирова, 25		0101000020E61000003944DC9C4A8E4D403F1F65C405384C40
86321	6	56	1	3	18663	\N	56.437676000000003	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Демьяна Бедного, 10		0101000020E61000003944DC9C4A8E4D403F1F65C405384C40
86405	6	56	1	3	18866	\N	56.4373434656748	Нижнесергинский муниципальный район, Михайловское муниципальное образование, город Михайловск, Грязнова, 61	Россия, Свердловская область, Нижнесергинский район, Михайловск	0101000020E6100000FD4E93196F8F4D403811FDDAFA374C40
86361	6	56	1	1937	\N	\N	56.934750999999999	Нижнесергинский муниципальный район, Кленовское сельское поселение, п. Малиновый, Дом культуры		0101000020E610000033DFC14F1C3E4D409F73B7EBA5774C40
86354	6	56	1	1582	18460	\N	56.768408000000001	Нижнесергинский муниципальный район, Дружининское городское поселение, п. Лазоревый, Химмашевская, 4		0101000020E61000004260E5D022C34D400DFE7E315B624C40
86396	6	56	1	3880	19852	\N	56.323307999999997	Нижнесергинский муниципальный район, Михайловское муниципальное образование, п. Красноармеец, Ленина, 7 а	Россия, Свердловская область, Нижнесергинский район, поселок Красноармеец	0101000020E6100000C91EA16648834D408044132862294C40
86372	6	56	1	2634	18841	\N	56.868526000000003	Нижнесергинский муниципальный район, Кленовское сельское поселение, д. Контуганово, переулок Клубный, 2		0101000020E61000006092CA1473604D40E4DC26DC2B6F4C40
86359	6	56	1	1706	18803	\N	56.829917823294302	Свердловская область, Нижнесергинский муниципальный район, Кленовское сельское поселение, п. Ключевая, Первомайская, 73,2	Россия, Свердловская область, Нижнесергинский район, поселок Ключевая	0101000020E61000002C7DE882FA3C4D404D2EC6C03A6A4C40
86356	6	56	1	1706	18803	\N	56.830858910622403	Свердловская область, Нижнесергинский муниципальный район, Кленовское сельское поселение, п. Ключевая, Первомайская, 70	Россия, Свердловская область, Нижнесергинский район, поселок Ключевая	0101000020E6100000F419506F463D4D402B4B7496596A4C40
86363	6	56	1	2058	18009	\N	56.825128999999997	Нижнесергинский муниципальный район, Кленовское сельское поселение, с. Кленовское, Красных Партизан, 2а		0101000020E610000007EFAB72A1524D4097FDBAD39D694C40
86365	6	56	1	2058	19050	\N	56.825128999999997	Нижнесергинский муниципальный район, Кленовское сельское поселение, с. Кленовское, Азина, 4,2		0101000020E610000007EFAB72A1524D4097FDBAD39D694C40
86366	6	56	1	2287	18820	\N	56.773124000000003	Нижнесергинский муниципальный район, Кленовское сельское поселение, д. Киселевка, Центральная, 49		0101000020E6100000E2016553AE4E4D4059E02BBAF5624C40
89255	6	56	1	14817	78587	\N	56.840882000000001	Свердловская область, Нижнесергинский район, с. Киргишаны, Трактовая , 95		0101000020E6100000E55E605628964D40C5E57805A26B4C40
86349	6	56	1	1251	18760	\N	56.789544999999997	Нижнесергинский муниципальный район, Дружининское городское поселение, поселок Дружинино, Калинина, 7а		0101000020E610000098FBE42840C24D4033DC80CF0F654C40
86351	6	56	1	1251	20020	\N	56.789544999999997	Нижнесергинский муниципальный район, Дружининское городское поселение, поселок Дружинино, Азина, 13		0101000020E610000098FBE42840C24D4033DC80CF0F654C40
86343	6	56	1	530	17988	\N	56.647098	Нижнесергинский муниципальный район, городское поселение Верхние Серги,  поселок Верхние Серги, Пришкольная, 1		0101000020E6100000C9E9EBF99AC74D404CA7751BD4524C40
86341	6	56	1	530	77080	\N	56.647098	Нижнесергинский муниципальный район, городское поселение Верхние Серги,  поселок Верхние Серги, Ленина, 68		0101000020E6100000C9E9EBF99AC74D404CA7751BD4524C40
86337	6	56	1	530	19029	\N	56.647098	Нижнесергинский муниципальный район, городское поселение Верхние Серги, поселок Верхние Серги, Володарского, 8 А		0101000020E6100000C9E9EBF99AC74D404CA7751BD4524C40
86382	6	56	1	3094	9715	\N	56.754575056571603	Нижнесергинский муниципальный район, Кленовское сельское поселение, д. Васькино, Школьная, 13	Россия, Свердловская область, Нижнесергинский район, поселок Васькино	0101000020E6100000965B5A0D89674D408AB0E1E995604C40
89254	6	56	1	13108	18846	\N	56.855693000000002	Нижнесергинский район, р.п. Бисерть, Чапаева, 7		0101000020E6100000CDC98B4CC0874D4044352559876D4C40
89252	6	56	1	13108	18847	\N	56.855693000000002	Свердловская область, Нижнесергинский район, р.п. Бисерть, Революции, 110а		0101000020E6100000CDC98B4CC0874D4044352559876D4C40
89249	6	56	1	13108	19123	\N	56.855693000000002	Нижнесергинский район,  р.п. Бисерть, Октябрьская, 10		0101000020E6100000CDC98B4CC0874D4044352559876D4C40
89247	6	56	1	13108	18140	\N	56.857479818856802	Нижнесергинский район, р.п. Бисерть, Ленина, 23	Россия, Свердловская область, Нижнесергинский район, поселок Бисерть	0101000020E6100000827170E998874D40AF7C96E7C16D4C40
89250	6	56	1	13108	18993	\N	56.855693000000002	Нижнесергинский район,  р.п. Бисерть, Дзержинского, 2а		0101000020E6100000CDC98B4CC0874D4044352559876D4C40
86347	6	56	1	1009	20264	\N	56.6871454536345	Нижнесергинский муниципальный район, Муниципальное образование рабочий поселок Атиг, п. Атиг, Заводская, 8	Россия, Свердловская область, Нижнесергинский район, поселок Атиг	0101000020E61000006825ADF886B84D40124E0B5EF4574C40
86345	6	56	1	1009	77081	\N	56.689782999999998	Нижнесергинский муниципальный район, Муниципальное образование рабочий поселок Атиг, п. Атиг, Гагарина, 19		0101000020E6100000C1FEEBDCB4B74D401B2B31CF4A584C40
86383	6	56	1	3263	18517	\N	56.442104999999998	Нижнесергинский муниципальный район, Михайловское муниципальное образование,с. Аракаево, Азина, 1		0101000020E6100000BDFBE3BD6A9B4D40F4328AE596384C40
86389	6	56	1	3586	19085	\N	56.383552999999999	Нижнесергинский муниципальный район, Михайловское муниципальное образование, с. Акбаш, Мысф Джаиля, 87		0101000020E610000011C4793881834D402FA4C34318314C40
86339	6	56	7059	50205	20259	\N	56.647098	Нижнесергинский муниципальный район, городское поселение Верхние Серги,  поселок Верхние Серги, Володарского, 2		0101000020E6100000C9E9EBF99AC74D404CA7751BD4524C40
86283	6	56	1035	49859	17902	\N	57.414935	с. Шурала, Советов, 48		0101000020E61000002522FC8BA0194E409E7B0F971CB54C40
82029	6	56	1035	11231	19067	\N	57.384960999999997	с. Шайдуриха, Ленина, 84	Россия, Свердловская область, Невьянский район, поселок Шайдуриха	0101000020E6100000213CDA3862494E40239EEC6646B14C40
86279	6	56	1035	45901	18924	\N	57.472150999999997	п. Цементный, Ленина, 33		0101000020E61000007D7A6CCB80134E4008E3A7716FBC4C40
86293	6	56	1035	30839	18953	\N	57.426018999999997	Федьковка, Ленина, 54		0101000020E61000008109DCBA9B214E40C03C64CA87B64C40
88856	6	56	1035	46920	19854	\N	57.130364	село Тарасково, Ленина, 30		0101000020E6100000F33AE2900D084E40B2497EC4AF904C40
86282	6	56	1035	30262	19955	\N	57.068559700504402	п. Таватуй (Аятский сельсовет), Центральная, 1	Россия, Свердловская область, Невьянский район, поселок Таватуй	0101000020E6100000EDD3F19881104E4029E8F692C6884C40
86295	6	56	1035	30262	20198	\N	57.071094692885197	п. Таватуй, Лесная, 10а	Россия, Свердловская область, Невьянский район, поселок Таватуй	0101000020E6100000419C871398104E405EF415A419894C40
86294	6	56	1035	30884	19968	\N	57.487184999999997	п. Середовина, Промышленная, 13		0101000020E61000007B2DE8BD31244E40060DFD135CBE4C40
86292	6	56	1035	30828	19965	\N	57.467509999999997	п. Ребристый, Ленина, 8		0101000020E610000015376E313F234E40C746205ED7BB4C40
88858	6	56	1035	46961	19098	\N	57.067928000000002	село Починок, Ленина, 15		0101000020E610000071FF91E9D0F74D40C93D5DDDB1884C40
88857	6	56	1035	46935	20392	\N	57.142203000000002	деревня Пальники, Восточная, 2А		0101000020E6100000501A6A1492EC4D40513239B533924C40
86288	6	56	1035	46094	17771	\N	57.505336999999997	д. Осиновка, КМаркса, 92		0101000020E61000007A185A9D9C474E40B83A00E2AEC04C40
88851	6	56	1035	17766	18091	\N	57.244922000000003	город Новоуральск, Чкалова, 11		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88843	6	56	1035	17766	18074	\N	57.244922000000003	город Новоуральск, Фрунзе, 7		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88852	6	56	1035	17766	17922	\N	57.2366154597388	город Новоуральск, Свердлова, 13	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E61000008448861C5B0B4E401C5F7B66499E4C40
89319	6	56	1035	17766	17798	\N	57.244922000000003	город Новоуральск, Микрорайон 15, 2		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88853	6	56	1035	17766	18114	\N	57.245108165087103	город Новоуральск, Ленина, 99	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E6100000E95F92CA140B4E4076FEEDB25F9F4C40
88849	6	56	1035	49928	19846	\N	57.244922000000003	город Новоуральск, Юбилейная, 7		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88848	6	56	1035	49928	19846	\N	57.244922000000003	город Новоуральск, Юбилейная, 7А		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88834	6	56	1035	49928	18784	\N	57.244922000000003	город Новоуральск, Чурина, 16		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88836	6	56	1035	49928	77103	\N	57.244922000000003	город Новоуральск, Театральный проезд, 20		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88846	6	56	1035	49928	18641	\N	57.248062700619997	город Новоуральск, Советская, 19А	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E6100000151DC9E53F084E40802C4487C09F4C40
88835	6	56	1035	49928	18786	\N	57.248516328720598	город Новоуральск, Мичурина, 5	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E61000000114234BE60C4E4031444E5FCF9F4C40
88839	6	56	1035	49928	19953	\N	57.242863024390999	город Новоуральск, Ленина, 38А	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E6100000EEB1F4A10B0C4E4048348122169F4C40
88656	6	56	1035	49928	19953	\N	57.253203490884502	город Новоуральск, Ленина, 34	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E61000003C139A24960C4E40E21FB6F468A04C40
88841	6	56	1035	49928	20075	\N	57.242352442145503	город Новоуральск, Крупской, 2		0101000020E610000091D10149D80B4E40620FED63059F4C40
88854	6	56	1035	49928	18452	\N	57.218205252258898	город Новоуральск, Корнилова, 7/1	Россия, Свердловская область, Невьянский район	0101000020E610000057EE0566850A4E406E693524EE9B4C40
88832	6	56	1035	49928	77083	\N	57.244922000000003	город Новоуральск, Комсомольская, 14		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
88855	6	56	1035	49928	19095	\N	57.244469735346499	город Новоуральск, Загородное шоссе, 12	Россия, Свердловская область, Невьянский район, Новоуральск	0101000020E6100000DE1FEF552B0B4E40336DFFCA4A9F4C40
88845	6	56	1035	49928	19081	\N	57.244922000000003	город Новоуральск, Автозаводская, 25		0101000020E6100000BE13B35E0C0B4E401409A69A599F4C40
86285	6	56	1035	30414	78513	\N	57.585500000000003	д. Нижние Таволги, Макаренко, 3Б		0101000020E61000003387A4164A304E406DE7FBA9F1CA4C40
86291	6	56	1035	30720	18273	\N	57.398693000000002	с. Кунара, Победы, 14а		0101000020E610000079758E01D93B4E4073124A5F08B34C40
86287	6	56	1035	46063	17776	\N	57.473577786813301	с. Конево, Горького, 1а	Россия, Свердловская область, Невьянский район, поселок Конёво	0101000020E61000001900AAB871514E40740D33349EBC4C40
86289	6	56	1035	46118	19817	\N	57.456864000000003	с. Киприно, Трактористов, 5		0101000020E61000003C1405FA445E4E40215C01857ABA4C40
86280	6	56	1035	45927	18367	\N	57.133665999999998	п. Калиново, Советская, 4		0101000020E61000006E88F19A57134E40274BADF71B914C40
86296	6	56	1035	31028	18300	\N	57.503532999999997	п. Забельный, Уральская, 3		0101000020E610000023BBD23252154E4077BAF3C473C04C40
86286	6	56	1035	30512	18646	\N	57.566346000000003	д. Верхние Таволги, Мира, 44		0101000020E6100000D6FECEF6E82F4E40371C96067EC84C40
89263	6	56	1035	15145	18581	\N	57.267536	Невьянский район, п. ВерхНейвинский, пл. Революции, 1		0101000020E610000038BA4A77D7114E405740A19E3EA24C40
86278	6	56	1035	30123	\N	\N	57.471826999999998	п. Вересковый, 5		0101000020E610000021AD31E884164E40552FBFD364BC4C40
86284	6	56	1035	30411	18635	\N	57.538260000000001	с. Быньги, Мартьянова, 42		0101000020E6100000B3B5BE4868254E405B5F24B4E5C44C40
86281	6	56	1035	30218	20014	\N	57.038449576930802	п. Аять, Ленина, 8	Россия, Свердловская область, Невьянский район	0101000020E6100000AE635C71711E4E40FE43FAEDEB844C40
86290	6	56	1035	30716	78414	\N	57.412021000000003	с. Аятское, Калинина, 18		0101000020E61000004E9A0645F3584E40F321A81ABDB44C40
88859	6	56	7048	50190	20209	\N	57.218863630916701	город Новоуральск, Корнилова, 9В		0101000020E610000074F04C68920A4E40C9224DBC039C4C40
86249	6	56	932	50159	20129	\N	56.440641999999997	село Юва, Октября, 1б		0101000020E6100000083D9B559FF94C403C9F01F566384C40
86230	6	56	932	27942	18569	\N	56.685631000000001	село Чувашково, Школьная, 2		0101000020E6100000BADBF5D214F14C40D80FB1C1C2574C40
86240	6	56	932	28326	19138	\N	56.552787000000002	деревня Чигвинцево, Набережная, 16б  1		0101000020E61000004E2B85402EDF4C40B55373B9C1464C40
86220	6	56	932	27472	17983	\N	56.785423000000002	село Чатлык, Ленина, 43	Россия, Свердловская область, Красноуфимский район, поселок Чатлык	0101000020E6100000DE02098A1FD94C405B43A9BD88644C40
86259	6	56	932	61321	78549	\N	56.289324829157401	деревня УстьБугалыш, Лесная, 40а		0101000020E610000048E00F3FFFED4C402575029A08254C40
86233	6	56	932	61332	78580	\N	56.6272817082871	деревня УстьБаяк, Октября, 2		0101000020E6100000C408E1D1C6FF4C404BAFCDC64A504C40
86261	6	56	932	29295	18717	\N	56.237105999999997	деревня Татарская Еманзельга, Советская, 78		0101000020E6100000C022BF7E88F74C40BAD7497D591E4C40
86250	6	56	932	28841	19912	\N	56.450060999999998	деревня Сызги, Центральная, 18		0101000020E6100000E5805D4D9EEE4C403F1A4E999B394C40
86252	6	56	932	28891	18988	\N	56.298492000000003	село Средний Бугалыш, Советская, 21	Россия, Свердловская область, Красноуфимский район, поселок Средний Бугалыш	0101000020E61000005743E21E4BFF4C400F0F61FC34264C40
86253	6	56	932	28891	20334	\N	56.301880199343898	село Средний Бугалыш, Ленина, 5	Россия, Свердловская область, Красноуфимский район, поселок Средний Бугалыш	0101000020E61000006AFAEC80EBFE4C4082A8FB00A4264C40
86237	6	56	932	28196	20122	\N	56.570683000000002	деревня Средний Баяк, Новая, 18		0101000020E61000007B1002F225FE4C400CB1FA230C494C40
86260	6	56	932	29277	20147	\N	56.213050000000003	село Сарсы Вторые, Ленина, 76		0101000020E6100000C6BFCFB870FE4C40D734EF38451B4C40
86265	6	56	932	29472	18359	\N	56.243830000000003	поселок Саргая, Труда, 7а		0101000020E61000006B48DC63E9DB4C4050E449D2351F4C40
86246	6	56	932	28564	18173	\N	56.477120047521304	поселок Сарана, Советская, 35	Россия, Свердловская область, Красноуфимский район, поселок Сарана	0101000020E6100000956588635DDC4C403E22A644123D4C40
86245	6	56	932	28564	18873	\N	56.483522000000001	поселок Сарана, Горького, 1		0101000020E6100000C102983270DC4C40C172840CE43D4C40
86256	6	56	932	61319	78541	\N	56.318697999999998	деревня Русский УстьМаш, Школьная, 9	Россия, Свердловская область, Красноуфимский район, поселок Русский Усть-Маш	0101000020E6100000D8101C9771EF4C407AA69718CB284C40
86234	6	56	932	28063	20324	\N	56.589773753965602	село Рахмангулово, Ленина, 62а	Россия, Свердловская область, Красноуфимский район, поселок Рахмангулово	0101000020E6100000999D45EF54064D40FB03E5B67D4B4C40
86228	6	56	932	27799	18146	\N	56.656247999999998	деревня Приданниково, Первомайская, 1а		0101000020E610000037E15E99B7E44C405F0839EFFF534C40
86227	6	56	932	49296	18554	\N	56.733046999999999	деревня Подгорная, Виктора Прокудина, 50		0101000020E6100000465F419AB1E64C4028B7ED7BD45D4C40
86251	6	56	932	45371	19002	\N	56.423808999999999	деревня Озерки, Сосновая, 1а		0101000020E6100000A73E90BC73EC4C400F60915F3F364C40
86258	6	56	932	29158	18354	\N	56.301957999999999	деревня Новый Бугалыш, Садовая, 8		0101000020E6100000F9D7F2CAF5F84C40FE614B8FA6264C40
86217	6	56	932	55028	41465	\N	56.868747806080101	село Новое Село, Уральская, 2	Россия, Свердловская область, Красноуфимский район, поселок Новое Село	0101000020E6100000790778D2C2C34C40923B6C22336F4C40
86257	6	56	932	61315	78534	\N	56.330693593716703	деревня Марийский УстьМаш, Заречная, 16	Россия, Свердловская область, Красноуфимский район, поселок Марийский Усть-Маш	0101000020E610000079AEEFC341F44C40E17D552E542A4C40
86244	6	56	932	28555	19903	\N	56.462848999999999	село Марийские Ключики, Советская, 17	Россия, Свердловская область, Красноуфимский район, поселок Марийские Ключики	0101000020E6100000EF74E789E7EA4C403FFED2A23E3B4C40
86232	6	56	932	49345	19127	\N	56.638044999999998	село Крылово, Гагарина, 2		0101000020E6100000A94E07B29EF24C402B306475AB514C40
86267	6	56	932	29558	19014	\N	56.587411000000003	Красноуфимский, Криулино, Советская 57. Клуб	Россия, Свердловская область, Красноуфимский район, поселок Криулино	0101000020E61000004DA25EF069E84C40C4279D48304B4C40
86239	6	56	932	29558	18865	\N	56.587411000000003	село Криулино, Советская, 26		0101000020E61000004DA25EF069E84C40C4279D48304B4C40
86221	6	56	932	27479	78511	\N	56.824134000000001	деревня Красный Турыш, Молодежная, 2		0101000020E6100000F6ED2422FCD74C40C6C210397D694C40
86215	6	56	932	27205	18829	\N	56.918211999999997	село Красносоколье, Центральная, 6		0101000020E61000003EAE0D15E3B44C40BA6587F887754C40
86242	6	56	932	49495	78508	\N	56.520474	деревня Красная Поляна, Центральная, 5а		0101000020E61000002B4D4A41B7ED4C408B355CE49E424C40
86224	6	56	932	49891	18141	\N	56.693322999999999	село Ключики, Студенческая, 22	Россия, Свердловская область, Красноуфимский район, поселок Ключики	0101000020E610000010AD156D8EDB4C404548DDCEBE584C40
86243	6	56	932	49510	18588	\N	56.588208999999999	деревня Калиновка, Заречная, 24а		0101000020E6100000B3EA73B515F14C403F1BB96E4A4B4C40
86241	6	56	932	28384	18584	\N	56.480629	деревня Зауфа, Новая, 1а		0101000020E610000061AA99B514E04C402D414640853D4C40
86266	6	56	932	45652	18214	\N	56.254147000000003	деревня Дегтярка, Трактовая, 22		0101000020E6100000A35A441493D14C4032B08EE387204C40
86255	6	56	932	45445	18606	\N	56.313369000000002	деревня Голенищево, Заречная, 20		0101000020E61000000664AF777F084D40454AB3791C284C40
86223	6	56	932	27586	20108	\N	56.806358000000003	деревня Верхняя Ирга, Кунгурская, 1		0101000020E6100000B325AB22DCC84C401A6F2BBD36674C40
86254	6	56	932	29024	20227	\N	56.302092999999999	деревня Верхний Бугалыш, Советская, 27		0101000020E61000005B5CE333D9014D40DEACC1FBAA264C40
86238	6	56	932	28277	19135	\N	56.547640999999999	деревня Верхний Баяк, Нагорная, 9		0101000020E6100000A6EECA2E18024D407079AC1919464C40
86229	6	56	932	27858	18147	\N	56.615357000000003	деревня Верхнее Никитино, Центральная, 29а		0101000020E6100000B22FD978B0D74C40AE2EA704C44E4C40
86219	6	56	932	27382	19117	\N	56.854463000000003	деревня Верхняя Бобровка, Свободы, 2		0101000020E610000030F65E7CD1CE4C402F52280B5F6D4C40
86222	6	56	932	27529	20105	\N	56.752299000000001	село Большой Турыш, Совхозная, 1		0101000020E61000005F27F56569CF4C4021E868554B604C40
86218	6	56	932	27377	18839	\N	56.849521000000003	деревня Большое Кошаево, Октября, 17		0101000020E6100000CC61F71DC3C54C40F321A81ABD6C4C40
86262	6	56	932	29366	18887	\N	56.136547	деревня Большая Тавра, Советская, 6а		0101000020E6100000B0E3BF4010024D40F7AE415F7A114C40
86236	6	56	932	28195	19895	\N	56.577213	деревня Бишково, Ленина, 22		0101000020E6100000DFC325C79D0E4D40BCE9961DE2494C40
86226	6	56	932	49281	18853	\N	56.713835000000003	село Александровское, Александровская, 4		0101000020E610000037DE1D19ABE94C40BEDEFDF15E5B4C40
86263	6	56	7066	50225	20346	\N	56.123583000000004	деревня Русская Тавра, Мира, 10		0101000020E610000037A6272CF1FC4C40B9AB5791D10F4C40
86264	6	56	7066	50227	20348	\N	56.656247999999998	"""Красноуфимский, Приданниково, Первомайская 1а, ОМЦ """"Маяк"""""""		0101000020E610000037E15E99B7E44C405F0839EFFF534C40
88341	6	56	7023	50162	20150	\N	59.705454053510799	городской округ Краснотурьинск, поселок Рудничный, Клубная, 8	Россия, Свердловская область, городской округ Краснотурьинск	0101000020E61000000B293FA9F6274E408C6A11514CDA4D40
88190	6	56	3951	49849	18314	\N	56.3904764690107	"""""""город КаменскУральский, Красногорский район, Трудовые резервы, 8а, ДК """"""""Металлург"""""""""""""""	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000B9A6406667F94E40BBEF181EFB314C40
88200	6	56	3951	49849	18334	\N	56.352612000000001	город КаменскУральский,Красногорский район, Железнодородная станция УАЗ, помещение ж/д станции УАЗ		0101000020E610000007B47405DBF84E40AD16D863222D4C40
88197	6	56	3951	49849	17838	\N	56.389333860628199	город КаменскУральский, Красногорский район, 2я Рабочая, 53, школа № 14	Россия, Свердловская область, Каменск-Уральский	0101000020E6100000BF4692205CF94E40459C4EB2D5314C40
88283	6	56	7015	50093	19851	\N	58.696620720451897	Качканарский городской округ, 4 микрорайон, 64	Россия, Свердловская область, Качканар	0101000020E610000064EAAEEC82BD4D40795A7EE02A594D40
86205	6	56	1800	61298	78452	\N	56.7909568480082	д.Шипицина, Кондратьева, 25	Россия, Свердловская область, Камышловский район, поселок Шипицына	0101000020E610000090A16307954A4F4069C537143E654C40
86202	6	56	1800	26646	18375	\N	56.694954000000003	д.Чикунова, Нагорная, 12 А		0101000020E61000004835ECF7C46A4F40B91CAF40F4584C40
86199	6	56	1800	26466	18805	\N	56.786000000000001	д.Фадюшина, Народная, 40		0101000020E61000005C1D0071575D4F40F853E3A59B644C40
86197	6	56	1800	48829	18129	\N	56.826030000000003	с.Раздольное, Школьная, 16		0101000020E6100000713B342C466B4F40E8C1DD59BB694C40
86200	6	56	1800	26562	19083	\N	56.754060000000003	д.Ожгиха, Советская, 3		0101000020E610000053B131AF23744F40639CBF0985604C40
86210	6	56	1800	26931	\N	\N	56.832777	с.Обуховское, Санаторий, Клуб		0101000020E61000005CACA8C1344E4F4035EECD6F986A4C40
86208	6	56	1800	26931	18497	\N	56.832777	с.Обуховское, Школьная, 1 Б		0101000020E61000005CACA8C1344E4F4035EECD6F986A4C40
86196	6	56	1800	48806	18835	\N	56.845426000000003	с.Никольское, пер.Школьный, 7		0101000020E6100000D80FB1C1C2754F4014984EEB366C4C40
81152	6	56	1800	49083	18614	\N	57.053172000000004	с.Куровское, Новая, 2		0101000020E6100000274BADF71B734F400E881057CE864C40
86203	6	56	1800	26655	18485	\N	56.642674	д.Куваева, Титова, 7		0101000020E61000004A9A3FA6B5574F40A8FE412443524C40
85636	6	56	1800	26938	20193	\N	56.850195999999997	деревня Кокшарова, Молодежная, 6		0101000020E61000000A4B3CA06C4A4F405298F738D36C4C40
86214	6	56	1800	27193	20309	\N	57.093102966041798	с.Квашнинское, Ленина, 49	Россия, Свердловская область, Камышловский район, поселок Квашнинское	0101000020E61000008B19E1ED41584F406A1492CCEA8B4C40
86207	6	56	1800	48987	18552	\N	56.822001	с.Калиновское, Советская, 25		0101000020E6100000F261F6B2ED3C4F40C0232A5437694C40
86211	6	56	1800	27029	20088	\N	56.901112122852901	с.Галкинское, Мира, 91	Россия, Свердловская область, Камышловский район, поселок Галкинское	0101000020E610000090DB2F9FAC5C4F403E0455A357734C40
86201	6	56	1800	48890	18524	\N	56.727609999999999	п.Восход, Комсомольская, 10 А		0101000020E6100000BE4A3E76176C4F400C1F1153225D4C40
86212	6	56	1800	27107	17936	\N	57.009886999999999	с.Б.Пульниково, Красных Партизан, 29		0101000020E6100000446E861BF0594F40E9D32AFA43814C40
86198	6	56	1800	26462	19842	\N	56.805289000000002	д.Баранникова, Ленина, 3		0101000020E61000006A2E3718EA644F400E6ABFB513674C40
86144	6	56	5880	49874	17968	\N	56.475290000000001	Каменский район, д.Шилова, Ленина, 30		0101000020E6100000FE463B6EF8AF4E40D40E7F4DD63C4C40
86187	6	56	5880	50090	19832	\N	56.253072000000003	Каменский район, с. Сипавское, Советская, 11б		0101000020E6100000855D143DF0F54E4044C4CDA964204C40
86122	6	56	1492	22861	18338	\N	57.407381999999998	Ирбитский район, деревня Якшина, улица Ленина, 51		0101000020E6100000A9DDAF027C3B4F40527DE71725B44C40
86125	6	56	1492	22996	18691	\N	57.397393000000001	Ирбитский район, село Шмаковское, улица Кирова, 30		0101000020E61000008C2C996379354F40655419C6DDB24C40
86049	6	56	1492	19213	18861	\N	57.614069999999998	Ирбитский район, село Черновское, улица Советская, 55		0101000020E61000000074982F2FB04F4034BA83D899CE4C40
86053	6	56	1492	19315	18583	\N	57.645209000000001	Свердловская область, Ирбитский район, село Чубаровское, улица Октябрьская, 12в		0101000020E610000069AB92C83EC04F40DD0A613596D24C40
86109	6	56	1492	22297	18302	\N	57.410136000000001	Ирбитский район, село Чернорицкое, улица Пролетарская, 51		0101000020E6100000D2510E6613604F40C57421567FB44C40
86077	6	56	1492	20754	18429	\N	57.702795000000002	Ирбитский район, деревня Чащина, улица Школьная, 8	Россия, Свердловская область, Ирбитский район, поселок Чащина	0101000020E6100000D998D71187664F406B65C22FF5D94C40
86063	6	56	1492	19887	18601	\N	57.432671999999997	Ирбитский район, село Харловское, улица Советская, 10		0101000020E6100000C6151747E58C4F408CF2CCCB61B74C40
86072	6	56	1492	20537	18615	\N	57.690261	Ирбитский район, деревня Фомина, улица Советская, 72А		0101000020E61000005EDA70581A7E4F40255AF2785AD84C40
86121	6	56	1492	22810	18685	\N	57.26352	Ирбитский район, село Стриганское, улица Октябрьская, 75		0101000020E61000005D4F745DF8434F40C4EBFA05BBA14C40
89312	6	56	1492	17588	18945	\N	57.639732000000002	Ирбитский район, поселок Спутник, улица Гагарина, 3		0101000020E6100000C7629B5434924F40331AF9BCE2D14C40
86081	6	56	1492	20183	18752	\N	57.624540000000003	Свердловская область, Ирбитский район, деревня Симанова, улица Береговая, 5		0101000020E6100000D00F238447634F409D853DEDF0CF4C40
86045	6	56	1492	19001	18361	\N	57.643292067947399	Ирбитский район, поселок Рябиновый, улица Центральная, 10	Россия, Свердловская область, Ирбитский район, поселок Рябиновый	0101000020E610000029B000A60C8A4F40A4E36A6457D24C40
86028	6	56	1492	18071	19114	\N	57.928409000000002	Ирбитский район, село Рудное, улица Центральная, 30А		0101000020E610000074B680D07A4E4F40F2272A1BD6F64C40
86078	6	56	1492	20847	18617	\N	57.586995999999999	Ирбитский район, деревня Речкалова, улица Центральная, 24		0101000020E61000006971C630276A4F40007157AF22CB4C40
86097	6	56	1492	21717	17749	\N	57.552423176688102	Ирбитский район, деревня Ретнева, улица Дорожная, 8	Россия, Свердловская область, Ирбитский район, поселок Ретнева	0101000020E61000008FE046CA16554F407347FFCBB5C64C40
86103	6	56	1492	22011	18355	\N	57.415714999999999	Свердловская область, Ирбитский район, село Пьянково, улица Юбилейная, 29д		0101000020E61000009F76F86BB27A4F4073BA2C2636B54C40
86064	6	56	1492	20047	18190	\N	57.390903000000002	Ирбитский район, деревня Прядеина, улица Прядеинская, 27		0101000020E610000070B0373124894F404374081C09B24C40
86128	6	56	1492	20233	20004	\N	57.680756548456898	Ирбитский район, поселок Пионерский, улица Ожиганова, 10	Россия, Свердловская область, Ирбитский район, поселок Пионерский	0101000020E6100000B49080D1E5814F40F4C29D0B23D74C40
86068	6	56	1492	20233	18609	\N	57.680691000000003	Ирбитский район, поселок Пионерский, улица Мира, 31Б		0101000020E61000008D7C5EF1D4814F403DD7F7E120D74C40
86117	6	56	1492	22616	18330	\N	57.262182000000003	Ирбитский район, деревня Першина, улица Школьная, 1		0101000020E610000073840CE4D9514F40C9CC052E8FA14C40
86098	6	56	1492	21776	18289	\N	57.551219000000003	Ирбитский район, село Осинцевское, улица Молодежная, 13		0101000020E61000005F622CD32F3F4F4088F71C588EC64C40
87250	6	56	1492	47006	17816	\N	57.509630000000001	п. Ольховка, Торфянников, 2, (Школа №29)		0101000020E61000005342B0AA5E9E4F40BE874B8E3BC14C40
86066	6	56	1492	20161	20337	\N	57.562832	Ирбитский район, деревня Новгородова, улица Школьная, 1		0101000020E61000002AAC5450518D4F40369204E10AC84C40
86030	6	56	1492	18168	18136	\N	57.880698000000002	Ирбитский район, село Ницинское, улица Центральная, 60		0101000020E6100000E4839ECDAA614F4089D349B6BAF04C40
86055	6	56	1492	19507	18871	\N	57.565482000000003	Ирбитский район, деревня Никитина, улица Комсомольская, 47А		0101000020E610000097C62FBC92A44F40043DD4B661C84C40
89307	6	56	1492	17273	17747	\N	57.643854962151799	Свердловская область, Ирбитский район, деревня Нижняя, улица Набережная, 12	Россия, Свердловская область, Ирбитский район, поселок Нижняя	0101000020E61000005C02F04FA9A84F40DC2E34D769D24C40
86070	6	56	1492	20421	18610	\N	57.690857000000001	Ирбитский район, деревня Мельникова, улица Новая, 16		0101000020E6100000A94F72874D844F40399B8E006ED84C40
86126	6	56	1492	23089	17845	\N	57.848269389170198	Свердловская область, Ирбитский район, поселок Лопатково, переулок Школьный, 2	Россия, Свердловская область, Ирбитский район, поселок Лопатково	0101000020E6100000E8C1DD59BBAF4F40F69A1E1494EC4C40
86114	6	56	1492	22553	18667	\N	57.294176999999998	Ирбитский район, деревня Лаптева, улица Центральная, 2		0101000020E610000012BC218D0A664F40211E8997A7A54C40
86033	6	56	1492	18359	18138	\N	57.827331000000001	Свердловская область, Ирбитский район, поселок Курьинский, улица Площадная, 10		0101000020E6100000586FD40AD3734F40C6FB71FBE5E94C40
86112	6	56	1492	22454	18315	\N	57.351427999999999	Ирбитский район, село Крутихинское, улица Советская, 12		0101000020E6100000B6A0F7C610604F400873BB97FBAC4C40
86031	6	56	1492	18272	19118	\N	57.822834999999998	Ирбитский район, село Ключи, улица Урицкого, 2		0101000020E610000062DC0DA2B5704F40888043A852E94C40
86074	6	56	1492	20593	19929	\N	57.636408000000003	Ирбитский район, деревня Кириллова, улица Центральная, 60		0101000020E6100000EEB3CA4C696F4F40D6743DD175D14C40
86048	6	56	1492	19112	18578	\N	57.644044000000001	Ирбитский район, село Кирга, улица Новая, 4		0101000020E61000008BA71E69709F4F40AF97A60870D24C40
86104	6	56	1492	22070	19259	\N	57.40184	Ирбитский район, село Килачевское, улица Ленина, 36		0101000020E6100000986C3CD862534F40C11C3D7E6FB34C40
88041	6	56	1492	50139	20052	\N	57.661575804870502	город Ирбит, ул.Пролетарская, 61		0101000020E61000005BE9B5D958894F40C4E8B985AED44C40
86056	6	56	1492	19570	18875	\N	57.546622965889703	Ирбитский район, село Знаменское, переулок Знаменский, 13	Россия, Свердловская область, Ирбитский район, поселок Знаменское	0101000020E61000008D96033DD49C4F40E61E12BEF7C54C40
86087	6	56	1492	21064	19059	\N	57.539003999999998	Ирбитский район, поселок Зайково, улица Школьная, 10		0101000020E6100000164B917C255E4F40E3344415FEC44C40
86084	6	56	1492	21064	19882	\N	57.5474816372353	Ирбитский район, поселок Зайково, улица Студенческая, 1	Россия, Свердловская область, Ирбитский район, поселок Зайково	0101000020E61000009A22C0E95D5E4F400893E2E313C64C40
86089	6	56	1492	21064	18918	\N	57.539003999999998	Ирбитский район, поселок Зайково, улица Мира, 3		0101000020E6100000164B917C255E4F40E3344415FEC44C40
86082	6	56	1492	21064	19888	\N	57.550541395659501	Ирбитский район, поселок Зайково, улица Коммунистическая, 181	Россия, Свердловская область, Ирбитский район, поселок Зайково	0101000020E6100000FE99417C605F4F40B70DA32078C64C40
86091	6	56	1492	21064	20365	\N	57.539003999999998	Ирбитский район, поселок Зайково, улица А лександра Матросова, 24		0101000020E6100000164B917C255E4F40E3344415FEC44C40
86039	6	56	1492	18690	18563	\N	57.676971000000002	Ирбитский район, деревня Дубская, улица Центральная, 22		0101000020E6100000029CDEC5FB974F4093AB58FCA6D64C40
86042	6	56	1492	18793	18567	\N	57.697659000000002	Ирбитский район, деревня Гуни, улица Советская, 10		0101000020E6100000895FB1868BAC4F404A61DEE34CD94C40
86111	6	56	1492	22344	17803	\N	57.309891999999998	Ирбитский район, село Горки, улица Советская, 16		0101000020E6100000B6A0F7C6104A4F4061A5828AAAA74C40
86044	6	56	1492	18907	19892	\N	57.650126999999998	Ирбитский район, деревня Гаева, улица Чайкина, 26		0101000020E6100000D234289A07924F40909F8D5C37D34C40
86035	6	56	1492	18476	18850	\N	57.784255000000002	Ирбитский район, село Волково, переулок Береговой, 2		0101000020E6100000535BEA20AF894F40BC5CC47762E44C40
86059	6	56	1492	19722	19154	\N	57.496492000000003	Ирбитский район, деревня Большой Камыш, переулок Галишевский, 2		0101000020E61000002DEBFEB110954F40E25CC30C8DBF4C40
86100	6	56	1492	21920	18293	\N	57.485337000000001	Ирбитский район, деревня Большая Кочевка, улица Кирова, 19А		0101000020E610000003CE52B29C744F40F644D7851FBE4C40
86061	6	56	1492	61336	78594	\N	57.521098076959397	Свердловская область, Ирбитский район, деревня Большая Зверева, улица Советская, 22	Россия, Свердловская область, Ирбитский район, поселок Болшая Зверева	0101000020E6100000DA70581AF8974F406901DA56B3C24C40
86037	6	56	1492	18595	18144	\N	57.747188999999999	Ирбитский район, деревня Бердюгина, улица Советская, 18		0101000020E61000007E737FF5B8874F4029779FE3A3DF4C40
86106	6	56	1492	22203	\N	\N	57.453499000000001	Ирбитский район, село Белослудское, улица Космонавтов, 2	Россия, Свердловская область, Ирбитский район, поселок Белослудское	0101000020E6100000A2B8E34D7E574F4065E256410CBA4C40
86119	6	56	1492	22736	18329	\N	57.200940000000003	Ирбитский район, село Анохинское, улица Центральная, 21А		0101000020E61000001FD61BB5C2584F40A83AE466B8994C40
89310	6	56	7039	50180	20189	\N	57.923141999999999	Ирбитский район, деревня Удинцева, улица Садовая, 2		0101000020E6100000450DA661F8564F4032C85D8429F64C40
86095	6	56	7069	50234	20374	\N	57.568218999999999	Ирбитский район, село Скородумское, улица Жукова, 76		0101000020E6100000D89B1892935B4F40A0FB7266BBC84C40
87487	6	56	7014	50086	19819	\N	56.877173036913298	город Екатеринбург, Железнодорожный район, пос Палкино, переулок Школьный, 3		0101000020E6100000A6B5696CAF334E4094F7713447704C40
86007	6	56	1483	17077	18799	\N	59.239418000000001	Свердловская область, Гаринский городской округ, д. Нихвор, Молодежная, 29		0101000020E61000007E3B8908FF584F407009C03FA59E4D40
86018	6	56	1483	17576	20297	\N	59.605459000000003	Свердловская область, Гаринский городской округ, д. Зыкова, Центральная, 10		0101000020E6100000910E0F61FC484F40D10836AE7FCD4D40
86002	6	56	1483	61112	77251	\N	59.429671951259202	Гаринский городской округ, Комсосмольская, 52	Россия, Свердловская область, Гаринский район, поселок Гари	0101000020E61000008484285FD02C4F40E200FA7DFFB64D40
86003	6	56	1483	61112	78536	\N	59.425274316684998	Гаринский городской округ, Колхозная, 38	Россия, Свердловская область, Гаринский район, поселок Гари	0101000020E61000004B7842AF3F2D4F4068EBE0606FB64D40
86010	6	56	1483	17169	18806	\N	59.213754000000002	Свердловская область, Гаринский городской округ, с. Андрюшино, Трудовая, 6		0101000020E6100000865968E7347F4F40D1B1834A5C9B4D40
85983	6	56	1364	61326	78554	\N	58.791226999999999	Верхотурский уезд, село УстьСалда, Центральная, 10	Россия, Свердловская область, Верхотурский район, поселок Усть-Салда	0101000020E6100000A9A27895B5AD4E40295B24ED46654D40
85639	6	56	1364	46967	19856	\N	58.700533	поселок Таежный, Школьная, 1		0101000020E6100000ABB4C5353EE94E406762BA10AB594D40
85993	6	56	1364	50133	20031	\N	58.703474	Верхотурский уезд, село ПрокопСалда, Сенянского, 40	Россия, Свердловская область, Верхотурский район, поселок Прокопьевская Салда	0101000020E61000004D2F3196E98B4E400CCB9F6F0B5A4D40
85978	6	56	1364	14737	18065	\N	58.876550999999999	Верхотурский уезд, пос. Привокзальный, Чапаева, 35		0101000020E610000037FB03E5B65B4E405723BBD232704D40
85959	6	56	1364	14737	18409	\N	58.876550999999999	Верхотурский уезд, поселок Привокзальный, Советская, 6		0101000020E610000037FB03E5B65B4E405723BBD232704D40
85976	6	56	1364	14737	18036	\N	58.891694339062497	Верхотурский уезд, поселок Привокзальный, Садовая, 10	Россия, Свердловская область, Верхотурский район, поселок Привокзальный	0101000020E6100000740B5D89405F4E400C056C0723724D40
85974	6	56	1364	14737	18597	\N	58.876550999999999	Верхотурский уезд, поселок Привокзальный, Крайняя, 6		0101000020E610000037FB03E5B65B4E405723BBD232704D40
85985	6	56	1364	15968	19046	\N	58.759475999999999	городской округ Верхотурский, село Меркушино, Центральная, 10		0101000020E6100000C1E5B16664CC4E40670C738236614D40
85981	6	56	1364	15818	18506	\N	58.800342999999998	Верхотурский уезд, село Красногорское, Ленина, 8		0101000020E6100000D5592DB0C7944E40904AB1A371664D40
85995	6	56	1364	16484	19061	\N	58.746918999999998	городской округ Верхотурский, поселок Косолманка, Клубная, 28		0101000020E6100000A33A1DC87A444E4069E1B20A9B5F4D40
85987	6	56	1364	16064	78420	\N	58.745682000000002	Верхотурский уезд, село Кордюково, Центральная, 36		0101000020E610000020D26F5F07E24E40A29BFD81725F4D40
85992	6	56	1364	16255	18445	\N	58.720056999999997	Верхотурский уезд, поселок Карпунинский, Первое мая, 2		0101000020E61000000B96EA025EE64E40C020E9D32A5C4D40
85998	6	56	1364	16564	20235	\N	58.707503000000003	Верхотурский уезд, поселок Карелино, Клубная, 14		0101000020E6100000691EC022BF324E40346953758F5A4D40
85990	6	56	1364	16166	19822	\N	58.740830000000003	Верхотурский уезд, село Дерябино, Молодежная, 7		0101000020E6100000643BDF4F8DF54E40A6F27684D35E4D40
85964	6	56	1364	14923	18421	\N	58.865934000000003	Свердловская область, Верхотурский уезд, город Верхотурье, Совхозная, 12	Россия, Свердловская область, Верхотурский район, Верхотурье	0101000020E610000006DA1D520C664E404B3FE1ECD66E4D40
85967	6	56	1364	14923	19031	\N	58.865934000000003	Верхотурский уезд, город Верхотурье, Мелиораторов, 31		0101000020E610000006DA1D520C664E404B3FE1ECD66E4D40
85970	6	56	1364	14923	19034	\N	58.865934000000003	Верхотурский уезд, город Верхотурье, Куйбышева, 2		0101000020E610000006DA1D520C664E404B3FE1ECD66E4D40
85980	6	56	1364	14923	19850	\N	58.865934000000003	Свердловская область,г.Верхотурье, Ершова, 15		0101000020E610000006DA1D520C664E404B3FE1ECD66E4D40
86000	6	56	1364	14923	19359	\N	58.865934000000003	городской округ Верхотурский, город Верхотурье, 70 лет Октября, 4		0101000020E610000006DA1D520C664E404B3FE1ECD66E4D40
85971	6	56	1364	14923	18434	\N	58.865934000000003	Свердловская область, Верхотурский уезд, город Верхотурье, 20 лет Победы, 82		0101000020E610000006DA1D520C664E404B3FE1ECD66E4D40
87253	6	56	7024	50200	20236	\N	57.062818999999998	"""""""п. Половинный, Мира, 3, (Здание """"""""Лесхоза"""""""")"""""""		0101000020E61000007A19C5724B4B4E40A148F7730A884C40
87249	6	56	7024	50125	19990	\N	57.158794	п. Кедровое, Школьников, 4, (Школа № 24)	Россия, Свердловская область, городской округ Верхняя Пышма, поселок Кедровое	0101000020E6100000B2B96A9E234A4E4088669E5C53944C40
85958	6	56	743	14633	17970	\N	58.008890999999998	Верхнесалдинский район, д.Северная, 8 Марта, 2	Россия, Свердловская область, Верхнесалдинский район, поселок Северная	0101000020E6100000C87DAB75E2384E40471D1D5723014D40
89297	6	56	743	16561	20145	\N	58.036926000000001	городской округ ЗАТО Свободный, Свободы, 19		0101000020E6100000CF9F36AAD3314E40A12FBDFDB9044D40
89295	6	56	743	16561	18898	\N	58.036926000000001	городской округ ЗАТО Свободный, Кузнецова, 71		0101000020E6100000CF9F36AAD3314E40A12FBDFDB9044D40
89294	6	56	743	16561	17912	\N	58.036926000000001	городской округ ЗАТО Свободный, Карбышева, 70		0101000020E6100000CF9F36AAD3314E40A12FBDFDB9044D40
89292	6	56	743	16561	17912	\N	58.036926000000001	городской округ ЗАТО Свободный, Карбышева, 9		0101000020E6100000CF9F36AAD3314E40A12FBDFDB9044D40
85954	6	56	743	14452	18353	\N	58.238033999999999	Свердловская область, Верхнесалдинский район, п.Песчаный, Центральная, 14		0101000020E61000000B7A6F0C01624E4004ABEAE5771E4D40
85955	6	56	743	14529	17960	\N	57.941912000000002	Верхнесалдинский район, д.Никитино, Центральная, 12		0101000020E61000007EE36BCF2C3B4E40E0DA899290F84C40
85961	6	56	743	14818	18255	\N	58.006669000000002	Верхнесалдинский район, д.Нелоба, Центральная, 29		0101000020E6100000C66E9F55665C4E40D272A087DA004D40
85962	6	56	743	14913	\N	\N	58.237641000000004	Верхнесалдинский район, д.Малыгино, Клуб		0101000020E610000090DAC4C9FD7A4E40299831056B1E4D40
86419	6	56	743	5217	19918	\N	58.326332269877703	поселок Выя, Привокзальная, 12А	Россия, Свердловская область, Верхнесалдинский район, поселок Выя	0101000020E6100000FDDCD0949D484E40B3D1393FC5294D40
85939	6	56	743	12163	17792	\N	58.046481947451099	г.Верхняя Салда, Энгельса, 87,1	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E6100000AFEB17EC864B4E4024ED461FF3054D40
85934	6	56	743	12163	17792	\N	58.070480673831902	г.Верхняя Салда, Энгельса, 87, 2	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E6100000B05758703F4A4E40A4FE7A8505094D40
85931	6	56	743	12163	17792	\N	58.046573000000002	г.Верхняя Салда, Энгельса, 47		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85928	6	56	743	12163	17792	\N	58.046573000000002	г.Верхняя Салда, Энгельса, 40		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85914	6	56	743	12163	17792	\N	58.0467574952985	г.Верхняя Салда, Энгельса, 32	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E61000000CB1FA230C474E40F6ED2422FC054D40
85925	6	56	743	12163	19208	\N	58.041996706399203	г.Верхняя Салда, Фрунзе, 23	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E6100000DE1D19ABCD474E40DBC35E2860054D40
85905	6	56	743	12163	17755	\N	58.046573000000002	г.Верхняя Салда, Труда, 1		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85947	6	56	743	12163	18143	\N	58.046573000000002	г.Верхняя Салда, Спортивная, 17		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85946	6	56	743	12163	18143	\N	58.054422825872003	г.Верхняя Салда, Спортивная, 10	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E610000011A96917D34A4E403A933655F7064D40
85932	6	56	743	12163	18684	\N	58.046573000000002	г.Верхняя Салда, Сабурова, 11		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85913	6	56	743	12163	20192	\N	58.046573000000002	г.Верхняя Салда, Рабочей молодежи, 1		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85911	6	56	743	12163	20356	\N	58.046573000000002	г.Верхняя Салда, Народная стройка, 1А		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85921	6	56	743	12163	9825	\N	58.046800516124797	г.Верхняя Салда, Ленина, 12	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E6100000A794D74AE8464E40C6353E93FD054D40
85907	6	56	743	12163	9825	\N	58.047369470551303	г.Верхняя Салда, Ленина, 64	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E6100000F9A3A833F7464E4010ECF82F10064D40
85944	6	56	743	12163	18349	\N	58.046573000000002	г.Верхняя Салда, Воронова, 13, 1		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85941	6	56	743	12163	18349	\N	58.046573000000002	г.Верхняя Салда, Воронова, 12, 1		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85936	6	56	743	12163	18349	\N	58.046573000000002	г.Верхняя Салда, Воронова, 11		0101000020E6100000F88C446804474E4035F0A31AF6054D40
85917	6	56	743	12163	18622	\N	58.053626589144102	г.Верхняя Салда, Парковая, 1	Россия, Свердловская область, Верхнесалдинский район, Верхняя Салда	0101000020E6100000F146E6913F484E405F97E13FDD064D40
85950	6	56	743	14248	20035	\N	58.306452999999998	Верхнесалдинский район, п.Басьяновский, Ленина, 10		0101000020E61000006F0F4240BE5E4E406B6116DA39274D40
85951	6	56	7068	50239	\N	\N	58.269779999999997	Верхнесалдинский район, п.Ежевичный, Клуб		0101000020E610000060AB048BC3614E40B48EAA2688224D40
85901	6	56	1197	12003	18923	\N	56.748660999999998	село Чернокоровское, Комсомольская, 47		0101000020E6100000B28009DCBA1D4F403465A71FD45F4C40
85892	6	56	1197	11608	18895	\N	56.778007000000002	село Тыгиш, Ленина, 47		0101000020E6100000CAA8328CBBF54E409087BEBB95634C40
85893	6	56	1197	11660	20301	\N	56.788030999999997	село Кунарское, Ленина, 25		0101000020E610000057B2632310F14E40F99D2633DE644C40
85891	6	56	1197	11561	18222	\N	56.796081999999998	село Коменки, 30 Лет Победы, 14		0101000020E61000002368CC24EA094F409677D503E6654C40
84839	6	56	1197	22607	18006	\N	56.664064000000003	село Каменноозерское, Ленина, 5		0101000020E6100000601E32E543EA4E40B939950C00554C40
85902	6	56	1197	47628	20367	\N	56.668471381339501	село Ильинское, Ленина, 22Б	Россия, Свердловская область, Богдановичский район, поселок Ильинское	0101000020E6100000F6EFFACC593D4F4086A92D7590554C40
85894	6	56	1197	11668	18894	\N	56.781517999999998	село Грязновское, Ленина, 46Б		0101000020E6100000029EB47059DB4E401F9E25C808644C40
85900	6	56	1197	11996	20184	\N	56.590890999999999	село Гарашкинское, Ильича, 15А	Россия, Свердловская область, Богдановичский район, поселок Гарашкинское	0101000020E610000000378B170B334F401840F850A24B4C40
85899	6	56	1197	47556	\N	\N	56.739243000000002	село Волковское, Степана Щипачева, 41	Россия, Свердловская область, Богдановичский район, поселок Волковское	0101000020E6100000B83EAC376A2D4F400266BE839F5E4C40
85896	6	56	1197	46685	78582	\N	56.698763999999997	село Байны, Степана Щипачева, 41		0101000020E6100000C79BFC169D104F40A2CF471971594C40
85897	6	56	7038	50173	20176	\N	56.649934000000002	поселок Полдневой, Вокзальная, 5		0101000020E6100000419FC893A40B4F407C478D0931534C40
87209	6	56	7021	50118	\N	\N	56.923664497895601	город Березовский, пос.Кедровка, в/ч	Россия, Свердловская область, городской округ Березовский, Берёзовский	0101000020E61000000116F9F543664E400C3F389F3A764C40
85857	6	56	920	61305	78485	\N	56.746680472082602	"""""""п.Прохладный, гараж ОАО""""""""Косулинское"""""""", Свердлова, 21В"""	Россия, Свердловская область, Белоярский район	0101000020E6100000632827DA55784E40E449D235935F4C40
85869	6	56	920	46982	19910	\N	56.571719000000002	с.Черноусово, Центральная, 5 А	Россия, Свердловская область, Белоярский район, поселок Черноусово	0101000020E610000057EE056685A04E403CC093162E494C40
84508	6	56	920	8500	18815	\N	56.664974000000001	д.Чернобровкина, Ленина, 5 А		0101000020E6100000EE06D15AD1A04E405C5837DE1D554C40
85871	6	56	920	10603	78522	\N	56.591777999999998	с.Хромцово, Калинина, 2А		0101000020E6100000FB95CE8767BB4E40033FAA61BF4B4C40
84721	6	56	920	47012	77065	\N	56.694893999999998	п.Студенческий, Мира, 23 А		0101000020E6100000CCB6D3D688A24E40E3175E49F2584C40
85870	6	56	920	46991	20329	\N	56.5559443824487	п.Совхозный, Первомайская, 4А	Россия, Свердловская область, Белоярский район, поселок Совхозный	0101000020E6100000D9B27C5D86B74E402634492C29474C40
87120	6	56	920	7323	\N	\N	56.708908999999998	поселок Светлый, 42А		0101000020E6100000419E5DBEF5794E40876BB587BD5A4C40
85855	6	56	920	9798	18858	\N	56.855919999999998	п.Режик, Центральная, 39		0101000020E6100000E947C32973B34E4004FF5BC98E6D4C40
85858	6	56	920	46750	19894	\N	56.714520999999998	п.Рассоха, Уральская, 6	Россия, Свердловская область, Белоярский район, поселок Рассоха	0101000020E6100000DA73999A04854E4011A7936C755B4C40
14617	6	56	920	22066	20098	\N	56.693643999999999	д.Поварня, Ленина, 64		0101000020E61000001C7C6132557E4E4087889B53C9584C40
86786	6	56	920	46914	18544	\N	56.655149000000002	поселок Октябрьский, Чапаева, 2Б		0101000020E610000069C878944ABA4E40E98024ECDB534C40
84276	6	56	920	47322	18458	\N	56.675142999999998	с.Некрасово, Ленина, 22		0101000020E61000003788D68A36D34E40C98FF8156B564C40
85859	6	56	920	9994	19132	\N	56.73639	с.Малобрусянское, Ленина, 38		0101000020E61000005DDF878384904E40FC8C0B07425E4C40
85856	6	56	920	50221	20328	\N	56.866543877228999	д.Малиновка, Набережная, 2, кв.2	Россия, Свердловская область, Белоярский район, поселок Малиновка	0101000020E6100000AED689CBF1C04E40C345EEE9EA6E4C40
85864	6	56	920	46867	18830	\N	56.621414000000001	с.Логиново, 8 Марта, 56		0101000020E61000000BD28C45D3A54E4066A3737E8A4F4C40
87992	6	56	920	49968	18950	\N	56.762967000000003	город Заречный, д. Курманка, Юбилейная, 1	Россия, Свердловская область, Белоярский район, поселок Курманка	0101000020E610000093E52494BEA44E40B07614E7A8614C40
86213	6	56	920	10684	19863	\N	56.633125	с.Кочневское, Юбилейная, 2		0101000020E6100000791EDC9DB5BF4E40D7A3703D0A514C40
85872	6	56	920	10684	19162	\N	56.633125	с.Кочневское, Ударников, 9		0101000020E6100000791EDC9DB5BF4E40D7A3703D0A514C40
84311	6	56	920	47971	18823	\N	56.739227999999997	с.Косулино, Уральская, 62		0101000020E61000001807978E397B4E40CC24EA059F5E4C40
85865	6	56	920	10332	19140	\N	56.615336999999997	с.Колюткино, Красноармейская, 3 А		0101000020E61000005DC47762D6974E406682E15CC34E4C40
85867	6	56	920	46937	77077	\N	56.535502000000001	с.Камышево, Школьная, 19		0101000020E6100000A73B4F3C67AB4E40A7785C548B444C40
84049	6	56	920	18065	19329	\N	56.707244000000003	д.Измоденова, Кирова, 32б		0101000020E610000006D7DCD1FFCC4E406825ADF8865A4C40
85868	6	56	920	10494	19907	\N	56.565415999999999	д.Златогорова, Советская, 7		0101000020E610000021CEC3094CAD4E404C512E8D5F484C40
87995	6	56	920	16360	18242	\N	56.800483	город Заречный,  с. Мезенское, Трактовая, 38		0101000020E6100000016A6AD95AAB4E408200193A76664C40
87985	6	56	920	16360	18936	\N	56.795114105414001	город Заречный, Ленинградская, 15а	Россия, Свердловская область, Белоярский район, Заречный	0101000020E61000004583143C85A84E40BE4BA94BC6654C40
87981	6	56	920	16360	18936	\N	56.800965404015699	город Заречный, Ленинградская, 6а	Россия, Свердловская область, Белоярский район, Заречный	0101000020E6100000C4EC65DB69AB4E40CD1E680586664C40
87978	6	56	920	16360	18499	\N	56.800612492189501	город Заречный, Ленина, 27	Россия, Свердловская область, Белоярский район, Заречный	0101000020E610000054E1CFF066A94E4080643A747A664C40
87976	6	56	920	16360	18499	\N	56.802048492302198	город Заречный, Ленина, 22	Россия, Свердловская область, Белоярский район, Заречный	0101000020E610000018CC5F2173A94E403EE94482A9664C40
87973	6	56	920	16360	18499	\N	56.813992389047201	город Заречный, Ленина, 11	Россия, Свердловская область, Белоярский район, Заречный	0101000020E61000001421753BFBA84E40529ACDE330684C40
87984	6	56	920	16360	18272	\N	56.802795122938001	город Заречный, Алещенкова, 22а	Россия, Свердловская область, Белоярский район, Заречный	0101000020E6100000F700DD9733A94E4038328FFCC1664C40
87980	6	56	920	16360	18272	\N	56.8009771768834	город Заречный, Алещенкова, 6	Россия, Свердловская область, Белоярский район, Заречный	0101000020E61000002EE6E786A6A84E4092EC116A86664C40
87971	6	56	920	16360	18272	\N	56.800483	город Заречный, Алещенкова, 19		0101000020E6100000016A6AD95AAB4E408200193A76664C40
87988	6	56	920	16360	17765	\N	56.802341617911402	город Заречный,  п.Муранитный, 50 лет ВЛКСМ, здание офиса ООО ВИЗАВЕСТ	Россия, Свердловская область, Белоярский район, Заречный	0101000020E61000004CE0D6DD3CAB4E40871A8524B3664C40
85860	6	56	920	46780	20056	\N	56.713593000000003	д.Гусева, Ленина, 48	Россия, Свердловская область, Белоярский район, поселок Гусева	0101000020E6100000817C09151C944E40C8D3F203575B4C40
85862	6	56	920	10185	\N	\N	56.750166999999998	п.Гагарский, воинская часть, воинская часть, школа №14		0101000020E61000008196AE601B994E40EBC4E57805604C40
87989	6	56	920	49911	18298	\N	56.766361000000003	город Заречный, д.Гагарка, Клубная, 2	Россия, Свердловская область, Белоярский район, поселок Гагарка	0101000020E610000048C153C895A24E4006F7031E18624C40
89259	6	56	920	15011	18575	\N	56.752338000000002	рабочий поселок Верхнее Дуброво, ул. Строителй, 5		0101000020E610000009DE904605864E40DFC4909C4C604C40
89261	6	56	920	15011	20017	\N	56.7524090422908	рабочий поселок Верхнее Дуброво, ул. Клубная, 8	Россия, Свердловская область, Белоярский район, поселок Верхнее Дуброво	0101000020E6100000C365153603864E40A81B28F04E604C40
84038	6	56	920	17457	17810	\N	56.712862778495399	с.Бруснятское, Советская, 33	Россия, Свердловская область, Белоярский район, поселок Бруснятское	0101000020E610000037C1374D9FC34E40A4C343183F5B4C40
87996	6	56	920	49947	18660	\N	56.781087511763303	город Заречный,  д.Боярка, 8 марта, 12	Россия, Свердловская область, Белоярский район, поселок Боярка	0101000020E6100000384A5E9D63A64E4026A60BB1FA634C40
85863	6	56	920	10193	18161	\N	56.635897	с.Большебрусянское, Школьная, 1		0101000020E61000003DD4B66114A04E40F04FA91265514C40
85866	6	56	920	10393	19143	\N	56.686585000000001	п.Белореченский, Восточная, 14		0101000020E6100000919C4CDC2AAE4E404B766C04E2574C40
85844	6	56	836	9305	18549	\N	57.360657000000003	д. Шаламы, Советская, 9		0101000020E61000003E05C07806D54F40680932022AAE4C40
83941	6	56	836	50096	19857	\N	57.562764000000001	с. Шадринка, Лаптева, 2	Россия, Свердловская область, Байкаловский район, поселок Шадринка	0101000020E61000002DB4739A05BC4F40DEAE97A608C84C40
85842	6	56	836	9219	78419	\N	57.469267000000002	с. Чурманское, Мамарина, 46		0101000020E610000068EA758BC0CC4F40C80BE9F010BC4C40
85840	6	56	836	9101	19956	\N	57.422564000000001	д. Пелевина, Новая, 77		0101000020E6100000DC9C4A0680FE4F40C53BC09316B64C40
85839	6	56	836	9066	78491	\N	57.560321000000002	д. Нижняя Иленка, Советская, 5	Россия, Свердловская область, Байкаловский район, поселок Нижняя Иленка	0101000020E610000093C7D3F2030250408A213999B8C74C40
82483	6	56	836	6126	20060	\N	57.647039999999997	д. Менщикова, Кайгородова, 5		0101000020E610000033A8363811CD4F40179AEB34D2D24C40
85838	6	56	836	9014	19871	\N	57.372709	д. Малая Серкова, Набережная, 3	Россия, Свердловская область, Байкаловский район, поселок Малая Серкова	0101000020E6100000A8DF85ADD9B44F4062F6B2EDB4AF4C40
81220	6	56	836	8774	18732	\N	57.616235000000003	д. Макушина, Центральная, 19		0101000020E6100000682096CD1CEE4F4046D3D9C9E0CE4C40
85837	6	56	836	46314	19869	\N	57.408937999999999	с. Ляпуново, Техническая, 16		0101000020E6100000250516C094BD4F40BB0B941458B44C40
86575	6	56	836	47289	\N	\N	57.3586735689967	"""""""п. Липовка (Водолечебница), Административный корпус СОГУЗ СБВЛ """"""""Липовка"""""""""""""""	Россия, Свердловская область, Байкаловский район, поселок Липовка	0101000020E61000001EFB592C45DE4F4077F69507E9AD4C40
85836	6	56	836	47289	19868	\N	57.359322966973103	д. Липовка, Аникина, 1	Россия, Свердловская область, Байкаловский район, поселок Липовка	0101000020E610000041D7BE805EDE4F40AED9CA4BFEAD4C40
85835	6	56	836	61324	78552	\N	57.530053310777198	с. Краснополянское, Советская, 24	Россия, Свердловская область, Байкаловский район	0101000020E61000001898158A74D54F40C712D6C6D8C34C40
81831	6	56	836	48894	20063	\N	57.617902999999998	д. Игнатьева, Набережная, 262		0101000020E6100000FDBD141E34E54F40D68C0C7217CF4C40
81349	6	56	836	48516	18208	\N	57.633045000000003	с. Елань, Советская, 27		0101000020E610000038BBB54C86D94F40BBF2599E07D14C40
86890	6	56	836	48516	20249	\N	57.631663853017301	село Елань, Кузнецова, 2	Россия, Свердловская область, Байкаловский район, поселок Елань	0101000020E6100000AF5FB01BB6D94F40C007AF5DDAD04C40
85841	6	56	836	46408	20104	\N	57.526181000000001	д. Гуляева, Дзержинского, 48		0101000020E610000073F22213F0045040676325E659C34C40
81250	6	56	836	46586	\N	\N	57.583960761773398	село Гордище	Россия, Свердловская область, Байкаловский район, поселок Городище	0101000020E6100000CF4A5AF10DF74F40DA91EA3BBFCA4C40
81009	6	56	836	46586	20400	\N	57.585267738888199	с. Городище, Советская, 47	Россия, Свердловская область, Байкаловский район, поселок Городище	0101000020E610000015E3FC4D28F64F409AB2D30FEACA4C40
85682	6	56	836	47803	20127	\N	57.501725	д. Вязовка, Советская, 55		0101000020E61000005E656D533CEE4F40F54A598638C04C40
85832	6	56	836	46131	18128	\N	57.398654000000001	с.Байкалово, Октябрьская, 40		0101000020E61000008B8A389D64E14F40B535221807B34C40
85830	6	56	836	46131	19106	\N	57.398654000000001	с.Байкалово, Кузнецова, 10		0101000020E61000008B8A389D64E14F40B535221807B34C40
85833	6	56	836	8775	19861	\N	57.540294000000003	с. Баженовское, Советская, 29		0101000020E6100000153AAFB14BF24F40CE1C925A28C54C40
85801	6	56	734	7279	18021	\N	56.783599000000002	Ачитский район, д. Ялым, Дружбы, 1		0101000020E6100000F0879FFF1E0C4D40D316D7F84C644C40
85826	6	56	734	8316	18808	\N	56.705930000000002	Ачитский район, п. Уфимский, Советская, 130		0101000020E6100000A4A833F790064D40F5A10BEA5B5A4C40
85824	6	56	734	8316	20082	\N	56.705930000000002	Ачитский район, п. Уфимский, Железнодорожная, 11А		0101000020E6100000A4A833F790064D40F5A10BEA5B5A4C40
85798	6	56	734	7080	17890	\N	56.797663999999997	Ачитский район, д. Тюш, Трактовая, 22А		0101000020E6100000C0CC77F0132D4D4028999CDA19664C40
85812	6	56	734	7754	17896	\N	56.742097000000001	Ачитский район, д. Судницына, Мира, 13		0101000020E61000005516855D14154D40D8BAD408FD5E4C40
85794	6	56	734	6926	17884	\N	56.808732390599502	Ачитский район, д. Сарга, Уральская, 5	Россия, Свердловская область, Ачитский район, поселок Сарга (Грачи)	0101000020E61000006BB8C83D5D154D40459DB98784674C40
85773	6	56	734	5859	18416	\N	56.884580999999997	Ачитский район, с. Русский Потам, Трактовая, 13		0101000020E6100000344B02D4D4084D40DCD440F339714C40
85770	6	56	734	5715	19027	\N	56.894297000000002	Ачитский район, д. Русские Карши, Красных Партизан, 19		0101000020E61000009A9658198DF64C4099F4F75278724C40
85795	6	56	734	7019	18061	\N	56.782809999999998	Ачитский район, д. Осыпь, Центральная, 52		0101000020E61000007C9A931799184D40AA7D3A1E33644C40
85809	6	56	734	7639	19996	\N	56.719323000000003	Ачитский район, д. Нижний Арий, 50 лет Октября, 1А		0101000020E6100000290989B48D194D405C21ACC6125C4C40
85776	6	56	734	6074	18422	\N	56.829345000000004	Ачитский район, д. Марийские Карши, Ленина, 24		0101000020E6100000664AEB6F09084D40F20C1AFA276A4C40
85783	6	56	734	6340	17887	\N	57.010074227473901	Ачитский район, д. Малый Ут, Светлая, 13	Россия, Свердловская область, Ачитский район, поселок Малый Ут	0101000020E6100000E3C5C21039F94C401C45D61A4A814C40
85784	6	56	734	6495	20267	\N	56.980682274670897	Ачитский район, д. Лямпа, Труда, 34А	Россия, Свердловская область, Ачитский район, поселок Лямпа	0101000020E6100000AEF199EC9FF94C4050E3DEFC867D4C40
85763	6	56	734	5322	19011	\N	56.856363000000002	Ачитский район, д. Кочкильда, Центральная, 18		0101000020E61000002194F77134FF4C409240834D9D6D4C40
85788	6	56	734	6618	19390	\N	56.935001	Ачитский район, д. Корзуновка, Молодёжная, 1		0101000020E6100000B41D5377651D4D40185DDE1CAE774C40
85817	6	56	734	8042	18304	\N	56.621532999999999	Ачитский район, д. Коневка, Пролетарская, 33		0101000020E6100000C1E09A3BFA314D404031B2648E4F4C40
85808	6	56	734	7559	18723	\N	56.579414999999997	Ачитский район, д. Кирчигаз, Центральная, 35		0101000020E6100000793D98141F234D40EAE74D452A4A4C40
85821	6	56	734	8262	18938	\N	56.624861000000003	Ачитский район, д. Катырева, Советская, 4		0101000020E6100000CC07043A933E4D40DFC5FB71FB4F4C40
85806	6	56	734	7504	18915	\N	56.619121	Ачитский район, с. Карги, Ленина, 23		0101000020E6100000A37895B54D214D4027A25F5B3F4F4C40
85799	6	56	734	7219	17891	\N	56.742047276115997	Свердловская область, Ачитский район, п. Заря, Советская, 29	Россия, Свердловская область, Ачитский район, поселок Заря	0101000020E6100000B612BA4BE2FA4C40268C6665FB5E4C40
85820	6	56	734	8111	20065	\N	56.592064999999998	Ачитский район, д. Еманзельга, Новая, 12		0101000020E61000008D0DDDEC0F2E4D40990D32C9C84B4C40
85775	6	56	734	61330	78574	\N	56.920479545688799	Ачитский район, д. ВерхПотам, Школьная, 2	Россия, Свердловская область, Ачитский район, поселок Верхний Потам	0101000020E6100000227024D060014D40A04FE449D2754C40
85813	6	56	734	7816	18501	\N	56.696446000000002	Ачитский район, д. Верхний  Арий, Свердлова, 32		0101000020E61000004774CFBA46254D400BB77C2425594C40
85768	6	56	734	61325	78555	\N	56.896090000000001	Ачитский район, д. ВерхТиса, Центральная, 11	Россия, Свердловская область, Ачитский район, поселок Верх-Тиса	0101000020E61000008028983105EB4C40E622BE13B3724C40
85767	6	56	734	5487	18747	\N	56.894419999999997	Ачитский район, с. Быково, Трактовая, 41		0101000020E6100000E7E099D024CF4C40B471C45A7C724C40
85781	6	56	734	6277	19381	\N	57.012112000000002	Ачитский район, с. Большой Ут, Молодежная, 2		0101000020E61000004D486B0C3AFF4C40D0F1D1E28C814C40
85765	6	56	734	5432	18746	\N	56.883091	Ачитский район, с. Бакряж, Советская, 2а		0101000020E610000093DFA293A5DA4C402B323A2009714C40
85758	6	56	734	5111	20041	\N	56.790398000000003	Ачитский район, р.п. Ачит, Ленина, 4		0101000020E6100000ED0C535BEAF24C407369FCC22B654C40
85760	6	56	734	5111	17938	\N	56.790398000000003	Ачитский район, р.п. Ачит, Ленина, 3		0101000020E6100000ED0C535BEAF24C407369FCC22B654C40
85789	6	56	734	6701	18191	\N	56.819887999999999	Ачитский район, с.  Афанасьевское, Советская, 5		0101000020E610000070287CB60E244D4001310917F2684C40
85792	6	56	734	6798	20083	\N	56.852839000000003	Ачитский район, п. Афанасьевский, Беляева, 27		0101000020E610000043209738F22A4D406EE00ED4296D4C40
85779	6	56	734	6130	20057	\N	56.849983999999999	Ачитский район, д. Артемейкова, Гагарина, 17		0101000020E610000063096B63EC084D40C70F9546CC6C4C40
85804	6	56	7037	50172	20174	\N	56.723235000000003	Ачитский район, д. Гайны, пер. Школьный, 1		0101000020E6100000A1496249B9034D404A29E8F6925C4C40
85815	6	56	7054	50195	20224	\N	56.622905000000003	Ачитский район, с. Ключ, Ленина, 37		0101000020E6100000492EFF21FD344D40E8C1DD59BB4F4C40
89280	6	56	7032	50160	20137	\N	57.088189226504298	поселок Рефтинский, Юбилейная, 1а	Россия, Свердловская область, городской округ Асбест, поселок Рефтинский	0101000020E6100000276A696E85D64E40F86EF3C6498B4C40
85751	6	56	446	4704	18705	\N	56.157228000000003	Артинский район, д. Черкасовка, Молодежная, 17		0101000020E6100000967840D9946F4D40FC010F0C20144C40
85738	6	56	446	3984	19091	\N	56.396512999999999	Артинский район, д. Чекмаш, Трактовая, 5		0101000020E6100000EAE8B81AD9394D402CB81FF0C0324C40
85715	6	56	446	61329	78572	\N	56.415129	Артинский район, поселок УстьЮгуш, 8 марта, 1	Россия, Свердловская область, Артинский район, поселок Усть-Югуш	0101000020E6100000C05DF6EB4E514D40834F73F222354C40
85752	6	56	446	4764	20001	\N	56.542876999999997	Артинский район, с. УстьМанчаж, Школьная, 4		0101000020E61000000E677E3507164D40136058FE7C454C40
85730	6	56	446	3598	18662	\N	56.409134999999999	Артинский район, д. Токари, Пролетарская, 4		0101000020E61000008E5BCCCF0D114D40115322895E344C40
85750	6	56	446	4701	19327	\N	56.152037999999997	Артинский район, с. Сухановка, Ленина, 179		0101000020E610000091B932A8365C4D40E7DF2EFB75134C40
85748	6	56	446	4585	18585	\N	56.315345999999998	Артинский район, с. Старые Арти, Ленина, 159		0101000020E6100000240B98C0AD4B4D405376FA415D284C40
85742	6	56	446	4206	18680	\N	56.257362999999998	Артинский район, д. Соколята, Победы, 41		0101000020E61000003997E2AAB20B4D40A8195245F1204C40
85745	6	56	446	4363	19318	\N	56.432834	Артинский район, с. Симинчи, Советская, 1а		0101000020E61000005DF8C1F9D4294D40664CC11A67374C40
85749	6	56	446	4590	18343	\N	56.257187999999999	Артинский район, д. Сенная, Свердлова, 242		0101000020E610000093FE5E0A0F544D403A765089EB204C40
85728	6	56	446	49840	17800	\N	56.472257844722002	Артинский район, с. Манчаж, Школьная, 15	Россия, Свердловская область, Артинский район	0101000020E61000000D33349E08124D401EA33CF3723C4C40
85743	6	56	446	4302	17835	\N	56.198495000000001	Артинский район, с. Свердловское, Ленина, 34		0101000020E61000006AC2F693312C4D40B3B5BE4868194C40
85740	6	56	446	4105	19981	\N	56.323067999999999	Артинский район, с. Сажино, Ленина, 19		0101000020E6100000BFEE74E789194D402B31CF4A5A294C40
85737	6	56	446	61309	78505	\N	56.447558089280598	Артинский район, с. Пристань, Советская, 8	Россия, Свердловская область, Артинский район, поселок Пристань	0101000020E610000002637D0393474D4016889E9449394C40
85734	6	56	446	3792	18666	\N	56.234454999999997	Артинский район, с. Поташка, Юбилейная, 20		0101000020E6100000BE840A0E2F664D401CB1169F021E4C40
85733	6	56	446	3736	20390	\N	56.366180999999997	Артинский район, д. Пантелейково, Трактовая, 49а		0101000020E61000003750E09D7C484D4052B5DD04DF2E4C40
85722	6	56	446	3149	20255	\N	56.260348	Артинский район, д. Омельково, Заречная, 232		0101000020E610000094F947DFA42B4D401DCA501553214C40
85731	6	56	446	3646	18306	\N	56.221184000000001	Артинский район, с. Новый Златоуст, Кирова, 1		0101000020E610000096B1A19BFD394D400133DFC14F1C4C40
85747	6	56	446	4519	78518	\N	56.469796000000002	Артинский район, д. Нижний Бардым, Школьная, 7		0101000020E610000062A1D634EF204D4054E57B46223C4C40
85726	6	56	446	3375	19963	\N	56.162821999999998	Артинский район, с. Малая Тавра, Советская, 7		0101000020E610000099BB96900F144D40DF88EE59D7144C40
85721	6	56	446	3073	18944	\N	56.333584000000002	Артинский район, д. Малая Дегтярка, Культуры, 21		0101000020E6100000CCD24ECDE5204D40043C69E1B22A4C40
85723	6	56	446	3220	18711	\N	56.497183	Артинский район, с. Курки, Заречная, 54		0101000020E6100000D0251C7A8B3D4D4047904AB1A33F4C40
85741	6	56	446	4150	19308	\N	56.355663999999997	Артинский район, д. Конево, Советская, 21		0101000020E6100000D942908312144D40A92EE065862D4C40
85729	6	56	446	3528	17801	\N	56.479743999999997	Артинский район, д. Кадочниково, Трактовая, 23а		0101000020E61000005D363AE7A7064D40E2395B40683D4C40
85717	6	56	446	61312	78531	\N	56.512109969932503	Артинский район, д. ДружиноБардым, Советская, 151	Россия, Свердловская область, Артинский район, поселок Дружино-Бардым	0101000020E61000001E8D43FD2E1E4D402FFA0AD28C414C40
85746	6	56	446	4431	78512	\N	56.4243337615261	Артинский район, д. Верхний Бардым, Трактовая, 12	Россия, Свердловская область, Артинский район, поселок Верхний Бардым	0101000020E6100000AC3C81B053244D405A4A969350364C40
85720	6	56	446	3035	17764	\N	56.301578877957603	Артинский район, д. Большие Карзи, Советская, 20	Россия, Свердловская область, Артинский район, поселок Большие Карзи	0101000020E61000008B36C7B94D2C4D40871403249A264C40
85718	6	56	446	2907	19958	\N	56.525827	Артинский район, д. Биткино, Советская, 48		0101000020E6100000C64E78094E1B4D40492D944C4E434C40
85736	6	56	446	3894	18671	\N	56.210867999999998	Артинский район, д. Березовка, Трактовая, 3		0101000020E610000063601DC70F754D40EFE2FDB8FD1A4C40
85719	6	56	446	2973	20379	\N	56.283070000000002	Артинский район, с. Бараба, Юбилейная, 11		0101000020E6100000CDE506431D2C4D40473D44A33B244C40
85895	6	56	446	2973	19952	\N	56.283070000000002	село Бараба, Ленина, 59а		0101000020E6100000CDE506431D2C4D40473D44A33B244C40
85753	6	56	446	4849	\N	\N	56.553868000000001	Артинский район, д. Бакийково, Азенбаева, 32	Россия, Свердловская область, Артинский район, поселок Бакийково	0101000020E6100000F96A47718E144D4085268925E5464C40
85727	6	56	446	3435	19966	\N	56.130949000000001	Артинский район, д. Багышково, Советская, 51		0101000020E61000004969368FC31C4D40D238D4EFC2104C40
85739	6	56	446	4044	18327	\N	56.458168999999998	Артинский район, д. Афонасково, Новая, 3		0101000020E610000055DB4DF04D434D4040852348A53A4C40
85735	6	56	446	3833	19296	\N	56.317489632614802	Артинский район, д. АртяШигири, Школьная, 8	Россия, Свердловская область, Артинский район, поселок Артя-Шигири	0101000020E61000001E882CD2C45B4D404D672783A3284C40
85711	6	56	446	2518	18270	\N	56.426552282355097	Артинский район, поселок Арти, Фрунзе, 145	Россия, Свердловская область, Артинский район, поселок Арти	0101000020E61000002D98F8A3A8434D408E05854199364C40
85725	6	56	446	2518	19254	\N	56.416276000000003	Артинский район, поселок Арти, Лесная, 2		0101000020E610000091B41B7DCC434D400B0E2F8848354C40
85714	6	56	446	2518	18932	\N	56.416276000000003	Артинский район, поселок Арти, Ленина, 258		0101000020E610000091B41B7DCC434D400B0E2F8848354C40
85713	6	56	446	2518	18932	\N	56.416276000000003	Артинский район, поселок Арти, Ленина, 82		0101000020E610000091B41B7DCC434D400B0E2F8848354C40
85712	6	56	446	2518	18268	\N	56.415229364016596	Артинский район, поселок Арти, Королева, 50	Россия, Свердловская область, Артинский район, поселок Арти	0101000020E610000089EAAD81AD444D40E6AC4F3926354C40
85667	6	56	446	2518	77070	\N	56.416276000000003	Артинский район, поселок Арти, Дерябина, 13		0101000020E610000091B41B7DCC434D400B0E2F8848354C40
85744	6	56	446	4358	20221	\N	56.224626999999998	Артинский район, д. Андрейково, Эрыкана, 32		0101000020E61000009B711AA20A2B4D403866D993C01C4C40
85716	6	56	446	2786	19393	\N	56.538013999999997	Артинский район, с. Азигулово, Советская, 37		0101000020E6100000E35295B6B8264D4023658BA4DD444C40
85732	6	56	7050	50187	20204	\N	56.478242999999999	Артинский, Манчаж, Школьная 15, СОЦ	Россия, Свердловская область, Артинский район, поселок Манчаж	0101000020E61000006CE8667FA0124D403D450E11373D4C40
85724	6	56	7050	50235	20383	\N	56.181894999999997	Артинский район, с. Малые Карзи, Юбилейная, 6а		0101000020E610000025917D9065314D402827DA5548174C40
85690	6	56	11	1255	18197	\N	57.447643999999997	Артемовский городской округ, с. Шогринское, 8 Марта, 36Б		0101000020E610000008ABB184B5FD4E4014200A664CB94C40
85681	6	56	11	61125	77306	\N	57.371276243047603	Артемовский городской округ,п. Сосновый Бор, Черемушки, 6	Россия, Свердловская область, Артемовский район, поселок Сосновый Бор	0101000020E61000001A6EC0E787214F4015E5D2F885AF4C40
85695	6	56	11	49898	18210	\N	57.348233	Артемовский городской округ, с. Покровское, Красных Партизан, 3	Россия, Свердловская область, Артемовский район, поселок Покровское	0101000020E6100000653909A52FD84E40A93121E692AC4C40
85684	6	56	11	892	18878	\N	57.364550999999999	Артемовский городской округ, п. Писанец, Школьная, 3		0101000020E61000000C1F115322134F40AF5C6F9BA9AE4C40
85702	6	56	11	1935	18620	\N	57.497694748822298	Артемовский городской округ, п. Незевай, Школьная, 1	Россия, Свердловская область, Артемовский район, поселок Незевай	0101000020E6100000185DDE1CAEE74E40FD304278B4BF4C40
85691	6	56	11	50109	19925	\N	57.390748000000002	Артемовский городской округ, с. Мостовское, Ленина, 18	Россия, Свердловская область, Артемовский район, поселок Мостовское	0101000020E6100000BF9B6ED921F84E401C7DCC0704B24C40
85700	6	56	11	1812	18892	\N	57.471580000000003	Артемовский городской округ, с. Липино, Школьная, 3А		0101000020E6100000EDF2AD0FEBD74E404EB9C2BB5CBC4C40
85686	6	56	11	1003	19165	\N	57.542946000000001	Артемовский городской округ, с. Лебедкино, Гагарина, 1		0101000020E6100000CCF09F6EA01E4F403CBF28417FC54C40
85677	6	56	11	449	19141	\N	57.376975000000002	Артемовский городской округ, Красногвардейский, Усиевича, 16		0101000020E6100000EACF7EA488284F406E3480B740B04C40
85675	6	56	11	449	19902	\N	57.377974099076198	Артемовский городской округ, п. Красногвардейский, Некрасова, 1	Россия, Свердловская область, Артемовский район, поселок Красногвардейский	0101000020E61000007460394206284F40815EB87361B04C40
85678	6	56	11	449	19906	\N	57.376975000000002	Артемовский городской округ,п. Красногвардейский, Комсомольская, 2А		0101000020E6100000EACF7EA488284F406E3480B740B04C40
85666	6	56	11	14	20322	\N	57.276538000000002	Артемовский городской округ, п. Буланаш, Театральная, 1	Россия, Свердловская область, Артемовский район, поселок Буланаш	0101000020E610000063EC8497E0FE4E40F60CE19865A34C40
85663	6	56	11	14	19128	\N	57.278967283471196	Артемовский городской округ,п. Буланаш, Кутузова, 23А	Россия, Свердловская область, Артемовский район, поселок Буланаш	0101000020E6100000363CBD5296FF4E40E5D4CE30B5A34C40
85671	6	56	11	14	18577	\N	57.276538000000002	Артемовский городской округ, п. Буланаш, Комсомольская, 7		0101000020E610000063EC8497E0FE4E40F60CE19865A34C40
85669	6	56	11	14	18577	\N	57.276538000000002	Артемовский городской округ,п. Буланаш, комсомольская, 21		0101000020E610000063EC8497E0FE4E40F60CE19865A34C40
85662	6	56	11	14	18565	\N	57.276538000000002	Артемовский городской округ,п. Буланаш, Грибоедова, 1		0101000020E610000063EC8497E0FE4E40F60CE19865A34C40
85673	6	56	11	14	18157	\N	57.276538000000002	Артемовский городской округ, п. Буланаш, Белинского, 32	Россия, Свердловская область, Артемовский район, поселок Буланаш	0101000020E610000063EC8497E0FE4E40F60CE19865A34C40
85688	6	56	11	1130	18880	\N	57.587913	Артемовский городской округ, село Бичур, Советская, 2А	Россия, Свердловская область, Артемовский район, поселок Бичур	0101000020E61000000B42791F47134F4056F2B1BB40CB4C40
85654	6	56	11	2059	19880	\N	57.336522000000002	г.Артемовский, Чайковского, 2А		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85645	6	56	11	2059	20251	\N	57.3507665292639	г.Артемовский, Станционная, 1К	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E610000000C974E8F4F04E400DC2DCEEE5AC4C40
85703	6	56	11	2059	19197	\N	57.336522000000002	Артемовский городской округ, г. Артемовский, Прилепского, 2А		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85653	6	56	11	2059	77067	\N	57.336522000000002	г.Артемовский, Площадь Советов, 6		0101000020E61000009AEFE0270EF24E403831242713AB4C40
84692	6	56	11	2059	18085	\N	57.336522000000002	г.Артемовский, пер.Заводской, 2а		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85827	6	56	11	2059	18813	\N	57.3410006790902	Свердловская область, Артемовский городской округ,г. Артемовский, Ж/Д вокзал, Октябрьская, 5	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E6100000D4EE5701BEF14E409F73B7EBA5AB4C40
85649	6	56	11	2059	18818	\N	57.336522000000002	г.Артемовский, Мира, 13		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85648	6	56	11	2059	18818	\N	57.344008309482298	г.Артемовский, Мира, 17	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E61000004E7FF62345F04E40FCC7427408AC4C40
85646	6	56	11	2059	18818	\N	57.336522000000002	г.Артемовский, Мира, 14		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85660	6	56	11	2059	18168	\N	57.341399222259199	Артемовский городской округ, Лесная, 23	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E6100000A5A31CCC26F24E408DF161F6B2AB4C40
85658	6	56	11	2059	18168	\N	57.337184749190598	Артемовский городской округ, Лесная, 10	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E610000015731074B4F24E40D3D9C9E028AB4C40
81368	6	56	11	2059	77062	\N	57.336522000000002	г.Артемовский, Кронштадтская, 12		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85647	6	56	11	2059	20092	\N	57.336522000000002	г.Артемовский, Красный Луч, 37а		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85705	6	56	11	2059	77426	\N	57.338051	Артемовский городской округ,г. Артемоваский, Котовского, 4	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E6100000F015DD7A4DF34E40A7B0524145AB4C40
85651	6	56	11	2059	19872	\N	57.336522000000002	г.Артемовский, Комсомольская, 2		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85650	6	56	11	2059	19872	\N	57.336522000000002	г.Артемовский, Комсомольская, 6		0101000020E61000009AEFE0270EF24E403831242713AB4C40
85643	6	56	11	2059	20086	\N	57.336522000000002	г.Артемовский, 8 Марта, 66	Россия, Свердловская область, Артемовский район, Артёмовский	0101000020E61000009AEFE0270EF24E403831242713AB4C40
3169	5	54	7205	52645	74573	\N	58.714565999999998	Парабель, Шишкова, 75, телефон: 21548		0101000020E61000008F54DFF945605440B16A10E6765B4D40
85697	6	56	7020	50112	19933	\N	57.486730999999999	Артемовский городской округ, с. Мироново, Школьный переулок, 5		0101000020E6100000AF06280D35DC4E4085798F334DBE4C40
85694	6	56	7067	50228	20349	\N	57.353772999999997	Артемовский городской округ,с. Большое Трифоново, Советская, 13		0101000020E61000008D96033DD4E84E40999A046F48AD4C40
81658	6	56	481	29732	18068	\N	57.869375544663299	деревня Ячменёва, Центральная, 31	Россия, Свердловская область, Алапаевский район, поселок Ячменёва	0101000020E61000000DFB3DB14E1D4F40B2F677B647EF4C40
85623	6	56	481	20288	19357	\N	57.940378000000003	поселок Ясашная, Клубная, 11		0101000020E61000005E82531F48964E405FF0694E5EF84C40
82240	6	56	481	47956	78500	\N	57.773764	село Ярославское, Матвеева, 18	Россия, Свердловская область, Алапаевский район, поселок Ярославское	0101000020E61000005AD76839D0094F403C69E1B20AE34C40
82364	6	56	481	19522	18404	\N	57.744494000000003	село Ялунинское, Мира, 49 а		0101000020E610000066F6798CF2FE4E40BC0853944BDF4C40
85638	6	56	481	19210	78498	\N	58.519956999999998	поселок Хабарчиха, Школьная, 10		0101000020E610000014083BC5AADF4E40C32973F38D424D40
83991	6	56	481	50226	20347	\N	58.4979508199945	село Фоминское, Центральная, 8	Россия, Свердловская область, Алапаевский район, поселок Фоминское	0101000020E6100000A987687407194F405801BEDBBC3F4D40
85624	6	56	481	30324	19358	\N	57.873638999999997	село Толмачёво, Ленина, 28		0101000020E610000066683C11C4E54E404CC11A67D3EF4C40
85617	6	56	481	29977	20067	\N	58.159844999999997	поселок Строкинка, Почтовая, 72		0101000020E6100000E63BF88903F84E40EDB60BCD75144D40
84520	6	56	481	9008	20315	\N	58.473135999999997	поселок Санкино, Кедровая, 10	Россия, Свердловская область, Алапаевский район, поселок Санкино	0101000020E6100000B682A625564C4F40B6476FB88F3C4D40
83636	6	56	481	29787	20168	\N	57.604166999999997	поселок Самоцвет, Школьная, 40	Россия, Свердловская область, Алапаевский район, поселок Самоцвет	0101000020E6100000008C67D0D0E34E404529215855CD4C40
83788	6	56	481	50157	20126	\N	57.557651	село Раскатиха, Ленина, 23	Россия, Свердловская область, Алапаевский район, поселок Раскатиха	0101000020E6100000028063CF9EDD4E4075CAA31B61C74C40
85630	6	56	481	61327	78560	\N	57.959830791767303	деревня Первунова, Победы, 8	Россия, Свердловская область, Алапаевский район, поселок Первунова	0101000020E61000000B7DB08C0D1D4F40EF5701BEDBFA4C40
85626	6	56	481	30412	20287	\N	57.948990999999999	село Нижняя Синячиха, Спиридоновская, 47	Россия, Свердловская область, Алапаевский район, поселок Нижняя Синячиха	0101000020E6100000D1217024D0E24E4063997E8978F94C40
81536	6	56	481	19406	78408	\N	57.919921000000002	село Невьянское, Ленина, 55		0101000020E61000006728EE7893214F40AAF3A8F8BFF54C40
84191	6	56	481	21925	78506	\N	58.435006999999999	поселок Муратково, Лесников, 14		0101000020E6100000842C0B26FE324F40FA43334FAE374D40
83928	6	56	481	49980	19100	\N	58.387581373557801	село Мугай, 70 лет Октября, 17	Россия, Свердловская область, Алапаевский район, поселок Мугайское	0101000020E6100000B69F8CF161C84E4086C613419C314D40
85430	6	56	481	21345	18060	\N	57.932336999999997	деревня Михалёва, Школьная, 3		0101000020E61000001E8B6D52D12E4F40E5EC9DD156F74C40
85632	6	56	481	30722	18481	\N	58.455762999999997	поселок городского типа Махнёво, Профсоюзная, 2 б	Россия, Свердловская область, Алапаевский район, поселок Махнёво	0101000020E6100000ACE3F8A1D2DA4E4009DD2571563A4D40
85635	6	56	481	30722	19086	\N	58.455762999999997	поселок городского типа Махнёво, Победы, 23	Россия, Свердловская область, Алапаевский район, поселок Махнёво	0101000020E6100000ACE3F8A1D2DA4E4009DD2571563A4D40
85634	6	56	481	30722	19086	\N	58.455762999999997	поселок городского типа Махнёво, Победы, 102		0101000020E6100000ACE3F8A1D2DA4E4009DD2571563A4D40
85633	6	56	481	30722	19086	\N	58.455762999999997	поселок городского типа Махнёво, Победы, 32		0101000020E6100000ACE3F8A1D2DA4E4009DD2571563A4D40
83418	6	56	481	61304	78480	\N	57.581052	поселок КурортСамоцвет, Центральная, 15	Россия, Свердловская область, Алапаевский район, поселок Курорт ''Самоцвет''	0101000020E6100000DB17D00B77E04E4040A374E95FCA4C40
85618	6	56	481	19729	78516	\N	57.581052	поселок Курорт Самоцвет, Курортная, 28		0101000020E6100000DB17D00B77E04E4040A374E95FCA4C40
81724	6	56	481	46879	18202	\N	57.849148999999997	село Костино, Молодежная, 3		0101000020E6100000E59D4319AA144F402E3718EAB0EC4C40
82423	6	56	481	47067	18946	\N	57.707368000000002	село Коптелово, Красных орлов, 52		0101000020E6100000F94D61A582EE4E40541EDD088BDA4C40
86209	6	56	481	49027	19859	\N	58.443373000000001	д.Кокшарова, Школьная, 2 А		0101000020E6100000CF2C095053E54E40F7764B72C0384D40
82006	6	56	481	14776	18736	\N	57.812624999999997	село Клевакино, Центральная, 30		0101000020E610000022382EE3A60E4F40BC74931804E84C40
85641	6	56	481	31165	78509	\N	58.461153000000003	село Кишкинское, Корелина, 1		0101000020E61000001958C7F143F14E40E5B9BE0F073B4D40
85628	6	56	481	45812	20290	\N	57.996344000000001	село Кировское, Школьная, 9		0101000020E61000006286C61341084F406DC83F3388FF4C40
82599	6	56	481	11671	18793	\N	57.646966999999997	деревня Катышка, Красных Партизан, 10		0101000020E6100000B96C74CE4FDF4E40AD4B8DD0CFD24C40
83878	6	56	481	9796	18333	\N	58.229435161199603	село Измоденово, Мира, 18	Россия, Свердловская область, Алапаевский район, поселок Измоденово	0101000020E6100000C843DFDDCADA4E4065C746205E1D4D40
85625	6	56	481	47443	20312	\N	57.8625505358957	поселок Заря, Набережная, 20	Россия, Свердловская область, Алапаевский район, поселок Заря	0101000020E6100000338CBB41B4DC4E40E910381268EE4C40
85616	6	56	481	29934	78503	\N	58.112428999999999	поселок Ельничная, Клубная, 17		0101000020E61000008D614ED026F14E409D0FCF12640E4D40
83833	6	56	481	47649	19973	\N	57.568112999999997	село Деево, Ленина,34		0101000020E610000085B01A4B58D54E405AB741EDB7C84C40
81374	6	56	481	16063	18378	\N	57.943522000000002	село Голубковское, 60 лет Октября, 9		0101000020E6100000FB57569A94404F403C873254C5F84C40
85455	6	56	481	19275	\N	\N	58.025857000000002	поселок Гаранинка, Союзов, 2	Россия, Свердловская область, Алапаевский район, поселок Гаранинка	0101000020E61000001C23D923D4364F40B4AF3C484F034D40
87035	6	56	481	2870	18632	\N	57.746285999999998	п. Вогулка, Советская, 66		0101000020E6100000AFCC5B751D084F4038BBB54C86DF4C40
50229	6	55	\N	54925	40600	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Квартал Новостроек, 17		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
85621	6	56	481	19942	19834	\N	57.992528638080699	рабочий поселок Верхняя Синячиха, Октябрьская, 16 а	Россия, Свердловская область, Алапаевский район, поселок Верхняя Синячиха	0101000020E61000009CC58B8521D84E4071AAB5300BFF4C40
85620	6	56	481	19942	19834	\N	57.990203999999999	рабочий поселок Верхняя Синячиха, Октябрьская, 2 а		0101000020E61000002F151BF33AD64E40272F3201BFFE4C40
82179	6	56	481	19942	19834	\N	57.990203999999999	рабочий поселок Верхняя Синячиха, Октябрьская, 17		0101000020E61000002F151BF33AD64E40272F3201BFFE4C40
85622	6	56	481	19942	9903	\N	57.990203999999999	рабочий поселок Верхняя Синячиха, Ленина, 23		0101000020E61000002F151BF33AD64E40272F3201BFFE4C40
85404	6	56	481	19942	78418	\N	57.990203999999999	рабочий поселок Верхняя Синячиха, Красной Гвардии, 11		0101000020E61000002F151BF33AD64E40272F3201BFFE4C40
85619	6	56	481	19942	18782	\N	57.990203999999999	рабочий поселок Верхняя Синячиха, Бажова, 46		0101000020E61000002F151BF33AD64E40272F3201BFFE4C40
81915	6	56	481	10502	19930	\N	57.816057000000001	деревня Бутакова, Советская, 7		0101000020E61000000116F9F543144F400056478E74E84C40
85615	6	56	481	20293	19824	\N	58.136172999999999	поселок Бубчиково, Ленина,2		0101000020E6100000CD5B751DAADB4E4092CCEA1D6E114D40
85637	6	56	481	31025	20296	\N	58.425494	деревня Большая Ерзовка, Центральная, 21		0101000020E610000068AF3E1EFAE44E4076525F9676364D40
84084	6	56	481	19834	20266	\N	58.521889000000002	село Болотовское, Центральная, 15		0101000020E6100000581AF8510D3B4F4032923D42CD424D40
85629	6	56	481	50216	20308	\N	57.989391296784802	деревня Бобровка, Клубная, 11	Россия, Свердловская область, Алапаевский район, поселок Бобровка	0101000020E6100000145AD6FD63154F4076FA415DA4FE4C40
83103	6	56	481	4039	78417	\N	57.606067000000003	село Арамашево, Школьная, 1		0101000020E61000007A7077D66EDD4E40A9177C9A93CD4C40
84664	6	56	7035	50201	20238	\N	58.550500535041699	поселок Калач, Центральная, 29	Россия, Свердловская область, Алапаевский район, поселок Калач	0101000020E610000012F8C3CF7F834F4028B517D176464D40
86137	6	56	7071	61092	77183	\N	56.469772551579901	Каменский район, с.Покровское, Ленина, 128	Россия, Свердловская область, городской округ Каменск-Уральский, поселок Покровское	0101000020E6100000501DAB949ECF4E409CC58B85213C4C40
49272	6	55	\N	60715	75683	\N	55.447631999999999	Курганская область, город Курган, Отдыха, 7А		0101000020E61000004ED4D2DC0A545040505260014CB94B40
50330	6	55	\N	54993	41071	\N	55.373859000000003	Курганская область, Юргамышский район, п. Юргамыш, Энергетиков, 22А		0101000020E6100000842BA0504F1D50405B28999CDAAF4B40
50264	6	55	\N	54952	\N	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, пос. Элеваторский, д. 2		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50260	6	55	\N	54952	40688	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, пл. Победы, д. 3		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50258	6	55	\N	54952	40912	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. Школьная, д. 19		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50259	6	55	\N	54952	41441	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. Пролетарская, д. 1		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50266	6	55	\N	54952	40701	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. Мира, д. 34		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50265	6	55	\N	54952	41067	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. им. Маршала Жукова Г. К, д. 5		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50261	6	55	\N	54952	41691	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. Ленина, д. 9		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50263	6	55	\N	54952	40827	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. Калинина, д. 20		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50267	6	55	\N	54952	41442	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. К. Маркса, д. 33		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50262	6	55	\N	54952	41250	\N	55.211300999999999	Курганская область, Щучанский район, город Щучье, ул. 1ое Мая, д. 45		0101000020E6100000C74CA25EF05F4F40594E42E90B9B4B40
50217	6	55	\N	54925	40908	\N	55.230178928412002	Курганская область, Шумихинский район, город Шумиха, Бульвар 50летия Октября, 4	Россия, Курганская область, Шумихинский район, город Шумиха	0101000020E6100000792288F370A64F40ED9C6681769D4B40
50224	6	55	\N	54925	40685	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Советская, 91		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50212	6	55	\N	54925	40685	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Советская, 36		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50216	6	55	\N	54925	40819	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Смолина, 36		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50228	6	55	\N	54925	40487	\N	55.232937882597398	Курганская область, Шумихинский район, город Шумиха, улица Победы, 21		0101000020E6100000D0285DFA97A64F4071FF91E9D09D4B40
50222	6	55	\N	54925	40821	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Морозова, 56		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50226	6	55	\N	54925	40700	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Магистральная, 1		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50223	6	55	\N	54925	40598	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Ленина, 112		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50219	6	55	\N	54925	40598	\N	55.225898370269398	Курганская область, Шумихинский район, город Шумиха, улица Ленина, 72		0101000020E6100000596B28B517A54F40AC1DC539EA9C4B40
50221	6	55	\N	54925	40698	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Комсомольская, 33		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50218	6	55	\N	54925	40923	\N	55.228302246866903	Курганская область, Шумихинский район, город Шумиха, улица Кирова, 19		0101000020E61000000F4240BE84A44F4042CEFBFF389D4B40
50227	6	55	\N	54925	40813	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Гоголя, 36		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50225	6	55	\N	54925	40813	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Гоголя, 141		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50214	6	55	\N	54925	40813	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Гоголя, 28		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50220	6	55	\N	54925	40910	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, улица Воронкова, 29		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
50213	6	55	\N	54925	41052	\N	55.231160000000003	Курганская область, Шумихинский район, город Шумиха, Бульвар 50летия Октября, 2		0101000020E6100000F85278D0ECA44F405A12A0A6969D4B40
49369	6	55	\N	54957	40730	\N	56.0894583065296	Курганская область, город Шадринск, Свердлова улица, 97	Россия, Курганская область, город Шадринск	0101000020E610000090DB2F9FACD24F40CB2E185C730B4C40
49360	6	55	\N	54957	40730	\N	56.086063203411399	Курганская область, город Шадринск, Свердлова улица, 43		0101000020E61000007B13437232CF4F40A532C51C040B4C40
49353	6	55	\N	54957	41418	\N	56.107214716908402	Курганская область, город Шадринск, Кирова улица, 48		0101000020E6100000E542E55FCBD54F4000529B38B90D4C40
49352	6	55	\N	1010	40653	\N	56.091135000000001	Курганская область, город Шадринск, Энергетиков улица, 11		0101000020E61000002D27A1F485D24F40AF42CA4FAA0B4C40
49351	6	55	\N	1010	40414	\N	56.080100051205797	Курганская область, город Шадринск, Щеткина улица, 4		0101000020E610000091BA9D7DE5D34F406E3480B7400A4C40
50355	6	55	\N	1010	40497	\N	56.091017793811098	Курганская область, город Шадринск, Февральская улица, 197	Россия, Курганская область, город Шадринск	0101000020E610000015CAC2D7D7D24F4075AC527AA60B4C40
49350	6	55	\N	1010	40411	\N	56.089266365251099	Курганская область, город Шадринск, Труда улица, 43	Россия, Курганская область, город Шадринск	0101000020E610000005DF347D76D24F4087527B116D0B4C40
49349	6	55	\N	1010	40411	\N	56.079092102928399	Курганская область, город Шадринск, Труда улица, 1		0101000020E61000005C92037635D74F4008B0C8AF1F0A4C40
49347	6	55	\N	1010	40738	\N	56.090681909600498	Курганская область, город Шадринск, Тобольская улица, 22	Россия, Курганская область, город Шадринск	0101000020E6100000B37DC85BAED24F40FE2AC0779B0B4C40
49363	6	55	\N	1010	40565	\N	56.090627927935202	Курганская область, город Шадринск, Спартака улица, 8		0101000020E61000005A0F5F268AD24F400B0DC4B2990B4C40
49362	6	55	\N	1010	40565	\N	56.090753885036101	Курганская область, город Шадринск, Спартака улица, 18	Россия, Курганская область, город Шадринск	0101000020E6100000A43330F2B2D24F4097FDBAD39D0B4C40
49355	6	55	\N	1010	40565	\N	56.091323685800702	Курганская область, город Шадринск, Спартака улица, 17	Россия, Курганская область, город Шадринск	0101000020E61000009E25C808A8D24F4082AB3C81B00B4C40
50099	6	55	7338	\N	40372	\N	56.089914163216399	Курганская область, город Шадринск, Свердлова улица, 132	Россия, Курганская область, городской округ Шадринск	0101000020E6100000EACA67791ED44F40EDB94C4D820B4C40
49368	6	55	\N	1010	40372	\N	56.088942462165598	Курганская область, город Шадринск, Свердлова улица, 91	Россия, Курганская область, город Шадринск	0101000020E6100000BD56427749D24F40D49E9273620B4C40
49367	6	55	\N	1010	40372	\N	56.0902440561239	Курганская область, город Шадринск, Свердлова улица, 59	Россия, Курганская область, город Шадринск	0101000020E6100000471FF30181D24F4082548A1D8D0B4C40
49364	6	55	7338	\N	40372	\N	56.086543094878898	Курганская область, город Шадринск, Свердлова улица, 49	Россия, Курганская область, городской округ Шадринск	0101000020E6100000B41CE8A1B6CF4F404F594DD7130B4C40
49357	6	55	\N	1010	40372	\N	56.091077772824796	Курганская область, город Шадринск, Свердлова улица, 3	Россия, Курганская область, город Шадринск	0101000020E6100000CDAFE600C1D24F404BB1A371A80B4C40
50359	6	55	7338	\N	40499	\N	56.076872123467503	Курганская область, город Шадринск, Розы Люксембург улица, 1	Россия, Курганская область, городской округ Шадринск	0101000020E610000014EB54F99ED14F4033FD12F1D6094C40
49366	6	55	\N	1010	40499	\N	56.091135000000001	Курганская область, город Шадринск, Розы Люксембург улица, 18		0101000020E61000002D27A1F485D24F40AF42CA4FAA0B4C40
49342	6	55	\N	1010	40734	\N	56.090202069911399	Курганская область, город Шадринск, Проектная улица, 8		0101000020E6100000E066F16261D24F40530438BD8B0B4C40
49348	6	55	\N	1010	40561	\N	56.0874428751994	Курганская область, город Шадринск, Первомайская улица, 63		0101000020E6100000FB07910C39D64F40CFA10C55310B4C40
49344	6	55	\N	1010	40406	\N	56.092595210667596	Курганская область, город Шадринск, Мичурина улица, 6		0101000020E6100000DC679599D2D24F40F6622827DA0B4C40
50358	6	55	\N	1010	40837	\N	56.091479629797703	Курганская область, город Шадринск, Михайловская улица, 180а	Россия, Курганская область, город Шадринск	0101000020E6100000CC7B9C69C2D24F40791EDC9DB50B4C40
50357	6	55	\N	1010	40837	\N	56.090214065976802	Курганская область, город Шадринск, Михайлоская улица, 79	Россия, Курганская область, город Шадринск	0101000020E61000002FFCE07CEAD24F4018D2E1218C0B4C40
49356	6	55	\N	1010	40929	\N	56.091041785427798	Курганская область, город Шадринск, Луначарского улица, 8	Россия, Курганская область, город Шадринск	0101000020E6100000BD8FA339B2D24F40FE47A643A70B4C40
49346	6	55	\N	1010	40649	\N	56.091437644937798	Курганская область, город Шадринск, Ломоносова улица, 12	Россия, Курганская область, город Шадринск	0101000020E61000000A4B3CA06CD24F404ACE893DB40B4C40
49361	6	55	\N	1010	40417	\N	56.081153250121098	Курганская область, город Шадринск, Ленина улица, 95		0101000020E6100000930035B56CD14F40747CB438630A4C40
49358	6	55	\N	1010	40657	\N	56.089764210956901	Курганская область, город Шадринск, Красноармейская улица, 93		0101000020E610000087C43D963ED24F40D82D02637D0B4C40
50380	6	55	\N	1010	75967	\N	56.091135000000001	Курганская область, город Шадринск, Крайняя улица, 17		0101000020E61000002D27A1F485D24F40AF42CA4FAA0B4C40
49343	6	55	\N	1010	40737	\N	56.090999800088703	Курганская область, город Шадринск, Кооперативная улица, 4	Россия, Курганская область, город Шадринск	0101000020E6100000D525E318C9D24F40CFF753E3A50B4C40
49365	6	55	\N	1010	40751	\N	56.091135000000001	Курганская область, город Шадринск, Карла Либкнехта улица, 3		0101000020E61000002D27A1F485D24F40AF42CA4FAA0B4C40
50360	6	55	\N	1010	41285	\N	56.091135000000001	Курганская область, город Шадринск, Демьяна Бедного улица, 5		0101000020E61000002D27A1F485D24F40AF42CA4FAA0B4C40
49354	6	55	\N	1010	40656	\N	56.091287323767901	Курганская область, город Шадринск, Батуринская улица, 34	Россия, Курганская область, город Шадринск	0101000020E6100000AEF4DA6CACD24F4065C6DB4AAF0B4C40
49359	6	55	7338	\N	40739	\N	56.088810500865101	Курганская область, город Шадринск, Архангельского улица, 58	Россия, Курганская область, городской округ Шадринск	0101000020E610000077A22424D2CE4F403543AA285E0B4C40
49345	6	55	\N	1010	40732	\N	56.091461636291903	Курганская область, город Шадринск, Автомобилистов улица, 30		0101000020E61000008E3F51D9B0D24F40D369DD06B50B4C40
49341	6	55	\N	1010	40732	\N	56.089590265601302	Курганская область, город Шадринск, Автомобилистов улица, 84		0101000020E6100000E5D2F88557D24F403A0664AF770B4C40
49340	6	55	\N	1010	40732	\N	56.091135000000001	Курганская область, город Шадринск, Автомобилистов улица, 20		0101000020E61000002D27A1F485D24F40AF42CA4FAA0B4C40
50356	6	55	\N	1010	40494	\N	56.087872044232498	Курганская область, город Шадринск, 4го Уральского полка улица, 30		0101000020E6100000E9F2E670ADD04F40F71DC3633F0B4C40
50061	6	55	\N	54920	40472	\N	54.503013537325799	Курганская область, Целинный район, Целинный сельсовет, село Целинное, ул. Свердлова, дом 48	Россия, Курганская область, Целинный район, поселок сельского типа Целинное	0101000020E61000000AF31E679AD64F400FB743C362404B40
49927	6	55	\N	54919	40505	\N	55.066195	Курганская область, Петуховский район, город Петухово, Чапаева, 62		0101000020E61000003A3DEFC682F850405114E81379884B40
49926	6	55	\N	54919	40888	\N	55.066195	Курганская область, Петуховский район, город Петухово, Строительная, 1А		0101000020E61000003A3DEFC682F850405114E81379884B40
50347	6	55	\N	54919	41270	\N	55.066034904282297	Курганская область, Петуховский район, город Петухово, Первомайская, 51	Россия, Курганская область, Петуховский район, город Петухово	0101000020E6100000B16D516683F8504018B2BAD573884B40
49922	6	55	\N	54919	40469	\N	55.062838681517299	Курганская область, Петуховский район, город Петухово, Линейная, 1		0101000020E6100000BCB1A03028F95040E8F4BC1B0B884B40
49925	6	55	\N	54919	40503	\N	55.066195	Курганская область, Петуховский район, город Петухово, Красная, 186		0101000020E61000003A3DEFC682F850405114E81379884B40
49924	6	55	\N	54919	40503	\N	55.066195	Курганская область, Петуховский район, город Петухово, Красная, 66		0101000020E61000003A3DEFC682F850405114E81379884B40
49921	6	55	\N	54919	40887	\N	55.066195	Курганская область, Петуховский район, город Петухово, Кирова, 34		0101000020E61000003A3DEFC682F850405114E81379884B40
49920	6	55	\N	54919	40468	\N	55.066195	Курганская область, Петуховский район, город Петухово, К. Маркса, 59		0101000020E61000003A3DEFC682F850405114E81379884B40
49919	6	55	\N	54919	40468	\N	55.066195	Курганская область, Петуховский район, город Петухово, К. Маркса, 55		0101000020E61000003A3DEFC682F850405114E81379884B40
49918	6	55	\N	54919	40977	\N	55.066195	Курганская область, Петуховский район, город Петухово, К.Маркса, 5		0101000020E61000003A3DEFC682F850405114E81379884B40
49803	6	55	\N	54918	40922	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, НовоСеверная, 32		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
49839	6	55	\N	54918	40464	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, Лесная, 4		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
49801	6	55	\N	54918	40689	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, Ленина, 68		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
49800	6	55	\N	54918	40689	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, Ленина, 95		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
49799	6	55	\N	54918	40463	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, Д.Бедного, 2		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
49804	6	55	\N	54918	41014	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, В.Ушаковой, 1а		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
49802	6	55	\N	54918	40919	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, 2я Вокзальная, 11		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
50377	6	55	\N	55032	41555	\N	55.290798623523202	Курганская область, Кетовский район, с.Лесниково, пр. Студенческий, (Доминтернат для престарелых и инвалидов), 1	Россия, Курганская область, село Лесниково	0101000020E61000002176A6D079545040D15AD1E638A54B40
49763	6	55	\N	54979	40879	\N	55.270615999999997	Курганская область, Лебяжьевский район, р. п. Лебяжье, Кирова, 2		0101000020E6100000AD3594DA8B9F50401DE38A8BA3A24B40
49702	6	55	\N	54914	40511	\N	54.909354	Курганская область, Куртамышский район, город Куртамыш, пр.Конституции, 5		0101000020E610000094FAB2B4531B50404F3E3DB665744B40
49698	6	55	\N	54914	40453	\N	54.900118107044698	Курганская область, Куртамышский район, город Куртамыш, Студенческая, 1		0101000020E6100000DAC69FA86C1A50403D450E1137734B40
49701	6	55	\N	54914	40588	\N	54.906188931405602	Курганская область, Куртамышский район, город Куртамыш, Пролетарская, 8	Россия, Курганская область, Куртамышский район, город Куртамыш	0101000020E6100000A704C4245C1B50405A7F4B00FE734B40
49693	6	55	\N	54914	40586	\N	54.913211277448298	Курганская область, Куртамышский район, город Куртамыш, Правды, 15	Россия, Курганская область, Куртамышский район, город Куртамыш	0101000020E6100000CB2C42B1151C504079AC1919E4744B40
49696	6	55	\N	54914	40898	\N	54.911610406353503	Курганская область, Куртамышский район, город Куртамыш, пер.Парковый, 6		0101000020E6100000F964C570751A5040715AF0A2AF744B40
49695	6	55	\N	54914	40673	\N	54.909354	Курганская область, Куртамышский район, город Куртамыш, Ленина, 4		0101000020E610000094FAB2B4531B50404F3E3DB665744B40
49700	6	55	\N	54914	40460	\N	54.907635766492902	Курганская область, Куртамышский район, город Куртамыш, Колхозная, 23	Россия, Курганская область, Куртамышский район, город Куртамыш	0101000020E6100000938B31B08E1B50400C569C6A2D744B40
49699	6	55	\N	54914	40455	\N	54.9152076409773	Курганская область, Куртамышский район, город Куртамыш, XXII партсъезда, 172	Россия, Курганская область, Куртамышский район, город Куртамыш	0101000020E6100000C4978922A41B5040CF84268925754B40
49273	6	55	\N	1331	81123	\N	55.471181999999999	Курганская область, город Курган, Алексеева, 1А	Россия, Курганская область, Курган, Заозерный район, улица Алексеева, 1	0101000020E610000022A5D93C0E505040603B18B14FBC4B40
49274	6	55	\N	1331	41416	\N	55.474058057575903	Курганская область, город Курган, Алексеева, 14		0101000020E61000002481069B3A5050401E34BBEEADBC4B40
49288	6	55	\N	1331	40617	\N	55.462809	город Курган, пр. Машиностроителей, 17		0101000020E6100000923B6C2233555040B1A547533DBB4B40
49259	6	55	\N	1331	40617	\N	55.456955694489999	город Курган, пр. Машиностроителей, 12	Россия, Курганская область, Курган, проспект Машиностроителей, 10	0101000020E6100000CF11F92EA555504001DBC1887DBA4B40
49302	6	55	\N	1331	75699	\N	55.4242389813786	Курганская область, город Курган, Конституции, 68		0101000020E61000006DFDF49F355150400858AB764DB64B40
49301	6	55	\N	1331	75628	\N	55.423018999999996	Курганская область, город Курган, Конституции, 60		0101000020E6100000B16F2711E1505040164B917C25B64B40
49300	6	55	\N	1331	75628	\N	55.424208999999998	Курганская область, город Курган, Конституции, 75		0101000020E61000004147AB5AD25050409DD5027B4CB64B40
49317	6	55	\N	1331	75638	\N	55.439982000000001	Курганская область, город Курган, площадь Слосмана, 5		0101000020E61000002861A6ED5F545040126A865451B84B40
94451	6	55	\N	1331	76013	\N	55.427498999999997	640000, Курганская область, город Курган, пл.Собанина, 1 (здание автовокзала)		0101000020E6100000E46723D74D5950404E098849B8B64B40
94450	6	55	\N	1331	77038	\N	55.441511711168502	640000, Курганская область, город Курган, пл.Слосмана, 6 (здание центрального железнодорожного вокзала)		0101000020E6100000B3D2A414745450405265187783B84B40
49261	6	55	\N	1331	75670	\N	55.415432341686802	город Курган, пос. Керамзитный, 11		0101000020E61000002CF52C08E55B50401FDB32E02CB54B40
49260	6	55	\N	1331	41794	\N	55.3923225893937	город Курган, Яблоневая, пос. Учхоз, 2а		0101000020E61000009F3C2CD49A595040FB3BDBA337B24B40
49294	6	55	\N	1331	40635	\N	55.433874000000003	Курганская область, город Курган, Электровозная, 23		0101000020E610000015AC71361D525040D84AE82E89B74B40
49332	6	55	\N	1331	76002	\N	55.458329710879603	Курганская область, город Курган, микрорайон Зайково, улица Школьная, 38		0101000020E61000002F51BD35B04A50404963B48EAABA4B40
49262	6	55	\N	1331	40534	\N	55.447274	город Курган, Центральная, микрорайон Глинки, Центральная. 24		0101000020E6100000908653E6E65C5040F12C414640B94B40
49295	6	55	\N	1331	41083	\N	55.299737	Курганская область, город Курган, Нижняя Утятка, улица Центральная, 1	Россия, Курганская область, Курган, микрорайон поселок Нижняя Утятка	0101000020E6100000A33D5E4887535040593332C85DA64B40
49278	6	55	\N	1331	75684	\N	55.4664338753878	Курганская область, город Курган, 2 микрорайон, улица Фарафонова, 27		0101000020E610000078D498107350504009DFFB1BB4BB4B40
49238	6	55	\N	1331	40520	\N	55.466222999999999	город Курган, Урожайная, 147а		0101000020E61000002DB1321AF95A50404ED2FC31ADBB4B40
48953	6	55	\N	1331	75712	\N	55.446612800772598	город Курган, Урицкого, 153		0101000020E6100000753DD175E1565040F67B629D2AB94B40
49248	6	55	\N	1331	40542	\N	55.450382422592298	город Курган, Урицкого, 193	Россия, Курганская область, Курган, Центральный район, улица Урицкого, 193	0101000020E6100000EE96E4805D575040815A0C1EA6B94B40
49266	6	55	\N	1331	40350	\N	55.498122000000002	город Курган, Тимирязева, 38а		0101000020E61000002B137EA99F54504085B53176C2BF4B40
49319	6	55	\N	1331	40392	\N	55.443812000000001	Курганская область, город Курган, Станционная, 44		0101000020E61000007289230F4455504043C9E4D4CEB84B40
49316	6	55	\N	1331	75637	\N	55.438986999999997	Курганская область, город Курган, Станционная, 6		0101000020E6100000D09A1F7F69545040402FDCB930B84B40
49318	6	55	\N	1331	40391	\N	55.442422999999998	Курганская область, город Курган, Станционная, 26		0101000020E61000000114234BE6545040C5FF1D51A1B84B40
49240	6	55	\N	1331	75864	\N	55.4485599233061	город Курган, Спортивная, 11		0101000020E61000006ADB300A825950409A25016A6AB94B40
49303	6	55	\N	1331	40388	\N	55.417219000000003	Курганская область, город Курган, бульвар Солнечный, 8		0101000020E61000002BDEC83CF25150408A22A46E67B54B40
49327	6	55	\N	1331	75624	\N	55.4343584358163	город Курган, Советская, 63		0101000020E6100000C092AB58FC555040C460FE0A99B74B40
49250	6	55	\N	1331	40339	\N	55.441580999999999	город Курган, Советская, 160	Россия, Курганская область, Курган, Центральный район, Советская улица, 160	0101000020E6100000BAF59A1E145750407AC4E8B985B84B40
49251	6	55	\N	1331	40708	\N	55.437581999999999	город Курган, Советская, 108		0101000020E61000000EDAAB8F87565040BDA8DDAF02B84B40
49263	6	55	\N	1331	40536	\N	55.407187	город Курган, Советская, микрорайон Утяк, Советская,41		0101000020E610000024B55032396250409D2D20B41EB44B40
49330	6	55	\N	1331	40430	\N	55.453027125701297	город Курган, Сиреневая, микрорайон Тополя, 25а		0101000020E6100000CB49287D215D50403D9AEAC9FCB94B40
49293	6	55	\N	1331	41767	\N	55.4456277210585	"""Курганская область, город Курган, Карчевская Роща, ЗАО """"Сады Зауралья""""""ул. Сады Зауралья,2"		0101000020E61000008BDEA9807B50504048179B560AB94B40
49321	6	55	\N	1331	75669	\N	55.440492999999996	город Курган, Пушкина, 137		0101000020E6100000AC527AA697555040F78E1A1362B84B40
49243	6	55	\N	1331	75872	\N	55.458613	город Курган, Пугачева, 97		0101000020E6100000B62FA017EE5750409E42AED4B3BA4B40
49256	6	55	\N	1331	40348	\N	55.445135000000001	город Курган, Пролетарская, 62		0101000020E6100000BAD7497D5956504009A7052FFAB84B40
49292	6	55	\N	1331	75657	\N	55.443612999999999	Курганская область, город Курган, улица Правды (здание школы №75), 53		0101000020E610000088D68A36C75250404C8A8F4FC8B84B40
49307	6	55	\N	1331	75630	\N	55.431039590642001	Курганская область, город Курган, Победы, 10		0101000020E610000079B0C56E9F53504049A297512CB74B40
49252	6	55	\N	1331	40353	\N	55.441622000000002	город Курган, Пичугина, 36		0101000020E6100000386744696F565040D998D71187B84B40
49267	6	55	\N	1331	40605	\N	55.502701000000002	город Курган, Пирогова, 17	Россия, Курганская область, Курган, район Рябково, улица Пирогова, 17	0101000020E610000062D7F6764B5450405055A18158C04B40
49291	6	55	\N	1331	40633	\N	55.443326999999996	Курганская область, город Курган, Омская, 1Б		0101000020E61000002DCDAD105654504086376BF0BEB84B40
49257	6	55	\N	1331	40612	\N	55.452129999999997	город Курган, Некрасова, 10		0101000020E61000006FA0C03BF95550402EC55565DFB94B40
49306	6	55	\N	1331	75702	\N	55.4342201111902	Курганская область, город Курган, Невежина, 26 корпус 2		0101000020E6100000DE3CD5213753504073A25D8594B74B40
49264	6	55	\N	1331	75627	\N	55.491232106469603	город Курган, Московская, 26		0101000020E61000005A65A6B4FE545040D45FAFB0E0BE4B40
49290	6	55	\N	1331	40382	\N	55.453589999999998	Курганская область, город Курган, Молодежи, 35		0101000020E610000025917D906553504075E5B33C0FBA4B40
49247	6	55	\N	1331	75625	\N	55.446983000000003	город Курган, Горького, 216		0101000020E6100000B66455849B5750401A6F2BBD36B94B40
49241	6	55	\N	1331	40752	\N	55.453729739424901	город Курган, Ломоносова, 41	Россия, Курганская область, Курган, Восточный район, улица Ломоносова, 41	0101000020E61000009F91088D60595040679B1BD313BA4B40
50296	6	55	\N	1331	75933	\N	55.453876000000001	Курганская область, город Курган, Ломоносова, 41		0101000020E61000009D0FCF12645950403B38D89B18BA4B40
49255	6	55	\N	1331	40345	\N	55.444093000000002	город Курган, ул. Ленина, 37	Россия, Курганская область, Курган, Центральный район, улица Ленина, 37	0101000020E610000012A3E716BA555040F7B0170AD8B84B40
49320	6	55	\N	1331	40393	\N	55.444093000000002	Курганская область, город Курган, Ленина, 37		0101000020E610000012A3E716BA555040F7B0170AD8B84B40
49328	6	55	\N	1331	40396	\N	55.433352999999997	город Курган, Куйбышева, 49		0101000020E6100000A452EC681C565040CE4F711C78B74B40
49246	6	55	\N	1331	40529	\N	55.444766999999999	город Курган, Куйбышева, 144а		0101000020E6100000A7C98CB79558504086AB0320EEB84B40
49269	6	55	\N	1331	75671	\N	55.491425999999997	город Курган, Кузнецова, 6а		0101000020E61000001B84B9DDCB535040B933130CE7BE4B40
49237	6	55	\N	1331	40325	\N	55.441535000000002	город Курган, Кравченко, 28		0101000020E6100000118DEE20765750400A85083884B84B40
49333	6	55	\N	1331	40559	\N	55.461962	город Курган, Котовского, 92		0101000020E610000032056B9C4D58504054FF209221BB4B40
49296	6	55	\N	1331	75653	\N	55.3525926686034	Курганская область, город Курган, Микрорайон Черемухово, ул. Космонавтов, 5а		0101000020E61000003E78EDD2864F504036E675C421AD4B40
49299	6	55	\N	1331	40412	\N	55.422119000000002	Курганская область, город Курган, Конституции, 56		0101000020E61000008A213999B85050409702D2FE07B64B40
49298	6	55	\N	1331	40731	\N	55.421168999999999	Курганская область, город Курган, Конституции, 53		0101000020E61000007653CA6B25505040658BA4DDE8B54B40
49309	6	55	\N	1331	75705	\N	55.434726448346296	Курганская область, город Курган, Мяготина, 67		0101000020E6100000B343FCC396535040465C001AA5B74B40
49249	6	55	\N	1331	40327	\N	55.449939999999998	город Курган, Мяготина, 176		0101000020E61000006364C91CCB565040C49448A297B94B40
49334	6	55	\N	1331	75640	\N	55.449939999999998	город Курган, К. Мяготина, 176		0101000020E61000006364C91CCB565040C49448A297B94B40
49324	6	55	\N	1331	75663	\N	55.433363	город Курган, Кирова, 52		0101000020E6100000FBE8D495CF555040F225547078B74B40
49254	6	55	\N	1331	40342	\N	55.439936000000003	город Курган, Маркса, 70	Россия, Курганская область, Курган, Центральный район, улица Карла Маркса, 70	0101000020E61000002716F88A6E565040A22AA6D24FB84B40
42136	6	55	\N	1331	40334	\N	55.444305762061099	город Курган, Маркса, 84	Россия, Курганская область, Курган, Центральный район, улица Карла Маркса, 84а	0101000020E61000007633A31F0D57504052B5DD04DFB84B40
49326	6	55	\N	1331	75664	\N	55.437382999999997	город Курган, Маркса, 52		0101000020E610000046787B1002565040C669882AFCB74B40
50104	6	55	\N	1331	40479	\N	55.426482999999998	Курганская область, город Курган, Карельцева, 84		0101000020E6100000AE0E80B8AB54504065A6B4FE96B64B40
49314	6	55	\N	1331	75633	\N	55.433595234901802	Курганская область, город Курган, Карельцева, 32		0101000020E61000006ADAC534D3545040C45A7C0A80B74B40
49313	6	55	\N	1331	75633	\N	55.427229312971598	Курганская область, город Курган, Карельцева, 103		0101000020E6100000CAE2FE23D35450408E739B70AFB64B40
49265	6	55	\N	1331	40352	\N	55.4879985922855	город Курган, Карбышева, 12а	Россия, Курганская область, Курган, район Рябково, улица Карбышева, 12а	0101000020E61000002D93E1783E54504088BD50C076BE4B40
50322	6	55	\N	1331	40477	\N	55.488095999999999	Курганская область, город Курган, ул. Карбышева, 12а		0101000020E6100000166BB8C83D5450407AA702EE79BE4B40
49331	6	55	\N	1331	75666	\N	55.501865000000002	город Курган, Карбышева, 56		0101000020E610000063096B63EC535040E700C11C3DC04B40
49329	6	55	\N	1331	71735	\N	55.384518	город Курган, пос. Увал, Интернатовская, 46		0101000020E6100000BA11161571585040965CC5E237B14B40
49310	6	55	\N	1331	40551	\N	55.438220999999999	Курганская область, город Курган, Зорге, 37		0101000020E610000000917EFB3A545040D0B52FA017B84B40
49311	6	55	\N	1331	75659	\N	55.433920000000001	Курганская область, город Курган, Зорге, 24		0101000020E61000005CE333D93F545040488AC8B08AB74B40
49289	6	55	\N	1331	40615	\N	55.454039000000002	город Курган, Дзержинского, 3		0101000020E610000097FF907EFB545040E50D30F31DBA4B40
49287	6	55	\N	1331	40615	\N	55.452430999999997	Курганская область, город Курган, Дзержинского, 1А	Россия, Курганская область, Курган, улица Дзержинского, 1а	0101000020E610000093C83EC8B254504029594E42E9B94B40
49258	6	55	\N	1331	40615	\N	55.456541000000001	город Курган, Дзержинского, 46		0101000020E610000094895B05315650403E247CEF6FBA4B40
49253	6	55	\N	1331	40344	\N	55.443840164238203	город Курган, Гоголя, 107а	Россия, Курганская область, Курган, Центральный район, улица Гоголя, 107а	0101000020E6100000725298F7385650400D54C6BFCFB84B40
49322	6	55	\N	1331	40384	\N	55.435749000000001	город Курган, Гоголя, 30		0101000020E61000003D7FDAA84E555040E2218C9FC6B74B40
49325	6	55	\N	1331	40395	\N	55.439329000000001	город Курган, Гоголя, 54		0101000020E6100000CAC51858C75550409A97C3EE3BB84B40
49297	6	55	\N	1331	40547	\N	55.399887999999997	Курганская область, город Курган, Глинки, 14		0101000020E61000006A882AFC194F50400B08AD872FB34B40
49305	6	55	\N	1331	40389	\N	55.424194	Курганская область, город Курган, Галкинская, 59А		0101000020E6100000EED11BEE2353504068942EFD4BB64B40
49245	6	55	\N	1331	75876	\N	55.448504374242901	город Курган, Гайдара, 9		0101000020E610000094A12AA6D258504006103E9468B94B40
49242	6	55	\N	1331	40533	\N	55.454932999999997	город Курган, Гагарина, 64		0101000020E610000022E010AAD4595040826F9A3E3BBA4B40
49239	6	55	\N	1331	40528	\N	55.460645	город Курган, Гагарина, 41, стр. 12		0101000020E6100000D367075C575A50407008556AF6BA4B40
49323	6	55	\N	1331	75707	\N	55.435579983957403	город Курган, Васильева, 7		0101000020E61000002670EB6E9E5450405665DF15C1B74B40
49315	6	55	\N	1331	75661	\N	55.4358	Курганская область, город Курган, С.Васильева, 7		0101000020E61000001B2AC6F99B54504064CC5D4BC8B74B40
49244	6	55	\N	1331	40712	\N	55.454964117938097	город Курган, Бородина, 41		0101000020E61000007D2079E750585040BD6DA6423CBA4B40
49304	6	55	\N	1331	75701	\N	55.423693	Курганская область, город Курган, Бажова, 116		0101000020E61000009E0B23BDA8525040A6457D923BB64B40
49271	6	55	\N	1331	75672	\N	55.487392	город Курган, Анфиногенова, 66		0101000020E6100000F303577902545040802A6EDC62BE4B40
49275	6	55	\N	1331	40541	\N	55.473097000000003	Курганская область, город Курган, Алексеева, 11		0101000020E61000001747E5266A505040F96A47718EBC4B40
49270	6	55	\N	1331	40540	\N	55.487622000000002	город Курган, 9 Мая, 8		0101000020E61000006AD95A5F24535040B267CF656ABE4B40
49285	6	55	\N	1331	40379	\N	55.467489	Курганская область, город Курган, 6 микрорайон, 16А		0101000020E6100000FED137691A525040B01EF7ADD6BB4B40
49335	6	55	\N	1331	41427	\N	55.466824634908001	Курганская область, город Курган, 6 микрорайон, ДЮСШ №3,66		0101000020E61000002CB649456352504044FAEDEBC0BB4B40
49284	6	55	\N	1331	75691	\N	55.467510621314098	"""Курганская область, город Курган, 6 микрорайон, 66 МОУ ДОД """"ДЮСШ № 3""""""16а"	Россия, Курганская область, Курган, Заозерный район, 6-й микрорайон, 16а	0101000020E61000008787307E1A52504098C28366D7BB4B40
49282	6	55	\N	1331	75619	\N	55.463258000000003	Курганская область, город Курган, 5 микрорайон, 15		0101000020E6100000D04202469751504021CEC3094CBB4B40
49283	6	55	\N	1331	40377	\N	55.464069000000002	Курганская область, город Курган, 5 микрорайон, 23		0101000020E61000008A7269FCC2515040310BED9C66BB4B40
49280	6	55	\N	1331	75686	\N	55.460690999999997	Курганская область, город Курган, 3 микрорайон, 32		0101000020E6100000D6AD9E93DE505040E04735ECF7BA4B40
49281	6	55	\N	1331	40378	\N	55.463451999999997	Курганская область, город Курган, 3 микрорайон, 25		0101000020E610000003ED0E290651504005A2276552BB4B40
49279	6	55	\N	1331	40543	\N	55.459001000000001	Курганская область, город Курган, 3 микрорайон, 4А		0101000020E61000009885764EB350504068EA758BC0BA4B40
49277	6	55	\N	1331	75668	\N	55.469667999999999	Курганская область, город Курган, 1 микрорайон, 7		0101000020E61000004BC972124A50504026FDBD141EBC4B40
49276	6	55	\N	1331	40368	\N	55.466169970035899	Курганская область, город Курган, 1 микрорайон, 11/1		0101000020E61000004CDD955D305050402B306475ABBB4B40
50105	6	55	\N	1331	40522	\N	55.469667999999999	Курганская область, город Курган, 1А Микрорайон, 7		0101000020E61000004BC972124A50504026FDBD141EBC4B40
49308	6	55	\N	1331	40651	\N	55.434886005155597	Курганская область, город Курган, 1 Мая, 19А	Россия, Курганская область, Курган, Центральный район, улица 1 Мая, 19а	0101000020E6100000AD6EF59CF45350407FBE2D58AAB74B40
49268	6	55	\N	55024	41417	\N	55.497684	город Курган, Карбышева, 52		0101000020E6100000A089B0E1E953504009DFFB1BB4BF4B40
49594	6	55	\N	54936	40763	\N	56.2785647824739	Курганская область, Катайский район, город Катайск, Советская, 1		0101000020E61000001D1CEC4D0C4B4F40B6679604A8234C40
49595	6	55	\N	54936	40856	\N	56.283184156403102	Курганская область, Катайский район, город Катайск, Островского, 4		0101000020E610000053211E89974B4F400F60915F3F244C40
49596	6	55	\N	54936	40859	\N	56.283112542479003	Курганская область, Катайский район, город Катайск, Маяковского, 1		0101000020E610000044696FF0854B4F404609FA0B3D244C40
49602	6	55	\N	54936	40579	\N	56.286263987167104	Курганская область, Катайский район, город Катайск, Матросова, 81	Россия, Курганская область, Катайский район, город Катайск	0101000020E6100000273108AC1C4A4F40D6027B4CA4244C40
49601	6	55	\N	54936	40579	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, Матросова, 66		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49635	6	55	\N	54936	40577	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, Ленина, 217		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49600	6	55	\N	54936	40577	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, Ленина, 210		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49598	6	55	\N	54936	40577	\N	56.285618949685798	Курганская область, Катайский район, город Катайск, Ленина, 184		0101000020E61000003465A71FD4494F40E00ED4298F244C40
49597	6	55	\N	54936	40577	\N	56.285117681443303	Курганская область, Катайский район, город Катайск, Ленина, 195		0101000020E6100000478E7406464A4F401EC022BF7E244C40
49605	6	55	\N	54936	41004	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, Красноармейская, 23		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49637	6	55	\N	54936	41398	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, Комарова, 16		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49603	6	55	\N	54936	40962	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, Гагарина, 24		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49604	6	55	\N	54936	40968	\N	56.296454278228403	Курганская область, Катайский район, город Катайск, Боровая, 1		0101000020E6100000B3B5BE48684D4F405A626534F2254C40
49636	6	55	\N	54936	40787	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, 30 лет Победы, 4		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49599	6	55	\N	54936	40787	\N	56.291324000000003	Курганская область, Катайский район, город Катайск, 30 лет Победы, 7		0101000020E61000008D0A9C6C03494F401C45D61A4A254C40
49589	6	55	\N	54987	40957	\N	55.948160000000001	Курганская область, Курганская область, Каргаполье р.п, Пушкина ул, 28Б		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
49575	6	55	\N	54987	40963	\N	55.948063685945201	Курганская область, Каргапольский район, Каргаполье п, Новая ул, 1А		0101000020E6100000731074B4AA1B5040EA4141295AF94B40
49492	6	55	\N	54933	40570	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, Советская, 233		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49491	6	55	\N	54933	40570	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, Советская, 193		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49490	6	55	\N	54933	40570	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, Советская, 177		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49488	6	55	\N	54933	40570	\N	56.259084252322999	Курганская область, Далматовский район, город Далматово, Советская, 112		0101000020E610000077137CD3F4794F405C751DAA29214C40
49487	6	55	\N	54933	40570	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, Советская, 151		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49486	6	55	\N	54933	40570	\N	56.257722703667099	Курганская область, Далматовский район, город Далматово, Советская, 110		0101000020E610000037C5E3A25A7C4F40A8363811FD204C40
49499	6	55	\N	54933	41320	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, Гагарина, 84		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49496	6	55	\N	54933	41320	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, Гагарина, 93		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49495	6	55	\N	54933	41320	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, Гагарина, 80		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49493	6	55	\N	54933	41116	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, 8 Марта, 95		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49489	6	55	\N	54933	40661	\N	56.263407000000001	Курганская область, Далматовский район, город Далматово, 4 Уральского полка, 109		0101000020E6100000BCB0355B79774F40CC441152B7214C40
49669	6	55	\N	54961	40744	\N	55.430655999999999	Курганская область, Кетовский район, с. Введенское, Ленина, 40	Россия, Курганская область, поселок сельского типа Введенское	0101000020E610000053CC41D0D1475040C0E95DBC1FB74B40
50010	6	55	\N	52056	40748	\N	55.512515	Курганская область, Целинный район, Целинный сельсовет. село Целинное, ул. Лесная, дом 21		0101000020E6100000DAE731CA33595040CFDA6D179AC14B40
50319	6	55	1124	12223	75884	\N	55.278415035321203	Кипельский сельсовет, Юргамышский район, Курганская область, с. Кипель, Советская, 81	Россия, Курганская область, Юргамышский район, поселок сельского типа Кипель	0101000020E610000017EFC7ED97215040A1DB4B1AA3A34B40
50344	6	55	1124	54976	40840	\N	55.373859000000003	Курганская область, Юргамышский район, п. Юргамыш, Труда, 147		0101000020E6100000842BA0504F1D50405B28999CDAAF4B40
50342	6	55	1124	54976	40924	\N	55.3765163376749	Курганская область, Юргамышский район, п. Юргамыш, Свободы, 25		0101000020E6100000309C6B98A11D5040DB3521AD31B04B40
50277	6	55	1124	54976	41105	\N	55.373859000000003	Курганская область, Юргамышский район, п. Юргамыш, Мичурина, 2		0101000020E6100000842BA0504F1D50405B28999CDAAF4B40
50343	6	55	1124	54976	41056	\N	55.374701868072897	Курганская область, Юргамышский район, п. Юргамыш, Мира, 58		0101000020E6100000DE04DF347D1D504076DF313CF6AF4B40
50341	6	55	1124	54976	41031	\N	55.373859000000003	Курганская область, Юргамышский район, п. Юргамыш, Ленина, 22		0101000020E6100000842BA0504F1D50405B28999CDAAF4B40
50340	6	55	1124	54976	40917	\N	55.373859000000003	Курганская область, Юргамышский район, п. Юргамыш, Блюхера, 2		0101000020E6100000842BA0504F1D50405B28999CDAAF4B40
50368	6	55	1124	10234	41066	\N	55.373859000000003	Курганская область, Юргамышский район, п. Юргамыш, Линейная, 5		0101000020E6100000842BA0504F1D50405B28999CDAAF4B40
50324	6	55	1124	12472	41610	\N	55.567014454865003	Кислянский сельсовет, Юргамышский район, Курганская область, д. Шемелино, Центральная, 26	Россия, Курганская область, Юргамышский район, село Шемелино	0101000020E6100000A376BF0AF0125040E42F2DEA93C84B40
50337	6	55	1124	13056	41268	\N	55.474995	Курганская область, Юргамышский район, Чинеевский сельсовет,  с. Чинеево, Школьная, 2		0101000020E610000062BD512B4C295040BB61DBA2CCBC4B40
50335	6	55	1124	12959	41264	\N	55.607177999999998	Фадюшинский сельсовет, Юргамышский район, Курганская область, д. Фадюшино, Центральная, 50		0101000020E610000075779D0DF90C5040E36C3A02B8CD4B40
50312	6	55	1124	11884	\N	\N	55.515858999999999	Вилкинский сельсовет, Юргамышский район, Курганская область, д. Туманова, Центральная, 20		0101000020E61000002E724F5777025040732CEFAA07C24B40
50334	6	55	1124	12895	41261	\N	55.2011153185979	Таловский сельсовет, Юргамышский район, Курганская область, с. Таловка, Центральная, 2	Россия, Курганская область, Юргамышский район, село Таловка	0101000020E61000008CF678211D14504016DEE522BE994B40
50333	6	55	1124	12878	41072	\N	55.156868000000003	Скоблинский сельсовет, Юргамышский район, Курганская область, с. Скоблино, Школьная, 48		0101000020E61000002BC24D4695145040FCE4284014944B40
50318	6	55	1124	12173	41266	\N	55.490223	Карасинский сельсовет, Юргамышский район, Курганская область, д. Редуть, 2я Деревенская, 7А		0101000020E6100000147AFD497C0E50409E5F94A0BFBE4B40
50327	6	55	1124	12599	41254	\N	55.340881000000003	Красноуральский сельсовет, Юргамышский район, Курганская область, д. Раздольная, Центральная, 16		0101000020E6100000A8195245F11C5040F56915FDA1AB4B40
50336	6	55	1124	12977	41455	\N	55.646513001268801	Фадюшинский сельсовет, Юргамышский район, Курганская область, д. Плотникова, Набережная, 10		0101000020E6100000124DA088450850402CB81FF0C0D24B40
50326	6	55	1124	12565	9769	\N	55.2880385356818	Красноуральский сельсовет, Юргамышский район, Курганская область, с. Петровское, Береговая, 6	Россия, Курганская область, Юргамышский район, село Петровское	0101000020E6100000144031B2641850407C7C4276DEA44B40
50332	6	55	1124	12819	41464	\N	55.1899726148444	Песковский сельсовет, Юргамышский район, Курганская область, с. Пески, Центральная, 39	Россия, Курганская область, Юргамышский район, село Пески	0101000020E6100000F7915B936E0F5040BF0F070951984B40
50320	6	55	1124	12265	41519	\N	55.169890431323601	Кипельский сельсовет, Юргамышский район, Курганская область, д. Падун, Победа, 21		0101000020E61000001096B1A19B2750406FF59CF4BE954B40
50314	6	55	1124	11995	41309	\N	55.073731000000002	Гагарьевский сельсовет, Юргамышский район, Курганская область, с. Норильное, Клиновая, 16		0101000020E610000022C5008926205040C7D9740470894B40
50345	6	55	1124	54954	40702	\N	55.334930999999997	Курганская область, Юргамышский район, п. Новый Мир, Ленина, 19		0101000020E6100000B9C2BB5CC41F504052B5DD04DFAA4B40
50338	6	55	1124	13109	41457	\N	55.430390000000003	Курганская область, Юргамышский район, Чинеевский сельсовет, д. Новая Заворина, Центральная, 66		0101000020E6100000AB5FE97C783150404243FF0417B74B40
50346	6	55	1124	13474	41505	\N	55.360582000000001	Курганская область, Юргамышский район, п. Нива, Заводская, 2		0101000020E6100000605AD427B91A50405DC30C8D27AE4B40
50328	6	55	1124	12683	40943	\N	55.424985999999997	Малобеловский сельсовет, Юргамышский район, Курганская область, с. Малое Белое, Школьная, 2		0101000020E610000063416150A61A504001A1F5F065B64B40
50323	6	55	1124	12422	41453	\N	55.672814440087897	Кислянский сельсовет, Юргамышский район, Курганская область, д. Кулаш, Верхняя, 17		0101000020E610000072C119FCFD1350403E25E7C41ED64B40
50325	6	55	1124	12490	41070	\N	55.298029999999997	Красноуральский сельсовет, Юргамышский район, Курганская область, с. Красный Уралец, Ленина, 4		0101000020E6100000D3DEE00B931A50400A9DD7D825A64B40
50321	6	55	1124	12321	41069	\N	55.559272	Кислянский сельсовет, Юргамышский район, Курганская область, с. Кислянское, Маюрова, 4		0101000020E610000032AEB8382A155040C5C8923996C74B40
50317	6	55	1124	12132	40997	\N	55.434466999999998	Карасинский сельсовет, Юргамышский район, Курганская область, с. Караси, Советская, 35А		0101000020E61000003C6A4C88B90B50407A185A9D9CB74B40
50339	6	55	1124	13137	41256	\N	55.395512655521301	Курганская область, Юргамышский район, Чинеевский сельсовет,  п. Зырянка, Центральная, 5	Россия, Курганская область, Юргамышский район	0101000020E6100000E3C281902C3150404912842BA0B24B40
50316	6	55	1124	12090	41531	\N	55.243510000000001	Гороховский сельсовет, Юргамышский район, Курганская область, д. Ерохина, Степная, 1		0101000020E6100000554CA59F702A5040DE1FEF552B9F4B40
50329	6	55	1124	12722	41612	\N	55.562708999999998	Островский сельсовет, Юргамышский район, Курганская область, с. Губерля, Школьная, 10		0101000020E610000094A5D6FB8D2650401A1538D906C84B40
50315	6	55	1124	54926	40491	\N	55.270091999999998	Гороховский сельсовет, Юргамышский район, Курганская область, с. Горохово, Школьная, 37		0101000020E6100000DA8F149161285040A374E95F92A24B40
50313	6	55	1124	11943	41257	\N	55.124381999999997	Гагарьевский сельсовет, Юргамышский район, Курганская область, с. Гагарье, Молодежная, 1б		0101000020E61000009B8D959867205040041BD7BFEB8F4B40
50331	6	55	1124	12787	41258	\N	55.583454000000003	Островский сельсовет, Юргамышский район, Курганская область, д. Вохменка, Баранова, 43		0101000020E610000026E4839ECD255040365CE49EAECA4B40
50311	6	55	1124	11824	41606	\N	55.544457270068499	Вилкинский сельсовет, Юргамышский район, Курганская область, с. Вилкино, Ленина, 1	Россия, Курганская область, Юргамышский район, село Вилкино	0101000020E6100000A60EF27A30085040058A58C4B0C54B40
50279	6	55	1058	10299	\N	\N	55.148899	Курганская область, Щучанский район, Чистовский сельсовет, д. Яковлевка, здание Яковлевского сельского клуба	Россия, Курганская область, Щучанский район, село Яковлевка	0101000020E6100000A67B9DD4972D4F401CB4571F0F934B40
50285	6	55	1058	54974	\N	\N	55.305681999999997	Курганская область, Щучанский район, Чумлякский сельсовет, с. Чумляк, здание Чумлякского сельского Дома культуры		0101000020E61000001A53B0C6D9564F40E97C789620A74B40
50307	6	55	1058	11637	41446	\N	55.576304	Курганская область, Щучанский район, Николаевский сельсовет, д. Чудняково, ул. Центральная, 23		0101000020E6100000B806B64AB0504F40E9465854C4C94B40
50276	6	55	1058	10147	\N	\N	55.155380999999998	Курганская область, Щучанский район, Чистовский сельсовет, с. Чистое, здание Чистовского сельсовета	Россия, Курганская область, Щучанский район, село Чистое	0101000020E61000003B53E8BCC63E4F40BBB54C86E3934B40
50290	6	55	1058	10855	41248	\N	55.349051000000003	Курганская область, Щучанский район, Белоярский сельсовет, д. Чесноковка 1я, ул. Солнечная, 27		0101000020E610000085402E71E4214F406CD102B4ADAC4B40
50308	6	55	1058	11706	41255	\N	55.611190000000001	Курганская область, Щучанский район, Николаевский сельсовет, д. Чердаки, ул. М.С, Быкова, 15	Россия, Курганская область, Щучанский район, село Чердаки	0101000020E61000003B70CE88D24E4F4035D252793BCE4B40
50310	6	55	1058	11798	41608	\N	55.702190999999999	Курганская область, Щучанский район, Песчанский сельсовет, д. Утичье, д. Утичье, ул. А. Усова, д. 16А		0101000020E6100000A3EA573A1F6A4F40D4450A65E1D94B40
50271	6	55	1058	9927	\N	\N	55.061203999999996	Курганская область, Щучанский район, Тунгуйский сельсовет, с. Тунгуй, здание Тунгуйского сельсовета	Россия, Курганская область, Щучанский район, село Тунгуй	0101000020E610000046EA3D95D36C4F4033315D88D5874B40
50273	6	55	1058	9996	\N	\N	55.145524000000002	Курганская область, Щучанский район, Сухоборский сельсовет, с. Сухоборское, здание Сухоборского сельсовета	Россия, Курганская область, Щучанский район, село Сухоборское	0101000020E610000054E57B4622584F403D64CA87A0924B40
50241	6	55	910	8519	41601	\N	55.347566	Курганская область, Шумихинский район, Кипельский сельсовет, деревня Горшково, улица Длинная, 12		0101000020E610000088687407B1814F40CC99ED0A7DAC4B40
50286	6	55	1058	10679	\N	\N	55.321933000000001	Курганская область, Щучанский район, Чумлякский сельсовет, д. Советская, здание Советского сельского клуба	Россия, Курганская область, Щучанский район, село Советская	0101000020E6100000B00111E2CA514F406840BD1935A94B40
50302	6	55	1058	11393	41448	\N	55.473112	Курганская область, Щучанский район, Пуктышский сельсовет, с. Пуктыш, ул. Озёрная, 63		0101000020E6100000B3B3E89D0A5A4F402EAC1BEF8EBC4B40
50268	6	55	1058	54962	\N	\N	55.264234048871302	"Курганская область, Щучанский район, город Щучье, пос. Плановый, здание МОУ """"Средняя общеобразовательная школа № 4"""""	Россия, Курганская область, Щучанский район, село Плановый	0101000020E610000098A3C7EF6D5C4F40E23E726BD2A14B40
50297	6	55	1058	10999	41649	\N	55.262003	Курганская область, Щучанский район, Пивкинский сельсовет, с. Пивкино, ул. Центральная, 1		0101000020E6100000A94A5B5CE32F4F40193A765089A14B40
50293	6	55	1058	10999	41443	\N	55.262003	Курганская область, Щучанский район, Каясановский сельсовет, п. Пивкино, ул. Станционная, 16		0101000020E6100000A94A5B5CE32F4F40193A765089A14B40
50298	6	55	1058	11220	41249	\N	55.267327999999999	Курганская область, Щучанский район, Пивкинский сельсовет, с. Петрушино, ул. Петрушино, 39		0101000020E610000098DA520779414F400DA7CCCD37A24B40
50300	6	55	1058	11306	41607	\N	55.365960000000001	Курганская область, Щучанский район, Петровский сельсовет, с. Петровское, ул.  Чапаева, 7		0101000020E6100000E1B6B6F0BC664F4074D2FBC6D7AE4B40
50309	6	55	1058	54994	40996	\N	55.686141999999997	Курганская область, Щучанский район, Песчанский сельсовет, с. Песчанское,  ул. Павших Борцов, д. 5А		0101000020E6100000D8EF8975AA5A4F40BD344580D3D74B40
50280	6	55	1058	10367	\N	\N	55.276657	Курганская область, Щучанский район, Зайковский сельсовет, с. Отрадное, здание Зайковского сельсовета	Россия, Курганская область, Щучанский район, село Отрадное	0101000020E610000019558671376E4F40D09A1F7F69A34B40
50269	6	55	1058	9836	\N	\N	55.189804000000002	Курганская область, Щучанский район, Нифанский сельсовет, с. Нифанка, здание Нифанской группы кратковременного пребывания	Россия, Курганская область, Щучанский район, село Нифанка	0101000020E61000008F519E7939644F4033535A7F4B984B40
50306	6	55	1058	11576	41603	\N	55.566332298139798	Курганская область, Щучанский район, Николаевский сельсовет, с. Николаевка, ул. Советская, 1	Россия, Курганская область, Щучанский район, село Николаевка	0101000020E6100000261DE56036614F40D25625917DC84B40
50305	6	55	1058	11549	41445	\N	55.462758000000001	Курганская область, Щучанский район, Пуктышский сельсовет, д. Никитино, ул. Никитинская, 18		0101000020E610000001C0B167CF4F4F402FFB75A73BBB4B40
50304	6	55	1058	11492	41496	\N	55.437300999999998	Курганская область, Щучанский район, Пуктышский сельсовет, д. Михайловка, ул. Центральная, 24А		0101000020E61000003D49BA66F23F4F4009C1AA7AF9B74B40
50282	6	55	1058	10462	\N	\N	55.243982000000003	"Курганская область, Щучанский район, Медведский сельсовет, с. Медведское, здание сельского досугового центра (СДЦ) """"Нефтяник"""""	Россия, Курганская область, Щучанский район, село Медведское	0101000020E6100000ED444948A47D4F4006685BCD3A9F4B40
50295	6	55	1058	11064	\N	\N	55.236021000000001	Курганская область, Щучанский район, Майковский сельсовет, с. Майка, ул. Майка, 20	Россия, Курганская область, Щучанский район, село Майка	0101000020E610000039B4C876BE214F40A915A6EF359E4B40
50278	6	55	1058	10280	\N	\N	55.134892999999998	"Курганская область, Щучанский район, Чистовский сельсовет, пос. Курорт Озеро, здание МОУ """"Начальная общеобразовательная школа"""""	Россия, Курганская область, Щучанский район, поселок Курорт Озеро	0101000020E61000003412A1116C444F40CBBA7F2C44914B40
50299	6	55	1058	11252	41602	\N	55.323208000000001	Курганская область, Щучанский район, Пивкинский сельсовет, д. Куликово, ул. Центральная, 15А		0101000020E6100000761A69A9BC374F401DE736E15EA94B40
50289	6	55	1058	10790	41253	\N	55.334085999999999	Курганская область, Щучанский район, Белоярский сельсовет, д. Красноярское,  ул. Цветочная, 4		0101000020E610000005C078060D3B4F4096067E54C3AA4B40
50288	6	55	1058	10783	41648	\N	55.325344000000001	Курганская область, Щучанский район, Белоярский сельсовет, д. Косулино, ул. Солнечная, 59		0101000020E6100000054D4BAC8C2A4F4094F947DFA4A94B40
50270	6	55	1058	9855	\N	\N	55.228715999999999	"Курганская область, Щучанский район, Нифанский сельсовет, д. Козино, здание МОУ """"Начальная общеобразовательная школа"""""	Россия, Курганская область, Щучанский район, село Козино	0101000020E610000013807F4A95544F403509DE90469D4B40
50284	6	55	1058	10595	\N	\N	55.214208999999997	Курганская область, Щучанский район, Медведский сельсовет, д. Клюквенная, здание Клюквенского сельского клуба	Россия, Курганская область, Щучанский район, село Клюквенная	0101000020E61000009B3924B5507A4F4022C154336B9B4B40
50291	6	55	1058	54992	40993	\N	55.206200000000003	Курганская область, Щучанский район, Каясановский сельсовет, с. Каясан, ул. Железнодорожная, , 73А		0101000020E6100000F1D6F9B7CB1E4F40B537F8C2649A4B40
50301	6	55	1058	55045	41743	\N	55.326275615342901	Курганская область, Щучанский район, Петровский сельсовет, с. КолмаковоМиасское,  ул. Береговая, 24		0101000020E6100000611A868F88694F401FBC7669C3A94B40
50281	6	55	1058	10446	\N	\N	55.266763578634801	Курганская область, Щучанский район, Зайковский сельсовет, с. Зайково, здание Зайковского сельского клуба	Россия, Курганская область, Щучанский район, село Зайково	0101000020E610000016FBCBEEC9714F4005E09F5225A24B40
49906	6	55	1680	24262	\N	\N	55.763635000000001	Курганская область, Мокроусовский район, д. Отставное, 17а		0101000020E6100000D576137CD39550405D8AABCABEE14B40
50274	6	55	1058	10078	\N	\N	55.102457000000001	Курганская область, Щучанский район, Сухоборский сельсовет, д. Даньково, здание Даньковского клуба	Россия, Курганская область, Щучанский район, село Даньково	0101000020E61000002D3F709527584F40861F9C4F1D8D4B40
50272	6	55	1058	9989	\N	\N	55.120896999999999	Курганская область, Щучанский район, Варгановский сельсовет, с. Варгановское, здание Дома культуры	Россия, Курганская область, Щучанский район, село Варгановское	0101000020E6100000363FFED2A27A4F409E978A8D798F4B40
50287	6	55	1058	10700	41251	\N	55.328873000000002	Курганская область, Щучанский район, Белоярский сельсовет, с. Болоярское, ул. Ленина, 75		0101000020E6100000992B836A832F4F40CAC4AD8218AA4B40
50275	6	55	1058	10124	\N	\N	55.086595000000003	"Курганская область, Щучанский район, Сухоборский сельсовет, д. Арасланова, здание МОУ """"Начальная общеобразовательная школа"""""	Россия, Курганская область, Щучанский район, село Арасланова	0101000020E6100000B84082E2C75A4F40A27F828B158B4B40
50294	6	55	1058	11048	41444	\N	55.208789245514303	Курганская область, Щучанский район, Каясановский сельсовет, п. Алакуль, ул. Привокзальная, 20		0101000020E6100000917D9065C1424F40DD611399B99A4B40
50230	6	55	910	55049	41752	\N	55.316137339708803	Курганская область, Шумихинский район, Кушмянский сельсовет, деревня Чеснокова, улица Центральная, 3	Россия, Курганская область, Шумихинский район, село Чесноково	0101000020E6100000C9737D1F0EBE4F401C075E2D77A84B40
50257	6	55	910	9234	41247	\N	55.238126000000001	Курганская область, Шумихинский район, Кушмянский сельсовет, деревня Хохлы, улица Центральная, 18		0101000020E6100000A04FE449D2BD4F40E529ABE97A9E4B40
50254	6	55	910	9125	41654	\N	55.182295000000003	Курганская область, Шумихинский район, Трусиловский сельсовет, село Трусилово, улица Агеева, 3		0101000020E61000000A4B3CA06CAC4F40B79C4B7155974B40
50235	6	55	910	8260	41686	\N	55.564714000000002	Курганская область, Шумихинский район, Травянский сельсовет, село Травяное, улица Центральная, 13		0101000020E6100000FC89CA8635B54F40F3CB608C48C84B40
50251	6	55	910	9007	41440	\N	55.06953	Курганская область, Шумихинский район, Столбовский сельсовет, село Столбово, улица Центральная, 3		0101000020E61000000FB8AE9811924F40A20BEA5BE6884B40
50237	6	55	910	8342	40825	\N	55.485280000000003	Курганская область, Шумихинский район, Стариковский сельсовет, село Стариково, улица Советская, 3		0101000020E61000007C9A931799804F4092B3B0A71DBE4B40
50253	6	55	910	9088	41647	\N	55.100375999999997	Курганская область, Шумихинский район, Птичанский сельсовет, деревня Сажино, улица Старая, 1		0101000020E61000007EAA0A0DC4AC4F40D2A6EA1ED98C4B40
50252	6	55	910	9028	40992	\N	55.114790999999997	Курганская область, Шумихинский район, Птичанский сельсовет, село Птичье, улица Зеленовка, 2а		0101000020E61000004BB1A371A8B34F400470B378B18E4B40
50231	6	55	910	8033	41434	\N	55.709231000000003	Курганская область, Шумихинский район, Прошкинский сельсовет, село Прошкино, улица Первая, 52		0101000020E610000029266F80997B4F409A27D714C8DA4B40
50255	6	55	910	9163	41136	\N	55.179015	Курганская область, Шумихинский район, Трусиловский сельсовет, село Петухи, улица Центральная, 52		0101000020E61000009626A5A0DBCF4F40293FA9F6E9964B40
50233	6	55	910	8107	41590	\N	55.649737999999999	Курганская область, Шумихинский район, Галкинский сельсовет, деревня Михайловка, улица Центральная, 13		0101000020E61000008255F5F23B6F4F40F67B629D2AD34B40
50245	6	55	910	8718	41318	\N	55.516772000000003	Курганская область, Шумихинский район, Большевистский сельсовет, деревня Межлесье, улица Центральная, 5		0101000020E610000073D712F241A94F4088BEBB9525C24B40
50250	6	55	910	8938	41643	\N	55.200615999999997	Курганская область, Шумихинский район, МалоДюрягинский сельсовет, село Малое Дюрягино, улица Центральная, 36		0101000020E6100000207EFE7BF09C4F40F486FBC8AD994B40
50256	6	55	910	9205	41599	\N	55.304887000000001	Курганская область, Шумихинский район, Кушмянский сельсовет, село Кушма, улица Советская, 20		0101000020E6100000A452EC681CB44F40DFFC868906A74B40
50236	6	55	910	8283	41316	\N	55.635176999999999	Курганская область, Шумихинский район, Травянский сельсовет, деревня Куликово, улица Центральная, 2		0101000020E6100000D8BCAAB35AB64F40F015DD7A4DD14B40
50242	6	55	910	8568	41065	\N	55.395347999999998	Курганская область, Шумихинский район, Большевистский сельсовет, село Крутая Горка, улица Центральная, 7		0101000020E61000006C5D6A847EA24F40FE4465C39AB24B40
50243	6	55	910	8640	41436	\N	55.433087	Курганская область, Шумихинский район, Большевистский сельсовет, деревня Красный Холм, улица Рабочая, 21		0101000020E610000051A2258FA79D4F4050A912656FB74B40
50244	6	55	910	8676	41642	\N	55.493931000000003	Курганская область, Шумихинский район, Большевистский сельсовет, деревня Котлик, улица Озерная, 15		0101000020E6100000E8C1DD59BBA14F4084BD892139BF4B40
50240	6	55	910	8472	41600	\N	55.306122000000002	Курганская область, Шумихинский район, Кипельский сельсовет, село Кипель, улица Шиловская, 4		0101000020E610000062105839B48A4F40064B75012FA74B40
50238	6	55	910	8411	40989	\N	55.397919999999999	Курганская область, Шумихинский район, Карачельский сельсовет, село Карачельское, улица Центральная, 84		0101000020E610000015376E313F9B4F405036E50AEFB24B40
50247	6	55	910	8786	41597	\N	55.226559000000002	Курганская область, Шумихинский район, Каменский сельсовет, деревня Карандашово, улица Набережная, 4		0101000020E6100000F67CCD72D9984F40A7CEA3E2FF9C4B40
50246	6	55	910	8767	41645	\N	55.259805713965697	Курганская область, Шумихинский район, Каменский сельсовет, село Каменное, улица Парковое кольцо, 2	Россия, Курганская область, Шумихинский район, село Каменное	0101000020E61000002BA6D24F389B4F40FCA6B05241A14B40
50232	6	55	910	8100	40991	\N	55.594987000000003	Курганская область, Шумихинский район, Галкинский сельсовет, село Галкино, улица Калинина, 1		0101000020E61000008751103CBE774F40C845B58828CC4B40
50239	6	55	910	8422	41644	\N	55.387847000000001	Курганская область, Шумихинский район, Карачельский сельсовет, деревня Большое Дюрягино, улица Центральная, 32		0101000020E610000098F738D3849D4F40056D72F8A4B14B40
50234	6	55	910	8183	41063	\N	55.587290000000003	Курганская область, Шумихинский район, Рижский сельсовет, село Рига, улица Центральная, 1		0101000020E61000005393E00D699C4F4049A297512CCB4B40
50248	6	55	910	8846	41437	\N	55.410504000000003	Курганская область, Шумихинский район, Благовещенский сельсовет, село Благовещенское, улица Молодежная, 31		0101000020E6100000D97745F0BFA94F40487023658BB44B40
50249	6	55	910	8864	41438	\N	55.178078999999997	Курганская область, Шумихинский район, Березовский сельсовет, село Березово, улица Центральная, 34		0101000020E610000058E71890BD864F405C8DEC4ACB964B40
50211	6	55	228	7120	41595	\N	56.643678000000001	Курганская область, Шатровский район, с. Яутла, ул. Школьная, 9		0101000020E6100000AC1919E42E1E5040CD936B0A64524C40
50210	6	55	228	7039	41604	\N	56.497283000000003	Курганская область, Шатровский район, с. Широково, Советская, 26		0101000020E6100000484E266E15315040ABED26F8A63F4C40
50179	6	55	228	54953	40810	\N	56.520021999999997	Курганская область, Шатровский район, с. Шатрово, Элеваторная, 10		0101000020E6100000548D5E0D50285040AA99B51490424C40
50178	6	55	228	54953	40694	\N	56.520021999999997	Курганская область, Шатровский район, с. Шатрово, Федосеева, 94		0101000020E6100000548D5E0D50285040AA99B51490424C40
50176	6	55	228	54953	40694	\N	56.520021999999997	Курганская область, Шатровский район, с. Шатрово, Федосеева, 64		0101000020E6100000548D5E0D50285040AA99B51490424C40
50058	6	55	228	54953	40694	\N	56.520021999999997	Курганская область, Шатровский район, с. Шатрово, Федосеева, 55		0101000020E6100000548D5E0D50285040AA99B51490424C40
50177	6	55	228	54953	40696	\N	56.520021999999997	Курганская область, Шатровский район, с. Шатрово, 30 лет Победы, 1		0101000020E6100000548D5E0D50285040AA99B51490424C40
50162	6	55	228	4576	41646	\N	56.377063999999997	Курганская область, Шатровский район, д. Черное Макарово, Рабочая, 9А		0101000020E6100000D238D4EFC2345040DD3F16A243304C40
50207	6	55	228	6906	40907	\N	56.293297000000003	Курганская область, Шатровский район, с. Терсюкское, А.И. Киселева, 24		0101000020E61000000DDE57E542345040E9818FC18A254C40
50205	6	55	228	6833	41639	\N	56.2125675630204	Курганская область, Шатровский район, с. Спицыно, ул. Мира, 85	Россия, Курганская область, Шатровский район, село Спицыно	0101000020E6100000A089B0E1E92950408B16A06D351B4C40
50204	6	55	228	6758	41638	\N	56.198951000000001	Курганская область, Шатровский район, д. Сопинина, Велесова, 16		0101000020E610000073F38DE89E265040D540F33977194C40
49754	6	55	228	16685	41169	\N	56.101584000000003	Курганская область, Шатровский район, д. Смолина, Северная, 5		0101000020E61000002CB81FF0C01D504000E65AB4000D4C40
50203	6	55	228	6735	41592	\N	56.223270999999997	Курганская область, Шатровский район, д. Сладчанка, Садовая, 33		0101000020E61000008CF2CCCB612C50409692E524941C4C40
50201	6	55	228	6639	41061	\N	56.646945000000002	Курганская область, Шатровский район, с. Самохвалово, Школьная, 13		0101000020E6100000950C0055DC2D5040C6A70018CF524C40
50187	6	55	228	5902	41637	\N	56.567033000000002	Курганская область, Шатровский район, д. Саломатова, Центральная, 21		0101000020E6100000622EA9DA6E3D50405B608F8994484C40
50209	6	55	228	7005	41433	\N	56.242809000000001	Курганская область, Шатровский район, д. Портнягино, Зеленая, 102		0101000020E610000010ECF82F103050405516855D141F4C40
49755	6	55	228	16755	41176	\N	56.111775000000002	Курганская область, Шатровский район, д. Поротова, Центральная, 17		0101000020E610000076F9D687F51F504055C1A8A44E0E4C40
50200	6	55	228	6578	41244	\N	56.397399999999998	Курганская область, Шатровский район, с. Ожогино, Центральная, 38		0101000020E6100000081D74098721504017B7D100DE324C40
50199	6	55	228	6543	40812	\N	56.411819000000001	Курганская область, Шатровский район, с. Мостовское, Школьная, 28		0101000020E6100000D84AE82E894050408B6F287CB6344C40
49756	6	55	228	54938	41542	\N	56.170736944619001	Курганская область, Шатровский район, с. Мехонское, Мира, 4	Россия, Курганская область, Шатровский район, поселок сельского типа Мехонское	0101000020E61000005E10919A76245040CC9BC3B5DA154C40
50196	6	55	228	54938	41428	\N	56.169317999999997	Курганская область, Шатровский район, с. Мехонское, Ленина, 29		0101000020E61000006F2A52616C245040E34F5436AC154C40
50193	6	55	228	54938	40597	\N	56.169317999999997	Курганская область, Шатровский район, с. Мехонское, Красных Уральцев, 15		0101000020E61000006F2A52616C245040E34F5436AC154C40
50195	6	55	228	6315	41636	\N	56.188102000000001	Курганская область, Шатровский район, д. Ленская, И. Сташкова, 1		0101000020E61000006A334E4354215040F627F1B913184C40
50191	6	55	228	55040	41593	\N	56.349364999999999	Курганская область, Шатровский район, с. Кызылбай, Центральная, 73		0101000020E61000000E164ED2FC105040FBAE08FEB72C4C40
50192	6	55	228	55010	41246	\N	56.349364999999999	Курганская область, Шатровский район, с. Кызылбай, Газовик, 26		0101000020E61000000E164ED2FC105040FBAE08FEB72C4C40
50206	6	55	228	6840	41699	\N	56.225403657666	Курганская область, Шатровский район, д. Коршунова, Лесная, 18	Россия, Курганская область, Шатровский район, село Коршунова	0101000020E6100000FC00A436713150409C31CC09DA1C4C40
50190	6	55	228	6018	41242	\N	56.097456999999999	Курганская область, Шатровский район, с. Кондинское, Центральная, 11		0101000020E6100000C573B680D01B504015E29178790C4C40
50189	6	55	228	6003	41060	\N	56.384151000000003	Курганская область, Шатровский район, с. Кодское, Школьная, 1		0101000020E6100000B7EEE6A90E395040E4DC26DC2B314C40
50197	6	55	228	6412	41588	\N	56.435082999999999	Курганская область, Шатровский район, д. Ключи, Береговая, 18		0101000020E6100000B000A60C1C445040D505BCCCB0374C40
50183	6	55	228	5696	41432	\N	56.244354999999999	Курганская область, Шатровский район, д. Каширцево, Механизаторов, 13		0101000020E610000043908312661650409ACE4E06471F4C40
50188	6	55	228	5934	41059	\N	56.355274999999999	Курганская область, Шатровский район, с. Камышевка, ул. Ленина, 11		0101000020E61000004DA1F31ABB3250400F0BB5A6792D4C40
50202	6	55	228	6672	41586	\N	56.683075000000002	Курганская область, Шатровский район, д. Ирюм, Свободная, 14		0101000020E610000049F4328AE52950408CDB68006F574C40
50185	6	55	228	5784	40811	\N	56.592491000000003	Курганская область, Шатровский район, с. Ильино, Центральная, 8		0101000020E610000095EEAEB3213850405116BEBED64B4C40
50184	6	55	228	5716	41587	\N	56.324536000000002	Курганская область, Шатровский район, с. Изъедугино, Школьная, 15		0101000020E61000005B40683D7C225040F52F49658A294C40
50198	6	55	228	6461	41585	\N	56.390709000000001	Курганская область, Шатровский район, д. Духовка, Центральная, 19		0101000020E610000055A18158364550405EA0A4C002324C40
50186	6	55	228	5823	41641	\N	56.583449999999999	Курганская область, Шатровский район, д. Дружинина, Центральная, 2		0101000020E6100000266F8099EF3B5040F46C567DAE4A4C40
50180	6	55	228	5486	41589	\N	56.519958000000003	Курганская область, Шатровский район, д. Дворцы, ул. Центральная, 8		0101000020E6100000CADC7C23BA23504094A5D6FB8D424C40
50182	6	55	228	5605	41431	\N	56.266976999999997	Курганская область, Шатровский район, с. Дальняя Кубасова, Заречная, 151		0101000020E6100000D74E9484441E504060E4654D2C224C40
50208	6	55	228	6943	41598	\N	56.261443	Курганская область, Шатровский район, д. Воротниково, Пролетарская, 25		0101000020E6100000857B65DEAA3050405262D7F676214C40
50181	6	55	228	54928	40517	\N	56.274929	Курганская область, Шатровский район, с. Барино, ул. Поселковая, 27		0101000020E61000004FAC53E57B3650406ADC9BDF30234C40
50163	6	55	436	4618	40808	\N	56.099103999999997	Курганская область, Шадринский район, Юлдусский сельсовет, село Юлдус, ул. Мира, д. 12		0101000020E6100000815EB873611750408E739B70AF0C4C40
50351	6	55	436	13687	41650	\N	56.025396999999998	Курганская область, Шадринский район, Чистопрудненский сельсовет, деревня Шахматово, ул. Гусиная, д. 12		0101000020E6100000833463D174EE4F4050357A3540034C40
50144	6	55	436	3621	40927	\N	56.015940143905297	Курганская область, Шадринский район, Чистопрудненский сельсовет, село Чистопрудное, ул. Ленина, д. 19	Россия, Курганская область, Шадринский район, село Чистопрудное	0101000020E61000008F6E844545F64F40605969520A024C40
50143	6	55	436	3541	41301	\N	56.013567999999999	Курганская область, Шадринский район, Черемисский сельсовет, село Черемисское, ул. Советская, д. 14		0101000020E6100000AF05BD3786E84F40D522A298BC014C40
50124	6	55	436	2487	41492	\N	55.783504000000001	Курганская область, Шадринский район, Песчанотаволжанский сельсовет, деревня Фрунзе, ул. Кольцевая, д. 5		0101000020E6100000F67B629D2AA54F408124ECDB49E44B40
50168	6	55	436	4894	41421	\N	56.220744000000003	Курганская область, Шадринский район, Тюленевский сельсовет, село Тюленево, ул. Механизаторов, д. 7		0101000020E6100000683D7C9928025040E564E256411C4C40
50165	6	55	436	4719	41239	\N	56.156621000000001	Курганская область, Шадринский район, Неонилинский сельсовет, деревня Титова, ул. Садовая, д. 31		0101000020E610000045D7851F9C105040F46E2C280C144C40
50171	6	55	436	5041	41422	\N	56.396563	Курганская область, Шадринский район, Тарасовский сельсовет, село Тарасова, ул. Советская, д. 5		0101000020E61000007FF8F9EFC1DB4F40DEE68D93C2324C40
50147	6	55	436	3760	40928	\N	56.133899	Курганская область, Шадринский район, Сухринский сельсовет, село Сухринское, ул. Школьная, д. 58		0101000020E6100000C710001C7BB04F40CAFB389A23114C40
50173	6	55	436	5157	41135	\N	56.307127000000001	Курганская область, Шадринский район, Сосновский сельсовет, село Сосновское, ул. Ленина, д. 1		0101000020E6100000F69507E929D04F40FB5B02F04F274C40
50146	6	55	436	3732	41493	\N	56.042577000000001	Курганская область, Шадринский район, Нижнеполевской сельсовет, деревня Соровское, пер. Центральный, д. 2		0101000020E6100000008E3D7B2E025040E947C32973054C40
50164	6	55	436	4681	41426	\N	56.121346000000003	Курганская область, Шадринский район, Юлдусский сельсовет, деревня Сибирки, ул. Гизатуллина, д. 32А		0101000020E6100000768A5583301350400EC00644880F4C40
50129	6	55	436	2746	41504	\N	55.857866999999999	Курганская область, Шадринский район, Краснозвездинский сельсовет, деревня Просвет, ул. Зелёная, д. 18		0101000020E6100000CC086F0F42A44F40A8A8FA95CEED4B40
50350	6	55	436	13661	41651	\N	56.118376569350502	Курганская область, Шадринский район, Ключевской сельсовет, село Прогресс, ул. Садовая, д. 17	Россия, Курганская область, Шадринский район, село Прогресс	0101000020E6100000CC41D0D1AACE4F409FCC3FFA260F4C40
50138	6	55	436	3304	41490	\N	56.001776	Курганская область, Шадринский район, Понькинский сельсовет, село Понькино, ул. Кирова, д. 2		0101000020E6100000B8239C16BCAC4F4077F52A323A004C40
50353	6	55	436	54973	\N	\N	56.073815000000003	Курганская область, Шадринский район, Погорельский сельсовет, село Погорелка, ул. ПМК3		0101000020E6100000E107E753C7DC4F40257A19C572094C40
50349	6	55	436	54973	40839	\N	56.073142962667298	Курганская область, Шадринский район, Погорельский сельсовет, село Погорелка, ул. Северная, д. 17	Россия, Курганская область, Шадринский район, поселок сельского типа Погорелка	0101000020E61000006E4F90D8EEDA4F403677F4BF5C094C40
50157	6	55	436	54973	40818	\N	56.073815000000003	Курганская область, Шадринский район, Погорельский сельсовет, село Погорелка, ул. Исетская, д. 8		0101000020E6100000E107E753C7DC4F40257A19C572094C40
50133	6	55	436	2988	41672	\N	55.978718143531196	Курганская область, Шадринский район, Краснозвездинский сельсовет, деревня Погадайское, ул. Рабочая, д. 2	Россия, Курганская область, Шадринский район, село Погадайское	0101000020E61000009E7B0F971CC14F40D600A5A146FD4B40
50123	6	55	436	2409	41131	\N	55.731338000000001	Курганская область, Шадринский район, Песчанотаволжанский сельсовет, село Песчанотаволжанское, ул. Рабочая, д. 1		0101000020E610000084D72E6D38A84F403929CC7B9CDD4B40
50170	6	55	436	54924	40485	\N	56.349274999999999	Курганская область, Шадринский район, Ольховский сельсовет, село Ольховка, ул. Ленина, д. 152	Россия, Курганская область, Шадринский район, поселок сельского типа Ольховка	0101000020E6100000FCA886FD9EE24F40BB270F0BB52C4C40
50130	6	55	436	2831	41132	\N	55.950721000000001	Курганская область, Шадринский район, Краснозвездинский сельсовет, деревня Октябрь, ул. Будённого, д. 3		0101000020E61000004CC3F01131AB4F406A4FC939B1F94B40
50145	6	55	436	3659	41302	\N	56.048575	Курганская область, Шадринский район, Нижнеполевской сельсовет, село Нижнеполевское, ул. Макеева, д. 26		0101000020E610000098C3EE3B86FB4F409C33A2B437064C40
50166	6	55	436	4807	41419	\N	56.195369727288202	Курганская область, Шадринский район, Неонилинский сельсовет, село Неонилинское, ул. Центральная, д. 61	Россия, Курганская область, Шадринский район, село Неонилинское	0101000020E61000006D54A703590C50404C4F58E201194C40
50149	6	55	436	3853	40902	\N	56.094540000000002	Курганская область, Шадринский район, Мыльниковский сельсовет, село Мыльниково, ул. Набережная, д. 25А		0101000020E6100000CEC4742156C14F40F91400E3190C4C40
49753	6	55	436	16643	41736	\N	56.094877439580301	Курганская область, Шатровский район, д. Могилева, Поселковая, 1 2	Россия, Курганская область, Шадринский район, село Могилева	0101000020E6100000B77EFACF9A1850404012F6ED240C4C40
50128	6	55	436	2715	41675	\N	55.868168238511501	Курганская область, Шадринский район, Мингалевский сельсовет, село Мингали, ул. Трудовая, д. 70	Россия, Курганская область, Шадринский район, село Мингали	0101000020E61000002CD49AE61DEB4F4084B7072120EF4B40
50158	6	55	436	4317	40990	\N	56.083967999999999	Курганская область, Шадринский район, Маслянский сельсовет, село Маслянское, ул. Советская, д. 54		0101000020E610000033C2DB8310F84F408CF4A276BF0A4C40
50151	6	55	436	3962	41078	\N	56.240088	Курганская область, Шадринский район, Мальцевский сельсовет, село Мальцево, ул. Ленина, д. 41		0101000020E61000008675E3DD91B74F40BE141E34BB1E4C40
50136	6	55	436	3182	41673	\N	55.9842068566359	Курганская область, Шадринский район, Краснонивинский сельсовет, деревня Макарово, ул. Труда, д. 3А	Россия, Курганская область, Шадринский район, село Макарово	0101000020E6100000569A94826ED74F4044BFB67EFAFD4B40
50140	6	55	436	3411	40946	\N	56.095067	Курганская область, Шадринский район, Красномыльский сельсовет, село Красномыльское, ул. Набережная, д. 40Б		0101000020E6100000AC90F2936AB94F40E4F6CB272B0C4C40
50137	6	55	436	54940	40603	\N	56.019168000000001	Курганская область, Шадринский район, Краснонивинский сельсовет, село Красная Нива, ул. Зелёная Роща, д. 2		0101000020E61000009CA5643909D34F409B90D61874024C40
50132	6	55	436	55001	41045	\N	55.980657139592701	Курганская область, Шадринский район, Краснозвездинский сельсовет, село Красная Звезда, ул. Ленина, д. 31		0101000020E6100000488C9E5BE8BA4F40F7CB272B86FD4B40
50348	6	55	436	13547	41652	\N	55.898967947929201	Курганская область, Шадринский район, Батуринский сельсовет, деревня Комсомольская, ул. Новая, д. 2	Россия, Курганская область, Шадринский район, село Комсомольская	0101000020E6100000B5FE9600FCD14F404513286211F34B40
50127	6	55	436	2639	41674	\N	55.762968061990101	Курганская область, Шадринский район, Батуринский сельсовет, деревня Колесниково, ул. Береговая, д. 49	Россия, Курганская область, Шадринский район, село Колесниково	0101000020E61000007C4276DEC6E44F4080F277EFA8E14B40
50160	6	55	436	4423	41423	\N	56.070343999999999	Курганская область, Шадринский район, Ильтяковский сельсовет, деревня Кокорина, ул. Уральская, д. 59		0101000020E610000088B9A46ABB06504023BC3D0801094C40
50139	6	55	436	3332	41305	\N	56.125926999999997	Курганская область, Шадринский район, Коврижский сельсовет, село Коврига, ул. Барыкина, д. 34А		0101000020E610000006BD378600A84F4079573D601E104C40
50156	6	55	436	4232	41046	\N	56.133817999999998	Курганская область, Шадринский район, Ключевской сельсовет, село Ключи, ул. Мира, д. 9		0101000020E6100000FBEAAA402DCE4F40DDCEBEF220114C40
50150	6	55	436	54951	40684	\N	56.202992000000002	Курганская область, Шадринский район, Канашский сельсовет, село Канаши, ул. 8 Марта		0101000020E61000001286014BAEBC4F40C1AC50A4FB194C40
50169	6	55	436	4953	41635	\N	56.245575000000002	Курганская область, Шадринский район, Ичкинский сельсовет, село Ичкино, ул. Советская, д. 11		0101000020E6100000A6608DB3E9EE4F408CDB68006F1F4C40
50161	6	55	436	4506	41581	\N	56.060825999999999	Курганская область, Шадринский район, Ильтяковский сельсовет, село Ильтяково, ул. Молодёжная, д. 17		0101000020E61000002DB308C5560B50408D5F7825C9074C40
50154	6	55	436	4129	41583	\N	56.217574999999997	Курганская область, Шадринский район, Ганинский сельсовет, деревня Иванищевское, ул. Молодёжная, д. 2		0101000020E61000008ECEF9298EC54F40AEB6627FD91B4C40
50174	6	55	436	5170	41429	\N	56.341498000000001	Курганская область, Шадринский район, Зеленоборский сельсовет, село Зеленоборское, пер. Школьный, д. 2		0101000020E61000000514EAE923F84F4020D3DA34B62B4C40
50148	6	55	436	3828	41697	\N	56.161900000000003	Курганская область, Шадринский район, Сухринский сельсовет, деревня Замараевское, ул. Восточная, д. 38		0101000020E61000000DFE7E315BA24F40789CA223B9144C40
50352	6	55	436	13748	41267	\N	56.077483000000001	Курганская область, Шадринский район, Маслянский сельсовет, деревня Завьялова, ул. Мира, д. 3		0101000020E610000059C16F438CF34F407C7F83F6EA094C40
50135	6	55	436	3092	41684	\N	55.921742999999999	Курганская область, Шадринский район, Деминский сельсовет, деревня Жеребенково, ул. Труда, д. 12		0101000020E6100000B1C403CAA6C44F409128B4ACFBF54B40
49912	6	55	1680	24568	41388	\N	55.837141000000003	Курганская область, Мокроусовский район, с. Одино, Октябрьская, 1а		0101000020E6100000C47AA35698C350400492B06F27EB4B40
50131	6	55	436	2867	41134	\N	55.934936	Курганская область, Шадринский район, Краснозвездинский сельсовет, деревня Демьяна Бедного, ул. Советская, д. 2		0101000020E61000000F26C5C727B64F4031ED9BFBABF74B40
50134	6	55	436	3057	41687	\N	55.973703	Курганская область, Шадринский район, Деминский сельсовет, село Демино, ул. Ленина, д. 14		0101000020E610000058AD4CF8A5C84F403082C64CA2FC4B40
50172	6	55	436	55041	41594	\N	56.208711268082197	Курганская область, Шадринский район, Глубокинский сельсовет, село Глубокое, ул. Капитана Быкова, д. 36	Россия, Курганская область, Шадринский район, село Глубокая	0101000020E6100000A8DF85ADD9E04F4061A8C30AB71A4C40
50155	6	55	436	4191	41494	\N	56.184350000000002	Курганская область, Шадринский район, Ганинский сельсовет, село Ганино, ул. Садовая, д. 12, кв. 1		0101000020E6100000AEBB79AA43C84F404182E2C798174C40
50159	6	55	436	4417	40904	\N	56.076985999999998	Курганская область, Шадринский район, Верхозинский сельсовет, село Верхозино, ул. Советская, д. 75		0101000020E610000065E08096AE015040FB1F60ADDA094C40
50141	6	55	436	3453	40925	\N	56.071941000000002	Курганская область, Шадринский район, Верхнеполевской сельсовет, село Верхняя Полевая, ул. Мира, д. 36		0101000020E61000005C57CC086FC94F40EB1ED95C35094C40
50167	6	55	436	4827	41420	\N	56.208919999999999	Курганская область, Шадринский район, Борчаниновский сельсовет, село Борчаниново, ул. Центральная, д. 43		0101000020E6100000508C2C99630550407BBDFBE3BD1A4C40
50125	6	55	436	2525	41133	\N	55.797614000000003	Курганская область, Шадринский район, Кабанский сельсовет, село Большое Кабанье, ул. Ленина, д. 17		0101000020E610000013F241CF66C34F40776A2E3718E64B40
50126	6	55	436	54930	40527	\N	55.860408	Курганская область, Шадринский район, Батуринский сельсовет, село Батурино, ул. Гагарина, д. 7		0101000020E6100000FF04172B6AD44F40BF9B6ED921EE4B40
50142	6	55	436	3519	41304	\N	56.047911999999997	Курганская область, Шадринский район, Верхнеполевской сельсовет, деревня Барневское, ул. Железнодорожная, д. 9		0101000020E6100000BAA0BE654EE94F40008BFCFA21064C40
50175	6	55	436	5244	41314	\N	56.476185000000001	Курганская область, Шадринский район, Байракский сельсовет, село Байрак, ул. Советская, д. 6		0101000020E6100000D027F224E90F504042EC4CA1F33C4C40
50153	6	55	436	4080	41415	\N	56.233769000000002	Курганская область, Шадринский район, Ганинский сельсовет, село Агапино, ул. Зелёная, д. 26		0101000020E61000000A48FB1F60C74F40C9E88024EC1D4C40
50365	6	55	318	14367	41273	\N	55.411056000000002	Курганская область, Частоозерский район,  деревня Шестаково, Луговая, дом 29, кв.1		0101000020E6100000293FA9F6E90051408C69A67B9DB44B40
50122	6	55	318	2372	41489	\N	55.463890367287199	Курганская область, Частоозерский район, село Чердынцево, Центральная, 58	Россия, Курганская область, Частоозерский район, село Чердынцево	0101000020E61000006A6D1ADB6B16514081785DBF60BB4B40
50113	6	55	318	1822	41452	\N	55.422165	Курганская область, Частоозерский район, деревня Чебачье, Садовая, 17		0101000020E6100000C558A65F220B51400742B28009B64B40
50108	6	55	318	54985	41043	\N	55.576952112759898	Курганская область, Частоозерский район, село Частоозерье, Энергетиков, 9		0101000020E61000002E54FEB5BCFA50404FAE2990D9C94B40
50369	6	55	318	54985	40936	\N	55.567982999999998	Курганская область, Частоозерский район, село Частоозерье, Октябрьская, 186		0101000020E610000044A7E7DD58FA50408CD7BCAAB3C84B40
50107	6	55	318	54985	40936	\N	55.567982999999998	Курганская область, Частоозерский район, село Частоозерье, Октябрьская, 139		0101000020E610000044A7E7DD58FA50408CD7BCAAB3C84B40
50106	6	55	318	54985	40986	\N	55.567982999999998	Курганская область, Частоозерский район, село Частоозерье, Береговая, 4		0101000020E610000044A7E7DD58FA50408CD7BCAAB3C84B40
50120	6	55	318	2256	41488	\N	55.555188999999999	Курганская область, Частоозерский район, село Сивково, Советская, 17		0101000020E6100000E223624A24ED5040AA0CE36E10C74B40
50118	6	55	318	2144	41579	\N	55.392076000000003	Курганская область, Частоозерский район, деревня Песьяное, Береговая, 22		0101000020E6100000B2632310AFF05040F4C5DE8B2FB24B40
50114	6	55	318	1897	41233	\N	55.467989000000003	Курганская область, Частоозерский район, деревня Окуневка, Мира, 21		0101000020E61000009E23F25D4AF65040A2F14410E7BB4B40
50115	6	55	318	1934	41669	\N	55.397422812138203	Курганская область, Частоозерский район, село Новотроицкое, Красноармейская, 11	Россия, Курганская область, Частоозерский район, село Новотроицкое	0101000020E61000009EEE3CF19C025140D0D6C1C1DEB24B40
50366	6	55	318	14412	41547	\N	55.442720000000001	Курганская область, Частоозерский район, деревня Малодолгие, Школьная, 13		0101000020E6100000D87E32C687F050407FA4880CABB84B40
50119	6	55	318	2184	41582	\N	55.680320999999999	Курганская область, Частоозерский район, село Лиханово, Советская, 1		0101000020E6100000F60D4C6E14EF504019E42EC214D74B40
50121	6	55	318	2296	41312	\N	55.676245000000002	Курганская область, Частоозерский район, деревня Лебяжье, Зелёная, 19		0101000020E61000002BD9B11188E55040B18A37328FD64B40
50110	6	55	318	1677	41619	\N	55.655239000000002	Курганская область, Частоозерский район, деревня Казанцево, Лесная, 19		0101000020E61000009B1C3EE944F9504029081EDFDED34B40
50117	6	55	318	2057	41300	\N	55.448408000000001	Курганская область, Частоозерский район, село Долгие, Советская, 1		0101000020E610000064AE0CAA0DEF5040E4A1EF6E65B94B40
50109	6	55	318	1584	41451	\N	55.591242999999999	Курганская область, Частоозерский район, деревня Денисова, Центральная, 54		0101000020E61000009D47C5FF1DFA5040957EC2D9ADCB4B40
50116	6	55	318	2028	41640	\N	55.3622665697809	Курганская область, Частоозерский район, деревня Гомзино, Центральная, 15	Россия, Курганская область, Частоозерский район, село Гомзино	0101000020E6100000DEE68D93C2025140C4B5DAC35EAE4B40
50101	6	55	80	1140	41237	\N	54.423796000000003	Курганская область, Целинный район, Южный сельсовет, деревня Марс, ул. Школьная, дом 1 кв. 2		0101000020E61000000B992B836ADB4F407B1684F23E364B40
50023	6	55	318	29606	41568	\N	55.421615795508202	Курганская область, Частоозерский район, село Восточное, Пушкина, 2	Россия, Курганская область, Частоозерский район, село Восточное	0101000020E6100000B2D47ABFD1F7504034BC5983F7B54B40
49932	6	55	318	25500	41516	\N	55.382655999999997	Курганская область, Частоозерский район, деревня Волчье, Центральная, 25		0101000020E61000007DE9EDCF45F6504020CF2EDFFAB04B40
50112	6	55	318	1788	41298	\N	55.512475000000002	Курганская область, Частоозерский район, село Бутырино, Центральная, 31		0101000020E61000007023658BA40A51404182E2C798C14B40
50111	6	55	318	1701	41402	\N	55.647005	Курганская область, Частоозерский район, село Беляковское, Калинина, 14		0101000020E6100000C97553CA6B0651409BAC510FD1D24B40
50098	6	55	80	975	41128	\N	54.317390000000003	Курганская область, Целинный район, Луговской сельсовет, деревня Чалкино, ул. Береговая, дом 41 кв. 2		0101000020E6100000CD22145B41BF4F40EA094B3CA0284B40
50059	6	55	80	54923	40480	\N	54.504510000000003	Курганская область, Целинный район, Целинный сельсовет, с.Целинное, ул.8 марта, дом 59		0101000020E6100000109370218FD64F40A3409FC893404B40
50060	6	55	80	54991	40987	\N	54.504510000000003	Курганская область, Целинный район, Целинный сельсовет, село Целинное, ул. Кооперативная, 23		0101000020E6100000109370218FD64F40A3409FC893404B40
50070	6	55	80	31930	41412	\N	54.452863000000001	Курганская область, Целинный район, Фроловский сельсовет, село Фроловка, ул. Центральная, дом 13		0101000020E610000022DE3AFF76C34F40C3482F6AF7394B40
50072	6	55	80	32001	40933	\N	54.268182000000003	Курганская область, Целинный район, УстьУйский сельсовет, село УстьУйское, ул.Кирова, дом 35		0101000020E61000001B67D311C0F34F401DB0ABC953224B40
50094	6	55	80	738	41596	\N	54.399528981211297	Курганская область, Целинный район, Трехозерский сельсовет, село Трехозерки, пер. Школьный, дом 12	Россия, Курганская область, Целинный район, село Трехозерки	0101000020E61000003D0FEECEDACD4F40DC662AC423334B40
50089	6	55	80	394	41229	\N	54.630946000000002	Курганская область, Целинный район, Становской сельсовет, село Становое, ул. Центральная, дом 41		0101000020E61000009A3E3BE0BA05504061C5A9D6C2504B40
50088	6	55	80	354	41231	\N	54.651114999999997	Курганская область, Целинный район, Сетовский сельсовет, село Сетово, ул.Центральная, дом 49		0101000020E610000022A64412BD005040AF777FBC57534B40
50071	6	55	80	31958	41410	\N	54.399531000000003	Курганская область, Целинный район, Фроловский сельсовет, деревня Рыбное, ул.Школьная, дом 17		0101000020E610000037A6272CF1C04F407D5EF1D423334B40
50064	6	55	80	31622	41630	\N	54.305031868280999	Курганская область, Целинный район, Рачеевский сельсовет, село Рачеевка, ул.Школьня, дом 2	Россия, Курганская область, Целинный район, село Рачеевка	0101000020E61000009C14E63DCEAC4F40E21DE0490B274B40
50102	6	55	80	1217	41668	\N	54.430914398840201	Курганская область, Целинный район, Южный сельсовет, деревня Пруды, ул. Клубная, дом 1	Россия, Курганская область, Целинный район, село Пруды	0101000020E61000000A3197546DF54F40BCB1A03028374B40
50069	6	55	80	31875	41137	\N	54.342429000000003	Курганская область, Целинный район, КазакКочердыкский сельсовет, деревня Приозёрная, ул. Притобольная, дом 8		0101000020E6100000FF7A8505F7065040DB19A6B6D42B4B40
50096	6	55	80	866	41154	\N	54.303154999999997	Курганская область, Целинный район, Луговской сельсовет, деревня Полынный Лог, ул. Лесная, дом 13. кв. 1		0101000020E610000017A06D35EBD24F40374F75C8CD264B40
50090	6	55	80	54963	41413	\N	54.695315000000001	Курганская область, Целинный район, Половинский сельсовет, село Половинное, ул. Школьная, дом 26		0101000020E6100000BF9CD9AED0EB4F4089B5F81400594B40
50091	6	55	80	54963	40760	\N	54.695315000000001	Курганская область, Целинный район, Половинский сельсовет, село Половинное, ул. Советская, 53		0101000020E6100000BF9CD9AED0EB4F4089B5F81400594B40
50075	6	55	80	32147	41573	\N	54.336601999999999	Курганская область, Целинный район, УстьУйский сельсовет, деревня Подуровка, ул. Береговая, дом 15		0101000020E6100000C782C2A04C00504054E23AC6152B4B40
50076	6	55	80	32189	40985	\N	54.619224000000003	Курганская область, Целинный район, Васькинский сельсовет, село Пески, ул. Ленина, дом 4		0101000020E610000057B1F84D61A14F40FC7266BB424F4B40
50084	6	55	80	40294	\N	\N	54.340312242609301	"Курганская область, Целинный район, Кислянский сельсовет, деревня Первомайка, Здание конторы бригады № 2 ЗАО """"Куйбышевское"""""	Россия, Курганская область, Целинный район, село Первомайка	0101000020E6100000C7BDF90D13A14F40DA37F7578F2B4B40
50085	6	55	80	145	41629	\N	54.361575999999999	Курганская область, Целинный район, Кислянский сельсовет, деревня Патранино, ул. Школьная, дом 2		0101000020E6100000E17D552E549C4F405E82531F482E4B40
50082	6	55	80	32437	41450	\N	54.432836000000002	Курганская область, Целинный район, Кислянский сельсовет, деревня Николаевка, ул. Центральная, дом 22		0101000020E6100000C45E28603BA84F400744882B67374B40
50077	6	55	80	32216	41591	\N	54.583915603478196	Курганская область, Целинный район, Васькинский сельсовет, деревня Молодёнки, ул. Конторская, дом 1	Россия, Курганская область, Целинный район, село Молоденки	0101000020E61000000D349F73B7AB4F403ACE6DC2BD4A4B40
50095	6	55	80	772	40895	\N	54.291106999999997	Курганская область, Целинный район, Луговской сельсовет, село Михалёво, ул. Советская, дом 1		0101000020E6100000E59997C3EEC94F407E5182FE42254B40
50063	6	55	80	31605	40807	\N	54.5691179637152	Курганская область, Целинный район, Матвеевский сельсовет, село Матвеевка, ул. Клубная, дом 8	Россия, Курганская область, Целинный район, село Матвеевка	0101000020E61000000D198F5209D54F4050C8CEDBD8484B40
49900	6	55	1680	23945	41197	\N	55.671554	Курганская область, Мокроусовский район, д. Новотроицкое, Войкова, 18		0101000020E61000004FCB0F5CE59C5040BEBF417BF5D54B40
50083	6	55	80	32471	\N	\N	54.353937000000002	"Курганская область, Целинный район, Кислянский сельсовет, деревня Мануйлово, Здание конторы бригады № 9 ЗАО """"Куйбышевское"""""	Россия, Курганская область, Целинный район, село Мануйлово	0101000020E61000003D5FB35C36AE4F4014ECBFCE4D2D4B40
50097	6	55	80	55016	41303	\N	54.2246865951088	Курганская область, Целинный район, Луговской сельсовет, деревня Луговая, ул. Большая, дом 57	Россия, Курганская область, Целинный район, село Луговое	0101000020E6100000685BCD3AE3C74F400E6B2A8BC21C4B40
50087	6	55	80	272	41626	\N	54.411563000000001	Курганская область, Целинный район, Косолаповский сельсовет, деревня Листвянка, ул. Советская, 22		0101000020E61000009206B7B585035040309FAC18AE344B40
50081	6	55	80	32377	41225	\N	54.421035000000003	Курганская область, Целинный район, Кислянский сельсовет, деревня Кременёвка, ул. Центральная, дом 13		0101000020E610000020425C397B9B4F4056BC9179E4354B40
50073	6	55	80	32056	41224	\N	54.272289000000001	Курганская область, Целинный район, УстьУйский сельсовет, деревня Красный Октябрь, ул. Речная, дом 10		0101000020E6100000F99D2633DEDE4F40C007AF5DDA224B40
50100	6	55	80	54982	40900	\N	54.431752000000003	Курганская область, Целинный район, Южный сельсовет, село Костыгин  Лог, ул. Строителей, дом 5		0101000020E61000002A1900AAB8E94F40C6FD47A643374B40
50086	6	55	80	237	41057	\N	54.502977999999999	Курганская область, Целинный район, Косолаповский сельсовет, село Косолапово, ул. Школьная, дом 11		0101000020E6100000A1BFD02346FF4F40C24D469561404B40
50079	6	55	80	55023	41411	\N	54.359603999999997	Курганская область, Целинный район, Кислянский сельсовет, село Кислянка, ул. Подорожко, дом 28		0101000020E610000002D6AA5D13A24F4061C1FD80072E4B40
50078	6	55	80	55023	41633	\N	54.360506280585803	Курганская область, Целинный район, Кислянский сельсовет, село Кислянка, ул. Заречная, дом 49		0101000020E6100000EC4E779E78A24F408201840F252E4B40
50068	6	55	80	31806	40981	\N	54.364766000000003	Курганская область, Целинный район, КазакКочердыкский сельсовет, село КазакКочердык, улю Советская, дом 6		0101000020E6100000C26D6DE1790F5040AC58FCA6B02E4B40
50067	6	55	80	31772	41227	\N	54.671934999999998	Курганская область, Целинный район, Иванковский сельсовет, село Иванково, ул. Школьная, дом 5		0101000020E61000007216F6B4C3B54F40D50451F701564B40
50103	6	55	80	60870	76558	\N	54.456899461192698	Курганская область, Целинный район, Южный сельсовет. деревня Зелёная сопка, ул. Центральная, дом 3	Россия, Курганская область, Целинный район, село Зеленая Сопка	0101000020E6100000EB1B98DC28EE4F409D499BAA7B3A4B40
50066	6	55	80	31724	41232	\N	54.678598999999998	Курганская область, Целинный район, Заманилкинский сельсовет, село Заманилки, пер. школьный, дом 4		0101000020E61000000EF96706F1CB4F40950C0055DC564B40
50062	6	55	80	31566	41574	\N	54.494951999999998	Курганская область, Целинный район, Дулинский сельсовет, село Дулино, ул. Центральная, дом 50		0101000020E61000002502D53F88DE4F407E8B4E965A3F4B40
50092	6	55	80	615	41634	\N	54.702306999999998	Курганская область, Целинный район, Половинский сельсовет, деревня Дудино, ул. им. В. Пяткова, дом 34		0101000020E61000000DA7CCCD37F04F403D601E32E5594B40
50093	6	55	80	661	41577	\N	54.658375976141201	Курганская область, Целинный район, Половинский сельсовет, деревня Воздвиженка, ул. Школьная, дом 3	Россия, Курганская область, Целинный район, село Воздвиженка	0101000020E610000005E10A28D4EF4F40533C2EAA45544B40
50065	6	55	80	31700	41670	\N	54.583806000000003	Курганская область, Целинный район, Дубровинский сельсовет, село Большое Дубровное, ул.Школьная, дом 5		0101000020E6100000952710768ABD4F40B39AAE27BA4A4B40
50080	6	55	80	55054	41758	\N	54.359867064224801	Курганская область, Целинный район, Кислянский сельсовет, деревня Белозёрка, ул. Лесная, дом 1	Россия, Курганская область, Целинный район, село Белоозерки	0101000020E6100000632B685A62B34F406FF4311F102E4B40
50045	6	55	1874	30699	41404	\N	54.977620000000002	Курганская область, Сафакулевский район, Яланский сельсовет, с.Яланское, ул. Ленина, д.12		0101000020E6100000596E6935245A4F4030F5F3A6227D4B40
50050	6	55	1874	30969	40978	\N	54.924655999999999	Курганская область, Сафакулевский район, Сулюклинский сельсовет, с.Сулюклино, ул. Колхозная, д. 12		0101000020E61000008DF161F6B24D4F406C06B8205B764B40
50037	6	55	1874	30289	41050	\N	54.758755000000001	Курганская область, Сафакулевский район, Сулеймановский сельсовет, с.Сулейманово, ул. Ленина, д. 2		0101000020E61000009696917A4F474F40975643E21E614B40
50043	6	55	1874	30602	\N	\N	54.864559999999997	Курганская область, Сафакулевский район, Субботинский сельсовет, с.Субботино, ул. Комсомольская, 29	Россия, Курганская область, Сафакулевский район, село Субботино	0101000020E61000008350DEC7D15C4F4002B7EEE6A96E4B40
50039	6	55	1874	30383	41576	\N	54.813479999999998	Курганская область, Сафакулевский район, Сулеймановский сельсовет, д.Сокольники, ул. Центральная, д. 6		0101000020E610000046D3D9C9E04C4F409CF9D51C20684B40
50055	6	55	1874	54921	40980	\N	54.989382999999997	Курганская область, Сафакулевский район, Сафакулевский сельсовет, с.Сафакулево, ул. Энергетиков, д. 1		0101000020E6100000E3C116BB7D444F40F31B261AA47E4B40
50056	6	55	1874	54921	40474	\N	54.989382999999997	Курганская область, Сафакулевский район, Сафакулевский сельсовет, с.Сафакулево, ул. Чапаева, д. 1а		0101000020E6100000E3C116BB7D444F40F31B261AA47E4B40
50054	6	55	1874	54921	41235	\N	54.980890609447698	Курганская область, Сафакулевский район, Сафакулевский сельсовет, с.Сафакулево, ул. Ленина, д. 11		0101000020E61000003E23111AC1464F406AF816D68D7D4B40
49986	6	55	1806	27978	\N	\N	54.760567999999999	Курганская область, Половинский район, Чулошненский сельсовет, д. Новая Украинка, 23		0101000020E6100000001B1021AE8450402B31CF4A5A614B40
50032	6	55	1874	55031	41491	\N	54.7747439843032	Курганская область, Сафакулевский район, СартАбдрашевский сельсовет, с.СартАбдрашево, ул. Октябрьская, 40	Россия, Курганская область, Сафакулевский район, село Сарт-Абдрашево	0101000020E6100000F4A96395D21F4F40D862B7CF2A634B40
50036	6	55	1874	55047	41747	\N	54.774247806294198	Курганская область, Сафакулевский район, СартАбдрашевский сельсовет, с. СартАбдрашево, ул. Больничная, д.1а	Россия, Курганская область, Сафакулевский район, село Сарт-Абдрашево	0101000020E61000006616A1D80A204F40287FF78E1A634B40
50034	6	55	1874	30163	41567	\N	54.743903050587598	Курганская область, Сафакулевский район, СартАбдрашевский сельсовет, д.Преображенка, ул. Школьная, д. 4		0101000020E610000073B9C15087154F40BA32A836385F4B40
50030	6	55	1874	29967	41625	\N	54.851433	Курганская область, Сафакулевский район, Камышинский сельсовет,  д.Озерная, ул. Набережная, 2в		0101000020E61000002A8C2D0439204F401ADEACC1FB6C4B40
50040	6	55	1874	30448	41306	\N	54.703400000000002	Курганская область, Сафакулевский район, Надеждинский сельсовет, с.Надеждинка, ул. Школьная, д. 2		0101000020E6100000CEE0EF17B3554F40D200DE02095A4B40
50044	6	55	1874	30630	41221	\N	54.928531	Курганская область, Сафакулевский район, Субботинский сельсовет, д.Мурзабаева, ул. Центральная, д. 32		0101000020E6100000B07092E68F634F403D29931ADA764B40
50052	6	55	1874	31064	41405	\N	54.913581999999998	Курганская область, Сафакулевский район, Мартыновский сельсовет, с.Мартыновка, ул. Труда, 16		0101000020E6100000C2D9AD65323E4F406D1B4641F0744B40
50026	6	55	1874	29758	41571	\N	55.008462792337298	Курганская область, Сафакулевский район, Мансуровский сельсовет, с.Мансурово, ул. Школьная, д. 6	Россия, Курганская область, Сафакулевский район, село Мансурово	0101000020E61000006901DA56B3244F40EF1CCA5015814B40
50047	6	55	1874	30789	41627	\N	54.929529346758798	Курганская область, Сафакулевский район, Яланский сельсовет,  д.Максимовка, ул. Братьев Михолап, д. 1	Россия, Курганская область, Сафакулевский район, село Максимовка	0101000020E6100000B1A371A8DF594F4080D767CEFA764B40
50025	6	55	1874	29720	41403	\N	55.057496999999998	Курганская область, Сафакулевский район, Карасевский сельсовет, с.Карасево, ул. 70 лет Октября, д. 9		0101000020E610000068B3EA73B52F4F401E4FCB0F5C874B40
50028	6	55	1874	29866	40806	\N	54.822085999999999	Курганская область, Сафакулевский район, Камышинский сельсовет, с.Камышное, ул. Комсомольская, д. 27		0101000020E61000002FC03E3A75254F40EE3F321D3A694B40
50046	6	55	1874	55050	41754	\N	54.986202008742403	Курганская область, Сафакулевский район, Яланский сельсовет,  д. КалмыкАбдрашево, ул. Школьная, д. 31	Россия, Курганская область, Сафакулевский район, село Калмык-Абдрашево	0101000020E6100000D34ECDE5065F4F40F99FFCDD3B7E4B40
50038	6	55	1874	30338	41503	\N	54.767268999999999	Курганская область, Сафакулевский район, Сулеймановский сельсовет, д.Бурматово, ул. Центральная, 2		0101000020E6100000AB05F69848394F40081EDFDE35624B40
50042	6	55	1874	30557	41632	\N	54.808312000000001	Курганская область, Сафакулевский район, Субботинский сельсовет, д.Бугуй, ул. Школьная, д. 6		0101000020E6100000151F9F909D614F40707B82C476674B40
50024	6	55	1874	29678	41575	\N	55.0622259811365	Курганская область, Сафакулевский район, Бахаревский сельсовет, с.Боровичи, ул. Центральная, 96	Россия, Курганская область, Сафакулевский район, село Боровичи (Боровое)	0101000020E61000008C14CAC2D7494F40FF7A8505F7874B40
50029	6	55	1874	29893	41695	\N	54.814517000000002	Курганская область, Сафакулевский район, Камышинский сельсовет, д.Большое Султаново, ул. Школьная, д. 25		0101000020E61000005E656D533C144F409D84D21742684B40
50053	6	55	1874	31082	41240	\N	54.881934000000001	Курганская область, Сафакулевский район, Мартыновский сельсовет, д.Бикбирды, ул. Заречная, д. 11		0101000020E61000007AE1CE8591324F40809D9B36E3704B40
50049	6	55	1874	30913	41407	\N	55.056449999999998	Курганская область, Сафакулевский район, Яланский сельсовет,  д.Белое Озеро, ул Аптыкаевская, д. 10		0101000020E610000065FB90B75C5D4F40FAEDEBC039874B40
50035	6	55	1874	30212	41215	\N	54.794491999999998	Курганская область, Сафакулевский район, СартАбдрашевский сельсовет, д.Баязитово, ул. Школьная, д. 12		0101000020E6100000B476DB85E62E4F408177F2E9B1654B40
50022	6	55	1874	29601	41570	\N	55.099850000000004	Курганская область, Сафакулевский район, Бахаревский сельсовет, д. Бахарево, ул. Школьная, 29А		0101000020E610000016855D143D424F40B84082E2C78C4B40
50041	6	55	1874	30476	41223	\N	54.668348000000002	Курганская область, Сафакулевский район, Надеждинский сельсовет, д.Бакаево, ул. Школьная, д. 21а		0101000020E6100000D74B5304384B4F406B2C616D8C554B40
50033	6	55	1874	30084	41217	\N	54.707436999999999	Курганская область, Сафакулевский район, СартАбдрашевский сельсовет, д.Азналино, ул. Зеленая, д. 15		0101000020E610000035289A07B0244F407C7DAD4B8D5A4B40
50027	6	55	1874	29812	\N	\N	54.964720999999997	Курганская область, Сафакулевский район, Аджитаровский сельсовет, с.Аджитарово, ул. Советская, д. 23	Россия, Курганская область, Сафакулевский район, село Аджитарово	0101000020E6100000D57954FCDF114F40D8614CFA7B7B4B40
50051	6	55	1874	30976	41219	\N	54.863906999999998	Курганская область, Сафакулевский район, Сулюклинский сельсовет, д.Абултаево, ул. Школьная, д. 1		0101000020E610000077137CD3F4494F408AE42B81946E4B40
50018	6	55	1838	29403	\N	\N	54.621934000000003	Курганская область, Притобольный район, Боровлянский сельсовет, село Боровлянка, Здание дома культуры	Россия, Курганская область, Притобольный район, поселок сельского типа Боровлянка	0101000020E6100000904FC8CEDB3F50409F2287889B4F4B40
49910	6	55	1680	24469	41389	\N	55.657428000000003	Курганская область, Мокроусовский район, с. Рассвет, Вострецова, 4		0101000020E6100000A933F790F0C75040C3BCC79926D44B40
50021	6	55	1838	29544	\N	\N	54.607335999999997	Курганская область, Притобольный район, Притобольный сельсовет, деревня Ясная, Здание школы	Россия, Курганская область, Притобольный район, село Ясная	0101000020E6100000425DA450165750407BD7A02FBD4D4B40
50002	6	55	1838	55042	\N	\N	55.0386642222403	Курганская область, Притобольный район, Ярославский сельсовет, село Ярославка, Здание школы	Россия, Курганская область, Притобольный район, село Ярославское	0101000020E6100000AABBB20B065350402AC423F1F2844B40
50009	6	55	1838	28990	\N	\N	54.769531290367098	Курганская область, Притобольный район, Ялымский сельсовет, село Ялым, Здание школы	Россия, Курганская область, Притобольный район, село Ялым	0101000020E610000059FAD005F54550400C21E7FD7F624B40
49996	6	55	1838	28424	\N	\N	54.996402000000003	Курганская область, Притобольный район, Чернавский сельсовет, село Чернавское, Здание дома культуры	Россия, Курганская область, Притобольный район, село Чернавское	0101000020E610000053793BC269475040A2D5C9198A7F4B40
50000	6	55	1838	28587	\N	\N	55.160590999999997	Курганская область, Притобольный район, Нагорский сельсовет, деревня Утятское, Здание дома культуры	Россия, Курганская область, Притобольный район, село Утятское	0101000020E610000056D7A19A924B50401684F23E8E944B40
50006	6	55	1838	55037	\N	\N	54.8366525075933	Курганская область, Притобольный район, Давыдовский сельсовет, деревня Туманово, Здание клуба	Россия, Курганская область, Притобольный район, село Туманова	0101000020E6100000F549EEB0895D5040D68C0C72176B4B40
49997	6	55	1838	28431	\N	\N	55.041801999999997	Курганская область, Притобольный район, Раскатихинский сельсовет, село Раскатиха, Здание школы	Россия, Курганская область, Притобольный район, село Раскатиха	0101000020E6100000800EF3E5054B5040257497C459854B40
50020	6	55	1838	29498	\N	\N	54.612113542072798	Курганская область, Притобольный район, Притобольный сельсовет, село Притобольное, Здание клуба	Россия, Курганская область, Притобольный район, село Притобольное	0101000020E61000009C14E63DCE4950403DB665C0594E4B40
50017	6	55	1838	29344	\N	\N	54.722929999999998	Курганская область, Притобольный район, Плотниковский сельсовет, село Плотниково, Здание Администрации сельсовета	Россия, Курганская область, Притобольный район, село Плотниково	0101000020E6100000B3075A81214450400DA661F8885C4B40
50005	6	55	1838	28844	\N	\N	54.948721585564002	Курганская область, Притобольный район, Давыдовский сельсовет, деревня Патраки, Здание клуба	Россия, Курганская область, Притобольный район, село Патраки	0101000020E61000001F84807C095E5040737FF5B86F794B40
50003	6	55	1838	28700	\N	\N	54.983224999999997	Курганская область, Притобольный район, Чернавский сельсовет, деревня Осиновка, Здание дома культуры	Россия, Курганская область, Притобольный район, село Осиновка	0101000020E6100000963E74417D56504007CE1951DA7D4B40
50001	6	55	1838	28622	\N	\N	55.080607000000001	Курганская область, Притобольный район, Обуховский сельсовет, село Обухово, Здание школы	Россия, Курганская область, Притобольный район, село Обухово	0101000020E61000003430F2B226595040126A8654518A4B40
50012	6	55	1838	29155	\N	\N	54.766385999999997	Курганская область, Притобольный район, Ялымский сельсовет, деревня Обрядовка, Здание клуба	Россия, Курганская область, Притобольный район, село Обрядовка	0101000020E610000035971B0C755050405E0EBBEF18624B40
50011	6	55	1838	29095	41538	\N	54.776259000000003	Курганская область, Притобольный район, Ялымский сельсовет, деревня Новокаминка, Центральная, 14		0101000020E610000037001B10214C5040E31C75745C634B40
50016	6	55	1838	29302	\N	\N	54.698982999999998	Курганская область, Притобольный район, Гладковский сельсовет, деревня Нижняя Алабуга, Здание школы	Россия, Курганская область, Притобольный район, село Нижняя Алабуга	0101000020E6100000A12C7C7DAD545040E0BA624678594B40
49999	6	55	1838	28516	\N	\N	55.150663999999999	Курганская область, Притобольный район, Нагорский сельсовет, село Нагорское, Здание школы	Россия, Курганская область, Притобольный район, село Нагорское	0101000020E61000008C2FDAE3854C50409F573CF548934B40
50019	6	55	1838	29433	\N	\N	54.648766000000002	Курганская область, Притобольный район, Боровлянский сельсовет, деревня Мочалово, Здание клуба	Россия, Курганская область, Притобольный район, село Мочалово	0101000020E6100000A51309A69A415040DD60A8C30A534B40
49995	6	55	1838	54972	\N	\N	54.952997000000003	Курганская область, Притобольный район, Межборный сельсовет, село Межборное, Здание школы	Россия, Курганская область, Притобольный район, поселок сельского типа Межборное	0101000020E61000004F2157EA59465040D31742CEFB794B40
49998	6	55	1838	28489	\N	\N	55.101643000000003	Курганская область, Притобольный район, Нагорский сельсовет, деревня Камышное, Здание школы	Россия, Курганская область, Притобольный район, село Камышное	0101000020E61000004434BA83D84B5040056F48A3028D4B40
50014	6	55	1838	29230	\N	\N	54.719773000000004	Курганская область, Притобольный район, Гладковский сельсовет, деревня Ершовка, Здание клуба	Россия, Курганская область, Притобольный район, село Ершовка	0101000020E6100000E066F162615F50409CC58B85215C4B40
50004	6	55	1838	28790	\N	\N	54.933485115931497	Курганская область, Притобольный район, Давыдовский сельсовет, село Давыдовка, Здание дома культуры	Россия, Курганская область, Притобольный район, село Давыдовка	0101000020E610000092CF2B9E7A5950403D27BD6F7C774B40
49993	6	55	1838	54950	40682	\N	54.907724000000002	Курганская область, Притобольный район, Глядянский сельсовет, село Глядянское, Красноармейская, 17		0101000020E6100000663046240A465040ACE5CE4C30744B40
49992	6	55	1838	54950	40682	\N	54.907724000000002	Курганская область, Притобольный район, Глядянский сельсовет, село Глядянское, Красноармейская, 38		0101000020E6100000663046240A465040ACE5CE4C30744B40
49991	6	55	1838	54950	40682	\N	54.907724000000002	Курганская область, Притобольный район, Глядянский сельсовет, село Глядянское, Красноармейская, 44		0101000020E6100000663046240A465040ACE5CE4C30744B40
50013	6	55	1838	29159	\N	\N	54.717359999999999	Курганская область, Притобольный район, Гладковский сельсовет, село Гладковское, Здание школы	Россия, Курганская область, Притобольный район, село Гладковское	0101000020E61000007A54FCDF115D5040B2BAD573D25B4B40
50008	6	55	1838	28980	\N	\N	54.818962999999997	Курганская область, Притобольный район, Березовский сельсовет, поселок Водный, Здание ФАП	Россия, Курганская область, Притобольный район, село Водный	0101000020E6100000C1FEEBDCB446504028D192C7D3684B40
50007	6	55	1838	28919	\N	\N	54.834662000000002	Курганская область, Притобольный район, Березовский сельсовет, деревня Верхнеберезово, Здание Администрации сельсовета	Россия, Курганская область, Притобольный район, село Верхнеберезово	0101000020E61000007E8D2441B8465040639B5434D66A4B40
50015	6	55	1838	29285	\N	\N	54.710749999999997	Курганская область, Притобольный район, Гладковский сельсовет, деревня Банщиково, Здание клуба	Россия, Курганская область, Притобольный район, село Банщиково	0101000020E6100000FAEE5696E8585040E5D022DBF95A4B40
49994	6	55	1838	28302	\N	\N	54.918585999999998	Курганская область, Притобольный район, Глядянский сельсовет, деревня Арсеновка, Здание Арсеновского дома культуры	Россия, Курганская область, Притобольный район, село Арсеновка	0101000020E610000006BD3786004750401F48DE3994754B40
49988	6	55	1806	28057	41558	\N	54.885283441783301	Курганская область, Половинский район, Яровинский сельсовет, с. Яровое, ул. Центральная, д. 1		0101000020E6100000A5F622DA8E8E5040365A0EF450714B40
49985	6	55	1806	27894	41401	\N	54.762601470386599	Курганская область, Половинский район, Чулошненский сельсовет, с. Чулошное, ул. Советская, д. 1	Россия, Курганская область, Половинский район, село Чулошное	0101000020E6100000BBD23252EF8D5040CD72D9E89C614B40
49983	6	55	1806	27907	41209	\N	54.833905000000001	Курганская область, Половинский район, Сухменский сельсовет, д. Чернавчик, ул. Береговая, д. 13		0101000020E6100000A9A10DC006A05040467C2766BD6A4B40
49984	6	55	1806	27889	40975	\N	54.774852000000003	Курганская область, Половинский район, Хлуповский сельсовет, с. Хлупово, пер. Садиковский, 2		0101000020E6100000354580D3BB795040BF9EAF592E634B40
49976	6	55	1806	27520	\N	\N	54.680909999999997	Курганская область, Половинский район, Половинский сельсовет, д. Филиппово, Здание начальной школы	Россия, Курганская область, Половинский район, село Филиппово	0101000020E6100000637C98BD6C8550407AC2120F28574B40
49987	6	55	1806	27990	\N	\N	54.790454547306197	Курганская область, Половинский район, Чулошненский сельсовет, д. Успенка, д. 22, кв. 1	Россия, Курганская область, Половинский район, село Успенка	0101000020E6100000BA10AB3FC2975040D7FA22A12D654B40
49982	6	55	1806	27798	41624	\N	54.873041000000001	Курганская область, Половинский район, Сухменский сельсовет, с. Сухмень, ул. Ленина, д. 13		0101000020E610000068D0D03FC1A550409888B7CEBF6F4B40
49981	6	55	1806	27643	\N	\N	55.053547000000002	Курганская область, Половинский район, Сумкинский сельсовет, ст. Сумки, ул. Центральная, д. 7, кв. 16	Россия, Курганская область, Половинский район, село Сумки, станция Сумки	0101000020E610000035255987A371504043E6CAA0DA864B40
49979	6	55	1806	27643	40754	\N	55.052778000000004	Курганская область, Половинский район, Сумкинский сельсовет, с. Сумки, ул. Ленинская, д. 45		0101000020E610000085950A2AAA71504062F9F36DC1864B40
49969	6	55	1806	27155	41399	\N	54.639211000000003	Курганская область, Половинский район, Пищальский сельсовет, д. Романово, ул. Центральная, д. 34а		0101000020E6100000DC65BFEE746550402A1F82AAD1514B40
49977	6	55	1806	27567	41524	\N	54.787590443518802	Курганская область, Половинский район, Привольненский сельсовет, с. Привольное, ул. Озерная, д. 1	Россия, Курганская область, Половинский район, село Привольное	0101000020E61000008196AE601BAE50400D54C6BFCF644B40
49970	6	55	1806	54948	40976	\N	54.793982999999997	Курганская область, Половинский район, Половинский сельсовет, с. Половинное, ул. Советская, д. 50		0101000020E61000007AFD497CEE7E50403C4A253CA1654B40
49971	6	55	1806	54948	40745	\N	54.793982999999997	Курганская область, Половинский район, Половинский сельсовет, с. Половинное, ул. Победы, д. 12		0101000020E61000007AFD497CEE7E50403C4A253CA1654B40
49972	6	55	1806	54948	40679	\N	54.793982999999997	Курганская область, Половинский район, Половинский сельсовет, с. Половинное, ул. К. Маркса, д. 14		0101000020E61000007AFD497CEE7E50403C4A253CA1654B40
49968	6	55	1806	27149	41207	\N	54.692469000000003	Курганская область, Половинский район, Пищальский сельсовет, с. Пищальное, ул. Ленина, д. 18		0101000020E61000009DBCC804FC6B5040363FFED2A2584B40
49975	6	55	1806	27438	\N	\N	54.757092999999998	Курганская область, Половинский район, Половинский сельсовет, д. Петровка, Здание начальной школы	Россия, Курганская область, Половинский район, село Петровка	0101000020E6100000575F5D15A87F5040E883656CE8604B40
49965	6	55	1806	27022	41206	\N	54.945231	Курганская область, Половинский район, Новобайдарский сельсовет, с. Новые Байдары, ул. Молодежная, д. 2		0101000020E6100000F4A5B73F177750402B155454FD784B40
49964	6	55	1806	26970	41501	\N	54.819248000000002	Курганская область, Половинский район, Менщиковский сельсовет, с. Менщиково, ул. Советская, д. 31		0101000020E610000041800C1D3B6A50401EA8531EDD684B40
49966	6	55	1806	27041	41211	\N	54.937292999999997	Курганская область, Половинский район, Новобайдарский сельсовет, д. Марай, ул. Школьная, д. 2		0101000020E61000008D976E128378504086E28E37F9774B40
49980	6	55	1806	55055	41760	\N	55.077094101870003	Курганская область, Половинский район, Сумкинский сельсовет, д. Малое Дубровное, ул. Победы, д. 71	Россия, Курганская область, Половинский район, село Малодубровное	0101000020E6100000EEEBC039236C5040E25B5837DE894B40
49990	6	55	1806	28130	41409	\N	54.911501999999999	Курганская область, Половинский район, Яровинский сельсовет, д. Казенное, ул. Веселая, д. 14		0101000020E6100000EEB089CC5C8E50408A1EF818AC744B40
49967	6	55	1806	27091	41212	\N	54.882669999999997	Курганская область, Половинский район, Новобайдарский сельсовет, д. Жилино, ул. Чуйкова, д. 27		0101000020E61000005B5CE333D97A504085949F54FB704B40
49974	6	55	1806	27417	41623	\N	54.827234802874401	Курганская область, Половинский район, Половинский сельсовет, д. Дубровка, ул. Сиреневая, д. 25	Россия, Курганская область, Половинский район, село Дубровка	0101000020E61000001A321EA512815040A48D23D6E2694B40
49963	6	55	1806	26892	41621	\N	54.637101159383803	Курганская область, Половинский район, Воскресенский сельсовет, с. Воскресенское, ул. Советская, 43	Россия, Курганская область, Половинский район, село Воскресенское	0101000020E61000000327DBC01D725040DC9F8B868C514B40
49978	6	55	1806	27594	\N	\N	54.765269000000004	Курганская область, Половинский район, Привольненский сельсовет, д. Воздвиженка, Здание начальной школы	Россия, Курганская область, Половинский район, село Воздвиженка	0101000020E6100000132C0E677EA0504042D2A755F4614B40
49962	6	55	1806	26885	41671	\N	54.888190000000002	Курганская область, Половинский район, Васильевский сельсовет, с. Васильевка, ул. Молодежная, д. 10, кв. 2		0101000020E610000048C0E8F2E68450402F51BD35B0714B40
49961	6	55	1806	26810	41400	\N	55.038072999999997	Курганская область, Половинский район, Булдакский сельсовет, с. Булдак, ул. Школьная, д. 18		0101000020E6100000887FD8D2A387504028EE7893DF844B40
49960	6	55	1806	26772	41023	\N	54.731352000000001	Курганская область, Половинский район, Башкирский сельсовет, с. Башкирское, ул. Ленина, д. 39		0101000020E6100000CF9ECBD4247650409EEE3CF19C5D4B40
49989	6	55	1806	28099	\N	\N	54.889982000000003	Курганская область, Половинский район, Яровинский сельсовет, д. Батырево, ул. Центральная, д. 4	Россия, Курганская область, Половинский район, село Батырево	0101000020E6100000511553E927975040AC0320EEEA714B40
49959	6	55	1806	26730	41522	\N	55.006883999999999	Курганская область, Половинский район, Байдарский сельсовет, с. Байдары, ул. Школьная, д. 43		0101000020E61000009032E202D0765040CE6E2D93E1804B40
49945	6	55	1293	26105	41203	\N	55.280681999999999	Курганская область, Петуховский район, Курортский сельсовет, с. Утчанское, Озёрная, 16		0101000020E6100000856055BDFCF95040B6494563EDA34B40
49951	6	55	1293	26344	41622	\N	55.146694896815603	Курганская область, Петуховский район, Троицкий сельсовет, с. Троицкое, Молодежная, 6	Россия, Курганская область, Петуховский район, село Троицкое	0101000020E6100000F18288D4B40351404DBED9E6C6924B40
49916	6	55	1293	24746	41467	\N	54.967264	Курганская область, Петуховский район, Стрелеченский сельсовет, с. Стрельцы, Озёрная, 31		0101000020E6100000D767CEFA94EE5040904C874ECF7B4B40
49958	6	55	1293	26680	41520	\N	55.152466923246799	Курганская область, Петуховский район, Рынковский сельсовет, д. Староберезово, Центральная, 4/1	Россия, Курганская область, Петуховский район, село Староберезово	0101000020E61000001494A2957BF25040105CE50984934B40
49956	6	55	1293	26575	41521	\N	55.179867999999999	Курганская область, Петуховский район, Рынковский сельсовет, с. Рынки, Школьная, 2		0101000020E6100000C05FCC96ACED504068CC24EA05974B40
49943	6	55	1293	26012	41391	\N	55.138660000000002	Курганская область, Петуховский район, Новоберезовский сельсовет, д. Пьянково, Железнодорожная, 3		0101000020E61000006A6AD95A5FE45040B6A1629CBF914B40
49955	6	55	1293	26548	41614	\N	54.8642599144654	Курганская область, Петуховский район, Приютинский сельсовет, д. Подувальная, Школьная, 13/2	Россия, Курганская область, Петуховский район, село Подувальная	0101000020E6100000ABED26F8A6E15040D89E5912A06E4B40
49928	6	55	1293	13535	\N	\N	55.065578784023202	Курганская область, Петуховский район, город Петухово, пос. КМП, здание ИП Кривоногов		0101000020E610000073D9E89C9FF85040F62686E464884B40
49953	6	55	1293	26451	41397	\N	55.102595999999998	Курганская область, Петуховский район, Петуховский сельсовет, с. Петухово, Набережная, 13		0101000020E6100000A94F72874DFD5040A759A0DD218D4B40
49942	6	55	1293	25949	41202	\N	55.250346	Курганская область, Петуховский район, Актабанский сельсовет, д. Песьяное, Московская, 22/1		0101000020E610000068588CBAD61D51409B5775560BA04B40
49949	6	55	1293	26258	41618	\N	55.251649567819399	Курганская область, Петуховский район, Пашковский сельсовет, с. Пашково, Школьная, 13	Россия, Курганская область, Петуховский район, село Пашково	0101000020E61000000D198F52090B5140EA04341136A04B40
49948	6	55	1293	54981	40892	\N	55.010323	Курганская область, Петуховский район, Октябрьский сельсовет, с. Октябрьское, Озёрная, 9		0101000020E6100000171230BABCF65040C4B2994352814B40
49935	6	55	1293	25608	41188	\N	55.245255	Курганская область, Петуховский район, Новоильинский сельсовет, с. Новое Ильинское, Молодежная, 31		0101000020E610000066F4A3E1940351401A170E84649F4B40
49886	6	55	1680	23309	\N	\N	55.785625000000003	Курганская область, Мокроусовский район, д. Пороги, 37		0101000020E6100000965D30B8E6B15040C3F5285C8FE44B40
49944	6	55	1293	26065	41205	\N	55.276944	Курганская область, Петуховский район, Новогеоргиевский сельсовет, с. Новогеоргиевка 2я, Центральная, 35		0101000020E6100000B76114048FF550406669A7E672A34B40
49957	6	55	1293	26624	41518	\N	55.229911999999999	Курганская область, Петуховский район, Рынковский сельсовет, д. Новогеоргиевка 1я, Тополиная, 2/2		0101000020E610000003232F6B62EA50409E7AA4C16D9D4B40
49941	6	55	1293	25917	41396	\N	55.078859999999999	Курганская область, Петуховский район, Новоберезовский сельсовет, с. Новоберёзово, Береговая, 60		0101000020E610000083893F8A3AF25040357BA015188A4B40
49931	6	55	1293	25432	41609	\N	55.255969999999998	Курганская область, Петуховский район, Большекаменский сельсовет, д. Новая Лебяжка, Новолебяжьевская, 30		0101000020E61000007D94111780275140E960FD9FC3A04B40
49938	6	55	1293	25762	41394	\N	55.006749999999997	Курганская область, Петуховский район, Матасинский сельсовет, с. Матасы, Береговая, 3А		0101000020E610000002BB9A3C65025140BE9F1A2FDD804B40
50354	6	55	1293	55013	\N	\N	55.240112000000003	"Курганская область, Петуховский район, Курортский сельсовет, поселок """"Курорт """"Озеро Медвежье"""""""", гл. корп. Курорта """"Озеро Медвежье"""""""		0101000020E6100000A20E2BDCF2FC504047B071FDBB9E4B40
49940	6	55	1293	13828	40890	\N	55.240112000000003	"Курганская область, Петуховский район, Курортский сельсовет, поселок """"Курорт """"Озеро Медвежье"""""""", Мира, 1"""		0101000020E6100000A20E2BDCF2FC504047B071FDBB9E4B40
49952	6	55	1293	26372	41395	\N	55.111846779315997	Курганская область, Петуховский район, Троицкий сельсовет, д. Казанцевское, Школьная, 41	Россия, Курганская область, Петуховский район, село Казанцевское	0101000020E610000088307E1AF70C5140EE93A300518E4B40
49936	6	55	1293	25702	41666	\N	55.083002999999998	Курганская область, Петуховский район, Зотинский сельсовет, с. Зотино, Школьная, 54		0101000020E6100000D5EC815660035140253CA1D79F8A4B40
49946	6	55	1293	26114	\N	\N	55.282328	"Курганская область, Петуховский район, Новогеоргиевский сельсовет, д. Золотовка, контора ООО """"Северное"""""		0101000020E6100000E1CE85915EF850405F5FEB5223A44B40
49934	6	55	1293	25603	41192	\N	55.306731999999997	Курганская область, Петуховский район, Жидковский сельсовет, с. Жидки, Новая, 18		0101000020E6100000E9616875720851407E5182FE42A74B40
49939	6	55	1293	25818	41693	\N	55.012286968027098	Курганская область, Петуховский район, Матасинский сельсовет, ст. Горбуново, Привокзальная, 8	Россия, Курганская область, Петуховский район, село Горбуново	0101000020E61000005F5FEB52230C51403E95D39E92814B40
49937	6	55	1293	25746	41620	\N	55.074962999999997	Курганская область, Петуховский район, Зотинский сельсовет, с. Горбунешное, Школьная, 17		0101000020E6100000B933130CE70D51407CB4386398894B40
49947	6	55	1293	26163	41392	\N	55.323782000000001	Курганская область, Петуховский район, Новогеоргиевский сельсовет, д. Воробьи, Плакуновская, 19		0101000020E6100000F2D077B7B2EE5040498446B071A94B40
49950	6	55	1293	26295	41393	\N	55.227544999999999	Курганская область, Петуховский район, Пашковский сельсовет, д. Буранное, Приозёрная, 3		0101000020E61000006B28B517D108514025AFCE31209D4B40
49954	6	55	1293	26474	41406	\N	54.910916999999998	Курганская область, Петуховский район, Приютинский сельсовет, с. Большое Приютное, С. Баева, 65		0101000020E61000000C1F115322E650406A2FA2ED98744B40
49930	6	55	1293	25394	41186	\N	55.292422999999999	Курганская область, Петуховский район, Большекаменский сельсовет, с. Большое Каменное, Набережная, 49		0101000020E6100000312592E86524514092CCEA1D6EA54B40
49933	6	55	1293	25514	41517	\N	54.985182999999999	Курганская область, Петуховский район, Большегусиновский сельсовет, с. Большое Гусиное, Северная, 9А/5		0101000020E61000002B4CDF6B08DB50409FC9FE791A7E4B40
49917	6	55	1293	24815	41611	\N	54.951914412598001	Курганская область, Петуховский район, Стрелеченский сельсовет, с. Богданы, Советская, 29	Россия, Курганская область, Петуховский район, село Богданы	0101000020E61000004F5B238271E65040624D6551D8794B40
49929	6	55	1293	25326	41002	\N	55.309314999999998	Курганская область, Петуховский район, Актабанский сельсовет,с. Актабан, Советская, 17		0101000020E6100000BE4EEACBD2145140C49448A297A74B40
49892	6	55	1680	23586	41563	\N	55.989316859541603	Курганская область, Мокроусовский район, с. Щигры, ул. Молодежная, 28	Россия, Курганская область, Мокроусовский район, село Щигры	0101000020E6100000134548DDCEA750403C3080F0A1FE4B40
49914	6	55	1680	24668	41184	\N	55.713110999999998	Курганская область, Мокроусовский район, с. Шелепово, Школьная, 10		0101000020E61000005322895E46D350407CB5A33847DB4B40
49887	6	55	1680	23323	\N	\N	55.799036000000001	Курганская область, Мокроусовский район, д. Чесноково, 28б		0101000020E610000074D0251C7AB95040D029C8CF46E64B40
49907	6	55	1680	24283	41616	\N	55.703200000000002	Курганская область, Мокроусовский район, с. Утичье, 70 лет Октября, 7а		0101000020E610000096B20C71ACB950400B46257502DA4B40
49891	6	55	1680	23506	41213	\N	55.929918999999998	Курганская область, Мокроусовский район,с. Уварово, Центральная, 20		0101000020E610000049F4328AE5A95040EA76F69507F74B40
49897	6	55	1680	23822	41035	\N	55.573734000000002	Курганская область, Мокроусовский район,  с. Травное, Школьная, 2		0101000020E6100000AD33BE2F2EB65040384D9F1D70C94B40
49908	6	55	1680	24355	41311	\N	55.732894000000002	Курганская область, Мокроусовский район, д. Тетерье, Первая Школьная, 1а		0101000020E6100000C075C58CF0B75040A2B77878CFDD4B40
49895	6	55	1680	55044	41738	\N	55.639106849207103	Курганская область, Мокроусовский район, с. Сунгурово, 40 лет Победы, 28	Россия, Курганская область, Мокроусовский район, село Сунгурова	0101000020E610000069A9BC1DE1A8504085D21742CED14B40
49901	6	55	1680	23988	41385	\N	55.695621000000003	Курганская область, Мокроусовский район, с. Старопершино, Школьная, 22		0101000020E6100000750470B3789A504096B4E21B0AD94B40
3172	5	54	7205	52645	65285	\N	58.714565999999998	Парабель, Советская, 78, телефон: 23502		0101000020E61000008F54DFF945605440B16A10E6765B4D40
49885	6	55	1680	54980	41562	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Советская, 1		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49877	6	55	1680	54980	41562	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Советская, 27		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49881	6	55	1680	54980	41383	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Сабанина, 15		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49878	6	55	1680	54980	41378	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Октябрьская, 25		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49883	6	55	1680	54980	41198	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Механизаторов, 32		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49858	6	55	1680	54980	41372	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Лесная, 13а		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49882	6	55	1680	54980	40885	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Куйбышева, 7		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49880	6	55	1680	54980	40883	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, Береговая, 7а		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49879	6	55	1680	54980	40882	\N	55.809818	Курганская область, Мокроусовский район, с. Мокроусово, 40 лет Победы, 18		0101000020E6100000FBAF73D366B1504027DBC01DA8E74B40
49899	6	55	1680	23906	41564	\N	55.635054847334402	Курганская область, Мокроусовский район, с. Михайловка, Центральная, 7	Россия, Курганская область, Мокроусовский район, село Михайловка	0101000020E6100000713AC956979F5040A514747B49D14B40
49909	6	55	1680	24398	41605	\N	55.693784000000001	Курганская область, Мокроусовский район, д. Межеумное, Вторая Школьная, 4		0101000020E6100000EFAD484C50BC5040793E03EACDD84B40
49904	6	55	1680	24166	\N	\N	55.812656812528097	Курганская область, Мокроусовский район, д. Малое Середкино, 9а	Россия, Курганская область, Мокроусовский район, село Малое Середкино	0101000020E61000007D2079E750985040C8EE022505E84B40
49896	6	55	1680	23777	\N	\N	55.582084999999999	Курганская область, Мокроусовский район, д. Малое Песьяново, 28		0101000020E610000036C98FF815A75040FF3EE3C281CA4B40
49903	6	55	1680	24085	41572	\N	55.774358191298198	Курганская область, Мокроусовский район, с. Малое Мостовское, 2 Береговая, 7	Россия, Курганская область, Мокроусовский район, село Малое Мостовское	0101000020E6100000C2F9D4B14A975040AFB2B6291EE34B40
49911	6	55	1680	24492	41617	\N	55.551237	Курганская область, Мокроусовский район, с. Лопарево, Школьная, 17		0101000020E61000001BD7BFEB33D450402EAC1BEF8EC64B40
49893	6	55	1680	23631	41379	\N	55.715387999999997	Курганская область, Мокроусовский район, с. Лапушки, Дружбы, 10		0101000020E61000009F01F566D4AA5040B5F97FD591DB4B40
49913	6	55	1680	24597	41182	\N	55.779949999999999	Курганская область, Мокроусовский район, с. Куртан, Победы, 14		0101000020E61000006D020CCB9FCC5040F241CF66D5E34B40
49905	6	55	1680	23846	\N	\N	55.790899000000003	Курганская область, Мокроусовский район, д. Круглое, 40а		0101000020E6100000991249F4329F504035B8AD2D3CE54B40
49898	6	55	1680	23846	\N	\N	55.790899000000003	Курганская область, Мокроусовский район, д. Круглое, 13		0101000020E6100000991249F4329F504035B8AD2D3CE54B40
49888	6	55	1680	23398	41737	\N	55.845483305242603	Курганская область, Мокроусовский район, с. Крепость, пер. Школьный, 2	Россия, Курганская область, Мокроусовский район, село Крепость	0101000020E6100000CCED5EEE93AF5040782975C938EC4B40
49889	6	55	1680	55039	41578	\N	55.877906731166	Курганская область, Мокроусовский район, д. Кокорево, Центральная, 27а	Россия, Курганская область, Мокроусовский район, село Кокарево	0101000020E6100000E412471E88AD5040F9F6AE415FF04B40
49890	6	55	1680	23498	41381	\N	55.861767	Курганская область, Мокроусовский район, с. Карпунино, А. Прокопьева, 3		0101000020E6100000BEC0AC50A4B75040D2E28C614EEE4B40
49902	6	55	1680	24074	41195	\N	55.722988999999998	Курганская область, Мокроусовский район, д. Дмитриевка, Новая, 4		0101000020E6100000D47E6B274A985040122F4FE78ADC4B40
49915	6	55	1680	24713	\N	\N	55.663842000000002	Курганская область, Мокроусовский район, д. Большое Щучье, 14		0101000020E6100000144031B264DB50400ADB4FC6F8D44B40
49894	6	55	1680	23694	\N	\N	55.675345999999998	Курганская область, Мокроусовский район, д Большое Песьяное, 12		0101000020E61000007BF7C77BD5AC504001BEDBBC71D64B40
49875	6	55	1349	22781	41667	\N	55.602137179884501	Курганская область, Мишкинский район, Шаламовский сельсовет, село Шаламово, Советская, 36	Россия, Курганская область, Мишкинский район, село Шаламово	0101000020E6100000865968E734C94F40145B41D312CD4B40
49865	6	55	1349	22348	41369	\N	55.695154000000002	Курганская область, Мишкинский район, Купайский сельсовет, деревня Троицкое, Береговая, 21		0101000020E610000096253ACB2CDC4F4080D767CEFAD84B40
49868	6	55	1349	22506	41374	\N	55.000497000000003	Курганская область, Мишкинский район, Мыркайский сельсовет, деревня Сосново, Солнечная, 13		0101000020E6100000A3E6ABE463E94F40815F234910804B40
49854	6	55	1349	21854	41734	\N	55.393866131268901	Курганская область, Мишкинский район, Восходский сельсовет, село Сладкокарасинское, Школьная, 12	Россия, Курганская область, Мишкинский район, село Сладкокарасинское	0101000020E61000007EFE7BF0DA055040D0807A336AB24B40
49852	6	55	1349	21759	41310	\N	55.349051000000003	Курганская область, Мишкинский район, Введенский сельсовет, станция Сладкое, Станционная, 1		0101000020E61000001D925A28990850406CD102B4ADAC4B40
49872	6	55	1349	22689	41194	\N	55.542360000000002	Курганская область, Мишкинский район, Первомайский сельсовет, село Первомайское, Советская, 5		0101000020E61000005969520ABAE54F404C546F0D6CC54B40
49874	6	55	1349	21965	41297	\N	55.376907000000003	Курганская область, Мишкинский район, Рождественский сельсовет, село Бутырское, Центральная, 35		0101000020E6100000978E39CFD8C74F401651137D3EB04B40
49870	6	55	1349	22599	41730	\N	55.342735349248002	Курганская область, Мишкинский район, Островнинский сельсовет, село Островное, Береговая, 21	Россия, Курганская область, Мишкинский район, село Островное	0101000020E61000002D228AC91BEA4F40E71890BDDEAB4B40
49869	6	55	1349	22518	41376	\N	55.776456000000003	Курганская область, Мишкинский район, Новопесковский сельсовет, село Новые Пески, Луговая, 28		0101000020E6100000A243E048A0F34F40396403E962E34B40
49867	6	55	1349	22416	41561	\N	55.041446000000001	Курганская область, Мишкинский район, Мыркайский сельсовет, село Мыркайское, Центральная, 43		0101000020E6100000E84A04AA7FE44F4067463F1A4E854B40
49876	6	55	1349	22849	41387	\N	55.662699000000003	Курганская область, Мишкинский район, Шаламовский сельсовет, деревня Мокрушино, Озёрная, 9		0101000020E6100000B3075A8121B54F40C40B2252D3D44B40
49846	6	55	1349	21187	40974	\N	55.338844951376799	Курганская область, Мишкинский район, рабочий поселок Мишкино, Победы, 4	Россия, Курганская область, Мишкинский район, поселок городского типа Мишкино	0101000020E61000004AB20E4757F54F40E1B4E0455FAB4B40
49843	6	55	1349	54929	40801	\N	55.343015000000001	Курганская область, Мишкинский район, рабочий поселок Мишкино, Строительная, 7		0101000020E6100000E657738060F44F40CB845FEAE7AB4B40
49845	6	55	1349	54929	41550	\N	55.343015000000001	Курганская область, Мишкинский район, рабочий поселок Мишкино, Северная, 2		0101000020E6100000E657738060F44F40CB845FEAE7AB4B40
49848	6	55	1349	54929	40525	\N	55.345387295457797	Курганская область, Мишкинский район, рабочий поселок Мишкино, РабочеКрестьянская, 136 А	Россия, Курганская область, Мишкинский район, поселок городского типа Мишкино	0101000020E6100000717500C45DF34F4056BB26A435AC4B40
49842	6	55	1349	54929	40593	\N	55.337878574337502	Курганская область, Мишкинский район, рабочий поселок Мишкино, Первомайская, 24	Россия, Курганская область, Мишкинский район, поселок городского типа Мишкино	0101000020E6100000D508FD4CBDF44F40AA807B9E3FAB4B40
49841	6	55	1349	54929	40591	\N	55.343846725480397	Курганская область, Мишкинский район, рабочий поселок Мишкино, Ленина, 1	Россия, Курганская область, Мишкинский район, поселок городского типа Мишкино	0101000020E610000011FE45D098F34F40F2E9B12D03AC4B40
49840	6	55	1349	54929	40591	\N	55.343015000000001	Курганская область, Мишкинский район, рабочий поселок Мишкино, Ленина, 23		0101000020E6100000E657738060F44F40CB845FEAE7AB4B40
49847	6	55	1349	54929	41196	\N	55.340911584926701	Курганская область, Мишкинский район, рабочий поселок Мишкино, Заводская, 28		0101000020E610000034DAAA24B2F34F4030682101A3AB4B40
49871	6	55	1349	22611	41560	\N	55.248139000000002	Курганская область, Мишкинский район, Островнинский сельсовет, деревня Маслово, Южная, 10		0101000020E6100000BC94BA641CE34F405BEECC04C39F4B40
49866	6	55	1349	22411	41559	\N	55.205081	Курганская область, Мишкинский район, Маслинский сельсовет, село Масли, Новая, 6		0101000020E6100000535E2BA1BBE64F40F7031E18409A4B40
49859	6	55	1349	22085	41732	\N	55.469974000000001	Курганская область, Мишкинский район, Иванковский сельсовет, деревня Малое Окунёво, Сиреневая, 10		0101000020E6100000213A048E04CA4F4033FCA71B28BC4B40
49863	6	55	1349	22277	41368	\N	55.156939999999999	Курганская область, Мишкинский район, Краснознаменский сельсовет, село Лебяжье, Береговая, 37		0101000020E6100000FBCA83F41406504095B7239C16944B40
49864	6	55	1349	22343	41193	\N	55.647198000000003	Курганская область, Мишкинский район, Купайский сельсовет, село Купай, Центральная, 23		0101000020E610000002F04FA912D34F40B0045262D7D24B40
49862	6	55	1349	54998	41033	\N	55.256242	Курганская область, Мишкинский район, Краснознаменский сельсовет, село Краснознаменское, Мира, 5		0101000020E610000024D40CA9A20150404AEEB089CCA04B40
49861	6	55	1349	22171	41733	\N	55.100731000000003	Курганская область, Мишкинский район, Коровинский сельсовет, село Коровье, Ленина, 34		0101000020E61000009F724C16F7F94F40C158DFC0E48C4B40
50367	6	55	1349	54996	41010	\N	55.553279000000003	Курганская область, Мишкинский район, Кировский сельсовет, село Кирово, Кирова, 52		0101000020E61000007A71E2AB1DE14F402448A5D8D1C64B40
49860	6	55	1349	54996	41010	\N	55.553279000000003	Курганская область, Мишкинский район, Кировский сельсовет, село Кирово, Кирова, 50		0101000020E61000007A71E2AB1DE14F402448A5D8D1C64B40
49849	6	55	1349	21582	41370	\N	55.390117997118701	Курганская область, Мишкинский район, поселок Иванковское, Николаева, 20	Россия, Курганская область, Мишкинский район, село Иванковское	0101000020E6100000B62FA017EEEE4F405CCAF962EFB14B40
49857	6	55	1349	21984	40803	\N	55.703128999999997	Курганская область, Мишкинский район, Дубровинский сельсовет, село Дубровное, Советская, 44		0101000020E6100000581AF8510DEF4F4041EF8D2100DA4B40
49855	6	55	1349	21893	41190	\N	55.378442	Курганская область, Мишкинский район, Гладышевский сельсовет, село Гладышево, Центральная, 29		0101000020E6100000062B4EB516DC4F4067B796C970B04B40
49873	6	55	1349	55052	41756	\N	55.565587051355102	Курганская область, Мишкинский район, Первомайский сельсовет, деревня Гаганово, Школьная, 4	Россия, Курганская область, Мишкинский район, село Гаганова	0101000020E6100000C5758C2B2EEA4F407905A22765C84B40
49853	6	55	1349	21793	40802	\N	55.361738000000003	Курганская область, Мишкинский район, Восходский сельсовет, с. Восход, Садовая, 5 Б		0101000020E61000005E4A5D328E04504038DC476E4DAE4B40
49851	6	55	1349	21681	41027	\N	55.324171	Курганская область, Мишкинский район, Введенский сельсовет, село Введенское, Советская, 35		0101000020E6100000BE840A0E2F055040E3A7716F7EA94B40
49850	6	55	1349	21659	\N	\N	55.585315999999999	Курганская область, Мишкинский район, Варлаковский сельсовет, село Варлаково, Советская, 23	Россия, Курганская область, Мишкинский район, село Варлаково	0101000020E610000006A051BAF4F94F40ABE97AA2EBCA4B40
49856	6	55	1349	21965	41554	\N	55.376907000000003	Курганская область, Мишкинский район, Гладышевский сельсовет, деревня Бутырское, Лесная, 33		0101000020E6100000978E39CFD8C74F401651137D3EB04B40
49807	6	55	1577	19404	41293	\N	55.140554000000002	Курганская область, Макушинский район, д. Ясные Зори, Яснозаринская, 1а		0101000020E6100000382C0DFCA8D3504037A968ACFD914B40
49820	6	55	1577	20098	41295	\N	55.069597000000002	Курганская область, Макушинский район, с. Чебаки, Центральная, 7		0101000020E6100000444FCAA486D150402A73F38DE8884B40
49810	6	55	1577	19562	41125	\N	55.339022	Курганская область, Макушинский район, д. Ударник, Центральная, 5		0101000020E6100000FEF3346090CE5040F04FA91265AB4B40
49814	6	55	1577	19759	41661	\N	55.508053557169099	Курганская область, Макушинский район, с. Трюхино, Школьная, 2	Россия, Курганская область, Макушинский район, село Трюхино	0101000020E6100000CFF8BEB854D350400E4DD9E907C14B40
49837	6	55	1577	21021	41729	\N	55.047835782741998	Курганская область, Макушинский район, с. Требушинненое, Береговая, 63	Россия, Курганская область, Макушинский район, село Требушинное	0101000020E6100000C21550A8A7B7504025C9737D1F864B40
49818	6	55	1577	19966	41021	\N	55.189162000000003	Курганская область, Макушинский район, с. Степное, Мира, 5		0101000020E61000007D1F0E12A2DB5040AFD2DD7536984B40
49822	6	55	1577	20201	41382	\N	54.975667000000001	Курганская область, Макушинский район, с. Слевное, Молодежная, 6а		0101000020E610000026C632FD12CE5040AA6400A8E27C4B40
49824	6	55	1577	20344	41725	\N	55.077843999999999	Курганская область, Макушинский район, с. Сетовное, Школьная, 35		0101000020E6100000FF3EE3C281C450404C18CDCAF6894B40
49805	6	55	1577	55046	41745	\N	55.177422177460599	Курганская область, Макушинский район, с. Садовод, Пролетарская, 1	Россия, Курганская область, Макушинский район, село Садовод	0101000020E6100000A3923A014DD05040A3CB9BC3B5964B40
49829	6	55	1577	20621	41552	\N	55.275640014623697	Курганская область, Макушинский район, Раздолье, Центральная, 9 кв. 2		0101000020E61000007EC7F0D8CFC7504017BCE82B48A34B40
49832	6	55	1577	20789	41553	\N	54.891933999999999	Курганская область, Макушинский район, д. Профинтерн, Дерибасовская, 4		0101000020E610000037FFAF3A72C050406118B0E42A724B40
49830	6	55	1577	20685	41126	\N	55.206682999999998	Курганская область, Макушинский район, д. Привольное, Центральная, 1		0101000020E61000006BD26D895CC15040D0D1AA96749A4B40
49815	6	55	1577	19799	41292	\N	55.471592000000001	Курганская область, Макушинский район, д. Покровка, Центральная, 12		0101000020E610000094BE1072DECD504012876C205DBC4B40
49817	6	55	1577	54997	41018	\N	55.263773	Курганская область, Макушинский район, с. Пионерское, Советская, 7		0101000020E610000096438B6CE7E05040AE484C50C3A14B40
49838	6	55	1577	21114	41181	\N	54.978777000000001	Курганская область, Макушинский район, д. Пеган, Центральная, 15		0101000020E61000005517F032C3BD5040DB899290487D4B40
49808	6	55	1577	19461	41015	\N	55.298665999999997	Курганская область, Макушинский район, с. Обутковское, Т.Дрязгова, 2б		0101000020E6100000D6E429ABE9D75040AC36FFAF3AA64B40
49835	6	55	1577	20937	41549	\N	54.805441999999999	Курганская область, Макушинский район, д. Неверовское, Лесная, 7		0101000020E6100000AC8DB1135EB55040946934B918674B40
49836	6	55	1577	21014	41728	\N	54.9864886040926	Курганская область, Макушинский район, с. Моховое, Молодежная, 15	Россия, Курганская область, Макушинский район, село Моховое	0101000020E6100000BAD8B45208B550408F6E8445457E4B40
49816	6	55	1577	19870	41016	\N	55.377741	Курганская область, Макушинский район, с. Моршиха, Советская, 14		0101000020E61000002EE23B31EBC35040DEAD2CD159B04B40
49823	6	55	1577	20260	41183	\N	54.910187000000001	Курганская область, Макушинский район, с. Мартино, Школьная, 16		0101000020E61000007B1684F23ECC5040471FF30181744B40
49811	6	55	1577	18962	41659	\N	55.211588999999996	Курганская область, Макушинский район, город Макушино, Ленина, 133А		0101000020E610000079C9FFE4EFCE5040BF982D59159B4B40
49809	6	55	1577	55043	41694	\N	55.337965046650602	Курганская область, Макушинский район, д. Копырино, Центральная, 9а	Россия, Курганская область, Макушинский район, село Копырено	0101000020E6100000E3FF8EA850D95040A818E76F42AB4B40
49828	6	55	1577	20576	41025	\N	55.256914000000002	Курганская область, Макушинский район, с. Коновалово, Молодежная, 1		0101000020E6100000E012807F4ABD504039F1D58EE2A04B40
49833	6	55	1577	20817	41731	\N	54.932788000000002	Курганская область, Макушинский район, с. Клюквенное, Глинских, 34		0101000020E610000034B91803EBAE5040F60CE19865774B40
49812	6	55	1577	19629	41660	\N	55.397475	Курганская область, Макушинский район, с.Казаркино, Школьная, 15		0101000020E61000002079E75086DA504022FDF675E0B24B40
49826	6	55	1577	20466	41548	\N	55.124290000000002	Курганская область, Макушинский район, с. Золотое, Центральная, 7		0101000020E61000008B389D64ABBF5040249C16BCE88F4B40
49806	6	55	1577	40343	9884	\N	55.194610530268299	Курганская область, Макушинский район, д. Журавлевское, Восточная, 15а	Россия, Курганская область, Макушинский район, село Журавлевка	0101000020E6100000E3A6069ACFD350408F386403E9984B40
49825	6	55	1577	20371	41546	\N	55.092143999999998	Курганская область, Макушинский район, д. Гренадеры, Центральная, 20		0101000020E6100000AAB8718BF9C75040E542E55FCB8B4B40
49821	6	55	1577	20153	41692	\N	55.053272999999997	Курганская область, Макушинский район, д. Братанники, Крестьянская, 14а		0101000020E61000003A2009FB76D55040416150A6D1864B40
49834	6	55	1577	20891	41723	\N	54.859302124148897	Курганская область, Макушинский район, д. Бородинка, Мира, 21	Россия, Курганская область, Макушинский район, село Бородинка	0101000020E61000006631B1F9B8AE504096B1A19BFD6D4B40
49831	6	55	1577	20729	40880	\N	54.917810000000003	Курганская область, Макушинский район, с. Большое Курейное, Первомайская, 47		0101000020E61000008D0DDDEC0FBD50408CF84ECC7A754B40
49827	6	55	1577	20513	41365	\N	55.181925	Курганская область, Макушинский район, д. Большое Кривинское, Центральная, 6		0101000020E61000003FE42D573FBA504093A9825149974B40
3171	5	54	7205	52645	65285	\N	58.714565999999998	Парабель, Советская, 78, телефон: 23383		0101000020E61000008F54DFF945605440B16A10E6765B4D40
49819	6	55	1577	20015	41664	\N	55.033124999999998	Курганская область, Макушинский район, с. Басковское, Школьная, 1а		0101000020E610000078B471C45ADF50400AD7A3703D844B40
49813	6	55	1577	19697	41665	\N	55.442371999999999	Курганская область, Макушинский район, д. Антипино, Центральная, 15		0101000020E61000005F97E13FDDDB504043554CA59FB84B40
49792	6	55	1472	18622	41487	\N	55.449730000000002	Курганская область, Лебяжьевский район, Прилогинский сельсовет, деревня Юдино, Широкая, 7		0101000020E610000061376C5B949D5040DA03ADC090B94B40
49797	6	55	1472	18862	41361	\N	55.287101999999997	Курганская область, Лебяжьевский район, Черемушкинский сельсовет, село Черемушки, Садовая, 2		0101000020E610000061FBC9181FA75040DF4E22C2BFA44B40
49798	6	55	1472	18927	41289	\N	55.365048999999999	Курганская область, Лебяжьевский район, Черемушкинский сельсовет, деревня Чаешное, Сиреневая, 2		0101000020E61000009A232BBF0CA650400038F6ECB9AE4B40
49768	6	55	1472	17395	41008	\N	55.161183000000001	Курганская область, Лебяжьевский район, Баксарский сельсовет, село Центральное, Ленина, 29		0101000020E6100000EFAB72A1F2A15040E9D500A5A1944B40
49796	6	55	1472	18814	41362	\N	55.080545000000001	Курганская область, Лебяжьевский район, Хуторской сельсовет, село Хутора, Центральная, 64		0101000020E61000003C873254C59050409C6D6E4C4F8A4B40
49783	6	55	1472	18160	41122	\N	55.435907	Курганская область, Лебяжьевский район, Менщиковский сельсовет, деревня Суерская, Весенняя, 23		0101000020E61000003CDD79E239A750407A8CF2CCCBB74B40
49793	6	55	1472	18660	41179	\N	55.186118999999998	Курганская область, Лебяжьевский район, Речновский сельсовет, село Речное, Центральная, 3		0101000020E6100000F435CB65A3975040051555BFD2974B40
49790	6	55	1472	18511	41287	\N	55.475929000000001	Курганская область, Лебяжьевский район, Прилогинский сельсовет, село Прилогино, Центральная, 15		0101000020E610000055682096CD985040E71BD13DEBBC4B40
49788	6	55	1472	18413	41180	\N	55.239733000000001	Курганская область, Лебяжьевский район, Плосковской сельсовет, село Плоское, Придорожная, 1		0101000020E6100000A6F0A0D975905040D0622992AF9E4B40
49781	6	55	1472	18034	41544	\N	55.048400000000001	Курганская область, Лебяжьевский район, Лопатинский сельсовет, деревня Песьяное, Школьная, 4		0101000020E6100000B79C4B7155A950402E90A0F831864B40
49777	6	55	1472	17837	41119	\N	55.215102000000002	Курганская область, Лебяжьевский район, Лисьевский сельсовет, деревня Островное, Школьная, 2		0101000020E6100000CD3FFA264DB25040F0A65B76889B4B40
49785	6	55	1472	18242	41545	\N	55.369210984729797	Курганская область, Лебяжьевский район, Налимовский сельсовет, село Налимово, Садовая, 1, кв. 2	Россия, Курганская область, Лебяжьевский район, село Налимово	0101000020E6100000766C04E275B950406729594E42AF4B40
49782	6	55	1472	18112	41360	\N	55.479669000000001	Курганская область, Лебяжьевский район, Менщиковский сельсовет, село Менщиково, Центральная, 51		0101000020E61000009FAA4203B1A65040D8F335CB65BD4B40
49779	6	55	1472	54989	41364	\N	54.986629999999998	Курганская область, Лебяжьевский район, Лопатинский сельсовет, село Лопатки, Комсомольская, 2		0101000020E61000001C7E37DDB2A7504051A04FE4497E4B40
49780	6	55	1472	54989	40971	\N	54.986629999999998	Курганская область, Лебяжьевский район, Лопатинский сельсовет, село Лопатки, К. Маркса, 30		0101000020E61000001C7E37DDB2A7504051A04FE4497E4B40
49776	6	55	1472	17802	41726	\N	55.139211000000003	Курганская область, Лебяжьевский район, Лисьевский сельсовет, село Лисье, Молодежная, 7		0101000020E6100000E275FD82DDB050402A1F82AAD1914B40
49787	6	55	1472	18335	41486	\N	55.327919999999999	Курганская область, Лебяжьевский район, Перволебяжьевский сельсовет, деревня Лебяжье1, Кривина, 2		0101000020E61000003D2828452B9D504027DA5548F9A94B40
49759	6	55	1472	54947	40911	\N	55.270615999999997	Курганская область, Лебяжьевский район, р. п. Лебяжье, Спортивная, 32		0101000020E6100000AD3594DA8B9F50401DE38A8BA3A24B40
49764	6	55	1472	54947	40675	\N	55.270615999999997	Курганская область, Лебяжьевский район, р. п. Лебяжье, Пушкина, 23		0101000020E6100000AD3594DA8B9F50401DE38A8BA3A24B40
49762	6	55	1472	54947	40675	\N	55.270615999999997	Курганская область, Лебяжьевский район, р. п. Лебяжье, Пушкина, 17		0101000020E6100000AD3594DA8B9F50401DE38A8BA3A24B40
49765	6	55	1472	54947	40797	\N	55.270615999999997	Курганская область, Лебяжьевский район, р. п. Лебяжье, Первомайская, 11		0101000020E6100000AD3594DA8B9F50401DE38A8BA3A24B40
49761	6	55	1472	54947	40795	\N	55.270615999999997	Курганская область, Лебяжьевский район, р. п. Лебяжье, К. Маркса, 87		0101000020E6100000AD3594DA8B9F50401DE38A8BA3A24B40
49760	6	55	1472	54947	40932	\N	55.270615999999997	Курганская область, Лебяжьевский район, р. п. Лебяжье, Железнодорожная, 124		0101000020E6100000AD3594DA8B9F50401DE38A8BA3A24B40
49775	6	55	1472	17751	41657	\N	55.317141724475498	Курганская область, Лебяжьевский район, Камышинский сельсовет, деревня Кукушкино, Советская, 23	Россия, Курганская область, Лебяжьевский район, село Кукушкино	0101000020E610000060CB2BD7DB8E50401118EB1B98A84B40
49784	6	55	1472	18181	41121	\N	55.504964999999999	Курганская область, Лебяжьевский район, Менщиковский сельсовет, деревня Кузнецово, Озерная, 8		0101000020E610000080D3BB783FA75040F44F70B1A2C04B40
49795	6	55	1472	18766	\N	\N	55.145715000000003	Курганская область, Лебяжьевский район, Речновский сельсовет, деревня Кузинка, 14		0101000020E610000081785DBF60915040B1C403CAA6924B40
49791	6	55	1472	18530	41696	\N	55.510016999999998	Курганская область, Лебяжьевский район, Прилогинский сельсовет, деревня Красная Горка, Зеленая, 2		0101000020E610000065FD6662BA9C5040B7B3AF3C48C14B40
49774	6	55	1472	17705	41178	\N	55.417363000000002	Курганская область, Лебяжьевский район, Камышинский сельсовет, село Камышное, Озерная, 46		0101000020E6100000FBAC32535A905040BDC799266CB54B40
49735	6	55	1305	15755	41537	\N	54.845512999999997	Курганская область, Куртамышский район, Обанинский сельсовет, с.Обанино, Центральная, 14		0101000020E6100000266DAAEE91295040E2AB1DC5396C4B40
49772	6	55	1472	17603	41359	\N	55.077199226854297	Курганская область, Лебяжьевский район, Калашинский сельсовет, село Калашное, Центральная, 6	Россия, Курганская область, Лебяжьевский район, село Калашное	0101000020E6100000AABBB20B06A25040572426A8E1894B40
49794	6	55	1472	18716	\N	\N	55.23368	Курганская область, Лебяжьевский район, Речновский сельсовет, деревня Желтики, 34		0101000020E6100000F7065F984C99504059DDEA39E99D4B40
49770	6	55	1472	17496	41724	\N	55.519648565957098	Курганская область, Лебяжьевский район, Дубровинский сельсовет, село Дубровное, Центральная, 34	Россия, Курганская область, Лебяжьевский район, село Дубровное	0101000020E6100000BAA3FFE55AB950401633C2DB83C24B40
49786	6	55	1472	18284	41722	\N	55.301929999999999	Курганская область, Лебяжьевский район, Нижнеголовинский сельсовет, село Головное, Школьная, 3		0101000020E610000058C51B9947B4504034D769A4A5A64B40
49758	6	55	1472	16892	41177	\N	55.295406	Курганская область, Лебяжьевский район, деревня Верхнеглубокое, Молодежная, 5		0101000020E6100000EBFEB1101DA15040668522DDCFA54B40
49771	6	55	1472	54983	\N	\N	55.25911	Курганская область, Лебяжьевский район, Елошанский сельсовет. село Елошное, Василки, 1		0101000020E610000081221631ECA35040850838842AA14B40
49767	6	55	1472	17319	41551	\N	55.558554000000001	Курганская область, Лебяжьевский район, Арлагульский сельсовет, деревня Моховое, Молодежная, 1		0101000020E6100000069CA5643992504066868DB27EC74B40
49789	6	55	1472	18421	41727	\N	55.2122736788616	Курганская область, Лебяжьевский район, Плосковской сельсовет, деревня Белянино, Центральная, 6	Россия, Курганская область, Лебяжьевский район, село Белянино	0101000020E61000003AB187F6B187504043E55FCB2B9B4B40
49769	6	55	1472	17436	41740	\N	55.4470737920619	Курганская область, Лебяжьевский район, Балакульский сельсовет, село Балакуль, Центральная, 19	Россия, Курганская область, Лебяжьевский район, село Балакуль	0101000020E61000008CF84ECC7AB650402A7288B839B94B40
49778	6	55	1472	17904	41663	\N	55.152075344435701	Курганская область, Лебяжьевский район, Лисьевский сельсовет, деревня Баксары, Южная, 18	Россия, Курганская область, Лебяжьевский район, село Баксары	0101000020E610000030293E3E21A6504005C58F3177934B40
49766	6	55	1472	17305	41284	\N	55.507474000000002	Курганская область, Лебяжьевский район, Арлагульский сельсовет, село Арлагуль, Центральная, 64, кв. 2		0101000020E6100000B6F468AA2796504000C974E8F4C04B40
49773	6	55	1472	17637	41271	\N	55.107622999999997	Курганская область, Лебяжьевский район, Калашинский сельсовет, деревня Александровка, Зеленая, 9		0101000020E6100000E8F9D3467598504011A62897C68D4B40
49737	6	55	1305	15864	41352	\N	54.803657000000001	Курганская область, Куртамышский район, Обанинский сельсовет, д.Ярки, Центральная, 1		0101000020E6100000BDC799266C335040CA198A3BDE664B40
49717	6	55	1305	14902	41530	\N	54.878345000000003	Курганская область, Куртамышский район, Закоуловский сельсовет, д.Язево, Северная, 7		0101000020E610000040BFEFDFBC3A504075CDE49B6D704B40
49720	6	55	1305	15040	41355	\N	54.543188000000001	Курганская область, Куртамышский район, Камаганский сельсовет, д.Чесноковка, Школьная, 2		0101000020E61000007FBF982D590A504032CA332F87454B40
49727	6	55	1305	15384	41718	\N	54.672190000000001	Курганская область, Куртамышский район, Костылевский сельсовет, д.Черноборье, Школьная, 5А		0101000020E61000004AED45B41D0D5040605969520A564B40
49749	6	55	1305	16445	41358	\N	54.443156999999999	Курганская область, Куртамышский район, Угловский сельсовет, с.Угловое, Новая, 15		0101000020E61000009F211CB3EC1450402AFF5A5EB9384B40
49709	6	55	1305	14509	41163	\N	54.909815000000002	Курганская область, Куртамышский район, Верхневский сельсовет, д.Сычево, Полевая, 13		0101000020E61000001DAED51EF6145040833463D174744B40
49713	6	55	1305	14681	41160	\N	55.027721999999997	Курганская область, Куртамышский район, Закомалдинский сельсовет, д.Стрижово, Крестьянская, 22А		0101000020E61000009E5C5320B31A50409AB0FD648C834B40
49742	6	55	1305	16086	41356	\N	55.077705000000002	Курганская область, Куртамышский район, Песьяновский сельсовет, д.Степное, Молодёжная, 161		0101000020E610000031D120054F3350402BDEC83CF2894B40
49723	6	55	1305	15182	41532	\N	55.066375000000001	Курганская область, Куртамышский район, Камышинский сельсовет, д.Сосновка, Школьная, 6		0101000020E6100000C1C58A1A4C405040D122DBF97E884B40
49711	6	55	1305	14610	41715	\N	54.956600999999999	Курганская область, Куртамышский район, Жуковский сельсовет, д.Сорокино, Новая, 9		0101000020E61000007A8B87F71C0D50401329CDE6717A4B40
49745	6	55	1305	54978	40877	\N	54.623899000000002	Курганская область, Куртамышский район, Советский сельсовет, с.Советское, Школьная, 9		0101000020E610000020CF2EDFFA215040E98024ECDB4F4B40
49744	6	55	1305	16170	40794	\N	54.976270999999997	Курганская область, Куртамышский район, Пушкинский сельсовет, с.Пушкино, Центральная, 66		0101000020E610000025EA059FE62850404084B872F67C4B40
49706	6	55	1305	14366	41536	\N	54.682898000000002	Курганская область, Куртамышский район, Большеберезовский сельсовет, д.Птичье, Главная, 12		0101000020E6100000FE4465C39A2150407D40A03369574B40
49739	6	55	1305	15952	41007	\N	54.998220000000003	Курганская область, Куртамышский район, Песьяновский сельсовет, с.Песьяное, Зеленая, 24		0101000020E6100000787C7BD7A0335040481B47ACC57F4B40
49734	6	55	1305	15701	41720	\N	54.755294999999997	Курганская область, Куртамышский район, Нижневский сельсовет, д.Перевалово, Школьная, 5		0101000020E6100000DD088B8A3822504089EAAD81AD604B40
49738	6	55	1305	15903	41167	\N	55.056997000000003	Курганская область, Куртамышский район, Пепелинский сельсовет, с.Пепелино, Центральная, 94		0101000020E6100000E7A8A3E36A0950402D7C7DAD4B874B40
49719	6	55	1305	14971	41716	\N	54.557881999999999	Курганская область, Куртамышский район, Камаганский сельсовет, д.Острова, Центральная, 2		0101000020E610000080B8AB5791165040778368AD68474B40
49705	6	55	1305	55048	41750	\N	54.747684545607001	Курганская область, Куртамышский район, Большеберезовский сельсовет, д.НовоКалиновка, Центральная, 16	Россия, Курганская область, Куртамышский район, село Новая Калиновка	0101000020E61000000C93A982511B5040D95A5F24B45F4B40
49731	6	55	1305	55002	41074	\N	54.858096283834101	Курганская область, Куртамышский район, Нижневский сельсовет, с.Нижнее, Садовая, 10	Россия, Курганская область, Куртамышский район, поселок сельского типа Нижнее	0101000020E610000011548D5E0D1F50400A6AF816D66D4B40
49730	6	55	1305	15536	41744	\N	55.0794691086302	Курганская область, Куртамышский район, Масловский сельсовет, с.Маслово, Радужная, 12	Россия, Курганская область, Куртамышский район, село Маслово	0101000020E61000000B2769FE98105040DE054A0A2C8A4B40
49733	6	55	1305	15673	41353	\N	54.856921	Курганская область, Куртамышский район, Нижневский сельсовет, д.Малетино, Центральная, 65		0101000020E6100000B5E0455F41225040B8205B96AF6D4B40
49741	6	55	1305	16045	41719	\N	54.954796999999999	Курганская область, Куртамышский район, Песьяновский сельсовет, д.Лебяжье, Центральная, 20		0101000020E6100000730F09DFFB3A5040D2A8C0C9367A4B40
49694	6	55	1305	13752	40741	\N	54.909354	Курганская область, Куртамышский район, город Куртамыш, Югова, 2а		0101000020E610000094FAB2B4531B50404F3E3DB665744B40
49697	6	55	1305	13752	40742	\N	54.909354	Курганская область, Куртамышский район, город Куртамыш, XXII партсъезда, 44		0101000020E610000094FAB2B4531B50404F3E3DB665744B40
49716	6	55	1305	14846	41341	\N	54.815389000000003	Курганская область, Куртамышский район, Закоуловский сельсовет, д.Курмыши, Южная, 14А		0101000020E61000009BE61DA7E83650405342B0AA5E684B40
49748	6	55	1305	16376	41349	\N	54.619807000000002	Курганская область, Куртамышский район, Советский сельсовет, д. Красная Звезда, Центральная, 1А		0101000020E6100000B9C32632732650407B6AF5D5554F4B40
49728	6	55	1305	15415	40969	\N	54.806890454909002	Курганская область, Куртамышский район, Косулинский сельсовет, с.Косулино, Центральная, 16	Россия, Курганская область, Куртамышский район, село Косулино	0101000020E610000066DAFE959503504017BCE82B48674B40
49724	6	55	1305	15237	41534	\N	54.762250999999999	Курганская область, Куртамышский район, Костылевский сельсовет, с.Костылево, Школьная, 1А		0101000020E61000001BF67B629D115040F12BD67091614B40
49732	6	55	1305	15622	41484	\N	54.850116	Курганская область, Куртамышский район, Нижневский сельсовет, д.Коновалова, Центральная, 22В		0101000020E6100000CFD72C978D25504036E7E099D06C4B40
49747	6	55	1305	16336	41348	\N	54.552995000000003	Курганская область, Куртамышский район, Советский сельсовет, д.Коминтерн, Центральная, 11А		0101000020E610000018CDCAF621235040FFEC478AC8464B40
49740	6	55	1305	15992	41539	\N	55.063122	Курганская область, Куртамышский район, Песьяновский сельсовет, д.Ключики, Центральная, 2		0101000020E61000006F826F9A3E2F50403DD4B66114884B40
49726	6	55	1305	15328	41717	\N	54.746347	Курганская область, Куртамышский район, Костылевский сельсовет, д.Клоктухино, Лесная, 31А		0101000020E6100000A6EF3504C70C5040DE3B6A4C885F4B40
49736	6	55	1305	15806	41307	\N	54.838898	Курганская область, Куртамышский район, Обанинский сельсовет, д.Кислое, Центральная, 30		0101000020E610000081E84999D42C504004577902616B4B40
49722	6	55	1305	15115	41533	\N	55.025364000000003	Курганская область, Куртамышский район, Камышинский сельсовет, с.Камыши, Школьная, 8		0101000020E61000005C5A0D897B3A5040753FA7203F834B40
49721	6	55	1305	15089	41346	\N	54.789898000000001	Курганская область, Куртамышский район,Каминский сельсовет, с. Каминское, Мичурина, 8		0101000020E6100000516859F78F3D50408196AE601B654B40
49718	6	55	1305	54988	40970	\N	54.595934999999997	Курганская область, Куртамышский район, Камаганский сельсовет, с.Камаган, Торговый, 6		0101000020E6100000923CD7F7E111504058C51B99474C4B40
49714	6	55	1305	14762	41714	\N	54.832644999999999	Курганская область, Куртамышский район,Закоуловский сельсовет, с.Закоулово, Клубный, 6		0101000020E6100000770FD07D39395040C616821C946A4B40
49712	6	55	1305	14664	41713	\N	55.014429922411601	Курганская область, Куртамышский район, Закомалдинский сельсовет, с.Закомалдино, Центральная, 11	Россия, Курганская область, Куртамышский район, село Закомалдино	0101000020E610000076A6D0798D225040670A9DD7D8814B40
49710	6	55	1305	14547	41712	\N	54.9328504468631	Курганская область, Куртамышский район, Жуковский сельсовет, с.Жуково, Новая, 1	Россия, Курганская область, Куртамышский район, село Жуково	0101000020E6100000A6272CF1800F50406C09F9A067774B40
49707	6	55	1305	14418	40876	\N	54.973160276241003	Курганская область, Куртамышский район, Долговский сельсовет, с.Долговка, Октябрьская, 4Г	Россия, Курганская область, Куртамышский район, село Долговка	0101000020E610000044FD2E6CCD0950403FE3C281907C4B40
49746	6	55	1305	16272	41541	\N	54.554687000000001	Курганская область, Куртамышский район, Советский сельсовет, д.Добровольное, Центральная, 3А		0101000020E61000004A287D21E41A50401842CEFBFF464B40
49725	6	55	1305	15254	41164	\N	54.770957000000003	Курганская область, Куртамышский район, Костылевский сельсовет, д.Вехти, Центральная, 65А		0101000020E6100000865451BCCA165040A7CF0EB8AE624B40
49708	6	55	1305	55003	41075	\N	54.902338080710599	Курганская область, Куртамышский район, Верхневский сельсовет, с.Верхнее, Центральная, 22	Россия, Курганская область, Куртамышский район, село Верхнее	0101000020E61000001FA166481511504012F8C3CF7F734B40
49704	6	55	1305	14260	41344	\N	54.666826999999998	Курганская область, Куртамышский район,Большеберезовский сельсовет, с.Березово, Школьная, 5		0101000020E61000006C3F19E3C31D50407E8B4E965A554B40
49703	6	55	1305	14229	41283	\N	54.773912000000003	Курганская область, Куртамышский район, Белоноговский сельсовет, Белоногово, Центральная, 37А		0101000020E610000090DAC4C9FD095040B1FD648C0F634B40
49674	6	55	1181	12869	40447	\N	55.400030999999998	Курганская область, Кетовский район, с. Новая Сидоровка, Садовая, 3		0101000020E6100000F8FBC56CC94750406E313F3734B34B40
49646	6	55	1181	60764	\N	\N	55.365969999999997	Курганская область, Кетовский район, микрорайон КГСХА, здание ДК КГСХА		0101000020E6100000726A6798DA50504097A8DE1AD8AE4B40
49682	6	55	1181	54917	40459	\N	55.190261999999997	Курганская область, Кетовский район, с. Шмаково, Заречная, 7		0101000020E61000002009FB7612375040F5D555815A984B40
49663	6	55	1181	55021	41351	\N	55.497886755749001	Курганская область, Кетовский район, д. Шкодинское, Заречная, 8		0101000020E610000051DA1B7C615F5040410DDFC2BABF4B40
49686	6	55	1181	13407	40873	\N	55.298788999999999	Курганская область, Кетовский район, с. Чесноки, Дорожная, 3		0101000020E61000009B02999D45385040C8B3CBB73EA64B40
49679	6	55	1181	13099	41336	\N	55.65887	Курганская область, Кетовский район, п. Чашинский, Заречная, 34		0101000020E6100000CE6C57E8833D5040632827DA55D44B40
50378	6	55	1181	11712	\N	\N	55.274000000000001	"Курганская область, Кетовский район, п. УстьУтяк, Дом культуры Санаторий ""Лесники"""		0101000020E6100000425C397B67535040508D976E12A34B40
49649	6	55	1181	11712	\N	\N	55.274000000000001	Курганская область, Кетовский район, п. УстьУтяк, здание детского сада	Россия, Курганская область, Кетовский район, село Усть-Утяк	0101000020E6100000425C397B67535040508D976E12A34B40
49652	6	55	1181	11819	41333	\N	55.204622999999998	Курганская область, Кетовский район, с. Темляково, пер. Центральный, 9		0101000020E610000074417DCB9C4D504034812216319A4B40
49676	6	55	1181	12957	40966	\N	55.434201000000002	Курганская область, Кетовский район, с. Сычево, Труда, 6		0101000020E6100000BDFE243E773D5040FC71FBE593B74B40
49681	6	55	1181	54970	40793	\N	55.599559999999997	Курганская область, Кетовский район, п. Старый Просвет, Томина, 15		0101000020E61000005DA8FC6B79435040B0FECF61BECC4B40
49654	6	55	1181	11934	40789	\N	55.256431999999997	Курганская область, Кетовский район, д. Становая, Фрунзе, 1		0101000020E6100000B0C8AF1F625F5040EDD286C3D2A04B40
49660	6	55	1181	12218	40872	\N	55.300372000000003	Курганская область, Кетовский район, п. Светлые Поляны, 1 микрорайон, 15		0101000020E6100000B0389CF9D56450402B51F69672A64B40
49689	6	55	1181	55029	41482	\N	55.250719168378701	Курганская область, Кетовский район, с. Садовое, Ленина, 4Б		0101000020E61000004A404CC2854850402FBE688F17A04B40
49691	6	55	1181	13669	41710	\N	55.341735999999997	Курганская область, Кетовский район, д. Романовка, Центральная, 10		0101000020E61000007D073F7100435040D4EE5701BEAB4B40
49657	6	55	1181	12094	41708	\N	55.149783999999997	Курганская область, Кетовский район, с. Ровная, Центральная, 9		0101000020E61000007522C154335F504066BB421F2C934B40
49680	6	55	1181	54946	40672	\N	55.567686999999999	Курганская область, Кетовский район, с. Просвет, Южная, 14		0101000020E6100000DDB243FCC3445040A3AEB5F7A9C84B40
49645	6	55	1181	11480	41149	\N	55.374974000000002	Курганская область, Кетовский район, п. Придорожный, Центральная, 4		0101000020E610000050C422861D5A5040D76CE525FFAF4B40
49685	6	55	1181	13392	41343	\N	55.344833000000001	Курганская область, Кетовский район, с. Пименовка, переулок Школьный, 9		0101000020E6100000CEDF8442043B504071CADC7C23AC4B40
49665	6	55	1181	54969	40792	\N	55.592159000000002	Курганская область, Кетовский район, с. Падеринское, Центральная, 3		0101000020E610000048C2BE9D446650401B84B9DDCBCB4B40
49683	6	55	1181	13259	41709	\N	55.199660000000002	Курганская область, Кетовский район, д. Орловка, Сиреневая, 41		0101000020E6100000309FAC18AE335040E12879758E994B40
49692	6	55	1181	13686	41711	\N	55.275159021853199	Курганская область, Кетовский район, д. Новокомогоровка, Береговая, 20 кв.1	Россия, Курганская область, Кетовский район, село Новокомогоровка	0101000020E61000007407B133853E50409C19FD6838A34B40
49666	6	55	1181	12487	41156	\N	55.579500000000003	Курганская область, Кетовский район, д. Новое Лушниково, Центральная, 20		0101000020E61000007C2AA73D256950401904560E2DCA4B40
49656	6	55	1181	12004	41005	\N	55.193066999999999	Курганская область, Кетовский район, с. Митино, Советская, 15		0101000020E61000001B2FDD24065F5040EA77616BB6984B40
49687	6	55	1181	54960	40743	\N	55.20917	Курганская область, Кетовский район, с. Менщиково, В. Менщикова, 1А		0101000020E61000008483BD8921465040F4A62215C69A4B40
49655	6	55	1181	11989	40874	\N	55.273806	Курганская область, Кетовский район, с. Марково, Победы, 11А		0101000020E61000002B69C537146B50406BB933130CA34B40
49659	6	55	1181	12171	41151	\N	55.354895999999997	Курганская область, Кетовский район, д. Лукино, Приозерная, 85		0101000020E6100000C45BE7DF2E5D504098BD6C3B6DAD4B40
49690	6	55	1181	12789	41161	\N	55.432796000000003	Курганская область, Кетовский район, д. Логоушка, Интернатовская, 1		0101000020E6100000CB660E492D41504079EBFCDB65B74B40
49672	6	55	1181	12789	41526	\N	55.432796000000003	Курганская область, Кетовский район, д. Логоушка, Заречная, 1		0101000020E6100000CB660E492D41504079EBFCDB65B74B40
49677	6	55	1181	12973	41335	\N	55.411659	Курганская область, Кетовский район, п. Логовушка, Советская, 2		0101000020E6100000C05AB56B423A5040520DFB3DB1B44B40
49650	6	55	1181	54942	\N	\N	55.287424999999999	"Курганская область, Кетовский район, с. Лесниково, Лицей им. """"А.В. Тюнина"""""""		0101000020E61000002CF015DD7A545040C286A757CAA44B40
49648	6	55	1181	54942	40662	\N	55.287424999999999	Курганская область, Кетовский район, с. Лесниково, Кирова, 28		0101000020E61000002CF015DD7A545040C286A757CAA44B40
49675	6	55	1181	12902	41158	\N	55.366855000000001	Курганская область, Кетовский район, с. Кропани, переулок Школьный, 2		0101000020E6100000CAE2FE23D3475040E2AFC91AF5AE4B40
49661	6	55	1181	54937	40583	\N	55.481127999999998	Курганская область, Кетовский район, с. Колташево, Почтовая, 23		0101000020E6100000374F75C8CD6650404E98309A95BD4B40
49658	6	55	1181	12130	40791	\N	55.325097999999997	Курганская область, Кетовский район, с. Колесниково, Центральная, 10		0101000020E610000021037976F96150405CFFAECF9CA94B40
49642	6	55	1181	54915	40674	\N	55.345040896960903	Курганская область, Кетовский район, с. Кетово, Ленина, 131		0101000020E610000044DE72F563545040BB63B14D2AAC4B40
49641	6	55	1181	54915	40592	\N	55.340850000000003	Курганская область, Кетовский район, с. Кетово, Красина, 21		0101000020E61000005B272EC72B555040BA6B09F9A0AB4B40
49644	6	55	1181	54915	40454	\N	55.344385826730999	Курганская область, Кетовский район, с. Кетово, Космонавтов, 41		0101000020E610000010EB8D5A61555040A29927D714AC4B40
49640	6	55	1181	54915	40454	\N	55.345320996587702	Курганская область, Кетовский район, с. Кетово, Космонавтов, 43		0101000020E61000006A847EA65E5550409ECF807A33AC4B40
49653	6	55	1181	54916	40457	\N	55.278657000000003	Курганская область, Кетовский район, с. Каширино, Ленина, 23		0101000020E61000001ABFF04A9261504097E65608ABA34B40
49678	6	55	1181	54945	40664	\N	55.609014000000002	Курганская область, Кетовский район, с. Иковка, Миронова, 45		0101000020E61000007C26FBE7693C50403067B62BF4CD4B40
49664	6	55	1181	12425	41525	\N	55.455976208875697	Курганская область, Кетовский район, п. Залесовский, Лесная, 14		0101000020E6100000E6B2D1393F66504065E1EB6B5DBA4B40
49662	6	55	1181	12326	41152	\N	55.507182999999998	Курганская область, Кетовский район, д. Грачево, Озерная, 42		0101000020E61000008CA37213B56B5040280B5F5FEBC04B40
49688	6	55	1181	13531	41528	\N	55.193519999999999	Курганская область, Кетовский район, д. Галишово, Октябрьская, 142		0101000020E61000001689096AF83E50409B8F6B43C5984B40
49670	6	55	1181	54949	41495	\N	55.428252699543002	Курганская область, Кетовский район, с. Введенское, Пушкина, 11		0101000020E6100000CAE2FE23D3475040FAB48AFED0B64B40
49673	6	55	1181	54949	40680	\N	55.427995973418	Курганская область, Кетовский район, п. Введенское, Гоголя, 8Б		0101000020E61000000EA14ACD1E485040CF68AB92C8B64B40
49667	6	55	1181	54943	40663	\N	55.509821923766097	Курганская область, Кетовский район, с. Большое Чаусово, Пичугина, 3А	Россия, Курганская область, село Большое Чаусово, улица Пичугина, 3а	0101000020E6100000388600E0D85850400264E8D841C14B40
49684	6	55	1181	13335	41527	\N	55.231144	Курганская область, Кетовский район, с. Большое Раково, Луговая, 14		0101000020E6100000FDF84B8BFA2F504054556820969D4B40
49668	6	55	1181	12597	41332	\N	55.539645	Курганская область, Кетовский район, д. Белый Яр, Совхозная, 2		0101000020E6100000232F6B62815E504097395D1613C54B40
49651	6	55	1181	11800	40788	\N	55.244557	Курганская область, Кетовский район, с. Бараба, Боброва, 109		0101000020E6100000EAE923F0874F50400281CEA44D9F4B40
49752	6	55	1181	16592	\N	\N	55.279318000000004	"Курганская область, Кетовский район, п. Балки, ООО """"Кетовское предприятие по строительству, ремонту и содержанию автомобильных дорог"""		0101000020E6100000F3CCCB61F7545040929735B1C0A34B40
49618	6	55	1038	10239	\N	\N	56.057125999999997	Курганская область, Катайский район, Шутихинский сельсовет, село Шутихинское, Школа		0101000020E6100000033FAA61BF514F402AE09EE74F074C40
49607	6	55	1038	9677	\N	\N	56.408487999999998	Курганская область, Катайский район, Шутинский сельсовет, село Шутино, Здание школы	Россия, Курганская область, Катайский район, село Шутино	0101000020E6100000A8A624EB70624F407B67B45549344C40
49639	6	55	1038	11205	\N	\N	56.184489999999997	Курганская область, Катайский район, Верхнепесковский сельсовет, деревня Чусовая, медпункт		0101000020E6100000E36DA5D766454F4032384A5E9D174C40
49614	6	55	1038	9990	\N	\N	56.244414999999996	Курганская область, Катайский район, Ильинский сельсовет, деревня Черемисское, Здание Клуба	Россия, Курганская область, Катайский район, село Черемисское	0101000020E610000095F430B43A554F406FD39FFD481F4C40
49628	6	55	1038	10709	\N	\N	56.281010999999999	Курганская область, Катайский район, Ушаковский сельсовет, село Ушаковское, школа		0101000020E610000031B1F9B8363A4F407B681F2BF8234C40
49616	6	55	1038	10126	\N	\N	56.067615000000004	Курганская область, Катайский район, Улугушский сельсовет, село Улугушское, Здание администрации Улугушского сельсовета	Россия, Курганская область, Катайский район, село Улугушское	0101000020E61000004276DEC6662B4F400ADCBA9BA7084C40
49617	6	55	1038	10150	\N	\N	56.078617999999999	Курганская область, Катайский район, Петропавловский сельсовет, село Петропавловское, Школа		0101000020E610000007EC6AF294474F403F709527100A4C40
49629	6	55	1038	10782	\N	\N	56.287657000000003	Курганская область, Катайский район, Ушаковский сельсовет, деревня Оконечникова, клуб		0101000020E61000000937195586354F4095BBCFF1D1244C40
49626	6	55	1038	10609	\N	\N	56.279057000000002	Курганская область, Катайский район, Никитинский сельсовет, село Никитинское, Здание администрации сельсовета	Россия, Курганская область, Катайский район, село Никитинское	0101000020E61000004303B16CE6304F40255CC823B8234C40
49633	6	55	1038	10928	\N	\N	56.232568999999998	Курганская область, Катайский район, Зырянский сельсовет, деревня Марай, Дом культуры		0101000020E6100000499EEBFB701A4F401E882CD2C41D4C40
49608	6	55	1038	9696	\N	\N	56.429146000000003	Курганская область, Катайский район, Шутинский сельсовет, деревня Лукина, Здание клуба	Россия, Курганская область, Катайский район, село Лукина	0101000020E61000001AA6B6D4415C4F40C89A9141EE364C40
49624	6	55	1038	10526	\N	\N	55.862212	Курганская область, Катайский район, Лобановский сельсовет, село Лобаново, Школа		0101000020E6100000B114C95702374F40001C7BF65CEE4B40
49609	6	55	1038	9768	\N	\N	56.394948999999997	Курганская область, Катайский район, Корюковский сельсовет, село Корюково, здание школы	Россия, Курганская область, Катайский район, село Корюково	0101000020E610000008759142593E4F40404B57B08D324C40
49622	6	55	1038	10445	\N	\N	55.912355021204696	Курганская область, Катайский район, Верхнетеченский сельсовет, деревня Камышино, клуб	Россия, Курганская область, Катайский район, село Камышино	0101000020E6100000D9EA724A405E4F40C9AB730CC8F44B40
49620	6	55	1038	10306	\N	\N	55.933276999999997	Курганская область, Катайский район, Верхнетеченский сельсовет, деревня Казанцева, Здание клуба	Россия, Курганская область, Катайский район, село Казанцева	0101000020E61000002219726C3D494F40F38DE89E75F74B40
49627	6	55	1038	10674	\N	\N	56.294075999999997	Курганская область, Катайский район, Никитинский сельсовет, деревня Ипатова, клуб		0101000020E610000022C66B5ED52D4F40ED444948A4254C40
49613	6	55	1038	54955	\N	\N	56.267541999999999	Курганская область, Катайский район, Ильинский сельсовет, село Ильинское, Здание школы		0101000020E61000004641F0F8F64A4F403927F6D03E224C40
49631	6	55	1038	10861	\N	\N	56.217064999999998	Курганская область, Катайский район, Зырянский сельсовет, село Зырянка, школа		0101000020E6100000272EC72B10114F40990D32C9C81B4C40
49638	6	55	1038	11149	\N	\N	56.260083000000002	Курганская область, Катайский район, Ильинский сельсовет, поселок Заречье, Здание медпункта	Россия, Курганская область, Катайский район, село Заречье	0101000020E6100000D384ED2763504F406F9F55664A214C40
49612	6	55	1038	9919	\N	\N	56.274599000000002	Курганская область, Катайский район, Боровской сельсовет, деревня Гусиное, Здание детского сада	Россия, Курганская область, Катайский район, село Гусиное	0101000020E6100000C364AA60545C4F40D5415E0F26234C40
49621	6	55	1038	10366	\N	\N	55.910104124420599	Курганская область, Катайский район, Верхнетеченский сельсовет, село Верхняя Теча, средняя школа	Россия, Курганская область, Катайский район, село Верхняя Теча	0101000020E6100000E272BC02D14B4F40B9FAB1497EF44B40
49615	6	55	1038	10086	\N	\N	56.183318	Курганская область, Катайский район, Верхнепесковский сельсовет, село Верхние Пески, школа		0101000020E6100000871A8524B34C4F405262D7F676174C40
49634	6	55	1038	10992	\N	\N	56.258122999999998	Курганская область, Катайский район, Верхнеключевской сельсовет, село Верхнеключевское, школа		0101000020E61000008CD651D5041F4F4036ACA92C0A214C40
49619	6	55	1038	10276	\N	\N	55.976326999999998	Курганская область, Катайский район, Шутихинский сельсовет, деревня Бугаево, начальная школа		0101000020E61000008ECD8E54DF594F40D4997B48F8FC4B40
49610	6	55	1038	9829	\N	\N	56.267662000000001	Курганская область, Катайский район, Боровской сельсовет, село Боровское, Здание школы	Россия, Курганская область, Катайский район, село Боровское	0101000020E61000006A4E5E6402544F40E43098BF42224C40
49632	6	55	1038	10916	\N	\N	56.232669000000001	Курганская область, Катайский район, Зырянский сельсовет, деревня Борисова, Дом культуры		0101000020E6100000F4DDAD2CD1134F4082E50819C81D4C40
49630	6	55	1038	10792	\N	\N	56.150543999999996	Курганская область, Катайский район, Большекасаргульский сельсовет, село Большое Касаргульское, школа		0101000020E61000001F679AB0FD2A4F40F44D9A0645134C40
49625	6	55	1038	10596	\N	\N	55.807834999999997	Курганская область, Катайский район, Лобановский сельсовет, деревня Басказык, Здание библиотеки	Россия, Курганская область, Катайский район, село Басказык	0101000020E61000003F8C101E6D464F4036C8242367E74B40
49623	6	55	1038	10458	\N	\N	55.8921386679487	Курганская область, Катайский район, Верхнетеченский сельсовет, деревня Анчугово, медпункт	Россия, Курганская область, Катайский район, село Анчугово	0101000020E61000000A82C7B777494F403A3E5A9C31F24B40
49559	6	55	909	7440	41514	\N	55.995744999999999	Курганская область, Каргапольский район, Шахматова д, Горная ул, 25		0101000020E610000059C0046EDD215040E813799274FF4B40
49565	6	55	909	7679	41707	\N	56.035620440311199	Курганская область, Каргапольский район, Чемякина д, Центральная ул, 36	Россия, Курганская область, Каргапольский район, село Чемякина	0101000020E610000037DDB243FC305040B18A37328F044C40
49569	6	55	909	55033	41507	\N	55.898224999999996	Курганская область, Каргапольский район, с. Чаши, ул. Советская, 1		0101000020E61000007898F6CDFD3750408CB96B09F9F24B40
49586	6	55	909	54913	40450	\N	55.898369861933404	Курганская область, Каргапольский район, Чаши с, Советская ул, 18В	Россия, Курганская область, Каргапольский район, поселок сельского типа Чаши	0101000020E610000015AB06616E38504090DAC4C9FDF24B40
49585	6	55	909	8673	41331	\N	56.043838999999998	Курганская область, Каргапольский район, УстьМиасское с, Советская ул, 19		0101000020E610000010E84CDA541E504009A52F849C054C40
49564	6	55	909	7672	41143	\N	55.964765	Курганская область, Каргапольский район, Тукманное д, Центральная ул, 30		0101000020E6100000F7CABC55D72D5040A8A9656B7DFB4B40
49584	6	55	909	8634	41329	\N	55.744678	Курганская область, Каргапольский район, Твердыш п, Школьная ул, 1		0101000020E6100000FB761211FE1F50407D06D49B51DF4B40
49582	6	55	909	55012	41263	\N	55.924990316712197	Курганская область, Каргапольский район, Тагильское с, Октябрьская ул, 32Б	Россия, Курганская область, Каргапольский район, село Тагильская	0101000020E6100000EB3BBF28411B50404390831266F64B40
49581	6	55	909	8480	41690	\N	55.714418999999999	Курганская область, Каргапольский район, Сосновка с, Школьная ул, 1		0101000020E6100000BF81C98D222B50400D52F01472DB4B40
49580	6	55	909	8425	41327	\N	55.641030999999998	Курганская область, Каргапольский район, Соколово с, Советская ул, 15		0101000020E61000007EFCA5457D045040705CC64D0DD24B40
49579	6	55	909	8407	41326	\N	56.068393999999998	Курганская область, Каргапольский район, Северная д, ул. Молодежная, 3		0101000020E610000054C8957A164150400E9F7422C1084C40
49561	6	55	909	7541	41703	\N	55.780501999999998	Курганская область, Каргапольский район, Салтосарайская д, Дачная ул, 3		0101000020E610000048A98427F43E5040363B527DE7E34B40
49578	6	55	909	8333	41013	\N	56.032719999999998	Курганская область, Каргапольский район, Осиновское с, Советская ул, 1В		0101000020E61000007007EA94470650406AF6402B30044C40
49577	6	55	909	8276	40779	\N	55.740380000000002	Курганская область, Каргапольский район, Окуневское с, Школьная ул, 24		0101000020E6100000327216F6B40B5040664E97C5C4DE4B40
49576	6	55	909	8261	41325	\N	55.948331000000003	Курганская область, Каргапольский район, Новоиковское с, Центральная ул, 46		0101000020E6100000609335EA21375040396403E962F94B40
49593	6	55	909	9023	41334	\N	56.051651999999997	Курганская область, Каргапольский район, Нечунаева д, Исетская ул, 47		0101000020E6100000739CDB847B145040F16261889C064C40
49555	6	55	909	7255	40769	\N	56.121164999999998	Курганская область, Каргапольский район, Малышева с, Клубная ул, 22		0101000020E61000002046088F36265040BD35B055820F4C40
49574	6	55	909	8114	40776	\N	55.864747999999999	Курганская область, Каргапольский район, Майский п, Ленина ул, 3		0101000020E610000002D4D4B2B50B504005A4FD0FB0EE4B40
49573	6	55	909	54967	40775	\N	55.649966999999997	Курганская область, Каргапольский район, Красный Октябрь р.п, Чкалова ул, 23		0101000020E61000008FA67A32FF335040573D601E32D34B40
49570	6	55	909	54967	40861	\N	55.649966999999997	Курганская область, Каргапольский район, Красный Октябрь р.п, Ленина ул, 99		0101000020E61000008FA67A32FF335040573D601E32D34B40
49571	6	55	909	54967	40862	\N	55.649966999999997	Курганская область, Каргапольский район, Красный Октябрь р.п, Заводская ул, 2		0101000020E61000008FA67A32FF335040573D601E32D34B40
49572	6	55	909	54967	40958	\N	55.651156251061302	Курганская область, Каргапольский район, Красный Октябрь р.п, Гагарина ул, 1		0101000020E610000073D87DC7F03350400E4C6E1459D34B40
50376	6	55	909	14900	41540	\N	55.925348999999997	Курганская область, Каргапольский район, Ключи п, Зеленая ул, 3А		0101000020E610000024F1F274AE1C5040723106D671F64B40
50362	6	55	909	54968	41040	\N	55.954468693088998	Курганская область, Каргапольский район, Каргаполье р.п, Щорса ул, 3		0101000020E6100000D00A0C59DD1B5040DE054A0A2CFA4B40
49587	6	55	909	54968	40865	\N	55.948160000000001	Курганская область, Каргаполье р.п, Ленина ул, 14		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
50364	6	55	909	54968	41328	\N	55.948160000000001	Курганская область, Каргапольский район, Каргаполье р.п, Крупской ул, 91		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
49592	6	55	909	54968	41328	\N	55.948160000000001	Курганская область, Каргаполье р.п, Крупской ул, 67		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
49588	6	55	909	54968	40867	\N	55.948160000000001	Курганская область, Каргаполье р.п, Калинина ул, 25		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
49591	6	55	909	54968	40782	\N	55.948160000000001	Курганская область, Каргаполье р.п, Горького ул, 29А		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
50361	6	55	909	54968	40870	\N	55.948160000000001	Курганская область, Каргапольский район, Каргаполье р.п, Гагарина ул, 4		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
49590	6	55	909	54968	40870	\N	55.948160000000001	Курганская область, Каргаполье р.п, Гагарина ул, 5		0101000020E61000006F0C01C0B11B50400CB08F4E5DF94B40
49568	6	55	909	55053	41757	\N	55.775890121591999	Курганская область, Каргапольский район, Зауральское с, Вишневая ул, 3	Россия, Курганская область, Каргапольский район, село Зауральская	0101000020E61000006745D4449F0650408FA50F5D50E34B40
49566	6	55	909	7749	41705	\N	55.874789	Курганская область, Каргапольский район, Журавлево с, Лабарешных ул, 28		0101000020E61000004F2157EA5915504045F30016F9EF4B40
49562	6	55	909	7556	40857	\N	55.908394000000001	Курганская область, Каргапольский район, Житниковское с, Советская ул, 29А		0101000020E6100000E0F599B33E305040FAF02C4146F44B40
49563	6	55	909	7615	41506	\N	55.877384999999997	Курганская область, Каргапольский район, Жикина д, Лесная ул, 37		0101000020E61000007EFCA5457D2A50401F80D4264EF04B40
49560	6	55	909	54966	40773	\N	55.821254000000003	Курганская область, Каргапольский район, Долговское с, Победы ул, 130		0101000020E6100000575A46EA3D105040C7DADFD91EE94B40
49554	6	55	909	7175	41511	\N	55.766648000000004	Курганская область, Каргапольский район, Деулина д, Центральная ул, 15		0101000020E6100000232D95B7233950409CC58B8521E24B40
49583	6	55	909	55051	41755	\N	55.900911898920199	Курганская область, Каргапольский район, Дачный п, Советская ул, 8	Россия, Курганская область, Каргапольский район, село Дачный	0101000020E61000001557957D5718504077499C1551F34B40
49557	6	55	909	7331	41513	\N	55.979984000000002	Курганская область, Каргапольский район, Вяткино с, Комсомольская ул, 8А		0101000020E610000046B1DCD26A205040384D9F1D70FD4B40
49558	6	55	909	7409	41706	\N	55.962815999999997	Курганская область, Каргапольский район, Володина д, Механизаторов ул, 22А		0101000020E6100000122EE411DC1F50406308008E3DFB4B40
49556	6	55	909	7318	40771	\N	56.058252000000003	Курганская область, Каргапольский район, Брылино с, Советская ул, 2		0101000020E610000071CCB227813C50409B7631CD74074C40
49553	6	55	909	7155	41280	\N	55.739635	Курганская область, Каргапольский район, Большое Банниково с, Советская ул, 43		0101000020E6100000E77283A10E3750400DFD135CACDE4B40
49567	6	55	909	7805	41324	\N	55.838106022008802	Курганская область, Каргапольский район, Бакланское с, Центральная ул, 23	Россия, Курганская область, Каргапольский район, село Бакланское	0101000020E61000001F84807C091450406B4AB20E47EB4B40
49550	6	55	839	7006	41510	\N	54.395620000000001	Курганская область, Звериноголовский район, д. Украинец, Победы, 23		0101000020E6100000E63FA4DFBE3350405FD218ADA3324B40
49549	6	55	839	6947	41509	\N	54.466810000000002	Курганская область, Звериноголовский район, с. Труд и Знание, 40лет Победы, 1		0101000020E6100000E02F664B562F50400FB9196EC03B4B40
49548	6	55	839	6919	41515	\N	54.552781000000003	Курганская область, Звериноголовский район, д. Северный, Центральная, 5		0101000020E6100000F836FDD98F2C5040D36C1E87C1464B40
49547	6	55	839	6851	41500	\N	54.657578999999998	Курганская область, Звериноголовский район, д. Редуть, Школьная, 16		0101000020E610000090D8EE1EA03B5040A8C4758C2B544B40
49552	6	55	839	54965	40768	\N	54.374127999999999	Курганская область, Звериноголовский район, с. Прорывное, Ленина, 16		0101000020E6100000D9B3E732351950404A42226DE32F4B40
49545	6	55	839	6767	41141	\N	54.446151	Курганская область, Звериноголовский район, с. ОтрядАлабуга, Советская, 6		0101000020E6100000DF32A7CB62455040F209D9791B394B40
49546	6	55	839	6836	41321	\N	54.405054	Курганская область, Звериноголовский район, с. Озерное, Школьная, 32		0101000020E610000081423D7D04295040978E39CFD8334B40
49544	6	55	839	6728	41322	\N	54.560685999999997	Курганская область, Звериноголовский район, д. Лебедевка, Южная, 6		0101000020E6100000ED293927F63450409BA9108FC4474B40
49543	6	55	839	6661	40854	\N	54.500582999999999	Курганская область, Звериноголовский район, с. Круглое, Ленина, 2а		0101000020E61000001F69705B5B3950407FF78E1A13404B40
49541	6	55	839	6569	41483	\N	54.529584999999997	Курганская область, Звериноголовский район, с. Красногорка, Центральная, 17/2		0101000020E61000003161342BDB485040E0B9F770C9434B40
49542	6	55	839	6634	41127	\N	54.515355999999997	Курганская область, Звериноголовский район, д. Комсомольская, Школьная, 13		0101000020E610000096B377465B3D504010E6762FF7414B40
49551	6	55	839	7031	40951	\N	54.406993	Курганская область, Звериноголовский район, п. Искра, Школьная, 16		0101000020E6100000377007EA94235040B859BC5818344B40
49540	6	55	839	6546	41701	\N	54.357071586818599	Курганская область, Звериноголовский район, д. Зубаревка, Центральная, 22	Россия, Курганская область, Звериноголовский район, село Зубаревка	0101000020E61000003C670B08AD4B50409E280989B42D4B40
49538	6	55	839	54911	40574	\N	54.465119999999999	Курганская область, Звериноголовский район, с. Звериноголовское, Октябрьская, 26		0101000020E61000008177F2E9B1365040965B5A0D893B4B40
49537	6	55	839	54911	40444	\N	54.463417113853303	Курганская область, Звериноголовский район, с. Звериноголовское, Кравченко, 45		0101000020E610000013EF004F5A37504089B48D3F513B4B40
49539	6	55	839	54911	40952	\N	54.465119999999999	Курганская область, Звериноголовский район, с. Звериноголовское, Косаревой, 11а		0101000020E61000008177F2E9B1365040965B5A0D893B4B40
49536	6	55	839	6320	41704	\N	54.456097	Курганская область, Звериноголовский район, д. Жаворонки, Школьная, 2		0101000020E61000007B2FBE688F425040E066F162613A4B40
49535	6	55	839	6244	41702	\N	54.565179999999998	Курганская область, Звериноголовский район, д. Верхняя Алабуга, Школьная, 4		0101000020E6100000EDD808C4EB3B5040382D78D157484B40
49534	6	55	839	6200	41139	\N	54.621147000000001	Курганская область, Звериноголовский район, с. Бугровое, Школьная, 35		0101000020E6100000E6CFB7054B3650401781B1BE814F4B40
49528	6	55	580	5892	\N	\N	55.984239000000002	Курганская область, Далматовский район, с.Ясная Поляна, Помещение администрации Яснополянского сельсовета	Россия, Курганская область, Далматовский район, село Ясная Поляна	0101000020E61000006B2920ED7F624F405039268BFBFD4B40
49501	6	55	580	4434	\N	\N	56.461750000000002	Курганская область, Далматовский район, с.Язовка, Помещение сельского клуба	Россия, Курганская область, Далматовский район, село Язовка	0101000020E6100000925ED4EE57D14F40C976BE9F1A3B4C40
49525	6	55	580	5708	\N	\N	56.057448000000001	Курганская область, Далматовский район, с. Юровка, Помещение администрации Юровского сельсовета	Россия, Курганская область, Далматовский район, село Юровка	0101000020E6100000AF7B2B12137C4F403D9CC0745A074C40
49514	6	55	580	5161	\N	\N	56.348168000000001	Курганская область, Далматовский район, с.Широковское, Помещение сельского дома культуры	Россия, Курганская область, Далматовский район, село Широковское	0101000020E6100000D61EF64201874F40C2C1DEC4902C4C40
49509	6	55	580	4885	\N	\N	56.422156000000001	Курганская область, Далматовский район, с.Уральцевское, Помещение Уральцевской средней общеобразовательной школы	Россия, Курганская область, Далматовский район, село Уральцевское	0101000020E6100000E65C8AABCA8E4F40B4E7323509364C40
49526	6	55	580	54935	\N	\N	55.947177000000003	Курганская область, Далматовский район, с. Уксянское, Помещение администрации Уксянского сельсовета		0101000020E61000006B7D91D096814F40FF428F183DF94B40
49511	6	55	580	4973	\N	\N	56.473654000000003	Курганская область, Далматовский район, с.Тамакульское, Помещение администрации Тамакульского сельсовета	Россия, Курганская область, Далматовский район, село Тамакульское	0101000020E61000007AC37DE4D6864F404FCFBBB1A03C4C40
49507	6	55	580	4802	\N	\N	56.306043000000003	Курганская область, Далматовский район, с.Смирново, Помещение администрации Смирновского сельсовета	Россия, Курганская область, Далматовский район, село Смирново	0101000020E6100000C3A04CA3C9994F40BA15C26A2C274C40
49504	6	55	580	52135	\N	\N	56.541949788671602	Курганская область, Далматовский район, д.Сараткуль, Помещение сельского клуба	Россия, Курганская область, Далматовский район, село Сараткуль	0101000020E61000006D01A1F5F0BB4F409A081B9E5E454C40
49533	6	55	580	54964	\N	\N	55.911149000000002	Курганская область, Далматовский район, с.ПесчаноКоледино, Помещение сельского дома культуры		0101000020E61000005D5320B3B3684F403D64CA87A0F44B40
49523	6	55	580	5611	\N	\N	56.113481	Курганская область, Далматовский район, с.Пески, Помещение сельского дома культуры	Россия, Курганская область, Далматовский район, село Пески	0101000020E6100000990E9D9E77714F40D3DB9F8B860E4C40
49522	6	55	580	5585	\N	\N	56.105449999999998	Курганская область, Далматовский район, с.Першинское, Помещение Першинской начальной общеобразовательной школы	Россия, Курганская область, Далматовский район, село Першинское	0101000020E61000008578245E9E604F407DAEB6627F0D4C40
49503	6	55	580	4572	\N	\N	56.505003000000002	Курганская область, Далматовский район, с.Параткуль, Помещение администрации Параткульского сельсовета	Россия, Курганская область, Далматовский район, село Параткуль	0101000020E610000094F59B89E9C04F40E2B034F0A3404C40
49512	6	55	580	52153	\N	\N	56.536439999999999	Курганская область, Далматовский район, д.Падерино, Помещение ФАП	Россия, Курганская область, Далматовский район, село Падерино	0101000020E61000008B170B43E47E4F401422E010AA444C40
49530	6	55	580	5999	\N	\N	55.968221999999997	Курганская область, Далматовский район, с.Павелево, Помещение сельского дома культуры	Россия, Курганская область, Далматовский район, село Павелево	0101000020E61000006F9C14E63D9A4F4044A2D0B2EEFB4B40
49510	6	55	580	4954	\N	\N	56.520657999999997	Курганская область, Далматовский район, с.Новосельское, Помещение сельского клуба	Россия, Курганская область, Далматовский район, село Новосельское	0101000020E6100000C98E8D40BC9E4F404C33DDEBA4424C40
49531	6	55	580	54959	\N	\N	55.878970000000002	Курганская область, Далматовский район, с.Новопетропавловское, Помещение сельского дома культуры		0101000020E6100000C8D11C59F97D4F402315C61682F04B40
49508	6	55	580	4813	\N	\N	56.199547000000003	Курганская область, Далматовский район, с. Нижний Яр, Помещение Нижнеярской начальной общеобразовательной школы	Россия, Курганская область, Далматовский район, село Нижний Яр	0101000020E6100000B0928FDD058C4F40E9818FC18A194C40
49513	6	55	580	5074	\N	\N	56.395895000000003	Курганская область, Далматовский район, с.Мясниково, Помещение администрации Мясниковского сельсовета	Россия, Курганская область, Далматовский район, село Мясниково	0101000020E61000000536E7E099824F4031D3F6AFAC324C40
49524	6	55	580	5701	\N	\N	56.082717000000002	Курганская область, Далматовский район, с.Макарьевское, Помещение медицинского пункта	Россия, Курганская область, Далматовский район, село Макарьевское	0101000020E61000001A3048FAB47C4F4060E97C78960A4C40
49527	6	55	580	54977	\N	\N	55.943598000000001	Курганская область, Далматовский район, с.Любимово, Помещение сельского дома культуры		0101000020E61000001D3D7E6FD3874F401749BBD1C7F84B40
49532	6	55	580	6118	\N	\N	55.773043999999999	Курганская область, Далматовский район, с.Лебяжье, Помещение администрации Лебяжского сельского совета	Россия, Курганская область, Далматовский район, село Лебяжье	0101000020E6100000431B800D888A4F403C2F151BF3E24B40
49519	6	55	580	5415	\N	\N	56.166530999999999	Курганская область, Далматовский район, с.Крутиха, Помещение сельского дома культуры	Россия, Курганская область, Далматовский район, село Крутиха	0101000020E6100000359A5C8C81934F40956247E350154C40
49505	6	55	580	4665	\N	\N	56.348641999999998	Курганская область, Далматовский район, с.Кривское, Помещение сельского дома культуры	Россия, Курганская область, Далматовский район, село Кривское	0101000020E6100000051901158EAE4F408A01124DA02C4C40
49515	6	55	580	5172	\N	\N	56.372323000000002	Курганская область, Далматовский район, с.Крестовка, Помещение администрации Крестовского сельсовета	Россия, Курганская область, Далматовский район, село Крестовка	0101000020E6100000CC26C0B0FC6B4F403946B247A82F4C40
49518	6	55	580	5331	\N	\N	56.210382000000003	Курганская область, Далматовский район, с.Красноисетское, Помещение Красноисетской специальной коррекционной школыинт	Россия, Курганская область, Далматовский район, село Красноисетское	0101000020E6100000CFDBD8EC487F4F4063D520CCED1A4C40
49521	6	55	580	5500	\N	\N	56.179504999999999	Курганская область, Далматовский район, с.Ключевское, Помещение Ключевской основной общеобразовательной школы	Россия, Курганская область, Далматовский район, село Ключевское	0101000020E610000044F8174163644F40F73B1405FA164C40
49517	6	55	580	5317	\N	\N	56.227615	Курганская область, Далматовский район, с. Затеченское, Помещение администрации Затеченского сельсовета	Россия, Курганская область, Далматовский район, село Затеченское	0101000020E6100000B2F2CB608C764F401E8A027D221D4C40
49520	6	55	580	52170	\N	\N	56.141778000000002	Курганская область, Далматовский район, д.Загайнова, Помещение сельского дома культуры	Россия, Курганская область, Далматовский район, село Загайнова	0101000020E61000000A4D124BCA9D4F406AA510C825124C40
49500	6	55	580	4407	\N	\N	56.495310000000003	Курганская область, Далматовский район, с.Вознесенское, Помещение сельского клуба		0101000020E61000003E3F8C101EC94F40DEB06D51663F4C40
49516	6	55	580	5248	\N	\N	56.266576999999998	Курганская область, Далматовский район, с.Верхний Яр, Помещение Верхнеярской начальной общеобразовательной школы	Россия, Курганская область, Далматовский район, село Верхний Яр	0101000020E6100000A4E36A6457664F40D26EF4311F224C40
49497	6	55	580	4227	\N	\N	56.271729999999998	Курганская область, Далматовский район, д. Верхний Суварыш	Россия, Курганская область, Далматовский район, село Верхний Суварыш	0101000020E610000044F7AC6BB4864F40C9AB730CC8224C40
49502	6	55	580	52128	\N	\N	56.562192000000003	Курганская область, Далматовский район, д.Беляковка, Помещение сельского клуба	Россия, Курганская область, Далматовский район, село Беляковка	0101000020E6100000FD8348861CC54F4053094FE8F5474C40
49529	6	55	580	5936	\N	\N	55.979148000000002	Курганская область, Далматовский район, с.Белоярка1, Помещение администрации Белоярского сельсовета	Россия, Курганская область, Далматовский район, село Белоярка 1-я	0101000020E61000005C74B2D47A9D4F40CFF8BEB854FD4B40
49506	6	55	580	52141	\N	\N	56.427034999999997	Курганская область, Далматовский район, д.Белое, Помещение ФАП	Россия, Курганская область, Далматовский район, село Белое	0101000020E61000004CE0D6DD3CBB4F40A99F3715A9364C40
49482	6	55	229	3440	41478	\N	55.761243999999998	Курганская область, Варгашинский район, с.Яблочное, ул.Андреева, 19		0101000020E61000000C03965CC58A50405B23827170E14B40
3168	5	54	7205	52645	65285	\N	58.714565999999998	Парабель, Советская, 36, телефон: 21317		0101000020E61000008F54DFF945605440B16A10E6765B4D40
49462	6	55	229	2277	\N	\N	55.325006513891701	Курганская область, Варгашинский район, п.с.т.Юрахлы, в помещении табельной	Россия, Курганская область, Варгашинский район, село Юрахлы	0101000020E610000087C267EBE08750404CFC51D499A94B40
49485	6	55	229	3623	41323	\N	55.925581000000001	Курганская область, Варгашинский район, д.Шмаково, ул.Береговая, 65		0101000020E6100000A7E67283A17B504045662E7079F64B40
49484	6	55	229	3526	41683	\N	55.939912999999997	Курганская область, Варгашинский район, с.Шастово, ул.Центральная, 3		0101000020E61000004E7E8B4E96815040E90AB6114FF84B40
49483	6	55	229	3518	41315	\N	55.827185999999998	Курганская область, Варгашинский район, д.Урал, ул.Больничная, 2		0101000020E610000015747B49638B5040C2DA183BE1E94B40
49481	6	55	229	3412	41313	\N	55.922705999999998	Курганская область, Варгашинский район, с.Терпугово, ул.Молодежная, 17		0101000020E6100000D218ADA3AA91504057E9EE3A1BF64B40
49480	6	55	229	3322	41681	\N	55.405675000000002	Курганская область, Варгашинский район, с.Сычево, ул.Школьная, 2		0101000020E6100000F8A75489B269504004E78C28EDB34B40
49478	6	55	229	3208	41476	\N	55.166880999999997	Курганская область, Варгашинский район, с.Строево, ул.Центральная, 43		0101000020E6100000B0FECF61BE78504071A94A5B5C954B40
49477	6	55	229	3193	41475	\N	55.142195000000001	Курганская область, Варгашинский район, с.Спорное, ул.Садовая, 25		0101000020E61000009C340D8AE6735040CE531D7233924B40
49475	6	55	229	3063	41103	\N	55.416223000000002	Курганская область, Варгашинский район, с.Попово, ул.Пролетарская, 27 б		0101000020E610000042B115342D845040E86B96CB46B54B40
49473	6	55	229	2946	40849	\N	55.440911999999997	Курганская область, Варгашинский район, с.Пичугино, ул.Пионерская, 11		0101000020E610000068075C57CC735040FC34EECD6FB84B40
49472	6	55	229	2853	41474	\N	55.963943999999998	Курганская область, Варгашинский район, с.Ошурково, ул.Школьная, 2		0101000020E61000000CAEB9A3FF8A50407496598462FB4B40
49470	6	55	229	54995	41001	\N	55.732477270605202	Курганская область, Варгашинский район, с.Мостовское, ул.Гоголя, 5	Россия, Курганская область, Варгашинский район, поселок сельского типа Мостовское	0101000020E61000006F1283C0CA8850403E096CCEC1DD4B40
49469	6	55	229	54995	41470	\N	55.735044000000002	Курганская область, Варгашинский район, с.Мостовское, ул.Больничная, 2		0101000020E61000000B444FCAA48850407E8FFAEB15DE4B40
49468	6	55	229	2620	41473	\N	55.289659999999998	Курганская область, Варгашинский район, с.Медвежье, ул.Центральная, 12		0101000020E61000009CC3B5DAC37D5040CC7A319413A54B40
49467	6	55	229	2600	41099	\N	55.506948000000001	Курганская область, Варгашинский район, с.Лихачи, ул.Чапаева, 21		0101000020E61000005AF10D85CF7F5040E5620CACE3C04B40
49474	6	55	229	2968	41319	\N	55.393109000000003	Курганская область, Варгашинский район, д.Кабанье, ул.Озерная, 38 б		0101000020E6100000292499D53B785040B3614D6551B24B40
49471	6	55	229	2839	41679	\N	55.691250956845103	Курганская область, Варгашинский район, д.Заложное, ул.Центральная, 26	Россия, Курганская область, Варгашинский район, село Заложное	0101000020E6100000274D83A279855040E529ABE97AD84B40
49466	6	55	229	2510	41678	\N	55.079081000000002	Курганская область, Варагашинский район, с.Дундино, ул.Центральная, 2 а		0101000020E610000006F1811DFF7E5040145E82531F8A4B40
49465	6	55	229	2492	41317	\N	55.257590999999998	Курганская область, Варгашинский район, с.Дубровное, ул.Новая, 12 а		0101000020E61000002AABE97AA2775040395FECBDF8A04B40
49464	6	55	229	2403	41012	\N	55.900072000000002	Курганская область, Варгашинский район, с.Верхнесуерское, ул.Гагарина, 1 а		0101000020E6100000EDD5C743DF925040CD052E8F35F34B40
50283	6	55	229	54958	40759	\N	55.374313999999998	Курганская облпасть, Варгашинский район, р.п.Варгаши, ул.Социалистическая, 58		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49457	6	55	229	54958	40759	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Социалистическая, 92		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49456	6	55	229	54958	40759	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Социалистическая, 114		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49455	6	55	229	54958	40759	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Социалистическая, 200		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49458	6	55	229	54958	40842	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Осипенко, 29 а		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49459	6	55	229	54958	40765	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Механизаторов, 12		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49453	6	55	229	54958	40847	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Матросова, 50		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
50292	6	55	229	54958	41089	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Космонавтов, 1 а		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
50370	6	55	229	54958	40823	\N	55.374313999999998	"Курганская область, Варгашинский район, р.п.Варгаши, ул.Комсомольская, 36 (здание детского сада ""Ромашка) "		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
50371	6	55	229	54958	40740	\N	55.374313999999998	"Курганская область, Варгашинский район, р.п.Варгаши, ул.Кирова, 107 в (здание ПО ""Хлеб"")"		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49461	6	55	229	54958	40740	\N	55.374313999999998	Курганская область, Варгашинский район, р.п.Варгаши, ул.Кирова, 85 а		0101000020E6100000DE205A2BDA735040AC376A85E9AF4B40
49460	6	55	229	54958	40740	\N	55.371210058061202	Курганская область, Варгашинский район, р.п.Варгаши, ул.Кирова, 81		0101000020E61000003FABCC94D67350405DF92CCF83AF4B40
49416	6	55	229	32139	41700	\N	55.352514633607001	Курганская область, Варгашинский район, с.Варгаши, ул.Центральная, 75	Россия, Курганская область, Варгашинский район, село Варгаши	0101000020E6100000B4E386DF4D765040BA2C26361FAD4B40
3341	5	54	448	2811	74592	\N	56.641455999999998	Томская область, Томский район, с.Гынгазово, ул.Центральная 45		0101000020E6100000DBFAE93F6BE5544057E9EE3A1B524C40
49454	6	55	229	1797	40950	\N	55.375364644094297	Курганская область, Варгашинский район, р.п.Варгаши, ул.Комсомольская, 42	Россия, Курганская область, Варгашинский район, поселок городского типа Варгаши	0101000020E610000015E126A3CA7350401288D7F50BB04B40
49476	6	55	229	3072	41680	\N	55.936933000000003	Курганская область, Варгашинский район, с.Просеково, ул.Молодежная, 5		0101000020E6100000FB7953910A8D504087C5A86BEDF74B40
49438	6	55	229	890	41077	\N	55.884630000000001	Курганская область, Варгашинский район, д.Белово, ул.Школьная, 25		0101000020E61000007F6C921FF1945040BE874B8E3BF14B40
49404	6	55	229	31606	41282	\N	55.493920000000003	Курганская область, Варгашинский район, с.Барашково, ул.Школьная, 7		0101000020E6100000E6AE25E483715040906B43C538BF4B40
49452	6	55	92	1698	\N	\N	56.092711999999999	"""Курганская область, Белозерский район, Ягоднинский сельсовет, д. Ягодная, Здание МОУ """"Ягоднинской средней общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Ягодная	0101000020E6100000D2FBC6D79E4550402FF99FFCDD0B4C40
49448	6	55	92	1493	\N	\N	55.854298999999997	Курганская область, Белозерский район, Светлодольский сельсовет, д. Юрково, Здание Юрковского сельского клуба	Россия, Курганская область, Белозерский район, село Юрково	0101000020E61000005B09DD2571545040B4006DAB59ED4B40
49451	6	55	92	1684	\N	\N	56.093701000000003	Курганская область, Белозерский район, Ягоднинский сельсовет, с. Чимеево, Здание Чимеевского сельского дома культуры	Россия, Курганская область, Белозерский район, село Чимеево	0101000020E6100000793BC269C14850401F4DF564FE0B4C40
49434	6	55	92	55015	\N	\N	56.036308467586302	Курганская область, Белозерский район, Памятинский сельсовет, с. УстьСуерское, Здание бывшей УстьСуерской начальной школы	Россия, Курганская область, Белозерский район, село Усть-Суерское	0101000020E6100000E7C75F5AD4735040A54A94BDA5044C40
49436	6	55	92	769	\N	\N	56.098104999999997	Курганская область, Белозерский район, Першинский сельсовет, д. Тюменцева, Здание бывшего Тебенякского лесничества	Россия, Курганская область, Белозерский район, село Тюменцева	0101000020E61000003AE8120EBD5A50407B4963B48E0C4C40
49433	6	55	92	616	\N	\N	56.037785	Курганская область, Белозерский район, Памятинский сельсовет, д. Стенниково, Здание бывшей Стенниковской начальной школы	Россия, Курганская область, Белозерский район, село Стенниково	0101000020E6100000548D5E0D50645040C2A38D23D6044C40
49412	6	55	92	31965	\N	\N	56.222104999999999	"""Курганская область, Белозерский район, Боровлянский сельсовет, п. Стеклозавод, Здание МОУ """"Стеклозаводская средняя общеобразовная школа"""""""	Россия, Курганская область, Белозерский район, село Стеклозавод	0101000020E6100000E4C0ABE5CE5F504098A3C7EF6D1C4C40
49450	6	55	92	1612	\N	\N	55.865974999999999	"""Курганская область, Белозерский район, Скопинский сельсовет, с. Скопино, Здание МОУ """"Скопинской начальной общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Скопино	0101000020E6100000D53F8864C85A5040A913D044D8EE4B40
49449	6	55	92	1552	\N	\N	55.715986000000001	"""Курганская область, Белозерский район, Скатинский сельсовет,с. Скаты, Здание МОУ """"Скатинской основной общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Скаты	0101000020E61000002843554CA55350406A32E36DA5DB4B40
49447	6	55	92	1425	\N	\N	55.804592	"""Курганская область, Белозерский район, Светлодольский сельсовет, с. Светлый Дол, Здание МОУ """"Светлодольская средняя общеобразовная школа"""""""	Россия, Курганская область, Белозерский район, село Светлый Дол	0101000020E6100000B83EAC376A575040C64FE3DEFCE64B40
49443	6	55	92	1233	\N	\N	55.645994000000002	"""Курганская область, Белозерский район, Рычковский сельсовет, с. Рычково, Здание МОУ """"Рычковской основной общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Рычково	0101000020E610000044A852B307605040C4B46FEEAFD24B40
49430	6	55	92	390	\N	\N	55.928899999999999	"""Курганская область, Белозерский район, Новодостоваловский сельсовет, с. Романовское, Здание МОУ """" Романовская средняя общеобразовательная школа"""""""	Россия, Курганская область, Белозерский район, село Романовское	0101000020E6100000CADDE7F86876504090A0F831E6F64B40
49441	6	55	92	1087	\N	\N	55.961016999999998	Курганская область, Белозерский район, Речкинский сельсовет, с. Речкино, Здание бывшей Речкинской начальной школы	Россия, Курганская область, Белозерский район, село Речкино	0101000020E61000002D5A80B6D569504034F3E49A02FB4B40
49442	6	55	92	1154	\N	\N	55.617358000000003	Курганская область, Белозерский район, Рычковский сельсовет, д. Редькино, Здание Редькинской сельской библиотеки	Россия, Курганская область, Белозерский район, село Редькино	0101000020E61000002843554CA55E504045F6419605CF4B40
49439	6	55	92	979	\N	\N	55.850934000000002	Курганская область, Белозерский район, Пьянковский сельсовет, с. Пьянково, Здание Пьянковского сельского Дома культуры	Россия, Курганская область, Белозерский район, село Пьянково	0101000020E6100000E57B462234455040F986C267EBEC4B40
49426	6	55	92	123	\N	\N	55.805385999999999	Курганская область, Белозерский район, Нижнетобольный сельсовет, с. Полевое, Здание бывшего Полевского фельдшерскоакушерского пункта	Россия, Курганская область, Белозерский район, село Полевое	0101000020E61000009A05DA1D52595040005471E316E74B40
49418	6	55	92	32215	\N	\N	56.119523999999998	Курганская область, Белозерский район, Вагинский сельсовет, д. Подборная, Здание Подборновского сельского клуба		0101000020E6100000BAF770C971665040268BFB8F4C0F4C40
49429	6	55	92	376	\N	\N	55.929907999999998	Курганская область, Белозерский район, Новодостоваловский сельсовет, д. Петуховское, Здание бывшего Петуховского фельдшерскоакушерского пункта	Россия, Курганская область, Белозерский район, село Петуховское	0101000020E61000003FE603029D725040F624B03907F74B40
49435	6	55	92	752	\N	\N	56.086177999999997	"""Курганская область, Белозерский район, Першинский сельсовет, с. Першино, Здание МОУ """"Першинская средняя общеобразовательная школа"""""""	Россия, Курганская область, Белозерский район, село Першино	0101000020E6100000A9C1340C1F5950403DD175E1070B4C40
49432	6	55	92	560	\N	\N	56.009331000000003	"""Курганская область, Белозерский район, Памятинский сельсовет, с. Памятное, Здание МОУ """"Памятинской средней общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Памятное	0101000020E61000006092CA14736C504064EB19C231014C40
49446	6	55	92	1387	\N	\N	55.909624999999998	Курганская область, Белозерский район, Светлодольский сельсовет, д. Орловка, Здание Орловского сельского клуба	Россия, Курганская область, Белозерский район, село Орловка	0101000020E6100000E54350357A585040DF4F8D976EF44B40
49428	6	55	92	286	\N	\N	55.920098000000003	Курганская область, Белозерский район, Новодостоваловский сельсовет, с. Новодостовалово, Здание Администрации Новодостоваловского сельсовета	Россия, Курганская область, Белозерский район, село Новодостовалово	0101000020E6100000DBDC989EB0745040B98E71C5C5F54B40
49425	6	55	92	109	\N	\N	55.772405999999997	"""Курганская область, Белозерский район, Нижнетобольный сельсовет, с. Нижнетобольное, Здание МОУ """"Нижнетобольной основной общеобразовной школы"""""""	Россия, Курганская область, Белозерский район, село Нижнетобольное	0101000020E610000022C5008926675040F99D2633DEE24B40
49417	6	55	92	32163	\N	\N	56.113657000000003	"""Курганская область, Белозерский район, Вагинский сельсовет, д. Мясникова, Здание МОУ """"Мясниковская основная общеобразовательная школа"""""""	Россия, Курганская область, Белозерский район, село Мясникова	0101000020E6100000685BCD3AE36F504012FB04508C0E4C40
49445	6	55	92	1340	\N	\N	55.811781000000003	Курганская область, Белозерский район, Светлодольский сельсовет, д. Мендерское, Здание Мендерского сельского клуба	Россия, Курганская область, Белозерский район, село Мендерское	0101000020E6100000F9DB9E20B1525040D1419770E8E74B40
49415	6	55	92	32082	\N	\N	55.811073	Курганская область, Белозерский район, Боровской сельсовет, д. Масляная, Здание Маслянского сельского клуба	Россия, Курганская область, Белозерский район, село Масляная	0101000020E61000005F268A90BA6D504095D5743DD1E74B40
49437	6	55	92	879	\N	\N	55.854143000000001	Курганская область, Белозерский район, Пьянковский сельсовет, д. Малый Камаган, Здание Малокамаганского сельского клуба	Россия, Курганская область, Белозерский район, село Малый Камаган	0101000020E6100000AD6A494739485040BD8DCD8E54ED4B40
49424	6	55	92	32474	\N	\N	55.713791000000001	Курганская область, Белозерский район, Нижнетобольный сельсовет, д. Малый Заполой, Здание Малозаполойского фельдшерскоакушерского пункта	Россия, Курганская область, Белозерский район, село Малый Заполой	0101000020E6100000AEBCE47FF2625040EE96E4805DDB4B40
49421	6	55	92	61046	\N	\N	55.668289077986103	Курганская область, Белозерский район, Зюзинский сельсовет, д. Лихачевка, Здание бывшей Лихачихинской начальной школы	Россия, Курганская область, Белозерский район, село Лихачи	0101000020E6100000F7CDFDD5E367504066A3737E8AD54B40
49410	6	55	92	31882	\N	\N	55.894216999999998	"""Курганская область, Белозерский район, Белозерский сельсовет, д. Куликово, Здание МОУ """"Куликовская основная общеобразовательная школа"""""""	Россия, Курганская область, Белозерский район, село Куликово	0101000020E610000004C6FA06266850407C43E1B375F24B40
49409	6	55	92	31805	\N	\N	55.807395	"""Курганская область, Белозерский район, Белозерский сельсовет, д. Корюкина, Здание """"Профессиональное училище № 33"""""""	Россия, Курганская область, Белозерский район, село Корюкина	0101000020E6100000E0A128D0276550401AFA27B858E74B40
49444	6	55	92	1258	\N	\N	55.759157000000002	"""Курганская область, Белозерский район, Светлодольский сельсовет, д. Кирово, Здание бывшего ООО """"Агрофирма """"Светлый Дол"""""""	Россия, Курганская область, Белозерский район, село Кирово	0101000020E6100000EBAC16D863555040C6C37B0E2CE14B40
49420	6	55	92	32307	\N	\N	55.710569999999997	"""Курганская область, Белозерский район, Зюзинский сельсовет, с. Зюзино, Здание МОУ """"Зюзинской основной общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Зюзино	0101000020E6100000CD76853E586D504065C22FF5F3DA4B40
49440	6	55	92	1041	\N	\N	55.993192000000001	Курганская область, Белозерский район, Речкинский сельсовет, д. Екимово, Здание Екимовского сельского клуба	Россия, Курганская область, Белозерский район, село Екимово	0101000020E610000093196F2BBD6B50400D535BEA20FF4B40
3352	5	54	448	47969	74737	\N	56.883901999999999	с. Гусево, ул. Гагарина, 10а, телефон: 46-145		0101000020E6100000D47C957CEC0055403B6F63B323714C40
49408	6	55	92	55005	\N	\N	55.912439999999997	Курганская область, Белозерский район, Белозерский сельсовет, д. Доможирово, Здание Доможировского сельского клуба	Россия, Курганская область, Белозерский район, село Доможирова	0101000020E61000008F183DB7D05E5040F7C77BD5CAF44B40
49431	6	55	92	509	\N	\N	56.025526999999997	Курганская область, Белозерский район, Памятинский сельсовет, д. Волосникова, Здание Волосниковского сельского клуба	Россия, Курганская область, Белозерский район, село Волосникова	0101000020E6100000FCFECD8B136F50401E15FF7744034C40
49414	6	55	92	32054	\N	\N	55.800300999999997	"""Курганская область, Белозерский район, Боровской сельсовет, с. Боровское, Здание МОУ """"Боровская средняя общеобразовательная школа"""""""	Россия, Курганская область, Белозерский район, село Боровское	0101000020E610000014048F6FEF6F504061FA5E4370E64B40
49411	6	55	92	31904	\N	\N	56.242699000000002	Курганская область, Белозерский район, Боровлянский сельсовет, с. Боровлянка, Здание Администрации Боровлянского сельсовета	Россия, Курганская область, Белозерский район, село Боровлянка	0101000020E6100000DA56B3CEF85D5040CEE2C5C2101F4C40
49422	6	55	92	32393	\N	\N	55.918483999999999	"""Курганская область, Белозерский район, Камаганский сельсовет, с. Большой Камаган, Здание МОУ""""Камаганская начальная общеобразовательная школа"""""""	Россия, Курганская область, Белозерский район, село Большой Камаган	0101000020E6100000008DD2A57F4550401BF33AE290F54B40
49419	6	55	92	32253	\N	\N	55.896054999999997	"""Курганская область, Белозерский район, Зарослинский сельсовет, д. Большое Зарослое, Здание МОУ""""Зарослинской основной общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Большое Зарослое	0101000020E61000001C295B24ED505040693524EEB1F24B40
49413	6	55	92	31991	\N	\N	55.790073999999997	Курганская область, Белозерский район, Боровской сельсовет, п. Березовский, Здание Березовской сельской библиотеки	Россия, Курганская область, Белозерский район, село Березовский	0101000020E6100000BDE3141DC97B5040BFB5132521E54B40
49403	6	55	92	31564	\N	\N	56.029862999999999	Курганская область, Белозерский район, Баяракский сельсовет, д. Березово, Здание Березовского сельского клуба	Россия, Курганская область, Белозерский район, село Березово	0101000020E6100000CC423BA7595E5040232E008DD2034C40
49406	6	55	92	54912	40446	\N	55.823476147305897	Курганская область, Белозерский район, Белозерский сельсовет, с. Белозерское, Советская, 30	Россия, Курганская область, Белозерский район, поселок сельского типа Белозерское	0101000020E6100000DE585018946550403C855CA967E94B40
49407	6	55	92	54934	40572	\N	55.8240801107343	Курганская область, Белозерский район, Белозерский сельсовет, с. Белозерское, Карла Маркса, 36	Россия, Курганская область, Белозерский район, поселок сельского типа Белозерское	0101000020E6100000299485AFAF655040D3A414747BE94B40
49405	6	55	92	54934	40572	\N	55.828020000000002	Курганская область, Белозерский район, Белозерский сельсовет, с. Белозерское, Карла Маркса, 6		0101000020E6100000BC92E4B9BE6450408B37328FFCE94B40
49402	6	55	92	31477	\N	\N	55.955039999999997	"""Курганская область, Белозерский район, Баяракский сельсовет, с. Баярак, Здание МОУ """"Баяракской основной общеобразовательной школы"""""""	Россия, Курганская область, Белозерский район, село Баярак	0101000020E61000008CBAD6DEA75A5040982F2FC03EFA4B40
49423	6	55	92	32422	\N	\N	55.750129999999999	Курганская область, Белозерский район, Нижнетобольный сельсовет, д. Ачикуль, Здание Ачикульского фельдшерскоакушерского пункта	Россия, Курганская область, Белозерский район, село Ачикуль	0101000020E6100000C05E61C1FD5E5040CEDF844204E04B40
49399	6	55	1880	31353	41091	\N	54.855657000000001	Курганская область, Альменевский район, Ягоднинский сельсовет, село Ягодное, Центральная.12		0101000020E61000002C7E5358A9D64F40F7CB272B866D4B40
49396	6	55	1880	31175	41682	\N	54.799551999999998	Курганская область, Альменевский район, Юламановский сельсовет, с. Юламаново, Шахты, 11		0101000020E61000006116DA39CD7A4F40C7B94DB857664B40
49376	6	55	1880	30211	41656	\N	54.982622912345803	Курганская область, Альменевский район, Бороздинский сельсовет, д. Щучанка, Школьная, 18	Россия, Курганская область, Альменевский район, село Щучанка	0101000020E6100000DB3521AD316E4F4011A62897C67D4B40
49395	6	55	1880	31167	41114	\N	54.845497999999999	Курганская область, Альменевский район, Шариповский сельсовет, д. Шарипово, Школьная, 4		0101000020E61000005BD2510E66BB4F40AD6A4947396C4B40
49390	6	55	1880	30917	41279	\N	54.881312999999999	Курганская область, Альменевский район, Чистовский сельсовет, с.Чистое, Школьная, 2		0101000020E61000006C0723F609EE4F40134548DDCE704B40
49382	6	55	1880	30485	41471	\N	55.034666999999999	Курганская область, Альменевский район, Малышевский сельсовет, д. Учкулево, Центральная, 31		0101000020E6100000BA68C87894AA4F400EA0DFF76F844B40
49384	6	55	1880	55014	41288	\N	54.734772999999997	Курганская область, Альменевский район, Парамоновский сельсовет, д. Убалино, Аминева, 27	Россия, Курганская область, Альменевский район, село Убалина	0101000020E61000004AB54FC763C24F40ED7DAA0A0D5E4B40
49386	6	55	1880	30701	41497	\N	54.905901999999998	Курганская область, Альменевский район, Танрыкуловский сельсовет, с.Танрыкулово, Советская, 12		0101000020E6100000B1170AD80E944F40C4B0C398F4734B40
3351	5	54	448	47969	74737	\N	56.883901999999999	с. Гусево, ул. Гагарина, 7, телефон: 46-137		0101000020E6100000D47C957CEC0055403B6F63B323714C40
49401	6	55	1880	31465	41462	\N	54.958694000000001	Курганская область, Альменевский район, Ягоднинский сельсовет, д. Солнечная, Центральная, 10		0101000020E6100000072461DF4ED84F408B6F287CB67A4B40
49385	6	55	1880	30627	41278	\N	54.943742	Курганская область, Альменевский район, Рыбновский сельсовет, с. Рыбное, Школьная, 13		0101000020E61000005D6DC5FEB2F54F404AEEB089CC784B40
49394	6	55	1880	31089	41685	\N	54.74192	Курганская область, Альменевский район, Шариповский сельсовет, д. Поляна, Школьная, 2		0101000020E6100000F6D1A92B9F954F40C91F0C3CF75E4B40
49387	6	55	1880	30770	41117	\N	54.860709999999997	Курганская область, Альменевский район, Танрыкуловский сельсовет, д.Подъясово, Школьная, 14		0101000020E610000017A06D35EB804F408AABCABE2B6E4B40
49383	6	55	1880	30554	41277	\N	54.806770999999998	Курганская область, Альменевский район, Парамоновский сельсовет, с. Парамоново, Советская, 25		0101000020E6100000444C89247AC54F403C2EAA4544674B40
49392	6	55	1880	54984	40930	\N	54.813853000000002	Курганская область, Альменевский район, Шариповский сельсовет, село Мир, Советская, 19		0101000020E6100000DAAD65321CBB4F403160C9552C684B40
49380	6	55	1880	55008	41200	\N	54.929879675771502	Курганская область, Альменевский район, Малышевский сельсовет, село Малышево, Центральная, 11	Россия, Курганская область, Альменевский район, село Малышева	0101000020E6100000520ABABDA4B54F402C9ACE4E06774B40
49374	6	55	1880	30073	41688	\N	54.994382999999999	Курганская область, Альменевский район, Бороздинский сельсовет, д, Майлык, Майлыкская, 15		0101000020E61000002D228AC91B844F40645930F1477F4B40
49388	6	55	1880	30777	41097	\N	54.834116999999999	Курганская область, Альменевский район, Танрыкуловский сельсовет, д.Крутой Лог, Почтовая, 2		0101000020E6100000844A5CC7B8984F40D1048A58C46A4B40
49379	6	55	1880	30342	41011	\N	54.800601	Курганская область, Альменевский район, Казенский сельсовет, село Казенное, Центральная, 21		0101000020E610000085436FF1F09E4F408C12F4177A664B40
49389	6	55	1880	30875	41677	\N	54.912992000000003	Курганская область, Альменевский район, Танрыкуловский сельсовет, д.Казакулово, Малая, 1		0101000020E6100000F1D7648D7A9A4F403CC1FEEBDC744B40
49375	6	55	1880	30153	41469	\N	54.961238000000002	Курганская область, Альменевский район, Бороздинский сельсовет, д. Искандарово, Кирпичная, 1		0101000020E610000062DC0DA2B5804F4013D6C6D8097B4B40
49378	6	55	1880	30227	76546	\N	55.040548724277798	Курганская область, Альменевский район, Иванковский сельсовет, пер. Советский, 1а	Россия, Курганская область, Альменевский район, село Иванково	0101000020E6100000D63BDC0E0DB74F405871AAB530854B40
49377	6	55	1880	30227	41655	\N	55.040157000000001	Курганская область, Альменевский район, Иванковский сельсовет, с. Иванково, Российская, 7		0101000020E61000003B53E8BCC6B64F404DDA54DD23854B40
49400	6	55	1880	31373	41676	\N	54.764184	Курганская область, Альменевский район, Ягоднинский сельсовет, д. Вишняково, Центральная, 46		0101000020E6100000E5D2F88557E64F40301004C8D0614B40
49398	6	55	1880	31263	41092	\N	54.775350000000003	Курганская область, Альменевский район, Юламановский сельсовет, д. Бухарово, Береговая (здание сельского клуба), 18		0101000020E61000001FF30181CE784F40107A36AB3E634B40
49373	6	55	1880	30066	41653	\N	54.9022066052773	Курганская область, Альменевский район, Бороздинский сельсовет, село Бороздинка, Школьная, 2	Россия, Курганская область, Альменевский район, село Бороздинка	0101000020E6100000C896E5EB32764F40739CDB847B734B40
49393	6	55	1880	31070	41499	\N	54.719461000000003	Курганская область, Альменевский район, Шариповский сельсовет, д. Байганино, Комсомольская, 14		0101000020E6100000C66B5ED559B34F40ADDF4C4C175C4B40
49397	6	55	1880	31255	41613	\N	54.736800000000002	Курганская область, Альменевский район, Юламановский сельсовет, д. Аскарово, Молодёжная, 22		0101000020E6100000E49EAEEE586A4F40AED85F764F5E4B40
49370	6	55	1880	54927	40514	\N	54.945473999999997	Курганская область, Альменевский район, Альменевский сельсовет, село Альменево, Комсомола, 2		0101000020E61000000E677E3507CA4F40F19BC24A05794B40
49372	6	55	1880	54927	40753	\N	54.945473999999997	Курганская область, Альменевский район, Альменевский сельсовет, село Альменево, В.И.Ленина, 103		0101000020E61000000E677E3507CA4F40F19BC24A05794B40
49371	6	55	1880	54927	40706	\N	54.945473999999997	Курганская область, Альменевский район, Альменевский сельсовет, село Альменево, улица 8 Марта, 2		0101000020E61000000E677E3507CA4F40F19BC24A05794B40
49381	6	55	1880	30452	41662	\N	54.931158461671899	Курганская область, Альменевский район, Малышевский сельсовет, д. Алакуль, Озерная, 1	Россия, Курганская область, Альменевский район, село Алакуль	0101000020E6100000C345EEE9EAA84F4053B4722F30774B40
2765	5	54	\N	155	\N	\N	56.579906000000001	Томская область, город Томск, Светлый пос, 33, телефон: 98-11-42, 98-26-00		0101000020E61000006FBBD05CA746554089601C5C3A4A4C40
2764	5	54	\N	155	\N	\N	56.580760320592397	Томская область, город Томск, Светлый пос, 33, телефон: 98-26-00, 98-11-42		0101000020E61000004835ECF7C44655409869FB57564A4C40
2763	5	54	\N	155	\N	\N	56.579906000000001	"Томская область, Муниципальное образование ""Город Томск"", Светлый пос, 33, телефон: 98-32-78, 98-11-77"		0101000020E61000006FBBD05CA746554089601C5C3A4A4C40
2751	5	54	\N	155	\N	\N	56.5803339986144	Томская область, город Томск, Светлый пос, 33, телефон: 98-11-77, 98-32-78		0101000020E61000005B3FFD67CD465540E1606F62484A4C40
3060	5	54	\N	155	29909	\N	56.495623000000002	Каргасокское сельское поселение, Энтузиастов, 2, телефон: 2-14-51	Россия, Томская область, Томск, улица Энтузиастов, 2	0101000020E61000002522FC8BA04455409D121093703F4C40
2638	5	54	\N	155	28962	\N	56.477020000000003	"Томская область, Муниципальное образование ""Город Томск"", Салтыкова-Щедрина улица, 35, телефон: 243196"	Россия, Томская область, Томск, улица Салтыкова-Щедрина, 35	0101000020E61000009CC1DF2F66405540DBC4C9FD0E3D4C40
2800	5	54	\N	155	28741	\N	56.500686000000002	"Томская область, Муниципальное образование ""Город Томск"", Розы Люксембург, 64, телефон: 51-68-71, 40-65-32"	Россия, Томская область, Томск, улица Розы Люксембург, 64	0101000020E610000092EBA694D73C554054C8957A16404C40
2642	5	54	\N	155	28966	\N	56.479326999999998	"Томская область, Муниципальное образование ""Город Томск"", Лебедева улица, 102, телефон: 450826"	Россия, Томская область, Томск, улица Лебедева, 102	0101000020E610000089230F44164055407E8B4E965A3D4C40
2662	5	54	\N	155	28986	\N	56.481831999999997	"Томская область, Муниципальное образование ""Город Томск"", Крылова улица, 12, телефон: 530627"	Россия, Томская область, Томск, улица Крылова, 12/1	0101000020E61000005516855D143D55404815C5ABAC3D4C40
2806	5	54	\N	155	28747	\N	56.494833	"Томская область, Муниципальное образование ""Город Томск"", Карла Маркса, 31, телефон: 51-46-25"	Россия, Томская область, Томск, улица Карла Маркса, 31	0101000020E61000000F289B72853C5540A4FD0FB0563F4C40
2782	5	54	\N	155	28718	\N	56.514310999999999	"Томская область, Муниципальное образование ""Город Томск"", Интернационалистов, 12, телефон: 72-73-80, 72-73-19"	Россия, Томская область, Томск, улица Интернационалистов, 12	0101000020E6100000E9EE3A1BF23E55408D7C5EF1D4414C40
95187	5	54	\N	155	28960	\N	56.476273999999997	г.Томск, пр.Фрунзе,  152	Россия, Томская область, Томск, проспект Фрунзе, 158	0101000020E6100000E7FF55478E3F5540B1F7E28BF63C4C40
2664	5	54	\N	155	28960	\N	56.476273999999997	"Томская область, Муниципальное образование ""Город Томск"", Фрунзе проспект, 152, телефон: 440023"	Россия, Томская область, Томск, проспект Фрунзе, 158	0101000020E6100000E7FF55478E3F5540B1F7E28BF63C4C40
2636	5	54	\N	155	28960	\N	56.473381000000003	"Томская область, Муниципальное образование ""Город Томск"", Фрунзе проспект, 135, телефон: 242766"	Россия, Томская область, Томск, проспект Фрунзе, 135	0101000020E61000004DA1F31ABB4055401EC6A4BF973C4C40
3108	5	54	\N	155	28742	\N	56.467533000000003	"Томская область, Муниципальное образование ""Кривошеинский район"", Кривошеинское сельское поселение, Ленина, 34, телефон: 21773"	Россия, Томская область, Томск, проспект Ленина, 34	0101000020E610000060C8EA56CF3C55408066101FD83B4C40
2987	5	54	\N	155	28742	\N	56.478188000000003	Томская область, Бакчарский район, ул.Ленина 54	Россия, Томская область, Томск, проспект Ленина, 54	0101000020E61000009CC3B5DAC33C55407AABAE43353D4C40
2813	5	54	\N	155	28742	\N	56.472889000000002	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Ленина, 38, телефон: 54-71-10"	Россия, Томская область, Томск, проспект Ленина, 38	0101000020E6100000C9772975C93C5540AFD172A0873C4C40
2805	5	54	\N	155	28742	\N	56.501967999999998	"Томская область, Муниципальное образование ""Город Томск"", проспект Ленина, 181, телефон: 40-74-22, 40-75-36, 40-72-63, 40-74-55"	Россия, Томская область, Томск, проспект Ленина, 181	0101000020E6100000C4EBFA05BB3C5540BBD1C77C40404C40
2801	5	54	\N	155	28742	\N	56.509270000000001	"Томская область, Муниципальное образование ""Город Томск"", проспект Ленина, 211, телефон: 40-28-66"	Россия, Томская область, Томск, проспект Ленина, 211	0101000020E610000006D50627A23C5540BE6A65C22F414C40
2707	5	54	\N	155	65464	\N	56.4609283710233	Томская область, город Томск, деревня Лоскутово, Ленина улица, 27А, телефон: 943-562	Россия, Томская область, Томск, проспект Ленина, 27	0101000020E61000003BC43F6CE93C5540C5E74EB0FF3A4C40
2705	5	54	\N	155	28785	\N	56.466714911222198	Томская область, город Томск, Кирова проспект, 56А, телефон: 55-95-42	Россия, Томская область, Томск, проспект Кирова	0101000020E610000015E5D2F8853E5540BDC62E51BD3B4C40
2669	5	54	\N	155	28785	\N	56.467019656342202	Томская область, город Томск, Кирова проспект, 12, телефон: 56-31-72	Россия, Томская область, Томск, проспект Кирова, 12	0101000020E610000077BE9F1A2F3D5540F949B54FC73B4C40
2650	5	54	\N	155	28785	\N	56.464171999999998	"Томская область, Муниципальное образование ""Город Томск"", Кирова проспект, 60/1, телефон: 480965"	Россия, Томская область, Томск, проспект Кирова, 60/7	0101000020E6100000810A47904A3F554005DCF3FC693B4C40
2659	5	54	\N	155	28983	\N	56.480271000000002	"Томская область, Муниципальное образование ""Город Томск"", Юрточный переулок, 8А, телефон: 533224"	Россия, Томская область, Томск, Юрточный переулок, 8а	0101000020E61000008AC8B08A373D5540CE1B2785793D4C40
2690	5	54	\N	155	74634	\N	56.525014365277102	Томская область, город Томск, деревня Эушта, Школьная улица, 3, телефон: 25-69-19		0101000020E61000005798BED71039554098F8A3A833434C40
2688	5	54	\N	155	66465	\N	56.496501686177602	Томская область, город Томск, село Тимирязевское, Школьная улица, 18, телефон: 911-012, 912-237	Россия, Томская область, Томск, село Тимирязевское	0101000020E61000003049658A393855400533A6608D3F4C40
2687	5	54	\N	155	74319	\N	56.478361962799298	Томская область, город Томск, село Тимирязевское, Школьная улица, 18, телефон: 911-278, 911-342		0101000020E610000041D653ABAF38554017D34CF73A3D4C40
2794	5	54	\N	155	28730	\N	56.524490999999998	"Томская область, Муниципальное образование ""Город Томск"", пер.Шегарский, 85, телефон: 46-34-20, 46-29-48"	Россия, Томская область, Томск, Шегарский переулок, 85	0101000020E610000065AA6054523D5540EE05668522434C40
2644	5	54	\N	155	74368	\N	56.484957999999999	"Томская область, Муниципальное образование ""Город Томск"", Челюскинцев улица, 20, телефон: 440217"		0101000020E6100000DA756F45623F55407FF78E1A133E4C40
2749	5	54	\N	155	65356	\N	56.527616561271898	"Томская область, город Томск, Центральная улица, 4а, телефон: 72-67-95, 72-67-84"	Россия, Томская область, Томск, Центральная улица, 4а	0101000020E61000004B04AA7F1042554025E82FF488434C40
2747	5	54	\N	155	65356	\N	56.527248932989004	Томская область, город Томск, Центральная улица, 4а, телефон: 72-67-95, 72-67-84	Россия, Томская область, Томск, Центральная улица, 4а	0101000020E6100000369204E10A425540A2EC2DE57C434C40
2746	5	54	\N	155	65356	\N	56.527628420189103	"Томская область, город Томск, Центральная улица, 4а, телефон: 72-67-84, 72-67-95"	Россия, Томская область, Томск, Центральная улица, 4а	0101000020E61000003F56F0DB10425540193A765089434C40
2692	5	54	\N	155	9839	\N	56.508828747190101	г.Томск, ул.Хмельницкого, 40	Россия, Томская область, Томск	0101000020E6100000F7AFAC3429415540D120054F21414C40
2779	5	54	\N	155	74377	\N	56.518676999999997	"Томская область, Муниципальное образование ""Город Томск"", Ференца Мюнниха, 12/1, телефон: 76-28-51"		0101000020E61000004A7B832F4C3F5540FC17080264424C40
2796	5	54	\N	155	28733	\N	56.516477000000002	"Томская область, Муниципальное образование ""Город Томск"", Ферганская, 25, телефон: 63-15-22, 63-15-24"	Россия, Томская область, Томск, Ферганская улица, 25	0101000020E61000006116DA39CD3D55406F1118EB1B424C40
2797	5	54	\N	155	74356	\N	56.516477000000002	"Томская область, Муниципальное образование ""Город Томск"", Ферганская, 25, телефон: 63-15-22,63-15-24"		0101000020E61000006116DA39CD3D55406F1118EB1B424C40
2682	5	54	\N	155	65322	\N	56.451359130063402	Томская область, город Томск, Фёдора Лыткина улица, 18, телефон: 41-26-54	Россия, Томская область, Томск, улица Федора Лыткина, 18	0101000020E610000003232F6B623E5540ACE0B721C6394C40
2681	5	54	\N	155	65322	\N	56.451414738177498	Томская область, город Томск, Фёдора Лыткина улица, 14, телефон: 41-48-63	Россия, Томская область, Томск, улица Федора Лыткина, 14	0101000020E6100000124A5F08393E554040F67AF7C7394C40
2680	5	54	\N	155	65322	\N	56.452398589091501	Томская область, город Томск, Фёдора Лыткина улица, 12, телефон: 41-27-20	Россия, Томская область, Томск, улица Федора Лыткина, 12	0101000020E6100000906B43C5383E55401EDFDE35E8394C40
2689	5	54	\N	155	74292	\N	56.517718809997199	Томская область, город Томск, село Дзержинское, Фабричная улица, 11, телефон: 914-014	Россия, Томская область, Томск, село Дзержинское	0101000020E61000000118CFA0A135554048C2BE9D44424C40
2678	5	54	\N	155	65298	\N	56.458316193867098	Томская область, город Томск, Учебная улица, 41, телефон: 55-60-26	Россия, Томская область, Томск, Учебная улица, 41	0101000020E6100000EC504D49D63D5540E59D4319AA3A4C40
2674	5	54	\N	155	65298	\N	56.458582858792099	Томская область, город Томск, Учебная улица, 37, телефон: 48-53-98		0101000020E6100000C0CE4D9B713D554033C005D9B23A4C40
2703	5	54	\N	155	65344	\N	56.464125499386199	Томская область, город Томск, Усова улица, 56, телефон: 55-35-57		0101000020E6100000A4A65D4C333E5540C520B072683B4C40
2699	5	54	\N	155	65344	\N	56.461658790505197	Томская область, город Томск, Усова улица, 68, телефон: 54-23-94	Россия, Томская область, Томск, улица Усова, 68	0101000020E6100000C3D32B65193F5540B87361A4173B4C40
2696	5	54	\N	155	65344	\N	56.461670670146397	Томская область, город Томск, Усова улица, 68, телефон: 54-27-92	Россия, Томская область, Томск, улица Усова, 68	0101000020E6100000D0B52FA0173F55407D410B09183B4C40
2753	5	54	\N	155	65902	\N	56.530248408328497	Томская область, город Томск, Угрюмова улица, 1/2,	Россия, Томская область, Томск, улица Угрюмова, 1	0101000020E6100000404CC2853C4155407C629D2ADF434C40
2798	5	54	\N	155	74366	\N	56.520955999999998	"Томская область, Муниципальное образование ""Город Томск"", Трудовая, 18, телефон: 46-07-41"		0101000020E6100000C39D0B23BD3B5540D653ABAFAE424C40
2654	5	54	\N	155	74370	\N	56.471829999999997	"Томская область, Муниципальное образование ""Город Томск"", Тверская улица, 74, телефон: 431090"		0101000020E6100000677DCA31593E5540C6A2E9EC643C4C40
2803	5	54	\N	155	28744	\N	56.499737000000003	"Томская область, Муниципальное образование ""Город Томск"", Сухоозерный, 6, телефон: 40-25-19, 40-83-11, 40-25-19"	Россия, Томская область, Томск, Сухоозерный переулок, 6	0101000020E610000053EBFD463B3C5540F3CCCB61F73F4C40
2802	5	54	\N	155	28744	\N	56.499737000000003	"Томская область, Муниципальное образование ""Город Томск"", Сухоозерный, 6, телефон: 40-25-19, 40-83-11"	Россия, Томская область, Томск, Сухоозерный переулок, 6	0101000020E610000053EBFD463B3C5540F3CCCB61F73F4C40
2727	5	54	\N	155	65434	\N	56.510675721379599	"Томская область, город Томск, Суворова улица, 5, телефон: 67-29-91, 67-31-08"	Россия, Томская область, Томск, улица Суворова, 5	0101000020E6100000AB9509BFD4415540116DC7D45D414C40
2726	5	54	\N	155	65434	\N	56.5107711913424	Томская область, город Томск, Суворова улица, 5, телефон: 67-31-08	Россия, Томская область, Томск, улица Суворова, 5	0101000020E6100000A1A014ADDC415540635FB2F160414C40
2718	5	54	\N	155	74301	\N	56.570724468191997	Томская область, город Томск, Спутник пос, 18, телефон: 72-36-25		0101000020E61000001B4641F0F83E55406A85E97B0D494C40
2685	5	54	\N	155	74584	\N	56.506045694586099	Томская область, город Томск, посёлок Нижний Склад, Сплавная улица, 56, телефон: 911-392	Россия, Томская область, Томск, поселок Нижний Склад, Сплавная улица	0101000020E61000000F4240BE843A5540C422861DC6404C40
2770	5	54	\N	155	65953	\N	56.496234732268803	Томская область, город Томск, Соляная площадь, 2, телефон: 65-52-00	Россия, Томская область, Томск, Соляная площадь, 2	0101000020E61000006A334E43543D5540B610E4A0843F4C40
3241	5	54	\N	155	74410	\N	56.416520329729202	п. Басандайка, Советская, 1а, школа, телефон: 939-019		0101000020E6100000C5AC1743393F5540A110018750354C40
2789	5	54	\N	155	9567	\N	56.494433509053799	"Томская область, Муниципальное образование ""Город Томск"", Смирнова, 48А, телефон: 73-96-39"	Россия, Томская область, Томск	0101000020E61000009F3E027FF83E5540E603029D493F4C40
2788	5	54	\N	155	9567	\N	56.528835000000001	"Томская область, Муниципальное образование ""Город Томск"", Смирнова, 50, телефон: 76-40-66"		0101000020E61000002E8CF4A2763E554076FD82DDB0434C40
2777	5	54	\N	155	9567	\N	56.522182000000001	"Томская область, Муниципальное образование ""Город Томск"", Смирнова, 28, телефон: 62-77-08, 62-77-06"		0101000020E6100000DEE4B7E8643F5540AA471ADCD6424C40
2776	5	54	\N	155	9567	\N	56.526933999999997	"Томская область, Муниципальное образование ""Город Томск"", Смирнова, 44, телефон: 72-99-03, 72-43-10"		0101000020E610000004ADC090D53E55404293C49272434C40
2658	5	54	\N	155	74354	\N	56.482351178382601	"Томская область, Муниципальное образование ""Город Томск"", Сибирская улица, 29/1,"	Россия, Томская область, Томск, Сибирская улица	0101000020E61000008B16A06D353E5540B11875ADBD3D4C40
2646	5	54	\N	155	74354	\N	56.481459000000001	"Томская область, Муниципальное образование ""Город Томск"", Сибирская, 81А, телефон: 442900"		0101000020E61000009352D0ED253F5540B4AED172A03D4C40
2645	5	54	\N	155	74354	\N	56.481560029180301	"Томская область, Муниципальное образование ""Город Томск"", Сибирская улица, 81А, телефон: 442900"	Россия, Томская область, Томск, Сибирская улица, 81ак1	0101000020E6100000AE6708C72C3F5540E88711C2A33D4C40
2767	5	54	\N	155	65257	\N	56.520498870875002	"Томская область, город Томск, С.Лазо улица, 26/1, телефон: 67-31-69, 66-87-29"	Россия, Томская область, Томск, улица Сергея Лазо, 26/1	0101000020E61000003C4A253CA1425540E44C13B69F424C40
2739	5	54	\N	155	65257	\N	56.520528523753903	Томская область, город Томск, С.Лазо улица, 26/1, телефон: 66-87-29	Россия, Томская область, Томск, улица Сергея Лазо, 26/1	0101000020E610000031D0B52FA04255404FCFBBB1A0424C40
2738	5	54	\N	155	65257	\N	56.520356536732002	"Томская область, город Томск, С.Лазо улица, 26/1, телефон: 66-87-29, 67-31-70"	Россия, Томская область, Томск, улица Сергея Лазо, 26/1	0101000020E61000003C3080F0A1425540519FE40E9B424C40
2737	5	54	\N	155	65257	\N	56.519531432921603	Томская область, город Томск, С.Лазо улица, 22, телефон: 67-31-75	Россия, Томская область, Томск, улица Сергея Лазо, 22	0101000020E610000090F98040674255400C21E7FD7F424C40
2651	5	54	\N	155	74365	\N	56.486643000000001	"Томская область, Муниципальное образование ""Город Томск"", Вицмана улица, 32, телефон: 453169"		0101000020E610000077D844662E405540E6E95C514A3E4C40
2758	5	54	\N	155	66499	\N	56.497459051387501	Томская область, город Томск, Северный городок улица, 61/1, телефон: 25-44-61	Россия, Томская область, Томск, улица Северный Городок, 61	0101000020E6100000397D3D5FB33F5540E90C8CBCAC3F4C40
3160	5	54	\N	155	74843	\N	56.488790000000002	Томская область, Парабельский район, д.Костарево, ул.Свердлова 39		0101000020E6100000D06394675E3D5540514EB4AB903E4C40
2768	5	54	\N	155	65254	\N	56.499787225228403	Томская область, город Томск, Пушкина улица, 29, телефон: 65-68-92	Россия, Томская область, Томск, улица Пушкина, 29	0101000020E6100000849F38807E3E5540A4FB3905F93F4C40
2722	5	54	\N	155	65254	\N	56.5023995973431	"Томская область, город Томск, Пушкина улица, 54/1, телефон: 66-05-06, 66-05-04"		0101000020E6100000E4F8A1D2883F554055C1A8A44E404C40
2720	5	54	\N	155	65254	\N	56.502441131274601	"Томская область, город Томск, Пушкина улица, 54/1, телефон: 66-05-04, 66-05-06"	Россия, Томская область, Томск, улица Пушкина, 54/1	0101000020E6100000D8648D7A883F5540B39597FC4F404C40
2679	5	54	\N	155	74289	\N	56.491611466367203	Томская область, город Томск, село Тимирязевское, Путевая улица, 1Д, телефон: 912-252, 911-342		0101000020E6100000BAA46ABB093855404BADF71BED3E4C40
2671	5	54	\N	155	65287	\N	56.461857217147802	Томская область, город Томск, Пирогова улица, 2, телефон: 410-95-37	Россия, Томская область, Томск, улица Пирогова, 2	0101000020E61000006284F068E33C5540DF3653211E3B4C40
2637	5	54	\N	155	65287	\N	56.461762180382401	Томская область, город Томск, Пирогова улица, 2, телефон: 41-95-37	Россия, Томская область, Томск, улица Пирогова, 2	0101000020E61000006DCA15DEE53C55408D4468041B3B4C40
2717	5	54	\N	155	65268	\N	56.501763603312298	"Томская область, город Томск, Переездный пер, 3, телефон: 79-87-66, 79-83-68"	Россия, Томская область, Томск, Переездный переулок	0101000020E6100000C7293A92CB3F5540B32781CD39404C40
2795	5	54	\N	155	74373	\N	56.518214999999998	"Томская область, Муниципальное образование ""Город Томск"", Первомайская, 65, телефон: 63-13-84"		0101000020E610000034DAAA24B23D5540F8A57EDE54424C40
2850	5	54	\N	155	28782	\N	56.497596000000001	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Партизанская, 47, телефон: 21678"	Россия, Томская область, Томск, Партизанская улица	0101000020E6100000E9F010C64F3E55406A4FC939B13F4C40
2712	5	54	\N	155	65256	\N	56.497467118187402	Томская область, город Томск, Партизанская улица, 16, телефон: 65-68-99	Россия, Томская область, Томск, Партизанская улица, 16	0101000020E6100000C4B12E6EA33E55406CEBA7FFAC3F4C40
2711	5	54	\N	155	65256	\N	56.4965293179784	Томская область, город Томск, Партизанская улица, 17, телефон: 65-67-59	Россия, Томская область, Томск, Партизанская улица, 17	0101000020E6100000AC1BEF8E8C3E5540FF4124438E3F4C40
2666	5	54	\N	155	74382	\N	56.492935000000003	"Томская область, Муниципальное образование ""Город Томск"", Октябрьская улица, 16, телефон: 653164"		0101000020E61000005F61C1FD803D5540E2067C7E183F4C40
2774	5	54	\N	155	74302	\N	56.4929547263689	"Томская область, город Томск, Октябрьская улица, 16, телефон: 65-39-64, 65-31-64"		0101000020E6100000ACE46377813D554029B34126193F4C40
2769	5	54	\N	155	65361	\N	56.512874342647201	Томская область, город Томск, Новосибирская улица, 38, телефон: 67-53-90, 67-83-13	Россия, Томская область, Томск, Новосибирская улица, 38	0101000020E6100000DA3BA3AD4A415540FE7BF0DAA5414C40
2752	5	54	\N	155	65361	\N	56.512898069744601	г.Томск, ул.Новосибирская 38	Россия, Томская область, Томск, Новосибирская улица, 38	0101000020E6100000E481C8224D415540871744A4A6414C40
2741	5	54	\N	155	65361	\N	56.510957496108396	Томская область, город Томск, Новосибирская улица, 39, телефон: 67-54-80, 68-06-54	Россия, Томская область, Томск, Новосибирская улица, 39	0101000020E610000061FE0A992B415540C554FA0967414C40
2740	5	54	\N	155	65361	\N	56.511028680970199	"Томская область, город Томск, Новосибирская улица, 39, телефон: 68-06-54, 67-86-91"	Россия, Томская область, Томск, Новосибирская улица, 39	0101000020E610000060E4654D2C4155405F27F56569414C40
2656	5	54	\N	155	74375	\N	56.478684999999999	"Томская область, Муниципальное образование ""Город Томск"", Никитина улица, 26, телефон: 262390"		0101000020E610000040321D3A3D3E5540FA0AD28C453D4C40
2676	5	54	\N	155	74296	\N	56.456288999999998	Томская область, город Томск, Нахимова улица, 30, телефон: 41-25-85		0101000020E6100000D061BEBC003E554024438EAD673A4C40
2675	5	54	\N	155	74296	\N	56.456241470975698	Томская область, город томск, Нахимова улица, 30, телефон: 42-34-11		0101000020E6100000C9569753023E5540130CE71A663A4C40
2791	5	54	\N	155	74720	\N	56.535773874435598	"Томская область, Муниципальное образование ""Город Томск"", Мостовая, 24, телефон: 72-99-15"	Россия, Томская область, Томск, Мостовая улица, 24	0101000020E61000008A592F86723D55400806103E94444C40
2698	5	54	\N	155	65339	\N	56.451316611617301	Томская область, город Томск, Мокрушина улица, 10, телефон: 42-78-53	Россия, Томская область, Томск, улица Мокрушина, 10	0101000020E61000008CBFED09123F55407E9065C1C4394C40
2697	5	54	\N	155	65339	\N	56.450660633203199	Томская область, город Томск, Мокрушина улица, 22, телефон: 41-13-66	Россия, Томская область, Томск, улица Мокрушина, 22	0101000020E6100000FE9C82FC6C3F5540944A7842AF394C40
2750	5	54	\N	155	65259	\N	56.504797736219402	Томская область, город Томск, Мичурина улица, 4, телефон: 72-28-05, 75-45-14	Россия, Томская область, Томск, улица Мичурина, 4	0101000020E61000004E2A1A6B7F405540098B8A389D404C40
2716	5	54	\N	155	65259	\N	56.504690941253699	"Томская область, город Томск, Мичурина улица, 4, телефон: 75-28-05, 75-45-14"	Россия, Томская область, Томск, улица Мичурина, 4	0101000020E610000058569A9482405540F3CAF5B699404C40
2713	5	54	\N	155	65259	\N	56.504655342864702	г.Томск, ул. Мичурина 4	Россия, Томская область, Томск, улица Мичурина, 4	0101000020E61000004CC2853C82405540A661F88898404C40
2719	5	54	\N	155	74446	\N	56.541699455966999	Томская область, город Томск, Томск-Северный МПС улица, 8/1, телефон: 79-88-12	Россия, Томская область, Томск, улица МПС, 8	0101000020E61000005531957EC243554051A3906456454C40
2667	5	54	\N	155	74466	\N	56.515661999999999	Томская область, город Томск, Ленина проспект, 49А, телефон: 53-41-50		0101000020E6100000809C3061344155401DE5603601424C40
2657	5	54	\N	155	65454	\N	56.480296000000003	"Томская область, Муниципальное образование ""Город Томск"", Лебедева улица, 6, телефон: 262474"		0101000020E6100000EF59D768393E55402733DE567A3D4C40
2647	5	54	\N	155	65454	\N	56.4795097727647	"Томская область, Муниципальное образование ""Город Томск"", Лебедева улиц, 94, телефон: 451916"	Россия, Томская область, Томск, улица Лебедева, 94	0101000020E610000003B00111E23F55406F0D6C95603D4C40
2643	5	54	\N	155	65454	\N	56.479554999999998	"Томская область, Муниципальное образование ""Город Томск"", Лебедева улица, 94, телефон: 451916"		0101000020E61000004B766C04E23F55400FD1E80E623D4C40
2700	5	54	\N	155	74396	\N	56.515661999999999	Томская область, город Томск, Косарева улица, 9, телефон: 54-19-09		0101000020E6100000809C3061344155401DE5603601424C40
2652	5	54	\N	155	28976	\N	56.468871	"Томская область, Муниципальное образование ""Город Томск"", Комсомольский проспект, 64, телефон: 521808"	Россия, Томская область, Томск, Комсомольский проспект, 64/1	0101000020E610000059147651F43E55407B8505F7033C4C40
2787	5	54	\N	155	28724	\N	56.531675	"Томская область, Муниципальное образование ""Город Томск"", Кольцевой проезд, 39, телефон: 47-32-95"	Россия, Томская область, Томск, Кольцевой проезд, 39	0101000020E6100000B491EBA6943E5540E78C28ED0D444C40
2702	5	54	\N	155	65282	\N	56.461295253118301	Томская область,город Томск, Киевская улица, 111, телефон: 55-74-34	Россия, Томская область, Томск, Киевская улица, 111	0101000020E6100000B821C66B5E3E55407767EDB60B3B4C40
2695	5	54	\N	155	65282	\N	56.461414050504203	Томская область, город Томск, Киевская улица, 111, телефон: 55-74-34		0101000020E6100000B95510035D3E554051F52B9D0F3B4C40
2653	5	54	\N	155	65282	\N	56.472078000000003	"Томская область, Муниципальное образование ""Город Томск"", Киевская улица, 64А, телефон: 521218"		0101000020E61000008655BC91793E55409F94490D6D3C4C40
2704	5	54	\N	155	66472	\N	56.468343561640701	Томская область, город Томск, Карташова улица, 47, телефон: 52-12-44	Россия, Томская область, Томск, улица Карташова, 47	0101000020E61000003BC8EBC1A43E554090A339B2F23B4C40
2807	5	54	\N	155	65372	\N	56.500602000000001	"Томская область, Муниципальное образование ""Город Томск"", Карла Маркса, 50, телефон: 40-74-02, 40-62-97"		0101000020E6100000FED64E94843C5540F627F1B913404C40
2790	5	54	\N	155	65372	\N	56.492337491114299	г.Томск, ул.К.Маркса, 21	Россия, Томская область, Томск, улица Карла Маркса, 21	0101000020E610000044696FF0853C55402DCE18E6043F4C40
2786	5	54	\N	155	74363	\N	56.508346000000003	"Томская область, Муниципальное образование ""Город Томск"", Карла Ильмера, 15/1, телефон: 62-17-51, 62-17-52"		0101000020E61000000E32C9C8593E5540B686527B11414C40
2785	5	54	\N	155	74363	\N	56.506036000000002	"Томская область, Муниципальное образование ""Город Томск"", Карла Ильмера, 4, телефон: 47-18-57"		0101000020E6100000A06EA0C03B3E5540A14CA3C9C5404C40
2784	5	54	\N	155	74363	\N	56.508163000000003	"Томская область, Муниципальное образование ""Город Томск"", Карла Ильмера, 11, телефон: 62-17-38, 62-17-39"		0101000020E610000092B245D26E3E5540C504357C0B414C40
2831	5	54	\N	155	74336	\N	56.601894999999999	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Калинина, 88, телефон: 77-25-26"	Россия	0101000020E6100000E17D552E543955401E5036E50A4D4C40
2829	5	54	\N	155	74336	\N	56.587204	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Калинина, 72, телефон: 56-12-75"	Россия	0101000020E61000004B75012F333B55404A0A2C80294B4C40
2762	5	54	\N	155	29031	\N	56.519437467799101	Томская область, город Томск, Иркутский тракт, 181, телефон: 64-51-80	Россия, Томская область, Томск, Иркутский тракт, 181	0101000020E6100000EF7211DF894455408BAA5FE97C424C40
2761	5	54	\N	155	29031	\N	56.5142681916413	Томская область, город Томск, Иркутский тракт, 122/1, телефон: 67-45-95, 67-43-61	Россия, Томская область, Томск, Иркутский тракт, 122/1	0101000020E6100000F8A75489B24255408EB0A888D3414C40
2760	5	54	\N	155	29031	\N	56.5143156440691	Томская область, город Томск, Иркутский тракт, 122/1, телефон: 67-45-95	Россия, Томская область, Томск, Иркутский тракт, 122/1	0101000020E6100000ED478AC8B04255409FE74F1BD5414C40
2734	5	54	\N	155	29031	\N	56.517823622007	Томская область, город Томск, Иркутский тракт, 175, телефон: 64-42-71, 64-41-09	Россия, Томская область, Томск, Иркутский тракт, 175	0101000020E61000001C5C3AE63C445540BD8A8C0E48424C40
2733	5	54	\N	155	29031	\N	56.517811760008101	Томская область, город Томск, Иркутский тракт, 175, телефон: 64-41-09, 64-42-71	Россия, Томская область, Томск, Иркутский тракт, 175	0101000020E61000001C5C3AE63C445540F9BCE2A947424C40
2725	5	54	\N	155	29031	\N	56.508518777395899	Томская область, город Томск, Иркутский тракт, 86/1, телефон: 67-80-67	Россия, Томская область, Томск, Иркутский тракт, 86/1	0101000020E610000093DFA293A541554083328D2617414C40
2724	5	54	\N	155	29031	\N	56.502702999999997	Томская область, ород Томск, Иркутский тракт, 51/3, телефон: 75-13-77		0101000020E6100000821E6ADB30415540F04C689258404C40
2723	5	54	\N	155	29031	\N	56.502702999999997	Томская область, город Томск, Иркутский тракт, 51/3, телефон: 75-18-22	Россия, Томская область, Томск, Иркутский тракт, 51/3	0101000020E6100000821E6ADB30415540F04C689258404C40
2715	5	54	\N	155	29031	\N	56.5014512577158	Томская область, город Томск, Иркутский тракт, 15, телефон: 75-12-81		0101000020E61000003B342C465D405540F4C5DE8B2F404C40
2781	5	54	\N	155	74360	\N	56.514310999999999	"Томская область, Муниципальное образование ""Город Томск"", Интернайионалистов, 12, телефон: 72-73-80, 72-73-19"		0101000020E6100000E9EE3A1BF23E55408D7C5EF1D4414C40
2780	5	54	\N	155	74360	\N	56.516621000000001	"Томская область, Муниципальное образование ""Город Томск"", Интернационалистов, 11, телефон: 62-40-17, 62-40-18"		0101000020E6100000486E4DBA2D3F5540A2B60DA320424C40
2744	5	54	\N	155	65352	\N	56.513863453373403	Томская область, город Томск, Ивановского улица, 8, телефон: 63-35-30	Россия, Томская область, Томск, улица Ивановского	0101000020E6100000B950F9D7F2455540EECF4543C6414C40
2743	5	54	\N	155	65277	\N	56.513469091212002	"Томская область, город Томск, И.Черных улица, 97, телефон: 67-44-54, 67-58-63"	Россия, Томская область, Томск, улица Ивана Черных, 97	0101000020E61000005EA0A4C0024255404241295AB9414C40
2736	5	54	\N	155	65277	\N	56.517024874866003	Томская область, город Томск, И. Черных улица, 123/1, телефон: 67-76-90, 64-44-77	Россия, Томская область, Томск, улица Ивана Черных, 123/1	0101000020E6100000F9484A7A18435540711B0DE02D424C40
2735	5	54	\N	155	65277	\N	56.517060461593402	Томская область, город Томск, И.Черных улица, 123/1, телефон: 64-44-77, 67-76-90	Россия, Томская область, Томск, улица Ивана Черных, 123/1	0101000020E6100000ED66463F1A435540EE08A7052F424C40
2729	5	54	\N	155	65277	\N	56.514014987444199	Томская область, город Томск, И.Черных улица, 101, телефон: 67-17-96	Россия, Томская область, Томск, улица Ивана Черных, 101	0101000020E61000003E5C72DC29425540A453573ECB414C40
2728	5	54	\N	155	65277	\N	56.513517	Томская область, город Томск, И.Черных улица, 97, телефон: 67-44-54		0101000020E61000005917B7D1004255405378D0ECBA414C40
95186	5	54	\N	155	74378	\N	56.471342	г.Томск, ул.Енисейская, 36		0101000020E6100000C520B072683F5540999D45EF543C4C40
2701	5	54	\N	155	65460	\N	56.456653324402502	Томская область, город Томск, Елизаровых улица, 2, телефон: 42-52-33	Россия, Томская область, Томск, улица Елизаровых, 2	0101000020E61000007100FDBE7F3E5540664F029B733A4C40
2691	5	54	\N	155	65460	\N	56.463018706758803	Томская область, город Томск, Елизаровых улица, 47, телефон: 54-07-79	Россия, Томская область, Томск, улица Елизаровых, 47	0101000020E61000009206B7B5853F55409C36E334443B4C40
2745	5	54	\N	155	66498	\N	56.495550787560603	Томская область, город Томск, Д. Бедного улица, 4, телефон: 63-35-89	Россия, Томская область, Томск, поселок Новый, улица Демьяна Бедного, 4	0101000020E6100000BD512B4CDF445540034015376E3F4C40
2677	5	54	\N	155	65303	\N	56.472572565729699	Томская область, город Томск, Максима Горького улица, 55, телефон: 51-41-95	Россия, Томская область, Томск, улица Горького, 55	0101000020E6100000F99FFCDD3B3C55407EFCA5457D3C4C40
2710	5	54	\N	155	65427	\N	56.471272561751	Томская область, город Томск, Герцена улица, 7, телефон: 53-31-14	Россия, Томская область, Томск, улица Герцена, 7	0101000020E610000007B309302C3D5540703E75AC523C4C40
2668	5	54	\N	155	65427	\N	56.471213178587497	Томская область, город Томск, Герцена улица, 7, телефон: 53-21-87	Россия, Томская область, Томск, улица Герцена, 7	0101000020E6100000105D50DF323D55409B3924B5503C4C40
2665	5	54	\N	155	65427	\N	56.473002612163299	г.Томск, ул. Герцена,  49	Россия, Томская область, Томск, улица Герцена, 49	0101000020E610000006B8205B963E554077F4BF5C8B3C4C40
2661	5	54	\N	155	65427	\N	56.472312000000002	"Томская область, Муниципальное образование ""Город Томск"", Герцена улица, 18, телефон: 531331"		0101000020E61000006F2A52616C3D554012C138B8743C4C40
2660	5	54	\N	155	65427	\N	56.473038000000003	"Томская область, Муниципальное образование ""Город Томск"", Герцена улица, 47, телефон: 432583"		0101000020E610000069AA27F38F3E5540F4E159828C3C4C40
2694	5	54	\N	155	74298	\N	56.425843841725197	Томская область, город Томск, посёлок Геологов, Геологов улица, 11А, телефон: 42-90-69		0101000020E61000003B527DE7174055405299620E82364C40
2778	5	54	\N	155	74380	\N	56.512295000000002	"Томская область, Муниципальное образование ""Город Томск"", 79-ой Гвардейской Дивизии, 25, телефон: 47-21-90"		0101000020E610000057B439CE6D3E5540C173EFE192414C40
2714	5	54	\N	155	65261	\N	56.506541640440403	Томская область, город Томск, Вокзальная улица, 67, телефон: 79-88-11	Россия, Томская область, Томск, Октябрьский район, Вокзальная улица	0101000020E610000029081EDFDE3F55407506465ED6404C40
2799	5	54	\N	155	74367	\N	56.508961999999997	"Томская область, Муниципальное образование ""Город Томск"", Войкова, 86, телефон: 40-50-63, 40-48-70"		0101000020E6100000921FF12BD63B55401074B4AA25414C40
2686	5	54	\N	155	74667	\N	56.495172368688003	Томская область, город Томск, село Тимирязевское, Водозаборная улица, 1, телефон: 418-450, 554-792	Россия, Томская область, Томск, село Тимирязевское	0101000020E61000002C64AE0CAA3855408CF2CCCB613F4C40
2709	5	54	\N	155	66413	\N	56.4595799814633	Томская область, город Томск, Вершинина улица, 48, телефон: 41-95-71	Россия, Томская область, Томск, улица Вершинина, 48	0101000020E6100000C22FF5F3A63D5540A6F27684D33A4C40
2706	5	54	\N	155	66413	\N	56.4687492518064	Томская область, город Томск, Вершинина улица, 17, телефон: 55-83-09	Россия, Томская область, Томск, улица Вершинина, 17	0101000020E610000017D522A2983D554030849CF7FF3B4C40
2670	5	54	\N	155	66413	\N	56.515661999999999	Томская область, город Томск, Вершинина улица, 46, телефон: 41-95-71		0101000020E6100000809C3061344155401DE5603601424C40
3143	5	54	\N	155	66454	\N	56.469945140216197	"Томская область, г.Томск, ул Вавилова улица, 8	Россия, Томская область, Томск, улица Вавилова, 8	0101000020E61000009AD2FA5B0243554099F56228273C4C40
2635	5	54	\N	155	66454	\N	56.470005	"Томская область, Муниципальное образование ""Город Томск"", Вавилова улица, 8, телефон: 492871"		0101000020E6100000A54C6A68034355406EFAB31F293C4C40
2634	5	54	\N	155	66454	\N	56.469897632025003	Вавилова 8-1	Россия, Томская область, Томск, улица Вавилова, 8	0101000020E61000008D0A9C6C03435540583A1F9E253C4C40
2766	5	54	\N	155	65475	\N	56.5026790234038	Томская область, город Томск, Бирюкова улица, 22, телефон: 67-88-78	Россия, Томская область, Томск, улица Бирюкова, 22	0101000020E6100000342C465D6B42554068B114C957404C40
2742	5	54	\N	155	65271	\N	56.520190850217602	Томская область, город Томск, Беринга улица, 24, телефон: 67-31-82	Россия, Томская область, Томск, улица Беринга, 24	0101000020E6100000F4311F10E84155403656629E95424C40
2732	5	54	\N	155	65271	\N	56.513013553763599	Томская область, город Томск, Беринга улица, 4, телефон: 67-44-11	Россия, Томская область, Томск, улица Беринга, 4	0101000020E6100000A3ACDF4C4C425540F0315871AA414C40
2731	5	54	\N	155	65271	\N	56.5128237371474	Томская область, город Томск, Беринга улица, 4, телефон: 64-41-00	Россия, Томская область, Томск, улица Беринга, 4	0101000020E6100000ADA415DF504255404D4D8237A4414C40
2730	5	54	\N	155	65271	\N	56.512906782034499	Томская область, город Томск, Беринга улица, 4, телефон: 67-48-39	Россия, Томская область, Томск, улица Беринга, 4	0101000020E6100000A37895B54D425540DA71C3EFA6414C40
2771	5	54	\N	155	65963	\N	56.498917630611103	"Томская область, город Томск, Белозерская улица, 12, телефон: 65-88-48, 65-30-62"	Россия, Томская область, Томск, Белозерская улица, 12/1	0101000020E610000058E4D70FB13D554060B1868BDC3F4C40
2684	5	54	\N	155	66462	\N	56.4623829777507	Томская область, город Томск, Белинского улица, 55, телефон: 56-35-18	Россия, Томская область, Томск, улица Белинского, 55	0101000020E610000070B6B9313D3D5540FA9CBB5D2F3B4C40
2756	5	54	\N	155	65924	\N	56.5196582947327	г.Томск, ул. Б.Куна, 20	Россия, Томская область, Томск, улица Бела Куна, 20	0101000020E6100000971FB8CA13435540698D412784424C40
2754	5	54	\N	155	65924	\N	56.517896999999998	Томская область, город Томск, Б.Куна улица, 1, телефон: 64-46-25		0101000020E61000002B6D718DCF43554027D9EA724A424C40
2683	5	54	\N	155	74483	\N	56.515661999999999	Томская область, город Томск, Басандайская улица, 11, телефон: 42-85-79		0101000020E6100000809C3061344155401DE5603601424C40
2773	5	54	\N	155	66501	\N	56.4941276866683	"Томская область, город Томск"", Ачинская улица, 20, телефон: 65-95-77"	Россия, Томская область, Томск, Ачинская улица, 20	0101000020E61000001B2C9CA4F93D5540DA0418963F3F4C40
2772	5	54	\N	155	66501	\N	56.494163294981199	Томская область, город Томск, Ачинская улица, 20, телефон: 65-95-77	Россия, Томская область, Томск, Ачинская улица, 20	0101000020E61000001ADEACC1FB3D554056F2B1BB403F4C40
2673	5	54	\N	155	65291	\N	56.463730896171199	Томская область, город Томск, Аркадия Иванова улица, 49, телефон: 42-07-80	Россия, Томская область, Томск, улица Аркадия Иванова	0101000020E6100000C007AF5DDA3B5540199293895B3B4C40
2672	5	54	\N	155	65291	\N	56.4619372186147	Томская область, город Томск, Аркадия Иванова улица, 4, телефон: 41-96-30	Россия, Томская область, Томск, улица Аркадия Иванова, 4	0101000020E610000022382EE3A63C5540FBE769C0203B4C40
2639	5	54	\N	155	28963	\N	56.480167000000002	"Томская область, Муниципальное образование ""Город Томск"", Алтайская улица, 159, телефон: 454580"	Россия, Томская область, Томск, Алтайская улица, 159	0101000020E6100000016A6AD95A40554029CFBC1C763D4C40
2648	5	54	\N	155	74369	\N	56.481479	"Томская область, Муниципальное образование ""Город Томск"", Алтайская улица, 120/1, телефон: 454849"		0101000020E6100000F60CE19865405540FB5A971AA13D4C40
2641	5	54	\N	155	74369	\N	56.481479	"Томская область, Муниципальное образование ""Город Томск"", Алтайская улица, 120/1, телефон: 450658"		0101000020E6100000F60CE19865405540FB5A971AA13D4C40
2640	5	54	\N	155	74369	\N	56.481479	"Томская область, Муниципальное образование ""Город Томск"", Алтайская улица, 120/1, телефон: 450681"		0101000020E6100000F60CE19865405540FB5A971AA13D4C40
2663	5	54	\N	155	74350	\N	56.481245104705501	"Томская область, Муниципальное образование ""Город Томск"", Беленца улица, 11, телефон: 513612"	Россия, Томская область, Томск, улица Алексея Беленца, 17	0101000020E6100000B891B245D23C5540882EA86F993D4C40
3356	5	54	448	3765	74596	\N	56.854782999999998	с. Малобрагино, ул. Школьная, 1, телефон: 36-515		0101000020E61000002A00C63368185540A0168387696D4C40
2783	5	54	\N	155	9610	\N	56.507914681223397	"Томская область, Муниципальное образование ""Город Томск"", 79 Гвардейской дивизии, 21, телефон: 76-29-26"	Россия, Томская область, Томск	0101000020E6100000007157AF223F5540EC12D55B03414C40
2792	5	54	\N	155	74372	\N	56.525584000000002	"Томская область, Муниципальное образование ""Город Томск"", 5-ой Армии, 24, телефон: 46-11-44"		0101000020E610000083DC4598A23C554083A6255646434C40
2793	5	54	\N	155	74529	\N	56.525584000000002	"Томская область, Муниципальное образование ""Город Томск"", 5-й Армии, 24, телефон: 46-11-44"		0101000020E610000083DC4598A23C554083A6255646434C40
2938	5	54	\N	15359	74543	\N	57.988554000000001	"Томская область, Муниципальное образование ""Колпашевский район"", д.Сугот, пер.Клубный, 1, телефон: 95436"		0101000020E610000060E4654D2CBE54403D2AFEEF88FE4C40
2958	5	54	\N	56685	66613	\N	60.739068000000003	"Томская область, Муниципальное образование ""Город Стрежевой"", пл. Нефтяников, 2, телефон: 50468"		0101000020E61000007DE6AC4F3963534094C2BCC7995E4E40
2960	5	54	\N	56685	66616	\N	60.739068000000003	"Томская область, Муниципальное образование ""Город Стрежевой"", Н. Мержи, 1, телефон: 53209"		0101000020E61000007DE6AC4F3963534094C2BCC7995E4E40
2965	5	54	\N	56685	66642	\N	60.735034192012002	"Томская область, Муниципальное образование ""Город Стрежевой"", Молодежная, 3, телефон: 67002"	Россия, Томская область, городской округ Стрежевой	0101000020E61000004D840D4FAF6553405AB91798155E4E40
2957	5	54	\N	56685	66611	\N	60.739068000000003	"Томская область, Муниципальное образование ""Город Стрежевой"", Коммунальная, 1, телефон: 55800"		0101000020E61000007DE6AC4F3963534094C2BCC7995E4E40
2955	5	54	\N	56685	74318	\N	60.739068000000003	"Томская область, Муниципальное образование ""Город Стрежевой"", Викулова, 1, телефон: 57199"		0101000020E61000007DE6AC4F3963534094C2BCC7995E4E40
2956	5	54	\N	56685	65995	\N	60.739068000000003	"Томская область, Муниципальное образование ""Город Стрежевой"", Буровиков, 18, телефон: 55658"		0101000020E61000007DE6AC4F3963534094C2BCC7995E4E40
2964	5	54	\N	56685	65417	\N	60.728309352296201	"Томская область, Муниципальное образование ""Город Стрежевой"", 4 микрорайон, 458, телефон: 57633"	Россия, Томская область, Александровский район	0101000020E6100000B587BD50C0635340F530B43A395D4E40
2963	5	54	\N	56685	65417	\N	60.737723732312901	"Томская область, Муниципальное образование ""Город Стрежевой"", 4 микрорайон, 458, телефон: 57634"	Россия, Томская область, городской округ Стрежевой	0101000020E61000004D840D4FAF655340B6BC72BD6D5E4E40
2962	5	54	\N	56685	65417	\N	60.7309994577274	"Томская область, Муниципальное образование ""Город Стрежевой"", 4 микрорайон, 460, телефон: 54498"	Россия, Томская область, городской округ Стрежевой	0101000020E61000002D944C4EED63534050340F60915D4E40
2961	5	54	\N	56685	65417	\N	60.735034192012002	"Томская область, Муниципальное образование ""Город Стрежевой"", 4 микрорайон, 433/1, телефон: 39622"	Россия, Томская область, городской округ Стрежевой	0101000020E610000065355D4F746453405AB91798155E4E40
2959	5	54	\N	56685	65389	\N	60.733016888446798	"Томская область, Муниципальное образование ""Город Стрежевой"", 3 микрорайон, 324, телефон: 50728"	Россия, Томская область, городской округ Стрежевой	0101000020E61000000ABFD4CF9B625340BD344580D35D4E40
2855	5	54	\N	56685	65389	\N	60.743774371591797	"Томская область, Муниципальное образование ""Город Стрежевой"", 3 микрорайон, 324, телефон: 52969"		0101000020E61000003927F6D03E655340BCCE86FC335F4E40
2937	5	54	\N	15337	\N	\N	57.964677000000002	"Томская область, Муниципальное образование ""Колпашевский район"", д.Староабрамкино, ул.Центральная, 14, телефон: 32116"	Россия, Томская область, село Староабрамкино	0101000020E610000077D66EBBD0C35440091A33897AFB4C40
2846	5	54	\N	60291	74381	\N	56.601421249175999	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Мира, 11, телефон: 54-68-14"	Россия	0101000020E6100000888043A8523955405610035DFB4C4C40
2839	5	54	\N	60291	74314	\N	56.600097105659998	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", просп. Коммунистический, 103, телефон: 52-24-83"	Россия	0101000020E6100000A86F99D365395540BFB67EFACF4C4C40
2834	5	54	\N	60291	74314	\N	56.599475703810498	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", просп. Коммунистический, 119,"		0101000020E610000015AB06616E3A5540535E2BA1BB4C4C40
2814	5	54	\N	60291	74314	\N	56.601464153605498	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", просп. Коммунистический, 39, телефон: 54-72-10"	Россия	0101000020E6100000C85EEFFE7839554055DCB8C5FC4C4C40
2843	5	54	\N	60291	74306	\N	56.604304613880601	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", просп. Коммунистический, 56, телефон: 52-16-14"		0101000020E61000002FDE8FDB2F39554096E7C1DD594D4C40
2838	5	54	\N	60291	74306	\N	56.601653524295799	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", просп. Коммунистический, 119, телефон: 52-79-20"		0101000020E6100000B60F79CBD5395540F9C08EFF024D4C40
2823	5	54	\N	60291	74342	\N	56.572834550038102	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", пер. Чекист, 2, телефон: 56-22-54"		0101000020E6100000D55E44DB313B5540888043A852494C40
2822	5	54	\N	60291	74532	\N	56.601464523471002	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"" п.Орловка, пер.Школьный, 4, телефон: 906-154"	Россия	0101000020E61000002975C938463A554025581CCEFC4C4C40
2824	5	54	\N	60291	74348	\N	56.604619	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Чапаева, 22, телефон: 56-14-56"	Россия	0101000020E61000001E8997A77338554026C5C727644D4C40
2819	5	54	\N	60291	74450	\N	56.605361225169801	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Чайковского, 15, телефон: 77-62-00"	Россия	0101000020E61000003DB5FAEAAA3855400EA320787C4D4C40
2810	5	54	\N	60291	74324	\N	56.604059410728503	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Строителей, 27, телефон: 52-57-26"	Россия	0101000020E6100000BD378600E03855405FED28CE514D4C40
2809	5	54	\N	60291	74324	\N	56.605624171424999	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Строителей, 38, телефон: 54-72-42"		0101000020E6100000D39FFD48113955401BD65416854D4C40
2808	5	54	\N	60291	74688	\N	57.457746	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Сосновая 16, 8, телефон: 77-83-73"		0101000020E610000002BB9A3C65055340FAEFC16B97BA4C40
2840	5	54	\N	60291	74315	\N	56.601456478894299	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Северная, 18, телефон: 52-91-87, 52-93-50"	Россия	0101000020E610000051888043A8395540D2FD9C82FC4C4C40
2828	5	54	\N	60291	74344	\N	56.607186278371699	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Победы, 8б, телефон: 56-85-14"	Россия	0101000020E61000009E3F6D54A7375540664B5645B84D4C40
2827	5	54	\N	60291	74344	\N	56.578181999999998	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Победы, 12а, телефон: 56-47-57"		0101000020E6100000F3583332C83A5540649126DE014A4C40
2817	5	54	\N	60291	74329	\N	56.604650999999997	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Пионерская, 12, телефон: 54-65-94"		0101000020E61000008C118942CB385540313F3734654D4C40
2818	5	54	\N	60291	74852	\N	56.600911000000004	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Первомайская, 30, телефон: 54-76-61"	Россия	0101000020E6100000C9586DFE5F3A55404167D2A6EA4C4C40
2815	5	54	\N	60291	74421	\N	56.600135388117003	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", парковая, 2а, телефон: 54-83-22"	Россия	0101000020E6100000C440D7BE80395540AD174339D14C4C40
2826	5	54	\N	60291	74331	\N	56.601047000000001	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Ленинградская, 11, телефон: 56-96-31"	Россия	0101000020E61000000A48FB1F603A5540F12DAC1BEF4C4C40
2837	5	54	\N	60291	74310	\N	56.597487000000001	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Курчатова, 14, телефон: 52-02-76"	Россия	0101000020E61000009DB81CAF403A554080643A747A4C4C40
2836	5	54	\N	60291	74310	\N	56.599041	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Курчатова, 16, телефон: 52-61-11"		0101000020E61000004AB54FC7633A554048FB1F60AD4C4C40
2835	5	54	\N	60291	74310	\N	56.600517000000004	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Курчатова, 7, телефон: 52-22-72"	Россия	0101000020E6100000168733BF9A39554095D8B5BDDD4C4C40
2844	5	54	\N	60291	74439	\N	56.598242116755898	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Крупской, 14, телефон: 52-47-68"	Россия	0101000020E6100000E4BA29E5B53A5540FC8BA031934C4C40
2845	5	54	\N	60291	74343	\N	56.593683874504102	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", просп. Коммунистический, 65, телефон: 780-223"	Россия	0101000020E610000017618A72693A554049145AD6FD4B4C40
2842	5	54	\N	60291	74340	\N	56.601143	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Калинина, 46а, телефон: 52-31-08, 52-43-95"		0101000020E6100000F04C689258395540139CFA40F24C4C40
2841	5	54	\N	60291	74340	\N	56.6009357969428	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Калинина, 109, телефон: 56-57-31"	Россия	0101000020E610000026E2ADF36F395540997E8978EB4C4C40
2832	5	54	\N	60291	74340	\N	56.599184000000001	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Калинина, 104, телефон: 56-73-19"	Россия	0101000020E6100000D8D825AAB7395540AB24B20FB24C4C40
2812	5	54	\N	60291	74340	\N	56.603543999999999	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Калинина, 25, телефон: 54-76-96"	Россия	0101000020E6100000F94ECC7A3138554038D906EE404D4C40
2811	5	54	\N	60291	74340	\N	56.601823000000003	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Калинина, 43а, телефон: 54-52-43"		0101000020E6100000A1F5F065A2395540857D3B89084D4C40
2816	5	54	\N	60291	74391	\N	56.597487000000001	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", Горького, 32, телефон: 54-90-95"		0101000020E6100000FFEA71DF6A3A554080643A747A4C4C40
2896	5	54	\N	13356	74418	\N	57.571776	с. Пудино, ул. Горького, дом 8, телефон: 34-235		0101000020E61000009A05DA1D52DC5340A051BAF42FC94C40
3345	5	54	448	47859	74495	\N	56.619196000000002	с. Каргала, ул. Юбилейная, 14, телефон: 33-246		0101000020E61000009F7422C154FD544032E884D0414F4C40
2900	5	54	\N	60301	74526	\N	58.313262199989801	"Томская область, Муниципальное образование ""Колпашевский район"". г.Колпашево, ул.Обская, 65/7, телефон: 33264"	Россия, Томская область, река Обь	0101000020E6100000DD79E2395BBA54402F8A1EF818284D40
2894	5	54	\N	13243	\N	\N	57.562449999999998	г.Кедровый, 1 микрорайон, дом 42, телефон: 35-491		0101000020E61000008CBE823463E453404ED1915CFEC74C40
2893	5	54	\N	13243	74491	\N	57.562449999999998	г. Кедровый, 1 микрорайон, дом 61, телефон: 38250, факс: 35-831		0101000020E61000008CBE823463E453404ED1915CFEC74C40
3257	5	54	\N	52317	66430	\N	56.430574	Томская область, Томский район, п. Зональная станция, ул.Совхозная 18		0101000020E6100000F4FDD478E94055400341800C1D374C40
3246	5	54	\N	52317	66430	\N	56.431275730808103	п. Зональная Станция, Совхозная, 10, здание администрации,  каб. № 5, телефон: 923-170	Россия, Томская область, поселок Зональная Станция, Совхозная улица	0101000020E610000094162EABB04055405CC64D0D34374C40
3256	5	54	\N	52317	74358	\N	56.427833283957597	Томская область, Томский район, пос.Зональная станция, ул.Зеленая 40	Россия, Томская область, поселок Зональная Станция, Зеленая улица	0101000020E61000002AE620E8684155402593533BC3364C40
2833	5	54	\N	60302	74459	\N	56.601464	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"", просп. Коммунистический, 141, телефон: 56-05-10"	Россия	0101000020E61000008FA850DD5C39554055DCB8C5FC4C4C40
3258	5	54	\N	60370	74893	\N	56.402535545801797	п. Госсортучасток, Центральная, контора сортоиспытательной станции, телефон: 924-315	Россия	0101000020E6100000245F09A4C441554038BBB54C86334C40
3245	5	54	\N	60304	\N	\N	56.384008999999999	п. Аэропорт, д.7, телефон: 964-814	Россия	0101000020E6100000B5519D0E644D5540512FF83427314C40
3244	5	54	\N	60320	\N	\N	56.3901807777602	п. Аэропорт, д.7, здание детского сада, телефон: 964-804	Россия	0101000020E6100000946C7539254D5540A2427573F1314C40
2858	5	54	\N	60289	74376	\N	56.987669202991803	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Ленина, 47, телефон: 21960"	Россия, Томская область, Асиновский район, Асино	0101000020E6100000D5EB1681B1895540F22213F06B7E4C40
2851	5	54	\N	60289	74376	\N	56.9944325657493	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Ленина, 36, телефон: 22752"	Россия, Томская область, Асиновский район, Асино	0101000020E6100000C0ED0912DB88554016889E94497F4C40
2861	5	54	\N	60289	74321	\N	57.004158769792298	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Тельмана, 39, телефон: 31834"	Россия, Томская область, Асиновский район, Асино	0101000020E61000002B4D4A41B7875540F67D384888804C40
2857	5	54	\N	60289	74308	\N	56.998163412429598	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Ивана Буева, 38, телефон: 24593#108"	Россия, Томская область, Асиновский район, Асино	0101000020E6100000AB07CC43A6895540E38920CEC37F4C40
2856	5	54	\N	60289	74438	\N	56.983217636623998	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Гончарова, 46, телефон: 22451"		0101000020E6100000DDCEBEF2208A5540556B6116DA7D4C40
3350	5	54	448	3346	74593	\N	56.867483	с. Федораевка, ул. Набережная, 2, телефон: 29-792	Россия, Томская область, Шегарский район, село Федораевка	0101000020E610000086E8103812ED5440016BD5AE096F4C40
3337	5	54	448	47717	74685	\N	56.821798999999999	д. Татьяновка, ул. Центральная, 36, телефон: 35-222		0101000020E6100000B64DF1B8A8E354405871AAB530694C40
3198	5	54	448	49299	74580	\N	56.709130999999999	с. Половинка, Центральная, 9, телефон: 927-411		0101000020E61000008FA850DD5C18554036CAFACDC45A4C40
3347	5	54	448	47910	74500	\N	56.534117000000002	п. Победа, ул. Ленина, 68, телефон: 42-264		0101000020E6100000F94CF6CFD30A55406B9E23F25D444C40
3354	5	54	448	3494	74595	\N	56.983882000000001	с. Новоильинка, ул. Новая, 9-2, телефон: 29-794		0101000020E61000003049658A39055540C18F6AD8EF7D4C40
3353	5	54	448	3494	74595	\N	56.983882000000001	с. Новоильинка, ул. Новая, 2, телефон: 29-687		0101000020E61000003049658A39055540C18F6AD8EF7D4C40
3368	5	54	448	4299	74412	\N	56.530002000000003	д. Нащеково, ул. Сибирская, 2, телефон: 29-5069		0101000020E61000003AADDBA0F60355404568041BD7434C40
3349	5	54	448	47937	74760	\N	56.942391804408999	с. Монастырка, ул. Советская, 32а, телефон: 29-570	Россия, Томская область, Шегарский район, село Монастырка	0101000020E61000002D077AA86DEE54408A01124DA0784C40
3036	5	54	448	46285	74441	\N	56.929927999999997	с.Михайловка, Гончарова, 42, телефон: 89016178152		0101000020E61000003145B9347EEB54403DD175E107774C40
3359	5	54	448	48124	74482	\N	56.560025000000003	с. Мельниково, ул. Школьная, 68, телефон: 21-697		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3364	5	54	448	48124	66411	\N	56.560025000000003	с. Мельниково, ул. Чапаева, 60, телефон: 21-076		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3360	5	54	448	48124	66411	\N	56.560025000000003	с. Мельниково, ул. Чапаева, 23, телефон: 23-734		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3366	5	54	448	48124	74417	\N	56.560025000000003	с. Мельниково, ул. Суворова, 3, телефон: 21-974		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3361	5	54	448	48124	74422	\N	56.560025000000003	с. Мельниково, ул. Московская, 13, телефон: 23-550		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3358	5	54	448	48124	74422	\N	56.560025000000003	с. Мельниково, ул. Московская, 24, телефон: 22-682		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3367	5	54	448	48124	74403	\N	56.560025000000003	с. Мельниково, ул. Коммунистическая, 101, телефон: 21-040		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3365	5	54	448	48124	74403	\N	56.560025000000003	с. Мельниково, ул. Коммунистическая, 24, телефон: 22-779		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3363	5	54	448	48124	74761	\N	56.560025000000003	с. Мельниково, ул. Калинина, 55, телефон: 22-731		0101000020E61000003123BC3D08055540A1F831E6AE474C40
3340	5	54	448	2761	74499	\N	56.704659999999997	с. Маркелово, ул. Рабочая, 1, телефон: 37-137		0101000020E6100000AE4A22FB20E454405166834C325A4C40
3338	5	54	448	2698	74608	\N	56.828280999999997	с. Вороновка, ул. Кооперативная, 9а, телефон: 35-145	Россия, Томская область, Шегарский район, село Вороновка	0101000020E61000004A7EC4AF58DD5440F7729F1C056A4C40
3357	5	54	448	48093	74602	\N	56.896279447521501	д. Бушуево, ул. Энергетическая, 6а, телефон: 36-559	Россия, Томская область, Шегарский район, село Бушуево	0101000020E6100000456458C51B125540B98B3045B9724C40
3260	5	54	448	60305	74501	\N	56.261968000000003	с. Батурино, Цветочная, 11, школа, телефон: 959-817		0101000020E6100000A06B5F402F3E55409D4CDC2A88214C40
3342	5	54	448	2888	74408	\N	56.552191000000001	с. Баткат, пер. Кооперативный, 1,		0101000020E61000009BFF571D39F75440A112D731AE464C40
3343	5	54	448	47828	74606	\N	56.555461000000001	с. Бабарыкино, ул. Советская, 27, телефон: 31-156		0101000020E61000005BD07B6308E754400B9A965819474C40
3336	5	54	448	2540	74745	\N	56.772250999999997	с. Анастасьевка, пер. Школьный, 2, телефон: 29-137		0101000020E61000003C16DBA4A2E45440D2A6EA1ED9624C40
3299	5	54	146	349	74589	\N	57.774791	Томская область, Чаинский район, п. Черемушки, Светлая, 16,		0101000020E61000000987DEE2E1A65440191EFB592CE34C40
3323	5	54	146	1774	74735	\N	57.740810000000003	Томская область, Чаинский район, с. Чемондаевка, Трактовая, 1, телефон: 3-37-18		0101000020E6100000BF7D1D3867C054405F46B1DCD2DE4C40
3322	5	54	146	1726	74588	\N	57.930230000000002	Томская область, Чаинский район, с. Чаинск, Комсомольская, 14, телефон: 5-61-67		0101000020E6100000B8E864A9F5A5544009E1D1C611F74C40
3311	5	54	146	1105	74508	\N	57.611761000000001	Томская область, Чаинский район,  с. Усть-Бакчар, Центральная, 17, телефон: 3-52-35		0101000020E610000049641F6459945440F0FB372F4ECE4C40
3327	5	54	146	2023	74661	\N	57.814383999999997	Томская область, Чаинский район, п. Трудовой, Трудовой, 22-1, телефон: 5-38-59		0101000020E61000001E19ABCDFFA854405D3123BC3DE84C40
3309	5	54	146	984	74806	\N	57.491441999999999	Томская область, Чаинский район, с. Третья Тига, Центральная, 23, телефон: 3-34-86		0101000020E6100000FED5E3BED5975440BFF04A92E7BE4C40
3321	5	54	146	60342	74818	\N	58.0317023481268	Томская область, Чаинский район, с. Тоинка, Мостовая, 2, телефон: 89016095659	Россия, Томская область, Чаинский район, село Тоинка	0101000020E6100000D95E0B7A6FAB5440E19BA6CF0E044D40
3325	5	54	146	1885	74591	\N	57.697693000000001	Томская область, Чаинский район, с. Сухой Лог, Центральная, 24, телефон: 2-16-03		0101000020E6100000EBE1CB4411B55440F6D214014ED94C40
3314	5	54	146	1249	74811	\N	57.714066000000003	Томская область, Чаинский район, с. Стрельниково, Береговая, 22, телефон: 5-34-42		0101000020E6100000FE9C82FC6C9C5440C097C28366DB4C40
3331	5	54	146	2135	\N	\N	57.785637000000001	Томская область, Чаинский район, с. Подгорное, Лесная, 34, телефон: 2-17-05	Россия, Томская область, Чаинский район, село Подгорное	0101000020E6100000F568AA27F3A8544087C3D2C08FE44C40
3330	5	54	146	2135	\N	\N	57.785637000000001	Томская область, Чаинский район, с. Подгорное, МК-44, 1,1, телефон: 2-19-17		0101000020E6100000F568AA27F3A8544087C3D2C08FE44C40
3332	5	54	146	2135	74406	\N	57.785637000000001	Томская область, Чаинский район, с. Подгорное, Трактовая, 49, телефон: 2-14-60		0101000020E6100000F568AA27F3A8544087C3D2C08FE44C40
3335	5	54	146	2135	74401	\N	57.785637000000001	Томская область, Чаинский район, с. Подгорное, Советская, 21б,1, телефон: 2-27-93		0101000020E6100000F568AA27F3A8544087C3D2C08FE44C40
3329	5	54	146	2135	74671	\N	57.785637000000001	Томская область, Чаинский район, с. Подгорное, Подлесная, 6, 1, телефон: 2-30-29		0101000020E6100000F568AA27F3A8544087C3D2C08FE44C40
3334	5	54	146	2135	74400	\N	57.785637000000001	Томская область, Чаинский район, с. Подгорное, Ленинская, 11, телефон: 2-15-94		0101000020E6100000F568AA27F3A8544087C3D2C08FE44C40
3333	5	54	146	2135	74481	\N	57.785637000000001	Томская область, Чаинский район, с. Подгорное, Горная, 1, телефон: 2-13-90		0101000020E6100000F568AA27F3A8544087C3D2C08FE44C40
3316	5	54	146	1353	74814	\N	57.739460000000001	Томская область, Чаинский район, с. Обское, Школьная, 20, телефон: 4-61-49		0101000020E61000001684F23E8ED854409F5912A0A6DE4C40
3312	5	54	146	1126	74816	\N	57.620457000000002	Томская область, Чаинский район, п. Новые Ключи, Больничная, 5, телефон: 3-51-03		0101000020E610000009168733BF95544082C98D226BCF4C40
3317	5	54	146	1452	74819	\N	57.829751000000002	Томская область, Чаинский район, с. Новоколомино, Обская, 24, телефон: 4-66-22		0101000020E6100000CBF5B6990AD154406269E04735EA4C40
3310	5	54	146	998	74617	\N	57.56232	Томская область, Чаинский район, с. Нижняя Тига, Трактовая, 3, телефон: 3-46-31		0101000020E61000008F54DFF94594544080F10C1AFAC74C40
3326	5	54	146	1959	74734	\N	57.805408	Томская область, Чаинский район, с. Мушкино, Октябрьская, 29, телефон: 89234025431		0101000020E6100000F1F5B52E35AA5440E8F7FD9B17E74C40
3308	5	54	146	907	74730	\N	57.521276	Томская область, Чаинский район, c. Лось Гора, Трактовая, 9, телефон: 3-40-35		0101000020E61000003BC269C18B9154404818062CB9C24C40
3315	5	54	146	1341	74812	\N	57.701579000000002	Томская область, Чаинский район, п. Чая, Набережная, 23а, телефон: 3-34-19		0101000020E61000002F3196E9979D5440BB473657CDD94C40
3318	5	54	146	1463	74662	\N	57.876860000000001	Томская область, Чаинский район, с. Леботер, Пролетарская, 8, телефон: 4-64-31		0101000020E6100000F94ECC7A31CB5440D595CFF23CF04C40
3319	5	54	146	1572	74507	\N	57.792703000000003	Томская область, Чаинский район, с. Коломинские Гривы, Советская, 21, телефон: 4-52-44		0101000020E6100000581CCEFC6AC954407638BA4A77E54C40
3324	5	54	146	1835	74705	\N	57.716532000000001	Томская область, Чаинский район, с. Ермиловка, Новая, 23, телефон: 5-35-21		0101000020E6100000FA2B64AE0CB05440CC441152B7DB4C40
3320	5	54	146	51982	74659	\N	58.042095000000003	Томская область, Чаинский район, с. Гришкино, Советская, 19, телефон: 5-63-41		0101000020E61000003BAA9A20EAA954409E29745E63054D40
3328	5	54	146	2083	74663	\N	57.756357000000001	Томская область, Чаинский район, п. Григорьевка, Энергетиков, 3, телефон: 5-33-09		0101000020E6100000566133C005A85440E38C614ED0E04C40
3307	5	54	146	856	74585	\N	57.475684000000001	Томская область, Чаинский район, с. Гореловка, Центральная, 34, телефон: 3-41-31		0101000020E61000008E76DCF0BB8D5440809D9B36E3BC4C40
3313	5	54	146	1229	74817	\N	57.678351999999997	Томская область, Чаинский район, с. Варгатер, Центральная, 42, телефон: 5-32-25		0101000020E61000006D1D1CEC4D9C54408D96033DD4D64C40
3306	5	54	146	799	74813	\N	57.546360999999997	Томская область, Чаинский район, с. Бундюр, Школьная, 10, телефон: 3-42-33		0101000020E61000003B394371C77F5440A9674128EFC54C40
3261	5	54	52	60353	74835	\N	56.155528581917501	с. Яр, Октябрьская, 80, Дом культуры, телефон: сот. 8-960-978-04-86	Россия, Томская область, Томский район, село Яр	0101000020E610000048BF7D1D383C5540304AD05FE8134C40
3292	5	54	52	46816	66410	\N	56.402092000000003	д. Черная речка, Береговая, 5, школа, телефон: 966-149		0101000020E6100000FF76D9AF3B3A5540DBFD2AC077334C40
3282	5	54	52	46643	74587	\N	56.634371999999999	д. Халдеево, Лесная, 1а, здание школы, телефон: 960-220		0101000020E61000009E78CE1610665540C2BF081A33514C40
3288	5	54	52	31900	74657	\N	56.641495999999997	с. Турунтаево, Школьная, 4, здание администрации, телефон: 947-126		0101000020E6100000F5143944DC7E5540E5417A8A1C524C40
3281	5	54	52	31900	74657	\N	56.641495999999997	с. Турунтаево, Школьная, 4, здание администрации, телефон: 947-175		0101000020E6100000F5143944DC7E5540E5417A8A1C524C40
3355	5	54	52	48060	74487	\N	56.427349	с. Трубачево, ул. Центральная, 7, телефон: 38-137		0101000020E6100000C6FCDCD094465540397D3D5FB3364C40
3265	5	54	52	46254	74444	\N	56.844819999999999	с. Томское, Маяковского, 1, школа, телефон: 959-301		0101000020E6100000ADF886C267675540DC80CF0F236C4C40
3293	5	54	52	32419	74411	\N	56.379121106519101	с. Тахтамышево, Советская, 42, школа, телефон: 964-137	Россия, Томская область, Томский район, село Тахтамышево	0101000020E6100000D0B7054B75385540081D740987304C40
3280	5	54	52	46591	74802	\N	56.478228000000001	с. Сухоречье, Лесная, 34, здание администрации, телефон: 251-843		0101000020E61000007500C45DBD5D554008043A93363D4C40
3285	5	54	52	32087	74651	\N	56.706907999999999	д. Спасо-Яйское, Сибирская, 53, ООО «ПП Воронино», телефон: сот. 8-961-095-05-80		0101000020E6100000A64412BD8C875540F0A31AF67B5A4C40
3263	5	54	52	31056	74751	\N	56.336987000000001	п. Синий Утес, Парковая, 5, школа, телефон: 954-221		0101000020E61000000AF5F411F83A5540AD16D863222B4C40
3279	5	54	52	31837	74416	\N	56.615887000000001	с. Семилужки, Иркутский  тракт, 2, здание школы, телефон: 946-139		0101000020E6100000A6423C122F5755400A849D62D54E4C40
2821	5	54	52	60283	74290	\N	56.746958999999997	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"" п.Самусь, Ленина, 28, телефон: 904-793"	Россия, Томская область, Томский район, поселок Самусь	0101000020E6100000C51C041DAD2C5540F7393E5A9C5F4C40
3236	5	54	52	29586	74484	\N	56.503338999999997	с. Рыбалово, Коммунистическая, 9, телефон: 919-250		0101000020E6100000F98216123021554092E68F696D404C40
3233	5	54	52	29586	74484	\N	56.503338999999997	с. Рыбалово, Коммунистическая, 9, Дом культуры, телефон: 919-250		0101000020E6100000F98216123021554092E68F696D404C40
3290	5	54	52	46795	74600	\N	56.455005	д. Романовка, Новая, 7/1, административное здание, телефон: 946-577		0101000020E6100000744694F6067C55401C42959A3D3A4C40
3273	5	54	52	46440	\N	\N	56.624524000000001	п. Рассвет, 11, административное здание, телефон: 988-872		0101000020E6100000D31742CEFB4C554097C80567F04F4C40
3303	5	54	52	610	74409	\N	56.549610999999999	д. Поросино, Школьная, 2а, школа, телефон: 915-731		0101000020E6100000D1798D5DA2305540CC423BA759464C40
3283	5	54	52	32012	74650	\N	56.647830999999996	д. Подломск, Молодежная, 9, телефон: сот. 8-960-972-88-09		0101000020E61000000E2C47C840745540E02A4F20EC524C40
3249	5	54	52	45909	74731	\N	56.382820000000002	д. Плотниково, Рабочая, д.14, магазин, телефон: сот. 8-903-952-41-67		0101000020E6100000DBC2F352B14F55409B20EA3E00314C40
3250	5	54	52	45923	74800	\N	56.321410999999998	с. Петухово, Новостройка, 4а, Дом культуры, телефон: 960-418		0101000020E6100000D4BB783F6E5155408EC9E2FE23294C40
3304	5	54	52	60332	74740	\N	56.5389665260236	д. Петрово, Гагарина, 21, клуб, телефон: 917-513	Россия, Томская область, Томский район, село Петрово	0101000020E6100000D673D2FBC6345540C64FE3DEFC444C40
3286	5	54	52	46696	74804	\N	56.692334000000002	д. Перовка, Лесная, 2, ФАП, телефон: сот. 8-962-777-80-24		0101000020E610000027C286A7577E554056F487669E584C40
3262	5	54	52	6058	66444	\N	56.725293999999998	Томская область, Томский район, с.Октябрьское, ул.Железнодорожная 29а		0101000020E610000088B9A46ABB5B554015FE0C6FD65C4C40
3291	5	54	52	32353	74399	\N	56.489387000000001	Томская область, Томский район, с.Новорождественское, ул.Советская 56		0101000020E6100000257A19C572805540350BB43BA43E4C40
3278	5	54	52	46543	74594	\N	56.540222999999997	д. Новомихайловка, Центральная, д.49, к.2, ФАП, телефон: 253-551	Россия, Томская область, Томский район, село Новомихайловка	0101000020E61000005DC5E2378549554004C6FA0626454C40
3287	5	54	52	46730	74809	\N	56.711793999999998	с. Новоархангельское, Советская, 55, Дом культуры, телефон: 950-712		0101000020E610000011A8FE412479554098BED7101C5B4C40
3284	5	54	52	46667	66402	\N	56.563378	д. Нелюбино, Почтовая, 1, Дом культуры, телефон: 918-566		0101000020E61000007E37DDB24323554098A432C51C484C40
3243	5	54	52	45795	74447	\N	56.760919000000001	с. Наумовка, Советская, 7а, здание администрации, телефон: 969-339		0101000020E61000001C7DCC0704485540D8F335CB65614C40
3239	5	54	52	60296	74355	\N	56.692896782801597	с. Моряковский Затон, Советская, 27, телефон: 928-977	Россия, Томская область, Томский район, село Моряковский Затон	0101000020E610000076C6F7C5A52955408E3F51D9B0584C40
3238	5	54	52	60296	74355	\N	56.690855999999997	с. Моряковский Затон, Советская, 35, телефон: 927-395		0101000020E610000070B6B9313D295540681F2BF86D584C40
3225	5	54	52	60296	74355	\N	56.693408996726298	с. Моряковский Затон, Советская, 29, телефон: 927-655	Россия, Томская область, Томский район, село Моряковский Затон	0101000020E610000048C153C89529554044E048A0C1584C40
3271	5	54	52	46410	\N	\N	56.672992000000001	п. Молодежный, 2, здание Дома культуры, телефон: 921-510		0101000020E6100000791EDC9DB55455401D3C139A24564C40
3247	5	54	52	45862	74474	\N	56.441792	п. Мирный, Трудовая, 2, культурно-спортивный центр, телефон: 955-304		0101000020E610000032AF230ED947554035D1E7A38C384C40
3242	5	54	52	29900	74652	\N	56.360999999999997	с. Межениновка, Первомайская, 22, Дом культуры, библиотека, телефон: 969-732		0101000020E6100000A2D11DC4CE57554091ED7C3F352E4C40
3240	5	54	52	29900	74652	\N	56.360999999999997	с. Межениновка, Первомайская, 22 , Дом культуры, телефон: 969-732		0101000020E6100000A2D11DC4CE57554091ED7C3F352E4C40
3289	5	54	52	32280	74394	\N	56.591956000000003	Томская область, Томский район, с.Мазалово, ул.Г.Николаевой 12		0101000020E610000058CA32C4B1885540E355D636C54B4C40
3275	5	54	52	31640	74796	\N	56.486479000000003	Томская область, Томский район, д.Лязгино, ул.Центральная 19		0101000020E6100000E57CB1F7E24E55406C98A1F1443E4C40
3255	5	54	52	30656	74393	\N	56.358961000000001	с. Лучаново, Зеленая, 21а, детский сад, телефон: 962-146	Россия, Томская область, Томский район, село Лучаново	0101000020E6100000663387A4164455400DC51D6FF22D4C40
2708	5	54	52	60297	74374	\N	56.384344216122898	Томская область, город Томск. деревня Лоскутово, Ленина улица, 27А, телефон: 943-562	Россия, Томская область, Томский район, село Лоскутово	0101000020E6100000BC5CC47762455540F834272F32314C40
3234	5	54	52	45618	74655	\N	56.439923567396399	д. Лаврово, Центральная, 25, телефон: 252-293	Россия, Томская область, Томский район, село Лаврово	0101000020E6100000F030ED9BFB1A5540DD5CFC6D4F384C40
3297	5	54	52	222	65582	\N	56.216414	Томская область, Томский район, с.Курлек, ул.Трактовая 48а		0101000020E6100000E94317D4B7365540C2323674B31B4C40
3301	5	54	52	493	74805	\N	56.537000999999997	д. Кудринский Участок, Бодажкова, 6, ФАП, телефон: 918-249		0101000020E610000075E95F92CA2A5540AB75E272BC444C40
3276	5	54	52	60303	74464	\N	56.494023643436599	Томская область, Томский район, с.Корнилово, ул.Гагарина 33	Россия	0101000020E61000006C79E57ADB4A554035B8AD2D3C3F4C40
3272	5	54	52	31521	66627	\N	56.602417000000003	Томская область, Томский район, п.Копылово, ул.Новая 18		0101000020E610000083DA6FED44485540F8C610001C4D4C40
3264	5	54	52	31115	74581	\N	56.337332000000004	с. Коларово, Центральная, 12, Дом культуры, телефон: 954-316	Россия, Томская область, Томский район, село Коларово	0101000020E610000066666666663C554078F2E9B12D2B4C40
3237	5	54	52	29748	74725	\N	56.806953999999998	д. Козюлино, Центральная, 40, телефон: 275-132		0101000020E61000000AF83592042055402DB0C7444A674C40
3294	5	54	52	6401	66635	\N	56.415971999999996	Томская область, Томский район, п.Кисловка, ул.Мира 16		0101000020E6100000D235936FB63755409E060C923E354C40
3295	5	54	52	62	65570	\N	56.35136	с. Кафтанчиково, Коммунистическая, 86, здание администрации, телефон: 961-169		0101000020E6100000E1F1ED5D83375540B08F4E5DF92C4C40
3232	5	54	52	45562	74793	\N	56.488844999999998	д. Карбышево, Центральная, 25, телефон: 250-921	Россия, Томская область, Томский район, село Карбышево	0101000020E610000069ACFD9DED1C554014E81379923E4C40
3296	5	54	52	159	74511	\N	56.296625326837599	д. Кандинка, Советская, 11а, Дом культуры, телефон: 960-716	Россия, Томская область, Томский район, село Кандинка	0101000020E6100000227024D0603355408716D9CEF7254C40
3298	5	54	52	293	74503	\N	56.280431	Томская область, Томский район, с.Калтай, ул.Ленина 74		0101000020E610000023A46E675F3855406DE4BA29E5234C40
3266	5	54	52	31208	66397	\N	56.823262	с. Итатка, Гагарина, 1, здание администрации, телефон: 959-323		0101000020E61000002062838593665540100533A660694C40
3302	5	54	52	546	66446	\N	56.524228000000001	Томская область, Томский район, с.Зоркальцево, ул.Трактовая 29		0101000020E61000009DB81CAF402F5540E1D231E719434C40
3216	5	54	52	49559	74597	\N	56.588527546599401	д. Губино, Совхозная, 3, телефон: 916-267	Россия, Томская область, Томский район, село Губино	0101000020E610000004C93B8732285540E063B0E2544B4C40
2872	5	54	52	52199	74646	\N	57.097541	"Томская область, Муниципальное образование ""Асиновский район"", Новониколаевское сельское поселение, д.Гарь, Почтовая, 4, телефон: 57124"	Россия, Томская область, Томский район, село Гарь	0101000020E6100000344DD87E32515540738236397C8C4C40
3096	5	54	52	47537	74461	\N	56.341746999999998	село Вороново, Уткина, 17, телефон: 31169		0101000020E61000008A0629780A4E5540C8409E5DBE2B4C40
3277	5	54	52	46520	74442	\N	56.554786	д. Воронино, Центральная, д.74, Дом культуры, телефон: 950-300	Россия, Томская область, Томский район, село Воронино	0101000020E610000038BEF6CC92505540AB23473A03474C40
3259	5	54	52	46120	74803	\N	56.229270999999997	с. Вершинино, Советская, 55,  школа, телефон: 959-643		0101000020E61000007EFFE6C5893B5540EA758BC0581D4C40
3235	5	54	52	29676	74647	\N	56.430703999999999	д. Верхнее Сеченово, Ветеранов, 25-1, телефон: 252-291		0101000020E6100000E3C5C21039165540D120054F21374C40
3305	5	54	52	726	74666	\N	56.558506999999999	д. Борики, Школьная, 1, школа, телефон: 917-591		0101000020E6100000B3EDB4352232554025CB49287D474C40
3248	5	54	52	30286	\N	\N	56.417934000000002	д. Большое Протопопово, о/л «Восход», д.12, к. 31, комендантская, телефон: 955-138	Россия, Томская область, Томский район, село Бол. Протопопово	0101000020E610000091628044134C554078F17EDC7E354C40
3252	5	54	52	5981	65564	\N	56.364949000000003	с. Богашево, Советская, 6, здание администрации, телефон: 931-105		0101000020E6100000596C938AC64955409DDA19A6B62E4C40
3251	5	54	52	5981	65425	\N	56.364949000000003	Томская область, Томский район, с.Богашево, ул.Новостройка 1а		0101000020E6100000596C938AC64955409DDA19A6B62E4C40
3231	5	54	52	45548	74641	\N	56.487448030677101	д. Березкино, Сибирская, 25, телефон: 912-894	Россия, Томская область, Томский район, село Берёзкино	0101000020E610000033FB3C4679285540144031B2643E4C40
3254	5	54	52	46002	74810	\N	56.307955999999997	д. Белоусово, Мира, 8, клуб-филиал, телефон: 252-642		0101000020E6100000200DA7CCCD4B5540B14D2A1A6B274C40
3101	5	54	52	23476	74708	\N	56.267842646934497	село Батурино, Школьная, 1, телефон: 37130	Россия, Томская область, Томский район, село Батурино	0101000020E6100000DC7F643A743E554034BBEEAD48224C40
3274	5	54	52	31608	74738	\N	56.442343999999999	д. Аркашево, Озерная, 2/2, мед.пункт, каб. фельдшера, телефон: 252-174		0101000020E6100000EA2285B2F050554079CA6ABA9E384C40
2976	5	54	52	31232	74498	\N	56.742649	село Александровское, мкр.Казахстан, 16, телефон: 2-29-61		0101000020E6100000D238D4EFC25855401CB4571F0F5F4C40
2966	5	54	52	31232	74322	\N	56.742649	село Александровское, Советская, 32, телефон: 2-10-73		0101000020E6100000D238D4EFC25855401CB4571F0F5F4C40
3267	5	54	52	31232	74440	\N	56.742649	с. Александровское, Пионерская, 2, здание администрации, библиотека, телефон: 960-045		0101000020E6100000D238D4EFC25855401CB4571F0F5F4C40
2975	5	54	52	31232	74304	\N	56.742649	село Александровское, Ленина, 9, телефон: 2-16-48		0101000020E6100000D238D4EFC25855401CB4571F0F5F4C40
3300	5	54	52	60348	74827	\N	56.372695655439699	п. 86-й квартал, Школьная, 31а, школа, телефон: 251-788	Россия, Томская область, Томский район, село 86-й Квартал	0101000020E61000008C0FB3976D235540CDACA580B42F4C40
3217	5	54	1384	28892	74640	\N	57.060504000000002	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, п. Четь-Конторка, МОУ ""Четь-Конторская ООШ"", Садовая, 2/1, телефон: 35-132"		0101000020E61000007FA1478C9E0756407BA35698BE874C40
3230	5	54	1384	60326	74654	\N	57.045708781203203	"Томская область, Муниципальное образование ""Тегульдетский район"", Черноярское сельское поселение, п. Черный Яр, п. Орловка, МОУ ""Черноярская СОШ"", Щитовая, 6, телефон: 31-1-22"	Россия, Томская область, Тегульдетский район, село Чёрный Яр	0101000020E6100000BA66F2CD36D455400211E2CAD9854C40
3218	5	54	1384	28911	74642	\N	57.425055	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, п. Центрополигон, Центрополигонский библиотечно-досуговый центр, Советская, 4, телефон: 2-20-69"		0101000020E6100000FCFECD8B131356402A00C63368B64C40
3222	5	54	1384	28977	66394	\N	57.305779000000001	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, с. Тегульдет, РЦТ и Д , Садовая, 12, телефон: 2-13-55"		0101000020E6100000417FA1478C0A5640DC662AC423A74C40
3220	5	54	1384	28977	74586	\N	57.305779000000001	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, с. Тегульдет, Южный филиал ГУП ТО ""Областное ДРСУ"", Пушкина, 34, телефон: 2-19-31"		0101000020E6100000417FA1478C0A5640DC662AC423A74C40
3219	5	54	1384	28977	74645	\N	57.302155635742999	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, с. Тегульдет, ОГКУ ""Томсклес"" филиал ""Тегульдетское лесничество"", Парковая, 52, телефон: 2-23-17"		0101000020E610000056F146E69109564024253D0CADA64C40
3223	5	54	1384	28977	66395	\N	57.305779000000001	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, с. Тегульдет, ОГОУ НПО ""ПУ-36"", Октябрьская, 37, телефон: 2-21-16"		0101000020E6100000417FA1478C0A5640DC662AC423A74C40
3221	5	54	1384	28977	74726	\N	57.305779000000001	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, с. Тегульдет, МУЗ  Тегульдетская ""ЦРБ"", Ленина, 35, телефон: 2-18-99"		0101000020E6100000417FA1478C0A5640DC662AC423A74C40
3215	5	54	1384	28778	74648	\N	57.078055999999997	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, п. Покровский Яр, Покровоярский библиотечно-досуговый центр, Лесная, 3, телефон: 36-1-22"		0101000020E61000008F6CAE9AE7115640D7A02FBDFD894C40
3229	5	54	1384	15157	74660	\N	57.475762000000003	"Томская область, Муниципальное образование ""Тегульдетский район"", Белоярское сельское поселение, д. Озерное, ФАП, Озерская, 8/1, телефон: 2-36-80"	Россия, Томская область, Тегульдетский район, село Озерное	0101000020E610000059897956D2285640FC56EBC4E5BC4C40
3228	5	54	1384	52803	74700	\N	57.421405	"Томская область, Муниципальное образование ""Тегульдетский район"", Белоярское сельское поселение, д. Новошумилово, Новошумиловский библиотечно-досуговый центр, Новая, 17, телефон: 2-36-44"		0101000020E6100000232F6B628120564079AF5A99F0B54C40
3214	5	54	1384	52781	74795	\N	57.348984999999999	"Томская область, Муниципальное образование ""Тегульдетский район"",  Тегульдетское сельское поселение, д. Куяновская Гарь, МОУ ""Куянгарская НОШ"" , Куяновская, 4, телефон: 2-36-45"		0101000020E610000089F02F82C6165640B4E55C8AABAC4C40
3224	5	54	1384	47501	74431	\N	57.228594121470998	"Томская область, Муниципальное образование ""Тегульдетский район"", Берегаевское сельское поселение, п. Берегаево, п. Красный Яр, МОУ ""Берегаевская СОШ"", Ленинская, 17, телефон: 33-2-36"	Россия, Томская область, Тегульдетский район, село Красный Яр	0101000020E6100000A872DA5372E75540EA077591429D4C40
3095	5	54	1384	47501	74703	\N	57.229407999999999	деревня Красный Яр, Коммунистическая, 40, телефон: 38441		0101000020E6100000A19E3E027FE755406BB8C83D5D9D4C40
3226	5	54	1384	52797	74566	\N	57.105426999999999	"Томская область, Муниципальное образование ""Тегульдетский район"", Берегаевское сельское поселение, д. Красная Горка, Красногорский ДТ и Т, Советская, 31, телефон: 32-1-38"		0101000020E61000006F0ED76A0FCF5540C58EC6A17E8D4C40
3010	5	54	1384	18749	74494	\N	57.496772999999997	Томская область, Верхнекетский район, р.п. Белый Яр, Чкалова, 8, телефон: 2-10-50		0101000020E610000014E81379923056409544F64196BF4C40
3227	5	54	1384	18749	74794	\N	57.496772999999997	"Томская область, Муниципальное образование ""Тегульдетский район"", Белоярское сельское поселение, п. Белый Яр, Администрация , Центральная, 2, телефон: 34-1-15"		0101000020E610000014E81379923056409544F64196BF4C40
3213	5	54	1384	52773	74722	\N	57.243465999999998	"Томская область, Муниципальное образование ""Тегульдетский район"", Тегульдетское сельское поселение, д.Байгалы, ФАП,  Байгалинская, 15, телефон: 2-12-91"		0101000020E61000008B4F01309EF855400ED8D5E4299F4C40
3188	5	54	1813	52709	\N	\N	57.561297000000003	"Томская область, Муниципальное образование ""Первомайский район"", Комсомольское сельское поселение поселок Францево, Здание ФАП, телефон: 382(45)2-48-68"		0101000020E6100000988A8D791D9A5540E52B8194D8C74C40
3194	5	54	1813	52728	\N	\N	57.138554999999997	"Томская область, Муниципальное образование ""Первомайский район"", Сергеевское сельское поселение деревня Успенка, здание медпункта, 38 кв. 2, телефон: 382(45)32-1-62"	Россия, Томская область, Первомайский район, село Успенка	0101000020E61000002593533BC389554040D9942BBC914C40
3181	5	54	1813	52691	74335	\N	57.710175999999997	"Томская область, Муниципальное образование ""Первомайский район"", Улу-Юльское сельское поселение поселок Улу-Юл, Комарова  (здание дома культуры), 26, телефон: 382(45)44-1-48"	Россия, Томская область, Первомайский район, село Улу-Юл	0101000020E6100000C76471FF91725540B933130CE7DA4C40
3184	5	54	1813	52691	74799	\N	57.712289537579899	"Томская область, Муниципальное образование ""Первомайский район"", Улу-Юльское сельское поселение, Дорожная  (здание школы), 1, телефон: 382(45)24-3-99"	Россия, Томская область, Первомайский район, село Улу-Юл	0101000020E610000018EB1B98DC72554049A297512CDB4C40
3210	5	54	1813	60354	74836	\N	56.933779000000001	"Томская область, Муниципальное образование ""Первомайский район"", Куяновское сельское поселение село Уйданово, Центральная   (здание дома культуры), 37, телефон: 382(45)33-2-14"		0101000020E6100000878A71FE26A355408658FD1186774C40
3191	5	54	1813	52720	\N	\N	57.299779000000001	"Томская область, Муниципальное образование ""Первомайский район"", Сергеевское сельское поселение поселок Узень, Дом культуры, телефон: 382(45)31-1-44"		0101000020E610000019E42EC2148D5540888384285FA64C40
3205	5	54	1813	52757	74724	\N	57.132925999999998	"Томская область, Муниципальное образование ""Первомайский район"", Новомариинское сельское поселение деревня Туендат, Шамского  (здание дома культуры), 26, телефон: 382(45)38-1-45"	Россия, Томская область, Первомайский район, село Туендат	0101000020E6100000EE98BA2BBB995540E0641BB803914C40
3202	5	54	1813	60356	74838	\N	57.025948999999997	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение деревня Торбеево, Советская  (здание дома культуры), 38а, телефон: 382(45)36-2-79"	Россия, Томская область, Первомайский район, село Торбеево	0101000020E610000097361C9606965540942EFD4B52834C40
3189	5	54	1813	60313	74544	\N	57.272872	"Томская область, Муниципальное образование ""Первомайский район"", Сергеевское сельское поселение село Сергеево, Школьная  (здание дома культуры), 3, телефон: 382(45)43-2-25"	Россия, Томская область, Первомайский район, село Сергеево	0101000020E6100000D52137C30D8655403FFF3D78EDA24C40
3190	5	54	1813	52717	\N	\N	57.312883609384002	"Томская область, Муниципальное образование ""Первомайский район"", Сергеевское сельское поселение деревня Сахалинка, Дом культуры, телефон: 382(45)43-8-16"	Россия, Томская область, Первомайский район, село Сахалинка	0101000020E61000006EFAB31F2983554088B839950CA84C40
3197	5	54	1813	52732	74311	\N	57.077714	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение село Первомайское, Ленинская  (контора ДРСУ), 108, телефон: 382(45)2-26-08"	Россия, Томская область, Первомайский район, село Первомайское	0101000020E6100000F04DD367078F55407E384888F2894C40
3195	5	54	1813	52732	74327	\N	57.077714	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение село Первомайское, Ленинская  (здание районного Дома культуры), 33, телефон: 382(45)2-17-34"	Россия, Томская область, Первомайский район, село Первомайское	0101000020E6100000F04DD367078F55407E384888F2894C40
3182	5	54	1813	52732	76183	\N	57.084738150081897	"Томская область, Муниципальное образование ""Первомайский район"", Улу-Юльское сельское поселение поселок Аргат-Юл, Комсомольская  (здание школы), 33, телефон: 382(45)3-03-32"		0101000020E6100000E7E44526E08F55403E5DDDB1D88A4C40
3196	5	54	1813	52732	74334	\N	57.077714	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение село Первомайское, Больничная   (здание Асиновского межрайонного Узла связи), 32, телефон: 382(45)2-18-80"	Россия, Томская область, Первомайский район, село Первомайское	0101000020E6100000F04DD367078F55407E384888F2894C40
3206	5	54	1813	60309	74534	\N	57.221508999999998	"Томская область, Муниципальное образование ""Первомайский район"", Новомариинское сельское поселение поселок Орехово, Ленина  (здание дома культуры), 9, телефон: 382(45)34-136"	Россия, Томская область, Первомайский район, село Орехово	0101000020E61000001A8A3BDEE4AB554084622B685A9C4C40
3200	5	54	1813	60321	74607	\N	57.109313	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение поселок Новый, Клубная  (здание дома культуры), 2, телефон: 382(45)39-1-45"	Россия, Томская область, Первомайский район, село Новый	0101000020E6100000A85489B2B78C55408A03E8F7FD8D4C40
2898	5	54	7205	60334	74754	\N	57.493671999999997	поселок Рогалево, Рабочая, дом 7, телефон: 89618880836		0101000020E6100000C6C4E6E3DAE65340B779E3A430BF4C40
3173	5	54	7205	52663	74670	\N	58.703969000000001	Прокоп, Центральная, 24, телефон: 39645		0101000020E61000008ACC5CE0F2565440EC32FCA71B5A4D40
3204	5	54	1813	60362	74854	\N	57.137656049337401	"Томская область, Муниципальное образование ""Первомайский район"", Новомариинское сельское поселение село Новомариинка, Центральная  (здание дома культуры), 42, телефон: 382(45)35-1-49"	Россия, Томская область, Первомайский район, село Новомариинка	0101000020E61000007CD2890453A05540910C39B69E914C40
3212	5	54	1813	60350	74833	\N	57.020040000000002	"Томская область, Муниципальное образование ""Первомайский район"", Куяновское сельское поселение деревня Малиновка, Центральная  (здание медпункта), 16, телефон: нет"	Россия, Томская область, Первомайский район, село Малиновка	0101000020E61000009DA04D0E9FB45540514EB4AB90824C40
3203	5	54	1813	60347	74826	\N	57.130596581535201	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение деревня Ломовицк, Центральная  (здание дома культуры), 13, телефон: 382(45)2-24-14"	Россия, Томская область, Первомайский район, село Ломовицк 2	0101000020E6100000C022BF7E8893554055FA0967B7904C40
3208	5	54	1813	60345	74822	\N	56.947791994203797	"Томская область, Муниципальное образование ""Первомайский район"", Куяновское сельское поселение село Куяново, Центральная  (здание дома культуры), 18, телефон: 382(45)33-1-98"	Россия, Томская область, Первомайский район, село Куяново	0101000020E61000002635B401D89D554089B48D3F51794C40
3201	5	54	1813	52748	74644	\N	57.042180000000002	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение деревня Крутоложное, ул. 40 Лет Победы  (здание дома культуры), 28 а, телефон: 382(45)24-5-98"		0101000020E61000003F027FF8F9945540CC457C2766854C40
3186	5	54	1813	27416	74533	\N	57.408366000000001	"Томская область, Муниципальное образование ""Первомайский район"", Комсомольское сельское поселение село Комсомольск, Первомайская  (здание школы), 10а, телефон: 382(45)42-1-18"	Россия, Томская область, Первомайский район, поселок Комсомольск	0101000020E6100000D4D4B2B5BE80554030664B5645B44C40
3185	5	54	1813	27416	74486	\N	57.408366000000001	Томская область, Первомайский район, с.Комсомольск, ул.Первомайская 11а		0101000020E6100000D4D4B2B5BE80554030664B5645B44C40
3209	5	54	1813	60351	74832	\N	56.988934	"Томская область, Муниципальное образование ""Первомайский район"", Куяновское сельское поселение деревня Калмаки, Центральная  (здание школы), 14, телефон: 382(45)45-3-49"	Россия, Томская область, Первомайский район, село Калмаки	0101000020E610000001DBC1887D9B554084F3A963957E4C40
3268	5	54	1813	46332	74801	\N	57.180261000000002	п. Заречный, Светлая, 9, ФАП, телефон: 921-383		0101000020E6100000234DBC033C8B554044DFDDCA12974C40
3193	5	54	1813	60357	74840	\N	57.158234999999998	"Томская область, Муниципальное образование ""Первомайский район"", Сергеевское сельское поселение село Ежи, Советская  (здание дома культуры), 23, телефон: 382(45)32-1-47"	Россия, Томская область, Первомайский район, село Ежи	0101000020E61000009198A0866F875540910A630B41944C40
3192	5	54	1813	60343	\N	\N	57.204126107909801	"Томская область, Муниципальное образование ""Первомайский район"", Сергеевское сельское поселение деревня Вознесенка, Дом культуры, телефон: 382(45)43-7-20"		0101000020E61000003CF9F4D896845540B421FFCC209A4C40
3211	5	54	1813	60368	74888	\N	57.007333000000003	"Томская область, Муниципальное образование ""Первомайский район"", Куяновское сельское поселение деревня Березовка, Центральная  (здание дома культуры), 1, телефон: 382(45)37-2-16"	Россия, Томская область, Первомайский район, село Берёзовка	0101000020E61000004C16F71F99B055403E97A949F0804C40
3199	5	54	1813	60312	74537	\N	57.051443999999996	"Томская область, Муниципальное образование ""Первомайский район"", Первомайское сельское поселение поселок Беляй, Зеленая  (здание дома культуры), 1, телефон: 382(45)41-1-79, 41-1-33"	Россия, Томская область, Первомайский район, село Беляй	0101000020E6100000FE7BF0DAA5905540A7C98CB795864C40
3187	5	54	1813	52704	\N	\N	57.415536000000003	"Томская область, Муниципальное образование ""Первомайский район"", Комсомольское сельское поселение деревня Балагачево, здание ФАП, телефон: 382(45)42-4-10"		0101000020E61000007061DD7877835540C4279D4830B54C40
3183	5	54	1813	60355	74837	\N	57.613737999999998	"Томская область, Муниципальное образование ""Первомайский район"", Улу-Юльское сельское поселение село Альмяково, Советская  (здание Администрации сельского поселения), 32, телефон: 382(45)30-5-19"	Россия, Томская область, Первомайский район, село Альмяково	0101000020E610000093A98251496C5540FE277FF78ECE4C40
3180	5	54	7205	60307	74509	\N	58.932504071363503	Шпалозавод, Центральная, 9, телефон: 39342	Россия, Томская область, Парабельский район, поселок Шпалозавод	0101000020E6100000C9224DBC03645440D1B1834A5C774D40
3178	5	54	7205	52675	74546	\N	58.049669000000002	Усть-Чузик, Набережная, 4, телефон: 27806		0101000020E61000006281AFE8D62554400150C58D5B064D40
3177	5	54	7205	60323	74615	\N	58.708289004975498	Толмачево, Молодёжная, 1а, телефон: 22036	Россия, Томская область, Парабельский район, село Толмачево	0101000020E6100000C9AB730CC85B5440EB8EC536A95A4D40
3176	5	54	7205	52671	74601	\N	58.288707000000002	Тарск, Школьная, 3, телефон: 27797		0101000020E610000012312592E82554402A90D959F4244D40
3175	5	54	7205	52667	74749	\N	58.979857000000003	Талиновка, Центральная, 5, телефон: 27630		0101000020E610000044DD0720B5655440DBE044F46B7D4D40
3174	5	54	7205	60358	74842	\N	58.134068999999997	Старица, Советская, 56, телефон: 34241	Россия, Томская область, Парабельский район, село Старица	0101000020E61000007FD93D79582554402634492C29114D40
3167	5	54	7205	52645	65285	\N	58.714565999999998	Парабель, Советская, 21, телефон: 21189		0101000020E61000008F54DFF945605440B16A10E6765B4D40
3170	5	54	7205	52645	65281	\N	58.714565999999998	Парабель, Некрасова, 1а, телефон: 22913		0101000020E61000008F54DFF945605440B16A10E6765B4D40
3166	5	54	7205	60322	74612	\N	58.633714159016797	Новосельцево, Лесная, 1а, телефон: 36152	Россия, Томская область, Парабельский район, село Новосельцево	0101000020E6100000BDFBE3BD6A6C54403882548A1D514D40
3165	5	54	7205	60338	74792	\N	58.209827970548403	Новиково, Совхозная, 3, телефон: 27780	Россия, Томская область, Парабельский район	0101000020E6100000020F0C207C2854407EE4D6A4DB1A4D40
3163	5	54	7205	52638	74603	\N	58.678379	Нельмач, Сибирская, 22, телефон: 37181		0101000020E61000000E828E56B546544087A5811FD5564D40
3162	5	54	7205	52632	74485	\N	58.923755999999997	Нарым, Куйбышева, 16, телефон: 33172		0101000020E61000001405FA449E665440ECBDF8A23D764D40
3164	5	54	7205	60366	74870	\N	58.659165000000002	Нестерово, Трудовая, 20, телефон: 36516	Россия, Томская область, Парабельский район, деревня Малое Нестерово	0101000020E610000031EC3026FD6454407CD5CA845F544D40
2897	5	54	7205	60331	74729	\N	57.558732999999997	п. Лушниково, Геологическая, дом 33, телефон: 34-506	Россия, Томская область, Парабельский район, село Лушниково	0101000020E610000056F146E691DB534015191D9084C74C40
3161	5	54	7205	60327	74683	\N	58.900538727413497	Луговское, Молодежная, 14, телефон: 33267	Россия, Томская область, Парабельский район, деревня Луговское	0101000020E61000004C6C3EAE0D695440E3E2A8DC44734D40
3159	5	54	7205	60300	74436	\N	58.674852516531203	Кирзавод, Центральная, 40, телефон: 22633		0101000020E61000005A66118AAD5F5440C24D469561564D40
2895	5	54	7205	60340	74808	\N	57.574427929475704	МО "г.Кедровый", п.Останино, ул.Лесная 3		0101000020E6100000695721E527DE53400EF450DB86C94C40
3158	5	54	7205	60337	74772	\N	58.6755	Заводской, 60 Лет СССР, 17, телефон: 39166	Россия, Томская область, Парабельский район	0101000020E61000009D9B36E3345554405839B4C876564D40
3179	5	54	7205	52684	74564	\N	58.565181000000003	Чигара, Красноармейская, 19, телефон: 27679		0101000020E610000045BB0A293F74544009A9DBD957484D40
3156	5	54	7205	60316	74574	\N	58.831249057673098	Алатаево, Советская, 15, телефон: 27935	Россия, Томская область, Парабельский район, село Алатаево	0101000020E610000085E97B0DC170544096EA025E666A4D40
3139	5	54	807	25289	74787	\N	57.703065631909297	Нижняя Фёдоровка, Зеленая, 15,	Россия, Томская область, Молчановский район, село Фёдоровка (Нижняя Фёдоровка)	0101000020E610000031276893C3F65440FB761211FED94C40
2489	5	54	807	25534	12281	\N	57.6193609635041	Тунгусово, Школьная, 2, телефон: 35552	Россия, Томская область, Молчановский район, село Тунгусово	0101000020E61000008411FB0450DF54407CB5A33847CF4C40
2621	5	54	807	25534	74687	\N	57.619407000000002	Тунгусово, Центральная, 23,		0101000020E6100000AAF1D24D62DF5440EDF483BA48CF4C40
3144	5	54	807	25534	74767	\N	57.619407000000002	Тунгусово, Кнакиса, 5, телефон: 35401		0101000020E6100000AAF1D24D62DF5440EDF483BA48CF4C40
3154	5	54	807	5854	74788	\N	57.790692999999997	Томская область, Молчановский район, с.Сулзат, ул.Клубная 1		0101000020E610000072A8DF85ADFA54408B16A06D35E54C40
3155	5	54	807	26064	74468	\N	57.868468999999997	Суйга, Комарова, 29, телефон: 34423		0101000020E61000008962F206982E55407F4B00FE29EF4C40
3141	5	54	807	48367	74741	\N	57.496679661029603	Соколовка, Центральная, 53, телефон: 36526	Россия, Томская область, Молчановский район, село Соколовка	0101000020E61000001A6D5512D9F45440E449D23593BF4C40
3146	5	54	807	5723	74739	\N	57.712719999999997	Томская область, Молчановский район, с.Сарафановка, ул.Школьная 38		0101000020E6100000EAEBF99AE5DC5440419AB1683ADB4C40
3018	5	54	807	52394	74427	\N	58.029544999999999	Томская область, Верхнекетский район, п. Сайга, Молодогвардейская, 3, телефон: 3-61-40		0101000020E6100000C154336B295B554052616C21C8034D40
3148	5	54	807	25683	74489	\N	57.68862	Нарга, Свердлова, 9, телефон: 32475	Россия, Томская область, Молчановский район, поселок Нарга (Новостройка)	0101000020E6100000C5E3A25A44E354408EAF3DB324D84C40
3147	5	54	807	25683	74389	\N	57.68862	Нарга, Карла Маркса, 41, телефон: 32495	Россия, Томская область, Молчановский район, поселок Нарга (Новостройка)	0101000020E6100000C5E3A25A44E354408EAF3DB324D84C40
3132	5	54	807	24957	74432	\N	57.589292	Томская область, Молчановский раойн, с.Молчаново, ул.Советская 13		0101000020E61000006C7BBB2539F15440B0E595EB6DCB4C40
3138	5	54	807	24957	74467	\N	57.589292	Молчаново, Комарова, 2а, телефон: 21784		0101000020E61000006C7BBB2539F15440B0E595EB6DCB4C40
3136	5	54	807	24957	74472	\N	57.583950587407301	Молчаново, Западная, 1а, телефон: 21111	Россия, Томская область, Молчановский район, село Молчаново	0101000020E610000069519FE40EF15440B6BB07E8BECA4C40
3133	5	54	807	24957	74448	\N	57.589292	Молчаново, Димтрова, 40, телефон: 23055		0101000020E61000006C7BBB2539F15440B0E595EB6DCB4C40
3135	5	54	807	24957	74465	\N	57.589292	Молчаново, Димитрова, 78, телефон: 21365		0101000020E61000006C7BBB2539F15440B0E595EB6DCB4C40
3134	5	54	807	24957	74465	\N	57.589292	Молчаново, Димитрова, 71, строение 2, телефон: 21172		0101000020E61000006C7BBB2539F15440B0E595EB6DCB4C40
3137	5	54	807	24957	74469	\N	57.589292	Молчаново, Валикова, 17а, телефон: 21868	Россия, Томская область, Молчановский район, село Молчаново	0101000020E61000006C7BBB2539F15440B0E595EB6DCB4C40
3151	5	54	807	60311	74610	\N	57.714119412136199	Могочино, Октябрьская, 10, телефон: 33470	Россия, Томская область, Молчановский район, поселок Могочин	0101000020E6100000C49448A297E45440E2395B4068DB4C40
3150	5	54	807	60311	74523	\N	57.712184565493999	Могочино, Октябрьская, 5, телефон: 33496	Россия, Томская область, Молчановский район, поселок Могочин	0101000020E6100000EB39E97DE3E55440D3D9C9E028DB4C40
3152	5	54	807	60311	74525	\N	57.713566	Могочино, Калинина, 33, телефон: 33467	Россия, Томская область, Молчановский район, поселок Могочин	0101000020E61000003B394371C7E45440CEC4742156DB4C40
3149	5	54	807	60311	74547	\N	57.710720000000002	Могочино, пер. Воказальный, 10, телефон: 33111	Россия, Томская область, Молчановский район, поселок Могочин	0101000020E610000077BF0AF0DDE454407B4E7ADFF8DA4C40
3140	5	54	807	48362	74770	\N	57.636947999999997	Майково, Школьная, 13, телефон: 23144		0101000020E6100000B58AFED0CCE8544055A0168387D14C40
3127	5	54	807	48088	74782	\N	57.512957	Колбинка, Мира, 20, телефон: 37454		0101000020E61000004146408523DB54408CA03193A8C14C40
3153	5	54	807	5797	74721	\N	57.741914999999999	Томская область, Молчановский район, с.Игреково, ул.Центральная 24/1		0101000020E61000001B12F758FAF25440B7B41A12F7DE4C40
3142	5	54	807	48388	74572	\N	57.533323000000003	Гришино, Луговая, 30,		0101000020E6100000CE37A27BD6E65440319A95ED43C44C40
3145	5	54	807	25592	74789	\N	57.625557000000001	Верхняя Фёдоровка, Центральная, 14-1, телефон: 37365		0101000020E61000003E5A9C31CCE354405664744012D04C40
3121	5	54	765	24463	74639	\N	57.135987243356503	"Томская область, Муниципальное образование ""Кривошеинский район"", д. Рыбалово, Колхозная, 35А, телефон: 44365"	Россия, Томская область, Кривошеинский район, село Рыбалово	0101000020E6100000013274ECA000554030D7A20568914C40
3114	5	54	765	24089	74783	\N	57.23218	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Пудовка, Центральная, 64, телефон: 46431"		0101000020E6100000DB334B02D4EB544084640113B89D4C40
3122	5	54	765	24507	74719	\N	57.191211000000003	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Петровка, Комсомольская, 12, телефон: 44416"		0101000020E6100000314278B471FB544057D11F9A79984C40
3118	5	54	765	24319	74713	\N	57.120601999999998	"Томская область, Муниципальное образование ""Кривошеинский район"", д. Новониколаевка, Центральная, 28, телефон: 34124"		0101000020E6100000B343FCC396F9544085EAE6E26F8F4C40
3113	5	54	765	24057	74748	\N	57.314996000000001	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Новокривошеино, Школьная, 2, телефон: 47417"		0101000020E61000009E62D520CCF25440772FF7C951A84C40
3112	5	54	765	5563	74557	\N	57.408807000000003	Томская область, Кривошеинский район, с.Новоисламбуль, ул.Светлая 36		0101000020E61000000DE36E10ADF254401DB0ABC953B44C40
3125	5	54	765	24663	74571	\N	57.193367000000002	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Никольское, пер. Центральный, 6, телефон: 34168"		0101000020E610000049641F64591755401590F63FC0984C40
3074	5	54	765	24171	74558	\N	57.365012	"Томская область, Муниципальное образование ""Кожевниковский район"", Малиновское сельское поселение  с. Малиновка, Школьная, 13, телефон: 53105"		0101000020E6100000C2853C821BDF5440E35295B6B8AE4C40
3270	5	54	765	24171	74337	\N	57.365012	с. Малиновка, Чулымская, 30, здание администрации, библиотек, телефон: 920-244		0101000020E6100000C2853C821BDF5440E35295B6B8AE4C40
3269	5	54	765	24171	74337	\N	57.365012	с. Малиновка, Чулымская, 30, здание администрации, телефон: 920-152		0101000020E6100000C2853C821BDF5440E35295B6B8AE4C40
3115	5	54	765	24171	74636	\N	57.365012	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Малиновка, Рабочая, 22, телефон: 21237"		0101000020E6100000C2853C821BDF5440E35295B6B8AE4C40
3104	5	54	765	23689	74519	\N	57.346966663616399	"Томская область, Муниципальное образование ""Кривошеинский район"", Кривошеинское сельское поселение, Ленина, 30, телефон: 21060"	Россия, Томская область, Кривошеинский район, село Кривошеино	0101000020E61000007670B03731FB544047E5266A69AC4C40
3107	5	54	765	23689	74502	\N	57.341783	Томская область, Кривошеинский район, с.Кривошеино, ул. Октябрьская 24		0101000020E61000003AE7A7380EFB544015AA9B8BBFAB4C40
3109	5	54	765	23689	74463	\N	57.341783	Томская область, Кривошеинский район, с.Кривошеино, ул.Ленина 9		0101000020E61000003AE7A7380EFB544015AA9B8BBFAB4C40
3105	5	54	765	23689	74779	\N	57.341783	Томская область, Кривошеинский район, с.Кривошеино, ул.Коммунистическая 43		0101000020E61000003AE7A7380EFB544015AA9B8BBFAB4C40
3106	5	54	765	23689	74527	\N	57.343625650894801	"Томская область, Муниципальное образование ""Кривошеинский район"", Кривошеинское сельское поселение, Зеленая, 37А, телефон: 21168"		0101000020E61000004C8C65FA25FB54401407D0EFFBAB4C40
3110	5	54	765	23689	74513	\N	57.344368124540203	"Томская область, Муниципальное образование ""Кривошеинский район"", Кривошеинское сельское поселение, Заводская, 14, телефон: 22847"	Россия, Томская область, Кривошеинский район, село Кривошеино	0101000020E6100000728BF9B9A1FB5440FCE4284014AC4C40
3130	5	54	765	24784	74505	\N	57.139688	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Красный Яр, Школьная, 1, телефон: 31437"		0101000020E610000034F6251B0F21554063D2DF4BE1914C40
3128	5	54	765	24784	74443	\N	57.139688	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Красный Яр, Советская, 19, телефон: 31451"		0101000020E610000034F6251B0F21554063D2DF4BE1914C40
3129	5	54	765	24784	74435	\N	57.139688	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Красный Яр, пер. Осиновский, 1, телефон: 31436"		0101000020E610000034F6251B0F21554063D2DF4BE1914C40
3126	5	54	765	24698	74575	\N	57.066347999999998	"Томская область, Муниципальное образование ""Кривошеинский район"", д. Карнаухово, Центральная, 26, телефон: 34180"		0101000020E6100000BB287AE063195540D7135D177E884C40
3120	5	54	765	24400	74786	\N	57.159297000000002	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Иштан, Школьная, 1, телефон: 43546"		0101000020E610000047E350BF0B085540EBAC16D863944C40
3111	5	54	765	5530	74710	\N	57.401097999999998	Томская область, Кривошеинский район, с.Жуково, ул.Центральная 21	Россия, Томская область, Кривошеинский район, село Жуково	0101000020E6100000A6F10BAF24FC5440D93EE42D57B34C40
3123	5	54	765	24558	74568	\N	57.296711000000002	"Томская область, Муниципальное образование ""Кривошеинский район"", д. Елизарьево, Советская, 22,"		0101000020E61000006A12BC218DFD544086AE44A0FAA54C40
2979	5	54	694	17401	74771	\N	56.952342999999999	д.Полынянка, Мира, 18, телефон: 22683		0101000020E61000005E2D776682A054408AC91B60E6794C40
3124	5	54	765	24606	74712	\N	57.184173000000001	"Томская область, Муниципальное образование ""Кривошеинский район"", д. Егорово, Центральная, 4, телефон: 44427"		0101000020E610000062DA37F75703554032E719FB92974C40
3116	5	54	765	24180	74490	\N	57.096640999999998	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Володино, Советская, 31, телефон: 45433"		0101000020E61000001D588E9081F95440F33977BB5E8C4C40
3117	5	54	765	24180	74570	\N	57.096640999999998	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Володино, Коммунистическая, 39, телефон: 45441"		0101000020E61000001D588E9081F95440F33977BB5E8C4C40
3131	5	54	765	24947	74728	\N	57.081158000000002	"Томская область, Муниципальное образование ""Кривошеинский район"", д. Вознесенка, Центральная, 27, телефон: 34070"		0101000020E610000076E09C11A5E8544086E7A562638A4C40
3119	5	54	765	24348	74780	\N	57.174674000000003	"Томская область, Муниципальное образование ""Кривошеинский район"", с. Белосток, Школьная, 35, телефон: 34181"		0101000020E6100000A9A10DC006EA544013BBB6B75B964C40
2948	5	54	7144	52297	74669	\N	58.443769000000003	"Томская область, Муниципальное образование ""Колпашевский район"", д.Юдино, ул.Совхозная, 14, телефон: 99231"		0101000020E6100000DC8310902FF4544044FD2E6CCD384D40
2944	5	54	7144	52289	74632	\N	58.281128000000002	"Томская область, Муниципальное образование ""Колпашевский район"", д.Чугунка, ул.Центральная, 43, телефон: 47158"	Россия, Томская область, Колпашевский район, деревня Чугунка	0101000020E6100000FB95CE8767C55440B5FE9600FC234D40
2932	5	54	7144	52271	66609	\N	58.058535999999997	"Томская область, Муниципальное образование ""Колпашевский район"", с.Чажемто, ул.Фестивальная, 4, телефон: 21190"		0101000020E61000008BFD65F7E4B45440BFD18E1B7E074D40
2936	5	54	7144	52271	74424	\N	58.058535999999997	"Томская область, Муниципальное образование ""Колпашевский район"", с.Чажемто, ул.Магистральная, 4, телефон: 21263"	Россия, Томская область, Р398	0101000020E61000008BFD65F7E4B45440BFD18E1B7E074D40
2940	5	54	7144	52282	74690	\N	58.268974999999998	"Томская область, Муниципальное образование ""Колпашевский район"", д.Усть-Чая, ул.Кооперативная, 1, телефон: 32421"	Россия, Томская область, Колпашевский район, поселок Усть-Чая	0101000020E610000081B4FF01D6A854408638D6C56D224D40
2926	5	54	7144	52253	\N	\N	58.359237999999998	Томская область, Колпашевский район, с.Тогур, ул.Свердлова 15	Россия, Томская область, Колпашевский район, село Тогур	0101000020E61000006F4BE48233B654407FBDC282FB2D4D40
2924	5	54	7144	52253	65989	\N	58.359237999999998	"Томская область, Муниципальное образование ""Колпашевский район"", с.Тогур, ул.Советская, 64, телефон: 46280"		0101000020E61000006F4BE48233B654407FBDC282FB2D4D40
2925	5	54	7144	52253	74346	\N	58.359237999999998	"Томская область, Муниципальное образование ""Колпашевский район"", сТогур, ул.Свердлова, 15, телефон: 57682"	Россия, Томская область, Колпашевский район, село Тогур	0101000020E61000006F4BE48233B654407FBDC282FB2D4D40
2922	5	54	7144	52253	74462	\N	58.359237999999998	"Томская область, Муниципальное образование ""Колпашевский район"", с.Тогур, ул.Мичурина, 8, телефон: 46270"		0101000020E61000006F4BE48233B654407FBDC282FB2D4D40
2929	5	54	7144	52253	65505	\N	58.359237999999998	"Томская область, Муниципальное образование ""Колпашевский район"", с.Тогур, ул.Лермонтова, 40, телефон: 32307"		0101000020E61000006F4BE48233B654407FBDC282FB2D4D40
2928	5	54	7144	52253	65505	\N	58.359237999999998	"Томская область, Муниципальное образование ""Колпашевский район"", с.Тогур, ул.Лермонтова, 40, телефон: 54829"		0101000020E61000006F4BE48233B654407FBDC282FB2D4D40
2927	5	54	7144	52253	74830	\N	58.359237999999998	"Томская область, Муниципальное образование ""Колпашевский район"", сТогур, ул.Источная, 6-2, телефон: 32181"	Россия, Томская область, Колпашевский район, село Тогур	0101000020E61000006F4BE48233B654407FBDC282FB2D4D40
2942	5	54	7144	52286	74616	\N	58.081836000000003	"Томская область, Муниципальное образование ""Колпашевский район"", д.Тискино, ул.Братская, 29, телефон: 77410"	Россия, Томская область, Колпашевский район, деревня Тискино	0101000020E6100000101FD8F15FCC544057D11F9A790A4D40
2935	5	54	7144	52276	74622	\N	58.033133999999997	"Томская область, Муниципальное образование ""Колпашевский район"", с.Старокороткино, ул.Центральная, 43, телефон: 95336"		0101000020E6100000E6E61BD13DBE54405D3123BC3D044D40
2931	5	54	7144	52267	\N	\N	58.443547000000002	"Томская область, Муниципальное образование ""Колпашевский район"", д.Север, -, *, телефон: 62549"	Россия, Томская область, Колпашевский район, деревня Север	0101000020E6100000E3A59BC420B45440959EE925C6384D40
2934	5	54	7144	60306	74496	\N	58.2311961724985	"Томская область, Муниципальное образование ""Колпашевский район"", с.Озерное, ул.Трактовая, 9, телефон: 24136"	Россия, Томская область, Колпашевский район, село Озерное	0101000020E610000093C6681D55BA5440A67B9DD4971D4D40
2945	5	54	7144	52108	74460	\N	58.397717999999998	Томская область, Колпашевский район, с.Новоселово, ул.Центральная 36		0101000020E61000007CEE04FBAFBF5440E883656CE8324D40
2943	5	54	7144	60336	74769	\N	58.228454532965699	"Томская область, Муниципальное образование ""Колпашевский район"", с.Новоильинка, пер.Школьный, 6, телефон: 27136"	Россия, Томская область, Колпашевский район, село Новоильинка	0101000020E61000008C48145AD6C15440C8CD70033E1D4D40
2939	5	54	7144	52281	74781	\N	58.248578000000002	"Томская область, Муниципальное образование ""Колпашевский район"", д.Новогорное, ул.Береговая, 42, телефон: 94136"		0101000020E6100000BD546CCCEBA85440A7406667D11F4D40
3045	5	54	7151	52122	74714	\N	58.981507999999998	Томская область, Крагасокский  район, с.Старая Березовка, ул. Центральная 5		0101000020E61000000BB77C2425E353409561DC0DA27D4D40
2933	5	54	7144	52272	74785	\N	58.120891	"Томская область, Муниципальное образование ""Колпашевский район"", д.Могильный Мыс, ул.Зеленая, 22, телефон: 96136"		0101000020E61000002CF3565D87B45440BCB0355B790F4D40
2946	5	54	7144	60349	74831	\N	58.390459	"Томская область, Муниципальное образование ""Колпашевский район"", д.Маракса, ул.Юбилейная, 24, телефон: 22566"		0101000020E6100000ABED26F8A6C55440E5B67D8FFA314D40
2951	5	54	7144	52302	74763	\N	58.904086999999997	"Томская область, Муниципальное образование ""Колпашевский район"", п.Куржино, ул.Лесная, 2, телефон: 62446"		0101000020E610000034D6FECEF6A354408FDE701FB9734D40
2954	5	54	7144	60344	74821	\N	58.658969308511899	"Томская область, Муниципальное образование ""Колпашевский район"", с.Копыловка, ул.Школьная, 1, телефон: 62225"	Россия, Томская область, Колпашевский район	0101000020E610000050C58D5BCC915440F609A01859544D40
2907	5	54	7144	52207	\N	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, мкр Геолог, 20, телефон: 52045"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2886	5	54	7144	52207	65394	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, пер.Чапаева, 23, телефон: 51123"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2914	5	54	7144	52207	65979	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, пер.Озерный, 10, телефон: 32420"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2915	5	54	7144	52207	74476	\N	58.318502241426302	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, пер.Лазо, 6, телефон: 32681"	Россия, Томская область, Колпашевский район, Колпашево	0101000020E610000051A1BAB9F8BA5440F5DA6CACC4284D40
2903	5	54	7144	52207	66422	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Толстого, 14, телефон: 53028"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2909	5	54	7144	52207	74449	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Портовая, 64, телефон: 41844"	Россия, Томская область, Р398	0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2905	5	54	7144	52207	66600	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Победы, 12, телефон: 51688"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2876	5	54	7144	52207	66600	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Победы, 75, телефон: 51383"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2921	5	54	7144	52207	74428	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Науки, 20, телефон: 47167"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2912	5	54	7144	52207	74451	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Комсомольская, 3/1, телефон: 53994"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2913	5	54	7144	52207	74454	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Коммунистическая, 4, телефон: 53691"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2908	5	54	7144	52207	65400	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Кирова, 32, телефон: 54194"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2906	5	54	7144	52207	65400	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Кирова, 30, телефон: 42049"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2901	5	54	7144	52207	65400	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Кирова, 45, телефон: 56228"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2910	5	54	7144	52207	74452	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Дорожная, 24, телефон: 53759"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2916	5	54	7144	52207	66603	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Горького, 22, телефон: 52561"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2920	5	54	7144	52207	65984	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Гоголя, 99, телефон: 32416"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2919	5	54	7144	52207	65984	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Гоголя, 87, телефон: 58808"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2918	5	54	7144	52207	65984	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Гоголя, 91/1, телефон: 59275"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2917	5	54	7144	52207	65984	\N	58.317056999999998	"Томская область, Муниципальное образование ""Колпашевский район"", г.Колпашево, ул.Гоголя, 87/2, телефон: 58886"		0101000020E610000079CA6ABA9EBA5440E3FBE25295284D40
2952	5	54	7144	52305	74506	\N	58.479348000000002	"Томская область, Муниципальное образование ""Колпашевский район"", с.Инкино, пер.Кооперативный, 11, телефон: 93136"	Россия, Томская область, Колпашевский район, село Инкино	0101000020E6100000E59A02999D88544096B377465B3D4D40
2953	5	54	7144	52306	74677	\N	58.441329000000003	"Томская область, Муниципальное образование ""Колпашевский район"", с.Иванкино, ул.Школьная, 7, телефон: 32126"		0101000020E610000059A7CAF78C9B544061E3FA777D384D40
2996	5	54	694	45469	74618	\N	57.220880999999999	д.Пчелка, Центральная, 6-1, телефон: 38-212		0101000020E6100000FAB48AFED07A544065A71FD4459C4C40
2950	5	54	7144	52300	74673	\N	58.715977000000002	"Томская область, Муниципальное образование ""Колпашевский район"", п.Дальнее, ул.Школьная, 1/1, телефон: 26725"		0101000020E610000055A52DAEF1BB544017D86322A55B4D40
2930	5	54	7144	52103	74776	\N	58.392757000000003	Томская область, Колпашевский район, д.Волково, ул.Волкова 18/1		0101000020E6100000DB6CACC43CB95440362383DC45324D40
2941	5	54	7144	52284	74407	\N	58.104179000000002	"Томская область, Муниципальное образование ""Колпашевский район"", п.Большая Саровка, ул.Советская, 35/1, телефон: 27314"		0101000020E610000012A3E716BAD054400AF7CABC550D4D40
2949	5	54	7144	52299	74554	\N	58.42089	"Томская область, Муниципальное образование ""Колпашевский район"", д.Белояровка, ул.Мира, 9, телефон: 98149"		0101000020E61000007FF964C570D65440529B38B9DF354D40
3100	5	54	746	23441	74480	\N	55.835680000000004	село Чилино, Советская, 1, телефон: 35347		0101000020E6100000BF0B5BB395E15440EDF5EE8FF7EA4B40
3080	5	54	746	47190	74774	\N	56.286987000000003	Хмелевка, Советская, 59, телефон: 39120	Россия, Томская область, Кожевниковский район, село Хмелевка	0101000020E610000067EF8CB62AD5544047B071FDBB244C40
3094	5	54	746	23153	66388	\N	56.132845000000003	село Уртам, Фрунзе, 25, телефон: 51218		0101000020E610000044DD0720B5FB5440F437A11001114C40
3081	5	54	746	22584	74775	\N	56.382167000000003	село Терсалгай, Зеленая, 4, телефон: 42332		0101000020E6100000ADA580B4FFDB5440234E27D9EA304C40
3040	5	54	746	20607	74548	\N	56.182191000000003	село Тека, Школьная, 1, телефон: 52137		0101000020E610000009E23C9CC0F054401250E10852174C40
3077	5	54	746	22400	74477	\N	56.312100000000001	"Томская область, Муниципальное образование ""Кожевниковский район"" с. Старая Ювала, Ульяновская, 34, телефон: 411343"		0101000020E61000007CD5CA845FDC5440728A8EE4F2274C40
3092	5	54	746	23082	74649	\N	56.358331999999997	Томская область, Кожевниковский район, д.Сафроновка, ул.Школьная 4		0101000020E61000001EA67D737FFA54401D8EAED2DD2D4C40
3082	5	54	746	22627	74405	\N	56.406295999999998	село Песочнодубровка, Молодежная, 37,		0101000020E610000022533E0455DD5440703FE08101344C40
3098	5	54	746	47569	74702	\N	55.956774000000003	село Осиновка, Мира, 13, телефон: 32646		0101000020E6100000A530EF71A6DF5440E1D4079277FA4B40
3103	5	54	746	47645	74773	\N	56.140515000000001	село Новосергеевка, Молодежная, 8, телефон: 55117		0101000020E6100000A1D79FC4E7ED544079CC4065FC114C40
3091	5	54	746	47426	74736	\N	56.322423999999998	село Новопокровка, Садовая, 2а, телефон: 58141		0101000020E6100000C8B3CBB73EF7544006B98B3045294C40
3084	5	54	746	22719	74563	\N	56.448573000000003	деревня Муллова, Центральная, 22, телефон: 42304		0101000020E61000004C1C7920B2DE54402F6F0ED76A394C40
3083	5	54	746	22672	74778	\N	56.438234000000001	село Кожевниково-на-Шегарке, ул Комсомольская, 24, телефон: 42363		0101000020E61000004C7155D977DB544065FF3C0D18384C40
3087	5	54	746	5233	66417	\N	56.260377827779202	село Кожевниково, Ленина, 10, телефон: 21805	Россия, Томская область, Кожевниковский район, село Кожевниково	0101000020E61000001EFD2FD7A2FD5440884CF91054214C40
3085	5	54	746	5233	65244	\N	56.258183000000002	Томская область, Кожевниковский район, с.Кожевниково, ул.Кирова 40		0101000020E6100000F6D37FD6FCFD54400CB1FA230C214C40
3088	5	54	746	5233	65429	\N	56.258183000000002	село Кожевниково, Гагарина, 9, телефон: 22982		0101000020E6100000F6D37FD6FCFD54400CB1FA230C214C40
3086	5	54	746	5233	65429	\N	56.258660733045303	село Кожевниково, Гагарина, 20, телефон: 22881	Россия, Томская область, Кожевниковский район, село Кожевниково	0101000020E6100000E161DA37F7FD544015E0BBCD1B214C40
3089	5	54	746	22919	74824	\N	56.366131000000003	село Киреевск, Карла Маркса, 21, телефон: 39016		0101000020E6100000B1DD3D40F7055540A1866F61DD2E4C40
3076	5	54	746	52483	74746	\N	56.285653000000003	"Томская область, Муниципальное образование ""Кожевниковский район"", Староювалинское сельское поселение с Зайцево, ул. Школьная, 24, телефон: 56145"		0101000020E6100000EDB8E177D3EA54408D800A4790244C40
3099	5	54	746	23390	74701	\N	55.873652	деревня Ерестная, Школьная, 10, телефон: 34448		0101000020E61000000A65E1EB6BE65440E10A28D4D3EF4B40
3097	5	54	746	47541	74707	\N	55.949397240904901	село Еловка, Новая, 10, телефон: 33722	Россия, Томская область, Кожевниковский район, село Еловка	0101000020E61000006FB9FAB149EF5440D3F544D785F94B40
3078	5	54	746	22428	74698	\N	56.250742000000002	село Елгай, Школьная, 2, телефон: 43518		0101000020E61000009E08E23C9CD55440E8DD585018204C40
3093	5	54	746	23115	74560	\N	56.422485000000002	село Десятово, Школьная, 15а, телефон: 23458	Россия, Томская область, Кожевниковский район, село Десятово	0101000020E61000003BAA9A20EAF8544079060DFD13364C40
3075	5	54	746	52480	74637	\N	56.136923000000003	"Томская область, Муниципальное образование ""Кожевниковский район"", Малиновское сельское поселение  с.  Борзуновка, Гагарина, 25, телефон: 54132"	Россия, Томская область, Кожевниковский район, село Борзуновка	0101000020E61000006ABE4A3E76E35440FD885FB186114C40
3102	5	54	746	23518	74635	\N	55.746426	село Базой, Советская, 16, телефон: 36532		0101000020E6100000EFC7ED974FD754402A711DE38ADF4B40
3090	5	54	746	47421	74621	\N	56.287121999999997	деревня Аркадьево, Октябрьская, 10, телефон: 31309		0101000020E61000009561DC0DA2F7544026FBE769C0244C40
3079	5	54	746	35509	74691	\N	56.174489253270202	Аптала, Садовая, 13, телефон: 39149	Россия, Томская область, Кожевниковский район, село Аптала	0101000020E610000071218FE046CE54408141D2A755164C40
3070	5	54	7151	60360	74848	\N	58.980752526596298	Каргасокское сельское поселение д. Лозунга, Береговая, 39, телефон: 47-1-34	Россия, Томская область, Каргасокский район	0101000020E6100000AE9D2809892C5440193A7650897D4D40
3048	5	54	7151	52422	74611	\N	59.430579000000002	Каргасокский район  с. Усть-Тым, Береговая, 62, телефон: 39-1-47		0101000020E610000097AAB4C53501544015AC71361DB74D40
3067	5	54	7151	52126	74732	\N	59.375540999999998	Томская область, Каргасокский район, с.Тымск, ул.Кедровая 16		0101000020E61000000D1B65FD6613544050A73CBA11B04D40
3071	5	54	7151	60329	74704	\N	59.001022753970297	Каргасокский район с.Староюгино, Лесная, 16а, телефон: 33-1-74	Россия, Томская область, Каргасокский район, село Староюгино	0101000020E610000011548D5E0D1F54409CC58B8521804D40
3046	5	54	7151	52419	66438	\N	59.217945	Каргасокский район  с. Средний Васюган, Студенческая, 11, телефон: 25-1-97		0101000020E61000009FABADD85F8F5340D2A92B9FE59B4D40
3064	5	54	7151	52460	74623	\N	59.118884999999999	Каргасокский район с.Сосновка, Школьная, 18, телефон: 38-1-44		0101000020E61000004AEF1B5F7B535440137EA99F378F4D40
3068	5	54	7151	60365	74868	\N	59.060614256302898	Каргасокское сельское поселение с.Пятый километр, Тополевая, 16, телефон: 2-44-09	Россия, Томская область, Каргасокский район	0101000020E61000004F93196F2B33544002D71533C2874D40
3063	5	54	7151	60310	74522	\N	58.999305999999997	Каргасокское сельское поселение с. Павлово, Школьная, 1, телефон: 31148	Россия, Томская область, Каргасокский район, село Павлово	0101000020E6100000B00111E2CA3A544029594E42E97F4D40
3044	5	54	7151	52417	74604	\N	59.142977959108201	Каргасокский район с. Новый Тевриз, Центральная, 5, телефон: 25-5-49	Россия, Томская область, Каргасокский район	0101000020E61000009240834D9D6153401406651A4D924D40
3047	5	54	7151	52421	65590	\N	58.577781000000002	Каргасокский район  с. Новый Васюган, Советская, 49, телефон: 2-92-84 : 2-93-93		0101000020E6100000A1A014ADDC1F534006A051BAF4494D40
3072	5	54	7151	52474	74555	\N	58.993136999999997	Каргасокский район с.Новоюгино, Центральная, 44/2, телефон: 37-1-32		0101000020E6100000529D0E643D25544049B9FB1C1F7F4D40
3050	5	54	7151	52429	\N	\N	59.726097000000003	Каргасокский район  п. Неготка, Студенческая, 5, телефон: 49-1-19	Россия, Томская область, Каргасокский район, поселок Неготка	0101000020E610000092205C0185295440A35C1ABFF0DC4D40
3053	5	54	7151	52433	74613	\N	59.893340000000002	Каргасокский район  с. Напас, Кооперативная, 1/1, телефон: 44-2-38		0101000020E6100000320400C79E805440B51A12F758F24D40
3054	5	54	7151	52438	74727	\N	58.992218999999999	Каргасокский район  с. Мыльджино, Береговая, 41, телефон: 40-1-36		0101000020E6100000A5BE2CEDD49E534023BC3D08017F4D40
3052	5	54	7151	60317	74576	\N	59.928732046100102	Каргасокский район  п. Молодежный, Гагарина, 10, телефон: 44-1-41		0101000020E610000058AEB7CD546D5440D45FAFB0E0F64D40
3066	5	54	7151	52466	74676	\N	59.152208000000002	Каргасокский район с.Киндал, Школьная, 4, телефон: 32-1-10		0101000020E61000003106D671FC25544044183F8D7B934D40
3051	5	54	7151	60318	74577	\N	59.770398	Каргасокский район  п. Киевский, Лесная, 4, телефон: 45-1-17	Россия, Томская область, Каргасокский район, село Киевский	0101000020E6100000605B3FFD67195440B073D3669CE24D40
3062	5	54	7151	60294	74520	\N	59.050776999999997	Каргасокское сельское поселение, Энтузиастов, 2, телефон: 2-33-77	Россия, Томская область, Каргасокский район, село Каргасок	0101000020E6100000B779E3A430375440CA3159DC7F864D40
3059	5	54	7151	60294	74531	\N	59.059371003027202	Каргасокское сельское поселение, Советская, 40, телефон: 2-33-02	Россия, Томская область, Каргасокский район	0101000020E61000006A1327F73B37544058AA0B7899874D40
3057	5	54	7151	60294	74347	\N	59.052899468098403	Каргасокское сельское поселение, Октябрьская, 97, телефон: 2-71-76	Россия, Томская область, Каргасокский район, село Каргасок	0101000020E610000057AF22A303375440DC7EF964C5864D40
3055	5	54	7151	60294	74347	\N	59.050776999999997	Каргасокское сельское поселение, Октябрьская, 1, телефон: 2-19-77		0101000020E6100000B779E3A430375440CA3159DC7F864D40
3056	5	54	7151	60294	74352	\N	59.055276729064801	Каргасокское сельское поселение, М. Горького, 16, телефон: 2-31-91	Россия, Томская область, Каргасокский район	0101000020E61000008638D6C56D355440499C155113874D40
3061	5	54	7151	60294	74364	\N	59.050776999999997	Каргасокское сельское поселение п.Нефтяников, Лугинецкая, 1, телефон: 2-42-81	Россия, Томская область, Каргасокский район, село Каргасок	0101000020E6100000B779E3A430375440CA3159DC7F864D40
3058	5	54	7151	60294	74540	\N	59.050776999999997	Каргасокское сельское поселение, Кирова, 104, телефон: 2-10-54	Россия, Томская область, Каргасокский район, село Каргасок	0101000020E6100000B779E3A430375440CA3159DC7F864D40
3065	5	54	7151	52462	74625	\N	59.169069	Каргасокский район с.Восток, Заводская, 22, телефон: 46-1-39		0101000020E6100000A6D590B8C75154403BE2900DA4954D40
3049	5	54	7151	52427	74684	\N	59.385927000000002	Каргасокский район  с. Вертикос, Молодежная, 1, телефон: 36-1-72		0101000020E6100000F6083543AAEA53405BD2510E66B14D40
3069	5	54	7151	52471	74697	\N	59.028388	Каргасокский район с.Бондарка, Центральная, 58, телефон: 2-31-02		0101000020E61000005E81E849992F5440A7CCCD37A2834D40
3073	5	54	7151	52477	74752	\N	58.924838000000001	Каргасокский район с.Большая Грива, Советская, 6, телефон: 30-1-48		0101000020E6100000632992AF041054408D0C721761764D40
2804	5	54	853	9043	74747	\N	56.6739382866919	с.Шиняево, Луговая, 54/1, телефон: 25766	Россия, Томская область, Зырянский район, село Шиняево	0101000020E61000009F758D9603C255400DC4B29943564C40
3042	5	54	853	20705	74398	\N	56.952097000000002	с.Чердаты, Советская, 1а, телефон: 32125		0101000020E61000008690F3FE3FBC554053CF8250DE794C40
3031	5	54	853	20081	74682	\N	56.870947000000001	с.Цыганово, Чапаева, 62, телефон: 42413		0101000020E6100000D25625917D9D554050C6F8307B6F4C40
3039	5	54	853	46361	74758	\N	56.740417999999998	с.Тукай, Лесная, 1, телефон: 25513		0101000020E61000007B6B60AB04C7554053AF5B04C65E4C40
3037	5	54	853	20467	74755	\N	56.733704000000003	с.Туендат, Нагорная, 9, телефон: 25987		0101000020E610000002A08A1BB7BB5540E2783E03EA5D4C40
3032	5	54	853	46188	74420	\N	56.875213961800704	с. Семеновка, Боровая, 3, телефон: 33126	Россия, Томская область, Зырянский район, село Семёновка	0101000020E61000007F87A2409F9255402C80290307704C40
3041	5	54	853	20695	74715	\N	56.885958000000002	п.Прушинский, Береговая, 10, телефон: 89016178153		0101000020E6100000D82B2CB81FBA554096D05D1267714C40
3029	5	54	853	60298	74397	\N	56.840158223429697	п. Причулымский, Степная, 15, телефон: 37359	Россия, Томская область, Зырянский район, село Причулымский	0101000020E61000006AF981AB3CA4554084BC1E4C8A6B4C40
3038	5	54	853	20490	74556	\N	56.771940000000001	с.Окунеево, Октябрьская, 32, телефон: 25840		0101000020E6100000C2BE9D4484BF5540B43C0FEECE624C40
3034	5	54	853	20231	74681	\N	56.713276	с. Мишутино, Центральная, 56, телефон: 34234		0101000020E610000052F355F2B1955540C782C2A04C5B4C40
2980	5	54	694	17411	74633	\N	57.005211000000003	с.Поротниково, Советская, 19, телефон: 36158		0101000020E6100000AF9811DE1E9654402C4A09C1AA804C40
3043	5	54	853	46441	\N	\N	56.969724999999997	п.Кучуково, Ворошилова, 24, телефон: 89627888332	Россия, Томская область, Зырянский район, село Кучуково	0101000020E610000098F6CDFDD5C155408A8EE4F21F7C4C40
3028	5	54	853	46087	74678	\N	56.820602535387401	с. Красноярка, Школьная, 1, телефон: 43354	Россия, Томская область, Зырянский район, село Красноярка	0101000020E6100000F99FFCDD3BB55540EFFFE38409694C40
2923	5	54	853	48566	74535	\N	56.889474	с.Иловка, Чкалова, 1, телефон: 31294		0101000020E61000006AA33A1DC8B455403752B648DA714C40
3025	5	54	853	6381	74430	\N	56.829428	с.Зырянское, Советская, 111, телефон: 22529		0101000020E6100000433BA759A0A755407F315BB22A6A4C40
3024	5	54	853	6381	74430	\N	56.829428	с.Зырянское, Советская, 18, телефон: 22560	Россия, Томская область, Зырянский район, село Зырянское	0101000020E6100000433BA759A0A755407F315BB22A6A4C40
2748	5	54	853	6381	74599	\N	56.829428	с. Зырянское, Свердлова, 25, телефон: 22666		0101000020E6100000433BA759A0A755407F315BB22A6A4C40
3022	5	54	853	6381	74395	\N	56.829428	с.Зырянское, Калинина, 1, телефон: 22227		0101000020E6100000433BA759A0A755407F315BB22A6A4C40
2633	5	54	853	6381	74395	\N	56.829428	с.Зырянское, Калинина, 90, телефон: 22281		0101000020E6100000433BA759A0A755407F315BB22A6A4C40
3026	5	54	853	6381	74429	\N	56.829428	с.Зырянское, Ефанова, 22, телефон: 89627888331		0101000020E6100000433BA759A0A755407F315BB22A6A4C40
3033	5	54	853	46223	74631	\N	56.727866213901301	с. Дубровка, Новая, 1, телефон: 34118	Россия, Томская область, Зырянский район, село Дубровка	0101000020E610000064CC5D4BC89C554067EF8CB62A5D4C40
3035	5	54	853	20348	74567	\N	56.596074999999999	с.Громышевка, Ленина, 103, телефон: 30109		0101000020E6100000684293C4929A55404A7B832F4C4C4C40
2775	5	54	853	7647	74530	\N	56.605400000000003	Томская область, Зырянский район, с.Высокое, ул Мира 62/3		0101000020E61000006FF4311F10BA5540CC7F48BF7D4D4C40
3027	5	54	853	46081	74413	\N	56.803445000000004	с.Богословка, Горького, 2, телефон: 35123		0101000020E610000077F4BF5C8BAE55403F912749D7664C40
3030	5	54	853	20033	74478	\N	56.830655	с.Берлинка, Луговая, 68, телефон: 37282		0101000020E6100000B9AAECBB22A3554023A12DE7526A4C40
2911	5	54	853	14094	74541	\N	56.594760999999998	с.Беловодовка, Советская, 45, телефон: 25312		0101000020E6100000AFB5F7A92AC45540D7F7E120214C4C40
2820	5	54	7388	55950	48704	\N	56.747548867657102	"Томская область, Городской округ ""Закрытое административно-территориальное образование Северск"" п.Самусь, Ленина, 28, телефон: 904-789"	Россия, Томская область, Томский район, поселок Самусь	0101000020E6100000B090B932A82C5540299485AFAF5F4C40
3016	5	54	7179	60308	74510	\N	58.250395218219502	Томская область, Верхнекетский район, п. Ягодное, Советская, 2, телефон: 3-21-80		0101000020E6100000C25087156E4F55407C0A80F10C204D40
3015	5	54	7179	60324	74643	\N	58.735219063447197	Томская область, Вернекетский район, п.Центральный, пер Школьный 11	Россия, Томская область, Верхнекетский район	0101000020E61000008FE4F21FD21E5540EC32FCA71B5E4D40
3012	5	54	7179	52384	74325	\N	58.638188	Томская область, Верхнекетский район, п. Степановка, Аптечный переулок, 2, телефон: 2-52-83		0101000020E6100000A0F99CBB5DB155408E59F624B0514D40
3021	5	54	7179	52401	74549	\N	58.377414000000002	Томская область, Верхнекетский район, п. Палочка, Молодежная, 26, телефон: 3-41-36		0101000020E610000089EAAD81AD265540BA86191A4F304D40
3017	5	54	7179	60339	74797	\N	58.283645	Томская область, Вернекетский район, п.Нибега, ул.Новошкольная 1	Россия, Томская область, Верхнекетский район, деревня Нибегинский	0101000020E610000056478E74063955404356B77A4E244D40
3020	5	54	7179	52398	74784	\N	58.621327000000001	Томская область, Верхнекетский район, п. Макзыр, Центральная, 16, телефон: 3-15-19		0101000020E61000007AAA436E86665540978FA4A4874F4D40
3019	5	54	7179	52397	74689	\N	58.701065999999997	Томская область, Верхнекетский район, п. Лисица, Таежная, 16, телефон: 3-51-31	Россия, Томская область, Верхнекетский район, поселок Лисица	0101000020E61000003B394371C74E5540342BDB87BC594D40
3013	5	54	7179	52387	66385	\N	58.541136999999999	Томская область, Верхнекетский район, п. Клюквинка, Центральная, 4, телефон: 2-42-22		0101000020E61000008066101FD8765540E9D32AFA43454D40
3011	5	54	7179	52382	65592	\N	58.747357999999998	Томская область, Верхнекетский район, п. Катайга, Кирова, 39, телефон: 3-31-98		0101000020E610000052EE3EC747FB5540B5334C6DA95F4D40
3014	5	54	7179	52388	74561	\N	58.759836	Томская область, Верхнекетский район, п. Дружный, Центральная, 3, телефон: 3-73-73		0101000020E61000005AD8D30E7F8455406729594E42614D40
3006	5	54	7179	58563	66006	\N	58.454676142034103	Томская область, Верхнекетский район, р.п. Белый Яр, Чкалова, 8, телефон: 2-14-87	Россия, Томская область, Верхнекетский район	0101000020E610000086764EB3404555405723BBD2323A4D40
3008	5	54	7179	58563	65554	\N	58.441717455613102	Томская область, Верхнекетский район, р.п. Белый Яр, Котовского, 1, стр.1, пом у-2, телефон: 2-19-98		0101000020E6100000BC07E8BE9C4455402A8BC22E8A384D40
3007	5	54	7179	58563	65537	\N	58.438837096898297	Томская область,Верхнекетский район, р.п. Белый Яр, Гагарина, 55, телефон: 2-21-67	Россия, Томская область, Верхнекетский район	0101000020E6100000A20C5531954355402BA391CF2B384D40
3009	5	54	7179	58563	74404	\N	58.453686411370903	Томская область, Верхнекетский район, р.п. Белый Яр, Вокзальная, 7 А, телефон: 3-01-68	Россия, Томская область, Верхнекетский район	0101000020E6100000726C3D433845554097530262123A4D40
2981	5	54	694	17499	74626	\N	57.044643000000001	д.Чумакаевка, Центральная, 10, телефон: 36191	Россия, Томская область, Бакчарский район, село Чумакаевка	0101000020E6100000E6E61BD13D955440677FA0DCB6854C40
2993	5	54	694	45415	74759	\N	56.999328052835999	с.Чернышевка, Центральная, 1, телефон: 32-135	Россия, Томская область, Бакчарский район, село Чернышевка	0101000020E6100000AC527AA6977F544011FDDAFAE97F4C40
2997	5	54	694	18300	74696	\N	57.270558000000001	д.Хуторское, Центральная, 17, телефон: 38-284		0101000020E61000008EC9E2FE237B5440E9D500A5A1A24C40
2991	5	54	694	45366	74675	\N	57.111604999999997	д.Сухое, Центральная, 24-1, телефон: 41-562		0101000020E6100000B554DE8E708B5440F8889812498E4C40
2978	5	54	694	49428	74504	\N	56.854255999999999	п.Плотниково, Школьная, 4, телефон: 39436		0101000020E61000003354C554FAC45440B534B742586D4C40
2982	5	54	694	49489	74679	\N	56.982421000000002	д.Первомайск, Луговая, 9, телефон: 41-878		0101000020E61000000F4757E9EE8F5440AAF3A8F8BF7D4C40
3001	5	54	694	18423	74638	\N	57.229402999999998	с.Парбиг, Советская, 76, телефон: 44286	Россия, Томская область, Бакчарский район, село Парбиг	0101000020E61000003BE466B8015A5440594DD7135D9D4C40
3000	5	54	694	18423	74426	\N	57.229915252744298	с.Парбиг, Новосибирская, 10, телефон: 44380	Россия, Томская область, Бакчарский район, село Парбиг	0101000020E6100000C2F693313E5A54400FEECEDA6D9D4C40
3002	5	54	694	18423	74458	\N	57.229402999999998	с.Парбиг, Кооперативная, 13, телефон: 44-271		0101000020E61000003BE466B8015A5440594DD7135D9D4C40
2994	5	54	694	18124	74550	\N	57.055956999999999	д.Панычево, Центральная, 24-2, телефон: 33742		0101000020E6100000459F8F32E2725440BB7D569929874C40
3003	5	54	694	18617	74790	\N	56.917681000000002	с.Новая Бурка, Ленина, 25, телефон: 45121		0101000020E61000005B9885764E4354408E942D9276754C40
3005	5	54	694	18735	74628	\N	57.427807000000001	с.Кенга, Совесткая, 41, телефон: 45318		0101000020E61000007D5A457F683E5440FCFF3861C2B64C40
2999	5	54	694	18403	74551	\N	57.453456000000003	Томская область, Бакчарский район, с.Крыловка, ул.Школьная 11		0101000020E610000026A8E15B587954406616A1D80ABA4C40
3004	5	54	694	45604	74553	\N	57.122419999999998	п.Кедровка, Центральная, 15-2, телефон: 44121		0101000020E61000005111A7936C4F54402B306475AB8F4C40
3157	5	54	694	18323	\N	\N	57.323292000000002	Высокий Яр, телефон: 27553	Россия, Томская область, Бакчарский район, село Высокий Яр	0101000020E610000021054F21577A54407B87DBA161A94C40
2998	5	54	694	18323	74695	\N	57.323292000000002	с.Высокий Яр, Больничный, 16, телефон: 38122		0101000020E610000021054F21577A54407B87DBA161A94C40
2504	5	54	694	41054	12287	\N	57.054972999999997	д.Вавиловка, Центральная, 2, телефон: 37295	Россия, Томская область, Бакчарский район, село Вавиловка	0101000020E6100000548CF337A1815440DD94F25A09874C40
2977	5	54	694	49417	74766	\N	57.021470999999998	с.Бородинск, Школьная, 22, телефон: 39544		0101000020E61000008F1D54E23ABB5440FD67CD8FBF824C40
2992	5	54	694	4867	74694	\N	56.924897999999999	Томская область, Бакчарский район, с.Большая Галка ул. Центральная 28		0101000020E6100000535E2BA1BB7D54406211C30E63764C40
2995	5	54	694	45452	74598	\N	56.979658999999998	с.Богатыревка, Ленина, 10, телефон: 34635		0101000020E6100000ECA012D731705440B41D5377657D4C40
2983	5	54	694	4850	74497	\N	57.024542825193997	с.Бакчар, Целинная, 11, телефон: 21293	Россия, Томская область, Бакчарский район, село Бакчар	0101000020E6100000C40AB77C24845440412C9B3924834C40
2989	5	54	694	4850	74387	\N	57.022759000000001	с.Бакчар, Трактовый, 27, телефон: 21-444		0101000020E61000003E4162BB7B835440475854C4E9824C40
2985	5	54	694	4850	74425	\N	57.022759000000001	с.Бакчар, Октябрьская, 62, телефон: 21117		0101000020E61000003E4162BB7B835440475854C4E9824C40
2990	5	54	694	4850	9660	\N	57.021729139553997	с.Бакчар, Ленина, 44, телефон: 41564	Россия, Томская область, Бакчарский район, село Бакчар	0101000020E61000008A01124DA0835440F92F1004C8824C40
2986	5	54	694	4850	9660	\N	57.022759000000001	с.Бакчар, Ленина, 44, телефон: 21371		0101000020E61000003E4162BB7B835440475854C4E9824C40
2988	5	54	694	4850	74492	\N	57.0212569862693	с.Бакчар, Вицмана, 2, телефон: 41569	Россия, Томская область, Бакчарский район, село Бакчар	0101000020E6100000514B732B84835440D1E7A38CB8824C40
2984	5	54	694	4850	74492	\N	57.022759000000001	с.Бакчар, Вицмана, 2, телефон: 21272		0101000020E61000003E4162BB7B835440475854C4E9824C40
2875	5	54	498	40332	74753	\N	57.053157399342801	"Томская область, Муниципальное образование ""Асиновский район"", Новокусковское сельское поселение, с.Нво-Кусково, Библиотечная, 8, телефон: 45122"	Россия, Томская область, Асиновский район, село Ново-Кусково	0101000020E6100000988A8D791D845540D8463CD9CD864C40
2890	5	54	498	13072	74453	\N	56.802681999999997	"Томская область, Муниципальное образование ""Асиновский район"", Ягодное сельское поселение, с.Ягодное, Школьная, 1д, телефон: 43705"		0101000020E61000004F1E166A4D8555403F8BA548BE664C40
2892	5	54	498	13166	74680	\N	56.805810999999999	"Томская область, Муниципальное образование ""Асиновский район"", Ягодное сельское поселение, с.Цветковка, Советская, 35-1, телефон: 30058"		0101000020E610000097A949F086755540E7E099D024674C40
2878	5	54	498	12554	74536	\N	57.181269999999998	"Томская область, Муниципальное образование ""Асиновский район"", Новокусковское сельское поселение, с.Филимоновка, Школьная, 2, телефон: 48131"		0101000020E6100000FD885FB1867455407ADFF8DA33974C40
2885	5	54	498	52217	74668	\N	56.964936000000002	"Томская область, Муниципальное образование ""Асиновский район"", Большедороховское сельское поселение, д.Феоктистовка, Волкова, 36,"		0101000020E61000001E5036E50A8D5540D55DD905837B4C40
2889	5	54	498	52221	74672	\N	56.931102000000003	"Томская область, Муниципальное образование ""Асиновский район"", Большедороховское сельское поселение, д.Тихомировка, Береговая, 36, телефон: 47400"		0101000020E61000008864C8B1F5845540BF9EAF592E774C40
2881	5	54	498	7098	74620	\N	56.935046	"Томская область, Муниципальное образование ""Асиновский район"", Новиковское сельское поселение, п.Светлый, имени Б.Н.Сидоренко, 6, телефон: 44504"		0101000020E6100000D905836BEE7D5540B8205B96AF774C40
2887	5	54	498	60333	74750	\N	56.946693000000003	"Томская область, Муниципальное образование ""Асиновский район"", Большедороховское сельское поселение, д.Победа, Советская, 22, телефон: 47518"	Россия, Томская область, Асиновский район, село Победа	0101000020E61000008CA19C6857905540132D793C2D794C40
2868	5	54	498	60325	74653	\N	57.573044000000003	"Томская область, Муниципальное образование ""Асиновский район"", Батуринское сельское поселение, п.Первопашенск, Береговая, 13, телефон: 30243"	Россия, Томская область, Асиновский район, село Первопашинск (Кайлушка)	0101000020E6100000CB4A9352D05E5540A3957B8159C94C40
8787	5	46	\N	11092	73492	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Центральный мкр, 1г		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
2874	5	54	498	12351	74415	\N	57.301374000000003	"Томская область, Муниципальное образование ""Асиновский район"", Новониколаевское сельское поселение, с.Новониколаевка, Школьная, 2, телефон: 42353"		0101000020E61000008448861C5B775540AFEE586C93A64C40
2877	5	54	498	12526	9704	\N	57.052554461322998	"Томская область, Муниципальное образование ""Асиновский район"", Новокусковское сельское поселение, с.Ново-Кусково, Школьная, 57, телефон: 45122"	Россия, Томская область, Асиновский район, село Ново-Кусково	0101000020E6100000C020E9D32A84554012A3E716BA864C40
2880	5	54	498	12670	74542	\N	56.924106999999999	"Томская область, Муниципальное образование ""Асиновский район"", Новиковское сельское поселение,с.Новиковка, Советская, 14, телефон: 44101"		0101000020E6100000C100C287127D554099805F2349764C40
2883	5	54	498	52214	74609	\N	56.874783999999998	"Томская область, Муниципальное образование ""Асиновский район"", Новиковское сельское поселение, д.Нижние Соколы, Центральная, 40-1, телефон: 44169"		0101000020E610000079211D1EC272554033880FECF86F4C40
2882	5	54	498	12746	74744	\N	56.935884999999999	"Томская область, Муниципальное образование ""Асиновский район"", Новиковское сельское поселение, д.Моисеевка, пер.Школьный, 1, телефон: 52149"		0101000020E61000003012DA722E73554092E86514CB774C40
2869	5	54	498	60315	74565	\N	57.279182467145603	"Томская область, Муниципальное образование ""Асиновский район"", Новониколаевское сельское поселение, д.Михайловка, Центральная, 14а, телефон: 42168"		0101000020E6100000F836FDD98F725540E1D05B3CBCA34C40
2871	5	54	498	12239	74390	\N	57.434741687080297	"Томская область, Муниципальное образование ""Асиновский район"", Новониколаевское сельское поселение, с.Минаевка, пер.Больничный, 1, телефон: 40526"	Россия, Томская область, Асиновский район, село Минаевка	0101000020E6100000F209D9791B7655404C1938A0A5B74C40
2891	5	54	498	52222	74614	\N	56.797584999999998	"Томская область, Муниципальное образование ""Асиновский район"", Ягодное сельское поселение, д.Мало-Жирово, Центральная, 70, телефон: 43105"		0101000020E6100000892991442F7F5540DC63E94317664C40
2870	5	54	498	12179	74665	\N	57.492249999999999	"Томская область, Муниципальное образование ""Асиновский район"", Новониколаевское сельское поселение, с.Копыловка, Береговая, 6а, телефон: 30129"		0101000020E61000007C28D192C76F55405EBA490C02BF4C40
2879	5	54	498	12630	74765	\N	57.089599999999997	"Томская область, Муниципальное образование ""Асиновский район"", Новокусковское сельское поселение,с.Казанка, Партизанская, 73, телефон: 45494"		0101000020E61000001805C1E3DB7A55405DDC4603788B4C40
2884	5	54	498	60335	74756	\N	56.900929490494498	"Томская область, Муниципальное образование ""Асиновский район"", Новиковское сельское поселение, д.Вороно-Пашня, Новая, 4, телефон: 44415"	Россия, Томская область, Асиновский район, село Воронино-Пашня	0101000020E6100000267156444D7955404D8237A451734C40
3346	5	54	498	47875	74590	\N	56.982788999999997	с. Вознесенка, ул. Советская, 37, телефон: 23-662		0101000020E6100000FB1EF5D72B9055402CEFAA07CC7D4C40
2873	5	54	498	12329	74539	\N	57.372762999999999	"Томская область, Муниципальное образование ""Асиновский район"", Новониколаевское сельское поселение, п.Большой Кордон, Центральная, 8, телефон: 40841"		0101000020E6100000C0401020437755405514AFB2B6AF4C40
2888	5	54	498	12975	74743	\N	56.890678000000001	"Томская область, Муниципальное образование ""Асиновский район"", Большедороховское сельское поселение, с.Больше-Дорохово, Центральная, 26, телефон: 47202"		0101000020E610000014252191B68C554023A298BC01724C40
2867	5	54	498	2998	74473	\N	57.756341578410797	"Томская область, Муниципальное образование ""Асиновский район"", Батуринское сельское поселение, Рабочая, 59, телефон: 41177"	Россия, Томская область, Асиновский район, поселок Батурино	0101000020E6100000B134F0A31A4C5540AD4B8DD0CFE04C40
2721	5	54	498	2998	74473	\N	57.754403000000003	Томская область, Асиновский район, с.Батурино, ул.Рабочая 21		0101000020E6100000960854FF204B55408D800A4790E04C40
3344	5	54	498	2998	74619	\N	57.754403000000003	д. Батурино, ул. Новая, 1, телефон: 23-277		0101000020E6100000960854FF204B55408D800A4790E04C40
2866	5	54	498	2998	74825	\N	57.754403000000003	"Томская область, Муниципальное образование ""Асиновский район"", Батуринское сельское поселение, Железнодорожная, 26, телефон: 30222"	Россия, Томская область, Асиновский район, поселок Батурино	0101000020E6100000960854FF204B55408D800A4790E04C40
2848	5	54	498	11644	\N	\N	56.995259062510399	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение,"	Россия, Томская область, Асиновский район, Асино	0101000020E610000011346612F58855405B069CA5647F4C40
2852	5	54	498	11644	74518	\N	56.994415821519503	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Ленина, 19, телефон: 23330"	Россия, Томская область, Асиновский район, Асино	0101000020E61000006D57E883658A5540404F0306497F4C40
2853	5	54	498	11644	74517	\N	56.996102284318901	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Советская, 46, телефон: 23540"	Россия, Томская область, Асиновский район, Асино	0101000020E6100000FE2955A2EC88554077BD3445807F4C40
2863	5	54	498	11644	74419	\N	56.993616000000003	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Свободы, 2, телефон: 30127"	Россия, Томская область, Асиновский район, Асино	0101000020E61000008DCF64FF3C895540246420CF2E7F4C40
26001	5	44	1140	45553	76729	\N	52.920976000000003	с.Соболиха, Набережная, 1		0101000020E610000007CF842689195B405133A48AE2754A40
2862	5	54	498	11644	74326	\N	56.995161984636503	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, П.Морозова, 6, телефон: 31223"	Россия, Томская область, Асиновский район, Асино	0101000020E61000005419C6DD20895540691CEA77617F4C40
2864	5	54	498	\N	74493	\N	57.305031361702703	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Мирная, 39, телефон: 27225"	Россия, Томская область, Асиновский район	0101000020E610000003CE52B29C63554012A27C410BA74C40
2865	5	54	498	11644	74515	\N	56.995540138577901	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Кирова, 8, телефон: 913 850 1885"	Россия, Томская область, Асиновский район, Асино	0101000020E6100000E9B7AF03E78855400FEECEDA6D7F4C40
2849	5	54	498	11644	74330	\N	57.001161212351803	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Ивана Буева, 38, телефон: 22811"	Россия, Томская область, Асиновский район, Асино	0101000020E6100000B00111E2CA885540ED832C0B26804C40
2847	5	54	498	11644	74434	\N	56.9964000973333	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, Гончарова, 268, телефон: 25942"	Россия, Томская область, Асиновский район, Асино	0101000020E610000037A79201A088554001DE02098A7F4C40
2854	5	54	498	11644	65500	\N	56.996102284318901	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, имени В.В.Липатова, 11, телефон: 22741"	Россия, Томская область, Асиновский район, Асино	0101000020E61000007366BB421F89554077BD3445807F4C40
2859	5	54	498	11644	65502	\N	56.993616000000003	Томская область, Асиновский район, г.Асино, Боровая, 5, телефон: 28690		0101000020E61000008DCF64FF3C895540246420CF2E7F4C40
2860	5	54	498	11644	74313	\N	56.994151481283097	"Томская область, Муниципальное образование ""Асиновский район"", Асиновское городское поселение, 370 Стрелковой дивизии, 26а, телефон: 32502"	Россия, Томская область, Асиновский район, Асино	0101000020E61000004C1938A0A588554092240857407F4C40
2969	5	54	5666	60314	74552	\N	60.677807999999999	Томская область, Александровский район, п.Северный, ул.Дорожная 4	Россия, Томская область, Александровский район, поселок Северный	0101000020E6100000892991442F4B5340CC7B9C69C2564E40
2970	5	54	5666	60330	74717	\N	59.4862329501684	Томская область, Александровский район, п.Октябрьский, ул.Школьная,4	Россия, Томская область, Александровский район, деревня Октябрьский	0101000020E6100000982F2FC03EDA5340349E08E23CBE4D40
2971	5	54	5666	38396	74629	\N	59.773838436354097	Томская область, Александровский район, с. Новоникольское, пер.Школьный 5 стр.1		0101000020E61000000BB6114F76D053407633A31F0DE34D40
2972	5	54	5666	52338	74578	\N	60.139144999999999	село Назино, Молодежная, 9/1, телефон: 4-21-61		0101000020E6100000E59D4319AABC53407233DC80CF114E40
2973	5	54	5666	52342	74762	\N	60.32732	село Лукашкин Яр, Центральная, 6, телефон: 4-33-48		0101000020E6100000D1031F83159A5340D2A92B9FE5294E40
2968	5	54	5666	60328	74692	\N	60.534998999999999	деревня Ларино, Обская, 10, телефон: 2-10-55	Россия, Томская область, Александровский район, село Ларино	0101000020E61000002BDCF291946B53404432E4D87A444E40
2947	5	54	5666	38490	65408	\N	60.449417653645398	село Александровское, переулок Солнечный, 2, телефон: 2-29-60	Россия, Томская область, Александровский район	0101000020E6100000895FB1868B755340EB1D6E8786394E40
2974	5	54	5666	38490	74333	\N	60.434488999999999	Томская область, Александровский район, с.Александровское, ул.ул.Пушкина 54б	Россия, Томская область, Александровский район, село Александровское	0101000020E61000004985B1852077534062BCE6559D374E40
2967	5	54	5666	38490	74699	\N	60.438221106890602	Томская область, Александровский район, ул. Партизанская 88 стр.1		0101000020E61000001893FE5E0A765340D0B52FA017384E40
8822	5	46	\N	59567	71977	\N	53.814700234778698	Республика Хакасия, город Черногорск, ул. Советская, д. 46		0101000020E6100000CD57C9C7EED156408E06F01648E84A40
8825	5	46	\N	12532	72126	\N	53.814311247076702	Республика Хакасия, город Черногорск, пер. Клубный, д. 5	Россия, Республика Хакасия, город Черногорск	0101000020E6100000C76647AAEFD15640F3E2C4573BE84A40
8836	5	46	\N	12532	71982	\N	53.813481176263899	Республика Хакасия, город Черногорск, ул. Юбилейная, д. 19А		0101000020E610000091D10149D8D156406D75392520E84A40
8834	5	46	\N	12532	71982	\N	53.813785944232301	Республика Хакасия, город Черногорск, ул. Юбилейная, д. 28А	Россия, Республика Хакасия, город Черногорск	0101000020E61000001EFD2FD7A2D15640A9F8BF232AE84A40
8833	5	46	\N	12532	71981	\N	53.813277999999997	Республика Хакасия, город Черногорск, ул. Чапаева, д. 49А		0101000020E6100000E60819C8B3D056403447567E19E84A40
8830	5	46	\N	12532	71981	\N	53.813481176263899	Республика Хакасия, город Черногорск, ул. Чапаева, д. 27А	Россия, Республика Хакасия, город Черногорск	0101000020E61000006ABDDF68C7D156406D75392520E84A40
8828	5	46	\N	12532	71942	\N	53.8142938858986	Республика Хакасия, город Черногорск, ул. Чайковского, д. 7		0101000020E610000030F2B22616D256401DAA29C93AE84A40
8817	5	46	\N	12532	71995	\N	53.813481176263899	Республика Хакасия, город Черногорск, ул. Фрунзе, д. 17	Россия, Республика Хакасия, город Черногорск	0101000020E61000002E3718EAB0D156406D75392520E84A40
8839	5	46	\N	12532	71941	\N	53.813277996381402	Республика Хакасия, город Черногорск, ул. Советская, д. 104		0101000020E6100000F58079C894D156403447567E19E84A40
8827	5	46	\N	12532	71941	\N	53.813481176263899	Республика Хакасия, город Черногорск, ул. Советская, д. 82В	Россия, Республика Хакасия, город Черногорск	0101000020E61000007F2F8507CDD156406D75392520E84A40
8786	5	46	\N	11092	73491	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Центральный мкр, №9а		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8826	5	46	\N	12532	71941	\N	53.812871633647603	Республика Хакасия, город Черногорск, ул. Советская, д. 79	Россия, Республика Хакасия, город Черногорск	0101000020E61000001C959BA8A5D15640C4EA8F300CE84A40
8815	5	46	\N	12532	71941	\N	53.812770042345697	Республика Хакасия, город Черногорск, ул. Советская, д. 26	Россия, Республика Хакасия, город Черногорск	0101000020E6100000E38BF67821D15640C095ECD808E84A40
8840	5	46	\N	12532	71945	\N	53.827337831681099	Республика Хакасия, город Черногорск, ул. Пушкина, д. 7А	Россия, Республика Хакасия, городской округ Черногорск	0101000020E61000000C8FFD2C96D45640785E2A36E6E94A40
8812	5	46	\N	12532	71739	\N	53.8148018213803	Республика Хакасия, город Черногорск, ул. Парковая, д. 16		0101000020E61000002F8A1EF818D25640925B936E4BE84A40
8811	5	46	\N	12532	72024	\N	53.8142096592805	Республика Хакасия, город Черногорск, ул. Октябрьская, д. 42	Россия, Республика Хакасия, город Черногорск	0101000020E6100000EFE2FDB8FDD15640C009850838E84A40
8810	5	46	\N	12532	72024	\N	53.813277996381402	Республика Хакасия, город Черногорск, ул. Октябрьская, д. 82		0101000020E6100000581B6327BCD156403447567E19E84A40
8808	5	46	\N	12532	72024	\N	53.812871633647603	Республика Хакасия, город Черногорск, ул. Октябрьская, д. 86	Россия, Республика Хакасия, город Черногорск	0101000020E61000004626E0D748D15640C4EA8F300CE84A40
8820	5	46	\N	12532	72006	\N	53.814700234778698	Республика Хакасия, город Черногорск, ул. Мира, д. 1А		0101000020E61000006EA296E656D156408E06F01648E84A40
8824	5	46	\N	12532	72225	\N	53.837060679881098	Республика Хакасия, город Черногорск, ул. Максима Горького, д. 11		0101000020E6100000807D74EACAD45640E7E099D024EB4A40
8816	5	46	\N	12532	72225	\N	53.812482628894799	Республика Хакасия, город Черногорск, ул. Максима Горького, д. 3	Россия, Республика Хакасия, город Черногорск	0101000020E610000003ED0E2906D256402AC76471FFE74A40
8842	5	46	\N	12532	72247	\N	53.815733450248402	Республика Хакасия, город Черногорск, ул. Ленина, д. 73	Россия, Республика Хакасия, город Черногорск	0101000020E61000002EE6E786A6D156404DA25EF069E84A40
8845	5	46	\N	12532	71943	\N	53.812058896305501	Республика Хакасия, город Черногорск, ул. Космонавтов, д. 44		0101000020E61000001B800D8810D2564013B69F8CF1E74A40
8841	5	46	\N	12532	71943	\N	53.813481176263899	Республика Хакасия, город Черногорск, ул. Космонавтов, д. 32	Россия, Республика Хакасия, город Черногорск	0101000020E61000008044132862D156406D75392520E84A40
8831	5	46	\N	12532	71943	\N	53.813277996381402	Республика Хакасия, город Черногорск, ул. Космонавтов, д. 21А		0101000020E6100000581B6327BCD156403447567E19E84A40
8813	5	46	\N	12532	71740	\N	53.8142938858986	Республика Хакасия, город Черногорск, ул. Комсомольская, д. 107		0101000020E610000091D10149D8D156401DAA29C93AE84A40
8809	5	46	\N	12532	71738	\N	53.814903407734498	Республика Хакасия, город Черногорск, ул. Кирова, д. 77		0101000020E6100000B8E52329E9D15640C634D3BD4EE84A40
8838	5	46	\N	12532	71983	\N	53.814497060833403	Республика Хакасия, город Черногорск, ул. Калинина, д. 38		0101000020E610000043A9BD88B6D1564056D80C7041E84A40
8837	5	46	\N	12532	71983	\N	53.833468821234597	Республика Хакасия, город Черногорск, ул. Калинина, д. 32		0101000020E6100000DA53724EECD456406B9DB81CAFEA4A40
8835	5	46	\N	12532	71983	\N	53.812465266955698	Республика Хакасия, город Черногорск, ул. Калинина, д. 15А		0101000020E6100000CE6C57E883D15640841266DAFEE74A40
8814	5	46	\N	12532	72240	\N	53.814903407734498	Республика Хакасия, город Черногорск, ул. Дружбы, д. 1А		0101000020E6100000CCEF3499F1D15640C634D3BD4EE84A40
8829	5	46	\N	12532	72227	\N	53.833202275218703	Республика Хакасия, город Черногорск, ул. Дзержинского, д. 12	Россия, Республика Хакасия, городской округ Черногорск	0101000020E6100000BFD364C6DBD456401C7BF65CA6EA4A40
8823	5	46	\N	12532	72025	\N	53.811855709496001	Республика Хакасия, город Черногорск, ул. горная, д. 96		0101000020E6100000E00ED4298FD15640DB87BCE5EAE74A40
8821	5	46	\N	12532	72015	\N	53.814514421927001	Республика Хакасия, город Черногорск, ул. Бограда, д. 104	Россия, Республика Хакасия, город Черногорск	0101000020E6100000C76647AAEFD156402C11A8FE41E84A40
8819	5	46	\N	12532	72015	\N	53.813277999999997	Республика Хакасия, город Черногорск, ул. Бограда, д. 3		0101000020E6100000E60819C8B3D056403447567E19E84A40
8844	5	46	\N	12532	9954	\N	53.813277999999997	Республика Хакасия, город Черногорск, ул. 30лет Победы, д. 93		0101000020E6100000E60819C8B3D056403447567E19E84A40
8843	5	46	\N	12532	9954	\N	53.813277996381402	Республика Хакасия, город Черногорск, ул. 30 лет Победы, д. 93		0101000020E61000006ABDDF68C7D156403447567E19E84A40
8832	5	46	\N	12532	71944	\N	53.816596907089803	Республика Хакасия, город Черногорск, ул. Космонавтов, д. 4А	Россия, Республика Хакасия, город Черногорск	0101000020E6100000569E40D829D256408081204086E84A40
8806	5	46	\N	12183	\N	\N	54.004776	"Республика Хакасия, город Сорск, ООО ""Сорский-горно-обогатительный комбинат"", ЦЕНТР - Промплощадка, здание ЦРММ"		0101000020E6100000F5B9DA8AFD8E564021E7FD7F9C004B40
8803	5	46	\N	12183	72023	\N	54.0043714717008	Республика Хакасия, город Сорск, улица Кирова, дом 32а		0101000020E6100000B7B6F0BC548F564081069B3A8F004B40
8802	5	46	\N	12183	72023	\N	54.003387078195097	Республика Хакасия, город Сорск, Кирова, дом 20		0101000020E610000003232F6B628F5640A31D37FC6E004B40
8804	5	46	\N	12183	72005	\N	54.004674843475499	Республика Хакасия, город Сорск, улица Геологов, дом 2		0101000020E6100000B81E85EB518F5640ED0DBE3099004B40
8805	5	46	\N	12183	72168	\N	54.0043714717008	Республика Хакасия, город Сорск, улица Боградская, дом 16	Россия, Республика Хакасия, город Сорск	0101000020E61000001BB96E4A798F564081069B3A8F004B40
8801	5	46	\N	12183	72022	\N	54.004802827776601	Республика Хакасия, город Сорск, 50 лет Октября, дом 36		0101000020E6100000DC0E0D8B518F56401BF67B629D004B40
8785	5	46	\N	11092	73487	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Заводской, №6а		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8792	5	46	\N	11092	72021	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Школьная, №4		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
25614	5	44	1140	47088	76778	\N	52.152022000000002	село Покровка, Подгорная, 21а		0101000020E610000051D9B0A6B2D25A40E222F77475134A40
8781	5	46	\N	11092	71967	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Советский мкр, №11		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8780	5	46	\N	11092	71972	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Ленинградский мкр, №51		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8778	5	46	\N	11092	73493	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Ленинградский мкр, №52		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8791	5	46	\N	11092	72020	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Комсомольский мкр, №60		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8789	5	46	\N	11092	72002	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Интернациональный мкр, №15		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8783	5	46	\N	11092	71974	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Заводской мкр, №34		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8782	5	46	\N	11092	73489	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Заводской мкр, №60		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8784	5	46	\N	11092	71975	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Заводской, №29		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8790	5	46	\N	11092	73485	\N	53.101674773586801	Республика Хакасия, город Саяногорск, Енисейский мкр, №20	Россия, Республика Хакасия, город Саяногорск	0101000020E6100000357D76C075DA564010E9B7AF038D4A40
8793	5	46	\N	11092	72003	\N	53.089897999999998	Республика Хакасия, город Саяногорск, Геологов, №6		0101000020E6100000FDDB65BFEED95640E7FC14C7818B4A40
8848	5	46	\N	14315	71984	\N	53.666445000000003	"Республика Хакасия, Алтайский район, с. Подсинее, ул. Октябрьская, д. 8 ""А"""		0101000020E61000009D0DF96706E3564097CADB114ED54A40
8847	5	46	\N	14315	72031	\N	53.6663430149177	Республика Хакасия, Алтайский район, с. Подсинее, ул. Зеленая, д. 4	Россия, Республика Хакасия, село Подсинее	0101000020E61000008B6B7C26FBE25640927538BA4AD54A40
8766	5	46	\N	7985	\N	\N	53.675145999999998	Республика Хакасия, город Абакан, станция Подсиний		0101000020E6100000A4E2FF8EA8E156403A03232F6BD64A40
8945	5	46	\N	7985	5238	\N	53.700164999999998	Республика Хакасия, Боградский район, д. Бей-Булук, ул. Ширинская, д. 4	Россия, Республика Хакасия, Абакан, улица Ширинская, 4	0101000020E6100000707841446ADC5640E466B8019FD94A40
9047	5	46	\N	7985	4497	\N	53.682554000000003	Республика Хакасия, Усть-Абаканский район, с. Красноозерное, Центральная (здание сельского Дома культуры), 29	Россия, Республика Хакасия, Абакан, улица Центральная, 29	0101000020E610000098BD6C3B6DD9564083E0F1ED5DD74A40
9040	5	46	\N	7985	4497	\N	53.684654999999999	Республика Хакасия, Усть-Абаканский район, аал Ах-Хол, Центральная, здание школы	Россия, Республика Хакасия, Абакан, улица Центральная, 1	0101000020E610000061545227A0D956407D0569C6A2D74A40
8974	5	46	\N	7985	4497	\N	53.684260000000002	Республика Хакасия, Орджоникидзевский район, д. Кагаево, ул. Центральная, д. 7	Россия, Республика Хакасия, Абакан, улица Центральная, 7	0101000020E6100000B91AD99596D9564001FBE8D495D74A40
8918	5	46	\N	7985	4497	\N	53.682169999999999	Республика Хакасия, Бейский район, аал Верх-Киндирла, ул. Центральная, д. 33	Россия, Республика Хакасия, Абакан, улица Центральная, 33	0101000020E61000000E4FAF9465D95640FA27B85851D74A40
8898	5	46	\N	7985	4497	\N	53.682692000000003	Республика Хакасия, Аскизский район, п. ст. Югачи, ул. Центральная, 27	Россия, Республика Хакасия, Абакан, улица Центральная, 27	0101000020E61000001343723271D95640D49E927362D74A40
8882	5	46	\N	7985	4497	\N	53.679625999999999	Республика Хакасия, Аскизский район, аал Усть-Таштып, ул. Центральная, 40А	Россия, Республика Хакасия, Абакан, улица Центральная, 40	0101000020E61000003B38D89B18D9564072C119FCFDD64A40
8760	5	46	\N	7985	2276	\N	53.730229821155902	Республика Хакасия, город Абакан, улица Тельмана, 98Б	Россия, Республика Хакасия, Абакан, улица Тельмана	0101000020E6100000F9D9C87553DB56406F47382D78DD4A40
9063	5	46	\N	7985	2369	\N	53.722521	Республика Хакасия, Ширинский район, д. Тупик, Советская, 18	Россия, Республика Хакасия, Абакан, улица Советская, 16	0101000020E6100000807F4A9528DD56402CD670917BDC4A40
8886	5	46	\N	7985	2369	\N	53.722974000000001	Республика Хакасия, Аскизский район, аал Отты, ул. Советская, 8	Россия, Республика Хакасия, Абакан, улица Советская, 8	0101000020E61000003AAFB14B54DD5640DDED7A698ADC4A40
8739	5	46	\N	7985	2525	\N	53.712447876566401	Республика Хакасия, город Абакан, улица Павших Коммунаров, 100	Россия, Республика Хакасия, Абакан, улица Павших Коммунаров, 100	0101000020E61000009BCAA2B08BDD5640E10CFE7E31DB4A40
8883	5	46	\N	7985	4498	\N	53.708517000000001	Республика Хакасия, Аскизский район, аал Сафронов, ул. Нагорная, 2	Россия, Республика Хакасия, Абакан, улица Нагорная, 4	0101000020E61000008BFB8F4C87DE56407CD45FAFB0DA4A40
8897	5	46	\N	7985	4663	\N	53.709828000000002	Республика Хакасия, Аскизский район, аал Тюрт-Тас, ул. Набережная, 7	Россия, Республика Хакасия, Абакан, улица Набережная, 6	0101000020E610000052B5DD04DFDE56407EE4D6A4DBDA4A40
9053	5	46	\N	7985	2805	\N	53.701864999999998	Республика Хакасия, Ширинский район, аал Марчелгаш, Молодежная, 19	Россия, Республика Хакасия, Абакан, улица Молодежная, 15	0101000020E610000025EA059FE6DF5640809A5AB6D6D94A40
9031	5	46	\N	7985	72296	\N	53.698175999999997	Республика Хакасия, Усть-Абаканский район, д. Чапаево, Мира (здание сельского Дома культуры), 71		0101000020E6100000228C9FC6BDDB5640116DC7D45DD94A40
9067	5	46	\N	7985	6552	\N	53.690286	Республика Хакасия, Ширинский район, аал Трошкин, Кадышева, 22	Россия, Республика Хакасия, Абакан, улица Кадышева, 22	0101000020E61000000D7217618AD956407E71A94A5BD84A40
8741	5	46	\N	7985	72050	\N	53.738351999999999	Республика Хакасия, город Абакан, улица Комарова, 6		0101000020E61000008FFAEB1516DC5640D5777E5182DE4A40
8748	5	46	\N	7985	71741	\N	53.745067794003901	Республика Хакасия, город Абакан, улица Маршала Жукова, 90	Россия, Республика Хакасия, Абакан, улица Жукова, 90	0101000020E6100000FED478E926DD5640E8A562635EDF4A40
8763	5	46	\N	7985	71994	\N	53.732110948642301	Республика Хакасия, город Абакан, улица Ивана Ярыгина, 43	Россия, Республика Хакасия, Абакан, улица Ярыгина	0101000020E61000002079E75086DB56405C0531D0B5DD4A40
8721	5	46	\N	7985	71994	\N	53.723209936280398	Республика Хакасия, город Абакан, улица Ивана Ярыгина, 28	Россия, Республика Хакасия, Абакан, улица Ярыгина, 28	0101000020E61000009FAD8383BDDB5640F111312592DC4A40
8719	5	46	\N	7985	72066	\N	53.726751	Республика Хакасия, город Абакан, улица Щетинкина, 27		0101000020E610000094895B0531DC5640EBAA402D06DD4A40
8718	5	46	\N	7985	72066	\N	53.720075000000001	Республика Хакасия, город Абакан, улица Щетинкина, 13		0101000020E6100000EE7C3F355EDC564067D5E76A2BDC4A40
8874	5	46	\N	7985	73524	\N	53.705525966369898	Республика Хакасия, Аскизский район, аал Апчинаев, ул. Школьная, 23	Россия, Республика Хакасия, Абакан, улица Школьная	0101000020E610000032FFE89B34DB5640253D0CAD4EDA4A40
8722	5	46	\N	7985	72109	\N	53.720086000000002	Республика Хакасия, город Абакан, улица Чернышевского, 43		0101000020E6100000A99F3715A9DA56405B272EC72BDC4A40
8735	5	46	\N	7985	72072	\N	53.702680999999998	Республика Хакасия, город Абакан, улица Челюскинцев, 6		0101000020E610000066A208A9DBDB5640A2427573F1D94A40
8737	5	46	\N	7985	72108	\N	53.712397000000003	Республика Хакасия, город Абакан, улица Хлебная, 28		0101000020E610000065A54929E8DB56405F622CD32FDB4A40
8749	5	46	\N	7985	72052	\N	53.722935999999997	Республика Хакасия, город Абакан, улица Хакасская, 6		0101000020E61000008716D9CEF7DD5640EF8CB62A89DC4A40
8723	5	46	\N	7985	72052	\N	53.717906999999997	Республика Хакасия, город Абакан, улица Хакасская, 165		0101000020E610000012A5BDC117DB5640E4486760E4DB4A40
8714	5	46	\N	7985	72052	\N	53.719946999999998	Республика Хакасия, город Абакан, улица Хакасская, 68		0101000020E6100000BEBED6A546DC564039ED293927DC4A40
8720	5	46	\N	7985	72098	\N	53.730283	Республика Хакасия, город Абакан, улица Тельмана, 93		0101000020E6100000A913D044D8DB564092E9D0E979DD4A40
8747	5	46	\N	7985	72074	\N	53.699689999999997	Республика Хакасия, город Абакан, улица Стофато, 18		0101000020E610000011018750A5D956404BAB21718FD94A40
8726	5	46	\N	7985	72100	\N	53.715994000000002	Республика Хакасия, город Абакан, улица Советская, 175		0101000020E6100000A3906456EFD95640ED10FFB0A5DB4A40
8725	5	46	\N	7985	72100	\N	53.717362999999999	Республика Хакасия, город Абакан, улица Советская, 171		0101000020E6100000361D01DC2CDA5640232E008DD2DB4A40
8757	5	46	\N	7985	2869	\N	53.746191000000003	Республика Хакасия, город Абакан, проезд Северный, 11	Россия, Республика Хакасия, Абакан, Северный проезд, 11	0101000020E61000005B7A34D593DB5640E7C8CA2F83DF4A40
8754	5	46	\N	7985	72090	\N	53.7105047013751	Республика Хакасия, город Абакан, улица Рыбацкая, 19	Россия, Республика Хакасия, Абакан, улица Рыбацкая, 19	0101000020E61000005C57CC086FE056407E52EDD3F1DA4A40
8740	5	46	\N	7985	72067	\N	53.720272999999999	Республика Хакасия, город Абакан, улица Пушкина, 30А		0101000020E6100000E2E995B20CDE56408D98D9E731DC4A40
8727	5	46	\N	7985	72067	\N	53.713856999999997	Республика Хакасия, город Абакан, улица Пушкина, 190		0101000020E61000000936AE7FD7D95640A5828AAA5FDB4A40
8724	5	46	\N	7985	72067	\N	53.716414999999998	Республика Хакасия, город Абакан, улица Пушкина, 122		0101000020E6100000E1D4079277DB564092AE997CB3DB4A40
8717	5	46	\N	7985	72067	\N	53.718193999999997	Республика Хакасия, город Абакан, улица Пушкина, 72		0101000020E6100000A1BE654E97DC56407A17EFC7EDDB4A40
8713	5	46	\N	7985	72067	\N	53.717458999999998	Республика Хакасия, город Абакан, улица Пушкина, 92		0101000020E61000001CEE23B726DC5640459C4EB2D5DB4A40
8732	5	46	\N	7985	72103	\N	53.703294	Республика Хакасия, город Абакан, улица Пирятинская, 20		0101000020E610000076A911FA99D956408CBCAC8905DA4A40
8730	5	46	\N	7985	72103	\N	53.705522000000002	Республика Хакасия, город Абакан, улица Пирятинская, 8		0101000020E61000000C40A374E9D95640E44D7E8B4EDA4A40
8729	5	46	\N	7985	72103	\N	53.703986999999998	Республика Хакасия, город Абакан, улица Пирятинская, 26		0101000020E610000015C8EC2C7AD9564092E7FA3E1CDA4A40
8751	5	46	\N	7985	72062	\N	53.714416	Республика Хакасия, город Абакан, улица Павших Коммунаров, 52		0101000020E6100000670FB40243DE56409CDEC5FB71DB4A40
8738	5	46	\N	7985	72062	\N	53.710537000000002	Республика Хакасия, город Абакан, улица Павших Коммунаров, 131		0101000020E610000039B4C876BEDC56408ACC5CE0F2DA4A40
8736	5	46	\N	7985	72062	\N	53.710515999999998	Республика Хакасия, город Абакан, улица Павших Коммунаров, 129		0101000020E6100000B075A911FADC564072A43330F2DA4A40
8750	5	46	\N	7985	72120	\N	53.713248999999998	Республика Хакасия, город Абакан, улица Островского, 24		0101000020E61000008FE4F21FD2DD5640CD7344BE4BDB4A40
8753	5	46	\N	7985	72088	\N	53.701822	Республика Хакасия, город Абакан, улица Молодежная, 20		0101000020E6100000618A7269FCDF564081CEA44DD5D94A40
8716	5	46	\N	7985	72056	\N	53.738298999999998	Республика Хакасия, город Абакан, улица Лермонтова, 12		0101000020E61000004CC3F01131DB5640B2D5E59480DE4A40
8743	5	46	\N	7985	2206	\N	53.724812	Республика Хакасия, город Абакан, проспект Ленина, 48	Россия, Республика Хакасия, Абакан, Ленина проспект, 48	0101000020E61000002176A6D079DD5640CADFBDA3C6DC4A40
8715	5	46	\N	7985	2206	\N	53.722878000000001	Республика Хакасия, город Абакан, проспект Ленина, 90	Россия, Республика Хакасия, Абакан, Ленина проспект, 90	0101000020E6100000FF428F183DDC5640BB7F2C4487DC4A40
8759	5	46	\N	7985	72051	\N	53.732142000000003	Республика Хакасия, город Абакан, улица Крылова, 73А		0101000020E61000002009FB7612DB564097033DD4B6DD4A40
8756	5	46	\N	7985	72050	\N	53.7402507905352	Республика Хакасия, город Абакан, улица Комарова, 15	Россия, Республика Хакасия, Абакан, улица Комарова, 11	0101000020E61000009AB1683A3BDC564068EA758BC0DE4A40
8755	5	46	\N	7985	72050	\N	53.741185999999999	Республика Хакасия, город Абакан, улица Комарова, 12		0101000020E6100000F0332E1C08DC56406420CF2EDFDE4A40
26007	5	44	1140	15579	76771	\N	52.367888999999998	с.Нестерово, Комсомольская, 34А		0101000020E6100000E20511A969F85A4071C79BFC162F4A40
8762	5	46	\N	7985	72107	\N	53.683002000000002	Республика Хакасия, город Абакан, улица Зоотехническая, 6		0101000020E6100000FAD346753AD95640228D0A9C6CD74A40
8746	5	46	\N	7985	72118	\N	53.731918	Республика Хакасия, город Абакан, улица Зеленая, 1		0101000020E6100000226E4E2503DE564047AD307DAFDD4A40
8752	5	46	\N	7985	71998	\N	53.721288239833797	Республика Хакасия, город Абакан, улица Маршала Жукова, 10	Россия, Республика Хакасия, Абакан, улица Жукова, 10	0101000020E610000025085740A1DD5640A67F492A53DC4A40
8758	5	46	\N	7985	2870	\N	53.737046999999997	Республика Хакасия, город Абакан, проспект Дружбы Народов, 21	Россия, Республика Хакасия, Абакан, Дружбы Народов проспект, 21	0101000020E61000007AA702EE79DB5640B54E5C8E57DE4A40
8731	5	46	\N	7985	72059	\N	53.707723000000001	Республика Хакасия, город Абакан, улица Гагарина, 82А		0101000020E610000019C8B3CBB7DA564042D0D1AA96DA4A40
8744	5	46	\N	7985	72053	\N	53.724471000000001	Республика Хакасия, город Абакан, улица Вяткина, 14		0101000020E610000020D099B4A9DC564041F33977BBDC4A40
8742	5	46	\N	7985	72053	\N	53.719729000000001	Республика Хакасия, город Абакан, улица Вяткина, 8		0101000020E6100000187D0569C6DC5640CC7D721420DC4A40
8745	5	46	\N	7985	2677	\N	53.737681000000002	Республика Хакасия, город Абакан, проезд Весенний, 6	Россия, Республика Хакасия, Абакан, Весенний проезд, 6	0101000020E6100000942F682101DD5640B7F0BC546CDE4A40
8728	5	46	\N	7985	72055	\N	53.725904	Республика Хакасия, город Абакан, улица Богдана Хмельницкого, 158		0101000020E610000095BBCFF1D1DB56408E041A6CEADC4A40
8733	5	46	\N	7985	72060	\N	53.696246000000002	Республика Хакасия, город Абакан, улица Белоярская, 60		0101000020E610000001892650C4DA564044FCC3961ED94A40
8734	5	46	\N	7985	72070	\N	53.700442000000002	Республика Хакасия, город Абакан, улица  Аскизская, 145		0101000020E610000068E6C93505DB5640575F5D15A8D94A40
8776	5	46	\N	10580	71737	\N	52.647320280526301	Республика Хакасия, город Абаза, ул. Энтузиастов, д. 4		0101000020E61000006825ADF886865640FB05BB61DB524A40
8775	5	46	\N	10580	72167	\N	52.642204	Республика Хакасия, город Абаза, ул. ТЭЦ, д. 10		0101000020E61000003EE76ED74B87564021AE9CBD33524A40
8777	5	46	\N	10580	71939	\N	52.649669412707198	Республика Хакасия, город Абаза, ул. Ленина, д. 31-А		0101000020E61000001D5BCF108E855640CE1C925A28534A40
8771	5	46	\N	10580	71939	\N	52.651780566656399	Республика Хакасия, город Абаза, ул. Ленина, д. 8-А		0101000020E6100000B3CEF8BEB8855640BC934F8F6D534A40
8770	5	46	\N	10580	71939	\N	52.642204	Республика Хакасия, город Абаза, ул. Ленина, д. 16-Г		0101000020E61000003EE76ED74B87564021AE9CBD33524A40
8769	5	46	\N	10580	71939	\N	52.651183230692098	Республика Хакасия, город Абаза, ул. Ленина, д. 24-А		0101000020E610000057EBC4E578865640085BECF659534A40
8774	5	46	\N	10580	72125	\N	52.650723524158401	Республика Хакасия, город Абаза, ул. Кулакова, д. 83-А	Россия, Республика Хакасия, город Абаза	0101000020E6100000295E656D53865640745C8DEC4A534A40
8773	5	46	\N	10580	72125	\N	52.642204	Республика Хакасия, город Абаза, ул. Кулакова, д. 5		0101000020E61000003EE76ED74B87564021AE9CBD33524A40
8772	5	46	\N	10580	72125	\N	52.642204	Республика Хакасия, город Абаза, ул. Кулакова, д. 3		0101000020E61000003EE76ED74B87564021AE9CBD33524A40
8767	5	46	\N	10580	72124	\N	52.646485002966401	Республика Хакасия, город Абаза, ул. Геологическая, д. 4	Россия, Республика Хакасия, город Абаза	0101000020E61000007D9752978C865640622D3E05C0524A40
8768	5	46	\N	10580	72166	\N	52.646599507906302	Республика Хакасия, город Абаза, ул. Вокзальная, д. 7	Россия, Республика Хакасия, город Абаза	0101000020E61000002849D74CBE865640FBCBEEC9C3524A40
9052	5	46	1651	22671	72205	\N	54.488624000000002	Республика Хакасия, Ширинский район, пгт Шира, Щетинина, 151		0101000020E61000007D5BB054177E56403605323B8B3E4B40
9050	5	46	1651	22671	72013	\N	54.488624000000002	Республика Хакасия, Ширинский район, пгт Шира, Школьная, 7		0101000020E61000007D5BB054177E56403605323B8B3E4B40
9051	5	46	1651	22671	71958	\N	54.488624000000002	Республика Хакасия, Ширинский район, пгт Шира, Рабочая, 3		0101000020E61000007D5BB054177E56403605323B8B3E4B40
9014	5	46	1651	22671	71996	\N	54.488624000000002	Республика Хакасия, Ширинский район, пгт Шира, Октябрьская, 80		0101000020E61000007D5BB054177E56403605323B8B3E4B40
9049	5	46	1651	22671	72268	\N	54.488624000000002	Республика Хакасия, Ширинский район, пгт Шира, Гаражная, 1		0101000020E61000007D5BB054177E56403605323B8B3E4B40
9068	5	46	1651	59591	72294	\N	54.684939783665499	Республика Хакасия, Ширинский район, с. Черное Озеро, Центральная, 2	Россия, Республика Хакасия, Ширинский район, село Черное Озеро	0101000020E61000004BE5ED08A75B564072DC291DAC574B40
9075	5	46	1651	25545	72163	\N	54.577956999999998	Республика Хакасия, Ширинский район, с. Целинное, Ленина, 7		0101000020E6100000E73922DFA57A564044BFB67EFA494B40
9077	5	46	1651	25640	72210	\N	54.629100999999999	Республика Хакасия, Ширинский район, с. Фыркал, Гагарина, 12		0101000020E61000007C9C69C2F6735640C170AE6186504B40
9057	5	46	1651	24709	71965	\N	54.338492944285697	Республика Хакасия, Ширинский район, пгт Туим, Первомайская, 5	Россия, Республика Хакасия, Ширинский район, поселок городского типа Туим	0101000020E6100000E1B88C9B1A7C5640647616BD532B4B40
9058	5	46	1651	24709	72411	\N	54.327257000000003	Республика Хакасия, Ширинский район, пгт Туим, Орджоникидзе, 111	Россия, Республика Хакасия, Ширинский район, поселок городского типа Туим	0101000020E610000094A5D6FB8D7B56408C31B08EE3294B40
9059	5	46	1651	24709	72046	\N	54.327257000000003	Республика Хакасия, Ширинский район, пгт Туим, Микрорайон, 8		0101000020E610000094A5D6FB8D7B56408C31B08EE3294B40
9055	5	46	1651	60022	73535	\N	54.541185158948899	Республика Хакасия, Ширинский район, аал Топанов, Школьная, 8	Россия, Республика Хакасия, Ширинский район, село Топанов	0101000020E6100000FCE42840146A5640FA0AD28C45454B40
9070	5	46	1651	25274	72340	\N	54.729917	Республика Хакасия, Ширинский район, д. Талкин Ключ, Нижняя, 16		0101000020E610000017BCE82B485B5640B0E595EB6D5D4B40
9080	5	46	1651	25766	72341	\N	54.384636999999998	Республика Хакасия, Ширинский район, с. Сон, Ленина, 4		0101000020E6100000C8B4368DED98564070EA03C93B314B40
9076	5	46	1651	25585	73518	\N	54.729334999999999	Республика Хакасия, Ширинский район, с. Соленоозерное, Карла Маркса, 42		0101000020E6100000772CB64945785640016A6AD95A5D4B40
9062	5	46	1651	33142	72209	\N	54.440396999999997	Республика Хакасия, Ширинский район, аал Малый Спирин, Победы, 13		0101000020E6100000B88FDC9A747C5640D520CCED5E384B40
9054	5	46	1651	59595	72335	\N	54.541944000000001	Республика Хакасия, Ширинский район, аал Малый Кобежиков, Таежная, 39	Россия, Республика Хакасия, Ширинский район, село Малый Кобежиков	0101000020E61000004F401361C36E5640B821C66B5E454B40
9061	5	46	1651	24879	71966	\N	54.345498999999997	Республика Хакасия, Ширинский район, пгт Коммунар, 50 лет ВЛКСМ, 6		0101000020E6100000C0594A96935256407DE6AC4F392C4B40
9056	5	46	1651	24670	71999	\N	54.482855000000001	Республика Хакасия, Ширинский район, п. Колодезный, Микрорайон, 1		0101000020E6100000EF8D210038895640E4DA5031CE3D4B40
9065	5	46	1651	25037	72339	\N	54.4679789968514	Республика Хакасия, Ширинский район, с. Ефремкино, Трактовая, 1	Россия, Республика Хакасия, Ширинский район, село Ефремкино	0101000020E61000004D4D8237A45C56407E1B62BCE63B4B40
9072	5	46	1651	25340	72148	\N	54.810127999999999	Республика Хакасия, Ширинский район, с. Джирим, 50 лет ВЛКСМ, 14		0101000020E6100000E7FF55478E99564075C93846B2674B40
9081	5	46	1651	60031	73551	\N	54.388763184801398	Республика Хакасия, Ширинский район, д. Гальджа, Мира, 15	Россия, Республика Хакасия, Ширинский район, село Гольджа	0101000020E61000009624CFF57DA056408A7269FCC2314B40
8977	5	46	1651	20932	73523	\N	54.619708000000003	Республика Хакасия, Орджоникидзевский район, п. Гайдаровск, ул. Целинная, д. 3		0101000020E6100000577BD80B054B5640E8887C97524F4B40
9073	5	46	1651	25434	72375	\N	54.704492000000002	Республика Хакасия, Ширинский район, с. Ворота, ул. Гагарина, 2		0101000020E610000052465C001AA1564096253ACB2C5A4B40
9079	5	46	1651	25749	73510	\N	54.464433999999997	Республика Хакасия, Ширинский район, д. Власьево, Октябрьская, 1		0101000020E6100000211E8997A79956404293C492723B4B40
9078	5	46	1651	25672	72211	\N	54.463057999999997	Республика Хакасия, Ширинский район, с. Борец, Ленина, 12		0101000020E61000007289230F4497564059130B7C453B4B40
9082	5	46	1651	25869	72409	\N	54.139878000000003	Республика Хакасия, Ширинский район, п. Беренжак, Школьная, 15		0101000020E610000047AD307DAF5E564007B7B585E7114B40
9069	5	46	1651	25237	72407	\N	54.556243000000002	Республика Хакасия, Ширинский район, д. Белый Балахчин, Новая, 30		0101000020E61000006BF12900C65E564081D07AF832474B40
8846	5	46	1625	59576	\N	\N	53.910031825554398	Республика Хакасия, город Черногорск, поселок Пригорск, п. Пригорск Администрация поселка		0101000020E610000062F6B2EDB4D056402028B7ED7BF44A40
9039	5	46	1625	59582	72091	\N	53.702627647942897	Республика Хакасия, Усть-Абаканский район, аал Чарков, Ленина (здание сельского Дома культуры), 19	Россия, Республика Хакасия, Усть-Абаканский район, село Чарков	0101000020E6100000CA4FAA7D3A9856407FA0DCB6EFD94A40
9041	5	46	1625	23894	71964	\N	53.834426211117297	Республика Хакасия, Усть-Абаканский район, с. Усть-Бюр, Ленина (здание сельского Дома культуры), 50	Россия, Республика Хакасия, Усть-Абаканский район, село Усть-Бюр	0101000020E61000001F9DBAF2598F56404F779E78CEEA4A40
9019	5	46	1625	22714	72011	\N	53.8243899272492	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Спортивная (здание Дома культуры им. Гагарина), 6а	Россия, Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан	0101000020E6100000915F3FC406D9564021938C9C85E94A40
9015	5	46	1625	22714	72214	\N	53.823780544031401	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Подгорный квартал, здание библиотеки	Россия, Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан	0101000020E6100000A6D1E4620CD956407808E3A771E94A40
9018	5	46	1625	22714	71960	\N	53.833021899548299	"Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Октябрьская (здание районного Дома культуры ""Дружба"", 17"	Россия, Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан	0101000020E6100000CDE506431DD956409C6C0377A0EA4A40
9017	5	46	1625	22714	71989	\N	53.831854149004798	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Мира (здание школы № 2), 44	Россия, Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан	0101000020E61000006A4B1DE4F5D85640FD851E317AEA4A40
9016	5	46	1625	22714	71989	\N	53.8325141859399	"Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Мира (здание культурного досугового центра ""Имидж"", 40а"	Россия, Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан	0101000020E61000007FBDC282FBD8564028BB99D18FEA4A40
9021	5	46	1625	22714	71961	\N	53.830889460840801	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Кирова  (здание школы № 1), 38	Россия, Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан	0101000020E6100000812557B1F8D8564096CD1C925AEA4A40
9022	5	46	1625	22714	72374	\N	53.822968000000003	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Заречная (здание сельского Дома культуры), 1		0101000020E610000031957EC2D9D85640C8D3F20357E94A40
9023	5	46	1625	22714	73507	\N	53.826703300530603	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Добровольского (здание ПУ-12), 14		0101000020E61000009DB98784EFD85640A7406667D1E94A40
9024	5	46	1625	60006	73514	\N	53.833732688212301	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, Волкова  (здание  коррекционной школы), 15	Россия, Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан	0101000020E61000007E552E54FED85640494C50C3B7EA4A40
9020	5	46	1625	60006	73488	\N	53.823069585689304	Республика Хакасия, Усть-Абаканский район, пгт Усть-Абакан, 30 лет Победы (здание школы № 3), 1		0101000020E6100000915F3FC406D95640CC28965B5AE94A40
9027	5	46	1625	23244	71962	\N	53.788421999999997	Республика Хакасия, Усть-Абаканский район, п. Тепличный, Ленина (здание сельского Дома культуры), 40а		0101000020E610000081B2295778D5564034B91803EBE44A40
9033	5	46	1625	23537	72196	\N	53.677226009840297	Республика Хакасия, Усть-Абаканский район, п. Ташеба, Вокзальная (здание сельского клуба), 2	Россия, Республика Хакасия, Усть-Абаканский район, село Ташеба	0101000020E610000081CD397826D356401D007157AFD64A40
8966	5	46	1625	20346	72235	\N	54.165720999999998	Республика Хакасия, Боградский район, с. Сонское, ул. Линейная, д. 8		0101000020E610000028EE7893DF8D564055A1815836154B40
9046	5	46	1625	24167	72264	\N	53.690499000000003	Республика Хакасия, Усть-Абаканский район, село Солнечное, 10-й Пятилетки (здание сельского Дома культуры), 15		0101000020E610000042EC4CA1F3CB5640DA756F4562D84A40
9032	5	46	1625	59590	72288	\N	53.619427841167301	Республика Хакасия, Усть-Абаканский район, аал Сапогов, Майская (здание сельского Дома культуры), 35	Россия, Республика Хакасия, Усть-Абаканский район, село Сапогов	0101000020E6100000A986FD9E58D25640041DAD6A49CF4A40
9026	5	46	1625	23210	72204	\N	53.787560999999997	Республика Хакасия, Усть-Абаканский район, п. Расцвет, Школьная (здание сельского Дома культуры), 1в		0101000020E6100000F3AD0FEB8DD65640724D81CCCEE44A40
9034	5	46	1625	59579	72044	\N	53.522101585942899	Республика Хакасия, Усть-Абаканский район, аал Райков, 30 лет Победы (здание школы), 10	Россия, Республика Хакасия, Усть-Абаканский район, село Райков	0101000020E6100000295E656D53CB56408D96033DD4C24A40
9044	5	46	1625	60038	73569	\N	53.925773028794701	Республика Хакасия, Усть-Абаканский район, аал Мохов, Школьная (здание начальной школы), 1	Россия, Республика Хакасия, Усть-Абаканский район, село Мохов	0101000020E6100000FC8F4C874EDA56408942CBBA7FF64A40
9043	5	46	1625	24020	72176	\N	53.927261999999999	Республика Хакасия, Усть-Абаканский район, с. Московское, Советская (здание администрации МО Московский сельсовет), 30		0101000020E6100000A6F27684D3C656406A696E85B0F64A40
9048	5	46	1625	24266	72337	\N	53.791145999999998	Республика Хакасия, Усть-Абаканский район, д. Курганная, Урожайная (здание школы), 4		0101000020E610000038F8C264AAC756403C2EAA4544E54A40
9042	5	46	1625	23971	73516	\N	53.904522	Республика Хакасия, Усть-Абаканский район, д. Ковыльная, Школьная (здание сельского Дома культуры), 20		0101000020E610000091BA9D7DE5CB56409A417C60C7F34A40
9038	5	46	1625	23757	73521	\N	53.620144000000003	Республика Хакасия, Усть-Абаканский район, д. Капчалы, Школьная (здание сельского Дома культуры), 20	Россия, Республика Хакасия, Усть-Абаканский район, село Капчалы	0101000020E6100000963FDF162CAF5640C367EBE060CF4A40
9029	5	46	1625	23325	71990	\N	53.752738555479397	Республика Хакасия, Усть-Абаканский район, с. Калинино, Школьная (здание сельского Дома культуры), 58	Россия, Республика Хакасия, Усть-Абаканский район, село Калинино	0101000020E61000006342CC2555D956403DB665C059E04A40
9030	5	46	1625	23325	72238	\N	53.752941999999997	Республика Хакасия, Усть-Абаканский район, с. Калинино, Советская (здание сельского Дома культуры), 88		0101000020E6100000C57421567FD9564075E4486760E04A40
9036	5	46	1625	23692	72405	\N	53.515895	Республика Хакасия, Усть-Абаканский район, п. Имени Ильича, Ленина (здание школы), 1		0101000020E610000080D4264EEEBB5640C095ECD808C24A40
9028	5	46	1625	23294	71963	\N	53.774426176836798	Республика Хакасия, Усть-Абаканский район, с. Зеленое, Хакасская (здание сельского Дома культуры), 6	Россия, Республика Хакасия, Усть-Абаканский район, село Зеленое	0101000020E61000007DD0B359F5D356400796236420E34A40
9035	5	46	1625	59586	72201	\N	53.443412287557699	Республика Хакасия, Усть-Абаканский район, аал Доможаков, Механизаторская (здание сельского Дома культуры), 46	Россия, Республика Хакасия, Усть-Абаканский район, село Доможаков	0101000020E6100000124E0B5EF4C15640B55373B9C1B84A40
9037	5	46	1625	23722	72202	\N	53.622846000000003	Республика Хакасия, Усть-Абаканский район, с. Весеннее, Мира (здание сельского Дома культуры), 26		0101000020E6100000863C821B29AD5640E338F06AB9CF4A40
9045	5	46	1625	24086	72174	\N	53.977535000000003	Республика Хакасия, Усть-Абаканский район, с. Вершино-Биджа, 30 лет Победы (здание сельского Дома культуры), 81		0101000020E6100000A31D37FC6EBE564002D9EBDD1FFD4A40
9007	5	46	1669	22376	72400	\N	52.813678000000003	Республика Хакасия, Таштыпский район, с. Чиланы, Центральная, 39		0101000020E61000008E93C2BCC7825640C3BCC79926684A40
9012	5	46	1669	22578	72347	\N	52.900567000000002	Республика Хакасия, Таштыпский район, д. Харой, Хакасская, 3		0101000020E6100000153B1A87FA775640AD6D8AC745734A40
9002	5	46	1669	22126	72327	\N	52.712195712826798	Республика Хакасия, Таштыпский район, п. Харачул, Школьная, 20	Россия, Республика Хакасия, Таштыпский район, село Харачул	0101000020E61000003410CB660E915640C72B103D295B4A40
8994	5	46	1669	21762	72042	\N	52.793985999999997	Республика Хакасия, Таштыпский район, с. Таштып, Ленина, 37		0101000020E610000079AF5A99F0785640ADBD4F55A1654A40
8995	5	46	1669	21762	72043	\N	52.793985999999997	Республика Хакасия, Таштыпский район, с. Таштып, Карла Маркса, 47		0101000020E610000079AF5A99F0785640ADBD4F55A1654A40
9008	5	46	1669	22404	72401	\N	52.86157	Республика Хакасия, Таштыпский район, д. Печегол, Мирная, 4		0101000020E6100000425F7AFB738556407C9BFEEC476E4A40
8990	5	46	1669	21552	73513	\N	52.630881000000002	Республика Хакасия, Таштыпский район, д. Нижний Матур, Центральная, 8		0101000020E61000001E19ABCDFF5C56407A5567B5C0504A40
26065	5	44	\N	60864	76545	\N	55.634451448795097	Республика Бурятия, город Северобайкальск, 60 лет ВЛКСМ, 6		0101000020E6100000E2AE5E4546545B400EF5BBB035D14B40
8991	5	46	1669	60012	73525	\N	52.780336232535902	Республика Хакасия, Таштыпский район, д. Нижний Курулгаш, Мира, 13	Россия, Республика Хакасия, Таштыпский район, село Нижний Курлугаш	0101000020E61000009AB0FD648C7556401BF2CF0CE2634A40
9009	5	46	1669	22427	72330	\N	52.827305000000003	Республика Хакасия, Таштыпский район, д. Нижний Имек, Советская, 23		0101000020E61000001EA67D737F7D56409D685721E5694A40
8992	5	46	1669	21650	72299	\N	52.755339999999997	Республика Хакасия, Таштыпский район, с. Нижние Сиры, Советская, 28 А		0101000020E610000060C8EA56CF70564029AE2AFBAE604A40
8989	5	46	1669	21509	72259	\N	52.656332999999997	Республика Хакасия, Таштыпский район, с. Матур, Клубная, 7		0101000020E61000000F289B72855D56408D2441B802544A40
9000	5	46	1669	22035	72193	\N	52.716583	Республика Хакасия, Таштыпский район, п. Малые Арбаты, Советская, 81 Д		0101000020E6100000454772F90F9456404EEFE2FDB85B4A40
9003	5	46	1669	22192	72397	\N	52.753945000000002	Республика Хакасия, Таштыпский район, д. Малая Сея, Центральная, 42		0101000020E61000006ABFB51325755640CAFD0E4581604A40
8997	5	46	1669	21900	72364	\N	52.786230191135502	Республика Хакасия, Таштыпский район, д. Кызылсуг, Луговая, 10	Россия, Республика Хакасия, Таштыпский район, село Кызылсуг	0101000020E610000054E41071736356402A91442FA3644A40
9013	5	46	1669	22615	73517	\N	52.331136000000001	Республика Хакасия, Таштыпский район, п. Кубайка, Набережная, 4 Б		0101000020E610000037C7B94DB87456409E4319AA622A4A40
9010	5	46	1669	22477	72260	\N	52.850630000000002	Республика Хакасия, Таштыпский район, с. Имек, Юбилейная, 16 А		0101000020E610000095826E2F697B56408D7F9F71E16C4A40
9005	5	46	1669	22266	72398	\N	52.680956999999999	Республика Хакасия, Таштыпский район, д. Верхняя Сея, Школьная, 32		0101000020E610000017F2086EA46C5640BB7D569929574A40
9011	5	46	1669	22549	73511	\N	52.872794874940297	Республика Хакасия, Таштыпский район, д. Верхний Имек, Молодежная, 7 А	Россия, Республика Хакасия, Таштыпский район, село Верхний Имек	0101000020E6100000D2E3F736FD755640618E1EBFB76F4A40
8993	5	46	1669	21710	72361	\N	52.774025000000002	Республика Хакасия, Таштыпский район, д. Верхние Сиры, Октябрьская, 25-1		0101000020E61000001F317A6EA16D5640A9A44E4013634A40
8998	5	46	1669	21951	72324	\N	52.811413000000002	Республика Хакасия, Таштыпский район, п. Верх-Таштып, Школьная, 23		0101000020E6100000C554FA09675C56404E469561DC674A40
9006	5	46	1669	22331	73508	\N	52.813263999999997	Республика Хакасия, Таштыпский район, д. Бутрахты, Кунучакова, 19		0101000020E610000002F566D47C7F5640CF81E50819684A40
9001	5	46	1669	22106	72365	\N	52.714329999999997	Республика Хакасия, Таштыпский район, д. Большие Арбаты, Сосновая, 20		0101000020E61000007D04FEF0F39756409D465A2A6F5B4A40
9004	5	46	1669	22236	72402	\N	52.741379999999999	Республика Хакасия, Таштыпский район, с. Большая Сея, Советская, 17		0101000020E61000007C80EECB9972564049F4328AE55E4A40
8999	5	46	1669	22010	72140	\N	52.695259	Республика Хакасия, Таштыпский район, с. Арбаты, Титова, 9		0101000020E6100000FEBAD39D27925640F59F353FFE584A40
8996	5	46	1669	21843	72362	\N	52.807516	Республика Хакасия, Таштыпский район, с. Анчул, Советская, 21		0101000020E61000006F8099EFE05E5640957F2DAF5C674A40
8973	5	46	1627	20707	72145	\N	54.906118999999997	Республика Хакасия, Орджоникидзевский район, с. Устинкино, ул. Советская, д. 13		0101000020E6100000FBE59315C363564061A417B5FB734B40
8986	5	46	1627	21360	72257	\N	54.865099000000001	Республика Хакасия, Орджоникидзевский район, с. Сарала, ул. Центральная, д. 151		0101000020E6100000FB2477D8444F5640B2666490BB6E4B40
8988	5	46	1627	21464	72336	\N	54.657975	Республика Хакасия, Орджоникидзевский район, с. Приисковое, ул. Заводская, д. 15		0101000020E6100000FA2AF9D85D2C5640F54A598638544B40
8975	5	46	1627	33154	72329	\N	54.820777999999997	Республика Хакасия, Орджоникидзевский район, д. Подкамень, ул. Центральная, д. 2		0101000020E610000027C11BD2A85C56405DA3E5400F694B40
8987	5	46	1627	21434	72360	\N	54.774509000000002	Республика Хакасия, Орджоникидзевский район, с. Орджоникидзевское, пер. Школьный, д. 6		0101000020E6100000BF982D59153E564095BA641C23634B40
8978	5	46	1627	20998	72237	\N	55.079962999999999	Республика Хакасия, Орджоникидзевский район, с. Новомарьясово, ул. Ленина, д. 29		0101000020E6100000A5677A89B1875640EDF1423A3C8A4B40
8982	5	46	1627	21202	72393	\N	55.039011959277197	Республика Хакасия, Орджоникидзевский район, д. Монастырево, ул. Школьная, д. 15	Россия, Республика Хакасия, Орджоникидзевский район, село Монастырево	0101000020E6100000772D211FF499564066136058FE844B40
8972	5	46	1627	20690	9970	\N	54.952717999999997	Республика Хакасия, Орджоникидзевский район, д. Малый Сютик, ул. Песочная, д. 6		0101000020E6100000DA3A38D89B755640BF27D6A9F2794B40
8976	5	46	1627	20912	72404	\N	55.030323000000003	Республика Хакасия, Орджоникидзевский район, д. Костино, ул. Центральная, д. 1		0101000020E610000018B0E42A1660564087A8C29FE1834B40
8970	5	46	1627	20583	72192	\N	55.039687000000001	Республика Хакасия, Орджоникидзевский район, с. Копьево, ул. Механизаторов, д. 11А		0101000020E61000009B560A815C765640C689AF7614854B40
8968	5	46	1627	20392	71988	\N	54.992021999999999	Республика Хакасия, Орджоникидзевский район, пгт Копьево, ул. Партизанская, д. 16		0101000020E61000005649641F64745640CD74AF93FA7E4B40
8967	5	46	1627	20392	71988	\N	54.992021999999999	Республика Хакасия, Орджоникидзевский район, пгт Копьево, ул. Партизанская, д. 6А		0101000020E61000005649641F64745640CD74AF93FA7E4B40
8969	5	46	1627	20392	72333	\N	54.992021999999999	Республика Хакасия, Орджоникидзевский район, пгт Копьево, ул. Залинейная, д. 23		0101000020E61000005649641F64745640CD74AF93FA7E4B40
8980	5	46	1627	21105	72392	\N	55.100255094858497	Республика Хакасия, Орджоникидзевский район, д. Конгарово, ул. Центральная, д. 29	Россия, Республика Хакасия, Орджоникидзевский район, село Конгарово	0101000020E610000038F3AB39408E56405721E527D58C4B40
8984	5	46	1627	21267	72394	\N	54.893518999999998	Республика Хакасия, Орджоникидзевский район, д. Кожухово, ул. Залинейная, д. 7		0101000020E6100000F20C1AFA2773564064ADA1D45E724B40
8981	5	46	1627	21151	72334	\N	54.957096999999997	Республика Хакасия, Орджоникидзевский район, д. Когунек, ул. Центральная, д. 52		0101000020E6100000ED7F80B56A8D5640C30C8D27827A4B40
8985	5	46	1627	21332	72396	\N	54.796719000000003	Республика Хакасия, Орджоникидзевский район, д. Кобяково, ул. Мира, д. 32		0101000020E6100000265305A392715640098D60E3FA654B40
8983	5	46	1627	21226	72256	\N	54.700721000000001	Республика Хакасия, Орджоникидзевский район, с. Июс, ул. Центральная, д. 5		0101000020E61000004582A966D67056406A4FC939B1594B40
8979	5	46	1627	21058	73505	\N	55.050545	Республика Хакасия, Орджоникидзевский район, д. Горюново, ул. Новая, д. 13		0101000020E610000081CF0F23848B5640F8FC304278864B40
8971	5	46	1627	20595	72358	\N	55.018768000000001	Республика Хакасия, Орджоникидзевский район, д. Большой Сютик, ул. Молодежная, д. 14		0101000020E61000000070ECD9737756400D1B65FD66824B40
8949	5	46	1574	19391	73500	\N	54.463732999999998	Республика Хакасия, Боградский район, д. Черемушка, ул. Трактовая, д. 8В		0101000020E6100000BB9BA73AE4BF5640B9895A9A5B3B4B40
8948	5	46	1574	19336	72309	\N	54.445596999999999	Республика Хакасия, Боградский район, с. Усть-Ерба, ул. Молодежная, д. 17		0101000020E61000007555A01683CA56400D198F5209394B40
8950	5	46	1574	19425	72301	\N	54.282368756603198	Республика Хакасия, Боградский район, с. Троицкое, ул. Молодежная, д. 16	Россия, Республика Хакасия, Боградский район, село Троицкое	0101000020E61000005F7AFB73D1C55640BE33DAAA24244B40
8954	5	46	1574	19641	72379	\N	54.057639000000002	Республика Хакасия, Боградский район, д. Толчея, ул. Школьная, д. 13		0101000020E61000006C425A63D0C45640B1FCF9B660074B40
8955	5	46	1574	19711	72383	\N	54.146107000000001	Республика Хакасия, Боградский район, д. Таежная, ул. Школьная, д. 10		0101000020E6100000B804E09F52BD5640BC5B59A2B3124B40
8956	5	46	1574	19740	72234	\N	54.112836999999999	Республика Хакасия, Боградский район, с. Советская Хакасия, ул. Школьная, д. 5		0101000020E610000091D442C9E4DB5640AE635C71710E4B40
8941	5	46	1574	18949	72190	\N	54.774352999999998	Республика Хакасия, Боградский район, с. Сарагаш, ул. Зеленая, д. 1		0101000020E6100000F0FD0DDAABAF56409D47C5FF1D634B40
8965	5	46	1574	20242	72297	\N	54.226284640466602	Республика Хакасия, Боградский район, с. Пушное, ул. Зеленая, д. 2	Россия, Республика Хакасия, Боградский район, село Пушное	0101000020E610000056B60F79CB9E5640A54929E8F61C4B40
8953	5	46	1574	19607	72378	\N	54.217951999999997	Республика Хакасия, Боградский район, д. Полиндейка, ул. Зеленая, д. 12		0101000020E61000002191B6F127C85640840CE4D9E51B4B40
8943	5	46	1574	19067	72215	\N	54.584958999999998	Республика Хакасия, Боградский район, с. Первомайское, ул. Школьная, д. 2Н		0101000020E6100000FD6CE4BA29B256401C40BFEFDF4A4B40
8957	5	46	1574	19819	72325	\N	54.092992000000002	Республика Хакасия, Боградский район, д. Красный Камень, ул. Торговая, д. 6		0101000020E61000007CD2890453D1564013656F29E70B4B40
8964	5	46	1574	59597	72391	\N	54.308561214799802	Республика Хакасия, Боградский район, д. Карасук, ул. Подгорная, д. 6	Россия, Республика Хакасия, Боградский район, село Карасуг	0101000020E6100000481B47ACC5A6564018E945ED7E274B40
8947	5	46	1574	19311	71957	\N	54.356556372559602	Республика Хакасия, Боградский район, с. Знаменка, ул. Дзержинского, д. 75	Россия, Республика Хакасия, Боградский район, село Знаменка	0101000020E61000009EB64604E3BE5640A69883A0A32D4B40
8944	5	46	1574	19138	73506	\N	54.584786999999999	Республика Хакасия, Боградский район, д. Заречная, ул. Степная, д. 10Б		0101000020E610000009E066F162AD56401F10E84CDA4A4B40
8963	5	46	1574	20135	72357	\N	54.320163000000001	Республика Хакасия, Боградский район, д. Верх-Ерба, ул. Школьная, д. 10Б		0101000020E610000041F4A44C6AB05640D331E719FB284B40
8946	5	46	1574	19231	73501	\N	54.538972000000001	Республика Хакасия, Боградский район, д. Борозда, ул. Горная, д. 4А		0101000020E61000002DB4739A05B35640D8BAD408FD444B40
8952	5	46	1574	19541	72158	\N	54.097845	Республика Хакасия, Боградский район, с. Бородино, ул. Пушкина, д. 20		0101000020E6100000B936548CF3C75640DF89592F860C4B40
8962	5	46	1574	20089	72191	\N	54.249932999999999	Республика Хакасия, Боградский район, с. Большая Ерба, ул. Зеленая, д. 2А		0101000020E610000073D9E89C9FA756407898F6CDFD1F4B40
8960	5	46	1574	19861	72161	\N	54.227148	Республика Хакасия, Боградский район, с. Боград, ул. Партизанская, д. 19		0101000020E6100000F0366F9C14B6564008AD872F131D4B40
8958	5	46	1574	19861	71971	\N	54.227148	Республика Хакасия, Боградский район, с. Боград, ул. Новая, д. 18		0101000020E6100000F0366F9C14B6564008AD872F131D4B40
8959	5	46	1574	19861	72009	\N	54.227148	Республика Хакасия, Боградский район, с. Боград, ул. 50 лет Октября, д. 19		0101000020E6100000F0366F9C14B6564008AD872F131D4B40
8961	5	46	1574	20041	73502	\N	54.147714999999998	Республика Хакасия, Боградский район, д. Белелик, ул. Центральная, д. 24		0101000020E6100000D0D556EC2FAF564077103B53E8124B40
8942	5	46	1574	19043	72331	\N	54.835822877477	Республика Хакасия, Боградский район, д. Базандаиха, ул. Центральная, д. 7		0101000020E6100000016BD5AE09AC56404F1F813FFC6A4B40
8951	5	46	1574	19490	72355	\N	54.272569532823397	Республика Хакасия, Боградский район, с. Абакано-Перевоз, ул. Новая, д. 1	Россия, Республика Хакасия, Боградский район, село Абакано-Перевоз	0101000020E610000066D993C0E6D3564074EFE192E3224B40
8934	5	46	1506	59583	72139	\N	53.106476000000001	Республика Хакасия, Бейский район, д. Новокурск, ул. Садовая, д. 58		0101000020E6100000198EE733A0D056408AE76C01A18D4A40
8928	5	46	1506	60018	73531	\N	53.348400921738502	Республика Хакасия, Бейский район, аал Шалгинов, ул. Школьная, д. 19	Россия, Республика Хакасия, Бейский район, село Шалгинов	0101000020E6100000DB6FED4449BC564065726A6798AC4A40
8799	5	46	1506	60005	\N	\N	52.8481433852644	Республика Хакасия, город Саяногорск, поселок Черемушки, №48		0101000020E6100000EE409DF2E8DA564069AA27F38F6C4A40
8797	5	46	1506	60005	\N	\N	52.8582750037734	Республика Хакасия, город Саяногорск, поселок Черемушки, №51		0101000020E6100000B29B19FD68DA5640B9FC87F4DB6D4A40
25955	5	44	\N	60876	76920	\N	50.350461000000003	г. Кяхта, ул. Цыбиктарова, д. 1		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
8800	5	46	1506	59571	\N	\N	52.851572814505197	Республика Хакасия, город Саяногорск, поселок Черемушки, №33	Россия, Республика Хакасия, Бейский район, поселок городского типа Черемушки	0101000020E61000003B35971B0CDB56400C941458006D4A40
8798	5	46	1506	59571	\N	\N	52.848247311362599	Республика Хакасия, город Саяногорск, поселок Черемушки, №14	Россия, Республика Хакасия, Бейский район, поселок городского типа Черемушки	0101000020E6100000027FF8F9EFDA56400EF7915B936C4A40
8927	5	46	1506	60021	73534	\N	53.239930000000001	Республика Хакасия, Бейский район, аал Чаптыков, ул. Набережная, д. 4	Россия, Республика Хакасия, Бейский район, село Чаптыков	0101000020E6100000AC38D55A98B3564026AAB706B69E4A40
8930	5	46	1506	18404	73499	\N	53.077570999999999	Республика Хакасия, Бейский район, д. Уты, ул. Кооперативная, д. 5		0101000020E6100000766D6FB724B256401B0FB6D8ED894A40
8921	5	46	1506	17939	73503	\N	53.033504000000001	Республика Хакасия, Бейский район, д. Усть-Киндирла, ул. Чебодаева, д. 46		0101000020E6100000BD512B4CDFA856408124ECDB49844A40
8919	5	46	1506	17826	72040	\N	52.938360804995298	Республика Хакасия, Бейский район, с. Табат, ул. Ленина, д. 140А	Россия, Республика Хакасия, Бейский район, село Табат	0101000020E6100000F3565D876AAD5640C26B97361C784A40
8933	5	46	1506	18524	72254	\N	53.088746	Республика Хакасия, Бейский район, с. Сабинка, ул. Молодежная, д. 1А		0101000020E6100000CB2F833122CB56404ED367075C8B4A40
8931	5	46	1506	18415	72186	\N	53.151904999999999	Республика Хакасия, Бейский район, с. Новотроицкое, пер. Гаражный, д. 1	Россия, Республика Хакасия, Бейский район, село Новотроицкое	0101000020E610000080D6FCF84BC35640A88C7F9F71934A40
8938	5	46	1506	18823	72359	\N	53.193634000000003	Республика Хакасия, Бейский район, д. Новониколаевка, ул. Мира, д. 62		0101000020E6100000CDE67118CCD2564064B2B8FFC8984A40
8937	5	46	1506	18738	72255	\N	53.164572	Республика Хакасия, Бейский район, с. Новоенисейка, ул. Ленина, д. 15А		0101000020E6100000276A696E85E056402DEBFEB110954A40
8917	5	46	1506	60037	73568	\N	53.0116724773088	Республика Хакасия, Бейский район, аал Маткечик, ул. Школьная, д. 4	Россия, Республика Хакасия, Бейский район, село Маткичек	0101000020E61000006902452C629B5640B323D5777E814A40
8915	5	46	1506	17633	72354	\N	52.841377999999999	Республика Хакасия, Бейский район, д. Малый Монок, ул. Школьная, д. 20		0101000020E6100000A98592C9A99C564075C93846B26B4A40
8794	5	46	1506	59569	71991	\N	52.998030419527502	Республика Хакасия, город Саяногорск, поселок Майна, Советская, №2	Россия, Республика Хакасия, Бейский район, поселок городского типа Майна	0101000020E61000004A0A2C8029DF5640A4367172BF7F4A40
8795	5	46	1506	59569	72004	\N	53.0020694790542	Республика Хакасия, город Саяногорск, поселок Майна, Победы, №8	Россия, Республика Хакасия, Бейский район, поселок городского типа Майна	0101000020E610000036069D103ADF5640EFAA07CC43804A40
8926	5	46	1506	18198	73504	\N	53.196579	Республика Хакасия, Бейский район, с. Куйбышево, ул. Октябрьская, д. 3		0101000020E61000005184D4EDECB156404A0A2C8029994A40
8914	5	46	1506	17621	73512	\N	53.022655999999998	Республика Хакасия, Бейский район, аал Красный Ключ, ул. Школьная, д. 5		0101000020E6100000EA7B0DC171C4564072874D64E6824A40
8936	5	46	1506	17621	72371	\N	53.022655999999998	Республика Хакасия, Бейский район, д. Красный Катамор, ул. Ленина, д. 49		0101000020E6100000EA7B0DC171C4564072874D64E6824A40
8929	5	46	1506	60015	73528	\N	53.159468797958901	Республика Хакасия, Бейский район, аал Койбалы, ул. Школьная, д. 8	Россия, Республика Хакасия, Бейский район, село Койбалы	0101000020E6100000A471A8DF85A95640E8DCED7A69944A40
8932	5	46	1506	18521	71956	\N	53.280710999999997	Республика Хакасия, Бейский район, с. Кирба, ул. Октябрьская, д. 12		0101000020E6100000F3E2C4573BCE564050508A56EEA34A40
8935	5	46	1506	18640	72332	\N	53.070126999999999	Республика Хакасия, Бейский район, д. Калы, ул. Гагарина, д. 15		0101000020E610000010070951BED1564086C8E9EBF9884A40
8940	5	46	1506	18940	72380	\N	53.270161999999999	Республика Хакасия, Бейский район, д. Дмитриевка, ул. Молодежная, д. 24		0101000020E61000009B745B2217D956409C4F1DAB94A24A40
8925	5	46	1506	18128	72377	\N	52.997169	Республика Хакасия, Бейский район, д. Дехановка, ул. Щетинкина, д. 24		0101000020E6100000D0F23CB83BBF5640E2CAD93BA37F4A40
8920	5	46	1506	60019	73532	\N	52.991375327351598	Республика Хакасия, Бейский район, д. Буденовка, ул. Ленина, д. 32	Россия, Республика Хакасия, Бейский район, село Буденновка	0101000020E6100000782AE09EE7B4564037894160E57E4A40
8916	5	46	1506	17719	72039	\N	52.930656375098899	Республика Хакасия, Бейский район, с. Бондарево, ул. 50 лет Октября, д. 4А	Россия, Республика Хакасия, Бейский район, село Бондарево	0101000020E61000003B8F8AFF3B9F5640C0E95DBC1F774A40
8913	5	46	1506	17537	72308	\N	52.870387999999998	Республика Хакасия, Бейский район, с. Большой Монок, ул. Октябрьская, д. 49		0101000020E6100000A088450C3B925640596ABDDF686F4A40
8796	5	46	1506	60013	73526	\N	52.978273527079097	Республика Хакасия, город Саяногорск, деревня Богословка, Центральная, №64	Россия, Республика Хакасия, Бейский район, село Богословка	0101000020E61000006728EE7893D1564078431A15387D4A40
8922	5	46	1506	18008	71954	\N	53.048918	Республика Хакасия, Бейский район, с. Бея, ул. Площадь Советов, д. 20А		0101000020E61000003A90F5D4EABA5640C617EDF142864A40
8923	5	46	1506	18008	72251	\N	53.048918	Республика Хакасия, Бейский район, с. Бея, ул. Павших партизан, д. 24		0101000020E61000003A90F5D4EABA5640C617EDF142864A40
8924	5	46	1506	18008	72188	\N	53.048918	Республика Хакасия, Бейский район, с. Бея, ул. Лесная, д. 1		0101000020E61000003A90F5D4EABA5640C617EDF142864A40
8904	5	46	1402	17102	72351	\N	53.32226	Республика Хакасия, Аскизский район, п. Шора, ул. Центральная, 18		0101000020E61000001E15FF77445656408C67D0D03FA94A40
8885	5	46	1402	16131	72150	\N	52.962831999999999	Республика Хакасия, Аскизский район, с. Усть-Чуль, улица Тейская, 39		0101000020E6100000450E1137A777564069C537143E7B4A40
8896	5	46	1402	60016	73529	\N	53.135689227457199	Республика Хакасия, Аскизский район, д. Усть-Хойза, ул. Школьная, 4	Россия, Республика Хакасия, Аскизский район, село Усть-Хоиза	0101000020E6100000C30C8D27827A5640A6B6D4415E914A40
8890	5	46	1402	16404	71969	\N	53.351014999999997	Республика Хакасия, Аскизский район, с. Усть-Камышта, ул. Мира, 1А		0101000020E610000071E481C822AD5640E5B33C0FEEAC4A40
8880	5	46	1402	59585	72187	\N	52.953612451903901	Республика Хакасия, Аскизский район, с. Усть-Есть, ул. Советская, 73	Россия, Республика Хакасия, Аскизский район, село Усть-Есь	0101000020E6100000CE3461FBC98F56405D8940F50F7A4A40
8912	5	46	1402	60011	73522	\N	53.161365000000004	Республика Хакасия, Аскизский район, аал Усть-База, ул. Школьная, 11	Россия, Республика Хакасия, Аскизский район, село Усть-База	0101000020E6100000225514AFB29856400ADCBA9BA7944A40
8891	5	46	1402	16432	72159	\N	53.387779999999999	Республика Хакасия, Аскизский район, с. Пуланколь, ул. Победы, 9		0101000020E6100000C58D5BCCCFA656407D0569C6A2B14A40
8881	5	46	1402	15934	72242	\N	52.956463999999997	Республика Хакасия, Аскизский район, с. Полтаков, ул. Первомайская, 8		0101000020E610000001344A97FE8B564092E68F696D7A4A40
8884	5	46	1402	16102	72367	\N	52.934221000000001	Республика Хакасия, Аскизский район, д. Нижняя Тея, ул. Школьная, 1		0101000020E610000098C3EE3B86825640431EC18D94774A40
8910	5	46	1402	17391	72306	\N	53.216276000000001	Республика Хакасия, Аскизский район, село Нижняя База, ул. Школьная, 3		0101000020E61000008466D7BD15965640717495EEAE9B4A40
8906	5	46	1402	17202	72328	\N	53.347828239662697	Республика Хакасия, Аскизский район, п. Неожиданный, ул. Октябрьская, 3		0101000020E6100000C72DE6E7864456400951BEA085AC4A40
8873	5	46	1402	15549	72352	\N	53.156992000000002	Республика Хакасия, Аскизский район, д. Луговая, ул. Степная, 8		0101000020E6100000D40FEA2285A45640E8DD585018944A40
8895	5	46	1402	16623	72142	\N	53.112637999999997	Республика Хакасия, Аскизский район, с. Кызлас, ул. Превомайская, 1		0101000020E6100000753C66A0327D5640B72407EC6A8E4A40
8889	5	46	1402	59589	72276	\N	53.236532166201499	Республика Хакасия, Аскизский район, аал Катанов, ул. Школьная, 2	Россия, Республика Хакасия, Аскизский район, село Катанов	0101000020E610000095EF1989D0AD56408E3A3AAE469E4A40
8892	5	46	1402	16510	73498	\N	53.564791999999997	Республика Хакасия, Аскизский район, с. Камышта, ул. Баланкульская, 16		0101000020E6100000C1C6F5EFFA9856406E85B01A4BC84A40
8894	5	46	1402	16609	72349	\N	53.221871999999998	Республика Хакасия, Аскизский район, д. Казановка, ул. Новая, 22		0101000020E6100000B7989F1B9A825640F5F23B4D669C4A40
8888	5	46	1402	59596	72348	\N	52.987396365047502	Республика Хакасия, Аскизский район, аал Илиморов, ул. Чахсы-Хоных, 21	Россия, Республика Хакасия, Аскизский район, село Илиморов	0101000020E61000007097FDBAD37A5640C119FCFD627E4A40
8903	5	46	1402	17000	71970	\N	53.268008000000002	Республика Хакасия, Аскизский район, пгт Вершина Теи, ул. Советская, 5		0101000020E6100000ECA17DACE06356407F880D164EA24A40
8902	5	46	1402	17000	71970	\N	53.268008000000002	Республика Хакасия, Аскизский район, пгт Вершина Теи, ул. Советская, 36		0101000020E6100000ECA17DACE06356407F880D164EA24A40
8887	5	46	1402	16207	72295	\N	52.992276192422999	Республика Хакасия, Аскизский район, аал Верхняя Тея, ул. Тейская, 35	Россия, Республика Хакасия, Аскизский район, село Верхняя Тея	0101000020E6100000554E7B4ACE6E5640874D64E6027F4A40
8911	5	46	1402	17425	72290	\N	53.244903000000001	Республика Хакасия, Аскизский район, аал Верхняя База, ул. Солнечная, 14		0101000020E6100000691A14CD039356409DD843FB589F4A40
8893	5	46	1402	16529	72169	\N	53.163837999999998	Республика Хакасия, Аскизский район, с. Верх-Аскиз, ул. Мира, 71		0101000020E610000023A0C211A48B5640C8EBC1A4F8944A40
8901	5	46	1402	16935	71952	\N	53.452987399439301	Республика Хакасия, Аскизский район, пгт Бискамжа, ул. Железнодорожная, 4	Россия, Республика Хакасия, Аскизский район, поселок городского типа Бискамжа	0101000020E6100000EC51B81E85615640AF415F7AFBB94A40
8900	5	46	1402	16840	72153	\N	53.344312000000002	Республика Хакасия, Аскизский район, с. Бирикчуль, ул. Советская, 8		0101000020E61000005FEB5223F478564068CF656A12AC4A40
8899	5	46	1402	16840	71951	\N	53.344312000000002	Республика Хакасия, Аскизский район, с. Бирикчуль, ул. Богдана Ховруна, 5		0101000020E61000005FEB5223F478564068CF656A12AC4A40
8879	5	46	1402	15716	72305	\N	53.031548999999998	Республика Хакасия, Аскизский район, с. Бельтирское, ул. Щорса, 6		0101000020E610000093A8177C9A9956405A9C31CC09844A40
8877	5	46	1402	15716	71950	\N	53.031548999999998	Республика Хакасия, Аскизский район, с. Бельтирское, ул. Ленина, 37		0101000020E610000093A8177C9A9956405A9C31CC09844A40
8876	5	46	1402	15716	71986	\N	53.031548999999998	Республика Хакасия, Аскизский район, с. Бельтирское, ул. Абаканская, 29		0101000020E610000093A8177C9A9956405A9C31CC09844A40
8905	5	46	1402	17124	71987	\N	53.418879426239101	Республика Хакасия, Аскизский район, с. Балыкса, пер. Почтовый, 12	Россия, Республика Хакасия, Аскизский район, село Балыкса	0101000020E610000032755776C148564097FDBAD39DB54A40
8907	5	46	1402	60008	73495	\N	53.133714140616902	Республика Хакасия, Аскизский район, поселок Аскиз, ул. Советская, 2		0101000020E6100000C74ACCB3929B56403882548A1D914A40
8908	5	46	1402	60008	73494	\N	53.133714140616902	Республика Хакасия, Аскизский район, поселок Аскиз, ул. Октябрьская, 22		0101000020E6100000F12E17F19D9B56403882548A1D914A40
8909	5	46	1402	17236	72353	\N	53.134540000000001	Республика Хакасия, Аскизский район, поселок Аскиз, ул. Нагорная, 30		0101000020E6100000DCBC7152989B56407E00529B38914A40
8870	5	46	1402	15443	71985	\N	53.130552999999999	Республика Хакасия, Аскизский район, с. Аскиз, ул. Советская, 20		0101000020E61000008A20CEC309A2564085B2F0F5B5904A40
8872	5	46	1402	15443	71949	\N	53.130552999999999	Республика Хакасия, Аскизский район, с. Аскиз, ул. Промышленная, 28		0101000020E61000008A20CEC309A2564085B2F0F5B5904A40
8871	5	46	1402	15443	72034	\N	53.130552999999999	Республика Хакасия, Аскизский район, с. Аскиз, ул. Горького, 10		0101000020E61000008A20CEC309A2564085B2F0F5B5904A40
8875	5	46	1402	60014	73527	\N	53.016218462848599	Республика Хакасия, Аскизский район, аал Анхаков, ул. Школьная, 16	Россия, Республика Хакасия, Аскизский район, село Анхаков (Ворошилово)	0101000020E610000008043A9336955640A3CD716E13824A40
8849	5	46	1343	59592	72307	\N	53.438183000000002	"Республика Хакасия, Алтайский район, д. Кайбалы, пер. Проспектный, д. 4 ""А"""		0101000020E610000056F31C91EFDD5640E3546B6116B84A40
8860	5	46	1343	14960	72414	\N	53.382559999999998	Республика Хакасия, Алтайский район, д. Смирновка, ул. Алтайская, д. 34		0101000020E61000007AA9D898D7D75640FE60E0B9F7B04A40
8857	5	46	1343	60024	73537	\N	53.466979339485803	Республика Хакасия, Алтайский район, аал Сартыков, ул. Мира, д. 49	Россия, Республика Хакасия, Алтайский район, село Сартыков	0101000020E6100000DA3BA3AD4ACB56409B75C6F7C5BB4A40
8869	5	46	1343	15367	72151	\N	53.169868000000001	Республика Хакасия, Алтайский район, с. Очуры, ул. Советская, д. 144		0101000020E61000001F300F99F2E956408751103CBE954A40
8864	5	46	1343	15130	72230	\N	53.378714000000002	Республика Хакасия, Алтайский район, с. Новороссийское, ул. Щетинкина, д. 7		0101000020E6100000535C55F65DE65640C8444AB379B04A40
8868	5	46	1343	15342	72232	\N	53.252623999999997	"Республика Хакасия, Алтайский район, с. Новомихайловка, ул. Новая, д. 10 ""А"""		0101000020E6100000E197FA7953E45640A417B5FB55A04A40
8862	5	46	1343	15045	73497	\N	53.414693	"Республика Хакасия, Алтайский район, д. Лукьяновка, ул. Центральная, д. 2 ""Б"""		0101000020E610000068244223D8E35640A87004A914B54A40
8861	5	46	1343	14979	72326	\N	53.5082695124729	Республика Хакасия, Алтайский район, д. Летник, ул. Молодежная, д. 2		0101000020E6100000E63FA4DFBEE95640DBC4C9FD0EC14A40
8859	5	46	1343	14873	72372	\N	53.430534000000002	Республика Хакасия, Алтайский район, с. Краснополье, ул. Строителей, д. 11		0101000020E610000068B0A9F3A8D7564075E8F4BC1BB74A40
8867	5	46	1343	15264	72147	\N	53.344059000000001	Республика Хакасия, Алтайский район, с. Кирово, ул. Ленина, д. 88		0101000020E61000006EDC627E6EF856407E7214200AAC4A40
8856	5	46	1343	14771	71940	\N	53.552388999999998	Республика Хакасия, Алтайский район, п. Изыхские Копи, ул. Ленина, д. 2		0101000020E6100000DFE1766858D25640C7D5C8AEB4C64A40
8863	5	46	1343	15068	73515	\N	53.326638000000003	"Республика Хакасия, Алтайский район, д. Герасимово, ул. Комсомольская, д. 1 ""А"""		0101000020E61000007F8978EBFCE35640C0D02346CFA94A40
8865	5	46	1343	15147	72413	\N	53.407740660329999	Республика Хакасия, Алтайский район, д. Березовка, пер. Березовый, д. 1	Россия, Республика Хакасия, Алтайский район, село Берёзовка	0101000020E6100000A4198BA6B3E95640821E6ADB30B44A40
8855	5	46	1343	14482	72016	\N	53.599380200541901	"Республика Хакасия, Алтайский район, с. Белый Яр, пер. Садовый, д. 5 ""Д"""	Россия, Республика Хакасия, Алтайский район, село Белый Яр	0101000020E61000008F183DB7D0D8564030F0DC7BB8CC4A40
8854	5	46	1343	14482	71948	\N	53.598359084459197	Республика Хакасия, Алтайский район, с. Белый Яр, ул. Советская, д. 4	Россия, Республика Хакасия, Алтайский район, село Белый Яр	0101000020E610000056629E95B4D856403622180797CC4A40
8853	5	46	1343	14482	71946	\N	53.599278090049602	Республика Хакасия, Алтайский район, с. Белый Яр, ул. Октябрьская, д. 20		0101000020E6100000DFA815A6EFD856402C9B3924B5CC4A40
8852	5	46	1343	14482	72032	\N	53.6002991838131	Республика Хакасия, Алтайский район, с. Белый Яр, ул. Кирова, д. 46		0101000020E610000031B610E4A0D856402769FE98D6CC4A40
8850	5	46	1343	14482	72032	\N	53.599584420782499	Республика Хакасия, Алтайский район, с. Белый Яр, ул. Кирова, д. 165	Россия, Республика Хакасия, Алтайский район, село Белый Яр	0101000020E6100000A3224E27D9D85640399A232BBFCC4A40
8851	5	46	1343	14482	72008	\N	53.599380200541901	Республика Хакасия, Алтайский район, с. Белый Яр, ул. Аткниных, д. 80	Россия, Республика Хакасия, Алтайский район, село Белый Яр	0101000020E610000031B610E4A0D8564030F0DC7BB8CC4A40
8858	5	46	1343	59584	72137	\N	53.412347980999797	Республика Хакасия, Алтайский район, с. Аршаново, ул. Ленина, д. 68	Россия, Республика Хакасия, Алтайский район, село Аршанов	0101000020E61000006E85B01A4BC456401749BBD1C7B44A40
8866	5	46	1343	60017	73530	\N	53.443503999999997	Республика Хакасия, Алтайский район, с. Алтай, пер. Школьный, д. 6	Россия, Республика Хакасия, Алтайский район, село Алтай	0101000020E610000018265305A3F3564095D233BDC4B84A40
4555	5	45	\N	28323	73349	\N	51.707898920952303	Республика Тыва, Юбилейная, 14	Россия, Республика Тыва, Кызыл	0101000020E610000018CC5F21739D574080EF366F9CDA4940
4552	5	45	\N	28323	72425	\N	51.719153860321001	Республика Тыва, город Кызыл, Эрзинская, 8	Россия, Республика Тыва, Кызыл	0101000020E6100000A20BEA5BE69B5740D064FF3C0DDC4940
4534	5	45	\N	28323	72444	\N	51.698890983982103	Республика Тыва, город Кызыл, Щетинкина-Кравченко, 46	Россия, Республика Тыва, Кызыл	0101000020E61000005890662C9A9E5740003CA24275D94940
4543	5	45	\N	28323	72424	\N	51.718514018682498	Республика Тыва, город Кызыл, Советская, 14	Россия, Республика Тыва, Кызыл	0101000020E6100000765089EB189C5740ECDB4944F8DB4940
4538	5	45	\N	28323	73354	\N	51.717154546256197	Республика Тыва, город Кызыл, Салчака Тока, 14	Россия, Республика Тыва, Кызыл	0101000020E610000014419C87139B5740D9942BBCCBDB4940
4537	5	45	\N	28323	73354	\N	51.706463929678897	Республика Тыва, город Кызыл, Салчака Тока, 2	Россия, Республика Тыва, Кызыл	0101000020E610000056B950F9D79F574092E68F696DDA4940
4540	5	45	\N	28323	72423	\N	51.717661125303898	Республика Тыва, город Кызыл, Ровенская, 25	Россия, Республика Тыва, Кызыл	0101000020E6100000DBC1887D029C5740AD4ECE50DCDB4940
4530	5	45	\N	28323	72422	\N	51.715315194643402	Республика Тыва, город Кызыл, Рабочая, 58	Россия, Республика Тыва, Кызыл	0101000020E610000015713AC9569C57404BAB21718FDB4940
4529	5	45	\N	28323	72422	\N	51.697184228758701	Республика Тыва, город Кызыл, Рабочая, 4	Россия, Республика Тыва, Кызыл	0101000020E6100000CB9C2E8B899A5740B1A547533DD94940
4551	5	45	\N	28323	73342	\N	51.715954977646497	Республика Тыва, город Кызыл, ул.Правобережная, 54	Россия, Республика Тыва, Кызыл	0101000020E610000012A1116C5C9C57402F34D769A4DB4940
4550	5	45	\N	28323	73342	\N	51.724058108249103	Республика Тыва, город Кызыл, Правобережная, 54	Россия, Республика Тыва, Кызыл	0101000020E6100000520C9068029C57401E34BBEEADDC4940
4528	5	45	\N	28323	72441	\N	51.708703570881099	Республика Тыва, город Кызыл, Оюна Курседи, 54	Россия, Республика Тыва, Кызыл	0101000020E6100000F69B89E9429F5740AE450BD0B6DA4940
4527	5	45	\N	28323	72441	\N	51.719153860321001	Республика Тыва, город Кызыл, Оюна Курседи, 4	Россия, Республика Тыва, Кызыл	0101000020E6100000ED6305BF0D9C5740D064FF3C0DDC4940
4549	5	45	\N	28323	73350	\N	51.7157417176563	Республика Тыва, город Кызыл, Московская, 105/1	Россия, Республика Тыва, Кызыл	0101000020E6100000EB8CEF8B4B9C5740D32F116F9DDB4940
4547	5	45	\N	28323	73353	\N	51.723844999999997	Республика Тыва, город Кызыл, Лопсанчапа, 29/2		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4526	5	45	\N	28323	72431	\N	51.718087521951603	Республика Тыва, город Кызыл, Лермонтова, 1	Россия, Республика Тыва, Кызыл	0101000020E610000064AE0CAA0D9C574035D3BD4EEADB4940
4557	5	45	\N	28323	72428	\N	51.721114769882199	Республика Тыва, Ленина, 36	Россия, Республика Тыва, Кызыл	0101000020E610000045BB0A293F9C5740D8D30E7F4DDC4940
4533	5	45	\N	28323	72428	\N	51.7127559716536	Республика Тыва, город Кызыл, Ленина, 1	Россия, Республика Тыва, Кызыл	0101000020E610000026FE28EACC9C57408E03AF963BDB4940
4536	5	45	\N	28323	72443	\N	51.716168236625798	Республика Тыва, город Кызыл, Красноармейская, 176	Россия, Республика Тыва, Кызыл	0101000020E6100000753BFBCA839C57408B389D64ABDB4940
4532	5	45	\N	28323	72443	\N	51.709130156568797	Республика Тыва, город Кызыл, Красноармейская, 76	Россия, Республика Тыва, Кызыл	0101000020E6100000E738B709F79D5740664E97C5C4DA4940
4539	5	45	\N	28323	72432	\N	51.723844999999997	Республика Тыва, город Кызыл, Кочетова, 165		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4535	5	45	\N	28323	72432	\N	51.714888667587097	Республика Тыва, город Кызыл, Кочетова, 59/1	Россия, Республика Тыва, Кызыл	0101000020E6100000ED478AC8B09C574094A2957B81DB4940
4525	5	45	\N	28323	72438	\N	51.723844999999997	Республика Тыва, город Кызыл, Колхозная, 56		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4524	5	45	\N	28323	72438	\N	51.723844999999997	Республика Тыва, город Кызыл, Колхозная, 67		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4523	5	45	\N	28323	72438	\N	51.723844999999997	Республика Тыва, город Кызыл, Колхозная, 2А		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4545	5	45	\N	28323	72445	\N	51.723844999999997	Республика Тыва, город Кызыл, Кечил-оола, 2а		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4544	5	45	\N	28323	72445	\N	51.723844999999997	Республика Тыва, город Кызыл, Кечил-оола, 15		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4542	5	45	\N	28323	72445	\N	51.710196603097202	Республика Тыва, город Кызыл, Кечил-оола, 73	Россия, Республика Тыва, Кызыл	0101000020E6100000E50E9BC8CC9E5740D15B3CBCE7DA4940
4548	5	45	\N	28323	72433	\N	51.7202200692942	Республика Тыва, город Кызыл, Калинина, 1	Россия, Республика Тыва, Кызыл	0101000020E6100000C91F0C3CF79B57406AF6402B30DC4940
4546	5	45	\N	28323	72433	\N	51.723844999999997	Республика Тыва, город Кызыл, Калинина, 1в		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4541	5	45	\N	28323	72433	\N	51.723844999999997	Республика Тыва, город Кызыл, Калинина, 116		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4531	5	45	\N	28323	73341	\N	51.723844999999997	Республика Тыва, город Кызыл, Интернациональная, 106		0101000020E61000008D9944BDE09B5740C22FF5F3A6DC4940
4554	5	45	\N	29675	72421	\N	51.174308594821099	Республика Тыва, г.Ак-Довурак, Юбилейная, 1	Россия, Республика Тыва, Ак-Довурак	0101000020E6100000D5963AC8EBA656400133DFC14F964940
4553	5	45	\N	29675	73362	\N	51.173473000000001	Республика Тыва, город Ак-Довурак, ул.Центральная, 23		0101000020E6100000B60F79CBD5A4564098DEFE5C34964940
4558	5	45	\N	29675	72429	\N	51.177437841979803	Республика Тыва, город Ак-Довурак, ул. Ленина, 24	Россия, Республика Тыва, Ак-Довурак	0101000020E6100000B1E07EC003A65640A988D349B6964940
4556	5	45	\N	29675	73337	\N	51.170207878813301	Республика Тыва, город Ак-Довурак, Данзырык-калдар-оола, 76	Россия, Республика Тыва, Ак-Довурак	0101000020E6100000E9818FC18AA6564040C23060C9954940
4700	5	45	724	5045	73474	\N	50.261049867446602	Республика Тыва, Эрзинский кожуун, село Эрзин, ул. С. Тока 8	Россия, Республика Тыва, Эрзинский район, поселок Эрзин	0101000020E6100000D74E948444CA5740764F1E166A214940
4703	5	45	724	59933	73391	\N	50.202415085423802	Республика Тыва, Эрзинский кожуун, сумон Нарын, Чаа Суур, 1	Россия, Республика Тыва, Эрзинский район, поселок Нарын	0101000020E61000005393E00D69E45740249C16BCE8194940
4701	5	45	724	59953	73414	\N	50.313116646906103	Республика Тыва, Эрзинский кожуун, сумон Морен,  ул. Дажимба Данил, 19	Россия, Республика Тыва, Эрзинский район, поселок Морен	0101000020E6100000D1ADD7F4A0D757402B69C53714284940
4702	5	45	724	5130	73477	\N	50.268317000000003	Республика Тыва, Эрзинский кожуун, с. Булун-Бажы, ул. Галина Доваадор, 20		0101000020E6100000D53C47E4BBCD5740FDFA213658224940
4699	5	45	724	59995	73473	\N	50.298932999999998	Республика Тыва, Эрзинский кожуун, сумон Бай-Даг, Ленина, 46	Россия, Республика Тыва, Эрзинский район, поселок Бай-Даг	0101000020E6100000FEB8FDF2C9C65740FB58C16F43264940
4695	5	45	7500	60036	73567	\N	51.3640469971266	Республика Тыва, Чеди-Хольский кожуун, сумон Элегест,  ул. Школьная 5	Россия, Республика Тыва, Тандинский район, поселок Элегест	0101000020E6100000109546CCEC7C57407C9A931799AE4940
4684	5	45	593	59963	73427	\N	51.614078537729199	Республика Тыва, Улуг-Хемский кожуун, сумон Эйлиг-Хем, ул. Маадыр-оола 2	Россия, Республика Тыва, Улуг-Хемский район, поселок Эйлиг-Хем	0101000020E6100000715985CD002B5740871403249ACE4940
4691	5	45	593	59981	73453	\N	51.605576999999997	Республика Тыва, Чаа-Хольский кожуун, сумон Шанчы, ул.  Даваа Самбуу,13		0101000020E6100000E1D05B3CBCFD5640DA1A118C83CD4940
4675	5	45	593	3725	73480	\N	51.529170000000001	Республика Тыва, Улуг-Хемский кожуун, город Шагонар, ул. Саяно-Шушенская, 2а		0101000020E61000000DFCA886FD3A57401D03B2D7BBC34940
4677	5	45	593	3725	73347	\N	51.529170000000001	город Шагонар, Октябрьская, 32		0101000020E61000000DFCA886FD3A57401D03B2D7BBC34940
4676	5	45	593	3725	73347	\N	51.533607476477499	город Шагонар, Октябрьская, 28	Россия, Республика Тыва, Улуг-Хемский район, Шагонар	0101000020E61000005AB91798153B574056F5F23B4DC44940
4678	5	45	593	3725	73467	\N	51.529170000000001	Республика Тыва, Улуг-Хемский кожуун, город Шагонар, Дружба, 55а		0101000020E61000000DFCA886FD3A57401D03B2D7BBC34940
4682	5	45	593	4045	73389	\N	51.376744000000002	Республика Тыва, Улуг-Хемский кожуун, с. Чодураа,  ул. Школьная 13		0101000020E6100000E9D2BF24953857406C7BBB2539B04940
4688	5	45	593	4397	73471	\N	51.514811999999999	Республика Тыва, Чаа-Хольский кожуун, село Чаа-Холь, ул.  Школьная 1	Россия, Республика Тыва, Улуг-Хемский район, поселок Чаа-Холь	0101000020E610000018D2E1218C1557404FCB0F5CE5C14940
4680	5	45	593	60026	73541	\N	51.564334534126701	Республика Тыва, Улуг-Хемский кожуун, сумон Хайыракан, ул. Кускелдей, 12	Россия, Республика Тыва, Улуг-Хемский район, поселок Хайыракан	0101000020E6100000144031B2644957407C7E18213CC84940
4683	5	45	593	59932	73388	\N	51.329410000000003	Республика Тыва, Улуг-Хемский кожуун, сумон Торгалыг, Советская, 51	Россия, Республика Тыва, Улуг-Хемский район, поселок Торгалыг	0101000020E6100000632AFD84B3345740D97C5C1B2AAA4940
4687	5	45	593	59991	73466	\N	51.320267098532298	сумон Иштии-Хем, Школьная, 1	Россия, Республика Тыва, Улуг-Хемский район, поселок Ишти-Хем	0101000020E610000016C3D501101E5740787E5182FEA84940
4681	5	45	593	59993	73470	\N	51.567065902856001	Республика Тыва, Улуг-Хемский кожуун, сумон Ийи-Тал, ул.  Барык 14	Россия, Республика Тыва, Улуг-Хемский район, поселок Ийи-Тал	0101000020E6100000DB85E63A8D5557403656629E95C84940
4686	5	45	593	59988	73463	\N	51.405529000000001	Республика Тыва, Улуг-Хемский кожуун, сумон Арыскан, Гагарина, 29	Россия, Республика Тыва, Улуг-Хемский район, поселок Арыскан	0101000020E61000005DA5BBEB6C2D5740304AD05FE8B34940
4685	5	45	593	59997	73476	\N	51.426237	Республика Тыва, Улуг-Хемский кожуун, сумон Арыг-Узуу, Кочетова, 23	Россия, Республика Тыва, Улуг-Хемский район, поселок Арыг-Узю	0101000020E61000005FD04202462657402EAC1BEF8EB64940
4679	5	45	593	59980	73452	\N	51.442788999999998	Республика Тыва, Улуг-Хемский кожуун, сумон Арыг-Бажы, ул. Айлыг-Кыйыг,25	Россия, Республика Тыва, Улуг-Хемский район, поселок Арыг-Бажы	0101000020E6100000693BA6EECA435740A703594FADB84940
4692	5	45	593	59951	73412	\N	51.394441612157102	Республика Тыва, Чаа-Хольский кожуун, сумон Ак-Дуруг, ул. Ленина 1	Россия, Республика Тыва, Улуг-Хемский район, поселок Ак-Дуруг	0101000020E61000000CEA5BE6740D57409C1551137DB24940
4673	5	45	551	59975	73447	\N	52.714749835439598	Республика Тыва, Тоджинский кожуун, сумон Ырбан, Промышленная, 9	Россия, Республика Тыва, Тоджинский район, поселок Ырбан	0101000020E6100000B3D1393FC5EE5740736891ED7C5B4A40
4669	5	45	551	3402	72437	\N	52.465752000000002	Республика Тыва, Тоджинский кожуун, село Тоора-Хем, ул. Советская 26		0101000020E610000047AD307DAF075840F705F4C29D3B4A40
4670	5	45	551	3402	73429	\N	52.465752000000002	Республика Тыва, Тоджинский кожуун, село Тоора-Хем, Енисейская, 49		0101000020E610000047AD307DAF075840F705F4C29D3B4A40
4674	5	45	551	59960	73424	\N	52.666367000000001	Республика Тыва, Тоджинский кожуун, сумон Сыстыг-Хем, ул. Школьная 4	Россия, Республика Тыва, Тоджинский район, поселок Сыстыг-Хем	0101000020E6100000B1A888D349E057401B118C834B554A40
4672	5	45	551	59944	73403	\N	52.568088000000003	Республика Тыва, Тоджинский кожуун, сумон Ий, ул. Советская 15	Россия, Республика Тыва, Тоджинский район, поселок Ий	0101000020E6100000DA3C0E83F901584002A08A1BB7484A40
4671	5	45	551	59968	73436	\N	52.448954000000001	Республика Тыва, Тоджинский кожуун, сумон Адыр-Кежиг, Анчы, 28	Россия, Республика Тыва, Тоджинский район, поселок Адыр-Кежиг	0101000020E6100000E84D452A8C0F584046B41D5377394A40
4663	5	45	500	60061	73699	\N	50.629391380633301	Республика Тыва, Тес-Хемский кожуун, сумон Чыргаланды, Ленина, 30	Россия, Республика Тыва, Тес-Хемский район	0101000020E61000003E95D39E92C15740C8B260E28F504940
4665	5	45	500	59956	73419	\N	50.649864593582201	Республика Тыва, Тес-Хемский кожуун, сумон Шуурмак, ул. Набережная 5	Россия, Республика Тыва, Тес-Хемский район, поселок Шуурмак	0101000020E61000002FC214E5D2D4574053E8BCC62E534940
4662	5	45	500	3012	73355	\N	50.600139061760501	Республика Тыва, Тес-Хемский кожуун, село Самагалтай,ул. Кунаа 42	Россия, Республика Тыва, Тес-Хемский район, поселок Самагалтай	0101000020E6100000E5B512BA4BC05740EE06D15AD14C4940
4666	5	45	500	60066	73716	\N	50.658627755932599	Республика Тыва, Тес-Хемский кожуун, сумон У-Шынаа, ул.Чооду Кежик-оола 32	Россия, Республика Тыва, Тес-Хемский район, поселок Оо-Шынаа	0101000020E6100000EC33677DCA6F57406D1D1CEC4D544940
4667	5	45	500	59950	73411	\N	50.661438410354201	Республика Тыва, Тес-Хемский кожуун, сумон О-Шынаа, Артына С.А. 1	Россия, Республика Тыва, Тес-Хемский район	0101000020E610000006137F14756F5740732A1900AA544940
4664	5	45	500	59940	73399	\N	50.625527062043503	Республика Тыва, Тес-Хемский кожуун, сумон Берт-Даг, Ленина, 17	Россия, Республика Тыва, Тес-Хемский район, поселок Берт-Даг	0101000020E6100000AD31E884D0B25740EBE1CB4411504940
4668	5	45	500	3355	73390	\N	50.516371999999997	Республика Тыва, Тес-Хемский кожуун, с. Ак-Эрик, ул. Дружбы 18		0101000020E6100000793F6EBF7CA75740F9484A7A18424940
4661	5	45	7499	59999	73479	\N	50.596514646865799	Республика Тыва, Тере-Хольский кожуун, Комсомольская, 45	Россия, Республика Тыва, Кызылский район, поселок Кунгуртуг	0101000020E6100000BF28417FA16158406649809A5A4C4940
4696	5	45	424	59992	73468	\N	51.2978588715687	Республика Тыва, Чеди-Хольский кожуун, сумон Чал-Кежиг,  ул. Школьная 1	Россия, Республика Тыва, Тандинский район, поселок Чал-Кежиг (Элегест)	0101000020E6100000C8091346B37B5740DEE8633E20A64940
25947	5	44	\N	60876	76586	\N	50.350461000000003	г. Кяхта, ул. Крупской, д. 42		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
4693	5	45	424	4687	73370	\N	51.132271000000003	Республика Тыва, Чеди-Хольский кожуун, поселок городского типа Хову-Аксы, ул. Мира  1		0101000020E6100000EBABAB02B56D5740C89A9141EE904940
4653	5	45	424	59973	73444	\N	51.289074999999997	Республика Тыва, Тандинский кожуун, сумон Хадын-Аксы, Туметея, 16	Россия, Республика Тыва, Тандинский район, поселок Усть-Хадын (Хадын-Аксы)	0101000020E6100000321CCF6740A45740AC8BDB6800A54940
4636	5	45	424	59973	73462	\N	51.289935661661502	Республика Тыва, Пий-Хемский кожуун, сумон Хадын, ул. Маады Парынмаа 8	Россия, Республика Тыва, Тандинский район, поселок Усть-Хадын (Хадын-Аксы)	0101000020E6100000CDE506431DA457406EF7729F1CA54940
4659	5	45	424	59987	73461	\N	51.232962000000001	Республика Тыва, Тандинский кожуун, сумон Успенка, Оюн Сенгиижик, 22	Россия, Республика Тыва, Тандинский район, поселок Успенка	0101000020E6100000394206F2EC8F5740FA9AE5B2D19D4940
4652	5	45	424	59972	73443	\N	51.137684999999998	Республика Тыва, Тандинский кожуун, сумон Сосновка, Красных Партизан, 88	Россия, Республика Тыва, Тандинский район, поселок Сосновка	0101000020E6100000217365506DA157402B137EA99F914940
4656	5	45	424	59971	73441	\N	51.004280023780403	Республика Тыва, Тандинский кожуун, сумон Сой, Санаторная, 5	Россия, Республика Тыва, Тандинский район, поселок Сой	0101000020E6100000DE1E84807CCE574071033E3F8C804940
4697	5	45	424	59996	73475	\N	51.123001000000002	Республика Тыва, Чеди-Хольский кожуун, сумон Сайлыг, Терешкова, 5	Россия, Республика Тыва, Тандинский район, поселок Сайлыг	0101000020E610000088D68A36C76B57400A302C7FBE8F4940
4658	5	45	424	32656	73380	\N	51.261167	Республика Тыва, Тандинский кожуун, сумон Межегей, Ленина, 38	Россия, Республика Тыва, Тандинский район, поселок Межегей (Алаак)	0101000020E6100000F16261889C945740B0E595EB6DA14940
4655	5	45	424	59961	73425	\N	50.920082999999998	Республика Тыва, Тандинский кожуун, сумон Кызыл-Арыг, Школьная, 26	Россия, Республика Тыва, Тандинский район, поселок Кызыл-Арыг (Кызларик)	0101000020E6100000827170E998CC5740834D9D47C5754940
4660	5	45	424	32675	73404	\N	51.344085	Республика Тыва, Тандинский кожуун, сумон Кочетово, Ленина, 28	Россия, Республика Тыва, Тандинский район, поселок Кочетово	0101000020E6100000C91F0C3CF7835740A7052FFA0AAC4940
4651	5	45	424	59937	73396	\N	51.149363000000001	Республика Тыва, Тандинский кожуун, сумон Дурген, Шоссейная, 14а	Россия, Республика Тыва, Тандинский район, поселок Дурген	0101000020E61000005C3E92921EA05740C11DA8531E934940
4657	5	45	424	2691	73445	\N	51.001890000000003	Республика Тыва, Тандинский кожуун,  с. Владимировка, ул.  Горького 10		0101000020E6100000013274ECA0D35740401878EE3D804940
4654	5	45	424	59910	73343	\N	50.998891	Республика Тыва, Тандинский кожуун, сумон Балгазын, Советская, 108	Россия, Республика Тыва, Тандинский район, поселок Балгазын	0101000020E61000002907B30930CB574066A208A9DB7F4940
4650	5	45	424	2302	73345	\N	51.160810111138098	Республика Тыва, Тандинский кожуун, село Бай-Хаак, Советская, 88	Россия, Республика Тыва, Тандинский район, поселок Бай-Хаак	0101000020E6100000B401D880089E5740546F0D6C95944940
4646	5	45	360	2095	73356	\N	51.401097	Республика Тыва, Сут-Хольский кожуун, село Суг-Аксы, ул.  Чолгаалчылар,20		0101000020E610000019575C1C95D1564009C3802557B34940
4648	5	45	360	59982	73454	\N	51.480663	Республика Тыва, Сут-Хольский кожуун, сумон Кызыл-Тайга, Ыймажап, 34	Россия, Республика Тыва, Сут-Хольский район, поселок Кызыл-Тайга	0101000020E61000002D08E57D1CD95640D9B27C5D86BD4940
4647	5	45	360	59947	73408	\N	51.420938269941601	Республика Тыва, Сут-Хольский кожуун, сумон Кара-Чыраа, ул. Арат 37	Россия, Республика Тыва, Сут-Хольский район, поселок Кара-Чыраа	0101000020E61000005051F52B9DD4564063D2DF4BE1B54940
4649	5	45	360	59957	73420	\N	51.569148770178998	Республика Тыва, Сут-Хольский кожуун, сумон Ишкин, ул. Мурзууна 69	Россия, Республика Тыва, Сут-Хольский район, поселок Ишкин	0101000020E6100000CEC133A149DE56408BC6DADFD9C84940
4644	5	45	360	59954	73416	\N	51.4039644587656	Республика Тыва, Сут-Хольский кожуун, сумон Бора-Тайга, Найырал, 68	Россия, Республика Тыва, Сут-Хольский район, поселок Бора-Тайга	0101000020E6100000C5CBD3B9A2C956407461A417B5B34940
4580	5	45	360	60001	73482	\N	51.462474222416901	Республика Тыва, Дзун-Хемчикский кожуун, сумон Баян-Тала, Самбуу, 20	Россия, Республика Тыва, Сут-Хольский район, поселок Баян-Тала	0101000020E6100000043DD4B661DB56400AA0185932BB4940
4642	5	45	360	32570	73367	\N	51.295016474064703	Республика Тыва, Сут-Хольский кожуун, сумон Алдан-Маадыр, Самбажык, б/н	Россия, Республика Тыва, Сут-Хольский район, поселок Алдан-Маадыр	0101000020E6100000AD32535A7FBE5640FBE59315C3A54940
4643	5	45	360	59985	73459	\N	51.338678850783602	Республика Тыва, Сут-Хольский кожуун, сумон Ак-Даш, Найырал, 31	Россия, Республика Тыва, Сут-Хольский район, поселок Ак-Даш	0101000020E61000001D3D7E6FD3C75640C66B5ED559AB4940
4618	5	45	263	59949	73410	\N	51.654329356622	Республика Тыва, Кызылский кожуун, сумон Ээрбек, л.  Школьная 14	Россия, Республика Тыва, Пий-Хемский район, поселок Ээрбек	0101000020E6100000569A94826E8D574085E97B0DC1D34940
4641	5	45	263	1790	73439	\N	52.236784	Республика Тыва, Пий-Хемский кожуун, сумон Шивилиг, п.Шивилиг, ул. Первомайская 2		0101000020E61000005F402FDCB96D5740A81B28F04E1E4A40
4698	5	45	263	60002	73483	\N	51.780788000000001	Республика Тыва, Чеди-Хольский кожуун, сумон Холчук, Новая, 5	Россия, Республика Тыва, Пий-Хемский район	0101000020E6100000ACC5A70018825740FC8D76DCF0E34940
4637	5	45	263	59934	73392	\N	52.077416999999997	Республика Тыва, Пий-Хемский кожуун, сумон Уюк, ул. Беспалова 45	Россия, Республика Тыва, Пий-Хемский район, поселок Уюк	0101000020E6100000FA08FCE1E7815740C493DDCCE8094A40
4632	5	45	263	1113	72434	\N	52.145119999999999	Республика Тыва, Пий-Хемский кожуун, город Туран, Советская, д.11, ДЮЦ г.Турана		0101000020E6100000ADC090D5AD7A57406DFFCA4A93124A40
4631	5	45	263	1113	72436	\N	52.144380752154099	Республика Тыва, Пий-Хемский кожуун, город Туран, Комсомольская, д.44	Россия, Республика Тыва, Пий-Хемский район, Туран	0101000020E6100000E9465854C47A5740F7949C137B124A40
4630	5	45	263	1113	72436	\N	52.145119999999999	Республика Тыва, Пий-Хемский кожуун, город Туран, Комсомольская, д.16		0101000020E6100000ADC090D5AD7A57406DFFCA4A93124A40
4629	5	45	263	1113	73366	\N	52.145119999999999	Республика Тыва, Пий-Хемский кожуун, город Туран, 30 лет Тувы, д.10, Контора ШАМ		0101000020E6100000ADC090D5AD7A57406DFFCA4A93124A40
4635	5	45	263	59979	73451	\N	52.0648139013067	Республика Тыва, Пий-Хемский кожуун, сумон Тарлаг, пер. Школьный 3	Россия, Республика Тыва, Пий-Хемский район, поселок Тарлаг	0101000020E6100000CFDBD8EC485A574056293DD34B084A40
4638	5	45	263	59976	73448	\N	52.061715999999997	Республика Тыва, Пий-Хемский кожуун, сумон Сушь, Зеленая, д.15	Россия, Республика Тыва, Пий-Хемский район, поселок Суш	0101000020E6100000CDEA1D6E878A5740E9D1544FE6074A40
4639	5	45	263	59952	73413	\N	51.878107999999997	Республика Тыва, Пий-Хемский кожуун, сумон Сесерлиг, Мандараа, д.3-А	Россия, Республика Тыва, Пий-Хемский район, поселок Сесерлиг (Германовка)	0101000020E6100000D996016729905740902DCBD765F04940
4633	5	45	263	1886	73469	\N	52.149065999999998	"Республика Тыва, Пий-Хемский кожуун, сумон Найырал, Площадь Победы, Контора МТФ ""Туранское"""	Россия, Республика Тыва, Пий-Хемский район, поселок Найырал	0101000020E6100000E02F664B567C574007793D9814134A40
4634	5	45	263	59922	73377	\N	52.061274282490103	Республика Тыва, Пий-Хемский кожуун, сумон Аржаан, ул.  Советская 1	Россия, Республика Тыва, Пий-Хемский район, поселок Аржаан	0101000020E61000008449F1F1096757402C0C91D3D7074A40
4624	5	45	196	789	73433	\N	50.827072000000001	Республика Тыва, Чаа-Суур, ул. Мезил-оола 14		0101000020E6100000CD8FBFB4A8305740FAB7CB7EDD694940
4626	5	45	196	914	73346	\N	50.733088000000002	Республика Тыва, Хандагайты,  пер. Школьный 1		0101000020E610000096EB6D3315055740878BDCD3D55D4940
4627	5	45	196	988	73422	\N	50.752074	Республика Тыва, Солчур, Дамдын, 1		0101000020E6100000F163CC5D4B0257400116F9F543604940
4628	5	45	196	1015	73435	\N	50.494103000000003	Республика Тыва, Саглы, ул. Чанчы-Хоо 2		0101000020E610000031444E5FCFD4564081ED60C43E3F4940
4625	5	45	196	849	73456	\N	50.813687999999999	Республика Тыва, Дус-Даг, ул. Мунзук Севен-оола 8		0101000020E6100000C861307F852B5740E692AAED26684940
4623	5	45	196	730	73418	\N	50.697847000000003	Республика Тыва, Ак-Чыраа, ул. Ирбитей 1		0101000020E61000009A6038D7304F57404D4EED0C53594940
4621	5	45	171	542	73365	\N	50.380564	Республика Тыва, Монгун-Тайгинский кожуун, село Мугур-Аксы, Саны-Шири, 58		0101000020E6100000DC627E6E689C564079043752B6304940
4620	5	45	171	542	73358	\N	50.380564	Республика Тыва, Монгун-Тайгинский кожуун, село Мугур-Аксы, ул. Кошкар-оола 3		0101000020E6100000DC627E6E689C564079043752B6304940
4622	5	45	171	59959	73423	\N	50.046098999999998	Республика Тыва, Монгун-Тайгинский кожуун, сумон Кызыл-Хая, Кечил, 10	Россия, Республика Тыва, Монгун-Тайгинский район, поселок Кызыл-Хая	0101000020E6100000871403249A7756406CB07092E6054940
4615	5	45	1924	59967	73432	\N	51.241796999999998	Республика Тыва, Кызылский кожуун, сумон Шамбалыг, ул. 40 лет Сов. Тувы 1	Россия, Республика Тыва, Кызылский район, поселок Шамбалыг	0101000020E61000009E08E23C9CC55740ADA23F34F39E4940
4611	5	45	1924	59948	73409	\N	51.890452088969099	Республика Тыва, Кызылский кожуун, сумон Черби, ул. Школьная 8	Россия, Республика Тыва, Кызылский район, поселок Черби	0101000020E61000007898F6CDFDA557403354C554FAF14940
4614	5	45	1924	59921	73375	\N	51.326766021111098	Республика Тыва, Кызылский кожуун, сумон Целинное, ул. Кужугет Серена 30	Россия, Республика Тыва, Кызылский район, поселок Целинное	0101000020E6100000912C6002B7B35740EDB8E177D3A94940
4619	5	45	1924	59936	73395	\N	51.565449647896301	Республика Тыва, Кызылский кожуун, сумон Усть-Элегест,  ул. Горная 1	Россия, Республика Тыва, Кызылский район, поселок Усть-Элегест	0101000020E61000008C9E5BE84A865740F8C264AA60C84940
4613	5	45	1924	59998	73478	\N	51.708776161553402	Республика Тыва, Кызылский кожуун, сумон Терлиг-Хая, ул.  Энтузиастов 6	Россия, Республика Тыва, Кызылский район, поселок Терлиг-Хая	0101000020E6100000BCCADAA6786157404818062CB9DA4940
4616	5	45	1924	33070	73352	\N	51.646321	Республика Тыва, Кызылский кожуун, сумон Сукпак, Фрунзе, 1-в	Россия, Республика Тыва, Кызылский район, поселок Сукпак	0101000020E6100000D5B14AE999905740E8DB82A5BAD24940
4617	5	45	1924	33070	73406	\N	51.643414999999997	Республика Тыва, Кызылский кожуун, сумон Сукпак, Геологов, 13, агро-лицей	Россия, Республика Тыва, Кызылский район, поселок Сукпак	0101000020E6100000F3AB394030915740BF60376C5BD24940
4645	5	45	1924	59925	73381	\N	50.598980568415797	Республика Тыва, Тере-Хольский кожуун, сумон Кунгуртуг, Дружба, 4	Россия, Республика Тыва, Кызылский район, поселок Кунгуртуг	0101000020E61000002B31CF4A5A61584073F6CE68AB4C4940
4610	5	45	1924	59919	73372	\N	51.8869249455296	Республика Тыва, Кызылский кожуун, сумон Кара-Хаак, ул. Механизаторская 10	Россия, Республика Тыва, Кызылский район, поселок Кара-Хаак	0101000020E6100000514EB4AB909D57409D8026C286F14940
4607	5	45	1924	32233	72442	\N	51.689208999999998	Республика Тыва, Кызылский кожуун, поселок городского типа Каа-Хем, пер.Чооду Кидиспея д.5, столовая ЦСРН по Кызылскому кожууну		0101000020E61000008F37F92D3AA55740EF8D210038D84940
4609	5	45	1924	32233	72426	\N	51.689208999999998	Республика Тыва, Кызылский кожуун, поселок городского типа Каа-Хем, ул.Таежная, 19		0101000020E61000008F37F92D3AA55740EF8D210038D84940
26034	5	44	1140	46239	76902	\N	52.116157000000001	с.Таловка, ул.Гагарина, 1		0101000020E61000000F5EBBB4E1C85A40CA198A3BDE0E4A40
4606	5	45	1924	32233	72426	\N	51.689208999999998	Республика Тыва, Кызылский кожуун, поселок городского типа Каа-Хем, ул.Таежная 17		0101000020E61000008F37F92D3AA55740EF8D210038D84940
4608	5	45	1924	32233	73357	\N	51.689208999999998	Республика Тыва, Кызылский кожуун, поселок городского типа Каа-Хем, ул.Народная, д.1 Кок-Тейская шк.№2		0101000020E61000008F37F92D3AA55740EF8D210038D84940
4612	5	45	1924	59939	73398	\N	51.582160999999999	Республика Тыва, Кызылский кожуун, сумон Баян-Кол, ул. Базыр Тулуш 15	Россия, Республика Тыва, Кызылский район, поселок Баян-Кол	0101000020E6100000B9FE5D9F39635740DA006C4084CA4940
4602	5	45	1929	59984	73457	\N	51.336176069507403	Республика Тыва, Каа-Хемский кожуун, сумон Эржей, ул.Центральная, 5	Россия, Республика Тыва, Каа-Хемский район, поселок Эржей	0101000020E61000001C78B5DC99FB57409DD9AED007AB4940
4603	5	45	1929	59983	73455	\N	51.335003999999998	Республика Тыва, Каа-Хемский кожуун, сумон Усть-Ужеп, ул.Набережная, 14	Россия, Республика Тыва, Каа-Хемский район, поселок Усть-Ужеп	0101000020E61000007F69519FE40F5840BC033C69E1AA4940
4599	5	45	1929	59966	73431	\N	51.416556390858801	Республика Тыва, Каа-Хемский кожуун, сумон Усть-Бурен, ул.Красных партизан, 52	Россия, Республика Тыва, Каа-Хемский район, поселок Усть-Бурен (Грязнуха)	0101000020E61000007575C7629BE95740EE79FEB451B54940
4591	5	45	1929	59941	73400	\N	51.653444	Республика Тыва, Каа-Хемский кожуун, сумон Суг-Бажы, ул.Валентина Хажики, 13	Россия, Республика Тыва, Каа-Хемский район, поселок Суг-Бажы	0101000020E6100000187D0569C6B657403BE2900DA4D34940
4601	5	45	1929	59978	73450	\N	51.317354000000002	Республика Тыва, Каа-Хемский кожуун, сумон Сизим, ул.Центральная, 28	Россия, Республика Тыва, Каа-Хемский район, поселок Сизим	0101000020E61000002E1B9DF353FC57409DA04D0E9FA84940
4596	5	45	1929	59916	73361	\N	51.487607441214202	Республика Тыва, Каа-Хемский кожуун, сумон Сарыг-Сеп, ул.Енисейская, 162	Россия, Республика Тыва, Каа-Хемский район, поселок Сарыг-Сеп (Знаменка)	0101000020E61000000E130D52F0E357407C26FBE769BE4940
4593	5	45	1929	59924	73379	\N	51.574542999999998	Республика Тыва, Каа-Хемский кожуун, сумон Кундустуг, ул.Центральная, 20	Россия, Республика Тыва, Каа-Хемский район, поселок Кундустуг (Федоровка)	0101000020E610000063D009A183CB5740A79201A08AC94940
4595	5	45	1929	60003	73484	\N	51.511583000000002	Республика Тыва, Каа-Хемский кожуун, сумон Кок-Хаак, ул.Центральная, 104	Россия, Республика Тыва, Каа-Хемский район, поселок Кок-Хаак	0101000020E61000003D2828452BDF574044183F8D7BC14940
4605	5	45	1929	33020	73376	\N	51.117244999999997	Республика Тыва, Каа-Хемский кожуун, сумон Ильинка, ул.Мира, 39		0101000020E6100000D525E318C9DE57404C4F58E2018F4940
4598	5	45	1929	59935	73393	\N	51.456124000000003	Республика Тыва, Каа-Хемский кожуун, сумон Дерзиг-Аксы, ул. Магистральная 1	Россия, Республика Тыва, Каа-Хемский район, поселок Дерзиг-Аксы (Даниловка)	0101000020E6100000FBE8D495CFE65740DA756F4562BA4940
4592	5	45	1929	59930	73386	\N	51.649918594004703	Республика Тыва, Каа-Хемский кожуун, сумон Бурен-Хем,  ул.Енисейская, 26	Россия, Республика Тыва, Каа-Хемский район, поселок Бурен-Хем (Зубовка)	0101000020E61000000B630B410EC057404606B98B30D34940
4604	5	45	1929	59969	73437	\N	51.246658544986197	Республика Тыва, Каа-Хемский кожуун, сумон Бурен-Бай-Хаак,  ул. Ленина 34	Россия, Республика Тыва, Каа-Хемский район, поселок Бурен-Бай-Хаак	0101000020E610000079CDAB3AABE35740CD21A985929F4940
4594	5	45	1929	59986	73460	\N	51.533083039979999	Республика Тыва, Каа-Хемский кожуун, сумон Бояровка, ул. Гагарина 8	Россия, Республика Тыва, Каа-Хемский район, поселок Бояровка	0101000020E6100000FA415DA450D65740DB8651103CC44940
4600	5	45	1929	59994	73472	\N	51.314148297348503	Республика Тыва, Каа-Хемский кожуун, сумон Авыйган, ул.Юбилейная, 1	Россия, Республика Тыва, Каа-Хемский район	0101000020E6100000D3FA5B02F0E557404A0D6D0036A84940
4597	5	45	7496	59912	73348	\N	51.493452544368097	Республика Тыва, Каа-Хемский кожуун, сумон Сарыг-Сеп, пер.Первомайский, 20	Россия, Республика Тыва, Каа-Хемский район, поселок Сарыг-Сеп (Знаменка)	0101000020E61000003E7B2E5393E357407A8EC87729BF4940
4581	5	45	7502	60027	73543	\N	51.581091999999998	Республика Тыва, Дзун-Хемчикский кожуун, сумон Ийме, Ленина, 7		0101000020E61000008E041A6CEAE55640CEFBFF3861CA4940
4590	5	45	1904	59990	73465	\N	50.869230000000002	Республика Тыва, Дзун-Хемчикский кожуун, сумон Элдиг-Хем, Ленина, 5	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Элдиг-Хем	0101000020E6100000978BF84ECCC65640DE59BBED426F4940
4589	5	45	1904	59918	73371	\N	51.155255265960697	Республика Тыва, Дзун-Хемчикский кожуун, сумон Шеми, ул. Найырал 34	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Шеми	0101000020E6100000EE06D15AD1D256402EC55565DF934940
4588	5	45	1904	59970	73440	\N	51.065828000000003	Республика Тыва, Дзун-Хемчикский кожуун, сумон Чыргакы, ул. Ийистер 48	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Чыргакы	0101000020E6100000A12DE7525CC056409F94490D6D884940
4587	5	45	1904	59938	73397	\N	51.171095999999999	Республика Тыва, Дзун-Хемчикский кожуун, сумон Чыраа-Бажы, ул. Ленина 45	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Чыраа-Бажы	0101000020E61000003A03232F6BC35640FB3C4679E6954940
4579	5	45	1904	30824	72430	\N	51.291271000000002	Республика Тыва, Дзун-Хемчикский кожуун, город Чадан, ул. Сельская, 2		0101000020E6100000BEDBBC7152E45640F9A23D5E48A54940
4578	5	45	1904	30824	72427	\N	51.291271000000002	Республика Тыва, Дзун-Хемчикский кожуун, город Чадан, ул.Победы, 86		0101000020E6100000BEDBBC7152E45640F9A23D5E48A54940
4577	5	45	1904	30824	72427	\N	51.282767811173201	Республика Тыва, Дзун-Хемчикский кожуун, город Чадан, ул.Победы, 26	Россия, Республика Тыва, Дзун-Хемчикский район, Чадан	0101000020E6100000A2EBC20FCEE556407B2DE8BD31A44940
4576	5	45	1904	30824	73360	\N	51.285459066901801	Республика Тыва, Дзун-Хемчикский кожуун, город Чадан, Ленина, 57	Россия, Республика Тыва, Дзун-Хемчикский район, Чадан	0101000020E6100000BBEF181EFBE45640A8ACA6EB89A44940
4585	5	45	1904	59958	73421	\N	51.2817755808816	Республика Тыва, Дзун-Хемчикский кожуун, сумон Хорум-Даг,  ул.Ховалыг Оюу, 24	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Хорум-Даг	0101000020E6100000B5C2F4BD86C356401B66683C11A44940
4584	5	45	1904	59965	73430	\N	51.125469501438701	Республика Тыва, Дзун-Хемчикский кожуун, сумон Хондергей, ул. Октябрьская 15	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Хондергей	0101000020E610000079CA6ABA9EE756408750A5660F904940
4583	5	45	1904	59977	73449	\N	51.296601070749198	Республика Тыва, Дзун-Хемчикский кожуун, сумон Хайыракан, Данзы-Белек, 58	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Хайыракан	0101000020E6100000A1DB4B1AA3E35640FF7A8505F7A54940
4582	5	45	1904	59917	73368	\N	51.364447773263997	Республика Тыва, Дзун-Хемчикский кожуун, сумон Теве-Хая, ул. Садовая 1	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Теве-Хая	0101000020E6100000799274CDE4DC5640DB8B683BA6AE4940
4586	5	45	1904	59926	73382	\N	51.231452480991798	Республика Тыва, Дзун-Хемчикский кожуун, сумон Бажын-Алаак, ул. К. Маркса 59	Россия, Республика Тыва, Дзун-Хемчикский район, поселок Бажын-Алаак	0101000020E61000002A745E6397EE5640014C1938A09D4940
4575	5	45	1890	30767	73364	\N	50.934079298379999	Республика Тыва, с.Эрги-Барлык, ул,Самбу 23	Россия, Республика Тыва, Барун-Хемчикский район, поселок Эрги-Барлык	0101000020E610000033C2DB83109A5640B07092E68F774940
4573	5	45	1890	30668	73363	\N	51.168916000000003	Республика Тыва, с.Шекпээр, ул. Октябрьская, 3		0101000020E6100000FA0967B796AB5640B5E21B0A9F954940
4574	5	45	1890	30671	73434	\N	51.253762418748998	Республика Тыва, с.Хонделен, ул. Чургуй-оол, 5	Россия, Республика Тыва, Барун-Хемчикский район, поселок Хонделен	0101000020E61000007C0C569C6A935640D97BF1457BA04940
4566	5	45	1890	30265	73338	\N	51.144297000000002	с.Кызыл-Мажалык, Чургуй-оол, 42		0101000020E610000060AB048BC3A4564099F4F75278924940
95190	5	45	1890	30265	73339	\N	51.144297000000002	с. Кызыл-Мажалык, ул.Авиация, б/н, МОУ СОШ №2		0101000020E610000060AB048BC3A4564099F4F75278924940
4572	5	45	1890	30589	73442	\N	51.216054999999997	Республика Тыва, с.Дон-Терезин, ул. Набережная, 1		0101000020E6100000239EEC6646AD56409291B3B0A79B4940
4571	5	45	1890	59974	73446	\N	51.100163000000002	Республика Тыва, с.Бижиктиг-Хая, Ленина, 1	Россия, Республика Тыва, Барун-Хемчикский район, поселок Бижиктик-Хая	0101000020E610000077853E58C6A8564077A22424D28C4940
4570	5	45	1890	30513	73415	\N	51.136352000000002	Республика Тыва, с.Барлык, ул. Октябрьская, 26	Россия, Республика Тыва, Барун-Хемчикский район, поселок Барлык	0101000020E6100000B08EE3874AA25640425F7AFB73914940
4569	5	45	1890	30450	73458	\N	50.993516999999997	Республика Тыва, с.Аянгаты, ул. М. Чыргала, 5		0101000020E6100000E04A766C04B656409082A7902B7F4940
4568	5	45	1890	30407	73374	\N	51.119948000000001	Республика Тыва, с.Аксы-Барлык, Культура, 9		0101000020E6100000F18288D4B49956403D9CC0745A8F4940
4565	5	45	389	59928	73384	\N	50.887824999999999	Республика Тыва, Бай-Тайгинский кожуун, сумон Шуй, ул. Нордуп, 46	Россия, Республика Тыва, Бай-Тайгинский район, поселок Шуй	0101000020E61000003B394371C79556401DC9E53FA4714940
4561	5	45	389	59964	73428	\N	51.0189555803601	Республика Тыва, Бай-Тайгинский кожуун, сумон Хемчик, ул. Чудурукпай, 16	Россия, Республика Тыва, Бай-Тайгинский район, поселок Хемчик	0101000020E6100000658D7A88468C5640100874266D824940
4559	5	45	389	29972	73336	\N	51.012555999999996	Республика Тыва, Бай-Тайгинский кожуун, село Тээли, ул.Ленина, 23		0101000020E610000001A5A146218D56402DAF5C6F9B814940
4690	5	45	389	59943	73402	\N	51.040529999999997	Республика Тыва, Чаа-Хольский кожуун, сумон Кызыл-Даг, ул. Ховалыг Сайын-оол 22	Россия, Республика Тыва, Бай-Тайгинский район, поселок Кызыл-Даг	0101000020E6100000F81BEDB8E1865640E140481630854940
4563	5	45	389	59927	73383	\N	51.282787999999996	Республика Тыва, Бай-Тайгинский кожуун, сумон Кара-Холь, ул. Монгуш Эдуард, 8	Россия, Республика Тыва, Бай-Тайгинский район, поселок Кара-Холь (Тапсы-Аксы)	0101000020E6100000AEB9A3FFE5705640C2D9AD6532A44940
4560	5	45	389	2020	73438	\N	51.006770000000003	Республика Тыва, Бай-Тайгинский кожуун, с. Дружба, ул. Хараар-Тей, 31		0101000020E6100000AB5CA8FC6B8E5640064CE0D6DD804940
4564	5	45	389	59920	73373	\N	50.912477748950998	Республика Тыва, Бай-Тайгинский кожуун, сумон Бай-Тал, ул. Мира, 39	Россия, Республика Тыва, Бай-Тайгинский район, поселок Бай-Тал (Чон-Терек)	0101000020E6100000F8FE06EDD5835640E5284014CC744940
4562	5	45	7497	59923	73378	\N	51.038670952538197	Республика Тыва, Бай-Тайгинский кожуун, сумон Кызыл-Даг, ул. Коп-Соок, 16	Россия, Республика Тыва, Бай-Тайгинский район, поселок Кызыл-Даг	0101000020E6100000C16F438CD7865640DD26DC2BF3844940
26265	5	44	\N	24699	\N	\N	51.832136432046198	Республика Бурятия, городской округ Город Улан-Удэ, Октябрьский район, Дом творчества п. Сосновый бор		0101000020E6100000EFE4D3635BE75A4081E9B46E83EA4940
26264	5	44	\N	24699	\N	\N	51.825108	Республика Бурятия, городской округ Город Улан-Удэ, Октябрьский район, МОУ «Средняя общеобразовательная школа №5» (здание начальной школы), п. Сосновый бор	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26170	5	44	\N	24699	\N	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, станция Мостовой"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26174	5	44	\N	24699	74820	\N	51.834263465101202	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, проспект 50-летия Октября, 29"		0101000020E61000007C6308008EE75A40A5A14621C9EA4940
26197	5	44	\N	24699	76050	\N	51.8438251421709	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, мкр. Новый Зеленый, 1"		0101000020E61000003F56F0DB10E75A400B46257502EC4940
26259	5	44	\N	24699	76513	\N	51.826098000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Энергетик, 1"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000004E44BFB67EE75A4040A54A94BDE94940
26255	5	44	\N	24699	76599	\N	51.832450000000001	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Шумяцкого, 4"		0101000020E6100000389F3A5629E75A4011C7BAB88DEA4940
26257	5	44	\N	24699	74433	\N	51.825952999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Шукшина, 1"		0101000020E610000005C58F3177E75A403C84F1D3B8E94940
26189	5	44	\N	24699	75682	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Шаляпина, 14А"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26204	5	44	7505	\N	76492	\N	51.837020000000003	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Чкалова, 1"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000677FA0DCB6E65A40890CAB7823EB4940
26203	5	44	\N	24699	74339	\N	51.824686	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Чкалова, 8"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000745C8DEC4AE75A400ABC934F8FE94940
26160	5	44	7505	\N	74445	\N	51.829898	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Чертенкова, 100"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000C1E5B16664E75A40068200193AEA4940
26198	5	44	\N	24699	76531	\N	51.825952000000001	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Чайковского, 8"		0101000020E610000048533D997FE75A406C088ECBB8E94940
26223	5	44	\N	24699	76422	\N	51.838405999999999	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Цыбикова, 2"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000003D0E83F92BEA5A40956247E350EB4940
26168	5	44	7523	\N	74757	\N	51.837130000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Цивилева, 50"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000936FB6B931E85A4010406A1327EB4940
26172	5	44	\N	24699	74516	\N	51.825851999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Хоца Намсараева, 5"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000003CD9CD8C7EE75A4008ABB184B5E94940
26205	5	44	\N	24699	74872	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Туполева, 14А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26226	5	44	\N	24699	76595	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Трубачеева, 152"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26190	5	44	\N	24699	74846	\N	51.823639	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Трактовая, 1"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000009F7422C154E75A40E65AB4006DE94940
26292	5	44	\N	24699	76570	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Толстихина, 2Б"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26238	5	44	\N	24699	71478	\N	51.815699828265103	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Тобольская, 53"		0101000020E61000000FB743C362EA5A4071AC8BDB68E84940
26224	5	44	\N	24699	76480	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Терешковой, 56"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26221	5	44	\N	24699	76480	\N	51.826729999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Терешковой, 13"		0101000020E610000076DD5B9198E75A40A04FE449D2E94940
26212	5	44	\N	24699	76480	\N	51.833726627271702	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Терешковой, 1"		0101000020E6100000F833BC5983E75A406765FB90B7EA4940
26284	5	44	\N	24699	76056	\N	51.826168983731897	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Талалихина, 64"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000CC79C6BE64E75A4009FCE1E7BFE94940
26278	5	44	\N	24699	75797	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Сухэ-Батора, 5"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26202	5	44	\N	24699	76494	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Столичная, 2А"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26194	5	44	\N	24699	76603	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Сперанского, 54А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26258	5	44	7505	\N	76604	\N	51.837980000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Совхозная, 50д"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E61000006937FA980FEE5A40DE59BBED42EB4940
26275	5	44	\N	24699	76486	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Советская, 43"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26277	5	44	\N	24699	74882	\N	51.836066000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Смолина, 24А"		0101000020E610000016FA60191BEA5A4016A6EF3504EB4940
26273	5	44	\N	24699	74882	\N	51.823645999999997	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Смолина, 14"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E610000022A81ABD1AE75A4098BD6C3B6DE94940
26217	5	44	7505	\N	71487	\N	51.833297588583598	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Северная, 92"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E61000006440F67AF7E75A403EE94482A9EA4940
26199	5	44	\N	24699	76489	\N	51.825803000000001	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Севастопольская, 3"		0101000020E6100000F1BDBF417BE75A4027F8A6E9B3E94940
26260	5	44	\N	24699	76566	\N	51.827767000000001	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Сахалинская, 32"		0101000020E6100000DBF97E6ABCE75A40A1DAE044F4E94940
26195	5	44	\N	24699	74359	\N	51.827821	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Родины, 8"		0101000020E610000087156EF948E75A4094F8DC09F6E94940
26214	5	44	\N	24699	76506	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Ринчино, 7"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26175	5	44	\N	24699	74528	\N	51.826171000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Революции 1905 года, 32"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000003E4162BB7BE75A40AAF3A8F8BFE94940
26167	5	44	\N	24699	74528	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Революции 1905 года, 71"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26216	5	44	\N	24699	76481	\N	51.826859645503099	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Раздольная, 15"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000B0E2546B61E75A406F2F698CD6E94940
26288	5	44	\N	24699	76568	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Радикальцева, 5А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26165	5	44	\N	24699	76591	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Пушкина, 8"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26161	5	44	\N	24699	76538	\N	51.839918306168798	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Пушкина, 40"		0101000020E6100000E3FA777DE6E35A402EA9DA6E82EB4940
26162	5	44	\N	24699	76462	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Пушкина, 24А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26233	5	44	\N	24699	76555	\N	51.827447878590903	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Пугачева, 39"		0101000020E6100000A2F0D93A38E75A40FF91E9D0E9E94940
26285	5	44	\N	24699	76561	\N	51.827447878590903	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Покровская, 32"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000009F73B7EBA5E75A40FF91E9D0E9E94940
26235	5	44	7525	\N	76557	\N	51.8288972901912	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Пищевая, 13"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E61000007EC51A2E72E85A405260014C19EA4940
26279	5	44	\N	24699	74884	\N	51.823492999999999	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Партизанская, 42"		0101000020E6100000BAD7497D59E75A4012BEF73768E94940
26243	5	44	\N	24699	76559	\N	51.826915999999997	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Павлова, 68"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000007B2FBE688FE75A4002452C62D8E94940
26268	5	44	\N	24699	74414	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Оцимика, 10"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26267	5	44	\N	24699	74414	\N	51.8330353443219	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Оцимика, 20"		0101000020E6100000AB92C83EC8E75A4031B610E4A0EA4940
26185	5	44	\N	24699	75680	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Октябрьская, 29"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26280	5	44	\N	24699	76600	\N	51.839095999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Новая, 44"		0101000020E61000005891D10149E75A402A1A6B7F67EB4940
26193	5	44	\N	24699	76619	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Н.Нищенко, 19"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26245	5	44	\N	24699	74878	\N	51.825614000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Мокрова, 18"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000F5DBD78173E75A40548F34B8ADE94940
26289	5	44	\N	24699	76569	\N	51.827224999999999	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Микрорайон Вагжанова, 3 участок"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000A0C552245FE75A4080B74082E2E94940
26283	5	44	\N	24699	75976	\N	51.7936196767794	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Микрорайон Аэропорт, 11"		0101000020E610000044FB58C16FDC5A40CBB9145795E54940
26200	5	44	7523	\N	74362	\N	51.835746999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Магистральная, 3"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000AA49F08634E85A40745DF8C1F9EA4940
26163	5	44	\N	24699	74456	\N	51.8244299730328	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Лысогорская, 85А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E610000060E7A6CD38E75A40AFEB17EC86E94940
26179	5	44	\N	24699	74624	\N	51.825932999999999	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Лимонова, 5"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000F4A78DEA74E75A40F5D72B2CB8E94940
26274	5	44	\N	24699	76565	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Ленина, 20"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26270	5	44	\N	24699	76607	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Куйбышева, 40"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26256	5	44	\N	24699	76483	\N	51.834257999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Крылова, 77А"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000D00A0C59DDE75A40933655F7C8EA4940
26254	5	44	\N	24699	76501	\N	51.825592999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Краснофлотская, 2"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000006555849B8CE75A403C670B08ADE94940
26252	5	44	\N	24699	76501	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Краснофлотская, 46"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26201	5	44	\N	24699	74388	\N	51.822290000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Краснодонская, 2А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000007573F1B73DE75A40F7E978CC40E94940
26177	5	44	7525	\N	76490	\N	51.834789999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Красноармейская, 24"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000118B187618E75A4090831266DAEA4940
26184	5	44	\N	24699	76503	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Комсомольская, 29"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26237	5	44	\N	24699	74371	\N	51.836593999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Ключевская, 60"		0101000020E6100000E0BBCD1B27EB5A40D1031F8315EB4940
26236	5	44	7505	\N	74371	\N	51.847023542937002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Ключевская, 94"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000022382EE3A6EE5A40AB764D486BEC4940
26232	5	44	\N	24699	74371	\N	51.832291600860202	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Ключевская, 41"		0101000020E6100000D384ED2763E85A40795C548B88EA4940
26231	5	44	\N	24699	74371	\N	51.834201566542397	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Ключевская, 23А"		0101000020E61000002C9FE57970E75A40FF209221C7EA4940
26229	5	44	\N	24699	74371	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Ключевская, 44А"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26227	5	44	\N	24699	74371	\N	51.822555000000001	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Ключевская, 21"		0101000020E6100000B37DC85BAEE75A40A514747B49E94940
26222	5	44	\N	24699	71484	\N	51.8036755780319	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, бульвар К. Маркса, 31"		0101000020E6100000A453573ECBE65A40414AECDADEE64940
26247	5	44	\N	24699	76497	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Калашникова, 12"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26282	5	44	7523	\N	74538	\N	51.8274568116138	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Кабанская, 49"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000960A2AAA7EE65A4053EC681CEAE94940
26192	5	44	\N	24699	76601	\N	51.801383999999999	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Зеленхоз"		0101000020E6100000C362D4B5F6E65A40D2C43BC093E64940
26248	5	44	7525	\N	74850	\N	51.823187039203098	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Жердева, 122"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000084F57F0EF3EB5A4005BF0D315EE94940
26230	5	44	\N	24699	74850	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Жердева, 27"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26228	5	44	\N	24699	74850	\N	51.823480000000004	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Жердева, 19"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000813E912749E75A407E74EACA67E94940
26276	5	44	\N	24699	76606	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Ербанова, 3"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26063	5	44	\N	60864	76544	\N	55.633286160515503	Республика Бурятия, город Северобайкальск, ул. Космонавтов, 13		0101000020E61000007CD5CA845F555B40E08101840FD14B40
26295	5	44	\N	24699	76572	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Дорожная, 42"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26171	5	44	7523	\N	76627	\N	51.836593999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Добролюбова, 5"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000019575C1C95E65A40D1031F8315EB4940
26164	5	44	\N	24699	76500	\N	51.835113999999997	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Дзержинского, 13"		0101000020E610000019C91EA166E75A404337FB03E5EA4940
26294	5	44	\N	24699	76430	\N	51.844997999999997	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Гурульбинская, 12А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000005AD427B9C3EC5A40BB97FBE428EC4940
26261	5	44	\N	24699	74479	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Горхонская, 3"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26211	5	44	\N	24699	74379	\N	51.821703991734097	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Геологическая, 9"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000172D40DB6AE75A40067FBF982DE94940
26210	5	44	\N	24699	74379	\N	51.838721390441499	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Геологическая, 10"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E61000000491459A78EC5A40F5BBB0355BEB4940
26182	5	44	\N	24699	76502	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Гвардейская, 1А"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26234	5	44	\N	24699	76597	\N	51.842658999999998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Гармаева, 43"		0101000020E610000086C77E164BE75A400C570740DCEB4940
26176	5	44	\N	24699	76061	\N	51.825805834094503	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Гагарина, 12"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000003DF372D87DE75A40986BD102B4E94940
26169	5	44	\N	24699	76556	\N	51.828085999999999	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Гагарина, 26А"		0101000020E61000008C4AEA0434E75A404223D8B8FEE94940
26286	5	44	\N	24699	76253	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Воронежская, 5"		0101000020E6100000DBA6785C54E75A4080D591239DE94940
26191	5	44	\N	24699	76083	\N	51.873719999999999	Республика Бурятия, городской округ Город Улан-Удэ, Железнодорожный район, Верхняя Березовка, кафе «Максим»,	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000D09A1F7F69EA5A4039EE940ED6EF4940
26188	5	44	\N	24699	74841	\N	51.835273000000001	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Буйко, 27А"		0101000020E6100000923CD7F7E1E65A40AC1DC539EAEA4940
26187	5	44	7523	\N	74841	\N	51.828604794105502	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Буйко, 2Б"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000CF488446B0EA5A40AB2688BA0FEA4940
26291	5	44	\N	24699	74889	\N	51.826281000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Батарейная, 60"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E61000005E9ECE15A5E75A4031276893C3E94940
26293	5	44	\N	24699	76659	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Баргузинская, 18"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26272	5	44	\N	24699	74521	\N	51.826664000000001	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Балтахинова, 38"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E610000038D89B1892E75A40E9633E20D0E94940
26209	5	44	\N	24699	76059	\N	51.853715999999999	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Бабушкина, 2"		0101000020E6100000E14389963CEE5A403509DE9046ED4940
26213	5	44	\N	24699	76594	\N	51.827162436411101	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Бабушкина, 31"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000ED116A8654E75A403A3FC571E0E94940
26215	5	44	\N	24699	75899	\N	51.825746001377503	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, 113 квартал, 4"		0101000020E61000008C69A67B9DE75A40C366800BB2E94940
26178	5	44	\N	59464	76527	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, проспект 50-летия Октября, 58"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26241	5	44	\N	59464	71482	\N	51.8095217403189	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Строителей, 16"		0101000020E61000005AF624B039E95A403EB2B96A9EE74940
26166	5	44	\N	59464	75648	\N	51.825108	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Революции 1905 года, 100"	Россия, Республика Бурятия, город Улан-Удэ	0101000020E6100000DBA6785C54E75A4080D591239DE94940
26055	5	44	\N	60864	76578	\N	55.625964000000003	Республика Бурятия, город Северобайкальск, пр-т Ленинградский, 10		0101000020E610000069519FE40E545B40973C9E961FD04B40
26057	5	44	\N	60864	76493	\N	55.629790086842199	Республика Бурятия, город Северобайкальск, пр-т 60 лет СССР, 12		0101000020E610000056D636C5E3545B4086AC6EF59CD04B40
25844	5	44	\N	60947	76808	\N	51.996708478091598	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Каменское"", станция ""Тимлюй"", Вокзальная, 1"	Россия, Республика Бурятия, Кабанский район, поселок городского типа Каменск	0101000020E6100000172829B000A65A40AED4B32094FF4940
25764	5	44	\N	60868	\N	\N	50.368965000000003	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание Закаменского ДРСуч"		0101000020E610000026FF93BF7BD25940302FC03E3A2F4940
25759	5	44	\N	60868	\N	\N	50.373393707823901	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание районного Дворца культуры"		0101000020E610000059DC7F643AD25940E542E55FCB2F4940
25756	5	44	\N	60868	\N	\N	50.369346479336699	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание МОУ ""СОШ №5 г. Закаменск"""		0101000020E61000007427D87F9DD259404774CFBA462F4940
25755	5	44	\N	60868	\N	\N	50.368965000000003	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание МОУ ""СОШ №4 г. Закаменск"""		0101000020E610000026FF93BF7BD25940302FC03E3A2F4940
26072	5	44	\N	60878	\N	\N	51.293469975764602	Республика Бурятия, Селенгинский район, город Гусиноозерск, 9 микрорайон, МОУ ООШ № 7		0101000020E61000002E1EDE7360A05A40B62DCA6C90A54940
25854	5	44	\N	60867	76520	\N	51.713981867626302	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Бабушкинское"", город ""Бабушкин"", 3 Интернационала, 47"		0101000020E61000009B1DA9BEF3775A4062F71DC363DB4940
26183	5	44	7505	60713	75679	\N	51.833301223641797	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Комсомольская, 28А"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E61000002C8194D8B5E95A40AF5C6F9BA9EA4940
26281	5	44	7505	60394	74948	\N	51.810434926510602	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Микрорайон Сокол, 4А"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000011902FA182E95A4052448655BCE74940
26266	5	44	7505	60394	75993	\N	51.850739460500797	Республика Бурятия, городской округ Город Улан-Удэ, Октябрьский район, МОУ «Средняя общеобразовательная школа №24» (п. Звездный), ул. Ясная,  д.1	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000329067976FE85A404337FB03E5EC4940
26173	5	44	7505	\N	75798	\N	51.829898	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Чертенкова, 3"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000097546D37C1E75A40068200193AEA4940
26269	5	44	7505	\N	75996	\N	51.847763	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Тарбагатайская, 49"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E61000000EBBEF181EE75A4022E17B7F83EC4940
26287	5	44	7505	\N	75812	\N	51.843935000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Советский район, Радикальцева, 5Б"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E61000005FB35C363AE75A409279E40F06EC4940
26180	5	44	7505	60394	75676	\N	51.834152026862498	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Комсомольская, 3"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000E46723D74DE85A404EF2237EC5EA4940
26186	5	44	7505	\N	75187	\N	51.830536000000002	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Буйко, 2А"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000035CF11F92EE75A404913EF004FEA4940
26327	5	44	1744	52913	75815	\N	52.157133999999999	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хоринское""с.Хоринск, Хоринская, 68"		0101000020E6100000BDC282FB01715B407A8B87F71C144A40
26328	5	44	1744	52913	74583	\N	52.160723173419498	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хоринское"", Театральная, 8"	Россия, Республика Бурятия, Хоринский район, село Хоринск	0101000020E6100000B8C83D5DDD715B40855B3E9292144A40
26326	5	44	1744	52913	74172	\N	52.159363906597697	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хоринское""Хоринск, Ленина, 38"	Россия, Республика Бурятия, Хоринский район, село Хоринск	0101000020E61000009546CCECF3705B407214200A66144A40
26305	5	44	1744	52856	76752	\N	52.288196807662203	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хасуртайское""с.Хасурта, Центральная, 113 A"	Россия, Республика Бурятия, Хоринский район, село Хасурта	0101000020E6100000D7FB8D76DC375B4014E7A8A3E3244A40
26313	5	44	1744	52878	76878	\N	52.010015000000003	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хандагайское""п.Хандагай, Школьная, 8"		0101000020E61000000D33349E08485B4017BCE82B48014A40
26307	5	44	1744	32815	76580	\N	52.140040999999997	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Удинское""с.Удинск, Ленина, 87"		0101000020E6100000338CBB41B44D5B40B08C0DDDEC114A40
26304	5	44	1744	60801	76280	\N	52.451692999999999	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Верхнекурбинское"" у.Тэгда, Центральная, 26А"		0101000020E6100000C66E9F5566645B40836A8313D1394A40
26035	5	44	1140	16960	76658	\N	52.089958000000003	с.Мостовка, ул.Молодежная, 19		0101000020E61000004AF086342AC25A40BD0166BE830B4A40
26302	5	44	1744	52847	76761	\N	52.558902000000003	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Ойбонтовское""улус Тохорюкта, Школьная, 16"		0101000020E6100000274F594DD7525B40A2D5C9198A474A40
26311	5	44	1744	60918	76763	\N	52.112063999999997	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Кульское"" с.Тарбагатай, Тарбагатайская, 32"	Россия, Республика Бурятия, Хоринский район, село Тарбагатай	0101000020E61000003C16DBA4A24C5B408B87F71C580E4A40
26312	5	44	1744	60985	76887	\N	52.120924883254503	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Кульское"" с.Санноомыск, Ленина, 1"	Россия, Республика Бурятия, Хоринский район, село Санномыск	0101000020E61000003C4CFBE6FE595B4068226C787A0F4A40
26320	5	44	1744	52905	76930	\N	52.255260999999997	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Краснопартизанское""с.Ониноборск, Школьная, 6"		0101000020E6100000B83EAC376A815B40DD787764AC204A40
26303	5	44	1744	52851	76989	\N	52.497957	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Верхнекурбинское"" п.Ойбонт, Центральная, 22"		0101000020E61000001F662FDB4E4D5B403AE8120EBD3F4A40
26314	5	44	1744	60917	76758	\N	52.076655217427003	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хандагайское""п.Нарын, Магистральная, 36"	Россия, Республика Бурятия, Хоринский район, село Нарын	0101000020E6100000A27DACE0B7535B409609BFD4CF094A40
26301	5	44	1744	52842	76951	\N	52.651242000000003	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Верхнекурбинское"" с.Малая Курба, Школьная, 6"		0101000020E61000005B07077B13615B400DE4D9E55B534A40
26319	5	44	1744	52893	76983	\N	52.507375000000003	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хоринское"" п.Майла, Школьная, 9"		0101000020E6100000F7AFAC3429805B406DE7FBA9F1404A40
26316	5	44	1744	60958	76837	\N	52.166724000000002	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Улан-Одонское"" у.Кульский Станок, Школьная, 5"	Россия, Республика Бурятия, Хоринский район, село Кульский Станок	0101000020E61000003C6876DD5B675B40AABA473657154A40
26315	5	44	1744	52887	76747	\N	52.131821000000002	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Кульское""с.Кульск, Кульская, 13А"		0101000020E6100000615111A793675B4088F6B182DF104A40
26322	5	44	1744	52901	76751	\N	52.167613000000003	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Краснопартизанское""п.Зун-хурай, Школьная, 7"		0101000020E6100000043DD4B661835B4036B1C05774154A40
26309	5	44	1744	60988	76892	\N	52.000785	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Верхнеталецкое"" у. Додо-гол, Советская, 34"	Россия, Республика Бурятия, Хоринский район, село Додо-Гол	0101000020E6100000CD72D9E89C2E5B40E7A90EB919004A40
26310	5	44	1744	32838	76654	\N	52.041851000000001	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Верхнеталецкое""с.Верхние-Тальцы, Комсомольская, 1А"		0101000020E610000096236420CF3B5B400727A25F5B054A40
26321	5	44	1744	52896	76743	\N	52.282558000000002	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Краснопартизанское""у.Булум, Школьная, 5"		0101000020E61000008DCF64FF3C875B40919C4CDC2A244A40
26308	5	44	1744	52871	76832	\N	52.173158999999998	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Удинское""у.Баян-Гол, Клубная, 3Б"		0101000020E610000082A966D652555B400801F9122A164A40
26306	5	44	1744	52861	76863	\N	52.148446999999997	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Удинское""у.Барун-Хасурта, Балбарова, 403"		0101000020E6100000FF1F274C18415B403B18B14F00134A40
26323	5	44	1744	52907	76982	\N	52.366728000000002	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Ашангинское""у.Ашанга, Центральная, 1"		0101000020E6100000FF3D78EDD2905B4085436FF1F02E4A40
26325	5	44	1744	52907	76850	\N	52.366252838601497	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Ашангинское""с.Георгиевка, Харитонова, 25"	Россия, Республика Бурятия, Хоринский район, село Ашанга	0101000020E6100000E7FBA9F1D2905B40EC87D860E12E4A40
26318	5	44	1744	52892	76750	\N	52.195815000000003	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Хоринское""у.Анинск, Строительная, 4"		0101000020E61000006D3CD862B7755B407B88467710194A40
26324	5	44	1744	52909	76981	\N	52.398533999999998	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Ашангинское""у.Амгаланта, Интернациональная, 26"		0101000020E61000008126C286A7985B400A2C802903334A40
26317	5	44	1744	52891	76855	\N	52.314061000000002	"Республика Бурятия, муниципальный район ""Хоринский район"", сельское поселение ""Улан-Одонское""у.Алан, Коммунистическая, 16"		0101000020E61000000B0A83328D775B407BF99D2633284A40
26124	5	44	1671	61057	77111	\N	51.798924802122301	c. Шулуты, Гагарина, 10		0101000020E61000001AFCFD62B6C85940787AA52C43E64940
26155	5	44	1671	22977	76708	\N	51.676354000000003	Республика Бурятия, Тункинский район, с. Шимки, Октябрьская, 44		0101000020E61000004E97C5C4E6805940684293C492D64940
26127	5	44	1671	21711	76769	\N	51.750773000000002	Республика Бурятия, Тункинский район, с. Шанай, Советская, помещение школы-сад		0101000020E61000007E52EDD3F1B6594023DC645419E04940
26022	5	44	1140	45959	76698	\N	52.167833999999999	с.Листвиничное, Заводская, 1		0101000020E610000051F86C1D1CE25A401494A2957B154A40
26154	5	44	1671	22913	76626	\N	51.677822133031903	Республика Бурятия, Тункинский район, с. Хужиры, Школьная, 1	Россия, Республика Бурятия, Тункинский район, село Хужиры	0101000020E6100000EF75525F9685594031410DDFC2D64940
26158	5	44	1671	60977	76871	\N	51.511896999999998	Республика Бурятия, Тункинский район, с. Хойтогол, Квартал 10, 37		0101000020E61000008272DBBE478F5940D3F544D785C14940
26147	5	44	1671	22646	76739	\N	51.668652000000002	Республика Бурятия, Тункинский район, с. Харбяты, Ербанова, 5		0101000020E610000027DD96C805925940D733846396D54940
26138	5	44	1671	22205	76829	\N	51.807274999999997	Республика Бурятия, Тункинский район, с. Улбугай, пер. Лесной, 4		0101000020E6100000DC0F7860009459406FF085C954E74940
26156	5	44	1671	23021	76759	\N	51.636220000000002	Республика Бурятия, Тункинский район, с. Туран, Центральная, 78		0101000020E610000062F3716DA8695940D3872EA86FD14940
26133	5	44	1671	21977	76577	\N	51.753777999999997	Республика Бурятия, Тункинский район, с. Тунка, Горького, 61		0101000020E61000007AA702EE79A25940DE3829CC7BE04940
26125	5	44	1671	21576	76576	\N	51.788800000000002	Республика Бурятия, Тункинский район, с. Торы, Трактовая, 26		0101000020E6100000CEA96400A8C05940DB8AFD65F7E44940
26139	5	44	1671	60961	76840	\N	51.511896999999998	Республика Бурятия, Тункинский район, с. Толтой, Кооперативная, 5		0101000020E61000008272DBBE478F5940D3F544D785C14940
26134	5	44	1671	61006	76980	\N	51.511896999999998	Республика Бурятия, Тункинский район, с. Токурен, Траковая, 6		0101000020E61000008272DBBE478F5940D3F544D785C14940
26137	5	44	1671	22194	76839	\N	51.822001999999998	Республика Бурятия, Тункинский район, с. Талое, Каменушка, 12а	Россия, Республика Бурятия, Тункинский район, село Талое	0101000020E6100000B77EFACF9A9E5940909F8D5C37E94940
26140	5	44	1671	22299	76830	\N	51.878925000000002	Республика Бурятия, Тункинский район, с. Тагархай, Балданова, 12		0101000020E61000001CB1169F029959408351499D80F04940
26136	5	44	1671	61014	76993	\N	51.786472804572497	Республика Бурятия, Тункинский район, с. Таблангут, Молодежная, 2а	Россия, Республика Бурятия, Тункинский район, село Табалангут	0101000020E6100000B3EE1F0BD19F5940F017B325ABE44940
26145	5	44	1671	22529	76741	\N	51.674702650881898	Республика Бурятия, Тункинский район, с. Охор-Шибирь, Школьная, 1	Россия, Республика Бурятия, Тункинский район, село Охор-Шибирь	0101000020E6100000C21550A8A79A5940ADC1FBAA5CD64940
26148	5	44	1671	22660	76748	\N	51.689008000000001	Республика Бурятия, Тункинский район, с. Нуган, Калинина, помещение школы-сад		0101000020E6100000C5538F34B88C59405857056A31D84940
26157	5	44	1671	60944	76805	\N	51.690875214860696	Республика Бурятия, Тункинский район, с. Нилова-Пустынь, Центральная, 32	Россия, Республика Бурятия, Тункинский район, село Ниловка	0101000020E610000029CC7B9C696B5940DF4F8D976ED84940
26132	5	44	1671	49341	77009	\N	51.731082194620299	Республика Бурятия, Тункинский район, с. Никольское, Трактовая, 2	Россия, Республика Бурятия, Тункинский район, село Никольск	0101000020E610000004029D499BA45940DE58501894DD4940
26159	5	44	1671	23169	76509	\N	51.674801000000002	Республика Бурятия, Тункинский район, с. Монды, Ленина, 38		0101000020E61000004CC5C6BC8E3F5940702711E15FD64940
26146	5	44	1671	22568	76740	\N	51.687288000000002	Республика Бурятия, Тункинский район, с. Малый Жемчуг, Тулаева, 21		0101000020E6100000902E36AD1497594075779D0DF9D74940
26151	5	44	1671	22716	\N	\N	51.682999000000002	Республика Бурятия, Тункинский район, с. Кырен, Ленина, 116А	Россия, Республика Бурятия, Тункинский район, село Кырен	0101000020E61000002028B7ED7B885940B119E0826CD74940
26149	5	44	1671	22716	76534	\N	51.682569676430496	Республика Бурятия, Тункинский район, с. Кырен, Чапаева, 16	Россия, Республика Бурятия, Тункинский район, село Кырен	0101000020E6100000F9669B1BD3885940889D29745ED74940
26152	5	44	1671	22716	76623	\N	51.6829965097997	Республика Бурятия, Тункинский район, с. Кырен, Ленина, 135	Россия, Республика Бурятия, Тункинский район, село Кырен	0101000020E6100000BF4868CBB9885940102219726CD74940
26150	5	44	1671	22716	76623	\N	51.685130615977599	Республика Бурятия, Тункинский район, с. Кырен, Ленина, 98	Россия, Республика Бурятия, Тункинский район, село Кырен	0101000020E6100000E277D32D3B895940E63C635FB2D74940
26126	5	44	1671	21646	76533	\N	51.742119000000002	Республика Бурятия, Тункинский район, с. Зун-Мурино, Индиры Ганди, б/н		0101000020E61000003B55BE6724B85940C05E61C1FDDE4940
26143	5	44	1671	22436	76881	\N	51.692151000000003	Республика Бурятия, Тункинский район, с. Зактуй, Школьная, б/н		0101000020E61000005E471CB281A8594065726A6798D84940
26144	5	44	1671	22489	76647	\N	51.683703000000001	Республика Бурятия, Тункинский район, с. Жемчуг, Советская, 2	Россия, Республика Бурятия, Тункинский район, село Жемчуг	0101000020E61000007DE9EDCF459D5940AB96749483D74940
26024	5	44	1671	21827	76807	\N	51.765165468424598	с.Еловка, Школьная, 2А	Россия, Республика Бурятия, Тункинский район, село Еловка	0101000020E6100000691A14CD03B159409D853DEDF0E14940
26130	5	44	1671	21827	76736	\N	51.755645999999999	Республика Бурятия, Тункинский район, с. Еловка, Комсомольская, 1		0101000020E6100000D787F546ADB0594036AD1402B9E04940
26128	5	44	1671	21733	76738	\N	51.810794000000001	Республика Бурятия, Тункинский район, с. Далахай, Ленина, 1		0101000020E6100000E9D1544FE6BF594082E50819C8E74940
26129	5	44	1671	21810	76842	\N	51.790889	Республика Бурятия, Тункинский район, с. Гужиры, Истомина, 25		0101000020E61000006B6116DA39B9594011E2CAD93BE54940
26135	5	44	1671	22083	76848	\N	51.790877999999999	Республика Бурятия, Тункинский район, с. Галбай, Ленина, 20		0101000020E610000035B401D880A259401D90847D3BE54940
26131	5	44	1671	21892	76735	\N	51.787970000000001	Республика Бурятия, Тункинский район, с. Ахалик, Ленина, 30		0101000020E61000002DCF83BBB3AB5940541D7233DCE44940
26142	5	44	1671	22355	76664	\N	51.909260000000003	Республика Бурятия, Тункинский район,  с. Аршан, Трактовая, 74А		0101000020E6100000D7A02FBDFD9B5940CEC7B5A162F44940
26141	5	44	1671	22355	76664	\N	51.909260000000003	с. Аршан, Трактовая, 30		0101000020E6100000D7A02FBDFD9B5940CEC7B5A162F44940
14700	5	44	1140	10649	76776	\N	52.760598999999999	с.Котокель, Озерная, 27		0101000020E610000076887FD8D2045B40662FDB4E5B614A40
26117	5	44	1632	21252	76879	\N	51.227409999999999	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Барыкинское"", с.Харитоново, Калинина, 40"		0101000020E6100000FC19DEACC1BF5A40456458C51B9D4940
26115	5	44	1632	60907	76706	\N	51.274354000000002	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Верхнежиримское"", с.Хандагатай, Антонова, 37"		0101000020E61000002BFA43334FD45A406EC328081EA34940
26111	5	44	1632	20832	71708	\N	51.480615	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Тарбагатайское"", с.Тарбагатай, Рокоссовского, 3"		0101000020E6100000C4279D4830D75A40C87BD5CA84BD4940
26109	5	44	1632	20832	75977	\N	51.480615	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Тарбагатайское"", с.Тарбагатай, Ленина, 31"		0101000020E6100000C4279D4830D75A40C87BD5CA84BD4940
26108	5	44	1632	20758	76742	\N	51.497759000000002	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Тарбагатайское"", с.Пестерево, Кирова, 60 А"		0101000020E61000009A5E622CD3DD5A4014252191B6BF4940
26123	5	44	1632	21491	76651	\N	51.653880000000001	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Заводское"", п.Николаевский, Октябрьская, 1"		0101000020E6100000FBAE08FEB7F25A4016C1FF56B2D34940
26112	5	44	1632	21008	76737	\N	51.426084000000003	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Нижнежиримское"", с.Нижний Жирим, Калинина, 47"		0101000020E6100000225514AFB2CC5A40A8ACA6EB89B64940
26104	5	44	1632	20545	76827	\N	51.546368000000001	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Куйтунское"", с.Надеино, Ленина, 77"		0101000020E6100000FF959526A5EA5A405CCAF962EFC54940
26103	5	44	1632	20526	76529	\N	51.527740999999999	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Куйтунское"", с.Куйтун, Ленина, 65 А"		0101000020E610000018EAB0C22DF05A4011E15F048DC34940
26106	5	44	1632	20646	76859	\N	51.417411999999999	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Десятниковское"", с.Десятниково, Ленина, 32"		0101000020E6100000E2EA0088BBDC5A409E7AA4C16DB54940
26113	5	44	1632	21028	76660	\N	51.314155999999997	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Верхнежиримское"", с.Верхний Жирим, Советская, 10"		0101000020E6100000C493DDCCE8CD5A40CCEB884336A84940
26107	5	44	1632	20746	76836	\N	51.426026999999998	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Десятниковское"", с.Бурнашево, Молодежная, 28"		0101000020E6100000B76114048FD85A40431B800D88B64940
26105	5	44	1632	20633	76583	\N	51.432777000000002	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Большекуналейское"", с.Большой Куналей, Ленина, 173"		0101000020E61000007C7C4276DEE65A4002BB9A3C65B74940
26114	5	44	1632	21093	76828	\N	51.258895000000003	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Верхнежиримское"", с.Барыкино-Ключи, Ленина, 20"		0101000020E61000000F81238106D15A40890CAB7823A14940
26116	5	44	1632	21188	76867	\N	51.236327000000003	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Барыкинское"", с.Барыкино, Ленина, 98"		0101000020E6100000912A8A5759CC5A40B61490F63F9E4940
26089	5	44	1551	60873	\N	\N	51.075093939274502	Республика Бурятия, Селенгинский район, Ноехонский сомон, улус Зурган-Дэбэ, средняя школа	Россия, Республика Бурятия, Селенгинский район, село Зурган-Дэбэ (Ноёхон)	0101000020E61000009FCA694FC9C05A401B1021AE9C894940
26077	5	44	1551	19085	\N	\N	51.40108	Республика Бурятия, Селенгинский район, село Ягодное, начальная школа		0101000020E61000001901158E20A05A40338AE59656B34940
26083	5	44	1551	19368	\N	\N	50.928986000000002	Республика Бурятия, Селенгинский район, село Шана, начальная школа		0101000020E6100000A8A624EB708D5A408F386403E9764940
26095	5	44	1551	60959	\N	\N	51.051132000000003	Республика Бурятия, Селенгинский район, Иройский сомон, улус Усть-Урма, школа-интернат	Россия, Республика Бурятия, Селенгинский район, село Усть-Урма	0101000020E6100000F0A65B76887E5A40B9E34D7E8B864940
25975	5	44	1551	61011	76988	\N	51.034725000000002	у.Усть-Алташа, Солнечная, 4		0101000020E6100000B56E83DA6FC45A4043AD69DE71844940
26096	5	44	1551	60955	\N	\N	51.122120000000002	Республика Бурятия, Селенгинский район, Иройский сомон, улус Удунга, клуб	Россия, Республика Бурятия, Селенгинский район, село Удунга	0101000020E610000096D1C8E7157F5A400118CFA0A18F4940
26076	5	44	1551	60874	\N	\N	51.363143112786098	Республика Бурятия, Селенгинский район, улус Тохой, Дом культуры	Россия, Республика Бурятия, Селенгинский район, село Тохой	0101000020E6100000B493C151F2A65A40BB6246787BAE4940
26097	5	44	1551	20127	76978	\N	51.004531	Республика Бурятия, Селенгинский район, Темникский сельсовет, поселок Темник, Садовая, 32		0101000020E61000001C446B459B8B5A40BA68C87894804940
26094	5	44	1551	60893	\N	\N	50.984760305364098	Республика Бурятия, Селенгинский район, Иройский сомон, улус Ташир, средняя школа	Россия, Республика Бурятия, Селенгинский район, село Ташир	0101000020E6100000DC2C5E2C0C745A4059349D9D0C7E4940
26080	5	44	1551	19255	\N	\N	51.201473999999997	Республика Бурятия, Селенгинский район, поселок Таежный, основная школа		0101000020E61000005C21ACC6126E5A40457F68E6C9994940
26019	5	44	1140	16145	76645	\N	52.165536000000003	с.Кома, Коммунистическая, 75а		0101000020E6100000927A4FE5B4DF5A40C4279D4830154A40
14701	5	44	1140	10714	76773	\N	52.496048999999999	с.Кика, Трактовая, 28		0101000020E61000003CBF28417F015B40541B9C887E3F4A40
26099	5	44	1551	20250	76826	\N	51.461365999999998	"Республика Бурятия, Селенгинский район, Нижне-Убукунский сельсовет, село Средний Убукун, Е.Волковой, 18""б"""		0101000020E6100000DDB6EF517FAE5A4040BE840A0EBB4940
26081	5	44	1551	19280	\N	\N	50.918709	Республика Бурятия, Селенгинский район, поселок Селендума, СДК		0101000020E6100000744012F6ED8E5A403BC5AA4198754940
26082	5	44	1551	60932	76792	\N	50.9170809785982	"Республика Бурятия, муниципальный район ""Селенгинский район"", сельское поселение ""Селендума"", ул.Фрунзе, 19, администрация с.Селендума"		0101000020E6100000B1FA230C038F5A40396403E962754940
26085	5	44	1551	19489	\N	\N	50.920116999999998	Республика Бурятия, Селенгинский район, поселок Поворот, школа-интернат		0101000020E61000002BC1E270E6A75A402FBFD364C6754940
26086	5	44	1551	60966	76849	\N	50.805760828489603	Республика Бурятия, Селенгинский район, улус Нур-Тухум, переулок Школьный, 1А	Россия, Республика Бурятия, Селенгинский район, село Нур-Тухум	0101000020E6100000A8C30AB77C9C5A4035B22B2D23674940
26084	5	44	1551	19449	\N	\N	51.091886000000002	Республика Бурятия, Селенгинский район, поселок Новоселенгинск, Дом культуры		0101000020E61000000D6FD6E07DA85A40EA7AA2EBC28B4940
26090	5	44	1551	60983	76885	\N	51.070619768443798	"Республика Бурятия, муниципальный район ""Селенгинский район"", сельское поселение ""Ноехонское"", Солнечная ул., 1, Здание администрации МО СП"	Россия, Республика Бурятия, Селенгинский район, село Зурган-Дэбэ (Ноёхон)	0101000020E6100000790261A758C15A40C5387F130A894940
26100	5	44	1551	60987	76891	\N	51.409272764242203	Республика Бурятия, Селенгинский район, Жаргалантуйский сомон, улус Жаргалантуй, Ленина, 28	Россия, Республика Бурятия, Селенгинский район, село Жаргаланта	0101000020E6100000E014562AA8AA5A406211C30E63B44940
26092	5	44	1551	60956	\N	\N	51.101038000000003	Республика Бурятия, Селенгинский район, Ехэ-Цаганский сомон, улус Ехэ-Цаган, средняя школа		0101000020E6100000BC07E8BE9C8B5A409ED32CD0EE8C4940
26088	5	44	1551	60954	\N	\N	50.991424237470902	Республика Бурятия, Селенгинский район, Убун-Дзокойский сомон, улус Енхор, начальная школа		0101000020E6100000A9BC1DE1B49F5A40193C4CFBE67E4940
26101	5	44	1551	60962	\N	\N	51.265495000000001	Республика Бурятия, Селенгинский район, Зуево-Сутойский сомон, улус Дэдэ-Сутой, Средняя школа	Россия, Республика Бурятия, Селенгинский район, село Дэдэ-Сутой	0101000020E61000007427D87F9DB65A4032207BBDFBA14940
26087	5	44	1551	46986	\N	\N	50.7467951370039	Республика Бурятия, Селенгинский район, улус Дэбэн, начальная школа	Россия, Республика Бурятия, Селенгинский район, село Дэбэн (Обон-Гызык)	0101000020E610000078D32D3BC4935A407DE882FA965F4940
25609	5	44	1551	46986	76937	\N	50.747611999999997	село Дэбэн, Дэбэн, 15		0101000020E61000008C118942CB935A406F0C01C0B15F4940
26091	5	44	1551	18497	\N	\N	51.2964834654424	Республика Бурятия, Селенгинский район, город Гусиноозерск, СОШ № 92	Россия, Республика Бурятия, Селенгинский район, город Гусиноозерск	0101000020E61000006939D0436DA05A40F568AA27F3A54940
26075	5	44	1551	18497	\N	\N	51.297072	Республика Бурятия, Селенгинский район, город Гусиноозерск, станция Загустай	Россия, Республика Бурятия, Селенгинский район, город Гусиноозерск	0101000020E610000019A9F7544EA05A4056478E7406A64940
26068	5	44	1551	18497	75729	\N	51.294277179996897	"Республика Бурятия, Селенгинский район, город Гусиноозерск, ул.Пушкина, 34, ГЦД ""Россия"""		0101000020E6100000ED0F94DBF6A15A40857B65DEAAA54940
26066	5	44	1551	18497	74869	\N	51.297072	Республика Бурятия, Селенгинский район, город Гусиноозерск, улица Ленина, 19, Спорткомплекс	Россия, Республика Бурятия, Селенгинский район, город Гусиноозерск	0101000020E610000019A9F7544EA05A4056478E7406A64940
26073	5	44	1551	18497	71704	\N	51.294546244903998	Республика Бурятия, Селенгинский район, город Гусиноозерск, ул.Красноармейская, 1, СОШ № 6	Россия, Республика Бурятия, Селенгинский район, город Гусиноозерск	0101000020E61000007A5567B5C0A15A407495EEAEB3A54940
26102	5	44	1551	18497	75795	\N	51.297072	"Республика Бурятия, Селенгинский район, город Гусиноозерск, ул.Комсомольская, 6, МУ ДК ""Шахтер"""		0101000020E610000019A9F7544EA05A4056478E7406A64940
26067	5	44	1551	18497	75969	\N	51.297072	Республика Бурятия, Селенгинский район, город Гусиноозерск, улицы Колхозная, 2А, Гусиноозерская гимназия		0101000020E610000019A9F7544EA05A4056478E7406A64940
26070	5	44	1551	18497	71700	\N	51.297072	Республика Бурятия, Селенгинский район, город Гусиноозерск, улица Ключевская, 14А, СОШ № 4		0101000020E610000019A9F7544EA05A4056478E7406A64940
26069	5	44	1551	18497	75974	\N	51.296214411948199	Республика Бурятия, Селенгинский район, город Гусиноозерск, улица Водная, 1		0101000020E61000008F6FEF1AF4A05A40054F2157EAA54940
26071	5	44	1551	60528	75180	\N	51.294922933111003	Республика Бурятия, Селенгинский район, город Гусиноозерск, 6 микрорайон, 20А, СОШ № 5		0101000020E6100000DB6D179AEBA15A404AEB6F09C0A54940
26079	5	44	1551	19181	\N	\N	51.243527999999998	Республика Бурятия, Селенгинский район, поселок Бараты, средняя школа		0101000020E6100000B515FBCBEE975A4084D4EDEC2B9F4940
26078	5	44	1551	19110	\N	\N	51.437869999999997	Республика Бурятия, Селенгинский район, поселок Ардасан, начальная школа		0101000020E61000001CD2A8C0C9A45A4023F3C81F0CB84940
26054	5	44	1479	17877	\N	\N	56.252237000000001	Республика Бурятия, Северо-Байкальский район, поселок Янчукан, Б/С, 102	Россия, Республика Бурятия, Северобайкальский район, поселок городского типа Янчукан	0101000020E61000005649641F64335C40ABEB504D49204C40
26025	5	44	1140	16450	76656	\N	52.095982999999997	с.Старое Татаурово, Юбилейная, 93	Россия, Республика Бурятия, Прибайкальский район, село Старое Татаурово	0101000020E6100000D1E80E6267DE5A4069FCC22B490C4A40
26042	5	44	1479	61052	77056	\N	55.881015874444302	Республика Бурятия, Северо-Байкальский район, село Холодное, Ленина, 12	Россия, Республика Бурятия, Северобайкальский район, село Холодная	0101000020E6100000C289E8D7D6705B405AA0DD21C5F04B40
26047	5	44	1479	17532	76775	\N	56.129865000000002	Республика Бурятия, Северо-Байкальский район, село Уоян, Набережная, 1а		0101000020E610000091EF52EA92E75B4091F2936A9F104C40
26056	5	44	1479	17925	76184	\N	55.625964000000003	Республика Бурятия, город Северобайкальск, пр-т Пролетарский, 2		0101000020E610000069519FE40E545B40973C9E961FD04B40
26060	5	44	1479	17925	74316	\N	55.629706626394203	"Республика Бурятия, городской округ ""Город Северобайкальск"", пр-т 60 лет СССР, 40А"		0101000020E6100000419C871398545B40F9872D3D9AD04B40
26058	5	44	1479	17925	74316	\N	55.631295379186597	Республика Бурятия, город Северобайкальск, пр-т 60 лет СССР, 19	Россия, Республика Бурятия, Северобайкальский район, город Северобайкальск	0101000020E610000017F2086EA4555B406D904946CED04B40
26059	5	44	1479	17925	71689	\N	55.625964000000003	Республика Бурятия, город Северобайкальск, пр-т Ленинградский, 11		0101000020E610000069519FE40E545B40973C9E961FD04B40
26064	5	44	1479	17925	76405	\N	55.624836779554698	Республика Бурятия, город Северобайкальск, пер. Пионерский, 4		0101000020E61000004434BA83D8545B40562AA8A8FACF4B40
26062	5	44	1479	17925	71693	\N	55.625964000000003	Республика Бурятия, город Северобайкальск, Пер. Школьный, 6		0101000020E610000069519FE40E545B40973C9E961FD04B40
26061	5	44	1479	17925	75954	\N	55.625964000000003	Республика Бурятия, город Северобайкальск, ул. Мира, 4		0101000020E610000069519FE40E545B40973C9E961FD04B40
26048	5	44	1479	17605	76563	\N	56.139276000000002	Республика Бурятия, Северо-Байкальский район, поселок Новый Уоян, Лесоводов, 6		0101000020E61000001FBFB7E9CFEE5B40118FC4CBD3114C40
26050	5	44	1479	17605	76573	\N	56.139276000000002	Республика Бурятия, Северо-Байкальский район, поселок Новый Уоян, Добровольцев, 15		0101000020E61000001FBFB7E9CFEE5B40118FC4CBD3114C40
26052	5	44	1479	17605	76977	\N	56.139276000000002	"Республика Бурятия, Северо-Байкальский район, поселок Новый Уоян, Байкальская, здание ком. магазина ""Волна"""		0101000020E61000001FBFB7E9CFEE5B40118FC4CBD3114C40
26049	5	44	1479	17605	76655	\N	56.139276000000002	Республика Бурятия, Северо-Байкальский район, поселок Новый Уоян, 70 лет Октября, 33		0101000020E61000001FBFB7E9CFEE5B40118FC4CBD3114C40
26051	5	44	1479	60933	76793	\N	56.139276000000002	Республика Бурятия, Северо-Байкальский район, поселок Новый Уоян, Восточная, 8		0101000020E61000001FBFB7E9CFEE5B40118FC4CBD3114C40
26039	5	44	1479	16975	76657	\N	55.790042999999997	Республика Бурятия, Северо-Байкальский район, поселок Нижнеангарск, Рабочая, 127а		0101000020E610000076711B0DE0645B4084B7072120E54B40
26037	5	44	1479	16975	71504	\N	55.790042999999997	Республика Бурятия, Северо-Байкальский район, поселок Нижнеангарск, Победы, 2		0101000020E610000076711B0DE0645B4084B7072120E54B40
26040	5	44	1479	16975	76574	\N	55.790042999999997	Республика Бурятия, Северо-Байкальский район, поселок Нижнеангарск, Озерная, 8		0101000020E610000076711B0DE0645B4084B7072120E54B40
26038	5	44	1479	16975	74867	\N	55.790042999999997	Республика Бурятия, Северо-Байкальский район, поселок Нижнеангарск, Кооперативная, 87		0101000020E610000076711B0DE0645B4084B7072120E54B40
26053	5	44	1479	17829	76755	\N	55.885711000000001	Республика Бурятия, Северо-Байкальский район, село Кумора, Юбилейная, 14		0101000020E610000027DC2BF356CD5B408E5A61FA5EF14B40
26044	5	44	1479	17318	76515	\N	55.935405000000003	Республика Бурятия, Северо-Байкальский район, поселок Кичера, Центральная, 1		0101000020E61000008AC745B588865B40E8C1DD59BBF74B40
26043	5	44	1479	17318	76553	\N	55.935405000000003	Республика Бурятия, Северо-Байкальский район, поселок Кичера, Мелиораторов, 7б		0101000020E61000008AC745B588865B40E8C1DD59BBF74B40
26045	5	44	1479	17423	76517	\N	55.848210000000002	Республика Бурятия, Северо-Байкальский район, с. Верхняя Заимка, ул. Советская 37 здание администрации села		0101000020E610000028EE7893DF885B40F111312592EC4B40
26041	5	44	1479	17238	76650	\N	55.356574999999999	Республика Бурятия, Северо-Байкальский район, село Байкальское, Победы, 7а		0101000020E610000046ED7E15E04B5B401DC9E53FA4AD4B40
26046	5	44	1479	17484	76560	\N	56.008947999999997	Республика Бурятия, Северо-Байкальский район, село Ангоя, Космонавтов, 2		0101000020E61000001FBE4C1421BA5B40ABAE433525014C40
26036	5	44	7504	60261	74154	\N	55.790042999999997	Республика Бурятия, Северо-Байкальский район, поселок Нижнеангарск, Победы, 43		0101000020E610000076711B0DE0645B4084B7072120E54B40
26005	5	44	1140	15474	\N	\N	52.876910000000002	"с.Ярцы, курорт ""Байкальский Бор"""		0101000020E6100000357BA01518095B4087C43D963E704A40
26032	5	44	1140	16796	76845	\N	52.122500000000002	с.Югово, 40 лет Октября, 31		0101000020E6100000705B5B785EC75A4048E17A14AE0F4A40
26013	5	44	1140	15847	76727	\N	52.225405000000002	с.Халзаново, Мелиораторов, 8		0101000020E6100000BDAAB35A60EB5A406DAD2F12DA1C4A40
26018	5	44	1140	16041	75675	\N	52.197420999999999	с.Турунтаево, Профсоюзная, 2		0101000020E61000000473F4F8BDE85A409545611745194A40
26017	5	44	1140	16041	76518	\N	52.197420999999999	с.Турунтаево, Ленина, 75		0101000020E61000000473F4F8BDE85A409545611745194A40
26016	5	44	1140	16041	71684	\N	52.197420999999999	с.Турунтаево, 50 лет Октября, 3		0101000020E61000000473F4F8BDE85A409545611745194A40
26015	5	44	1140	16041	76726	\N	52.197420999999999	с.Турунтаево, 16 квартал, ТУСМ		0101000020E61000000473F4F8BDE85A409545611745194A40
26003	5	44	1140	15360	75714	\N	52.9456545607298	с.Турка, Школьная, 34	Россия, Республика Бурятия, Прибайкальский район, село Турка	0101000020E6100000117349D5760E5B40422619390B794A40
26031	5	44	1140	46156	76744	\N	52.118903329780899	с.Троицкое, ул.60 лет Октября, 30	Россия, Республика Бурятия, Прибайкальский район, село Троицкое	0101000020E6100000A20914B188CB5A40BA32A836380F4A40
26026	5	44	1140	16467	75722	\N	52.139029999999998	ст.Татаурово, Школьная, 20		0101000020E610000082E50819C8DB5A40D9942BBCCB114A40
26033	5	44	1140	46239	74866	\N	52.116224294077199	ст.Таловка, Лазо, 3а	Россия, Республика Бурятия, Прибайкальский район, село Таловка	0101000020E61000009357E71890C85A405281936DE00E4A40
26004	5	44	1140	45613	76821	\N	52.8676466640947	с.Исток, Братьев Ильиных, 73	Россия, Республика Бурятия, Прибайкальский район, село Исток	0101000020E6100000E1B20A9B010D5B407BBC900E0F6F4A40
26014	5	44	1140	15868	76646	\N	52.190482000000003	с.Иркилик, Братьев Седуновых, 24		0101000020E6100000EB707495EEEA5A40043DD4B661184A40
26030	5	44	1140	33021	76733	\N	52.122439	с.Ильинка, Павлова, 9		0101000020E610000093533BC3D4D05A40A260C614AC0F4A40
26028	5	44	1140	33021	71493	\N	52.123125784800898	с.Ильинка, Октябрьская, 123	Россия, Республика Бурятия, Прибайкальский район, село Ильинка	0101000020E610000057CD7344BED05A40C6A4BF97C20F4A40
26027	5	44	1140	33021	71493	\N	52.122439	с.Ильинка, Октябрьская, 65а	Россия, Республика Бурятия, Прибайкальский район, село Ильинка	0101000020E610000093533BC3D4D05A40A260C614AC0F4A40
26029	5	44	1140	33021	76649	\N	52.124554779970303	с.Ильинка, Коммунистическая, 63	Россия, Республика Бурятия, Прибайкальский район, село Ильинка	0101000020E6100000925A28999CD05A40D2C6116BF10F4A40
26011	5	44	1140	15763	76802	\N	52.265051	с.Зырянск, Партизанская, 1А		0101000020E61000007B4CA4349BF15A40D462F030ED214A40
26000	5	44	1140	15202	76970	\N	52.986891999999997	с.Золотой Ключ, Набережная, 13		0101000020E610000021037976F9295B408E57207A527E4A40
14702	5	44	1140	10737	76933	\N	52.401423999999999	с.Гурулево, Центральная, 12а		0101000020E61000009065C1C41FFB5A402DEA93DC61334A40
26006	5	44	1140	15497	76550	\N	52.798838000000003	с.Гремячинск, Пионерская, 23		0101000020E6100000C5758C2B2EFE5A40AA66D65240664A40
26002	5	44	1140	15323	\N	\N	52.983986000000002	с.Горячинск, Октябрьская, 66А	Россия, Республика Бурятия, Прибайкальский район, село Горячинск	0101000020E610000022E2E65432135B4066DCD440F37D4A40
26009	5	44	1140	15663	\N	\N	52.354475000000001	с.Бурля, 12		0101000020E610000066101FD8F1EF5A40F31FD26F5F2D4A40
26020	5	44	1140	45925	76841	\N	52.090899	с.Бурдуково, Октябрьская, 32		0101000020E6100000B98E71C5C5E05A409B1E1494A20B4A40
26008	5	44	1140	45693	76799	\N	52.334994000000002	с.Батурино, Монастырская, 2Б		0101000020E61000000805A568E5F65A40992D5915E12A4A40
26010	5	44	1140	61054	77063	\N	52.681749386569898	с.Ангыр, Центральная, 35	Россия, Республика Бурятия	0101000020E61000005D6F9BA910355B40558A1D8D43574A40
25997	5	44	1362	15063	76720	\N	52.604292000000001	Хара-Хужир, Набережная, 8		0101000020E6100000D576137CD3ED5840029EB470594D4A40
25990	5	44	1362	14759	76917	\N	52.324745999999998	Сорок, Школьный переулок, 14		0101000020E6100000946C7539250B5940DFC0E44691294A40
25991	5	44	1362	14759	77022	\N	52.322560609486402	Сорок, Центральная, 6	Россия, Республика Бурятия, Окинский район, село Сорок	0101000020E61000000D39B69E210B594087FBC8AD49294A40
25998	5	44	1362	15118	76728	\N	52.6872046658263	Саяны, Лесная, 2	Россия, Республика Бурятия, Окинский район, село Саяны	0101000020E6100000DC9DB5DB2EEB5840E7525C55F6574A40
25989	5	44	1362	14689	\N	\N	52.102611000000003	"Самарта, административное здание рудника ""Холбинский"""		0101000020E61000006A8995D1C8485940DD9A745B220D4A40
25994	5	44	1362	14976	\N	\N	52.515436999999999	"Орлик, Комсомольская предприятие ""Коммунальник"", 26"		0101000020E6100000923CD7F7E1F45840FD12F1D6F9414A40
25995	5	44	1362	14976	76732	\N	52.515436999999999	здание детской библиотеки Окинский район, село Орлик, улица Школьная, 1а.	Россия, Республика Бурятия, Окинский район, село Орлик	0101000020E6100000923CD7F7E1F45840FD12F1D6F9414A40
25992	5	44	1362	14976	76732	\N	52.512400999999997	Поликлиника МУЗ «Окинская центральная районная больница» Окинский район, село Орлик, улица Школьная,10, детская консультация	Россия, Республика Бурятия, Окинский район, село Орлик	0101000020E6100000200C3CF71EF5584006B8205B96414A40
25993	5	44	1362	14976	76824	\N	52.515436999999999	Орлик, Советская, 29		0101000020E6100000923CD7F7E1F45840FD12F1D6F9414A40
25996	5	44	1362	14976	76819	\N	52.515436999999999	Орлик, Молодежная, 13		0101000020E6100000923CD7F7E1F45840FD12F1D6F9414A40
25958	5	44	1278	61031	77014	\N	51.341443143519101	у.Шинестуй, Октябрьская, 19Б	Россия, Республика Бурятия, Мухоршибирский район, село Шинестуй	0101000020E6100000D97BF1457B0F5B405C397B67B4AB4940
25988	5	44	1278	14648	71681	\N	51.026812	с.Шаралдай, И.Калашникова, 100		0101000020E610000008AA46AF06E95A40F7915B936E834940
14698	5	44	1278	60886	76624	\N	51.077927510759501	у.Цолга, Школьная, 5	Россия, Республика Бурятия, Мухоршибирский район, село Цолга	0101000020E61000000DC2DCEEE5CF5A40AAB8718BF9894940
25981	5	44	1278	14323	75721	\N	51.135255000000001	с.Хонхолой, Школьная, 4		0101000020E6100000F19C2D20B40E5B406CCF2C0950914940
25982	5	44	1278	14348	76731	\N	51.250264999999999	у.Харьястка, Арсаланова, 9	Россия, Республика Бурятия, Мухоршибирский район, село Харьястка	0101000020E610000089096AF816EA5A40AE2AFBAE08A04940
25980	5	44	1278	14280	76616	\N	51.095868000000003	с.Харашибирь, Ленина, 1А	Россия, Республика Бурятия, Мухоршибирский район, село Харашибирь	0101000020E61000002B14E97E4EFF5A40D15D1267458C4940
25979	5	44	1278	14213	76548	\N	51.214880999999998	с.Тугнуй, Комсомольская, 2Б		0101000020E6100000992CEE3F32075B4011C47938819B4940
25987	5	44	1278	61038	77027	\N	51.037741602357201	с.Куготы, Ленина, здание школы		0101000020E6100000EF1CCA5015E15A40C3D7D7BAD4844940
25977	5	44	1278	49423	76972	\N	51.219073000000002	п.Степной, Пионерская, здание клуба		0101000020E6100000AB5B3D27BD0D5B40E33785950A9C4940
25976	5	44	1278	14070	74716	\N	51.342374999999997	п.Саган-Нур, Молодежная, 10		0101000020E610000027874F3A911C5B40E7FBA9F1D2AB4940
25974	5	44	1278	13995	76644	\N	50.918590000000002	с.Подлопатки, Ленина, 50		0101000020E6100000FD32182312C65A4061376C5B94754940
25973	5	44	1278	13895	76547	\N	51.027797	с.Новый Заган, Солнечная, 1	Россия, Республика Бурятия, Мухоршибирский район, село Новый Заган	0101000020E6100000E8F692C668F05A40A5F622DA8E834940
25972	5	44	1278	13895	76686	\N	51.0337505632843	с.Новый Заган, Партизанская, 2	Россия, Республика Бурятия, Мухоршибирский район, село Новый Заган	0101000020E61000006D8C9DF012F15A40899AE8F351844940
25978	5	44	1278	49427	76823	\N	51.276060999999999	с.Новоспасск, Манзанова, здание клуба		0101000020E6100000CB4A9352D0075B40BC5983F755A34940
25971	5	44	1278	60757	75960	\N	51.190386814988003	с.Никольск, Ленина, 14а	Россия, Республика Бурятия, Мухоршибирский район, село Никольск	0101000020E61000002D7B12D89C145B40B24AE9995E984940
25970	5	44	1278	61039	77030	\N	51.264318455587997	у.Нарсата, Ленина, 38		0101000020E61000005FB4C70BE9F95A4040DF162CD5A14940
25968	5	44	1278	13613	71682	\N	51.046515999999997	с.Мухоршибирь, Доржиева, 32		0101000020E610000096404AECDAF45A40D05E7D3CF4854940
25967	5	44	1278	13613	71682	\N	51.046515999999997	с.Мухоршибирь, Доржиева, 26		0101000020E610000096404AECDAF45A40D05E7D3CF4854940
25966	5	44	1278	13613	74865	\N	51.046515999999997	с.Мухоршибирь, 30 лет Победы, 18		0101000020E610000096404AECDAF45A40D05E7D3CF4854940
25965	5	44	1278	60883	76617	\N	51.349021173080999	у.Кусоты, Ленина, 1а	Россия, Республика Бурятия, Мухоршибирский район, село Кусоты	0101000020E61000003DD7F7E120165B40014F5AB8ACAC4940
25963	5	44	1278	49230	76973	\N	51.285373999999997	с.Калиновка, Солнечная, 1		0101000020E61000000AF2B391EBF15A4079909E2287A44940
25986	5	44	1278	61020	77000	\N	51.070650000000001	у.Зандин, 50 лет Октября, 1	Россия, Республика Бурятия, Мухоршибирский район, село Зандин	0101000020E6100000E199D024B1DB5A4030BB270F0B894940
25984	5	44	1278	14439	76820	\N	51.038882000000001	с.Гашей, Гагарина, 10		0101000020E6100000F7729F1C05D85A409833DB15FA844940
25964	5	44	1278	13495	76909	\N	51.235126000000001	у.Галтай, Лодоева, 13	Россия, Республика Бурятия, Мухоршибирский район, село Галтай	0101000020E61000005859DB148FF25A403B38D89B189E4940
25969	5	44	1278	13764	76967	\N	51.312220000000003	с.Верхний Сутай, Заречная, 8		0101000020E6100000D53F8864C8F95A401D9430D3F6A74940
25962	5	44	1278	61022	77002	\N	51.2237737627363	у.Бом, Советская, 6	Россия, Республика Бурятия, Мухоршибирский район, село Бом	0101000020E61000004F5DF92CCF015B40F9D85DA0A49C4940
25961	5	44	1278	13363	76723	\N	51.297792999999999	с.Бар, Ленина, 78		0101000020E61000008FE4F21FD2E35A4026FDBD141EA64940
25985	5	44	1278	61029	77012	\N	51.073939001870997	у.Балта, Балтинская, 10		0101000020E6100000E5D4CE30B5C95A40117349D576894940
25960	5	44	1267	60900	\N	\N	56.411872628714598	"Республика Бурятия, муниципальный район ""Муйский район"", сельское поселение ""Муйская сельская администрация"""		0101000020E610000001BD70E7C2E75C407E8D2441B8344C40
25957	5	44	1267	32530	\N	\N	56.345294000000003	"Республика Бурятия, муниципальный район ""Муйский район"", городское поселение ""Поселок Таксимо"""	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	0101000020E61000003D29931ADAB75C40A5C00298322C4C40
25959	5	44	1267	60717	\N	\N	56.237437	"Республика Бурятия, муниципальный район ""Муйский район"", городское поселение ""Северомуйское"""		0101000020E610000018080264E8D25C4020EEEA55641E4C40
25586	5	44	1267	61058	77091	\N	56.223505019007199	"Республика Бурятия, муниципальный район ""Баунтовский эвенкийский район"", сельское поселение ""Витимское"", ул.Первомайская, д.2"	Россия, Республика Бурятия, Муйский район, село Витим	0101000020E6100000E3C4573B8AEE5C400ABFD4CF9B1C4C40
25926	5	44	1152	61003	76975	\N	50.218854999999998	улус Энхэ-Тала, ул. Школьная, школа		0101000020E610000074ED0BE885CA5A4075C8CD70031C4940
25921	5	44	1152	11502	76906	\N	50.017705999999997	с. Шарагол, ул. Октябрьская, д. 20		0101000020E61000004B3E761728D65A40B378B13044024940
25916	5	44	1152	11242	76907	\N	50.26887	с. Шазагай, ул. Степанова, клуб		0101000020E6100000B70BCD751AD55A40117008556A224940
25936	5	44	1152	12217	76608	\N	50.271754000000001	с. Чикой, ул. Нагорная, д. 1		0101000020E61000009607E92972BA5A405247C7D5C8224940
25922	5	44	1152	61021	77001	\N	50.022260000000003	с. Хутор, ул. Советская, д. 23	Россия, Республика Бурятия, Кяхтинский район, село Хутор	0101000020E6100000228C9FC6BDD45A4026016A6AD9024940
25943	5	44	1152	12561	75857	\N	50.477722999999997	с. Хоронхой, ул. Школьная, д. 1		0101000020E6100000DD274701A2895A4004C6FA06263D4940
25925	5	44	1152	61008	77032	\N	50.221263409857301	улус Холой, ул. Клубная, ФП		0101000020E61000001DE6CB0BB0C75A404D689258521C4940
25935	5	44	1152	60960	76838	\N	50.4346111542445	улус Хилгантуй, ул. Молодежная, школа	Россия, Республика Бурятия, Кяхтинский район, село Хилгантуй	0101000020E61000005C3B511212B85A40ADBD4F55A1374940
25938	5	44	1152	61061	77104	\N	50.7223547730813	улус Харьясты, ул. Набережная, д. 7	Россия, Республика Бурятия, Кяхтинский район, село Харьяста	0101000020E6100000484F9143C4A85A40118DEE20765C4940
25913	5	44	1152	11136	76804	\N	50.178052999999998	с. Хамнигадай, ул. Лесная, д. 31		0101000020E610000004AE2B6684DB5A4033FAD170CA164940
25942	5	44	1152	12515	74861	\N	50.522305000000003	с. Усть-Кяхта, ул. Школьная, д. 8		0101000020E6100000D175E107E7915A40C6C4E6E3DA424940
25929	5	44	1152	11886	76652	\N	50.413832121151202	с. Усть-Киран, пл. Победы, д. 7	Россия, Республика Бурятия, Кяхтинский район, село Усть-Киран	0101000020E61000009B5434D6FEB35A40E6046D72F8344940
25906	5	44	1152	60881	76613	\N	49.991009628519301	улус Усть-Дунгуй, ул. Центральная, д. 42	Россия, Республика Бурятия, Кяхтинский район, село Усть-Дунгуй	0101000020E6100000D237691A14EB5A4026016A6AD9FE4840
25927	5	44	1152	11808	76816	\N	50.304662999999998	с. Унгуркуй, ул. Школьная, д. 39		0101000020E61000003106D671FCC95A408FA67A32FF264940
25908	5	44	1152	10896	76795	\N	50.174256999999997	с. Уладый, ул. Набережная, д. 1		0101000020E610000065FF3C0D18E95A40AE0CAA0D4E164940
25918	5	44	1152	11343	76718	\N	50.278149999999997	с. Убур-Киреть, ул. Партизанская, школа		0101000020E61000004FC939B187CF5A40F2B0506B9A234940
25915	5	44	1152	11213	76874	\N	50.256875000000001	с. Тамир, ул. Школьная, д. 1 А		0101000020E6100000A9A0A2EA57D95A407B14AE47E1204940
25941	5	44	1152	61012	77004	\N	50.561943401462699	улус Субуктуй, ул. Школьная, д. 8 А		0101000020E6100000B6BA9C12109B5A40AA9B8BBFED474940
25914	5	44	1152	48420	76825	\N	50.1569	с. Семеновка, ул. Дорожная, д. 31		0101000020E6100000E3E0D231E7D55A40075F984C15144940
25928	5	44	1152	11821	76971	\N	50.309047	с. Полканово, ул. Кооперативная, д. 7		0101000020E6100000DD7C23BA67C25A40A5F622DA8E274940
25910	5	44	1152	48354	76956	\N	50.116235000000003	с. Первомайское, ул. Рабочая, д. 8		0101000020E6100000F949B54FC7DC5A4046D3D9C9E00E4940
25924	5	44	1152	48588	76725	\N	50.220134000000002	с. Октябрьский, ул. Дорожная, здание администрации		0101000020E61000000DA837A3E6C45A406C5ED5592D1C4940
25939	5	44	1152	12393	76940	\N	50.787177	с. Новодесятниково, ул. Баннова, д. 15		0101000020E6100000984C158C4AAD5A40EA944737C2644940
25945	5	44	1152	12616	71667	\N	50.395283999999997	пос. Наушки, ул. Железнодорожная, д. 4		0101000020E61000008EAF3DB324875A40E75086AA98324940
25944	5	44	1152	12616	71667	\N	50.395283999999997	пос. Наушки, ул. Железнодорожная, 2		0101000020E61000008EAF3DB324875A40E75086AA98324940
25934	5	44	1152	61041	77033	\N	50.277132122193599	улус Мурочи, ул. Школьная, д. 24		0101000020E6100000CCB392567CBE5A406956B60F79234940
25907	5	44	1152	10854	76965	\N	50.188822000000002	с. Малая Кудара, ул. Школьная, д. 3		0101000020E6100000384BC97212EC5A40F661BD512B184940
25953	5	44	1152	60812	\N	\N	50.350461000000003	"г. Кяхта, пос. Майский, кафе ""Чайная"""		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25950	5	44	1152	60525	75863	\N	50.350461000000003	г. Кяхта, ул. Юбилейная, д. 1а		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25946	5	44	1152	60525	75860	\N	50.350461000000003	г. Кяхта, ул. Советская, д. 5		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25948	5	44	1152	60525	75171	\N	50.350461000000003	г. Кяхта, ул. Крупской, 42, Центральная межпоселенческая библиотека.		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25952	5	44	1152	12692	75867	\N	50.350461000000003	г. Кяхта, ул. Сухэ-Батора, д. 1		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25949	5	44	1152	12692	71672	\N	50.350461000000003	г. Кяхта, ул. Пограничная, д. 69		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25951	5	44	1152	12692	71675	\N	50.350461000000003	г. Кяхта, ул. Горнозелентуйская, д. 14		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25954	5	44	1152	12692	71677	\N	50.350461000000003	г. Кяхта, ул. Гармаева, д. 53		0101000020E61000009BE61DA7E89C5A4001C3F2E7DB2C4940
25931	5	44	1152	60950	76817	\N	50.327665000000003	с.п. Курорт Киран, ул. Озерная, клуб	Россия, Республика Бурятия, Кяхтинский район, село Курорт Киран	0101000020E610000062D9CC21A9B65A409D853DEDF0294940
25912	5	44	1152	11057	75715	\N	50.159381000000003	с. Кудара-Сомон, ул. Ломоносова, д. 52		0101000020E610000030D5CC5A0AD95A40494DBB9866144940
25933	5	44	1152	12061	76822	\N	50.342940543166002	с. Киран, ул. Заречная, д. 17	Россия, Республика Бурятия, Кяхтинский район, село Киран	0101000020E61000003881E9B46EAD5A4091BA9D7DE52B4940
25940	5	44	1152	12403	76730	\N	50.652940999999998	с. Калинишна, ул. Трактовая, д. 17 кв. 1		0101000020E610000079944A78429F5A40D89B189293534940
25917	5	44	1152	60925	76789	\N	50.183827000000001	с. Ивановка, ул. Луговая, клуб	Россия, Республика Бурятия, Кяхтинский район, село Ивановка	0101000020E6100000E71DA7E848CF5A40978FA4A487174940
25932	5	44	1152	12050	76815	\N	50.318705000000001	с. Дурены, ул. Школьная, д. 17		0101000020E61000008ECA4DD4D2B85A402D095053CB284940
25909	5	44	1152	10952	76905	\N	50.150303000000001	с. Дунгуй, ул. Жарникова, д. 28		0101000020E6100000E88711C2A3E35A40CFBEF2203D134940
25930	5	44	1152	60991	76914	\N	50.403645734892599	улус Бурдуны, ул. Центральная, клуб	Россия, Республика Бурятия, Кяхтинский район, село Бурдуны	0101000020E6100000F1A0D9756FA85A40A39410ACAA334940
25937	5	44	1152	33064	76663	\N	50.610540999999998	улус Большой Луг, ул. Цыбиктарова, д. 47		0101000020E6100000FE98D6A6B1B15A40FEEE1D35264E4940
25923	5	44	1152	11591	76642	\N	50.202159999999999	с. Большая Кудара, ул. Евдокимова, школа		0101000020E61000008352B4722FC35A409947FE60E0194940
25911	5	44	1152	11038	76900	\N	50.133375999999998	с. Ара-Алцагат, ул. Школьная, д. 27		0101000020E61000004F081D7409DC5A402009FB7612114940
25919	5	44	1152	11425	76911	\N	49.986932000000003	с. Анагустай, ул. Заринская, д. 16		0101000020E610000098309A95EDE45A401DB0ABC953FE4840
26098	5	44	1111	60857	76475	\N	54.051949177706497	Республика Бурятия, Селенгинский район, Нижне-Убукунский сельсовет, улус Харгана, Ленина, 12	Россия, Республика Бурятия, Курумканский район	0101000020E610000050DF32A7CB915B40AB07CC43A6064B40
25903	5	44	1111	60951	76818	\N	54.033060785010001	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Элэсун"", Ленина, 61"	Россия, Республика Бурятия, Курумканский район, село Элэсун	0101000020E61000009A6038D730865B40F3E2C4573B044B40
25900	5	44	1111	10514	76811	\N	54.467401000000002	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Сахули"", село Шаманка, Рабочая, 42"		0101000020E61000004B5AF10D859E5B40118FC4CBD33B4B40
25897	5	44	1111	10394	76964	\N	54.232975000000003	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Барагхан"", село Хонхино, бр.Данжуровых, 26В"		0101000020E6100000936FB6B9318E5B408FE4F21FD21D4B40
25902	5	44	1111	60890	76643	\N	54.861818999999997	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Улюнхан эвенкийское"", Ленина, 10"	Россия, Республика Бурятия, Курумканский район, село Улюнхан	0101000020E6100000F3E8465854C45B402409C215506E4B40
25901	5	44	1111	60992	76919	\N	54.422473346231598	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Сахули"", Набережная, 10"	Россия, Республика Бурятия, Курумканский район, село Сахули	0101000020E6100000315D88D51F9A5B40B438639813364B40
25890	5	44	1111	32779	76612	\N	54.382534999999997	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Могойто"", Трактовая, 2"		0101000020E6100000F913950D6B9D5B40A54929E8F6304B40
25899	5	44	1111	32846	76575	\N	54.594011000000002	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Майск"", Ленина, 7"		0101000020E6100000E95F92CA14B35B406D3B6D8D084C4B40
25895	5	44	1111	60287	76991	\N	54.331354946122097	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Курумкан"", заимка Ехэ-Нуга"	Россия, Республика Бурятия, Курумканский район, село Курумкан	0101000020E61000003E5B07077B935B40DC2E34D7692A4B40
25893	5	44	1111	60287	76721	\N	54.327166182000099	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Курумкан"", Набережная, 13"	Россия, Республика Бурятия, Курумканский район, село Курумкан	0101000020E61000003C17467A51945B407B2E5393E0294B40
25894	5	44	1111	60287	74295	\N	54.326664504865299	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Курумкан"", Балдакова, 45А"	Россия, Республика Бурятия, Курумканский район, село Курумкан	0101000020E6100000EB1ED95C35945B40B9DFA128D0294B40
25891	5	44	1111	60287	74295	\N	54.328366948692697	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Курумкан"", Балдакова, 13"	Россия, Республика Бурятия, Курумканский район, село Курумкан	0101000020E610000063D1747632945B40F60A0BEE072A4B40
25622	5	44	1820	28819	76687	\N	50.702638999999998	село Узкий Луг, Ленина, 52		0101000020E610000041800C1D3B015B4073F22213F0594940
25892	5	44	1111	60875	76585	\N	54.740895999999999	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Курумкан"", Ленина, 42а"		0101000020E6100000419FC893A4BE5B405DDE1CAED55E4B40
25896	5	44	1111	60885	76621	\N	54.1551029482711	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Барагхан"", Ленина, 29"	Россия, Республика Бурятия, Курумканский район, село Барагхан (Саранхур)	0101000020E61000002AFD84B35B8A5B407841446ADA134B40
25904	5	44	1111	60889	76641	\N	54.374747277770297	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Арзгун"", Комсомольская, 5"		0101000020E6100000CB80B3942CAF5B4016A3AEB5F72F4B40
25889	5	44	1111	60288	\N	\N	54.2392042376256	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Аргада"", Здание библиотеки"	Россия, Республика Бурятия, Курумканский район, село Аргада	0101000020E6100000B9C667B27FAB5B404489963C9E1E4B40
25905	5	44	1111	60288	74303	\N	54.243149958328601	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Аргада"", Хышиктуева, 14"	Россия, Республика Бурятия, Курумканский район, село Аргада	0101000020E61000009E42AED4B3AB5B40DE02098A1F1F4B40
25888	5	44	1111	60288	76770	\N	54.239631279417402	"Республика Бурятия, муниципальный район ""Курумканский район"", сельское поселение ""Аргада"", Верхняя Аргада, 1"	Россия, Республика Бурятия, Курумканский район, село Аргада	0101000020E6100000501A6A1492AB5B40CC0D863AAC1E4B40
25898	5	44	1111	10418	76632	\N	54.689050000000002	Республика Бурятия, муниципальный район Курумканский район, сельское поселение Дырен эвенкийское,Дыренская СОШ, с.  Алла, ул. Ленина, 49	Россия, Республика Бурятия, Курумканский район, село Алла	0101000020E6100000A9143B1A87B45B4087A757CA32584B40
25879	5	44	1022	60896	76673	\N	51.774095000000003	улус Могсохон, ул. Советская, д. 28		0101000020E6100000D32EA699EE9B5B40A27F828B15E34940
25868	5	44	1022	61024	77005	\N	51.689153985567799	улус Эдэрмэг, ул. Школьная, д. 6	Россия, Республика Бурятия, Кижингинский район, село Эдэрмэг	0101000020E610000013D38558FD695B402CF4C13236D84940
25881	5	44	1022	61007	76984	\N	51.960782000000002	улус Чесан, ул. Центральная,б/н	Россия, Республика Бурятия, Кижингинский район, село Чесан	0101000020E61000004580D3BB78A05B40F14A92E7FAFA4940
25884	5	44	1022	9715	76611	\N	51.945259999999998	село Хуртэй, ул. Клубная, д. 15		0101000020E6100000334E4354E1B45B40C51B9947FEF84940
25870	5	44	1022	61026	77008	\N	51.818422434558499	улус Ушхайта, ул. Центральная, д. 30	Россия, Республика Бурятия, Кижингинский район, село Ушхайта	0101000020E61000000BB6114F76765B40D829560DC2E84940
25874	5	44	1022	61042	77036	\N	51.978425470957198	улус Усть-Орот, ул. Центральная, д. 27	Россия, Республика Бурятия, Кижингинский район, село Усть-Орот	0101000020E6100000CF68AB92C8715B405E4BC8073DFD4940
25873	5	44	1022	61042	77050	\N	51.982807758497302	улус Орот, ул. Центральная, д. 25	Россия, Республика Бурятия, Кижингинский район, село Усть-Орот	0101000020E610000010C99063EB715B40A31F0DA7CCFD4940
25878	5	44	1022	61044	77043	\N	51.916992116923097	улус Улзыто, ул. Советская, д. 20	Россия, Республика Бурятия, Кижингинский район, село Улзытэ	0101000020E61000006F826F9A3E885B40C9586DFE5FF54940
25876	5	44	1022	9339	76814	\N	51.750093	с. Сулхара, ул. Профсоюзная,22		0101000020E61000005437177FDB8A5B40B1FA230C03E04940
25867	5	44	1022	8908	75710	\N	51.618322999999997	с. Новокижингинск, ул. Строитетелей, д. 1		0101000020E610000029CC7B9C69665B40ABAE433525CF4940
25866	5	44	1022	8908	76901	\N	51.618322999999997	"с. Новокижингинск, ул. Мира, д. 58  ""а"""		0101000020E610000029CC7B9C69665B40ABAE433525CF4940
25880	5	44	1022	47765	76712	\N	51.893878000000001	село Михайловка, ул. Школьная, д. 34		0101000020E6100000D82C978DCE9D5B40944E24986AF24940
25869	5	44	1022	9026	76963	\N	51.748553999999999	с. Леоновка, ул. Школьная, д. 2		0101000020E6100000DFDFA0BDFA6E5B401EA5129ED0DF4940
25887	5	44	1022	61017	76996	\N	51.563445599608301	улус Куорка, ул. Номтоева, д. 4	Россия, Республика Бурятия, Кижингинский район, село Куорка	0101000020E6100000E00F3FFF3D5D5B40F0879FFF1EC84940
25885	5	44	1022	60911	76717	\N	52.048541999999998	улус Кулькисон, ул. Раднаева, д. 50	Россия, Республика Бурятия, Кижингинский район, село Кулькисон	0101000020E610000065C5707500C15B40C03DCF9F36064A40
25803	5	44	1022	60906	76704	\N	51.920365445844197	с. Красный Яр, ул. Школьная, д. 2	Россия, Республика Бурятия, Кижингинский район, село Красный Яр	0101000020E6100000C8D11C59F9795B4007B13385CEF54940
25875	5	44	1022	61023	77003	\N	52.044126332496901	улус Кодунский станок, ул. Центральная, д. 21	Россия, Республика Бурятия, Кижингинский район, село Кодунский Станок (Худанский Станок)	0101000020E61000004CFDBCA948705B409F73B7EBA5054A40
25871	5	44	1022	9123	71646	\N	51.839461	с. Кижинга, проспект Ленина, 4,		0101000020E610000099BA2BBB607A5B403CA2427573EB4940
25886	5	44	1022	9123	71651	\N	51.839461	с. Кижинга, ул. Советская, д. 149	Россия, Республика Бурятия, Кижингинский район, село Кижинга	0101000020E610000099BA2BBB607A5B403CA2427573EB4940
25872	5	44	1022	9123	71651	\N	51.839461	с. Кижинга, ул. Советская, д. 159		0101000020E610000099BA2BBB607A5B403CA2427573EB4940
25877	5	44	1022	9366	76942	\N	51.919276000000004	село Иннокентьевка, ул. Центральная, д. 6		0101000020E610000074266DAAEE815B40B5FF01D6AAF54940
25883	5	44	1022	60884	76618	\N	51.978012999999997	улус Загустай, ул. Дарижапова, д. 41	Россия, Республика Бурятия, Кижингинский район, село Загустай	0101000020E61000007D224F92AEAE5B400B08AD872FFD4940
25882	5	44	1022	61025	77007	\N	51.969329715762697	улус Булак, ул. Центральная, д. 21	Россия, Республика Бурятия, Кижингинский район, село Булак	0101000020E61000001DAED51EF6A35B400E84640113FC4940
25858	5	44	1022	61036	77024	\N	51.7880633724156	улус Бахлайта, ул. Рабочая, д. 8	Россия, Республика Бурятия, Кижингинский район, село Бахлайта	0101000020E61000002EE23B31EB815B400518963FDFE44940
25834	5	44	718	7376	76710	\N	52.183160000000001	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Твороговское"", село ""Шигаево"", Советская, 43 А"		0101000020E6100000A0C6BDF90D9E5A40BAF770C971174A40
25804	5	44	718	5888	76893	\N	52.111460999999998	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Шергинское"", село ""Шергино"", Почтовая, 2"		0101000020E6100000AB06616EF7AE5A40C5E3A25A440E4A40
25794	5	44	718	5355	\N	\N	52.260641999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Байкало-Кударинское"", село ""Шерашово"", 34-2"		0101000020E61000002448A5D8D1AC5A4065FB90B75C214A40
25805	5	44	718	5952	76714	\N	52.115764734442699	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Шергинское"", село ""Хандала"", Братьев Мункоевых, 3"		0101000020E6100000F31C91EF52AD5A40BF823463D10E4A40
25806	5	44	718	6006	76895	\N	52.055703000000001	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Шергинское"", село ""Фофоново"", Школьная, 18"		0101000020E6100000DFA7AAD040B05A4001A5A14621074A40
25809	5	44	718	6154	75698	\N	52.053854000000001	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Брянское"", село ""Тресково"", Шашина, 51"		0101000020E610000096E99788B7B95A40206118B0E4064A40
25843	5	44	718	7801	76537	\N	51.977957000000004	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Каменское"", село ""Тимлюй"", Советская, 36"		0101000020E61000001B7FA2B261A45A4078F2E9B12DFD4940
25833	5	44	718	7359	76682	\N	52.167729000000001	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Твороговское"", село ""Творогово"", Школьная, 17 А"		0101000020E6100000CC99ED0A7D9F5A409FCBD42478154A40
25808	5	44	718	6082	76959	\N	52.073475999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Брянское"", село ""Таракановка"", Терешковой, 12"		0101000020E6100000802DAF5C6FBD5A403C855CA967094A40
25862	5	44	718	8657	76702	\N	51.554577999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Танхойское"", поселок ""Танхой"", Центральная, 13"		0101000020E6100000581F0F7D77475A40618A7269FCC64940
25861	5	44	718	8657	76702	\N	51.554577999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Танхойское"", поселок ""Танхой"", Центральная, 55 А"		0101000020E6100000581F0F7D77475A40618A7269FCC64940
25788	5	44	718	5026	76833	\N	52.545020999999998	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Сухинское"", село Сухая, Школьная, 6"		0101000020E6100000FCC6D79E59C75A400D51853FC3454A40
25837	5	44	718	7549	76809	\N	52.172274999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Ранжуровское"", село ""Степной Дворец"", Трактовая, 23"		0101000020E6100000BEA4315A47995A408E75711B0D164A40
25819	5	44	718	6266	\N	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", мкр.Солнечный, 48"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25817	5	44	718	6266	\N	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", мкр. Березовый, 56"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25816	5	44	718	6266	\N	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", мкр. Южный, 51"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25815	5	44	718	6266	\N	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", мкр. Южный, 40"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25818	5	44	718	6266	76161	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", мкр. Солнечный, 42"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25814	5	44	718	6266	76158	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", мкр. Березовый, 55"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25812	5	44	718	6266	76158	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", мкр. Березовый, 58"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25811	5	44	718	6266	76922	\N	52.008602000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Селенгинское"", поселок ""Селенгинск"", Мостовая, 24"		0101000020E6100000897AC1A739B75A401157CEDE19014A40
25801	5	44	718	5756	76810	\N	52.11056	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Красноярское"", село ""Романово"", Братьев Голубевых, 54 А"		0101000020E6100000882EA86F99AA5A40751F80D4260E4A40
25836	5	44	718	7475	76757	\N	52.175077881578503	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Ранжуровское"", село ""Ранжурово"", Трактовая, 17 В"	Россия, Республика Бурятия, Кабанский район, село Ранжурово	0101000020E6100000FB58C16F439B5A40E21FB6F468164A40
25785	5	44	577	4900	76889	\N	51.518881	село Ганзурино, Набережная, 77, здание СОШ		0101000020E61000002A00C63368CF5A4005C24EB16AC24940
25608	5	44	1820	28174	76777	\N	50.468384	село Топка, Смородникова, 1		0101000020E6100000B9C3263273C55A401EFCC401F43B4940
25850	5	44	718	8152	76640	\N	52.019919936934102	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Посольское"", село ""Посольское"", Набережная, 53"	Россия, Республика Бурятия, Кабанский район, село Посольское	0101000020E6100000635E471CB28B5A40A64412BD8C024A40
25847	5	44	718	7997	76666	\N	51.968330999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Большереченское"", станция ""Посольская"", Центральная, 11"		0101000020E61000008CA19C6857965A40FB592C45F2FB4940
25860	5	44	718	8639	76962	\N	51.578999000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Танхойское"", станция ""Переемная"", Табельная"		0101000020E61000004208C89750505A4057B5A4A31CCA4940
25791	5	44	718	5201	76957	\N	52.331747	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Оймурское"", село ""Оймур"", Рабочая, 35 А"		0101000020E61000007F33315D88B55A40E7C589AF762A4A40
25792	5	44	718	5201	76639	\N	52.331747	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Оймурское"", село ""Оймур"", Октябрьская, 4 А"		0101000020E61000007F33315D88B55A40E7C589AF762A4A40
25821	5	44	718	6779	76709	\N	52.027042000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Нюки"", Трактовая, 8 А"		0101000020E61000006684B70721AD5A4029CFBC1C76034A40
25789	5	44	718	60945	76806	\N	52.489457999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Сухинское"", село ""Энхалук"", Лесная, 8"	Россия, Республика Бурятия, Кабанский район, село Новый Энхэлук	0101000020E6100000889CBE9EAFBE5A40FE614B8FA63E4A40
25807	5	44	718	6062	76899	\N	52.070248999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Шергинское"", село ""Никольск"", Школьная, 17"		0101000020E61000001893FE5E0AB85A40D1C952EBFD084A40
25859	5	44	718	8566	76812	\N	51.651918999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Танхойское"", станция ""Мишиха"", Табельная"		0101000020E6100000376DC66988655A400D52F01472D34940
25853	5	44	718	8299	76960	\N	51.777250000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Бабушкинское"", поселок ""Мантуриха"", Железнодорожная, 3"		0101000020E6100000272F3201BF7E5A40736891ED7CE34940
25832	5	44	718	7301	76936	\N	52.127139	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Колесовское"", село ""Малое Колесово"", Тупышева, 10 А"		0101000020E6100000583849F3C7A25A40E8853B1746104A40
25796	5	44	718	60894	76665	\N	52.227228176765102	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Байкало-Кударинское"", село ""Байкало-Кудара"", Нелюбина, 2 А"	Россия, Республика Бурятия, Кабанский район, село Кудара	0101000020E61000008731E9EFA5A95A40245E9ECE151D4A40
25795	5	44	718	60894	76928	\N	52.231627648826901	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Байкало-Кударинское"", село ""Байкало-Кудара"", Куйбышева, 1"	Россия, Республика Бурятия, Кабанский район, село Кудара	0101000020E6100000371AC05B20AA5A40406B7EFCA51D4A40
25797	5	44	718	60894	76939	\N	52.229993999999998	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Байкало-Кударинское"", село ""Байкало-Кудара"", Боброва, 2"	Россия, Республика Бурятия, Кабанский район, село Кудара	0101000020E6100000E55FCB2BD7A95A405B238271701D4A40
25799	5	44	718	5642	76872	\N	52.179476999999999	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Красноярское"", село ""Красный Яр"", Карачовых, 58"		0101000020E6100000F0181EFB59A55A402DB1321AF9164A40
25798	5	44	718	5569	\N	\N	52.253117000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Корсаковское"", село ""Корсаково"", Школьная, 1"	Россия, Республика Бурятия, Кабанский район, село Корсаково	0101000020E6100000268A90BA9DA75A40E4874A2366204A40
25857	5	44	718	8488	76638	\N	51.687919000000001	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Клюевское"", село ""Клюевка"", Парижской Коммуны, 17"		0101000020E6100000B34291EEE7705A4005A6D3BA0DD84940
25830	5	44	718	7189	76896	\N	52.084684000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Колесовское"", село ""Каргино"", Трактовая, 21"		0101000020E6100000043A933655A65A404B3FE1ECD60A4A40
25842	5	44	718	7618	\N	\N	51.990920000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Каменское"", поселок ""Каменск"", мкр. Молодежный, 18"		0101000020E6100000EC8497E0D4A55A40E6797077D6FE4940
25841	5	44	718	7618	74839	\N	51.990920000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Каменское"", поселок ""Каменск"", Луговая, 2"		0101000020E6100000EC8497E0D4A55A40E6797077D6FE4940
25840	5	44	718	7618	75709	\N	51.990920000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Каменское"", поселок ""Каменск"", Комсомольская, 17"		0101000020E6100000EC8497E0D4A55A40E6797077D6FE4940
25839	5	44	718	60736	75853	\N	51.990920000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Каменское"", поселок ""Каменск"", Прибайкальская, 3 Б"		0101000020E6100000EC8497E0D4A55A40E6797077D6FE4940
25723	5	44	24	1411	76635	\N	52.031297000000002	с.Первомаевка, Школьная, 10 (школа)		0101000020E6100000315C1D0071195B4041BB438A01044A40
25829	5	44	718	6895	\N	\N	52.055304999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Кабанск"", Бабушкина, 4 А"	Россия, Республика Бурятия, Кабанский район, село Кабанск	0101000020E61000006F490ED8D5A95A401327F73B14074A40
25828	5	44	718	6895	76539	\N	52.055304999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Кабанск"", пер.Октябрьский, 83 А"		0101000020E61000006F490ED8D5A95A401327F73B14074A40
25824	5	44	718	6895	76567	\N	52.055304999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Кабанск"", Совхозная, 1"		0101000020E61000006F490ED8D5A95A401327F73B14074A40
25825	5	44	718	6895	76679	\N	52.055304999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Кабанск"", Маяковского, 1"		0101000020E61000006F490ED8D5A95A401327F73B14074A40
25827	5	44	718	6895	71633	\N	52.055304999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Кабанск"", 8 марта, 1"		0101000020E61000006F490ED8D5A95A401327F73B14074A40
25826	5	44	718	6895	75706	\N	52.055304999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Кабанск"", 1 мая, 52"		0101000020E61000006F490ED8D5A95A401327F73B14074A40
25838	5	44	718	7576	76903	\N	52.132966000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Ранжуровское"", село ""Истомино"", Лесная, 12 А"		0101000020E610000082734694F6925A406FBDA60705114A40
25851	5	44	718	8174	76711	\N	52.098976999999998	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Посольское"", село ""Исток"", Трактовая, 30"		0101000020E6100000904DF2237E905A4031074147AB0C4A40
25787	5	44	718	5002	76875	\N	52.549802	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Сухинское"", село ""Заречье"", Речная, 19"		0101000020E6100000EFC9C342ADC95A4040A374E95F464A40
25823	5	44	718	6867	76876	\N	52.018552	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Закалтус"", Клубная, 1 А"		0101000020E6100000EACF7EA488A55A4040A374E95F024A40
25800	5	44	718	5669	76932	\N	52.145369000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Красноярское"", село ""Жилино"", Коневой Н.Е, 33 А"		0101000020E6100000B743C362D4A65A40166D8E739B124A40
25822	5	44	718	6811	76894	\N	52.002991000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село ""Елань"", Клубная, 2 А"		0101000020E6100000E960FD9FC3AB5A405797530262004A40
25790	5	44	718	60948	76813	\N	52.374559265332202	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Сухинское"", улус ""Дулан"", Центральная, 17 А"	Россия, Республика Бурятия, Кабанский район, село Дулан	0101000020E6100000E7FD7F9C30B85A4013B69F8CF12F4A40
25793	5	44	718	5312	76968	\N	52.302961000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Оймурское"", село ""Дубинино"", Подгорная, 3 Б"		0101000020E6100000D4484BE5EDB05A40537B116DC7264A40
25845	5	44	718	7893	\N	\N	51.973353000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Каменское"", поселок ""Горный"", ФАП №11"		0101000020E6100000AF5E4546079A5A40543BC3D496FC4940
25865	5	44	718	8812	75711	\N	51.460602000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Выдринское"", село ""Выдрино"", Школьная, 4 А"		0101000020E6100000C614AC7136295A40713C9F01F5BA4940
25864	5	44	718	8812	71639	\N	51.460602000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Выдринское"", село ""Выдрино"", Октябрьская, 1"		0101000020E6100000C614AC7136295A40713C9F01F5BA4940
25863	5	44	718	8812	76541	\N	51.460602000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Выдринское"", станция ""Выдрино"", Красных Партизан, Сельский клуб"	Россия, Республика Бурятия, Кабанский район, село Выдрино	0101000020E6100000C614AC7136295A40713C9F01F5BA4940
25802	5	44	718	5769	76966	\N	52.160868000000001	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Шергинское"", село ""Быково"", Трактовая, 94"		0101000020E61000007E3672DD94AD5A40897C975297144A40
25810	5	44	718	6215	76681	\N	52.032333000000001	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Брянское"", село ""Брянск"", Истомина, 94"		0101000020E6100000029B73F04CB75A4071CADC7C23044A40
25852	5	44	718	8256	\N	\N	51.848869444920297	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Бабушкинское"", станция ""Боярский"", ЖД вокзал"	Россия, Республика Бурятия, Кабанский район, село Боярский	0101000020E610000088484DBB98845A404BCB48BDA7EC4940
25835	5	44	718	7452	76715	\N	52.153995000000002	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Твороговское"", поселок ""Борки"", Молодежная, 36"		0101000020E6100000A8397991099E5A40AF5FB01BB6134A40
25831	5	44	718	7274	76540	\N	52.107788999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Колесовское"", село ""Большое Колесово"", Ленина, 41 Г"		0101000020E61000002975C93846A35A402CEFAA07CC0D4A40
25623	5	44	1820	60888	76634	\N	50.796452000000002	улус Шибертуй, Елаева, 1	Россия, Республика Бурятия, Бичурский район, село Шибертуй	0101000020E610000080492A53CCF75A40BA6A9E23F2654940
25846	5	44	718	7909	76713	\N	51.972358999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Большереченское"", село ""Большая Речка"", Вагжанова, 102"		0101000020E6100000E811A3E716945A40527C7C4276FC4940
25820	5	44	718	6721	76707	\N	52.025291000000003	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Кабанское"", село Береговая, Селенгинская, 1 А"		0101000020E6100000F81A82E332AF5A400BF148BC3C034A40
25849	5	44	718	60982	76884	\N	51.936892857450196	"Республика Бурятия, муниципальный район ""Кабанский район"", сельское поселение ""Большереченское"", о/п ""Байкальский Прибой"", Вокзальная, ЖД магазин"	Россия, Республика Бурятия, Кабанский район, село Байкальский Прибой	0101000020E6100000FED2A23EC98C5A40F86C1D1CECF74940
25855	5	44	718	8338	74858	\N	51.717333958151997	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Бабушкинское"", город ""Бабушкин"", Комсомольская, 19"		0101000020E6100000B22D03CE52775A408927BB99D1DB4940
25856	5	44	718	8338	74911	\N	51.712328999999997	"Республика Бурятия, муниципальный район ""Кабанский район"", городское поселение ""Бабушкинское"", город ""Бабушкин"", 3 Интернационала, 35"		0101000020E61000009ECE15A584775A40067FBF982DDB4940
25782	5	44	577	60880	76610	\N	51.630887000000001	улус Хурамша, Ленина, 27, здание СДК	Россия, Республика Бурятия, Иволгинский район, село Хурамша	0101000020E6100000DA9255116EBF5A405C3CBCE7C0D04940
25772	5	44	577	60899	76689	\N	51.792317778541502	с.Хойто-Бэе, переулок Иркутский, 8 б, здание сельского клуба	Россия, Республика Бурятия, Иволгинский район, село Хойтобэе	0101000020E610000081B053AC1ADC5A401D041DAD6AE54940
25731	5	44	577	4821	\N	\N	51.517777000000002	улус Шулута, нет, сельская школа	Россия, Республика Бурятия, Иволгинский район, село Улус Оронгой	0101000020E6100000F9D9C87553C45A407DCF488446C24940
25920	5	44	577	4821	76719	\N	51.517777000000002	улус Цаган-Челутай, ул. Ранжурова, школа		0101000020E6100000F9D9C87553C45A407DCF488446C24940
25784	5	44	577	4821	75695	\N	51.517777000000002	улус Оронгой, Абидуева, 56 а, здание ОСШ		0101000020E6100000F9D9C87553C45A407DCF488446C24940
25773	5	44	577	4238	\N	\N	51.731895000000002	пос.Тапхар, 22, здание СДК		0101000020E61000008CBCAC8905D85A408F8D40BCAEDD4940
25770	5	44	577	4063	71581	\N	51.776090000000003	с.Сужа, Советская, 23, здание ОСШ		0101000020E6100000A1F48590F3DD5A405760C8EA56E34940
25767	5	44	577	45473	74807	\N	51.886512910390302	с.Сотниково, Трактовая, дом 18, здание средней школы	Россия, Республика Бурятия, Иволгинский район, село Сотниково	0101000020E6100000DB334B02D4DE5A404B3D0B4279F14940
25766	5	44	577	45473	74798	\N	51.885078849126799	с.Сотниково, Партизанская, 27, здание сельского Дома культуры	Россия, Республика Бурятия, Иволгинский район, село Сотниково	0101000020E6100000DACBB6D3D6DE5A402DB0C7444AF14940
26118	5	44	577	21262	76670	\N	51.614236965395698	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Шалутское"", с.Солонцы, Бабушкина, 38"	Россия, Республика Бурятия, Иволгинский район, село Солонцы	0101000020E6100000BB80971936D95A40207F69519FCE4940
26121	5	44	577	52463	76834	\N	51.651774000000003	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Шалутское"", с.Саратовка, Ленина, б/н"	Россия, Республика Бурятия, Иволгинский район, село Саратовка	0101000020E610000001F9122A38DB5A400A3197546DD34940
25768	5	44	577	26360	76631	\N	51.807592	с.Поселье, Советская, 37, здание начальной школы		0101000020E61000009696917A4FE25A407041B62C5FE74940
25765	5	44	577	3808	76762	\N	51.959995999999997	с.Ошурково, Школьная, здание начальной ОШ		0101000020E61000008C4AEA0434DE5A4039252026E1FA4940
25783	5	44	577	4780	76637	\N	51.529461272151103	пос.Оронгой, Почтовая, 5, здание фельдшерского пункта	Россия, Республика Бурятия, Иволгинский район, село Оронгой	0101000020E6100000575A46EA3DC35A40F4C0C760C5C34940
25771	5	44	577	4141	71587	\N	51.771822	с.Нижняя Иволга, Коммунистическая, 43, здание СДК		0101000020E6100000ACC95356D3DA5A40AA2A3410CBE24940
26119	5	44	577	21329	71711	\N	51.735616	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Саянтуйское"", с.Нижний Саянтуй, Ленина, 35"		0101000020E6100000A7406667D1E05A40093543AA28DE4940
25774	5	44	577	4260	76753	\N	51.790716000000003	с.Красноярово, Партизанская, 53, здание ОСШ		0101000020E6100000C2887D0228D25A404436902E36E54940
25778	5	44	577	45685	76703	\N	51.651578000000001	с.Колобки, Центральная, 6 а, здание ООШ		0101000020E6100000A1698995D1D75A4084656CE866D34940
14609	5	44	577	47758	\N	\N	51.616807000000001	с.Кокорино, здание СОШ		0101000020E610000035B39602D2BF5A40D1782288F3CE4940
25779	5	44	577	45702	\N	\N	51.688348881947597	с.Ключи, здание СДК	Россия, Республика Бурятия, Иволгинский район, село Ключи	0101000020E6100000CEDE196D55CB5A40FE9DEDD11BD84940
25786	5	44	577	4928	76868	\N	51.420366000000001	село Кибалино, Проточная, 25 а, здание ОСШ		0101000020E61000009224085740C15A40D82C978DCEB54940
25781	5	44	577	4688	76536	\N	51.755929999999999	с.Каленово, Школьная, 9, здание СОШ		0101000020E6100000355D4F745DC75A405B087250C2E04940
25761	5	44	577	3615	\N	\N	51.748190999999998	с.Иволгинск, квартал Студенческий, здание БРАТ		0101000020E6100000F27B9BFEECD15A40AD1402B9C4DF4940
25775	5	44	577	3615	75692	\N	51.748190999999998	"с.Иволгинск, Первомайская, 22, здание ""Бурятмелиоводхоз"""		0101000020E6100000F27B9BFEECD15A40AD1402B9C4DF4940
25777	5	44	577	3615	71591	\N	51.746460000541902	с.Иволгинск, Ленина, 32, здание РДК	Россия, Республика Бурятия, Иволгинский район, село Иволгинск	0101000020E6100000DEC9A7C7B6D15A40D6E253008CDF4940
25776	5	44	577	3615	71591	\N	51.748190999999998	"с.Иволгинск, Ленина, 42, здание МОУ ДОД ""Иволгинский"""		0101000020E6100000F27B9BFEECD15A40AD1402B9C4DF4940
25769	5	44	577	4010	75690	\N	51.822859000000001	с.Гурульба, Луговая, 26 а, здание ОСШ		0101000020E6100000E25AED612FDA5A40111C977153E94940
25600	5	44	1820	27842	76691	\N	50.548509000000003	село Сухой Ручей, Комсомольская, 1		0101000020E6100000A2B60DA320E05A40E547FC8A35464940
26120	5	44	577	21352	76749	\N	51.712496000000002	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Саянтуйское"", с.Вознесеновка, Школьная, 9"		0101000020E610000022DE3AFF76DE5A40F243A51133DB4940
25780	5	44	577	4592	76609	\N	51.751424999999998	с.Верхняя Иволга, Центральная, 17 а, здание СДК		0101000020E6100000EB1D6E8786CC5A40CA32C4B12EE04940
26122	5	44	577	21468	76835	\N	51.637908000000003	"Республика Бурятия, муниципальный район ""Тарбагатайский район"", сельское поселение ""Саянтуйское"", с.Верхний Саянтуй, Ленина, 73"		0101000020E6100000562B137EA9E35A40ABED26F8A6D14940
25750	5	44	379	61000	\N	\N	50.729382000000001	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Усть-Бургалтайское"", здание МОУ ""Усть-Бургалтайская СОШ"""		0101000020E610000011A62897C6D959404225AE635C5D4940
25745	5	44	379	61001	\N	\N	50.729382000000001	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Мылинское"", здание МОУ ""Мылинская СОШ"""		0101000020E610000011A62897C6D959404225AE635C5D4940
25736	5	44	379	60978	\N	\N	50.4812697650407	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Шара-Азаргинское"", здание МОУ ""Шара-Азаргинская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Шара-Азарга	0101000020E6100000C7D45DD905C35940E1455F419A3D4940
25742	5	44	379	60912	\N	\N	50.442536911978401	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Цакирское"", здание МОУ ""Цакирская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Цакир	0101000020E6100000C7B94DB857E559408E226B0DA5384940
25743	5	44	379	60946	\N	\N	50.743166452905797	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Цаган-Моринское"", здание МОУ ""Цаган-Моринская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Цаган-Морин	0101000020E6100000A8FFACF9F1CC5940E4BF4010205F4940
25749	5	44	379	60941	\N	\N	50.443624659038001	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Хуртагинское"", здание МОУ ""Хуртагинская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Хуртага	0101000020E6100000EFA83121E6FB5940105839B4C8384940
25738	5	44	379	45517	\N	\N	50.4252294569974	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Хужирское"", здание МОУ ""Хужирская начальная школа-сад"""	Россия, Республика Бурятия, Закаменский район, село Хужир	0101000020E6100000B3CD8DE909D15940C82764E76D364940
25754	5	44	379	60901	\N	\N	50.2984379573955	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Холтосонское"", здание МОУ ""Холтосонская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Холтосон	0101000020E610000025766D6FB7D359401BF1643733264940
25753	5	44	379	60910	\N	\N	50.481077121931598	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Харацайское"", здание МОУ ""Харацайская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Харацай	0101000020E61000002C2AE274921E5A40CCED5EEE933D4940
25748	5	44	379	60940	\N	\N	50.402948671407501	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Хамнейское"", здание МОУ ""Хамнейская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Хамней	0101000020E610000060B1868BDCF759405B7A34D593334940
25733	5	44	379	60942	\N	\N	50.826577071663202	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Утатайское"", здание МОУ ""Утатуйская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Утата	0101000020E61000008A20CEC309B259401A506F46CD694940
25740	5	44	379	60949	\N	\N	50.4973778610089	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Улентуйское"", здание МОУ ""Улентуйская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Улентуй	0101000020E6100000A873452921DB5940FCDF1115AA3F4940
25752	5	44	379	60892	\N	\N	50.477681510463398	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Улекчинское"", здание МОУ ""Улекчинская СОШ"""		0101000020E610000020D099B4A9125A40A6F10BAF243D4940
25734	5	44	379	60909	\N	\N	50.730139999999999	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Санагинское"", здание МОУ ""Санагинская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Санага	0101000020E6100000CD3FFA264DB359402FC03E3A755D4940
25737	5	44	379	60963	\N	\N	50.388668000000003	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Нуртинское"", здание МОУ ""Нуртинская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Нурта	0101000020E610000032C7F2AE7AC8594039807EDFBF314940
25751	5	44	379	60908	\N	\N	50.406207295724499	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Михайловское"", здание МОУ ""Михайловская СОШ"""		0101000020E61000007D94111780095A4001344A97FE334940
25763	5	44	379	32545	\N	\N	50.368965000000003	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание ГУ Центр занятости по Закаменскому району"		0101000020E610000026FF93BF7BD25940302FC03E3A2F4940
25625	5	44	1820	60903	76694	\N	50.832815911079898	улус Шанага, Токтохоева, 23	Россия, Республика Бурятия, Бичурский район, село Шанага	0101000020E6100000AC8C463EAF095B40F3CAF5B6996A4940
25762	5	44	379	32545	\N	\N	50.368965000000003	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание Закаменского филиала РГУ ветеринарии ""БСРББЖ"""		0101000020E610000026FF93BF7BD25940302FC03E3A2F4940
25760	5	44	379	32545	\N	\N	50.368965000000003	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание  МУК ""Межпоселенческая центральная библиотека"""		0101000020E610000026FF93BF7BD25940302FC03E3A2F4940
25758	5	44	379	32545	\N	\N	50.378553209015202	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание МУДОД ""Центр дополнительного образования"""	Россия, Республика Бурятия, Закаменский район, город Закаменск	0101000020E6100000575F5D15A8D25940BE66B96C74304940
25757	5	44	379	32545	\N	\N	50.370602209079898	"Республика Бурятия, муниципальный район ""Закаменский район"", городское поселение ""Город Закаменск"", здание МОУ ""Закаменская районная гимназия"""	Россия, Республика Бурятия, Закаменский район, город Закаменск	0101000020E61000008B19E1ED41D2594085EAE6E26F2F4940
25741	5	44	379	60935	\N	\N	50.476482654700597	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Ехэ-Цакирское"", здание МОУ ""Ехэ-Цакирская СОШ"""		0101000020E6100000DA70581AF8E05940CC0C1B65FD3C4940
25735	5	44	379	60986	\N	\N	50.508558275206198	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Енгорбойское"", здание МОУ ""Енгорбойская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Енгорбой	0101000020E610000065E3C116BBBA5940410FB56D18414940
25739	5	44	379	60895	\N	\N	50.438621842217103	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Дутулурское"", здание МОУ ""Дутулурская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Дутулур	0101000020E6100000B43EE5982CD859402FA704C424384940
25732	5	44	379	60979	\N	\N	50.899926999999998	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Далахайское"", здание МОУ ""Дабатуйская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Далахай	0101000020E6100000A06EA0C03BB95940C9E4D4CE30734940
25747	5	44	379	60999	\N	\N	50.458803000000003	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Бургуйское"", здание МОУ ""Бургуйская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Бургуй	0101000020E6100000A2ED98BA2BF259404227840EBA3A4940
25744	5	44	379	60975	\N	\N	50.679481942916702	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Бортойское"", здание МОУ ""Бортойская СОШ"""	Россия, Республика Бурятия, Закаменский район, село Бортой	0101000020E610000086730D3334D959403F1C2444F9564940
25746	5	44	379	33128	\N	\N	50.701247000000002	"Республика Бурятия, муниципальный район ""Закаменский район"", сельское поселение ""Баянгольское"", здание МОУ ""Баянгольская СОШ"""		0101000020E6100000A60BB1FA23DE594085B53176C2594940
25627	5	44	24	60937	76797	\N	51.504839085886204	улус Хонхолой, Цыдыпова, 24	Россия, Республика Бурятия, Заиграевский район	0101000020E61000003239B5334C215B40675F79909EC04940
25720	5	44	24	1286	75835	\N	51.888626000000002	с.Эрхирик, Гагарина, 1 (администрация)		0101000020E6100000A5DC7D8E8FF45A400A302C7FBEF14940
25705	5	44	24	61035	77021	\N	51.735990033974502	с.Шэнэ-Бусы, Центральная, 24 (школа)	Россия, Республика Бурятия, Заиграевский район, село Шэнэ-Буса	0101000020E6100000274C18CDCA1F5B406E179AEB34DE4940
25716	5	44	24	1025	76526	\N	51.475116999999997	с.Шабур, Советская, 14 а (эдание администрации)		0101000020E6100000E5D5390664145B40066344A2D0BC4940
25709	5	44	24	60882	76615	\N	51.757441	п.Челутай 3 км, переулок Связи, 1 (дом культуры)	Россия, Республика Бурятия, Заиграевский район, село Челутай, 3-й км	0101000020E61000003D7C992842175B4024D3A1D3F3E04940
25707	5	44	24	475	76590	\N	51.756670999999997	п.Челутай 24 км, Клубная, 3 (дом культуры)		0101000020E6100000FAD346753A185B40726A6798DAE04940
25704	5	44	24	60968	\N	\N	52.071266999999999	улус Хара-Шибирь, нет, сельский клуб		0101000020E61000008F8CD5E6FF1C5B405B24ED461F094A40
25713	5	44	24	862	76690	\N	51.762318999999998	с.Хара-Кутул, Центральная, 13 сельский клуб	Россия, Республика Бурятия, Заиграевский район, село Хара-Кутул	0101000020E610000016FA60191B545B40490F43AB93E14940
25700	5	44	24	32483	76629	\N	51.936264999999999	село Усть-Брянь, Победы, 10 (дом культуры)		0101000020E61000003FA88B14CA085B40D9B11188D7F74940
25726	5	44	24	1594	75837	\N	52.100093999999999	Унэгэтэй, Школьная, 6 (дом культуры)		0101000020E6100000F3AE7AC03C245B404E4354E1CF0C4A40
25699	5	44	24	32432	\N	\N	51.846955999999999	с.Тодогто, Центральная, 5 (проходная СПК Надежда)	Россия, Республика Бурятия, Заиграевский район, село Тодогто	0101000020E6100000B2BCAB1E30035B405393E00D69EC4940
25710	5	44	24	688	76913	\N	51.683959999999999	с.Ташелан, Ленина, 29		0101000020E6100000BAD7497D59395B40D6E253008CD74940
25708	5	44	24	531	75832	\N	51.686104	п.Татарский Ключ, ул.Спортивная, 5 (дом культуры)	Россия, Республика Бурятия, Заиграевский район, село Татарский Ключ	0101000020E610000002BB9A3C65195B40D0D38041D2D74940
25721	5	44	24	1292	76675	\N	51.940773999999998	с.Старый Онохой, Клубная, 1 (дом культуры)	Россия, Республика Бурятия, Заиграевский район, село Старый Онохой	0101000020E610000018EDF1423A035B40AB764D486BF84940
25724	5	44	24	1511	76961	\N	52.006517000000002	с.Старая Курба, Школьная, 1(школа)		0101000020E6100000A0A696ADF5205B401CEF8E8CD5004A40
25714	5	44	24	898	76880	\N	51.580868000000002	с,Старая Брянь, Центральная, 64 а (дом культуры)		0101000020E6100000ACC5A70018085B407FA5F3E159CA4940
25690	5	44	24	60934	76794	\N	51.975609271328999	улус Онохой Шибирь, ул. Харза, 39	Россия, Республика Бурятия, Заиграевский район, село Онохой-Шибирь	0101000020E610000052D158FB3B015B40755776C1E0FC4940
25695	5	44	24	60877	76588	\N	51.922050770935599	Онохой, Серова, 3		0101000020E6100000C381902C60035B403F1F65C405F64940
25698	5	44	24	32193	74723	\N	51.922054000000003	п.Онохой, Школьная, 33 (школа)		0101000020E61000004F7974232C035B40B0928FDD05F64940
25694	5	44	24	32193	75829	\N	51.922054000000003	п.Онохой, Серова, 11		0101000020E61000004F7974232C035B40B0928FDD05F64940
25697	5	44	24	32193	76521	\N	51.922054000000003	Онохой, Промышленная, 18 (клуб)		0101000020E61000004F7974232C035B40B0928FDD05F64940
25696	5	44	24	32193	76653	\N	51.922054000000003	Онохой, ул.40 Лет ЛПК, 11 (автошкола)	Россия, Республика Бурятия, Заиграевский район, поселок городского типа Онохой	0101000020E61000004F7974232C035B40B0928FDD05F64940
25703	5	44	24	169	75687	\N	51.680692999999998	поселок Новоильинск, Полевая, 1 (школа)		0101000020E6100000395E81E8492E5B40DDCEBEF220D74940
25702	5	44	24	169	71570	\N	51.680692999999998	с.Новоильинск, Ленина, 33 (центр молодежи)		0101000020E6100000395E81E8492E5B40DDCEBEF220D74940
25725	5	44	24	1560	76696	\N	52.041728999999997	с.Новая Курба, Советская, 3 (дом культуры)		0101000020E61000004E266E15C4205B40BB25396057054A40
25675	5	44	24	29982	75685	\N	51.714857000000002	с.Новая Брянь, Октябрьская, 1 (дом культуры)		0101000020E61000004C4F58E201115B408928266F80DB4940
25648	5	44	24	29982	75685	\N	51.714857000000002	с. Новая Брянь, Октябрьская, 1 (дом культуры)		0101000020E61000004C4F58E201115B408928266F80DB4940
25701	5	44	24	30	76598	\N	51.886391000000003	с.Нижние Тальцы, Новая, 12 (дом культуры)	Россия, Республика Бурятия, Заиграевский район, село Нижние Тальцы	0101000020E6100000BFD18E1B7EFB5A40003CA24275F14940
25722	5	44	24	1393	76890	\N	52.005996000000003	с.Нарын-Ацагат, Раднаева, 25 (дом культуры)		0101000020E6100000DC48D92269125B4013F4177AC4004A40
25712	5	44	24	52879	77015	\N	51.713420783808303	улус.Нарын, Школьная, 12	Россия, Республика Бурятия, Заиграевский район, село Нарын	0101000020E61000007E1EA33CF3445B40CAA31B6151DB4940
25711	5	44	24	699	76877	\N	51.754297000000001	с.Мухор-Тала, Афанасьева, 29		0101000020E61000002FF99FFCDD335B40473CD9CD8CE04940
25719	5	44	24	1191	76695	\N	51.456623999999998	ст.Кижа, Железнодорожная, 6 (вокзал)		0101000020E61000003CA583F57F385B40CB48BDA772BA4940
25706	5	44	24	417	75689	\N	51.722405999999999	п.Илька, Трактовая, 6 (дом культуры)		0101000020E6100000E2ADF36F97215B409337C0CC77DC4940
25693	5	44	24	32098	76593	\N	51.833685000000003	Заиграево, пер.Молодежный, 2		0101000020E6100000983446EBA8115B403815A930B6EA4940
25692	5	44	24	32098	74764	\N	51.833685000000003	Заиграево, Ленина, 39 (дом культуры)		0101000020E6100000983446EBA8115B403815A930B6EA4940
25691	5	44	24	32098	74764	\N	51.833685000000003	Заиграево, Ленина (дом культуры), 39		0101000020E6100000983446EBA8115B403815A930B6EA4940
25730	5	44	24	60929	\N	\N	52.002411390755803	улус Добо-Енхор, нет, сельская библиотека	Россия, Республика Бурятия, Заиграевский район, село Добо-Ёнхор	0101000020E6100000EF59D768390A5B404913EF004F004A40
25718	5	44	24	48986	76764	\N	51.559382169101703	п.Горхон (Лесозавод), Лесная, 20 (ново-горхонская школа)	Россия, Республика Бурятия, Заиграевский район, село Горхон	0101000020E61000002FE1D05B3C325B404CFC51D499C74940
25717	5	44	24	48986	74978	\N	51.559545	п.Горхон, Железнодорожная, 22 (школа)		0101000020E6100000F20C1AFA27325B40F6D1A92B9FC74940
25715	5	44	24	967	76954	\N	51.537982	п.Атхатай, Гаражная, 1 (сельский клуб)		0101000020E6100000F2785A7EE0025B4018EB1B98DCC44940
25727	5	44	24	1661	\N	\N	52.219572999999997	с.Ангир, нет, 24		0101000020E610000014200A664C265B40D40AD3F71A1C4A40
25669	5	44	1903	31035	76931	\N	52.424681999999997	Республика Бурятия, Еравнинский район, Эгитуйская СОШ, село Эгита, Гомбоева, 33		0101000020E61000002A1BD65416AF5B409599D2FA5B364A40
25683	5	44	1903	31716	76782	\N	52.677571999999998	Республика Бурятия, Еравнинский район, Ширингинская СОШ, с.Ширинга, Школьная, 3		0101000020E61000004F7633A31FED5B40B857E6ADBA564A40
25689	5	44	1903	60930	76791	\N	52.605955000000002	"Республика Бурятия, Еравнинский район, помещение МО ""Целинное"", село Целинный, пер. Школьный, 3"		0101000020E610000092955F0663375C4081ECF5EE8F4D4A40
25685	5	44	1903	31825	76786	\N	52.819125999999997	Республика Бурятия, Еравнинский район, Сельский клуб, с.Хорга, Бадмаева, 11		0101000020E6100000E86A2BF697F45B40D2A6EA1ED9684A40
25667	5	44	1903	60984	76886	\N	52.361257999999999	Республика Бурятия, Еравнинский район, Сельский клуб, улус Хангир, ул. Хангирская, б/н	Россия, Республика Бурятия, Еравнинский район, село Хангир	0101000020E6100000ECA012D731B95B408DB5BFB33D2E4A40
25666	5	44	1903	30893	76614	\N	52.332486032317902	Республика Бурятия, Еравнинский район, сельский дом культуры, село Усть-Эгита, Дамдинова, 15	Россия, Республика Бурятия, Еравнинский район, село Усть-Эгита	0101000020E6100000554D10751FA75B405E30B8E68E2A4A40
25664	5	44	1903	30822	76476	\N	52.223264	Республика Бурятия, Еравнинский район, Дом культуры, село Ульдурга, ул. Ленина, 46		0101000020E6100000D619DF1797A25B40E42F2DEA931C4A40
25671	5	44	1903	60976	76870	\N	52.462618999999997	Республика Бурятия, Еравнинский район, Сельский клуб с.Улзытэ, Центральная, б/н	Россия, Республика Бурятия, Еравнинский район, село Улзытэ (Занультуй)	0101000020E61000006CCF2C0950B75B400DC17119373B4A40
25674	5	44	1903	31298	76801	\N	52.526072999999997	Республика Бурятия, Еравнинский район, Сельская библиотека, село Укыр, Центральная, 14\\1		0101000020E610000068B27F9E06DA5B4080272D5C56434A40
25682	5	44	1903	31696	76953	\N	52.686923999999998	Республика Бурятия, Еравнинский район, Дом культуры, с.Тулдун, Ленина, 16		0101000020E6100000E76ED74B53E55B40336B2920ED574A40
25665	5	44	1903	30859	76800	\N	52.306870000000004	Республика Бурятия, Еравнинский район, сельский клуб, село Тужинка, ул. Почтовая 4		0101000020E610000094861A8524A35B40D00F238447274A40
25688	5	44	1903	31944	76602	\N	52.737526881085401	Республика Бурятия, Еравнинский район, Телембинская СОШ, село Телемба, Ланцева, 11	Россия, Республика Бурятия, Еравнинский район, село Телемба	0101000020E6100000431B800D88525C406075E448675E4A40
25678	5	44	1903	31453	\N	\N	52.52713	Республика Бурятия, Еравнинский район, Сосново-Озерская СОШ № 1, село Сосново-Озерское, Матросова, 46	Россия, Республика Бурятия, Еравнинский район, село Сосново-Озерское	0101000020E6100000583CF54883E25B40C85EEFFE78434A40
25677	5	44	1903	31453	76662	\N	52.52713	Республика Бурятия, Еравнинский район, Районный дом культуры, село Сосново-Озерское, Перовмайская, 115		0101000020E6100000583CF54883E25B40C85EEFFE78434A40
25679	5	44	1903	31453	76522	\N	52.52713	Республика Бурятия, Еравнинский район, Районный дом культуры, село Сосново-Озерское, Первомайская, 115		0101000020E6100000583CF54883E25B40C85EEFFE78434A40
25680	5	44	1903	31453	76525	\N	52.52713	Республика Бурятия, Еравнинский район, Контора РЭС, село Сосново-Озерское, Заречная, 8		0101000020E6100000583CF54883E25B40C85EEFFE78434A40
25585	5	44	1903	60898	76678	\N	53.213597132622297	В помещении СДК с.Романовка, ул.Первомайская, д 2	Россия, Республика Бурятия, Еравнинский район, село Романовка	0101000020E61000003830B95164315C4009C38025579B4A40
25668	5	44	1903	31017	76924	\N	52.383651	Республика Бурятия, Еравнинский район, Сельский клуб, село Поперечное, Школьная, 3		0101000020E61000007C2C7DE882AD5B40F209D9791B314A40
25686	5	44	1903	31852	76950	\N	52.930058000000002	Республика Бурятия, Еравнинский район, Озерниная СОШ, поселок Озерный, Комсомольская, 1		0101000020E6100000CC07043A93EC5B400CB1FA230C774A40
25670	5	44	1903	31117	76589	\N	52.412318999999997	Республика Бурятия, Еравнинский район, Дом культуры, село Можайка, Цырендылыкова, 28		0101000020E6100000B76114048FB25B407C4276DEC6344A40
25672	5	44	1903	60936	76796	\N	52.479712991506503	Республика Бурятия, Еравнинский район, Дом культуры, село Комсомольск, Советская, 22		0101000020E61000003048FAB48AC55B40A73B4F3C673D4A40
25687	5	44	1903	31928	76514	\N	52.911479	Республика Бурятия, Еравнинский район, Дом культуры, село Исинга, Клубная, 2		0101000020E61000008DF0F62004005C40D2FE0758AB744A40
25681	5	44	1903	31652	76865	\N	52.562016999999997	Республика Бурятия, Еравнинский район, здание школы, село Домна, Сампилова, 11		0101000020E61000000305DEC9A7ED5B40E4654D2CF0474A40
25684	5	44	1903	31779	76592	\N	52.780158	Республика Бурятия, Еравнинский район, Дом культуры, с.Гунда, Ленина, б/н		0101000020E6100000C98FF8156BEE5B403CDBA337DC634A40
25673	5	44	1903	31242	76866	\N	52.531112999999998	Республика Бурятия, Еравнинский район, Дом культуры, село Гонда, Школьная, 8		0101000020E61000007539252026CF5B407FBDC282FB434A40
25676	5	44	1903	31391	76803	\N	52.574162999999999	Республика Бурятия, Еравнинский район, Дом культуры, село Гарам, Орлова, 12		0101000020E6100000329067976FDC5B4060C9552C7E494A40
25631	5	44	1860	29207	\N	\N	50.512602999999999	"Республика Бурятия, муниципальный район ""Джидинский район"", с. ""Шартыкей"", с.""Подхулдочи"", Б/н"	Россия, Республика Бурятия, Джидинский район, село Шартыкей	0101000020E61000002810768A55335A406E6AA0F99C414940
25651	5	44	1860	60904	76699	\N	50.7280362313765	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Цагатуй"", ул. Шарапова, 5"	Россия, Республика Бурятия, Джидинский район, село Цагатуй	0101000020E6100000E57ADB4C85535A40C4279D48305D4940
25661	5	44	1860	30655	76854	\N	50.435307999999999	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Цаган-Усун"", Набережная, 15"		0101000020E6100000ED461FF301825A40F5D72B2CB8374940
25633	5	44	1860	29311	76941	\N	50.49004	"Республика Бурятия, муниципальный район ""Джидинский район"", с. ""Хулдат"", Центральная, 74"		0101000020E61000003D0B42791F2C5A40ADDD76A1B93E4940
25656	5	44	1860	60914	76766	\N	50.574522000000002	"Республика Бурятия, муниципальный район ""Джидинский район"", с. ""Зарубино"", поселок станции Хужир, Ульянова, 45"	Россия, Республика Бурятия, Джидинский район, село Хужир	0101000020E6100000FDBFEAC8918C5A40906AD8EF89494940
25999	5	44	1860	60914	76724	\N	50.573920414926199	Хужир, Патархеева, 42	Россия, Республика Бурятия, Джидинский район, село Хужир	0101000020E61000000E2E1D739E8C5A409A42E73576494940
25637	5	44	1860	60995	76944	\N	50.756069460278603	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Улзар"", ул.Центральная, 8"	Россия, Республика Бурятия, Джидинский район, село Улзар	0101000020E6100000CF84268925345A407C4276DEC6604940
25639	5	44	1860	60902	76693	\N	50.484483611659201	"Республика Бурятия, муниципальный район ""Джидинский район"", с. ""Желтура"", с.""Тэнгэрэк"", сельский поселок ""Мельница"", Ленина, 2"	Россия, Республика Бурятия, Джидинский район, село Тэнгэрэк	0101000020E610000032005471E3475A40B7B75B92033E4940
25653	5	44	1860	60970	76857	\N	50.523762650886702	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Тасархой"", Советская, 52"	Россия, Республика Бурятия, Джидинский район, село Тасархай	0101000020E61000005B423EE8D9635A406CED7DAA0A434940
25636	5	44	1860	60905	76701	\N	50.510998999999998	"Республика Бурятия, муниципальный район ""Джидинский район"", с. ""Тохой"", с.""Старый Укырчелон"", Советская, 98"	Россия, Республика Бурятия, Джидинский район, село Старый Укырчелон	0101000020E6100000B01C2103793E5A40F4A44C6A68414940
25646	5	44	1860	29818	74979	\N	50.6096325481574	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Петропавловка"", ул. Терешковой 9"	Россия, Республика Бурятия, Джидинский район, село Петропавловка	0101000020E610000022FFCC203E545A40FCC74274084E4940
25647	5	44	1860	29818	71565	\N	50.609141000000001	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Петропавловка"", ул. Свердлова, 52"		0101000020E610000022FFCC203E545A408DD31055F84D4940
25604	5	44	1820	61019	77006	\N	50.6159303562969	улус Хаян, Центральная, 7		0101000020E61000005F622CD32FD35A40095053CBD64E4940
25645	5	44	1860	29818	71565	\N	50.608430979877397	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Петропавловка"", ул. Свердлова, 49"	Россия, Республика Бурятия, Джидинский район, село Петропавловка	0101000020E61000003509DE9046545A40B16F2711E14D4940
25644	5	44	1860	29818	74733	\N	50.607068190871303	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Петропавловка"", ул. Балтахинова, 45"	Россия, Республика Бурятия, Джидинский район, село Петропавловка	0101000020E61000003332C85D84545A405C397B67B44D4940
25634	5	44	1860	29338	76692	\N	50.535983999999999	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Оёр"", Центральная, 98"		0101000020E6100000CD902A8A573F5A40F296AB1F9B444940
25654	5	44	1860	60973	76861	\N	50.523170600740102	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Нюгуй"", Школьная, 12"	Россия, Республика Бурятия, Джидинский район, село Нюгуй	0101000020E61000004DA3C9C518705A40999B6F44F7424940
25632	5	44	1860	29274	76512	\N	50.530282	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Нижний Торей"", А-Мельникова, 54"		0101000020E6100000CC7B9C69C2345A4028D4D347E0434940
25638	5	44	1860	60928	76788	\N	50.5603363254709	"Республика Бурятия, муниципальный район ""Джидинский район"",  улус ""Нижний Бургалтай"", Яковлева, 2"	Россия, Республика Бурятия, Джидинский район, село Нижний Бургалтай	0101000020E6100000394206F2EC475A40BF620D17B9474940
25630	5	44	1860	60980	76882	\N	50.532388209526403	"Республика Бурятия, муниципальный район ""Джидинский район"", с. ""Большой Нарын"", Центральная, 65"	Россия, Республика Бурятия, Джидинский район, село Нарын	0101000020E61000004CC45BE7DF235A4034643C4A25444940
25642	5	44	1860	60980	76969	\N	50.531622317220503	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Малый Нарын"", Вампилова, 10"	Россия, Республика Бурятия, Джидинский район, село Нарын	0101000020E61000007270E998F3235A40C4EA8F300C444940
25663	5	44	1860	60972	76860	\N	50.829399000000002	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Инзагатуй"", Школьная, 11"	Россия, Республика Бурятия, Джидинский район, село Инзагатуй	0101000020E6100000F4DDAD2CD16F5A40E52A16BF296A4940
25659	5	44	1860	30549	76798	\N	50.517437000000001	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Енхор"", Ленина, 11"		0101000020E61000003D2828452B755A40C45E28603B424940
25650	5	44	1860	30076	76676	\N	50.736001000000002	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Дэдэ Ичетуй"", ул. Ленина, 35"	Россия, Республика Бурятия, Джидинский район, село Дэдэ-Ичетуй	0101000020E6100000485167EE215B5A406269E047355E4940
25655	5	44	1860	60887	76630	\N	50.651818061442	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Дырестуй"", Ленина, 48"	Россия, Республика Бурятия, Джидинский район, село Дырестуй	0101000020E6100000F0315871AA845A40D978B0C56E534940
25649	5	44	1860	60989	76898	\N	50.639110798612798	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Додо Ичетуй"", Центральная, 8"	Россия, Республика Бурятия, Джидинский район, село Додо-Ичетуй	0101000020E610000097016729595D5A40C6C1A563CE514940
25658	5	44	1860	30413	74742	\N	50.681229999999999	"Республика Бурятия, муниципальный район ""Джидинский район"", ""Поселок Джида"", Торговая, 20б"		0101000020E6100000E5B7E864A98B5A40EC866D8B32574940
25657	5	44	1860	30413	74742	\N	50.681229999999999	"Республика Бурятия, муниципальный район ""Джидинский район"",  ""Поселок Джида"", Торговая, 16"		0101000020E6100000E5B7E864A98B5A40EC866D8B32574940
25641	5	44	1860	60897	76677	\N	50.645594262299902	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Гэгэтуй"", ул. Ч.Раднаева, 5"	Россия, Республика Бурятия, Джидинский район, село Гэгэтуй	0101000020E610000074B33F506E4E5A40363FFED2A2524940
25635	5	44	1860	60926	76785	\N	50.659758239651197	"Республика Бурятия, муниципальный район ""Джидинский район"",  улус ""Верхний Торей"", Гармаева, 44"	Россия, Республика Бурятия, Джидинский район, село Верхний Торей	0101000020E61000009D9E776341345A401EA33CF372544940
25640	5	44	1860	29607	76946	\N	50.612941999999997	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Верхний Бургалтай"", Набережная, 20"		0101000020E6100000EA7AA2EBC2435A40232C2AE2744E4940
25643	5	44	1860	29746	76697	\N	50.595843000000002	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Булык"", село ""Баян"", переулок Клубный, 47"		0101000020E6100000BDA8DDAF02515A4078465B95444C4940
25660	5	44	1860	30570	76853	\N	50.472752999999997	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Боций"", Ленина, 40"		0101000020E610000065FD6662BA695A40FE0A992B833C4940
25662	5	44	1860	60993	76921	\N	50.747579953253201	"Республика Бурятия, муниципальный район ""Джидинский район"", улус ""Боргой"", Советская, 1"	Россия, Республика Бурятия, Джидинский район, село Боргой	0101000020E6100000EB8B84B69C755A40649291B3B05F4940
25652	5	44	1860	30176	76625	\N	50.648702999999998	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Белоозерск"", Школьная, 49"		0101000020E610000067B5C01E136D5A4096E82CB308534940
25629	5	44	1860	29134	76873	\N	50.605441999999996	"Республика Бурятия, муниципальный район ""Джидинский район"", село ""Армак"", ул. Центральная, 32"		0101000020E61000000AF8359204265A40FACF9A1F7F4D4940
25628	5	44	1860	60994	76925	\N	50.672886107583203	"Республика Бурятия, муниципальный район ""Джидинский район"",  улус ""Алцак"", ул. Центральная, 6"	Россия, Республика Бурятия, Джидинский район, село Алцак	0101000020E610000059DFC0E446275A40D7F7E12021564940
25606	5	44	1820	28073	76948	\N	50.561036999999999	село Старые Ключи, Заречная, 15		0101000020E610000018D00B772EC55A40486C770FD0474940
25607	5	44	1820	61030	77023	\N	50.638174693036902	улус Средний Харлун, Центральная, 4		0101000020E61000000E2DB29DEFBA5A40F90FE9B7AF514940
25620	5	44	1820	47204	76938	\N	50.615319999999997	село Слобода, Гагарина, 2		0101000020E6100000E9BAF083F3F95A40904946CEC24E4940
25595	5	44	1820	27584	76674	\N	50.630068999999999	поселок Сахарный Завод, Набережная, 4		0101000020E6100000C5E3A25A44E15A40999CDA19A6504940
25626	5	44	1820	33056	76571	\N	50.810017000000002	поселок Потанино, Центральная, 1		0101000020E61000008237A45181095B401E1A16A3AE674940
25568	5	44	1820	61004	76976	\N	50.613725000000002	село Поселье, Ленина, 47	Россия, Республика Бурятия, Бичурский район, село Поселье	0101000020E61000006A334E4354F95A406ADE718A8E4E4940
26023	5	44	1820	45991	76765	\N	50.711789000000003	с.Покровка, Первомайская, 28		0101000020E6100000C8D11C59F9DC5A408753E6E61B5B4940
25613	5	44	1820	28374	76511	\N	50.705203620675398	село Петропавловка, Гагарина, 38а	Россия, Республика Бурятия, Бичурский район, село Петропавловка	0101000020E61000002FC37FBA81E15A401381EA1F445A4940
25605	5	44	1820	28051	76584	\N	50.599238999999997	село Окино-Ключи, Центральная, 16		0101000020E6100000478D093197C65A406EBE11DDB34C4940
25615	5	44	1820	28483	76949	\N	50.726122874702398	село Новосретенка, Иванова, 139	Россия, Республика Бурятия, Бичурский район, село Новосретенка	0101000020E6100000A08A1BB798EB5A40CCEF3499F15C4940
25612	5	44	1820	28363	76869	\N	50.676270000000002	село Нижний Мангиртуй, Лесная, 47		0101000020E610000026FF93BF7BCA5A400AA2EE0390564940
25616	5	44	1820	28539	76783	\N	50.678502000000002	село Мотня, Новая, 57		0101000020E61000008C14CAC2D7ED5A40A3224E27D9564940
25618	5	44	1820	28625	76862	\N	50.605294000000001	село Малый Куналей, Школьная, 2		0101000020E6100000E0A293A5D6F45A40863B17467A4D4940
25619	5	44	1820	28625	74686	\N	50.605294000000001	село Малый Куналей, Советская, 12		0101000020E6100000E0A293A5D6F45A40863B17467A4D4940
25603	5	44	1820	32946	76552	\N	50.537821999999998	село Елань, Логовского, 84		0101000020E610000071AC8BDB68D65A40DF88EE59D7444940
25601	5	44	1820	61028	77011	\N	50.586258999999998	улус Дунда-Киреть, Центральная, 31	Россия, Республика Бурятия, Бичурский район, село Дунда-Киреть	0101000020E61000001EDE736039DD5A402AFEEF880A4B4940
25624	5	44	1820	61016	76995	\N	50.802421443262403	улус Дабатуй, Школьная, 7	Россия, Республика Бурятия, Бичурский район, село Дабатуй	0101000020E610000076A6D0798DFC5A40D34F38BBB5664940
25617	5	44	1820	61033	77017	\N	50.7386461568125	улус Гутай, Центральная, 26	Россия, Республика Бурятия, Бичурский район, село Гутай	0101000020E6100000F3AFE595EBEF5A401EA9BEF38B5E4940
25611	5	44	1820	28296	76685	\N	50.672576999999997	село Верхний Мангиртуй, Дружбы, 1а		0101000020E6100000D7A02FBDFDCF5A405985CD0017564940
25621	5	44	1820	28759	76688	\N	50.642729000000003	село Буй, Трактовая, 25		0101000020E6100000A1866F61DDFD5A406C98A1F144524940
25593	5	44	1820	27404	71562	\N	50.596877999999997	село Бичура, Соломенникова, 35		0101000020E61000001424B6BB07E65A40D7D9907F664C4940
25597	5	44	1820	27404	74693	\N	50.596877999999997	село Бичура, Советская, 7а		0101000020E61000001424B6BB07E65A40D7D9907F664C4940
25591	5	44	1820	27404	74693	\N	50.596877999999997	село Бичура, Советская, 45		0101000020E61000001424B6BB07E65A40D7D9907F664C4940
25598	5	44	1820	27404	74711	\N	50.596877999999997	село Бичура, Рабочая, 27		0101000020E61000001424B6BB07E65A40D7D9907F664C4940
25592	5	44	1820	27404	76551	\N	50.596877999999997	село Бичура, Краснопартизанская, 60		0101000020E61000001424B6BB07E65A40D7D9907F664C4940
25599	5	44	1820	27404	76582	\N	50.596877999999997	село Бичура, Коммунинстическая, 341		0101000020E61000001424B6BB07E65A40D7D9907F664C4940
25596	5	44	1820	27404	76581	\N	50.596877999999997	село Бичура, Кирова, 38		0101000020E61000001424B6BB07E65A40D7D9907F664C4940
25594	5	44	1820	27404	76628	\N	50.595676069502197	село Бичура, Калинина, 150	Россия, Республика Бурятия, Бичурский район, село Бичура	0101000020E61000002843554CA5E55A408C81751C3F4C4940
25610	5	44	1820	60971	76858	\N	50.777332479185297	село Билютай, Молодежная, 11	Россия, Республика Бурятия, Бичурский район, село Билютай	0101000020E610000049D576137CC65A4030116F9D7F634940
25602	5	44	1820	27927	76851	\N	50.591417	село Ара-Киреть, Назимова, 44		0101000020E6100000F3E7DB82A5DB5A4033A6608DB34B4940
25589	5	44	1750	60967	76897	\N	54.921188999999998	В помещении администрации СП «Ципиканское» ул. Центральная 9	Россия, Республика Бурятия, Баунтовский район, село Ципикан	0101000020E6100000B360E28FA2565C40AC376A85E9754B40
25587	5	44	1750	60996	76947	\N	53.662080708742799	В помещении школы с. Усть-Джилинда, ул.Северная 19	Россия, Республика Бурятия, Баунтовский район, село Усть-Джилинда	0101000020E6100000AF5A99F04BFC5B40C826F911BFD44A40
25590	5	44	1750	60981	76883	\N	55.480683999999997	В помещении школы с.Уакит ул.Советская, д 4		0101000020E61000001F317A6EA1685C40F0DAA50D87BD4B40
25582	5	44	1750	46427	76935	\N	54.351638999999999	п.Северный, ул.Геологическая, д.15		0101000020E610000047054EB681515C40C37FBA81022D4B40
25584	5	44	1750	61051	77054	\N	54.289861999999999	В помещении администрации сельского поселения «Усойское», ул.Центральная дом 1	Россия, Республика Бурятия, Баунтовский район, село Россошино	0101000020E610000070B4E386DF925C40342DB1321A254B40
25583	5	44	1750	61013	76992	\N	53.964874781289602	В помещении школы с.Монгой, ул.Школьная д 1	Россия, Республика Бурятия, Баунтовский район, село Монгой	0101000020E6100000B6847CD0B3745C402FDD240681FB4A40
25581	5	44	1750	26962	75824	\N	54.396180999999999	п.Маловский, ул.Центральная, д.14		0101000020E610000079E9263108635C40F6251B0FB6324B40
25588	5	44	1750	60916	76754	\N	54.316384999999997	В помещении школы с. Варваринский, ул.Красноармейская 37	Россия, Республика Бурятия, Баунтовский район, село Варваринский	0101000020E61000006308008E3D175C40F4F8BD4D7F284B40
25580	5	44	1750	24438	74664	\N	54.442031	с.Багдарин, ул.Ленина, д.45		0101000020E610000027F911BF62655C40BA68C87894384B40
25527	5	44	1750	24438	74664	\N	54.442031	с.Багдарин, ул.Ленина, 103А		0101000020E610000027F911BF62655C40BA68C87894384B40
25983	5	44	1768	61034	77018	\N	53.423804960466697	у.Хошун-Узур, Кооперативная, 13	Россия, Республика Бурятия, Баргузинский район	0101000020E6100000359886E123625B40CE70033E3FB64A40
25577	5	44	1768	60924	76784	\N	53.596353999999998	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Улюнское"", с.Ярикто, Центральная, 11"		0101000020E6100000E1D4079277745B405D6BEF5355CC4A40
25569	5	44	1768	26386	76669	\N	53.726826000000003	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Юбилейное"", с.Юбилейный, Калинина, 7""А"""		0101000020E6100000111D0247028F5B40F6F065A208DD4A40
25549	5	44	1768	60919	76768	\N	53.566155999999999	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баргузинское"", с.Шапеньково, Лесная, 16""Б"""		0101000020E6100000596DFE5F75695B409337C0CC77C84A40
25561	5	44	1768	26041	76661	\N	53.500664999999998	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Читканское"", с.Читкан, Профсоюзная, 32"		0101000020E6100000971AA19FA9715B403CA06CCA15C04A40
25578	5	44	1768	26832	76622	\N	53.915442751123699	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Хилганайское"", с.Хилгана, Очирова, 2А"	Россия, Республика Бурятия, Баргузинский район, село Хилгана	0101000020E61000009A982EC4EA855B40132D793C2DF54A40
25574	5	44	1768	26642	76683	\N	53.803702000000001	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баянгольское"", с.Хара-Усун, Центральная, 6"		0101000020E61000005B25581CCE875B406ADD06B5DFE64A40
25550	5	44	1768	25547	74658	\N	53.408628	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", п.Усть-Баргузин, Щербакова, 9"		0101000020E6100000BFB67EFACF415B406D1D1CEC4DB44A40
25556	5	44	1768	25547	76667	\N	53.408628	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", п.Усть-Баргузин, Производственная, 6"		0101000020E6100000BFB67EFACF415B406D1D1CEC4DB44A40
25553	5	44	1768	25547	71556	\N	53.408628	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", п.Усть-Баргузин, Оцимика, 24"		0101000020E6100000BFB67EFACF415B406D1D1CEC4DB44A40
25555	5	44	1768	25547	75821	\N	53.408628	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", п.Усть-Баргузин, Ленина, 24"		0101000020E6100000BFB67EFACF415B406D1D1CEC4DB44A40
25552	5	44	1768	25547	74894	\N	53.408628	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", п.Усть-Баргузин, Ватутина, 43"		0101000020E6100000BFB67EFACF415B406D1D1CEC4DB44A40
25562	5	44	1768	26106	76912	\N	53.544080000000001	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Уринское"", с.Уро, переулок Школьный, 2"		0101000020E6100000CA1649BBD1755B402F34D769A4C54A40
25564	5	44	1768	26106	76684	\N	53.544080000000001	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Уринское"", с.Уро, Советская, 2"		0101000020E6100000CA1649BBD1755B402F34D769A4C54A40
25572	5	44	1768	26520	76700	\N	53.827964000000001	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баянгольское"", с.Уржил, Караликская, 1"		0101000020E6100000467EFD101B965B40F7216FB9FAE94A40
25575	5	44	1768	26675	76672	\N	53.827502562243801	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Улюнское"", с.Улюн, Очирова, 23"	Россия, Республика Бурятия, Баргузинский район, село Улюн	0101000020E6100000658BA4DDE87A5B40C32B499EEBE94A40
25576	5	44	1768	26746	76774	\N	53.871031000000002	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Улюнское"", с.Улюкчикан, Цыденжапова, 16"		0101000020E6100000583B8A73D47C5B40AE669DF17DEF4A40
25566	5	44	1768	26235	76923	\N	53.657263	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Сувинское"", с.Суво, Кабашова, 5"		0101000020E61000005D50DF32A7805B4078EFA83121D44A40
25573	5	44	1768	26588	76929	\N	53.855010999999998	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баянгольское"", с.Соёл, Колхозная, 20"		0101000020E61000006876DD5B918C5B40315C1D0071ED4A40
25547	5	44	1768	52412	76780	\N	53.645276000000003	Республика Бурятия, муниципальный район Баргузинский район, сельское поселение Баргузинское с.Нестериха, начальная школа, ул, Школьная,18		0101000020E6100000DB34B6D7826D5B4065726A6798D24A40
25563	5	44	1768	26111	76844	\N	53.527244000000003	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Уринское"", с.Малое Уро, Комсомольская, 36"		0101000020E61000007764AC36FF755B4091813CBB7CC34A40
25554	5	44	1768	25723	76843	\N	53.266888000000002	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", с.Максимиха, Клубная, 19"		0101000020E610000099107349D52E5B40F1D8CF6229A24A40
25558	5	44	1768	25923	76915	\N	53.442045	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Адамовское"", с.Макаринино, Набережная, 41"		0101000020E61000000ABABDA431465B401F2E39EE94B84A40
25557	5	44	1768	25854	76760	\N	53.705714	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", с.Курбулик, Нагорная, 2"		0101000020E61000001AA54BFF92425B40282A1BD654DA4A40
25570	5	44	1768	26448	76926	\N	53.741132	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баянгольское"", с.Ина, Центральная, 3"		0101000020E610000039EFFFE3848E5B407102D369DDDE4A40
25560	5	44	1768	25989	76847	\N	53.507499000000003	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Адамовское"", с.Зорино, Набережная, 18"		0101000020E6100000E19A3BFA5F575B4059E02BBAF5C04A40
25565	5	44	1768	26211	76918	\N	53.598416999999998	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Уринское"", с. Душелан, Бр.Чирковых, 2"		0101000020E6100000439259BDC3785B406A2FA2ED98CC4A40
25551	5	44	1768	25556	76945	\N	53.432127000000001	"Республика Бурятия, муниципальный район ""Баргузинский район"", городское поселение ""Поселок Усть-Баргузин"", с.Гусиха, Баргузинская, 24"		0101000020E61000008BDD3EABCC505B40FB5B02F04FB74A40
25579	5	44	1768	26849	76927	\N	53.901414000000003	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Хилганайское"", с.Борогол, Энгельса, 30"		0101000020E6100000D26EF4311F8B5B400A14B18861F34A40
25567	5	44	1768	26294	76779	\N	53.706263	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Сувинское"", с.Бодон, Ленина, 19"		0101000020E61000003D635FB2F1855B40FBAF73D366DA4A40
25571	5	44	1768	26489	74900	\N	53.780118000000002	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баянгольское"", с.Баянгол, Ленина, 69"		0101000020E6100000C30E63D2DF915B40AE8218E8DAE34A40
25548	5	44	1768	25173	76916	\N	53.614935492011803	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баргузинское"", с.Баргузин, м-н Старый Аэропорт, Административное здание метеостанци"	Россия, Республика Бурятия, Баргузинский район, поселок городского типа Баргузин	0101000020E6100000EB01F39029685B403815A930B6CE4A40
25546	5	44	1768	25173	76620	\N	53.615293999999999	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баргузинское"", с.Баргузин, Очирова, Административное здание ООО ""Комхоз"		0101000020E61000006C7C26FBE7675B4067B62BF4C1CE4A40
25544	5	44	1768	25173	74168	\N	53.620855284969402	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баргузинское"", Калинина, 51а"	Россия, Республика Бурятия, Баргузинский район, поселок городского типа Баргузин	0101000020E6100000FB7953910A695B406F47382D78CF4A40
25543	5	44	1768	25173	74706	\N	53.615293999999999	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баргузинское"", с.Баргузин, Дзержинского, 19"		0101000020E61000006C7C26FBE7675B4067B62BF4C1CE4A40
25545	5	44	1768	25173	76508	\N	53.615293999999999	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Баргузинское"", с.Баргузин, Братьев Козулиных, 19"		0101000020E61000006C7C26FBE7675B4067B62BF4C1CE4A40
25559	5	44	1768	25975	76958	\N	53.481143000000003	"Республика Бурятия, муниципальный район ""Баргузинский район"", сельское поселение ""Адамовское"", с.Адамово, Советская, 40"		0101000020E610000065C746205E535B4084D9041896BD4A40
15070	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 32		0101000020E610000043FE99417C7C5540D50792770EF94940
15069	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 14		0101000020E610000043FE99417C7C5540D50792770EF94940
15066	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 50		0101000020E610000043FE99417C7C5540D50792770EF94940
15065	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 70		0101000020E610000043FE99417C7C5540D50792770EF94940
15064	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 63		0101000020E610000043FE99417C7C5540D50792770EF94940
15062	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 93		0101000020E610000043FE99417C7C5540D50792770EF94940
15061	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 154		0101000020E610000043FE99417C7C5540D50792770EF94940
15059	5	43	\N	12949	70195	\N	51.945754000000001	город Горно-Алтайск, проспект Коммунистический, 121		0101000020E610000043FE99417C7C5540D50792770EF94940
15068	5	43	\N	12949	70221	\N	51.945754000000001	город Горно-Алтайск, Чорос-Гуркина, 14		0101000020E610000043FE99417C7C5540D50792770EF94940
15067	5	43	\N	12949	70221	\N	51.945754000000001	город Горно-Алтайск, Чорос-Гуркина, 42		0101000020E610000043FE99417C7C5540D50792770EF94940
15075	5	43	\N	12949	70147	\N	51.945754000000001	город Горно-Алтайск, Социалистическая, 5		0101000020E610000043FE99417C7C5540D50792770EF94940
15073	5	43	\N	12949	70147	\N	51.945754000000001	город Горно-Алтайск, Социалистическая, 21		0101000020E610000043FE99417C7C5540D50792770EF94940
15063	5	43	\N	12949	70369	\N	51.945754000000001	город Горно-Алтайск, П.Сухова, 2		0101000020E610000043FE99417C7C5540D50792770EF94940
15071	5	43	\N	12949	70366	\N	51.945754000000001	город Горно-Алтайск, П.Кучияк, 61		0101000020E610000043FE99417C7C5540D50792770EF94940
15077	5	43	\N	12949	70407	\N	51.945754000000001	город Горно-Алтайск, Льва Толстого, 72		0101000020E610000043FE99417C7C5540D50792770EF94940
15072	5	43	\N	12949	70316	\N	51.945754000000001	город Горно-Алтайск, Ленкина, 1		0101000020E610000043FE99417C7C5540D50792770EF94940
15076	5	43	\N	12949	70154	\N	51.945754000000001	город Горно-Алтайск, Ленина, 79		0101000020E610000043FE99417C7C5540D50792770EF94940
14850	5	43	\N	12949	70154	\N	51.945754000000001	город Горно-Алтайск, Ленина, 11		0101000020E610000043FE99417C7C5540D50792770EF94940
14756	5	43	\N	12949	70154	\N	51.945754000000001	город Горно-Алтайск, Ленина, 195		0101000020E610000043FE99417C7C5540D50792770EF94940
15058	5	43	\N	12949	70197	\N	51.945754000000001	город Горно-Алтайск, Заводская, 3		0101000020E610000043FE99417C7C5540D50792770EF94940
14749	5	43	\N	12949	70140	\N	51.945754000000001	город Горно-Алтайск, Больничная, 13		0101000020E610000043FE99417C7C5540D50792770EF94940
15074	5	43	\N	12949	70336	\N	51.945754000000001	город Горно-Алтайск, Барнаульская, 8		0101000020E610000043FE99417C7C5540D50792770EF94940
94873	5	43	687	32526	74277	\N	51.203051260742498	Шебалинский район, село Шыргайты, ул.Песчаная, д.28	Россия, Республика Алтай, Шебалинский район, поселок Шыргайту	0101000020E610000073B8567BD8525540C6353E93FD994940
15212	5	43	323	3254	70507	\N	51.405918	с. Чемал, Советская, 3		0101000020E6100000693BA6EECA805540CA6DFB1EF5B34940
94889	5	43	687	5733	70375	\N	51.295304000000002	Шебалинский район, село Шебалино, Советская, 11А		0101000020E61000004B5B5CE3336B554062307F85CCA54940
15250	5	43	687	5381	70277	\N	51.566684000000002	Республика Алтай, Шебалинский район, село Черга, Октябрьская, 122		0101000020E61000009818CBF44B6455404F95EF1989C84940
15249	5	43	687	60267	74203	\N	51.5115061438363	Республика Алтай, Шебалинский район, село Улус-Черга, Советская, 44	Россия, Республика Алтай, Шебалинский район, поселок Улусчерга	0101000020E6100000DF313CF6B35C554098DA520779C14940
94890	5	43	687	5941	71726	\N	51.126216999999997	Шебалинский район, село Топучая, Центральная, 32		0101000020E6100000D122DBF97E6555408099EFE027904940
15258	5	43	687	5785	74159	\N	51.417147999999997	Республика Алтай, Шебалинский район, село Мыюта, Трактовая, 8Г		0101000020E610000033F9669B1B685540C0CB0C1B65B54940
15248	5	43	687	5242	74177	\N	51.409449836874799	Республика Алтай, Шебалинский район, село Мухор-Черга, Заречная, 13	Россия, Республика Алтай, Шебалинский район, поселок Мухор-Черга	0101000020E6100000DD0A61359656554071AC8BDB68B44940
15247	5	43	687	5195	71013	\N	51.411501999999999	Республика Алтай, Шебалинский район,село Мариинск, Центральная, 14		0101000020E6100000EBAA402D063E55408A1EF818ACB44940
15264	5	43	687	6119	74222	\N	51.344208999999999	Республика Алтай, Шебалинский район, село Малая-Черга, Школьная, 6		0101000020E61000009109F8359263554093FE5E0A0FAC4940
94874	5	43	687	5988	74253	\N	51.204554999999999	Шебалинский район, село Кумалыр, ул.Центральная, 38		0101000020E6100000EEAF1EF7AD675540DC9DB5DB2E9A4940
94888	5	43	687	4787	74221	\N	51.115305999999997	Шебалинский район, село Каспа, Телесова, 44		0101000020E61000003927F6D03E8055402B84D558C28E4940
15252	5	43	687	5388	74259	\N	51.625883000000002	Шебалинский район, село Камлак, ул.Центральная, д.71А		0101000020E6100000F5F6E7A2216B5540AA0F24EF1CD04940
15255	5	43	687	5624	71326	\N	51.507675999999996	Республика Алтай, Шебалинский район, село Камай, Центральная, 5		0101000020E6100000E0BBCD1B27705540677BF486FBC04940
15246	5	43	687	5139	70847	\N	51.443365999999997	Республика Алтай, Шебалинский район, село Ильинка, Центральная, 65		0101000020E6100000EFA99CF69446554044149337C0B84940
15260	5	43	687	5844	74250	\N	51.271028999999999	Шебалинский район, село Дьектиек, ул.Школьная, д.4		0101000020E610000042E90B21E766554040A20914B1A24940
15265	5	43	687	6133	74165	\N	51.372055000000003	Республика Алтай, Шебалинский район, село Верх-Черга, Центральная, 18		0101000020E61000008EE9094B3C5D55401AA88C7F9FAF4940
15240	5	43	687	60265	74190	\N	51.234033728116501	"Республика Алтай, муниципальное образование ""Шебалинский район"", Верх-Апшуяхтинское сельское поселение, Центральная, 45"	Россия, Республика Алтай, Шебалинский район, поселок Верх-Апшуяхта	0101000020E6100000E1D39CBCC879554077137CD3F49D4940
15242	5	43	687	4893	74233	\N	51.119046605390999	Шебалинский район, село Беш-Озек, ул.Центральная, д.20	Россия, Республика Алтай, Шебалинский район, поселок Беш-Озек	0101000020E610000025B37A87DB4F5540EDD79DEE3C8F4940
15245	5	43	687	5076	70499	\N	51.276364999999998	Республика Алтай, Шебалинский район, село Барагаш, Партизанская, 1		0101000020E6100000912BF52C084D55402861A6ED5FA34940
15254	5	43	687	5542	74235	\N	51.519390999999999	Шебалинский район, село Актел, ул.Молодежная, д.1В		0101000020E6100000E99E758D966A55401A6B7F677BC24940
15229	5	43	280	4125	71177	\N	51.823900000000002	Чойский район, Ыныргинское с/поселение, с.Ынырга, Тихоновского, 8		0101000020E610000055DE8E705AB255405396218E75E94940
15227	5	43	280	4125	71177	\N	51.823900000000002	с.Ынырга, Тихоновского, 8		0101000020E610000055DE8E705AB255405396218E75E94940
15223	5	43	280	3898	70773	\N	52.011285000000001	с.Чоя, Социалистическая, 28		0101000020E61000007B8505F703A35540BAF770C971014A40
15224	5	43	280	3898	70516	\N	52.011285000000001	с.Чоя, Ленина, 38		0101000020E61000007B8505F703A35540BAF770C971014A40
15230	5	43	280	4286	71219	\N	52.036095000000003	с.Ускуч, Заречная, 1		0101000020E610000040DB6AD619BA55404A46CEC29E044A40
15231	5	43	280	60274	74228	\N	51.656846999999999	"Республика Алтай, муниципальное образование ""Чойский район, Уйменское сельское поселение, Центральная, 6"	Россия, Республика Алтай, Чойский район, поселок Уймень	0101000020E61000000C570740DCBA5540E4BCFF8F13D44940
15234	5	43	280	4509	74189	\N	52.006273	с.Туньжа, Центральная, 22		0101000020E610000078B306EFAB9D554085ECBC8DCD004A40
15226	5	43	280	1181	71209	\N	52.035037000000003	с.Советское, Совхозная, 10		0101000020E6100000087250C24CA755403293A8177C044A40
15236	5	43	280	4543	70681	\N	51.882438999999998	с.Сейка, Школьная, 37 (а)		0101000020E6100000F3C64961DEAE554083DBDAC2F3F04940
15235	5	43	280	4543	70681	\N	51.882438999999998	с.Сейка, ул.Школьная, 37а		0101000020E6100000F3C64961DEAE554083DBDAC2F3F04940
15233	5	43	280	4364	70861	\N	51.939281199958302	с. Паспаул, Трактовая, 36	Россия, Республика Алтай, Чойский район, поселок Паспаул	0101000020E610000088D68A36C795554089601C5C3AF84940
15232	5	43	280	4364	70861	\N	51.935201460645402	с.Паспаул, Трактовая, 36	Россия, Республика Алтай, Чойский район, поселок Паспаул	0101000020E6100000889E94490D965540DF1797AAB4F74940
15225	5	43	280	3985	71717	\N	52.060039000000003	с.Киска, Дружная, 1		0101000020E6100000018750A5669F554006BEA25BAF074A40
15238	5	43	280	4644	70786	\N	51.765512999999999	Республика Алтай, с.Каракокша, ул.Тартыкова, 32		0101000020E6100000EECD6F9868AC5540D8D47954FCE14940
15237	5	43	280	4644	70786	\N	51.765512999999999	с.Каракокша, Тартыкова, 32		0101000020E6100000EECD6F9868AC5540D8D47954FCE14940
15222	5	43	280	3868	74249	\N	52.028360999999997	Чойский район, Чойское с/поселение, с.Гусевка, Зеленая, 9		0101000020E6100000FBCDC47421A25540ADBD4F55A1034A40
94887	5	43	323	3478	70470	\N	51.462471000000001	Чемальский район, с. Элекмонар, Советская, 1		0101000020E61000001BF5108DEE805540992CEE3F32BB4940
15216	5	43	323	3478	70470	\N	51.462471000000001	с. Элекмонар, Советская, 142		0101000020E61000001BF5108DEE805540992CEE3F32BB4940
15215	5	43	323	3478	70470	\N	51.462471000000001	с. Элекмонар, Советская, 35		0101000020E61000001BF5108DEE805540992CEE3F32BB4940
15207	5	43	323	3036	71189	\N	51.107598000000003	с. Эдиган, ул. Центральная, 10		0101000020E6100000056A317898905540B98E71C5C58D4940
94886	5	43	323	1529	70747	\N	51.58896	Чемальский район, с. Чепош, Кучияк, 29		0101000020E6100000868DB27E337555407A53910A63CB4940
15213	5	43	323	3254	70507	\N	51.405918	с. Чемал, Советская, 48		0101000020E6100000693BA6EECA805540CA6DFB1EF5B34940
15192	5	43	323	2183	74257	\N	51.646481000000001	Чемальский район, с. Усть-Сема, Зеленая, 2		0101000020E6100000DB4DF04DD3705540213EB0E3BFD24940
15219	5	43	323	3703	71509	\N	51.523902	с. Узнезя, Новые Черемушки, 13	Россия, Республика Алтай, Чемальский район, поселок Узнезя	0101000020E6100000054EB6813B7C55408D2782380FC34940
15221	5	43	323	46162	74158	\N	51.546025999999998	с. Катунь, Сосновая, 5		0101000020E61000006937FA980F7A55400262122EE4C54940
15209	5	43	323	3137	71724	\N	51.339759000000001	с. Толгоек, ул. Энергетиков, 4		0101000020E6100000B98E71C5C5835540C6C210397DAB4940
14687	5	43	323	10025	71428	\N	51.053497999999998	с. Ороктой, Центральная, 17		0101000020E610000036CCD078228755406133C005D9864940
15203	5	43	323	2812	74239	\N	51.026857	Чемальский район, с. Куюс, Центральная, 17		0101000020E61000005B5F24B4E58E55409755D80C70834940
15208	5	43	323	45884	71203	\N	51.217306999999998	с. Еланда, ул. Катунская, 30		0101000020E61000006C3F19E3C38555408F183DB7D09B4940
94885	5	43	323	1482	71110	\N	51.630735999999999	Чемальский район, с. Бешпельтир, Центральная, 31		0101000020E610000021CA17B4907F554076340EF5BBD04940
15217	5	43	323	3613	74217	\N	51.435079000000002	с. Аюла, Центральная, 17		0101000020E6100000001FBC76697E554094162EABB0B74940
15220	5	43	323	3783	71175	\N	51.535366000000003	с. Аскат, Озерная, 20		0101000020E61000009D66817687795540F7B182DF86C44940
15218	5	43	323	3662	71476	\N	51.501520999999997	с. Анос, Центральная, 51		0101000020E6100000EB3713D3857C5540ECA012D731C04940
15199	5	43	253	32949	\N	\N	50.264684397168203	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Чендекское сельское поселение, Медпункт"	Россия, Республика Алтай, Усть-Коксинский район, поселок Чендек	0101000020E61000003DF372D87D7D554022E3512AE1214940
15206	5	43	253	32949	74153	\N	50.265289587735303	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Чендекское сельское поселение, Центральная, 6 кв 2"	Россия, Республика Алтай, Усть-Коксинский район, поселок Чендек	0101000020E610000063D34A21907D554059FAD005F5214940
15198	5	43	253	32949	74153	\N	50.266001579379797	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Чендекское сельское поселение, Центральная, 48"	Россия, Республика Алтай, Усть-Коксинский район, поселок Чендек	0101000020E6100000EB8B84B69C7D5540D655815A0C224940
15176	5	43	253	32782	70457	\N	50.270174456172597	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Амурское сельское поселение, переулок Школьный, 8"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E6100000E00F3FFF3D675540601DC70F95224940
15186	5	43	253	32782	74288	\N	50.269580824667699	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Усть-Коксинское сельское поселение, Школьная, 8"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E6100000ADDF4C4C17675540BE4F55A181224940
15200	5	43	253	32782	70463	\N	50.269844387229902	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Чендекское сельское поселение, Центральная, 15"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E61000006BD3D85E0B675540CB82893F8A224940
15194	5	43	253	32782	70463	\N	50.270064433447303	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Верх-Уймонское сельское поселение, Центральная, 28"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E61000007FDDE9CE13675540D9E9077591224940
15185	5	43	253	32782	70463	\N	50.268469075206902	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Усть-Коксинское сельское поселение, Центральная, 23"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E6100000F3E505D847675540B37E33315D224940
15178	5	43	253	32782	70463	\N	50.2680839806835	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Усть-Коксинское сельское поселение, Центральная, 3"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E6100000566133C0056755405A4A969350224940
15182	5	43	253	32782	70265	\N	50.268138994378603	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Усть-Коксинское сельское поселение, /Харитошкина, 5"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E6100000B8E68EFE976755401DE4F56052224940
15201	5	43	253	32782	70871	\N	50.267533999999998	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Катандинское сельское поселение, Советская, 130"		0101000020E6100000581CCEFC6A675540B648DA8D3E224940
15179	5	43	253	32782	70435	\N	50.267533999999998	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Усть-Коксинское сельское поселение, Набережная, 3"		0101000020E6100000581CCEFC6A675540B648DA8D3E224940
15183	5	43	253	32782	74219	\N	50.268634222205897	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Усть-Коксинское сельское поселение, переулок Клубный, 6/2"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E61000007FDDE9CE13675540FD4B529962224940
15205	5	43	253	32782	74243	\N	50.268028966924597	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Таллинское сельское поселение, Заря Алтая, 1"	Россия, Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса	0101000020E610000059FD11860167554096B036C64E224940
15191	5	43	253	59425	71468	\N	50.203352681634698	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Верх-Уймонское сельское поселение, Центральная, 11"	Россия, Республика Алтай, Усть-Коксинский район, поселок Тихонькая	0101000020E6100000B22E6EA30173554091459A78071A4940
15172	5	43	253	60270	74212	\N	50.504376930293503	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Талдинское сельское поселение, центральная, 20"	Россия, Республика Алтай, Усть-Коксинский район, поселок Талда	0101000020E61000009BE271512D41554063EDEF6C8F404940
15189	5	43	253	60250	74122	\N	50.2315606710183	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Огневское сельское поселение, Скосырева, 2""а"""	Россия, Республика Алтай, Усть-Коксинский район, поселок Огневка	0101000020E610000001F9122A38615540B80375CAA31D4940
15187	5	43	253	60250	74263	\N	50.23128248615	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Огневское сельское поселение, Садовая, 27"	Россия, Республика Алтай, Усть-Коксинский район, поселок Огневка	0101000020E61000002EAD86C43D615540A51309A69A1D4940
15188	5	43	253	60250	74232	\N	50.231891006709297	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Огневское сельское поселение, Новая, 9"	Россия, Республика Алтай, Усть-Коксинский район, поселок Огневка	0101000020E6100000EDBAB722316155404D9EB29AAE1D4940
15202	5	43	253	60255	74139	\N	50.167836341043298	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Катандинское сельское поселение, Сухова, 45"	Россия, Республика Алтай, Усть-Коксинский район, поселок Катанда	0101000020E6100000E3FC4D28448B5540B58B69A67B154940
15204	5	43	253	60255	74160	\N	50.166992477099903	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Катандинское сельское поселение, Ленина, 46"	Россия, Республика Алтай, Усть-Коксинский район, поселок Катанда	0101000020E6100000728C648F508B5540C9586DFE5F154940
15184	5	43	253	59494	71683	\N	50.323271929502397	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Усть-Коксинское сельское поселение, Заречная, 2"	Россия, Республика Алтай, Усть-Коксинский район, поселок Кастахта	0101000020E61000009082A7902B6F554034DB15FA60294940
15173	5	43	253	60252	74215	\N	50.394375426185	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Карагайское сельское поселение, Школьная, 30"	Россия, Республика Алтай, Усть-Коксинский район, поселок Карагай	0101000020E6100000BAA29410AC27554014AE47E17A324940
15174	5	43	253	60252	74127	\N	50.393991034831501	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Карагайское сельское поселение, Зеленая, 1"	Россия, Республика Алтай, Усть-Коксинский район, поселок Карагай	0101000020E61000007F129F3BC12755408CF50D4C6E324940
15197	5	43	253	60259	74155	\N	50.223266146841297	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Горбуновское сельское поселение, Центральная, 39"	Россия, Республика Алтай, Усть-Коксинский район, поселок Горбуново	0101000020E610000032056B9C4D7555408527F4FA931C4940
15195	5	43	253	60259	74155	\N	50.221724280242398	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Горбуновское сельское поселение, Центральная, 1"	Россия, Республика Алтай, Усть-Коксинский район, поселок Горбуново	0101000020E61000002E54FEB5BC755540815EB873611C4940
15196	5	43	253	60259	74152	\N	50.221559077277298	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Горбуновское сельское поселение, Первомайская, 4"	Россия, Республика Алтай, Усть-Коксинский район, поселок Горбуново	0101000020E610000019AE0E80B87555403691990B5C1C4940
15193	5	43	253	32898	74120	\N	50.212253005407902	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Верх-Уймонское сельское поселение, Школьная, 11"	Россия, Республика Алтай, Усть-Коксинский район, поселок Верх-Уймон	0101000020E610000079CE16105A6F55402BBD361B2B1B4940
15190	5	43	253	32898	74163	\N	50.211977611845398	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Верх-Уймонское сельское поселение, Центральная, 5"	Россия, Республика Алтай, Усть-Коксинский район, поселок Верх-Уймон	0101000020E610000003B16CE6906F55405ABC5818221B4940
15177	5	43	253	60257	74147	\N	50.3993471553826	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Амурское сельское поселение, переулок Новый, 9"	Россия, Республика Алтай, Усть-Коксинский район, поселок Амур	0101000020E6100000C1E44691B5475540BB6070CD1D334940
15175	5	43	253	60257	74145	\N	50.399402445067302	"Республика Алтай, муниципальное образование ""Усть-Коксинский район"", Амурское сельское поселение, Советская, 45"	Россия, Республика Алтай, Усть-Коксинский район, поселок Амур	0101000020E6100000AC915D69194855407FFACF9A1F334940
15162	5	43	29	406	70240	\N	51.034464999999997	с. Яконур, Кудачина, 28		0101000020E6100000FA804067D2375540A6ED5F5969844940
15159	5	43	29	228	70423	\N	50.909129	с.Ябоган, Ленинская, 18		0101000020E610000009FF2268CC4455402F6CCD565E744940
15166	5	43	29	680	71643	\N	51.355044294032197	с. Черный-Ануй, Центральная, 7	Россия, Республика Алтай, Усть-Канский район, поселок Черный Ануй	0101000020E6100000D8B8FE5D9F2E55400D52F01472AD4940
15164	5	43	29	566	71101	\N	51.234206	с. Усть-Мута, Центральная, 46		0101000020E6100000E603029D4930554074435376FA9D4940
15149	5	43	29	32186	71628	\N	51.031875999999997	"Республика Алтай, муниципальное образование ""Усть-Канский район"", Талицкое сельское поселение, с.Усть-Кумир, Зеленая, 27"		0101000020E610000084656CE8661255407EC3448314844940
15156	5	43	29	49276	70087	\N	50.930331000000002	с.Усть-Кан, Первомайская, 1		0101000020E6100000323B8BDEA93055403DBA111615774940
15152	5	43	29	32300	71050	\N	50.992905	с. Тюдрала, Мира, 34		0101000020E61000007CB94F8E021F55407784D382177F4940
15151	5	43	29	49209	71044	\N	51.036991	с. Талица, Партизанская, 12		0101000020E61000004DF564FED1135540889FFF1EBC844940
15150	5	43	29	32201	71031	\N	51.064796999999999	с.Санаровка, Волонковская, 17		0101000020E6100000620FED630519554080F0A1444B884940
15161	5	43	29	325	74240	\N	50.912177999999997	Усть-Канский район, с.Оро, Школьная, 2		0101000020E610000005A6D3BA0D405540BA10AB3FC2744940
15157	5	43	29	35	71348	\N	50.796970000000002	с.Мендур-Соккон, Казакова, 23		0101000020E610000028F1B913EC33554052F2EA1C03664940
15158	5	43	29	167	70768	\N	50.803671000000001	с. Кырлык, Победы, 147		0101000020E6100000863B17467A3C55402FDFFAB0DE664940
15171	5	43	29	59447	71450	\N	51.097006066151202	"Республика Алтай, муниципальное образование ""Усть-Канский район"", Коргонское сельское поселение, Набережная, 18"	Россия, Республика Алтай, Усть-Канский район, поселок Коргон	0101000020E6100000D6C8AEB48C02554005C24EB16A8C4940
15154	5	43	29	32380	71341	\N	50.972859999999997	с.Козуль, Молодежная, 18		0101000020E6100000F7CDFDD5E32B554014CB2DAD867C4940
15163	5	43	29	469	71095	\N	51.180447000000001	с. Келей, Тан-Чолмон, 62		0101000020E6100000874F3A9160305540A6D425E318974940
15153	5	43	29	32333	74207	\N	50.951177999999999	с. Кайсын, Центральная, 3		0101000020E6100000785E2A36E62555405C566133C0794940
15148	5	43	29	49172	71332	\N	51.047400000000003	с.Владимировка, Центральная, 33		0101000020E6100000139ED0EB4F0D55404BEA043411864940
15160	5	43	29	279	71353	\N	50.926958999999997	с.Верх-Ябоган, Нагорная, 1		0101000020E6100000F0F96184F04E5540CEDDAE97A6764940
15165	5	43	29	572	71636	\N	51.1958014259911	с. Верх-Мута, Чапаева, 10	Россия, Республика Алтай, Усть-Канский район, поселок Верх-Мута	0101000020E6100000228C9FC6BD2A554016C3D50110994940
15170	5	43	29	897	74208	\N	51.143794	с. Верх-Ануй, Ануйская, 63		0101000020E61000003271AB20063F554036AE7FD767924940
15169	5	43	29	32702	70853	\N	51.232941720269203	с. Бело-Ануй, Советская, 64	Россия, Республика Алтай, Усть-Канский район, поселок Белый Ануй	0101000020E610000058AB764D48395540B3EE1F0BD19D4940
15130	5	43	1911	31274	74276	\N	50.616097000000003	Улаганский район,  с.Язула, Набережная, 1		0101000020E6100000ED10FFB0A5315640F5143944DC4E4940
15143	5	43	1911	31867	74262	\N	50.317583999999997	Улаганский район, с.Чибит, Кокышева, 10		0101000020E6100000EE26F8A6E9E05540CEDDAE97A6284940
15147	5	43	1911	32053	74241	\N	50.621682579936603	Улаганский район, с.Чибиля, Набережная, 38	Россия, Республика Алтай, Улаганский район, поселок Чибиля	0101000020E61000001B2D077AA8FA554055BDFC4E934F4940
15144	5	43	1911	31936	74229	\N	50.631298000000001	Улаганский район, с.Улаган, А.В.Санаа, 18		0101000020E61000004888F2052DFD5540DE03745FCE504940
15128	5	43	1911	31194	74254	\N	50.519579	Улаганский район, с.Саратан, Школьная, 13		0101000020E61000003C4CFBE6FE1056401D588E9081424940
15135	5	43	1911	31515	74238	\N	50.835104999999999	Улаганский район, с.Паспарта, Куюкова, 62		0101000020E61000001C075E2D77F85540F0DC7BB8E46A4940
15139	5	43	1911	31678	74268	\N	51.096479000000002	Улаганский район, с.Коо, Южная, 12		0101000020E6100000D4F2035779F955401AE0826C598C4940
15126	5	43	1911	31112	74252	\N	50.674791999999997	Улаганский район, с.Кара-Кудюр, Набережная, 4		0101000020E6100000EC6AF294D5F455401CCD91955F564940
15136	5	43	1911	31592	74230	\N	51.286405000000002	Улаганский район, с.Балыкча, Центральная, 20		0101000020E61000009BE3DC26DCED5540983446EBA8A44940
15132	5	43	1911	31370	74264	\N	50.755350999999997	Улаганский район,  с.Балыктуюль, Центральная, 91		0101000020E61000001BBCAFCA850256401D007157AF604940
15141	5	43	1911	31793	74242	\N	50.321840000000002	Улаганский район, с.Акташ, Ст.Мохова, 21		0101000020E6100000228D0A9C6CE75540B745990D32294940
14737	5	43	851	12409	74170	\N	51.770238999999997	с. Яйлю, Школьная, 10		0101000020E61000000AD80E46ECE65540478D093197E24940
15118	5	43	851	30676	\N	\N	51.966183999999998	с. Чуйка, школа		0101000020E610000084F4143944E0554090F5D4EAABFB4940
14724	5	43	851	11801	71256	\N	51.858587999999997	с. Усть-Пыжа, Центральная, 43		0101000020E6100000E04A766C04C65540785E2A36E6ED4940
15125	5	43	851	31050	74206	\N	52.354497000000002	Удаловка, Береговая, 14		0101000020E6100000098CF50D4CBC5540DBC35E28602D4A40
14758	5	43	851	13312	70388	\N	52.259974999999997	Турочак, Советская, 75		0101000020E6100000BEF73768AFC7554088635DDC46214A40
14757	5	43	851	13312	70388	\N	52.259974999999997	Турочак село, Советская, 75		0101000020E6100000BEF73768AFC7554088635DDC46214A40
14723	5	43	851	11733	71251	\N	52.005242000000003	с. Тулой, Строительная, 1		0101000020E6100000098A1F63EEC75540674815C5AB004A40
14872	5	43	851	18964	71616	\N	52.121521000000001	с. Тондошка, Береговая, 18		0101000020E6100000AF9811DE1EC755407C6308008E0F4A40
15120	5	43	851	6335	\N	\N	52.293444000000001	Турочакский р-н, с. Суранаш, ФАП		0101000020E61000001494A2957BF055408D9AAF928F254A40
14763	5	43	851	60281	74287	\N	52.188024420885498	с.Санькино, Боровая, 4		0101000020E6100000C5591135D1C655407A6EA12B11184A40
15123	5	43	851	30965	74166	\N	52.465553999999997	с. Озеро-Куреево, Центральная, 20		0101000020E61000005A68E7340BB05540D0420246973B4A40
15121	5	43	851	48728	74226	\N	52.332417999999997	с. Майск, Центральная, 3 Б		0101000020E61000009C887E6DFD085640054D4BAC8C2A4A40
15119	5	43	851	30744	\N	\N	52.126717999999997	с. Курмач-Байгол, школа		0101000020E6100000FA997ADD22EA554042E8A04B38104A40
14722	5	43	851	11703	71599	\N	51.908882417940099	с. Кебезень, Центральная, 34	Россия, Республика Алтай, Турочакский район, поселок Кебезень	0101000020E6100000D998D71187C6554027F6D03E56F44940
14760	5	43	851	13444	74184	\N	52.376449999999998	Каяшкан, Центральная, 33		0101000020E61000009088299144D75540234A7B832F304A40
15122	5	43	851	30918	71625	\N	52.458125000000003	с. Каначак, Береговая, 5		0101000020E6100000766C04E275AE5540713D0AD7A33A4A40
14738	5	43	851	12455	70275	\N	51.782375999999999	с. Иогач, Школьная, 8		0101000020E6100000236937FA98D05540709692E524E44940
15124	5	43	851	48766	74200	\N	52.4384324327077	Дмитриевка, ул. Морозова, дом. 41	Россия, Республика Алтай, Турочакский район, поселок Дмитриевка	0101000020E61000001E1A16A3AEBA55408BC22E8A1E384A40
14707	5	43	851	10991	71274	\N	52.034865000000003	с. Верх-Бийск, Школьная, 13		0101000020E6100000162F1686C8C555403563D17476044A40
15117	5	43	851	30653	74225	\N	51.930650999999997	с. Бийка, Центральная, клуб	Россия, Республика Алтай, Турочакский район, поселок Бийка	0101000020E61000000B630B410EEA5540AE7E6C921FF74940
14746	5	43	851	12838	71293	\N	51.792369131678903	с. Артыбаш, Бийская, 13	Россия, Республика Алтай, Турочакский район, поселок Артыбаш	0101000020E6100000F435CB65A3D055409FAEEE586CE54940
14725	5	43	195	60279	74279	\N	50.747867999999997	Онгудайский район, с.Малый Яломан, ул.Садовая, д.19	Россия, Республика Алтай, Онгудайский район	0101000020E6100000CC272B86AB975540CADC7C23BA5F4940
14729	5	43	195	45507	71648	\N	50.684243000000002	с.Хабаровка, Центральная, 43		0101000020E6100000F48AA71E699255402BC24D4695574940
14730	5	43	195	12086	71658	\N	50.708765999999997	с.Улита, Советская, 26		0101000020E61000002F6CCD565E8D5540244223D8B85A4940
14743	5	43	195	60275	74234	\N	50.838453959159402	с.Туэкта, Семенова, 66	Россия, Республика Алтай, Онгудайский район, поселок Туекта	0101000020E6100000035B25581C785540A699EE75526B4940
14751	5	43	195	13020	71301	\N	50.839081	с.Теньга, Центральная, 31		0101000020E6100000D78A36C7B9695540F5D89601676B4940
14747	5	43	195	12892	71408	\N	50.841197000000001	с.Талда, Яш-Корбо, 19а		0101000020E610000042CEFBFF38715540253FE257AC6B4940
14732	5	43	195	12168	70383	\N	50.747737000000001	с.Онгудай, Советская, 80		0101000020E6100000D5CE30B5A58855402C8194D8B55F4940
14752	5	43	195	45966	74224	\N	50.909685000000003	с.Озерное, Центральная, 11		0101000020E6100000CF4A5AF10D655540B554DE8E70744940
15155	5	43	195	45966	74161	\N	50.909685000000003	с.Озерное, Казакова, 3		0101000020E6100000CF4A5AF10D655540B554DE8E70744940
14736	5	43	195	12369	71603	\N	50.854488000000003	с.Нижняя-Талда, Талду, 38		0101000020E6100000A5F9635A9B7E55408869DFDC5F6D4940
14744	5	43	195	45805	74180	\N	50.853560999999999	с.Нефтебаза, Новая, 25		0101000020E61000003BAC70CB477555400E12A27C416D4940
14716	5	43	195	49547	74246	\N	50.449218999999999	с.Малая Иня, Подгорная, 1		0101000020E6100000A5DAA7E331AB5540F4DE180280394940
14728	5	43	195	11960	71266	\N	50.624464000000003	с.Купчегень, Трактовая, 13		0101000020E610000016BD5301F79A5540C2C3B46FEE4F4940
14742	5	43	195	12655	74191	\N	50.687336999999999	с.Кулада, Этенова, 32		0101000020E61000000E15E3FC4D725540562AA8A8FA574940
14755	5	43	195	13229	71457	\N	50.682245999999999	с.Каярлык, Меес-Дьяны, 40		0101000020E6100000FCE1E7BF07655540D5E940D653574940
14739	5	43	195	724	70883	\N	50.814399999999999	с.Каракол, Чорос-Гуркина, 43		0101000020E6100000AC55BB26A47C554063EE5A423E684940
15167	5	43	195	724	74258	\N	50.814399999999999	с. Каракол, Центральная, 11		0101000020E6100000AC55BB26A47C554063EE5A423E684940
14753	5	43	195	60285	74293	\N	50.815218999999999	с.Кара-Коба, Подгорная, 5	Россия, Республика Алтай, Онгудайский район, поселок Кара Кобы	0101000020E6100000E0BBCD1B27655540F609A01859684940
14714	5	43	195	11300	71669	\N	50.399458000000003	с.Иодро, Центральная, 9		0101000020E610000053CDACA580BE55401310937021334940
14717	5	43	195	49562	71285	\N	50.450957000000002	с.Иня, Подгорная, 40		0101000020E610000016A5846055A855407E737FF5B8394940
14715	5	43	195	11368	71605	\N	50.322817000000001	с.Инегень, Центральная, 14		0101000020E61000000B992B836AAC5540E2CB441152294940
14754	5	43	195	13167	70475	\N	50.770591000000003	с.Ело, Почтовая, 21		0101000020E6100000B6F5D37FD6635540C5CBD3B9A2624940
14741	5	43	195	12618	74175	\N	50.740570168441501	с.Боочи, 60-лет Победы, 31	Россия, Республика Алтай, Онгудайский район, поселок Боочи	0101000020E61000004B033FAA6174554009336DFFCA5E4940
14727	5	43	195	11918	71261	\N	50.488641999999999	с.Большой Яломан, Центральная, 45		0101000020E61000006D567DAEB69A5540DCB930D28B3E4940
14740	5	43	195	12559	74164	\N	50.789544999999997	с.Бичикту-Боом, Сетерлинская, 21		0101000020E610000051A39064567A554033DC80CF0F654940
15108	5	43	863	30185	70829	\N	51.725150999999997	село Усть-Муны, ул.Кошурникова, 23		0101000020E61000002C7DE882FA6F5540B2D47ABFD1DC4940
15116	5	43	863	30601	71657	\N	51.683480000000003	село Урлу-Аспак, пер. Школьный, Здание школы		0101000020E61000004A253CA1D78D55402CBCCB457CD74940
14708	5	43	863	11011	\N	\N	51.763266000000002	село Средний Сайдыс, Здание Дома культуры	Россия, Республика Алтай, Майминский район, поселок Средний Сайдыс	0101000020E610000011C30E63D28955400A1346B3B2E14940
15105	5	43	863	30034	70237	\N	51.886969000000001	село Соузга, ул.Трактовая, 11		0101000020E61000004C8BFA24777655406DC83F3388F14940
15110	5	43	863	48533	\N	\N	52.032471999999999	село Подгорное, Здание Дома культуры	Россия, Республика Алтай, Майминский район, поселок Подгорное	0101000020E6100000645A9BC6F67855409204E10A28044A40
15107	5	43	863	30101	70810	\N	51.826338	село Манжерок, ул.Советская, Здание средней школы		0101000020E61000000A302C7FBE71554095B88E71C5E94940
15106	5	43	863	30101	70837	\N	51.826338	село Манжерок, ул.Дружбы, здание Дома культуры		0101000020E61000000A302C7FBE71554095B88E71C5E94940
15096	5	43	863	6509	70101	\N	52.007281999999996	село Майма, ул. Советская, 50		0101000020E61000006325E65949795540BBECD79DEE004A40
14713	5	43	863	6509	70101	\N	52.007281999999996	село Майма, ул. Советская, 79		0101000020E61000006325E65949795540BBECD79DEE004A40
14711	5	43	863	6509	70101	\N	52.007281999999996	село Майма, ул.Советская, 190		0101000020E61000006325E65949795540BBECD79DEE004A40
14712	5	43	863	6509	70272	\N	52.007281999999996	село Майма, ул. Подгорная, 4		0101000020E61000006325E65949795540BBECD79DEE004A40
14861	5	43	863	6509	74265	\N	52.0018765700122	Майминский район, село Майма, ул.Мира, 10	Россия, Республика Алтай, Майминский район, поселок Майма	0101000020E61000007558E1968F795540ABCE6A813D004A40
15060	5	43	863	6509	70819	\N	52.007281999999996	село Майма, ул.Механизаторов, 12		0101000020E61000006325E65949795540BBECD79DEE004A40
15102	5	43	863	6509	70409	\N	52.007281999999996	село Майма, ул.Ленина, 89		0101000020E61000006325E65949795540BBECD79DEE004A40
15098	5	43	863	6509	70409	\N	52.007281999999996	село Майма, ул.Ленина, 15А		0101000020E61000006325E65949795540BBECD79DEE004A40
15097	5	43	863	6509	70409	\N	52.007281999999996	село Майма, ул.Ленина, 6		0101000020E61000006325E65949795540BBECD79DEE004A40
14706	5	43	863	6509	70409	\N	52.007281999999996	село Майма, ул.Ленина, 56		0101000020E61000006325E65949795540BBECD79DEE004A40
15100	5	43	863	6509	70832	\N	52.007281999999996	село Майма, ул.Зональная, 13		0101000020E61000006325E65949795540BBECD79DEE004A40
15099	5	43	863	6509	70929	\N	52.007281999999996	"село Майма, ул.Гидростроителей, Здание детского сада ""Оленёнок"""		0101000020E61000006325E65949795540BBECD79DEE004A40
15101	5	43	863	6509	70488	\N	52.007281999999996	село Майма, ул.50 лет Победы, Здание ПУ-49		0101000020E61000006325E65949795540BBECD79DEE004A40
15113	5	43	863	30379	70325	\N	51.890093	село Кызыл-Озёк, ул.Советская, Здание средней школы		0101000020E6100000D42B6519E27F554003B34291EEF14940
15112	5	43	863	30379	70325	\N	51.890093	село Кызыл-Озёк, ул.Советская, Здание начальной школы		0101000020E6100000D42B6519E27F554003B34291EEF14940
15103	5	43	863	29956	\N	\N	51.980924999999999	посёлок Карлушка, здание Дома культуры		0101000020E6100000CEA96400A8765540166A4DF38EFD4940
14710	5	43	863	11107	\N	\N	51.850183000000001	село Карасук, Здание Дома культуры	Россия, Республика Алтай, Майминский район, поселок Карасук	0101000020E6100000E86C01A1F5885540BE4EEACBD2EC4940
15104	5	43	863	48410	71322	\N	51.928874	посёлок Дубровка, ул.Школьная, здание Дома культуры		0101000020E61000001D5723BBD2755540670DDE57E5F64940
15109	5	43	863	30215	71664	\N	52.046985999999997	село Верх-Карагуж, ул.Заречная, 2		0101000020E6100000A67D737FF582554057AF22A303064A40
15114	5	43	863	30503	\N	\N	51.781970793820498	село Бирюля, Здание Дома культуры	Россия, Республика Алтай, Майминский район, поселок Бирюля	0101000020E6100000EB7420EBA9835540D0B52FA017E44940
15111	5	43	863	59414	70844	\N	51.976875304638398	село Алфёрово, ул.Центральная, Здание средней школы	Россия, Республика Алтай, Майминский район, поселок Алферово	0101000020E6100000B8E864A9F57F5540D7A3703D0AFD4940
15115	5	43	863	48613	\N	\N	51.737478000000003	село Александровка, Здание Дома культуры	Россия, Республика Алтай, Майминский район, поселок Александровка	0101000020E610000082380F27308755407FC2D9AD65DE4940
15080	5	43	841	28909	74236	\N	50.102116000000002	Чаган-Узун, Центральная, 19		0101000020E6100000C2D9AD6532175640FD321823120D4940
15089	5	43	841	29312	74271	\N	50.010719000000002	Теленгит-Сортогой, Центральная, 1		0101000020E610000060AE450BD02F564011397D3D5F014940
15090	5	43	841	32886	74273	\N	49.914582000000003	Тобелер, Советская, 21		0101000020E6100000CDACA580B432564051C1E10511F54840
15093	5	43	841	29486	74244	\N	49.715812	Ташанта, Пограничная, 9а		0101000020E6100000F0694E5E644C5640CC0A45BA9FDB4840
15081	5	43	841	28949	74270	\N	50.034852999999998	Ортолык, Кокышева, 31		0101000020E61000009A779CA2232056407095271076044940
15082	5	43	841	29004	74269	\N	49.989445000000003	Мухор-Тархата, Бухарова, 3		0101000020E610000079573D601E2256406A183E22A6FE4840
15079	5	43	841	28856	74274	\N	50.214097132912499	Кызыл-Таш, Белеекова, 24	Россия, Республика Алтай, Кош-Агачский район, поселок Кызыл-Таш	0101000020E6100000FA9CBB5D2FFC5540FB95CE87671B4940
14658	5	43	841	32738	74248	\N	50.232697000000002	Курай, Зеленая,3		0101000020E6100000F7CB272B86FB55404C70EA03C91D4940
15085	5	43	841	29091	74260	\N	49.996349000000002	Кош-Агач, Советская, 53		0101000020E61000007B849A21552A56407F33315D88FF4840
15086	5	43	841	29091	74247	\N	49.996349000000002	Кош-Агач, Новочуйская, 35		0101000020E61000007B849A21552A56407F33315D88FF4840
15087	5	43	841	29091	74275	\N	49.996349000000002	Кош-Агач, Молодежная, 11		0101000020E61000007B849A21552A56407F33315D88FF4840
15088	5	43	841	29091	74261	\N	49.996349000000002	Кош-Агач, Восточная, 1а		0101000020E61000007B849A21552A56407F33315D88FF4840
15084	5	43	841	29091	74256	\N	49.996349000000002	Кош-Агач, Абая, 20		0101000020E61000007B849A21552A56407F33315D88FF4840
15092	5	43	841	29429	74251	\N	49.913671999999998	Кокоря, Молодежная, 1		0101000020E6100000C30E63D2DF3F5640ADA23F34F3F44840
15091	5	43	841	29384	74267	\N	49.845109999999998	Жана-Аул, Абая, 9		0101000020E6100000DDB5847CD03A5640E3C281902CEC4840
15094	5	43	841	32924	74255	\N	49.706882	Беляши, Центральная, 4		0101000020E6100000C2D9AD6532DB5540C710001C7BDA4840
15083	5	43	841	29041	74266	\N	49.976662652003299	Кош-Агачский район, с. Бельтир, Школьная, 2	Россия, Республика Алтай, Кош-Агачский район, поселок Бельтир	0101000020E6100000BF7E880D160B56404C1B0E4B03FD4840
67348	5	53	\N	60029	73563	\N	54.954800965904901	д.Приветная, Новая, 3 А		0101000020E61000001422E010AA4B524014984EEB367A4B40
66410	5	53	\N	41	6651	\N	55.035564999999998	Омская область, город Омск, Советский административный округ, Волкова, 5б	Россия, Омская область, Омск, улица космонавта Волкова, 5б	0101000020E61000005AB8ACC266535240EDF0D7648D844B40
66389	5	53	\N	41	6358	\N	55.045042000000002	Омская область, город Омск, Советский административный округ, Энтузиастов, 11б	Россия, Омская область, Омск, улица Энтузиастов, 11б	0101000020E61000007AC7293A925252402579AEEFC3854B40
66396	5	53	\N	41	6525	\N	55.041404999999997	Омская область, город Омск, Советский административный округ, Энергетиков, 64	Россия, Омская область, Омск, улица Энергетиков, 64	0101000020E6100000CBA145B6F3515240087250C24C854B40
66307	5	53	\N	41	5586	\N	54.925794000000003	Омская область, город Омск, Ленинский административный округ, Шота Руставели, 1	Россия, Омская область, Омск, улица Шота Руставели, 1	0101000020E6100000D237691A145A5240A16AF46A80764B40
66492	5	53	\N	41	7481	\N	54.975563000000001	Омская область, город Омск, Чокана Валиханова, 17	Россия, Омская область, Омск, улица Чокана Валиханова, 17	0101000020E6100000715AF0A2AF5852400518963FDF7C4B40
66494	5	53	\N	41	7258	\N	54.978596000000003	Омская область, город Омск, Чкалова, 3	Россия, Омская область, Омск, улица Чкалова, 3	0101000020E610000044A51133FB5752408BFF3BA2427D4B40
66294	5	53	\N	41	5432	\N	54.929886000000003	Омская область, город Омск, Ленинский административный округ, Чайковского, 68	Россия, Омская область, Омск, улица Чайковского, 68	0101000020E61000002B16BF29AC5752400F81238106774B40
66293	5	53	\N	41	5432	\N	54.931126999999996	Омская область, город Омск, Ленинский административный округ, Чайковского, 5	Россия, Омская область, Омск, улица Чайковского, 5	0101000020E61000005516855D1458524017B6662B2F774B40
66484	5	53	\N	41	7391	\N	54.962426000000001	Омская область, город Омск, Циолковского, 1	Россия, Омская область, Омск, улица Циолковского, 1	0101000020E6100000B398D87C5C585240F96871C6307B4B40
66646	5	53	\N	41	30166	\N	54.888693055824298	д. Северная, Центральная, 3	Россия, Омская область, Омск, поселок Армейский, улица Центральная	0101000020E6100000FB95CE8767575240929735B1C0714B40
67327	5	53	\N	41	15442	\N	55.068195000000003	д.18 Партсъезд, Центральная, 44 А	Россия, Омская область, Омск, поселок Большие Поля, улица Центральная	0101000020E6100000DAA84E07B25A524018601F9DBA884B40
66265	5	53	\N	41	5085	\N	54.941848999999998	Омская область, город Омск, Ленинский административный округ, Озеро Хасан, 1	Россия, Омская область, Омск, улица Хасан Озеро, 1	0101000020E61000005FD38382525A524099620E828E784B40
66393	5	53	\N	41	6321	\N	55.033676999999997	Омская область, город Омск, Советский административный округ, 20 Партсъезда, 12	Россия, Омская область, Омск, улица ХХ Партсъезда, 12	0101000020E6100000F778211D1E5252404ED026874F844B40
66374	5	53	\N	41	6321	\N	55.031756999999999	Омская область, город Омск, Советский административный округ, 20 партсъезда, 48	Россия, Омская область, Омск, улица ХХ Партсъезда, 48	0101000020E610000030A182C30B515240A435069D10844B40
67878	5	53	245	45866	29329	\N	54.555751999999998	д. Путиловка, ул. Центральная, 32		0101000020E61000009545611745065240E257ACE122474B40
66377	5	53	\N	41	6339	\N	55.042653999999999	Омская область, город Омск, Советский административный округ, 19 Партсъезда, 37	Россия, Омская область, Омск, улица ХIХ Партсъезда, 35	0101000020E610000045A165DD3F5152409485AFAF75854B40
66238	5	53	\N	41	4744	\N	54.995488000000002	Омская область, город Омск, Кировский административный округ, Фугенфирова, 5а	Россия, Омская область, Омск, улица Фугенфирова, 5а	0101000020E61000004700378B17515240BDC799266C7F4B40
66237	5	53	\N	41	4744	\N	54.997166	Омская область, город Омск, Кировский административный округ, Фугенфирова, 11б	Россия, Омская область, Омск, улица Фугенфирова, 11	0101000020E6100000C5E74EB0FF5052407157AF22A37F4B40
66427	5	53	\N	41	6831	\N	54.994816999999998	Омская область, город Омск, Фрунзе, 71	Россия, Омская область, Омск, улица Фрунзе, 71	0101000020E61000003411363CBD5752409E40D829567F4B40
66258	5	53	\N	41	15479	\N	54.944823	Омская область, город Омск, Ленинский административный округ, Ф.Крылова, 4а	Россия, Омская область, Омск, улица Федора Крылова, 4а	0101000020E61000006325E659495852401AC1C6F5EF784B40
66271	5	53	\N	41	5157	\N	54.916791000000003	Омская область, город Омск, Ленинский административный округ, Усадебная, 13	Россия, Омская область, Омск, улица Усадебная, 13	0101000020E6100000F6B52E35425C52403222516859754B40
66387	5	53	\N	41	6368	\N	55.044423000000002	Омская область, город Омск, Советский административный округ, Белозерова, 5	Россия, Омская область, Омск, улица Тимофея Белозерова, 5	0101000020E6100000C1E270E657535240591822A7AF854B40
66386	5	53	\N	41	6368	\N	55.043778000000003	Омская область, город Омск, Советский административный округ, Белозерова, 6	Россия, Омская область, Омск, улица Тимофея Белозерова, 6	0101000020E610000020459DB98753524064247B849A854B40
66380	5	53	\N	41	6368	\N	55.049354000000001	Омская область, город Омск, Советский административный округ, Белозерова, 20	Россия, Омская область, Омск, улица Тимофея Белозерова, 20	0101000020E610000035423F53AF535240A1F65B3B51864B40
67496	5	53	\N	41	4014	\N	54.990859999999998	Омская область, Саргатский муниципальный район, Тарская, 12	Россия, Омская область, Омск, улица Тарская, 10	0101000020E6100000C8CF46AE9B57524010751F80D47E4B40
66209	5	53	\N	41	4407	\N	54.946109999999997	Омская область, город Омск, Кировский административный округ, Суровцева, 49	Россия, Омская область, Омск, улица Суровцева, 49/66	0101000020E6100000C636A968AC5552409335EA211A794B40
66310	5	53	\N	41	5624	\N	54.922606999999999	Омская область, город Омск, Ленинский административный округ, Спортивная, 74	Россия, Омская область, Омск, улица Спортивная, 74	0101000020E6100000A114ADDC0B5A5240C40776FC17764B40
66419	5	53	\N	41	6766	\N	55.032898000000003	Омская область, город Омск, Советский административный округ, СибНИИСХоз, 3 корпус 2	Россия, Омская область, Омск, улица Сибниисхоз, 3	0101000020E61000005589B2B7945552404A0D6D0036844B40
66214	5	53	\N	41	4453	\N	54.948985	Омская область, город Омск, Кировский административный округ, Седова, 57	Россия, Омская область, Омск, улица Седова, 57	0101000020E6100000DC476E4DBA54524081B2295778794B40
66212	5	53	\N	41	4453	\N	54.947299999999998	Омская область, город Омск, Кировский административный округ, Седова, 55а	Россия, Омская область, Омск, улица Седова, 55а	0101000020E6100000D449B6BA9C5452401AC05B2041794B40
66356	5	53	\N	41	5796	\N	54.937080999999999	Омская область, город Омск, Октябрьский административный округ, Свободы, 157	Россия, Омская область, Омск, улица Свободы, 157	0101000020E61000004DD6A887685B5240FB592C45F2774B40
66384	5	53	\N	41	6404	\N	55.050004000000001	Омская область, город Омск, Советский административный округ, Светлая, 5	Россия, Омская область, Омск, улица Светлая, 5	0101000020E6100000679AB0FD64535240A855F48766864B40
66489	5	53	\N	41	30162	\N	54.975739534270403	Омская область, город Омск, Садовая, 52а	Россия, Омская область, Омск, Кировский административный округ, улица Садовая	0101000020E61000004C70EA03C952524014B35E0CE57C4B40
66332	5	53	\N	41	5874	\N	54.982115	Омская область, город Омск, Октябрьский административный округ, Романенко, 15а	Россия, Омская область, Омск, улица Романенко, 15а	0101000020E610000098689082A75E52409DF4BEF1B57D4B40
66249	5	53	\N	41	4883	\N	54.997404000000003	Омская область, город Омск, Рабиновича, 93	Россия, Омская область, Омск, улица Рабиновича, 93а	0101000020E61000005B07077B1358524026732CEFAA7F4B40
66236	5	53	\N	41	4718	\N	54.991826000000003	Омская область, город Омск, Кировский административный округ, Путилова, 2	Россия, Омская область, Омск, улица Путилова, 2	0101000020E6100000F90FE9B7AF51524048A98427F47E4B40
66530	5	53	\N	41	7903	\N	54.960638000000003	Омская область, Большереченский муниципальный район, Большереченское городское поселение, Промышленная, 48	Россия, Омская область, Омск, улица Промышленная, 42	0101000020E61000002EC72B103D5C5240BEA59C2FF67A4B40
67468	5	53	\N	41	3638	\N	54.980688999999998	Омская область, Русско-Полянский муниципальный район, Сибирское сельское поселение с.Сибирское, Почтовая, 2	Россия, Омская область, Омск, улица Почтовая, 4	0101000020E61000004580D3BB7858524002469737877D4B40
66303	5	53	\N	41	15762	\N	54.833839397961903	Омская область, город Омск, Ленинский административный округ, Поморцева, 50	Россия, Омская область, Омск, поселок Новая Станица, улица Поморцева	0101000020E610000012C138B8745852408E90813CBB6A4B40
66315	5	53	\N	41	5696	\N	54.971037000000003	Омская область, город Омск, Октябрьский административный округ, Плеханова, 59	Россия, Омская область, Омск, улица Плеханова, 59	0101000020E6100000942F6821015A52405D1ABFF04A7C4B40
66336	5	53	\N	41	5919	\N	54.973728999999999	Омская область, город Омск, Октябрьский административный округ, П.Осминина, 16а	Россия, Омская область, Омск, улица Петра Осминина, 16а	0101000020E6100000F030ED9BFB5D52405915E126A37C4B40
66219	5	53	\N	41	4553	\N	54.987647000000003	Омская область, город Омск, Кировский административный округ, Перелета, 1	Россия, Омская область, Омск, улица Перелета, 1	0101000020E610000009A4C4AEED5152400B7F86376B7E4B40
66690	5	53	335	\N	15373	\N	54.934235508631502	Омская область, Исилькульский муниципальный район, Первомайская, 77	Россия, Омская область, Исилькульский район	0101000020E61000004C1C7920B2D25140785F950B95774B40
66685	5	53	\N	41	15373	\N	55.065663999999998	Омская область, Исилькульский муниципальный район, Первомайская, 2	Россия, Омская область, Омск, поселок Большие Поля, улица Первомайская, 2	0101000020E61000002F88484DBB5A524024438EAD67884B40
66418	5	53	\N	41	15373	\N	55.065663999999998	Омская область, город Омск, Советский административный округ, пос.Большие Поля, Первомайская, 2	Россия, Омская область, Омск, поселок Большие Поля, улица Первомайская, 2	0101000020E61000002F88484DBB5A524024438EAD67884B40
66329	5	53	\N	41	5854	\N	54.972256000000002	Омская область, город Омск, Октябрьский административный округ, Пархоменко, 7	Россия, Омская область, Омск, улица Пархоменко, 7	0101000020E610000078D15790665C52407EAB75E2727C4B40
66476	5	53	\N	41	7115	\N	54.990499	Омская область, город Омск, Омская, 75	Россия, Омская область, Омск, улица Омская, 75	0101000020E6100000E4874A236659524040DCD5ABC87E4B40
66475	5	53	\N	41	7115	\N	54.989821999999997	Омская область, город Омск, Омская, 106	Россия, Омская область, Омск, улица Омская, 106	0101000020E610000026C45C52B55952403F6EBF7CB27E4B40
66334	5	53	\N	41	5889	\N	54.975279	Омская область, город Омск, Октябрьский административный округ, Олимпийская, 7а	Россия, Омская область, Омск, улица Олимпийская, 7а	0101000020E61000002C7FBE2D585E5240E0BC38F1D57C4B40
67738	5	53	\N	41	1904	\N	54.999701999999999	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, Октябрьская улица, 135	Россия, Омская область, Омск, улица Октябрьская, 127	0101000020E6100000CCD424784358524076DF313CF67F4B40
66525	5	53	\N	41	1904	\N	54.997481000000001	Омская область, Большереченский муниципальный район, Большереченское городское поселение, Октябрьская, 1	Россия, Омская область, Омск, улица Октябрьская, 3	0101000020E6100000CEC7B5A162565240D1B01875AD7F4B40
66426	5	53	\N	41	1904	\N	55.000038000000004	Омская область, город Омск, Октябрьская, 92	Россия, Омская область, Омск, улица Октябрьская, 92	0101000020E610000047E6913F18575240EE60C43E01804B40
66204	5	53	\N	41	4343	\N	54.928736999999998	Омская область, город Омск, Кировский административный округ, Новостройка, 20б	Россия, Омская область, Омск, улица Новостройка, 20б	0101000020E61000001C446B459B515240E6CAA0DAE0764B40
66221	5	53	\N	41	4576	\N	54.981251999999998	Омская область, город Омск, Кировский административный округ, Новороссийская, 2	Россия, Омская область, Омск, улица Новороссийская, 2	0101000020E6100000D4997B48F85152403A9160AA997D4B40
66262	5	53	\N	41	5049	\N	54.910446	Омская область, город Омск, Ленинский административный округ, Моторная, 9	Россия, Омская область, Омск, улица Моторная, 9	0101000020E6100000C408E1D1C65C52401363997E89744B40
66276	5	53	\N	41	5216	\N	54.925477999999998	Омская область, город Омск, Ленинский административный округ, Молодогвардейская, 33	Россия, Омская область, Омск, улица Молодогвардейская, 33	0101000020E6100000EDD3F198815D52407095271076764B40
66274	5	53	\N	41	5200	\N	54.905591000000001	Омская область, город Омск, Ленинский административный округ, Молодова, 12	Россия, Омская область, Омск, улица Молодова, 12	0101000020E610000030478FDFDB5C5240A646E867EA734B40
66252	5	53	\N	41	4917	\N	54.918861	Омская область, город Омск, Кировский административный округ, Менжинского, 1в	Россия, Омская область, Омск, улица Менжинского, 1в	0101000020E61000005AD93EE42D545240F148BC3C9D754B40
66250	5	53	\N	41	4292	\N	54.913581999999998	Омская область, город Омск, Кировский административный округ, Мельничная, 102	Россия, Омская область, Омск, улица Мельничная, 102	0101000020E6100000944C4EED0C5452406D1B4641F0744B40
66248	5	53	\N	41	4292	\N	54.909939000000001	Омская область, город Омск, Кировский административный округ, Мельничная, 89 к.3	Россия, Омская область, Омск, улица Мельничная, 89/3	0101000020E61000000BEBC6BB235452406F2D93E178744B40
66206	5	53	\N	41	4292	\N	54.933377999999998	Омская область, город Омск, Кировский административный округ, Мельничная, 4	Россия, Омская область, Омск, улица Мельничная, 4	0101000020E6100000D656EC2FBB545240276728EE78774B40
66326	5	53	\N	41	5665	\N	54.975645999999998	Омская область, город Омск, Октябрьский административный округ, Масленникова, 144	Россия, Омская область, Омск, улица Масленникова, 144	0101000020E61000002AE5B512BA5B5240923CD7F7E17C4B40
66325	5	53	\N	41	5665	\N	54.975703000000003	Омская область, город Омск, Октябрьский административный округ, Масленникова, 171	Россия, Омская область, Омск, улица Масленникова, 171	0101000020E61000002A1900AAB85A5240F7CDFDD5E37C4B40
66313	5	53	\N	41	5665	\N	54.975485999999997	Омская область, город Омск, Октябрьский административный округ, Масленникова, 43	Россия, Омская область, Омск, улица Масленникова, 43	0101000020E610000006651A4D2E5A524059DAA9B9DC7C4B40
66408	5	53	\N	41	73654	\N	55.037557	Омская область, город Омск, Советский административный округ, Блюхера, 22в		0101000020E6100000D8497D59DA525240315EF3AACE844B40
66371	5	53	\N	41	6291	\N	55.034244000000001	Омская область, город Омск, Советский административный округ, Мамина-Сибиряка, 11	Россия, Омская область, Омск, улица Мамина-Сибиряка, 9	0101000020E6100000B03C484F91505240C80A7E1B62844B40
66395	5	53	\N	41	3885	\N	55.037453999999997	Омская область, город Омск, Советский административный округ, Магистральная, 22	Россия, Омская область, Омск, улица Магистральная, 22	0101000020E6100000B7F1272A1B5252405C8DEC4ACB844B40
66372	5	53	\N	41	3885	\N	55.033490999999998	Омская область, город Омск, Советский административный округ, Магистральная, 70	Россия, Омская область, Омск, улица Магистральная, 70	0101000020E61000007364E597C1505240ECDADE6E49844B40
66291	5	53	\N	41	5003	\N	54.935606999999997	Омская область, город Омск, Ленинский административный округ, Лобкова, 17	Россия, Омская область, Омск, улица Лобкова, 17	0101000020E61000006AC18BBE825852404F745DF8C1774B40
66531	5	53	\N	41	7362	\N	54.981738	Омская область, Большереченский муниципальный район, Большереченское городское поселение, Лермонтова, 34	Россия, Омская область, Омск, улица Лермонтова, 32	0101000020E61000005D876A4AB2585240C79E3D97A97D4B40
66497	5	53	\N	41	7362	\N	54.984026	Омская область, город Омск, Лермонтова, 131	Россия, Омская область, Омск, улица Лермонтова, 131	0101000020E61000002383DC45985A5240F4346090F47D4B40
67481	5	53	\N	41	65	\N	54.984867999999999	Омская область, Русско-Полянский муниципальный район, Калининское сельское поселение с.Калинино, Ленина, 15А	Россия, Омская область, Омск, улица Ленина, 15а	0101000020E6100000C3B986191A5852403F709527107E4B40
67478	5	53	\N	41	65	\N	54.987941999999997	Омская область, Русско-Полянский муниципальный район, Новосанжаровское сельское поселение с.Новосанжаровка, Ленина, 8	Россия, Омская область, Омск, улица Ленина, 8	0101000020E610000013B70A62A0575240232C2AE2747E4B40
67220	5	53	\N	41	65	\N	54.985028	Омская область, Нижнеомский муниципальный район, Ситниковское сельское поселение, с. Ситнитково, Ленина, 13	Россия, Омская область, Омск, улица Ленина, 13	0101000020E6100000744694F60658524078D2C265157E4B40
66658	5	53	\N	41	65	\N	54.973765	Омская область, Знаменский муниципальный район, Знаменское сельское поселение, Ленина 45, БОУ «Омский техникум строительства	Россия, Омская область, Омск, улица Ленина, 45	0101000020E61000006325E65949585240A67EDE54A47C4B40
66657	5	53	\N	41	65	\N	54.985714999999999	Омская область, Знаменский муниципальный район, Знаменское сельское поселение, Ленина 12, Дом культуры	Россия, Омская область, Омск, улица Ленина, 12	0101000020E61000006CCD565EF25752409C16BCE82B7E4B40
66574	5	53	\N	41	65	\N	54.984046999999997	Омская область, Большереченский муниципальный район, Старокарасукское сельское поселение, Ленина, 16	Россия, Омская область, Омск, улица Ленина, 16	0101000020E6100000520C9068025852400B5D8940F57D4B40
66541	5	53	\N	41	65	\N	54.986319999999999	Омская область, Большереченский муниципальный район, Такмыкское сельское поселение, Ленина, 5	Россия, Омская область, Омск, улица Ленина, 5	0101000020E6100000B1C398F4F757524003B2D7BB3F7E4B40
66493	5	53	\N	41	65	\N	54.974885999999998	Омская область, город Омск, Ленина, 36	Россия, Омская область, Омск, улица Ленина, 36	0101000020E61000001AA375543558524004AA7F10C97C4B40
66490	5	53	\N	41	65	\N	54.970855999999998	Омская область, город Омск, Ленина, 48	Россия, Омская область, Омск, улица Ленина, 48/1	0101000020E610000074EE76BD345852400C906802457C4B40
66473	5	53	\N	41	7286	\N	54.978017999999999	Омская область, город Омск, Куйбышева, 79а	Россия, Омская область, Омск, улица Куйбышева, 79а	0101000020E6100000261C7A8B875952401D739EB12F7D4B40
66376	5	53	\N	41	6336	\N	55.038330999999999	Омская область, город Омск, Советский административный округ, Круговая, 2 корпус 1	Россия, Омская область, Омск, улица Круговая, 2/1	0101000020E6100000FFAF3A72A450524024B6BB07E8844B40
66428	5	53	\N	41	290	\N	54.998189000000004	Омская область, город Омск, Красный Путь, 22а	Россия, Омская область, Омск, улица Красный Путь, 22а	0101000020E6100000F568AA27F35652400D1D3BA8C47F4B40
66424	5	53	\N	41	290	\N	55.00217	Омская область, город Омск, Советский административный округ, Красный путь, 68	Россия, Омская область, Омск, улица Красный Путь, 68	0101000020E6100000B1A4DC7D8E5652402384471B47804B40
66423	5	53	\N	41	290	\N	55.007458	Омская область, город Омск, Советский административный округ, Красный путь, 80в	Россия, Омская область, Омск, улица Красный Путь, 80в	0101000020E6100000D61A4AED45565240FA0B3D62F4804B40
66451	5	53	\N	41	7028	\N	55.037036000000001	Омская область, город Омск, Краснознаменная, 26	Россия, Омская область, Омск, улица Краснознаменная, 26/1	0101000020E6100000B20DDC813A5D524028637C98BD844B40
67491	5	53	\N	41	15780	\N	55.067354999999999	Омская область, Русско-Полянский муниципальный район, Русско-Полянское городское поселение р.п. Русская Поляна, Комсомольская, 57	Россия, Омская область, Омск, поселок Большие Поля, улица Комсомольская	0101000020E61000002EABB019E05A52406D1CB1169F884B40
67464	5	53	\N	41	15780	\N	55.068010000000001	Омская область, Русско-Полянский муниципальный район, Розовское сельское поселение с.Бологое, Комсомольская, 10	Россия, Омская область, Омск, поселок Большие Поля, улица Комсомольская, 12	0101000020E61000004DD87E32C65A524086E63A8DB4884B40
66267	5	53	\N	41	5103	\N	54.925142000000001	Омская область, город Омск, Ленинский административный округ, Полторацкого, 51	Россия, Омская область, Омск, улица Алексея Полторацкого, 51	0101000020E6100000D76CE525FF5A5240F913950D6B764B40
67462	5	53	\N	41	15780	\N	55.069555999999999	Омская область, Русско-Полянский муниципальный район, Целинное сельское поселение с.Целинное, Комсомольская, 1	Россия, Омская область, Омск, поселок Большие Поля, улица Комсомольская, 1	0101000020E610000051BCCADAA65A5240CB9E0436E7884B40
66383	5	53	\N	41	6392	\N	55.053918000000003	Омская область, город Омск, Советский административный округ, Коммунальная, 13б	Россия, Омская область, Омск, улица Коммунальная, 13б	0101000020E61000008E5BCCCF0D5452403755F7C8E6864B40
66359	5	53	\N	41	6147	\N	54.949218000000002	Омская область, город Омск, Октябрьский административный округ, Кирова, 7-а	Россия, Омская область, Омск, улица Кирова, 7а	0101000020E6100000234E27D9EA5A52402463B5F97F794B40
66358	5	53	\N	41	6147	\N	54.949218000000002	Омская область, город Омск, Октябрьский административный округ, Кирова, 7а	Россия, Омская область, Омск, улица Кирова, 7а	0101000020E6100000234E27D9EA5A52402463B5F97F794B40
66316	5	53	\N	41	5707	\N	54.963836999999998	Омская область, город Омск, Октябрьский административный округ, Ипподромная, 1	Россия, Омская область, Омск, улица Ипподромная, 1	0101000020E6100000831953B0C65952405ED6C4025F7B4B40
66474	5	53	\N	41	7293	\N	54.986308999999999	Омская область, город Омск, Звездова, 96	Россия, Омская область, Омск, улица Звездова, 96	0101000020E610000074B2D47ABF5952400F60915F3F7E4B40
66244	5	53	\N	41	4817	\N	54.997812000000003	Омская область, город Омск, Кировский административный округ, Звездная, 2б	Россия, Омская область, Омск, улица Звездная, 2б	0101000020E6100000EAE923F0874F524037C7B94DB87F4B40
66412	5	53	\N	41	6676	\N	55.046841999999998	Омская область, город Омск, Советский административный округ, Заозерная, 11г	Россия, Омская область, Омск, улица Заозерная, 11г	0101000020E61000009E9ACB0D86545240240A2DEBFE854B40
66454	5	53	\N	41	7023	\N	55.032778999999998	Омская область, город Омск, Завертяева, 30	Россия, Омская область, Омск, улица Завертяева, 30	0101000020E6100000575BB1BFEC5D52406F7F2E1A32844B40
66450	5	53	\N	41	7023	\N	55.033521999999998	Омская область, город Омск, Завертяева, 31	Россия, Омская область, Омск, улица Завертяева, 31	0101000020E61000007506465ED65D524027D9EA724A844B40
66448	5	53	\N	41	7023	\N	55.035271000000002	Омская область, город Омск, Завертяева, 5	Россия, Омская область, Омск, улица Завертяева, 5	0101000020E6100000021077F52A5C5240A5BF97C283844B40
66765	5	53	\N	41	5871	\N	54.978456999999999	д. Ермолаевка, Ермолаевский ДК	Россия, Омская область, Омск, улица Ермолаева	0101000020E6100000DAFE9595265E524069C537143E7D4B40
66331	5	53	\N	41	5871	\N	54.979014999999997	Омская область, город Омск, Октябрьский административный округ, Ермолаева, 5а	Россия, Омская область, Омск, улица Ермолаева, 5а	0101000020E6100000978DCEF9295E52408FA50F5D507D4B40
66462	5	53	\N	41	7173	\N	54.984315000000002	Омская область, город Омск, Достоевского, 2	Россия, Омская область, Омск, улица Достоевского, 2	0101000020E6100000BD72BD6DA65752402BFBAE08FE7D4B40
66390	5	53	\N	41	5409	\N	55.017152000000003	Омская область, город Омск, Долгирева, 91	Россия, Омская область, Омск, улица Долгирева, 91	0101000020E61000005704FF5BC9565240CF87670932824B40
65818	5	53	\N	41	5409	\N	55.022593000000001	Омская область, город Омск, Долгирева, 117	Россия, Омская область, Омск, улица Долгирева, 117	0101000020E6100000737FF5B86F5652402C0FD253E4824B40
66264	5	53	\N	41	5037	\N	54.940344000000003	Омская область, город Омск, Ленинский административный округ, Добролюбова, 22	Россия, Омская область, Омск, улица Добролюбова, 22	0101000020E61000006BB75D68AE595240B37E33315D784B40
66261	5	53	\N	41	5037	\N	54.941941999999997	Омская область, город Омск, Ленинский административный округ, Добролюбова, 15	Россия, Омская область, Омск, улица Добролюбова, 15	0101000020E61000002DB29DEFA75952404A5D328E91784B40
66229	5	53	\N	41	4511	\N	54.990251000000001	Омская область, город Омск, Кировский административный округ, Дмитриева, 2 к.8	Россия, Омская область, Омск, улица Дмитриева, 2/8	0101000020E6100000F04C68925854524068EA758BC07E4B40
66217	5	53	\N	41	4511	\N	54.979799999999997	Омская область, город Омск, Кировский административный округ, Дмитриева, 13	Россия, Омская область, Омск, улица Дмитриева, 13	0101000020E610000043A9BD88B6535240764F1E166A7D4B40
66216	5	53	\N	41	4511	\N	54.979191	Омская область, город Омск, Кировский административный округ, Дмитриева, 13 к.10	Россия, Омская область, Омск, улица Дмитриева, 13/10	0101000020E61000001BD9959691535240CEC47421567D4B40
66243	5	53	\N	41	4766	\N	54.997135	Омская область, город Омск, Кировский административный округ, Дианова, 18 к.2	Россия, Омская область, Омск, улица Дианова, 18/2	0101000020E61000002FA86F99D34F52403659A31EA27F4B40
66239	5	53	\N	41	4766	\N	54.996262999999999	Омская область, город Омск, Кировский административный округ, Дианова, 12 к.2	Россия, Омская область, Омск, улица Дианова, 12/2	0101000020E610000029B2D6506A505240809BC58B857F4B40
66488	5	53	\N	41	7265	\N	54.967326	Омская область, город Омск, Декабристов, 112	Россия, Омская область, Омск, улица Декабристов, 112	0101000020E6100000EE5C18E94559524006499F56D17B4B40
66471	5	53	\N	41	7265	\N	54.983597000000003	Омская область, город Омск, Декабристов, 35	Россия, Омская область, Омск, улица Декабристов, 35	0101000020E6100000596E693524595240CCB8A981E67D4B40
66504	5	53	\N	41	5614	\N	54.920760000000001	г.Омск, ул. Гуртьева, 1б	Россия, Омская область, Омск, улица Гуртьева, 1б	0101000020E6100000CFD72C978D59524084BBB376DB754B40
66375	5	53	\N	41	6330	\N	55.034269999999999	Омская область, город Омск, Советский административный округ, Грозненская, 7	Россия, Омская область, Омск, улица Грозненская, 7	0101000020E6100000E20511A969515240F19D98F562844B40
67290	5	53	\N	41	6	\N	54.986494999999998	"Омская область, Оконешниковский муниципальный район, Оконешниковское городское поселение, МУП ""Коммунальник"", Гагарина, 1"	Россия, Омская область, Омск, улица Гагарина, 3	0101000020E6100000959D7E50175852407155D977457E4B40
66461	5	53	\N	41	7163	\N	54.996087000000003	Омская область, город Омск, Волочаевская, 17г	Россия, Омская область, Омск, улица Волочаевская, 17г	0101000020E6100000B48EAA2688565240427C60C77F7F4B40
66208	5	53	\N	41	4398	\N	54.943313000000003	Омская область, город Омск, Кировский административный округ, Володарского, 74	Россия, Омская область, Омск, улица Володарского, 74	0101000020E6100000880E8123815552402272FA7ABE784B40
66278	5	53	\N	41	5235	\N	54.926560000000002	Омская область, город Омск, Ленинский административный округ, Волго-Донская, 15	Россия, Омская область, Омск, улица Волго-Донская, 15	0101000020E610000085ED27637C5E524011E4A08499764B40
66337	5	53	\N	41	5940	\N	54.977935000000002	Омская область, город Омск, Октябрьский административный округ, Товстухо, 4а	Россия, Омская область, Омск, улица Василия Товстухо, 4	0101000020E6100000D9D138D4EF5D5240904E5DF92C7D4B40
66502	5	53	\N	41	15586	\N	54.887512000000001	г.Омск,ул. Маргелова, 400/1	Россия, Омская область, Омск, поселок Светлый, улица Василия Маргелова, 400/1	0101000020E610000047E350BF0B5F52405E6743FE99714B40
66285	5	53	\N	41	15586	\N	54.887512000000001	Омская область, город Омск, Ленинский административный округ, Маргелова, 400/1	Россия, Омская область, Омск, поселок Светлый, улица Василия Маргелова, 400/1	0101000020E610000047E350BF0B5F52405E6743FE99714B40
67494	5	53	\N	41	3997	\N	54.965676999999999	Омская область, Русско-Полянский муниципальный район, Русско-Полянское городское поселение р.п. Русская Поляна, Бульварная, 17	Россия, Омская область, Омск, улица Бульварная, 15	0101000020E6100000CD785BE9B5595240ECBFCE4D9B7B4B40
66464	5	53	\N	41	7193	\N	54.994796000000001	Омская область, город Омск, Булатова, 101	Россия, Омская область, Омск, улица Булатова, 101	0101000020E6100000AA9D616A4B5852408718AF79557F4B40
66381	5	53	\N	41	6376	\N	55.052464000000001	Омская область, город Омск, Советский административный округ, Бородина, 19	Россия, Омская область, Омск, улица Бородина, 19	0101000020E61000003106D671FC535240D21BEE23B7864B40
66318	5	53	\N	41	5729	\N	54.960068999999997	Омская область, город Омск, Октябрьский административный округ, Б.Хмельницкого, 214	Россия, Омская область, Омск, улица Богдана Хмельницкого, 214	0101000020E6100000E9616875725A5240A3737E8AE37A4B40
66205	5	53	\N	41	4356	\N	54.929265000000001	Омская область, город Омск, Кировский административный округ, Бетховена, 1	Россия, Омская область, Омск, улица Бетховена, 1	0101000020E6100000560BEC3191555240A228D027F2764B40
66279	5	53	\N	41	5250	\N	54.923108999999997	Омская область, город Омск, Ленинский административный округ, Батумская, 28	Россия, Омская область, Омск, улица Батумская, 28	0101000020E610000084BD8921395E524056D28A6F28764B40
66411	5	53	\N	41	6661	\N	55.046615000000003	Омская область, город Омск, Советский административный округ, Бархатовой, 6г	Россия, Омская область, Омск, улица Бархатовой, 6г	0101000020E6100000FB743C66A05452406440F67AF7854B40
66446	5	53	\N	41	6992	\N	55.021664000000001	Омская область, город Омск, Барнаульская, 134	Россия, Омская область, Омск, улица Барнаульская, 134	0101000020E6100000DD257156445B524012C0CDE2C5824B40
66440	5	53	\N	41	6938	\N	55.023485000000001	Омская область, город Омск, Багратиона, 7	Россия, Омская область, Омск, улица Багратиона, 7	0101000020E61000000E83F92B645A52402979758E01834B40
66260	5	53	\N	41	5008	\N	54.944904999999999	Омская область, город Омск, Ленинский административный округ, Избышева, 3	Россия, Омская область, Омск, улица Артема Избышева, 3	0101000020E6100000FB3E1C2444595240D769A4A5F2784B40
66469	5	53	\N	41	7251	\N	55.012264000000002	Омская область, город Омск, Арсеньева, 1	Россия, Омская область, Омск, улица Арсеньева, 1	0101000020E61000006519E258175A52408675E3DD91814B40
66404	5	53	\N	41	6554	\N	55.026921999999999	Омская область, город Омск, Советский административный округ, Андрианова, 4	Россия, Омская область, Омск, улица Андрианова, 4	0101000020E6100000E3FDB8FDF25152407EC51A2E72834B40
66403	5	53	\N	41	6554	\N	55.026138000000003	Омская область, город Омск, Советский административный округ, Андрианова, 24	Россия, Омская область, Омск, улица Андрианова, 24	0101000020E61000000B5D8940F550524068976F7D58834B40
66399	5	53	\N	41	6554	\N	55.027437999999997	Омская область, город Омск, Советский административный округ, Андрианова, 14 корпус 3	Россия, Омская область, Омск, улица Андрианова, 14/3	0101000020E61000009F94490D6D5152407555A01683834B40
66254	5	53	\N	41	4928	\N	54.950789999999998	Омская область, город Омск, Ленинский административный округ, Ангарская, 7 А	Россия, Омская область, Омск, улица Ангарская, 7а	0101000020E61000001171732A1959524092AE997CB3794B40
66253	5	53	\N	41	4928	\N	54.950789999999998	Омская область, город Омск, Ленинский административный округ, Ангарская, 7а	Россия, Омская область, Омск, улица Ангарская, 7а	0101000020E61000001171732A1959524092AE997CB3794B40
66269	5	53	\N	41	5103	\N	54.924453999999997	Омская область, город Омск, Ленинский административный округ, Полторацкого, 54	Россия, Омская область, Омск, улица Алексея Полторацкого, 54	0101000020E6100000E82FF488D15A52400454388254764B40
66268	5	53	\N	41	5103	\N	54.925468000000002	Омская область, город Омск, Ленинский административный округ, Полторацкого, 57а	Россия, Омская область, Омск, улица Алексея Полторацкого, 57а	0101000020E6100000838AAA5FE95A52404DBF44BC75764B40
66211	5	53	\N	41	4438	\N	54.954372999999997	Омская область, город Омск, Кировский административный округ, Авиагородок, 27	Россия, Омская область, Омск, улица Авиагородок, 27	0101000020E61000004F1F813FFC545240BB97FBE4287A4B40
66226	5	53	\N	41	4622	\N	54.982909999999997	Омская область, город Омск, Кировский административный округ, 70 лет Октября, 20 к.1	Россия, Омская область, Омск, улица 70 Лет Октября, 20/1	0101000020E6100000320400C79E545240A774B0FECF7D4B40
66225	5	53	\N	41	4622	\N	54.984904	Омская область, город Омск, Кировский административный округ, 70 лет Октября, 20 к.3	Россия, Омская область, Омск, улица 70 Лет Октября, 20/3	0101000020E61000006F8104C58F5452408CD99255117E4B40
66347	5	53	\N	41	6022	\N	54.952298999999996	Омская область, город Омск, Октябрьский административный округ, 6 Шинная, 9б	Россия, Омская область, Омск, улица 6-я Шинная, 9	0101000020E61000007CD3F4D9015D5240BA8102EFE4794B40
66346	5	53	\N	41	6022	\N	54.952298999999996	Омская область, город Омск, Октябрьский административный округ, 6 шинная, 9б	Россия, Омская область, Омск, улица 6-я Шинная, 9	0101000020E61000007CD3F4D9015D5240BA8102EFE4794B40
66277	5	53	\N	41	5205	\N	54.924092000000002	Омская область, город Омск, Ленинский административный округ, 6-я Станционная, 31	Россия, Омская область, Омск, улица 6-я Станционная, 31	0101000020E6100000C93D5DDDB15D5240643F8BA548764B40
66275	5	53	\N	41	5205	\N	54.923124000000001	Омская область, город Омск, Ленинский административный округ, 6-я Станционная, 11	Россия, Омская область, Омск, улица 6-я Станционная, 11	0101000020E6100000B1886187315D52408C135FED28764B40
66467	5	53	\N	41	7228	\N	55.005284000000003	Омская область, город Омск, 6-я Ремесленная, 13	Россия, Омская область, Омск, улица 6-я Ремесленная, 13	0101000020E61000007C5F5CAAD258524096986725AD804B40
66368	5	53	\N	41	6259	\N	55.033599000000002	Омская область, город Омск, Советский административный округ, 50 лет Профсоюзов, 105	Россия, Омская область, Омск, улица 50 Лет Профсоюзов, 105	0101000020E610000076FBAC3253505240D316D7F84C844B40
66526	5	53	\N	41	5885	\N	54.980327000000003	Омская область, Большереченский муниципальный район, Большереченское городское поселение, 50 лет ВЛКСМ, 3	Россия, Омская область, Омск, улица 50 Лет ВЛКСМ, 3	0101000020E61000005E4A5D328E5E52406231EA5A7B7D4B40
66360	5	53	\N	41	6182	\N	54.949187000000002	Омская область, город Омск, Октябрьский административный округ, 5 Рабочая, 44	Россия, Омская область, Омск, улица 5-я Рабочая, 44	0101000020E6100000863C821B295B5240E964A9F57E794B40
66343	5	53	\N	41	5997	\N	54.959722999999997	Омская область, город Омск, Октябрьский административный округ, 5 кордная, 3	Россия, Омская область, Омск, улица 5-я Кордная, 3	0101000020E61000004165FCFB8C5C5240081C0934D87A4B40
66465	5	53	\N	41	7202	\N	55.000508000000004	Омская область, город Омск, 5-й Армии, 141	Россия, Омская область, Омск, улица 5 Армии, 141	0101000020E61000001A19E42EC258524075B169A510804B40
66453	5	53	\N	41	16470	\N	55.029988000000003	Омская область, город Омск, поселок Степной, 40 лет Ракетных войск, 8	Россия, Омская область, Омск, поселок Степной, улица 40 Лет Ракетных Войск, 8	0101000020E6100000124DA08845605240E0A293A5D6834B40
66435	5	53	\N	41	6904	\N	55.016511999999999	Омская область, город Омск, 4-я Челюскинцев, 2а	Россия, Омская область, Омск, улица 4-я Челюскинцев, 2а	0101000020E61000009DF3531C075B5240EBFEB1101D824B40
66361	5	53	\N	41	6194	\N	54.950918999999999	Омская область, город Омск, Октябрьский административный округ, 4 Транспортная, 56	Россия, Омская область, Омск, улица 4-я Транспортная, 56	0101000020E61000006D533C2EAA5B52409012BBB6B7794B40
66405	5	53	\N	41	6607	\N	55.028790000000001	Омская область, город Омск, Советский административный округ, 4-я Поселковая, 40	Россия, Омская область, Омск, улица 4-я Поселковая, 38	0101000020E6100000B58AFED0CC525240D6390664AF834B40
66296	5	53	\N	41	5476	\N	54.917769	Омская область, город Омск, Ленинский административный округ, 4-я Марьяновская, 67а	Россия, Омская область, Омск, улица 4-я Марьяновская, 67а	0101000020E6100000E5F21FD26F5752402D24607479754B40
66021	5	53	\N	41	1834	\N	55.033088999999997	Омская область, город Омск, 35-я Северная, 3	Россия, Омская область, Омск, улица 35-я Северная, 3	0101000020E6100000D80E46EC13585240BD6DA6423C844B40
66436	5	53	\N	41	6909	\N	55.029833000000004	Омская область, город Омск, 33-я Северная, 48	Россия, Омская область, Омск, улица 33-я Северная, 48	0101000020E61000005514AFB2B6585240B9AB5791D1834B40
66442	5	53	\N	41	2142	\N	55.028796	Омская область, город Омск, 30-я Северная, 121	Россия, Омская область, Омск, улица 30-я Северная, 121	0101000020E610000046990D32C9595240B8205B96AF834B40
66043	5	53	\N	41	2142	\N	55.029285999999999	Омская область, город Омск, 30-я Северная, 71	Россия, Омская область, Омск, улица 30-я Северная, 71	0101000020E6100000DFFAB0DEA8585240861DC6A4BF834B40
66365	5	53	\N	41	6235	\N	54.932389999999998	Омская область, город Омск, Октябрьский административный округ, 30 Рабочая, 14а	Россия, Омская область, Омск, улица 30-я Рабочая, 14а	0101000020E610000082FE428F185C5240088F368E58774B40
66319	5	53	\N	41	5749	\N	54.957442999999998	Омская область, город Омск, Октябрьский административный округ, 3 Транспортная, 7	Россия, Омская область, Омск, улица 3-я Транспортная, 7	0101000020E61000002026E1421E5A52405E64027E8D7A4B40
66283	5	53	\N	41	5305	\N	54.928545999999997	Омская область, город Омск, Ленинский административный округ, 3-я Станционная, 69	Россия, Омская область, Омск, улица 3-я Станционная, 69	0101000020E6100000384A5E9D635F5240726A6798DA764B40
66227	5	53	\N	41	4640	\N	54.980497999999997	Омская область, город Омск, Кировский административный округ, 3 Островская, 164		0101000020E6100000B284B531765652408EE55DF5807D4B40
66281	5	53	\N	41	15641	\N	54.923186000000001	Омская область, город Омск, Ленинский административный округ, 3-я Ленинградская, 50	Россия, Омская область, Омск, Ленинский район, улица 3-я Ленинградская, 50	0101000020E610000093C7D3F2035F5240021077F52A764B40
66345	5	53	\N	41	6009	\N	54.961455000000001	Омская область, город Омск, Октябрьский административный округ, 3 Кордная, 25а	Россия, Омская область, Омск, улица 3-я Кордная, 25а	0101000020E6100000D6FECEF6E85C5240B0C91AF5107B4B40
66344	5	53	\N	41	6009	\N	54.961455000000001	Омская область, город Омск, Октябрьский административный округ, 3 Кордная, 25-а	Россия, Омская область, Омск, улица 3-я Кордная, 25а	0101000020E6100000D6FECEF6E85C5240B0C91AF5107B4B40
66438	5	53	\N	41	6925	\N	55.025018000000003	Омская область, город Омск, 27-я Северная, 90	Россия, Омская область, Омск, улица 27-я Северная, 90	0101000020E6100000D5EB1681B1595240DAE731CA33834B40
66290	5	53	\N	41	5384	\N	54.936796000000001	Омская область, город Омск, Ленинский административный округ, 25 лет Октября, 4	Россия, Омская область, Омск, улица 25 Лет Октября, 4	0101000020E6100000689604A8A957524006836BEEE8774B40
66432	5	53	\N	41	2558	\N	55.022478999999997	Омская область, город Омск, 24-я Северная, 216	Россия, Омская область, Омск, улица 24-я Северная, 216	0101000020E6100000CA1649BBD159524063EC8497E0824B40
66071	5	53	\N	41	2558	\N	55.023722999999997	Омская область, город Омск, 24-я Северная, 119	Россия, Омская область, Омск, улица 24-я Северная, 119	0101000020E6100000DBC01DA853585240DD94F25A09834B40
66447	5	53	\N	41	6934	\N	55.029491999999998	Омская область, город Омск, 21-я Амурская, 20а	Россия, Омская область, Омск, улица 21-я Амурская, 20а	0101000020E61000005B3FFD67CD5A52402FBFD364C6834B40
66445	5	53	\N	41	6934	\N	55.030724999999997	Омская область, город Омск, 21-я Амурская, 17	Россия, Омская область, Омск, улица 21-я Амурская, 17	0101000020E6100000336C94F59B5A5240B515FBCBEE834B40
66443	5	53	\N	41	6934	\N	55.029027999999997	Омская область, город Омск, 21-я Амурская, 15	Россия, Омская область, Омск, улица 21-я Амурская, 15	0101000020E61000003CBF28417F5A52408A558330B7834B40
66439	5	53	\N	41	6934	\N	55.026091999999998	Омская область, город Омск, 21-я Амурская, 5	Россия, Омская область, Омск, улица 21-я Амурская, 5	0101000020E61000007767EDB60B5A5240F7578FFB56834B40
66207	5	53	\N	41	4382	\N	54.94173	Омская область, город Омск, Кировский административный округ, 20 лет Октября, 12а	Россия, Омская область, Омск, улица 20 Лет Октября, 12а	0101000020E610000098A7734529555240BFD4CF9B8A784B40
66246	5	53	\N	41	4838	\N	54.999046	Омская область, город Омск, Кировский административный округ, 2-я Солнечная, 15	Россия, Омская область, Омск, улица 2-я Солнечная, 15	0101000020E6100000441669E21D4E52408D9944BDE07F4B40
66458	5	53	\N	41	7128	\N	54.997394	Омская область, город Омск, 2-я Производственная, 37	Россия, Омская область, Омск, улица 2-я Производственная, 37	0101000020E61000008121AB5B3D5C5240029D499BAA7F4B40
66415	5	53	\N	41	6712	\N	55.025765999999997	Омская область, город Омск, Советский административный округ, 2-я Поселковая, 1	Россия, Омская область, Омск, улица 2-я Поселковая, 1	0101000020E61000009FAEEE586C535240A3ACDF4C4C834B40
66280	5	53	\N	41	5256	\N	54.924433000000001	Омская область, город Омск, Ленинский административный округ, 2-я Ленинградская, 24	Россия, Омская область, Омск, улица 2-я Ленинградская, 24	0101000020E610000080290307B45E5240ED2B0FD253764B40
66300	5	53	\N	41	5506	\N	54.905560000000001	Омская область, город Омск, Ленинский административный округ, 19-я Марьяновская, 40а	Россия, Омская область, Омск, улица 19-я Марьяновская, 40а	0101000020E610000024D5777E515752406B48DC63E9734B40
66299	5	53	\N	41	5506	\N	54.905560000000001	Омская область, город Омск, Ленинский административный округ, 19-я Марьяновская, 40 А	Россия, Омская область, Омск, улица 19-я Марьяновская, 40а	0101000020E610000024D5777E515752406B48DC63E9734B40
66109	5	53	\N	41	3108	\N	55.018684999999998	Омская область, город Омск, 18-я Северная, 91	Россия, Омская область, Омск, улица 18-я Северная, 91	0101000020E61000009C6B98A1F15752407FF6234564824B40
66363	5	53	\N	41	6196	\N	54.943333000000003	Омская область, город Омск, Октябрьский административный округ, 17 Рабочая, 89	Россия, Омская область, Омск, улица 17-я Рабочая, 89	0101000020E6100000B9DFA128D05B5240691EC022BF784B40
66362	5	53	\N	41	6196	\N	54.943333000000003	Омская область, город Омск, Октябрьский административный округ, 17 рабочая, 89	Россия, Омская область, Омск, улица 17-я Рабочая, 89	0101000020E6100000B9DFA128D05B5240691EC022BF784B40
66301	5	53	\N	41	5534	\N	54.907651000000001	Омская область, город Омск, Ленинский административный округ, 13-я Комсомольская, 1	Россия, Омская область, Омск, улица 13-я Комсомольская, 1	0101000020E6100000B9FFC874E8585240429770E82D744B40
66210	5	53	\N	41	4424	\N	54.952806000000002	Омская область, город Омск, Кировский административный округ, 12 Декабря, 114	Россия, Омская область, Омск, улица 12 Декабря, 114	0101000020E610000002840F255A5552405FB7088CF5794B40
66270	5	53	\N	41	5137	\N	54.921385999999998	Омская область, город Омск, Ленинский административный округ, 10-я Чередовая, 32а	Россия, Омская область, Омск, улица 10-я Чередовая, 32а	0101000020E6100000799274CDE45A5240027FF8F9EF754B40
66295	5	53	\N	41	5461	\N	54.922369000000003	Омская область, город Омск, Ленинский административный округ, 1-я Красной Звезды, 25	Россия, Омская область, Омск, улица 1-я Красной Звезды, 25	0101000020E61000005F9B8D959857524010ECF82F10764B40
66297	5	53	\N	41	5481	\N	54.913271999999999	Омская область, город Омск, Ленинский административный округ, 1 Мая, 25	Россия, Омская область, Омск, улица 1-го Мая, 25	0101000020E610000073486AA1645752401F2DCE18E6744B40
66263	5	53	\N	41	73539	\N	54.940256577483801	Омская область, город Омск, Ленинский административный округ, Академика Павлова, 24	Россия, Омская область, Омск, Ленинский административный округ, улица академика Павлова	0101000020E61000006CB3B112F3585240E46A64575A784B40
66247	5	53	\N	41	29960	\N	54.886988381673397	Омская область, город Омск, Кировский административный округ, Я.М.Сметнева, 5		0101000020E61000008350DEC7D1535240E4F8A1D288714B40
66391	5	53	\N	41	73589	\N	55.045319999999997	Омская область, город Омск, Советский административный округ, Энтузиастов, 25б		0101000020E6100000836C59BE2E52524067EDB60BCD854B40
66379	5	53	\N	41	73589	\N	55.044428000000003	Омская область, город Омск, Советский административный округ, Энтузиастов, 47		0101000020E610000005C24EB16A5152406B8313D1AF854B40
66544	5	53	\N	41	71488	\N	55.035859000000002	Омская область, Большереченский муниципальный район, Евгащинское сельское поселение, пер.Школьный, 4		0101000020E6100000806264C91C5252403622180797844B40
66470	5	53	\N	41	73661	\N	54.979103000000002	Омская область, город Омск, Чкалова, 25		0101000020E61000004DF38E53745852402F35423F537D4B40
66357	5	53	\N	41	73646	\N	54.942413000000002	Омская область, город Омск, Октябрьский административный округ, Харьковская, 21		0101000020E6100000A33CF372D85A5240A2293BFDA0784B40
66434	5	53	\N	41	29545	\N	55.019438370743998	Омская область, город Омск, XXII Партсъезда, 19	Россия, Омская область, Омск, Центральный административный округ, улица ХХII Партсъезда, 19	0101000020E610000071CB4752D25A52405B26C3F17C824B40
66421	5	53	\N	41	73594	\N	55.021152999999998	Омская область, город Омск, Советский административный округ, Физкультурная, 1		0101000020E6100000BEA4315A475452402C9B3924B5824B40
66230	5	53	\N	41	4666	\N	54.992859000000003	Омская область, город Омск, Кировский административный округ, Туполева, 1	Россия, Омская область, Омск, Туполева бульвар, 1	0101000020E610000016A243E0485352400745F300167F4B40
66251	5	53	\N	41	73626	\N	54.917019000000003	Омская область, город Омск, Кировский административный округ, Талалихина, 29а		0101000020E61000009AEAC9FCA3535240C367EBE060754B40
66463	5	53	\N	41	29565	\N	54.985336811858403	Омская область, город Омск, Т.К. Щербанева, 20	Россия, Омская область, Омск, Центральный административный округ, улица Щербанева, 20	0101000020E61000006D0377A04E585240F644D7851F7E4B40
66485	5	53	\N	41	7406	\N	54.957411999999998	Омская область, город Омск, проезд Спортивный, 9а	Россия, Омская область, Омск, Спортивный проезд, 9	0101000020E6100000CE893DB48F5852402366F6798C7A4B40
66272	5	53	\N	41	5161	\N	54.914653999999999	Омская область, город Омск, Ленинский административный округ, Сибирский проспект, 6а	Россия, Омская область, Омск, Сибирский проспект, 6а	0101000020E6100000E17EC003035D5240EA93DC6113754B40
66420	5	53	\N	41	73655	\N	55.024053000000002	Омская область, город Омск, Советский административный округ, Сибаковская, 6		0101000020E6100000F817416326545240732F302B14834B40
66385	5	53	\N	41	73650	\N	55.042090999999999	Омская область, город Омск, Советский административный округ, Тюленина, 5		0101000020E6100000CD920035B55352405C3AE63C63854B40
66324	5	53	\N	41	73680	\N	54.944642000000002	Омская область, город Омск, Октябрьский административный округ, Свободы, 54		0101000020E610000007600322C45A5240CA367007EA784B40
65867	5	53	\N	41	73608	\N	55.026865999999998	Омская область, город Омск, Сазонова, 199		0101000020E6100000DF3312A111575240EAAF575870834B40
66341	5	53	\N	41	29615	\N	54.990302	Омская область, город Омск, Октябрьский административный округ, Российская, 10		0101000020E6100000B0C8AF1F62575240EA944737C27E4B40
66235	5	53	\N	41	73625	\N	54.994754999999998	Омская область, город Омск, Кировский административный округ, Путилова, 12а		0101000020E6100000677BF486FB5152402844C021547F4B40
66306	5	53	\N	41	73671	\N	54.936056999999998	Омская область, город Омск, Ленинский административный округ, Правды, 30		0101000020E61000001903EB387E5A52408F183DB7D0774B40
66366	5	53	\N	41	30106	\N	54.941265000000001	Омская область, город Омск, Советский административный округ, Полевая, 95		0101000020E6100000487023658B6152404AEF1B5F7B784B40
67868	5	53	\N	41	5223	\N	54.955798999999999	Омская область, Черлакский муниципальный район, Южно-Подольское сельское поселение, Победы, 39	Россия, Омская область, Омск, Победы бульвар	0101000020E610000079AD84EE925852405646239F577A4B40
67828	5	53	\N	41	5223	\N	54.95476	Омская область, Черлакский муниципальный район, Черлакское городское поселение, Победы, 14	Россия, Омская область, Омск, Победы бульвар, 10	0101000020E6100000CBA2B08BA2585240B5C35F93357A4B40
66338	5	53	\N	41	73579	\N	54.97484	Омская область, город Омск, Октябрьский административный округ, П.Осминина, 22		0101000020E6100000A67EDE54A45D5240946A9F8EC77C4B40
66004	5	53	\N	41	73620	\N	55.029131	Омская область, город Омск, Орджоникидзе, 287		0101000020E610000037A5BC56425752405F268A90BA834B40
66282	5	53	\N	41	5285	\N	54.914555	Омская область, город Омск, Ленинский административный округ, Птицефабрица, 53	Россия, Омская область, Омск, Омская Птицефабрика поселок, 53	0101000020E6100000CC086F0F425F524057B2632310754B40
66457	5	53	\N	41	73660	\N	54.992358000000003	Омская область, город Омск, Омская, 197		0101000020E6100000C8D0B1834A5B524045F64196057F4B40
66355	5	53	\N	41	73709	\N	54.962814000000002	Омская область, город Омск, Октябрьский административный округ, Ноябрьская, 15		0101000020E61000006A16687748635240C310397D3D7B4B40
67572	5	53	\N	41	76419	\N	55.071545999999998	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, д.Юрт-Уйск, ул.Новая, д.1А		0101000020E610000006D847A7AE5A52406E14596B28894B40
66327	5	53	\N	41	73638	\N	54.974535000000003	Омская область, город Омск, Октябрьский административный округ, Кузнецова, 4а		0101000020E610000048DDCEBEF25B524058E71890BD7C4B40
66417	5	53	\N	41	6255	\N	55.023769000000001	Омская область, город Омск, Советский административный округ, пр.Мира, 2а	Россия, Омская область, Омск, Мира проспект, 2а	0101000020E6100000A1DB4B1AA35352404ED4D2DC0A834B40
66416	5	53	\N	41	6255	\N	55.022039999999997	Омская область, город Омск, Советский административный округ, пр.Мира, 5	Россия, Омская область, Омск, Мира проспект, 5	0101000020E61000008849B89047535240179AEB34D2824B40
66414	5	53	\N	41	6255	\N	55.024419000000002	Омская область, город Омск, Советский административный округ, пр.Мира, 9	Россия, Омская область, Омск, Мира проспект, 9	0101000020E61000004A7CEE04FB52524055336B2920834B40
66406	5	53	\N	41	6255	\N	55.027329999999999	Омская область, город Омск, Советский административный округ, пр.Мира, 11	Россия, Омская область, Омск, Мира проспект, 11	0101000020E61000009E60FF756E5252408F19A88C7F834B40
66402	5	53	\N	41	6255	\N	55.027991	Омская область, город Омск, Советский административный округ, пр.Мира, 55а	Россия, Омская область, Омск, Мира проспект, 55а	0101000020E61000003A799109F85052408ACA863595834B40
66401	5	53	\N	41	6255	\N	55.028238000000002	Омская область, город Омск, Советский административный округ, пр.Мира, 165д	Россия, Омская область, Омск, Мира проспект, 165д	0101000020E610000074B4AA251D4E52409240834D9D834B40
66400	5	53	\N	41	6255	\N	55.030952999999997	Омская область, город Омск, Советский административный округ, пр.Мира, 169г	Россия, Омская область, Омск, Мира проспект, 169г	0101000020E6100000984D8061F94D5240465B9544F6834B40
66392	5	53	\N	41	6255	\N	55.030234999999998	Омская область, город Омск, Советский административный округ, пр.Мира, 58	Россия, Омская область, Омск, Мира проспект, 58	0101000020E61000001172DEFFC7515240E71890BDDE834B40
66370	5	53	\N	41	6255	\N	55.029420000000002	Омская область, город Омск, Советский административный округ, пр.Мира, 90 корпус 1	Россия, Омская область, Омск, Мира проспект, 90/1	0101000020E6100000280D350A4950524096ECD808C4834B40
66369	5	53	\N	41	6255	\N	55.030276999999998	Омская область, город Омск, Советский административный округ, пр.Мира, 96б	Россия, Омская область, Омск, Мира проспект, 96б	0101000020E610000084B70721205052401669E21DE0834B40
66367	5	53	\N	41	6255	\N	55.030394999999999	Омская область, город Омск, Советский административный округ, пр.Мира, 102а	Россия, Омская область, Омск, Мира проспект, 102а	0101000020E61000001E37FC6EBA4F5240207BBDFBE3834B40
66407	5	53	\N	41	6622	\N	55.040661999999998	Омская область, город Омск, Советский административный округ, пр.Менделеева, 32в	Россия, Омская область, Омск, Менделеева проспект, 32в	0101000020E6100000603DEE5BAD5452405018946934854B40
66200	5	53	\N	41	30107	\N	54.914234	Омская область, город Омск, Кировский административный округ, Мельничная, 44		0101000020E6100000DB4C8578245452401572A59E05754B40
66394	5	53	\N	41	73652	\N	55.037081999999998	Омская область, город Омск, Советский административный округ, Магистральная, 40		0101000020E6100000DF4E22C2BF51524098A25C1ABF844B40
66289	5	53	\N	41	73629	\N	54.938037999999999	Омская область, город Омск, Ленинский административный округ, Лобкова, 5		0101000020E610000018EC866D8B585240DF3312A111784B40
66259	5	53	\N	41	73629	\N	54.940069999999999	Омская область, город Омск, Ленинский административный округ, Лобкова, 2		0101000020E610000012F8C3CF7F585240B1F9B83654784B40
66222	5	53	\N	41	4588	\N	54.991382000000002	Омская область, город Омск, Кировский административный округ, Лесной Проезд, 5	Россия, Омская область, Омск, Лесной проезд, 5	0101000020E6100000B42094F771505240EAEBF99AE57E4B40
67490	5	53	\N	41	73604	\N	54.974885999999998	Омская область, Русско-Полянский муниципальный район, Русско-Полянское городское поселение р.п. Русская Поляна, Ленина, 36		0101000020E61000001AA375543558524004AA7F10C97C4B40
66308	5	53	\N	41	73633	\N	54.923884999999999	Омская область, город Омск, Ленинский административный округ, Крыловская, 50		0101000020E61000002D5DC136E2595240EA211ADD41764B40
66498	5	53	\N	41	30092	\N	54.979768999999997	Омская область, город Омск, Красных Зорь, 108б		0101000020E61000000AF4893C495A52403B511212697D4B40
66422	5	53	\N	41	73595	\N	55.010911	Омская область, город Омск, Советский административный округ, Красный путь, 143		0101000020E61000004293C4927255524055151A8865814B40
66305	5	53	\N	41	29418	\N	54.990302	Омская область, город Омск, Ленинский административный округ, Красноярова, 1/1		0101000020E6100000B0C8AF1F62575240EA944737C27E4B40
66449	5	53	\N	41	73636	\N	55.035705	Омская область, город Омск, Краснознаменная, 3		0101000020E6100000726F7EC3445E5240DFA63FFB91844B40
66339	5	53	\N	41	5837	\N	54.968012999999999	Омская область, город Омск, Октябрьский административный округ, Космический проспект, 14а	Россия, Омская область, Омск, Космический проспект, 14а	0101000020E61000000DE02D90A05C52402A8D98D9E77B4B40
66330	5	53	\N	41	5837	\N	54.975160000000002	Омская область, город Омск, Октябрьский административный округ, Космический проспект, 79	Россия, Омская область, Омск, Космический проспект, 79	0101000020E6100000B003E78C285D5240062FFA0AD27C4B40
66328	5	53	\N	41	5837	\N	54.970122000000003	Омская область, город Омск, Октябрьский административный округ, Космический проспект, 13	Россия, Омская область, Омск, Космический проспект, 13	0101000020E61000004E44BFB67E5C5240A8902BF52C7C4B40
66388	5	53	\N	41	6448	\N	55.040998000000002	Омская область, город Омск, Советский административный округ, пр.Королева, 1	Россия, Омская область, Омск, Королева проспект, 2	0101000020E610000056D636C5E3525240C899266C3F854B40
66245	5	53	\N	41	73584	\N	54.998064999999997	Омская область, город Омск, Кировский административный округ, Комкова, 3в		0101000020E610000001193A76504F524020240B98C07F4B40
66218	5	53	\N	41	4537	\N	54.979914000000001	Омская область, город Омск, Кировский административный округ, Комарова, 27 к.3	Россия, Омская область, Омск, Комарова проспект, 27/3	0101000020E610000011548D5E0D5452403F726BD26D7D4B40
66215	5	53	\N	41	73623	\N	54.946891000000001	Омская область, город Омск, Кировский административный округ, Ключевая, 37		0101000020E61000001D90847D3B53524039F06AB933794B40
66486	5	53	\N	41	7415	\N	54.962617999999999	Омская область, город Омск, проспект К. Маркса, 24а	Россия, Омская область, Омск, Карла Маркса проспект, 24а	0101000020E6100000A3570394865852403D450E11377B4B40
66350	5	53	\N	41	6046	\N	54.954144999999997	Омская область, город Омск, Октябрьский административный округ, переулок Камерный, 47	Россия, Омская область, Омск, Камерный переулок, 47	0101000020E6100000A1478C9E5B5D52402A52616C217A4B40
66349	5	53	\N	41	6046	\N	54.954129999999999	Омская область, город Омск, Октябрьский административный округ, переулок Камерный, 47а	Россия, Омская область, Омск, Камерный переулок, 47а	0101000020E61000001AC05B20415D5240F5108DEE207A4B40
66348	5	53	\N	41	6046	\N	54.954129999999999	Омская область, город Омск, Октябрьский административный округ, Камерный, 47-а	Россия, Омская область, Омск, Камерный переулок, 47а	0101000020E61000001AC05B20415D5240F5108DEE207A4B40
66533	5	53	\N	41	7926	\N	54.977682000000001	Омская область, Большереченский муниципальный район, Большереченское городское поселение, Иртышская, 1	Россия, Омская область, Омск, Иртышская набережная, 7	0101000020E6100000CE8E54DFF9575240A6F10BAF247D4B40
66317	5	53	\N	41	73632	\N	54.963707999999997	Омская область, город Омск, Октябрьский административный округ, Ипподромная, 12		0101000020E610000005E09F52255A52406072A3C85A7B4B40
66456	5	53	\N	41	73659	\N	54.989955999999999	Омская область, город Омск, Иванишко, 31		0101000020E6100000E23C9CC0745B52404F3DD2E0B67E4B40
66234	5	53	\N	41	4678	\N	55.001756999999998	Омская область, город Омск, Кировский административный округ, бульвар Заречный, 3	Россия, Омская область, Омск, Заречный бульвар, 3	0101000020E6100000D5EC81566052524000C5C89239804B40
66233	5	53	\N	41	4678	\N	55.001756999999998	Омская область, город Омск, Кировский административный округ, бульвар Зарченый, 3	Россия, Омская область, Омск, Заречный бульвар, 3	0101000020E6100000D5EC81566052524000C5C89239804B40
66232	5	53	\N	41	4678	\N	55.003166999999998	Омская область, город Омск, Кировский административный округ, бульвар Заречный, 5	Россия, Омская область, Омск, Заречный бульвар, 5	0101000020E61000006F675F799052524095B6B8C667804B40
66231	5	53	\N	41	4678	\N	55.002490000000002	Омская область, город Омск, Кировский административный округ, бульвар Заречный, 8	Россия, Омская область, Омск, Заречный бульвар, 8	0101000020E6100000D926158DB55252409548A29751804B40
66452	5	53	\N	41	16466	\N	55.064334000000002	Омская область, город Омск, микрорайон Загородный, 13	Россия, Омская область, Омск, поселок Загородный, Загородный микрорайон, 13	0101000020E61000000569C6A2E9605240AC02B5183C884B40
66292	5	53	\N	41	73587	\N	55.015542000000003	Омская область, город Омск, Долгирева, 79		0101000020E610000067F0F78BD956524073DBBE47FD814B40
66228	5	53	\N	41	73542	\N	54.988545999999999	Омская область, город Омск, Кировский административный округ, Дмитриева, 4 к.3		0101000020E6100000FD8348861C545240BA4BE2AC887E4B40
66491	5	53	\N	41	73603	\N	54.970576999999999	Омская область, город Омск, Декабристов, 121		0101000020E6100000CEAACFD556595240F99FFCDD3B7C4B40
66487	5	53	\N	41	73603	\N	54.965119000000001	Омская область, город Омск, Декабристов, 178		0101000020E6100000C7B94DB857595240C6DFF604897B4B40
66284	5	53	\N	41	5321	\N	54.935502999999997	Омская область, город Омск, Ленинский административный округ, п.Дальний, 1	Россия, Омская область, Омск, Дальний поселок, 1	0101000020E6100000E0F76F5E9C605240AA27F38FBE774B40
66302	5	53	\N	41	29721	\N	54.990302	Омская область, город Омск, Ленинский административный округ, Гуртьевской дивизии, 7		0101000020E6100000B0C8AF1F62575240EA944737C27E4B40
66309	5	53	\N	41	73677	\N	54.920760000000001	Омская область, город Омск, Ленинский административный округ, Гуртьева, 1б		0101000020E6100000CFD72C978D59524084BBB376DB754B40
66287	5	53	\N	41	5336	\N	54.952863000000001	Омская область, город Омск, Ленинский административный округ, п.Входной, 101	Россия, Омская область, Омск, Входной микрорайон, 101	0101000020E6100000FF1F274C184B5240C3482F6AF7794B40
66286	5	53	\N	41	5336	\N	54.952097999999999	Омская область, город Омск, Ленинский административный округ, п.Входной, 22/2	Россия, Омская область, Омск, Входной микрорайон, 22/2	0101000020E6100000D0D6C1C1DE4A5240234BE658DE794B40
66257	5	53	\N	41	29412	\N	54.949634275158502	Омская область, город Омск, Ленинский административный округ, В.Иванова, 13	Россия, Омская область, Омск, Ленинский административный округ, улица Всеволода Иванова	0101000020E6100000A400513063585240B8955E9B8D794B40
66255	5	53	\N	41	29412	\N	54.946929434520499	Омская область, город Омск, Ленинский административный округ, В.Иванова, 5	Россия, Омская область, Омск, Ленинский административный округ, улица Всеволода Иванова	0101000020E61000007E6E68CA4E58524026512FF834794B40
66223	5	53	\N	41	73592	\N	54.991692	Омская область, город Омск, Кировский административный округ, Волгоградская, 34б		0101000020E61000004A99D4D00650524038DA71C3EF7E4B40
66220	5	53	\N	41	73540	\N	54.985683999999999	Омская область, город Омск, Кировский административный округ, Ватутина, 13 к.1		0101000020E6100000D4997B48F85152406118B0E42A7E4B40
66256	5	53	\N	41	29361	\N	54.895119335122402	Омская область, город Омск, Ленинский административный округ, В.Иванова, 13а	Россия, Омская область, Омск, Ленинский административный округ	0101000020E6100000B58D3F51D95852409D83674293724B40
66499	5	53	\N	41	7575	\N	54.992280999999998	Омская область, город Омск, Биофабрика, 14	Россия, Омская область, Омск, Биофабрика поселок, 14	0101000020E6100000394206F2EC5C524099B85510037F4B40
66335	5	53	\N	41	29359	\N	54.960654089559803	Омская область, город Омск, Октябрьский административный округ, 75 Гв. бригады, 10	Россия, Омская область, Омск, Октябрьский административный округ	0101000020E6100000910E0F61FC5F5240C362D4B5F67A4B40
66466	5	53	\N	41	73668	\N	55.001958999999999	Омская область, город Омск, 7-я Ремесленная, 77		0101000020E6100000895FB1868B5952406877483140804B40
66333	5	53	\N	41	73698	\N	54.978147	Омская область, город Омск, Октябрьский административный округ, 50 лет ВЛКСМ, 7б		0101000020E6100000E31C75745C5E52401BD7BFEB337D4B40
66472	5	53	\N	41	7272	\N	54.981318999999999	Омская область, город Омск, 5-я Линия, 117б	Россия, Омская область, Омск, 5-я линия, 117б	0101000020E6100000C8B7770DFA595240C2F869DC9B7D4B40
66352	5	53	\N	41	73644	\N	54.959417999999999	Омская область, город Омск, Октябрьский административный округ, 5 Кордная, 43а		0101000020E61000002F8B89CDC75D5240CC988235CE7A4B40
66322	5	53	\N	41	73637	\N	54.959277999999998	Омская область, город Омск, Октябрьский административный округ, 3 Транспортная, 2		0101000020E61000001D71C806D2595240DAE21A9FC97A4B40
66321	5	53	\N	41	73637	\N	54.959277999999998	Омская область, город Омск, Октябрьский административный округ, 3 транспортная, 2		0101000020E61000001D71C806D2595240DAE21A9FC97A4B40
66351	5	53	\N	41	73705	\N	54.952779999999997	Омская область, город Омск, Октябрьский административный округ, 3 молодежная, 65		0101000020E61000002331410DDF5D52403524EEB1F4794B40
66437	5	53	\N	41	73599	\N	55.023738000000002	Омская область, город Омск, 24-я Северная, 121		0101000020E61000008D7A88467758524013D6C6D809834B40
66364	5	53	\N	41	73647	\N	54.937314000000001	Омская область, город Омск, Октябрьский административный округ, 22 рабочая, 80		0101000020E6100000FF5A5EB9DE5B52409E0AB8E7F9774B40
66397	5	53	\N	41	73630	\N	55.042957999999999	Омская область, город Омск, Советский административный округ, 22 Апреля, 20а		0101000020E6100000CC26C0B0FC515240008DD2A57F854B40
66444	5	53	\N	41	73657	\N	55.032004999999998	Омская область, город Омск, 21-я Амурская, 19		0101000020E61000008A558330B75A52407C2766BD18844B40
66298	5	53	\N	41	30087	\N	54.907688	Омская область, город Омск, Ленинский административный округ, 2-я Электровозная, 15		0101000020E610000015731074B45652405F7CD11E2F744B40
66323	5	53	\N	41	15859	\N	54.952579	Омская область, город Омск, Октябрьский административный округ, 16 военный городок, 108	Россия, Омская область, Омск, военный городок 16-й, 16-й Военный городок, 108	0101000020E6100000800C1D3BA85952409EEDD11BEE794B40
66477	5	53	\N	41	7320	\N	54.989812000000001	Омская область, город Омск, 14-я Линия, 40	Россия, Омская область, Омск, 14-я линия, 41	0101000020E61000007862D68BA15A52401C98DC28B27E4B40
66304	5	53	\N	41	15771	\N	54.848722000000002	Омская область, город Омск, Ленинский административный округ, 14 Военный городок, 148	Россия, Омская область, Омск, военный городок 14-й, 14-й Военный городок, 148	0101000020E61000000AA1832EE1595240A7B228ECA26C4B40
66455	5	53	\N	41	73658	\N	54.987208000000003	Омская область, город Омск, 10 лет Октября, 149		0101000020E6100000CE16105A0F5B5240BF2CEDD45C7E4B40
66496	5	53	\N	41	30118	\N	55.007475715184803	Омская область, город Омск, 1-я Учхозная, 25	Россия, Омская область, Омск, Центральный административный округ, 1-я Учхозная улица	0101000020E61000005E0F26C5C75D5240A0C03BF9F4804B40
66213	5	53	\N	41	73612	\N	55.004576	Омская область, город Омск, 1-я Северная, 39		0101000020E61000004948A46DFC5652405A2C45F295804B40
66354	5	53	\N	41	76470	\N	54.942599000000001	Омская область, город Омск, Октябрьский административный округ, 1 Полевая, 7		0101000020E61000009EB12FD978615240041F8315A7784B40
66373	5	53	\N	41	29487	\N	54.990302	Омская область, город Омск, Советский административный округ, 1-я Осенняя, 45		0101000020E6100000B0C8AF1F62575240EA944737C27E4B40
66433	5	53	\N	41	6884	\N	55.008479999999999	Омская область, город Омск, 1-я Челюскинцев, 92	Россия, Омская область, Омск, 1-й Челюскинцев проезд	0101000020E6100000A29927D7145A5240C55565DF15814B40
67335	5	53	\N	13096	29095	\N	55.01867	с.Новомосковка, Интернациональная, 5		0101000020E61000009E7DE5417A6252404AB54FC763824B40
67102	5	53	\N	48683	29184	\N	56.405344999999997	р.п.Муромцево, ул. Зеленая, 22		0101000020E610000063B5F97FD5D252406E4C4F58E2334C40
67350	5	53	\N	7329	1990	\N	54.929493000000001	п.Магистральный, Молодежная, 13 В		0101000020E6100000CA349A5C8C4F5240336E6AA0F9764B40
67898	5	53	245	46330	29343	\N	54.393129999999999	д. Яблоновка, ул. Центральная, 26		0101000020E6100000E124CD1FD3245240CA89761552324B40
67872	5	53	245	32275	29873	\N	54.629153000000002	р.п. Шербакуль, пл. Гуртьева, 2		0101000020E6100000E692AAED261952401497E31588504B40
67873	5	53	245	32275	29079	\N	54.629153000000002	р.п. Шербакуль, ул. Чапаева, 27		0101000020E6100000E692AAED261952401497E31588504B40
67871	5	53	245	32275	29609	\N	54.629153000000002	р.п. Шербакуль, пл. Гуртьева, 1		0101000020E6100000E692AAED261952401497E31588504B40
67883	5	53	245	60850	76465	\N	54.377527000000001	а. Шахат, ул. Джамбула, 3	Россия, Омская область, Шербакульский район, поселок Шахат	0101000020E6100000290989B48D185240B22D03CE52304B40
67900	5	53	245	60851	76466	\N	54.328150000000001	д. Чадск, ул. Школьная, 23	Россия, Омская область, Шербакульский район, поселок Чадское	0101000020E6100000FBE59315C32452405917B7D1002A4B40
67890	5	53	245	46150	29895	\N	54.642144000000002	"д. Центральное, ул. Советская, 3""а"""	Россия, Омская область, Шербакульский район, поселок Центральное	0101000020E6100000CD902A8A572352404CA94BC631524B40
67891	5	53	245	973	29759	\N	54.591746999999998	д. Тарналы, ул. Фермерская, 1		0101000020E6100000C614AC71362B5240C8409E5DBE4B4B40
67892	5	53	245	1018	29340	\N	54.445869000000002	с. Таловское, ул. Северная, 38		0101000020E61000004643C6A3541252406EA6423C12394B40
67901	5	53	245	46402	29208	\N	54.295504999999999	д. Солнцево, ул. Центральная, 27		0101000020E6100000AA45443179245240F9669B1BD3254B40
67895	5	53	245	46261	29626	\N	54.47448	д. Славянское, ул. Зеленая, 13		0101000020E6100000BDFF8F1326085240944DB9C2BB3C4B40
67885	5	53	245	46039	29886	\N	54.336449999999999	д. Новоскатовка, ул. Центральная, 30		0101000020E6100000FDC0559E401252409E5E29CB102B4B40
67877	5	53	245	52999	29427	\N	54.523561000000001	с. Максимовка, ул. Ленина, 19		0101000020E610000005888219530B5240043BFE0B04434B40
67880	5	53	245	45928	29880	\N	54.467433	с. Кутузовка, ул. Молодежная, 45		0101000020E6100000C80A7E1B622152401C0934D8D43B4B40
67884	5	53	245	30437	76543	\N	54.373967999999998	а. Кудук-Чилик, ул. Школьная, 6	Россия, Омская область, Шербакульский район, поселок Кудук-Чилик	0101000020E6100000AB4198DBBD1F524011E0F42EDE2F4B40
67785	5	53	245	28239	28675	\N	54.308030000000002	д. Крушановка, ул. 30 лет Целины, 17	Россия, Омская область, Шербакульский район, поселок Крушановка	0101000020E6100000D845D1031F1B5240EC17EC866D274B40
67894	5	53	245	46234	29504	\N	54.436256	д. Красный Восток, ул. Победы, 16		0101000020E6100000F4160FEF390B52408657923CD7374B40
14621	5	53	245	53094	30062	\N	54.385201025613398	с. Красноярка, Ленина, 15	Россия, Омская область, Шербакульский район, поселок Красноярка	0101000020E6100000863C821B292B524079B130444E314B40
67889	5	53	245	60823	76418	\N	54.505006000000002	"д. 1-е Комиссаровское, ул. Центральная, 1""а"""	Россия, Омская область, Шербакульский район, поселок Комиссаровское-1	0101000020E6100000996379573D2E524053245F09A4404B40
67899	5	53	245	1451	29210	\N	54.364114999999998	д. Кокчинск, ул. Школьная, 27		0101000020E610000051A04FE449255240D47D00529B2E4B40
67897	5	53	245	60189	74003	\N	54.411188513313803	а. Карагаш, ул. Центральная, 25	Россия, Омская область, Шербакульский район, поселок Карагаш	0101000020E610000005FD851E312C5240CBBC55D7A1344B40
53471	5	53	245	53109	30113	\N	54.721178781714798	а. Койчубай, ул. Мира, 6	Россия, Омская область, Шербакульский район, поселок Кайчубай	0101000020E6100000B07614E7A82D5240EFC7ED974F5C4B40
67797	5	53	245	28789	29828	\N	54.674861	с. Изюмовка, ул. Школьная, 25		0101000020E6100000A3C9C51858295240452C62D861564B40
67879	5	53	245	45912	29877	\N	54.499234000000001	д. Елизаветино, ул. Школьная, 2		0101000020E6100000FC56EBC4E5045240908653E6E63F4B40
67882	5	53	245	45974	29584	\N	54.346049999999998	с. Екатеринославка, ул. Школьная, 38		0101000020E6100000D36BB3B1121D5240F163CC5D4B2C4B40
67881	5	53	245	45947	29494	\N	54.497070000000001	д. Дубровка, ул. Центральная, 28		0101000020E610000037397CD2891C52404FE960FD9F3F4B40
67713	5	53	245	47257	29097	\N	54.770546000000003	"д. Вишневка, ул. Школьная, 11""а"""		0101000020E61000006FF4311F1021524025085740A1624B40
67875	5	53	245	45821	29614	\N	54.588788999999998	"д. Вербовка, ул. Мира, 26 ""а"""		0101000020E61000009A97C3EE3B0F52404D9F1D705D4B4B40
67888	5	53	245	46108	29084	\N	54.624383999999999	с. Борисовское, ул. Советская, 17		0101000020E61000006A2FA2ED98255240A5129ED0EB4F4B40
67887	5	53	245	53114	30127	\N	54.727610142924703	"а. Большой Искак, ул. Пролетарская, 5 ""а"""	Россия, Омская область, Шербакульский район, поселок Большой Искак	0101000020E6100000118AADA0693452400C1F1153225D4B40
67876	5	53	245	60846	76459	\N	54.650506	д. Больше-Васильевка, ул. Лесная, 2		0101000020E6100000488B33863910524007EDD5C743534B40
67874	5	53	245	32397	29193	\N	54.635094000000002	с. Бабеж, ул. Победы, 18		0101000020E61000000E12A27C410D524063F19BC24A514B40
67886	5	53	245	46053	29493	\N	54.662703	с. Александровское, ул. Ленина, 33		0101000020E61000008672A25D852D524005FBAF73D3544B40
66620	5	53	1788	60807	76343	\N	54.547723919278504	д. Большое Озеро, Центральная, 20/1	Россия, Омская область, Черлакский район	0101000020E6100000239EEC6646985240FE9DEDD11B464B40
67827	5	53	1788	52986	30102	\N	54.157136123287302	Омская область, Черлакский муниципальный район, Черлакское городское поселение, Транспортная, 40	Россия, Омская область, Черлакский район, поселок Черлак	0101000020E610000095D233BDC4B352401B834E081D144B40
67826	5	53	1788	52986	30144	\N	54.157438375349997	Омская область, Черлакский муниципальный район, Черлакское городское поселение, Красноармейская, 52	Россия, Омская область, Черлакский район, поселок Черлак	0101000020E6100000BCB20B06D7B35240E692AAED26144B40
67829	5	53	1788	52986	30117	\N	54.156481236210801	Омская область, Черлакский муниципальный район, Черлакское городское поселение, Зеленая, 170	Россия, Омская область, Черлакский район, поселок Черлак	0101000020E6100000450E1137A7B3524002B9C49107144B40
67825	5	53	1788	52986	30121	\N	54.157992498372302	Омская область, Черлакский муниципальный район, Черлакское городское поселение, ул. Береговая, 13	Россия, Омская область, Черлакский район, поселок Черлак	0101000020E61000005BD3BCE314B45240CB83F41439144B40
67830	5	53	1788	52986	30151	\N	54.158748108664199	Омская область, Черлакский муниципальный район, Черлакское городское поселение, 4 Восточная, 38а	Россия, Омская область, Черлакский район, поселок Черлак	0101000020E6100000A7406667D1B352401827BEDA51144B40
67832	5	53	1788	52986	29325	\N	54.156783493078102	Омская область, Черлакский муниципальный район, Большеатмасское сельское поселение, 20 Лет Победы, 6	Россия, Омская область, Черлакский район, поселок Черлак	0101000020E6100000F838D384EDB35240CDC8207711144B40
67844	5	53	1788	30998	30003	\N	54.138131999999999	Омская область, Черлакский муниципальный район, Краснооктябрьское сельское поселение, д. Целинное, Школьная, 4		0101000020E61000005CAD1397E3BA5240FA43334FAE114B40
67867	5	53	1788	53126	30155	\N	53.879188747414297	Омская область, Черлакский муниципальный район, Татарское сельское поселение, ЖД ст. Черлак, Привокзальная, 9-2	Россия, Омская область, Черлакский район	0101000020E61000006F9C14E63DC752406000E14389F04A40
67862	5	53	1788	31881	\N	\N	53.960984000000003	Омская область, Черлакский муниципальный район, Татарское сельское поселение, с. Татарка, Зеленая, 42б	Россия, Омская область, Черлакский район, поселок Татарка	0101000020E6100000D89AADBCE4C3524059FD118601FB4A40
67860	5	53	1788	31762	29830	\N	54.475731000000003	Омская область, Черлакский муниципальный район, Солянское сельское поселение, д. Суворовка, Центральная, 4		0101000020E6100000DC679599D2AB5240C158DFC0E43C4B40
67691	5	53	873	23866	29159	\N	57.047967999999997	д.Новоермаковка, Таежная, 39		0101000020E61000000C23BDA8DDB0524094A0BFD023864C40
67848	5	53	1788	31197	29465	\N	54.402450000000002	Омская область, Черлакский муниципальный район, Курумбельское сельское поселение, д. Стретенка, Школьная, 23		0101000020E61000008D9AAF928FD552403A234A7B83334B40
67856	5	53	1788	31584	\N	\N	54.374071000000001	Омская область, Черлакский муниципальный район, Солянское сельское поселение, с. Соляное, 50 Лет Октября, 2б	Россия, Омская область, Черлакский район, поселок Соляное	0101000020E6100000CA54C1A8A4A65240E6B0FB8EE12F4B40
67857	5	53	1788	31584	29251	\N	54.374071000000001	Омская область, Черлакский муниципальный район, Солянское сельское поселение, с. Соляное, Октябрьская, 53		0101000020E6100000CA54C1A8A4A65240E6B0FB8EE12F4B40
67859	5	53	1788	31747	29432	\N	54.505299000000001	Омская область, Черлакский муниципальный район, Солянское сельское поселение, д. Северное, Центральная, 49		0101000020E610000068757286E2B05240CBD93BA3AD404B40
67835	5	53	1788	30565	29062	\N	54.248980000000003	Омская область, Черлакский муниципальный район, Елизаветинское сельское поселение, д. Путь Ленина, Транспортная, 4		0101000020E61000004DBF44BC75B35240D6AD9E93DE1F4B40
67836	5	53	1788	52437	29645	\N	54.335022000000002	Омская область, Черлакский муниципальный район, Елизаветинское сельское поселение д. Пробуждение, Школьная, 22		0101000020E61000008C868C47A9B8524063B83A00E22A4B40
67858	5	53	1788	31684	28686	\N	54.415686000000001	Омская область, Черлакский муниципальный район, Солянское сельское поселение, д. Привольное, Зеленая, 21		0101000020E6100000C98E8D40BCB05240D9B3E73235354B40
67854	5	53	1788	31437	29570	\N	54.313887000000001	Омская область, Черлакский муниципальный район, Николаевское сельское поселение, д. Преображенка, 1 Переулок, 4		0101000020E610000049D8B79388C65240DDD1FF722D284B40
67861	5	53	1788	31833	\N	\N	54.354525000000002	Омская область, Черлакский муниципальный район, Солянское сельское поселение, д. Подлесное, Центральная, 17	Россия, Омская область, Черлакский район, поселок Подлесное (отд. №5 свх. Коммунист)	0101000020E61000004703780B24AB5240A54E4013612D4B40
67851	5	53	1788	31364	29982	\N	54.103763000000001	Омская область, Черлакский муниципальный район, Медетское сельское поселение, д. Погранично-Григорьевка, Восточная, 3		0101000020E610000080D8D2A3A9D2524076C4211B480D4B40
67833	5	53	1788	30446	29736	\N	54.067030000000003	Омская область, Черлакский муниципальный район, Большеатмасское сельское поселение, д. Первый Шаг, Лесная, 2		0101000020E6100000FDFA213658D05240EAEC647094084B40
67865	5	53	1788	31985	29754	\N	53.883414999999999	Омская область, Черлакский муниципальный район, Татарское сельское поселение, д. Ольховка, Центральная, 8		0101000020E6100000E09D7C7A6CC35240DEE522BE13F14A40
67855	5	53	1788	31536	\N	\N	54.358381000000001	Омская область, Черлакский муниципальный район, Николаевское сельское поселение, д. Ольговка, Школьная, 1	Россия, Омская область, Черлакский район, поселок Ольговка	0101000020E610000092CEC0C8CBBF5240FF40B96DDF2D4B40
67852	5	53	1788	31413	29149	\N	54.260435999999999	Омская область, Черлакский муниципальный район, Николаевское сельское поселение, с. Николаевка, Мельникова, 13		0101000020E6100000AD307DAF21C15240BC5983F755214B40
67863	5	53	1788	60230	74076	\N	53.908005578249401	Омская область, Черлакский муниципальный район, Татарское сельское поселение, д. Народное Степное, Зеленая, 25а	Россия, Омская область, Черлакский район, поселок Народно-Степное	0101000020E6100000E277D32D3BC852403049658A39F44A40
67864	5	53	1788	60181	73979	\N	53.919145	Омская область, Черлакский муниципальный район, Татарское сельское поселение, д. Народное Береговое, Центральная, 17		0101000020E61000008A75AA7CCFC4524016A4198BA6F54A40
67845	5	53	1788	31074	\N	\N	54.148553999999997	Омская область, Черлакский муниципальный район, Краснооктябрьское сельское поселение, д. Михайловка, Школьная, 2	Россия, Омская область, Черлакский район, поселок Михайловка	0101000020E6100000BC202235EDCF524051D845D103134B40
67849	5	53	1788	31257	30014	\N	54.184524000000003	Омская область, Черлакский муниципальный район, Медетское сельское поселение, с. Медет, Школьная, 9		0101000020E6100000E59D4319AAE25240DFA9807B9E174B40
67737	5	53	1788	26047	29523	\N	53.993386000000001	Омская область, Черлакский муниципальный район, Малый Атмас, Школьная, 27		0101000020E61000008E3EE60302BC5240F226BF4527FF4A40
67869	5	53	1788	32183	30030	\N	54.443716999999999	Омская область, Черлакский муниципальный район, Южно-Подольское сельское поселение, д. Макаркино, Советская, 53		0101000020E61000001D71C806D2BB5240F1D6F9B7CB384B40
67846	5	53	1788	31080	29458	\N	54.144244999999998	Омская область, Черлакский муниципальный район, Краснооктябрьское сельское поселение, д. Лесная База, Российская, 9/2		0101000020E610000008AEF204C2BD524046CEC29E76124B40
67866	5	53	1788	32055	29472	\N	53.974558999999999	Омская область, Черлакский муниципальный район, Татарское сельское поселение, д. Кузнецовка, Молодежная, 2		0101000020E610000004E8F7FD9BD45240E0826C59BEFC4A40
67841	5	53	1788	30853	29049	\N	54.465972999999998	Омская область, Черлакский муниципальный район, Иртышское сельское поселение, д. Крупское, Октябрьская, 2в		0101000020E6100000A514747B499F5240D5E8D500A53B4B40
67843	5	53	1788	30946	29301	\N	54.133954000000003	Омская область, Черлакский муниципальный район, Краснооктябрьское сельское поселение, с. Красный Октябрь, Победы, 31		0101000020E61000004FB16A10E6C052408E95986725114B40
67842	5	53	1788	30902	29453	\N	54.578943000000002	Омская область, Черлакский муниципальный район, Иртышское сельское поселение, д. Красный Овцевод, Школьная, 26б		0101000020E61000001478279F1E9D5240C39FE1CD1A4A4B40
67661	5	53	873	46166	29307	\N	56.950394000000003	д.Нерпинский Кордон, 2 Кордон, 16		0101000020E6100000B7F0BC546C9D52404628B682A6794C40
67850	5	53	1788	31277	29981	\N	54.138834000000003	Омская область, Черлакский муниципальный район, Медетское сельское поселение, д. Козинка, Школьная, 4		0101000020E6100000FF9600FC53DA524054C90050C5114B40
67838	5	53	1788	30714	29173	\N	54.491391	Омская область, Черлакский муниципальный район, Иртышское сельское поселение, с. Иртыш, Ленина, 98		0101000020E6100000AB7B6473D59752403D4679E6E53E4B40
67870	5	53	1788	32219	28693	\N	54.431710000000002	Омская область, Черлакский муниципальный район, Южно-Подольское сельское поселение, д. Золотухино, Кооперативная, 48		0101000020E6100000132BA391CFB2524097ADF54542374B40
67834	5	53	1788	60069	73725	\N	54.262558346080098	Омская область, Черлакский муниципальный район, Елизаветинское сельское поселение, Центральная, 15	Россия, Омская область, Черлакский район, поселок Елизаветинка	0101000020E6100000F2D1E28C61AB5240CEA623809B214B40
67847	5	53	1788	31159	30009	\N	54.379089999999998	Омская область, Черлакский муниципальный район, Курумбельское сельское поселение, с. Джартаргуль, Почтовая, 16		0101000020E6100000800C1D3BA8E45240CD1E680586304B40
67837	5	53	1788	30654	29069	\N	54.313068000000001	Омская область, Черлакский муниципальный район, Елизаветинское сельское поселение, д. Гринск, Школьная, 26		0101000020E6100000EE7893DFA2A952404AB6BA9C12284B40
67840	5	53	1788	30804	29729	\N	54.541761999999999	Омская область, Черлакский муниципальный район, Иртышское сельское поселение, д. Верхнеильинка, Мира, 38		0101000020E61000002A52616C21925240971B0C7558454B40
95159	5	53	1788	50013	29944	\N	54.442785000000001	Черлакский муниципальный район, Южно-подольское сельское поселение, д. Васьковка ул. Советская 21		0101000020E61000000247020D36C052406614CB2DAD384B40
67839	5	53	1788	30739	29045	\N	54.417185000000003	Омская область, Черлакский муниципальный район, Иртышское сельское поселение, д. Бердниково, Октябрьская, 65		0101000020E6100000CB2E185C739B5240DEB06D5166354B40
66830	5	53	4673	36928	29313	\N	61.658740999999999	с. Чапаево (школа), Зеленая, 37		0101000020E61000008849B890C72C604065C405A051D44E40
67823	5	53	1443	53101	30094	\N	57.649765271667803	Омская область, Усть-Ишимский муниципальный район, Ярковское сельское поселение с. Ярково, Октябрьская, 16	Россия, Омская область, Усть-Ишимский район, поселок Ярково	0101000020E6100000C9ACDEE176DD5140F08AE07F2BD34C40
67810	5	53	1443	60825	76423	\N	57.660485000000001	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение п. Южный, Магистральная, 1 А	Россия, Омская область, Усть-Ишимский район, поселок Южный	0101000020E61000007B681F2BF8CB5140D13FC1C58AD44C40
67822	5	53	1443	60845	76458	\N	57.691015999999998	Омская область, Усть-Ишимский муниципальный район, Ярковское сельское поселение д. Эбаргуль, Центральная, 6	Россия, Омская область, Усть-Ишимский район, поселок Эбаргуль	0101000020E6100000936E4BE482D85140A181583673D84C40
67820	5	53	1443	60131	73865	\N	57.738010775543202	Омская область, Усть-Ишимский муниципальный район, Утускунское сельское поселение с. Утускун, Советская, 33	Россия, Омская область, Усть-Ишимский район, поселок Утускун	0101000020E610000058C51B9947D551404C8BFA2477DE4C40
67813	5	53	1443	52408	29993	\N	57.694884000000002	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, Школьная (Общежитие ПУ-50), 18		0101000020E61000004B598638D6CA5140C0417BF5F1D84C40
67817	5	53	1443	52408	30105	\N	57.6873920132848	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, Советская (ДК), 35	Россия, Омская область, Усть-Ишимский район, поселок Усть-Ишим	0101000020E6100000C2DEC4909CCA51401AC40776FCD74C40
67814	5	53	1443	52408	30134	\N	57.691760967055501	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, Садовая (АТП), 39	Россия, Омская область, Усть-Ишимский район, поселок Усть-Ишим	0101000020E6100000FDDD3B6A4CCA5140FAD2DB9F8BD84C40
67812	5	53	1443	52408	76460	\N	57.693321416779703	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, Карбышева (Лесхоз), 23	Россия, Омская область, Усть-Ишимский район, поселок Усть-Ишим	0101000020E61000004DA25EF069CA5140A45016BEBED84C40
67816	5	53	1443	52408	30149	\N	57.692031893903398	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, Горького (ДНТ), 1	Россия, Омская область, Усть-Ишимский район, поселок Усть-Ишим	0101000020E61000005CAFE94141CA51408AE42B8194D84C40
67815	5	53	1443	52408	30149	\N	57.691485190521298	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, Горького (ДДТ), 28	Россия, Омская область, Усть-Ишимский район, поселок Усть-Ишим	0101000020E610000010E84CDA54CA514058569A9482D84C40
67818	5	53	1443	52408	29294	\N	57.694884000000002	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, Агалакова (Метеостанция), 33 А		0101000020E61000004B598638D6CA5140C0417BF5F1D84C40
67811	5	53	1443	52408	29652	\N	57.694884000000002	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение с. Усть-Ишим, 40 лет Октября ПУ-50, 107		0101000020E61000004B598638D6CA5140C0417BF5F1D84C40
67807	5	53	1443	60228	74069	\N	57.5028170486177	Омская область, Усть-Ишимский муниципальный район, Слободчиковское сельское поселение с. Слободчики, Центральная, 24	Россия, Омская область, Усть-Ишимский район, поселок Слободчики	0101000020E6100000328FFCC1C0BB5140B96FB54E5CC04C40
67692	5	53	873	46825	29139	\N	56.727097000000001	с.Нагорное, Центральная, 34Б		0101000020E61000005BB6D61709B952408602B683115D4C40
67806	5	53	1443	53103	30096	\N	57.797140808239	Омская область, Усть-Ишимский муниципальный район, Пановское сельское поселение п. Скородум, Советская, 36	Россия, Омская область, Усть-Ишимский район, поселок Скородум	0101000020E61000008E05854199BB51407FA65EB708E64C40
67799	5	53	1443	52391	29399	\N	57.766387000000002	Омская область, Усть-Ишимский муниципальный район, Загваздинское сельское поселение д. Саургачи, Школьная, 9		0101000020E6100000FDBFEAC891AC51402F8A1EF818E24C40
67805	5	53	1443	60835	76447	\N	57.795408999999999	Омская область, Усть-Ишимский муниципальный район, Пановское сельское поселение с. Паново, Центральная, 16	Россия, Омская область, Усть-Ишимский район, поселок Паново	0101000020E6100000CB0F5CE509B55140D7F84CF6CFE54C40
67803	5	53	1443	52403	29280	\N	57.455170000000003	Омская область, Усть-Ишимский муниципальный район, Ореховское сельское поселение с. Орехово, Школьная, 32		0101000020E6100000F226BF4527B65140670FB40243BA4C40
67802	5	53	1443	52993	29356	\N	57.7399937236517	Омская область, Усть-Ишимский муниципальный район, Никольское сельское поселение, Советская, 18	Россия, Омская область, Усть-Ишимский район, поселок Никольск	0101000020E61000006D6FB72407CB51403D9E961FB8DE4C40
66896	5	53	1443	52993	29356	\N	57.740177327757898	д. Никольск (д. Моторово), Советская, 1	Россия, Омская область, Усть-Ишимский район, поселок Никольск	0101000020E610000059315C1D00CB51402E20B41EBEDE4C40
67794	5	53	1443	53125	30147	\N	57.939484661698103	Омская область, Усть-Ишимский муниципальный район, Большебичинское сельское поселение п. Малая Бича, Лесная, 17	Россия, Омская область, Усть-Ишимский район, поселок Малая Бича	0101000020E6100000C1374D9F1D9D5140910A630B41F84C40
67824	5	53	1443	30014	29715	\N	57.680709999999998	д. Летние, ул. Центральная, 16,  клуб		0101000020E6100000E2CB441152CF5140B3075A8121D74C40
67288	5	53	1443	47930	\N	\N	57.732700000000001	"с.Красноярка, Санаторий ""Колос"""		0101000020E6100000B3CEF8BEB8D05140BDE3141DC9DD4C40
67793	5	53	1443	28578	\N	\N	57.919395000000002	Омская область, Усть-Ишимский муниципальный район, Большебичинское сельское поселение, д. Кайнаул, 45		0101000020E610000011AAD4EC819B51408F8D40BCAEF54C40
67800	5	53	1443	51912	28687	\N	57.291137340671298	Омская область, Усть-Ишимский муниципальный район, Кайлинское сельское поселение с. Кайлы, Школьная, 2	Россия, Омская область, Усть-Ишимский район, поселок Кайлы	0101000020E61000000400C79E3DAC5140E9D32AFA43A54C40
67821	5	53	1443	52413	29282	\N	57.617507000000003	Омская область, Усть-Ишимский муниципальный район, Ярковское сельское поселение д. Ильчебага, Гаражная, 6		0101000020E6100000BABE0F0709E351408A0629780ACF4C40
67831	5	53	1443	30336	29176	\N	57.751362999999998	Омская область, Черлакский муниципальный район, Черлакское городское поселение, Затон, Колеватова, 1		0101000020E61000006DA818E76FBA51405436ACA92CE04C40
67798	5	53	1443	53122	30142	\N	57.816607554859402	Омская область, Усть-Ишимский муниципальный район, Загваздинское сельское поселение с. Загваздино, Советская, 78	Россия, Омская область, Усть-Ишимский район, поселок Загваздино	0101000020E6100000EBFD463B6EA4514074D3669C86E84C40
67804	5	53	1443	60226	74067	\N	57.793648915176298	Омская область, Усть-Ишимский муниципальный район, Пановское сельское поселение п. Борки, Центральная, 21	Россия, Омская область, Усть-Ишимский район, поселок Борки	0101000020E6100000831953B0C6B6514066C0594A96E54C40
67796	5	53	1443	52389	29274	\N	57.730359999999997	Омская область, Усть-Ишимский муниципальный район, Большетебендинское сельское поселение с. Большая Тебендя, Школьная, 1		0101000020E610000034BDC458A6B551403D27BD6F7CDD4C40
67795	5	53	1443	60840	76452	\N	57.498058999999998	Омская область, Усть-Ишимский муниципальный район, Большетавинское сельское поселение с. Большая Тава, Центральная, 13	Россия, Омская область, Усть-Ишимский район, поселок Большая Тава	0101000020E61000005C397B67B4CC51403E3DB665C0BF4C40
67792	5	53	1443	52381	29608	\N	57.872911000000002	Омская область, Усть-Ишимский муниципальный район, Большебичинское сельское поселение с. Большая Бича, Школьная, 2		0101000020E6100000DE7536E49FA75140CAA8328CBBEF4C40
67791	5	53	1443	53043	\N	\N	57.9132969581118	Омская область, Усть-Ишимский муниципальный район, Большебичинское сельское поселение, д. Бакшеево, д. 46	Россия, Омская область, Усть-Ишимский район, поселок Бакшеева	0101000020E610000019ABCDFFAB9F5140784485EAE6F44C40
67808	5	53	1443	60843	76456	\N	57.635257000000003	Омская область, Усть-Ишимский муниципальный район, Усть-Ишимское сельское поселение д. Ашеваны, Центральная, 3		0101000020E61000006840BD1935CC51400DC7F31950D14C40
67819	5	53	1443	16296	30120	\N	57.686648883910003	Омская область, Усть-Ишимский муниципальный район, Утускунское сельское поселение п. Аксеново, Советская, 33	Россия, Омская область, Усть-Ишимский район, поселок Аксёново	0101000020E6100000FC389A232BE05140626A4B1DE4D74C40
67744	5	53	447	26358	29930	\N	55.989390999999998	Омская область, Тюкалинский муниципальный район, Атрачинское сельское поселение,  Ярославка, Ленина, 32		0101000020E61000003A234A7B83F6514076FA415DA4FE4B40
67027	5	53	447	60824	76420	\N	55.9247752460032	д. Чистое Поле, Солнечная, 26	Россия, Омская область, Тюкалинский район, поселок Чистое	0101000020E6100000CF143AAFB12952404694F6065FF64B40
67755	5	53	447	26858	30083	\N	55.723486000000001	Омская область, Тюкалинский муниципальный район, Валуевское сельское поселение, д. Черноусово, Центральная, 25/А		0101000020E61000005BEA20AF07045240938E72309BDC4B40
67743	5	53	447	26318	30072	\N	55.936211999999998	Омская область, Тюкалинский муниципальный район, Атрачинское сельское поселение, Чащино, Центральная, 28/А		0101000020E61000000D0055DCB80A5240B60F79CBD5F74B40
67787	5	53	447	28309	29823	\N	56.225763000000001	Омская область, Тюкалинский муниципальный район, Хуторское сельское поселение, д. Хутора, Школьная, 2/А		0101000020E610000076FEEDB25F0C5240CCD24ECDE51C4C40
67730	5	53	447	59474	71518	\N	55.855764691195098	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, Калинина, 70/А	Россия, Омская область, Тюкалинский район	0101000020E6100000675F79909E0D5240DD0720B589ED4B40
67734	5	53	447	25792	73674	\N	55.871306818007298	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, Первомайская улица, 7	Россия, Омская область, Тюкалинский район, Тюкалинск	0101000020E6100000F607CA6DFB0C524050E3DEFC86EF4B40
67736	5	53	447	25792	76446	\N	55.869676104292502	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, Ленина, 41	Россия, Омская область, Тюкалинский район, Тюкалинск	0101000020E6100000D6E07D552E0D5240DC0E0D8B51EF4B40
67731	5	53	447	25792	29781	\N	55.869096999999996	Омская область, Тюкалинский муниципальный район,  г.Тюкалинск, Калинина, 70/А		0101000020E6100000B2F677B6470C52409E060C923EEF4B40
67735	5	53	447	25792	29190	\N	55.872329925919701	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, 30 лет Победы, 34	Россия, Омская область, Тюкалинский район, Тюкалинск	0101000020E610000050E3DEFC860C5240EBA86A82A8EF4B40
67732	5	53	447	25792	12185	\N	55.865611980916803	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, 2-Береговая, 2/А		0101000020E6100000E2C96E66F40C52403883BF5FCCEE4B40
67733	5	53	447	25792	29748	\N	55.871895614969098	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, 2-Магистральная улица, 3	Россия, Омская область, Тюкалинский район, Тюкалинск	0101000020E6100000ED48F59D5F0C5240B1C1C2499AEF4B40
67739	5	53	447	25792	29601	\N	55.976655000000001	Омская область, Тюкалинский муниципальный район, Тюкалинское городское поселение, 1-Кооперативная, 13		0101000020E6100000A65F22DE3A205240C93CF20703FD4B40
67784	5	53	447	28178	29415	\N	55.701754999999999	Омская область, Тюкалинский муниципальный район, Троицкое сельское поселение, с. Троицк, Школьная, 6		0101000020E61000007EFE7BF0DA0E5240F9669B1BD3D94B40
67778	5	53	447	27909	28667	\N	56.097848999999997	Омская область, Тюкалинский муниципальный район, Новокошкульское сельское поселение, д. Старый Конкуль, Новая, 19		0101000020E610000047E867EA750452402079E750860C4C40
67782	5	53	447	28096	29380	\N	56.198425	Омская область, Тюкалинский муниципальный район, Старосолдатское сельское поселение, с. Старосолдатское, Советская, 8/А		0101000020E6100000848252B472275240BADA8AFD65194C40
67790	5	53	447	28451	29693	\N	56.125500000000002	Омская область, Тюкалинский муниципальный район, Хуторское сельское поселение, д. Соколовка, Центральная, 16/А		0101000020E6100000F5A10BEA5B0E5240F2D24D6210104C40
66769	5	53	447	46772	\N	\N	55.747357999999998	д. Сергеевка, Сергеевский сельский клуб		0101000020E61000007592AD2EA7185240B5334C6DA9DF4B40
67759	5	53	447	27062	29309	\N	56.267296999999999	Омская область, Тюкалинский муниципальный район, Кабырдакское сельское поселение, д. Сарыбалы, Юбилейная, 27		0101000020E6100000C6A70018CF1A5240D2A8C0C936224C40
67780	5	53	447	28006	29936	\N	55.890694000000003	Омская область, Тюкалинский муниципальный район, Сажинское сельское поселение, с. Сажино, Центральная, 17		0101000020E6100000340EF5BBB0185240295FD04202F24B40
67751	5	53	447	26710	29122	\N	56.107523	Омская область, Тюкалинский муниципальный район, Белоглазовское сельское поселение, д. Приозерка, Почтовая, 4		0101000020E61000003602F1BA7E255240AE484C50C30D4C40
67763	5	53	447	27240	29949	\N	55.941147999999998	Омская область, Тюкалинский муниципальный район, Коршуновское сельское поселение, д. Охотниково, Центральная, 19		0101000020E61000003AC95697533352401059A48977F84B40
67789	5	53	447	28394	29692	\N	56.348193000000002	Омская область, Тюкалинский муниципальный район, Хуторское сельское поселение, д. Островная, Береговая, 24		0101000020E6100000CFBBB1A0300952401BD99596912C4C40
67786	5	53	447	52378	29659	\N	55.761192999999999	Омская область, Тюкалинский муниципальный район, Троицкое сельское поселение, д. ОрловоКукушкино, Центральная, 7		0101000020E6100000807EDFBF790C5240D978B0C56EE14B40
67772	5	53	447	27628	29130	\N	55.898175000000002	Омская область, Тюкалинский муниципальный район, Нагибинское сельское поселение, д. Орловка, Центральная, 28		0101000020E6100000BE4A3E76172F5240DB8AFD65F7F24B40
67779	5	53	447	27968	29815	\N	55.818396999999997	Омская область, Тюкалинский муниципальный район, Октябрьское сельское поселение, п. Октябрьский, Ленина, 28		0101000020E610000064744012F60D52407F129F3BC1E84B40
67120	5	53	447	27968	28695	\N	55.818396999999997	п. Октябрьский, Зеленая, 1 А		0101000020E610000064744012F60D52407F129F3BC1E84B40
67748	5	53	447	26565	29657	\N	55.54945	Омская область, Тюкалинский муниципальный район, Бекишевское сельское поселение, д. Оброскино, Школьная, 20/А		0101000020E61000004F58E201652A5240C364AA6054C64B40
67775	5	53	447	27786	29407	\N	55.992154999999997	Омская область, Тюкалинский муниципальный район, Новокошкульское сельское поселение,  Новый Кошкуль, Ленина, 18/А		0101000020E61000001E51A1BAB91552400CC85EEFFEFE4B40
67777	5	53	447	27870	29681	\N	56.085405000000002	Омская область, Тюкалинский муниципальный район, Новокошкульское сельское поселение, д. Новый Конкуль, Центральная, 9/А		0101000020E6100000B988EFC4AC0552401BF5108DEE0A4C40
67770	5	53	447	27532	29789	\N	55.763998999999998	Омская область, Тюкалинский муниципальный район, Нагибинское сельское поселение, Нагибино, Юбилейная, 12		0101000020E610000004543882542D52409E961FB8CAE14B40
67767	5	53	447	27405	29405	\N	55.642955999999998	Омская область, Тюкалинский муниципальный район, Малиновское сельское поселение, с. Малиновка, Ленина, 5		0101000020E610000072A43330F22152402C62D8614CD24B40
67747	5	53	447	26510	29379	\N	55.642620999999998	Омская область, Тюкалинский муниципальный район, Бекишевское сельское поселение, д. Максимовка, Молодежная, 19/А		0101000020E6100000FC8D76DCF02C5240855CA96741D24B40
67788	5	53	447	32502	29433	\N	56.189619999999998	Омская область, Тюкалинский муниципальный район, Хуторское сельское поселение, Луговая, Луговая, 1		0101000020E6100000D4D2DC0A610952407155D97745184C40
67754	5	53	447	26828	29386	\N	55.660262000000003	Омская область, Тюкалинский муниципальный район, Валуевское сельское поселение, д. Лидинка, Центральная, 2/А		0101000020E61000008733BF9A03FB51405265187783D44B40
67742	5	53	447	26256	29108	\N	56.006914999999999	Омская область, Тюкалинский муниципальный район, Атрачинское сельское поселение, Лаптево, Центральная, 10/А		0101000020E6100000CA6FD1C952065240096D3997E2004C40
67757	5	53	447	26980	29123	\N	56.200071999999999	Омская область, Тюкалинский муниципальный район, Кабырдакское сельское поселение, Кумыра, Ленина, 25		0101000020E61000000D6C956071145240336C94F59B194C40
67781	5	53	447	28053	29262	\N	55.858640000000001	Омская область, Тюкалинский муниципальный район, Сажинское сельское поселение, д. Красный Шар, Центральная, 13		0101000020E61000005E64027E8D145240CB845FEAE7ED4B40
67764	5	53	447	27257	29668	\N	55.861978999999998	Омская область, Тюкалинский муниципальный район, Красноусовское сельское поселение, с. Красноусово, Ленина, 16		0101000020E6100000AE0FEB8D5A0152405D6BEF5355EE4B40
67776	5	53	447	27825	29677	\N	56.01708	Омская область, Тюкалинский муниципальный район, Новокошкульское сельское поселение, с. Кошкуль, Центральная, 13/А		0101000020E61000003BAC70CB4718524035B56CAD2F024C40
67761	5	53	447	27102	29699	\N	56.005046999999998	Омская область, Тюкалинский муниципальный район, Коршуновское сельское поселение, д. Коршуновка, ул. Школьная, 2/А		0101000020E61000004C89247A19385240B1F84D61A5004C40
67760	5	53	447	27102	29699	\N	56.005046999999998	Омская область, Тюкалинский муниципальный район, Коршуновское сельское поселение, с. Коршуновка, Школьная, 2/А		0101000020E61000004C89247A19385240B1F84D61A5004C40
67753	5	53	447	3060	29541	\N	55.580990999999997	Омская область, Тюкалинский муниципальный район, Валуевское сельское поселение, д. Короли, ул.Центральная,24		0101000020E61000000893E2E3130452409A22C0E95DCA4B40
67766	5	53	447	3176	29675	\N	55.845041000000002	Омская область, Тюкалинский муниципальный район, Красноусовское сельское поселение, д. Климино, Центральная, 18		0101000020E6100000FE9AAC510FFC5140BB63B14D2AEC4B40
67769	5	53	447	27525	29954	\N	55.759968000000001	Омская область, Тюкалинский муниципальный район, Малиновское сельское поселение, д. Каспиль, Заозерная, 7/А		0101000020E61000004A44F817411F5240D600A5A146E14B40
67783	5	53	447	28122	29411	\N	56.189069000000003	Омская область, Тюкалинский муниципальный район, Старосолдатское сельское поселение, д. Карбаиново, Школьная, 6		0101000020E610000082751C3F542F5240FED7B96933184C40
67756	5	53	447	3119	29847	\N	56.116838999999999	Омская область, Тюкалинский муниципальный район, Кабырдакское сельское поселение, с. Кабырдак, ул.Аптечная,1		0101000020E6100000E4688EACFC1B5240DCF29194F40E4C40
67774	5	53	447	27751	29680	\N	55.639913	Омская область, Тюкалинский муниципальный район, Никольское сельское поселение, д. Ильинка, Центральная, 19		0101000020E6100000938B31B08E19524083A44FABE8D14B40
67741	5	53	447	26213	29376	\N	55.988374	Омская область, Тюкалинский муниципальный район, Атрачинское сельское поселение, Зотино, Центральная, 20/А		0101000020E6100000280F0BB5A60B5240BD1B0B0A83FE4B40
67768	5	53	447	27461	29549	\N	55.668356000000003	Омская область, Тюкалинский муниципальный район, Малиновское сельское поселение, д. Залесная, Лесная, 22		0101000020E6100000A31F0DA7CC245240EE0A7DB08CD54B40
67762	5	53	447	27178	29934	\N	56.045217000000001	Омская область, Тюкалинский муниципальный район, Коршуновское сельское поселение, Журавлевка, Зеленая, 15		0101000020E61000009432A9A10D3C5240931CB0ABC9054C40
67746	5	53	447	2529	30074	\N	55.590623000000001	Омская область, Тюкалинский муниципальный район, Бекишевское сельское поселение, Гуровка, ул.Мира,43а		0101000020E610000005BF0D315E285240F9A1D28899CB4B40
67765	5	53	447	27325	29670	\N	55.857013000000002	Омская область, Тюкалинский муниципальный район, Красноусовское сельское поселение, д. Вторая Пятилетка, Центральная, 38/А		0101000020E61000002828452BF7095240999F1B9AB2ED4B40
67750	5	53	447	26625	29792	\N	55.993625000000002	Омская область, Тюкалинский муниципальный район, Белоглазовское сельское поселение, Восточный, Озерная, 6/А	Россия, Омская область, Тюкалинский район, поселок Восточный	0101000020E61000002C11A8FE4127524077BE9F1A2FFF4B40
67752	5	53	447	2618	29940	\N	55.693888699146797	Омская область, Тюкалинский муниципальный район, Валуевское сельское поселение, с. Валуевка, ул.Березовая, 3д	Россия, Омская область, Тюкалинский район, поселок Валуевка	0101000020E6100000D5415E0F26015240EE06D15AD1D84B40
67749	5	53	447	2613	29491	\N	56.052768	Омская область, Тюкалинский муниципальный район, Белоглазовское сельское поселение, с. Белоглазово, ул.Озерная, 31б		0101000020E61000006A6CAF05BD2A52403E23111AC1064C40
67745	5	53	447	26370	29529	\N	55.580981000000001	Омская область, Тюкалинский муниципальный район, Бекишевское сельское поселение, Бекишево, Мира, 43/А		0101000020E61000006F4562821A2D5240774CDD955DCA4B40
67544	5	53	873	40456	29203	\N	57.410994000000002	д. Петровка, Таежная, 10	Россия, Омская область, Тарский район, поселок Петровка	0101000020E6100000381268B0A9C65240166D8E739BB44C40
67740	5	53	447	26182	29925	\N	55.953623999999998	Омская область, Тюкалинский муниципальный район, Атрачинское сельское поселение, с. Атрачи, Ленина, 32/А		0101000020E6100000838593347F0152402157EA5910FA4B40
67706	5	53	1155	24600	29763	\N	57.590285999999999	Омская область, Тевризский муниципальный район, Александровское сельское поселение, д. Федоровка, Федоровская, 20		0101000020E610000078D0ECBAB7505240B1A4DC7D8ECB4C40
67727	5	53	1155	25581	30053	\N	57.576664999999998	Омская область, Тевризский муниципальный район, Утьминское сельское поселение, с. Утьма, Победы, 26		0101000020E61000003FA9F6E978F05140B9DFA128D0C94C40
67725	5	53	1155	25468	29358	\N	57.514043999999998	Омская область, Тевризский муниципальный район, Петровское сельское поселение, д. Утузы, Советская, 57		0101000020E61000002522FC8BA01052403E5A9C31CCC14C40
67729	5	53	1155	25681	29780	\N	57.608843999999998	Омская область, Тевризский муниципальный район, Утьминское сельское поселение, д. Ураш, Переулок Клубный, 1		0101000020E610000085D1AC6C1FE85140D32EA699EECD4C40
67701	5	53	1155	24013	29083	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Советская, 93		0101000020E610000051FA42C879195240670C738236C14C40
67699	5	53	1155	24013	29083	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Советская, 28		0101000020E610000051FA42C879195240670C738236C14C40
67698	5	53	1155	24013	29083	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Советская, 14		0101000020E610000051FA42C879195240670C738236C14C40
67703	5	53	1155	24013	29085	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Парковая, 2-А		0101000020E610000051FA42C879195240670C738236C14C40
67697	5	53	1155	24013	29336	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Павлика Морозова, 7-А		0101000020E610000051FA42C879195240670C738236C14C40
67700	5	53	1155	24013	29891	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Максима Горького, 1		0101000020E610000051FA42C879195240670C738236C14C40
67696	5	53	1155	24013	29758	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Карбышева, 33		0101000020E610000051FA42C879195240670C738236C14C40
67695	5	53	1155	24013	9899	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Гуртьева, 51		0101000020E610000051FA42C879195240670C738236C14C40
67694	5	53	1155	24013	9899	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Гуртьева, 60		0101000020E610000051FA42C879195240670C738236C14C40
67702	5	53	1155	24013	29892	\N	57.509475999999999	Омская область, Тевризский муниципальный район, р.п. Тевриз, Гагарина, 53		0101000020E610000051FA42C879195240670C738236C14C40
67709	5	53	1155	24769	29346	\N	57.407550999999998	Омская область, Тевризский муниципальный район, Бакшеевское сельское поселение, д. Ташетканы, Береговая, 36		0101000020E610000046239F573C335240DE3994A12AB44C40
67717	5	53	1155	25125	29634	\N	57.328316999999998	Омская область, Тевризский муниципальный район, Иваново-Мысское сельское поселение, с. Тайчи, Школьная, 3		0101000020E610000018963FDF164D524044DC9C4A06AA4C40
67728	5	53	1155	25632	30054	\N	57.590918000000002	Омская область, Тевризский муниципальный район, Утьминское сельское поселение, д. Тавинск, Молодежная, 9		0101000020E61000001D3C139A24ED5140124F7633A3CB4C40
67720	5	53	1155	25218	29776	\N	57.492569000000003	Омская область, Тевризский муниципальный район, Кипское сельское поселение, д. Поддол, Центральная, 2		0101000020E6100000C37DE4D6A4F75140000341800CBF4C40
67724	5	53	1155	25445	30048	\N	57.526494999999997	Омская область, Тевризский муниципальный район, Петровское сельское поселение, с. Петрово, Школьная, 13		0101000020E6100000FA264D83A2045240F6402B3064C34C40
67722	5	53	1155	25322	30047	\N	57.428165999999997	Омская область, Тевризский муниципальный район, Петелинское сельское поселение, с. Петелино, Школьная, 2		0101000020E61000008D4468041B2C52402BA1BB24CEB64C40
67708	5	53	1155	24690	29205	\N	57.396273000000001	Омская область, Тевризский муниципальный район, Бакшеевское сельское поселение, д. Нагорно-Аевск, Школьная, 8		0101000020E6100000D464C6DB4A3C5240D7A4DB12B9B24C40
67726	5	53	1155	53093	\N	\N	57.538426846388802	Омская область, Тевризский муниципальный район, Петровское сельское поселение, д. Малые Кулары, Здание школы, 41	Россия, Омская область, Тевризский район, поселок Малая Кулары	0101000020E6100000D6C8AEB48CFE514046240A2DEBC44C40
67704	5	53	1155	24501	29624	\N	57.520212000000001	Омская область, Тевризский муниципальный район, д. Кускуны, Школьная, 2		0101000020E610000038143E5B071D52404E7E8B4E96C24C40
67721	5	53	1155	25301	29638	\N	57.582740999999999	Омская область, Тевризский муниципальный район, Кузнецовское сельское поселение, с. Кузнецово, Гагарина, 2		0101000020E610000057EA5910CA0D5240E884D04197CA4C40
67719	5	53	1155	25202	30042	\N	57.533935999999997	Омская область, Тевризский муниципальный район, Кипское сельское поселение, д. Кипо-Кулары, Береговая, 14		0101000020E6100000844BC79C67F751401A14CD0358C44C40
67718	5	53	1155	25135	29771	\N	57.549954	Омская область, Тевризский муниципальный район, Кипское сельское поселение, с. Кип, Переулок Набережный, 2		0101000020E6100000234BE658DEF55140F62686E464C64C40
67801	5	53	1155	53037	29775	\N	57.660980302483203	Омская область, Усть-Ишимский муниципальный район, Кайсинское сельское поселение п. Кайсы, Кайсинская, 8	Россия, Омская область, Тевризский район, поселок Кайсы	0101000020E6100000FCE3BD6A65EC5140B1A71DFE9AD44C40
67716	5	53	1155	53102	30095	\N	57.385636524640503	Омская область, Тевризский муниципальный район, Иваново-Мысское сельское поселение, с. Иванов Мыс, Береговая, 38	Россия, Омская область, Тевризский район, поселок Иванов-Мыс	0101000020E6100000E3512AE10947524054909F8D5CB14C40
67715	5	53	1155	25016	29641	\N	57.501593999999997	Омская область, Тевризский муниципальный район, Журавлевское сельское поселение, с. Журавлевка, Клубная, 1		0101000020E6100000C0B0FCF9B62A524056EF703B34C04C40
67714	5	53	1155	24990	29630	\N	57.634881	Омская область, Тевризский муниципальный район, Ермиловское сельское поселение, с. Ермиловка, Северная, 42		0101000020E61000000FF10F5B7A3A524007EDD5C743D14C40
67712	5	53	1155	24908	29766	\N	57.603926000000001	Омская область, Тевризский муниципальный район, Екатерининское сельское поселение, с. Екатериновка, Школьная, 2		0101000020E6100000098849B8902A5240209A79724DCD4C40
67711	5	53	1155	10889	29996	\N	57.465845000000002	Омская область, Тевризский муниципальный район, Бородинское сельское поселение, п. Бородинка, Школьная, 3		0101000020E6100000D1764CDD953D5240A80018CFA0BB4C40
67710	5	53	1155	24789	29629	\N	57.586151999999998	Омская область, Тевризский муниципальный район, Белоярское сельское поселение, п. Белый Яр, Гагарина, 18		0101000020E6100000C53D963E74185240143E5B0707CB4C40
67707	5	53	1155	24675	29505	\N	57.400438000000001	Омская область, Тевризский муниципальный район, Бакшеевское сельское поселение, с. Бакшеево, Зеленая, 24		0101000020E610000000CADFBDA33F5240AF09698D41B34C40
67723	5	53	1155	25400	29357	\N	57.460655000000003	Омская область, Тевризский муниципальный район, Петелинское сельское поселение, д. Байбы, Школьная, 1		0101000020E610000014E813799222524094DE37BEF6BA4C40
67705	5	53	1155	24548	29500	\N	57.580458	Омская область, Тевризский муниципальный район, Александровское сельское поселение, с. Александровка, Молодежная, 2		0101000020E610000032C85D8429435240CD599F724CCA4C40
67687	5	53	873	60834	76445	\N	56.877579106243203	с.Екатерининское, Комсомольская, 1/1		0101000020E6100000CA367007EAA452400454388254704C40
67683	5	53	873	23494	29802	\N	56.696717999999997	с.Черняево, Победы, 22		0101000020E6100000AC1919E42EA152406B44300E2E594C40
67658	5	53	873	22356	29306	\N	56.9136562049394	с.Чекрушево, Первомайская, 28	Россия, Омская область, Тарский район, поселок Чекрушево	0101000020E610000029081EDFDE905240A8E507AEF2744C40
67681	5	53	873	60826	76425	\N	56.826787709991002	д.Фрунзе, Коммуны, 3А		0101000020E61000003599F1B6D2A05240D55C6E30D4694C40
67677	5	53	873	23218	29319	\N	56.675697	д. Усть-Тара, Зеленая, 35		0101000020E6100000DD0A613596A95240AE80423D7D564C40
67654	5	53	873	22159	29177	\N	57.206195000000001	д.Тимирка, Центральная, 23		0101000020E6100000D8648D7A888C5240A3CC0699649A4C40
67670	5	53	873	60829	76434	\N	56.939594145861903	д.Тимино, Центральная, 8	Россия, Омская область, Тарский район, поселок Тимино	0101000020E610000044DC9C4A0675524048C2BE9D44784C40
67635	5	53	873	6562	\N	\N	56.908085	г.Тара, пл. Ленина, 18	Россия, Омская область, Тарский район, Тара	0101000020E6100000543A58FFE79752407C7E18213C744C40
67630	5	53	873	6562	29976	\N	56.908085	г.Тара, Школьная, 69		0101000020E6100000543A58FFE79752407C7E18213C744C40
67629	5	53	873	6562	29169	\N	56.908085	г.Тара, Чкалова, 37		0101000020E6100000543A58FFE79752407C7E18213C744C40
67627	5	53	873	6562	29720	\N	56.908085	г.Тара, Транспортная, 22		0101000020E6100000543A58FFE79752407C7E18213C744C40
67626	5	53	873	6562	29720	\N	56.908085	г.Тара, Транспортная, 19		0101000020E6100000543A58FFE79752407C7E18213C744C40
67632	5	53	873	6562	29426	\N	56.908085	г.Тара, Советская, 42		0101000020E6100000543A58FFE79752407C7E18213C744C40
67631	5	53	873	6562	29426	\N	56.908085	г.Тара, Советская, 25		0101000020E6100000543A58FFE79752407C7E18213C744C40
67628	5	53	873	6562	29426	\N	56.908085	г.Тара, Советская, 75		0101000020E6100000543A58FFE79752407C7E18213C744C40
67640	5	53	873	6562	29244	\N	56.908085	г.Тара, Сельскохозяйственная, 1		0101000020E6100000543A58FFE79752407C7E18213C744C40
14614	5	53	873	6562	29768	\N	56.908085	г.Тара, Радищева, 17		0101000020E6100000543A58FFE79752407C7E18213C744C40
67625	5	53	873	6562	29590	\N	56.908085	г.Тара, Нерпинская, 48		0101000020E6100000543A58FFE79752407C7E18213C744C40
67638	5	53	873	6562	28893	\N	56.908085	г.Тара, Немчиновская, 69		0101000020E6100000543A58FFE79752407C7E18213C744C40
67639	5	53	873	6562	28688	\N	56.908085	г.Тара, Лихачева, 2		0101000020E6100000543A58FFE79752407C7E18213C744C40
67633	5	53	873	6562	29856	\N	56.908085	г.Тара, Ленина, 93		0101000020E6100000543A58FFE79752407C7E18213C744C40
67637	5	53	873	6562	29850	\N	56.908085	г.Тара, Калинина, 4		0101000020E6100000543A58FFE79752407C7E18213C744C40
67636	5	53	873	6562	29989	\N	56.908085	г.Тара, Избышева, 38		0101000020E6100000543A58FFE79752407C7E18213C744C40
67624	5	53	873	6562	28694	\N	56.908085	г.Тара, Елецкого, 1		0101000020E6100000543A58FFE79752407C7E18213C744C40
67623	5	53	873	6562	28694	\N	56.908085	г.Тара, Елецкого, 28	Россия, Омская область, Тарский район, Тара	0101000020E6100000543A58FFE79752407C7E18213C744C40
67634	5	53	873	6562	29120	\N	56.908085	г.Тара, Александровская, 78		0101000020E6100000543A58FFE79752407C7E18213C744C40
67669	5	53	873	22853	29468	\N	56.979370000000003	с.Соусканово, Зеленый пер, 5/2		0101000020E610000080D767CEFA7452407E5704FF5B7D4C40
67690	5	53	873	53008	29490	\N	57.009950000000003	д. Сидоровка, Черемуховая, 13	Россия, Омская область, Тарский район, поселок Сидоровка	0101000020E610000061FA5E4370A65240304CA60A46814C40
52720	5	53	873	46381	29299	\N	56.998911999999997	д.Сеитово, Молодежная, 12		0101000020E610000068B3EA73B58D52407DCA3159DC7F4C40
67662	5	53	873	60856	76474	\N	57.031508000000002	д.Сибиляково, Школьная, 13	Россия, Омская область, Тарский район, поселок Себеляково	0101000020E61000005E2C0C91D3865240FCC7427408844C40
67660	5	53	873	40295	9741	\N	56.9716046240328	с.Самсоново, Комсомольская, 33	Россия, Омская область, Тарский район, поселок Самсоново	0101000020E610000026C79DD2C1965240A6D0798D5D7C4C40
67652	5	53	873	7130	30007	\N	57.131605185733498	п.Пятилетка, Интернациональная, 47	Россия, Омская область, Тарский район, поселок Пятилетка	0101000020E61000002497FF907E875240BB7EC16ED8904C40
67651	5	53	873	22056	29175	\N	57.118203000000001	с.Пологрудово, Советская, 10		0101000020E610000033FD12F1D689524001A5A146218F4C40
67643	5	53	873	21662	29521	\N	57.466555999999997	п.Пихтовое, Рабочая, 9		0101000020E6100000FCA71B28F09E524054E0641BB8BB4C40
67659	5	53	873	53034	29737	\N	56.956451034795201	д.Петрово, Зеленая, 4/2	Россия, Омская область, Тарский район, поселок Петрово	0101000020E6100000575A46EA3D8B5240FE9C82FC6C7A4C40
66750	5	53	873	40456	\N	\N	57.410994000000002	д. Петровка, Петровский сельский клуб		0101000020E6100000381268B0A9C65240166D8E739BB44C40
67647	5	53	873	21784	76424	\N	57.092912790518398	д.Межевная, Центральная, 7/2	Россия, Омская область, Тарский район, поселок Межевная	0101000020E61000006C5D6A847EB65240C72FBC92E48B4C40
67675	5	53	873	46453	29064	\N	56.811526999999998	п.Междуречье, Центральная, 14		0101000020E610000044DC9C4A06A652401669E21DE0674C40
67674	5	53	873	46453	29314	\N	56.811526999999998	п.Междуречье, Советская, 49		0101000020E610000044DC9C4A06A652401669E21DE0674C40
67679	5	53	873	23317	29950	\N	56.720137999999999	д. Машканка, Центральная, 24		0101000020E6100000D13C80457EB35240AD4D637B2D5C4C40
67648	5	53	873	21871	29878	\N	57.118496	с.Мартюшево, Разгуляевой, 55		0101000020E6100000E607AEF204A15240795A7EE02A8F4C40
67665	5	53	873	46260	29056	\N	56.872146999999998	д.Лоскутово, Школьная, 1		0101000020E6100000DAA84E07B28E5240FA264D83A26F4C40
67666	5	53	873	46282	29714	\N	56.895038999999997	с.Ложниково, Тарская, 30		0101000020E6100000D7F6764B7278524080D250A390724C40
67520	5	53	873	15387	29347	\N	57.341665999999996	с.Литковка, Лесная, 53		0101000020E610000068D0D03FC1C65240DB1324B6BBAB4C40
67645	5	53	873	21769	29872	\N	57.17483	д. Курляно-Дубовка, Мира, 18		0101000020E6100000D8BCAAB35AB552400A2E56D460964C40
67471	5	53	873	47022	30019	\N	57.081505	д.Крапивка, пер. Школьный, 1		0101000020E61000004985B18520955240F1BA7EC16E8A4C40
67682	5	53	873	46630	30032	\N	56.750211	д.Коренево, Сельскохозяйственная, 27		0101000020E6100000ECF82F1004A15240BB0CFFE906604C40
67673	5	53	873	46442	29871	\N	56.805013000000002	д.Коновалово, Центральная, 12		0101000020E6100000A5F8F884EC7F52406CED7DAA0A674C40
67684	5	53	873	23509	29070	\N	56.688547	д.Кольтюгино, Хуторская, 40		0101000020E610000032AF230ED99352402461DF4E22584C40
67667	5	53	873	22771	29057	\N	56.885043000000003	с.Кириллино, Школьная, 20		0101000020E610000011A96917D3715240E146CA1649714C40
67678	5	53	873	23243	29582	\N	56.719278000000003	д. Киргап, Садовая, 19		0101000020E6100000D95E0B7A6FA75240BC5D2F4D115C4C40
51659	5	53	873	13234	29216	\N	57.330581000000002	д.Киксы, Центральная, 30/2		0101000020E6100000C571E0D572AA5240E9D66B7A50AA4C40
52268	5	53	873	10900	29633	\N	57.078344999999999	д.Ишеево, Центральная, 1		0101000020E6100000C367EBE0609752400E677E35078A4C40
67620	5	53	873	20492	29557	\N	57.355783000000002	с.Имшегал, Центральная, 17		0101000020E6100000D80B056C07A4524084BC1E4C8AAD4C40
67693	5	53	873	53010	29516	\N	56.727299000000002	д.Ивановка, Молодежная, 15А	Россия, Омская область, Тарский район, поселок Ивановка	0101000020E6100000707841446ABB5240EEB43522185D4C40
67680	5	53	873	46583	29476	\N	56.793790000000001	с.Заливино, Советская, 12А		0101000020E6100000CA198A3BDEA0524028F224E99A654C40
67689	5	53	873	46769	29197	\N	57.042552000000001	с.Ермаковка, Центральная, 50		0101000020E6100000520B259353AE524090300C5872854C40
67686	5	53	873	53121	30140	\N	56.877918164973899	с.Екатерининское, Советская, 64	Россия, Омская область, Тарский район, поселок Екатерининскоое	0101000020E610000028B7ED7BD4A45240ED48F59D5F704C40
67644	5	53	873	45802	29312	\N	57.166500999999997	с. Егоровка, пер.Первый, 2		0101000020E61000007A8B87F71CB952402AE09EE74F954C40
67657	5	53	873	46079	29460	\N	57.300533000000001	д.Гриневичи, Школьная, 14		0101000020E6100000C77F812040935240342F87DD77A64C40
67672	5	53	873	22952	28755	\N	56.857765000000001	с.Вставское, Свободы, 2		0101000020E6100000020EA14ACD7D5240A453573ECB6D4C40
67671	5	53	873	22948	29794	\N	56.755871999999997	с.Большие Туралы, Школьная, 14		0101000020E61000001DE90C8CBC7F524026FBE769C0604C40
67664	5	53	873	22606	29753	\N	56.713043999999996	д.Большие Кучки, Центральная, 14		0101000020E61000003CF54883DB865240F44D9A06455B4C40
67649	5	53	873	45890	29706	\N	57.149273999999998	д.Бобровка, Центральная, 27		0101000020E6100000E0A128D027AC5240511212691B934C40
67650	5	53	873	45937	29599	\N	57.059227	д.Баженово, Центральная, 44		0101000020E61000008FFE976BD1A05240250516C094874C40
67656	5	53	873	22290	29752	\N	57.255623999999997	с.Атирка, Восточная, 2А		0101000020E6100000B2632310AF9152404E098849B8A04C40
67676	5	53	873	23138	29466	\N	56.804377000000002	п.Атак, Горская, 9		0101000020E6100000D28C45D3D9A85240CA5356D3F5664C40
67583	5	53	1527	53085	29970	\N	54.569898999999999	Омская область, Таврический муниципальный район, ст. Стрела, Тополиная, д. 7		0101000020E6100000AB3E575BB16C5240F5824F73F2484B40
67600	5	53	1527	19366	29419	\N	54.345073999999997	Омская область, Таврический муниципальный район, д, Черноглазовка, Лесная, 11 Б		0101000020E6100000A19E3E027F825240965984622B2C4B40
66862	5	53	1527	18604	\N	\N	54.586551	Черниговка, Здание администрации сельского поселения		0101000020E6100000AD68739CDB5E5240D237691A144B4B40
67585	5	53	1527	18604	29406	\N	54.586551	Омская область, Таврический муниципальный район, д. Черниговка, Центральная, д. 21		0101000020E6100000AD68739CDB5E5240D237691A144B4B40
67614	5	53	1527	20159	29289	\N	54.690814000000003	Омская область, Таврический муниципальный район, с. Харламово, Мира, 1  В		0101000020E6100000821C9430D36752403ACFD8976C584B40
67599	5	53	1527	19345	29270	\N	54.409807000000001	Омская область, Таврический муниципальный район, д. Тихорецкое, Почтовая, 1 А		0101000020E6100000B91798158A8452400056478E74344B40
67574	5	53	1527	18055	29255	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, площадь Победы, д.12		0101000020E6100000849D62D5206952403468E89FE04A4B40
67576	5	53	1527	18055	29256	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Пролетарская, 29 А		0101000020E6100000849D62D5206952403468E89FE04A4B40
67575	5	53	1527	18055	29256	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Пролетарская, д. 29 А		0101000020E6100000849D62D5206952403468E89FE04A4B40
67581	5	53	1527	18055	29733	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Пионерская, д. 6		0101000020E6100000849D62D5206952403468E89FE04A4B40
67582	5	53	1527	18055	29258	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Пансионатная, 9		0101000020E6100000849D62D5206952403468E89FE04A4B40
67579	5	53	1527	18055	29128	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Лермонтова, д. 65		0101000020E6100000849D62D5206952403468E89FE04A4B40
67578	5	53	1527	18055	29673	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Ленина, д. 141		0101000020E6100000849D62D5206952403468E89FE04A4B40
67577	5	53	1527	18055	29401	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Клименко, д. 8		0101000020E6100000849D62D5206952403468E89FE04A4B40
67598	5	53	1527	18055	74059	\N	54.587775858644598	Омская область, Таврический муниципальный район, Отделение № 4, Зеленая, 6 Б	Россия, Омская область, Таврический район, поселок Таврическое	0101000020E61000008C9DF0129C695240D5AF743E3C4B4B40
67580	5	53	1527	18055	29800	\N	54.584980000000002	Омская область, Таврический муниципальный район, р.п. Таврическое, Гагарина, д. 16		0101000020E6100000849D62D5206952403468E89FE04A4B40
67610	5	53	1527	19876	29278	\N	54.601036000000001	Омская область, Таврический муниципальный район, с. Сосновское, Улыбина, д. 4		0101000020E610000022365838494A5240FDDB65BFEE4C4B40
67609	5	53	1527	19876	29278	\N	54.601036000000001	Омская область, Таврический муниципальный район, с. Сосновское, Улыбина, д. 5		0101000020E610000022365838494A5240FDDB65BFEE4C4B40
67604	5	53	1527	19576	29825	\N	54.496457999999997	Омская область, Таврический муниципальный район, д. Сосновка, Сосновка, 18 А		0101000020E6100000882EA86F9986524035EB8CEF8B3F4B40
67591	5	53	1527	18925	28669	\N	54.583117000000001	Омская область, Таврический муниципальный район, д. Солоновка, Березовая, д. 12 Б		0101000020E61000005952EE3EC77D5240EE5EEE93A34A4B40
67613	5	53	1527	52980	29209	\N	54.640732427591601	Омская область, Таврический муниципальный район, С. Садовое, переулок Сосновский	Россия, Омская область, Таврический район, поселок Садовое	0101000020E6100000D33252EFA94F524016C0948103524B40
67605	5	53	1527	19662	29697	\N	54.465553999999997	Омская область, Таврический муниципальный район, с. Пристанское, Совхозная, д. 2		0101000020E610000033198EE733965240D0420246973B4B40
67603	5	53	1527	19567	29563	\N	54.533926000000001	Омская область, Таврический муниципальный район, с. Прииртышье, Ленина, д. 11		0101000020E610000066868DB27E855240F73DEAAF57444B40
67608	5	53	1527	19779	29277	\N	54.503799000000001	Омская область, Таврический муниципальный район, д. Победа, Зеленая, д. 7		0101000020E6100000EF1D3526C4935240F660527C7C404B40
67589	5	53	1527	18818	28668	\N	54.480767999999998	Омская область, Таврический муниципальный район, д. Пальцевка, Карбышева, д. 14 А		0101000020E61000008FC536A9686952404E7B4ACE893D4B40
67595	5	53	1527	19135	29555	\N	54.354609000000004	Омская область, Таврический муниципальный район, п. Новоуральский, Школьная, д. 15 А		0101000020E61000008D5E0D501A88524003EFE4D3632D4B40
67597	5	53	1527	19135	29558	\N	54.354609000000004	Омская область, Таврический муниципальный район, п. Новоуральский, Майская, 3 А		0101000020E61000008D5E0D501A88524003EFE4D3632D4B40
67586	5	53	1527	18662	28665	\N	54.656948999999997	Омская область, Таврический муниципальный район, д. Новоселецк, Садовая, д. 21		0101000020E610000033A5F5B704615240E811A3E716544B40
67587	5	53	1527	18734	29959	\N	54.590238999999997	Омская область, Таврический муниципальный район, д. Новобелозёровка, Центральная, д. 23		0101000020E610000083328D26175B524070E998F38C4B4B40
67617	5	53	1527	20310	29843	\N	54.457572999999996	Омская область, Таврический муниципальный район, с. Неверовка, Пушкина, д. 9		0101000020E61000001E6D1CB1165352402C4487C0913A4B40
67622	5	53	1527	20636	29266	\N	54.528095999999998	Омская область, Таврический муниципальный район, д. Муртук, Центральная, 10		0101000020E6100000D78A36C7B9535240FF9254A698434B40
67592	5	53	1527	18991	29137	\N	54.432490000000001	Омская область, Таврический муниципальный район, с. Любомировка, Лизы Чайкиной, д. 6		0101000020E610000046EF54C03D6552406CEC12D55B374B40
67590	5	53	1527	18836	29963	\N	54.621355999999999	Омская область, Таврический муниципальный район, с. Луговое, Ленина, д. 2 А		0101000020E6100000C2323674B37952403196E997884F4B40
67615	5	53	1527	20195	30063	\N	54.702858999999997	Омская область, Таврический муниципальный район, д. Лобково, Тупик, 2/1		0101000020E61000004A0A2C80296452408159A148F7594B40
67612	5	53	1527	19986	29840	\N	54.555016000000002	Омская область, Таврический муниципальный район, с. Лесное, Школьная, д. 1 А		0101000020E6100000C6FB71FBE53C5240DD60A8C30A474B40
67619	5	53	1527	20483	29439	\N	54.449401999999999	Омская область, Таврический муниципальный район, а. Коянбай, пеперулок Зеленый, д. 2		0101000020E610000068CF656A124B5240E560360186394B40
67584	5	53	1527	18566	29719	\N	54.649276	Омская область, Таврический муниципальный район, д. Копейкино, Школьная, д. 23		0101000020E610000097E5EB32FC705240F209D9791B534B40
67588	5	53	1527	18747	29133	\N	54.51164	Омская область, Таврический муниципальный район, с. Карповка, Первомайская, д. 3		0101000020E61000009FC9FE791A6F5240A8A9656B7D414B40
67616	5	53	1527	20273	28696	\N	54.761451000000001	Омская область, Таврический муниципальный район, д. Камышино, Камышинская, д. 25		0101000020E61000008F705AF0A2615240D540F33977614B40
67621	5	53	1527	53044	29846	\N	54.522303589874902	Омская область, Таврический муниципальный район, д. Зеленое Поле, Школьная, д. 1	Россия, Омская область, Таврический район, поселок Зеленополье	0101000020E6100000A06B5F402F505240F54883DBDA424B40
67601	5	53	1527	19455	29560	\N	54.359330999999997	Омская область, Таврический муниципальный район, ст. Жатва, Энергетиков, 5 Б		0101000020E610000018EDF1423A85524030B8E68EFE2D4B40
67602	5	53	1527	19455	29562	\N	54.359330999999997	Омская область, Таврический муниципальный район, ст. Жатва, Солнечная, 16 А		0101000020E610000018EDF1423A85524030B8E68EFE2D4B40
67611	5	53	1527	19974	29987	\N	54.556080999999999	Омская область, Таврический муниципальный район, с. Воронково, Одесская, д. 14		0101000020E6100000D8BCAAB35A485240A77686A92D474B40
67593	5	53	1527	19019	29408	\N	54.521037	Омская область, Таврический муниципальный район, д. Веселые Рощи, Центральная, д. 22		0101000020E61000009755D80C70635240C3802557B1424B40
67594	5	53	1527	19096	29140	\N	54.480767999999998	Омская область, Таврический муниципальный район, д. Березовка, Центральная, д. 13		0101000020E61000009A232BBF0C5A52404E7B4ACE893D4B40
67606	5	53	1527	19676	29567	\N	54.425027	Омская область, Таврический муниципальный район, д. Баландино, Школьная, д. 21		0101000020E61000005EF415A4199752406075E44867364B40
67607	5	53	1527	19775	29568	\N	54.392485999999998	Омская область, Таврический муниципальный район, д. Байдалин, Лесная, д. 14		0101000020E6100000C974E8F4BC905240A51133FB3C324B40
67618	5	53	1527	20405	29844	\N	54.3902	Омская область, Таврический муниципальный район, д. Андреевка, переулок Зеленый, д. 2		0101000020E6100000D520CCED5E5152401973D712F2314B40
67688	5	53	2846	34423	29072	\N	58.474224	"с.Екатерининское, Интернатовская, Здание БСУ СО ""Дом-интернат"""		0101000020E61000001900AAB871094B40397D3D5FB33C4D40
67558	5	53	1448	17213	29935	\N	56.820419999999999	Омская область, Седельниковский муниципальный район, Голубовское сельское поселение, д.Хмелевка, ул.Хмелевская, д.36		0101000020E6100000518369183ED15240FE7DC68503694C40
67562	5	53	1448	17450	29248	\N	57.002671999999997	Омская область, Седельниковский муниципальный район, Кукарское сельское поселение, д.Усть-Инцы, ул.Заречная, д.16		0101000020E61000004AB54FC763BE5240B54E5C8E57804C40
67564	5	53	1448	17522	29247	\N	57.051659000000001	Омская область, Седельниковский муниципальный район, Унарское сельское поселение, с.Унара, ул.Школьная, д.1		0101000020E610000052616C21C8B95240A4C519C39C864C40
67553	5	53	1448	16984	29931	\N	56.88223	Омская область, Седельниковский муниципальный район, Евлантьевское сельское поселение, д.Тамбовка, ул.Центральная, д.42		0101000020E610000005C4245CC8D8524069C6A2E9EC704C40
67563	5	53	1448	17511	29663	\N	56.974994000000002	Омская область, Седельниковский муниципальный район, Кукарское сельское поселение, д.Сыщиково, ул.Ишимская, д.33		0101000020E61000008080B56AD7C75240EBE5779ACC7C4C40
67570	5	53	1448	17627	29544	\N	56.949097999999999	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, с.Седельниково, ул.Советская, д.22		0101000020E6100000C442AD69DED352407959130B7C794C40
67569	5	53	1448	17627	29124	\N	56.949097999999999	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, с.Седельниково, ул.Пролетарская, д.41		0101000020E6100000C442AD69DED352407959130B7C794C40
67571	5	53	1448	17627	29381	\N	56.949097999999999	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, с.Седельниково, ул.Кропотова, д.17		0101000020E6100000C442AD69DED352407959130B7C794C40
67566	5	53	1448	17627	29943	\N	56.949097999999999	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, с.Седельниково, ул.Избышева, д.18А		0101000020E6100000C442AD69DED352407959130B7C794C40
67568	5	53	1448	17627	29390	\N	56.949097999999999	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, с.Седельниково, ул.Горького, д.24		0101000020E6100000C442AD69DED352407959130B7C794C40
67567	5	53	1448	17627	29390	\N	56.949097999999999	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, с.Седельниково, ул.Горького, д.3Б		0101000020E6100000C442AD69DED352407959130B7C794C40
67543	5	53	1448	16509	29922	\N	57.080007999999999	Омская область, Седельниковский муниципальный район, Саратовское сельское поселение, с.Саратовка, Школьная, 8		0101000020E61000008672A25D85FC52408DB5BFB33D8A4C40
67545	5	53	1448	16606	29920	\N	56.940266000000001	Омская область, Седельниковский муниципальный район, Рагозинское сельское поселение, с.Рагозино, ул.Советская, д.1		0101000020E61000003F74417DCBFB524037C5E3A25A784C40
67546	5	53	1448	16667	\N	\N	56.952775000000003	Омская область, Седельниковский муниципальный район, Рагозинское сельское поселение, д.Петропавловка, ул.Петропавловская, д.12	Россия, Омская область, Седельниковский район, поселок Петропавловка	0101000020E61000008DD2A57F49FE524024B9FC87F4794C40
67560	5	53	1448	17352	29384	\N	56.795839999999998	Омская область, Седельниковский муниципальный район, Голубовское сельское поселение, д.павловка, ул.Павловская, д.41		0101000020E6100000556AF6402BC95240A06CCA15DE654C40
67554	5	53	1448	17052	29928	\N	57.032463999999997	Омская область, Седельниковский муниципальный район, Новоуйское сельское поселение, с.Новоуйка, ул.З.Максименко, д.2		0101000020E6100000AA27F38FBECC52400F26C5C727844C40
67550	5	53	1448	16839	29374	\N	56.860830999999997	Омская область, Седельниковский муниципальный район, Бакинское сельское поселение, д.Новоалександровка, ул.Александровская, д.5		0101000020E610000076C075C58CEB52400531D0B52F6E4C40
67559	5	53	1448	17295	29286	\N	56.841025000000002	Омская область, Седельниковский муниципальный район, Голубовское сельское поселение, д.Михайловка, ул.Михайловская, д.55		0101000020E6100000740D33349EC95240280F0BB5A66B4C40
66817	5	53	1448	17295	73744	\N	56.842523481022297	д. Михайловка (школа), Верхняя, 53	Россия, Омская область, Седельниковский район, поселок Михайловка	0101000020E6100000D3BEB9BF7AC952405C902DCBD76B4C40
67555	5	53	1448	17111	29654	\N	57.054645000000001	Омская область, Седельниковский муниципальный район, Новоуйское сельское поселение, д.Лилейка, ул.Лилейская, д.27		0101000020E61000002B33A5F5B7C95240E9F17B9BFE864C40
67548	5	53	1448	16759	29785	\N	56.920585000000003	Омская область, Седельниковский муниципальный район, Кейзесское сельское поселение, д.Лебединка, ул.Центральная, д.23		0101000020E6100000812557B1F8F552401618B2BAD5754C40
67561	5	53	1448	17388	29382	\N	56.941350999999997	Омская область, Седельниковский муниципальный район, Кукарское сельское поселение, с.Кукарка, ул.Центральная, д.12		0101000020E61000003B8C497F2FC45240488787307E784C40
67556	5	53	1448	17134	\N	\N	57.009166	Омская область, Седельниковский муниципальный район, Новоуйское сельское поселение, д.Короленка, ул.Короленская, д.49	Россия, Омская область, Седельниковский район, поселок Короленка	0101000020E6100000983270404BC85240191EFB592C814C40
67370	5	53	1448	17134	76428	\N	57.009166	д.Королевка, Центральная, 2 Б	Россия, Омская область, Седельниковский район, поселок Короленка	0101000020E6100000983270404BC85240191EFB592C814C40
67547	5	53	1448	16700	29230	\N	56.933861999999998	Омская область, Седельниковский муниципальный район, Кейзесское сельское поселение, с.Кейзес, ул.Советская, д.1		0101000020E61000005130630AD6EE5240137D3ECA88774C40
67542	5	53	1448	16438	29924	\N	56.921675999999998	Омская область, Седельниковский муниципальный район, Ельничное сельское поселение, с.Ельничное, ул.Центральная, д.4		0101000020E61000001EA8531EDD09534009C1AA7AF9754C40
67541	5	53	1448	16371	\N	\N	56.939346999999998	Омская область, Седельниковский муниципальный район, Ельничное сельское поселение, д.Елизарово, ул.Верхняя, д.1	Россия, Омская область, Седельниковский район, поселок Елизарово	0101000020E61000006519E25817035340404CC2853C784C40
67551	5	53	1448	16911	29649	\N	56.926980999999998	Омская область, Седельниковский муниципальный район, Евлантьевское сельское поселение, с.Евлантьевка, ул.Кропотова, д.12		0101000020E6100000793F6EBF7CDD5240B6813B50A7764C40
67573	5	53	1448	17997	29798	\N	56.970171999999998	Омская область, Седельниковский муниципальный район, Седельниковское сельское поселение, д.Денисовка, ул.Набережная, д.9А		0101000020E6100000FA0D130D52D5524059BF99982E7C4C40
67557	5	53	1448	17200	29932	\N	56.882264999999997	Омская область, Седельниковский муниципальный район, Голубовское сельское поселение, с.Голубовка, ул.Новая, д.21		0101000020E6100000EA20AF0793D15240E5B33C0FEE704C40
67565	5	53	1448	17609	29793	\N	57.026702999999998	Омская область, Седельниковский муниципальный район, Унарское сельское поселение, д.Богомель, ул.Зеленая, д.5		0101000020E610000036751E15FFB8524040DAFF006B834C40
66847	5	53	1448	16964	\N	\N	56.942273999999998	Богдановка, Здание школы		0101000020E61000007923F3C81FD9524080EF366F9C784C40
67552	5	53	1448	16964	29106	\N	56.942273999999998	Омская область, Седельниковский муниципальный район, Евлантьевское сельское поселение, д.Богдановка, ул.Озерная, д.31/2		0101000020E61000007923F3C81FD9524080EF366F9C784C40
67549	5	53	1448	16819	\N	\N	56.827818000000001	Омская область, Седельниковский муниципальный район, Бакинское сельское поселение, с.Бакино, ул.Зеленая, д.1	Россия, Омская область, Седельниковский район, поселок Бакино	0101000020E61000009FCDAACFD5EA52402385B2F0F5694C40
50735	5	53	375	60853	76469	\N	56.065317438245401	с.Васисс, Кирова, 24	Россия, Омская область, Саргатский район	0101000020E61000003B35971B0C555240B96FB54E5C084C40
67533	5	53	375	52968	29078	\N	56.017255763497801	Омская область, Саргатский  муниципальный район,Администрация с/п с. Щербаки, фойе,ул. Кооперативная, 46	Россия, Омская область, Саргатский район, поселок Щербаки	0101000020E61000007AC8940F415E524074D4D17135024C40
67504	5	53	375	14581	29414	\N	55.741616999999998	Омская область, Саргатский  муниципальный район,МОУ «Черноозерская НОШ», д. Черноозерье,ул. Зеленая, 20		0101000020E6100000A29BFD81727F52402D944C4EEDDE4B40
67528	5	53	375	53079	29915	\N	55.8791181337808	Омская область, Саргатский  муниципальный район,МОУ «Хохловская СОШ», кабинет ОБЖ, с. Хохлово, ул. Центральная, 1, д. Александровка	Россия, Омская область, Саргатский район, поселок Хохлово	0101000020E61000003CA41820D167524097A949F086F04B40
67500	5	53	375	14423	29842	\N	55.657590999999996	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Урусовская ООШ», д. Урусово,ул. Заозерная, 35		0101000020E6100000B1FB8EE1B15252406C921FF12BD44B40
67537	5	53	375	2425	29512	\N	55.492237000000003	Омская область, Саргатский  муниципальный район,Администрация с/п, фойе, с. Увальная Бития,ул. Подгорная,15		0101000020E6100000ECA4BE2CED555240CA703C9F01BF4B40
67519	5	53	375	15321	29348	\N	55.473658	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Тамбовская ООШ», фойе, д. Тамбовка, ул. Центральная, 4		0101000020E61000005184D4EDEC41524090BE49D3A0BC4B40
67502	5	53	375	1926	\N	\N	55.611058	Омская область, Саргатский  муниципальный район,РО СТО (ДОСААФ), фойе, р.п. Саргатское,ул. Пионерская, 1	Россия, Омская область, Саргатский район, поселок Саргатское	0101000020E610000099D9E731CA5F5240C6FA062637CE4B40
67498	5	53	375	1926	29749	\N	55.611058	р.п. Саргатское, Худенко, 1а		0101000020E610000099D9E731CA5F5240C6FA062637CE4B40
67497	5	53	375	1926	29749	\N	55.611058	р.п. Саргатское, Худенко, 67		0101000020E610000099D9E731CA5F5240C6FA062637CE4B40
67495	5	53	375	1926	29884	\N	55.607657333558102	Омская область, Саргатский муниципальный район, Саргатское городское поселение, Трактовая, 38	Россия, Омская область, Саргатский район, поселок Саргатское	0101000020E6100000739CDB847B5F5240BE175FB4C7CD4B40
67501	5	53	375	1926	29214	\N	55.611058	р.п. Саргатское, Октябрьская,12		0101000020E610000099D9E731CA5F5240C6FA062637CE4B40
67514	5	53	375	60198	74024	\N	55.542467281555297	Омская область, Саргатский  муниципальный район,Сельский клуб, фойе, д. Преображеновка,ул. Центральная, 22А	Россия, Омская область, Саргатский район, поселок Преображенка	0101000020E6100000AE11C138B84352406214048F6FC54B40
67527	5	53	375	15705	29528	\N	55.844976000000003	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Плосковская ООШ», фойе, д. Плоское, ул. Центральная, 34		0101000020E6100000E107E753C73D5240D4F36E2C28EC4B40
67104	5	53	375	15032	29604	\N	55.574466999999999	д. Павловка, ул. Центральная (здание ФАП)		0101000020E610000057EA5910CA335240CCD0782288C94B40
67513	5	53	375	15032	29501	\N	55.574466999999999	Омская область, Саргатский  муниципальный район,МОУ «Павловская НОШ», фойе, д. Павловка,ул. Центральная, 28б		0101000020E610000057EA5910CA335240CCD0782288C94B40
49743	5	53	422	46284	29890	\N	55.323126000000002	с.Красноярка, Мичурина, 58		0101000020E61000007E8FFAEB15465240603E59315CA94B40
67532	5	53	375	15932	29683	\N	55.909664999999997	Омская область, Саргатский  муниципальный район,Сельский клуб, фойе, д. Орловка, ул. Центральная, 35		0101000020E61000006058FE7C5B6552406DA818E76FF44B40
67521	5	53	375	52966	29067	\N	55.742367000000002	Омская область, Саргатский  муниципальный район,Сельский Дом культуры, фойе, с. Новотроицкое,ул. Юбилейная,4		0101000020E610000079B29B19FD5A52409850C1E105DF4B40
67516	5	53	375	15159	29341	\N	55.578527999999999	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Новопокровская НОШ», фойе,д. Новопокровка, ул. Зеленая, 15		0101000020E6100000486B0C3A214C5240FFE89B340DCA4B40
67510	5	53	375	14875	29497	\N	55.620550000000001	Омская область, Саргатский  муниципальный район,МОУ «Николаевская НОШ», фойе, д. Николаевка,ул. Зеленая, 6		0101000020E61000001B81785DBF35524033C4B12E6ECF4B40
67517	5	53	375	15233	29091	\N	55.446483000000001	Омская область, Саргатский  муниципальный район,Администрация с/п, актовый зал, с. Нижнеиртышское, ул. Центральная, 3		0101000020E6100000077E54C37E505240289CDD5A26B94B40
67509	5	53	375	14865	29893	\N	55.667762000000003	Омская область, Саргатский  муниципальный район,Сельский клуб, фойе, д. Михайловка,ул. Центральная, 29в		0101000020E61000001B498270053E52407BC1A73979D54B40
67526	5	53	375	15683	\N	\N	55.911835000000004	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Куртайлинская НОШ», учебный класс, д. Куртайлы, ул. Центральная, 14		0101000020E61000001C7BF65CA6455240912C6002B7F44B40
67506	5	53	375	2032	29098	\N	55.645221999999997	Омская область, Саргатский  муниципальный район,МОУ «Краснопутинская НОШ», фойе,д. Красный Путь, ул. Цветочная, 32		0101000020E61000009CBF09850867524071546EA296D24B40
67531	5	53	375	15926	30043	\N	55.810789	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Кармановская НОШ», учебный класс,д. Карманово, ул. Новая, 2		0101000020E610000057957D57045D5240707A17EFC7E74B40
67536	5	53	375	16148	29709	\N	56.030054999999997	Омская область, Саргатский  муниципальный район,МОУ «Калмакульская НОШ», фойе, д. Калмакуль,ул. Калмакульская, 1		0101000020E6100000EF3A1BF2CF545240670A9DD7D8034C40
67540	5	53	375	16352	29103	\N	55.528436999999997	Омская область, Саргатский  муниципальный район,ФАП, фойе, д. Калачёвка, ул. Светлая, 39		0101000020E61000000C790437525A5240887FD8D2A3C34B40
67530	5	53	375	15841	30041	\N	55.831600000000002	Омская область, Саргатский  муниципальный район,Сельский клуб, фойе, д. Казырлы, ул. Центральная, 22		0101000020E61000004C1938A0A56E524043AD69DE71EA4B40
67529	5	53	375	15798	29509	\N	55.775378000000003	Омская область, Саргатский  муниципальный район,МОУ «Интенисская ООШ», фойе, д. Интенис,ул. Центральная, 18		0101000020E6100000B0E8D66B7A5F5240DA0418963FE34B40
67505	5	53	375	14659	30033	\N	55.677154000000002	Омская область, Саргатский  муниципальный район,Сельский клуб, фойе, д. Ивановка, ул. Карбышева, 30,д. Степановка		0101000020E6100000B72572C1196C5240842D76FBACD64B40
67499	5	53	375	14365	30027	\N	55.603563000000001	Омская область, Саргатский  муниципальный район,ФАП, д. Заготзерно, ул. Садовая, 38		0101000020E6100000494739984D665240AF09698D41CD4B40
67524	5	53	375	2267	29092	\N	55.708576999999998	Омская область, Саргатский  муниципальный район,Сельский Дом культуры д. Десподзиновка, фойе,ул. Центральная, 26, д. Алексеевка		0101000020E61000009F5BE84A044B524051D9B0A6B2DA4B40
67534	5	53	375	16046	29916	\N	56.009642999999997	Омская область, Саргатский  муниципальный район,ФАП, фойе, д. Горькое, ул. Центральная, 22		0101000020E610000009151C5E1071524052D158FB3B014C40
67523	5	53	375	53026	29637	\N	55.858268611294598	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Галицинская НОШ», учебный класс,д. Галицино, ул. Центральная, 16	Россия, Омская область, Саргатский район, поселок Галицыно	0101000020E61000002AAC545051455240D71533C2DBED4B40
67518	5	53	375	15279	29204	\N	55.393507999999997	Омская область, Саргатский  муниципальный район,Администрация с/п, актовый зал, с. Верблюжье, ул. Почтовая,29		0101000020E610000092088D60E3495240705B5B785EB24B40
67522	5	53	375	53048	29881	\N	55.729872698786103	Омская область, Саргатский  муниципальный район,Бывшая МОУ «Большешипицинская НОШ», учебный класс, д. Большешипицино, ул. Центральная, 14	Россия, Омская область, Саргатский район, поселок Большешипицыно	0101000020E61000007FDFBF79714A5240E09D7C7A6CDD4B40
67535	5	53	375	16098	29774	\N	55.945256000000001	Омская область, Саргатский  муниципальный район,МОУ «Беспаловская СОШ», учебный класс,д. Беспалово, ул. Молодежная, 16		0101000020E610000047382D78D1535240842C0B26FEF84B40
67508	5	53	375	52984	29283	\N	55.636818807584099	Омская область, Саргатский  муниципальный район,Администрация с/п с. Баженово, актовый зал,ул. Саргатская, 26А	Россия, Омская область, Саргатский район, поселок Баженово	0101000020E6100000BBD1C77C40465240583CF54883D14B40
67503	5	53	375	49168	29883	\N	55.715302078852901	Омская область, Саргатский  муниципальный район,Администрация с/п с. Андреевка, актовый зал,ул. 1 Мая, 2	Россия, Омская область, Саргатский район, поселок Андреевка	0101000020E61000005A9C31CC09755240B76114048FDB4B40
67538	5	53	375	16219	29101	\N	55.569057000000001	Омская область, Саргатский  муниципальный район,ФАП, фойе, д. Аксёново, ул. Центральная, 24		0101000020E610000002D9EBDD1F525240AA471ADCD6C84B40
67525	5	53	6900	40328	9830	\N	55.858502343721398	Омская область, Саргатский  муниципальный район,МОУ «Индерская НОШ», фойе, д. Индеры,ул. Центральная, 17	Россия, Омская область, Саргатский район, поселок Индеры	0101000020E610000000E2AE5E455152407AC6BE64E3ED4B40
67345	5	53	422	24765	29215	\N	54.944853978363	с. Лузино, Майорова, 12	Россия, Омская область, Омский район, поселок Лузино	0101000020E6100000CF656A12BC41524055BFD2F9F0784B40
67480	5	53	1257	52855	29179	\N	53.572113000000002	Омская область, Русско-Полянский муниципальный район, Калининское сельское поселение д.Черноусовка, Мартыненко, 33		0101000020E6100000365B79C9FF5C5240E84EB0FF3AC94A40
67477	5	53	1257	52844	29607	\N	53.665489999999998	Омская область, Русско-Полянский муниципальный район, Цветочинское сельское поселение с.Цветочное, Кооперативная, 14		0101000020E61000007FDB1324B683524053E8BCC62ED54A40
67482	5	53	1257	52866	29435	\N	53.774988999999998	Омская область, Русско-Полянский муниципальный район, Хлебодаровское сельское поселение с.Хлебодаровка, 25лет Совхоза, 1		0101000020E61000007D772B4B745E52403FE1ECD632E34A40
67483	5	53	1257	52868	29192	\N	53.775365999999998	Омская область, Русско-Полянский муниципальный район, Хлебодаровское сельское поселение д.Тогунас, Школьная, 15		0101000020E6100000406CE9D15463524015376E313FE34A40
67486	5	53	1257	60147	73914	\N	53.736944990747602	Омская область, Русско-Полянский муниципальный район, Солнечное сельское поселение д.Там-Чилик, Магистральная, 10	Россия, Омская область, Русско-Полянский район, поселок Тамчилик	0101000020E61000007A522635B46D5240B1F9B83654DE4A40
67469	5	53	1257	12969	29462	\N	53.788252	Омская область, Русско-Полянский муниципальный район, Сибирское сельское поселение д.Степное, Вторая, 18		0101000020E6100000103E9468C9995240D8800871E5E44A40
67484	5	53	1257	53116	30132	\N	53.840269134627803	Омская область, Русско-Полянский муниципальный район, Хлебодаровское сельское поселение с.Степановка, Зеленая, 1	Россия, Омская область, Русско-Полянский район, поселок Степановка	0101000020E6100000E8A1B60DA35D5240DB6B41EF8DEB4A40
67489	5	53	1257	53110	30115	\N	53.772640101179498	Омская область, Русско-Полянский муниципальный район, Солнечное сельское поселение с.Солнечное, Титова, 1	Россия, Омская область, Русско-Полянский район, поселок Солнечное	0101000020E6100000E481C8224D7952406DCA15DEE5E24A40
67493	5	53	1257	53099	30156	\N	53.782515787767601	Омская область, Русско-Полянский муниципальный район, Русско-Полянское городское поселение р.п. Русская Поляна, Северная, 70	Россия, Омская область, Русско-Полянский район, поселок Русская Поляна	0101000020E61000002AC76471FF785240624CFA7B29E44A40
67492	5	53	1257	53099	30089	\N	53.780633452044498	Омская область, Русско-Полянский муниципальный район, Русско-Полянское городское поселение р.п. Русская Поляна, Ленина, 120	Россия, Омская область, Русско-Полянский район, поселок Русская Поляна	0101000020E6100000C311A452EC785240D5963AC8EBE34A40
67467	5	53	1257	53119	30137	\N	53.776260000000001	Омская область, Русско-Полянский муниципальный район, Розовское сельское поселение д.Ротовка, Тельмана, 25	Россия, Омская область, Русско-Полянский район, поселок Ротовка	0101000020E610000076374F75C8825240B398D87C5CE34A40
67465	5	53	1257	49460	30114	\N	53.850257487309797	Омская область, Русско-Полянский муниципальный район, Розовское сельское поселение д.Розовка, Степная, 1	Россия, Омская область, Русско-Полянский район, поселок Розовка	0101000020E61000001B49827005835240F818AC38D5EC4A40
67473	5	53	1257	60863	76487	\N	53.836472000000001	Омская область, Русско-Полянский муниципальный район, Алаботинское сельское поселение д.Пограничное, Центральная, 14		0101000020E610000037C478CDAB6E52408602B68311EB4A40
67474	5	53	1257	46104	29436	\N	53.925842000000003	Омская область, Русско-Полянский муниципальный район, Алаботинское сельское поселение д.Озерное, Главная, 10А		0101000020E61000008942CBBA7F725240B2A19BFD81F64A40
67488	5	53	1257	51913	28689	\N	53.723915934734997	Омская область, Русско-Полянский муниципальный район, Солнечное сельское поселение д.Невольное, Школьная, 60	Россия, Омская область, Русско-Полянский район, поселок Невольное	0101000020E6100000C826F911BF7352408C868C47A9DC4A40
67470	5	53	1257	60140	73894	\N	53.865899742297302	Омская область, Русско-Полянский муниципальный район, Сибирское сельское поселение д.Логуновка, Сибирская, 7	Россия, Омская область, Русско-Полянский район, поселок Логуновка	0101000020E610000023DC6454199D52409FCDAACFD5EE4A40
67479	5	53	1257	52850	29985	\N	53.587600000000002	Омская область, Русско-Полянский муниципальный район, Новосанжаровское сельское поселение д.Жуковка, Школьная, 10		0101000020E6100000D107CBD8D064524097900F7A36CB4A40
67476	5	53	1257	60813	76403	\N	53.645350999999998	Омская область, Русско-Полянский муниципальный район, Добровольское сельское поселение с.Добровольск, Ленина, 14В	Россия, Омская область, Русско-Полянский район, поселок Добровольск	0101000020E610000090BB0853949052406FB88FDC9AD24A40
67466	5	53	1257	53112	30122	\N	53.810262623151502	Омская область, Русско-Полянский муниципальный район, Розовское сельское поселение д.Волотовка, Степная, 3	Россия, Омская область, Русско-Полянский район, поселок Волотовка	0101000020E6100000A7052FFA0A8352405514AFB2B6E74A40
67475	5	53	1257	53086	29991	\N	53.930318546548698	Омская область, Русско-Полянский муниципальный район, Алаботинское сельское поселение а.Бузан, Школьная, 4	Россия, Омская область, Русско-Полянский район, поселок Бузан	0101000020E6100000529ACDE3307C524078EC67B114F74A40
67463	5	53	1257	60839	76451	\N	53.909810999999998	Омская область, Русско-Полянский муниципальный район, Целинное сельское поселение а.Бас-Агаш, Молодежная, 9	Россия, Омская область, Русско-Полянский район, поселок Бас-Агаш	0101000020E6100000DC8310902F8F52404145D5AF74F44A40
67344	5	53	422	24765	29215	\N	54.944853999999999	с.Лузино, Майорова, 8		0101000020E6100000CF656A12BC41524055BFD2F9F0784B40
67472	5	53	1257	53111	30116	\N	53.951669411278999	Омская область, Русско-Полянский муниципальный район, Алаботинское сельское поселение с.Алабота, Набережная, 7	Россия, Омская область, Русско-Полянский район, поселок Алабота	0101000020E61000002FF99FFCDD705240FBCE2F4AD0F94A40
67485	5	53	7253	53082	29951	\N	54.991551999999999	Омская область, Русско-Полянский муниципальный район, Солнечное сельское поселение д.Андриановка, 60 лет Победы, 19		0101000020E610000035255987A356524046240A2DEB7E4B40
67432	5	53	373	46185	29718	\N	54.284995000000002	деревня Щегловка, Труда, 38		0101000020E610000095287B4B39E35140034356B77A244B40
50611	5	53	373	45543	29992	\N	54.458734999999997	село Шахово, Юбилейная, 24		0101000020E6100000FE277FF78EF65140E94317D4B73A4B40
67446	5	53	373	46509	29300	\N	54.575775	деревня  Шаровка, Марии Долиной, 12		0101000020E610000067EE21E17BE251405D6DC5FEB2494B40
67445	5	53	373	11812	29044	\N	54.539144999999998	деревня  Хмаровка, Центральная, 5		0101000020E61000005CAB3DEC85E45140A5660FB402454B40
67407	5	53	373	45678	29999	\N	54.441946999999999	деревня  Увальное, Озерная, 15		0101000020E610000014CC988235E551405CC823B891384B40
67448	5	53	373	11983	29727	\N	54.249969	деревня  Терпенье, Школьная, 4		0101000020E61000000CC9C9C4ADCF5140C501F4FBFE1F4B40
67457	5	53	373	52990	29339	\N	54.480469999999997	село Соловьевка, Победы, 2	Россия, Омская область, Полтавский район, поселок Соловьевка	0101000020E610000041834D9D47D25140C45A7C0A803D4B40
67461	5	53	373	12610	29178	\N	54.496667000000002	деревня  Смелое, Юбилейная, 23		0101000020E6100000CA8CB7955EDA51405000C5C8923F4B40
67431	5	53	373	11170	29293	\N	54.386204999999997	село Святогорск, Школьная, 27		0101000020E61000005CAFE94141D851409D465A2A6F314B40
67456	5	53	373	46708	29746	\N	54.365873000000001	рабочий поселок Полтавка, Пушкина, 3		0101000020E61000003F541A31B3F05140A5BE2CEDD42E4B40
67455	5	53	373	46708	29315	\N	54.365925364750602	рабочий поселок Полтавка, Победы, 28	Россия, Омская область, Полтавский район, поселок Полтавка	0101000020E61000008C14CAC2D7F05140F7E461A1D62E4B40
67444	5	53	373	46452	29295	\N	54.488419999999998	село Платово, Центральная, 3		0101000020E6100000BC7669C361EE51402D5BEB8B843E4B40
67449	5	53	373	46561	28913	\N	54.267099000000002	село Ольгино, Победы, 14		0101000020E6100000F609A01859EB5140ACE5CE4C30224B40
67460	5	53	373	12547	29619	\N	54.517147999999999	Омская область, Полтавский муниципальный район, д. Ольвиополь, ул. Школьная, 11, сельский клуб		0101000020E61000003C889D2974D051408D98D9E731424B40
67430	5	53	373	11124	29820	\N	54.347560999999999	деревня Новотимофеевка, Горького, 28		0101000020E610000030F1475167E45140BA2EFCE07C2C4B40
67437	5	53	373	46310	29442	\N	54.459493999999999	деревня Новосергеевка, Центральная, 19		0101000020E6100000AA0EB9196EFF5140A75A0BB3D03A4B40
67447	5	53	373	46525	29145	\N	54.235216000000001	село  Новоильиновка, Ленина, 5		0101000020E6100000EFAD484C50C751407BBFD18E1B1E4B40
67453	5	53	373	12237	\N	\N	54.151263999999998	деревня  Никополь, Центральная, 4	Россия, Омская область, Полтавский район, поселок Никополь	0101000020E61000001E51A1BAB9EF5140F487669E5C134B40
67459	5	53	373	12516	29520	\N	54.439957999999997	деревня  Мечебилово, Центральная, 16		0101000020E6100000F33977BB5ECF514089CE328B50384B40
67458	5	53	373	12464	30023	\N	54.472607000000004	деревня Лубянск, Почтовая, 1А		0101000020E610000051F9D7F2CADC51402B6EDC627E3C4B40
67452	5	53	373	46633	29734	\N	54.231633000000002	деревня Крым, Школьная, 18		0101000020E6100000E02EFB75A7DF514052D66F26A61D4B40
67436	5	53	373	1916	29586	\N	54.415318999999997	Омская область, Полтавский муниципальный район,с. Краснопутиловка, Школьный переулок, 2, сельский клуб		0101000020E61000003C11C47938FD51402634492C29354B40
67442	5	53	373	46416	29119	\N	54.568792000000002	село Красногорка, Ленина, 6		0101000020E6100000675F79909EEB5140FC1C1F2DCE484B40
67441	5	53	373	11624	29995	\N	54.309569000000003	деревня Коконовка, Школьная, 30		0101000020E6100000B24CBF44BCFC51407F6DFDF49F274B40
67440	5	53	373	46372	29855	\N	54.380380000000002	деревня Каменка, Школьная, 2		0101000020E61000006D533C2EAA015240B806B64AB0304B40
67438	5	53	373	46325	28699	\N	54.280315999999999	село Еремеевка, 50 лет Октября, 10		0101000020E6100000BBD573D2FB025240D4450A65E1234B40
67427	5	53	373	46071	29265	\N	54.219110000000001	деревня Добрянка, Мира, 23 А		0101000020E61000009B1C3EE944DB5140001DE6CB0B1C4B40
67426	5	53	373	10955	29821	\N	54.217210000000001	деревня Длинное, Центральная, 49		0101000020E6100000E675C4211BD851409D2E8B89CD1B4B40
67439	5	53	373	11557	29971	\N	54.354498999999997	село  Гостиловка, Центральная, 20		0101000020E6100000645C717154FD51407BBB2539602D4B40
66623	5	53	373	46616	29726	\N	54.297817000000002	с. Георгиевка, Центральная, 53 а		0101000020E6100000FB03E5B67DF15140AF9811DE1E264B40
67428	5	53	373	46111	29263	\N	54.328507000000002	село  Воронцовка, Ленина, 39		0101000020E61000005D8940F50FE05140E8C072840C2A4B40
67423	5	53	373	45987	29811	\N	54.285151999999997	село  Вольное, Садовая, 6		0101000020E610000082397AFCDED65140CA3159DC7F244B40
67425	5	53	373	53021	29592	\N	54.311408	деревня Бородинка, Садовая, 13		0101000020E6100000E1EEACDD76CF51403CDBA337DC274B40
67434	5	53	373	52963	29055	\N	54.418086000000002	п. Бельдеж №7, Лесная, 1	Россия, Омская область, Полтавский район, поселок Бельдеж №7	0101000020E61000005396218E75F551402E7590D783354B40
67433	5	53	373	11261	29848	\N	54.391699000000003	п. Бельдеж №3, Школьная, 3		0101000020E61000000C1F115322F151401E705D3123324B40
67435	5	53	373	53019	29576	\N	54.389294722958603	п. Бельдеж №12, Ленина, 27 А	Россия, Омская область, Полтавский район	0101000020E610000093A9825149F7514087BF266BD4314B40
67443	5	53	373	11757	29428	\N	54.516537	деревня Белотурковка, Центральная, 5		0101000020E610000000CADFBDA3E55140441669E21D424B40
67424	5	53	373	10851	29259	\N	54.234273999999999	деревня Бежевка, Труда, 18		0101000020E61000008DF0F62004D65140CC26C0B0FC1D4B40
67450	5	53	373	46588	29858	\N	54.222605999999999	деревня  Андрюшевка, Солнечная, 7		0101000020E610000042959A3DD0E751405AF2785A7E1C4B40
67403	5	53	1043	9818	29554	\N	54.311155999999997	Омская область, Павлоградский муниципальный район, Хорошковское сельское поселение,д.Ясная Поляна, Центральная, 3а		0101000020E6100000E63E390A1064524022FAB5F5D3274B40
67410	5	53	1043	10135	29142	\N	54.334375999999999	Омская область, Павлоградский муниципальный район, Логиновское сельское поселение,д.Ярмоклеевка, Центральная, 17/2		0101000020E6100000F0366F9C146C52409D4830D5CC2A4B40
67343	5	53	422	24765	29360	\N	54.944853999999999	с.Лузино, Комсомольская, 19		0101000020E6100000CF656A12BC41524055BFD2F9F0784B40
67393	5	53	1043	9340	29965	\N	54.110340000000001	Омская область, Павлоградский муниципальный район, Нивское сельское поселение,д.Явлено-Покровка, Советская, 2		0101000020E6100000C3D4963AC860524067B8019F1F0E4B40
67398	5	53	1043	9554	29961	\N	54.024335000000001	Омская область, Павлоградский муниципальный район, Юрьевское сельское поселение,с.Юрьевка, Новая, 2		0101000020E6100000CA181F662F595240F792C6681D034B40
67413	5	53	1043	10325	29559	\N	54.007331999999998	Омская область, Павлоградский муниципальный район, Южное сельское поселение,с.Южное, Центральная, 19		0101000020E61000008E5A61FA5E8152406D1B4641F0004B40
67401	5	53	1043	9719	29153	\N	54.269713000000003	Омская область, Павлоградский муниципальный район, Хорошковское сельское поселение,с.Хорошки, 20 лет Победы, 13		0101000020E6100000C2189128B46152402D27A1F485224B40
67419	5	53	1043	10613	29421	\N	54.395778	Омская область, Павлоградский муниципальный район, Тихвинское сельское поселение,д.Топольки, Центральная, 12		0101000020E610000055682096CD7A5240F73C7FDAA8324B40
67418	5	53	1043	10464	29170	\N	54.358631485209301	Омская область, Павлоградский муниципальный район, Тихвинское сельское поселение,а.Кирибай, Школьная, 9	Россия, Омская область, Павлоградский район, поселок Тихвинка	0101000020E6100000BE30992A18755240782AE09EE72D4B40
67416	5	53	1043	10464	29170	\N	54.360695	Омская область, Павлоградский муниципальный район, Тихвинское сельское поселение,с.Тихвинка, Школьная, 2		0101000020E61000002CA0504F1F755240556AF6402B2E4B40
67415	5	53	1043	10426	29975	\N	54.046433	Омская область, Павлоградский муниципальный район, Южное сельское поселение,д.Степное, Школьная, 10		0101000020E610000091D0967329785240433A3C84F1054B40
67406	5	53	1043	9952	29968	\N	54.263539000000002	Омская область, Павлоградский муниципальный район, Логиновское сельское поселение,д.Семяновка, Клубная, 2		0101000020E6100000A88DEA74207052403B1C5DA5BB214B40
67414	5	53	1043	10351	29704	\N	54.083844999999997	Омская область, Павлоградский муниципальный район, Южное сельское поселение,д.Раздольное, Школьная, 4		0101000020E610000073BED87BF17D52407077D66EBB0A4B40
67421	5	53	1043	10717	29131	\N	54.210839	Омская область, Павлоградский муниципальный район, Новоуральское сельское поселение,д.Пашенная Роща, Центральная, 29		0101000020E6100000E3A6069ACF83524055DCB8C5FC1A4B40
67391	5	53	1043	9131	28684	\N	54.203218999999997	Омская область, Павлоградский муниципальный район, Павлоградское городское поселение,р.п.Павлоградка, Пролетарская, 34а		0101000020E61000002CB7B41A1264524081768714031A4B40
67390	5	53	1043	9131	28684	\N	54.203218999999997	Омская область, Павлоградский муниципальный район, Павлоградское городское поселение,р.п.Павлоградка, Пролетарская, 32		0101000020E61000002CB7B41A1264524081768714031A4B40
67389	5	53	1043	9131	29404	\N	54.203218999999997	Омская область, Павлоградский муниципальный район, Павлоградское городское поселение,р.п.Павлоградка, Ленина, 64		0101000020E61000002CB7B41A1264524081768714031A4B40
67388	5	53	1043	9131	29404	\N	54.203218999999997	Омская область, Павлоградский муниципальный район, Павлоградское городское поселение,р.п.Павлоградка, Ленина, 68		0101000020E61000002CB7B41A1264524081768714031A4B40
67392	5	53	1043	9131	29150	\N	54.203218999999997	Омская область, Павлоградский муниципальный район, Павлоградское городское поселение,р,п.Павлоградка, Зеленая, 11		0101000020E61000002CB7B41A1264524081768714031A4B40
67420	5	53	1043	10644	29146	\N	54.246175999999998	Омская область, Павлоградский муниципальный район, Новоуральское сельское поселение,с.Новоуральское, Центральная, 24		0101000020E61000004CC2853C828D5240B187F6B1821F4B40
67394	5	53	1043	9389	29424	\N	54.168650999999997	Омская область, Павлоградский муниципальный район, Нивское сельское поселение,д..Назаровка, Центральная, 23		0101000020E6100000D2C6116BF15B524006B8205B96154B40
67411	5	53	1043	10230	\N	\N	54.089924000000003	Омская область, Павлоградский муниципальный район, Милоградовское сельское поселение,с.Милоградовка, Ленина, 15	Россия, Омская область, Павлоградский район, поселок Милоградовка	0101000020E6100000C74ACCB3926A524011902FA1820B4B40
67412	5	53	1043	10230	73852	\N	54.0942187929057	Омская область, Павлоградский муниципальный район, Милоградовское сельское поселение,а.Кайдаул, Зеленая, 1	Россия, Омская область, Павлоградский район, поселок Милоградовка	0101000020E6100000A950DD5CFC6A5240B7D4415E0F0C4B40
67405	5	53	1043	9923	29429	\N	54.277419999999999	Омская область, Павлоградский муниципальный район, Логиновское сельское поселение,с.Логиновка, пер.Советский, 8		0101000020E61000007FC16ED8B66E5240CFA0A17F82234B40
67396	5	53	1043	9457	29700	\N	54.224359	Омская область, Павлоградский муниципальный район, Нивское сельское поселение,д.Липов Кут, Школьная, 12		0101000020E6100000A7CD380D5157524019C8B3CBB71C4B40
67417	5	53	1043	10542	29978	\N	54.250359000000003	Омская область, Павлоградский муниципальный район, Тихвинское сельское поселение,д.Краснодарка, Зеленая, 26		0101000020E6100000E3C116BB7D81524030A182C30B204B40
67404	5	53	1043	9852	29409	\N	54.273623999999998	Омская область, Павлоградский муниципальный район, Хорошковское сельское поселение,д.Кохановка, Советская, 16а		0101000020E610000058CA32C4B15452404AB3791C06234B40
67408	5	53	1043	10072	29574	\N	54.199568999999997	Омская область, Павлоградский муниципальный район, Логиновское сельское поселение,д.Константиноградка, Магистральная, 15/1		0101000020E6100000C6C03A8E1F765240D0251C7A8B194B40
67422	5	53	1043	10784	29839	\N	54.206763000000002	Омская область, Павлоградский муниципальный район, Новоуральское сельское поселение,д.Золотухино, Колхозная, 8		0101000020E61000002829B000A68D5240ED82C135771A4B40
67399	5	53	1043	9623	29809	\N	53.969183000000001	Омская область, Павлоградский муниципальный район, Юрьевское сельское поселение,д.Дувановка, Центральная, 13		0101000020E6100000AB05F698485052406A6B44300EFC4A40
67402	5	53	1043	9762	29154	\N	54.267829999999996	Омская область, Павлоградский муниципальный район, Хорошковское сельское поселение,д Глинкино, Школьная, 19		0101000020E6100000263ACB2C426552409F71E14048224B40
67409	5	53	1043	10119	29822	\N	54.186126000000002	Омская область, Павлоградский муниципальный район, Логиновское сельское поселение,д.Божедаровка, Центральная, 10		0101000020E61000009F3C2CD49A6F5240B8770DFAD2174B40
67397	5	53	1043	9493	29831	\N	54.079650999999998	Омская область, Павлоградский муниципальный район, Богодуховское сельское поселение,с.Богодуховка, Степная, 23		0101000020E610000066F84F3750595240FE0B0401320A4B40
67395	5	53	1043	9394	29281	\N	54.199638	Омская область, Павлоградский муниципальный район, Нивское сельское поселение, д.Бердовка, Центральная, 8/2		0101000020E61000003FE5982CEE5B5240F984ECBC8D194B40
67400	5	53	1043	9643	29813	\N	54.044012000000002	Омская область, Павлоградский муниципальный район, Юрьевское сельское поселение,д.Белоусовка, Центральная, 23а		0101000020E610000078616BB6F2615240D7506A2FA2054B40
67384	5	53	422	8923	29398	\N	54.733406000000002	п.им.Комиссарова, Музейная, 1		0101000020E6100000814067D2A66852405858703FE05D4B40
67363	5	53	422	7922	28680	\N	55.242668000000002	с.Чернолучье, 50 лет Октября, 62 А		0101000020E6100000064A0A2C8041524093E4B9BE0F9F4B40
67385	5	53	422	53098	76394	\N	55.2838571390811	д.п.Чернолучинский, Поселковая, 4 Б	Россия, Омская область, Омский район, поселок Чернолучинский	0101000020E6100000512D228AC9415240CEDE196D55A44B40
67386	5	53	422	53098	30088	\N	55.284227463056403	д.п.Чернолучинский, Пионерская, 16	Россия, Омская область, Омский район, поселок Чернолучинский	0101000020E61000007B116DC7D4415240F2D1E28C61A44B40
67379	5	53	422	49445	29395	\N	55.111099000000003	п.Хвойный, Хвойная, 1 А		0101000020E61000007F85CC954165524025CFF57D388E4B40
67166	5	53	422	45468	30060	\N	55.158611000000001	с. Харино, Центральная, 117 А		0101000020E610000029B4ACFBC74C524097E4805D4D944B40
67373	5	53	422	8444	29927	\N	55.326563	д.Халдеевка, Центральная, 13		0101000020E6100000726BD26D896A5240B58AFED0CCA94B40
67383	5	53	422	8899	29126	\N	54.764640999999997	с. Усть-Заостровка, Степная, 21		0101000020E610000034BDC458A666524022179CC1DF614B40
67336	5	53	422	40308	9775	\N	54.9714392319136	с.Ульяновка, Школьная, 19	Россия, Омская область, Омский район, поселок Ульяновка	0101000020E6100000DA740470B36A52408B87F71C587C4B40
67368	5	53	422	49308	29239	\N	55.242016999999997	д.Трусовка, Центральная, 13 Б		0101000020E6100000187B2FBE686D5240BB09BE69FA9E4B40
50447	5	53	422	46928	29388	\N	54.870238000000001	с.Троицкое, Октябрьская, 1 А		0101000020E6100000EE21E17B7F53524044DE72F5636F4B40
67387	5	53	422	46928	29603	\N	54.870238000000001	с.Троицкое, Бульвар Школьный, 1		0101000020E6100000EE21E17B7F53524044DE72F5636F4B40
67380	5	53	422	52994	29402	\N	54.711071686211902	с.Розовка, Парковая, 5	Россия, Омская область, Омский район, поселок Розовка	0101000020E6100000C68B8521726B5240F88C4468045B4B40
67331	5	53	422	48717	29764	\N	54.676130999999998	п.Речной, Центральная, 7 А		0101000020E6100000787AA52C43735240E867EA758B564B40
67351	5	53	422	49060	30055	\N	54.919037000000003	с.Ребровка, Школьная, 3		0101000020E61000009CA4F9635A4B524030682101A3754B40
67354	5	53	422	49090	29365	\N	54.898995999999997	д.Ракитинка, Центральная, 19 А		0101000020E61000002C82FFAD646152400E9E094D12734B40
67346	5	53	422	45977	29317	\N	54.936776000000002	п. Пятилетка, Центральная, 12 Б		0101000020E61000006571FF91E93B5240BFD6A546E8774B40
67377	5	53	422	48834	\N	\N	55.092036	с.Пушкино, 40 лет Победы, 38	Россия, Омская область, Омский район, поселок Пушкино	0101000020E6100000DC8310902F5E5240FF06EDD5C78B4B40
66877	5	53	422	48834	29447	\N	55.0924269141248	д. Пушкино, Крылова, 23	Россия, Омская область, Омский район, поселок Пушкино	0101000020E61000003F389F3A565E52403A22DFA5D48B4B40
67360	5	53	422	7768	28679	\N	54.796314000000002	д.Путинцево, Мира		0101000020E610000055A181583650524069ACFD9DED654B40
67254	5	53	422	2265	29724	\N	54.557167	п. Покрово-Иртышское, Центральная, 59		0101000020E6100000533C2EAA4589524089B48D3F51474B40
67374	5	53	422	52995	29403	\N	55.377612999999997	с. Покровка, Центральная, 45 В	Россия, Омская область, Омский район, поселок Покровка	0101000020E61000009599D2FA5B5C5240B0C56E9F55B04B40
67378	5	53	422	8684	29168	\N	55.143579000000003	д.Подгородка, Зеленая, 2 В		0101000020E61000005E11FC6F256352403AB2F2CB60924B40
67366	5	53	422	40405	29240	\N	54.959279395351899	с.Петровка, Школьная, 11		0101000020E610000095BBCFF1D1425240AB5E7EA7C97A4B40
67347	5	53	422	40405	28681	\N	54.959527000000001	д.Петровка, Полевая, 1		0101000020E610000034828DEBDF4252408350DEC7D17A4B40
67364	5	53	422	49247	29080	\N	55.102925999999997	п.Омский, Ленина, 1		0101000020E610000022A7AFE76B5652403CF4DDAD2C8D4B40
67362	5	53	422	46636	29525	\N	55.269492	с.Новотроицкое, Ленина, 37		0101000020E6100000E0A128D0274A52404E44BFB67EA24B40
67358	5	53	422	7642	29705	\N	54.836087230803301	п.Новоомский, Титова, 40	Россия, Омская область, Омский район, поселок Новоомский	0101000020E6100000EB71DF6A9D5852402DCE18E6046B4B40
67357	5	53	422	7642	29613	\N	54.835642	п.Новоомский, Гагарина, 1		0101000020E6100000C02500FF94585240FF942A51F66A4B40
67375	5	53	422	46133	29148	\N	55.367576	с.Никоновка, Центральная, 21, кв.2		0101000020E6100000E107E753C7635240B265F9BA0CAF4B40
67429	5	53	422	46133	28673	\N	55.367576	село  Никоновка, Победы, 25		0101000020E6100000E107E753C7635240B265F9BA0CAF4B40
67332	5	53	422	48732	29425	\N	54.791725	д.Николенко, Центральная, 13 А		0101000020E6100000207BBDFBE37752407A36AB3E57654B40
67341	5	53	422	6855	28666	\N	55.381633000000001	д. Нижняя Ильинка, Зеленая, 73		0101000020E6100000425DA450164F52408509A359D9B04B40
67381	5	53	422	49475	29666	\N	54.751092	д.Нива, Лесная, 20		0101000020E6100000AD307DAF21725240C4245CC823604B40
67355	5	53	422	49119	29368	\N	55.195863000000003	с.Надеждино, Центральная, 39		0101000020E61000005EF1D4230D5052408CBFED0912994B40
67352	5	53	422	41365	28683	\N	54.923724	с. Морозовка, 60 лет Победы, 4		0101000020E6100000F913950D6B635240E14389963C764B40
49611	5	53	422	48546	29387	\N	55.023769000000001	с.Мельничное, Школьная, 21		0101000020E61000001A6EC0E7874252404ED4D2DC0A834B40
67050	5	53	422	24765	30004	\N	54.944853999999999	д.Лузино, Северная, 10		0101000020E6100000CF656A12BC41524055BFD2F9F0784B40
67342	5	53	422	24765	29635	\N	54.944853999999999	с. Лузино, 30 лет Победы, 14		0101000020E6100000CF656A12BC41524055BFD2F9F0784B40
67896	5	53	422	46284	29089	\N	55.323126000000002	с. Красноярка, ул. Ленина, 32		0101000020E61000007E8FFAEB15465240603E59315CA94B40
67266	5	53	422	2956	29385	\N	54.645181999999998	п. Красная Тула, Центральная, 10		0101000020E6100000B2D7BB3FDE925240E3FBE25295524B40
67338	5	53	422	48835	29579	\N	55.119470999999997	с.Красная Горка, Школьная, 4 А		0101000020E61000005B423EE8D947524003E962D34A8F4B40
67218	5	53	422	53105	30104	\N	54.646351913105903	д.Комсомол, Центральная, 32	Россия, Омская область, Омский район, поселок Комсомол	0101000020E610000061C43E011483524023DA8EA9BB524B40
67132	5	53	422	49226	29495	\N	55.154285000000002	п.Ключи, Березовая, 9		0101000020E6100000A91611C5E44D5240B6A1629CBF934B40
67376	5	53	422	8555	29616	\N	55.313357000000003	д.Классино, Центральная, 48, кв. 2		0101000020E61000006118B0E42A605240817C09151CA84B40
67371	5	53	422	49340	29546	\N	55.200718999999999	д.Калиновка, Гагарина, 9		0101000020E61000004BEA043411675240C9570229B1994B40
49729	5	53	422	46364	29196	\N	54.855018999999999	с.Калинино, Советская, 2 Б		0101000020E61000005CC98E8D40705240B43A3943716D4B40
67359	5	53	422	49173	30069	\N	54.766407000000001	д.Калачево, Школьная, 19 А		0101000020E610000064CF9ECBD45452407636E49F19624B40
49715	5	53	422	14811	29199	\N	54.813957000000002	п.Иртышский, Ленина, 21		0101000020E6100000242BBF0CC6655240D6AC33BE2F684B40
67337	5	53	422	48830	29770	\N	55.023434000000002	с. Дружино, Кленовая, 1 А		0101000020E6100000C8D0B1834A485240A7CEA3E2FF824B40
67372	5	53	422	60838	76450	\N	55.249479000000001	д.Девятериковка, Школьная, 11	Россия, Омская область, Омский район, поселок Девятириковка	0101000020E61000005969520ABA745240F70489EDEE9F4B40
67356	5	53	422	49135	\N	\N	55.252732000000002	п.Дачный, Дачная, 14 Г	Россия, Омская область, Омский район, поселок Дачный	0101000020E61000001B66683C115652408B53AD8559A04B40
66983	5	53	422	49135	73930	\N	55.253091375609102	д. Дачное, ул. Школьная, 8А	Россия, Омская область, Омский район, поселок Дачный	0101000020E6100000624A24D1CB555240BAF42F4965A04B40
67339	5	53	422	48860	29707	\N	55.033925000000004	п. Горячий Ключ, Лесная, 3		0101000020E61000007E8D2441B849524027C286A757844B40
67328	5	53	422	48662	\N	\N	55.090041999999997	д.Вперед, д.70		0101000020E610000041295AB9177152401AA20A7F868B4B40
67382	5	53	422	8854	29253	\N	54.891629000000002	д.Верхний Карбуш, Школьная, 4		0101000020E6100000CAC342AD694E5240259529E620724B40
67367	5	53	422	49291	29937	\N	55.299353000000004	д.Бородинка, Центральная, 38		0101000020E6100000D4D2DC0A616B5240D17AF83251A64B40
67333	5	53	422	53092	30045	\N	55.035065000000003	с.Богословка, Ленина, 34	Россия, Омская область, Омский район, поселок Богословка	0101000020E6100000A20A7F86376E5240FC1D8A027D844B40
67365	5	53	422	8038	29808	\N	55.185645999999998	д.Березянка, Центральная, 9 А		0101000020E61000006902452C625952400D51853FC3974B40
67179	5	53	422	30711	29933	\N	54.603107000000001	п.Ачаирский, Центральная, 2		0101000020E6100000E42CEC69877F52408D7E349C324D4B40
67330	5	53	422	6358	29947	\N	54.658208999999999	с.Ачаир, Школьная, 44		0101000020E6100000378AAC35947752406877483140544B40
67329	5	53	422	48678	29833	\N	55.092638000000001	п. Андреевский, Центральная, 4		0101000020E6100000978C63247B6D5240F52EDE8FDB8B4B40
14688	5	53	422	53087	30002	\N	55.042059438541003	с.Андреевка, Школьная, 6	Россия, Омская область, Омский район, поселок Андреевка	0101000020E61000003BC5AA419867524051C0763062854B40
67303	5	53	636	4932	29514	\N	54.762745000000002	Омская область, Оконешниковский муниципальный район, Чистовское сельское поселение, д.Язово, здание школы, Школьная, 2а		0101000020E610000067B96C74CEE252400118CFA0A1614B40
67301	5	53	636	4848	29220	\N	54.681024000000001	Омская область, Оконешниковский муниципальный район, Чистовское сельское поселение, с Чистово, здание администрации с.п, Дзержинского, 49		0101000020E6100000B9347EE195E3524043E55FCB2B574B40
67296	5	53	636	4536	30040	\N	54.748337999999997	Омская область, Оконешниковский муниципальный район, Оконешниковское городское поселение, д.Стрельниково, здание ФАПа, Стрельникова, 8		0101000020E6100000F294D5743DBF5240512D228AC95F4B40
67326	5	53	636	6160	29250	\N	54.990988999999999	Омская область, Оконешниковский муниципальный район, Золотонивское сельское поселение, д.Соловьевка,здание клуба, Зеленая, 5		0101000020E61000000C3ECDC98BC152400ED940BAD87E4B40
67316	5	53	636	5628	29653	\N	54.815072000000001	Омская область, Оконешниковский муниципальный район, Сергеевское сельское поселение, с.Сергеевка, Дом культуры, Центральная, 6		0101000020E61000005F29CB10C7B7524052F17F4754684B40
67312	5	53	636	5410	29373	\N	54.614916999999998	Омская область, Оконешниковский муниципальный район, Любимовское сельское поселение, д.Рождественка, здание школы, Школьная, 1		0101000020E61000008F1A13622EC052409160AA99B54E4B40
67299	5	53	636	4725	29355	\N	54.806932000000003	Омская область, Оконешниковский муниципальный район, Куломзинское сельское поселение, д.Пресновка, клуб, Центральная, 2		0101000020E6100000E7357689EAD25240460C3B8C49674B40
67318	5	53	636	5742	29041	\N	54.842433999999997	Омская область, Оконешниковский муниципальный район, Сергеевское сельское поселение, д.Павловка,здание клуба, Школьная, 22		0101000020E6100000DC2DC901BBA95240EC8497E0D46B4B40
67307	5	53	636	5166	29678	\N	54.730317999999997	Омская область, Оконешниковский муниципальный район, Крестинское сельское поселение, д.Орловка, здание клуба, Центральная, 15		0101000020E6100000A374E95F92D252400ED76A0F7B5D4B40
67320	5	53	636	5828	29788	\N	54.783866000000003	Омская область, Оконешниковский муниципальный район, Сергеевское сельское поселение,д.Ольховка,  здание клуба, Школьная, 19		0101000020E6100000166EF9484AB95240223999B855644B40
67289	5	53	636	4321	29875	\N	54.834149050934499	Омская область, Оконешниковский муниципальный район, Оконешниковское городское поселение, Дом культуры, Пролетарская, 67	Россия, Омская область, Оконешниковский район, поселок Оконешниково	0101000020E6100000B876A22424C65240DC7EF964C56A4B40
67292	5	53	636	4321	29093	\N	54.842232000000003	Омская область, Оконешниковский район, .р.п. Оконешниково, школа, Маяковского, 9		0101000020E6100000226E4E2503C5524085D21742CE6B4B40
67053	5	53	353	24902	29852	\N	56.153613	с. Артын, ул. Боровая, 7		0101000020E6100000E606431D56B05240C79E3D97A9134C40
67293	5	53	636	4321	30020	\N	54.835406604548403	Омская область, Оконешниковский муниципальный район, Оконешниковское городское поселение, БУ КЦСОН, Коммунистическая, 169	Россия, Омская область, Оконешниковский район, поселок Оконешниково	0101000020E6100000A585CB2A6CC55240BBECD79DEE6A4B40
67291	5	53	636	4321	30020	\N	54.838428597710099	Омская область, Оконешниковский муниципальный район, Оконешниковское городское поселение, школа №1, Коммунистическая, 87	Россия, Омская область, Оконешниковский район, поселок Оконешниково	0101000020E6100000430070ECD9C452404D8237A4516B4B40
67325	5	53	636	6125	29451	\N	54.951250000000002	Омская область, Оконешниковский муниципальный район, Оконешниковское городское поселение, д.Николаевка,жилой дом, Почтовая, 17		0101000020E61000000281CEA44DBF5240F6285C8FC2794B40
67295	5	53	636	4524	29912	\N	54.729044000000002	Омская область, Оконешниковский муниципальный район, Оконешниковское городское поселение, д.Михайловка, клуб, Школьная, 10		0101000020E6100000D481ACA756CC52402AAC5450515D4B40
67313	5	53	636	5445	29651	\N	54.559986000000002	Омская область, Оконешниковский муниципальный район, Андреевское сельское поселение, с. МАЯК, здание администрациис.п, Лесная, 5		0101000020E610000004029D499BC35240E31B0A9FAD474B40
67315	5	53	636	5559	29113	\N	54.569538999999999	Омская область, Оконешниковский муниципальный район, Андреевское сельское поселение, д.Мариновка, здание школы, Школьная, 13		0101000020E61000001AFCFD62B6D35240F56569A7E6484B40
67308	5	53	636	5209	29231	\N	54.665889999999997	Омская область, Оконешниковский муниципальный район, Любимовское сельское поселение, с.Любимовка, здание администрации с.п, Ленина, 32		0101000020E6100000D84812842BC75240E15D2EE23B554B40
67305	5	53	636	5062	29363	\N	54.539572999999997	Омская область, Оконешниковский муниципальный район, Крестинское сельское поселение, д.Ленинск , здание клуба, Первомайская, 25		0101000020E6100000C2887D0228DF5240FD6662BA10454B40
67298	5	53	636	4700	30044	\N	54.832914000000002	Омская область, Оконешниковский муниципальный район, Куломзинское сельское поселение, с.Куломзино, здание администрации с.п, Ленина, 23		0101000020E61000004E637B2DE8DD5240B6300BED9C6A4B40
67304	5	53	636	4998	29589	\N	54.626229000000002	Омская область, Оконешниковский муниципальный район, Крестинское сельское поселение, с.Крестики, здание администрации с.п, Центральная, 16		0101000020E6100000EEEC2B0FD2DB52404567994528504B40
67297	5	53	636	4643	\N	\N	54.927655999999999	Омская область, Оконешниковский муниципальный район, Красовское сельское поселение, с.Красовка, здание администрации с.п, Островского, 11	Россия, Омская область, Оконешниковский район, поселок Красовка	0101000020E61000000DFCA886FDCA524016F88A6EBD764B40
67317	5	53	636	5680	29838	\N	54.753439999999998	Омская область, Оконешниковский муниципальный район, Сергеевское сельское поселение, д.Кочковатое, здание школы, Школьная, 2		0101000020E6100000D55DD90583AA5240C6BFCFB870604B40
67311	5	53	636	5339	29783	\N	54.704720999999999	Омская область, Оконешниковский муниципальный район, Любимовское сельское поселение, д.Костяковка, здание клуба, Центральная, 27		0101000020E61000007CB94F8E02C55240F7E6374C345A4B40
67310	5	53	636	5310	29290	\N	54.649025999999999	Омская область, Оконешниковский муниципальный район, Любимовское сельское поселение, д.Кирилловка, здание школы, Зеленая, 26		0101000020E6100000A59F70766BCB52407920B24813534B40
67309	5	53	636	5228	29107	\N	54.692323000000002	Омская область, Оконешниковский муниципальный район, Любимовское сельское поселение, д.Камышино, здание клуба, Целинная, 16а		0101000020E6100000D388997D1EB8524062A2410A9E584B40
67321	5	53	636	5915	29725	\N	54.897064999999998	Омская область, Оконешниковский муниципальный район, Золотонивское сельское поселение, с. Золотая Нива, здание школы, Садовая, 28		0101000020E61000000211E2CAD9B9524070B1A206D3724B40
67324	5	53	636	6057	30035	\N	54.875092000000002	Омская область, Оконешниковский муниципальный район, Золотонивское сельское поселение, д.Елизаветино, здание клуба, Центральная, 36		0101000020E6100000613255302AB15240E17EC00303704B40
67319	5	53	636	5803	29711	\N	54.798110000000001	Омская область, Оконешниковский муниципальный район, Сергеевское сельское поселение, д.Волчино,  здание клуба, Зеленая, 9		0101000020E61000004D4BAC8C46BD5240274EEE7728664B40
67323	5	53	636	5974	29939	\N	54.858668000000002	Омская область, Оконешниковский муниципальный район, Золотонивское сельское поселение, д.Березовка,здание клуба, Центральная, 36		0101000020E6100000139ED0EB4FBB5240950F41D5E86D4B40
67314	5	53	636	5529	29223	\N	54.534725999999999	Омская область, Оконешниковский муниципальный район, Андреевское сельское поселение, д.Андреевка, здание клуба, Школьная, 8		0101000020E61000002E76FBAC32C552401329CDE671444B40
67302	5	53	636	4910	30052	\N	54.769652999999998	Омская область, Оконешниковский муниципальный район, Чистовское сельское поселение, д.Алексеевка, клуб, Первомайская, 22		0101000020E61000009AB0FD648CDC5240572250FD83624B40
67286	5	53	527	47874	29486	\N	54.077801999999998	с.Цветково, Почтовая, 19		0101000020E6100000CBD58F4DF21F52401DC87A6AF5094B40
67281	5	53	527	47794	30012	\N	54.313240999999998	с.Тишанка, Школьная, 4		0101000020E610000086915ED4EE3952401762F54718284B40
67270	5	53	527	3194	29942	\N	54.115369999999999	с.Славгородка, Школьная, 10		0101000020E6100000284696CCB13B52404278B471C40E4B40
67280	5	53	527	3715	29751	\N	54.365971999999999	с.Сарат, Центральная, 34		0101000020E6100000F65FE7A6CD45524038A0A52BD82E4B40
67287	5	53	527	47899	30028	\N	54.196593	с.Побочино, Октябрьская, 32б		0101000020E61000001EDE7360392B5240AFCF9CF529194B40
67099	5	53	7252	53023	29610	\N	56.405344999999997	р.п.Муромцево, ул. Нахимова, 4		0101000020E610000063B5F97FD5D252406E4C4F58E2334C40
67279	5	53	527	47753	\N	\N	54.339630999999997	с.Песчанка, Центральная, 29	Россия, Омская область, Одесский район, поселок Песчанка	0101000020E610000094DBF63DEA4A524098DA5207792B4B40
67282	5	53	527	47811	29534	\N	53.982968	с.Орехово, Мира, 3а		0101000020E6100000435376FA411F5240DC813AE5D1FD4A40
67269	5	53	527	47570	29322	\N	54.210365000000003	С.Одесское, Ленина, 36а		0101000020E61000009C1727BEDA3D52408D9C853DED1A4B40
67268	5	53	527	47570	29322	\N	54.210365000000003	с.Одесское, Ленина, 27		0101000020E61000009C1727BEDA3D52408D9C853DED1A4B40
67277	5	53	527	47722	30029	\N	54.315468000000003	с.Лукьяновка, Центральный, 3		0101000020E610000057B439CE6D4352409F77634161284B40
67275	5	53	527	47684	29456	\N	54.161836000000001	с.Желанное, Ленина, 22		0101000020E610000009707A17EF24524061A8C30AB7144B40
67285	5	53	527	3935	29622	\N	53.969664999999999	с.Громогласово, Центральная, 16		0101000020E610000077BF0AF0DD2B5240B58993FB1DFC4A40
67278	5	53	527	47740	29879	\N	54.248502000000002	с.Генераловка, Школьный, 1		0101000020E6100000C289E8D7D64C5240CC7EDDE9CE1F4B40
67274	5	53	527	47660	29046	\N	54.108065000000003	с.Ганновка, Романенко, 4		0101000020E61000001C261AA4E0505240CF6BEC12D50D4B40
67273	5	53	527	3343	29316	\N	54.126843000000001	с.Буняковка, Школьный, 8		0101000020E61000004089CF9D604A5240FF5C34643C104B40
67276	5	53	527	3524	29235	\N	54.189408	с.Брезицк, Центральная, 9		0101000020E610000076F9D687F51F5240E6CC76853E184B40
67283	5	53	527	47826	29618	\N	54.086939999999998	с.Бобровица, Бобровицкая, 21		0101000020E6100000711DE38A8B1A52406C5B94D9200B4B40
67272	5	53	527	47624	30000	\N	54.07197	с.Благодаровка, Центральная, 23		0101000020E6100000FD885FB1864B524085251E5036094B40
67271	5	53	527	47612	29174	\N	54.168582999999998	с.Белосток, Ленина, 20		0101000020E6100000F2D24D6210325240AED4B32094154B40
67263	5	53	266	53091	30038	\N	53.777622000000001	Омская область, Нововаршавский муниципальный район, Черлакское сельское поселение, Школьная, 13	Россия, Омская область, Нововаршавский район, поселок Черлакское	0101000020E6100000821C9430D3A052403753211E89E34A40
67893	5	53	266	40474	29998	\N	54.178159000000001	д. Славянка, ул. Центральная, 60		0101000020E61000004303B16CE6A15240793E03EACD164B40
67262	5	53	266	40474	29739	\N	54.178188008455201	Омская область, Нововаршавский муниципальный район, Славянское сельское поселение, Рассохина, 30	Россия, Омская область, Нововаршавский район, поселок Славянка	0101000020E6100000FEF2C98AE1A15240134548DDCE164B40
67252	5	53	266	2155	29660	\N	54.009813000000001	Омская область, Нововаршавский муниципальный район, Новороссийское сельское поселение, поселок Сибирское, Центральная, 1,а		0101000020E6100000AAF413CE6EB65240AF09698D41014B40
67259	5	53	266	61442	79182	\N	54.123244999999997	Омская область, Нововаршавский муниципальный район, Русановское сельское поселение, Центральная, 14	Россия, Омская область, Нововаршавский район, поселок Русановка	0101000020E61000002463B5F97FA35240A032FE7DC60F4B40
67249	5	53	266	1963	29723	\N	54.240889000000003	Омская область, Нововаршавский муниципальный район, Изумруднинское сельское поселение, деревня Рассохино, Береговая, 3		0101000020E6100000E3E13D0796A75240AB7B6473D51E4B40
67253	5	53	266	46354	79203	\N	54.050958999999999	Омская область, Нововаршавский муниципальный район, Победовское сельское поселение, Центральная, 6,а	Россия, Омская область, Нововаршавский район, поселок Победа	0101000020E61000002461DF4E229F5240EB3713D385064B40
66979	5	53	266	46354	29926	\N	54.050503999999997	д. Победа, ул. Новая, 2		0101000020E61000004A41B797349F5240992842EA76064B40
67258	5	53	266	46354	79192	\N	54.050958999999999	Омская область, Нововаршавский муниципальный район, Победовское сельское поселение, деревня Молодежная, Зеленая, 21	Россия, Омская область, Нововаршавский район, поселок Победа	0101000020E61000002461DF4E229F5240EB3713D385064B40
67267	5	53	266	2997	29246	\N	53.883266999999996	Омская область, Нововаршавский муниципальный район, Черлакское сельское поселение, деревня Платоновка, Школьная, 10-а		0101000020E610000050FEEE1D35AB524069519FE40EF14A40
67265	5	53	266	2859	30010	\N	53.763950999999999	Омская область, Нововаршавский муниципальный район, Черлакское сельское поселение, деревня Пичугино, Школьная, 6		0101000020E6100000D2544FE61FA652408D5F7825C9E14A40
67250	5	53	266	53042	29819	\N	54.112681239371497	Омская область, Нововаршавский муниципальный район, Новороссийское сельское поселение, Школьная, 2	Россия, Омская область, Нововаршавский район, поселок Новороссийка	0101000020E61000005036E50AEFAA5240B7F0BC546C0E4B40
67246	5	53	266	1765	29166	\N	54.389496999999999	Омская область, Нововаршавский муниципальный район, Зареченское сельское поселение, деревня Новоивановка, Новоивановская, 15,а		0101000020E61000005B9544F6419A5240EF71A609DB314B40
67244	5	53	266	52967	29076	\N	54.167512470355099	Омская область, Нововаршавский муниципальный район, Зареченское сельское поселение, Школьная, 13,а	Россия, Омская область, Нововаршавский район, поселок Нововаршавка	0101000020E61000004DF73AA92FAC524002D8800871154B40
67234	5	53	266	52967	79244	\N	54.170001999999997	Омская область, Нововаршавский муниципальный район, Нововаршавское городское поселение, Красный путь, 141	Россия, Омская область, Нововаршавский район, поселок Нововаршавка	0101000020E610000030116F9D7FAC5240962023A0C2154B40
67233	5	53	266	52967	30091	\N	54.166171833014403	Омская область, Нововаршавский муниципальный район, Нововаршавское городское поселение, Красноармейская, 3	Россия, Омская область, Нововаршавский район, поселок Нововаршавка	0101000020E610000092E68F696DAC524066C1C41F45154B40
67232	5	53	266	52967	30091	\N	54.1701504347024	Омская область, Нововаршавский муниципальный район, Нововаршавское городское поселение, ул. Красноармейская, 4	Россия, Омская область, Нововаршавский район, поселок Нововаршавка	0101000020E61000007EC7F0D8CFAC52400BB5A679C7154B40
66986	5	53	1656	21770	29238	\N	54.885337	д. Чебуренки, ул. Центральная, 5		0101000020E6100000096F0F424021524029780AB952714B40
67248	5	53	266	1909	28698	\N	54.232038000000003	Омская область, Нововаршавский муниципальный район, Изумруднинское сельское поселение, деревня Нетесово, Гагарина, 2		0101000020E610000084BD8921399A5240F2B6D26BB31D4B40
67257	5	53	266	2417	29288	\N	53.932537000000004	Омская область, Нововаршавский муниципальный район, Победовское сельское поселение, деревня Моисеевка, Нижняя, 17		0101000020E610000000AAB8718BA45240ADA7565F5DF74A40
67260	5	53	266	2612	29851	\N	54.147378000000003	Омская область, Нововаршавский муниципальный район, Русановское сельское поселение, поселок Любовский, Ветеранов, 7		0101000020E610000075392520269D524030134548DD124B40
67261	5	53	266	2645	29696	\N	54.160170000000001	Омская область, Нововаршавский муниципальный район, Русановское сельское поселение, станция Любовка, Школьная, 8		0101000020E6100000894336902E9C524071E6577380144B40
67235	5	53	266	1118	29434	\N	54.137104000000001	Омская область, Нововаршавский муниципальный район, д.Красный яр, Мельничная, 9		0101000020E6100000C617EDF142AE52404D13B69F8C114B40
67243	5	53	266	53113	30123	\N	53.8550744995324	Омская область, Нововаршавский муниципальный район, аул Караман, Береговая, 20	Россия, Омская область, Нововаршавский район, поселок Караман	0101000020E6100000CB4A9352D0BF524078D4981073ED4A40
67256	5	53	266	2361	29043	\N	54.067923	Омская область, Нововаршавский муниципальный район, Победовское сельское поселение, аул Каразюк, переулок Школьный, 2		0101000020E610000071E316F373A35240B7D26BB3B1084B40
67247	5	53	266	60837	76449	\N	54.217374	Омская область, Нововаршавский муниципальный район, Изумруднинское сельское поселение, Центральная, 3	Россия, Омская область, Нововаршавский район, поселок Изумрудное	0101000020E610000040A20914B1A85240178046E9D21B4B40
67245	5	53	266	60858	76478	\N	54.365701999999999	Омская область, Нововаршавский муниципальный район, Зареченское сельское поселение, аул Жар-агач, Верхняя, 10	Россия, Омская область, Нововаршавский район, поселок Жар-Агач	0101000020E61000004451A04FE4A05240780AB952CF2E4B40
67239	5	53	266	53120	30139	\N	54.035285695140601	Омская область, Нововаршавский муниципальный район, Ермаковское сельское поселение, Паркова, 5	Россия, Омская область, Нововаршавский район	0101000020E6100000041C42959AA35240DA006C4084044B40
67255	5	53	266	2310	29580	\N	53.986488000000001	Омская область, Нововаршавский муниципальный район, Победовское сельское поселение, село Дробышево, Центральная, 16		0101000020E6100000868DB27E33AB5240BFF2203D45FE4A40
67238	5	53	266	61475	79224	\N	53.915500000000002	Омская область, Нововаршавский муниципальный район, Большегривское городское поселение, Ленина, 16	Россия, Омская область, Нововаршавский район, поселок Большегривское	0101000020E610000045B8C9A832BA524077BE9F1A2FF54A40
67237	5	53	266	61475	79229	\N	53.915500000000002	Омская область, Нововаршавский муниципальный район, Большегривское городское поселение, Гагарина, 16	Россия, Омская область, Нововаршавский район, поселок Большегривское	0101000020E610000045B8C9A832BA524077BE9F1A2FF54A40
67251	5	53	266	2075	30080	\N	54.089348000000001	Омская область, Нововаршавский муниципальный район, Новороссийское сельское поселение, деревня Богдановка, Школьная, 2		0101000020E610000096D05D1267B2524044FB58C16F0B4B40
67236	5	53	266	61485	79236	\N	54.119481999999998	Омская область, Нововаршавский муниципальный район, Бобринское сельское поселение, Ленина, 46	Россия, Омская область, Нововаршавский район, поселок Бобринка	0101000020E61000000B42791F478F5240F73AA92F4B0F4B40
67242	5	53	266	1573	29164	\N	53.946874000000001	Омская область, Нововаршавский муниципальный район, село Береговое, Победы, 30		0101000020E61000000E6954E064BA524063B7CF2A33F94A40
67241	5	53	266	53039	29805	\N	53.942228779676199	Омская область, Нововаршавский муниципальный район, аул Алкул, Школьная, 14	Россия, Омская область, Нововаршавский район, поселок Алкул	0101000020E61000002881CD3978BC5240E02BBAF59AF84A40
67240	5	53	266	1453	29161	\N	53.971127000000003	Омская область, Нововаршавский муниципальный район, село Александровка, Центральная, 21		0101000020E610000079245E9ECEB652409DA1B8E34DFC4A40
67225	5	53	95	528	29143	\N	55.877732999999999	Омская область, Нижнеомский муниципальный район, Старомалиновское сельское поселение, д. Хутора, ул. Молодежная, 17А		0101000020E6100000DDD26A48DCA652405BCF108E59F04B40
67194	5	53	95	31446	29708	\N	55.589280000000002	Омская область, Нижнеомский муниципальный район, Хортицкое сельское поселение, с. Хортицы, К. Маркса, 7		0101000020E6100000D5777E5182BA5240EC17EC866DCB4B40
67211	5	53	95	32171	29812	\N	55.496588000000003	Омская область, Нижнеомский муниципальный район, Хомутинское сельское поселение, д. Хомутинка, ул. Центральная, 9 А		0101000020E61000004F5B238271C8524004CB113290BF4B40
67210	5	53	95	32171	29964	\N	55.496588000000003	Омская область, Нижнеомский муниципальный район, Хомутинское сельское поселение, с. Хомутинка, 70 лет Октября, 15		0101000020E61000004F5B238271C8524004CB113290BF4B40
67195	5	53	95	31498	29254	\N	55.647041000000002	Омская область, Нижнеомский муниципальный район, Хортицкое сельское поселение, д. Удачная, Советская, 12		0101000020E6100000BA30D28BDABE5240E8154F3DD2D24B40
67227	5	53	95	53104	30099	\N	55.857711381458998	Омская область, Нижнеомский муниципальный район, Старомалиновское сельское поселение, Пролетарская, 10	Россия, Омская область, Нижнеомский район, поселок Старомалиновка	0101000020E610000092B245D26EA45240B1355B79C9ED4B40
66901	5	53	1089	17351	29305	\N	56.222845999999997	д. Усть-Логатка (д. Мысы, д. им. М. Горького), Заречная, 34А		0101000020E6100000FB3BDBA337FF5140AF05BD37861C4C40
67207	5	53	95	53016	29571	\N	55.309546446495297	Омская область, Нижнеомский муниципальный район, Соловецкое сельское поселение, Школьная, 21	Россия, Омская область, Нижнеомский район, поселок Соловецкое	0101000020E6100000BDFE243E77BF5240C64D0D349FA74B40
67180	5	53	95	30742	29655	\N	55.480077000000001	Омская область, Нижнеомский муниципальный район, Смирновское сельское поселение, с. Смирновка, Центральная, 20 В		0101000020E61000003F6F2A5261B55240E947C32973BD4B40
67208	5	53	95	60836	76448	\N	55.387156813290801	Омская область, Нижнеомский муниципальный район, Соловецкое сельское поселение,д. Слободка, ул. Центральная, 3, здание школы	Россия, Омская область, Нижнеомский район, поселок Слободка (Малая Омка)	0101000020E61000009F1F46088FBE524070B54E5C8EB14B40
67215	5	53	95	32396	29684	\N	55.720661999999997	Омская область, Нижнеомский муниципальный район, Ситниковское сельское поселение, д. Сидоровка, Зеленая, 2		0101000020E61000009E42AED4B3A3524027BC04A73EDC4B40
67212	5	53	95	32268	29962	\N	55.528060000000004	Омская область, Нижнеомский муниципальный район, Хомутинское сельское поселение, д. Рязанка, ,ул. Новая, 13/1		0101000020E6100000D80DDB1665CC5240B329577897C34B40
67187	5	53	95	31087	30082	\N	55.553325000000001	Омская область, Нижнеомский муниципальный район, Паутовское сельское поселение, д. Рождественка, Интернациональная, 17		0101000020E6100000D2A6EA1ED9A252409487855AD3C64B40
67231	5	53	95	52983	29279	\N	55.875412375576197	Омская область, Нижнеомский муниципальный район, Новотроицкое сельское поселение, д. Радищевка, ул. Школьная, 5	Россия, Омская область, Нижнеомский район, поселок Радищево	0101000020E6100000B60F79CBD5C4524052431B800DF04B40
67224	5	53	95	425	29713	\N	55.939424000000002	Омская область, Нижнеомский муниципальный район, Старомалиновское сельское поселение, д. Пустынное, ул. Нииз, 15		0101000020E61000008DD13AAA9AAB5240EC89AE0B3FF84B40
67178	5	53	95	30651	29114	\N	55.36598	Омская область, Нижнеомский муниципальный район, Антоновское сельское поселение, д. Пугачевка, Центральная, 18		0101000020E610000078B7B24467B45240BB7EC16ED8AE4B40
67174	5	53	95	30432	29835	\N	55.406748	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселениед, Придорожное, ул. Центральная, 6		0101000020E610000018B0E42A16B4524051DB865110B44B40
67206	5	53	95	31978	\N	\N	55.297978999999998	Омская область, Нижнеомский муниципальный район, Соловецкое сельское поселение, д. Полтавка, ул. Центральная, 33	Россия, Омская область, Нижнеомский район, поселок Полтавка	0101000020E6100000F27C06D49BC4524088F2052D24A64B40
67454	5	53	95	31978	29308	\N	55.297978999999998	рабочий поселок Полтавка, Победы, 139		0101000020E6100000F27C06D49BC4524088F2052D24A64B40
67216	5	53	95	32408	29138	\N	55.786504999999998	Омская область, Нижнеомский муниципальный район, Ситниковское сельское поселение, д. Покровка, ул. Школьная, 6		0101000020E6100000C84109336DA85240FB912232ACE44B40
67229	5	53	95	800	29273	\N	55.817293999999997	Омская область, Нижнеомский муниципальный район, Новотроицкое сельское поселение, д. Петропавловка, ул. Школьная, 2		0101000020E6100000BABDA4315AC15240C79BFC169DE84B40
67184	5	53	95	30945	29750	\N	55.489294999999998	Омская область, Нижнеомский муниципальный район, Паутовское сельское поселение, с. Паутовка, Советская, 1		0101000020E610000051853FC39B9F5240548CF337A1BE4B40
66981	5	53	95	118	76412	\N	55.800958999999999	д. Отрадное, ул. Школьная, 2А	Россия, Омская область, Нижнеомский район, поселок Отрадновка	0101000020E6100000ECA353573EAC5240EB3713D385E64B40
67219	5	53	95	118	29268	\N	55.800958999999999	Омская область, Нижнеомский муниципальный район, Ситниковское сельское поселение, д. Отрадновка, ул. Рабочая, 3  А		0101000020E6100000ECA353573EAC5240EB3713D385E64B40
67197	5	53	95	31582	29400	\N	55.684381000000002	Омская область, Нижнеомский муниципальный район, Хортицкое сельское поселение, д. Озерное, ул. Зеленая, 15		0101000020E6100000C6E061DA37B752407C80EECB99D74B40
67228	5	53	95	740	29566	\N	55.790711999999999	Омская область, Нижнеомский муниципальный район, Новотроицкое сельское поселение, с. Новотроицк, Советская, 13		0101000020E610000003965CC5E2C452400247020D36E54B40
67191	5	53	95	31267	29860	\N	55.564954	Омская область, Нижнеомский муниципальный район, Паутовское сельское поселение, д. Новоивановка, Школьная, 2		0101000020E6100000D2C6116BF19F524048DFA46950C84B40
67221	5	53	95	258	29267	\N	55.807865	Омская область, Нижнеомский муниципальный район, Старомалиновское сельское поселение, д. Николаевка, ул. Зеленая, 11 А		0101000020E610000020B8CA1308B65240A14ACD1E68E74B40
67171	5	53	95	30099	29105	\N	55.415145000000003	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, с. Нижняя Омка, Юбилейная, 2		0101000020E61000004CA8E0F082BC5240890CAB7823B54B40
67168	5	53	95	30099	30064	\N	55.415145000000003	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, Нижняя Омка, Школьная, 9		0101000020E61000004CA8E0F082BC5240890CAB7823B54B40
67169	5	53	95	30099	30066	\N	55.415145000000003	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, с. Нижняя Омка, Транспортная, 55		0101000020E61000004CA8E0F082BC5240890CAB7823B54B40
67170	5	53	95	30099	29832	\N	55.415145000000003	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, с. Нижняя Омка, Романенко, 38		0101000020E61000004CA8E0F082BC5240890CAB7823B54B40
67167	5	53	95	30099	29229	\N	55.415145000000003	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, с. Нижняя Омка, Ленина, 79		0101000020E61000004CA8E0F082BC5240890CAB7823B54B40
67204	5	53	95	31972	29551	\N	55.257458	Омская область, Нижнеомский муниципальный район, Соловецкое сельское поселение, д. Медвежья Грива, ул. Центральная, 6		0101000020E6100000D49D279EB3CD5240FA0B3D62F4A04B40
67188	5	53	95	31162	29389	\N	55.505744999999997	Омская область, Нижнеомский муниципальный район, Паутовское сельское поселение, д. Любимовка, Зеленая, 12		0101000020E61000001B4CC3F011AB5240C98E8D40BCC04B40
67203	5	53	95	31835	28663	\N	55.226708000000002	Омская область, Нижнеомский муниципальный район, Соловецкое сельское поселение, д. Локти, ул. Центральная, 16		0101000020E6100000698EACFC32C25240ECDE8AC4049D4B40
67202	5	53	95	31835	29837	\N	55.226708000000002	Омская область, Нижнеомский муниципальный район, Глухониколаевское сельское поселение, д. Локти, ул. Калачинская, 10		0101000020E6100000698EACFC32C25240ECDE8AC4049D4B40
67192	5	53	95	31362	29048	\N	55.588738165389501	Омская область, Нижнеомский муниципальный район, Паутовское сельское поселение, п. Лесной, Колупаева, 13	Россия, Омская область, Нижнеомский район, поселок Лесной	0101000020E61000007B4ACE893DA35240CBF44BC45BCB4B40
67175	5	53	95	30481	29526	\N	55.386073000000003	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, д. Лаврино, ул. Школьная, 3		0101000020E6100000C45E28603BAF52402F6F0ED76AB14B40
67209	5	53	95	32123	29810	\N	55.462268000000002	Омская область, Нижнеомский муниципальный район, Хомутинское сельское поселение, д. Киршовка, Школьная, 13 А		0101000020E61000007B116DC7D4C4524061FE0A992BBB4B40
67173	5	53	95	60848	76463	\N	55.441116000000001	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, д. Камышенка, ул. Центральная, 13		0101000020E61000008F71C5C551B4524005DF347D76B84B40
67199	5	53	95	31680	29118	\N	55.258853000000002	Омская область, Нижнеомский муниципальный район, Глухониколаевское сельское поселение, д. Измайловка, ул. Школьная, 14		0101000020E610000045B9347EE1B852405ABC581822A14B40
67183	5	53	95	30898	29539	\N	55.492997000000003	Омская область, Нижнеомский муниципальный район, Смирновское сельское поселение, д. Зенкуль, Центральная, 21		0101000020E610000063EE5A423EB05240580394861ABF4B40
67213	5	53	95	53031	29695	\N	55.599862251365899	Омская область, Нижнеомский муниципальный район, Хомутинское сельское поселение, д. Епанчино, ул. Трудовая, 18 А	Россия, Омская область, Нижнеомский район, поселок Еланчино	0101000020E61000008124ECDB49C552407C0E2C47C8CC4B40
67201	5	53	95	53028	29679	\N	55.284619704803902	Омская область, Нижнеомский муниципальный район, Глухониколаевское сельское поселение, Административный переулок, 1	Россия, Омская область, Нижнеомский район, поселок Глухониколаевка	0101000020E610000076C24B70EAC15240CDE49B6D6EA44B40
67230	5	53	95	843	29276	\N	55.777180000000001	Омская область, Нижнеомский муниципальный район, Новотроицкое сельское поселение, д. Воскресенка, ул. Школьная, 3		0101000020E6100000B9E177D32DBA52407A8D5DA27AE34B40
67172	5	53	95	30334	29234	\N	55.445445999999997	Омская область, Нижнеомский муниципальный район, Нижнеомское сельское поселение, д. Вишневка, ул. Южная, 2		0101000020E6100000A52DAEF199BE52402711E15F04B94B40
67193	5	53	95	31410	29578	\N	55.525633999999997	Омская область, Нижнеомский муниципальный район, Хортицкое сельское поселение, д. Виноградовка, Трудовая, 19		0101000020E610000058C7F143A5BE524034D593F947C34B40
67222	5	53	95	370	29275	\N	55.879576	Омская область, Нижнеомский муниципальный район, Старомалиновское сельское поселение, д. Борисовка, Заовражная, 3А		0101000020E6100000E3C4573B8AAD52405A2C45F295F04B40
67226	5	53	95	631	29974	\N	55.831029000000001	Омская область, Нижнеомский муниципальный район, Старомалиновское сельское поселение, д. Бещаул, Сибирская, 7		0101000020E610000031444E5FCFA05240888384285FEA4B40
67181	5	53	95	30811	29115	\N	55.534275999999998	Омская область, Нижнеомский муниципальный район, Смирновское сельское поселение, д. Ачаирка, Центральная, 22		0101000020E6100000586FD40AD3B65240D384ED2763C44B40
67177	5	53	95	30572	29787	\N	55.345779999999998	Омская область, Нижнеомский муниципальный район, Антоновское сельское поселение, с. Антоновка, Петра Ильичева, 15		0101000020E61000007653CA6B25BD524031CEDF8442AC4B40
67128	5	53	625	28307	29885	\N	55.886755999999998	Омская область, Называевский муниципальный район, Искровское сельское поселение, деревня Ястреб, Школьная, 10		0101000020E610000011A7936C75C9514011C4793881F14B40
67147	5	53	625	29164	29094	\N	55.675646	Омская область, Называевский муниципальный район, Налимовское сельское поселение, деревня Черняевка, Школьная, 5		0101000020E610000067994528B6ED51402CD670917BD64B40
67162	5	53	625	29877	29983	\N	55.41769	Омская область, Называевский муниципальный район, Черемновское сельское поселение, село Черемновка, Центральная, 25		0101000020E6100000E2EA0088BBF15140E1EEACDD76B54B40
67163	5	53	625	29921	29226	\N	55.472259999999999	Омская область, Называевский муниципальный район, Черемновское сельское поселение, деревня Фомиха, Центральная, 23		0101000020E61000000C5A48C0E8E05140BF9A030473BC4B40
67158	5	53	625	29661	29919	\N	55.319110000000002	Омская область, Называевский муниципальный район, Утинское сельское поселение, село Утичье, Школьная, 7		0101000020E610000024B6BB07E8E85140CDE9B298D8A84B40
67131	5	53	625	28458	29334	\N	55.449520999999997	Омская область, Называевский муниципальный район, Кисляковское сельское поселение, деревня Тупицыно, Зелёная, 21		0101000020E610000049D576137CA55140BFEE74E789B94B40
67151	5	53	625	29341	30039	\N	55.541060999999999	Омская область, Называевский муниципальный район, Покровское сельское поселение, деревня Сырьёвка, Школьная, 33		0101000020E61000007A50508A56C651400E12A27C41C54B40
67139	5	53	625	28818	29342	\N	55.655453000000001	Омская область, Называевский муниципальный район, Лорис-Меликовское сельское поселение, аул Сулу-Терек, Центральная, 1		0101000020E61000004912842BA0E35140558847E2E5D34B40
67126	5	53	625	28238	29287	\N	55.472689000000003	Омская область, Называевский муниципальный район, Жирновское сельское поселение, деревня Староназываевка, Центральная, 11		0101000020E6100000E0A128D027D25140E816BA1281BC4B40
67155	5	53	625	29516	29917	\N	55.741352999999997	Омская область, Называевский муниципальный район, Старинское сельское поселение, село Старинка, Школьная, 31		0101000020E610000093A8177C9ADA51404FE5B4A7E4DE4B40
67159	5	53	625	29710	29777	\N	55.399172	Омская область, Называевский муниципальный район, Утинское сельское поселение, деревня Спасск, Школьная, 1		0101000020E6100000B1DEA815A6E851404DBD6E1118B34B40
67149	5	53	625	29256	29632	\N	55.449817000000003	Омская область, Называевский муниципальный район, Покровское сельское поселение, деревня Рыбье, Южная, д. 19, кв. 1		0101000020E610000057EA5910CABE5140A9177C9A93B94B40
67300	5	53	625	30001	\N	\N	55.382221999999999	п.Ростовка, 5		0101000020E6100000349F73B7EBF85140E6E786A6ECB04B40
67165	5	53	625	30001	29151	\N	55.382221999999999	Омская область, Называевский муниципальный район, Черемновское сельское поселение, деревня Ростовка, Северная, 3		0101000020E6100000349F73B7EBF85140E6E786A6ECB04B40
67122	5	53	625	28046	29482	\N	55.765087999999999	Омская область, Называевский муниципальный район, Большесафонинское сельское поселение, деревня Редкое, Школьная, 1		0101000020E6100000823B50A73CC35140F1475167EEE14B40
67121	5	53	625	28003	29071	\N	55.756461999999999	Омская область, Называевский муниципальный район, Большесафонинское сельское поселение, село Путь Социализма, Школьная, 3		0101000020E61000009626A5A0DBD0514058552FBFD3E04B40
67148	5	53	625	29237	29349	\N	55.522959	Омская область, Называевский муниципальный район, Покровское сельское поселение, село Покровка, Зелёная, 38		0101000020E610000035272F3201C051400E130D52F0C24B40
67133	5	53	625	28554	29757	\N	55.317214999999997	Омская область, Называевский муниципальный район, Кисляковское сельское поселение, деревня Носовка, Центральная, 31		0101000020E61000009D4A06802AA351407B6649809AA84B40
67156	5	53	625	29596	29217	\N	55.846809999999998	Омская область, Называевский муниципальный район, Старинское сельское поселение, деревня Новоосиново, Зелёная, 1		0101000020E6100000E9EFA5F0A0D551407FF6234564EC4B40
67125	5	53	625	28172	29755	\N	55.485219000000001	Омская область, Называевский муниципальный район, Жирновское сельское поселение, деревня Нововоскресенка, Центральная, 11		0101000020E610000001310917F2D45140EC32FCA71BBE4B40
67124	5	53	625	28127	30031	\N	55.322854999999997	Омская область, Называевский муниципальный район, Жирновское сельское поселение, деревня Нахимовка, Зелёная, 16		0101000020E61000005F7CD11E2FD35140CF2C095053A94B40
67146	5	53	625	29157	29211	\N	55.638083999999999	Омская область, Называевский муниципальный район, Налимовское сельское поселение, село Налимово, Школьная, 8		0101000020E61000007EA7C98CB7F45140E90C8CBCACD14B40
67113	5	53	625	27322	29745	\N	55.577134000000001	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, переулок Транспортный, 23		0101000020E610000086AA984A3FD6514070B4E386DFC94B40
67111	5	53	625	27322	30018	\N	55.577134000000001	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, Чкалова, 18		0101000020E610000086AA984A3FD6514070B4E386DFC94B40
67110	5	53	625	27322	29606	\N	55.577134000000001	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, Пролетарская, 66		0101000020E610000086AA984A3FD6514070B4E386DFC94B40
67108	5	53	625	27322	29606	\N	55.577134000000001	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, Пролетарская, 27		0101000020E610000086AA984A3FD6514070B4E386DFC94B40
67109	5	53	625	27322	29061	\N	55.577134000000001	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, Красная, 105		0101000020E610000086AA984A3FD6514070B4E386DFC94B40
67107	5	53	625	27322	29318	\N	55.577134000000001	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, Кирова, 44		0101000020E610000086AA984A3FD6514070B4E386DFC94B40
67106	5	53	625	27322	29318	\N	55.577134000000001	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, Кирова, 21		0101000020E610000086AA984A3FD6514070B4E386DFC94B40
67112	5	53	625	27322	29744	\N	55.568918275100302	Омская область, Называевский муниципальный район, Называевское городское поселение, город Называевск, Вокзальная, 5	Россия, Омская область, Называевский район, Называевск	0101000020E61000005B3FFD67CDD65140880D164ED2C84B40
67143	5	53	625	29011	29897	\N	55.672930000000001	Омская область, Называевский муниципальный район, Муравьевское сельское поселение, село Муравьёвка, Колхозная, 47		0101000020E610000033198EE733DA5140A73FFB9122D64B40
66848	5	53	625	29419	\N	\N	55.585113	Михайловка, Здание школы		0101000020E610000064963D096CCE514073BB97FBE4CA4B40
67668	5	53	625	29419	29485	\N	55.585113	д.Михайловка, Новая, 6		0101000020E610000064963D096CCE514073BB97FBE4CA4B40
67153	5	53	625	29419	29354	\N	55.585113	Омская область, Называевский муниципальный район, Покровское сельское поселение, деревня Михайловка, Зелёная, 18		0101000020E610000064963D096CCE514073BB97FBE4CA4B40
66905	5	53	1089	17528	29866	\N	56.079819000000001	д. Усть-Китерма, Школьная, 1		0101000020E6100000226E4E2503EB5140BA4C4D82370A4C40
67116	5	53	625	27781	29874	\N	55.507371999999997	Омская область, Называевский муниципальный район, Богодуховское сельское поселение, деревня Милютино, Озёрная, 2		0101000020E6100000C1E10511A9F55140FB73D190F1C04B40
67140	5	53	625	28885	29506	\N	55.778866000000001	Омская область, Называевский муниципальный район, Мангутское сельское поселение, село Мангут, Кирова, 10		0101000020E6100000F2B1BB4049B15140B1FB8EE1B1E34B40
67138	5	53	625	28787	29503	\N	55.583407999999999	Омская область, Называевский муниципальный район, Лорис-Меликовское сельское поселение, село Лорис-Меликово, Ленина, 19		0101000020E610000037548CF337E65140C51C041DADCA4B40
67164	5	53	625	29948	29225	\N	55.442801000000003	Омская область, Называевский муниципальный район, Черемновское сельское поселение, деревня Лески, Зелёная, 18		0101000020E6100000CFA10C5531FC51406CD102B4ADB84B40
67137	5	53	625	28708	29088	\N	55.233927000000001	Омская область, Называевский муниципальный район, Князевское сельское поселение, деревня Лебяжье, Центральная, д. 14, кв. 1		0101000020E610000055FA0967B7C051406153E751F19D4B40
67115	5	53	625	53036	29762	\N	55.453814999999999	"Омская область, Называевский муниципальный район, Богодуховское сельское поселение, остановочный пункт ""Кочковатский"", д. 44, кв. 2"		0101000020E61000001C9947FE60EC514095B7239C16BA4B40
67117	5	53	625	27828	29612	\N	55.509583999999997	Омская область, Называевский муниципальный район, Богодуховское сельское поселение, деревня Кочковатка, Южная, 2		0101000020E61000001650A8A78FE951404D486B0C3AC14B40
67142	5	53	625	28962	29507	\N	55.764875000000004	Омская область, Называевский муниципальный район, Мангутское сельское поселение, деревня Котино, Зелёная, 46		0101000020E6100000D8D825AAB7B3514096438B6CE7E14B40
67161	5	53	625	29795	29569	\N	55.228130999999998	Омская область, Называевский муниципальный район, Утинское сельское поселение, деревня Константиновка, Школьная, 10-а		0101000020E6100000310A82C7B7ED5140151A8865339D4B40
67134	5	53	625	28576	30034	\N	55.343854999999998	Омская область, Называевский муниципальный район, Князевское сельское поселение, село Князево, Советская, 5		0101000020E6100000103D29931ABF514075C8CD7003AC4B40
67130	5	53	625	28403	29200	\N	55.344980999999997	Омская область, Называевский муниципальный район, Кисляковское сельское поселение, село Кисляки, Центральная, 8		0101000020E610000054AD855968A85140E55E605628AC4B40
67145	5	53	625	29107	29212	\N	55.667141999999998	Омская область, Называевский муниципальный район, Муравьевское сельское поселение, аул Кирей, Абая, 22		0101000020E6100000C45F9335EAE35140DEE4B7E864D54B40
67129	5	53	625	28372	29756	\N	55.831792	Омская область, Называевский муниципальный район, Искровское сельское поселение, деревня Караульное, Центральная, 14		0101000020E6100000960A2AAA7EBC51408789062978EA4B40
67157	5	53	625	52985	29310	\N	55.766196641065299	Омская область, Называевский муниципальный район, Старинское сельское поселение, аул Каран-Гарал, Отобая, 3	Россия, Омская область, Называевский район, поселок Каран-Гарал	0101000020E6100000AE282504ABE351408BA548BE12E24B40
67119	5	53	625	27912	29074	\N	55.462681000000003	Омская область, Называевский муниципальный район, Большепесчанское сельское поселение, деревня Калмацкое, Центральная, 18		0101000020E610000037548CF337B5514084BD892139BB4B40
67135	5	53	625	28636	29499	\N	55.339559999999999	Омская область, Называевский муниципальный район, Князевское сельское поселение, деревня Кабаново, Центральная, д. 24, кв. 1		0101000020E6100000C24CDBBFB2B75140CF83BBB376AB4B40
67127	5	53	625	28249	29081	\N	55.922725999999997	Омская область, Называевский муниципальный район, Искровское сельское поселение, село Искра, Горького, 10		0101000020E61000007288B83995BE51409E95B4E21BF64B40
67123	5	53	625	28092	29195	\N	55.388047	Омская область, Называевский муниципальный район, Жирновское сельское поселение, село Жирновка, Бондаренко, 51		0101000020E610000026C5C72764D55140CC272B86ABB14B40
67136	5	53	625	28691	29760	\N	55.327941000000003	Омская область, Называевский муниципальный район, Князевское сельское поселение, деревня Дурбет, Центральная, 8		0101000020E6100000AE635C7171CC51403F027FF8F9A94B40
66909	5	53	625	17761	29703	\N	55.328319999999998	Омская область, Любинский муниципальный район, посёлок Драгунский, Центральная, 5		0101000020E61000005F45460724FD5140B54FC76306AA4B40
67160	5	53	625	29788	29640	\N	55.316958999999997	Омская область, Называевский муниципальный район, Утинское сельское поселение, деревня Драгунка, Слободская, 21		0101000020E6100000077DE9EDCFF551402096CD1C92A84B40
67152	5	53	625	29411	29914	\N	55.525359000000002	Омская область, Называевский муниципальный район, Покровское сельское поселение, деревня Гагаринка, Центральная, 22		0101000020E6100000E085ADD9CAD0514063D4B5F63EC34B40
67141	5	53	625	28937	29898	\N	55.691800000000001	Омская область, Называевский муниципальный район, Мангутское сельское поселение, деревня Бузан, Озерная, 32		0101000020E610000006668522DDA45140B8AF03E78CD84B40
67118	5	53	625	27861	29480	\N	55.526831999999999	Омская область, Называевский муниципальный район, Большепесчанское сельское поселение, село Большепесчанка, Советская, 54		0101000020E6100000C07630629FB351403E3E213B6FC34B40
67144	5	53	625	29036	29765	\N	55.650927000000003	Омская область, Называевский муниципальный район, Муравьевское сельское поселение, деревня Богословка, Центральная, д. 4, кв. 1		0101000020E61000002B6B9BE271D45140AD8A709351D34B40
67114	5	53	625	27702	29478	\N	55.481026	Омская область, Называевский муниципальный район, Богодуховское сельское поселение, село Богодуховка, Молодёжная, 2		0101000020E610000054A9D903ADF051404A438D4292BD4B40
67150	5	53	625	29327	29213	\N	55.525562999999998	Омская область, Называевский муниципальный район, Покровское сельское поселение, деревня Батареевка, Центральная, 22		0101000020E610000048C32973F3C351406B7EFCA545C34B40
67154	5	53	625	29503	29639	\N	55.622309000000001	Омская область, Называевский муниципальный район, Покровское сельское поселение, аул Байымбет, Школьная, 31		0101000020E6100000EB8D5A61FAC85140D48041D2A7CF4B40
67083	5	53	353	26255	29728	\N	56.444572999999998	д. Юдинка, ул. Центральная, 23		0101000020E6100000E9F010C64F025340A1D79FC4E7384C40
67080	5	53	353	26118	29743	\N	56.354925999999999	д. Черталы, ул. Новостройка, 2		0101000020E6100000AE8218E8DAD85240034015376E2D4C40
67095	5	53	353	48587	29867	\N	56.365946999999998	с. Ушаково, ул. Школьная, 12		0101000020E6100000DBDE6E490EEC5240DF88EE59D72E4C40
67094	5	53	353	48587	30075	\N	56.365946999999998	с. Ушаково, ул. Ушаковская, 31		0101000020E6100000DBDE6E490EEC5240DF88EE59D72E4C40
67062	5	53	353	25294	29824	\N	56.501117999999998	д. Тармакла, Молодежная, 185		0101000020E61000005F7AFB73D1E15240EDB776A224404C40
67057	5	53	353	14212	28697	\N	56.373415000000001	Омская область, Муромцевский  муниципальный район,д. Танатово ул. Мира 6, ФАП		0101000020E61000005CAB3DEC85B35240FD6A0E10CC2F4C40
67071	5	53	353	25724	\N	\N	56.120161000000003	д. Сперановка, ул. Центральная, 23	Россия, Омская область, Муромцевский район, поселок Сперановка	0101000020E610000056F31C91EFBC524099A0866F610F4C40
67096	5	53	353	48627	29053	\N	56.345210000000002	д. Самохвалово, ул. Центральная, 58		0101000020E610000054AD855968E4524047205ED72F2C4C40
67090	5	53	353	48530	29527	\N	56.572006999999999	с. Рязаны, ул. Центральная, 50		0101000020E6100000CEDE196D55CD5240A20A7F8637494C40
67085	5	53	353	48437	29051	\N	56.578209999999999	с. Поречье, ул.Зеленая, 25б		0101000020E61000009869FB5756BC52402E1C08C9024A4C40
67105	5	53	353	48793	29738	\N	56.376795000000001	д. Плотбище, ул. Школьная, 1		0101000020E61000008BFED0CC93DE5240EE258DD13A304C40
67058	5	53	353	47925	29587	\N	56.442304	д. Окунево, ул. Центральная, 75		0101000020E610000089981249F4B95240EB71DF6A9D384C40
67069	5	53	353	48140	29167	\N	56.202866999999998	д. Новорождественка, Центральная, 38	Россия, Омская область, Муромцевский район, поселок Новорождественка	0101000020E61000005CFFAECF9CBA52400438BD8BF7194C40
67081	5	53	353	26174	29481	\N	56.393433999999999	с. Низовое, ул. Трактовая, 54		0101000020E61000002B8716D9CEF652403691990B5C324C40
67076	5	53	353	60136	73883	\N	56.350866709865699	с.Мыс, ул. Тарская, 16	Россия, Омская область, Муромцевский район, поселок Мыс	0101000020E6100000FF756EDA8CDB5240711FB935E92C4C40
67100	5	53	353	48657	29182	\N	56.371924	р.п.Муромцево, ул. Лисина, 174		0101000020E61000001D9430D3F6CE52407B4CA4349B2F4C40
67101	5	53	353	48657	29311	\N	56.371924	р.п.Муромцево, ул. Ленина, 66		0101000020E61000001D9430D3F6CE52407B4CA4349B2F4C40
67098	5	53	353	48657	29311	\N	56.371924	р.п.Муромцево, ул. Ленина, 144		0101000020E61000001D9430D3F6CE52407B4CA4349B2F4C40
67097	5	53	353	48657	29311	\N	56.371924	р.п.Муромцево, ул. Ленина, 33		0101000020E61000001D9430D3F6CE52407B4CA4349B2F4C40
67103	5	53	353	48657	29870	\N	56.371924	р.п.Муромцево, ул. Кооперативная, 29		0101000020E61000001D9430D3F6CE52407B4CA4349B2F4C40
67072	5	53	353	25791	29448	\N	56.038905999999997	с. Моховой Привал, ул. Юбилейная, 3		0101000020E6100000A4AA09A2EEBA524020CF2EDFFA044C40
67064	5	53	353	52962	29042	\N	56.547502000000001	д. Михайловка, ул. Солнечная, 34	Россия, Омская область, Муромцевский район, поселок Михайловка	0101000020E6100000755B22179CFB52404F3FA88B14464C40
67056	5	53	353	25010	29849	\N	56.400956999999998	д. Лисино, ул. Центральная, 10		0101000020E6100000A1A014ADDCC55240170D198F52334C40
67079	5	53	353	26053	29063	\N	56.301563999999999	д. Курнево, ул. Центральная, 9	Россия, Омская область, Муромцевский район, поселок Курнево	0101000020E610000083FB010F0CE4524052D32EA699264C40
67065	5	53	353	48054	29446	\N	56.442722000000003	с. Курганка, ул. Береговая, 58		0101000020E6100000815EB87361F45240209C4F1DAB384C40
67068	5	53	353	48119	29857	\N	56.173377000000002	с. Костино, ул. 40 лет Победы, 17		0101000020E610000096AFCBF09FBC52407670B03731164C40
67074	5	53	353	48232	29383	\N	55.925828000000003	д.Копьево, Копьевская, 7		0101000020E610000054E6E61BD1C152404DDC2A8881F64B40
67061	5	53	353	47988	29172	\N	56.459378000000001	с. Кондратьево, ул. Ленина, 107		0101000020E61000007841446ADAE452403E40F7E5CC3A4C40
67059	5	53	353	53106	30109	\N	56.388436338433003	д. Кокошенево, ул. Центральная, 61	Россия, Омская область, Муромцевский район, поселок Кокшенёво	0101000020E61000007FBF982D59CA5240664B5645B8314C40
67067	5	53	353	48094	28671	\N	56.040742000000002	д. Качесово, ул. Центральная, 45 г	Россия, Омская область, Муромцевский район, поселок Качесово	0101000020E6100000B613252191B052406DC9AA0837054C40
67063	5	53	353	25313	29977	\N	56.589969000000004	с. Карбыза, ул. Центральная, 10		0101000020E6100000386A85E97BFA5240B153AC1A844B4C40
67091	5	53	353	26640	29602	\N	56.651671	д. Караклинка, ул. Старая, 3		0101000020E61000000A1346B3B2CB5240356090F469534C40
67066	5	53	353	25464	28690	\N	55.965147999999999	с. Камышино Курское, ул.Зеленая, 1б		0101000020E6100000DFFE5C3464B6524060E63BF889FB4B40
67089	5	53	353	26512	9725	\N	56.492152114554699	д. Инцисс, ул. Молодежная, 8 а	Россия, Омская область, Муромцевский район, поселок Инцисс	0101000020E610000094A3005130B752409B5434D6FE3E4C40
67093	5	53	353	26716	29600	\N	56.567053000000001	д. Игоревка, ул. Песчаная, 28		0101000020E610000016DD7A4D0FC65240A20C553195484C40
67073	5	53	353	48205	29997	\N	56.014795999999997	д. Захаровка, д. Центральная, 21		0101000020E6100000C899266C3FBE5240490ED8D5E4014C40
67077	5	53	353	26000	29869	\N	56.292133	Омская область, Муромцевский  муниципальный район,д. Дурново ул. Центральная 6, Дом культуры		0101000020E6100000C39B35785FDA52408B8A389D64254C40
67060	5	53	353	47954	29994	\N	56.303970999999997	с. Гурово, ул. Центральная, 3		0101000020E610000028D6A9F23DC9524059F78F85E8264C40
67084	5	53	353	26315	29241	\N	56.440711999999998	д. Гузенево, ул. Центральная, 13		0101000020E61000008FAB915D69055340357A354069384C40
67070	5	53	353	25678	29449	\N	56.140725000000003	д. Большеникольск, ул. Центральная, 22		0101000020E6100000C1E270E657C05240645DDC4603124C40
67082	5	53	353	1780	29452	\N	56.409793000000001	Омская область, Муромцевский  муниципальный район,д. Большекрасноярка ул. Центральная 54, сельский клуб		0101000020E61000005DFC6D4F90FB52409B90D61874344C40
67055	5	53	353	24985	29722	\N	56.41404	с. Бергамак, ул. Центральная, 20		0101000020E61000008BDEA9807BC35240309E4143FF344C40
67023	5	53	1708	61540	79363	\N	54.794488999999999	д.Ясная Поляна, Центральная, 12	Россия, Омская область, Москаленский район, поселок Ясная Поляна	0101000020E610000016DD7A4D0FEC51401004C8D0B1654B40
48971	5	53	1708	49335	29882	\N	54.912810999999998	с.Элита, Ленина, 2		0101000020E61000006F9BA9108F075240EB36A8FDD6744B40
67036	5	53	1708	24073	28676	\N	55.005557000000003	д.Шефер, Центральная, 13		0101000020E6100000F86EF3C649015240C7A17E17B6804B40
67021	5	53	1708	47223	29682	\N	54.816566000000002	"с.Шевченко, Центральная, 40 ""б"""		0101000020E6100000C460FE0A99F251404583143C85684B40
67042	5	53	1708	53014	\N	\N	54.732657000000003	а.Тумба, 8	Россия, Омская область, Москаленский район, поселок Тумба	0101000020E61000001C295B24EDEE5140BE175FB4C75D4B40
67048	5	53	1708	24677	28670	\N	55.094627000000003	с.Тумановка, Центральная, 36		0101000020E61000002DCF83BBB3FC5140C828CFBC1C8C4B40
67039	5	53	1708	47575	29827	\N	54.715811000000002	д.Татьяновка, Школьная, 13		0101000020E6100000C9E369F981075240FC8EE1B19F5B4B40
49494	5	53	1708	46229	29483	\N	54.839773999999998	"д.Степок, Западная, 2""а"""		0101000020E6100000397B67B455015240FB03E5B67D6B4B40
67033	5	53	1708	47464	29420	\N	55.028961000000002	д.Спартак, Центральная, 19		0101000020E61000001D1F2DCE180E524003EE79FEB4834B40
67038	5	53	1708	47560	29332	\N	54.615616000000003	д.Селивановка, Школьная, 1		0101000020E61000009146054EB60052407A724D81CC4E4B40
67051	5	53	1708	24782	29688	\N	54.989466	Омская область, Москаленский  муниципальный район,д. Северное, ул. Центральная,21, здание Дома культуры		0101000020E61000005BEB8B84B6075240814067D2A67E4B40
67809	5	53	1708	24782	29888	\N	54.990245965313797	д. Северное, ул. Гагарина, 28	Россия, Омская область, Москаленский район, поселок Северное	0101000020E61000002FF834272F085240567F8461C07E4B40
67028	5	53	1708	23683	29701	\N	54.908313999999997	"д.Розенталь, Центральная, 40""в"""		0101000020E6100000CD3D247CEFFC5140DD3F16A243744B40
67045	5	53	1708	24496	29583	\N	54.865363000000002	д.Родная Долина, 40 лет Победы, 8		0101000020E61000000E881057CEEF51409015FC36C46E4B40
67052	5	53	1708	47809	29438	\N	54.945976000000002	п.Помурино, Центральная, 23		0101000020E61000003D433866D90752408466D7BD15794B40
67037	5	53	1708	24088	29144	\N	54.665281	с.Новоцарицыно, Центральная, 62		0101000020E610000089D1730B5DFC514039D384ED27554B40
67046	5	53	1708	53030	29685	\N	54.858207	д.Новоалександровка, Центральная, 32		0101000020E6100000B8ACC26680EB514061191BBAD96D4B40
67012	5	53	1708	22852	\N	\N	54.940716999999999	р.п.Москаленки, Ленина, 12	Россия, Омская область, Москаленский район, поселок Москаленки	0101000020E6100000776A2E3718FB514047E5266A69784B40
67013	5	53	1708	22852	29257	\N	54.940716999999999	р.п.Москаленки, Пролетарская, 12		0101000020E6100000776A2E3718FB514047E5266A69784B40
67010	5	53	1708	22852	29671	\N	54.940716999999999	р.п.Москаленки, Пионерская, 2		0101000020E6100000776A2E3718FB514047E5266A69784B40
67016	5	53	1708	22852	29552	\N	54.940716999999999	р.п.Москаленки, Механизаторов, 1		0101000020E6100000776A2E3718FB514047E5266A69784B40
67015	5	53	1708	22852	28691	\N	54.940716999999999	р.п. Москаленки, Комсомольская, 137		0101000020E6100000776A2E3718FB514047E5266A69784B40
67011	5	53	1708	22852	28691	\N	54.940716999999999	р.п. Москаленки, Комсомольская, 1		0101000020E6100000776A2E3718FB514047E5266A69784B40
67014	5	53	1708	22852	29958	\N	54.940716999999999	р.п. Москаленки, ул. 1 Северная, 65		0101000020E6100000776A2E3718FB514047E5266A69784B40
67035	5	53	1708	47504	29611	\N	55.05959	д.Мироновка, Литау, 32		0101000020E6100000B8C9A8328C035240969526A5A0874B40
67047	5	53	1708	24605	\N	\N	54.865890999999998	д.Миролюбовка, Центральная, 37	Россия, Омская область, Москаленский район, поселок Миролюбовка	0101000020E61000007172BF4351E951404B732B84D56E4B40
67030	5	53	1708	47404	29689	\N	55.116258000000002	п.Майский, Мира, 1		0101000020E610000013F06B2409F15140FEF2C98AE18E4B40
67019	5	53	1708	47170	29291	\N	54.871119	д.Красный Флаг, Молодежная, 14		0101000020E61000009692E52494FB51404DF6CFD3806F4B40
67049	5	53	1708	47749	29966	\N	55.091313999999997	с.Красное Знамя, Школьная, 2		0101000020E6100000C03C64CA870352405ED5592DB08B4B40
67026	5	53	1708	47310	29967	\N	54.919677999999998	д.Корнеевка, Центральная, 11		0101000020E6100000516859F78FF15140E36C3A02B8754B40
47967	5	53	1708	26062	29690	\N	54.928649999999998	д.Клаус, Центральная, 54		0101000020E61000004CAAB69BE0FC514017B7D100DE764B40
67041	5	53	1708	60854	76472	\N	54.713346180494902	а.Кзыл-Агшаш, Школьная, 12	Россия, Омская область, Москаленский район, поселок Кзыл-Агаш	0101000020E6100000D57B2AA73DF65140C05DF6EB4E5B4B40
67022	5	53	1708	33161	74044	\N	54.808076	д.Инсарка, Центральная, 20	Россия, Омская область, Москаленский район, поселок Инсарка	0101000020E61000006A4FC939B1F651405C57CC086F674B40
67034	5	53	1708	47488	29271	\N	55.049729999999997	с.Ильичевка, Школьна, 2		0101000020E6100000CE3461FBC9015240A6D0798D5D864B40
67020	5	53	1708	23315	30078	\N	54.799515999999997	а.Илеуш, Акжигита, 11		0101000020E610000037E15E99B7FE51407A50508A56664B40
67032	5	53	1708	53088	30011	\N	55.078347119765702	"д.Ивановка, Школьная, 47""а"""	Россия, Омская область, Москаленский район, поселок Ивановка	0101000020E61000001BD5E940D60A5240AF5E4546078A4B40
48937	5	53	1708	48826	29232	\N	54.967269000000002	с.Звездино, Школьная, 2		0101000020E6100000DEACC1FBAAEA5140A2B77878CF7B4B40
67040	5	53	1708	60167	73949	\N	54.73601	а.Жанааул, Центральная, 21	Россия, Омская область, Москаленский район, поселок Жанааул	0101000020E6100000AE669DF17DFD5140B5C35F93355E4B40
67025	5	53	1708	61518	79283	\N	54.918551000000001	с.Екатериновка, Центральная, 10	Россия, Омская область, Москаленский район, поселок Екатериновка	0101000020E610000000529B38B9F45140A35A441493754B40
67044	5	53	1708	47661	29585	\N	54.874248000000001	д.Доброе Поле, Центральная, 5		0101000020E61000007DCF488446F45140F54BC45BE76F4B40
67024	5	53	1708	23500	73729	\N	54.921475999999998	д. Гольбштадт, Центральная, 37	Россия, Омская область, Москаленский район, поселок Гольбштадт	0101000020E6100000A7CD380D51FA51404206F2ECF2754B40
67043	5	53	1708	47642	29470	\N	54.583274000000003	д.Гвоздевка, Школьная, 34		0101000020E61000005680EF366FF85140B64DF1B8A84A4B40
67017	5	53	1708	47137	\N	\N	54.965631000000002	д.Волчанка, здание сельского клуба		0101000020E6100000F31E679AB0FA51407C80EECB997B4B40
67029	5	53	1708	47390	29556	\N	54.967461	п.Веселый, Фрайгонгова, 7		0101000020E61000008D2441B802F35140E69315C3D57B4B40
67018	5	53	1708	52996	29413	\N	54.842978478676798	"с.Алексеевка, Центральная, 50""г"""	Россия, Омская область, Москаленский район, поселок Алексеевка	0101000020E61000003A799109F8FA5140AE9FFEB3E66B4B40
66998	5	53	1656	46734	29391	\N	54.848945000000001	д. Шереметьевка, пер. Школьный, 3		0101000020E6100000E338F06AB9235240268DD13AAA6C4B40
66912	5	53	1656	49350	29077	\N	54.874450000000003	д. Уютное, ул. Школьная, 11	Россия, Омская область, Марьяновский район, поселок Уютное	0101000020E61000004B75012F331B52405DFE43FAED6F4B40
66988	5	53	1656	21863	29656	\N	54.914669000000004	д. Усовка, ул. Зеленая, 17		0101000020E610000034F44F70B129524020D5B0DF13754B40
67009	5	53	1656	53013	29550	\N	55.033390320251002	с. Степное, ул. Молодежная, 24	Россия, Омская область, Марьяновский район, поселок Степное	0101000020E610000036E675C421355240B8019F1F46844B40
67002	5	53	1656	22508	29581	\N	54.939827000000001	д. Райнфельд, ул. Зеленая, 53		0101000020E61000000F0BB5A679165240EB724A404C784B40
66999	5	53	1656	22350	30086	\N	54.950588000000003	с. Пикетное, ул. 1-я Советская, 4А		0101000020E6100000B325AB22DC1352402BFC19DEAC794B40
67006	5	53	1656	61531	79339	\N	54.966065	д. Петровка, ул. Центральная, 32	Россия, Омская область, Марьяновский район, поселок Петровка	0101000020E6100000B5A50EF27A2D5240B6679604A87B4B40
66987	5	53	1656	21780	29443	\N	54.950370999999997	д. Охровка, ул. Южная, 7		0101000020E6100000643E20D0991D52408D08C6C1A5794B40
67003	5	53	1656	53022	79324	\N	55.027529999999999	с. Орловка, ул. 50 лет Октября, 1	Россия, Омская область, Марьяновский район, поселок Орловка	0101000020E6100000E1EEACDD761D524056D4601A86834B40
67005	5	53	1656	22613	29547	\N	54.980808000000003	с. Новая Шараповка, ул. Молодежная, 11		0101000020E61000008C82E0F1ED315240DDD3D51D8B7D4B40
66980	5	53	1656	21476	29104	\N	54.849007	д. Нейдорф, ул. Школьная, 2А		0101000020E61000004B5AF10D851252409C89E942AC6C4B40
66978	5	53	1656	21383	29369	\N	54.887636000000001	п. Москаленский, ул. Мира, 1Б		0101000020E6100000992A1895D41452404A60730E9E714B40
66995	5	53	1656	53003	29459	\N	54.806075122841499	д. Михайловка, ул. Пономаренко, 17	Россия, Омская область, Марьяновский район, поселок Михайловка	0101000020E610000016BEBED6A52D5240C58F31772D674B40
66985	5	53	1656	21671	29929	\N	54.922043000000002	п. Марьяновский, ул. Школьная, 27А		0101000020E6100000E52B8194D8215240BC40498105764B40
66973	5	53	1656	21121	29515	\N	54.961340999999997	р.п. Марьяновка, ул. Южная, 17		0101000020E6100000651C23D923295240E7A6CD380D7B4B40
66977	5	53	1656	21121	29782	\N	54.961340999999997	р.п. Марьяновка, ул. Садовая, 1		0101000020E6100000651C23D923295240E7A6CD380D7B4B40
66975	5	53	1656	21121	29378	\N	54.961340999999997	р.п. Марьяновка, ул. Победы, 4А		0101000020E6100000651C23D923295240E7A6CD380D7B4B40
66974	5	53	1656	21121	29378	\N	54.961340999999997	р.п. Марьяновка, ул. Победы, 77		0101000020E6100000651C23D923295240E7A6CD380D7B4B40
66976	5	53	1656	21121	30058	\N	54.961340999999997	р.п. Марьяновка, ул. Ленина, 12		0101000020E6100000651C23D923295240E7A6CD380D7B4B40
67008	5	53	1656	22774	28661	\N	55.053330000000003	д. Малая Степнинка, ул. Центральная, 19		0101000020E6100000A988D349B62C5240A6F27684D3864B40
66982	5	53	1656	21567	30068	\N	54.844698999999999	д. Лесногорский, ул. Школьная, 5		0101000020E61000007CF1457BBC0B524061FBC9181F6C4B40
66989	5	53	1656	21875	29112	\N	54.945262	д. Конезаводский, ул. Октябрьская, 35		0101000020E6100000A226FA7C9436524066136058FE784B40
66991	5	53	1656	46607	29532	\N	54.854956999999999	аул Кара-Терек, ул. Школьная, 7		0101000020E61000008E90813CBB3552403E3E213B6F6D4B40
67001	5	53	1656	61528	79313	\N	54.991554999999998	д. Чапаево, ул. Центральная, 4	Россия, Омская область, Марьяновский район, поселок Имени Чапаева	0101000020E6100000F838D384ED135240B7973446EB7E4B40
66996	5	53	1656	46702	\N	\N	54.773642000000002	д. Зеленая Долина, ул. Школьная, 15/2	Россия, Омская область, Марьяновский район, поселок Зеленая Долина	0101000020E6100000897C9752972D5240F16778B306634B40
67000	5	53	1656	46785	29796	\N	54.984073000000002	с. Заря Свободы, ул. Ленина, 59		0101000020E61000008E03AF963B18524035F0A31AF67D4B40
66984	5	53	1656	60819	76414	\N	54.764372204959699	аул Домбай, ул. Центральная, 14А	Россия, Омская область, Марьяновский район, поселок Домбай	0101000020E610000076FF58880E0A524033FD12F1D6614B40
66990	5	53	1656	46587	30073	\N	54.919978	д. Голенки, ул. Школьная, 14		0101000020E610000064CC5D4BC83652400E85CFD6C1754B40
66992	5	53	1656	46641	29533	\N	54.910415	д. Васильевка, ул. Школьная, 28		0101000020E6100000C9E88024EC2F5240D8648D7A88744B40
66997	5	53	1656	22291	29791	\N	54.795524999999998	д. Большая Роща, ул. Школьная, 2		0101000020E61000002C9ACE4E06235240401361C3D3654B40
66994	5	53	1656	53081	29946	\N	54.802894999999999	с. Боголюбовка, пер. Центральный, 10	Россия, Омская область, Марьяновский район, поселок Боголюбовка	0101000020E61000002997C62FBC2952409B8F6B43C5664B40
67004	5	53	1656	61530	79335	\N	55.047150000000002	д. Березовка, ул. Центральная, 36	Россия, Омская область, Марьяновский район, поселок Березовка	0101000020E610000077A1B94E23285240D200DE0209864B40
66993	5	53	1656	52973	29127	\N	54.9465652628597	д. Алексеевка, ул. Новая, 24	Россия, Омская область, Марьяновский район, поселок Алексеевка	0101000020E6100000C5AC1743392D5240E544BB0A29794B40
66972	5	53	1507	21116	29644	\N	55.054614000000001	Омская область, Любинский муниципальный район, посёлок Южный, Пикетинская, 19/2		0101000020E61000009B3C65355D145240AEF36F97FD864B40
66908	5	53	1507	17709	29054	\N	55.431820999999999	Омская область, Любинский муниципальный район, посёлок Щучье, Центральная, 35		0101000020E61000002E55698B6B085240EE5C18E945B74B40
66955	5	53	1507	20166	29767	\N	55.191181	Омская область, Любинский муниципальный район, деревня Шулаевка, Центральная, 18/2		0101000020E61000004C8DD0CFD40D5240EC4E779E78984B40
66969	5	53	1507	20957	29218	\N	55.206108	Омская область, Любинский муниципальный район, деревня Шандровка, Пролетарская, 27		0101000020E610000068041BD7BF1C5240D4B837BF619A4B40
66970	5	53	1507	21016	29513	\N	55.154074000000001	Омская область, Любинский муниципальный район, посёлок Чулково, Колхозная, 50		0101000020E6100000734A404CC2255240FB9463B2B8934B40
66967	5	53	1507	20843	29918	\N	55.126313000000003	Омская область, Любинский муниципальный район, посёлок Центрально-Любинский, Школьная, 4		0101000020E6100000369204E10A205240A3073E062B904B40
66930	5	53	1507	18821	29980	\N	55.099221999999997	Омская область, Любинский муниципальный район, деревня 16 Партсъезд, Центральная, 17		0101000020E6100000BE688F17D23752409885764EB38C4B40
66924	5	53	1507	18525	29156	\N	55.216740999999999	Омская область, Любинский муниципальный район, деревня Филатовка, Школьная, 29		0101000020E6100000F9A067B3EA295240E659492BBE9B4B40
66616	5	53	345	3442	29242	\N	55.361702000000001	с. Астыровка, 30 лет Победы, 40		0101000020E61000007BDCB75A279C5240EB724A404CAE4B40
66929	5	53	1507	18740	30024	\N	55.080519000000002	Омская область, Любинский муниципальный район, деревня Фёдоровка, Школьная, 21		0101000020E6100000B5C189E8D73B524073DA53724E8A4B40
66971	5	53	1507	21026	29642	\N	55.071510000000004	Омская область, Любинский муниципальный район, посёлок Урожайный, Центральная, 45		0101000020E61000002FDFFAB0DE12524022AB5B3D27894B40
66963	5	53	1507	20637	29353	\N	55.374139999999997	Омская область, Любинский муниципальный район, село Увало-Ядрино, Советская, 44		0101000020E61000004ED026874F3A52400E10CCD1E3AF4B40
66915	5	53	1507	18053	29186	\N	55.525368999999998	Омская область, Любинский муниципальный район, деревня Тарлык, Вторая, 21		0101000020E6100000AED51EF64228524086AA984A3FC34B40
66961	5	53	1507	20491	29498	\N	55.456744999999998	Омская область, Любинский муниципальный район, село Тавричанка, Молодёжная, 4		0101000020E61000002A1BD6541631524046CEC29E76BA4B40
66919	5	53	1507	18208	29742	\N	55.373888999999998	Омская область, Любинский муниципальный район, деревня Субботинка, Молодёжная, 3/1		0101000020E6100000E603029D491A5240C5AA4198DBAF4B40
66965	5	53	1507	20736	\N	\N	55.424286000000002	"Омская область, Любинский муниципальный район, деревня Степановка, Здание конторы СПК ""Сибирь"""		0101000020E6100000E4A1EF6E653552404913EF004FB64B40
66840	5	53	1507	20736	\N	\N	55.424286000000002	Степановка, Здание сельского клуба	Россия, Омская область, Любинский район, поселок Степановка	0101000020E6100000E4A1EF6E653552404913EF004FB64B40
66950	5	53	1507	19880	29836	\N	55.263387999999999	Омская область, Любинский муниципальный район, деревня Смоляновка, Школьная, 2		0101000020E610000055A4C2D8422252405514AFB2B6A14B40
66959	5	53	1507	20408	29631	\N	55.193452999999998	Омская область, Любинский муниципальный район, посёлок Северо-Любинский, Никифорова, 20		0101000020E610000053927538BA32524013286211C3984B40
66958	5	53	1507	20330	30036	\N	55.104835999999999	Омская область, Любинский муниципальный район, деревня Ровная Поляна, Южная, 37		0101000020E6100000F67B629D2A215240C3B81B446B8D4B40
66956	5	53	1507	20198	29508	\N	55.098757999999997	Омская область, Любинский муниципальный район, село Протопоповка, Зеленая, 7		0101000020E610000071917BBABA265240F31B261AA48C4B40
66952	5	53	1507	19973	29894	\N	55.212349000000003	Омская область, Любинский муниципальный район, посёлок Пролетарский, Октябрьская, 6		0101000020E6100000151C5E10911652404E2B85402E9B4B40
67031	5	53	1507	19973	29841	\N	55.212349000000003	п.Пролетарский, Клубная, 11		0101000020E6100000151C5E10911652404E2B85402E9B4B40
66922	5	53	1507	18388	29473	\N	55.217157	Омская область, Любинский муниципальный район, деревня Помогаевка, Школьная, 37		0101000020E610000014EB54F99E2252407A8CF2CCCB9B4B40
66946	5	53	1507	19665	29206	\N	55.207526000000001	"Омская область, Любинский муниципальный район, посёлок Политотдел, Ленина, 32 ""а"""		0101000020E6100000BDE5EAC7264A5240EC884336909A4B40
66949	5	53	1507	19781	29285	\N	55.261459000000002	Омская область, Любинский муниципальный район, село Новокиевка, Куйбышева, 47		0101000020E6100000BCE6559DD51C5240581F0F7D77A14B40
66947	5	53	1507	19684	29086	\N	55.350110000000001	Омская область, Любинский муниципальный район, село Новоархангелка, Советская, 40		0101000020E6100000B62C5F97E141524054008C67D0AC4B40
66918	5	53	1507	18199	29059	\N	55.346803999999999	Омская область, Любинский муниципальный район, деревня Мокшино, Центральная, 18		0101000020E6100000FEB4519D0E1452409D0FCF1264AC4B40
66927	5	53	1507	18663	29803	\N	55.265819999999998	"Омская область, Любинский муниципальный район, деревня Матюшино, Центральная, 40 ""А"""		0101000020E6100000FD84B35BCB315240B54FC76306A24B40
66937	5	53	1507	53009	30126	\N	55.155408584820798	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Ремесленная, 65	Россия, Омская область, Любинский район, поселок Любинский	0101000020E6100000172CD505BC2C524085402E71E4934B40
66934	5	53	1507	53009	78980	\N	55.153835999999998	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Почтовая, 8	Россия, Омская область, Любинский район, поселок Любинский	0101000020E6100000A2EF6E65892C52404679E6E5B0934B40
66936	5	53	1507	53009	79040	\N	55.153835999999998	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Победы, 12	Россия, Омская область, Любинский район, поселок Любинский	0101000020E6100000A2EF6E65892C52404679E6E5B0934B40
66941	5	53	1507	53009	79123	\N	55.153835999999998	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Октябрьская, 180	Россия, Омская область, Любинский район, поселок Любинский	0101000020E6100000A2EF6E65892C52404679E6E5B0934B40
66935	5	53	1507	53009	29829	\N	55.152117776059903	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Мопра, 99	Россия, Омская область, Любинский район, поселок Любинский	0101000020E61000004E999B6F442D52400491459A78934B40
66939	5	53	1507	53009	79085	\N	55.153835999999998	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Матросова, 5	Россия, Омская область, Любинский район, поселок Любинский	0101000020E6100000A2EF6E65892C52404679E6E5B0934B40
66938	5	53	1507	53009	29496	\N	55.154229000000001	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Максима Горького, 102	Россия, Омская область, Любинский район, поселок Любинский	0101000020E61000008C683BA6EE2C5240228C9FC6BD934B40
66940	5	53	1507	53009	79113	\N	55.153835999999998	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, Ленина, 12	Россия, Омская область, Любинский район, поселок Любинский	0101000020E6100000A2EF6E65892C52404679E6E5B0934B40
66942	5	53	1507	53009	79143	\N	55.153835999999998	Омская область, Любинский муниципальный район, рабочий посёлок Любинский, 70 лет Октября, 1	Россия, Омская область, Любинский район, поселок Любинский	0101000020E6100000A2EF6E65892C52404679E6E5B0934B40
66943	5	53	1507	19500	29702	\N	55.201858999999999	Омская область, Любинский муниципальный район, село Любино-Малороссы, Старожильская, 46		0101000020E61000002E043928614052409EB30584D6994B40
66944	5	53	1507	19500	29623	\N	55.201858999999999	"Омская область, Любинский муниципальный район, село Любино-Малороссы, Мира, 1 ""в"""		0101000020E61000002E043928614052409EB30584D6994B40
66968	5	53	1507	20875	29510	\N	55.116968999999997	Омская область, Любинский муниципальный район, посёлок Луговой, Пролетарская, 5		0101000020E6100000AF06280D35195240AAD216D7F88E4B40
66931	5	53	1507	53123	78914	\N	55.221915000000003	Омская область, Любинский муниципальный район, рабочий посёлок Красный Яр, Октябрьская, 31	Россия, Омская область, Любинский район, поселок Красный Яр	0101000020E610000022A98592C93B5240F5BEF1B5679C4B40
66933	5	53	1507	53123	78933	\N	55.221915000000003	Омская область, Любинский муниципальный район, рабочий посёлок Красный Яр, Первомайская, 12		0101000020E610000022A98592C93B5240F5BEF1B5679C4B40
66932	5	53	1507	53123	30143	\N	55.237466358592201	Омская область, Любинский муниципальный район, рабочий посёлок Красный Яр, Октябрьская, 16	Россия, Омская область, Любинский район, поселок Красный Яр	0101000020E6100000B01D8CD8273B5240BAF42F49659E4B40
66957	5	53	1507	20275	30037	\N	55.088748000000002	Омская область, Любинский муниципальный район, деревня Кочки, Солнечная, 47		0101000020E61000000BB3D0CE692B5240EFCA2E185C8B4B40
66945	5	53	1507	19581	29338	\N	55.219268	Омская область, Любинский муниципальный район, село Китайлы, Западная, 9		0101000020E610000095D5743DD144524098874CF9109C4B40
66926	5	53	1507	18599	29188	\N	55.274456999999998	Омская область, Любинский муниципальный район, деревня Квасовка, Новая, 2 В		0101000020E6100000EE7BD45FAF2C524042942F6821A34B40
66917	5	53	1507	18132	30016	\N	55.424183999999997	Омская область, Любинский муниципальный район, деревня Капустино, Центральная, 16		0101000020E6100000910DA48B4D18524044BE4BA94BB64B40
66951	5	53	1507	19890	29284	\N	55.311543999999998	Омская область, Любинский муниципальный район, деревня Канаковка, Труда, 33		0101000020E61000007024D06053215240ECA17DACE0A74B40
66928	5	53	1507	18727	29191	\N	55.116000999999997	Омская область, Любинский муниципальный район, посёлок Камышловский, Зелёная, 2		0101000020E61000007044F7AC6B3C5240D2A6EA1ED98E4B40
66964	5	53	1507	20667	\N	\N	55.377510999999998	Омская область, Любинский муниципальный район, деревня Калиновка, Здание досугового объекта, 41		0101000020E61000009E280989B4315240AC70CB4752B04B40
66925	5	53	1507	18571	29066	\N	55.268779000000002	Омская область, Любинский муниципальный район, село Казанка, Школьная, 2		0101000020E6100000B134F0A31A305240016DAB5967A24B40
66920	5	53	1507	18294	29471	\N	55.234302	Омская область, Любинский муниципальный район, село Замелетёновка, Ленина, 41		0101000020E610000099BC0166BE29524096B1A19BFD9D4B40
66916	5	53	1507	18113	29741	\N	55.376938000000003	Омская область, Любинский муниципальный район, посёлок Весёлая Поляна, Октябрьская, 3		0101000020E61000009D4B7155D9135240514F1F813FB04B40
66962	5	53	1507	20577	29772	\N	55.420949	Омская область, Любинский муниципальный район, деревня Быструха, Центральная, 36		0101000020E6100000B476DB85E6325240572426A8E1B54B40
66954	5	53	1507	20111	29344	\N	55.278790000000001	Омская область, Любинский муниципальный район, деревня Борятино, Борятинская, 10		0101000020E610000063D34A21900C5240D6390664AFA34B40
66911	5	53	1507	17849	29155	\N	55.397213999999998	Омская область, Любинский муниципальный район, д. Большемогильное, Школьная, 35		0101000020E610000035B742588D275240B5C189E8D7B24B40
66914	5	53	1507	17992	29710	\N	55.430200999999997	Омская область, Любинский муниципальный район, п. Большаковка, Центральная, 27		0101000020E6100000299831056B2252406EDA8CD310B74B40
66910	5	53	1507	17786	29467	\N	55.310053000000003	Омская область, Любинский муниципальный район, с. Боголюбовка, Школьная, 28		0101000020E6100000E29178793A2A52406B8313D1AFA74B40
66921	5	53	1507	18347	30017	\N	55.236514	Омская область, Любинский муниципальный район, деревня Беляевка, Центральная, 42		0101000020E6100000CCED5EEE932D5240E8853B17469E4B40
66960	5	53	1507	20480	29769	\N	55.227837999999998	Омская область, Любинский муниципальный район, деревня Барсуковка, Труда, 9		0101000020E610000035B401D8802F52409D64ABCB299D4B40
66923	5	53	1507	18456	30050	\N	55.225727999999997	Омская область, Любинский муниципальный район, деревня Бабайловка, Школьная, 2		0101000020E610000067B45549642752404FE5B4A7E49C4B40
66913	5	53	1507	17955	29868	\N	55.264814000000001	Омская область, Любинский муниципальный район, д. Астрахановка, Центральная, 26		0101000020E6100000BAA0BE654E265240F0C2D66CE5A14B40
66907	5	53	1507	17630	29181	\N	55.349901000000003	Омская область, Любинский муниципальный район, село Алексеевка, переулок Школьный, 2		0101000020E6100000FD851E317A0452403AEB538EC9AC4B40
67087	5	53	1507	17630	29304	\N	55.349901000000003	д. Алексеевка, ул. Центральная, 7а		0101000020E6100000FD851E317A0452403AEB538EC9AC4B40
66614	5	53	1507	17630	30076	\N	55.349901000000003	д. Алексеевка, Зеленая, 7		0101000020E6100000FD851E317A0452403AEB538EC9AC4B40
66948	5	53	1507	19777	29430	\N	55.320447000000001	Омская область, Любинский муниципальный район, деревня Авлы, Центральная, 39		0101000020E6100000A2427573F13F5240F88C446804A94B40
67653	5	53	1089	53004	29461	\N	56.197228000000003	п. им. М.Горького, 1 Новая, 1	Россия, Омская область, Крутинский район, поселок им. Максима Горького	0101000020E6100000CBDAA6785CEE514081ED60C43E194C40
66883	5	53	1089	16440	29698	\N	56.043315999999997	с. Яман, Центральная, 25А		0101000020E6100000A27BD6355AD951405FB2F1608B054C40
66891	5	53	1089	49070	29189	\N	56.183914000000001	д. Ширяево, Центральная, 1		0101000020E6100000A9BEF38B12CE514066A3737E8A174C40
66897	5	53	1089	49144	29595	\N	56.255206999999999	с. Шипуново, Центральная, 16		0101000020E61000001ADD41EC4CE25140EA5A7B9FAA204C40
66879	5	53	1089	48862	29591	\N	55.960120000000003	д. Чумановка, Зелёная, 12		0101000020E6100000F67CCD72D9E85140261E5036E5FA4B40
66878	5	53	1089	16202	30046	\N	55.903837000000003	д. Чикишево, Лермонтова, 1		0101000020E6100000F20A444FCAE5514017F549EEB0F34B40
66895	5	53	1089	17049	29303	\N	56.451008676379203	с. Толоконцево (д. Троицк), Зелёная, 5	Россия, Омская область, Крутинский район, поселок Толоконцево	0101000020E6100000ED629AE95ECD5140D099B4A9BA394C40
66889	5	53	1089	16766	29183	\N	56.288496000000002	д. Стахановка, Стахановская, 17		0101000020E610000055682096CDC151406F83DA6FED244C40
66899	5	53	1089	17216	29598	\N	56.245285000000003	д. Сингуль, Светлая, 11		0101000020E61000005BB6D61709EA51408599B67F651F4C40
66875	5	53	1089	48781	29147	\N	55.827190999999999	д. Самаровка, Школьная, 6		0101000020E61000004F779E78CEDC5140D4450A65E1E94B40
66906	5	53	1089	17618	29180	\N	56.047158261009599	д. Салтаим (д. Берёзово, д. Калугино), Центральная, 27	Россия, Омская область, Крутинский район, поселок Салтаим	0101000020E6100000E413B2F336F2514055DFF94509064C40
66880	5	53	1089	48883	29171	\N	55.997028999999998	с. Рыжково, Зелёная, 8		0101000020E6100000BC067DE9EDBF5140F01472A59EFF4B40
66892	5	53	1089	52981	29237	\N	56.351287342390201	с. Паново (д. Козулино), Зелёная, 4	Россия, Омская область, Крутинский район, поселок Паново	0101000020E61000005B608F8994BD51404641F0F8F62C4C40
66890	5	53	1089	49047	29605	\N	56.240197999999999	д. Ольгино, Новая, 1		0101000020E6100000F08B4B55DAC251404548DDCEBE1E4C40
66876	5	53	1089	16085	28851	\N	55.860655999999999	с. Оглухино, Советская, 45		0101000020E610000018EDF1423AF25140978DCEF929EE4B40
66638	5	53	1089	48669	29261	\N	56.014915999999999	с. Новопокровка, Центральная, 3		0101000020E610000033C170AE61CF5140F4177AC4E8014C40
66900	5	53	1089	53033	29732	\N	56.264173673371701	с. Новокарасук (д. Старичье), 50 лет Октября, 14	Россия, Омская область, Крутинский район, поселок Новокарасук	0101000020E61000000A2FC1A90FF451400C3A2174D0214C40
66874	5	53	1089	15999	\N	\N	55.938586999999998	п. Новгородцево, Школа, 1		0101000020E6100000F52B9D0FCFE75140B2B96A9E23F84B40
67773	5	53	1089	27705	28664	\N	56.494002999999999	Омская область, Тюкалинский муниципальный район, Никольское сельское поселение, с. Никольск, Молодежная, 14		0101000020E61000001C3F541A31CF51401D90847D3B3F4C40
66871	5	53	1089	9605	29296	\N	56.004337999999997	р.п. Крутинка, пер. Больничный, 21		0101000020E610000093E34EE960E05140A510C8258E004C40
66870	5	53	1089	9605	29747	\N	56.004337999999997	р.п. Крутинка, Ленина, 69		0101000020E610000093E34EE960E05140A510C8258E004C40
66869	5	53	1089	9605	29747	\N	56.004337999999997	р.п. Крутинка, Ленина, 16		0101000020E610000093E34EE960E05140A510C8258E004C40
66872	5	53	1089	9605	29854	\N	56.004337999999997	р.п. Крутинка, Красный Путь, 196		0101000020E610000093E34EE960E05140A510C8258E004C40
14680	5	53	1089	9605	29972	\N	56.004337999999997	р.п. Крутинка, Заречная, 10		0101000020E610000093E34EE960E05140A510C8258E004C40
14679	5	53	1089	9605	29068	\N	56.004337999999997	р.п. Крутинка, Вишневского, 43		0101000020E610000093E34EE960E05140A510C8258E004C40
66893	5	53	1089	49102	29672	\N	56.386862000000001	д. Красный Яр, Зелёная, 24А		0101000020E610000017BA1281EAC551405708ABB184314C40
66885	5	53	1089	60830	76438	\N	56.091925716095503	д. Ик (д. Красный Пахарь), Набережная, 18	Россия, Омская область, Крутинский район, поселок Красный Пахарь	0101000020E61000004F5C8E5720E0514078D32D3BC40B4C40
66902	5	53	1089	17381	30006	\N	56.303111999999999	д. Коломенка, Школьная, 7		0101000020E61000005ABC581822F551403883BF5FCC264C40
66881	5	53	1089	16347	29990	\N	56.005122999999998	д. Колодцы, Викуловская, 16А		0101000020E6100000D7A3703D0ABC51408CBAD6DEA7004C40
66904	5	53	1089	17505	29862	\N	56.097036000000003	с. Китерма (д. Кабанье), Ленина, 23		0101000020E610000047ACC5A700E851407044F7AC6B0C4C40
66894	5	53	1089	40470	30025	\N	56.368229999999997	д. Камчатка, Центральная, 13		0101000020E6100000B61490F63FD25140FAB31F29222F4C40
66873	5	53	1089	15921	28843	\N	56.051676999999998	д. Калачики, Зелёная, 2		0101000020E6100000423EE8D9ACE851404A7A185A9D064C40
66886	5	53	1089	48980	29863	\N	56.280861000000002	с. Зимино, Центральная, 3		0101000020E610000015FF774485B7514066DCD440F3234C40
66903	5	53	1089	17440	76435	\N	56.391569855720697	д. Заозёрная (д. Чагино), Северная, 5	Россия, Омская область, Крутинский район, поселок Заозёрная	0101000020E610000029594E42E9F75140200C3CF71E324C40
66887	5	53	1089	16684	29921	\N	56.267372000000002	д. Гуляй-Поле, Школьная, 4		0101000020E6100000EF02250516BC5140DDEEE53E39224C40
66898	5	53	1089	52775	29050	\N	56.273715000000003	д. Горькое (д. Челдак), Новая, 15		0101000020E6100000A9DDAF027CE551405BB6D61709234C40
66882	5	53	1089	52745	29450	\N	56.007075999999998	д. Верхний Яман (д. Орлово), Верх-Яманская, 15		0101000020E61000008081204086CB5140124BCADDE7004C40
14678	5	53	1075	49006	\N	\N	55.148173999999997	Юрьево, Здание школы		0101000020E61000001D56B8E5238D52400A0F9A5DF7924B40
66849	5	53	1075	48346	\N	\N	54.802053999999998	Фоминовка 2-я, Здание сельского клуба		0101000020E6100000D908C4EBFA90524020D099B4A9664B40
66854	5	53	1075	48417	\N	\N	54.832002000000003	Фоминовка 1-я, Здание сельского клуба		0101000020E61000000B613596B0905240721AA20A7F6A4B40
14677	5	53	1075	53096	\N	\N	54.975110067175798	Сыропятское ж/д ст, Здание ФАП	Россия, Омская область, Кормиловский район, обгонный пункт Сыропятское	0101000020E6100000A9177C9A9377524054008C67D07C4B40
66858	5	53	1075	15162	\N	\N	55.047009844417602	Сыропятская (левй берег), Здание ФАП	Россия, Омская область, Кормиловский район, поселок Сыропятское	0101000020E61000008A743FA720785240E04A766C04864B40
66857	5	53	1075	15162	\N	\N	55.047404	село Сыропятское, Здание дома культуры		0101000020E610000018080264E87752408CD9925511864B40
66864	5	53	1075	15518	\N	\N	54.929031999999999	Станкеевка, Здание сельского клуба		0101000020E6100000BD546CCCEB7C5240FF774485EA764B40
66856	5	53	1075	15136	\N	\N	54.716149000000001	Спайка, Здание сельского клуба		0101000020E610000048895DDBDB85524014083BC5AA5B4B40
66852	5	53	1075	48397	\N	\N	54.910400000000003	Салтыковка, Здание сельского клуба		0101000020E610000010069E7B0F845240A323B9FC87744B40
66868	5	53	1075	48658	\N	\N	55.106299	Рощинский, Здание сельского клуба		0101000020E61000006DACC43C2B8852407B4CA4349B8D4B40
66855	5	53	1075	15078	\N	\N	54.779021	Победитель, Здание школы		0101000020E61000001747E5266A845240D8F2CAF5B6634B40
66853	5	53	1075	48404	\N	\N	54.868197000000002	Новоселье, Здание школы		0101000020E61000009F56D11F9A8F52401FBE4C14216F4B40
66843	5	53	1075	48206	\N	\N	54.977325	Новая Деревня, Здание сельского клуба		0101000020E610000055850662D9825240174850FC187D4B40
66867	5	53	1075	48651	\N	\N	55.036256999999999	Никитино, Здание ФАП		0101000020E61000004B901150E185524023A0C211A4844B40
66863	5	53	1075	15470	\N	\N	54.924670999999996	Немировка, Здание дома культуры		0101000020E610000001A1F5F065785240A1478C9E5B764B40
66851	5	53	1075	40466	\N	\N	54.889862999999998	Некрасовка, Здание дома культуры		0101000020E6100000F0FCA204FD875240D175E107E7714B40
51601	5	53	1075	53007	29489	\N	54.765897240687401	с.Михайловка, Новая, 8	Россия, Омская область, Кормиловский район, поселок Михайловка	0101000020E6100000B1DEA815A6915240618DB3E908624B40
66844	5	53	1075	48239	\N	\N	55.023077999999998	Корниловка, Здание сельского клуба		0101000020E6100000AEB8382A377D5240E8A04B38F4824B40
66837	5	53	1075	13946	29538	\N	55.002996000000003	р.п.Кормиловка, Юбилейная, 26		0101000020E6100000C6E061DA378652406902452C62804B40
66831	5	53	1075	13946	29117	\N	55.002996000000003	р.п.Кормиловка, Энергетиков, 4		0101000020E6100000C6E061DA378652406902452C62804B40
66835	5	53	1075	13946	29152	\N	55.002996000000003	р.п.Кормиловка, Ленина, 112		0101000020E6100000C6E061DA378652406902452C62804B40
66833	5	53	1075	13946	29152	\N	55.002996000000003	р.п.Кормиловка, Ленина, 22		0101000020E6100000C6E061DA378652406902452C62804B40
66832	5	53	1075	13946	29152	\N	55.002996000000003	р.п.Кормиловка, Ленина, 37		0101000020E6100000C6E061DA378652406902452C62804B40
66836	5	53	1075	13946	29136	\N	55.002996000000003	р.п.Кормиловка, Кирова, 87		0101000020E6100000C6E061DA378652406902452C62804B40
66834	5	53	1075	13946	29260	\N	55.002996000000003	р.п.Кормиловка, Базарный переулок, 17		0101000020E6100000C6E061DA378652406902452C62804B40
66866	5	53	1075	48638	\N	\N	55.153416	Кольцово, Здание ФАП		0101000020E61000006B63EC84979152407157AF22A3934B40
66865	5	53	1075	48602	\N	\N	55.056507000000003	Игнатьево, Здание ФАП		0101000020E61000003126FDBD148D52405F7F129F3B874B40
66846	5	53	1075	48271	\N	\N	55.070242	Зотино, Здание сельского клуба		0101000020E610000081B053AC1A8F52401F679AB0FD884B40
14611	5	53	1075	47787	\N	\N	54.761597000000002	Ефимовка, Здание сельского клуба		0101000020E6100000AC376A85E9965240A9DDAF027C614B40
66845	5	53	1075	48268	\N	\N	55.076529999999998	Георгиевка, Здание дома культуры		0101000020E6100000B1A547533D935240D9942BBCCB894B40
14676	5	53	1075	48971	\N	\N	54.881172999999997	Веселый Привал, Здание школы		0101000020E6100000E38DCC237F985240218FE046CA704B40
66842	5	53	1075	48193	\N	\N	55.027056999999999	Борки, Здание школы		0101000020E6100000B98AC56F0A8252405E10919A76834B40
66861	5	53	1075	15317	\N	\N	55.094482999999997	Байкал, Здание ФАП		0101000020E610000089981249F47D52409483D904188C4B40
52859	5	53	1250	61158	77393	\N	56.091425999999998	а. Артакшил, ул. Ленина, 12	Россия, Омская область, Колосовский район	0101000020E6100000124A5F08395552408600E0D8B30B4C40
66829	5	53	1250	13849	29658	\N	56.621606999999997	д. Тоскино (сельский клуб), Центральная, 39		0101000020E61000008F352383DC6E52407AFB73D1904F4C40
66828	5	53	1250	13801	29553	\N	56.238227000000002	с. Таскатлы (сельский дом культуры), Центральная, 39		0101000020E6100000B7291E17D54952401903EB387E1E4C40
66827	5	53	1250	13720	30077	\N	56.350866000000003	с. Талбакуль (сельский дом культуры), Почтовая, 3		0101000020E6100000C0D02346CF505240A1A3552DE92C4C40
66826	5	53	1250	53080	29938	\N	56.368837999999997	с. Строкино (сельский дом культуры), К.Строкина, 1	Россия, Омская область, Колосовский район, поселок Строкино	0101000020E6100000C269C18BBE5A5240D2C26515362F4C40
66825	5	53	1250	53011	29543	\N	56.192713409714599	д. Сафоново (сельский клуб), Саргатская, 17-А	Россия, Омская область, Колосовский район, поселок Сафоново	0101000020E61000004F779E78CE6E5240CC41D0D1AA184C40
66824	5	53	1250	52982	29243	\N	56.3539150965114	д. Плотниково (ФАП), Рабочая, 9	Россия, Омская область, Колосовский район, поселок Плотниково	0101000020E610000003ECA353578252402C4833164D2D4C40
66823	5	53	1250	52589	29662	\N	56.324147000000004	д. Плахино (сельский клуб), Центральная, 26		0101000020E61000009148DBF8135752405B0C1EA67D294C40
66822	5	53	1250	53107	30111	\N	56.412761232565998	д. Новотроицк (сельский клуб), К. Остапова, 20	Россия, Омская область, Колосовский район, поселок Новотроицк	0101000020E6100000D28C45D3D95452403A083A5AD5344C40
66821	5	53	1250	13441	30079	\N	56.493904000000001	с. Новологиново (сельский дом культуры), Центральная, 46		0101000020E6100000572426A8E17152408AAE0B3F383F4C40
66819	5	53	1250	52998	29422	\N	56.219312000000002	д. Николаевка (детский сад), Николаевская, 53	Россия, Омская область, Колосовский район, поселок Николаевка	0101000020E6100000A0FA07910C45524068CF656A121C4C40
66726	5	53	1250	45841	\N	\N	56.259557999999998	д.Мясники	Россия, Омская область, Колосовский район, поселок Мясники	0101000020E6100000DAC70A7E1B85524024B5503239214C40
66816	5	53	1250	13241	29667	\N	56.089115999999997	д. Меркутлы (школа), Б.Зеленая, 1		0101000020E61000002BBD361B2B3E524071C63027680B4C40
66814	5	53	1250	13153	29795	\N	56.291614000000003	с. Ламаново (сельский дом культуры), Центральная, 30-Б		0101000020E61000005C7347FFCB7452402387889B53254C40
66813	5	53	1250	13097	29665	\N	56.202922000000001	с. Кутырлы (сельский дом культуры), Советская, 30		0101000020E610000028B85851833D5240C8D11C59F9194C40
66812	5	53	1250	13038	30026	\N	56.266764352961196	с. Крайчиково (сельский дом культуры), Ленина, 1	Россия, Омская область, Колосовский район, поселок Крайчиково	0101000020E610000049809A5AB654524005E09F5225224C40
66811	5	53	1250	13012	30101	\N	56.569590442385604	с. Корсино (сельский дом культуры), Центральная, 9		0101000020E6100000F583BA48A17D524077103B53E8484C40
14674	5	53	1250	52987	29417	\N	56.462352000000003	с. Колосовка (школа), Свердлова, 22	Россия, Омская область, Колосовский район, поселок Колосовка	0101000020E6100000CB83F41439675240BF9EAF592E3B4C40
66809	5	53	1250	52987	29575	\N	56.462352000000003	с. Колосовка (районный дом культуры), Ленина, 7	Россия, Омская область, Колосовский район, поселок Колосовка	0101000020E6100000CB83F41439675240BF9EAF592E3B4C40
66810	5	53	1250	52987	29327	\N	56.468623796392002	с. Колосовка (ПУ-55), Кирова, 58	Россия, Омская область, Колосовский район, поселок Колосовка	0101000020E6100000A5D7666325675240730F09DFFB3B4C40
66808	5	53	1250	12858	29109	\N	56.529981999999997	д. Коготово (сельский клуб), Коготовская, 51		0101000020E61000005794128255645240FDBB3E73D6434C40
66807	5	53	1250	52561	29297	\N	56.208840000000002	д. Кабурлы (школа-сад), Центральная, 29		0101000020E6100000B58B69A67B7C52405F0CE544BB1A4C40
66806	5	53	1250	60844	76457	\N	56.354002999999999	д. Зеленая (начальная школа), Хуторская, 4	Россия, Омская область, Колосовский район, поселок Зелёная (Ильинка)	0101000020E61000004ED1915CFE485240CBD765F84F2D4C40
66805	5	53	1250	53108	30112	\N	56.463078845241697	д. Дубрава (ФАП), Дубравинская, 30	Россия, Омская область, Колосовский район, поселок Дубрава (Николаевка)	0101000020E610000010EA2285B25C5240713B342C463B4C40
66804	5	53	1250	53097	30084	\N	56.141170385521697	д. Владимировка (школа), Обоянская, 27 А	Россия, Омская область, Колосовский район, поселок Владимировка	0101000020E6100000B08EE3874A6952409296CADB11124C40
66803	5	53	1250	52548	29535	\N	56.514108	с. Бражниково (сельский дом культуры), Луговая, 5		0101000020E6100000FB22A12DE7755240554E7B4ACE414C40
66802	5	53	1250	52976	29163	\N	56.530295933307301	д. Аникино (школа), Выселки, 4	Россия, Омская область, Колосовский район, поселок Аникино	0101000020E6100000560E2DB29D7952408D9944BDE0434C40
66801	5	53	1250	60833	76441	\N	56.215613309464999	д. Александровка (сельский клуб), 2-я Заимка, 5	Россия, Омская область, Колосовский район, поселок Александровка	0101000020E610000097E5EB32FC515240D5CBEF34991B4C40
66776	5	53	495	46912	\N	\N	54.827474000000002	с. Царицыно, Администрация Царицынского сельского поселения		0101000020E61000007ADFF8DA339F5240292504ABEA694B40
66772	5	53	495	46831	\N	\N	55.073458000000002	д. Тургеневка, Тургеневский сельский клуб		0101000020E6100000E12538F581A8524096D05D1267894B40
66755	5	53	495	46484	\N	\N	55.095182999999999	д. Таволжанка, Таволжанский сельский клуб		0101000020E6100000E23E726BD2B152404D11E0F42E8C4B40
66783	5	53	495	47052	\N	\N	54.574497000000001	д. Стеклянка, Стеклянский сельский клуб		0101000020E6100000CEFC6A0E10B852403753211E89494B40
66758	5	53	495	10544	\N	\N	55.193823000000002	д. Старый Ревель, Староревельский сельский клуб		0101000020E61000004C512E8D5FC05240371B2B31CF984B40
66747	5	53	495	9955	\N	\N	55.07855	"д. Стародубка, МКОУ ""Воскресенская СОШ"" структурное подразделение ООШ"		0101000020E61000004FE5B4A7E4A15240E78C28ED0D8A4B40
66751	5	53	495	46405	\N	\N	55.111257999999999	с. Сорочино, Сорочинский ДК		0101000020E6100000C8940F41D5B352408DB5BFB33D8E4B40
66780	5	53	495	46993	\N	\N	54.624232999999997	д. Семеновка, Семеновский сельский клуб		0101000020E6100000ABEAE5779AA15240BF0AF0DDE64F4B40
66779	5	53	495	11505	\N	\N	54.611153000000002	д. Розенталь, Розентальский сельский клуб		0101000020E6100000F1811DFF05A6524018EDF1423A4E4B40
66782	5	53	495	47046	\N	\N	54.603566000000001	с. Репинка, Репинский ДК		0101000020E6100000CEFFAB8E1CB05240207D93A6414D4B40
66774	5	53	495	46864	\N	\N	54.892147000000001	с. Осокино, Осокинский ДК		0101000020E6100000E8A221E351A75240BD1C76DF31724B40
66759	5	53	495	53025	\N	\N	55.194685233468299	с. Орловка, Орловский ДК		0101000020E6100000BB5E9A22C0C85240C9022670EB984B40
66756	5	53	495	46496	\N	\N	55.120218000000001	с. Новый Свет, Новосветский ДК		0101000020E6100000DAE55B1FD6B65240FD31AD4D638F4B40
66760	5	53	495	10618	\N	\N	55.142539999999997	д. Новый Ревель, Новоревельский ДК		0101000020E6100000053411363CCB5240982F2FC03E924B40
66773	5	53	495	60855	\N	\N	54.967519000000003	д. Новое Село, Новосельский сельский клуб	Россия, Омская область, Калачинский район, поселок Новое Село	0101000020E6100000E9F17B9BFEA552401BA19FA9D77B4B40
66767	5	53	495	46723	\N	\N	55.041400000000003	"д. Львовка, МКОУ ""Львовская СОШ"""		0101000020E61000001D8F19A88CC45240F7065F984C854B40
66768	5	53	495	10981	\N	\N	54.940593	с. Лагушино, Лагушинский ДК		0101000020E6100000CADFBDA3C6B452405BECF65965784B40
66770	5	53	495	46333	\N	\N	55.061796999999999	с. Куликово, Куликовский ДК		0101000020E6100000B9FAB1497E9D5240D6FECEF6E8874B40
66748	5	53	495	46333	\N	\N	55.061796999999999	д.Куликово, Куликовский сельский клуб		0101000020E6100000B9FAB1497E9D5240D6FECEF6E8874B40
66757	5	53	495	10450	\N	\N	55.147505000000002	д. Крутые Луки, Крутолучинский сельский клуб		0101000020E6100000302C7FBE2DB952408D7F9F71E1924B40
66764	5	53	495	46661	\N	\N	55.094323000000003	д. Ковалево, Ковалевский ДК		0101000020E6100000E7E44526E0D152405C21ACC6128C4B40
66749	5	53	495	53051	\N	\N	55.203557994336897	д. Кибер-Спасск, Киберспасский сельский клуб	Россия, Омская область, Калачинский район, поселок Кибер-Спасское	0101000020E6100000A67F492A53A152406A6B44300E9A4B40
66792	5	53	495	6671	29370	\N	55.041131999999998	г. Калачинск, Черепова, 87		0101000020E61000001F48DE3994A55240D76839D043854B40
66795	5	53	495	6671	28662	\N	55.041131999999998	г. Калачинск, Строительная, 3а		0101000020E61000001F48DE3994A55240D76839D043854B40
66798	5	53	495	6671	29377	\N	55.041131999999998	г. Калачинск, Смирнова, 42		0101000020E61000001F48DE3994A55240D76839D043854B40
66797	5	53	495	6671	29377	\N	55.041131999999998	г. Калачинск, Смирнова, 7		0101000020E61000001F48DE3994A55240D76839D043854B40
66796	5	53	495	6671	29377	\N	55.041131999999998	г. Калачинск, Смирнова, 19		0101000020E61000001F48DE3994A55240D76839D043854B40
66786	5	53	495	6671	29786	\N	55.041131999999998	г. Калачинск, Семашко, 23		0101000020E61000001F48DE3994A55240D76839D043854B40
66788	5	53	495	6671	29518	\N	55.041131999999998	г. Калачинск, Пионерская, 3		0101000020E61000001F48DE3994A55240D76839D043854B40
66689	5	53	495	6671	30138	\N	55.046816471698399	Омская область, Калачинский муниципальный район, Первомайская, 70	Россия, Омская область, Калачинский район, Калачинск	0101000020E610000027C11BD2A8A45240FB761211FE854B40
66791	5	53	495	6671	30065	\N	55.041131999999998	г. Калачинск, Осминина, 48а		0101000020E61000001F48DE3994A55240D76839D043854B40
66789	5	53	495	6671	29519	\N	55.041131999999998	г. Калачинск, Новоселов, 1а		0101000020E61000001F48DE3994A55240D76839D043854B40
66799	5	53	495	6671	29625	\N	55.041131999999998	г. Калачинск, им. Крупской, 132		0101000020E61000001F48DE3994A55240D76839D043854B40
66787	5	53	495	6671	29364	\N	55.041131999999998	г. Калачинск, Красноармейская, 27		0101000020E61000001F48DE3994A55240D76839D043854B40
66790	5	53	495	6671	30061	\N	55.041131999999998	г. Калачинск, Комбинатовская, 1б		0101000020E61000001F48DE3994A55240D76839D043854B40
66785	5	53	495	6671	29227	\N	55.0472158252771	г. Калачинск, Калинина, 25	Россия, Омская область, Калачинский район, Калачинск	0101000020E61000004BAE62F19BA4524089EC832C0B864B40
66677	5	53	495	6671	29227	\N	55.041131999999998	г. Калачинск, Калинина, 62		0101000020E61000001F48DE3994A55240D76839D043854B40
66784	5	53	495	6671	30056	\N	55.043025	г. Калачинск, Калачинская, 27		0101000020E610000049D74CBED9A4524088F4DBD781854B40
66794	5	53	495	6671	29372	\N	55.041131999999998	г. Калачинск, Заводская, 61		0101000020E61000001F48DE3994A55240D76839D043854B40
66793	5	53	495	6671	29372	\N	55.041131999999998	г. Калачинск, Заводская		0101000020E61000001F48DE3994A55240D76839D043854B40
66766	5	53	495	52970	\N	\N	54.999417999999999	с. Кабанье, Администрация Кабаньевского сельского поселения	Россия, Омская область, Калачинский район, поселок Кабанье	0101000020E6100000EBA9D55757CD52405184D4EDEC7F4B40
66775	5	53	495	46895	\N	\N	54.956507999999999	п. Индейка, Березовский ДК		0101000020E61000007427D87F9D9A5240622EA9DA6E7A4B40
66763	5	53	495	60816	76409	\N	55.107555266528102	о.п. Илюшкино, Лесная, 5-2	Россия, Омская область, Калачинский район, поселок Илюшкино	0101000020E610000079E9263108C35240B9C2BB5CC48D4B40
66753	5	53	495	46448	\N	\N	55.251973	д. Измайловка, ФАП д. Измайловка		0101000020E6100000BE175FB4C7B65240CD3CB9A640A04B40
66761	5	53	495	46610	\N	\N	55.131011999999998	с. Ивановка, Администрация Ивановского сельского поселения		0101000020E6100000904FC8CEDBCD524018B14F00C5904B40
66752	5	53	495	10236	\N	\N	55.175775999999999	д. Докучаевка, Докучаевский сельский клуб		0101000020E61000009F573CF548B95240FAB5F5D37F964B40
66754	5	53	495	46466	\N	\N	55.086337	с. Глуховка, Глуховский ДК		0101000020E61000003B3602F1BAAD5240A6B73F170D8B4B40
66781	5	53	495	47014	\N	\N	55.080889999999997	д. Воскресенка, Новоградский сельский клуб	Россия, Омская область, Калачинский район, поселок Воскресенка	0101000020E6100000ABCB290131A852406649809A5A8A4B40
66778	5	53	495	11438	\N	\N	54.651713999999998	с. Великорусское, Великорусский ДК		0101000020E61000002A58E36C3AA85240342C465D6B534B40
66771	5	53	495	11126	\N	\N	55.067704999999997	д. Архангелка, Архангельский сельский клуб		0101000020E6100000AF7D01BD70A052404963B48EAA884B40
66713	5	53	335	53029	\N	\N	54.882691585590301	Омская область, Исилькульский муниципальный район,п. Южный Клуб	Россия, Омская область, Исилькульский район, поселок Южный	0101000020E61000004A29E8F692D851406D382C0DFC704B40
66740	5	53	335	53047	\N	\N	55.0586028897064	Омская область, Исилькульский муниципальный район,хутор №12 Клуб	Россия, Омская область, Исилькульский район, поселок Хутор №12	0101000020E6100000334E4354E1D251404739984D80874B40
66706	5	53	335	53017	\N	\N	54.793804025985203	Омская область, Исилькульский муниципальный район,д. Улендыкуль Школа	Россия, Омская область, Исилькульский район, поселок Улендыкуль	0101000020E6100000AA4885B185DD51408DB7955E9B654B40
66745	5	53	335	52988	\N	\N	54.655467880268901	Омская область, Исилькульский муниципальный район,с. Украинка ДК	Россия, Омская область, Исилькульский район, поселок Украинка	0101000020E61000008CF84ECC7AD551408AC91B60E6534B40
66850	5	53	335	46316	\N	\N	55.119957546375801	Сосновка, Здание школы	Россия, Омская область, Исилькульский район, поселок Сосновка	0101000020E6100000B7D4415E0FCB51406072A3C85A8F4B40
66738	5	53	335	52991	\N	\N	54.988067974624698	Омская область, Исилькульский муниципальный район,с. Солнцевка ДК	Россия, Омская область, Исилькульский район, поселок Солнцевка	0101000020E610000025085740A1D25140B01C2103797E4B40
66724	5	53	335	52972	\N	\N	55.096520966877797	Омская область, Исилькульский муниципальный район,п. Северный (Лесной) Клуб	Россия, Омская область, Исилькульский район, поселок Северный	0101000020E610000048FDF50A0BDD51404930D5CC5A8C4B40
66710	5	53	335	52972	\N	\N	55.100556828244997	Омская область, Исилькульский муниципальный район,п. Северный (Боевой) Контора	Россия, Омская область, Исилькульский район, поселок Северный	0101000020E6100000580394861ADD51402331410DDF8C4B40
66687	5	53	335	52972	\N	\N	55.097310999999998	Омская область, Исилькульский муниципальный район, 3-Северная, 36	Россия, Омская область, Исилькульский район, поселок Северный	0101000020E61000000E130D52F0DC51404145D5AF748C4B40
66723	5	53	335	53001	\N	\N	54.944526457921	Омская область, Исилькульский муниципальный район,д. Рославка Школа	Россия, Омская область, Исилькульский район, поселок Рославка	0101000020E61000009C3061342BC25140611C5C3AE6784B40
66718	5	53	335	52977	\N	\N	54.9362463643129	Омская область, Исилькульский муниципальный район,д. Пучково Школа	Россия, Омская область, Исилькульский район, поселок Пучково	0101000020E61000003B376DC669E051406281AFE8D6774B40
66735	5	53	335	53024	\N	\N	55.070760891771101	Омская область, Исилькульский муниципальный район,с. Первотаровка Клуб	Россия, Омская область, Исилькульский район, поселок Первотаровка	0101000020E61000004AF1F109D9C35140876A4AB20E894B40
66744	5	53	335	53084	\N	\N	54.712574862344397	Омская область, Исилькульский муниципальный район,д. Ночка Клуб	Россия, Омская область, Исилькульский район, поселок Ночка	0101000020E6100000AC55BB26A4D451403E7958A8355B4B40
66732	5	53	335	9260	\N	\N	55.095255000000002	Омская область, Исилькульский муниципальный район,с. Новорождественка Школа		0101000020E610000005DEC9A7C7DD5140E7E3DA50318C4B40
66707	5	53	335	53090	\N	\N	54.755978095610999	Омская область, Исилькульский муниципальный район,д. Новопетроград Клуб	Россия, Омская область, Исилькульский район, поселок Новопетроград	0101000020E6100000D32D3BC43FDE51406C3F19E3C3604B40
66728	5	53	335	52969	\N	\N	55.139194968151998	Омская область, Исилькульский муниципальный район,д. Новолосево Школа	Россия, Омская область, Исилькульский район, поселок Новолосево	0101000020E6100000D7D9907F66CD514024624A24D1914B40
66742	5	53	335	51914	\N	\N	54.654835809983503	Омская область, Исилькульский муниципальный район,д. Новодонка Школа	Россия, Омская область, Исилькульский район, поселок Новодонка	0101000020E6100000E8DEC325C7D951402A1F82AAD1534B40
66720	5	53	335	53006	\N	\N	54.868030210159702	Омская область, Исилькульский муниципальный район,д. Николайполь Детский сад	Россия, Омская область, Исилькульский район, поселок Николайполь	0101000020E6100000FF1F274C18E1514033F9669B1B6F4B40
66741	5	53	335	8999	\N	\N	54.5835880568468	Омская область, Исилькульский муниципальный район,д. Мясники Школа	Россия, Омская область, Исилькульский район, поселок Мясники	0101000020E61000000A67B796C9DA5140452BF702B34A4B40
66727	5	53	335	9044	\N	\N	55.188184999999997	Омская область, Исилькульский муниципальный район,с. Медвежье Школа		0101000020E61000003D47E4BB94D25140834C327216984B40
66615	5	53	345	48250	29790	\N	55.537078000000001	п. Алексеевский, Юбилейная, 26		0101000020E6100000721AA20A7F84524057B3CEF8BEC44B40
66719	5	53	335	53020	\N	\N	54.917323550256398	Омская область, Исилькульский муниципальный район,с.Кухаревское с. Маргенау,  ДК	Россия, Омская область, Исилькульский район, поселок Маргенау	0101000020E6100000174A26A776E45140FFEA71DF6A754B40
66731	5	53	335	51910	\N	\N	55.217152712686399	Омская область, Исилькульский муниципальный район,д. Лукерьино Клуб		0101000020E61000005CE333D93FD85140399D64ABCB9B4B40
66721	5	53	335	8749	\N	\N	54.967998000000001	Омская область, Исилькульский муниципальный район,п. Лесной Школа		0101000020E6100000EEEA556474C95140F54BC45BE77B4B40
66712	5	53	335	8357	\N	\N	54.841121999999999	Омская область, Исилькульский муниципальный район,п. Ленинский Школа		0101000020E61000002BDA1CE736D651401AF9BCE2A96B4B40
66729	5	53	335	53049	\N	\N	55.231920338820501	Омская область, Исилькульский муниципальный район,д. Культжугут Клуб	Россия, Омская область, Исилькульский район, поселок Культжугут	0101000020E6100000978DCEF929CE5140E8A4F78DAF9D4B40
66743	5	53	335	52997	\N	\N	54.746641088965298	Омская область, Исилькульский муниципальный район,д. Кудряевка ФАП		0101000020E6100000473B6EF8DDCE5140266DAAEE915F4B40
66702	5	53	335	52396	\N	\N	54.716532139951397	Омская область, Исилькульский муниципальный район,с. Ксеньевка Клуб	Россия, Омская область, Исилькульский район, поселок Ксеньевка	0101000020E6100000A110018750E95140CC441152B75B4B40
66716	5	53	335	8544	\N	\N	54.768904999999997	Омская область, Исилькульский муниципальный район,с. Кромы Школа		0101000020E61000003EE76ED74BC551408D5DA27A6B624B40
66705	5	53	335	53012	\N	\N	54.782820553713897	Омская область, Исилькульский муниципальный район,д. Красновознесенка Клуб		0101000020E6100000BF6378EC67E651409ECF807A33644B40
66725	5	53	335	8917	\N	\N	54.87576	Омская область, Исилькульский муниципальный район,п. Комсомольский Школа		0101000020E6100000D044D8F0F4C851408E9257E718704B40
66715	5	53	335	53038	\N	\N	54.796721346088802	Омская область, Исилькульский муниципальный район,аул Каскат Клуб	Россия, Омская область, Исилькульский район, поселок Каскат	0101000020E610000005C24EB16AC85140A98427F4FA654B40
66694	5	53	335	52974	78664	\N	54.909883999999998	Омская область, Исилькульский муниципальный район, Строителей, 2	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000000327DBC01DD15140AB93331477744B40
66686	5	53	335	52974	78646	\N	54.909883999999998	Омская область, Исилькульский муниципальный район,Здание Дворца Культуры, ул.Пушкина, 30	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000000327DBC01DD15140AB93331477744B40
66698	5	53	335	52974	78845	\N	54.909883999999998	Омская область, Исилькульский муниципальный район, Партизанская, 1	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000000327DBC01DD15140AB93331477744B40
66692	5	53	335	52974	30103	\N	54.914660080191297	Омская область, Исилькульский муниципальный район, Ленина, 98 А	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E6100000A27DACE0B7D05140CC7A319413754B40
66699	5	53	335	52974	78887	\N	54.909883999999998	Омская область, Исилькульский муниципальный район, Крупской, 6	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000000327DBC01DD15140AB93331477744B40
66697	5	53	335	52974	78811	\N	54.909883999999998	Омская область, Исилькульский муниципальный район, Деповская, 24	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000000327DBC01DD15140AB93331477744B40
66688	5	53	335	52974	30161	\N	54.914462299782102	Омская область, Исилькульский муниципальный район, Тельмана, 187	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E6100000B804E09F52D05140A6B73F170D754B40
66700	5	53	335	52974	30129	\N	54.913671168382798	Омская область, Исилькульский муниципальный район, Степная, 43	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E6100000EE7BD45FAFD15140DD26DC2BF3744B40
66695	5	53	335	52974	78712	\N	54.909883999999998	Омская область, Исилькульский муниципальный район, Степная, 5	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000000327DBC01DD15140AB93331477744B40
66696	5	53	335	52974	78748	\N	54.909883999999998	Омская область, Исилькульский муниципальный район, Партизанская, 198	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000000327DBC01DD15140AB93331477744B40
66684	5	53	335	52974	30141	\N	54.917138722874597	Омская область, Исилькульский муниципальный район, Исилькульское городское поселение, Октябрьская 16	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000002F6F0ED76AD151406D718DCF64754B40
66691	5	53	335	52974	30119	\N	54.914066736034997	Омская область, Исилькульский муниципальный район, Ленинградская, 56	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E6100000284701A260D151402AADBF2500754B40
66693	5	53	335	52974	29135	\N	54.916440059942602	Омская область, Исилькульский муниципальный район, Ленина, 94	Россия, Омская область, Исилькульский район, Исилькуль	0101000020E61000002A711DE38AD05140855FEAE74D754B40
66736	5	53	335	9463	\N	\N	55.149019092288498	Омская область, Исилькульский муниципальный район,д. Емонтаево частный дом		0101000020E6100000919A7631CDBC5140C7BDF90D13934B40
66733	5	53	335	52978	\N	\N	55.169513999999999	Омская область, Исилькульский муниципальный район,д. Евсюки Клуб	Россия, Омская область, Исилькульский район, поселок Евсюки	0101000020E6100000D9CEF753E3DD5140691B7FA2B2954B40
66717	5	53	335	53046	\N	\N	54.961458954900699	Омская область, Исилькульский муниципальный район,д. Гофнунгсталь Школа	Россия, Омская область, Исилькульский район, поселок Гофнунгсталь	0101000020E6100000BE33DAAA24E05140F1B8A816117B4B40
66739	5	53	335	53040	\N	\N	55.007212875885998	Омская область, Исилькульский муниципальный район,д. Водяное Клуб	Россия, Омская область, Исилькульский район, поселок Водяное	0101000020E6100000079B3A8F8AD55140938D075BEC804B40
66704	5	53	335	52975	\N	\N	54.818850793604597	Омская область, Исилькульский муниципальный район,с. Васютино Клуб	Россия, Омская область, Исилькульский район, поселок Васютино	0101000020E61000002CB7B41A12E8514001A60C1CD0684B40
66711	5	53	335	8297	\N	\N	54.770052999999997	Омская область, Исилькульский муниципальный район,п. Боровое Школа		0101000020E6100000B020CD5834D75140E597C11891624B40
66708	5	53	335	53083	\N	\N	54.936626459029497	Омская область, Исилькульский муниципальный район,п. Боевой ДК	Россия, Омская область, Исилькульский район, поселок Боевой	0101000020E610000018601F9DBADC5140A94A5B5CE3774B40
66777	5	53	335	46934	\N	\N	54.885590999999998	д. Благовещенка, Благовещенский сельский клуб		0101000020E61000004084B872F6C25140E350BF0B5B714B40
66701	5	53	335	7779	29661	\N	54.783605999999999	Омская область, Исилькульский муниципальный район, с. Баррикада, Ленина		0101000020E6100000A7203F1BB9E2514085798F334D644B40
66734	5	53	335	53089	\N	\N	55.166534223530299	Омская область, Исилькульский муниципальный район,д. Апполоновка Школа		0101000020E61000009373620FEDE2514006D671FC50954B40
66680	5	53	469	6814	\N	\N	57.236193999999998	Омская область, Знаменский муниципальный район, Шуховское сельское поселение ,с.Шухово, Ленина,36, Школа	Россия, Омская область, Знаменский район, поселок Шухово	0101000020E6100000054F2157EA5E524076C1E09A3B9E4C40
66676	5	53	469	6648	29165	\N	57.018805	Омская область, Знаменский муниципальный район, Чередовское сельское поселение,с.Чередово, Зелёная 17, Дом культуры		0101000020E6100000AB06616EF76952402A00C63368824C40
66672	5	53	469	6418	29730	\N	57.324789000000003	Омская область, Знаменский муниципальный район, Новоягодинское сельское поселение,п.Усть-Шиш, Советская, 25, Школа		0101000020E610000095F3C5DE8B585240DF8C9AAF92A94C40
66670	5	53	469	6328	29160	\N	57.246690000000001	Омская область, Знаменский муниципальный район, Качуковское сельское поселение,д.Усть-Тамак, Зелёная, 22-Б, Школа		0101000020E61000005930F147516E52400820B589939F4C40
66683	5	53	469	2760	28770	\N	57.251821999999997	Омская область, Знаменский муниципальный район, Шуховское сельское поселение, д.Тузаклы, Зелёная,8, Школа		0101000020E610000004763579CA575240E7340BB43BA04C40
66675	5	53	469	6591	29628	\N	57.144903999999997	Омская область, Знаменский муниципальный район, Семеновское сельское поселение,д.Солдатка, Солдатская 47, Школа		0101000020E6100000D86322A5D9725240A087DA368C924C40
66673	5	53	469	6480	29686	\N	57.139366000000003	Омская область, Знаменский муниципальный район, Семеновское сельское поселение,с.Семеновка, Школьная, 2, Школа		0101000020E6100000B726DD96C86F52405116BEBED6914C40
66674	5	53	469	6504	29162	\N	57.138066999999999	Омская область, Знаменский муниципальный район, Семеновское сельское поселение,д.Пушкарёво, Школьная, 1-A, Школа		0101000020E61000000A82C7B7776B524013D4F02DAC914C40
66671	5	53	469	6365	29292	\N	57.355307000000003	Омская область, Знаменский муниципальный район, Новоягодинское сельское поселение,с.Новоягодное, Школьная, 1-A, Школа		0101000020E6100000FFCF61BEBC6052401B8524B37AAD4C40
66679	5	53	469	6793	29865	\N	57.060935000000001	Омская область, Знаменский муниципальный район, Чередовское сельское поселение,д.Никольск, Центральная, 41, Школа		0101000020E6100000FAF202ECA36A52404417D4B7CC874C40
66665	5	53	469	6046	29157	\N	57.099637999999999	Омская область, Знаменский муниципальный район, Бутаковское сельское поселение,д. Мамешево, Центральная 9, Сельский клуб		0101000020E6100000586FD40AD38252402CB81FF0C08C4C40
66682	5	53	469	6929	29269	\N	57.214905999999999	Омская область, Знаменский муниципальный район, Шуховское сельское поселение, Малобутаково, Зелёная, 2, Школа		0101000020E6100000992D5915E16352406ADB300A829B4C40
66678	5	53	469	6749	29441	\N	56.932875000000003	Омская область, Знаменский муниципальный район, Чередовское сельское поселение,д.Котовщиково, Новая,1, Школа		0101000020E6100000EB025E66D8635240C520B07268774C40
66664	5	53	469	5979	29423	\N	56.980168999999997	Омская область, Знаменский муниципальный район, Бутаковское сельское поселение, д.Копейкино, Молодежная 16, Школа		0101000020E61000009BCAA2B08B875240C9C6832D767D4C40
66681	5	53	469	6858	29588	\N	57.153745999999998	Омская область, Знаменский муниципальный район, Шуховское сельское поселение,д.Кондрашино, Центральная, 26, Школа		0101000020E6100000DA1D520C906A524006F2ECF2AD934C40
66660	5	53	469	5800	29564	\N	57.119262999999997	Омская область, Знаменский муниципальный район, Знаменское сельское поселение д.Киселево, Новая 2, Школа		0101000020E6100000F06E6589CE795240B94F8E02448F4C40
66669	5	53	469	6274	28692	\N	57.197346000000003	Омская область, Знаменский муниципальный район, Качуковское сельское поселение,с.Качуково, Тавлетова 26, Школа		0101000020E61000007EC68503217652408BFF3BA242994C40
66661	5	53	469	5821	29826	\N	57.123651000000002	Омская область, Знаменский муниципальный район, Знаменское сельское поселение, с .Знаменское, Новостроевская 9, контора «ЗАО Знаменский лён»		0101000020E61000006B0C3A2174745240118FC4CBD38F4C40
66659	5	53	469	5821	30090	\N	57.123651000000002	Омская область, Знаменский муниципальный район, Знаменское сельское поселение, Ленина 72, Школа	Россия, Омская область, Знаменский район, поселок Знаменское	0101000020E61000006B0C3A2174745240118FC4CBD38F4C40
66618	5	53	345	60818	76411	\N	55.358324809711299	аул Бельсенды-Казах, Школьная, 22/1	Россия, Омская область, Горьковский район, поселок Бельсенды-Казах	0101000020E6100000F0C16B97368252406B2BF697DDAD4B40
66656	5	53	469	5821	30169	\N	57.1278140255192	Омская область, Знаменский муниципальный район, Знаменское сельское поселение, Гагарина 15, Дом детского творчества	Россия, Омская область, Знаменский район, поселок Знаменское	0101000020E6100000CB9E0436E774524048FC8A355C904C40
66666	5	53	469	6120	29158	\N	57.148864000000003	Омская область, Знаменский муниципальный район, Завьяловское сельское поселение,с.Завьялово, Школьная  1А, Средняя школа		0101000020E61000003A799109F85B5240A0C6BDF90D934C40
66662	5	53	469	5901	29694	\N	57.050871000000001	Омская область, Знаменский муниципальный район, Бутаковское сельское поселение,с Бутаково, Школьная 8, Школа		0101000020E610000079793A57948552404CA8E0F082864C40
66668	5	53	469	6211	29717	\N	57.134526000000001	Омская область, Знаменский муниципальный район, Завьяловское сельское поселение,д.Авяк, Вятка 24, Школа		0101000020E6100000D5EC815660525240193BE12538914C40
66818	5	53	4828	37138	29536	\N	54.808337999999999	д. Мясники (школа), Мясниковская, 13		0101000020E61000009C8C2AC3B8AF4040990E9D9E77674B40
67054	5	53	345	60842	76455	\N	55.413377932588702	д. карташово, ул. Центральная, 16	Россия, Омская область, Горьковский район	0101000020E6100000948444DAC67052406571FF91E9B44B40
66655	5	53	345	5524	29973	\N	55.400818000000001	д. Яковлевка, Центральная, 23 а		0101000020E6100000CCCF0D4DD99C5240F6D214014EB34B40
66654	5	53	345	5447	29691	\N	55.418374	д. Чучкино, переулок Зеленый, 3 а		0101000020E6100000BAF94674CF68524094BF7B478DB54B40
66653	5	53	345	5405	29141	\N	55.296953999999999	д. Чулино, Центральная, 15		0101000020E6100000C7F65AD07BA252404C35B39602A64B40
66652	5	53	345	48916	29245	\N	55.186129000000001	п. Ударный, Производственная, 5		0101000020E6100000F3E2C4573B8F524029EB3713D3974B40
47475	5	53	345	1703	29082	\N	55.611159999999998	д. Сягаевка, Клубная, 8		0101000020E61000009FAF592E1B8B5240CA4FAA7D3ACE4B40
66651	5	53	345	5297	29988	\N	55.421982	с. Сухое, Кирова, 1		0101000020E6100000925B936E4B7B524016C0948103B64B40
66650	5	53	345	48879	29264	\N	55.213202000000003	с. Спасское, Озерная, 36		0101000020E610000057410C74ED8952408DB800344A9B4B40
66649	5	53	345	48848	28672	\N	55.437658999999996	д. Соснино, Луговая, 2		0101000020E61000002BF702B3429A524068E6C93505B84B40
66648	5	53	345	48843	29816	\N	55.711599999999997	д. Согра, Большая, 18		0101000020E6100000E44C13B69F8F5240B3EA73B515DB4B40
66647	5	53	345	48822	29818	\N	55.707780999999997	с. Серебряное, Красноярова, 2 б		0101000020E61000008B16A06D3595524076DD5B9198DA4B40
66645	5	53	345	60144	73903	\N	55.7037744049751	д. Саратово, Центральная, 23 б	Россия, Омская область, Горьковский район, поселок Саратово	0101000020E6100000B4AB90F29389524037E3344415DA4B40
66644	5	53	345	48774	29134	\N	55.456837	с. Рощино, В. Гулака, 11		0101000020E61000005706D506278F5240274D83A279BA4B40
66643	5	53	345	48752	\N	\N	55.516272000000001	д. Подольск, Центральная, 22 а	Россия, Омская область, Горьковский район, поселок Подольск	0101000020E61000003AEAE8B81A96524096EB6D3315C24B40
66642	5	53	345	4847	29676	\N	55.269302000000003	с. Павлодаровка, Центральная, 39		0101000020E610000075B169A5107C5240AB5FE97C78A24B40
66641	5	53	345	48713	29807	\N	55.405281000000002	д. Осиповка, Центральная, 21 а		0101000020E610000033DDEBA4BE6352405858703FE0B34B40
66640	5	53	345	48711	\N	\N	55.556843000000001	с. Октябрьское, Ленина, 16	Россия, Омская область, Горьковский район, поселок Октябрьское	0101000020E6100000224F92AE99665240D600A5A146C74B40
66639	5	53	345	53131	30160	\N	55.242376292479697	д. Ново-Юрьево, Центральная, 42	Россия, Омская область, Горьковский район, поселок Новоюрьево	0101000020E610000024ED461FF3905240EBAA402D069F4B40
66884	5	53	345	47864	29864	\N	55.708181496243498	д. Новопокровка, Центральная, 18	Россия, Омская область, Горьковский район, поселок Новопокровка	0101000020E6100000E61E12BEF78252400553CDACA5DA4B40
66637	5	53	345	4549	29913	\N	55.586888000000002	д. Новооболонь, Новая, 38		0101000020E610000047C9AB730C7052401A355F251FCB4B40
66636	5	53	345	53041	29814	\N	55.458086999999999	д. Максимовка, Центральная, 28	Россия, Омская область, Горьковский район, поселок Максимовка	0101000020E6100000BB2BBB607068524083DC4598A2BA4B40
66635	5	53	345	4456	29957	\N	55.466586	с. Лежанка, Советская, 3 а		0101000020E61000000647C9AB735C5240BF620D17B9BB4B40
66634	5	53	345	48600	29801	\N	55.598618999999999	д. Крутиха, Центральная, 31		0101000020E61000004EED0C535B735240D2E1218C9FCC4B40
66633	5	53	345	48580	29437	\N	55.270527999999999	с. Красная Поляна, Центральная, 16		0101000020E61000008388D4B48B8F52407E5358A9A0A24B40
66632	5	53	345	60831	76442	\N	55.266853269870701	д. Кирсаново, Центральная, 16		0101000020E6100000971C774A0799524074EB353D28A24B40
66631	5	53	345	4249	28678	\N	55.309634893267699	д. Карасево, Школьная, 3/1	Россия, Омская область, Горьковский район, поселок Карасево	0101000020E61000007EA83462669552403659A31EA2A74B40
66630	5	53	345	4163	29669	\N	55.25441	д. Калачинская, Центральная, 2		0101000020E6100000B9A981E673A452403FE3C28190A04B40
46502	5	53	345	46191	29712	\N	55.745843000000001	с. Исаковка, Новая, 22		0101000020E6100000414AECDADE9A5240AB798EC877DF4B40
66609	5	53	345	48136	29110	\N	55.304938999999997	д. Исаевка, 2-я Малая, 1		0101000020E61000000CAD4ECE508A52403123BC3D08A74B40
66839	5	53	345	48142	\N	\N	55.511158999999999	Дубровка, Здание сельского клуба		0101000020E6100000D09849D40B6B52402D077AA86DC14B40
66629	5	53	345	48142	29956	\N	55.511158999999999	д. Дубровка, ул. Школьная, 1		0101000020E6100000D09849D40B6B52402D077AA86DC14B40
66628	5	53	345	48494	29952	\N	55.419953	д. Демьяновка, Ленина, 22		0101000020E61000001536035C90725240B56D1805C1B54B40
66624	5	53	345	3924	29397	\N	55.368492000000003	р.п. Горьковское, Павлика Морозова, 6		0101000020E61000001283C0CAA1975240386BF0BE2AAF4B40
66627	5	53	345	3924	29799	\N	55.368492000000003	р.п. Горьковское, Маяковского, 29		0101000020E61000001283C0CAA1975240386BF0BE2AAF4B40
66626	5	53	345	3924	29948	\N	55.368492000000003	р.п. Горьковское, Ленина, 12		0101000020E61000001283C0CAA1975240386BF0BE2AAF4B40
66625	5	53	345	3924	29396	\N	55.368492000000003	р.п. Горьковское, Кирова, 18		0101000020E61000001283C0CAA1975240386BF0BE2AAF4B40
67451	5	53	345	53032	29731	\N	55.5822436564588	село  Георгиевка, Центральная, 17	Россия, Омская область, Горьковский район, поселок Георгиевка	0101000020E6100000E1EB6B5D6A7852406825ADF886CA4B40
66622	5	53	345	48386	29664	\N	55.306215000000002	п. Веселый, Зеленая, 4		0101000020E61000008CF337A1109D5240B745990D32A74B40
66619	5	53	345	48335	30081	\N	55.704478999999999	д. Богданово, Центральная, 38		0101000020E6100000C9CC052E8F7D524001DC2C5E2CDA4B40
66838	5	53	345	53035	\N	\N	55.520763320951197	Алексеевка, Здание ДДЮТ	Россия, Омская область, Горьковский район, поселок Алексеевка	0101000020E6100000D95E0B7A6F825240C2FBAA5CA8C24B40
66613	5	53	345	3307	29531	\N	55.450726000000003	д. Аксеновка, Центральная, 16		0101000020E6100000FB592C45F27F52407CBABA63B1B94B40
66612	5	53	345	3191	29375	\N	55.523972999999998	д. Агафоновка, Новая, 4		0101000020E6100000D7DAFB5415775240567E198C11C34B40
66610	5	53	397	3108	29236	\N	56.549869000000001	Омская область, Большеуковский муниципальный район, Чернецовское сельское поселение, с.Чернецовка, Иванова, 3		0101000020E6100000BFEFDFBC38215240C80A7E1B62464C40
66607	5	53	397	2961	29650	\N	57.092069000000002	Омская область, Большеуковский муниципальный район, Чебаклинское сельское поселение, с. Чебаклы, Молодёжная, 22в		0101000020E6100000F8C5A52A6D445240DBFCBFEAC88B4C40
66608	5	53	397	3011	29784	\N	57.143960999999997	Омская область, Большеуковский муниципальный район, Чебаклинское сельское поселение, д. Чаунино, Школьная, 14а		0101000020E61000009AB4A9BA47455240217365506D924C40
66603	5	53	397	2693	29984	\N	56.781759000000001	Омская область, Большеуковский муниципальный район, Становское сельское поселение, д. Форпост, Ямщицкая, 8		0101000020E6100000971E4DF5640A5240452DCDAD10644C40
66605	5	53	397	2842	29923	\N	57.037179999999999	Омская область, Большеуковский муниципальный район, Фирстовское сельское поселение, с Фирстово, Калинина, 11		0101000020E610000008E6E8F17B3852405B087250C2844C40
66604	5	53	397	2722	29228	\N	57.06944	Омская область, Большеуковский муниципальный район, Уралинское сельское поселение, с. Уралы, Центральная,62		0101000020E6100000ABB019E0823D52406284F068E3884C40
66595	5	53	397	2260	29222	\N	56.98912	Омская область, Большеуковский муниципальный район, Аевское сельское поселение, д. Уки, Молодёжная, 1		0101000020E61000005D876A4AB2275240E6E8F17B9B7E4C40
66601	5	53	397	2607	29648	\N	56.859285999999997	Омская область, Большеуковский муниципальный район, Становское сельское поселение, с. Становка, Школьная, 1		0101000020E6100000D90A9A965818524090F46915FD6D4C40
66594	5	53	397	2163	29102	\N	56.925989000000001	Омская область, Большеуковский муниципальный район, Аевское сельское поселение, д. Решетино, Клементьева, 2		0101000020E61000009F1D705D311C524056BABBCE86764C40
66600	5	53	397	2516	29647	\N	57.235171000000001	Омская область, Большеуковский муниципальный район, Листвяжинское сельское поселение, с. Листвяги, Школьная, 1		0101000020E6100000D7DD3CD521FA5140DBFB54151A9E4C40
66602	5	53	397	2652	29233	\N	56.844347999999997	Омская область, Большеуковский муниципальный район, Становское сельское поселение, д. Коновалиха, Школьный переулок, 25		0101000020E61000003B527DE7171C5240B4386398136C4C40
66593	5	53	397	2152	29099	\N	56.774791	Омская область, Большеуковский муниципальный район, Аевское сельское поселение, д. Верхние Уки, Кольцевая, 9/2		0101000020E6100000B91B446B45315240191EFB592C634C40
66599	5	53	397	2366	29517	\N	56.951847000000001	Омская область, Большеуковский муниципальный район, Большеуковское сельское поселение, с. Большие Уки, Карла Маркса, 11		0101000020E610000023BF7E880D285240DAE55B1FD6794C40
66598	5	53	397	2366	30059	\N	56.951847000000001	Омская область, Большеуковский муниципальный район, Большеуковское сельское поселение, с. Большие Уки, Калинина, 43		0101000020E610000023BF7E880D285240DAE55B1FD6794C40
66597	5	53	397	2366	29522	\N	56.951847000000001	Омская область, Большеуковский муниципальный район, Большеуковское сельское поселение, с. Большие Уки, Избышева, 20		0101000020E610000023BF7E880D285240DAE55B1FD6794C40
66596	5	53	397	2309	29646	\N	56.624791999999999	Омская область, Большеуковский муниципальный район, Белогривское сельское поселение, с. Белогривка, П. Сидельникова, 2		0101000020E6100000BD56427749355240B6662B2FF94F4C40
66606	5	53	397	2862	29524	\N	57.008209999999998	Омская область, Большеуковский муниципальный район, Фирстовское сельское поселение, д. Баслы, Центральная, 25		0101000020E6100000D3A57F492A32524005C078060D814C40
66592	5	53	397	2074	29362	\N	56.928959999999996	Омская область, Большеуковский муниципальный район, Аевское сельское поселение, с. Аёв, Березовая, 1а		0101000020E61000003BA6EECA2E28524065A54929E8764C40
66573	5	53	103	972	29907	\N	56.114469999999997	Омская область, Большереченский муниципальный район, д.Яланкуль, Школьная, 25		0101000020E6100000C0B0FCF9B6715240C22FF5F3A60E4C40
66556	5	53	103	32392	29484	\N	56.404513000000001	Омская область, Большереченский муниципальный район, д.Яготово, Южная, 3		0101000020E61000005E2EE23B3199524047E7FC14C7334C40
66550	5	53	103	32101	29326	\N	56.528517999999998	Омская область, Большереченский муниципальный район, д.Шуево, Дорожная, 15		0101000020E6100000F81BEDB8E1A9524075AC527AA6434C40
66589	5	53	103	53052	29889	\N	56.016646552054702	Омская область, Большереченский муниципальный район, Шипицынское сельское поселение, Школьная, 11	Россия, Омская область, Большереченский район, поселок Шипицино	0101000020E610000000C45DBD8AA45240CB49287D21024C40
66576	5	53	103	1135	29896	\N	55.839274000000003	Омская область, Большереченский муниципальный район, д.Черново, Центральная, 1		0101000020E6100000E9B5D958897C52400A3197546DEB4B40
66561	5	53	103	249	29492	\N	56.322679000000001	Омская область, Большереченский муниципальный район, д.Черналы, Приозерная, 56		0101000020E610000014419C87138B5240910DA48B4D294C40
66552	5	53	103	32225	29876	\N	56.583207000000002	Омская область, Большереченский муниципальный район, д.Чеплярово, Береговая, 67		0101000020E61000006E6B0BCF4BB052402EE6E786A64A4C40
66570	5	53	103	60852	76468	\N	55.968398000000001	Омская область, Большереченский муниципальный район, Чебаклинское сельское поселение, Центральная, 7		0101000020E6100000AE9B525E2B78524083C13577F4FB4B40
66571	5	53	103	871	29761	\N	56.008268999999999	Омская область, Большереченский муниципальный район, д.Уваровка, Школьная, 71		0101000020E6100000567DAEB6628052400A4966F50E014C40
66560	5	53	103	143	29198	\N	56.369422	Омская область, Большереченский муниципальный район, д.Тусказань, Казанская, 78		0101000020E61000001021AE9CBD94524022365838492F4C40
66575	5	53	103	1075	29207	\N	55.849504000000003	Омская область, Большереченский муниципальный район, д.Трубчевка, Центральная, 1		0101000020E610000076711B0DE08152401DE90C8CBCEC4B40
66548	5	53	103	32044	30022	\N	56.551799000000003	Омская область, Большереченский муниципальный район, д.Терехово, Иртышская, 34		0101000020E61000002594BE1072A85240967B8159A1464C40
66540	5	53	103	52979	29202	\N	56.244331550983198	Омская область, Большереченский муниципальный район, Такмыкское сельское поселение, Школьная, 5А	Россия, Омская область, Большереченский район, поселок Такмык	0101000020E61000005B40683D7CAB5240E2AE5E45461F4C40
66567	5	53	103	517	29337	\N	56.082892999999999	Омская область, Большереченский муниципальный район, д.Сухокарасук, Лесная, 16		0101000020E6100000FD885FB1868752409E08E23C9C0A4C40
66547	5	53	103	32011	29477	\N	56.611632	Омская область, Большереченский муниципальный район, д.Секменево, Береговая, 65		0101000020E61000001CF0F96184A45240F29716F5494E4C40
66584	5	53	103	1621	29096	\N	55.985508000000003	Омская область, Большереченский муниципальный район, д.Рямовка, Рязанская, 48а		0101000020E61000007FBF982D5998524023F94A2025FE4B40
66578	5	53	103	1277	29090	\N	55.887174999999999	Омская область, Большереченский муниципальный район, д.Русиново, Центральная, 9		0101000020E6100000C976BE9F1A7A5240166A4DF38EF14B40
66582	5	53	103	1490	29911	\N	55.802826000000003	Омская область, Большереченский муниципальный район, д.Ростовка, Зеленая, 17		0101000020E6100000C23060C95598524073309B00C3E64B40
66542	5	53	103	31753	\N	\N	56.298181999999997	Омская область, Большереченский муниципальный район, д.Решетниково, Советов, 47	Россия, Омская область, Большереченский район, поселок Решетниково	0101000020E610000027C0B0FCF9AC5240C020E9D32A264C40
66553	5	53	103	53100	30093	\N	56.515200732130602	Омская область, Большереченский муниципальный район, Почекуевское сельское поселение, пер.Школьный, 19	Россия, Омская область, Большереченский район, поселок Почекуево	0101000020E6100000B95164ADA19D5240E9EE3A1BF2414C40
66539	5	53	103	31633	29469	\N	56.115167999999997	Омская область, Большереченский муниципальный район, д.Осихино, Центральная, 11		0101000020E6100000B020CD58349E5240DAC534D3BD0E4C40
66546	5	53	103	53128	30154	\N	56.5798671483074	Омская область, Большереченский муниципальный район, Новологиновское сельское поселение, Советская, 70	Россия, Омская область, Большереченский район, поселок Новологиново	0101000020E61000001215AA9B8BA75240CB83F414394A4C40
66586	5	53	103	1711	29351	\N	55.930613999999998	Омская область, Большереченский муниципальный район, д.Моховое Озеро, Луговая, 25а		0101000020E6100000DD0A6135968E524091990B5C1EF74B40
66583	5	53	103	53130	30159	\N	55.921586317390002	Омская область, Большереченский муниципальный район, Могильно-Посельское сельское поселение, Чехова, 97	Россия, Омская область, Большереченский район, поселок Могильно-Посельское	0101000020E6100000560C5707409D5240C939B187F6F54B40
66580	5	53	103	1367	29910	\N	55.842322000000003	Омская область, Большереченский муниципальный район, д.Милино, Победы, 25		0101000020E61000000A2DEBFEB1945240C5591135D1EB4B40
66564	5	53	103	53050	29887	\N	56.120833503005301	Омская область, Большереченский муниципальный район, Курносовское сельское поселение, Советов, 28	Россия, Омская область, Большереченский район, поселок Курносово	0101000020E6100000CAC4AD8218945240581F0F7D770F4C40
66569	5	53	103	742	29620	\N	56.220202999999998	Омская область, Большереченский муниципальный район, д.Куйгалы, Школьная, 2		0101000020E610000099A0866F618A524094BDA59C2F1C4C40
66538	5	53	103	31588	29740	\N	56.174104	Омская область, Большереченский муниципальный район, д.Криводаново, Школьная, 20		0101000020E61000000344C18C299F5240280D350A49164C40
66535	5	53	103	52964	29058	\N	56.146840150385103	Омская область, Большереченский муниципальный район, Красноярское сельское поселение, Советов, 6	Россия, Омская область, Большереченский район, поселок Красный Яр	0101000020E61000009CC1DF2F66A7524050DF32A7CB124C40
66554	5	53	103	32295	29194	\N	56.498738000000003	Омская область, Большереченский муниципальный район, д.Кошкуль, Центральная, 1		0101000020E6100000211E8997A7935240E0A293A5D63F4C40
66557	5	53	103	32449	29073	\N	56.450822000000002	Омская область, Большереченский муниципальный район, д.Коршуново, Центральная, 1		0101000020E61000006745D4449F9A52409E280989B4394C40
66545	5	53	103	31908	30021	\N	56.452249999999999	Омская область, Большереченский муниципальный район, д.Колбышево, Новая, 2б		0101000020E6100000812381069BAA5240D9CEF753E3394C40
66590	5	53	103	1966	29511	\N	56.041597000000003	Омская область, Большереченский муниципальный район, д.Кирсановка, Кирсановская, 32		0101000020E61000003ECF9F36AAA452404D4EED0C53054C40
66563	5	53	103	362	29333	\N	56.317238000000003	Омская область, Большереченский муниципальный район, д.Каракуль, Лесная, 26		0101000020E61000003B72A43330865240348639419B284C40
66579	5	53	103	52989	29331	\N	55.849894420753003	Омская область, Большереченский муниципальный район, Ингалинское сельское поселение, Школьная, 2а	Россия, Омская область, Большереченский район, поселок Ингалы	0101000020E6100000912749D74C8E524087889B53C9EC4B40
66565	5	53	103	496	29335	\N	56.120553000000001	Омская область, Большереченский муниципальный район, д.Добролюбовка, Зеленая, 10		0101000020E61000006B10E6762F8E5240A437DC476E0F4C40
66591	5	53	103	2025	29219	\N	56.013593	Омская область, Большереченский муниципальный район, д.Гущино, Гущинская, 16а		0101000020E6100000DFC14F1C40A952402E3A596ABD014C40
66543	5	53	103	31820	29321	\N	56.279062000000003	Омская область, Большереченский муниципальный район, д.Ботвино, Центральная, 9		0101000020E61000008942CBBA7FA3524037C7B94DB8234C40
66532	5	53	103	52965	29621	\N	56.099947355099602	Омская область, Большереченский муниципальный район, Большереченское городское поселение, Трудовая, 1	Россия, Омская область, Большереченский район, поселок Большеречье	0101000020E6100000C39CA04D0EA85240AA2A3410CB0C4C40
66529	5	53	103	52965	29065	\N	56.095170931446702	Омская область, Большереченский муниципальный район, Большереченское городское поселение, О.Бронского, 4	Россия, Омская область, Большереченский район, поселок Большеречье	0101000020E61000005299620E82A85240894336902E0C4C40
66527	5	53	103	52965	30145	\N	56.087664536590196	Омская область, Большереченский муниципальный район, Большереченское городское поселение, Коммунистическая, 21	Россия, Омская область, Большереченский район, поселок Большеречье	0101000020E610000089D1730B5DA852407E00529B380B4C40
66528	5	53	103	52965	30124	\N	56.099563576567398	Омская область, Большереченский муниципальный район, Большереченское городское поселение, Дорожная, 27	Россия, Омская область, Большереченский район, поселок Большеречье	0101000020E61000003BA92F4B3BA85240F2ED5D83BE0C4C40
66559	5	53	103	52965	30125	\N	56.089104132884302	Омская область, Большереченский муниципальный район, Уленкульское сельское поселение, Гагарина, 48	Россия, Омская область, Большереченский район, поселок Большеречье	0101000020E6100000B0E595EB6DA85240ADF886C2670B4C40
66524	5	53	103	52965	30128	\N	56.101386490382602	Омская область, Большереченский муниципальный район, Большереченское городское поселение, 50 лет ВЛКСМ, 28	Россия, Омская область, Большереченский район, поселок Большеречье	0101000020E610000077DCF0BBE9A75240D9226937FA0C4C40
66588	5	53	103	60811	76391	\N	55.929420977229697	Омская область, Большереченский муниципальный район, д.Большие Мурлы, Молодежная, 1б	Россия, Омская область, Большереченский район, поселок Большемурлы	0101000020E6100000A2F14410E7A25240999B6F44F7F64B40
66551	5	53	103	32156	29328	\N	56.623246999999999	Омская область, Большереченский муниципальный район, д.Берняжка, Береговая, 23		0101000020E61000008B389D64ABA45240412AC58EC64F4C40
66572	5	53	103	918	29627	\N	55.918650999999997	Омская область, Большереченский муниципальный район, д.Березовка, пер.Школьный, 1		0101000020E61000001F8315A75A77524006B8205B96F54B40
66536	5	53	103	31494	29185	\N	56.132835	Омская область, Большереченский муниципальный район, д.Безымянная, Центральная, 4/1		0101000020E61000007AFEB4519DA35240D061BEBC00114C40
66409	5	53	929	25582	29367	\N	54.673960000000001	д. Ягодное, 1 Мая, 8		0101000020E610000055698B6B7C3A5240F5673F5244564B40
66382	5	53	929	61522	79296	\N	54.633434000000001	д. Южное, Школьная, 1	Россия, Омская область, Азовский Немецкий Национальный район, поселок Южное	0101000020E6100000BEFA78E8BB4152405516855D14514B40
66522	5	53	929	30801	29455	\N	54.488608999999997	с. Цветнополье, Кирова, 66		0101000020E61000000DAA0D4E4438524000C45DBD8A3E4B40
66521	5	53	929	60201	74030	\N	54.837212000000001	а. Тулумбай, Березовая, 14	Россия, Омская область, Азовский Немецкий Национальный район, поселок Тулумбай	0101000020E6100000AB5B3D27BD415240CDE847C3296B4B40
66054	5	53	929	46235	29249	\N	54.610016000000002	д. Трубецкое, Колхозная, 34		0101000020E6100000184339D1AE395240B4041901154E4B40
66517	5	53	929	61502	79260	\N	54.816363000000003	с. Сосновка, Школьная, 17	Россия, Омская область, Азовский Немецкий Национальный район, поселок Сосновка	0101000020E61000002429E961684952400D5531957E684B40
66516	5	53	929	30488	29298	\N	54.433731000000002	д. Сереброполье, Школьная, 37		0101000020E6100000F94CF6CFD34052407521567F84374B40
66441	5	53	929	60827	76427	\N	54.768189999999997	а. Сегизбай, Школьная, 3	Россия, Омская область, Азовский Немецкий Национальный район, поселок Сегизбай	0101000020E6100000C4263273813A52409F8EC70C54624B40
66035	5	53	929	7481	29986	\N	54.677447999999998	д. Руслановка, Российская, 10		0101000020E610000000AC8E1CE9365240CC5EB69DB6564B40
66523	5	53	929	53134	30175	\N	54.472665634501098	д. Роза Долина, Центральная, 40	Россия, Омская область, Азовский Немецкий Национальный район, поселок Розо-Долина	0101000020E6100000C310397D3D3C52402FF7C951803C4B40
66514	5	53	929	46237	29121	\N	54.431804	с. Пришиб, Центральная, 31		0101000020E6100000268FA7E50744524018247D5A45374B40
66510	5	53	929	30168	30015	\N	54.688648999999998	с. Привальное, Карла Маркса, 48		0101000020E6100000E014562AA83F524028B682A625584B40
66520	5	53	929	46380	29597	\N	54.864347000000002	д. Поповка, Школьная, 24А		0101000020E61000000874266DAA465240A7B228ECA26E4B40
66273	5	53	929	45992	29969	\N	54.678317	д. Пахомовка, Центральная, 51		0101000020E6100000899AE8F35149524011A96917D3564B40
66519	5	53	929	46363	29596	\N	54.760984000000001	д. Новинка, Ленина, 18		0101000020E610000060C77F8120495240BF6378EC67614B40
66518	5	53	929	46341	29047	\N	54.901164999999999	д. Мириная Долина, Ворошилова, 61		0101000020E610000058552FBFD344524061A6ED5F59734B40
66515	5	53	929	46266	29060	\N	54.507427	д. Кудук-Чилик, Центральная, 26	Россия, Омская область, Азовский Немецкий Национальный район, поселок Кудук-Чилик	0101000020E610000094DA8B683B475240BF0D315EF3404B40
66513	5	53	929	30341	29475	\N	54.749277999999997	д. Круч, Центральная, 15		0101000020E61000004BCB48BDA75752405FCE6C57E85F4B40
66512	5	53	929	30300	29187	\N	54.741733000000004	д. Кошкарево, Центральная, 17		0101000020E61000007DB3CD8DE954524097AE601BF15E4B40
66511	5	53	929	30244	29540	\N	54.690849999999998	с. Звонарев Кут, Школьная, 44		0101000020E610000054C6BFCFB85752408638D6C56D584B40
66468	5	53	929	51911	28677	\N	54.785325	д. Гауф, Школьная, 8		0101000020E610000055DFF9450959524098DD938785644B40
94871	5	52	\N	65	16641	\N	54.976410999999999	город Новосибирск, улица Первомайская, 206		0101000020E61000009FCC3FFA26C45440323A2009FB7C4B40
66127	5	53	929	53005	29464	\N	54.7947738096968	с. Березовка, Школьная, 1	Россия, Омская область, Азовский Немецкий Национальный район, поселок Березовка	0101000020E61000008313D1AFAD44524005DB8827BB654B40
66314	5	53	929	53117	30135	\N	54.638693434510401	д. Бердянка, Совхозная, 11	Россия, Омская область, Азовский Немецкий Национальный район, поселок Бердянка	0101000020E610000062F3716DA8465240929735B1C0514B40
67007	5	53	929	46941	\N	\N	54.558748999999999	д. Александровка, ул. Лесная, 51	Россия, Омская область, Азовский Немецкий Национальный район, поселок Александровка	0101000020E6100000687A89B14C3052401BD6541685474B40
65956	5	53	929	46941	29125	\N	54.558748999999999	с. Александровка, Советская, 39		0101000020E6100000687A89B14C3052401BD6541685474B40
66508	5	53	929	46051	30008	\N	54.7074	с. Азово, Советская, 22а		0101000020E6100000F7E5CC76854152405F984C158C5A4B40
66509	5	53	929	46051	29224	\N	54.7074	с. Азово, Бульвар Дружбы, 1		0101000020E6100000F7E5CC76854152405F984C158C5A4B40
66507	5	53	929	46051	29861	\N	54.7074	с. Азово, 40 лет Октября, 11		0101000020E6100000F7E5CC76854152405F984C158C5A4B40
66506	5	53	929	46051	29593	\N	54.704567016313803	с. Азово, 1 Мая, 19	Россия, Омская область, Азовский Немецкий Национальный район, поселок Азово	0101000020E61000001B49827005425240A06B5F402F5A4B40
64367	5	52	\N	59179	68860	\N	54.963206999999997	Новосибирская область, Доволенский район, Баклушевский с/с, п.Каревски, Первомайская, 13		0101000020E6100000191EFB592CC854409E23F25D4A7B4B40
65643	5	52	\N	59197	68980	\N	55.030824000000003	п. Сибиряк, улица Центральная, 12		0101000020E6100000573D601E32C2544049F7730AF2834B40
65349	5	52	\N	5332	\N	\N	55.218049999999998	"город Татарск, поселок Наливная станция, Дом культуры ""Нефтяник"""	Россия, Новосибирская область, Татарск	0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65341	5	52	\N	5332	\N	\N	55.218049999999998	город Татарск, Телегина, 52	Россия, Новосибирская область, Татарск	0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65339	5	52	\N	5332	\N	\N	55.218049999999998	город Татарск, Урицкого, 90	Россия, Новосибирская область, Татарск	0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65338	5	52	\N	5332	\N	\N	55.218049999999998	город Татарск, Ленина, 98	Россия, Новосибирская область, Татарск	0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65344	5	52	\N	5332	13905	\N	55.218049999999998	город Татарск, Школьный, 18		0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65346	5	52	\N	5332	13740	\N	55.217118113763902	город Татарск, Татарская, 12 А	Россия, Новосибирская область, Татарск	0101000020E6100000E0826C59BEFD5240BCAFCA85CA9B4B40
65343	5	52	\N	5332	13477	\N	55.2179889239912	город Татарск, Пушкина, 93	Россия, Новосибирская область, Татарск	0101000020E6100000B41CE8A1B6FD5240A2F14410E79B4B40
65334	5	52	\N	5332	15938	\N	55.218049999999998	город Татарск, Никишкиной, 2а		0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65347	5	52	\N	5332	13875	\N	55.217657700168502	город Татарск, Мичурина, 1	Россия, Новосибирская область, Татарск	0101000020E6100000A9DBD9571EFE52403CDBA337DC9B4B40
65342	5	52	\N	5332	13483	\N	55.218049999999998	город Татарск, Ленина, 33		0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65336	5	52	\N	5332	14153	\N	55.216676279992697	город Татарск, Комиссаровская, 24	Россия, Новосибирская область, Татарск	0101000020E610000070D234289AFD5240FFE9060ABC9B4B40
65337	5	52	\N	5332	13559	\N	55.216796232568299	город Татарск, Интернациональная, 21	Россия, Новосибирская область, Татарск	0101000020E6100000815F234910FE5240AAF3A8F8BF9B4B40
65335	5	52	\N	5332	15976	\N	55.218049999999998	город Татарск, Зеленая, 2	Россия, Новосибирская область, Татарск	0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65340	5	52	\N	5332	14159	\N	55.218344679827702	город Татарск, Закриевского, 87	Россия, Новосибирская область, Татарск	0101000020E6100000344C6DA983FD5240601F9DBAF29B4B40
65345	5	52	\N	5332	13872	\N	55.217461418078003	город Татарск, Аэродромная, 1 А	Россия, Новосибирская область, Татарск	0101000020E6100000815F234910FE5240E69315C3D59B4B40
65348	5	52	\N	5332	13744	\N	55.218049999999998	город Татарск, А. Матросова, 106		0101000020E6100000340EF5BBB0FD52404772F90FE99B4B40
65810	5	52	\N	15154	\N	\N	54.999470000000002	Новосибирская область, город Обь, административное здание ОПМС-19	Россия, Новосибирская область, Обь	0101000020E6100000F20A444FCAAC5440A4AA09A2EE7F4B40
65809	5	52	\N	15154	\N	\N	54.999470000000002	Новосибирская область, город Обь, Авиационная, 12	Россия, Новосибирская область, Обь	0101000020E6100000F20A444FCAAC5440A4AA09A2EE7F4B40
65808	5	52	\N	15154	\N	\N	54.9976548501038	Новосибирская область, город Обь, Толмачевская  средняя общеобразовательная школа №60	Россия, Новосибирская область, Обь	0101000020E61000001BBB44F5D6AC54406FD8B628B37F4B40
65803	5	52	\N	15154	\N	\N	54.999470000000002	Новосибирская область, город Обь, Вокзальная, 48	Россия, Новосибирская область, Обь	0101000020E6100000F20A444FCAAC5440A4AA09A2EE7F4B40
65805	5	52	\N	15154	13649	\N	54.990341005709503	Новосибирская область, город Обь, Шевченко, 11А	Россия, Новосибирская область, городской округ Обь	0101000020E61000001BA19FA9D7AC5440A8716F7EC37E4B40
65807	5	52	\N	15154	16514	\N	54.999470000000002	Новосибирская область, город Обь, ЖКО Аэропорта, 25/1		0101000020E6100000F20A444FCAAC5440A4AA09A2EE7F4B40
65806	5	52	\N	15154	13947	\N	54.999470000000002	Новосибирская область, город Обь, Геодезическая, 21		0101000020E6100000F20A444FCAAC5440A4AA09A2EE7F4B40
66091	5	52	\N	65	\N	\N	55.011592999999998	Новосибирская область, город Новосибирск, Октябрьский район, Татьяны Снежиной, 51	Россия, Новосибирская область, Новосибирск, Октябрьский район	0101000020E61000009605137F14C0544067EE21E17B814B40
65991	5	52	\N	65	\N	\N	54.995533999999999	Новосибирская область, город Новосибирск, Ленинский район, микрорайон Горский, 7	Россия, Новосибирская область, Новосибирск, Ленинский район, Горский микрорайон, 7	0101000020E610000057ED9A90D6B954402D077AA86D7F4B40
66104	5	52	\N	65	68126	\N	54.974519999999998	Новосибирская область, город Новосибирск, Первомайский район, улица Шмидта, 3		0101000020E6100000F5D901D715C5544022A64412BD7C4B40
65959	5	52	\N	65	16253	\N	54.972205000000002	Новосибирская область, город Новосибирск, Кировский район, Немировича-Данченко, 124	Россия, Новосибирская область, Новосибирск, Кировский район, улица Немировича-Данченко	0101000020E61000000395F1EF33B95440FC00A436717C4B40
66055	5	52	\N	65	14339	\N	54.985621003385397	Новосибирская область, город Новосибирск, Октябрьский район, Ключ-Камышенское плато, 1А	Россия, Новосибирская область, Новосибирск, улица Ключ-Камышенское Плато, 1а	0101000020E6100000CF83BBB376C254401BA034D4287E4B40
66076	5	52	\N	65	2476	\N	54.998184000000002	Новосибирская область, город Новосибирск, Октябрьский район, Кирова, 86	Россия, Новосибирская область, Новосибирск, улица Кирова	0101000020E61000001D3BA8C475C35440FBB1497EC47F4B40
66093	5	52	\N	65	13602	\N	55.047837000000001	Новосибирская область, город Новосибирск, Октябрьский район, Гусинобродский Тракт, а/я 139	Россия, Новосибирская область, Новосибирск, улица Гусинобродский Тракт	0101000020E61000006CED7DAA0AC55440F644D7851F864B40
65831	5	52	\N	65	15698	\N	55.050879999999999	Новосибирская область, город Новосибирск, Дзержинский район, Гоголя, 217	Россия, Новосибирская область, Новосибирск, Дзержинский район, улица Гоголя, 217	0101000020E61000003999B85510BE54409F02603C83864B40
66088	5	52	\N	65	2852	\N	55.029566143323002	Новосибирская область, город Новосибирск, Октябрьский район, В.Высоцкого, 1	Россия, Новосибирская область, Новосибирск, улица Владимира Высоцкого, 1	0101000020E6100000FF06EDD5C7C054406A8995D1C8834B40
66029	5	52	\N	65	13577	\N	54.964778000000003	Новосибирская область, город Новосибирск, Ленинский район, улица 9-й Гв.Дивизии, 6	Россия, Новосибирская область, Новосибирск, улица 9-й Гвардейской Дивизии, 6	0101000020E6100000EB55647440B654403DF372D87D7B4B40
65995	5	52	\N	65	1427	\N	54.987259999999999	Новосибирская область, город Новосибирск, Ленинский район, проспект К.Маркса, 31	Россия, Новосибирская область, Новосибирск, проспект Карла Маркса, 31	0101000020E61000000F45813E91B95440115322895E7E4B40
65994	5	52	\N	65	1427	\N	54.987259999999999	Новосибирская область, город Новосибирск, Ленинский район, проспект К. Маркса, 31	Россия, Новосибирская область, Новосибирск, проспект Карла Маркса, 31	0101000020E61000000F45813E91B95440115322895E7E4B40
65992	5	52	\N	65	1427	\N	54.988334000000002	Новосибирская область, город Новосибирск, Ленинский район, проспект К. Маркса, 35/1	Россия, Новосибирская область, Новосибирск, проспект Карла Маркса, 35/1	0101000020E6100000DECCE847C3B954402FC37FBA817E4B40
65856	5	52	\N	65	7755	\N	55.030504000000001	Новосибирская область, город Новосибирск, Железнодорожный район, проспект Димитрова, 4	Россия, Новосибирская область, Новосибирск, проспект Димитрова, 4	0101000020E610000056BB26A435BA5440D732198EE7834B40
94866	5	52	\N	65	75544	\N	55.028739000000002	"город Новосибирск, (здание военного сонатория ""Ельцовка"")"	Россия, Новосибирская область, Новосибирск, проспект Димитрова	0101000020E6100000E8F4BC1B0BBA5440548F34B8AD834B40
94864	5	52	\N	65	7429	\N	55.056651000000002	город Новосибирск, проспект Дзержинского, 34/1		0101000020E610000050711C78B5BE54409224085740874B40
65842	5	52	\N	65	7429	\N	55.062952000000003	Новосибирская область, город Новосибирск, Дзержинский район, проспект Дзержинского, 79	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 79	0101000020E6100000450F7C0C56BF5440E19BA6CF0E884B40
65841	5	52	\N	65	7429	\N	55.066014000000003	Новосибирская область, город Новосибирск, Дзержинский район, проспект Дзержинского, 60	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 60	0101000020E610000037A6272CF1BF5440018A912573884B40
65840	5	52	\N	65	7429	\N	55.056021999999999	Новосибирская область, город Новосибирск, Дзержинский район, проспект Дзержинского, 43	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 43	0101000020E61000004F965AEF37BE5440A2ED98BA2B874B40
65836	5	52	\N	65	7429	\N	55.043221000000003	Новосибирская область, город Новосибирск, Дзержинский район, проспект Дзержинского, 1	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 1	0101000020E61000007CEE04FBAFBC54400EC0064488854B40
65830	5	52	\N	65	7429	\N	55.054248000000001	Новосибирская область, город Новосибирск, Дзержинский район, проспект Дзержинского, 26	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 26	0101000020E610000048A8195245BE5440CCEF3499F1864B40
65828	5	52	\N	65	7429	\N	55.065179000000001	Новосибирская область, город Новосибирск, Дзержинский район, проспект Дзержинского, 83	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 83	0101000020E6100000BD55D7A19ABF544068B114C957884B40
66063	5	52	\N	65	68012	\N	55.013930999999999	Новосибирская область, город Новосибирск, Октябрьский район, Якушева, 21		0101000020E6100000F1D6F9B7CBBB544046B3B27DC8814B40
66178	5	52	\N	65	68315	\N	55.032933999999997	Новосибирская область, город Новосибирск, Центральный район, улица Ядринцевская, дом 46		0101000020E6100000CEA78E554ABB544096766A2E37844B40
66122	5	52	\N	65	68132	\N	54.860207000000003	Новосибирская область, город Новосибирск, Советский район, Энгельса, 6		0101000020E610000093AAED26F8BE5440286552431B6E4B40
66152	5	52	\N	65	68210	\N	54.885824	Новосибирская область, город Новосибирск, Советский район, Экваторная, 5		0101000020E61000002FE1D05B3CC6544086014BAE62714B40
66100	5	52	\N	65	68206	\N	54.970044999999999	Новосибирская область, город Новосибирск, Первомайский район, улица Эйхе, 1		0101000020E610000025E99AC937C65440FC523F6F2A7C4B40
64283	5	52	\N	65	68398	\N	55.001007999999999	Новосибирская область, Болотнинский район, Байкальский сельсовет, Школьная, 9		0101000020E6100000CE1C925A28B854406684B70721804B40
66000	5	52	\N	65	1569	\N	55.013069000000002	Новосибирская область, город Новосибирск, Ленинский район, улица Чулымская, 111	Россия, Новосибирская область, Новосибирск, Чулымская улица, 114	0101000020E6100000F1D6F9B7CBB85440B4CBB73EAC814B40
65968	5	52	\N	65	67970	\N	54.962432	Новосибирская область, город Новосибирск, Кировский район, Чигорина, 8		0101000020E6100000C7F0D8CF62BD5440DB4FC6F8307B4B40
66073	5	52	\N	65	68195	\N	55.01135	Новосибирская область, город Новосибирск, Октябрьский район, Чехова, 271		0101000020E61000002444F98216BE5440A167B3EA73814B40
65971	5	52	\N	65	68087	\N	54.954300000000003	Новосибирская область, город Новосибирск, Кировский район, Чемская, 38		0101000020E610000032AA0CE36EBD544052499D80267A4B40
66181	5	52	\N	65	68041	\N	55.026133000000002	Новосибирская область, город Новосибирск, Центральный район, улица Чаплыгина, дом 59		0101000020E6100000C16F438CD7BA5440562C7E5358834B40
94826	5	52	\N	65	3131	\N	54.937531	Усть-Таркский район, село Новый Силиш  , ул. Центральная, дом 2,	Россия, Новосибирская область, Новосибирск, Центральная улица, 2	0101000020E6100000A99F3715A9C454403BFE0B0401784B40
64596	5	52	250	\N	3131	\N	55.312179	аул Нижнебаяновский, улица Центральная, 24	Россия, Новосибирская область, Каргатский район	0101000020E6100000EF586C938A065440BEBF417BF5A74B40
64190	5	52	\N	65	3131	\N	54.937562	село Лепокурово, Центральная, 1б	Россия, Новосибирская область, Новосибирск, Центральная улица, 1	0101000020E61000005648F949B5C4544076FC170802784B40
65201	5	52	\N	65	14083	\N	55.107612257806601	НСО, Северный район, Гражданцевский сельсовет, д. Ударник, Центральная, 14	Россия, Новосибирская область, Новосибирск, дачные участки управления по НСО	0101000020E6100000828DEBDFF5B354401E54E23AC68D4B40
64277	5	52	\N	65	14083	\N	54.934804999999997	Новосибирская область, Болотнинский район, Варламовский сельсовет, Центральная, 27а		0101000020E6100000184339D1AEC454409291B3B0A7774B40
66025	5	52	\N	65	68181	\N	54.950836000000002	Новосибирская область, город Новосибирск, Ленинский район, улица Хилокская, 4		0101000020E6100000A514747B49B5544003EE79FEB4794B40
66019	5	52	\N	65	68180	\N	54.985674000000003	Новосибирская область, город Новосибирск, Ленинский район, улица Халтурина, 30/1		0101000020E6100000C34659BF99B454403E42CD902A7E4B40
66180	5	52	\N	65	16662	\N	55.036802999999999	Новосибирская область, город Новосибирск, Центральный район, улица Фрунзе, дом 5/3		0101000020E61000000B2AAA7EA5BA544085B2F0F5B5844B40
66165	5	52	\N	65	16662	\N	55.039718000000001	Новосибирская область, город Новосибирск, Центральный район, улица Фрунзе, дом 57А		0101000020E61000000EA0DFF76FBC54400188BB7A15854B40
66159	5	52	\N	65	16662	\N	55.038516000000001	Новосибирская область, город Новосибирск, Центральный район, улица Фрунзе, дом 53		0101000020E610000097395D1613BC5440B62FA017EE844B40
66155	5	52	\N	65	16662	\N	55.037649999999999	Новосибирская область, город Новосибирск, Центральный район, улица Фрунзе, дом 96		0101000020E61000003FC8B260E2BB5440E25817B7D1844B40
65941	5	52	\N	65	16659	\N	55.171149739694897	Новосибирская область, город Новосибирск, Калининский район, Флотская, 21А	Россия, Новосибирская область, Новосибирск, Флотская улица	0101000020E61000004A7D59DAA9BF5440EE5A423EE8954B40
66011	5	52	\N	65	67990	\N	54.989367000000001	Новосибирская область, город Новосибирск, Ленинский район, улица Филатова, 9		0101000020E6100000AEB9A3FFE5B45440EE5EEE93A37E4B40
66102	5	52	\N	65	68022	\N	54.975816999999999	Новосибирская область, город Новосибирск, Первомайский район, улица Физкультурная, 16А		0101000020E6100000AB75E272BCC55440BFF04A92E77C4B40
66079	5	52	\N	65	68295	\N	55.030116999999997	Новосибирская область, город Новосибирск, Октябрьский район, Федосеева, 38		0101000020E6100000327381CB63BE5440DD06B5DFDA834B40
65853	5	52	\N	65	68228	\N	55.017710000000001	Новосибирская область, город Новосибирск, Железнодорожный район, Фабричная, 8		0101000020E61000004B395FECBDBA5440F5673F5244824B40
65924	5	52	\N	65	67962	\N	55.082756000000003	Новосибирская область, город Новосибирск, Калининский район, Учительская, 42		0101000020E6100000D1967329AEBD54401EC6A4BF978A4B40
66151	5	52	\N	65	68209	\N	54.833086000000002	Новосибирская область, город Новосибирск, Советский район, Ученых, 10		0101000020E61000009813B4C9E1C65440B360E28FA26A4B40
66118	5	52	\N	65	68130	\N	54.940277000000002	Новосибирская область, город Новосибирск, Первомайский район, улица Ученическая, 8		0101000020E6100000B1F84D61A5C754402B172AFF5A784B40
65967	5	52	\N	65	68122	\N	54.965052	Новосибирская область, город Новосибирск, Кировский район, Урманова, 26		0101000020E610000094F59B89E9BC54403E78EDD2867B4B40
66115	5	52	\N	65	67778	\N	54.924511000000003	Новосибирская область, город Новосибирск, Первомайский район, улица Узорная, 1/2		0101000020E610000001DF6DDE38C5544069E55E6056764B40
66049	5	52	\N	65	68290	\N	54.966163000000002	Новосибирская область, город Новосибирск, Ленинский район, улица Ударная, 21		0101000020E6100000177E703E75B7544079CDAB3AAB7B4B40
66074	5	52	\N	65	68102	\N	55.012521999999997	Новосибирская область, город Новосибирск, Октябрьский район, Тургенева, 202		0101000020E61000008ECD8E54DFBD5440813D26529A814B40
66068	5	52	\N	65	68102	\N	55.019908999999998	Новосибирская область, город Новосибирск, Октябрьский район, Тургенева, 84		0101000020E610000086E63A8DB4BC5440B2F2CB608C824B40
65960	5	52	\N	65	68317	\N	54.977217000000003	Новосибирская область, город Новосибирск, Кировский район, Тульская, 86		0101000020E61000008E1F2A8D98BA5440310C5872157D4B40
66144	5	52	\N	65	68217	\N	54.849074000000002	Новосибирская область, город Новосибирск, Советский район, Тружеников, 16а		0101000020E6100000861F9C4F1DC3544024F1F274AE6C4B40
66078	5	52	\N	65	68198	\N	55.032128999999998	Новосибирская область, город Новосибирск, Октябрьский район, Тополевая, 31		0101000020E6100000C139234A7BBC5440682096CD1C844B40
66037	5	52	\N	65	68002	\N	54.982016999999999	Новосибирская область, город Новосибирск, Ленинский район, улица Титова, 7		0101000020E61000000A100533A6B85440DA8EA9BBB27D4B40
66026	5	52	\N	65	68002	\N	54.981530999999997	Новосибирская область, город Новосибирск, Ленинский район, улица Титова, 94		0101000020E610000092B245D26EB654404D81CCCEA27D4B40
66024	5	52	\N	65	68002	\N	54.979382000000001	Новосибирская область, город Новосибирск, Ленинский район, улица Титова, 43/2		0101000020E61000001938A0A52BB754404225AE635C7D4B40
65893	5	52	\N	65	16645	\N	55.059415000000001	Новосибирская область, город Новосибирск, Заельцовский район, Тимирязева, 81А		0101000020E61000002AE3DF675CB9544028F224E99A874B40
65891	5	52	\N	65	16645	\N	55.050953	Новосибирская область, город Новосибирск, Заельцовский район, Тимирязева, 2		0101000020E610000061A6ED5F59B854400951BEA085864B40
65885	5	52	\N	65	16645	\N	55.051762629864101	Новосибирская область, город Новосибирск, Заельцовский район, Тимирязева, 5	Россия, Новосибирская область, Новосибирск, улица Тимирязева	0101000020E61000009E40D82956B854404912842BA0864B40
65823	5	52	\N	65	68050	\N	55.070242	Новосибирская область, город Новосибирск, Дзержинский район, Театральная, 1		0101000020E6100000E3FF8EA850BE54401F679AB0FD884B40
65916	5	52	\N	65	68065	\N	55.061616999999998	Новосибирская область, город Новосибирск, Калининский район, Танковая, 9/1		0101000020E6100000E833A0DE8CBB544056F0DB10E3874B40
65928	5	52	\N	65	67815	\N	55.102100999999998	Новосибирская область, город Новосибирск, Калининский район, Столетова, 22		0101000020E61000000723F609A0BD5440C7F143A5118D4B40
66046	5	52	\N	65	68286	\N	54.977434000000002	Новосибирская область, город Новосибирск, Ленинский район, улица Степная, 57		0101000020E61000000E83F92B64B75440CEFFAB8E1C7D4B40
66003	5	52	\N	65	68411	\N	54.998907000000003	Новосибирская область, город Новосибирск, Ленинский район, улица Станционная, 8а		0101000020E6100000EBC9FCA36FB754406C5F402FDC7F4B40
66005	5	52	\N	65	67982	\N	54.99682	Новосибирская область, город Новосибирск, Ленинский район, улица Станционная, 50/1		0101000020E61000000CE71A6668B55440D6FF39CC977F4B40
66047	5	52	\N	65	16646	\N	54.973072999999999	Новосибирская область, город Новосибирск, Ленинский район, улица Станиславского, 30		0101000020E6100000F20A444FCAB7544070CFF3A78D7C4B40
66040	5	52	\N	65	16646	\N	54.979272999999999	Новосибирская область, город Новосибирск, Ленинский район, улица Станиславского, 23		0101000020E610000031957EC2D9B754408B6D52D1587D4B40
66023	5	52	\N	65	16646	\N	54.993608000000002	Новосибирская область, город Новосибирск, Ленинский район, улица Станиславского, 2/1		0101000020E6100000412E71E481B75440A185048C2E7F4B40
66020	5	52	\N	65	16646	\N	54.988137999999999	Новосибирская область, город Новосибирск, Ленинский район, улица Станиславского, 6б		0101000020E6100000F9D85DA0A4B75440A9F7544E7B7E4B40
65947	5	52	\N	65	16646	\N	54.967497000000002	Новосибирская область, город Новосибирск, Кировский район, Станиславского, 33		0101000020E610000069C9E369F9B7544033FD12F1D67B4B40
65890	5	52	\N	65	68069	\N	55.051824000000003	Новосибирская область, город Новосибирск, Заельцовский район, Союза Молодежи, 10		0101000020E61000002504ABEAE5B85440EF92382BA2864B40
65944	5	52	\N	65	68099	\N	55.158096999999998	Новосибирская область, город Новосибирск, Калининский район, Солидарности, 71Б		0101000020E6100000916456EF70BD5440404CC2853C944B40
65942	5	52	\N	65	68099	\N	55.157392000000002	Новосибирская область, город Новосибирск, Калининский район, Солидарности, 65		0101000020E610000047054EB681BD54407653CA6B25944B40
65869	5	52	\N	65	16657	\N	55.034393999999999	Новосибирская область, город Новосибирск, Железнодорожный район, Советская, 63		0101000020E61000005DDC460378BA5440DD96C80567844B40
65852	5	52	\N	65	16657	\N	55.042657046789799	Новосибирская область, город Новосибирск, Железнодорожный район, Советская, 93	Россия, Новосибирская область, Новосибирск, Советская улица	0101000020E61000008FDFDBF467BA544005F9D9C875854B40
64308	5	52	\N	65	16657	\N	55.027082	Новосибирская область, Болотнинский район, Новобибеевский сельсовет, Советская, 29а		0101000020E6100000EFE3688EACBA5440B727486C77834B40
64302	5	52	\N	65	16657	\N	55.032680999999997	Новосибирская область, Болотнинский район, Егоровский сельсовет, Советская, 1		0101000020E6100000423EE8D9ACBA5440AC1919E42E844B40
65985	5	52	\N	65	68263	\N	54.940255999999998	Новосибирская область, город Новосибирск, Кировский район, Сибиряков-Гвардейцев, 58		0101000020E610000060C77F8120B9544013EF004F5A784B40
65870	5	52	\N	65	67827	\N	55.035395000000001	Новосибирская область, город Новосибирск, Железнодорожный район, Сибирская, 30		0101000020E610000027F73B1405BA544091B8C7D287844B40
65854	5	52	\N	65	67812	\N	55.036436999999999	Новосибирская область, город Новосибирск, Железнодорожный район, Сибирская, 35		0101000020E61000006CED7DAA0ABA5440A3AEB5F7A9844B40
66169	5	52	\N	65	68038	\N	55.016848000000003	Новосибирская область, город Новосибирск, Центральный район, улица Серебренниковская, дом 2/1		0101000020E610000089D4B48B69BB54406380441328824B40
66172	5	52	\N	65	68039	\N	55.027107999999998	Новосибирская область, город Новосибирск, Центральный район, улица Серебренниковская, дом 36		0101000020E6100000266E15C440BB5440E0BA624678834B40
66170	5	52	\N	65	68039	\N	55.019831000000003	Новосибирская область, город Новосибирск, Центральный район, улица Серебренниковская, дом 10		0101000020E61000002D077AA86DBB544037397CD289824B40
65835	5	52	\N	65	68057	\N	55.045273999999999	Новосибирская область, город Новосибирск, Дзержинский район, Селезнева, 46		0101000020E6100000952A51F696BC5440F7ADD689CB854B40
65906	5	52	\N	65	68075	\N	55.073314000000003	Новосибирская область, город Новосибирск, Заельцовский район, Северная, 1		0101000020E610000024B6BB07E8BA5440632B685A62894B40
65904	5	52	\N	65	68075	\N	55.066060999999998	Новосибирская область, город Новосибирск, Заельцовский район, Северная, 31		0101000020E6100000E3E2A8DC44B954404145D5AF74884B40
66030	5	52	\N	65	68093	\N	54.965702999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Связистов, 135		0101000020E6100000B476DB85E6B554401553E9279C7B4B40
65863	5	52	\N	65	68233	\N	55.037717000000001	Новосибирская область, город Новосибирск, Железнодорожный район, Саратовская, 24а		0101000020E610000019541B9C88B854406AC020E9D3844B40
66064	5	52	\N	65	68107	\N	55.016269999999999	Новосибирская область, город Новосибирск, Октябрьский район, Садовая, 26		0101000020E6100000897AC1A739BC5440F5F3A62215824B40
65970	5	52	\N	65	67972	\N	54.957619000000001	Новосибирская область, город Новосибирск, Кировский район, Саввы Кожевникова, 21		0101000020E6100000A9BEF38B12BE54409D836742937A4B40
65969	5	52	\N	65	67972	\N	54.958280999999999	Новосибирская область, город Новосибирск, Кировский район, Саввы Кожевникова, 21/1		0101000020E61000007539252026BE544068B0A9F3A87A4B40
66145	5	52	\N	65	68309	\N	54.846291000000001	Новосибирская область, город Новосибирск, Советский район, Русская, 35		0101000020E610000054A703594FC3544017F37343536C4B40
66147	5	52	\N	65	68208	\N	54.845010000000002	Новосибирская область, город Новосибирск, Советский район, Русская, 1а		0101000020E61000008BE07F2BD9C254408065A549296C4B40
66142	5	52	\N	65	68134	\N	54.867066999999999	Новосибирская область, город Новосибирск, Советский район, Российская, 3		0101000020E610000068AF3E1EFAC554406D382C0DFC6E4B40
66179	5	52	\N	65	68040	\N	55.034419999999997	Новосибирская область, город Новосибирск, Центральный район, улица Романова, дом 23		0101000020E61000003C4A253CA1BA5440062AE3DF67844B40
65937	5	52	\N	65	67838	\N	55.111170999999999	Новосибирская область, город Новосибирск, Родники, 4		0101000020E6100000FCFF3861C2BC5440BEA1F0D93A8E4B40
66038	5	52	\N	65	68285	\N	54.976173000000003	Новосибирская область, город Новосибирск, Ленинский район, улица Римского-Корсакова, 22		0101000020E61000008D08C6C1A5B854407E1EA33CF37C4B40
65949	5	52	\N	65	68285	\N	54.97795	Новосибирская область, город Новосибирск, Кировский район, Римского-Корсакова, 13		0101000020E61000006077BAF3C4B85440C58F31772D7D4B40
65822	5	52	\N	65	68225	\N	55.068241	Новосибирская область, город Новосибирск, Дзержинский район, Республиканская, 15/1		0101000020E61000003BFBCA83F4BD5440889FFF1EBC884B40
66083	5	52	\N	65	68296	\N	55.027082	Новосибирская область, город Новосибирск, Октябрьский район, Радиотехническая, 57А		0101000020E6100000083A5AD592BF5440B727486C77834B40
65838	5	52	\N	65	68152	\N	55.052985	Новосибирская область, город Новосибирск, Дзержинский район, Промышленная, 1/1		0101000020E61000001CD3139678BD5440DB166536C8864B40
65322	5	52	\N	65	68848	\N	54.951993999999999	д. Чинявино, Приозёрная, 11 А		0101000020E61000009BC8CC052EC754407EFE7BF0DA794B40
66123	5	52	\N	65	68028	\N	54.856807000000003	Новосибирская область, город Новосибирск, Советский район, Приморская, 3		0101000020E610000020D099B4A9BE5440F0FD0DDAAB6D4B40
66114	5	52	\N	65	3179	\N	54.936971999999997	Новосибирская область, город Новосибирск, Первомайский район, переулок Прибрежный, 9	Россия, Новосибирская область, Новосибирск, Прибрежный переулок, 9	0101000020E6100000F96A47718EC4544044A2D0B2EE774B40
66016	5	52	\N	65	67776	\N	54.991329999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Порт-Артурская, 1а		0101000020E6100000552FBFD364B3544097C5C4E6E37E4B40
65817	5	52	\N	65	68221	\N	55.074319000000003	Новосибирская область, город Новосибирск, Дзержинский район, Полякова, 1в		0101000020E6100000EB7420EBA9C25440583CF54883894B40
66133	5	52	\N	65	68311	\N	54.866622	Новосибирская область, город Новосибирск, Советский район, Полевая, 5		0101000020E6100000A54A94BDA5C654403FFF3D78ED6E4B40
66041	5	52	\N	65	68095	\N	54.985385000000001	Новосибирская область, город Новосибирск, Ленинский район, улица Плахотного, 31		0101000020E61000003621AD31E8B75440077C7E18217E4B40
66032	5	52	\N	65	68095	\N	54.986387000000001	Новосибирская область, город Новосибирск, Ленинский район, улица Плахотного, 10		0101000020E6100000E2AB1DC539B754408B19E1ED417E4B40
65999	5	52	\N	65	67980	\N	54.995916999999999	Новосибирская область, город Новосибирск, Ленинский район, улица Планировочная, 7/2		0101000020E610000022A7AFE76BB85440E54350357A7F4B40
65998	5	52	\N	65	67980	\N	54.994965999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Планировочная, 7		0101000020E6100000DEB06D5166B85440E350BF0B5B7F4B40
66119	5	52	\N	65	16647	\N	54.953985000000003	Новосибирская область, город Новосибирск, Первомайский район, улица Пихтовая, 44		0101000020E610000050E1085229C75440F2EF332E1C7A4B40
66138	5	52	\N	65	75541	\N	54.847135999999999	Новосибирская область, город Новосибирск, Советский район, Пирогова, 10		0101000020E610000048FAB48AFEC55440D3A1D3F36E6C4B40
65975	5	52	\N	65	68089	\N	54.938445999999999	Новосибирская область, город Новосибирск, Кировский район, Петухова, 100		0101000020E610000024B9FC87F4BA5440F0879FFF1E784B40
66120	5	52	\N	65	2964	\N	54.9616419379661	Новосибирская область, город Новосибирск, Первомайский район, улица Первомайская, 1	Россия, Новосибирская область, Новосибирск, Первомайская улица	0101000020E6100000C5AEEDED96C85440E23AC615177B4B40
66106	5	52	\N	65	68042	\N	54.975144999999998	Новосибирская область, город Новосибирск, Первомайский район, улица Первомайская, 202		0101000020E610000031B1F9B836C45440D0ED258DD17C4B40
66103	5	52	\N	65	68042	\N	54.972897000000003	Новосибирская область, город Новосибирск, Первомайский район, улица Первомайская, 174		0101000020E61000003561FBC918C5544032B08EE3877C4B40
66110	5	52	\N	65	16641	\N	54.968871	Новосибирская область, город Новосибирск, Первомайский район, улица Первомайская, 236		0101000020E61000003961C26856C654407B8505F7037C4B40
66099	5	52	\N	65	16641	\N	54.966003000000001	Новосибирская область, город Новосибирск, Первомайский район, улица Первомайская, 96		0101000020E610000078B7B24467C75440406B7EFCA57B4B40
66098	5	52	\N	65	16641	\N	54.965223000000002	Новосибирская область, город Новосибирск, Первомайский район, улица Первомайская, 82		0101000020E61000007216F6B4C3C754406B2C616D8C7B4B40
66042	5	52	\N	65	68188	\N	54.988799	Новосибирская область, город Новосибирск, Ленинский район, улица Пархоменко, 2		0101000020E61000006F0D6C9560B85440A4A833F7907E4B40
66094	5	52	\N	65	68205	\N	55.022469000000001	Новосибирская область, город Новосибирск, Октябрьский район, Панфиловцев, 41		0101000020E610000073D87DC7F0BE54404016A243E0824B40
65986	5	52	\N	65	67976	\N	54.947392999999998	Новосибирская область, город Новосибирск, Кировский район, Палласа, 28		0101000020E6100000AE122C0E67B85440CBBA7F2C44794B40
65910	5	52	\N	65	67901	\N	55.120331	Новосибирская область, город Новосибирск, Заельцовский район, Охотская, 84		0101000020E61000001C2444F982B95440F5D89601678F4B40
66174	5	52	\N	65	68062	\N	55.026107000000003	Новосибирская область, город Новосибирск, Центральный район, улица Октябрьская, дом 89А		0101000020E6100000F3380CE6AFBB54402D99637957834B40
65865	5	52	\N	65	68062	\N	55.023933999999997	Новосибирская область, город Новосибирск, Железнодорожный район, Октябрьская, 5		0101000020E61000000E66136058BA544098A1F14410834B40
66116	5	52	\N	65	68027	\N	54.939103000000003	Новосибирская область, город Новосибирск, Первомайский район, улица Одоевского, 1		0101000020E6100000E831CA332FC75440AA49F08634784B40
65926	5	52	\N	65	67966	\N	55.094811999999997	Новосибирская область, город Новосибирск, Калининский район, Объединения, 82/2		0101000020E6100000BF4868CBB9BD544059A2B3CC228C4B40
65939	5	52	\N	65	67840	\N	55.173504000000001	Новосибирская область, город Новосибирск, Калининский район, Новоуральская, 11/3		0101000020E61000000BB5A679C7BD5440D3DC0A6135964B40
65938	5	52	\N	65	67840	\N	55.177010000000003	Новосибирская область, город Новосибирск, Калининский район, Новоуральская, 21		0101000020E61000001CD0D2156CBD544051888043A8964B40
66128	5	52	\N	65	68322	\N	54.850422000000002	Новосибирская область, город Новосибирск, Советский район, Новоморская, 12		0101000020E61000004DBC033C69BE544043E6CAA0DA6C4B40
65958	5	52	\N	65	68115	\N	54.982027000000002	Новосибирская область, город Новосибирск, Кировский район, Новогодняя, 20/2		0101000020E61000000057B26323BA5440FE648C0FB37D4B40
65957	5	52	\N	65	68115	\N	54.981406999999997	Новосибирская область, город Новосибирск, Кировский район, Новогодняя, 14/1		0101000020E6100000F758FAD005BA544061889CBE9E7D4B40
65925	5	52	\N	65	68255	\N	55.078870000000002	Новосибирская область, город Новосибирск, Калининский район, Новая Заря, 27		0101000020E61000000514EAE923BE544059518369188A4B40
66056	5	52	\N	65	68293	\N	55.006341999999997	Новосибирская область, город Новосибирск, Октябрьский район, Никитина, 2		0101000020E6100000E2E6543200BD5440AD4B8DD0CF804B40
66048	5	52	\N	65	68288	\N	54.968209999999999	Новосибирская область, город Новосибирск, Ленинский район, улица Немировича-Данченко, 20/2		0101000020E6100000B2D826158DB7544080D4264EEE7B4B40
65953	5	52	\N	65	16635	\N	54.973579460387199	Новосибирская область, город Новосибирск, Кировский район, Немировича-Данченко, 137/1	Россия, Новосибирская область, Новосибирск, Ленинский район, улица Немировича-Данченко, 137/1	0101000020E6100000E23E726BD2B954404489963C9E7C4B40
65951	5	52	\N	65	16635	\N	54.972493256198298	Новосибирская область, город Новосибирск, Кировский район, Немировича-Данченко, 121	Россия, Новосибирская область, Новосибирск, Ленинский район, улица Немировича-Данченко, 121	0101000020E6100000583A1F9E25B95440624B8FA67A7C4B40
65952	5	52	\N	65	16636	\N	54.970382479582597	Новосибирская область, город Новосибирск, Кировский район, Немировича-Данченко, 102/2	Россия, Новосибирская область, Новосибирск, Ленинский район, улица Немировича-Данченко, 102/2	0101000020E6100000656D533C2EB954404450357A357C4B40
66167	5	52	\N	65	68141	\N	55.046187000000003	Новосибирская область, город Новосибирск, Центральный район, улица Некрасова, дом 82		0101000020E6100000D32EA699EEBB54400C40A374E9854B40
66166	5	52	\N	65	68141	\N	55.046280000000003	Новосибирская область, город Новосибирск, Центральный район, улица Некрасова, дом 84		0101000020E610000036751E15FFBB5440BD3AC780EC854B40
66161	5	52	\N	65	68141	\N	55.044195999999999	Новосибирская область, город Новосибирск, Центральный район, улица Некрасова, дом 4		0101000020E61000001684F23E8EBA5440984EEB36A8854B40
66014	5	52	\N	65	68273	\N	54.990741	Новосибирская область, город Новосибирск, Ленинский район, улица Невельского, 53/1		0101000020E6100000AA0CE36E10B4544036E7E099D07E4B40
65915	5	52	\N	65	68250	\N	55.079194999999999	Новосибирская область, город Новосибирск, Калининский район, Народная, 67		0101000020E610000012A3E716BABD5440DC80CF0F238A4B40
65918	5	52	\N	65	68164	\N	55.072149000000003	Новосибирская область, город Новосибирск, Калининский район, Народная, 37		0101000020E61000006F2F698CD6BC544035B8AD2D3C894B40
65917	5	52	\N	65	68164	\N	55.065818999999998	Новосибирская область, город Новосибирск, Калининский район, Народная, 11		0101000020E610000045847F1134BC54404B3ACAC16C884B40
66001	5	52	\N	65	68007	\N	55.017333000000001	Новосибирская область, город Новосибирск, Ленинский район, улица Моторная, 16		0101000020E6100000577C43E1B3B854401F12BEF737824B40
66135	5	52	\N	65	3447	\N	54.835833999999998	Новосибирская область, город Новосибирск, Советский район, проспект Морской, 23	Россия, Новосибирская область, Новосибирск, Морской проспект, 23	0101000020E6100000C0EB33677DC654404371C79BFC6A4B40
66121	5	52	\N	65	68304	\N	54.857823000000003	Новосибирская область, город Новосибирск, Советский район, Молодости, 15		0101000020E610000001A60C1CD0BE5440D960E124CD6D4B40
65964	5	52	\N	65	68177	\N	54.963450000000002	Новосибирская область, город Новосибирск, Кировский район, Мира, 14		0101000020E6100000F06AB93313BA544065AA6054527B4B40
65963	5	52	\N	65	68177	\N	54.964953999999999	Новосибирская область, город Новосибирск, Кировский район, Мира, 1		0101000020E6100000F9122A38BCB954407B12D89C837B4B40
65929	5	52	\N	65	68257	\N	55.101154000000001	Новосибирская область, город Новосибирск, Калининский район, Макаренко, 25/1		0101000020E6100000FF7A8505F7BD544007EE409DF28C4B40
65927	5	52	\N	65	68257	\N	55.098078000000001	Новосибирская область, город Новосибирск, Калининский район, Макаренко, 28		0101000020E610000024F1F274AEBD5440823AE5D18D8C4B40
65940	5	52	\N	65	68306	\N	55.163666999999997	Новосибирская область, город Новосибирск, Калининский район, Магистральная, 16		0101000020E6100000A1BE654E97BE54409B374E0AF3944B40
65907	5	52	\N	65	67897	\N	55.075968000000003	Новосибирская область, город Новосибирск, Заельцовский район, Магаданская, 2А		0101000020E6100000CA332F87DDBB544072C5C551B9894B40
66139	5	52	\N	65	68045	\N	54.861061999999997	Новосибирская область, город Новосибирск, Советский район, Лыкова, 4		0101000020E61000004C16F71F99C5544007EA9447376E4B40
65847	5	52	\N	65	68060	\N	55.043427000000001	Новосибирская область, город Новосибирск, Дзержинский район, Липецкая, 25/2		0101000020E6100000F487669E5CC05440B76114048F854B40
65883	5	52	\N	65	67830	\N	55.050503999999997	Новосибирская область, город Новосибирск, Заельцовский район, Линейная, 33/4		0101000020E6100000581AF8510DBA5440992842EA76864B40
65876	5	52	\N	65	67830	\N	55.053784	Новосибирская область, город Новосибирск, Заельцовский район, Линейная, 223		0101000020E6100000D76D50FBADBB54402786E464E2864B40
66153	5	52	\N	65	68138	\N	54.890017999999998	Новосибирская область, город Новосибирск, Советский район, Лесосечная, 4		0101000020E6100000C845B58828C55440F86C1D1CEC714B40
65519	5	52	\N	65	75579	\N	54.811238000000003	дер. Майск  , ул. Лесная, дом 1\\2,		0101000020E6100000E3A9471ADCC55440E0A293A5D6674B40
66070	5	52	\N	65	68016	\N	55.014226000000001	Новосибирская область, город Новосибирск, Октябрьский район, Ленинградская, 113		0101000020E6100000DBC35E2860BD54405F605628D2814B40
65909	5	52	\N	65	16595	\N	55.082942495726101	Новосибирская область, город Новосибирск, Заельцовский район, Лебедевского, 1		0101000020E6100000857CD0B359BB544080BBECD79D8A4B40
66087	5	52	\N	65	68020	\N	55.032015000000001	Новосибирская область, город Новосибирск, Октябрьский район, Лазурная, 10/1		0101000020E610000063D34A2190C05440A0FD481119844B40
66090	5	52	\N	65	68298	\N	55.035158000000003	Новосибирская область, город Новосибирск, Октябрьский район, Лазурная, 27		0101000020E61000001F8315A75AC15440AD18AE0E80844B40
65931	5	52	\N	65	68305	\N	55.107607000000002	Новосибирская область, город Новосибирск, Калининский район, Курчатова, 37/1		0101000020E610000047AD307DAFBD54400CE9F010C68D4B40
66028	5	52	\N	65	68183	\N	54.972365000000003	Новосибирская область, город Новосибирск, Ленинский район, улица Курганская, 36а		0101000020E6100000D13E56F0DBB554403563D174767C4B40
65851	5	52	\N	65	68052	\N	55.045037000000001	Новосибирская область, город Новосибирск, Дзержинский район, Куприна, 4		0101000020E6100000BF0F070951BF5440130EBDC5C3854B40
65871	5	52	\N	65	68237	\N	55.128439	Новосибирская область, город Новосибирск, Заельцовский район, Кубовая, 107/1		0101000020E61000008E5BCCCF0DB95440F6436CB070904B40
65911	5	52	\N	65	68244	\N	55.123244999999997	Новосибирская область, город Новосибирск, Заельцовский район, Кубовая, 47Б		0101000020E6100000EDD808C4EBB95440A032FE7DC68F4B40
65862	5	52	\N	65	68230	\N	55.028806000000003	Новосибирская область, город Новосибирск, Железнодорожный район, Кубановская, 17а		0101000020E6100000EFC7ED974FB95440DCF63DEAAF834B40
66156	5	52	\N	65	68212	\N	55.040028	Новосибирская область, город Новосибирск, Центральный район, улица Крылова, дом 18		0101000020E6100000F986C267EBBA54404F7633A31F854B40
65912	5	52	\N	65	67832	\N	55.056274999999999	Новосибирская область, город Новосибирск, Калининский район, Кропоткина, 132/2		0101000020E6100000F3599E0777BC54408C4AEA0434874B40
65879	5	52	\N	65	67832	\N	55.053665000000002	Новосибирская область, город Новосибирск, Заельцовский район, Кропоткина, 110		0101000020E610000055D97745F0BA54404DF8A57EDE864B40
65878	5	52	\N	65	67832	\N	55.055202000000001	Новосибирская область, город Новосибирск, Заельцовский район, Кропоткина, 119		0101000020E61000003198BF42E6BA54403F56F0DB10874B40
65875	5	52	\N	65	67832	\N	55.057687999999999	Новосибирская область, город Новосибирск, Заельцовский район, Кропоткина, 265		0101000020E61000001650A8A78FBB544092AF045262874B40
65874	5	52	\N	65	67832	\N	55.054355999999999	Новосибирская область, город Новосибирск, Заельцовский район, Кропоткина, 126/2		0101000020E6100000A2EBC20FCEBB5440B22B2D23F5864B40
65934	5	52	\N	65	69028	\N	55.112386000000001	новосибирск, улица Красных Зорь, 7		0101000020E61000000821205F42BE54409E4319AA628E4B40
66183	5	52	\N	65	29	\N	55.016022	Новосибирская область, город Новосибирск, Центральный район, проспект Красный, дом 4	Россия, Новосибирская область, Новосибирск, Красный проспект, 4	0101000020E610000064EB19C231BB54401D0247020D824B40
66182	5	52	\N	65	29	\N	55.046981000000002	Новосибирская область, город Новосибирск, Центральный район, проспект Красный, дом 75	Россия, Новосибирская область, Новосибирск, Красный проспект, 75	0101000020E6100000334FAE2990BA54404644317903864B40
66162	5	52	\N	65	29	\N	55.043953000000002	Новосибирская область, город Новосибирск, Центральный район, проспект Красный, дом 72	Россия, Новосибирская область, Новосибирск, Красный проспект, 72	0101000020E61000009A249694BBBA5440D2C77C40A0854B40
47372	5	49	\N	1225	73328	\N	56.007866	г. Красноярск Сурикова 2		0101000020E6100000AFE94141293857400B60CAC001014C40
66154	5	52	\N	65	29	\N	55.034157	Новосибирская область, город Новосибирск, Центральный район, проспект Красный, дом 48	Россия, Новосибирская область, Новосибирск, Красный проспект, 48	0101000020E61000001BBE8575E3BA5440F9F6AE415F844B40
65902	5	52	\N	65	29	\N	55.066637999999998	Новосибирская область, город Новосибирск, Заельцовский район, Красный проспект, 171/4	Россия, Новосибирская область, Новосибирск, Красный проспект, 171/4	0101000020E6100000680932022ABA5440DE550F9887884B40
65901	5	52	\N	65	29	\N	55.064323000000002	Новосибирская область, город Новосибирск, Заельцовский район, Красный проспект, 167	Россия, Новосибирская область, Новосибирск, Красный проспект, 167	0101000020E610000014CFD90242BA5440B8B06EBC3B884B40
65882	5	52	\N	65	29	\N	55.056975999999999	Новосибирская область, город Новосибирск, Заельцовский район, Красный проспект, 153	Россия, Новосибирская область, Новосибирск, Красный проспект, 153	0101000020E6100000A1478C9E5BBA5440155454FD4A874B40
65880	5	52	\N	65	29	\N	55.051917000000003	Новосибирская область, город Новосибирск, Заельцовский район, Красный проспект, 83/1	Россия, Новосибирская область, Новосибирск, Красный проспект, 83/1	0101000020E610000086014BAE62BA5440A08D5C37A5864B40
66129	5	52	\N	65	68031	\N	54.850769	Новосибирская область, город Новосибирск, Советский район, Красноуфимская, 8		0101000020E6100000DA0418963FBE5440AEB9A3FFE56C4B40
65935	5	52	\N	65	68084	\N	55.111181000000002	Новосибирская область, город Новосибирск, Калининский район, Кочубея, 11/1		0101000020E610000048DC63E943BD5440E277D32D3B8E4B40
66033	5	52	\N	65	67985	\N	54.992553999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Котовского, 2а		0101000020E610000001C287122DB85440CAC16C020C7F4B40
66022	5	52	\N	65	67985	\N	54.991985999999997	Новосибирская область, город Новосибирск, Ленинский район, улица Котовского, 16		0101000020E6100000463F1A4E99B75440800BB265F97E4B40
66007	5	52	\N	65	67985	\N	54.991289000000002	Новосибирская область, город Новосибирск, Ленинский район, улица Котовского, 38		0101000020E6100000A7AD11C138B7544039F1D58EE27E4B40
65993	5	52	\N	65	1466	\N	54.988117000000003	Новосибирская область, город Новосибирск, Ленинский район, улица Космическая, 21	Россия, Новосибирская область, Новосибирск, Космическая улица, 21	0101000020E6100000BBED42739DB9544092CF2B9E7A7E4B40
65996	5	52	\N	65	68176	\N	54.984955999999997	Новосибирская область, город Новосибирск, Ленинский район, улица Космическая, 10		0101000020E610000024456458C5B95440DEFFC709137E4B40
65857	5	52	\N	65	7757	\N	55.031756999999999	Новосибирская область, город Новосибирск, Железнодорожный район, проспект Комсомольский, 20	Россия, Новосибирская область, Новосибирск, Комсомольский проспект, 20	0101000020E61000006FD40AD3F7B95440A435069D10844B40
66095	5	52	\N	65	68116	\N	55.019604000000001	Новосибирская область, город Новосибирск, Октябрьский район, Коммунстроевская, 161		0101000020E6100000A1BE654E97BE5440766F456282824B40
66171	5	52	\N	65	68215	\N	55.023392000000001	Новосибирская область, город Новосибирск, Центральный район, улица Коммунистическая, дом 58		0101000020E61000009B1F7F6951BB5440787E5182FE824B40
64292	5	52	\N	65	68858	\N	54.948148000000003	Новосибирская область, Болотнинский район, Баратаевский сельсовет, Колхозная, 17		0101000020E61000000D535BEA20BF544048E2E5E95C794B40
66006	5	52	\N	65	67984	\N	55.019283999999999	Новосибирская область, город Новосибирск, Ленинский район, улица Клубная, 39		0101000020E6100000B1DEA815A6B2544004ABEAE577824B40
66066	5	52	\N	65	68194	\N	55.002598999999996	Новосибирская область, город Новосибирск, Октябрьский район, Кирова, 327		0101000020E6100000185DDE1CAEBE54404B00FE2955804B40
66017	5	52	\N	65	67987	\N	54.991670999999997	Новосибирская область, город Новосибирск, Ленинский район, улица Киевская, 14		0101000020E6100000E694809884B6544020B24813EF7E4B40
66010	5	52	\N	65	67987	\N	54.989223000000003	Новосибирская область, город Новосибирск, Ленинский район, улица Киевская, 15а		0101000020E6100000E38C614ED0B55440BBB9F8DB9E7E4B40
66009	5	52	\N	65	67987	\N	54.989857999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Киевская, 7		0101000020E6100000D90A9A9658B654408CD7BCAAB37E4B40
66008	5	52	\N	65	68178	\N	54.988416999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Киевская, 5		0101000020E61000000951BEA085B65440BCE7C072847E4B40
65990	5	52	\N	65	68267	\N	54.990442000000002	Новосибирская область, город Новосибирск, Ленинский район, проспект К.Маркса, 26		0101000020E6100000124A5F0839BA5440DC4AAFCDC67E4B40
66177	5	52	\N	65	68213	\N	55.036926999999999	Новосибирская область, город Новосибирск, Центральный район, улица Каменская, дом 56		0101000020E61000001BB96E4A79BB544071AB2006BA844B40
66175	5	52	\N	65	68213	\N	55.039867999999998	Новосибирская область, город Новосибирск, Центральный район, улица Каменская, дом 68		0101000020E6100000C8B60C384BBB5440161406651A854B40
66157	5	52	\N	65	68213	\N	55.041916000000001	Новосибирская область, город Новосибирск, Центральный район, улица Каменская, дом 82		0101000020E6100000F8510DFB3DBB5440EE96E4805D854B40
65839	5	52	\N	65	68247	\N	55.055377	Новосибирская область, город Новосибирск, Дзержинский район, Индустриальная, 4а		0101000020E61000007923F3C81FBE5440ADF9F19716874B40
66136	5	52	\N	65	68192	\N	54.842418000000002	Новосибирская область, город Новосибирск, Советский район, Ильича, 21		0101000020E61000009CDCEF5014C65440E7C75F5AD46B4B40
66140	5	52	\N	65	68033	\N	54.866503000000002	Новосибирская область, город Новосибирск, Советский район, Иванова, 9		0101000020E6100000B0AE0AD462C554406571FF91E96E4B40
66132	5	52	\N	65	68033	\N	54.872501999999997	Новосибирская область, город Новосибирск, Советский район, Иванова, 49		0101000020E6100000F2EB87D860C65440E8D84125AE6F4B40
66130	5	52	\N	65	68033	\N	54.869259	Новосибирская область, город Новосибирск, Советский район, Иванова, 36		0101000020E610000032C85D8429C65440786000E1436F4B40
65984	5	52	\N	65	67975	\N	54.934908999999998	Новосибирская область, город Новосибирск, Кировский район, Зорге, 2		0101000020E6100000191D90847DB9544037DE1D19AB774B40
65983	5	52	\N	65	67975	\N	54.933010000000003	Новосибирская область, город Новосибирск, Кировский район, Зорге, 42А		0101000020E6100000124F7633A3B95440A56B26DF6C774B40
65982	5	52	\N	65	67975	\N	54.934654999999999	Новосибирская область, город Новосибирск, Кировский район, Зорге, 12		0101000020E6100000F6B3588AE4B954407D0569C6A2774B40
65981	5	52	\N	65	67975	\N	54.931013999999998	Новосибирская область, город Новосибирск, Кировский район, Зорге, 78/1		0101000020E6100000E99C9FE238BA54401F0F7D772B774B40
65979	5	52	\N	65	67975	\N	54.929079000000002	Новосибирская область, город Новосибирск, Кировский район, Зорге, 259/1		0101000020E6100000EC4CA1F31ABB54404033880FEC764B40
65974	5	52	\N	65	67975	\N	54.935659000000001	Новосибирская область, город Новосибирск, Кировский район, Зорге, 149		0101000020E610000094313ECC5EBB5440A29A92ACC3774B40
65946	5	52	\N	65	67975	\N	54.933010000000003	новосибирск, улица Зорге, 42А		0101000020E6100000124F7633A3B95440A56B26DF6C774B40
66113	5	52	\N	65	68025	\N	54.955665000000003	Новосибирская область, город Новосибирск, Первомайский район, улица Звездная, 8А		0101000020E61000009DF2E84658C454404777103B537A4B40
66015	5	52	\N	65	67992	\N	54.989888999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Забалуева, 74		0101000020E6100000F33E8EE6C8B35440C7D5C8AEB47E4B40
66013	5	52	\N	65	67992	\N	54.987043	Новосибирская область, город Новосибирск, Ленинский район, улица Забалуева, 47		0101000020E6100000271422E010B45440745FCE6C577E4B40
66012	5	52	\N	65	67992	\N	54.991174999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Забалуева, 10а		0101000020E61000001D05888219B5544070CE88D2DE7E4B40
65905	5	52	\N	65	68240	\N	55.063988000000002	Новосибирская область, город Новосибирск, Заельцовский район, Жуковского, 98		0101000020E610000079060DFD13B9544011AB3FC230884B40
65892	5	52	\N	65	68240	\N	55.060538999999999	Новосибирская область, город Новосибирск, Заельцовский район, Жуковского, 113/5		0101000020E610000075CAA31B61B95440F790F0BDBF874B40
66137	5	52	\N	65	68323	\N	54.836455999999998	Новосибирская область, город Новосибирск, Советский район, Жемчужная, 16		0101000020E61000003D7D04FEF0C5544080457EFD106B4B40
65820	5	52	\N	65	67809	\N	55.049514000000002	Новосибирская область, город Новосибирск, Дзержинский район, Есенина, 15		0101000020E61000005C7171546EBF5440DA58897956864B40
65898	5	52	\N	65	68158	\N	55.074117999999999	Новосибирская область, город Новосибирск, Заельцовский район, Ереванская, 14		0101000020E61000003201BF4692B95440C005D9B27C894B40
65886	5	52	\N	65	67836	\N	55.047167000000002	Новосибирская область, город Новосибирск, Заельцовский район, Ельцовская, 31		0101000020E610000043A9BD88B6B85440A839799109864B40
65884	5	52	\N	65	67835	\N	55.045470000000002	Новосибирская область, город Новосибирск, Заельцовский район, Ельцовская, 5		0101000020E6100000D7BFEB3367B854407D7901F6D1854B40
65894	5	52	\N	65	68058	\N	55.065128000000001	Новосибирская область, город Новосибирск, Заельцовский район, Дуси Ковальчук, 191		0101000020E61000008F1A13622EBB5440E606431D56884B40
65888	5	52	\N	65	68058	\N	55.054898000000001	Новосибирская область, город Новосибирск, Заельцовский район, Дуси Ковальчук, 85		0101000020E6100000FAEFC16B97B95440D34ECDE506874B40
65887	5	52	\N	65	68058	\N	55.05151	Новосибирская область, город Новосибирск, Заельцовский район, Дуси Ковальчук, 65А		0101000020E6100000E621533E04B954405FB532E197864B40
66163	5	52	\N	65	68143	\N	55.046619999999997	Новосибирская область, город Новосибирск, Центральный район, улица Достоевского, дом 27		0101000020E6100000634337FB03BB544075ABE7A4F7854B40
65819	5	52	\N	65	15634	\N	55.040104999999997	Новосибирская область, город Новосибирск, Дзержинский район, Доватора, 27/1	Россия, Новосибирская область, Новосибирск, Дзержинский район, Доватора улица	0101000020E61000000EF96706F1BF5440FAB31F2922854B40
65846	5	52	\N	65	16639	\N	55.039083489526497	Новосибирская область, город Новосибирск, Дзержинский район, Доватора, 33/4	Россия, Новосибирская область, Новосибирск, Октябрьский район, улица Доватора, 33/4	0101000020E61000001D90847D3BC054402F6AF7AB00854B40
66084	5	52	\N	65	68010	\N	55.030793000000003	Новосибирская область, город Новосибирск, Октябрьский район, Добролюбова, 223		0101000020E61000001805C1E3DBBE54400EF96706F1834B40
66081	5	52	\N	65	68010	\N	55.029176999999997	Новосибирская область, город Новосибирск, Октябрьский район, Добролюбова, 162		0101000020E6100000DAFF006BD5BE5440CF656A12BC834B40
66080	5	52	\N	65	68010	\N	55.027923999999999	Новосибирская область, город Новосибирск, Октябрьский район, Добролюбова, 160		0101000020E6100000DD611399B9BE544002637D0393834B40
65903	5	52	\N	65	67895	\N	55.067529999999998	Новосибирская область, город Новосибирск, Заельцовский район, Дмитрия Донского, 6А		0101000020E61000001F84807C09BA5440DBBFB2D2A4884B40
66149	5	52	\N	65	3617	\N	54.842185000000001	Новосибирская область, город Новосибирск, Советский район, проезд Детский, 10	Россия, Новосибирская область, Новосибирск, Детский проезд, 10	0101000020E61000003A3C84F1D3C654404417D4B7CC6B4B40
65834	5	52	\N	65	68149	\N	55.044339999999998	Новосибирская область, город Новосибирск, Дзержинский район, Гоголя, 188/1		0101000020E61000005055A18158BD5440CBF3E0EEAC854B40
65832	5	52	\N	65	68149	\N	55.047409000000002	Новосибирская область, город Новосибирск, Дзержинский район, Гоголя, 195		0101000020E610000062F3716DA8BD54409E44847F11864B40
66057	5	52	\N	65	68104	\N	54.995018000000002	Новосибирская область, город Новосибирск, Октябрьский район, Большевистская, 175/6		0101000020E61000005280289831BE54403677F4BF5C7F4B40
66164	5	52	\N	65	16640	\N	55.045053646984499	Новосибирская область, город Новосибирск, Центральный район, улица Гоголя, дом 35А	Россия, Новосибирская область, Новосибирск, Дзержинский район, улица Гоголя, 35а	0101000020E61000006E32AA0CE3BB5440E9465854C4854B40
65833	5	52	\N	65	68055	\N	55.054310000000001	Новосибирская область, город Новосибирск, Дзержинский район, Гоголя, 233		0101000020E6100000F418E59997BE544042EC4CA1F3864B40
66124	5	52	\N	65	16648	\N	54.862755999999997	Новосибирская область, город Новосибирск, Советский район, Гидромонтажная, 58		0101000020E6100000253CA1D79FBE5440C136E2C96E6E4B40
66107	5	52	\N	65	68124	\N	54.977305000000001	Новосибирская область, город Новосибирск, Первомайский район, улица Героев Революции, 103		0101000020E6100000FA47DFA469C45440D09B8A54187D4B40
66105	5	52	\N	65	68124	\N	54.977046000000001	Новосибирская область, город Новосибирск, Первомайский район, улица Героев Революции, 68		0101000020E6100000AB77B81D1AC554400458E4D70F7D4B40
66101	5	52	\N	65	68124	\N	54.973222999999997	Новосибирская область, город Новосибирск, Первомайский район, улица Героев Революции, 6		0101000020E6100000F777B6476FC65440855B3E92927C4B40
66146	5	52	\N	65	15437	\N	54.867772000000002	Новосибирская область, город Новосибирск, Советский район, Вяземского, 4		0101000020E6100000EE2422FC8BC6544038312427136F4B40
65997	5	52	\N	65	68175	\N	54.990766999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Выставочная, 36		0101000020E6100000804754A86EB954405F7AFB73D17E4B40
66034	5	52	\N	65	68283	\N	54.986117999999998	Новосибирская область, город Новосибирск, Ленинский район, улица Выставочная, 8		0101000020E61000002B6D718DCFB854409BFF571D397E4B40
66065	5	52	\N	65	68193	\N	54.999020000000002	Новосибирская область, город Новосибирск, Октябрьский район, Выборная, 126		0101000020E61000006BF12900C6C0544064062AE3DF7F4B40
94870	5	52	\N	65	68005	\N	54.996721999999998	город Новосибирск, улица Выборная, 120		0101000020E61000009C6C0377A0C05440139A2496947F4B40
66062	5	52	\N	65	68005	\N	55.006286000000003	Новосибирская область, город Новосибирск, Октябрьский район, Выборная, 111/1		0101000020E610000014D1AFAD9FC154401A36CAFACD804B40
66060	5	52	\N	65	68005	\N	54.996721999999998	Новосибирская область, город Новосибирск, Октябрьский район, Выборная, 120		0101000020E61000009C6C0377A0C05440139A2496947F4B40
65843	5	52	\N	65	16628	\N	55.044397452783798	Новосибирская область, город Новосибирск, Дзержинский район, Волочаевская, 111		0101000020E61000002B1213D4F0C054402F8507CDAE854B40
65868	5	52	\N	65	7880	\N	55.031638999999998	Новосибирская область, город Новосибирск, Железнодорожный район, Вокзальная магистраль, 12	Россия, Новосибирская область, Новосибирск, Вокзальная магистраль, 12	0101000020E6100000309DD66D50BA54409A232BBF0C844B40
66069	5	52	\N	65	68014	\N	55.025863999999999	Новосибирская область, город Новосибирск, Октябрьский район, Воинская, 3		0101000020E6100000BA313D6189BD54406612F5824F834B40
66096	5	52	\N	65	14032	\N	55.011592999999998	Новосибирская область, город Новосибирск, Октябрьский район, территория Военного Городка, 17		0101000020E61000009605137F14C0544067EE21E17B814B40
94865	5	52	\N	65	67789	\N	55.036766999999998	город Новосибирск, улица Владимировская, 15		0101000020E610000011ACAA97DFB854403849F3C7B4844B40
66089	5	52	\N	65	68297	\N	55.029677999999997	Новосибирская область, город Новосибирск, Октябрьский район, Высоцкого, 1		0101000020E6100000F3583332C8C0544091B41B7DCC834B40
66061	5	52	\N	65	68191	\N	55.000377999999998	Новосибирская область, город Новосибирск, Октябрьский район, Вилюйская, 28		0101000020E6100000E84B6F7F2EC15440A6D1E4620C804B40
66131	5	52	\N	65	16661	\N	54.855429000000001	Новосибирская область, город Новосибирск, Советский район, Ветлужская, 28а		0101000020E6100000BEC1172653BE544066868DB27E6D4B40
65954	5	52	\N	65	68006	\N	54.978383999999998	Новосибирская область, город Новосибирск, Кировский район, Вертковская, 2		0101000020E610000048DE3994A1B95440FF76D9AF3B7D4B40
65950	5	52	\N	65	67989	\N	54.976301999999997	Новосибирская область, город Новосибирск, Кировский район, Вертковская, 16		0101000020E6100000B0E76B96CBB854407B82C476F77C4B40
65955	5	52	\N	65	68310	\N	54.978471999999996	Новосибирская область, город Новосибирск, Кировский район, Ватутина, 61А		0101000020E61000006CED7DAA0ABA54409E060C923E7D4B40
65965	5	52	\N	65	68086	\N	54.965738999999999	Новосибирская область, город Новосибирск, Кировский район, Бурденко, 55		0101000020E6100000F110C64FE3BA544062BCE6559D7B4B40
66059	5	52	\N	65	68186	\N	54.986536999999998	Новосибирская область, город Новосибирск, Октябрьский район, Бугурусланская, 19		0101000020E61000004567994528BF5440A0A52BD8467E4B40
65987	5	52	\N	65	16650	\N	54.932389999999998	Новосибирская область, город Новосибирск, Кировский район, Бородина, 14		0101000020E6100000747E8AE3C0B75440088F368E58774B40
66148	5	52	\N	65	68312	\N	54.811529	Новосибирская область, город Новосибирск, Советский район, Боровая партия, 13		0101000020E6100000F33D23111AC65440B760A92EE0674B40
66097	5	52	\N	65	68201	\N	55.033197000000001	Новосибирская область, город Новосибирск, Октябрьский район, Бориса Богаткова, 51		0101000020E610000026FDBD141EBD5440A4A99ECC3F844B40
66086	5	52	\N	65	68201	\N	55.036839999999998	Новосибирская область, город Новосибирск, Октябрьский район, Бориса Богаткова, 189		0101000020E61000005E2F4D11E0BD5440A297512CB7844B40
66085	5	52	\N	65	68201	\N	55.035952000000002	Новосибирская область, город Новосибирск, Октябрьский район, Бориса Богаткова, 187		0101000020E6100000DCBB067DE9BD5440E71C3C139A844B40
65848	5	52	\N	65	68201	\N	55.039821000000003	Новосибирская область, город Новосибирск, Дзержинский район, Бориса Богаткова, 241/1		0101000020E61000004E64E60297BE5440D658C2DA18854B40
66058	5	52	\N	65	68104	\N	54.998871000000001	Новосибирская область, город Новосибирск, Октябрьский район, Большевистская, 32		0101000020E610000048DFA46950BD54401FF64201DB7F4B40
65923	5	52	\N	65	67909	\N	55.078952000000001	Новосибирская область, город Новосибирск, Калининский район, Богдана Хмельницкого, 51		0101000020E610000089EB18575CBD544016FA60191B8A4B40
65921	5	52	\N	65	67909	\N	55.074168999999998	Новосибирская область, город Новосибирск, Калининский район, Богдана  Хмельницкого, 40		0101000020E6100000C231CB9E04BD544042B0AA5E7E894B40
65919	5	52	\N	65	67909	\N	55.075149000000003	Новосибирская область, город Новосибирск, Калининский район, Богдана Хмельницкого, 37		0101000020E6100000B1C05774EBBC5440DFA9807B9E894B40
66126	5	52	\N	65	16655	\N	54.863757781123702	Новосибирская область, город Новосибирск, Советский район, Бердышева, 15	Россия, Новосибирская область, Новосибирск, улица Бердышева	0101000020E6100000DB87BCE5EABD544045D4449F8F6E4B40
66067	5	52	\N	65	68110	\N	55.024594999999998	Новосибирская область, город Новосибирск, Октябрьский район, Белинского, 1		0101000020E6100000D481ACA756BC54409352D0ED25834B40
66125	5	52	\N	65	68030	\N	54.863990000000001	Новосибирская область, город Новосибирск, Советский район, Барьерная, 8		0101000020E61000007787140324BF544018096D39976E4B40
65922	5	52	\N	65	68407	\N	55.076087000000001	Новосибирская область, город Новосибирск, Калининский район, Александра Невского, 1А		0101000020E6100000BC75FEEDB2BC54404C530438BD894B40
66111	5	52	\N	65	68300	\N	54.966054999999997	Новосибирская область, город Новосибирск, Первомайский район, улица Аксенова, 21		0101000020E61000008AAC3594DAC354409291B3B0A77B4B40
66150	5	52	\N	65	68035	\N	54.835839	Новосибирская область, город Новосибирск, Советский район, Академическая, 9		0101000020E610000012BC218D0AC7544055DCB8C5FC6A4B40
65849	5	52	\N	65	68154	\N	55.039366999999999	Новосибирская область, город Новосибирск, Дзержинский район, Адриена Лежена, 22		0101000020E6100000FB5C6DC5FEBE544054C554FA09854B40
65821	5	52	\N	65	68154	\N	55.043443000000003	Новосибирская область, город Новосибирск, Дзержинский район, Адриена Лежена, 16		0101000020E6100000D95A5F24B4BE5440BD1E4C8A8F854B40
65845	5	52	\N	65	67811	\N	55.074618000000001	Новосибирская область, город Новосибирск, Дзержинский район, Авиастроителей, 16		0101000020E61000009AD024B1A4BE5440B2D826158D894B40
65844	5	52	\N	65	68048	\N	55.072592	Новосибирская область, город Новосибирск, Дзержинский район, Авиастроителей, 10		0101000020E610000037DF88EE59BE5440C2F9D4B14A894B40
66031	5	52	\N	65	14418	\N	54.9674126612084	Новосибирская область, город Новосибирск, Ленинский район, улица 9-й Гв.Дивизии, 20		0101000020E6100000EEB1F4A10BB65440D55C6E30D47B4B40
65824	5	52	\N	65	7379	\N	55.049152999999997	Новосибирская область, город Новосибирск, Дзержинский район, 3-й Почтовый переулок, 21		0101000020E61000002733DE567AC0544009C03FA54A864B40
64287	5	52	\N	65	3931	\N	54.999139	Новосибирская область, Болотнинский район, Боровской сельсовет, Школьная, 10	Россия, Новосибирская область, Новосибирск, 2-я Школьная улица, 2а	0101000020E610000070EA03C93BB854403E9468C9E37F4B40
64285	5	52	\N	65	68403	\N	55.0010018305464	Новосибирская область, Болотнинский район, Боровской сельсовет, Школьная, 1	Россия, Новосибирская область, Новосибирск, 2-я Школьная улица	0101000020E6100000D84812842BB85440849D62D520804B40
65889	5	52	\N	65	67844	\N	55.055681999999997	Новосибирская область, город Новосибирск, Заельцовский район, 2-я Союза Молодежи, 31		0101000020E61000002CF015DD7AB95440E97C789620874B40
66002	5	52	\N	65	16653	\N	55.027289000000003	Новосибирская область, город Новосибирск, Ленинский район, улица 2-я Портовая, 36		0101000020E61000004FC939B187B654403145B9347E834B40
65861	5	52	\N	65	68056	\N	55.041978	Новосибирская область, город Новосибирск, Железнодорожный район, 1905 года, 39		0101000020E6100000D9B5BDDD92B954406493FC885F854B40
65860	5	52	\N	65	68056	\N	55.042487999999999	Новосибирская область, город Новосибирск, Железнодорожный район, 1905 года, 41		0101000020E61000007C0BEBC6BBB95440793C2D3F70854B40
65858	5	52	\N	65	68056	\N	55.039574000000002	Новосибирская область, город Новосибирск, Железнодорожный район, 1905 года, 12		0101000020E6100000C4B5DAC35EB95440CEE2C5C210854B40
65855	5	52	\N	65	68056	\N	55.043278000000001	Новосибирская область, город Новосибирск, Железнодорожный район, 1905 года, 61		0101000020E61000004298DBBDDCB9544072512D228A854B40
65973	5	52	\N	65	1150	\N	54.948721999999997	Новосибирская область, город Новосибирск, Кировский район, переулок 15-й Бронный, 20А	Россия, Новосибирская область, Новосибирск, 15-й Бронный переулок, 20а	0101000020E61000005725917D90BC5440737FF5B86F794B40
65908	5	52	\N	65	68079	\N	55.077714999999998	Новосибирская область, город Новосибирск, Заельцовский район, 1-я Шевцовой, 83		0101000020E61000002104E44BA8BA54404EB4AB90F2894B40
66112	5	52	\N	65	68129	\N	54.962978999999997	Новосибирская область, город Новосибирск, Первомайский район, улица 1-я Механическая, 18		0101000020E6100000FE0DDAAB8FC354400DDE57E5427B4B40
66039	5	52	\N	65	2087	\N	54.979826000000003	Новосибирская область, город Новосибирск, Ленинский район, 1-й переулок Серафимовича, 4	Россия, Новосибирская область, Новосибирск, 1-й переулок Серафимовича, 4а	0101000020E6100000DD088B8A38B85440A0E238F06A7D4B40
65961	5	52	\N	65	954	\N	54.962581	Новосибирская область, город Новосибирск, Кировский район, переулок 1-й Чукотский, 8	Россия, Новосибирская область, Новосибирск, 1-й Чукотский переулок, 8	0101000020E6100000F4DDAD2CD1B854402060ADDA357B4B40
66045	5	52	\N	65	2164	\N	54.983313000000003	Новосибирская область, город Новосибирск, Ленинский район, 1-й переулок Петропавловский, 10	Россия, Новосибирская область, Новосибирск, 1-й Петропавловский переулок, 10	0101000020E610000037E0F3C308B75440A75D4C33DD7D4B40
94783	5	52	1564	24493	68711	\N	55.482816	Мошковский район, д. Вороново, улица Школьная, д. 2		0101000020E6100000992B836A83F2544026FE28EACCBD4B40
65866	5	52	\N	65	68235	\N	55.028336000000003	Новосибирская область, город Новосибирск, Железнодорожный район, Щетинкина, 33		0101000020E61000002BD9B11188BA544055A69883A0834B40
65837	5	52	\N	65	68059	\N	55.041034000000003	Новосибирская область, город Новосибирск, Дзержинский район, Фрунзе, 63/1		0101000020E6100000AEB9A3FFE5BC54401503249A40854B40
65930	5	52	\N	65	68082	\N	55.094684000000001	Новосибирская область, город Новосибирск, Калининский район, Фадеева, 50/1		0101000020E610000036785F950BBC54402CBAF59A1E8C4B40
66143	5	52	\N	65	68135	\N	54.848073999999997	Новосибирская область, город Новосибирск, Советский район, Тружеников, 10		0101000020E6100000F33AE2900DC35440404B57B08D6C4B40
66036	5	52	\N	65	68003	\N	54.983184000000001	Новосибирская область, город Новосибирск, Ленинский район, улица Титова, 14		0101000020E61000003315E29178B85440A9F92AF9D87D4B40
66027	5	52	\N	65	68003	\N	54.980466999999997	Новосибирская область, город Новосибирск, Ленинский район, улица Титова, 202		0101000020E610000054C90050C5B4544053E751F17F7D4B40
65962	5	52	\N	65	67791	\N	54.966168000000003	Новосибирская область, город Новосибирск, Кировский район, Сибиряков-Гвардейцев, 44/6		0101000020E6100000A872DA5372B954408B389D64AB7B4B40
65948	5	52	\N	65	67902	\N	54.974535000000003	Новосибирская область, город Новосибирск, Кировский район, Серафимовича, 32		0101000020E61000004C512E8D5FB8544058E71890BD7C4B40
66117	5	52	\N	65	68302	\N	54.938994999999998	Новосибирская область, город Новосибирск, Первомайский район, улица Пришвина, 3		0101000020E6100000DEAF027CB7C75440C30DF8FC30784B40
65976	5	52	\N	65	68173	\N	54.938772	Новосибирская область, город Новосибирск, Кировский район, Петухова, 86		0101000020E61000000AA2EE0390BA544044334FAE29784B40
65914	5	52	\N	65	68248	\N	55.072298000000004	Новосибирская область, город Новосибирск, Калининский район, Олеко Дундича, 1/1		0101000020E61000000DE4D9E55BBD54407AC8940F41894B40
66082	5	52	\N	65	68199	\N	55.027036000000003	Новосибирская область, город Новосибирск, Октябрьский район, Никитина, 147		0101000020E610000001A60C1CD0BE544047E867EA75834B40
66176	5	52	\N	65	68144	\N	55.028346999999997	Новосибирская область, город Новосибирск, Центральный район, улица Максима Горького, дом 93		0101000020E610000034A0DE8C9ABB544048F8DEDFA0834B40
66173	5	52	\N	65	67793	\N	55.039707999999997	Новосибирская область, город Новосибирск, Центральный район, улица Ломоносова, дом 59		0101000020E6100000427A8A1C22BC5440DDB1D82615854B40
66160	5	52	\N	65	68139	\N	55.042138000000001	Новосибирская область, город Новосибирск, Центральный район, улица Крылова, дом 61А		0101000020E6100000AA81E673EEBB54409DF529C764854B40
66158	5	52	\N	65	68139	\N	55.041307000000003	Новосибирская область, город Новосибирск, Центральный район, улица Крылова, дом 44		0101000020E6100000D027F224E9BB5440460C3B8C49854B40
65913	5	52	\N	65	68162	\N	55.058100000000003	Новосибирская область, город Новосибирск, Калининский район, Кропоткина, 323		0101000020E610000012DC48D922BC5440E5F21FD26F874B40
65933	5	52	\N	65	68167	\N	55.112386000000001	Новосибирская область, город Новосибирск, Калининский район, Красных Зорь, 7		0101000020E61000000821205F42BE54409E4319AA628E4B40
65980	5	52	\N	65	67907	\N	54.932927999999997	Новосибирская область, город Новосибирск, Кировский район, Зорге, 181/1		0101000020E610000060394206F2BA5440E7C2482F6A774B40
65978	5	52	\N	65	67907	\N	54.937567000000001	Новосибирская область, город Новосибирск, Кировский район, Зорге, 21		0101000020E61000002FA2ED98BAB954408867093202784B40
65977	5	52	\N	65	67907	\N	54.937407	Новосибирская область, город Новосибирск, Кировский район, Зорге, 39		0101000020E6100000C1A90F24EFB954404F05DCF3FC774B40
65896	5	52	\N	65	68223	\N	55.067225999999998	Новосибирская область, город Новосибирск, Заельцовский район, Залесского, 4		0101000020E6100000D0D1AA9674BB54406FB88FDC9A884B40
65895	5	52	\N	65	67834	\N	55.063901000000001	Новосибирская область, город Новосибирск, Заельцовский район, Дуси Ковальчук, 187		0101000020E6100000986DA7AD11BB5440429770E82D884B40
65881	5	52	\N	65	67834	\N	55.058466000000003	Новосибирская область, город Новосибирск, Заельцовский район, Дуси Ковальчук, 179		0101000020E6100000B188618731BA5440C7F65AD07B874B40
65877	5	52	\N	65	67834	\N	55.059657000000001	Новосибирская область, город Новосибирск, Заельцовский район, Дуси Ковальчук, 270/2		0101000020E6100000D3C08F6AD8BA54401EFD2FD7A2874B40
66168	5	52	\N	65	68037	\N	55.048471999999997	Новосибирская область, город Новосибирск, Центральный район, улица Достоевского, дом 77		0101000020E610000079B130444EBC5440C7629B5434864B40
66072	5	52	\N	65	68018	\N	55.019945	Новосибирская область, город Новосибирск, Октябрьский район, Добролюбова, 113		0101000020E6100000BDC3EDD0B0BD5440FF5BC98E8D824B40
65859	5	52	\N	65	68155	\N	55.035621999999996	Новосибирская область, город Новосибирск, Железнодорожный район, Дмитрия Шамшурина, 43		0101000020E61000009010E50B5AB954405182FE428F844B40
66075	5	52	\N	65	68112	\N	55.005000000000003	Новосибирская область, город Новосибирск, Октябрьский район, Декабристов, 86		0101000020E61000000264E8D841BD5440713D0AD7A3804B40
65972	5	52	\N	65	68168	\N	54.955438000000001	Новосибирская область, город Новосибирск, Кировский район, Водозабор, 1		0101000020E6100000E607AEF204BF544086ADD9CA4B7A4B40
66077	5	52	\N	65	68294	\N	55.011716999999997	Новосибирская область, город Новосибирск, Октябрьский район, Бориса Богаткова, 46		0101000020E6100000BCCD1B2785BC544053E751F17F814B40
65920	5	52	\N	65	68166	\N	55.074168999999998	Новосибирская область, город Новосибирск, Калининский район, Богдана Хмельницкого, 40		0101000020E6100000C231CB9E04BD544042B0AA5E7E894B40
65899	5	52	\N	65	68071	\N	55.079518999999998	Новосибирская область, город Новосибирск, Заельцовский район, Аэропорт, 21/1		0101000020E6100000457F68E6C9B954408F34B8AD2D8A4B40
65966	5	52	\N	65	68319	\N	54.968732000000003	Новосибирская область, город Новосибирск, Кировский район, Аникина, 2		0101000020E61000002F50526001BD54405A4B0169FF7B4B40
65108	5	52	\N	13294	14187	\N	54.975008915672198	Новосибирская область, Новосибирский район, с. Новолуговое, Андреева, 57 (здание администрации с/совета)	Россия, Новосибирская область, село Новолуговое, улица Андреева	0101000020E61000001250E10852C7544020274C18CD7C4B40
65474	5	52	\N	59203	69025	\N	55.700299134566798	дер. Никологавриловка,  ул. Центральная, дом 18,	Россия, Новосибирская область, Усть-Таркский район, поселок Николо-Гавриловка	0101000020E61000005D88D51F61D15240F435CB65A3D94B40
94756	5	52	\N	59110	67828	\N	54.371230779987698	Купинский район, г.Купино, улица Р.Люксембург,8	Россия, Новосибирская область, Купинский район, Купино	0101000020E6100000F6ECB94C4D5453407521567F842F4B40
64885	5	52	\N	14082	\N	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, квартал 8, д. 20	Россия, Новосибирская область, Куйбышев	0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64878	5	52	\N	14082	\N	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Папшева, д. 9	Россия, Новосибирская область, Куйбышев	0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64876	5	52	\N	14082	\N	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Луговая, д. 10	Россия, Новосибирская область, Куйбышев	0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64874	5	52	\N	14082	\N	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Достоевского, д. 34	Россия, Новосибирская область, Куйбышев	0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64872	5	52	\N	14082	\N	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Войкова, д. 2	Россия, Новосибирская область, Куйбышев	0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64870	5	52	\N	14082	\N	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Агафонова, д. 71	Россия, Новосибирская область, Куйбышев	0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64857	5	52	\N	14082	\N	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Герцена, д. 2	Россия, Новосибирская область, Куйбышев	0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64883	5	52	\N	14082	13665	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, квартал 5, д. 1		0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64884	5	52	\N	14082	13438	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Партизанская, д. 95		0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64873	5	52	\N	14082	13813	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Интернатская, д. 2А		0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64879	5	52	\N	14082	16606	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Закраевского, д. 104		0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64881	5	52	\N	14082	13818	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Володарского, д. 61		0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64871	5	52	\N	14082	16532	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Молодежная, д. 7		0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
65092	5	52	\N	41205	\N	\N	54.926193489546002	Новосибирская область, Новосибирский район, рабочий поселок Краснообск, дом № 209 (школа-гимназия № 13)	Россия, Новосибирская область, Краснообск, 209	0101000020E61000001C295B24EDBE54405E64027E8D764B40
65088	5	52	\N	41205	\N	\N	54.921095999999999	"Новосибирская область, Новосибирский район, рабочий поселок Краснообск, дом 77 (здание ДДТ ""Мастер"")"	Россия, Новосибирская область, Краснообск, 77	0101000020E61000008E91EC116ABF5440FB3C4679E6754B40
65801	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Подгорный, 11А	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65799	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, проспект Юбилейный, 15	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65798	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Южный, 55	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65796	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Южный, 53	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65789	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Индустриальный, 44	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65787	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, Советская, 221	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65785	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, Пушкина, 65	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65784	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, Коротеева, 1А	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65781	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, Коммунистическая, 59	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65778	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, Почтовая, 2	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65775	5	52	\N	26706	\N	\N	54.625222999999998	Новосибирская область, город Искитим, Гоголя, 24	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65795	5	52	\N	26706	13411	\N	54.629935972879302	Новосибирская область, город Искитим, проспект Юбилейный, 4	Россия, Новосибирская область, Искитим	0101000020E61000009BAA7B6473D254405A492BBEA1504B40
65797	5	52	\N	26706	13407	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Южный, 52		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65802	5	52	\N	26706	13413	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Подгорный, 46Б		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65800	5	52	\N	26706	13413	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Подгорный, 35		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65791	5	52	\N	26706	13397	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Индустриальный, 11Б		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65790	5	52	\N	26706	13397	\N	54.625222999999998	Новосибирская область, город Искитим, микрорайон Индустриальный, 9А		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65774	5	52	\N	26706	13923	\N	54.625222999999998	Новосибирская область, город Искитим, Элеваторная, 2А	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65779	5	52	\N	26706	14120	\N	54.625222999999998	Новосибирская область, город Искитим, Школьная, 41		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65786	5	52	\N	26706	13626	\N	54.625222999999998	Новосибирская область, город Искитим, Пушкина, 79		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65794	5	52	\N	26706	13643	\N	54.615981425773697	Новосибирская область, город Искитим, Прорабская, 2А	Россия, Новосибирская область, Искитим	0101000020E61000005B069CA564D354408BFA2477D84E4B40
65777	5	52	\N	26706	13796	\N	54.625222999999998	Новосибирская область, город Искитим, Нагорная, 2А		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65792	5	52	\N	26706	13630	\N	54.625222999999998	Новосибирская область, город Искитим, Литейная, 5		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65783	5	52	\N	26706	14068	\N	54.625222999999998	Новосибирская область, город Искитим, Комсомольская, 6А		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65782	5	52	\N	26706	14068	\N	54.625222999999998	Новосибирская область, город Искитим, Комсомольская, 28	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65780	5	52	\N	26706	13845	\N	54.653093702009301	Новосибирская область, город Искитим, Кирова, 35	Россия, Новосибирская область, Искитим	0101000020E6100000DDD1FF722DD354405F9B8D9598534B40
65776	5	52	\N	26706	13617	\N	54.625222999999998	Новосибирская область, город Искитим, Заводская, 1А		0101000020E6100000AB05F69848D354407FDAA84E07504B40
65793	5	52	\N	26706	13935	\N	54.624125015848499	Новосибирская область, город Искитим, Дачная, 1	Россия, Новосибирская область, Искитим	0101000020E6100000E4F90CA837D35440D9CEF753E34F4B40
65788	5	52	\N	26706	13932	\N	54.625222999999998	Новосибирская область, город Искитим, Советская, 252	Россия, Новосибирская область, Искитим	0101000020E6100000AB05F69848D354407FDAA84E07504B40
65772	5	52	\N	25298	\N	\N	54.773781999999997	Новосибирская область, город Бердск, Микрорайон, 52	Россия, Новосибирская область, Бердск	0101000020E610000058C85C1954C55440E21DE0490B634B40
65761	5	52	\N	25298	\N	\N	54.773781999999997	Новосибирская область, город Бердск, улица Островского, 99	Россия, Новосибирская область, Бердск	0101000020E610000058C85C1954C55440E21DE0490B634B40
65750	5	52	\N	25298	\N	\N	54.773781999999997	Новосибирская область, город Бердск, улица Ленина, 13А	Россия, Новосибирская область, Бердск	0101000020E610000058C85C1954C55440E21DE0490B634B40
65746	5	52	\N	25298	\N	\N	54.773781999999997	"Новосибирская область, город Бердск, ГАУССО ""Бердский пансионат ветеранов труда им. М.И.Калинина"""		0101000020E610000058C85C1954C55440E21DE0490B634B40
65745	5	52	\N	25298	\N	\N	54.773781999999997	"Новосибирская область, город Бердск, здание корпуса № 1 ЗАО ""Сосновка"""		0101000020E610000058C85C1954C55440E21DE0490B634B40
65764	5	52	\N	25298	16367	\N	54.773781999999997	Новосибирская область, город Бердск, улица Школьная, 5		0101000020E610000058C85C1954C55440E21DE0490B634B40
65765	5	52	\N	25298	13766	\N	54.773781999999997	Новосибирская область, город Бердск, улица Пушкина, 38	Россия, Новосибирская область, Бердск	0101000020E610000058C85C1954C55440E21DE0490B634B40
65748	5	52	\N	25298	13897	\N	54.773781999999997	Новосибирская область, город Бердск, улица Попова, 12		0101000020E610000058C85C1954C55440E21DE0490B634B40
65747	5	52	\N	25298	14103	\N	54.773781999999997	Новосибирская область, город Бердск, улица Парижской Коммуны, 15		0101000020E610000058C85C1954C55440E21DE0490B634B40
65758	5	52	\N	25298	13903	\N	54.771135215857797	Новосибирская область, город Бердск, Островского, 69	Россия, Новосибирская область, Бердск	0101000020E6100000E7FC14C781C5544086E63A8DB4624B40
65763	5	52	\N	25298	16582	\N	54.773781999999997	Новосибирская область, город Бердск, улица Озерная, 32		0101000020E610000058C85C1954C55440E21DE0490B634B40
65773	5	52	\N	25298	13919	\N	54.773781999999997	Новосибирская область, город Бердск, Микрорайон, 39		0101000020E610000058C85C1954C55440E21DE0490B634B40
65770	5	52	\N	25298	13919	\N	54.773781999999997	Новосибирская область, город Бердск, Микрорайон, 48Б		0101000020E610000058C85C1954C55440E21DE0490B634B40
65769	5	52	\N	25298	13919	\N	54.745315588557602	Новосибирская область, город Бердск, Микрорайон, 12	Россия, Новосибирская область, Бердск	0101000020E610000087FBC8AD49C35440C097C283665F4B40
65757	5	52	\N	25298	13931	\N	54.773781999999997	Новосибирская область, город Бердск, улица М.Горького, 7/3	Россия, Новосибирская область, Бердск	0101000020E610000058C85C1954C55440E21DE0490B634B40
65771	5	52	\N	25298	13950	\N	54.7462793639559	Новосибирская область, город Бердск, улица Лунная, 23	Россия, Новосибирская область, Бердск	0101000020E61000005F7CD11E2FC354408658FD11865F4B40
65759	5	52	\N	25298	13605	\N	54.773781999999997	Новосибирская область, город Бердск, улица Ленина, 104		0101000020E610000058C85C1954C55440E21DE0490B634B40
94825	5	52	1204	41345	13997	\N	55.716589999999997	Усть-Таркский район, село Новоникольск,  ул. Центральная, дом 64,		0101000020E6100000E1CFF0660DFF524000529B38B9DB4B40
65755	5	52	\N	25298	13605	\N	54.758628545634203	Новосибирская область, город Бердск, улица Ленина, 34	Россия, Новосибирская область, Бердск	0101000020E6100000D175E107E7C554400A664CC11A614B40
65753	5	52	\N	25298	13605	\N	54.752340657624899	Новосибирская область, город Бердск, улица Ленина, 31	Россия, Новосибирская область, Бердск	0101000020E61000006EDBF7A8BFC554405038BBB54C604B40
65766	5	52	\N	25298	13607	\N	54.754580140817701	Новосибирская область, город Бердск, улица Кутузова, 34	Россия, Новосибирская область, Бердск	0101000020E6100000E694809884C554409B1BD31396604B40
65754	5	52	\N	25298	13910	\N	54.773781999999997	Новосибирская область, город Бердск, улица Комсомольская, 31		0101000020E610000058C85C1954C55440E21DE0490B634B40
65752	5	52	\N	25298	13910	\N	54.773781999999997	Новосибирская область, город Бердск, улица Комсомольская, 29	Россия, Новосибирская область, Бердск	0101000020E610000058C85C1954C55440E21DE0490B634B40
65767	5	52	\N	25298	14060	\N	54.754227126955897	Новосибирская область, город Бердск, улица Кольцова, 2	Россия, Новосибирская область, Бердск	0101000020E61000000B410E4A98C554404E61A5828A604B40
65760	5	52	\N	25298	14057	\N	54.761073110820099	Новосибирская область, город Бердск, улица Вокзальная, 54	Россия, Новосибирская область, Бердск	0101000020E61000001AC39CA04DC754402F6F0ED76A614B40
65751	5	52	\N	25298	14057	\N	54.762138489998897	Новосибирская область, город Бердск, улица Вокзальная, 50	Россия, Новосибирская область, Бердск	0101000020E6100000CCB73EAC37C75440F984ECBC8D614B40
65768	5	52	\N	25298	14114	\N	54.753686568914098	Новосибирская область, город Бердск, улица Рогачева, 11		0101000020E6100000F836FDD98FC55440CE35CCD078604B40
65762	5	52	\N	25298	14059	\N	54.754028555394598	Новосибирская область, город Бердск, улица Котовского, 20	Россия, Новосибирская область, Бердск	0101000020E61000005969520ABAC55440289EB30584604B40
65756	5	52	\N	25298	14107	\N	54.752991554848599	Новосибирская область, город Бердск, улица К. Маркса, 26	Россия, Новосибирская область, Бердск	0101000020E61000000E1137A792C554402713B70A62604B40
65744	5	52	\N	25298	14095	\N	54.753134971262298	Новосибирская область, город Бердск, улица Боровая, 101	Россия, Новосибирская область, Бердск	0101000020E61000000B410E4A98C554408A3C49BA66604B40
64276	5	52	\N	16965	\N	\N	55.344700000000003	город Барабинск, улица Путевая, 115	Россия, Новосибирская область, Барабинск	0101000020E61000005682C5E1CC95534032772D211FAC4B40
64272	5	52	\N	16965	\N	\N	55.344700000000003	город Барабинск, улица Ленина, 113	Россия, Новосибирская область, Барабинск	0101000020E61000005682C5E1CC95534032772D211FAC4B40
64263	5	52	\N	16965	\N	\N	55.344700000000003	город Барабинск, переулок Работницы, 13	Россия, Новосибирская область, Барабинск	0101000020E61000005682C5E1CC95534032772D211FAC4B40
64260	5	52	\N	16965	\N	\N	55.344700000000003	город Барабинск, улица Калинина, 2а	Россия, Новосибирская область, Барабинск	0101000020E61000005682C5E1CC95534032772D211FAC4B40
64274	5	52	\N	16965	15628	\N	55.344700000000003	город Барабинск, переулок Халтурина, 31а	Россия, Новосибирская область, Барабинск	0101000020E61000005682C5E1CC95534032772D211FAC4B40
64267	5	52	\N	16965	13619	\N	55.344700000000003	город Барабинск, переулок Гутова, 18	Россия, Новосибирская область, Барабинск	0101000020E61000005682C5E1CC95534032772D211FAC4B40
64264	5	52	\N	16965	13618	\N	55.349275424145198	город Барабинск, улица Ульяновская, 66		0101000020E6100000AD889AE8F3965340BB270F0BB5AC4B40
64262	5	52	\N	16965	13623	\N	55.344700000000003	город Барабинск, улица Сельская, 2		0101000020E61000005682C5E1CC95534032772D211FAC4B40
94703	5	52	\N	16965	67767	\N	55.352254165615598	Барабинский район, город Барабинск , улица Мира, 227	Россия, Новосибирская область, городской округ Барабинск	0101000020E6100000721AA20A7F9453404EF1B8A816AD4B40
64266	5	52	\N	16965	13787	\N	55.344995805702702	город Барабинск, улица Луначарского, 79а	Россия, Новосибирская область, Барабинск	0101000020E6100000DF8AC404359653401BA034D428AC4B40
64270	5	52	\N	16965	13777	\N	55.344702329135501	город Барабинск, улица Ленина, 102	Россия, Новосибирская область, Барабинск	0101000020E6100000B9DE365321965340D26EF4311FAC4B40
64268	5	52	\N	16965	14118	\N	55.347453586214002	город Барабинск, улица Коммунистическая, 10а	Россия, Новосибирская область, городской округ Барабинск	0101000020E6100000A3C9C51858975340A46E675F79AC4B40
64265	5	52	\N	16965	13408	\N	55.344700000000003	город Барабинск, улица Карла Маркса, 111		0101000020E61000005682C5E1CC95534032772D211FAC4B40
64261	5	52	\N	16965	13769	\N	55.344897980422999	город Барабинск, улица Калининв, 5	Россия, Новосибирская область, Барабинск	0101000020E6100000B876A22424965340583A1F9E25AC4B40
64259	5	52	\N	16965	13769	\N	55.350791520396399	город Барабинск, улица Калинина, 5	Россия, Новосибирская область, городской округ Барабинск	0101000020E61000004354E1CFF095534066D993C0E6AC4B40
64258	5	52	\N	16965	16381	\N	55.344700000000003	город Барабинск, улица Ермака, 91		0101000020E61000005682C5E1CC95534032772D211FAC4B40
64273	5	52	\N	16965	14124	\N	55.343430572106499	город Барабинск, улица Деповская, 15	Россия, Новосибирская область, Барабинск	0101000020E610000080289831059653405FB7088CF5AB4B40
64269	5	52	\N	16965	16411	\N	55.344700000000003	город Барабинск, улица Барабинская, 164		0101000020E61000005682C5E1CC95534032772D211FAC4B40
64275	5	52	\N	16965	13781	\N	55.344700000000003	город Барабинск, улица Пролетарская, 54		0101000020E61000005682C5E1CC95534032772D211FAC4B40
65667	5	52	6941	41268	13700	\N	55.130531699518201	поселок Озерный, переулок Школьный, 1	Россия, Новосибирская область, городской округ Новосибирск, поселок Озерный	0101000020E61000008D0C721761BC54406E8AC745B5904B40
65106	5	52	6941	41268	14171	\N	55.130363609448104	Новосибирская область, Новосибирский район, п. Озерный, в/ч 12202, здание магазина	Россия, Новосибирская область, городской округ Новосибирск, поселок Озерный	0101000020E61000000FD1E80E62BC5440B2497EC4AF904B40
65489	5	52	6941	41268	13847	\N	55.131699665747398	пос. Озерный  , ул. Луговая, дом 4,	Россия, Новосибирская область, городской округ Новосибирск, поселок Озерный	0101000020E610000084622B685ABC54400D71AC8BDB904B40
64877	5	52	6896	40313	14144	\N	55.44943135682	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Карла Либкнехта, д. 1	Россия, Новосибирская область, городской округ Куйбышев	0101000020E6100000D731AEB8389453407F677BF486B94B40
64502	5	52	1771	25214	\N	\N	54.739621999999997	Новосибирская область, Искитимский район, поселок Мичуринский, ул.Солнечная, 2А (клуб)	Россия, Новосибирская область, городской округ Бердск, поселок Мичуринский	0101000020E6100000A7203F1BB9C7544078B306EFAB5E4B40
94785	5	52	1771	25214	13692	\N	54.738611096986197	Новосибирский район, п. Мичуринский, улица Солнечная, 10	Россия, Новосибирская область, городской округ Бердск, поселок Мичуринский	0101000020E6100000D21BEE23B7C75440A1BB24CE8A5E4B40
65749	5	52	1771	41374	\N	\N	54.790879907220997	"Новосибирская область, город Бердск, территория санатория ""Бердский"", 36"		0101000020E6100000A1BAB9F8DBC25440BE874B8E3B654B40
64500	5	52	1771	28664	13714	\N	54.747661999999998	Новосибирская область, Искитимский район, поселок Агролес, ул.Жемчужная, 2 (здание школы)		0101000020E61000007EE4D6A4DBC85440213B6F63B35F4B40
64271	5	52	6939	41301	13832	\N	55.360125231772102	город Барабинск, улица Некрасова, 65	Россия, Новосибирская область, городской округ Барабинск	0101000020E610000004E275FD829753406ABC749318AE4B40
65412	5	52	2649	34154	\N	\N	58.976699000000004	село Мокрушино, улица Школьная, 27	Россия, Пермский край, Юсьвинский район, село Мокрушино	0101000020E6100000C1ABE5CE4C704B4099840B79047D4D40
65726	5	52	5877	38649	\N	\N	54.040331999999999	п.Залесный, улица Залесная, 8	Россия, Тульская область, Щекинский район, поселок Залесный	0101000020E6100000868E1D54E2CC4240BB7D569929054B40
64327	5	52	3985	35929	\N	\N	58.647165000000001	деревня Малинино, улица Школьная, 20	Россия, Костромская область, Чухломский район, поселок Малинино	0101000020E61000000186E5CFB7494540D40E7F4DD6524D40
65712	5	52	1423	15860	\N	\N	55.085044000000003	г.Чулым, Семафорная, 1	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E6100000C07ADCB75A3D54404B5CC7B8E28A4B40
65711	5	52	1423	15860	\N	\N	55.085044000000003	"г.Чулым 3, комбинат ""Техника"""		0101000020E6100000C07ADCB75A3D54404B5CC7B8E28A4B40
65708	5	52	1423	15860	\N	\N	55.085044000000003	г.Чулым, Мелиораторов, 20	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E6100000C07ADCB75A3D54404B5CC7B8E28A4B40
65707	5	52	1423	15860	\N	\N	55.097372999999997	г.Чулым, Чулымская, 4	Россия, Новосибирская область, Чулымский район, Чулым, станция Чулымская	0101000020E61000003BA6EECA2E3E5440B741EDB7768C4B40
65706	5	52	1423	15860	\N	\N	55.085044000000003	г.Чулым, Кожемякина, 12	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E6100000C07ADCB75A3D54404B5CC7B8E28A4B40
43154	5	52	1423	15860	\N	\N	55.097372999999997	с.Чулым, Чулымская, 1	Россия, Новосибирская область, Чулымский район, Чулым, станция Чулымская	0101000020E61000003BA6EECA2E3E5440B741EDB7768C4B40
94863	5	52	1423	15860	68390	\N	55.085044000000003	Чулымский район, город Чулым, улица Элеваторная, 34		0101000020E6100000C07ADCB75A3D54404B5CC7B8E28A4B40
46442	5	52	1423	15860	13570	\N	55.085609790438198	г.Чулым, Трудовая, 64А	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E6100000234910AE803D5440F41ABB44F58A4B40
65715	5	52	1423	15860	14035	\N	55.074247831242403	г.Чулым, Трактовая, 47	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E61000004F78094E7D3C54408EE55DF580894B40
65714	5	52	1423	15860	16573	\N	55.093754438958598	г.Чулым, Северная, 7	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E6100000E63BF889033E544041EF8D21008C4B40
65713	5	52	1423	15860	14271	\N	55.083465348069602	г.Чулым, Нефтянников, 8	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E61000009CF86A47713D544029AE2AFBAE8A4B40
65709	5	52	1423	15860	14021	\N	55.087797920973799	г.Чулым, Льва Толстого, 12	Россия, Новосибирская область, Чулымский район, Чулым	0101000020E6100000EB353D28283D5440BD5301F73C8B4B40
65730	5	52	1423	42883	14670	\N	54.771948999999999	с.Чикман, Больничная, 18	Россия, Новосибирская область, Чулымский район, поселок Чикман	0101000020E61000006956B60F7955544007978E39CF624B40
65728	5	52	1423	24502	\N	\N	54.931634000000003	п.Филимоновский, улица Филимоновская, 10	Россия, Новосибирская область, Чулымский район, поселок Филимоновский	0101000020E6100000CE380D5185445440BCEB6CC83F774B40
65731	5	52	1423	24689	14036	\N	54.6745177868045	с.Ужаниха, Гриценко, 3	Россия, Новосибирская область, Чулымский район, поселок Ужаниха	0101000020E61000005743E21E4B4254401B48179B56564B40
65734	5	52	1423	24853	13751	\N	54.874305	с.Серебрянское, Советская, 40Б		0101000020E610000088F6B182DF2C544059DDEA39E96F4B40
65741	5	52	1423	25124	13588	\N	55.143903000000002	п.Секты, улица Трактовая, 45	Россия, Новосибирская область, Чулымский район, поселок Секты	0101000020E610000073B9C150875B5440ED65DB696B924B40
65718	5	52	1423	24046	\N	\N	55.494506999999999	с.Пенек, Железнодорожная, 27	Россия, Новосибирская область, Чулымский район, поселок Пенек	0101000020E6100000F2ED5D83BE635440505260014CBF4B40
65729	5	52	1423	41370	14088	\N	54.821474000000002	п.Осиновский, Молодежная, 22	Россия, Новосибирская область, Чулымский район, поселок Осиновский	0101000020E6100000FC00A436715E5440D5415E0F26694B40
65724	5	52	1423	24349	\N	\N	55.049833	с.Новоиткульское, Мира, 22	Россия, Новосибирская область, Чулымский район, поселок Новоиткульское	0101000020E61000000E4A9869FB4354407BA180ED60864B40
65739	5	52	1423	25062	\N	\N	55.178362	п.Кузнецкий, Школьная, 18		0101000020E6100000916456EF70535440B16CE690D4964B40
65735	5	52	1423	24904	16579	\N	55.147536000000002	с.Кокошино, Лесная, 7		0101000020E61000000FB743C362285440C87DAB75E2924B40
65738	5	52	1423	25013	\N	\N	55.094420999999997	с.Кабинетное, Центральная, 43	Россия, Новосибирская область, Чулымский район, поселок Кабинетное	0101000020E610000028BA2EFCE05254401E87C1FC158C4B40
65377	5	52	843	7493	13608	\N	55.275657000000002	село Гутово, улица Центральная, д.9, кв. 1		0101000020E6100000944F8F6D19135540EDF483BA48A34B40
65723	5	52	1423	41279	\N	\N	55.082895000000001	с.Иткуль, улица Комсомольская, 88в	Россия, Новосибирская область, Чулымский район, поселок Иткуль	0101000020E6100000BDC282FB014254403F00A94D9C8A4B40
65743	5	52	1423	25199	\N	\N	55.022514999999999	п.Илюшино, улица Лесная, 19а	Россия, Новосибирская область, Чулымский район, поселок Илюшино	0101000020E61000005ED905836B585440B05582C5E1824B40
65716	5	52	1423	41280	13741	\N	54.993644000000003	с.Золотая Грива, Центральная, 16	Россия, Новосибирская область, Чулымский район, поселок Золотая Грива	0101000020E61000000CAEB9A3FF2B5440EEEE01BA2F7F4B40
65733	5	52	1423	48934	16578	\N	54.647213000000001	п.Воздвиженский, Центральная, 13		0101000020E61000001631EC30262F5440E54526E0D7524B40
65721	5	52	1423	24220	14330	\N	54.604995000000002	с.Большеникольское, Центральная, 35	Россия, Новосибирская область, Чулымский район, поселок Большеникольское	0101000020E6100000C72B103D295E54402C9FE579704D4B40
65720	5	52	1423	24152	\N	\N	54.535964	п.Базово, Центральная, 36	Россия, Новосибирская область, Чулымский район, поселок Базово	0101000020E6100000A2B60DA3204F5440ABEAE5779A444B40
64899	5	52	1423	41378	14148	\N	54.511540141705098	д.Алексеевка, улица Алексеевская, 14/1	Россия, Новосибирская область, Чулымский район, поселок Алексеевка	0101000020E6100000F0A485CB2A495440444C89247A414B40
65701	5	52	1609	23246	16560	\N	54.711260000000003	деревня Яминка, Шевченко, 11		0101000020E6100000016BD5AE09FD5240FB7953910A5B4B40
94862	5	52	1609	23399	68449	\N	54.709074999999999	Чистоозерный район, поселок Яблоневка, улица Озерная, 40		0101000020E6100000770FD07D39215340A2B437F8C25A4B40
65658	5	52	1609	41299	13828	\N	54.757939530712299	деревня Юдино, улица Октябрьская, 16	Россия, Новосибирская область, Чистоозерный район, поселок Юдино	0101000020E610000014E7A8A3E32F5340452A8C2D04614B40
94857	5	52	1609	41306	68347	\N	54.521507	Чистоозерный район, село Шипицыно, улица Школьная, 16		0101000020E6100000C1A8A44E403653404AD1CABDC0424B40
65705	5	52	1609	20954	\N	\N	54.707853	Новосибирская область, Чистоозерный район, рабочий поселок Чистоозерное, Южная, 10	Россия, Новосибирская область, Чистоозерный район, поселок Чистоозерное	0101000020E61000003E7782FDD724534010B056ED9A5A4B40
65655	5	52	1609	20954	\N	\N	54.707853	рабочий поселок Чистоозерное, Маяковского, 68	Россия, Новосибирская область, Чистоозерный район, поселок Чистоозерное	0101000020E61000003E7782FDD724534010B056ED9A5A4B40
65651	5	52	1609	20954	13977	\N	54.707853	рабочий поселок Чистоозерное, Энергетиков, 8	Россия, Новосибирская область, Чистоозерный район, поселок Чистоозерное	0101000020E61000003E7782FDD724534010B056ED9A5A4B40
94845	5	52	1609	20954	67761	\N	54.708551578594097	Чистоозерный район, рабочий поселок Чистоозерное, улица Покрышкина,14	Россия, Новосибирская область, Чистоозерный район, поселок Чистоозерное	0101000020E6100000F04E3E3DB6245340F8C1F9D4B15A4B40
94846	5	52	1609	20954	16611	\N	54.707853	Чистоозерный район, рабочий поселок Чистоозерное, улица 50 лет Октября, 3		0101000020E61000003E7782FDD724534010B056ED9A5A4B40
65654	5	52	1609	20954	16611	\N	54.707853	рабочий поселок Чистоозерное, 50 лет Октября, 9		0101000020E61000003E7782FDD724534010B056ED9A5A4B40
65688	5	52	1609	22685	16555	\N	54.647036	деревня Чебаклы, Лесная, 19	Россия, Новосибирская область, Чистоозерный район, поселок Чебаклы	0101000020E61000000057B263233A5340D6AA5D13D2524B40
65660	5	52	1609	21392	\N	\N	54.701172999999997	деревня Чаячье, улица Центральная,18	Россия, Новосибирская область, Чистоозерный район, поселок Чаячье	0101000020E6100000F2EB87D8601553404AEB6F09C0594B40
65684	5	52	1609	22419	14181	\N	54.426048000000002	деревня Цветнополье, улица Цветнополье, 26 кв.1	Россия, Новосибирская область, Чистоозерный район, поселок Цветнополье	0101000020E61000006495D233BD0653405B43A9BD88364B40
94853	5	52	1609	41237	68652	\N	54.949347000000003	Чистоозерный район, село Троицкое, улица 60 лет Октября, 4		0101000020E61000003D0B42791F2E534022C7D63384794B40
65668	5	52	1609	19888	13693	\N	54.901947	поселок Табулгинский, улица Центральная, 30А	Россия, Новосибирская область, Чистоозерный район, поселок Табулгинский	0101000020E610000052616C21C8135340D7DCD1FF72734B40
65666	5	52	1609	21570	\N	\N	54.904772999999999	поселок Табулга, улица Дзержинского, 11	Россия, Новосибирская область, Чистоозерный район, поселок Табулга	0101000020E61000004162BB7B80155340E3A6069ACF734B40
94850	5	52	1609	21570	68559	\N	54.904772999999999	Чистоозерный район, поселок Табулга, улица Школьная,2		0101000020E61000004162BB7B80155340E3A6069ACF734B40
65675	5	52	1609	22077	\N	\N	54.968349000000003	деревня Старый Кошкуль, улица Береговая, 29	Россия, Новосибирская область, Чистоозерный район, поселок Старый Кошкуль	0101000020E6100000520FD1E80E2A5340A20E2BDCF27B4B40
94860	5	52	1609	49311	68727	\N	54.64949	Чистоозерный район, село Романовка, улица Школьная, 48		0101000020E61000009E0AB8E7F90253401E8A027D22534B40
94859	5	52	1609	22943	14185	\N	54.561067000000001	Чистоозерный район, село Польяново, улица Первомайская, 29		0101000020E61000002E742502D5F95240B3EE1F0BD1474B40
64895	5	52	1609	59167	68695	\N	54.827347264364498	д.Покровка, Покровская, 41	Россия, Новосибирская область, Чистоозерный район, поселок Покровка	0101000020E610000053EBFD463B1E5340CCB8A981E6694B40
94854	5	52	1609	41218	13503	\N	54.491422	Чистоозерный район, село Павловка, улица Проселочная, 2		0101000020E6100000A62897C62F0E5340784485EAE63E4B40
65656	5	52	1609	47305	15921	\N	54.746112077163801	с.Ольховка, Кирова, 9	Россия, Новосибирская область, Чистоозерный район, поселок Ольховка	0101000020E6100000D95A5F24B42753409A931799805F4B40
94848	5	52	1609	49677	68555	\N	54.780235549471101	Чистоозерный район, село Ольгино, улица Черниговка, 1	Россия, Новосибирская область, Чистоозерный район, поселок Ольгино	0101000020E61000009C16BCE82B0B5340B894F3C5DE634B40
65690	5	52	1609	22772	13716	\N	54.538434000000002	деревня Олтарь, Центральная, 11	Россия, Новосибирская область, Чистоозерный район, поселок Олтарь	0101000020E6100000250516C094295340F986C267EB444B40
94858	5	52	1609	49678	68445	\N	54.646140000000003	Чистоозерный район, село Новопокровка, улица Школьная, 27		0101000020E6100000382F4E7CB543534098512CB7B4524B40
94852	5	52	1609	47827	68651	\N	54.840344999999999	Чистоозерный район, село Новопесчаное, улица Молодежная, 35		0101000020E61000007097FDBAD32C5340B62DCA6C906B4B40
94855	5	52	1609	41346	14001	\N	54.335189999999997	Чистоозерный район, село Новокрасное, улица Молодежная, 35		0101000020E6100000990CC7F3190C53401EF98381E72A4B40
64426	5	52	1609	45822	68685	\N	54.787635000000002	д.Новоалексеевка, Самарская, 12		0101000020E61000004ED2FC31AD265340AD174339D1644B40
94851	5	52	1609	21783	13697	\N	54.920521999999998	Чистоозерный район, село Новая Кулында, улица Центральная, 26		0101000020E6100000A73FFB9122185340CF9F36AAD3754B40
65681	5	52	1609	41224	\N	\N	54.523581	деревня Мухино, улица Зеленая 29/1	Россия, Новосибирская область, Чистоозерный район, поселок Мухино	0101000020E610000050A912656F0553404BE7C3B304434B40
65679	5	52	1609	41272	13707	\N	54.514929859498402	село Мироновка, улица Швачко,14	Россия, Новосибирская область, Чистоозерный район, поселок Мироновка	0101000020E6100000520C90680209534059DDEA39E9414B40
65699	5	52	1609	60698	75581	\N	54.598283183381596	деревня Малая Тохта, улица Озерная,30-1	Россия, Новосибирская область, Чистоозерный район, поселок Малая Тахта	0101000020E610000097361C96061053405B608F89944C4B40
65671	5	52	1609	21865	\N	\N	54.690553999999999	деревня Канавы, улица Зеленая, 16	Россия, Новосибирская область, Чистоозерный район, поселок Канавы	0101000020E610000029064834814153409D0FCF1264584B40
94861	5	52	1609	23224	68448	\N	54.727364999999999	Чистоозерный район, село Ишимская, улица Центральная, 27		0101000020E61000008C834BC79CF95240A5A0DB4B1A5D4B40
94849	5	52	1609	41208	68368	\N	54.622033000000002	Чистоозерный район, село Журавка, улица Центральная, 36Б		0101000020E61000003D27BD6F7C245340320400C79E4F4B40
94847	5	52	1609	49676	68649	\N	54.748068852804799	Чистоозерный район, село Елизаветикна, улица Центральная,55	Россия, Новосибирская область, Чистоозерный район, поселок Елизаветинка	0101000020E61000002121CA17B41E5340621399B9C05F4B40
64346	5	52	1609	41342	13991	\N	54.761472510136699	деревня Георгиевка, улица Заречная, 27	Россия, Новосибирская область, Чистоозерный район, поселок Георгиевка (Юхлино)	0101000020E6100000E869C020E9FB5240BDE47FF277614B40
94856	5	52	1609	41277	68725	\N	54.395766999999999	Чистоозерный район, село Варваровка, улица Молодежная, 29		0101000020E6100000F583BA48A110534003EB387EA8324B40
65693	5	52	1609	22889	13531	\N	54.395316000000001	деревня Бугриновка, улица Озерная, 18		0101000020E6100000E0DA8992902A5340F3CAF5B699324B40
65702	5	52	1609	23313	\N	\N	54.702547000000003	деревня Большая Тахта, улица Береговая, 8	Россия, Новосибирская область, Чистоозерный район, поселок Большая Тахта	0101000020E61000003E3DB665C00453409373620FED594B40
65689	5	52	1609	22724	\N	\N	54.542513999999997	с.Барабо-Юдино, Школьная, 28	Россия, Новосибирская область, Чистоозерный район, поселок Барабо-Юдино	0101000020E61000005F402FDCB92E5340A2CF471971454B40
64362	5	52	4853	37177	\N	\N	54.646014999999998	деревня Тимофеевка, улица Ленина, 25	Россия, Калининградская область, Черняховский район, село Тимофеевка	0101000020E610000079758E01D9E33540DBDC989EB0524B40
65380	5	52	2685	39729	\N	\N	59.057279000000001	село Доронино, улица Центральная, 13	Россия, Вологодская область, Череповецкий район, село Доронино	0101000020E6100000147651F4C00D4340B1DF13EB54874D40
65609	5	52	1505	18675	\N	\N	54.262998000000003	Новосибирская область, Черепановский район, Огнево-Заимковский сельсовет, с. Ясная Поляна, Школьная, 1	Россия, Новосибирская область, Черепановский район, поселок Ясная Поляна	0101000020E6100000B6813B50A7F55440EB7420EBA9214B40
65632	5	52	1505	19875	14133	\N	54.148222429424301	Новосибирская область, Черепановский район, с. Ярки, Новая, 1/1	Россия, Новосибирская область, Черепановский район, поселок Ярки	0101000020E61000006534F279C5D154401B4641F0F8124B40
64397	5	52	1505	19875	14031	\N	54.148978218903103	Новосибирская область, Доволенский район, Ярковский с/с, с.Ярки, Ливенская, 2	Россия, Новосибирская область, Черепановский район, поселок Ярки	0101000020E6100000C5FEB27BF2D1544068E90AB611134B40
65626	5	52	1505	19566	\N	\N	54.011918999999999	Новосибирская область, Черепановский район, Безменовский сельсовет, п. Южный, Школьная, 28	Россия, Новосибирская область, Черепановский район, поселок Южный	0101000020E610000078D503E621DB5440BB99D18F86014B40
94843	5	52	1505	19985	16605	\N	54.074917999999997	Черепановский район, с. Шурыгино, улица Советская, 24		0101000020E61000005A677C5F5CB75440DCF0BBE996094B40
65595	5	52	1505	17523	\N	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Заводская, 20	Россия, Новосибирская область, Черепановский район, Черепаново	0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65593	5	52	1505	17523	\N	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Цыцаркина, 1а	Россия, Новосибирская область, Черепановский район, Черепаново	0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65590	5	52	1505	17523	\N	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Толстого, 6	Россия, Новосибирская область, Черепановский район, Черепаново	0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65598	5	52	1505	17523	13409	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Юбилейная, 11		0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65597	5	52	1505	17523	13391	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Цыцаркина, 54		0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65596	5	52	1505	17523	13790	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Свободная, 59а	Россия, Новосибирская область, Черепановский район, Черепаново	0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65594	5	52	1505	17523	13790	\N	54.220015868102898	Новосибирская область, Черепановский район, город Черепаново, Свободная, 105	Россия, Новосибирская область, Черепановский район, Черепаново	0101000020E6100000E69315C3D5D85440624CFA7B291C4B40
65587	5	52	1505	17523	13398	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Пролетарская, 71а		0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65588	5	52	1505	17523	13924	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Партизанская, 10б		0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65591	5	52	1505	17523	13417	\N	54.220943238302503	Новосибирская область, Черепановский район, город Черепаново, Мичурина, 4	Россия, Новосибирская область, Черепановский район, Черепаново	0101000020E610000012FA997ADDD75440DBA337DC471C4B40
65592	5	52	1505	17523	13387	\N	54.212611874388202	Новосибирская область, Черепановский район, город Черепаново, Линейная, 63	Россия, Новосибирская область, Черепановский район, Черепаново	0101000020E6100000CB660E492DD854405B5EB9DE361B4B40
65589	5	52	1505	17523	13615	\N	54.220874000000002	Новосибирская область, Черепановский район, город Черепаново, Богдана Хмельницкого, 1		0101000020E6100000809A5AB6D6D75440B3446799451C4B40
65646	5	52	1505	20638	13833	\N	54.059049999999999	с. Чащино, улица Центральная, 14	Россия, Новосибирская область, Черепановский район, поселок Чащино	0101000020E610000003ECA35357BD5440166A4DF38E074B40
65614	5	52	1505	18988	13424	\N	54.188738999999998	с. Татарка, улица Заречная, 9	Россия, Новосибирская область, Черепановский район, поселок Татарка	0101000020E61000009775FF5888EE5440683D7C9928184B40
64723	5	52	1505	20197	13690	\N	54.257309678340199	п.Семёновский, Молодёжная, 1	Россия, Новосибирская область, Черепановский район, поселок Семеновский	0101000020E6100000A2B2614D65C254408577B988EF204B40
65619	5	52	1505	19185	13951	\N	54.194639000000002	Новосибирская область, Черепановский район, Искровский сельсовет, с. Романово, Школьная, 5		0101000020E610000089D00836AEDD544059C345EEE9184B40
65648	5	52	1505	20781	\N	\N	54.243088	Новосибирская область, Черепановский район, п. Пятилетка, Центральная, 21а	Россия, Новосибирская область, Черепановский район, поселок Пятилетка	0101000020E61000005B24ED461FD554406806F1811D1F4B40
94842	5	52	1505	19671	67765	\N	54.236527000000002	Черепановский район, п. Пушной, переулок Школьный, 7		0101000020E61000003C66A032FED954407DCF4884461E4B40
65623	5	52	1505	19355	14142	\N	54.123165183716203	п. Привольный, улица Центральная, 8	Россия, Новосибирская область, Черепановский район, поселок Привольный	0101000020E610000061C614AC71D754408481E7DEC30F4B40
65600	5	52	1505	18125	\N	\N	54.300302000000002	Новосибирская область, Черепановский район, рабочий поселок Посевная, Островского, 59	Россия, Новосибирская область, Черепановский район, поселок Посевная	0101000020E61000002159C0046ED554403276C24B70264B40
65599	5	52	1505	18125	\N	\N	54.300302000000002	Новосибирская область, Черепановский район, рабочий поселок Посевная, Островского, 43а	Россия, Новосибирская область, Черепановский район, поселок Посевная	0101000020E61000002159C0046ED554403276C24B70264B40
65606	5	52	1505	18516	\N	\N	54.344008000000002	Новосибирская область, Черепановский район, Медведский сельсовет, п. Падун, Школьная, 10	Россия, Новосибирская область, Черепановский район, поселок Падун	0101000020E61000004C37894160E75440FCC74274082C4B40
65631	5	52	1505	19782	13662	\N	54.192258000000002	Новосибирская область, Черепановский район, п. Отважный, Молодежная, 8		0101000020E61000004721C9ACDED454407B32FFE89B184B40
65608	5	52	1505	49607	16617	\N	54.293596509480203	Новосибирская область, Черепановский район, Огнево-Заимковский сельсовет, с. Огнево-Заимка, Кооперативная, 25	Россия, Новосибирская область, Черепановский район, поселок Огнева Заимка	0101000020E610000003B5183C4CEF5440139A249694254B40
65610	5	52	1505	60692	75573	\N	54.237100876638102	Новосибирская область, Черепановский район, Огнево-Заимковский сельсовет, с. Ново-Шмаково, Центральная, 19	Россия, Новосибирская область, Черепановский район, поселок Новошмаково	0101000020E6100000910DA48B4DEC5440A96C5853591E4B40
65647	5	52	1505	60617	75466	\N	54.091443224652302	Новосибирская область, Черепановский район, с. Ново-Воскресенка, Центральная, 25	Россия, Новосибирская область, Черепановский район, поселок Нововоскресенка	0101000020E6100000F38FBE49D3C354405C397B67B40B4B40
65605	5	52	1505	59165	68676	\N	54.402049661744798	Новосибирская область, Черепановский район, Медведский сельсовет, с. Медведск, Романова, 30	Россия, Новосибирская область, Черепановский район, поселок Медведское	0101000020E610000021AF0793E2E25440ACADD85F76334B40
65629	5	52	1505	19686	13431	\N	54.189969963280603	Новосибирская область, Черепановский район, п. Майский, Шоссейная, 2	Россия, Новосибирская область, Черепановский район, поселок Майский	0101000020E6100000FC8C0B0742D754404E9CDCEF50184B40
64674	5	52	1505	19686	13802	\N	54.189265262221902	п.Майский, Клубная, 12	Россия, Новосибирская область, Черепановский район, поселок Майский	0101000020E6100000C40AB77C24D7544083A3E4D539184B40
65611	5	52	1505	18754	13939	\N	54.299113683061698	Новосибирская область, Черепановский район, Огнево-Заимковский сельсовет, п. Лихановский, Центральная, 20		0101000020E6100000EA5C514A08E854404CE3175E49264B40
65613	5	52	1505	18842	13414	\N	54.150252000000002	Новосибирская область, Черепановский район, Татарский сельсовет, с. Листвянка, Школьная, 6		0101000020E6100000008FA850DDED54404D1421753B134B40
65641	5	52	1505	20409	\N	\N	54.21651	Новосибирская область, Черепановский район, с. Куриловка, Центральная, 25	Россия, Новосибирская область, Черепановский район, поселок Куриловка	0101000020E61000001CB62DCA6CB05440E4A08499B61B4B40
65618	5	52	1505	19117	14132	\N	54.1806089881361	Новосибирская область, Черепановский район, с. Крутишка, Школьная, 2а	Россия, Новосибирская область, Черепановский район, поселок Крутишка	0101000020E6100000282CF180B2C954407F2E1A321E174B40
65644	5	52	1505	20573	16609	\N	54.172967999999997	Новосибирская область, Черепановский район, с. Карасево, Гагарина, 8а		0101000020E6100000E4A3C519C3BF544094A0BFD023164B40
65634	5	52	1505	19976	13667	\N	54.155071	Новосибирская область, Черепановский район, с. Карагужево, Широкая, 6		0101000020E6100000D2FD9C82FCC754406DC7D45DD9134B40
65616	5	52	1505	19029	13945	\N	54.185831	Новосибирская область, Черепановский район, Искровский сельсовет, п. Искра, Центральная, 4а		0101000020E61000007C9BFEEC47DA54409FCA694FC9174B40
65650	5	52	1505	20888	14146	\N	54.221553	Новосибирская область, Черепановский район, п. Инской, Центральная, 4	Россия, Новосибирская область, Черепановский район, поселок Инской	0101000020E6100000739F1C0588CE544054AA44D95B1C4B40
65620	5	52	1505	19258	13653	\N	54.230617000000002	Новосибирская область, Черепановский район, Искровский сельсовет, с. Зимовье, Ленина, 6		0101000020E61000002E1D739EB1E2544069739CDB841D4B40
65625	5	52	1505	19459	13955	\N	54.099555000000002	п. Еловкино, улица Южная, 3		0101000020E6100000E7525C55F6D254409F93DE37BE0C4B40
65604	5	52	1505	18296	\N	\N	54.362946000000001	Новосибирская область, Черепановский район, рабочий поселок Дорогино, Светлая, 23	Россия, Новосибирская область, Черепановский район, поселок Дорогино	0101000020E61000007F677BF486D45440651BB803752E4B40
65603	5	52	1505	18296	\N	\N	54.362946000000001	Новосибирская область, Черепановский район, рабочий поселок Дорогино, Центральная, 37	Россия, Новосибирская область, Черепановский район, поселок Дорогино	0101000020E61000007F677BF486D45440651BB803752E4B40
65602	5	52	1505	18296	\N	\N	54.362946000000001	Новосибирская область, Черепановский район, рабочий поселок Дорогино, Светлая, 21	Россия, Новосибирская область, Черепановский район, поселок Дорогино	0101000020E61000007F677BF486D45440651BB803752E4B40
65601	5	52	1505	18207	\N	\N	54.344507	Новосибирская область, Черепановский район, село Дорогина Заимка, Молодежная, 3	Россия, Новосибирская область, Черепановский район, поселок Дорогина Заимка	0101000020E6100000FA4674CFBACB54401D1F2DCE182C4B40
65649	5	52	1505	20841	13976	\N	54.287123000000001	Новосибирская область, Черепановский район, п. Грибной, Мира, 33		0101000020E6100000C9772975C9CF5440F7764B72C0244B40
65607	5	52	1505	18564	\N	\N	54.331263	Новосибирская область, Черепановский район, Медведский сельсовет, с. Высокая Поляна, Тополиная, 25	Россия, Новосибирская область, Черепановский район, поселок Высокая Поляна	0101000020E610000017A06D35EBE15440FBAF73D3662A4B40
65637	5	52	1505	20104	\N	\N	54.018585000000002	п. Виноград, улица Центральная, 34	Россия, Новосибирская область, Черепановский район, поселок Виноград	0101000020E6100000A46FD23428B854401C9947FE60024B40
94844	5	52	1505	20316	68344	\N	54.3015631034121	Черепановский район, с. Верх-Мильтюши, улица Торговая, 19/1	Россия, Новосибирская область, Черепановский район, поселок Верх-Мильтюши	0101000020E610000037363B527DBA54408257CB9D99264B40
94840	5	52	1505	18832	68444	\N	54.203814000000001	Черепановский район, с. Бураново, улица Советская, 8		0101000020E61000006939D0436DF95440C53BC093161A4B40
65627	5	52	1505	19571	14138	\N	54.250884999999997	Новосибирская область, Черепановский район, Бочкаревский сельсовет, с. Бочкарево, Школьная, 7		0101000020E6100000323A2009FBDD54404A07EBFF1C204B40
94841	5	52	1505	59122	67933	\N	54.082498764521802	Черепановский район, ст. Безменово, улица Вокзальная, 23	Россия, Новосибирская область, Черепановский район	0101000020E6100000344A97FE25D95440F279C5538F0A4B40
65617	5	52	1505	19088	\N	\N	54.123649999999998	Новосибирская область, Черепановский район, Искровский сельсовет, п. Безменово, Центральная, 23а	Россия, Новосибирская область, Черепановский район, поселок Безменово	0101000020E6100000CAA8328CBBDE5440401361C3D30F4B40
65630	5	52	1505	19765	15823	\N	54.174121999999997	Новосибирская область, Черепановский район, п. Бариново, Шоссейная, 4		0101000020E6100000F564FED137D35440CEC133A149164B40
94834	5	52	467	60677	75545	\N	55.335548623545797	Чановский район, курортный поселок Озеро-Карачи, улица Школьная, 58		0101000020E6100000BD715298F73B53404E9A0645F3AA4B40
65538	5	52	467	15138	14514	\N	55.057079000000002	поселок Юрки, Центральная, 20	Россия, Новосибирская область, Чановский район, поселок Юрки	0101000020E610000032CA332F87375340EA245B5D4E874B40
65584	5	52	467	41324	13921	\N	55.350248208331401	село Щеглово, 2-ой переулок, 1/1	Россия, Новосибирская область, Чановский район, поселок Щеглово	0101000020E61000008104C58F31245340A5BE2CEDD4AC4B40
65504	5	52	467	47886	16067	\N	55.033965999999999	дер. Черниговка, ул. Заводская, дом 29,		0101000020E6100000D42AFA43333D5340859675FF58844B40
65529	5	52	467	14422	\N	\N	55.308720000000001	рабочий поселок Чаны, Герцена, 1г	Россия, Новосибирская область, Чановский район, поселок Чаны	0101000020E6100000BBD23252EF30534081CF0F2384A74B40
65526	5	52	467	14422	\N	\N	55.308720000000001	рабочий поселок Чаны, Советская, 120	Россия, Новосибирская область, Чановский район, поселок Чаны	0101000020E6100000BBD23252EF30534081CF0F2384A74B40
65524	5	52	467	14422	\N	\N	55.308720000000001	рабочий поселок Чаны, Победы, 55	Россия, Новосибирская область, Чановский район, поселок Чаны	0101000020E6100000BBD23252EF30534081CF0F2384A74B40
65531	5	52	467	14422	13572	\N	55.312212352129599	рабочий поселок Чаны, Пионерская, 1а		0101000020E6100000B79A75C6F73053409AB51490F6A74B40
65523	5	52	467	14422	16565	\N	55.308720000000001	рабочий поселок Чаны, Маяковского, 60	Россия, Новосибирская область, Чановский район, поселок Чаны	0101000020E6100000BBD23252EF30534081CF0F2384A74B40
65527	5	52	467	14422	14293	\N	55.308328538197699	рабочий поселок Чаны, Ленина, 254а	Россия, Новосибирская область, Чановский район, поселок Чаны	0101000020E610000043C6A354C230534046B41D5377A74B40
65528	5	52	467	14422	14029	\N	55.308720000000001	рабочий поселок Чаны, Зеленая, 30		0101000020E6100000BBD23252EF30534081CF0F2384A74B40
65530	5	52	467	14422	13728	\N	55.308720000000001	рабочий поселок Чаны, Бр.Желтиковых, 178	Россия, Новосибирская область, Чановский район, поселок Чаны	0101000020E6100000BBD23252EF30534081CF0F2384A74B40
65525	5	52	467	14422	13728	\N	55.312000221130901	рабочий поселок Чаны, Бр.Желтиковых, 129	Россия, Новосибирская область, Чановский район, поселок Чаны	0101000020E610000056B60F79CB3053400E2DB29DEFA74B40
65578	5	52	467	17107	\N	\N	55.340952000000001	село Тебисское, 60 лет Октября, 9	Россия, Новосибирская область, Чановский район, поселок Тебисское	0101000020E610000077BAF3C4735D5340BEC0AC50A4AB4B40
65579	5	52	467	49617	16638	\N	55.305676299848599	аул Тебисс, Школьная, 1а	Россия, Новосибирская область, Чановский район, поселок Тебис	0101000020E6100000D0B359F5B96053400796236420A74B40
65563	5	52	467	16353	16345	\N	55.311103000000003	деревня Тармакуль, Центральная, 52		0101000020E61000003276C24B703E534000581D39D2A74B40
65583	5	52	467	17357	16583	\N	55.330240000000003	поселок Танчик, Центральная, 26а		0101000020E61000000F643DB5FA58534060EAE74D45AA4B40
65549	5	52	467	15662	16316	\N	55.464376000000001	поселок Тайский, Тайская, 10/2		0101000020E610000093FC885FB13853400E863AAC70BB4B40
65575	5	52	467	41251	13612	\N	54.955882000000003	село Таган, Береговая, 50	Россия, Новосибирская область, Чановский район, поселок Таган	0101000020E610000076DD5B9198525340E46A64575A7A4B40
94838	5	52	467	16824	13913	\N	55.494869000000001	Чановский район, с. Старые Карачи, улица Центральная,  78В		0101000020E6100000618BDD3EAB425340F1660DDE57BF4B40
64529	5	52	467	29991	14173	\N	55.499713531793397	Новосибирская область, Искитимский район, село Преображенка, ул.Советская, 2 (помещение администрации МО)	Россия, Новосибирская область, Чановский район, поселок Старая Преображенка	0101000020E6100000965AEF37DA4253403AADDBA0F6BF4B40
94833	5	52	467	49593	16528	\N	55.377367999999997	Чановский район, д. Север, улица Центральная, 2Б/1		0101000020E610000093196F2BBD355340494739984DB04B40
94839	5	52	467	17196	68722	\N	55.408454999999996	Чановский район, п. Приомский, улица Восточная, 12А		0101000020E6100000224F92AE996953409F71E14048B44B40
65553	5	52	467	41285	13754	\N	55.125627999999999	село Полтавка, Школьная, 58	Россия, Новосибирская область, Чановский район, поселок Полтавка	0101000020E6100000B91803EB381E53401FBB0B9414904B40
94837	5	52	467	49675	68674	\N	55.560020999999999	Чановский район, с. Покровка, улица Московская, 14		0101000020E6100000FD135CACA84E53405F09A4C4AEC74B40
94836	5	52	467	41252	68424	\N	55.446497999999998	Чановский район, д. Погорелка, улица Центральная, 66		0101000020E6100000B2BCAB1E305C53405DDDB1D826B94B40
65550	5	52	467	15690	13889	\N	55.025967999999999	село Песчаное Озеро, Центральная, 13		0101000020E61000006D8FDE701F2953400B5F5FEB52834B40
65532	5	52	467	14867	\N	\N	55.300018999999999	поселок Песцы, Центральная, 1	Россия, Новосибирская область, Чановский район, поселок Песцы	0101000020E6100000F78F85E8102B5340DD96C80567A64B40
94835	5	52	467	16373	68388	\N	55.119342000000003	Чановский район, с. Отреченское, улица Школьная, 8		0101000020E610000012691B7FA24E534006854199468F4B40
65574	5	52	467	16906	14115	\N	55.4963505308028	деревня Осинцево, Широкая, 33а		0101000020E610000006BD3786004F53401F2BF86D88BF4B40
64837	5	52	467	16906	13927	\N	55.497230000000002	д. Осинцево, ул. Гагарина, 3/2	Россия, Новосибирская область, Чановский район, поселок Осинцево	0101000020E610000093AAED26F84E5340884B8E3BA5BF4B40
65586	5	52	467	17500	13386	\N	55.444788000000003	деревня Оравка, Центральная, 66		0101000020E61000009C6A2DCC422353409ED32CD0EEB84B40
65559	5	52	467	60681	75553	\N	55.334374805197797	Новосибирская область, Чановский район, Озеро-Карачинский сельсовет, Школьная, 32	Россия, Новосибирская область, Чановский район	0101000020E6100000E38BF678213C5340CDCCCCCCCCAA4B40
65558	5	52	467	16079	\N	\N	55.350535000000001	поселок Озеро Карачи, Вокзальная, 2а	Россия, Новосибирская область, Чановский район, поселок Озеро-Карачи	0101000020E61000001BA19FA9D73D53403B8DB454DEAC4B40
65562	5	52	467	16293	13596	\N	55.366777999999996	поселок Новояркуль, Гагарина, 7	Россия, Новосибирская область, Чановский район, поселок Новояркуль	0101000020E6100000AC55BB26A43D53403672DD94F2AE4B40
65577	5	52	467	17056	\N	\N	54.880406999999998	деревня Новояблоновка, Широкая, 37	Россия, Новосибирская область, Чановский район, поселок Новояблоновка	0101000020E6100000929735B1C0535340B115342DB1704B40
65536	5	52	467	15031	13745	\N	55.128362000000003	село Новофеклино, Абрамовская, 19		0101000020E6100000E38BF678214253404B06802A6E904B40
65554	5	52	467	41245	13587	\N	55.342596	поселок Новопреображенка, Центральная, 82	Россия, Новосибирская область, Чановский район, поселок Новопреображенка	0101000020E6100000ACC8E88024465340C6DE8B2FDAAB4B40
65567	5	52	467	16525	\N	\N	55.042819000000001	поселок Нововасильевский, Центральная, 27	Россия, Новосибирская область, Чановский район, поселок Нововасильевский	0101000020E610000022C32ADEC8575340DF52CE177B854B40
64988	5	52	467	41325	13926	\N	55.334321674853399	д.Николаевка, улица Зеленая,36	Россия, Новосибирская область, Чановский район, поселок Николаевка	0101000020E6100000658F5033A42B5340AA2A3410CBAA4B40
65813	5	52	1354	28414	\N	\N	54.938208000000003	Новосибирская область, рабочий поселок Кольцово, 9А		0101000020E6100000683F524486CB54403C6C223317784B40
65533	5	52	467	2743	14085	\N	55.295724	поселок Моховое, Школьная, 1	Россия, Новосибирская область, Чановский район, поселок Моховое	0101000020E610000042B0AA5E7E3453403752B648DAA54B40
65286	5	52	467	2743	13836	\N	55.295724	д. Моховое, Школьная, 2		0101000020E610000042B0AA5E7E3453403752B648DAA54B40
65570	5	52	467	16688	14175	\N	55.401575000000001	поселок Межгривный, Школьная, 1	Россия, Новосибирская область, Чановский район, поселок Межгривный	0101000020E61000003CF54883DB4D534013F241CF66B34B40
65547	5	52	467	49618	16642	\N	55.485082566196397	поселок Малый Тебисс, Школьная, 26	Россия, Новосибирская область, Чановский район, поселок Малый Тебис	0101000020E61000008B37328FFC2D53403C6C223317BE4B40
65546	5	52	467	40418	13798	\N	55.536075840950701	село Красное, Школьная, 6	Россия, Новосибирская область, Чановский район, поселок Красное	0101000020E6100000E59997C3EE335340D3156C239EC44B40
65557	5	52	467	48553	16226	\N	55.363047999999999	станция Кошкуль, Северная, 14	Россия, Новосибирская область, Чановский район	0101000020E61000005C21ACC6124A534069705B5B78AE4B40
65556	5	52	467	48553	16631	\N	55.289228560801099	аул Кошкуль, улица Кооперативная, 36		0101000020E61000009F01F566D44B53400307B47405A54B40
65552	5	52	467	15749	\N	\N	55.134106000000003	п. Ковыльный, улица Школьная, 28	Россия, Новосибирская область, Чановский район, поселок Ковыльный	0101000020E6100000AC71361D012C53404419AA622A914B40
65540	5	52	467	15230	\N	\N	55.188751000000003	деревня Кабаклы, Приозёрная, 20	Россия, Новосибирская область, Чановский район, поселок Кабаклы	0101000020E610000023DBF97E6A2153402D0B26FE28984B40
65576	5	52	467	45826	\N	\N	55.024141	деревня Зенкино, Зеленая, 33	Россия, Новосибирская область, Чановский район, поселок Зенкино	0101000020E6100000B894F3C5DE47534012BF620D17834B40
65539	5	52	467	15149	16577	\N	55.171559999999999	село Земляная Заимка, Центральная, 32	Россия, Новосибирская область, Чановский район, поселок Земляная Заимка	0101000020E61000009291B3B0A7275340A0A696ADF5954B40
65566	5	52	467	16444	\N	\N	55.090232	п. Двуозерный, улица Центральная, 20	Россия, Новосибирская область, Чановский район, поселок Двуозерный	0101000020E6100000462234828D4D5340BE86E0B88C8B4B40
65534	5	52	467	14956	\N	\N	55.113014	село Блюдчанское, Центральная, 16	Россия, Новосибирская область, Чановский район, поселок Блюдчанское	0101000020E61000002ECA6C9049395340BDFE243E778E4B40
65535	5	52	467	15004	14089	\N	54.948312999999999	деревня Блюдцы, Центральная, 26		0101000020E6100000C780ECF5EE3F534092AF045262794B40
65561	5	52	467	16213	14116	\N	55.261566999999999	деревня Белехта, Молодежная, 23	Россия, Новосибирская область, Чановский район, поселок Белехта	0101000020E610000040FB9122323453403E5B07077BA14B40
65568	5	52	467	60697	75580	\N	55.171199999999999	аул Аялу, улица Центральная, 12	Россия, Новосибирская область, Чановский район, поселок Аялу	0101000020E61000006E85B01A4B535340A089B0E1E9954B40
65518	5	52	1204	14197	14023	\N	55.845602	с.Яркуль-Матюшкино, Центральная, дом культуры		0101000020E61000004E42E90B2106534052B7B3AF3CEC4B40
94831	5	52	1204	49674	68644	\N	55.991993999999998	Усть-Таркский район, село Яркуль, ул. Школьная, дом 4,		0101000020E6100000A73B4F3C67EB524003EACDA8F9FE4B40
65469	5	52	1204	11887	13468	\N	55.9913598790545	дер.Янабино,  ул. Крестьянская, дом 4\\1,	Россия, Новосибирская область, Усть-Таркский район, поселок Янабино	0101000020E6100000D8BCAAB35A0F534002486DE2E4FE4B40
94830	5	52	1204	41233	13547	\N	55.548192	Усть-Таркский район, село Щербаки  , ул. Кооперативная, дом 2,		0101000020E6100000A7EB89AE0BEB5240E4F6CB272BC64B40
65506	5	52	1204	13573	14297	\N	56.0997405686579	дер. Чичканка  , ул. Есенина, дом 10,	Россия, Новосибирская область, Усть-Таркский район, поселок Чичканка	0101000020E6100000551344DD070E534001892650C40C4C40
65537	5	52	1204	41282	13743	\N	56.016993507041903	деревня Черниговка, Большая, 20	Россия, Новосибирская область, Усть-Таркский район, поселок Черниговка	0101000020E6100000F7CDFDD5E3005340361D01DC2C024C40
66196	5	52	1204	13667	\N	\N	55.566206000000001	с.Усть-Тарка, Транспортная, 1 административное здание	Россия, Новосибирская область, Усть-Таркский район, поселок Усть-Тарка	0101000020E610000008E9297288EC524045662E7079C84B40
65509	5	52	1204	13667	14193	\N	55.566206000000001	с.Усть-Тарка, Дзержинского, 12 районный Дом культуры		0101000020E610000008E9297288EC524045662E7079C84B40
65507	5	52	1204	13667	13529	\N	55.566206000000001	село Усть-Тарка  , ул. Комсомольская, дом 103,	Россия, Новосибирская область, Усть-Таркский район, поселок Усть-Тарка	0101000020E610000008E9297288EC524045662E7079C84B40
94828	5	52	1204	13438	68641	\N	56.030546999999999	Усть-Таркский район, село Угуй, ул. Центральная, дом 6,		0101000020E6100000F33CB83B6B035340D6FECEF6E8034C40
65492	5	52	1204	48745	\N	\N	55.768096	дер. Тихоновка  , ул. Центральная, дом 29,	Россия, Новосибирская область, Усть-Таркский район, поселок Тихоновка	0101000020E6100000A723809BC5F852401E1840F850E24B40
65483	5	52	1204	12555	\N	\N	55.609130999999998	дер. Тарка, ул. Центральная, дом 7,	Россия, Новосибирская область, Усть-Таркский район, поселок Тарка	0101000020E61000007C293C6876E8524069FD2D01F8CD4B40
65494	5	52	1204	13049	14053	\N	55.907702	дер. Силиш,  ул. Старосилишинская, дом 11,	Россия, Новосибирская область, Усть-Таркский район, поселок Силиш	0101000020E6100000642310AFEBF65240C44142942FF44B40
65501	5	52	1204	13325	16557	\N	55.845764000000003	дер. Резино  , ул. Центральная, дом 24,		0101000020E6100000286552431BD352402C11A8FE41EC4B40
94827	5	52	1204	41226	13526	\N	55.646949999999997	Усть-Таркский район, село Победа, ул. Центральная, дом 30,		0101000020E61000004450357A35E35240D712F241CFD24B40
94819	5	52	1204	49672	68442	\N	55.938642000000002	Усть-Таркский район, пос. Октябрьский, ул. Школьная, дом 2,		0101000020E61000002E20B41EBE0853407653CA6B25F84B40
65197	5	52	1204	41345	16072	\N	55.715930344729102	НСО, Северный район, Верх-Красноярский сельсовет, д. Новоникольск, Центральная, 22а	Россия, Новосибирская область, Усть-Таркский район, поселок Новоникольск	0101000020E610000057D11F9A79FE5240D61C2098A3DB4B40
65486	5	52	1204	44419	\N	\N	55.722056000000002	дер. Мураши,  ул. Широкая, дом 27,	Россия, Новосибирская область, Усть-Таркский район, поселок Мураши	0101000020E6100000F6D03E56F0E45240B7F0BC546CDC4B40
65513	5	52	1204	46038	68984	\N	55.497127999999996	дер. Михайловка, ул. Луговая, дом 27,		0101000020E61000006B0C3A2174E4524083F6EAE3A1BF4B40
65468	5	52	1204	41203	13470	\N	55.997316336369003	пос. Мирный, ул. Школьная, дом 4,		0101000020E6100000693524EEB108534086E3F90CA8FF4B40
65397	5	52	1204	41203	13470	\N	55.996113807251497	поселок Мирный, улица Школьная, 8	Россия, Новосибирская область, Усть-Таркский район, поселок Мирный	0101000020E610000055F7C8E6AA0853403B8BDEA980FF4B40
94832	5	52	1204	40417	68646	\N	56.061352999999997	Усть-Таркский район, дер. Мартыново, ул. Степная, дом 13,		0101000020E6100000B33F506EDBEF52407841446ADA074C40
94824	5	52	1204	12657	16541	\N	55.671414585206598	Усть-Таркский район, село Кушаги, ул. Береговая, дом 21А,	Россия, Новосибирская область, Усть-Таркский район, поселок Кушаги	0101000020E610000078D2C26515F052409D853DEDF0D54B40
94823	5	52	1204	41302	13837	\N	55.514803999999998	Усть-Таркский район, село Козино , ул. Школьная, дом 15,		0101000020E6100000670B08AD87DF5240CCECF318E5C14B40
94821	5	52	1204	48479	68684	\N	55.623671000000002	Усть-Таркский район, село Камышево , ул. Школьная, дом 42А,		0101000020E6100000923CD7F7E1015340583B8A73D4CF4B40
64807	5	52	1204	41384	\N	\N	55.580736999999999	поселок Зеленая Роща, улица Мира ,10	Россия, Новосибирская область, Усть-Таркский район, поселок Зеленая Роща	0101000020E6100000952BBCCB45DE5240E0490B9755CA4B40
94820	5	52	1204	49673	68366	\N	55.625591999999997	Усть-Таркский район, село Еланка,  ул. Гагарина, дом 39,		0101000020E610000088D68A36C7D25240D2510E6613D04B40
65466	5	52	1204	11705	13989	\N	55.947427604337499	дер. Дубровино, ул. Озерная, дом 20,	Россия, Новосибирская область, Усть-Таркский район, поселок Дубровино	0101000020E6100000774EB340BB10534048A8195245F94B40
65074	5	52	1204	11705	13669	\N	55.948016255553298	д. Дубровино, Кооперативная, 10	Россия, Новосибирская область, Усть-Таркский район, поселок Дубровино	0101000020E610000089F02F82C6105340D90A9A9658F94B40
65498	5	52	1204	41230	13530	\N	55.708546972285497	дер. Дмитриевка  , ул. Зеленая, дом 16,	Россия, Новосибирская область, Усть-Таркский район, поселок Дмитриевка	0101000020E6100000D61EF64201DA5240E75608ABB1DA4B40
94822	5	52	1204	40414	68638	\N	55.504924000000003	Усть-Таркский район, дер.Верхнеомка  , ул. Школьная, дом 6,		0101000020E6100000726BD26D89005340967B8159A1C04B40
64582	5	52	1204	40415	14302	\N	55.517439000000003	село Богословка, улица Школьная, 32 А	Россия, Новосибирская область, Усть-Таркский район, поселок Богословка	0101000020E6100000E4486760E4F552406556EF703BC24B40
94829	5	52	1204	40415	68720	\N	55.517439000000003	Усть-Таркский район, дер. Богословка  , ул. Зеленая, дом 21,		0101000020E6100000E4486760E4F552406556EF703BC24B40
65329	5	52	5442	38000	\N	\N	54.469164999999997	деревня Кабанка, Школьная, 4 А	Россия, Челябинская область, Увельский район, поселок Кабанка	0101000020E6100000D2C43BC093864E40C3B645990D3C4B40
65431	5	52	1091	41293	13805	\N	55.540086595436698	село Черный Мыс, Руднева, 29	Россия, Новосибирская область, Убинский район, поселок Черный Мыс	0101000020E610000079CC4065FC04544054FF209221C54B40
65435	5	52	1091	10249	\N	\N	55.054175999999998	деревня Херсонка, Мира, 21	Россия, Новосибирская область, Убинский район, поселок Херсонка	0101000020E61000003481221631F35340321D3A3DEF864B40
65462	5	52	1091	9646	\N	\N	55.300460000000001	с. Убинское, площадь 50лет Октября, 5	Россия, Новосибирская область, Убинский район, поселок Убинское	0101000020E61000007104A9143BEB5340CAE0287975A64B40
65423	5	52	1091	9646	\N	\N	55.300460000000001	село Убинское, Ленина, 33	Россия, Новосибирская область, Убинский район, поселок Убинское	0101000020E61000007104A9143BEB5340CAE0287975A64B40
65424	5	52	1091	9646	13885	\N	55.301911505679598	село Убинское, Элеваторная, 3	Россия, Новосибирская область, Убинский район, поселок Убинское	0101000020E610000045F12A6B9BEB53408E226B0DA5A64B40
65456	5	52	1091	9646	13824	\N	55.300460000000001	село Убинское, Матросова, 26	Россия, Новосибирская область, Убинский район, поселок Убинское	0101000020E61000007104A9143BEB5340CAE0287975A64B40
65433	5	52	1091	10145	\N	\N	55.188637	село Раисино, Кирова, 78	Россия, Новосибирская область, Убинский район, поселок Раисино	0101000020E6100000328FFCC1C0E5534064E8D84125984B40
65429	5	52	1091	47581	\N	\N	55.640889000000001	деревня Пешково, Центральная, 33	Россия, Новосибирская область, Убинский район, поселок Пешково	0101000020E61000003604C765DCEB5340DEAE97A608D24B40
65430	5	52	1091	41258	13656	\N	55.510308000000002	село Орловское, Центральная, 24	Россия, Новосибирская область, Убинский район, поселок Орловское	0101000020E6100000226C787AA5EE53408F71C5C551C14B40
65428	5	52	1091	9925	13418	\N	55.703515000000003	село Новодубровское, Центральная, 39		0101000020E6100000651A4D2EC6FE53406B9F8EC70CDA4B40
65443	5	52	1091	10651	\N	\N	55.006760999999997	село Новогандичево, Центральная, 15	Россия, Новосибирская область, Убинский район, поселок Новогандичево	0101000020E6100000CEC64ACCB3D25340B2F1608BDD804B40
94818	5	52	1091	41336	13975	\N	55.185302	Убинский район, п. Николаевка 2-я, улица Центральная, 21	Россия, Новосибирская область, Убинский район, поселок Николаевский 2-й	0101000020E610000009336DFFCAC0534013F1D6F9B7974B40
65446	5	52	1091	41332	13967	\N	55.248694	поселок Московка, Московская, 21	Россия, Новосибирская область, Убинский район, поселок Московка	0101000020E61000001EFCC401F4F25340105B7A34D59F4B40
65444	5	52	1091	10718	\N	\N	54.903452999999999	село Кундран, Новая, 2	Россия, Новосибирская область, Убинский район, поселок Кундран	0101000020E610000077F4BF5C8BD453408E3C1059A4734B40
65448	5	52	1091	10948	13458	\N	55.4409677439129	д. Ксеньевка, улица Озерная, 19	Россия, Новосибирская область, Убинский район, поселок Ксеньевка	0101000020E6100000DFDFA0BDFADB5340904AB1A371B84B40
47325	5	49	\N	1225	72275	\N	55.981625999999999	Красноярск, Судостроительная, 38А		0101000020E6100000F910548D5E3557409F73B7EBA5FD4B40
65439	5	52	1091	10459	\N	\N	55.079725000000003	село Круглоозерное, Школьная, 21	Россия, Новосибирская область, Убинский район, поселок Круглоозерное	0101000020E6100000C0B2D2A414D3534039D6C56D348A4B40
65440	5	52	1091	10459	13963	\N	55.079725000000003	село Круглоозерное, Школьная, 19		0101000020E6100000C0B2D2A414D3534039D6C56D348A4B40
65426	5	52	1091	41327	13941	\N	55.4021210537706	поселок Крещенский, Цветочная, 10	Россия, Новосибирская область, Убинский район, поселок Крещенский	0101000020E6100000D66EBBD05CF15340750470B378B34B40
65451	5	52	1091	41260	13670	\N	55.433965999999998	с. Колмаково, улица Центральная, 13б	Россия, Новосибирская область, Убинский район, поселок Колмаково	0101000020E61000008D96033DD4D15340B8C9A8328CB74B40
65458	5	52	1091	11290	16610	\N	55.340558000000001	село Кожурла, Трудовая, 1	Россия, Новосибирская область, Убинский район, поселок Кожурла	0101000020E61000007C293C6876C253401232906797AB4B40
65457	5	52	1091	11290	13820	\N	55.340558000000001	село Кожурла, Ленинская, 1	Россия, Новосибирская область, Убинский район, поселок Кожурла	0101000020E61000007C293C6876C253401232906797AB4B40
65453	5	52	1091	11177	16460	\N	55.324238000000001	станция Клубничная, Центральная, 7	Россия, Новосибирская область, Убинский район, поселок Клубничная	0101000020E610000023861DC6A4D553406B0F7BA180A94B40
65437	5	52	1091	41330	13960	\N	55.124738000000001	деревня Кирилловка, Школьная, 2		0101000020E61000009C53C90050DD5340C3482F6AF78F4B40
65434	5	52	1091	41215	13490	\N	55.145766000000002	деревня Каменка, Центральная, 39	Россия, Новосибирская область, Убинский район, поселок Каменка	0101000020E6100000C765DCD440EB5340336FD575A8924B40
65445	5	52	1091	41297	13821	\N	55.317768000000001	село Ермолаевка, Центральная, 23	Россия, Новосибирская область, Убинский район, поселок Ермолаевка	0101000020E6100000350D8AE601FA534090DB2F9FACA84B40
65447	5	52	1091	41295	13817	\N	55.374760003417101	село Владимировское, Школьная, 26	Россия, Новосибирская область, Убинский район, поселок Владимировское	0101000020E6100000111B2C9CA4E65340ABECBB22F8AF4B40
94817	5	52	1091	41335	13974	\N	55.271149000000001	Убинский район, с. Борисоглебка, улица Школьная, 9	Россия, Новосибирская область, Убинский район, поселок Борисоглебский	0101000020E6100000E61E12BEF7D35340EBABAB02B5A24B40
65461	5	52	1091	11442	\N	\N	55.155931000000002	поселок Белоозерный, Центральная, 36	Россия, Новосибирская область, Убинский район, поселок Белоозерный	0101000020E6100000E6762FF7C9CB53405FB7088CF5934B40
94816	5	52	1091	10113	13420	\N	55.239615000000001	Убинский район, д. Асенкритово, улица Центральная, 39		0101000020E6100000AA0CE36E10E55340C6504EB4AB9E4B40
65459	5	52	1091	48132	16537	\N	55.258052999999997	село Александро-Невское, Школьная, 1б		0101000020E61000007A6F0C01C0CA53403DD175E107A14B40
65516	5	52	5368	37903	\N	\N	57.211421000000001	дер. Воробьи  , ул. Трудовая, дом 9,	Россия, Нижегородская область, Тонкинский район, поселок Воробьи	0101000020E6100000C8B3CBB73E0247400458E4D70F9B4C40
65452	5	52	3763	35629	\N	\N	47.650725000000001	село Новоселово, Луговая, 5б	Россия, Сахалинская область, Томаринский район, село Новоселово	0101000020E61000006E15C440D7BF614045D8F0F44AD34740
65366	5	52	843	41296	13819	\N	55.180768	станция Изынский, улица Путейская, 4	Россия, Новосибирская область, Тогучинский район	0101000020E61000002C7FBE2D58F75440E814E46723974B40
65367	5	52	843	41255	13644	\N	55.147409013052801	станция Буготак, улица Железнодорожная, 4	Россия, Новосибирская область, Тогучинский район	0101000020E6100000F25B74B2D4F054406B11514CDE924B40
65375	5	52	843	7421	\N	\N	55.285558000000002	село Янченково, улица Школьная, 9	Россия, Новосибирская область, Тогучинский район, поселок Янченково	0101000020E6100000DE21C500891055403B8E1F2A8DA44B40
94805	5	52	843	41294	13808	\N	54.851256999999997	Тогучинский район, село Юрты, улица Центральная, 99		0101000020E610000018B2BAD573335540DBBE47FDF56C4B40
65401	5	52	843	8690	\N	\N	55.077685000000002	село Шубкино, лица Центральная, 17	Россия, Новосибирская область, Тогучинский район, поселок Шубкино	0101000020E6100000A2D5C9198A0F5540E4310395F1894B40
94815	5	52	843	9629	67757	\N	55.095770999999999	Тогучинский район, поселок Шахта, улица Долгих, 1		0101000020E6100000DC2E34D769305540DE736039428C4B40
65420	5	52	843	9496	\N	\N	54.851163	село Чемское, улица Центральная, 28	Россия, Новосибирская область, Тогучинский район, поселок Чемское	0101000020E61000007DE71725E8FC54405A48C0E8F26C4B40
94814	5	52	843	40240	9633	\N	55.002749000000001	Тогучинский район, село Усть-Каменка, улица Мира, 24/1		0101000020E6100000FB928D075BF65440618C48145A804B40
65358	5	52	843	6267	\N	\N	55.242221999999998	город Тогучин, улица Крупская, 7	Россия, Новосибирская область, Тогучинский район, Тогучин	0101000020E61000005CCB64389E185540942F6821019F4B40
65355	5	52	843	6267	\N	\N	55.242221999999998	город Тогучин, улица Садовая, 25	Россия, Новосибирская область, Тогучинский район, Тогучин	0101000020E61000005CCB64389E185540942F6821019F4B40
65353	5	52	843	6267	14087	\N	55.242221999999998	город Тогучин, улица Школьная, 2 б		0101000020E61000005CCB64389E185540942F6821019F4B40
94802	5	52	843	6267	68606	\N	55.242516228021003	Тогучинский район, город Тогучин, улица Челюскинцев, 34	Россия, Новосибирская область, Тогучинский район, Тогучин	0101000020E61000005E6743FE99185540DD60A8C30A9F4B40
65354	5	52	843	6267	14098	\N	55.239344509672897	город Тогучин, улица Центральная, 60	Россия, Новосибирская область, Тогучинский район, Тогучин	0101000020E6100000FA9AE5B2D119554006BB61DBA29E4B40
65360	5	52	843	6267	14041	\N	55.242221999999998	город Тогучин, улица Трактовая, 2		0101000020E61000005CCB64389E185540942F6821019F4B40
65356	5	52	843	6267	13904	\N	55.228468293701802	город Тогучин, улица Свердлова, 5	Россия, Новосибирская область, Тогучинский район, Тогучин	0101000020E6100000A13193A8171A55405D177E703E9D4B40
65357	5	52	843	6267	14100	\N	55.2404670472107	город Тогучин, улица Никитина, 43	Россия, Новосибирская область, Тогучинский район, Тогучин	0101000020E6100000E8F86871C61955403562669FC79E4B40
65359	5	52	843	6267	13888	\N	55.240074708076797	город Тогучин, улица Дзержинского, 10	Россия, Новосибирская область, Тогучинский район, Тогучин	0101000020E6100000E90DF7915B19554029CB10C7BA9E4B40
94812	5	52	843	46241	15666	\N	55.305568999999998	Тогучинский район, село Сурково, переулок Клубный, 2		0101000020E61000003F73D6A71C215540F1D58EE21CA74B40
94811	5	52	843	9062	13403	\N	54.849598	Тогучинский район, село Степногутово, улица Школьная, 43		0101000020E6100000C1AA7AF99D3D55409E5F94A0BF6C4B40
65398	5	52	843	8546	13922	\N	54.744309999999999	село Старогутово, улица Центральная, 29	Россия, Новосибирская область, Тогучинский район, поселок Старогутово	0101000020E610000024ED461FF3265540FA0AD28C455F4B40
65392	5	52	843	41288	13771	\N	54.975253000000002	поселок Смирновка,, улица Лесная, 5	Россия, Новосибирская область, Тогучинский район, поселок Смирновка	0101000020E6100000F64201DBC1305540B7291E17D57C4B40
65386	5	52	843	7913	13761	\N	55.155379883458302	деревня Саламатово, улица Крестьянская, 16	Россия, Новосибирская область, Тогучинский район, поселок Саламатово	0101000020E6100000D13DEB1A2D315540EB39E97DE3934B40
94813	5	52	843	9333	68636	\N	55.279344000000002	Тогучинский район, поселок Русско-Семеновский, улица Школьная, 16		0101000020E610000026AAB706B61E5540BB2A508BC1A34B40
94810	5	52	843	9003	68386	\N	55.061039000000001	Тогучинский район, село Репьево, улица Центральная, 25		0101000020E610000083143C855CDD5440E9633E20D0874B40
65370	5	52	843	7211	14043	\N	55.056436132503599	село Пойменное, улица Клубная, 2	Россия, Новосибирская область, Тогучинский район, поселок Пойменное	0101000020E61000001AC1C6F5EF1A554095287B4B39874B40
65381	5	52	843	7694	\N	\N	54.891700999999998	село Новоабышево, улица Центральная, 20	Россия, Новосибирская область, Тогучинский район, поселок Новоабышево	0101000020E6100000D482177D05225540BE67244223724B40
65362	5	52	843	41371	14091	\N	55.207986296618898	поселок Нечаевский, улица Весенняя, 12	Россия, Новосибирская область, Тогучинский район, поселок Нечаевский	0101000020E61000005B5EB9DE361855404F0306499F9A4B40
65418	5	52	843	9397	16592	\N	54.947159999999997	деревня Налетиха, улица Центральная, 27		0101000020E6100000ED6305BF0DF95440280AF4893C794B40
64751	5	52	843	41355	14013	\N	54.725223080326401	п.Мирный, Школьная, 17	Россия, Новосибирская область, Тогучинский район, поселок Мирный	0101000020E61000009B00C3F2E72F55404CA7751BD45C4B40
65409	5	52	843	9049	13393	\N	55.119069000000003	село Льниха, улица Центральная, 4	Россия, Новосибирская область, Тогучинский район, поселок Льниха	0101000020E6100000F1B73D4162E85440D57B2AA73D8F4B40
94809	5	52	843	8855	68365	\N	55.000843000000003	Тогучинский район, село Лекарственное, улица Центральная, 51		0101000020E6100000BA1457957DE954401CB7989F1B804B40
94807	5	52	843	41185	13399	\N	54.917008000000003	Тогучинский район, село Лебедево, улица Центральная, 51		0101000020E6100000575F5D15A8155540CF15A58460754B40
65390	5	52	843	49610	16626	\N	55.2589302700544	деревня Кусьмень, улица Новая, 6	Россия, Новосибирская область, Тогучинский район, поселок Кусмень	0101000020E6100000BF44BC75FE32554005FA449E24A14B40
65394	5	52	843	8356	13920	\N	55.054465	село Курундус, улица Суворова, 15	Россия, Новосибирская область, Тогучинский район, поселок Курундус	0101000020E61000007289230F4432554069E388B5F8864B40
65387	5	52	843	46713	\N	\N	55.249966000000001	село Кудрино, улица Центральная, 1	Россия, Новосибирская область, Тогучинский район, поселок Кудрино	0101000020E6100000A59F70766B125540548EC9E2FE9F4B40
94806	5	52	843	8550	68382	\N	55.160030999999996	Тогучинский район, село Кудельный Ключ, улица Лесная, 2		0101000020E61000007365506D701055404FAC53E57B944B40
65395	5	52	843	8392	\N	\N	54.826301999999998	село Коурак, улица Центральная, 35	Россия, Новосибирская область, Тогучинский район, поселок Коурак	0101000020E6100000D2393FC5712B5540484F9143C4694B40
65411	5	52	843	9129	\N	\N	54.789078000000003	деревня Колтырак, улица Центральная, 42	Россия, Новосибирская область, Тогучинский район, поселок Колтырак	0101000020E610000048A7AE7C963A55401EFF058200654B40
65378	5	52	843	46542	\N	\N	55.294103999999997	поселок Ковалевка, улица Центральная, 25 кв 1	Россия, Новосибирская область, Тогучинский район, поселок Ковалевка	0101000020E61000009B1E1494A20E5540B7CF2A33A5A54B40
65389	5	52	843	8068	\N	\N	55.245825000000004	село Киик, улица Центральная, 14	Россия, Новосибирская область, Тогучинский район, поселок Киик	0101000020E6100000635FB2F1602C554005C58F31779F4B40
65406	5	52	843	8897	\N	\N	55.042302999999997	село Карпысак,  улица Центральная, 86	Россия, Новосибирская область, Тогучинский район, поселок Карпысак	0101000020E61000001F11532289ED5440E7C2482F6A854B40
65372	5	52	843	7314	\N	\N	55.025734999999997	поселок Кадниха, улица Центральная, 18/2	Россия, Новосибирская область, Тогучинский район, поселок Кадниха	0101000020E610000082583673480F554068AED3484B834B40
65364	5	52	843	6930	\N	\N	55.182355999999999	поселок Изынский, улица Центральная, 2 б	Россия, Новосибирская область, Тогучинский район, поселок Изынский	0101000020E6100000A3E5400FB5FF54405C1D007157974B40
65383	5	52	843	7777	13604	\N	55.170585371448297	деревня Изылы, улица Озёрная, 1	Россия, Новосибирская область, Тогучинский район, поселок Изылы	0101000020E6100000F110C64FE32455401618B2BAD5954B40
65388	5	52	843	46745	16373	\N	55.257354999999997	село Златоуст, улица Центральная, 56		0101000020E610000003B68311FB085540253B3602F1A04B40
65382	5	52	843	46631	16361	\N	55.154778999999998	село Заречное, улица Гагарина, 1		0101000020E6100000F75965A6B4275540C58D5BCCCF934B40
65414	5	52	843	41326	13933	\N	55.438507000000001	деревня Долгово, улица Школьная, 2	Россия, Новосибирская область, Тогучинский район, поселок Долгово	0101000020E6100000A5F44C2F311D5540960854FF20B84B40
94808	5	52	843	59170	68738	\N	55.0009155846559	Тогучинский район, село Дергоусово, улица Школьная, 14	Россия, Новосибирская область, Новосибирск, 2-я Школьная улица	0101000020E61000000C3CF71E2EB854408505F7031E804B40
94803	5	52	843	44098	67755	\N	55.1243650181475	Тогучинский район, рабочий поселок Горный, улица Юбилейная, 1	Россия, Новосибирская область, Тогучинский район, поселок Горный	0101000020E61000000806103E94F954402EE23B31EB8F4B40
65042	5	52	843	44098	15003	\N	55.124459999999999	п. Горный, улица Рабочая, д. 29	Россия, Новосибирская область, Тогучинский район, поселок Горный	0101000020E61000001DB0ABC953F9544080D4264EEE8F4B40
94804	5	52	843	44098	67772	\N	55.124459999999999	Тогучинский район, рабочий поселок Горный, улица Планетная, 4		0101000020E61000001DB0ABC953F9544080D4264EEE8F4B40
65384	5	52	843	46663	\N	\N	55.116793999999999	деревня Гаревка,  улица Центральная, 32	Россия, Новосибирская область, Тогучинский район, поселок Гаревка	0101000020E61000009702D2FE072255403C2F151BF38E4B40
64186	5	52	843	41331	13965	\N	54.959913999999998	село Владимировка, Садовая, 38		0101000020E6100000DBFCBFEAC8FF54407C7C4276DE7A4B40
65421	5	52	843	41331	14151	\N	54.962037707120501	село Владимировка, улица Озерная, 15/1	Россия, Новосибирская область, Тогучинский район, поселок Владимировка	0101000020E61000009D9FE238F0FF54402FC1A90F247B4B40
65415	5	52	843	9279	13406	\N	55.445855000000002	деревня Верх-Ачино, улица Центральная, 19		0101000020E6100000C095ECD80828554009E1D1C611B94B40
65371	5	52	843	7249	13896	\N	55.057456000000002	село Вассино, улица Центральная, 20/5		0101000020E610000009FEB7921D185540C07ADCB75A874B40
65365	5	52	843	6941	15547	\N	55.147494999999999	село Буготак, переулок Центральный, 1в	Россия, Новосибирская область, Тогучинский район, поселок Буготак	0101000020E6100000D7F6764B72F3544069A9BC1DE1924B40
65363	5	52	843	46216	16315	\N	55.149234	село Борцово, улица Центральная, 7а	Россия, Новосибирская область, Тогучинский район, поселок Борцово	0101000020E610000023DDCF29C8055540C3B986191A934B40
65402	5	52	843	47027	16286	\N	55.017570999999997	деревня Боровлянка, переулок Школьный, 5	Россия, Новосибирская область, Тогучинский район, поселок Боровлянка	0101000020E610000058AB764D48075540D32D3BC43F824B40
65391	5	52	843	8202	14061	\N	55.044565039860601	село Березиково, улица Центральная, 1	Россия, Новосибирская область, Тогучинский район, поселок Березиково	0101000020E6100000AFCDC64ACC335540EBC5504EB4854B40
65419	5	52	843	9461	\N	\N	54.940674999999999	деревня Аплаксино, улица Центральная, 45	Россия, Новосибирская область, Тогучинский район, поселок Аплаксино	0101000020E6100000E998F38C7DEF54401895D40968784B40
65297	5	52	315	3388	\N	\N	55.035038999999998	п. Чернышевский, Кооперативная, 1/2	Россия, Новосибирская область, Татарский район, поселок Чернышевский	0101000020E6100000B682A62556F95240D28A6F287C844B40
65265	5	52	315	1485	\N	\N	55.351528000000002	д. Чаны-Сакан, Центральная, 13	Россия, Новосибирская область, Татарский район, поселок Чаны-Сакан	0101000020E6100000AA9B8BBFED0953406CD097DEFEAC4B40
94468	5	52	315	4309	68562	\N	55.331423669301799	Татарский район , с.Ускюль, улица Комсомольская, 2 А	Россия, Новосибирская область, Татарский район, поселок Ускюль	0101000020E610000063B5F97FD5D65240048E041A6CAA4B40
94798	5	52	315	4518	68379	\N	55.474550999999998	Татарский район , с.Увальское, улица Школьная, 17		0101000020E61000003C32569BFFD752405DA45016BEBC4B40
94800	5	52	315	4926	14145	\N	55.394387000000002	Татарский район , д.Тайлаково, улица Озёрная, 17		0101000020E6100000815B77F354E95240D97BF1457BB24B40
65302	5	52	315	3670	13510	\N	55.227715000000003	д. 2-я Степановка, Центральная, 11		0101000020E6100000B30B06D7DCE0524082E7DEC3259D4B40
64306	5	52	315	43382	14820	\N	55.149105114098198	поселок Сибиряк, улица Школьная,12	Россия, Новосибирская область, Татарский район, поселок Сибиряк	0101000020E610000034DB15FA60DA5240C55565DF15934B40
65292	5	52	315	3101	\N	\N	55.185003999999999	с. Северотатарское, Школьная, 1	Россия, Новосибирская область, Татарский район, поселок Северотатарское	0101000020E610000084B7072120F9524089D00836AE974B40
65313	5	52	315	41354	14011	\N	55.315404637042803	д. Розенталь, Клубная, 15	Россия, Новосибирская область, Татарский район, поселок Розенталь	0101000020E6100000EEB25F77BADE524058FFE7305FA84B40
65293	5	52	315	3197	13842	\N	55.111572000000002	д. Первомихайловка, Гагарина, 1	Россия, Новосибирская область, Татарский район, поселок Первомихайловка	0101000020E6100000E2016553AEF352401D93C5FD478E4B40
94791	5	52	315	49669	68632	\N	54.873905999999998	Татарский район , с.Орловка, улица Молодёжная, 10		0101000020E610000008E3A7716FFC52409BE3DC26DC6F4B40
65262	5	52	315	43635	14896	\N	55.001570999999998	с. Новотроицк, Центральная, 18 А		0101000020E6100000433C122F4FEC52409ECF807A33804B40
65290	5	52	315	43635	75530	\N	55.001629829924099	д. 1-Новотроицк, Клубная, 6	Россия, Новосибирская область, Татарский район, поселок Новотроицк	0101000020E610000021AF0793E2EB5240A3586E6935804B40
94775	5	52	315	49668	68395	\N	55.190646999999998	Татарский район, с.Новопокровка, улица Зелёная, 32		0101000020E6100000C9ACDEE1760053404E0AF31E67984B40
65306	5	52	315	3836	\N	\N	55.142180000000003	с. Новопервомайское, Клубная, 11 А	Россия, Новосибирская область, Татарский район, поселок Новопервомайское	0101000020E6100000F8AA9509BFD95240991249F432924B40
94790	5	52	315	41263	68378	\N	55.078293000000002	Татарский район, с.Новомихайловка, улица Учительская, 1 Б		0101000020E610000047E4BB94BA0B5340BC404981058A4B40
64698	5	52	315	41263	13679	\N	55.078293000000002	с.Новомихайловка, Большевистская, 23	Россия, Новосибирская область, Татарский район, поселок Новомихайловка	0101000020E610000047E4BB94BA0B5340BC404981058A4B40
65263	5	52	315	1429	13966	\N	55.361324000000003	д. Нововознесенка, Надежды, 26		0101000020E6100000774CDD955DFA524045A165DD3FAE4B40
94794	5	52	315	41380	68633	\N	55.049554999999998	Татарский район , с.Никулино, улица Школьная, 7 А		0101000020E610000090F7AA9509E15240382D78D157864B40
94792	5	52	315	41308	68464	\N	54.815674000000001	Татарский район , с.Николаевка, улица Ленина, 33		0101000020E610000003B5183C4CEF52404819710168684B40
94796	5	52	315	4176	\N	\N	55.135485000000003	Татарский район , с.Неудачино, улица Центральная, 57		0101000020E6100000D8B628B341E052409E0C8E9257914B40
64316	5	52	315	41266	\N	\N	55.224710999999999	село Минино, улица Центральная, 55	Россия, Новосибирская область, Татарский район, поселок Минино	0101000020E6100000813FFCFCF70D534096067E54C39C4B40
65311	5	52	315	4133	13812	\N	55.232649320913303	д. Малый Ермак, Центральная, 9	Россия, Новосибирская область, Татарский район, поселок Малый Ермак	0101000020E6100000E17A14AE47E952403B394371C79D4B40
65282	5	52	315	2515	15950	\N	54.823585000000001	д. Малая Старинка, Школьная, 3		0101000020E6100000E6EAC726F9F25240F33CB83B6B694B40
94799	5	52	315	45429	68713	\N	55.391002	Татарский район , с.Лопатино, площадь Центральная, 7		0101000020E61000006F2D93E178EE5240D655815A0CB24B40
65308	5	52	315	41348	14004	\N	55.19107803024	д. Кузнецово, Сухая, 5 А	Россия, Новосибирская область, Татарский район, поселок Кузнецово	0101000020E6100000CEE2C5C210D75240177E703E75984B40
94801	5	52	315	45547	68714	\N	55.535941000000001	Татарский район , с.Красноярка, улица Центральная, 28		0101000020E61000004432E4D87A135340F3CAF5B699C44B40
65328	5	52	315	5057	16593	\N	55.480117999999997	село Кочневка, Зеленая, 67		0101000020E610000012312592E8075340471CB28174BD4B40
65333	5	52	315	60695	75577	\N	55.4643576323476	д. Камбар, Центральная, 18 А	Россия, Новосибирская область, Татарский район, поселок Комбар	0101000020E6100000BCAE5FB01B14534067D13B1570BB4B40
94797	5	52	315	49671	68634	\N	55.236263000000001	Татарский район , с.Козловка, улица Приозёрная, 25 А		0101000020E6100000390CE6AF90EC52409F20B1DD3D9E4B40
65350	5	52	315	45924	15732	\N	55.256534000000002	с. Киевка, Гагарина, 39		0101000020E6100000AB08371955045340F2272A1BD6A04B40
64926	5	52	315	41386	14178	\N	54.876408118280203	д.Камышино, Центральная, 33а	Россия, Новосибирская область, Татарский район, поселок Камышино	0101000020E6100000239EEC6646F85240F4F928232E704B40
65323	5	52	315	4800	14191	\N	55.5084565554139	село Казачий Мыс, Школьная, 55	Россия, Новосибирская область, Татарский район, поселок Казачий Мыс	0101000020E6100000C632FD12F1F752400D36751E15C14B40
65272	5	52	315	1952	13457	\N	55.031345000000002	с. Казаткуль, Мира, 4	Россия, Новосибирская область, Татарский район, поселок Казаткуль	0101000020E6100000313F37346503534052F2EA1C03844B40
65269	5	52	315	41298	\N	\N	55.251612999999999	д. Ивановка, Школьная, 17	Россия, Новосибирская область, Татарский район, поселок Ивановка	0101000020E61000007D073F7100155340CD1FD3DA34A04B40
94793	5	52	315	49670	68441	\N	54.848371839380498	Татарский район , с.Зубовка, улица Ленина, 8 Б	Россия, Новосибирская область, Татарский район, поселок Зубовка	0101000020E610000000FE2955A2E15240CA6B2574976C4B40
65300	5	52	315	41344	13996	\N	55.083373999999999	д. Евгеньевка, Школьная, 6	Россия, Новосибирская область, Татарский район, поселок Евгеньевка	0101000020E6100000344DD87E32EC524019ABCDFFAB8A4B40
94795	5	52	315	41353	68342	\N	55.16433	Татарский район , с.Дмитриевка, улица Школьная, 1		0101000020E61000006A4C88B9A4E6524037E0F3C308954B40
65277	5	52	315	41183	13392	\N	54.953058098822702	д. Городенка, Рыбака, 11 А	Россия, Новосибирская область, Татарский район, поселок Городенка	0101000020E6100000B85CFDD824F452407898F6CDFD794B40
65279	5	52	315	41206	13476	\N	54.833660668861697	д. Волово, Сибирская, 2	Россия, Новосибирская область, Татарский район, поселок Волово	0101000020E6100000809F71E140FA5240AF795567B56A4B40
65317	5	52	315	40397	\N	\N	55.285117	д. Воздвиженка, Школьная, 13 А	Россия, Новосибирская область, Татарский район, поселок Воздвиженка	0101000020E61000002DB0C7444AD252404E44BFB67EA44B40
65295	5	52	315	3301	13495	\N	55.085301000000001	п. Ваховский, Школьная, 4		0101000020E6100000DFF8DA334BFA524076A8A624EB8A4B40
65288	5	52	315	2854	13985	\N	54.959387	д. Варваровка, Зелёная, 13		0101000020E6100000F9D687F546E15240919A7631CD7A4B40
65261	5	52	315	41334	13973	\N	55.317543000000001	д. Богдановка, Мира, 22	Россия, Новосибирская область, Татарский район, поселок Богдановка	0101000020E6100000FB9463B2B80D53407009C03FA5A84B40
65304	5	52	315	41223	\N	\N	55.180017999999997	д. Безбожник, Центральная, 1	Россия, Новосибирская область, Татарский район, поселок Безбожник	0101000020E61000002F34D769A4E152407D586FD40A974B40
65202	5	52	33	62069	81082	\N	54.1121117324804	с.Харьковка, улица Новая, 16А	Россия, Новосибирская область, Сузунский район	0101000020E610000037195586719454409DBE9EAF590E4B40
65259	5	52	33	46433	15707	\N	53.966610027264103	Новосибирская область, Сузунский район, уч.Шипуновский, ул.Центральная, №26	Россия, Новосибирская область, Сузунский район, поселок Шипуновский	0101000020E61000002A55A2EC2DA6544048FE60E0B9FB4A40
65257	5	52	33	1083	\N	\N	54.001959999999997	Новосибирская область, Сузунский район, с.Шипуново, ул.Юбилейная, №15	Россия, Новосибирская область, Сузунский район, поселок Шипуново	0101000020E6100000D2FC31AD4DA6544038F3AB3940004B40
65145	5	52	33	513	\N	\N	54.251074000000003	с.Шигаево, улица Центральная, 16	Россия, Новосибирская область, Сузунский район, поселок Шигаево	0101000020E6100000B340BB438A9454401E705D3123204B40
65253	5	52	33	869	13451	\N	54.269215646923897	Новосибирская область, Сузунский район, с.Шарчино, ул.Советская, №47	Россия, Новосибирская область, Сузунский район, поселок Шарчино	0101000020E6100000003620425CA25440ACC77DAB75224B40
65244	5	52	33	260	16529	\N	54.011707999999999	Новосибирская область, Сузунский район, с.Шайдурово, ул.Выглазова, №84		0101000020E610000015562AA8A8725440008DD2A57F014B40
65258	5	52	33	1145	\N	\N	54.115307000000001	Новосибирская область, Сузунский район, д.Холодное, ул.Центральная, №15А	Россия, Новосибирская область, Сузунский район, поселок Холодное	0101000020E6100000E7ABE46377A55440FCFF3861C20E4B40
65235	5	52	33	32261	13415	\N	53.770487000000003	д.Тараданово, улица Полевая, 8		0101000020E6100000BB63B14D2A765440207F69519FE24A40
65219	5	52	33	31459	\N	\N	53.792726000000002	Новосибирская область, Сузунский район, р.п.Сузун, ул.Ленина, №55	Россия, Новосибирская область, Сузунский район, поселок Сузун	0101000020E610000021E9D32AFA9354402E58AA0B78E54A40
47324	5	49	\N	1225	72275	\N	55.981715999999999	Красноярск, Судостроительная, 50		0101000020E61000007364E597C1355740DFFAB0DEA8FD4B40
65222	5	52	33	31459	15616	\N	53.792726000000002	Новосибирская область, Сузунский район, р.п.Сузун, ул.Строительная, №35	Россия, Новосибирская область, Сузунский район, поселок Сузун	0101000020E610000021E9D32AFA9354402E58AA0B78E54A40
65223	5	52	33	31459	15639	\N	53.792726000000002	Новосибирская область, Сузунский район, р.п.Сузун, ул.Партизанская, №213		0101000020E610000021E9D32AFA9354402E58AA0B78E54A40
65221	5	52	33	31459	16444	\N	53.792726000000002	Новосибирская область, Сузунский район, р.п.Сузун, ул.Молодежная, №1		0101000020E610000021E9D32AFA9354402E58AA0B78E54A40
65220	5	52	33	31459	13778	\N	53.792726000000002	Новосибирская область, Сузунский район, р.п.Сузун, ул.Ленина, №14		0101000020E610000021E9D32AFA9354402E58AA0B78E54A40
65218	5	52	33	31459	13778	\N	53.792726000000002	Новосибирская область, Сузунский район, р.п.Сузун, ул.Ленина, №53		0101000020E610000021E9D32AFA9354402E58AA0B78E54A40
65217	5	52	33	31459	13778	\N	53.790896260110102	Новосибирская область, Сузунский район, р.п.Сузун, ул.Ленина, №57	Россия, Новосибирская область, Сузунский район, поселок Сузун	0101000020E61000006C41EF8D21945440C34483143CE54A40
65255	5	52	33	915	13435	\N	54.2089891910719	с.Плоское, улица Молодёжная, 16	Россия, Новосибирская область, Сузунский район, поселок Плоское	0101000020E6100000F224E99AC99C5440A41CCC26C01A4B40
65225	5	52	33	41333	13972	\N	53.803371799173497	уч.Нечунаевский, улица Лесниковская, 3	Россия, Новосибирская область, Сузунский район, поселок Нечунаевский	0101000020E6100000E2CD1ABCAF9C5440D542C9E4D4E64A40
65243	5	52	33	243	\N	\N	54.016787000000001	Новосибирская область, Сузунский район, с.Мышланка, ул.Советская, №45	Россия, Новосибирская область, Сузунский район, поселок Мышланка	0101000020E61000005BCEA5B8AA855440BDFF8F1326024B40
65226	5	52	33	31842	14127	\N	53.575035887669401	Новосибирская область, Сузунский район, с.Мереть, ул.Чкалова, №20	Россия, Новосибирская область, Сузунский район, поселок Мереть	0101000020E610000042B0AA5E7E995440E60297C79AC94A40
65256	5	52	33	1016	14140	\N	54.312210755392499	Новосибирская область, Сузунский район, с.Маюрово, ул.Центральная, №13		0101000020E61000009F776341619B5440C939B187F6274B40
65233	5	52	33	32153	13444	\N	53.742443734834502	Новосибирская область, Сузунский район, с.Малышево, ул.Центральная, №18	Россия, Новосибирская область, Сузунский район, поселок Малышево	0101000020E6100000E8A4F78DAF835440438EAD6708DF4A40
64401	5	52	33	32153	14682	\N	53.743777934523699	д.Малышево, Озерная, 13А	Россия, Новосибирская область, Сузунский район, поселок Малышево	0101000020E6100000FBAE08FEB7835440FDBD141E34DF4A40
65245	5	52	33	361	\N	\N	54.061064000000002	д.Малая Крутишка, улица.Молодёжная, 4	Россия, Новосибирская область, Сузунский район, поселок Малая Крутишка	0101000020E6100000C2C073EFE1775440427BF5F1D0074B40
65227	5	52	33	31901	13940	\N	53.593730999999998	п.Лесниковский, улица Рабочая, 1		0101000020E610000039D384ED2797544089CF9D60FFCB4A40
65242	5	52	33	39	\N	\N	53.909089000000002	п.Красный Камешок, улица Центральная, 22	Россия, Новосибирская область, Сузунский район, поселок Красный Камешок	0101000020E6100000DFC0E446918A5440A11342075DF44A40
65237	5	52	33	32346	\N	\N	53.900081999999998	Новосибирская область, Сузунский район, с.Ключики, ул.Кирова, №56	Россия, Новосибирская область, Сузунский район, поселок Ключики	0101000020E61000006FD575A8A6795440F0DB10E335F34A40
65234	5	52	33	32228	\N	\N	53.751063000000002	Новосибирская область, Сузунский район, с.Каргаполово, ул.Центральная, №46	Россия, Новосибирская область, Сузунский район, поселок Каргаполово	0101000020E61000003F74417DCB7B54402A1E17D522E04A40
65238	5	52	33	32447	14131	\N	53.864910000000002	п.Земледелец, улица Центральная, 5		0101000020E6100000849B8C2AC3825440DFFDF15EB5EE4A40
65252	5	52	33	753	\N	\N	54.032808000000003	Новосибирская область, Сузункий район, с.Заковряжино, ул.Ленина, №21	Россия, Новосибирская область, Сузунский район, поселок Заковряжино	0101000020E61000005133A48AE29A54400A86730D33044B40
65229	5	52	33	32016	13791	\N	53.681330725645502	Новосибирская область, Сузунский район, с.Верх-Сузун, ул.Мира, №20	Россия, Новосибирская область, Сузунский район, поселок Верх-Сузун	0101000020E6100000B4024356B79254402060ADDA35D74A40
65249	5	52	33	625	13807	\N	54.0274018533458	Новосибирская область, Сузункий район, с.Болтово, ул.Центральная, №7	Россия, Новосибирская область, Сузунский район, поселок Болтово	0101000020E6100000DE5A26C3F190544029ECA2E881034B40
65240	5	52	33	32476	\N	\N	53.927936000000003	Новосибирская область, Сузунский район, с.Бобровка, пер.Центральный, №5	Россия, Новосибирская область, Сузунский район, поселок Бобровка	0101000020E6100000AAF413CE6E885440FA635A9BC6F64A40
65247	5	52	33	503	13809	\N	54.201481000000001	Новосибирская область, Сузунский район, с.Битки, ул.Ленина, №32А		0101000020E610000006137F1475915440F8E12021CA194B40
65441	5	52	3428	35203	\N	\N	52.510334999999998	п. Суходолье, улица Центральная, 3	Россия, Брянская область, Стародубский район, поселок Суходолье	0101000020E6100000DE9046054E744040888043A852414A40
65196	5	52	1376	49608	16620	\N	56.280893005001303	НСО, Северный район, Верх-Красноярский сельсовет, д. Большие Кулики, Красная, 1а	Россия, Новосибирская область, Северный район, поселок Большие Кулики	0101000020E6100000D7A4DB12B96D53407156444DF4234C40
65212	5	52	1376	31182	13782	\N	56.398555999999999	НСО, Северный район, Чувашинский сельсовет, с. Чуваши, Советская, 37		0101000020E610000037001B1021B45340F2CF0CE203334C40
65210	5	52	1376	31123	13389	\N	56.323082999999997	НСО, Северный район, Чебаковский сельсовет, с. Чебаки, Советская, 16		0101000020E6100000FB21365838A353406072A3C85A294C40
94789	5	52	1376	31075	68630	\N	56.074956	Северный район, с. Федоровка, ул. Центральная , д. 29		0101000020E6100000E15F048D99B55340CA51802898094C40
65204	5	52	1376	30796	13768	\N	55.893526000000001	НСО, Северный район, Потюкановский сельсовет, п.Среднеичинский, Центральная, 14	Россия, Новосибирская область, Северный район, поселок Среднеичинский	0101000020E61000004EF04DD3679C534017105A0F5FF24B40
65206	5	52	1376	30881	13385	\N	56.350328230139503	Новосибирская область, Северный район, Северный сельсовет,с. Северное, Ленина, 18	Россия, Новосибирская область, Северный район, поселок Северное	0101000020E6100000F7AC6BB41C975340C16F438CD72C4C40
65205	5	52	1376	30881	13385	\N	56.346964999999997	Новосибирская область, Северный район, Северный сельсовет, с. Северное, Ленина, 18		0101000020E6100000CEC3094CA7965340A6ED5F59692C4C40
65207	5	52	1376	30967	\N	\N	56.709175999999999	НСО, Северный район, Остяцкий сельсовет, с. Остяцк, Центральная, 21	Россия, Новосибирская область, Северный район, поселок Остяцк	0101000020E6100000F1A1444B1E855340D68D7747C65A4C40
65208	5	52	1376	30977	13410	\N	56.722476092006701	НСО, Северный район, Останинский сельсовет, с. Останинка, Зеленая, 30	Россия, Новосибирская область, Северный район, поселок Останинка	0101000020E610000041834D9D479153408C12F4177A5C4C40
65203	5	52	1376	30751	\N	\N	56.187761999999999	НСО, Северный район, Новотроицкий сельсовет, с.Новотроицк, Трудовая, 28	Россия, Новосибирская область, Северный район, поселок Новотроицк	0101000020E610000004E5B67D8FAB53403DB7D09508184C40
65213	5	52	1376	45957	15583	\N	56.440061190169203	НСО, Северный район, Чувашинский сельсовет, п.Коб-Кордон, Набережная, 40	Россия, Новосибирская область, Северный район	0101000020E6100000944A7842AFC553405E9F39EB53384C40
64158	5	52	1376	41383	14165	\N	56.346122985428302	село Ивановка, Центральная, 29	Россия, Новосибирская область, Северный район, поселок Ивановка	0101000020E61000002C7DE882FAB553405BB22AC24D2C4C40
65200	5	52	1376	30573	\N	\N	56.359095000000003	НСО, Северный район, Гражданцевский сельсовет, с. Гражданцево, Центральная, 34	Россия, Новосибирская область, Северный район, поселок Гражданцево	0101000020E61000008675E3DD918A53401D9430D3F62D4C40
65211	5	52	1376	31143	13394	\N	56.297960877771501	НСО, Северный район, Чебаковский сельсовет, д.Витинск, Центральная, 10	Россия, Новосибирская область, Северный район, поселок Витинск	0101000020E6100000C1CAA145B69A5340E23D079623264C40
65216	5	52	1376	31344	14143	\N	56.605371580331401	д.Веселая, ул. Веселая , д. 3	Россия, Новосибирская область, Северный район, поселок Весёлая	0101000020E6100000081EDFDE358E534002F566D47C4D4C40
65195	5	52	1376	30357	\N	\N	56.370145000000001	НСО, Северный район, Верх-Красноярский сельсовет, с.Верх-Красноярка, Партизанская, 3	Россия, Новосибирская область, Северный район, поселок Верх-Красноярка	0101000020E610000030F2B226167B534093E34EE9602F4C40
65214	5	52	1376	31282	13621	\N	56.594726999999999	Новосибирская область, Северный район, Биазинский сельсовет, с. Биаза, Бугаева, 67		0101000020E61000008D614ED0269353402B86AB03204C4C40
65199	5	52	1376	30568	16547	\N	56.607114000000003	Новосибирская область, Северный район, Бергульский сельсовет,с.Бергуль, Гагарина, 12		0101000020E610000082FFAD64C79E5340CD785BE9B54D4C40
65719	5	52	1376	14944	13907	\N	56.315087095466303	п.Алексеевка, Сибирская, 27	Россия, Новосибирская область, Северный район, поселок Алексеевка	0101000020E6100000CCB56801DA6E5340873254C554284C40
65472	5	52	3594	36329	\N	\N	55.201649000000003	дер.Красноникольск,  ул. Московская, дом 5,	Россия, Смоленская область, Сафоновский район, поселок Красноникольск	0101000020E61000009B030473F4D44040B4226AA2CF994B40
65307	5	52	4868	37198	\N	\N	52.717700999999998	д. Платоновка, Школьная, 19	Россия, Тамбовская область, Рассказовский район, поселок Платоновка	0101000020E61000007C9E3F6D54FB44403BA759A0DD5B4A40
65183	5	52	1819	29779	\N	\N	54.409781000000002	Новосибирская область, Ордынский район, Шайдуровский, Сибирская, 35	Россия, Новосибирская область, Ордынский район, поселок Шайдуровский	0101000020E6100000F8E28BF678545440D7C22CB473344B40
65192	5	52	1819	49614	16629	\N	54.126746510314099	Новосибирская область, Ордынский район, Чингис, Школьная, 23	Россия, Новосибирская область, Ордынский район, поселок Чингисы	0101000020E6100000588FFB56EB675440DDEEE53E39104B40
65162	5	52	1819	28810	13770	\N	54.372635986439001	Новосибирская область, Ордынский район, Чернаково, Ильича, 52	Россия, Новосибирская область, Ордынский район, поселок Чернаково	0101000020E61000009E2633DE567C5440F8A75489B22F4B40
65179	5	52	1819	29593	14892	\N	54.215772999999999	Новосибирская область, Ордынский район, Черемшанка, Садовая, 2		0101000020E610000032ACE28DCC5F54400E2E1D739E1B4B40
65182	5	52	1819	29699	13756	\N	54.317946999999997	Новосибирская область, Ордынский район, Филиппово, Советская, 41		0101000020E61000007A185A9D9C6154403F6EBF7CB2284B40
65187	5	52	1819	29965	14929	\N	54.182595999999997	Новосибирская область, Ордынский район, Устюжанино, Школьная, 7		0101000020E61000001D56B8E523545440B130444E5F174B40
65191	5	52	1819	30154	\N	\N	54.270122999999998	Новосибирская область, Ордынский район, Усть-Хмелевка, Советская, 37	Россия, Новосибирская область, Ордынский район, поселок Усть-Хмелевка	0101000020E61000006919A9F754715440DE72F56393224B40
65180	5	52	1819	29636	\N	\N	54.386372999999999	Новосибирская область, Ордынский район, Усть-Луковска, Полины Савостиной, 25	Россия, Новосибирская область, Ордынский район, поселок Усть-Луковка	0101000020E61000006C239EEC666E54405987A3AB74314B40
94788	5	52	1819	29889	14924	\N	54.098516288695599	Ордынский район, с. Усть-Алеус, улица Кириллова, 56	Россия, Новосибирская область, Ордынский район, поселок Усть-Алеус	0101000020E610000009F9A067B35C5440FD101B2C9C0C4B40
65066	5	52	1564	24396	13663	\N	55.425485999999999	Новосибирская область, Мошковский район, село Участок Балта, Кирова, 28а		0101000020E610000022A98592C9FB5440F373435376B64B40
65170	5	52	1819	29184	\N	\N	54.692723999999998	Новосибирская область, Ордынский район, Степной, Набережная, 13	Россия, Новосибирская область, Ордынский район, поселок Степной	0101000020E6100000B7973446EB865440C093162EAB584B40
64811	5	52	1819	29184	68975	\N	54.691831195717	поселок Степной , улица Школьная,13	Россия, Новосибирская область, Ордынский район, поселок Степной	0101000020E6100000C939B187F6865440F3AD0FEB8D584B40
65185	5	52	1819	29873	14919	\N	54.134101999999999	Новосибирская область, Ордынский район, Спирино, Ленина, 103		0101000020E61000009C89E942AC635440022A1C412A114B40
65181	5	52	1819	29686	14063	\N	54.346285999999999	Новосибирская область, Ордынский район, Рогалево, Советская, 25	Россия, Новосибирская область, Ордынский район, поселок Рогалево	0101000020E61000009AEC9FA70166544005888219532C4B40
65131	5	52	1819	27401	\N	\N	54.172372000000003	Новосибирская область, Ордынский район, Пушкарево, Школьная, 2	Россия, Новосибирская область, Ордынский район, поселок Пушкарево	0101000020E61000007FBE2D58AA585440815F234910164B40
65184	5	52	1819	29793	\N	\N	54.383882	Новосибирская область, Ордынский район, Пролетарский, Ленина, 5	Россия, Новосибирская область, Ордынский район, поселок Пролетарский	0101000020E61000009E5DBEF5614A5440F4C29D0B23314B40
65165	5	52	1819	28965	\N	\N	54.595497000000002	"Новосибирская область, Ордынский район, Плотниково, контора производственного участка ЗАО племзавод ""Ирмень"""		0101000020E6100000AFD007CBD88D5440DDEEE53E394C4B40
65175	5	52	1819	29386	\N	\N	54.523634000000001	Новосибирская область, Ордынский район, Петровский, Октябрьская, 50	Россия, Новосибирская область, Ордынский район, поселок Петровский	0101000020E6100000D7506A2FA26F54406E895C7006434B40
65157	5	52	1819	28601	\N	\N	54.359015999999997	Новосибирская область, Ордынский район, рабочий поселок Ордынское, Ленина, 32	Россия, Новосибирская область, Ордынский район, поселок Ордынское	0101000020E610000051DA1B7C61795440D05E7D3CF42D4B40
65158	5	52	1819	28601	14075	\N	54.359015999999997	Новосибирская область, Ордынский район, рабочий поселок Ордынское, Пушкина, 72		0101000020E610000051DA1B7C61795440D05E7D3CF42D4B40
65159	5	52	1819	28601	14457	\N	54.359015999999997	Новосибирская область, Ордынский район, рабочий поселок Ордынское, Октябрьская, 12		0101000020E610000051DA1B7C61795440D05E7D3CF42D4B40
65160	5	52	1819	28601	13746	\N	54.359015999999997	Новосибирская область, Ордынский район, рабочий поселок Ордынское, Западная, 3а	Россия, Новосибирская область, Ордынский район, поселок Ордынское	0101000020E610000051DA1B7C61795440D05E7D3CF42D4B40
65174	5	52	1819	29368	13583	\N	54.410559281087899	Новосибирская область, Ордынский район, Новый Шарап, Мира, 81	Россия, Новосибирская область, Ордынский район, поселок Новый Шарап	0101000020E6100000C53D963E748254400B0A83328D344B40
65166	5	52	1819	28996	\N	\N	54.608634000000002	Новосибирская область, Ордынский район, Новопичугово, Ленина, 25	Россия, Новосибирская область, Ордынский район, поселок Новопичугово	0101000020E61000009946938B31965440E99D0AB8E74D4B40
65189	5	52	1819	30072	14058	\N	54.130277	Новосибирская область, Ордынский район, Новокузминка, Центральная, 29		0101000020E6100000D0D03FC1C54A5440E335AFEAAC104B40
65190	5	52	1819	30082	\N	\N	54.314050000000002	Новосибирская область, Ордынский район, Нижнекаменка, Мира, 4	Россия, Новосибирская область, Ордынский район, поселок Нижнекаменка	0101000020E6100000AF5A99F04B7A544087A757CA32284B40
65194	5	52	1819	30263	14056	\N	54.093271999999999	Новосибирская область, Ордынский район, Милованово, Береговая, 50а		0101000020E61000001557957D57635440F6D03E56F00B4B40
65172	5	52	1819	29248	\N	\N	54.690959999999997	Новосибирская область, Ордынский район, Малый-Чик, Школьная, 20	Россия, Новосибирская область, Ордынский район, поселок Малый Чик	0101000020E61000008B170B43E47D54400D6C956071584B40
65168	5	52	1819	29113	14039	\N	54.538863738458502	Новосибирская область, Ордынский район, Малоирменка, Центральная, 7	Россия, Новосибирская область, Ордынский район, поселок Малоирменка	0101000020E610000032022A1C41795440F17EDC7EF9444B40
65173	5	52	1819	29324	\N	\N	54.453245000000003	Новосибирская область, Ордынский район, Красный Яр, Советская, 36А	Россия, Новосибирская область, Ордынский район, поселок Красный Яр	0101000020E61000004B598638D6895440AB09A2EE033A4B40
65167	5	52	1819	29066	\N	\N	54.562654000000002	Новосибирская область, Ордынский район, Козиха, Центральная, 13	Россия, Новосибирская область, Ордынский район, поселок Козиха	0101000020E6100000302E55698B875440577BD80B05484B40
65178	5	52	1819	29541	\N	\N	54.243588000000003	Новосибирская область, Ордынский район, Кирза, Школьная, 28	Россия, Новосибирская область, Ордынский район, поселок Кирза	0101000020E6100000D2510E66136A54405AD93EE42D1F4B40
65171	5	52	1819	29239	16581	\N	54.650657000000002	Новосибирская область, Ордынский район, Верх-Чик, Молодежная, 12		0101000020E61000005BEA20AF077C5440EDF483BA48534B40
65163	5	52	1819	28875	\N	\N	54.573625	Новосибирская область, Ордынский район, Верх-Ирмень, Агрогородок, 20/1		0101000020E6100000C90567F0F78E54408195438B6C494B40
65164	5	52	1819	28875	14084	\N	54.572677704461498	Новосибирская область, Ордынский район, Верх-Ирмень, Кандикова, 69	Россия, Новосибирская область, Ордынский район, поселок Верх-Ирмень	0101000020E610000067614F3BFC8E5440C19140834D494B40
65188	5	52	1819	29998	\N	\N	54.176625999999999	Новосибирская область, Ордынский район, Верх-Алеус, Зеленая, 7	Россия, Новосибирская область, Ордынский район, поселок Верх-Алеус	0101000020E61000005280289831515440C8CF46AE9B164B40
64903	5	52	4196	36217	\N	\N	56.789544999999997	д.Дружинино, улица Центральная, 26	Россия, Свердловская область, Нижнесергинский район, поселок Дружинино	0101000020E610000098FBE42840C24D4033DC80CF0F654C40
65161	5	52	1819	28791	13749	\N	54.3671534579154	Новосибирская область, Ордынский район, Вагайцево, Космонавтов, 26	Россия, Новосибирская область, Ордынский район, поселок Вагайцево	0101000020E610000022E2E654327754406CD097DEFE2E4B40
65177	5	52	1819	29482	13893	\N	54.472873999999997	Новосибирская область, Ордынский район, Бугринская Роща, Центральная, 5	Россия, Новосибирская область, Ордынский район, поселок Бугринская Роща	0101000020E610000093A7ACA6EB6C544079909E22873C4B40
65176	5	52	1819	29431	\N	\N	54.532201999999998	Новосибирская область, Ордынский район, Борисовский, Борисовская, 13	Россия, Новосибирская область, Ордынский район, поселок Борисовский	0101000020E6100000548D5E0D50675440D26EF4311F444B40
65169	5	52	1819	60678	75546	\N	54.609526000000002	Новосибирская область, Ордынский район, Березовска, Центральная, 4	Россия, Новосибирская область, Ордынский район, поселок Березовка	0101000020E6100000726E13EE95835440E607AEF2044E4B40
65374	5	52	6418	39482	\N	\N	54.936776000000002	поселок Пятилетка,  улица Центральная, 18/2	Россия, Омская область, Омский район, поселок Пятилетка	0101000020E61000006571FF91E93B5240BFD6A546E8774B40
65812	5	52	1354	41190	\N	\N	54.938208000000003	Новосибирская область, рабочий поселок Кольцово, д.1А		0101000020E6100000683F524486CB54403C6C223317784B40
65152	5	52	1354	27929	\N	\N	54.806283000000001	Новосибирская область, Новосибирский район, с. Ярково, Лесная, 7 (здание ДШС)	Россия, Новосибирская область, Новосибирский район, поселок Ярково	0101000020E61000000934D8D479A654400F29064834674B40
65150	5	52	1354	27929	16566	\N	54.806283000000001	Новосибирская область, Новосибирский район, с. Ярково, Подгорбунского, 18 (здание школы № 3)		0101000020E61000000934D8D479A654400F29064834674B40
65085	5	52	1354	25300	14152	\N	54.913734231553804	Новосибирская область, Новосибирский район, п. Элитный, Минеральная, 8 (здание ДК)	Россия, Новосибирская область, Новосибирский район, поселок Элитный	0101000020E6100000A20E2BDCF2BC5440239F573CF5744B40
65132	5	52	1354	27451	14192	\N	54.912624999999998	"Новосибирская область, Новосибирский район, п. Тулинский, Академика Першилина, 21 (""Областнй центр образования"")"	Россия, Новосибирская область, Новосибирский район, поселок Тулинский	0101000020E6100000333509DE90B55440894160E5D0744B40
65146	5	52	1354	28070	\N	\N	54.983572000000002	Новосибирская область, Новосибирский район, с. Толмачево, Советская, 52 (здание школы № 61)	Россия, Новосибирская область, Новосибирский район, поселок Толмачево	0101000020E6100000A437DC476EAD544073A1F2AFE57D4B40
65804	5	52	1354	28070	13953	\N	54.986811732341998	Новосибирская область, город Обь, О.Кошевого, 30А	Россия, Новосибирская область, Новосибирский район, поселок Толмачево	0101000020E61000008AAF7614E7AD544072A609DB4F7E4B40
65116	5	52	1354	26742	13711	\N	55.233803999999999	Новосибирская область, Новосибирский район, п. Степной, Центральная, здание школы № 33		0101000020E610000059DC7F643AC4544045D61A4AED9D4B40
94722	5	52	1354	26704	68330	\N	55.235461999999998	Искитимский район, село Сосновка, ул.Школьная, 52А		0101000020E6100000C5C8923996BC5440B2B96A9E239E4B40
65115	5	52	1354	26704	13852	\N	55.235461999999998	Новосибирская область, Новосибирский район, с. Сосновка, Центральная, здание школы № 32	Россия, Новосибирская область, Новосибирский район, поселок Сосновка	0101000020E6100000C5C8923996BC5440B2B96A9E239E4B40
65103	5	52	1354	49619	16644	\N	55.129402216640401	Новосибирская область, Новосибирский район, п. Советский, Береговая, здание школы № 29		0101000020E6100000C6DFF60489C75440BC04A73E90904B40
65151	5	52	1354	28321	13737	\N	54.839704980956498	Новосибирская область, Новосибирский район, с. Сенчанка, Строителей, 32 (здание Дома культуры)	Россия, Новосибирская область, Новосибирский район, поселок Сенчанка	0101000020E6100000041E1840F89C5440D3A414747B6B4B40
65124	5	52	1354	59137	68314	\N	55.138039894046301	Новосибирская область, Новосибирский район, п. Садовый, Совхозная, 3а (здание ДК)	Россия, Новосибирская область, городской округ Новосибирск, поселок Садовый	0101000020E61000004948A46DFCBD544019C5724BAB914B40
65112	5	52	1354	26535	13708	\N	55.060006210388998	Новосибирская область, Новосибирский район, с. Раздольное, Ленина, д.2 (здание школы № 19)	Россия, Новосибирская область, Новосибирский район, поселок Раздольное	0101000020E6100000D9226937FAC754402AC8CF46AE874B40
65156	5	52	1354	14556	\N	\N	54.701621000000003	п. Прогресс, улица Первых коммунаров, 21/1	Россия, Новосибирская область, Новосибирский район, поселок Прогресс	0101000020E61000002BBD361B2BA35440EA9788B7CE594B40
65140	5	52	1354	27797	\N	\N	55.074195000000003	Новосибирская область, Новосибирский район, п. Приобский, здание центра досуга	Россия, Новосибирская область, Новосибирский район, поселок Приобский	0101000020E6100000E674594C6CB154406C43C5387F894B40
65110	5	52	1354	26436	\N	\N	55.036467999999999	Новосибирская область, Новосибирский район, с. Плотниково, Береговая, 19 (здание школы № 111)	Россия, Новосибирская область, Новосибирский район, поселок Плотниково	0101000020E61000000ED76A0F7BD95440DEACC1FBAA844B40
65143	5	52	1354	27984	\N	\N	54.839810999999997	Новосибирская область, Новосибирский район, с. Пайвино, Солнечная, 21 (здание школы № 80)	Россия, Новосибирская область, Новосибирский район, поселок Пайвино	0101000020E61000002C6519E258A3544018E945ED7E6B4B40
65107	5	52	1354	26308	\N	\N	54.983510000000003	Новосибирская область, Новосибирский район, с. Новолуговое, Советская, 13 (здание школы № 57)	Россия, Новосибирская область, Новосибирский район, поселок Новолуговое	0101000020E6100000B83EAC376AC75440FDA4DAA7E37D4B40
94867	5	52	1354	27050	\N	\N	55.159010105235502	"город Новосибирск, (здание санатория ""Обские зори"")"	Россия, Новосибирская область, Новосибирский район, поселок Мочище	0101000020E6100000BBED42739DC7544055DE8E705A944B40
65104	5	52	1354	27050	68617	\N	55.159786019692397	"Новосибирская область, Новосибирский район, д.п. Мочище, Первомайская, 166 (здание МУ КЦ ""Мочище"")"	Россия, Новосибирская область, Новосибирский район, поселок Мочище	0101000020E6100000AAD381ACA7C75440E82D1EDE73944B40
65123	5	52	1354	27050	13727	\N	55.1575138068009	Новосибирская область, Новосибирский район, ст. Мочище, Линейная, 68 (здание администрации с/совета)	Россия, Новосибирская область, Новосибирский район, поселок Мочище	0101000020E610000009DFFB1BB4C75440C154336B29944B40
65732	5	52	1354	41316	13882	\N	55.074655759169303	п.Михайловский, Зеленая, 2А	Россия, Новосибирская область, Новосибирский район, поселок Михайловский	0101000020E6100000444FCAA486DD54409F39EB538E894B40
65137	5	52	1354	27697	\N	\N	55.036262000000001	Новосибирская область, Новосибирский район, с. Марусино, здание клуба	Россия, Новосибирская область, Новосибирский район, поселок Марусино	0101000020E61000001A34F44F70B05440350BB43BA4844B40
65086	5	52	1354	25341	13829	\N	54.818947000000001	Новосибирская область, Новосибирский район, с. Ленинское, Ленина, 50 (здание школы № 47)	Россия, Новосибирская область, Новосибирский район, поселок Ленинское	0101000020E61000002829B000A6B6544023145B41D3684B40
65125	5	52	1354	27143	\N	\N	55.139972	Новосибирская область, Новосибирский район, п. Ленинский, Центральная, 54 (здание школы № 6)	Россия, Новосибирская область, Новосибирский район, поселок Ленинский	0101000020E6100000E6913F1878C95440882D3D9AEA914B40
94786	5	52	1354	59141	68385	\N	55.099565972979697	Новосибирский район, д.п. Кудряшовский, улица Октябрьская, 16А	Россия, Новосибирская область, Новосибирский район, поселок Кудряшовский	0101000020E61000004E0D349F73B1544093E52494BE8C4B40
65139	5	52	1354	59141	68385	\N	55.097077383292799	Новосибирская область, Новосибирский район, д.п. Кудряшовский, Октябрьская, 16А (здание школы № 25)	Россия, Новосибирская область, Новосибирский район, поселок Кудряшовский	0101000020E61000000EC0064488B15440CE18E6046D8C4B40
65118	5	52	1354	26818	\N	\N	55.259842020027598	Новосибирская область, Новосибирский район, с. Кубовая, Центральная, 16а (здание школы № 31)		0101000020E61000005DDC460378BA54404910AE8042A14B40
65130	5	52	1354	27351	13534	\N	54.8308185112774	Новосибирская область, Новосибирский район, п. им. Крупской, Степная, 1 (здание школы № 16)	Россия, Новосибирская область, Новосибирский район, поселок Крупской	0101000020E61000007EC9C6832DAF54409DF2E846586A4B40
65136	5	52	1354	27599	\N	\N	55.090221999999997	Новосибирская область, Новосибирский район, с. Криводановка, здание Дома культуры	Россия, Новосибирская область, Новосибирский район, поселок Криводановка	0101000020E6100000C366800BB2A954409AB0FD648C8B4B40
65135	5	52	1354	27599	\N	\N	55.090221999999997	Новосибирская область, Новосибирский район, с. Криводановка, здание ДК	Россия, Новосибирская область, Новосибирский район, поселок Криводановка	0101000020E6100000C366800BB2A954409AB0FD648C8B4B40
65114	5	52	1354	26609	\N	\N	55.219605999999999	Новосибирская область, Новосибирский район, п. Красный Яр, д.1 (здание ДК)		0101000020E61000000057B26323BA5440B000A60C1C9C4B40
65133	5	52	1354	27503	13642	\N	54.928587	"Новосибирская область, Новосибирский район, п. Красный Восток, Советская, 65/1 (зд. конторы ОАО ""Тулинское"")"	Россия, Новосибирская область, Новосибирский район, поселок Красный Восток	0101000020E61000006519E25817B45440D13E56F0DB764B40
65091	5	52	1354	41273	\N	\N	54.921976000000001	Новосибирская область, Новосибирский район, рабочий поселок Краснообск, дом №75 (здание школы № 1)		0101000020E61000002121CA17B4BF544034D93F4F03764B40
65090	5	52	1354	41273	\N	\N	54.9207757256994	Новосибирская область, Новосибирский район, рабочий поселок Краснообск, здание Дома Ученых	Россия, Новосибирская область, Краснообск, 21	0101000020E610000030DAE38574BF54408978EBFCDB754B40
65089	5	52	1354	41273	\N	\N	54.926318514384299	Новосибирская область, Новосибирский район, рабочий поселок Краснообск, дом № 209 (здание школы № 13)	Россия, Новосибирская область, Краснообск, 209	0101000020E6100000E6E786A6ECBE5440EB54F99E91764B40
65087	5	52	1354	41209	\N	\N	54.922510633049697	Новосибирская область, Новосибирский район, рабочий поселок Краснообск, дом № 76 (здание школы № 2)	Россия, Новосибирская область, Краснообск, 76а	0101000020E610000072BF4351A0BF5440A29927D714764B40
65149	5	52	1354	28210	13729	\N	54.994667	Новосибирская область, Новосибирский район, п. Красномайский, Школьная, 17 (здание школы № 49)		0101000020E6100000DFC14F1C40A1544089B48D3F517F4B40
94787	5	52	1354	28145	67752	\N	54.971232999999998	Новосибирский район, с. Красноглинное, улица Мира, 12		0101000020E6100000A4C4AEEDEDAC5440E2E5E95C517C4B40
65816	5	52	1354	28414	\N	\N	54.938208000000003	Новосибирская область, рабочий поселок Кольцово, Центральная, 10А	Россия, Новосибирская область, Новосибирский район, поселок Кольцово	0101000020E6100000683F524486CB54403C6C223317784B40
65815	5	52	1354	28414	\N	\N	54.938208000000003	Новосибирская область, рабочий поселок Кольцово, 30А		0101000020E6100000683F524486CB54403C6C223317784B40
65814	5	52	1354	28414	\N	\N	54.938208000000003	Новосибирская область, рабочий поселок Кольцово, 14	Россия, Новосибирская область, Новосибирский район, поселок Кольцово	0101000020E6100000683F524486CB54403C6C223317784B40
65094	5	52	1354	25725	\N	\N	54.871403999999998	Новосибирская область, Новосибирский район, п. Каинская Заимка, контора ЭХ СО РАН	Россия, Новосибирская область, Новосибирский район, поселок Каинская Заимка	0101000020E61000007A50508A56C9544042CD902A8A6F4B40
65097	5	52	1354	26378	13672	\N	54.986804999999997	Новосибирская область, Новосибирский район, ст. Издревая, пер. Школьный, д.2 (здание школы № 161)	Россия, Новосибирская область, Новосибирский район, поселок Издревая	0101000020E61000001D041DAD6ACF5440BF4351A04F7E4B40
65109	5	52	1354	26378	16552	\N	54.977742037685502	Новосибирская область, Новосибирский район, д. Издревая, Лесная, 3 (здание клуба)	Россия, Новосибирская область, Новосибирский район	0101000020E61000008C84B69C4BCD54407BF65CA6267D4B40
65120	5	52	1354	60680	75552	\N	55.297626694892202	Новосибирская область, Новосибирский район, п. Зеленый Мыс, Береговая, 14 (помещение клуба дома-интерната)	Россия, Новосибирская область, Новосибирский район, поселок Зеленый Мыс	0101000020E61000003F912749D7B854400BB43BA418A64B40
65111	5	52	1354	26479	\N	\N	55.115696999999997	Новосибирская область, Новосибирский район, с. Жеребцово, Центральная, 15 (здание школы № 39)	Россия, Новосибирская область, Новосибирский район, поселок Жеребцово	0101000020E6100000F513CE6E2DD25440669FC728CF8E4B40
65099	5	52	1354	25960	\N	\N	54.984681999999999	Новосибирская область, Новосибирский район, п. Железнодорожный, Центральная, 17 ( здание Дома культуры)	Россия, Новосибирская область, Новосибирский район, поселок Железнодорожный	0101000020E6100000DBA7E33103D25440DD7A4D0F0A7E4B40
65093	5	52	1354	25687	\N	\N	54.958528999999999	"Новосибирская область, Новосибирский район, п. Двуречье, Рабочая, 15 (здание детсада ""Незабудка"")"	Россия, Новосибирская область, Новосибирский район, поселок Двуречье	0101000020E6100000012F336C94CD544040A20914B17A4B40
65113	5	52	1354	26596	14000	\N	55.069678921836598	Новосибирская область, Новосибирский район, с. Гусиный Брод, Центральная, д.15а (здание школы № 18)	Россия, Новосибирская область, Новосибирский район, поселок Гусиный Брод	0101000020E6100000D84812842BCF5440E71BD13DEB884B40
65153	5	52	1354	60689	75566	\N	54.834076000000003	"Новосибирская область, Новосибирский район, п. Голубой Залив, м/район Сибирский, д.14, офис 2 (ООО ""КЖЭК ""Горский"")"	Россия, Новосибирская область, Новосибирский район, поселок Голубой Залив	0101000020E6100000DB8B683BA6BA544073309B00C36A4B40
65101	5	52	1354	26032	\N	\N	55.083503	Новосибирская область, Новосибирский район, п. Восход, Мирная, 1б (здание администрации с/совета)	Россия, Новосибирская область, Новосибирский район, поселок Восход	0101000020E6100000151DC9E53FC35440170FEF39B08A4B40
65102	5	52	1354	26032	13479	\N	55.083503	"Новосибирская область, Новосибирский район, п. Восход, Титова, 26 (контора ЗАО ""Чкаловское"")"	Россия, Новосибирская область, Новосибирский район, поселок Восход	0101000020E6100000151DC9E53FC35440170FEF39B08A4B40
65127	5	52	1354	27228	13527	\N	55.134220217012498	Новосибирская область, Новосибирский район, п. Витаминка, Центральная, здание ФАП	Россия, Новосибирская область, Новосибирский район, поселок Витаминка	0101000020E61000002AC8CF46AEC654400C3CF71E2E914B40
65129	5	52	1354	27299	13528	\N	54.883239711904899	Новосибирская область, Новосибирский район, с. Верх-Тула, Советская, 14 (здание школы № 14)	Россия, Новосибирская область, Новосибирский район, поселок Верх-Тула	0101000020E610000038A4518193B15440704221020E714B40
65100	5	52	1354	26019	15440	\N	54.933574	Новосибирская область, Новосибирский район, с. Быково, Школьная, 30 ( здание школы № 10)		0101000020E6100000A8FDD64E94D25440AD32535A7F774B40
65154	5	52	1354	14744	\N	\N	54.693852999999997	с. Боровое, улица Ленина, 30	Россия, Новосибирская область, Новосибирский район, поселок Боровое	0101000020E6100000FC8BA03193A85440A19DD32CD0584B40
65122	5	52	1354	26952	\N	\N	55.325369999999999	"Новосибирская область, Новосибирский район, п. Бибиха, контора СТ ""Бибиха"""		0101000020E6100000E65AB4006DB75440BD8C62B9A5A94B40
65098	5	52	1354	25895	\N	\N	54.992027999999998	Новосибирская область, Новосибирский район, п. Березовка, Кирова, 1а (здание ДК)	Россия, Новосибирская область, Новосибирский район, поселок Березовка	0101000020E6100000469737876BD55440AF5B04C6FA7E4B40
64428	5	52	1354	25895	\N	\N	54.992027999999998	п.Березовка, Центральная, 14	Россия, Новосибирская область, Новосибирский район, поселок Березовка	0101000020E6100000469737876BD55440AF5B04C6FA7E4B40
64947	5	52	1354	25895	16159	\N	54.992027999999998	д.Березовка, Школьная, 4		0101000020E6100000469737876BD55440AF5B04C6FA7E4B40
65155	5	52	1354	14815	\N	\N	54.655755999999997	с. Береговое, улица Центральная, 41	Россия, Новосибирская область, Новосибирский район, поселок Береговое	0101000020E6100000193A765089A05440F01307D0EF534B40
65095	5	52	1354	25776	13986	\N	54.958677333040399	Новосибирская область, Новосибирский район, с. Барышево, ул. Матросова, д. 5 (здание школы № 9)	Россия, Новосибирская область, Новосибирский район, поселок Барышево	0101000020E610000083A5BA8097CB5440B5368DEDB57A4B40
65096	5	52	1354	25776	16200	\N	54.960766999999997	"Новосибирская область, Новосибирский район, с. Барышево, пер. Институтский, д.4 (МУ БКЦ ""Радуга"")"		0101000020E61000009758198D7CCB5440BB09BE69FA7A4B40
65148	5	52	1354	28186	\N	\N	54.933630999999998	Новосибирская область, Новосибирский район, д. Алексеевка, здание школы № 4		0101000020E6100000B37E33315DA5544011C4793881774B40
94782	5	52	1564	24462	68364	\N	55.468927999999998	Мошковский район, п. Широкий Яр, улица Семилетка, д. 2а		0101000020E61000005E4BC8073DF85440DF162CD505BC4B40
65050	5	52	1564	23611	15768	\N	55.436331000000003	Новосибирская область, Мошковский район, село Успенка, Поросская, 1		0101000020E6100000130CE71A66CF5440919DB7B1D9B74B40
64953	5	52	1564	18819	14022	\N	55.546444999999999	д. Умрева, улица Восточная, д. 18а		0101000020E6100000618A7269FCE754400708E6E8F1C54B40
94780	5	52	1564	24154	68462	\N	55.214537	Мошковский район, с. Томилово, улица Школьная, д. 8		0101000020E6100000B77EFACF9AF554401764CBF2759B4B40
94777	5	52	1564	23501	68338	\N	55.519503	Мошковский район, с. Ташара, улица Обская, д. 8		0101000020E61000000DE36E10ADDF5440429605137FC24B40
65047	5	52	1564	23501	13799	\N	55.519503	Новосибирская область, Мошковский район, село Ташара, Гагарина, 1в		0101000020E61000000DE36E10ADDF5440429605137FC24B40
65056	5	52	1564	23864	\N	\N	55.464131000000002	Новосибирская область, Мошковский район, рабочий поселок Станционно-Ояшинский, Коммунистическая, 66б	Россия, Новосибирская область, Мошковский район, поселок Станционно-Ояшинский	0101000020E610000018778368ADF45440A70705A568BB4B40
65055	5	52	1564	23864	13646	\N	55.464131000000002	Новосибирская область, Мошковский район, рабочий поселок Станционно-Ояшинский, Производственная, 8		0101000020E610000018778368ADF45440A70705A568BB4B40
65077	5	52	1564	24890	\N	\N	55.209581	Новосибирская область, Мошковский район, село Сокур, Советская, 13	Россия, Новосибирская область, Мошковский район, поселок Сокур	0101000020E610000006F4C29D0BD45440766EDA8CD39A4B40
65076	5	52	1564	24890	13969	\N	55.209581	Новосибирская область, Мошковский район, село Сокур, квартал 4, 4		0101000020E610000006F4C29D0BD45440766EDA8CD39A4B40
65079	5	52	1564	25031	13442	\N	55.199640103505601	Новосибирская область, Мошковский район, поселок Смоленский, Победы, 17	Россия, Новосибирская область, Мошковский район, поселок Смоленский	0101000020E61000005F61C1FD80D754409A7CB3CD8D994B40
65046	5	52	1564	23404	13949	\N	55.503089000000003	д. Сарачевка, улица Н.Передня, д. 7		0101000020E61000004FADBEBA2AE654401AFD683865C04B40
94779	5	52	1564	24093	68339	\N	55.157741999999999	Мошковский район, с. Сарапулка, улица  Ленина, д. 8		0101000020E6100000E275FD82DDEF5440529ACDE330944B40
94778	5	52	1564	23938	16602	\N	55.496664000000003	Мошковский район, п. Радуга, улица Ключевская, д. 12		0101000020E6100000F4A5B73F17EF5440DF8C9AAF92BF4B40
65081	5	52	1564	25076	13822	\N	55.206137515884599	с. Орск, улица Центральная, д. 2	Россия, Новосибирская область, Мошковский район, поселок Орск	0101000020E61000004835ECF7C4DB54403F3BE0BA629A4B40
65070	5	52	1564	24607	\N	\N	55.173149000000002	Новосибирская область, Мошковский район, поселок Октябрьский, Октябрьская, 14	Россия, Новосибирская область, Мошковский район, поселок Октябрьский	0101000020E61000002EABB019E0CA5440E52A16BF29964B40
65052	5	52	1564	23707	\N	\N	55.474387999999998	Новосибирская область, Мошковский район, поселок Обской, Новая, 1а	Россия, Новосибирская область, Мошковский район, поселок Обской	0101000020E610000059C16F438CDC5440B3CEF8BEB8BC4B40
65041	5	52	1564	23226	\N	\N	55.331975999999997	Новосибирская область, Мошковский район, село Новомошковское, Коммунальная, 11	Россия, Новосибирская область, Мошковский район, поселок Новомошковское	0101000020E6100000FA7ABE66B9E55440488787307EAA4B40
65058	5	52	1564	24007	\N	\N	55.228884999999998	Новосибирская область, Мошковский район, село Мошнино, Школьная, 8	Россия, Новосибирская область, Мошковский район, поселок Мошнино	0101000020E61000001215AA9B8BE85440C1C58A1A4C9D4B40
65038	5	52	1564	22950	\N	\N	55.303632	Новосибирская область, Мошковский район, рабочий поселок Мошково, Школьный переулок, 1	Россия, Новосибирская область, Мошковский район, поселок Мошково	0101000020E6100000AAD216D7F8E554407102D369DDA64B40
65059	5	52	1564	22950	16632	\N	55.307946147213102	Новосибирская область, Мошковский район, село Мотково, Школьная, 17	Россия, Новосибирская область, Мошковский район, поселок Мошково	0101000020E6100000978FA4A487E754408E7747C66AA74B40
65037	5	52	1564	22950	13794	\N	55.303632	Новосибирская область, Мошковский район, рабочий поселок Мошково, улица Советская, 12		0101000020E6100000AAD216D7F8E554407102D369DDA64B40
65036	5	52	1564	22950	13786	\N	55.303632	Новосибирская область, Мошковский район, рабочий поселок Мошково, улица Линейная, 61		0101000020E6100000AAD216D7F8E554407102D369DDA64B40
65039	5	52	1564	22950	13936	\N	55.303632	Новосибирская область, Мошковский район, рабочий поселок Мошково, улица Западная, 2а		0101000020E6100000AAD216D7F8E554407102D369DDA64B40
65040	5	52	1564	23142	\N	\N	55.392423999999998	Новосибирская область, Мошковский район, поселок Красногорский, Школьная, 9	Россия, Новосибирская область, Мошковский район, поселок Красногорский	0101000020E61000006553AEF02EE754402F151BF33AB24B40
65082	5	52	1564	25150	13825	\N	55.256436999999998	п. Кошево, ул. Школьная, д. 4		0101000020E610000065A9F57EA3DF5440FF3D78EDD2A04B40
94781	5	52	1564	24216	68440	\N	55.295011000000002	Мошковский район, с. Кайлы, улица Школьная, д. 8		0101000020E610000028D192C7D3055540EA7AA2EBC2A54B40
65078	5	52	1564	24967	13680	\N	55.253003999999997	Новосибирская область, Мошковский район, поселок Емельяновский, Школьная, 9		0101000020E6100000E57E87A240D65440EBE0606F62A04B40
65063	5	52	1564	24247	\N	\N	55.361041999999998	Новосибирская область, Мошковский район, село Ёлтышево, Нарымская, 8	Россия, Новосибирская область, Мошковский район, поселок Елтышево	0101000020E6100000596C938AC6055540C03DCF9F36AE4B40
65049	5	52	1564	23603	13645	\N	55.473036	Новосибирская область, Мошковский район, село Дубровино, Советская, 25	Россия, Новосибирская область, Мошковский район, поселок Дубровино	0101000020E6100000BE326FD575D2544053EA92718CBC4B40
65368	5	52	1564	23312	14048	\N	55.3275582475801	рабочий поселок Горный, улица Советская, 15а	Россия, Новосибирская область, Мошковский район, поселок Горный	0101000020E610000047AAEFFCA2E2544087C5A86BEDA94B40
65064	5	52	1564	24299	\N	\N	55.335566	с. Верх-Балта, переулок Почтовый, д. 18	Россия, Новосибирская область, Мошковский район, поселок Верх-Балта	0101000020E61000006614CB2DADF0544024D3A1D3F3AA4B40
65051	5	52	1564	23690	\N	\N	55.413739	Новосибирская область, Мошковский район, село Белоярка, Школьная, 27	Россия, Новосибирская область, Мошковский район, поселок Белоярка	0101000020E610000064247B849ACC5440350A4966F5B44B40
65075	5	52	1564	24856	\N	\N	55.170017999999999	Новосибирская область, Мошковский район, поселок Барлакский, Центральная, 25	Россия, Новосибирская область, Мошковский район, поселок Барлакский	0101000020E6100000B27F9E060CCF54409CDD5A26C3954B40
65073	5	52	1564	24768	\N	\N	55.210557000000001	Новосибирская область, Мошковский район, село Барлак, Школьная, 27	Россия, Новосибирская область, Мошковский район, поселок Барлак	0101000020E6100000B9C7D2872ECE5440D1782288F39A4B40
94784	5	52	1564	24553	68340	\N	55.516761000000002	Мошковский район, д. Балта, улица Шкрольная, д. 1		0101000020E6100000768C2B2E8EF75440946C753925C24B40
65427	5	52	3083	34738	\N	\N	55.560366999999999	село Крещенское, Центральная, 63	Россия, республика Башкортостан, Мишкинский район, село Крещенское	0101000020E6100000F3052D2460104C40FA60191BBAC74B40
94774	5	52	1647	21022	68707	\N	54.395404999999997	Маслянинский район, село Чупино , улица Центральная 28а		0101000020E6100000BE33DAAA240A554062D68BA19C324B40
65012	5	52	1647	21966	16377	\N	54.336092999999998	село Чудиново, улица Школьная 19		0101000020E6100000041E1840F83455400FB56D18052B4B40
94776	5	52	1647	21663	68439	\N	54.403739000000002	Маслянинский район, село Суенга , улица Школьная 10		0101000020E6100000CAFB389A23235540548F34B8AD334B40
64993	5	52	1647	20948	13598	\N	54.367902999999998	село Серебренниково, улица Центральная 25	Россия, Новосибирская область, Маслянинский район, поселок Серебренниково	0101000020E6100000925ED4EE571C5540D68C0C72172F4B40
65024	5	52	1647	22421	\N	\N	54.320788	Новосибирская область, Маслянинский район, село Прямское, улица Центральная, 34а	Россия, Новосибирская область, Маслянинский район, поселок Прямское	0101000020E610000065C5707500F754408179C8940F294B40
65005	5	52	1647	21489	\N	\N	54.423271999999997	село Петени , улица Центральная 16	Россия, Новосибирская область, Маслянинский район, поселок Петени	0101000020E610000079E8BB5B5930554000A8E2C62D364B40
65021	5	52	1647	22321	14119	\N	54.337099494952	Новосибирская область, Маслянинский район, село Пеньково, улица Центральная, 17	Россия, Новосибирская область, Маслянинский район, поселок Пеньково	0101000020E610000021CB82893FFF5440D5415E0F262B4B40
65025	5	52	1647	22507	13625	\N	54.405467999999999	Новосибирская область, Маслянинский район, село Пайвино, улица Центральная, 42	Россия, Новосибирская область, Маслянинский район, поселок Пайвино	0101000020E610000047382D78D10755408AC91B60E6334B40
65018	5	52	1647	22167	\N	\N	54.435254999999998	Новосибирская область, Маслянинский район, село Никоново, улица Советская, 20	Россия, Новосибирская область, Маслянинский район, поселок Никоново	0101000020E61000002D93E1783EFE5440D235936FB6374B40
65003	5	52	1647	21478	13909	\N	54.463244976849097	Новосибирская область, Маслянинский район, село Нижняя Матренка, улица Центральная, 24	Россия, Новосибирская область, Маслянинский район, поселок Нижняя Матренка	0101000020E61000004852D2C3D03055408C84B69C4B3B4B40
65033	5	52	1647	22538	\N	\N	54.340066999999998	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Боровая, 17	Россия, Новосибирская область, Маслянинский район, поселок Маслянино	0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65030	5	52	1647	22538	\N	\N	54.340066999999998	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Кирпичная, 54а	Россия, Новосибирская область, Маслянинский район, поселок Маслянино	0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65028	5	52	1647	22538	\N	\N	54.340066999999998	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Пролетарская, 82	Россия, Новосибирская область, Маслянинский район, поселок Маслянино	0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65026	5	52	1647	22538	\N	\N	54.340066999999998	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Коммунистическая, 4	Россия, Новосибирская область, Маслянинский район, поселок Маслянино	0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65032	5	52	1647	22538	16428	\N	54.340066999999998	Новосибирская область, Маслянинский район, р.п.Маслянино, ул. Озерная, 136		0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65029	5	52	1647	22538	14125	\N	54.339985768118503	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул.Ленинская, 46	Россия, Новосибирская область, Маслянинский район, поселок Маслянино	0101000020E610000027BF45274B0D5540878C47A9842B4B40
65027	5	52	1647	22538	14122	\N	54.336497290212201	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Коммунистическая, 1	Россия, Новосибирская область, Маслянинский район, поселок Маслянино	0101000020E610000087DC0C37E00D5540DF196D55122B4B40
65031	5	52	1647	22538	16589	\N	54.340066999999998	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Заводская, 10		0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65035	5	52	1647	22538	13930	\N	54.340066999999998	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Больничная, 50б		0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65691	5	52	1555	20482	13857	\N	56.940059092973897	деревня Орловка, Первомайская, 32	Россия, Новосибирская область, Кыштовский район, поселок Орловка	0101000020E61000007B4B395FEC145340BDA772DA53784C40
65034	5	52	1647	22538	13628	\N	54.340066999999998	Новосибирская область, Маслянинский район, рабочий поселок Маслянино, ул. Бердская, 27	Россия, Новосибирская область, Маслянинский район, поселок Маслянино	0101000020E6100000DAE6C6F4840C554073B9C150872B4B40
65017	5	52	1647	22151	\N	\N	54.309390999999998	Новосибирская область, Маслянинский район, село Мамоново, улица Гагарина, 7	Россия, Новосибирская область, Маслянинский район, поселок Мамоново	0101000020E610000096E7C1DD591155409F56D11F9A274B40
65014	5	52	1647	21969	13916	\N	54.290891000000002	Новосибирская область, Маслянинский район, село Малая Томка, улица Центральная, 14	Россия, Новосибирская область, Маслянинский район, поселок Малая Томка	0101000020E6100000F6B704E09F1A5540B2D991EA3B254B40
64997	5	52	1647	21203	\N	\N	54.478816999999999	Новосибирская область, Маслянинский район, Березовский сельсовет, село Кинтереп, улица Сосновая, 9	Россия, Новосибирская область, Маслянинский район, поселок Кинтереп	0101000020E6100000C501F4FBFEFE544069E21DE0493D4B40
65011	5	52	1647	21862	13917	\N	54.302760999999997	Новосибирская область, Маслянинский район, Елбанский сельсовет, село Загора, улица Центральная, 7		0101000020E61000002EC55565DF2655408BC058DFC0264B40
65009	5	52	1647	21777	\N	\N	54.335248	село Жерновка, улица Центральная 2	Россия, Новосибирская область, Маслянинский район, поселок Жерновка	0101000020E6100000F778211D1E2C554053060E68E92A4B40
65008	5	52	1647	21679	13934	\N	54.322614999999999	Новосибирская область, Маслянинский район, село Елбань, улица Парковая, 9		0101000020E6100000D6355A0EF42555407A19C5724B294B40
65006	5	52	1647	21585	14111	\N	54.501494252844203	Новосибирская область, Маслянинский район, село Егорьевское, улица Почтовая, 7	Россия, Новосибирская область, Маслянинский район, поселок Егорьевское	0101000020E610000027D9EA724A255540F39194F430404B40
65002	5	52	1647	21398	\N	\N	54.464696000000004	Новосибирская область, Маслянинский район, село Дубровка, улица Ленина, 3	Россия, Новосибирская область, Маслянинский район, поселок Дубровка	0101000020E610000067B5C01E132E5540804A95287B3B4B40
65015	5	52	1647	22067	13610	\N	54.196616208157501	село Дресвянка , улица Новая 4	Россия, Новосибирская область, Маслянинский район, поселок Дресвянка	0101000020E610000086200725CC22554067EF8CB62A194B40
64999	5	52	1647	21273	14067	\N	54.606147	Новосибирская область, Маслянинский район, село Верх-Ики, улица Пролетарская, 3	Россия, Новосибирская область, Маслянинский район, поселок Верх-Ики	0101000020E6100000DC0DA2B5A2095540C5C89239964D4B40
65001	5	52	1647	21388	\N	\N	54.224943000000003	Новосибирская область, Маслянинский район, село Борково, переулок Школьный, 19	Россия, Новосибирская область, Маслянинский район, поселок Борково	0101000020E61000009C4D470037035540693BA6EECA1C4B40
64998	5	52	1647	21251	\N	\N	54.512121	Новосибирская область, Маслянинский район, село Большой Изырак, улица Садовая, 2	Россия, Новосибирская область, Маслянинский район, поселок Большой Изырак	0101000020E6100000319A95ED43115540234C512E8D414B40
64996	5	52	1647	21120	\N	\N	54.516280999999999	Новосибирская область, Маслянинский район, Березовский сельсовет, село Березово, улица Школьная, 21	Россия, Новосибирская область, Маслянинский район, поселок Березово	0101000020E6100000D7A4DB12B9FE5440E945ED7E15424B40
65019	5	52	1647	22288	13803	\N	54.391322000000002	село Барсуково , улица Центральная 37	Россия, Новосибирская область, Маслянинский район, поселок Барсуково	0101000020E6100000CF4BC5C6BCFB5440481ADCD616324B40
94773	5	52	1647	20874	14102	\N	54.373730000000002	Маслянинский район, село Бажинск, улица Советская 9		0101000020E61000003AE8120EBD1155405DC47762D62F4B40
64995	5	52	1647	21115	\N	\N	54.434910000000002	Новосибирская область, Маслянинский район, село Александровка, улица Перминова, 6	Россия, Новосибирская область, Маслянинский район, поселок Александровка	0101000020E6100000D65757056A175540085A8121AB374B40
65230	5	52	2859	34439	\N	\N	51.397241999999999	д.Камышенка, улица Школьная, 23	Россия, Курская область, Мантуровский район, поселок Камышенка	0101000020E6100000198D7C5EF1B042407F4C6BD3D8B24940
66044	5	52	3585	59101	67782	\N	54.983980000000003	Новосибирская область, город Новосибирск, Ленинский район, улица Крашенинникова, 6а		0101000020E61000001212691B7FB7544084F57F0EF37D4B40
64762	5	52	1555	20315	75304	\N	56.777539890973799	село Черновка, улица Школьная, 12/1	Россия, Новосибирская область, Кыштовский район, поселок Черновка	0101000020E6100000821ABE85751D53407AAA436E86634C40
94767	5	52	1555	20315	68436	\N	56.778011999999997	Кыштовский район, с.Черновка, улица Центральная,2		0101000020E6100000AB967494831D5340A1F2AFE595634C40
64960	5	52	1555	19186	13561	\N	56.575186000000002	Новосибирская область, Кыштовский район, с.Чернаковка, Нарымская, 18		0101000020E61000002AADBF2500515340FC8EE1B19F494C40
64966	5	52	1555	19491	14069	\N	56.293976000000001	Новосибирская область, Кыштовский район, д.Усманка, Школьная, 10	Россия, Новосибирская область, Кыштовский район, поселок Усманка	0101000020E6100000C87A6AF5D51E53408AE76C01A1254C40
94763	5	52	1555	19579	68434	\N	56.452006927030403	Кыштовский район, с.Сергеевка, улица Школьная,3	Россия, Новосибирская область, Кыштовский район, поселок Сергеевка	0101000020E61000008D5E0D501A0D53401348895DDB394C40
64965	5	52	1555	19372	13731	\N	56.428727000000002	д.Пахомово, улица Соловьева,26	Россия, Новосибирская область, Кыштовский район, поселок Пахомово	0101000020E6100000DBDE6E490E285340C3F4BD86E0364C40
94770	5	52	1555	20482	13899	\N	56.939656999999997	Кыштовский район, с.Орловка, улица Центральная,2		0101000020E610000016DA39CD021553408E3A3AAE46784C40
64907	5	52	354	16507	16612	\N	54.516976	с.Чаинка, ШКОЛЬНАЯ, 19		0101000020E610000006668522DD555340906802452C424B40
94760	5	52	1555	18985	68702	\N	56.573103000000003	Кыштовский район, с.Новый Майзас, улица Школьная,7		0101000020E61000004D4EED0C533D5340A81E69705B494C40
94766	5	52	1555	20267	14758	\N	56.506464000000001	Кыштовский район, с.Новоложниково, улица Центральная,8		0101000020E6100000AE65321CCF1A5340F94CF6CFD3404C40
64962	5	52	1555	19276	\N	\N	56.646642999999997	Новосибирская область, Кыштовский район, с.Межовка, Партизанская, 2 б	Россия, Новосибирская область, Кыштовский район, поселок Межовка	0101000020E6100000A60F5D50DF6E5340FA97A432C5524C40
94764	5	52	1555	19874	14080	\N	56.464464999999997	Кыштовский район, с.Малокрасноярка, улица Школьная,1		0101000020E61000002BF697DD930053407D91D096733B4C40
64975	5	52	1555	19897	13573	\N	56.480634000000002	д.Малая Скирла, улица Горская,32		0101000020E6100000A1A17F828B0553403FAC376A853D4C40
64952	5	52	1555	18572	\N	\N	56.556894	Новосибирская область, Кыштовский район, село Кыштовка, Льнозаводская, 38	Россия, Новосибирская область, Кыштовский район, поселок Кыштовка	0101000020E6100000056C0723F627534058AB764D48474C40
64949	5	52	1555	18572	14280	\N	56.556894	Новосибирская область, Кыштовский район, село Кыштовка, Садовая, 10		0101000020E6100000056C0723F627534058AB764D48474C40
64950	5	52	1555	18572	13870	\N	56.568196693269599	Новосибирская область, Кыштовский район, село Кыштовка, Мелиоративная, 17	Россия, Новосибирская область, Кыштовский район, поселок Кыштовка	0101000020E61000007C7C4276DE285340B857E6ADBA484C40
64948	5	52	1555	18572	14214	\N	56.556894	Новосибирская область, Кыштовский район, село Кыштовка, Ленина, 40	Россия, Новосибирская область, Кыштовский район, поселок Кыштовка	0101000020E6100000056C0723F627534058AB764D48474C40
64951	5	52	1555	18572	14027	\N	56.5426299295153	Новосибирская область, Кыштовский район, село Кыштовка, Волкова, 55	Россия, Новосибирская область, Кыштовский район, поселок Кыштовка	0101000020E610000037A6272CF12753400CEA5BE674454C40
64959	5	52	1555	19133	14277	\N	56.519865127684099	Новосибирская область, Кыштовский район, д.Куляба, Центральная, 31	Россия, Новосибирская область, Кыштовский район, поселок Куляба	0101000020E6100000CA3505323B4C5340E3AAB2EF8A424C40
94772	5	52	1555	20829	68706	\N	56.818252000000001	Кыштовский район, с.Крутиха, улица Матросовка,1		0101000020E6100000C4CE143AAF4A53407CF1457BBC684C40
64958	5	52	1555	19031	\N	\N	56.542321999999999	д.Коровинка, улица Трудовая,28	Россия, Новосибирская область, Кыштовский район, поселок Коровинка	0101000020E61000003DEE5BAD133153405EF3AACE6A454C40
94768	5	52	1555	20402	68624	\N	56.887925000000003	Кыштовский район, с.Колбаса, улица Центральная,21		0101000020E610000031ED9BFBAB2C53408126C286A7714C40
64352	5	52	1555	41269	13703	\N	56.787731000000001	деревня Козловка, улица Школьная, 7		0101000020E61000001172DEFFC7415340CF85915ED4644C40
64986	5	52	1555	60693	75574	\N	56.725724	Новосибирская область, Кыштовский район, д.Камышенка, Центральная, 60	Россия, Новосибирская область, Кыштовский район, поселок Камышинка	0101000020E61000000745F300163753400EF62686E45C4C40
94762	5	52	1555	19565	68433	\N	56.451518	Кыштовский район, с.Заливино, улица Центральная,15А		0101000020E61000000AA359D93E15534015C78157CB394C40
64977	5	52	1555	20100	\N	\N	56.609735000000001	Новосибирская область, Кыштовский район, с.Еремино, Центральная, 35	Россия, Новосибирская область, Кыштовский район, поселок Ерёмино	0101000020E61000005BCF108E59195340001DE6CB0B4E4C40
64955	5	52	1555	18848	14286	\N	56.543587000000002	д.Вятка, улица Центральная,7	Россия, Новосибирская область, Кыштовский район, поселок Вятка	0101000020E6100000AA2B9FE5792D5340F0C3414294454C40
64969	5	52	1555	19680	13858	\N	56.438060038935198	д.Воскресенка, улица Центральная,17	Россия, Новосибирская область, Кыштовский район, поселок Воскресенка	0101000020E61000005BB6D617090A5340C7D79E5912384C40
64181	5	52	1555	19680	13858	\N	56.438250231322698	село Воскресенка, Центральная, 12	Россия, Новосибирская область, Кыштовский район, поселок Воскресенка	0101000020E61000000856D5CBEF0953406ABC749318384C40
94761	5	52	1555	19257	68608	\N	56.620505283021302	Кыштовский район, с.Верх-Тарка, улица Волкова,70	Россия, Новосибирская область, Кыштовский район, поселок Верх-Тарка	0101000020E61000003BA759A0DD5F5340930035B56C4F4C40
64985	5	52	1555	20578	16322	\N	56.684522999999999	Новосибирская область, Кыштовский район, с.Верх-Майзас, Нарымская, 30	Россия, Новосибирская область, Кыштовский район, поселок Верх-Майзас	0101000020E610000071935165183953400E2E1D739E574C40
64963	5	52	1555	19348	\N	\N	56.509220999999997	Новосибирская область, Кыштовский район, с.Вараксино, Зеленая, 17	Россия, Новосибирская область, Кыштовский район, поселок Вараксино	0101000020E610000013EF004F5A215340DCB75A272E414C40
94769	5	52	1555	20479	68437	\N	56.933279672233802	Кыштовский район, д.Бочкаревка, улица Школьная,5	Россия, Новосибирская область, Кыштовский район, поселок Бочкарёвка	0101000020E61000006666666666375340650113B875774C40
94765	5	52	1555	19997	68705	\N	56.565455999999998	Кыштовский район, с.Большеречье, улица Смоленская,6А		0101000020E61000005DF92CCF830E5340DAA9B9DC60484C40
94771	5	52	1555	20676	68460	\N	56.796973999999999	Кыштовский район, с.Березовка, улица Заречная,8		0101000020E6100000BBD408FD4C3B534093E1783E03664C40
64971	5	52	1555	19767	13748	\N	56.470804999999999	д.Бакейка, улица Центральная,3		0101000020E6100000D4282499D50C53408AE59656433C4C40
64901	5	52	354	14008	13984	\N	54.639826707292997	с.Яркуль, Советская, 43	Россия, Новосибирская область, Купинский район, поселок Яркуль	0101000020E6100000BC75FEEDB2585340840CE4D9E5514B40
64909	5	52	354	16603	\N	\N	54.647686999999998	д.Шаитик, Школьная, 19	Россия, Новосибирская область, Купинский район, поселок Шаитик	0101000020E6100000B1506B9A77655340AD855968E7524B40
64914	5	52	354	16833	\N	\N	54.469259000000001	с.Чумашки, Центральная, 10	Россия, Новосибирская область, Купинский район, поселок Чумашки	0101000020E6100000B3976DA7AD725340452DCDAD103C4B40
64904	5	52	354	16351	\N	\N	54.722222000000002	д.Тюменка, Центральная, 18	Россия, Новосибирская область, Купинский район, поселок Тюменка	0101000020E61000009FABADD85F535340D2393FC5715C4B40
64893	5	52	354	45997	\N	\N	54.355573999999997	с.Стеклянное, Центральная, 31	Россия, Новосибирская область, Купинский район, поселок Стеклянное	0101000020E6100000FE28EACC3D49534069A7E672832D4B40
64928	5	52	354	46754	\N	\N	54.080390999999999	д.Спасск, улица Степная, 6	Россия, Новосибирская область, Купинский район, поселок Спасск	0101000020E6100000CD069964E441534045F295404A0A4B40
64758	5	52	354	41358	14020	\N	54.028036978396898	поселок Советский, улица Ленина, 22а	Россия, Новосибирская область, Купинский район, поселок Советский	0101000020E6100000CF2D742502425340FA0967B796034B40
64896	5	52	354	41363	\N	\N	54.518999000000001	пос.Сибирский, Октябрьская, 10а	Россия, Новосибирская область, Купинский район, поселок Сибирский	0101000020E6100000F0315871AA4E53400FD4298F6E424B40
64922	5	52	354	40396	16125	\N	54.286586999999997	с.Рождественка, Южная, 66		0101000020E61000003D2828452B645340B83A00E2AE244B40
65319	5	52	354	40396	14076	\N	54.285127946557303	д. Рождественка, Светлая, 10 А	Россия, Новосибирская область, Купинский район, поселок Рождественка	0101000020E6100000ED6305BF0D645340429605137F244B40
65581	5	52	354	40396	13767	\N	54.286586999999997	п. Рождественка, улица Путевая, 2А		0101000020E61000003D2828452B645340B83A00E2AE244B40
65294	5	52	354	40396	14079	\N	54.286586999999997	д. Рождественка, Кооперативная, 23		0101000020E61000003D2828452B645340B83A00E2AE244B40
65023	5	52	354	41292	13801	\N	53.910795935965702	село Петропавловка , улица Центральная 16		0101000020E61000006E895C7006445340EFA99CF694F44A40
64921	5	52	354	40467	13952	\N	54.264764	д.Петровка, Центральная, 73		0101000020E610000096438B6CE77653403E9468C9E3214B40
94757	5	52	354	49667	68697	\N	54.315005999999997	Купинский район, д.Орловка, улица Центральная, 37		0101000020E6100000CEFA9463B23B53409A05DA1D52284B40
64943	5	52	354	41600	14268	\N	54.170797137557102	с.Новоселье, Новосельский проспект, 109	Россия, Новосибирская область, Купинский район, поселок Новоселье	0101000020E6100000516C054D4B385340A1A014ADDC154B40
64913	5	52	354	16822	\N	\N	54.650568	с.Новорозино, Набережная, 6	Россия, Новосибирская область, Купинский район, поселок Новорозино	0101000020E6100000B47405DB887253407DE9EDCF45534B40
94755	5	52	354	17121	13736	\N	54.243872000000003	Купинский район, с.Новоключи, улица Школьная, 5		0101000020E61000003546EBA86A8053407F349C32371F4B40
64917	5	52	354	16987	16550	\N	54.373531	д.Новоказарино, Надежды, 19	Россия, Новосибирская область, Купинский район, поселок Новоказарино	0101000020E61000003D484F9143745340668522DDCF2F4B40
64925	5	52	354	43197	14770	\N	54.240134120590398	д.Морьевка, улица Морьевская, 23А	Россия, Новосибирская область, Купинский район, поселок Моревка	0101000020E6100000A530EF71A65253402E54FEB5BC1E4B40
64945	5	52	354	18376	13541	\N	54.092374	с.Метелево, Центральная, 77	Россия, Новосибирская область, Купинский район, поселок Метелево	0101000020E6100000707CED99252F5340178046E9D20B4B40
64927	5	52	354	41347	14002	\N	54.128315000000001	с.Медяково, Пролетарская, 45	Россия, Новосибирская область, Купинский район, поселок Медяково	0101000020E6100000137D3ECA884553400A4B3CA06C104B40
94758	5	52	354	41373	68616	\N	54.581881000000003	Купинский район, д.Мальково, улица Школьная, 7		0101000020E61000000BB3D0CE695C5340F7949C137B4A4B40
64918	5	52	354	17050	\N	\N	54.400579	с.Лягушье, Бельского, 108	Россия, Новосибирская область, Купинский район, поселок Лягушье	0101000020E6100000AF7C96E7C17E5340713B342C46334B40
64919	5	52	354	17104	68886	\N	54.3187930521621	д.Лукошино, Центральная, 39	Россия, Новосибирская область, Купинский район, поселок Лукошино	0101000020E61000008CF7E3F6CB845340CC988235CE284B40
64887	5	52	354	1791	\N	\N	54.357049000000004	г.Купино, Переездный пер, 1	Россия, Новосибирская область, Купинский район, Купино	0101000020E61000002174D0251C535340E60819C8B32D4B40
46158	5	52	354	1791	\N	\N	54.357049000000004	г.Купино, Советов, 261	Россия, Новосибирская область, Купинский район, Купино	0101000020E61000002174D0251C535340E60819C8B32D4B40
64890	5	52	354	1791	14176	\N	54.364139118951897	г.Купино, Советов, 89	Россия, Новосибирская область, Купинский район, Купино	0101000020E6100000D2FD9C82FC5253405D19541B9C2E4B40
64888	5	52	354	1791	14176	\N	54.357049000000004	г.Купино, Советов, 1		0101000020E61000002174D0251C535340E60819C8B32D4B40
64891	5	52	354	1791	13455	\N	54.372364579916102	г.Купино, Садовая, 143	Россия, Новосибирская область, Купинский район, Купино	0101000020E610000056EF703B34535340689604A8A92F4B40
64889	5	52	354	1791	13441	\N	54.364832468434798	г.Купино, Осипенко, 84	Россия, Новосибирская область, Купинский район, Купино	0101000020E61000005E0F26C5C75253406344A2D0B22E4B40
64844	5	52	354	1791	13929	\N	54.356444653826202	г.Купино, Новый городок, 34	Россия, Новосибирская область, Купинский район, Купино	0101000020E6100000D5B32094F75253404FE960FD9F2D4B40
65717	5	52	354	41243	13574	\N	54.506338999999997	с.Куликовка, Центральная, 53	Россия, Новосибирская область, Купинский район, поселок Куликовка	0101000020E6100000309FAC18AE4953403CD862B7CF404B40
64898	5	52	354	41243	13982	\N	54.506338999999997	д.Куликовка, улица Куликовская, 19А	Россия, Новосибирская область, Купинский район, поселок Куликовка	0101000020E6100000309FAC18AE4953403CD862B7CF404B40
64915	5	52	354	16898	13488	\N	54.392501415487203	с.Копкуль, Центральная, 9	Россия, Новосибирская область, Купинский район, поселок Копкуль	0101000020E6100000BE4BA94BC6685340DB5207793D324B40
64944	5	52	354	18341	\N	\N	54.237900000000003	д.Киргинцево, Центральная, 49	Россия, Новосибирская область, Купинский район, поселок Киргинцево	0101000020E61000002D0B26FE28425340F5DBD781731E4B40
64923	5	52	354	17297	13512	\N	54.279628000000002	с.Зятьковка, Центральная, 68а	Россия, Новосибирская область, Купинский район, поселок Зятьковка	0101000020E6100000287FF78E1A555340E085ADD9CA234B40
94759	5	52	354	46506	68699	\N	54.344948000000002	Купинский район, д.Вороновка, улица Центральная, 66		0101000020E61000006494675E0E7053400A698D41272C4B40
64935	5	52	354	41307	13856	\N	53.983614000000003	д.Вишневка, Центральная, 35	Россия, Новосибирская область, Купинский район, поселок Вишневка	0101000020E6100000FAF19716F5355340A2F14410E7FD4A40
64932	5	52	354	17763	\N	\N	54.177695	д.Веселый Кут, Центральная, 14	Россия, Новосибирская область, Купинский район, поселок Веселый Кут	0101000020E610000012F8C3CF7F4D5340D4D4B2B5BE164B40
65585	5	52	354	41256	13647	\N	54.040766572323399	деревня Васильевка, Центральная, 71	Россия, Новосибирская область, Купинский район, поселок Васильевка	0101000020E610000092EC116A863B5340C6E061DA37054B40
64937	5	52	354	41256	13647	\N	54.0410359997935	д.Васильевка, улица Центральная, 23В	Россия, Новосибирская область, Купинский район, поселок Васильевка	0101000020E61000007EE200FA7D3B5340B5FAEAAA40054B40
64940	5	52	354	46997	\N	\N	53.926642000000001	д.Благовещенка, Мира, 34	Россия, Новосибирская область, Купинский район, поселок Благовещенка	0101000020E61000003B8C497F2F3C5340CE8C7E349CF64A40
64911	5	52	354	41328	13943	\N	54.463220627752698	с.Басково, улица Школьная, 8	Россия, Новосибирская область, Купинский район, поселок Басково	0101000020E61000005BB6D617096A534003E962D34A3B4B40
64933	5	52	354	17789	\N	\N	54.070131000000003	д.Аполиха, Ершова, 38	Россия, Новосибирская область, Купинский район, поселок Аполиха	0101000020E61000002A1A6B7F674B5340C8B7770DFA084B40
64946	5	52	354	41447	14215	\N	54.113295999999998	д.Алферовка, Солнечная, 31	Россия, Новосибирская область, Купинский район, поселок Алферовка	0101000020E6100000D1E7A38CB82053404162BB7B800E4B40
64845	5	52	1260	13528	\N	\N	55.649560999999999	Новосибирская область, Куйбышевский район, Верх-Ичинский сельсовет, деревня Ярково, ул. Зеленая, д. 1	Россия, Новосибирская область, Куйбышевский район, поселок Ярково	0101000020E610000050E3DEFC86745340E7E099D024D34B40
64853	5	52	1260	49616	75554	\N	55.799431417818901	Новосибирская область, Куйбышевский район, Камский сельсовет, аул Шагир, ул. Школьная, д. 9А	Россия, Новосибирская область, Куйбышевский район, поселок Шагир (Татары)	0101000020E610000022533E04556A53404C3448C153E64B40
64867	5	52	1260	14558	14135	\N	55.686432000000003	Новосибирская область, Куйбышевский район, Чумаковский сельсовет, село Чумаково, ул. Советская, д. 17	Россия, Новосибирская область, Куйбышевский район, поселок Чумаково	0101000020E610000086CABF9657C35340C576F700DDD74B40
64868	5	52	1260	14588	\N	\N	55.681559	Новосибирская область, Куйбышевский район, Чумаковский сельсовет, село Ушково, ул. Ченина, д. 46/1	Россия, Новосибирская область, Куйбышевский район, поселок Ушково	0101000020E6100000151BF33AE2C35340B1A547533DD74B40
64866	5	52	1260	14494	\N	\N	55.785573999999997	Новосибирская область, Куйбышевский район, Сергинский сельсовет, село Сергино, ул. Центральная, д. 23	Россия, Новосибирская область, Куйбышевский район, поселок Сергино	0101000020E6100000E9818FC18A9B5340404B57B08DE44B40
65571	5	52	1260	14494	14109	\N	55.786006542968501	деревня Сергино, Речная, 30	Россия, Новосибирская область, Куйбышевский район, поселок Сергино	0101000020E6100000A9BC1DE1B49B5340AAB69BE09BE44B40
64696	5	52	1260	41262	13678	\N	55.458125672422298	с.Сартаково, Школьная, 2а	Россия, Новосибирская область, Куйбышевский район, поселок Сартаково	0101000020E6100000CFDA6D179A9E534041B96DDFA3BA4B40
64860	5	52	1260	14202	13800	\N	55.464145430314801	Новосибирская область, Куйбышевский район, Октябрьский сельсовет, деревня Помельцево, ул. Северная, д. 1	Россия, Новосибирская область, Куйбышевский район, поселок Помельцево	0101000020E6100000E2C96E66F4A053400CCD751A69BB4B40
64865	5	52	1260	14478	\N	\N	55.529052999999998	Новосибирская область, Куйбышевский район, Отрадненский сельсовет, село Отрадненское, ул. Центральная, д. 49	Россия, Новосибирская область, Куйбышевский район, поселок Отрадненское	0101000020E6100000BD19355F25A35340E36C3A02B8C34B40
64862	5	52	1260	14331	\N	\N	55.461671000000003	Новосибирская область, Куйбышевский район, Осиновский сельсовет, село Осиново, ул. Школьная, д. 8/1	Россия, Новосибирская область, Куйбышевский район, поселок Осиново	0101000020E6100000C0B0FCF9B6B553407D410B0918BB4B40
64840	5	52	1260	49613	16634	\N	55.424176914777803	Новосибирская область, Куйбышевский район, Булатовский сельсовет, аул Омь, ул. Береговая, д. 9/2		0101000020E6100000A35A441493725340925B936E4BB64B40
64858	5	52	1260	14138	14129	\N	55.662438725014603	Новосибирская область, Куйбышевский район, Новоичинский сельсовет, село Новоичинское, ул. Школьная, д. 1А	Россия, Новосибирская область, Куйбышевский район, поселок Новоичинское	0101000020E610000064CC5D4BC8675340274C18CDCAD44B40
64859	5	52	1260	14195	\N	\N	55.425885000000001	Новосибирская область, Куйбышевский район, Октябрьский сельсовет, село Нагорное, ул. Омская, д. 32	Россия, Новосибирская область, Куйбышевский район, поселок Нагорное	0101000020E61000002A5778978B915340B16D516683B64B40
64856	5	52	1260	14050	16264	\N	55.585352	Новосибирская область, Куйбышевский район, Михайловский сельсовет, село Михайловка, ул. Заимская, д. 2		0101000020E6100000B0726891EDD65340F85278D0ECCA4B40
64864	5	52	1260	14413	\N	\N	55.535370999999998	Новосибирская область, Куйбышевский район, Осиновский сельсовет, село Кульча, ул. Центральная, д. 33/2	Россия, Новосибирская область, Куйбышевский район, поселок Кульча	0101000020E61000004696CCB1BCC65340081D740987C44B40
64886	5	52	1260	40315	13450	\N	55.448010527230402	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Партизанская, д. 2	Россия, Новосибирская область, Куйбышев	0101000020E61000001E882CD2C4945340C79FA86C58B94B40
64882	5	52	1260	40315	13450	\N	55.4451992065326	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Партизанская, д. 50	Россия, Новосибирская область, Куйбышев	0101000020E61000001C25AFCE31955340209BE447FCB84B40
64875	5	52	1260	40315	15886	\N	55.448065999999997	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Каинская, д. 78А		0101000020E6100000ADFA5C6DC59453408A39083A5AB94B40
64880	5	52	1260	40315	9802	\N	55.449626488200799	Новосибирская область, Куйбышевский район, город Куйбышев, ул. Закраевского, д. 84	Россия, Новосибирская область, Куйбышев	0101000020E6100000255AF2785A94534035B742588DB94B40
64229	5	52	1260	41320	13898	\N	55.631006218095699	п.Красный Яр , улица Центральная, 31	Россия, Новосибирская область, Куйбышевский район, поселок Красный Яр	0101000020E61000000F9A5DF756BD534036CAFACDC4D04B40
65737	5	52	1260	48994	68964	\N	55.4832414001635	п.Красновка, улица Центральная, 17	Россия, Новосибирская область, Куйбышевский район, поселок Красновка	0101000020E610000083F8C08EFFBF53400D8B51D7DABD4B40
64850	5	52	1260	13716	13632	\N	55.637478999999999	Новосибирская область, Куйбышевский район, Горбуновский сельсовет, деревня Константиновка, ул. Центральная, д. 38		0101000020E6100000D7A546E867B35340827170E998D14B40
65275	5	52	1260	13716	13685	\N	55.637818716113699	с. Константиновка, Ленина, 29 Б	Россия, Новосибирская область, Куйбышевский район, поселок Константиновка (Опаринское)	0101000020E61000008672A25D85B353403BE2900DA4D14B40
64863	5	52	1260	14361	16599	\N	55.445394999999998	Новосибирская область, Куйбышевский район, Осиновский сельсовет, поселок Кондусла, ул. Центральная, д. 2/1	Россия, Новосибирская область, Куйбышевский район, поселок Кондусла	0101000020E61000004C5299620EBC5340A5660FB402B94B40
64855	5	52	1260	14007	\N	\N	55.544280000000001	Новосибирская область, Куйбышевский район, Куйбышевский сельсовет, поселок Комсомольский, ул. Центральная, д. 10	Россия, Новосибирская область, Куйбышевский район, поселок Комсомольский	0101000020E610000063416150A6955340F6EE8FF7AAC54B40
94754	5	52	1260	13850	68326	\N	55.876863603470298	Куйбышевский район, с. Кама, ул. Показановская, 35	Россия, Новосибирская область, Куйбышевский район, поселок Кама	0101000020E61000005871AAB5306E534016855D143DF04B40
64854	5	52	1260	13940	\N	\N	55.541060999999999	Новосибирская область, Куйбышевский район, Куйбышевский сельсовет, поселок Ивушка, ул. Зеленая, д. 16	Россия, Новосибирская область, Куйбышевский район, поселок Ивушка	0101000020E6100000A1BC8FA3398E53400E12A27C41C54B40
64851	5	52	1260	13802	14072	\N	55.730800766819002	Новосибирская область, Куйбышевский район, Зоновский сельсовет, село Зоново, ул. Новая, д. 61	Россия, Новосибирская область, Куйбышевский район, поселок Зоново	0101000020E61000000DFFE9060AD553402A711DE38ADD4B40
64861	5	52	1260	14279	\N	\N	55.471189000000003	Новосибирская область, Куйбышевский район, Октябрьский сельсовет, поселок Заречный, ул. Центральная, д. 17А	Россия, Новосибирская область, Куйбышевский район, поселок Заречный	0101000020E6100000D07CCEDDAE925340139ED0EB4FBC4B40
64849	5	52	1260	13708	13405	\N	55.511200000000002	Новосибирская область, Куйбышевский район, Горбуновский сельсовет, село Горбуново, ул. Рабочая, д. 22		0101000020E6100000B5FE9600FCAD53408CDB68006FC14B40
64847	5	52	1260	13607	14126	\N	55.702528830132401	Новосибирская область, Куйбышевский район, Гжатский сельсовет, село Гжатск, ул. Центральная, д. 149	Россия, Новосибирская область, Куйбышевский район, поселок Гжатск	0101000020E6100000A1698995D18B5340ECBE6378ECD94B40
64842	5	52	1260	13382	13783	\N	55.545639999999999	Новосибирская область, Куйбышевский район, Веснянский сельсовет, поселок Веснянка, ул. Центральная, д. 1		0101000020E61000006284F068E3875340D9B11188D7C54B40
64843	5	52	1260	13437	13795	\N	55.728416998769298	Новосибирская область, Куйбышевский район, Верх-Ичинский сельсовет, село Верх-Ича, ул. Молодежная, д. 2А	Россия, Новосибирская область, Куйбышевский район, поселок Верх-Ича	0101000020E61000000F81238106815340DB6CACC43CDD4B40
64839	5	52	1260	13246	\N	\N	55.517536	Новосибирская область, Куйбышевский район, Булатовский сельсовет, село Булатово, ул. Центральная, д. 12	Россия, Новосибирская область, Куйбышевский район, поселок Булатово	0101000020E61000007F33315D887353405740A19E3EC24B40
64838	5	52	1260	13160	16420	\N	55.804273000000002	Новосибирская область, Куйбышевский район, Балманский сельсовет, село Балман, ул. Центральная, д. 22		0101000020E61000003849F3C7B4DB53402507EC6AF2E64B40
64848	5	52	1260	13665	13944	\N	55.606608999999999	Новосибирская область, Куйбышевский район, Гжатский сельсовет, аул Бергуль, ул. Рапикова, д. 71	Россия, Новосибирская область, Куйбышевский район, поселок Аул-Бергуль	0101000020E6100000A873452921975340C93A1C5DA5CD4B40
64869	5	52	1260	14663	\N	\N	55.708261999999998	Новосибирская область, Куйбышевский район, Чумаковский сельсовет, деревня Андреевка, ул. Кривая, д. 12/3	Россия, Новосибирская область, Куйбышевский район, поселок Андреевка	0101000020E6100000CFBA46CB81C95340F17F4754A8DA4B40
64146	5	52	1260	14663	9949	\N	55.707150263260203	село Андреевка, Центральная, 20/1	Россия, Новосибирская область, Куйбышевский район, поселок Андреевка	0101000020E61000007FC2D9AD65C95340E6AE25E483DA4B40
64835	5	52	1260	13052	13616	\N	55.437980000000003	Новосибирская область, Куйбышевский район, Абрамовский сельсовет, село Абрамово, ул. Зеленая, д. 26		0101000020E6100000A114ADDC0B8E5340AB2688BA0FB84B40
64930	5	52	4882	37222	13735	\N	53.690040000000003	д.Украинка, улица Гагарина, 18		0101000020E6100000ABED26F8A61F49404777103B53D84A40
64797	5	52	1105	11265	14042	\N	54.076143112155897	Новосибирская область, Краснозерский район, село Чернаки, Молодежная, 16	Россия, Новосибирская область, Краснозерский район, поселок Чернаки	0101000020E6100000F3E670ADF6F35340E068C70DBF094B40
64830	5	52	1105	11380	13384	\N	53.749375000000001	Новосибирская область, Краснозерский район,  поселок Целинный, Школьная, 1		0101000020E61000002AE620E868E2534052B81E85EBDF4A40
64812	5	52	1105	11982	13603	\N	53.845711000000001	поселок Хабаровский , улица Школьная,8/2	Россия, Новосибирская область, Краснозерский район, поселок Хабаровский	0101000020E6100000E5D022DBF9F05340096F0F4240EC4A40
64776	5	52	1105	10245	\N	\N	53.658175	Новосибирская область, Краснозерский район,поселок Успенский, Комсомольская, 25	Россия, Новосибирская область, Краснозерский район, поселок Успенский	0101000020E61000005359147651AF5340BC0512143FD44A40
64786	5	52	1105	10245	13880	\N	53.656727271874303	Новосибирская область, Краснозерский район, поселок Успенский, Рязань, 32	Россия, Новосибирская область, Краснозерский район, поселок Успенский	0101000020E6100000E65AB4006DAF534039B35DA10FD44A40
64827	5	52	1105	12702	\N	\N	53.793736000000003	Новосибирская область, Краснозерский район,  поселок Урожайный, Центральная, 18	Россия, Новосибирская область, Краснозерский район, поселок Урожайный	0101000020E61000004F5C8E5720E2534035D4282499E54A40
94745	5	52	1105	10148	13732	\N	53.738250999999998	Краснозерский район, село Ульяновка, улица Зеленорощенская,9		0101000020E6100000CB660E492DB45340A19E3E027FDE4A40
64831	5	52	1105	12861	13772	\N	54.194205169945597	Новосибирская область, Краснозерский район, село Светлое, Центральная, 1А	Россия, Новосибирская область, Краснозерский район, поселок Светлое	0101000020E610000019575C1C95AD53401EDC9DB5DB184B40
64417	5	52	1105	12861	13772	\N	54.193953518217299	с.Светлое, Центральная, 53	Россия, Новосибирская область, Краснозерский район, поселок Светлое	0101000020E6100000520DFB3DB1AD5340D576137CD3184B40
64826	5	52	1105	60586	75370	\N	53.746561417476201	Новосибирская область, Краснозерский район, село Садовое, Почтовая, 18	Россия, Новосибирская область, Краснозерский район, поселок Садовый	0101000020E6100000C85D8429CADF53400ABC934F8FDF4A40
64792	5	52	1105	60654	75512	\N	54.286747081863901	Новосибирская область, Краснозерский район, поселок Рямской, Центральная, 13	Россия, Новосибирская область, Краснозерский район, поселок Рямское	0101000020E61000003F90BC7328B25340F19C2D20B4244B40
64824	5	52	1105	12552	\N	\N	54.199685000000002	Новосибирская область, Краснозерский район,село Полойка, Советская, 43	Россия, Новосибирская область, Краснозерский район, поселок Полойка	0101000020E6100000EAD0E97937D453403A4030478F194B40
64820	5	52	1105	12379	\N	\N	53.750089000000003	Новосибирская область, Краснозерский район, село Половинное, Центральная, 25	Россия, Новосибирская область, Краснозерский район, поселок Половинное	0101000020E610000010255AF278CF5340700B96EA02E04A40
64822	5	52	1105	12379	13762	\N	53.750394154434197	Новосибирская область, Краснозерский район, село Половинное, Станционная, 57	Россия, Новосибирская область, Краснозерский район, поселок Половинное	0101000020E610000097033DD4B6CF5340AC8E1CE90CE04A40
64202	5	52	1105	12379	13622	\N	53.750089000000003	деревня Половинное, улица Северная, 17		0101000020E610000010255AF278CF5340700B96EA02E04A40
64821	5	52	1105	12379	13914	\N	53.749783690415398	Новосибирская область, Краснозерский район, село Половинное, Молодежная, 1А	Россия, Новосибирская область, Краснозерский район, поселок Половинное	0101000020E6100000C0E78711C2CF534033880FECF8DF4A40
64823	5	52	1105	12379	13925	\N	53.750038051506301	Новосибирская область, Краснозерский район, село Половинное, Малининская, 17	Россия, Новосибирская область, Краснозерский район, поселок Половинное	0101000020E61000000D897B2C7DCF5340EE60C43E01E04A40
64802	5	52	1105	11512	14047	\N	54.014951000000003	Новосибирская область, Краснозерский район,  село Петропавловка, Полтавская, 6		0101000020E610000037514B732BE95340710514EAE9014B40
64942	5	52	1105	11512	68955	\N	54.014950842526702	д. Петропавловка, улица Зеленая, 38	Россия, Новосибирская область, Краснозерский район, поселок Петропавловка	0101000020E61000000F289B7285E95340710514EAE9014B40
64805	5	52	1105	11610	13590	\N	53.890627000000002	Новосибирская область, Краснозерский район, поселок Осинниковский, Московская, 24	Россия, Новосибирская область, Краснозерский район, поселок Осинниковский	0101000020E6100000210725CCB4B25340A1F7C61000F24A40
64817	5	52	1105	12241	\N	\N	53.837997000000001	Новосибирская область, Краснозерский район, село Орехов Лог, Ленина, 14	Россия, Новосибирская область, Краснозерский район, поселок Орехов Лог	0101000020E6100000EA2285B2F0D85340B492567C43EB4A40
64809	5	52	1105	11818	16584	\N	53.958452000000001	Новосибирская область, Краснозерский район, поселок Октябрьский, Школьная, 25/1	Россия, Новосибирская область, Краснозерский район, поселок Октябрьский	0101000020E6100000B9C4910722E9534095641D8EAEFA4A40
94753	5	52	1105	13009	68431	\N	53.865206999999998	Краснозерский район, поселок Новый Баганенок, Мира, 4		0101000020E6100000BFF4F6E7A2AE534098A25C1ABFEE4A40
64803	5	52	1105	11556	\N	\N	53.949344000000004	Новосибирская область, Краснозерский район, село Нижнечеремошное, Октябырьская, 47	Россия, Новосибирская область, Краснозерский район, поселок Нижнечеремошное	0101000020E61000009BCAA2B08BB85340B153AC1A84F94A40
94750	5	52	1105	11440	16330	\N	54.020499999999998	Краснозерский район, село Мохнатый Лог, улица Молодежная,6		0101000020E6100000D482177D05E65340B4C876BE9F024B40
47323	5	49	\N	1225	72275	\N	55.985976999999998	Красноярск, Судостроительная, 105		0101000020E6100000A96917D34C365740D9CD8C7E34FE4B40
64796	5	52	1105	11189	14040	\N	54.072012000000001	Новосибирская область, Краснозерский район, село Майское, Ломоносова, 11		0101000020E610000070EF1AF4A5F05340B47570B037094B40
64825	5	52	1105	12611	\N	\N	54.098166999999997	Новосибирская область, Краснозерский район, поселок Луговой, Краснозёрская, 48	Россия, Новосибирская область, Краснозерский район, поселок Луговой	0101000020E610000023F433F5BADB5340F1457BBC900C4B40
64795	5	52	1105	11176	13890	\N	54.137511953939899	Новосибирская область, Краснозерский район,  село Лотошное, Лазорская, 12	Россия, Новосибирская область, Краснозерский район, поселок Лотошное	0101000020E6100000CFBBB1A030B353405E6743FE99114B40
94747	5	52	1105	10946	68430	\N	53.949497000000001	Краснозерский район, село Локтенок , улица Центральная,12		0101000020E6100000BD8DCD8E54C253403753211E89F94A40
94749	5	52	1105	11130	14093	\N	53.861373	Краснозерский район, село Лобино, улица Полтава 10А		0101000020E61000002881CD3978C153402654707841EE4A40
64778	5	52	1105	60655	75549	\N	54.127253000000003	Новосибирская область, Краснозерский район, поселок Ленинград, Новая, 20/2	Россия, Новосибирская область, Краснозерский район, поселок Ленинградский	0101000020E6100000F2CEA10C55CF5340B1A888D349104B40
94751	5	52	1105	11804	68602	\N	53.955261999999998	Краснозерский район, поселок Курьинский, улица Школьная,14		0101000020E61000006891ED7C3FF65340478E740646FA4A40
64785	5	52	1105	10716	\N	\N	53.961190000000002	Новосибирская область, Краснозерский район, поселок Красный Хутор, Краснохуторская, 59	Россия, Новосибирская область, Краснозерский район, поселок Красный Хутор	0101000020E61000003ACB2C42B1D05340029F1F4608FB4A40
64783	5	52	1105	10429	\N	\N	53.984591999999999	Новосибирская область, Краснозерский район, Санаторий, Санаторий, главный корпус	Россия, Новосибирская область, Краснозерский район, поселок Краснозерское	0101000020E6100000BE1248895DCE53409DF3531C07FE4A40
64782	5	52	1105	10429	\N	\N	53.981108999999996	Новосибирская область, Краснозерский район, рабочий поселок Краснозерское, Советская, 68	Россия, Новосибирская область, Краснозерский район, поселок Краснозерское	0101000020E610000024287E8CB9CF5340D767CEFA94FD4A40
64779	5	52	1105	10429	\N	\N	53.981108999999996	Новосибирская область, Краснозерский район, рабочий поселок Краснозерское, Ленина, 34	Россия, Новосибирская область, Краснозерский район, поселок Краснозерское	0101000020E610000024287E8CB9CF5340D767CEFA94FD4A40
64780	5	52	1105	10429	13873	\N	53.979892262517701	Новосибирская область, Краснозерский район, рабочий поселок Краснозерское, Советская, 2	Россия, Новосибирская область, Краснозерский район, поселок Краснозерское	0101000020E61000000FB6D8EDB3CF534057CEDE196DFD4A40
64781	5	52	1105	10429	13752	\N	53.981108999999996	Новосибирская область, Краснозерский район, рабочий поселок Краснозерское, Панарина, 1	Россия, Новосибирская область, Краснозерский район, поселок Краснозерское	0101000020E610000024287E8CB9CF5340D767CEFA94FD4A40
94748	5	52	1105	10983	68377	\N	54.235106000000002	Краснозерский район, село Конево , улица Дмитрия Пахомова,2Б		0101000020E610000018213CDA38C05340F48B12F4171E4B40
94746	5	52	1105	10886	68359	\N	54.066042000000003	Краснозерский район, село Колыбелька, улица Центральная ,5		0101000020E6100000915F3FC406C95340CB14731074084B40
64784	5	52	1105	10647	13750	\N	53.980698861413003	Новосибирская область, Краснозерский район, п.Кайгородский, Студенческая, 33А	Россия, Новосибирская область, Краснозерский район, поселок Кайгородский	0101000020E6100000EE5C18E945CC5340261C7A8B87FD4A40
64777	5	52	1105	10326	13779	\N	54.186014885568298	Новосибирская область, Краснозерский район, с.Казанак, Набережная, 24А		0101000020E61000009010E50B5ACA534060C8EA56CF174B40
64816	5	52	1105	12103	\N	\N	53.759175999999997	Новосибирская область, Краснозерский район, поселок Зуевский, Зуевская, 24	Россия, Новосибирская область, Краснозерский район, поселок Зуевский	0101000020E610000001857AFA08D953403CF4DDAD2CE14A40
94744	5	52	1105	10064	68335	\N	53.773469395553398	Краснозерский район, село Зубково, улица Центральная ,62	Россия, Новосибирская область, Краснозерский район, поселок Зубково	0101000020E6100000DE718A8EE4A9534023BC3D0801E34A40
64773	5	52	1105	10064	75572	\N	53.77393	Новосибирская область, Краснозерский район,Зубковский сельсовет,станция  Зубково, Новая, 26	Россия, Новосибирская область, Краснозерский район, поселок Зубково	0101000020E6100000293C6876DDA9534057B2632310E34A40
65482	5	52	1105	11692	14169	\N	53.903075498456197	дер. Зеленая Роща, ул. Центральная, дом 19	Россия, Новосибирская область, Краснозерский район, поселок Зеленая Роща	0101000020E6100000861BF0F961E95340E86A2BF697F34A40
64818	5	52	1105	12296	13765	\N	53.702157999999997	Новосибирская область, Краснозерский район, поселок Галубинский, Центральная, 71		0101000020E610000032CB9E0436D15340F84F3750E0D94A40
64788	5	52	1105	10863	14086	\N	53.982901225527499	Новосибирская область, Краснозерский район,село Гербаево, Новая, 6	Россия, Новосибирская область, Краснозерский район, поселок Гербаево	0101000020E6100000226FB9FAB1DA5340541A31B3CFFD4A40
64771	5	52	1105	10028	14030	\N	53.761811189848601	Новосибирская область, Краснозерский район, поселок Ганино, Ганинская, 25	Россия, Новосибирская область, Краснозерский район, поселок Ганино	0101000020E6100000B98C9B1A68C15340D55DD90583E14A40
64833	5	52	1105	12915	\N	\N	53.992269	Новосибирская область, Краснозерский район,село  Веселовское, Калинина, 45	Россия, Новосибирская область, Краснозерский район, поселок Веселовское	0101000020E61000005265187783AD5340D5EAABAB02FF4A40
94752	5	52	1105	12915	68363	\N	53.993946852693902	Краснозерский район, село Веселовское, Ленина, 24	Россия, Новосибирская область, Краснозерский район, поселок Веселовское	0101000020E6100000D6C8AEB48CAD5340897AC1A739FF4A40
64800	5	52	1105	11420	\N	\N	54.183923999999998	Новосибирская область, Краснозерский район,поселок Беспятый, Советская, 3	Россия, Новосибирская область, Краснозерский район, поселок Беспятый	0101000020E61000008F705AF0A2EC5340897956D28A174B40
64769	5	52	1105	9914	\N	\N	53.717806000000003	Новосибирская область,Краснозерский район,село Аксениха, Ленина, 30	Россия, Новосибирская область, Краснозерский район, поселок Аксениха	0101000020E6100000F6436CB070BC5340B16F2711E1DB4A40
64293	5	52	3058	34708	13937	\N	55.750084000000001	деревня Александровка, улица Длинная,27		0101000020E610000069C70DBF9B9A42405EA0A4C002E04B40
64764	5	52	1054	48031	\N	\N	54.005622000000002	поселок Троицкий, улица Новая, 1а	Россия, Новосибирская область, Кочковский район, поселок Троицкий	0101000020E6100000DC627E6E68FB5340AE11C138B8004B40
64934	5	52	1054	41350	14007	\N	54.200112940102798	пос.Советский, Гагарина, 4	Россия, Новосибирская область, Кочковский район, поселок Советский	0101000020E6100000F964C570751954409240834D9D194B40
64761	5	52	1054	47984	\N	\N	54.216540999999999	село Решеты, улица Ленина, 5	Россия, Новосибирская область, Кочковский район, поселок Решеты	0101000020E610000073309B00C30D54401F9F909DB71B4B40
64767	5	52	1054	9814	13551	\N	54.265143049906698	поселок  Республиканский, улица Центральная, 5		0101000020E6100000446B459BE3315440B5E1B034F0214B40
65672	5	52	1054	41341	68647	\N	54.117561000000002	село Покровка, Школьная, 4а		0101000020E61000001FA16648152154407D24253D0C0F4B40
65476	5	52	1054	41341	13988	\N	54.118465987166203	дер. Покровка,  ул. Центральная, дом 21,	Россия, Новосибирская область, Кочковский район, поселок Покровка	0101000020E6100000F758FAD0052154400ED8D5E4290F4B40
64757	5	52	1054	41341	13988	\N	54.119323165888702	поселок Покровка, улица Центральная, 6	Россия, Новосибирская область, Кочковский район, поселок Покровка	0101000020E61000001D058882192154408F54DFF9450F4B40
64760	5	52	1054	9455	\N	\N	54.128788999999998	поселок Новые Решеты, улица Школьная, 2г	Россия, Новосибирская область, Кочковский район, поселок Новые Решеты	0101000020E610000089B5F81400195440D28A6F287C104B40
64755	5	52	1054	9269	14017	\N	54.356251	село Новоцелинное, улица Комсомольская, 11	Россия, Новосибирская область, Кочковский район, поселок Новоцелинное	0101000020E610000056D5CBEF342154406A15FDA1992D4B40
64756	5	52	1054	9274	\N	\N	54.325004999999997	село Красная Сибирь, улица Комсомольская, 6	Россия, Новосибирская область, Кочковский район, поселок Красная Сибирь	0101000020E61000001A69A9BC1D205440AB048BC399294B40
64765	5	52	1054	9713	13726	\N	54.332380999999998	село Кочки, улица Революционная, 10		0101000020E6100000EF703B342C1F5440E867EA758B2A4B40
64768	5	52	1054	9845	14285	\N	54.360475000000001	село Жуланка, улица Лахина, 54	Россия, Новосибирская область, Кочковский район, поселок Жуланка	0101000020E6100000F1475167EE2654404703780B242E4B40
64759	5	52	1054	47950	\N	\N	54.124115000000003	поселок Ермаковский, улица Ленина, 30	Россия, Новосибирская область, Кочковский район, поселок Ермаковский	0101000020E6100000AEB6627FD9135440B6F81400E30F4B40
64766	5	52	1054	41311	13864	\N	54.433221851499297	село Быструха, улица Центральная, 60	Россия, Новосибирская область, Кочковский район, поселок Быструха	0101000020E6100000D026874F3A38544030F488D173374B40
64763	5	52	1054	9625	\N	\N	54.133896	деревня Букреево Плесо, улица Советская, 8	Россия, Новосибирская область, Кочковский район, поселок Букреево Плесо	0101000020E61000002429E96168FC534059880E8123114B40
64739	5	52	829	41385	14177	\N	54.912215859149399	с.Шагалово, Школьная, 13	Россия, Новосибирская область, Коченевский район, поселок Шагалово	0101000020E6100000548B8862F28D5440A8716F7EC3744B40
64737	5	52	829	41225	13515	\N	54.964075000000001	с.Чистополье, Центральная, 13	Россия, Новосибирская область, Коченевский район, поселок Чистополье	0101000020E6100000D3C08F6AD89F544013F241CF667B4B40
64750	5	52	829	7488	\N	\N	54.992916000000001	р.п.Чик, Комсомольская, 24	Россия, Новосибирская область, Коченевский район, поселок Чик	0101000020E61000005FB35C363A9C54406BD619DF177F4B40
64717	5	52	829	7488	13734	\N	54.992916000000001	д.Чик, Новая, 2		0101000020E61000005FB35C363A9C54406BD619DF177F4B40
64731	5	52	829	41216	\N	\N	54.810589999999998	с.Целинное, Школьная, 10	Россия, Новосибирская область, Коченевский район, поселок Целинное	0101000020E61000002B4D4A41B77F5440793BC269C1674B40
64740	5	52	829	47590	\N	\N	54.874133999999998	д.Федосово, Центральная, 14	Россия, Новосибирская область, Коченевский район, поселок Федосово	0101000020E61000008AE6012CF28954402C29779FE36F4B40
64727	5	52	829	41369	14077	\N	54.745933443196797	с.Федосиха, Клубная, 12	Россия, Новосибирская область, Коченевский район	0101000020E610000066A208A9DB735440EB0088BB7A5F4B40
64720	5	52	829	47200	\N	\N	55.131881999999997	д.Троицк, Центральная, 34	Россия, Новосибирская область, Коченевский район, поселок Троицк	0101000020E6100000F8C43A55BE8F54402D776682E1904B40
64699	5	52	829	41248	13601	\N	55.190774585944403	д.Студенкино, Лесная, 11	Россия, Новосибирская область, Коченевский район	0101000020E61000009817601F9D7754407CF2B0506B984B40
65639	5	52	829	41211	68969	\N	55.158847999999999	п. Семеновский, улица Центральная, 15		0101000020E6100000A391CF2B9E8354407B849A2155944B40
64716	5	52	829	47113	\N	\N	55.013348000000001	п.Светлый, Школьная, 6	Россия, Новосибирская область, Коченевский район, поселок Светлый	0101000020E610000039B35DA10F925440C7BB2363B5814B40
64738	5	52	829	40453	13942	\N	54.895124000000003	п.Речник, Центральная, 6	Россия, Новосибирская область, Коченевский район, поселок Речник	0101000020E6100000355D4F745DA05440AFEE586C93724B40
94732	5	52	99	41275	68333	\N	53.643749	Карасукский  район, с.Михайловка, улица Ценетральная, 33		0101000020E6100000B22AC24D4683534096EA025E66D24A40
64713	5	52	829	7207	\N	\N	55.013173000000002	с.Прокудское, Политотдельская, 135а	Россия, Новосибирская область, Коченевский район, поселок Прокудское	0101000020E61000005C72DC291D9D5440591822A7AF814B40
64711	5	52	829	7207	\N	\N	55.013173000000002	с.Прокудское, Совхозная, 23	Россия, Новосибирская область, Коченевский район, поселок Прокудское	0101000020E61000005C72DC291D9D5440591822A7AF814B40
64712	5	52	829	7207	16559	\N	55.013173000000002	с.Прокудское, Вокзальная, 57		0101000020E61000005C72DC291D9D5440591822A7AF814B40
64706	5	52	829	6934	14184	\N	54.733623999999999	с.Поваренка, Центральный переулок, 6	Россия, Новосибирская область, Коченевский район, поселок Поваренка	0101000020E6100000F12DAC1BEF995440C5C72764E75D4B40
64697	5	52	829	6516	\N	\N	55.013022999999997	п.Ольшанский, Средняя, 5	Россия, Новосибирская область, Коченевский район, поселок Ольшанский	0101000020E61000007495EEAEB3725440438CD7BCAA814B40
64703	5	52	829	41197	13449	\N	55.197486091546999	с.Овчинниково, Советская, 15а	Россия, Новосибирская область, Коченевский район, поселок Овчинниково	0101000020E61000000473F4F8BD6B54407CB5A33847994B40
64704	5	52	829	49611	16623	\N	55.206937051036398	п.Новорощенский, Сибирская, 8	Россия, Новосибирская область, Коченевский район, поселок Новорощинский	0101000020E6100000E21DE0490B6754408BAA5FE97C9A4B40
64721	5	52	829	7651	\N	\N	55.130420000000001	д.Новоотрубное, Центральная, 12	Россия, Новосибирская область, Коченевский район, поселок Новоотрубное (Улькино)	0101000020E61000008ECC237F30895440465F419AB1904B40
64688	5	52	829	6048	13673	\N	55.198031	с.Новокремлевское, Маяковского, 6	Россия, Новосибирская область, Коченевский район, поселок Новокремлевское	0101000020E6100000056B9C4D479454400E4C6E1459994B40
64689	5	52	829	6117	13698	\N	55.298943000000001	п.Молот, Заводская, 5		0101000020E6100000354580D3BB9254401F2FA4C343A64B40
64733	5	52	829	41221	13507	\N	54.865341999999998	п.Маслово, Центральная, 10	Россия, Новосибирская область, Коченевский район, поселок Маслово	0101000020E610000092E86514CB75544078EDD286C36E4B40
64736	5	52	829	8352	14019	\N	54.846542306695099	п.Малореченка, Школьная, 24	Россия, Новосибирская область, Коченевский район, поселок Малореченка	0101000020E6100000A8A624EB708054406058FE7C5B6C4B40
64729	5	52	829	47402	\N	\N	54.741759000000002	п.Лесной, Школьная, 1	Россия, Новосибирская область, Коченевский район, поселок Лесной	0101000020E61000001807978E396C5440C0417BF5F15E4B40
64694	5	52	829	6361	13511	\N	55.044895805085801	ст.Лесная Поляна, Школьная, 4	Россия, Новосибирская область, Коченевский район, поселок Лесная Поляна	0101000020E6100000CA32C4B12E7C544051DCF126BF854B40
64692	5	52	829	6264	\N	\N	55.306379	с.Крутологово, Московская, 14/2	Россия, Новосибирская область, Коченевский район, поселок Крутологово	0101000020E61000000E65A88AA98554403197546D37A74B40
64718	5	52	829	7515	\N	\N	55.146301000000001	д.Крохалевка, Мира, 34	Россия, Новосибирская область, Коченевский район, поселок Крохалевка	0101000020E610000022179CC1DFA25440A12FBDFDB9924B40
64745	5	52	829	8716	\N	\N	55.019202	р.п.Коченево, Октябрьская, 54	Россия, Новосибирская область, Коченевский район, поселок Коченево	0101000020E61000003FADA23F348D544047020D3675824B40
64743	5	52	829	8716	\N	\N	55.019202	р.п.Коченево, Школьная, 46	Россия, Новосибирская область, Коченевский район, поселок Коченево	0101000020E61000003FADA23F348D544047020D3675824B40
64747	5	52	829	8716	14012	\N	55.019202	р.п.Коченево, Строительная, 29		0101000020E61000003FADA23F348D544047020D3675824B40
64748	5	52	829	8716	13522	\N	55.019202	р.п.Коченево, Строительная, 15		0101000020E61000003FADA23F348D544047020D3675824B40
64744	5	52	829	8716	13851	\N	55.019202	р.п.Коченево, Малокузнецкая, 27а	Россия, Новосибирская область, Коченевский район, поселок Коченево	0101000020E61000003FADA23F348D544047020D3675824B40
64746	5	52	829	8716	13523	\N	55.0182451781371	р.п.Коченево, Максима Горького, 139а	Россия, Новосибирская область, Коченевский район, поселок Коченево	0101000020E610000002124DA0888D5440632827DA55824B40
64749	5	52	829	8716	14182	\N	55.019202	р.п.Коченево, Кузнецкая, 176		0101000020E61000003FADA23F348D544047020D3675824B40
64708	5	52	829	7014	14884	\N	54.776046000000001	п. Комихинский, улица Раздольная, 23		0101000020E610000053EA92718C8754408718AF7955634B40
64732	5	52	829	41271	13705	\N	54.909185197904002	д.Козлово, Центральная, 11	Россия, Новосибирская область, Коченевский район, поселок Козлово	0101000020E610000020D3DA34B67C5440C381902C60744B40
64715	5	52	829	41382	14158	\N	55.206333999999998	д.Катково, Лесная, 1	Россия, Новосибирская область, Коченевский район, поселок Катково	0101000020E610000073BB97FBE47D5440C4060B27699A4B40
64742	5	52	829	41278	13721	\N	54.947423999999998	д.Казаково, Центральная, 15	Россия, Новосибирская область, Коченевский район, поселок Казаково	0101000020E6100000FE60E0B9F792544006B98B3045794B40
64702	5	52	829	41198	13456	\N	55.309964999999998	с.Ермиловка, Школьная, 9	Россия, Новосибирская область, Коченевский район, поселок Ермиловка	0101000020E61000009A97C3EE3B7C5440CBF3E0EEACA74B40
64687	5	52	829	5978	13494	\N	55.085235994187599	ст.Дупленская, Садовая, 25	Россия, Новосибирская область, Коченевский район, поселок Дупленская	0101000020E6100000D95DA0A4C06754408F386403E98A4B40
64752	5	52	829	41367	14066	\N	54.974612824751802	п.Дружный, Цетральная, 1	Россия, Новосибирская область, Коченевский район, поселок Дружный	0101000020E6100000902E36AD148A5440D3A0681EC07C4B40
64693	5	52	829	46655	16536	\N	55.246805000000002	д.Вахрушево, Московская, 8/3	Россия, Новосибирская область, Коченевский район, поселок Вахрушево	0101000020E61000005BCD3AE3FB895440A1BE654E979F4B40
64714	5	52	829	41300	13830	\N	55.063302999999998	д.Буньково, Молодёжная, 27	Россия, Новосибирская область, Коченевский район, поселок Буньково	0101000020E6100000E77283A10E9F54408D5E0D501A884B40
94702	5	52	1326	41323	68571	\N	55.009796000000001	Барабинский район, д.Квашнино , улица Рыбозаводская, 25		0101000020E6100000D09D60FF75755340D9D0CDFE40814B40
64722	5	52	829	41381	14157	\N	55.065666910597102	д.Белобородово, Новая, 4	Россия, Новосибирская область, Коченевский район, поселок Белобородово	0101000020E6100000F56569A7E682544095B6B8C667884B40
64754	5	52	829	9147	13537	\N	55.007591236748702	п. Бармашево, улица Центральная, 17	Россия, Новосибирская область, Коченевский район, поселок Бармашево	0101000020E61000003A0664AF77845440395FECBDF8804B40
64709	5	52	829	41200	13460	\N	54.828859753730796	д.Антоновка, Школьная, 5	Россия, Новосибирская область, Коченевский район, поселок Антоновка	0101000020E6100000F8FBC56CC9935440357BA015186A4B40
64658	5	52	597	4459	\N	\N	55.446666999999998	д. Юрт-Ора, Колыванский район, Новосибирская область, ул.Горская, д.10	Россия, Новосибирская область, Колыванский район, поселок Юрт-Ора	0101000020E61000000491459A78BA5440E9995E622CB94B40
64673	5	52	597	5211	15917	\N	55.657758000000001	д. Юрт-Акбалык, Колыванский район, Новосибирская область, ул.Центральная, д.28		0101000020E610000020D5B0DF13E454405857056A31D44B40
94743	5	52	597	4292	68428	\N	55.489294999999998	Колыванский район, дер. Южино, улица Школьная, 20		0101000020E6100000AF230ED940A15440548CF337A1BE4B40
64669	5	52	597	5058	13452	\N	55.514977913923097	д. Черный Мыс, Колыванский район, Новосибирская область, ул.Лесная, д.20		0101000020E6100000E0641BB803D154406A1492CCEAC14B40
64649	5	52	597	3930	13627	\N	55.343783000000002	Новосибирская область, Колыванский район, д.Чаус, ул.Титова, д.24		0101000020E6100000A8C821E2E6B15440DCF5D21401AC4B40
64661	5	52	597	4634	\N	\N	55.532685999999998	с. Тропино, Колыванский район, Новосибирская область, ул.Зеленая, д.10а	Россия, Новосибирская область, Колыванский район, поселок Тропино	0101000020E6100000412B306475AC5440BE840A0E2FC44B40
64665	5	52	597	4846	\N	\N	55.583061999999998	д. Таловка, Колыванский район, Новосибирская область, ул.Учительская, д.2	Россия, Новосибирская область, Колыванский район, поселок Таловка	0101000020E6100000AB59677C5FBC54402AC58EC6A1CA4B40
64650	5	52	597	4027	13948	\N	55.200322569564698	Новосибирская область, Колыванский район, Соколово, ул. Советская, д.43	Россия, Новосибирская область, Колыванский район, поселок Соколово	0101000020E6100000AF78EA9106A454407CD11E2FA4994B40
64656	5	52	597	4315	13815	\N	55.377951000000003	с. Скала, Колыванский район, Новосибирская область, ул.Калинина, д.3		0101000020E610000023A298BC01B15440C93EC8B260B04B40
64654	5	52	597	4248	13434	\N	55.441631999999998	с. Сидоровка, Колыванский район, Новосибирская область, ул.Советская, д.28		0101000020E61000008F17D2E1219A5440FC6EBA6587B84B40
64677	5	52	597	5442	14018	\N	56.018081000000002	пос. Северный, Колыванский район, Новосибирская область, ул.Октябрьская, д.2		0101000020E610000097C4591135AC5440E9D66B7A50024C40
64683	5	52	597	5798	13838	\N	56.137249221982302	д.Пономаревка, Колыванский район, Новосибирская область, ул.Береговая, д.40 А	Россия, Новосибирская область, Колыванский район, поселок Пономаревка	0101000020E6100000198F52094F97544050340F6091114C40
64676	5	52	597	5420	13831	\N	55.995559	с. Пихтовка, Колыванский район, Новосибирская область, ул.Максима Горького, д.8		0101000020E61000000E4C6E1459AD5440861E317A6EFF4B40
64663	5	52	597	4685	\N	\N	55.565294999999999	пос. Паутовский, Колыванский район, Новосибирская область, ул.Береговая, д.38, кв.2	Россия, Новосибирская область, Колыванский район, поселок Паутовский	0101000020E61000005F7F129F3BB05440D1CB28965BC84B40
64653	5	52	597	4151	15803	\N	55.287604000000002	с. Новотырышкино, Колыванский район, Новосибирская область, ул.Мира, д.15		0101000020E61000001D90847D3B9A544072193735D0A44B40
64668	5	52	597	4986	\N	\N	55.601604999999999	с. Новотроицк, Колыванский район, Новосибирская область, ул.Калинина, д.17	Россия, Новосибирская область, Колыванский район, поселок Новотроицк	0101000020E61000008F5033A48AD15440170E846401CD4B40
65522	5	52	597	41339	68951	\N	56.167008960055902	дер. Новоалександровка  , ул. Иванова, дом 26\\1,	Россия, Новосибирская область, Колыванский район, поселок Новоалександровка	0101000020E61000004206F2ECF2A154409F91088D60154C40
65273	5	52	597	41339	13981	\N	56.1675357259329	д. Новоалександровка, Горького, 50	Россия, Новосибирская область, Колыванский район, поселок Новоалександровка	0101000020E61000002575029A08A254408A73D4D171154C40
64681	5	52	597	5676	13958	\N	55.848246000000003	д. Мальчиха, Колыванский район, Новосибирская область, ул.Школьная, д.11	Россия, Новосибирская область, Колыванский район, поселок Мальчиха	0101000020E61000007D923B6C22A354403E7B2E5393EC4B40
64651	5	52	597	4033	13641	\N	55.275148999999999	Новосибирская область, Колыванский район, д. Малый Оёш, ул.Октябрьская, д.9 А		0101000020E61000009161156F64AA544078431A1538A34B40
65696	5	52	597	41312	13867	\N	56.028666741236698	поселок Малиновка, улица Лесная, 4	Россия, Новосибирская область, Колыванский район, поселок Малиновка	0101000020E6100000F4DC425722AF5440BABC395CAB034C40
64666	5	52	597	4904	\N	\N	55.594825	д. Малая Черемшанка, Колыванский район, Новосибирская область, ул.Садовая, д.2	Россия, Новосибирская область, Колыванский район, поселок Малая Черемшанка	0101000020E6100000F2CEA10C55C15440EEEBC03923CC4B40
64679	5	52	597	5545	\N	\N	55.790610000000001	д. Лаптевка, Колыванский район, Новосибирская область, ул.Береговая, д.1	Россия, Новосибирская область, Колыванский район, поселок Лаптевка	0101000020E6100000CEE0EF17B3935440FEF15EB532E54B40
64682	5	52	597	5740	14164	\N	56.031447999999997	с. Королевка, Колыванский район, Новосибирская область, ул.Школьная, д.20	Россия, Новосибирская область, Колыванский район, поселок Королевка	0101000020E610000057EA5910CAC1544026C3F17C06044C40
64434	5	52	1399	44373	15073	\N	54.7032697427396	с.Цветники, Центральная, 37	Россия, Новосибирская область, Здвинский район, поселок Цветники	0101000020E61000001F8315A75AB05340042159C0045A4B40
64686	5	52	597	3752	\N	\N	55.309725	Новосибирская область, Колыванский район, рабочий поселок Колывань, ул.Карла Маркса, д.64	Россия, Новосибирская область, Колыванский район, поселок Колывань	0101000020E61000000F63D2DF4BAF544076E09C11A5A74B40
64646	5	52	597	3752	\N	\N	55.309725	Новосибирская область, Колыванский район, рабочий поселок Колывань, ул.Калинина, д.45	Россия, Новосибирская область, Колыванский район, поселок Колывань	0101000020E61000000F63D2DF4BAF544076E09C11A5A74B40
64645	5	52	597	3752	\N	\N	55.309725	Новосибирская область, Колыванский район, рабочий поселок Колывань, ул.Московская, д.99	Россия, Новосибирская область, Колыванский район, поселок Колывань	0101000020E61000000F63D2DF4BAF544076E09C11A5A74B40
64647	5	52	597	3752	16223	\N	55.309725	"Новосибирская область, Колыванский район, рабочий поселок Колывань, ул.Чехова, д.3""а"""		0101000020E61000000F63D2DF4BAF544076E09C11A5A74B40
64685	5	52	597	3752	14168	\N	55.308992526148998	Новосибирская область, Колыванский район, рабочий поселок Колывань, ул.Советская, д.48	Россия, Новосибирская область, Колыванский район, поселок Колывань	0101000020E6100000F9BCE2A947AF5440B2D826158DA74B40
64684	5	52	597	3752	16337	\N	55.309725	Новосибирская область, Колыванский район, рабочий поселок Колывань, ул.Московская, д.48	Россия, Новосибирская область, Колыванский район, поселок Колывань	0101000020E61000000F63D2DF4BAF544076E09C11A5A74B40
64675	5	52	597	5340	13467	\N	55.676433003677097	с. Кандаурово Колыванский район, Новосибирская область, ул.Советская, д.15	Россия, Новосибирская область, Колыванский район, поселок Кандаурово	0101000020E6100000F6B4C35F93CC5440B477465B95D64B40
64671	5	52	597	5156	13983	\N	55.667451999999997	д.Казанка, Колыванский район, Новосибирская область, ул.Зарипова, д.42		0101000020E61000008BFB8F4C87DE54402CD32F116FD54B40
64664	5	52	597	4805	\N	\N	55.522540999999997	с. Вьюны, Колыванский район, Новосибирская область, ул.Советская, д.21	Россия, Новосибирская область, Колыванский район, поселок Вьюны	0101000020E6100000B972F6CE68BB5440D9E89C9FE2C24B40
64652	5	52	597	4138	13433	\N	55.309714	д. Воробьево, Колыванский район, Новосибирская область, ул.Дорожная, д.3		0101000020E6100000D7F9B7CB7EA45440828E56B5A4A74B40
64660	5	52	597	4550	14139	\N	55.619494114692003	с. Боярка, Колыванский район, Новосибирская область, ул.Ленина, д.8	Россия, Новосибирская область, Колыванский район, поселок Боярка	0101000020E610000002D71533C2AF5440BC0853944BCF4B40
64648	5	52	597	3925	14121	\N	55.289587599046797	Новосибирская область, Колыванский район, д.Большой Оёш, ул.Суворова, д.45	Россия, Новосибирская область, Колыванский район, поселок Большой Оёш	0101000020E610000020CF2EDFFAAD544033A8363811A54B40
64657	5	52	597	4408	16607	\N	55.438935999999998	д. Амба, Колыванский район, Новосибирская область, ул.Школьная, д.9		0101000020E61000000D7041B62CB15440BE840A0E2FB84B40
64626	5	52	250	2695	\N	\N	55.036963	Новосибирская область, Каргатский район, Первомайский сельсовет, п. Чернявский, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Чернявский	0101000020E610000011A7936C75105440BE141E34BB844B40
64622	5	52	250	2493	\N	\N	55.275435999999999	Новосибирская область, Каргатский район, Форпост-Каргатский сельсовет, с. Форпост-Каргат, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Форпост-Каргат	0101000020E6100000A9BD88B6631C54400E12A27C41A34B40
64613	5	52	250	1961	\N	\N	55.286748000000003	Новосибирская область, Каргатский район, Карганский сельсовет, п. Филино, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Филино	0101000020E610000042CF66D5E7FC5340C2189128B4A44B40
64635	5	52	250	3213	\N	\N	54.846300999999997	Новосибирская область, Каргатский район, Суминский сельсовет, с. Усть-Сумы, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Усть-Сумы	0101000020E61000009626A5A0DB0F54403AC95697536C4B40
64616	5	52	250	2157	\N	\N	55.428220477789402	Новосибирская область, Каргатский район, Карганский сельсовет, п. Третьяковский, Сельский клуб		0101000020E610000037A968ACFD1354401FBFB7E9CFB64B40
64623	5	52	250	2505	\N	\N	55.341321000000001	Новосибирская область, Каргатский район, Форпост-Каргатский сельсовет, п. Теренино, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Теренино	0101000020E6100000B3CEF8BEB81A544011381268B0AB4B40
64634	5	52	250	3202	\N	\N	54.811731000000002	Новосибирская область, Каргатский район, Суминский сельсовет, с. Сумы, Администрация	Россия, Новосибирская область, Каргатский район, поселок Сумы	0101000020E6100000AED4B320941C54401F1329CDE6674B40
64610	5	52	250	41289	\N	\N	55.090048641903202	Новосибирская область, Каргатский район, Беркутовский сельсовет, п. Старо-Михайловский, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Старомихайловский	0101000020E6100000459F8F32E2FF5340CD04C3B9868B4B40
64641	5	52	250	3537	\N	\N	54.5266167713242	Новосибирская область, Каргатский район, Алабугинский сельсовет, п. Сапожковский, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Сапожковский	0101000020E6100000F4531C075E1B54404242942F68434B40
64638	5	52	250	3399	\N	\N	54.576296999999997	Новосибирская область, Каргатский район, Алабугинский сельсовет, п. Петровский, Школа	Россия, Новосибирская область, Каргатский район, поселок Петровский	0101000020E6100000DC8310902F25544036E49F19C4494B40
64419	5	52	1399	24965	14113	\N	54.710692999999999	д.Хапово, Ленина, 17А		0101000020E6100000A79201A08AB65340813FFCFCF75A4B40
64631	5	52	250	3002	\N	\N	55.092467999999997	Новосибирская область, Каргатский район, Кубанский сельсовет, с. Первотроицк, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Первотроицк	0101000020E61000001842CEFBFF17544098F6CDFDD58B4B40
64628	5	52	250	2841	\N	\N	55.0435056967234	Новосибирская область, Каргатский район, Первомайский сельсовет, п. Первомайский, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Первомайский	0101000020E6100000E78D93C2BC0B54400397C79A91854B40
64640	5	52	250	41267	\N	\N	54.638980593827199	Новосибирская область, Каргатский район, Алабугинский сельсовет, д. Озерки-6, Школа	Россия, Новосибирская область, Каргатский район, поселок Озерки 6-е	0101000020E61000004374081C09105440F8E12021CA514B40
64621	5	52	250	2365	\N	\N	55.311822031152403	Новосибирская область, Каргатский район, Верх-Каргатский сельсовет, п. Натальинский, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Натальинский	0101000020E610000028806264C93654402F1686C8E9A74B40
64603	5	52	250	1364	\N	\N	55.173735000000001	Новосибирская область, Каргатский район, Беркутовский сельсовет, с. Набережное, Дом Культуры	Россия, Новосибирская область, Каргатский район, поселок Набережное	0101000020E61000007A6EA12B110B5440D595CFF23C964B40
64618	5	52	250	2259	\N	\N	55.453936376920097	Новосибирская область, Каргатский район, Мусинский сельсовет, с. Мусы, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Мусы	0101000020E61000009755D80C701B5440103D29931ABA4B40
64636	5	52	250	3305	\N	\N	54.735573000000002	Новосибирская область, Каргатский район, Суминский сельсовет, п. Москвинка, Школа	Россия, Новосибирская область, Каргатский район, поселок Москвинка	0101000020E6100000C0266BD4431054400A698D41275E4B40
64642	5	52	250	3633	\N	\N	55.032454000000001	Новосибирская область, Каргатский район, Маршанский сельсовет, с. Маршанское, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Маршанское	0101000020E610000075C8CD7003F65340EC4FE27327844B40
64639	5	52	250	3445	\N	\N	54.665536000000003	Новосибирская область, Каргатский район, Алабугинский сельсовет, с. Мамонтовое, Администрация сельсовета		0101000020E6100000B56B425A63155440C4279D4830554B40
64611	5	52	250	1805	\N	\N	55.229331999999999	Новосибирская область, Каргатский район, Карганский сельсовет, п. Лебедевский, Сельский клуб		0101000020E6100000CE548847E209544090F63FC05A9D4B40
64632	5	52	250	3049	\N	\N	55.106709998437303	Новосибирская область, Каргатский район, Кубанский сельсовет, п. Кубанский, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Кубанский	0101000020E61000006B9BE271511C5440FD135CACA88D4B40
64625	5	52	250	2651	\N	\N	54.986339999999998	Новосибирская область, Каргатский район, Первомайский сельсовет, с. Кольцовка, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Кольцовка	0101000020E6100000223317B83C0E54404A5E9D63407E4B40
64602	5	52	250	1029	\N	\N	55.194172000000002	Новосибирская область, Каргатский район, город Каргат, Мостовая, 22	Россия, Новосибирская область, Каргатский район, Каргат	0101000020E610000037DE1D19AB11544043E6CAA0DA984B40
64601	5	52	250	1029	\N	\N	55.194172000000002	Новосибирская область, Каргатский район, город Каргат, Вокзальная, 9	Россия, Новосибирская область, Каргатский район, Каргат	0101000020E610000037DE1D19AB11544043E6CAA0DA984B40
64600	5	52	250	1029	\N	\N	55.194172000000002	Новосибирская область, Каргатский район, город Каргат, Советская, 418	Россия, Новосибирская область, Каргатский район, Каргат	0101000020E610000037DE1D19AB11544043E6CAA0DA984B40
64599	5	52	250	1029	\N	\N	55.194172000000002	Новосибирская область, Каргатский район, город Каргат, Крестьянская, 22	Россия, Новосибирская область, Каргатский район, Каргат	0101000020E610000037DE1D19AB11544043E6CAA0DA984B40
64598	5	52	250	1029	\N	\N	55.194172000000002	Новосибирская область, Каргатский район, город Каргат, Матросова, 11	Россия, Новосибирская область, Каргатский район, Каргат	0101000020E610000037DE1D19AB11544043E6CAA0DA984B40
64597	5	52	250	1029	13575	\N	55.192981697012499	Новосибирская область, Каргатский район, город Каргат, Советская, 124 А	Россия, Новосибирская область, Каргатский район, Каргат	0101000020E6100000C26856B60F125440BC5B59A2B3984B40
64615	5	52	250	2076	\N	\N	55.348436999999997	Новосибирская область, Каргатский район, Карганский сельсовет, с. Карган, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Карган	0101000020E6100000456458C51B035440B1DB679599AC4B40
64643	5	52	250	3668	\N	\N	54.889857999999997	Новосибирская область, Каргатский район, Маршанский сельсовет, с. Иванкино, Школа	Россия, Новосибирская область, Каргатский район, поселок Иванкино	0101000020E61000004CE2AC889AFA5340BF0AF0DDE6714B40
64617	5	52	250	2168	\N	\N	55.25168	Новосибирская область, Каргатский район, Карганский сельсовет, д. Груздевка, Бывший сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Груздевка	0101000020E6100000A852B3075A0054405587DC0C37A04B40
64630	5	52	250	2949	\N	\N	54.990845	Новосибирская область, Каргатский район, Кубанский сельсовет, п. Голубовский, Фельдшерско-акушерский пункт	Россия, Новосибирская область, Каргатский район, поселок Голубовский	0101000020E61000000F5EBBB4E1195440DB334B02D47E4B40
94713	5	52	1623	22255	14003	\N	56.246451	Венгеровский район, село Филошенка, улица Центральная, 7		0101000020E6100000AFEDED96E45653408388D4B48B1F4C40
64604	5	52	250	41318	\N	\N	55.162878680945497	Новосибирская область, Каргатский район, Беркутовский сельсовет, п. Гавриловка, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Гавриловка	0101000020E6100000FC17080264095440431A1538D9944B40
64978	5	52	250	41318	13884	\N	55.161817854865099	д.Гавриловка, улица Лесная,10	Россия, Новосибирская область, Каргатский район, поселок Гавриловка	0101000020E6100000E603029D49095440BAF3C473B6944B40
64619	5	52	250	2307	\N	\N	55.367981	Новосибирская область, Каргатский район, Верх-Каргатский сельсовет, с. Верх-Каргат, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Верхний Каргат	0101000020E6100000AF93FAB2B429544052465C001AAF4B40
64605	5	52	250	1477	\N	\N	55.183121999999997	Новосибирская область, Каргатский район, Беркутовский сельсовет, д. Беркуты, Сельский Клуб		0101000020E6100000F69A1E1494FF5340CC96AC8A70974B40
64608	5	52	250	1615	\N	\N	55.228495000000002	Новосибирская область, Каргатский район, Беркутовский сельсовет, п. Безлюдный, Сельский клуб		0101000020E6100000A6F10BAF240454405726FC523F9D4B40
64644	5	52	250	3713	\N	\N	54.971879000000001	Новосибирская область, Каргатский район, Маршанский сельсовет, с. Аткуль, Сельский клуб	Россия, Новосибирская область, Каргатский район, поселок Аткуль	0101000020E6100000E621533E04EA5340A855F487667C4B40
64637	5	52	250	3349	\N	\N	54.669150000000002	Новосибирская область, Каргатский район, Алабугинский сельсовет, д. Алабуга, Дом культуры	Россия, Новосибирская область, Каргатский район, поселок Алабуга	0101000020E6100000247F30F0DC1D5440280F0BB5A6554B40
65072	5	52	3692	35542	\N	\N	55.992291000000002	с. Локти, улица Школьная, д. 1	Россия, Курганская область, Каргапольский район, село Локти	0101000020E61000007F69519FE43A5040BD8E386403FF4B40
64558	5	52	99	41387	14180	\N	53.762860000000003	посёлок Ягодный, улица Школьная, 10	Россия, Новосибирская область, Карасукский район, поселок Ягодный	0101000020E6100000E9D7D64FFF8053409AB67F65A5E14A40
94724	5	52	99	31339	68351	\N	53.806068000000003	Карасукский  район, с.Шилово_Курья, улица Центральная, 27		0101000020E61000000F289B72858B5340132D793C2DE74A40
64593	5	52	99	764	13876	\N	53.849420301173197	село Чернокурья, улица Центральная, 42	Россия, Новосибирская область, Карасукский район, поселок Чернокурья	0101000020E6100000B41EBE4C14985340BF4868CBB9EC4A40
64557	5	52	99	31386	\N	\N	53.829846000000003	посёлок Чернозёрка, улица Школьная, 11	Россия, Новосибирская область, Карасукский район, поселок Чернозерка	0101000020E6100000965D30B8E67B5340B45BCB6438EA4A40
94741	5	52	99	642	68357	\N	53.585222000000002	Карасукский  район, с.Хорошее, улица Набережная, 8		0101000020E61000001500E31934A053402A73F38DE8CA4A40
64585	5	52	99	41235	13556	\N	53.723494218973997	село Троицкое, улица Зеленая, 37 Г	Россия, Новосибирская область, Карасукский район, поселок Троицкое	0101000020E61000004301DBC188745340166D8E739BDC4A40
64194	5	52	99	41235	13556	\N	53.723154855770701	с. Троицкое, улица Зеленая, 22	Россия, Новосибирская область, Карасукский район, поселок Троицкое	0101000020E6100000F47002D3697453402D78D15790DC4A40
94742	5	52	99	735	14487	\N	53.594014000000001	Карасукский  район, д.Токаревка, улица Мира, 47		0101000020E61000008369183E22965340DEAE97A608CC4A40
94739	5	52	99	48892	68355	\N	53.613996	Карасукский  район, с.Студёное, улица 35 лет Победы, 41 А		0101000020E610000057276728EE615340FAEFC16B97CE4A40
64587	5	52	99	386	\N	\N	53.730772999999999	село Сорочиха, улица Зеленая, 3 А	Россия, Новосибирская область, Карасукский район, поселок Сорочиха	0101000020E61000004F0647C9AB7C534060E63BF889DD4A40
64571	5	52	99	48718	\N	\N	53.660229000000001	посёлок Свободный Труд, улица Центральная, 3	Россия, Новосибирская область, Карасукский район, поселок Свободный Труд	0101000020E6100000C503CAA65CA45340766F456282D44A40
94728	5	52	99	41356	68425	\N	54.104275000000001	Карасукский  район, п.Рождественский, переулок Центральный, 10		0101000020E6100000357F4C6BD3A453402C6519E2580D4B40
64586	5	52	99	41766	14331	\N	53.666567617777503	село Рассказово, улица Школьная, 17 Б	Россия, Новосибирская область, Карасукский район, поселок Рассказово	0101000020E610000021956247E37A5340B247A81952D54A40
94726	5	52	99	49662	68376	\N	53.734879999999997	Карасукский  район, п.Поповка, улица Ленина, 45		0101000020E6100000EC17EC866D695340033E3F8C10DE4A40
94735	5	52	99	49666	68457	\N	53.433259	Карасукский  район, д.Павловка, улица Молодёжная, 26		0101000020E6100000471CB281747053404DD9E90775B74A40
64560	5	52	99	31484	13860	\N	53.778686999999998	ст.Осолодино, улица Станционная, 1 А	Россия, Новосибирская область, Карасукский район, поселок Осолодино	0101000020E61000009A6038D7307D53400169FF03ACE34A40
64576	5	52	99	48804	\N	\N	53.512275000000002	село Октябрьское, улица Ленина, 82	Россия, Новосибирская область, Карасукский район, поселок Октябрьское	0101000020E61000009A7CB3CD8D7353407AC7293A92C14A40
64588	5	52	99	505	\N	\N	53.753261999999999	посёлок Озёрное-Титово, улица Озёрная, 1 А	Россия, Новосибирская область, Карасукский район, поселок Озерное-Титово	0101000020E6100000494DBB98667F5340E7A8A3E36AE04A40
94737	5	52	99	41239	13567	\N	53.458217423350703	Карасукский  район, д.Новоивановка, улица Сиреневая, 31	Россия, Новосибирская область, Карасукский район, поселок Новоивановка	0101000020E6100000BB2BBB607079534051BCCADAA6BA4A40
94730	5	52	99	48688	68426	\N	53.781005999999998	Карасукский  район, д.Нестеровка, улица Заречная, 39/2		0101000020E6100000D8463CD9CDA1534069FD2D01F8E34A40
64594	5	52	99	49110	68582	\N	53.919939999999997	село Морозовка, улица Пушкина, 3 А		0101000020E6100000D009A1832E95534020240B98C0F54A40
64906	5	52	99	41275	14163	\N	53.643647347875302	д.Михайловка, улица Центральная, 36	Россия, Новосибирская область, Карасукский район, поселок Михайловка	0101000020E6100000A1BC8FA33983534092955F0663D24A40
64584	5	52	99	131	\N	\N	53.62274	село Луганск, улица Трудовая, 14 В	Россия, Новосибирская область, Карасукский район, поселок Луганск	0101000020E61000004BC972124A6653409DF4BEF1B5CF4A40
64595	5	52	99	917	13877	\N	53.997599000000001	посёлок Кучугур, улица Школьная, 1		0101000020E6100000B900344A978D5340DBC2F352B1FF4A40
64567	5	52	99	41310	13862	\N	54.208584999999999	деревня Кукарка, улица Школьная, 29	Россия, Новосибирская область, Карасукский район, поселок Кукарка	0101000020E6100000B5C2F4BD86995340D4B7CCE9B21A4B40
64554	5	52	99	29532	\N	\N	53.735002000000001	город Карасук, улица Союзная, 130	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64552	5	52	99	29532	\N	\N	53.735002000000001	город Карасук, улица Тургенева, 16	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64550	5	52	99	29532	\N	\N	53.735002000000001	город Карасук, улица Тургенева, 1	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64547	5	52	99	29532	\N	\N	53.735002000000001	город Карасук, улица Коммунистическая, 11	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64545	5	52	99	29532	\N	\N	53.735002000000001	город Карасук, улица Радищева, 20	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64519	5	52	99	29532	13835	\N	53.735002000000001	город Карасук, улица Щорса, 17		0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64546	5	52	99	29532	16567	\N	53.735002000000001	город Карасук, улица Фрунзе, 89		0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64551	5	52	99	29532	14005	\N	53.733532275024203	город Карасук, улица Тургенева, 14	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000DD09F65FE7815340E4486760E4DD4A40
64549	5	52	99	29532	13709	\N	53.735002000000001	город Карасук, улица Сергея Лазо, 1		0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
64548	5	52	99	29532	13713	\N	53.732218600970199	город Карасук, улица Луначарского, 44	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000D0420246978353404241295AB9DD4A40
64553	5	52	99	29532	13849	\N	53.735002000000001	город Карасук, улица Ленина, 157	Россия, Новосибирская область, Карасукский район, Карасук	0101000020E6100000185DDE1CAE8253404F3FA88B14DE4A40
94734	5	52	99	49665	68586	\N	53.624245999999999	Карасукский  район, а.Карасарт, улица Центральная, 8		0101000020E610000035B39602D29053405454FD4AE7CF4A40
94729	5	52	99	49663	68686	\N	53.717053999999997	Карасукский  район, с.Калиновка, улица Школьная, 44		0101000020E61000003E5DDDB1D89F5340A5BBEB6CC8DB4A40
65541	5	52	99	49663	68962	\N	53.716440456070998	д. Калиновка, улица Калиновская, 27	Россия, Новосибирская область, Карасукский район, поселок Калиновка	0101000020E61000005133A48AE29F5340EBC5504EB4DB4A40
94736	5	52	99	32347	68687	\N	53.590305000000001	Карасукский  район, с.Калачи, улица Набережная, 27		0101000020E610000098C118912878534028D53E1D8FCB4A40
64575	5	52	99	49347	16473	\N	53.648459135194798	аул Кавкуй, улица Сельская, 14	Россия, Новосибирская область, Карасукский район, поселок Кавкуй	0101000020E6100000007157AF228A534000E65AB400D34A40
94727	5	52	99	31754	68354	\N	54.036482999999997	Карасукский  район, с.Ирбизино, улица, Центральная, 10		0101000020E6100000187B2FBE689E534013EE9579AB044B40
94731	5	52	99	32014	13865	\N	53.745297000000001	Карасукский  район, п.Грамотино, улица Центральная,6/2		0101000020E61000005680EF366F965340496760E465DF4A40
94723	5	52	99	41352	68374	\N	53.842337000000001	Карасукский  район, с.Благодатное, улица Центральная, 24		0101000020E6100000412B306475835340FA9AE5B2D1EB4A40
94725	5	52	99	48543	68352	\N	53.941325999999997	Карасукский  район, с.Белое, улица Пушкина, 1		0101000020E610000054556820969D5340EF6FD05E7DF84A40
94740	5	52	99	627	68593	\N	53.641482620701403	Карасукский  район, п.Астродым, улица Озерная, 30 Г	Россия, Новосибирская область, Карасукский район, поселок Астродым	0101000020E6100000395FECBDF870534051F86C1D1CD24A40
94738	5	52	99	48874	68691	\N	53.4138182074376	Карасукский  район, с.Анисимовка, улица Заречная, 28	Россия, Новосибирская область, Карасукский район, поселок Анисимовка	0101000020E61000004703780B24775340813FFCFCF7B44A40
94733	5	52	99	49664	68583	\N	53.701044000000003	Карасукский  район, п.Александровский, улица Центральная, 23		0101000020E61000009694BBCFF18D53404D874ECFBBD94A40
65932	5	52	7467	59108	67817	\N	55.107534999999999	Новосибирская область, город Новосибирск, Калининский район, Курчатова, 13/1		0101000020E610000095EEAEB321BE54407216F6B4C38D4B40
65936	5	52	7467	59108	67821	\N	55.111170999999999	Новосибирская область, город Новосибирск, Калининский район, Родники, 4		0101000020E6100000FCFF3861C2BC5440BEA1F0D93A8E4B40
64460	5	52	1791	26865	14070	\N	54.491689000000001	Новосибирская область, Искитимский район, деревня Шибково, ул.Советская, 21 (здание школы)	Россия, Новосибирская область, Искитимский район, поселок Шибково	0101000020E6100000C2BE9D4484D25440C76647AAEF3E4B40
64465	5	52	1791	26865	13784	\N	54.491443291202899	Новосибирская область, Искитимский район, деревня Шибково, ул.Береговая, 53А (здание администрации с/с)	Россия, Новосибирская область, Искитимский район, поселок Шибково	0101000020E61000006E13EE9579D254408F6CAE9AE73E4B40
94718	5	52	1791	27300	13631	\N	54.459122999999998	Искитимский район, деревня Шадрино, ул.Центральная, 2А		0101000020E6100000AB59677C5FDA5440B3EBDE8AC43A4B40
64520	5	52	1791	29589	\N	\N	54.524182000000003	Новосибирская область, Искитимский район, деревня Чупино, ул.Школьная, 8 (здание клуба)	Россия, Новосибирская область, Искитимский район, поселок Чупино	0101000020E61000009293895B05BD54407193516518434B40
64457	5	52	1791	26745	\N	\N	54.567962000000001	Новосибирская область, Искитимский район, поселок Койниха, ул.Пушкина, 8 (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Койниха	0101000020E610000010CB660E49D0544075AF93FAB2484B40
64452	5	52	1791	26482	\N	\N	54.652031999999998	Новосибирская область, Искитимский район, поселок Чернореченский, ул.Кооперативная, 3 (дом культуры)	Россия, Новосибирская область, Искитимский район, поселок Чернореченский	0101000020E6100000AFCDC64ACCD1544005F9D9C875534B40
64538	5	52	1791	30464	\N	\N	54.369439999999997	Новосибирская область, Искитимский район, поселок Целинный, ул.Центральная, 3 (клуб)	Россия, Новосибирская область, Искитимский район, поселок Целинный	0101000020E610000051F9D7F2CAB65440C8EA56CF492F4B40
64798	5	52	1791	30464	13613	\N	54.3696036060023	поселок Целинный, улица Зелена,2	Россия, Новосибирская область, Искитимский район, поселок Целинный	0101000020E61000003DBB7CEBC3B65440433C122F4F2F4B40
64487	5	52	1791	28071	13956	\N	54.617415000000001	Новосибирская область, Искитимский район, деревня Харино, ул.Центральная, 2А (помещение клуба)		0101000020E61000004A97FE25A9E65440A9876874074F4B40
64544	5	52	1791	30755	13702	\N	54.477446999999998	поселок Факел Революции, ул.Красный Факел, 2	Россия, Новосибирская область, Искитимский район, поселок Факел Революции	0101000020E610000094BDA59C2F9C54406249B9FB1C3D4B40
64485	5	52	1791	27994	13810	\N	54.663879999999999	Новосибирская область, Искитимский район, село Усть-Чем, ул.Центральная, 21А (клуб)		0101000020E6100000FCC56CC9AAEE5440F73B1405FA544B40
64474	5	52	1791	27502	13416	\N	54.500829000000003	Новосибирская область, Искитимский район, деревня Ургун, ул.Школьная, 7 (помещение школы)		0101000020E610000083A5BA8097DB5440B7F1272A1B404B40
64517	5	52	1791	29428	\N	\N	54.581713999999998	Новосибирская область, Искитимский район, село Улыбино, ул.Первомайская, 55 (помещение администрации МО)	Россия, Новосибирская область, Искитимский район, поселок Улыбино	0101000020E610000083C0CAA145BB54400BD0B69A754A4B40
64515	5	52	1791	29367	\N	\N	54.591903000000002	Новосибирская область, Искитимский район, поселокТула, ул.Школьная, 9 (здание клуба)	Россия, Новосибирская область, Искитимский район, поселок Тула	0101000020E61000003A083A5AD5AC5440C0B33D7AC34B4B40
64461	5	52	1791	26915	\N	\N	54.505937000000003	Новосибирская область, Искитимский район, деревняТаскаево, ул.Советская, 46А (здание клуба)	Россия, Новосибирская область, Искитимский район, поселок Таскаево	0101000020E61000006B7F677BF4CE54400E6B2A8BC2404B40
64489	5	52	1791	28187	\N	\N	54.708415000000002	Новосибирская область, Искитимский район, с.Тальменка, ул.Кооперативная, 21 (дом культуры)	Россия, Новосибирская область, Искитимский район, поселок Тальменка	0101000020E6100000CEFDD5E3BED15440787FBC57AD5A4B40
64522	5	52	1791	29685	14150	\N	54.504258999999998	Новосибирская область, Искитимский район, поселок Степной, ул.Первомайская, 16 (помещение администрации МО)	Россия, Новосибирская область, Искитимский район, поселок Степной	0101000020E6100000478E740646BC544059DB148F8B404B40
64459	5	52	1791	26825	13776	\N	54.612597000000001	Новосибирская область, Искитимский район, село Старый Искитим, пер. Солнечный, 2А (помещение Дома культуры)		0101000020E6100000A4C519C39CD9544059501894694E4B40
64483	5	52	1791	27887	\N	\N	54.597208000000002	Новосибирская область, Искитимский район, деревня Старососедово, ул.Школьная, 17 (клуб)	Россия, Новосибирская область, Искитимский район, поселок Старососедово	0101000020E6100000126A865451FB54406D74CE4F714C4B40
94719	5	52	1791	59133	68128	\N	54.510264279125501	Искитимский район, станция Евсино, ул.Пушкина, 2	Россия, Новосибирская область, Искитимский район	0101000020E6100000D6C56D3480D65440BF29AC5450414B40
64516	5	52	1791	29393	13682	\N	54.451768999999999	Новосибирская область, Искитимский район, поселок Советский, ул.Школьная, 19 (здание школы)		0101000020E610000059198D7C5EAB54405E2C0C91D3394B40
65141	5	52	1791	41314	13874	\N	54.677277006866802	Новосибирская область, Новосибирский район, с. Новошилово, Степная, 18а (здание школы № 82)	Россия, Новосибирская область, Искитимский район	0101000020E6100000817B9E3F6DBD54409FAA4203B1564B40
64454	5	52	1791	26594	\N	\N	54.614907000000002	Новосибирская область, Искитимский район, поселок Рябчинка, ул.Горная, 5 (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Рябчинка	0101000020E6100000BEDC274701C754406E8AC745B54E4B40
64453	5	52	1791	26530	\N	\N	54.634954	Новосибирская область, Искитимский район, поселок Рощинский, ул.Космическая, 23 (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Рощинский	0101000020E6100000AAB8718BF9CD5440713B342C46514B40
64524	5	52	1791	29797	13475	\N	54.484690999999998	поселок Раздольный, ул.Лесная, 16	Россия, Новосибирская область, Искитимский район, поселок Раздольный	0101000020E61000001FDAC70A7EC5544030D5CC5A0A3E4B40
64518	5	52	1791	29489	13980	\N	54.577340999999997	Новосибирская область, Искитимский район, поселок Первомайский, ул.Садовая, 17А (помещение школы)		0101000020E61000000F7C0C569CC05440E9D1544FE6494B40
64527	5	52	1791	29892	\N	\N	54.443973999999997	Новосибирская область, Искитимский район, поселок Октябрьский, ул.Центральная, 1 (здание клуба)	Россия, Новосибирская область, Искитимский район, поселок Октябрьский	0101000020E61000006D1D1CEC4DBA54401C23D923D4384B40
64512	5	52	1791	29242	\N	\N	54.507547000000002	Новосибирская область, Искитимский район, поселок Озерки, ул.Трудовая, 20А (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Озерки	0101000020E6100000B613252191A854406A17D34CF7404B40
64496	5	52	1791	28492	13659	\N	54.844492000000002	Новосибирская область, Искитимский район, деревня Китерня, ул.Центральная, 2Б (помещение школы)		0101000020E6100000618907944DEC5440E8DD5850186C4B40
64484	5	52	1791	27985	\N	\N	54.644489	Новосибирская область, Искитимский район, деревня Новососедово, ул.Центральная, 18 (помещение клуба)	Россия, Новосибирская область, Искитимский район, поселок Новососедово	0101000020E61000009EB30584D6FE5440DDD0949D7E524B40
64535	5	52	1791	30271	13696	\N	54.392968000000003	Новосибирская область, Искитимский район, село Новолокти, ул.Советская, 5/5 (здание администрации с/с)		0101000020E6100000C154336B29BA5440F12F82C64C324B40
64464	5	52	1791	27008	13629	\N	54.461896000000003	Новосибирская область, Искитимский район, деревня Новолебедевка, ул.Центральная, 23А (клуб)	Россия, Новосибирская область, Искитимский район, поселок Новолебедевка	0101000020E61000001E4E603AADC954409D137B681F3B4B40
64499	5	52	1791	28604	13666	\N	54.817422000000001	Новосибирская область, Искитимский район, деревня Нижний Коен, переулок Нагорный, 7/1 (здание школы)		0101000020E6100000657094BC3AD95440F583BA48A1684B40
64486	5	52	1791	28059	13422	\N	54.772058000000001	Новосибирская область, Искитимский район, село Мосты, ул.Рабочая, 5 (помещение школы)		0101000020E6100000DD408177F2F65440BE4EEACBD2624B40
64497	5	52	1791	27272	13816	\N	54.769886999999997	Новосибирская область, Искитимский район, село Морозово, ул.Школьная, 6 (школа)		0101000020E610000077137CD3F4CD5440CA4E3FA88B624B40
64469	5	52	1791	27272	13401	\N	54.769886999999997	"Новосибирская область, Искитимский район, село Морозово, ул.Тимуровская, 3 (помещение ДСОЛКД ""Тимуровец""))"		0101000020E610000077137CD3F4CD5440CA4E3FA88B624B40
64540	5	52	1791	28413	\N	\N	54.429411000000002	Новосибирская область, Искитимский район, поселок Михайловка, ул.Нижняя, 26/1 (школа)	Россия, Новосибирская область, Искитимский район, поселок Михайловка	0101000020E610000053AF5B04C6C5544076C58CF0F6364B40
64494	5	52	1791	28413	16533	\N	54.429411000000002	Новосибирская область, Искитимский район, деревня Михайловка, ул.Центральная, 17Б (школа)		0101000020E610000053AF5B04C6C5544076C58CF0F6364B40
64506	5	52	1791	28973	\N	\N	54.695439999999998	Новосибирская область, Искитимский район, поселок Маяк, ул.Центральная, 21А  (здание школы)	Россия, Новосибирская область, Искитимский район, поселок Маяк	0101000020E6100000548F34B8ADC85440452A8C2D04594B40
64481	5	52	1791	27803	13946	\N	54.662058000000002	Новосибирская область, Искитимский район, деревня Малиновка, ул.Центральная, 31А (помещение клуба)	Россия, Новосибирская область, Искитимский район, поселок Малиновка	0101000020E610000033FD12F1D6F6544010070951BE544B40
64468	5	52	1791	27224	\N	\N	54.440663999999998	Новосибирская область, Искитимский район, р.п.Листвянский, ул.Шахматова, 8 (помещение дома культуры)	Россия, Новосибирская область, Искитимский район, поселок Листвянский	0101000020E6100000EAD0E97937DF544024438EAD67384B40
64444	5	52	1791	26100	\N	\N	54.451774	Новосибирская область, Искитимский район, р.п.Линево, ул.Кольцевая, 4 (Детская музыкальная школа)	Россия, Новосибирская область, Искитимский район, поселок Линево	0101000020E6100000CDAE7B2B12D854407097FDBAD3394B40
64448	5	52	1791	26100	14064	\N	54.452226052687301	Новосибирская область, Искитимский район, р.п.Линево, пр.Мира, 50 (Линевская школа № 4)	Россия, Новосибирская область, Искитимский район, поселок Линево	0101000020E61000007DEA58A5F4D754405133A48AE2394B40
64450	5	52	1791	26100	14117	\N	54.458099501976498	Новосибирская область, Искитимский район, р.п.Линево, пр.Коммунистический, 3 (клуб НовЭЗа)	Россия, Новосибирская область, Искитимский район, поселок Линево	0101000020E6100000B6F3FDD478D8544018265305A33A4B40
64446	5	52	1791	26100	14117	\N	54.451774	"Новосибирская область, Искитимский район, р.п. Линево, пр.Коммунистический, 3 (клуб ЗАО ""НОВЭЗ"")"		0101000020E6100000CDAE7B2B12D854407097FDBAD3394B40
64542	5	52	1791	26100	13501	\N	54.451774	Новосибирская область, Искитимский район, р.п.Линево, ул.Листвянская, 31А (Линевская школа № 3)		0101000020E6100000CDAE7B2B12D854407097FDBAD3394B40
64447	5	52	1791	26100	13501	\N	54.452025995985103	Новосибирская область, Искитимский район, р.п. Линево, ул. Листвянская, 43А (детская художественная школа)	Россия, Новосибирская область, Искитимский район, поселок Линево	0101000020E610000093C49272F7D754408978EBFCDB394B40
64445	5	52	1791	26100	13869	\N	54.451925967265701	Новосибирская область, Искитимский район, р.п.Линево, Бульвар Ветеранов войны, 10 (Линевская школа № 1)	Россия, Новосибирская область, Искитимский район, поселок Линево	0101000020E6100000939048DBF8D75440261B0FB6D8394B40
64449	5	52	1791	26100	13918	\N	54.451774	"Новосибирская область, Искитимский район, р.п.Линево, 4-й микрорайон, 16 (МОУ ""Гимназия № 1)"		0101000020E6100000CDAE7B2B12D854407097FDBAD3394B40
64443	5	52	1791	26100	13918	\N	54.454910051677999	"Новосибирская область, Искитимский район, р.п.Линево, 4-й микрорайон, 16 (МОУ ""Гимназия № 1"")"	Россия, Новосибирская область, Искитимский район, поселок Линево	0101000020E6100000F4C29D0B23D85440CA4FAA7D3A3A4B40
64543	5	52	1791	27793	13840	\N	54.642793291134502	село Легостаево, ул.Новый Поселок, 15А	Россия, Новосибирская область, Искитимский район, поселок Легостаево	0101000020E61000006B65C22FF5F35440828C800A47524B40
64480	5	52	1791	27793	16597	\N	54.646864000000001	Новосибирская область, Искитимский район, село Легостаево, ул.Милицейская, 12 (помещение Дома культуры)		0101000020E610000022A98592C9F35440D97A8670CC524B40
64505	5	52	1791	28893	\N	\N	54.672362	Новосибирская область, Искитимский район, село Лебедевка, ул.Центральная, 54 (Лебедевский центр досуга)	Россия, Новосибирская область, Искитимский район, поселок Лебедевка	0101000020E61000009A982EC4EACE54405D8940F50F564B40
64467	5	52	1791	27170	13785	\N	54.435543000000003	Новосибирская область, Искитимский район, поселок Керамкомбинат, ул.Центральная, 5 (дом культуры)		0101000020E61000000B9A965819D6544039807EDFBF374B40
64530	5	52	1791	30071	14162	\N	54.388081999999997	Новосибирская область, Искитимский район, поселок Каменка, ул.Центральная, 10/2 (помещение ФАПа)		0101000020E610000023BBD23252A754404815C5ABAC314B40
64492	5	52	1791	28318	\N	\N	54.708247999999998	Новосибирская область, Искитимский район, деревня Калиновка, ул.Школьная, 35 (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Калиновка	0101000020E6100000562B137EA9DD54408CBAD6DEA75A4B40
65379	5	52	1791	29330	68380	\N	54.499454	село Завьялово, улица Центральная, 6А		0101000020E61000003B70CE88D29C54409EEDD11BEE3F4B40
64514	5	52	1791	29330	13445	\N	54.498882186875399	Новосибирская область, Искитимский район, село Завьялово, ул.Совхозная, 47А (здание школы)	Россия, Новосибирская область, Искитимский район, поселок Завьялово	0101000020E61000002EE57CB1F79C54401348895DDB3F4B40
94721	5	52	1791	28214	13425	\N	54.735289328978297	Искитимский район, село Елбаши, ул.Центральная, 59	Россия, Новосибирская область, Искитимский район, поселок Елбаши	0101000020E6100000A514747B49E65440E50D30F31D5E4B40
64466	5	52	1791	27142	13789	\N	54.417096000000001	Новосибирская область, Искитимский район, деревня Евсино, ул.Речная, 10А (здание клуба)		0101000020E61000008658FD1186D454406EA5D76663354B40
64495	5	52	1791	28447	14137	\N	54.913479000000002	Новосибирская область, Искитимский район, поселок Дзержинский, пер.Школьный, 2 (помещение школы)		0101000020E6100000F04E3E3DB6DE5440994A3FE1EC744B40
64478	5	52	1791	27704	\N	\N	54.617367999999999	Новосибирская область, Искитимский район, деревня Девкино, ул Центральная, 12 (здание клуба)	Россия, Новосибирская область, Искитимский район, поселок Девкино	0101000020E61000002BA5677A89EC544068CC24EA054F4B40
64476	5	52	1791	27610	13792	\N	54.515783999999996	Новосибирская область, Искитимский район, село Гусельниково, ул.Центральная, 7 (здание Дома культуры)		0101000020E6100000969350FA42EC544068E6C93505424B40
64532	5	52	1791	30169	13694	\N	54.368488056036298	Новосибирская область, Искитимский район, деревня Горевка, ул.Зеленая, 2 (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Горевка	0101000020E610000085798F334DAE5440F67B629D2A2F4B40
64537	5	52	1791	30389	\N	\N	54.348920999999997	Новосибирская область, Искитимский район, деревня Гилево, ул.Центральная, 6 (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Гилево	0101000020E6100000B8E864A9F5BB54409DF17D71A92C4B40
64493	5	52	1791	28332	13655	\N	54.865810367437597	Новосибирская область, Искитимский район, село Верх-Коен, ул.Газовая, 1 (помещение дома культуры)	Россия, Новосибирская область, Искитимский район, поселок Верх-Коен	0101000020E6100000D4298F6E84E054405F46B1DCD26E4B40
64511	5	52	1791	29181	\N	\N	54.534923999999997	Новосибирская область, Искитимский район, село Быстровка, ул.Советская, 15А (дом культуры)	Россия, Новосибирская область, Искитимский район, поселок Быстровка	0101000020E6100000BBD1C77C40A5544039ECBE6378444B40
64503	5	52	1791	28804	\N	\N	54.635948999999997	"Новосибирская область, Искитимский район, деревня Бурмистрово, Административный корпус СОЛКД ""Чкаловец"""	Россия, Новосибирская область, Искитимский район, поселок Бурмистрово	0101000020E61000005F44DB3175B554404276DEC666514B40
64510	5	52	1791	28804	14141	\N	54.635948999999997	Новосибирская область, Искитимский район, деревня Бурмистрово, ул.Береговая, 32А (дом культуры)		0101000020E61000005F44DB3175B554404276DEC666514B40
64523	5	52	1791	29691	13827	\N	54.487312000000003	Новосибирская область, Искитимский район, деревня Бородавкино, ул.Школьная, 6 (здание школы)		0101000020E610000081423D7D04BA54406479573D603E4B40
64526	5	52	1791	29874	13688	\N	54.482066000000003	Новосибирская область, Искитимский район, поселок Березовка, ул.Школьная, 2  (помещение школы)		0101000020E6100000C443183F8DBF5440BC41B456B43D4B40
64501	5	52	1791	28726	13970	\N	54.739165	Новосибирская область, Искитимский район, деревня Бердь, ул.Речная, 24 (клуб д.Бердь)		0101000020E61000004F5B238271CB544086AC6EF59C5E4B40
94720	5	52	1791	27634	68348	\N	54.537055422183897	Искитимский район, село Белово, ул.Зеленая, 53	Россия, Новосибирская область, Искитимский район, поселок Белово	0101000020E61000006BB75D68AEE854409F93DE37BE444B40
64491	5	52	1791	28271	\N	\N	54.659765999999998	Новосибирская область, Искитимский район, поселок Барабка, ул.Школьная, 6А (здание школы)	Россия, Новосибирская область, Искитимский район, поселок Барабка	0101000020E6100000842D76FBACDB5440A181583673544B40
64534	5	52	1791	30242	\N	\N	54.305435000000003	Новосибирская область, Искитимский район, поселок Алексеевский, ул.Мира, 37 (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Алексеевский	0101000020E6100000641F645930AF5440E2067C7E18274B40
64456	5	52	1791	26700	\N	\N	54.583686	Новосибирская область, Искитимский район, поселок Александровский, ул.Достоевского, 5А (помещение школы)	Россия, Новосибирская область, Искитимский район, поселок Александровский	0101000020E61000008B8D791D71CA544008910C39B64A4B40
43294	5	52	1399	23208	13624	\N	54.66525	д.Щелчиха, Садовая, 21		0101000020E61000006DE7FBA9F1985340FED478E926554B40
64439	5	52	1399	25892	13912	\N	54.569627672137401	д.Широкая Курья, Курьинская, 20	Россия, Новосибирская область, Здвинский район, поселок Широкая Курья	0101000020E6100000E3DF675C388953406571FF91E9484B40
94717	5	52	1399	25767	15333	\N	54.745189000000003	Здвинский район, Чича, улица Утюпина, 34		0101000020E6100000D41055F833A55340632B685A625F4B40
64413	5	52	1399	24707	\N	\N	54.666572000000002	с.Старогорносталево, Томская, 16	Россия, Новосибирская область, Здвинский район, поселок Старогорносталево	0101000020E610000016F88A6EBDCE5340F436363B52554B40
64387	5	52	1399	15374	68973	\N	54.827302550797697	д.Сарыбалык, улица Набережная, 15	Россия, Новосибирская область, Здвинский район, поселок Сарыбалык	0101000020E61000004CA60A4625B05340FC709010E5694B40
64431	5	52	1399	15374	14937	\N	54.826799999999999	с.Сарыбалык, Береговая, 9		0101000020E6100000882CD2C43BB05340992A1895D4694B40
64404	5	52	1399	41242	13571	\N	54.918536215875797	п.Петропавловский, Береговая, 8	Россия, Новосибирская область, Здвинский район, поселок Петропавловский	0101000020E6100000ACC5A70018A953406E19709692754B40
64423	5	52	1399	45793	\N	\N	54.759684999999998	с.Петраки, Клубная, 17	Россия, Новосибирская область, Здвинский район, поселок Петраки	0101000020E6100000021077F52A9853408121AB5B3D614B40
64430	5	52	1399	25418	14104	\N	54.941052999999997	д.Новощербаки, Центральная, 20		0101000020E6100000B11A4B581BB95340BE66B96C74784B40
64420	5	52	1399	41286	13755	\N	54.346216446188897	с.Новороссийское, Центральная, 31	Россия, Новосибирская область, Здвинский район, поселок Новороссийское	0101000020E610000059FCA6B0529253400CAD4ECE502C4B40
94715	5	52	1399	49661	68450	\N	54.902163999999999	Здвинский район, Новогребенщиково, улица Сартланская, 16/2		0101000020E6100000E7DF2EFB75A1534074D0251C7A734B40
64418	5	52	1399	24937	\N	\N	54.615366000000002	с.Нижний-Чулым, Центральная, 20А	Россия, Новосибирская область, Здвинский район, поселок Нижний Чулым (Сарапулово)	0101000020E61000009F0436E7E0BB534001892650C44E4B40
64416	5	52	1399	24854	\N	\N	54.525969000000003	с.Нижний-Урюм, Степная, 2	Россия, Новосибирская область, Здвинский район, поселок Нижний Урюм (Лохмоткино)	0101000020E61000005A0EF450DB9D5340DCDAC2F352434B40
94716	5	52	1399	46272	68456	\N	54.566172000000002	Здвинский район, Михайловка, улица Северная, 19		0101000020E610000089B5F81400A4534099F4F75278484B40
64421	5	52	1399	25081	13895	\N	54.445658999999999	с.Мамон, Садовая, 4		0101000020E6100000BDE5EAC7269153408315A75A0B394B40
64424	5	52	1399	25204	14123	\N	54.8083222060705	д.Маландино, Школьная, 7	Россия, Новосибирская область, Здвинский район, поселок Маландино	0101000020E6100000E6AC4F3926A353409351651877674B40
64414	5	52	1399	41319	13886	\N	54.365451180730403	с.Лянино, Центральная, 38	Россия, Новосибирская область, Здвинский район, поселок Лянино	0101000020E6100000B03DB32440A053402FA52E19C72E4B40
64441	5	52	1399	26020	\N	\N	54.702266000000002	с.Здвинск, Здвинского, 37	Россия, Новосибирская область, Здвинский район, поселок Здвинск	0101000020E6100000F816D68D77AA5340DF8B2FDAE3594B40
64442	5	52	1399	26020	13911	\N	54.702266000000002	с.Здвинск, Калинина, 11		0101000020E6100000F816D68D77AA5340DF8B2FDAE3594B40
64433	5	52	1399	25594	14105	\N	54.880267000000003	п.Горькое Озеро, Озерная, 1	Россия, Новосибирская область, Здвинский район, поселок Горькое Озеро	0101000020E61000004D8578245EB45340C05FCC96AC704B40
64427	5	52	1399	45848	\N	\N	54.639242000000003	д.Городище, Мира, 11	Россия, Новосибирская область, Здвинский район, поселок Городище (Заворино)	0101000020E6100000060DFD135C835340651D8EAED2514B40
64410	5	52	1399	24570	\N	\N	54.491343999999998	с.Верх-Урюм, Лянинская, 1	Россия, Новосибирская область, Здвинский район, поселок Верх-Урюм	0101000020E6100000E0BDA3C684A55340FC8A355CE43E4B40
64407	5	52	1399	24384	\N	\N	54.795546000000002	с.Верх-Каргат, Центральная, 1А	Россия, Новосибирская область, Здвинский район, поселок Верх-Каргат	0101000020E61000000AD80E46ECC55340583B8A73D4654B40
64408	5	52	1399	42961	14702	\N	54.757331999999998	п.Бережки, Береговая, 1	Россия, Новосибирская область, Здвинский район, поселок Бережки	0101000020E61000001AC231CB9EBE53406D1B4641F0604B40
64415	5	52	1399	24798	13887	\N	54.306393568184198	с.Барлакуль, Центральная, 40	Россия, Новосибирская область, Здвинский район, поселок Барлакуль	0101000020E61000005A66118AADAA534066D828EB37274B40
64411	5	52	1399	24619	13581	\N	54.551093999999999	д.Алексотово, Молодежная, 13		0101000020E6100000A45016BEBEB35340CB82893F8A464B40
64400	5	52	1399	45362	75547	\N	54.887630999999999	д.Алексеевка, Центральная, 27		0101000020E610000006651A4D2EA1534038F581E49D714B40
64394	5	52	1400	23778	13564	\N	54.295957000000001	Новосибирская область, Доволенский район, Шагальский с/с , с.Шагалка, Централья, 1		0101000020E6100000A3586E6935DF5340DA0242EBE1254B40
64396	5	52	1400	23789	13871	\N	54.719664000000002	Новосибирская область, Доволенский район, Утянский с/с, с.Утянка, Центральная, 49		0101000020E6100000BF0CC68844F05340E50D30F31D5C4B40
64395	5	52	1400	23789	13871	\N	54.719664000000002	Новосибирская область, Доволенский район, Утянский с/с, с.Утянка, Центральная, 35	Россия, Новосибирская область, Доволенский район, поселок Утянка	0101000020E6100000BF0CC68844F05340E50D30F31D5C4B40
64393	5	52	1400	41313	13868	\N	54.265612868692799	Новосибирская область, Доволенский район, Травнинский с/с, С.Травное, Юбилейная, 37	Россия, Новосибирская область, Доволенский район	0101000020E61000004E7FF62345E953403C32569BFF214B40
64391	5	52	1400	23642	\N	\N	54.585704999999997	Новосибирская область, Доволенский район, Суздальский с/с, с.Суздалка, Школьная, 11Б	Россия, Новосибирская область, Доволенский район, поселок Суздалка	0101000020E61000004A7EC4AF58DD5340450DA661F84A4B40
64385	5	52	1400	23300	16651	\N	54.809713099847102	п.Солонцвый, улица Солнечная, 7	Россия, Новосибирская область, Доволенский район, поселок Солонцовый	0101000020E6100000D1950854FFF95340B212F3ACA4674B40
64389	5	52	1400	23553	\N	\N	54.292042000000002	Новосибирская область, Доволенский район, Согорнский с/с, с.Согорное, Ленина, 2	Россия, Новосибирская область, Доволенский район, поселок Согорное	0101000020E61000001DE38A8BA3FC53407B87DBA161254B40
65543	5	52	1400	15426	13758	\N	54.747915828575998	д. Сарыбалык, улица Клубная, 1	Россия, Новосибирская область, Доволенский район, поселок Сарыбалык	0101000020E610000007B13385CEFC5340DB1324B6BB5F4B40
64376	5	52	1400	22941	\N	\N	54.367074000000002	Новосибирская область, Доволенский район, Доволенский с/с, с.Покровка, 34	Россия, Новосибирская область, Доволенский район, поселок Покровка	0101000020E61000006BD619DF17F15340209BE447FC2E4B40
64369	5	52	1400	22623	\N	\N	54.358848000000002	Новосибирская область, Доволенский район, Волчанский с/с, д.Плеханово, Юдинская, 1	Россия, Новосибирская область, Доволенский район, поселок Плеханово	0101000020E61000000726378AACDB5340151E34BBEE2D4B40
64398	5	52	1400	60762	76005	\N	54.534132078634599	Новосибирская область, Доволенский район, Ярковский с/с. д.Кротово, Партизанская, 23	Россия, Новосибирская область, Доволенский район	0101000020E6100000A818E76F42E65340A0DFF76F5E444B40
64383	5	52	1400	23241	\N	\N	54.770758999999998	Новосибирская область, Доволенский район, п.Красная Грива, Набережная, 10	Россия, Новосибирская область, Доволенский район, поселок Красная Грива	0101000020E610000075CC79C6BEFC5340800C1D3BA8624B40
64392	5	52	1400	23698	14028	\N	54.601818999999999	Новосибирская область, Доволенский район,  д.Комендантка, Набережная, 7А		0101000020E6100000CB9E0436E7E75340438EAD67084D4B40
64380	5	52	1400	23113	14026	\N	54.420772999999997	Новосибирская область, Доволенский район, Комарьевский с/с, с.Комарье, Центральная, 29		0101000020E610000015A930B6100E54401805C1E3DB354B40
64379	5	52	1400	23059	13722	\N	54.544894999999997	Новосибирская область, Доволенский район, Индерский с/с, с.Индерь, Новая, 27Б		0101000020E6100000D4F2035779FE534080608E1EBF454B40
64377	5	52	1400	22989	\N	\N	54.523690999999999	Новосибирская область, Доволенский район, Ильинский с/с, с.Ильинка, Ленина, 83	Россия, Новосибирская область, Доволенский район, поселок Ильинка	0101000020E610000012876C205DCF5340D21A834E08434B40
64349	5	52	1400	22989	13701	\N	54.525363949259102	деревня Ильинка, улица Рабочая, 28	Россия, Новосибирская область, Доволенский район, поселок Ильинка	0101000020E610000000E5EFDE51CF5340753FA7203F434B40
94714	5	52	1400	23016	68422	\N	54.433548000000002	Доволенский район, п.Дружный, улица Баганская, 24		0101000020E6100000C504357C0BC65340849F38807E374B40
64372	5	52	1400	22674	\N	\N	54.485532999999997	Новосибирская область, Доволенский район, Доволенский с/с, с.Довольное, Мичурина, 1	Россия, Новосибирская область, Доволенский район, поселок Довольное	0101000020E6100000BDC799266CEA53407B1002F2253E4B40
64371	5	52	1400	22674	\N	\N	54.485532999999997	Новосибирская область, Доволенский район, Доволенский с/с, с.Довольное, Ленина, 47	Россия, Новосибирская область, Доволенский район, поселок Довольное	0101000020E6100000BDC799266CEA53407B1002F2253E4B40
64374	5	52	1400	22674	13724	\N	54.485532999999997	Новосибирская область, Доволенский район, Доволенский с/с, с.Довольное, Рабочая, 1	Россия, Новосибирская область, Доволенский район, поселок Довольное	0101000020E6100000BDC799266CEA53407B1002F2253E4B40
64373	5	52	1400	22674	13532	\N	54.494397190761298	Новосибирская область, Доволенский район, Доволенский с/с, с.Довольное, Пушкина, 1	Россия, Новосибирская область, Доволенский район, поселок Довольное	0101000020E6100000BB0CFFE906EB5340C91EA166483F4B40
64370	5	52	1400	22674	14186	\N	54.485532999999997	Новосибирская область, Доволенский район, Доволенский с/с, с.Довольное, Коммунистическая, 12	Россия, Новосибирская область, Доволенский район, поселок Довольное	0101000020E6100000BDC799266CEA53407B1002F2253E4B40
64388	5	52	1400	23499	13725	\N	54.718316999999999	Новосибирская область, Доволенский район, п.Даниловская ферма, Центральная, 16		0101000020E61000009274CDE49B0754409694BBCFF15B4B40
64368	5	52	1400	22582	13718	\N	54.431919000000001	Новосибирская область, Доволенский район, Волчанский с/с, с.Волчанка, Центральная, 4		0101000020E61000001E6E8786C5D95340B1C22D1F49374B40
64390	5	52	1400	23579	\N	\N	54.209243999999998	Новосибирская область, Доволенский район, Согорнский с/с, п.Брянский, Зеленая, 19	Россия, Новосибирская область, Доволенский район, поселок Брянский	0101000020E6100000C8B7770DFAEF53402E71E481C81A4B40
64381	5	52	1400	23157	\N	\N	54.403419	Новосибирская область, Доволенский район, Комарьевский с/с, с.Безногое, Мира, 32	Россия, Новосибирская область, Доволенский район, поселок Безногое	0101000020E6100000D3669C86A8025440E2CAD93BA3334B40
64366	5	52	1400	22495	13853	\N	54.379062401541297	Новосибирская область, Доволенский район, Баклушевский с/с, с.Баклуши, Гагарина, 9	Россия, Новосибирская область, Доволенский район, поселок Баклуши	0101000020E610000019E8DA17D0C753400394861A85304B40
64375	5	52	1400	22863	13536	\N	54.509543999999998	Новосибирская область, Доволенский район, Доволенский с/с, п.Баган, Школьная, 3	Россия, Новосибирская область, Доволенский район, поселок Баган	0101000020E61000008F8D40BCAEF15340BFEFDFBC38414B40
65545	5	52	6065	38927	\N	\N	56.860531000000002	село Красноселье, Центральная, 2	Россия, Нижегородская область, Городецкий район, село Красноселье	0101000020E610000073D6A71C93D54540DB183BE1256E4C40
65251	5	52	3417	35187	\N	\N	59.622205000000001	с.Бедрино, улица Центральная, 27	Россия, Вологодская область, Вологодский район, село Бедрино	0101000020E61000000AF5F411F89943402F34D769A4CF4D40
64361	5	52	1623	41228	13863	\N	56.075295372553803	село Шипицыно, улица Ленина, 55	Россия, Новосибирская область, Венгеровский район, поселок Шипицыно	0101000020E610000009DFFB1BB4525340B2463D44A3094C40
64354	5	52	1623	21963	\N	\N	55.660561999999999	посёлок Чистое Озеро, улица Школьная, 14	Россия, Новосибирская область, Венгеровский район, поселок Чистое Озеро	0101000020E61000005DA45016BE4A53407C7DAD4B8DD44B40
64350	5	52	1623	21771	14172	\N	55.793777282851998	деревня Чаргары, улица Школьная, 1	Россия, Новосибирская область, Венгеровский район, поселок Чаргары	0101000020E6100000B9196EC0E72C534093A8177C9AE54B40
64359	5	52	1623	49029	\N	\N	55.676153999999997	село Усть-Ламенка, улица Школьная, 3	Россия, Новосибирская область, Венгеровский район, поселок Усть-Ламенка	0101000020E610000023658BA4DD515340A087DA368CD64B40
94712	5	52	1623	22156	13848	\N	55.929949000000001	Венгеровский район, село Усть-Изес, улица Ленина, 74		0101000020E61000004432E4D87A3C534055F99E9108F74B40
64355	5	52	1623	21979	13706	\N	55.917934000000002	село Урез, улица Зелёная, 2	Россия, Новосибирская область, Венгеровский район, поселок Урез	0101000020E61000006AA33A1DC847534078F17EDC7EF54B40
64351	5	52	1623	21789	13498	\N	55.641320999999998	село Туруновка, улица Новая, 6а		0101000020E61000001EA7E8482E425340779E78CE16D24B40
64337	5	52	1623	21128	\N	\N	55.612197000000002	село Старый Тартас, улица Школьная, 1	Россия, Новосибирская область, Венгеровский район, поселок Старый Тартас	0101000020E6100000DAE38574782F5340CBDAA6785CCE4B40
94711	5	52	1623	49605	75228	\N	56.022899712492297	Венгеровский район, село Сибирцево 2-е, улица Школьная, 12	Россия, Новосибирская область, Венгеровский район, поселок Сибирцево 2-е	0101000020E61000000168942EFD445340098A1F63EE024C40
64345	5	52	1623	47485	15972	\N	55.593730607584803	село Сибирцево 1-е, улица Центральная, 1	Россия, Новосибирская область, Венгеровский район, поселок Сибирцево 1-е	0101000020E61000003E3F8C101E22534089CF9D60FFCB4B40
64328	5	52	1623	20665	13686	\N	55.771428	деревня Селикла, улица Советская, 49		0101000020E6100000070ABC934F165340FE9B1727BEE24B40
94710	5	52	1623	21474	68453	\N	55.978633927045301	Венгеровский район, село Петропавловка 2-я, улица Школьная, 44	Россия, Новосибирская область, Венгеровский район, поселок Петропавловка 2-я	0101000020E610000034F44F70B1235340786000E143FD4B40
64341	5	52	1623	21303	14038	\N	55.804473104390198	село Петропавловка 1-я, улица Юбилейная, 12	Россия, Новосибирская область, Венгеровский район, поселок Петропавловка 1-я	0101000020E61000004F07B29E5A3F5340ECC1A4F8F8E64B40
94709	5	52	1623	41340	13987	\N	56.146913112661998	Венгеровский район, село Павлово, улица Площадь, 1	Россия, Новосибирская область, Венгеровский район, поселок Павлово	0101000020E61000002EE411DC48325340BA2D910BCE124C40
64332	5	52	1623	41199	13459	\N	55.777811256047002	деревня Орлово, улица Центральная, 49	Россия, Новосибирская область, Венгеровский район, поселок Орлово	0101000020E61000007A185A9D9C3A53400ABC934F8FE34B40
64334	5	52	1623	41204	13466	\N	55.813445000000002	деревня Ночка, улица Набережная, 6		0101000020E610000002D88008713E5340200C3CF71EE84B40
64336	5	52	1623	21117	13834	\N	55.673133	село Новый Тартас, улица Юбилейная, 3		0101000020E61000008BFED0CC932D5340DF6DDE3829D64B40
94708	5	52	1623	21024	68656	\N	56.144340999999997	Венгеровский район, село Новые Кулики, улица Центральная, 22		0101000020E6100000130EBDC5C34B5340683C11C479124C40
65268	5	52	1623	41265	14155	\N	56.172417723299702	д. Минино, Зелёная, 24	Россия, Новосибирская область, Венгеровский район, поселок Минино	0101000020E6100000CFF8BEB854625340F19E03CB11164C40
94704	5	52	1623	41368	14071	\N	55.932490000000001	Венгеровский район, село Меньшиково, улица Школьная, 1а		0101000020E6100000D61C2098A32C53406CEC12D55BF74B40
64357	5	52	1623	22072	13516	\N	55.969954999999999	деревня Мариинка, улица Центральная, 26		0101000020E61000001EC6A4BF974E5340BCCB457C27FC4B40
64343	5	52	1623	41304	13843	\N	55.752813048285297	деревня Красноярка, улица Набережная, 28	Россия, Новосибирская область, Венгеровский район, поселок Красноярка	0101000020E61000006B0C3A21743D53407880272D5CE04B40
64330	5	52	1623	41377	14147	\N	55.718056947986	село Ключевая, улица Советская, 35	Россия, Новосибирская область, Венгеровский район, поселок Ключевая	0101000020E61000001D3EE94482355340FAD4B14AE9DB4B40
64339	5	52	1623	48684	16542	\N	55.611123999999997	деревня Игнатьевка, улица Центральная, 31		0101000020E6100000B96C74CE4F2253407DE6AC4F39CE4B40
64338	5	52	1623	48675	\N	\N	55.669417000000003	посёлок Зыково, улица Школьная, 1	Россия, Новосибирская область, Венгеровский район, поселок Зыково	0101000020E6100000A41B6151113C53407731CD74AFD54B40
64348	5	52	1623	41214	13492	\N	55.707164387290298	село Заречье, улица Советская, 7	Россия, Новосибирская область, Венгеровский район, поселок Заречье	0101000020E6100000ABCE6A813D2F53404B74965984DA4B40
64342	5	52	1623	47438	15957	\N	55.849251000000002	деревня Григорьевка, улица Луговая, 21	Россия, Новосибирская область, Венгеровский район, поселок Григорьевка	0101000020E61000004D86E3F90C405340338CBB41B4EC4B40
94707	5	52	1623	49660	68419	\N	56.125765999999999	Венгеровский район, село Воробьево, улица Дорожная, 1б		0101000020E61000003BE5D18DB02153407079AC1919104C40
64179	5	52	1623	41357	14016	\N	55.613118070124401	село Вознесенка, Школьная, 50	Россия, Новосибирская область, Венгеровский район, поселок Вознесенка	0101000020E610000018062CB98A185340624B8FA67ACE4B40
64325	5	52	1623	41357	16238	\N	55.613712	село Вознесенка, улица Ленина, 49		0101000020E610000077F4BF5C8B185340D594641D8ECE4B40
64323	5	52	1623	20327	\N	\N	55.683041000000003	село Венгерово, улица Ленина, 3	Россия, Новосибирская область, Венгеровский район, поселок Венгерово	0101000020E6100000F8544E7B4A305340E06932E36DD74B40
64322	5	52	1623	20327	13684	\N	55.683041000000003	село Венгерово, улица Луговая, 6		0101000020E6100000F8544E7B4A305340E06932E36DD74B40
64364	5	52	1623	20327	13846	\N	55.682165820967803	село Венгерово, улица Ленина, 131	Россия, Новосибирская область, Венгеровский район, поселок Венгерово	0101000020E61000009414580053305340B9382A3751D74B40
64363	5	52	1623	20327	13846	\N	55.683041000000003	село Венгерово, улица Ленина, 213		0101000020E6100000F8544E7B4A305340E06932E36DD74B40
64324	5	52	1623	20327	13846	\N	55.682262807957798	село Венгерово, улица Ленина, 66	Россия, Новосибирская область, Венгеровский район, поселок Венгерово	0101000020E610000070D05E7D3C305340AB22DC6454D74B40
64356	5	52	1623	41222	13509	\N	55.922666	деревня Бровничи, улица Центральная, 31	Россия, Новосибирская область, Венгеровский район, поселок Бровничи	0101000020E610000056293DD34B405340C99063EB19F64B40
64305	5	52	1554	49609	16621	\N	55.488704387653499	Новосибирская область, Болотнинский район, Светлополянский сельсовет, Садовая, 2	Россия, Новосибирская область, Болотнинский район, поселок Светлая Поляна	0101000020E6100000D061BEBC0002554052B648DA8DBE4B40
64300	5	52	1554	19127	15787	\N	55.550457999999999	деревня Правососновка, улица Сосновская,35		0101000020E6100000D7851F9C4F2E554029E9616875C64B40
64309	5	52	1554	60573	75542	\N	55.553353760336996	Новосибирская область, Болотнинский район, Ояшинский сельсовет, Школьная, 9		0101000020E61000009E7C7A6CCBF554402E8ECA4DD4C64B40
64310	5	52	1554	60573	75489	\N	55.549217965978002	Новосибирская область, Болотнинский район, Ояшинский сельсовет, Школьная, 24	Россия, Новосибирская область, Болотнинский район, поселок Ояш	0101000020E6100000B1A547533DF65440F12F82C64CC64B40
64278	5	52	1554	60623	75475	\N	55.920752308711599	Новосибирская область, Болотнинский район, Кунчурукский сельсовет, Центральная, 13	Россия, Новосибирская область, Болотнинский район, поселок Кунчурук	0101000020E6100000A2B3CC221413554001DD9733DBF54B40
94705	5	52	1554	49659	68573	\N	55.503430999999999	Болотнинский район, деревня Кривояш, переулок Центральный,4		0101000020E61000002DCDAD10560B55407365506D70C04B40
64299	5	52	1554	41338	75548	\N	55.518306937522901	Новосибирская область, Болотнинский район, Корниловский сельсовет, Новая, 5		0101000020E61000002F6AF7AB00265540D9243FE257C24B40
64939	5	52	1554	46957	68958	\N	55.605911999999996	д.Киевка, улица Центральная, 24		0101000020E6100000F56915FDA10E5540812040868ECD4B40
64281	5	52	1554	60576	75329	\N	55.720365297054599	Новосибирская область, Болотнинский район, Карасевский сельсовет, Центральная, 74а	Россия, Новосибирская область, Болотнинский район, поселок Карасево	0101000020E610000087DD770C8F0A55406E179AEB34DC4B40
64282	5	52	1554	60576	75477	\N	55.719687047439599	Новосибирская область, Болотнинский район, Карасевский сельсовет, Молодежная, 4	Россия, Новосибирская область, Болотнинский район, поселок Карасево	0101000020E6100000B0592E1B9D0A55409D2D20B41EDC4B40
64288	5	52	1554	41360	75344	\N	55.827573476933097	Новосибирская область, Болотнинский район, Зудовский сельсовет, Центральная, 71	Россия, Новосибирская область, Болотнинский район, поселок Зудово	0101000020E6100000D449B6BA9C105540BC067DE9EDE94B40
64289	5	52	1554	41360	14033	\N	55.8279632762966	Новосибирская область, Болотнинский район, Зудовский сельсовет, Бабахина, 53	Россия, Новосибирская область, Болотнинский район, поселок Зудово	0101000020E6100000A88B14CAC210554026A60BB1FAE94B40
64297	5	52	1554	47908	16600	\N	55.632555000000004	деревня Елфимово, улица Центральная,9		0101000020E61000005B99F04BFD2B5540EDF5EE8FF7D04B40
64304	5	52	1554	60684	75560	\N	55.619827999999998	Новосибирская область, Болотнинский район, Егоровский сельсовет, Школьная, 48	Россия, Новосибирская область, Болотнинский район, поселок Егоровка	0101000020E61000005019FF3EE30D554092921E8656CF4B40
64279	5	52	1554	60579	75350	\N	55.693323044082	Новосибирская область, Болотнинский район, Дивинский сельсовет, Центральная, 20а	Россия, Новосибирская область, Болотнинский район, поселок Дивинка	0101000020E6100000EC89AE0B3F1E55404548DDCEBED84B40
64280	5	52	1554	60579	75571	\N	55.699015484634501	Новосибирская область, Болотнинский район, Дивинский сельсовет, Центральная, 6	Россия, Новосибирская область, Болотнинский район, поселок Дивинка	0101000020E61000003830B951641E5540EC34D25279D94B40
64321	5	52	1554	60682	75555	\N	55.807845	Новосибирская область, Болотнинский район, Варламовский сельсовет, Почтовая, 21	Россия, Новосибирская область, Болотнинский район, поселок Варламово	0101000020E6100000637D03931B1755405A9E077767E74B40
64317	5	52	1554	19692	\N	\N	55.668640000000003	Новосибирская область, Болотнинский район, город Болотное, Эстакадный, 9	Россия, Новосибирская область, Болотнинский район, Болотное	0101000020E610000083C13577F41855401366DAFE95D54B40
64314	5	52	1554	19692	\N	\N	55.668640000000003	Новосибирская область, Болотнинский район, город Болотное, Титова, 39	Россия, Новосибирская область, Болотнинский район, Болотное	0101000020E610000083C13577F41855401366DAFE95D54B40
64319	5	52	1554	19692	13971	\N	55.6682543055568	Новосибирская область, Болотнинский район, город Болотное, Ремесленная, 2	Россия, Новосибирская область, Болотнинский район, Болотное	0101000020E6100000C11E1329CD185540E9B5D95889D54B40
64313	5	52	1554	19692	13823	\N	55.668640000000003	Новосибирская область, Болотнинский район, город Болотное, Промышленная, 1		0101000020E610000083C13577F41855401366DAFE95D54B40
64320	5	52	1554	19692	13448	\N	55.668640000000003	Новосибирская область, Болотнинский район, город Болотное, Московская, 220		0101000020E610000083C13577F41855401366DAFE95D54B40
64312	5	52	1554	19692	13448	\N	55.668615461423499	Новосибирская область, Болотнинский район, город Болотное, Московская, 47	Россия, Новосибирская область, Болотнинский район, Болотное	0101000020E6100000ACE0B721C6185540BA4E232D95D54B40
64311	5	52	1554	19692	14134	\N	55.667769193769999	Новосибирская область, Болотнинский район, город Болотное, Ленина, 4	Россия, Новосибирская область, Болотнинский район, Болотное	0101000020E6100000C286A757CA1855402D24607479D54B40
64318	5	52	1554	19692	15879	\N	55.668640000000003	Новосибирская область, Болотнинский район, город Болотное, Березовская, 72а		0101000020E610000083C13577F41855401366DAFE95D54B40
94706	5	52	1554	19692	68371	\N	55.668640000000003	Болотнинский район, город Болотное, улица 40 лет Победы,8ж		0101000020E610000083C13577F41855401366DAFE95D54B40
94692	5	52	1326	41375	68416	\N	55.01229	Барабинский район, с.Кожевниково , улица Сибирская, 30		0101000020E61000009B3DD00A0C905340AF08FEB792814B40
47377	5	49	\N	1225	73334	\N	56.012390000000003	г. Красноярск пр. Мира 82		0101000020E6100000C64D0D349F3757401366DAFE95014C40
64290	5	52	1554	49200	75558	\N	55.617809999999999	Новосибирская область, Болотнинский район, Баратаевский сельсовет, Пролетарская, 6	Россия, Новосибирская область, Болотнинский район, поселок Баратаевка	0101000020E610000001A260C6141D55402592E86514CF4B40
64295	5	52	1554	49200	75550	\N	55.617809999999999	Новосибирская область, Болотнинский район, Баратаевский сельсовет, Озерная, 44	Россия, Новосибирская область, Болотнинский район, поселок Баратаевка	0101000020E610000001A260C6141D55402592E86514CF4B40
64291	5	52	1554	49200	75561	\N	55.618247234968301	Новосибирская область, Болотнинский район, Баратаевский сельсовет, Береговая, 2	Россия, Новосибирская область, Болотнинский район, поселок Баратаевка	0101000020E6100000DB6E826F9A1C5540D0ECBAB722CF4B40
64284	5	52	1554	60683	75559	\N	55.638279168250698	Новосибирская область, Болотнинский район, Байкальский сельсовет, Центральная, 30	Россия, Новосибирская область, Болотнинский район, поселок Байкал	0101000020E61000005BEB8B84B6F854409E5C5320B3D14B40
64296	5	52	1554	60627	75479	\N	55.643454042988402	Новосибирская область, Болотнинский район, Ачинский сельсовет, Центральная, 5	Россия, Новосибирская область, Болотнинский район, поселок Ача	0101000020E61000002BC3B81B442755407D3D5FB35CD24B40
64563	5	52	5168	37628	\N	\N	54.452638	посёлок Осиновка, улица Весенняя, 5 А	Россия, Кемеровская область, Беловский район, поселок Осиновка	0101000020E61000000ABABDA431975540A376BF0AF0394B40
64201	5	52	1326	41236	13557	\N	55.341330999999997	ст.Кирзинское , улица Вокзальная, 13		0101000020E610000028B682A6257D5340340EF5BBB0AB4B40
94689	5	52	1326	15608	14094	\N	55.153348999999999	Барабинский район, д.Юный Пионер , улица Весенняя, 23		0101000020E6100000809E060C928C5340E9EFA5F0A0934B40
94684	5	52	1326	14360	68563	\N	55.323802000000001	Барабинский район, с. Шубинское, улица Новая, 1		0101000020E6100000C971A774B08D534090300C5872A94B40
94683	5	52	1326	14112	68349	\N	55.293144321820698	Барабинский район, д.Устьянцево, улица Центральная, 35	Россия, Новосибирская область, Барабинский район, поселок Устьянцево	0101000020E610000058C85C19547C534062821ABE85A54B40
94694	5	52	1326	16089	13600	\N	55.007142999999999	Барабинский район, д.Усть-Тандовка , переулок Школьный, 8		0101000020E6100000371AC05B208553409AB2D30FEA804B40
64216	5	52	1326	14882	14082	\N	55.342381000000003	ст.Труновское , улица Северная, 25/2		0101000020E6100000FF1F274C18B05340CAE2FE23D3AB4B40
94696	5	52	1326	16372	14106	\N	54.815254000000003	Барабинский район, п.Тополевка , улица Школьная, 9В		0101000020E610000048A30227DB82534073F7393E5A684B40
94686	5	52	1326	46628	68392	\N	55.094174000000002	Барабинский район, с.Таскаево, улица Центральная, 87		0101000020E6100000772CB64945A653401711C5E40D8C4B40
64238	5	52	1326	15925	\N	\N	55.160679000000002	аул Тандов, улица Центральная, 6	Россия, Новосибирская область, Барабинский район, поселок Тандов (Аул-Тандов)	0101000020E610000001344A97FE885340B613252191944B40
94688	5	52	1326	15388	68662	\N	55.069127999999999	Барабинский район, д.Старый Карапуз , улица Молодёжная, 24		0101000020E6100000C84274081CBA5340739EB12FD9884B40
64248	5	52	1326	16439	\N	\N	54.881819999999998	д.Староярково , улица Озерная, 21	Россия, Новосибирская область, Барабинский район, поселок Староярково	0101000020E6100000E3C798BB967F5340B77A4E7ADF704B40
64209	5	52	1326	14590	14340	\N	55.369340999999999	деревня Старощербаково, улица Мира, 9	Россия, Новосибирская область, Барабинский район, поселок Старощербаково (Марандино)	0101000020E610000048A5D8D1389D53403509DE9046AF4B40
64241	5	52	1326	41321	13902	\N	54.896132999999999	деревня Сизево, улица Центральная, 47	Россия, Новосибирская область, Барабинский район, поселок Сизево	0101000020E61000003CA2427573915340E5EE737CB4724B40
94685	5	52	1326	15133	68659	\N	55.286189	Барабинский район, д.Пензино , улица Школьная, 7		0101000020E6100000B282DF8618B45340CBBC55D7A1A44B40
94695	5	52	1326	16346	68565	\N	54.925747000000001	Барабинский район, с.Новоярково , улица Центральная, 25		0101000020E610000035B6D782DE85534060AFB0E07E764B40
94693	5	52	1326	16048	13900	\N	54.952181000000003	Барабинский район, с.Новочановское , улица Центральная,29		0101000020E610000047E9D2BF248B5340B16F2711E1794B40
64212	5	52	1326	14741	16601	\N	55.397086000000002	село Новоульяновское, площадь Труда, 2		0101000020E6100000A08A1BB798A1534088D9CBB6D3B24B40
64256	5	52	1326	16834	\N	\N	55.092019999999998	д.Новотандово , улица Центральная, 10	Россия, Новосибирская область, Барабинский район, поселок Новотандово	0101000020E6100000DCA16131EA7C5340F949B54FC78B4B40
94691	5	52	1326	41372	14097	\N	55.112746999999999	Барабинский район, с.Новоспасск , улица Центральная, 27		0101000020E61000006876DD5B918B53406EDC627E6E8E4B40
64910	5	52	1326	46385	68613	\N	54.796298	д.Новониколаевка, Южная, 35		0101000020E61000009D4A06802A75534063EFC517ED654B40
94697	5	52	1326	46385	68568	\N	54.796298	Барабинский район, с.Новониколаевка , улица Школьная, 51		0101000020E61000009D4A06802A75534063EFC517ED654B40
64231	5	52	1326	15657	14877	\N	55.101205	деревня Новокурупкаевка, улица Башира, 53		0101000020E6100000C9C859D8D394534089981249F48C4B40
64217	5	52	1326	14999	13879	\N	55.269588802716399	село Новокозловское, улица Зеленая, 11	Россия, Новосибирская область, Барабинский район, поселок Новокозловское	0101000020E61000002D23F59ECAA25340412E71E481A24B40
64214	5	52	1326	14805	\N	\N	55.308427999999999	д. Новогутово , улица Майская, 30	Россия, Новосибирская область, Барабинский район, поселок Новогутово	0101000020E6100000EE2422FC8B9D5340D99596917AA74B40
64206	5	52	1326	14419	\N	\N	55.225630000000002	д.Круглоозёрка, улица Центральная, 21	Россия, Новосибирская область, Барабинский район, поселок Круглоозерка	0101000020E6100000DDD26A48DC8053408D7F9F71E19C4B40
64208	5	52	1326	41241	13569	\N	55.2659280458968	п. Красный Пахарь, переулок Сельский, 5А	Россия, Новосибирская область, Барабинский район, поселок Красный Пахарь	0101000020E6100000786000E1438553409C8BBFED09A24B40
64222	5	52	1326	15236	\N	\N	55.181086999999998	д.Кармышак , улица Зеленая, 15	Россия, Новосибирская область, Барабинский район, поселок Кармышак	0101000020E6100000E816BA1281A05340895DDBDB2D974B40
64242	5	52	1326	16201	16545	\N	54.963743999999998	деревня Кармакла, улица Центральная, 29		0101000020E610000034A2B437F8995340ADDBA0F65B7B4B40
94700	5	52	1326	41287	13764	\N	55.076586458744899	Барабинский район, д.Казанцево , улица Центральная, 32	Россия, Новосибирская область, Барабинский район, поселок Казанцево	0101000020E61000009D0DF967066C53406DAAEE91CD894B40
94699	5	52	1326	16659	68369	\N	55.091479	Барабинский район, с.Зюзя , улица Молодёжная, 14		0101000020E610000013807F4A95765340A9A27895B58B4B40
64233	5	52	1326	41246	13589	\N	55.217849999999999	п.Дунаевка , улица Школьная, 5	Россия, Новосибирская область, Барабинский район, поселок Дунаевка	0101000020E6100000925852EE3E8E534080B74082E29B4B40
64210	5	52	1326	46152	15665	\N	55.407412000000001	п.Горка , улица Центральная, 1	Россия, Новосибирская область, Барабинский район, поселок Горка	0101000020E6100000A032FE7DC6965340BDFF8F1326B44B40
64243	5	52	1326	41322	13906	\N	54.986020000000003	д.Голованово , улица Школьная, 7	Россия, Новосибирская область, Барабинский район, поселок Голованово	0101000020E61000005401F73C7F915340D99942E7357E4B40
94698	5	52	1326	16605	68569	\N	54.711083000000002	Барабинский район, д.Богатиха , улица Центральная, 45		0101000020E6100000354580D3BB745340ECDE8AC4045B4B40
94701	5	52	1326	41366	14062	\N	55.044241999999997	Барабинский район, д.Белово , улица Центральная, 55		0101000020E6100000B189CC5CE0605340088ECBB8A9854B40
94687	5	52	1326	15308	68661	\N	55.152639000000001	Барабинский район, д.Бакмасиха , улица Центральная, 11		0101000020E6100000F99E91088DB553400D8CBCAC89934B40
94690	5	52	1326	15689	68564	\N	55.188000000000002	Барабинский район, д.Бадажки , улица Майская, 39		0101000020E6100000465ED6C402885340F2D24D6210984B40
64218	5	52	1326	15036	\N	\N	55.27317	п. Арисово , улица Школьная, 4	Россия, Новосибирская область, Барабинский район, поселок Арисово	0101000020E6100000C5AC174339A85340C91F0C3CF7A24B40
64227	5	52	1326	41244	13584	\N	55.191859999999998	д. Абакумово , улица Зеленая, 8	Россия, Новосибирская область, Барабинский район, поселок Абакумово	0101000020E6100000CA8CB7955EA953408DB454DE8E984B40
62403	5	52	232	46710	15778	\N	54.105089860605702	село Тычкино, Центральная, 7	Россия, Новосибирская область, Баганский район, поселок Тычкино	0101000020E6100000C09481035A7253407D91D096730D4B40
64153	5	52	232	11971	14161	\N	53.826172999999997	поселок Теренгуль, Школьная, 49	Россия, Новосибирская область, Баганский район, поселок Теренгуль	0101000020E610000096EA025E664A53404AEB6F09C0E94A40
60388	5	52	232	41274	13710	\N	54.051049268357801	село Стретинка, Жемчужная, 44	Россия, Новосибирская область, Баганский район, поселок Стретинка	0101000020E61000005036E50AEF6F53402BBF0CC688064B40
64166	5	52	232	41270	13704	\N	53.937679000000003	с. Соловьевка, улица Приозерная, 25	Россия, Новосибирская область, Баганский район, поселок Соловьевка	0101000020E6100000F7E80DF791575340B0928FDD05F84A40
64176	5	52	232	41351	14008	\N	54.135951803301197	с. Славянка, улица Светлая, 25	Россия, Новосибирская область, Баганский район, поселок Славянка	0101000020E610000022E2E65432565340B4E908E066114B40
64191	5	52	232	45750	16563	\N	53.902850999999998	село Савкино, Садовая, 32		0101000020E6100000AA9ECC3FFA79534098141F9F90F34A40
64150	5	52	232	41303	13841	\N	53.859596169229803	д. Романовка, улица Зеленая, 28	Россия, Новосибирская область, Баганский район, поселок Романовка	0101000020E610000061FC34EECD515340DFE2E13D07EE4A40
64147	5	52	232	41213	13720	\N	53.782298678898101	о.п. Районная, переулок Половинный, 7	Россия, Новосибирская область, Баганский район, поселок Районная	0101000020E61000002079E750865B5340C558A65F22E44A40
64160	5	52	232	41343	13994	\N	53.957698999999998	д. Подольск, улица Степная, 9	Россия, Новосибирская область, Баганский район, поселок Подольск	0101000020E61000006C09F9A0674E5340B9347EE195FA4A40
64182	5	52	232	45571	\N	\N	53.838948000000002	деревня Петрушино, Центральная, 15	Россия, Новосибирская область, Баганский район, поселок Петрушино	0101000020E61000006ADAC534D3645340B685E7A562EB4A40
64451	5	52	232	45499	15753	\N	54.149251893940601	п.Первомайский, Целинная, 1	Россия, Новосибирская область, Баганский район, поселок Первомайский	0101000020E61000002079E750865B5340696E85B01A134B40
64177	5	52	232	45499	75594	\N	54.151655944263503	п. Первомайский, улица Переселенческая, 20А	Россия, Новосибирская область, Баганский район, поселок Первомайский	0101000020E6100000B4722F302B5B5340001FBC7669134B40
64183	5	52	232	13381	\N	\N	54.118684999999999	село Палецкое, Октябрьская, 18	Россия, Новосибирская область, Баганский район, поселок Палецкое	0101000020E61000000A2DEBFEB18953404CC3F011310F4B40
64185	5	52	232	45612	\N	\N	54.203539999999997	с. Осинники, улица Октябрьская, 40	Россия, Новосибирская область, Баганский район, поселок Осинники	0101000020E610000010768A5583815340C3B645990D1A4B40
64174	5	52	232	12916	13938	\N	54.086232000000003	д. Нижний Баган, улица Молодежная, 20А		0101000020E610000002D880087159534031EF71A6090B4B40
64180	5	52	232	41227	13519	\N	53.843987224489602	село Мироновка, Центральная, 38	Россия, Новосибирская область, Баганский район, поселок Мироновка	0101000020E61000005D328E91EC6F5340E49F19C407EC4A40
64169	5	52	232	12765	13999	\N	54.101086000000002	село Лозовское, Центральная, 30		0101000020E6100000CB49287D21685340AF0AD462F00C4B40
65054	5	52	232	41349	\N	\N	53.910829	д. Кузнецовка, улица Садовая, д. 38	Россия, Новосибирская область, Баганский район, поселок Кузнецовка	0101000020E610000095F0845E7F635340CB9F6F0B96F44A40
64168	5	52	232	41349	14006	\N	53.910829	село Кузнецовка, Центральная, 27	Россия, Новосибирская область, Баганский район, поселок Кузнецовка	0101000020E610000095F0845E7F635340CB9F6F0B96F44A40
64187	5	52	232	41391	14190	\N	54.109121999999999	с. Красный Остров, улица Зеленая, 32	Россия, Новосибирская область, Баганский район, поселок Красный Остров	0101000020E61000008CA37213B593534016A3AEB5F70D4B40
64171	5	52	232	12775	\N	\N	54.073940999999998	д. Караси, улица Озерная, 10Б	Россия, Новосибирская область, Баганский район, поселок Караси	0101000020E6100000AF95D05D126A5340B16A10E676094B40
64198	5	52	232	41231	13538	\N	53.981435586813397	с. Казанка, улица Центральная, 30	Россия, Новосибирская область, Баганский район, поселок Казанка	0101000020E6100000E3FBE252955B5340FC8EE1B19FFD4A40
64163	5	52	232	41231	13538	\N	53.982703000000001	село Казанка, Центральная, 30	Россия, Новосибирская область, Баганский район, поселок Казанка	0101000020E6100000E2395B40685B53402E573F36C9FD4A40
64728	5	52	232	41231	68595	\N	53.982548554867499	с.Казанка, Весенняя, 1	Россия, Новосибирская область, Баганский район, поселок Казанка	0101000020E610000095D39E92735B5340D7DB662AC4FD4A40
64192	5	52	232	41232	\N	\N	53.960405999999999	с. Кавказское, улица Школьная, 11	Россия, Новосибирская область, Баганский район, поселок Кавказское	0101000020E61000006C3EAE0D157F5340EB707495EEFA4A40
64161	5	52	232	12413	\N	\N	53.918348999999999	д. Грушевка, улица Мира, 19	Россия, Новосибирская область, Баганский район, поселок Грушевка	0101000020E610000054A703594F4B53403BA8C4758CF54A40
60641	5	52	232	906	13891	\N	54.163204156535002	село Гнедухино, Молодежная, 29	Россия, Новосибирская область, Баганский район, поселок Гнедухино	0101000020E6100000C0CFB870206D5340C74961DEE3144B40
64172	5	52	232	12864	\N	\N	54.021991999999997	поселок Водино, Школьная, 1	Россия, Новосибирская область, Баганский район, поселок Водино	0101000020E6100000FD15325706615340066344A2D0024B40
64196	5	52	232	13979	\N	\N	53.949190000000002	п. Бронзовка, улица Школьная, 19	Россия, Новосибирская область, Баганский район, поселок Бронзовка	0101000020E61000009A779CA2238753405AD8D30E7FF94A40
60603	5	52	232	31382	\N	\N	54.183912999999997	село Бочаниха, Мира, 44	Россия, Новосибирская область, Баганский район, поселок Бочаниха	0101000020E61000007A54FCDF116B5340952710768A174B40
64189	5	52	232	41309	13861	\N	54.034388999999997	село Большие Луки, Широкая, 50	Россия, Новосибирская область, Баганский район, поселок Большие Луки	0101000020E6100000ED647094BC8C5340CB2BD7DB66044B40
64157	5	52	232	12043	13478	\N	54.096752000000002	село Баган, Сибиряков-Гвардейцев, 75		0101000020E6100000C460FE0A996A53404BE9995E620C4B40
64156	5	52	232	12043	13844	\N	54.096752000000002	село Баган, Максима Горького, 30		0101000020E6100000C460FE0A996A53404BE9995E620C4B40
64154	5	52	232	12043	13844	\N	54.096752000000002	село Баган, Максима Горького, 18		0101000020E6100000C460FE0A996A53404BE9995E620C4B40
60292	5	52	232	12043	16594	\N	54.096752000000002	село Баган, Куйбышева, 31		0101000020E6100000C460FE0A996A53404BE9995E620C4B40
64155	5	52	232	12043	14051	\N	54.103584539826201	село Баган, Инкубаторная, 3	Россия, Новосибирская область, Баганский район, поселок Баган	0101000020E61000003C873254C569534097ADF545420D4B40
64164	5	52	232	41219	13505	\N	54.019663999999999	п. Александро-Невский, улица Степная, 39Б	Россия, Новосибирская область, Баганский район, поселок Александро-Невский	0101000020E6100000B82231410D5953404B74965984024B40
64151	5	52	232	11875	\N	\N	53.753736000000004	п. III-Интернационал, улица Центральная, 21	Россия, Новосибирская область, Баганский район, поселок III Интернационал	0101000020E6100000C90050C58D535340B0E8D66B7AE04A40
48783	5	49	\N	59636	75623	\N	65.797387999999998	с.Туруханск, Советская, 17	Россия	0101000020E61000003541D47D00FE5540438EAD6708735040
42059	5	49	\N	59833	73100	\N	60.891215301335002	с.Зотино, Рабочая, 30	Россия	0101000020E610000064C91CCBBB6B5640325A475513724E40
47715	5	49	\N	51807	28107	\N	55.007731	с. Вознесенка, Солнечная, 4А		0101000020E61000007C2C7DE8828457402B155454FD804B40
49048	5	49	\N	59701	72767	\N	60.3448830197053	с. Ванавара, Нефтеразведочная, 14	Россия	0101000020E61000002AC423F1F291594023F94A20252C4E40
47805	5	49	\N	59593	72312	\N	58.380874506970201	с. Богучаны, Ленина, 119	Россия	0101000020E61000005B0A48FB1F5D5840986E1283C0304D40
49039	5	49	\N	59905	73305	\N	61.613607999999999	п.Суломай, Школьная, 1	Россия	0101000020E6100000A795422097CA56403048FAB48ACE4E40
49015	5	49	\N	60815	\N	\N	71.564251999999996	п. Хета, Сельский дом культуры	Россия	0101000020E6100000533C2EAA45EA5840F7AC6BB41CE45140
47824	5	49	\N	59631	72601	\N	58.422846999999997	"п. Невонка, Юбилейная, 1 ""А"""		0101000020E6100000151E34BBEE945840191BBAD91F364D40
47811	5	49	\N	59498	71703	\N	58.412798094722199	"п. Гремучий, Береговая, 20 ""А"""	Россия	0101000020E6100000EE974F560C5D584057ED9A90D6344D40
49032	5	49	\N	59893	73253	\N	63.384107949087301	поселок Юкта, Центральная, 3	Россия	0101000020E6100000EA93DC61136B5A40E41071732AB14F40
47562	5	49	\N	15627	28259	\N	56.324910000000003	д.Шивера, Центральная, 4		0101000020E6100000E9F010C64F5F57405A12A0A696294C40
48234	5	49	\N	48592	27910	\N	56.295397923520603	п.Шахтинский, Лесная, 2	Россия, Красноярский край, поселок Шахтинский	0101000020E6100000BF99982EC4EB5740E3A6069ACF254C40
47521	5	49	\N	51737	\N	\N	55.536677242646498	Красноярский край, город Шарыпово, 2 микрорайон, 8		0101000020E610000098A1F144104C5640F8C1F9D4B1C44B40
47524	5	49	\N	51737	28498	\N	55.5376507218621	Красноярский край, город Шарыпово, 6 микрорайон, 23	Россия, Красноярский край, Шарыповский район, город Шарыпово	0101000020E6100000E8DEC325C74B5640B2D47ABFD1C44B40
47523	5	49	\N	51737	28498	\N	55.537652999999999	Красноярский край, город Шарыпово, 6 микрорайон, 58		0101000020E6100000009013268C4B564053CC41D0D1C44B40
47519	5	49	\N	51737	27892	\N	55.537652999999999	Красноярский край, город Шарыпово, 4 микрорайон, 26		0101000020E6100000009013268C4B564053CC41D0D1C44B40
47688	5	49	\N	59633	72605	\N	55.249273060533199	п.Чистое Поле, Пришкольная, 19	Россия, Красноярский край, Балахтинский район, поселок Чистое Поле	0101000020E6100000522B4CDF6BCC56404E637B2DE89F4B40
48231	5	49	\N	6946	71564	\N	56.130392000000001	с.Чечеул, Кооперативная, 8		0101000020E610000003EB387EA8ED57407CD45FAFB0104C40
49050	5	49	\N	59871	73150	\N	59.611100132957802	п.Чемдальск, Центральная, 2	Россия	0101000020E61000006150A6D1E4D45940F54A598638CE4D40
49019	5	49	\N	59495	71691	\N	71.978574179605303	с. Хатанга, Советская, 24-А	Россия	0101000020E6100000975643E21E9F5940D1ADD7F4A0FE5140
48788	5	49	\N	59781	73036	\N	65.722865136919694	п.Фарково, Киевская, 13	Россия	0101000020E6100000AE8218E8DABE5540139B8F6B436E5040
47373	5	49	\N	1225	73328	\N	56.010725000000001	г. Красноярск Сурикова 12		0101000020E6100000DCA0F65B3B385740F31FD26F5F014C40
48864	5	49	\N	59668	72695	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Л.Чайкиной, 15		0101000020E61000001651137D3E945740BF47FDF50AE74B40
47147	5	49	\N	59662	\N	\N	55.941349000000002	Красноярский край, город Дивногорск, пос. Усть-Мана, Дом культуры	Россия, Красноярский край, Балахтинский район, М-54 шоссе	0101000020E6100000505436ACA91E5740A88FC01F7EF84B40
48818	5	49	\N	51753	28202	\N	55.316282999999999	Красноярский край, Ужурский район, город Ужур, Тракторная, 4А		0101000020E6100000317C444C89755640F0A31AF67BA84B40
48817	5	49	\N	51753	72657	\N	55.313348044684503	Красноярский край, Ужурский район, город Ужур, Строителей, 9	Россия, Красноярский край, Ужурский район, город Ужур	0101000020E6100000A65EB7088C7556402D228AC91BA84B40
48813	5	49	\N	51753	27851	\N	55.316282999999999	Красноярский край, Ужурский район, город Ужур, Ленина, 22		0101000020E6100000317C444C89755640F0A31AF67BA84B40
48815	5	49	\N	51753	72676	\N	55.316282999999999	Красноярский край, Ужурский район, город Ужур, Гоголя, 13	Россия, Красноярский край, Ужурский район, город Ужур	0101000020E6100000317C444C89755640F0A31AF67BA84B40
49025	5	49	\N	59465	72742	\N	64.277341498551294	поселок городского типа Тура, Таёжная, 1	Россия	0101000020E61000003B730F09DF0E5940C23577F4BF115040
49023	5	49	\N	59465	71655	\N	64.280214547396795	поселок городского типа Тура, Советская, 10		0101000020E610000001310917F20E59405036E50AEF115040
49026	5	49	\N	51876	28483	\N	64.281223685641194	поселок городского типа Тура, Увачана, 7	Россия	0101000020E6100000F816D68D770E59406BB6F292FF115040
49024	5	49	\N	51876	28483	\N	55.007731	поселок городского типа Тура, Увачана, 13 А		0101000020E61000007C2C7DE8828457402B155454FD804B40
48446	5	49	\N	17183	28194	\N	53.6611521236686	Красноярский край, Минусинский район, поселок Топольки, Набережная, 47	Россия, Красноярский край, поселок Топольки	0101000020E6100000F0366F9C14E95640AED7F4A0A0D44A40
47717	5	49	\N	13809	72922	\N	56.116598000000003	д. Терентьево, Гагарина, 14А		0101000020E6100000BB438A0112535740B763EAAEEC0E4C40
41869	5	49	\N	59645	72636	\N	57.202621999999998	с.Тасеево, Кирова, 51		0101000020E6100000C1559E40D8B857409DB98784EF994C40
47499	5	49	\N	59607	72489	\N	69.494534000000002	Красноярский край, город Норильск, район Талнах, Энтузиастов, 5	Россия	0101000020E6100000F5A0A014AD195640A530EF71A65F5140
47964	5	49	\N	25896	72906	\N	56.142765861110597	Красноярский край, Емельяновский район, Сухая Балка, Почтовая, 7	Россия, Красноярский край, поселок Сухая Балка	0101000020E6100000361D01DC2C3A5740897D022846124C40
49043	5	49	\N	59895	73261	\N	62.560772999999998	п.Суринда, Школьная, 3	Россия	0101000020E6100000B1DEA815A65958406ABDDF68C7474F40
47387	5	49	\N	51907	28645	\N	58.076490613344099	Красноярский край, город Лесосибирск, поселок Стрелка, Береговая, 6А		0101000020E6100000A9DDAF027C4157401BB80375CA094D40
47962	5	49	\N	9531	27779	\N	56.164416000000003	Красноярский край, Емельяновский район, Старцево, Новая, 2 А		0101000020E6100000FBAE08FEB73E574036785F950B154C40
47515	5	49	\N	3083	72543	\N	56.126613999999996	Красноярский край, город Сосновоборск, Юности, 7		0101000020E6100000B4AF3C484F5557409D9B36E334104C40
47516	5	49	\N	3083	72478	\N	56.125450000000001	Красноярский край, город Сосновоборск, Энтузиастов, 26		0101000020E610000086C613419C55574040A4DFBE0E104C40
47517	5	49	\N	3083	72178	\N	56.126649	Красноярский край, город Сосновоборск, Труда, 21		0101000020E6100000A10F96B1A15557401A89D00836104C40
47509	5	49	\N	3083	72178	\N	56.123241999999998	Красноярский край, город Сосновоборск, Труда, 5		0101000020E6100000E7FD7F9C305657402FBFD364C60F4C40
47510	5	49	\N	3083	72292	\N	56.121972999999997	Красноярский край, город Сосновоборск, Ленинского Комсомола, 7		0101000020E6100000016C4084B85557405CFFAECF9C0F4C40
47512	5	49	\N	3083	72541	\N	56.115724999999998	Красноярский край, город Сосновоборск, Весенняя, 3		0101000020E6100000AB5FE97C78555740302AA913D00E4C40
47514	5	49	\N	3083	72293	\N	56.122714999999999	Красноярский край, город Сосновоборск, 9 Пятилетки, 15		0101000020E610000097E4805D4D55574044DD0720B50F4C40
47513	5	49	\N	3083	72293	\N	56.120603000000003	Красноярский край, город Сосновоборск, 9 Пятилетки, 24		0101000020E61000006C0A64761655574056664AEB6F0F4C40
47511	5	49	\N	3083	72293	\N	56.119283000000003	Красноярский край, город Сосновоборск, 9 Пятилетки, 7		0101000020E6100000075DC2A1B755574001FC53AA440F4C40
48906	5	49	\N	51796	28017	\N	55.882486396841202	д.Сорокино, Советская, 22А	Россия, Красноярский край, поселок Сорокино	0101000020E6100000CB129D6516595740C4961E4DF5F04B40
48399	5	49	\N	51796	28017	\N	55.883053257638302	Красноярский край, Манский район, п.Сорокино, ул.Советская, д.6	Россия, Красноярский край, поселок Сорокино	0101000020E610000086C8E9EBF95857403DD175E107F14B40
47489	5	49	\N	51908	28651	\N	55.007731	Красноярский край, город Норильск, поселок Снежногорск, Хантайская Набережная, 10		0101000020E61000007C2C7DE8828457402B155454FD804B40
47942	5	49	\N	24874	27813	\N	56.089979999999997	Красноярский край, Емельяновский район, Снежница, Вокзальная, 3	Россия, Красноярский край, поселок Снежница	0101000020E61000005419C6DD201A5740A4A5F276840B4C40
48782	5	49	\N	60820	76415	\N	65.794235	с.Туруханск, Спандаряна, 37  (РДК)		0101000020E61000005648F949B5FE5540AB9509BFD4725040
94352	5	49	\N	51798	\N	\N	58.3760918978899	Богучаны, промплощадка Богучаского алюминиевого завода	Россия	0101000020E6100000757808E3A75D5840C4245CC823304D40
47806	5	49	\N	51798	72598	\N	58.381328000000003	с. Богучаны, Перенсона, 9	Россия	0101000020E61000008CF50D4C6E5D584049861C5BCF304D40
47809	5	49	\N	51798	28030	\N	58.379428248690097	с. Богучаны, Олимпийская, 1		0101000020E6100000FED30D14785D5840E597C11891304D40
47804	5	49	\N	51798	72195	\N	58.382372565275901	с. Богучаны, Октябрьская, 115	Россия	0101000020E61000004D49D6E1E85C5840CCEF3499F1304D40
47807	5	49	\N	51798	72593	\N	58.3805997885148	с. Богучаны, Космонавтов, 12	Россия	0101000020E61000000F0EF626865D5840C66D3480B7304D40
47808	5	49	\N	51798	72573	\N	58.379729040092997	с. Богучаны, Заречная, 32		0101000020E6100000310C5872155D5840E02BBAF59A304D40
48443	5	49	\N	17053	28405	\N	53.692717000000002	Красноярский край, Минусинский район, село Селиваниха, Набережная, 16		0101000020E610000065506D7022E756400E315EF3AAD84A40
48785	5	49	\N	17053	28534	\N	53.692717000000002	д.Селиваниха, Дудинская, 6	Россия, Красноярский край, село Селиваниха	0101000020E610000065506D7022E756400E315EF3AAD84A40
48702	5	49	\N	59605	72477	\N	60.3743040345095	Красноярский край, Северо-Енисейский район, Карла Маркса, 26	Россия	0101000020E61000005725917D9042574089618731E92F4E40
47731	5	49	\N	47800	27883	\N	55.882888999999999	д. Свищево, Октябрьская, 13		0101000020E610000034F44F70B14D5740C37FBA8102F14B40
47173	5	49	\N	59688	72735	\N	56.003793999999999	п.Светлогорск, Энергетиков, 19 (здание КДЦ Заполярье)		0101000020E6100000E1F08288D4415740E4F560527C004C40
47644	5	49	\N	10388	28493	\N	56.389513000000001	Красноярский край, Ачинский район, Причулымский сельсовет, п. Причулымский, Просвещения, 17		0101000020E6100000A1496249B99B5640F52EDE8FDB314C40
47642	5	49	\N	10388	73034	\N	56.389513000000001	Красноярский край, Ачинский район, Причулымский сельсовет, Комунаров, 1а	Россия, Красноярский край, поселок Причулымский	0101000020E6100000A1496249B99B5640F52EDE8FDB314C40
47961	5	49	\N	25797	6691	\N	56.228551000000003	Красноярский край, Емельяновский район, Придорожный, Трактовая, 3	Россия, Красноярский край, поселок Придорожный, улица Трактовая	0101000020E6100000BE86E0B88C3E5740EB3BBF28411D4C40
47648	5	49	\N	16851	28064	\N	56.354467	Красноярский край, Ачинский район, Преображенский сельсовет, с. Преображенка Школьная 3	Россия, Красноярский край, село Преображенка	0101000020E6100000D255BABBCEA456407041B62C5F2D4C40
48271	5	49	\N	59915	73359	\N	58.667005877101197	663491, Кежемский район, д.Сыромолотово, ул. Солнечная, 32	Россия	0101000020E6100000C2FA3F87F9BC58402E1EDE7360554D40
49020	5	49	\N	51884	\N	\N	55.007731	п. Попигай, Сельский дом культуры		0101000020E61000007C2C7DE8828457402B155454FD804B40
47983	5	49	\N	59620	72537	\N	58.6004122619334	Красноярский край, Енисейский район, поселок Подтесово, Калинина, 43	Россия	0101000020E6100000B933130CE70557401F10E84CDA4C4D40
47559	5	49	\N	6241	72298	\N	56.122895999999997	пос.Подгорный, Мира, 9		0101000020E6100000D4450A65E15B574094675E0EBB0F4C40
47558	5	49	\N	6241	72544	\N	56.124647000000003	пос.Подгорный, Лесная, 7		0101000020E61000009510ACAA975B5740B345D26EF40F4C40
47972	5	49	\N	26231	27784	\N	56.337766000000002	Красноярский край, Емельяновский район, Погорелка, Центральная, 13		0101000020E6100000BDAC8905BE3E5740B2D991EA3B2B4C40
48007	5	49	\N	59784	73041	\N	58.698564689008798	Красноярский край, Енисейский район, с.Погодаево, Калинина, 22	Россия	0101000020E6100000FF0758AB76035740AC90F2936A594D40
47802	5	49	\N	59602	72469	\N	58.368111920151001	"п. Пинчуга, Ленина, 13 ""А"""		0101000020E6100000A33CF372D83B5840F1A1444B1E2F4D40
47935	5	49	\N	24564	28254	\N	56.216054	Красноярский край, Емельяновский район, Памяти 13 Борцов, Советская, 49		0101000020E61000002827DA5548145740C21550A8A71B4C40
47937	5	49	\N	24564	28631	\N	56.216054	Красноярский край, Емельяновский район, Памяти 13 Борцов, Лесная, 15	Россия, Красноярский край, поселок Памяти 13 Борцов	0101000020E61000002827DA5548145740C21550A8A71B4C40
47740	5	49	\N	45449	27891	\N	56.239103928744903	с.Орловка, Октябрьская, 27	Россия, Красноярский край, деревня Орловка	0101000020E610000083C0CAA145A85640E02BBAF59A1E4C40
47845	5	49	\N	45449	27738	\N	56.238911999999999	деревня Орловка, Лесная, 25		0101000020E61000000B45BA9F53A856409C4F1DAB941E4C40
47148	5	49	\N	18240	\N	\N	55.9598575144379	Красноярский край, город Дивногорск, Село Овсянка, Клуб-филиал	Россия, Красноярский край, деревня Овсянка, улица Центральная	0101000020E610000075E95F92CA235740E8667FA0DCFA4B40
47149	5	49	\N	18240	72988	\N	55.961301527741803	Красноярский край, город Дивногорск, Село Овсянка, Набережная, Библиотека-музей В.П. Астафьева	Россия, Красноярский край, деревня Овсянка, улица Набережная	0101000020E61000007120240B982457402ACAA5F10BFB4B40
47481	5	49	\N	51757	71611	\N	69.328583127791404	Красноярский край, город Норильск, площадь Металлургов, 23		0101000020E61000009DA04D0E9F0F564061C1FD8007555140
47502	5	49	\N	51757	72615	\N	69.351004000000003	Красноярский край, город Норильск, район Кайеркан, Шахтерская, 14	Россия	0101000020E6100000F38FBE49D3F05540F9307BD976565140
47485	5	49	\N	51757	71685	\N	69.3255437241191	Красноярский край, город Норильск, Хантайская, 17	Россия	0101000020E61000008DD0CFD4EB0D56402D5A80B6D5545140
47484	5	49	\N	51757	71670	\N	69.507950396598702	Красноярский край, город Норильск, Талнахская, 64	Россия	0101000020E610000020425C397B1256403480B74082605140
47483	5	49	\N	51757	71670	\N	69.317778193637594	Красноярский край, город Норильск, Талнахская, 71а	Россия	0101000020E6100000C765DCD440045640DA58897956545140
47472	5	49	\N	51757	71670	\N	69.3265142190441	Красноярский край, город Норильск, Талнахская, 53а	Россия	0101000020E6100000B7ED7BD45F035640EAEBF99AE5545140
47471	5	49	\N	51757	71670	\N	69.495429176940107	Красноярский край, город Норильск, Талнахская, 54	Россия	0101000020E610000073D53C47E41356405C1FD61BB55F5140
47470	5	49	\N	51757	71670	\N	69.331737000000004	Красноярский край, город Норильск, Талнахская, 42	Россия	0101000020E61000008B6D52D1580E5640E277D32D3B555140
47491	5	49	\N	51757	71697	\N	55.946618000000001	Красноярский край, город Норильск, район Талнах, Строителей, 17		0101000020E6100000B51666A19D49574008E753C72AF94B40
47473	5	49	\N	51757	71671	\N	69.319360770305593	Красноярский край, город Норильск, Советская, 5	Россия	0101000020E61000005072874D640D56408BA71E6970545140
47493	5	49	\N	51757	28048	\N	69.374015050024894	Красноярский край, город Норильск, район Талнах, Рудная, 15		0101000020E610000086915ED4EE0A5640A94D9CDCEF575140
47462	5	49	\N	51757	56766	\N	69.3431187694069	Красноярский край, город Норильск, Пушкина, 8	Россия	0101000020E610000070B4E386DF0D5640B8E864A9F5555140
47504	5	49	\N	51757	72554	\N	69.352982225078506	Красноярский край, город Норильск, район Кайеркан, Победы, 11	Россия	0101000020E6100000265646239FF05540E884D04197565140
47480	5	49	\N	51757	27932	\N	55.007731	Красноярский край, город Норильск, площадь Металлургов, 15		0101000020E61000007C2C7DE8828457402B155454FD804B40
47505	5	49	\N	51757	71701	\N	69.343376351463405	Красноярский край, город Норильск, район Кайеркан, Первомайская, 34	Россия	0101000020E6100000A5D93C0E830D5640CE8E54DFF9555140
47468	5	49	\N	51757	72460	\N	69.347391321750194	Красноярский край, город Норильск, Павлова, 21а	Россия	0101000020E610000043739D465A0D56402FFB75A73B565140
47488	5	49	\N	51757	71696	\N	69.330523800693101	Красноярский край, город Норильск, Озерная, 25	Россия	0101000020E610000005A4FD0FB00D5640C2A2224E27555140
47507	5	49	\N	51757	72471	\N	69.353624999999994	Красноярский край, город Норильск, район Кайеркан, Норильская, 6	Россия	0101000020E6100000F47002D369F055401283C0CAA1565140
47508	5	49	\N	51757	28122	\N	69.320690594902302	Красноярский край, город Норильск, район Кайеркан, Надеждинская, 3а	Россия	0101000020E6100000A6811FD5B00C5640C7478B3386545140
47501	5	49	\N	51757	28122	\N	69.350512494585203	Красноярский край, город Норильск, район Кайеркан, Надеждинская, 16		0101000020E6100000459DB98784F05540C136E2C96E565140
47479	5	49	\N	51757	28212	\N	69.319234443374199	Красноярский край, город Норильск, Молодежный проезд, 7		0101000020E6100000C9569753020E56405C7171546E545140
47478	5	49	\N	51757	28212	\N	69.307096027544006	Красноярский край, город Норильск, Молодежный проезд, 19	Россия	0101000020E610000025CD1FD3DA0F5640E02EFB75A7535140
47477	5	49	\N	51757	28212	\N	69.3521747897084	Красноярский край, город Норильск, Молодежный проезд, 17		0101000020E6100000CB0F5CE5090B564001DE02098A565140
47469	5	49	\N	51757	72462	\N	69.329410999999993	Красноярский край, город Норильск, Мира, 3	Россия	0101000020E6100000F3E84658540E564054FCDF1115555140
47492	5	49	\N	51757	28411	\N	69.484115354062894	Красноярский край, город Норильск, район Талнах, Маслова, 1		0101000020E61000001557957D5718564032207BBDFB5E5140
47476	5	49	\N	51757	27872	\N	69.326642280361995	Красноярский край, город Норильск, Ленинский проспект, 45в	Россия	0101000020E610000005A4FD0FB00D564001E0D8B3E7545140
47474	5	49	\N	51757	27872	\N	69.353730117052606	Красноярский край, город Норильск, Ленинский проспект, 37в	Россия	0101000020E6100000BD378600E00B56404D672783A3565140
47460	5	49	\N	51757	27872	\N	69.345891402787998	Красноярский край, город Норильск, Ленинский проспект, 9		0101000020E6100000E10CFE7E310D5640C43E011423565140
47490	5	49	\N	51757	28217	\N	69.498328063698096	Красноярский край, город Норильск, район Талнах, Кравца, 8а		0101000020E6100000EB3713D38519564097AB1F9BE45F5140
47461	5	49	\N	51757	72451	\N	69.344268	Красноярский край, город Норильск, Комсомольская, 16	Россия	0101000020E6100000CE548847E20C5640CC43A67C08565140
47459	5	49	\N	51757	72451	\N	69.345648172450396	Красноярский край, город Норильск, Комсомольская, 27а	Россия	0101000020E61000008E5A61FA5E0C564061FBC9181F565140
47458	5	49	\N	51757	72451	\N	69.343431454210702	Красноярский край, город Норильск, Комсомольская, 5	Россия	0101000020E610000075B169A5100D5640AF5B04C6FA555140
47465	5	49	\N	51757	72516	\N	69.334442999999993	Красноярский край, город Норильск, Кирова, 30	Россия	0101000020E6100000F38E5374240E564012D89C8367555140
47498	5	49	\N	51757	71707	\N	69.339982082242699	Красноярский край, город Норильск, район Талнах, Игарская, 40	Россия	0101000020E6100000C91D3691990D5640A3CEDC43C2555140
47497	5	49	\N	51757	72548	\N	69.490330814078007	Красноярский край, город Норильск, район Талнах, Игарская, 16	Россия	0101000020E610000047ACC5A700185640C24D4695615F5140
47500	5	49	\N	51757	72532	\N	69.496827249825799	Красноярский край, город Норильск, район Талнах, Енисейская, 26	Россия	0101000020E610000025E99AC93719564044317903CC5F5140
47464	5	49	\N	51757	28178	\N	69.342763523664701	Красноярский край, город Норильск, Ветеранов, 17		0101000020E61000001B649291B30D5640C18F6AD8EF555140
47487	5	49	\N	51757	71563	\N	69.331979190843697	Красноярский край, город Норильск, Вальковская, 6	Россия	0101000020E61000008B6D52D1580E56405DFDD8243F555140
47466	5	49	\N	51757	72468	\N	69.337186783646303	Красноярский край, город Норильск, Б.Хмельницкого, 12	Россия	0101000020E61000008ECA4DD4D2085640BA68C87894555140
47482	5	49	\N	51757	72463	\N	69.331403288305296	Красноярский край, город Норильск, Бегичева, 11	Россия	0101000020E6100000679B1BD3130F5640F6B2EDB435555140
47495	5	49	\N	51757	28274	\N	69.492543298473507	Красноярский край, город Норильск, район Талнах, Бауманская, 22а		0101000020E6100000AA46AF0628185640EB3713D3855F5140
47494	5	49	\N	51757	28274	\N	69.506750411562706	Красноярский край, город Норильск, район Талнах, Бауманская, 12	Россия	0101000020E610000077103B53E8185640DF4F8D976E605140
47503	5	49	\N	59609	72611	\N	69.317778000000004	Красноярский край, город Норильск, район Кайеркан, Школьная, 10	Россия	0101000020E6100000363FFED2A20B5640DA58897956545140
47463	5	49	\N	59609	72521	\N	69.341565000000003	Красноярский край, город Норильск, Севастопольская, 8а	Россия	0101000020E61000009F3BC1FEEB0D5640541D7233DC555140
47506	5	49	\N	\N	75621	\N	69.352958999999998	Красноярский край, город Норильск, район Кайеркан, Первомайская, 20а	Россия	0101000020E6100000CAA99D616AF055400C7558E196565140
47561	5	49	\N	6422	72696	\N	56.170400000000001	пос.Новый Путь, Гагарина, 2А		0101000020E6100000D2A755F4875D5740849ECDAACF154C40
48233	5	49	\N	6422	27917	\N	56.166851999999999	п.Новый Путь, Зеленая, 28		0101000020E6100000384D9F1D705D5740D7A205685B154C40
49021	5	49	\N	51860	\N	\N	72.819504445090104	п. Новорыбная, Сельский дом культуры		0101000020E610000013622EA9DA785A403CBCE7C072345240
48896	5	49	\N	7257	28219	\N	55.758553999999997	д.Новокурск, Центральная, 53		0101000020E61000004D0F0A4AD1545640FF1F274C18E14B40
47447	5	49	\N	51788	71500	\N	56.011302999999998	Красноярский край, город Назарово, ул.Кузнечная, д.8		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47450	5	49	\N	51788	28140	\N	56.011302999999998	Красноярский край, город Назарово, ул.Борисенко, д.№10		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
48968	5	49	\N	51788	27996	\N	56.011302999999998	" город Назарово ул.Арбузова д. № 112 ""А"""		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47422	5	49	\N	745	72510	\N	53.709626	Красноярский край, город Минусинск, Штабная, 26		0101000020E6100000149337C0CCEC564016325706D5DA4A40
47426	5	49	\N	745	71722	\N	53.721077000000001	Красноярский край, город Минусинск, Хвастанцева, 71		0101000020E610000034F44F70B1EB5640EB724A404CDC4A40
47429	5	49	\N	745	72216	\N	53.698335999999998	Красноярский край, город Минусинск, Февральская, 9		0101000020E6100000F4BF5C8B16EC56404ACFF41263D94A40
47430	5	49	\N	745	72177	\N	53.694401999999997	Красноярский край, город Минусинск, Тимирязева, 9А		0101000020E61000003997E2AAB2EA564074232C2AE2D84A40
47467	5	49	\N	745	71644	\N	53.722670000000001	Красноярский край, город Норильск, Талнахская, 23		0101000020E6100000583A1F9E25EB564071E6577380DC4A40
47431	5	49	\N	745	7945	\N	53.692588999999998	Красноярский край, город Минусинск, Сургуладзе, 4	Россия, Красноярский край, Минусинск, Сургуладзе проезд, 4	0101000020E6100000236AA2CF47EA5640E048A0C1A6D84A40
47424	5	49	\N	745	7945	\N	53.691719999999997	Красноярский край, город Минусинск, Сургуладзе, 6	Россия, Красноярский край, Минусинск, Сургуладзе проезд, 6	0101000020E61000004F7633A31FEA56409BFEEC478AD84A40
49070	5	49	\N	745	72701	\N	53.701006999999997	Красноярский край, город Минусинск, Советская, 2Г		0101000020E61000005DC2A1B778EC56402FA2ED98BAD94A40
47427	5	49	\N	745	72287	\N	53.705570000000002	Красноярский край, город Минусинск, Свердлова, 105		0101000020E61000007079AC1919EB5640F584251E50DA4A40
47432	5	49	\N	745	8018	\N	53.687080999999999	Красноярский край, город Минусинск, Сафьяновых, 13	Россия, Красноярский край, Минусинск, Сафьяновых проезд, 13	0101000020E6100000596C938AC6EA5640FB592C45F2D74A40
47425	5	49	\N	745	72019	\N	53.710872999999999	Красноярский край, город Минусинск, Подсинская, 41		0101000020E6100000DFC14F1C40EB5640014EEFE2FDDA4A40
48704	5	49	\N	745	72078	\N	53.715401999999997	Красноярский край, Северо-Енисейский район, Октябрьская, 8		0101000020E6100000810871E5ECEB56401ABFF04A92DB4A40
47419	5	49	\N	745	72078	\N	53.705207000000001	Красноярский край, город Минусинск, Октябрьская, 95А		0101000020E6100000DDD1FF722DED564084F4143944DA4A40
47417	5	49	\N	745	72058	\N	53.699280000000002	Красноярский край, город Минусинск, Набережная, 93А		0101000020E6100000A81C93C5FDEC56409A5FCD0182D94A40
47423	5	49	\N	745	71690	\N	53.715590937366599	Красноярский край, город Минусинск, Мира, 28	Россия, Красноярский край, Минусинск, улица Мира	0101000020E61000002F3201BF46EC5640EE27637C98DB4A40
47438	5	49	\N	745	72513	\N	53.721018000000001	Красноярский край, город Минусинск, Литейная, 1		0101000020E6100000A4C2D84290EC5640E6E95C514ADC4A40
47420	5	49	\N	745	72173	\N	53.710200999999998	Красноярский край, город Минусинск, Ленина, 77		0101000020E61000006BD619DF17EC5640124BCADDE7DA4A40
47437	5	49	\N	\N	28162	\N	53.679323205360902	Красноярский край, город Минусинск, Кызыльская, 6	Россия, Красноярский край, улица Кызыльская, 6	0101000020E610000002637D0393ED5640D6355A0EF4D64A40
47428	5	49	\N	745	72175	\N	53.698388999999999	Красноярский край, город Минусинск, Крупской, 100		0101000020E610000062BA10AB3FEB56406D718DCF64D94A40
47434	5	49	\N	745	72580	\N	53.689943999999997	Красноярский край, город Минусинск, Кретова, 9		0101000020E6100000CC99ED0A7DEB56402409C21550D84A40
47435	5	49	\N	745	28229	\N	53.622723999999998	Красноярский край, город Минусинск, Журавлева, 8	Россия, Красноярский край, поселок Зеленый Бор, улица Журавлева, 8	0101000020E6100000BAF8DB9E20E856409737876BB5CF4A40
47416	5	49	\N	745	72069	\N	53.691831999999998	Красноярский край, город Минусинск, Вокзальная, 18Д		0101000020E610000044A4A65D4CED5640C32973F38DD84A40
47433	5	49	\N	745	72577	\N	53.690157999999997	Красноярский край, город Минусинск, Ванеева, 8		0101000020E61000002AA913D044EB56405089EB1857D84A40
47418	5	49	\N	745	72089	\N	53.710270000000001	Красноярский край, город Минусинск, Автомобильная, 37		0101000020E61000007AA9D898D7ED56403BAA9A20EADA4A40
47941	5	49	\N	24861	71510	\N	56.052546999999997	Красноярский край, Емельяновский район, Минино, Вокзальная, 9	Россия, Красноярский край, деревня Минино	0101000020E61000003DD7F7E1202257405F402FDCB9064C40
47960	5	49	\N	51791	28005	\N	56.274095000000003	Красноярский край, Емельяновский район, Минжуль, Лесная, Клуб	Россия, Красноярский край, поселок Минжуль	0101000020E61000003E5A9C31CC485740A27F828B15234C40
47796	5	49	\N	59614	72518	\N	58.498384073359396	п. Манзя, Ленина, 20	Россия	0101000020E61000006EE00ED429125840C26C020CCB3F4D40
48920	5	49	\N	59756	73005	\N	55.126784563047302	с.Малое Озеро, Центральная, 57	Россия, Красноярский край, Шарыповский район, поселок Малое Озеро	0101000020E61000001CB5C2F4BD555640CA4FAA7D3A904B40
39542	5	49	\N	49346	\N	\N	55.958486999999998	д. Лопатино, Речная, 2	Россия, Красноярский край, деревня Лопатино	0101000020E61000005D3123BC3D5057401152B7B3AFFA4B40
47402	5	49	\N	3405	\N	\N	58.2228549288143	Красноярский край, город Лесосибирск, 9 микрорайон, 10	Россия, Красноярский край, Лесосибирск, 9-ый микрорайон, 10	0101000020E61000009B38B9DFA120574003603C83861C4D40
47385	5	49	\N	3405	7536	\N	58.290131000000002	Красноярский край, город Лесосибирск, поселок Стрелка, Комсомольская, 18	Россия, Красноярский край, Лесосибирск, улица Комсомольская, 16	0101000020E6100000C37DE4D6A418574024473A0323254D40
47404	5	49	\N	3405	7674	\N	58.245215000000002	Красноярский край, город Лесосибирск, Горького, 25	Россия, Красноярский край, Лесосибирск, улица Горького, 25	0101000020E6100000F660527C7C1E57408CBE8234631F4D40
47389	5	49	\N	3405	72165	\N	58.173274999999997	"Красноярский край, город Лесосибирск, микрорайон ""Строитель"", 6"		0101000020E610000005F86EF3C6215740711B0DE02D164D40
47415	5	49	\N	3405	72714	\N	58.317005000000002	Красноярский край, город Лесосибирск, Рябиновая, 1		0101000020E6100000624ED026871A574091D5AD9E93284D40
47413	5	49	\N	3405	72370	\N	58.299950000000003	Красноярский край, город Лесосибирск, Просвещения, 34		0101000020E6100000C80C54C6BF185740B537F8C264264D40
47412	5	49	\N	3405	72370	\N	58.298654999999997	Красноярский край, город Лесосибирск, Просвещения, 32		0101000020E610000062DC0DA2B5185740B8E4B8533A264D40
47410	5	49	\N	3405	72285	\N	58.290939999999999	Красноярский край, город Лесосибирск, Промышленная, 18		0101000020E610000047C66AF3FF185740938C9C853D254D40
47409	5	49	\N	3405	73015	\N	58.248444999999997	Красноярский край, город Лесосибирск, Подгорная, 15		0101000020E6100000E4F4F57CCD15574067EDB60BCD1F4D40
47393	5	49	\N	3405	72280	\N	58.184359999999998	Красноярский край, город Лесосибирск, Победы, 40А		0101000020E6100000B7B41A12F72157406458C51B99174D40
47392	5	49	\N	3405	72280	\N	58.186304999999997	Красноярский край, город Лесосибирск, Победы, 31		0101000020E6100000645A9BC6F6215740670A9DD7D8174D40
47391	5	49	\N	3405	72280	\N	58.183349	Красноярский край, город Лесосибирск, Победы, 42		0101000020E61000008716D9CEF72157408D60E3FA77174D40
47390	5	49	\N	3405	72280	\N	58.179544	Красноярский край, город Лесосибирск, Победы, 48		0101000020E6100000D6AC33BE2F225740B5183C4CFB164D40
47407	5	49	\N	3405	72213	\N	58.233310000000003	Красноярский край, город Лесосибирск, Пионерская, 8		0101000020E61000008463963D091E574036EA211ADD1D4D40
47405	5	49	\N	3405	72087	\N	58.236427999999997	Красноярский край, город Лесосибирск, Первомайская, 10А		0101000020E6100000551344DD071F5740E9EDCF45431E4D40
47386	5	49	\N	3405	71688	\N	58.250045999999998	Красноярский край, город Лесосибирск, поселок Стрелка, Октябрьская, 34		0101000020E6100000F7764B72C01C5740703FE08101204D40
47408	5	49	\N	3405	72693	\N	58.251874000000001	Красноярский край, город Лесосибирск, Мичурина, 6		0101000020E6100000DE8D0585411D57403A5B40683D204D40
47411	5	49	\N	3405	72172	\N	58.292284000000002	Красноярский край, город Лесосибирск, Ленинградская, 13		0101000020E610000020D3DA34B61857407192E68F69254D40
48004	5	49	\N	3405	7101	\N	58.229913000000003	Красноярский край, Енисейский район, с.Подгорное, пер.Клубный, 3	Россия, Красноярский край, Лесосибирск, Клубный переулок, 3	0101000020E610000055D97745F01F57406FF607CA6D1D4D40
47403	5	49	\N	3405	7101	\N	58.229913000000003	Красноярский край, город Лесосибирск, переулок Клубный, 3	Россия, Красноярский край, Лесосибирск, Клубный переулок, 3	0101000020E610000055D97745F01F57406FF607CA6D1D4D40
47399	5	49	\N	3405	73032	\N	58.194014000000003	Красноярский край, город Лесосибирск, Клубная, 1Б		0101000020E610000090DB2F9FAC1E5740AB7B6473D5184D40
47406	5	49	\N	3405	72283	\N	58.240833000000002	Красноярский край, город Лесосибирск, Горького, 30		0101000020E61000001686C8E9EB1E57401766A19DD31E4D40
47397	5	49	\N	3405	72283	\N	58.211224000000001	Красноярский край, город Лесосибирск, Горького, 120		0101000020E6100000FE63213A04215740AE105663091B4D40
47396	5	49	\N	3405	72170	\N	58.195000999999998	Красноярский край, город Лесосибирск, Белинского, 16в		0101000020E610000086E63A8DB4215740F9D7F2CAF5184D40
47395	5	49	\N	3405	72170	\N	58.190323999999997	Красноярский край, город Лесосибирск, Белинского, 21		0101000020E6100000D09849D40B2257406BD26D895C184D40
47388	5	49	\N	3405	72719	\N	58.148572000000001	Красноярский край, город Лесосибирск, Абалаковская, 8		0101000020E61000002E724F5777265740F88C446804134D40
47398	5	49	\N	3405	72282	\N	58.208550000000002	Красноярский край, город Лесосибирск, 7 микрорайон, 10		0101000020E61000004A7D59DAA920574058CA32C4B11A4D40
47414	5	49	\N	3405	72286	\N	58.304864000000002	Красноярский край, город Лесосибирск, 6 квартал, 7а		0101000020E61000008DEE2076A618574027DD96C805274D40
47401	5	49	\N	3405	72171	\N	58.218556999999997	Красноярский край, город Лесосибирск, 5 микрорайон, 5А		0101000020E61000002461DF4E22205740EBA7FFACF91B4D40
47400	5	49	\N	3405	73057	\N	58.218556999999997	Красноярский край, город Лесосибирск, 5 микрорайон, 5а		0101000020E61000002461DF4E22205740EBA7FFACF91B4D40
47394	5	49	\N	3405	72578	\N	58.189127999999997	Красноярский край, город Лесосибирск, Победы, 20А		0101000020E61000006AA0F99CBB2157400261A75835184D40
48239	5	49	\N	59743	72987	\N	56.235602764049403	с.Левобережное, Береговая, 12	Россия, Красноярский край, село Левоборежное	0101000020E61000009CE1067C7EE5574074EB353D281E4C40
47842	5	49	\N	59647	72640	\N	56.797915000000003	село Лакино Мира 41		0101000020E6100000C616821C9440574072FE261422664C40
47684	5	49	\N	46862	28571	\N	56.354782	с.Курбатово, Центральная, 29-2		0101000020E610000011C5E40D309C5640D09A1F7F692D4C40
48467	5	49	\N	59669	72697	\N	58.092030084159703	Красноярский край, Мотыгинский район, Кулаковский сельсовет, п. Кулаково, Ангарская, 23	Россия	0101000020E61000009E978A8D797057401D2098A3C70B4D40
47721	5	49	\N	13985	27895	\N	55.944333999999998	д. Кузнецово, Кооперативная, 2		0101000020E6100000B91798158A4357401C40BFEFDFF84B40
47969	5	49	\N	26135	72853	\N	56.241833999999997	Красноярский край, Емельяновский район, Куваршино, Еланская, 34		0101000020E61000003D7C992842585740CA87A06AF41E4C40
49018	5	49	\N	51742	\N	\N	55.007731	п. Кресты, Сельский дом культуры		0101000020E61000007C2C7DE8828457402B155454FD804B40
47959	5	49	\N	25689	72846	\N	56.284118999999997	Красноярский край, Емельяновский район, Красный Пахарь, Центральная, 11		0101000020E610000073BA2C26364457400B96EA025E244C40
49087	5	49	\N	1225	\N	\N	55.986449673035899	Красноярск, Октябрьский район, Академгородок, 50/44		0101000020E6100000D9942BBCCB305740D1915CFE43FE4B40
49061	5	49	\N	1225	\N	\N	56.024748000000002	Красноярский край, город Красноярск, Ленинский район Шевченок 8	Россия, Красноярский край, Красноярск, Ленинский район	0101000020E6100000DEC66647AA4157401A5245F12A034C40
47343	5	49	\N	1225	\N	\N	56.089934594166401	Красноярский край, город Красноярск, Советский район		0101000020E6100000D5963AC8EB42574004E275FD820B4C40
47287	5	49	\N	1225	\N	\N	55.991580999999996	Красноярский край, город Красноярск, Октябрьский район, Академгородок, 50		0101000020E61000005BB39597FC305740E02A4F20ECFE4B40
48707	5	49	7126	\N	5886	\N	56.025640266754003	Красноярский край, Северо-Енисейский район, Студенческая, 9		0101000020E6100000BB2BBB607035574017BCE82B48034C40
47226	5	49	\N	1225	5938	\N	55.989803999999999	г. Красноярск Новая 16	Россия, Красноярский край, Красноярск, улица Новая, 16	0101000020E61000006BB933130C3E574099B9C0E5B1FE4B40
47378	5	49	\N	1225	4740	\N	56.013204999999999	г. Красноярск Ленина 63	Россия, Красноярский край, Красноярск, улица Ленина, 63	0101000020E610000005FBAF73D3375740649291B3B0014C40
47050	5	49	\N	1225	3230	\N	55.985458000000001	г. Красноярск Кутузова 90	Россия, Красноярский край, Красноярск, улица Кутузова, 90	0101000020E610000095D40968223C574071CADC7C23FE4B40
47281	5	49	\N	1225	6481	\N	56.014529000000003	Красноярский край, город Красноярск, Октябрьский район, корнеева, 50	Россия, Красноярский край, Красноярск, улица Корнеева, 50	0101000020E6100000D6E5948098335740FBEB1516DC014C40
47233	5	49	\N	1225	5996	\N	56.006618000000003	г. Красноярск Коммунальная 12	Россия, Красноярский край, Красноярск, улица Коммунальная, 12	0101000020E6100000384C3448C13B574050C8CEDBD8004C40
47376	5	49	\N	1225	7420	\N	56.010739999999998	г. Красноярск Кирова 24	Россия, Красноярский край, Красноярск, улица Кирова, 24	0101000020E6100000F436363B523757402861A6ED5F014C40
49086	5	49	\N	1225	4565	\N	56.019253999999997	Красноярск, Октябрьский район, Вильского, 13	Россия, Красноярский край, Красноярск, улица Вильского, 13	0101000020E6100000E4BF401020315740992842EA76024C40
47288	5	49	\N	1225	72523	\N	55.994477858511502	Красноярский край, город Красноярск, Октябрьский район, Академгородок, 21		0101000020E61000009E40D82956305740B64B1B0E4BFF4B40
44716	5	49	\N	1225	73332	\N	55.990125999999997	г. Красноярск Пионерской правды 5		0101000020E61000003BAC70CB473C5740AB75E272BCFE4B40
47316	5	49	\N	1225	4729	\N	55.994948999999998	"Красноярск, пр. им.газеты ""Красноярский рабочий"", 168А"	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 168а	0101000020E610000066DB696B443957400D18247D5AFF4B40
47237	5	49	\N	1225	4729	\N	56.002595999999997	" г. Красноярск пр. им. газеты ""Красноярский рабочий"" 126"	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 126	0101000020E610000061A92EE0653B5740DA8CD31055004C40
47235	5	49	\N	1225	4729	\N	56.001756	" г. Красноярск пр. им. газеты ""Красноярский рабочий"" 95"	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 95	0101000020E6100000E75608ABB13B57403049658A39004C40
47231	5	49	\N	1225	4729	\N	56.008118000000003	" г. Красноярск пр. им. газеты ""Красноярский рабочий"" 92б"	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 92б	0101000020E6100000FED30D14783C57402541B8020A014C40
47229	5	49	\N	1225	4729	\N	55.998373000000001	" г. Красноярск пр. им. газеты ""Красноярский рабочий"" 156"	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 156	0101000020E61000002C2E8ECA4D3A5740CE1ABCAFCAFF4B40
47313	5	49	\N	1225	72086	\N	55.996111999999997	Красноярск, академика Вавилова, 19А		0101000020E61000005D6F9BA9103B57409A93179980FF4B40
47236	5	49	\N	1225	6038	\N	56.000889999999998	г. Красноярск пер. Якорный 3	Россия, Красноярский край, Красноярск, Якорный переулок, 3	0101000020E610000079909E22873B57405C72DC291D004C40
47224	5	49	\N	1225	72475	\N	56.018805999999998	Красноярский край, город Красноярск, Железнодорожный район, Яковлева, 1а		0101000020E610000067B62BF4C1345740FA7B293C68024C40
47299	5	49	\N	1225	72143	\N	56.035446	Красноярский край, город Красноярск, Октябрьский район, Юшкова, 38		0101000020E61000004ED1915CFE3057401363997E89044C40
47298	5	49	\N	1225	72143	\N	56.030285999999997	Красноярский край, город Красноярск, Октябрьский район, Юшкова, 8а		0101000020E6100000AED85F764F31574069C36169E0034C40
47249	5	49	\N	1225	72253	\N	56.017890000000001	Красноярский край, город Красноярск, Ленинский район, Юности, 16		0101000020E6100000541D7233DC3E5740757632384A024C40
47247	5	49	\N	1225	72253	\N	56.015953000000003	Красноярский край, город Красноярск, Ленинский район, Юности, 28		0101000020E6100000F8544E7B4A3E5740F5A276BF0A024C40
47257	5	49	\N	1225	72131	\N	56.003808999999997	Красноярский край, город Красноярск, Ленинский район, Энергетиков, 17		0101000020E6100000E869C020E9415740193735D07C004C40
44312	5	49	\N	1225	73308	\N	55.991204000000003	г. Красноярск Щорса 64		0101000020E6100000A7954220973C57400BD5CDC5DFFE4B40
44258	5	49	\N	1225	73308	\N	55.989581999999999	г. Красноярск Щорса 55		0101000020E610000074982F2FC03C5740EA5A7B9FAAFE4B40
43994	5	49	\N	1225	73308	\N	55.992362	г. Красноярск Щорса 46		0101000020E610000089981249F43C574086E5CFB705FF4B40
47210	5	49	\N	1225	72483	\N	56.024883000000003	Красноярский край, город Красноярск, Железнодорожный район, Щетинкина, 1		0101000020E6100000E8F527F1B9355740FA9CBB5D2F034C40
47354	5	49	\N	1225	72156	\N	56.064982000000001	Красноярский край, город Красноярск, Советский район, Шумяцкого, 3		0101000020E6100000B6DB2E34D73B5740126A865451084C40
47268	5	49	\N	1225	72133	\N	55.999344000000001	Красноярский край, город Красноярск, Ленинский район, Шевченко, 56		0101000020E61000005376FA415D42574017BA1281EAFF4B40
47267	5	49	\N	1225	72133	\N	55.997118999999998	Красноярский край, город Красноярск, Ленинский район, Шевченко, 38		0101000020E6100000FD69A33A1D425740309C6B98A1FF4B40
47266	5	49	\N	1225	72133	\N	55.993015999999997	Красноярский край, город Красноярск, Ленинский район, Шевченко, 8		0101000020E6100000D82AC1E270415740CE33F6251BFF4B40
49085	5	49	\N	1225	72572	\N	56.015903000000002	" Красноярский край, город Красноярск, Ленинский район Чайковского 13""А"""		0101000020E6100000C47C7901F63D57404374081C09024C40
47246	5	49	\N	1225	72572	\N	56.015903000000002	Красноярский край, город Красноярск, Ленинский район, Чайковского, 13А		0101000020E6100000C47C7901F63D57404374081C09024C40
47368	5	49	\N	1225	73304	\N	56.009985	г. Красноярск Урицкого 26		0101000020E61000002DCC423BA7385740AC39403047014C40
47302	5	49	\N	1225	73304	\N	56.008127999999999	г. Красноярск Урицкого 121		0101000020E6100000027E8D244137574048179B560A014C40
38775	5	49	\N	1225	73304	\N	56.009154000000002	г. Красноярск Урицкого 106		0101000020E6100000F0A7C64B37375740555051F52B014C40
47360	5	49	\N	1225	72036	\N	56.062992000000001	Красноярский край, город Красноярск, Советский район, Урванцева, 23		0101000020E61000003C6A4C88B93A57406FF4311F10084C40
47359	5	49	\N	1225	72036	\N	56.065027000000001	Красноярский край, город Красноярск, Советский район, Урванцева, 26-а		0101000020E6100000E141B3EBDE3A5740B22D03CE52084C40
47353	5	49	\N	1225	72036	\N	56.061228	Красноярский край, город Красноярск, Советский район, Урванцева, 10-а		0101000020E6100000075E2D77663B5740BCCCB051D6074C40
47352	5	49	\N	1225	72036	\N	56.061228	Красноярский край, город Красноярск, Советский район, Урванцева, 10-А		0101000020E6100000075E2D77663B5740BCCCB051D6074C40
48973	5	49	\N	1225	72435	\N	56.064505106667397	Красноярский край, город Красноярск, Советский район, Урванцева, 30-а	Россия, Красноярский край, Красноярск, Советский район	0101000020E6100000FEEF880AD53A5740D8B628B341084C40
47218	5	49	\N	1225	72249	\N	56.021261000000003	Красноярский край, город Красноярск, Железнодорожный район, Толстого, 43		0101000020E6100000D8101C977134574013D731AEB8024C40
47243	5	49	\N	1225	6102	\N	56.011111999999997	Красноярский край, город Красноярск, Ленинский район, Тихий, 18	Россия, Красноярский край, Красноярск, Тихий переулок, 18	0101000020E6100000ADF9F197163D5740EC4B361E6C014C40
47348	5	49	\N	1225	72080	\N	56.049892999999997	Красноярский край, город Красноярск, Советский район, Тельмана, 29-А		0101000020E61000003D484F91433E574050A6D1E462064C40
47382	5	49	\N	1225	73312	\N	56.023001999999998	г. Красноярск Степана Разина 39		0101000020E61000009B1E1494A23757400DDFC2BAF1024C40
47273	5	49	\N	1225	72134	\N	56.006467000000001	Красноярский край, город Красноярск, Октябрьский район, Сопочная, 40		0101000020E61000006A4FC939B13357406AC020E9D3004C40
47365	5	49	\N	1225	7287	\N	56.120322000000002	Красноярский край, город Красноярск, Советский район, Солнечный бульвар, 11	Россия, Красноярский край, Красноярск, Солнечный бульвар, 11	0101000020E610000068976F7D583B5740A27E17B6660F4C40
47363	5	49	\N	1225	7287	\N	56.115031999999999	Красноярский край, город Красноярск, Советский район, Солнечный бульвар, 9	Россия, Красноярский край, Красноярск, Солнечный бульвар, 9	0101000020E6100000486AA164723B57402AFF5A5EB90E4C40
48974	5	49	\N	1225	72681	\N	56.083983000000003	Красноярский край, город Красноярск, Советский район, д.Песчанка, ул.Лазо		0101000020E6100000DDEC0F94DB445740C23577F4BF0A4C40
47322	5	49	\N	1225	72085	\N	55.982743999999997	Красноярск, Семафорная, 123		0101000020E6100000253CA1D79F3657408C2B2E8ECAFD4B40
47320	5	49	\N	1225	72085	\N	55.986359999999998	Красноярск, Семафорная, 227А		0101000020E6100000A0504F1F81385740910A630B41FE4B40
47318	5	49	\N	1225	72085	\N	55.987220999999998	Красноярск, Семафорная, 247А		0101000020E6100000A662635E473957405376FA415DFE4B40
47314	5	49	\N	1225	72085	\N	55.989733000000001	Красноярск, Семафорная, 261		0101000020E6100000912BF52C083A5740D0622992AFFE4B40
46740	5	49	\N	1225	72085	\N	55.997562000000002	г. Красноярск Семафорная 381/2		0101000020E61000001F662FDB4E3C5740BEDD921CB0FF4B40
47222	5	49	\N	1225	72250	\N	56.027107000000001	Красноярский край, город Красноярск, Железнодорожный район, Северо-Енисейская, 42		0101000020E61000004A09C1AA7A355740103FFF3D78034C40
47291	5	49	\N	1225	5829	\N	56.015002000000003	Красноярский край, город Красноярск, Октябрьский район, пр. Свободный, 75	Россия, Красноярский край, Красноярск, Свободный проспект, 75	0101000020E6100000C630276893325740F3AFE595EB014C40
47286	5	49	\N	1225	5829	\N	56.022860999999999	Красноярский край, город Красноярск, Октябрьский район, пр. Свободный, 61	Россия, Красноярский край, Красноярск, Свободный проспект, 61	0101000020E6100000F84F3750E03357404BADF71BED024C40
47285	5	49	\N	1225	5829	\N	56.023082000000002	Красноярский край, город Красноярск, Октябрьский район, пр. Свободный, 67	Россия, Красноярский край, Красноярск, Свободный проспект, 67	0101000020E6100000029D499BAA3357402A90D959F4024C40
47283	5	49	\N	1225	5829	\N	56.019877999999999	Красноярский край, город Красноярск, Октябрьский район, пр. Свободный, 48	Россия, Красноярский край, Красноярск, Свободный проспект, 48	0101000020E610000060AE450BD032574077F4BF5C8B024C40
47277	5	49	\N	1225	5829	\N	56.005530999999998	Красноярский край, город Красноярск, Октябрьский район, Свободный, 82	Россия, Красноярский край, Красноярск, Свободный проспект, 82	0101000020E610000067B5C01E133157409D0E643DB5004C40
47216	5	49	\N	1225	5829	\N	56.023690999999999	Красноярский край, город Красноярск, Железнодорожный район, Свободный, 36	Россия, Красноярский край, Красноярск, Свободный проспект, 36	0101000020E6100000755776C1E0335740D21A834E08034C40
47358	5	49	\N	1225	7249	\N	56.059106999999997	Красноярский край, город Красноярск, Советский район, Светлогорский переулок, 7	Россия, Красноярский край, Красноярск, Светлогорский переулок, 7	0101000020E61000004AB3791C063A57407AFB73D190074C40
47366	5	49	\N	1225	72160	\N	56.121009000000001	Красноярский край, город Красноярск, Советский район, Светлова, 6		0101000020E610000072F90FE9B73A5740C6C210397D0F4C40
47341	5	49	\N	1225	72155	\N	55.970227000000001	Красноярск, Свердловская, 126		0101000020E61000005CE509849D3057401D59F96530FC4B40
47339	5	49	\N	1225	72155	\N	55.975194000000002	Красноярск, Свердловская, 101А		0101000020E61000004B77D7D990335740B2A03028D3FC4B40
47337	5	49	\N	1225	72155	\N	55.977969000000002	Красноярск, Свердловская, 63		0101000020E6100000BDC3EDD0B03557403CC093162EFD4B40
47254	5	49	\N	1225	72130	\N	56.044834999999999	Красноярский край, город Красноярск, Ленинский район, Рейдовая, 67А		0101000020E6100000F241CF66D5415740AB5B3D27BD054C40
47208	5	49	\N	1225	72236	\N	56.008425000000003	Красноярский край, город Красноярск, Железнодорожный район, Профсоюзов, 17		0101000020E6100000B340BB438A35574002BC051214014C40
47312	5	49	\N	1225	72245	\N	55.996253000000003	Красноярск, Побежимова, 46А		0101000020E6100000A67B9DD4973A57405DC5E23785FF4B40
47367	5	49	\N	1225	72162	\N	56.121115000000003	Красноярский край, город Красноярск, Советский район, Петрушина, 2		0101000020E61000000E9F7422C13B57400C0742B2800F4C40
49075	5	49	\N	1225	72505	\N	56.027543999999999	Красноярский край, город Красноярск, Октябрьский район, ул. Словцова, 14		0101000020E6100000645DDC4603305740BB99D18F86034C40
47310	5	49	\N	1225	72505	\N	56.027543999999999	Красноярский край, город Красноярск, Октябрьский район, Словцова, 14		0101000020E6100000645DDC4603305740BB99D18F86034C40
47251	5	49	\N	1225	72128	\N	56.024642	Красноярский край, город Красноярск, Ленинский район, Песочная, 20		0101000020E6100000FCA5457D92405740D40D147827034C40
47333	5	49	\N	1225	72097	\N	55.975914000000003	Красноярск, Парашютная, 8		0101000020E610000005357C0BEB365740B2DAFCBFEAFC4B40
47255	5	49	\N	1225	72485	\N	56.052748000000001	Красноярский край, город Красноярск, Ленинский район, Одесская, 3		0101000020E6100000E0F599B33E415740F7764B72C0064C40
47380	5	49	\N	1225	73293	\N	56.017919999999997	г. Красноярск Обороны 21А		0101000020E61000005B43A9BD88365740DFF8DA334B024C40
49076	5	49	\N	1225	72702	\N	56.057722845837503	Красноярский край, город Красноярск, Октябрьский район, Норильская, 1Д	Россия, Красноярский край, Красноярск, улица Норильская, 1д	0101000020E61000002D5BEB8B842E57400F9D9E7763074C40
47284	5	49	\N	1225	72492	\N	56.019862000000003	Красноярский край, город Красноярск, Октябрьский район, Новая заря, 2		0101000020E6100000DBF97E6ABC335740723788D68A024C40
47227	5	49	\N	1225	73300	\N	55.988897000000001	г. Красноярск Новая 32		0101000020E61000008063CF9ECB3D5740670E492D94FE4B40
47242	5	49	\N	1225	72252	\N	56.009974999999997	Красноярский край, город Красноярск, Ленинский район, Московская, 31		0101000020E6100000AAB8718BF93D574088635DDC46014C40
47241	5	49	\N	1225	72252	\N	56.007916000000002	Красноярский край, город Красноярск, Ленинский район, Московская, 20А		0101000020E6100000A29A92ACC33D5740BD8E386403014C40
47238	5	49	\N	1225	72252	\N	56.005858000000003	Красноярский край, город Красноярск, Ленинский район, Московская, 2		0101000020E610000098A432C51C3D5740C23577F4BF004C40
47225	5	49	\N	1225	73297	\N	55.985925999999999	г. Красноярск Мичурина 75, строение 1		0101000020E61000005839B4C8763E57405723BBD232FE4B40
45877	5	49	\N	1225	73297	\N	55.999651	г. Красноярск Мичурина 37		0101000020E6100000FF774485EA3D5740F4346090F4FF4B40
49051	5	49	\N	1225	368	\N	56.013553000000002	п.Стрелка-Чуня, Мира, 18	Россия, Красноярский край, Красноярск, Мира проспект, 18	0101000020E6100000B9E2E2A8DC385740A0E1CD1ABC014C40
47374	5	49	\N	1225	368	\N	56.013080000000002	г. Красноярск пр. Мира 44	Россия, Красноярский край, Красноярск, Мира проспект, 44	0101000020E6100000085BECF659385740A81DFE9AAC014C40
47364	5	49	\N	1225	72279	\N	56.118219000000003	Красноярский край, город Красноярск, Советский район, Микуцкого, 10		0101000020E61000003FC7478B333B57400762D9CC210F4C40
47217	5	49	\N	1225	72246	\N	56.025210000000001	Красноярский край, город Красноярск, Железнодорожный район, Мечникова, 13		0101000020E61000006DFFCA4A933457401EC4CE143A034C40
47351	5	49	\N	1225	7165	\N	56.054955	Красноярский край, город Красноярск, Советский район, Металлургов, 14-А	Россия, Красноярский край, Красноярск, Металлургов проспект, 14а	0101000020E6100000BE6A65C22F3D574037E0F3C308074C40
47350	5	49	\N	1225	7165	\N	56.059609000000002	Красноярский край, город Красноярск, Советский район, Металлургов, 4-А	Россия, Красноярский край, Красноярск, Металлургов проспект, 4а	0101000020E61000008C9DF0129C3D57400DC68844A1074C40
47221	5	49	\N	1225	72233	\N	56.014428000000002	Красноярский край, город Красноярск, Железнодорожный район, Менжинского, 11		0101000020E6100000CD3B4ED191345740C712D6C6D8014C40
47220	5	49	\N	1225	72233	\N	56.014192000000001	Красноярский край, город Красноярск, Железнодорожный район, Менжинского, 15		0101000020E6100000F433F5BA45345740B3EE1F0BD1014C40
47205	5	49	\N	1225	72233	\N	56.014428000000002	Красноярск, Менжинского, 11		0101000020E6100000CD3B4ED191345740C712D6C6D8014C40
47272	5	49	\N	1225	72688	\N	55.996192181601899	Красноярский край, город Красноярск, Октябрьский район, Мелькомбинатская, 2		0101000020E6100000E204A6D3BA335740B7442E3883FF4B40
47336	5	49	\N	1225	7008	\N	55.973928999999998	Красноярск, пер. Медицинский, 27	Россия, Красноярский край, Красноярск, Медицинский переулок, 27	0101000020E61000006FF085C95436574020D099B4A9FC4B40
43634	5	49	\N	1225	1017	\N	55.992367000000002	г. Красноярск пер. Маяковского 9	Россия, Красноярский край, Красноярск, Маяковского переулок, 9	0101000020E6100000639813B4C93D57409850C1E105FF4B40
43558	5	49	\N	1225	1017	\N	55.992367000000002	г. Красноярск пер.Маяковского 9	Россия, Красноярский край, Красноярск, Маяковского переулок, 9	0101000020E6100000639813B4C93D57409850C1E105FF4B40
47264	5	49	\N	1225	6325	\N	55.985629000000003	Красноярский край, город Красноярск, Ленинский район, Машиностроителей, 8	Россия, Красноярский край, Красноярск, Машиностроителей проспект, 8	0101000020E61000003ACE6DC2BD4057409E7E501729FE4B40
49080	5	49	\N	1225	72076	\N	56.063178000000001	Красноярский край, город Красноярск, Советский район, Мате Залки, 15		0101000020E6100000A054FB743C3C5740D1E9793716084C40
47355	5	49	\N	1225	72076	\N	56.068624999999997	Красноярский край, город Красноярск, Советский район, Мате Залки, 4-а		0101000020E6100000CC0BB08F4E3C5740105839B4C8084C40
47375	5	49	\N	1225	73321	\N	56.015968000000001	г. Красноярск Марковского 36		0101000020E61000001899805F233857402AE44A3D0B024C40
47258	5	49	\N	1225	71555	\N	56.0268985731078	Красноярский край, город Красноярск, Ленинский район, Малая, 64	Россия, Красноярский край, Красноярск, Ленинский район	0101000020E61000002E573F36C9415740C6A52A6D71034C40
47213	5	49	\N	1225	72122	\N	56.024033000000003	Красноярский край, город Красноярск, Железнодорожный район, Маерчака, 34		0101000020E6100000AFB14B546F3557402C836A8313034C40
47212	5	49	\N	1225	72122	\N	56.023133000000001	Красноярский край, город Красноярск, Железнодорожный район, Маерчака, 20		0101000020E610000012F8C3CF7F355740AC3AAB05F6024C40
47260	5	49	\N	1225	72488	\N	55.998010000000001	Красноярский край, город Красноярск, Ленинский район, Львовская, 43		0101000020E610000075E95F92CA4057405D8AABCABEFF4B40
47259	5	49	\N	1225	72488	\N	56.001952000000003	Красноярский край, город Красноярск, Ленинский район, Львовская, 24		0101000020E61000003605323B8B415740B61490F63F004C40
47206	5	49	\N	1225	72208	\N	55.994410999999999	Красноярский край, город Красноярск, Железнодорожный район, Ломоносова, 47		0101000020E6100000209BE447FC3357402EE411DC48FF4B40
47215	5	49	\N	1225	5813	\N	56.033177999999999	Красноярский край, город Красноярск, Железнодорожный район, Лизы Чайкиной, 5		0101000020E610000001BEDBBC713457402D793C2D3F044C40
47211	5	49	\N	1225	72121	\N	56.020083999999997	Красноярский край, город Красноярск, Железнодорожный район, Лиды Прушинской, 2		0101000020E6100000F372D87DC73557402096CD1C92024C40
47290	5	49	\N	1225	72493	\N	55.981782000000003	Красноярский край, город Красноярск, Октябрьский район, Лесная, 147		0101000020E610000056647440122E574097E65608ABFD4B40
47384	5	49	\N	1225	73318	\N	56.013638	г. Красноярск Ленина 90		0101000020E61000006058FE7C5B375740CEFDD5E3BE014C40
38760	5	49	\N	1225	73318	\N	56.013024000000001	г. Красноярск Ленина 114		0101000020E610000099F04BFDBC36574014083BC5AA014C40
47219	5	49	\N	1225	72472	\N	56.020932048311202	Красноярский край, город Красноярск, Железнодорожный район, Ладо Кецховели, 62	Россия, Красноярский край, Красноярск, улица Ладо Кецховели, 62	0101000020E6100000CEFFAB8E1C3457404EB857E6AD024C40
43788	5	49	\N	1225	73309	\N	55.993600000000001	г. Красноярск Кутузова 6		0101000020E610000061E124CD1F3E57401EA7E8482EFF4B40
35145	5	49	\N	1225	73309	\N	55.989697999999997	г. Красноярск Кутузова 52		0101000020E610000075E8F4BC1B3D574053758F6CAEFE4B40
34562	5	49	\N	1225	73309	\N	55.986978999999998	г. Красноярск Кутузова 72		0101000020E61000009F1F46088F3C57405D6BEF5355FE4B40
34502	5	49	\N	1225	73309	\N	55.984814	г. Красноярск Кутузова 91		0101000020E610000011A7936C753C57404C5299620EFE4B40
47293	5	49	\N	1225	72138	\N	56.019485000000003	Красноярский край, город Красноярск, Октябрьский район, Курчатова, 7		0101000020E6100000F06AB933133257409CE1067C7E024C40
47292	5	49	\N	1225	72138	\N	56.017206000000002	Красноярский край, город Красноярск, Октябрьский район, Курчатова, 1		0101000020E6100000309DD66D50325740C2A563CE33024C40
47296	5	49	\N	1225	72376	\N	56.023766999999999	Красноярский край, город Красноярск, Октябрьский район, Крупской, 10в		0101000020E610000081971936CA315740ADDC0BCC0A034C40
47295	5	49	\N	1225	72376	\N	56.026518000000003	Красноярский край, город Красноярск, Октябрьский район, Крупской, 42		0101000020E6100000A795422097315740AF601BF164034C40
47250	5	49	\N	1225	72127	\N	56.018186999999998	Красноярский край, город Красноярск, Ленинский район, Красноярский Рабочий, 38		0101000020E6100000E7543200543F57402E1B9DF353024C40
47327	5	49	\N	1225	71718	\N	55.974040000000002	Красноярск, Краснопресненская, 12		0101000020E61000009B7631CD743A5740787FBC57ADFC4B40
47209	5	49	\N	1225	72239	\N	56.013044000000001	Красноярский край, город Красноярск, Железнодорожный район, Красной Армии, 19		0101000020E610000026C632FD123657405BB4006DAB014C40
47347	5	49	\N	1225	72033	\N	56.047288000000002	Красноярский край, город Красноярск, Советский район, Краснодарская, 5-Б		0101000020E61000008942CBBA7F3C574023BF7E880D064C40
49084	5	49	\N	1225	73331	\N	56.017361999999999	Красноярский край, город Красноярск, Ленинский район Крайняя 4		0101000020E610000055867137883D5740B91803EB38024C40
36745	5	49	\N	1225	73295	\N	56.005304000000002	г. Красноярск Корнетова 12		0101000020E61000002EC55565DF3C5740DD442DCDAD004C40
47282	5	49	\N	1225	72263	\N	56.014529000000003	Красноярский край, город Красноярск, Октябрьский район, Корнеева, 50		0101000020E6100000D6E5948098335740FBEB1516DC014C40
47369	5	49	\N	1225	73167	\N	56.015486131552898	г. Красноярск Конституции СССР 19		0101000020E61000000F62670A9D385740DFC5FB71FB014C40
49060	5	49	\N	1225	4207	\N	56.066836000000002	Красноярский край, город Красноярск, Советский район, Комсомольский проспект, 15	Россия, Красноярский край, Красноярск, Комсомольский проспект, 15	0101000020E610000074D190F1283B5740051901158E084C40
47234	5	49	\N	1225	73319	\N	56.005284000000003	г. Красноярск Коммунальная 14		0101000020E61000001286014BAE3B574096986725AD004C40
47232	5	49	\N	1225	73319	\N	56.005284000000003	город Красноярск Коммунальная 14		0101000020E61000001286014BAE3B574096986725AD004C40
47214	5	49	\N	1225	72530	\N	56.033177999999999	Красноярский край, город Красноярск, Железнодорожный район, Комбайностроителей, 8		0101000020E6100000419B1C3EE93457402D793C2D3F044C40
47317	5	49	\N	1225	72269	\N	55.988847	Красноярск, Кольцевая, 3А		0101000020E61000007F1475E61E395740B5DFDA8992FE4B40
38665	5	49	\N	1225	72269	\N	55.991036999999999	Красноярск, Кольцевая, 12А		0101000020E6100000386A85E97B3957401F10E84CDAFE4B40
47245	5	49	\N	1225	72123	\N	56.014111	Красноярский край, город Красноярск, Ленинский район, Коломенская, 25		0101000020E61000008524B37A873D5740C6C1A563CE014C40
47340	5	49	\N	1225	72506	\N	55.973849000000001	Красноярск, Ключевская, 99		0101000020E6100000B745990D32335740041F8315A7FC4B40
47338	5	49	\N	1225	72506	\N	55.975364999999996	Красноярск, Ключевская, 61		0101000020E6100000BCCCB051D6335740DE54A4C2D8FC4B40
47342	5	49	\N	1225	71627	\N	55.970543999999997	Красноярск, Карьерная, 26А		0101000020E6100000C503CAA65C3257401DAA29C93AFC4B40
47371	5	49	\N	1225	73303	\N	56.010956	г. Красноярск Карла Маркса 37		0101000020E6100000D525E318C9385740F5D8960167014C40
47370	5	49	\N	1225	73303	\N	56.011871999999997	г. Красноярск Карла Маркса 14		0101000020E6100000AE8218E8DA3857407ADE8D0585014C40
47301	5	49	\N	1225	72146	\N	56.034838000000001	Красноярский край, город Красноярск, Октябрьский район, Карбышева, 28а		0101000020E6100000137F1475E63157403B54539275044C40
47300	5	49	\N	1225	72146	\N	56.031458000000001	Красноярский край, город Красноярск, Октябрьский район, Карбышева, 1		0101000020E6100000FA62EFC5173257404A99D4D006044C40
47306	5	49	\N	1225	72149	\N	56.044713999999999	Красноярский край, город Красноярск, Октябрьский район, Калинина, 79		0101000020E61000007BDB4C857831574030D63730B9054C40
47305	5	49	\N	1225	72149	\N	56.038317999999997	Красноярский край, город Красноярск, Октябрьский район, Калинина, 80		0101000020E6100000C11F7EFE7B3257408F6CAE9AE7044C40
47304	5	49	\N	1225	72149	\N	56.039952	Красноярский край, город Красноярск, Октябрьский район, Калинина, 67		0101000020E6100000B56FEEAF1E32574074B4AA251D054C40
47381	5	49	\N	1225	73306	\N	56.022765	г. Красноярск Енисейская 1		0101000020E610000069C4CC3E8F385740293FA9F6E9024C40
47308	5	49	\N	1225	72500	\N	56.024183999999998	Красноярский край, город Красноярск, Октябрьский район, Стасовой, 10		0101000020E610000024607479732F5740118B187618034C40
47349	5	49	\N	1225	72278	\N	56.062891	Красноярский край, город Красноярск, Советский район, Джамбульская, 24		0101000020E6100000B01F6283853E57403B1BF2CF0C084C40
47326	5	49	\N	1225	72503	\N	55.971577000000003	Красноярск, Делегатская, 18		0101000020E6100000D5928E72303B5740DD4598A25CFC4B40
47309	5	49	\N	1225	72267	\N	56.029254999999999	Красноярский край, город Красноярск, Октябрьский район, Гусарова, 16		0101000020E610000062F9F36DC13057404B1FBAA0BE034C40
47307	5	49	\N	1225	72267	\N	56.029536	Красноярский край, город Красноярск, Октябрьский район, Гусарова, 56		0101000020E6100000703FE08101305740FF06EDD5C7034C40
39296	5	49	\N	1225	73302	\N	56.020839000000002	г. Красноярск Горького 97		0101000020E610000065506D70223657409DBD33DAAA024C40
47256	5	49	\N	1225	72258	\N	56.023319000000001	Красноярский край, город Красноярск, Ленинский район, Глинки, 2Б		0101000020E6100000B75D68AED34357400E30F31DFC024C40
43820	5	49	\N	1225	73299	\N	55.996606	г. Красноярск Гастелло 38		0101000020E6100000ED293927F63D5740AA7F10C990FF4B40
47294	5	49	\N	1225	72499	\N	56.024853	Красноярский край, город Красноярск, Октябрьский район, Высотная, 2		0101000020E6100000A22424D2363257408F1A13622E034C40
49081	5	49	\N	1225	72054	\N	56.059378000000002	Красноярский край, город Красноярск, Советский район, Воронова, 18-а		0101000020E6100000B5A4A31CCC3C57400B0DC4B299074C40
47183	5	49	\N	1037	72112	\N	56.206916999999997	Красноярский край, город Канск, Краснопартизанская, 29		0101000020E61000001C7A8B87F7ED574043FE99417C1A4C40
49003	5	49	\N	1225	73291	\N	56.096412999999998	Диксонский район, п. Волочанка, ул. Волочанская, СОШ №15	Россия, Красноярский край, Красноярск, улица Волочанская	0101000020E6100000CA332F87DD3B574062F4DC42570C4C40
47280	5	49	\N	1225	72497	\N	56.011750999999997	Красноярский край, город Красноярск, Октябрьский район, Волочаевская, 44		0101000020E610000024D40CA9A2335740FF58880E81014C40
47261	5	49	\N	1225	72030	\N	55.995966000000003	Красноярский край, город Красноярск, Ленинский район, Волжская, 29А		0101000020E610000070D234289A405740C7F65AD07BFF4B40
47239	5	49	\N	1225	72480	\N	56.003875000000001	Красноярский край, город Красноярск, Ленинский район, Волгоградская, 2А		0101000020E6100000C4060B27693D5740D122DBF97E004C40
49077	5	49	\N	1225	73311	\N	56.033067000000003	г. Красноярск Водянникова 2		0101000020E610000043E21E4B1F375740D6C9198A3B044C40
47297	5	49	\N	1225	72141	\N	56.019253999999997	Красноярский край, город Красноярск, Октябрьский район, Вильского, 13		0101000020E6100000E4BF401020315740992842EA76024C40
49078	5	49	\N	1225	72322	\N	56.035758000000001	Красноярский край, город Красноярск, Советский район, Взлетная, 20		0101000020E6100000A6D6FB8D763A57400249D8B793044C40
48972	5	49	\N	1225	72079	\N	56.039876999999997	Красноярский край, город Красноярск, Советский район, Весны, 9-а		0101000020E61000005E2BA1BB243A5740696E85B01A054C40
47271	5	49	\N	1225	72584	\N	56.020294	Красноярский край, город Красноярск, Ленинский район, Верхняя, 3Б	Россия, Красноярский край, Красноярск, улица Верхняя, 3б	0101000020E6100000983270404B4457400B2769FE98024C40
47276	5	49	\N	1225	72018	\N	56.038705439259303	Красноярский край, город Красноярск, Октябрьский район, Ботаническая, 22	Россия, Красноярский край, Красноярск, улица Ботаническая	0101000020E61000001406651A4D2F574089981249F4044C40
47275	5	49	\N	1225	72491	\N	55.995306999999997	Красноярский край, город Красноярск, Октябрьский район, Борисова, 1		0101000020E61000008A3BDEE4B73257406C3D433866FF4B40
47270	5	49	\N	1225	72261	\N	56.006180000000001	Красноярский край, город Красноярск, Ленинский район, Борисевича, 7		0101000020E6100000A9A3E36A64435740D4F19881CA004C40
47269	5	49	\N	1225	72261	\N	56.005133000000001	Красноярский край, город Красноярск, Ленинский район, Борисевича, 23		0101000020E6100000892650C422435740B090B932A8004C40
47207	5	49	\N	1225	72559	\N	56.005521000000002	Красноярский край, город Красноярск, Железнодорожный район, Бограда, 91		0101000020E6100000E4D9E55B1F3657407A3881E9B4004C40
47230	5	49	\N	1225	73327	\N	55.999806999999997	г. Красноярск Базарная 172		0101000020E6100000ED9925016A3B5740EBA7FFACF9FF4B40
47263	5	49	\N	1225	72368	\N	55.988238000000003	Красноярский край, город Красноярск, Ленинский район, Аральская, 1		0101000020E6100000F913950D6B4057400D5531957EFE4B40
47262	5	49	\N	1225	72368	\N	55.989386000000003	Красноярский край, город Красноярск, Ленинский район, Аральская, 5		0101000020E6100000632827DA55405740658F5033A4FE4B40
47321	5	49	\N	1225	72501	\N	55.988453999999997	Красноярск, Гладкова, 8		0101000020E61000009D9E776341385740D9CC21A985FE4B40
47228	5	49	\N	1225	72231	\N	55.973661999999997	г. Красноярск Тимошенкова 161		0101000020E61000009BE5B2D1393C5740D1ADD7F4A0FC4B40
47204	5	49	\N	1225	72231	\N	55.968912000000003	Красноярск, Алеши Тимошенкова, 82		0101000020E61000005C8E57207A3C5740DA59F44E05FC4B40
49079	5	49	\N	1225	72199	\N	56.043481999999997	Красноярский край, город Красноярск, Советский район, Алексеева, 95		0101000020E6100000F8325184D43957407AFB73D190054C40
49059	5	49	\N	1225	72199	\N	56.050873000000003	Красноярский край, город Красноярск, Советский район, Алексеева, 29		0101000020E610000048A46DFC893A5740ED9FA70183064C40
47331	5	49	\N	1225	72152	\N	55.978180999999999	Красноярск, Александра Матросова, 30/10		0101000020E61000001BA19FA9D7385740C748F60835FD4B40
47330	5	49	\N	1225	72152	\N	55.982008	Красноярск, Александра Матросова, 20		0101000020E61000008330B77BB938574087342A70B2FD4B40
47329	5	49	\N	1225	72152	\N	55.983514	Красноярск, Александра Матросова, 15		0101000020E610000010CCD1E3F73857403E9468C9E3FD4B40
47319	5	49	\N	1225	72152	\N	55.987206	Красноярск, Александра Матросова, 12В		0101000020E61000009067976F7D3857401E3526C45CFE4B40
45782	5	49	\N	1225	73294	\N	55.998207000000001	г. Красноярск Павлова 24		0101000020E6100000B69F8CF1613D5740B3D1393FC5FF4B40
45700	5	49	\N	1225	73294	\N	55.995730000000002	г. Красноярск Павлова 23		0101000020E6100000F374AE28253D5740B3D2A41474FF4B40
45529	5	49	\N	1225	73294	\N	55.994168999999999	г. Красноярск Павлова 54		0101000020E61000003B545392753C574038D906EE40FF4B40
45163	5	49	\N	1225	73294	\N	55.993338000000001	г. Красноярск Павлова 70		0101000020E61000003106D671FC3B5740E1EF17B325FF4B40
47279	5	49	\N	1225	72574	\N	56.006351000000002	Красноярский край, город Красноярск, Октябрьский район, Киренского, 70		0101000020E6100000F6EFFACC5933574001A60C1CD0004C40
47278	5	49	\N	1225	72574	\N	55.996279000000001	Красноярский край, город Красноярск, Октябрьский район, Киренского, 28		0101000020E6100000EA9788B7CE3257408658FD1186FF4B40
47274	5	49	\N	1225	72574	\N	55.995423000000002	Красноярский край, город Красноярск, Октябрьский район, Киренского, 26		0101000020E6100000469561DC0D335740D65757056AFF4B40
47315	5	49	\N	1225	72439	\N	55.992044	Красноярск, академика Вавилова, 1В		0101000020E6100000015130630A3A5740B5183C4CFBFE4B40
36691	5	49	\N	1225	72439	\N	56.003573000000003	г. Красноярск Вавилова 92		0101000020E61000007AA9D898D73C574006137F1475004C40
36589	5	49	\N	1225	72439	\N	55.999802000000003	г. Красноярск Вавилова 49б		0101000020E6100000249D8191973C5740DA3C0E83F9FF4B40
36342	5	49	\N	1225	72439	\N	55.998403000000003	г. Красноярск Вавилова 37		0101000020E61000002B1895D4093C5740399D64ABCBFF4B40
35973	5	49	\N	1225	72439	\N	55.996701000000002	г. Красноярск Вавилова 25		0101000020E610000008E3A7716F3B5740FC71FBE593FF4B40
35370	5	49	\N	1225	72439	\N	55.996450000000003	г. Красноярск Вавилова 21		0101000020E61000002A6F47382D3B5740B30C71AC8BFF4B40
47289	5	49	\N	1225	72494	\N	55.986606000000002	Красноярский край, город Красноярск, Октябрьский район, Академгородок, 50/44		0101000020E6100000D9942BBCCB305740C904FC1A49FE4B40
47303	5	49	\N	1225	72710	\N	56.026161000000002	Красноярский край, город Красноярск, Октябрьский район, Азовская, 1		0101000020E6100000A9A0A2EA572D574020B75F3E59034C40
47379	5	49	\N	1225	73322	\N	56.014816000000003	г. Красноярск Ады Лебедевой 89		0101000020E6100000B6696CAF0537574091BA9D7DE5014C40
45146	5	49	\N	1225	4705	\N	55.988933000000003	г. Красноярск пер. Автобусный 4	Россия, Красноярский край, Красноярск, Автобусный переулок, 4	0101000020E61000002098A3C7EF3B5740B477465B95FE4B40
49082	5	49	\N	1225	71665	\N	56.0430784645092	Красноярский край, город Красноярск, Советский район, Авиаторов, 22-д		0101000020E6100000D8B79388F03A5740AB96749483054C40
47361	5	49	\N	1225	72077	\N	56.063369000000002	Красноярский край, город Красноярск, Советский район, 9 мая, 26		0101000020E6100000EE23B726DD3A5740454AB3791C084C40
47357	5	49	\N	1225	72077	\N	56.057523000000003	Красноярский край, город Красноярск, Советский район, 9 мая, 56-а		0101000020E61000008449F1F1093A574048E2E5E95C074C40
47356	5	49	\N	1225	72508	\N	56.057468	Красноярский край, город Красноярск, Советский район, 9 мая, 54		0101000020E61000000EDB1665363A57408448861C5B074C40
47335	5	49	\N	1225	72132	\N	55.977103	Красноярск, 60 лет Октября, 21		0101000020E6100000A3CD716E1336574068E90AB611FD4B40
47332	5	49	\N	1225	72132	\N	55.978769999999997	Красноярск, 60 лет Октября, 96		0101000020E61000000708E6E8F13757402827DA5548FD4B40
47265	5	49	\N	1225	72132	\N	55.980392000000002	Красноярск, 60 лет Октября, 81		0101000020E6100000CA87A06AF437574049A12C7C7DFD4B40
47334	5	49	\N	1225	27877	\N	55.980474710822499	Красноярск 60 лет Октября 81	Россия, Красноярский край, Красноярск, улица 60 Лет Октября, 81	0101000020E6100000A1DAE044F4375740D6C56D3480FD4B40
47328	5	49	\N	1225	27877	\N	55.986687000000003	Красноярск, 60 лет Октября, 137		0101000020E6100000588D25AC8D3A5740B63176C24BFE4B40
47244	5	49	\N	1225	72571	\N	56.012701999999997	Красноярский край, город Красноярск, Ленинский район, 52 Квартал, 1		0101000020E6100000834C3272163D5740014C1938A0014C40
47362	5	49	\N	1225	72084	\N	56.108978999999998	Красноярский край, город Красноярск, Советский район, 40 лет Победы, 24		0101000020E610000007600322C43A5740B3791C06F30D4C40
48703	5	49	\N	1225	72448	\N	56.112589098207302	Красноярский край, Северо-Енисейский район, 40 лет победы, 12А	Россия, Красноярский край, Красноярск, улица 40 Лет Победы, 12	0101000020E6100000FE5F75E4483B5740D671FC50690E4C40
47383	5	49	\N	1225	73329	\N	56.031775000000003	г. Красноярск 4-я Продольная 19		0101000020E6100000986E1283C03657404BEA043411044C40
47253	5	49	\N	1225	72075	\N	56.032851000000001	Красноярский край, город Красноярск, Ленинский район, 26 Бакинских Комиссаров, 5Б		0101000020E6100000B950F9D7F24157400952297634044C40
47252	5	49	\N	1225	72075	\N	56.031865000000003	Красноярский край, город Красноярск, Ленинский район, 26 Бакинских Комиссаров, 24А		0101000020E610000041B79734464157408B71FE2614044C40
48230	5	49	\N	6912	27964	\N	56.179771000000002	п.Краснополянск, Центральная, 7		0101000020E610000078B81D1A16E4574076E272BC02174C40
47812	5	49	\N	59612	72509	\N	58.419261128435103	"п. Красногорьевский, Ленина, 11 ""А"""	Россия	0101000020E6100000B00111E2CA6058407FBE2D58AA354D40
48278	5	49	\N	51789	72454	\N	58.611200366388999	Красноярский край, Кежемский район, город Кодинск, Маяковского, 15	Россия	0101000020E6100000EB39E97DE3CB584058A835CD3B4E4D40
49031	5	49	\N	51854	28373	\N	55.007731	поселок Кислокан, Ветеранов, 8		0101000020E61000007C2C7DE8828457402B155454FD804B40
47714	5	49	\N	13664	72841	\N	56.064022000000001	д. Киндяково, Березовая, 1		0101000020E6100000B56E83DA6F545740BD1C76DF31084C40
48297	5	49	\N	7605	72954	\N	56.237262000000001	п. Кедровый, Школьная, 1		0101000020E6100000139A249694145740B24AE9995E1E4C40
47586	5	49	\N	7605	72217	\N	56.235039999999998	Красноярский край, поселок Кедровый, Жуковского, 2		0101000020E6100000E738B709F71457403CA06CCA151E4C40
47189	5	49	\N	1037	72447	\N	56.199511999999999	Красноярский край, город Канск, Строителей, 59		0101000020E6100000707D586FD4F157406C94F59B89194C40
48705	5	49	\N	1037	72453	\N	60.169322000000001	Красноярский край, Северо-Енисейский район, Юбилейная, 23		0101000020E61000005AD5928E72435740253FE257AC154E40
47191	5	49	\N	1037	72073	\N	56.192349999999998	Красноярский край, город Канск, Элеваторная, 23А		0101000020E61000002E1F49490FED57405BB1BFEC9E184C40
47184	5	49	\N	1037	72533	\N	56.193362	Красноярский край, город Канск, Эйдемана, 17		0101000020E6100000834F73F222EE574003250516C0184C40
47193	5	49	\N	1037	72228	\N	56.221508999999998	Красноярский край, город Канск, Шоссейная, 46		0101000020E6100000B29FC55224F0574084622B685A1C4C40
47202	5	49	\N	1037	72418	\N	56.256107999999998	Красноярский край, город Канск, Солнечный, 85		0101000020E610000054FEB5BC72EB57403A1F9E25C8204C40
47192	5	49	\N	1037	71656	\N	56.218675065421699	Красноярский край, город Канск, Северный, 29А	Россия, Красноярский край, Канск, Северный микрорайон, 29	0101000020E61000005456D3F544EE5740F5B9DA8AFD1B4C40
47194	5	49	\N	1037	71680	\N	56.22175	Красноярский край, город Канск, Северный, 29		0101000020E610000078B81D1A16EC5740AAF1D24D621C4C40
47181	5	49	\N	1037	72410	\N	56.201450000000001	Красноярский край, город Канск, Революции, 19		0101000020E6100000FC71FBE593ED5740BDE3141DC9194C40
47195	5	49	\N	1037	71537	\N	56.206766999999999	Красноярский край, город Канск, Предмостная площадь, 11Б		0101000020E61000002BC0779B37ED57402E724F57771A4C40
47188	5	49	\N	1037	72116	\N	56.191709000000003	Красноярский край, город Канск, Николая Буды, 5		0101000020E61000006F10AD156DEF5740A8ACA6EB89184C40
47201	5	49	\N	1037	72417	\N	56.248441	Красноярский край, город Канск, Муромская, 13		0101000020E610000083DDB06D51EC574026FE28EACC1F4C40
47197	5	49	\N	1037	72555	\N	56.227804999999996	Красноярский край, город Канск, Молодогвардейская, 5		0101000020E6100000FDF675E09CED5740C16ED8B6281D4C40
47190	5	49	\N	1037	5531	\N	55.007731	Красноярский край, город Канск, Мелькомбината, 33		0101000020E61000007C2C7DE8828457402B155454FD804B40
47177	5	49	\N	1037	72224	\N	56.210272000000003	Красноярский край, город Канск, Луначарского, 1		0101000020E6100000BCCE86FC33EC5740DCA16131EA1A4C40
47182	5	49	\N	1037	72412	\N	56.202626000000002	Красноярский край, город Канск, Ленина, 10		0101000020E6100000A3586E6935ED5740DFA815A6EF194C40
47179	5	49	\N	1037	72111	\N	56.206541999999999	Красноярский край, город Канск, Крестьянская, 27		0101000020E610000067EF8CB62AEC57400EA0DFF76F1A4C40
47186	5	49	\N	1037	72114	\N	56.191684000000002	Красноярский край, город Канск, Красноярская, 22		0101000020E61000008ECA4DD4D2EE57404F95EF1989184C40
47185	5	49	\N	1037	72114	\N	56.190657000000002	Красноярский край, город Канск, Красноярская, 26		0101000020E6100000EC4E779E78EE574072E0D57267184C40
47095	5	49	\N	3300	72096	\N	56.266587000000001	г.Ачинск, микрорайон 7, 16		0101000020E6100000F7562426A89F5640F644D7851F224C40
47187	5	49	\N	1037	72226	\N	56.199091000000003	Красноярский край, город Канск, Краевая, 66		0101000020E6100000508E0244C1EF5740C7F65AD07B194C40
49058	5	49	\N	1037	73141	\N	56.189439999999998	п.Карьерный, м-он.ДСУ-4 ул.Трактовая, 14Б	Россия, Красноярский край, Канск, Карьерный переулок	0101000020E610000046B247A819F05740F146E6913F184C40
47180	5	49	\N	1037	72408	\N	56.207869000000002	Красноярский край, город Канск, Кайтымская, 56		0101000020E61000008E5BCCCF0DED5740166D8E739B1A4C40
47199	5	49	\N	1037	5619	\N	56.238236999999998	Красноярский край, город Канск, Индустриальный, 1	Россия, Красноярский край, Канск, Индустриальный переулок, 1	0101000020E610000059DB148F8BEC57403CD9CD8C7E1E4C40
46952	5	49	\N	1037	72522	\N	56.203381999999998	Красноярский край, город Канск, Земледелия, 39		0101000020E6100000917EFB3A70EB57402B4CDF6B081A4C40
47178	5	49	\N	1037	72531	\N	56.209516000000001	Красноярский край, город Канск, Бограда, 59		0101000020E610000081B2295778EB57408FFE976BD11A4C40
47200	5	49	\N	1037	72119	\N	56.247205999999998	Красноярский край, город Канск, 40 лет Октября, 65		0101000020E610000072F90FE9B7EB5740FFAF3A72A41F4C40
47198	5	49	\N	1037	72119	\N	56.234259999999999	Красноярский край, город Канск, 40 лет Октября, 33		0101000020E6100000689599D2FAEC574067614F3BFC1D4C40
47196	5	49	\N	1037	72119	\N	56.225042999999999	Красноярский край, город Канск, 40 лет Октября, 5		0101000020E61000009160AA99B5ED5740CC988235CE1C4C40
47944	5	49	\N	24992	72882	\N	56.11439	Красноярский край, Емельяновский район, Каменный Яр, Заводская, 1		0101000020E610000093C7D3F203135740A67EDE54A40E4C40
47794	5	49	\N	49394	27888	\N	56.165911258417303	д. Каменка Мира 12	Россия, Красноярский край, деревня Каменка	0101000020E6100000EF3B86C77E9B5640F98557923C154C40
47661	5	49	\N	49394	28266	\N	56.166026679448002	Красноярский край, Ачинский район, Ключинский сельсовет, д.Каменка, Лесная, б/н	Россия, Красноярский край, деревня Каменка	0101000020E61000004E44BFB67E9B564062A06B5F40154C40
47595	5	49	\N	49394	72855	\N	56.166105000000002	д. Каменка, ул. Длинная, 18		0101000020E6100000639CBF09859B5640DE59BBED42154C40
48727	5	49	\N	30713	28322	\N	56.376795000000001	Красноярский край, Сухобузимский район, Иркутское, Советская, 48		0101000020E610000011FDDAFAE9475740EE258DD13A304C40
47175	5	49	\N	59468	71492	\N	67.4649638501797	г.Игарка, Первый м-он, 19	Россия	0101000020E61000006C921FF12BA355404F745DF8C1DD5040
47174	5	49	\N	59468	72709	\N	67.467775664629002	г.Игарка, Горького, 39а	Россия	0101000020E6100000548EC9E2FEA25540A376BF0AF0DD5040
47176	5	49	\N	59468	71609	\N	67.433333000000005	г.Игарка, Второй м-он, 10а	Россия	0101000020E610000008E9297288A85540C4D155BABBDB5040
47718	5	49	\N	1592	72545	\N	55.949379999999998	с. Зыково, Школьная, 5Б		0101000020E6100000BDAC8905BE495740FDBCA94885F94B40
47719	5	49	\N	1592	71629	\N	55.960245999999998	с. Зыково, Советская, 27		0101000020E61000001AFD6838654A5740B20E4757E9FA4B40
14683	5	49	\N	1592	72535	\N	55.948900999999999	с. Зыково, Клубная, 6		0101000020E6100000E9103812684957402312859675F94B40
48232	5	49	\N	48555	28138	\N	56.161929999999998	п.Зеленый Луг, Первомайская, 14Б		0101000020E61000005055A18158F15740E21E4B1FBA144C40
47568	5	49	\N	59489	71617	\N	56.095530390327397	г. Зеленогорск, Первомайская, 10	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E610000009DD257156A55740B8E4B8533A0C4C40
47577	5	49	\N	59489	71612	\N	56.094954654771797	г. Зеленогорск, Парковая, 6	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E61000006D8C9DF012A55740BCCB457C270C4C40
47583	5	49	\N	59489	71666	\N	56.072302198974199	г. Зеленогорск, Диктатуры Пролетариата, 19А	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E6100000091B9E5E29A65740BBB7223141094C40
47163	5	49	\N	59598	72403	\N	55.958739956195302	Красноярский край, Рыбинский район, городское поселение город Заозерный, Победы, 9	Россия, Красноярский край, Рыбинский район, город Заозерный	0101000020E61000005E471CB281AD5740FBAE08FEB7FA4B40
47164	5	49	\N	59598	72406	\N	55.959125143173601	Красноярский край, Рыбинский район, городское поселение город Заозерный, 40 лет Октября, 38	Россия, Красноярский край, Рыбинский район, город Заозерный	0101000020E610000022C154336BAD574054E3A59BC4FA4B40
47533	5	49	\N	51733	28466	\N	56.257997965850002	г.Железногорск, Свердлова, 47		0101000020E61000008F368E588B6257407A37161406214C40
47532	5	49	\N	51733	28466	\N	56.240166575364199	г.Железногорск, Свердлова, 63	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E61000009146054EB65F57400A4AD1CABD1E4C40
47547	5	49	\N	51733	71620	\N	56.2300144441054	г.Железногорск, Саянская, 7	Россия, Красноярский край, Березовский район	0101000020E61000009F724C16F7635740A2CF4719711D4C40
47551	5	49	\N	51733	28256	\N	56.240426187858503	г.Железногорск, Ленинградский проспект, 77	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E6100000A81B28F04E5F5740D68D7747C61E4C40
47554	5	49	\N	51733	28455	\N	56.240713	г.Железногорск, Белорусская, 45А		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
48994	5	49	\N	51877	\N	\N	55.007731	п. Жданиха, Сельский дом культуры		0101000020E61000007C2C7DE8828457402B155454FD804B40
39758	5	49	\N	11422	71532	\N	56.136181000000001	с. Есаулово, Клубная, 4		0101000020E61000004B22FB20CB51574015AB06616E114C40
47716	5	49	\N	47515	28581	\N	56.137298999999999	д. Ермолаево, Первомайская, 1		0101000020E6100000F25EB532E149574002637D0393114C40
47162	5	49	\N	59478	\N	\N	58.448788572978003	Красноярский край, город Енисейск, мкр. Полюс, Здание МБОУ СОШ №7		0101000020E61000008655BC91790A5740FBE6FEEA71394D40
47160	5	49	\N	59478	71545	\N	58.4482917824933	Красноярский край, город Енисейск, Рабоче-Крестьянская, 210	Россия	0101000020E6100000D4D688601C0B57407B87DBA161394D40
47158	5	49	\N	59478	71678	\N	58.448551998589103	Красноярский край, город Енисейск, Перенсона, 85	Россия	0101000020E6100000B859BC58180B57401747E5266A394D40
47157	5	49	\N	59478	72461	\N	58.453449999999997	Красноярский край, город Енисейск, Ленина, 130	Россия	0101000020E6100000DD94F25A090C5740832F4CA60A3A4D40
47155	5	49	\N	59478	72461	\N	58.451186999999997	Красноярский край, город Енисейск, Ленина, 102	Россия	0101000020E6100000EC884336900B5740AFB0E07EC0394D40
47154	5	49	\N	59478	72461	\N	58.447618340244802	Красноярский край, город Енисейск, Ленина, 44	Россия	0101000020E6100000D3156C239E0A5740EB8CEF8B4B394D40
47153	5	49	\N	59478	71649	\N	58.448788572978103	Красноярский край, город Енисейск, Куйбышева, 43	Россия	0101000020E6100000B1A888D349095740FBE6FEEA71394D40
47156	5	49	\N	59478	72538	\N	58.449486	Красноярский край, город Енисейск, Горького, 5	Россия	0101000020E610000074D3669C860B57404301DBC188394D40
47161	5	49	\N	59478	72479	\N	58.454659096128204	Красноярский край, город Енисейск, Гастелло, 10	Россия	0101000020E610000001310917F20C574081EA1F44323A4D40
47159	5	49	\N	59478	71702	\N	58.444468817551403	Красноярский край, город Енисейск, Бабкина, 74	Россия	0101000020E61000008046E9D2BF0B5740FC8A355CE4384D40
47931	5	49	\N	1330	6396	\N	56.173507000000001	Красноярский край, Емельяновский район, Емельяново, Советская, 1 К	Россия, Красноярский край, поселок Емельяново, улица Советская, 1а	0101000020E6100000566133C0052B57404450357A35164C40
47933	5	49	\N	1330	72998	\N	56.189725411754701	Красноярский край, Емельяновский район, Емельяново, Центральная, 5 А	Россия, Красноярский край, поселок Емельяново, улица Центральная, 5	0101000020E61000009E23F25D4A2B5740E71DA7E848184C40
47930	5	49	\N	1330	72998	\N	56.189198951553998	Красноярский край, Емельяновский район, Емельяново, Центральная, 26	Россия, Красноярский край, поселок Емельяново	0101000020E6100000F19E03CB112B5740CCB73EAC37184C40
47929	5	49	\N	1330	72689	\N	56.1926682018984	Красноярский край, Емельяновский район, Емельяново, Спортиная, 5	Россия, Красноярский край, поселок Емельяново, улица Спортивная, 5	0101000020E6100000A088450C3B2B57402C7E5358A9184C40
47927	5	49	\N	1330	27923	\N	56.168268902369299	Красноярский край, Емельяновский район, Емельяново, СПТУ-81, 3		0101000020E61000002FDD2406812A57401FF7ADD689154C40
47926	5	49	\N	1330	72610	\N	56.161738999999997	Красноярский край, Емельяновский район, Емельяново, Новая, 13а	Россия, Красноярский край, поселок Емельяново, улица Новая, 13а	0101000020E6100000F38E5374242C57406EBE11DDB3144C40
47928	5	49	\N	1330	72556	\N	56.177360999999998	Красноярский край, Емельяновский район, Емельяново, Московская, 371		0101000020E61000007193516518295740FD4AE7C3B3164C40
47924	5	49	\N	1330	72313	\N	56.167648999999997	Красноярский край, Емельяновский район, Емельяново, Декабристов, 85		0101000020E61000006C09F9A0672B5740821ABE8575154C40
47925	5	49	\N	1330	28127	\N	56.174180377848799	Красноярский край, Емельяновский район, Емельяново Московская 290	Россия, Красноярский край, поселок Емельяново, улица Московская, 289	0101000020E6100000D8B628B3412A574003CFBD874B164C40
48990	5	49	\N	51811	\N	\N	69.414291092487304	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, ТМКОУ ""Дудинская средняя общеобразовательная школа № 4"""	Россия	0101000020E6100000F0DDE68D938C5540BD0166BE835A5140
48987	5	49	\N	51811	\N	\N	69.397672515203098	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, ТМКОУ ""Дудинская средняя общеобразовательная школа № 7"""	Россия	0101000020E6100000A038807EDF8C55402460747973595140
48986	5	49	\N	51811	\N	\N	69.411874643392096	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, ТМКОУ ""Дудинская средняя общеобразовательная школа № 3"""	Россия	0101000020E61000008C2E6F0ED78C55408FC2F5285C5A5140
48980	5	49	\N	51811	\N	\N	69.409216235468605	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, ТМКОУ ""Дудинская средняя общеобразовательная школа № 1"""	Россия	0101000020E6100000DA56B3CEF88C5540FF3F4E98305A5140
48978	5	49	\N	51811	\N	\N	69.3964029320652	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, ТМКОУ ""Дудинская средняя общеобразовательная школа № 5"""	Россия	0101000020E6100000624A24D1CB8C55405342B0AA5E595140
47955	5	49	\N	25495	72684	\N	56.103617999999997	Красноярский край, Емельяновский район, Дрокино, Московская, 15		0101000020E6100000C03C64CA872F574072A3C85A430D4C40
47557	5	49	\N	51734	27753	\N	56.272627202450899	пос.Додоново, Новоселов, 7	Россия, Красноярский край, Красноярск, река Енисей	0101000020E6100000B9FFC874E85B5740D8800871E5224C40
47151	5	49	\N	17601	\N	\N	55.900424601788799	"Красноярский край, город Дивногорск, пос. Манский, КГБУ ""Дивногорский"""	Россия, Красноярский край, поселок Манский	0101000020E6100000787FBC57AD2057401AC05B2041F34B40
47150	5	49	\N	17601	\N	\N	55.962477999999997	Красноярский край, город Дивногорск, пос. Слизнево, Клуб-филиал	Россия, Красноярский край, Дивногорск	0101000020E6100000EB5223F4331857404B8FA67A32FB4B40
47146	5	49	\N	17601	\N	\N	55.962477999999997	Красноярский край, город Дивногорск, пос. Верхняя Бирюса, -		0101000020E6100000EB5223F4331857404B8FA67A32FB4B40
47141	5	49	\N	17601	72106	\N	55.960472000000003	Красноярский край, город Дивногорск, Чкалова, 169		0101000020E610000053094FE8F5165740A35C1ABFF0FA4B40
47139	5	49	\N	17601	72106	\N	55.952893000000003	Красноярский край, город Дивногорск, Чкалова, 41		0101000020E6100000FC709010E51757402ECBD765F8F94B40
47138	5	49	\N	17601	72104	\N	55.956814000000001	Красноярский край, город Дивногорск, Спортивная, 2		0101000020E610000005357C0BEB1857406F2D93E178FA4B40
47137	5	49	\N	17601	72071	\N	55.949782999999996	Красноярский край, город Дивногорск, Саянская, 12		0101000020E61000002A00C63368185740FCA5457D92F94B40
47145	5	49	\N	17601	72524	\N	55.965879000000001	Красноярский край, город Дивногорск, Парковая, 10		0101000020E61000009B594B016917574054724EECA1FB4B40
47144	5	49	\N	17601	72110	\N	55.96602	Красноярский край, город Дивногорск, Набережная, 9		0101000020E6100000E659492BBE18574016A4198BA6FB4B40
47143	5	49	\N	17601	72390	\N	55.963168000000003	Красноярский край, город Дивногорск, Комсомольская, 6		0101000020E6100000A4FACE2F4A185740E146CA1649FB4B40
47142	5	49	\N	17601	72389	\N	55.959333999999998	Красноярский край, город Дивногорск, Бочкина, 22		0101000020E6100000416150A6D11757406EF8DD74CBFA4B40
48962	5	49	\N	3300	72373	\N	56.256098000000001	г.Ачинск микрорайон 4, 30		0101000020E6100000B8019F1F469F56401749BBD1C7204C40
47140	5	49	\N	17601	72388	\N	55.959040999999999	Красноярский край, город Дивногорск, Б.Полевого, 3		0101000020E61000003276C24B70185740F64201DBC1FA4B40
48787	5	49	\N	59752	73000	\N	66.399667561409103	д.Горошиха, Северная, 11	Россия	0101000020E61000004FCFBBB1A0E055407F50172994995040
47655	5	49	\N	10919	28641	\N	56.243313999999998	Красноярский край, Ачинский район, Горновский сельсовет, п.Горный, Центральная, 16		0101000020E610000098A3C7EF6DA356405854C4E9241F4C40
47825	5	49	\N	51889	28526	\N	58.599524477694104	п. Говорково, Первомайский, 2		0101000020E6100000BEBD6BD097AE58406495D233BD4C4D40
48690	5	49	\N	8248	72857	\N	56.010876000000003	с.Вознесенка, Центральная, 68		0101000020E6100000D89FC4E74E515740D927806264014C40
47599	5	49	\N	8248	28214	\N	56.010876000000003	с. Вознесенка ул. Советская 35 Б		0101000020E6100000D89FC4E74E515740D927806264014C40
47997	5	49	\N	59617	72527	\N	58.434708123216602	Красноярский край, Енисейский район, с.Верхнепашино, Геофизиков, 10	Россия	0101000020E6100000B3B794F3C5115740A0A70183A4374D40
47996	5	49	\N	59496	71692	\N	58.408853718006803	Красноярский край, Енисейский район, с.Верхнепашино, Советская, 39	Россия	0101000020E61000008507CDAE7B1057405D6BEF5355344D40
49047	5	49	\N	59625	72576	\N	60.349089195549602	с.Ванавара, Советская, 64	Россия	0101000020E61000007DB262B83A9159405932C7F2AE2C4E40
47952	5	49	\N	25325	28479	\N	56.045442999999999	Красноярский край, Емельяновский район, Бугачево, Заречная, 19	Россия, Красноярский край, деревня Бугачево, улица Центральная	0101000020E610000095F0845E7F2A5740836A8313D1054C40
47130	5	49	\N	17249	\N	\N	55.907238	город Бородино, м-н Стахановский, 14	Россия, Красноярский край, город Бородино	0101000020E610000048FE60E0B9B957401FD8F15F20F44B40
47129	5	49	\N	17249	28414	\N	55.907238	город Бородино, м-н Стахановский, 13		0101000020E610000048FE60E0B9B957401FD8F15F20F44B40
47131	5	49	\N	17249	71489	\N	55.907238	город Бородино, Советская, 68	Россия, Красноярский край, город Бородино	0101000020E610000048FE60E0B9B957401FD8F15F20F44B40
47134	5	49	\N	17249	27862	\N	55.907238	город Бородино, Октябрьская, 56		0101000020E610000048FE60E0B9B957401FD8F15F20F44B40
47133	5	49	\N	17249	28060	\N	55.907238	город Бородино, Маяковского, 30		0101000020E610000048FE60E0B9B957401FD8F15F20F44B40
47132	5	49	\N	17249	71533	\N	55.907238	город Бородино, Ленина, 33		0101000020E610000048FE60E0B9B957401FD8F15F20F44B40
47135	5	49	\N	17249	28208	\N	55.907238	город Бородино, 9 Мая, 38	Россия, Красноярский край, город Бородино	0101000020E610000048FE60E0B9B957401FD8F15F20F44B40
48712	5	49	\N	29937	27776	\N	56.395488735803397	Красноярский край, Сухобузимский район, Большие Пруды, Космонавтов, 12	Россия, Красноярский край, поселок Большие Пруды	0101000020E610000035289A07B05C5740C07630629F324C40
47113	5	49	\N	59867	73213	\N	56.208636057256598	Боготолькский район,662060 г. Боготол Школьная 70	Россия, Красноярский край, Боготольский район, город Боготол	0101000020E6100000A4C2D8429060564056629E95B41A4C40
47121	5	49	\N	59867	73142	\N	56.2055750845348	Боготолькский район,662060 г. Боготол Урицкого 8а	Россия, Красноярский край, Боготольский район, город Боготол	0101000020E61000006342CC255561564007F01648501A4C40
47117	5	49	\N	59867	73204	\N	56.204808999999997	Боготолькский район,662060 г. Боготол 40 лет Октября 27а		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47119	5	49	\N	59886	73220	\N	56.203708724728699	Боготолькский район,662060 г. Боготол Северная 9		0101000020E610000093E1783E036256405073F222131A4C40
47111	5	49	\N	59886	73243	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Деповская 3		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47115	5	49	\N	59886	73335	\N	56.204808999999997	Боготолькский район,662060 г. Боготол 40 лет Октября 12		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47704	5	49	\N	1148	72092	\N	56.043930000000003	Красноярский край, Березовский район, поселок Березовка, Центральная, 27		0101000020E6100000F22213F06B4857401AA88C7F9F054C40
47710	5	49	\N	1148	72486	\N	56.026784999999997	Красноярский край, Березовский район, поселок Березовка, Солнечная, 2А		0101000020E61000002B6D718DCF465740FD82DDB06D034C40
47705	5	49	\N	1148	72482	\N	56.046191999999998	Красноярский край, Березовский район, поселок Березовка, Советская, 47		0101000020E6100000A245B6F3FD4857401DAB949EE9054C40
47858	5	49	\N	1148	72997	\N	56.034899270142603	с.Березовка, Мира, 100		0101000020E61000009AB1683A3B485740E1D4079277044C40
47707	5	49	\N	1148	71727	\N	56.030897299426698	Красноярский край, Березовский район, поселок Березовка, Кирова, 116А	Россия, Красноярский край, поселок Березовка, улица Кирова	0101000020E6100000535A7F4B00485740B345D26EF4034C40
47709	5	49	\N	1148	72083	\N	56.035164999999999	Красноярский край, Березовский район, поселок Березовка, Заводская, 57В		0101000020E6100000AAD4EC81564757405F7B664980044C40
47708	5	49	\N	1148	72181	\N	56.038573999999997	Красноярский край, Березовский район, поселок Березовка, Бружбы, 1В		0101000020E6100000A20BEA5BE6465740EA3C2AFEEF044C40
47596	5	49	\N	1148	72999	\N	56.020254999999999	с. Березовка, ул. Новая, 4		0101000020E6100000BB4560AC6F4757404D4A41B797024C40
48238	5	49	\N	48664	27845	\N	56.232698999999997	п.Бережки, Новая, 9		0101000020E610000051BCCADAA6E85740EC67B114C91D4C40
47713	5	49	\N	13618	71635	\N	56.041023000000003	с. Бархатово, Ленина, 2А		0101000020E6100000F607CA6DFB56574021B1DD3D40054C40
47667	5	49	\N	59628	72591	\N	55.388790449351603	поселок Балахта, Мудрова, 4		0101000020E610000053944BE317E856408481E7DEC3B14B40
49036	5	49	\N	51896	28550	\N	61.6825210685572	с.Байкит, Увачана, 15		0101000020E61000004F948444DA165840A7EA1ED95CD74E40
49037	5	49	\N	51896	72550	\N	61.682862999999998	с.Байкит, Гагарина, 10	Россия	0101000020E6100000790778D2C21658400053060E68D74E40
47098	5	49	\N	3300	\N	\N	56.256087999999998	г.Ачинск, Юго-Восточный микрорайон, 17	Россия, Красноярский край, Ачинск, 2-ой Юго-Восточный микрорайон	0101000020E61000007AC8940F41A05640F372D87DC7204C40
47096	5	49	\N	3300	\N	\N	56.263311442704797	г.Ачинск, микрорайон 6, 18	Россия, Красноярский край, Ачинск, 6-ой микрорайон, 18	0101000020E6100000C99063EB19A05640AAD6C22CB4214C40
47083	5	49	\N	3300	\N	\N	56.257323	г.Ачинск, 3 микрорайон Привокзального района, 17 А	Россия, Красноярский край, Ачинск	0101000020E610000035D42824999F56401AC1C6F5EF204C40
47094	5	49	\N	3300	72381	\N	56.268711000000003	г.Ачинск, микрорайон 8, 3		0101000020E61000000798F90E7E9F5640A9893E1F65224C40
41895	5	49	\N	3300	72095	\N	56.259777999999997	г.Ачинск, микрорайон 3, 40		0101000020E6100000AC72A1F2AF9F5640321CCF6740214C40
47065	5	49	\N	3300	72382	\N	56.263646999999999	г.Ачинск, микрорайон 1, 54		0101000020E610000008759142599F56402158552FBF214C40
47097	5	49	\N	3300	28035	\N	56.252492251147501	г.Ачинск, Юго-Восточный микрорайон, 10 А		0101000020E6100000CE5147C7D59F5640354069A851204C40
47107	5	49	\N	3300	27850	\N	56.202882000000002	г.Ачинск, пос.Мазульский, Чернявского, 13		0101000020E6100000361D01DC2C9656403A799109F8194C40
47100	5	49	\N	3300	72386	\N	56.244219999999999	г.Ачинск, Чайковского, 17		0101000020E6100000BD5296218EA15640BA83D899421F4C40
47091	5	49	\N	3300	72722	\N	56.277458000000003	г.Ачинск, Трудовых резервов, 5		0101000020E61000004948A46DFCA05640BD0166BE83234C40
47110	5	49	\N	3300	72223	\N	56.263706999999997	г.Ачинск, Свердлова, 88		0101000020E6100000B4C70BE9F09E5640F65CA626C1214C40
47099	5	49	\N	3300	72221	\N	56.248406000000003	г.Ачинск, Республики, 7		0101000020E6100000800EF3E505A05640AA108FC4CB1F4C40
47092	5	49	\N	3300	72099	\N	56.277403	г.Ачинск, Партизанская, 37		0101000020E6100000DEE8633E20A05640F96706F181234C40
47090	5	49	\N	3300	72385	\N	56.282299999999999	г.Ачинск, Омская, 27		0101000020E61000002D7B12D89CA1564095D4096822244C40
47089	5	49	\N	3300	72220	\N	56.289096000000001	г.Ачинск, Льва Толстого, 26		0101000020E610000054AA44D95BA05640C4B3041901254C40
47101	5	49	\N	3300	72101	\N	56.254021999999999	г.Ачинск, Кравченко, 34		0101000020E6100000569A94826E9E5640753BFBCA83204C40
47093	5	49	\N	3300	72093	\N	56.277973000000003	г.Ачинск, Комсомольская, 7		0101000020E6100000B745990D32A05640E415889E94234C40
47088	5	49	\N	3300	72219	\N	56.298147	г.Ачинск, Кирова, 1		0101000020E6100000B8CA13083BA0564044334FAE29264C40
47086	5	49	\N	3300	72219	\N	56.301788000000002	г.Ачинск, Кирова, 32		0101000020E6100000F8FA5A971AA15640A2293BFDA0264C40
47106	5	49	\N	3300	72222	\N	56.247041000000003	г.Ачинск, Калинина, 15		0101000020E6100000E1B54B1B0E9E5640B5E21B0A9F1F4C40
47104	5	49	\N	3300	72222	\N	56.247960999999997	г.Ачинск, Калинина, 8 А		0101000020E6100000F488D1730B9E56407BD7A02FBD1F4C40
47085	5	49	\N	3300	72218	\N	56.298611999999999	г.Ачинск, Дружбы Народов, 8		0101000020E6100000C9022670EBA15640B91803EB38264C40
47105	5	49	\N	3300	72387	\N	56.249687000000002	г.Ачинск, Декабристов, 33		0101000020E6100000333674B33F9E5640419E5DBEF51F4C40
47103	5	49	\N	3300	72081	\N	56.254302000000003	г.Ачинск, Гагарина, 27		0101000020E6100000307F85CC959E564059A7CAF78C204C40
47102	5	49	\N	3300	72081	\N	56.250836999999997	г.Ачинск, Гагарина, 20		0101000020E61000008DD47B2AA79E564039D0436D1B204C40
43232	5	49	\N	3300	72081	\N	56.252217000000002	г.Ачинск, Гагарина, 22		0101000020E610000007D2C5A6959E5640643F8BA548204C40
47087	5	49	\N	3300	72705	\N	56.309463999999998	г.Ачинск, Береговая, 44		0101000020E61000003AE97DE36BA0564009A52F849C274C40
43450	5	49	\N	3300	72536	\N	56.252536999999997	г.Ачинск, микрорайон 5, 15		0101000020E6100000A663CE33F69E5640D503E62153204C40
43203	5	49	\N	3300	72565	\N	56.256098000000001	г.Ачинск, микрорайон 4, 30		0101000020E6100000B8019F1F469F56401749BBD1C7204C40
41841	5	49	\N	3300	72549	\N	56.258642999999999	г.Ачинск, микрорайон 3, 38		0101000020E6100000791F4773649F56406F2BBD361B214C40
47108	5	49	\N	3300	71486	\N	56.257323	г. Ачинск, 3 микрорайон Привокзального района, 17 А		0101000020E610000035D42824999F56401AC1C6F5EF204C40
47084	5	49	\N	3300	28173	\N	56.2577517229265	г.Ачинск, 3 микрорайон Привокзального района, 36 А	Россия, Красноярский край, Ачинск, 3-ий микрорайон, 36	0101000020E6100000BAA0BE654E9F5640433D7D04FE204C40
47109	5	49	\N	3300	72102	\N	56.259777999999997	г.Ачинск, 3 микрорайон, 40		0101000020E6100000AC72A1F2AF9F5640321CCF6740214C40
41640	5	49	\N	3300	28518	\N	56.259723000000001	г.Ачинск, микрорайон 2, 17	Россия, Красноярский край, Ачинск, 2-ой микрорайон, 17	0101000020E6100000744012F6ED9E56406F826F9A3E214C40
48389	5	49	\N	59643	72626	\N	54.347079000000001	Красноярский край, Курагинский район, г. Артёмовск, Ольховская, 46		0101000020E61000003B730F09DF5B57406F10AD156D2C4B40
48190	5	49	\N	4815	28097	\N	56.257187999999999	с.Анцирь, Советская, 48		0101000020E61000001DAED51EF6E157403A765089EB204C40
49053	5	49	7119	59857	73126	\N	60.267840523879798	п.Оскоба, Лесная, 6		0101000020E610000032384A5E9D1F594093C3279D48224E40
49030	5	49	7119	51883	28499	\N	55.007731	поселок Эконда, Максима Ялогира, 7А		0101000020E61000007C2C7DE8828457402B155454FD804B40
49034	5	49	7119	59817	73080	\N	63.815199797966699	поселок Учами, Таежная, 1		0101000020E610000066C1C41F451C58407FD93D7958E84F40
49035	5	49	7119	59911	73344	\N	64.214751000000007	поселок Тутончаны, Набережная, 5	Россия	0101000020E6100000D4D688601C7357402272FA7ABE0D5040
49027	5	49	7119	59820	73083	\N	64.279872769367401	поселок городского типа Тура, Нефтяников, 2 Д	Россия	0101000020E6100000E10D6954E00E594023827170E9115040
49042	5	49	7119	51754	27857	\N	55.007731	п.Полигус с входящим в состав поселения населенным пунктом Учами, Бояки, 1		0101000020E61000007C2C7DE8828457402B155454FD804B40
49033	5	49	7119	51831	28235	\N	64.128635209718198	Красноярский край, Эвенкийский район. поселок Нидым, 70 лет Октября, 8	Россия	0101000020E6100000310917F208FB5840BE874B8E3B085040
49046	5	49	7119	59854	73122	\N	60.312748999999997	с.Мирюга Лесная, 1А	Россия	0101000020E6100000BAD8B45208D85840A86DC32808284E40
49044	5	49	7119	59797	73056	\N	60.9567768645217	п.Куюмба, Солнечная, 19		0101000020E61000004F401361C33E5840524832AB777A4E40
49049	5	49	7119	59717	72822	\N	60.348184000000003	с.Ванавара, Спортивная, 11	Россия	0101000020E6100000A5A487A1D5915940C87E164B912C4E40
49041	5	49	7119	59872	73153	\N	61.818779722078297	п.Бурный, Таежная, 9		0101000020E61000005D363AE7A7285740374F75C8CDE84E40
49038	5	49	7119	59640	73175	\N	61.684640999999999	с.Байкит, Центральная, 10	Россия	0101000020E6100000B073D3669C1658401840F850A2D74E40
48930	5	49	994	8427	73315	\N	53.330074000000003	662710 Шушенский район, поселок Шушенское Тельмана 3	Россия, Красноярский край, Шушенский район, поселок городского типа Шушенское	0101000020E610000089EE59D768FC564045A165DD3FAA4A40
48923	5	49	994	8427	73310	\N	53.330074000000003	Шушенский район, поселок Шушенское Первомайская 1	Россия, Красноярский край, Шушенский район, поселок городского типа Шушенское	0101000020E610000089EE59D768FC564045A165DD3FAA4A40
48922	5	49	994	59878	73168	\N	52.725265999999998	662710 Шушенский район, поселок Шушенское квартал Строителей 1		0101000020E6100000378DEDB5A0DF56404B732B84D55C4A40
48921	5	49	994	59878	73288	\N	53.330074000000003	662710 Шушенский район, поселок Шушенское квартал СХТ 20		0101000020E610000089EE59D768FC564045A165DD3FAA4A40
48928	5	49	994	59878	73269	\N	53.3317672234474	662710 Шушенский район, поселок Шушенское Полукольцевая 6	Россия, Красноярский край, Шушенский район, поселок городского типа Шушенское	0101000020E6100000B1C22D1F49FC56402E724F5777AA4A40
48925	5	49	994	59878	73320	\N	53.330074000000003	662710 Шушенский район, поселок Шушенское Победы 3а		0101000020E610000089EE59D768FC564045A165DD3FAA4A40
48924	5	49	994	59878	73320	\N	53.330074000000003	Шушенский район, поселок Шушенское Победы 3а		0101000020E610000089EE59D768FC564045A165DD3FAA4A40
48926	5	49	994	59878	73330	\N	53.333154450202102	Шушенский район, поселок Шушенское Новая 2		0101000020E61000004FAF946588FC56400B444FCAA4AA4A40
48927	5	49	994	59878	73292	\N	53.330074000000003	662710 Шушенский район, поселок Шушенское 2 микрорайон 27		0101000020E610000089EE59D768FC564045A165DD3FAA4A40
48929	5	49	994	59878	73230	\N	53.330074000000003	662710 Шушенский район, поселок Шушенское 1 микрорайон 12		0101000020E610000089EE59D768FC564045A165DD3FAA4A40
48939	5	49	994	32605	73190	\N	53.127127000000002	Шушенский район, Каптыревский сельсовет, с.Шунеры Победы 28		0101000020E610000029B4ACFBC7E5564024B891B245904A40
48940	5	49	994	32612	73231	\N	53.098236999999997	Шушенский район, Каптыревский сельсовет, п.Шарып Большая 24		0101000020E6100000562DE92807E85640EA20AF07938C4A40
48945	5	49	994	32640	73146	\N	53.073281000000001	Шушенский район, Субботинский сельсовет,с.Субботино Ленина 22		0101000020E6100000D61BB5C2F4FA56408735954561894A40
48947	5	49	994	32652	73203	\N	53.038642000000003	Шушенский район, Субботинский сельсовет, с.Средняя Шушь Ленина 34		0101000020E61000005A9C31CC09FE564043209738F2844A40
48954	5	49	994	32717	73240	\N	53.484551000000003	Шушенский район, Синеборский сельсовет, п.Синеборск Ленина 24		0101000020E6100000FF93BF7B470657403F1F65C405BE4A40
48944	5	49	994	32634	73251	\N	53.000697000000002	Шушенский район, Сизинский сельсовет, с.Сизая Ленина 40		0101000020E6100000FDDD3B6A4CE15640481ADCD616804A40
48941	5	49	994	32617	73248	\N	53.139137219446901	Шушенский район, Каптыревский сельсовет, с.Саянск Малая 37	Россия, Красноярский край, Шушенский район, поселок Саянск	0101000020E61000006BB75D68AEDE5640EF54C03DCF914A40
48613	5	49	994	32619	27824	\N	53.144720318514402	деревня Новопокровка, Шинкарева, 23	Россия, Красноярский край, Шушенский район, поселок Новопокровка	0101000020E61000007D2079E750EC5640DF89592F86924A40
48942	5	49	994	32619	73233	\N	53.148461524191397	Шушенский район, Каптыревский с\\с, с.Новопокровка Большая 50	Россия, Красноярский край, Шушенский район, поселок Новопокровка	0101000020E61000002C9E7AA4C1EC5640715985CD00934A40
48951	5	49	994	32684	73229	\N	53.456294	Шушенский район, Казанцевский сельсовет, д.Нижняя Коя Центральная 36		0101000020E610000071732A1900FB564036AE7FD767BA4A40
48946	5	49	994	32645	73179	\N	53.031683644579999	Шушенский район, Субботинский сельсовет, п.Майский Центральная 27/2	Россия, Красноярский край, Шушенский район, поселок Майский	0101000020E61000006117450F7CF756403AE7A7380E844A40
48952	5	49	994	32690	73191	\N	53.501651000000003	Шушенский район, Казанцевский сельсовет, д.Лыткино Советская 26		0101000020E610000090A2CEDC43025740BB80971936C04A40
48948	5	49	994	32659	73236	\N	53.050579999999997	Шушенский район, Субботинский сельсовет, д.Ленск Ленина 49		0101000020E6100000FE0A992B83F4564074EACA6779864A40
49055	5	49	994	32693	73170	\N	53.395539999999997	Шушенский район, Казанцевский сельсовет, д.Козлово Центральная 8		0101000020E61000006075E448670357404221020EA1B24A40
48938	5	49	994	32599	73161	\N	53.197771000000003	Шушенский район, Каптыревский сельсовет,с.Каптырево Малая 19		0101000020E61000007380608E1EF35640728C648F50994A40
48950	5	49	994	59906	73307	\N	53.407893000000001	Шушенский район, Казанцевский сельсовет Ленина 40	Россия, Красноярский край, Шушенский район, поселок Казанцево	0101000020E6100000E674594C6C00574038A27BD635B44A40
48931	5	49	994	32559	73215	\N	53.273333999999998	Шушенский район, Ильичевский сельсовет, п.Ильичево Кирова 10а		0101000020E61000004774CFBA46F656404371C79BFCA24A40
48943	5	49	994	32630	73197	\N	53.182189999999999	Шушенский район, Иджинский сельсовет, с.Иджа Большая 34		0101000020E61000001EA4A7C821FE564041D47D0052974A40
48932	5	49	994	9006	73266	\N	53.244618000000003	Шушенский район, Ильичевский сельсовет, п.Зарничный Ленина 2а		0101000020E610000087A3AB7477FE5640A80183A44F9F4A40
48934	5	49	994	32582	73242	\N	53.234599000000003	Шушенский район, Ильичевский сельсовет, д.Ермолаево Центральная 24		0101000020E6100000581F0F7D7700574050560C57079E4A40
48955	5	49	994	32721	73258	\N	53.466855000000002	Шушенский район, Синеборский сельсовет, с.Дубенское Октябрьская 25а		0101000020E6100000124C35B396135740AF7C96E7C1BB4A40
48956	5	49	994	32733	73211	\N	53.448791999999997	Шушенский район, Синеборский сельсовет, п.Веселые Ключи Комсомольская 6		0101000020E61000009752978C631757406C5A290472B94A40
48949	5	49	994	32670	73282	\N	53.092078000000001	Шушенский район, Субботинский сельсовет, д.Белозеровка Ленина 19		0101000020E6100000DD0BCC0A45EF56402E573F36C98B4A40
48936	5	49	994	9090	73205	\N	53.240662	Шушенский район, Ильичевский сельсовет, п.Алтан Школьная 7б		0101000020E610000067B62BF4C1F85640EAB12D03CE9E4A40
48907	5	49	566	7740	28032	\N	55.598776999999998	с.Шушь, Октябрьская, 12	Россия, Красноярский край, Шарыповский район, поселок Шушь	0101000020E6100000CBBBEA01F35C56406A4C88B9A4CC4B40
47527	5	49	566	4113	\N	\N	55.537652999999999	Красноярский край, город Шарыпово, Пионерный микрорайон, 4	Россия, Красноярский край, Шарыповский район, город Шарыпово	0101000020E6100000009013268C4B564053CC41D0D1C44B40
47522	5	49	566	4113	\N	\N	55.537652999999999	Красноярский край, город Шарыпово, 3 микрорайон, 32	Россия, Красноярский край, Шарыповский район, город Шарыпово	0101000020E6100000009013268C4B564053CC41D0D1C44B40
47520	5	49	566	4113	71506	\N	55.537652999999999	Красноярский край, город Шарыпово, переулок Школьный, 1		0101000020E6100000009013268C4B564053CC41D0D1C44B40
47530	5	49	566	4113	28091	\N	55.537652999999999	Красноярский край, город Шарыпово, п. Дубинино, Шахтерская, 26		0101000020E6100000009013268C4B564053CC41D0D1C44B40
47525	5	49	566	4113	71543	\N	55.537652999999999	Красноярский край, город Шарыпово, Северный микрорайон, 3		0101000020E6100000009013268C4B564053CC41D0D1C44B40
47526	5	49	566	4113	27763	\N	55.537652999999999	Красноярский край, город Шарыпово, Пионерный микрорайон, 52		0101000020E6100000009013268C4B564053CC41D0D1C44B40
47531	5	49	566	4113	28225	\N	55.537652999999999	Красноярский край, город Шарыпово, п. Дубинино, Комсомольская, 28А		0101000020E6100000009013268C4B564053CC41D0D1C44B40
47518	5	49	566	4113	71526	\N	55.537652999999999	Красноярский край, город Шарыпово, Кирова, 9		0101000020E6100000009013268C4B564053CC41D0D1C44B40
48910	5	49	566	7815	\N	\N	55.457647999999999	с.Холмогорское, мкр-он. Энергетик, 1	Россия, Красноярский край, Шарыповский район, поселок Холмогорское	0101000020E61000005952EE3EC7475640378AAC3594BA4B40
48909	5	49	566	7815	28471	\N	55.457647999999999	с.Холмогорское, Центральная, 12	Россия, Красноярский край, Шарыповский район, поселок Холмогорское	0101000020E61000005952EE3EC7475640378AAC3594BA4B40
48913	5	49	566	8031	27781	\N	55.434303	с.Темра, Калинина, 76А		0101000020E6100000C11DA8531E51564000C79E3D97B74B40
48509	5	49	566	20505	72939	\N	55.8949186777824	"д. Сютик, Советская, 2 ""А"""	Россия, Красноярский край, Шарыповский район, поселок Сютик	0101000020E61000002B4EB51666705640D6C8AEB48CF24B40
48897	5	49	566	7319	72980	\N	55.792873	д.Скрипачи, Школьная, 9А		0101000020E6100000C68844A165585640D270CADC7CE54B40
48865	5	49	566	5698	28242	\N	55.248745	д.Сартачуль, Набережная, 1	Россия, Красноярский край, Шарыповский район, поселок Сартачуль	0101000020E6100000DC8310902F4E564092054CE0D69F4B40
48903	5	49	566	48226	72863	\N	55.691023999999999	д.Росинка, Центральная, 12		0101000020E6100000D7C1C1DEC45556402460747973D84B40
48802	5	49	566	33057	72677	\N	55.642567956392	с.Родники, Октябрьская, 17	Россия, Красноярский край, Шарыповский район, поселок Родники	0101000020E6100000A7EB89AE0B4D564062BA10AB3FD24B40
48916	5	49	566	8176	72648	\N	55.287906	с.Парная, Советская, 8А		0101000020E610000013B69F8CF14E56403D29931ADAA44B40
48918	5	49	566	8280	28467	\N	55.325595	с.Ораки, Центральная, 25а		0101000020E6100000E2C96E66F4605640DD5ED218ADA94B40
48895	5	49	566	7176	28469	\N	55.724454000000001	с Новоалтатка, Советская, 1В		0101000020E61000004DA1F31ABB5E56406BBA9EE8BADC4B40
48902	5	49	566	51880	28492	\N	55.695367563298802	с.Никольск, Октябрьская, 34	Россия, Красноярский край, Шарыповский район, поселок Никольск	0101000020E610000024438EAD674A5640AC5791D101D94B40
48908	5	49	566	7803	72927	\N	55.504761000000002	д.Можары, Центральная, 19		0101000020E61000000B410E4A98655640ECA529029CC04B40
48914	5	49	566	48427	72869	\N	55.384256999999998	д.Линево, Кирова, 14Б		0101000020E6100000B517D1764C455640292158552FB14B40
48899	5	49	566	48138	28454	\N	55.722988999999998	п.Крутоярский, Центральная, 19а		0101000020E610000028999CDA19685640122F4FE78ADC4B40
48917	5	49	566	8258	72981	\N	55.375658999999999	д.Косые Ложки, Центральная, 30		0101000020E6100000973AC8EBC14D56405AB9179815B04B40
48905	5	49	566	7673	28497	\N	55.516731	п.Инголь, кв-л. Путейский, 28А		0101000020E610000012DBDD03742D564029EACC3D24C24B40
48904	5	49	566	7610	28113	\N	55.568812000000001	Красноярский край, Шарыповский район , Ивановский сельсовет,с.Ивановка ул.Строителей (здание Ивановского сельсовета) д.1-А		0101000020E61000004777103B5332564043C9E4D4CEC84B40
48891	5	49	566	47983	28074	\N	55.947505	д.Ершово, Садовая, 1В		0101000020E6100000FA2B64AE0C595640F3E505D847F94B40
48901	5	49	566	7462	28489	\N	55.625166	Красноярский край, Шарыповский район ,Родниковский сельсовет ,с.Дубинино ул.Школьная (здание СОШ №13) д.1	Россия, Красноярский край, Шарыповский район, поселок городского типа Дубинино	0101000020E6100000630E828E564656401B49827005D04B40
47528	5	49	566	7462	28489	\N	55.627836211958197	Красноярский край, город Шарыпово, п. Дубинино, Школьная, 4		0101000020E610000029931ADA0046564030A017EE5CD04B40
47529	5	49	566	7462	27782	\N	55.624484872018201	Красноярский край, город Шарыпово, п. Дубинино, Олега Кошевого, 16	Россия, Красноярский край, Шарыповский район, поселок городского типа Дубинино	0101000020E6100000EB55647440465640D9EBDD1FEFCF4B40
48892	5	49	566	7029	72979	\N	55.895297999999997	д..Гудково, Южная, 2		0101000020E6100000C993A46B266756404C16F71F99F24B40
49068	5	49	566	59650	72646	\N	55.399709000000001	Красноярский край, город Шарыпово, п. Горячегорск, Центральная, 7	Россия, Красноярский край, Шарыповский район, поселок городского типа Горячегорск	0101000020E6100000D49CBCC8043A56405C751DAA29B34B40
48894	5	49	566	7152	28635	\N	55.763756000000001	Красноярский край, Шарыповский район, Березовский сельсовет, д.Горбы ул.Центральная  (здание СОШ №12) д.28, помещение 1		0101000020E61000002A029CDEC56E5640D80FB1C1C2E14B40
48912	5	49	566	59875	73156	\N	55.493615191506997	д.Гляден, Новая, 2	Россия, Красноярский край, Шарыповский район, поселок Гляден	0101000020E61000003D484F914353564053E8BCC62EBF4B40
48898	5	49	566	7327	28098	\N	55.769221000000002	д.Глинка, Центральная, 2А		0101000020E6100000CE6F986890615640BE326FD575E24B40
48919	5	49	566	59753	73002	\N	55.188747280638502	с.Большое Озеро, Советская, 1	Россия, Красноярский край, Шарыповский район, поселок Большое Озеро	0101000020E6100000E0A0BDFA78545640EB1B98DC28984B40
48915	5	49	566	8105	28136	\N	55.485284999999998	с.Береш, Школьная, 11А	Россия, Красноярский край, Шарыповский район, поселок Береш	0101000020E6100000C2189128B4495640A31EA2D11DBE4B40
48890	5	49	566	6932	28468	\N	55.846710216221297	с.Берёзовское, Просвещения, 3	Россия, Красноярский край, Шарыповский район, поселок Березовское	0101000020E6100000CD0182397A6556401C9947FE60EC4B40
48900	5	49	566	48159	28302	\N	55.650165000000001	д.Белоозерка, Центральная, 28	Россия, Красноярский край, Шарыповский район, поселок Белоозерка	0101000020E61000001BF2CF0CE26256407E00529B38D34B40
47869	5	49	566	45910	28363	\N	55.802796000000001	д.Александровка, Центральная, 49		0101000020E61000006878B306EF6F564008AEF204C2E64B40
48893	5	49	566	45910	72918	\N	55.803364168992097	д.Александровка, Свободная, 24а-1	Россия, Красноярский край, Шарыповский район, поселок Александровка	0101000020E61000004298DBBDDC6F56405264ADA1D4E64B40
48911	5	49	566	7953	28187	\N	55.546047999999999	с.Ажинское, Комсомольская, 1А		0101000020E6100000791F4773644D5640EA059FE6E4C54B40
48876	5	49	729	5070	\N	\N	55.805022000000001	Красноярский край, Уярский район, Толстихинский сельсовет, Ленина, 11	Россия, Красноярский край, Уярский район, город Уяр	0101000020E61000001651137D3E945740BF47FDF50AE74B40
48854	5	49	729	5070	28147	\N	55.805022000000001	Красноярский край, Уярский район, .город Уяр, Уланова, 19	Россия, Красноярский край, Уярский район, город Уяр	0101000020E61000001651137D3E945740BF47FDF50AE74B40
48861	5	49	729	5070	27897	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Ленина, 172, корп. 6		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48858	5	49	729	5070	27897	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Ленина, 72		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48855	5	49	729	5070	27897	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Ленина, 83		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48866	5	49	729	5070	28622	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Красных Партизан, 81		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48862	5	49	729	5070	28616	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Интернациональная, 67а		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48860	5	49	729	5070	27668	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Дзержинского, 221	Россия, Красноярский край, Уярский район, город Уяр	0101000020E61000001651137D3E945740BF47FDF50AE74B40
48863	5	49	729	5070	72675	\N	55.814208469090097	Красноярский край, Уярский район, город Уяр, Громовой, 7	Россия, Красноярский край, Уярский район, город Уяр	0101000020E61000003A950C00559557401F12BEF737E84B40
48857	5	49	729	5070	28206	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, Герцена, 46		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48859	5	49	729	5070	28233	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, 30 лет ВЛКСМ, 131		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48856	5	49	729	5070	28233	\N	55.805022000000001	Красноярский край, Уярский район, город Уяр, 30 лет ВЛКСМ, 59		0101000020E61000001651137D3E945740BF47FDF50AE74B40
48674	5	49	729	28218	73003	\N	55.808725000000003	Красноярский край, Рыбинский район, деревня Татьяновка, Трактовая, 29		0101000020E6100000F31E679AB0A65740933A014D84E74B40
48873	5	49	729	51741	27789	\N	55.779583966922303	Красноярский край, Уярский район, Сушиновский сельсовет, Школьная, 5	Россия, Красноярский край, Уярский район, поселок Сушиновка	0101000020E6100000C0CDE2C5C28D5740103E9468C9E34B40
48888	5	49	729	59834	73101	\N	55.608794255261799	Красноярский край, Уярский район, Сухонойский сельсовет, Механизаторов, 20	Россия, Красноярский край, Уярский район, поселок Сухоной	0101000020E61000001BF5108DEE8A5740220038F6ECCD4B40
48875	5	49	729	6213	\N	\N	55.700994000000001	Красноярский край, Уярский район, с. Семеновка, клуб		0101000020E61000002CF4C132368A57409B58E02BBAD94B40
48887	5	49	729	6834	\N	\N	55.721442000000003	Красноярский край, Уярский район, д. Покровка, Клуб		0101000020E6100000B2B96A9E23A35740FDFA213658DC4B40
48884	5	49	729	6664	\N	\N	55.866894000000002	Красноярский край, Уярский район, c. Ольгино, Клуб	Россия, Красноярский край, Уярский район, поселок Ольгино	0101000020E61000008A9466F338935740A08CF161F6EE4B40
48881	5	49	729	32942	72654	\N	55.853812528107603	Красноярский край, Уярский район, Новопятницкий сельсовет, Центральный, 5	Россия, Красноярский край, Уярский район, поселок Новопятницкое	0101000020E6100000419E5DBEF59E574028F38FBE49ED4B40
48877	5	49	729	6310	\N	\N	55.628006999999997	Красноярский край, Уярский район, д. Новониколаевка, клуб	Россия, Красноярский край, Уярский район, поселок Новониколаевка	0101000020E61000009BAF928FDD9757405C548B8862D04B40
48874	5	49	729	6161	\N	\N	55.779783000000002	Красноярский край, Уярский район, д. Новомихайловка, Клуб		0101000020E6100000ED9BFBABC7865740077DE9EDCFE34B40
48883	5	49	729	6638	\N	\N	55.865257999999997	Красноярский край, Уярский район, д. Новоалександровка, Клуб	Россия, Красноярский край, Уярский район, поселок Новоалександровка	0101000020E6100000F1D93A38D8A057401A4D2EC6C0EE4B40
48870	5	49	729	5940	72856	\N	55.898947	Красноярский край, Уярский район, с. Никольское, Школьная, 7		0101000020E6100000F4C29D0B238257402DEBFEB110F34B40
48878	5	49	729	6347	\N	\N	55.713045000000001	Красноярский край, Уярский район, д. Николаевка, Клуб	Россия, Красноярский край, Уярский район, поселок Николаевка	0101000020E6100000DD611399B9985740C5C9FD0E45DB4B40
48871	5	49	729	5992	28447	\N	55.850721999999998	Красноярский край, Уярский район, д. Марьевка, Ленина, 9		0101000020E6100000CEFBFF38618957406DFE5F75E4EC4B40
48872	5	49	729	6021	\N	\N	55.885762315314203	Красноярский край, Уярский район, д. Каменно-Горновка, Клуб	Россия, Красноярский край, Уярский район, поселок Каменно-Горновка	0101000020E61000000F98874CF98B5740100533A660F14B40
48869	5	49	729	5895	27726	\N	55.890411	Красноярский край, Уярский район, п. Жандат, Ленина, 3		0101000020E6100000A26131EA5A7B5740D47FD6FCF8F14B40
48885	5	49	729	59642	72625	\N	55.898099825426897	Красноярский край, Уярский район, Громадский сельсовет, Железнодорожная, 6	Россия, Красноярский край, Уярский район, поселок Громадск	0101000020E6100000D80B056C079A5740D044D8F0F4F24B40
48879	5	49	729	59777	73030	\N	55.624179629973199	Красноярский край, Уярский район, Восточный сельсовет, Советская, 1		0101000020E610000047CB811E6A9F57409D685721E5CF4B40
48880	5	49	729	6448	\N	\N	55.669660999999998	Красноярский край, Уярский район, д. Воронино, Клуб		0101000020E6100000D74D29AF95A357400D349F73B7D54B40
48867	5	49	729	40267	9684	\N	55.869196802202403	Красноярский край, Уярский район, Балайский сельсовет, Ленина, 34	Россия, Красноярский край, Уярский район, поселок Балай	0101000020E6100000DAFF006BD57F57400264E8D841EF4B40
48886	5	49	729	59811	73074	\N	55.737921999999998	Красноярский край, Уярский район, Авдинский сельсовет, Юбилейная, 6	Россия, Красноярский край, Уярский район, поселок Авда	0101000020E6100000B7EF517FBDA75740DC7F643A74DE4B40
48834	5	49	476	4004	72978	\N	55.500478000000001	Красноярский край, Ужурский район, д. Яга, Советская, 10		0101000020E610000021B07268919056400A2FC1A90FC04B40
48837	5	49	476	4187	28038	\N	55.184012000000003	Красноярский край, Ужурский район, д. Черноозерск, Школьная, 5		0101000020E6100000643E20D0998D5640290989B48D974B40
48960	5	49	476	10272	72850	\N	55.570655000000002	Красноярский край, Ужурский район, д. Ушканка, Главная, 3		0101000020E61000008A5A9A5B218E5640422619390BC94B40
48829	5	49	476	3737	28416	\N	55.498596999999997	Красноярский край, Ужурский район, д. Усть-Изыкчуль, Центральная, 6	Россия, Красноярский край, Ужурский район, поселок Усть-Изыкчуль (Марьясово)	0101000020E6100000B4722F302B8156401D71C806D2BF4B40
48814	5	49	476	2845	28485	\N	55.316282999999999	Красноярский край, Ужурский район, город Ужур, Советская, 50		0101000020E6100000317C444C89755640F0A31AF67BA84B40
48816	5	49	476	2845	28044	\N	55.316282999999999	Красноярский край, Ужурский район, город Ужур, Кирова, 30		0101000020E6100000317C444C89755640F0A31AF67BA84B40
48820	5	49	476	2845	28031	\N	55.316282999999999	Красноярский край, Ужурский район, город Ужур, Вокзальная, 2		0101000020E6100000317C444C89755640F0A31AF67BA84B40
48819	5	49	476	2845	28031	\N	55.3118265888167	Красноярский край, Ужурский район, город Ужур Вокзальная 34	Россия, Красноярский край, Ужурский район, город Ужур	0101000020E6100000F981AB3C81755640418177F2E9A74B40
48849	5	49	476	4829	72852	\N	55.131759000000002	Красноярский край, Ужурский район, д. Тургужан, Школьная, 31		0101000020E61000003C2EAA454480564012FA997ADD904B40
48833	5	49	476	3961	28656	\N	55.432504999999999	Красноярский край, Ужурский район, д. Терехта, Крупской, 1		0101000020E61000001764CBF2758C5640A12DE7525CB74B40
48836	5	49	476	4112	72972	\N	55.595689	Красноярский край, Ужурский район, д. Тарханка, Советская, 6А	Россия, Красноярский край, Ужурский район, поселок Тарханка	0101000020E61000006F10AD156D9D564021CB82893FCC4B40
48961	5	49	476	10294	28523	\N	55.277799999999999	Красноярский край, Ужурский район, д. Тальники, Школьная, 9		0101000020E61000004BCD1E6805A95640166A4DF38EA34B40
48958	5	49	476	10136	72787	\N	55.593716000000001	Красноярский край, Ужурский район, Сухореченск, Садовая, 1	Россия, Красноярский край, Ужурский район, поселок Сухореченский	0101000020E610000015A8C5E061855640548EC9E2FECB4B40
48851	5	49	476	4948	28583	\N	55.233367000000001	Красноярский край, Ужурский район, д. Сухая Долина, Российская, 18		0101000020E61000003A765089EB7156409A7B48F8DE9D4B40
48838	5	49	476	4236	72970	\N	55.218558999999999	Красноярский край, Ужурский район, д. Старая Кузурба, Новая, 22		0101000020E61000002BBEA1F0D99656408C9FC6BDF99B4B40
47590	5	49	476	51778	28554	\N	55.280600521270401	Красноярский край, Ужурский район, ЗАТО п. Солнечный, Неделина М.И, 10б	Россия, Красноярский край, Ужурский район, поселок городского типа Солнечный	0101000020E6100000EC2FBB270F745640C91CCBBBEAA34B40
47588	5	49	476	51778	27961	\N	55.283812839014203	Красноярский край, Ужурский район, ЗАТО Солнечный, Неделина М.И, 35	Россия, Красноярский край, Ужурский район, поселок городского типа Солнечный	0101000020E610000071AAB5300B755640FF9600FC53A44B40
47587	5	49	476	51778	27961	\N	55.281069391256999	Красноярский край, Ужурский район, ЗАТО Солнечный, Неделина М.И, 10а	Россия, Красноярский край, Ужурский район, поселок городского типа Солнечный	0101000020E610000073B8567BD8745640B075A911FAA34B40
47589	5	49	476	59573	72007	\N	55.282266228446503	Красноярский край, Ужурский район, ЗАТО п. Солнечный, Солнечная, 16 стр.1	Россия, Красноярский край, Ужурский район, поселок городского типа Солнечный	0101000020E61000004BE5ED08A7745640E962D34A21A44B40
48835	5	49	476	4065	71624	\N	55.527152999999998	Красноярский край, Ужурский район, с. Солгон, Совхозная, 4		0101000020E6100000F1B913ECBF985640807EDFBF79C34B40
48852	5	49	476	4968	72973	\N	55.174613999999998	Красноярский край, Ужурский район, д. Солбатский, Мира, 11 А		0101000020E61000009E45EF54C06D56403DB665C059964B40
48842	5	49	476	4421	28063	\N	55.21011	Красноярский край, Ужурский район, с. Приреченск, Октябрьская, 3	Россия, Красноярский край, Ужурский район, поселок Приреченск	0101000020E6100000F25F20089091564002486DE2E49A4B40
48848	5	49	476	59803	73065	\N	55.170479999999998	Красноярский край, Ужурский район, Прилужский сельсовет, Садовая, 1	Россия, Красноярский край, Ужурский район, поселок Прилужье	0101000020E6100000321F10E84C765640A04FE449D2954B40
48853	5	49	476	5029	72716	\N	55.078373183812097	"Красноярский край, Ужурский район, с. Курорт ""Озеро Учум"", Почтовая, 5"	Россия, Красноярский край, Ужурский район, поселок Озеро Учум	0101000020E61000001FB935E9B66C5640D8F15F20088A4B40
48828	5	49	476	3731	27858	\N	55.584355000000002	Красноярский край, Ужурский район, д. Новоракитка, Победы, 7	Россия, Красноярский край, Ужурский район, поселок Новоракитка	0101000020E6100000E2AB1DC53989564086200725CCCA4B40
48846	5	49	476	4679	72974	\N	55.257817000000003	Красноярский край, Ужурский район, д. Новая Кузурба, Школьная, 8		0101000020E6100000206118B0E48B56402AADBF2500A14B40
48825	5	49	476	3527	27855	\N	55.588526999999999	Красноярский край, Ужурский район, с. Михайловка, Тимирязева, 5		0101000020E61000001096B1A19B79564010E84CDA54CB4B40
47671	5	49	476	11633	72763	\N	55.451896153199698	д.Марьясово, Центральная, 2	Россия, Красноярский край, Ужурский район, поселок Марьясово	0101000020E61000004580D3BB78785640BB9866BAD7B94B40
48839	5	49	476	4285	28422	\N	55.220047999999998	Красноярский край, Ужурский район, с. Малый Имыш, Кооперативная, 2		0101000020E610000058AA0B7899A156406DC669882A9C4B40
48847	5	49	476	4720	9936	\N	55.321595000000002	Красноярский край, Ужурский район, д. Лопатка, Главная, 27		0101000020E61000004818062CB98A564050C763062AA94B40
48823	5	49	476	3429	72603	\N	55.471837000000001	Красноярский край, Ужурский район, с. Локшино, Центральная, 19		0101000020E6100000B3295778976C56407905A22765BC4B40
48821	5	49	476	3327	71626	\N	55.335478999999999	Красноярский край, Ужурский район, с. Кулун, Главная, 18		0101000020E6100000DFFDF15EB571564055BFD2F9F0AA4B40
48826	5	49	476	3624	71521	\N	55.570497000000003	Красноярский край, Ужурский район, с. Крутояр, Главная, 28		0101000020E610000017F032C346805640AABBB20B06C94B40
48824	5	49	476	51904	28592	\N	55.371504999999999	Красноярский край, Ужурский район, д. Корнилово, Школьная, 27	Россия, Красноярский край, Ужурский район	0101000020E6100000EC1516DC0F83564076A6D0798DAF4B40
48845	5	49	476	4620	72976	\N	55.288336999999999	Красноярский край, Ужурский район, с. Ильинка, Главная, 46		0101000020E610000049A297512C825640069D103AE8A44B40
48832	5	49	476	3921	72969	\N	55.4498789760977	Красноярский край, Ужурский район, д. Изыкчуль, Ужурская, 31	Россия, Красноярский край, Ужурский район, поселок Изыкчуль	0101000020E61000009A5DF756248456401F1494A295B94B40
48850	5	49	476	4891	27886	\N	55.132001000000002	Красноярский край, Ужурский район, с. Златоруновск, Мира, 7	Россия, Красноярский край, Ужурский район, поселок Златоруновск	0101000020E6100000E867EA758B7356400805A568E5904B40
48831	5	49	476	3832	\N	\N	55.426437	Красноярский край, Ужурский район, с. Васильевка, Советская, 40	Россия, Красноярский край, Ужурский район, поселок Васильевка	0101000020E61000006BB933130C7A5640F566D47C95B64B40
48840	5	49	476	4314	28057	\N	55.138345999999999	Красноярский край, Ужурский район, с. Большой Имыш, Школьная, 5		0101000020E6100000E42EC214E5A7564026C45C52B5914B40
48841	5	49	476	4401	72771	\N	55.158369	Красноярский край, Ужурский район, д. Березовый Лог, Первомайская, 22		0101000020E61000003D7FDAA84EAA5640A1D9756F45944B40
48843	5	49	476	4502	28423	\N	55.144156000000002	Красноярский край, Ужурский район, д. Белопольск, Красноярская, 1-2	Россия, Красноярский край, Ужурский район, поселок Белопольск	0101000020E61000009E7AA4C16D965640D7C22CB473924B40
48830	5	49	476	59858	73127	\N	55.4974353061831	Красноярский край, Ужурский район, п. Белая Роща, Главная, 11	Россия, Красноярский край, Ужурский район, поселок Белая Роща	0101000020E6100000E318C91EA1755640617138F3ABBF4B40
48822	5	49	476	3413	27852	\N	55.374478000000003	Красноярский край, Ужурский район, д. Ашпан, Школьная, 11		0101000020E6100000EE06D15AD1635640278925E5EEAF4B40
48844	5	49	476	4573	72775	\N	55.08323	Красноярский край, Ужурский район, п. Арабкаево, Промышленная, 1		0101000020E6100000A01518B2BA945640E605D847A78A4B40
48827	5	49	476	3636	\N	\N	55.554353999999996	Красноярский край, Ужурский район, д. Андроново, Молодежная, 4	Россия, Красноярский край, Ужурский район, поселок Андроново	0101000020E610000034F8FBC56C82564011346612F5C64B40
48959	5	49	476	10227	27957	\N	55.621333	Красноярский край, Ужурский район, д. Алексеевка, Звездная, 6		0101000020E61000003126FDBD147D56407976F9D687CF4B40
49029	5	49	336	51825	28221	\N	57.498903033690098	поселок Чиринда, Заполярная, 7	Россия, Красноярский край, Тюхтетский район	0101000020E610000068244223D85956402A70B20DDCBF4C40
48811	5	49	336	2728	28393	\N	57.383768000000003	Красноярский край, Тюхтетский район, Чиндатский сельсовет,с.Чиндат, Центральная, 44, сельский клуб	Россия, Красноярский край, Тюхтетский район, поселок Чиндат	0101000020E6100000F96871C6305356402CA0504F1FB14C40
48792	5	49	336	1606	28484	\N	56.532082000000003	"Красноярский край, Тюхтетский район, Тюхтетский сельсовет, с.Тюхтет, Юбилейная, 1-Б, детский сад ""Солнышко"""	Россия, Красноярский край, Тюхтетский район, поселок Тюхтет	0101000020E6100000DB34B6D782545640286552431B444C40
48791	5	49	336	1606	27972	\N	56.532082000000003	Красноярский край, Тюхтетский район, Тюхтетский сельсовет, с.Тюхтет, Советская, 12, районный Дом культуры	Россия, Красноярский край, Тюхтетский район, поселок Тюхтет	0101000020E6100000DB34B6D782545640286552431B444C40
48809	5	49	336	2619	27939	\N	57.009039000000001	Красноярский край, Тюхтетский район, Верх-Четский сельсовет, п. Сплавной, Трактовая, 17, сельский Дом культуры		0101000020E6100000E43098BF42455640BCB1A03028814C40
48803	5	49	336	2274	28501	\N	56.573926	Красноярский край, Тюхтетский район, Леонтьевский с/с,д.Соловьевка, Боброва, 28-А сельский клуб	Россия, Красноярский край, Тюхтетский район, поселок Соловьёвка	0101000020E610000039D6C56D344E56407C293C6876494C40
48794	5	49	336	1799	28379	\N	56.428862000000002	Красноярский край, Тюхтетский район, Тюхтетский сельсовет, д.Пузаново, Центральная, 17-А, сельский клуб		0101000020E610000096CB46E7FC535640A33F34F3E4364C40
47756	5	49	336	15664	28356	\N	57.503495000000001	п.Проточный, Советская, 7		0101000020E61000000D5531957E7A56408A592F8672C04C40
48793	5	49	336	1695	27833	\N	56.536703000000003	Красноярский край, Тюхтетский район, Тюхтетский сельсовет, д. Покровка, Заречная, 14-Б, сельский клуб	Россия, Красноярский край, Тюхтетский район, поселок Покровка	0101000020E6100000E751F17F474F5640225514AFB2444C40
48810	5	49	336	2707	72774	\N	57.068119000000003	Красноярский край, Тюхтетский район, Поваренкинский с/с,с.Поваренкино, Сибирская, 46, сельский Дом культуры		0101000020E61000009293895B053D56403D9E961FB8884C40
48812	5	49	336	2840	27944	\N	57.436998000000003	Красноярский край, Тюхтетский район, Чиндатский сельсовет, д.Пасечное, Чулымская, 3, сельский Дом культуры	Россия, Красноярский край, Тюхтетский район, поселок Пасечное	0101000020E61000002FC4EA8F305456406E35EB8CEFB74C40
48795	5	49	336	1809	28555	\N	56.434212000000002	Красноярский край, Тюхтетский район, Тюхтетский сельсовет, д.Оскаровка, Колхозная, 20-А, сельский клуб	Россия, Красноярский край, Тюхтетский район, поселок Оскаровка	0101000020E610000051888043A84B5640F0C3414294374C40
48800	5	49	336	2151	72764	\N	56.535581999999998	Красноярский край, Тюхтетский район, Новомитропольский сельсовет, с.Новомитрополька, Советская, 46, сельский Дом кулььтуры		0101000020E6100000B45549641F695640C32973F38D444C40
48801	5	49	336	2169	72983	\N	56.549889	Красноярский край, Тюхтетский район, Новомитропольский сельсовет, д.Никольск, Лесная, 7-1, ФАП		0101000020E6100000E0A0BDFA787256400FB743C362464C40
48804	5	49	336	2384	72849	\N	56.604191	Красноярский край, Тюхтетский район, Леонтьевский с/с, с.Леонтьевка, Центральная, 3, администрация сельсовета		0101000020E61000002158552FBF495640CEC47421564D4C40
48798	5	49	336	2030	28182	\N	56.520802000000003	Красноярский край, Тюхтетский район, Новомитропольский сельсовет, д.Ларневка, Верхняя, 15, сельский клуб		0101000020E61000001842CEFBFF5E564080D8D2A3A9424C40
48797	5	49	336	1929	72756	\N	56.445099999999996	Красноярский край, Тюхтетский район, Лазаревский сельсовет,с.Лазарево, Шахова, 14, администрация сельсовета		0101000020E6100000B84082E2C75C56408CB96B09F9384C40
48807	5	49	336	2503	27848	\N	56.852809000000001	Красноярский край, Тюхтетский район, Красинский сельсовет, с.Красинка, Советская, 8, администрация сельсовета	Россия, Красноярский край, Тюхтетский район, поселок Красинка	0101000020E6100000A16AF46A80585640035E66D8286D4C40
48132	5	49	336	51885	73246	\N	56.569893525091601	с. Ивановка Интернациональная 3	Россия, Красноярский край, Тюхтетский район, поселок Ивановка	0101000020E61000007BDB4C8578465640E3175E49F2484C40
48805	5	49	336	59759	73008	\N	56.584412077564501	Красноярский край, Тюхтетский район, Зареченский сельсоветс.Зареченка, Революции, 33, администрация сельсовета	Россия, Красноярский край, Тюхтетский район, поселок Зареченка	0101000020E610000065E08096AE525640EAB12D03CE4A4C40
48796	5	49	336	1906	28561	\N	56.484596000000003	Красноярский край, Тюхтетский район, Двинский сельсовет, д.Двинка, Советская, 10, администрация сельсовета	Россия, Красноярский край, Тюхтетский район, поселок Двинка	0101000020E610000055849B8C2A3E5640DFE2E13D073E4C40
48808	5	49	336	2602	28647	\N	56.923498000000002	Красноярский край, Тюхтетский район, Верх-Четский сельсовет, п.Верх-Четск, Советская, 6, сельский Дом культуры		0101000020E61000003695456117445640F1F5B52E35764C40
48799	5	49	336	2048	28378	\N	56.524952999999996	Красноярский край, Тюхтетский район, Новомитропольский сельсовет, с.Васильевка, Еланьская, 29, сельский клуб	Россия, Красноярский край, Тюхтетский район, поселок Васильевка	0101000020E6100000514F1F813F635640F277EFA831434C40
48806	5	49	336	2496	\N	\N	56.607475999999998	Красноярский край, Тюхтетский район, Зареченский с/с, д.Безручейка, сельский клуб		0101000020E6100000E674594C6C5A56406D8D08C6C14D4C40
48780	5	49	7483	59823	73088	\N	63.858271771378298	д.Сургутиха, Центральная, 14	Россия	0101000020E61000009241EE224CDA554048895DDBDBED4F40
48786	5	49	7483	59889	73241	\N	65.9159046520289	д.Старо-Туруханск, Декабристов, 29		0101000020E610000055850662D9E655408B4F01309E7A5040
48789	5	49	7483	60007	73490	\N	66.817247229661106	п.Совречка, Центральная, 2	Россия	0101000020E61000007DB08C0DDDF0544043705CC64DB45040
48779	5	49	7483	59869	73144	\N	62.493234806352298	п.Келлог, Центральная, 33	Россия	0101000020E610000091B75CFDD89255400C1F1153223F4F40
48778	5	49	7483	59810	73073	\N	63.155264000000003	с.Верхнеимбатск, Бограда, 17  (дом культуры)	Россия	0101000020E61000006ABFB51325FE5540821FD5B0DF934F40
48781	5	49	7483	59899	73284	\N	64.235240660725196	с.Верещагино, Набережная, 9		0101000020E610000050340F6091E555406A6B44300E0F5040
49052	5	49	7492	59942	73401	\N	61.326815000000003	п.Муторай, Набережная, 14	Россия	0101000020E6100000047289230F1F5940CF6BEC12D5A94E40
48757	5	49	93	32141	28337	\N	57.143883000000002	п.Ялай, Школьная, 2	Россия, Красноярский край, Тасеевский район, поселок Ялай	0101000020E6100000B08EE3874A8F5740A6B915C26A924C40
49073	5	49	93	6460	28655	\N	57.378161990456803	Красноярский край, Абанский район, Почетский сельсовет, д. Шивера, ул. Лесная, 35	Россия, Красноярский край, Тасеевский район, поселок Шивера	0101000020E6100000321D3A3DEFFC5740844BC79C67B04C40
47621	5	49	93	9236	28276	\N	57.388734999999997	п. Чигашет, ул. Школьная, 39		0101000020E6100000234C512E8DFF5740C0E78711C2B14C40
48758	5	49	93	32162	28435	\N	57.129694999999998	с.Хандала, Центральная, 6	Россия, Красноярский край, Тасеевский район, поселок Хандала	0101000020E6100000EE7893DFA2BA574034BA83D899904C40
48762	5	49	93	32338	27898	\N	57.146794	с.Фаначет, Центральная, 22	Россия, Красноярский край, Тасеевский район, поселок Фаначет	0101000020E6100000F931E6AE25DF5740E09F5225CA924C40
48763	5	49	93	45422	72968	\N	57.214804000000001	с.Унжа, Карпачева, 39		0101000020E61000002BDCF291949F574066868DB27E9B4C40
48768	5	49	93	113	72661	\N	57.415579000000001	с.Троицк, Большевитская, 10	Россия, Красноярский край, Тасеевский район, поселок Троицк	0101000020E61000000A4D124BCAB55740C3F352B131B54C40
48746	5	49	93	1549	27816	\N	57.202621999999998	с.Тасеево, пер.Центральный, 1	Россия, Красноярский край, Тасеевский район, поселок Тасеево	0101000020E6100000C1559E40D8B857409DB98784EF994C40
48790	5	49	93	1549	28011	\N	57.202621999999998	с.Тасеево, Сурикова, 10		0101000020E6100000C1559E40D8B857409DB98784EF994C40
48749	5	49	93	1549	72639	\N	57.202621999999998	с.Тасеево, Октябрьская, 141		0101000020E6100000C1559E40D8B857409DB98784EF994C40
48889	5	49	93	1549	72606	\N	57.207466389004999	с.Тасеево, Мичурина, 8	Россия, Красноярский край, Тасеевский район, поселок Тасеево	0101000020E6100000889FFF1EBCB857401684F23E8E9A4C40
48715	5	49	93	1549	27759	\N	57.202621999999998	с.Тасеево, Луначарского, 6	Россия, Красноярский край, Тасеевский район, поселок Тасеево	0101000020E6100000C1559E40D8B857409DB98784EF994C40
48748	5	49	93	1549	27825	\N	57.202903585255498	с.Тасеево, Гагарина, 12	Россия, Красноярский край, Тасеевский район, поселок Тасеево	0101000020E610000033C2DB8310B95740211D1EC2F8994C40
48747	5	49	93	1549	28351	\N	57.202621999999998	с.Тасеево, Лихачева, 18		0101000020E6100000C1559E40D8B857409DB98784EF994C40
48750	5	49	93	32943	28015	\N	57.069018354853803	с.Сухово Пролетарская (здание сельской администрации) 7	Россия, Красноярский край, Тасеевский район, поселок Сухово	0101000020E6100000C495B37746A95740EC6AF294D5884C40
48751	5	49	93	49476	27841	\N	56.989531999999997	д.Струково, Раздолинская, 10 кв.2		0101000020E61000008ACDC7B5A1A15740382C0DFCA87E4C40
48761	5	49	93	32305	28223	\N	57.138311000000002	д.Скакальная, Гагарина, 40 кв.2	Россия, Красноярский край, Тасеевский район, поселок Скакальная	0101000020E6100000CB2DAD86C4C35740AAD6C22CB4914C40
48754	5	49	93	31984	72759	\N	57.092913246794801	с.Сивохино, Слобода, 1	Россия, Красноярский край, Тасеевский район, поселок Сивохино	0101000020E6100000E316F37343A15740C72FBC92E48B4C40
48764	5	49	93	32411	28112	\N	57.284385999999998	д.Мурма, Советская, 44 А	Россия, Красноярский край, Тасеевский район, поселок Мурма	0101000020E61000008A0629780AB357405AB8ACC266A44C40
48756	5	49	93	32077	72848	\N	57.126724000000003	д.Лукашино, Центральная, 18		0101000020E6100000EFE3688EAC97574025CFF57D38904C40
48769	5	49	93	45516	27834	\N	57.312210999999998	п.Лужки, Чкалова, 1	Россия, Красноярский край, Тасеевский район, поселок Лужки	0101000020E61000000D384BC972B15740C939B187F6A74C40
48755	5	49	93	49544	27799	\N	57.082464000000002	д.Корсаково, Гагарина, 41		0101000020E610000053CBD6FA22995740768C2B2E8E8A4C40
48752	5	49	93	49486	28332	\N	57.082019000000003	с.Караульное, Октябрьская, 61		0101000020E61000006F675F7990AF574048533D997F8A4C40
48760	5	49	93	45363	72845	\N	57.083579	с.Веселое, Советская, 39		0101000020E6100000F450DB8651CC5740F2D077B7B28A4C40
48766	5	49	93	45458	27758	\N	57.225636999999999	с.Вахрушево, Центральная, 4		0101000020E610000069FF03AC55A057403FE257ACE19C4C40
48753	5	49	93	49515	28509	\N	57.012366	д.Бурмакино, Чапаева, 27		0101000020E610000072DEFFC709B257408ACA863595814C40
48765	5	49	93	32472	28478	\N	57.258141000000002	д.Бартанас, Пролетарская, 13 А		0101000020E610000000FF942A51AA5740DD60A8C30AA14C40
48759	5	49	93	32218	28338	\N	57.057552999999999	с.Бакчет, Кузнечная, 71	Россия, Красноярский край, Тасеевский район, поселок Бакчет	0101000020E6100000CE6DC2BD32BF5740B2648EE55D874C40
49022	5	49	7120	51861	\N	\N	73.258534466928793	п. Сындасско, Сельский дом культуры		0101000020E610000040FB9122320E5B40DCB930D28B505240
48995	5	49	7120	51761	\N	\N	69.406278010043707	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, МБУК ""Городской дом культуры"""		0101000020E6100000689604A8A98A554065C57075005A5140
49012	5	49	7120	51760	\N	\N	55.007731	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, сельское поселение Караул, п. Байкаловск, Дом культуры посёлка Байкаловск		0101000020E61000007C2C7DE8828457402B155454FD804B40
49006	5	49	7490	59850	\N	\N	71.713785999999999	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, сельское поселение Караул, п. Воронцово, Дом культуры посёлка Воронцово	Россия	0101000020E6100000274A42226DE55440EE9579ABAEED5140
49013	5	49	7490	59744	\N	\N	69.297751559319394	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, сельское поселение Караул, п. Тухард, Дом культуры посёлка Тухард	Россия	0101000020E6100000AD156D8E731655406494675E0E535140
49009	5	49	7490	59675	\N	\N	70.074324432481703	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, сельское поселение Караул, Дом культуры села Караул	Россия	0101000020E6100000D05FE811A3CC5440B55373B9C1845140
48982	5	49	7490	59637	\N	\N	69.408816643417396	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, ТМКОУ ""Дудинская гимназия"""	Россия	0101000020E610000016325706D58B55402043C70E2A5A5140
49007	5	49	7121	59737	\N	\N	69.661461000000003	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, сельское поселение Караул, п. Усть-Порт, Дом культуры посёлка Усть-Порт	Россия	0101000020E61000003BC61517471A554016A58460556A5140
49010	5	49	7121	59689	\N	\N	70.171289000000002	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, сельское поселение Караул, п. Носок, Дом культуры посёлка Носок	Россия	0101000020E61000005CFFAECF9C945440884A2366F68A5140
48992	5	49	7121	51775	\N	\N	69.416918672406197	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, Общежитие КГБОУСПО ""Таймырский колледж"""		0101000020E61000003412A1116C8B55402F8507CDAE5A5140
48996	5	49	7121	51775	28137	\N	69.474366404927906	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, п. Левинские Пески, ТМККДОУ ""Детский сад посёлка Левинские Пески"""		0101000020E6100000B8AE9811DE815540661536035C5E5140
48977	5	49	7121	51898	\N	\N	73.504406794224394	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Диксон, МКУК ""Культурно-досуговый центр"" г.п. Диксон"		0101000020E610000049A297512C225440E7374C3448605240
48726	5	49	7122	59466	71490	\N	56.436744824996602	Красноярский край, Сухобузимский район, Миндерла, Степная, 10	Россия, Красноярский край, село Миндерла	0101000020E6100000CF328B506C3F574084D89942E7374C40
48716	5	49	7122	51810	28114	\N	56.458394573256399	Красноярский край, Сухобузимский район, Мингуль, Школьная, 3-а	Россия, Красноярский край, поселок Мингуль	0101000020E6100000E54350357A5F574031D3F6AFAC3A4C40
48740	5	49	7122	51786	27983	\N	56.499288223706998	Красноярский край, Сухобузимский район, Воробино, Школьная, 8		0101000020E6100000F2B4FCC0554C574083A44FABE83F4C40
48717	5	49	7122	51782	27973	\N	56.44014	Красноярский край, Сухобузимский район, Борск Ленина 12		0101000020E6100000BE672442233A5740AAD4EC8156384C40
48745	5	49	1147	31604	28218	\N	56.585324	Красноярский край, Сухобузимский район, Шошкино, Зеленая, 15-2	Россия, Красноярский край, Сухобузимский район, поселок Шошкино	0101000020E61000007784D382173457402EC896E5EB4A4C40
48718	5	49	1147	30237	72965	\N	56.538217000000003	Красноярский край, Сухобузимский район, Шилинка, Новая, 2		0101000020E61000002BD9B111883A57405C936E4BE4444C40
48742	5	49	1147	31454	27981	\N	56.549948999999998	Красноярский край, Сухобузимский район, Шила, Ленина, 75	Россия, Красноярский край, Сухобузимский район, поселок Шила	0101000020E6100000983270404B435740E4BB94BA64464C40
48725	5	49	1147	30594	72966	\N	56.467469000000001	Красноярский край, Сухобузимский район, Хлоптуново, Первомайская, 57		0101000020E6100000C02500FF9469574069723106D63B4C40
48741	5	49	1147	59742	72986	\N	56.420721999999998	Красноярский край, Сухобузимский район, Толстомысово, Южная, 14		0101000020E6100000B1DD3D40F7575740965AEF37DA354C40
49056	5	49	1147	14809	27730	\N	56.498137	Красноярский край, Сухобузимский район, Сухобузимское, Юбилейная, 1		0101000020E6100000A0DE8C9AAF515740BAF605F4C23F4C40
48737	5	49	1147	14809	72595	\N	56.498137	Красноярский край, Сухобузимский район, Сухобузимское, Центральная, 8		0101000020E6100000A0DE8C9AAF515740BAF605F4C23F4C40
48738	5	49	1147	14809	28294	\N	56.498137	Красноярский край, Сухобузимский район, Сухобузимское, Ленина, 33		0101000020E6100000A0DE8C9AAF515740BAF605F4C23F4C40
48736	5	49	1147	14809	28294	\N	56.497241618028802	Красноярский край, Сухобузимский район, Сухобузимское Ленина 75-Б	Россия, Красноярский край, Сухобузимский район, поселок Сухобузимское	0101000020E6100000C32973F38D5157404C1938A0A53F4C40
48722	5	49	1147	30440	28318	\N	56.525022999999997	Красноярский край, Сухобузимский район, Седельниково, 8 Марта, 9-а		0101000020E6100000ED478AC8B0595740EB5223F433434C40
47978	5	49	1147	26527	27945	\N	56.567926	Красноярский край, Емельяновский район, Первомайский, Октябрьская, 3		0101000020E6100000FAD005F52D255740284696CCB1484C40
48732	5	49	1147	30935	28139	\N	56.751494000000001	Красноярский край, Сухобузимский район, Павловщина, Лукьянова, 30		0101000020E6100000EB387EA834655740F39194F430604C40
48744	5	49	1147	31551	28200	\N	56.659587000000002	Красноярский край, Сухобузимский район, Новотроицкое, Ленина, 54		0101000020E610000063416150A6415740F2EEC8586D544C40
48728	5	49	1147	30753	72799	\N	56.673813000000003	Красноярский край, Сухобузимский район, Нахвальское, Школьная, 15		0101000020E610000071E82D1EDE645740514F1F813F564C40
48730	5	49	1147	30866	28319	\N	56.705015000000003	Красноярский край, Сухобузимский район, Малое Нахвальское, Новая, 40	Россия, Красноярский край, Сухобузимский район, поселок Малое Нахвальское	0101000020E61000000F81238106645740401878EE3D5A4C40
48731	5	49	1147	10781	28270	\N	56.590727000000001	Красноярский край, Сухобузимский район, Малиновка, Трактовая, 39-а		0101000020E6100000A7E9B303AE5E57409EEE3CF19C4B4C40
48723	5	49	1147	30474	72670	\N	56.503379000000002	Красноярский край, Сухобузимский район, Кононово, Транспортная, 11		0101000020E610000078279F1EDB6D5740213F1BB96E404C40
48743	5	49	1147	31489	28340	\N	56.622618000000003	Красноярский край, Сухобузимский район, Ковригино, Ленина, 23	Россия, Красноярский край, Сухобузимский район, поселок Ковригино	0101000020E610000011902FA1824D574052F355F2B14F4C40
48721	5	49	1147	30399	27967	\N	56.615138999999999	Красноярский край, Сухобузимский район, Кекур, Центральная, 24	Россия, Красноярский край, Сухобузимский район, поселок Кекур	0101000020E61000001570CFF3A764574040BFEFDFBC4E4C40
48734	5	49	1147	51815	28134	\N	56.335630000000002	Красноярский край, Сухобузимский район, Карымская, Центральная, 24		0101000020E61000004B1DE4F5605257403BC780ECF52A4C40
48714	5	49	1147	30033	27777	\N	56.603982999999999	Красноярский край, Сухобузимский район, Исток, Центральная, 17		0101000020E61000005395B6B8C66C5740842BA0504F4D4C40
48719	5	49	1147	30307	27884	\N	56.550088000000002	Красноярский край, Сухобузимский район, Высотино, Площадь Победы, 1		0101000020E6100000A6457D923B5A574006F6984869464C40
47839	5	49	1147	19871	72864	\N	56.699066000000002	деревня Бузуново, Механизаторов, 12 А		0101000020E61000005D50DF32A75457406EDFA3FE7A594C40
48739	5	49	1147	30016	\N	\N	56.507977343789101	Красноярский край, Сухобузимский район, База отдыха Бузим, Здание базы отдыха	Россия, Красноярский край, Сухобузимский район, поселок Бузим	0101000020E6100000D3C08F6AD8565740620FED6305414C40
48713	5	49	1147	30016	28490	\N	56.505858000000003	Красноярский край, Сухобузимский район, Бузим, Школьная, 1-а		0101000020E61000004E266E15C4565740C23577F4BF404C40
48724	5	49	1147	30547	72753	\N	56.453358999999999	Красноярский край, Сухобузимский район, Большой Балчуг, Центральная, 37		0101000020E6100000C9CC052E8F6D5740732CEFAA073A4C40
48729	5	49	1147	30787	28500	\N	56.797060234979803	Красноярский край, Сухобузимский район, Берег-Таскино, Береговая, 17-а	Россия, Красноярский край, Сухобузимский район, поселок Берег Таскино	0101000020E610000071E82D1EDE6157409279E40F06664C40
49063	5	49	1147	21467	28299	\N	56.402460159433701	Красноярский край, Сухобузимский район, Атамановский сельсовет, Школьная, 6	Россия, Красноярский край, Сухобузимский район, поселок Атаманово	0101000020E61000007B2FBE688F6857405DF92CCF83334C40
48711	5	49	1147	21467	28385	\N	56.399889961621398	Красноярский край, Сухобузимский район, Атаманово Октябрьская 47-В	Россия, Красноярский край, Сухобузимский район, поселок Атаманово	0101000020E61000001BB80375CA675740ACFF73982F334C40
48720	5	49	1147	30323	28311	\N	56.571437000000003	Красноярский край, Сухобузимский район, Абакшино, Центральная, 48	Россия, Красноярский край, Сухобузимский район, поселок Абакшино	0101000020E6100000F3052D24606C5740B85CFDD824494C40
48735	5	49	7118	51783	27974	\N	56.316772999999998	Красноярский край, Сухобузимский район, Татарская, Новая, 1		0101000020E6100000D926158DB54D5740BEA085048C284C40
48733	5	49	7118	51744	27794	\N	56.424909	Красноярский край, Сухобузимский район, Подсопки, Новая, 17	Россия, Красноярский край, село Подсопки	0101000020E61000002DB0C7444A4D57405663096B63364C40
48709	5	49	7126	59639	72616	\N	60.383439000000003	Красноярский край, Северо-Енисейский район, р.п. Северо-Енисейский, Ленина, 9	Россия	0101000020E610000059A65F22DE4257406781768714314E40
48706	5	49	7126	59627	73059	\N	60.381226187364597	Красноярский край, Северо-Енисейский район, Энергетиков, 1	Россия	0101000020E6100000616EF7729F43574044317903CC304E40
48710	5	49	7126	59838	73106	\N	61.014866465937502	Красноярский край, Северо-Енисейский район, Центральная, 25	Россия	0101000020E6100000C40AB77C245B574042E90B21E7814E40
48708	5	49	7126	59914	73351	\N	59.103663253865903	Красноярский край, Северо-Енисейский район, Школьная, 42	Россия	0101000020E610000023827170E95E5740126745D4448D4D40
48611	5	49	252	25330	27837	\N	55.380108999999997	д.Чарга, Центральная, 12	Россия, Красноярский край, Саянский район, поселок Чарга	0101000020E6100000DC4AAFCDC6CA574027F56569A7B04B40
48701	5	49	252	21413	28634	\N	55.344116420328703	Красноярский край, Саянский район, Нагорновский сельсовет, д.Усть-Анжа Центральная 34	Россия, Красноярский край, Саянский район, поселок Усть-Анжа	0101000020E610000057276728EEC85740E2033BFE0BAC4B40
48699	5	49	252	29363	27748	\N	55.441673000000002	с.Унер, Советская, 43а	Россия, Красноярский край, Саянский район, поселок Унер	0101000020E61000007D03931B45B257405B43A9BD88B84B40
48692	5	49	252	29033	28604	\N	55.135731999999997	п.Тугач, Антонова, 7		0101000020E610000079060DFD13D25740A5828AAA5F914B40
41532	5	49	252	1042	72898	\N	55.419345	с.Тинская, Ковалева, 1		0101000020E6100000D594641D8EC25740DD5ED218ADB54B40
48698	5	49	252	29298	28070	\N	55.321179999999998	д.Ср.Агинка, Советская, 39		0101000020E61000006D8D08C6C1AF57408C101E6D1CA94B40
47692	5	49	252	47044	72868	\N	55.180788999999997	с.Петропавловка, Ленина, 17		0101000020E6100000A089B0E1E9B65740FF3C0D1824974B40
48505	5	49	252	59660	72673	\N	55.243809243499399	с. Павловка, Центральная, 23	Россия, Красноярский край, Саянский район, поселок Павловка	0101000020E6100000634337FB03B8574038BC2022359F4B40
48691	5	49	252	29018	72747	\N	55.007168	п.Орье, Школьный, 2		0101000020E61000007C98BD6C3BC75740F3C98AE1EA804B40
48696	5	49	252	59726	72910	\N	55.229050745618203	Красноярский край, Саянский район, Кулижниковский сельсовет, д.Орловка Центральная 48	Россия, Красноярский край, Саянский район, поселок Орловка	0101000020E610000038DBDC989EA85740DC0E0D8B519D4B40
41700	5	49	252	46790	28355	\N	55.318660000000001	с.Нагорное, Кузьмина, 74		0101000020E61000009B92ACC3D1C357408D45D3D9C9A84B40
47841	5	49	252	19970	28548	\N	55.543582000000001	село Межово, Я.Стоценко, 39		0101000020E6100000F433F5BA45BF5740DE58501894C54B40
41313	5	49	252	19970	72652	\N	55.543582000000001	с.Межово, Новая, 34		0101000020E6100000F433F5BA45BF5740DE58501894C54B40
48689	5	49	252	48514	72854	\N	55.127671999999997	с.Малиновка, Ленина, 46		0101000020E610000006F4C29D0BB15740B54E5C8E57904B40
48697	5	49	252	29265	72984	\N	55.276375000000002	с.Кулижниково, Советская, 52		0101000020E610000002F390291FAC57404C37894160A34B40
48694	5	49	252	29123	28096	\N	55.128906999999998	д.Карлык, Таежная, 31		0101000020E6100000BB09BE69FAAA5740DC9C4A0680904B40
48693	5	49	252	48572	72964	\N	55.215349000000003	с.Гладково, Киселева, 12а		0101000020E610000014CFD90242C55740F81C588E909B4B40
48688	5	49	252	59840	73108	\N	55.175831000000002	д.Большой Ильбин, Зеленая, 6	Россия, Красноярский край, Саянский район, поселок Большой Ильбин	0101000020E61000008141D2A755BC5740BE4F55A181964B40
48695	5	49	252	21370	28119	\N	55.180608999999997	663591 Красноярский край, Саянский район, Большеарбайский сельсовет, с.Большой Арбай Кооперативная 42	Россия, Красноярский край, Саянский район, поселок Большой Арбай	0101000020E6100000AB048BC399AC57407F2E1A321E974B40
48700	5	49	252	48705	28365	\N	55.490501260410099	д.Благодатка, Центральная, 18	Россия, Красноярский край, Саянский район, поселок Благодатка	0101000020E61000002D05A4FD0FB55740E1D39CBCC8BE4B40
48687	5	49	252	28710	28515	\N	55.259765999999999	с.Агинское, Строительная, 21		0101000020E6100000D4997B48F8B957406E4E250340A14B40
48685	5	49	252	28710	28427	\N	55.259765999999999	с.Агинское, Советская, 149		0101000020E6100000D4997B48F8B957406E4E250340A14B40
48686	5	49	252	28710	27734	\N	55.259765999999999	с.Агинское, Дружбы, 7а	Россия, Красноярский край, Саянский район, поселок Агинское	0101000020E6100000D4997B48F8B957406E4E250340A14B40
47995	5	49	252	27226	28325	\N	55.067400871290502	Красноярский край, Енисейский район, п. Абалаково, Школьная, 5а	Россия, Красноярский край, Саянский район, поселок Абалаково	0101000020E610000048DC63E943B55740DD5B9198A0884B40
47993	5	49	252	27226	71514	\N	55.068112999999997	Красноярский край, Енисейский район, с.Абалаково, Нефтяников, 14		0101000020E6100000D731AEB838B557405AB741EDB7884B40
48680	5	49	1113	28500	28090	\N	55.656559999999999	Красноярский край, Рыбинский район, деревня Чуриново, Подгорная, 31	Россия, Красноярский край, Рыбинский район, поселок Чуриново	0101000020E6100000747B4963B4B757404EEE77280AD44B40
48683	5	49	1113	28619	28095	\N	55.539456000000001	Красноярский край, Рыбинский район, деревня Усть-Кандыга, Советская, 39	Россия, Красноярский край, Рыбинский район, поселок Усть-Кандыга	0101000020E6100000E78C28ED0DAF5740C4D0EAE40CC54B40
48158	5	49	1113	9979	73187	\N	55.925798	Ирбейский район, д. Успенка Энергетиков 9-1		0101000020E610000037A79201A0A05740E259828C80F64B40
48572	5	49	1113	9979	27924	\N	55.9258461638996	" Красноярский край, Нижнеингашский район, деревня Успенка Центральная 27""а"""	Россия, Красноярский край, Рыбинский район, поселок Успенка	0101000020E6100000109370218FA05740F390291F82F64B40
48648	5	49	1113	9979	72587	\N	55.925798	Красноярский край, Рыбинский район, село Успенка, Просвещение, 38		0101000020E610000037A79201A0A05740E259828C80F64B40
47636	5	49	1113	9979	28529	\N	55.925798	д. Успенка, ул. Новая, 4		0101000020E610000037A79201A0A05740E259828C80F64B40
47171	5	49	1113	19395	28646	\N	55.907904000000002	Красноярский край, Рыбинский район, поселок Урал, Первомайская, 10		0101000020E6100000A185048C2EB057402CF4C13236F44B40
48671	5	49	1113	28098	28236	\N	55.832379000000003	Красноярский край, Рыбинский район, деревня Тульское, Зеленая, 30	Россия, Красноярский край, Рыбинский район, поселок Тульское	0101000020E6100000DB87BCE5EAC15740487023658BEA4B40
48662	5	49	1113	27683	28587	\N	56.039827000000002	Красноярский край, Рыбинский район, деревня Старая Солянка, Школьная, 11		0101000020E6100000BC24CE8AA8D15740B83F170D19054C40
48679	5	49	1113	28434	72955	\N	55.707304000000001	Красноярский край, Рыбинский район, деревня Соловьевка, Школьная, 3, 2		0101000020E610000001DE02098ABC57403D2AFEEF88DA4B40
48681	5	49	1113	28514	27733	\N	55.597231000000001	Красноярский край, Рыбинский район, деревня Снегиревка, Центральная, 17	Россия, Красноярский край, Рыбинский район, поселок Снегирёвка	0101000020E6100000240A2DEBFEAE57402594BE1072CC4B40
47963	5	49	1113	25870	72941	\N	55.911521999999998	Красноярский край, Емельяновский район, Сибиряк, Центральная, 13		0101000020E6100000B98B3045B9A15740D1CABDC0ACF44B40
49069	5	49	1113	15423	27737	\N	55.549118999999997	Красноярский край, Рыбинский район, поселок Саянский, Комсомольская, 5		0101000020E610000080F0A1444BAD57405D4E098849C64B40
48684	5	49	1113	15423	27737	\N	55.549118999999997	Красноярский край, Рыбинский район, поселок Саянский, Комсомольская, 4	Россия, Красноярский край, Рыбинский район, поселок городского типа Саянский	0101000020E610000080F0A1444BAD57405D4E098849C64B40
48661	5	49	1113	27647	72748	\N	56.009275000000002	Красноярский край, Рыбинский район, деревня Рябинки, Лесная, 24		0101000020E610000036CD3B4ED1C95740D0D556EC2F014C40
48673	5	49	1113	18757	28071	\N	55.778182999999999	Красноярский край, Рыбинский район, село Рыбинское, Трактовая, 1 А		0101000020E61000006729594E42B25740CEA623809BE34B40
48477	5	49	1113	18757	27904	\N	55.778182999999999	Красноярский край, Мотыгинский район, Рыбинский сельсовет, п. Рыбное, Советская, 49		0101000020E61000006729594E42B25740CEA623809BE34B40
48665	5	49	1113	32861	28222	\N	55.671950000000002	Красноярский край, Рыбинский район, село Переяславка, Садова, 6		0101000020E61000003A05F9D9C8AF57400B46257502D64B40
48655	5	49	1113	27308	28213	\N	55.969098000000002	Красноярский край, Рыбинский район, село Новокамала, Шахтерская, 26		0101000020E6100000A4367172BFBF57403C4F3C670BFC4B40
48654	5	49	1113	27308	72667	\N	55.969098000000002	Красноярский край, Рыбинский район, село Новокамала, Советская, 20 А		0101000020E6100000A4367172BFBF57403C4F3C670BFC4B40
48660	5	49	1113	27562	27882	\N	56.003487	Красноярский край, Рыбинский район, село Новая Солянка, Южная, 16		0101000020E61000009EB29AAE27CD5740077B134372004C40
48659	5	49	1113	27562	28449	\N	56.003922551125399	Красноярский край, Рыбинский район, село Новая Солянка, 1-я Центральная, 13	Россия, Красноярский край, Рыбинский район, поселок Новая Солянка	0101000020E610000065FCFB8C0BCD5740E259828C80004C40
48650	5	49	1113	27148	28058	\N	56.010472999999998	Красноярский край, Рыбинский район, деревня Новая Прилука, Низовая, 15, 1		0101000020E6100000B2D991EA3BA05740D93EE42D57014C40
48651	5	49	1113	27160	72956	\N	56.049087999999998	Красноярский край, Рыбинский район, деревня Новая Печера, Советская, 42		0101000020E61000005393E00D69A157402250FD8348064C40
49016	5	49	1113	59749	\N	\N	55.871597000000001	п. Новая, Сельский дом культуры	Россия, Красноярский край, Рыбинский район, поселок Новая	0101000020E6100000BB0F406A13B357405725917D90EF4B40
48675	5	49	1113	59749	73140	\N	55.871980999999998	Красноярский край, Рыбинский район, деревня Новая, Молодежная, 1, 1	Россия, Красноярский край, Рыбинский район, поселок Новая	0101000020E6100000E1EF17B325B35740DFDDCA129DEF4B40
48668	5	49	1113	27979	27894	\N	55.807839999999999	Красноярский край, Рыбинский район, деревня Низинка, Центральная, 6	Россия, Красноярский край, Рыбинский район, поселок Низинка	0101000020E61000009F3C2CD49AC157404833164D67E74B40
48676	5	49	1113	28295	28240	\N	55.904432999999997	Красноярский край, Рыбинский район, село Налобино, Советская, 15		0101000020E6100000EE224C512EAC57402A36E675C4F34B40
48652	5	49	1113	27234	28437	\N	56.089331999999999	Красноярский край, Рыбинский район, село Малая Камала, Трактовая, 8		0101000020E610000088122D793CBC57403E3E213B6F0B4C40
48672	5	49	1113	28125	27900	\N	55.760483999999998	Красноярский край, Рыбинский район, деревня Лощинка, Центральная, 16	Россия, Красноярский край, Рыбинский район, поселок Лощинка	0101000020E6100000DBFAE93F6BCA5740CD902A8A57E14B40
48669	5	49	1113	27986	72893	\N	55.775995999999999	Красноярский край, Рыбинский район, деревня Лозовая, Центральная, 19		0101000020E610000033A48AE255BA5740D5E940D653E34B40
48682	5	49	1113	28595	28448	\N	55.575280999999997	Красноярский край, Рыбинский район, село Красногорьевка, Школьная, 21		0101000020E6100000D733846396B457404D81CCCEA2C94B40
47170	5	49	1113	19343	27728	\N	55.927608999999997	Красноярский край, Рыбинский район, поселок Ирша, Победы, 4		0101000020E61000002101A3CB9BB25740D53C47E4BBF64B40
48212	5	49	1113	27440	28532	\N	56.045304151778403	д.Ивановка, Трактовая, 3	Россия, Красноярский край, Рыбинский район, поселок Ивановка	0101000020E61000001C78B5DC99C3574062307F85CC054C40
48657	5	49	1113	27440	72959	\N	56.047946284284698	Красноярский край, Рыбинский район, деревня Ивановка, Советская, 2 Б, 2	Россия, Красноярский край, Рыбинский район, поселок Ивановка	0101000020E610000045D5AF743EC35740ADFC321823064C40
47585	5	49	1113	40374	28020	\N	56.072704999999999	г. Зеленогорск, Шолохова, 1	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47579	5	49	1113	40374	28023	\N	56.072704999999999	г. Зеленогорск, Строителей, 19		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47578	5	49	1113	40374	28023	\N	56.072704999999999	г. Зеленогорск, Строителей, 12А		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47567	5	49	1113	40374	28132	\N	56.072704999999999	г. Зеленогорск, Советская, 5А	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47582	5	49	1113	40374	28135	\N	56.104581065215498	г. Зеленогорск, Парковая, 54А	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E6100000DEAB5626FCA55740396403E9620D4C40
47580	5	49	1113	40374	28135	\N	56.072704999999999	г. Зеленогорск, Парковая, 40	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47581	5	49	1113	40374	27808	\N	56.072704999999999	г. Зеленогорск, Набережная, 62		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47573	5	49	1113	40374	27808	\N	56.072704999999999	г. Зеленогорск, Набережная, 28		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47569	5	49	1113	40374	27808	\N	56.072704999999999	г. Зеленогорск, Набережная, 14		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47566	5	49	1113	40374	27808	\N	56.072704999999999	г. Зеленогорск, Набережная, 4		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47574	5	49	1113	40374	27966	\N	56.072704999999999	г. Зеленогорск, Заводская, 8А		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47584	5	49	1113	40374	71613	\N	56.072704999999999	г. Зеленогорск, Диктатуры Пролетариата, 20		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47572	5	49	1113	40374	28374	\N	56.072704999999999	г. Зеленогорск, Гагарина, 21		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47571	5	49	1113	40374	28374	\N	56.072704999999999	г. Зеленогорск, Гагарина, 11		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47576	5	49	1113	40374	27835	\N	56.072704999999999	г. Зеленогорск, Бортникова, 23	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47575	5	49	1113	40374	27835	\N	56.072704999999999	г. Зеленогорск, Бортникова, 13	Россия, Красноярский край, Рыбинский район, город Зеленогорск	0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47570	5	49	1113	40374	27835	\N	56.072704999999999	г. Зеленогорск, Бортникова, 1		0101000020E6100000C7BC8E3864A65740BAA0BE654E094C40
47165	5	49	1113	33106	27928	\N	55.959709216963198	Красноярский край, Рыбинский район, городское поселение город Заозерный, Советская, 12	Россия, Красноярский край, Рыбинский район, город Заозерный	0101000020E6100000AF5E454607AD5740A35698BED7FA4B40
47168	5	49	1113	33106	27903	\N	55.957638823068002	Красноярский край, Рыбинский район, городское поселение город Заозерный, Прохорова, 29	Россия, Красноярский край, Рыбинский район, город Заозерный	0101000020E6100000D7DAFB5415AD5740E42F2DEA93FA4B40
47167	5	49	1113	33106	28164	\N	55.958547361262497	Красноярский край, Рыбинский район, городское поселение город Заозерный, Панина, 2	Россия, Красноярский край, Рыбинский район, город Заозерный	0101000020E61000003563D17476AD5740E75608ABB1FA4B40
47166	5	49	1113	33106	73009	\N	55.964379232017897	Красноярский край, Рыбинский район, городское поселение город Заозерный, Армейская, 1		0101000020E61000002618CE35CCAC57407FF964C570FB4B40
47169	5	49	1113	33106	28283	\N	55.958316000000003	Красноярский край, Рыбинский район, городское поселение город Заозерный, 3-е Сентября, 22		0101000020E610000099840B7904AD5740E59D4319AAFA4B40
48663	5	49	1113	27744	28436	\N	55.969909000000001	Красноярский край, Рыбинский район, деревня Завировка, Победы, 1, 1		0101000020E610000010C99063EBD657404C8C65FA25FC4B40
48678	5	49	1113	28425	27880	\N	55.708556999999999	Красноярский край, Рыбинский район, село Двуречное, Садовая, 6		0101000020E6100000051A6CEA3CB157400A2DEBFEB1DA4B40
48656	5	49	1113	27419	28595	\N	56.005927999999997	Красноярский край, Рыбинский район, деревня Гмирянка, Центральная, 45		0101000020E6100000D9EE1EA0FBB75740BA10AB3FC2004C40
48677	5	49	1113	28355	27725	\N	55.859538999999998	Красноярский край, Рыбинский район, деревня Глубоково, Школьная, 22		0101000020E61000003849F3C7B4B057407A51BB5F05EE4B40
48658	5	49	1113	27519	72746	\N	55.945129999999999	Красноярский край, Рыбинский район, деревня Воскресенка, Лесная, 24		0101000020E610000073D712F241BE5740F73B1405FAF84B40
48670	5	49	1113	28055	72751	\N	55.893808	Красноярский край, Рыбинский район, деревня Верховая, Центральная, 10		0101000020E610000000E31934F4C657409B73F04C68F24B40
48667	5	49	1113	27895	28441	\N	55.870733000000001	Красноярский край, Рыбинский район, село Бородино, Советская, 12	Россия, Красноярский край, Рыбинский район, поселок Бородино	0101000020E6100000EBC726F911BE57402446CF2D74EF4B40
48666	5	49	1113	27891	72914	\N	55.949511000000001	Красноярский край, Рыбинский район, село Большие Ключи, 40 лет Победы, 4		0101000020E61000009294F430B4CB57409C18929389F94B40
48649	5	49	1113	27088	28473	\N	55.992538000000003	Красноярский край, Рыбинский район, село Александровка, Советская, 29 А		0101000020E6100000FA0CA837A3A35740C504357C0BFF4B40
48647	5	49	1795	27014	72963	\N	57.430053044584	п. Чайда, Школьная, 7	Россия, Красноярский край, Пировский район, поселок Чайда	0101000020E610000074999A046FED5640FA4509FA0BB74C40
48784	5	49	1795	51906	28614	\N	57.591346999999999	с.Туруханск, Портовая, здание аэровокзала	Россия, Красноярский край, Пировский район, поселок Туруханка	0101000020E61000008AC745B588F556403ACB2C42B1CB4C40
48644	5	49	1795	51812	28116	\N	57.7721709275948	с.Троица, Мира, 63	Россия, Красноярский край, Пировский район, поселок Троица	0101000020E61000008E3D7B2E530B5740B6F5D37FD6E24C40
48641	5	49	1795	26731	28201	\N	57.754772000000003	с. Солоуха, Центральная, 26	Россия, Красноярский край, Пировский район, поселок Солоуха	0101000020E61000002881CD3978135740E0F76F5E9CE04C40
48640	5	49	1795	26679	28410	\N	57.621580000000002	с. Пировское, 1 Мая, 28	Россия, Красноярский край, Пировский район, поселок Пировское	0101000020E6100000BD55D7A19A11574081ECF5EE8FCF4C40
47612	5	49	1795	45395	28524	\N	57.565109999999997	с. Петропавловка, ул. Молодежная, 16		0101000020E6100000FEB8FDF2C90A57403F52448655C84C40
48635	5	49	1795	26453	28577	\N	57.593753999999997	п. Омский, Школьная, 1а		0101000020E610000043705CC64DF9564041EF8D2100CC4C40
48633	5	49	1795	59787	73044	\N	57.594693577112601	д.Новый Тимершик, Центральная, 31	Россия, Красноярский край, Пировский район, поселок Новый Тимерщик	0101000020E61000003C2F151BF30457404F90D8EE1ECC4C40
48183	5	49	1795	47650	72843	\N	57.629826379298798	с. Новотроицкое, Центральная, 29	Россия, Красноярский край, Пировский район, поселок Новотроицкое	0101000020E61000008195438B6C035740D3156C239ED04C40
48643	5	49	1795	47646	27863	\N	57.871690999999998	д. Новониколаевское, Бирнасовская, 29а	Россия, Красноярский край, Пировский район, поселок Новониколаевское	0101000020E61000007767EDB60B1C5740D89B189293EF4C40
48646	5	49	1795	26969	28052	\N	57.823535	д. Куренная Ошма, Солнечная, 22		0101000020E6100000D93EE42D570F5740410E4A9869E94C40
48639	5	49	1795	47574	28409	\N	57.562479000000003	с. Комаровка, Центральный, 2		0101000020E6100000F04FA91265F85640E9D7D64FFFC74C40
48638	5	49	1795	26578	72842	\N	57.615169000000002	д.Коврига, Зелёная, 2		0101000020E61000001EC4CE143AFE5640AB4198DBBDCE4C40
48636	5	49	1795	47532	28408	\N	57.580573999999999	с. Кириково, Зеленая, 1б		0101000020E6100000AD510FD1E81E57403674B33F50CA4C40
48634	5	49	1795	26364	27854	\N	57.582146999999999	п. Кетский, Центральная, 37		0101000020E6100000BA15C26A2CF85640753BFBCA83CA4C40
48632	5	49	1795	26285	28192	\N	57.638730000000002	с.Икшурма, Школьная, 6		0101000020E610000072158BDF14005740AF7C96E7C1D14C40
48642	5	49	1795	47619	28415	\N	57.731138000000001	д. Долгово, Качаева, 1	Россия, Красноярский край, Пировский район, поселок Долгово	0101000020E610000085D1AC6C1F145740726E13EE95DD4C40
48637	5	49	1795	26551	28195	\N	57.658380999999999	"д.Волоковое, Березовая, 28""Б"""	Россия, Красноярский край, Пировский район, поселок Волоковое	0101000020E6100000F549EEB0891C574065A71FD445D44C40
48631	5	49	1795	26259	28574	\N	57.466526999999999	с.Бушуй, Молодёжная, 7		0101000020E6100000BC04A73E900D5740BAD91F28B7BB4C40
48645	5	49	1795	47674	28207	\N	57.821022999999997	с. Бельское, Дзержинского, 16а	Россия, Красноярский край, Пировский район, поселок Бельское	0101000020E6100000BE839F38800A5740C4211B4817E94C40
48630	5	49	1795	26169	72816	\N	57.4929581521397	с.Алтат, Советская, 32	Россия, Красноярский край, Пировский район, поселок Алтат	0101000020E610000044C02154A9D956409A266C3F19BF4C40
48263	5	49	1795	26169	72847	\N	57.492451854531197	д. Алтат, Партизанская, 1	Россия, Красноярский край, Пировский район, поселок Алтат	0101000020E61000000AD6389B8ED95640C66CC9AA08BF4C40
49014	5	49	1513	59746	\N	\N	55.007731	п. Катырык, сельский дом культуры	Россия, Красноярский край, Партизанский район	0101000020E61000007C2C7DE8828457402B155454FD804B40
47681	5	49	1513	59765	73016	\N	55.016035256567797	п.Чистые Пруды, Школьная, 8	Россия, Красноярский край, Партизанский район	0101000020E610000087A6ECF483855740B24B546F0D824B40
48617	5	49	1513	25617	27846	\N	55.468066	деревня Хайдак, Центральная, 56		0101000020E6100000EDD45C6E308557404D2F3196E9BB4B40
48626	5	49	1513	19039	9786	\N	54.946297390969598	"Красноярский край, Партизанский район, Минский сельсовет, поселок Хабайдак улица Гагарина (помещение сельского клуба) д.9""а"""	Россия, Красноярский край, Партизанский район, поселок Хабайдак	0101000020E6100000986E1283C07F5740C6A6954220794B40
48595	5	49	1513	24599	28624	\N	55.498111999999999	село Стойба, Советская, 5		0101000020E6100000EC51B81E859F574061DF4E22C2BF4B40
48612	5	49	1513	25384	72942	\N	55.295565000000003	"деревня Солонечно-Талое, Партизанская, 26 ""а"""		0101000020E6100000884677103B8F5740CF6BEC12D5A54B40
48627	5	49	1513	26107	28130	\N	55.501232999999999	село Партизанское, Советская, 23	Россия, Красноярский край, Партизанский район, поселок Партизанское	0101000020E61000008F6E8445459957408656276728C04B40
48628	5	49	1513	26107	28189	\N	55.501232999999999	"663540 Красноярский край, Партизанский район, Партизанский сельсовет, село Партизанское улица 60 лет СССР (помещение библиотеки имени М.Д.Родкина) д.4""а"""	Россия, Красноярский край, Партизанский район, поселок Партизанское	0101000020E61000008F6E8445459957408656276728C04B40
48616	5	49	1513	17737	27971	\N	55.545614999999998	"Красноярский край, Партизанский район, Имбежский сельсовет, деревня Ной улица Центральная (помещение сельского клуба) д.33""а"""		0101000020E61000006E88F19A57925740809A5AB6D6C54B40
48620	5	49	1513	47195	72788	\N	55.285358000000002	деревня Новомихайловка, Кирова, 52	Россия, Красноярский край, Партизанский район, поселок Новомихайловка	0101000020E610000063416150A6A3574074D3669C86A44B40
48624	5	49	1513	25948	72951	\N	54.977908999999997	поселок Мина, Школьная, 30		0101000020E6100000B3976DA7AD88574066BB421F2C7D4B40
48625	5	49	1513	26017	72633	\N	54.958750999999999	поселок Мана, Лесная, 15		0101000020E61000007616BD53017D5740EF004F5AB87A4B40
48615	5	49	1513	25506	28185	\N	55.535310000000003	деревня Малый Имбеж, Зеленая, 56		0101000020E610000055BE672442845740639CBF0985C44B40
48623	5	49	1513	25926	72949	\N	55.101447019721	"деревня Кой, Берегового, 56 ""а"""	Россия, Красноярский край, Партизанский район, поселок Кой	0101000020E6100000E4BA29E5B58457407FA31D37FC8C4B40
48622	5	49	1513	25863	28040	\N	55.339432000000002	деревня Кожелак, Центральная, 28		0101000020E61000003FE0810184805740A29BFD8172AB4B40
48619	5	49	1513	47174	72826	\N	55.186067999999999	деревня Ивашиха, Гагарина, 56		0101000020E610000068041BD7BF9F5740836A8313D1974B40
48614	5	49	1513	25499	72682	\N	55.558717000000001	поселок Запасной Имбеж, Центральная, 12		0101000020E61000006B49473998875740105CE50984C74B40
49001	5	49	1513	59755	\N	\N	55.007731	"Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, п. Усть-Авам, МБУК ""Сельский дом культуры посёлка Усть-Авам"""	Россия, Красноярский край, Партизанский район	0101000020E61000007C2C7DE8828457402B155454FD804B40
48772	5	49	1513	59632	72602	\N	54.827106000000001	с.Ворогово, Андреевой, 27		0101000020E61000009A22C0E95DA05740A629029CDE694B40
48565	5	49	1513	23136	72662	\N	55.280394999999999	"село Вершино-Рыбное, Ленина, 31 ""а"""		0101000020E610000017D4B7CCE9945740207BBDFBE3A34B40
48535	5	49	1513	59775	73028	\N	55.480485534548301	дередня Богуславка, переулок Школьный, 3		0101000020E61000009FE74F1BD5A85740CA17B49080BD4B40
48601	5	49	1737	51794	28010	\N	55.162498999999997	Красноярский край, Новоселовский район, поселок Чулым, Советская, 26		0101000020E61000009AEE75525FC25640FC5069C4CC944B40
48600	5	49	1737	24862	72825	\N	55.204889999999999	Красноярский край, Новоселовский район, поселок Чесноки, Зеленая, 10		0101000020E6100000C3D8429083E2564083A3E4D5399A4B40
48591	5	49	1737	24393	28290	\N	54.929234000000001	Красноярский край, Новоселовский район, деревня Черная Кома, Народная, 55		0101000020E61000002F34D769A4D15640672AC423F1764B40
48603	5	49	1737	24994	28551	\N	55.111325000000001	Красноярский край, Новоселовский район, деревня Увалы, Центральная, 31	Россия, Красноярский край, Новоселовский район, поселок Увалы	0101000020E61000001BDA006C40BF5640151DC9E53F8E4B40
48608	5	49	1737	25183	72744	\N	54.969419000000002	Красноярский край, Новоселовский район, поселок Толстый Мыс, Степная, 2в		0101000020E6100000A9F92AF9D8B056407E8FFAEB157C4B40
48587	5	49	1737	24175	28345	\N	54.743817	Красноярский край, Новоселовский район, поселок Тесь, Школьная, 5	Россия, Красноярский край, Новоселовский район, поселок Тесь	0101000020E610000053CF8250DEC55640BB9A3C65355F4B40
48586	5	49	1737	24160	27980	\N	54.894517999999998	Красноярский край, Новоселовский район, поселок Тальцы, Победы, 4	Россия, Красноярский край, Новоселовский район, поселок Тальцы	0101000020E6100000FF9600FC53CA564077D7D9907F724B40
48588	5	49	1737	24260	28522	\N	54.811383999999997	Красноярский край, Новоселовский район, поселок Табажак, Советская, 2		0101000020E610000008CA6DFB1EC55640B33F506EDB674B40
48604	5	49	1737	33088	28370	\N	55.093297999999997	Красноярский край, Новоселовский район, село Светлолобо, Мудрова, 21	Россия, Красноярский край, Новоселовский район, поселок Светлолобово	0101000020E6100000B6F81400E3B556401F645930F18B4B40
48589	5	49	1737	24290	28346	\N	54.751559	Красноярский край, Новоселовский район, поселок Приморский, Советская, 20	Россия, Красноярский край, Новоселовский район, поселок Приморский	0101000020E610000044DC9C4A06BF5640DA01D71533604B40
48583	5	49	1737	23911	28511	\N	55.002670999999999	Красноярский край, Новоселовский район, село Новоселово, Школьная, 8	Россия, Красноярский край, Новоселовский район, поселок Новоселово	0101000020E6100000575C1C959BBE5640E5D2F88557804B40
48582	5	49	1737	23911	71622	\N	55.002670999999999	Красноярский край, Новоселовский район, село Новоселово, Театральная, 11		0101000020E6100000575C1C959BBE5640E5D2F88557804B40
48581	5	49	1737	23911	27937	\N	55.002670999999999	Красноярский край, Новоселовский район, c. Новоселово, Почтовая, 1		0101000020E6100000575C1C959BBE5640E5D2F88557804B40
48605	5	49	1737	25060	72834	\N	55.104470999999997	Красноярский край, Новоселовский район, деревня Николаевка, рабочая, 1		0101000020E610000034BBEEAD48B15640B130444E5F8D4B40
48602	5	49	1737	24940	72802	\N	55.133040000000001	Красноярский край, Новоселовский район, село Легостаево, Октябрьская, 11		0101000020E6100000D66EBBD05CC25640A987687407914B40
48599	5	49	1737	24817	27773	\N	55.148178999999999	Красноярский край, Новоселовский район, поселок Куртак, Школьный, 2		0101000020E61000009E9ACB0D86E256401C7A8B87F7924B40
48597	5	49	1737	24718	72741	\N	55.182099000000001	Красноярский край, Новоселовский район, поселок Курганы, Советская, 2		0101000020E6100000DDEEE53E39D4564031D120054F974B40
48594	5	49	1737	24563	27819	\N	54.910818999999996	Красноярский край, Новоселовский район, деревня Кульчек, Клубная, 8		0101000020E6100000A48E8EAB91DA5640A7C98CB795744B40
48585	5	49	1737	24081	28159	\N	54.815761999999999	Красноярский край, Новоселовский район, деревня Куллог, Центральная, 16	Россия, Красноярский край, Новоселовский район, поселок Куллог	0101000020E610000026FE28EACCCB5640E7A8A3E36A684B40
48590	5	49	1737	24359	72630	\N	55.010905999999999	Красноярский край, Новоселовский район, поселок Кома, Анашкина, 4		0101000020E6100000D105F52D73CD564043AA285E65814B40
48607	5	49	1737	25143	28557	\N	55.120676000000003	Красноярский край, Новоселовский район, деревня Камчатка, Береговая, 31а		0101000020E610000021CEC3094CB75640C0B4A84F728F4B40
48610	5	49	1737	25293	28179	\N	54.953059000000003	Красноярский край, Новоселовский район, поселок Интикуль, Октябрьская, 4а	Россия, Красноярский край, Новоселовский район, поселок Интикуль	0101000020E61000008849B89047A5564049145AD6FD794B40
48592	5	49	1737	24464	72925	\N	55.036975748313303	Красноярский край, Новоселовский район, поселок Енисей, Партизанская, 7	Россия, Красноярский край, Новоселовский район, поселок Енисей	0101000020E610000041800C1D3BD75640535E2BA1BB844B40
48598	5	49	1737	24753	27826	\N	55.094456999999998	Красноярский край, Новоселовский район, поселок Дивный, Центральная, 4	Россия, Красноярский край, Новоселовский район, поселок Дивный	0101000020E6100000B43BA41820D156406BF0BE2A178C4B40
48593	5	49	1737	24506	28446	\N	54.901631000000002	Красноярский край, Новоселовский район, деревня Бескиш, Рабочая, 10		0101000020E61000001D007157AFD35640A70705A568734B40
48596	5	49	1737	24664	72820	\N	55.188319	Красноярский край, Новоселовский район, поселок Берёзовый, Маяковского, 11		0101000020E6100000A62BD8463CCD5640931B45D61A984B40
48606	5	49	1737	25096	72839	\N	55.162776999999998	Красноярский край, Новоселовский район, село Бараит, Центральная, 9б		0101000020E610000093A641D13CB056403FC571E0D5944B40
48609	5	49	1737	25223	28560	\N	54.922384000000001	Красноярский край, Новоселовский район, поселок Аёшка, Школьная, 20а		0101000020E6100000E202D0285DB65640452DCDAD10764B40
48584	5	49	1737	24075	28018	\N	54.871026000000001	Красноярский край, Новоселовский район, поселок Анаш, Октябрьская, 41	Россия, Красноярский край, Новоселовский район, поселок Анаш	0101000020E61000002DCC423BA7C356409CFBABC77D6F4B40
48551	5	49	1163	22605	28285	\N	56.491424000000002	Красноярский край, Нижнеингашский район, поселок Южная Тунгкска Трактовая 26	Россия, Красноярский край, Нижнеингашский район, поселок Южная Тунгуска	0101000020E610000097C5C4E6E35B5840193C4CFBE63E4C40
48567	5	49	1163	23032	27965	\N	56.398568866619698	Красноярский край, Нижнеингашский район, деревня Эстония Таллинская 20	Россия, Красноярский край, Нижнеингашский район, поселок Эстония	0101000020E61000000DAB7823F31F584087191A4F04334C40
48578	5	49	1163	23625	27993	\N	56.119905000000003	Красноярский край, Нижнеингашский район, село Тины Мира 5	Россия, Красноярский край, Нижнеингашский район, поселок Тины	0101000020E6100000BF823463D13758403ED00A0C590F4C40
48545	5	49	1163	21152	27952	\N	56.153021000000003	Красноярский край, Нижнеингашский район, поселок Тинской Молодежная 20	Россия, Красноярский край, Нижнеингашский район, поселок городского типа Тинской	0101000020E6100000EA5DBC1FB73B5840F54C2F3196134C40
48547	5	49	1163	21152	28320	\N	56.152598339350398	Красноярский край, Нижнеингашский район, поселок Тинской, Вокзальная, 5	Россия, Красноярский край, Нижнеингашский район, поселок городского типа Тинской	0101000020E61000008330B77BB93B5840AEB7CD5488134C40
48548	5	49	1163	51776	72631	\N	56.153021000000003	Красноярский край, Нижнеингашский район, поселок Тинской, Советская, 29		0101000020E6100000EA5DBC1FB73B5840F54C2F3196134C40
48546	5	49	1163	51776	72634	\N	56.153021000000003	Красноярский край, Нижнеингашский район, поселок Тинской, Первомайская, 47		0101000020E6100000EA5DBC1FB73B5840F54C2F3196134C40
48573	5	49	1163	23134	27988	\N	56.465679000000002	Красноярский край, Нижнеингашский район, село Стретенка пер.Западный 2		0101000020E61000004485EAE6E21958408DB7955E9B3B4C40
48576	5	49	1163	59681	72717	\N	56.1684940246517	Красноярский край, Нижнеингашский район, поселок Тиличеть, Центральная, 1	Россия, Красноярский край, деревня Старцево, улица Центральная, 1	0101000020E6100000D82B2CB81F3F57403FC91D3691154C40
48569	5	49	1163	20905	72905	\N	56.374287000000002	Красноярский край, Нижнеингашский район, село Соколовка пер.Клубный 1		0101000020E610000097E4805D4D2F5840B328ECA2E82F4C40
48574	5	49	1163	23510	28255	\N	56.473754	Красноярский край, Нижнеингашский район, деревня Поскотино Центральная 35	Россия, Красноярский край, Нижнеингашский район, поселок Поскотино	0101000020E61000002A58E36C3A135840B22C98F8A33C4C40
47622	5	49	1163	23127	28247	\N	56.422814454735402	с. Покровка, ул. Советская, 18б	Россия, Красноярский край, Нижнеингашский район, поселок Покровка	0101000020E6100000C231CB9E043158403E25E7C41E364C40
48571	5	49	1163	23127	28649	\N	56.421371581298402	Красноярский край, Нижнеингашский район, деревня Покровка Зеленая 13	Россия, Красноярский край, Нижнеингашский район, поселок Покровка	0101000020E6100000CBF5B6990A3158409DB98784EF354C40
48549	5	49	1163	22600	27906	\N	56.512913177224597	Красноярский край, Нижнеингашский район, поселок Поканаевка Октябрьская 3		0101000020E610000092CD55F31C6A5840BC581822A7414C40
48580	5	49	1163	18235	27925	\N	56.071653072173298	" Красноярский край, Нижнеингашский район, поселок Поймо-Тины Центральная 1""а"""	Россия, Красноярский край, Нижнеингашский район, поселок Поймо-Тины	0101000020E61000000801F9122A2F584084D4EDEC2B094C40
48568	5	49	1163	23043	27956	\N	56.086092999999998	Красноярский край, Нижнеингашский район, деревня Павловка Центральная 11	Россия, Красноярский край, Нижнеингашский район, поселок Павловка	0101000020E610000040FCFCF7E02758400FB56D18050B4C40
48563	5	49	1163	59727	72913	\N	56.324365999999998	Красноярский край, Нижнеингашский район, деревня Ошарово Дачная 31		0101000020E6100000AF963B33C142584098F738D384294C40
49045	5	49	1163	14269	72982	\N	56.276848000000001	п.Ошарово, Набережная, 8А		0101000020E610000098DA52077930584044FB58C16F234C40
48575	5	49	1163	23588	28153	\N	56.435387864888597	Красноярский край, Нижнеингашский район, деревня Новорождественка Молодежная 1	Россия, Красноярский край, Нижнеингашский район, поселок Новорождественка	0101000020E61000007022FAB5F51A5840128942CBBA374C40
48564	5	49	1163	21588	28109	\N	56.422535000000003	Красноярский край, Нижнеингашский район, село Новоалександровка Центральная 49	Россия, Красноярский край, Нижнеингашский район, поселок Новоалександровка	0101000020E6100000D09B8A54182558402B357BA015364C40
48538	5	49	1163	22509	72908	\N	56.178804	Красноярский край, Нижнеингашский район, деревня Новая Пойма Центральная 35/1	Россия, Красноярский край, Нижнеингашский район, поселок Новая Пойма	0101000020E6100000B77D8FFAEB2558406E32AA0CE3164C40
48540	5	49	1163	59487	71595	\N	56.164185000000003	Красноярский край, Нижнеингашский район, поселок Нижняя Пойма, Дзержинского, 8		0101000020E61000008578245E9E4C584034BF9A0304154C40
48541	5	49	1163	22054	27921	\N	56.164185000000003	" Красноярский край, Нижнеингашский район, поселок Нижняя Пойма микрорайон ""Спутник"" 18"		0101000020E61000008578245E9E4C584034BF9A0304154C40
48543	5	49	1163	22054	28480	\N	56.164185000000003	Красноярский край, Нижнеингашский район, поселок Нижняя Пойма, Семафорная, 1		0101000020E61000008578245E9E4C584034BF9A0304154C40
48542	5	49	1163	22054	27969	\N	56.164185000000003	Красноярский край, Нижнеингашский район, поселок Нижняя Пойма, Первомайская, 1		0101000020E61000008578245E9E4C584034BF9A0304154C40
48533	5	49	1163	51848	28314	\N	56.195931000000002	Красноярский край, Нижнеингашский район, поселокНижний Ингаш, Зеленая, 18		0101000020E6100000DD9A745B22225840E4A25A4414194C40
48536	5	49	1163	21653	72828	\N	56.195931000000002	Красноярский край, Нижнеингашский район, поселок Нижний Ингаш, Терешковой, 2		0101000020E6100000DD9A745B22225840E4A25A4414194C40
48534	5	49	1163	21653	28642	\N	56.195545342257503	"Красноярский край, Нижнеингашский район, поселок Нижний Ингаш, Новая, 2""б"""	Россия, Красноярский край, Нижнеингашский район, поселок городского типа Нижний Ингаш	0101000020E6100000A2293BFDA0215840BBF2599E07194C40
48532	5	49	1163	21653	28477	\N	56.195931000000002	Красноярский край, Нижнеингашский район, село Нижний Ингаш, Лесная, 1	Россия, Красноярский край, Нижнеингашский район, поселок городского типа Нижний Ингаш	0101000020E6100000DD9A745B22225840E4A25A4414194C40
48560	5	49	1163	21653	28648	\N	56.195931000000002	Красноярский край, Нижнеингашский район,поселок Нижний Ингаш, Ленина, 157		0101000020E6100000DD9A745B22225840E4A25A4414194C40
48570	5	49	1163	17906	28591	\N	56.343837110474198	Красноярский край, Нижнеингашский район, деревня Михайловка Цетральная 40	Россия, Красноярский край, Нижнеингашский район, поселок Михайловка	0101000020E6100000467C2766BD285840CF13CFD9022C4C40
48557	5	49	1163	22777	28419	\N	56.262632709212902	Красноярский край, Нижнеингашский район, деревня Максаковка Центральная 25	Россия, Красноярский край, Нижнеингашский район, поселок Максаковка	0101000020E6100000D5CDC5DFF6205840D9EC48F59D214C40
48562	5	49	1163	22865	28059	\N	56.310533339989597	Красноярский край, Нижнеингашский район, село Кучерово Центральная 46	Россия, Красноярский край, Нижнеингашский район, поселок Кучерово	0101000020E6100000C7D97404703D584015AA9B8BBF274C40
48544	5	49	1163	22232	28482	\N	56.089533000000003	Красноярский край, Нижнеингашский район, поселок Курдояки, Центральная, 1	Россия, Красноярский край, Нижнеингашский район, поселок Курдояки	0101000020E6100000266F8099EF4F5840D6743DD1750B4C40
48552	5	49	1163	21190	27795	\N	56.547333999999999	Красноярский край, Нижнеингашский район, поселок Кедровый пер.Школьный 4		0101000020E610000036EA211ADD6C584093FE5E0A0F464C40
48561	5	49	1163	18111	28003	\N	56.057760000000002	Красноярский край, Нижнеингашский район, деревня Касьяново Центральная 3	Россия, Красноярский край, Нижнеингашский район, поселок Касьяново	0101000020E6100000184339D1AE1658402C82FFAD64074C40
48558	5	49	1163	21288	71585	\N	56.264639299673298	Красноярский край, Нижнеингашский район, поселок Канифольный Школьная 1	Россия, Красноярский край, Нижнеингашский район, поселок Канифольный	0101000020E6100000E4326E6AA0545840821FD5B0DF214C40
48556	5	49	1163	22767	28210	\N	56.314445217392901	Красноярский край, Нижнеингашский район, село Ивановка Центральная 20	Россия, Красноярский край, Нижнеингашский район, поселок Ивановка	0101000020E61000005DFDD8243F21584003B2D7BB3F284C40
48579	5	49	1163	18157	27908	\N	56.134409630676998	Красноярский край, Нижнеингашский район, деревня Елизаветка Центральная 9	Россия, Красноярский край, Нижнеингашский район, поселок Елизаветка	0101000020E610000035EF384547435840B020CD5834114C40
48555	5	49	1163	21230	28303	\N	56.208503999999998	Красноярский край, Нижнеингашский район, село Верхний Ингаш Центральная 83	Россия, Красноярский край, Нижнеингашский район, поселок Верхний Ингаш	0101000020E6100000DA37F7578F1B5840E78A5242B01A4C40
48537	5	49	1163	21230	28009	\N	56.209687780782097	Красноярский край, Нижнеингашский район, Верхнеингашский сельсовет В/Ч, Лаптева, 7	Россия, Красноярский край, Нижнеингашский район, поселок Верхний Ингаш	0101000020E6100000B0045262D71B58408C2E6F0ED71A4C40
48559	5	49	1163	22847	28549	\N	56.239683753038001	" Красноярский край, Нижнеингашский район, поселок Бельняки Молодежная 1""а"""	Россия, Красноярский край, Нижнеингашский район, поселок Бельняки	0101000020E6100000DB8651103C4F5840EEAF1EF7AD1E4C40
48553	5	49	1163	22683	28361	\N	56.339821000000001	Красноярский край, Нижнеингашский район, деревня Александровка Центральная 25	Россия, Красноярский край, Нижнеингашский район, поселок Александровка	0101000020E61000005CAD1397E34058403CBF28417F2B4C40
40247	5	49	79	2904	27800	\N	56.008062000000002	д. Ярлыково, Садовая, 3	Россия, Красноярский край, Назаровский район, поселок Ярлыково	0101000020E6100000FB230C0396B05640912BF52C08014C40
48502	5	49	79	59864	73134	\N	55.776764999999997	д. Шипиловка, Нижняя, 6	Россия, Красноярский край, Назаровский район, поселок Шипиловка	0101000020E6100000573D601E327E5640B6D617096DE34B40
48516	5	49	79	49407	28265	\N	55.870738000000003	д. Чердынь, Молодежная, 3		0101000020E6100000ADF71BEDB894564036B1C05774EF4B40
48519	5	49	79	21018	27918	\N	55.803488999999999	д. Холма, Гусарова, 43	Россия, Красноярский край, Назаровский район, поселок Холма	0101000020E61000006BF0BE2A17AA56400ED940BAD8E64B40
48529	5	49	79	49599	28312	\N	55.794162999999998	"д. Усть - Березовка, Заречная, 35 ""А"""	Россия, Красноярский край, Назаровский район, поселок Усть-Березовка	0101000020E610000028BA2EFCE0995640BC581822A7E54B40
48487	5	49	79	19270	28425	\N	55.736350999999999	д. Степноозерка, Центральная, 45		0101000020E61000008CF4A276BF8856403EB0E3BF40DE4B40
48521	5	49	79	49478	28433	\N	55.699548	п. Степной, Школьная, 13	Россия, Красноярский край, Назаровский район, поселок Степной	0101000020E61000009B8D9598679B5640B9FDF2C98AD94B40
48512	5	49	79	20677	28633	\N	55.830083000000002	п. Старожилово, Центральная, 3		0101000020E6100000944BE3175EB8564098FBE42840EA4B40
48524	5	49	79	21282	28659	\N	55.746856000000001	"д. Средняя Березовка, Степная, 33 ""А"""		0101000020E6100000992CEE3F32975640236937FA98DF4B40
48481	5	49	79	18967	72814	\N	55.960476999999997	п. Сохновка, Борьбы, 10		0101000020E6100000E97E4E417E8B5640B4C70BE9F0FA4B40
48511	5	49	79	20610	28099	\N	55.757668000000002	д. Скоробогатово, Центральная, 26	Россия, Красноярский край, Назаровский район, поселок Скоробогатово	0101000020E610000098874CF910B85640E59CD843FBE04B40
48518	5	49	79	49435	28636	\N	55.791829999999997	"д. Сереуль, Борисенко, 29 ""А"""		0101000020E6100000295AB91798A25640EFFE78AF5AE54B40
48475	5	49	79	18651	28609	\N	55.858942999999996	с. Сереж, Клубная, 10		0101000020E610000008CBD8D0CD8C564066101FD8F1ED4B40
48513	5	49	79	20717	28562	\N	55.894424000000001	"с. Селедково, Причулымская, 6 ""Б"""		0101000020E610000032E719FB92C25640F660527C7CF24B40
48517	5	49	79	20930	72686	\N	55.758938999999998	с. Сахапта, Клубная, 17		0101000020E61000008EE6C8CA2FAC56405854C4E924E14B40
48491	5	49	79	49058	72923	\N	55.838430000000002	"д. Прогресс, Центральная, 12 ""А"""		0101000020E6100000ABB184B5318356401EFE9AAC51EB4B40
48514	5	49	79	20790	28100	\N	55.937220000000003	п. Преображенский, Комсомольская, 16		0101000020E6100000BDE2A9471A9C56401D9430D3F6F74B40
48522	5	49	79	49487	28431	\N	55.639297999999997	п. Предгорный, Полевая, 9	Россия, Красноярский край, Назаровский район, поселок Предгорный	0101000020E6100000D5230D6E6B905640F8325184D4D14B40
48510	5	49	79	20566	27915	\N	55.844121000000001	"с. Подсосное, Школьная, 52 ""Б"""		0101000020E61000007214200A66C05640F46E2C280CEC4B40
47742	5	49	79	40386	72765	\N	55.849054000000002	д.Петровка, Щетинкина, 38		0101000020E610000006802A6EDC835640DD442DCDADEC4B40
48531	5	49	79	51909	28660	\N	55.588155	"д. Новоалександровка, Школьная, 56 ""А"""	Россия, Красноярский край, Назаровский район, поселок Новоалександровка	0101000020E6100000E23FDD4081A856404CFDBCA948CB4B40
48504	5	49	79	20189	27742	\N	55.679924999999997	"д. Новая Сокса, Просвещения, 1 ""А"""	Россия, Красноярский край, Назаровский район, поселок Новая Сокса	0101000020E61000002C0E677E35765640CC5D4BC807D74B40
48483	5	49	79	19072	28085	\N	55.914796000000003	"д. Нижний Ададым, Зеленая, 40 ""А"""		0101000020E61000008AABCABE2B9256407D410B0918F54B40
47451	5	49	79	95	71503	\N	56.005147848388603	"Красноярский край, город Назарово, ул.Труда, д.№11 ""Д"""	Россия, Красноярский край, Назаровский район, город Назарово	0101000020E6100000ACC5A70018985640E5D18DB0A8004C40
47453	5	49	79	95	71540	\N	56.007840735253097	Красноярский край, город Назарово, ул.Полиграфистов, д.№20		0101000020E61000006859F78F85995640B24813EF00014C40
47455	5	49	79	95	27916	\N	56.011302999999998	"Красноярский край, город Назарово, ул.Ленина, д.№4 ""А"""		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47448	5	49	79	95	27827	\N	56.011302999999998	Красноярский край, город Назарово, ул.Кузнечная, д.6		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47452	5	49	79	95	71539	\N	56.011302999999998	Красноярский край, город Назарово, ул.Кравченко, д.№2		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47456	5	49	79	95	71497	\N	56.011302999999998	Красноярский край, город Назарово, ул.Клубная, д.№10		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47445	5	49	79	95	28286	\N	56.011302999999998	"Красноярский край, город Назарово, ул.К.Маркса, д.№46 ""А"""		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47442	5	49	79	95	28343	\N	56.011302999999998	Красноярский край, город Назарово, ул.К.Маркса, д.№21		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47441	5	49	79	95	28343	\N	56.011302999999998	Красноярский край, город Назарово, ул.К.Маркса, д.№17		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47439	5	49	79	95	28289	\N	56.011302999999998	Красноярский край, город Назарово, ул.Гуськова, д.№4		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47454	5	49	79	95	28024	\N	56.011302999999998	"Красноярский край, город Назарово, ул.Вокзальная, д.5 ""А"""	Россия, Красноярский край, Назаровский район, город Назарово	0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
48970	5	49	79	95	73280	\N	56.006922933871202	город Назарово Борисенко д.№ 10	Россия, Красноярский край, Назаровский район, город Назарово	0101000020E61000006FBDA607059856408C4B55DAE2004C40
47449	5	49	79	95	27991	\N	56.011302999999998	Красноярский край, город Назарово, ул.Арбузова, д.62		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47446	5	49	79	95	27991	\N	56.011302999999998	"Красноярский край, город Назарово, ул.Арбузова, д.№98 ""А"""	Россия, Красноярский край, Назаровский район, город Назарово	0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
48969	5	49	79	95	27987	\N	56.011302999999998	город Назарово ул. 30 лет ВЛКСМ д.№ 84		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47444	5	49	79	95	27987	\N	56.011302999999998	Красноярский край, город Назарово, ул.30 лет ВЛКСМ, д.№84	Россия, Красноярский край, Назаровский район, город Назарово	0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47443	5	49	79	95	27987	\N	56.011302999999998	"Красноярский край, город Назарово, ул.30 лет ВЛКСМ, д.№85""А"""		0101000020E61000000B7BDAE1AF98564060AC6F6072014C40
47440	5	49	79	95	27987	\N	56.008417778042997	Красноярский край, город Назарово, ул.30 лет ВЛКСМ, д.№95	Россия, Красноярский край, Назаровский район, город Назарово	0101000020E61000000E9E094D129856404F594DD713014C40
48527	5	49	79	49575	72835	\N	55.632489	д. Московка, Подгорная, 28		0101000020E6100000280D350A49A55640350A4966F5D04B40
48525	5	49	79	59801	73063	\N	55.689728849831901	"д. Медведск, Московская, 1 ""А"""	Россия, Красноярский край, Назаровский район, поселок Медведовск	0101000020E61000000281CEA44D9F5640280D350A49D84B40
48460	5	49	79	48519	72811	\N	55.924213999999999	"д. Лесные Поляны, Школьная, 14 ""А"""		0101000020E6100000CC2A6C06B8AD5640AF40F4A44CF64B40
48507	5	49	79	20361	27746	\N	55.991345000000003	д. Куличка, Центральная, 20	Россия, Красноярский край, Назаровский район, поселок Куличка	0101000020E61000001AE0826C596B5640CD069964E4FE4B40
48523	5	49	79	49504	72745	\N	55.621901999999999	п. Красногорский, Центральная, 3		0101000020E6100000BB7F2C448798564093A8177C9ACF4B40
48497	5	49	79	19764	72928	\N	55.700816000000003	п. Красная Сопка, Новая, 14		0101000020E610000007616EF772825640BC41B456B4D94B40
48496	5	49	79	19764	28251	\N	55.700816000000003	п. Красная Сопка, Вокзальная, 1	Россия, Красноярский край, Назаровский район, поселок Красная Сопка	0101000020E610000007616EF772825640BC41B456B4D94B40
48444	5	49	79	48237	28573	\N	55.948478000000001	с. Красная Поляна, Мира, 33		0101000020E6100000BBB6B75B92AA5640DD7C23BA67F94B40
48530	5	49	79	45351	28607	\N	55.787067	с. Кольцово, Верхняя, 36		0101000020E610000025B37A87DB9156406361889CBEE44B40
48490	5	49	79	19457	27792	\N	55.799197999999997	с. Кибитень, Центральная, 35	Россия, Красноярский край, Назаровский район, поселок Кибитень	0101000020E61000002657B1F84D835640A983BC1E4CE64B40
48501	5	49	79	20016	28629	\N	55.775170000000003	"д. Каргала, Зеленая, 48 ""А"""		0101000020E61000007D09151C5E795640906B43C538E34B40
48520	5	49	79	49458	28470	\N	55.702002999999998	д. Канаш, Верхняя, 14		0101000020E6100000406D54A703B15640D158FB3BDBD94B40
48489	5	49	79	49038	72916	\N	55.893858999999999	п. Зеленая Горка, Цветочная, 7	Россия, Красноярский край, Назаровский район, поселок Зеленая Горка	0101000020E6100000FF0758AB767C56401D1EC2F869F24B40
48506	5	49	79	20347	28460	\N	56.023153000000001	д. Захаринка, Центральная, 18		0101000020E61000005DFA97A432775640F3E670ADF6024C40
48488	5	49	79	19344	28445	\N	55.895741999999998	п. Зарянка, Центральная, 6		0101000020E6100000D42CD0EE90835640AAD381ACA7F24B40
48528	5	49	79	49587	27960	\N	55.672407	д. Жгутово, Набережная, 16	Россия, Красноярский край, Назаровский район, поселок Жгутово	0101000020E61000007BF65CA6269C5640FD4CBD6E11D64B40
48482	5	49	79	48918	72932	\N	55.936256999999998	д. Ельник, Комсомольская, 4		0101000020E61000001F9DBAF25982564056D3F544D7F74B40
48493	5	49	79	33058	72638	\N	56.031287021346103	с. Дорохово, Зеленая, 39	Россия, Красноярский край, Назаровский район, поселок Дорохово	0101000020E61000003E7958A8359456401DE5603601044C40
48494	5	49	79	33058	28463	\N	56.034747000000003	с. Дорохово, Верхняя, 56		0101000020E610000047C7D5C8AE9156402B51F69672044C40
48492	5	49	79	19557	72921	\N	55.787593999999999	п. Голубки, Школьная, 20		0101000020E6100000EC51B81E858C56404E4354E1CFE44B40
48485	5	49	79	19153	72821	\N	55.779557796807602	п. Глядень, Элеваторная, 1	Россия, Красноярский край, Назаровский район, поселок Глядень	0101000020E61000003B18B14F00895640E7AA798EC8E34B40
48484	5	49	79	19153	28615	\N	55.779944772588799	п. Глядень, Новая, 19	Россия, Красноярский край, Назаровский район, поселок Глядень	0101000020E6100000EC87D860E1885640E0D6DD3CD5E34B40
48498	5	49	79	19153	28626	\N	55.7794610522593	"д. Глядень, Пролетарская, 7 ""А"""	Россия, Красноярский край, Назаровский район, поселок Глядень	0101000020E6100000D87DC7F0D8885640F4C0C760C5E34B40
48495	5	49	79	49121	28452	\N	56.017322	д. Владимировка, Новая, 1		0101000020E6100000268A90BA9DA156402BC0779B37024C40
48362	5	49	1068	13126	28456	\N	54.122225999999998	Красноярский край, Курагинский район, с. Поначево, Горка, 37		0101000020E6100000DECCE847C3315740465C001AA50F4B40
48526	5	49	79	21376	28304	\N	55.686177999999998	д. Верхняя Березовка, Заречная, 35	Россия, Красноярский край, Назаровский район, поселок Верхняя Березовка	0101000020E6100000A779C7293A9256400A9E42AED4D74B40
48480	5	49	79	18923	72947	\N	55.906584000000002	"c. Верхний Ададым, Курская, 21""А"""	Россия, Красноярский край, Назаровский район, поселок Верхний Ададым	0101000020E6100000BB99D18F868C5640D789CBF10AF44B40
48503	5	49	79	20151	27745	\N	55.679284609977501	"с. Большая Сосновка, Школьная, 1 ""А"""	Россия, Красноярский край, Назаровский район, поселок Большая Сосновка	0101000020E610000033C170AE61825640E9D495CFF2D64B40
48499	5	49	79	59764	73014	\N	55.722653999999999	п. Березовая Роща, Клубная, 16	Россия, Красноярский край, Назаровский район, поселок Березовая Роща	0101000020E6100000B4722F302B8156406B2920ED7FDC4B40
48500	5	49	79	49196	28627	\N	55.722943000000001	п. Березняки, Дорожная, 25		0101000020E6100000FBEAAA402D765640A2EF6E6589DC4B40
48486	5	49	79	48976	27723	\N	55.815893000000003	с. Антропово, Романова, 21		0101000020E6100000A6D3BA0D6A89564086048C2E6FE84B40
48464	5	49	1541	59568	72047	\N	58.182454763993697	Красноярский край, Мотыгинский район, п. Мотыгино, Центральная, 8А	Россия	0101000020E6100000B2D6506A2FAD5740EFFE78AF5A174D40
48463	5	49	1541	59568	71978	\N	58.179915852329799	Красноярский край, Мотыгинский район, п. Мотыгино, Советская, 28		0101000020E6100000F2B0506B9AAB57407903CC7C07174D40
48479	5	49	1541	51853	28369	\N	58.786460170547102	Красноярский край, Мотыгинский район, п. Южно-Енисейск, Оборонная, 16	Россия, Красноярский край, Мотыгинский район	0101000020E6100000865AD3BCE3A857405BCEA5B8AA644D40
48478	5	49	1541	18820	72734	\N	57.984575	Красноярский край, Мотыгинский район, Первомайский сельсовет, п. Слюдрудник, Клубная, 2		0101000020E6100000ADA415DF508C5740C7BAB88D06FE4C40
48476	5	49	1541	59587	72203	\N	58.412552128482702	Красноярский край, Мотыгинский район, Поселок Раздолинск, Комсомольская, 11	Россия	0101000020E6100000A088450C3BA757401FF30181CE344D40
48473	5	49	1541	59677	72708	\N	58.018412988470601	Красноярский край, Мотыгинский район, Первомайский сельсовет, п. Первомайск, Центральная, 7	Россия	0101000020E610000072C45A7C0A8657401F69705B5B024D40
48474	5	49	1541	59710	72793	\N	58.688020000000002	Красноярский край, Мотыгинский район, Партизанский сельсовет, п. Партизанск, Центральная, 3	Россия	0101000020E610000074620FED638F5740397F130A11584D40
48472	5	49	1541	59714	72808	\N	58.453788000000003	Красноярский край, Мотыгинский район, Орджоникидзевский сельсовет, п. Орджоникидзе, Строителей, 30	Россия	0101000020E610000094162EABB0DC57409CA8A5B9153A4D40
48470	5	49	1541	51771	73111	\N	58.125830123142798	Красноярский край, Мотыгинский район, Новоангарский сельсовет, п. Новоангарск, Просвещения, 17		0101000020E6100000A67F492A53605740876D8B321B104D40
48471	5	49	1541	51771	27933	\N	58.124286199017803	Красноярский край, Мотыгинский район, Новоангарский сельсовет, п. Новоангарск, 4 квартал, 8		0101000020E6100000569C6A2DCC5F5740E2AC889AE80F4D40
47606	5	49	1541	48195	28145	\N	57.881903999999999	с. Никольск ул. Советская 39		0101000020E6100000441669E21D905740151BF33AE2F04C40
48465	5	49	1541	59678	72712	\N	58.182198065201099	Красноярский край, Мотыгинский район, п. Мотыгино, Шоссейная, 50		0101000020E610000009FB761211AD5740C4B2994352174D40
48462	5	49	1541	59678	72730	\N	58.173383729504501	Красноярский край, Мотыгинский район, п. Мотыгино, Советская, 128	Россия	0101000020E610000000FF942A51AD574028D3687231164D40
48469	5	49	1541	18329	28068	\N	57.794367999999999	Красноярский край, Мотыгинский район, Машуковский сельсовет, п. Машуковка, Центральная, 10	Россия, Красноярский край, Мотыгинский район, поселок Машуковка	0101000020E61000005C1B2AC6F9985740957EC2D9ADE54C40
48468	5	49	1541	59730	72926	\N	57.741559000000002	Красноярский край, Мотыгинский район, Кирсантьевский сельсовет, п. Кирсантьево, Новая, 22		0101000020E61000004F232D95B7B85740F986C267EBDE4C40
48466	5	49	1541	59809	73072	\N	58.1706654206588	Красноярский край, Мотыгинский район, Рыбинский сельсовет, п. Бельск, Советская, 11	Россия	0101000020E61000003FFD67CD8FA1574032C9C859D8154D40
48457	5	49	1439	17736	28420	\N	53.692785999999998	Красноярский край, Минусинский район, поселок имени Крупской, Вокзальная, 9а		0101000020E6100000766C04E275FD564036902E36ADD84A40
48448	5	49	1439	17308	28045	\N	53.818514	Красноярский край, Минусинский район, село Шошино, Хвастанцева, 48		0101000020E61000009C3061342B1C5740B9A81611C5E84A40
48461	5	49	1439	17934	72623	\N	53.593992	Красноярский край, Минусинский район, село Тигрицкое, Ленина, 48		0101000020E610000023145B41D31A5740F60A0BEE07CC4A40
48435	5	49	1439	16648	28042	\N	53.868307999999999	Красноярский край, Минусинский район, село Тесь, Мира, 14		0101000020E61000005F402FDCB90B5740766D6FB724EF4A40
48452	5	49	1439	17492	28412	\N	53.607548000000001	Красноярский край, Минусинский район, поселок Сухое Озеро, Школьная, 7		0101000020E6100000880E812381F9564007600322C4CD4A40
48434	5	49	1439	16583	72911	\N	53.784745999999998	Красноярский край, Минусинский район, поселок Суходол, Трактовая, 6		0101000020E61000003DD52137C3F156405AD5928E72E44A40
48447	5	49	1439	17248	28580	\N	53.658261000000003	Красноярский край, Минусинский район, деревня Солдатово, Некрасова, 43		0101000020E6100000ABECBB22F8F55640BB9D7DE541D44A40
48438	5	49	1439	16803	72651	\N	53.796326000000001	Красноярский край, Минусинский район, поселок Прихолмье, Зеленая, 19-1		0101000020E610000028D53E1D8F0457402D7AA702EEE54A40
48439	5	49	1439	16858	28395	\N	53.901085000000002	Красноярский край, Минусинский район, поселок Притубинский, Комсомольская, 16		0101000020E61000004A60730E9E00574045F5D6C056F34A40
48450	5	49	1439	17397	72733	\N	53.549767000000003	Красноярский край, Минусинский район, поселок Пригородный, Весёлая, 4		0101000020E610000047753A90F5015740C4B5DAC35EC64A40
48445	5	49	1439	59751	72995	\N	53.673492000000003	Красноярский край, Минусинский район, поселок Опытное поле, Набережная, 13		0101000020E6100000279F1EDB32EB56400F0F61FC34D64A40
48138	5	49	272	32776	73274	\N	55.610255000000002	Ирбейский район, д. Первое Мая Центральная 21		0101000020E61000002A8F6E8445D65740399CF9D51CCE4B40
48442	5	49	1439	16982	28575	\N	53.598630999999997	Красноярский край, Минусинский район, поселок Озеро Тагарское, Юбилейная, 16		0101000020E61000009B20EA3E00F3564096AFCBF09FCC4A40
48429	5	49	1439	16343	28036	\N	53.871811999999998	Красноярский край, Минусинский район, село Новотроицкое, улица Мира, 2		0101000020E61000008907944DB9F2564053211E8997EF4A40
48428	5	49	1439	16277	28391	\N	53.933407000000003	Красноярский край, Минусинский район, село Николо Петровка, Советская, 43 Б		0101000020E6100000E3A6069ACFEB5640C26D6DE179F74A40
48455	5	49	1439	17642	72739	\N	53.629649999999998	Красноярский край, Минусинский район, село Малая Ничка, 1 Мая, 9	Россия, Красноярский край, Минусинский район, поселок Малая Ничка	0101000020E6100000139B8F6B4302574094F6065F98D04A40
48433	5	49	1439	16538	28041	\N	53.730096000000003	Красноярский край, Минусинский район, село Малая Минуса, переулок Центральный, 6		0101000020E61000003CF6B3588AF25640607825C973DD4A40
48437	5	49	1439	16760	72798	\N	53.804935999999998	Красноярский край, Минусинский район, деревня Малая Иня, Чапаева, 42	Россия, Красноярский край, Минусинский район, поселок Малая Иня	0101000020E6100000A857CA32C40D5740C0AF912408E74A40
48440	5	49	1439	16891	28193	\N	53.519739000000001	Красноярский край, Минусинский район, село Лугавское, Ленина, 16		0101000020E61000008C118942CBF2564056BABBCE86C24A40
48441	5	49	1439	16959	28399	\N	53.592452999999999	Красноярский край, Минусинский район, село Кутужеково, Ленина, 21	Россия, Красноярский край, Минусинский район, поселок Кутужеково	0101000020E610000095D74AE82EFB564063B5F97FD5CB4A40
47172	5	49	1439	59828	73094	\N	53.928652125513103	п.Курейка, Октябрьская, 1а	Россия, Красноярский край, Минусинский район	0101000020E6100000514F1F813FFE5640B8AE9811DEF64A40
48348	5	49	1439	32811	72668	\N	53.815367000000002	Красноярский край, Курагинский район, Кочергинский сельсовет, с. Кочергино, Школьная, 1-А		0101000020E6100000FE4465C39A1F57406B9E23F25DE84A40
48456	5	49	1439	17710	72909	\N	53.690888000000001	Красноярский край, Минусинский район, деревня Коныгино, Боровая, 8		0101000020E610000081AFE8D66B03574074999A046FD84A40
48459	5	49	1439	17846	28211	\N	53.711938000000004	Красноярский край, Минусинский район, село Колмаково, Луговая, 10		0101000020E6100000616F62484E135740CC63CDC820DB4A40
48431	5	49	1439	16448	27831	\N	53.965586999999999	Красноярский край, Минусинский район, село Кавказское, Калинина, 37-1	Россия, Красноярский край, Минусинский район, поселок Кавказское	0101000020E61000004819710168FB5640AC38D55A98FB4A40
48449	5	49	1439	17315	28197	\N	53.533892000000002	Красноярский край, Минусинский район, село Знаменка, Пролетарская, 58		0101000020E6100000043752B648FA56404BCCB39256C44A40
48458	5	49	1439	17799	27870	\N	53.756082999999997	Красноярский край, Минусинский район, село Жерлык, Школьная, 2		0101000020E6100000DCBA9BA73A1C5740E107E753C7E04A40
48427	5	49	1439	16234	28033	\N	53.921880999999999	Красноярский край, Минусинский район, село Городок, Заводская, 5		0101000020E6100000063065E080F35640E2E6543200F64A40
48451	5	49	1439	17429	72901	\N	53.574807999999997	Красноярский край, Минусинский район, село Восточное, Ленина, 98		0101000020E6100000B1BFEC9E3C08574055BDFC4E93C94A40
48453	5	49	1439	17548	27865	\N	53.494698	Красноярский край, Минусинский район, село Верхняя Коя, Юбилейная, 2		0101000020E6100000BBD1C77C400A5740C4B2994352BF4A40
48430	5	49	1439	59655	72663	\N	53.723402717493798	Красноярский край, Минусинский район, деревня Быстрая, переулок Молодёжный, 2		0101000020E6100000F30016F9F5E55640056A317898DC4A40
48454	5	49	1439	17607	28051	\N	53.667219000000003	Красноярский край, Минусинский район, село Большая Ничка, Автомобильная, 83		0101000020E6100000BCE7C072840857408A22A46E67D54A40
48436	5	49	1439	16690	28568	\N	53.767223999999999	Красноярский край, Минусинский район, село Большая Иня, Ленина, 4		0101000020E6100000F487669E5C075740685A626534E24A40
48406	5	49	1366	15241	71602	\N	55.715429	Красноярский край, Манский район, с.Шалинское, ул.Манская, д.50		0101000020E61000000B4625750270574014CE6E2D93DB4B40
48407	5	49	1366	15241	71623	\N	55.715429	Красноярский край, Манский район, с.Шалинское, ул.Ленина, д.33		0101000020E61000000B4625750270574014CE6E2D93DB4B40
48404	5	49	1366	15116	72896	\N	55.877985000000002	Красноярский край, Манский район, с.Тертеж ул.Юности д.1в		0101000020E6100000481630815B70574075B0FECF61F04B40
47815	5	49	1366	41028	12172	\N	55.828507913136598	"п. Таежный, Новая, 6 ""В"""	Россия, Красноярский край, Манский район, поселок Новосельск	0101000020E610000078EFA831215F5740B83CD68C0CEA4B40
48411	5	49	1366	15478	28360	\N	55.576518	Красноярский край, Манский район, д.Сугристое, ул.Лесная, д.2		0101000020E6100000A112D731AE76574015C78157CBC94B40
48423	5	49	1366	16031	28564	\N	55.204217	Красноярский край, Манский район, с.Степной Баджей ул.Партизанская д.1	Россия, Красноярский край, Манский район, поселок Степной Баджей	0101000020E6100000DE019EB470705740C4245CC8239A4B40
48409	5	49	1366	59766	73017	\N	55.635196805370697	Красноярский край, Манский район, д.Сосновка ул.Трактовая д.46 Б	Россия, Красноярский край, Манский район, поселок Сосновка	0101000020E6100000A5BF97C28371574037C2A2224ED14B40
48405	5	49	1366	15184	28353	\N	55.928068000000003	"Красноярский край, Манский район, д.Сергеевка, ул.Центральная, д.38 ""А"""	Россия, Красноярский край, Манский район, поселок Сергеевка	0101000020E6100000F778211D1E735740693BA6EECAF64B40
48412	5	49	1366	15538	28141	\N	55.586781999999999	Красноярский край, Манский район, д.Покосное ул.Зеленая д.2		0101000020E61000004AECDADE6E7C5740D4F02DAC1BCB4B40
48419	5	49	1366	15857	28029	\N	55.362203999999998	Красноярский край, Манский район, п.Пимия, ул.Центральная, д.28		0101000020E6100000EFC8586DFE6857407D3D5FB35CAE4B40
48398	5	49	1366	14834	27814	\N	55.854970999999999	Красноярский край, Манский район, п.Первоманск, ул.Крупской, д.4	Россия, Красноярский край, Манский район, поселок Первоманск	0101000020E6100000D8F0F44A59685740A30392B06FED4B40
48245	5	49	936	32793	73256	\N	53.599170999999998	662850 Каратузский район, Каратузский сельсовет, с.Каратузское Советская 21		0101000020E610000043AB93331438574016DBA4A2B1CC4A40
48420	5	49	1366	15892	72903	\N	55.292186999999998	Красноярский край, Манский район, п.Орешное ул.Партизанская д.5	Россия, Красноярский край, Манский район, поселок Орешное	0101000020E6100000EA4141295A6B57407EA8346266A54B40
48400	5	49	1366	14962	72912	\N	55.822837	Красноярский край, Манский район, д.Новосельск, ул.Железнодорожная, д.72 кв.2		0101000020E6100000274BADF71B5F574029780AB952E94B40
48401	5	49	1366	14972	28348	\N	55.783619999999999	Красноярский край, Манский район, д.Новоникольск ул.Центральная д.34а		0101000020E6100000BE13B35E0C675740EA3E00A94DE44B40
48410	5	49	1366	15413	72837	\N	55.564444999999999	Красноярский край, Манский район, д.Новомихайловка ул.Здрестова д.20		0101000020E61000004A0C022B8771574003B2D7BB3FC84B40
48403	5	49	1366	15088	27947	\N	55.785868000000001	Красноярский край, Манский район, с.Нижняя Есауловка, ул.Школьная, д.12		0101000020E6100000378E588B4F6E5740897C975297E44B40
48417	5	49	1366	15753	27977	\N	55.403410000000001	Красноярский край, Манский район, п.Нарва, ул.Кравченко, д.45		0101000020E61000007E71A94A5B6957408F705AF0A2B34B40
48418	5	49	1366	15753	28376	\N	55.403410000000001	Красноярский край, Манский район, п.Нарва, ул.Заводская, д.21	Россия, Красноярский край, Манский район, поселок Нарва	0101000020E61000007E71A94A5B6957408F705AF0A2B34B40
48415	5	49	1366	15670	72838	\N	55.442224000000003	Красноярский край, Манский район, п.Малый Унгут, ул.Манская, д.29		0101000020E61000006D533C2EAA565740CFC0C8CB9AB84B40
48396	5	49	1366	14757	72915	\N	55.950574000000003	Красноярский край, Манский район, д.Кускун, ул.Трактовая, д.36		0101000020E610000092955F0663655740C636A968ACF94B40
48421	5	49	1366	15946	28027	\N	55.164057999999997	Красноярский край, Манский район, п.Колбинский ул.Советская д.2		0101000020E6100000A6D3BA0D6A605740D65240DAFF944B40
48413	5	49	1366	15559	28016	\N	55.515537999999999	Красноярский край, Манский район, с.Кияй, ул.Школьная, д.2		0101000020E61000006C43C5387F71574031EC3026FDC14B40
48424	5	49	1366	16072	27866	\N	55.11027	Красноярский край, Манский район, д.Кирза ул.Чапаева д.28		0101000020E61000009CFD8172DB7257406EDDCD531D8E4B40
49017	5	49	1366	59694	\N	\N	55.5968707308459	п. Каяк, Сельский дом культуры		0101000020E61000009D103AE8127C57402577D84466CC4B40
48402	5	49	1366	15037	28349	\N	55.811953000000003	Красноярский край, Манский район, п.Камарчага ул.Линейная д.21		0101000020E61000009E7B0F971C6C5740CE716E13EEE74B40
48426	5	49	1366	16176	28384	\N	54.85163	Красноярский край, Манский район, п.Жайма, ул.Вокзальная, д.2 пом.11		0101000020E6100000BC0512143F6B574070253B36026D4B40
48425	5	49	1366	16134	27840	\N	54.974003000000003	Красноярский край, Манский район, д.Выезжий Лог, ул.Советская, д.31а		0101000020E6100000130CE71A667B57405B9A5B21AC7C4B40
48397	5	49	1366	14816	28158	\N	55.891845000000004	Красноярский край, Манский район, п.Ветвистый, ул.Мирная, д.2		0101000020E6100000B0E600C11C665740F20C1AFA27F24B40
48408	5	49	1366	15329	72790	\N	55.673721999999998	Красноярский край, Манский район, д.Верхняя Есауловка, ул.Мира, д.33		0101000020E6100000EA78CC4065725740404CC2853CD64B40
48414	5	49	1366	15621	28367	\N	55.430349999999997	Красноярский край, Манский район, п.Большой Унгут, ул.Юбилейная, д.2	Россия, Красноярский край, Манский район, поселок Большой Унгут	0101000020E6100000BB0D6ABFB55A5740B3EA73B515B74B40
48422	5	49	1366	15988	28180	\N	55.123384000000001	Красноярский край, Манский район, п.Анастасино, ул.Мира, д.5		0101000020E6100000D9791B9B1D595740C26C020CCB8F4B40
47240	5	49	7127	51865	28440	\N	56.007916000000002	Красноярский край, город Красноярск, Ленинский район, Москаовская, 20А		0101000020E6100000A29A92ACC33D5740BD8E386403014C40
47698	5	49	1068	12893	28203	\N	54.537092000000001	д.Щетинкино, Школьная, 2	Россия, Красноярский край, Курагинский район, поселок Щетинкино	0101000020E61000009F5912A0A65C5740BC783F6EBF444B40
48395	5	49	1068	12893	28155	\N	54.537092000000001	Красноярский край, Курагинский район, Щетинкинский сельсовет, с. Щетинкино, Кравченко, 7		0101000020E61000009F5912A0A65C5740BC783F6EBF444B40
48342	5	49	1068	12219	72692	\N	53.940581826447001	Красноярский край, Курагинский район, Шалоболинский сельсовет, с. Шалоболино, Ленина, 38-А	Россия, Красноярский край, Курагинский район, поселок Шалоболино	0101000020E610000014D1AFAD9F125740679AB0FD64F84A40
48394	5	49	1068	14671	27811	\N	54.399231999999998	Красноярский край, Курагинский район, р.п. Чибижек, Заречная, 30	Россия, Красноярский край, Курагинский район, поселок городского типа Чибижек	0101000020E6100000EDD286C3D267574022C2BF081A334B40
48387	5	49	1068	14322	28643	\N	53.876987	Красноярский край, Курагинский район, Черемшанский сельсовет, с. Черемшанка, Октябрьская, 51		0101000020E61000006DE34F54366F574032022A1C41F04A40
47878	5	49	1068	14322	27861	\N	53.877156044223803	д.Черемшанка, Лесная, 23	Россия, Красноярский край, Курагинский район, поселок Черемшанка	0101000020E61000006CAF05BD376F5740BEBED6A546F04A40
48360	5	49	1068	13057	28324	\N	54.039968000000002	Красноярский край, Курагинский район, Березовский сельсовет, д. Уральская, Молодежная, 2-А		0101000020E61000008693347F4C3457407A71E2AB1D054B40
48385	5	49	1068	14231	27805	\N	53.924612000000003	Красноярский край, Курагинский район, Можарский сельсовет, с. Тюхтят, Центральная, 34	Россия, Красноярский край, Курагинский район, поселок Тюхтят	0101000020E6100000151A8865336157409DBE9EAF59F64A40
48370	5	49	1068	13534	72889	\N	54.187658999999996	Красноярский край, Курагинский район, Брагинский сельсовет, п. Тагашет, Трудовая, 31-А		0101000020E610000026FC523F6F26574068E6C93505184B40
48868	5	49	1068	13807	27927	\N	53.876847083666	Красноярский край, Уярский район, Рощинский сельсовет, Советская, 8	Россия, Красноярский край, Курагинский район, поселок Рощинский	0101000020E610000003250516C0315740404CC2853CF04A40
48376	5	49	1068	13807	72586	\N	53.877609	Красноярский край, Курагинский район, Рощинский сельсовет, п. Рощинский, Мира, 30		0101000020E6100000D3122BA3913257406FD6E07D55F04A40
48365	5	49	1068	13267	28510	\N	53.998874999999998	Красноярский край, Курагинский район, Марининский сельсовет, п. Прудный, Клубная, 1		0101000020E6100000191D90847D1E574060E5D022DBFF4A40
48345	5	49	1068	12387	27780	\N	53.853205000000003	Красноярский край, Курагинский район, Пойловский сельсовет, с.Пойлово, Мира, 1-Б	Россия, Красноярский край, Курагинский район, поселок Пойлово	0101000020E6100000259012BBB61C574050E449D235ED4A40
48378	5	49	1068	13815	72894	\N	53.850610753798499	Красноярский край, Курагинский район, Рощинский сельсовет, п. Подгорный, Трактовая, 11	Россия, Красноярский край, Курагинский район, поселок Подгорный	0101000020E6100000C7D9740470365740164F3DD2E0EC4A40
48386	5	49	1068	14271	27926	\N	53.900841	Красноярский край, Курагинский район, Черемшанский сельсовет, д. Петропавловка, Октябрьская, 7		0101000020E61000002B85402E716A5740AEF204C24EF34A40
48349	5	49	1068	12576	72962	\N	53.868248999999999	Красноярский край, Курагинский район, с. Ойха, Мира, 6-А		0101000020E61000008CDAFD2AC024574071E481C822EF4A40
48341	5	49	1068	12176	72958	\N	54.123877	Красноярский край, Курагинский район, Алексеевский сельсовет, д. Новопокровка, Школьная, 42-Б		0101000020E6100000E5805D4D9E11574001DD9733DB0F4B40
48393	5	49	1068	14604	28151	\N	54.216794	Красноярский край, Курагинский район, с Нижняя Быстрая, Центральная, 44-2		0101000020E6100000359BC7613034574009FCE1E7BF1B4B40
48346	5	49	1068	12418	72961	\N	53.838585999999999	Красноярский край, Курагинский район, Муринский сельсовет, с.Мурино, Ленина, 14		0101000020E6100000B62BF4C13226574015713AC956EB4A40
48384	5	49	1068	14173	72629	\N	53.965221999999997	Красноярский край, Курагинский район, Можарский сельсовет, с. Можарка, Школьная, 7-А		0101000020E6100000F9A23D5E485557409AB0FD648CFB4A40
48363	5	49	1068	13186	72632	\N	54.018796999999999	Красноярский край, Курагинский район, Марининский сельсовет, с. Маринино, Школьная, 2		0101000020E610000037C7B94DB8255740A721AAF067024B40
48371	5	49	1068	13542	28542	\N	53.985292000000001	Красноярский край, Курагинский район, Курский сельсовет, с. Курское, Октябрьская, 48		0101000020E6100000917BBABA633A574056815A0C1EFE4A40
48343	5	49	1068	12267	27968	\N	53.979382999999999	Красноярский край, Курагинский район, Шалоболинский сельсовет, д. Курганчики, Комсомольская, 46-А		0101000020E61000005454FD4AE714574012A1116C5CFD4A40
48352	5	49	1068	59475	71566	\N	53.883198	Красноярский край, Курагинский район, р.п. Курагино, Трактовая, 20		0101000020E61000007D59DAA9B92A574041F2CEA10CF14A40
48351	5	49	1068	59475	71520	\N	53.883198	Красноярский край, Курагинский район, р.п. Курагино, Партизанская, 47		0101000020E61000007D59DAA9B92A574041F2CEA10CF14A40
48350	5	49	1068	59475	71520	\N	53.890296779688001	Красноярский край, Курагинский район, р.п. Курагино, Партизанская, 8	Россия, Красноярский край, Курагинский район, поселок городского типа Курагино	0101000020E61000003E9468C9E32B57400B5D8940F5F14A40
48355	5	49	1068	59475	71621	\N	53.883198	Красноярский край, Курагинский район, р.п. Курагино, Новостройка, 15		0101000020E61000007D59DAA9B92A574041F2CEA10CF14A40
48353	5	49	1068	12592	27757	\N	53.883198	Красноярский край, Курагинский район, р.п. Курагино, Партизанская, 154	Россия, Красноярский край, Курагинский район, поселок городского типа Курагино	0101000020E61000007D59DAA9B92A574041F2CEA10CF14A40
48358	5	49	1068	12592	72690	\N	53.883198	Красноярский край, Курагинский район, р.п. Курагино, Новостройка, 1	Россия, Красноярский край, Курагинский район, поселок городского типа Курагино	0101000020E61000007D59DAA9B92A574041F2CEA10CF14A40
48356	5	49	1068	12592	28653	\N	53.883198	Красноярский край, Курагинский район, р.п. Курагино, Монаенко, 2-Б		0101000020E61000007D59DAA9B92A574041F2CEA10CF14A40
48357	5	49	1068	12592	28321	\N	53.883198	Красноярский край, Курагинский район, р.п. Курагино, Красноярская, 8-А	Россия, Красноярский край, Курагинский район, поселок городского типа Курагино	0101000020E61000007D59DAA9B92A574041F2CEA10CF14A40
48372	5	49	1068	13616	28506	\N	54.068758000000003	Красноярский край, Курагинский район, Курский сельсовет, п. Красный Кордон, Железнодорожников, 5	Россия, Красноярский край, Курагинский район, поселок Красный Кордон	0101000020E6100000079ACFB9DB44574050ABE80FCD084B40
48392	5	49	1068	14546	28342	\N	54.339436999999997	Красноярский край, Курагинский район, р.п. Краснокаменск, Центральная, 8-А	Россия, Красноярский край, Курагинский район, поселок городского типа Краснокаменск	0101000020E610000074B33F506E505740B306EFAB722B4B40
48391	5	49	1068	14457	27815	\N	54.308818000000002	Красноярский край, Курагинский район, р.п. Кошурниково, Центральная, 2-Б		0101000020E61000009E5DBEF5615857404435255987274B40
48390	5	49	1068	14457	27942	\N	54.308818000000002	Красноярский край, Курагинский район, р.п. Кошурниково, Невского, 12		0101000020E61000009E5DBEF5615857404435255987274B40
48373	5	49	1068	13662	28329	\N	54.093556999999997	Красноярский край, Курагинский район, Кордовский сельсовет, с. Кордово, Наберажная, 32		0101000020E6100000D76D50FBAD515740EBA7FFACF90B4B40
48383	5	49	1068	14135	27801	\N	53.903477000000002	Красноярский край, Курагинский район, Имисский сельсовет, с. Имисское, Береговая, 15-А		0101000020E61000005987A3AB744A574017D86322A5F34A40
48344	5	49	1068	51890	28531	\N	54.2689893010349	Красноярский край, Курагинский район, Шалоболинский сельсовет, д. Ильинка, Боровая, 22	Россия, Красноярский край, Курагинский район	0101000020E610000050A73CBA11615740EBFD463B6E224B40
48367	5	49	1068	13388	28149	\N	54.054076999999999	Красноярский край, Курагинский район, Детловский сельсовет, п. Заречный, Верхняя, 4	Россия, Красноярский край, Курагинский район, поселок Заречный	0101000020E6100000321EA5129E1857409F3BC1FEEB064B40
48368	5	49	1068	13415	28156	\N	54.109195	Красноярский край, Курагинский район, Детловский сельсовет, п. Загорье, Советская, 1		0101000020E61000000ADAE4F04922574080F10C1AFA0D4B40
47854	5	49	1460	20726	72866	\N	56.846691	деревня Пакуль, Лесная, 13		0101000020E6100000DD0C37E0F3545740A568E55E606C4C40
48375	5	49	1068	13745	27982	\N	54.160975999999998	Красноярский край, Курагинский район, Кордовский сельсовет, п. Журавлево, Лесная, 8	Россия, Красноярский край, Курагинский район, поселок Журавлёво	0101000020E61000001A187959135057406FB88FDC9A144B40
48381	5	49	1068	14043	28336	\N	53.865011000000003	Красноярский край, Курагинский район, Имисский сельсовет, п. Жербатиха, Школьная, 29		0101000020E610000079060DFD1347574013D731AEB8EE4A40
48366	5	49	1068	13341	28514	\N	54.089750000000002	Красноярский край, Курагинский район, Детловский сельсовет, с. Детлово, Ленина, 32		0101000020E61000006D8D08C6C11C5740736891ED7C0B4B40
48380	5	49	1068	13957	72897	\N	53.813091999999997	Красноярский край, Курагинский район, Рощинский сельсовет, п. Бугуртак, Береговая, 19	Россия, Красноярский край, Курагинский район, поселок Бугуртак	0101000020E6100000BEDA519CA3375740D2510E6613E84A40
48369	5	49	1068	13472	28528	\N	54.112372999999998	Красноярский край, Курагинский район, Брагинский сельсовет, с. Брагино, Центральная, 75		0101000020E61000007592AD2EA726574009FA0B3D620E4B40
48284	5	49	1068	9425	28328	\N	54.084964999999997	Красноярский край, Кежемский район, с.Ирба, Луговая, 4	Россия, Красноярский край, Курагинский район, поселок городского типа Большая Ирба	0101000020E6100000EF1EA0FB723B5740FE261422E00A4B40
48361	5	49	1068	9425	71574	\N	54.082085368800001	Красноярский край, Курагинский район, р.п. Большая Ирба, Ленина, 2-А	Россия, Красноярский край, Курагинский район, поселок городского типа Большая Ирба	0101000020E610000004560E2DB23B5740FF3EE3C2810A4B40
48359	5	49	1068	12979	28315	\N	53.933900000000001	Красноярский край, Курагинский район, Березовский сельсовет, с. Березовское, Ленина, 4	Россия, Красноярский край, Курагинский район, поселок Березовское	0101000020E6100000C47762D68B33574001DE02098AF74A40
48347	5	49	1068	10144	72887	\N	53.838517000000003	Красноярский край, Курагинский район, Муринский сельсовет, д. Белый Яр, Зеленая, 17		0101000020E6100000DAAED007CB2A5740ED116A8654EB4A40
48364	5	49	1068	13256	27992	\N	54.008861000000003	Красноярский край, Курагинский район, Марининский сельсовет, п. Байдово, Мира, 27	Россия, Красноярский край, Курагинский район, поселок Байдово	0101000020E610000060ADDA3521245740DD9A745B22014B40
48388	5	49	1068	14368	28154	\N	54.347079000000001	Красноярский край, Курагинский район, г. Артёмовск, Ольховская, 124		0101000020E61000003B730F09DF5B57406F10AD156D2C4B40
48340	5	49	1068	12141	28262	\N	54.051428999999999	Красноярский край, Курагинский район, Алексеевский сельсовет, с. Алексеевка, Колхозный, 2		0101000020E610000092CB7F48BF0E57407288B83995064B40
48339	5	49	1149	12100	\N	\N	54.619453	Красноярский край, Краснотуранский район, Беллыкский сельсовет, деревня Уяр, Здание сельского дома культуры		0101000020E610000056478E7406D756405D34643C4A4F4B40
48338	5	49	1149	12020	\N	\N	54.436486000000002	Красноярский край, Краснотуранский район, Кортузский сельсовет, деревня Уза, Здание сельского дома культуры		0101000020E610000087A5811FD5E75640B894F3C5DE374B40
48337	5	49	1149	11992	\N	\N	54.077759999999998	Красноярский край, Краснотуранский район, Тубинский сельсовет, село Тубинск, Здание сельского дома культуры		0101000020E61000001CB62DCA6C025740EE77280AF4094B40
48336	5	49	1149	11936	\N	\N	54.247714287082601	Красноярский край, Краснотуранский район, Саянский сельсовет, поселок Теплый Ключ, Здание сельского клуба	Россия, Красноярский край, Краснотуранский район, поселок Теплый Ключ	0101000020E61000009DB98784EFFB56407461A417B51F4B40
48335	5	49	1149	11877	\N	\N	54.151560000000003	Красноярский край, Краснотуранский район, Саянский сельсовет, село Саянск, Здание сельского дома культуры		0101000020E6100000AB048BC399F85640DEB06D5166134B40
48334	5	49	1149	11815	\N	\N	54.502527999999998	Красноярский край, Краснотуранский район, Кортузский сельсовет, деревня Сарушка, Здание сельского дома культуры		0101000020E61000002368CC24EAE2564082A966D652404B40
48333	5	49	1149	11793	\N	\N	54.679296000000001	Красноярский край, Краснотуранский район, Салбинский сельсовет, село Салба, Здание сельского совета		0101000020E610000013D4F02DACED5640DD26DC2BF3564B40
48332	5	49	1149	11748	\N	\N	54.057333	"Красноярский край, Краснотуранский район, Тубинский сельсовет, село Новоивановка, Здание конторы ЗАО ""Тубинск"""	Россия, Красноярский край, Краснотуранский район, поселок Новоивановка	0101000020E6100000828B153598025740A4FD0FB056074B40
48331	5	49	1149	11713	\N	\N	54.397920999999997	Красноярский край, Краснотуранский район, Новосыдинский сельсовет, село Новая Сыда, Здание сельского дома культуры	Россия, Красноярский край, Краснотуранский район, поселок Новая Сыда	0101000020E61000000D349F73B7DB564020B24813EF324B40
48330	5	49	1149	11635	\N	\N	54.296056999999998	Красноярский край, Краснотуранский район, Саянский сельсовет, деревня Николаевка, Здание сельского дома культуры		0101000020E6100000B2101D0247F956403D601E32E5254B40
48216	5	49	1149	11635	28359	\N	54.296056999999998	д.Николаевка, Центральная, 79		0101000020E6100000B2101D0247F956403D601E32E5254B40
48033	5	49	1149	11635	72874	\N	54.296056999999998	"деревня Николаевка, Красных Партизан, 28""а"""		0101000020E6100000B2101D0247F956403D601E32E5254B40
48329	5	49	1149	11574	\N	\N	54.169505000000001	Красноярский край, Краснотуранский район, Саянский сельсовет, село Моисеевка, Здание сельского дома культуры	Россия, Красноярский край, Краснотуранский район, поселок Моисеевка	0101000020E6100000A357039486F1564016C1FF56B2154B40
48328	5	49	1149	11542	\N	\N	54.193016999999998	Красноярский край, Краснотуранский район, Лебяженский сельсовет, село Лебяжье, Здание сельского дома культуры		0101000020E6100000B763EAAEECE456403849F3C7B4184B40
48327	5	49	1149	11386	28106	\N	54.315199999999997	Красноярский край, Краснотуранский район, Краснотуранский сельсовет, село Краснотуранск улица Советская д.20		0101000020E61000005F7CD11E2FE456407FD93D7958284B40
48326	5	49	1149	11386	28261	\N	54.315199999999997	Красноярский край, Краснотуранский район, Краснотуранский сельсовет, село Краснотуранск, улица Ленина, д.39		0101000020E61000005F7CD11E2FE456407FD93D7958284B40
48325	5	49	1149	11386	28261	\N	54.315199999999997	Красноярский край, Краснотуранский район, Краснотуранский сельсовет, село Краснотуранск улица Ленина д.20	Россия, Красноярский край, Краснотуранский район, поселок Краснотуранск	0101000020E61000005F7CD11E2FE456407FD93D7958284B40
48324	5	49	1149	11381	\N	\N	54.493952999999998	Красноярский край, Краснотуранский район, Кортузский сельсовет, село Кортуз, Здание сельского дома культуры		0101000020E6100000BE2EC37FBAEC56406B6116DA393F4B40
48322	5	49	1149	11246	\N	\N	54.582782999999999	Красноярский край, Краснотуранский район, Кортузский сельсовет, деревня Кара-Беллык, Здание сельского клуба		0101000020E61000000C022B8716E7564017D522A2984A4B40
48320	5	49	1149	11159	\N	\N	54.073365000000003	Красноярский край, Краснотуранский район, Восточенский сельсовет, деревня Диссос, Здание сельского клуба	Россия, Красноярский край, Краснотуранский район, поселок Диссос	0101000020E61000009A79724D81F65640E5D5390664094B40
48321	5	49	1149	11211	\N	\N	54.020060999999998	"Красноярский край, Краснотуранский район, Тубинский сельсовет, поселок Джирим, Здание конторы ЗАО ""Тубинск"""		0101000020E610000031CEDF84420857406876DD5B91024B40
48319	5	49	1149	11127	\N	\N	54.136707999999999	Красноярский край, Краснотуранский район, Тубинский сельсовет, село Галактионово, Здание сельского дома культуры		0101000020E6100000CD94D6DF12075740008DD2A57F114B40
48318	5	49	1149	11059	\N	\N	54.092224691231898	Красноярский край, Краснотуранский район, Восточенский сельсовет, село Восточное	Россия, Красноярский край, Краснотуранский район, поселок Восточное	0101000020E610000069FD2D01F8E95640D26F5F07CE0B4B40
48062	5	49	1149	11059	73201	\N	54.091002916414197	Красноярский край, Идринский район, пос. Восточный, Восточная, 1	Россия, Красноярский край, Краснотуранский район, поселок Восточное	0101000020E6100000DA8D3EE603EA5640406B7EFCA50B4B40
48316	5	49	1149	11001	\N	\N	54.388370000000002	Красноярский край, Краснотуранский район, Кортузский сельсовет, село Белоярск, Здание сельского дома культуры		0101000020E61000001651137D3EEB5640AF5FB01BB6314B40
48191	5	49	1149	11001	28170	\N	54.388370000000002	д.Белоярск, пер.Тупиковый, 2		0101000020E61000001651137D3EEB5640AF5FB01BB6314B40
48317	5	49	1149	11047	\N	\N	54.547474999999999	Красноярский край, Краснотуранский район, Беллыкский сельсовет, село Беллык, Здание сельского дома культуры		0101000020E6100000768A558330D5564055302AA913464B40
48315	5	49	1149	10923	\N	\N	54.629153000000002	Красноярский край, Краснотуранский район, Салбинский сельсовет, деревня Александровка, Здание сельского клуба		0101000020E61000005664744012F256401497E31588504B40
48313	5	49	1149	10794	\N	\N	54.654318000000004	Красноярский край, Краснотуранский район, Салбинский сельсовет, деревня Алгаштык, Здание начальной школы	Россия, Красноярский край, Краснотуранский район, поселок Алгаштык	0101000020E610000090D78349F1E65640929735B1C0534B40
48306	5	49	1080	51868	28451	\N	55.876404086848503	с. Шадрино, Советский, 7	Россия, Красноярский край, Козульский район, поселок Шадрино	0101000020E61000001B13622EA9C65640B30A9B012EF04B40
48295	5	49	1080	9981	28237	\N	56.206921999999999	д. Старая Козулька, Трактовая, 38	Россия, Красноярский край, Козульский район, поселок Старая Козулька	0101000020E6100000DCDAC2F352D5564055698B6B7C1A4C40
48309	5	49	1080	10598	28250	\N	56.268160999999999	п. Новочернореченский, Советская, 36		0101000020E61000009947FE60E0C556400588821953224C40
48310	5	49	1080	10598	27740	\N	56.268160999999999	п. Новочернореченский Железнодорожная 12	Россия, Красноярский край, Козульский район, поселок городского типа Новочернореченский	0101000020E61000009947FE60E0C556400588821953224C40
48311	5	49	1080	51768	71525	\N	56.268160999999999	п. Новочернореченский, Кооперативная, 30		0101000020E61000009947FE60E0C556400588821953224C40
48308	5	49	1080	51768	27929	\N	56.268160999999999	п. Новочернореченский, Деповская, 16		0101000020E61000009947FE60E0C556400588821953224C40
48305	5	49	1080	10452	72810	\N	56.070735999999997	д. Ничково, Школьный, 2		0101000020E61000000533A6608DCD56402E5393E00D094C40
48294	5	49	1080	33086	28081	\N	56.158912000000001	п. Лазурный, Центральная, 7	Россия, Красноярский край, Козульский район, поселок Лазурный	0101000020E610000003EB387EA8DA56409278793A57144C40
48304	5	49	1080	59908	73325	\N	55.986488765635301	" Красный Яр Чулымская 16 ""б"""	Россия, Красноярский край, Козульский район, поселок Красный Яр	0101000020E610000043E55FCB2BC356408F6E844545FE4B40
48301	5	49	1080	10237	27755	\N	56.134746	п. Косачи, Молодежная, 12	Россия, Красноярский край, Козульский район, поселок Косачи	0101000020E6100000904B1C7920E8564027A25F5B3F114C40
48290	5	49	1080	9530	28228	\N	56.165308000000003	"р.п. Козулька, Школьная, 6 ""а"""		0101000020E61000008A592F8672D9564033E202D028154C40
48289	5	49	1080	9530	28226	\N	56.165308000000003	р.п. Козулька, Советская, 76		0101000020E61000008A592F8672D9564033E202D028154C40
48288	5	49	1080	9530	28226	\N	56.163248000000003	р.п. Козулька, Советская, 60	Россия, Красноярский край, Козульский район, поселок городского типа Козулька	0101000020E61000006FBDA60705D9564097917A4FE5144C40
48287	5	49	1080	9530	28226	\N	56.165308000000003	р.п. Козулька, Советская, 7	Россия, Красноярский край, Козульский район, поселок городского типа Козулька	0101000020E61000008A592F8672D9564033E202D028154C40
48291	5	49	1080	9530	28443	\N	56.165308000000003	р.п. Козулька, Свердлова, 47		0101000020E61000008A592F8672D9564033E202D028154C40
48292	5	49	1080	9530	28079	\N	56.165308000000003	р.п. Козулька, 40 лет Победы, 70	Россия, Красноярский край, Козульский район, поселок городского типа Козулька	0101000020E61000008A592F8672D9564033E202D028154C40
48302	5	49	1080	40457	\N	\N	56.042914000000003	Заречный, в/ч 63185		0101000020E6100000E333D93F4FEE56403145B9347E054C40
48299	5	49	1080	33112	28620	\N	56.091321000000001	с. Жуковка, Школьная, 13		0101000020E6100000E15D2EE23BED564011381268B00B4C40
48303	5	49	1080	10356	27810	\N	55.984566999999998	"с. Балахтон Молодежная 2 ""а"""	Россия, Красноярский край, Козульский район, поселок Балахтон	0101000020E6100000226DE34F54CF564044DC9C4A06FE4B40
48307	5	49	1080	10593	72881	\N	55.795003000000001	д. Аммала, Рабочая, 34-1		0101000020E6100000C7D9740470C65640679C86A8C2E54B40
48270	5	49	1013	59719	72870	\N	57.890832000000003	Красноярский край, Кежемский район, п.Таежный, Первомайская		0101000020E6100000361FD7868AD158407A1D71C806F24C40
48286	5	49	1013	59782	73037	\N	59.134579000000002	Красноярский край, Кежемский район, с.Яркино, Центральная, 74	Россия	0101000020E6100000D9B45208E4D958403CDD79E239914D40
48279	5	49	1013	51799	28072	\N	57.890832000000003	Красноярский край, Кежемский район, д.Тагара, пер.Первомайский, 4		0101000020E6100000361FD7868AD158407A1D71C806F24C40
48269	5	49	1013	51862	28413	\N	57.890832000000003	Красноярский край, Кежемский район, п.Недокура, Супругов Самаль, 3		0101000020E6100000361FD7868AD158407A1D71C806F24C40
48277	5	49	1013	51817	28599	\N	58.680953923045699	Красноярский край, Кежемский район, город Кодинск, пр.Ленинского Комсомола, 24		0101000020E6100000EA059FE6E4CB58404A0A2C8029574D40
48276	5	49	1013	51817	28157	\N	57.890832000000003	Красноярский край, Кежемский район, город Кодинск, Колесниченко, 6А		0101000020E6100000361FD7868AD158407A1D71C806F24C40
48273	5	49	1013	51817	28157	\N	57.890832000000003	Красноярский край, Кежемский район, город Кодинск, Колесниченко, 6		0101000020E6100000361FD7868AD158407A1D71C806F24C40
48280	5	49	1013	59846	73115	\N	58.640703952290004	Красноярский край, Кежемский район, д.Климино, Ленина, 11	Россия	0101000020E61000005A2A6F4738AF58404C35B39602524D40
48283	5	49	1013	59686	72731	\N	57.932268009588398	Красноярский край, Кежемский район, п.Имбинский, Мира, 8	Россия, Красноярский край, Кежемский район, поселок Имба (нежил.)	0101000020E610000048C32973F3D45840BD8DCD8E54F74C40
48247	5	49	936	32824	73260	\N	53.353498000000002	" Каратузский район, Амыльский сельсовет, с.Ширыштык Мира 33""а"""		0101000020E610000059A7CAF78C475740C899266C3FAD4A40
48248	5	49	936	32824	73225	\N	53.353498000000002	" Каратузский район, Амыльский сельсовет, с.Ширыштык Мира 41""а"""		0101000020E610000059A7CAF78C475740C899266C3FAD4A40
48262	5	49	936	32938	73181	\N	53.525514999999999	Каратузский район, Черемушинский сельсовет, д.Шалагино Центарльная 22, 2		0101000020E61000003A24B550323157405A47551344C34A40
48266	5	49	936	32967	73273	\N	53.540843000000002	" Каратузский район, Черемушинский сельсовет, д. Чубчиково Мира 14""а"",1"		0101000020E6100000226DE34F54295740A1A2EA573AC54A40
48261	5	49	936	32929	73171	\N	53.536272366519498	" Каратузский район, Черемушинский сельсовет, с.Черемушка Зеленая 26""б"""	Россия, Красноярский край, Каратузский район, поселок Черёмушка	0101000020E61000004568041BD72E574058E1968FA4C44A40
48268	5	49	936	32973	73234	\N	53.738287999999997	Каратузский район, Уджейский сельсовет, с.Уджей Советская 35		0101000020E6100000293E3E213B345740BE839F3880DE4A40
48260	5	49	936	32920	73290	\N	53.771284999999999	Каратузский район, Таятский сельсовет, с.Таяты Советская 2		0101000020E61000000056478E745F57409B728577B9E24A40
48259	5	49	936	24715	73180	\N	53.711022	662855 Каратузский район, Таскинский сельсовет, с. Таскино Советская 50		0101000020E610000047382D78D1255740465ED6C402DB4A40
47851	5	49	936	59644	72627	\N	53.358128915955199	село  Таловка, Советская, 16	Россия, Красноярский край, Каратузский район, поселок Таловка	0101000020E61000005419C6DD20405740E55FCB2BD7AD4A40
48264	5	49	936	32957	73238	\N	53.562589000000003	Каратузский район, Черемушинский сельсовет, д.Старо-Молино Центральная 10		0101000020E61000005A677C5F5C245740700B96EA02C84A40
48258	5	49	936	32910	73216	\N	53.653345999999999	662850 Каратузский район, Старокопский сельсовет, с. Старая Копь Советская 24		0101000020E61000006B990CC7F3385740787C7BD7A0D34A40
48254	5	49	936	32871	73209	\N	53.488655000000001	Каратузский район, Каратузский сельсовет, д. Средний Кужебар Полтавская 8		0101000020E61000000307B474053E574071033E3F8CBE4A40
48257	5	49	936	32894	73157	\N	53.647368	Каратузский район, Сагайский сельсовет, с. Сагайское Советская 30		0101000020E6100000A31F0DA7CC3257400C3D62F4DCD24A40
48253	5	49	936	32862	73272	\N	53.350042000000002	Каратузский район, Моторский сельсовет, д.Нижняя Буланка Колхозная 19		0101000020E6100000B5FAEAAA402D5740FC1C1F2DCEAC4A40
48255	5	49	936	32875	73151	\N	53.5349729799104	Каратузский район, Нижнекужебарский сельсовет, с.Нижний Кужебар Советская 55	Россия, Красноярский край, Каратузский район, поселок Нижний Кужебар	0101000020E61000009065C1C41F4557401B9FC9FE79C44A40
48256	5	49	936	32889	73268	\N	53.783470000000001	Каратузский район, Нижнекурятский сельсовет, с.Нижние Куряты Советская 63		0101000020E61000004A5D328E914C5740D5B2B5BE48E44A40
48252	5	49	936	32860	73249	\N	53.403024000000002	Каратузский район, Моторский сельсовет, с. Моторское Крупская 1А	Россия, Красноярский край, Каратузский район, поселок Моторское	0101000020E610000016C09481033C574066C0594A96B34A40
48267	5	49	936	32970	73277	\N	53.589877000000001	662850 Каратузский район, Лебедевский сельсовет, д. Лебедевка Центральная 16		0101000020E61000004B1FBAA0BE305740D0D4EB1681CB4A40
48251	5	49	936	32850	73227	\N	53.760544495092603	" Каратузский район, Качульский сельсовет, с.Качулька Мира 69""а"""	Россия, Красноярский край, Каратузский район, поселок Качулька	0101000020E6100000416667D13B3A5740A3957B8159E14A40
48244	5	49	936	32793	73267	\N	53.5982519854957	662850 Каратузский район, Каратузский сельсовет, с.Каратузское Шевченко 16	Россия, Красноярский край, Каратузский район, поселок Каратузское	0101000020E610000095B88E71C53757402062838593CC4A40
48243	5	49	936	32793	73166	\N	53.599170999999998	662850 Каратузский район, Каратузский сельсовет, с.Каратузское Революционная 23		0101000020E610000043AB93331438574016DBA4A2B1CC4A40
48246	5	49	936	32793	73208	\N	53.599170999999998	662850 Каратузский район, Каратузский сельсовет, с.Каратузское Пушкина 10		0101000020E610000043AB93331438574016DBA4A2B1CC4A40
48265	5	49	936	32959	73250	\N	53.462651999999999	" Каратузский район, Черемушинский сельсовет, д. Верхний Суэтук Партизанская 1""а"""		0101000020E610000022C66B5ED5215740E9B6442E38BB4A40
48250	5	49	936	32847	73195	\N	53.368389000000001	"662862 Каратузский район, Верхнекужебарский сельсовет,  с.Верхний Кужебар Садовая 6""б"""		0101000020E6100000B3EF8AE07F4F5740639AE95E27AF4A40
48249	5	49	936	32847	73165	\N	53.367875634940198	662862 Каратузский район, Верхнекужебарский сельсовет, с. Верхний Кужебар Ленина 49	Россия, Красноярский край, Каратузский район, поселок Верхний Кужебар	0101000020E61000001422E010AA4F5740DD7D8E8F16AF4A40
48237	5	49	723	7266	73038	\N	56.339766247955303	д.Хаерино, Молодежная, 29/1	Россия, Красноярский край, Канский район, поселок Хаерино	0101000020E6100000AF2479AEEFCC57407825C9737D2B4C40
48242	5	49	723	7469	27881	\N	56.204904999999997	с. Филимоново, Луговая, 9		0101000020E61000003E93FDF334DD5740B8E4B8533A1A4C40
48228	5	49	723	6835	27731	\N	56.213075000000003	д.Терское, Центральная, 36	Россия, Красноярский край, Канский район, поселок Терское	0101000020E6100000CB694FC939CD5740304CA60A461B4C40
48194	5	49	723	5043	28013	\N	55.862161	д.Тарай, Ушакова, 15	Россия, Красноярский край, Канский район, поселок Тарай	0101000020E610000063F19BC24AF557407E71A94A5BEE4B40
48197	5	49	723	47897	27912	\N	56.439503000000002	д.Тайна, Трактовая, 25		0101000020E610000087A3AB7477E0574038BF61A241384C40
47814	5	49	723	7164	72440	\N	56.258636939688003	"п. Таежный Новая 6 ""В"""	Россия, Красноярский край, Канский район, поселок Таежное	0101000020E610000030F2B22616C057408D4468041B214C40
48235	5	49	723	7164	28380	\N	56.255087000000003	с.Таежное, Ленина, 25		0101000020E61000008DB454DE8EBF57404051D9B0A6204C40
48220	5	49	723	6421	72797	\N	56.515681999999998	д.Тагаши, пер.Клубный, 1		0101000020E6100000EAEC647094EB5740649126DE01424C40
48226	5	49	723	48450	28174	\N	56.200864000000003	д.Сухая речка, магазинная, 27		0101000020E6100000C9E9EBF99AD75740CD785BE9B5194C40
48201	5	49	723	47975	28368	\N	55.954934000000002	с.Степняки, Юбилейная, 1А		0101000020E6100000BBD6DEA7AAEE574053EBFD463BFA4B40
48223	5	49	723	6572	27901	\N	56.345917999999998	с.Сотниково, Комсомольская, 34	Россия, Красноярский край, Канский район, поселок Сотниково	0101000020E6100000A19E3E027FE25740828C800A472C4C40
48211	5	49	723	59855	73123	\N	56.530315573242099	д.Северная Александровка, Пионерская, 19	Россия, Красноярский край, Канский район, поселок Северо-Александровка	0101000020E6100000D1798D5DA2CF5740D4450A65E1434C40
48219	5	49	723	6354	27722	\N	56.502975999999997	с.Рудяное, Новая, 16		0101000020E6100000651BB80375E7574021567F8461404C40
48241	5	49	723	7449	72851	\N	56.210647000000002	с.Польное, Лугова, 12		0101000020E6100000F6F065A208E0574011001C7BF61A4C40
48227	5	49	723	6760	28339	\N	56.129694999999998	д.Петрушки, Соломенная, 2	Россия, Красноярский край, Канский район, поселок Петрушки	0101000020E6100000F01989D008CF574034BA83D899104C40
48192	5	49	723	51895	28546	\N	56.232230224860501	д.Пермяково, ул.Набережная, 36	Россия, Красноярский край, Канский район, поселок Пермяково	0101000020E61000003A419B1C3ECC574036936FB6B91D4C40
48207	5	49	723	51804	28092	\N	55.8635792405777	д.Орловка, Новая, 9	Россия, Красноярский край, Канский район, поселок Орловка	0101000020E610000003EE79FEB4E757409641B5C189EE4B40
48664	5	49	723	51870	28459	\N	56.0600603301815	Красноярский край, Рыбинский район, деревня Орешники, Солнечная, 11	Россия, Красноярский край, Канский район, поселок Орешники	0101000020E61000007A39ECBE63CA57401DE6CB0BB0074C40
48213	5	49	723	32583	28552	\N	56.420980999999998	с.Мокруша, Школьная, 6	Россия, Красноярский край, Канский район, поселок Мокруша	0101000020E61000004BB0389CF9CC5740629E95B4E2354C40
48205	5	49	723	59861	73131	\N	56.103680375333298	п.Малые Пруды, Московская, 12	Россия, Красноярский край, Канский район, поселок Малые Пруды	0101000020E61000003BFE0B0401E65740E89FE062450D4C40
48203	5	49	723	5494	28424	\N	56.116874000000003	д. Малая Уря, Набережная, 4	Россия, Красноярский край, Канский район, поселок Малая Уря	0101000020E6100000A3772AE09EDB574059E02BBAF50E4C40
48215	5	49	723	6157	72801	\N	56.382809999999999	д.Любава, Центральная, 38		0101000020E6100000EDF1423A3CC65740774A07EBFF304C40
48198	5	49	723	51751	27830	\N	56.455353886999603	д.Леонтьевка, Центральная, 20	Россия, Красноярский край, Канский район, поселок Леонтьевка	0101000020E6100000091B9E5E29DB5740280D350A493A4C40
48240	5	49	723	48709	28037	\N	56.164310999999998	с.Крутая Горка, Луговая, 2/1		0101000020E61000000D6C956071DE5740C0AF912408154C40
48222	5	49	723	59795	73054	\N	56.338758427059098	д.Круглово, Зеленая, 13	Россия, Красноярский край, Канский район, поселок Круглово	0101000020E61000005C8DEC4ACBDA574012A1116C5C2B4C40
48229	5	49	723	32678	28026	\N	56.201059000000001	с.Красный Маяк, Победы, 64		0101000020E6100000C172840CE4DB574082C8224DBC194C40
48236	5	49	723	7185	28628	\N	56.215077999999998	с.Красный Курыш, Центральная, 31/2		0101000020E6100000AF415F7AFBC25740670B08AD871B4C40
48208	5	49	723	48130	72957	\N	55.912990000000001	д.Зеленая Дубрава, Центральная, 3	Россия, Красноярский край, Канский район, поселок Зеленая Дубрава	0101000020E6100000444E5FCFD7E157409BC937DBDCF44B40
48217	5	49	723	48295	27950	\N	56.499270000000003	п.Залесный, Первая, 10	Россия, Красноярский край, Канский район, поселок Залесный	0101000020E6100000506D7022FABD5740DDEF5014E83F4C40
48653	5	49	723	59866	73139	\N	56.110493577240902	Красноярский край, Рыбинский район, деревня Загорск, Школьная, 25	Россия, Красноярский край, Канский район, поселок Загорский	0101000020E61000007D7901F6D1C25740BE33DAAA240E4C40
48204	5	49	723	48030	28301	\N	56.050213999999997	п.Дорожный, Первомайская, 7	Россия, Красноярский край, Канский район, поселок Дорожный	0101000020E610000074CFBA46CBE4574092E68F696D064C40
48165	5	49	272	32972	73182	\N	55.680467999999998	Ирбейский район, д. Петропавловка Советская 18		0101000020E6100000DC8310902FEF5740BDFC4E9319D74B40
48105	5	49	723	59721	72885	\N	56.440846000000001	Красноярский край, Иланский район, д. Гремучая Падь, Центральная, сельский клуб	Россия, Красноярский край, Канский район, поселок Гремучая Падь	0101000020E6100000D8D47954FCF15740454948A46D384C40
48209	5	49	723	59648	72642	\N	56.515053929431197	с.Георгиевка, Советская, 37	Россия, Красноярский край, Канский район, поселок Георгиевка	0101000020E610000052D4997B48DA574045D61A4AED414C40
48206	5	49	723	5705	28596	\N	55.903115	с.Верх-Амонаш, Центральная, 2В		0101000020E6100000A0FF1EBC76E8574076C3B64599F34B40
48224	5	49	723	6629	27802	\N	56.114494999999998	п.Бошняково, Центральная, 13		0101000020E61000000F289B7285D557401B47ACC5A70E4C40
48202	5	49	723	5469	72655	\N	56.026865000000001	с.Большая Уря, 9 Пятилетки, 7		0101000020E6100000317BD976DADE57401A34F44F70034C40
48199	5	49	723	5324	28142	\N	56.109586	д.Ашкаул, Кирова, 25	Россия, Красноярский край, Канский район, поселок Ашкаул	0101000020E6100000EE3EC7478BF45740BB0CFFE9060E4C40
48196	5	49	723	5164	72596	\N	56.397196000000001	с.Астафьевка, Пионерская, 14		0101000020E6100000705F07CE19DE57400F0D8B51D7324C40
48218	5	49	723	48314	72795	\N	56.542276999999999	д.Архангельское, Центральная, 26А		0101000020E6100000F700DD9733E35740BE2F2E5569454C40
48221	5	49	723	6459	28067	\N	56.356617	д.Арефьевка, Молодежная, 1	Россия, Красноярский край, Канский район, поселок Арефьевка	0101000020E610000019E3C3EC65EE57404C1938A0A52D4C40
48214	5	49	723	6111	28335	\N	56.421872999999998	д.Алега, Полевая, 46	Россия, Красноярский край, Канский район, поселок Алега	0101000020E61000002DB1321AF9C557405F0839EFFF354C40
48189	5	49	581	4801	28334	\N	57.578054999999999	д. Челноки, Ленина, 10		0101000020E61000000917F2086E4D57400725CCB4FDC94C40
48188	5	49	581	4724	28543	\N	57.517201	с. Талажанка, Советская, 32	Россия, Красноярский край, Казачинский район, поселок Талажанка	0101000020E6100000A9177C9A93315740B03A72A433C24C40
48187	5	49	581	47724	28169	\N	57.618577999999999	с. Рождественское, Пушкина, 10,А	Россия, Красноярский край, Казачинский район, поселок Рождественское	0101000020E6100000C24D46956149574036035C902DCF4C40
48186	5	49	581	47704	72800	\N	57.410091999999999	с. Пятково, Школьная, 6		0101000020E6100000DD96C805674C5740F52C08E57DB44C40
48185	5	49	581	4580	28330	\N	57.550204999999998	д. Пискуновка, Клубная, 9	Россия, Красноярский край, Казачинский район, поселок Пискуновка	0101000020E610000057D0B4C4CA5557403F8C101E6DC64C40
48184	5	49	581	4515	28507	\N	57.380370999999997	с. Отношка, Школьная, 2,А		0101000020E610000026AB22DC642D574064AC36FFAFB04C40
48181	5	49	581	4318	28537	\N	57.628943999999997	с. Момотово, Центральная, 5		0101000020E610000033FB3C4679545740F981AB3C81D04C40
48180	5	49	581	4283	72609	\N	57.520299000000001	с. Мокрушинское, Свердлова, 10		0101000020E61000007288B839954C57401D925A2899C24C40
47609	5	49	581	49600	72917	\N	57.529466999999997	д. Матвеевка, ул. Советская, 17		0101000020E610000077BE9F1A2F365740D6A71C93C5C34C40
48179	5	49	581	49600	72904	\N	57.530711203430798	д. Матвеевка, Новая, 4	Россия, Красноярский край, Казачинский район, поселок Матвеевка	0101000020E61000007711A6289736574050508A56EEC34C40
48177	5	49	581	4131	28148	\N	57.393222000000002	д. Кемское, Центральная, 30		0101000020E610000076C1E09A3B395740AB08371955B24C40
48176	5	49	581	4076	71515	\N	57.697201999999997	с. Казачинское, Советская, 107		0101000020E61000007098689082515740575A46EA3DD94C40
48174	5	49	581	4016	28152	\N	57.344118999999999	д. Казанка, Школьная, 2,А		0101000020E6100000573ECBF3E0715740537765170CAC4C40
48173	5	49	581	47470	72960	\N	57.801102	с. Захаровка, Набережная, 30		0101000020E61000004FCDE506435357404E61A5828AE64C40
48172	5	49	581	3834	28640	\N	57.457357999999999	с. Дудовка, Буденного, 13		0101000020E6100000412E71E4814557403048FAB48ABA4C40
48171	5	49	581	40436	72791	\N	57.39669	д. Гамурино, Лесная, 46,а	Россия, Красноярский край, Казачинский район, поселок Гамурино	0101000020E6100000C79DD2C1FA2957403B53E8BCC6B24C40
48170	5	49	581	47417	28502	\N	57.622172999999997	с. Галанино, Трактовая, 8,А		0101000020E610000000732D5A8051574023BA675DA3CF4C40
48169	5	49	581	3729	28323	\N	57.595139000000003	с. Вороковка, Советская, 29		0101000020E6100000C2F869DC9B3657407EC9C6832DCC4C40
47865	5	49	581	3645	72943	\N	57.323588999999998	с.Бобровка, Центральная, 43		0101000020E6100000EE5EEE93A3485740342C465D6BA94C40
48162	5	49	272	33044	73177	\N	55.670544	д. Юдино Колхозная 27		0101000020E6100000DA20938C9CE05740B743C362D4D54B40
48160	5	49	272	32944	73147	\N	55.796410000000002	Ирбейский район, д. Чухломино Комсомольская 1а		0101000020E610000059FAD005F5DD57408B1A4CC3F0E54B40
48153	5	49	272	32897	73224	\N	55.721792000000001	Ирбейский район, д. Хомутово Комсомольская 9		0101000020E61000009F8F32E202EB5740D94125AE63DC4B40
48155	5	49	272	32906	73217	\N	55.801430000000003	Ирбейский район, с. Усть-Яруль Строительная 1а		0101000020E6100000A98427F4FAD1574043041C4295E64B40
48154	5	49	272	32891	73228	\N	55.865268	Ирбейский район, с. Усть-Каначуль Молодежная 12		0101000020E610000057ED9A90D6DA57403E23111AC1EE4B40
48152	5	49	272	32879	73254	\N	55.793685012560502	Ирбейский район, с. Тумаково Советская 2	Россия, Красноярский край, Ирбейский район, поселок Тумаково	0101000020E61000004A0B9755D8E35740B329577897E54B40
48148	5	49	272	26425	73265	\N	55.408285999999997	Ирбейский район, с. Талое Рабочая 2а		0101000020E61000008C497F2F85EA574013B534B742B44B40
48142	5	49	272	2165	73184	\N	55.547274999999999	Ирбейский район, д. Стрелка Набережная 18а	Россия, Красноярский край, Ирбейский район, поселок Стрелка	0101000020E6100000C51EDAC70AF457408E75711B0DC64B40
48147	5	49	272	2494	73185	\N	55.181492519056299	Ирбейский район, п. Степановка ул. Центральная 18а	Россия, Красноярский край, Ирбейский район, поселок Степановка	0101000020E610000009A4C4AEEDF05740FAB9A1293B974B40
48143	5	49	272	32816	73193	\N	55.481413000000003	Ирбейский район, д. Сергеевка Советская 24		0101000020E61000005017299485D85740446FF1F09EBD4B40
48150	5	49	272	32863	73296	\N	55.362378	Ирбейский район, д. Рождественка Центральная 3а		0101000020E610000038656EBE11EB57401B65FD6662AE4B40
48157	5	49	272	32923	73287	\N	55.800472999999997	Ирбейский район, д.Преображенка Мира 34а	Россия, Красноярский край, Ирбейский район, поселок Преображенка	0101000020E6100000F12A6B9BE2D557405E2A36E675E64B40
48195	5	49	272	33149	73055	\N	55.793280418434598	д.Подьянда, Школьная, 21	Россия, Красноярский край, Ирбейский район, поселок Подьянда	0101000020E6100000F46F97FDBAF257401349F4328AE54B40
48146	5	49	272	2397	\N	\N	55.456366786694097	Ирбейский район, д. Новотроицк здание сельского клуба	Россия, Красноярский край, Ирбейский район, поселок Новотроицк	0101000020E61000002FC4EA8F30D55740A0FCDD3B6ABA4B40
47694	5	49	272	2397	28584	\N	55.458219999999997	д.Ново-Троицк, Новотроицкая, 35		0101000020E61000001D9430D3F6D45740C22FF5F3A6BA4B40
48145	5	49	272	2376	\N	\N	55.477837000000001	Ирбейский район, д. Новоалександровка здание сельского клуба		0101000020E6100000A7CF0EB8AEDC5740CDE847C329BD4B40
48133	5	49	272	1687	73259	\N	55.433593000000002	Ирбейский район, д. Николаевка пер. Школьный 4		0101000020E6100000E9EE3A1BF2CC57402463B5F97FB74B40
48163	5	49	272	59903	73301	\N	55.675987043551103	Ирбейский район, д. Нагорная Трактовая 2а	Россия, Красноярский край, Ирбейский район, поселок Нагорная	0101000020E6100000AFEE586C93DB5740B5C2F4BD86D64B40
48130	5	49	272	32715	73244	\N	55.700445999999999	Ирбейский район, д. Михайловка Ленина 27		0101000020E610000026E4839ECDC95740984EEB36A8D94B40
48128	5	49	272	32688	73270	\N	55.399658000000002	Ирбейский район, д. Минушка Центральная 8		0101000020E61000003ACAC16C02F95740DACA4BFE27B34B40
48141	5	49	272	32807	73281	\N	55.604289999999999	Ирбейский район, с. Мельничное Школьная 10		0101000020E610000000E48409A3E5574061A6ED5F59CD4B40
48135	5	49	272	32753	73186	\N	55.637402999999999	Ирбейский район, п. Малый Ирбей Школьная 11		0101000020E61000003B6F63B323D85740A7AFE76B96D14B40
48139	5	49	272	32785	73210	\N	55.680686000000001	Ирбейский район, с. Маловка Школьная 17а		0101000020E610000073672618CEE957402B6C06B820D74B40
48161	5	49	272	32956	73149	\N	55.723638000000001	Ирбейский район, д. Латынцево Советская 25	Россия, Красноярский край, Ирбейский район, поселок Латынцево	0101000020E6100000F9669B1BD3D657404912842BA0DC4B40
48140	5	49	272	32792	73263	\N	55.671959999999999	Ирбейский район, д. Коростелево Солнечная 36а		0101000020E61000000873BB97FBE657402E1C08C902D64B40
48156	5	49	272	32916	73152	\N	55.840026999999999	Ирбейский район, д. Каменка Центральная 53		0101000020E6100000EA03C93B87CF5740E560360186EB4B40
48136	5	49	272	32760	73194	\N	55.640253999999999	Ирбейский район, с. Ирбейское Ленина 55		0101000020E61000002CD505BCCCDC57400C91D3D7F3D14B40
48137	5	49	272	32760	73192	\N	55.640253999999999	Ирбейский район, с. Ирбейское Интеранциональная 142		0101000020E61000002CD505BCCCDC57400C91D3D7F3D14B40
48134	5	49	272	1704	73239	\N	55.654451999999999	Ирбейский район, п. Изумрудный пер. Центральный 3		0101000020E6100000E38BF67821DB5740A1664815C5D34B40
48618	5	49	272	33036	28271	\N	55.448946858941703	деревня Ивановка, Суворова, 22	Россия, Красноярский край, Ирбейский район, поселок Ивановка	0101000020E610000082A8FB00A4CE57409351651877B94B40
47741	5	49	272	33036	28430	\N	55.448407472858698	д.Ивановка, Колхозная, 2	Россия, Красноярский край, Ирбейский район, поселок Ивановка	0101000020E61000001D7233DC80CE574014268C6665B94B40
48131	5	49	272	32719	73160	\N	55.591248	Ирбейский район, д. Елисеевка 40 Лет Октября 38	Россия, Красноярский край, Ирбейский район, поселок Елисеевка	0101000020E6100000D029C8CF46C65740A7E9B303AECB4B40
48129	5	49	272	32703	73264	\N	55.673802999999999	Ирбейский район, с. Верхняя Уря 40 Лет Октября 59		0101000020E61000002D6002B7EEC457402D793C2D3FD64B40
48082	5	49	272	31376	28428	\N	55.487453000000002	Красноярский край, Идринский район, д.Васильевка, Таёжная, 2-2		0101000020E6100000D61F6118B0EE574026AB22DC64BE4B40
48126	5	49	272	31376	73178	\N	55.487453000000002	Ирбейский район, д. Васильевка Ленина 23		0101000020E6100000D61F6118B0EE574026AB22DC64BE4B40
48164	5	49	272	32971	73219	\N	55.634155999999997	Ирбейский район, д. Бычковка Таежная 1а		0101000020E61000002D99637957F15740F54718062CD14B40
48159	5	49	272	32936	73183	\N	55.303811000000003	Ирбейский район, д. Буинка Центральная 29		0101000020E610000029CE5147C7DF574021956247E3A64B40
48149	5	49	272	32858	73202	\N	55.382891999999998	Ирбейский район, д. Богачево Центральная 27		0101000020E6100000F75965A6B4F1574034F3E49A02B14B40
48125	5	49	272	32673	73278	\N	55.441816000000003	Ирбейский район, с. Благовещенка Трактовая 9А		0101000020E61000005B3FFD67CDF35740BE6C3B6D8DB84B40
48151	5	49	272	32870	73206	\N	55.445650999999998	Ирбейский район, д. Березовка Центральная 18		0101000020E6100000B9AB5791D1E2574000378B170BB94B40
48144	5	49	272	2282	\N	\N	55.499668	Ирбейский район, д. Альгинка здание МОУ Альгинской основной общеобразовательной школы		0101000020E6100000CF31207BBDDB5740CA6DFB1EF5BF4B40
48124	5	49	272	1146	73262	\N	55.565314999999998	Ирбейский район, с. Александровка пер Красноармейский 2		0101000020E610000018B0E42A16D857401878EE3D5CC84B40
48127	5	49	272	32686	73283	\N	55.501437000000003	Ирбейский район, д. Агул Центральная 14		0101000020E6100000A73D25E7C4F857408F006E162FC04B40
49028	5	49	7493	59853	73121	\N	68.458174398212705	поселок Ессей, Центральная, 4		0101000020E6100000BD8FA339B28B594029780AB9521D5140
48096	5	49	83	32049	27842	\N	56.309773999999997	Красноярский край, Иланский район, д. Черниговка, Центральная, библиотека-клуб		0101000020E610000069ACFD9DED0158405793A7ACA6274C40
48123	5	49	83	1093	27943	\N	55.789684000000001	Красноярский край, Иланский район, п. Хайрюзовка, Центральная, штаб ФГУ ОИУ-3 ОУХД ГУФСИН России		0101000020E6100000D158FB3BDB2758405516855D14E54B40
48117	5	49	83	746	72879	\N	55.956097999999997	Красноярский край, Иланский район, д. Троицк, Центральная, сельский клуб		0101000020E6100000102219726C0B5840B0E2546B61FA4B40
47565	5	49	83	746	72760	\N	55.956097999999997	д.Троицк, Нагорная, 27		0101000020E6100000102219726C0B5840B0E2546B61FA4B40
48110	5	49	83	299	27729	\N	56.430788	Красноярский край, Иланский район, д. Тарака, Центральная, сельский клуб	Россия, Красноярский край, Иланский район, поселок Тарака	0101000020E61000008B338639410A58402FC1A90F24374C40
48099	5	49	83	32159	28610	\N	56.223596000000001	Красноярский край, Иланский район, д. Степаново, Центральная, сельский Дом культуры		0101000020E6100000AFB2B6291E1358401AC231CB9E1C4C40
48102	5	49	83	59741	72985	\N	56.429907999999998	Красноярский край, Иланский район, Соколовский сельсовет, Центральная, Администрация сельсовета	Россия, Красноярский край, Иланский район, поселок Соколовка	0101000020E610000029081EDFDEF95740F624B03907374C40
47904	5	49	822	23040	28066	\N	56.690693000000003	Красноярский край, Дзержинский район,с. Курай, Новая, 1		0101000020E610000056B77A4E7ADF5740BF49D3A068584C40
48122	5	49	83	1040	27736	\N	55.713304000000001	Красноярский край, Иланский район, п. Росляки, Центральная, начальная общеобразовательная школа		0101000020E6100000249C16BCE8125840910DA48B4DDB4B40
48120	5	49	83	884	72952	\N	55.753798000000003	Красноярский край, Иланский район, д.Прокопьевка, Центральная, сельская библиотека		0101000020E6100000077AA86DC3F8574026E5EE737CE04B40
48103	5	49	83	32337	27935	\N	56.407766000000002	Красноярский край, Иланский район, д. Новосеменовка, Центральная, сельский клуб		0101000020E61000003719558671FC5740DB3521AD31344C40
48106	5	49	83	59725	72907	\N	56.357228999999997	Красноярский край, Иланский район, Новопокровский сельсовет, Центральная, Сельский Дом культуры	Россия, Красноярский край, Иланский район, поселок Новопокровка	0101000020E610000040FA264D8307584065170CAEB92D4C40
48108	5	49	83	111	28450	\N	56.383288999999998	Красноярский край, Иланский район, д. Новоникольск, Центральная, сельский клуб-библиотека		0101000020E6100000A4349BC7610F584051F52B9D0F314C40
47868	5	49	83	111	72827	\N	56.383288999999998	с.Новоникольск, Советская, 50-А		0101000020E6100000A4349BC7610F584051F52B9D0F314C40
48119	5	49	83	20457	27934	\N	55.784526516461199	Красноярский край, Иланский район, Новониколаевский сельсовет, Центральная, сельский Дом культуры		0101000020E610000070EEAF1EF70B58401CEA77616BE44B40
48508	5	49	83	20457	72945	\N	55.786611999999998	д. Новониколаевка, Тамбовская, 22		0101000020E610000046240A2DEB0B58401152B7B3AFE44B40
48112	5	49	83	381	28088	\N	56.369805999999997	Красноярский край, Иланский район, д. Новогеоргиевка, Центральная, сельский клуб		0101000020E6100000E23C9CC074FF5740AAEE91CD552F4C40
48116	5	49	83	655	28249	\N	55.8342562332654	Красноярский край, Иланский район, д. Лобачевка, Центральная, сельский клуб	Россия, Красноярский край, Иланский район, поселок Лобачевка	0101000020E6100000164D672783165840F33E8EE6C8EA4B40
48113	5	49	83	51814	28126	\N	55.942630785945397	Красноярский край, Иланский район, Кучердаевский сельсовет, Центральная, сельский Дом культуры	Россия, Красноярский край, Иланский район, поселок Кучердаевка	0101000020E6100000EB1A2D077AFB57400F99F221A8F84B40
48097	5	49	83	32083	27889	\N	56.343468000000001	Красноярский край, Иланский район, д. Курыш-Поповичи, Центральная, сельский клуб		0101000020E61000003E096CCEC1F057407C9C69C2F62B4C40
48101	5	49	83	32249	28231	\N	56.291184000000001	Красноярский край, Иланский район, д. Красный Хлебороб, Центральная, здание бригадной конторы		0101000020E61000006EF7729F1C0158402A8F6E8445254C40
48111	5	49	83	373	72946	\N	56.408577000000001	Красноярский край, Иланский район, д. Краснинка, Центральная, школа		0101000020E61000006534F279C5035840EB724A404C344C40
48107	5	49	83	101	28619	\N	56.350411999999999	Красноярский край, Иланский район, д. Коха, Центральная, бывшая начальная школа		0101000020E6100000F6622827DA1558401F10E84CDA2C4C40
48098	5	49	83	59641	72621	\N	56.217604999999999	Красноярский край, Иланский район, Карапсельский сельсовет, Центральная, Сельский Дом культуры	Россия, Красноярский край, Иланский район, поселок Карапсель	0101000020E610000012FA997ADDF8574019390B7BDA1B4C40
48090	5	49	83	11004	71559	\N	56.2409846147861	Красноярский край, Иланский район, город Иланский, пер. Алгасинский, 7		0101000020E6100000EC8497E0D4035840CDE9B298D81E4C40
48092	5	49	83	11004	71558	\N	56.240315472354297	Красноярский край, Иланский район, город Иланский, Школьная, 17		0101000020E6100000EC8497E0D40358407FDE54A4C21E4C40
48114	5	49	83	11004	27938	\N	56.237257	Красноярский край, Иланский район, Южно-Александровский сельсовет, Центральная, администрация сельсовета		0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48091	5	49	83	11004	27931	\N	56.237257	Красноярский край, Иланский район, город Иланский, Трактовая, 108		0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48093	5	49	83	11004	71512	\N	56.237257	"Красноярский край, Иланский район, город Иланский, Первомайская, 42""в"""		0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48975	5	49	83	11004	28358	\N	56.237257	город Иланский, Медицинская, 6	Россия, Красноярский край, Иланский район, город Иланский	0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48089	5	49	83	11004	28594	\N	56.237257	Красноярский край, Иланский район, город Иланский, Ленина, 56		0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48088	5	49	83	11004	28594	\N	56.237257	Красноярский край, Иланский район, город Иланский, Ленина, 1		0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48087	5	49	83	11004	28593	\N	56.237257	Красноярский край, Иланский район, город Иланский, Красная, 53		0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48086	5	49	83	11004	27768	\N	56.237257	Красноярский край, Иланский район, город Иланский, Коммунистическая, 91	Россия, Красноярский край, Иланский район, город Иланский	0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48094	5	49	83	11004	28605	\N	56.237257	Красноярский край, Иланский район, город Иланский, 50 лет Краснохлеборобовской Коммуны, 8		0101000020E610000023111AC1C6045840A0DFF76F5E1E4C40
48121	5	49	83	985	27735	\N	55.741546	Красноярский край, Иланский район, Ельниковский сельсовет, п. Ельники, Центральная, сельский Дом культуры		0101000020E6100000A6643909A51A5840643DB5FAEADE4B40
48095	5	49	83	51881	28494	\N	56.294287254165297	Красноярский край, Иланский район, Далайский сельсовет, Центральная, Сельский Дом культуры	Россия, Красноярский край, Иланский район, поселок Далай	0101000020E61000007AABAE4335FA5740A8514832AB254C40
48118	5	49	83	754	28288	\N	55.995548999999997	Красноярский край, Иланский район, д. Гавриловка, Центральная, сельская библиотека-клуб		0101000020E61000008177F2E9B10B584062484E266EFF4B40
48061	5	49	1187	30333	72796	\N	54.255529000000003	Красноярский край, Идринский район, с.Большие Кныши, Байкалова, 17		0101000020E6100000828FC18A53245740FD169D2CB5204B40
48115	5	49	83	613	72886	\N	55.911985999999999	Красноярский край, Иланский район, д. Верх-Атины, Центральная, сельский клуб	Россия, Красноярский край, Иланский район, поселок Верх-Атины	0101000020E610000030A182C30B13584076340EF5BBF44B40
48200	5	49	83	47963	71516	\N	56.064684999999997	с.Бражное, Коростелева, 19		0101000020E6100000919C4CDC2AF7574058C51B9947084C40
48104	5	49	83	32389	72944	\N	56.459750999999997	Красноярский край, Иланский район, д. Богдановка, Центральная, сельский клуб		0101000020E610000097C79A9141F95740D2A6EA1ED93A4C40
48193	5	49	83	4969	27976	\N	55.904694999999997	с.Амонаш, Школьная, 4		0101000020E6100000A1496249B9F5574067EDB60BCDF34B40
48056	5	49	1187	30107	28567	\N	54.362667999999999	Красноярский край, Идринский район, п.Центральный, Советская, 4	Россия, Красноярский край, Идринский район, поселок Центральный	0101000020E6100000378DEDB5A010574022A7AFE76B2E4B40
48064	5	49	1187	30468	28401	\N	54.188780999999999	Красноярский край, Идринский район, д.Средняя Салба, Рабочий, 6	Россия, Красноярский край, Идринский район, поселок Средняя Салба	0101000020E61000001E54E23AC6135740978DCEF929184B40
48566	5	49	1187	30934	28104	\N	54.726605999999997	Красноярский край, Нижнеингашский район, деревня Романовка Таежная 42	Россия, Красноярский край, Идринский район, поселок Романовка	0101000020E6100000826F9A3E3B015740E789E76C015D4B40
48073	5	49	1187	30934	72877	\N	54.726605999999997	Красноярский край, Идринский район, с.Романовка, Молодежная, 21-2		0101000020E6100000826F9A3E3B015740E789E76C015D4B40
48055	5	49	1187	51857	28390	\N	55.931457000000002	Красноярский край, Идринский район, п.Сибирь, Краснокаменная, 5		0101000020E6100000B306EFAB72515740AD50A4FB39F74B40
48059	5	49	1187	30233	28394	\N	54.446314000000001	Красноярский край, Идринский район, с.Отрок, Школьная, 9	Россия, Красноярский край, Идринский район, поселок Отрок	0101000020E61000004F7633A31F2357409CDF30D120394B40
48072	5	49	1187	30912	72878	\N	54.390566999999997	Красноярский край, Идринский район, п.Октябрьский, Центральная, 18		0101000020E6100000E833A0DE8CF75640CBF27519FE314B40
48084	5	49	1187	31481	28083	\N	54.543996999999997	Красноярский край, Идринский район, с.Новотроицкое, Октябрьская, 44		0101000020E6100000280AF4893C225740A10F96B1A1454B40
48078	5	49	1187	31204	27864	\N	54.536230000000003	Красноярский край, Идринский район, с.Новоберезовка, Ленина, 70		0101000020E61000003F8EE6C8CA0357402A91442FA3444B40
48081	5	49	1187	31338	27867	\N	54.485951999999997	Красноярский край, Идринский район, с.Никольское, Ленина, 86	Россия, Красноярский край, Идринский район, поселок Никольское	0101000020E6100000350C1F11530F574080B6D5AC333E4B40
48080	5	49	1187	31308	28056	\N	54.560972999999997	Красноярский край, Идринский район, д.Мензот, Громовой, 39	Россия, Красноярский край, Идринский район, поселок Мензот	0101000020E6100000848252B4720F5740317898F6CD474B40
48069	5	49	1187	30747	72876	\N	54.439717000000002	Красноярский край, Идринский район, д.Малый Хабык, Мира, 69		0101000020E6100000573ECBF3E0045740643F8BA548384B40
48067	5	49	1187	28390	28191	\N	54.388821	Красноярский край, Идринский район, с.Майское Утро, Молодежная, 22		0101000020E610000099654F029BFF5640BF7FF3E2C4314B40
48071	5	49	1187	30862	28638	\N	54.487321999999999	Красноярский край, Идринский район, п.Майский, Центральная, 5		0101000020E61000005726FC523FFF5640874F3A91603E4B40
48066	5	49	1187	30606	72899	\N	54.211592000000003	Красноярский край, Идринский район, с.Куреж, Зеленая, 38		0101000020E6100000E31B0A9FAD065740310C5872151B4B40
48076	5	49	1187	31094	28204	\N	54.742595000000001	Красноярский край, Идринский район, д.Королевка, Заречная, 6	Россия, Красноярский край, Идринский район, поселок Королевка	0101000020E61000008065A5492909574029965B5A0D5F4B40
48060	5	49	1187	30308	72872	\N	54.440429000000002	Красноярский край, Идринский район, д.Козино, Хохлатская, 23		0101000020E61000006C09F9A0672B5740E19A3BFA5F384B40
48323	5	49	1187	11311	\N	\N	54.174886031617802	Красноярский край, Краснотуранский район, Тубинский сельсовет, деревня Кедровая, Здание сельского клуба	Россия, Красноярский край, Идринский район, поселок Кедровая	0101000020E6100000A33B889D290257409E4319AA62164B40
49040	5	49	1187	11311	73019	\N	54.1743321358461	п.Кузьмовка с входящим в состав поселения населенным пунктом Кочумдек, Кедровая, 2	Россия, Красноярский край, Идринский район, поселок Кедровая	0101000020E6100000A3073E062B025740B952CF8250164B40
48621	5	49	1187	31012	72950	\N	54.781461999999998	село Иннокентьевка, Красных Партизан, 38		0101000020E61000003DB665C059F856408B8862F206644B40
48075	5	49	1187	31012	28054	\N	54.781461999999998	Красноярский край, Идринский район, д.Иннокентьевка, Зеленая, 21		0101000020E61000003DB665C059F856408B8862F206644B40
48054	5	49	1187	29919	28388	\N	54.377625999999999	Красноярский край, Идринский район, с.Идринское, Титова, 30		0101000020E6100000BE175FB4C7085740450F7C0C56304B40
48053	5	49	1187	29919	28186	\N	54.377625999999999	Красноярский край, Идринский район, с.Идринское, Октябрьская, 178		0101000020E6100000BE175FB4C7085740450F7C0C56304B40
48052	5	49	1187	29919	71517	\N	54.377625999999999	Красноярский край, Идринский район, с.Идринское, Мира, 7		0101000020E6100000BE175FB4C7085740450F7C0C56304B40
48085	5	49	1187	31547	28061	\N	54.561045999999997	Красноярский край, Идринский район, д.Зезезино, Таёжная, 1		0101000020E61000001938A0A52B1C57409BC6F65AD0474B40
48083	5	49	1187	31445	72883	\N	54.505648999999998	Красноярский край, Идринский район, д.Еленинск, Ленина, 33		0101000020E61000001D76DF313C185740A7203F1BB9404B40
48079	5	49	1187	31213	28053	\N	54.556215999999999	Красноярский край, Идринский район, с.Екатериновка, Ленина, 17		0101000020E6100000A9D898D7110A574087C1FC1532474B40
48070	5	49	1187	30794	27752	\N	54.496704000000001	Красноярский край, Идринский район, п.Добромысловский, Храпова, 2		0101000020E6100000062AE3DF67F856406DE525FF933F4B40
48068	5	49	1187	30707	28582	\N	54.424602	Красноярский край, Идринский район, с.Большой Хабык, Ленина, 1		0101000020E61000004BE9995E62FC564079E8BB5B59364B40
48065	5	49	1187	30546	72902	\N	54.293708000000002	Красноярский край, Идринский район, с.Большой Телек, Советская, 47		0101000020E61000003E3C4B90110457406B49473998254B40
48063	5	49	1187	30443	28398	\N	54.235337000000001	Красноярский край, Идринский район, с.Большая Салба, Советская, 24	Россия, Красноярский край, Идринский район, поселок Большая Салба	0101000020E6100000A54C6A6803155740F644D7851F1E4B40
48057	5	49	1187	30145	72873	\N	54.355516999999999	Красноярский край, Идринский район, д.Большая Идра, Советская, 25		0101000020E6100000132A38BC201757400516C094812D4B40
48058	5	49	1187	18277	28305	\N	54.4247621175059	Красноярский край, Идринский район, д.Адриха Адрихинская (здание сельского клуба) д. 38	Россия, Красноярский край, Идринский район, поселок Адриха	0101000020E61000005DC47762D61A5740B24AE9995E364B40
48040	5	49	1722	29359	28559	\N	53.116681	поселок Танзыбей, Мира, 32		0101000020E6100000E38DCC237F3C574044882B67EF8E4A40
48051	5	49	1722	32892	72624	\N	53.200274	село Семенниково, трактовая, 38		0101000020E6100000239EEC66460F57409B1E1494A2994A40
48036	5	49	1722	49136	28366	\N	53.237127000000001	село Салба, Центральная, 18		0101000020E6100000C899266C3F265740D2FF722D5A9E4A40
48049	5	49	1722	29772	27844	\N	53.123572000000003	село Разъезжее, Саянская, 55	Россия, Красноярский край, Ермаковский район, поселок Разъезжее	0101000020E6100000981936CAFA1B5740C5591135D18F4A40
48032	5	49	1722	40416	28175	\N	53.267415999999997	"поселок Песочный, Центральная, 3""а"""		0101000020E610000011381268B01C5740AC36FFAF3AA24A40
48035	5	49	1722	29125	72592	\N	53.242969000000002	поселок Ойский, Мира, 37		0101000020E61000008D45D3D9C91F57408E78B29B199F4A40
48038	5	49	1722	32805	28375	\N	53.324427	село Новополтавка, Комсомольская, 24	Россия, Красноярский край, Ермаковский район, поселок Новополтавка	0101000020E610000025E82FF4882757403E78EDD286A94A40
48034	5	49	1722	29109	72871	\N	53.243237999999998	поселок Новоозерный, Центральная, 10		0101000020E6100000F3AD0FEB8D1A57407D923B6C229F4A40
48047	5	49	1722	29628	27843	\N	52.259230000000002	село Нижнеусинское, Кравченко, 38	Россия, Красноярский край, Ермаковский район, поселок Нижнеусинское	0101000020E61000004D9EB29AAE4057403012DA722E214A40
48037	5	49	1722	59692	72738	\N	53.344521999999998	село Нижний Суэтук, Ленина, 2	Россия, Красноярский край, Ермаковский район, поселок Нижнесуэтук	0101000020E61000008C2B2E8ECA1D57405260014C19AC4A40
48048	5	49	1722	29703	28183	\N	53.132314000000001	село Мигна, Щетинкина, 48		0101000020E6100000B7B6F0BC540E5740C76647AAEF904A40
47917	5	49	1722	59757	73006	\N	53.384725000000003	"село Ивановка, Ленина, 8""б"""		0101000020E610000026C808A8700C5740107A36AB3EB14A40
48031	5	49	1722	23304	28597	\N	53.277776000000003	село Ермаковское площадь Победы 8		0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48025	5	49	1722	23304	72589	\N	53.277776000000003	село Ермаковское, Щетинкина, 11		0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48041	5	49	1722	23304	72622	\N	53.277776000000003	село Ермаковское, Трактовая, 42		0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48028	5	49	1722	23304	71552	\N	53.277776000000003	село Ермаковское, Старковых, 19		0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48029	5	49	1722	23304	71554	\N	53.277776000000003	село Ермаковское, Российская, 42		0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48027	5	49	1722	23304	27989	\N	53.277776000000003	село Ермаковское, Октябрьская, 53		0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48024	5	49	1722	23304	72803	\N	53.277776000000003	"село Ермаковское, Мостовая, 5""а"""		0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48026	5	49	1722	23304	72659	\N	53.277776000000003	село Ермаковское, Ленина, 80	Россия, Красноярский край, Ермаковский район, поселок Ермаковское	0101000020E61000006D91B41B7D1857408ECEF9298EA34A40
48030	5	49	1722	23304	28019	\N	53.275384256767097	село Ермаковское, 60 лет ВЛКСМ, 23	Россия, Красноярский край, Ермаковский район, поселок Ермаковское	0101000020E61000001844A4A65D195740BCEB6CC83FA34A40
48039	5	49	1722	32810	72599	\N	53.2238883178767	село Григорьевка, Трактовая, 1	Россия, Красноярский край, Ермаковский район, поселок Григорьевка	0101000020E61000000648348122365740C2FBAA5CA89C4A40
48044	5	49	1722	29562	28181	\N	52.239458999999997	село Верхнеусинское, Ленина, 119	Россия, Красноярский край, Ермаковский район, поселок Верхнеусинское	0101000020E6100000D9AF3BDD79415740CEDDAE97A61E4A40
48050	5	49	1722	49325	28034	\N	53.036244000000003	поселок Большая Речка, Ленина, 37		0101000020E61000009E996038D71A57408F56B5A4A3844A40
48043	5	49	1722	29425	27836	\N	52.575580000000002	посёлок Арадан, Нагорная, 1	Россия, Красноярский край, Ермаковский район, поселок Арадан	0101000020E61000002E043928615C5740A81DFE9AAC494A40
48017	5	49	1509	59578	72028	\N	60.242209874482	Красноярский край, Енисейский район, с.Ярцево, Матросова, 40а	Россия	0101000020E610000041F4A44C6A8E5640D061BEBC001F4E40
47992	5	49	1509	59594	72320	\N	58.016534882777499	Красноярский край, Енисейский район, п.Новокаргино, Набережная, 8	Россия	0101000020E6100000876EF607CA3C5740A31EA2D11D024D40
48022	5	49	1509	59799	73061	\N	59.4264023510435	Красноярский край, Енисейский район, п.Александровский Шлюз, Лесная, 20		0101000020E61000001CCEFC6A0E52564079793A5794B64D40
48012	5	49	1509	59738	72975	\N	57.798205000000003	Красноярский край, Енисейский район, д.Назимово, Ермака, 47		0101000020E6100000E02F664B56C056407940D9942BE64C40
48003	5	49	1509	51888	28519	\N	58.225950757420001	Красноярский край, Енисейский район, д.Малобелая, 70 лет Октября, 19		0101000020E61000007500C45DBDFD5640CFBF5DF6EB1C4D40
48013	5	49	1509	59863	73133	\N	59.266007790822499	Красноярский край, Енисейский район, д.Колмогорово, Набережная, 8		0101000020E6100000E44A3D0B42D35640B83CD68C0CA24D40
48010	5	49	1509	59816	73079	\N	59.075953436004397	Красноярский край, Енисейский район, п.Шишмарево, Школьная, 3	Россия	0101000020E6100000A88E554ACFEC56403C84F1D3B8894D40
47989	5	49	1509	27047	27990	\N	57.888038000000002	Красноярский край, Енисейский район, п.Шапкино, Центральная, 26		0101000020E6100000DB5031CEDF42574079CDAB3AABF14C40
47991	5	49	1509	27047	72782	\N	57.888038000000002	Красноярский край, Енисейский район, п.Шапкино, Мира, дос.16 б кв.4		0101000020E6100000DB5031CEDF42574079CDAB3AABF14C40
48005	5	49	1509	59709	72789	\N	57.798205000000003	Красноярский край, Енисейский район, Чалбышево, Рождественского, 38		0101000020E6100000E02F664B56C056407940D9942BE64C40
47994	5	49	1509	59851	73119	\N	58.112114181807598	Красноярский край, Енисейский район,  д.Усть-Тунгуска, Центральная, 32		0101000020E6100000DAE4F049273A57403DB665C0590E4D40
48009	5	49	1509	59860	73129	\N	58.982680301329303	Красноярский край, Енисейский район, с.Усть-Пит, Молодежная, 1	Россия	0101000020E6100000F8FBC56CC9F0564076374F75C87D4D40
48006	5	49	1509	59603	72474	\N	58.540642810109098	Красноярский край, Енисейский район, п.Усть-Кемь, Калинина, 5	Россия	0101000020E61000009B3924B550035740DAE731CA33454D40
48023	5	49	1509	51823	28196	\N	57.798205000000003	Красноярский край, Енисейский район, Сымский сельсовет, с.Сым Набережная 13		0101000020E6100000E02F664B56C056407940D9942BE64C40
47986	5	49	1509	59663	72678	\N	58.436418566116899	Красноярский край, Енисейский район, с.Потапово, Административная, 2		0101000020E6100000CEE15AED61145740302DEA93DC374D40
47982	5	49	1509	51849	28326	\N	58.597903377468	Красноярский край, Енисейский район, поселок Подтесово, Талалихина, 8		0101000020E6100000E2AFC91AF50557401497E315884C4D40
49066	5	49	1509	51849	72563	\N	58.601845829101201	Красноярский край, Енисейский район, п. Подтесово, Калинина, 6		0101000020E6100000F1D4230D6E0657403D9D2B4A094D4D40
48001	5	49	1509	59492	71661	\N	58.472760690256401	Красноярский край, Енисейский район, с.Озерное, Ленинградская, 50	Россия	0101000020E6100000658EE55DF504574081E9B46E833C4D40
48015	5	49	1509	59865	73135	\N	59.833356749606502	Красноярский край, Енисейский район, п.Новый Городок, Восточная, 1		0101000020E6100000232E008DD28B564043723271ABEA4D40
48011	5	49	1509	59667	72694	\N	59.544973430862697	Красноярский край, Енисейский район, п.Новоназимово, Центральная, 50	Россия	0101000020E6100000FBE93F6B7EB45640FC19DEACC1C54D40
48016	5	49	1509	59750	72996	\N	58.187260151337199	Красноярский край, Енисейский район, с.Маковское, Пролетарская, 31		0101000020E6100000AF06280D35B85640ABECBB22F8174D40
48019	5	49	1509	51893	28538	\N	57.798205000000003	Красноярский край, Енисейский район, п.Майское, Школьная, 12а	Россия, Красноярский край, Енисейский район	0101000020E6100000E02F664B56C056407940D9942BE64C40
48020	5	49	1509	59674	72706	\N	60.3016397304485	Красноярский край, Енисейский район, п.Кривляк, Рабочая, 3	Россия	0101000020E61000009E4319AA628156402D95B7239C264E40
48021	5	49	1509	51800	28076	\N	59.3074130076402	Красноярский край, Енисейский район, д.Безымянка Свободная 1	Россия	0101000020E610000015ADDC0BCC3F5640C0AE264F59A74D40
47987	5	49	1509	59762	73012	\N	58.296246497504399	Красноярский край, Енисейский район, с.Городище, 70 лет Октября, 26	Россия	0101000020E6100000D82AC1E2701C574010C99063EB254D40
47988	5	49	1509	59691	72737	\N	58.169849178708603	Красноярский край, Енисейский район, п. Высокогорский, Набережная, 7а		0101000020E6100000BE66B96C742757401021AE9CBD154D40
47998	5	49	1509	59839	73107	\N	58.333824814695497	Красноярский край, Енисейский район, п.Байкал, Набережная, 6	Россия	0101000020E61000002849D74CBE1B574029CB10C7BA2A4D40
48008	5	49	1509	59891	73247	\N	58.871021598950698	Красноярский край, Енисейский район, д.Анциферово, Лесная, 2	Россия	0101000020E6100000CDAE7B2B12F756405B0C1EA67D6F4D40
47950	5	49	1509	59798	73058	\N	58.523747	Красноярский край, Енисейский район, Айдара, Лесная, 1	Россия	0101000020E6100000EBE2361AC0195640663046240A434D40
47949	5	49	202	59575	72014	\N	56.081968604024198	Красноярский край, Емельяновский район, Элита, Заводская, 19		0101000020E61000002AABE97AA22457409624CFF57D0A4C40
47956	5	49	202	59659	72672	\N	56.190192882142199	Красноярский край, Емельяновский район, Шуваево, Просвещения, 3	Россия, Красноярский край, село Шуваево	0101000020E61000001920D1048A395740CD76853E58184C40
47965	5	49	202	59491	71634	\N	56.192585000000001	Красноярский край, Емельяновский район, Частоостровское, Советская, 56		0101000020E610000011E2CAD93B5557409F5912A0A6184C40
47971	5	49	202	59654	72660	\N	56.364809698534799	Красноярский край, Емельяновский район, Устюг, Трактовая, 10		0101000020E61000004F24986A663657407BA01518B22E4C40
47976	5	49	202	59634	72607	\N	56.483984	Красноярский край, Емельяновский район, Талое, Центральная, 13	Россия, Красноярский край, село Талое	0101000020E6100000CA3505323B305740C5E40D30F33D4C40
47954	5	49	202	59599	72446	\N	56.065790999999997	Красноярский край, Емельяновский район, Солонцы, Новостроек, 10		0101000020E6100000C4D2C08F6A36574081AFE8D66B084C40
47966	5	49	202	59843	73112	\N	56.214075999999999	Красноярский край, Емельяновский район, Серебряково, Центральная, 19		0101000020E6100000D52137C30D505740E36DA5D7661B4C40
47980	5	49	202	59733	72936	\N	56.3029602020803	Красноярский край, Емельяновский район, Раскаты, Лесная, 1	Россия, Красноярский край, деревня Раскаты	0101000020E61000008F37F92D3A26574082FFAD64C7264C40
47973	5	49	202	59720	72884	\N	56.305664	Красноярский край, Емельяновский район, Плоское, Центральная, 15 А		0101000020E610000047382D78D130574043C879FF1F274C40
47936	5	49	202	51871	28461	\N	56.216054	Красноярский край, Емельяновский район, Памяти 13 Борцов, Культуры, 8а		0101000020E61000002827DA5548145740C21550A8A71B4C40
47981	5	49	202	59480	71568	\N	56.377212999999998	Красноярский край, Емельяновский район, Никольское, Советская, 75 А		0101000020E610000052431B800D2157402250FD8348304C40
48296	5	49	202	9997	\N	\N	56.191457999999997	"п. Можарский, 6 ""а"""	Россия, Красноярский край, Емельяновский район, поселок Можарский	0101000020E6100000F4A8F8BF23EA56405E471CB281184C40
47953	5	49	202	59652	72656	\N	56.052546999999997	Красноярский край, Емельяновский район, Минино, Юбилейная, 26		0101000020E61000003DD7F7E1202257405F402FDCB9064C40
47975	5	49	202	26411	72940	\N	56.506428999999997	Красноярский край, Емельяновский район, Медведа, Центральная, 22		0101000020E6100000E2E995B20C1A57407C5F5CAAD2404C40
47939	5	49	202	18712	28014	\N	56.230426999999999	Красноярский край, Емельяновский район, Малый Кемчуг 60 лет СССР 5, 1	Россия, Красноярский край, Емельяновский район, М-53 шоссе	0101000020E6100000ECF65965A6095740C58EC6A17E1D4C40
47968	5	49	202	59729	72924	\N	56.145606797959402	Красноярский край, Емельяновский район, Кубеково, Центральная, 2 А	Россия, Красноярский край, деревня Кубеково	0101000020E61000009A779CA223475740CA880B40A3124C40
47948	5	49	202	25138	27749	\N	56.099570999999997	Красноярский край, Емельяновский район, Кача, Вокзальная, 10	Россия, Красноярский край, Емельяновский район, поселок Кача	0101000020E6100000DF3653211E0E5740A45016BEBE0C4C40
47946	5	49	202	25064	28101	\N	56.073990999999999	Красноярский край, Емельяновский район, Зеледеево, Центральная, 73		0101000020E61000009D8026C286FE564063997E8978094C40
47958	5	49	202	59862	73132	\N	56.179155999999999	Красноярский край, Емельяновский район, Замятино, Новая, 2	Россия, Красноярский край, деревня Замятино, улица Новая, 6	0101000020E61000006762BA10AB375740EB707495EE164C40
47934	5	49	202	59649	\N	\N	56.172576392455902	Красноярский край, Емельяновский район, Емельяново, Аэропорт, 4	Россия, Красноярский край, поселок Емельяново	0101000020E6100000A0E1CD1ABC29574089096AF816164C40
47932	5	49	202	59649	73001	\N	56.174482052751401	Красноярский край, Емельяновский район, Емельяново, Рабочая, 5	Россия, Красноярский край, поселок Емельяново, улица Рабочая	0101000020E61000003C4A253CA12A5740CEDE196D55164C40
47940	5	49	202	51749	27823	\N	56.144159215557799	Красноярский край, Емельяновский район, Еловое, Гурского, 16	Россия, Красноярский край, деревня Еловая	0101000020E6100000C4CE143AAF225740483657CD73124C40
47974	5	49	202	59791	73048	\N	56.3670275074874	Красноярский край, Емельяновский район, Гляден, Центральная, 41 А	Россия, Красноярский край, село Гляден	0101000020E610000013F241CF662E5740AF5B04C6FA2E4C40
47977	5	49	202	26494	28143	\N	56.646123000000003	Красноярский край, Емельяновский район, Гаревое, Центральная, 6	Россия, Красноярский край, Емельяновский район, поселок Гаревое	0101000020E6100000E6779ACC78295740C2189128B4524C40
48777	5	49	202	765	72761	\N	55.738945999999999	п.Бахта, Школьная, 5		0101000020E61000000B5D8940F51A574048C153C895DE4B40
47970	5	49	202	59769	73022	\N	56.287257815808204	Красноярский край, Емельяновский район, Барабаново, Горная, 10		0101000020E6100000BDE0D39CBC5A5740D7C1C1DEC4244C40
47951	5	49	202	51838	28268	\N	56.102473000000003	Красноярский край, Емельяновский район, Арейское, Солнечная, 3		0101000020E6100000E7374C34481C57408CDCD3D51D0D4C40
47957	5	49	202	59783	73039	\N	56.231023	Красноярский край, Емельяновский район, Арей, Центральная, 9 А		0101000020E610000086AA984A3F365740D9CF6229921D4C40
48554	5	49	202	51777	27959	\N	56.6253057120771	" Красноярский край, Нижнеингашский район, деревня Алексеевка Первомайская 7""а"""	Россия, Красноярский край, Емельяновский район, поселок Алексеевка	0101000020E6100000B03BDD79E2FE56400DFFE9060A504C40
47938	5	49	7125	51837	28267	\N	56.314506150944098	Красноярский край, Емельяновский район, Таскино, Школьная, 21	Россия, Красноярский край, деревня Таскино	0101000020E61000005B40683D7C3D5740A9328CBB41284C40
49000	5	49	7495	60915	\N	\N	76.232438000000002	Диксонский район, п. Хант. Оз., сельский Дом культуры	Россия	0101000020E61000005723BBD232F257404016A243E00E5340
48998	5	49	7495	59913	\N	\N	68.680166	Диксонский район, п. Потапово, сельский Дом культуры	Россия	0101000020E610000079573D601E9255407976F9D6872B5140
47919	5	49	822	23775	28238	\N	56.801167999999997	Красноярский край, Дзержинский район,с. Шеломки, Центральная, 15	Россия, Красноярский край, Дзержинский район, поселок Шеломки	0101000020E610000042B28009DCB65740054D4BAC8C664C40
47900	5	49	822	22858	27874	\N	56.632323	Красноярский край, Дзержинский район, д. Чурюково, Центральная, 30		0101000020E610000087BF266BD4C357401AC1C6F5EF504C40
47913	5	49	822	23488	72780	\N	56.907803999999999	Красноярский край, Дзержинский район, д. Чемурай, Центральная, 4		0101000020E610000091F12895F0D55740C896E5EB32744C40
47895	5	49	822	22686	72777	\N	56.778914	Красноярский край, Дзержинский район, д. Усолка, Центральная, 1		0101000020E610000084F068E388D45740C2323674B3634C40
47902	5	49	822	22956	27878	\N	56.707031000000001	Красноярский край, Дзержинский район, д. Улюколь, Центральная, 50	Россия, Красноярский край, Дзержинский район, поселок Улюколь	0101000020E6100000EECEDA6D17BB57400C21E7FD7F5A4C40
47916	5	49	822	23626	27896	\N	56.943654000000002	Красноярский край, Дзержинский район, д. Топол, Центральная, 46	Россия, Красноярский край, Дзержинский район, поселок Топол	0101000020E6100000DFA63FFB91C75740AB5E7EA7C9784C40
47909	5	49	822	23306	27807	\N	56.805885000000004	Красноярский край, Дзержинский район, д. Таловая, Кедровая, 30		0101000020E6100000583CF54883DF574022AB5B3D27674C40
47670	5	49	822	23306	28392	\N	56.805885000000004	д.Таловая, Дружбы, 14		0101000020E6100000583CF54883DF574022AB5B3D27674C40
48210	5	49	822	5904	72792	\N	56.583421000000001	д.Сухо-Ерша, Зеленая, 37		0101000020E61000005BD2510E66D357405A66118AAD4A4C40
47910	5	49	822	23319	72727	\N	56.841473000000001	Красноярский край, Дзержинский район, д. Семёновка, Школьная, 40		0101000020E6100000C286A757CADA5740C7BB2363B56B4C40
47907	5	49	822	23223	27887	\N	56.743952999999998	Красноярский край, Дзержинский район, д. Плитная, Чулпан, 26	Россия, Красноярский край, Дзержинский район, поселок Плитная	0101000020E61000005DFC6D4F90E357406B6116DA395F4C40
47906	5	49	822	23133	28073	\N	56.594925000000003	Красноярский край, Дзержинский район, д. Петровка, Центральная, 15		0101000020E6100000F0694E5E64DF574052499D80264C4C40
47911	5	49	822	17538	73118	\N	56.936931000000001	Красноярский край, Дзержинский район, д. Орловска, Центральная, 43	Россия, Красноярский край, Дзержинский район, поселок Орловка	0101000020E61000000D535BEA20E05740E6CDE15AED774C40
47903	5	49	822	59815	73078	\N	56.7325230956884	Красноярский край, Дзержинский район, п. Новый, Школьная, 7	Россия, Красноярский край, Дзержинский район, поселок Новый	0101000020E610000045D5AF743EB25740AE484C50C35D4C40
47898	5	49	822	22783	27876	\N	56.618715000000002	Красноярский край, Дзержинский район, д. Николаевка, Центральная, 52		0101000020E6100000ECA529029CD75740B745990D324F4C40
47908	5	49	822	23231	72888	\N	56.753171999999999	Красноярский край, Дзержинский район, д. Н-Танай, д. В-Танай, Набережная, 4		0101000020E6100000A2D3F36E2CD75740A721AAF067604C40
47901	5	49	822	22933	72935	\N	56.691839999999999	Красноярский край, Дзержинский район, д.Михайловка, Центральная, 58		0101000020E6100000BBB6B75B92C8574046088F368E584C40
47923	5	49	822	23952	27727	\N	56.816867999999999	Красноярский край, Дзержинский район, д. Макарово, Центральная, 30		0101000020E6100000DEC66647AAB95740109370218F684C40
47918	5	49	822	23700	28444	\N	56.847493	Красноярский край, Дзержинский район, д. Кондратьево, Центральная, 29		0101000020E6100000B136C64E78C05740624B8FA67A6C4C40
47915	5	49	822	23593	28239	\N	57.017884000000002	Красноярский край, Дзержинский район, д. Колон, Центральная, 15	Россия, Красноярский край, Дзержинский район, поселок Колон	0101000020E6100000179D2CB5DEC65740938FDD054A824C40
47893	5	49	822	22598	28650	\N	56.859616000000003	Красноярский край, Дзержинский район, д. Кедровка, Центральная, 20		0101000020E610000079758E01D9D35740268FA7E5076E4C40
47920	5	49	822	8926	72934	\N	56.951430000000002	Красноярский край, Дзержинский район, д. Канарай, Школьная, 2		0101000020E61000006C0A647616AF574076374F75C8794C40
47892	5	49	822	22235	72619	\N	56.834480999999997	Красноярский край, Дзержинский район,с. Дзержинское, пер. Южный, 7		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47888	5	49	822	22235	28205	\N	56.834480999999997	Красноярский край, Дзержинский район,с. Дзержинское, Советская, 14		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47890	5	49	822	22235	28291	\N	56.834480999999997	Красноярский край, Дзержинский район,с. Дзержинский, Ракуса, 87		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47887	5	49	822	22235	28417	\N	56.834480999999997	Красноярский край, Дзержинский район, с. Дзержинское, Новый переулок, 1 а		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47891	5	49	822	22235	28418	\N	56.834480999999997	Красноярский край, Дзержинский район, с. Дзержинское, Кирова, 164		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47886	5	49	822	22235	28418	\N	56.834480999999997	Красноярский край, Дзержинский район,с. Дзержинское, Кирова, 20		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47885	5	49	822	22235	28199	\N	56.834480999999997	Красноярский край, Дзержинский район, с. Дзержинское, ул. Денисовская, 66		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47889	5	49	822	22235	28586	\N	56.834480999999997	Красноярский край, Дзержинский район, с.Дзержинское, Больничная, 7		0101000020E61000003C889D2974CE57401211FE45D06A4C40
47914	5	49	822	23502	72614	\N	56.854571	Красноярский край, Дзержинский район, с. Денисово, Лесная, 5		0101000020E6100000D76CE525FFC55740158E2095626D4C40
47899	5	49	822	22846	72778	\N	56.657528999999997	Красноярский край, Дзержинский район, д. Вознесенка, Центральная, 21		0101000020E61000007FC16ED8B6C35740F69507E929544C40
47616	5	49	822	45472	28530	\N	56.971255999999997	д. Борки, ул. Лесная, 24		0101000020E6100000C765DCD440BD57409A05DA1D527C4C40
47922	5	49	822	23908	72867	\N	56.884093999999997	Красноярский край, Дзержинский район, д. Большая-Степь, Калинина, 9		0101000020E61000003D47E4BB94B257407F4B00FE29714C40
47921	5	49	822	23851	28621	\N	56.834598999999997	Красноярский край, Дзержинский район, д. Батов, Кайтымская, 35		0101000020E610000041446ADAC5A557401C23D923D46A4C40
47905	5	49	822	23126	28606	\N	56.685808999999999	Красноярский край, Дзержинский район, д. Ашпатск, Центральная, 74		0101000020E6100000DA37F7578FE25740B726DD96C8574C40
47897	5	49	822	22698	28589	\N	56.629555000000003	Красноярский край, Дзержинский район, д Александро-Ерша, Центральная, 66		0101000020E610000010E6762FF7D0574043041C4295504C40
47875	5	49	875	21790	28402	\N	56.679698000000002	с.Удачное, Советская, 22	Россия, Красноярский край, Большеулуйский район, поселок Удачное	0101000020E61000002237C30DF89756400C94145800574C40
49057	5	49	875	14837	28209	\N	56.575538000000002	д.Турецк, Колхозная, 22-А		0101000020E6100000555051F52BAC564079CDAB3AAB494C40
47864	5	49	875	21178	72768	\N	56.622959000000002	п.Таежка, Центральная, 15		0101000020E6100000871403249AC05640DBDFD91EBD4F4C40
47874	5	49	875	46009	28572	\N	56.5707792529711	с.Сучково, Советская, 58	Россия, Красноярский край, Большеулуйский район, поселок Сучково	0101000020E6100000EB71DF6A9D9F56402E1F49490F494C40
47563	5	49	875	59780	73035	\N	56.620626999999999	с. Сосновый Бор, Боровая, 2-Б		0101000020E610000096E99788B7A35640DE019EB4704F4C40
47873	5	49	875	21657	72862	\N	56.508400999999999	д.Симоново, Мира, 35		0101000020E6100000382C0DFCA89D56407920B24813414C40
47872	5	49	875	21559	27853	\N	56.493253000000003	с.Новая Еловка, Советская, 50-Б	Россия, Красноярский край, Большеулуйский район, поселок Новая-Еловка	0101000020E6100000E3C281902CA95640B3D30FEA223F4C40
47861	5	49	875	21107	28565	\N	56.804228999999999	п.Кытат, Таежная, 15	Россия, Красноярский край, Большеулуйский район, поселок Кытат	0101000020E610000060E5D022DBCC564055BFD2F9F0664C40
47877	5	49	875	59754	73004	\N	56.747718999999996	д.Карабановка, Лесная, 19-А	Россия, Красноярский край, Большеулуйский район, поселок Карабановка	0101000020E610000097C9703C9F9B564085CC9541B55F4C40
47860	5	49	875	21011	27829	\N	56.795544	д.Елга, Дружбы, 3		0101000020E610000026FBE769C0B55640B743C362D4654C40
47881	5	49	875	21985	72948	\N	56.558601000000003	с.Бычки, Центральная, 46		0101000020E6100000E5417A8A1C905640A741D13C80474C40
47856	5	49	875	20827	71551	\N	56.652151000000003	с.Большой Улуй, Советская, 123		0101000020E6100000541C075E2DA55640E08618AF79534C40
47884	5	49	875	20827	27859	\N	56.652151000000003	с.Большой Улуй, Медицинская, 1		0101000020E6100000541C075E2DA55640E08618AF79534C40
48167	5	49	875	21310	28295	\N	56.622658135705997	д. Бобровка, Трактовая, 35,А	Россия, Красноярский край, Большеулуйский район, поселок Бобровка	0101000020E610000014AFB2B629B45640E04BE141B34F4C40
47847	5	49	1460	20352	72769	\N	57.323321	поселок Язаевка, Набережная, 11		0101000020E61000004E25034015535740158E209562A94C40
47853	5	49	1460	51790	28002	\N	56.845779966608703	село Юксеево Центральная 27	Россия, Красноярский край, Большемуртинский район, поселок Юксеево	0101000020E61000007B87DBA1615C574031CEDF84426C4C40
47835	5	49	1460	19638	72931	\N	56.809251000000003	деревня Тигино, пер.Садовый, 11		0101000020E61000002FDFFAB0DE495740AEA0698995674C40
47848	5	49	1460	16762	28371	\N	57.057459999999999	село Российка Заречная 61	Россия, Красноярский край, Большемуртинский район, поселок Российка	0101000020E610000071ADF6B017545740016A6AD95A874C40
47844	5	49	1460	45432	72929	\N	57.237869000000003	поселок Раздольное, Центральная, 43		0101000020E6100000CEFFAB8E1C495740BADDCB7D729E4C40
47831	5	49	1460	19063	28354	\N	57.062109999999997	поселок Предивинск Луговая 11	Россия, Красноярский край, Большемуртинский район, поселок городского типа Предивинск	0101000020E6100000D238D4EFC25B574095607138F3874C40
47852	5	49	1460	45583	27838	\N	57.187162999999998	деревня Муратово, Дачная, 1		0101000020E6100000429946938B535740B8020AF5F4974C40
47843	5	49	1460	19157	28168	\N	56.759976999999999	поселок Мостовское Чуева 27	Россия, Красноярский край, Большемуртинский район, поселок Мостовское	0101000020E610000017F4DE1802305740295B24ED46614C40
47850	5	49	1460	20508	28277	\N	57.098216000000001	деревня Минск, Нагорная, 27/1		0101000020E6100000F25F200890555740D3F88557928C4C40
47833	5	49	1460	19564	28160	\N	56.952775000000003	деревня Малый Кантат, Новая, 24		0101000020E6100000D8B8FE5D9F47574024B9FC87F4794C40
47846	5	49	1460	51827	28230	\N	57.303694	поселок Луговское Центральная 23/1	Россия, Красноярский край, Большемуртинский район, поселок Луговское	0101000020E6100000170FEF39B0535740E7FEEA71DFA64C40
47840	5	49	1460	45353	28105	\N	56.926799000000003	поселок Красные Ключи, Советская, 26 А		0101000020E61000002236583849325740967B8159A1764C40
48225	5	49	1460	45644	28172	\N	56.900298999999997	д.Комарово, Школьная, 13		0101000020E61000009E98F562285357408DCF64FF3C734C40
47855	5	49	1460	45644	72724	\N	56.900298999999997	деревня Комарово, Центральная, 24		0101000020E61000009E98F562285357408DCF64FF3C734C40
47837	5	49	1460	49567	72779	\N	57.028892999999997	деревня Казанка, Кооперативная, 30 А	Россия, Красноярский край, Большемуртинский район, поселок Казанка	0101000020E6100000E8FA3E1C24355740AA0A0DC4B2834C40
47678	5	49	1460	46751	\N	\N	56.753715	с.Еловка, Ленина, 22	Россия, Красноярский край, Большемуртинский район, поселок Еловка	0101000020E6100000AA0EB9196E51574098C0ADBB79604C40
47838	5	49	1460	46751	72875	\N	56.753715	село Еловка, Центральная, 1 А		0101000020E6100000AA0EB9196E51574098C0ADBB79604C40
47836	5	49	1460	19701	72890	\N	57.048608999999999	село Верх-Казанка, Солнечная, 17		0101000020E61000002B31CF4A5A32574048A5D8D138864C40
47849	5	49	1460	20463	72865	\N	57.048437999999997	деревня Большой Кантат, Верхняя, 1		0101000020E6100000F6D1A92B9F4857401BF1643733864C40
47829	5	49	1460	19273	71618	\N	56.902392999999996	поселок Большая Мурта, пер.Центральный, 10		0101000020E61000001D3EE94482495740D591239D81734C40
47830	5	49	1460	59486	71619	\N	56.902392999999996	поселок Большая Мурта, Советская, 167 а		0101000020E61000001D3EE94482495740D591239D81734C40
47828	5	49	1460	59486	71590	\N	56.902392999999996	поселок Большая Мурта, Кооперативная, 15		0101000020E61000001D3EE94482495740D591239D81734C40
47834	5	49	1460	19149	28004	\N	56.724900920980097	село Бартат Центральная 40	Россия, Красноярский край, Большемуртинский район, поселок Бартат	0101000020E610000025CD1FD3DA4857403AEB538EC95C4C40
47832	5	49	1460	19468	28487	\N	57.009945000000002	село Айтат, Новая, 1		0101000020E6100000942F6821013F57401EE1B4E045814C40
47826	5	49	1558	59712	72804	\N	58.587122000000001	"п. Хребтовый, Киевская, 9 ""Б"""	Россия	0101000020E610000015CAC2D7D7A758408D614ED0264B4D40
47800	5	49	1558	59856	73124	\N	58.859181229923799	п. Беляки, Школьная, 22		0101000020E610000008C89750C14C58401B2C9CA4F96D4D40
47772	5	49	1558	59656	72664	\N	58.439182123042301	п. Ангарский, Ленина, 18	Россия	0101000020E610000084F1D3B8374A5840F67EA31D37384D40
40073	5	49	1558	59845	73114	\N	58.392453785647199	д. Ярки, Ленина, 9		0101000020E6100000D0D38041D24658409A97C3EE3B324D40
47810	5	49	1558	59672	72704	\N	58.421084636557502	п. Шиверский, Центральный, 10	Россия	0101000020E6100000BA4DB857E673584007EBFF1CE6354D40
47820	5	49	1558	18867	28341	\N	57.446568999999997	с. Чунояр, Партизанская, 33	Россия, Красноярский край, Богучанский район, поселок Чунояр	0101000020E61000000E828E56B55458402634492C29B94C40
47823	5	49	1558	51758	27875	\N	57.6176866730641	"п. Такучет, 50 лет Октября, 37 ""А"""	Россия, Красноярский край, Богучанский район, поселок Токучет	0101000020E6100000C26C020CCB2C584009151C5E10CF4C40
47803	5	49	1558	59621	72542	\N	58.381172116206798	с. Богучаны, Октябрьская, 65	Россия	0101000020E6100000F1A0D9756F5D584051137D3ECA304D40
47827	5	49	1558	49421	\N	\N	57.750359000000003	д. Прилуки, здание школы		0101000020E6100000B1DEA815A6EE574030A182C30BE04C40
47801	5	49	1558	59826	73091	\N	58.368382508289997	п. Пинчуга, Ленина, 67	Россия	0101000020E61000001D925A28993B584081B3942C272F4D40
94448	5	49	1558	32714	28352	\N	57.567514000000003	д. Осиновый Мыс, Советская, 46		0101000020E6100000DD5F3DEE5B3A5840D6027B4CA4C84C40
47818	5	49	1558	49301	28533	\N	57.443750999999999	п. Октябрьский, Победы, 19		0101000020E6100000304CA60A466258409D4830D5CCB84C40
47817	5	49	1558	18719	27803	\N	57.755113000000001	п. Новохайский, Школьная, 8		0101000020E6100000D95BCAF9625B584069E4F38AA7E04C40
47795	5	49	1558	60034	73559	\N	58.424598226304397	п. Нижнетерянск, Октябрьская, 8		0101000020E6100000C55565DF1595584038F92D3A59364D40
47819	5	49	1558	49315	72930	\N	57.430641999999999	"д. Малеево, Центральная, 3 ""А"""	Россия, Красноярский край, Богучанский район, поселок Малеево	0101000020E61000007A8CF2CCCB6158405B24ED461FB74C40
47816	5	49	1558	18647	27984	\N	57.819360000000003	п. Кежек, Черемушки, 12		0101000020E610000096EB6D331572584046D3D9C9E0E84C40
47813	5	49	1558	59870	73145	\N	58.026629871434501	д. Карабула, Центральная, 10	Россия	0101000020E61000007E5182FE42595840D68BA19C68034D40
47798	5	49	1558	59841	73109	\N	58.495551813841402	д. Иркинеево, Октябрьская, 26	Россия	0101000020E610000076FBAC3253355840D4BB783F6E3F4D40
47799	5	49	1558	59822	73086	\N	58.805832978131299	д. Бедоба, Ленина, 8	Россия	0101000020E6100000FEF15EB5324E5840CF84268925674D40
47797	5	49	1558	59676	72707	\N	58.510203317230598	п. Артюгино, Юбилейная, 25		0101000020E6100000F8FBC56CC92F584019A9F7544E414D40
47775	5	49	1396	51752	27832	\N	56.247315999999998	Красноярский край, Боготольский район, Вагинский сельсовет, д.Коробейниково Школьная 33		0101000020E61000005E6919A9F765564086E3F90CA81F4C40
47790	5	49	1396	20374	28544	\N	56.314276999999997	Красноярский край, Боготольский район, Юрьевский сельсовет,с.Юрьевка Центральная 88		0101000020E61000001EA67D737F54564047718E3A3A284C40
47785	5	49	1396	32756	72818	\N	56.384616889214001	Красноярский край, Боготольский район, Чайковский сельсовет, д.Шулдат 50 лет Октября 39	Россия, Красноярский край, Боготольский район, поселок Шулдат	0101000020E6100000CD22145B41665640293E3E213B314C40
47783	5	49	1396	16990	\N	\N	56.351973999999998	Красноярский край, Боготольский район, Чайковский сельсовет,п.Чайковский, помещение сельского Дома культуры	Россия, Красноярский край, Боготольский район, поселок Чайковский	0101000020E6100000ADC3D155BA6756406A85E97B0D2D4C40
47125	5	49	1396	16488	73212	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Сибирская 34б		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47767	5	49	1396	40279	9701	\N	56.274449527909198	Красноярский край, Боготольский район, Боготольский сельсовет,с.Медяково Советская 2	Россия, Красноярский край, Боготольский район	0101000020E610000028BA2EFCE06956409031772D21234C40
47780	5	49	1396	32735	72830	\N	56.270820087321397	Красноярский край, Боготольский район, Критовский сельсовет, д.Разгуляевка Центральная 62	Россия, Красноярский край, Боготольский район, поселок Разгуляевка	0101000020E61000001EC18D942D765640268DD13AAA224C40
47766	5	49	1396	19558	28129	\N	56.149669712419701	662074 Красноярский край, Боготольский район, Боготольский сельсовет, п.Орга Мира 33	Россия, Красноярский край, Боготольский район, поселок Орга	0101000020E6100000CA32C4B12E7256409E98F56228134C40
47770	5	49	1396	19635	28047	\N	56.082956417029799	Красноярский край, Боготольский район, Большекосульский сельсовет, д.Малая Косуль Береговая 7	Россия, Красноярский край, Боготольский район, поселок Малая Косуль	0101000020E6100000588CBAD6DE555640E5805D4D9E0A4C40
47793	5	49	1396	32773	27871	\N	56.275219545671199	Красноярский край, Боготольский район, Юрьевский сельсовет, д.Лебедевка Верхняя 17		0101000020E610000086CB2A6C06505640419AB1683A234C40
47778	5	49	1396	20149	72679	\N	56.241963289131	Красноярский край, Боготольский район, Критовский сельсовет, с.Критово Переездная 1	Россия, Красноярский край, Боготольский район, поселок Критово	0101000020E6100000A75CE15D2E805640C8EBC1A4F81E4C40
47776	5	49	1396	20002	27821	\N	56.187269999979897	Красноярский край, Боготольский район, Краснозаводский сельсовет,с.Красный Завод Центральная 7	Россия, Красноярский край, Боготольский район, поселок Красный Завод	0101000020E6100000628731E9EF815640CEC29E76F8174C40
47777	5	49	1396	20097	28539	\N	56.227829999999997	Красноярский край, Боготольский район, Краснозаводский сельсовет,д.Красная Речка Трактовая 89	Россия, Красноярский край, Боготольский район, поселок Красная Речка	0101000020E61000001AA88C7F9F8356401A868F88291D4C40
47769	5	49	1396	16594	27902	\N	56.114435556981903	Красноярский край, Боготольский район, Большекосульский сельсовет,п Каштан Буркова 7	Россия, Красноярский край, Боготольский район, поселок Каштан	0101000020E61000006AA33A1DC84F564016BEBED6A50E4C40
48515	5	49	1396	51735	28078	\N	56.3657193794946	"с. Ильинка, Школьная, 4 ""А"""	Россия, Красноярский край, Боготольский район, поселок Ильинка	0101000020E61000004D4BAC8C467356404E4354E1CF2E4C40
47773	5	49	1396	51735	27764	\N	56.365894055449402	Красноярский край, Боготольский район, Вагинский сельсовет, д.Ильинка Пахомова 41	Россия, Красноярский край, Боготольский район, поселок Ильинка	0101000020E61000003A75E5B33C735640BCE6559DD52E4C40
47774	5	49	1396	51780	72817	\N	56.389527999999999	Красноярский край, Боготольский район, Вагинский сельсовет, д.Дмитриевка Октябрьская 53	Россия, Красноярский край, Боготольский район, поселок Дмитриевка	0101000020E610000027F6D03E567A56402A70B20DDC314C40
47779	5	49	1396	33054	72900	\N	56.283917725132703	Красноярский край, Боготольский район, Критовский сельсовет, д.Гнетово Центральная 10	Россия, Красноярский край, Боготольский район, поселок Гнетово	0101000020E6100000B5334C6DA9785640745FCE6C57244C40
47792	5	49	1396	32762	72836	\N	56.392599334317801	Красноярский край, Боготольский район, Юрьевский сельсовет, д.Георгиевка Центральная 16		0101000020E6100000B2F336363B5656409DB81CAF40324C40
47765	5	49	1396	32635	28632	\N	56.168761700522502	" Красноярский край, Боготольский район, Боготольский сельсовет, д.Владимировка Школьная 1""А"""	Россия, Красноярский край, Боготольский район, поселок Владимировка	0101000020E6100000890CAB78237656405E6743FE99154C40
47789	5	49	1396	33002	28080	\N	56.304441660972998	Красноярский край, Боготольский район, Юрьевский сельсовет, д.Вишняково-Катеюл Центральная 7	Россия, Красноярский край, Боготольский район, поселок Вишняково-Катеюл	0101000020E610000076FBAC32535D5640B1C398F4F7264C40
47781	5	49	1396	19709	28350	\N	56.350791000000001	Красноярский край, Боготольский район, Критовский сельсовет,станция Вагино Северная 13	Россия, Красноярский край, Боготольский район, поселок Вагино	0101000020E61000009605137F14745640965D30B8E62C4C40
47771	5	49	1396	19709	28021	\N	56.350741049765098	Красноярский край, Боготольский район, Вагинский сельсовет, с.Вагино Кооперативная 5	Россия, Красноярский край, Боготольский район, поселок Вагино	0101000020E610000070253B3602745640E42EC214E52C4C40
47788	5	49	1396	33125	\N	\N	56.420293999999998	Красноярский край, Боготольский район, Чайковский сельсовет,д.Булатово, помещение школы		0101000020E6100000AD3594DA8B6956403E5A9C31CC354C40
47768	5	49	1396	19600	\N	\N	56.134120651725901	Красноярский край, Боготольский район, Большекосульский сельсовет,с.Большая Косуль Ленина 101	Россия, Красноярский край, Боготольский район, поселок Большая Косуль	0101000020E610000054C90050C5565640795A7EE02A114C40
47128	5	49	1396	16488	73164	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Школьная 75а	Россия, Красноярский край, Боготольский район, город Боготол	0101000020E610000059C4B0C3985F564096766A2E371A4C40
47114	5	49	1396	16488	73198	\N	56.204808999999997	Красноярский край, город Боготол Совхозная 24	Россия, Красноярский край, Боготольский район, город Боготол	0101000020E610000059C4B0C3985F564096766A2E371A4C40
47764	5	49	1396	16488	28637	\N	56.206387792465001	Красноярский край, Боготольский район, с.Боготол Советская 11	Россия, Красноярский край, Боготольский район, город Боготол	0101000020E6100000E5EE737CB4615640B72407EC6A1A4C40
49067	5	49	1396	16488	73279	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Советская 63		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47118	5	49	1396	16488	73199	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Кирова 18		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47127	5	49	1396	16488	73285	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Кирова 78		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47126	5	49	1396	16488	73196	\N	56.204808999999997	Боготолькский район,662060 г. Боготол 40 лет Октября 33	Россия, Красноярский край, Боготольский район, город Боготол	0101000020E610000059C4B0C3985F564096766A2E371A4C40
47120	5	49	1396	16488	73226	\N	56.204808999999997	Боготолькский район,662060 г. Боготол 1-я Зарельсовая 48		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47791	5	49	1396	51747	28055	\N	56.388457261021898	Красноярский край, Боготольский район, Юрьевский сельсовет, д.Березовка Ленинская 8	Россия, Красноярский край, Боготольский район, поселок Берёзовка	0101000020E610000086AE44A0FA4C56407E737FF5B8314C40
47763	5	49	1396	51801	\N	\N	56.010465721696299	Красноярский край, Боготольский район, Александровский сельсовет, Дом культуры	Россия, Красноярский край, Боготольский район, поселок Александровка	0101000020E61000008B389D64AB55564027DC2BF356014C40
47116	5	49	7494	59892	73252	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Куйбышева 43		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47112	5	49	7494	59892	73257	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Деповская 17		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47124	5	49	7494	59882	73188	\N	56.204808999999997	Боготолькский район,662060 г. Боготол Промышленная 6а		0101000020E610000059C4B0C3985F564096766A2E371A4C40
47752	5	49	1352	15533	27986	\N	57.212010999999997	д.Шпагино, Центральная, 7		0101000020E6100000388600E0D8A7564035B22B2D239B4C40
47744	5	49	1352	32917	28252	\N	56.983224999999997	с.Суриково, Строительная, 21		0101000020E61000007EFCA5457DD9564007CE1951DA7D4C40
47734	5	49	1352	14607	28601	\N	56.893422000000001	д.Старая Еловка, Школьная, 1		0101000020E61000001502B9C491AA564072C3EFA65B724C40
39886	5	49	1352	17552	72858	\N	57.469223	д.Сопка, Новая, 1		0101000020E6100000BEF561BD51845640F8C3CF7F0FBC4C40
47738	5	49	1352	14806	72809	\N	56.804913999999997	д.Сахарное Профсоюзная 45	Россия, Красноярский край, Бирилюсский район, поселок Сахарное	0101000020E6100000AB7B6473D5925640D80B056C07674C40
47745	5	49	1352	48055	28429	\N	57.001126999999997	поселок Рассвет, Комсомольская, 15	Россия, Красноярский край, Бирилюсский район, поселок городского типа Рассвет	0101000020E61000004450357A35DE56404012F6ED24804C40
47755	5	49	1352	15624	28465	\N	57.329273999999998	д.Промбор, Центральная, 13	Россия, Красноярский край, Бирилюсский район, поселок Промбор	0101000020E61000001ADB6B41EF99564028B682A625AA4C40
47754	5	49	1352	48238	27914	\N	57.347951000000002	с.Полевое, Центральная, 3	Россия, Красноярский край, Бирилюсский район, поселок Полевое	0101000020E6100000D996016729A2564025CE8AA889AC4C40
47733	5	49	1352	14505	28089	\N	56.950226999999998	Красноярский край, Бирилюсский район, с.Новобирилюссы, Советская, 130		0101000020E6100000DA571EA4A7AB56405A63D009A1794C40
47732	5	49	1352	14505	28089	\N	56.950226999999998	с.Новобирилюссы, Советская, 151		0101000020E6100000DA571EA4A7AB56405A63D009A1794C40
47757	5	49	1352	15699	72953	\N	57.099575000000002	д.Нижний Тунуй, Новая, 23		0101000020E61000008F8EAB915D965640E63FA4DFBE8C4C40
47759	5	49	1352	15795	73070	\N	57.165525000000002	д.Муслинка, Центральная, 32	Россия, Красноярский край, Бирилюсский район, поселок Муслинка	0101000020E610000098874CF9108F5640D0D556EC2F954C40
47748	5	49	1352	15245	27739	\N	57.097375	п.Мендельский, Центральная, 12		0101000020E6100000DCF3FC69A3DE56405839B4C8768C4C40
47750	5	49	1352	15389	28260	\N	57.152247000000003	с.Маталассы, Школьная, 10	Россия, Красноярский край, Бирилюсский район, поселок Маталассы	0101000020E6100000988A8D791DB8564002F566D47C934C40
47749	5	49	1352	15326	27817	\N	57.327635999999998	п.Малая Кеть, Почтовая, 7	Россия, Красноярский край, Бирилюсский район, поселок Малая Кеть	0101000020E61000002D42B11534EA5640027FF8F9EFA94C40
47758	5	49	1352	15747	27747	\N	57.136626	с.Кирчиж, Советская, 9	Россия, Красноярский край, Бирилюсский район, поселок Кирчиж	0101000020E61000001F2DCE18E68C564043E4F4F57C914C40
47747	5	49	1352	15235	72859	\N	57.022734999999997	п.Кемчуг, Береговая, 3		0101000020E6100000AA7D3A1E33DE5640BEBC00FBE8824C40
47737	5	49	1352	14760	28280	\N	56.889758999999998	с.Зачулымка, Новая, 10		0101000020E6100000C2BF081A339D56402C29779FE3714C40
47736	5	49	1352	14673	28623	\N	57.144469761533998	д.Дорохта Центральная 2	Россия, Красноярский край, Бирилюсский район, поселок Дорохта	0101000020E6100000ADC1FBAA5CA4564066A032FE7D924C40
48776	5	49	1352	51875	72068	\N	57.490926690813403	п. Бор, Кирова, 78а   (дом культуры)	Россия, Красноярский край, Бирилюсский район, поселок Бор	0101000020E6100000DB17D00B777C564098DC28B2D6BE4C40
48774	5	49	1352	51875	28481	\N	57.489700999999997	п. Бор, 60 лет Аэрофлота, 7	Россия, Красноярский край, Бирилюсский район, поселок Бор	0101000020E610000000E5EFDE517C5640C4E8B985AEBE4C40
47760	5	49	1352	15829	72806	\N	57.199081999999997	д.Биктимировка Зеленая 31		0101000020E6100000BF2A172AFF8E5640739CDB847B994C40
47735	5	49	1352	47863	28243	\N	57.025492999999997	с.Арефьево, Школьная, 1	Россия, Красноярский край, Бирилюсский район, поселок Арефьево	0101000020E61000003657CD7344AB564072A3C85A43834C40
48166	5	49	1352	51773	27946	\N	57.106995722675101	с. Александровка, Центральная, 23	Россия, Красноярский край, Бирилюсский район, поселок Александровка	0101000020E610000053245F09A48E5640C366800BB28D4C40
47729	5	49	493	14355	28600	\N	55.551889000000003	п. Урман, Молодежная, 7		0101000020E610000005323B8BDE3E5740D6027B4CA4C64B40
47556	5	49	493	6148	28102	\N	56.166857345166001	пос.Тартат, 40 лет Октября, 6	Россия, Красноярский край, Березовский район, поселок Тартат	0101000020E61000003145B9347E575740E90DF7915B154C40
47722	5	49	493	14037	72649	\N	55.865051000000001	с. Маганск, Новая, 2		0101000020E61000000798F90E7E505740A12FBDFDB9EE4B40
47720	5	49	493	59703	72772	\N	55.944467081144801	д. Лукино, Мамина, 29		0101000020E6100000B3B112F3AC4657405C936E4BE4F84B40
48550	5	49	493	59735	72938	\N	56.185426999999997	деревня Калиновка, Советская, 45		0101000020E6100000E0D91EBDE15A5740CF656A12BC174C40
47984	5	49	465	26797	72583	\N	55.324289	Красноярский край, Енисейский район, с. Епишино, Лесная, 11		0101000020E6100000CD77F01307EF5640EDB94C4D82A94B40
48416	5	49	493	51809	28120	\N	55.400077000000003	Красноярский край, Манский район, п.Жержул ул.Нагорная д.2	Россия, Красноярский край, Березовский район, поселок Жержул	0101000020E610000018EE5C18E9525740DF701FB935B34B40
47538	5	49	493	2945	28082	\N	56.240713	г.Железногорск, Школьная, 18		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47537	5	49	493	2945	28082	\N	56.240713	г.Железногорск, Школьная, 34	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47496	5	49	493	2945	28082	\N	56.240713	г.Железногорск, Школьная, 46		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47560	5	49	493	2945	27744	\N	56.257369432067897	г.Железногорск, Толстого, 22		0101000020E6100000FFB1101D026257408A00A777F1204C40
47553	5	49	493	2945	28438	\N	56.240713	г.Железногорск, Сибирская, 19		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47542	5	49	493	2945	28464	\N	56.248171647857703	г.Железногорск, Свердлова, 5	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E6100000999F1B9AB262574036E49F19C41F4C40
47539	5	49	493	2945	27879	\N	56.240713	г.Железногорск, Парковая, 1	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47543	5	49	493	2945	71541	\N	56.240713	г.Железногорск, Молодежная, 7		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
48976	5	49	493	2945	28248	\N	56.240713	г.Железногорск, Ленинградский проспект, 32		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47552	5	49	493	2945	28248	\N	56.240713	г.Железногорск, Ленинградский проспект, 81		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47550	5	49	493	2945	28248	\N	56.2398678461076	г.Железногорск, Ленинградский проспект, 37	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E61000000B9C6C03775F5740B0AD9FFEB31E4C40
47540	5	49	493	2945	71546	\N	56.240713	г.Железногорск, Ленина, 23		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47536	5	49	493	2945	71546	\N	56.246642450426002	г.Железногорск, Ленина, 48		0101000020E61000005FD4EE5701635740F7E80DF7911F4C40
47541	5	49	493	2945	28087	\N	56.240713	г.Железногорск, Крупской, 8		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47546	5	49	493	2945	28246	\N	56.240713	г.Железногорск, Королева, 7А		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47534	5	49	493	2945	71604	\N	56.246068985577502	г.Железногорск, Комсомольская, 35А		0101000020E61000004E4700378B6257409BC761307F1F4C40
47545	5	49	493	2945	28602	\N	56.238454544946002	г.Железногорск, Восточная, 25		0101000020E6100000410B09185D635740AA4885B1851E4C40
47544	5	49	493	2945	28602	\N	56.240713	г.Железногорск, Восточная, 15		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47555	5	49	493	2945	71550	\N	56.240713	г.Железногорск, Белорусская, 42		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47535	5	49	493	2945	28612	\N	56.240713	г.Железногорск, Андреева, 14		0101000020E6100000F8DF4A766C5F57406C5CFFAECF1E4C40
47549	5	49	493	2945	28603	\N	56.242815921412799	г.Железногорск, 60 лет ВЛКСМ, 32	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E6100000E36DA5D7665F574007793D98141F4C40
47548	5	49	493	2945	28603	\N	56.247789354249399	г.Железногорск, 60 лет ВЛКСМ, 18	Россия, Красноярский край, Березовский район, город Железногорск	0101000020E610000060E97C78966257407EA7C98CB71F4C40
47726	5	49	493	14174	27907	\N	55.690547000000002	п. Верх-Базаиха, Школьная, 3		0101000020E6100000DE8FDB2F9F585740EBAC16D863D84B40
47728	5	49	493	14267	72861	\N	55.689973999999999	п. Береть, Центральная, 1		0101000020E6100000247B849A214057408F8B6A1151D84B40
47724	5	49	493	14130	72933	\N	55.806503999999997	п. Березовский, Победы, 1		0101000020E610000028B9C32632525740ED0BE8853BE74B40
47723	5	49	493	14130	28611	\N	55.806503999999997	п. Березовский, Нагорная, 6А, Сельский клуб		0101000020E610000028B9C32632525740ED0BE8853BE74B40
47706	5	49	493	59481	71572	\N	56.0311189120143	Красноярский край, Березовский район, поселок Березовка, Юбилейная, 6	Россия, Красноярский край, поселок Березовка	0101000020E610000029E961687548574061A417B5FB034C40
47712	5	49	493	59481	73087	\N	56.008777000000002	Красноярский край, Березовский район, поселок Березовка, Молодежная, 1		0101000020E6100000E065868DB24657407FFACF9A1F014C40
47711	5	49	493	59481	72041	\N	56.018554000000002	Красноярский край, Березовский район, поселок Березовка, Матросова, 21А		0101000020E6100000D4298F6E84475740E19A3BFA5F024C40
47700	5	49	465	59785	73042	\N	55.325267639772399	д.Малая Тумна, Клубная, 1а	Россия, Красноярский край, Балахтинский район, М-54 шоссе	0101000020E6100000A663CE33F6EE5640B937BF61A2A94B40
47643	5	49	465	59773	73027	\N	55.235117930739698	д.Ямская, Мира, 21а	Россия, Красноярский край, Балахтинский район, поселок Ямская	0101000020E6100000A4E36A6457E85640B859BC58189E4B40
47691	5	49	465	59713	72805	\N	55.192352999999997	д.Якушово, Новая, 2	Россия, Красноярский край, Балахтинский район, поселок Якушево	0101000020E61000004F0306499FC35640CC24EA059F984B40
47703	5	49	465	47249	72752	\N	55.176063999999997	п.Черемушки, Мира, 5		0101000020E6100000F0F78BD9920B57406000E14389964B40
49062	5	49	465	46821	72812	\N	55.500376000000003	д.Холодный Ключ, Школьная, 2		0101000020E6100000255D33F966C2564006DA1D520CC04B40
47682	5	49	465	12152	72937	\N	55.376125000000002	п.Угольный, Мира, 7а	Россия, Красноярский край, Балахтинский район, поселок Угольный	0101000020E6100000DEAF027CB7D55640A01A2FDD24B04B40
47674	5	49	465	11794	72635	\N	55.357613999999998	с.Тюльково, Ленина, 118а	Россия, Красноярский край, Балахтинский район, поселок Тюльково	0101000020E6100000A7E8482EFFCF5640BE4BA94BC6AD4B40
47679	5	49	465	12012	\N	\N	55.559196	д.Трясучая, Школьная, 12-2	Россия, Красноярский край, Балахтинский район, поселок Трясучая	0101000020E610000048FC8A355CD85640EA060ABC93C74B40
47685	5	49	465	12301	72833	\N	55.471648000000002	д.Тойлук, Заречная, 18		0101000020E6100000B51666A19DC95640A69C2FF65EBC4B40
47683	5	49	465	33118	27954	\N	55.510221000000001	с.Ровное, Школьная, 6		0101000020E61000006631B1F9B8C75640C05DF6EB4EC14B40
47695	5	49	465	47093	71614	\N	55.203724000000001	п.Приморск, Карла Маркса, 18		0101000020E6100000F4FC69A33AF9564085B4C6A0139A4B40
39346	5	49	465	23471	28556	\N	55.355995999999998	с.Огур, Тольятти, 3а		0101000020E61000003C139A2496F75640DFC0E44691AD4B40
47693	5	49	465	12717	27860	\N	55.261463999999997	п.Могучий, Новая, 4		0101000020E6100000DC9BDF30D1B55640698A00A777A14B40
48178	5	49	465	51787	27994	\N	55.579051044903103	с. Курбатово, Береговая, 2,2	Россия, Красноярский край, Балахтинский район, поселок Курбатово	0101000020E6100000DD25715644CA5640A9DBD9571ECA4B40
47676	5	49	465	46691	72824	\N	55.359036000000003	д.Крюково, Центральная, 37		0101000020E6100000AB5FE97C78C25640180B43E4F4AD4B40
47699	5	49	465	59793	73050	\N	55.446635999999998	д.КрасныйКлюч, Центральная, 15а	Россия, Красноярский край, Балахтинский район, поселок Красный Ключ	0101000020E6100000791EDC9DB5FD5640AE9B525E2BB94B40
47672	5	49	465	59794	73052	\N	55.307222000000003	д.Красная, Центральная, 24б	Россия, Красноярский край, Балахтинский район, поселок Красная	0101000020E6100000D3BF249529EC56404D4EED0C53A74B40
47677	5	49	465	46724	\N	\N	55.358401999999998	с.Кожаны, клуб, 29		0101000020E61000009259BDC3EDC556401669E21DE0AD4B40
47675	5	49	465	46690	28372	\N	55.353860691769803	д.Ключи, Центральная, 6	Россия, Красноярский край, Балахтинский район, поселок Ключи	0101000020E6100000D8F2CAF5B6C95640392A37514BAD4B40
47689	5	49	465	12491	72823	\N	55.212822000000003	д.Ильтюково, Космонавтов, 12		0101000020E61000005C1D007157C6564046EF54C03D9B4B40
47697	5	49	465	59830	73096	\N	55.195172999999997	с.Ижуль, Ижульская, 10	Россия, Красноярский край, Балахтинский район, поселок Ижульское	0101000020E6100000E73922DFA5EB5640F607CA6DFB984B40
48000	5	49	465	51826	28227	\N	53.318533407000601	"село Жеблахты, Ойская, 63""а"""	Россия, Красноярский край, Балахтинский район, М-54 шоссе	0101000020E61000002C67EF8CB60B574030D978B0C5A84A40
47696	5	49	465	12816	28472	\N	55.224336000000001	с.Даурское, Юности, 2		0101000020E6100000172B6A300DFE564061A8C30AB79C4B40
47686	5	49	465	12386	72749	\N	55.479453999999997	с.Грузенка, Московская, 18		0101000020E610000064CDC82077BD5640DBF7A8BF5EBD4B40
47680	5	49	465	46792	28389	\N	55.486224	д.Гладкий Мыс, Мира, 20	Россия, Красноярский край, Балахтинский район, поселок Гладкий Мыс	0101000020E6100000C501F4FBFED05640E14389963CBE4B40
47690	5	49	465	46992	28406	\N	55.269424672507199	, п.Вольный, Старая, 8	Россия, Красноярский край, Балахтинский район, поселок Вольный	0101000020E6100000FE277FF78EC25640C6DCB5847CA24B40
47702	5	49	465	13101	72860	\N	55.600113999999998	д.Виленка, Ленина, 43		0101000020E61000002716F88A6EE4564095EF1989D0CC4B40
47701	5	49	465	13059	28215	\N	55.516205999999997	с.Большие Сыры, Космонавтов, 15		0101000020E610000087DBA16131E35640DEFFC70913C24B40
47673	5	49	465	11743	72832	\N	55.287430000000001	д.Безъязыково, пер.Центральный, 3		0101000020E61000009128B4ACFBDF5640D4F19881CAA44B40
47687	5	49	465	12429	28403	\N	55.405445	д.Балдаштык, Центральная, 4		0101000020E6100000AD69DE718ABF5640D2A92B9FE5B34B40
47665	5	49	465	59477	71597	\N	55.389279000000002	поселок Балахта, Ленина, 9		0101000020E6100000F10EF0A485E756408202EFE4D3B14B40
47663	5	49	465	59477	71528	\N	55.389279000000002	поселок Балахта, 60 лет Октября, 11		0101000020E6100000F10EF0A485E756408202EFE4D3B14B40
47668	5	49	465	11245	28563	\N	55.389279000000002	поселок Балахта, Чайковского, 40		0101000020E6100000F10EF0A485E756408202EFE4D3B14B40
47669	5	49	465	11245	28387	\N	55.389279000000002	поселок Балахта, пер. Школьный, 8		0101000020E6100000F10EF0A485E756408202EFE4D3B14B40
47664	5	49	465	11245	27770	\N	55.383708863881999	поселок Балахта, Космонавтов, 19	Россия, Красноярский край, Балахтинский район, поселок городского типа Балахта	0101000020E61000002B4CDF6B08E85640271763601DB14B40
47666	5	49	465	11245	27839	\N	55.389279000000002	поселок Балахта, Каткова, 22		0101000020E6100000F10EF0A485E756408202EFE4D3B14B40
47657	5	49	1133	10996	28117	\N	56.137320000000003	Красноярский край, Ачинский район, Ястребовский сельсовет, с.Ястребово, Новая, 2		0101000020E61000005070B1A206AB56401A8BA6B393114C40
47650	5	49	1133	10673	28118	\N	56.399755999999996	Красноярский край, Ачинский район, Лапшихинский сельсовет, д.Тимонино, им.Ивченко М.Л, 34		0101000020E61000004565C39ACAAF56409C3061342B334C40
47654	5	49	1133	10852	28541	\N	56.299385999999998	Красноярский край, Ачинский район, Тарутинский сельсовет, п.Тарутино, Переулок Клубный, б/н		0101000020E61000008D7DC9C683B55640AC70CB4752264C40
47653	5	49	1133	10786	72919	\N	56.292298000000002	Красноярский край, Ачинский район, Тарутинский сельсовет, с.Покровка, Центральная, 26		0101000020E61000001668774831B15640D65757056A254C40
48002	5	49	1133	27626	72786	\N	56.044186000000003	Красноярский край, Енисейский район, с.Плотбище, Советская, 18	Россия, Красноярский край, Ачинский район, поселок Плотбище	0101000020E6100000F243A51133B65640757808E3A7054C40
47662	5	49	1133	11212	28377	\N	56.405365000000003	Красноярский край, Ачинский район, Тарутинский сельсовет, с.Ольховка, Партизанская, 40а		0101000020E61000005534D6FECEBD5640B6F81400E3334C40
47645	5	49	1133	59768	73021	\N	56.406405999999997	Красноярский край, Ачинский район, Причулымский сельсовет, д.Нагорново, Уланова, 1а		0101000020E61000008E5A61FA5E9A5640F7729F1C05344C40
47659	5	49	1133	11062	72892	\N	56.120347000000002	Красноярский край, Ачинский район, Ключинский сельсовет, д.Мылый Улуй, Центральная, 20		0101000020E6100000F67D3848889B5640FB95CE87670F4C40
47649	5	49	1133	10601	28124	\N	56.453026000000001	Красноярский край, Ачинский район, Лапшихинский сельсовет, с.Лапшиха, Советская, 13		0101000020E610000037548CF337B056406D1E87C1FC394C40
47882	5	49	1133	46199	72773	\N	56.483547000000002	д.Красная Заря, Зеленая, 27	Россия, Красноярский край, Ачинский район, поселок Красная Заря	0101000020E6100000F73C7FDAA89256401A8A3BDEE43D4C40
48354	5	49	1133	59776	73029	\N	56.074466000699402	"д. Костеньки, Зеленая, 11 ""А"""	Россия, Красноярский край, Ачинский район, поселок Костеньки	0101000020E61000001094DBF63D9E5640FC54151A88094C40
47658	5	49	1133	51859	28397	\N	56.164636999999999	Красноярский край, Ачинский район, Ключинский сельсовет, п.Ключи, Центральная, 5	Россия, Красноярский край, поселок Ключи	0101000020E61000009DBB5D2F4D9F5640145B41D312154C40
49083	5	49	1133	59747	72990	\N	56.218972000000001	Красноярский край, Ачинский район, Горный сельсовет, д. Карловка, Армейская, здание казармы в\\ч 74076-2		0101000020E61000002BDD5D6743A35640AF5E4546071C4C40
47646	5	49	1133	10465	28161	\N	56.390394999999998	Красноярский край, Ачинский район, Причулымский сельсовет, д.Борцы, Центральная, 48		0101000020E61000001CD31396788F5640CEC29E76F8314C40
47647	5	49	1133	59497	71695	\N	56.309177077636797	Красноярский край, Ачинский район, Преображенский сельсовет, с. Большая Салырь, Школьная, 16	Россия, Красноярский край, село Большая Салырь, улица Школьная	0101000020E6100000FBCA83F414A1564073D6A71C93274C40
47640	5	49	1133	51832	\N	\N	56.287692	Красноярский край, Ачинский район, Белоярский сельсовет, п.Белый Яр, МПС, 12а		0101000020E61000005CACA8C13494564011A96917D3244C40
47641	5	49	1133	51832	28241	\N	56.287692	Красноярский край, Ачинский район, Белоярский сельсовет, с.Белый Яр, Трактовая, 55		0101000020E61000005CACA8C13494564011A96917D3244C40
47652	5	49	7123	51792	28006	\N	56.2768015027968	Красноярский край, Ачинский район, Малиновский сельсовет, п.Малиновка, Квартал 1, 4	Россия, Красноярский край, поселок Малиновка	0101000020E610000066D993C0E6A45640D4BB783F6E234C40
47656	5	49	7123	51820	28171	\N	56.242130475264098	Красноярский край, Ачинский район, Ястребовский сельсовет, п.Березовый, Клубная, 3а	Россия, Красноярский край, поселок Берёзовый	0101000020E6100000B3B45373B9AB5640B4B0A71DFE1E4C40
49074	5	49	955	59859	73128	\N	57.0030435874611	Красноярский край, Абанский район, Почетский сельсовет, п. Хиндичет, ул. Заречная, 16-1	Россия, Красноярский край, Абанский район	0101000020E610000087DC0C37E05A58407A39ECBE63804C40
47637	5	49	955	9995	72844	\N	57.093052	с. Хандальск, ул. Школьная, 20		0101000020E61000001D5723BBD2475840E869C020E98B4C40
47631	5	49	955	9682	28516	\N	56.522153000000003	с. Устьянск, ул. Мира, 29Б	Россия, Красноярский край, Абанский район, поселок Устьянск	0101000020E6100000EF92382BA20058401041D5E8D5424C40
47627	5	49	955	45667	28065	\N	56.653407999999999	с. Турово, ул. Советская, 48	Россия, Красноярский край, Абанский район, поселок Турово	0101000020E61000000394861A851A5840EE7893DFA2534C40
47604	5	49	955	49522	28442	\N	56.666899000000001	д. Стерлитамак, ул. Центральная, 9	Россия, Красноярский край, Абанский район, поселок Стерлитамак	0101000020E61000003B54539275F85740185E49F25C554C40
47608	5	49	955	8677	27798	\N	56.732098999999998	д. Средние Мангареки, ул. Набережная, 10		0101000020E610000053CA6B2574F757409737876BB55D4C40
49071	5	49	955	15540	28630	\N	56.613672999999999	Красноярский край, Абанский район, Туровский сельсовет, д. Сенное, ул. Советская, 21-2		0101000020E6100000E8853B174615584017B83CD68C4E4C40
47626	5	49	955	32806	72618	\N	56.835760999999998	с. Самойловка, ул. Советская, 56		0101000020E61000002BD9B11188F95740D9226937FA6A4C40
47629	5	49	955	45708	27951	\N	56.708123000000001	д. Пушкино, ул. А.С. Пушкина, 26		0101000020E610000054C554FA09215840D04543C6A35A4C40
47617	5	49	955	9074	72891	\N	57.193530107346099	п.Почет, ул. Юбилейная, 10	Россия, Красноярский край, Абанский район, поселок Почет	0101000020E6100000BD378600E01A5840BF654E97C5984C40
47619	5	49	955	9074	28613	\N	57.189337999999999	п. Почет, ул. Победы, 10		0101000020E6100000B05758703F1B5840EDF1423A3C984C40
47625	5	49	955	59748	72991	\N	56.9934790475886	с. Пакатеево, ул. Советская, 36	Россия, Красноярский край, Абанский район, поселок Покатеево	0101000020E61000006B662D05A45A5840A321E3512A7F4C40
47620	5	49	955	45535	28075	\N	57.290427000000001	с. Плахино, ул. Школьная, 47-2	Россия, Красноярский край, Абанский район, поселок Плахино	0101000020E61000004AB72572C12558400D7041B62CA54C40
47639	5	49	955	45903	28357	\N	57.176036000000003	п. Пея, ул. Больничная, 10		0101000020E61000003A58FFE7303858409775FF5888964C40
47635	5	49	955	9921	27809	\N	56.534092999999999	д. Огурцы, ул. Береговая, 20А		0101000020E6100000BF45274BADF95740E202D0285D444C40
47597	5	49	955	8109	28144	\N	56.606926000000001	д. Ношино, ул. Советская, 46		0101000020E61000007079AC1919EE5740CA8B4CC0AF4D4C40
47611	5	49	955	45342	73060	\N	56.772204343538299	д. Зимник, ул. Советская 35	Россия, Красноярский край, Абанский район, поселок Новоуспенка	0101000020E610000097546D37C114584092EBA694D7624C40
47610	5	49	955	45342	28512	\N	56.769438999999998	с. Новоуспенка, ул. А. Лебедя, 25		0101000020E6100000CDCCCCCCCC1458402BA226FA7C624C40
47634	5	49	955	9858	27806	\N	56.562842000000003	д. Новокиевлянка, ул. Покровская, 14		0101000020E61000006DE690D4420D58405A68E7340B484C40
48109	5	49	955	59763	73013	\N	56.463915576927803	Красноярский край, Иланский район, Новогородский сельсовет, Центральная, сельский Дом культуры	Россия, Красноярский край, Абанский район, поселок Новгородка	0101000020E6100000C5C9FD0E450A5840AA0B7899613B4C40
47598	5	49	955	49439	72807	\N	56.561146000000001	д. Мачино, ул. Школьная, 4		0101000020E6100000013274ECA0F15740FF23D3A1D3474C40
49072	5	49	955	15546	28462	\N	56.922074000000002	Красноярский край, Абанский район, Покровский сельсовет, д. Малкас, Школьная, 2		0101000020E6100000E8DA17D00BF45740F73E558506764C40
47602	5	49	955	49488	27797	\N	56.823630999999999	д. Лазарево ул. Центральная 22		0101000020E6100000FEBAD39D27335840637C98BD6C694C40
47630	5	49	955	9675	72831	\N	56.8184085370617	д. Кунгул, ул. Советская, 10	Россия, Красноярский край, Абанский район, поселок Кунгул	0101000020E610000077BE9F1A2FF8574044E048A0C1684C40
47633	5	49	955	45794	27999	\N	56.541592000000001	д. Красный Яр, ул. Школьная, 6		0101000020E6100000DC2A8881AE0658403BE3FBE252454C40
47614	5	49	955	45439	28163	\N	56.717331999999999	д. Канарай, ул. Подгорная, 26		0101000020E6100000A1BB24CE8A0D5840E82FF488D15B4C40
47603	5	49	955	8418	28317	\N	56.712254000000001	с. Заозерка, ул. Сибирская, 15	Россия, Красноярский край, Абанский район, поселок Заозерка	0101000020E6100000A796ADF545F45740FC389A232B5B4C40
47628	5	49	955	9545	28282	\N	56.671858999999998	с. Залипье, ул. Молодежная, 17		0101000020E6100000527FBDC282175840FA42C879FF554C40
47605	5	49	955	8506	27772	\N	56.686728000000002	д. Долженовка ул. Буденного 38 Б		0101000020E6100000EC51B81E85F95740AE9FFEB3E6574C40
47601	5	49	955	49473	27948	\N	56.749797000000001	с. Долгий Мост ул. Советская 98		0101000020E6100000C9B08A3732335840C8D11C59F95F4C40
47600	5	49	955	49473	72680	\N	56.749797000000001	с. Долгий Мост, ул. Дзержинского, 22	Россия, Красноярский край, Абанский район, поселок Долгий Мост	0101000020E6100000C9B08A3732335840C8D11C59F95F4C40
47632	5	49	955	45765	72920	\N	56.577247999999997	д. Денисовка, ул. Почтовая, 26		0101000020E61000002DE92807B304584038D73043E3494C40
47613	5	49	955	8868	28166	\N	56.728020000000001	п. Гагарина, ул. Молодежная, 16	Россия, Красноярский край, Абанский район, поселок Гагарина	0101000020E61000009961A3ACDF065840BE6A65C22F5D4C40
47615	5	49	955	9010	72815	\N	56.711497999999999	д. Высокогородецк, ул. Советская, 30		0101000020E61000005776C1E09A125840AF95D05D125B4C40
47623	5	49	955	45590	28216	\N	56.950668999999998	п. Восток, ул. Первомайская, 20		0101000020E61000000FF10F5B7AF4574017299485AF794C40
47624	5	49	955	9367	28146	\N	56.976303999999999	д.Быстровка, ул. Школьная, 3		0101000020E61000003929CC7B9CEC57401C7A8B87F77C4C40
47638	5	49	955	45870	28001	\N	57.115921	п. Борзово, ул. Железнодорожная, 2	Россия, Красноярский край, Абанский район, поселок Борзово	0101000020E61000005DA79196CA485840B6F5D37FD68E4C40
47618	5	49	955	9118	28364	\N	57.162733000000003	д. Бирюса, ул. Новая, 1		0101000020E61000007D59DAA9B91F5840707D586FD4944C40
47594	5	49	955	7959	27920	\N	56.858420000000002	с. Апано-Ключи, Ул. Советская, 31	Россия, Красноярский край, Абанский район, поселок Апано-Ключи	0101000020E61000001C0C7558E10D5840BD1DE1B4E06D4C40
47607	5	49	955	49574	72743	\N	56.735219000000001	д. Алексеевка, ул. Трактовая, 29	Россия, Красноярский край, Абанский район, поселок Алексеевка	0101000020E61000007F68E6C935015840EC32FCA71B5E4C40
47591	5	49	955	7810	27790	\N	56.674619	п. Абан, ул. Советская, 71А	Россия, Красноярский край, Абанский район, поселок городского типа Абан	0101000020E61000006DC83F33880458404F2157EA59564C40
47592	5	49	955	7810	27788	\N	56.674619	п. Абан, ул. Пиоерская, 3		0101000020E61000006DC83F33880458404F2157EA59564C40
49054	5	49	955	7810	28617	\N	56.674619	Красноярский край, Абанский район, поселок Абан, ул. Больничная, 26		0101000020E61000006DC83F33880458404F2157EA59564C40
47593	5	49	955	7810	27750	\N	56.674619	п. Абан, ул. Д.Бедного, 56		0101000020E61000006DC83F33880458404F2157EA59564C40
48275	5	49	7124	51793	28008	\N	58.657704068825801	Красноярский край, Кежемский район, город Кодинск, Колесниченко, 10	Россия	0101000020E6100000BF0CC68844CC5840653909A52F544D40
48274	5	49	7124	51793	28008	\N	58.604136754185497	Красноярский край, Кежемский район, город Кодинск, Колесниченко, 16		0101000020E6100000A69C2FF65ECB5840DBA6785C544D4D40
48281	5	49	7124	59716	72819	\N	58.670672252111402	Красноярский край, Кежемский район, с.Заледеево, Октябрьская, 35	Россия	0101000020E6100000E3DEFC8689B45840E52B8194D8554D40
41075	5	51	\N	56070	50409	\N	53.760584999999999	п.ст.Тальжино, Свердлова, 2		0101000020E6100000D15966118ADA5540016A6AD95AE14A40
41574	5	51	\N	60737	75859	\N	56.206834036324999	Кемеровская область, Яйский муниципальный район, Яйское городское поселение,пгт.Яя, Жуковского, 17		0101000020E61000007171546EA29B5540B6D95889791A4C40
40685	5	51	\N	3682	957	\N	55.342922999999999	Кемеровская область, Прокопьевский городской округ, Зенковский район, Центральная, 2	Россия, Кемеровская область, поселок Ясногорский, Центральная улица, 2	0101000020E610000043739D465A795540EA059FE6E4AB4B40
40919	5	51	\N	3682	70330	\N	55.344234	Кемеровская область, Кемеровский район, п.Ясногорский, Центральная, 11		0101000020E6100000A3073E062B795540EC1516DC0FAC4B40
41273	5	51	\N	60794	76277	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица К. Цеткин, 28		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41278	5	51	\N	60794	76224	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Геологическая, 62		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41270	5	51	\N	60794	76298	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица 20 партсъезда, 86а		0101000020E61000005D18E945EDF75540E9482EFF21674A40
40703	5	51	\N	7244	\N	\N	56.063262999999999	Кемеровская область, город Тайга, р-д Сураново		0101000020E61000005C1E6B4606685540FF05820019084C40
40671	5	51	\N	7244	\N	\N	56.063262999999999	Кемеровская область, город Тайга, р-д Кузель		0101000020E61000005C1E6B4606685540FF05820019084C40
40713	5	51	\N	7244	49998	\N	56.063262999999999	Кемеровская область, город Тайга, Щетинкина, 74		0101000020E61000005C1E6B4606685540FF05820019084C40
40707	5	51	\N	7244	49998	\N	56.063262999999999	Кемеровская область, город Тайга, Щетинкина, 56		0101000020E61000005C1E6B4606685540FF05820019084C40
40701	5	51	\N	7244	75763	\N	56.063262999999999	652401, Кемеровская область, город Тайга, Трудовые резервы, 18		0101000020E61000005C1E6B4606685540FF05820019084C40
40590	5	51	\N	7244	50146	\N	56.063262999999999	Кемеровская область, город Тайга, Советская, 101		0101000020E61000005C1E6B4606685540FF05820019084C40
40715	5	51	\N	7244	75759	\N	56.063262999999999	Кемеровская область, город Тайга, Привокзальная, 15		0101000020E61000005C1E6B4606685540FF05820019084C40
40630	5	51	\N	7244	49994	\N	56.063262999999999	652400, Кемеровская область, город Тайга, ул.Почтовая, 99/2		0101000020E61000005C1E6B4606685540FF05820019084C40
40702	5	51	\N	7244	75953	\N	56.101802292979002	Кемеровская область, город Тайга, п.Таёжный, Народная, 7	Россия, Кемеровская область, Яшкинский район, поселок Таёжный	0101000020E610000040F850A2256055406D5512D9070D4C40
40700	5	51	\N	7244	75775	\N	56.058413103701803	Кемеровская область, город Тайга, Молокова, 31	Россия, Кемеровская область, Тайга	0101000020E61000004E61A5828A665540A454C2137A074C40
40712	5	51	\N	7244	12416	\N	56.059997864050203	Кемеровская область, город Тайга, Молодежная, 13	Россия, Кемеровская область, Тайга	0101000020E6100000202922C32A685540A7E9B303AE074C40
40708	5	51	\N	7244	12416	\N	56.063262999999999	Кемеровская область, город Тайга, Молодежная, 1		0101000020E61000005C1E6B4606685540FF05820019084C40
40710	5	51	\N	7244	50150	\N	56.063262999999999	Кемеровская область, город Тайга, Мира, 6		0101000020E61000005C1E6B4606685540FF05820019084C40
40716	5	51	\N	7244	49996	\N	56.063262999999999	Кемеровская область, город Тайга, Кирова, 57		0101000020E61000005C1E6B4606685540FF05820019084C40
40714	5	51	\N	7244	49996	\N	56.063262999999999	Кемеровская область, город Тайга, Кирова, 42		0101000020E61000005C1E6B4606685540FF05820019084C40
40705	5	51	\N	7244	49996	\N	56.063262999999999	Кемеровская область, город Тайга, Кирова, 1		0101000020E61000005C1E6B4606685540FF05820019084C40
40644	5	51	\N	7244	13668	\N	56.060574124324802	Кемеровская область, город Тайга, Калинина, 106	Россия, Кемеровская область, Тайга	0101000020E610000036035C902D685540747E8AE3C0074C40
40704	5	51	\N	7244	50339	\N	56.063262999999999	Кемеровская область, город Тайга, Деповская, 11		0101000020E61000005C1E6B4606685540FF05820019084C40
40909	5	51	\N	3096	803	\N	55.365375999999998	Кемеровская область, Кемеровский район, д.Сухово, Заречная, 2-А		0101000020E610000095B9F946748D5540245F09A4C4AE4B40
41078	5	51	\N	60781	76186	\N	53.820239617274297	п.Старо-Абашево, Линейная, 2А	Россия, Кемеровская область, поселок Староабашево, улица Куюкова	0101000020E610000076FBAC3253DE55407E6FD39FFDE84A40
40823	5	51	\N	60720	75741	\N	54.231855752515699	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Приисковая, 1-а		0101000020E6100000232F6B6281735540D1B01875AD1D4B40
40822	5	51	\N	60720	76179	\N	54.235073810326298	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, ул. Мира, 23	Россия, Кемеровская область, Гурьевский район, Салаир	0101000020E6100000361FD7868A735540E811A3E7161E4B40
39649	5	51	\N	60798	76255	\N	56.083486000000001	Кемеровская область, Анжеро-Судженский городской округ, р.п.Рудничный, Советская, 7		0101000020E6100000F52D73BA2C90554041D653ABAF0A4C40
40575	5	51	\N	60705	75693	\N	53.893996421754501	Кемеровская область, Прокопьевский городской округ, Рудничный район, пр. Строителей, 93	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000F9F4D89601AE55409E60FF756EF24A40
40652	5	51	\N	60705	75910	\N	53.888926436378298	Кемеровская область, Прокопьевский городской округ, Зенковский район, переулок Городской, 31		0101000020E6100000471D1D5723AE55403448C153C8F14A40
40623	5	51	\N	60705	75612	\N	53.908594527488503	Кемеровская область, Прокопьевский городской округ, Центральный район, Революции, 2		0101000020E610000058AA0B7899AE5540912749D74CF44A40
40636	5	51	\N	60705	75732	\N	53.896429795258101	Кемеровская область, Прокопьевский городской округ, Центральный район, Калинина, 1	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000ABCC94D6DFAD55409F93DE37BEF24A40
40603	5	51	\N	60705	75614	\N	53.8945055646575	Кемеровская область, Прокопьевский городской округ, Рудничный район, Институтская, 41		0101000020E61000009694BBCFF1AD5540B309302C7FF24A40
40678	5	51	\N	60705	75739	\N	53.817849403593797	Кемеровская область, Прокопьевский городской округ, Зенковский район, Захаренко, 33	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000AABBB20B06B355407D08AA46AFE84A40
40580	5	51	\N	60705	75604	\N	53.876961000000001	Кемеровская область, Прокопьевский городской округ, Рудничный район, Есенина, 66		0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40571	5	51	\N	60705	75604	\N	53.9064948605578	Кемеровская область, Прокопьевский городской округ, Рудничный район, Есенина, 48		0101000020E6100000946A9F8EC7AE5540677E350708F44A40
40635	5	51	\N	60705	75696	\N	53.893185265617497	Кемеровская область, Прокопьевский городской округ, Центральный район, Вокзальная, 21	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000E7525C55F6AD55408E23D6E253F24A40
40922	5	51	\N	3800	50153	\N	55.354947000000003	Кемеровская область, Кемеровский район, п.Пригородный, Центральная, 120-А		0101000020E61000008FE21C75747C55401B683EE76EAD4B40
40547	5	51	\N	59364	70069	\N	54.498308999999999	Кемеровская область, Осинниковский городской округ, Ефимова, 2		0101000020E61000007079AC1919D85540B726DD96C83F4B40
40544	5	51	\N	16765	50571	\N	53.610707042012002	Кемеровская область, Осинниковский городской округ, 50 лет Октября, 33	Россия, Кемеровская область, Осинники	0101000020E61000006E15C440D7D555401938A0A52BCE4A40
40520	5	51	\N	16765	12789	\N	53.621574868889603	Кемеровская область, Осинниковский городской округ, Шахтовая, 3	Россия, Кемеровская область, Осинники	0101000020E6100000BEF561BD51D655406F8104C58FCF4A40
40548	5	51	\N	16765	75601	\N	53.619936000000003	Кемеровская область, Осинниковский городской округ, Советская, 6	Россия, Кемеровская область, Осинники	0101000020E6100000E71C3C139AD7554079CE16105ACF4A40
40540	5	51	\N	16765	75601	\N	53.623201760837198	Кемеровская область, Осинниковский городской округ, Советская, 23	Россия, Кемеровская область, Осинники	0101000020E61000004DF6CFD380D65540A1664815C5CF4A40
40546	5	51	\N	16765	75602	\N	53.592912746421199	Кемеровская область, Осинниковский городской округ, Победы, 54	Россия, Кемеровская область, Осинники	0101000020E6100000F2CEA10C55D55540C72FBC92E4CB4A40
40535	5	51	\N	16765	69696	\N	53.619936000000003	Кемеровская область, Осинниковский городской округ, Победы, 11	Россия, Кемеровская область, Осинники	0101000020E6100000E71C3C139AD7554079CE16105ACF4A40
40291	5	51	\N	16765	13681	\N	53.619936000000003	Кемеровская область, Осинниковский городской округ, Куйбышева, 7	Россия, Кемеровская область, Осинники	0101000020E6100000E71C3C139AD7554079CE16105ACF4A40
40529	5	51	\N	16765	50037	\N	53.619936000000003	Кемеровская область, город Осинники, Кирова, 17		0101000020E6100000E71C3C139AD7554079CE16105ACF4A40
40498	5	51	\N	16765	75595	\N	53.619936000000003	Кемеровская область, Осинниковский городской округ, Заречная, 15	Россия, Кемеровская область, Осинники	0101000020E6100000E71C3C139AD7554079CE16105ACF4A40
40545	5	51	\N	16765	13419	\N	53.608356478615796	Кемеровская область, Осинниковский городской округ, Ефимова, 8	Россия, Кемеровская область, Осинники	0101000020E610000024EEB1F4A1D55540A629029CDECD4A40
40528	5	51	\N	16765	69697	\N	53.619936000000003	Кемеровская область, Осинниковский городской округ, Вокзальная, 13	Россия, Кемеровская область, Осинники	0101000020E6100000E71C3C139AD7554079CE16105ACF4A40
40521	5	51	\N	16765	12299	\N	53.622187203172203	Кемеровская область, Осинниковский городской округ, 9-я штольня, 29	Россия, Кемеровская область, Осинники	0101000020E61000001EC022BF7ED65540887FD8D2A3CF4A40
40539	5	51	\N	16765	75900	\N	53.623584754967901	Кемеровская область, Осинниковский городской округ, 50 лет Октября, 1		0101000020E61000008675E3DD91D6554059A31EA2D1CF4A40
40453	5	51	\N	51916	81138	\N	53.759376801360702	Кемеровская область, город Новокузнецк, Центральный район, Энтузиастов, 55, училище искусств	Россия, Кемеровская область, Новокузнецк, улица Энтузиастов, 55	0101000020E6100000E141B3EBDEC75540D42AFA4333E14A40
40429	5	51	\N	51916	76216	\N	53.761370552896601	Кемеровская область, город Новокузнецк, Центральный район, Франкфурта, 16, художественная гимназия №70	Россия, Кемеровская область, Новокузнецк, улица Франкфурта, 16	0101000020E6100000F2237EC51ACA5540B88FDC9A74E14A40
39793	5	51	\N	51916	28867	\N	53.752543000000003	652806, Кемеровская область, Калтанский городской округ, Невского, 15	Россия, Кемеровская область, Новокузнецк, улица Невского, 9	0101000020E6100000DF8B2FDAE3C65540B8EA3A5453E04A40
40306	5	51	\N	51916	28832	\N	53.894266999999999	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Косыгина, 63	Россия, Кемеровская область, Новокузнецк, улица Косыгина, 63	0101000020E61000005DDC460378C855402E724F5777F24A40
40435	5	51	\N	51916	28818	\N	53.771995005824898	Кемеровская область, город Новокузнецк, Центральный район, Строителей, 55, МАУ по орг. пасс.перевозок	Россия, Кемеровская область, Новокузнецк, проспект Строителей, 55	0101000020E6100000984EEB36A8C7554077D66EBBD0E24A40
40433	5	51	\N	51916	28818	\N	53.768273199036898	Кемеровская область, город Новокузнецк, Центральный район, пр.Строителей, 17, ТУ 87	Россия, Кемеровская область, Новокузнецк, проспект Строителей, 17	0101000020E610000083328D2617C755402DB308C556E24A40
40341	5	51	\N	51916	28863	\N	53.831783245978102	Кемеровская область, город Новокузнецк, Заводской район, пр. Советской Армии, 13	Россия, Кемеровская область, Новокузнецк, проспект Советской Армии, 13	0101000020E6100000BF9D44847FCB5540342F87DD77EA4A40
40303	5	51	\N	51916	28840	\N	53.905625999999998	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, Пр. Мира, 46	Россия, Кемеровская область, Новокузнецк, проспект Мира, 46	0101000020E61000004A0C022B87C855402234828DEBF34A40
40302	5	51	\N	51916	28840	\N	53.905664051316798	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, пр. Мира, 46	Россия, Кемеровская область, Новокузнецк, проспект Мира, 46	0101000020E610000052B648DA8DC85540109546CCECF34A40
39801	5	51	\N	51916	28840	\N	53.902687	652740, Кемеровская область, Калтанский городской округ, Мира проспект, 30	Россия, Кемеровская область, Новокузнецк, проспект Мира, 30	0101000020E610000041649126DEC855401EC3633F8BF34A40
40487	5	51	\N	51916	28942	\N	53.754460000000002	Кемеровская область, город Новокузнецк, Куйбышевский район, Курако, 33	Россия, Кемеровская область, Новокузнецк, проспект Курако, 33	0101000020E6100000D124B1A4DCC65540F111312592E04A40
40457	5	51	\N	51916	76238	\N	53.748992000000001	Кемеровская область, город Новокузнецк, Центральный район, Бардина, 14, Кузбассгражданпроект	Россия, Кемеровская область, Новокузнецк, проспект Бардина, 14	0101000020E610000015E46723D7C755409A7B48F8DEDF4A40
40304	5	51	\N	51916	28835	\N	53.898426999999998	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, пр. Авиаторов, 106	Россия, Кемеровская область, Новокузнецк, проспект Авиаторов, 106	0101000020E610000045A0FA0791C85540F46BEBA7FFF24A40
40300	5	51	\N	51916	28835	\N	53.900576000000001	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, пр. Авиаторов, 47	Россия, Кемеровская область, Новокузнецк, проспект Авиаторов, 47	0101000020E61000004DF564FED1C7554000C8091346F34A40
40299	5	51	\N	51916	28835	\N	53.896506000000002	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, пр. Авиаторов, 76	Россия, Кемеровская область, Новокузнецк, проспект Авиаторов, 76	0101000020E61000008E041A6CEAC755407A5567B5C0F24A40
40349	5	51	\N	51916	75840	\N	53.826180831559498	Кемеровская область, город Новокузнецк, Заводской район, Чекистов, 13	Россия, Кемеровская область, Новокузнецк, проезд Чекистов, 13	0101000020E6100000E02A4F20ECCB5540CDC98B4CC0E94A40
40445	5	51	\N	51916	81139	\N	53.753322250761101	Кемеровская область, город Новокузнецк, Центральный район, Кулакова, 3, лицей 84	Россия, Кемеровская область, Новокузнецк, проезд Кулакова, 3	0101000020E61000006E85B01A4BC75540BCADF4DA6CE04A40
40444	5	51	\N	51916	76290	\N	53.755502999999997	Кемеровская область, город Новокузнецк, Центральный район, Коммунаров, 1, Металлургический колледж	Россия, Кемеровская область, Новокузнецк, проезд Коммунаров, 1	0101000020E61000000EF8FC3042C75540D3838252B4E04A40
40605	5	51	\N	51916	50624	\N	53.762231999999997	Кемеровская область, Прокопьевский городской округ, Центральный район, Яворского, 5А		0101000020E61000003CA1D79FC4CC55407AFB73D190E14A40
40267	5	51	\N	51916	71716	\N	53.708368	Кемеровская область, город Междуреченск - Междуреченский район, ул.Юдина, 17		0101000020E6100000C7A0134207C8554037C478CDABDA4A40
40362	5	51	\N	51916	70434	\N	53.775483000000001	Кемеровская область, город Новокузнецк, Кузнецкий район, Шункова, 26	Россия, Кемеровская область, Новокузнецк, улица Шункова, 26	0101000020E61000000EBDC5C37BCC55404FCDE50643E34A40
40361	5	51	\N	51916	70434	\N	53.771774000000001	Кемеровская область, город Новокузнецк, Кузнецкий район, Шункова, 6	Россия, Кемеровская область, Новокузнецк, улица Шункова, 6	0101000020E61000007A008BFCFACB554099F38C7DC9E24A40
40369	5	51	\N	51916	71067	\N	53.777222999999999	Кемеровская область, город Новокузнецк, Кузнецкий район, Шестакова, 17	Россия, Кемеровская область, Новокузнецк, переулок Шестакова, 17	0101000020E61000001B65FD6662CD55407959130B7CE34A40
40467	5	51	\N	51916	75762	\N	53.754573566631898	Кемеровская область, город Новокузнецк, Куйбышевский район, Щебелинская, 10	Россия, Кемеровская область, Новокузнецк, Шебелинская улица, 10	0101000020E61000005E6743FE99C35540B9347EE195E04A40
40481	5	51	\N	51916	28938	\N	53.741616999999998	Кемеровская область, город Новокузнецк, Куйбышевский район, Читинский, 2	Россия, Кемеровская область, Новокузнецк, Читинский проезд, 2	0101000020E61000004D9F1D705DC455402D944C4EEDDE4A40
40491	5	51	\N	51916	71501	\N	53.750962000000001	Кемеровская область, город Новокузнецк, Куйбышевский район, Черноморская, 1	Россия, Кемеровская область, Новокузнецк, Черноморская улица, 1	0101000020E6100000884A2366F6C65540F644D7851FE04A40
40477	5	51	\N	51916	71306	\N	53.746803	Кемеровская область, город Новокузнецк, Куйбышевский район, Челюскина, 15	Россия, Кемеровская область, Новокузнецк, улица Челюскина, 15	0101000020E6100000DE21C50089C4554000C79E3D97DF4A40
40474	5	51	\N	51916	71306	\N	53.747670999999997	Кемеровская область, город Новокузнецк, Куйбышевский район, Челюскина, 16	Россия, Кемеровская область, Новокузнецк, улица Челюскина, 16	0101000020E610000064247B849AC455407495EEAEB3DF4A40
40458	5	51	\N	51916	76215	\N	53.7484897037682	Кемеровская область, город Новокузнецк, Центральный район, Циолковского, 42а, школа 31		0101000020E61000009E5E29CB10C9554007B13385CEDF4A40
40447	5	51	\N	51916	76215	\N	53.787565080057597	Кемеровская область, город Новокузнецк, Центральный район, Циолковского, 47, проф.лицей №10		0101000020E610000091F0BDBF41CE5540B43C0FEECEE44A40
40417	5	51	\N	51916	76215	\N	53.755601217174899	Кемеровская область, город Новокузнецк, Центральный район, Циолковского, 65, лицей 34	Россия, Кемеровская область, Новокузнецк, улица Циолковского, 65	0101000020E6100000C6A2E9EC64C9554096E99788B7E04A40
40399	5	51	\N	51916	76215	\N	53.753890836644402	Кемеровская область, город Новокузнецк, Центральный район, Циолковского, 78а		0101000020E6100000632AFD84B3C95540D7DF12807FE04A40
40430	5	51	\N	51916	76282	\N	53.7614722693232	Кемеровская область, город Новокузнецк, Центральный район, Франкфурта, 16 худ.гимн. №70		0101000020E6100000FEB7921D1BCA5540EC681CEA77E14A40
40439	5	51	\N	51916	76250	\N	53.772807232480197	Кемеровская область, город Новокузнецк, Центральный район, Филиппова, 10, школа 2		0101000020E6100000FE2B2B4D4AC85540588FFB56EBE24A40
40384	5	51	\N	51916	71283	\N	53.805101000000001	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Уютная, 30	Россия, Кемеровская область, Новокузнецк, Уютная улица, 30	0101000020E61000007E1AF7E637D755400B7DB08C0DE74A40
40442	5	51	\N	51916	76383	\N	53.765942000000003	Кемеровская область, Новокузнецкий городской округ, Центральный район, Ушинского, 5		0101000020E61000000B96EA025EC75540015130630AE24A40
40380	5	51	\N	51916	71076	\N	53.800973999999997	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Тузовского, 17	Россия, Кемеровская область, Новокузнецк, улица Тузовского, 17	0101000020E6100000B18BA2073ED855402079E75086E64A40
40634	5	51	\N	51916	71720	\N	53.747661000000001	Кемеровская область, Прокопьевский городской округ, Центральный район, Транспортная, 13	Россия, Кемеровская область, Новокузнецк, Транспортная улица, 13	0101000020E61000008BFD65F7E4C7554051BF0B5BB3DF4A40
40504	5	51	\N	51916	70619	\N	53.743555000000001	Кемеровская область, город Новокузнецк, Куйбышевский район, Транспортная, 57	Россия, Кемеровская область, Новокузнецк, Транспортная улица, 57	0101000020E6100000DDCD531D72C855407EE36BCF2CDF4A40
40456	5	51	\N	51916	70619	\N	53.745800352877502	Кемеровская область, город Новокузнецк, Центральный район, Транспортная, 29 МОУ СОШ 91	Россия, Кемеровская область, Новокузнецк, Транспортная улица, 29	0101000020E6100000BEBF417BF5C75540ACADD85F76DF4A40
40338	5	51	\N	51916	70422	\N	53.834930999999997	Кемеровская область, город Новокузнецк, Заводской район, Тореза, 11	Россия, Кемеровская область, Новокузнецк, улица Тореза, 11	0101000020E61000007521567F84CB554052B5DD04DFEA4A40
40329	5	51	\N	51916	70422	\N	53.831077999999998	Кемеровская область, город Новокузнецк, Заводской район, Тореза, 22в	Россия, Кемеровская область, Новокузнецк, улица Тореза, 22в	0101000020E6100000DCD5ABC8E8CA554069368FC360EA4A40
40309	5	51	\N	51916	70422	\N	53.822218999999997	Кемеровская область, город Новокузнецк, Заводской район, Тореза, 82а	Россия, Кемеровская область, Новокузнецк, улица Тореза, 82а	0101000020E6100000A1698995D1C955402D93E1783EE94A40
40352	5	51	\N	51916	28873	\N	53.781059999999997	Кемеровская область, город Новокузнецк, Заводской район, пр. Томский, 9	Россия, Кемеровская область, Новокузнецк, Томский проезд, 9	0101000020E61000003A94A12AA6C955405C1B2AC6F9E34A40
40432	5	51	\N	51916	76209	\N	53.761443999999997	Кемеровская область, город Новокузнецк, Центральный район, Тольятти, 52, школа 67	Россия, Кемеровская область, Новокузнецк, улица Тольятти, 52	0101000020E6100000E8BE9CD9AEC9554022DE3AFF76E14A40
40431	5	51	\N	51916	76209	\N	53.761227414419999	Кемеровская область, город Новокузнецк, Центральный район, Тольятти, 52, школа 57	Россия, Кемеровская область, Новокузнецк, улица Тольятти, 52	0101000020E6100000F2EA1C03B2C9554085EAE6E26FE14A40
40426	5	51	\N	51916	76209	\N	53.763097215272097	Кемеровская область, город Новокузнецк, Центральный район, Тольятти, 39, школа-лицей 62	Россия, Кемеровская область, Новокузнецк, улица Тольятти, 39	0101000020E610000065FD6662BAC855407E569929ADE14A40
40420	5	51	\N	51916	76209	\N	53.748936736316999	Кемеровская область, город Новокузнецк, Центральный район, Тольятти, 3, школа 103	Россия, Кемеровская область, Новокузнецк, улица Тольятти, 3	0101000020E6100000965CC5E237CA5540D6E1E82ADDDF4A40
40409	5	51	\N	51916	76209	\N	53.754641421753497	Кемеровская область, город Новокузнецк, Центральный район, Тольятти, 30а, экологическая школа	Россия, Кемеровская область, Новокузнецк, улица Тольятти, 30а	0101000020E6100000ACC5A70018CA5540419C871398E04A40
40336	5	51	\N	51916	75737	\N	53.909580380147702	Кемеровская область, город Новокузнецк, Заводской район, Строительная, 6	Россия, Кемеровская область, Новокузнецк, Строительная улица, 6	0101000020E61000000AF31E679AD455403F8C101E6DF44A40
40510	5	51	\N	51916	75768	\N	53.761379294161799	Кемеровская область, город Новокузнецк, Куйбышевский район, Спортивная, 11б	Россия, Кемеровская область, Новокузнецк, улица Свердлова	0101000020E6100000C84274081CC955403B6EF8DD74E14A40
40486	5	51	\N	51916	71098	\N	53.751910000000002	Кемеровская область, город Новокузнецк, Куйбышевский район, Сибиряков-Гвардейцев, 16	Россия, Кемеровская область, Новокузнецк, улица Сибиряков-Гвардейцев, 16	0101000020E6100000E55E605628C6554087C43D963EE04A40
40082	5	51	\N	51916	50402	\N	53.739013	Кемеровская область, Киселевский городской округ, Сетевая, 32		0101000020E6100000A4E194B9F9C75540D0285DFA97DE4A40
40428	5	51	\N	51916	76354	\N	53.7596074619508	Кемеровская область, город Новокузнецк, Центральный район, СВЕРДЛОВА, 10, школа 72		0101000020E6100000A873452921C9554006685BCD3AE14A40
40301	5	51	\N	51916	76231	\N	53.904273000000003	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Рокоссовского, 21		0101000020E61000000BEC3191D2C75540F2D3B837BFF34A40
40501	5	51	\N	51916	70614	\N	53.717607999999998	Кемеровская область, город Новокузнецк, Куйбышевский район, Редаково, 104	Россия, Кемеровская область, Новокузнецк, улица Верхне-Редаково, 104	0101000020E6100000501BD5E940C655408AAC3594DADB4A40
40391	5	51	\N	51916	71085	\N	53.785347999999999	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Разведчиков, 46	Россия, Кемеровская область, Новокузнецк, улица Разведчиков, 46	0101000020E61000003944DC9C4AD4554050FD834886E44A40
40387	5	51	\N	51916	71289	\N	53.792634999999997	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Радищева, 24	Россия, Кемеровская область, Новокузнецк, улица Радищева, 24	0101000020E6100000A10F96B1A1D555401D554D1075E54A40
40381	5	51	\N	51916	71474	\N	53.799208999999998	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Пушкина, 26	Россия, Кемеровская область, Новокузнецк, улица Пушкина, 26	0101000020E61000004F1F813FFCD755409DD5027B4CE64A40
40497	5	51	\N	51916	71100	\N	53.734532999999999	Кемеровская область, город Новокузнецк, Куйбышевский район, Пролетарская, 81	Россия, Кемеровская область, Новокузнецк, Пролетарская улица, 81	0101000020E6100000315C1D0071C75540986A662D05DE4A40
40690	5	51	\N	51916	28704	\N	53.764499000000001	Кемеровская область, Прокопьевский городской округ, Зенковский район, Забутовочная, 1	Россия, Кемеровская область, Новокузнецк, Прокопьевский переулок, 1	0101000020E6100000725303CDE7CC554090696D1ADBE14A40
40677	5	51	\N	51916	28704	\N	53.764355999999999	653048, Кемеровская область, Прокопьевский городской округ, Зенковский район, Черных, 3	Россия, Кемеровская область, Новокузнецк, Прокопьевский переулок, 3	0101000020E6100000D8800871E5CC55402D40DB6AD6E14A40
40665	5	51	\N	51916	28704	\N	53.764355999999999	Кемеровская область, Прокопьевский городской округ, Зенковский район, Слуцкая, 3	Россия, Кемеровская область, Новокузнецк, Прокопьевский переулок, 3	0101000020E6100000D8800871E5CC55402D40DB6AD6E14A40
40620	5	51	\N	51916	28704	\N	53.763829000000001	Кемеровская область, Прокопьевский городской округ, Центральный район, Планерная, 21	Россия, Кемеровская область, Новокузнецк, Прокопьевский переулок, 21	0101000020E6100000821FD5B0DFCC5540425E0F26C5E14A40
40425	5	51	\N	51916	76220	\N	53.766856628585899	Кемеровская область, город Новокузнецк, Центральный район, Покрышкина, 18, школа 97	Россия, Кемеровская область, Новокузнецк, улица Покрышкина, 18	0101000020E61000006EC1525DC0C75540B6DAC35E28E24A40
40449	5	51	\N	51916	76348	\N	53.760077520849997	Кемеровская область, город Новокузнецк, Центральный район, Пионерский, 36, школа 26		0101000020E6100000FC7266BB42C855405D34643C4AE14A40
40436	5	51	\N	51916	76348	\N	53.7610686801303	Кемеровская область, город Новокузнецк, Центральный район, Пионерский, 9, школа-интернат 38		0101000020E610000081053065E0C65540ED7F80B56AE14A40
40437	5	51	\N	51916	76370	\N	53.761087553450302	Кемеровская область, город Новокузнецк, Центральный район, Пионерский, 13 КУЗГПА	Россия, Кемеровская область, Новокузнецк, Пионерский проспект, 13	0101000020E6100000D0ECBAB722C7554064B0E2546BE14A40
40424	5	51	\N	51916	76334	\N	53.763804030653397	Кемеровская область, город Новокузнецк, Центральный район, Орджоникидзе, 23, Городской дворец культуры	Россия, Кемеровская область, Новокузнецк, улица Орджоникидзе, 23	0101000020E6100000E202D0285DC75540E9465854C4E14A40
40310	5	51	\N	51916	76389	\N	53.894579999999998	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Олимпийская, 17		0101000020E61000006B2A8BC22EC75540EDD3F19881F24A40
40448	5	51	\N	51916	76340	\N	53.749200045095101	Кемеровская область, город Новокузнецк, Центральный район, Октябрьский, 24а , школа №31		0101000020E6100000F20C1AFA27C95540E4141DC9E5DF4A40
40370	5	51	\N	51916	70594	\N	53.775058000000001	Кемеровская область, город Новокузнецк, Кузнецкий район, Обнорского, 92	Россия, Кемеровская область, Новокузнецк, улица Обнорского, 92	0101000020E6100000552E54FEB5CD55406840BD1935E34A40
40000	5	51	\N	2895	71589	\N	55.342038000000002	город Кемерово, Тухачевского, 10		0101000020E6100000EB0088BB7A885540A0FEB3E6C7AB4B40
40305	5	51	\N	51916	76384	\N	53.897955000000003	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Новоселов, 53		0101000020E61000004F232D95B7C85540CD237F30F0F24A40
40298	5	51	\N	51916	76384	\N	53.895465999999999	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Новоселов, 19		0101000020E610000082FFAD64C7C75540085740A19EF24A40
40398	5	51	\N	51916	28889	\N	53.765951817869102	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Новогодняя, 15а	Россия, Кемеровская область, Новокузнецк, Новогодняя улица	0101000020E610000002637D0393D25540242713B70AE24A40
40403	5	51	\N	51916	71294	\N	53.784480000000002	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Новобайдаевская, 9	Россия, Кемеровская область, Новокузнецк, Новобайдаевская улица, 9	0101000020E6100000187B2FBE68D25540DC2E34D769E44A40
40374	5	51	\N	51916	71070	\N	53.771258000000003	Кемеровская область, город Новокузнецк, Кузнецкий район, Народная, 31	Россия, Кемеровская область, Новокузнецк, Народная улица, 31	0101000020E6100000D7FB8D76DCCC5540A2630795B8E24A40
40372	5	51	\N	51916	71070	\N	53.770896	Кемеровская область, город Новокузнецк, Кузнецкий район, Народная, 27	Россия, Кемеровская область, Новокузнецк, Народная улица, 27	0101000020E610000016DEE522BECC5540014F5AB8ACE24A40
40393	5	51	\N	51916	70606	\N	53.789672000000003	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Мурманская, 54	Россия, Кемеровская область, Новокузнецк, Мурманская улица, 54	0101000020E6100000D1967329AED355409148DBF813E54A40
40392	5	51	\N	51916	70606	\N	53.781835999999998	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Мурманская, 24	Россия, Кемеровская область, Новокузнецк, Мурманская улица, 24	0101000020E6100000F06E6589CED35540F06AB93313E44A40
40390	5	51	\N	51916	70439	\N	53.788694	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Монтажная, 35	Россия, Кемеровская область, Новокузнецк, Монтажная улица, 35	0101000020E61000008B8862F206D655409546CCECF3E44A40
40489	5	51	\N	51916	70492	\N	53.754151	Кемеровская область, город Новокузнецк, Куйбышевский район, Мичурина, 4а		0101000020E610000040A54A94BDC65540739F1C0588E04A40
40379	5	51	\N	51916	70600	\N	53.804122	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Маркшейдерская, 12	Россия, Кемеровская область, Новокузнецк, Маркшейдерская улица, 12	0101000020E6100000B2BD16F4DED755403FFF3D78EDE64A40
40689	5	51	\N	51916	71519	\N	53.770448999999999	Кемеровская область, Прокопьевский городской округ, Зенковский район, Луначарского, 9	Россия, Кемеровская область, Новокузнецк, улица Луначарского, 10	0101000020E6100000D11E2FA4C3CB5540321EA5129EE24A40
40502	5	51	\N	51916	75681	\N	53.703241386442599	654000, Кемеровская область, Новокузнецкий городской округ, Куйбышевский район, Литейная, 112	Россия, Кемеровская область, Новокузнецк, Литейная улица	0101000020E6100000357D76C075C65540691A14CD03DA4A40
40479	5	51	\N	51916	71096	\N	53.742106999999997	Кемеровская область, город Новокузнецк, Куйбышевский район, Лесная, 1		0101000020E61000001F477364E5C25540FB90B75CFDDE4A40
40366	5	51	\N	51916	71057	\N	53.785049999999998	Кемеровская область, город Новокузнецк, Кузнецкий район, Ленина, 119	Россия, Кемеровская область, Новокузнецк, улица Ленина, 119	0101000020E6100000C03DCF9F36CE5540C6DCB5847CE44A40
40365	5	51	\N	51916	71057	\N	53.781633999999997	Кемеровская область, город Новокузнецк, Кузнецкий район, Ленина, 78	Россия, Кемеровская область, Новокузнецк, улица Ленина, 78	0101000020E6100000A7AE7C96E7CD554088B839950CE44A40
40364	5	51	\N	51916	71057	\N	53.778931	Кемеровская область, город Новокузнецк, Кузнецкий район, Ленина, 61	Россия, Кемеровская область, Новокузнецк, улица Ленина, 61	0101000020E61000003FFED2A23ECD5540986BD102B4E34A40
40363	5	51	\N	51916	71057	\N	53.776148999999997	Кемеровская область, город Новокузнецк, Кузнецкий район, Ленина, 41		0101000020E610000090831266DACC55405BE9B5D958E34A40
40367	5	51	\N	51916	70367	\N	53.793052878286097	Кемеровская область, город Новокузнецк, Кузнецкий район, Левитана, 1		0101000020E61000003BC43F6CE9CE5540527FBDC282E54A40
40319	5	51	\N	51916	70364	\N	53.799022999999998	Кемеровская область, город Новокузнецк, Заводской район, Ладожская, 110	Россия, Кемеровская область, Новокузнецк, Ладожская улица, 110	0101000020E6100000193A765089C955403BE0BA6246E64A40
40660	5	51	\N	51916	75608	\N	53.786501999999999	Кемеровская область, Новокузнецкий городской округ, Заводской район, Кучина, 9	Россия, Кемеровская область, Новокузнецк, Курская улица	0101000020E61000003ECBF3E0EEC955408A1EF818ACE44A40
40505	5	51	\N	51916	71102	\N	53.742932000000003	Кемеровская область, город Новокузнецк, Куйбышевский район, Кутузова, 84	Россия, Кемеровская область, Новокузнецк, улица Кутузова, 84	0101000020E61000007102D369DDC855407193516518DF4A40
40454	5	51	\N	51916	71102	\N	53.751421013501599	Кемеровская область, город Новокузнецк, Центральный район, КУТУЗОВА, 12, фак-т ин.яз		0101000020E61000002C8194D8B5C75540894336902EE04A40
40446	5	51	\N	51916	71102	\N	53.751281417789698	Кемеровская область, город Новокузнецк, Центральный район, Кутузова, 4, школа 31	Россия, Кемеровская область, Новокузнецк, улица Кутузова, 4	0101000020E610000081785DBF60C75540978DCEF929E04A40
40378	5	51	\N	51916	75760	\N	53.8060121771246	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Кустарная, 47		0101000020E61000008EAD6708C7D855407F17B6662BE74A40
40492	5	51	\N	51916	70289	\N	53.757610999999997	Кемеровская область, город Новокузнецк, Куйбышевский район, Куйбышева, 4	Россия, Кемеровская область, Новокузнецк, улица Куйбышева, 4	0101000020E610000066A032FE7DC65540800BB265F9E04A40
40511	5	51	\N	51916	70286	\N	53.677166999999997	Кемеровская область, город Новокузнецк, Куйбышевский район, Кубинская, 23а	Россия, Кемеровская область, Новокузнецк, Кубинская улица, 23а	0101000020E61000004C8E3BA583BD554018778368ADD64A40
40396	5	51	\N	51916	70587	\N	53.793821000000001	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Крупской, 35		0101000020E6100000562AA8A8FAD1554063F030ED9BE54A40
40122	5	51	\N	51916	50455	\N	53.739390999999998	Кемеровская область, Киселевский городской округ, Красина, 1		0101000020E6100000C9224DBC03C8554076FA415DA4DE4A40
40307	5	51	\N	51916	76382	\N	53.894798000000002	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Косыгина, 73		0101000020E6100000111E6D1CB1C855405B43A9BD88F24A40
40297	5	51	\N	51916	76382	\N	53.892628000000002	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Косыгина, 49		0101000020E6100000DDCF29C8CFC7554038BF61A241F24A40
39846	5	51	\N	51916	70535	\N	53.786501999999999	Кемеровская область, город Новокузнецк, Заводской район, Коммунистическая, 14	Россия, Кемеровская область, Новокузнецк, Курская улица	0101000020E61000003ECBF3E0EEC955408A1EF818ACE44A40
40325	5	51	\N	51916	70420	\N	53.827385	Кемеровская область, город Новокузнецк, Заводской район, Клименко, 7а	Россия, Кемеровская область, Новокузнецк, улица Клименко, 7а	0101000020E6100000E44D7E8B4ECA5540B9196EC0E7E94A40
40324	5	51	\N	51916	70420	\N	53.823197	Кемеровская область, город Новокузнецк, Заводской район, Клименко, 36а	Россия, Кемеровская область, Новокузнецк, улица Клименко, 36а	0101000020E61000004BADF71BEDC955402995F0845EE94A40
40332	5	51	\N	51916	71023	\N	53.837385304239803	Кемеровская область, город Новокузнецк, Заводской район, Климасенко, 12/3	Россия, Кемеровская область, Новокузнецк, улица Климасенко, 12к3	0101000020E6100000CCEEC9C342CB55409A94826E2FEB4A40
40331	5	51	\N	51916	71023	\N	53.838431999999997	Кемеровская область, город Новокузнецк, Заводской район, Климасенко, 20/1	Россия, Кемеровская область, Новокузнецк, улица Климасенко, 20к1	0101000020E61000008028983105CB5540BEF561BD51EB4A40
40318	5	51	\N	51916	71023	\N	53.836993	Кемеровская область, город Новокузнецк, Заводской район, Климасенко, 1/2	Россия, Кемеровская область, Новокузнецк, улица Климасенко, 1к2	0101000020E6100000A5129ED0EBCB55408FFD2C9622EB4A40
40316	5	51	\N	51916	71023	\N	53.841778886897401	Кемеровская область, город Новокузнецк, Заводской район, Климасенко, 11/5		0101000020E6100000CBD93BA3ADCB5540D4BA0D6ABFEB4A40
40314	5	51	\N	51916	71023	\N	53.841417999999997	Кемеровская область, город Новокузнецк, Заводской район, Климасенко, 21/5	Россия, Кемеровская область, Новокузнецк, улица Климасенко, 21к5	0101000020E6100000876EF607CACA55400322C495B3EB4A40
40312	5	51	\N	51916	71023	\N	53.8387021189059	Кемеровская область, город Новокузнецк, Заводской район, Климасенко, 25а		0101000020E610000030A182C30BCB55407E8B4E965AEB4A40
40137	5	51	\N	51916	28701	\N	53.738970000000002	Кемеровская область, Киселевский городской округ, Прогрессивная, 9	Россия, Кемеровская область, Новокузнецк, Киселевский переулок, 9	0101000020E610000075C8CD7003C85540D15CA79196DE4A40
40123	5	51	\N	51916	28701	\N	53.739193999999998	Кемеровская область, Киселевский городской округ, Больничная, 5	Россия, Кемеровская область, Новокузнецк, Киселевский переулок, 5	0101000020E6100000DCF5D21401C8554020B3B3E89DDE4A40
40096	5	51	\N	51916	28701	\N	53.739646	Кемеровская область, Киселевский городской округ, Ставропольская, 6	Россия, Кемеровская область, Новокузнецк, Киселевский переулок, 6	0101000020E6100000E2E6543200C85540014F5AB8ACDE4A40
40079	5	51	\N	51916	28701	\N	53.738475000000001	Кемеровская область, Киселевский городской округ, Казанская, 17	Россия, Кемеровская область, Новокузнецк, Киселевский переулок, 17	0101000020E61000001AFB928D07C85540F1F44A5986DE4A40
40078	5	51	7401	\N	28701	\N	54.000325413547301	Кемеровская область, Киселевский городской округ, 1 Мая, 19	Россия, Кемеровская область, городской округ Киселевск	0101000020E61000008D2AC3B81BAA5540832F4CA60A004B40
41456	5	51	\N	51916	71522	\N	53.758208000000003	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Кирова, д. 13 (МКК)	Россия, Кемеровская область, Новокузнецк, улица Кирова, 13	0101000020E61000002864E76D6CC7554065C8B1F50CE14A40
40408	5	51	\N	51916	71522	\N	53.760565999999997	Кемеровская область, город Новокузнецк, Центральный район, Кирова, 79а, гимназия 44		0101000020E6100000BB80971936CA55408A39083A5AE14A40
39770	5	51	\N	51916	71522	\N	53.758868	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Кирова, 41	Россия, Кемеровская область, Новокузнецк, улица Кирова, 41	0101000020E61000004BE9995E62C855408FFD2C9622E14A40
40452	5	51	\N	51916	76344	\N	53.757139764690002	Кемеровская область, город Новокузнецк, Центральный район, Кирова, 42, СибГИУ	Россия, Кемеровская область, Новокузнецк, улица Кирова, 42	0101000020E610000059C2DA183BC85540293FA9F6E9E04A40
40483	5	51	\N	51916	28940	\N	53.742224	654000, Кемеровская область, Новокузнецкий городской округ, Куйбышевский район, Кирзаводская, 4/10	Россия, Кемеровская область, Новокузнецк, Кирзаводская улица, 4/10	0101000020E61000007CD6355A0EC5554035272F3201DF4A40
40377	5	51	\N	51916	28885	\N	53.806131999999998	Кемеровская область, город Новокузнецк, Орджоникидзевский район, пер. Кедровый, 5	Россия, Кемеровская область, Новокузнецк, Кедровый переулок, 5	0101000020E6100000F0BF95ECD8D75540292158552FE74A40
40070	5	51	\N	2895	50378	\N	55.350754999999999	Кемеровская область, Киселевский городской округ, Томская, 20		0101000020E61000008F5033A48A85554049F4328AE5AC4B40
40471	5	51	\N	51916	70612	\N	53.748373999999998	Кемеровская область, город Новокузнецк, Куйбышевский район, Карла Маркса, 5	Россия, Кемеровская область, Новокузнецк, улица Карла Маркса, 5	0101000020E6100000B24CBF44BCC355409E961FB8CADF4A40
40469	5	51	\N	51916	70612	\N	53.749454999999998	Кемеровская область, город Новокузнецк, Куйбышевский район, Карла Маркса, 10	Россия, Кемеровская область, Новокузнецк, улица Карла Маркса, 10	0101000020E6100000F2D3B837BFC355406E693524EEDF4A40
40376	5	51	\N	51916	75677	\N	53.815389000000003	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Кавказская, 5		0101000020E61000005EDBDB2DC9D755405342B0AA5EE84A40
40337	5	51	\N	51916	70280	\N	53.832811	Кемеровская область, город Новокузнецк, Заводской район, пр. Ижевский, 14	Россия, Кемеровская область, Новокузнецк, Ижевский проезд, 14	0101000020E6100000EE3F321D3ACC5540E15F048D99EA4A40
40389	5	51	\N	51916	70602	\N	53.789746999999998	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Зыряновская, 99	Россия, Кемеровская область, Новокузнецк, Зыряновская улица, 99	0101000020E6100000070B2769FED555409B8E006E16E54A40
40402	5	51	\N	51916	71291	\N	53.784581000000003	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Зорге, 36	Россия, Кемеровская область, Новокузнецк, улица Зорге, 36	0101000020E6100000098CF50D4CD25540100874266DE44A40
40628	5	51	\N	51916	71719	\N	53.737744999999997	Кемеровская область, Прокопьевский городской округ, Центральный район, Западная, 5	Россия, Кемеровская область, Новокузнецк, Западная улица, 3	0101000020E6100000D2510E6613C45540CDE49B6D6EDE4A40
40463	5	51	\N	51916	71298	\N	53.743245999999999	Кемеровская область, город Новокузнецк, Куйбышевский район, Жасминная, 8	Россия, Кемеровская область, Новокузнецк, Жасминная улица, 8	0101000020E6100000D74B530438C25540007157AF22DF4A40
40383	5	51	\N	51916	70515	\N	53.793747000000003	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Емельяновская, 1	Россия, Кемеровская область, Новокузнецк, Емельяновская улица, 1	0101000020E6100000BDA60705A5D6554029266F8099E54A40
40385	5	51	\N	51916	71475	\N	53.795352999999999	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Дузенко, 14а	Россия, Кемеровская область, Новокузнецк, улица Дузенко, 14а	0101000020E6100000793D98141FD6554043E38920CEE54A40
40394	5	51	\N	51916	71473	\N	53.747331000000003	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Дорстроевская, 5а	Россия, Кемеровская область, Новокузнецк, Дорстроевская улица, 5а	0101000020E61000005FB7088CF5D35540BC24CE8AA8DF4A40
40434	5	51	\N	51916	76276	\N	53.783235876150798	Кемеровская область, город Новокузнецк, Центральный район, ул. ДОЗ, 17, Новок. уч-курсовой комб. а/тран		0101000020E6100000174A26A776C855406286C61341E44A40
40422	5	51	\N	51916	76235	\N	53.751500299684203	Кемеровская область, город Новокузнецк, Центральный район, грдины, 6, школа 55	Россия, Кемеровская область, Новокузнецк, улица Грдины, 6	0101000020E610000072A8DF85ADCA5540D578E92631E04A40
40414	5	51	\N	51916	76235	\N	53.751691000000001	Кемеровская область, город Новокузнецк, Центральный район, Грдины, 6, школа 55		0101000020E610000080D8D2A3A9CA554049D9226937E04A40
40411	5	51	\N	51916	76235	\N	53.753989789469699	Кемеровская область, город Новокузнецк, Центральный район, Грдины, 20, гимназия 48		0101000020E61000000F643DB5FACA55406AC18BBE82E04A40
40405	5	51	\N	51916	76235	\N	53.753888054834697	Кемеровская область, город Новокузнецк, Центральный район, Грдины, 20	Россия, Кемеровская область, Новокузнецк, улица Грдины, 20	0101000020E61000001407D0EFFBCA5540666CE8667FE04A40
40351	5	51	\N	51916	70430	\N	53.825386999999999	Кемеровская область, город Новокузнецк, Заводской район, Горьковская, 33	Россия, Кемеровская область, Новокузнецк, Горьковская улица, 33	0101000020E61000008F8D40BCAECB554093C5FD47A6E94A40
40346	5	51	\N	51916	70430	\N	53.828569999999999	Кемеровская область, город Новокузнецк, Заводской район, Горьковская, 27а	Россия, Кемеровская область, Новокузнецк, Горьковская улица, 27а	0101000020E61000003465A71FD4CB55402E39EE940EEA4A40
40345	5	51	\N	51916	70430	\N	53.830919000000002	Кемеровская область, город Новокузнецк, Заводской район, Горьковская, 17	Россия, Кемеровская область, Новокузнецк, Горьковская улица, 17	0101000020E61000007C0DC17119CC55400150C58D5BEA4A40
40342	5	51	\N	51916	70430	\N	53.831513999999999	Кемеровская область, город Новокузнецк, Заводской район, Горьковская, 15	Россия, Кемеровская область, Новокузнецк, Горьковская улица, 15	0101000020E61000003106D671FCCB55404415FE0C6FEA4A40
40464	5	51	\N	51916	71088	\N	53.747915999999996	Кемеровская область, город Новокузнецк, Куйбышевский район, Горноспасательная, 5	Россия, Кемеровская область, Новокузнецк, Горноспасательная улица, 5	0101000020E6100000F46C567DAEC25540DB1324B6BBDF4A40
40626	5	51	\N	51916	71560	\N	53.734650999999999	Кемеровская область, Прокопьевский городской округ, Центральный район, Волховская, 18		0101000020E610000076FA415DA4C75540A27C410B09DE4A40
40661	5	51	\N	51916	71638	\N	53.712502999999998	Кемеровская область, Прокопьевский городской округ, Зенковский район, Волжская, 11	Россия, Кемеровская область, Новокузнецк, Волжская улица, 11	0101000020E6100000252026E142C85540A4A65D4C33DB4A40
40496	5	51	\N	51916	70495	\N	53.740434999999998	654000, Кемеровская область, Новокузнецкий городской округ, Куйбышевский район, Вокзальная, 103		0101000020E6100000744694F606C8554029E8F692C6DE4A40
40494	5	51	\N	51916	70495	\N	53.744875999999998	Кемеровская область, город Новокузнецк, Куйбышевский район, Вокзальная, 29	Россия, Кемеровская область, Новокузнецк, Вокзальная улица, 29	0101000020E6100000234DBC033CC75540A3C9C51858DF4A40
40508	5	51	\N	51916	75772	\N	53.7596054752157	Кемеровская область, город Новокузнецк, Куйбышевский район, Водосточная, 1а	Россия, Кемеровская область, Новокузнецк, улица Хитарова	0101000020E61000009AEC9FA701C75540657094BC3AE14A40
40472	5	51	\N	51916	71092	\N	53.746989999999997	Кемеровская область, город Новокузнецк, Куйбышевский район, Веры Соломиной, 12	Россия, Кемеровская область, Новокузнецк, улица Веры Соломиной, 12	0101000020E61000008335CEA623C3554032384A5E9DDF4A40
40503	5	51	\N	51916	71229	\N	53.7146019816117	654000, Кемеровская область, Новокузнецкий городской округ, Куйбышевский район, Варшавская, 2	Россия, Кемеровская область, Новокузнецк, Варшавская улица, 2	0101000020E6100000E564E25641C85540FED30D1478DB4A40
40368	5	51	\N	51916	70591	\N	53.778787999999999	Кемеровская область, город Новокузнецк, Кузнецкий район, Бугарева, 17	Россия, Кемеровская область, Новокузнецк, улица Бугарева, 17	0101000020E6100000C63368E89FCD554035423F53AFE34A40
39661	5	51	\N	51916	28797	\N	53.792240999999997	Кемеровская область, Беловский городской округ, Козлова, 2	Россия, Кемеровская область, Новокузнецк, Беловский проезд, 2	0101000020E61000007CF31B261ACA554071C6302768E54A40
40507	5	51	\N	51916	70626	\N	53.743884999999999	Кемеровская область, город Новокузнецк, Куйбышевский район, Батюшкова, 16а	Россия, Кемеровская область, Новокузнецк, улица Батюшкова, 16а	0101000020E6100000309C6B98A1C95540137EA99F37DF4A40
40506	5	51	\N	51916	70626	\N	53.743380000000002	Кемеровская область, город Новокузнецк, Куйбышевский район, Батюшкова, 3	Россия, Кемеровская область, Новокузнецк, улица Батюшкова, 3	0101000020E610000029780AB952C9554010406A1327DF4A40
40624	5	51	\N	51916	71607	\N	53.712097999999997	Кемеровская область, Прокопьевский городской округ, Центральный район, Акмолинская, 15	Россия, Кемеровская область, Новокузнецк, Акмолинская улица, 17	0101000020E6100000B80721205FC8554004C6FA0626DB4A40
40515	5	51	\N	51916	76353	\N	53.829304	" Новокузнецкий городской округ, Орджоникидзевский район, ул. Автодорожная (здание магазина ООО ""Щербина""), д. 91"		0101000020E610000065FCFB8C0BD8554093382BA226EA4A40
40101	5	51	\N	51916	50403	\N	53.739013	Кемеровская область, Киселевский городской округ, 50 лет городу, 34		0101000020E6100000A4E194B9F9C75540D0285DFA97DE4A40
40401	5	51	\N	51916	70772	\N	53.777351000000003	Кемеровская область, город Новокузнецк, Орджоникидзевский район, 40 лет Победы, 9	Россия, Кемеровская область, Новокузнецк, улица 40 лет Победы, 9	0101000020E610000043AA285E65D25540A741D13C80E34A40
40400	5	51	\N	51916	70772	\N	53.777324	Кемеровская область, город Новокузнецк, Орджоникидзевский район, 40 лет Победы, 17	Россия, Кемеровская область, Новокузнецк, улица 40 лет Победы, 17	0101000020E6100000CD3B4ED191D25540AD32535A7FE34A40
40328	5	51	\N	51916	70574	\N	53.828080999999997	Кемеровская область, город Новокузнецк, Заводской район, 40 лет ВЛКСМ, 52а	Россия, Кемеровская область, Новокузнецк, улица 40 лет ВЛКСМ, 52а	0101000020E6100000CD94D6DF12CB554030B8E68EFEE94A40
40326	5	51	\N	51916	70574	\N	53.823250000000002	Кемеровская область, город Новокузнецк, Заводской район, 40 лет ВЛКСМ, 98а	Россия, Кемеровская область, Новокузнецк, улица 40 лет ВЛКСМ, 98а	0101000020E6100000AB07CC43A6CA55404C37894160E94A40
40323	5	51	\N	51916	70574	\N	53.818263999999999	Кемеровская область, город Новокузнецк, Заводской район, 40 лет ВЛКСМ, 112	Россия, Кемеровская область, Новокузнецк, улица 40 лет ВЛКСМ, 112	0101000020E61000006BD5AE0969CA554040BFEFDFBCE84A40
40320	5	51	\N	51916	70574	\N	53.817169	Кемеровская область, город Новокузнецк, Заводской район, 40 лет ВЛКСМ, 112а	Россия, Кемеровская область, Новокузнецк, улица 40 лет ВЛКСМ, 112а	0101000020E61000008B87F71C58CA55400B2769FE98E84A40
39676	5	51	\N	51916	50400	\N	53.791092999999996	Кемеровская область, Беловский городской округ, 3 микрорайон, 34		0101000020E61000008753E6E61BCA5540198C118942E54A40
40438	5	51	\N	51916	76236	\N	53.7728262991101	Кемеровская область, город Новокузнецк, Центральный район, Филиппова, 10, школа №2	Россия, Кемеровская область, Новокузнецк, улица Филиппова, 10	0101000020E61000000B0E2F8848C85540CFBF5DF6EBE24A40
39662	5	51	890	\N	50369	\N	54.389465999999999	Кемеровская область, Беловский городской округ, Октябрьская, 12	Россия, Кемеровская область, Беловский район	0101000020E610000017D34CF73AAC5540B4739A05DA314B40
40918	5	51	\N	4775	75991	\N	55.303641578761301	Кемеровская область, Кемеровский район, п.Новоискитимск, Новая, 2	Россия, Кемеровская область, поселок Новоискитимск	0101000020E6100000022A1C412A83554095D8B5BDDDA64B40
40284	5	51	\N	41081	12914	\N	53.708233322679099	652840, Кемеровская область, Мысковский городской округ, квартал 7, (ДК "Юбилейный", танц.зал), д.1	Россия, Кемеровская область, Мыски	0101000020E610000061889CBE9EF2554057790261A7DA4A40
40283	5	51	\N	41081	12914	\N	53.718290000000003	652840, Кемеровская область, Мысковский городской округ, квартал 7, (ДК "Юбилейный", спорт.зал), д.1	Россия, Кемеровская область, Мыски	0101000020E6100000D525E318C9F155409D853DEDF0DB4A40
40279	5	51	\N	41081	12968	\N	53.7090480813224	652840, Кемеровская область, Мысковский городской округ, бульвар Юбилейный, (школа №4), д.4а	Россия, Кемеровская область, Мыски	0101000020E61000009CF9D51C20F35540A9A5B915C2DA4A40
40296	5	51	\N	41081	76386	\N	53.711184857757601	652840, Кемеровская область, Мысковский городской округ, ул. Энергетиков, (школа №7), д.15	Россия, Кемеровская область, Мыски	0101000020E610000036ACA92C0AF35540F0332E1C08DB4A40
40292	5	51	\N	41081	76372	\N	53.718822059409	652840, Кемеровская область, Мысковский городской округ, ул. Энергетиков, (ТУ ГЭТК), д.4	Россия, Кемеровская область, Мыски	0101000020E6100000D200DE0209F255409AD2FA5B02DC4A40
40295	5	51	\N	41081	76366	\N	53.709822743754103	652840, Кемеровская область, Мысковский городской округ, ул. Центральная, (школа №3), д.4	Россия, Кемеровская область, Мыски	0101000020E610000019C91EA166F355406C79E57ADBDA4A40
40275	5	51	\N	41081	76252	\N	53.717301094513701	652840, Кемеровская область, Мысковский городской округ, ул. Рембазовская, (СОК "Олимп"), д.1	Россия, Кемеровская область, Мыски	0101000020E610000070B0373124F35540AD31E884D0DB4A40
40277	5	51	\N	41081	76311	\N	53.718111202137202	652840, Кемеровская область, Мысковский городской округ, ул. Первомайская, (ГЦК), д.15	Россия, Кемеровская область, Мыски	0101000020E610000067B62BF4C1F15540EDF2AD0FEBDB4A40
40280	5	51	\N	41081	76301	\N	53.718290000000003	"Мысковский городской округ, ул. Первомайская, (Спортивный клуб ""Меркурий""), д. 33"	Россия, Кемеровская область, Мыски	0101000020E6100000D525E318C9F155409D853DEDF0DB4A40
40278	5	51	\N	41081	76301	\N	53.718290000000003	652840, Кемеровская область, Мысковский городской округ, ул. Первомайская, (ЦДО), д.35	Россия, Кемеровская область, Мыски	0101000020E6100000D525E318C9F155409D853DEDF0DB4A40
40271	5	51	\N	41081	76358	\N	53.710115538353101	652840, Кемеровская область, Мысковский городской округ, ул. Панфилова, (школа №6), д. 4а	Россия, Кемеровская область, Мыски	0101000020E610000010CCD1E3F7F25540E42EC214E5DA4A40
40273	5	51	\N	41081	12389	\N	53.707998499771001	652840, Кемеровская область, Мысковский городской округ, ул. Олимпийская, (ООО "Водоканал"), д.1	Россия, Кемеровская область, Мыски	0101000020E6100000FD4D2844C0F2554014D1AFAD9FDA4A40
40294	5	51	\N	41081	76364	\N	53.715818259640798	652840, Кемеровская область, Мысковский городской округ, ул. Ленина, (ДК им. Горького), д.8а		0101000020E61000004E7CB5A338F25540AEF199EC9FDB4A40
40293	5	51	\N	41081	76364	\N	53.709097113532899	652840, Кемеровская область, Мысковский городской округ, ул. Ленина, (ДК им. Горького, малый зал), д.8А	Россия, Кемеровская область, Мыски	0101000020E61000006D57E88365F455408A58C4B0C3DA4A40
40287	5	51	\N	41081	76286	\N	53.7099118553705	652840, Кемеровская область, Мысковский городской округ, ул. Левологовая, (ЗАО "ТУ ЗЖБК"), д.1	Россия, Кемеровская область, Мыски	0101000020E61000000DFCA886FDF25540DC847B65DEDA4A40
40286	5	51	\N	41081	12946	\N	53.7094554546997	652840, Кемеровская область, Мысковский городской округ, ул. 50 лет пионерии, (школа №2), д.14	Россия, Кемеровская область, Мыски	0101000020E610000060730E9E09F35540E97DE36BCFDA4A40
40290	5	51	\N	41081	76246	\N	53.719403742279503	652840, Кемеровская область, Мысковский городской округ, 17 квартал, (школа №5), д.24	Россия, Кемеровская область, Мыски	0101000020E61000005F0839EFFFF15540484E266E15DC4A40
40905	5	51	\N	2899	75849	\N	55.422379999999997	Кемеровская область, Кемеровский район, д.Мозжуха, Школьная, 1	Россия, Кемеровская область, деревня Мозжуха	0101000020E61000008750A5660F7B5540033E3F8C10B64B40
41100	5	51	\N	59411	75774	\N	53.897655735416798	п.Металлургов, Рабочая, 43	Россия, Кемеровская область, поселок Металлургов, Рабочая улица, 43	0101000020E61000005FCE6C57E8C1554072874D64E6F24A40
41099	5	51	\N	59411	71401	\N	53.898479999999999	п.Металлургов, Молодежная, 7	Россия, Кемеровская область, поселок Металлургов, Молодежная улица, 7	0101000020E61000002F151BF33AC25540170E846401F34A40
39693	5	51	\N	2673	50393	\N	55.323079999999997	Кемеровская область, Беловский городской округ, мкрн Чертинский, Южная, 5А		0101000020E6100000200A664CC18C5540EFFE78AF5AA94B40
39671	5	51	\N	2673	1590	\N	55.310380000000002	Кемеровская область, Беловский городской округ, Советская, 41		0101000020E610000081EB8A19E18C55408FAA2688BAA74B40
39672	5	51	\N	2673	50370	\N	55.310380000000002	Кемеровская область, Беловский городской округ, Советская, 44		0101000020E610000081EB8A19E18C55408FAA2688BAA74B40
40907	5	51	\N	2673	71179	\N	55.313214000000002	Кемеровская область, Кемеровский район, п.Металлплощадка, Зеленая, 4-А	Россия, Кемеровская область, поселок Металлплощадка, Зеленая улица, 4	0101000020E6100000FF2268CC248D55401E53776517A84B40
40249	5	51	\N	60703	\N	\N	53.693356999999999	Кемеровская область, город Междуреченск, пос.Улус, бывшая школа		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40242	5	51	\N	60703	\N	\N	53.683985210352198	Кемеровская область, город Междуреченск, Ортонский сельсовет, школа №16 ОРТОН	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E6100000459F8F32E20456402FFA0AD28CD74A40
40241	5	51	\N	60703	75987	\N	53.693356999999999	Кемеровская область, город Междуреченск, ЛЕСОРУБОВ, 9		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40259	5	51	\N	60703	75593	\N	53.691245297276403	Кемеровская область, город Междуреченск - Междуреченский район, ул.Кузнецкая, 51	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E6100000821B295B24045640034356B77AD84A40
40109	5	51	\N	26262	50563	\N	53.9887680378732	Кемеровская область, Киселевский городской округ, Строителей, 10	Россия, Кемеровская область, Киселевск	0101000020E6100000187B2FBE68AA554069AA27F38FFE4A40
40081	5	51	\N	26262	50033	\N	54.006967000000003	652700, Кемеровская область, Киселевский городской округ, город Киселевск, Ярославского, 2а		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40063	5	51	\N	26262	12762	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Юргинская, 1	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40098	5	51	\N	26262	12984	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Чумова, 2а	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40092	5	51	\N	26262	12984	\N	53.999511887820098	Кемеровская область, Киселевский городской округ, Чумова, 25	Россия, Кемеровская область, Киселевск	0101000020E6100000E9EE3A1BF2A85540D3FA5B02F0FF4A40
40080	5	51	\N	26262	50579	\N	54.005672142778302	Кемеровская область, Киселевский городской округ, Черных, 17а	Россия, Кемеровская область, Киселевск	0101000020E61000004A6249B9FBA855405F402FDCB9004B40
40131	5	51	\N	26262	50621	\N	54.010773705148402	Кемеровская область, Киселевский городской округ, Цветочный переулок, 4а	Россия, Кемеровская область, Киселевск	0101000020E61000004390831266A85540D4D2DC0A61014B40
40083	5	51	\N	26262	75642	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Хмельницкого, 10		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40042	5	51	\N	26262	50653	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Фадеева, 2	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40087	5	51	\N	26262	50619	\N	54.006495224970202	Кемеровская область, Киселевский городской округ, Ускатная, 6а	Россия, Кемеровская область, Киселевск	0101000020E6100000847EA65EB7AC5540344B02D4D4004B40
40119	5	51	\N	26262	50105	\N	54.006967000000003	652700, Кемеровская область, Киселевский городской округ, город Киселевск, Строителей проезд, 5		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40125	5	51	\N	26262	75622	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Садовая, 5	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40140	5	51	\N	26262	50570	\N	53.999794455747498	Кемеровская область, Киселевский городской округ, Рейдовая, 25а	Россия, Кемеровская область, Киселевск	0101000020E6100000C493DDCCE8A85540575EF23FF9FF4A40
40100	5	51	\N	26262	13053	\N	54.002335011406302	652700, Кемеровская область, Киселевский городской округ, город Киселевск, Привольная, 17	Россия, Кемеровская область, Киселевск	0101000020E610000047E5266A69A955406E5166834C004B40
40118	5	51	\N	26262	12382	\N	54.000206995535201	Кемеровская область, Киселевский городской округ, Пионерская, 7	Россия, Кемеровская область, Киселевск	0101000020E610000091EF52EA92AC55407A1D71C806004B40
40066	5	51	\N	26262	13635	\N	54.006967000000003	652700, Кемеровская область, Киселевский городской округ, город Киселевск, Панфилова, 5		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40084	5	51	\N	26262	75885	\N	53.998997611222599	Кемеровская область, Киселевский городской округ, Нижне-Заводская, 2	Россия, Кемеровская область, Киселевск	0101000020E6100000BE4BA94BC6A855407C629D2ADFFF4A40
40135	5	51	\N	26262	50566	\N	53.980358062201503	Кемеровская область, Киселевский городской округ, Мурманский переулок, 20	Россия, Кемеровская область, Киселевск	0101000020E6100000C1374D9F1DAE55409D2FF65E7CFD4A40
40112	5	51	\N	26262	75590	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Мира, 40	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40130	5	51	\N	26262	12388	\N	53.996578835474402	Кемеровская область, Киселевский городской округ, Лутугина, 39	Россия, Кемеровская область, Киселевск	0101000020E61000003447567E19A95540B07092E68FFF4A40
40128	5	51	\N	26262	12388	\N	53.9680498655351	Кемеровская область, Киселевский городской округ, Лутугина, 12	Россия, Кемеровская область, Киселевск	0101000020E61000007E74EACA67AE55404772F90FE9FB4A40
40103	5	51	\N	26262	75655	\N	54.0075428412649	Кемеровская область, Киселевский городской округ, Луговая, 10		0101000020E6100000310BED9C66A955402828452BF7004B40
40108	5	51	\N	26262	75660	\N	53.988476701054601	Кемеровская область, Киселевский городской округ, Ленина, 35	Россия, Кемеровская область, Киселевск	0101000020E610000050A6D1E462AA554092EC116A86FE4A40
40107	5	51	\N	26262	75674	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Ленина, 37		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40683	5	51	\N	26262	50406	\N	53.991668649029798	Кемеровская область, Прокопьевский городской округ, Зенковский район, Кустарная, 35	Россия, Кемеровская область, Киселевск	0101000020E61000009694BBCFF1AA554080BA8102EFFE4A40
40654	5	51	\N	26262	50439	\N	53.966119065287302	Кемеровская область, Прокопьевский городской округ, Зенковский район, Коксовая, 41	Россия, Кемеровская область, Киселевск	0101000020E6100000AD889AE8F3AD5540A98592C9A9FB4A40
40133	5	51	\N	26262	12403	\N	53.989711484863399	Кемеровская область, Киселевский городской округ, Кирпичный переулок, 7а	Россия, Кемеровская область, Киселевск	0101000020E610000042B115342DA95540E8BE9CD9AEFE4A40
40076	5	51	\N	26262	75856	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Дружбы, 11	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40121	5	51	\N	26262	75620	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Дзержинского, 12	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40116	5	51	\N	26262	75618	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Весенняя, 9		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40067	5	51	\N	26262	75584	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, Багратиона, 11а	Россия, Кемеровская область, Киселевск	0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40117	5	51	\N	26262	12415	\N	54.006967000000003	652700, Кемеровская область, Киселевский городской округ, город Киселевск, 50 лет городу, 21		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
40115	5	51	\N	26262	12415	\N	54.007593399511002	Кемеровская область, Киселевский городской округ, 50 лет городу, 20а	Россия, Кемеровская область, Киселевск	0101000020E6100000454948A46DA95540DA56B3CEF8004B40
40085	5	51	\N	26262	75650	\N	54.006967000000003	Кемеровская область, Киселевский городской округ, 50 лет Октября, 5а		0101000020E6100000BFD4CF9B8AA955405C936E4BE4004B40
39914	5	51	\N	2895	\N	\N	55.391466999999999	Кемеровская область, город Кемерово, Кировский район, Леонова, 3А		0101000020E61000009FCA694FC98055404B3B35971BB24B40
39679	5	51	890	\N	16037	\N	54.390012528190098	Кемеровская область, Беловский городской округ, Щетинкина ул, 61	Россия, Кемеровская область, Беловский район	0101000020E61000003B8DB454DE945540E7012CF2EB314B40
40613	5	51	\N	2895	16101	\N	55.385075000000001	Кемеровская область, Прокопьевский городской округ, Центральный район, Шишкина, 24		0101000020E6100000F629C76471815540ECC039234AB14B40
39942	5	51	\N	2895	16190	\N	55.333891000000001	Кемеровская область, город Кемерово, Ленинский район, Тухачевского, 32	Россия, Кемеровская область, Кемерово, Ленинский район, улица Тухачевского, 32	0101000020E6100000A0A4C00298885540E1B6B6F0BCAA4B40
39995	5	51	\N	2895	16430	\N	55.337086999999997	город Кемерово, Трофимова, 45	Россия, Кемеровская область, Кемерово, Заводский район, улица Трофимова, 45	0101000020E6100000E8DD5850188755401074B4AA25AB4B40
39906	5	51	\N	2895	16028	\N	55.405884	Кемеровская область, город Кемерово, Кировский район, Спартака, 16	Россия, Кемеровская область, Кемерово, Кировский район, улица Спартака, 16	0101000020E6100000EA40D653AB8255401EFCC401F4B34B40
39824	5	51	\N	2895	15517	\N	55.315770000000001	Кемеровская область, город Кемерово, Заводской район, Радищева, 7	Россия, Кемеровская область, Кемерово, Заводский район, улица Радищева, 7	0101000020E61000006FD39FFD488555406A87BF266BA84B40
39895	5	51	\N	2895	15979	\N	55.387044000000003	Кемеровская область, город Кемерово, Кировский район, Назарова, 8	Россия, Кемеровская область, Кемерово, Кировский район, улица Назарова, 8	0101000020E6100000B63176C24B805540780E65A88AB14B40
40451	5	51	\N	2895	15677	\N	55.356952999999997	Кемеровская область, город Новокузнецк, Центральный район, Кирова, 35, лицей 111	Россия, Кемеровская область, Кемерово, Центральный район, улица Кирова, 33/36	0101000020E61000004DF6CFD380845540C39ACAA2B0AD4B40
39965	5	51	\N	2895	15706	\N	55.342272999999999	город Кемерово, Гагарина, 146	Россия, Кемеровская область, Кемерово, Центральный район, улица Гагарина, 146	0101000020E61000004C38F4160F895540E3A6069ACFAB4B40
39919	5	51	\N	2895	16080	\N	55.402439000000001	Кемерово, Кировский район, имени Василия Толстикова (здание школы №39), 1	Россия, Кемеровская область, Кемерово, Кировский район, улица Василия Толстикова, 1	0101000020E61000004337FB03E582554046D1031F83B34B40
40072	5	51	7401	\N	15679	\N	54.003901201557603	Кемеровская область, Киселевский городской округ, Багратиона, 36		0101000020E6100000DFA9807B9EAA5540FAB5F5D37F004B40
39917	5	51	\N	2895	15679	\N	55.387228	Кемеровская область, город Кемерово, Кировский район, Багратиона, 2	Россия, Кемеровская область, Кемерово, Кировский район, улица Багратиона, 2	0101000020E6100000904AB1A371825540390CE6AF90B14B40
40047	5	51	\N	2895	15350	\N	55.398508	Кемеровская область, город Кемерово, Рудничный район, пр-т Шахтеров, 52	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 52	0101000020E6100000DC4B1AA375875540E198654F02B34B40
40040	5	51	\N	2895	15350	\N	55.395173999999997	Кемеровская область, город Кемерово, Рудничный район, пр-т Шахтеров, 59	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 59	0101000020E61000001B834E081D875540601DC70F95B24B40
40027	5	51	\N	2895	15350	\N	55.384231999999997	Кемеровская область, город Кемерово, Рудничный район, пр-т Шахтеров, 2	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 2	0101000020E6100000079ACFB9DB855540D009A1832EB14B40
40024	5	51	\N	2895	15350	\N	55.395823999999998	"Кемеровская область, город Кемерово, Рудничный район, пр-т Шахтеров, 46""Б"""	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 46б	0101000020E610000084656CE866875540677C5F5CAAB24B40
40022	5	51	\N	2895	15350	\N	55.406241999999999	Кемеровская область, город Кемерово, Рудничный район, пр-т Шахтеров, 105	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 105	0101000020E6100000CF143AAFB18755407D21E4BCFFB34B40
40050	5	51	\N	2895	76388	\N	55.406241999999999	Кемерово, Рудничный район, просп. Шахтеров (здание школы № 34), д. 105		0101000020E6100000CF143AAFB18755407D21E4BCFFB34B40
41458	5	51	\N	2895	15654	\N	55.345038000000002	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Ленина, д. 70 (ПЛ №79)	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 70	0101000020E6100000FDDAFAE93F8755404AF086342AAC4B40
40526	5	51	\N	2895	15654	\N	55.344617999999997	Кемеровская область, Осинниковский городской округ, Ленина, 28	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 28	0101000020E6100000D1419770E884554074CE4F711CAC4B40
40524	5	51	\N	2895	15654	\N	55.345550000000003	Кемеровская область, Осинниковский городской округ, Ленина, 123	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 123	0101000020E61000006495D233BD89554000917EFB3AAC4B40
40105	5	51	\N	2895	15654	\N	55.344709999999999	Кемеровская область, Киселевский городской округ, Ленина, 50	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 50	0101000020E61000009C3237DF88855540554D10751FAC4B40
39997	5	51	\N	2895	15654	\N	55.346347999999999	город Кемерово, просп. Ленина, 62Б	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 62б	0101000020E610000093AB58FCA68655407B849A2155AC4B40
39993	5	51	\N	2895	15654	\N	55.344141999999998	город Кемерово, Ленина проспект, 79	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 79	0101000020E610000024D40CA9A28755400B9755D80CAC4B40
39984	5	51	\N	2895	15654	\N	55.346347999999999	город Кемерово, Ленина проспект, 62Б	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 62б	0101000020E610000093AB58FCA68655407B849A2155AC4B40
39960	5	51	\N	2895	15654	\N	55.354219999999998	Кемеровская область, город Кемерово, Ленинский район, Ленина проспект, 160А	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 160а	0101000020E61000008D5E0D501A8B554068CBB91457AD4B40
39948	5	51	\N	2895	15654	\N	55.349634000000002	Кемеровская область, город Кемерово, Ленинский район, Ленина проспект, 130А	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 130а	0101000020E6100000D46531B1F9895540EBC891CEC0AC4B40
39946	5	51	\N	2895	15654	\N	55.348543999999997	Кемеровская область, город Кемерово, Ленинский район, проспект Ленина, 126А	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 126а	0101000020E6100000B2834A5CC7895540C79BFC169DAC4B40
39856	5	51	\N	2895	15654	\N	55.342984999999999	Кемеровская область, город Кемерово, Заводской район, Ленина проспект, 55А	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 55а	0101000020E6100000408864C8B18555406002B7EEE6AB4B40
39779	5	51	\N	2895	15654	\N	55.344571999999999	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Ленина, 105	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 105	0101000020E61000002368CC24EA885540048F6FEF1AAC4B40
39777	5	51	\N	2895	15654	\N	55.345114000000002	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Ленина, 84	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 84	0101000020E61000005A2BDA1CE787554025B20FB22CAC4B40
39668	5	51	\N	2895	15654	\N	55.343629999999997	Кемеровская область, Беловский городской округ, Ленина, 9	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 9	0101000020E6100000B16EBC3B3284554055F65D11FCAB4B40
39655	5	51	\N	2895	15654	\N	55.344531000000003	Кемеровская область, Анжеро-Судженский городской округ, Ленина, 8	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 8	0101000020E6100000C2DF2F664B845540A6BA809719AC4B40
39920	5	51	\N	2895	71538	\N	55.402439000000001	Кемеровская область, город Кемерово, Кировский район, имени Толстикова Василия, 1		0101000020E61000004337FB03E582554046D1031F83B34B40
39999	5	51	\N	2895	71588	\N	55.340465999999999	город Кемерово, Гагарина, 118		0101000020E610000081D1E5CDE187554031B3CF6394AB4B40
40908	5	51	\N	2895	15892	\N	55.348416194270897	Кемеровская область, Кемеровский район, п.Металлплощадка, б-р Строителей, 73	Россия, Кемеровская область, Кемерово, Ленинский район	0101000020E61000001B67D311C08A55409AB33EE598AC4B40
39955	5	51	\N	2895	15892	\N	55.347766	Кемеровская область, город Кемерово, Ленинский район, Строителей бульвар, 24В	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 24в	0101000020E6100000EF54C03DCF8A55409354A69883AC4B40
39938	5	51	\N	2895	15892	\N	55.336092999999998	Кемеровская область, город Кемерово, Ленинский район, Строителей бульвар, 47	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 47	0101000020E61000004BCADDE7F88A55400FB56D1805AB4B40
39925	5	51	\N	2895	15892	\N	55.336902000000002	Кемеровская область, город Кемерово, Ленинский район, Строителей бульвар, 50А	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 50а	0101000020E6100000BF2CEDD45C8B55407FFACF9A1FAB4B40
39922	5	51	\N	2895	15892	\N	55.339534	Кемеровская область, город Кемерово, Ленинский район, Строителей бульвар, 44Б	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 44б	0101000020E61000000A117008558B5540A6F0A0D975AB4B40
40037	5	51	\N	2895	71592	\N	55.391553999999999	"Кемеровская область, город Кемерово, Рудничный район, Ю. Смирнова, 18""А"""		0101000020E61000003A083A5AD58655401A4F04711EB24B40
40051	5	51	\N	2895	50510	\N	55.415564000000003	Кемеровская область, город Кемерово, Рудничный район, Щегловская, 2		0101000020E61000003B35971B0C8F55408EB27E3331B54B40
40030	5	51	\N	2895	71710	\N	55.393450999999999	Кемеровская область, город Кемерово, Рудничный район, Шахтерская, 9		0101000020E61000002D414640858455400CCA349A5CB24B40
40020	5	51	\N	2895	71142	\N	55.419049000000001	Кемеровская область, город Кемерово, Рудничный район, Черноморская, 38Б		0101000020E610000036E50AEF72855540F435CB65A3B54B40
40089	5	51	\N	2895	71549	\N	55.387683000000003	Кемеровская область, Киселевский городской округ, Циолковского, 51	Россия, Кемеровская область, Кемерово, Кировский район, улица Циолковского, 51	0101000020E6100000AFCDC64ACC8255408B1BB7989FB14B40
40045	5	51	\N	2895	50372	\N	55.398876000000001	Кемеровская область, город Кемерово, Рудничный район, Цимлянская, 6		0101000020E6100000990F0874268755406494675E0EB34B40
39665	5	51	\N	2895	50372	\N	55.398232	Кемеровская область, Беловский городской округ, Цимлянская, 58		0101000020E610000075ABE7A4F78655403F1C2444F9B24B40
39891	5	51	\N	2895	70414	\N	55.297037408707702	Кемеровская область, город Кемерово, Заводской район, Центральная, 157	Россия, Кемеровская область, Кемерово, Заводский район, Центральная улица	0101000020E61000009CFC169D2C805540DA59F44E05A64B40
39862	5	51	\N	2895	71534	\N	55.334741000000001	Кемеровская область, город Кемерово, Заводской район, Федоровского, 6		0101000020E6100000209738F240845540AFD007CBD8AA4B40
39848	5	51	\N	2895	71673	\N	55.344459000000001	Кемеровская область, город Кемерово, Заводской район, Угловая, 141		0101000020E6100000BEDC2747018355400CE8853B17AC4B40
40002	5	51	\N	2895	71542	\N	55.338284999999999	город Кемерово, Терешковой, 35		0101000020E610000059F78F85E88855401ADD41EC4CAB4B40
40095	5	51	\N	2895	15791	\N	55.390281000000002	Кемеровская область, Киселевский городской округ, Студенческая, 2	Россия, Кемеровская область, Кемерово, Рудничный район, Студенческая улица, 2	0101000020E6100000B821C66B5E86554006A051BAF4B14B40
39962	5	51	\N	2895	16117	\N	55.359200000000001	город Кемерово, Советский проспект, 26	Россия, Кемеровская область, Кемерово, Центральный район, Советский проспект, 26	0101000020E610000062F3716DA8845540925CFE43FAAD4B40
39853	5	51	\N	2895	71531	\N	55.342503999999998	Кемеровская область, город Кемерово, Заводской район, Соборная, 5А		0101000020E61000001344DD0720865540E55FCB2BD7AB4B40
40005	5	51	\N	2895	71544	\N	55.341709999999999	город Кемерово, Сибиряков-Гвардейцев, 332	Россия, Кемеровская область, Кемерово, Центральный район, улица Сибиряков-Гвардейцев, 332	0101000020E6100000C8957A1684895540AB5B3D27BDAB4B40
39829	5	51	\N	2895	71659	\N	55.318930999999999	Кемеровская область, город Кемерово, Заводской район, Сергея Тюленина, 15		0101000020E61000004C1762F5478555401D5723BBD2A84B40
39843	5	51	\N	2895	71136	\N	55.341760999999998	Кемеровская область, город Кемерово, Заводской район, Семашко, 46		0101000020E61000009D84D217428255402D060FD3BEAB4B40
39974	5	51	\N	2895	71583	\N	55.347991	город Кемерово, Рукавишникова, 15		0101000020E61000006C787AA52C845540B32616F88AAC4B40
40018	5	51	\N	2895	71547	\N	55.416907999999999	Кемеровская область, город Кемерово, Рудничный район, Ракитянского, 81		0101000020E61000004ED4D2DC0A8855406BB8C83D5DB54B40
39826	5	51	\N	2895	71571	\N	55.317563	Кемеровская область, город Кемерово, Заводской район, Радищева, 5		0101000020E61000002497FF907E855540B7B585E7A5A84B40
40263	5	51	\N	2895	71715	\N	55.350807000000003	Кемеровская область, город Междуреченск - Междуреченский район, ул.Пушкина, 15		0101000020E61000005ED5592DB08255409C1A683EE7AC4B40
40258	5	51	\N	2895	71715	\N	55.349894999999997	Кемеровская область, город Междуреченск - Междуреченский район, ул.Пушкина, 18		0101000020E6100000B439CE6DC28255405704FF5BC9AC4B40
40256	5	51	\N	2895	71715	\N	55.349138000000004	Кемеровская область, город Междуреченск - Междуреченский район, ул Пушкина, 22		0101000020E6100000B14F00C5C88255403BE5D18DB0AC4B40
40061	5	51	\N	2895	76484	\N	55.359618432690901	ул.Пром.шоссе, 17 (стадион "Факел")		0101000020E6100000740D33349E855540C6866EF607AE4B40
39852	5	51	\N	2895	71576	\N	55.339272999999999	Кемеровская область, город Кемерово, Заводской район, Пролетарская, 13		0101000020E6100000DF52CE177B84554039B5334C6DAB4B40
39851	5	51	\N	2895	71576	\N	55.342646999999999	Кемеровская область, город Кемерово, Заводской район, Пролетарская, 10		0101000020E610000038143E5B0785554048895DDBDBAB4B40
39818	5	51	\N	2895	76170	\N	55.314264000000001	Кемеровская область, город Кемерово, Заводской район, Плодопитомник, 39		0101000020E610000058569A9482875540B32781CD39A84B40
40443	5	51	\N	2895	16325	\N	55.342011999999997	Кемеровская область, город Новокузнецк, Центральный район, Пионерский, 15, школа №12	Россия, Кемеровская область, Кемерово, Центральный район, Пионерский бульвар, 15	0101000020E61000004303B16CE6865540766B990CC7AB4B40
39983	5	51	\N	2895	16325	\N	55.349665000000002	город Кемерово, Пионерский бульвар, 4А	Россия, Кемеровская область, Кемерово, Центральный район, Пионерский бульвар, 4а	0101000020E61000002942EA76F686554026C79DD2C1AC4B40
39821	5	51	\N	2895	76398	\N	55.319868	Кемерово, Заводский район, ул.Патриотов (центр дополнительного образования детей), д.9		0101000020E610000020B58993FB845540BA84436FF1A84B40
39823	5	51	\N	2895	71654	\N	55.319868	Кемеровская область, город Кемерово, Заводской район, Патриотов, 9		0101000020E610000020B58993FB845540BA84436FF1A84B40
40065	5	51	\N	2895	71713	\N	55.387994999999997	Кемеровская область, Киселевский городской округ, Панфилова, 7		0101000020E6100000B4AF3C484F8355407901F6D1A9B14B40
40274	5	51	\N	2895	71645	\N	55.323551000000002	Кемеровская область, Осинниковский городской округ, Радищева, 1		0101000020E6100000B81E85EB5186554047CB811E6AA94B40
39967	5	51	\N	2895	71582	\N	55.356191000000003	Кемеровская область, город Кемерово, Центральный район, Орджоникидзе, 9		0101000020E6100000C07630629F8555409510ACAA97AD4B40
40008	5	51	\N	2895	16221	\N	55.350433000000002	город Кемерово, Октябрьский проспект, 40А	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 40а	0101000020E6100000F2EF332E1C895540373811FDDAAC4B40
39989	5	51	\N	2895	16221	\N	55.347244000000003	город Кемерово, Октябрьский проспект, 39	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 39	0101000020E61000004FAE2990D9875540BADDCB7D72AC4B40
39988	5	51	\N	2895	16221	\N	55.347152000000001	город Кемерово, Октябрьский проспект, 17А	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 17а	0101000020E6100000DD28B2D650875540D95E0B7A6FAC4B40
39985	5	51	\N	2895	16221	\N	55.348717999999998	город Кемерово, Октябрьский проспект, 8	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 8	0101000020E61000006A4E5E640287554065C39ACAA2AC4B40
39957	5	51	\N	2895	16221	\N	55.352500999999997	Кемеровская область, город Кемерово, Ленинский район, Октябрьский проспект, 85А	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 85а	0101000020E610000081069B3A8F8A55405567B5C01EAD4B40
39950	5	51	\N	2895	16221	\N	55.352618	Кемеровская область, город Кемерово, Ленинский район, Октябрьский проспект, 56Б	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 56б	0101000020E610000014252191B68955408FFD2C9622AD4B40
40029	5	51	\N	2895	71548	\N	55.384216000000002	"Кемеровская область, город Кемерово, Рудничный район, Озерная, 1""А"""		0101000020E61000000805A568E5835540CB4C69FD2DB14B40
39845	5	51	\N	2895	71529	\N	55.343901000000002	Кемеровская область, город Кемерово, Заводской район, Невьянская, 4А		0101000020E61000005857056A31805540E607AEF204AC4B40
40049	5	51	\N	2895	71130	\N	55.406726999999997	Кемеровская область, город Кемерово, Рудничный район, Нахимова, 177		0101000020E6100000CB0F5CE50987554039B35DA10FB44B40
40033	5	51	\N	2895	71130	\N	55.393093	"Кемеровская область, город Кемерово, Рудничный район, Нахимова, 34""А"""		0101000020E61000004205871744865540ADA415DF50B24B40
39958	5	51	\N	2895	16241	\N	55.356420999999997	Кемеровская область, город Кемерово, Ленинский район, Московский проспект, 25А	Россия, Кемеровская область, Кемерово, Ленинский район, Московский проспект, 25а	0101000020E61000007A6D3656628A5540C64D0D349FAD4B40
39877	5	51	\N	2895	15838	\N	55.324427	Кемеровская область, город Кемерово, Заводской район, Молодежный проспект, 9Б	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 9б	0101000020E610000058A9A0A2EA8755403E78EDD286A94B40
39874	5	51	\N	2895	15838	\N	55.324986000000003	Кемеровская область, город Кемерово, Заводской район, Молдежный проспект, 20	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 20	0101000020E6100000D714C8EC2C87554035D4282499A94B40
39873	5	51	\N	2895	15838	\N	55.324986000000003	Кемеровская область, город Кемерово, Заводской район, Молодежный проспект, 20	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 20	0101000020E6100000D714C8EC2C87554035D4282499A94B40
39871	5	51	\N	2895	15838	\N	55.324950000000001	Кемеровская область, город Кемерово, Заводской район, Молодежный, 7Б	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 7б	0101000020E6100000691A14CD03885540E86A2BF697A94B40
39868	5	51	\N	2895	15838	\N	55.324950000000001	Кемеровская область, город Кемерово, Заводской район, Молодежный проспект, 7Б	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 7б	0101000020E6100000691A14CD03885540E86A2BF697A94B40
39867	5	51	\N	2895	15838	\N	55.328426999999998	Кемеровская область, город Кемерово, Заводской район, Молодежный проспект, 2А	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 2а	0101000020E6100000376F9C14E6875540CB0F5CE509AA4B40
39861	5	51	\N	2895	71578	\N	55.337705999999997	Кемеровская область, город Кемерово, Заводской район, Мичурина, 55		0101000020E6100000000341800C855540DCD440F339AB4B40
39675	5	51	\N	2895	50373	\N	55.361001000000002	Кемеровская область, Беловский городской округ, Маркса, 108		0101000020E6100000CCEB8843368355406269E04735AE4B40
39881	5	51	\N	2895	70802	\N	55.323177000000001	Кемеровская область, город Кемерово, Заводской район, Марата, 1		0101000020E6100000C9CB9A58E07C5540E2E82ADD5DA94B40
39959	5	51	\N	2895	16115	\N	55.358888	Кемеровская область, город Кемерово, Ленинский район, Ленинградский проспект, 14А	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 14а	0101000020E6100000CF9F36AAD38A5540A376BF0AF0AD4B40
39952	5	51	\N	2895	16115	\N	55.345016999999999	Кемеровская область, город Кемерово, Ленинский район, Ленинградский проспект, 29А	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 29а	0101000020E6100000D7C05609168B554032C85D8429AC4B40
39928	5	51	\N	2895	16115	\N	55.340378999999999	Кемеровская область, город Кемерово, Ленинский район, Ленинградский проспект, 34Б	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34б	0101000020E61000004E9D47C5FF8B5540629F008A91AB4B40
39926	5	51	\N	2895	16115	\N	55.340004999999998	Кемеровская область, город Кемерово, Ленинский район, Ленинградский проспект, 34В	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34в	0101000020E6100000C53BC093168C5540FDBCA94885AB4B40
39972	5	51	\N	2895	15681	\N	55.354199999999999	Кемеровская область, город Кемерово, Центральный район, просп. Кузнецкий, 44	Россия, Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 44	0101000020E610000010CB660E49845540211FF46C56AD4B40
39971	5	51	\N	2895	15681	\N	55.354199999999999	город Кемерово, просп. Кузнецкий, 44	Россия, Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 44	0101000020E610000010CB660E49845540211FF46C56AD4B40
39840	5	51	\N	2895	15681	\N	55.340741999999999	Кемеровская область, город Кемерово, Заводской район, Кузнецкий проспект, 83	Россия, Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 83	0101000020E6100000419B1C3EE9835540D32F116F9DAB4B40
39837	5	51	\N	2895	15681	\N	55.305194999999998	Кемеровская область, город Кемерово, Заводской район, Кузнецкий проспект, 262	Россия, Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 262	0101000020E61000000CB265F9BA8155408CF337A110A74B40
39688	5	51	\N	2895	50376	\N	55.387028999999998	Кемеровская область, Беловский городской округ, мкрн 8 марта, Крылова ул, 88		0101000020E6100000185FB4C70B82554042CD902A8AB14B40
39977	5	51	\N	2895	71207	\N	55.348385339976097	город Кемерово, Красноармейская, 117		0101000020E610000075392520268555405FB532E197AC4B40
39978	5	51	\N	2895	16335	\N	55.345683000000001	город Кемерово, Красная, 20	Россия, Кемеровская область, Кемерово, Центральный район, Красная улица, 20	0101000020E610000061376C5B948555403FE42D573FAC4B40
39980	5	51	\N	2895	71653	\N	55.351630999999998	город Кемерово, Красная, 6		0101000020E61000007250C24CDB85554040A19E3E02AD4B40
39866	5	51	\N	2895	71535	\N	55.334567	Кемеровская область, город Кемерово, Заводской район, Котовского, 8		0101000020E6100000B98D06F01688554011A96917D3AA4B40
39857	5	51	\N	2895	15494	\N	55.328079412538202	Кемеровская область, город Кемерово, Заводской район, Космическая, 2	Россия, Кемеровская область, Кемерово, Заводский район, Космическая улица, 4	0101000020E610000066868DB27E84554090C01F7EFEA94B40
39811	5	51	\N	2895	15494	\N	55.321390000000001	Кемеровская область, город Кемерово, Заводской район, Космическая, 8	Россия, Кемеровская область, Кемерово, Заводский район, Космическая улица, 8	0101000020E6100000560F98874C85554077A1B94E23A94B40
39813	5	51	\N	2895	71527	\N	55.315427	Кемеровская область, город Кемерово, Заводской район, Космическая, 31	Россия, Кемеровская область, Кемерово, Заводский район, Космическая улица, 31	0101000020E6100000C687D9CBB685554040A374E95FA84B40
40831	5	51	\N	2895	71561	\N	55.339236999999997	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Комсомольская, 7		0101000020E61000006C054D4BAC835540EC4B361E6CAB4B40
39842	5	51	\N	2895	71125	\N	55.350307812552302	Кемеровская область, город Кемерово, Заводской район, Коммунистическая, 59		0101000020E61000007ADFF8DA338355407AC37DE4D6AC4B40
40622	5	51	\N	2895	71596	\N	55.360280000000003	Кемеровская область, Прокопьевский городской округ, Центральный район, Кирова, 19		0101000020E610000084D89942E784554092B3B0A71DAE4B40
40531	5	51	\N	2895	71596	\N	55.358570999999998	Кемеровская область, Осинниковский городской округ, Кирова, 27	Россия, Кемеровская область, Кемерово, Центральный район, улица Кирова, 27	0101000020E6100000629E95B4E2845540A2258FA7E5AD4B40
40407	5	51	\N	2895	71596	\N	55.357951	,Кемеровская область, город Новокузнецк, Центральный район, Кирова, 79а, гимназия 44		0101000020E6100000A60F5D50DF84554006499F56D1AD4B40
39769	5	51	\N	2895	71596	\N	55.364629000000001	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Кирова, 4		0101000020E610000028806264C98455402B16BF29ACAE4B40
39694	5	51	\N	2895	50377	\N	55.336989000000003	Кемеровская область, Беловский городской округ, пгт Новый Городок, Киевская, 38		0101000020E6100000F03499F1B68555404E0E9F7422AB4B40
40062	5	51	\N	2895	76408	\N	55.362869778896602	ул.Каракумская, 14 (шк.№57)		0101000020E61000004FCB0F5CE58455408A592F8672AE4B40
40264	5	51	\N	2895	71594	\N	55.354424999999999	Кемеровская область, город Междуреченск - Междуреченский район, ул.Интернациональная, 35		0101000020E6100000E57FF277EF82554041F163CC5DAD4B40
40615	5	51	\N	2895	15457	\N	55.392301000000003	Кемеровская область, Прокопьевский городской округ, Центральный район, Институтская, 106		0101000020E610000090BFB4A84F87554014984EEB36B24B40
40601	5	51	\N	2895	15457	\N	55.396509000000002	Кемеровская область, Прокопьевский городской округ, Рудничный район, Институтская, 15	Россия, Кемеровская область, Кемерово, Рудничный район, Институтская улица, 15	0101000020E61000006EDBF7A8BF875540EBC891CEC0B24B40
40043	5	51	\N	2895	70651	\N	55.394534999999998	Кемеровская область, город Кемерово, Рудничный район, Институтская, 20		0101000020E61000000CCA349A5C8755404D10751F80B24B40
40036	5	51	\N	2895	70651	\N	55.389049	Кемеровская область, город Кемерово, Рудничный район, Институтская, 1		0101000020E610000075560BEC3187554050C58D5BCCB14B40
39911	5	51	\N	2895	71536	\N	55.411704999999998	Кемеровская область, город Кемерово, Кировский район, Инициативная, 125А		0101000020E6100000D7BE805EB8835540C24CDBBFB2B44B40
39908	5	51	\N	2895	71536	\N	55.404094999999998	Кемеровская область, город Кемерово, Кировский район, Инициативная, 90		0101000020E610000082919735B182554012BD8C62B9B34B40
39905	5	51	\N	2895	71536	\N	55.399754999999999	Кемеровская область, город Кемерово, Кировский район, Инициативная, 42		0101000020E6100000E1D1C6116B815540CCB4FD2B2BB34B40
40141	5	51	\N	2895	16050	\N	55.347299999999997	Кемеровская область, Киселевский городской округ, Индустриальная, 7а		0101000020E61000005116BEBED68255404DF38E5374AC4B40
39832	5	51	\N	2895	71575	\N	55.308064000000002	Кемеровская область, город Кемерово, Заводской район, Зейская, 54		0101000020E610000079E9263108835540988922A46EA74B40
40025	5	51	\N	2895	15390	\N	55.3675	Кемеровская область, город Кемерово, Рудничный район, Елыкаевская, 151	Россия, Кемеровская область, Кемерово, Рудничный район, Елыкаевская улица, 151	0101000020E61000003D0B42791F885540D7A3703D0AAF4B40
39814	5	51	\N	2895	78546	\N	55.309505000000001	Кемеровская область, город Кемерово, Заводской район, Дружбы, 7	Россия, Кемеровская область, Кемерово, Заводский район, микрорайон поселок Южный	0101000020E610000020B8CA130886554068791EDC9DA74B40
39892	5	51	\N	2895	50287	\N	55.359594000000001	Кемеровская область, город Кемерово, Заводской район, Докучаева, 1		0101000020E6100000740D33349E8555403EEB1A2D07AE4B40
39903	5	51	\N	2895	15655	\N	55.398411000000003	Кемеровская область, город Кемерово, Кировский район, Гурьевская, 14А	Россия, Кемеровская область, Кемерово, Кировский район, Гурьевская улица, 14а	0101000020E6100000C251F2EA1C815540EFAEB321FFB24B40
41617	5	51	\N	2895	76357	\N	55.338372	Кемерово, Заводский район, ул.Грузовая (здание столовой), д.1	Россия, Кемеровская область, Кемерово, Заводский район, Грузовая улица, 11	0101000020E61000001DE8A1B60D7F5540E9F010C64FAB4B40
40013	5	51	\N	2895	71181	\N	55.444180000000003	Кемеровская область, город Кемерово, Рудничный район, Городецкая, 1А		0101000020E6100000FED5E3BED5845540C6C4E6E3DAB84B40
40592	5	51	\N	2895	71600	\N	55.391882000000003	Кемеровская область, Прокопьевский городской округ, Рудничный район, Гайдара, 1		0101000020E61000008ECD8E54DF8155400FF27A3029B24B40
40534	5	51	\N	2895	71557	\N	55.339176000000002	Кемеровская область, Осинниковский городской округ, Гагарина, 7		0101000020E610000023DDCF29C885554047CB811E6AAB4B40
39991	5	51	\N	2895	71557	\N	55.339922999999999	город Кемерово, Гагарина, 110		0101000020E61000004A97FE25A98755404014CC9882AB4B40
39941	5	51	\N	2895	49970	\N	55.336435999999999	Кемеровская область, город Кемерово, Ленинский район, Ворошилова, 17		0101000020E6100000F46A80D2508A55403999B85510AB4B40
39937	5	51	\N	2895	49970	\N	55.344428000000001	Кемеровская область, город Кемерово, Ленинский район, Ворошилова, 10Б		0101000020E610000060048D99448A5540D1E9793716AC4B40
39934	5	51	\N	2895	49970	\N	55.336621000000001	Кемеровская область, город Кемерово, Ленинский район, Ворошилов, 10Б		0101000020E61000003D433866D98A5540CB129D6516AB4B40
39932	5	51	\N	2895	49970	\N	55.342790000000001	Кемеровская область, город Кемерово, Ленинский район, Ворошилова, 18Д		0101000020E610000096B377465B8A5540ABB2EF8AE0AB4B40
39931	5	51	\N	2895	49970	\N	55.338078654738503	Кемеровская область, город Кемерово, Ленинский район, Ворошилова, 22А	Россия, Кемеровская область, Кемерово, Ленинский район, проспект Химиков, 13/22а	0101000020E610000018E945ED7E8A5540713B342C46AB4B40
40006	5	51	\N	2895	71699	\N	55.347724999999997	город Кемерово, Волгоградская, 9А		0101000020E610000059C2DA183B8955403480B74082AC4B40
39944	5	51	\N	2895	71699	\N	55.342637000000003	Кемеровская область, город Кемерово, Ленинский район, Волгоградская, 28В		0101000020E61000009EB64604E389554025B37A87DBAB4B40
39975	5	51	\N	2895	71553	\N	55.348534000000001	город Кемерово, Весенняя, 28		0101000020E61000005FB7088CF5845540A4C519C39CAC4B40
39968	5	51	\N	2895	71553	\N	55.352603000000002	Кемеровская область, город Кемерово, Центральный район, Весенняя, 17		0101000020E6100000ACA8C1340C8555405ABC581822AD4B40
39830	5	51	\N	2895	71569	\N	55.317194000000001	Кемеровская область, город Кемерово, Заводской район, Веры Волошиной, 13		0101000020E6100000992D5915E1845540643E20D099A84B40
39819	5	51	\N	2895	71569	\N	55.315463000000001	Кемеровская область, город Кемерово, Заводской район, Веры Волошиной, 21		0101000020E61000008CF678211D8555408D0C721761A84B40
40015	5	51	\N	2895	16512	\N	55.444645000000001	Кемеровская область, город Кемерово, Рудничный район, Благовещенская, 53	Россия, Кемеровская область, Кемерово, Рудничный район, Благовещенская улица, 53	0101000020E6100000116F9D7FBB8555403BAA9A20EAB84B40
39816	5	51	\N	2895	71567	\N	55.331350999999998	Кемеровская область, город Кемерово, Заводской район, Бийская, 37		0101000020E6100000A0168387698555409A3FA6B569AA4B40
39888	5	51	\N	2895	70809	\N	55.282782537490803	Кемеровская область, город Кемерово, Заводской район, Белозерная, 42	Россия, Кемеровская область, Кемерово, Ягуновский жилой район, Белозерная улица	0101000020E6100000EA4141295A7F5540B16EBC3B32A44B40
39889	5	51	\N	2895	70760	\N	55.2838407777231	Кемеровская область, город Кемерово, Заводской район, Баха, 23	Россия, Кемеровская область, Кемерово, Ягуновский жилой район, улица Баха	0101000020E61000002E73BA2C267E5540C921E2E654A44B40
39885	5	51	\N	2895	49966	\N	55.359594000000001	Кемеровская область, город Кемерово, Заводской район, Барнаульская, 23		0101000020E6100000740D33349E8555403EEB1A2D07AE4B40
40637	5	51	\N	2895	71632	\N	55.399146999999999	Кемеровская область, Прокопьевский городской округ, Центральный район, Артема, 8	Россия, Кемеровская область, Кемерово, Кировский район, улица Артема, 8	0101000020E61000000BD0B69A75825540F4A5B73F17B34B40
40012	5	51	\N	2895	71709	\N	55.421956000000002	Кемеровская область, город Кемерово, Рудничный район, Антипова, 4А		0101000020E6100000419AB1683A885540ED2C7AA702B64B40
39915	5	51	\N	2895	71138	\N	55.394979999999997	Кемеровская область, город Кемерово, Кировский район, Александрова, 3		0101000020E6100000D06394675E8155407B4963B48EB24B40
39901	5	51	\N	2895	71138	\N	55.397639000039803	Кемеровская область, город Кемерово, Кировский район, Александрова, 18		0101000020E610000068E90AB6118155409C4EB2D5E5B24B40
39964	5	51	\N	2895	49972	\N	55.355843	Кемеровская область, город Кемерово, Центральный район, А.К.Боброва, 2		0101000020E61000007B4963B48E86554059C16F438CAD4B40
40543	5	51	\N	2895	71148	\N	55.352670000000003	Кемеровская область, Осинниковский городской округ, 50 лет Октября, 8		0101000020E61000008C497F2F85855540E223624A24AD4B40
39900	5	51	\N	2895	71579	\N	55.390858999999999	Кемеровская область, город Кемерово, Кировский район, 40 лет Октября, 4		0101000020E610000030815B77F37F5540732CEFAA07B24B40
39897	5	51	\N	2895	71579	\N	55.389018	Кемеровская область, город Кемерово, Кировский район, 40 лет Октября, 18		0101000020E6100000C0594A969380554015C78157CBB14B40
39894	5	51	\N	2895	71579	\N	55.392291	Кемеровская область, город Кемерово, Кировский район, 40 лет Октября, 17В		0101000020E61000004966F50EB7805540F0C16B9736B24B40
39835	5	51	\N	2895	71662	\N	55.311964000000003	Кемеровская область, город Кемерово, Заводской район, 4-я Цветочная, 47		0101000020E610000062F8889812845540C2C3B46FEEA74B40
39834	5	51	\N	2895	76387	\N	55.311964000000003	Кемерово, Заводский район, ул,4-я Цветочная (здание школы-№68), д.47		0101000020E610000062F8889812845540C2C3B46FEEA74B40
39882	5	51	\N	2895	71642	\N	55.320678000000001	Кемеровская область, город Кемерово, Заводской район, 2-я Аральская, 2А		0101000020E61000008EB27E33317C5540FA4509FA0BA94B40
39803	5	51	\N	41201	76326	\N	53.514271368649901	652740, Кемеровская область, Калтанский городской округ, Мира проспект, 55 А	Россия, Кемеровская область, Калтан	0101000020E6100000B2632310AFD15540FF23D3A1D3C14A40
39797	5	51	\N	41201	76326	\N	53.539996233916497	652741, Кемеровская область, Калтанский городской округ, Мира проспект, 10	Россия, Кемеровская область, Калтан	0101000020E610000063B48EAA26D1554044FCC3961EC54A40
39794	5	51	\N	41201	76350	\N	53.541632274759799	652806, Кемеровская область, Калтанский городской округ, Спортивная, 14		0101000020E6100000EE77280AF4D05540C93B873254C54A40
39804	5	51	\N	41201	76296	\N	53.539167999999997	652740, Кемеровская область, Калтанский городской округ, Советский переулок, 9 А	Россия, Кемеровская область, Калтан	0101000020E6100000D00EB8AE98D055405D86FF7403C54A40
39752	5	51	\N	9765	50099	\N	55.619858999999998	Кемеровская область, город Березовский, Ленина п-т, 41		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39791	5	51	\N	41201	76404	\N	53.522284003591402	652816, Кемеровская область, Калтанский городской округ, Пожарского, 20	Россия, Кемеровская область, Калтан	0101000020E6100000FDF49F353FD15540AE9CBD33DAC24A40
39802	5	51	\N	41201	13461	\N	53.541077382039902	652740, Кемеровская область, Калтанский городской округ, Мира проспект, 55 а	Россия, Кемеровская область, Калтан	0101000020E6100000AA7D3A1E33D1554014CFD90242C54A40
39798	5	51	\N	41201	76303	\N	53.539167999999997	652740, Кемеровская область, Калтанский городской округ, Мира, 33 Б	Россия, Кемеровская область, Калтан	0101000020E6100000D00EB8AE98D055405D86FF7403C54A40
39796	5	51	\N	41201	76376	\N	53.540609756677398	652741, Кемеровская область, Калтанский городской округ, Комсомольская, 7	Россия, Кемеровская область, Калтан	0101000020E61000003CA06CCA15D15540FEF15EB532C54A40
39800	5	51	\N	41201	76305	\N	53.540088702274197	652740, Кемеровская область, Калтанский городской округ, Калинина, 40		0101000020E6100000698EACFC32D15540F5F6E7A221C54A40
39799	5	51	\N	41201	76305	\N	53.540405250082998	652740, Кемеровская область, Калтанский городской округ, Калинина, 38	Россия, Кемеровская область, Калтан	0101000020E610000017F4DE1802D1554025CCB4FD2BC54A40
39795	5	51	\N	41201	76347	\N	53.541300058959798	652809, Кемеровская область, Калтанский городской округ, Дзержинского, 3	Россия, Кемеровская область, Калтан	0101000020E6100000B459F5B9DACF554093A9825149C54A40
39792	5	51	\N	41201	76375	\N	53.540902235330698	652809, Кемеровская область, Калтанский городской округ, Дзержинского, 19	Россия, Кемеровская область, Калтан	0101000020E6100000A796ADF545D15540A62BD8463CC54A40
39809	5	51	\N	41201	76367	\N	53.536622000000001	652830, Кемеровская область, Калтанский городской округ, п. Малинова, 60 лет Октября, 20	Россия, Кемеровская область, Калтан	0101000020E61000002C47C8409ED0554035289A07B0C44A40
40987	5	51	\N	60760	75995	\N	53.784099112026901	пос. Ивановка, ул. Центральная, дом 8	Россия, Кемеровская область, поселок Ивановка	0101000020E6100000384BC97212C15540C4E9245B5DE44A40
41118	5	51	\N	37297	\N	\N	53.757807999999997	п.Загорский, 5А	Россия, Кемеровская область, поселок Загорский, 5а	0101000020E610000051DD5CFC6DC05540D65240DAFFE04A40
40899	5	51	\N	2542	50349	\N	55.300730999999999	Кемеровская область, Кемеровский район, с.Елыкаево, Клопова, 16		0101000020E6100000213A048E049055405AF2785A7EA64B40
41083	5	51	\N	59402	70728	\N	53.704743000000001	п.Елань, Победы, 14	Россия, Кемеровская область, поселок Елань, улица Победы, 14	0101000020E610000000C8091346D15540DF8AC40435DA4A40
40582	5	51	\N	59402	78010	\N	53.709594000000003	Кемеровская область, Прокопьевский городской округ, Рудничный район, Обручева, 50	Россия, Кемеровская область, поселок Елань, улица Обручева	0101000020E6100000D36BB3B112D155400BB8E7F9D3DA4A40
39788	5	51	\N	60719	75861	\N	54.285701830820997	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Мичурина, 11А		0101000020E61000001D041DAD6A7C55406E3315E291244B40
39768	5	51	\N	60719	75855	\N	54.286957266596403	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Мира, 1		0101000020E61000001DAA29C93A7C5540DC2DC901BB244B40
39772	5	51	\N	60719	75887	\N	54.285199645748101	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Ленина, 30		0101000020E6100000A67EDE54A47C5540DC68006F81244B40
39775	5	51	\N	60719	75898	\N	54.281205093751403	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Гагарина, 1	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000B5C2F4BD867D5540603C8386FE234B40
39787	5	51	\N	60719	75736	\N	54.286277374430902	Кемеровская область, Гурьевский район, Гурьевское городское поселение, 7 Ноября, 15		0101000020E6100000003620425C7C55406A4C88B9A4244B40
39757	5	51	\N	9765	\N	\N	55.619858999999998	"Кемеровская область, город Березовский, Здание детского сада ""Родничок"""		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39733	5	51	\N	9765	50552	\N	55.617884263068902	Кемеровская область, Березовский городской округ, Карбышева, 8	Россия, Кемеровская область, Березовский	0101000020E61000007EE5417A8A9055405F5CAAD216CF4B40
39734	5	51	\N	9765	49963	\N	55.619858999999998	Кемеровская область, город Березовский, Школьная, 5		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39742	5	51	\N	9765	13289	\N	55.616121059604502	Кемеровская область, город Березовский, Шахтеров п-т, 14	Россия, Кемеровская область, Березовский	0101000020E6100000583B8A73D49055407DB08C0DDDCE4B40
39727	5	51	\N	9765	50089	\N	55.619858999999998	Кемеровская область, город Березовский, Чехова, 10		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39728	5	51	\N	9765	12361	\N	55.618064041783803	Кемеровская область, город Березовский, Советская, 5	Россия, Кемеровская область, Березовский	0101000020E6100000465B9544F68F5540DF6A9DB81CCF4B40
39723	5	51	\N	9765	75970	\N	55.586979247499201	Кемеровская область, Березовский городской округ, Резвых, 34	Россия, Кемеровская область, Березовский	0101000020E6100000C347C494488D55402A38BC2022CB4B40
39740	5	51	\N	9765	50284	\N	55.619858999999998	Кемеровская область, город Березовский, Молодежный б-р, 19		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39738	5	51	\N	9765	50096	\N	55.619858999999998	Кемеровская область, город Березовский, Мира, 46		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39737	5	51	\N	9765	50096	\N	55.619858999999998	Кемеровская область, город Березовский, Мира, 13		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39756	5	51	\N	9765	50031	\N	55.619858999999998	Кемеровская область, город Березовский, пос.Барзас, Мира, 3		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
40863	5	51	\N	9765	76060	\N	55.619858999999998	п.Березовский, ул.Механическая, д.17	Россия, Кемеровская область, Березовский	0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39750	5	51	\N	9765	50030	\N	55.619858999999998	Кемеровская область, город Березовский, Ленина проспект, 66		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39751	5	51	\N	9765	50099	\N	55.619858999999998	Кемеровская область, город Березовский, Ленина п-т, 66		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39746	5	51	\N	9765	50099	\N	55.619858999999998	Кемеровская область, город Березовский, Ленина п-т, 20		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39736	5	51	\N	9765	75972	\N	55.619858999999998	Кемеровская область, город Березовский, Ермака, 1		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39754	5	51	\N	9765	50102	\N	55.619858999999998	Кемеровская область, город Березовский, Волкова, 5а		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39731	5	51	\N	9765	13319	\N	55.617286860516501	Кемеровская область, город Березовский, Больничная, 2	Россия, Кемеровская область, Березовский	0101000020E61000007DE71725E89055407B9FAA4203CF4B40
39724	5	51	\N	9765	50279	\N	55.619858999999998	Кемеровская область, город Березовский, А.Лужбина, 17		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39744	5	51	\N	9765	50029	\N	55.619858999999998	Кемеровская область, город Березовский, 8 Марта, 14		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39748	5	51	\N	9765	49965	\N	55.619858999999998	Кемеровская область, город Березовский, 40 лет Победы, 3		0101000020E61000004B94BDA59C8F5540CD902A8A57CF4B40
39685	5	51	\N	60701	75651	\N	54.3659080381398	Кемеровская область, Беловский городской округ, мкрн Бабанаково, Хмельницкого, 49	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000460C3B8C4997554021ACC612D62E4B40
39682	5	51	\N	60701	75587	\N	54.386797225989703	Кемеровская область, Беловский городской округ, мкрн Бабанаково, Тимирязева ул, 30	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000A2B3CC22149555407098689082314B40
39697	5	51	\N	60701	75733	\N	54.305226371598998	Кемеровская область, Беловский городской округ, пгт Новый Городок, Киевская, 50А		0101000020E610000053944BE317935540C7F143A511274B40
41077	5	51	\N	52146	71392	\N	53.784241000000002	с.Атаманово, Центральная, 99Б	Россия, Кемеровская область, село Атаманово, Центральная улица, 99б	0101000020E610000043E6CAA0DAD855405797530262E44A40
39653	5	51	\N	41109	76369	\N	56.080167546796403	Кемеровская область, Анжеро-Судженский городской округ, Ленина, 18а	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000006DACC43C2B815540C617EDF1420A4C40
39609	5	51	\N	41109	76269	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, переулок Силовой, 1	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39636	5	51	\N	41109	76363	\N	56.089295231481302	Кемеровская область, Анжеро-Судженский городской округ, Школьная, 23		0101000020E6100000BD1B0B0A838255402159C0046E0B4C40
39602	5	51	\N	41109	76395	\N	56.097447000000003	Кемеровская область, Анжеро-Судженский городской округ, Челинская, 18	Россия, Кемеровская область, Анжеро-Судженск	0101000020E610000068075C57CC815540F20BAF24790C4C40
39658	5	51	\N	41109	13658	\N	56.077093564685299	Кемеровская область, Анжеро-Судженский городской округ, Чекистов, 1	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000008445459C4E815540E25B5837DE094C40
39648	5	51	\N	41109	76331	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Фестивальная, 1а	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39622	5	51	\N	41109	76339	\N	56.083872497592303	Кемеровская область, Анжеро-Судженский городской округ, Угольная, 22	Россия, Кемеровская область, Анжеро-Судженск	0101000020E610000070B54E5C8E8155406A865451BC0A4C40
39654	5	51	\N	41109	76380	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Солнечная, 2	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39611	5	51	\N	41109	12929	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Силовой, 1	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39651	5	51	\N	41109	76234	\N	56.081952762063501	Кемеровская область, Анжеро-Судженский городской округ, Семеновка, 43	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000E4DC26DC2B8255409067976F7D0A4C40
39646	5	51	\N	41109	76225	\N	56.0921262658077	Кемеровская область, Анжеро-Судженский городской округ, Северная, 31	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000008527F4FA938155403F8EE6C8CA0B4C40
39644	5	51	\N	41109	76249	\N	56.0794569622634	Кемеровская область, Анжеро-Судженский городской округ, Рабиновича, 25	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000342F87DD778155401938A0A52B0A4C40
39606	5	51	\N	41109	76356	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, ул.Прокопьевская, 18а	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39613	5	51	\N	41109	76274	\N	56.085888116514099	Кемеровская область, Анжеро-Судженский городской округ, Перовская, 27	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000009607E92972825540368FC360FE0A4C40
39632	5	51	\N	41109	76270	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Новобольничная, 79	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39642	5	51	\N	41109	76355	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Мира, 7		0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39640	5	51	\N	41109	76355	\N	56.109734657915801	Кемеровская область, Анжеро-Судженский городской округ, Мира, 4		0101000020E610000072512D228A815540001DE6CB0B0E4C40
39619	5	51	\N	41109	76333	\N	56.089439187421803	Кемеровская область, Анжеро-Судженский городской округ, Милицейская, 64	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000331AF9BCE281554054FEB5BC720B4C40
39659	5	51	\N	41109	76360	\N	56.086799909330999	Кемеровская область, Анжеро-Судженский городской округ, Менделеева, 73	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000022EC896E58255407AA52C431C0B4C40
39600	5	51	\N	41109	76379	\N	56.091550479144502	Кемеровская область, Анжеро-Судженский городской округ, Львовская, 13	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000FA635A9BC681554072F90FE9B70B4C40
39641	5	51	\N	41109	76374	\N	56.080176921174498	Кемеровская область, Анжеро-Судженский городской округ, Ленина, 15	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000000B2593533B81554019726C3D430A4C40
39627	5	51	\N	41109	76374	\N	56.093469734405303	Кемеровская область, Анжеро-Судженский городской округ, Ленина, 10	Россия, Кемеровская область, Анжеро-Судженск	0101000020E610000049A12C7C7D8155401D9430D3F60B4C40
39639	5	51	\N	41109	76265	\N	56.077345004857499	Кемеровская область, Анжеро-Судженский городской округ, пер.Лебедянский, 38	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000000D1B65FD668155402BC1E270E6094C40
39623	5	51	\N	41109	13496	\N	56.077285566874501	Кемеровская область, Анжеро-Судженский городской округ, Куйбышева, 48	Россия, Кемеровская область, Анжеро-Судженск	0101000020E610000082751C3F548155402638F581E4094C40
39633	5	51	\N	41109	76223	\N	56.091838373556598	Кемеровская область, Анжеро-Судженский городской округ, Кубанская, 3	Россия, Кемеровская область, Анжеро-Судженск	0101000020E610000022E010AAD4815540D943FB58C10B4C40
39643	5	51	\N	41109	76397	\N	56.121575721449702	Кемеровская область, Анжеро-Судженский городской округ, Коминтерна, 9	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000001ADF1797AA8155403FFD67CD8F0F4C40
39638	5	51	\N	41109	76240	\N	56.082723761141501	Кемеровская область, Анжеро-Судженский городской округ, Китатская, 15а	Россия, Кемеровская область, Анжеро-Судженск	0101000020E610000088F71C588E815540124C35B3960A4C40
39605	5	51	\N	41109	76362	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Киселевская, 11А	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39620	5	51	\N	41109	12498	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Кемсеть, 16	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39629	5	51	\N	41109	76402	\N	56.130347904925401	Кемеровская область, Анжеро-Судженский городской округ, Маркса, 1	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000ABB019E082825540AC8C463EAF104C40
39631	5	51	\N	41109	13542	\N	56.076901561535301	Кемеровская область, Анжеро-Судженский городской округ, Динамитная, 33	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000CE88D2DEE08155409D7FBBECD7094C40
39603	5	51	\N	41109	76319	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Гурьевская, 3	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39628	5	51	\N	41109	76325	\N	56.092576467977501	Кемеровская область, Анжеро-Судженский городской округ, Горького, 30	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000002FFB75A73B8155407F32C687D90B4C40
39650	5	51	\N	41109	76359	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Гайдара, 50	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39614	5	51	\N	41109	76361	\N	56.079264970939001	Кемеровская область, Анжеро-Судженский городской округ, Гагарина, 3	Россия, Кемеровская область, Анжеро-Судженск	0101000020E61000000C06D7DCD1815540D55B035B250A4C40
39617	5	51	\N	41109	76304	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Восстания, 80	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39626	5	51	\N	41109	76294	\N	56.076000971440102	Кемеровская область, Анжеро-Судженский городской округ, Войкова, 39	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000228D0A9C6C8155404DBB9866BA094C40
39647	5	51	\N	41109	12810	\N	56.075718114661598	Кемеровская область, Анжеро-Судженский городской округ, Водоканальная, 53	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000069CA56439815540F9DB9E20B1094C40
39599	5	51	\N	41109	12810	\N	56.076768996299897	Кемеровская область, Анжеро-Судженский городской округ, Водоканальная, 29а	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000342F87DD778155405E2C0C91D3094C40
39624	5	51	\N	41109	76228	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, Ванцетти, 6	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39616	5	51	\N	41109	76310	\N	56.084213034395503	Кемеровская область, Анжеро-Судженский городской округ, Бийская, 64	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000D174763238825540F372D87DC70A4C40
39612	5	51	\N	41109	76327	\N	56.071776559946102	Кемеровская область, Анжеро-Судженский городской округ, Матросова, 107		0101000020E610000010EB8D5A6181554070CD1DFD2F094C40
39660	5	51	\N	41109	76237	\N	56.086947000000002	Кемеровская область, Анжеро-Судженский городской округ, 6 пер. У.Громовой, 1	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000A911FA997A8255401FBE4C14210B4C40
39645	5	51	\N	41109	76390	\N	56.086847897826303	Кемеровская область, Анжеро-Судженский городской округ, им.137 Отд.Стр.Бригады, 7		0101000020E6100000EB538EC9E28255408CDCD3D51D0B4C40
39656	5	51	\N	41109	76288	\N	56.076576991525997	Кемеровская область, Анжеро-Судженский городской округ, 137 ОСБ, 2	Россия, Кемеровская область, Анжеро-Судженск	0101000020E6100000AD50A4FB398155401A506F46CD094C40
40517	5	51	1434	41089	12409	\N	53.692727609416103	Кемеровская область, Осинниковский городской округ, поселок Тайжина, Коммунистическая, 43	Россия, Кемеровская область, городской округ Осинники, поселок Тайжина	0101000020E6100000CA501553E9DB55400283A44FABD84A40
40518	5	51	1434	16092	50338	\N	53.690995553662098	Кемеровская область, Осинниковский городской округ, поселок Тайжина, Дорожная, 2	Россия, Кемеровская область, городской округ Осинники, поселок Тайжина	0101000020E610000040A20914B1DB55405AD5928E72D84A40
40270	5	51	640	41161	13267	\N	53.596080530075902	652840, Кемеровская область, Мысковский городской округ, Чувашка поселок, ул. Алтын Шор, (клуб), д. 4	Россия, Кемеровская область, городской округ Мыски, поселок Чувашка	0101000020E610000023F609A018F455402C62D8614CCC4A40
40281	5	51	640	4783	76258	\N	53.743236000000003	652840, Кемеровская область, Мысковский городской округ, поселок Бородино, ул. Бородинская, (школа №10), д.1		0101000020E6100000217365506DF05540DD9A745B22DF4A40
41589	5	51	574	4229	75827	\N	55.873353999999999	Кемеровская область, Яшкинский район, п.Яшкинский, Осенняя, 6		0101000020E6100000B81D1A16A359554057EA5910CAEF4B40
41578	5	51	574	3580	50368	\N	55.879581000000002	Кемеровская область, Яшкинский район, пгт.Яшкино, Ленинская, 4		0101000020E610000059A31EA2D15B55406C97361C96F04B40
41576	5	51	574	3580	13633	\N	55.879099098420703	Кемеровская область, Яшкинский район, пгт.Яшкино, Куйбышева, 11а	Россия, Кемеровская область, Яшкинский район, поселок Яшкино	0101000020E6100000D2C43BC0935B55402079E75086F04B40
41577	5	51	574	3580	50367	\N	55.879581000000002	Кемеровская область, Яшкинский район, пгт.Яшкино, Комарова, 24		0101000020E610000059A31EA2D15B55406C97361C96F04B40
41579	5	51	574	3580	50365	\N	55.879581000000002	Кемеровская область, Яшкинский район, пгт.Яшкино, Заводская, 16		0101000020E610000059A31EA2D15B55406C97361C96F04B40
41583	5	51	574	3580	75818	\N	55.879581000000002	Кемеровская область, Яшкинский район, пгт.Яшкино, Больничная, 16		0101000020E610000059A31EA2D15B55406C97361C96F04B40
41581	5	51	574	3580	76147	\N	55.879581000000002	Кемеровская область, Яшкинский район, пгт.Яшкино, 50 лет Советской власти, 6		0101000020E610000059A31EA2D15B55406C97361C96F04B40
41580	5	51	574	41157	13124	\N	55.871282123589502	Кемеровская область, Яшкинский район, пгт.Яшкино, Вторая, 9	Россия, Кемеровская область, Яшкинский район, поселок Яшкино	0101000020E61000009259BDC3ED5B5540F7CB272B86EF4B40
41598	5	51	574	4714	76015	\N	56.067991999999997	Кемеровская область, Яшкинский район, д.Юрты-Константиновы, братьев Сидельниковых, 16		0101000020E6100000855CA967413D5540DF313CF6B3084C40
41615	5	51	574	41094	12429	\N	55.813611999999999	Кемеровская область, Яшкинский район, п.Шахтер, Новая, 1		0101000020E6100000E29178793A4855400BD1217024E84B40
41593	5	51	574	60778	76180	\N	55.941704843808502	Кемеровская область, Яшкинский район, п.ст.Хопкино, Железнодорожная, 23		0101000020E610000035423F53AF5C554066BD18CA89F84B40
41613	5	51	574	5537	76154	\N	55.755949513100397	Кемеровская область, Яшкинский район, ст.Тутальская, М.Ракевича, 68а	Россия, Кемеровская область, Яшкинский район, поселок Тутальская	0101000020E6100000B7B24467993F5540A2B437F8C2E04B40
41614	5	51	574	41092	12421	\N	55.962634000000001	Кемеровская область, Яшкинский район, с.Таловка, Школьная, 13д		0101000020E6100000E97E4E417E7555404302469737FB4B40
41597	5	51	574	4680	76150	\N	55.927799397183897	Кемеровская область, Яшкинский район, д.Соломатово, пер.Школьный, 1	Россия, Кемеровская область, Яшкинский район, поселок Соломатово	0101000020E6100000DFFE5C346441554079211D1EC2F64B40
41609	5	51	574	5278	76151	\N	56.043593000000001	Кемеровская область, Яшкинский район, д.Северная, Верхняя, 14а		0101000020E6100000B9FDF2C98A545540D2AA967494054C40
41610	5	51	574	5368	75825	\N	55.744413999999999	Кемеровская область, Яшкинский район, с.Поломошное, Бениваленского, 18		0101000020E61000008B1BB7989F3D55409F573CF548DF4B40
41612	5	51	574	5368	75823	\N	55.744413999999999	Кемеровская область, Яшкинский район, с.Поломошное, Базарная, 15а		0101000020E61000008B1BB7989F3D55409F573CF548DF4B40
41608	5	51	574	5265	75826	\N	56.050938000000002	Кемеровская область, Яшкинский район, с.Пашково, Леонова, 11а		0101000020E610000038F3AB3940485540D40FEA2285064C40
41605	5	51	574	5105	75820	\N	55.704751999999999	Кемеровская область, Яшкинский район, с.Пача, Ленина, 14а		0101000020E6100000BFF1B567965F554032E5435035DA4B40
41224	5	51	574	46461	\N	\N	55.778081999999998	пос.Октябрьский, сельский клуб пос.Октябрьский		0101000020E6100000242A5437174755409ACDE33098E34B40
41587	5	51	574	4096	76003	\N	55.670549000000001	Кемеровская область, Яшкинский район, д.Нижняя Тайменка, Кирпичная, 3-2		0101000020E61000000893E2E3134E5540C9AEB48CD4D54B40
41607	5	51	574	5188	76157	\N	55.825488158279299	Кемеровская область, Яшкинский район, д.Нижнеяшкино, Солнечная, 1	Россия, Кемеровская область, Яшкинский район, поселок Нижнеяшкино	0101000020E6100000F372D87DC75E5540C79E3D97A9E94B40
41616	5	51	574	5674	76164	\N	55.836989000000003	Кемеровская область, Яшкинский район, д.Мохово, Центральная, 23-2		0101000020E61000009D4830D5CC3C55404E0E9F7422EB4B40
41606	5	51	574	5118	76153	\N	55.705640000000002	Кемеровская область, Яшкинский район, д.Морковкино, Молодежная, 16		0101000020E610000015562AA8A8675540EE5F596952DA4B40
41603	5	51	574	4982	76155	\N	55.832130999999997	Кемеровская область, Яшкинский район, д.Литвиново, Строительная, 5		0101000020E6100000166C239EEC5255406F7EC34483EA4B40
41599	5	51	574	4982	75845	\N	55.833435245170101	Кемеровская область, Яшкинский район, п.ст.Литвиново, Октябрьская, 26а	Россия, Кемеровская область, Яшкинский район, поселок Литвиново	0101000020E61000009EB29AAE27535540BF2B82FFADEA4B40
41595	5	51	574	4547	76156	\N	56.025266000000002	Кемеровская область, Яшкинский район, п.Ленинский, Больничная, 2		0101000020E6100000C59272F739445540B2D991EA3B034C40
40490	5	51	38	6960	12372	\N	55.724549498718297	Кемеровская область, город Юрга, Кирова, 7	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000FED64E94843A5540BDAC8905BEDC4B40
41596	5	51	574	4614	76148	\N	55.891996421621997	Кемеровская область, Яшкинский район, д.Кулаково, Береговая, 19	Россия, Кемеровская область, Яшкинский район, поселок Кулаково	0101000020E6100000A243E048A0415540D714C8EC2CF24B40
41602	5	51	574	4936	75828	\N	55.866049378960099	Кемеровская область, Яшкинский район, с.Красноселка, Мира, 1	Россия, Кемеровская область, Яшкинский район, поселок Красноселка	0101000020E6100000C780ECF5EE4D5540E3DD91B1DAEE4B40
41601	5	51	574	41083	12396	\N	55.8006393294839	Кемеровская область, Яшкинский район, д.Корчуганово, Клубная, 5а	Россия, Кемеровская область, Яшкинский район, поселок Корчуганово	0101000020E61000008C31B08EE35055407973B8567BE64B40
41594	5	51	574	4508	50079	\N	55.638145000000002	Кемеровская область, Яшкинский район, с.Колмогорово, мкр.Молодежный, 5		0101000020E6100000354069A8516A55408F8D40BCAED14B40
41586	5	51	574	4083	76143	\N	55.717689999999997	Кемеровская область, Яшкинский район, д.Зырянка, Центральная, 19а		0101000020E6100000CDEA1D6E874E554047551344DDDB4B40
41592	5	51	574	4395	76149	\N	55.922519999999999	Кемеровская область, Яшкинский район, п.Дубровка, 40 лет Победы, 11б		0101000020E6100000F38DE89E75565540F5F3A62215F64B40
41585	5	51	574	3973	76011	\N	55.754669	Кемеровская область, Яшкинский район, д.Власково, Центральная, 17		0101000020E6100000F4DE1802805A55400B2769FE98E04B40
41591	5	51	574	41164	13275	\N	55.935495132160597	Кемеровская область, Яшкинский район, д.Ботьево, Победы, 19	Россия, Кемеровская область, Яшкинский район, поселок Ботьево	0101000020E61000002A013109174F55402849D74CBEF74B40
41600	5	51	574	4841	13315	\N	55.8989387502452	Кемеровская область, Яшкинский район, д.Балахнино, Центральная, 22	Россия, Кемеровская область, Яшкинский район, поселок Балахнино	0101000020E6100000F8DEDFA0BD4E5540AA0CE36E10F34B40
41584	5	51	574	3965	75764	\N	55.735449000000003	Кемеровская область, Яшкинский район, п.Акация, Мира, 6		0101000020E6100000F583BA48A15755401E705D3123DE4B40
41536	5	51	236	1276	76146	\N	56.273850000000003	Кемеровская область, Яйский район, Бекетское сельское поселение, село Яя-Борик, Центральная, 69		0101000020E610000042B115342D9D55403B014D840D234C40
41562	5	51	236	41150	75839	\N	56.236291000000001	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Юбилейный, 12		0101000020E6100000A0C1A6CEA385554069AB92C83E1E4C40
41565	5	51	236	41150	13027	\N	56.203676580755001	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Августовская, 11	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E61000002FDCB930D29C554044F98216121A4C40
41570	5	51	236	41250	75892	\N	56.206068616522202	Кемеровская область, Яйский муниципальный район, Яйское городское поселение, пгт.Яя, Ленина, 7		0101000020E6100000444E5FCFD79C554016DC0F78601A4C40
41563	5	51	236	41250	76145	\N	56.194968305260701	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Юбилейный, 3	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E6100000FC34EECD6F9B55401EE21FB6F4184C40
41561	5	51	236	41250	75862	\N	56.204537730890998	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Юбилейная, 43	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E6100000BA9F53909F9C554006651A4D2E1A4C40
41568	5	51	236	41250	75616	\N	56.201093013840101	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Школьная, 5	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E6100000E6ADBA0ED59B55402E3A596ABD194C40
41560	5	51	236	41250	75784	\N	56.190039115769302	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Трактовая, 160	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E61000003882548A1D9B554076FBAC3253184C40
41566	5	51	236	41250	13609	\N	56.206560180001397	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Пионерская, 7	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E6100000E42F2DEA939C5540B554DE8E701A4C40
41575	5	51	236	41250	76152	\N	56.209130203684602	Кемеровская область, Яйский муниципальный район, Яйское городское поселение, пгт.Яя, переулок Логовой, 20	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E61000000ED76A0F7B9B5540664E97C5C41A4C40
41572	5	51	236	41250	75858	\N	56.206068616522202	Кемеровская область, Яйский муниципальный район, Яйское городское поселение, пгт.Яя, Осоавиахимовская, 4		0101000020E6100000BD6F7CED999C554016DC0F78601A4C40
41569	5	51	236	41250	75858	\N	56.209895562122099	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Осоавиахимовская, 36А	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E61000005CFFAECF9C9B5540D6C743DFDD1A4C40
41567	5	51	236	41250	76218	\N	56.206068616522202	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Озерная, 3	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E6100000CEFC6A0E109D554016DC0F78601A4C40
41571	5	51	236	41250	75902	\N	56.2028154112013	Кемеровская область, Яйский муниципальный район, Яйское городское поселение, пгт.Яя, Ленина, 9	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E610000059C0046EDD9C5540B21188D7F5194C40
41564	5	51	236	41250	76206	\N	56.203389526394602	Кемеровская область, Яйский район, Яйское городское поселение, пгт.Яя, Западная, 76	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E6100000705CC64D0D9C5540AE2AFBAE081A4C40
41573	5	51	236	41250	76160	\N	56.1964995744679	Кемеровская область, Яйский муниципальный район, Яйское городское поселение, пгт.Яя, Жуковского, 17	Россия, Кемеровская область, Яйский район, поселок Яя	0101000020E6100000D40B3ECDC99B5540FED478E926194C40
41534	5	51	236	1163	13552	\N	56.179572387621398	Кемеровская область, Яйский муниципальный район, Безлесное сельское поселение, поселок Щербиновка, Пролетарская, 18	Россия, Кемеровская область, Яйский район, поселок Щербиновка	0101000020E610000021AD31E8847E55407FA31D37FC164C40
41557	5	51	236	2454	75822	\N	56.407018999999998	Кемеровская область, Яйский муниципальный район, Улановское сельское поселение, село Улановка, Ленина, 109		0101000020E6100000C8B5A1629C865540E1ECD63219344C40
41544	5	51	236	1738	13578	\N	56.084044500456798	Кемеровская область, Яйский муниципальный район, Дачно-Троицкое сельское поселение, поселок Турат, Майская, 1А	Россия, Кемеровская область, Яйский район, поселок Турат	0101000020E610000010EA2285B28B554038328FFCC10A4C40
41555	5	51	236	2343	76144	\N	56.182622000000002	Кемеровская область, Яйский муниципальный район, Судженское сельское поселение, село Судженка, Советская, 61А		0101000020E6100000685DA3E540905540DBC35E2860174C40
41543	5	51	236	2343	75844	\N	56.110570000000003	Кемеровская область, Яйский муниципальный район, Дачно-Троицкое сельское поселение, поселок станция Судженка, Механическая, 8	Россия, Кемеровская область, Яйский район	0101000020E61000008D63247B848A554099F56228270E4C40
41541	5	51	236	1526	76132	\N	56.267736999999997	Кемеровская область, Яйский муниципальный район, Вознесенское сельское поселение, деревня Соболинка, Таёжная, 31-2		0101000020E610000090696D1ADB785540EE76BD3445224C40
41551	5	51	236	2108	76134	\N	56.384998000000003	Кемеровская область, Яйский муниципальный район, Марьевское сельское поселение, деревня Сергеевка, Сибирская, 29А		0101000020E610000035EECD6F9896554041834D9D47314C40
39657	5	51	236	6230	76251	\N	56.085411309975299	Кемеровская область, Анжеро-Судженский городской округ,р.п.Рудничный, Металлургов,, 2а	Россия, Кемеровская область, Яйский район, поселок Рудничный	0101000020E6100000390B7BDAE18F5540FDDB65BFEE0A4C40
41556	5	51	236	2444	13595	\N	56.227745306430997	Кемеровская область, Яйский муниципальный район, Судженское сельское поселение, деревня Ольговка, Октябрьская, 3	Россия, Кемеровская область, Яйский район, поселок Ольговка	0101000020E6100000923B6C2233975540EC6987BF261D4C40
41533	5	51	236	1060	76014	\N	56.178142000000001	Кемеровская область, Яйский муниципальный район, Безлесное сельское поселение, поселок Новостройка, Гагарина, 13		0101000020E6100000E7559DD502875540A305685BCD164C40
41547	5	51	236	1862	75834	\N	56.168610999999999	Кемеровская область, Яйский муниципальный район, Китатское сельское поселение, село Новониколаевка, Школьная, 38		0101000020E61000008847E2E5E99D5540785F950B95154C40
41542	5	51	236	1631	13576	\N	56.238064965374299	Кемеровская область, Яйский муниципальный район, Вознесенское сельское поселение, деревня Назаровка, Школьная, 6	Россия, Кемеровская область, Яйский район, поселок Назаровка	0101000020E61000004721C9ACDE7955403FA9F6E9781E4C40
41086	5	51	236	48283	76055	\N	56.273510000000002	д.Михайловка, Зеленая, 5А		0101000020E610000023861DC6A473554082902C6002234C40
41559	5	51	236	2569	76137	\N	56.526805000000003	Кемеровская область, Яйский муниципальный район, Улановское сельское поселение, деревня Медведчиково, Центральная, 23		0101000020E610000048348122168C5540452FA3586E434C40
41550	5	51	236	2094	76139	\N	56.294905999999997	Кемеровская область, Яйский муниципальный район, Марьевское сельское поселение, деревня Марьевка, Школьная, 4А		0101000020E6100000950C0055DC98554074B2D47ABF254C40
41549	5	51	236	1989	76133	\N	56.120136000000002	Кемеровская область, Яйский муниципальный район, Китатское сельское поселение, село Мальцево, Набережная, 20		0101000020E6100000F5F1D077B79C55404089CF9D600F4C40
41531	5	51	236	937	76140	\N	56.1757129477162	Кемеровская область, Яйский район, Безлесное сельское поселение, поселок Майский, Героев Соцтруда, 32	Россия, Кемеровская область, Яйский район, поселок Майский	0101000020E61000000ED76A0F7B8A5540B43D7AC37D164C40
39634	5	51	236	60802	76284	\N	56.112704961100697	Кемеровская область, Анжеро-Судженский городской округ, пос.Красная Горка, Тепличная, 8	Россия, Кемеровская область, Яйский район, поселок Красная Горка	0101000020E610000093567C43E18255403F8C101E6D0E4C40
41545	5	51	236	1757	75817	\N	56.227870000000003	Кемеровская область, Яйский муниципальный район, Кайлинское сельское поселение, село Кайла, Садовая, 6		0101000020E61000001D76DF313C855540A9DE1AD82A1D4C40
41558	5	51	236	2550	\N	\N	56.512255000000003	Кемеровская область, Яйский муниципальный район, Улановское сельское поселение, село Ишим, Молодёжная, 29	Россия, Кемеровская область, Яйский район, поселок Ишим	0101000020E6100000B743C362D48D5540331B649291414C40
41540	5	51	236	1503	76138	\N	56.379007999999999	Кемеровская область, Яйский муниципальный район, Вознесенское сельское поселение, деревня Емельяновка, Центральная, 1		0101000020E6100000A5D76663257A554010768A5583304C40
41546	5	51	236	1845	76136	\N	56.297133000000002	Кемеровская область, Яйский муниципальный район, Кайлинское сельское поселение, деревня Данковка, Советская, 46		0101000020E6100000FA28232E00875540FCC7427408264C40
41539	5	51	236	1402	13562	\N	56.320661054644198	Кемеровская область, Яйский муниципальный район, Вознесенское сельское поселение, село Вознесенка, Центральная, 20	Россия, Кемеровская область, Яйский район, поселок Вознесенка	0101000020E610000003CFBD874B7D5540240D6E6B0B294C40
41538	5	51	236	1398	76131	\N	56.425207999999998	Кемеровская область, Яйский муниципальный район, Бекетское сельское поселение, село Верх-Великосельское, Советская, 27		0101000020E6100000EE96E4805D975540B0FF3A376D364C40
41537	5	51	236	1310	76142	\N	56.360866000000001	Кемеровская область, Яйский муниципальный район, Бекетское сельское поселение, село Бекет, Центральная, 6		0101000020E6100000F6ED2422FC9D5540821E6ADB302E4C40
41530	5	51	236	928	13548	\N	56.144497438897098	Кемеровская область, Яйский район, Безлесное сельское поселение, поселок Безлесный, Ленинградская, 9	Россия, Кемеровская область, Яйский район, поселок Безлесный	0101000020E6100000CAC16C020C87554060AFB0E07E124C40
41554	5	51	236	41131	12606	\N	56.314791	Кемеровская область, Яйский муниципальный район, Марьевское сельское поселение, деревня Арышево, Арышева, 35		0101000020E6100000FDBE7FF3E29855409E094D124B284C40
41507	5	51	38	41105	\N	\N	55.690429496130598	Кемеровская область, Юргинский район, пос. Юргинский, Дом Культуры	Россия, Кемеровская область, Юргинский район, поселок Юргинский	0101000020E6100000815CE2C803295540E19A3BFA5FD84B40
41503	5	51	38	41148	\N	\N	55.670247274686197	Кемеровская область, Юргинский район, пос. ст. Юрга-2, Дом культуры	Россия, Кемеровская область, Юргинский район, поселок Юрга II	0101000020E610000057CF49EF1B315540FE9E58A7CAD54B40
41501	5	51	38	41148	\N	\N	55.6732656684582	Кемеровская область, Юргинский район, пос. ст. Юрга-2, школа	Россия, Кемеровская область, Юргинский район, поселок Юрга II	0101000020E610000068B0A9F3A83155401EC18D942DD64B40
40757	5	51	38	6960	12453	\N	55.723652999999999	Кемеровская область, город Юрга, пр.Победы, 15а		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40744	5	51	38	6960	12453	\N	55.720189585364103	Кемеровская область, город Юрга, пр.Победы, 38б	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000F88903E8F73A55400074982F2FDC4B40
40735	5	51	38	6960	12453	\N	55.719802013852799	Кемеровская область, город Юрга, пр.Победы, 4б	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000FB592C45F23A554036CCD07822DC4B40
40734	5	51	38	6960	12453	\N	55.723652999999999	Кемеровская область, город Юрга, пр.Победы, 10в		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40729	5	51	38	6960	12453	\N	55.723652999999999	Кемеровская область, город Юрга, пр.Победы, 4в		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40746	5	51	38	6960	13446	\N	55.723290018404903	Кемеровская область, город Юрга, пр.Кузбасский, 14а	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000AF7AC03C643A55400DC347C494DC4B40
40752	5	51	38	6960	12483	\N	55.723652999999999	Кемеровская область, город Юрга, б-р Металлургов, 5а		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40748	5	51	38	6960	12483	\N	55.720577153012897	Кемеровская область, город Юрга, б-р Металлургов, 2а	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000F88903E8F73A5540F99FFCDD3BDC4B40
40766	5	51	38	6960	50151	\N	55.723652999999999	Кемеровская область, город Юрга, Шоссейная, 100		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40742	5	51	38	6960	12472	\N	55.723652999999999	Кемеровская область, город Юрга, Фестивальная, 7		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40739	5	51	38	6960	12472	\N	55.723652999999999	Кемеровская область, город Юрга, Фестивальная, 3а		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40763	5	51	38	6960	50063	\N	55.723652999999999	Кемеровская область, город Юрга, Строительная, 25		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40765	5	51	38	6960	50346	\N	55.723652999999999	Кемеровская область, город Юрга, Осенняя, 54		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40754	5	51	38	6960	50345	\N	55.723652999999999	Кемеровская область, город Юрга, Никитина, 30		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40764	5	51	38	6960	12523	\N	55.723652999999999	Кемеровская область, город Юрга, Московская, 55		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40761	5	51	38	6960	12523	\N	55.723652999999999	Кемеровская область, город Юрга, Московская, 33		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40759	5	51	38	6960	12523	\N	55.718639276143598	Кемеровская область, город Юрга, Московская, 35	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000AD31E884D03A5540A950DD5CFCDB4B40
40756	5	51	38	6960	12523	\N	55.723096248581903	Кемеровская область, город Юрга, Московская, 50	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E61000004F9143C4CD39554028EFE3688EDC4B40
40755	5	51	38	6960	12523	\N	55.719414438478999	Кемеровская область, город Юрга, Московская, 48	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E61000004CC11A67D33955406C2409C215DC4B40
40733	5	51	38	6960	13404	\N	55.724065088041002	Кемеровская область, город Юрга, Мира, 11б	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000E964A9F57E3A5540D1967329AEDC4B40
40750	5	51	38	6960	50344	\N	55.723652999999999	Кемеровская область, город Юрга, Машиностроителей, 45а		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40720	5	51	38	6960	12437	\N	55.723652999999999	Кемеровская область, город Юрга, Леонова, 12		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40722	5	51	38	6960	50084	\N	55.723652999999999	Кемеровская область, город Юрга, Ленинградская, 10		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40718	5	51	38	6960	50084	\N	55.723652999999999	Кемеровская область, город Юрга, Ленинградская, 27		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40684	5	51	38	6960	12379	\N	55.724355735171599	Кемеровская область, город Юрга, Ленина, 97	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E6100000FB0626378A3A5540A85489B2B7DC4B40
39664	5	51	38	6960	12379	\N	55.723652999999999	Кемеровская область, город Юрга, Ленина, 55а		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40767	5	51	38	6960	69787	\N	55.723096248581903	Кемеровская область, город Юрга, Колхозная, 21		0101000020E61000002383DC45983A554028EFE3688EDC4B40
40731	5	51	38	6960	12372	\N	55.723652999999999	Кемеровская область, город Юрга, Кирова, 46		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40725	5	51	38	6960	12372	\N	55.723652999999999	Кемеровская область, город Юрга, Кирова, 23		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40724	5	51	38	6960	12372	\N	55.723652999999999	Кемеровская область, город Юрга, Кирова, 14		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40723	5	51	38	6960	49991	\N	55.723652999999999	Кемеровская область, город Юрга, Исайченко, 11	Россия, Кемеровская область, Юргинский район, Юрга	0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40727	5	51	38	6960	50340	\N	55.723652999999999	Кемеровская область, город Юрга, Достоевского, 10		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40758	5	51	38	6960	50001	\N	55.723652999999999	Кемеровская область, город Юрга, Волгоградская, 3		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
40753	5	51	38	6960	50001	\N	55.723652999999999	Кемеровская область, город Юрга, Волгоградская, 20		0101000020E61000004DC0AF91243A55407E5358A9A0DC4B40
41500	5	51	38	31765	\N	\N	55.434977000000003	Кемеровская область, Юргинский район, дер. Юльяновка, фельдшерско - акушерский пункт		0101000020E6100000DEAE97A60831554090C18A53ADB74B40
41498	5	51	38	31671	\N	\N	55.388081999999997	Кемеровская область, Юргинский район, д. Черный Падун, фельдшерско - акушерский пункт		0101000020E610000032CA332F873A55404815C5ABACB14B40
41513	5	51	38	32348	\N	\N	55.866162000000003	Кемеровская область, Юргинский район, д. Филоново, клуб		0101000020E610000026FDBD141E325540DC847B65DEEE4B40
41526	5	51	38	682	\N	\N	55.990820999999997	Кемеровская область, Юргинский район, д. Томилово, клуб		0101000020E6100000F81C588E903855405298F738D3FE4B40
41528	5	51	38	60730	\N	\N	55.787592043123801	Кемеровская область, Юргинский район, д.Талая, школа	Россия, Кемеровская область, Юргинский район, поселок Талая	0101000020E610000039B69E211C395540AD4B8DD0CFE44B40
41504	5	51	38	31948	\N	\N	55.611612000000001	Кемеровская область, Юргинский район, д. Старый Шалай, клуб		0101000020E61000008FFB56EBC4365540ABEB504D49CE4B40
41515	5	51	38	32414	\N	\N	55.863399000000001	Кемеровская область, Юргинский район, пос. Сокольники, клуб		0101000020E61000007D2079E7502955401633C2DB83EE4B40
41506	5	51	38	32028	\N	\N	55.690764999999999	Кемеровская область, Юргинский район, д. Сарсаз, Дом Культуры		0101000020E610000016C1FF56B2345540581CCEFC6AD84B40
41492	5	51	38	31411	\N	\N	55.691892000000003	Кемеровская область, Юргинский район, пос. Речной, школа		0101000020E610000037AAD381AC465540992EC4EA8FD84B40
41529	5	51	38	824	\N	\N	55.855759999999997	Кемеровская область, Юргинский район, д. Пятково, СДК	Россия, Кемеровская область, Юргинский район, поселок Пятково	0101000020E6100000658C0FB3973C5540CB9C2E8B89ED4B40
41510	5	51	38	32213	\N	\N	55.837409000000001	Кемеровская область, Юргинский район, с. Проскоково, школа		0101000020E6100000CE8DE9094B2E55402330D63730EB4B40
41512	5	51	38	32213	76129	\N	55.837409000000001	Кемеровская область, Юргинский район, с.Проскоково, Сосновая, 1		0101000020E6100000CE8DE9094B2E55402330D63730EB4B40
41516	5	51	38	32470	\N	\N	55.890608	Кемеровская область, Юргинский район, пос. Приречье, клуб		0101000020E6100000C8B60C384B3355402AC76471FFF14B40
41493	5	51	38	41188	\N	\N	55.503552999999997	Кемеровская область, Юргинский р-н, с. Поперечное, Дом Культуры		0101000020E6100000562DE928073F5540BE66B96C74C04B40
41454	5	51	38	184	\N	\N	55.663666725739198	Кемеровская область, Юргинский район, д. Новороманово, детская школа искуств	Россия, Кемеровская область, Юргинский район, поселок Новороманово	0101000020E6100000006F8104C55555409B374E0AF3D44B40
41525	5	51	38	41116	\N	\N	55.957147821719303	Кемеровская область, Юргинский район, д. Мальцево, Дом Культуры	Россия, Кемеровская область, Юргинский район, поселок Мальцево	0101000020E6100000548B8862F234554045B75ED383FA4B40
41524	5	51	38	41115	\N	\N	56.035953999999997	Кемеровская область, Юргинский район, д. Макурино, клуб		0101000020E6100000998235CEA62A5540871403249A044C40
41494	5	51	38	31491	\N	\N	55.511536999999997	Кемеровская область, Юргинский район, д. Любаровка, клуб		0101000020E61000000B42791F47385540D3D85E0B7AC14B40
41497	5	51	38	31658	\N	\N	55.471321000000003	Кемеровская область, Юргинский район, пос. Линейный, школа		0101000020E6100000085740A19E31554082751C3F54BC4B40
41508	5	51	38	41210	\N	\N	55.743461000000003	Кемеровская область, Юргинский район, д. Лебяжье-Асаново, клуб		0101000020E6100000486B0C3A21295540FD6CE4BA29DF4B40
41487	5	51	38	60773	\N	\N	55.6564684546371	"Кемеровская область, Юргинский район, д. Копылово, магазин ЧП ""Еровикова"""	Россия, Кемеровская область, Юргинский район, поселок Копылово	0101000020E610000030BB270F0B5E55406D6FB72407D44B40
41520	5	51	38	302	\N	\N	56.010216	Кемеровская область, Юргинский район, д. Кожевниково, клуб		0101000020E6100000F1BDBF417B275540AEF204C24E014C40
41505	5	51	38	60729	\N	\N	55.6654302448623	Кемеровская область, Юргинский район, д. Зимник, школа		0101000020E610000090149161153B55407EE36BCF2CD54B40
41522	5	51	38	437	\N	\N	56.039333999999997	Кемеровская область, Юргинский район, д. Зеледеево, Дом Культуры	Россия, Кемеровская область, Юргинский район, поселок Зеледеево	0101000020E6100000A297512CB737554078CF81E508054C40
41517	5	51	38	46	\N	\N	55.890133794248598	Кемеровская область, Юргинский район, пос. Заозерный, школа	Россия, Кемеровская область, Юргинский район, поселок Заозерный	0101000020E6100000E78F696D1A2E5540628731E9EFF14B40
41527	5	51	38	60772	\N	\N	55.915268676528697	Кемеровская область, Юргинский район, д. Елгино, школа	Россия, Кемеровская область, Юргинский район, поселок Елгино	0101000020E6100000C5591135D13655407505DB8827F54B40
41491	5	51	38	31333	\N	\N	55.655127	Кемеровская область, Юргинский район, с. Верх-Тайменка, школа		0101000020E610000040D9942BBC4D554001DD9733DBD34B40
41496	5	51	38	41101	\N	\N	55.3983487100502	Кемеровская область, Юргинский район, пос. Васильевка, клуб	Россия, Кемеровская область, Юргинский район, поселок Васильевка	0101000020E6100000AC3AAB05F62D554079B29B19FDB24B40
41523	5	51	38	41151	\N	\N	56.106208000000002	Кемеровская область, Юргинский район, д. Варюхино, клуб		0101000020E610000033897AC1A73955406B494739980D4C40
41363	5	51	1748	24390	50163	\N	55.276235999999997	Кемеровская область, г.Топки, Кузнецкая, 1		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41486	5	51	38	41097	\N	\N	55.5822159290488	Кемеровская область, Юргинский район, с. Большеямное, клуб	Россия, Кемеровская область, Юргинский район, поселок Большеямное	0101000020E6100000BAC0E5B1665F55409E9ACB0D86CA4B40
41489	5	51	38	41186	\N	\N	55.537886197525303	Кемеровская область, Юргинский район, д. Белянино, школа		0101000020E61000002C9ACE4E06505540F67CCD72D9C44B40
41509	5	51	38	32160	\N	\N	55.836013999999999	Кемеровская область, Юргинский район, д. Безменово, Дом Культуры		0101000020E61000005A457F68E62F5540C37FBA8102EB4B40
41518	5	51	38	156	\N	\N	55.954808	Кемеровская область, Юргинский район, д. Алабучинка, клуб		0101000020E6100000DD2230D6372A5540C6FA062637FA4B40
41480	5	51	823	30793	76119	\N	55.894651000000003	Кемеровская область, Чебулинский муниципальный район, Усть-Сертинское сельское поселение, д. Шестаково, ул. Оренбурская, 2а		0101000020E6100000693524EEB1FD5540B72A89EC83F24B40
41482	5	51	823	6033	76127	\N	55.740811000000001	Кемеровская область, Чебулинский муниципальный район, Чумайское сельское поселение, с. Чумай, ул. Совхозная, 26		0101000020E6100000BA1457957DF155402FC214E5D2DE4B40
41481	5	51	823	30847	76121	\N	56.128270000000001	Кемеровская область, Чебулинский муниципальный район, Усть-Чебулинское сельское поселение, с. Усть-Чебула, ул. Лесная, 1		0101000020E6100000FCAA5CA8FCF055406A87BF266B104C40
41478	5	51	823	6016	75814	\N	56.004916999999999	Кемеровская область, Чебулинский муниципальный район, Усть-Сертинское сельское поселение, с. Усть-Серта, ул. Кирова, 4		0101000020E610000063B323D577FF5540E318C91EA1004C40
41475	5	51	823	30538	\N	\N	55.955553999999999	Кемеровская область, Чебулинский муниципальный район, Усманское сельское поселение, с. Усманка, ул. 40 лет Победы, 108	Россия, Кемеровская область, Чебулинский район, поселок Усманка	0101000020E6100000CEE33098BFDA5540EFC7ED974FFA4B40
41467	5	51	823	41091	12418	\N	55.963403036527097	Кемеровская область, Чебулинский муниципальный район, Верх-Чебулинское городское поселение, д. Покровка, ул. Трактовая, 64	Россия, Кемеровская область, Чебулинский район, поселок Покровка	0101000020E6100000AE11C138B8EB554024EF1CCA50FB4B40
41006	5	51	823	30132	76012	\N	55.962826	д. Покровка, ул. Центральная, дом 31Б		0101000020E61000007381CB63CDEB554087DEE2E13DFB4B40
41466	5	51	823	30115	76122	\N	55.969920000000002	Кемеровская область, Чебулинский муниципальный район, Верх-Чебулинское городское поселение, д. Петропавловка, ул. Центральная, 11		0101000020E610000055F99E9108E1554040DEAB5626FC4B40
41468	5	51	823	30202	76111	\N	56.055176000000003	Кемеровская область, Чебулинский муниципальный район, Верх-Чебулинское городское поселение, д. Орлово-Розово, ул. Молодежная, 43		0101000020E6100000E0D6DD3CD5ED554016C3D50110074C40
41465	5	51	823	30046	76141	\N	56.105514999999997	Кемеровская область, Чебулинский муниципальный район, Верх-Чебулинское городское поселение, д. Новоказанка, ул. Молодежная, 1а		0101000020E6100000D175E107E7E55540641EF983810D4C40
41472	5	51	823	30370	75813	\N	55.858891999999997	Кемеровская область, Чебулинский муниципальный район, Ивановское сельское поселение, п. Новоивановский, ул. Трактовая, 1		0101000020E6100000AFD007CBD8F25540E4654D2CF0ED4B40
41477	5	51	823	30640	76118	\N	55.881318	Кемеровская область, Чебулинский муниципальный район, Усманское сельское поселение, с. Николаевка, ул. Центральная, 93		0101000020E6100000E6E61BD13DD1554025B03907CFF04B40
41474	5	51	823	30469	12433	\N	55.908929662742402	Кемеровская область, Чебулинский муниципальный район, Ивановское сельское поселение, д. Михайловка, ул. Набережная, 5	Россия, Кемеровская область, Чебулинский район, поселок Михайловка	0101000020E61000004D4D8237A4F95540382D78D157F44B40
41479	5	51	823	30745	76116	\N	55.956305	Кемеровская область, Чебулинский муниципальный район, Усть-Сертинское сельское поселение, д. Курск-Смоленка, ул. Советская, 58		0101000020E610000070ECD973990656402A00C63368FA4B40
41483	5	51	823	30956	76123	\N	55.752327999999999	Кемеровская область, Чебулинский муниципальный район, Чумайское сельское поселение, д. Кураково, ул. Юбилейная, 50а		0101000020E6100000446D1B4641F65540BBEEAD484CE04B40
41485	5	51	823	31052	76124	\N	55.745215000000002	Кемеровская область, Чебулинский муниципальный район, Чумайское сельское поселение, д. Карачарово, ул. Первомайская, 2		0101000020E6100000C72E51BD35EC55408CBE823463DF4B40
41484	5	51	823	30991	76010	\N	55.649611	Кемеровская область, Чебулинский муниципальный район, Чумайское сельское поселение, п. Казанка-20, ул. Школьная, 1		0101000020E610000068791EDC9DE05540990F087426D34B40
41473	5	51	823	30433	76120	\N	55.886231000000002	Кемеровская область, Чебулинский муниципальный район, Ивановское сельское поселение, с. Ивановка, ул. Кооперативная, 1		0101000020E610000060CB2BD7DBF05540C7D9740470F14B40
41470	5	51	823	41178	13372	\N	56.031396371801002	Кемеровская область, Чебулинский муниципальный район, Алчедатское сельское поселение, д. Дмитриевка, ул. Октябрьская, 2а	Россия, Кемеровская область, Чебулинский район, поселок Дмитриевка	0101000020E61000002992AF0452FA5540D49CBCC804044C40
41464	5	51	823	5905	75816	\N	56.035285000000002	Кемеровская область, Чебулинский муниципальный район, Верх-Чебулинское городское поселение, пгт. Верх-Чебула, м-р. Южный, 8		0101000020E6100000CEAACFD556E755400A85083884044C40
41462	5	51	823	5905	75766	\N	56.035285000000002	Кемеровская область, Чебулинский муниципальный район, Верх-Чебулинское городское поселение, пгт. Верх-Чебула, ул. Советская, 8		0101000020E6100000CEAACFD556E755400A85083884044C40
41351	5	51	1748	24390	50023	\N	55.276235999999997	Кемеровская область, г.Топки, Калинина, 4		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41463	5	51	823	41175	13341	\N	56.035285000000002	Кемеровская область, Чебулинский муниципальный район, Верх-Чебулинское городское поселение, пгт. Верх-Чебула, ул. Советская, 105		0101000020E6100000CEAACFD556E755400A85083884044C40
41476	5	51	823	30574	76113	\N	55.911245000000001	Кемеровская область, Чебулинский муниципальный район, Усманское сельское поселение, п. Боровой, ул. Центральна, 12		0101000020E6100000CD1FD3DA34D955405FD218ADA3F44B40
41469	5	51	823	30241	76114	\N	55.984819000000002	Кемеровская область, Чебулинский муниципальный район, Алчедатское сельское поселение, с. Алчедат, ул. Октябрьская, 25		0101000020E61000000BD0B69A75FA55405EBD8A8C0EFE4B40
41471	5	51	823	30241	75920	\N	55.986408512996597	Кемеровская область, Чебулинский муниципальный район, Алчедатское сельское поселение, п. 1-й, ул. Воронова, 24а	Россия, Кемеровская область, Чебулинский район, поселок Алчедат	0101000020E61000000BEF7211DFFA554073BD6DA642FE4B40
41449	5	51	1825	46367	76107	\N	56.044015000000002	с. Чулым, ул. Школьная, 20 (администрация)		0101000020E6100000E223624A244D564048C49448A2054C40
41403	5	51	1825	60793	76219	\N	55.951037195352903	д. Чернышово, ул. Чулымская, 4 (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Чернышево	0101000020E61000001FA2D11DC45056409A249694BBF94B40
41447	5	51	1825	60765	76017	\N	56.300641159484101	д. Теплая Речка, ул. Горская, 9 (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Тёплая Речка	0101000020E6100000C9AD49B7251B56401A6B7F677B264C40
41457	5	51	1825	41259	75716	\N	56.111765403159602	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Чехова, д. 33 (ТСШ №3)	Россия, Кемеровская область, Тяжинский район, поселок Тяжинский	0101000020E61000005B79C9FFE420564031EBC5504E0E4C40
41459	5	51	1825	41259	75850	\N	56.111959479820896	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Чапаева, д. 8 (ТСШ №2)		0101000020E61000005CAD1397E320564016BF29AC540E4C40
41455	5	51	1825	41259	75588	\N	56.112197000000002	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Советская, 2 (администрация пгт. Тяжинский)	Россия, Кемеровская область, Тяжинский район, поселок Тяжинский	0101000020E6100000AAB69BE09B205640CBDAA6785C0E4C40
41461	5	51	1825	41259	75838	\N	56.1102259620083	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Радищева, Д. 99 (КЭК)	Россия, Кемеровская область, Тяжинский район, поселок Тяжинский	0101000020E6100000E7559DD5022256409E95B4E21B0E4C40
41460	5	51	1825	41259	76163	\N	56.111957231834303	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Рабочая, д. 10 (Райгаз)	Россия, Кемеровская область, Тяжинский район, поселок Тяжинский	0101000020E610000048A30227DB20564075C7629B540E4C40
41453	5	51	1825	41259	13664	\N	56.109458606885298	Кемеровская область, Тяжинский муниципальный район, Тяжинское городское поселение, ул. Комунальная, д. 1	Россия, Кемеровская область, Тяжинский район, поселок Тяжинский	0101000020E61000003A782634492156405EA0A4C0020E4C40
41440	5	51	1825	28921	76105	\N	55.917707	д. Тяжино-Вершинка, ул. Ленина, 2а (СДК)		0101000020E6100000F7E7A221E3255640B727486C77F54B40
41448	5	51	1825	29257	75833	\N	56.070498999999998	с. Тисуль, ул. Пушкина, 5 (школа)		0101000020E610000001A60C1CD02B56404AB3791C06094C40
41446	5	51	1825	41166	13292	\N	56.2092866026398	с. Ступишино, ул. Кирова, 94 (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Ступишино	0101000020E6100000535C55F65D2356402E3D9AEAC91A4C40
41419	5	51	1825	27949	76099	\N	55.840164000000001	д. Старый Урюп, ул. Советская, 15 (СДК)		0101000020E6100000A1BC8FA33955564066A3737E8AEB4B40
41430	5	51	1825	41154	13097	\N	56.136803	с. Старый Тяжин, ул. Московская, 64 (СДК)		0101000020E6100000D9CEF753E3245640527FBDC282114C40
41445	5	51	1825	29132	75939	\N	56.336402999999997	с. Сандайка, ул. Береговая, 33 (СДК)		0101000020E6100000AF97A608701D56405DA3E5400F2B4C40
41423	5	51	1825	28136	76100	\N	55.997190000000003	п. Путятинский, ул. Центральная, 1а (СДК)		0101000020E6100000ECF82F1004115640FAF202ECA3FF4B40
41444	5	51	1825	46244	76117	\N	56.365617999999998	с. Прокопьево, ул. Курская, 22		0101000020E61000004DD7135D171656401A6A1492CC2E4C40
41439	5	51	1825	46122	75811	\N	56.036678000000002	с. Преображенка, ул. Советская, 41а (школа)		0101000020E6100000BA4E232D95245640C93D5DDDB1044C40
41429	5	51	1825	45899	76106	\N	56.136215999999997	д.Почаевка, ул. Почаевская, 15 (СДК)		0101000020E6100000CFBC1C76DF1A56409198A0866F114C40
41418	5	51	1825	27930	76101	\N	55.880974999999999	д. Новопреображенка, ул Молодежная, 1 (СДК)		0101000020E6100000016DAB59674E5640FBCBEEC9C3F04B40
41438	5	51	1825	60756	75952	\N	55.954706999999999	с. Новопокровка, ул. Мира, 1а (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Новопокровка (Маковка)	0101000020E61000003BFF76D9AF3C56409221C7D633FA4B40
41433	5	51	1825	41156	13116	\N	55.857771347694701	с. Новоподзорново, ул. Пролетарская, 2 (администрация)	Россия, Кемеровская область, Тяжинский район, поселок Новоподзорново	0101000020E61000008EE6C8CA2F465640863AAC70CBED4B40
41450	5	51	1825	60751	75915	\N	56.086131719533299	д. Новомарьинка, ул. Центральная, 52 (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Новомарьинка	0101000020E6100000C093162EAB405640CD91955F060B4C40
41427	5	51	1825	28281	76110	\N	56.148091999999998	п. Нововосточный, ул. Советская, 1 (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Нововосточный	0101000020E61000004679E6E5B02356404D66BCADF4124C40
41436	5	51	1825	41158	13254	\N	55.848982999999997	с. Малопичугино, ул. Новая, 19а (СДК)		0101000020E6100000A9F92AF9D838564013EE9579ABEC4B40
41422	5	51	1825	45774	75808	\N	56.069800999999998	п. Листвянка, ул. Советская, 3 (СДК)		0101000020E6100000B22D03CE52195640321D3A3DEF084C40
41417	5	51	1825	27876	75643	\N	55.945725000000003	с.Кубитет, ул. Рабочая, 22 (СДК)		0101000020E6100000ACAA97DF694856403B014D840DF94B40
41188	5	51	771	45699	\N	\N	53.879501751706101	п.Свободный, СДК п.Свободный		0101000020E610000003999D45EFA355402062838593F04A40
41425	5	51	1825	41152	\N	\N	56.1708920979654	д. Ключевая, ул. Ключевская, 22 (контора)	Россия, Кемеровская область, Тяжинский район, поселок Ключевая	0101000020E610000000E2AE5E45155640F392FFC9DF154C40
41452	5	51	1825	60706	75615	\N	56.068575000000003	Кемеровская область, Тяжинский муниципальный район, Итатское городское поселение, ул. Советская, д. 333	Россия, Кемеровская область, Тяжинский район, поселок Итатский	0101000020E6100000FA28232E004356405F29CB10C7084C40
41451	5	51	1825	60706	75615	\N	56.068961652647701	Кемеровская область, Тяжинский муниципальный район, Итатское городское поселение, Советская, 200 (ГДК)	Россия, Кемеровская область, Тяжинский район, поселок Итатский	0101000020E6100000C1C58A1A4C42564058552FBFD3084C40
41431	5	51	1825	41074	12364	\N	55.7482545917482	д. Изындаево, ул. Школьная, 4	Россия, Кемеровская область, Тяжинский район, поселок Изындаево	0101000020E6100000B4B0A71DFE4B5640C408E1D1C6DF4B40
41421	5	51	1825	45755	76102	\N	56.040962999999998	п. Заря, ул. Наберажная, 4 (СДК)		0101000020E61000003D27BD6F7C1456404BAC8C463E054C40
41442	5	51	1825	46189	76108	\N	56.308509999999998	с. Даниловка, ул. Школьная, 22а (СДК)		0101000020E6100000C3B81B446B295640963E74417D274C40
41441	5	51	1825	46181	\N	\N	56.274399000000003	д. Георгиевка, ул. Рабочая, 2а (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Георгиевка	0101000020E610000037E15E99B72756400E87A5811F234C40
41420	5	51	1825	28011	76109	\N	56.012587000000003	п. Валерьяновка, ул. Средняя, 36а (СДК)		0101000020E610000005E09F522519564069AD68739C014C40
41416	5	51	1825	41068	12335	\N	56.1286698961597	с. Бороковка, ул. Верхняя, 43 (помещение СК)		0101000020E61000000B08AD872F315640F8FC304278104C40
41424	5	51	1825	41072	12351	\N	56.197676583795896	с. Борисоглебское, ул. Центральная, 20	Россия, Кемеровская область, Тяжинский район, поселок Борисоглебское	0101000020E6100000BAD91F28B7285640F015DD7A4D194C40
41434	5	51	1825	60786	76197	\N	55.906872999999997	с. Большепокровка, ул. Некрасова, 12 (СДК)	Россия, Кемеровская область, Тяжинский район, поселок Большая Покровка	0101000020E6100000F6CE68AB923256400D501A6A14F44B40
41415	5	51	1825	27788	76112	\N	56.079532999999998	д.Акимо-Анненка, ул. Центральная, 21 (СДК)		0101000020E61000009301A08A1B335640F4F928232E0A4C40
41265	5	51	3787	41084	\N	\N	59.420563999999999	с.Тарасово, помещение учебного корпуса ПУ-82		0101000020E6100000DD4598A25CEA3E40FEEF880AD5B54D40
41389	5	51	1748	26579	50362	\N	55.365335000000002	Кемеровская область, Топкинский район, пос.Шишино, Максима Горького, 21		0101000020E6100000487023658B4E5540C68A1A4CC3AE4B40
41406	5	51	1748	27341	75744	\N	55.155616405105	Кемеровская область, Топкинский район, с.Черемичкино, м-он Дружба, 7	Россия, Кемеровская область, Топкинский район, поселок Черемичкино	0101000020E610000040A20914B1765540FF5D9F39EB934B40
41411	5	51	1748	27588	75949	\N	55.143830999999999	Кемеровская область, Топкинский район, дер.Цыпино, пер.Школьный, 11		0101000020E6100000051555BFD25F55405393E00D69924B40
41385	5	51	1748	26409	75806	\N	55.245455	Кемеровская область, Топкинский район, пос.Центральный, Советская, 17		0101000020E610000003249A4011565540E1D1C6116B9F4B40
41398	5	51	1748	27003	76088	\N	55.518600999999997	Кемеровская область, Топкинский  район, с.Хорошеборка, Школьная, 8		0101000020E6100000E6E8F17B9B5B554021567F8461C24B40
41380	5	51	1748	26156	\N	\N	55.222302999999997	Кемеровская область, Топкинский  район, с.Усть-Сосново, Школьная, 11	Россия, Кемеровская область, Топкинский район, поселок Усть-Сосново	0101000020E6100000AD69DE718A3F5540BE66B96C749C4B40
41383	5	51	1748	26156	13611	\N	55.223973285768999	Кемеровская область, Топкинский район, с.Усть-Сосново, Красная, 1а	Россия, Кемеровская область, Топкинский район, поселок Усть-Сосново	0101000020E610000036E49F19C43F5540F017B325AB9C4B40
41377	5	51	1748	26035	76006	\N	55.132773	Кемеровская область, Топкинский район, дер.Тыхта, Молодежная, 2-2		0101000020E6100000753E3C4B905055405A65A6B4FE904B40
41408	5	51	1748	27442	75807	\N	55.123722999999998	Кемеровская область, Топкинский район, пос.Трещевский, Малыхина, 14		0101000020E610000055A1815836715540AA61BF27D68F4B40
41342	5	51	1748	24390	50162	\N	55.276235999999997	Кемеровская область, г.Топки, м-он Солнечный, 10		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41355	5	51	1748	24390	12656	\N	55.276235999999997	Кемеровская область, г.Топки, м-он Красная Горка, 29		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41359	5	51	1748	24390	50360	\N	55.276235999999997	Кемеровская область, г.Топки, Топкинская, 2		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41369	5	51	1748	24390	12304	\N	55.276235999999997	Кемеровская область, г.Топки, Революции, 189		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41367	5	51	1748	24390	12304	\N	55.273198145370898	Кемеровская область, г.Топки, Революции, 76	Россия, Кемеровская область, Топкинский район, Топки	0101000020E61000004DBB9866BA67554093AAED26F8A24B40
41366	5	51	1748	24390	12304	\N	55.272806130677701	Кемеровская область, г.Топки, Революции, 49	Россия, Кемеровская область, Топкинский район, Топки	0101000020E6100000240B98C0AD6755408813984EEBA24B40
41362	5	51	1748	24390	12304	\N	55.276235999999997	Кемеровская область, г.Топки, Революции, 20		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41353	5	51	1748	24390	50161	\N	55.276235999999997	Кемеровская область, г.Топки, Пролетарская, 59		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41349	5	51	1748	24390	50161	\N	55.276235999999997	Кемеровская область, г.Топки, Пролетарская, 109		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41354	5	51	1748	24390	12648	\N	55.276235999999997	Кемеровская область, г.Топки, Пионерская, 60		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41370	5	51	1748	24390	12640	\N	55.272022089631697	Кемеровская область, Топкинский район, с.Топки, Микрорайон, 8а	Россия, Кемеровская область, Топкинский район, Топки	0101000020E61000000F99F221A867554071E5EC9DD1A24B40
41350	5	51	1748	24390	12568	\N	55.274570166190998	Кемеровская область, г.Топки, Максима Горького, 124а	Россия, Кемеровская область, Топкинский район, Топки	0101000020E61000003BE5D18DB06755403A3B191C25A34B40
41089	5	51	632	12025	\N	\N	53.962133000000001	п.Чистогорский, 35Б		0101000020E61000000490DAC4C9D7554081B3942C27FB4A40
41357	5	51	1748	24390	50359	\N	55.276235999999997	Кемеровская область, г.Топки, Заводская, 11		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41358	5	51	1748	24390	12678	\N	55.276235999999997	Кемеровская область, г.Топки, Алма-Атинская, 31		0101000020E610000036AD1402B96755402AFD84B35BA34B40
41394	5	51	1748	26834	76087	\N	55.346369000000003	Кемеровская область, Топкинский район, дер.Терехино, Центральная, 6а		0101000020E6100000205ED72FD85F554093ACC3D155AC4B40
41373	5	51	1748	25880	13661	\N	55.204273999999998	Кемеровская область, Топкинский район, пос.Среднеберезовский, Майская, 23		0101000020E6100000AA471ADCD64C554028B682A6259A4B40
41392	5	51	1748	26722	76086	\N	55.386512000000003	Кемеровская область, Топкинский район, дер.Симаново, Школьная, 7/1		0101000020E610000086C954C1A85555407BC1A73979B14B40
41384	5	51	1748	26353	76082	\N	55.272190000000002	Кемеровская область, Топкинский район, пос.Романовский, Леонова, 9		0101000020E6100000988A8D791D4055402D26361FD7A24B40
41391	5	51	1748	41138	12703	\N	55.352746000000003	Кемеровская область, Топкинский район, пос.Рассвет, Ленина, 2а		0101000020E610000024EEB1F4A15B5540BDE5EAC726AD4B40
41396	5	51	1748	41140	12766	\N	55.484551000000003	Кемеровская область, Топкинский район, пос.Раздолье, Центральная, 16		0101000020E610000091628044135455403F1F65C405BE4B40
41407	5	51	1748	27411	76092	\N	55.085144256785497	Кемеровская область, Топкинский район, дер.Пинигино, Центральная, 5	Россия, Кемеровская область, Топкинский район, поселок Пинигино	0101000020E610000099BC0166BE7F5540AEB9A3FFE58A4B40
41400	5	51	1748	27077	75805	\N	55.431519000000002	Кемеровская область, Топкинский район, дер.Опарино, Центральная, 6		0101000020E61000000E2F88484D4E5540234DBC033CB74B40
41404	5	51	1748	41142	12802	\N	55.321595000000002	Кемеровская область, Топкинский район, пос.Октябрьский, Центральная, 1а		0101000020E61000002907B3093066554050C763062AA94B40
41412	5	51	1748	27635	76103	\N	55.177529	Кемеровская область, Топкинский район, пос.Мокроусовский, Центральная, 25		0101000020E61000009E094D124B645540B98B3045B9964B40
41405	5	51	1748	27287	76091	\N	55.553269	Кемеровская область, Топкинский район, дер.Медынино, Центральная, 40/1		0101000020E610000035289A07B06755400072C284D1C64B40
41410	5	51	1748	27568	76115	\N	55.237341000000001	Кемеровская область, Топкинский район, дер.Малый Корчуган, Центральная, 31		0101000020E610000097395D1613655540FE7F9C30619E4B40
41375	5	51	1748	25954	76094	\N	55.181583075067401	Кемеровская область, Топкинский район, пос.Магистральный, Строителей, 19	Россия, Кемеровская область, Топкинский район, поселок Магистральный	0101000020E6100000831953B0C65255403A419B1C3E974B40
41386	5	51	1748	41137	12664	\N	55.269666999999998	Кемеровская область, Топкинский район, с.Лукошкино, Кооперативная, 2		0101000020E6100000E97E4E417E4C5540BCE7C07284A24B40
41390	5	51	1748	26636	76093	\N	55.376804999999997	Кемеровская область, Топкинский район, пос.Комсомольский, Центральная, 18		0101000020E61000003EEAAF57584B554011FC6F253BB04B40
40985	5	51	1748	60767	76042	\N	55.331126842496602	пос. Кокуй, ул. Свободная, дом 21, квартира 1	Россия, Кемеровская область, Топкинский район, поселок Кокуй	0101000020E6100000882CD2C43B4155404BE9995E62AA4B40
41388	5	51	1748	26552	76084	\N	55.233603000000002	Кемеровская область, Топкинский район, дер.Козлово, Нагорного, 8		0101000020E610000096CD1C925A505540AE9FFEB3E69D4B40
41395	5	51	1748	26837	76089	\N	55.325533999999998	Кемеровская область, Топкинский район, пос.Ключевой, Новая, 13		0101000020E6100000AF0B3F389F57554037DE1D19ABA94B40
41379	5	51	1748	26136	76097	\N	55.145149000000004	Кемеровская область, Топкинский район, дер.Катково, Клубная, 2		0101000020E6100000871A8524B34355400806103E94924B40
41409	5	51	1748	27485	76096	\N	55.194541999999998	Кемеровская область, Топкинский район, пос.Знаменский, Клубная, 3		0101000020E6100000070C923EAD6C554066D993C0E6984B40
41401	5	51	1748	27125	50364	\N	55.457082	Кемеровская область, Топкинский район, с.Зарубино, Центральная, 9а		0101000020E6100000CAFE791A306255408ECBB8A981BA4B40
41402	5	51	1748	27187	75809	\N	55.5243750956664	Кемеровская область, Топкинский район, с.Глубокое, Рабочая, 54	Россия, Кемеровская область, Топкинский район, поселок Глубокое	0101000020E610000009E23C9CC06D554085EB51B81EC34B40
41372	5	51	1748	25833	13654	\N	55.156523	Кемеровская область, Топкинский район, пос.Верх-Падунский, Советская, 3		0101000020E6100000698B6B7C264D5540310917F208944B40
41413	5	51	1748	41065	12329	\N	55.208979999999997	Кемеровская область, Топкинский район, дер.Большой Корчуган, Магистральная, 11		0101000020E6100000F33D23111A59554050C24CDBBF9A4B40
41381	5	51	1748	26204	76081	\N	55.360843000000003	Кемеровская область, Топкинский район, дер.Бархатово, Новая, 4		0101000020E61000005E9F39EB53435540CAFE791A30AE4B40
41348	5	51	860	41120	12563	\N	55.209518557490902	Кемеровская область, Тисульский район, п. Центральный, Леонова, 14	Россия, Кемеровская область, Тисульский район, поселок Центральный	0101000020E610000079E8BB5B59E955400072C284D19A4B40
41345	5	51	860	24542	76080	\N	55.740324999999999	Кемеровская область, Тисульский район, п. Утинка, Ленина, 39		0101000020E61000004489963C9E155640A2B437F8C2DE4B40
41334	5	51	860	24004	76072	\N	55.882368	Кемеровская область, Тисульский район, с. Усть-Колба, Советская, 45		0101000020E6100000AE10566309135640BA84436FF1F04B40
41329	5	51	860	23762	76068	\N	55.816121000000003	Кемеровская область, Тисульский район, д. Усть-Барандат, Центральная, 24		0101000020E610000036AD1402B92B5640174A26A776E84B40
41340	5	51	860	24285	76074	\N	55.793616999999998	Кемеровская область, Тисульский район, с. Третьяково, Береговая, 2А		0101000020E61000001442075DC21C56405A46EA3D95E54B40
41311	5	51	860	22614	50078	\N	55.760894	Кемеровская область, Тисульский район, пгт. Тисуль, Терешковой, 27		0101000020E610000019709692E51356407FDC7EF964E14B40
41312	5	51	860	22614	75799	\N	55.760894	Кемеровская область, Тисульский район, пгт. Тисуль, Октябрьская, 44		0101000020E610000019709692E51356407FDC7EF964E14B40
41268	5	51	868	20971	\N	\N	55.003224000000003	дер.Усть-Тарсьма, Усть-Тарсьминский сельский клуб		0101000020E6100000FC6D4F90D85B5540FA47DFA469804B40
41314	5	51	860	22614	12484	\N	55.759877977214799	Кемеровская область, Тисульский район, пгт. Тисуль, Ленина, 76	Россия, Кемеровская область, Тисульский район, поселок Тисуль	0101000020E6100000F2272A1BD61356409679ABAE43E14B40
41304	5	51	860	22614	12484	\N	55.760894	Кемеровская область, Тисульский район, пгт. Тисуль, Ленина, 76А		0101000020E610000019709692E51356407FDC7EF964E14B40
41308	5	51	860	41103	12469	\N	55.759055223848499	Кемеровская область, Тисульский район, пгт. Тисуль, Заводская, 1	Россия, Кемеровская область, Тисульский район, поселок Тисуль	0101000020E6100000F5F75278D0135640C16ED8B628E14B40
41310	5	51	860	41103	13439	\N	55.760894	Кемеровская область, Тисульский район, пгт. Тисуль, Гагарина, 17		0101000020E610000019709692E51356407FDC7EF964E14B40
41338	5	51	860	24186	75803	\N	55.594194000000002	Кемеровская область, Тисульский муниципальный район, с. Тамбар, Калинина		0101000020E61000009BFEEC478A2756405EBD8A8C0ECC4B40
41337	5	51	860	60792	76211	\N	55.691285999999998	Кемеровская область, Тисульский район, д. Серебряково, Новая, 35А	Россия, Кемеровская область, Тисульский район, поселок Серебряково	0101000020E6100000BBEEAD484C4156406117450F7CD84B40
41315	5	51	860	23116	76062	\N	55.693241	Кемеровская область, Тисульский район, п. Ржавчик, Клубная, 1		0101000020E610000055A69883A0115640889FFF1EBCD84B40
41336	5	51	860	6457	75804	\N	55.324385999999997	Кемеровская область, Тисульский район, п. Полуторник, Школьная, 50		0101000020E6100000A0FCDD3B6A1E5640DFA3FE7A85A94B40
41324	5	51	860	23521	75912	\N	55.491442829597297	Кемеровская область, Тисульский район, п. Новый Берикуль, Октябрьская, 7	Россия, Кемеровская область, Тисульский район, поселок Новый Берикуль	0101000020E6100000FA0AD28C450856408F6CAE9AE7BE4B40
41325	5	51	860	23565	\N	\N	55.364465000000003	Кемеровская область, Тисульский район, п. Московка, СДК		0101000020E610000065C6DB4AAF055640B1C403CAA6AE4B40
41320	5	51	860	23330	76007	\N	55.598343999999997	Кемеровская область, Тисульский район, п. Макаракский, Советская, 4		0101000020E61000001211FE45D002564000E1438996CC4B40
41333	5	51	860	23923	76070	\N	55.925727999999999	Кемеровская область, Тисульский район, д. Листвянка, Советская, 19Б		0101000020E610000084A0A3552D0D5640E97E4E417EF64B40
41331	5	51	860	23857	76069	\N	55.795484000000002	Кемеровская область, Тисульский район, с. Куликовка, Советская, 62		0101000020E610000082C98D226B085640E23E726BD2E54B40
41346	5	51	860	24615	76078	\N	55.722988999999998	Кемеровская область, Тисульский район, д. Кондрашка, Школьная, 15		0101000020E6100000A6F10BAF241A5640122F4FE78ADC4B40
41317	5	51	860	23209	76066	\N	55.628551249897001	Кемеровская область, Тисульский район, пгт. Комсомольск, Октябрьская, 3	Россия, Кемеровская область, Тисульский район, поселок Комсомольск	0101000020E6100000E1B20A9B010C56401E6FF25B74D04B40
41318	5	51	860	23209	75801	\N	55.627580000000002	Кемеровская область, Тисульский район, пгт. Комсомольск, Ленина, 25		0101000020E610000095F25A09DD0B5640D5CF9B8A54D04B40
41319	5	51	860	41106	12493	\N	55.627580000000002	Кемеровская область, Тисульский район, пгт. Комсомольск, 1 мая, 2Б		0101000020E610000095F25A09DD0B5640D5CF9B8A54D04B40
41332	5	51	860	23914	76073	\N	55.826701	Кемеровская область, Тисульский район, с. Колба, Школьная, 36		0101000020E61000001C96067E540D564006499F56D1E94B40
41343	5	51	860	24445	76077	\N	55.735813999999998	Кемеровская область, Тисульский район, д. Кайчак, Центральная, 1		0101000020E6100000664B5645B82356402FF834272FDE4B40
41341	5	51	860	24340	76075	\N	55.798222000000003	Кемеровская область, Тисульский район, д. Дворниково, Центральная, 41		0101000020E6100000FBAD9D28091A56404F7974232CE64B40
41327	5	51	860	41220	13506	\N	55.768374999999999	Кемеровская область, Тисульский район, д. Вознесенка, Молодежная, 25		0101000020E610000087BF266BD42D56403108AC1C5AE24B40
41347	5	51	860	24639	76079	\N	55.635486999999998	Кемеровская область, Тисульский район, с. Большой Берчикуль, пер. Советский, 2		0101000020E6100000F8C264AA601356403E0455A357D14B40
41326	5	51	860	23616	76067	\N	55.758982154491001	Кемеровская область, Тисульский район, с. Большой Барандат, Школьная, 6	Россия, Кемеровская область, Тисульский район, поселок Большой Барандат	0101000020E610000052280B5F5F30564058207A5226E14B40
41339	5	51	860	24252	\N	\N	55.658554144462997	Кемеровская область, Тисульский район, д. Большепичугино, СДК	Россия, Кемеровская область, Тисульский район, поселок Большепичугино	0101000020E6100000F8FE06EDD538564033535A7F4BD44B40
41321	5	51	860	23387	76085	\N	55.517775999999998	Кемеровская область, Тисульский район, п. Большая Натальевка, Почтовая, 3		0101000020E61000002F8507CDAEFB5540AC53E57B46C24B40
41323	5	51	860	23486	75802	\N	55.524605000000001	Кемеровская область, Тисульский район, п. Берикульский, Горняка, 2		0101000020E610000085B35BCB64085640B728B34126C34B40
41316	5	51	860	23148	50160	\N	55.021296999999997	Кемеровская область, Тисульский район, пгт. Белогорск, Юбилейная, 15		0101000020E610000039454772F91E56405F402FDCB9824B40
41344	5	51	860	24522	76076	\N	55.744678	Кемеровская область, Тисульский район, д. Байла, Трактовая, 20		0101000020E61000007636E49F192056407D06D49B51DF4B40
41291	5	51	1653	21993	76254	\N	52.919977000000003	652990, Кемеровская область, Таштагольский муниципальный район, поселок Шерегеш, улица Советская, Дом творчества		0101000020E6100000B610E4A084FF55403E096CCEC1754A40
41293	5	51	1653	21993	76278	\N	52.919977000000003	652990, Кемеровская область, Таштагольский муниципальный район, поселок Шерегеш, улица Дзержинского, Кинотеатр "Мустаг"		0101000020E6100000B610E4A084FF55403E096CCEC1754A40
41292	5	51	1653	21993	76273	\N	52.919977000000003	652990, Кемеровская область, Таштагольский муниципальный район, поселок Шерегеш, улица Гагарина, 6		0101000020E6100000B610E4A084FF55403E096CCEC1754A40
41290	5	51	1653	21993	76289	\N	52.919977000000003	652990, Кемеровская область, Таштагольский муниципальный район, поселок Шерегеш, улица 19 партсъезда, Дом культуры "Горняк"		0101000020E6100000B610E4A084FF55403E096CCEC1754A40
41295	5	51	1653	22225	\N	\N	52.897938000000003	652990, Кемеровская область, Таштагольский муниципальный район, поселок Чугунаш, Здание администрации поселка Чугунаш	Россия, Кемеровская область, Таштагольский район, поселок Чугунаш	0101000020E610000019761893FEF05540F7EAE3A1EF724A40
41298	5	51	1653	22366	\N	\N	53.037331999999999	652990, Кемеровская область, Таштагольский муниципальный район, поселок Центральный, Здание школы № 29		0101000020E6100000FC19DEACC1EA5540118C834BC7844A40
41289	5	51	1653	21910	76293	\N	53.140811999999997	652990, Кемеровская область, Таштагольский муниципальный район, поселок Темиртау, улица Центральная, 30		0101000020E61000005DA8FC6B79DC55403271AB2006924A40
41288	5	51	1653	21910	76257	\N	53.140811999999997	652990, Кемеровская область, Таштагольский муниципальный район, поселок Темиртау, улица Центральная, 16-а		0101000020E61000005DA8FC6B79DC55403271AB2006924A40
41280	5	51	1653	20973	\N	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Островского, 1-а	Россия, Кемеровская область, Таштагольский район, Таштагол	0101000020E61000005D18E945EDF75540E9482EFF21674A40
41279	5	51	1653	20973	76229	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Советская, 36-а		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41277	5	51	1653	20973	12412	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Поспелова, 6		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41275	5	51	1653	20973	12412	\N	52.760227089685301	652990, Кемеровская область, город Таштагол, улица Поспелова, 4	Россия, Кемеровская область, Таштагольский район, Таштагол	0101000020E6100000529D0E643DF65540A2444B1E4F614A40
41276	5	51	1653	20973	13343	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Ноградская, 10		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41274	5	51	1653	20973	13343	\N	52.804931109612902	652990, Кемеровская область, город Таштагол, улица Ноградская, 7	Россия, Кемеровская область, Таштагольский район, Таштагол	0101000020E6100000D4D4B2B5BEF75540AF44A0FA07674A40
41272	5	51	1653	20973	76239	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Ленина, 46		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41271	5	51	1653	20973	76239	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Ленина, 28		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41281	5	51	1653	20973	76264	\N	52.805725000000002	652990, Кемеровская область, город Таштагол, улица Коммунистическая, 26		0101000020E61000005D18E945EDF75540E9482EFF21674A40
41269	5	51	1653	20973	13328	\N	52.803058526487803	652990, Кемеровская область, город Таштагол, улица Калинина, 16	Россия, Кемеровская область, Таштагольский район, Таштагол	0101000020E6100000ADC090D5ADF7554015E126A3CA664A40
41303	5	51	1653	22585	\N	\N	52.747311000000003	652990, Кемеровская область, Таштагольский муниципальный район, поселок Спасск, Дом культуры "Юность"		0101000020E61000004302469737F05540757808E3A75F4A40
41287	5	51	1653	21748	76241	\N	53.207819999999998	652990, Кемеровская область, Таштагольский муниципальный район, поселок Мундыбаш, улица Школьная, Здание школы № 95		0101000020E6100000D6E3BED53AD2554034BA83D8999A4A40
41286	5	51	1653	21748	76245	\N	53.210756859353403	652990, Кемеровская область, Таштагольский муниципальный район, поселок Мундыбаш, улица Октябрьская, Курсовая сеть аглофабрики	Россия, Кемеровская область, Таштагольский район, поселок Мундыбаш	0101000020E6100000D76A0F7BA1D255409833DB15FA9A4A40
41285	5	51	1653	21748	76244	\N	53.207819999999998	652990, Кемеровская область, Таштагольский муниципальный район, поселок Мундыбаш, улица Ленина, 2		0101000020E6100000D6E3BED53AD2554034BA83D8999A4A40
41297	5	51	1653	22307	\N	\N	52.919335205255898	652990, Кемеровская область, Таштагольский муниципальный район, поселок Калары, Клуб поселка Калары	Россия, Кемеровская область, Таштагольский район, поселок Калары	0101000020E610000002F1BA7EC1E45540B988EFC4AC754A40
41282	5	51	1653	21581	76283	\N	53.112794999999998	652990, Кемеровская область, Таштагольский муниципальный район, поселок Каз, улица Победы, 10		0101000020E61000006F0ED76A0FE555407F130A11708E4A40
41284	5	51	1653	21581	76233	\N	53.112794999999998	652990, Кемеровская область, Таштагольский муниципальный район, поселок Каз, улица Ленина, Клуб "Юбилейный"		0101000020E61000006F0ED76A0FE555407F130A11708E4A40
41283	5	51	1653	21581	76247	\N	53.112794999999998	652990, Кемеровская область, Таштагольский муниципальный район, поселок Каз, улица Горноспасательная, 1-а		0101000020E61000006F0ED76A0FE555407F130A11708E4A40
40120	5	51	1653	28829	50106	\N	52.977556	Кемеровская область, Киселевский городской округ, Веселая, 41		0101000020E61000003D9D2B4A09D955401901158E207D4A40
41299	5	51	1653	22396	\N	\N	52.883828000000001	Кемеровская область, Таштагольский муниципальный район, поселок Базанча, Клуб поселка Базанча		0101000020E610000012F6ED2422E7554001A5A14621714A40
41300	5	51	1653	22426	\N	\N	53.014270000000003	Кемеровская область, Таштагольский муниципальный район, поселок Амзас, Здание школы № 164		0101000020E61000004D4A41B797E255402FA86F99D3814A40
41301	5	51	1653	22494	\N	\N	52.551231000000001	652990, Кемеровская область, Таштагольский муниципальный район, поселок Алтамаш, Здание администрации поселка Алтамаш		0101000020E6100000AEF4DA6CACEB55404CC5C6BC8E464A40
41263	5	51	868	20674	\N	\N	54.832194000000001	дер.Шуринка, Дом Культуры деревни Шуринка		0101000020E61000008DB454DE8E525540B6F63E55856A4B40
41255	5	51	868	20177	\N	\N	54.895553	пос.Цветущий, Клуб поселка Цветущий		0101000020E61000008A56EE05667F5540D76A0F7BA1724B40
41222	5	51	868	46423	\N	\N	54.92924	дер.Ушаково, медпункт дер.Ушаково	Россия, Кемеровская область, Промышленновский район, поселок Ушаково	0101000020E61000008FAA2688BA76554049111956F1764B40
41227	5	51	868	41147	\N	\N	54.987250000000003	деревня Уфимцево, Дом культуры деревни Уфимцево		0101000020E61000007D23BA675D685540EE7C3F355E7E4B40
41267	5	51	868	41172	\N	\N	55.004782879322903	"дер.Усть-Каменка, МОУ ""Усть-Каменовская ООШ"""		0101000020E6100000F17EDC7EF94B5540D449B6BA9C804B40
41257	5	51	868	47139	\N	\N	54.862166000000002	с.Труд, клуб села Труд		0101000020E61000001F9E25C8087B554090DC9A745B6E4B40
41266	5	51	868	47318	\N	\N	55.0188145042519	с. Титово, Дом Культуры селаТитово		0101000020E61000000F9D9E77635055404DD6A88768824B40
41261	5	51	868	47211	\N	\N	54.885244	"с.Тарасово, МОУ ""Тарасовская СОШ"""		0101000020E610000008944DB9C2495540787DE6AC4F714B40
41243	5	51	868	19535	\N	\N	55.055681199196798	"поселок Соревнование, МОУ ""Соревнованская ООШ"""	Россия, Кемеровская область, Промышленновский район, поселок Соревнование	0101000020E61000009A9658198D7955401901158E20874B40
41230	5	51	868	18845	\N	\N	54.888407999999998	поселок Ранний, помещение клуба поселка Ранний		0101000020E610000044C18C29585C55409CC0745AB7714B40
41232	5	51	868	18954	\N	\N	54.922610951807798	деревня Пьяново, Дом культуры деревни Пьяново	Россия, Кемеровская область, Промышленновский район, поселок Пьяново	0101000020E610000033E197FA7952554006F7031E18764B40
41250	5	51	868	41162	\N	\N	54.774461783810203	деревня Пушкино, сельский клуб деревни Пушкино	Россия, Кемеровская область, Промышленновский район, поселок Пушкино	0101000020E6100000EC33677DCA5F554054FF209221634B40
41256	5	51	868	41079	\N	\N	54.872869561871802	дер.Протопопово, клуб деревни Протопопово	Россия, Кемеровская область, Промышленновский район, поселок Протопопово	0101000020E610000003931B45D68055406BD44334BA6F4B40
41214	5	51	868	17693	\N	\N	54.916028871557202	пгт.Промышленная, помещение МОУ СОШ № 3	Россия, Кемеровская область, Промышленновский район, поселок Промышленная	0101000020E61000000586AC6EF56855400398327040754B40
41212	5	51	868	17693	\N	\N	54.917608000000001	"пгт.Промышленная, помещение ООО ""Шумахер"" (территория СХТ)"	Россия, Кемеровская область, Промышленновский район, поселок Промышленная	0101000020E61000000586AC6EF56855402446CF2D74754B40
41211	5	51	868	17693	\N	\N	54.917608000000001	пгт.Промышленная, Дворец Культуры		0101000020E61000000586AC6EF56855402446CF2D74754B40
41210	5	51	868	17693	\N	\N	54.917608000000001	пгт.Промышленная, помещение Беловской дистанции пути № 31(контора ПЧ-36)	Россия, Кемеровская область, Промышленновский район, поселок Промышленная	0101000020E61000000586AC6EF56855402446CF2D74754B40
41208	5	51	868	17693	\N	\N	54.916325530205697	пгт.Промышленная, помещение МОУ СОШ № 2	Россия, Кемеровская область, Промышленновский район, поселок Промышленная	0101000020E6100000F1660DDE57695540BC3C9D2B4A754B40
41207	5	51	868	17693	\N	\N	54.917608000000001	"пгт.Промышленная, контора ЗАО ""Ударник полей"""		0101000020E61000000586AC6EF56855402446CF2D74754B40
41213	5	51	868	41062	\N	\N	54.915237771089103	пгт.Промышленная, помещение 6-го сетевого участка	Россия, Кемеровская область, Промышленновский район, поселок Промышленная	0101000020E610000016139B8F6B6955403A07CF8426754B40
41209	5	51	868	41062	\N	\N	54.916622186657698	пгт.Промышленная, помещение столовой ПМС-20	Россия, Кемеровская область, Промышленновский район, поселок Промышленная	0101000020E6100000F3AFE595EB685540A565A4DE53754B40
41218	5	51	868	46348	\N	\N	54.756398293439901	деревня Прогресс, Дом культуры деревни Прогресс	Россия, Кемеровская область, Промышленновский район, поселок Прогресс	0101000020E6100000E542E55FCB565540416150A6D1604B40
41223	5	51	868	46444	\N	\N	54.96454	дер.Портнягино, медпункт дер.Портнягино		0101000020E6100000BC77D498106D554088D7F50B767B4B40
41226	5	51	868	41146	\N	\N	55.055573000000003	деревня Пор-Искитим, Дом культуры деревни Пор-Искитима		0101000020E610000088A1D5C91974554033C51C041D874B40
41248	5	51	868	46803	\N	\N	55.019691999999999	поселок Плотниково, помещение спортивного комплекса пос.Плотниково	Россия, Кемеровская область, Промышленновский район, поселок Плотниково	0101000020E6100000F05014E8137C554015FF774485824B40
41246	5	51	868	46803	\N	\N	55.019691999999999	поселок Плотниково, Заринский городской Дом Культуры		0101000020E6100000F05014E8137C554015FF774485824B40
41242	5	51	868	46803	\N	\N	55.019691999999999	поселок Плотниково, помещение железнодорожного вокзала		0101000020E6100000F05014E8137C554015FF774485824B40
41241	5	51	868	46803	\N	\N	55.019691999999999	поселок Плотниково, Плотниковская библиотека (бывшее здание школы №2)		0101000020E6100000F05014E8137C554015FF774485824B40
41176	5	51	868	46747	\N	\N	54.980553164149001	п.Первомайский, основная школа п.Первомайский	Россия, Кемеровская область, Промышленновский район, поселок Первомайский	0101000020E6100000A661F888987A5540527FBDC2827D4B40
41251	5	51	868	19930	\N	\N	54.698900000000002	деревня Пархаевка, сельский клуб деревни Пархаевка		0101000020E610000013BA4BE2AC5D55405396218E75594B40
41236	5	51	868	19025	\N	\N	55.030704999999998	станция Падунская, Падунский сельский Дом культуры		0101000020E61000005B441493374255406E693524EE834B40
41233	5	51	868	19025	\N	\N	55.033071	"ст.Падунская, МОУ ""Падунская СОШ"""	Россия, Кемеровская область, Промышленновский район, поселок Падунская	0101000020E6100000E65AB4006D42554017B9A7AB3B844B40
41247	5	51	868	46544	\N	\N	54.951273474769302	"ело Окунево, помещение МОУ ""Окуневская СОШ"""	Россия, Кемеровская область, Промышленновский район, поселок Окунево	0101000020E610000000FE2955A25B5540AE484C50C3794B40
41228	5	51	868	46544	\N	\N	54.952950999999999	село Окунево, Дом культуры села Окунево		0101000020E6100000F0C34142945B554062D8614CFA794B40
41428	5	51	868	45867	76130	\N	54.979671000000003	п. Октябрьский, ул. Школьная, 2а (СДК)		0101000020E610000083E0F1ED5D74554079EBFCDB657D4B40
41237	5	51	868	41073	\N	\N	54.991955886761097	деревня Озерки, сельский Дом культуры деревни Озерки	Россия, Кемеровская область, Промышленновский район, поселок Озерки	0101000020E6100000AFEDED96E43955401689096AF87E4B40
41163	5	51	771	40407	\N	\N	54.054335999999999	п.Севск, библиотека п.Севск		0101000020E6100000BD1C76DF31AE55406B7F677BF4064B40
41259	5	51	868	41168	\N	\N	54.904147780291197	с.Морозово, Дом Культуры села Морозово	Россия, Кемеровская область, Промышленновский район, поселок Морозово	0101000020E610000001BF469220725540355F251FBB734B40
41225	5	51	868	41066	\N	\N	55.041826380448498	село Лебеди, здание администрации Лебедевской сельского поселения	Россия, Кемеровская область, Промышленновский район, поселок Лебеди	0101000020E6100000AC527AA697655540AE0FEB8D5A854B40
41249	5	51	868	19839	\N	\N	54.797252999999998	село Краснинское, Дом Культуры села Краснинское		0101000020E6100000A41B6151115D5540A6D1E4620C664B40
41245	5	51	868	46855	\N	\N	55.013801999999998	деревня Колычево, сельский Дом Культуры деревни Колычево		0101000020E6100000742843554C865540484F9143C4814B40
41244	5	51	868	46855	\N	\N	55.013801999999998	деревня Колычево, сельский Дом культуры деревни Колычево		0101000020E6100000742843554C865540484F9143C4814B40
41252	5	51	868	47032	\N	\N	54.840215000000001	деревня Каменка, Дом Культуры деревни Каменка		0101000020E6100000EB01F39029635540E84D452A8C6B4B40
41264	5	51	868	20710	\N	\N	54.831866949290998	дер.Калтышино, Калтышинский сельский клуб	Россия, Кемеровская область, Промышленновский район, поселок Калтышино	0101000020E610000023A30392B047554092CF2B9E7A6A4B40
41221	5	51	868	46404	\N	\N	54.923931000000003	дер.Калинкино, Помещение молодежного центра дер.Калинкино		0101000020E61000005D8AABCABE7155405B61FA5E43764B40
41254	5	51	868	20154	\N	\N	54.894337	поселок Иваново-Родионовский, Сельский клуб пос.Иваново-Родионовский		0101000020E61000000398327040625540274D83A279724B40
41219	5	51	868	18312	\N	\N	54.783066556001998	село Журавлево, Дом культуры села Журавлево	Россия, Кемеровская область, Промышленновский район, поселок Журавлево	0101000020E61000007AFEB4519D435540D6C9198A3B644B40
41260	5	51	868	41169	\N	\N	54.8998546581455	дер.Еремино, Дом культуры деревни Еремино	Россия, Кемеровская область, Промышленновский район, поселок Еремино	0101000020E61000006FF25B74B26D55403012DA722E734B40
41238	5	51	868	46746	\N	\N	54.955219999999997	деревня Денисовка, помещение сельского клуба деревни Денисовка		0101000020E61000002219726C3D405540183E22A6447A4B40
41262	5	51	868	47244	\N	\N	54.851283000000002	пос.Голубево, Дом Культуры поселка Голубево		0101000020E610000021E692AAED445540055262D7F66C4B40
41235	5	51	868	20048	\N	\N	55.051056000000003	деревня Васьково, Васьковский сельский Дом Культуры		0101000020E61000006ADE718A8E455540DE21C50089864B40
41216	5	51	868	46292	\N	\N	54.691713999999997	село Ваганово, Дом культуры села Ваганово		0101000020E61000004CFBE6FEEA4A5540B91798158A584B40
41240	5	51	868	46796	\N	\N	55.174213000000002	село Березово, бывшее здание Березовской начальной школы		0101000020E610000004560E2DB2425540DFC4909C4C964B40
41125	5	51	868	46796	76057	\N	55.174213000000002	с.Березово, Школьная, 8		0101000020E610000004560E2DB2425540DFC4909C4C964B40
41258	5	51	868	20411	\N	\N	54.867637000000002	дер.Байрак, клуб деревни Байрак		0101000020E6100000D0D1AA967477554058E6ADBA0E6F4B40
41239	5	51	868	46771	\N	\N	55.062497999999998	село Абышево, Абышевский сельский Дом культуры		0101000020E61000002F8507CDAE3F55405F0839EFFF874B40
41174	5	51	771	17055	\N	\N	53.995016	п.Ясная Поляна, СДК п.Ясная Поляна	Россия, Кемеровская область, Прокопьевский район, поселок Ясная Поляна	0101000020E6100000C138B874CCBB5540957F2DAF5CFF4A40
41180	5	51	771	60768	\N	\N	54.000875999999998	п.Школьный, общежитие Аграрного колледжа	Россия, Кемеровская область, Прокопьевский район, поселок Школьный	0101000020E61000000114234BE6B45540F7AC6BB41C004B40
41177	5	51	771	16157	\N	\N	53.912616	с.Шарап, СДК с.Шарап		0101000020E610000090831266DAB9554036E7E099D0F44A40
41166	5	51	771	49560	\N	\N	54.138533000000002	п.Чапаевский, библиотека п.Чапаевский	Россия, Кемеровская область, Прокопьевский район, поселок Чапаевский	0101000020E6100000605793A7ACB3554059350873BB114B40
41205	5	51	771	41070	\N	\N	54.092409856240501	, Кемеровская область, Прокопьевский район, п.ст.Углерод, здание ж/д станции Углерод	Россия, Кемеровская область, Прокопьевский район, поселок Углерод	0101000020E61000004A7F2F8507A0554064E94317D40B4B40
41155	5	51	771	41057	\N	\N	54.318441	п.Тыхта, СДК п.Тыхта	Россия, Кемеровская область, Прокопьевский район, поселок Тыхта	0101000020E61000001D5A643BDFBC55404F5AB8ACC2284B40
41203	5	51	771	60769	\N	\N	54.133497712277197	п.ст.Тырган, здание ж/д станции Тырган	Россия, Кемеровская область, Прокопьевский район, поселок Тырган	0101000020E610000005A22765529655406C0A647616114B40
41201	5	51	771	17241	\N	\N	54.125053999999999	п.Трудармейский, администрация п.Трудармейский		0101000020E610000073F4F8BD4D9A5540F31DFCC401104B40
41198	5	51	771	17241	\N	\N	54.125053999999999	п.Трудармейский, начальная школа п.Трудармейский		0101000020E610000073F4F8BD4D9A5540F31DFCC401104B40
41204	5	51	771	41139	\N	\N	54.128279736240003	п. Трудармейский, библиотека п.Трудармейский	Россия, Кемеровская область, Прокопьевский район, поселок Трудармейский	0101000020E610000072C0AE264F9A55408D5DA27A6B104B40
41160	5	51	771	16812	\N	\N	54.235852999999999	п.Тихоновка, СДК п.Тихоновка	Россия, Кемеровская область, Прокопьевский район, поселок Тихоновка	0101000020E610000084BA48A12CA55540EDD45C6E301E4B40
41171	5	51	771	41126	\N	\N	54.095706	с.Терентьевское, ДК с.Терентьевское		0101000020E610000069723106D6BB5540F7031E18400C4B40
41168	5	51	771	15737	\N	\N	54.095706	с.Терентьевское, здание ГРП		0101000020E610000069723106D6BB5540F7031E18400C4B40
41172	5	51	771	60727	\N	\N	54.066623	п.ст.Терентьевская, СДК п.ст.Терентьевская	Россия, Кемеровская область, Прокопьевский район, поселок Терентьевская	0101000020E61000001E1A16A3AEB75540A9143B1A87084B40
41158	5	51	771	49441	\N	\N	54.198790000000002	с.Соколово, средняя школа с.Соколово		0101000020E610000048FE60E0B9B95540CC6262F371194B40
41187	5	51	771	45680	\N	\N	53.823281999999999	п.Смышляево, СДК п.Смышляево	Россия, Кемеровская область, Прокопьевский район, поселок Смышляево	0101000020E6100000D0F1D1E28CA5554057B1F84D61E94A40
41161	5	51	771	49465	\N	\N	54.191293999999999	п.Пушкино, СДК п.Пушкино		0101000020E6100000D9B11188D7B25540E4F560527C184B40
40607	5	51	771	59367	69913	\N	53.8727946243269	Кемеровская область, Прокопьевский городской округ, Центральный район, Институтская, 24		0101000020E6100000C7BAB88D06B05540618E1EBFB7EF4A40
40581	5	51	771	41060	75697	\N	53.868220999999998	Кемеровская область, Прокопьевский городской округ, Рудничный район, пр. Строителей, 25	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000001766A19DD3A75540A759A0DD21EF4A40
40594	5	51	771	41060	78191	\N	53.867460000000001	Кемеровская область, Прокопьевский городской округ, Рудничный район, Ленина, 17	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FEB4519D0EA95540494BE5ED08EF4A40
40608	5	51	771	41060	12843	\N	53.916960862738897	Кемеровская область, Прокопьевский городской округ, Центральный район, пр.Гагарина, 8	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000B03A72A433AE55408E5A61FA5EF54A40
40633	5	51	771	41060	12696	\N	53.942490078646301	Кемеровская область, Прокопьевский городской округ, Центральный район, пер. Соколовский, 1	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000C1C760C5A9AE55404D672783A3F84A40
40614	5	51	771	41060	75694	\N	53.894604778476698	Кемеровская область, Прокопьевский городской округ, Центральный район, Шишкина, 21	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000F9F4D89601AE554046EBA86A82F24A40
40679	5	51	771	41060	12314	\N	53.879651913689003	Кемеровская область, Прокопьевский городской округ, Зенковский район, Черных, 3	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000295C8FC2F5AD554035EECD6F98F04A40
40667	5	51	771	41060	50460	\N	53.872453830452699	Кемеровская область, Прокопьевский городской округ, Зенковский район, Цикличная, 27	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000005E6919A9F7AF5540D7A19A92ACEF4A40
40680	5	51	771	41060	50635	\N	53.905035563238698	Кемеровская область, Прокопьевский городской округ, Зенковский район, Тюленевка, 5	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FB03E5B67DAE5540F1D93A38D8F34A40
40632	5	51	771	41060	12296	\N	53.889590718855899	Кемеровская область, Прокопьевский городской округ, Центральный район, Союзная, 6	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E610000013D55B035BAE554071E82D1EDEF14A40
40631	5	51	771	41060	12296	\N	53.904651180039501	Кемеровская область, Прокопьевский городской округ, Центральный район, Союзная, 4	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000002332ACE28DAE554098A59D9ACBF34A40
40629	5	51	771	41060	12296	\N	53.880260480188198	Кемеровская область, Прокопьевский городской округ, Центральный район, Союзная, 59	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000BE88B663EAAF55400DFD135CACF04A40
40619	5	51	771	41060	50520	\N	53.908627389620499	Кемеровская область, Прокопьевский городской округ, Центральный район, Сафоновская, 28	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000289B728577AE55409DA1B8E34DF44A40
40621	5	51	771	41060	75607	\N	53.876654514591699	Кемеровская область, Прокопьевский городской округ, Центральный район, Революции, 67	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000965AEF37DAAD5540FC6F253B36F04A40
40617	5	51	771	41060	75606	\N	53.883830478506098	Кемеровская область, Прокопьевский городской округ, Центральный район, Проспектная, 111	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000000D198F5209AE5540A29C685721F14A40
40600	5	51	771	41060	78050	\N	53.865583000000001	Кемеровская область, Прокопьевский городской округ, Рудничный район, Жолтовского, 15	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000008789062978A855409E7C7A6CCBEE4A40
40596	5	51	771	41060	78050	\N	53.865025000000003	Кемеровская область, Прокопьевский городской округ, Рудничный район, Жолтовского, 14	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000009BC761307FA85540789CA223B9EE4A40
40688	5	51	771	41060	50388	\N	53.952237273972898	Кемеровская область, Прокопьевский городской округ, Зенковский район, Прокопьевская, 75	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000003D98141F9FAE55404485EAE6E2F94A40
40612	5	51	771	41060	13636	\N	53.876961000000001	Кемеровская область, Прокопьевский городской округ, Центральный район, Подольская, 10	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40676	5	51	771	41060	75609	\N	53.875487986585703	Кемеровская область, Прокопьевский городской округ, Зенковский район, Пионерская, 68а		0101000020E610000036902E36ADAD55402D05A4FD0FF04A40
40674	5	51	771	41060	12358	\N	53.875386547822799	Кемеровская область, Прокопьевский городской округ, Зенковский район, Пионерская, 36	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E610000034F44F70B1AD5540FA2B64AE0CF04A40
40672	5	51	771	41060	12358	\N	53.902091768496199	Кемеровская область, Прокопьевский городской округ, Зенковский район, Пионерская, 15	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000158F8B6A11AE5540DBFD2AC077F34A40
41130	5	51	632	41107	\N	\N	54.033977	п.Чистая Грива, 23А		0101000020E61000008656276728E0554079E8BB5B59044B40
40656	5	51	771	41060	12688	\N	53.904798578498102	Кемеровская область, Прокопьевский городской округ, Зенковский район, Печорская, 4	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000008811C2A38DAE55400C3A2174D0F34A40
40602	5	51	771	41060	13683	\N	53.864721000000003	Кемеровская область, Прокопьевский городской округ, Рудничный район, Петренко, 20	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E610000035EECD6F98A955400C957F2DAFEE4A40
40587	5	51	771	41060	12316	\N	53.858024	Кемеровская область, Прокопьевский городской округ, Рудничный район, Обручева, 65	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000D97745F0BFA755407097FDBAD3ED4A40
40586	5	51	771	41060	12316	\N	53.859952	Кемеровская область, Прокопьевский городской округ, Рудничный район, Обручева, 53	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000C6C03A8E1FA855409D103AE812EE4A40
40627	5	51	771	41060	13015	\N	53.875893739165498	Кемеровская область, Прокопьевский городской округ, Центральный район, Морозовой, 62	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000365CE49EAEAD55409E616A4B1DF04A40
40552	5	51	771	41060	76316	\N	53.876961000000001	652560, Кемеровская область, Прокопьевский городской округ, Молодогвардейцев, 30	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40669	5	51	771	41060	75735	\N	53.880223039342198	Кемеровская область, Прокопьевский городской округ, Зенковский район, Маганак, 47	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000A5129ED0EBAD5540F017B325ABF04A40
40662	5	51	771	41060	12383	\N	53.876961000000001	Кемеровская область, Прокопьевский городской округ, Зенковский район, Крестьянская, 39	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40649	5	51	771	41060	50500	\N	53.879549593610399	Кемеровская область, Прокопьевский городской округ, Зенковский район, Космонавта Волынова, 9	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000008AE3C0ABE5AF554031992A1895F04A40
40650	5	51	771	41060	70161	\N	53.904689192855301	Кемеровская область, Прокопьевский городской округ, Зенковский район, Комсомольская, 4		0101000020E610000055C03DCF9FAE5540850662D9CCF34A40
40610	5	51	771	41060	75605	\N	53.885529200479297	Кемеровская область, Прокопьевский городской округ, Центральный район, Институтская, 49	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000485167EE21AE55406D54A70359F14A40
40687	5	51	771	41060	75888	\N	53.876961000000001	Кемеровская область, Прокопьевский городской округ, Зенковский район, Зенковская, 21	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40598	5	51	771	41060	12347	\N	53.868524999999998	Кемеровская область, Прокопьевский городской округ, Рудничный район, Жолтовского, 42	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000D6E5948098A855401361C3D32BEF4A40
40578	5	51	771	41060	75599	\N	53.876961000000001	Кемеровская область, Прокопьевский городской округ, Рудничный район, Есенина, 80А	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40577	5	51	771	41060	75599	\N	53.8873546154433	653052, Кемеровская область, Прокопьевский городской округ, Рудничный район, Есенина, 66	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000006F6589CE32AE5540967840D994F14A40
40659	5	51	771	41060	70163	\N	53.876961000000001	Кемеровская область, Прокопьевский городской округ, Зенковский район, Дружбы, 27	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40682	5	51	771	41060	75891	\N	53.875335828348597	Кемеровская область, Прокопьевский городской округ, Зенковский район, Гончарова, 78	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000365CE49EAEAD5540778192020BF04A40
40681	5	51	771	41060	13640	\N	53.903176671738301	Кемеровская область, Прокопьевский городской округ, Зенковский район, Главная, 274	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000003AE97DE36BAE5540ECBFCE4D9BF34A40
40589	5	51	771	41060	69703	\N	53.860306999999999	Кемеровская область, Прокопьевский городской округ, Рудничный район, Гайдара, 8	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E610000012A0A696ADA855408BC22E8A1EEE4A40
40618	5	51	771	41060	69812	\N	53.897795634059896	Кемеровская область, Прокопьевский городской округ, Центральный район, Высокогорная, 2А		0101000020E61000006B2DCC423BAE5540643DB5FAEAF24A40
40686	5	51	771	41060	75868	\N	53.876961000000001	Кемеровская область, Прокопьевский городской округ, Зенковский район, Ветеранов, 20	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E6100000FA43334FAEAD5540096F0F4240F04A40
40692	5	51	771	41060	50503	\N	53.877893518554401	Кемеровская область, Прокопьевский городской округ, Зенковский район, 2-я Ярославская, 29	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E610000011A96917D3AF554064ADA1D45EF04A40
41136	5	51	632	14207	\N	\N	54.193838999999997	п.Усть-Аскарлы, Центральная, 17А	Россия, Кемеровская область, Новокузнецкий район, поселок Усть-Аскарлы	0101000020E6100000A8E3310395E355403CD862B7CF184B40
40573	5	51	771	41060	13502	\N	53.879987999999997	Кемеровская область, Прокопьевский городской округ, Рудничный район, 10-й микрорайон, 15А	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E61000009F5912A0A6A75540AC6F6072A3F04A40
40572	5	51	771	41060	13502	\N	53.878767970846901	Кемеровская область, Прокопьевский городской округ, Рудничный район, 10-й микрорайон, 18В		0101000020E61000000055DCB8C5AD5540BB6246787BF04A40
40570	5	51	771	41060	13502	\N	53.879227999999998	Кемеровская область, Прокопьевский городской округ, Рудничный район, 10-й микрорайон, 45	Россия, Кемеровская область, Прокопьевский район, Прокопьевск	0101000020E610000001A1F5F065A755401EDD088B8AF04A40
41175	5	51	771	17141	\N	\N	53.988669999999999	п.Плодопитомник, СДК п.Плодопитомник	Россия, Кемеровская область, Прокопьевский район, поселок Плодопитомник	0101000020E610000078B306EFABB85540A64412BD8CFE4A40
41186	5	51	771	16657	\N	\N	53.845902000000002	п.Новосафоновский, РДК п.Новосафоновский		0101000020E610000044F9821612A655407DCF488446EC4A40
41185	5	51	771	45630	\N	\N	53.766829999999999	с.Новорождественское, ДК с.Новорождественское		0101000020E6100000DFE2E13D07B05540BCCB457C27E24A40
41195	5	51	771	41253	\N	\N	54.048347	с.Михайловка, СДК с.Михайловка	Россия, Кемеровская область, Прокопьевский район, поселок Михайловка	0101000020E6100000D462F030ED9655400BEE073C30064B40
41179	5	51	771	16284	\N	\N	54.005876999999998	п.Маяковка, СДК п.Маяковка		0101000020E61000003410CB660EB155403866D993C0004B40
41156	5	51	771	49399	\N	\N	54.301741999999997	п.Майский, СДК п.Майский		0101000020E61000006F4BE48233B6554031EA5A7B9F264B40
41178	5	51	771	16239	\N	\N	53.835287000000001	с.Лучшево, СДК с.Лучшево	Россия, Кемеровская область, Прокопьевский район, поселок Лучшево	0101000020E6100000776A2E3718BA554011E335AFEAEA4A40
41157	5	51	771	49422	\N	\N	54.218930999999998	д.Лукьяновка, СДК д.Лукьяновка		0101000020E610000011FE45D098AD5540508A56EE051C4B40
41164	5	51	771	15576	\N	\N	54.092585	с.Кутоново, СДК с.Кутоново	Россия, Кемеровская область, Прокопьевский район, поселок Кутоново	0101000020E6100000268FA7E507AC5540D28C45D3D90B4B40
40149	5	51	771	29819	\N	\N	54.158783	Кемеровская область, Краснобродский городской округ, Ленина, 26	Россия, Кемеровская область, Прокопьевский район, поселок Краснобродский	0101000020E6100000FBEAAA402D9C55409414580053144B40
40147	5	51	771	29819	\N	\N	54.158783	Кемеровская область, Краснобродский городской округ, Юбилейная, 2	Россия, Кемеровская область, Прокопьевский район, поселок Краснобродский	0101000020E6100000FBEAAA402D9C55409414580053144B40
40145	5	51	771	29819	49973	\N	54.158783	Кемеровская область, Краснобродский городской округ, Новая, 45		0101000020E6100000FBEAAA402D9C55409414580053144B40
40144	5	51	771	29819	49973	\N	54.158783	Кемеровская область, Краснобродский городской округ, Новая, 59		0101000020E6100000FBEAAA402D9C55409414580053144B40
40142	5	51	771	29819	49973	\N	54.158783	Кемеровская область, Краснобродский городской округ, Новая, 44		0101000020E6100000FBEAAA402D9C55409414580053144B40
40151	5	51	771	29819	75632	\N	54.158783	Кемеровская область, Краснобродский городской округ, Линейная, 8		0101000020E6100000FBEAAA402D9C55409414580053144B40
40143	5	51	771	29819	50289	\N	54.158783	Кемеровская область, Краснобродский городской округ, Комсомольская, 24		0101000020E6100000FBEAAA402D9C55409414580053144B40
41154	5	51	771	15997	\N	\N	54.246049999999997	с.Котино, Котинское ДК		0101000020E610000055A4C2D842BB55402497FF907E1F4B40
41165	5	51	771	15595	\N	\N	54.123364000000002	п.Кольчегиз, СДК п.Кольчегиз	Россия, Кемеровская область, Прокопьевский район, поселок Кольчегиз	0101000020E610000093718C648FB755407BC03C64CA0F4B40
41159	5	51	771	15287	\N	\N	54.168830999999997	с.Карагайла, СДК с.Карагайла	Россия, Кемеровская область, Прокопьевский район, поселок Карагайла	0101000020E6100000C45DBD8A8CA3554086C613419C154B40
41197	5	51	771	60724	\N	\N	54.092914990833798	п.ст.Каменный Ключ, здание администрации п.ст.Каменный	Россия, Кемеровская область, Прокопьевский район, поселок Каменный Ключ	0101000020E6100000D95C35CF11865540672783A3E40B4B40
41181	5	51	771	16388	\N	\N	53.789039000000002	п.Калачево, СДК п.Калачево		0101000020E6100000973B33C170BB55406022DE3AFFE44A40
41183	5	51	771	41135	\N	\N	53.784055000000002	п.Калачево, магазин Сельпо		0101000020E6100000F700DD9733BA5540F5A10BEA5BE44A40
41184	5	51	771	16526	\N	\N	53.8301328076084	п.Индустрия, СДК п.Индустрия	Россия, Кемеровская область, Прокопьевский район, поселок Индустрия	0101000020E61000005C72DC291DAE5540492A53CC41EA4A40
40114	5	51	771	41159	13257	\N	53.962350999999998	Кемеровская область, Киселевский городской округ, д. Верх-Чумыш, Центральная, 2а		0101000020E6100000C5CA68E4F39D5540EE224C512EFB4A40
41190	5	51	771	16835	\N	\N	53.929961207559003	п.Верх-Егос, СДК п.Верх-Егос	Россия, Кемеровская область, Прокопьевский район, поселок Верх-Егос	0101000020E6100000378AAC3594A6554019C748F608F74A40
41162	5	51	771	16428	\N	\N	54.157060953484702	с.Бурлаки, СДК.с.Бурлаки	Россия, Кемеровская область, Прокопьевский район, поселок Бурлаки	0101000020E6100000240C03965CAB5540103D29931A144B40
41192	5	51	771	16934	\N	\N	53.893507999999997	п.Большой Керлегеш, СДК п.Большой Керлегеш		0101000020E6100000416150A6D19F5540705B5B785EF24A40
41153	5	51	771	15019	\N	\N	54.165008999999998	с.Большая Талда, здание сельской администрации	Россия, Кемеровская область, Прокопьевский район, поселок Большая Талда	0101000020E61000002DCC423BA7C35540D845D1031F154B40
40269	5	51	632	4097	76287	\N	53.491402999999998	652840, Кемеровская область, Мысковский городской округ, Чуазас поселок, ул.Центральная, (клуб), д.18		0101000020E6100000D829560DC2EE55400114234BE6BE4A40
41113	5	51	632	13123	76041	\N	53.992950950424898	п.Чичербаево, Центральная, 58-2	Россия, Кемеровская область, Новокузнецкий район, поселок Чичербаево	0101000020E61000001D7233DC80CA5540E7C3B30419FF4A40
41112	5	51	632	48742	76126	\N	54.081611000000002	п.Успенка, Центральная, 10		0101000020E6100000EF004F5AB8CD554037FFAF3A720A4B40
41129	5	51	632	49021	76135	\N	53.990850999999999	п.Терехино, Центральная, 29-2		0101000020E6100000DD0720B589D55540BD1AA034D4FE4A40
41087	5	51	632	60749	75906	\N	53.5544910169316	п.Таргайский Дом отдыха, Лесная, 13	Россия, Кемеровская область, Новокузнецкий район, поселок Таргайский Дом Отдыха	0101000020E61000007FF8F9EFC1C655409276A38FF9C64A40
41079	5	51	632	11550	76034	\N	53.748261999999997	п.Тальжино, Центральная, 2Б		0101000020E61000002EE411DC48DC5540766B990CC7DF4A40
41092	5	51	632	12149	76043	\N	53.444839999999999	п.Тайлеп, Школьная, 2		0101000020E6100000BADBF5D214CD5540F0F96184F0B84A40
41108	5	51	632	12897	\N	\N	54.014549000000002	п.Тагарыш, 6-2		0101000020E61000007FBE2D58AAC855404298DBBDDC014B40
41097	5	51	632	13445	50158	\N	53.953969000000001	п.Степной, Старцева, 15		0101000020E610000050340F6091C75540EC32FCA71BFA4A40
41109	5	51	632	60787	76198	\N	53.994443510742201	п.ст.Ерунаково, Вокзальная, 11	Россия, Кемеровская область, Новокузнецкий район, поселок Старое Ерунаково	0101000020E610000082CAF8F719CC55400ADAE4F049FF4A40
41085	5	51	632	41090	12410	\N	53.666351377811701	с.Сосновка, Кузнецкая, 10	Россия, Кемеровская область, Новокузнецкий район, поселок Сосновка	0101000020E61000002619390B7BC95540155454FD4AD54A40
41128	5	51	632	49015	75796	\N	53.961830999999997	с.Сидорово, Куюкова, 34А		0101000020E61000004C530438BDD55540B5A338471DFB4A40
41101	5	51	632	48548	\N	\N	53.939418000000003	п.Северный, 201		0101000020E61000009700FC53AAC055400AA359D93EF84A40
41143	5	51	632	14542	76053	\N	53.239935000000003	с.Сары-Чумыш, Советская, 29		0101000020E61000006B47718E3AAE55403815A930B69E4A40
39805	5	51	632	41207	13472	\N	53.463844454347601	652829, Кемеровская область, Калтанский городской округ, с. Сарбала, Советская, 11 А	Россия, Кемеровская область, Новокузнецкий район, поселок Сарбала	0101000020E610000037894160E5D3554011397D3D5FBB4A40
41116	5	51	632	41191	13427	\N	53.724188249503001	п.Рассвет, Центральная, 20А	Россия, Кемеровская область, Новокузнецкий район, поселок Рассвет	0101000020E6100000334E4354E1BB5540EC134031B2DC4A40
40288	5	51	632	5122	\N	\N	53.761384999999997	652840, Кемеровская область, Мысковский городской округ, Подобас поселок, ул. Дружбы, (школа №12), д.2а	Россия, Кемеровская область, Новокузнецкий район, поселок Подобас	0101000020E61000002579AEEFC3E955401D554D1075E14A40
41119	5	51	632	48866	76040	\N	53.812660999999999	п.Подгорный, Центральная, 1А		0101000020E610000023145B41D3C0554009DE904605E84A40
41133	5	51	632	14089	75745	\N	54.210002000000003	п.Осиновое Плесо, Суворова, 14		0101000020E610000049D74CBED9E355401C0C7558E11A4B40
41002	5	51	632	46629	76016	\N	53.589305000000003	пос. Новый, ул. Луговая, дом 1		0101000020E6100000ED6305BF0DC85540452FA3586ECB4A40
40360	5	51	632	6235	13648	\N	53.780266287903103	Новокузнецкий городской округ, Новоильинский район, пр. Авиаторов, д. 47 (здание школы №107)	Россия, Кемеровская область, Новокузнецкий район, Новокузнецк	0101000020E6100000CA6ABA9EE8CE554022179CC1DFE34A40
40413	5	51	632	6235	12578	\N	53.787971689251897	Кемеровская область, город Новокузнецк, Центральный район, Тольятти, 3, школа №103	Россия, Кемеровская область, Новокузнецкий район, Новокузнецк	0101000020E6100000670C738236CE5540F5143944DCE44A40
40440	5	51	632	6235	12661	\N	53.788784895762397	Кемеровская область, город Новокузнецк, Центральный район, Покрышкина, 36 педучилище№1	Россия, Кемеровская область, Новокузнецкий район, Новокузнецк	0101000020E610000069C70DBF9BCE5540A54929E8F6E44A40
40308	5	51	632	6235	12350	\N	53.8651764228944	654011, Кемеровская область, Новокузнецкий городской округ, Новоильинский район, ул. Олимпийская, 20	Россия, Кемеровская область, Новокузнецкий район, Новокузнецк	0101000020E6100000E1F1ED5D83CE55405DA45016BEEE4A40
40514	5	51	632	6235	12407	\N	53.790817842750997	Кемеровская область, город Новокузнецк, Куйбышевский район, Ливинская, 38	Россия, Кемеровская область, Новокузнецкий район, Новокузнецк	0101000020E61000006ADC9BDF30CE5540488B338639E54A40
40484	5	51	632	6235	75770	\N	53.796826000000003	Кемеровская область, город Новокузнецк, Куйбышевский район, Лермонтова, 6		0101000020E61000004E0B5EF415CE55401F4DF564FEE54A40
40455	5	51	632	6235	12298	\N	53.790004675833401	Кемеровская область, город Новокузнецк, Центральный район, Кутузова, 44а, гимназия 17	Россия, Кемеровская область, Новокузнецкий район, Новокузнецк	0101000020E6100000A3923A014DCE5540975643E21EE54A40
40395	5	51	632	6235	75749	\N	53.796826000000003	Кемеровская область, город Новокузнецк, Орджоникидзевский район, Интернатная, 2		0101000020E61000004E0B5EF415CE55401F4DF564FEE54A40
40416	5	51	632	6235	76308	\N	53.796826000000003	Кемеровская область, город Новокузнецк, Центральный район, Дружбы, 42а, школа 101		0101000020E61000004E0B5EF415CE55401F4DF564FEE54A40
40327	5	51	632	6235	12391	\N	53.796826000000003	Кемеровская область, город Новокузнецк, Заводской район, 40 лет ВЛКСМ, 76а		0101000020E61000004E0B5EF415CE55401F4DF564FEE54A40
41091	5	51	632	13168	76168	\N	53.478248999999998	п.Николаевка, Школьная, 1	Россия, Кемеровская область, Новокузнецкий район, поселок Николаевка	0101000020E6100000EA944737C2CA55401F2C634337BD4A40
41107	5	51	632	12879	75791	\N	54.003003	п.Недорезово, Центральная, 11	Россия, Кемеровская область, Новокузнецкий район, поселок Недорезово (Пашкино)	0101000020E610000082FFAD64C7C755401B65FD6662004B40
41117	5	51	632	41194	13430	\N	53.737332612323897	п.Мир, Куйбышева, 8	Россия, Кемеровская область, Новокузнецкий район, поселок Мир	0101000020E610000046B6F3FDD4C055407BA180ED60DE4A40
39807	5	51	632	41212	13482	\N	53.410684000000003	652830, Кемеровская область, Калтанский городской округ, п. Малиновка, 60 лет Октября, 19		0101000020E610000001BF469220D35540C87E164B91B44A40
39808	5	51	632	13646	\N	\N	53.410684000000003	652830, Кемеровская область, Калтанский городской округ, п. Малиновка, 60 лет Октября, 30	Россия, Кемеровская область, Новокузнецкий район, поселок Малиновка	0101000020E610000001BF469220D35540C87E164B91B44A40
41088	5	51	632	11966	75792	\N	53.639372000000002	с.Куртуково, Полосухина, 9А		0101000020E61000006C3D433866CD554033FD12F1D6D14A40
41151	5	51	632	14726	75958	\N	53.330176000000002	п.Кузедеево, Яценко, 22		0101000020E61000000186E5CFB7CC554049F6083543AA4A40
41147	5	51	632	14726	13545	\N	53.332744930005703	п.Кузедеево, Станционная, 15	Россия, Кемеровская область, Новокузнецкий район, поселок Кузедеево	0101000020E6100000F052EA9271CC55402A745E6397AA4A40
41148	5	51	632	14726	75646	\N	53.330176000000002	п.Кузедеево, Октябрьская, 8-1		0101000020E61000000186E5CFB7CC554049F6083543AA4A40
41149	5	51	632	14726	13546	\N	53.333258711145298	п.Кузедеево, Ленинская, 43	Россия, Кемеровская область, Новокузнецкий район, поселок Кузедеево	0101000020E610000005C58F3177CC5540800C1D3BA8AA4A40
41150	5	51	632	14726	76054	\N	53.330176000000002	п.Кузедеево, 40 лет Победы, 16-2		0101000020E61000000186E5CFB7CC554049F6083543AA4A40
41131	5	51	632	13980	76051	\N	53.810492000000004	с.Кругленькое, Мира, 2		0101000020E6100000D95BCAF962CD5540B7D5AC33BEE74A40
41104	5	51	632	41096	12445	\N	54.025123317554701	с.Красулино, Центральная, 4	Россия, Кемеровская область, Новокузнецкий район, поселок Красулино	0101000020E6100000BA2C26361FC555404FB0FF3A37034B40
41142	5	51	632	41112	12533	\N	53.584586999999999	с.Красная Орловка, 60 лет Октября, 1Б	Россия, Кемеровская область, Новокузнецкий район, поселок Красная Орловка	0101000020E6100000DA38622D3ED5554058552FBFD3CA4A40
41121	5	51	632	13541	75848	\N	53.633161562163401	с.Косенково, Школьная, 33	Россия, Кемеровская область, Новокузнецкий район, поселок Костенково	0101000020E6100000B0AD9FFEB3B45540F488D1730BD14A40
41122	5	51	632	13541	76044	\N	53.629223000000003	с.Костенково, Центральная, 1А	Россия, Кемеровская область, Новокузнецкий район, поселок Костенково	0101000020E610000096AFCBF09FB455400D7217618AD04A40
41145	5	51	632	14625	13543	\N	53.2718699842954	п.Кандалеп, Школьная, 15	Россия, Кемеровская область, Новокузнецкий район, поселок Кандалеп	0101000020E6100000D55A988576BB5540BB61DBA2CCA24A40
41110	5	51	632	12988	13402	\N	53.9988340527415	п.Казанково, Юбилейная, 19	Россия, Кемеровская область, Новокузнецкий район, поселок Казанково	0101000020E6100000488AC8B08AD155400211E2CAD9FF4A40
41095	5	51	632	60718	75731	\N	53.897578000000003	с.Ильинка, Жиха, 12		0101000020E610000024B5503239CA5540F7CDFDD5E3F24A40
41141	5	51	632	14455	76046	\N	53.477767	п.Зеленый Луг, Новая, 5-2		0101000020E6100000026729594ED35540D40D147827BD4A40
41093	5	51	632	60770	76071	\N	53.598374	п.Заречный, Юный Запсибовец	Россия, Кемеровская область, Новокузнецкий район, поселок Заречный	0101000020E61000003694DA8B68D355406B63EC8497CC4A40
41139	5	51	632	14373	76047	\N	54.145474	п.Загадное, Центральная, 34		0101000020E61000003BE0BA6246F455408B355CE49E124B40
41132	5	51	632	41108	12495	\N	53.895964999999997	д.Есаулка, Лесная, 8		0101000020E6100000FA0E7EE200DC554029AE2AFBAEF24A40
41115	5	51	632	41187	13423	\N	53.746628000000001	с.Бунгур, Ленинская, 16А		0101000020E61000003A58FFE730C0554092239D8191DF4A40
41081	5	51	632	41173	13330	\N	53.790836305585501	с.Боровково, Школьная, 13Б	Россия, Кемеровская область, Новокузнецкий район, поселок Боровково	0101000020E6100000A837A3E6ABDF5540EE3F321D3AE54A40
40289	5	51	632	41174	13340	\N	53.675638238343303	652840, Кемеровская область, Мысковский городской округ, Берензас поселок, ул. Речная, (клуб), д.9а	Россия, Кемеровская область, Новокузнецкий район, поселок Берензас	0101000020E610000032AEB8382AE55540A9F7544E7BD64A40
41144	5	51	632	41114	12538	\N	53.263026000000004	Новокузнецкий муниципальный район, Сары-Чумышское с/поселение, с.Бенжереп-2, ул.Зеленая (здание ФАПа), д.2		0101000020E6100000A88B14CAC2B25540B5FF01D6AAA14A40
41146	5	51	632	14698	13544	\N	53.322652185008799	с.Бенжереп-1, Центральная, 18	Россия, Кемеровская область, Новокузнецкий район, поселок Бенжереп 1-й	0101000020E6100000DB6B41EF8DBF554097FE25A94CA94A40
41082	5	51	632	12443	71725	\N	53.770736999999997	с.Безруково, Коммунальная, 2		0101000020E6100000711B0DE02DE5554098689082A7E24A40
41080	5	51	632	12443	71725	\N	53.770736999999997	с.Безруково, Коммунальная, 4	Россия, Кемеровская область, Новокузнецкий район, поселок Безруково	0101000020E6100000711B0DE02DE5554098689082A7E24A40
41096	5	51	632	12391	76039	\N	53.856152999999999	с.Бедарево, Центральная, 12-1		0101000020E610000083A7902BF5C75540A7AFE76B96ED4A40
41076	5	51	632	11423	76037	\N	53.725627000000003	п.Баевка, Зеленая, 46	Россия, Кемеровская область, Новокузнецкий район, поселок Баевка	0101000020E61000005645B8C9A8DA55401C0C7558E1DC4A40
41084	5	51	632	11805	76038	\N	53.633056000000003	с.Ашмарино, Советская, 15		0101000020E6100000A54FABE80FD15540AF44A0FA07D14A40
41126	5	51	632	41202	13462	\N	53.528065115269797	п.Апанас, Шабалова, 18Б	Россия, Кемеровская область, Новокузнецкий район, поселок Апанас	0101000020E6100000C4D155BABBB55540C49448A297C34A40
41105	5	51	632	41182	13390	\N	54.048283031766204	с.Анисимово, Центральная, 28	Россия, Кемеровская область, Новокузнецкий район, поселок Анисимово (Васьково)	0101000020E6100000B43EE5982CC45540F4F928232E064B40
40423	5	51	632	41134	12639	\N	53.725754999999999	Кемеровская область, город Новокузнецк, Центральный район, п. Абагур-Лесной, ул. Громовой, 61, школа 16	Россия, Кемеровская область, Новокузнецкий район, Новокузнецк	0101000020E6100000710168942ED0554049F4328AE5DC4A40
40244	5	51	285	1208	\N	\N	53.693356999999999	"Кемеровская область, город Междуреченск, АБК ЦОФ ""КУЗБАССКАЯ"""		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40243	5	51	285	1208	\N	\N	53.693356999999999	Кемеровская область, город Междуреченск, Тебинский сельсовет, здание администрации поселка Теба	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40240	5	51	285	1208	\N	\N	53.682762335119897	Кемеровская область, город Междуреченск, СДК пос.Камешек	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E61000007C5F5CAAD2055640CC79C6BE64D74A40
41072	5	51	815	60785	76196	\N	56.531922585521201	Таежная Михайловка, Школьный, 8	Россия, Кемеровская область, Мариинский район, поселок Таёжно-Михайловка	0101000020E61000003AE7A7380EDE5540BF7E880D16444C40
40239	5	51	285	1208	\N	\N	53.694072569779799	Кемеровская область, город Междуреченск, ФАНТАЗИЯ	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E6100000DC291DACFF055640B0045262D7D84A40
40265	5	51	285	1208	50517	\N	53.682269214123103	Кемеровская область, город Междуреченск - Междуреченский район, проспект Строителей, 10	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E610000091813CBB7C0556408D09319754D74A40
40266	5	51	285	1208	50308	\N	53.693356999999999	Кемеровская область, город Междуреченск - Междуреченский район, проспект Коммунистический, 9	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40226	5	51	285	1208	50308	\N	53.693356999999999	Кемеровская область, город Междуреченск, проспект Коммунистический, 17		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40245	5	51	285	1208	49974	\N	53.693356999999999	Кемеровская область, город Междуреченск, ШИРОКИЙ ЛОГ, 42А		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40237	5	51	285	1208	50267	\N	53.693356999999999	Кемеровская область, город Междуреченск, УСИНСКАЯ, 27		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40229	5	51	285	1208	12586	\N	53.693356999999999	Кемеровская область, город Междуреченск, Строителей, 36		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40225	5	51	285	1208	12586	\N	53.681539424210598	Кемеровская область, город Междуреченск, Строителей, 23	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E61000007F8978EBFC0456406AF981AB3CD74A40
40058	5	51	285	1208	50288	\N	53.693356999999999	Кемеровская область, город Междуреченск, СТРОИТЕЛЕЙ, 59		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40260	5	51	285	1208	75909	\N	53.6938688087711	Кемеровская область, город Междуреченск - Междуреченский район, ул.Пушкина, 22	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E6100000DD5D6743FE055640A75A0BB3D0D84A40
40250	5	51	285	1208	50051	\N	53.693356999999999	Кемеровская область, город Междуреченск, Проходчиков, 38		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40254	5	51	285	1208	50312	\N	53.693356999999999	Кемеровская область, город Междуреченск, ПУШКИНА, 30		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40251	5	51	285	1208	50310	\N	53.693356999999999	"Кемеровская область, город Междуреченск, ПРИТОМСКИЙ, ГДК ""ЮНОСТЬ"""		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40234	5	51	285	1208	71511	\N	53.693356999999999	Кемеровская область, город Междуреченск, Лазо, 33		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40235	5	51	285	1208	50048	\N	53.693356999999999	Кемеровская область, город Междуреченск, ЛАЗО, 33		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40230	5	51	285	1208	50127	\N	53.693356999999999	Кемеровская область, город Междуреченск, Кузнецкая, 32		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40227	5	51	285	1208	13591	\N	53.686838447152802	Кемеровская область, город Междуреченск, Коммунистический, 23	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E61000008E01D9EBDD05564035D3BD4EEAD74A40
40268	5	51	285	1208	75585	\N	53.693356999999999	Кемеровская область, город Междуреченск - Междуреченский район, ул.Комарова, 19А	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40236	5	51	285	1208	13499	\N	53.693356999999999	Кемеровская область, город Междуреченск, КУЗНЕЦКАЯ, 51		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40217	5	51	285	1208	13499	\N	53.687042242348902	Кемеровская область, город Междуреченск, КУЗНЕЦКАЯ, 27	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E61000007C5F5CAAD20556403D7D04FEF0D74A40
40190	5	51	285	1208	13499	\N	53.685615655165101	Кемеровская область, город Междуреченск, КУЗНЕЦКАЯ, 32	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E6100000537B116DC7055640A3CEDC43C2D74A40
40238	5	51	285	1208	50050	\N	53.693356999999999	Кемеровская область, город Междуреченск, ДУНАЕВСКОГО, 1а		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40233	5	51	285	1208	50046	\N	53.693356999999999	Кемеровская область, город Междуреченск, ГУЛИ КОРОЛЕВОЙ, 3		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40232	5	51	285	1208	50046	\N	53.693356999999999	Кемеровская область, город Междуреченск, ГУЛИ КОРОЛЕВОЙ, 11		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40262	5	51	285	1208	12954	\N	53.679437462726902	Кемеровская область, город Междуреченск - Междуреченский район, ул.Вокзальная, 6	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E610000018247D5A450556409F58A7CAF7D64A40
40257	5	51	285	1208	12954	\N	53.684002725233	Кемеровская область, город Междуреченск - Междуреченский район, ул.Вокзальная, 42		0101000020E6100000FFCBB56801055640D5AE09698DD74A40
40255	5	51	285	1208	12954	\N	53.682354702114303	Кемеровская область, город Междуреченск, ВОКЗАЛЬНАЯ, 42	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E6100000A4880CAB780556408CA19C6857D74A40
40228	5	51	285	1208	13594	\N	53.683373777195698	Кемеровская область, город Междуреченск, Весенняя, 9	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E610000040D9942BBC055640E6779ACC78D74A40
40246	5	51	285	1208	12650	\N	53.686430853787499	Кемеровская область, город Междуреченск, Вахрушева, 3	Россия, Кемеровская область, Междуреченский район, Междуреченск	0101000020E6100000DFF94509FA055640F4FA93F8DCD74A40
40253	5	51	285	1208	12676	\N	53.693356999999999	Кемеровская область, город Междуреченск, БУЛЬВАР МЕДИКОВ, 7		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40252	5	51	285	1208	49976	\N	53.693356999999999	Кемеровская область, город Междуреченск, БРЯНСКАЯ, 6а		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
40231	5	51	285	1208	50129	\N	53.693356999999999	Кемеровская область, город Междуреченск, 50 лет Комсомола, 36А		0101000020E610000018B0E42A16065640F1B913ECBFD84A40
41073	5	51	815	60795	76227	\N	56.571511000000001	Таежная Александровка, Александровская, 31		0101000020E6100000B37BF2B050D65540F226BF4527494C40
41070	5	51	815	11069	50020	\N	56.215998999999996	Суслово, Трактовая, 23		0101000020E61000005EBD8A8C0E085640FE7BF0DAA51B4C40
41069	5	51	815	11069	50018	\N	56.215998999999996	Суслово, Стройка, 7		0101000020E61000005EBD8A8C0E085640FE7BF0DAA51B4C40
41067	5	51	815	47903	76032	\N	56.357613999999998	Рубино, Школьная, 24		0101000020E61000001AA721AAF00A5640BE4BA94BC62D4C40
41053	5	51	815	47648	75998	\N	56.171463000000003	Раевка, Центральная, 31		0101000020E6100000F12900C633F85540AEBCE47FF2154C40
41052	5	51	815	60740	75873	\N	56.203092097677001	2-Пристань, Весенняя, 13	Россия, Кемеровская область, Мариинский район, поселок Пристань 2-я	0101000020E6100000DC291DACFFF45540240A2DEBFE194C40
41054	5	51	815	41075	12366	\N	56.231138000000001	Приметкино, Центральная, 62		0101000020E610000091D5AD9E93FA5540726E13EE951D4C40
41045	5	51	815	9937	75923	\N	56.330660000000002	Правдинка, Правдинская, 44 А		0101000020E6100000983270404BCB5540350C1F11532A4C40
41061	5	51	815	60745	75897	\N	56.652592139423803	Пихтовка, Лесная, 23	Россия, Кемеровская область, Мариинский район, поселок Пихтовка	0101000020E6100000E6797077D6045640CCD0782288534C40
41058	5	51	815	47746	76045	\N	56.214722000000002	Петровка, Центральная, 21		0101000020E6100000CB129D6516D95540A9DDAF027C1B4C40
40778	5	51	815	45470	76058	\N	56.172938772604901	Первомайский, Рабочая, 5	Россия, Кемеровская область, Мариинский район, поселок Первомайский	0101000020E6100000E7A6CD380D015640FA997ADD22164C40
40658	5	51	815	23191	9641	\N	56.356377194461899	Обояновка, Новая, 2	Россия, Кемеровская область, Мариинский район, поселок Обояновка	0101000020E6100000AB5B3D27BDE75540F705F4C29D2D4C40
41065	5	51	815	60776	76166	\N	56.2870536257197	2-Николаевка, Молодежная, 18 А	Россия, Кемеровская область, Мариинский район, поселок Николаевка 2-я	0101000020E61000009A081B9E5E055640CE177B2FBE244C40
39493	5	51	815	60782	76193	\N	56.283152918575198	1-Николаевка, Николаевская, 18		0101000020E610000037FA980F08D45540D461855B3E244C40
41066	5	51	815	47892	76030	\N	56.323193000000003	Мелехино, Боровая, 17		0101000020E61000009AEE75525FFB5540E8A562635E294C40
41042	5	51	815	6824	49951	\N	56.214182000000001	Мариинск, Юбилейная, 1 А		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41038	5	51	815	6824	49951	\N	56.214182000000001	Мариинск, Юбилейная, 26		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41037	5	51	815	6824	49951	\N	56.214182000000001	Мариинск, Юбилейная, 7		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41029	5	51	815	6824	50076	\N	56.214182000000001	Мариинск, Чердынцева, 22		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41013	5	51	815	6824	12297	\N	56.214182000000001	Мариинск, Фабричная, 1		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41030	5	51	815	6824	50077	\N	56.214182000000001	Мариинск, Трудовая, 2		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41041	5	51	815	6824	75790	\N	56.214182000000001	Мариинск, Сибиряков-Гвардейцев, 1		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41014	5	51	815	6824	50072	\N	56.214182000000001	Мариинск, Покрышкина, 25 А		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41032	5	51	815	6824	12322	\N	56.210166218044201	Мариинск, Пальчикова, 1 Д	Россия, Кемеровская область, Мариинский район, Мариинск	0101000020E6100000D32EA699EEEE5540965D30B8E61A4C40
41017	5	51	815	6824	50074	\N	56.214182000000001	Мариинск, Ноградский, 3		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41035	5	51	815	6824	50017	\N	56.214182000000001	Мариинск, Молодежная, 9		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41025	5	51	815	6824	12317	\N	56.214182000000001	Мариинск, Ленина, 30		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41024	5	51	815	6824	12317	\N	56.210070549756601	Мариинск, Ленина, 44	Россия, Кемеровская область, Мариинский район, Мариинск	0101000020E6100000FD12F1D6F9EE5540446B459BE31A4C40
40979	5	51	815	6824	12317	\N	56.214182000000001	Мариинск, Ленина, 8		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41019	5	51	815	6824	50354	\N	56.214182000000001	Мариинск, Котовского, 19		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41021	5	51	815	6824	12784	\N	56.2099748812293	Мариинск, Достоевского, 8	Россия, Кемеровская область, Мариинский район, Мариинск	0101000020E6100000BC92E4B9BEEF554022FDF675E01A4C40
41022	5	51	815	6824	13671	\N	56.211888206232203	Мариинск, Дорожная, 1	Россия, Кемеровская область, Мариинский район, Мариинск	0101000020E6100000957EC2D9ADEF55401A355F251F1B4C40
41034	5	51	815	6824	12328	\N	56.208826840205099	Мариинск, Добролюбова, 1	Россия, Кемеровская область, Мариинский район, Мариинск	0101000020E6100000486B0C3A21EF5540CAC2D7D7BA1A4C40
41010	5	51	815	6824	50015	\N	56.214182000000001	Мариинск, Гагарина, 8		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41020	5	51	815	6824	50016	\N	56.214182000000001	Мариинск, 50 лет Октября, 73 А		0101000020E6100000350708E6E8EE554029B2D6506A1B4C40
41050	5	51	815	41153	13090	\N	56.131316497171902	Мальковка, Центральная, 14	Россия, Кемеровская область, Мариинский район, поселок Мальковка	0101000020E610000021B0726891E3554084B872F6CE104C40
41047	5	51	815	10043	76009	\N	56.281351000000001	Малый Антибес, Просвещения, 1		0101000020E6100000EE77280AF4EC554034D93F4F03244C40
41063	5	51	815	10806	76031	\N	56.430732999999996	Малопесчанка, Победы, 1	Россия, Кемеровская область, Мариинский район, поселок Малопесчанка	0101000020E610000083DC4598A2C755406B274A4222374C40
41059	5	51	815	47759	76025	\N	56.382770000000001	Лебяжий, Школьная, 7		0101000020E61000007786A92D750A5640E9F17B9BFE304C40
41060	5	51	815	10665	76027	\N	56.409300000000002	Куркули, Рабочая, 19		0101000020E6100000CE1B2785790356405C2041F163344C40
41055	5	51	815	10413	75785	\N	56.169432999999998	Красные Орлы, Центральная, 4	Россия, Кемеровская область, Мариинский район, поселок Красные Орлы	0101000020E610000076543541D4CE55407CEE04FBAF154C40
41068	5	51	815	41167	13296	\N	56.130128269060201	Константиновка, Центральная, 31	Россия, Кемеровская область, Мариинский район, поселок Константиновка	0101000020E61000008811C2A38D0456409E25C808A8104C40
40450	5	51	815	12958	75985	\N	56.517037999999999	Колеул, Ленина, 45		0101000020E61000006AA67B9DD4D5554006651A4D2E424C40
41064	5	51	815	47850	76033	\N	56.5032	Кирсановка, Победы, 1		0101000020E6100000C233A14962C4554071AC8BDB68404C40
41056	5	51	815	41076	12369	\N	56.102811612067903	Камышенка, Центральная, 25	Россия, Кемеровская область, Мариинский район, поселок Камышенка	0101000020E610000052465C001AD0554074D190F1280D4C40
41049	5	51	815	47580	75800	\N	56.194913999999997	Калининский, Студенческая, 2 А		0101000020E6100000A33F34F3E4E855402AC423F1F2184C40
41071	5	51	815	47980	76035	\N	56.055230999999999	Знаменка, Центральная, 53		0101000020E6100000397D3D5FB30E5640D95C35CF11074C40
41046	5	51	815	60789	76208	\N	56.304819999999999	Большой Антибес, Ленина, 68	Россия, Кемеровская область, Мариинский район, поселок Болшой Антибес	0101000020E6100000C0EB33677DF0554057957D5704274C40
40418	5	51	815	48673	75752	\N	56.379815000000001	Благовещенка, Трактовая, 35		0101000020E61000009A249694BBD85540DFC325C79D304C40
41044	5	51	815	5826	76018	\N	56.287052000000003	Белогородка, Пальчикова, 62 А		0101000020E6100000F0FD0DDAABCA55402E20B41EBE244C40
41051	5	51	815	60790	76203	\N	56.169473000000004	ст.Антибесская, Зеленая, 10 Б	Россия, Кемеровская область, Мариинский район, поселок Антибесский	0101000020E6100000BB9C121093E155400B47904AB1154C40
41003	5	51	35	8378	50353	\N	54.670560999999999	с. Шабаново, ул. Советская, дом 71Б		0101000020E610000072DF6A9DB86655408D7C5EF1D4554B40
40999	5	51	35	7748	75794	\N	54.837741999999999	с. Чусовитино, ул. Школьная, дом 22		0101000020E61000004B5CC7B8E2945540293E3E213B6B4B40
40961	5	51	35	59500	71723	\N	54.688575999999998	пос. Чкаловский, ул. 50 Лет Октября, дом 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Чкаловский	0101000020E61000000B08AD872F7D5540BE67244223584B40
40969	5	51	35	45907	75955	\N	54.818237000000003	с. Чесноково, ул. Центральная, дом 8		0101000020E61000006E85B01A4B9A554047B071FDBB684B40
40978	5	51	35	6768	75946	\N	54.817447706239001	с. Худяшово, ул. Центральная, дом 55	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Худяшово	0101000020E6100000A087DA368C8255401E17D522A2684B40
40984	5	51	35	7040	75924	\N	54.571485000000003	пос. Хрестиновский, ул. Старательская, дом 41		0101000020E61000007F129F3BC1545540C993A46B26494B40
40975	5	51	35	46042	75943	\N	54.720756000000002	с. Хмелево, ул. Зеленая, дом 13		0101000020E61000001021AE9CBD845540A9328CBB415C4B40
40977	5	51	35	6739	75947	\N	54.832411	с. Трекино, ул. Горка, дом 16		0101000020E610000058A835CD3B84554053EA92718C6A4B40
41004	5	51	35	8514	12343	\N	54.682107000000002	д. Торопово, ул. Весенняя, дом 48А		0101000020E610000019FF3EE3C26C5540B4AF3C484F574B40
40966	5	51	35	45834	75942	\N	54.638433999999997	пос. Солнечный, ул. Апрельская, дом 3, квартира 2		0101000020E61000006E6C76A4FA855540C5538F34B8514B40
41009	5	51	35	46778	\N	\N	54.701158	д. Соколовка, ул. Весенняя, дом 40А	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Соколовка	0101000020E6100000999A046F4874554015AA9B8BBF594B40
41000	5	51	35	46581	76022	\N	54.899721	д. Семеново, ул. Центральная, дом 34А		0101000020E610000026016A6AD99A55402043C70E2A734B40
40989	5	51	35	41247	13599	\N	54.582139283645901	пос. Свердловский, ул. Школьная, дом 13	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Свердловский	0101000020E61000006798DA5207895540F25CDF87834A4B40
40988	5	51	35	60743	75893	\N	54.401899999999998	пос. Родниковый, ул. Садовая, дом 15	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Родниковый	0101000020E6100000BA2C26361F82554096218E7571334B40
40994	5	51	35	7510	\N	\N	54.697567999999997	пос. Ракитный, ул. Зеленая, дом 7А	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Ракитный	0101000020E6100000143E5B0707785540395E81E849594B40
40964	5	51	35	6030	75981	\N	54.689749814054899	пос. Клейзавода, ул. Заводская, дом 11	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Поселок Клейзавода	0101000020E6100000B2D7BB3FDE8455403F355EBA49584B40
40558	5	51	35	41071	12486	\N	54.595317999999999	Полысаевский городской округ, Ягодная (здание школы искусств № 54), 6	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000342F87DD779055402D5C5661334C4B40
40550	5	51	35	41071	76335	\N	54.606763239935802	652560, Кемеровская область, Полысаевский городской округ, Читинская, 47	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E61000008DCF64FF3C92554020B6F468AA4D4B40
40566	5	51	35	41071	76222	\N	54.596573779674898	652560, Кемеровская область, Полысаевский городской округ, Токарева, 6	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E61000001CEDB8E1779055406BD26D895C4C4B40
40564	5	51	35	41071	76222	\N	54.603860874524102	652560, Кемеровская область, Полысаевский городской округ, Токарева, 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E61000009EF0129CFA905540392A37514B4D4B40
40560	5	51	35	41071	12342	\N	54.594121970635904	652560, Кемеровская область, Полысаевский городской округ, Покрышкина, 7а	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000228D0A9C6C905540C4EA8F300C4C4B40
40567	5	51	35	41071	12500	\N	54.601696908301797	652560, Кемеровская область, Полысаевский городской округ, Панферова, 20	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000EF6FD05E7D925540F88C4468044D4B40
40559	5	51	35	41071	76337	\N	54.597183399344601	652560, Кемеровская область, Полысаевский городской округ, Мира, 5		0101000020E61000007689EAAD81905540145D177E704C4B40
40563	5	51	35	41071	76314	\N	54.604945490536203	652560, Кемеровская область, Полысаевский городской округ, Макаренко, 2	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E61000001A321EA5129055407A7077D66E4D4B40
40562	5	51	35	41071	76313	\N	54.592486999999998	652560, Кемеровская область, Полысаевский городской округ, Крупской, 62	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000DDE9CE13CF9055400F27309DD64B4B40
40553	5	51	35	41071	76313	\N	54.597470831400599	652560, Кемеровская область, Полысаевский городской округ, Крупской, 106	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000A648BE12489055407AA702EE794C4B40
40556	5	51	35	41071	76351	\N	54.592486999999998	652560, Кемеровская область, Полысаевский городской округ, Кремлевская, 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000DDE9CE13CF9055400F27309DD64B4B40
40554	5	51	35	41071	76351	\N	54.592486999999998	652560, Кемеровская область, Полысаевский городской округ, Кремлевская, 5	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000DDE9CE13CF9055400F27309DD64B4B40
40561	5	51	35	41071	13469	\N	54.5985076333831	652560, Кемеровская область, Полысаевский городской округ, Космонавтов, 17	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000D464C6DB4A9055407B32FFE89B4C4B40
40568	5	51	35	41071	76336	\N	54.598467532259797	652560, Кемеровская область, Полысаевский городской округ, Карбышева, 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E61000007DCC07043A905540ECD973999A4C4B40
40565	5	51	35	41071	76329	\N	54.592486999999998	652560, Кемеровская область, Полысаевский городской округ, Заречная, 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000DDE9CE13CF9055400F27309DD64B4B40
40551	5	51	35	41071	76242	\N	54.596784709312502	652560, Кемеровская область, Полысаевский городской округ, Бажова, 3	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000CA8CB7955E90554026DF6C73634C4B40
40549	5	51	35	41071	76242	\N	54.592486999999998	652560, Кемеровская область, Полысаевский городской округ, Бажова, 7	Россия, Кемеровская область, Ленинск-Кузнецкий район, Полысаево	0101000020E6100000DDE9CE13CF9055400F27309DD64B4B40
40986	5	51	35	46276	75789	\N	54.488567000000003	с. Подгорное, пер. Кольцевой, дом 10		0101000020E61000002657B1F84D805540D2730B5D893E4B40
41001	5	51	35	46618	50070	\N	54.947088000000001	с. Панфилово, ул. Советская, дом 14А		0101000020E61000007A50508A569855408F37F92D3A794B40
40991	5	51	35	46398	75965	\N	54.500624999999999	пос. Павловка, ул. Центральная, дом 43А		0101000020E610000058E71890BD855540AE47E17A14404B40
41008	5	51	35	46748	75992	\N	54.793537000000001	пос. Орловский, ул. Магистральная, дом 1В		0101000020E6100000E55E6056286F55403E95D39E92654B40
40973	5	51	35	7013	13585	\N	54.660011147601502	д. Новопокровка, ул. Центральная, дом 14	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Новопокровка	0101000020E6100000D3139678409D554008008E3D7B544B40
40995	5	51	35	7590	75961	\N	54.706125999999998	д. Новопокасьма, ул. Туснолобовой-Марченко, дом 1		0101000020E610000030A017EE5C7955407A6D3656625A4B40
40997	5	51	35	7645	75973	\N	54.612211000000002	пос. Новогородец, ул. Никитинская, дом 30		0101000020E61000002C2D23F59E82554030A017EE5C4E4B40
40974	5	51	35	41240	13568	\N	54.696914121283299	д. Новогеоргиевка, ул. Молодежная, дом 29	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Новогеоргиевка	0101000020E610000090300C5872945540F10F5B7A34594B40
41007	5	51	35	8151	76004	\N	54.710053000000002	пос. Мусохраново, ул. Советская, дом 60А		0101000020E610000066DAFE95957155409EB64604E35A4B40
40996	5	51	35	46512	75786	\N	54.61206	пос. Мирный, ул. Весенняя, дом 4	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Мирный	0101000020E61000000E83F92B647B55404A9869FB574E4B40
40208	5	51	35	43	\N	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Магаданная, 16	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40213	5	51	35	43	50085	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Шахтеров, 21		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40172	5	51	35	43	50042	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Текстильщиков, 4/4		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40168	5	51	35	43	50042	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Текстильщиков, 12		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40162	5	51	35	43	50042	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Текстильщиков, 4/3		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40181	5	51	35	43	12455	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Ленина, 15		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40178	5	51	35	43	12455	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Ленина, 46		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40174	5	51	35	43	12455	\N	54.663878830326503	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Ленина, 31	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E610000001310917F28B554027C0B0FCF9544B40
40169	5	51	35	43	12455	\N	54.6640778457785	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Ленина, 61/3	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E6100000279F1EDB328B55401EFF058200554B40
40161	5	51	35	43	50081	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Кольчугинский, 3		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40206	5	51	35	43	12549	\N	54.663281778093697	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Кирова, 55	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E610000074B2D47ABF8B55404303B16CE6544B40
40203	5	51	35	43	12549	\N	54.663082758724002	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Кирова, 4	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E61000008A39083A5A8B55404CC45BE7DF544B40
40202	5	51	35	43	12549	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Кирова, 25		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40182	5	51	35	43	12549	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Кирова, 106		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40177	5	51	35	43	12549	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Кирова, 99		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40207	5	51	35	43	12557	\N	54.6618886219375	Кемеровская область, Ленинск-Кузнецкий городской округ, проспект Дзержинского, 29	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E6100000518369183E8B5540844A5CC7B8544B40
40201	5	51	35	43	50264	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, площадь Кирова, 13а		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40215	5	51	35	43	50306	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, переулок Челюскина, 20		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40155	5	51	35	43	50294	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, бульвар Химиков, 7/1		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40157	5	51	35	43	50296	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Юргинская, 6		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40199	5	51	35	43	50119	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Энгельса, 6		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40191	5	51	35	43	50301	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Широкая, 1		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40221	5	51	35	43	50125	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Шилина, 1		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40185	5	51	35	43	13474	\N	54.664973403192803	Кемеровская область, Ленинск-Кузнецкий городской округ, Шевцовой, 2	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E61000008CA19C68578B55408CDCD3D51D554B40
40164	5	51	35	43	13396	\N	54.630231147707498	Кемеровская область, Ленинск-Кузнецкий городской округ, Топкинская, 8	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E610000035ED629AE98C554073F6CE68AB504B40
40165	5	51	35	43	75932	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Телефонная, 5	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40218	5	51	35	43	13566	\N	54.663281778093697	Кемеровская область, Ленинск-Кузнецкий городской округ, Суворова, 131	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E6100000FE60E0B9F78B55404303B16CE6544B40
40205	5	51	35	43	13566	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Суворова, 3		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40211	5	51	35	43	50121	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Советская, 159		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40192	5	51	35	43	50118	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Садовая, 84		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40166	5	51	35	43	50108	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Рылеева, 39		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40222	5	51	35	43	50307	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Рубинштейна, 1		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40189	5	51	35	43	12491	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Пушкина, 9		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40184	5	51	35	43	12491	\N	54.663679813895001	Кемеровская область, Ленинск-Кузнецкий городской округ, Пушкина, 17	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E61000003E7958A8358B554030815B77F3544B40
40152	5	51	35	43	50035	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Пирогова, 3		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40194	5	51	35	43	75634	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Мусохранова, 2а		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40154	5	51	35	43	50293	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Лесной городок, 31		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40214	5	51	35	43	50123	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Кирсанова, 3		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40195	5	51	35	43	13533	\N	54.6644758737445	Кемеровская область, Ленинск-Кузнецкий городской округ, Зорина, 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E61000009BC6F65AD08B55400B7DB08C0D554B40
40187	5	51	35	43	50109	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Зварыгина, 6		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40200	5	51	35	43	12532	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Горького, 10а		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40196	5	51	35	43	12532	\N	54.663082758724002	Кемеровская область, Ленинск-Кузнецкий городской округ, Горького, 16	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E6100000B41D5377658B55404CC45BE7DF544B40
40210	5	51	35	43	13549	\N	54.6640778457785	Кемеровская область, Ленинск-Кузнецкий городской округ, Глинки, 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E610000074B2D47ABF8B55401EFF058200554B40
40186	5	51	35	43	50299	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Вокзальная, 30		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40847	5	51	26	183	75753	\N	56.194553999999997	пгт.Ижморский, ул.Комсомольская, д.5		0101000020E6100000E31A9FC9FEA855402AA73D25E7184C40
40220	5	51	35	43	50124	\N	54.667259999999999	Кемеровская область, Ленинск-Кузнецкий городской округ, Витебская, 52		0101000020E610000063D2DF4BE18B5540E8F692C668554B40
40224	5	51	35	43	12584	\N	54.665172413258198	Кемеровская область, Ленинск-Кузнецкий городской округ, 7 Ноября, 4	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E61000009E961FB8CA8B5540821B295B24554B40
40223	5	51	35	43	13580	\N	54.655917409099999	Кемеровская область, Ленинск-Кузнецкий городской округ, 7 Ноября, 1а	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	0101000020E61000009E961FB8CA8B5540FAF19716F5534B40
40970	5	51	35	6842	9906	\N	54.650063034912698	д. Красноярка, ул. Центральная, дом 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Красноярка	0101000020E6100000315C1D00719455407AABAE4335534B40
40945	5	51	35	41110	12499	\N	54.6062436827537	с. Красное, ул. 40 Лет Октября, дом 7	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Красное	0101000020E61000001FDB32E02C585540B7B24467994D4B40
40981	5	51	35	7337	50014	\N	54.606642000000001	с. Красное, ул. 40 лет Октября, дом 2		0101000020E610000098FC4FFEEE575540A530EF71A64D4B40
40968	5	51	35	60753	75941	\N	54.732953112005802	пос. Красная Поляна, пер. Энергетиков, дом 10	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Красная Поляна	0101000020E6100000C4263273818C5540A7406667D15D4B40
41005	5	51	35	8574	75787	\N	54.619374999999998	с. Камышино, ул. Центральная, дом 68	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Камышино	0101000020E610000076E272BC02735540E17A14AE474F4B40
40965	5	51	35	60734	75846	\N	54.713813000000002	пос. станции Егозово, ул. Полевая, 34	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Егозово	0101000020E6100000BD5301F73C875540D63A71395E5B4B40
40976	5	51	35	6657	12466	\N	54.761343772148599	с. Драченино, пер. Рабочий, дом 1	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Драченино	0101000020E61000002B8881AE7D825540BF805EB873614B40
40967	5	51	35	41234	13550	\N	54.750114647554	пос. Демьяновка, ул. Чкалова, дом 2	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Демьяновка	0101000020E61000001E34BBEEAD8F5540999EB0C403604B40
40963	5	51	35	6005	75788	\N	54.684021999999999	пос. Восходящий, ул. Вострикова, дом 1А		0101000020E6100000E38920CEC38455404CDF6B088E574B40
40998	5	51	35	7701	75986	\N	54.569982000000003	д. Возвышенка, ул. Октябрьская, дом 11, квартира 2		0101000020E61000007AC8940F4177554083A7902BF5484B40
40982	5	51	35	41125	12588	\N	54.555526657656799	с. Ариничево, ул. Центральная, дом 7	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Ариничево	0101000020E610000079AEEFC3415A5540C2853C821B474B40
40958	5	51	613	5759	75781	\N	55.071443000000002	Кемеровская область, Крапивинский район, с. Шевели, Московская, 3		0101000020E61000002AC6F99B509655409A43520B25894B40
40955	5	51	613	5283	75780	\N	54.749454999999998	Кемеровская область, Крапивинский район, с. Тараданово, Садовая, 6		0101000020E61000009E0AB8E7F9AB55406E693524EE5F4B40
40935	5	51	613	4517	75935	\N	54.960576000000003	Кемеровская область, Крапивинский район, с. Скарюпино, Школьная, 18		0101000020E6100000C367EBE0608F554048A98427F47A4B40
40962	5	51	613	5922	75959	\N	55.069113000000002	Кемеровская область, Крапивинский район, с. Сарапки, Центральная, 5-2		0101000020E610000034BA83D8999A55403E5DDDB1D8884B40
40952	5	51	613	5185	75950	\N	54.867907000000002	Кемеровская область, Крапивинский район, с. Поперечное, Набережная, 1		0101000020E61000002AFF5A5EB9B25540187C9A93176F4B40
40942	5	51	613	60774	76159	\N	55.013734999999997	Кемеровская область, Крапивинский район, п. Плотниковка, Школьная, 2	Россия, Кемеровская область, Крапивинский район, поселок Плотниковский	0101000020E6100000041BD7BFEB9E5540C0E78711C2814B40
40953	5	51	613	5439	75778	\N	54.883048000000002	Кемеровская область, Крапивинский район, с. Прехляй, Центральная, 14		0101000020E6100000F6CE68AB92A455402C6684B707714B40
40960	5	51	613	60777	76167	\N	55.045974999999999	Кемеровская область, Крапивинский район, д. Ново-Барачаты, Советская, 1	Россия, Кемеровская область, Крапивинский район, поселок Новобарачаты	0101000020E6100000DBA7E331038B554080B74082E2854B40
40932	5	51	613	4339	75956	\N	55.001328999999998	Кемеровская область, Крапивинский район, п. Михайловский, Кооперативная		0101000020E6100000FD86890629A95540A8C4758C2B804B40
40951	5	51	613	5093	13535	\N	54.932614337749499	Кемеровская область, Крапивинский район, с. Междугорное, 60 лет октября	Россия, Кемеровская область, Крапивинский район, поселок Междугорное	0101000020E61000009372F7393EB5554058E542E55F774B40
40938	5	51	613	4682	75944	\N	54.828496000000001	Кемеровская область, Крапивинский район, с. Максимово, Школьная, 3		0101000020E61000008716D9CEF7A15540F46E2C280C6A4B40
40934	5	51	613	60754	75945	\N	54.997118846375997	Барачатское сельское поселение, п. Красный Ключ, Ленина	Россия, Кемеровская область, Крапивинский район, поселок Красные Ключи	0101000020E61000000F643DB5FA905540309C6B98A17F4B40
40927	5	51	613	3886	75613	\N	55.006630999999999	Кемеровская область, Крапивинский район, рп. Крапивинский, Юбилейная, 4	Россия, Кемеровская область, Крапивинский район, поселок Крапивинский	0101000020E61000007DAF21382EB35540E411DC48D9804B40
40926	5	51	613	3886	50155	\N	55.006630999999999	Кемеровская область, Крапивинский район, р.п. Крапивинский, Мостовая, 32		0101000020E61000007DAF21382EB35540E411DC48D9804B40
40925	5	51	613	3886	50154	\N	55.006630999999999	Кемеровская область, Крапивинский район, рабочий поселок Крапивинский, Кирова, 1А		0101000020E61000007DAF21382EB35540E411DC48D9804B40
40924	5	51	613	3886	50154	\N	55.006630999999999	Кемеровская область, Крапивинский район, рабочий поселок Крапивинский, Кирова, 16А		0101000020E61000007DAF21382EB35540E411DC48D9804B40
40947	5	51	613	5125	75940	\N	54.775022999999997	Кемеровская область, Крапивинский район, д. Ключи, Центральная, 20		0101000020E6100000A8195245F1B55540EB5223F433634B40
40949	5	51	613	5262	75948	\N	54.954796999999999	Кемеровская область, Крапивинский район, п. Каменный, Мира, 17		0101000020E6100000A435069D10AE5540D2A8C0C9367A4B40
40943	5	51	613	4842	75782	\N	54.799287999999997	Кемеровская область, Крапивинский район, с. Каменка, Почтовая, 17А		0101000020E6100000F357C85C19AD5540E90AB6114F664B40
40930	5	51	613	4234	50351	\N	55.002949999999998	Кемеровская область, Крапивинский район, п. Зеленогорский, Центральная, 425		0101000020E61000000ADAE4F049BD5540F8C264AA60804B40
40928	5	51	613	4234	50351	\N	55.002160591071103	Зеленогорское городское поселение, Центральная, 29	Россия, Кемеровская область, Крапивинский район, поселок Зеленогорский	0101000020E61000001DE4F56052BD5540D029C8CF46804B40
40940	5	51	613	60731	75836	\N	55.0016976690695	Кемеровская область, Крапивинский район, с. Зеленовка, Школьная, 27	Россия, Кемеровская область, Крапивинский район, поселок Зеленовский	0101000020E6100000F8325184D4985540FB3BDBA337804B40
40956	5	51	613	5608	75938	\N	54.774535	Кемеровская область, Крапивинский район, с. Долгополово, Мира, 14		0101000020E61000003815A930B6A65540BE4D7FF623634B40
40939	5	51	613	4621	76297	\N	54.808098999999999	"Крапивинский район, с. Борисово, ул. Санатоий, (здание санатория ""Борисовский"")"		0101000020E6100000EA961DE21FA455401477BCC96F674B40
40937	5	51	613	4621	50013	\N	54.808098999999999	Кемеровская область, Крапивинский район, с. Борисово, Геологов, 15		0101000020E6100000EA961DE21FA455401477BCC96F674B40
40959	5	51	613	5768	75936	\N	55.119928999999999	Кемеровская область, Крапивинский район, с. Березовка, Новая		0101000020E61000009EB4705985A05540C66B5ED5598F4B40
40954	5	51	613	5534	75905	\N	54.865595999999996	Кемеровская область, Крапивинский район, с. Бердюгино, Школьная, 3	Россия, Кемеровская область, Крапивинский район, поселок Бердюгино	0101000020E6100000655419C6DD9E554032C687D9CB6E4B40
40933	5	51	613	4404	75779	\N	54.974710999999999	Кемеровская область, Крапивинский район, с. Барачаты, Юбилейная, 23		0101000020E61000000B5D8940F58C554096067E54C37C4B40
40931	5	51	613	4254	75769	\N	55.084322	Кемеровская область, Крапивинский район, с. Банново, Центральная, 6		0101000020E6100000016A6AD95AAD5540AA2A3410CB8A4B40
40944	5	51	613	4991	75937	\N	54.803398000000001	Кемеровская область, Крапивинский район, с. Арсеново, Почтовая, 40		0101000020E6100000384E0AF31EB85540FED5E3BED5664B40
40090	5	51	7515	60710	75713	\N	54.005874384525299	Кемеровская область, Киселевский городской округ, Студенческая, 18/3		0101000020E6100000A9F8BF232AA95540C7F2AE7AC0004B40
40111	5	51	7515	60710	75649	\N	54.005267656322502	Кемеровская область, Киселевский городской округ, Весенняя, 7		0101000020E6100000D368723106A9554090DB2F9FAC004B40
40917	5	51	384	41184	13395	\N	55.248762730144698	Кемеровская область, Кемеровский район, с.Ягуново, Центральная, 25	Россия, Кемеровская область, Кемеровский район, поселок Ягуново	0101000020E6100000312592E86580554038BA4A77D79F4B40
40916	5	51	384	3495	75765	\N	55.562897	Кемеровская область, Кемеровский район, п.Щегловский, Советская, 20		0101000020E610000005DD5ED2187B55401D0247020DC84B40
40912	5	51	384	3269	75927	\N	55.610621000000002	Кемеровская область, Кемеровский район, д.Черемушки, Школьная, 10		0101000020E6100000147651F4C07A55401BA034D428CE4B40
40914	5	51	384	3401	75931	\N	55.621927999999997	Кемеровская область, Кемеровский район, д.Усть-Хмелевка, Школьная, 15		0101000020E6100000CF83BBB376735540BC3B32569BCF4B40
40891	5	51	384	2099	75928	\N	55.712812	Кемеровская область, Кемеровский район, п.Успенка, Промысловая, 7-А		0101000020E6100000EB353D2828A655402219726C3DDB4B40
40900	5	51	384	2565	75922	\N	55.360228999999997	Кемеровская область, Кемеровский район, д.Тебеньковка, Центральная, 10		0101000020E6100000488C9E5BE89655400F09DFFB1BAE4B40
40897	5	51	384	41176	13346	\N	55.237484846580301	Кемеровская область, Кемеровский район, д.Сухая Речка, Школьная, 7	Россия, Кемеровская область, Кемеровский район, поселок Сухая Речка	0101000020E610000029AE2AFBAE875540312592E8659E4B40
40903	5	51	384	2778	75756	\N	55.160735000000003	Кемеровская область, Кемеровский район, д.Старочервово, Советская, 1		0101000020E6100000946B0A64769755404A29E8F692944B40
40892	5	51	384	48904	75925	\N	55.841129000000002	п.Сосновка-2, Школьная, 1		0101000020E610000054C37E4FAC805540CD5B751DAAEB4B40
40902	5	51	384	2675	75777	\N	55.268051	Кемеровская область, Кемеровский район, с.Силино, Центральная, 11		0101000020E61000006B9F8EC70C9355407E54C37E4FA24B40
40890	5	51	384	1979	75750	\N	55.7338149617119	Кемеровская область, Кемеровский район, п.Разведчик, Коммунистическая, 3	Россия, Кемеровская область, Кемеровский район, поселок Разведчик	0101000020E6100000C8EA56CF498A5540392861A6EDDD4B40
40060	5	51	384	60866	76499	\N	55.4968333019008	ул.Пром.шоссе, 56а (Д/К)	Россия, Кемеровская область, Кемеровский район, поселок Промышленновский	0101000020E6100000B1A71DFE9A8A55406B49473998BF4B40
40913	5	51	384	3361	\N	\N	55.562989000000002	Кемеровская область, Кемеровский район, д.Подьяково, Кедровый бор		0101000020E6100000B890477023755540FE80070610C84B40
40901	5	51	384	2667	75767	\N	55.389508999999997	Кемеровская область, Кемеровский район, д.Осиновка, Центральная, 1-А		0101000020E6100000F8E28BF678935540B33F506EDBB14B40
41193	5	51	384	2330	\N	\N	55.250706911014902	п.Новостройка, СДК п.Новостройка	Россия, Кемеровская область, Кемеровский район, поселок Новостройка	0101000020E6100000836A8313D18D55406BF0BE2A17A04B40
40896	5	51	384	2330	50262	\N	55.251342000000001	Кемеровская область, Кемеровский район, п.Новостройка, Набережная, 3		0101000020E610000035D3BD4EEA8D55403D0E83F92BA04B40
40921	5	51	384	60726	75783	\N	55.325609999999998	Кемеровская область, Кемеровский район, с.Мазурово, Школьная, 2-А		0101000020E6100000D7D9907F6679554012A0A696ADA94B40
40894	5	51	384	2220	50010	\N	55.141938000000003	Кемеровская область, Кемеровский район, п.Кузбасский, Лобанова, 14		0101000020E6100000AF2479AEEF895540A3073E062B924B40
40057	5	51	384	45980	\N	\N	55.51484	Кедровка, ул.Стахановская, 27 (шк.№70)	Россия, Кемеровская область, Кемеровский район, поселок Кедровка	0101000020E61000000533A6608D8655401956F146E6C14B40
40053	5	51	384	45980	76318	\N	55.515356353714097	Кедровка, ул.Стадионная,22а(спорткомпл"Горняк")	Россия, Кемеровская область, Кемеровский район, поселок Кедровка	0101000020E610000048C153C89586554010E6762FF7C14B40
40055	5	51	384	45980	76285	\N	55.519295995856901	Кедровка, ул.Советская, 5а (шк.№96)		0101000020E6100000A4E194B9F9855540C878944A78C24B40
40054	5	51	384	45980	76267	\N	55.51484	Кедровка, ул.Новогодняя, 15а (Д/К Содружество)	Россия, Кемеровская область, Кемеровский район, поселок Кедровка	0101000020E61000000533A6608D8655401956F146E6C14B40
40052	5	51	384	45980	76267	\N	55.51484	Кедровка,ул.Новогодняя, 8 (шк.52)		0101000020E61000000533A6608D8655401956F146E6C14B40
40904	5	51	384	2790	75773	\N	55.455162000000001	Кемеровская область, Кемеровский район, п.Звездный, Центральная, 12		0101000020E61000007B849A2155765540E43098BF42BA4B40
40915	5	51	384	3456	13388	\N	55.469957427570101	Кемеровская область, Кемеровский район, с.Верхотомское, Московская, 31	Россия, Кемеровская область, Кемеровский район, поселок Верхотомское	0101000020E6100000B29C84D2177D55405DC30C8D27BC4B40
40906	5	51	384	41093	12425	\N	55.400431972262098	Кемеровская область, Кемеровский район, п.Благодатный, Весенняя, 1-А	Россия, Кемеровская область, Кемеровский район, поселок Благодатный	0101000020E61000004277499C15745540CD22145B41B34B40
40895	5	51	384	2325	50347	\N	55.232914999999998	Кемеровская область, Кемеровский район, с.Березово, Абызова, 14		0101000020E61000003C855CA9678F5540B9DFA128D09D4B40
40893	5	51	384	2209	50009	\N	55.137872999999999	Кемеровская область, Кемеровский район, д.Береговая, Молодежная, 1		0101000020E6100000D960E124CD9355402E008DD2A5914B40
40911	5	51	384	3256	75771	\N	55.638469999999998	Кемеровская область, Кемеровский район, д.Барановка, Центральная, 22-А		0101000020E610000011514CDE007D554012BD8C62B9D14B40
40898	5	51	384	2449	50152	\N	55.444291999999997	Кемеровская область, Кемеровский район, д.Андреевка, Советская, 18		0101000020E61000000E2DB29DEF8D5540EDEF6C8FDEB84B40
39806	5	51	7521	60804	76299	\N	53.553747224779997	652830, Кемеровская область, Калтанский городской округ, п. Малиновка, Советская, 44	Россия	0101000020E6100000A81E69705BC555400AA1832EE1C64A40
40866	5	51	26	29220	76214	\N	56.343474999999998	с.Теплая Речка, ул.Строителей, д.3	Россия, Кемеровская область, Ижморский район, поселок Тёплая Речка	0101000020E6100000BAA0BE654EAA55402EFF21FDF62B4C40
40880	5	51	26	1396	75980	\N	56.019935409302299	с.Тунда, ул.Ленина, д.23	Россия, Кемеровская область, Ижморский район, поселок Тунда	0101000020E6100000E2900DA48BC45540DB85E63A8D024C40
40889	5	51	26	48851	75748	\N	56.057206999999998	с.Троицкое, ул.Молодежная, д.30		0101000020E6100000D8648D7A88B85540170D198F52074C40
40878	5	51	26	1313	75919	\N	56.040973000000001	с.Симбирка, Новая, 177		0101000020E61000002C2B4D4A41CA55406F826F9A3E054C40
40872	5	51	26	48559	75926	\N	56.437680999999998	с.Святославка, ул.Советская, д.31А		0101000020E6100000FC8EE1B19FB35540508A56EE05384C40
40884	5	51	26	1522	75929	\N	56.285938000000002	с.Почитанка, ул.Ленинская, д.66А		0101000020E61000001B62BCE655AC55408257CB9D99244C40
40883	5	51	26	41170	13298	\N	56.241752041729299	с.Постниково, ул.Ленинская, д.69А	Россия, Кемеровская область, Ижморский район, поселок Постниково	0101000020E61000005D6A847EA6B155400DDFC2BAF11E4C40
40873	5	51	26	48577	\N	\N	56.377088999999998	с.Островка, ул.Островского, д.20	Россия, Кемеровская область, Ижморский район, поселок Островка	0101000020E61000007D93A641D1BC55403657CD7344304C40
40865	5	51	26	48428	76063	\N	56.553471000000002	д.Ольговка, ул.Лесная, д.10		0101000020E61000005C0531D0B597554068244223D8464C40
40868	5	51	26	48498	\N	\N	55.826118999999998	п.Новый Свет, ул.Садовая, д.12	Россия, Кемеровская область, Ижморский район, поселок Новый Свет	0101000020E61000000DE4D9E55BB5554057CD7344BEE94B40
40875	5	51	26	1161	75918	\N	56.535105000000001	с.Новославянка, ул.Молодежная, д.13		0101000020E61000007286E28E37B255408A7615527E444C40
40876	5	51	26	48639	76026	\N	56.566256556776899	д.Новоорловка, Заречная, 27	Россия, Кемеровская область, Ижморский район, поселок Новоорловка	0101000020E6100000849F38807EAB5540C710001C7B484C40
40867	5	51	26	48466	75951	\N	56.408408000000001	с.Нижегородка, ул.Советская, д.49		0101000020E61000005E6397A8DEA655405FB69DB646344C40
40888	5	51	26	41086	12401	\N	56.136235999999997	с.Ломачевка, ул.Школьная, д.6		0101000020E6100000C15774EB35B55540D844662E70114C40
40879	5	51	26	1390	75975	\N	55.989854000000001	с.Летяжка, ул.Молодежная, д.23		0101000020E61000004374081C09CC55404BE82E89B3FE4B40
40877	5	51	26	41165	13291	\N	56.535693936582497	с.Левашовка, ул.Набережная, д.7	Россия, Кемеровская область, Ижморский район, поселок Левашовка	0101000020E610000034DAAA24B2BA5540EB54F99E91444C40
40869	5	51	26	48501	75758	\N	55.903983217438203	с.Красный Яр, пер.Школьный, 2		0101000020E6100000DE1E84807CBC5540EA9106B7B5F34B40
40871	5	51	26	923	76021	\N	55.901248000000002	д.Красная Тайга, ул.Центральная, д.11-2		0101000020E61000006B49473998B85540EFCA2E185CF34B40
40874	5	51	26	1057	76024	\N	56.371473714322001	п.Котовский, ул.Школьная, д.15	Россия, Кемеровская область, Ижморский район, поселок Котовский	0101000020E610000093A641D13CB155403BA8C4758C2F4C40
40864	5	51	26	452	75746	\N	56.473847999999997	с.Колыон, ул.Микрорайон, д.3		0101000020E61000008A3F8A3A73A3554033A31F0DA73C4C40
40860	5	51	26	183	75743	\N	56.194268820804403	пгт. Ижморский, ул.Почтовая, д.8	Россия, Кемеровская область, Ижморский район, поселок Ижморский	0101000020E61000008061F9F36DA9554035D07CCEDD184C40
40862	5	51	26	183	76221	\N	56.194553999999997	Ижморский муниципальный район, Ижморское городское поселение, пгт.Ижморский, ул.Лесная (Помещение отделения сестринского ухода ЦРБ), д.25		0101000020E6100000E31A9FC9FEA855402AA73D25E7184C40
40861	5	51	26	183	50068	\N	56.194553999999997	пгт. Ижморский, ул.Ленинская, д.84		0101000020E6100000E31A9FC9FEA855402AA73D25E7184C40
40261	5	51	26	183	50068	\N	56.195893859409502	пгт. Ижморский, ул.Ленинская, д.119	Россия, Кемеровская область, Ижморский район, поселок Ижморский	0101000020E61000007F6B274A42A95540C7BDF90D13194C40
40824	5	51	26	183	75742	\N	56.195465152020397	пгт.Ижморский, ул.Кирова, д.4	Россия, Кемеровская область, Ижморский район, поселок Ижморский	0101000020E6100000BA2C26361FA955409E4143FF04194C40
40858	5	51	26	31	75916	\N	56.159478999999997	с.Ижморка, ул.Москалева, д.51А		0101000020E6100000F20BAF2479A855400BB3D0CE69144C40
40870	5	51	26	41077	12375	\N	55.943331000000001	с.Иверка, ул.Трактовая, д.3-2		0101000020E6100000419E5DBEF5B45540C826F911BFF84B40
40887	5	51	26	1756	75957	\N	56.137529999999998	с.Воскресенка, ул.Школьная, д.20		0101000020E61000000A647616BDBC5540041C42959A114C40
40881	5	51	26	1500	75921	\N	56.235790999999999	д.Большая Песчанка, ул.Ленинская, д.53		0101000020E6100000C6A6954220B8554077D844662E1E4C40
40538	5	51	26	17165	75989	\N	56.209676000000002	с.Берикуль, ул.Молодежная, д.2Б		0101000020E61000009A6038D730C45540C860C5A9D61A4C40
40859	5	51	26	48327	76020	\N	56.113861791200101	с.Азаново, ул.Колхозная, д.24	Россия, Кемеровская область, Ижморский район, поселок Азаново	0101000020E6100000E3A7716F7EA45540EA20AF07930E4C40
40840	5	51	1192	41059	12295	\N	54.449259681600402	Кемеровская область, Гурьевский муниципальный район, Урское сельское поселение, Широкая, 29	Россия, Кемеровская область, Гурьевский район, поселок Урск	0101000020E6100000C4D0EAE40C59554053B3075A81394B40
40835	5	51	1192	60742	75882	\N	54.452084997184897	Кемеровская область, Гурьевский муниципальный район, Урское сельское поселение, Стахановская, 36		0101000020E61000008F71C5C5515955408E01D9EBDD394B40
40838	5	51	1192	60742	76182	\N	54.452638	Кемеровская область, Гурьевский муниципальный район, Урское сельское поселение, Солнечная, 36	Россия, Кемеровская область, Гурьевский район, поселок Урск	0101000020E6100000F20BAF2479595540A376BF0AF0394B40
40836	5	51	1192	60742	76189	\N	54.452638	Кемеровская область, Гурьевский муниципальный район, Урское сельское поселение, Пушкина, 40	Россия, Кемеровская область, Гурьевский район, поселок Урск	0101000020E6100000F20BAF2479595540A376BF0AF0394B40
40837	5	51	1192	60742	76169	\N	54.452638	652764, Кемеровская область, Гурьевский муниципальный район, Урское сельское поселение, Мира, 42	Россия, Кемеровская область, Гурьевский район, поселок Урск	0101000020E6100000F20BAF2479595540A376BF0AF0394B40
40839	5	51	1192	60742	76173	\N	54.451434807061602	Кемеровская область, Гурьевский муниципальный район, Урское сельское поселение, Алтайская, 29	Россия, Кемеровская область, Гурьевский район, поселок Урск	0101000020E61000004015376E3159554087A2409FC8394B40
40857	5	51	1192	60779	76172	\N	54.442722000000003	Кемеровская область, Гурьевский муниципальный район, Ур-Бедаревское сельское поселение, Советская, 48	Россия, Кемеровская область, Гурьевский район, поселок Ур-Бедари	0101000020E6100000D76CE525FF7B5540209C4F1DAB384B40
40856	5	51	1192	60779	76187	\N	54.439809149875103	Кемеровская область, Гурьевский муниципальный район, Ур-Бедаревское сельское поселение, Проездная, 6	Россия, Кемеровская область, Гурьевский район, поселок Ур-Бедари	0101000020E610000045D5AF743E7C554044BE4BA94B384B40
40845	5	51	1192	41067	12333	\N	54.294562423937201	Кемеровская область, Гурьевский муниципальный район, Сосновское сельское поселение, 8 Марта, 14	Россия, Кемеровская область, Гурьевский район, поселок Сосновка	0101000020E610000024D6E253006E55407A522635B4254B40
40846	5	51	1192	60783	76212	\N	54.294626359806699	Кемеровская область, Гурьевский муниципальный район, Сосновское сельское поселение, Пушкина, 9	Россия, Кемеровская область, Гурьевский район, поселок Сосновка	0101000020E610000004013274EC6D55409146054EB6254B40
40848	5	51	1192	60783	76195	\N	54.293923999999997	Кемеровская область, Гурьевский муниципальный район, Сосновское сельское поселение, Полевая, 1-а	Россия, Кемеровская область, Гурьевский район, поселок Сосновка	0101000020E610000054E41071736E554037C1374D9F254B40
40849	5	51	1192	60783	76205	\N	54.294726578101098	Кемеровская область, Гурьевский муниципальный район, Сосновское сельское поселение, К.Маркса, 2	Россия, Кемеровская область, Гурьевский район, поселок Сосновка	0101000020E6100000E86A2BF6976E5540C51F459DB9254B40
40832	5	51	1192	41144	76177	\N	54.230648915849201	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Станционная, 1	Россия, Кемеровская область, Гурьевский район, Салаир	0101000020E6100000BE6A65C22F74554074ED0BE8851D4B40
40830	5	51	1192	41144	69922	\N	54.234127000000001	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Ленина, 1	Россия, Кемеровская область, Гурьевский район, Салаир	0101000020E6100000F8A8BF5E61735540280EA0DFF71D4B40
40826	5	51	1192	41144	75895	\N	54.230397487081802	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Крупской, 9	Россия, Кемеровская область, Гурьевский район, Салаир	0101000020E6100000E57E87A2407455405B0C1EA67D1D4B40
40828	5	51	1192	41144	75611	\N	54.234127000000001	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Коммунистическая, 7	Россия, Кемеровская область, Гурьевский район, Салаир	0101000020E6100000F8A8BF5E61735540280EA0DFF71D4B40
40834	5	51	1192	41144	50525	\N	54.234127000000001	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Гагарина, 102	Россия, Кемеровская область, Гурьевский район, Салаир	0101000020E6100000F8A8BF5E61735540280EA0DFF71D4B40
40827	5	51	1192	41144	50525	\N	54.229370148866401	Кемеровская область, Гурьевский муниципальный район, Салаирское городское поселение, Гагарина, 1	Россия, Кемеровская область, Гурьевский район, Салаир	0101000020E61000002733DE567A7355407E5704FF5B1D4B40
40851	5	51	1192	60741	76213	\N	54.292855338569296	Кемеровская область, Гурьевский муниципальный район, Раздольное сельское поселение, Шоссейная, 1	Россия, Кемеровская область, Гурьевский район, поселок Раздольный	0101000020E61000001651137D3E8055402CBCCB457C254B40
40850	5	51	1192	60741	75877	\N	54.292563102904602	Кемеровская область, Гурьевский муниципальный район, Раздольное сельское поселение, Центральная, 9а	Россия, Кемеровская область, Гурьевский район, поселок Раздольный	0101000020E6100000A2D3F36E2C805540848252B472254B40
40852	5	51	1192	60741	76268	\N	54.293065197795002	Кемеровская область, Гурьевский муниципальный район, Раздольное сельское поселение, Клубная, 2		0101000020E6100000C9E7154F3D805540164D672783254B40
40844	5	51	1192	60733	76192	\N	54.446558636687897	Кемеровская область, Гурьевский муниципальный район, Новопестеревское сельское поселение, Центральная, 39	Россия, Кемеровская область, Гурьевский район, поселок Новопестерево	0101000020E6100000331AF9BCE26E5540035E66D828394B40
40842	5	51	1192	60733	75843	\N	54.444507723790998	Кемеровская область, Гурьевский муниципальный район, Новопестеревское сельское поселение, Степная, 22	Россия, Кемеровская область, Гурьевский район, поселок Новопестерево	0101000020E6100000FAD005F52D6F5540BA675DA3E5384B40
40843	5	51	1192	60733	75913	\N	54.447098215195503	Кемеровская область, Гурьевский муниципальный район, Новопестеревское сельское поселение, Лесная, 5/1	Россия, Кемеровская область, Гурьевский район, поселок Новопестерево	0101000020E61000009C340D8AE66E5540B20DDC813A394B40
40855	5	51	1192	60700	75586	\N	54.328502	Кемеровская область, Гурьевский муниципальный район, Малосалаирское сельское поселение, Трактовая, 2	Россия, Кемеровская область, Гурьевский район, поселок Малая Салаирка	0101000020E6100000A7C98CB7957C5540D655815A0C2A4B40
39784	5	51	1192	41063	50451	\N	54.2863554468682	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Лермонтова, 107	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000A7052FFA0A7C5540E605D847A7244B40
39761	5	51	1192	41063	50093	\N	54.286076503959201	Кемеровская область, Гурьевский муниципальный район, Гурьевское городское поселение, пер. Лесной, 1	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000C8EE0225057B5540A391CF2B9E244B40
39766	5	51	1192	41063	50549	\N	54.287785244687399	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Садовая, 8	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000338D2617637C5540C2A38D23D6244B40
39760	5	51	1192	41063	75596	\N	54.284647999999997	Кемеровская область, Гурьевский муниципальный район, Гурьевское городское поселение, Революционная, 95	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000CE6C57E8837C5540976F7D586F244B40
39780	5	51	1192	41063	69679	\N	54.284647999999997	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Лермонтова, 9	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000CE6C57E8837C5540976F7D586F244B40
39773	5	51	1192	41063	75881	\N	54.284971306438798	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Ленина, 64	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E610000008AD872F137B55407AA702EE79244B40
39764	5	51	1192	41063	69649	\N	54.284484021392799	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Коммунистическая, 23	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E61000005E9D6340F67C55401D1EC2F869244B40
39790	5	51	1192	41063	75851	\N	54.2886877433384	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Коммунистическая, 12А		0101000020E6100000EBC37AA3567C5540B35F77BAF3244B40
39789	5	51	1192	41063	75851	\N	54.284948550905398	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Коммунистическая, 19	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000A5164A26A77C55409203763579244B40
39782	5	51	1192	41063	12321	\N	54.287281712029099	Кемеровская область, Гурьевский район, Гурьевское городское поселение, Войкова, 186	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E6100000B03DB324407C55405F5D15A8C5244B40
39763	5	51	1192	41063	75880	\N	54.285952921051198	Кемеровская область, Гурьевский район, Гурьевское городское поселение, 40 лет ВЛКСМ, 28	Россия, Кемеровская область, Гурьевский район, Гурьевск	0101000020E61000002E910BCEE07C5540B7989F1B9A244B40
40853	5	51	1192	60748	75904	\N	54.466228999999998	Кемеровская область, Гурьевский муниципальный район, Горскинское сельское поселение, Революционная, 47	Россия, Кемеровская область, Гурьевский район, поселок Горскино	0101000020E61000003E7958A83568554030B95164AD3B4B40
41090	5	51	1192	60791	76210	\N	54.260222895071003	п.Гавриловка, Молодежная, 11-1	Россия, Кемеровская область, Гурьевский район, поселок Гавриловка	0101000020E610000059BE2EC37F7555406155BDFC4E214B40
40804	5	51	890	60759	\N	\N	54.354303999999999	Кемеровская область, Беловский район, пос.ст.Разрез, контора вагонного депо ст.Разрез	Россия, Кемеровская область, Беловский район	0101000020E6100000274F594DD7885540C66B5ED5592D4B40
39680	5	51	890	59361	69799	\N	54.360019306124002	Кемеровская область, Беловский городской округ, мкрн Старобелово, Фрунзе ул, 3	Россия, Кемеровская область, Беловский район	0101000020E6100000C98FF8156B9655402578431A152E4B40
39176	3	24	\N	1518	59247	\N	61.767342999999997	город Петрозаводск, Березовая аллея, 28		0101000020E610000049658A390828414042E8A04B38E24E40
40802	5	51	890	29862	\N	\N	54.310578	"Кемеровская область, Беловский район, пос.им.Ильича, контора ООО ""Светлана"""		0101000020E6100000C6DCB5847C985540B56D1805C1274B40
40820	5	51	890	30736	\N	\N	54.198273999999998	Кемеровская область, Беловский район, п.Щебзавод, школа п.Щебзавод		0101000020E61000007E1D3867448B5540D4D2DC0A61194B40
40817	5	51	890	30577	\N	\N	54.212608000000003	Кемеровская область, Беловский район, д.Шестаки, клуб д.Шестаки		0101000020E6100000A19E3E027F9055401A6F2BBD361B4B40
40777	5	51	890	28713	\N	\N	54.475914000000003	Кемеровская область, Беловский район, д.Хахалино, здание ФАП д.Хахалино		0101000020E6100000FA7ABE66B9A15540B2DAFCBFEA3C4B40
40782	5	51	890	28948	\N	\N	54.523769999999999	Кемеровская область, Беловский район, д.Уроп, библиотека с.Уроп		0101000020E61000007155D97745AB55401E5036E50A434B40
40811	5	51	890	30270	\N	\N	54.478328151073597	Кемеровская область, Беловский район, п.Убинский, клуб п.Убинский	Россия, Кемеровская область, Беловский район, поселок Убинский	0101000020E6100000691B7FA2B29355406B6116DA393D4B40
40787	5	51	890	41123	\N	\N	54.306817000000002	Кемеровская область, Беловский район, п.Степной, сельский клуб п.Степной		0101000020E6100000F94A2025769E5540AD6D8AC745274B40
40773	5	51	890	28464	\N	\N	54.497582000000001	Кемеровская область, Беловский район, с.Старопестерево, школа с.Старопестерево		0101000020E6100000C7DADFD91E995540058A58C4B03F4B40
40772	5	51	890	28464	\N	\N	54.497582000000001	"Кемеровская область, Беловский район, с.Старопестерево, СДК ""Горняк"" с.Старопестерево"		0101000020E6100000C7DADFD91E995540058A58C4B03F4B40
40816	5	51	890	30340	\N	\N	54.240656999999999	Кемеровская область, Беловский район, п.Старобачаты, Бачатская основная школа		0101000020E610000009A87004A98C5540D8463CD9CD1E4B40
40815	5	51	890	30340	\N	\N	54.240656999999999	Кемеровская область, Беловский район, п.Старобачаты, СДК п.Старобачаты		0101000020E610000009A87004A98C5540D8463CD9CD1E4B40
40813	5	51	890	30340	\N	\N	54.240656999999999	Кемеровская область, Беловский район, п.Старобачаты, детский сад п.Старобачаты		0101000020E610000009A87004A98C5540D8463CD9CD1E4B40
40775	5	51	890	28579	\N	\N	54.439900000000002	Кемеровская область, Беловский район, п.Снежинский, школа п.Снежинский		0101000020E6100000ACFD9DEDD197554055C1A8A44E384B40
40789	5	51	890	41124	\N	\N	54.376752081459003	Кемеровская область, Беловский район, с.Сидоренково, школа с.Сидоренково	Россия, Кемеровская область, Беловский район, поселок Сидоренково	0101000020E610000009FB761211A65540EF59D76839304B40
40785	5	51	890	41122	\N	\N	54.559489999999997	Кемеровская область, Беловский район, д.Рямовая, клуб д.Рямовая		0101000020E61000006E13EE9579BB554032384A5E9D474B40
40809	5	51	890	23478	\N	\N	54.544974045129202	Кемеровская область, Беловский район, п.ст.Проектная, вокзал п.ст.Проектная	Россия, Кемеровская область, Беловский район, поселок Проектная	0101000020E61000005AF624B0398F5540CD9541B5C1454B40
40664	5	51	890	23478	50083	\N	54.545197999999999	Кемеровская область, Прокопьевский городской округ, Зенковский район, Проектная, 96		0101000020E6100000397B67B4558F55401CEC4D0CC9454B40
40788	5	51	890	29218	\N	\N	54.3958054796407	Кемеровская область, Беловский район, с.Поморцево, клуб с.Поморцево	Россия, Кемеровская область, Беловский район, поселок Поморцево	0101000020E6100000DCF4673F52A15540F14BFDBCA9324B40
40797	5	51	890	41130	\N	\N	54.465674999999997	Кемеровская область, Беловский район, с.Пермяки, школа с.Пермяки		0101000020E61000002AFF5A5EB9BA55404BC8073D9B3B4B40
40796	5	51	890	29453	\N	\N	54.392187	Кемеровская область, Беловский район, п.Новый Каракан, клуб п.Новый Каракан		0101000020E6100000C2DF2F664BAD55404B75012F33324B40
39696	5	51	890	41069	12336	\N	54.3006082371151	Кемеровская область, Беловский городской округ, пгт Новый Городок, Гражданская, 16	Россия, Кемеровская область, Беловский район, поселок Новый Городок	0101000020E6100000B35E0CE5449355403E75AC527A264B40
39698	5	51	890	41069	12777	\N	54.3002066356078	Кемеровская область, Беловский городской округ, пгт Новый Городок, Гастелло, 10	Россия, Кемеровская область, Беловский район, поселок Новый Городок	0101000020E61000006536C82423935540E083D72E6D264B40
39695	5	51	890	60702	75592	\N	54.304851999999997	Кемеровская область, Беловский городской округ, пгт Новый Городок, Киевская, 23		0101000020E6100000280EA0DFF7925540620FED6305274B40
40798	5	51	890	29644	\N	\N	54.508498000000003	Кемеровская область, Беловский район, с.Новохудяково, клуб с.Новохудяково		0101000020E61000005EBC1FB75FB555406C0A647616414B40
40806	5	51	890	30047	\N	\N	54.446010000000001	Кемеровская область, Беловский район, д.Новороссийка, клуб д.Новороссийка		0101000020E610000083312251688B554030D80DDB16394B40
40800	5	51	890	29741	\N	\N	54.253757	Кемеровская область, Беловский район, с.Новобачаты, школа с.Новобачаты		0101000020E61000009A40118B18965540C710001C7B204B40
40768	5	51	890	28288	\N	\N	54.579501	Кемеровская область, Беловский район, с.Мохово, СДК с.Мохово		0101000020E61000006A50340F60965540E97FB9162D4A4B40
40810	5	51	890	30245	\N	\N	54.501455999999997	Кемеровская область, Беловский район, п.ст.Мереть, ФП п.ст.Мереть		0101000020E61000009B8E006E169455400531D0B52F404B40
40779	5	51	890	28839	\N	\N	54.427379000000002	"Кемеровская область, Беловский район, с.Менчереп, МБУ ""Культурно-досуговый центр Беловского района"" с.Менчереп"		0101000020E6100000FE7E315BB29E5540A4FFE55AB4364B40
40776	5	51	890	28670	\N	\N	54.460498999999999	Кемеровская область, Беловский район, д.Коротково, сельский клуб д.Коротково		0101000020E61000003DD4B661149C55409C6B98A1F13A4B40
40790	5	51	890	29306	\N	\N	54.353028999999999	Кемеровская область, Беловский район, с.Коновалово, клуб с.Коновалово	Россия, Кемеровская область, Беловский район, поселок Коновалово	0101000020E6100000F4FC69A33AAA554011C5E40D302D4B40
40808	5	51	890	30130	\N	\N	54.528973999999998	Кемеровская область, Беловский район, с.Конево, клуб с.Конево		0101000020E61000004A97FE25A98F55409737876BB5434B40
40799	5	51	890	29717	\N	\N	54.391597192419901	Кемеровская область, Беловский район, с.Каралда, школа с.Каралда	Россия, Кемеровская область, Беловский район, поселок Каралда	0101000020E61000007BBC900E0FBF5540191BBAD91F324B40
40794	5	51	890	41127	\N	\N	54.392276000000003	Кемеровская область, Беловский район, с.Каракан, СДК им.Есенина с.Каракан		0101000020E61000007D3D5FB35CB15540BB80971936324B40
40807	5	51	890	41136	\N	\N	54.494847	Кемеровская область, Беловский район, д.Калиновка, клуб д.Калиновка		0101000020E610000051A04FE4498D554009C38025573F4B40
40783	5	51	890	60761	\N	\N	54.607863000000002	Кемеровская область, Беловский район, д.Инюшка, школа д.Инюшка		0101000020E610000090A2CEDC43B3554067B96C74CE4D4B40
39713	5	51	890	9204	50027	\N	54.433590000000002	Кемеровская область, Беловский городской округ, пгт Инской, Энергетическая, 13		0101000020E6100000338B506C059B5540B3EF8AE07F374B40
39714	5	51	890	9204	50087	\N	54.433590000000002	Кемеровская область, Беловский городской округ, пгт Инской, Чистопольская, 13		0101000020E6100000338B506C059B5540B3EF8AE07F374B40
39712	5	51	890	9204	49956	\N	54.433590000000002	Кемеровская область, Беловский городской округ, пгт Инской, Парковая, 4		0101000020E6100000338B506C059B5540B3EF8AE07F374B40
39715	5	51	890	9204	50276	\N	54.433590000000002	Кемеровская область, Беловский городской округ, пгт Инской, Ильича, 28		0101000020E6100000338B506C059B5540B3EF8AE07F374B40
40805	5	51	890	29986	\N	\N	54.469844999999999	Кемеровская область, Беловский район, д.Ивановка, СДК д.Ивановка		0101000020E6100000B85A272EC78F5540359886E1233C4B40
40770	5	51	890	28383	\N	\N	54.530797	Кемеровская область, Беловский район, п.Заря, клуб п.Заря		0101000020E610000067F0F78BD9A055404FE8F527F1434B40
40769	5	51	890	28361	\N	\N	54.594976000000003	Кемеровская область, Беловский район, с.Заринское, СДК с.Заринское		0101000020E61000000E2F88484DA05540D4F36E2C284C4B40
39699	5	51	890	8604	75963	\N	54.313361999999998	Кемеровская область, Беловский городской округ, Заречное, Кузбасская, 57		0101000020E6100000EE4108C8978F554092E7FA3E1C284B40
40780	5	51	890	28846	\N	\N	54.430453	Кемеровская область, Беловский район, п.Задубровский, клуб п.Задубровский		0101000020E6100000B3EDB43522A7554088BB7A1519374B40
40792	5	51	890	29364	\N	\N	54.354824000000001	Кемеровская область, Беловский район, с.Евтино, СДК с.Евтино		0101000020E6100000DDB243FCC3AC5540FFEA71DF6A2D4B40
40781	5	51	890	28931	\N	\N	54.468254000000002	Кемеровская область, Беловский район, п.Дунай-Ключ, СДК п.Дунай-Ключ	Россия, Кемеровская область, Беловский район, поселок Дунай-Ключ	0101000020E61000004E2844C021AD5540501C40BFEF3B4B40
39721	5	51	890	9363	50269	\N	54.519615000000002	Кемеровская область, Беловский городской округ, пгт Грамотеино, Центральная, 1		0101000020E6100000E42F2DEA939855406AC18BBE82424B40
39718	5	51	890	9363	50277	\N	54.519615000000002	Кемеровская область, Беловский городской округ, пгт Грамотеино, Светлая, 22А		0101000020E6100000E42F2DEA939855406AC18BBE82424B40
39717	5	51	890	9363	50277	\N	54.519615000000002	Кемеровская область, Беловский городской округ, пгт Грамотеино, Светлая, 12А		0101000020E6100000E42F2DEA939855406AC18BBE82424B40
39720	5	51	890	9363	49957	\N	54.519615000000002	Кемеровская область, Беловский городской округ, пгт Грамотеино, Лесная, 1		0101000020E6100000E42F2DEA939855406AC18BBE82424B40
39722	5	51	890	9363	50088	\N	54.519615000000002	Кемеровская область, Беловский городской округ, пгт Грамотеино, Колмогоровская, 19А		0101000020E6100000E42F2DEA939855406AC18BBE82424B40
39716	5	51	890	9363	49952	\N	54.519615000000002	Кемеровская область, Беловский городской округ, пгт Грамотеино, Грамотеинская, 31		0101000020E6100000E42F2DEA939855406AC18BBE82424B40
39719	5	51	890	9363	50286	\N	54.519615000000002	Кемеровская область, Беловский городской округ, пгт Грамотеино, 7 Ноября, 16		0101000020E6100000E42F2DEA939855406AC18BBE82424B40
40786	5	51	890	29050	\N	\N	54.411427002993101	"Кемеровская область, Беловский район, с.Вишневка, контора колхоза ""Вишневский"""	Россия, Кемеровская область, Беловский район, поселок Вишневка	0101000020E6100000E6913F187899554080D8D2A3A9344B40
40818	5	51	890	60766	\N	\N	54.193928647865199	Кемеровская область, Беловский район, п.ст.Бускускан, общежитие п.ст.Бускускан	Россия, Кемеровская область, Беловский район, поселок Бускускан	0101000020E6100000759483D9049055407C5F5CAAD2184B40
39667	5	51	890	41141	50548	\N	54.3765415743528	Кемеровская область, Беловский городской округ, Юности, 26	Россия, Кемеровская область, Беловский район, Белово	0101000020E610000074620FED6396554004C93B8732304B40
39683	5	51	890	41141	75984	\N	54.387851638973402	Кемеровская область, Беловский городской округ, мкрн Бабанаково, Энгельса, 18	Россия, Кемеровская область, Беловский район, Белово	0101000020E61000007F315BB22A95554017D86322A5314B40
39681	5	51	890	41141	75641	\N	54.409170340063802	Кемеровская область, Беловский городской округ, мкрн Бабанаково, Энгельса ул, 6		0101000020E61000006C5A2904729355408E40BCAE5F344B40
39686	5	51	890	41141	12772	\N	54.373433752624997	652616, Кемеровская область, Беловский городской округ, мкрн Бабанаково, Шахтовая, 78	Россия, Кемеровская область, Беловский район, Белово	0101000020E610000082E7DEC325965540749B70AFCC2F4B40
39663	5	51	890	41141	50491	\N	54.375050867249101	Кемеровская область, Беловский городской округ, Цинкзаводской пер, 22А	Россия, Кемеровская область, Беловский район, Белово	0101000020E61000002DCF83BBB396554082AAD1AB01304B40
39674	5	51	890	41141	75583	\N	54.384757999999998	Кемеровская область, Беловский городской округ, Советская, 60	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000282A1BD654945540EB6F09C03F314B40
39175	3	24	\N	1518	59247	\N	61.771104999999999	город Петрозаводск, Березовая аллея, 42		0101000020E6100000115663096B2741401B649291B3E24E40
39669	5	51	890	41141	75583	\N	54.384757999999998	Кемеровская область, Беловский городской округ, Советская, 31	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000282A1BD654945540EB6F09C03F314B40
39692	5	51	890	41141	75639	\N	54.377560042879097	Кемеровская область, Беловский городской округ, мкрн Чертинский, Победы, 21		0101000020E6100000658D7A88469655408E23D6E253304B40
39666	5	51	890	41141	13674	\N	54.374035076580398	Кемеровская область, Беловский городской округ, Морозова, 4	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000965984622B9655409947FE60E02F4B40
39687	5	51	890	41141	75755	\N	54.381450677991999	Кемеровская область, Беловский городской округ, мкрн Совхозный, Механическая ул, 1Б	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000965984622B9655406403E962D3304B40
39678	5	51	890	41141	75591	\N	54.384757999999998	Кемеровская область, Беловский городской округ, Линейный переулок, 41	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000282A1BD654945540EB6F09C03F314B40
39673	5	51	890	41141	69820	\N	54.377293855803103	Кемеровская область, Беловский городской округ, Ленина, 48		0101000020E61000009EB64604E39555400F7D772B4B304B40
39670	5	51	890	41141	50639	\N	54.370923638509197	Кемеровская область, Беловский городской округ, Ленина, 39		0101000020E61000006DC9AA083796554098A608707A2F4B40
39689	5	51	890	41141	50420	\N	54.412659617473999	Кемеровская область, Беловский городской округ, мкрн 8 марта, Боевая, 30	Россия, Кемеровская область, Беловский район, Белово	0101000020E610000065C39ACAA2935540062FFA0AD2344B40
39677	5	51	890	41141	13368	\N	54.376841138067398	Кемеровская область, Беловский городской округ, 3 микрорайон, 113	Россия, Кемеровская область, Беловский район, Белово	0101000020E610000030DAE385749655405E656D533C304B40
39691	5	51	890	41141	76202	\N	54.354912284571903	Кемеровская область, Беловский городской округ, мкрн Телеут, 3 Телеут, 24	Россия, Кемеровская область, Беловский район, Белово	0101000020E6100000E57B4622349555409E7AA4C16D2D4B40
40803	5	51	890	29810	\N	\N	54.361969999999999	Кемеровская область, Беловский район, с.Беково, СДК с.Беково		0101000020E61000008A7780272D8B55400A117008552E4B40
39710	5	51	890	41064	12324	\N	54.283270999999999	Кемеровская область, Беловский городской округ, пгт Бачатский, мкрн Финский, 27		0101000020E6100000B519A721AA855540DE73603942244B40
39704	5	51	890	8672	49955	\N	54.283270999999999	Кемеровская область, Беловский городской округ, пгт Бачатский, Шевцовой, 33		0101000020E6100000B519A721AA855540DE73603942244B40
39702	5	51	890	8672	49955	\N	54.283270999999999	Кемеровская область, Беловский городской округ, пгт Бачатский, Шевцовой, 49		0101000020E6100000B519A721AA855540DE73603942244B40
39708	5	51	890	8672	50026	\N	54.283270999999999	Кемеровская область, Беловский городской округ, пгт Бачатский, Комсомольская, 10		0101000020E6100000B519A721AA855540DE73603942244B40
39706	5	51	890	8672	50026	\N	54.283270999999999	Кемеровская область, Беловский городской округ, пгт Бачатский, Комсомольская, 49		0101000020E6100000B519A721AA855540DE73603942244B40
39701	5	51	890	8672	13695	\N	54.283270999999999	Кемеровская область, Беловский городской округ, пгт Бачатский, 50 лет Октября, 9		0101000020E6100000B519A721AA855540DE73603942244B40
40819	5	51	890	30679	\N	\N	54.119877000000002	Кемеровская область, Беловский район, с.Артышта, школа с.Артышта		0101000020E6100000BC0512143F91554074452921580F4B40
36838	5	50	\N	59262	69461	\N	55.436641999999999	Помещение спортивного зала МОУ СОШ с. Преображенка ул. Школьная, 4		0101000020E6100000EF703B342C9D5940AF0793E2E3B74B40
35956	5	50	\N	59156	68554	\N	57.832867999999998	Иркутская область, муниципальное образование - Киренский район, Алексеевское муниципальное образование, п.Алексеевск, Чапаева, 47	Россия	0101000020E61000009EEBFB7090155B4045F12A6B9BEA4C40
36038	5	50	\N	59254	69392	\N	55.436641999999999	Иркутская область, Мамско-Чуйский район, п. Витимский, ул. Школьная, д.13		0101000020E6100000EF703B342C9D5940AF0793E2E3B74B40
35959	5	50	\N	59232	\N	\N	57.942166	Иркутская область, муниципальное образование - Киренский район, Алымовское муниципальное образование, д.Салтыково, сельский клуб	Россия	0101000020E61000005CAAD216D71D5B409AB33EE598F84C40
36772	5	50	\N	59098	\N	\N	52.207521999999997	Иркутская область, город Шелехов, микрорайон 1, дом 35		0101000020E6100000975643E21E035A40AA99B514901A4A40
36762	5	50	\N	59098	67736	\N	52.2145407627618	Иркутская область, город Шелехов, переулок Садовый, дом 20	Россия, Иркутская область, городской округ Шелехов	0101000020E610000056BB26A435065A4058535914761B4A40
36769	5	50	\N	59098	68091	\N	52.212642727306203	Иркутская область, город Шелехов, квартал 3, дом 15		0101000020E61000004149810530065A40965CC5E2371B4A40
36770	5	50	\N	59098	67829	\N	52.208530037528199	Иркутская область, город Шелехов, квартал 6, дом 28	Россия, Иркутская область, М-55	0101000020E61000001A355F251F065A40111E6D1CB11A4A40
36763	5	50	\N	59098	68094	\N	52.214118984148897	Иркутская область, город Шелехов, улица Кочубея, дом 21 А		0101000020E610000056BB26A435065A40E2395B40681B4A40
35964	5	50	\N	59327	69603	\N	58.073583772628801	Иркутская область, муниципальное образование - Киренский район, Юбилейнинское муниципальное образование, с.Чечуйск, Советская, 8	Россия	0101000020E6100000EF91CD55F32A5B4022C154336B094D40
36705	5	50	\N	59090	68628	\N	53.118012025318301	Иркутская область, город Черемхово, Щорса, 58	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E6100000BB29E5B512C859408D4468041B8F4A40
36699	5	50	\N	59090	67965	\N	53.116703000000001	Иркутская область, город Черемхово, Ференца Патаки, 1		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36690	5	50	\N	59090	68019	\N	53.116703000000001	Иркутская область, город Черемхово, Толстого, 8		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36640	5	50	174	20076	69253	\N	52.970109999999998	Иркутская область, Черемховский район,  д.Средний Булай, Советская, 39		0101000020E610000053060E68E9C75940E3C281902C7C4A40
36714	5	50	\N	59090	69226	\N	53.121833063209202	Иркутская область, город Черемхово, Спартаковская, 26	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E610000059F78F85E8C759406B494739988F4A40
36715	5	50	\N	59090	69227	\N	53.116703000000001	Иркутская область, город Черемхово, Сибирская, 3		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36719	5	50	\N	59090	68815	\N	53.147951556216498	Иркутская область, город Черемхово, Первомайская, 117	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000008AAC3594DAC559405BB05417F0924A40
36688	5	50	\N	59090	68815	\N	53.116703000000001	Иркутская область, город Черемхово, Первомайская, 87		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36311	5	50	\N	59090	67708	\N	53.1160497380992	Иркутская область, город Черемхово, Маяковского, 195		0101000020E6100000BD18CA8976C85940B459F5B9DA8E4A40
35789	5	50	\N	59090	67708	\N	53.116703000000001	Иркутская область, город Черемхово, Маяковского, 143		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36706	5	50	\N	59090	68825	\N	53.1350827279282	Иркутская область, город Черемхово, Краснодонская, 2	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000003D9D2B4A09C659406F9F55664A914A40
36711	5	50	\N	59090	67783	\N	53.116359578906497	Иркутская область, город Черемхово, Дударского, 13	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000005665DF15C1C8594002486DE2E48E4A40
36591	5	50	\N	29581	\N	\N	56.802849000000002	Иркутская область, Усть-Кутское муниципальное образование, Здание школы	Россия, Иркутская область, Усть-Кут	0101000020E6100000DA756F4562735A402B508BC1C3664C40
36598	5	50	\N	29581	68799	\N	56.799458814229503	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, пер.Энергетический, д.1	Россия, Иркутская область, Усть-Кут	0101000020E6100000C8957A1684715A4016BF29AC54664C40
36606	5	50	\N	29581	68179	\N	56.7799796123984	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, пер.Школьный, д.2	Россия, Иркутская область, Усть-Кут	0101000020E61000007C65DEAAEB6E5A405DC47762D6634C40
36593	5	50	\N	29581	68557	\N	56.798770619110897	Иркутская область, Усть-Кутское муниципальное образование, Ручейское муниципальное образование, ул.Школьная, д.3	Россия, Иркутская область, Усть-Кут	0101000020E610000087BF266BD4705A4022FFCC203E664C40
36600	5	50	\N	29581	68361	\N	56.782512668001402	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Советская, д.97	Россия, Иркутская область, Усть-Кут	0101000020E610000028B9C326326F5A40F1D8CF6229644C40
36602	5	50	\N	29581	68902	\N	56.7898883424769	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование,  ул.Седова,21	Россия, Иркутская область, Усть-Кут	0101000020E6100000984F560C57705A405DC0CB0C1B654C40
36612	5	50	\N	29581	67744	\N	56.796910350068202	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Речников,44а	Россия, Иркутская область, Усть-Кут	0101000020E6100000E2016553AE725A407CED992501664C40
36611	5	50	\N	29581	67744	\N	56.789303475938297	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Речников, д.40	Россия, Иркутская область, Усть-Кут	0101000020E610000076FEEDB25F705A403DD175E107654C40
36610	5	50	\N	29581	67744	\N	56.791357874700097	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Речников, д.34	Россия, Иркутская область, Усть-Кут	0101000020E610000090F46915FD705A40C8B60C384B654C40
36608	5	50	\N	29581	67744	\N	56.790269048227998	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Речников, д.1	Россия, Иркутская область, Усть-Кут	0101000020E6100000D8648D7A88705A407505DB8827654C40
36607	5	50	\N	29581	67744	\N	56.797499052825401	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Речников, д.2	Россия, Иркутская область, Усть-Кут	0101000020E61000009775FF5888725A40DECB7D7214664C40
36615	5	50	\N	29581	68391	\N	56.796933898356698	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Пушкина, д.70	Россия, Иркутская область, Усть-Кут	0101000020E610000041B7973446735A400589EDEE01664C40
36624	5	50	\N	29581	69548	\N	56.788192139883499	Иркутская область, Усть-Кутское муниципальное образование, Верхнемарковское муниципальное образование, ул.Партизанская, д.55	Россия, Иркутская область, Усть-Кут	0101000020E6100000765089EB18715A40037CB779E3644C40
36596	5	50	\N	29581	69427	\N	56.789473683442097	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Панихинская, д.2	Россия, Иркутская область, Усть-Кут	0101000020E6100000BBED42739D705A406A85E97B0D654C40
36601	5	50	\N	29581	68915	\N	56.795549859288201	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Островского, д.13	Россия, Иркутская область, Усть-Кут	0101000020E61000003811FDDAFA725A40992A1895D4654C40
36620	5	50	\N	29581	67843	\N	56.791470297560799	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Нефтяников, д.27	Россия, Иркутская область, Усть-Кут	0101000020E610000027C11BD2A8705A40EFE192E34E654C40
36087	5	50	\N	25086	67868	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Шнеерсон, дом 4		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36619	5	50	\N	29581	67843	\N	56.7856290128911	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Нефтяников, д.12	Россия, Иркутская область, Усть-Кут	0101000020E61000002A00C633686F5A4004E5B67D8F644C40
36621	5	50	\N	29581	68370	\N	56.790339797612603	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Набережная, д.15		0101000020E610000016342DB132705A403E5C72DC29654C40
36617	5	50	\N	29581	68513	\N	56.797575031598903	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Коммунистическая, д.13	Россия, Иркутская область, Усть-Кут	0101000020E610000067B62BF4C1715A40B98D06F016664C40
36604	5	50	\N	29581	68331	\N	56.797575031598903	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Кирова, д.80	Россия, Иркутская область, Усть-Кут	0101000020E6100000397EA83462735A40B98D06F016664C40
36603	5	50	\N	29581	68331	\N	56.788343123069602	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Кирова, д.18	Россия, Иркутская область, Усть-Кут	0101000020E6100000BC02D19332705A40E883656CE8644C40
36605	5	50	\N	29581	68921	\N	56.787701831348897	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Кедровая, д.19	Россия, Иркутская область, Усть-Кут	0101000020E61000006571FF91E96F5A40357F4C6BD3644C40
36628	5	50	\N	29581	68675	\N	56.789491900199202	Иркутская область, Усть-Кутское муниципальное образование, Звезднинское муниципальное образование, ул.Горбунова, д.5		0101000020E61000008908FF2268705A40113AE8120E654C40
36616	5	50	\N	29581	9960	\N	56.763556415082199	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Геологическая, д.2	Россия, Иркутская область, Усть-Кут	0101000020E610000070E998F38C6A5A401155F833BC614C40
36613	5	50	\N	29581	68332	\N	56.795807887210003	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Володарского, д.65	Россия, Иркутская область, Усть-Кут	0101000020E61000009A40118B18715A4095F25A09DD654C40
36592	5	50	\N	29581	69517	\N	56.7883744053116	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Береговая, д.10	Россия, Иркутская область, Усть-Кут	0101000020E6100000365B79C9FF705A4023827170E9644C40
36578	5	50	\N	59092	68111	\N	58.028134999999999	Иркутская область, город Усть- Илимск, пр.Мира, д.36		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36562	5	50	\N	59092	67999	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Чайковского, д.1		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36526	5	50	\N	59092	67711	\N	58.028134999999999	Иркутская область, город Усть- Илимск, ул.Трудовая, д.2		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36561	5	50	\N	59092	67746	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Романтиков, д.14		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36567	5	50	\N	59092	67713	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Наймушина, д.9		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36566	5	50	\N	59092	67713	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Наймушина, д.40		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36563	5	50	\N	59092	67762	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Ленина, д.20Б		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36572	5	50	\N	59092	67716	\N	58.0092768427604	Иркутская область,  город Усть- Илимск, ул.Дружбы Народов, д.7	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E61000000CC85EEFFEA9594070CD1DFD2F014D40
36571	5	50	\N	59092	67716	\N	58.016519759319102	Иркутская область, город Усть- Илимск, ул.Дружбы Народов, д.7		0101000020E6100000B83D4162BBAA59406EDDCD531D024D40
36575	5	50	\N	59092	67722	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Героев Труда, д.19		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36573	5	50	\N	59092	67722	\N	58.028134999999999	Иркутская область, город Усть- Илимск, ул.Героев Труда, д.19		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36580	5	50	\N	59092	68133	\N	58.028134999999999	Иркутская область, город Усть- Илимск, ул.Георгия Димитрова, д.10		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36538	5	50	\N	1308	4187	\N	52.750331000000003	Иркутская область, муниципальное образование города Усолье-Сибирское, Толбухина, 21	Россия, Иркутская область, Усолье-Сибирское, улица Толбухина, 21	0101000020E6100000984D8061F9E959406616A1D80A604A40
35840	5	50	\N	1308	3697	\N	52.762233999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Пушкина, 64	Россия, Иркутская область, Усолье-Сибирское, улица Пушкина, 64	0101000020E610000074B4AA251DEA59401BF33AE290614A40
36540	5	50	\N	1308	68683	\N	52.7486331132516	Иркутская область, муниципальное образование города Усолье-Сибирское, Матросова, 2	Россия, Иркутская область, Усолье-Сибирское, улица Матросова, 2	0101000020E6100000C9C9C4AD82EA59406ADAC534D35F4A40
36542	5	50	\N	1308	4242	\N	52.738042999999998	Иркутская область, муниципальное образование города Усолье-Сибирское, Луначарского, 12	Россия, Иркутская область, Усолье-Сибирское, улица Луначарского, 10	0101000020E61000001B9B1DA9BEE9594057056A31785E4A40
35606	5	50	\N	1308	346	\N	52.747131000000003	Иркутская область, Зиминское городское муниципальное образование, Куйбышева, 11	Россия, Иркутская область, Усолье-Сибирское, улица Куйбышева, 11	0101000020E6100000B4226AA2CFE85940F56915FDA15F4A40
36529	5	50	\N	1308	4099	\N	52.758152000000003	Иркутская область, муниципальное образование города Усолье-Сибирское, Коростова, 35	Россия, Иркутская область, Усолье-Сибирское, улица Коростова, 35	0101000020E61000002CA0504F1FE85940D1B2EE1F0B614A40
36546	5	50	\N	1308	4297	\N	52.725833000000002	Иркутская область, муниципальное образование города Усолье-Сибирское, Химиков проспект, 17	Россия, Иркутская область, Усолье-Сибирское, проспект Химиков, 15	0101000020E61000005ED72FD80DEA5940C5AD8218E85C4A40
36545	5	50	\N	1308	4282	\N	52.725363999999999	Иркутская область, муниципальное образование города Усолье-Сибирское, Космонавтов проспект, 1	Россия, Иркутская область, Усолье-Сибирское, проспект Космонавтов, 1	0101000020E6100000F10EF0A485EA59400ED940BAD85C4A40
36532	5	50	\N	1308	4132	\N	52.750940999999997	Иркутская область, муниципальное образование города Усолье-Сибирское, Серегина проезд, 34	Россия, Иркутская область, Усолье-Сибирское, проезд Серегина, 34	0101000020E610000090662C9ACEE85940DE1CAED51E604A40
36599	5	50	\N	1308	68904	\N	52.745359305584898	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Щорса, д.43	Россия, Иркутская область, Усолье-Сибирское, улица Щорса	0101000020E6100000D55E44DB31E75940BF6378EC675F4A40
36527	5	50	\N	1308	4075	\N	52.758839000000002	Иркутская область, муниципальное образование города Усолье-Сибирское, Фестивальный проезд, 11	Россия, Иркутская область, Усолье-Сибирское, Фестивальный проезд, 11	0101000020E6100000CA4FAA7D3AE95940F5F6E7A221614A40
36537	5	50	\N	1308	68399	\N	52.749410379916398	Иркутская область, муниципальное образование города Усолье-Сибирское, Толбухина, 52	Россия, Иркутская область, Усолье-Сибирское, улица Толбухина, 50	0101000020E6100000E97DE36BCFE95940CEA5B8AAEC5F4A40
36541	5	50	\N	1308	68572	\N	52.7424950552331	Иркутская область, муниципальное образование города Усолье-Сибирское, Розы Люксембурк, 46	Россия, Иркутская область, Усолье-Сибирское, улица Розы Люксембург, 46	0101000020E6100000999A046F48EA5940C5387F130A5F4A40
36521	5	50	\N	1308	68520	\N	52.757259778589201	Иркутская область, муниципальное образование города Усолье-Сибирское, Октябрьская, 4а	Россия, Иркутская область, Усолье-Сибирское, Октябрьская улица	0101000020E6100000F4311F10E8E95940D4484BE5ED604A40
36519	5	50	\N	1308	3966	\N	52.745981	Иркутская область, муниципальное образование города Усолье-Сибирское, Молотовая, 92	Россия, Иркутская область, Усолье-Сибирское, Молотовая улица, 92	0101000020E610000042B28009DCEA5940FC372F4E7C5F4A40
36524	5	50	\N	1308	68481	\N	52.761437999999998	Иркутская область, муниципальное образование города Усолье-Сибирское, Менделеева, 20		0101000020E6100000D82E6D382CE9594040F7E5CC76614A40
36544	5	50	\N	1308	68400	\N	52.735011	Иркутская область, муниципальное образование города Усолье-Сибирское, Луначарского, 31		0101000020E61000002C0C91D3D7E95940A29927D7145E4A40
36543	5	50	\N	1308	68400	\N	52.734459515052002	Иркутская область, муниципальное образование города Усолье-Сибирское, Луначарского, 35а	Россия, Иркутская область, Усолье-Сибирское, улица Луначарского, 35	0101000020E610000007EFAB72A1E959402E1C08C9025E4A40
36522	5	50	\N	1308	68927	\N	52.759706398592797	Иркутская область, муниципальное образование города Усолье-Сибирское, Ленина, 1	Россия, Иркутская область, Усолье-Сибирское, улица Ленина, 1	0101000020E6100000371C96067EEA59409949D40B3E614A40
36523	5	50	\N	1308	68353	\N	52.771332083293899	Иркутская область, муниципальное образование города Усолье-Сибирское, Крупской, 37	Россия, Иркутская область, Усолье-Сибирское, улица Крупской, 37	0101000020E6100000C76471FF91EA5940DC2DC901BB624A40
36536	5	50	\N	1308	4084	\N	52.749884000000002	Иркутская область, муниципальное образование города Усолье-Сибирское, Комсомольский проспект, 77	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 77	0101000020E6100000C1A7397991E9594097E5EB32FC5F4A40
36534	5	50	\N	1308	4084	\N	52.754528000000001	Иркутская область, муниципальное образование города Усолье-Сибирское, Комсомольский проспект, 51	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 51	0101000020E6100000B9DE365321E9594049F59D5F94604A40
36533	5	50	\N	1308	4084	\N	52.753585000000001	Иркутская область, муниципальное образование города Усолье-Сибирское, Комсомольский проспект, 40	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 40	0101000020E6100000DCF29194F4E85940CAE0287975604A40
36528	5	50	\N	1308	4084	\N	52.756293999999997	Иркутская область, муниципальное образование города Усолье-Сибирское, Комсомольский проспект, 30	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 30	0101000020E610000067B62BF4C1E859409C14E63DCE604A40
36531	5	50	\N	1308	68394	\N	52.735059999999997	Иркутская область, муниципальное образование города Усолье-Сибирское, Клары Цеткин, 8		0101000020E61000001AA20A7F86E85940834C3272165E4A40
36539	5	50	\N	1308	68511	\N	52.7493151677876	Иркутская область, муниципальное образование города Усолье-Сибирское, Карла Либкнехта, 58	Россия, Иркутская область, Усолье-Сибирское, улица Карла Либкнехта, 58	0101000020E6100000EAB303AE2BEA59407DB3CD8DE95F4A40
36520	5	50	\N	1308	68500	\N	52.750816	Иркутская область, муниципальное образование города Усолье-Сибирское, Интернациональная, 81		0101000020E6100000C2F869DC9BEA594022A81ABD1A604A40
39183	3	24	\N	1518	59289	\N	61.76885	город Петрозаводск, Балтийская, 4		0101000020E61000000458E4D70F314140CAC342AD69E24E40
36530	5	50	\N	1308	68307	\N	52.749725717738698	Иркутская область, муниципальное образование города Усолье-Сибирское, Жуковского, 45	Россия, Иркутская область, Усолье-Сибирское, улица Жуковского, 45	0101000020E6100000F7562426A8E75940FF7A8505F75F4A40
36484	5	50	\N	59117	\N	\N	52.848393659994997	Иркутская область, Усольское районное муниципальное образование, Мишелевское муниципальное образование, п.Усолье-7, Дом офицеров		0101000020E6100000FE9C82FC6CC85940B20FB22C986C4A40
36123	5	50	\N	59188	68911	\N	52.270845912197203	Иркутская область, Нижнеудинский район, поселок Ук, улица Коммунистическая, дом 1	Россия, Иркутская область, Иркутск, улица Красных Мадьяр	0101000020E6100000DC9BDF30D1125A404F20EC14AB224A40
36457	5	50	\N	59087	68601	\N	54.541970999999997	Иркутская область, город Тулун, микрорайон Угольщиков, 33		0101000020E61000003C889D2974285940B130444E5F454B40
36454	5	50	\N	59087	68601	\N	54.541970999999997	Иркутская область, город Тулун, микрорайон Угольщиков, 43 А		0101000020E61000003C889D2974285940B130444E5F454B40
36452	5	50	\N	59087	68726	\N	54.541970999999997	Иркутская область, город Тулун, улица Строителей, 10		0101000020E61000003C889D2974285940B130444E5F454B40
36472	5	50	\N	59087	68528	\N	54.541970999999997	Иркутская область, город Тулун, улица Совхозная, 17		0101000020E61000003C889D2974285940B130444E5F454B40
36466	5	50	\N	59087	67774	\N	54.541970999999997	Иркутская область, город Тулун, улица Сигаева, 3		0101000020E61000003C889D2974285940B130444E5F454B40
36465	5	50	\N	59087	67703	\N	54.541970999999997	Иркутская область, город Тулун, улица Речная, 94		0101000020E61000003C889D2974285940B130444E5F454B40
36474	5	50	\N	59087	68611	\N	54.541970999999997	Иркутская область, город Тулун, улица Островского, 28		0101000020E61000003C889D2974285940B130444E5F454B40
36464	5	50	\N	59087	68928	\N	54.541970999999997	Иркутская область, город Тулун, улица Мясокомбинатская, 29		0101000020E61000003C889D2974285940B130444E5F454B40
36462	5	50	\N	59087	68266	\N	54.541970999999997	Иркутская область, город Тулун, улица Ленина, 7		0101000020E61000003C889D2974285940B130444E5F454B40
36451	5	50	\N	59087	68268	\N	54.541970999999997	Иркутская область, город Тулун, улица Ватутина, 4		0101000020E61000003C889D2974285940B130444E5F454B40
36394	5	50	\N	52142	\N	\N	55.934572876783498	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, микрорайон им. Пахотищева, помещение школы № 20"		0101000020E6100000AAF3A8F8BF825840C05C8B16A0F74B40
36390	5	50	\N	52142	\N	\N	55.941125107289501	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, микрорайон им. Мясникова, дом 4А, помещение д/сада ""Белочка"""		0101000020E6100000C9737D1F0E8258405839B4C876F84B40
36388	5	50	\N	52142	\N	\N	55.938575179246897	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, микрорайон Новый, дом 20, помещение школы № 5"	Россия, Иркутская область, городской округ Тайшет	0101000020E61000007D08AA46AF815840EEEBC03923F84B40
36387	5	50	\N	52142	\N	\N	55.942317311580197	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, микрорайон Новый, дом 7А, помещение д/сада ""Сказка"""		0101000020E610000053CF8250DE81584080BBECD79DF84B40
36395	5	50	\N	52142	69130	\N	55.941658179198598	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Тайшетское муниципальное образование, г. Тайшет, мкр-н.Пахотищева, СОШ№20"""	Россия, Иркутская область, городской округ Тайшет	0101000020E6100000593332C85D8058402502D53F88F84B40
36392	5	50	\N	52142	38294	\N	55.9345825690014	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Шевченко, дом 1, помещение школы № 85"	Россия, Иркутская область, городской округ Тайшет	0101000020E61000008672A25D85815840E4326E6AA0F74B40
36403	5	50	\N	52142	68724	\N	55.936644999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Чапаева, дом 1, помещение школы искусств"		0101000020E610000035423F53AF7F5840207BBDFBE3F74B40
36385	5	50	\N	52142	38226	\N	55.938355197480703	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Транспортная, дом 20, помещение школы № 14"	Россия, Иркутская область, городской округ Тайшет	0101000020E61000001C2444F982805840E08442041CF84B40
36370	5	50	\N	52142	68929	\N	55.938021176574701	"Иркутская область, муниципальное образование ""Тайшетский район"", Старо-Акульшетское муниципальное образование, г. Тайшет, улица Суворова, дом 13, помещение администрации"		0101000020E61000007CB5A3384781584009FB761211F84B40
36397	5	50	\N	52142	67906	\N	55.936066861082899	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Пушкина, дом 43, помещение школы № 2"	Россия, Иркутская область, Тайшет	0101000020E610000047E4BB94BA7F5840B3EE1F0BD1F74B40
36400	5	50	\N	52142	68258	\N	55.936644999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Пионерская, дом 50, помещение лесного хозяйства"		0101000020E610000035423F53AF7F5840207BBDFBE3F74B40
36406	5	50	\N	52142	68269	\N	55.936644999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Первомайская, дом 48, помещение школы-интернат№19"		0101000020E610000035423F53AF7F5840207BBDFBE3F74B40
36405	5	50	\N	52142	68269	\N	55.928746472205397	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Первомайская, дом 36, помещение школы № 3"	Россия, Иркутская область, Тайшет	0101000020E6100000C30C8D278283584039252026E1F64B40
36393	5	50	\N	52142	38305	\N	55.931513872349697	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Мира, дом 4, помещение РДК ""Юбилейный"""	Россия, Иркутская область, Тайшет	0101000020E61000003255302AA982584011E2CAD93BF74B40
36404	5	50	\N	52142	68264	\N	55.936644999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Ленина, дом 113, помещение МОУ ""Радуга"""		0101000020E610000035423F53AF7F5840207BBDFBE3F74B40
36391	5	50	\N	52142	38236	\N	55.937512141969599	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Крупской, дом 123, помещение ОГОУ № 21"	Россия, Иркутская область, городской округ Тайшет	0101000020E6100000F31E679AB0815840C4CDA96400F84B40
36386	5	50	\N	52142	38236	\N	55.939704047973997	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Крупской, дом 91"	Россия, Иркутская область, городской округ Тайшет	0101000020E610000012842BA050815840CFF57D3848F84B40
36396	5	50	\N	52142	38885	\N	55.936644999999999	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Тайшетское муниципальное образование, г. Тайшет, улица Кирова, дом 234, """		0101000020E610000035423F53AF7F5840207BBDFBE3F74B40
36384	5	50	\N	52142	38213	\N	55.952359266719803	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, город Тайшет, улица Ивана Бича, дом 1, помещение школы № 23"	Россия, Иркутская область, Тайшет	0101000020E610000014EB54F99E7F5840908653E6E6F94B40
36399	5	50	\N	52142	68260	\N	55.936644999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица Воинов Интернационалистов, дом 109, помещение школы № 1"		0101000020E610000035423F53AF7F5840207BBDFBE3F74B40
36401	5	50	\N	52142	68781	\N	55.936644999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, улица 50 лет ВЛКСМ, дом 87"		0101000020E610000035423F53AF7F5840207BBDFBE3F74B40
36297	5	50	\N	59286	69542	\N	52.737645000000001	Иркутская область, Слюдянский район, п. Сухой Ручей, Линейная, 15		0101000020E61000006C7A50508AE859406A87BF266B5E4A40
36289	5	50	\N	59085	68256	\N	51.661658000000003	Иркутская область, Слюдянский район, г. Слюдянка, Слюдянских Красногвардейцев, 9		0101000020E61000009A5FCD0182EC594082919735B1D44940
36296	5	50	\N	59085	67697	\N	51.661658000000003	Иркутская область, Слюдянский район, г. Слюдянка, Ленина, 8 А		0101000020E61000009A5FCD0182EC594082919735B1D44940
36294	5	50	\N	59085	67697	\N	51.661658000000003	Иркутская область, Слюдянский район, г. Слюдянка, Ленина, 21		0101000020E61000009A5FCD0182EC594082919735B1D44940
36277	5	50	\N	59160	68723	\N	53.077811968336398	Иркутская область, город Свирск, Тимирязева, 10	Россия, Иркутская область, Черемховский район, Свирск	0101000020E61000003E22A64412D55940419E5DBEF5894A40
36276	5	50	\N	59160	68622	\N	53.071149045375499	Иркутская область, город Свирск, Молодёжная, 1	Россия, Иркутская область, Черемховский район, Свирск	0101000020E6100000BCE9961DE2D55940511212691B894A40
36286	5	50	\N	59160	69196	\N	53.056154999999997	Иркутская область, город Свирск, Лесная, 1		0101000020E6100000CEDE196D55D65940E140481630874A40
36264	5	50	\N	59083	67692	\N	54.026146971566803	Иркутская область, город Саянск, микрорайон Центральный, школа №4		0101000020E6100000C18EFF0241835940BBF1EEC858034B40
36265	5	50	\N	59083	67694	\N	54.027865145215003	Иркутская область, город Саянск, микрорайон Строителей, школа №5	Россия, Иркутская область, Зиминский район, Саянск	0101000020E6100000AD31E884D0825940FDD98F1491034B40
36262	5	50	\N	59083	68083	\N	54.0276630108403	Иркутская область, город Саянск, микрорайон Солнечный, школа №6	Россия, Иркутская область, Зиминский район, Саянск	0101000020E6100000861DC6A4BF825940952710768A034B40
36273	5	50	\N	59083	67699	\N	54.026673000000002	"Иркутская область, город Саянск, микрорайон Олимпийский, здание ""Мегаполис-спорт"""		0101000020E610000060E811A3E7835940D65757056A034B40
35430	5	50	\N	59293	69552	\N	52.275984999999999	Иркутская область, Братский район, п. Сахарово, улица Молодёжная, дом 18		0101000020E6100000963D096CCE175A40E197FA7953234A40
35898	5	50	\N	59284	69538	\N	52.282426000000001	Иркутская область, Катангский район, с.Преображенка, Советская, 8		0101000020E6100000FBCBEEC9C3155A4022C5008926244A40
35966	5	50	\N	59332	69620	\N	58.229832000000002	Иркутская область, муниципальное образование - Киренский район, Петропавловское муниципальное образование, с.Петропавловское, Советская, 15	Россия	0101000020E6100000B7291E17D53D5B4082C98D226B1D4D40
35681	5	50	\N	5456	69502	\N	52.235151000000002	Иркутская область, Иркутский район, п. Новолисиха, Клубная, 28		0101000020E61000006BF3FFAA231D5A40944F8F6D191E4A40
35646	5	50	\N	59186	68903	\N	52.249602986154301	Иркутская область, Иркутский район, п. Новая Разводная, Совхозная, 35	Россия, Иркутская область, поселок Новая Разводная, улица Совхозная	0101000020E610000036C8242367195A40E3FDB8FDF21F4A40
36096	5	50	\N	25086	67968	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, переулок Красный, дом 2		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36089	5	50	\N	25086	67951	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Циолковского, дом 10		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36088	5	50	\N	25086	68231	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Советская, дом 37		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36100	5	50	\N	25086	68688	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Петина, дом 145		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36092	5	50	\N	25086	67957	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица П. Осипенко, дом 27		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36090	5	50	\N	25086	67943	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Октябрьская, дом 3		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36086	5	50	\N	25086	67865	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Нагорная, дом 2		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36094	5	50	\N	25086	68879	\N	54.913480626223098	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Маяковского, дом 40	Россия, Иркутская область, Нижнеудинск	0101000020E6100000EE05668522C25840394206F2EC744B40
36097	5	50	\N	25086	67971	\N	54.904579279278899	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Масловского, дом 34		0101000020E61000004F232D95B7C25840FED2A23EC9734B40
36093	5	50	\N	25086	67866	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Лермонтова, дом 20		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36091	5	50	\N	25086	68760	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Ленина, дом 10		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36101	5	50	\N	25086	67955	\N	54.907002619572097	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Кржижановского, дом 24-а	Россия, Иркутская область, городской округ Нижнеудинск	0101000020E610000040DF162CD5C15840DC2F9FAC18744B40
36098	5	50	\N	25086	68234	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Краснопролетарская, дом 16		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36085	5	50	\N	25086	68229	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Карла Маркса, дом 83		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36103	5	50	\N	25086	67683	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Знаменская, дом 60		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36099	5	50	\N	25086	67683	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Знаменская, дом 91		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36105	5	50	\N	25086	67969	\N	54.912986255391303	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Гагарина, дом 11	Россия, Иркутская область, Нижнеудинск	0101000020E6100000B27F9E060CC2584059DAA9B9DC744B40
36104	5	50	\N	25086	68243	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица 6-й Пятилетки, дом 2		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
36095	5	50	\N	25086	68665	\N	54.913184000000001	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица 2-я Западная, дом 2		0101000020E6100000B27F9E060CC25840809D9B36E3744B40
35647	5	50	\N	3568	\N	\N	52.243879812553999	"Иркутская область, Иркутский район, п. Молодежный, МОУ ""Средняя общеобразовательная школа"""	Россия, Иркутская область, поселок Молодежный	0101000020E61000004A95287B4B1A5A400113B875371F4A40
35348	5	50	\N	59223	69195	\N	58.691115869208303	Иркутская область, муниципальное образование города Бодайбо и района, Артемовское муниципальное образование, поселок Маракан, улица Школьная, 46	Россия	0101000020E6100000B6F63E5585A65C4005DF347D76584D40
35342	5	50	\N	59321	69590	\N	57.814116187949899	Иркутская область, муниципальное образование города Бодайбо и района, Мамаканское муниципальное образование, улица Советская, 12	Россия	0101000020E610000083DF8618AF805C403E93FDF334E84C40
36034	5	50	\N	59142	68415	\N	58.304052704830397	Иркутская область, Мамско-Чуйский район, п. Мама, ул. Советская, д. 19	Россия	0101000020E6100000352A70B20D395C4017A06D35EB264D40
35671	5	50	\N	2001	1333	\N	52.344430000000003	Иркутская область, Иркутский район, п. Малая Топка, ул.Ключевая, 27	Россия, Иркутская область, поселок Малая Топка, улица Ключевая, 27б	0101000020E61000004205871744145A4072E14048162C4A40
35972	5	50	\N	59159	68618	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, Красный Октябрь, 15		0101000020E610000081AFE8D66B6059409E29745E632B4B40
35941	5	50	\N	59218	69167	\N	57.783707471044302	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, село Кривошапкино, Советская, 6	Россия	0101000020E61000001503249A40075B40B952CF8250E44C40
35938	5	50	\N	17848	\N	\N	57.337144000000002	Иркутская область, муниципальное образование - Киренский район, с.Красноярово, здание администрации		0101000020E6100000EA5BE67459DD5A407505DB8827AB4C40
36036	5	50	\N	59309	69570	\N	58.199557477928003	Иркутская область, Мамско-Чуйский район,  п. Колотовка, ул. Первомайская, д.11	Россия	0101000020E6100000876D8B321B4D5C400C5872158B194D40
35943	5	50	\N	59112	67845	\N	57.7782536893084	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, квартал Водников, 7а	Россия	0101000020E61000000FF27A3029085B4097FDBAD39DE34C40
35724	5	50	\N	27	68452	\N	52.350124000000001	Иркутская область, город Иркутск, Ленинский административный округ, улица Севастопольская, 214		0101000020E6100000569929ADBF0A5A40B9C5FCDCD02C4A40
35947	5	50	\N	59112	69694	\N	57.772177734958703	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, м-он Гарь, Школьная, 4	Россия	0101000020E61000001CB3EC4960045B4068588CBAD6E24C40
35945	5	50	\N	59112	67854	\N	57.785541000000002	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, Ленрабочих, 49	Россия	0101000020E6100000C9AA083719075B406555849B8CE44C40
35946	5	50	\N	59112	68945	\N	57.7761497913041	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, Алексеева, 1	Россия	0101000020E6100000C556D0B4C4065B402C6519E258E34C40
35866	5	50	\N	27	\N	\N	52.218966000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Юбилейный, 64	Россия, Иркутская область, Иркутск, Свердловский административный округ, Юбилейный микрорайон, 64	0101000020E61000005A9E077767135A40CD77F013071C4A40
35865	5	50	\N	27	\N	\N	52.225718999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Юбилейный, 22		0101000020E61000006214048F6F135A40FC8A355CE41C4A40
35864	5	50	\N	27	\N	\N	52.228409331713898	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Юбилейный, 14	Россия, Иркутская область, Иркутск, микрорайон Юбилейный, 14	0101000020E61000005C1B2AC6F9125A40588E90813C1D4A40
35863	5	50	\N	27	\N	\N	52.224969000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Юбилейный, 37	Россия, Иркутская область, Иркутск, Свердловский административный округ, Юбилейный микрорайон, 37	0101000020E610000089B48D3F51135A4092CEC0C8CB1C4A40
35853	5	50	\N	27	\N	\N	52.23075	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Радужный, 34-Б	Россия, Иркутская область, Иркутск, Свердловский административный округ, Радужный микрорайон, 34б	0101000020E61000001FB935E9B6115A40A8C64B37891D4A40
35816	5	50	\N	27	3370	\N	52.264076000000003	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Маршала Конева, 86	Россия, Иркутская область, Иркутск, улица маршала Конева, 86	0101000020E6100000D0285DFA970C5A404AD40B3ECD214A40
35734	5	50	\N	27	2202	\N	52.331422000000003	Иркутская область, город Иркутск, Ленинский административный округ, улица Генерала Доватора, 21	Россия, Иркутская область, Иркутск, улица генерала Доватора, 21	0101000020E610000042B456B439105A4064963D096C2A4A40
35735	5	50	\N	27	2226	\N	52.331493999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Воровского, 12	Россия, Иркутская область, Иркутск, улица генерала Воровского, 12	0101000020E61000004182E2C798105A40FD6838656E2A4A40
35715	5	50	\N	27	1947	\N	52.336039	Иркутская область, город Иркутск, Ленинский административный округ, улица Образцова, 23	Россия, Иркутская область, Иркутск, улица академика Образцова, 23	0101000020E61000009FAEEE586C0D5A401C977153032B4A40
35720	5	50	\N	27	2022	\N	52.343257999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Ярославского, 221	Россия, Иркутская область, Иркутск, улица Ярославского, 221	0101000020E610000050ABE80FCD0A5A40910BCEE0EF2B4A40
35708	5	50	\N	27	1850	\N	52.346789999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Шпачека, 19	Россия, Иркутская область, Иркутск, улица Шпачека, 19	0101000020E61000008DD47B2AA70E5A40384A5E9D632C4A40
35950	5	50	\N	27	28866	\N	52.284067999999998	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, Трудовых Резервов, 8	Россия, Иркутская область, Иркутск, улица Трудовых Резервов, 16	0101000020E6100000895DDBDB2D145A4089EB18575C244A40
36595	5	50	\N	27	4891	\N	52.277709999999999	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Трудовая, д.5	Россия, Иркутская область, Иркутск, улица Трудовая, 5	0101000020E6100000E6B2D1393F145A40D6E253008C234A40
36480	5	50	\N	27	3437	\N	52.285462000000003	Иркутская область, Усольское районное муниципальное образование, Мишелевское муниципальное образование, п.Мишелевка, Тимирязева, 42	Россия, Иркутская область, Иркутск, улица Тимирязева, 42	0101000020E6100000B1DCD26A48135A401920D1048A244A40
35778	5	50	\N	27	2883	\N	52.283588000000002	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Степана Разина, 20	Россия, Иркутская область, Иркутск, улица Степана Разина, 20	0101000020E6100000153944DC9C115A40DFC4909C4C244A40
35795	5	50	\N	27	627	\N	52.280900000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Советская, 139	Россия, Иркутская область, Иркутск, улица Советская, 139	0101000020E610000055682096CD165A4024B9FC87F4234A40
35769	5	50	\N	27	627	\N	52.278877999999999	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Советская, 45	Россия, Иркутская область, Иркутск, улица Советская, 45	0101000020E61000005A9C31CC09145A4075C93846B2234A40
35764	5	50	\N	27	627	\N	52.277577000000001	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Советская, 94	Россия, Иркутская область, Иркутск, улица Советская, 94	0101000020E61000008D4468041B145A40978FA4A487234A40
35759	5	50	\N	27	627	\N	52.277659999999997	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Советская, 176	Россия, Иркутская область, Иркутск, улица Советская, 176	0101000020E61000003AAE4676A5155A4024B4E55C8A234A40
35700	5	50	\N	27	1728	\N	52.351537999999998	Иркутская область, город Иркутск, Ленинский административный округ, улица Сибирских партизан, 19	Россия, Иркутская область, Иркутск, улица Сибирских Партизан, 19	0101000020E6100000C0B0FCF9B60D5A408FA67A32FF2C4A40
35699	5	50	\N	27	1728	\N	52.351109000000001	Иркутская область, город Иркутск, Ленинский административный округ, улица Сибирских партизан, 22	Россия, Иркутская область, Иркутск, улица Сибирских Партизан, 22	0101000020E61000002CF52C08E50D5A40672AC423F12C4A40
35698	5	50	\N	27	1728	\N	52.353116	Иркутская область, город Иркутск, Ленинский административный округ, улица Сибирских партизан, 30	Россия, Иркутская область, Иркутск, улица Сибирских Партизан, 30	0101000020E61000006CD102B4AD0D5A40E0D8B3E7322D4A40
35726	5	50	\N	27	2075	\N	52.352406999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Севастопольская, 218	Россия, Иркутская область, Иркутск, улица Севастопольская, 218	0101000020E61000009E78CE16100A5A40D4F02DAC1B2D4A40
36614	5	50	\N	27	2904	\N	52.283968999999999	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Российская, д.3	Россия, Иркутская область, Иркутск, улица Российская, 3	0101000020E6100000580229B16B115A40F609A01859244A40
35779	5	50	\N	27	2904	\N	52.283968999999999	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Российская, 3	Россия, Иркутская область, Иркутск, улица Российская, 3	0101000020E6100000580229B16B115A40F609A01859244A40
35731	5	50	\N	27	2042	\N	52.358463	Иркутская область, город Иркутск, Ленинский административный округ, улица Розы Люксембург, 343	Россия, Иркутская область, Иркутск, улица Розы Люксембург, 343	0101000020E61000003F73D6A71C095A40BCE9961DE22D4A40
35729	5	50	\N	27	2042	\N	52.356361999999997	Иркутская область, город Иркутск, Ленинский административный округ, улица Розы Люксембург, 317-а	Россия, Иркутская область, Иркутск, улица Розы Люксембург, 317	0101000020E6100000952A51F696095A40C1C41F459D2D4A40
35752	5	50	\N	27	2483	\N	52.249952	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Ржанова, 29	Россия, Иркутская область, Иркутск, улица Ржанова, 29	0101000020E6100000C2F693313E175A40EFC8586DFE1F4A40
35809	5	50	\N	27	3274	\N	52.322736999999996	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Рабочего Штаба, 99	Россия, Иркутская область, Иркутск, улица Рабочего Штаба, 99	0101000020E610000075E789E76C135A40C51A2E724F294A40
35834	5	50	\N	27	3604	\N	52.287185999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Профсоюзная, 3	Россия, Иркутская область, Иркутск, улица Профсоюзная, 3	0101000020E6100000AA0B789961105A403DEFC682C2244A40
35711	5	50	\N	27	1797	\N	52.344358999999997	Иркутская область, город Иркутск, Ленинский административный округ, улица Просвещения, 14	Россия, Иркутская область, Иркутск, улица Просвещения, 14	0101000020E610000021956247E30D5A40A88AA9F4132C4A40
35704	5	50	\N	27	1797	\N	52.348863999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Просвещения, 13	Россия, Иркутская область, Иркутск, улица Просвещения, 13	0101000020E6100000ABD1AB014A0E5A4039605793A72C4A40
36609	5	50	\N	27	5065	\N	52.287433999999998	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Пролетарская, д.10а	Россия, Иркутская область, Иркутск, улица Пролетарская, 10	0101000020E61000009AB4A9BA47125A4015E126A3CA244A40
35718	5	50	\N	27	1999	\N	52.338455000000003	Иркутская область, город Иркутск, Ленинский административный округ, улица Пржевальского, 78	Россия, Иркутская область, Иркутск, улица Пржевальского, 78	0101000020E6100000BB287AE0630C5A407715527E522B4A40
35942	5	50	\N	27	28856	\N	52.287543999999997	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, Полины Осипенко, 8	Россия, Иркутская область, Иркутск, улица Полины Осипенко, 8	0101000020E6100000E2E82ADD5D115A409C14E63DCE244A40
35792	5	50	\N	27	3070	\N	52.284426000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Поленова, 18-а	Россия, Иркутская область, Иркутск, улица Поленова, 18а	0101000020E61000005680EF366F145A40E910381268244A40
35738	5	50	\N	27	2260	\N	52.272128000000002	Иркутская область, город Иркутск, Октябрьский Административный округ, Пискунова, 128	Россия, Иркутская область, Иркутск, улица Пискунова, 128а	0101000020E61000008C3045B934155A40B7291E17D5224A40
35195	5	50	\N	304	67823	\N	52.533646855219899	Иркутская область, Ангарское муниципальное образование, Средняя школа № 12, кв.9, 1		0101000020E6100000C93A1C5DA5F95940E44D7E8B4E444A40
35714	5	50	\N	27	1940	\N	52.341068	Иркутская область, город Иркутск, Ленинский административный округ, улица Павла Красильникова, 54-а	Россия, Иркутская область, Иркутск, улица Павла Красильникова	0101000020E6100000FFCBB568010C5A4027DBC01DA82B4A40
35702	5	50	\N	27	1692	\N	52.349975000000001	Иркутская область, город Иркутск, Ленинский административный округ, улица Новаторов, 14	Россия, Иркутская область, Иркутск, улица Новаторов, 14	0101000020E61000000BF0DDE68D0D5A4074B515FBCB2C4A40
35695	5	50	\N	27	1692	\N	52.362262999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Новаторов, 49	Россия, Иркутская область, Иркутск, улица Новаторов, 49	0101000020E61000004A9A3FA6B50D5A4082C64CA25E2E4A40
35705	5	50	\N	27	1809	\N	52.349347999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Муравьева, 14	Россия, Иркутская область, Иркутск, улица Муравьева, 14	0101000020E61000009ECF807A330E5A4025766D6FB72C4A40
35710	5	50	\N	27	1874	\N	52.343352000000003	Иркутская область, город Иркутск, Ленинский административный округ, улица Мира, 37	Россия, Иркутская область, Иркутск, улица Мира, 37	0101000020E6100000B935E9B6440E5A40138255F5F22B4A40
35709	5	50	\N	27	1874	\N	52.341828	Иркутская область, город Иркутск, Ленинский административный округ, улица Мира, 14	Россия, Иркутская область, Иркутск, улица Мира, 14	0101000020E6100000D0420246970E5A40B56D1805C12B4A40
35739	5	50	\N	27	2279	\N	52.269962	Иркутская область, город Иркутск, Октябрьский Административный округ, Лыткина, 75	Россия, Иркутская область, Иркутск, улица Лыткина, 75	0101000020E6100000D45FAFB0E0145A40D594641D8E224A40
36482	5	50	\N	27	3474	\N	52.302922000000002	Иркутская область, Усольское районное муниципальное образование, Мишелевское муниципальное образование, п.Мишелевка, Лесная, 11	Россия, Иркутская область, Иркутск, улица Лесная, 3	0101000020E6100000812381069B155A40959EE925C6264A40
35849	5	50	\N	27	3678	\N	52.240031999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 134	Россия, Иркутская область, Иркутск, улица Лермонтова, 134	0101000020E6100000503750E09D115A402AFF5A5EB91E4A40
35848	5	50	\N	27	3678	\N	52.243406999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 311	Россия, Иркутская область, Иркутск, улица Лермонтова, 311	0101000020E6100000E7FC14C781115A40094FE8F5271F4A40
35846	5	50	\N	27	3678	\N	52.243319	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 128	Россия, Иркутская область, Иркутск, улица Лермонтова, 128	0101000020E6100000772FF7C951115A406ABFB513251F4A40
35839	5	50	\N	27	3678	\N	52.269207000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 82	Россия, Иркутская область, Иркутск, улица Лермонтова, 80	0101000020E6100000C93B873254105A40596DFE5F75224A40
35796	5	50	\N	27	3135	\N	52.293613999999998	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Ленская, 2-а	Россия, Иркутская область, Иркутск, улица Ленская, 2а	0101000020E61000004FAE2990D9155A40E9D2BF2495254A40
35701	5	50	\N	27	1767	\N	52.346151999999996	Иркутская область, город Иркутск, Ленинский административный округ, улица Ленинградская, 75	Россия, Иркутская область, Иркутск, улица Ленинградская, 75	0101000020E6100000F0A65B76880D5A40F5B86FB54E2C4A40
35782	5	50	\N	27	519	\N	52.276359999999997	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Ленина, 56	Россия, Иркутская область, Иркутск, улица Ленина, 56	0101000020E6100000F86BB2463D125A4016F6B4C35F234A40
35777	5	50	\N	27	519	\N	52.288580000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Ленина, 8	Россия, Иркутская область, Иркутск, улица Ленина, 8	0101000020E610000012DDB3AED1115A40CD237F30F0244A40
35349	5	50	\N	27	519	\N	52.288580000000003	Иркутская область, муниципальное образование города Бодайбо и района, Кропоткинское муниципальное образование, улица Ленина, 8	Россия, Иркутская область, Иркутск, улица Ленина, 8	0101000020E610000012DDB3AED1115A40CD237F30F0244A40
35343	5	50	\N	27	519	\N	52.290227000000002	Иркутская область, муниципальное образование города Бодайбо и района, Мамаканское муниципальное образование, улица Ленина, 2	Россия, Иркутская область, Иркутск, улица Ленина, 4	0101000020E6100000F818AC38D5115A4046B5882826254A40
35851	5	50	\N	27	3842	\N	52.237015	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Костычева, 1	Россия, Иркутская область, Иркутск, улица Костычева, 1	0101000020E6100000AEB9A3FFE5115A40AAD4EC81561E4A40
35761	5	50	\N	27	2625	\N	52.275561000000003	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Коммунаров, 10	Россия, Иркутская область, Иркутск, улица Коммунаров, 10	0101000020E6100000ABD0402C9B125A40CB86359545234A40
35781	5	50	\N	27	68438	\N	52.548914000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Карла Маркса, 7		0101000020E6100000BB0A293FA9F8594085285FD042464A40
35765	5	50	\N	27	2662	\N	52.272855	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Карла Либкнехта, 159	Россия, Иркутская область, Иркутск, улица Карла Либкнехта, 159	0101000020E61000009355116E32145A4069C6A2E9EC224A40
35475	5	50	\N	27	28894	\N	52.325104000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Бикей, Загородная, 2	Россия, Иркутская область, Иркутск, улица Загородная, 2	0101000020E6100000813E912749105A403FE603029D294A40
35707	5	50	\N	27	1833	\N	52.348737999999997	Иркутская область, город Иркутск, Ленинский административный округ, улица Жукова, 11	Россия, Иркутская область, Иркутск, улица Жукова, 11	0101000020E61000007313B534B70E5A40AC6F6072A32C4A40
35774	5	50	\N	27	1297	\N	52.278365000000001	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Дорожная, 4	Россия, Иркутская область, Иркутск, улица Дорожная, 4	0101000020E6100000AC1F9BE447175A40EFACDD76A1234A40
35736	5	50	\N	27	2238	\N	52.309018000000002	Иркутская область, город Иркутск, Ленинский административный округ, улица Днепровская, 2-а	Россия, Иркутская область, Иркутск, улица Днепровская, 2а	0101000020E6100000D7D9907F660F5A400BF0DDE68D274A40
35741	5	50	\N	27	2318	\N	52.269399999999997	Иркутская область, город Иркутск, Октябрьский Административный округ, Депутатская, 45/2	Россия, Иркутская область, Иркутск, улица Депутатская, 45/2	0101000020E6100000300DC347C4145A406DC5FEB27B224A40
35791	5	50	\N	27	3014	\N	52.280123000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Декабрьских Событий, 119-а	Россия, Иркутская область, Иркутск, улица Декабрьских Событий, 119а	0101000020E610000093FDF33460145A40C0ED0912DB234A40
35835	5	50	\N	27	3626	\N	52.281131000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Гоголя, 33	Россия, Иркутская область, Иркутск, улица Гоголя, 33	0101000020E6100000EF59D76839105A402672C119FC234A40
35804	5	50	\N	27	3232	\N	52.308593999999999	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Вьюжная, 2	Россия, Иркутская область, Иркутск, улица Вьюжная, 2	0101000020E61000004EB340BB43155A40F4DE180280274A40
35742	5	50	\N	27	2332	\N	52.264076000000003	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Волжская, 14/1	Россия, Иркутская область, Иркутск, улица Волжская, 14/1	0101000020E6100000C171193735145A404AD40B3ECD214A40
35716	5	50	\N	27	1969	\N	52.337916	Иркутская область, город Иркутск, Ленинский административный округ, улица Василия Ледовского, 17	Россия, Иркутская область, Иркутск, улица Василия Ледовского, 17	0101000020E610000057B3CEF8BE0C5A40C765DCD4402B4A40
35837	5	50	\N	27	3649	\N	52.277543999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Терешковой, 38	Россия, Иркутская область, Иркутск, улица Валентины Терешковой, 38	0101000020E6100000202A8D98D90F5A40BB99D18F86234A40
35730	5	50	\N	27	1985	\N	52.354689999999998	Иркутская область, город Иркутск, Ленинский административный округ, улица Баумана, д.232, кв.61	Россия, Иркутская область, Иркутск, улица Баумана, 232	0101000020E61000001B8524B37A095A40EF1B5F7B662D4A40
35725	5	50	\N	27	1985	\N	52.351978000000003	Иркутская область, город Иркутск, Ленинский административный округ, улица Баумана, 214-а	Россия, Иркутская область, Иркутск, улица Баумана, 214а	0101000020E610000066BFEE74E7095A40AC74779D0D2D4A40
35717	5	50	\N	27	1985	\N	52.335906999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Баумана, 50	Россия, Иркутская область, Иркутск, улица Баумана, 50	0101000020E6100000DE1CAED51E0C5A40ADBF2500FF2A4A40
35801	5	50	\N	27	3144	\N	52.291901000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Баррикад, 34	Россия, Иркутская область, Иркутск, улица Баррикад, 34	0101000020E6100000EA3E00A94D145A40B95510035D254A40
35798	5	50	\N	27	3144	\N	52.291516000000001	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Баррикад, 135	Россия, Иркутская область, Иркутск, улица Баррикад, 135	0101000020E6100000187959130B155A406021736550254A40
35797	5	50	\N	27	3144	\N	52.291918000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Баррикад, 147	Россия, Иркутская область, Иркутск, улица Баррикад, 147	0101000020E610000043A9BD88B6155A408F8EAB915D254A40
35775	5	50	\N	27	2351	\N	52.256739000000003	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 202	Россия, Иркутская область, Иркутск, улица Байкальская, 202	0101000020E61000009A44BDE0D3145A40CB4DD4D2DC204A40
35771	5	50	\N	27	2351	\N	52.256292000000002	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 263	Россия, Иркутская область, Иркутск, улица Байкальская, 263	0101000020E6100000B6A1629CBF165A40FC1C1F2DCE204A40
35722	5	50	\N	27	68479	\N	52.345832999999999	Иркутская область, город Иркутск, Ленинский административный округ, улица Розы Люксембург, 150		0101000020E61000006CEA3C2AFE0B5A4054707841442C4A40
35756	5	50	\N	27	2351	\N	52.254908999999998	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 267	Россия, Иркутская область, Иркутск, улица Байкальская, 267	0101000020E610000078EFA83121175A40603AADDBA0204A40
35751	5	50	\N	27	2351	\N	52.256193000000003	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 209	Россия, Иркутская область, Иркутск, улица Байкальская, 209	0101000020E61000003C33C170AE155A40693BA6EECA204A40
35745	5	50	\N	27	2351	\N	52.262934999999999	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 126	Россия, Иркутская область, Иркутск, улица Байкальская, 126	0101000020E6100000D28F8653E6135A40A4FCA4DAA7214A40
35743	5	50	\N	27	2351	\N	52.267774000000003	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 105	Россия, Иркутская область, Иркутск, улица Байкальская, 105	0101000020E610000025EA059FE6135A400C5C1E6B46224A40
35860	5	50	\N	27	3970	\N	52.222293000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Багратиона, 45	Россия, Иркутская область, Иркутск, улица Багратиона, 45	0101000020E6100000618A7269FC135A409B90D618741C4A40
35859	5	50	\N	27	3949	\N	52.224732000000003	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Аносова, 2	Россия, Иркутская область, Иркутск, улица Аносова, 2	0101000020E6100000C9E4D4CE30145A40AE2EA704C41C4A40
35856	5	50	\N	27	3920	\N	52.234467000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Ангаргэсстроя, 1	Россия, Иркутская область, Иркутск, улица Ангаргэсстроя, 1	0101000020E61000000762D9CC21145A40E17EC003031E4A40
35823	5	50	\N	27	3473	\N	52.261606	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Алмазная, 18	Россия, Иркутская область, Иркутск, улица Алмазная, 18	0101000020E6100000EBFEB1101D0F5A40FC372F4E7C214A40
35854	5	50	\N	27	3888	\N	52.235934	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Академическая, 5	Россия, Иркутская область, Иркутск, улица Академическая, 5а	0101000020E6100000E0D7481284125A40DA01D715331E4A40
35838	5	50	\N	27	3662	\N	52.263430999999997	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица 5-я Железнодорожная, 53	Россия, Иркутская область, Иркутск, улица 5-я Железнодорожная, 53	0101000020E6100000B4E386DF4D105A4054E0641BB8214A40
35744	5	50	\N	27	2363	\N	52.265166999999998	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, 4-я Советская, 1	Россия, Иркутская область, Иркутск, улица 4-я Советская, 1	0101000020E610000041649126DE125A403D7D04FEF0214A40
35767	5	50	\N	27	2293	\N	52.266264	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Иркутской 30-й Дивизии, 24	Россия, Иркутская область, Иркутск, улица 30 Иркутской Дивизии, 24	0101000020E610000042791F4773155A40130D52F014224A40
35831	5	50	\N	27	3565	\N	52.293339000000003	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица 2-я Железнодорожная, 4	Россия, Иркутская область, Иркутск, улица 2-я Железнодорожная, 4	0101000020E610000069E1B20A9B0F5A4018D2E1218C254A40
35793	5	50	\N	27	3089	\N	52.281835999999998	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Красноказачья, 10-а	Россия, Иркутская область, Иркутск, улица 1-я Красноказачья, 10а	0101000020E610000001F6D1A92B145A40F06AB93313244A40
35833	5	50	\N	27	69180	\N	52.254010000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Левый берег Ангары, поселок Затон		0101000020E61000001364045438115A40B16D516683204A40
35788	5	50	\N	27	68350	\N	52.2884721081764	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, переулок Волконского, 7	Россия, Иркутская область, Иркутск, переулок Волконского, 7	0101000020E6100000A8C64B3789135A40E6E786A6EC244A40
35861	5	50	\N	27	68503	\N	52.219380000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Юбилейный, 100		0101000020E61000002AADBF2500135A40C0B2D2A4141C4A40
35862	5	50	\N	27	68401	\N	52.221100999999997	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Юбилейный, 9-А		0101000020E610000081D07AF832125A40730E9E094D1C4A40
35829	5	50	\N	27	68245	\N	52.250976355105003	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Университетский, 85	Россия, Иркутская область, Иркутск, микрорайон Университетский, 85	0101000020E6100000AFEDED96E40F5A405B0A48FB1F204A40
35827	5	50	\N	27	68222	\N	52.254010000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Университетский, 33		0101000020E61000001364045438115A40B16D516683204A40
35828	5	50	\N	27	67949	\N	52.2537572243385	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Университетский, 70	Россия, Иркутская область, Иркутск, микрорайон Университетский, 70	0101000020E61000001EA5129ED00F5A40C710001C7B204A40
35810	5	50	\N	27	68486	\N	52.324807	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, микрорайон Топкинский, 42		0101000020E6100000956247E350145A408541994693294A40
35852	5	50	\N	27	68429	\N	52.231053000000003	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Радужный, 34-А , (1-й подъезд)		0101000020E610000057CD7344BE115A4044520B25931D4A40
35826	5	50	\N	27	68516	\N	52.253436999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Первомайский, 57		0101000020E6100000056B9C4D470F5A40554CA59F70204A40
35825	5	50	\N	27	68461	\N	52.254390000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, микрорайон Первомайский, 10		0101000020E6100000CBD93BA3AD0E5A40F836FDD98F204A40
35812	5	50	\N	27	68465	\N	52.329403347434898	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, микрорайон Зелёный, 46		0101000020E6100000F41ABB44F5175A40261AA4E0292A4A40
35813	5	50	\N	27	68397	\N	52.328065000000002	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, микрорайон Зелёный, 11-а		0101000020E6100000D2E0B6B6F0175A402BFBAE08FE294A40
35811	5	50	\N	27	68499	\N	52.327812000000002	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, микрорайон Зелёный, 42		0101000020E61000000D54C6BFCF175A40419E5DBEF5294A40
35755	5	50	\N	27	2497	\N	52.249245999999999	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Маршала Жукова, 56	Россия, Иркутская область, Иркутск, маршала Жукова проспект, 56	0101000020E6100000B0E595EB6D165A405454FD4AE71F4A40
35754	5	50	\N	27	2497	\N	52.249113999999999	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Маршала Жукова, 36	Россия, Иркутская область, Иркутск, маршала Жукова проспект, 36	0101000020E61000000395F1EF33165A40E57CB1F7E21F4A40
35753	5	50	\N	27	2497	\N	52.245916000000001	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Маршала Жукова, 2	Россия, Иркутская область, Иркутск, маршала Жукова проспект, 2	0101000020E6100000ECDADE6E49165A4015C8EC2C7A1F4A40
35819	5	50	\N	27	68402	\N	52.267826380339699	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, бульвар Рябикова, 13-А	Россия, Иркутская область, Иркутск, бульвар Валентина Рябикова, 13а	0101000020E6100000E7A90EB9190D5A405E82531F48224A40
35845	5	50	\N	27	68413	\N	52.256346999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Академика Курчатова, 13-А		0101000020E610000057AF22A303115A40BFB67EFACF204A40
35727	5	50	\N	27	68512	\N	52.346279000000003	Иркутская область, город Иркутск, Ленинский административный округ, улица Ярославского, 268		0101000020E6100000FF3C0D18240A5A405325CADE522C4A40
35772	5	50	\N	27	67929	\N	52.279237602985297	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Ядринцева, 1-и	Россия, Иркутская область, Иркутск, улица Ядринцева	0101000020E6100000431B800D88155A4075E61E12BE234A40
35773	5	50	\N	27	68396	\N	52.275302000000003	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Ширямова, 6-А		0101000020E6100000056D72F8A4165A40FF428F183D234A40
35806	5	50	\N	27	68470	\N	52.306061	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Шевцова, 16		0101000020E6100000DF50F86C1D135A4060CAC0012D274A40
35842	5	50	\N	27	68501	\N	52.270710999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Чернышевского, 15		0101000020E610000055FA0967B7105A406FD575A8A6224A40
35867	5	50	\N	27	69556	\N	52.283374000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Челнокова, 1, (3-й подъезд)		0101000020E610000014EB54F99E105A40B344679945244A40
35732	5	50	\N	27	68423	\N	52.389454999999998	Иркутская область, город Иркутск, Ленинский административный округ, улица Центральная, 16-а		0101000020E6100000024BAE62F1085A40C02154A9D9314A40
36247	5	50	\N	27	68466	\N	52.311560999999998	Иркутская область, Осинский район, п.КНГРЭ, Трактовая, 5		0101000020E6100000132A38BC200F5A40C2DA183BE1274A40
35780	5	50	\N	27	68484	\N	52.28669	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Сухэ-Батора, 9		0101000020E6100000C3B986191A125A408D0B0742B2244A40
35762	5	50	\N	27	68334	\N	52.274740000000001	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Советская, 46		0101000020E61000000A2B155454135A40977329AE2A234A40
35644	5	50	\N	27	68913	\N	52.21405	Иркутская область, Иркутский район, п. Зеленый Берег, Сибирская, 2	Россия, Иркутская область, Иркутск, Свердловский административный округ, Сибирская улица, 2	0101000020E61000001CEC4D0CC9135A40BADA8AFD651B4A40
35803	5	50	\N	27	68373	\N	52.302927800667099	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Радищева, 132	Россия, Иркутская область, Иркутск, улица Радищева, 132	0101000020E61000005C7171546E145A4077853E58C6264A40
35808	5	50	\N	27	68495	\N	52.301110000000001	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Рабочего Штаба, 6		0101000020E6100000B2BCAB1E30135A40D13FC1C58A264A40
35703	5	50	\N	27	1792	\N	52.353743999999999	Иркутская область, город Иркутск, Ленинский административный округ, переулок Пулковский, 26	Россия, Иркутская область, Иркутск, Пулковский переулок, 26	0101000020E6100000BF29AC54500E5A40FF93BF7B472D4A40
35746	5	50	\N	27	2393	\N	52.262025000000001	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Постышева, 33	Россия, Иркутская область, Иркутск, Постышева бульвар, 33	0101000020E6100000A52DAEF199135A4001DE02098A214A40
35733	5	50	\N	27	68427	\N	52.333056999999997	Иркутская область, город Иркутск, Ленинский административный округ, улица Полярная, 95		0101000020E6100000CE1ABCAFCA105A40185A9D9CA12A4A40
35949	5	50	\N	27	28865	\N	52.280816999999999	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, Партизанская, 12	Россия, Иркутская область, Иркутск, Партизанская улица, 12	0101000020E610000020D5B0DF13135A409694BBCFF1234A40
35758	5	50	\N	27	68515	\N	52.274695000000001	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Омулевского, 49		0101000020E6100000802BD9B111155A40F7AFAC3429234A40
35737	5	50	\N	27	68906	\N	52.298346220637001	Иркутская область, город Иркутск, Ленинский административный округ, улица Олонская, 6		0101000020E61000004E64E602970E5A403B72A43330264A40
35612	5	50	\N	27	68490	\N	52.273896000000001	Иркутская область, Зиминское городское муниципальное образование, Новокшонова, 2А		0101000020E6100000D61F6118B00F5A40AB402D060F234A40
35697	5	50	\N	27	68472	\N	52.356796000000003	Иркутская область, город Иркутск, Ленинский административный округ, улица Новаторов, 24		0101000020E61000007D1F0E12A20D5A40FCABC77DAB2D4A40
35802	5	50	\N	27	68912	\N	52.299354455779799	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Нестерова, 32	Россия, Иркутская область, Иркутск, улица Нестерова, 32	0101000020E6100000541B9C887E145A40A1F65B3B51264A40
35786	5	50	\N	27	68496	\N	52.288249	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Некрасова, 2		0101000020E61000008048BF7D1D125A40670DDE57E5244A40
35858	5	50	\N	27	68517	\N	52.228735999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Мухиной, 3		0101000020E610000077BF0AF0DD135A407CB5A338471D4A40
35815	5	50	\N	27	68487	\N	52.262499014898602	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Маршала Конева, 22	Россия, Иркутская область, Иркутск, улица Маршала Конева, 22	0101000020E610000014967840D90C5A40C91D369199214A40
35822	5	50	\N	27	68497	\N	52.263519000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Мамина-Сибиряка, 35		0101000020E6100000F2EF332E1C0F5A40F46F97FDBA214A40
35696	5	50	\N	27	68504	\N	52.354899000000003	Иркутская область, город Иркутск, Ленинский административный округ, улица Макаренко, 6		0101000020E61000004147AB5AD20D5A400A3197546D2D4A40
35850	5	50	\N	27	68459	\N	52.242871999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 331		0101000020E6100000E59D4319AA115A409B8E006E161F4A40
35847	5	50	\N	27	68459	\N	52.241196000000002	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 130		0101000020E61000008F8EAB915D115A4088F6B182DF1E4A40
35844	5	50	\N	27	68459	\N	52.262658999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 83		0101000020E610000051137D3ECA105A40028063CF9E214A40
35843	5	50	\N	27	68459	\N	52.262014000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Лермонтова, 92		0101000020E6100000EA3D95D39E105A400D8CBCAC89214A40
35954	5	50	\N	27	68919	\N	52.286265999999998	Иркутская область, муниципальное образование - Киренский район, Бубновское муниципальное образование, Ленина, 16		0101000020E61000003F19E3C3EC115A4076FA415DA4244A40
35766	5	50	\N	27	68483	\N	52.278557999999997	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Красных Мадьяр, 123		0101000020E6100000083D9B559F145A400305DEC9A7234A40
35794	5	50	\N	27	68383	\N	52.2847745286562	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Красноярская, 11	Россия, Иркутская область, Иркутск, Красноярская улица, 9	0101000020E6100000BA2C26361F155A40F5DBD78173244A40
35760	5	50	\N	27	68494	\N	52.273229999999998	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Красного Восстания, 2		0101000020E6100000161406651A125A409E245D33F9224A40
35269	5	50	\N	304	\N	\N	52.4985353073845	Иркутская область, Ангарское муниципальное образование, Средняя школа № 25, квартал 219, стр.5		0101000020E6100000564ACFF412F55940A774B0FECF3F4A40
35458	5	50	\N	27	68080	\N	52.282415	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Космонавтов, 9		0101000020E610000096438B6CE7125A402E73BA2C26244A40
35944	5	50	\N	27	28859	\N	52.270381	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, Коммунистическая4	Россия, Иркутская область, Иркутск, Коммунистическая улица, 2	0101000020E610000015ADDC0BCC125A40DA3A38D89B224A40
35615	5	50	\N	27	68918	\N	52.265442	Иркутская область, Зиминское городское муниципальное образование, Коммунистическая, 54		0101000020E610000092AF045262135A400F7EE200FA214A40
35800	5	50	\N	27	68360	\N	52.297739999999997	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Каштаковская, 54		0101000020E6100000C5C9FD0E45155A40035B25581C264A40
35763	5	50	\N	27	68356	\N	52.276232219058897	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Карла Либкнехта, 131	Россия, Иркутская область, Иркутск, улица Карла Либкнехта, 131	0101000020E610000039F06AB933145A40E90DF7915B234A40
35790	5	50	\N	27	67942	\N	52.329375103554902	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Иосифа Уткина, 15	Россия, Иркутская область, Иркутск, микрорайон Зеленый, 19	0101000020E61000004F57772CB6175A405C8FC2F5282A4A40
35749	5	50	\N	27	68480	\N	52.263612999999999	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Зверева, 10		0101000020E6100000D45FAFB0E0145A4075E61E12BE214A40
35841	5	50	\N	27	68471	\N	52.274073000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Звездинская, 12		0101000020E6100000B306EFAB72105A40BADBF5D214234A40
35757	5	50	\N	27	68476	\N	52.279076000000003	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Дорожная, 29-А		0101000020E6100000A297512CB7175A409C8C2AC3B8234A40
35669	5	50	\N	27	68476	\N	52.278564000000003	Иркутская область, Иркутский район, заимка Глазунова, Дорожная, 9		0101000020E610000071CCB22781175A40E6EB32FCA7234A40
35787	5	50	\N	27	68454	\N	52.284061999999999	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Декабрьских Событий, 88		0101000020E61000008B6CE7FBA9135A40A704C4245C244A40
35805	5	50	\N	27	68455	\N	52.303708999999998	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Госпитальная, 2		0101000020E61000006D91B41B7D135A401C40BFEFDF264A40
35855	5	50	\N	27	68488	\N	52.233893999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Гидростроителей, 6		0101000020E6100000ECF82F1004145A40855D143DF01D4A40
35830	5	50	\N	27	68410	\N	52.271146999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Воронежская, 2		0101000020E61000001CCF6740BD0E5A404AB4E4F1B4224A40
35712	5	50	\N	27	68787	\N	52.349078455944301	Иркутская область, город Иркутск, Ленинский административный округ, территория Воинская площадка, 26	Россия, Иркутская область, Иркутск, улица Воинская Площадка	0101000020E6100000357F4C6BD30C5A4065E08096AE2C4A40
35821	5	50	\N	27	3396	\N	52.258243999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, бульвар Рябикова, 47-А	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 47а	0101000020E6100000D1CE6916680D5A40B131AF230E214A40
35820	5	50	\N	27	3396	\N	52.255223000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, бульвар Рябикова, 63	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 63	0101000020E610000001158E20950D5A40F017B325AB204A40
35818	5	50	\N	27	3396	\N	52.267713000000001	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, бульвар Рябикова, 22-А	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 22а	0101000020E6100000D53DB2B96A0D5A4066DB696B44224A40
35817	5	50	\N	27	3396	\N	52.266351999999998	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, бульвар Рябикова, 11-Б	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 11б	0101000020E61000002F336C94F50C5A40B29C84D217224A40
35832	5	50	\N	27	68389	\N	52.289206405806198	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Боткина, 1	Россия, Иркутская область, Иркутск, улица Боткина, 1	0101000020E6100000706072A3C80F5A404BE7C3B304254A40
35857	5	50	\N	27	68468	\N	52.235531999999999	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Безбокова, 1-А		0101000020E6100000CA1B60E63B135A40AB949EE9251E4A40
35750	5	50	\N	27	68493	\N	52.254852999999997	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 230		0101000020E6100000CFF6E80DF7145A40CC24EA059F204A40
35824	5	50	\N	27	68458	\N	52.259130999999996	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Афанасьева, 8		0101000020E61000000EBBEF181E0F5A409C3061342B214A40
35706	5	50	\N	27	68412	\N	52.351872999999998	Иркутская область, город Иркутск, Ленинский административный округ, улица Авиастроителей, 4-а		0101000020E61000007EE5417A8A0E5A4036ACA92C0A2D4A40
35785	5	50	\N	27	2973	\N	52.285577000000004	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, переулок 8 Марта, 1	Россия, Иркутская область, Иркутск, 8 Марта переулок, 1	0101000020E610000028806264C9125A40B2BE81C98D244A40
35619	5	50	\N	27	68343	\N	52.280684999999998	Иркутская область, Зиминское городское муниципальное образование, 5-й Армии, 63		0101000020E6100000E92CB308C5115A4027BD6F7CED234A40
35740	5	50	\N	27	68485	\N	52.266264	Иркутская область, город Иркутск, Октябрьский Административный округ, Иркутской 30-й Дивизии, 24		0101000020E610000042791F4773155A40130D52F014224A40
35723	5	50	\N	27	2062	\N	52.348478999999998	Иркутская область, город Иркутск, Ленинский административный округ, переулок 15-й Советский, 2	Россия, Иркутская область, Иркутск, 15-й Советский переулок, 2	0101000020E6100000B95510035D0B5A40E02BBAF59A2C4A40
35719	5	50	\N	27	2008	\N	52.343693000000002	Иркутская область, город Иркутск, Ленинский административный округ, переулок 12-й Советский, 4-а	Россия, Иркутская область, Иркутск, 12-й Советский переулок, 4	0101000020E6100000B900344A970B5A409C6ED921FE2B4A40
35728	5	50	\N	27	68524	\N	52.348177	Иркутская область, город Иркутск, Ленинский административный округ, улица Ярославского, 380		0101000020E61000008A558330B7095A40151C5E10912C4A40
35721	5	50	\N	27	68443	\N	52.344282	Иркутская область, город Иркутск, Ленинский административный округ, улица Ярославского, 211	Россия, Иркутская область, Иркутск, улица Ярославского, 211	0101000020E6100000774B72C0AE0A5A40FD4CBD6E112C4A40
35747	5	50	\N	27	68447	\N	52.260300000000001	Иркутская область, муниципальное образование город Иркутск, Октябрьский административный округ, Байкальская, 176		0101000020E6100000BCADF4DA6C145A400C93A98251214A40
35617	5	50	\N	59134	68157	\N	53.914726999999999	Иркутская область, Зиминское городское муниципальное образование, микрорайон Ангарский, Здание средней школы №7	Россия, Иркутская область, Зиминский район, Зима	0101000020E61000006347E350BF83594054E23AC615F54A40
35620	5	50	\N	59134	68337	\N	53.920543247766602	Иркутская область, Зиминское городское муниципальное образование, Мира, 1А	Россия, Иркутская область, городской округ Зима	0101000020E61000001A6A1492CC825940E7C75F5AD4F54A40
35618	5	50	\N	59134	68474	\N	53.919641965748099	Иркутская область, Зиминское городское муниципальное образование, Ленина, 6	Россия, Иркутская область, городской округ Зима	0101000020E61000000D6E6B0BCF82594097033DD4B6F54A40
35537	5	50	\N	59118	67908	\N	53.556037000000003	Иркутская область, Заларинский район, п.Залари, Российская, 17		0101000020E6100000D38558FD11A05940D82E6D382CC74A40
35533	5	50	\N	59169	68729	\N	54.811793000000002	"Иркутская область, муниципальное образование ""Жигаловский район"", Жигаловское муниципальное образование, п.Жигалово, Рабочая, 1"		0101000020E61000003F1D8F19A8495A40950F41D5E8674B40
36050	5	50	\N	59124	67950	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, квартал 8, дом 23		0101000020E6100000030AF5F411085A40DC291DACFF474C40
35896	5	50	\N	59206	69055	\N	61.258416204292999	Иркутская область, Катангский район, с.Ербогачен, Ленина, 5	Россия	0101000020E610000028B9C32632015B40AE6186C613A14E40
35631	5	50	\N	2764	718	\N	52.280926999999998	Иркутская область, Иркутский район, п. Дзержинск, Центральная, 18	Россия, Иркутская область, поселок Дзержинск, улица Центральная, 18	0101000020E61000007D224F92AE185A401DC87A6AF5234A40
35499	5	50	\N	59081	68667	\N	56.273899999999998	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, переулок 4-й Коммунальный, 21	Россия, Иркутская область, Братский район, Братск	0101000020E6100000B39597FC4F795940EC2FBB270F234C40
35459	5	50	\N	59081	68196	\N	56.269851000000003	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, бульвар Победы, 8	Россия, Иркутская область, Братский район, Братск	0101000020E6100000685A6265346A59407EE5417A8A224C40
35485	5	50	\N	59081	67665	\N	56.301948000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Юбилейная, 37А		0101000020E610000023A298BC01705940DB8B683BA6264C40
35486	5	50	\N	59081	67919	\N	56.276523391995902	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Юбилейная, 5	Россия, Иркутская область, Братский район	0101000020E6100000E36C3A02B8755940C0CB0C1B65234C40
35455	5	50	\N	59081	68203	\N	56.284807275980803	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Энгельса, 5А	Россия, Иркутская область, Братский район, Братск	0101000020E61000005436ACA92C7759400056478E74244C40
35508	5	50	\N	59081	67704	\N	56.27943608687	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Осиновка, Томская, 6	Россия, Иркутская область, Братский район, Братск	0101000020E61000006EF8DD74CB7959409BA9108FC4234C40
35510	5	50	\N	59081	68160	\N	56.269851000000003	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Осиновка, Спортивная, 1А	Россия, Иркутская область, Братский район, Братск	0101000020E6100000685A6265346A59407EE5417A8A224C40
39189	3	24	\N	1518	59261	\N	61.762768000000001	город Петрозаводск, Антонова, 10А		0101000020E61000006AF5D55581364140B937BF61A2E14E40
35444	5	50	\N	59081	68077	\N	56.157122336372097	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Снежная, 39	Россия, Иркутская область, Братский район, Братск	0101000020E6100000BAA1293BFD665940B6BDDD921C144C40
35462	5	50	\N	59081	68068	\N	52.282415	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Рябикова, 16		0101000020E610000096438B6CE7125A402E73BA2C26244A40
35493	5	50	\N	59081	68174	\N	56.301948000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Приморская, 47		0101000020E610000023A298BC01705940DB8B683BA6264C40
35440	5	50	\N	59081	67857	\N	56.290273174990801	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Подбельского, 9	Россия, Иркутская область, Братский район, Братск	0101000020E6100000999EB0C403795940B6F468AA27254C40
35489	5	50	\N	59081	68202	\N	56.301948000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Погодаева, 8		0101000020E610000023A298BC01705940DB8B683BA6264C40
35460	5	50	\N	59081	67877	\N	56.283876324146803	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Обручева, 41	Россия, Иркутская область, Братский район, Братск	0101000020E61000005B5EB9DE36775940450F7C0C56244C40
35452	5	50	\N	59081	67877	\N	56.287695468865898	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Обручева, 11А		0101000020E6100000C34483143C785940821C9430D3244C40
35450	5	50	\N	59081	67877	\N	56.269851000000003	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Обручева, 40А	Россия, Иркутская область, Братский район, Братск	0101000020E6100000685A6265346A59407EE5417A8A224C40
35479	5	50	\N	59081	68381	\N	56.281107204669198	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Падун, Набережная, 42А		0101000020E6100000A1D79FC4E77659409DD66D50FB234C40
35490	5	50	\N	59081	68170	\N	56.301948000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Макаренко, 40		0101000020E610000023A298BC01705940DB8B683BA6264C40
35451	5	50	\N	59081	67939	\N	56.147768617479301	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Ленина, 25		0101000020E6100000BD8A8C0E486859406A2E3718EA124C40
35466	5	50	\N	59081	67660	\N	56.286454288852198	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Крупской, 29	Россия, Иркутская область, Братский район, Братск	0101000020E61000006327BC04A777594079E75086AA244C40
35457	5	50	\N	59081	68142	\N	56.279422191665702	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Космонавтов, 1		0101000020E61000009E7939ECBE76594036E49F19C4234C40
35445	5	50	\N	59081	67888	\N	56.281953646347198	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Комсомольская, 39	Россия, Иркутская область, Братский район, Братск	0101000020E61000004ED2FC31AD765940FA7C941117244C40
35439	5	50	\N	59081	67888	\N	56.277287399088003	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Комсомольская, 10Г	Россия, Иркутская область, Братский район	0101000020E61000004337FB03E5755940904DF2237E234C40
35454	5	50	\N	59081	67701	\N	56.284067290481197	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, К. Маркса, 11		0101000020E6100000295C8FC2F5775940B96FB54E5C244C40
35509	5	50	\N	59081	68184	\N	56.280343274202899	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Осиновка, Иркутская, 16		0101000020E6100000CDE506431D765940CE548847E2234C40
35505	5	50	\N	59081	68663	\N	56.273899999999998	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Енисейская, 45А		0101000020E6100000B39597FC4F795940EC2FBB270F234C40
35448	5	50	\N	59081	68118	\N	52.282415	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Депутатская, 9		0101000020E610000096438B6CE7125A402E73BA2C26244A40
35502	5	50	\N	59081	67940	\N	56.2754280894696	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Горького, 18	Россия, Иркутская область, Братский район, Братск	0101000020E61000002CB7B41A127959408B33863941234C40
35500	5	50	\N	59081	67940	\N	56.277528759471103	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Горького, 1А	Россия, Иркутская область, Братский район, Братск	0101000020E6100000D7D9907F667959408658FD1186234C40
35481	5	50	\N	59081	68299	\N	56.269851000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Падун, Гидростроителей, 67	Россия, Иркутская область, Братский район, Братск	0101000020E6100000685A6265346A59407EE5417A8A224C40
35265	5	50	\N	304	\N	\N	52.508837999999997	"Иркутская область, Ангарское муниципальное образование, Спортивный комплекс ""АТОМ-спорт"", квартал 189, 9"		0101000020E6100000BB0CFFE906F55940247B849A21414A40
35480	5	50	\N	59081	68299	\N	56.285881422890803	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Падун, Гидростроителей, 54	Россия, Иркутская область, Братский район, Братск	0101000020E61000008CF678211D7859401EC6A4BF97244C40
35464	5	50	\N	59081	68214	\N	56.282457380718	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Гагарина, 21А		0101000020E6100000FB230C03967759405DC30C8D27244C40
35469	5	50	\N	59081	67663	\N	56.281608525709501	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Возрождения, 30А		0101000020E610000019C5724BAB76594030A182C30B244C40
35359	5	50	\N	59113	67847	\N	53.145052	Иркутская область, Боханский район, п. Бохан, Карла Маркса, 3		0101000020E6100000D41055F833F25940151C5E1091924A40
36832	5	50	\N	59158	68596	\N	57.833532965629203	Иркутская область, муниципальное образование города Бодайбо и района, Балахнинское муниципальное образование, улица Школьная,3	Россия	0101000020E6100000CFA44DD53D8C5C4082919735B1EA4C40
35331	5	50	\N	59080	68346	\N	57.846349611026902	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица Урицкого, 51	Россия	0101000020E6100000B64DF1B8A88C5C401C7C613255EC4C40
35339	5	50	\N	59080	69524	\N	57.8584849066755	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, микрорайон Бисяга, улица Центральная, 10		0101000020E61000002F6EA301BC8D5C40A48D23D6E2ED4C40
35340	5	50	\N	59080	69522	\N	57.822177256946603	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, микрорайон Колобовщина, улица Солнечная, 8		0101000020E6100000F7C77BD5CA865C40FF428F183DE94C40
35337	5	50	\N	59080	68432	\N	57.850589289407601	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица Ремесленная, 47	Россия	0101000020E6100000488C9E5BE88C5C402EABB019E0EC4C40
35333	5	50	\N	59080	68387	\N	57.851841057988402	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, переулок Почтовый, 5	Россия	0101000020E61000002C45F295408D5C402B323A2009ED4C40
35336	5	50	\N	59080	67656	\N	57.857399398103396	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица Петра Поручикова, 41 А	Россия	0101000020E610000099D36531B18D5C40C24F1C40BFED4C40
35350	5	50	\N	59080	68923	\N	57.854471184794598	Иркутская область, муниципальное образование города Бодайбо и района, Жуинское муниципальное образование, улица Набережная, 46	Россия	0101000020E6100000EA25C632FD8C5C40B130444E5FED4C40
35338	5	50	\N	59080	68875	\N	57.861059328563101	"Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица Мехколонна-135, МОУ ДО ДООЦ Лыжная база ""Таежная"""		0101000020E61000000E10CCD1E38D5C4096766A2E37EE4C40
35334	5	50	\N	59080	68414	\N	57.8538665318708	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица Иркутская, 1	Россия	0101000020E61000009B728577B98D5C401B118C834BED4C40
35329	5	50	\N	59080	68367	\N	57.858098709579899	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица Железнодорожная, 1	Россия	0101000020E61000009EB5DB2E348D5C407BDD2230D6ED4C40
35328	5	50	\N	59080	68693	\N	57.852390156454298	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица Аэропортовая, 25		0101000020E6100000ED7F80B56A8E5C40FEB7921D1BED4C40
35347	5	50	\N	59080	68580	\N	57.848980140457797	Иркутская область, муниципальное образование города Бодайбо и района, Артемовское муниципальное образование, улица Артемовская, 20	Россия	0101000020E6100000C4263273818C5C40A27A6B60ABEC4C40
35346	5	50	\N	59080	68580	\N	57.854654205130302	Иркутская область, муниципальное образование города Бодайбо и района, Артемовское муниципальное образование, улица Артемовская, 10	Россия	0101000020E6100000AD8A7093518D5C40A2B2614D65ED4C40
35335	5	50	\N	59080	68694	\N	57.854837135167401	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица 60 лет Октября, 77 Б	Россия	0101000020E61000006DC5FEB27B8E5C4094347F4C6BED4C40
35332	5	50	\N	59080	68197	\N	57.8496445800712	Иркутская область, муниципальное образование города Бодайбо и района, Бодайбинское муниципальное образование, улица 30 лет Победы, 7	Россия	0101000020E6100000F7CDFDD5E38B5C40DF1AD82AC1EC4C40
36375	5	50	\N	59135	68262	\N	55.961551	"Иркутская область, муниципальное образование ""Тайшетский район"", Бирюсинское муниципальное образование, г. Бирюсинск, улица Октябрьская, дом 23, помещение д/сада ""Солнышко"""		0101000020E61000006A4E5E6402745840D237691A14FB4B40
36378	5	50	\N	59135	69489	\N	55.961551	"Иркутская область, муниципальное образование ""Тайшетский район"", Бирюсинское муниципальное образование, город Бирюсинск, улица Марата, дом 10, помещение школы № 13"		0101000020E61000006A4E5E6402745840D237691A14FB4B40
35345	5	50	\N	59180	68871	\N	58.008905439921101	Иркутская область, муниципальное образование города Бодайбо и района, Балахнинское муниципальное образование, улица Школьная,2	Россия	0101000020E6100000064CE0D6DD915C40ACE28DCC23014D40
35262	5	50	\N	304	\N	\N	52.508915000000002	"Иркутская область, Ангарское муниципальное образование, ДК ""Современник"", квартал 181, 1"	Россия, Иркутская область, Ангарск, 181-й квартал, 1	0101000020E6100000C25087156EF55940D0B8702024414A40
35260	5	50	\N	304	\N	\N	52.511645174235802	"Иркутская область, Ангарское муниципальное образование, Гимназия № 1, нач.школа ""Орленок"", кв-л 179, 13"	Россия, Иркутская область, Ангарск, улица 14 Декабря, 14а	0101000020E61000000D5531957EF55940BA1457957D414A40
35259	5	50	\N	304	\N	\N	52.511201	Иркутская область, Ангарское муниципальное образование, Гимназия № 1, квартал 178, 6	Россия, Иркутская область, Ангарск, 178-й квартал, 6	0101000020E61000006364C91CCBF559405C57CC086F414A40
35257	5	50	\N	304	\N	\N	52.509030000000003	Иркутская область, Ангарское муниципальное образование, Техникум питания и торговли, мкр.22, 17	Россия, Иркутская область, Ангарск, 22-й микрорайон, 17	0101000020E610000015C440D7BEF65940695721E527414A40
35254	5	50	\N	304	\N	\N	52.500630359263198	"Иркутская область, Ангарское муниципальное образование, Общественная организация ""АРДИ"", мкр. 18, 13"	Россия, Иркутская область, Ангарск, 18-й микрорайон	0101000020E6100000F59F353FFEF55940C0B2D2A414404A40
35250	5	50	\N	304	\N	\N	52.501331142874299	Иркутская область, Ангарское муниципальное образование, Средняя школа № 30, мкр. 15, 34	Россия, Иркутская область, Ангарск, 15-й микрорайон, 34	0101000020E61000008A929048DBF6594049BC3C9D2B404A40
35249	5	50	\N	304	\N	\N	52.457018525800599	Иркутская область, Ангарское муниципальное образование, Средняя школа № 30, мкр.15, 34	Россия, Иркутская область, Ангарск	0101000020E6100000D6C56D3480FD594048533D997F3A4A40
35245	5	50	\N	304	\N	\N	52.508074460373699	Иркутская область, Ангарское муниципальное образование, Средняя школа № 40, мкр. 10, 64		0101000020E6100000446CB07092F7594055F99E9108414A40
35243	5	50	\N	304	\N	\N	52.509511168212399	Иркутская область, Ангарское муниципальное образование, Средняя школа № 35, мкр. 9, 35	Россия, Иркутская область, Ангарск, 9-й микрорайон, 35	0101000020E61000008E91EC116AF75940E4F90CA837414A40
35240	5	50	\N	304	\N	\N	52.516652069780299	Иркутская область, Ангарское муниципальное образование, Средняя школа № 39, мкр.13, 20		0101000020E610000096B036C64EF75940DDB419A721424A40
35238	5	50	\N	304	\N	\N	52.512718683906598	Иркутская область, Ангарское муниципальное образование, Средняя школа №5, мкр. 8, 21	Россия, Иркутская область, Ангарск, 8-й микрорайон, 21	0101000020E61000001B13622EA9F75940D784B4C6A0414A40
35236	5	50	\N	304	\N	\N	52.5180334776622	Иркутская область, Ангарское муниципальное образование, Средняя школа № 4, мкр.6, 25	Россия, Иркутская область, Ангарск, 6-й микрорайон, 25	0101000020E61000004F93196F2BF85940D89FC4E74E424A40
35235	5	50	\N	304	\N	\N	52.518261424175002	Иркутская область, Ангарское муниципальное образование, Средняя школа №4, мкр. 6, 25	Россия, Иркутская область, Ангарск, 6-й микрорайон, 25	0101000020E610000064E8D84125F8594069E55E6056424A40
35229	5	50	\N	304	\N	\N	52.522089999999999	Иркутская область, Ангарское муниципальное образование, Техникум строительных технологий, квартал 96, 5	Россия, Иркутская область, Ангарск, 96-й квартал, 5	0101000020E6100000910A630B41F85940C9C859D8D3424A40
35228	5	50	\N	304	\N	\N	52.550039477257798	Иркутская область, Ангарское муниципальное образование, Средняя школа № 7, мкр.11, 14	Россия, Иркутская область, Ангарск	0101000020E6100000DAAA24B20FFD594024438EAD67464A40
35227	5	50	\N	304	\N	\N	52.520389583460499	Иркутская область, Ангарское муниципальное образование, Средняя школа № 2, мкр.7, 20	Россия, Иркутская область, Ангарск, 7-й микрорайон, 9б	0101000020E61000009F1EDB32E0F759402D95B7239C424A40
35211	5	50	\N	304	\N	\N	52.531908000000001	Иркутская область, Ангарское муниципальное образование, здание администрации Ангарского мун.образования, квартал 86, 4а	Россия, Иркутская область, Ангарск, 86-й квартал, 4	0101000020E61000000AD6389B8EF859408A3DB48F15444A40
35209	5	50	\N	304	\N	\N	52.540830014269901	Иркутская область, Ангарское муниципальное образование, Средняя школа № 24, квартал 89, 27	Россия, Иркутская область, Ангарск	0101000020E6100000522635B401FC59400C59DDEA39454A40
35207	5	50	\N	304	\N	\N	52.538514261395498	Иркутская область, Ангарское муниципальное образование, Ангарское муниципальное образование, Средняя школа №27, квартал 80, 21	Россия, Иркутская область, Ангарск, 80-й квартал, 16	0101000020E61000003A799109F8F859401538D906EE444A40
35205	5	50	\N	304	\N	\N	52.539848778039897	Иркутская область, Ангарское муниципальное образование, Ангарское муниципальное образование, Ангарский лицей № 1, квартал 72, 21	Россия, Иркутская область, Ангарск, 72-й квартал, 18	0101000020E6100000A08B868C47F859409FE3A3C519454A40
35204	5	50	\N	304	\N	\N	52.539993000000003	Иркутская область, Ангарское муниципальное образование, Ангарский лицей № 1, квартал 72, 21	Россия, Иркутская область, Ангарск, 72-й квартал, 21	0101000020E61000001633C2DB83F85940D388997D1E454A40
35202	5	50	\N	304	\N	\N	52.548208204648503	"Иркутская область, Ангарское муниципальное образование, УСКС ОАО ""АНХК"", квартал 78, 5/6, офис 8"	Россия, Иркутская область, Ангарск, 78-й квартал, 14	0101000020E6100000C009850838F95940EAB303AE2B464A40
35194	5	50	\N	304	\N	\N	52.5366432527521	Иркутская область, Ангарское муниципальное образование, Автотранспортный техникум, кв.8, 3	Россия, Иркутская область, Ангарск	0101000020E6100000CA32C4B12EFC59404C50C3B7B0444A40
36035	5	50	\N	304	2956	\N	52.529595999999998	Иркутская область, Мамско-Чуйский район, п. Мама, ул. Урицкого, д.5	Россия, Иркутская область, Ангарск, улица Урицкого, 5а	0101000020E6100000ECF99AE5B2F95940D40B3ECDC9434A40
35783	5	50	\N	304	2956	\N	52.527842999999997	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Урицкого, 22	Россия, Иркутская область, Ангарск, улица Урицкого, 22	0101000020E61000004DBB9866BAF959401536035C90434A40
36618	5	50	\N	304	3637	\N	52.548498000000002	Иркутская область, Усть-Кутское муниципальное образование, Усть-Кутское муниципальное образование, ул.Маяковского, д.41	Россия, Иркутская область, Ангарск, улица Маяковского, 41	0101000020E6100000F241CF66D5F85940F1F5B52E35464A40
35836	5	50	\N	304	3637	\N	52.547266	Иркутская область, муниципальное образование город Иркутск, Свердловский административный округ, улица Маяковского, 14		0101000020E6100000BDC458A65FF859403B1BF2CF0C464A40
35200	5	50	\N	304	425	\N	52.548290000000001	"Иркутская область, Ангарское муниципальное образование, Дворец культуры ""Энергетик"", ул. Кирова, 2а"	Россия, Иркутская область, Ангарск, улица Кирова, 2а	0101000020E6100000C66CC9AA08F85940A75CE15D2E464A40
35196	5	50	\N	304	425	\N	52.552002999999999	Иркутская область, Ангарское муниципальное образование, Иркутский колледж экономики, сервиса и туризма, ул. Кирова, 38	Россия, Иркутская область, Ангарск, улица Кирова, 38	0101000020E6100000180B43E4F4F859409E25C808A8464A40
35231	5	50	\N	304	67640	\N	52.525244999999998	"Иркутская область, Ангарское муниципальное образование, ЗАО МСУ-76 ""Электрон"", пр. К.Маркса, 71"		0101000020E61000009F56D11F9AF959409AB1683A3B434A40
35248	5	50	\N	304	68043	\N	52.503203663448502	Иркутская область, Ангарское муниципальное образование, Средняя школа № 29, мкр. 15, 16		0101000020E6100000B1A6B228ECF65940B29B19FD68404A40
35244	5	50	\N	304	67633	\N	52.555689777234697	Иркутская область, Ангарское муниципальное образование, Средняя школа № 40, мкр.10, 64		0101000020E6100000522635B401FC59406C5B94D920474A40
35246	5	50	\N	304	67879	\N	52.525755794870499	Иркутская область, Ангарское муниципальное образование, Школа искусств № 3, мкр. 9, 83	Россия, Иркутская область, Ангарск, улица Кулибина	0101000020E6100000371B2B31CFF9594080D6FCF84B434A40
35218	5	50	\N	304	68123	\N	52.524080560576202	Иркутская область, Ангарское муниципальное образование, Спец. школа № 2, мкр. 12, 18	Россия, Иркутская область, Ангарск, микрорайон Старо-Байкальск	0101000020E6100000AB4203B16CFA59403DBA111615434A40
35157	5	50	\N	304	67921	\N	52.599215999999998	Иркутская область, Ангарское муниципальное образование, мкр. Цементный, Средняя школа № 21		0101000020E6100000CB49287D21F95940B69E211CB34C4A40
35270	5	50	\N	304	67653	\N	52.481864417778098	Иркутская область, Ангарское муниципальное образование, Средняя школа № 25, мкр. Новый-4, 40	Россия, Иркутская область, Ангарск, микрорайон Новый-4	0101000020E61000006C054D4BACF55940548F34B8AD3D4A40
35237	5	50	\N	304	68140	\N	52.512522312155902	Иркутская область, Ангарское муниципальное образование, Средняя школа № 5, мкр. 8, 21	Россия, Иркутская область, Ангарск, 8-й микрорайон, 21	0101000020E61000001840F850A2F75940813D26529A414A40
35234	5	50	\N	304	68009	\N	52.515689926333401	Иркутская область, Ангарское муниципальное образование, Средняя школа № 15, мкр. 6а, 16	Россия, Иркутская область, Ангарск, микрорайон 6А, 16	0101000020E6100000666CE8667FF85940E76F422102424A40
35242	5	50	\N	304	66997	\N	52.558409929096499	Иркутская область, Ангарское муниципальное образование, Школа искусств №4, мкр. 12а, 14	Россия, Иркутская область, Ангарск	0101000020E6100000EE76BD3445FC594033E197FA79474A40
35253	5	50	\N	304	68408	\N	52.495128000000001	Иркутская область, Ангарское муниципальное образование, Призывной пункт военкомата, мкр.17а, 22а		0101000020E610000071C971A774F65940BDAAB35A603F4A40
35241	5	50	\N	304	68477	\N	52.512878000000001	"Иркутская область, Ангарское муниципальное образование, ДЮСШ ""Сибирь"", мкр.12а, 7а"		0101000020E61000003E3F8C101EF75940406B7EFCA5414A40
35221	5	50	\N	304	68519	\N	52.528314000000002	"Иркутская область, Ангарское муниципальное образование, ООО ""Жилищная компания"", квартал 94, 17"		0101000020E6100000F8DF4A766CF859406D020CCB9F434A40
35223	5	50	\N	304	67991	\N	52.528863969657998	Иркутская область, Ангарское муниципальное образование, Средняя школа № 3, квартал 93, 25	Россия, Иркутская область, Ангарск, улица 40 лет Октября, 26а	0101000020E61000000C93A98251F959401004C8D0B1434A40
35225	5	50	\N	304	68163	\N	52.532220550148097	Иркутская область, Ангарское муниципальное образование, Средняя школа №6, квартал 92, 21		0101000020E610000057957D5704F95940499F56D11F444A40
35224	5	50	\N	304	67641	\N	52.550196439908198	Иркутская область, Ангарское муниципальное образование, Средняя школа № 6, квартал 92, 21		0101000020E6100000876D8B321BF95940EC3191D26C464A40
35266	5	50	\N	304	67643	\N	52.556525999999998	Иркутская область, Ангарское муниципальное образование, Ангарский лицей №2, квартал 211, 18		0101000020E6100000A8195245F1F75940D5AF743E3C474A40
35264	5	50	\N	304	67852	\N	52.509596268605698	Иркутская область, Ангарское муниципальное образование, Средняя школа № 23, квартал 189, 3	Россия, Иркутская область, Ангарск, 189-й квартал	0101000020E6100000CFF6E80DF7F45940121615713A414A40
35263	5	50	\N	304	68211	\N	52.505282124703001	"Иркутская область, Ангарское муниципальное образование, МОУ ДОД ""Гармония"", квартал  А, 20"		0101000020E6100000DBFAE93F6BF55940F5A0A014AD404A40
35230	5	50	\N	304	68032	\N	52.531649999999999	Иркутская область, Ангарское муниципальное образование, Школа-интернат № 7, квартал 98, 3		0101000020E6100000B1DB679599F959408E75711B0D444A40
35216	5	50	\N	304	67864	\N	52.536656337006796	Иркутская область, Ангарское муниципальное образование, Средняя школа № 20, квартал 95, 20	Россия, Иркутская область, Ангарск, 95-й квартал, 20	0101000020E61000004D4EED0C53F75940E199D024B1444A40
35222	5	50	\N	304	67850	\N	52.526086457919199	Иркутская область, Ангарское муниципальное образование, Средняя школа № 38, квартал 94, 29	Россия, Иркутская область, Ангарск, 94-й квартал, 28	0101000020E61000001AE0826C59F8594015713AC956434A40
35213	5	50	\N	304	68076	\N	52.5323750210719	Иркутская область, Ангарское муниципальное образование, Средняя школа № 32, квартал 85, 32	Россия, Иркутская область, Ангарск, 85-й квартал, 31	0101000020E6100000E17A14AE47F85940A01A2FDD24444A40
35215	5	50	\N	304	68049	\N	52.541667318423798	"Иркутская область, Ангарское муниципальное образование, Школа олимпийского резерва ""Сибиряк"", лыжная база, кв-л 71, 6"		0101000020E6100000560BEC3191FB59404529215855454A40
35203	5	50	\N	304	67024	\N	52.550876604873601	"""Иркутская область, Ангарское муниципальное образование"", ДК ""Нефтехимик"""",кв.63-1"	Россия, Иркутская область, Ангарск	0101000020E6100000522635B401FC59402E8F352383464A40
35271	5	50	\N	304	68291	\N	52.444688631933197	Иркутская область, Ангарское муниципальное образование, Основная школа №22, мкр. Юго-Восточный, кв-л 4, 6		0101000020E61000002F8A1EF818FB59400AF2B391EB384A40
35267	5	50	\N	304	68047	\N	52.5414579938899	Иркутская область, Ангарское муниципальное образование, Средняя школа № 36, квартал 207/210, 3	Россия, Иркутская область, Ангарск	0101000020E6100000185B087250FC59402B14E97E4E454A40
35217	5	50	\N	304	68505	\N	52.527754999999999	Иркутская область, Ангарское муниципальное образование, АГТА, ул. Чайковского, 60		0101000020E6100000AE0FEB8D5AF7594076A6D0798D434A40
35192	5	50	\N	304	67010	\N	52.597439117742802	Иркутская область, Ангарское муниципальное образование, мкр. Китой, ул. Трактовая, 15	Россия, Иркутская область, Ангарск, Трактовая улица, 15	0101000020E6100000E23C9CC074F659406F2D93E1784C4A40
35198	5	50	\N	304	67938	\N	52.5380367038684	Иркутская область, Ангарское муниципальное образование, Средняя школа № 14, ул. Советская, 16	Россия, Иркутская область, Ангарск, Советская улица	0101000020E61000000EF62686E4F85940DC847B65DE444A40
35232	5	50	\N	304	67769	\N	52.524615734566098	"Иркутская область, Ангарское муниципальное образование, ЗАО ""Стальконструкция"", мкр. Байкальск, ул. Полевая, 29"	Россия, Иркутская область, Ангарск, Полевая улица	0101000020E6100000CB694FC939F95940AB7AF99D26434A40
35477	5	50	\N	304	1095	\N	52.555391999999998	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Падун, Набережная, 1	Россия, Иркутская область, Ангарск, Набережная улица, 4	0101000020E61000001DAB949EE9F75940E23AC61517474A40
35201	5	50	\N	304	3967	\N	52.542479999999998	Иркутская область, Ангарское муниципальное образование, Дворец творчества детей и молодежи, ул. Московская, 37	Россия, Иркутская область, Ангарск, Московская улица, 37	0101000020E6100000D80DDB1665F85940F65D11FC6F454A40
35197	5	50	\N	304	67657	\N	52.5503534019944	Иркутская область, Ангарское муниципальное образование, Средняя школа № 14, ул. Московская, 10	Россия, Иркутская область, Ангарск, Московская улица, 10	0101000020E61000006F6589CE32F85940B42094F771464A40
35220	5	50	\N	304	4185	\N	52.532049999999998	"Иркутская область, Ангарское муниципальное образование, Учебный центр ОАО ""АНХК"", пр. Ленинградский, 6а"	Россия, Иркутская область, Ангарск, Ленинградский проспект, 6	0101000020E6100000DF8AC40435F759401CEBE2361A444A40
35219	5	50	\N	304	4185	\N	52.529874999999997	Иркутская область, Ангарское муниципальное образование, Промышленно-экономический техникум , пр. Ленинградский, 13	Россия, Иркутская область, Ангарск, Ленинградский проспект, 13	0101000020E61000006B7EFCA545F75940E7FBA9F1D2434A40
35258	5	50	\N	304	68046	\N	52.524918185749399	Иркутская область, Ангарское муниципальное образование, Средняя школа № 37, квартал 177, 11	Россия, Иркутская область, Ангарск, Кольский переулок, 7	0101000020E610000097E5EB32FCF95940768A558330434A40
35784	5	50	\N	304	67033	\N	52.536444000000003	Иркутская область, муниципальное образование город Иркутск, Правобережный административный округ, Карла Маркса, 47		0101000020E6100000CDCEA2772AF9594056116E32AA444A40
35193	5	50	\N	304	67636	\N	52.591827606129897	"""Иркутская область, Ангарское муниципальное образование, мкр. Китой,   ул. Заводская, 4"""	Россия, Иркутская область, Ангарск, 2-я Комсомольская улица	0101000020E6100000B1868BDCD3F75940B56D1805C14B4A40
35226	5	50	\N	304	67893	\N	52.520265236606299	"Иркутская область, Ангарское муниципальное образование, Техническая школа ""ДОССАФ"", мкр. 14, 1"	Россия, Иркутская область, Ангарск, 14-й микрорайон, 1	0101000020E61000001DAA29C93AF759407120240B98424A40
35214	5	50	\N	304	67016	\N	52.538331089262599	"Иркутская область, Ангарское муниципальное образование, Школа олимпийского резерва ""Сибиряк"", ул. Горького, 36"	Россия, Иркутская область, Ангарск, улица Горького, 36	0101000020E610000014419C8713F8594024B6BB07E8444A40
35208	5	50	\N	304	67016	\N	52.542282203440799	Иркутская область, Ангарское муниципальное образование, Средняя школа № 10, ул. Горького, 8	Россия, Иркутская область, Ангарск, улица Горького, 8	0101000020E6100000C2BF081A33F95940D09A1F7F69454A40
36359	5	50	\N	304	68910	\N	52.595250999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Венгерское муниципальное образование, поселок Венгерка, улица Гагарина, дом 7, помещение школы"		0101000020E6100000A25F5B3FFDF65940A5F44C2F314C4A40
35239	5	50	\N	304	68063	\N	52.516174682374697	Иркутская область, Ангарское муниципальное образование, Средняя школа № 39, мкр. 13, 20		0101000020E610000086E7A56263F75940A301BC0512424A40
35210	5	50	\N	304	68053	\N	52.536303060753298	Иркутская область, Ангарское муниципальное образование, Средняя школа № 19, квартал 88, 34	Россия, Иркутская область, Ангарск, улица Файзулина, 15	0101000020E61000002D978DCEF9F8594093DFA293A5444A40
35212	5	50	\N	304	68506	\N	52.532246999999998	"Иркутская область, Ангарское муниципальное образование, НОУДО ""Русич"", квартал 85, 31"		0101000020E6100000938FDD054AF85940723271AB20444A40
35199	5	50	\N	304	68384	\N	52.5496868201827	Иркутская область, Ангарское муниципальное образование, Ангарский политехнический техникум, квартал 52, 1	Россия, Иркутская область, Ангарск, 52-й квартал	0101000020E6100000F6798CF2CCF85940A704C4245C464A40
35233	5	50	\N	304	68489	\N	52.521274010707799	Иркутская область, Ангарское муниципальное образование, Индустриальный техникум, квартал 277, 15	Россия, Иркутская область, Ангарск, 277-й квартал, 15	0101000020E61000002BC24D4695F85940A7203F1BB9424A40
35268	5	50	\N	304	68446	\N	52.504223000000003	"Иркутская область, Ангарское муниципальное образование, Детская юношеская спорт.школа ""Ермак"", квартал 206, 6"		0101000020E6100000FF25A94C31F559400D7217618A404A40
35261	5	50	\N	304	67874	\N	52.512299756438999	Иркутская область, Ангарское муниципальное образование, Индустриальный техникум, квартал 180, 1	Россия, Иркутская область, Ангарск, Пойменная улица, 19	0101000020E61000003FC4060B27F55940D3DEE00B93414A40
35255	5	50	\N	304	68677	\N	52.500404469248302	Иркутская область, Ангарское муниципальное образование, Гимназия №8, мкр. 18, 15		0101000020E610000059349D9D0CF65940D064FF3C0D404A40
35251	5	50	\N	304	68190	\N	52.499088391184699	Иркутская область, Ангарское муниципальное образование, Средняя школа № 17, мкр.17, 17	Россия, Иркутская область, Ангарск, 17-й микрорайон, 17	0101000020E61000004C7155D977F65940BCE9961DE23F4A40
35247	5	50	\N	304	68172	\N	52.503281206005099	Иркутская область, Ангарское муниципальное образование, Средняя школа № 29, мкр.15, 16		0101000020E61000009A982EC4EAF659405ED905836B404A40
35957	5	50	\N	59163	68666	\N	57.833967000000001	Иркутская область, муниципальное образование - Киренский район, Алексеевское муниципальное образование, п.Алексеевск, Ленский, 2	Россия	0101000020E6100000143DF03158155B40BC783F6EBFEA4C40
36764	5	50	7465	59099	68327	\N	52.216175116868797	Иркутская область, город Шелехов, улица Орловских комсомольцев, дом 2	Россия, Иркутская область, городской округ Шелехов	0101000020E6100000A609DB4FC6065A403D9B559FAB1B4A40
36102	5	50	7464	59088	67706	\N	54.893993994127399	Иркутская область, Нижнеудинский район, город Нижнеудинск, улица Петина, дом 124	Россия, Иркутская область, городской округ Нижнеудинск	0101000020E61000004209336DFFC05840FD6838656E724B40
35614	5	50	7469	59145	68435	\N	53.923026323084201	Иркутская область, Зиминское городское муниципальное образование, Степная, 12	Россия, Иркутская область, городской округ Зима	0101000020E6100000BB421F2C63825940C9AD49B725F64A40
36819	5	50	275	28534	69445	\N	52.809144000000003	Иркутская область, Эхирит-Булагатский район, дер.Шохтой, ул.Школьная, д.8		0101000020E610000099D87C5C1B475A4098E0D40792674A40
36814	5	50	275	28280	68604	\N	52.753366999999997	Иркутская область, Эхирит-Булагатский район, с.Харат, ул.Ленина, ДК		0101000020E6100000BC9179E40F445A405C7171546E604A40
36824	5	50	275	28763	69313	\N	52.758538999999999	Иркутская область, Эхирит-Булагатский район, дер.Харанут, ул.Школьная, д.41А		0101000020E6100000A7E7DD58503C5A40CADE52CE17614A40
36802	5	50	275	1160	\N	\N	52.964931	Иркутская область, Эхирит-Булагатский район, с.Харазаргай, Дом культуры		0101000020E61000009EB30584D62A5A40C3F2E7DB827B4A40
36810	5	50	275	28139	69462	\N	53.099772000000002	Иркутская область, Эхирит-Булагатский район, дер.Хабаровск, ул.Центральная, д.11		0101000020E61000006C95607138405A403C873254C58C4A40
36787	5	50	275	27070	67805	\N	52.808632000000003	Иркутская область, Эхирит-Булагатский район, пос.Усть-Ордынский, пер.Коммунальный, д.7		0101000020E6100000F6402B30642F5A40E23FDD4081674A40
36791	5	50	275	27070	68098	\N	52.808632000000003	Иркутская область, Эхирит-Булагатский район, пос.Усть-Ордынский, ул.Чапаева, д.23		0101000020E6100000F6402B30642F5A40E23FDD4081674A40
36788	5	50	275	27070	68597	\N	52.808632000000003	Иркутская область, Эхирит-Булагатский район, пос.Усть-Ордынский, ул.Первомайская, д.3		0101000020E6100000F6402B30642F5A40E23FDD4081674A40
36793	5	50	275	27070	67737	\N	52.808632000000003	Иркутская область, Эхирит-Булагатский район, пос.Усть-Ордынский, ул.Ленина, д.5		0101000020E6100000F6402B30642F5A40E23FDD4081674A40
36790	5	50	275	27070	67737	\N	52.808632000000003	Иркутская область, Эхирит-Булагатский район, пос.Усть-Ордынский, ул.Ленина, д.35		0101000020E6100000F6402B30642F5A40E23FDD4081674A40
36792	5	50	275	27070	37455	\N	52.808632000000003	Иркутская область, Эхирит-Булагатский район, пос.Усть-Ордынский, ул.Буденного, д.2		0101000020E6100000F6402B30642F5A40E23FDD4081674A40
36789	5	50	275	27070	68284	\N	52.808632000000003	Иркутская область, Эхирит-Булагатский район, пос.Усть-Ордынский, ул.50 лет Октября, д.35		0101000020E6100000F6402B30642F5A40E23FDD4081674A40
36820	5	50	275	28584	68832	\N	52.680258000000002	Иркутская область, Эхирит-Булагатский район, с.Тугутуй, ул.Степная, д.23		0101000020E610000063B323D577335A40D36BB3B112574A40
36806	5	50	275	27945	69442	\N	53.142626999999997	Иркутская область, Эхирит-Булагатский район, дер.Серафимовск, пер.Школьный, д.2		0101000020E61000003123BC3D08395A406743FE9941924A40
36826	5	50	275	28855	69448	\N	52.587755999999999	Иркутская область, Эхирит-Булагатский район, пос.Свердлово, ул.Советская, д.19		0101000020E6100000E014562AA8325A408E03AF963B4B4A40
36812	5	50	275	28208	69451	\N	52.946230999999997	Иркутская область, Эхирит-Булагатский район, дер.Отонхой, ул.Школьная, д.12		0101000020E6100000B7D5AC33BE465A400EBBEF181E794A40
36811	5	50	275	28161	68762	\N	52.907024999999997	Иркутская область, Эхирит-Булагатский район, с.Олой, ул.Трактовая, д.24, ФАП		0101000020E61000001C28F04E3E435A40C3D32B6519744A40
36807	5	50	275	59299	69560	\N	53.1558045898404	Иркутская область, Эхирит-Булагатский район, с.Ново-Николаевск, ул.Советская, д.40	Россия, Иркутская область, Эхирит-Булагатский район, поселок Новониколаевск	0101000020E6100000D76839D043465A40D2C6116BF1934A40
36800	5	50	275	27668	69439	\N	52.904130000000002	Иркутская область, Эхирит-Булагатский район, дер.Нижняя Идыга, ул.Шабагановская, д.2		0101000020E610000086713788D6275A408FAA2688BA734A40
36808	5	50	275	59245	69333	\N	53.203973915150499	Иркутская область, Эхирит-Булагатский район, дер.Мурамцовка, ул.Школьная, д.3	Россия, Иркутская область, Эхирит-Булагатский район, поселок Муромцовка	0101000020E6100000CC63CDC8204D5A40FE9DEDD11B9A4A40
36829	5	50	275	29003	69454	\N	52.614218000000001	Иркутская область, Эхирит-Булагатский район, дер.Куяда, ул.Молодежная, д.8		0101000020E61000009279E40F062B5A40A94E07B29E4E4A40
36794	5	50	275	27406	69232	\N	52.840688	Иркутская область, Эхирит-Булагатский район, с.Кулункун, ул.Школьная, д.4		0101000020E6100000973AC8EBC12A5A40E01115AA9B6B4A40
36803	5	50	275	59247	69345	\N	52.993759048441902	Иркутская область, Эхирит-Булагатский район, с.Кукунуты, ул.Школьная, д.10	Россия, Иркутская область, Эхирит-Булагатский район, поселок Кукунут	0101000020E61000002783A3E4D52D5A40868DB27E337F4A40
36796	5	50	275	27490	\N	\N	52.871257999999997	Иркутская область, Эхирит-Булагатский район, дер.Кударейка, ул.Клубная, д.10	Россия, Иркутская область, Эхирит-Булагатский район, поселок Кударейка	0101000020E6100000E1ED4108C81B5A406E30D461856F4A40
36816	5	50	275	28380	69238	\N	52.792439999999999	Иркутская область, Эхирит-Булагатский район, с.Корсук, ул.Трактовая, д.8		0101000020E61000000F63D2DF4B405A40680586AC6E654A40
36821	5	50	275	59258	69423	\N	52.713284043171299	Иркутская область, Эхирит-Булагатский район, дер.Камой, ул.Школьная, д.3	Россия, Иркутская область, Эхирит-Булагатский район, поселок Комой	0101000020E610000050FC1873D7385A404A61DEE34C5B4A40
36830	5	50	275	29059	68950	\N	52.687038999999999	Иркутская область, Эхирит-Булагатский район, с.Капсал, ул.Центральная, д.16		0101000020E6100000F88C446804295A40CC09DAE4F0574A40
36817	5	50	275	28461	69440	\N	52.815055000000001	Иркутская область, Эхирит-Булагатский район, дер.Ишины, ул.Нагорная, д.4		0101000020E61000009109F83592405A407CB8E4B853684A40
36828	5	50	275	28939	68987	\N	52.601897000000001	Иркутская область, Эхирит-Булагатский район, с.Захал, ул.Свердлова, д.39		0101000020E61000006E3480B7402F5A40BF47FDF50A4D4A40
36831	5	50	275	29090	69007	\N	52.766778000000002	Иркутская область, Эхирит-Булагатский район, дер.Зады, ул.Депутатская, д.2		0101000020E6100000CD902A8A57245A406AA510C825624A40
36827	5	50	275	28928	69316	\N	52.613376000000002	Иркутская область, Эхирит-Булагатский район, дер.Еловка, ул.Школьная, д.10		0101000020E6100000B7EEE6A90E325A405E13D21A834E4A40
36818	5	50	275	59200	68996	\N	52.885771419161898	Иркутская область, Эхирит-Булагатский район, дер.Гушиты, ул.Школьная, д.13	Россия, Иркутская область, Эхирит-Булагатский район, поселок Гушит	0101000020E61000000EF450DB863F5A40635FB2F160714A40
36797	5	50	275	27558	68827	\N	53.047325999999998	Иркутская область, Эхирит-Булагатский район, с.Гаханы, ул.Советская, д.17		0101000020E61000006B9DB81CAF375A40102043C70E864A40
36801	5	50	275	27731	69438	\N	52.923012	Иркутская область, Эхирит-Булагатский район, дер.Верхняя Идыга, ул.Бохолдой, д.1		0101000020E6100000C5CA68E4F3235A4064E8D84125764A40
36815	5	50	275	28364	69236	\N	52.736451000000002	Иркутская область, Эхирит-Булагатский район, дер.Верхний Кукут, ул.Российская, ДК		0101000020E6100000DA571EA4A7445A40A20DC006445E4A40
36795	5	50	275	27434	69435	\N	52.798250000000003	Иркутская область, Эхирит-Булагатский район, с.Булуса, ул.Молодежная, д.9		0101000020E6100000B0027CB779265A401904560E2D664A40
36823	5	50	275	28703	68993	\N	52.734454999999997	Иркутская область, Эхирит-Булагатский район, дер.Большая Кура, ул.Центральная, д.40Б		0101000020E61000007172BF4351365A401CB1169F025E4A40
36799	5	50	275	27639	68576	\N	52.928987280167	Иркутская область, Эхирит-Булагатский район, пос.Бозой, ул.Ленина, д.44	Россия, Иркутская область, Эхирит-Булагатский район, поселок Бозой	0101000020E6100000096EA46C91365A405FB4C70BE9764A40
36813	5	50	275	28269	69443	\N	52.988783894720903	Иркутская область, Эхирит-Булагатский район, дер.Баянгазуй, ул.Школьная, д.5	Россия, Иркутская область, Эхирит-Булагатский район, поселок Баянгазуй	0101000020E61000000729780AB93E5A406F675F79907E4A40
36805	5	50	275	27932	69235	\N	53.139976316787099	Иркутская область, Эхирит-Булагатский район, с.Байтог, ул.Советская, д.2А	Россия, Иркутская область, Эхирит-Булагатский район, поселок Байтог	0101000020E61000009B3A8F8AFF375A40C91CCBBBEA914A40
36804	5	50	275	27880	69234	\N	53.262385000000002	Иркутская область, Эхирит-Булагатский район, с.Ахины, ул.Ленина, д.29А		0101000020E6100000DBF97E6ABC3E5A4001FBE8D495A14A40
36822	5	50	275	59269	69509	\N	52.707112000000002	Иркутская область, Эхирит-Булагатский район, с.Алужино, ул.Центральная, д.126	Россия, Иркутская область, Эхирит-Булагатский район, поселок Алужина	0101000020E6100000BEBC00FBE8315A40F94D61A5825A4A40
36771	5	50	1786	25959	\N	\N	52.194079863347902	Иркутская область, город Шелехов, микрорайон Привокзальный, дом 11 А	Россия, Иркутская область, Шелеховский район, Шелехов	0101000020E6100000F6F065A208065A4062670A9DD7184A40
36775	5	50	1786	25959	68092	\N	52.207521999999997	Иркутская область, город Шелехов, микрорайон 4, дом 18		0101000020E6100000975643E21E035A40AA99B514901A4A40
36774	5	50	1786	25959	68127	\N	52.1942908487624	Иркутская область, город Шелехов, микрорайон 4, дом 30 Б	Россия, Иркутская область, Шелеховский район, Шелехов	0101000020E6100000E17EC00303065A401D740987DE184A40
36773	5	50	1786	25959	67750	\N	52.208002741934301	Иркутская область, город Шелехов, микрорайон 1, дом 48	Россия, Иркутская область, Шелеховский район, Шелехов	0101000020E6100000BD55D7A19A035A40253CA1D79F1A4A40
36767	5	50	1786	25959	67807	\N	52.207521999999997	Иркутская область, город Шелехов, квартал 4, дом 24		0101000020E6100000975643E21E035A40AA99B514901A4A40
36765	5	50	1786	25959	67790	\N	52.215595191684301	Иркутская область, город Шелехов, квартал 18, дом 39		0101000020E610000009A87004A9055A402F17F19D981B4A40
36766	5	50	1786	25959	68085	\N	52.207521999999997	Иркутская область, город Шелехов, улица Орловских комсомольцев, дом 46		0101000020E6100000975643E21E035A40AA99B514901A4A40
36776	5	50	1786	25959	68109	\N	52.2092682407933	Иркутская область, город Шелехов, микрорайон 4, дом 44		0101000020E6100000AAF23D2311055A40B70C384BC91A4A40
36768	5	50	1786	25959	68280	\N	52.1945018331703	Иркутская область, город Шелехов, улица Ленина, дом 3	Россия, Иркутская область, Шелеховский район, Шелехов	0101000020E6100000F3203D450E065A40D8800871E5184A40
36785	5	50	1786	26994	68830	\N	52.071587999999998	Иркутская область, Шелеховский район, село Шаманка, улица Советская, дом 23		0101000020E6100000A1D79FC4E7F359409D64ABCB29094A40
36782	5	50	1786	59140	\N	\N	52.044809000000001	Иркутская область, Шелеховский район, поселок Чистые Ключи, посёлок Чистые Ключи, здание клуба		0101000020E610000091D3D7F335F6594082C8224DBC054A40
36784	5	50	1786	26934	68813	\N	51.968525	Иркутская область, Шелеховский район, поселок Подкаменная, улица Железнодорожная, дом 15		0101000020E6100000583849F3C7F95940E02D90A0F8FB4940
36783	5	50	1786	26911	67784	\N	52.161453999999999	Иркутская область, Шелеховский район, село Олха, улица Школьная, дом 5		0101000020E6100000D6E3BED53A065A4079E75086AA144A40
36786	5	50	1786	27057	68986	\N	52.061889000000001	Иркутская область, Шелеховский район, село Моты, переулок Солнечный, дом 7/1		0101000020E61000007EFCA5457DFA5940B77D8FFAEB074A40
36781	5	50	1786	26819	67743	\N	52.206716	Иркутская область, Шелеховский район, село Введенщина, улица Мира, дом 20		0101000020E6100000B933130CE7FB5940ACC77DAB751A4A40
36778	5	50	1786	26623	67741	\N	52.065620000000003	Иркутская область, Шелеховский район, поселок Большой Луг, улица Клубная, дом 24		0101000020E6100000F645425BCE055A4055FB743C66084A40
36777	5	50	1786	26623	68097	\N	52.065337943860399	Иркутская область, Шелеховский район, поселок Большой Луг, улица 2-я Железнодорожная, дом 15	Россия, Иркутская область, Шелеховский район, поселок Большой Луг (Ханчин)	0101000020E6100000C5758C2B2E055A40D097DEFE5C084A40
36780	5	50	1786	26723	68101	\N	52.224572000000002	Иркутская область, Шелеховский район, село Баклаши, улица Ангарская, дом 104		0101000020E61000002C47C8409E025A4075CC79C6BE1C4A40
36779	5	50	1786	26723	68096	\N	52.224572000000002	Иркутская область, Шелеховский район, село Баклаши, улица 8 Марта, дом 13		0101000020E61000002C47C8409E025A4075CC79C6BE1C4A40
36731	5	50	294	24042	68816	\N	56.086509999999997	"Иркутская область, Чунский район, Чунское муниципальное образование, поселок Чунский, м-н ""Северный"", 9"		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36729	5	50	294	24042	67779	\N	56.086509999999997	Иркутская область, Чунский район, Чунское муниципальное образование, поселок Чунский, Солнечная, 5		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36730	5	50	294	24042	68034	\N	56.086509999999997	Иркутская область, Чунский район, Чунское муниципальное образование, поселок Чунский, Советская, 24 А		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36728	5	50	294	24042	68036	\N	56.086509999999997	Иркутская область,Чунский район, Чунское муниципальное образование, поселок Чунский, Мира, 31		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36727	5	50	294	24042	67729	\N	56.086509999999997	Иркутская область, Чунский район, Чунское муниципальное образование, поселок Чунский, Ленина, 56		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36726	5	50	294	24042	67729	\N	56.086509999999997	Иркутская область, Чунский район, Чунское муниципальное образование, поселок Чунский, Ленина, 71		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36725	5	50	294	24042	68802	\N	56.086509999999997	Иркутская область,Чунский район, Чунское муниципальное образование, поселок Чунский, Коморова, 1		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36724	5	50	294	24042	9861	\N	56.086509999999997	Иркутская область, Чунский район,  Чунское муниципальное образование, поселок Чунский, Комарова, 1		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36723	5	50	294	24042	67768	\N	56.086509999999997	Иркутская область, Чунский район, Чунское муниципальное образование,  поселок Чунский, 50 лет Октября, 1 А		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36722	5	50	294	24042	67768	\N	56.086509999999997	Иркутская область, Чунский район, Чунское муниципальное образование , поселок Чунский, 50 лет Октября, 9 А		0101000020E61000005E64027E8DE9584073637AC2120B4C40
36744	5	50	294	25089	69124	\N	56.070605	Иркутская область, Чунский район, Октябрьское муниципальное образование, поселок  Хоняки, Совхозная, 62		0101000020E61000007BD80B056CD7584090F7AA9509094C40
36750	5	50	294	25364	68982	\N	56.165564000000003	Иркутская область, Чунский район, Таргизское муниципальное образование,поселок Таргиз, Школьная, 5		0101000020E61000001094DBF63DFD58408EB27E3331154C40
36751	5	50	294	12507	68805	\N	56.127628000000001	Иркутская область, Чунский район, Таргизское муниципальное образование, поселок Сосновка, Первомайская, 6		0101000020E610000075931804560F5940E606431D56104C40
36760	5	50	294	25883	68979	\N	55.727699000000001	Иркутская область, Чунский район, Новочунское муниципальное образование, поселок Приудинск, Мира, 21		0101000020E61000004A4563EDEFDC58407C2AA73D25DD4B40
36681	5	50	174	22190	69303	\N	53.254133000000003	Иркутская область, Черемховский район, д.Старый Кутугун, Сосновая, 20		0101000020E6100000ADA580B4FFCB5940CDEA1D6E87A04A40
36754	5	50	294	25588	69242	\N	56.091546999999998	Иркутская область, Чунский район, Новочунское муниципальное образование,  поселок .Пионерский, Рабочая, 1		0101000020E6100000A1A3552DE9D658400186E5CFB70B4C40
36753	5	50	294	25550	68635	\N	56.167844000000002	Иркутская область, Чунский район,  Каменское муни ципальное образование, поселок Парчум, Центральная, 20		0101000020E610000010B22C98F8C15840386A85E97B154C40
36747	5	50	294	25220	69017	\N	55.928794000000003	Иркутская область, Чунский район, Веселовское муниципальное образование,деревня Паренда, Совхозная, 15		0101000020E61000008C2B2E8ECAE458404B5CC7B8E2F64B40
36739	5	50	294	1278	69224	\N	56.071313000000004	Иркутская область, Чунский район, Октябрьское муниципальное образование, поселок Октябрьский, Советская, 12		0101000020E6100000D23AAA9A20DB5840CC63CDC820094C40
36738	5	50	294	1278	68758	\N	56.071313000000004	Иркутская область, Чунский район, Октябрьское муниципальное образование, поселок Октябрьский, Октябрьская, 39		0101000020E6100000D23AAA9A20DB5840CC63CDC820094C40
36742	5	50	294	1278	69230	\N	56.071313000000004	Иркутская область, Чунский район, Октябрьское муниципальное образование, поселок Октябрьский, Красные Зори, 39 А		0101000020E6100000D23AAA9A20DB5840CC63CDC820094C40
36743	5	50	294	1278	69433	\N	56.071313000000004	Иркутская область, Чунский район, Октябрьское муниципальное образование, поселок Октябрьский, Звездная, 17		0101000020E6100000D23AAA9A20DB5840CC63CDC820094C40
36740	5	50	294	1278	68821	\N	56.071313000000004	Иркутская область, Чунский район, Октябрьское муниципальное образование, поселок Октябрьский, Декабристов, 9		0101000020E6100000D23AAA9A20DB5840CC63CDC820094C40
36741	5	50	294	1278	68044	\N	56.071313000000004	Иркутская область, Чунский район, Октябрьское муниципальное образование, поселок Октябрьский, Горького, 17		0101000020E6100000D23AAA9A20DB5840CC63CDC820094C40
36755	5	50	294	25619	68278	\N	56.110087999999998	Иркутская область, Чунский район, Новочунское муниципальное образование, поселок. Новочунка, Толстого, 9		0101000020E6100000E9B5D95889D158404DD7135D170E4C40
36757	5	50	294	59278	69527	\N	56.182015017705702	Иркутская область, Чунский район, Балтуринское муниципальное образование, село Новобалтурино, Береговая, 11	Россия, Иркутская область, Чунский район, поселок Новобалтурина	0101000020E61000001C295B24EDCC5840D3307C444C174C40
36759	5	50	294	25828	68981	\N	55.819580000000002	Иркутская область, Чунский район, Мухинское муниципальное образование, село Мухино, улица Школьная, 4		0101000020E610000018D00B772EE05840543A58FFE7E84B40
36733	5	50	294	24620	68026	\N	56.054321999999999	Иркутская область, Чунский район, Лесогорское муниципальное образование, поселок  Лесогорск, Шастина, 24		0101000020E6100000C614AC7136E2584006BAF605F4064C40
36735	5	50	294	24620	67731	\N	56.054321999999999	Иркутская область, Чунский район, Лесогорское муниципальное образование, поселок Лесогорск, Рабочая, 33		0101000020E6100000C614AC7136E2584006BAF605F4064C40
36736	5	50	294	24620	68828	\N	56.054321999999999	Иркутская область, Чунский район, Лесогорское муниципальное образование, поселок  Лесогорск, Мелиораторов, 27		0101000020E6100000C614AC7136E2584006BAF605F4064C40
36734	5	50	294	24620	67730	\N	56.051727707917401	Иркутская область, Чунский район, Лесогорское муниципальное образование, поселок Лесогорск, Ленина, 6	Россия, Иркутская область, Чунский район, поселок Лесогорск	0101000020E6100000043752B648E15840CC24EA059F064C40
36748	5	50	294	25277	69229	\N	55.841144	Иркутская область, Чунский район, Веселовское  муниципальное образование,  деревня Кулиш, Совхозная, 1		0101000020E610000064E8D84125EF5840029D499BAAEB4B40
36752	5	50	294	25469	68829	\N	56.173633000000002	Иркутская область, Чунский район,  Каменское муни ципальное образование, поселокКаменск, Молодежная, 30 А		0101000020E6100000FDA19927D7C75840D1402C9B39164C40
36749	5	50	294	25317	69349	\N	56.126995000000001	Иркутская область, Чунский район, Таргизское муниципальное образование, поселок Изыкан, Ангарская, 10		0101000020E6100000E4BB94BA64F15840B5E0455F41104C40
36756	5	50	294	25667	69308	\N	56.156127826411499	Иркутская область, Чунский район, Новочунское муниципальное образование, поселок Заводской, Первомайская, 5	Россия, Иркутская область, Чунский район, поселок Заводской	0101000020E610000077F4BF5C8BCB5840B5FE9600FC134C40
36746	5	50	294	25198	68070	\N	55.935611999999999	Иркутская область , Чунский район, Веселовское муниципальное образование, поселок Веселый, Мира, 2		0101000020E610000046B1DCD26AE5584061DF4E22C2F74B40
36758	5	50	294	25773	69233	\N	56.383392999999998	Иркутская область, Чунский район, Бунбуйское муниципальное образование, село Бунбуй, Советская, 31		0101000020E6100000B7989F1B9AC15840F641960513314C40
36732	5	50	294	59307	69568	\N	56.049788069665603	Иркутская область, Чунский район, Лесогорское муниципальное образование, поселок Бидоги, Советская, 6	Россия, Иркутская область, Чунский район, поселок Бидога	0101000020E610000003999D45EFDE5840DBDD03745F064C40
36737	5	50	294	24792	69228	\N	55.994829000000003	Иркутская область, Чунский район, Лесогорское муниципальное образование, село Баянда, Зеленая, 1		0101000020E6100000001DE6CB0BE45840630E828E56FF4B40
36675	5	50	174	21886	69120	\N	52.740366000000002	Иркутская область, Черемховский район, п. Юлинск, Дроздова, 7		0101000020E6100000793BC269C198594001892650C45E4A40
36693	5	50	174	3270	\N	\N	53.116703000000001	Иркутская область, город Черемхово, Декабрьских Событий, 34	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36687	5	50	174	3270	68021	\N	53.116703000000001	Иркутская область, город Черемхово, проезд Краснопеева, 9		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36694	5	50	174	3270	67727	\N	53.111608439961202	Иркутская область, город Черемхово, переулок Пролетарский, 9А	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E610000055698B6B7CC9594069FCC22B498E4A40
36692	5	50	174	3270	68801	\N	53.116703000000001	Иркутская область, город Черемхово, переулок Копейский, 1		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36716	5	50	174	3270	68274	\N	53.115688254321398	Иркутская область, город Черемхово, Ярославского, 33	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E610000009C4EBFA05C95940134548DDCE8E4A40
36717	5	50	174	3270	68287	\N	53.114642516196703	Иркутская область, город Черемхово, Шевченко, 71	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000006616A1D80ACA594090DB2F9FAC8E4A40
36493	5	50	174	3270	68620	\N	53.111608439961202	Иркутская область, город Черемхово, Фрунзе, 1	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E6100000560BEC3191C9594069FCC22B498E4A40
36700	5	50	174	3270	67960	\N	53.116703000000001	Иркутская область, город Черемхово, Ференца Патаки, 8		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
35640	5	50	174	3270	67669	\N	53.116703000000001	Иркутская область, город Черемхово, Советская, 2		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36709	5	50	174	3270	69307	\N	53.115120202214698	Иркутская область, город Черемхово, Российская, 8	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000002F51BD35B0C85940C98E8D40BC8E4A40
36695	5	50	174	3270	68226	\N	53.116824335910501	Иркутская область, город Черемхово, переулок Пролетарский, 4		0101000020E610000059350873BBC85940A7B1BD16F48E4A40
36685	5	50	174	3270	68535	\N	53.116703000000001	Иркутская область, город Черемхово, ул. Первомайская, 87		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36701	5	50	174	3270	68008	\N	53.116703000000001	Иркутская область, город Черемхово, Орджоникидзе, 15		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36708	5	50	174	3270	67696	\N	53.116703000000001	Иркутская область, город Черемхово, Маяковского, 172		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36702	5	50	174	3270	67696	\N	53.116703000000001	Иркутская область, город Черемхово, Маяковского, 124		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36381	5	50	174	3270	69420	\N	53.116703000000001	Иркутская область, город Черемхово, Маковского, 14		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36721	5	50	174	3270	68277	\N	53.116703000000001	Иркутская область, город Черемхово, Ленина, 83		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36698	5	50	174	3270	68277	\N	53.1344813614405	Иркутская область, город Черемхово, Ленина, 25	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000008CDB68006FC55940797764AC36914A40
36697	5	50	174	3270	68277	\N	53.112021603420402	Иркутская область, город Черемхово, Ленина, 19	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E6100000CD5CE0F258C959405D37A5BC568E4A40
36686	5	50	174	3270	68277	\N	53.116703000000001	Иркутская область, город Черемхово, Ленина, 26		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36689	5	50	174	3270	68626	\N	53.116703000000001	Иркутская область, город Черемхово, Красношахтерская, 91		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36710	5	50	174	3270	68004	\N	53.117773199118297	Иркутская область, город Черемхово, Забойщика, 12	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E6100000D9EBDD1FEFC8594008AD872F138F4A40
36707	5	50	174	3270	69305	\N	53.116566138198202	Иркутская область, город Черемхово, Ершовская, 26/1	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000000B0DC4B299C85940ABE97AA2EB8E4A40
36712	5	50	174	3270	68270	\N	53.132055243170903	Иркутская область, город Черемхово, Дударского, 25	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000009B3924B550C65940FB22A12DE7904A40
36713	5	50	174	3270	68540	\N	53.116703000000001	Иркутская область, город Черемхово, Детская, 31		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36696	5	50	174	3270	67787	\N	53.116703000000001	Иркутская область, город Черемхово, Декабрьских Событий, 49		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36718	5	50	174	3270	68974	\N	53.116703000000001	Иркутская область, город Черемхово, Врубовая, 5		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36704	5	50	174	3270	68275	\N	53.116703000000001	Иркутская область, город Черемхово, Бердниковой, 83		0101000020E6100000F8DD74CB0EC859402C2CB81FF08E4A40
36703	5	50	174	3270	68275	\N	53.113261069863697	Иркутская область, город Черемхово, Бердниковой, 44	Россия, Иркутская область, Черемховский район, Черемхово	0101000020E61000001B8524B37AC95940C57421567F8E4A40
36683	5	50	174	22274	68970	\N	53.148184000000001	Иркутская область, Черемховский район, д. Чемодариха, Школьная, 12		0101000020E6100000B8AE9811DED259402EE57CB1F7924A40
36678	5	50	174	59276	69523	\N	52.965978	Иркутская область, Черемховский район, д.Худорожника, Колхозная, 6	Россия, Иркутская область, Черемховский район, поселок Худорожкина	0101000020E6100000320395F1EFCE5940E753C72AA57B4A40
36673	5	50	174	21794	\N	\N	53.129213	Иркутская область, Черемховский район, д.Хандагай, 3		0101000020E6100000E4F8A1D288895940E99B340D8A904A40
36677	5	50	174	21971	69299	\N	52.903233999999998	Иркутская область, Черемховский район, с. Узкий Луг, Центральная, 92		0101000020E61000003735D07CCECF59405051F52B9D734A40
36676	5	50	174	21952	69311	\N	52.647913998955502	Иркутская область, Черемховский район, с. Тунгуска, Октябрьская, 33	Россия, Иркутская область, Черемховский район, поселок Тунгуска	0101000020E6100000F88DAF3DB3B259406E4F90D8EE524A40
36674	5	50	174	2925	68838	\N	52.782772999999999	Иркутская область, Черемховский район, с. Тальники, Лесозаготовительная,15,		0101000020E61000007102D369DD9A59408D98D9E731644A40
36856	5	50	174	30236	68607	\N	53.035637000000001	Иркутская область, Черемховский район, с.Табук, Солнечная,49, школа		0101000020E61000004D4BAC8C46B8594087C3D2C08F844A40
36282	5	50	174	1874	68853	\N	53.056154999999997	Иркутская область, город Свирск, Хасановских боёв, 1		0101000020E6100000CEDE196D55D65940E140481630874A40
36279	5	50	174	1874	68853	\N	53.056154999999997	Иркутская область, город Свирск, Хасановских боёв, 7		0101000020E6100000CEDE196D55D65940E140481630874A40
36278	5	50	174	1874	68716	\N	53.056154999999997	Иркутская область, город Свирск, Тимирязева, 4		0101000020E6100000CEDE196D55D65940E140481630874A40
36287	5	50	174	1874	69412	\N	53.056154999999997	"Иркутская область, город Свирск, микрорайон Берёзовый, Серегина, МОУ ""ООШ"""		0101000020E6100000CEDE196D55D65940E140481630874A40
36275	5	50	174	1874	68708	\N	53.056154999999997	Иркутская область, город Свирск, О.Кошевого, 17		0101000020E6100000CEDE196D55D65940E140481630874A40
36284	5	50	174	1874	68812	\N	53.056154999999997	Иркутская область, город Свирск, Мира, 4		0101000020E6100000CEDE196D55D65940E140481630874A40
36280	5	50	174	1874	68550	\N	53.081739959269498	Иркутская область, город Свирск, Ленина, 4	Россия, Иркутская область, Черемховский район, Свирск	0101000020E6100000C7BB2363B5D559403563D174768A4A40
36285	5	50	174	1874	68673	\N	53.056154999999997	Иркутская область, город Свирск, Киевская, 16		0101000020E6100000CEDE196D55D65940E140481630874A40
36283	5	50	174	1874	68778	\N	53.068507395311599	Иркутская область, город Свирск, Дзержинского, 4	Россия, Иркутская область, Черемховский район, Свирск	0101000020E6100000C7BB2363B5D5594006465ED6C4884A40
36671	5	50	174	21700	68797	\N	53.073870999999997	Иркутская область, Черемховский район, с. Саянское, Совхозная, 1		0101000020E61000001E5036E50A905940B88FDC9A74894A40
36669	5	50	174	21607	\N	\N	52.958101999999997	Иркутская область, Черемховский район, д.Савинская, 50		0101000020E61000000612143FC6B95940B81D1A16A37A4A40
36679	5	50	174	22114	68819	\N	53.200830000000003	Иркутская область, Черемховский район, с. Рысево, Российсская, 5	Россия, Иркутская область, Черемховский район, поселок Рысево	0101000020E6100000D313967840C15940210725CCB4994A40
36670	5	50	174	21620	69436	\N	52.946964000000001	Иркутская область, Черемховский район, д.Русская Аларь, Центральная, 38		0101000020E61000000E6ABFB513B15940A33EC91D36794A40
36682	5	50	174	22215	69432	\N	53.195819	Иркутская область, Черемховский район, д.Поздеева, Нагорная, 1		0101000020E6100000B8B06EBC3BD25940BC77D49810994A40
36648	5	50	174	20560	69274	\N	53.057059000000002	Иркутская область, Черемховский район, д.Петровка, Морозова, 26		0101000020E6100000859675FF58CD5940A37895B54D874A40
36639	5	50	174	20000	69222	\N	53.036942000000003	Иркутская область, Черемховский район,  д.Паршевникова, Северная, 20-2		0101000020E6100000067FBF982DCA5940A7ECF483BA844A40
36667	5	50	174	2883	68756	\N	52.987960000000001	Иркутская область, Черемховский район, с.Парфеново,Мира,25		0101000020E610000074D4D17135B65940CAE02879757E4A40
36666	5	50	174	21465	68525	\N	52.737689000000003	Иркутская область, Черемховский район, с. Онот, Школьная, 8		0101000020E6100000A30392B06F8359403ACFD8976C5E4A40
36664	5	50	174	21365	68814	\N	52.979301999999997	Иркутская область, Черемховский район, с. Новостройка, Школьная, 30		0101000020E61000008CF678211D755940257497C4597D4A40
36662	5	50	174	2766	68743	\N	53.180143999999999	Иркутская область, Черемховский район, с. Новогромово, Советская,17		0101000020E61000007BA180ED60BD59400A4966F50E974A40
36660	5	50	174	814	68643	\N	52.980201048500597	Иркутская область, Черемховский район, с. Нижняя Иреть, Советская,10	Россия, Иркутская область, Черемховский район, поселок Нижняя Иреть	0101000020E610000046240A2DEB9E5940D540F339777D4A40
36654	5	50	174	20885	68943	\N	53.093207999999997	Иркутская область, Черемховский район,  д.Нены, Школьная, 24		0101000020E6100000226FB9FAB1B35940DFDC5F3DEE8B4A40
36481	5	50	174	59190	69537	\N	52.8652275476854	Иркутская область, Усольское районное муниципальное образование, Мишелевское муниципальное образование, п.Мишелевка, Щорса, 8В кв.46	Россия, Иркутская область, Черемховский район, поселок Мышелевка	0101000020E6100000B0FECF61BECB5940B0CA85CABF6E4A40
36479	5	50	174	59190	68920	\N	52.861591415335702	Иркутская область, Усольское районное муниципальное образование, Мишелевское муниципальное образование, п.Мишелевка, Ленина, 31	Россия, Иркутская область, Черемховский район, поселок Мышелевка	0101000020E6100000FDBE7FF3E2CB594093C3279D486E4A40
36483	5	50	174	59193	68930	\N	52.860240773901999	Иркутская область, Усольское районное муниципальное образование, Мишелевское муниципальное образование, п.Мишелевка, переулок Бельский, 6		0101000020E61000003C84F1D3B8CA5940D4D688601C6E4A40
36657	5	50	174	20926	68000	\N	52.965147999999999	Иркутская область, Черемховский район, п. Михайловка, Советская, 8а		0101000020E610000090831266DAD2594060E63BF8897B4A40
36658	5	50	174	20926	69298	\N	52.964906799638797	Иркутская область, Черемховский район, п. Михайловка, Заречная, 13	Россия, Иркутская область, Черемховский район, поселок Михайловка	0101000020E6100000D2FE0758ABD259403A579412827B4A40
36659	5	50	174	20926	67726	\N	52.958946791958901	Иркутская область, Черемховский район, п. Михайловка, Горького, 1а	Россия, Иркутская область, Черемховский район, поселок Михайловка	0101000020E6100000E8D84125AED2594075CC79C6BE7A4A40
36656	5	50	174	20926	67994	\N	52.958583982226003	Иркутская область, Черемховский район, п. Михайловка, Iкв, 6	Россия, Иркутская область, Черемховский район, поселок Михайловка	0101000020E6100000ABEAE5779AD25940043C69E1B27A4A40
36655	5	50	174	20926	67764	\N	52.965147999999999	Иркутская область, Черемховский район,  п. Михайловка, IIкв, 5		0101000020E610000090831266DAD2594060E63BF8897B4A40
36652	5	50	174	20763	68800	\N	53.059803000000002	Иркутская область, Черемховский район, с.Лохово, Школьная, 27		0101000020E6100000B9AAECBB22B95940F299EC9FA7874A40
36644	5	50	174	20292	69295	\N	53.033752999999997	Иркутская область, Черемховский район,  д.Козлова, Нижняя, 12		0101000020E6100000BCC96FD1C9BB59402992AF0452844A40
36642	5	50	174	20185	69135	\N	52.9469878467699	Иркутская область, Черемховский район,  д.Ключи, Школьная, 3а	Россия, Иркутская область, Черемховский район, поселок Ключи	0101000020E6100000B16B7BBB25C359402BDA1CE736794A40
36684	5	50	174	22322	69225	\N	53.223106999999999	Иркутская область, Черемховский район, д. Кирзавод, Полевая, 22		0101000020E610000063D34A2190BB59401C412AC58E9C4A40
36857	5	50	174	30277	68847	\N	53.156187000000003	Иркутская область, Черемховский район, с.Катом,Тополиная,4, клуб		0101000020E6100000874D64E602B75940BA8784EFFD934A40
36650	5	50	174	20661	69142	\N	53.281162999999999	Иркутская область, Черемховский район, с.Каменно-Ангарск, Совхозная, 1		0101000020E6100000C687D9CBB6D7594031EC3026FDA34A40
36665	5	50	174	2803	69318	\N	52.973570000000002	Иркутская область, Черемховский район, с.Инга, Берёзовая,13-1		0101000020E6100000395FECBDF87D5940F12E17F19D7C4A40
36647	5	50	174	2658	68861	\N	53.053373000000001	Иркутская область, Черемховский район, с.Зерновое, Иркутская, 5		0101000020E6100000F20A444FCAD05940A5BE2CEDD4864A40
36653	5	50	174	20824	\N	\N	53.130617999999998	Иркутская область, Черемховский район,  д. Жмурова	Россия, Иркутская область, Черемховский район, поселок Жмурова	0101000020E610000035EF384547BB59406C223317B8904A40
36672	5	50	174	21723	\N	\N	53.139082999999999	Иркутская область, Черемховский район, д.Жалгай, 5		0101000020E6100000F085C954C1945940FC36C478CD914A40
36645	5	50	174	20397	67995	\N	53.042231999999998	Иркутская область, Черемховский район, с.Голуметь, Кирова		0101000020E6100000FBB0DEA8159859401E6CB1DB67854A40
36855	5	50	174	20397	68605	\N	53.042231999999998	Иркутская область, Черемховский район, с.Голуметь, Калинина,10а,ДК		0101000020E6100000FBB0DEA8159859401E6CB1DB67854A40
36668	5	50	174	59350	69724	\N	53.010621873199902	Иркутская область, Черемховский район, д.Герасимово, Центральная, 48	Россия, Иркутская область, Черемховский район, поселок Герасимова	0101000020E610000091ED7C3F35B259401E4FCB0F5C814A40
36646	5	50	174	59233	\N	\N	52.967196142198702	Иркутская область, Черемховский район,  д. В. Иреть	Россия, Иркутская область, Черемховский район, поселок Верхняя Иреть	0101000020E61000004E7B4ACE8993594038691A14CD7B4A40
36643	5	50	174	20278	69449	\N	53.031202	Иркутская область, Черемховский район, Верхний Булай, Булайская, 48		0101000020E6100000F94A202576C25940EFC8586DFE834A40
36641	5	50	174	20122	68165	\N	52.871006999999999	Иркутская область, Черемховский район, с.Бельск, Иванова, 34а		0101000020E6100000620FED6305C5594025CB49287D6F4A40
36680	5	50	174	549	69460	\N	53.217925999999999	Иркутская область, Черемховский район, д. Белобородова, Центральная,1-1		0101000020E61000009AD024B1A4C459405B79C9FFE49B4A40
36649	5	50	174	20613	69296	\N	53.007882000000002	Иркутская область, Черемховский район, д.Бархатова, Ангарская, 11		0101000020E6100000B5C5353E93D65940111D024702814A40
36651	5	50	174	20749	69284	\N	53.240889000000003	Иркутская область, Черемховский район,  д.Балухарь, Школьная, 2		0101000020E610000086AB0320EECF5940AB7B6473D59E4A40
36661	5	50	174	21246	69320	\N	52.972712999999999	Иркутская область, Черемховский район,  д.Бажей, Луговая, 30		0101000020E61000008FAB915D69A9594070B20DDC817C4A40
36638	5	50	174	19967	68530	\N	53.072259654964	Иркутская область, Черемховский район, с. Алехино, Площадь Труда, 12	Россия, Иркутская область, Черемховский район, поселок Алехино	0101000020E6100000DAE6C6F484C859408C67D0D03F894A40
36846	5	50	212	29745	68837	\N	54.185599000000003	Иркутская область, Усть-Удинский район, с. Юголок, Мира, 1		0101000020E6100000BBB88D06F0D25940CD9541B5C1174B40
36850	5	50	212	29950	69317	\N	54.189318999999998	Иркутская область, Усть-Удинский район, д. Чичкова, Центральная, 20		0101000020E6100000766C04E275ED594076C1E09A3B184B40
36631	5	50	212	3126	68965	\N	53.836163999999997	Иркутская область, Усть-Удинский район, д. Халюты, ул. Центральная, 3а		0101000020E6100000CF9ECBD424D95940D80B056C07EB4A40
36625	5	50	212	19271	\N	\N	54.171745000000001	Иркутская область, р.п. Усть-Уда, Комсомольская, 19	Россия, Иркутская область, Усть-Удинский район, поселок Усть-Уда	0101000020E61000002046088F36C2594032207BBDFB154B40
36635	5	50	212	19271	67899	\N	54.171745000000001	Иркутская область, р.п. Усть-Уда, Пионерская, 10		0101000020E61000002046088F36C2594032207BBDFB154B40
36798	5	50	212	27583	68988	\N	53.949767999999999	Иркутская область, Усть-Удинский район, д. Усть-Малой, Ленина, 14		0101000020E6100000C0EB33677DEA5940C76471FF91F94A40
36256	5	50	212	803	69360	\N	53.719841000000002	Иркутская область, Осинский район, д.Тагай, Школьная, 1		0101000020E6100000F8DF4A766CE25940F4A8F8BF23DC4A40
36845	5	50	212	29648	68600	\N	54.335189999999997	Усть- Удинский район, с. Средняя Муя, ул. Лесная, 5,		0101000020E61000003B00E2AE5EE159401EF98381E72A4B40
36637	5	50	212	19909	68940	\N	54.281925000000001	Иркутская область, Усть-Удинский район, с.Светлолобово, Совхозная, 2А		0101000020E610000017B6662B2FC8594060764F1E16244B40
36854	5	50	212	30126	69397	\N	55.206802000000003	Иркутская область, Усть-Удинский район, с. Подволочное, Советская, 16		0101000020E6100000F8FF71C284D75940AB5FE97C789A4B40
35621	5	50	212	29884	\N	\N	54.028407999999999	Иркутская область, Зиминское городское муниципальное образование, Новая, 68А	Россия, Иркутская область, Усть-Удинский район, поселок Новая Уда	0101000020E610000072A774B0FEE65940EE7893DFA2034B40
36849	5	50	212	29884	68614	\N	54.028407999999999	Иркутская область, Усть-Удинский район, с. Новая Уда, Юбилейная, 1		0101000020E610000072A774B0FEE65940EE7893DFA2034B40
36632	5	50	212	2577	68757	\N	53.881774999999998	Иркутская область,  Усть-Удинский район, с. Молька, Радищева,25		0101000020E610000072C3EFA65BD5594017B7D100DEF04A40
36636	5	50	212	19832	69133	\N	54.200544000000001	Иркутская область, Усть-Удинский район, д. Михайловщина, Набережная, 9		0101000020E6100000E370E65773C259405BB4006DAB194B40
36630	5	50	212	19559	68841	\N	53.734752	Иркутская область, Усть-Удинский район, с. Малышевка, Центральная, 23		0101000020E61000004B766C04E2D85940D655815A0CDE4A40
36633	5	50	212	19681	68941	\N	53.950817000000001	Иркутская область, Усть-Удинский район, д. Лобагай, Советская, 18		0101000020E610000041F50F2219D559408CBD175FB4F94A40
36851	5	50	212	29983	68957	\N	54.537677000000002	Иркутская область, Усть-Удинский район, д. Ключи, Комарова, 4		0101000020E61000004B5645B8C9D05940DC679599D2444B40
39160	3	24	\N	1518	59260	\N	61.784323999999998	город Петрозаводск, Анохина, 16		0101000020E6100000971B0C75582D4140E4BB94BA64E44E40
36847	5	50	212	29807	69237	\N	54.124203999999999	Иркутская область, Усть-Удинский район, д. Кижа, Мира, 4		0101000020E6100000912A8A5759D759402504ABEAE50F4B40
36634	5	50	212	19745	68804	\N	54.022430999999997	Иркутская область, Усть-Удинский район, с. Игжей, Некрасова, 1		0101000020E6100000E8BD310400C9594052B5DD04DF024B40
36848	5	50	212	29863	69450	\N	54.065930999999999	Иркутская область, Усть-Удинский район, с. Балаганка, Рабочая, 41		0101000020E6100000653909A52FD559407365506D70084B40
36853	5	50	212	30118	69312	\N	54.830156000000002	Иркутская область, Усть-Удинский район, с. Аталанка, Школьная, 8		0101000020E610000039B5334C6DC55940024A438D426A4B40
36852	5	50	212	30042	68603	\N	54.653270999999997	Иркутская область, Усть-Удинский район, с. Аносово, Набережная, 8		0101000020E6100000BE141E34BBCF59406D3656629E534B40
36594	5	50	7466	59144	68421	\N	56.846803054551799	Иркутская область, Усть-Кутское муниципальное образование, Янтальское муниципальное образование, ул.Лесная, д.10	Россия, Иркутская область, Усть-Кутский район, поселок Янталь	0101000020E6100000618A7269FC4F5A40CD936B0A646C4C40
36622	5	50	7466	59187	68905	\N	56.975632086093697	Иркутская область, Усть-Кутское муниципальное образование, Подымахинское муниципальное образование, ул.Мира, д.1	Россия, Иркутская область, Усть-Кутский район, поселок Подымахино	0101000020E61000002315C616828B5A402D776682E17C4C40
36629	5	50	7466	59177	68834	\N	56.547002393911598	Иркутская область, Усть-Кутское муниципальное образование, Нийское муниципальное образование, ул.Тбилисская, д.5	Россия, Иркутская область, Усть-Кутский район, поселок Ния	0101000020E61000004E7B4ACE89B35A405D6C5A2904464C40
35937	5	50	7466	59335	69624	\N	56.370064921350703	Иркутская область, муниципальное образование - Киренский район, Небельское муниципальное образование, Молодежная, 10	Россия, Иркутская область, Усть-Кутский район, поселок Небель	0101000020E6100000D4F36E2C28C45A407632384A5E2F4C40
36623	5	50	7466	59176	69593	\N	57.322546782381899	Иркутская область, Усть-Кутское муниципальное образование, Верхнемарковское муниципальное образование, ул.Центральная, д.4		0101000020E610000013B875374FC15A402236583849A94C40
36626	5	50	7466	59176	68810	\N	57.326272382984698	Иркутская область, Усть-Кутское муниципальное образование, Верхнемарковское муниципальное образование, ул.Фонтанная, д.7а	Россия, Иркутская область, Усть-Кутский район, поселок Верхнемарково	0101000020E61000001004C8D0B1C15A40DECCE847C3A94C40
36627	5	50	7466	59176	69535	\N	57.327189669168703	Иркутская область, Усть-Кутское муниципальное образование, Верхнемарковское муниципальное образование, ул.40 лет Победы, д.47	Россия, Иркутская область, Усть-Кутский район, поселок Верхнемарково	0101000020E6100000EA79371614C25A4004CAA65CE1A94C40
36552	5	50	331	59126	67979	\N	57.908752999999997	Иркутская область, Усть-Илимский район, р.п. Железнодорожный, Ленина, 68		0101000020E61000008505F7031EB159402992AF0452F44C40
36556	5	50	331	15780	68619	\N	57.363724309195803	Иркутская область, Усть-Илимский район, п. Эдучанка, Ермака, 4	Россия, Иркутская область, Усть-Илимский район, поселок Эдучанка	0101000020E6100000E50E9BC8CC89594099620E828EAE4C40
36557	5	50	331	15780	68621	\N	57.364420000000003	Иркутская область, Усть-Илимский район, п. Эдучанка, Дзержинского, 9		0101000020E6100000AC3940304789594011018750A5AE4C40
36582	5	50	331	14351	67759	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, пр.Дружбы Народов, д.70		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36581	5	50	331	14351	67759	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, пр.Дружбы Народов, д.38		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36586	5	50	331	14351	67725	\N	58.007272253689003	Иркутская область, город Усть- Илимск, ул.Энгельса, д.7	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E610000047E6913F18AA59409816F549EE004D40
36585	5	50	331	14351	67725	\N	57.987812773554303	Иркутская область,  город Усть- Илимск, ул.Энгельса, д.7	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E6100000AB764D486BA9594026C808A870FE4C40
36568	5	50	331	14351	68794	\N	58.005540926977602	Иркутская область, город Усть- Илимск, ул.Солнечная, д.2	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E6100000D1949D7E50AA5940C1E44691B5004D40
36565	5	50	331	14351	68120	\N	57.988542125848198	Иркутская область,  город Усть- Илимск, ул.Наймушина, д.30	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E6100000C5C72764E7A95940795C548B88FE4C40
36584	5	50	331	14351	67724	\N	58.018842647282597	Иркутская область, город Усть- Илимск, ул.Карла Маркса, д.45	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E6100000DC80CF0F23AA594017618A7269024D40
36577	5	50	331	14351	67724	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Карла Маркса, д.21		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36576	5	50	331	14351	67724	\N	58.006816649546401	Иркутская область,  город Усть- Илимск, ул.Карла Маркса, д.7	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E6100000809C306134AA594046072461DF004D40
36574	5	50	331	14351	67723	\N	58.007818970976103	Иркутская область,город Усть- Илимск, ул.Героев Труда, д.19	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E610000096236420CFA95940CAA4863600014D40
36579	5	50	331	14351	67977	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Георгия Димитрова, д.10		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36564	5	50	331	14351	67718	\N	58.028134999999999	Иркутская область,  город Усть- Илимск, ул.Булгакова, д.7		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36423	5	50	307	9460	69372	\N	54.285899000000001	Иркутская область, Тулунский район, д.Харгажин, ул.Нижняя, 5		0101000020E6100000D4D17135B23F5940C47AA35698244B40
36570	5	50	331	14351	67983	\N	58.018022821757903	Иркутская область, город Усть- Илимск, ул.Братская, д.45	Россия, Иркутская область, Усть-Илимский район, Усть-Илимск	0101000020E6100000DE3B6A4C88AA5940B4C9E1934E024D40
36569	5	50	331	14351	67983	\N	58.028134999999999	Иркутская область, город Усть- Илимск, ул.Братская, д.8		0101000020E6100000F0DDE68D93AA5940BD6F7CED99034D40
36583	5	50	331	59103	67796	\N	57.995105625687202	Иркутская область,  город Усть- Илимск, ул.Карла Маркса, д.45	Россия, Иркутская область, Усть-Илимский район	0101000020E61000000F0D8B51D7AD5940D50627A25FFF4C40
36550	5	50	331	15515	67040	\N	57.653713089075303	Иркутская область, Усть-Илимский район, п. Тубинский, Спортивная, 13	Россия, Иркутская область, Усть-Илимский район, поселок Тубинский	0101000020E6100000307F85CC95D159402BFC19DEACD34C40
36560	5	50	331	1654	67781	\N	56.979816	Иркутская область, Усть-Илимский район, п. Седаново, Солнечная,15а		0101000020E6100000FA635A9BC65359407C0C569C6A7D4C40
36559	5	50	331	15942	69466	\N	57.082478000000002	Иркутская область, Усть-Илимский район, с. Подъеланка, Мира, 8		0101000020E6100000363CBD5296695940DB519CA38E8A4C40
36549	5	50	331	15409	68119	\N	58.053022966611202	Иркутская область, Усть-Илимский район, п. Невон, Сказочная, 1	Россия, Иркутская область, Усть-Илимский район, поселок Невон	0101000020E6100000910BCEE0EFAD5940C9772975C9064D40
36548	5	50	331	15409	68013	\N	58.046106000000002	Иркутская область, Усть-Илимский район, п. Невон, Кеульская, 9		0101000020E6100000F33D23111AAE59401F1329CDE6054D40
36547	5	50	331	1536	67777	\N	58.430712838015502	Иркутская область, Усть-Илимский район, с. Кеуль, Ленина, 4	Россия, Иркутская область, Усть-Илимский район, поселок Кеуль	0101000020E61000001555BFD2F9B35940247B849A21374D40
36553	5	50	331	13411	67712	\N	57.908752999999997	Иркутская область, Усть-Илимский район, р.п. Железнодорожный, Ленина, 30 а		0101000020E61000008505F7031EB159402992AF0452F44C40
36506	5	50	331	13411	67734	\N	57.9068972411985	Иркутская область, Усольское районное муниципальное образование, Железнодорожное муниципальное образование, п.Железнодорожный, Комсомольская, 28А	Россия, Иркутская область, Усть-Илимский район, поселок Железнодорожный	0101000020E6100000DFC14F1C40B1594096EB6D3315F44C40
36551	5	50	331	13411	68121	\N	57.908752999999997	Иркутская область, Усть-Илимский район, р.п. Железнодорожный, Дорожная, 4		0101000020E61000008505F7031EB159402992AF0452F44C40
36558	5	50	331	15881	68796	\N	57.149332999999999	Иркутская область, Усть-Илимский район, с.Ершово, Комарова, 15		0101000020E6100000A1F7C610008F5940569BFF571D934C40
36554	5	50	331	1618	68645	\N	57.767068000000002	Иркутская область, Усть-Илимский район, п. Бадарминск, Школьная, 6		0101000020E61000004489963C9E98594071E7C2482FE24C40
36555	5	50	331	15748	69145	\N	57.754057000000003	Иркутская область, Усть-Илимский район, п. Бадарма, Молодежная, 3		0101000020E61000005F07CE19519B5940F22895F084E04C40
36510	5	50	1227	13594	69129	\N	52.477809000000001	Иркутская область, Усольское районное муниципальное образование, Большееланское муниципальное образование, с.Целоты, Мира, 35		0101000020E610000017D86322A5E25940035E66D8283D4A40
36494	5	50	1227	12880	68937	\N	52.875034999999997	Иркутская область, Усольское районное муниципальное образование, Тайтурское муниципальное образование, с.Холмушино, Набережная, 86		0101000020E6100000A038807EDFD359407CED992501704A40
36518	5	50	1227	13988	69137	\N	52.261110000000002	Иркутская область, Усольское районное муниципальное образование, Тальянское муниципальное образование, п.Ходарей, Набережная, 20		0101000020E61000000A12DBDD03CE59404C546F0D6C214A40
36485	5	50	1227	12471	69446	\N	52.810378999999998	Иркутская область, Усольское районное муниципальное образование, Мишелевское муниципальное образование, с.Хайта, Центральная, ОСП ДК с.Хайта		0101000020E6100000A83462669FCC5940BE2EC37FBA674A40
36505	5	50	1227	13318	67961	\N	52.685357000000003	Иркутская область, Усольское районное муниципальное образование, Тельминское муниципальное образование, п.Тельма, Крупской, 11		0101000020E6100000A8E2C62DE6ED5940D78A36C7B9574A40
36504	5	50	1227	13318	67710	\N	52.685357000000003	Иркутская область, Усольское районное муниципальное образование, Тельминское муниципальное образование, п.Тельма, 2-я Советская, 4		0101000020E6100000A8E2C62DE6ED5940D78A36C7B9574A40
36508	5	50	1227	13318	69463	\N	52.668512999999997	Иркутская область, Усольское районное муниципальное образование, Железнодорожное муниципальное образование, станция Тельма, 2-я Железнодорожная, 1А		0101000020E6100000D0285DFA97EE5940B5F97FD591554A40
36517	5	50	1227	59191	68924	\N	52.1949941605478	Иркутская область, Усольское районное муниципальное образование, Тальянское муниципальное образование. п.Тальяны, Клубная, 2	Россия, Иркутская область, Усольский район, поселок Тальяны	0101000020E61000004031B2648ED0594047753A90F5184A40
36497	5	50	1227	12911	67707	\N	52.865169000000002	Иркутская область, Усольское районное муниципальное образование, Тайтурское муниципальное образование, п.Тайтурка, Пеньковского, 8		0101000020E61000006E313F3734DD5940AB4198DBBD6E4A40
36495	5	50	1227	12911	68523	\N	52.865169000000002	Иркутская область, Усольское районное муниципальное образование, Тайтурское муниципальное образование, п.Тайтурка, Ленина, 21		0101000020E61000006E313F3734DD5940AB4198DBBD6E4A40
36496	5	50	1227	12911	67926	\N	52.865169000000002	Иркутская область, Усольское районное муниципальное образование, Тайтурское муниципальное образование, п.Тайтурка, Гоголя, 2		0101000020E61000006E313F3734DD5940AB4198DBBD6E4A40
36501	5	50	1227	59100	\N	\N	52.894602999999996	Иркутская область, Усольское районное муниципальное образование, Среднинское муниципальное образование, п.Средний, Дом офицеров п.Средний		0101000020E610000071E481C822E15940A5F3E15982724A40
36500	5	50	1227	59100	67775	\N	52.902672131260097	Иркутская область, Усольское районное муниципальное образование, Среднинское муниципальное образование, п.Средний, 3-я Степная, 14	Россия, Иркутская область, Усольский район, поселок Средний	0101000020E61000007E5182FE42E25940E9818FC18A734A40
36486	5	50	1227	58906	66990	\N	52.820028999999998	"""Иркутская область, Усольское районное муниципальное образование, Сосновское муниципальное образование, с.Сосновка, ул.Лесная,2-б,школа"	Россия, Иркутская область, Усольский район, поселок Сосновка	0101000020E6100000F73C7FDAA8D95940C362D4B5F6684A40
36515	5	50	1227	13831	68793	\N	52.445923999999998	Иркутская область, Усольское районное муниципальное образование, Раздольинское муниципальное образование, п.Раздолье, Мира, 25		0101000020E6100000CA6B257497CC59403140A20914394A40
36516	5	50	1227	59242	69343	\N	52.411322852783599	Иркутская область, Усольское районное муниципальное образование, Раздольинское муниципальное образование, п.Октябрьский, Октябрьская, 24	Россия, Иркутская область, Усольский район, поселок Октябрьский	0101000020E6100000D542C9E4D4BE5940DB8B683BA6344A40
36502	5	50	1227	13223	67715	\N	52.869017999999997	Иркутская область, Усольское районное муниципальное образование, Новомальтинское муниципальное образование, п.Новомальтинск, Квартал 2, 1		0101000020E6100000EBC6BB2363E3594052D158FB3B6F4A40
36512	5	50	1227	13695	\N	\N	52.558408999999997	Иркутская область, Усольское районное муниципальное образование, Новожилкинское муниципальное образование, с.Новожилкино, Ленина, 1	Россия, Иркутская область, Усольский район, поселок Новожилкино	0101000020E6100000D15D126745E35940626534F279474A40
36491	5	50	1227	12701	67749	\N	52.834606000000001	Иркутская область, Усольское районное муниципальное образование, Мальтинское муниципальное образование, с.Мальта, Школьная, 21А		0101000020E6100000098849B890E15940CF85915ED46A4A40
36490	5	50	1227	12701	68795	\N	52.834606000000001	Иркутская область, Усольское районное муниципальное образование, Мальтинское муниципальное образование, с.Мальта, Разведочная, 17		0101000020E6100000098849B890E15940CF85915ED46A4A40
36492	5	50	1227	12701	69429	\N	52.834606000000001	Иркутская область, Усольское районное муниципальное образование, Мальтинское муниципальное образование, с.Мальта, Ленина, 83		0101000020E6100000098849B890E15940CF85915ED46A4A40
36498	5	50	1227	13035	68952	\N	52.943376999999998	Иркутская область, Усольское районное муниципальное образование, Тайтурское муниципальное образование, д.Кочерикова, Главная, ОСП клуб д.Кочерикова		0101000020E6100000E17D552E54DA59403866D993C0784A40
36513	5	50	1227	59280	69530	\N	52.586514000000001	Иркутская область, Усольское районное муниципальное образование, Новожилкинское муниципальное образование, д.Ключевая, Рабочая, 7А	Россия, Иркутская область, Усольский район, поселок Ключевая	0101000020E610000059A65F22DEE45940B55208E4124B4A40
36499	5	50	1227	13093	69465	\N	52.990952	Иркутская область, Усольское районное муниципальное образование, Тайтурское муниципальное образование, д. Буреть, Набережная, ОСП клуб д.Буреть		0101000020E6100000AE11C138B8E05940F1F3DF83D77E4A40
36509	5	50	1227	13561	67974	\N	52.572865999999998	Иркутская область, Усольское районное муниципальное образование, Большееланское муниципальное образование, с.Большая Елань, Победы, 2		0101000020E610000002D8800871EA5940C37E4FAC53494A40
36511	5	50	1227	13650	68820	\N	52.540841999999998	Иркутская область, Усольское районное муниципальное образование, Большееланское муниципальное образование, д.Большежилкина, Мира, 21, кв.2		0101000020E6100000AFB5F7A92AE55940D026874F3A454A40
36489	5	50	1227	12557	\N	\N	52.808838999999999	Иркутская область, Усольское районное муниципальное образование, Белореченское муниципальное образование, п.Белореченский, 109		0101000020E61000000E492D944CE159405B5D4E0988674A40
36488	5	50	1227	12557	\N	\N	52.808838999999999	Иркутская область, Усольское районное муниципальное образование, Белореченское муниципальное образование, п.Белореченский, 106		0101000020E61000000E492D944CE159405B5D4E0988674A40
36487	5	50	1227	12557	\N	\N	52.808838999999999	Иркутская область, Усольское районное муниципальное образование, Белореченское муниципальное образование, п.Белореченский, 48		0101000020E61000000E492D944CE159405B5D4E0988674A40
36503	5	50	1227	13282	69241	\N	52.876697999999998	Иркутская область, Усольское районное муниципальное образование, Новомальтинское муниципальное образование, д.Бадай, Совхозная, 11		0101000020E6100000BA8102EFE4E65940FB3BDBA337704A40
36417	5	50	307	59257	69416	\N	54.166527000000002	Иркутская область, Тулунский район п.1 отделение Государственной селекционной станции, ул.Зерновая, 20а		0101000020E61000006F83DA6FED0A59405473B9C150154B40
36422	5	50	307	59192	68925	\N	54.453912233781097	Иркутская область, Тулунский район, п.ж/д ст.Шуба, ул.Клубная, 2	Россия, Иркутская область, Тулунский район, поселок Шуба	0101000020E6100000E962D34A2139594088A1D5C9193A4B40
36419	5	50	307	9290	37456	\N	54.460546000000001	Иркутская область, Тулунский район, с.Шерагул, ул.Гагарина, 20		0101000020E6100000F778211D1E3A5940DD26DC2BF33A4B40
36414	5	50	307	9083	68785	\N	54.596963000000002	Иркутская область, Тулунский район, п.Центральные Мастерские, ул.Докучаева, 2		0101000020E6100000804A95287B21594006F69848694C4B40
36445	5	50	307	10565	69221	\N	54.698394999999998	Иркутская область, Тулунский район, п.Целинные Земли, ул.Шолохова, 16		0101000020E6100000BDFBE3BD6A2859404F58E20165594B40
39467	3	24	1828	29081	59314	\N	62.069932999999999	п.Водла, ул.Комсомольская, д.13а		0101000020E6100000E8154F3DD2BA4240A1F48590F3084F40
36424	5	50	307	9507	69424	\N	54.338833000000001	Иркутская область, Тулунский район, д.Уталай, ул.Центральная, 25		0101000020E61000008753E6E61B3A59401DE736E15E2B4B40
36409	5	50	307	8827	69093	\N	54.6394892082658	Иркутская область, Тулунский район, п.Утай, ул.Нагорная, 30	Россия, Иркутская область, Тулунский район, поселок Утай	0101000020E61000002BDCF291941459406C938AC6DA514B40
36447	5	50	307	10659	69425	\N	54.880805000000002	Иркутская область, Тулунский район, с.Усть-Кульск, ул.Школьная, 11		0101000020E61000005C3CBCE7C02459409F93DE37BE704B40
36442	5	50	307	10431	68783	\N	54.751840000000001	Иркутская область, Тулунский район, с.Умыган, ул.И.Каторжного, 77		0101000020E6100000DBC2F352B10E59408EE9094B3C604B40
36413	5	50	307	9035	69369	\N	54.084088000000001	Иркутская область, Тулунский район, с.Уйгат, ул.Школьная, 1		0101000020E6100000EF8E8CD5E625594037FE4465C30A4B40
36456	5	50	307	1419	68599	\N	54.541970999999997	Иркутская область, город Тулун, микрорайон Угольщиков, 34		0101000020E61000003C889D2974285940B130444E5F454B40
36455	5	50	307	1419	68599	\N	54.541970999999997	Иркутская область, город Тулун, микрорайон Угольщиков, 4		0101000020E61000003C889D2974285940B130444E5F454B40
36449	5	50	307	1419	68892	\N	54.565920086416	Иркутская область, город Тулун, улица Угольная, 8 Г	Россия, Иркутская область, Тулунский район, Тулун	0101000020E6100000BD512B4CDF2459407F130A1170484B40
35095	5	50	307	1419	67751	\N	54.541970999999997	Иркутская область, город Тулун, улица Сигаева, 17		0101000020E61000003C889D2974285940B130444E5F454B40
36450	5	50	307	1419	68792	\N	54.541970999999997	Иркутская область, город Тулун, улица Сибстроя, 11		0101000020E61000003C889D2974285940B130444E5F454B40
36473	5	50	307	1419	68808	\N	54.541970999999997	Иркутская область, город Тулун, улица Пугачева, 9		0101000020E61000003C889D2974285940B130444E5F454B40
36468	5	50	307	1419	67705	\N	54.541970999999997	Иркутская область, город Тулун, улица Протасюка, 49		0101000020E61000003C889D2974285940B130444E5F454B40
36415	5	50	307	1419	68960	\N	54.558872665129797	Иркутская область, Тулунский район, п.4 отделение Государственной селекционной станции, ул.Мичурина, 36	Россия, Иркутская область, Тулунский район, Тулун	0101000020E61000001B834E081D24594007CF842689474B40
36453	5	50	307	1419	68598	\N	54.541970999999997	Иркутская область, город Тулун, улица Мира, 3		0101000020E61000003C889D2974285940B130444E5F454B40
36475	5	50	307	1419	68741	\N	54.541970999999997	Иркутская область, город Тулун, улица Ломоносова, 26		0101000020E61000003C889D2974285940B130444E5F454B40
36463	5	50	307	1419	68281	\N	54.565084681039899	Иркутская область, город Тулун, улица Ленина, 3 А	Россия, Иркутская область, Тулунский район, Тулун	0101000020E6100000BD56427749255940E73A8DB454484B40
36461	5	50	307	1419	68281	\N	54.541970999999997	Иркутская область, город Тулун, улица Ленина, 96		0101000020E61000003C889D2974285940B130444E5F454B40
36460	5	50	307	1419	68281	\N	54.541970999999997	Иркутская область, город Тулун, улица Ленина, 91		0101000020E61000003C889D2974285940B130444E5F454B40
36459	5	50	307	1419	68281	\N	54.541970999999997	Иркутская область, город Тулун, улица Ленина, 101		0101000020E61000003C889D2974285940B130444E5F454B40
36469	5	50	307	1419	68522	\N	54.541970999999997	Иркутская область, город Тулун, улица Красноармейская, 4		0101000020E61000003C889D2974285940B130444E5F454B40
36448	5	50	307	1419	68790	\N	54.541970999999997	Иркутская область, город Тулун, улица Заречная 2-я, 9		0101000020E61000003C889D2974285940B130444E5F454B40
36458	5	50	307	1419	68731	\N	54.541970999999997	Иркутская область, город Тулун, улица Жданова, 1 Б		0101000020E61000003C889D2974285940B130444E5F454B40
36470	5	50	307	1419	68789	\N	54.541970999999997	Иркутская область, город Тулун, улица Ермакова, 5		0101000020E61000003C889D2974285940B130444E5F454B40
36471	5	50	307	1419	68791	\N	54.541970999999997	Иркутская область, город Тулун, улица Горячкина, 12		0101000020E61000003C889D2974285940B130444E5F454B40
36476	5	50	307	1419	67740	\N	54.541970999999997	Иркутская область, город Тулун, улица Блюхера, 60		0101000020E61000003C889D2974285940B130444E5F454B40
36420	5	50	307	9331	69371	\N	54.484315000000002	Иркутская область, Тулунский район, д.Трактовая, ул.Лесная, 10		0101000020E610000015ADDC0BCC4359402BFBAE08FE3D4B40
36412	5	50	307	8985	69459	\N	54.719434999999997	Иркутская область, Тулунский район, п.Сибиряк, ул.Садовая, 13		0101000020E6100000D40B3ECDC9205940834C3272165C4B40
36398	5	50	307	8344	69141	\N	54.673184999999997	Иркутская область, Тулунский район, д.Северный Кадуй, ул.Новая, 8		0101000020E610000045847F1134065940319413ED2A564B40
36429	5	50	307	9755	69223	\N	54.370111000000001	Иркутская область, Тулунский район, д.Петровск, ул.Центральная, 14		0101000020E6100000CC0BB08F4E195940E77118CC5F2F4B40
36428	5	50	307	9693	69281	\N	54.4099042239013	Иркутская область, Тулунский район, с.Перфилово, ул.50 лет Октября, 39	Россия, Иркутская область, Тулунский район, поселок Перфилово	0101000020E6100000B648DA8D3E1F5940F23FF9BB77344B40
36332	5	50	307	5037	69428	\N	54.841382000000003	Иркутская область, Тулунский район, д.Паберега, ул.Набережная, 29		0101000020E6100000E2E995B20C3B5940B7B8C667B26B4B40
36434	5	50	307	10027	69108	\N	54.186281530507301	Иркутская область, Тулунский район, д.Одон, ул.Набережная, 23	Россия, Иркутская область, Тулунский район, поселок Одон	0101000020E6100000588FFB56EB1E5940AFEAAC16D8174B40
36421	5	50	307	9360	69215	\N	54.455679000000003	Иркутская область, Тулунский район, д.Новотроицк, ул.Школьная, 20		0101000020E61000003080F0A144435940AC3C81B0533A4B40
36443	5	50	307	10467	68890	\N	54.633557000000003	Иркутская область, Тулунский район, с.Никитаево, ул.Кировская, 47		0101000020E610000098DEFE5C342C59407193516518514B40
36427	5	50	307	9667	69218	\N	54.467789000000003	Иркутская область, Тулунский район, д.Нижний Манут, ул.Набережная, 24		0101000020E6100000CD5B751DAA215940DB368C82E03B4B40
36438	5	50	307	10216	69100	\N	54.256791999999997	Иркутская область, Тулунский район, д.Нижний Бурбук, ул.Зеленая, 4		0101000020E610000076DD5B9198FE5840EDEF6C8FDE204B40
36440	5	50	307	10307	68784	\N	54.469981177565501	Иркутская область, Тулунский район, с.Мугун, ул.Ленина, 61	Россия, Иркутская область, Тулунский район, поселок Мугун	0101000020E6100000707A17EFC70F5940E55E6056283C4B40
36410	5	50	307	8896	67036	\N	54.650016000000001	Иркутская область, Тулунский район, с.Котик, ул.Центральная, 1а		0101000020E6100000DA1EBDE13E1D594039F06AB933534B40
36439	5	50	307	10277	69426	\N	54.119767800639501	Иркутская область, Тулунский район, п.Ишидей, ул.Школьная, 37	Россия, Иркутская область, Тулунский район, поселок Ишидей	0101000020E6100000473B6EF8DDED5840BD8DCD8E540F4B40
36436	5	50	307	10117	68591	\N	54.189065999999997	Иркутская область, Тулунский район, с.Икей, пер.Пионерский, 9		0101000020E61000005F7F129F3B0559408C648F5033184B40
36433	5	50	307	9964	69096	\N	54.312080000000002	Иркутская область, Тулунский район, д.Изегол, ул.Ленина, 38		0101000020E6100000BDC3EDD0B00759402BDEC83CF2274B40
36411	5	50	307	59281	69531	\N	54.629351	Иркутская область, Тулунский район, д.Заусаева, ул.Кирова, 48	Россия, Иркутская область, Тулунский район, поселок Заусаево	0101000020E6100000BB473657CD2059403A5AD5928E504B40
36432	5	50	307	9910	68730	\N	54.253562000000002	Иркутская область, Тулунский район, с.Едогон, ул.Ленина, 70		0101000020E6100000761BD47E6B0F594012C138B874204B40
36431	5	50	307	59173	68753	\N	54.234879999999997	Иркутская область, Тулунский район, п.Евдокимовский,  ул.Центральная, 19		0101000020E610000094DE37BEF62A5940033E3F8C101E4B40
36446	5	50	307	10630	68594	\N	54.758428000000002	Иркутская область, Тулунский район, с.Гуран, ул.Бурлова, 36		0101000020E6100000E292E34EE9285940732F302B14614B40
36425	5	50	307	9551	68782	\N	54.398072999999997	Иркутская область, Тулунский район, с.Гадалей, ул.Степная, 1а		0101000020E61000001DE736E15E2F5940D6355A0EF4324B40
36435	5	50	307	10056	69288	\N	54.174717999999999	Иркутская область, Тулунский район, д.Владимировка, ул.Полевая, 5		0101000020E61000007288B83995135940E202D0285D164B40
36408	5	50	307	8795	69212	\N	54.824617000000003	Иркутская область, Тулунский район, с.Бурхун, ул.Трактовая, 13		0101000020E610000088653387A4345940E25CC30C8D694B40
36416	5	50	307	9168	69095	\N	54.582329999999999	Иркутская область, Тулунский район, д.Булюшкина, ул.Школьная, 1		0101000020E61000004225AE635C19594066BD18CA894A4B40
36389	5	50	307	7881	69421	\N	54.627183000000002	Иркутская область, Тулунский район, с.Будагово, ул.Школьная, 12		0101000020E6100000F9DC09F65F085940B8CD548847504B40
36430	5	50	307	9828	68542	\N	54.398570999999997	Иркутская область, Тулунский район, с.Бадар, ул.Братская, 20		0101000020E61000001094DBF63D2659402711E15F04334B40
36444	5	50	307	10529	69103	\N	54.640321	Иркутская область, Тулунский район, д.Афанасьева, ул.Ленина, 8		0101000020E610000006B8205B9627594094F8DC09F6514B40
36437	5	50	307	10162	69289	\N	53.925815	Иркутская область, Тулунский район, п.Аршан, ул.Школьная, 1		0101000020E61000007C2766BD18FA5840B8921D1B81F64A40
36441	5	50	307	10358	68888	\N	54.410226999999999	Иркутская область, Тулунский район, с.Алгатуй, Солнечная, 16		0101000020E6100000B515FBCBEE0C5940D5777E5182344B40
36426	5	50	307	9242	69216	\N	54.509166999999998	Иркутская область, Тулунский район, д.Азей, ул.Школьная, 27		0101000020E6100000F5824F73F2305940E9995E622C414B40
36418	5	50	307	9242	68891	\N	54.509166999999998	Иркутская область, Тулунский район, с.Азей, ул.Привокзальная, 12		0101000020E6100000F5824F73F2305940E9995E622C414B40
36380	5	50	139	7443	68885	\N	56.049188999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Юртинское муниципальное образование, рабочий поселок Юрты, улица Школьная, дом 9, помещение школы № 24"		0101000020E61000001B2AC6F99B68584056293DD34B064C40
36383	5	50	139	7443	68721	\N	56.049188999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Юртинское муниципальное образование, рабочий поселок Юрты, улица Советская, дом 25А, помещение центра досуга"		0101000020E61000001B2AC6F99B68584056293DD34B064C40
36379	5	50	139	7443	68899	\N	56.049188999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Юртинское муниципальное образование, рабочий поселок Юрты, улица Матросова, дом 5, помещение школы № 17"		0101000020E61000001B2AC6F99B68584056293DD34B064C40
36382	5	50	139	7443	68590	\N	56.049188999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Юртинское муниципальное образование, рабочий поселок Юрты, улица Дружбы, дом 6, помещение администрации"		0101000020E61000001B2AC6F99B68584056293DD34B064C40
36336	5	50	139	5254	68533	\N	56.369630999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Шиткинское муниципальное образование, рабочий поселок Шиткино, улица Кирова, дом 19, помещение школы"		0101000020E6100000317C444C899658403C4B9011502F4C40
36337	5	50	139	5254	68780	\N	56.369630999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Шиткинское муниципальное образование, рабочий поселок Шиткино, улица Барковская, дом 21, помещение школы"		0101000020E6100000317C444C899658403C4B9011502F4C40
36357	5	50	139	52151	68745	\N	55.722036000000003	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Шелеховское муниципальное образование, село Шелехово, улица Первомайская, дом 8"""		0101000020E61000004815C5ABAC6C58407044F7AC6BDC4B40
36330	5	50	139	4930	68746	\N	56.926941999999997	"Иркутская область, муниципальное образование ""Тайшетский район"", Шелаевское муниципальное образование, cело Шелаево, улица Советская, дом 49, помещение Дома культуры"		0101000020E6100000CE6C57E8836C5840F8A41309A6764C40
36327	5	50	139	52134	69365	\N	56.724691999999997	"Иркутская область, муниципальное образование ""Тайшетский район"", Черчетское муниципальное образование, село Черчет, улица Ленина, дом 57"		0101000020E6100000AC3AAB05F67658401FD61BB5C25C4C40
36361	5	50	139	52203	69090	\N	55.918984000000002	"Иркутская область, муниципальное образование ""Тайшетский район"", Зареченское муниципальное образование, деревня Троицк, улица Центральная, дом 13, помещение сельского клуба"		0101000020E6100000287CB60E0E6358400DC68844A1F54B40
36325	5	50	139	52125	69140	\N	56.718938000000001	"Иркутская область, муниципальное образование ""Тайшетский район"", Джогинское муниципальное образование, деревня Тремина, улица Центральная, дом 55, помещение  Дома культуры"		0101000020E6100000191D90847D83584003ED0E29065C4C40
36364	5	50	139	52205	69419	\N	55.943022999999997	"Иркутская область, муниципальное образование ""Тайшетский район"", Тимирязевское муниципальное образование, деревня Тимирязева, улица Зеленая, дом 29, помещение администрации"		0101000020E610000054707841447058401A3048FAB4F84B40
36319	5	50	139	4332	68712	\N	57.271463756414803	"Иркутская область, муниципальное образование ""Тайшетский район"", Тамтачетское муниципальное образование поселок ж.д. Тамтачет, улица Гайнулина, дом 1В, помещение Дома культуры"	Россия, Иркутская область, Тайшетский район, поселок Тамтачет	0101000020E6100000A6B8AAECBB6E58404B051555BFA24C40
36354	5	50	139	52185	69272	\N	55.587494	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Тальское муниципальное образование, село Талая, улица Советская, дом 109"""		0101000020E6100000978BF84ECC6F5840514CDE0033CB4B40
36402	5	50	139	59260	\N	\N	55.935150829829396	"Иркутская область, муниципальное образование ""Тайшетский район"", Тайшетское муниципальное образование, г. Тайшет, поселок 10-го сельхоза, помещение учреждения колонии № 22"		0101000020E6100000A3CEDC43C27F58402DE92807B3F74B40
36369	5	50	139	52180	69115	\N	56.015363999999998	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Старо-Акульшетское муниципальное образование, село Старый акульшет, улица Бирюсинская,30"""		0101000020E61000007DE6AC4F3984584093C49272F7014C40
36355	5	50	139	52187	68610	\N	55.531320999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Соляновское муниципальное образование, поселок Соляная, улица Береговая, дом 3, помещение администрации"		0101000020E6100000488AC8B08A745840C956975302C44B40
36356	5	50	139	52191	69089	\N	55.408593000000003	"Иркутская область, муниципальное образование ""Тайшетский район"", Соляновское муниципальное образование, поселок Сереброво, улица Профсоюзная, дом 19, помещение школы"		0101000020E61000008DB800344A775840F12F82C64CB44B40
36365	5	50	139	52200	69457	\N	55.885292	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Тимирязевское муниципальное образование, деревня Сафроновка, улица Зеленая, дом 55"""		0101000020E61000009B3C65355D74584089B48D3F51F14B40
36363	5	50	139	52197	68947	\N	55.791946000000003	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Рождественское муниципальное образование, село Рождественка, улица Колхозная, дом 6"""		0101000020E6100000016C4084B868584059198D7C5EE54B40
36350	5	50	139	59211	69106	\N	55.712715000000003	"Иркутская область, муниципальное образование ""Тайшетский район"", Разгонское муниципальное образование, поселок ж.д. станции Разгон, улица Железнодорожная, дом 4, помещение Дома культуры"	Россия, Иркутская область, Тайшетский район, поселок Разгон	0101000020E61000005BE9B5D958995840302FC03E3ADB4B40
36366	5	50	139	52209	68893	\N	56.068765670402499	"Иркутская область, муниципальное образование ""Тайшетский район"", Половино-Черемховское муниципальное образование, село Половино-Черемхово, улица Трактовая, дом 78, помещение дома культуры"	Россия, Иркутская область, Тайшетский район, поселок Половино-Черемхово	0101000020E6100000AB09A2EE03685840D2890453CD084C40
36317	5	50	139	59288	69544	\N	57.347717860047702	"Иркутская область, муниципальное образование ""Тайшетский район"", Полинчетское муниципальное образование поселок Полинчет, улица Центральная, дом 9, помещение Дома культуры"	Россия, Иркутская область, Тайшетский район, поселок Полинчет	0101000020E6100000368FC360FE865840821DFF0582AC4C40
35591	5	50	139	430	68680	\N	55.845956000000001	"Иркутская область, Зиминское районное муниципальное образование, Покровское муниципальное образование, с Покровка, Центральная, 28 ""А"""		0101000020E6100000A5F622DA8E63584070ED444948EC4B40
36329	5	50	139	52139	69456	\N	56.895324000000002	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Мирнинское муниципальное образование, поселок Пея, улица Капустина, дом 5"""		0101000020E61000004FCC7A319475584076A911FA99724C40
36371	5	50	139	52212	69094	\N	55.941893999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Старо-Акульшетское муниципальное образование, деревня Парижская Коммуна, улица Школьная, дом 18, здание ФАПа"		0101000020E6100000A9BEF38B1288584039268BFB8FF84B40
36349	5	50	139	59291	69547	\N	55.668021225256801	"Иркутская область, муниципальное образование ""Тайшетский район"", Разгонское муниципальное образование, поселок ж.д. станции Облепиха, улица Трактовая, дом 15, помещение школы"	Россия, Иркутская область, Тайшетский район, поселок Облепиха	0101000020E6100000ED9E3C2CD49C584047054EB681D54B40
36347	5	50	139	59253	69375	\N	55.909891999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Березовское муниципальное образование, деревня Новый Акульшет, улица Трактовая, дом 44, помещение ФАПа"		0101000020E6100000C6DE8B2FDA8458402E724F5777F44B40
36313	5	50	235	3971	69003	\N	51.742944000000001	Иркутская область, Слюдянский район, д. Быстрая, Советская, 50		0101000020E6100000382C0DFCA8DC59403561FBC918DF4940
36326	5	50	139	52131	69374	\N	56.724691999999997	"Иркутская область, муниципальное образование ""Тайшетский район"", Джогинское муниципальное образование, поселок Новотремино, улица Зеленая, дом 13"		0101000020E61000004757E9EE3A8458401FD61BB5C25C4C40
36323	5	50	139	4491	68777	\N	56.9577703975066	"Иркутская область, муниципальное образование ""Тайшетский район"", Новобирюсинское муниципальное образование, рабочий поселок Новобирюсинский, улица Советская, дом 9, помещение Дома культуры"	Россия, Иркутская область, Тайшетский район, поселок Новобирюсинский	0101000020E61000006EA301BC056D5840828B1535987A4C40
36322	5	50	139	4491	68894	\N	56.957020999999997	"Иркутская область, муниципальное образование ""Тайшетский район"", Новобирюсинское муниципальное образование, рабочий поселок Новобирюсинский, улица Ленина, дом 22 помещение администрации"		0101000020E61000001E51A1BAB96D5840E84A04AA7F7A4C40
36351	5	50	139	6043	68719	\N	55.790489000000001	"Иркутская область, муниципальное образование ""Тайшетский район"",  село Николаевка, улица 40 лет Октября, дом 17 ДК"		0101000020E6100000FA449E245D8B5840836C59BE2EE54B40
36334	5	50	139	52147	69405	\N	56.143101999999999	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Нижнезаимское муниципальное образование, село Нижняя Заимка, улица Пионерская,1"		0101000020E6100000CB811E6ADB8E584000FF942A51124C40
36344	5	50	139	59336	69625	\N	56.116995000000003	"Иркутская область, муниципальное образование ""Тайшетский район"", Квитокское муниципальное образование, поселок ж.д. станции Невельская, улица Транспортная, дом 2, помещение школы"	Россия, Иркутская область, Тайшетский район, поселок Невельская	0101000020E6100000EBA9D55757A25840D46531B1F90E4C40
36328	5	50	139	52137	68779	\N	56.879367999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Мирнинское муниципальное образование, село Мирный, улица Школьная, дом 11А, помещение администрации"		0101000020E61000008121AB5B3D6D5840109370218F704C40
36367	5	50	139	52210	69092	\N	56.029079000000003	"Иркутская область, муниципальное образование ""Тайшетский район"", Половино-Черемховское муниципальное образование, село Конторка, улица Трактовая, дом 61, помещение школы"		0101000020E61000004CA94BC6317758400D0055DCB8034C40
36335	5	50	139	52149	69088	\N	56.101503999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Нижнезаимское муниципальное образование, деревня Коновалова, улица Трактовая, дом 12А"		0101000020E6100000DE0033DFC18A5840E3344415FE0C4C40
36318	5	50	139	59305	69567	\N	57.351388999999998	"Иркутская область, муниципальное образование ""Тайшетский район"", Полинчетское муниципальное образование с. Кондратьево, улица Центральная, дом 36, помещение сельского клуба"	Россия, Иркутская область, Тайшетский район, поселок Кондратьево	0101000020E6100000FDA19927D78B58404A969350FAAC4C40
36341	5	50	139	5525	67698	\N	56.073011999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Квитокское муниципальное образование, рабочий поселок Квиток, улица Первомайская, дом 52, помещение Дома Досуга"		0101000020E610000039471D1D579E5840971B0C7558094C40
36345	5	50	139	5525	69417	\N	56.073011999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Квитокское муниципальное образование, рабочий поселок Квиток, улица Октябрьская, дом 10, помещение администрации"		0101000020E610000039471D1D579E5840971B0C7558094C40
36343	5	50	139	5525	67894	\N	56.073011999999999	"Иркутская область, муниципальное образование ""Тайшетский район"", Квитокское муниципальное образование, рабочий поселок Квиток, улица Калинина, дом 31, помещение школы"		0101000020E610000039471D1D579E5840971B0C7558094C40
36333	5	50	139	52145	69366	\N	56.511192000000001	"Иркутская область, муниципальное образование ""Тайшетский район"", Бузыкановское муниципальное образование, деревня Иванов Мыс, улица Молодежная, дом 12, помещение сельского клуба"		0101000020E6100000FFB1101D029A584009FD4CBD6E414C40
36360	5	50	139	52195	69277	\N	55.966225116061501	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Зареченское муниципальное образование, село Заречное, улица Ленина, дом 16"	Россия, Иркутская область, Тайшетский район, поселок Заречное	0101000020E6100000D522A298BC6A5840EFC9C342ADFB4B40
36324	5	50	139	52124	69087	\N	56.650696000000003	"Иркутская область, муниципальное образование ""Тайшетский район"", Джогинское муниципальное образование, село Джогино, улица Больничная, дом 8, помещение администрации"		0101000020E6100000C4EC65DB698A5840ABD1AB014A534C40
36320	5	50	139	59326	69602	\N	57.176481821090697	"Иркутская область, муниципальное образование ""Тайшетский район"", Тамтачетское муниципальное образование поселок ж.д. станции Горевая, улица Мира, дом 4, помещение сельского клуба"	Россия, Иркутская область, Тайшетский район, поселок Горевая	0101000020E6100000BF7CB262B8705840952A51F696964C40
36331	5	50	139	52143	69458	\N	56.575453000000003	"Иркутская область, муниципальное образование ""Тайшетский район"", Бузыкановское муниципальное образование, село Бузыканово, улица Школьная, дом 1, помещение администрации"		0101000020E6100000A3755435419858404BB1A371A8494C40
36302	5	50	235	3244	67803	\N	51.513848000000003	Иркутская область, Слюдянский район, г. Байкальск, микрорайон Южный, 2 квартал, 51		0101000020E61000008D9944BDE0085A40B98E71C5C5C14940
36338	5	50	139	52157	69415	\N	56.165413000000001	"Иркутская область, муниципальное образование ""Тайшетский район"", Борисовское муниципальное образование, село Борисово, улица Центральная, дом 15А, помещение администрации"		0101000020E6100000915F3FC406935840A8AAD0402C154C40
36373	5	50	139	52216	67896	\N	55.961551	"Иркутская область, муниципальное образование ""Тайшетский район"", Бирюсинское муниципальное образование, г. Бирюсинск, улица Советская, дом 19А, помещение центра культуры"		0101000020E61000006A4E5E6402745840D237691A14FB4B40
36376	5	50	139	52216	67973	\N	55.961551	"Иркутская область, муниципальное образование ""Тайшетский район"", Бирюсинское муниципальное образование, г. Бирюсинск, улица Октябрьская, дом 10, помещение школы №6"		0101000020E61000006A4E5E6402745840D237691A14FB4B40
36377	5	50	139	52216	67766	\N	55.961551	"Иркутская область, муниципальное образование ""Тайшетский район"", Бирюсинское муниципальное образование, город Бирюсинск, улица Ленина, дом 65, помещение школы № 16"		0101000020E61000006A4E5E6402745840D237691A14FB4B40
36374	5	50	139	52216	67967	\N	55.961551	"Иркутская область, муниципальное образование ""Тайшетский район"", Бирюсинское муниципальное образование, г. Бирюсинск, улица Дружбы, дом 49, помещение школы"		0101000020E61000006A4E5E6402745840D237691A14FB4B40
36368	5	50	139	52155	68966	\N	55.991304	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Бирюсинское муниципальное образование, село Бирюса, пер.Школьный,14"		0101000020E61000007AFCDEA63F7958406E32AA0CE3FE4B40
36346	5	50	139	52174	68750	\N	55.868808999999999	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Березовское муниципальное образование, село Березовка, улица Школьная,20"		0101000020E6100000425E0F26C581584038BC202235EF4B40
36372	5	50	139	59216	69153	\N	55.956412389497501	"""Иркутская область, муниципальное образование """"Тайшетский район"""", Старо-Акульшетское муниципальное образование, поселок ж/д. станции Акульшет, улица Юбилейная, 1"	Россия, Иркутская область, Тайшетский район, поселок Акульшет	0101000020E6100000865451BCCA86584040C05AB56BFA4B40
36309	5	50	235	3797	\N	\N	51.542065999999998	Иркутская область, Слюдянский район, с. Утулик, здание сельского дома культуры	Россия, Иркутская область, Слюдянский район, поселок Утулик	0101000020E6100000CC7EDDE9CE035A4003232F6B62C54940
36314	5	50	235	4079	69086	\N	51.769085269758399	Иркутская область, Слюдянский район, с. Тибельти, Набережная, 5	Россия, Иркутская область, Слюдянский район, поселок Тибельти	0101000020E6100000A8ACA6EB89CF59400D6C956071E24940
36304	5	50	235	3565	69091	\N	51.497949641320098	Иркутская область, Слюдянский район, п. Солзан, Терешковой, 13 А	Россия, Иркутская область, Слюдянский район, поселок Солзан	0101000020E61000008978EBFCDB0E5A4088855AD3BCBF4940
36290	5	50	235	919	68254	\N	51.661658000000003	Иркутская область, Слюдянский район, г. Слюдянка, Ржанова, 2		0101000020E61000009A5FCD0182EC594082919735B1D44940
36292	5	50	235	919	67958	\N	51.660730128412098	Иркутская область, Слюдянский район, г. Слюдянка, Ленина, 83,б.	Россия, Иркутская область, Слюдянский район, Слюдянка	0101000020E610000046425BCEA5ED594038BEF6CC92D44940
36291	5	50	235	919	67958	\N	51.657920903208201	Иркутская область, Слюдянский район, г. Слюдянка, Ленина, 90	Россия, Иркутская область, Слюдянский район, Слюдянка	0101000020E61000005D177E703EED5940022D5DC136D44940
36295	5	50	235	919	67959	\N	51.657920903208201	Иркутская область, Слюдянский район, г. Слюдянка, Куприна, 2	Россия, Иркутская область, Слюдянский район, Слюдянка	0101000020E6100000473D44A33BED5940022D5DC136D44940
36293	5	50	235	919	67978	\N	51.661658000000003	Иркутская область, Слюдянский район, г. Слюдянка, Гранитная, 1		0101000020E61000009A5FCD0182EC594082919735B1D44940
36288	5	50	235	919	67981	\N	51.661658000000003	Иркутская область, Слюдянский район, г. Слюдянка, Героя Ивана Тонконог, 2		0101000020E61000009A5FCD0182EC594082919735B1D44940
36312	5	50	235	59263	\N	\N	51.465919047793001	Иркутская область, Слюдянский район, п. Новоснежный, здание сельского дома культуры	Россия, Иркутская область, Слюдянский район, поселок Новоснежная	0101000020E6100000AA9A20EA3E285A40E2CAD93BA3BB4940
36310	5	50	235	3857	\N	\N	51.477910999999999	Иркутская область, Слюдянский район, п. Мурино, здание сельского дома культуры	Россия, Иркутская область, Слюдянский район, поселок Мурино	0101000020E61000002575029A081A5A4007B309302CBD4940
36316	5	50	235	4186	\N	\N	51.786109000000003	Иркутская область, Слюдянский район, ст. Маритуй, здание администрации Маритуйского сельского поселения	Россия, Иркутская область, Слюдянский район, поселок Маритуй, станция Маритуй	0101000020E6100000DC9C4A06800E5A40AF0B3F389FE44940
36514	5	50	235	3599	68935	\N	51.723030999999999	Иркутская область, Усольское районное муниципальное образование, Новожилкинское муниципальное образование, д.Култук, Трактовая, 8		0101000020E6100000508A56EE05EC5940417FA1478CDC4940
36305	5	50	235	3599	67964	\N	51.723030999999999	Иркутская область, Слюдянский район, р.п. Култук, Кооперативный переулок, 6 Б		0101000020E6100000508A56EE05EC5940417FA1478CDC4940
36306	5	50	235	3599	67892	\N	51.723030999999999	Иркутская область, Слюдянский район, р.п. Култук, Кирова, 165		0101000020E6100000508A56EE05EC5940417FA1478CDC4940
36841	5	50	235	3971	69003	\N	51.742944000000001	Иркутская область, Слюдянский район,  д. Быстрая,  ул. Советская, д.36, здание администрации Быстринского сельского поселения,		0101000020E6100000382C0DFCA8DC59403561FBC918DF4940
36298	5	50	235	3244	67015	\N	51.5218165395938	Иркутская область, Слюдянский район, г. Байкальск, Школьный переулок, 1	Россия, Иркутская область, Слюдянский район, Байкальск	0101000020E6100000A3923A014D085A4098BF42E6CAC24940
36301	5	50	235	3244	67890	\N	51.513848000000003	Иркутская область, Слюдянский район, г. Байкальск, Гагарина, 146 Б		0101000020E61000008D9944BDE0085A40B98E71C5C5C14940
36300	5	50	235	3244	67890	\N	51.513848000000003	Иркутская область, Слюдянский район, г. Байкальск, Гагарина, 208		0101000020E61000008D9944BDE0085A40B98E71C5C5C14940
36299	5	50	235	3244	67890	\N	51.513848000000003	Иркутская область, Слюдянский район, г. Байкальск, Гагарина, 211		0101000020E61000008D9944BDE0085A40B98E71C5C5C14940
36303	5	50	235	3244	67814	\N	51.513848000000003	Иркутская область, Слюдянский район, г. Байкальск, микрорайон Южный, 3 квартал, Здание школы № 11		0101000020E61000008D9944BDE0085A40B98E71C5C5C14940
36315	5	50	235	59312	69574	\N	51.566493000000001	Иркутская область, Слюдянский район, р.п. Байкал, Набережная, 10	Россия, Иркутская область, Слюдянский район	0101000020E6100000E3FA777DE6F55940DB34B6D782C84940
36308	5	50	235	59255	\N	\N	51.805289750335596	Иркутская область, Слюдянский район, п.ж.д.ст.Андриановская, здание электроподстанции	Россия, Иркутская область, Слюдянский район, поселок Андрияновская	0101000020E6100000020EA14ACDF35940DEE522BE13E74940
36307	5	50	235	59259	\N	\N	51.7472039192591	Иркутская область, Слюдянский район, п.ж.д.ст.Ангасолка, здание сельского дома культуры	Россия, Иркутская область, Слюдянский район, поселок Ангасолка	0101000020E6100000ECC039234AF059405FB87361A4DF4940
36226	5	50	7	31692	69220	\N	53.426279000000001	Иркутская область, Осинский район, д.Шотой, Шотойская, 11		0101000020E61000004B5CC7B8E20F5A405DFC6D4F90B64A40
36233	5	50	7	31997	69219	\N	53.465573999999997	Иркутская область, Осинский район, с.Хокта, Центральная, 8		0101000020E6100000C39B35785FFE594017EFC7ED97BB4A40
36239	5	50	7	32264	69082	\N	53.403345999999999	Иркутская область, Осинский район, д.Харай, Озерная, 5		0101000020E6100000BF4692205CF85940787C7BD7A0B34A40
36251	5	50	7	464	69107	\N	53.700446999999997	Иркутская область, Осинский район, д.Хайга, Правая Хайга, 2		0101000020E6100000484E266E15EE594068CA4E3FA8D94A40
36242	5	50	7	32375	68589	\N	53.524422999999999	Иркутская область, Осинский район, с.Усть-Алтан, Ленина, 22		0101000020E6100000CA8B4CC0AFE759409622F94A20C34A40
36255	5	50	7	709	68588	\N	53.698751999999999	Иркутская область, Осинский район, с.Унгин, Школьная, 8		0101000020E61000008735954561E55940DE019EB470D94A40
36231	5	50	7	31907	68843	\N	53.348381000000003	Иркутская область, Осинский район, с.Русские Янгуты, Школьная, 1		0101000020E61000000A85083884FF59401EC6A4BF97AC4A40
36243	5	50	7	32431	69085	\N	53.560721999999998	Иркутская область, Осинский район, с.Рассвет, Ленина, 2а		0101000020E61000001310937021DC5940E8120EBDC5C74A40
36229	5	50	7	31809	69409	\N	53.351073999999997	Иркутская область, Осинский район, д.Прохоровка, Ворошилова, 6		0101000020E61000000FD1E80E62025A40EA3C2AFEEFAC4A40
36249	5	50	7	335	67872	\N	53.583494999999999	Иркутская область, Осинский район, п.Приморский, Октябрьская, 16		0101000020E6100000F59ECA694FEE59409430D3F6AFCA4A40
36238	5	50	7	1070	67771	\N	53.388854000000002	Иркутская область, Осинский район, с.Оса, Свердлова,83		0101000020E6100000D5B0DF13EBF759409B75C6F7C5B14A40
36237	5	50	7	1070	67771	\N	53.388854000000002	Иркутская область, Осинский район, с.Оса, Свердлова,55		0101000020E6100000D5B0DF13EBF759409B75C6F7C5B14A40
36236	5	50	7	1070	67771	\N	53.388854000000002	Иркутская область, Осинский район, с.Оса, Свердлова, 3		0101000020E6100000D5B0DF13EBF759409B75C6F7C5B14A40
36227	5	50	7	31729	69083	\N	53.390180999999998	Иркутская область, Осинский район,  д.Онгосор, Онгосорская, 37		0101000020E61000008DF0F62004105A40A2427573F1B14A40
36232	5	50	7	31942	69414	\N	53.508237999999999	Иркутская область, Осинский район, д.Онгой, Нагорная, 22		0101000020E6100000CB0F5CE509025A40CF4A5AF10DC14A40
36252	5	50	7	547	68755	\N	53.721103999999997	Иркутская область, Осинский район, с.Обуса, 11 Комсомольцев, 21		0101000020E6100000D97A8670CCF55940E481C8224DDC4A40
36234	5	50	7	32029	69210	\N	53.435254999999998	Иркутская область, Осинский район, д.Мольта, Молодежная, 2		0101000020E6100000365CE49EAEFC5940D235936FB6B74A40
36240	5	50	7	59217	69158	\N	53.4140272340547	Иркутская область, Осинский район, с.Майск, Трактовая, 9	Россия, Иркутская область, Осинский район, поселок Майская	0101000020E6100000800C1D3BA8F359409B5434D6FEB44A40
36235	5	50	7	32086	68878	\N	53.368980000000001	Иркутская область, Осинский район, д.Лузгино, Жданова, 35		0101000020E6100000EDF483BA48FA5940657094BC3AAF4A40
36248	5	50	7	300	69209	\N	53.633338999999999	Иркутская область, Осинский район, с.Кутанка, Ленина, 1		0101000020E61000006364C91CCBF5594003249A4011D14A40
36244	5	50	7	32480	68887	\N	53.435228000000002	Иркутская область, Осинский район, с.Ирхидей, Ленина, 5		0101000020E61000005169C4CC3EF35940D926158DB5B74A40
36245	5	50	7	10	69084	\N	53.544198000000002	Иркутская область, Осинский район, с.Жданово, Хлебоприемная		0101000020E61000001E335019FFEC59403946B247A8C54A40
36228	5	50	7	59184	68898	\N	53.360419999999998	Иркутская область, Осинский район,  с.Енисей, Павлова, 40	Россия, Иркутская область, Осинский район, поселок Енисей (Бурятский Янгут)	0101000020E6100000C9AF1F6283095A408369183E22AE4A40
36230	5	50	7	31858	69410	\N	53.321899000000002	Иркутская область, Осинский район, д.Грязнушка, Гагарина, 60		0101000020E6100000C1A90F24EF035A40BCCE86FC33A94A40
36253	5	50	7	592	68934	\N	53.723474997792103	Иркутская область, Осинский район, д.Горхон, Горхонская, 34	Россия, Иркутская область, Осинский район, поселок Горхон	0101000020E6100000F73E558506FC59409F3C2CD49ADC4A40
36254	5	50	7	673	69211	\N	53.720692999999997	Иркутская область, Осинский район, д.Борохал, Борохальская, 5		0101000020E61000003BFBCA83F4FF594062BA10AB3FDC4A40
36246	5	50	7	157	68710	\N	53.564953000000003	Иркутская область, Осинский район, с.Бильчир, Ленина, 24		0101000020E61000006B65C22FF5ED59407863416150C84A40
39322	3	24	1619	49502	59422	\N	66.297196	п.Чкаловский, ул.Набережная, д.14		0101000020E610000098874CF910B2404021205F4205935040
36241	5	50	7	32342	69413	\N	53.391024000000002	Иркутская область, Осинский район, д.Абрамовка, Центральная, 49		0101000020E61000001478279F1EF25940BEF90D130DB24A40
36225	5	50	516	31646	69102	\N	53.138176000000001	Иркутская область, Ольхонский район, д. Ялга, Восточная, 5		0101000020E610000053AF5B04C6CB5A40CA8B4CC0AF914A40
36220	5	50	516	31389	69206	\N	53.002566999999999	Иркутская область, Ольхонский район, с. Шара Тогот, 50 лет Победы, 7		0101000020E6100000F168E388B5AD5A4040868E1D54804A40
36218	5	50	516	31295	69080	\N	52.808545000000002	Иркутская область, Ольхонский район, д. Хурай Нур, Молодежная, 11		0101000020E610000030A182C30B9E5A40132C0E677E674A40
36224	5	50	516	31585	68553	\N	53.193573999999998	Иркутская область, Ольхонский район, п. Хужир, Советская, 2		0101000020E6100000ECDB4944F8D55A408EAD6708C7984A40
36223	5	50	516	31537	69208	\N	53.221063999999998	Иркутская область, Ольхонский район, д. Харанцы, Байкальская, 4		0101000020E6100000C328081EDFDA5A4056293DD34B9C4A40
36219	5	50	516	30426	69279	\N	52.879224999999998	Иркутская область, Ольхонский район, д. Тонта, Лесная, школа		0101000020E61000006F62484E26A05A40AD69DE718A704A40
36215	5	50	516	31134	69418	\N	52.675955999999999	Иркутская область, Ольхонский район, д. Таловка, Молодежная, 1		0101000020E6100000DAE731CA338E5A407AC4E8B985564A40
36221	5	50	516	31439	69207	\N	53.016447999999997	Иркутская область, Ольхонский район, с. Сахюрта, Центральная, 13		0101000020E6100000D829560DC2B85A40D40AD3F71A824A40
36216	5	50	516	31181	69361	\N	52.758392000000001	Иркутская область, Ольхонский район, д. Нарин Кунта, Солнечная, 27		0101000020E6100000357C0BEBC6975A4026C632FD12614A40
36210	5	50	516	30908	69407	\N	52.617508999999998	Иркутская область, Ольхонской район, д. Куртун, Центральная, 28		0101000020E6100000FE7C5BB054745A402AFEEF880A4F4A40
36214	5	50	516	31106	69359	\N	52.817112000000002	"Иркутская область, Ольхонский район, д. Куреть, М. Копыловой, 15 ""б"""		0101000020E6100000E4A1EF6E658D5A40A795422097684A40
36213	5	50	516	31049	69358	\N	52.844495000000002	Иркутская область, Ольхонский район, с. Косая Степь, Верховая, 7		0101000020E6100000AA6395D233855A4059518369186C4A40
36217	5	50	516	31228	67870	\N	52.800046999999999	Иркутская область, Ольхонский район, с. Еланцы, Советская, 7		0101000020E6100000008C67D0D0995A40A721AAF067664A40
36211	5	50	516	30940	68883	\N	52.544790999999996	Иркутская область, Ольхонский район, п. Бугульдейка, Ленина, 13		0101000020E61000009B560A815C845A40DB1324B6BB454A40
36212	5	50	516	30999	69079	\N	52.776339999999998	Иркутская область, Ольхонский район, д. Алагуй, Центральная, 2		0101000020E6100000FFAF3A72A47F5A40CF49EF1B5F634A40
36183	5	50	155	29574	69353	\N	53.825318000000003	Иркутская область, Нукутская область, д. Шараты, ул. Юбилейная, д. 7		0101000020E610000005A568E55EA459406B662D05A4E94A40
36203	5	50	155	30541	69356	\N	53.585067000000002	Иркутская область, Нукутский район, д. Шалоты, ул. Коммунаров, д. 21		0101000020E6100000DD79E2395BBF5940037CB779E3CA4A40
36179	5	50	155	29382	69406	\N	53.641235000000002	Иркутская область, Нукутский район, п. Целинный, ул. Советская, д. 17		0101000020E6100000AB75E272BCA5594079060DFD13D24A40
36187	5	50	155	29780	68831	\N	53.816158999999999	Иркутская область, Нукутский район, с. Хареты, ул. Центральная, д. 32		0101000020E6100000EA95B20C71AE594004ABEAE577E84A40
36199	5	50	155	30337	69078	\N	53.732376000000002	Иркутская область, Нукутский район, д. Хамхар, ул. Школьная, д. 2		0101000020E6100000FD2D01F8A7BB59400A302C7FBEDD4A40
36194	5	50	155	30078	68776	\N	53.553662000000003	Иркутская область, Нукутский район, с. Хадахан, ул. Административная, д. 2		0101000020E6100000DFF94509FAD25940DC847B65DEC64A40
36180	5	50	155	29441	69404	\N	53.6491670911306	Иркутская область, Нукутский район, д. Ункурлик, ул. Школьная, д. 1	Россия, Иркутская область, Нукутский район, поселок Ункурлик	0101000020E6100000331AF9BCE2A559403B527DE717D34A40
36185	5	50	155	29658	69069	\N	53.770870000000002	Иркутская область, Нукутский район, с. Тангуты, ул. Нагорная, д. 7		0101000020E61000007AFD497CEEA55940D8BB3FDEABE24A40
36121	5	50	155	26776	69393	\N	53.786481000000002	Иркутская область, Нукутский район, д. Степное, пер. Школьный, д. 5		0101000020E6100000F5BD86E0B8C1594073F6CE68ABE44A40
36037	5	50	155	22824	68581	\N	53.760092	Иркутская область, Нукутский район, с. Первомайское, ул. Ленина, д. 58		0101000020E61000003EB0E3BF40CF5940C2F9D4B14AE14A40
36198	5	50	155	30283	69163	\N	53.720539000000002	Иркутская область, Нукутский район, с. Нукуты, ул. Октябрьская, д. 3		0101000020E6100000C571E0D572B359400C3F389F3ADC4A40
36208	5	50	155	30634	68773	\N	53.699525000000001	Иркутская область, Нукутский район, п. Новонукутский, ул. Шолохова, д. 1		0101000020E6100000FDA4DAA7E3AC594001DE02098AD94A40
36207	5	50	155	30634	68584	\N	53.699525000000001	Иркутская область, Нукутский район, п. Новонукутский, ул. Чехова, д. 26		0101000020E6100000FDA4DAA7E3AC594001DE02098AD94A40
36205	5	50	155	30634	68541	\N	53.699525000000001	Иркутская область, Нукутский район, п. Новонукутский, ул. Ленина, д. 27		0101000020E6100000FDA4DAA7E3AC594001DE02098AD94A40
36206	5	50	155	30634	68881	\N	53.699525000000001	Иркутская область, Нукутский район, п. Новонукутский, ул. Ербанова, д. 2		0101000020E6100000FDA4DAA7E3AC594001DE02098AD94A40
36190	5	50	155	424	68728	\N	53.809534999999997	Иркутская область, Нукутский район, с. Новоленино, ул. школьная, д. 6		0101000020E610000039984D8061B55940D2FBC6D79EE74A40
36250	5	50	155	424	68774	\N	53.809534999999997	Иркутская область, Осинский район, с.Новоленино, Мира, 6		0101000020E610000039984D8061B55940D2FBC6D79EE74A40
36182	5	50	155	29531	69199	\N	53.660966000000002	Иркутская область, Нукутский район, д. Наймодай, ул.Школьная, д. 3		0101000020E6100000F7915B936EA859404CE2AC889AD44A40
36195	5	50	155	30136	69076	\N	53.658917000000002	Иркутская область, Нукутский район, д. Мельхитуй, пер. Школьный, д. 2		0101000020E61000007D24253D0CD15940A4E36A6457D44A40
36197	5	50	155	30136	69203	\N	53.658917000000002	Иркутская область, Нукутский район, д. Мельхитуй, ул. Центральная, д. 4		0101000020E61000007D24253D0CD15940A4E36A6457D44A40
36201	5	50	155	59275	69521	\N	53.567207021526102	Иркутская область, Нукутский район, д. Макарьевск, ул. Лесная, д. 22	Россия, Иркутская область, Нукутский район, поселок Макарьевская	0101000020E61000007C992842EAB45940F9872D3D9AC84A40
36184	5	50	155	29624	69403	\N	53.814107	Иркутская область, Нукутский район, д. Куйта, пер. Школьный, д. 2		0101000020E6100000C58CF0F6209E5940EB387EA834E84A40
36204	5	50	155	30590	69097	\N	53.507964999999999	Иркутская область, Нукутский район, д. Кирилловская, ул. Школьная, д. 1		0101000020E6100000FAB48AFED0B959409E4143FF04C14A40
36191	5	50	155	29927	69408	\N	54.028609000000003	Иркутская область, Нукутский район, д. Зунгар, ул. Центральная, д. 5		0101000020E610000098A7734529B8594086AFAF75A9034B40
36192	5	50	155	30007	69355	\N	53.840286999999996	Иркутская область, Нукутский район, д. Заходы, ул. Школьная, д. 1		0101000020E61000005F44DB3175BB5940812040868EEB4A40
36209	5	50	155	30849	69362	\N	53.682729999999999	Иркутская область, Нукутский район, с. Заречный, ул. Советская, д. 20		0101000020E61000001A868F8829AB5940C1FF56B263D74A40
36196	5	50	155	30190	68715	\N	53.690376000000001	Иркутская область, Нукутский район, с. Закулей, ул. Имегенова, д. 1		0101000020E61000003C139A2496C15940BEF8A23D5ED84A40
36186	5	50	155	59194	68931	\N	53.759127999999997	Иркутская область, Нукутский район, д. Ей, ул. Школьная, д. 4		0101000020E6100000E5D18DB0A8B659402BBD361B2BE14A40
36193	5	50	155	30058	69072	\N	53.873260999999999	Иркутская область, Нукутский район, д. Дружный, ул. Школьная, д. 11		0101000020E61000004016A243E0C25940A6EF3504C7EF4A40
36200	5	50	155	30382	69077	\N	53.661270000000002	Иркутская область, Нукутский район, д. Ворот-Онгой, ул. Школьная, д. 6		0101000020E61000005CCCCF0D4DB55940B8E9CF7EA4D44A40
36189	5	50	155	29849	69201	\N	53.898029000000001	Иркутская область, Нукутский район, д. Васильевское, ул. Центральная, д. 14		0101000020E6100000AD307DAF21A9594007EE409DF2F24A40
36188	5	50	155	29794	69081	\N	53.901493000000002	Иркутская область, Нукутский район, д. Большебаяновская, ул. Лесная, д. 20		0101000020E610000053944BE317A559405649641F64F34A40
36202	5	50	155	30496	69245	\N	53.480424999999997	Иркутская область, Нукутский район, с. Алтарик, ул. Комсомольская, д. 1		0101000020E61000001A88653387BA59402497FF907EBD4A40
36152	5	50	282	59214	69138	\N	54.625698	Иркутская область, Нижнеудинский район, станция Шеберта, улица Привокзальная, дом 2-б		0101000020E6100000F855B950F9F5584018963FDF16504B40
36126	5	50	282	26992	68242	\N	54.831882999999998	Иркутская область, Нижнеудинский район, поселок Шумский, улица Советская, дом 38		0101000020E6100000C992399677C85840978C63247B6A4B40
36132	5	50	282	27262	69287	\N	54.808450578710897	Иркутская область, Нижнеудинский район, деревня Шум, улица Нагорная, дом 2-а	Россия, Иркутская область, Нижнеудинский район, поселок Шум	0101000020E61000009D4CDC2A88C8584091B586527B674B40
36149	5	50	282	28023	68592	\N	54.639601999999996	Иркутская область, Нижнеудинский район, село Шеберта, улица Трактовая, дом 4		0101000020E610000063F20698F9F85840643A747ADE514B40
36134	5	50	282	27359	69048	\N	54.814979000000001	Иркутская область, Нижнеудинский район, деревня Швайкина, улица Школьная, дом 8		0101000020E61000004F3C670B08C25840A1F65B3B51684B40
36142	5	50	282	27726	\N	\N	54.472591999999999	Иркутская область, Нижнеудинский район, село Чехово, помещение Дома культуры, б/н	Россия, Иркутская область, Нижнеудинский район, поселок Чехово	0101000020E6100000E7E26F7B82D85840F52C08E57D3C4B40
36138	5	50	282	27570	69065	\N	54.651605000000004	Иркутская область, Нижнеудинский район, деревня Чалоты, улица Центральная, дом 14		0101000020E6100000223317B83CC558407E74EACA67534B40
36155	5	50	282	28264	68698	\N	54.707109000000003	Иркутская область, Нижнеудинский район, село Худоеланское, улица Школьная, дом 1-а		0101000020E61000007F4DD6A887E8584088DA368C825A4B40
36154	5	50	282	28264	68822	\N	54.707109000000003	Иркутская область, Нижнеудинский район, село Худоеланское, улица Московская, дом 45-а		0101000020E61000007F4DD6A887E8584088DA368C825A4B40
36158	5	50	282	28450	\N	\N	54.7913	Иркутская область, Нижнеудинский район, станция Хингуй, помещение СДК, б/н		0101000020E610000015E46723D7D5584093A9825149654B40
36115	5	50	282	26484	69036	\N	55.148575000000001	Иркутская область, Нижнеудинский район, поселок Усть-Кадуй, переулок Школьный, дом 1		0101000020E6100000AC72A1F2AFDB584069006F8104934B40
36146	5	50	282	27924	69290	\N	54.302368432842897	Иркутская область, Нижнеудинский район, деревня Унгудул, улица Первомайская, дом 17	Россия, Иркутская область, Нижнеудинский район, поселок Унгудул	0101000020E6100000EACDA8F92AEC5840B0AD9FFEB3264B40
36119	5	50	282	26708	69400	\N	55.061663000000003	Иркутская область, Нижнеудинский район, деревня Укар, улица Центральная, помещение школы, б/н		0101000020E6100000D200DE0209D15840C72FBC92E4874B40
36122	5	50	282	59146	68451	\N	55.0779580805875	Иркутская область, Нижнеудинский район, поселок Ук, улица 40 лет Победы, дом 9-а	Россия, Иркутская область, Нижнеудинский район, поселок Ук	0101000020E6100000E9818FC18AB65840153B1A87FA894B40
36135	5	50	282	27412	69291	\N	54.867207000000001	Иркутская область, Нижнеудинский район, деревня Уват, улица Мира, дом 5		0101000020E61000008FA9BBB20BBD58405FEE93A3006F4B40
36156	5	50	282	28357	69399	\N	54.628709999999998	Иркутская область, Нижнеудинский район, деревня Талый Ключ, улица Центральная, дом 26		0101000020E61000000BD462F030EE58408655BC9179504B40
36170	5	50	282	59210	69075	\N	54.489038000000001	Иркутская область, Нижнеудинский район, участок Таежный, улица Почтовая, дом 7		0101000020E6100000E2900DA48B7B5840294014CC983E4B40
36167	5	50	282	28849	69198	\N	55.596895000000004	Иркутская область, Нижнеудинский район, село Старый Алзамай, улица Кирова, дом 20		0101000020E6100000CF328B506CA65840AE122C0E67CC4B40
36136	5	50	282	27447	69063	\N	54.669004000000001	Иркутская область, Нижнеудинский район, село Солонцы, улица Школьная, дом 1		0101000020E610000032CB9E0436CC584054724EECA1554B40
36129	5	50	282	27124	69394	\N	54.866984000000002	Иркутская область, Нижнеудинский район, деревня Рубахина, улица Береговая, дом 33		0101000020E6100000B2834A5CC7C55840E013EB54F96E4B40
36028	5	50	113	22443	68864	\N	54.341425999999998	Иркутская область, Куйтунский район, Уян, 1-я Советская, 6		0101000020E610000055BFD2F9F07F59408600E0D8B32B4B40
36141	5	50	282	27665	69315	\N	54.560947047378697	Иркутская область, Нижнеудинский район, деревня Привольное, улица Центральная, дом 10-а	Россия, Иркутская область, Нижнеудинский район, поселок Привольное	0101000020E6100000CEFDD5E3BED0584008E57D1CCD474B40
36140	5	50	282	27645	69067	\N	54.552827999999998	Иркутская область, Нижнеудинский район, село Порог, улица Новая, дом 31-в		0101000020E6100000378B170B43D0584013286211C3464B40
36128	5	50	282	27079	69283	\N	54.856822999999999	Иркутская область, Нижнеудинский район, поселок Подгорный, улица Просвещения, дом 10		0101000020E6100000C156091687BF5840F5BA4560AC6D4B40
36165	5	50	282	28753	69354	\N	55.447074999999998	Иркутская область, Нижнеудинский район, поселок Первомайский, улица Центральная, дом 19		0101000020E6100000BFEE74E789A65840FAEDEBC039B94B40
36145	5	50	282	1192	69452	\N	54.313493000000001	Иркутская область, Нижнеудинский район, деревня Орик, улица Центральная, дом 1		0101000020E61000000A100533A6E458403143E38920284B40
36168	5	50	282	28914	69402	\N	55.667197999999999	Иркутская область, Нижнеудинский район, поселок Новокиевск, улица Школьная, дом 14		0101000020E610000015527E52EDAA584072FA7ABE66D54B40
36114	5	50	282	28645	\N	\N	54.900973999999998	Иркутская область, Нижнеудинский район, поселок Балакшин Бор, помещение школы, б/н		0101000020E61000007711A62897B65840ED45B41D53734B40
36162	5	50	282	28645	69351	\N	54.902340000000002	Иркутская область, Нижнеудинский район, деревня Новое Село, улица Шевченко, дом 15-а	Россия, Иркутская область, Нижнеудинский район, поселок Новое Село (Большой Курят)	0101000020E6100000B2632310AFB65840B3EF8AE07F734B40
36120	5	50	282	59125	69269	\N	54.907073034117602	деревня Каксат, Иркутская область, Нижнеудинский район, улица Центральная, дом 42	Россия, Иркутская область, городской округ Нижнеудинск	0101000020E61000007AC2120F28C25840D40AD3F71A744B40
36127	5	50	282	27052	67952	\N	54.851815999999999	Иркутская область, Нижнеудинский район, село Мельница, улица Ленина, дом 42		0101000020E6100000D311C0CDE2C45840D21A834E086D4B40
36148	5	50	282	28016	69187	\N	54.59919	Иркутская область, Нижнеудинский район, деревня Марга, улица Клубная, дом 16		0101000020E61000003CA1D79FC4F558408D0B0742B24C4B40
36163	5	50	282	28660	69352	\N	55.000656999999997	Иркутская область, Нижнеудинский район, деревня Мара, улица Московская, дом 1-б		0101000020E610000036AFEAAC16B65840B9C1508715804B40
36133	5	50	282	27290	69128	\N	54.827801000000001	Иркутская область, Нижнеудинский район, поселок Майский, улица Школьная, дом 9		0101000020E6100000F37519FED3C058404D4C1762F5694B40
36117	5	50	282	26569	69325	\N	55.045062000000001	Иркутская область, Нижнеудинский район, поселок Лесной, улица Просвещения, дом 15		0101000020E6100000D0B9DBF5D2DE58406C257497C4854B40
36137	5	50	282	27501	69396	\N	54.638226000000003	Иркутская область, Нижнеудинский район, деревня Кушун, улица Центральная, дом 24		0101000020E610000073D712F241CC58407CBABA63B1514B40
36160	5	50	282	59317	69579	\N	54.939018617836702	Иркутская область, Нижнеудинский район, участок Куряты, улица Мира, дом 25-б	Россия, Иркутская область, Нижнеудинский район, поселок Куряты	0101000020E6100000680932022ABC58404CA94BC631784B40
36143	5	50	282	27784	\N	\N	54.377472162190699	Иркутская область, Нижнеудинский район, деревня Кургатей, помещение Дома культуры, б/н	Россия, Иркутская область, Нижнеудинский район, поселок Кургатей	0101000020E61000008AAC3594DADB5840EE93A30051304B40
36139	5	50	282	27593	69066	\N	54.629460999999999	Иркутская область, Нижнеудинский район, поселок Кирей-Муксут, улица Школьная, дом 7		0101000020E61000003CA583F57FD35840C18D942D92504B40
36169	5	50	282	28974	69323	\N	55.666564000000001	Иркутская область, Нижнеудинский район, село Катарма, улица Катарминская, ул.Катарминская,21		0101000020E6100000F3583332C8C6584071581AF851D54B40
36144	5	50	282	27810	68963	\N	54.364939	Иркутская область, Нижнеудинский район, село Катарбей, улица Советская, дом 78		0101000020E6100000D594641D8EEB584079043752B62E4B40
36125	5	50	282	26940	68692	\N	55.203986	Иркутская область, Нижнеудинский район, поселок Камышет, улица Мира, дом 1		0101000020E6100000799274CDE4B25840C26B97361C9A4B40
36161	5	50	282	28575	69071	\N	54.932938	Иркутская область, Нижнеудинский район, село Каменка, улица Садовая, дом 51-в		0101000020E6100000A35698BED7B458400B992B836A774B40
36157	5	50	282	28381	69411	\N	54.741129999999998	Иркутская область, Нижнеудинский район, деревня Кадуй, улица Дорожная, дом 2		0101000020E6100000B5DC990986E05840D00A0C59DD5E4B40
36147	5	50	282	27953	69293	\N	54.558830673674997	Иркутская область, Нижнеудинский район, село Иргей, улица Клубная, дом 6	Россия, Иркутская область, Нижнеудинский район, поселок Иргей	0101000020E6100000BDAC8905BEFF5840D87E32C687474B40
36164	5	50	282	28717	68884	\N	55.369137000000002	Иркутская область, Нижнеудинский район, поселок Замзор, улица Школьная, дом 6		0101000020E61000007F17B6662BA958402D5F97E13FAF4B40
36166	5	50	282	59225	69217	\N	55.298741063548498	Иркутская область, Нижнеудинский район, участок Загорье, улица Школьная, дом 5	Россия, Иркутская область, Нижнеудинский район, поселок Загорье	0101000020E6100000747E8AE3C0AB5840B77C24253DA64B40
36151	5	50	282	28137	69453	\N	54.751548999999997	Иркутская область, Нижнеудинский район, село Даур, улица Советская, дом 63		0101000020E6100000454772F90FF95840B62BF4C132604B40
36130	5	50	282	27189	68704	\N	54.893560000000001	Иркутская область, Нижнеудинский район, поселок Вознесенский, улица Транспортная, дом 7		0101000020E6100000A8514832ABC65840C381902C60724B40
36124	5	50	282	26920	69039	\N	55.047384000000001	Иркутская область, Нижнеудинский район, поселок Водопадный, улица Молодежная, дом 1		0101000020E6100000A4C343183FC25840452DCDAD10864B40
36153	5	50	282	28217	69204	\N	54.628408	Иркутская область, Нижнеудинский район, поселок Вершина, улица Школьная, дом 12		0101000020E6100000C05AB56B42F45840BB4560AC6F504B40
36159	5	50	282	28493	\N	\N	54.796666999999999	Иркутская область, Нижнеудинский район, деревня Верхний Хингуй, помещение школы, б/н	Россия, Иркутская область, Нижнеудинский район, поселок Верхний Хингуй	0101000020E610000037FC6EBA65DC5840B6662B2FF9654B40
36150	5	50	282	28090	69118	\N	54.693097999999999	Иркутская область, Нижнеудинский район, деревня Большеверстовск, улица Советская, дом 35		0101000020E610000096ED43DE72F9584025766D6FB7584B40
36113	5	50	282	26414	68241	\N	55.104328254484997	Иркутская область, Нижнеудинский район, поселок Атагай, переулок Клубный, дом 1-а	Россия, Иркутская область, Нижнеудинский район, поселок Атагай	0101000020E6100000D576137CD3D858404F07B29E5A8D4B40
36112	5	50	282	26096	68609	\N	55.555698	Иркутская область, Нижнеудинский район, город Алзамай, улица Рабочая, дом 20		0101000020E610000019E3C3EC65AA5840EF39B01C21C74B40
36108	5	50	282	26096	68844	\N	55.555698	Иркутская область, Нижнеудинский район, город Алзамай, улица Первомайская,61		0101000020E610000019E3C3EC65AA5840EF39B01C21C74B40
36106	5	50	282	26096	68844	\N	55.555698	Иркутская область, Нижнеудинский район, город Алзамай, улица Первомайская, дом 84		0101000020E610000019E3C3EC65AA5840EF39B01C21C74B40
36111	5	50	282	26096	68880	\N	55.555698	Иркутская область, Нижнеудинский район, город Алзамай, улица Некрасова, дом 10		0101000020E610000019E3C3EC65AA5840EF39B01C21C74B40
36109	5	50	282	26096	68696	\N	55.555698	Иркутская область, Нижнеудинский район, город Алзамай, улица Линейная, дом 6		0101000020E610000019E3C3EC65AA5840EF39B01C21C74B40
36107	5	50	282	26096	68587	\N	55.555698	Иркутская область, Нижнеудинский район, город Алзамай, улица Комсомольская, дом 8		0101000020E610000019E3C3EC65AA5840EF39B01C21C74B40
36110	5	50	282	26096	68775	\N	55.555698	Иркутская область, Нижнеудинский район, город Алзамай, улица Вокзальная, дом 37		0101000020E610000019E3C3EC65AA5840EF39B01C21C74B40
36131	5	50	282	27203	69046	\N	54.744388000000001	Иркутская область, Нижнеудинский район, село Абалаково, улица Центральная, дом 21		0101000020E610000096D1C8E715C7584076C4211B485F4B40
36077	5	50	1713	24758	68873	\N	57.083573999999999	Иркутская область, Нижнеилимский район, пос. Янгель, мкр. Космонавтов, дом 9а		0101000020E6100000A6B915C26AE95940E065868DB28A4C40
36066	5	50	1713	24146	68742	\N	56.487189999999998	Иркутская область, Нижнеилимский район, пос. Шестаково, улица Ленина, 20А		0101000020E61000007098689082FD59401878EE3D5C3E4C40
36065	5	50	1713	24146	68742	\N	56.487189999999998	Иркутская область, Нижнеилимский район, пос. Шестаково, улица Ленина, 20б		0101000020E61000007098689082FD59401878EE3D5C3E4C40
36063	5	50	1713	59256	69401	\N	56.415626889132398	Иркутская область, Нижнеилимский район, ст. Черная, ул. Железнодорожная, дом 10	Россия, Иркутская область, Нижнеилимский район, поселок Чёрная	0101000020E6100000D2C6116BF1E85940D42AFA4333354C40
36073	5	50	1713	24544	69282	\N	56.381083798077199	Иркутская область, Нижнеилимский район, пос. Чистополянский, улица Ленина, дом 1	Россия, Иркутская область, Нижнеилимский район, поселок Чистополянский	0101000020E61000007B6AF5D555C75940B2834A5CC7304C40
36069	5	50	1713	24354	69117	\N	56.705697000000001	Иркутская область, Нижнеилимский район, пос. Хребтовая, улица Трактовая, дом 43		0101000020E6100000D20149D8B7105A4052F17F47545A4C40
36070	5	50	1713	24354	67800	\N	56.705697000000001	Иркутская область, Нижнеилимский район, пос. Хребтовая, улица Калинина, дом 1		0101000020E6100000D20149D8B7105A4052F17F47545A4C40
36067	5	50	1713	24236	68766	\N	56.499642999999999	Иркутская область, Нижнеилимский район, пос. Суворовский, улица Зеленая, 91	Россия, Иркутская область, Нижнеилимский район, поселок Суворовский	0101000020E61000004C6BD3D85EFC59407156444DF43F4C40
36062	5	50	1713	23980	68869	\N	56.463501000000001	Иркутская область, Нижнеилимский район, пос. Соцгородок, улица Школьная, дом 1		0101000020E6100000FD8348861CDD5940E7543200543B4C40
36064	5	50	1713	24091	68870	\N	56.680627000000001	Иркутская область, Нижнеилимский район, пос. Семигорск, улица Семигорская, дом 10		0101000020E610000063F19BC24A295A4026E318C91E574C40
36068	5	50	1713	24291	69278	\N	56.440864444009001	Иркутская область, Нижнеилимский район, пос. Селезневский, улица Нагорная, дом 2-1	Россия, Иркутская область, Нижнеилимский район, поселок Селезнёвский	0101000020E6100000287D21E4BCFC5940EBFD463B6E384C40
36076	5	50	1713	24633	68232	\N	57.267904999999999	Иркутская область, Нижнеилимский район, пос. Рудногорск, улица Школьная, дом 1		0101000020E610000084D6C39789F05940AAB706B64AA24C40
36075	5	50	1713	24633	67806	\N	57.267904999999999	Иркутская область, Нижнеилимский район, пос. Рудногорск, улица Вокзальная, дом 10		0101000020E610000084D6C39789F05940AAB706B64AA24C40
36060	5	50	1713	23881	67794	\N	56.532598	Иркутская область, Нижнеилимский район, пос. Речушка, улица Красноярская, дом 20		0101000020E610000078D4981073B759401FF5D72B2C444C40
36078	5	50	1713	24787	\N	\N	57.226022	Иркутская область, Нижнеилимский район, пос. Радищев, дом 5		0101000020E61000002E8CF4A276DF59409816F549EE9C4C40
36079	5	50	1713	24849	68549	\N	57.295777000000001	Иркутская область, Нижнеилимский район, пос. Новоилимск, улица Зверева,20		0101000020E6100000A12FBDFDB9EB59405AF44E05DCA54C40
36084	5	50	1713	24928	68259	\N	57.137891000000003	Иркутская область, Нижнеилимский район, пос. Новая Игирма, микрорайон Химки, дом 33		0101000020E6100000AF42CA4FAAFA5940D5B48B69A6914C40
36081	5	50	1713	24928	67682	\N	57.137891000000003	Иркутская область, Нижнеилимский район, пос. Новая Игирма, квартал 3, дом 32		0101000020E6100000AF42CA4FAAFA5940D5B48B69A6914C40
36083	5	50	1713	24928	68246	\N	57.137891000000003	Иркутская область, Нижнеилимский район, пос. Новая Игирма, улица Пионерская, дом 27		0101000020E6100000AF42CA4FAAFA5940D5B48B69A6914C40
36027	5	50	113	22383	68578	\N	54.404164000000002	Иркутская область, Куйтунский район, Уховский, Комсомольская, 6 А		0101000020E6100000A708707A174859403B1C5DA5BB334B40
36082	5	50	1713	24928	67944	\N	57.137891000000003	Иркутская область, Нижнеилимский район, пос. Новая Игирма, улица Бархатова, дом 11		0101000020E6100000AF42CA4FAAFA5940D5B48B69A6914C40
36080	5	50	1713	24882	68627	\N	56.491065999999996	Иркутская область, Нижнеилимский район, пос. Коршуновский, улица Ленина, дом 7А		0101000020E6100000F0DDE68D930C5A40B9162D40DB3E4C40
36074	5	50	1713	24628	69034	\N	56.379601000000001	Иркутская область, Нижнеилимский район, пос. Каймоновский, улица Лесная, дом 1а		0101000020E61000004660AC6F60C65940B343FCC396304C40
36059	5	50	1713	23855	\N	\N	56.981082000000001	"Иркутская область, Нижнеилимский район, пос. Игирма, МОУ ""Игирменская ООШ"""		0101000020E61000005F45460724E85940DE585018947D4C40
36061	5	50	1713	23939	69116	\N	56.192821000000002	Иркутская область, Нижнеилимский район, пос. Заярск, улица Заярская, дом 1		0101000020E61000002FC03E3A75B55940B37DC85BAE184C40
36057	5	50	1713	23761	69031	\N	57.084018999999998	Иркутская область, Нижнеилимский район, пос. Заморский, улица Ленина, дом 6		0101000020E6100000118AADA069CD59400E9F7422C18A4C40
36043	5	50	1713	23095	\N	\N	56.578353962116402	Иркутская область, г. Железногорск-Илимский, квартал 1, дом 43	Россия, Иркутская область, Нижнеилимский район, Железногорск-Илимский	0101000020E61000006BEF535568075A4061C1FD80074A4C40
36054	5	50	1713	23095	69054	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, пос. Донецкого ЛПХ, дом 34		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36053	5	50	1713	23095	68227	\N	56.5789224202382	Иркутская область, г. Железногорск-Илимский, микрорайон 10, дом 35	Россия, Иркутская область, Нижнеилимский район, Железногорск-Илимский	0101000020E6100000A6608DB3E9075A40AB77B81D1A4A4C40
36051	5	50	1713	23095	68224	\N	56.579680351051898	Иркутская область, г. Железногорск-Илимский, квартал 8, дом 29	Россия, Иркутская область, Нижнеилимский район, Железногорск-Илимский	0101000020E6100000CD74AF93FA075A40991249F4324A4C40
36046	5	50	1713	23095	67681	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, квартал 3, дом 34		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36044	5	50	1713	23095	68788	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, квартал 1, дом 45		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36048	5	50	1713	23095	67801	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, квартал 6а, дом 4		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36047	5	50	1713	23095	37453	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, квартал 6, дом 17а		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36045	5	50	1713	23095	67956	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, квартал 2, дом 43		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36049	5	50	1713	23095	67686	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, квартал 7, дом 17		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36052	5	50	1713	23095	68660	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, улица Энтузиастов, дом 2А		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36840	5	50	1713	23095	67645	\N	56.562489999999997	Иркутская область, г. Железногорск-Илимский, 3кв,15а, ДК		0101000020E6100000030AF5F411085A40DC291DACFF474C40
36055	5	50	1713	23678	68552	\N	57.358808000000003	"Иркутская область, Нижнеилимский район, пос. Дальний, улица Школьная, МОУ ""Дальнинская СОШ"""		0101000020E6100000643A747ADEB2594087C5A86BEDAD4C40
36071	5	50	1713	24442	68678	\N	56.407550999999998	Иркутская область, Нижнеилимский район, пос. Видим, улица Нагорная, дом 1а		0101000020E6100000D93F4F0306C75940DE3994A12A344C40
36072	5	50	1713	24442	69390	\N	56.407550999999998	Иркутская область, Нижнеилимский район, пос. Видим, улица Железнодорожная, дом 1		0101000020E6100000D93F4F0306C75940DE3994A12A344C40
36056	5	50	1713	23708	69119	\N	57.270567999999997	Иркутская область, Нижнеилимский район, пос. Брусничный, улица Ленина, 11		0101000020E610000030630AD638D159400CACE3F8A1A24C40
36058	5	50	1713	23818	68876	\N	56.939563	Иркутская область, Нижнеилимский район, пос. Березняки, улица Янгеля, дом 25		0101000020E610000092088D60E3E559400DC4B29943784C40
36041	5	50	7474	59334	69622	\N	55.436641999999999	Иркутская область, Мамско-Чуйский район, п. Согдиондон, ул. Мира, д.24	Россия, Иркутская область, Братский район	0101000020E6100000EF703B342C9D5940AF0793E2E3B74B40
36042	5	50	7474	59337	69629	\N	57.627911562971498	Иркутская область, Мамско-Чуйский район, п. Горно-Чуйский, ул. Советская, д. 26	Россия	0101000020E6100000F870C971A7EE5B400B62A06B5FD04C40
36039	5	50	7474	59323	69595	\N	58.2119885517615	Иркутская область, Мамско-Чуйский район, п. Мусковит, ул. Комсомольская, д. 7	Россия	0101000020E6100000ADF6B0170A535C404E0E9F74221B4D40
36040	5	50	7474	59265	69464	\N	58.026098561998197	Иркутская область, Мамско-Чуйский район, п.Луговский, ул.Школьная, д.26		0101000020E6100000C102983270385C40AABA473657034D40
36033	5	50	113	59195	68938	\N	54.430824999999999	Иркутская область, Куйтунский район, ж/д станция Мингатуй, Ленина, помещение дома досуга	Россия, Иркутская область, Куйтунский район	0101000020E61000001E520C90685359404CA60A4625374B40
36032	5	50	113	22628	68579	\N	54.380609999999997	Иркутская область, Куйтунский район, Чеботариха, Мира, 75		0101000020E61000007497C459114F5940E94317D4B7304B40
35997	5	50	113	21004	69112	\N	54.227722	Иркутская область, Куйтунский район, Харчев, Макарова, 18-2		0101000020E61000008126C286A7775940344A97FE251D4B40
36030	5	50	113	52140	68639	\N	54.238116827190098	Иркутская область, Куйтунский район, Харик (село), Озерная, 10	Россия, Иркутская область, Куйтунский район, поселок Харик	0101000020E6100000B3F0F5B52E6A594092CF2B9E7A1E4B40
35995	5	50	113	52140	68216	\N	54.239122344072797	Иркутская область, Куйтунский район, Харик (поселок), Ленина, 10	Россия, Иркутская область, Куйтунский район, поселок Харик	0101000020E6100000EA9106B7B56A594087E0B88C9B1E4B40
35988	5	50	113	20497	69249	\N	54.350275000000003	Иркутская область, Куйтунский район, Хаихта, Зеленая, 4-2		0101000020E61000005C04C6FA067159409FCDAACFD52C4B40
36022	5	50	113	22191	69111	\N	54.496718999999999	Иркутская область, Куйтунский район, Усть-Када, Лесная, 5		0101000020E6100000D1B2EE1F0B815940A226FA7C943F4B40
35604	5	50	113	1194	69503	\N	53.951903000000001	Иркутская область, Зиминское районное муниципальное образование, Хазанское муниципальное образование, с.Урункуй, Пионерская, 23		0101000020E610000052EDD3F1985C59406EFB1EF5D7F94A40
36025	5	50	113	52497	67788	\N	54.451045999999998	Иркутская область, Куйтунский район, Тулюшка (станция), Мира, 9		0101000020E61000003123BC3D084C5940ED7E15E0BB394B40
36024	5	50	113	52497	69285	\N	54.451045999999998	Иркутская область, Куйтунский район, Тулюшка (село), Ленина, 29 А		0101000020E61000003123BC3D084C5940ED7E15E0BB394B40
35983	5	50	113	20180	69300	\N	54.454894000000003	Иркутская область, Куйтунский район, Тобино, Степная, 17		0101000020E6100000E606431D56545940C59272F7393A4B40
36011	5	50	113	21629	69024	\N	54.148169000000003	Иркутская область, Куйтунский район, Тихорут, Степная, 24		0101000020E61000005439ED2939695940F9A3A833F7124B40
35982	5	50	113	20116	69110	\N	54.439832000000003	Иркутская область, Куйтунский район, Сулкет, Трактовая, 33		0101000020E61000000D8CBCAC895E5940FDDD3B6A4C384B40
36015	5	50	113	21856	69431	\N	54.212181999999999	Иркутская область, Куйтунский район, 3-я Станица, Центральная, 46 А		0101000020E6100000BBF083F3A955594062669FC7281B4B40
35998	5	50	113	192	69136	\N	54.281078999999998	Иркутская область, Куйтунский район, Сосновский, Трактовая,5-2		0101000020E6100000BA11161571745940D34B8C65FA234B40
36001	5	50	113	21166	69022	\N	54.197062000000003	Иркутская область, Куйтунский район, Садовый, Центральная, 15-1		0101000020E61000003F389F3A566D594066A4DE5339194B40
36021	5	50	113	22121	69074	\N	54.630639000000002	Иркутская область, Куйтунский район, Панагино, Центральная, 1		0101000020E610000087A6ECF4838C5940844A5CC7B8504B40
36362	5	50	113	6642	69214	\N	54.89866	Иркутская область,Тулунский район, п.Октябрьский- 2, ул.Школьная, 10		0101000020E6100000F8F9EFC16B3E5940971C774A07734B40
35992	5	50	113	20744	69382	\N	54.618144000000001	Иркутская область, Куйтунский район, Окинский, Верхняя, 15		0101000020E61000008F37F92D3A6C5940FC1BB4571F4F4B40
36020	5	50	113	22108	69109	\N	54.780906000000002	Иркутская область, Куйтунский район, Новая Тельба, Ленина, 1		0101000020E6100000C7F319506F7F594006A051BAF4634B40
36023	5	50	113	22216	69385	\N	54.520321000000003	Иркутская область, Куйтунский район, Новая Када, Мира, 56		0101000020E6100000916456EF707F59400536E7E099424B40
36019	5	50	113	22034	69292	\N	55.025477000000002	Иркутская область, Куйтунский район, Наратай, Набережная,21		0101000020E61000000954FF20928359406DE690D442834B40
36018	5	50	113	21973	69032	\N	54.732999870654602	Иркутская область, Куйтунский район, Мингатуй, Мира, 15	Россия, Иркутская область, Куйтунский район, поселок Мингатуй	0101000020E610000047AE9B525E645940E7FBA9F1D25D4B40
35984	5	50	113	20280	69123	\N	54.503793000000002	Иркутская область, Куйтунский район, Малая Кочерма, Школьная, 2		0101000020E6100000100874266D585940147AFD497C404B40
36026	5	50	113	22369	69389	\N	54.524177000000002	Иркутская область, Куйтунский район, Майский, Лесная, 1 Б		0101000020E61000002C6519E2584F59405F28603B18434B40
35999	5	50	113	21081	69294	\N	54.2379740496526	Иркутская область, Куйтунский район, Листвянка, Школьная, 19	Россия, Иркутская область, Куйтунский район, поселок Листвянка	0101000020E6100000917BBABA636F59402FA699EE751E4B40
36013	5	50	113	21727	69029	\N	54.302252000000003	Иркутская область, Куйтунский район, Лермонтовский, Лазо, 7		0101000020E6100000E99B340D8A57594047938B31B0264B40
36010	5	50	113	21605	69268	\N	54.089924000000003	Иркутская область, Куйтунский район, Ленинский, Солнечная, 18		0101000020E610000098141F9F906B594011902FA1820B4B40
36006	5	50	113	21405	68818	\N	54.340947999999997	Иркутская область, Куйтунский район, Кундуй, переулок Советский, 2 А		0101000020E6100000B360E28FA25059407CD11E2FA42B4B40
35976	5	50	113	18957	68751	\N	54.336700700122698	Иркутская область, Куйтунский район, Куйтун, Чернышевского, 5	Россия, Иркутская область, Куйтунский район, поселок Куйтун	0101000020E6100000669FC728CF5F5940E7C3B304192B4B40
35977	5	50	113	18957	68631	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, Фрунзе, 78		0101000020E610000081AFE8D66B6059409E29745E632B4B40
35979	5	50	113	18957	68866	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, Тургенева, 1		0101000020E610000081AFE8D66B6059409E29745E632B4B40
35978	5	50	113	18957	68733	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, Нахимова, 2		0101000020E610000081AFE8D66B6059409E29745E632B4B40
35975	5	50	113	18957	69386	\N	54.337202254277102	Иркутская область, Куйтунский район, Куйтун, Молодежная, 16	Россия, Иркутская область, Куйтунский район, поселок Куйтун	0101000020E61000001B47ACC5A75F5940A912656F292B4B40
35971	5	50	113	18957	68867	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, Коммунальная, 31		0101000020E610000081AFE8D66B6059409E29745E632B4B40
35960	5	50	113	18957	68737	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, Киевская, 2 А		0101000020E610000081AFE8D66B6059409E29745E632B4B40
35974	5	50	113	18957	67786	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, Карла Маркса, 24		0101000020E610000081AFE8D66B6059409E29745E632B4B40
35970	5	50	113	18957	67786	\N	54.340010843959298	Иркутская область, Куйтунский район, Куйтун, Карла Маркса, 4	Россия, Иркутская область, Куйтунский район, поселок Куйтун	0101000020E6100000B682A62556605940DFA3FE7A852B4B40
35980	5	50	113	18957	68740	\N	54.338970000000003	Иркутская область, Куйтунский район, Куйтун, 1-я Рабочая, 1		0101000020E610000081AFE8D66B6059409E29745E632B4B40
36029	5	50	113	22461	69113	\N	54.384852000000002	Иркутская область, Куйтунский район, Красный Яр, Зеленая, 27		0101000020E610000037C5E3A25A8359406DE690D442314B40
35987	5	50	113	20456	69306	\N	54.404781999999997	Иркутская область, Куйтунский район, Ключи, Центральная, 46		0101000020E61000000952297634665940360186E5CF334B40
36004	5	50	113	21263	67936	\N	54.101270999999997	Иркутская область, Куйтунский район, Карымск (село), Набережная, 6 А		0101000020E61000007764AC36FF7559404084B872F60C4B40
39251	3	24	459	57569	59464	\N	63.841075169514902	п.Маленга, ул.Школьная, д.16		0101000020E6100000D2FD9C82FC384240D93D7958A8EB4F40
36003	5	50	113	21263	67936	\N	54.101270999999997	Иркутская область, Куйтунский район, Карымск (поселок), Набережная, 6		0101000020E61000007764AC36FF7559404084B872F60C4B40
36017	5	50	113	21955	69387	\N	54.131411999999997	Иркутская область, Куйтунский район, Каранцай, Российская, 55 А		0101000020E610000008ABB184B54E5940A626C11BD2104B40
36002	5	50	113	21248	68577	\N	54.354540999999998	Иркутская область, Куйтунский район, Каразей, Мира, 49		0101000020E61000006F29E78BBD475940AA0B7899612D4B40
36016	5	50	113	21887	\N	\N	54.171266000000003	Иркутская область, Куйтунский район, Или, Центральная, 49 А	Россия, Иркутская область, Куйтунский район, поселок Или	0101000020E61000001B0FB6D8ED5759405875560BEC154B40
36009	5	50	113	21551	68739	\N	54.088740999999999	Иркутская область, Куйтунский район, Игнино, Ленина, 5		0101000020E6100000965984622B7059403C6876DD5B0B4B40
36014	5	50	113	21800	69027	\N	54.347622316557803	Иркутская область, Куйтунский район, Еланский, Заречная, 13 А	Россия, Иркутская область, Куйтунский район, поселок Еланский	0101000020E6100000B988EFC4AC57594060AFB0E07E2C4B40
35990	5	50	113	20606	69021	\N	54.512345000000003	Иркутская область, Куйтунский район, Бурук, Ленина, 23		0101000020E610000019A9F7544E64594073A25D8594414B40
35991	5	50	113	20666	69064	\N	54.614730000000002	Иркутская область, Куйтунский район, Броды, Центральная, 13		0101000020E61000001D9430D3F65F59405FEFFE78AF4E4B40
35603	5	50	113	1159	69250	\N	54.031433226872203	"Иркутская область, Зиминское районное муниципальное образование, Хазанское муниципальное образование, с.Боровое, Школьная, 1 ""А"""	Россия, Иркутская область, Куйтунский район, поселок Боровое	0101000020E6100000D57ABFD18E615940F1811DFF05044B40
35993	5	50	113	20757	\N	\N	54.071727000000003	Иркутская область, Куйтунский район, Большой Кашелак, Социалистическая, 43	Россия, Иркутская область, Куйтунский район, поселок Большой Кашелак	0101000020E61000004435255987635940BF9EAF592E094B40
35989	5	50	113	20552	69261	\N	54.404063999999998	Иркутская область, Куйтунский район, Березовский, Школьная, 3		0101000020E610000072158BDF14785940D7BE805EB8334B40
35768	5	50	113	9669	68862	\N	54.537723999999997	Иркутская область, Куйтунский район, Барлук, Школьная, 17 А		0101000020E61000007D586FD40A6E59401C23D923D4444B40
36000	5	50	113	21160	69384	\N	54.235394999999997	Иркутская область, Куйтунский район, Ахтинский, Центральная, 21		0101000020E6100000FCDF1115AA6359402A52616C211E4B40
36031	5	50	113	22561	69114	\N	54.196125000000002	Иркутская область, Куйтунский район, Аршан, Лесная, 20		0101000020E61000009869FB5756605940C976BE9F1A194B40
35994	5	50	113	59328	69604	\N	54.101979	Иркутская область, Куйтунский район, Апраксино, Советская, 26	Россия, Иркутская область, Куйтунский район, поселок Апраксина	0101000020E6100000454AB3791C5B59407CF0DAA50D0D4B40
35986	5	50	113	20399	68744	\N	54.364131	Иркутская область, Куйтунский район, Андрюшино, Советская, 73 А		0101000020E61000002ECBD765F8685940DA3A38D89B2E4B40
36008	5	50	113	21487	69447	\N	54.216830999999999	Иркутская область, Куйтунский район, Амур, Центральная,37б		0101000020E6100000A43330F2B247594026E1421EC11B4B40
35981	5	50	113	20066	69134	\N	54.488928000000001	Иркутская область, Куйтунский район, Алкин, переулок Больничный, 1		0101000020E6100000FF3F4E98305C5940A20C5531953E4B40
35985	5	50	113	20298	69434	\N	54.575682	Иркутская область, Куйтунский район, Александро-Невский завод, 1-я Заречная, 12		0101000020E61000009B8D959867525940AC72A1F2AF494B40
36007	5	50	113	21460	69326	\N	54.293813	Иркутская область, Куйтунский район, Александро-Невская станица, Центральная, 41		0101000020E6100000C7F484251E525940E01115AA9B254B40
35961	5	50	7470	59322	69592	\N	57.972873	Иркутская область, муниципальное образование - Киренский район, Алымовское муниципальное образование, с.Алымовка, Центральная, 5	Россия	0101000020E610000088A06AF46A245B40A9143B1A87FC4C40
35965	5	50	7470	59338	69632	\N	58.131611791910501	Иркутская область, муниципальное образование - Киренский район, Юбилейнинское муниципальное образование, п.Юбилейный, Гагарина, 2	Россия	0101000020E610000054ABAFAE0A365B406DE179A9D8104D40
35948	5	50	7470	59227	\N	\N	57.762568665081098	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, д.Сидорово, сельский клуб	Россия	0101000020E6100000C3A04CA3C9065B40C2F869DC9BE14C40
35939	5	50	7470	59202	69010	\N	57.480640817647597	Иркутская область, муниципальное образование - Киренский район, Макаровское муниципальное образование, Полевая, 47		0101000020E6100000F25EB532E1F55A40F10EF0A485BD4C40
35940	5	50	7470	59215	69152	\N	57.602647600796203	Иркутская область, муниципальное образование - Киренский район, Криволукское муниципальное образование, Боровкова, 8	Россия	0101000020E6100000B6B9313D61F55A40FA7FD59123CD4C40
35952	5	50	7470	59199	68994	\N	57.783111475443199	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, м-он Пролетарск, Майская, 16	Россия	0101000020E610000003B4AD669D075B40A51133FB3CE44C40
35955	5	50	7470	59219	\N	\N	57.774676935751899	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, село Змеиново, Здание ФАП	Россия	0101000020E61000005708ABB184125B4050FBAD9D28E34C40
35958	5	50	7470	59302	69619	\N	57.866914440413098	Иркутская область, муниципальное образование - Киренский район, Алексеевское муниципальное образование, п.Воронежский, Первомайская, 2	Россия	0101000020E6100000416667D13B195B40E738B709F7EE4C40
35963	5	50	7470	59382	70099	\N	57.990697242717097	Иркутская область, муниципальное образование - Киренский район, Алымовское муниципальное образование, с.Банщиково, Центральная, 2	Россия	0101000020E6100000D7169E978A265B40669FC728CFFE4C40
35912	5	50	905	16530	69101	\N	53.987616000000003	Иркутская область, Качугский район, д. Щапова, Ключевая, 23		0101000020E6100000D74D29AF95885A40D0807A336AFE4A40
35913	5	50	905	16581	68933	\N	54.093229999999998	Иркутская область, Качугский район, д. Шеина, Школьная, 21		0101000020E6100000DA01D71533885A40C780ECF5EE0B4B40
35926	5	50	905	17246	68735	\N	53.748806000000002	Иркутская область, Качугский район, с. Харбатово, Трактовая, 28 А		0101000020E610000016855D143D805A40388600E0D8DF4A40
36839	5	50	905	17246	69319	\N	53.748806000000002	Иркутская область, Качугский район, с. Харбатово, Новая,24 бар		0101000020E610000016855D143D805A40388600E0D8DF4A40
35930	5	50	905	17445	69381	\N	53.802292999999999	Иркутская область, Качугский район, д. Хальск, Кольцевая, 20		0101000020E610000037C478CDAB825A40A5677A89B1E64A40
35922	5	50	905	17048	68953	\N	54.096012000000002	Иркутская область, Качугский район, д. Толмачева, Киселева, 47		0101000020E6100000C76471FF91625A400403081F4A0C4B40
35907	5	50	905	16266	69383	\N	53.925136000000002	Иркутская область, Качугский район, д. Тимирязева, Совхозная, 23		0101000020E6100000BE67244223795A40172D40DB6AF64A40
35932	5	50	905	17547	69213	\N	53.5312181056958	Иркутская область, Качугский район, д. Полоскова, Трактовая, 34 Б	Россия, Иркутская область, Качугский район, поселок Полоскова	0101000020E610000086C8E9EBF97E5A40F58590F3FEC34A40
35927	5	50	905	17277	69105	\N	53.674826000000003	Иркутская область, Качугский район, с. Никилей, Школьная, 12		0101000020E6100000118FC4CBD37D5A40C93EC8B260D64A40
35931	5	50	905	17459	68736	\N	53.481341	Иркутская область, Качугский район, с. Манзурка, Октябрьская, 13		0101000020E61000006C95607138845A40AA9CF6949CBD4A40
35917	5	50	905	16798	69240	\N	53.8337251520121	Иркутская область, Качугский район, д. Малая Тарель, Петровская, 15	Россия, Иркутская область, Качугский район, поселок Малый Тарель	0101000020E6100000E109BDFE24975A40C66D3480B7EA4A40
35890	5	50	905	15468	69270	\N	53.929817999999997	Иркутская область, Качугский район, д. Малые Голы, Трактовая, 4		0101000020E6100000E23FDD4081825A40B69DB64604F74A40
35929	5	50	905	17370	69104	\N	53.620581999999999	Иркутская область, Качугский район, д. Литвинова, Гаражная, 19 А		0101000020E6100000F60CE198657F5A403E3E213B6FCF4A40
35880	5	50	905	14982	68772	\N	53.950927999999998	Иркутская область, Качугский район, д. Краснояр, Трактовая, 39		0101000020E61000009F2287889B7B5A40E36C3A02B8F94A40
35928	5	50	905	17347	68978	\N	53.745057000000003	Иркутская область, Качугский район, д. Корсукова, Школьная, 4		0101000020E6100000003B376DC68D5A40F4531C075EDF4A40
35934	5	50	905	17653	69262	\N	53.360081999999998	Иркутская область, Качугский район, д. Копылова, Лесная, 39		0101000020E6100000A1BDFA78E8845A406BF0BE2A17AE4A40
35713	5	50	905	7090	67673	\N	53.962626	Иркутская область, Качугский район, пгт Качуг, пер. Восточный, 2		0101000020E6100000C66CC9AA08785A40C0232A5437FB4A40
35905	5	50	905	7090	67941	\N	53.962626	Иркутская область, Качугский район, пгт Качуг, Юбилейная, 2 А		0101000020E6100000C66CC9AA08785A40C0232A5437FB4A40
35807	5	50	905	7090	68826	\N	53.962626	Иркутская область, Качугский район, пгт Качуг, Пуляевского, 77		0101000020E6100000C66CC9AA08785A40C0232A5437FB4A40
35870	5	50	905	7090	68561	\N	53.962626	Иркутская область, Качугский район, пгт Качуг, Маяковского, 12		0101000020E6100000C66CC9AA08785A40C0232A5437FB4A40
35904	5	50	905	7090	67930	\N	53.962626	Иркутская область, Качугский район, пгт Качуг, Красноармейская, д.42		0101000020E6100000C66CC9AA08785A40C0232A5437FB4A40
35799	5	50	905	7090	67676	\N	53.962626	Иркутская область, Качугский район, пгт Качуг, Каландарашвили, 209		0101000020E6100000C66CC9AA08785A40C0232A5437FB4A40
35935	5	50	905	17678	69126	\N	53.423622999999999	Иркутская область, Качугский район, с. Карлук, Школьная, 26		0101000020E61000000DC17119377F5A40AD6A494739B64A40
35909	5	50	905	16386	69121	\N	53.844064000000003	Иркутская область, Качугский район, д. Исеть, Береговая, 43		0101000020E6100000CCB6D3D6887E5A4090DD054A0AEC4A40
35933	5	50	905	17569	69260	\N	53.413286999999997	Иркутская область, Качугский район, с. Заречное, Центральная, 19		0101000020E6100000C3B645990D875A40546EA296E6B44A40
35919	5	50	905	16883	69388	\N	53.936709	Иркутская область, Качугский район, с. Залог, Центральная, 27		0101000020E61000004227840EBA985A40376F9C14E6F74A40
35921	5	50	905	16988	68575	\N	54.100637999999996	Иркутская область, Качугский район, с. Верхоленск, Федосеева, 44 А		0101000020E6100000ED116A8654645A400F5EBBB4E10C4B40
35911	5	50	905	16485	69398	\N	54.057735000000001	Иркутская область, Качугский район, с. Бутаково, Совхозная, 37		0101000020E6100000E3DEFC8689875A40D36A48DC63074B40
35908	5	50	905	59237	69304	\N	53.878810761878597	Иркутская область, Качугский район, д. Босогол, Мархеева, 13	Россия, Иркутская область, Качугский район, поселок Босогол (Наран)	0101000020E610000005172B6A307A5A40BA2EFCE07CF04A40
35920	5	50	905	16952	69243	\N	53.755349000000002	Иркутская область, Качугский район, с. Большая Тарель, Пуляевского, 12		0101000020E61000009DF3531C07A85A407D08AA46AFE04A40
35918	5	50	905	16843	69378	\N	53.842039999999997	Иркутская область, Качугский район, д. Большой Косогол, Центральная, 12		0101000020E6100000B587BD50C0895A4040F67AF7C7EB4A40
35906	5	50	905	16224	69444	\N	53.871907	Иркутская область, Качугский район, д. Большие Голы, Береговая, 23		0101000020E61000007616BD5301805A40A51309A69AEF4A40
35916	5	50	905	16692	68932	\N	53.865244395636203	Иркутская область, Качугский район, с. Бирюлька, Окладникова, 13	Россия, Иркутская область, Качугский район, поселок Бирюлька	0101000020E610000074B33F506E955A40B587BD50C0EE4A40
35915	5	50	905	16692	68570	\N	53.865117565940899	Иркутская область, Качугский район, с. Бирюлька, Ленина, 41	Россия, Иркутская область, Качугский район, поселок Бирюлька	0101000020E6100000C6C03A8E1F955A402997C62FBCEE4A40
35923	5	50	905	17088	69016	\N	54.033912999999998	Иркутская область, Качугский район, с. Белоусово, Победы, 19		0101000020E61000007E384888F25D5A4062F4DC4257044B40
35914	5	50	905	16647	69377	\N	54.188733999999997	Иркутская область, Качугский район, д. Ацикяк, Трактовая, 16		0101000020E61000004FE960FD9F935A4056D28A6F28184B40
35936	5	50	905	17753	69380	\N	53.367572000000003	Иркутская область, Качугский район, д. Аргун, Центральная, 16 Б		0101000020E6100000A48B4D2B857B5A4071766B990CAF4A40
35910	5	50	905	16436	68732	\N	53.983125999999999	Иркутская область, Качугский район, с. Анга, Советская, 23 А		0101000020E610000064213A048E8B5A4074ECA012D7FD4A40
35899	5	50	7473	59373	70016	\N	58.2643388161109	Иркутская область, Катангский район, с.Подволошино, Майская, 22	Россия	0101000020E610000071917BBABA1B5B40570740DCD5214D40
35895	5	50	7473	59196	68959	\N	61.274382613480299	Иркутская область, Катангский район, с.Ербогачен, Авиаторов, 11	Россия	0101000020E6100000C617EDF142015B4008CA6DFB1EA34E40
36837	5	50	1344	52067	\N	\N	55.898659000000002	"Иркутская область, муниципальное образование """"Казачинско-Ленский район"""", Тарасовское муниципальное образование, д.Юхта, помещение Дома досуга, "	Россия, Иркутская область, Казачинско-Ленский район, поселок Юхта	0101000020E6100000C32973F38DF15A40C7A0134207F34B40
35872	5	50	1344	52268	67680	\N	55.909953000000002	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Ульканское муниципальное образование, п. Улькан, Машурова, 16"		0101000020E6100000CEC5DFF604F35A40D4F2035779F44B40
35871	5	50	1344	52268	67677	\N	55.909953000000002	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Ульканское муниципальное образование, п. Улькан, Лесная, 4"		0101000020E6100000CEC5DFF604F35A40D4F2035779F44B40
35873	5	50	1344	52268	67923	\N	55.909953000000002	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Ульканское муниципальное образование, п. Улькан, Дзержинского, 10"		0101000020E6100000CEC5DFF604F35A40D4F2035779F44B40
35874	5	50	1344	52273	\N	\N	55.860230999999999	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Тарасовское муниципальное образование, с. Тарасово, д. Юхта, помещение Администрации, 26"		0101000020E6100000F584251E50F45A40B000A60C1CEE4B40
36181	5	50	1344	29487	69122	\N	56.05885	Иркутская область, Нукутский район, д. Новосёлово, ул. Центральная, д. 20		0101000020E6100000AF5FB01BB6EC5A404FAF946588074C40
35883	5	50	1344	52287	69197	\N	56.353869000000003	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Небельское муниципальное образование, п. Небель, Ленина, 21"		0101000020E610000050A8A78FC0C65A40BC0853944B2D4C40
35881	5	50	1344	52158	\N	\N	56.083111457680502	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Магистральнинское муниципальное образование, п. Магистральный, д. Седанкина, помещение Административного здания ООО ""Байкал Лес"""	Россия, Иркутская область, Казачинско-Ленский район, поселок Магистральный	0101000020E6100000ACE63922DFDE5A400C789961A30A4C40
35876	5	50	1344	52158	67937	\N	56.092325000000002	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Магистральнинское муниципальное образование, п. Магистральный, Российская, 4"		0101000020E61000009B594B0169DE5A4036CD3B4ED10B4C40
35877	5	50	1344	52158	68637	\N	56.088121351839298	"""Иркутская область, муниципальное образование """"Казачинско-Ленский район"""", Магистральнинское муниципальное образование, п. Магистральный, Пугачева, 40"""	Россия, Иркутская область, Казачинско-Ленский район, поселок Магистральный	0101000020E6100000B471C45A7CDE5A40A08B868C470B4C40
35879	5	50	1344	52158	67916	\N	56.092325000000002	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Магистральнинское муниципальное образование, п. Магистральный, Ленина, 4"		0101000020E61000009B594B0169DE5A4036CD3B4ED10B4C40
35878	5	50	1344	52158	69379	\N	56.089081077275701	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Магистральнинское муниципальное образование, п. Магистральный, Карбышева, В/Ч 75238"		0101000020E6100000EE27637C98DE5A40F5D89601670B4C40
35882	5	50	1344	52158	67780	\N	56.092325000000002	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Магистральнинское муниципальное образование, п. Магистральный, 60 лет Октября, 5"		0101000020E61000009B594B0169DE5A4036CD3B4ED10B4C40
35869	5	50	1344	52264	68948	\N	55.764212000000001	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Кунерминское муниципальное образование, п. Кунерма, Железнодорожная"		0101000020E610000019558671371C5B40FA9AE5B2D1E14B40
35875	5	50	1344	59153	68537	\N	56.021758633504703	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Новоселовское муниципальное образование, с. Новоселово, д. Конец-Луг, крестьянское хозяйство ""Рассвет"", 40 лет Победы, 10"	Россия, Иркутская область, Казачинско-Ленский район, поселок Конец-Луг	0101000020E610000047CB811E6AED5A4064B2B8FFC8024C40
35886	5	50	1344	52294	68700	\N	56.198394999999998	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Ключевское муниципальное образование, п. Ключи, 30 лет Победы, 37"		0101000020E6100000DDB6EF517FDF5A404F58E20165194C40
35884	5	50	1344	15178	67932	\N	56.266706999999997	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Казачинское муниципальное образование, с. Казачинское, Октябрьская, 20"		0101000020E6100000637E6E68CAE45A40A04E797423224C40
35885	5	50	1344	15178	68253	\N	56.266706999999997	"Иркутская область, муниципальное образование ""Казачинско-Ленский район"", Казачинское муниципальное образование, с.Казачинское, Коммунистическая, 5"		0101000020E6100000637E6E68CAE45A40A04E797423224C40
35642	5	50	425	59120	67931	\N	52.238293806569501	Иркутская область, Иркутский район, р.п. Маркова, Мира, 13		0101000020E61000004B395FECBD0C5A40A16AF46A801E4A40
35670	5	50	425	59303	69564	\N	52.395016655561598	Иркутская область, Иркутский район, д. Столбова, Центральная, 2	Россия, Иркутская область, Иркутский район	0101000020E6100000F4A44C6A683A5A40992EC4EA8F324A40
35691	5	50	425	6008	68771	\N	52.552363999999997	Иркутская область, Иркутский район, д. Ширяева, Ленина, 26		0101000020E61000000C93A982510E5A406EBE11DDB3464A40
35662	5	50	425	4460	69498	\N	52.647029000000003	Иркутская область, Иркутский район, д. Черемушка, Дзержинского, 28 А		0101000020E6100000AE0E80B8AB245A402448A5D8D1524A40
35685	5	50	425	5616	67820	\N	52.466431171876103	Иркутская область, Иркутский район, с. Хомутово, Колхозная, 138	Россия, Иркутская область, Иркутский район, поселок Хомутово	0101000020E61000000AB952CF82175A40986BD102B43B4A40
35684	5	50	425	5616	67928	\N	52.472867000000001	Иркутская область, Иркутский район, с. Хомутово, Кирова, 10 Б		0101000020E61000004F3DD2E0B6175A40C72DE6E7863C4A40
35677	5	50	425	5251	68767	\N	52.437640999999999	Иркутская область, Иркутский район, д. Усть-Куда, Муханова, 5		0101000020E6100000D32F116F9D095A40C231CB9E04384A40
35678	5	50	425	5251	68840	\N	52.437640999999999	Иркутская область, Иркутский район, д. Усть-Куда, Геологическая, 3		0101000020E6100000D32F116F9D095A40C231CB9E04384A40
35674	5	50	425	5089	69051	\N	52.633000781179298	Иркутская область, Иркутский район, п. Усть-Балей, Ангарская, 27	Россия, Иркутская область, Иркутский район, поселок Усть-Балей	0101000020E610000075B0FECF61FF5940EBAA402D06514A40
35666	5	50	425	4659	67913	\N	52.457943999999998	Иркутская область, Иркутский район, с. Урик, Лунина, 2 Г		0101000020E6100000A4A99ECC3F0F5A4020B3B3E89D3A4A40
35656	5	50	425	4089	69189	\N	52.531962999999998	Иркутская область, Иркутский район, д. Турская, Центральная, 26		0101000020E6100000450F7C0C561C5A404DD7135D17444A40
35693	5	50	425	6099	69053	\N	52.631722000000003	Иркутская область, Иркутский район, д. Тихонова Падь, Центральная, 71		0101000020E610000013BA4BE2AC095A40F5143944DC504A40
35665	5	50	425	4602	68681	\N	52.659916000000003	Иркутская область, Иркутский район, д. Сосновый Бор, Мелехова, 10		0101000020E610000005FC1A4982205A40B70DA32078544A40
35664	5	50	425	4558	67911	\N	52.251533999999999	Иркутская область, Иркутский район, с. Смоленщина, Горького, 33		0101000020E6100000228AC91B60085A4081EA1F4432204A40
35628	5	50	425	2580	69505	\N	52.842222	Иркутская область, Иркутский район, д. Сайгуты, Комсомольская, 31		0101000020E6100000B119E0826C0A5A4061FC34EECD6B4A40
35650	5	50	425	3795	69507	\N	52.714061999999998	Иркутская область, Иркутский район, д. Рязановщина, Школьная, 20 В		0101000020E6100000FD2FD7A205155A407EA83462665B4A40
35661	5	50	425	4383	68859	\N	52.588954000000001	Иркутская область, Иркутский район, д. Ревякина, Молодежная, 8		0101000020E6100000A0DD21C500285A40986C3CD8624B4A40
35687	5	50	425	5770	69059	\N	52.482702000000003	Иркутская область, Иркутский район, д. Позднякова, Российская, 1		0101000020E610000083C13577F41B5A405EDBDB2DC93D4A40
35688	5	50	425	59168	\N	\N	52.343130911316599	"Иркутская область, Иркутский район, п. Плишкино, Центральная МОУ ""Плишкинская ООШ"""	Россия, Иркутская область, городской округ Иркутск, поселок Плишкино	0101000020E6100000A5C00298321F5A40349F73B7EB2B4A40
35679	5	50	425	5356	68218	\N	52.272530000000003	Иркутская область, Иркутский район, с. Пивовариха, Дачная, 6		0101000020E61000008FE1B19FC51C5A40E6965643E2224A40
35682	5	50	425	5531	69255	\N	52.159835000000001	Иркутская область, Иркутский район, п. Патроны, Школьная, 2		0101000020E61000002C6519E2581E5A40CAE0287975144A40
35639	5	50	425	3246	69172	\N	52.163983999999999	Иркутская область, Иркутский район, п. Падь Мельничная, Заводской, 1		0101000020E610000000C5C89239185A409C887E6DFD144A40
35652	5	50	425	3893	67671	\N	52.589888999999999	Иркутская область, Иркутский район, с. Оёк, Кирова, 91 Д		0101000020E6100000D0436D1B461D5A4094A2957B814B4A40
35953	5	50	425	3701	\N	\N	52.753678000000001	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, с.Никольск, сельский клуб		0101000020E6100000B939950C001D5A407BDB4C8578604A40
35648	5	50	425	3701	68769	\N	52.753678000000001	Иркутская область, Иркутский район, с. Никольск, Комсомольская площадь, 9		0101000020E6100000B939950C001D5A407BDB4C8578604A40
35668	5	50	425	4772	68946	\N	52.521070000000002	Иркутская область, Иркутский район, д. Московщина, Центральная, 33		0101000020E6100000BA111615710A5A409F76F86BB2424A40
35645	5	50	425	59123	68492	\N	52.244422	Иркутская область, Иркутский район, п. Молодежный, Совхозная, 2		0101000020E6100000CE548847E21A5A4022365838491F4A40
35641	5	50	425	3344	68204	\N	52.209282000000002	Иркутская область, Иркутский район, р.п. Маркова, Мира, 15		0101000020E6100000A2B8E34D7E0D5A401CD2A8C0C91A4A40
35643	5	50	425	3344	68558	\N	52.237470459272899	Иркутская область, Иркутский район, р.п. Маркова, Лесная, 2		0101000020E6100000F6436CB0700C5A40FCE3BD6A651E4A40
35637	5	50	425	59150	68508	\N	52.302548000000002	Иркутская область, Иркутский район, с. Мамоны, Садовая, 11		0101000020E610000077853E58C6095A4030BC92E4B9264A40
35623	5	50	425	2312	67664	\N	52.305059	Иркутская область, Иркутский район, с. Малое Голоустное, Мира, 24		0101000020E6100000BCCCB051D6545A40DC2C5E2C0C274A40
35638	5	50	425	3155	68679	\N	52.363818999999999	Иркутская область, Иркутский район, д. Малая Еланка, Мелиораторов, 12		0101000020E6100000F96A47718E035A40EB54F99E912E4A40
35660	5	50	425	3034	\N	\N	52.603318999999999	Иркутская область, Иркутский район, п. Максимовщина, клуб воинской части № 51870		0101000020E6100000505436ACA9215A401807978E394D4A40
35636	5	50	425	3034	67666	\N	52.603318999999999	Иркутская область, Иркутский район, с. Максимовщина, Советская, 30 А		0101000020E6100000505436ACA9215A401807978E394D4A40
35658	5	50	425	3034	69191	\N	52.603318999999999	Иркутская область, Иркутский район, д. Максимовщина, Веселая, 2		0101000020E6100000505436ACA9215A401807978E394D4A40
35692	5	50	425	6038	69504	\N	52.516440000000003	Иркутская область, Иркутский район, д. Лыловщина, Мира, 2		0101000020E61000001AC39CA04D0F5A40522CB7B41A424A40
35633	5	50	425	2889	68857	\N	51.852730999999999	Иркутская область, Иркутский район, р.п. Листвянка, Октябрьская, 1		0101000020E61000001A4D2EC6C0375A4087A4164A26ED4940
35634	5	50	425	2889	68889	\N	51.852730999999999	Иркутская область, Иркутский район, р.п. Листвянка, Горького, 89		0101000020E61000001A4D2EC6C0375A4087A4164A26ED4940
35651	5	50	425	3878	69052	\N	52.730899999999998	Иркутская область, Иркутский район, д. Кыцигировка, Кыцигировская, 1 А		0101000020E6100000ED293927F6225A40BD5296218E5D4A40
35686	5	50	425	5745	68219	\N	52.444299000000001	Иркутская область, Иркутский район, д. Куда, Ленина, 7 А		0101000020E6100000B090B932A8195A40A05225CADE384A40
35654	5	50	425	3978	69348	\N	52.551608999999999	Иркутская область, Иркутский район, д. Коты, Депутатская, 41		0101000020E6100000DF32A7CB62205A40F296AB1F9B464A40
35632	5	50	425	2801	68113	\N	52.422995999999998	Иркутская область, Иркутский район, д. Карлук, Гагарина, 2		0101000020E6100000A2258FA7E5125A405E2BA1BB24364A40
35675	5	50	425	5136	69193	\N	52.720945999999998	Иркутская область, Иркутский район, д. Зорино-Быково, Трактовая, А - 2		0101000020E6100000022D5DC136FD59404C1762F5475C4A40
35659	5	50	425	4274	69256	\N	52.653950999999999	Иркутская область, Иркутский район, д. Жердовка, Трактовая, 9 Б		0101000020E61000002FC03E3A75225A40DF1797AAB4534A40
35672	5	50	425	5007	69058	\N	52.700465000000001	Иркутская область, Иркутский район, с. Еловка, Центральная, 16 А		0101000020E6100000F9D7F2CAF5FD59400F7F4DD6A8594A40
35649	5	50	425	3775	69497	\N	52.664346000000002	Иркутская область, Иркутский район, с. Егоровщина, Школьная, 15		0101000020E6100000C9570229B11C5A403D9D2B4A09554A40
35667	5	50	425	4729	68560	\N	52.462623999999998	Иркутская область, Иркутский район, д. Грановщина, Загоскина, 70 В		0101000020E61000007364E597C1125A401F2C6343373B4A40
35694	5	50	425	6146	69061	\N	52.581933999999997	Иркутская область, Иркутский район, д. Горяшина, 40 лет Октября, 21		0101000020E610000082E673EE76105A40193735D07C4A4A40
35680	5	50	425	5406	68868	\N	52.276426000000001	Иркутская область, Иркутский район, п. Горячий Ключ, Учительская, 7		0101000020E6100000EFAA07CC433A5A40CEE15AED61234A40
35625	5	50	425	59181	68882	\N	52.809942146551798	Иркутская область, Иркутский район, с. Горохово-1, Школьная, 15	Россия, Иркутская область, Иркутский район, поселок Горохово	0101000020E6100000A7CAF78C44025A4013D4F02DAC674A40
35626	5	50	425	59181	69585	\N	52.807499999999997	Иркутская область, Иркутский район, с. Горохово-2, Советская, 38	Россия, Иркутская область, Иркутский район, поселок Горохово	0101000020E610000027BD6F7CED015A408FC2F5285C674A40
35689	5	50	425	5890	\N	\N	52.395803000000001	Иркутская область, Иркутский район, п. Горный, клуб воинской части № 36728		0101000020E61000005DA79196CA175A40505436ACA9324A40
35653	5	50	425	3969	69496	\N	52.623392000000003	Иркутская область, Иркутский район, д. Галки, Первомайская, 41 А		0101000020E61000001AA88C7F9F1C5A40454B1E4FCB4F4A40
35630	5	50	425	2699	69000	\N	52.965240000000001	Иркутская область, Иркутский район, д. Верхний Кет, Центральная, 10		0101000020E61000005551BCCADA0C5A404165FCFB8C7B4A40
35676	5	50	425	5183	69259	\N	52.737420959073802	Иркутская область, Иркутский район, д. Быкова, Калинина, 6 А	Россия, Иркутская область, Иркутский район, поселок Быкова	0101000020E61000003ED00A0C59015A401A31B3CF635E4A40
35629	5	50	425	59222	69190	\N	52.897410999999998	Иркутская область, Иркутский район, п. Бухун, Некрасова, 11		0101000020E61000002288F370020C5A400B09185DDE724A40
35655	5	50	425	4077	69050	\N	52.563220999999999	Иркутская область, Иркутский район, д. Бутырки, Придорожная, 1		0101000020E61000005DC2A1B778205A40D0B52FA017484A40
35683	5	50	425	5573	69192	\N	52.096907000000002	Иркутская область, Иркутский район, д. Бурдаковка, Лесная, 11		0101000020E6100000C8ED974F56255A4072E0D572670C4A40
35663	5	50	425	4503	69500	\N	52.540030999999999	Иркутская область, Иркутский район, д. Бургаз, Центральная, 69		0101000020E6100000B2683A3B192D5A40C0E95DBC1F454A40
35624	5	50	425	2346	69185	\N	52.036766	Иркутская область, Иркутский район, п. Большое Голоустное, Байкальская, 26-1		0101000020E6100000E3E2A8DC445A5A4068CD8FBFB4044A40
35622	5	50	425	59149	68482	\N	51.9497703644521	Иркутская область, Иркутский район, р.п. Большая Речка, Ленина, 8А	Россия, Иркутская область, Иркутский район, поселок Большая Речка	0101000020E610000012D89C83672F5A40685C381092F94940
35627	5	50	425	2545	69430	\N	52.823979999999999	Иркутская область, Иркутский район, д. Баруй, Маяковского, 22		0101000020E610000037C2A2224E035A406F47382D78694A40
35962	5	50	7471	59212	\N	\N	57.9861090831334	Иркутская область, муниципальное образование - Киренский район, Алымовское муниципальное образование, д.Никулина, сельский клуб	Россия	0101000020E61000008CA03193A8235B4048A5D8D138FE4C40
35582	5	50	10	59271	69512	\N	54.207783823055998	"Иркутская область, Зиминское районное муниципальное образование, Буринское муниципальное образование, с.Черемшанка, Школьная, 2 ""А"""	Россия, Иркутская область, Зиминский район, поселок Черемшанка	0101000020E6100000429770E82D915940E75086AA981A4B40
35602	5	50	10	1076	67918	\N	53.893689000000002	Иркутская область, Зиминское районное муниципальное образование, Хазанское муниципальное образование, п.Центральный Хазан, Мира, 57		0101000020E6100000DDB243FCC3765940C1E5B16664F24A40
35599	5	50	10	911	69506	\N	54.066591000000003	Иркутская область, Зиминское районное муниципальное образование, Харайгунское муниципальное образование, с.Харайгун, Центральная, 21		0101000020E6100000DD79E2395B8E59409E9ACB0D86084B40
35600	5	50	10	956	69244	\N	53.951008000000002	Иркутская область, Зиминское районное муниципальное образование, Филлиповское муниципальное образование, с.Филипповск, Новокшонова, 65		0101000020E6100000BCB0355B79945940001E51A1BAF94A40
35594	5	50	10	595	68682	\N	53.951103913963699	Иркутская область, Зиминское районное муниципальное образование, Ухтуйское муниципальное образование, с. Ухтуй, Лесная, 11	Россия, Иркутская область, Зиминский район, поселок Ухтуй	0101000020E6100000209738F240855940228C9FC6BDF94A40
35548	5	50	350	30732	68664	\N	53.476818999999999	Иркутская область, Заларинский район, д.Сорты, Трактовая, 18		0101000020E6100000E61F7D93A68E5940438EAD6708BD4A40
35592	5	50	10	465	68567	\N	53.932876999999998	"Иркутская область, Зиминское районное муниципальное образование, Услонское муниципальное образование, с.Услон, 40 лет Победы, 3 ""А"""		0101000020E6100000A41B6151117E59406518778368F74A40
35579	5	50	10	32211	69073	\N	53.811743499950097	Иркутская область, Зиминское районное муниципальное образование, Батаминское муниципальное образование, с.Сологубово, Школьная, 11	Россия, Иркутская область, Зиминский район, поселок Сологубово	0101000020E61000007380608E1E705940E3E0D231E7E74A40
36274	5	50	10	828	\N	\N	54.026673000000002	"Иркутская область, муниципальное образование город Саянск, микрорайон Олимпийский, здание ""Мегаполис-спорт"""		0101000020E610000060E811A3E7835940D65757056A034B40
36269	5	50	10	828	\N	\N	54.027359807427402	"Иркутская область, город Саянск, микрорайон Ленинградский, дом №7, детский спортклуб ""Искра"""	Россия, Иркутская область, Зиминский район, Саянск	0101000020E610000025EB707495825940FA9B508880034B40
36263	5	50	10	828	\N	\N	54.027056601793703	Иркутская область, город Саянск, микрорайон Центральный, дом №2, Центральная библиотека	Россия, Иркутская область, Зиминский район, Саянск	0101000020E610000011E15F048D8259405E10919A76034B40
36259	5	50	10	828	67687	\N	54.018111036420699	Иркутская область, город Саянск, микрорайон Юбилейный, школа №1	Россия, Иркутская область, Зиминский район, Саянск	0101000020E610000025CCB4FD2B8259405359147651024B40
36258	5	50	10	828	67687	\N	54.026673000000002	Иркутская область, город Саянск, микрорайон Юбилейный, школа № 3		0101000020E610000060E811A3E7835940D65757056A034B40
36257	5	50	10	828	67687	\N	54.026673000000002	Иркутская область, город Саянск, микрорайон Юбилейный, дом № 65, Картинная галерея		0101000020E610000060E811A3E7835940D65757056A034B40
36268	5	50	10	828	67690	\N	54.026673000000002	Иркутская область, город Саянск, микрорайон Строителей, дом №26, Детско-юношеская спортшкол		0101000020E610000060E811A3E7835940D65757056A034B40
36271	5	50	10	828	67693	\N	54.018667031840899	Иркутская область, город Саянск, микрорайон Олимпийский, школа №2	Россия, Иркутская область, Зиминский район, Саянск	0101000020E610000036CB65A373835940D94125AE63024B40
36260	5	50	10	828	67693	\N	54.026673000000002	Иркутская область, город Саянск, микрорайон Олимпийский, дом № 23, Спорткомплекс		0101000020E610000060E811A3E7835940D65757056A034B40
36261	5	50	10	828	68252	\N	54.026702859080601	Иркутская область, город Саянск, микрорайон Октябрьский, школа №7	Россия, Иркутская область, Зиминский район, Саянск	0101000020E61000005F09A4C4AE82594040DAFF006B034B40
36270	5	50	10	828	68939	\N	54.026673000000002	"Иркутская область, город Саянск, микрорайон Молодежный, дом №2, Клуб ""Вертикаль"""		0101000020E610000060E811A3E7835940D65757056A034B40
36266	5	50	10	828	67889	\N	54.026673000000002	"Иркутская область, город Саянск, микрорайон Мирный, дом №2, клуб ""Пилигрим"""		0101000020E610000060E811A3E7835940D65757056A034B40
36267	5	50	10	828	67884	\N	54.028875802282499	Иркутская область, город Саянск, микрорайон Ленинградский, дом №2, ф-л Центральной библиотеки	Россия, Иркутская область, Зиминский район, Саянск	0101000020E6100000FF3EE3C281825940D4D17135B2034B40
35593	5	50	10	552	68556	\N	53.850056000000002	Иркутская область, Зиминское районное муниципальное образование, Услонское муниципальное образование, с.Самара, Черемушки, 2		0101000020E610000019E59997C380594061E28FA2CEEC4A40
35586	5	50	10	12	69495	\N	54.104492	Иркутская область, Зиминское районное муниципальное образование, Кимильтейское муниципальное образование, с.Перевоз, Молодежная, 7		0101000020E610000024D40CA9A2825940C9586DFE5F0D4B40
35587	5	50	10	12	69606	\N	54.106191527535003	Иркутская область, Зиминское районное муниципальное образование, Кимильтейское муниципальное образование, ж\\д ст. Перевоз, Вокзальная, 2	Россия, Иркутская область, Зиминский район, поселок Перевоз	0101000020E61000008E59F624B0825940658C0FB3970D4B40
35595	5	50	10	678	69310	\N	53.961699000000003	Иркутская область, Зиминское районное муниципальное образование, Ухтуйское муниципальное образование, с.Норы, Солнечная, 11		0101000020E61000001BF164373388594047CCECF318FB4A40
35590	5	50	10	338	69188	\N	53.619550434600001	Иркутская область, Зиминское районное муниципальное образование, Новолетниковское муниципальное образование, с Новолетники, Центральная, 60	Россия, Иркутская область, Зиминский район, поселок Новолетники	0101000020E6100000284701A2607659404F1E166A4DCF4A40
35597	5	50	10	806	69194	\N	53.980812999999998	Иркутская область, Зиминское районное муниципальное образование, Ухтуйское муниципальное образование, с. Мордино, Школьная, 3		0101000020E61000009A22C0E95D855940EE3EC7478BFD4A40
35588	5	50	10	202	68539	\N	53.575459330155297	Иркутская область, Зиминское районное муниципальное образование, Масляногорское муниципальное образование, с.Масляногорск, Полевая, 20	Россия, Иркутская область, Зиминский район, поселок Масляногорск	0101000020E610000063D520CCED6C59402D98F8A3A8C94A40
35584	5	50	10	32420	67912	\N	54.132508999999999	Иркутская область, Зиминское районное муниципальное образование, Кимильтейское муниципальное образование, с.Кимильтей, Чкалова, 70		0101000020E6100000B2D5E594807E59407CB60E0EF6104B40
36005	5	50	10	32420	69367	\N	54.136954700779	Иркутская область, Куйтунский район, ж/д станция Кимильтей, Вокзальная, помещение здания ж/д вокзала	Россия, Иркутская область, Зиминский район, поселок Кимильтей	0101000020E61000001538D906EE7E59400803CFBD87114B40
39258	3	24	459	19119	59143	\N	64.289468999999997	п.Летнереченский, ул.Школьная, д.19		0101000020E61000000C76C3B6453141402C0DFCA886125040
35583	5	50	10	32382	69056	\N	53.684932000000003	Иркутская область, Зиминское районное муниципальное образование, Зулумайское муниципальное образование, с.Зулумай, Центральная, 33-1		0101000020E6100000E1455F419A545940F0FD0DDAABD74A40
35610	5	50	10	1273	68467	\N	53.913210016871602	Иркутская область, Зиминское городское муниципальное образование, Трактовая, 2	Россия, Иркутская область, Зиминский район, Зима	0101000020E6100000A20C553195835940A930B610E4F44A40
35607	5	50	10	1273	68325	\N	53.921345558353003	Иркутская область, Зиминское городское муниципальное образование, Садовая, 43	Россия, Иркутская область, Зиминский район, Зима	0101000020E6100000632AFD84B381594074266DAAEEF54A40
35608	5	50	10	1273	68329	\N	53.913840261809497	Иркутская область, Зиминское городское муниципальное образование, Орджоникидзе, 49	Россия, Иркутская область, Зиминский район, Зима	0101000020E6100000A60A46257583594069E388B5F8F44A40
35605	5	50	10	1273	42049	\N	53.914726999999999	Иркутская область, город Зима, Куйбышева, 13		0101000020E61000006347E350BF83594054E23AC615F54A40
35611	5	50	10	1273	68498	\N	53.913210016871602	Иркутская область, Зиминское городское муниципальное образование, Кирова, 12	Россия, Иркутская область, Зиминский район, Зима	0101000020E6100000B51666A19D835940A930B610E4F44A40
35616	5	50	10	1273	68320	\N	53.913007323001402	Иркутская область, Зиминское городское муниципальное образование, Бограда, 59	Россия, Иркутская область, Зиминский район, Зима	0101000020E61000009F3C2CD49A8359407102D369DDF44A40
35613	5	50	10	1273	68507	\N	53.911081681937503	Иркутская область, Зиминское городское муниципальное образование, Ангарская, 6	Россия, Иркутская область, Зиминский район, Зима	0101000020E6100000B51666A19D835940B5FCC0559EF44A40
35598	5	50	10	835	69049	\N	53.859583999999998	Иркутская область, Зиминское районное муниципальное образование, Ухтуйское муниципальное образование, с.Глинки, Центральная, 59		0101000020E610000034F5BA45609059401A1538D906EE4A40
35589	5	50	10	303	69047	\N	53.466126000000003	Иркутская область, Зиминское районное муниципальное образование, Масляногорское муниципальное образование, с Верхнеокинский, Школьная, 10		0101000020E610000034A0DE8C9A5459405CE84A04AABB4A40
35580	5	50	10	32257	69179	\N	54.274439000000001	Иркутская область, Зиминское районное муниципальное образование, Буринское муниципальное образование, с.Буря, Центральная, 53		0101000020E610000053B29C84D29259409CDF30D120234B40
35601	5	50	10	59283	69536	\N	53.943137999999998	Иркутская область, Зиминское районное муниципальное образование, Филлиповское муниципальное образование, уч.Большеворонежский, Молодежная, 1	Россия, Иркутская область, Зиминский район, поселок Большеворонежский	0101000020E61000008C0FB3976D9C5940B3CEF8BEB8F84A40
35577	5	50	10	32132	68551	\N	53.872815000000003	Батаминское муниципальное образование, Зиминское районное муниципальное образование, Иркутская область, с.Батама, Ленина, 40		0101000020E6100000F0FCA204FD675940A83AE466B8EF4A40
35578	5	50	10	32169	69499	\N	53.784559999999999	Иркутская область, Зиминское районное муниципальное образование, Батаминское муниципальное образование, Басалаевка, Речная, 62		0101000020E6100000F0879FFF1E635940F8DF4A766CE44A40
35585	5	50	10	32486	69182	\N	54.211492	Иркутская область, Зиминское районное муниципальное образование, Кимильтейское муниципальное образование, с.Баргадай, Школьная, 20		0101000020E610000050A73CBA11845940CDAE7B2B121B4B40
35551	5	50	350	30900	69173	\N	53.413040000000002	Иркутская область, Заларинский район, д.Щербакова, Набережная, 10		0101000020E61000006347E350BF8359404DF8A57EDEB44A40
35560	5	50	350	31329	69042	\N	53.285755000000002	Иркутская область, Заларинский район, с.Черемшанка, Советская, 37		0101000020E61000001D007157AF69594091D5AD9E93A44A40
35556	5	50	350	31137	69170	\N	53.366987000000002	Иркутская область, Заларинский район, д.Чаданова, Трактовая, 10		0101000020E61000002E724F57778359405187156EF9AE4A40
35562	5	50	350	31441	68670	\N	53.419690000000003	Иркутская область, Заларинский район, с.Хор-Тагна, Леспромхозовская, 6		0101000020E61000004B581B6327635940A83AE466B8B54A40
35547	5	50	350	30690	68811	\N	53.491740999999998	Иркутская область, Заларинский район, с.Холмогой, Юбилейная, 1		0101000020E610000010EA2285B2935940198D7C5EF1BE4A40
35568	5	50	350	31720	68672	\N	53.618642999999999	Иркутская область, Заларинский район, с.Ханжиново, пер.Солнечный, 2		0101000020E6100000F4A96395D28E59401D739EB12FCF4A40
35555	5	50	350	59279	69528	\N	53.343294058168802	Иркутская область, Заларинский район, уч.Халты, Дудкина, 6	Россия, Иркутская область, Заларинский район, поселок Халты	0101000020E6100000E607AEF204885940DE74CB0EF1AB4A40
35570	5	50	350	31811	69175	\N	53.720022	Иркутская область, Заларинский район, д.Тыреть вторая, Верхняя, 9		0101000020E61000007EAB75E27294594044334FAE29DC4A40
35572	5	50	350	1871	67986	\N	53.670372	Иркутская область, Заларинский район, п.Тыреть, микр.Солерудник, 9		0101000020E6100000C478CDAB3A945940BA13ECBFCED54A40
35573	5	50	350	59132	68125	\N	53.670372	Иркутская область, Заларинский район, п.Тыреть, ул. Школьная, 55		0101000020E6100000C478CDAB3A945940BA13ECBFCED54A40
35549	5	50	350	30803	68671	\N	53.463059999999999	Иркутская область, Заларинский район, с.Троицк, Ленина, 35		0101000020E6100000B7B75B92038A5940FA0AD28C45BB4A40
35563	5	50	350	31499	69044	\N	53.587814000000002	Иркутская область, Заларинский район, д.Тагна, Дорожная, 24		0101000020E61000002C6519E258785940C310397D3DCB4A40
35561	5	50	350	59320	69583	\N	53.3803424089731	Иркутская область, Заларинский район, уч.Средне-Пихтинский, Центральная, 22	Россия, Иркутская область, Заларинский район, поселок Среднепихтинский	0101000020E610000078962023A06A5940CAA5F10BAFB04A40
35546	5	50	350	30636	69252	\N	53.560775999999997	Иркутская область, Заларинский район, д.Сенная Падь, Центральная, 27		0101000020E61000005D177E703E955940DB300A82C7C74A40
35575	5	50	350	32036	69043	\N	53.736089	Иркутская область, Заларинский район, с.Семеновское, Ленина, 1а		0101000020E6100000B45BCB6438A0594001F9122A38DE4A40
35545	5	50	350	30586	69019	\N	53.512093	Иркутская область, Заларинский район, д.Романова, Школьная, 8		0101000020E61000008D9AAF928F97594059C16F438CC14A40
35553	5	50	350	30996	69125	\N	53.395603999999999	Иркутская область, Заларинский район, д.Романенкина, Центральная, 32		0101000020E6100000728BF9B9A19659405915E126A3B24A40
35544	5	50	350	59277	69526	\N	53.395952999999999	Иркутская область, Заларинский район, уч.Ремезовский, Центральная, 24	Россия, Иркутская область, Заларинский район, поселок Ремезовский	0101000020E61000004A5E9D6340A2594065E08096AEB24A40
35543	5	50	350	30489	69248	\N	53.402917000000002	Иркутская область, Заларинский район, с.Новочеремхово, Центральная, 12		0101000020E61000000726378AAC9D59405000C5C892B34A40
35567	5	50	350	59207	69060	\N	53.636029999999998	Иркутская область, Заларинский район, уч.Николаевский, пер.Верхний, 5	Россия, Иркутская область, Заларинский район, поселок Николаевский	0101000020E6100000E789E76C018959402FA3586E69D14A40
35557	5	50	350	1762	69127	\N	53.345779	Иркутская область, Заларинский район, д.Муруй, Центральная, школа		0101000020E610000051A1BAB9F880594061527C7C42AC4A40
35554	5	50	350	31041	69041	\N	53.340533000000001	Иркутская область, Заларинский район, с.Мойган, Центральная, 25		0101000020E61000005436ACA92C8F5940B91AD99596AB4A40
35565	5	50	350	31589	68770	\N	53.526376999999997	Иркутская область, Заларинский район, с.Моисеевка, Школьная, 2		0101000020E61000008FAB915D69805940EC2E505260C34A40
35542	5	50	350	30430	69045	\N	53.509785000000001	Иркутская область, Заларинский район, д.Минеева, пер.Клубный, 1		0101000020E6100000259012BBB69F5940E57E87A240C14A40
35574	5	50	350	59268	69508	\N	53.712520175781599	Иркутская область, Заларинский район, уч.Мейеровка, Олейникова, 4	Россия, Иркутская область, Заларинский район, поселок Мейеровка	0101000020E6100000F12C4146409A59407ADFF8DA33DB4A40
35504	5	50	350	28658	69322	\N	53.620742	Иркутская область, Заларинский район, д.Красное Поле, Механизаторов, 24		0101000020E61000004D4D8237A4A4594077A04E7974CF4A40
35576	5	50	350	1962	68954	\N	53.721747999999998	Иркутская область, Заларинский район, д.Корсунгай, Ербанова, школа		0101000020E6100000E4BCFF8F139E594009FA0B3D62DC4A40
35541	5	50	350	30390	69012	\N	53.556401000000001	Иркутская область, Заларинский район, с.Илганское, Центральная, 2		0101000020E61000000F5F268A909B5940193BE12538C74A40
35536	5	50	350	30085	67917	\N	53.556037000000003	Иркутская область, Заларинский район, п.Залари, Победы, 50		0101000020E6100000D38558FD11A05940D82E6D382CC74A40
35539	5	50	350	30085	68189	\N	53.556037000000003	Иркутская область, Заларинский район, п.Залари, Ленина, 15		0101000020E6100000D38558FD11A05940D82E6D382CC74A40
35538	5	50	350	30085	68189	\N	53.556037000000003	Иркутская область, Заларинский район, п.Залари, Ленина, 76		0101000020E6100000D38558FD11A05940D82E6D382CC74A40
35535	5	50	350	30085	68187	\N	53.556037000000003	Иркутская область, Заларинский район, п.Залари, Лазо, 1		0101000020E6100000D38558FD11A05940D82E6D382CC74A40
35550	5	50	350	30851	69174	\N	53.435756662820303	Иркутская область, Заларинский район, д.Заблагар, Набережная, 1	Россия, Иркутская область, Заларинский район, поселок Заблагар	0101000020E6100000F8A92A34108759406500A8E2C6B74A40
35559	5	50	350	31289	69177	\N	53.305168000000002	Иркутская область, Заларинский район, д.Жизневка, Юбилейная, 5		0101000020E6100000B87878CF8188594093E4B9BE0FA74A40
35552	5	50	350	30953	69491	\N	53.3821702721918	Иркутская область, Заларинский район, д.Дмитриевка, Центральная, 13	Россия, Иркутская область, Заларинский район, поселок Дмитриевка	0101000020E6100000EA758BC05882594094C151F2EAB04A40
35442	5	50	350	2351	68547	\N	53.475440999999996	Иркутская область, Заларинский район, с.Владимир, ул.Школьная,23		0101000020E610000030478FDFDBA95940B9162D40DBBC4A40
35569	5	50	350	31783	68901	\N	53.684047	Иркутская область, Заларинский район, с.Веренка, Новая, 2		0101000020E6100000BC749318048E5940A5F622DA8ED74A40
35566	5	50	350	31645	69251	\N	53.548200363154798	Иркутская область, Заларинский район, д.Большая Заимка, Первомайская, здание Дома Досуга	Россия, Иркутская область, Заларинский район, поселок Большая Заимка	0101000020E610000042EDB776A289594067D5E76A2BC64A40
35564	5	50	350	1841	69131	\N	53.505077999999997	Иркутская область, Заларинский район, д.Благодатный, Ветеранов.42		0101000020E61000003FFD67CD8F7D5940ECF65965A6C04A40
35540	5	50	350	30343	69008	\N	53.590310000000002	Иркутская область, Заларинский район, с.Бажир, Юбилейная, 14		0101000020E61000003FFF3D78EDA259403A4030478FCB4A40
35558	5	50	350	31225	69176	\N	53.270927	Иркутская область, Заларинский район, с.Бабагай, пер.Школьный, 4		0101000020E61000002E55698B6B8659403C4D66BCADA24A40
35522	5	50	426	59289	69545	\N	54.891838491945002	"Иркутская область, муниципальное образование ""Жигаловский район"", Лукиновское муниципальное образование, с.Луконово, Полевая, 17"	Россия, Иркутская область, Жигаловский район	0101000020E61000007E8D2441B8665A403FAA61BF27724B40
35514	5	50	426	52562	69002	\N	54.823004202807297	"Иркутская область, муниципальное образование ""Жигаловский район"", Чиканское муниципальное образование, д.Якимовка, Центральная, 29"	Россия, Иркутская область, Жигаловский район, поселок Якимовка	0101000020E6100000BC77D49810575A40143DF03158694B40
35513	5	50	426	52558	69239	\N	54.902982000000002	"Иркутская область, муниципальное образование ""Жигаловский район"", Чиканское муниципальное образование, с.Чикан, Школьная, 1"		0101000020E61000003946B247A8695A40377007EA94734B40
35428	5	50	402	25189	68150	\N	56.193106	Иркутская область, Братский район, п. Турма, улица Гагарина, дом 26		0101000020E610000091B75CFDD8385940A85489B2B7184C40
35528	5	50	426	52585	68972	\N	55.008412999999997	"Иркутская область, муниципальное образование ""Жигаловский район"", Усть-Илгинское муниципальное образование, с.Усть-Илга, Молодёжная, 2"		0101000020E61000008753E6E61B455A403DEE5BAD13814B40
35519	5	50	426	52574	69484	\N	54.578155000000002	"Иркутская область, муниципальное образование ""Жигаловский район"", Дальне-Закорское муниципальное образование, д.Тыпта, Таежная, 23"		0101000020E6100000F06AB93313225A406B82A8FB004A4B40
35515	5	50	426	52564	69246	\N	54.784889	"Иркутская область, муниципальное образование ""Жигаловский район"", Тутурское муниципальное образование, с.Тутура, Кооперативная, 5"		0101000020E6100000ADDA3521AD4E5A40BDFE243E77644B40
35521	5	50	426	59301	69562	\N	54.392575000000001	"Иркутская область, муниципальное образование ""Жигаловский район"", Тимошинское муниципальное образование. с. Тимошино, Николаева, 3"	Россия, Иркутская область, Жигаловский район, поселок Тимошино	0101000020E61000008B36C7B94D2E5A40151DC9E53F324B40
35524	5	50	426	59267	69494	\N	54.750810999999999	"Иркутская область, муниципальное образование ""Жигаловский район"", Рудовское муниципальное образование. с.Рудовка, Школьная, 4"	Россия, Иркутская область, Жигаловский район, поселок Рудовка	0101000020E61000005CC64D0D344D5A40103D29931A604B40
35525	5	50	426	52582	69009	\N	54.659239999999997	"Иркутская область, муниципальное образование ""Жигаловский район"", Рудовское муниципальное образование, д.Пономарёва, Центральная, 31"		0101000020E61000002FA699EE754E5A40861BF0F961544B40
35527	5	50	426	52584	69493	\N	54.495835999999997	"Иркутская область, муниципальное образование ""Жигаловский район"", Петровское муниципальное образование, с.Петрово, Ленская, 50"		0101000020E610000012D89C83674E5A40F816D68D773F4B40
35517	5	50	426	52568	69486	\N	54.738567000000003	"Иркутская область, муниципальное образование ""Жигаловский район"", Знаменское муниципальное образование, д.Нижняя Слобода, Центральная, 2"		0101000020E6100000D47FD6FCF83A5A40D2730B5D895E4B40
35512	5	50	426	52554	69488	\N	55.356887	"Иркутская область, муниципальное образование ""Жигаловский район"", Коношановское муниципальное образование, с.Коношаново, Ленская, 26"		0101000020E6100000CA1AF5108D5E5A400CAF2479AEAD4B40
35520	5	50	426	52577	69487	\N	54.610146999999998	"Иркутская область, муниципальное образование ""Жигаловский район"", Дальне-Закорское муниципальное образование, с.Качень, Речная, 4"		0101000020E61000000E65A88AA9315A405260014C194E4B40
35516	5	50	426	52233	68545	\N	54.697556699845997	"""Иркутская область, муниципальное образование """"Жигаловский район"""", Знаменское муниципальное образование, с.Знаменка,ул. Магистральная, 79 "	Россия, Иркутская область, Жигаловский район, поселок Знаменка	0101000020E61000000056478E74355A40460C3B8C49594B40
35534	5	50	426	52587	69571	\N	54.804322877642598	"Иркутская область, муниципальное образование ""Жигаловский район"", Жигаловское муниципальное образование. п.Жигалово, Сосновая, 1"		0101000020E6100000B537F8C2644A5A40D6355A0EF4664B40
35531	5	50	426	52587	68855	\N	54.811793000000002	"Иркутская область, муниципальное образование ""Жигаловский район"", Жигаловское муниципальное образование, п. Жигалово, Советская, 11"		0101000020E61000003F1D8F19A8495A40950F41D5E8674B40
35530	5	50	426	52587	68689	\N	54.811793000000002	"Иркутская область, муниципальное образование ""Жигаловский район"", Жигаловское муниципальное образование, п. Жигалово, Партизанская, 48"		0101000020E61000003F1D8F19A8495A40950F41D5E8674B40
35529	5	50	426	52587	68765	\N	54.811793000000002	"Иркутская область, муниципальное образование ""Жигаловский район"", Жигаловское муниципальное образование, п. Жигалово, Неугодниковская, 45"		0101000020E61000003F1D8F19A8495A40950F41D5E8674B40
35532	5	50	426	52587	68529	\N	54.811793000000002	"Иркутская область, муниципальное образование ""Жигаловский район"", Жигаловское муниципальное образование, п.Жигалово, Колчанова, 16"		0101000020E61000003F1D8F19A8495A40950F41D5E8674B40
35518	5	50	426	52570	69004	\N	54.657553	"Иркутская область, муниципальное образование ""Жигаловский район"", Дальне-Закорское муниципальное образование, с.Дальняя Закора, Школьная, 4"		0101000020E6100000029B73F04C2F5A407F315BB22A544B40
35523	5	50	426	52580	69247	\N	54.770287000000003	"Иркутская область, муниципальное образование ""Жигаловский район"", Рудовское муниципальное образование, д.Головновка, Центральная, 16"		0101000020E6100000B2F336363B4E5A4059C4B0C398624B40
35526	5	50	426	52583	69181	\N	54.580205999999997	"Иркутская область, муниципальное образование ""Жигаловский район"", Петровское муниципальное образование, д.Воробьёва, Таежная, 38"		0101000020E61000009E23F25D4A4E5A40B378B130444A4B40
35492	5	50	402	54497	67910	\N	56.301948000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Наймушина, 26А		0101000020E610000023A298BC01705940DB8B683BA6264C40
35484	5	50	402	54497	37452	\N	56.301948000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Зверева, 7		0101000020E610000023A298BC01705940DB8B683BA6264C40
35410	5	50	402	2197	68842	\N	55.947842000000001	Иркутская область, Братский район, п. Шумилово, улица Гагарина,2		0101000020E6100000A29A92ACC3C059403BE3FBE252F94B40
35399	5	50	402	23799	69480	\N	55.469524999999997	Иркутская область, Братский район, д. Худобок, улица Центральная, дом 39в		0101000020E610000014B4C9E193375940C3D32B6519BC4B40
35393	5	50	402	23515	69482	\N	55.333134000000001	Иркутская область, Братский район, с. Тэмь, улица Ленина, дом 24		0101000020E6100000DA0242EBE12E5940C4978922A4AA4B40
35420	5	50	402	24845	68764	\N	55.981313	Иркутская область, Братский район, п. Тарма, улица 1-ая Нагорная, дом 16		0101000020E61000006C223317B8525940E01115AA9BFD4B40
35395	5	50	402	23644	67846	\N	55.380426	Иркутская область, Братский район, с. Тангуй, улица Ленина, дом 54		0101000020E610000051C1E10511425940284696CCB1B04B40
35401	5	50	402	23890	69168	\N	55.544055999999998	Иркутская область, Братский район, п. Сосновый, улица Школьная, дом 1	Россия, Иркутская область, Братский район, поселок Сосновый	0101000020E6100000799274CDE4455940A69883A0A3C54B40
35389	5	50	402	23350	68146	\N	55.207593000000003	Иркутская область, Братский район, п. Прибрежный, периулок Школьный, дом 4		0101000020E6100000D8101C97712C594074F04C68929A4B40
35400	5	50	402	23848	68156	\N	55.522097000000002	Иркутская область, Братский район, с. Покосное, улица Сибирская, дом 22		0101000020E61000000B9755D80C4359407C2B1213D4C24B40
35388	5	50	402	23273	69350	\N	55.079782000000002	Иркутская область, Братский район, д. Новое Приречье, улица Новая, дом 7		0101000020E610000080EECB99ED4359409D67EC4B368A4B40
35419	5	50	402	24793	69169	\N	55.849043999999999	Иркутская область, Братский район, п. Новодолоново, улица Лесная, дом 1		0101000020E6100000C426327381635940B96E4A79ADEC4B40
35436	5	50	402	25571	69171	\N	56.581536999999997	Иркутская область, Братский район, п. Мамырь, улица Центральная, дом 2		0101000020E6100000AF7B2B1213AA5940FC34EECD6F4A4C40
35392	5	50	402	23482	68956	\N	55.253090999999998	Иркутская область, Братский район, п. Луговой, улица Таежная, 5		0101000020E61000000EBBEF181E1F5940BAF42F4965A04B40
35416	5	50	402	24661	69030	\N	55.5633002092978	Иркутская область, Братский район, д. Леонова, улица Кооперативная, дом 21	Россия, Иркутская область, Братский район, поселок Леонова	0101000020E6100000F7AB00DF6D6059401CEBE2361AC84B40
35415	5	50	402	24598	69483	\N	55.533999999999999	Иркутская область, Братский район, д. Кумейка, улица Школьная, дом 1		0101000020E61000009C86A8C29F7159403108AC1C5AC44B40
35421	5	50	402	24897	68763	\N	56.087142	Иркутская область, Братский район, с. Кузнецовка, улица Почтовая, дом 19		0101000020E61000000B7E1B62BC4F5940D40D1478270B4C40
35413	5	50	402	24517	68852	\N	55.501814000000003	Иркутская область, Братский район, д. Куватка, улица Лесная, дом 4а		0101000020E6100000A62A6D718D7D59406556EF703BC04B40
35402	5	50	402	23947	69267	\N	55.434992999999999	Иркутская область, Братский район, с. Кобь, улица Школьная,1		0101000020E61000006473D53C47575940957EC2D9ADB74B40
35429	5	50	402	25211	68786	\N	56.587451000000001	Иркутская область, Братский район, с. Кобляково, улица Сазонова, дом 8		0101000020E6100000514A0856D55B594052802898314B4C40
35414	5	50	402	24534	67848	\N	55.522041000000002	Иркутская область, Братский район, с. Ключи-Булак, улица Ленина, дом 2		0101000020E610000034677DCA316C5940E8154F3DD2C24B40
35435	5	50	402	25510	68151	\N	56.557017999999999	Иркутская область, Братский район, п. Кежемский, улица Октябрьская, дом 7		0101000020E610000016A1D80A9A9C594044A4A65D4C474C40
35391	5	50	402	23435	69026	\N	55.214475999999998	Иркутская область, Братский район, д. Кардой, улица Трактовая, дом 56		0101000020E61000009C6B98A1F124594071E316F3739B4B40
35417	5	50	402	24697	68051	\N	55.678037000000003	"Иркутская область, Братский район, с. Калтук, улица Погодаева, дом 12 ""б"""		0101000020E61000003140A209146F59402E3D9AEAC9D64B40
35390	5	50	402	23368	68761	\N	55.223560999999997	Иркутская область, Братский район, с. Илир, улица Кирова, дом 14		0101000020E6100000D53DB2B96A2B59409DD497A59D9C4B40
35433	5	50	402	25439	69037	\N	56.379102000000003	Иркутская область, Братский район, п. Зяба, улица Кооперативная, дом 3а		0101000020E61000002C62D8614C88594092EC116A86304C40
35397	5	50	402	23726	69342	\N	55.446472999999997	Иркутская область, Братский район, с. Зарбь, улица Центральная, дом 56		0101000020E610000060ADDA352142594004C6FA0626B94B40
35432	5	50	402	25355	69492	\N	56.607362000000002	Иркутская область, Братский район, с. Дубынино, улица Центральная, дом 26а		0101000020E610000034D593F947725940A56ABB09BE4D4C40
35951	5	50	402	59228	\N	\N	55.436641999999999	Иркутская область, муниципальное образование - Киренский район, Киренское муниципальное образование, город Киренск, д.Воронино, сельский клуб	Россия, Иркутская область, Братский район	0101000020E6100000EF703B342C9D5940AF0793E2E3B74B40
94942	5	50	402	2232	68153	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Школьная,9		0101000020E610000019709692E54A5940081EDFDE35104C40
94944	5	50	402	2232	67650	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Пионерская,18		0101000020E610000019709692E54A5940081EDFDE35104C40
36835	5	50	402	2232	67650	\N	56.126643999999999	"Иркутская область, Братский район, г. Вихоревка, улица Пионерская, дом 35,школа ""10"		0101000020E610000019709692E54A5940081EDFDE35104C40
36834	5	50	402	2232	67650	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Пионерская, дом 18,школа №2		0101000020E610000019709692E54A5940081EDFDE35104C40
36836	5	50	402	2232	68078	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Октябрьская,7,ДШИ		0101000020E610000019709692E54A5940081EDFDE35104C40
94943	5	50	402	2232	68105	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Ленина 35		0101000020E610000019709692E54A5940081EDFDE35104C40
36833	5	50	402	2232	68105	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Ленина 21,помещение РЖД		0101000020E610000019709692E54A5940081EDFDE35104C40
94945	5	50	402	2232	68015	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Дзержинского,101		0101000020E610000019709692E54A5940081EDFDE35104C40
35437	5	50	402	2232	68015	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица Дзержинского, дом 101, школа		0101000020E610000019709692E54A5940081EDFDE35104C40
35422	5	50	402	2232	67998	\N	56.126643999999999	Иркутская область, Братский район, г. Вихоревка, улица 35лет Победы, дом15а		0101000020E610000019709692E54A5940081EDFDE35104C40
35344	5	50	402	59266	69479	\N	55.436641999999999	Иркутская область, муниципальное образование города Бодайбо и района, Балахнинское муниципальное образование, поселок Васильевский, улица Ленских Событий, 42	Россия, Иркутская область, Братский район	0101000020E6100000EF703B342C9D5940AF0793E2E3B74B40
35431	5	50	402	25350	69481	\N	56.363384000000003	Иркутская область, Братский район, п. Бурнинская Вихоря, улица Первомайская, дом 18		0101000020E6100000F67EA31D37665940E1F1ED5D832E4C40
35438	5	50	402	2114	68316	\N	56.282635019627897	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Порожский, 50 лет Октября, 112	Россия, Иркутская область, Братский район, Братск	0101000020E61000009FAD8383BD7759403CDA38622D244C40
35473	5	50	402	2114	68318	\N	56.279197000000003	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Чекановский, Школьная, 19	Россия, Иркутская область, Братский район, Братск	0101000020E6100000B534B74258775940171230BABC234C40
35443	5	50	402	2114	67873	\N	56.277751932529199	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Снежная, 2	Россия, Иркутская область, Братский район, Братск	0101000020E610000094C151F2EA7859400533A6608D234C40
35476	5	50	402	2114	68301	\N	56.290655042535803	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Падун, Пролетарская, 50	Россия, Иркутская область, Братский район, Братск	0101000020E61000007FF62345646B59409EB5DB2E34254C40
35487	5	50	402	2114	68321	\N	56.2830040023686	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Приморская, 9А	Россия, Иркутская область, Братский район, Братск	0101000020E61000005FB2F1608B7759408F519E7939244C40
35491	5	50	402	2114	67684	\N	56.301947956716397	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Погодаева, 13/15	Россия, Иркутская область, Братский район, Братск	0101000020E6100000FB78E8BB5B705940DB8B683BA6264C40
35447	5	50	402	2114	68292	\N	56.282654695067698	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Пионерская, 13Б	Россия, Иркутская область, Братский район, Братск	0101000020E6100000C74ACCB3927759408386FE092E244C40
35483	5	50	402	2114	67883	\N	56.300802868870903	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Олимпийская, 17	Россия, Иркутская область, Братский район, Братск	0101000020E6100000F8A8BF5E61705940F4C473B680264C40
35482	5	50	402	2114	67883	\N	56.300993750305999	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Олимпийская, 25	Россия, Иркутская область, Братский район, Братск	0101000020E6100000BC22F8DF4A7059406825ADF886264C40
35488	5	50	402	2114	67898	\N	56.301948000000003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Энергетик, Наймушина, 18А		0101000020E610000023A298BC01705940DB8B683BA6264C40
35453	5	50	402	2114	68207	\N	56.283398904120602	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Курчатова, 54	Россия, Иркутская область, Братский район, Братск	0101000020E610000051853FC39B7759400C5C1E6B46244C40
35467	5	50	402	2114	67655	\N	56.284162773289303	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Крупской, 39	Россия, Иркутская область, Братский район, Братск	0101000020E6100000DB334B02D4775940DBDD03745F244C40
35465	5	50	402	2114	67655	\N	56.269851000000003	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Крупской, 5	Россия, Иркутская область, Братский район, Братск	0101000020E6100000685A6265346A59407EE5417A8A224C40
35461	5	50	402	2114	67027	\N	56.2843885183119	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Комсомольская,75	Россия, Иркутская область, Братский район, Братск	0101000020E6100000BE141E34BB775940CB2BD7DB66244C40
35441	5	50	402	2114	67876	\N	56.303560490657397	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Кирова, 9	Россия, Иркутская область, Братский район, Братск	0101000020E6100000C7F5EFFACC6D5940D72FD80DDB264C40
35497	5	50	402	2114	67920	\N	56.273899999999998	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Заводская, 11Б		0101000020E6100000B39597FC4F795940EC2FBB270F234C40
35496	5	50	402	2114	67920	\N	56.273899999999998	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Заводская, 3Б		0101000020E6100000B39597FC4F795940EC2FBB270F234C40
35498	5	50	402	2114	67948	\N	56.2856334020763	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Енисейская, 66/7	Россия, Иркутская область, Братский район, Братск	0101000020E61000003ECDC98B4C78594045D4449F8F244C40
35511	5	50	402	2114	67689	\N	56.278899858866403	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Сухой, Еловая, 20	Россия, Иркутская область, Братский район	0101000020E6100000E3FA777DE67459405D6DC5FEB2234C40
35478	5	50	402	2114	68308	\N	56.281202694900003	Иркутская область, муниципальное образование города Братска, Падунский округ, жилой район Падун, Гидростроителей, 31	Россия, Иркутская область, Братский район, Братск	0101000020E61000003D9AEAC9FC775940BF44BC75FE234C40
35503	5	50	402	2114	68768	\N	56.276192118532599	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Гайнулина, 71	Россия, Иркутская область, Братский район, Братск	0101000020E6100000F030ED9BFB7859405BB56B425A234C40
35470	5	50	402	2114	67903	\N	56.270111265119397	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Гагарина, 16	Россия, Иркутская область, Братский район, Братск	0101000020E61000006EC2BD326F7859401AA54BFF92224C40
35463	5	50	402	2114	67903	\N	56.277784573693999	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Гагарина, 49	Россия, Иркутская область, Братский район, Братск	0101000020E6100000F833BC59836A5940E12879758E234C40
35446	5	50	402	2114	68169	\N	56.283603207055897	Иркутская область, муниципальное образование города Братска, Центральный округ, жилой район Центральный, Верхняя, 30А	Россия, Иркутская область, Братский район, Братск	0101000020E6100000AA2B9FE5797759401406651A4D244C40
35501	5	50	402	2114	67922	\N	56.273899999999998	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Гидростроитель, Байкальская, 43		0101000020E6100000B39597FC4F795940EC2FBB270F234C40
35507	5	50	402	2114	67905	\N	56.269851000000003	Иркутская область, муниципальное образование города Братска, Правобережный округ, жилой район Осиновка, Ангарстроя, 11	Россия, Иркутская область, Братский район, Братск	0101000020E6100000685A6265346A59407EE5417A8A224C40
35434	5	50	402	25487	69038	\N	56.489362	Иркутская область, Братский район, п. Боровской, улица Школьная, дом 1		0101000020E6100000DB166536C88A5940DCF3FC69A33E4C40
35418	5	50	402	24754	68536	\N	55.743811000000001	Иркутская область, Братский район, с. Большеокинское, улица Первомайская, дом 4		0101000020E61000008BFED0CC936F5940D9B3E73235DF4B40
35394	5	50	402	23584	69373	\N	55.369055000000003	Иркутская область, Братский район, д. Барчим, улица Мира, дом 38а		0101000020E6100000DFE2E13D0733594070B6B9313DAF4B40
35396	5	50	402	23657	69344	\N	55.398502999999998	"Иркутская область, Братский район, д. Бада, улица Пионерская, дом 3 ""а"" (здание начальная школа)"		0101000020E6100000255CC823B8495940CF2D742502B34B40
35398	5	50	402	23769	69166	\N	55.423678000000002	Иркутская область, Братский район, с. Александровка, улица Советская, дом 16		0101000020E6100000A9D898D7113B59407104A9143BB64B40
35376	5	50	441	59295	69554	\N	53.105069919987301	Иркутская область, Боханский район, д. Баргазово, Дорожная, 1	Россия, Иркутская область, Боханский район	0101000020E61000002C64AE0CAA025A4036E50AEF728D4A40
35358	5	50	441	21949	69338	\N	53.159194999999997	Иркутская область, Боханский район, д. Шунта, Депутатская, 1		0101000020E6100000D9092FC1A9F45940E657738060944A40
35341	5	50	441	21150	\N	\N	53.112022000000003	Иркутская область, Боханский район, д. Чилим, Школьная, 16	Россия, Иркутская область, Боханский район, поселок Чилим	0101000020E6100000B01BB62DCA115A405D37A5BC568E4A40
35356	5	50	441	21857	68548	\N	53.161900000000003	Иркутская область, Боханский район, с. Хохорск, Ленина, 8		0101000020E6100000397F130A11FB5940789CA223B9944A40
35357	5	50	441	21877	69178	\N	53.151893999999999	Иркутская область, Боханский район, д. Харатирген, Ленина, 49		0101000020E6100000DC4944F817F85940B43A394371934A40
35353	5	50	441	21709	69474	\N	53.171340999999998	Иркутская область, Боханский район, д. Харагун, Школьная, 9		0101000020E610000009A69A594B135A4062BB7B80EE954A40
35365	5	50	441	22281	69339	\N	53.167605999999999	Иркутская область, Боханский район, д. Хандагай, Комсомольская, 18		0101000020E6100000AA29C93A1CE85940834E081D74954A40
35006	5	50	441	4611	68833	\N	53.143765999999999	Иркутская область, Боханский район, с. Укыр, Школьная, 24		0101000020E6100000CEFA9463B2085A406C239EEC66924A40
35381	5	50	441	22968	69164	\N	53.219321999999998	Иркутская область, Боханский район, д. Угольная, Школьная, 3		0101000020E61000008AC91B60E6D959408BA548BE129C4A40
35252	5	50	441	16487	68100	\N	53.174888000000003	Иркутская область, Боханский район, с. Тихоновка, Ленина, 13		0101000020E6100000C1560916870E5A403F3BE0BA62964A40
35366	5	50	441	22326	68654	\N	53.085808999999998	Иркутская область, Боханский район, с. Тараса, Ленина, 17		0101000020E61000000EDC813AE5F15940EA5910CAFB8A4A40
35387	5	50	441	2543	68990	\N	53.440544000000003	Иркутская область, Боханский район, с. Середкино, Ленина,2		0101000020E610000029B000A60CDA59407A39ECBE63B84A40
35355	5	50	441	21803	69165	\N	53.132330000000003	Иркутская область, Боханский район, д. Русиновка, Ключевая, 5		0101000020E6100000EC6B5D6A84FE5940CD237F30F0904A40
35181	5	50	441	13089	69331	\N	53.065100000000001	Иркутская область, Боханский район, д. Петрограновка, Лесная, 44		0101000020E61000002BDB87BCE50B5A401C7C613255884A40
35369	5	50	441	22445	68145	\N	52.903604000000001	Иркутская область, Боханский район, с. Олонки, Калинина, 5		0101000020E61000009D67EC4B36ED59407444BE4BA9734A40
35367	5	50	441	22372	69514	\N	53.108432999999998	Иркутская область, Боханский район, д. Новый Алендарь, Школьная, 1		0101000020E610000097395D1613EB59405167EE21E18D4A40
35354	5	50	441	59316	69584	\N	53.150807197719601	Иркутская область, Боханский район, д. Новоскресенка, Ленина, 15		0101000020E6100000C57421567F015A400281CEA44D934A40
35364	5	50	441	22209	68854	\N	53.176205000000003	Иркутская область, Боханский район, с. Новая Ида, Центральная, 44		0101000020E610000087C1FC1532EC59402332ACE28D964A40
35386	5	50	441	59298	69559	\N	53.384005000000002	Иркутская область, Боханский район, д. Мутиново, Полевая, 1	Россия, Иркутская область, Боханский район, поселок Мутинова	0101000020E610000018D2E1218CDF594010406A1327B14A40
35382	5	50	441	59235	69297	\N	53.196779967407799	Иркутская область, Боханский район, д. Морозово, Школьная, 10	Россия, Иркутская область, Боханский район, поселок Морозова	0101000020E6100000BDAB1E300FE15940E140481630994A40
35206	5	50	441	14273	\N	\N	53.133983000000001	Иркутская область, Боханский район, д. Манькова, Центральная, 23	Россия, Иркутская область, Боханский район, поселок Манькова	0101000020E6100000639AE95E27045A40289CDD5A26914A40
35383	5	50	441	59273	69515	\N	53.289200000000001	Иркутская область, Боханский район, д. Логаново, Трудовая, 26	Россия, Иркутская область, Боханский район, поселок Логанова	0101000020E610000020EF552B13E4594069006F8104A54A40
35384	5	50	441	59231	69264	\N	53.322657999999997	Иркутская область, Боханский район, д. Крюково, Кузнецовская, 36 (А)	Россия, Иркутская область, Боханский район, поселок Крюкова	0101000020E61000005D8C81751CE1594079E57ADB4CA94A40
35380	5	50	441	22908	68701	\N	53.163767002691102	Иркутская область, Боханский район, с. Каменка, Школьная, 1	Россия, Иркутская область, Боханский район, поселок Каменка	0101000020E61000002F6EA301BCD75940FF942A51F6944A40
35378	5	50	441	22823	69478	\N	53.078037000000002	Иркутская область, Боханский район, д. Калашникова, Школьная, 8		0101000020E61000009A0AF148BCD959406170CD1DFD894A40
35385	5	50	441	23152	68759	\N	53.336117999999999	Иркутская область, Боханский район, с. Казачье, Мира, 10		0101000020E6100000B22E6EA301DC594068CC24EA05AB4A40
35371	5	50	441	22534	69340	\N	52.967875999999997	Иркутская область, Боханский район, д. Захаровская, Трактовая, 9		0101000020E610000061FC34EECDEF5940A94A5B5CE37B4A40
35362	5	50	441	22122	69341	\N	53.175351999999997	Иркутская область, Боханский район, д. Заглик, Трактовая, 19		0101000020E610000013B69F8CF1EF5940E3A430EF71964A40
35352	5	50	441	21632	69014	\N	53.215246	Иркутская область, Боханский район, с. Дундай, Центральная, 32		0101000020E6100000705B5B785E165A40234C512E8D9B4A40
35377	5	50	441	59209	69070	\N	53.036433000000002	Иркутская область, Боханский район, д. Грязная, Пионерская, 3		0101000020E61000004CA7751BD4DC594062BF27D6A9844A40
35379	5	50	441	22877	69018	\N	53.231974999999998	Иркутская область, Боханский район, д. Гречехан, Колхозная, 12		0101000020E6100000EBE3A1EF6EE85940AB3E575BB19D4A40
35372	5	50	441	22563	69013	\N	52.900584000000002	Иркутская область, Боханский район, д. Грехневка, Школьная, 2		0101000020E61000007AFCDEA63FF1594083A6255646734A40
35373	5	50	441	22636	69020	\N	53.004263000000002	Иркутская область, Боханский район, д. Воробьевка, Школьная, 15		0101000020E6100000747D1F0E12EB59409BCAA2B08B804A40
35351	5	50	441	21610	69477	\N	53.242483999999997	Иркутская область, Боханский район, с. Вершина, Советская, 47		0101000020E61000009E4319AA621A5A40D1E638B7099F4A40
35375	5	50	441	2466	68615	\N	53.025115	Иркутская область, Боханский район, с. Буреть, Центральная, 27		0101000020E6100000AF5DDA7058E55940CCD1E3F736834A40
35368	5	50	441	2466	69501	\N	53.025115	Иркутская область, Боханский район, с. Красная Буреть, Мира, 26		0101000020E6100000AF5DDA7058E55940CCD1E3F736834A40
35363	5	50	441	22195	69161	\N	53.257143999999997	Иркутская область, Боханский район, д. Булык, Ленина, 10		0101000020E61000002A8C2D0439F459406A2E3718EAA04A40
35360	5	50	441	21976	68136	\N	53.154983840722402	Иркутская область, Боханский район, п. Бохан, Ленина, 50	Россия, Иркутская область, Боханский район, поселок Бохан	0101000020E6100000446E861BF0F159409EB30584D6934A40
35361	5	50	441	21976	69162	\N	53.145052	Иркутская область, Боханский район, п. Бохан, Киевская, 4		0101000020E6100000D41055F833F25940151C5E1091924A40
35374	5	50	441	22661	68754	\N	52.794269999999997	Иркутская область, Боханский район, с. Александровское, Дзержинского, 35		0101000020E6100000EDD5C743DFF55940D218ADA3AA654A40
35323	5	50	1576	59345	69682	\N	53.326292533803198	Иркутская область, Баяндаевский район, д.Шетхулун, ул.Трактовая, д.51	Россия, Иркутская область, Баяндаевский район, поселок Шитхулун	0101000020E610000099805F23497C5A40F5F411F8C3A94A40
35305	5	50	1576	19169	69532	\N	53.127138000000002	Иркутская область, Баяндаевский район, с.Шаманка, ул.Бурлова, д.38		0101000020E6100000ACC43C2B69665A40180AD80E46904A40
35321	5	50	1576	20003	68544	\N	53.241616	Иркутская область, Баяндаевский район, с.Хогот, ул.Трактовая, д.85		0101000020E61000007BDD2230D6775A405D18E945ED9E4A40
35315	5	50	1576	19690	69276	\N	52.843777000000003	Иркутская область, Баяндаевский район, с.Хадай, ул.трактовая, д.2		0101000020E6100000FA0E7EE2004F5A40FA0E7EE2006C4A40
35302	5	50	1576	19016	69470	\N	53.124381999999997	Иркутская область, Баяндаевский район,  д.Харагун, ул.Трактовая, д.4		0101000020E6100000D4D7F335CB735A40041BD7BFEB8F4A40
35325	5	50	1576	20270	\N	\N	53.164988000000001	Иркутская область, Баяндаевский район, д.Хандагай, ул.Нагорная, д.12	Россия, Иркутская область, Баяндаевский район, поселок Хандагай	0101000020E610000032E719FB92765A40C11DA8531E954A40
35306	5	50	1576	19242	69001	\N	53.236302999999999	Иркутская область, Баяндаевский район, д.Улан, ул.Подгорная, д.12		0101000020E610000039B874CC796E5A402D793C2D3F9E4A40
35327	5	50	1576	20398	69475	\N	53.423478000000003	Иркутская область, Баяндаевский район, д.Тухум, ул.Центральная, д.1А		0101000020E6100000DCB930D28B6D5A40AA49F08634B64A40
35303	5	50	1576	19061	69154	\N	53.025896326034399	Иркутская область, Баяндаевский район, с.Тургеневка, ул.Советская, д.56	Россия, Иркутская область, Баяндаевский район, поселок Тургеневка	0101000020E61000002D5DC136E26A5A40728C648F50834A40
35322	5	50	1576	20074	69265	\N	53.296531000000002	Иркутская область, Баяндаевский район,с.Старый Хогот, ул.Трактовая, д.31, кв.2		0101000020E6100000F5BD86E0B8725A4006A051BAF4A54A40
35304	5	50	1576	19123	69156	\N	53.134281000000001	Иркутская область, Баяндаевский район, с.Половинка, пер.Клубный, д.5		0101000020E610000026732CEFAA695A40B2BCAB1E30914A40
35307	5	50	1576	19268	68642	\N	53.080725000000001	Иркутская область, Баяндаевский район, с.Покровка, ул.Мира, д.1		0101000020E6100000074147AB5A625A401C7C6132558A4A40
35311	5	50	1576	19485	68851	\N	52.946387999999999	Иркутская область, Баяндаевский район,с.Ользоны, ул.Титова, д.13		0101000020E610000080289831054E5A40D6A9F23D23794A40
35319	5	50	1576	59220	69183	\N	53.150239309625199	Иркутская область, Баяндаевский район, с.Нухунур, ул.Хургалдайраг, д.7	Россия, Иркутская область, Баяндаевский район, поселок Нуху-Нур	0101000020E61000002EE23B31EB555A40B8CA13083B934A40
35316	5	50	1576	19738	69011	\N	52.841324	Иркутская область, Баяндаевский район, с.Наумовка, ул.Центральная, д.36		0101000020E610000096CCB1BCAB4A5A4082AB3C81B06B4A40
35318	5	50	1576	19824	69015	\N	53.103572999999997	Иркутская область, Баяндаевский район, с.Нагалык, ул.Ленина, д.6		0101000020E6100000094FE8F527535A40D2DF4BE1418D4A40
35309	5	50	1576	19390	69155	\N	53.001081999999997	Иркутская область, Баяндаевский район, с.Люры, ул.Чкалова, д.2А		0101000020E6100000AE635C71715D5A40A04E797423804A40
35312	5	50	1576	59287	69543	\N	53.085181399758497	Иркутская область, Баяндаевский район, д.Кокорино, ул.Центральная, д.12	Россия, Иркутская область, Баяндаевский район, поселок Кокорина	0101000020E6100000055262D7F6495A40CB9E0436E78A4A40
35324	5	50	1576	59343	69674	\N	53.299666121055701	Иркутская область, Баяндаевский район, д.Кайзеран, ул.Клубная, д.13	Россия, Иркутская область, Баяндаевский район, поселок Кайзаран	0101000020E6100000C44142942F805A4090DC9A745BA64A40
35313	5	50	1576	19580	68749	\N	52.890538999999997	Иркутская область, Баяндаевский район, с.Загатуй, ул.Микрорайон-1, д.41		0101000020E610000075CDE49B6D555A400168942EFD714A40
35320	5	50	1576	19964	69473	\N	53.198608	Иркутская область, Баяндаевский район, д.Еленинск, ул.горная, д.1		0101000020E6100000A3CC0699645B5A40AB5CA8FC6B994A40
35301	5	50	1576	18961	69151	\N	53.076673	Иркутская область, Баяндаевский район,с.Васильевск, ул.Центральная, д.12		0101000020E6100000AFB5F7A92A705A403CBEBD6BD0894A40
35310	5	50	1576	19430	69302	\N	52.982246000000004	Иркутская область, Баяндаевский район, д.Бохолдой, ул.Муринская, д.14		0101000020E6100000E3A430EF715F5A403C50A73CBA7D4A40
35308	5	50	1576	19328	67649	\N	53.060723000000003	Иркутская область, Баяндаевский район, с.Баяндай, ул.Гагарина, д.40		0101000020E6100000E23B31EBC5605A40B98E71C5C5874A40
35314	5	50	1576	19642	69476	\N	52.923983	Иркутская область, Баяндаевский район,с.Бахай, ул.Муринская, д.26		0101000020E6100000EE224C512E585A40AD872F1345764A40
35326	5	50	1576	20297	69157	\N	53.371397999999999	Иркутская область, Баяндаевский район,с.Байша, ул.Центральная, д.64Б		0101000020E61000008690F3FE3F685A4060E63BF889AF4A40
35317	5	50	1576	19818	69160	\N	53.020988000000003	Иркутская область, Баяндаевский район, с.Бадагуй, ул.Урбаева, д.2		0101000020E6100000F7B0170AD8525A40E2CD1ABCAF824A40
35296	5	50	398	18693	69336	\N	54.328507000000002	Иркутская область, Балаганский район, с. Шарагай, Центральная, 13		0101000020E6100000C24D469561C45940E8C072840C2A4B40
35289	5	50	398	2086	69455	\N	53.891837000000002	"""Иркутская область, Балаганский район"", дер. Ташлыкова, ул. Школьная, д. 2 Школа"		0101000020E6100000D5EC815660C559406F2EFEB627F24A40
35291	5	50	398	18444	69329	\N	54.050224	Иркутская область, Балаганский район, с.Тарнополь, Садовый, 6		0101000020E61000002499D53BDCB05940B6BC72BD6D064B40
35295	5	50	398	18666	68998	\N	54.373730000000002	Иркутская область, Балаганский район, дер. Тарасовск, Школьная, 14		0101000020E61000009B1BD31396BA59405DC47762D62F4B40
35293	5	50	398	18550	69286	\N	54.123334	Иркутская область, Балаганский район, дер. Метляева, Трудовая, 19		0101000020E61000004227840EBAB65940103E9468C90F4B40
35297	5	50	398	18768	68650	\N	54.480595999999998	Иркутская область, Балаганский район, с. Кумарейска, Первомайская, 2		0101000020E6100000D2A92B9FE5BE5940514B732B843D4B40
35288	5	50	398	18258	68824	\N	53.982581000000003	Иркутская область, Балаганский район, с. Коновалово, Лесная, 10		0101000020E6100000CF328B506CC45940E355D636C5FD4A40
35294	5	50	398	18581	68849	\N	54.220500000000001	Иркутская область, Балаганский район, дер. Заславская, Ленина, 11		0101000020E610000004560E2DB2BD59404E621058391C4B40
35290	5	50	398	18363	69006	\N	54.075857999999997	Иркутская область, Балаганский район, с. Бирит, 2 Советская, 1		0101000020E6100000BE326FD575BA5940EA9106B7B5094B40
35299	5	50	398	18787	67839	\N	54.008336999999997	Иркутская область, Балаганский район, п. Балаганск, Горького, 31		0101000020E61000001899805F23C35940622CD32F11014B40
35298	5	50	398	18787	67839	\N	54.008336999999997	Иркутская область, Балаганский район, п. Балаганск, Горького, 33		0101000020E61000001899805F23C35940622CD32F11014B40
35292	5	50	398	18473	69057	\N	54.052148000000003	Иркутская область, Балаганский район, дер. Анучинск, Школьная, 6-1		0101000020E610000008008E3D7BA55940A24621C9AC064B40
35272	5	50	1285	17463	67014	\N	52.330657000000002	"Иркутская область, Ангарское муниципальное образование, Савватеевское муниципальное образование, ДК ""Нива"", с. Савватеевка, ул. Клубная, 2"		0101000020E6100000A1F7C61000E95940C498F4F7522A4A40
35274	5	50	1285	17578	67647	\N	52.452587000000001	"Иркутская область, Ангарское муниципальное образование, Одинское муниципальное образование, ""Спорткомплекс"", с. Одинск, ул. Молодежная, 2а"		0101000020E610000090300C5872ED594021CCED5EEE394A40
35277	5	50	1285	59111	\N	\N	52.421041000000002	"Иркутская область, Ангарское муниципальное образование, Мегетское муниципальное образование, Адм.здание ОАО ""Хлебная база №15"""	Россия, Иркутская область, Ангарский район, поселок Мегет	0101000020E6100000B5519D0E64035A4038A3E6ABE4354A40
35276	5	50	1285	59111	67842	\N	52.421041000000002	Иркутская область, Ангарское муниципальное образование, Мегетское муниципальное образование, Мегетская средняя школа, пер. Школьный, 8		0101000020E6100000B5519D0E64035A4038A3E6ABE4354A40
35275	5	50	1285	59111	68072	\N	52.421140109710002	Иркутская область, Ангарское муниципальное образование, Мегетское муниципальное образование, Здание администрации п. Мегет, кв-л 1, 7	Россия, Иркутская область, Ангарский район, поселок Мегет	0101000020E61000009B00C3F2E7025A40CB845FEAE7354A40
33701	5	48	214	5287	73985	\N	50.979369796749097	Дешулан, Октябрьская, 16	Россия, Забайкальский край, Улетовский район, село Дешулан	0101000020E61000004628B682A6F15B407E5704FF5B7D4940
35278	5	50	1285	59111	68147	\N	52.4190410479465	Иркутская область, Ангарское муниципальное образование, Мегетское муниципальное образование, Мегетская средняя школа, ул. Детсадовская, 6	Россия, Иркутская область, Ангарский район, поселок Мегет	0101000020E610000037514B732B035A407157AF22A3354A40
36507	5	50	1285	13460	68809	\N	52.598019000000001	Иркутская область, Усольское районное муниципальное образование, Железнодорожное муниципальное образование, с.Биликтуй, Советская, 47, кв.1		0101000020E610000080B9162D40F559407DB1F7E28B4C4A40
35256	5	50	1285	59115	67881	\N	52.4001449724691	Иркутская область, Ангарское муниципальное образование, Средняя школа № 9, мкр. 19, 16	Россия, Иркутская область, Ангарский район	0101000020E61000003B3602F1BA025A4037548CF337334A40
35176	5	50	1177	52030	68983	\N	53.528098776912998	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Маниловск"",д.Шаховская, Центральная, 37"	Россия, Иркутская область, Аларский район, поселок Шаховская	0101000020E6100000CEC3094CA7B3594070067FBF98C34A40
35165	5	50	1177	51999	69258	\N	53.170580000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Иваническ"", д.Шалоты, Центральная, 23"		0101000020E6100000BAA1293BFD94594004ADC090D5954A40
35155	5	50	1177	51956	68977	\N	53.378532	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Егоровск"", д.Хуруй, Первая, 23"		0101000020E610000065E3C116BBBE5940A73E90BC73B04A40
35149	5	50	1177	51943	69468	\N	53.263145000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Аляты"", д.Халты, Светлая, 22"		0101000020E610000040DAFF006B9059408F8D40BCAEA14A40
35146	5	50	1177	51937	68942	\N	53.287182000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Александровск"", д.Угольная, Советская"		0101000020E6100000CD0182397AAD5940FCFF3861C2A44A40
35180	5	50	1177	52040	69490	\N	53.350951000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Могоенок"",д.Тютрина, Новая, 5-2"		0101000020E6100000268C6665FBB65940CFBF5DF6EBAC4A40
35190	5	50	1177	52068	68856	\N	53.348967000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Тыргетуй"", с.Тыргетуй, Севетская, 33-1"		0101000020E610000047E867EA75D159400E315EF3AAAC4A40
35188	5	50	1177	52061	68747	\N	53.431392000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Табарсук"", с.Табарсук, Чумакова, 14"		0101000020E6100000323CF6B358BA5940C6E061DA37B74A40
35164	5	50	1177	51989	69472	\N	53.241109999999999	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Иваническ"", д.Отрадная, Новая, 16"		0101000020E6100000DC9C4A0680965940895E46B1DC9E4A40
35186	5	50	1177	52057	68527	\N	53.016902999999999	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Ныгда"", д.Ныгда, Советская, 12"		0101000020E6100000F5BA4560ACAB5940261AA4E029824A40
35184	5	50	1177	52048	69332	\N	53.357576999999999	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Нельхай"", д.Нельхай, Мира, 7"		0101000020E610000049D9226937C85940A1664815C5AD4A40
35159	5	50	1177	51965	68997	\N	53.228572999999997	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Забитуй"", д.Нарены, Центральная, 12"		0101000020E610000046B5882826B35940D2DF4BE1419D4A40
35183	5	50	1177	52046	68995	\N	53.365321000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Нельхай"", д.Мольта, Трактовая, 29А"		0101000020E61000009FC893A46BC3594061C5A9D6C2AE4A40
35179	5	50	1177	52038	69148	\N	53.393424000000003	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Могоенок"", с.Могоенок, Лесная, 1А"		0101000020E6100000F5BBB0355BB7594013BBB6B75BB24A40
35175	5	50	1177	52025	69328	\N	53.498640000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Маниловск"", д.Маниловская, Советская, 40"		0101000020E61000001825E82FF4AE59401D3D7E6FD3BF4A40
35178	5	50	1177	52037	69023	\N	53.395459000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Могоенок"", д.Малый Кутулик, Школьная, 1А"		0101000020E610000014799274CDB1594056F487669EB24A40
35177	5	50	1177	52031	69485	\N	53.400125000000003	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Могоенок"", д.Маломолева, Центральная, 14А"		0101000020E61000001DCA501553B55940F0A7C64B37B34A40
35172	5	50	1177	52008	67763	\N	53.353918	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Кутулик"", п.Кутулик, Шилова, 1"		0101000020E6100000390F27309DB159409DBB5D2F4DAD4A40
35171	5	50	1177	52008	67945	\N	53.359925044495	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Кутулик"", п.Кутулик, Советская, 49"	Россия, Иркутская область, Аларский район, поселок Кутулик	0101000020E6100000889FFF1EBCB15940A301BC0512AE4A40
35170	5	50	1177	52008	68845	\N	53.353918	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Кутулик"", п.Кутулик, Ветеринарная, 18"		0101000020E6100000390F27309DB159409DBB5D2F4DAD4A40
15647	5	47	\N	902	69692	\N	53.003270999999998	Алтайский край, г.Славгород, м-н 3, средняя школа № 15		0101000020E6100000B796C9703CA953403A03232F6B804A40
35143	5	50	1177	51932	69144	\N	53.173456999999999	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Аларь"", д.Куркат, Центральная, 37"		0101000020E6100000B1DCD26A489B59409221C7D633964A40
35581	5	50	1177	32296	69200	\N	53.278196000000001	Иркутская область, Зиминское районное муниципальное образование, Буринское муниципальное образование, с.Кундулун, Партизанская, 10		0101000020E6100000C8D3F20357C6594063F030ED9BA34A40
35142	5	50	1177	51928	69143	\N	53.186301	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Аларь"", д.Кукунур, Центральная, 3"		0101000020E61000009AB51490F6A05940261B0FB6D8974A40
35168	5	50	1177	52002	69271	\N	53.184677000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Куйта"", с.Куйта, Центральная, 23"		0101000020E610000061A8C30AB7AF594065A9F57EA3974A40
35174	5	50	1177	52022	69335	\N	53.390664000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Маниловск"",д.Корховская, Центральная, 22"		0101000020E610000051A2258FA7AD5940BEDC274701B24A40
35187	5	50	1177	59246	69337	\N	53.446078	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Табарсук"", д.Кирюшина, Звездочка, 34-2"		0101000020E610000091D6187442B5594088BB7A1519B94A40
35163	5	50	1177	51984	69149	\N	53.238813999999998	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Иваническ"",д.Киркей, Центральная, 32"		0101000020E61000002F4D11E0F4995940D9E90775919E4A40
35189	5	50	1177	52064	69469	\N	53.391984999999998	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Тыргетуй"", д.Икинат, Ербанова, 2А"		0101000020E610000072C284D1ACD15940E3C281902CB24A40
35167	5	50	1177	51998	68625	\N	53.158676	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Куйта"", с.Идеал, Коммунаров, 17"		0101000020E61000008EAED2DD75AC59407E54C37E4F944A40
35158	5	50	1177	51961	69257	\N	53.319502685266798	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Забитуй"", д.Иванова, Белорусская, 4-2"	Россия, Иркутская область, Аларский район, поселок Иванова	0101000020E610000078978BF84EB05940A8FC6B79E5A84A40
35162	5	50	1177	51978	68823	\N	53.201191000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Иваническ"", с.Иваническое, Юбилейная, 7А"		0101000020E61000007C65DEAAEB955940F19F6EA0C0994A40
35161	5	50	1177	51970	68835	\N	53.315793999999997	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Зоны"", с.Зоны, Центральная, 12"		0101000020E6100000CEDE196D55A25940F22213F06BA84A40
35166	5	50	1177	51996	69266	\N	53.165700000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Куйта"", д.Заречное, Первая, 9"		0101000020E610000082035ABA82A859403E7958A835954A40
35173	5	50	1177	52018	69139	\N	53.42754	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Маниловск"", д.Занина, Центральная, 51"		0101000020E6100000D0D2156C23A75940ADDD76A1B9B64A40
35156	5	50	1177	51960	67756	\N	53.271452235646002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Забитуй"", п.Забитуй, 70 лет Октября, 24"	Россия, Иркутская область, Аларский район, поселок Забитуй	0101000020E61000003FC7478B33B5594086376BF0BEA24A40
35154	5	50	1177	59304	69566	\N	53.303468000000002	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Егоровск"", с.Егоровск, Центральная, 1"	Россия, Иркутская область, Аларский район, поселок Егоровская	0101000020E6100000566133C005C15940F7B0170AD8A64A40
35169	5	50	1177	52006	68117	\N	53.433157000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Кутулик"", с.Головинское, Васильева, 6"		0101000020E61000000FB6D8EDB3AA5940498446B071B74A40
35148	5	50	1177	51941	68971	\N	53.275305000000003	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Аляты"", д.Высотская, Нагорная, 27"		0101000020E6100000459C4EB2D58B594070B6B9313DA34A40
35152	5	50	1177	51949	69146	\N	53.503568000000001	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Ангарский"", п.Быково, Мира, 11А"		0101000020E61000003CBEBD6BD0D45940F4A78DEA74C04A40
36663	5	50	1177	59252	69368	\N	53.218649763037398	Иркутская область, Черемховский район,  д. Малиновка, Школьная	Россия, Иркутская область, Аларский район, поселок Бурятский Забитуй (Малиновка)	0101000020E610000023C0E95DBCB759409CA223B9FC9B4A40
35160	5	50	1177	51967	69147	\N	53.356625999999999	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Зоны"", д.Бурятская, Верхняя"		0101000020E61000007FDAA84E079C59409F73B7EBA5AD4A40
35185	5	50	1177	52051	69330	\N	53.023527999999999	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Ныгда"", д.Буркова, Школьная, 2А"		0101000020E61000001A8A3BDEE4A6594028452BF702834A40
35153	5	50	1177	51950	68623	\N	53.504468000000003	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Бахтай"", с.Бахтай, Ербанова, 21"		0101000020E6100000876A4AB20EC7594074F04C6892C04A40
15655	5	47	\N	902	69925	\N	53.003270999999998	Алтайский край, г.Славгород, м-н 2, средняя школа № 17		0101000020E6100000B796C9703CA953403A03232F6B804A40
35182	5	50	1177	52045	68968	\N	53.344430000000003	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Нельхай"", с.Апхульта, Октябрьская, 11"		0101000020E61000000BEF7211DFC5594072E1404816AC4A40
35151	5	50	1177	51946	69467	\N	53.413148	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Ангарский"", д.Апхайта, Победы, 12А"		0101000020E6100000FB57569A94CD594033349E08E2B44A40
35150	5	50	1177	51945	68976	\N	53.462304000000003	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Ангарский"", п.Ангарский, Ленина, 15"		0101000020E61000007BDAE1AFC9D65940AE6708C72CBB4A40
35147	5	50	1177	51940	68538	\N	53.212311062936102	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Аляты"", с.Аляты, Жана Зимина, 1А"		0101000020E6100000B01D8CD8278E594060CAC0012D9B4A40
35141	5	50	1177	51926	69376	\N	53.114254000000003	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Аларь"", д.Алзобей, Школьная, 14"		0101000020E61000009241EE224CA85940F6B704E09F8E4A40
35144	5	50	1177	51934	68967	\N	53.341048999999998	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Александровск"",с.Александровск, Центральная, 50"		0101000020E61000008FA67A32FFA95940B0AA5E7EA7AB4A40
35140	5	50	1177	51923	68734	\N	53.069569999999999	"Иркутская область, муниципальное образование ""Аларский район"", муниципальное образование ""Аларь"",с.Аларь, Лазо, 14-2"		0101000020E61000004B395FECBDA25940306475ABE7884A40
34275	5	48	\N	60046	73597	\N	51.856436000000002	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Шилкинское"", г. Шилка, Бородина, 11"		0101000020E61000000F80B8AB57015D40FC8EE1B19FED4940
33536	5	48	\N	50869	\N	\N	52.0583629808892	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, здание станции Черновской Забайкальской железной дороги"		0101000020E6100000075C57CC08565C40F225547078074A40
33537	5	48	\N	50869	73707	\N	52.043421657717602	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, проезд Булгакова, 60"	Россия, Забайкальский край, городской округ Чита	0101000020E6100000C442AD69DE5E5C40A5F622DA8E054A40
33428	5	48	\N	50869	73598	\N	52.061325740567497	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, мкр. Геофизический, 14А"		0101000020E6100000A7069ACFB9595C407F32C687D9074A40
33429	5	48	\N	50869	73553	\N	52.037618132378697	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, мкр. Северный, 1"		0101000020E6100000A69D9ACB0D605C40D7DEA7AAD0044A40
33482	5	48	\N	50869	73558	\N	52.067126171880602	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Ярославского, 47"		0101000020E6100000D5B48B69A65A5C400C5BB39597084A40
33532	5	48	\N	50869	73724	\N	51.999302	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Юбилейная, 1"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000D7DEA7AAD0535C40E869C020E9FF4940
33514	5	48	\N	50869	23936	\N	52.063183254598201	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Труда, 14"		0101000020E610000090A2CEDC43565C40E3546B6116084A40
33523	5	48	\N	50869	73610	\N	52.040112000000001	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Строителей, 26"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000007898F6CDFD515C40AD16D86322054A40
33504	5	48	\N	50869	73642	\N	52.031817882207001	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Романовский Тракт, 77"		0101000020E6100000B6F81400E35B5C404AB6BA9C12044A40
33499	5	48	\N	50869	73635	\N	52.00997175893	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Ползунова, 11"		0101000020E6100000E5284014CC5B5C4017F032C346014A40
33784	5	48	\N	50869	73766	\N	52.053000950132997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Александровское"", ул.Первомайская, д.36а"	Россия, Забайкальский край, городской округ Чита	0101000020E61000006494675E0E5B5C40E1D39CBCC8064A40
33440	5	48	\N	50869	73606	\N	52.070236388138703	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Новобульварная, 32"		0101000020E610000086014BAE62585C403D80457EFD084A40
33486	5	48	\N	50869	73576	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Луговая, 87"		0101000020E610000012A3E716BA595C40F2237EC51A084A40
33476	5	48	\N	50869	24185	\N	52.068285051501199	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Ленина, 2"	Россия, Забайкальский край, городской округ Чита	0101000020E6100000FCFECD8B135E5C4058E71890BD084A40
33480	5	48	\N	50869	67467	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Лазо, 28"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33433	5	48	\N	50869	73640	\N	52.068943358528898	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Красной Звезды, 36А"		0101000020E61000009679ABAE43595C40E124CD1FD3084A40
15649	5	47	\N	902	69644	\N	53.003270999999998	Алтайский край, город Славгород, Энгельса, 73		0101000020E6100000B796C9703CA953403A03232F6B804A40
33431	5	48	\N	50869	73640	\N	52.069242031648798	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Красной Звезды, 7"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000DF1797AAB4575C403CC1FEEBDC084A40
33496	5	48	\N	50869	73574	\N	52.0611618598167	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Карла Маркса, 10"		0101000020E6100000E223624A245A5C4005E10A28D4074A40
33475	5	48	\N	50869	73590	\N	52.064587000000003	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Забайкальского Рабочего, 16"		0101000020E6100000F9F884ECBC5A5C40965F066344084A40
33446	5	48	\N	50869	73645	\N	52.073520000000002	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Журавлева, 3"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000E90AB6114F595C400CCD751A69094A40
33443	5	48	\N	50869	73645	\N	52.076242999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Журавлева, 77"		0101000020E6100000E4A1EF6E65595C4043C6A354C2094A40
33527	5	48	\N	50869	73653	\N	52.063818079439102	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Жилой городок, 15"		0101000020E61000009FC728CFBC565C40B4722F302B084A40
33477	5	48	\N	50869	73611	\N	52.061560917688603	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Декабристов, 12"		0101000020E6100000684128EFE35A5C40C2DA183BE1074A40
33451	5	48	\N	50869	73566	\N	52.062470512386099	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Горького, 39а"		0101000020E6100000034015376E585C4066F9BA0CFF074A40
33450	5	48	\N	50869	73575	\N	52.067829851075601	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Горького, 38"		0101000020E61000004580D3BB78595C4006D847A7AE084A40
33460	5	48	\N	50869	73651	\N	52.068097021023704	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Геофизический мкр, 14А"		0101000020E61000006F6589CE32595C4055FA0967B7084A40
33432	5	48	\N	50869	73554	\N	52.072204066041998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Геодезическая, 45"		0101000020E61000008BE07F2BD9585C40F8510DFB3D094A40
33469	5	48	\N	50869	73622	\N	52.0325362857768	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Гагарина, 1"		0101000020E6100000E6779ACC785E5C40A9F8BF232A044A40
33494	5	48	7101	\N	73727	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Вайнштейна, 1"	Россия, Забайкальский край, городской округ Чита	0101000020E610000040A374E95F5D5C40F2237EC51A084A40
33462	5	48	\N	50869	73613	\N	52.069119999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Балябина, 1"		0101000020E6100000853FC39B35595C40F0BF95ECD8084A40
33474	5	48	7089	\N	67263	\N	52.080665933252703	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Бабушкина, 28"	Россия, Забайкальский край, городской округ Чита	0101000020E61000001BB96E4A795C5C4017F37343530A4A40
33461	5	48	\N	50869	67263	\N	52.069142956284402	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Бабушкина, 125"		0101000020E6100000DDCD531D72595C40A8DF85ADD9084A40
33449	5	48	\N	50869	67263	\N	52.068841286452397	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Бабушкина, 129"		0101000020E6100000707B82C476595C40DDCF29C8CF084A40
33534	5	48	\N	50869	73701	\N	51.992237417886997	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Агрогородок ""Опытный"", 10"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000BD8BF7E3F64F5C40CA703C9F01FF4940
33520	5	48	\N	50869	73670	\N	52.062125193042803	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 6-ой микрорайон, 4-А"		0101000020E610000065FCFB8C0B575C40CBA145B6F3074A40
33511	5	48	\N	50869	73627	\N	52.062078178980897	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 4 микрорайон, 13-А"		0101000020E61000002CA0504F1F565C408AE6012CF2074A40
33510	5	48	\N	50869	73627	\N	52.053283504766902	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 4 микрорайон, 15-Б"		0101000020E61000002D5BEB8B84565C4035B39602D2064A40
33444	5	48	\N	50869	73546	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Хабаровская, 2"		0101000020E610000012A3E716BA595C40F2237EC51A084A40
33484	5	48	\N	50869	73682	\N	52.048743999999999	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Промышленная, 49"	Россия, Забайкальский край, городской округ Чита	0101000020E6100000C8B1F50CE15B5C4028F04E3E3D064A40
33454	5	48	\N	50869	34056	\N	52.075660590620302	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Кайдаловская, 15"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000B2F50CE198575C40944A7842AF094A40
33509	5	48	\N	50869	73685	\N	52.026500838842203	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 5 микрорайон, 5"		0101000020E6100000BFD4CF9B8A4F5C40D927806264034A40
33762	5	48	208	8340	73801	\N	51.850962000000003	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Ингодинское"", с. Ингода, ул.Центральная, д.17"		0101000020E6100000B5A50EF27A465C40C311A452ECEC4940
33441	5	48	\N	54090	34045	\N	52.053706816614699	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Курнатовского, 45а"	Россия, Забайкальский край, городской округ Чита	0101000020E6100000984F560C575E5C407C48F8DEDF064A40
33466	5	48	\N	54090	73618	\N	51.979948999999998	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Песчанка, Дивизионная, вл. 3"		0101000020E61000004A5D328E91655C40BB5F05F86EFD4940
33470	5	48	\N	54090	73678	\N	52.050320208960102	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Белорусская, 1"		0101000020E61000003E03EACDA85B5C40D82AC1E270064A40
33547	5	48	\N	29213	73815	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, пл.Ленина, дворец культуры		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33546	5	48	\N	29213	24278	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Чехова, 14	Россия, Забайкальский край, Петровск-Забайкальский	0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33544	5	48	\N	29213	24275	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Федосеевка, 3		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33554	5	48	\N	29213	23366	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Станционная, 20		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33552	5	48	\N	29213	27376	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Спортивная, 9	Россия, Забайкальский край, Петровск-Забайкальский	0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33548	5	48	\N	29213	27376	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Спортивная, 20		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33543	5	48	\N	29213	28103	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Островского, 60		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33545	5	48	\N	29213	27235	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Некрасова, 1		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33541	5	48	\N	29213	73798	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Нагорная, 2		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33557	5	48	\N	29213	28177	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Нагаева, 2		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33553	5	48	\N	29213	73982	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Мира, 1		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33550	5	48	\N	29213	73615	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Микрорайон 1, гимназия №1		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33559	5	48	\N	29213	24355	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Лесная, 68	Россия, Забайкальский край, Петровск-Забайкальский	0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33558	5	48	\N	29213	24355	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Лесная, 19		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33549	5	48	\N	29213	24282	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Ленина, 16		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33556	5	48	\N	29213	24327	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Лазо, 1		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33542	5	48	\N	29213	73859	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Красная, 14		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33540	5	48	\N	29213	73981	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Декабристов, 14		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
33539	5	48	\N	29213	24234	\N	51.278922999999999	Забайкальский край, город Петровск-Забайкальский, Горбачевского, 17		0101000020E61000006A2E3718EA355B40158DB5BFB3A34940
34057	5	48	\N	60040	73572	\N	51.984190552300099	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Красноармейская, 140, ДЮСШ"		0101000020E6100000EA5910CAFB255D403F027FF8F9FD4940
34055	5	48	\N	60040	73797	\N	51.984614521803699	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", ул.Береговая, 67, СОШ № 2"		0101000020E610000051D9B0A6B2255D40551344DD07FE4940
33860	5	48	\N	60023	\N	\N	50.102116273652797	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №8"		0101000020E61000007E5182FE42835D40FD321823120D4940
33857	5	48	\N	60023	\N	\N	50.102999565984902	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №5"		0101000020E6100000CC79C6BE64835D4077BE9F1A2F0D4940
33804	5	48	\N	60045	73774	\N	51.582243239434298	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Чернышевского, 14"	Россия, Забайкальский край, Балейский район, Балей	0101000020E6100000CAC0012D5D295D4097A949F086CA4940
33502	5	48	7101	51745	73704	\N	52.063039632485903	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Трактовая, 40"	Россия, Забайкальский край, городской округ Чита	0101000020E6100000676490BB085D5C40802BD9B111084A40
33458	5	48	7101	51745	71615	\N	52.039150471453901	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Профсоюзная, 14"	Россия, Забайкальский край, городской округ Чита	0101000020E6100000CF2F4AD05F5E5C40B7D100DE02054A40
33487	5	48	7101	51745	73832	\N	52.042793467485602	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Молоковский Тракт, 124"		0101000020E61000003CD9CD8C7E5C5C40B6BFB33D7A054A40
33479	5	48	7101	51745	27804	\N	52.039311952229703	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Ингодинская, 19"	Россия, Забайкальский край, городской округ Чита	0101000020E610000026529ACDE35C5C40912BF52C08054A40
33472	5	48	7101	51745	67459	\N	52.056545361517102	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Баргузинская, 41"	Россия, Забайкальский край, городской округ Чита	0101000020E61000009604A8A9655B5C404CE0D6DD3C074A40
33483	5	48	7101	51745	73687	\N	52.043546219643297	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, 1-й Микрорайон, 16"	Россия, Забайкальский край, городской округ Чита	0101000020E610000042EE224C51605C4091EF52EA92054A40
34278	5	48	178	557	71586	\N	51.856436000000002	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Шилкинское"", г. Шилка, Ленина, 53"		0101000020E61000000F80B8AB57015D40FC8EE1B19FED4940
34282	5	48	178	557	73830	\N	51.854416144274502	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Шилкинское"", Дорурс, Забелина, школа"		0101000020E6100000BFBB95253A025D40EE96E4805DED4940
34281	5	48	178	557	24203	\N	51.856436000000002	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Шилкинское"", г. Шилка, Вокзальная, 3"		0101000020E61000000F80B8AB57015D40FC8EE1B19FED4940
34280	5	48	178	557	67209	\N	51.856436000000002	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Шилкинское"", г. Шилка, Балябина, 162"		0101000020E61000000F80B8AB57015D40FC8EE1B19FED4940
34276	5	48	178	557	67209	\N	51.856436000000002	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Шилкинское"", г. Шилка, Балябина, 64"		0101000020E61000000F80B8AB57015D40FC8EE1B19FED4940
34304	5	48	178	2226	28108	\N	51.627996000000003	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Чиронское"", с. Чирон, Советская, Дом культуры"	Россия, Забайкальский край, Шилкинский район, село Чирон	0101000020E610000034F790F0BDF15C406902452C62D04940
34283	5	48	178	1038	23600	\N	51.904069999999997	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Холбонское"", п. Холбон, Просвещенская, 16а"		0101000020E6100000E353008C670F5D40B9A5D590B8F34940
34302	5	48	178	2123	74021	\N	51.545017999999999	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Усть-Теленгуйское"", с. Усть-Теленгуй, Советская, 19"		0101000020E6100000D8EF8975AAFD5C409CDD5A26C3C54940
34321	5	48	178	60220	74055	\N	51.464900014877301	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Ононское"", с. Усть-Ножовое, Зеленая, 1"	Россия, Забайкальский край, Шилкинский район, село Усть-Ножовая	0101000020E61000003B1BF2CF0CF15C4088F4DBD781BB4940
34319	5	48	178	3145	73994	\N	52.061911000000002	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Верхнехилинское"", с. Ульяновка, Центральная, 23б"		0101000020E6100000684293C492F25C409F211CB3EC074A40
34300	5	48	178	1995	73965	\N	51.993487000000002	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Богомягковское"", с. Средняя Кия, Центральная, Дом культуры"		0101000020E610000075E8F4BC1BE95C402600FF942AFF4940
34312	5	48	178	60217	74050	\N	51.765572483828102	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Галкинское"", с. Савино, Жалган, 2"	Россия, Забайкальский край, Шилкинский район, село Саввино	0101000020E6100000D594641D8EC55C40DD5D6743FEE14940
34307	5	48	178	2439	73810	\N	51.775778000000003	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Размахнинское"", с. Размахнино, Зеленская, 1"		0101000020E61000004BCCB39256DF5C40687A89B14CE34940
34290	5	48	178	1166	67211	\N	51.663663	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Первомайское"", пгт. Первомайский, Чкалова, 2"		0101000020E61000004B1FBAA0BEE75C405A48C0E8F2D44940
34288	5	48	178	1166	28039	\N	51.663663	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Первомайское"", пгт. Первомайский, Строительная, 2"		0101000020E61000004B1FBAA0BEE75C405A48C0E8F2D44940
34286	5	48	178	60039	73672	\N	51.663663	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Первомайское"", пгт. Первомайский, микрорайон, 19"		0101000020E61000004B1FBAA0BEE75C405A48C0E8F2D44940
34287	5	48	178	60039	73571	\N	51.666652032185503	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Первомайское"", пгт. Первомайский, Пролетарская, 3"	Россия, Забайкальский край, Шилкинский район, поселок городского типа Первомайский	0101000020E61000008509A359D9E75C4010E84CDA54D54940
34285	5	48	178	60039	73600	\N	51.663876536384699	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Первомайское"", пгт. Первомайский, Ленина, 40"	Россия, Забайкальский край, Шилкинский район, поселок городского типа Первомайский	0101000020E6100000FDF675E09CE75C4086C8E9EBF9D44940
34315	5	48	178	2896	73872	\N	52.072768000000003	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Новоберезовское"", с. Островки, Центральная, 20"		0101000020E61000007009C03FA5FE5C4001193A7650094A40
15654	5	47	\N	902	70126	\N	53.003270999999998	Алтайский край, г.Славгород, Титова, 169		0101000020E6100000B796C9703CA953403A03232F6B804A40
34320	5	48	178	3153	73732	\N	51.478876633988598	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Ононское"", с. Ононское, Школьная, интернат"	Россия, Забайкальский край, Шилкинский район, село Ононское	0101000020E610000054742497FFFC5C403EE76ED74BBD4940
34306	5	48	178	2350	73909	\N	51.638779999999997	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Номоконовское"", с. Номоконово, Школьная, 12"		0101000020E61000001DE6CB0BB0DF5C4060AB048BC3D14940
34313	5	48	178	2763	73873	\N	52.115659000000001	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Новоберезовское"", с. Новоберезовское, Центральная, 48"		0101000020E6100000C53A55BE67065D40793E03EACD0E4A40
34314	5	48	178	2804	73871	\N	52.058528000000003	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Новоберезовское"", с. Нижняя Хила, Советская, 21"		0101000020E6100000EE98BA2BBB095D403DF372D87D074A40
34297	5	48	178	1834	27342	\N	51.819701999999999	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Шилкинское"", с. Митрофаново, Глазова, Дом культуры"		0101000020E6100000F2B5679604FD5C409F3BC1FEEBE84940
34295	5	48	178	1735	73760	\N	51.886541000000001	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Мирсановское"", с. Мирсаново, Кирова, Дом культуры"		0101000020E6100000AD31E884D0095D4015C8EC2C7AF14940
34301	5	48	178	2091	73912	\N	52.065130476648399	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Богомягковское"", с. Кыэкен, Соболева, Библиотека"	Россия, Забайкальский край, Шилкинский район, село Кыэкен	0101000020E6100000F296AB1F9BDA5C4087FE092E56084A40
34308	5	48	178	2465	24322	\N	51.767752999999999	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Размахнинское"", с. Красноярово, Центральная, 42"		0101000020E610000074B515FBCBE55C40F433F5BA45E24940
34298	5	48	178	1870	27238	\N	51.933328000000003	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Богомягковское"", с. Кокуй-Комогорцево, Центральная, Дом культуры"		0101000020E6100000DFA7AAD040F75C407638BA4A77F74940
34305	5	48	178	2316	28404	\N	51.597974000000001	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Чиронское"", с. Кироча, Заимочная, 18"		0101000020E6100000B8955E9B8DF55C40DDED7A698ACC4940
34296	5	48	178	1760	74026	\N	51.863143999999998	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Мирсановское"", с. Кибасово, Лазо, Клуб"		0101000020E6100000CE716E13EE045D408BDEA9807BEE4940
34294	5	48	178	1662	34022	\N	51.775861999999996	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Казановское"", с. Казаново, Октябрьской революции, 61"		0101000020E610000067D7BD1589F75C40C51A2E724FE34940
34311	5	48	178	2660	74025	\N	51.785584999999998	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Галкинское"", с. Зубарево, Центральная, 26"		0101000020E610000017BCE82B48D15C40349D9D0C8EE44940
34310	5	48	178	2576	24647	\N	51.776581	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Галкинское"", с. Галкино, Центральная, 16"		0101000020E610000015CAC2D7D7CB5C40F5D8960167E34940
34317	5	48	178	3000	73811	\N	52.086956749323797	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Верхнехилинское"", с. Верхняя Хила, Советская, 27"	Россия, Забайкальский край, Шилкинский район, село Верхняя Хила	0101000020E61000002E8D5F7825F95C4042942F68210B4A40
34318	5	48	178	3043	73874	\N	52.027186	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Верхнехилинское"", с. Васильевка, Клубная, 1а"		0101000020E610000006BD378600FC5C405C74B2D47A034A40
34299	5	48	178	50793	\N	\N	51.9938782229192	"Забайкальский край, муниципальный район ""Шилкинский район"", сельское поселение ""Богомягковское"", И.П. Богомягкова, Дом культуры"	Россия, Забайкальский край, Шилкинский район, село Богомягково	0101000020E6100000AC376A85E9F25C40611BF16437FF4940
34284	5	48	178	1067	73904	\N	51.942711000000003	"Забайкальский край, муниципальный район ""Шилкинский район"", городское поселение ""Холбонское"", п. Арбагар, Первомайская, 3"		0101000020E6100000E4654D2CF0115D402C4A09C1AAF84940
34260	5	48	15	60175	73970	\N	51.891195177786102	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шивиинское"", Центральная, 8"	Россия, Забайкальский край, Шелопугинский район, село Шивия	0101000020E610000050C763062A5B5D40EBAD81AD12F24940
34259	5	48	15	60175	74061	\N	51.890504999999997	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шивиинское"", Верхняя, 20"		0101000020E6100000136058FE7C5B5D4055F65D11FCF14940
34271	5	48	15	50952	73969	\N	51.650486726270699	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шелопугинское"", Центральная, 21а"	Россия, Забайкальский край, Шелопугинский район, село Шелопугино	0101000020E610000016855D143D645D4090BC732843D34940
34268	5	48	15	50952	73969	\N	51.651628000000002	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шелопугинское"", Центральная, 1"	Россия, Забайкальский край, Шелопугинский район, село Шелопугино	0101000020E61000004B732B84D5635D403694DA8B68D34940
34267	5	48	15	50952	27270	\N	51.651394388225697	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шелопугинское"", Советская, 136"	Россия, Забайкальский край, Шелопугинский район, село Шелопугино	0101000020E6100000DD7BB8E4B8635D40C367EBE060D34940
34266	5	48	15	50952	27270	\N	51.650059584911602	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шелопугинское"", Советская, 17"	Россия, Забайкальский край, Шелопугинский район, село Шелопугино	0101000020E61000008CD651D504645D400938842A35D34940
34270	5	48	15	50952	73926	\N	51.657180720800902	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шелопугинское"", Набережная, 20а"	Россия, Забайкальский край, Шелопугинский район, село Шелопугино	0101000020E6100000BF47FDF50A645D40BB46CB811ED44940
34269	5	48	15	50952	73715	\N	51.6479000519831	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Шелопугинское"", ул.Лазо, 2"		0101000020E610000027124C35B3645D40098A1F63EED24940
34273	5	48	15	60205	74035	\N	51.387943314307101	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Нижне-Шахтаминское"", Первомайская, 10"	Россия, Забайкальский край, Шелопугинский район, село Нижняя Шахтама	0101000020E6100000944F8F6D196C5D4027DBC01DA8B14940
34272	5	48	15	60205	74049	\N	51.3876747999809	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Нижне-Шахтаминское"", Нагорная, 1"	Россия, Забайкальский край, Шелопугинский район, село Нижняя Шахтама	0101000020E61000006B9F8EC70C6C5D40083D9B559FB14940
34255	5	48	15	50976	73913	\N	51.977169000000004	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Мироновское"", Школьная, 17а"	Россия, Забайкальский край, Шелопугинский район, село Мироново	0101000020E6100000B821C66B5E695D4020D5B0DF13FD4940
34254	5	48	15	50976	24182	\N	51.973727495719402	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Мироновское"", Центральная, 29а"	Россия, Забайкальский край, Шелопугинский район, село Мироново	0101000020E6100000882B67EF8C695D40B81D1A16A3FC4940
34262	5	48	15	51435	73877	\N	51.834510019921403	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Мало-Тонтойское"", Чугуевского, 24"	Россия, Забайкальский край, Шелопугинский район, село Малый Тонтой	0101000020E61000003694DA8B68725D40AD174339D1EA4940
34261	5	48	15	51435	27025	\N	51.8367014325705	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Мало-Тонтойское"", Атавина, 18"	Россия, Забайкальский край, Шелопугинский район, село Малый Тонтой	0101000020E6100000F12900C633725D40E7C3B30419EB4940
34258	5	48	15	60216	74053	\N	51.889872462820399	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Копунское"", Верхняя, 23"	Россия, Забайкальский край, Шелопугинский район, село Копунь	0101000020E61000001E5036E50A695D4024D06053E7F14940
34257	5	48	15	60202	74031	\N	51.677174999999998	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Копунское"", Нагорная, 22"		0101000020E6100000C3651536037E5D409B559FABADD64940
34263	5	48	15	51726	27698	\N	51.657261111080402	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Глинянское"", Центральная, 18"	Россия, Забайкальский край, Шелопугинский район, село Глинянка	0101000020E6100000B20E4757E9595D40D7F7E12021D44940
34264	5	48	15	51726	74039	\N	51.658601643422699	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Глинянское"", Трактовая, 16"	Россия, Забайкальский край, Шелопугинский район, село Глинянка	0101000020E61000003F6EBF7CB2595D40448A01124DD44940
34274	5	48	15	50786	23598	\N	51.2965511489625	"Забайкальский край, муниципальный район ""Шелопугинский район"", сельское поселение ""Вершино-Шахтаминское"", Трактовая, 2"	Россия, Забайкальский край, Шелопугинский район, село Вершино-Шахтаминский	0101000020E610000087C43D963E795D404D4C1762F5A54940
33755	5	48	208	7983	24378	\N	51.841932	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Яблоновское"", пгт. Яблоново, ул.Школьная, д.16"		0101000020E6100000DDED7A698A305C405ABA826DC4EB4940
33756	5	48	208	7983	73856	\N	51.840819346820901	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Яблоновское"", ст. Кука, ул.Вокзальная, д.60"	Россия, Забайкальский край, Читинский район, поселок городского типа Яблоново	0101000020E6100000A4FB3905F9305C407F6DFDF49FEB4940
33740	5	48	208	7308	67860	\N	52.308407000000003	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Шишкинское"", с. Шишкино, ул.Центральная, д.48а"		0101000020E610000078465B9544655C40C26D6DE179274A40
33518	5	48	208	50808	27970	\N	52.064163798918599	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, проспект Фадеева, 29"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000312592E865575C404FCAA48636084A40
33508	5	48	208	50808	27970	\N	52.014745250309097	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, проспект Фадеева, 2"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000000A86730D33555C40C763062AE3014A40
34256	5	48	208	50808	67399	\N	52.073896568453897	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, мкр. Октябрьский, 3"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000273108AC1C595C40E222F77475094A40
33430	5	48	208	50808	73581	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, мкр. Северный, 50"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33503	5	48	208	50808	27242	\N	52.013003429037198	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Ямаровская, 4"	Россия, Забайкальский край, Читинский район	0101000020E6100000D314014EEF585C40FCDF1115AA014A40
33465	5	48	208	50808	67448	\N	51.980796580725801	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Песчанка, Юности, 6"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000009B215514AF655C40E9818FC18AFD4940
33528	5	48	208	50808	28327	\N	52.068520191791599	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Школьная, 1"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000017D4B7CCE9565C409B8F6B43C5084A40
33452	5	48	208	50808	73545	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Чайковского, 6"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33516	5	48	208	50808	27102	\N	52.0641571862581	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Текстильщиков, 14"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000008FFCC1C073575C409D67EC4B36084A40
33524	5	48	208	50808	27524	\N	52.061325740567497	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Строителей, 17"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000EDEF6C8FDE565C407F32C687D9074A40
33521	5	48	208	50808	27524	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Строителей, 9"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33535	5	48	208	50808	73722	\N	52.064946999999997	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Сретенская, 22"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000059DE550F98595C40957CEC2E50084A40
33501	5	48	208	50808	73719	\N	52.059634000000003	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Рахова, 15"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000BF64E3C1165A5C4066DD3F16A2074A40
33525	5	48	208	50808	73708	\N	52.009091401126398	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Ранетная, 7"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000094347F4C6B555C400ED8D5E429014A40
33456	5	48	208	50808	73564	\N	52.075589000000001	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Полины Осипенко, 18"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000037A968ACFD595C40FB777DE6AC094A40
33436	5	48	208	50808	27724	\N	52.0659340967429	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Подгорбунского, 98"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000002522FC8BA0585C40E4D87A8670084A40
33448	5	48	208	50808	24085	\N	52.071012127147803	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Новобульварная, 28"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000005DC30C8D27595C40D1CFD4EB16094A40
33438	5	48	208	50808	24085	\N	52.075165902943901	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Новобульварная, 60"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000003DB83B6BB7585C40B5E21B0A9F094A40
33435	5	48	208	50808	24085	\N	52.064923111788701	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Новобульварная, 64"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000CE1ABCAFCA595C400DE198654F084A40
33493	5	48	208	50808	28133	\N	52.027830000000002	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Недорезова, 16"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000000D71AC8BDB595C4081ECF5EE8F034A40
33515	5	48	208	50808	73700	\N	52.063865091660197	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Назара Широких, 10-А"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000F8FE06EDD5595C40F52D73BA2C084A40
33491	5	48	208	50808	73550	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Малая, 2"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33505	5	48	208	50808	73690	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Магистральная, 15а"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33697	5	48	214	51571	27254	\N	50.838447189226201	Ленинский, Ленина, 6	Россия, Забайкальский край, Улетовский район, село Ленинский	0101000020E6100000C2120F289BE05B40F436363B526B4940
33498	5	48	208	50808	73690	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Магистральная, 11"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000009B58E02BBA595C40F2237EC51A084A40
33453	5	48	208	50808	73694	\N	52.071143430009599	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Ленинградская, 67"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000E674594C6C595C406F2BBD361B094A40
33481	5	48	208	50808	73565	\N	52.067126585144301	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Лазо, 81"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000234C512E8D595C40DCD6169E97084A40
33492	5	48	208	50808	28128	\N	52.031717792821297	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Краснознаменная, 48"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000A3AEB5F7A95A5C40E658DE550F044A40
33512	5	48	208	50808	28407	\N	52.060855485922097	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Космонавтов, 10"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000C9AB730CC8565C402766BD18CA074A40
33526	5	48	208	50808	28028	\N	52.067669611938697	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Ключевая, 18-А"		0101000020E61000009B3924B550575C40CD751A69A9084A40
33497	5	48	208	50808	24631	\N	52.058315962847203	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Карла Маркса, 1"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000274C18CDCA575C40B16A10E676074A40
33468	5	48	208	50808	73570	\N	51.989195000000002	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Антипиха, Каларская, 30"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000473EAF78EA625C40F12E17F19DFE4940
33455	5	48	208	50808	27585	\N	52.067250667396202	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Кайдаловская, 10а"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000000BB6114F76595C40C8CF46AE9B084A40
33434	5	48	208	50808	28184	\N	52.067250999999999	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Июньская, 2"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000059DE550F98595C40C8CF46AE9B084A40
33538	5	48	208	50808	27066	\N	52.060785000000003	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Зыкова, 1-А"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000D1EAE40CC5595C402F8B89CDC7074A40
33495	5	48	208	50808	71712	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Донская, 11"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33530	5	48	208	50808	73706	\N	52.009605652199703	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Гайдара, 4"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000067D2A6EA1E565C4035ECF7C43A014A40
33529	5	48	208	50808	73706	\N	52.009112999999999	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Гайдара, 3-А"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000005C3AE63C63555C40F67B629D2A014A40
33517	5	48	208	50808	67758	\N	52.066279799759101	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Весенняя, 16-А"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000006BF0BE2A17575C407F30F0DC7B084A40
33513	5	48	208	50808	67758	\N	51.996444914787702	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Весенняя, 13"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000009ED2C1FA3F535C40A1A17F828BFF4940
33500	5	48	208	50808	71630	\N	52.063740586658398	"Забайкальский край, Городской округ ""Город Чита"", Железнодорожный административный район, Ватутина, 18"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000060CB2BD7DB595C40093543AA28084A40
33437	5	48	208	50808	28458	\N	52.062119000000003	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Богомягкова, 23а"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000D367075C57595C40E9BAF083F3074A40
33489	5	48	208	50808	24637	\N	52.072704674972897	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Баргузинская, 49"	Россия, Забайкальский край, Читинский район	0101000020E610000076A4FACE2F5C5C40BAA0BE654E094A40
33442	5	48	208	50808	67219	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Балябина, 44"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33485	5	48	208	50808	73745	\N	52.070663568337103	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Балейская, 2"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000060AFB0E07E595C40958098840B094A40
33751	5	48	208	7781	73996	\N	51.982022999999998	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Беклемишевское"", с.Иргень, ул.Центральная, Дом культуры"		0101000020E6100000A8902BF52C255C40BC75FEEDB2FD4940
33471	5	48	208	50808	27098	\N	52.061941889584098	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Бабушкина, 2б"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000004D83A279005A5C40DA1F28B7ED074A40
33447	5	48	208	50808	27098	\N	52.072626784477997	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Бабушкина, 66"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000005053CBD6FA585C403EE76ED74B094A40
33464	5	48	208	50808	24044	\N	52.064791999999997	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Анохина, 56"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000D3838252B4595C406E85B01A4B084A40
33463	5	48	208	50808	24044	\N	52.067203658757101	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Анохина, 71"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000E5B67D8FFA585C40871403249A084A40
33445	5	48	208	50808	24044	\N	52.07432	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Анохина, 110"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000009F3D97A949595C4028B8585183094A40
33478	5	48	208	50808	73703	\N	52.061748975826603	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Амурская, 15"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000A7069ACFB9595C40C5C72764E7074A40
33522	5	48	208	50808	27285	\N	52.0630186574191	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, Автозаводская, 3-А"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000002976340EF5565C406803B00111084A40
33457	5	48	208	50808	73585	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, 9 Января, 64"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33519	5	48	208	50808	73693	\N	52.063316999999998	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 6 микрорайон, 5"	Россия, Забайкальский край, Читинский район, Чита	0101000020E610000012A3E716BA595C40F2237EC51A084A40
33507	5	48	208	50808	67451	\N	52.069172708296001	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 5 микрорайон, 4"		0101000020E61000000DFFE9060A595C4013622EA9DA084A40
33506	5	48	208	50808	67451	\N	52.063740586658398	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 5 микрорайон, 3"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000006BF0BE2A17575C40093543AA28084A40
33533	5	48	208	50808	27531	\N	52.067972527879697	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 40 лет октября, 17"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000000B26FE28EA565C406901DA56B3084A40
33531	5	48	208	50808	27531	\N	51.996899999999997	"Забайкальский край, Городской округ ""Город Чита"", Черновский административный район, 40 лет октября, 6"	Россия, Забайкальский край, Читинский район, Чита	0101000020E6100000C4961E4DF5525C40F2B0506B9AFF4940
33439	5	48	208	50808	28588	\N	52.070588999999998	"Забайкальский край, Городской округ ""Город Чита"", Центральный административный район, Богомягкова, 121"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000006CE8667FA0595C408A3A730F09094A40
33768	5	48	208	8621	74001	\N	51.956654999999998	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Колочнинское"", с. Черново, ул.Центральная, ФАП"		0101000020E6100000B05582C5E14F5C400647C9AB73FA4940
33743	5	48	208	60055	73663	\N	52.157957000000003	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Угданское"", ул.Центральная, д.25"	Россия, Забайкальский край, Читинский район, село Угдан	0101000020E61000005A2E1B9DF35C5C404F965AEF37144A40
33747	5	48	208	7611	24510	\N	52.215103999999997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Арахлейское"", с.Тасей, ул.Центральная, д.12"		0101000020E61000002C802903073D5C40909E2287881B4A40
33774	5	48	208	8890	28307	\N	51.993504000000001	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Новотроицкое"", с.Танха, ул.Центральная, д.41"		0101000020E6100000876D8B321B7E5C40FC389A232BFF4940
33788	5	48	208	9504	73998	\N	51.351680000000002	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Оленгуйское"", с.Сыпчегур, ул.Комсомольская, контора лесничества"		0101000020E6100000FE2AC0779B5C5C402254A9D903AD4940
33753	5	48	208	7871	73743	\N	51.822629999999997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Сохондинское"",  с. Сохондо, ул.Центральная, д.78а"		0101000020E6100000B8AD2D3C2F215C40AF5A99F04BE94940
34279	5	48	208	795	28381	\N	52.139538000000002	"""Забайкальский край, муниципальный район """"Читинский район"""", сельское поселение """"Смоленское"""", село Смоленка, ул.Садовая д. № 2а"""		0101000020E61000007D40A03369605C404E469561DC114A40
33744	5	48	208	795	73616	\N	52.139538000000002	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Смоленское"",  с.Смоленка, ул.Садовая, д.2а"		0101000020E61000007D40A03369605C404E469561DC114A40
33706	5	48	214	47888	73934	\N	51.640239000000001	Красная Речка, Совхозная, 6	Россия, Забайкальский край, Улетовский район, село Красная Речка	0101000020E610000030F0DC7BB8435C40D74FFF59F3D14940
33769	5	48	208	8665	73802	\N	51.894067	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Сивяковское"", с.Сивяково, ул.Советская, д.34"	Россия, Забайкальский край, Читинский район, село Сивяково	0101000020E61000000262122EE44E5C4067B796C970F24940
33748	5	48	208	7659	\N	\N	52.214739999999999	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Арахлейское"", с.Преображенка, ул.Арахлейская, д.63"	Россия, Забайкальский край, Читинский район, село Преображенка	0101000020E6100000129F3BC1FE345C404F92AE997C1B4A40
33738	5	48	208	7196	73975	\N	52.420699999999997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Шишкинское"", с.Подволок, ул.Центральная, д.18"	Россия, Забайкальский край, Читинский район, село Подволок	0101000020E6100000D42CD0EE906B5C40AEB6627FD9354A40
33467	5	48	208	60052	\N	\N	51.979948999999998	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Песчанка, ДОС, 765"	Россия, Забайкальский край, Читинский район, Чита	0101000020E61000004A5D328E91655C40BB5F05F86EFD4940
33789	5	48	208	9555	27676	\N	51.306989000000002	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Оленгуйское"", с.Оленгуй, Центральная, д.47"		0101000020E6100000A29BFD81725A5C40AA9D616A4BA74940
33773	5	48	208	8833	73769	\N	51.992534536628597	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Новотроицкое"", с.Новотроицк, ул.Шоссейная, д.10"	Россия, Забайкальский край, Читинский район, село Новотроицк	0101000020E61000006405BF0D31865C4053910A630BFF4940
33781	5	48	208	60051	73628	\N	51.776451733149102	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Новокручининское"", ул.Рабочая, д.34"		0101000020E61000001BBCAFCA85725C40F77475C762E34940
33783	5	48	208	51414	27013	\N	51.776025785902	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Новокручининское"", ул.Фабричная, д.1а"	Россия, Забайкальский край, Читинский район, поселок городского типа Новокручининский	0101000020E6100000A29A92ACC3725C40406CE9D154E34940
33782	5	48	208	51414	27002	\N	51.771742476337401	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Новокручининское"", ул.Ленинградская, д.36"	Россия, Забайкальский край, Читинский район, поселок городского типа Новокручининский	0101000020E6100000CAC342AD69725C408E791D71C8E24940
33779	5	48	208	51414	33999	\N	51.774653283211101	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Новокручининское"", ул.Заводская, д.10а"	Россия, Забайкальский край, Читинский район, поселок городского типа Новокручининский	0101000020E6100000064A0A2C80725C40C85F5AD427E34940
33780	5	48	208	51414	67634	\N	51.774653283211101	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Новокручининское"", ул.Дорожная, д.29"	Россия, Забайкальский край, Читинский район, поселок городского типа Новокручининский	0101000020E610000007B29E5A7D725C40C85F5AD427E34940
33760	5	48	208	8241	73573	\N	51.795853419108397	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Новокукинское"", с. Новая-Кука, мкр.Забайкальская птицефабрика, д.66"	Россия, Забайкальский край, Читинский район, село Новая Кука	0101000020E6100000603FC4060B445C4035B6D782DEE54940
33791	5	48	208	51867	34005	\N	51.755016455171102	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Маккавеевское"", ул.Советская, д.47"	Россия, Забайкальский край, Читинский район, село Маккавеево	0101000020E610000010E9B7AF037B5C4076FA415DA4E04940
33792	5	48	208	51867	28439	\N	51.754699650493002	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Маккавеевское"", ул.Бутина, д.35"	Россия, Забайкальский край, Читинский район, село Маккавеево	0101000020E610000020EC14AB067B5C40462575029AE04940
33758	5	48	208	50697	23414	\N	51.733268564893301	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Леснинское"", с. Лесной городок, ул.Трактовая, д.8"	Россия, Забайкальский край, Читинский район, село Лесной Городок	0101000020E6100000CE55F31C91445C40D71533C2DBDD4940
33759	5	48	208	4189	73723	\N	51.770094652135001	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Новокукинское"", ст. Лесная, ул.Таежная, д.25"	Россия, Забайкальский край, Читинский район, село Лесная	0101000020E6100000F56393FC88405C4014E8137992E24940
33790	5	48	208	47729	27321	\N	51.1310437727223	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Ленинское"", ул.Первомайская, д.7"	Россия, Забайкальский край, Читинский район, село Ленинский	0101000020E61000001EFB592C45455C40242BBF0CC6904940
33767	5	48	208	8573	\N	\N	51.961405999999997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Колочнинское"", с. Колочное, ул.Южная, д.9"	Россия, Забайкальский край, Читинский район, село Колочное 1-е	0101000020E6100000E20511A9694A5C40CE16105A0FFB4940
33745	5	48	208	7522	\N	\N	52.206567	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Смоленское"", с. Карповка, мкр.ДФТБ"		0101000020E61000001E5036E50A625C4067B796C9701A4A40
33772	5	48	208	8799	28306	\N	52.064113999999996	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Новотроицкое"", с.Ильинка, ул.Набережная, д.20"		0101000020E610000073D712F2418B5C409D9B36E334084A40
33746	5	48	208	7587	73845	\N	52.269916326083703	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Арахлейское"", с. Иван-Озеро, ул.Центральная, д.15"		0101000020E610000028F04E3E3D405C406555849B8C224A40
33771	5	48	208	60060	73689	\N	52.011234850590299	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Засопкинское"", ул.Школьная, д.25"	Россия, Забайкальский край, Читинский район, село Засопка	0101000020E61000003CBEBD6BD05A5C4008C9022670014A40
33761	5	48	208	8284	73921	\N	51.804084000000003	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Новокукинское"", с. Жипковщина, ул.Школьная, д.20а"		0101000020E6100000425BCEA5B8405C40529E7939ECE64940
33770	5	48	208	8720	24526	\N	51.957842999999997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Сивяковское"", с.Еремино, ул.Центральная, д.16"		0101000020E6100000CAF962EFC5555C40ECD973999AFA4940
33785	5	48	208	9358	73733	\N	51.659405999999997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Елизаветинское"", с. Елизаветино, ул.Пионерская, д.6"		0101000020E6100000B01EF7ADD6665C40A164726A67D44940
33763	5	48	208	8385	73945	\N	51.963470000000001	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Ингодинское"", с. Домно-Ключи, ул.Партизанская, д.72а"		0101000020E61000006C3F19E3C33F5C40AC5626FC52FB4940
33766	5	48	208	59034	73712	\N	51.897959373440898	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Домнинское"", ул.Центральная, д.10"	Россия, Забайкальский край, Читинский район, село Домна	0101000020E610000055C1A8A44E4A5C400E130D52F0F24940
33765	5	48	208	59034	67330	\N	51.898085999999999	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Домнинское"", ул.Геологическая, д.1а"	Россия, Забайкальский край, Читинский район, село Домна	0101000020E6100000ED0F94DBF6495C406B7F677BF4F24940
33787	5	48	208	9452	27671	\N	51.582026999999997	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Елизаветинское"", с.Верх-Нарым, ул.Зеленая, д.3а"		0101000020E6100000C05AB56B425C5C40CA3159DC7FCA4940
33741	5	48	208	51816	28150	\N	52.227490166534899	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Верх-Читинское"", ул.Центральная, д.6"	Россия, Забайкальский край, Читинский район, село Верх-Чита	0101000020E6100000EB71DF6A9D605C4062156F641E1D4A40
33737	5	48	208	7159	74020	\N	52.421979999999998	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Шишкинское"", с.Бургень, ул.Школьная, д.17"		0101000020E6100000D4BA0D6ABF715C4075C8CD7003364A40
33750	5	48	208	7733	67867	\N	52.119374999999998	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Беклемишевское"", с. Беклемишево, ул.Бурлова, д.12"		0101000020E6100000C4EC65DB692B5C40E17A14AE470F4A40
33776	5	48	208	60044	73588	\N	51.929141000000001	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Атамановское"", ул.Матюгина, д.156"		0101000020E610000054E3A59BC4685C40B62FA017EEF64940
33775	5	48	208	40314	27796	\N	51.931841374627297	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Атамановское"", ул.Рабочая, д.3"	Россия, Забайкальский край, Читинский район, поселок городского типа Атамановка	0101000020E6100000E014562AA8685C403509DE9046F74940
33777	5	48	208	40314	9797	\N	51.921953648016697	"Забайкальский край, муниципальный район ""Читинский район"", городское поселение ""Атамановское"", ул.Заводская, д.1"	Россия, Забайкальский край, Читинский район, поселок городского типа Атамановка	0101000020E61000005308E41247695C404C35B39602F64940
33749	5	48	208	7699	73919	\N	52.162841	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Арахлейское"", с. Арахлей, ул.Центральная, д.15"	Россия, Забайкальский край, Читинский район, село Арахлей	0101000020E6100000C8B260E28F355C4056B950F9D7144A40
33739	5	48	208	7254	28257	\N	52.370170999999999	"Забайкальский край, муниципальный район ""Читинский район"", сельское поселение ""Шишкинское"", с.Авдей, ул.Весенняя, д.4а"		0101000020E61000007C0BEBC6BB685C40BC7669C3612F4A40
34221	5	48	1886	59093	67714	\N	52.522396000000001	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Чернышевское"", Молодежная, 12"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Чернышевск	0101000020E6100000CEC4742156415D40D6C743DFDD424A40
34220	5	48	1886	51513	73683	\N	52.539313790586	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Чернышевское"", Центральная, 8"		0101000020E6100000E7DF2EFB75415D403123BC3D08454A40
34218	5	48	1886	51513	27167	\N	52.537639076002698	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Чернышевское"", Лазо, 23"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Чернышевск	0101000020E6100000F9BF232A54415D40EE06D15AD1444A40
33414	5	48	214	23431	67745	\N	51.564733336990002	Дровяная, Кирова, 39	Россия, Забайкальский край, Улетовский район, поселок городского типа Горный	0101000020E610000059198D7C5E425C4069FCC22B49C84940
34224	5	48	1886	51513	73901	\N	52.518549807023902	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Чернышевское"", Железнодорожная, 59"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Чернышевск	0101000020E6100000FD135CACA8405D409FABADD85F424A40
34223	5	48	1886	51648	27418	\N	52.521004767956498	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Чернышевское"", Первомайская, 70"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Чернышевск	0101000020E610000098FC4FFEEE405D40B806B64AB0424A40
34217	5	48	1886	51648	28585	\N	52.524308884556703	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Чернышевское"", Партизанская, 26"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Чернышевск	0101000020E61000009ACC785BE9405D40CEFFAB8E1C434A40
34222	5	48	1886	51648	71530	\N	52.522396000000001	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Чернышевское"", Журавлева, 61а"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Чернышевск	0101000020E6100000CEC4742156415D40D6C743DFDD424A40
34249	5	48	1886	59482	71573	\N	52.572668999999998	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Утанское"", Погодаева, 45б"	Россия, Забайкальский край, Чернышевский район, село Утан	0101000020E6100000C45F9335EA3E5D406D37C1374D494A40
34253	5	48	1886	51731	\N	\N	53.167216759520898	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Урюмское"", здание администрации сельского поселения ""Урюмское"""	Россия, Забайкальский край, Чернышевский район, село Урюм	0101000020E6100000D1AE42CA4F875D40E92ADD5D67954A40
34252	5	48	1886	51731	73848	\N	53.169789867180903	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Урюмское"", Папанина, 39"		0101000020E610000022E2E65432875D400B98C0ADBB954A40
34244	5	48	1886	60088	73767	\N	52.347971982575203	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Укурейское"", Транспортная, 1"	Россия, Забайкальский край, Чернышевский район, село Укурей	0101000020E6100000D3DA34B6D7405D403CF6B3588A2C4A40
34237	5	48	1886	50725	23464	\N	52.453658322217102	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Старооловское"", Ленина, 49а"	Россия, Забайкальский край, Чернышевский район	0101000020E6100000EB36A8FDD62B5D40CDC82077113A4A40
34235	5	48	1886	60153	73939	\N	52.607059999999997	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Новооловское"", Партизанская, 9"	Россия, Забайкальский край, Чернышевский район, село Новый Олов	0101000020E6100000020D36751E215D40D95A5F24B44D4A40
34236	5	48	1886	60153	73925	\N	52.596808268338201	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Новооловское"", Журавлева, 17а"	Россия, Забайкальский край, Чернышевский район, село Новый Олов	0101000020E6100000C72B103D29215D40DFFE5C34644C4A40
34238	5	48	1886	60192	74009	\N	52.512982000000001	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Новоильинское"", Ленина, 49а"	Россия, Забайкальский край, Чернышевский район, село Новоильинск	0101000020E6100000FA635A9BC6305D40E5B7E864A9414A40
34250	5	48	1886	60114	73821	\N	52.658252658704299	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Мильгидунское"", Молодежная, 21"	Россия, Забайкальский край, Чернышевский район, село Мильгидун	0101000020E61000003B8908FF223B5D4038BF61A241544A40
34245	5	48	1886	51750	27828	\N	52.371851272589197	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Курлыченское"", Школьная, 1"	Россия, Забайкальский край, Чернышевский район, село Курлыч	0101000020E6100000354415FE0C505D4011FE45D0982F4A40
34239	5	48	1886	51887	28513	\N	52.350155131088201	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Комсомольское"", Набережная, 6"	Россия, Забайкальский край, Чернышевский район, село Комсомольское	0101000020E61000000C03965CC5375D40F4C308E1D12C4A40
34241	5	48	1886	51887	74014	\N	52.350448999999998	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Комсомольское"", Базарная, 127"	Россия, Забайкальский край, Чернышевский район, село Комсомольское	0101000020E61000004165FCFB8C375D403CF54883DB2C4A40
34247	5	48	1886	60191	\N	\N	52.46799	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Икшицкое"", здание средней школы"	Россия, Забайкальский край, Чернышевский район, село Икшица	0101000020E61000000CCA349A5C4C5D40726DA818E73B4A40
34229	5	48	1886	59054	\N	\N	52.815664693367602	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Жирекенское"", здание МОУ СОШ"		0101000020E6100000B212F3ACA4525D40F5BEF1B567684A40
34230	5	48	1886	60047	\N	\N	52.822538000000002	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Жирекенское"", здание Центра досуга"		0101000020E61000008FFB56EBC4525D40CFDBD8EC48694A40
31643	5	48	214	811	28043	\N	51.124707999999998	Доронинское, Пионерская, 22		0101000020E61000009370218FE0095C4058C6866EF68F4940
39249	3	24	459	18659	59301	\N	64.490468000000007	п.Золотец, ул.Центральная, д.10А		0101000020E61000000307B4740553414003EFE4D3631F5040
34246	5	48	1886	60193	74012	\N	52.444485999999998	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Гаурское"", Центральная, 2"	Россия, Забайкальский край, Чернышевский район, село Гаур	0101000020E610000066BD18CA89415D40D2C3D0EAE4384A40
34251	5	48	1886	50810	23706	\N	52.743888444551601	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Бушулейское"", Железнодорожная, 7-10"	Россия, Забайкальский край, Чернышевский район, село Бушулей	0101000020E6100000802DAF5C6F515D4084F1D3B8375F4A40
34225	5	48	1886	60177	73972	\N	52.979161513035997	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Букачачинское"", Вокзальная, 1"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Букачача	0101000020E61000002BDEC83CF2395D4034BE2F2E557D4A40
34228	5	48	1886	50921	27667	\N	52.996253893864697	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Букачачинское"", Центральная, 16"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Букачача	0101000020E610000051DD5CFC6D3A5D402D414640857F4A40
34227	5	48	1886	50921	74023	\N	52.981431682729898	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Букачачинское"", Фабричный переулок, 2"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Букачача	0101000020E6100000AF415F7AFB3A5D40BA9F53909F7D4A40
34226	5	48	1886	50921	73713	\N	52.977964306151399	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Букачачинское"", Клубный проспект, 1"		0101000020E6100000008BFCFA213A5D402A55A2EC2D7D4A40
34243	5	48	1886	60067	73717	\N	52.246490000000001	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Байгульское"", Советская, 5"	Россия, Забайкальский край, Чернышевский район, село Байгул	0101000020E61000006D72F8A413305D404165FCFB8C1F4A40
94933	5	48	1886	51624	27366	\N	52.403768785946298	"""Забайкальский край, муниципальный район """"Чернышевский район"""", сельское поселение """"Багульное"""", Набережная, 10"""	Россия, Забайкальский край, Чернышевский район, село Багульный	0101000020E610000093C6681D55335D40BE11DDB3AE334A40
34248	5	48	1886	51518	27173	\N	52.554034593820496	"Забайкальский край, муниципальный район ""Чернышевский район"", сельское поселение ""Алеурское"", Кирова, 45а"	Россия, Забайкальский край, Чернышевский район, село Алеур	0101000020E6100000771211FE45445D4070EB6E9EEA464A40
34231	5	48	1886	51062	\N	\N	53.070065769441499	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Аксёново-Зиловское"", здание клуба железнодорожников"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Аксеново-Зиловское	0101000020E6100000ECDCB419A7605D40E04735ECF7884A40
34234	5	48	1886	60081	\N	\N	53.071425591431698	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Аксёново-Зиловское"", микрорайон ""Берёзка"", здание ТСЖ"		0101000020E61000007D3F355EBA605D40C40AB77C24894A40
34233	5	48	1886	60081	73850	\N	53.067037116223098	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Аксёново-Зиловское"", Октябрьская, 9"	Россия, Забайкальский край, Чернышевский район, поселок городского типа Аксеново-Зиловское	0101000020E6100000E4BED53A71605D409C4F1DAB94884A40
34232	5	48	1886	60081	73755	\N	53.071172873301499	"Забайкальский край, муниципальный район ""Чернышевский район"", городское поселение ""Аксёново-Зиловское"", Западная, 1"		0101000020E610000045F12A6B9B605D40DAAD65321C894A40
33728	5	48	809	60063	73711	\N	51.427350848053301	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Хушенгинское"", Центральная, 24"	Россия, Забайкальский край, Хилокский район, село Хушенга	0101000020E610000057410C74EDBA5B40DA740470B3B64940
33714	5	48	809	50925	73556	\N	51.356506000000003	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Хилокское"", Новая, 22 А"	Россия, Забайкальский край, Хилокский район, Хилок	0101000020E610000049B9FB1C1F9D5B40F56915FDA1AD4940
33712	5	48	809	50925	67556	\N	51.356506000000003	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Хилокское"", Кирова, 37 А"	Россия, Забайкальский край, Хилокский район, Хилок	0101000020E610000049B9FB1C1F9D5B40F56915FDA1AD4940
33710	5	48	809	50925	24069	\N	51.3625834396912	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Хилокское"", Калинина, 16"	Россия, Забайкальский край, Хилокский район, Хилок	0101000020E6100000B41D5377659D5B40F48AA71E69AE4940
33711	5	48	809	50925	27283	\N	51.351310155678597	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Хилокское"", Ленина, 20"	Россия, Забайкальский край, Хилокский район, Хилок	0101000020E6100000B41D5377659D5B40FE60E0B9F7AC4940
33713	5	48	809	50925	27953	\N	51.354176544381602	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Хилокское"", Карла Маркса, 78"	Россия, Забайкальский край, Хилокский район, Хилок	0101000020E610000054539275389D5B4069FF03AC55AD4940
33726	5	48	809	6651	\N	\N	51.150348000000001	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Хилогосонское"", с. Хилогосон, СДК"		0101000020E6100000E107E753C7A85B406F826F9A3E934940
33732	5	48	809	51545	27212	\N	51.554230808307999	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Харагунское"", Шоссеная, 43"	Россия, Забайкальский край, Хилокский район, село Харагун	0101000020E6100000C6504EB4ABCB5B40F6B6990AF1C64940
33731	5	48	809	51545	73764	\N	51.555943395713001	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Харагунское"", Вокзальная, 20"	Россия, Забайкальский край, Хилокский район, село Харагун	0101000020E61000008AABCABE2BCB5B4056B8E52329C74940
33715	5	48	809	6049	\N	\N	51.316374000000003	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Закультинское"", с. Ушоты, СДК"	Россия, Забайкальский край, Хилокский район, село Ушоты	0101000020E61000004754A86E2E695B4001A777F17EA84940
33721	5	48	809	6349	\N	\N	51.353569999999998	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Бадинское"", с. Тэрэпхэн, СДК"		0101000020E6100000060DFD135C795B40616C21C841AD4940
33735	5	48	809	51009	28566	\N	51.745047051776801	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Могзонское"", Советская, 47"	Россия, Забайкальский край, Хилокский район, поселок городского типа Могзон	0101000020E610000089D00836AEFD5B40D07D39B35DDF4940
33734	5	48	809	51009	73795	\N	51.737379432908703	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Могзонское"", Комсомольская, 20"	Россия, Забайкальский край, Хилокский район, поселок городского типа Могзон	0101000020E61000007EFE7BF0DAFD5B40EBE0606F62DE4940
33733	5	48	809	51009	24351	\N	51.739150336086901	"Забайкальский край, муниципальный район ""Хилокский район"", городское поселение ""Могзонское"", Деповская, 1"	Россия, Забайкальский край, Хилокский район, поселок городского типа Могзон	0101000020E610000061A7583508FE5B40516B9A779CDE4940
33724	5	48	809	59031	67320	\N	51.359785000000002	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Линёво-Озерское"", Хлуднева, 7"	Россия, Забайкальский край, Хилокский район, село Линево Озеро	0101000020E6100000BE141E34BBA95B40B24B546F0DAE4940
33720	5	48	809	6313	\N	\N	51.402197999999999	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Бадинское"", с. Зурун, СДК"		0101000020E610000028EE7893DF7D5B4020425C397BB34940
33716	5	48	809	51543	73837	\N	51.358619013951198	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Закультинское"", Школьная, 11"		0101000020E610000044DB3175576F5B40B35C363AE7AD4940
33723	5	48	809	60053	73648	\N	51.457667000000001	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Жипхегенское"", Таёжная, 25"	Россия, Забайкальский край, Хилокский район, село Жипхеген	0101000020E61000008350DEC7D18A5B40AEBA0ED594BA4940
33729	5	48	809	6777	\N	\N	51.485213999999999	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Харагунское"""", с. Дайгур, Медпункт"		0101000020E6100000C1A7397991C35B40DAC70A7E1BBE4940
33725	5	48	809	6576	73750	\N	51.398995999999997	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Линёво-Озерское"", с. Гыршелун, ул. Первомайская, 4"		0101000020E610000086764EB340AA5B400E9E094D12B34940
33722	5	48	809	6428	\N	\N	51.424719000000003	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Глинкинское"", с. Глинка, Администрация с/п ""Глинкинское"""		0101000020E61000004D4C1762F5825B40B37E33315DB64940
33718	5	48	809	58981	67155	\N	51.388840999999999	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Бадинское"", Пионерская, 43"	Россия, Забайкальский край, Хилокский район, село Бада	0101000020E6100000333509DE90775B40062CB98AC5B14940
33717	5	48	809	58981	67855	\N	51.388840999999999	"Забайкальский край, муниципальный район ""Хилокский район"", сельское поселение ""Бадинское"", Лесная, 44"	Россия, Забайкальский край, Хилокский район, село Бада	0101000020E6100000333509DE90775B40062CB98AC5B14940
33703	5	48	214	5408	73984	\N	51.031467999999997	Шехолан, Школьная, 1		0101000020E61000003CA41820D1FB5B406D6FB72407844940
33698	5	48	214	5129	\N	\N	51.031247	Шебартуй, Центральная	Россия, Забайкальский край, Улетовский район, село Шебартуй 2-й	0101000020E61000001FBC7669C3D85B408F8CD5E6FF834940
32126	5	48	214	48451	24263	\N	51.459553	Черемхово, Чехова, 24		0101000020E6100000CEFC6A0E102E5C40ACE3F8A1D2BA4940
32055	5	48	214	21534	73738	\N	51.425359	Хадакта, Большая, 16		0101000020E6100000FBC9181F66245C409607E92972B64940
30198	5	48	214	3267	34034	\N	51.357838999999998	Улеты, Лазо, 124	Россия, Забайкальский край, Улетовский район, село Улеты	0101000020E61000003C69E1B20A1F5C40DE1D19ABCDAD4940
31686	5	48	214	3267	67423	\N	51.357838999999998	Улеты, Кооперативная, 16		0101000020E61000003C69E1B20A1F5C40DE1D19ABCDAD4940
31782	5	48	214	3267	73639	\N	51.357838999999998	Улеты, Дорожная, 14		0101000020E61000003C69E1B20A1F5C40DE1D19ABCDAD4940
33354	5	48	214	45427	73794	\N	51.600436000000002	с.Татаурово, Кирова, 108		0101000020E61000003EAF78EA913B5C40A8AB3B16DBCC4940
33700	5	48	214	5249	73752	\N	50.983221	Танга, Партизанская, 1а	Россия, Забайкальский край, Улетовский район, село Танга	0101000020E610000076AA7CCF48E35B40C6DE8B2FDA7D4940
33699	5	48	214	5181	27286	\N	50.977702999999998	Новосалия, Центральная, 40		0101000020E6100000D4997B48F8DA5B40BD19355F257D4940
33702	5	48	214	47814	67145	\N	51.056238	Николаевское, Октябрьская, 68	Россия, Забайкальский край, Улетовский район, село Николаевское	0101000020E610000026E5EE737CF15B406F6589CE32874940
15657	5	47	\N	902	70783	\N	53.003270999999998	Алтайский край, г.Славгород, п.Бурсоль, Советская, 3		0101000020E6100000B796C9703CA953403A03232F6B804A40
33707	5	48	214	59072	67527	\N	51.555967000000003	Забайкальский край, ЗАТО поселок Горный, Площадь Тюрина, 1	Россия, Забайкальский край, Улетовский район, поселок городского типа Горный	0101000020E6100000226DE34F54425C40DF5339ED29C74940
33709	5	48	214	58976	73772	\N	51.555967000000003	Забайкальский край, ЗАТО поселок Горный, Таежная, МОУ СОШ №2	Россия, Забайкальский край, Улетовский район, поселок городского типа Горный	0101000020E6100000226DE34F54425C40DF5339ED29C74940
33708	5	48	214	58976	67142	\N	51.555967000000003	Забайкальский край, ЗАТО поселок Горный, Молодежная, 33	Россия, Забайкальский край, Улетовский район, поселок городского типа Горный	0101000020E6100000226DE34F54425C40DF5339ED29C74940
33688	5	48	214	4612	28540	\N	51.123277999999999	Горекацан, Шоссейная, 6		0101000020E6100000E1D1C6116BFC5B407C28D192C78F4940
33704	5	48	214	5449	73916	\N	51.074005999999997	Горека, Школьная, бн	Россия, Забайкальский край, Улетовский район, село Горека	0101000020E61000003B527DE717FF5B4098DA520779894940
33705	5	48	214	5533	73989	\N	51.623092999999997	Голубичная, Набережная, 6		0101000020E610000002B9C49107435C40EAAEEC82C1CF4940
33654	5	48	214	2756	\N	\N	51.356662999999998	Бальзой, Центральная, бн	Россия, Забайкальский край, Улетовский район, село Бальзой	0101000020E6100000027E8D2441175C40BC581822A7AD4940
33631	5	48	214	1414	73749	\N	51.249590957133599	Арта, Советская, 27	Россия, Забайкальский край, Улетовский район, село Арта	0101000020E61000001FDB32E02C195C401F300F99F29F4940
33696	5	48	214	47696	74000	\N	50.971745925531003	с.Арей, Школьная, 2	Россия, Забайкальский край, Улетовский район, село Арей	0101000020E61000001BD6541685CF5B406902452C627C4940
33577	5	48	214	31045	27438	\N	51.245969000000002	Аблатукан, Трудовая, 26		0101000020E610000056B60F79CB075C40386A85E97B9F4940
33551	5	48	214	29767	27374	\N	51.18721	Аблатуйский Бор, Центральная, 62		0101000020E6100000ACAB02B5180E5C40F9BD4D7FF6974940
33694	5	48	614	60159	73932	\N	52.650668673065603	"Забайкальский край, муниципальный район ""Тунгокоченский район"", сельское поселение ""Усуглинское"", Советская, 1"	Россия, Забайкальский край, Тунгокоченский район, село Усугли	0101000020E61000000FD6FF39CCD05C40B1C22D1F49534A40
33691	5	48	614	60082	73758	\N	53.532624375034601	"Забайкальский край, муниципальный район ""Тунгокоченский район"", сельское поселение ""Тунгокоченское"", Центральная, 7"	Россия, Забайкальский край, Тунгокоченский район, село Тунгокочен	0101000020E61000002C67EF8CB6E75C404888F2052DC44A40
33687	5	48	614	51822	\N	\N	52.288923605521397	"Забайкальский край, муниципальный район ""Тунгокоченский район"", сельское поселение ""Нижнестанское"", ФАП"	Россия, Забайкальский край, Тунгокоченский район, село Нижний Стан	0101000020E610000089D00836AEED5C40C7832D76FB244A40
33676	5	48	614	51822	\N	\N	52.2902951339845	"Забайкальский край, муниципальный район ""Тунгокоченский район"", сельское поселение ""Нижнестанское"", сельский дом культуры"	Россия, Забайкальский край, Тунгокоченский район, село Нижний Стан	0101000020E6100000B806B64AB0ED5C409E98F56228254A40
33686	5	48	614	60115	73822	\N	54.123159999999999	"Забайкальский край, муниципальный район ""Тунгокоченский район"", сельское поселение ""Нижнестанское"", Клубная, 1"		0101000020E6100000DD0BCC0A45005D407216F6B4C30F4B40
33679	5	48	614	60056	73702	\N	52.36421	"Забайкальский край, муниципальный район ""Тунгокоченский район"", городское поселение ""Вершино-Дарасунское"", Центральная, 31"		0101000020E610000034D593F947E25C402670EB6E9E2E4A40
33682	5	48	614	60056	73753	\N	52.364843036445897	"Забайкальский край, муниципальный район ""Тунгокоченский район"", городское поселение ""Вершино-Дарасунское"", Рабочая, 1"	Россия, Забайкальский край, Тунгокоченский район, поселок городского типа Вершино-Дарасунский	0101000020E61000000EDDEC0F94E15C405796E82CB32E4A40
33677	5	48	614	60056	73785	\N	52.364405247656698	"Забайкальский край, муниципальный район ""Тунгокоченский район"", городское поселение ""Вершино-Дарасунское"", Подгорная, 1"		0101000020E61000007E8B4E965AE15C40DBBFB2D2A42E4A40
33680	5	48	614	60056	73665	\N	52.364300161278699	"Забайкальский край, муниципальный район ""Тунгокоченский район"", городское поселение ""Вершино-Дарасунское"", Лесная, 13"		0101000020E61000004F3E3DB665E35C4066F7E461A12E4A40
33683	5	48	614	51774	73624	\N	52.367032325462901	"Забайкальский край, муниципальный район ""Тунгокоченский район"", городское поселение ""Вершино-Дарасунское"", Центральная, 1"	Россия, Забайкальский край, Тунгокоченский район, поселок городского типа Вершино-Дарасунский	0101000020E61000001ADCD6169EE15C40F14A92E7FA2E4A40
33678	5	48	614	51774	28062	\N	52.370528970335897	"Забайкальский край, муниципальный район ""Тунгокоченский район"", городское поселение ""Вершино-Дарасунское"", Дарасунская, 78"	Россия, Забайкальский край, Тунгокоченский район, поселок городского типа Вершино-Дарасунский	0101000020E61000007BDAE1AFC9E15C401B9C887E6D2F4A40
33681	5	48	614	54085	33992	\N	52.367872957202103	"Забайкальский край, муниципальный район ""Тунгокоченский район"", городское поселение ""Вершино-Дарасунское"", Цыборо, 1"	Россия, Забайкальский край, Тунгокоченский район, поселок городского типа Вершино-Дарасунский	0101000020E610000039B709F7CAE35C406C0A6476162F4A40
33693	5	48	614	51866	28434	\N	52.694888918520299	"Забайкальский край, муниципальный район ""Тунгокоченский район"", сельское поселение ""Усуглинское"", Кооперативная, 2а"	Россия, Забайкальский край, Тунгокоченский район, село Верхние Усугли	0101000020E610000097546D37C1CB5C40D2AC6C1FF2584A40
75144	3	32	\N	57377	58384	\N	56.023108000000001	г.Невель, ул.Урицкого, д.36		0101000020E610000001F73C7FDAEC3D405323F433F5024C40
33675	5	48	614	51866	67537	\N	52.689734999999999	"Забайкальский край, муниципальный район ""Тунгокоченский район"", сельское поселение ""Верх-Усуглинское"", Клубная, 1"	Россия, Забайкальский край, Тунгокоченский район, село Верхние Усугли	0101000020E6100000605969520ACC5C400AF4893C49584A40
33670	5	48	586	60078	73751	\N	54.428007663196702	"Забайкальский край, муниципальный район ""Тунгиро-Олекминский район"", сельское поселение ""Тупикское"", Нагорная, 20"	Россия, Забайкальский край, Тунгиро-Олекминский район, село Тупик	0101000020E6100000B16F2711E1FB5D40933655F7C8364B40
33671	5	48	586	21883	73986	\N	54.459776302983002	"Забайкальский край, муниципальный район ""Тунгиро-Олекминский район"", сельское поселение ""Зареченское"", Центральная, 3"	Россия, Забайкальский край, Тунгиро-Олекминский район, село Заречное	0101000020E6100000C8091346B3FB5D402BBEA1F0D93A4B40
34210	5	48	1840	51732	27743	\N	52.576251355358302	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Шилко- Заводское"", Центральная, 1"	Россия, Забайкальский край, Сретенский район, село Шилкинский Завод	0101000020E610000021CB82893FAB5D40C6A4BF97C2494A40
34198	5	48	1840	51690	27522	\N	52.370198976959102	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Чикичейское"", Титкова, 29"	Россия, Забайкальский край, Сретенский район, село Чикичей	0101000020E6100000D7169E978A5F5D4086014BAE622F4A40
34209	5	48	1840	52248	73870	\N	52.451588999999998	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Ботовское"" с. Чалбучи, Луговая, 2"	Россия, Забайкальский край, Сретенский район, село Чалбучи	0101000020E61000001C7DCC0704A85D40DE1D19ABCD394A40
34204	5	48	1840	60146	73910	\N	52.313751406732102	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Фирсовское"", Набережная, 36"	Россия, Забайкальский край, Сретенский район, село Фирсово	0101000020E6100000E833A0DE8C885D402D0B26FE28284A40
34195	5	48	1840	60156	73928	\N	52.268265850263802	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Усть-Наринзорское"", Центральная, 4"	Россия, Забайкальский край, Сретенский район, село Усть-Наринзор	0101000020E6100000BC74931804575D407A50508A56224A40
34189	5	48	1840	60139	73893	\N	52.164160538392402	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Кокуйское"" с. Усть-Курлыч, Школьная, Школа"	Россия, Забайкальский край, Сретенский район, село Усть-Курлыч	0101000020E610000059164CFC515D5D40AB23473A03154A40
34214	5	48	1840	51678	27492	\N	52.699199612870203	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение "" Усть-Карское"", Киргизова, 20"	Россия, Забайкальский край, Сретенский район, поселок городского типа Усть-Карск	0101000020E6100000B665C0594AB35D407DAEB6627F594A40
34213	5	48	1840	60096	73786	\N	52.708586720054399	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение "" Усть-Карское"", Советская, 18"	Россия, Забайкальский край, Сретенский район, поселок городского типа Усть-Карск	0101000020E61000008BFD65F7E4B35D4075AF93FAB25A4A40
34205	5	48	1840	52244	73976	\N	52.331350999999998	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Фирсовское"" с. Уктыча, Набережная, 13"		0101000020E610000042EDB776A2915D409A3FA6B5692A4A40
34179	5	48	1840	50855	73899	\N	52.231020000000001	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Энергетиков, 6"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E61000005E6397A8DE6B5D40685C3810921D4A40
34176	5	48	1840	50855	73827	\N	52.24146066886	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Фабричная, 6"		0101000020E61000001A506F46CD6C5D403621AD31E81E4A40
34184	5	48	1840	50855	73895	\N	52.2368705381813	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Сельская, 51"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E6100000CBBF9657AE6C5D40772FF7C9511E4A40
34178	5	48	1840	50855	28578	\N	52.240336567837097	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Партизанская, 37"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E6100000698D4127846C5D406682E15CC31E4A40
34181	5	48	1840	50855	27760	\N	52.2411796205594	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Набережная, 69"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E610000042791F47736C5D4082397AFCDE1E4A40
34177	5	48	1840	50855	74008	\N	52.231600680375799	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Молодежная, 2"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E61000007D59DAA9B96B5D40465C001AA51D4A40
34180	5	48	1840	50855	73808	\N	52.238556759878101	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Луначарского, 226"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E6100000C8EF6DFAB36C5D40AE9D2809891E4A40
34182	5	48	1840	50855	28504	\N	52.241577775542503	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Клубная, 3"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E6100000B6A0F7C6106D5D406FB72407EC1E4A40
34183	5	48	1840	50855	73866	\N	52.2364489726966	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Сретенское"", Вокзальная, 1"	Россия, Забайкальский край, Сретенский район, Сретенск	0101000020E6100000B4E55C8AAB6C5D400116F9F5431E4A40
34192	5	48	1840	52227	73997	\N	52.090398495299702	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Дунаевское"" с. Нижняя Куэнга, Нагорная, 11"	Россия, Забайкальский край, Сретенский район, село Нижняя Куэнга	0101000020E6100000D7D9907F66415D40D9CF6229920B4A40
34202	5	48	1840	51629	27381	\N	52.261829384505397	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Молодовское"", Набережная, 50а"	Россия, Забайкальский край, Сретенский район, село Молодовск	0101000020E6100000AFB2B6291E785D407B12D89C83214A40
34203	5	48	1840	51504	27148	\N	52.2856278374637	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Молодовское"" с. Ломы, Молодежная, 28"	Россия, Забайкальский край, Сретенский район, село Ломы	0101000020E6100000698A00A777805D40346953758F244A40
34200	5	48	1840	52240	74006	\N	52.401626999999998	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Чикичейское"" с. Кулан, Новая, 14"	Россия, Забайкальский край, Сретенский район, село Кулан	0101000020E6100000D87E32C687565D406518778368334A40
34206	5	48	1840	52245	73868	\N	52.386816974853801	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Фирсовское"" с. Кудея, Нижняя, 9 кв.2"	Россия, Забайкальский край, Сретенский район, село Кудея	0101000020E6100000CA1AF5108D8A5D40B7442E3883314A40
34187	5	48	1840	54087	\N	\N	52.207667617598503	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Кокуйское"", ПУ-30"	Россия, Забайкальский край, Сретенский район, поселок городского типа Кокуй	0101000020E61000006534F279C5625D407E3672DD941A4A40
33896	5	48	1840	54087	74063	\N	52.2062103018377	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Первококуйское"", Новая, 14"	Россия, Забайкальский край, Сретенский район, поселок городского типа Кокуй	0101000020E6100000B91B446B45635D40D80DDB16651A4A40
34185	5	48	1840	54087	73582	\N	52.204417377080297	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Кокуйское"", Заводская, 22"	Россия, Забайкальский край, Сретенский район, поселок городского типа Кокуй	0101000020E6100000A4FCA4DAA7635D408BDF14562A1A4A40
34186	5	48	1840	51843	28292	\N	52.204995902796398	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Кокуйское"", 2-Набережная, 10"	Россия, Забайкальский край, Сретенский район, поселок городского типа Кокуй	0101000020E61000006534F279C5625D40C9E7154F3D1A4A40
34188	5	48	1840	51843	73812	\N	52.208741000000003	"Забайкальский край, муниципальный район ""Сретенский район"", городское поселение ""Кокуйское"", 1-Луговая, 6"	Россия, Забайкальский край, Сретенский район, поселок городского типа Кокуй	0101000020E6100000A12C7C7DAD635D40CC2A6C06B81A4A40
34190	5	48	1840	50914	73867	\N	52.069645000000001	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Дунаевское"", Школьная, 9"	Россия, Забайкальский край, Сретенский район, село Дунаево	0101000020E6100000AA656B7D91435D403BAA9A20EA084A40
34191	5	48	1840	50914	24055	\N	52.070044750503598	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Дунаевское"", Нагорная, 2"	Россия, Забайкальский край, Сретенский район, село Дунаево	0101000020E6100000096CCEC133435D40C91F0C3CF7084A40
34197	5	48	1840	52234	74002	\N	52.20937	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Усть-Наринзорское"" с. Делюн, Центральная, 21"	Россия, Забайкальский край, Сретенский район, село Делюн	0101000020E61000002DEC6987BF5C5D40BB61DBA2CC1A4A40
34216	5	48	1840	51422	27009	\N	53.097798355894902	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Верхне- Куларкинское"" с. Горбица, Набережная, 4а"	Россия, Забайкальский край, Сретенский район, село Горбица	0101000020E6100000850662D9CCCD5D409ECE15A5848C4A40
34193	5	48	1840	51762	27890	\N	52.135368104740103	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Верхне -Куэнгинское"", Центральная, 17"	Россия, Забайкальский край, Сретенский район, село Верхняя Кузнга	0101000020E610000043A9BD88B6435D40647616BD53114A40
34215	5	48	1840	60204	74034	\N	52.829470000000001	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Верхне- Куларкинское"", Молодежная, 1"	Россия, Забайкальский край, Сретенский район, село Верхние Куларки	0101000020E61000008CBB41B456BC5D40AE81AD122C6A4A40
34208	5	48	1840	60183	73987	\N	52.643684999999998	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Ботовское"", Шилкинская, 26"		0101000020E610000055DD239BAB995D407FF6234564524A40
34207	5	48	1840	51764	27905	\N	52.470847938623798	"Забайкальский край, муниципальный район ""Сретенский район"",  сельское поселение ""Фирсовское"" с. Бори, Центральная, 1"	Россия, Забайкальский край, Сретенский район, село Бори	0101000020E610000028B682A625875D4089B14CBF443C4A40
15650	5	47	\N	902	70123	\N	53.003270999999998	Алтайский край, г.Славгород, Розы Люксембург, 121		0101000020E6100000B796C9703CA953403A03232F6B804A40
34194	5	48	1840	51503	27146	\N	52.082191111586198	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Верхне -Куэнгинское"" с. Болотово, Центральная, 32"	Россия, Забайкальский край, Сретенский район, село Болотово	0101000020E6100000C939B187F64E5D404583143C850A4A40
34201	5	48	1840	51654	27432	\N	52.313949286423799	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение "" Алиянское"", Красноармейская, 46"	Россия, Забайкальский край, Сретенский район, село Алия	0101000020E6100000DCF3FC69A3675D4053CE177B2F284A40
34199	5	48	1840	52238	74011	\N	52.436712999999997	"Забайкальский край, муниципальный район ""Сретенский район"", сельское поселение ""Чикичейское"" с. Адом, Зеленая, 16"		0101000020E6100000779FE3A3C5605D40785E2A36E6374A40
34173	5	48	7503	60121	73831	\N	50.365236000000003	"Забайкальский край, муниципальный район ""Приаргунский район "", городское поселение ""Приаргунское"", Приаргунск поселок, Магистральная, здание Приаргунского ДЭУ"		0101000020E6100000C289E8D7D6C55D4033A9A10DC02E4940
34150	5	48	1809	27033	73887	\N	50.358288999999999	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Усть-Тасуркайское"", Усть-Тасуркай село, Советская, Здание Администрации"		0101000020E6100000C1745AB7419A5D401EC2F869DC2D4940
34148	5	48	1809	51042	24522	\N	50.461570729206798	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Урулюнгуйское"", Аксенова,30"	Россия, Забайкальский край, Приаргунский район, село Урулюнгуй	0101000020E61000001F2BF86D88A15D4019E42EC2143B4940
34165	5	48	1809	27743	73890	\N	50.477195999999999	"Забайкальский край, муниципальный район ""Приаргунский район"" сельское поселение ""Новоцурухайтуйское"", Улан село, Юбилейная, здание школы"		0101000020E610000009FD4CBD6EBB5D4019E42EC2143D4940
34166	5	48	1809	27760	73862	\N	50.560070000000003	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Пограничнинское"", Талман-Борзя село, Юбилейная, 12"		0101000020E61000008D5F7825C9B55D4041BCAE5FB0474940
34154	5	48	1809	60119	73825	\N	50.198265402694901	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Староцурухайтуйское"", Старый Цурухайтуй село, Колхозная, 70а"	Россия, Забайкальский край, Приаргунский район, село Староцурухайтуй	0101000020E6100000AE9D280989D45D4081785DBF60194940
34149	5	48	1809	27018	73967	\N	50.565134	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Быркинское"", Селинда село, Нагорная, 9а"		0101000020E610000034B91803EB945D40C8ED974F56484940
34170	5	48	1809	51696	27534	\N	50.365236000000003	"Забайкальский край, муниципальный район ""Приаргунский район"", городское поселение ""Приаргунское"", Приаргунск поселок, Ленина, Центр Досуга"		0101000020E6100000C289E8D7D6C55D4033A9A10DC02E4940
34171	5	48	1809	27899	27439	\N	50.365236000000003	"Забайкальский край, муниципальный район ""Приаргунский район"", городское поселение ""Приаргунское"", Приаргунск поселок, Строительная, здание ПУ-31"		0101000020E6100000C289E8D7D6C55D4033A9A10DC02E4940
34169	5	48	1809	27899	23903	\N	50.365236000000003	"Забайкальский край, муниципальный район ""Приаргунский район"", городское поселение ""Приаргунское"", Приаргунск поселок, Декабристов, здание ДЮСШ"		0101000020E6100000C289E8D7D6C55D4033A9A10DC02E4940
34159	5	48	1809	51645	27410	\N	50.591222999999999	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Пограничнинское"", Пограничный поселок, Школьная, 10"		0101000020E6100000C440D7BE80BD5D404ED2FC31AD4B4940
34157	5	48	1809	27371	24745	\N	50.331201999999998	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Погадаевское"", Погадаево село, Советская, 16"		0101000020E6100000008FA850DDAA5D40552FBFD3642A4940
34161	5	48	1809	27556	\N	\N	50.668004000000003	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Пограничнинское"", Норинск село, Центральная, помещение  Администрации"		0101000020E610000000AE64C746C25D4071CCB22781554940
34153	5	48	1809	51869	28453	\N	50.394647723822999	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение  ""Новоцурухайтуйское"", Новый-Цурухайтуй село, Федорова, 70а"	Россия, Забайкальский край, Приаргунский район, село Новоцурухайтуй	0101000020E6100000EECD6F9868C75D4045B75ED383324940
34168	5	48	1809	51869	74032	\N	50.390791795596201	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение  ""Новоцурухайтуйское"", Новый Цурухайтуй село, Лазо, ОАО ""Агроремтех"""	Россия, Забайкальский край, Приаргунский район, село Новоцурухайтуй	0101000020E6100000E5982CEE3FC75D40EBC4E57805324940
34167	5	48	1809	27819	28297	\N	50.374716012417601	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Усть-Тасуркайское"", Новоивановка село, Советская, 13"	Россия, Забайкальский край, Приаргунский район, село Новоивановка	0101000020E6100000821FD5B0DF895D40DBA4A2B1F62F4940
34162	5	48	1809	51720	27664	\N	50.282886483979198	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Молодежнинское"", Молодежное поселок, Молодежная, 25"	Россия, Забайкальский край, Приаргунский район, село Молодёжный	0101000020E610000071033E3F8CBF5D40853FC39B35244940
15653	5	47	\N	902	69969	\N	53.003270999999998	Алтайский край, г.Славгород, ул. Первомайская, д. 194		0101000020E6100000B796C9703CA953403A03232F6B804A40
34163	5	48	1809	27632	24408	\N	50.096176	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Молодежнинское"", Кути село, Молодежная, 4"		0101000020E6100000FDBFEAC891CB5D407E54C37E4F0C4940
34175	5	48	1809	28111	73783	\N	50.430092000000002	"Забайкальский край, муниципальный район ""Приаргунский район"", городское поселение ""Кличкинское"",Кличка поселок, Социалистическая, 4"		0101000020E6100000C2F7FE06ED7F5D40B82231410D374940
34174	5	48	1809	28111	73688	\N	50.430092000000002	"Забайкальский край, муниципальный район ""Приаргунский район"", городское поселение ""Кличкинское"", Кличка поселок, Ленина, 18"	Россия, Забайкальский край, Приаргунский район, поселок городского типа Кличка	0101000020E6100000C2F7FE06ED7F5D40B82231410D374940
34156	5	48	1809	27304	27488	\N	50.606963	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Зоргольское"", Зоргол село, Пешкова, 16"		0101000020E6100000CB2C42B115D15D40E770ADF6B04D4940
34155	5	48	1809	27256	28316	\N	50.011443	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Дуройское"", Дурой село, Баженова, 34а"		0101000020E6100000C5AEEDED96BB5D405262D7F676014940
34164	5	48	1809	27684	28094	\N	50.394170000000003	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Досатуйское"", Досатуй поселок, Юбилейная, 4"		0101000020E61000002B8716D9CEA85D403C889D2974324940
34158	5	48	1809	27390	27406	\N	50.168590999999999	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Погадаевское"", Горда село, Школьная, 8"		0101000020E6100000C4D155BABBB85D4031B3CF6394154940
34152	5	48	1809	27111	73897	\N	50.429237999999998	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение Усть-Тасуркайское"", Верх-Тасуркай село, Ленина, Дом Культуры"		0101000020E6100000389ECF807A955D40A8195245F1364940
34160	5	48	1809	27477	74004	\N	50.589889999999997	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Пограничнинское"",  Верея поселок, Новая, помещение ФАП"	Россия, Забайкальский край, Приаргунский район, село Верея	0101000020E61000008AE42B8194C75D40641EF983814B4940
34147	5	48	1809	26869	27451	\N	50.644796999999997	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Быркинское"", Бырка село, Новая, 12"		0101000020E6100000EC6987BF26A35D408AC745B588524940
34146	5	48	1809	26869	24434	\N	50.644796999999997	"Забайкальский край, муниципальный район ""Приаргунский район"", сельское поселение ""Быркинское"", Бырка село, Кооперативная, 19"		0101000020E6100000EC6987BF26A35D408AC745B588524940
33669	5	48	427	3605	73605	\N	51.285943000000003	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", с. Хохотуй, Кооперативная, 31-А"		0101000020E61000002A3A92CB7F645B4094C2BCC799A44940
33658	5	48	427	52246	73740	\N	51.245156999999999	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Хараузское""с. Харауз, Нагорная, 43"	Россия, Забайкальский край, Петровск-Забайкальский район, село Харауз	0101000020E6100000EFE4D3635B1E5B4057B1F84D619F4940
33651	5	48	427	52239	73814	\N	50.931795999999999	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Усть-Оборское""с. Усть-Обор, Клубная, 11"		0101000020E6100000F660527C7C245B409545611745774940
33668	5	48	427	3572	73992	\N	51.205125470351298	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", с. Толбага, Почтовая, 20-А"		0101000020E6100000B709F7CABC545B40C74B3789419A4940
33663	5	48	427	60072	73735	\N	51.178974146633003	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", городское поселение ""Тарбагатайское"" пос. Тарбагатай, Кооперативная, 57"	Россия, Забайкальский край, Петровск-Забайкальский район, поселок городского типа Тарбагатай	0101000020E61000004128EFE368465B40CA6ABA9EE8964940
33664	5	48	427	60085	73762	\N	51.168972913123902	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", городское поселение ""Тарбагатайское"" пос. Тарбагатай, Заводская, 18"	Россия, Забайкальский край, Петровск-Забайкальский район, поселок городского типа Тарбагатай	0101000020E6100000F22895F084455B40197442E8A0954940
33646	5	48	427	50784	73824	\N	50.770367676127698	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Песчанское""с. Пески, Вакарина, 43"		0101000020E61000006C3F19E3C3075B4045F12A6B9B624940
33655	5	48	427	52242	73973	\N	50.958185	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Катангарское""с. Орсук, Трактовая, 20"		0101000020E6100000315BB22AC2335B4046425BCEA57A4940
33652	5	48	427	52241	73991	\N	50.969644000000002	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Катаевское""с. Обор, Центральная, 60"		0101000020E6100000A4C7EF6DFA225B409E616A4B1D7C4940
33666	5	48	427	60041	73614	\N	51.215100999999997	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", п. Новопавловка, Советская, 2"		0101000020E61000006CCD565EF24D5B401F2BF86D889B4940
33665	5	48	427	60041	73577	\N	51.215100999999997	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", п. Новопавловка, Заводская, 10"		0101000020E61000006CCD565EF24D5B401F2BF86D889B4940
15573	5	47	\N	59340	70114	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Мира, 6		0101000020E6100000AA49F08634545440454772F90FE54A40
33647	5	48	427	52230	73863	\N	50.790422	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Песчанское""с. Новая Зардама, Центральная, 17"		0101000020E6100000BA111615710A5B40FB04508C2C654940
33649	5	48	427	51858	28396	\N	50.838993301597498	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Малетинское"" с. Малета, Пионерская, 16"	Россия, Забайкальский край, Петровск-Забайкальский район, село Малета	0101000020E61000000E87A5811F1B5B405649641F646B4940
33650	5	48	427	51858	73601	\N	50.835622999999998	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Малетинское""с. Малета, Комсомольская, 47"		0101000020E6100000917F66101F1B5B408864C8B1F56A4940
33657	5	48	427	52243	73920	\N	50.998460999999999	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Катангарское""с. Лесоучасток Катангар, Нагаева, 17"	Россия, Забайкальский край, Петровск-Забайкальский район, село Лесоучасток Катангар	0101000020E61000006F8104C58F3F5B406DAAEE91CD7F4940
33661	5	48	427	50967	24171	\N	51.134257080197301	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", городское поселение ""Балягинское""с. Кули, Шахтовая, 7"		0101000020E610000010E9B7AF03435B40292158552F914940
33656	5	48	427	50905	24043	\N	51.013278783751403	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Катангарское""с. Катангар, Центральная, 35"	Россия, Забайкальский край, Петровск-Забайкальский район, село Катангар	0101000020E6100000986E1283C03D5B409E5C5320B3814940
33653	5	48	427	51626	27369	\N	50.944211727539901	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Катаевское""с. Катаево, Центральная, 46-А"	Россия, Забайкальский край, Петровск-Забайкальский район, село Катаево	0101000020E6100000AC90F2936A2A5B40D13E56F0DB784940
33667	5	48	427	3490	27134	\N	51.185138999999999	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", с.Зугмара, Колхозная, 20"		0101000020E61000009A9658198D4D5B40691B7FA2B2974940
33662	5	48	427	51556	27241	\N	51.109253603782498	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", сельское поселение ""Баляга-Катангарское""с. Баляга-Катангар, Улан-Туя, 13"	Россия, Забайкальский край, Петровск-Забайкальский район, село Баляга-Катангар	0101000020E610000032AA0CE36E3E5B40857AFA08FC8D4940
33660	5	48	427	51767	27919	\N	51.158539300703502	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", городское поселение ""Балягинское""пос. Баляга, Шоссейная, 25-А"	Россия, Забайкальский край, Петровск-Забайкальский район, поселок городского типа Баляга	0101000020E6100000CEDF8442043A5B40FD1186014B944940
33659	5	48	427	51767	37941	\N	51.155804624081	"Забайкальский край, муниципальный район ""Петровск-Забайкальский район"", городское поселение ""Балягинское""пос. Баляга, Клубная, 18"	Россия, Забайкальский край, Петровск-Забайкальский район, поселок городского типа Баляга	0101000020E61000001FD8F15F203A5B40D2C6116BF1934940
34145	5	48	1785	50749	73857	\N	50.5769836018886	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Чиндантское"", Солнечная, 30"		0101000020E6100000F0FB372F4EDA5C405B28999CDA494940
34143	5	48	1785	50749	73942	\N	50.578076671871102	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Чиндантское"", Нагорная, 13"	Россия, Забайкальский край, Ононский район, село Чиндант 1-й	0101000020E610000016BD5301F7D95C40EFC8586DFE494940
34144	5	48	1785	50749	23524	\N	50.577138490602003	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Чиндантское"", Васильева, 30"	Россия, Забайкальский край, Ононский район, село Чиндант 1-й	0101000020E610000029B2D6506ADA5C40B1A371A8DF494940
34141	5	48	1785	50813	23726	\N	50.493117780678702	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Холуй-Базинское"", Молодежная, 6"	Россия, Забайкальский край, Ононский район, село Холуй-База	0101000020E6100000BF81C98D22F15C40D388997D1E3F4940
34142	5	48	1785	50813	27436	\N	50.4897108523109	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Холуй-Базинское"", Кушурская, 2"	Россия, Забайкальский край, Ононский район, село Холуй-База	0101000020E6100000BF81C98D22F15C40E8BE9CD9AE3E4940
34133	5	48	1785	51819	73891	\N	50.456081696947997	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Тут-Халтуйское"", Школьная, 38"	Россия, Забайкальский край, Ононский район, село Тут-Халтуй	0101000020E6100000C573B680D08A5C40AB251DE5603A4940
34134	5	48	1785	51819	28167	\N	50.461667572365101	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Тут-Халтуйское"", Ленина, 13"	Россия, Забайкальский край, Ононский район, село Тут-Халтуй	0101000020E610000018EC866D8B8A5C400CCEE0EF173B4940
34132	5	48	1785	51016	24373	\N	50.345091552535301	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Дурулгуйское"", Центральная, 18"	Россия, Забайкальский край, Ононский район, село Новый Дурулгуй	0101000020E6100000B03907CF849A5C403D0E83F92B2C4940
15570	5	47	\N	59340	70111	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Мамонтова, 20		0101000020E6100000AA49F08634545440454772F90FE54A40
34131	5	48	1785	51016	73684	\N	50.346156000000001	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Дурулгуйское"", Ветрова, 18"	Россия, Забайкальский край, Ононский район, село Новый Дурулгуй	0101000020E6100000492C29779F9A5C4037A8FDD64E2C4940
34139	5	48	1785	60092	73775	\N	50.360821708615497	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Новозоринское"", Центральная, 22"	Россия, Забайкальский край, Ононский район, село Новая Заря	0101000020E61000002CB81FF0C0E35C40B2D6506A2F2E4940
34125	5	48	1785	59128	68023	\N	50.511474	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Нижнецасучейское"", Комсомольская, 42"	Россия, Забайкальский край, Ононский район, село Нижний Цасучей	0101000020E610000036AB3E575BC85C408D60E3FA77414940
34140	5	48	1785	51785	27978	\N	50.230882249781203	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Кулусутайское"", Казачий переулок, 10"	Россия, Забайкальский край, Ононский район, село Кулусутай	0101000020E610000037E2C96E66EB5C40179E978A8D1D4940
34138	5	48	1785	51878	28488	\N	50.262174793972299	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Ималкинское"", Молодежная, 5"	Россия, Забайкальский край, Ононский район, село Красная Ималка	0101000020E61000007DAF21382ED45C40166A4DF38E214940
34137	5	48	1785	60195	74018	\N	50.280147999999997	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Ималкинское"", Ленина, 45"		0101000020E6100000028063CF9EBC5C401805C1E3DB234940
34126	5	48	1785	60048	73607	\N	50.508747999999997	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Верхнецасучейское"", Григорьева, 16"	Россия, Забайкальский край, Ононский район, село Верхний Цасучей	0101000020E6100000DC48D92269C65C40E4F38AA71E414940
34136	5	48	1785	51882	73851	\N	50.243445823536	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Буйлэсанское"", Центральная, 2"		0101000020E6100000C36169E047B85C40C72B103D291F4940
34135	5	48	1785	51882	73851	\N	50.243837246066498	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Буйлэсанское"", Центральная, 32"	Россия, Забайкальский край, Ононский район, село Буйлэсан	0101000020E6100000C5C9FD0E45B85C400247020D361F4940
34128	5	48	1785	51639	73892	\N	50.487403767700897	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Большевистское"", Школьная, 1"	Россия, Забайкальский край, Ононский район, село Большевик	0101000020E6100000809E060C92AA5C4044F81741633E4940
34129	5	48	1785	51639	73888	\N	50.488469729720002	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Большевистское"", Центральная, 15"	Россия, Забайкальский край, Ононский район, село Большевик	0101000020E610000024438EAD67AA5C40DF89592F863E4940
34130	5	48	1785	51639	27395	\N	50.487420238051399	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Большевистское"", Ленина, 22"	Россия, Забайкальский край, Ононский район, село Большевик	0101000020E61000005F61C1FD80AA5C404AB54FC7633E4940
34127	5	48	1785	51639	27395	\N	50.486963000000003	"Забайкальский край, муниципальный район ""Ононский район"", сельское поселение ""Большевистское"", Ленина, 57"	Россия, Забайкальский край, Ононский район, село Большевик	0101000020E61000006D37C1374DAA5C4058AEB7CD543E4940
34117	5	48	1190	59078	\N	\N	50.874578	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Ясногорское"" п.Ясногорск, КСЦ"	Россия, Забайкальский край, Оловяннинский район, поселок городского типа Ясногорск	0101000020E6100000F06DFAB31FEC5C408AE6012CF26F4940
34116	5	48	1190	51616	\N	\N	50.826476522265303	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Яснинское"" п.Ясная, школа № 2"	Россия, Забайкальский край, Оловяннинский район, село Ясная	0101000020E61000002B3410CB66F35C40B6F292FFC9694940
34093	5	48	1190	50901	\N	\N	50.954317901303099	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Хара-Быркинское"" с.Хара-Бырка, школа"	Россия, Забайкальский край, Оловяннинский район, село Хара-Бырка	0101000020E61000002101A3CB9BFA5C40F8FD9B17277A4940
34111	5	48	1190	50850	\N	\N	50.647364047923404	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Хада-Булакское"" с.Хада-Булак, школа"	Россия, Забайкальский край, Оловяннинский район, село Хада-Булак	0101000020E61000004A95287B4B135D40CB4DD4D2DC524940
34115	5	48	1190	50790	\N	\N	50.727867371393998	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Уртуйское"" с.Уртуй, администрация"	Россия, Забайкальский край, Оловяннинский район, село Уртуйский	0101000020E6100000A03715A930FE5C40386BF0BE2A5D4940
34099	5	48	1190	51863	\N	\N	51.165324416565603	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Улятуйское"" с.Улятуй, школа"	Россия, Забайкальский край, Оловяннинский район, село Улятуй	0101000020E6100000E338F06AB90F5D40389F3A5629954940
34110	5	48	1190	52096	\N	\N	50.861998999999997	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Улан-Цацыкское"" с.Улан-Цацык, школа"		0101000020E61000004B92E7FA3E0E5D40A417B5FB556E4940
34105	5	48	1190	50853	\N	\N	51.0551518892498	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Тургинское"" с.Турга, школа"	Россия, Забайкальский край, Оловяннинский район, село Турга	0101000020E6100000BC3C9D2B4A285D408D2782380F874940
34089	5	48	1190	24208	\N	\N	50.904795	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Оловяннинское"", с.Тополевка, школа"	Россия, Забайкальский край, Оловяннинский район, село Тополевка	0101000020E6100000E21E4B1FBAE65C40CB4A9352D0734940
34090	5	48	1190	60030	\N	\N	51.009858622007897	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Степнинское"" ст.Степь, школа"	Россия, Забайкальский край, Оловяннинский район, село Степь	0101000020E610000006B98B3045DA5C401F49490F43814940
34102	5	48	1190	51841	\N	\N	51.063157484412699	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Бурулятуйское"" с.Победа, фельдшерско-акушерский пункт"	Россия, Забайкальский край, Оловяннинский район, село Победа	0101000020E61000009FE57970770D5D40B9C1508715884940
34091	5	48	1190	24288	\N	\N	50.984881999999999	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Ононское"", с.Ононск, школа"		0101000020E610000056F146E691E45C40A435069D107E4940
34124	5	48	1190	59027	\N	\N	50.943913999999999	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Оловяннинское"" п.Оловянная, здание редакции газеты ""Ленинский путь"""		0101000020E6100000D42CD0EE90E35C40471E882CD2784940
34123	5	48	1190	11404	\N	\N	50.944619151738102	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Оловяннинское"" п.Оловянная, административное здание учреждения ЯГ-14/7"	Россия, Забайкальский край, Оловяннинский район, поселок городского типа Оловянная	0101000020E61000005436ACA92CE45C4012178046E9784940
34122	5	48	1190	11404	\N	\N	50.943913999999999	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Оловяннинское"" п.Оловянная, здание МУП ""Коммунальное хозяйство"""		0101000020E6100000D42CD0EE90E35C40471E882CD2784940
34121	5	48	1190	11404	\N	\N	50.939629943919797	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Оловяннинское"" п.Оловянная, школа № 1"	Россия, Забайкальский край, Оловяннинский район, поселок городского типа Оловянная	0101000020E6100000C478CDAB3AE55C40952BBCCB45784940
34120	5	48	1190	60028	\N	\N	50.947817841794802	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Оловяннинское"" п.Оловянная, школа № 235"	Россия, Забайкальский край, Оловяннинский район, поселок городского типа Оловянная	0101000020E6100000AB4198DBBDE45C40B247A81952794940
34119	5	48	1190	60028	\N	\N	50.940280699236297	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Оловяннинское"" п.Оловянная, районный Дом культуры"	Россия, Забайкальский край, Оловяннинский район, поселок городского типа Оловянная	0101000020E6100000C6E061DA37E55C406C06B8205B784940
34113	5	48	1190	51730	\N	\N	50.754118014604998	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Мирнинское"" пст.Мирная, школа"	Россия, Забайкальский край, Оловяннинский район, село Мирная	0101000020E61000001212691B7F035D4097A949F086604940
34092	5	48	1190	50986	\N	\N	50.956305627637001	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Ононское"" с.Кулинда, школа"	Россия, Забайкальский край, Оловяннинский район, село Кулинда	0101000020E610000084F1D3B837E75C40FA7B293C687A4940
34100	5	48	1190	60151	\N	\N	51.192598431625598	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Улятуйское"" с.Камкай, библиотека"	Россия, Забайкальский край, Оловяннинский район, село Комкай	0101000020E610000010CD3CB9A6165D4033A31F0DA7984940
34096	5	48	1190	50989	\N	\N	51.262765662083602	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Единенское"" с.Караксар, школа"	Россия, Забайкальский край, Оловяннинский район, село Караксар	0101000020E6100000DD94F25A09FD5C401840F850A2A14940
34104	5	48	1190	59084	\N	\N	51.015072000000004	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Калангуйское"" п.Калангуй, школа"	Россия, Забайкальский край, Оловяннинский район, поселок городского типа Калангуй	0101000020E61000002AE09EE74F215D40EC8A19E1ED814940
34106	5	48	1190	50883	\N	\N	51.053529026932601	"Забайкальский край, муниципальный район ""Оловяннинский район"", городское поселение ""Золотореченское"" п.Золотореченск, школа"	Россия, Забайкальский край, Оловяннинский район, поселок городского типа Золотореченск	0101000020E6100000F0F78BD9922F5D409C31CC09DA864940
34097	5	48	1190	52081	\N	\N	51.147817000000003	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Единенское"" с.Заря, сельский клуб"		0101000020E61000008194D8B5BD035D407C65DEAAEB924940
34043	5	48	1663	22109	73828	\N	51.984485999999997	"Забайкальский край, муниципальный район ""Нерчинский район"",сельское поселение ""Нижнеключевское"", с.Нижние Ключи, Советская, 4, Дом культуры"		0101000020E610000056BABBCE86345D4057AF22A303FE4940
34095	5	48	1190	51897	\N	\N	51.177339002510998	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Единенское"" с.Единение, школа"	Россия, Забайкальский край, Оловяннинский район, село Единение	0101000020E61000002CF52C08E5F85C4016A75A0BB3964940
34103	5	48	1190	51855	\N	\N	51.0664021548574	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Долгокычинское"" с.Долгокыча, школа"	Россия, Забайкальский край, Оловяннинский район, село Долгокыча	0101000020E6100000A54FABE80F1B5D40CA3159DC7F884940
34094	5	48	1190	52077	\N	\N	51.078397000000002	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Единенское"" с.Верхний Шаранай, школа"	Россия, Забайкальский край, Оловяннинский район, село Верхний Шаранай	0101000020E6100000776A2E3718F15C40618DB3E9088A4940
34114	5	48	1190	51806	\N	\N	50.7392333573763	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Уртуйское"" с.Бырка, школа"	Россия, Забайкальский край, Оловяннинский район, село Бырка	0101000020E61000007BFA08FCE1FC5C40DE8FDB2F9F5E4940
34101	5	48	1190	52087	\N	\N	51.0871	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Бурулятуйское"" с.Бурулятуй, школа"		0101000020E61000000EF3E505D8145D40A5BDC117268B4940
34109	5	48	1190	51805	\N	\N	50.866252869868802	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Булумское"" с.Булум, школа"	Россия, Забайкальский край, Оловяннинский район, село Булум	0101000020E6100000AB949EE925235D40EC87D860E16E4940
34112	5	48	1190	51894	\N	\N	50.721256559561603	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Безречнинское"" пст.Безречная, школа"	Россия, Забайкальский край, Оловяннинский район, село Безречная	0101000020E61000001D8F19A88C0B5D406B813D26525C4940
34098	5	48	1190	51902	\N	\N	51.2837864070355	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Арендинское"" с.Аренда, школа"	Россия, Забайкальский край, Оловяннинский район, село Аренда	0101000020E61000000B62A06B5F0F5D400588821953A44940
34108	5	48	1190	52093	\N	\N	50.950366000000002	"Забайкальский край, муниципальный район ""Оловяннинский район"", сельское поселение ""Булумское"" с.Антия, школа"	Россия, Забайкальский край, Оловяннинский район, село Антия	0101000020E6100000EE5D83BEF4245D407C9DD497A5794940
34070	5	48	1684	60165	73941	\N	51.787134000000002	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Булдуруйское"", Балябина, 3"		0101000020E6100000102219726CF35D40EBC891CEC0E44940
34087	5	48	1684	60190	74005	\N	51.370117449092596	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Широковское"", Садовая, 8"	Россия, Забайкальский край, Нерчинско-Заводский район, село Широкая	0101000020E61000007EAB75E272E65D40C9586DFE5FAF4940
34085	5	48	1684	51795	28012	\N	51.068053820518799	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Чашино-Ильдиканское"", Мира, 15"	Россия, Забайкальский край, Нерчинско-Заводский район, село Чашино-Ильдикан	0101000020E610000072DD94F25AD05D40552E54FEB5884940
34083	5	48	1684	60211	74041	\N	51.694620999999998	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Уров-Ключевское"", Новая, 8"	Россия, Забайкальский край, Нерчинско-Заводский район, село Уровские Ключи	0101000020E610000039B35DA10FDE5D40B20E4757E9D84940
34081	5	48	1684	60150	73917	\N	51.350824235436598	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Олочинское"", Набережная, 18"	Россия, Забайкальский край, Нерчинско-Заводский район, село Олочи	0101000020E61000007A6CCB80B3F95D40725303CDE7AC4940
34080	5	48	1684	59106	67802	\N	51.308723000000001	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Нерчинско-Заводское"", Булгаковой, 2"	Россия, Забайкальский край, Нерчинско-Заводский район, село Нерчинский Завод	0101000020E6100000166C239EECE65D40F2423A3C84A74940
34079	5	48	1684	22247	73840	\N	51.117347707347598	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Михайловское"", Перфильева, 16"	Россия, Забайкальский край, Нерчинско-Заводский район, село Михайловка	0101000020E61000001F82AAD1ABDB5D4021205F42058F4940
34046	5	48	1684	22247	73884	\N	51.115588000000002	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Приисковское"", с.Михайловка Михайловка, Молодежная, 3, Библиотека"		0101000020E61000004D2D5BEB8BDB5D40B0E76B96CB8E4940
34078	5	48	1684	60133	73876	\N	51.4805779407721	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Ишагинское"", Центральная, здание сельского Дома культуры"		0101000020E6100000FCFECD8B13FE5D40AB96749483BD4940
34077	5	48	1684	51872	28475	\N	51.263838865477403	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Ивановское"", Молодежная, 20"	Россия, Забайкальский край, Нерчинско-Заводский район, село Ивановка	0101000020E610000078280AF489DD5D406534F279C5A14940
15563	5	47	\N	59340	69854	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Ленина, 29		0101000020E6100000AA49F08634545440454772F90FE54A40
34071	5	48	1684	51872	73968	\N	51.260157999999997	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Ивановское"", Конторская, 4 квартира 2"	Россия, Забайкальский край, Нерчинско-Заводский район, село Ивановка	0101000020E61000003997E2AAB2DD5D4079E57ADB4CA14940
34075	5	48	1684	51725	27688	\N	51.216364020374897	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Горно-Зерентуйское"", Пушкина, 10"	Россия, Забайкальский край, Нерчинско-Заводский район, село Горный Зерентуй	0101000020E6100000F279C5538FE15D401004C8D0B19B4940
34074	5	48	1684	60168	73952	\N	51.230735102929202	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Горбуновское"", Центральная, 21"	Россия, Забайкальский край, Нерчинско-Заводский район, село Горбуновка	0101000020E6100000ED9FA70183F05D40738577B9889D4940
34073	5	48	1684	60187	73995	\N	51.368882999999997	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Георгиевское"", Клубная, 18"	Россия, Забайкальский край, Нерчинско-Заводский район, село Георгиевка	0101000020E61000001B4B581B63DC5D407286E28E37AF4940
34069	5	48	1684	60185	73990	\N	51.021565392856203	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Булдуруйское"", Солнечная, 63а"	Россия, Забайкальский край, Нерчинско-Заводский район, село Булдуруй-1	0101000020E6100000DA54DD239BEA5D407FDE54A4C2824940
34086	5	48	1684	60185	76429	\N	51.021566	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Булдуруйское"", Верхняя, 64"	Россия, Забайкальский край, Нерчинско-Заводский район, село Булдуруй-1	0101000020E61000005342B0AA5EEA5D404F5AB8ACC2824940
34076	5	48	1684	60103	73933	\N	51.3629178997558	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Больше-Зерентуйское"", Центральная, 9"	Россия, Забайкальский край, Нерчинско-Заводский район, село Большой Зерентуй	0101000020E61000003E7B2E5393CE5D409B90D61874AE4940
34068	5	48	1684	60103	73796	\N	51.365257	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Больше-Зерентуйское"", Советский переулок, 7"	Россия, Забайкальский край, Нерчинско-Заводский район, село Большой Зерентуй	0101000020E61000001631EC3026CE5D404AD1CABDC0AE4940
34082	5	48	1684	50685	24108	\N	51.578718678204702	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Аргунское"", Сурина, 5"	Россия, Забайкальский край, Нерчинско-Заводский район, село Аргунск	0101000020E610000039EFFFE384015E407349D57613CA4940
34067	5	48	1684	50685	27661	\N	51.578671153550097	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Аргунское"", Советская, 5"	Россия, Забайкальский край, Нерчинско-Заводский район, село Аргунск	0101000020E61000006118B0E42A015E4062122EE411CA4940
34072	5	48	1684	50685	23386	\N	51.580762676592698	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Аргунское"", Дорожная, 10"	Россия, Забайкальский край, Нерчинско-Заводский район, село Аргунск	0101000020E61000003A57941282015E4009DD257156CA4940
34066	5	48	1663	60113	73820	\N	51.9657930579571	"Забайкальский край, муниципальный район ""Нерчинский район""., городское поселение ""Нерчинское"", Тетерина-Петрова, 3, СОШ № 1"	Россия, Забайкальский край, Нерчинский район	0101000020E61000005F46B1DCD2235D4055DAE21A9FFB4940
34048	5	48	1663	22335	24078	\N	51.917732000000001	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Приисковское"", с. Шивки, ул.Верхняя, Сельский клуб"		0101000020E61000006FF4311F102D5D40103FFF3D78F54940
34051	5	48	1663	22451	27539	\N	51.867888000000001	"Забайкальский край, муниципальный район ""Нерчинский район"",сельское поселение ""Пешковское"", с. Савватеево, ул.Центральная, 30"		0101000020E6100000B0E42A16BF205D40A14B38F416EF4940
34045	5	48	1663	22181	67996	\N	51.920347999999997	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Приисковское"", п.Приисковый, Центральная, 2, Дом культуры"	Россия, Забайкальский край, Нерчинский район, поселок городского типа Приисковый	0101000020E6100000D6E1E82ADD275D40317898F6CDF54940
34037	5	48	1663	21796	27634	\N	52.074416999999997	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Кумакинское"", с. Правые Кумаки, Центральная, 21, Администрация"		0101000020E610000099F38C7DC9165D401AA20A7F86094A40
34052	5	48	1663	22470	27544	\N	51.824344237857098	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Пешковское"", с.Пешково, Центральная, 35, Дом культуры"	Россия, Забайкальский край, Нерчинский район, село Пешково	0101000020E6100000EBC891CEC01C5D40B153AC1A84E94940
34030	5	48	1663	21457	27700	\N	52.395769999999999	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Олинское"", с.Олинск, Рабочая, 7"		0101000020E6100000C66E9F55660D5D40745E6397A8324A40
34031	5	48	1663	21524	73737	\N	52.366728000000002	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Олеканское"", с.Олекан, Молодежная,2"		0101000020E6100000CFD8976C3C045D4085436FF1F02E4A40
34063	5	48	1663	40367	73676	\N	51.967228464359501	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Студгородок улица ,1, Аграрный техникум"		0101000020E610000050C422861D265D4043E38920CEFB4940
34064	5	48	1663	40367	27155	\N	51.988642030910498	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Советская, 18, ОСОШ"		0101000020E61000007D410B0918245D40DCB930D28BFE4940
34061	5	48	1663	40367	27155	\N	51.982706627272002	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Советская, 2, кинотеатр ""Нерча"""	Россия, Забайкальский край, Нерчинский район, Нерчинск	0101000020E61000007D410B0918245D406F46CD57C9FD4940
34065	5	48	1663	40367	9958	\N	51.9844025375561	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Рабочая,37, СПТУ-29"	Россия, Забайкальский край, Нерчинский район, Нерчинск	0101000020E6100000BADC60A8C3235D40CA8AE1EA00FE4940
34056	5	48	1663	40367	23611	\N	51.985014989628702	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Пушкинская, 26, школа №2"	Россия, Забайкальский край, Нерчинский район, Нерчинск	0101000020E610000007F0164850245D40E388B5F814FE4940
34058	5	48	1663	40367	73804	\N	51.984826505042903	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Первомайская, 82, Центр детского творчества"	Россия, Забайкальский край, Нерчинский район, Нерчинск	0101000020E6100000751DAA29C9255D40E19BA6CF0EFE4940
34060	5	48	1663	40367	27188	\N	51.981858647927503	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Достовалова, 3, Дом культуры"	Россия, Забайкальский край, Нерчинский район, Нерчинск	0101000020E6100000280AF4893C255D404224438EADFD4940
34059	5	48	1663	40367	27188	\N	51.979455917655201	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Достовалова,11, СОШ № 9"	Россия, Забайкальский край, Нерчинский район, Нерчинск	0101000020E610000004C6FA0626255D407CEF6FD05EFD4940
34054	5	48	1663	40367	24166	\N	51.977668617968099	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Нерчинское"", Дорожная ,8, районный Дом культуры"	Россия, Забайкальский край, Нерчинский район, Нерчинск	0101000020E6100000C45A7C0A80255D4011A8FE4124FD4940
34041	5	48	1663	60138	73889	\N	52.018666400268799	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение "", сельское поселение ""Зареченское"" п. Нагорное, Октябрьская, 19, Дом культуры"	Россия, Забайкальский край, Нерчинский район, село Нагорный	0101000020E61000001F4DF564FE235D4009C6C1A563024A40
34038	5	48	1663	21851	73947	\N	52.058638000000002	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Кумакинское"", с. Левые Кумаки, Набережная, 21, Дом культуры"		0101000020E6100000FF942A51F6175D40C426327381074A40
34029	5	48	1663	21404	73880	\N	52.475071999999997	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Олинское"", с.Крупянка, Советская, 14"		0101000020E6100000D1B1834A5C0B5D40669FC728CF3C4A40
34035	5	48	1663	21692	73829	\N	52.244867999999997	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Знаменское"",с. Кангил, Центральная, 25, Сельский клуб"		0101000020E61000002B69C53714155D4020EBA9D5571F4A40
34047	5	48	1663	22268	24065	\N	51.899697000000003	"Забайкальский край, муниципальный район ""Нерчинский район"", городское поселение ""Приисковское"", с.Калинино, Новая, 3, Администрация"		0101000020E61000006F1118EB1B2A5D4098A7734529F34940
34032	5	48	1663	21539	73789	\N	52.210551000000002	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Илимское"", с.Илим, Советская, 26, администрация"		0101000020E610000037E2C96E66035D40EF91CD55F31A4A40
34027	5	48	1663	21304	27699	\N	52.53228	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Зюльзинское"", с.Зюльзя, К-Маркса,7"		0101000020E6100000F9484A7A180D5D404E2844C021444A40
34033	5	48	1663	21604	27717	\N	52.183557999999998	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Знаменское"", с.Знаменка, Школьная, 3, Дом культуры"		0101000020E610000063EDEF6C8F125D40A7751BD47E174A40
34039	5	48	1663	51479	27095	\N	52.029579467399401	"Забайкальский край, муниципальный район ""Нерчинский район"",сельское поселение ""Зареченское"", с.Заречное, Набережная, 9, Администрация"	Россия, Забайкальский край, Нерчинский район, село Заречный	0101000020E6100000C70F9546CC205D40FED2A23EC9034A40
34042	5	48	1663	22024	23579	\N	52.138387999999999	"Забайкальский край, муниципальный район ""Нерчинский район"",сельское поселение ""Верхнеумыкэйское"",с. Верхний Умыкэй, Центральная, 37, Дом культуры"		0101000020E61000006F1283C0CA225D405514AFB2B6114A40
34044	5	48	1663	22125	24604	\N	51.965001999999998	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Верхнеключевское"", с.Верхние Ключи, Центральная, 56, Дом культуры"		0101000020E61000003CF88903E8305D408C497F2F85FB4940
34049	5	48	1663	51023	24404	\N	51.851903982128398	"Забайкальский край, муниципальный район ""Нерчинский район"",сельское поселение ""Бишигинское"", Набережная, 40, Дом культуры"		0101000020E610000076FC1708021C5D4071AAB5300BED4940
74773	3	32	683	45788	58574	\N	57.627184999999997	дер.Крутец, Центральная, 4		0101000020E610000020425C397B133E4058C51B9947D04C40
34036	5	48	1663	21765	74052	\N	52.154950999999997	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Знаменское"", с. Березово, Казанушка, 12, Библиотека"		0101000020E610000078D2C265151D5D40C2BD326FD5134A40
34034	5	48	1663	21625	27074	\N	52.170662	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Знаменское"", с.Беломестново, Центральная, 14-2, медицинский пункт"		0101000020E610000061C5A9D6C2115D40C1559E40D8154A40
34053	5	48	1663	60129	73861	\N	51.728014999999999	"Забайкальский край, муниципальный район ""Нерчинский район"", сельское поселение ""Андронниковское"", Луговая, 14"	Россия, Забайкальский край, Нерчинский район, село Андронниково	0101000020E6100000321CCF6740145D40ACFF73982FDD4940
34022	5	48	1622	21066	73983	\N	53.782273000000004	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", п. Чалдонка, Набережная, 10"		0101000020E61000004AB6BA9C12CE5D409CC58B8521E44A40
34020	5	48	1622	20992	28547	\N	53.682895000000002	"Забайкальский край, муниципальный район ""Могочинский район"", сельское поселение ""Семиозернинское"", п. Таптугары, Школьная, 1"		0101000020E61000005378D0ECBA035E400CCD751A69D74A40
34019	5	48	1622	20928	73791	\N	53.709780000000002	"Забайкальский край, муниципальный район ""Могочинский район"", сельское поселение ""Семиозернинское"", п. Семиозерный, Советская, 20"		0101000020E61000000F80B8AB57175E406DAD2F12DADA4A40
34025	5	48	1622	21235	67201	\N	53.313660882722999	"Забайкальский край, муниципальный район ""Могочинский район"", сельское поселение ""Сбегинское"", с. Сбега, Центральная, 5"	Россия, Забайкальский край, Могочинский район, село Сбега	0101000020E6100000C24EB16A10A15D40ED832C0B26A84A40
34011	5	48	1622	20325	73777	\N	53.742032000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", г. Могоча, Шулешко, 10"		0101000020E6100000A2F14410E7F05D40F14A92E7FADE4A40
34009	5	48	1622	20325	67382	\N	53.742032000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", г. Могоча, Советская, 32"		0101000020E6100000A2F14410E7F05D40F14A92E7FADE4A40
34010	5	48	1622	20325	73741	\N	53.742032000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", г. Могоча, Промышленная, 11"	Россия, Забайкальский край, Могочинский район, Могоча	0101000020E6100000A2F14410E7F05D40F14A92E7FADE4A40
34008	5	48	1622	20325	37931	\N	53.742032000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", г. Могоча, Красноармейская, 1"	Россия, Забайкальский край, Могочинский район, Могоча	0101000020E6100000A2F14410E7F05D40F14A92E7FADE4A40
34012	5	48	1622	20325	67993	\N	53.742032000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", г. Могоча, Комсомольская, 13"		0101000020E6100000A2F14410E7F05D40F14A92E7FADE4A40
34013	5	48	1622	20325	67190	\N	53.742032000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", г. Могоча, Клубная, 1"	Россия, Забайкальский край, Могочинский район, Могоча	0101000020E6100000A2F14410E7F05D40F14A92E7FADE4A40
34014	5	48	1622	20325	67193	\N	53.742032000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Могочинское"", г. Могоча, Березовая, 29"		0101000020E6100000A2F14410E7F05D40F14A92E7FADE4A40
34017	5	48	1622	20821	73881	\N	53.46463	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Давендинское"", п. Кудеча, Школьная, 1"		0101000020E6100000EF02250516D35D40C85EEFFE78BB4A40
34023	5	48	1622	60059	73803	\N	53.557647000000003	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Ксеньевское"", п. Ксеньевская, Приисковая, Клуб"	Россия, Забайкальский край, Могочинский район, поселок городского типа Ксеньевка	0101000020E6100000E90DF7915BAE5D4034DB15FA60C74A40
34024	5	48	1622	60058	73675	\N	53.560589	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Ксеньевское"", п. Ксеньевская, Камерона, 8"	Россия, Забайкальский край, Могочинский район, поселок городского типа Ксеньевка	0101000020E6100000D6AC33BE2FAE5D40A9BF5E61C1C74A40
34018	5	48	1622	20886	27679	\N	53.535583000000003	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Ключевское"", п. Ключевский, Школьная, 40"		0101000020E6100000CEDF844204DD5D4094A5D6FB8DC44A40
34021	5	48	1622	21049	\N	\N	53.892023000000002	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Ксеньевское"", п. Итака, Школа"		0101000020E6100000058BC3995FAD5D40D12346CF2DF24A40
34016	5	48	1622	60094	73776	\N	53.552026100666403	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Давендинское"", п. Давенда, Октябрьская, 5"	Россия, Забайкальский край, Могочинский район, поселок городского типа Давенда	0101000020E61000007007EA9447D45D405645B8C9A8C64A40
34015	5	48	1622	58993	67199	\N	53.858067308166397	"Забайкальский край, муниципальный район ""Могочинский район"", городское поселение ""Амазарское"", п. Амазар, Клубная, 15"	Россия, Забайкальский край, Могочинский район, поселок городского типа Амазар	0101000020E6100000821E6ADB30375E406F63B323D5ED4A40
15557	5	47	\N	59340	70050	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Куйбышева, 48		0101000020E6100000AA49F08634545440454772F90FE54A40
34366	5	48	692	60093	\N	\N	51.048936208419498	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Цугол"", здание администрации СП"		0101000020E6100000BF27D6A9F2E75C406CCCEB8843864940
34369	5	48	692	60123	\N	\N	51.075956427119102	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Цаган-Челутай"", здание сельского комплекса бытовых услуг"	Россия, Забайкальский край, Могойтуйский район, село Цаган-Челутай	0101000020E61000000EA2B5A2CDC55C40ADF71BEDB8894940
34362	5	48	692	60068	\N	\N	51.355187884406	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Цаган-Ола"", здание администрации СП"	Россия, Забайкальский край, Могойтуйский район, село Цаган-Ола	0101000020E6100000FA0967B796DE5C4040F7E5CC76AD4940
34357	5	48	692	50886	\N	\N	51.262635135245297	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Догой"", Село Харганаши, здание сельского клуба"	Россия, Забайкальский край, Могойтуйский район, село Харганаша	0101000020E6100000DFA815A6EFC25C407AE40F069EA14940
34361	5	48	692	59058	\N	\N	51.5325106068466	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Хара-Шибирь"", здание Дома культуры"	Россия, Забайкальский край, Могойтуйский район, село Хара-Шибирь	0101000020E6100000DFDE35E84BCC5C4050E1085229C44940
34358	5	48	692	60080	\N	\N	51.398417388400603	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Ушарбай"", здание администрации СП"	Россия, Забайкальский край, Могойтуйский район, село Ушарбай	0101000020E61000007172BF4351B55C40D1950854FFB24940
34367	5	48	692	60075	\N	\N	50.815327000000003	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Ортуй"", здание Дома культуры"	Россия, Забайкальский край, Могойтуйский район, село Ортуй	0101000020E6100000EA03C93B87E85C40DD4598A25C684940
34352	5	48	692	59059	67408	\N	51.2845708649104	"Забайкальский край, муниципальный район ""Могойтуйский район"", Городское поселение ""Могойтуй"", Гагарина, 18"	Россия, Забайкальский край, Могойтуйский район, поселок городского типа Могойтуй	0101000020E6100000D6E6FF5547BB5C40EC3191D26CA44940
34354	5	48	692	54089	34031	\N	51.279628828788802	"Забайкальский край, муниципальный район ""Могойтуйский район"", Городское поселение ""Могойтуй"", переулок Черемушки, 1"	Россия, Забайкальский край, Могойтуйский район, поселок городского типа Могойтуй	0101000020E61000002A560DC2DCBB5C40B00111E2CAA34940
34351	5	48	692	51842	73681	\N	51.282902272594697	"Забайкальский край, муниципальный район ""Могойтуйский район"", Городское поселение ""Могойтуй"", Ленина, 3"		0101000020E6100000E8887C9752BB5C408BFCFA2136A44940
34353	5	48	692	51842	73560	\N	51.281115	"Забайкальский край, муниципальный район ""Могойтуйский район"", Городское поселение ""Могойтуй"", Зугалайская, б/н"	Россия, Забайкальский край, Могойтуйский район, поселок городского типа Могойтуй	0101000020E610000009FD4CBD6EBB5C4020B58993FBA34940
34368	5	48	692	60117	\N	\N	50.704521778205603	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Кусоча"", здание Дома культуры"	Россия, Забайкальский край, Могойтуйский район, село Кусоча	0101000020E6100000202A8D98D9E85C4000A8E2C62D5A4940
34372	5	48	692	51781	\N	\N	50.830856855245003	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Хила"", Село Курильжа, здание сельского клуба"	Россия, Забайкальский край, Могойтуйский район, село Курилжа	0101000020E6100000EDB94C4D82D35C408B53AD85596A4940
34360	5	48	692	51766	\N	\N	51.467905007264299	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Зугалай"", здание Дома культуры"	Россия, Забайкальский край, Могойтуйский район, село Зугалай	0101000020E6100000E34F5436ACC15C404451A04FE4BB4940
34356	5	48	692	51059	\N	\N	51.351509417630297	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Догой"", здание Дома культуры"	Россия, Забайкальский край, Могойтуйский район, село Догой	0101000020E61000001AC40776FCA95C40F59F353FFEAC4940
34359	5	48	692	60203	\N	\N	51.446135648857997	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Ушарбай"", Станция Бурятская, здание сельского клуба"	Россия, Забайкальский край, Могойтуйский район, село Бурятская	0101000020E6100000C713419C87AD5C40BDC804FC1AB94940
34370	5	48	692	5835	\N	\N	51.068719999999999	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Цаган-Челутай"", Село Бильчиртуй, здание клуба гарнизона"		0101000020E610000039ED293927CB5C40624A24D1CB884940
34373	5	48	692	6007	\N	\N	51.195107999999998	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Хила"", Село Ара-Булак, здание офиса ОАО ""Славянка"""		0101000020E6100000D09849D40BC65C400F98874CF9984940
34371	5	48	692	60101	\N	\N	51.187086000000001	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Хила"", здание Дома культуры"	Россия, Забайкальский край, Могойтуйский район, село Ага (Хила)	0101000020E61000001F2C634337CB5C400DC51D6FF2974940
15568	5	47	\N	59340	69642	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Карла Маркса, 106		0101000020E6100000AA49F08634545440454772F90FE54A40
34355	5	48	692	60101	\N	\N	51.190226377774898	"Забайкальский край, муниципальный район ""Могойтуйский район"", Сельское поселение ""Ага-Хангил"", здание Дома культуры"	Россия, Забайкальский край, Могойтуйский район, село Ага (Хила)	0101000020E6100000205F420587CA5C40A96C585359984940
33641	5	48	283	60109	73816	\N	49.8509039681757	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Ульхун-Партионское"", Богомолова, 44"	Россия, Забайкальский край, Кыринский район, село Ульхун-Партия	0101000020E6100000B5C189E8D7305C408E041A6CEAEC4840
33643	5	48	283	51002	73842	\N	49.563239759243203	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Верхне-Ульхунское"" с. Тырин, Молодежная, 2"		0101000020E6100000D446753A90195C4047E6913F18C84840
33639	5	48	283	60184	73988	\N	49.735688000000003	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Тарбальджейское"", Пионерская, 20в"	Россия, Забайкальский край, Кыринский район, село Тарбальджей	0101000020E6100000B5FB5580EF205C40A3073E062BDE4840
33635	5	48	283	60132	73869	\N	49.693368410011203	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Мордойское"", Центральная, здание администрации"	Россия, Забайкальский край, Кыринский район, село Мордой	0101000020E6100000344C6DA983015C40E50B5A48C0D84840
33644	5	48	283	60178	73974	\N	49.778258999999998	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Михайло-Павловское"", Дзержинского, 1"		0101000020E6100000804A95287BD55B40A968ACFD9DE34840
33640	5	48	283	51472	27082	\N	49.699702737010803	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Мангутское"", Колхозная, 67"	Россия, Забайкальский край, Кыринский район, село Мангут	0101000020E61000001A6B7F677B2B5C40E0F42EDE8FD94840
33636	5	48	283	60043	73583	\N	49.640242000000001	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Любавинское"", Клубная, 1"	Россия, Забайкальский край, Кыринский район, село Любовь	0101000020E61000002E20B41EBE095C4048C32973F3D14840
33632	5	48	283	51591	67520	\N	49.578994999999999	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Кыринское"", Профсоюзная, 6"	Россия, Забайкальский край, Кыринский район, село Кыра	0101000020E61000001FBE4C1421FE5B4015C616821CCA4840
33633	5	48	283	51591	27289	\N	49.575073816240597	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Кыринское"", Горького, 6"	Россия, Забайкальский край, Кыринский район, село Кыра	0101000020E6100000406A1327F7FE5B40D4635B069CC94840
33638	5	48	283	51591	73779	\N	49.579218210268301	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Хапчерангинское"", Балуева, 1"	Россия, Забайкальский край, Кыринский район, село Кыра	0101000020E6100000BB421F2C63FE5B4094A0BFD023CA4840
33634	5	48	283	60213	74043	\N	49.465711491681901	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Гаваньское"", Новая, 2"	Россия, Забайкальский край, Кыринский район, село Гавань	0101000020E6100000178046E9D20A5C409831056B9CBB4840
33642	5	48	283	60097	73787	\N	49.576301942863502	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Верхне-Ульхунское"", Ленина, 47а"	Россия, Забайкальский край, Кыринский район, село Верхний Ульхун	0101000020E6100000C30E63D2DF225C40484F9143C4C94840
33629	5	48	283	51588	73721	\N	49.589571272367202	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Билютуйское"", Пионерская, 18"		0101000020E61000004AEB6F09C0EC5B40C3D5011077CB4840
33628	5	48	283	51523	27182	\N	49.509838634426899	"Забайкальский край, муниципальный район ""Кыринский район"", сельское поселение ""Алтанское"", Трактовая, 108"	Россия, Забайкальский край, Кыринский район, село Алтан	0101000020E61000004DF4F92823E25B40D89C836742C14840
33592	5	48	34	51714	27630	\N	50.616820725415202	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Черемховское"" село Ямаровка, Центральная, 16"	Россия, Забайкальский край, Красночикойский район, село Ямаровка	0101000020E6100000658BA4DDE88F5B40363E93FDF34E4940
33590	5	48	34	52148	73835	\N	50.604373000000002	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Черемховское"" село Ядрихино, Центральная, 2"		0101000020E61000005CAD1397E3955B40EFCA2E185C4D4940
33613	5	48	34	52194	74015	\N	50.297522999999998	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Байхорское"" село Этытэй, Советская, 9"		0101000020E6100000583CF548831E5B406667D13B15264940
33594	5	48	34	60142	73900	\N	50.562261499872399	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Шимбиликское"", Центральная, 86"	Россия, Забайкальский край, Красночикойский район, село Шимбилик	0101000020E6100000F16261889C645B407B681F2BF8474940
33591	5	48	34	51698	27536	\N	50.582022613897102	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Черемховское"", Центральная, 61"	Россия, Забайкальский край, Красночикойский район, село Черемхово	0101000020E6100000304CA60A468A5B408942CBBA7F4A4940
33623	5	48	34	50737	73819	\N	49.921202367762398	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Жиндойское"" село Хилкотой, Набережная, 16"		0101000020E6100000B2D6506A2F055B40418177F2E9F54840
33598	5	48	34	52169	74010	\N	50.508271999999998	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Захаровское"" село Фомичево, Центральная, 18"		0101000020E6100000E9B7AF03E7505B407BBC900E0F414940
33626	5	48	34	52213	73971	\N	49.943148000000001	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Урлукское"" село Уссть-Урлук, Вторая, 1"		0101000020E6100000307F85CC95F35A40D7A4DB12B9F84840
33625	5	48	34	51797	28022	\N	50.047997749341498	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Урлукское"", Школьная, 9"	Россия, Забайкальский край, Красночикойский район, село Урлук	0101000020E610000005DF347D76F95A40FF2268CC24064940
33595	5	48	34	52160	73911	\N	50.557216411878997	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Захаровское"" село Осиновка, Центральная, 23"	Россия, Забайкальский край, Красночикойский район, село Осиновка	0101000020E6100000139ED0EB4F5D5B406A6798DA52474940
33619	5	48	34	51724	27684	\N	50.092075867486102	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Альбитуйское"" село Нижний Нарым, Центральная, 121"	Россия, Забайкальский край, Красночикойский район, село Нижний Нарым	0101000020E610000062BA10AB3F0F5B408D5F7825C90B4940
33604	5	48	34	51834	28253	\N	50.400568014512501	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Малоархангельское"", Центральная, 110"	Россия, Забайкальский край, Красночикойский район, село Малоархангельск	0101000020E6100000C6A86BED7D365B407DE9EDCF45334940
33606	5	48	34	59029	67311	\N	50.368523000000003	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Красночикойское"", Первомайская, 61"	Россия, Забайкальский край, Красночикойский район, село Красный Чикой	0101000020E610000062F5471806305B407369FCC22B2F4940
33605	5	48	34	59029	67311	\N	50.368523000000003	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Красночикойское"", Первомайская, 1"	Россия, Забайкальский край, Красночикойский район, село Красный Чикой	0101000020E610000062F5471806305B407369FCC22B2F4940
33599	5	48	34	51856	28386	\N	50.4635596665969	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Коротковское"" село Красные Речки, Первомайская, 27"	Россия, Забайкальский край, Красночикойский район, село Красные Речки (Дурново)	0101000020E6100000B18A37328F465B40ECDD1FEF553B4940
33601	5	48	34	51891	28535	\N	50.444850042553	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Коротковское"", Советская, 59"	Россия, Забайкальский край, Красночикойский район, село Коротково	0101000020E6100000BD1B0B0A833E5B4014D044D8F0384940
33596	5	48	34	60106	73805	\N	50.536818877669603	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Захаровское"", Центральная, 37"	Россия, Забайкальский край, Красночикойский район, село Захарово	0101000020E61000001C08C90226585B408B6F287CB6444940
33621	5	48	34	50858	23894	\N	50.077127909885498	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Жиндойское"" село Жиндокон, Транспортная, 25а"	Россия, Забайкальский край, Красночикойский район, село Жиндокон	0101000020E61000006551D845D1035B408ECD8E54DF094940
33622	5	48	34	60141	73898	\N	49.943597397262003	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Жиндойское"", Советская, 40а"	Россия, Забайкальский край, Красночикойский район, село Жиндо-1	0101000020E6100000A7CB6262F3FD5A4046CD57C9C7F84840
33620	5	48	34	52208	73878	\N	49.995120999999997	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Альбитуйское"" село Гутай, Центральная, 49а"		0101000020E610000018265305A30C5B400A48FB1F60FF4840
33615	5	48	34	51707	27595	\N	50.194395053151098	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Верхнешергольджинское"", Центральная, 52"	Россия, Забайкальский край, Красночикойский район, село Верхний Шергольджин	0101000020E6100000382F4E7CB5145B40C2C073EFE1184940
33602	5	48	34	52175	73961	\N	50.418810000000001	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Коротковское"" село Быково, Заречная, 16"	Россия, Забайкальский край, Красночикойский район, село Быково	0101000020E6100000B2D991EA3B415B406F9EEA909B354940
33616	5	48	34	52198	73964	\N	50.179749000000001	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Верхнешергольджинское"" село Бурсомон, Новая, 2"	Россия, Забайкальский край, Красночикойский район, село Бурсомон	0101000020E6100000CA8B4CC0AF105B408E3EE60302174940
33617	5	48	34	60070	73726	\N	50.576338849432503	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Большереченское"", Советская, 24"		0101000020E610000049BDA772DA7E5B406534F279C5494940
33603	5	48	34	52179	73962	\N	50.423734000000003	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Коротковское"" село Барахоево, Октябрьская, 109"		0101000020E6100000FD868906293A5B40051A6CEA3C364940
15276	5	47	\N	5685	69774	\N	52.496465938493898	Алтайский край, г. Алейск, Давыдова, 185		0101000020E6100000A96917D34CB15440B8C9A8328C3F4A40
33614	5	48	34	51706	27582	\N	50.295386017463301	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Байхорское"" село Мостовка, Центральная, 5"	Россия, Забайкальский край, Красночикойский район, село Байхор	0101000020E6100000CFA0A17F82255B401FD95C35CF254940
33612	5	48	34	51706	27582	\N	50.295902115291803	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Байхорское"", Центральная, 31"	Россия, Забайкальский край, Красночикойский район, село Байхор	0101000020E6100000AB764D486B255B401669E21DE0254940
33597	5	48	34	52164	73908	\N	50.486309973774098	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Захаровское"" село Аца, Горная, 2"	Россия, Забайкальский край, Красночикойский район, село Аца	0101000020E610000014200A664C635B40E0DBF4673F3E4940
33593	5	48	34	51027	24425	\N	50.571577547544003	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Черемховское"" село Афонькино, Шоссейная, 8"	Россия, Забайкальский край, Красночикойский район, село Афонькино	0101000020E6100000AFEB17EC86875B407A8EC87729494940
33607	5	48	34	51763	27899	\N	50.315580936019302	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Архангельское"", Колхозная, 1"	Россия, Забайкальский край, Красночикойский район, село Архангельское (Качен)	0101000020E61000004356B77A4E305B40971E4DF564284940
33618	5	48	34	51900	28558	\N	50.142145024826704	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Альбитуйское"", Адрияновская, 10"	Россия, Забайкальский край, Красночикойский район, село Альбитуй	0101000020E610000040A03369530E5B401C25AFCE31124940
33608	5	48	34	52183	73923	\N	50.344676496319202	"Забайкальский край, муниципальный район ""Красночикойский район"", сельское поселение ""Архангельское"" село Александровка, Центральная, 13"	Россия, Забайкальский край, Красночикойский район, село Александровка (Карымка)	0101000020E6100000C4EC65DB69345B40A9DBD9571E2C4940
33869	5	48	1224	51864	\N	\N	50.270403502601503	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Юбилейнинское"", Дом культуры п.Юбилейный"	Россия, Забайкальский край, Краснокаменский район, село Юбилейный	0101000020E61000009C6ED921FE965D40925A28999C224940
33867	5	48	1224	60054	\N	\N	50.264180746353397	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Целиннинское"", Дом культуры п.Целинный"	Россия, Забайкальский край, Краснокаменский район, село Целинный	0101000020E6100000EC504D49D6875D40BF9CD9AED0214940
33865	5	48	1224	51530	\N	\N	50.078123859809097	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Соктуй-Милозанское"", Дом культуры с.Соктуй-Милозан"	Россия, Забайкальский край, Краснокаменский район, село Соктуй-Милозан	0101000020E610000055A0168387715D4030849CF7FF094940
33864	5	48	1224	51528	\N	\N	50.071286630025199	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", здание администрации п. Октябрьский"		0101000020E610000020ED7F80B58E5D40A2D0B2EE1F094940
33868	5	48	1224	60118	\N	\N	50.402997099760299	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Маргуцекское"", Дом культуры п.Маргуцек"	Россия, Забайкальский край, Краснокаменский район, село Маргуцек	0101000020E6100000D811876C20795D406CB1DB6795334940
33870	5	48	1224	60176	\N	\N	50.240076618027999	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Юбилейнинское"", Дом культуры п.Куйтун"		0101000020E61000005C38109205A75D40CAC2D7D7BA1E4940
33874	5	48	1224	12362	\N	\N	50.106090999999999	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Среднеаргунское"", Дом культуры с.Среднеаргунск"	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E61000005358A9A0A2835D4031B3CF63940D4940
33862	5	48	1224	12362	\N	\N	50.097746258758399	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №3"	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E61000009C86A8C29F825D404CA8E0F0820C4940
33861	5	48	1224	12362	\N	\N	50.103220386509001	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", здание УМП ""ЖКУ"""		0101000020E6100000CAA99D616A835D4085251E50360D4940
33859	5	48	1224	12362	\N	\N	50.086690521751599	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №7"	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E610000033535A7F4B825D40C4EDD0B0180B4940
33957	5	48	1453	51492	\N	\N	49.926158999999998	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Даурское"", Здание МУК ИБДЦ ""Камертон"""		0101000020E6100000E62329E961365D40B2F2CB608CF64840
33858	5	48	1224	12362	\N	\N	50.102482013870798	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №6"	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E6100000FB3BDBA337835D40DF3653211E0D4940
33856	5	48	1224	12362	\N	\N	50.102999565984902	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Общежитие 9-ти этажное"	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E610000091F3FE3F4E835D4077BE9F1A2F0D4940
33854	5	48	1224	12362	\N	\N	50.090307566750297	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №4"		0101000020E61000009FE925C632825D40994869368F0B4940
33853	5	48	1224	12362	\N	\N	50.103144479569302	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Профессиональное училище №11"	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E61000002E5915E126835D40AA6395D2330D4940
33852	5	48	1224	12362	\N	\N	50.105649344717101	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Дом культуры ""Даурия"""	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E6100000DF1B430070835D4074ED0BE8850D4940
33851	5	48	1224	12362	\N	\N	50.103882841939601	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №1"	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E6100000B80721205F835D4021CEC3094C0D4940
33850	5	48	1224	12362	\N	\N	50.103586118250398	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Специальная коррекционная школа №11"		0101000020E6100000AF7B2B1213835D406729594E420D4940
33849	5	48	1224	12362	\N	\N	50.106090999999999	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Средняя школа №2"		0101000020E61000005358A9A0A2835D4031B3CF63940D4940
33848	5	48	1224	12362	\N	\N	50.106090999999999	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Школа-гимназия №9"		0101000020E61000005358A9A0A2835D4031B3CF63940D4940
33847	5	48	1224	12362	\N	\N	50.105980556694902	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", городское поселение ""Город Краснокаменск"", Районный Дом культуры ""Строитель"""	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	0101000020E6100000CC79C6BE64835D40AA7F10C9900D4940
33866	5	48	1224	51765	\N	\N	50.374138165365899	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Ковылинское"", Дом культуры п.Ковыли"	Россия, Забайкальский край, Краснокаменский район, село Ковыли	0101000020E6100000F27C06D49B675D406E1805C1E32F4940
33872	5	48	1224	60200	\N	\N	49.955570000000002	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Капцегайтуйское"", Здание администрации с.Капцегайтуй"		0101000020E6100000D28BDAFD2AA65D40F584251E50FA4840
33873	5	48	1224	60120	\N	\N	49.832700691208203	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Кайластуйское"", Дом культуры с.Кайластуй"	Россия, Забайкальский край, Краснокаменский район, село Кайластуй	0101000020E61000000F9D9E7763995D405A2C45F295EA4840
33871	5	48	1224	51770	\N	\N	50.004446132014401	"Забайкальский край, муниципальный район ""Город Краснокаменск и Краснокаменский район"", сельское поселение ""Богдановское"", Дом культуры с.Богдановка"	Россия, Забайкальский край, Краснокаменский район, село Богдановка	0101000020E610000024B891B245B05D408C4CC0AF91004940
33982	5	48	1560	51899	28553	\N	51.769964541368303	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Урульгинское"", Центральная, здание библиотеки"	Россия, Забайкальский край, Карымский район, село Урульга	0101000020E610000094A2957B81B35C4046088F368EE24940
33980	5	48	1560	51899	67358	\N	51.767870000000002	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Урульгинское"", Забелина, 1"	Россия, Забайкальский край, Карымский район, село Урульга	0101000020E61000009F55664AEBB25C402ECA6C9049E24940
34003	5	48	1560	51746	27818	\N	51.446175350590899	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Тыргетуйское"", Центральная, 16"	Россия, Забайкальский край, Карымский район, село Тыргетуй	0101000020E610000032C687D9CB725C407AA52C431CB94940
34002	5	48	1560	51746	27818	\N	51.444601920260602	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Тыргетуйское"", Центральная, 68"	Россия, Забайкальский край, Карымский район, село Тыргетуй	0101000020E6100000F90FE9B7AF725C403CDEE4B7E8B84940
34001	5	48	1560	60180	73978	\N	51.535689270544403	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Новодоронинское"", Центральная, 47"	Россия, Забайкальский край, Карымский район, село Новодоронинск	0101000020E610000020B41EBE4C775C40D9E9077591C44940
33978	5	48	1560	50837	23832	\N	51.931036681108999	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Нарын-Талачинское"", Школьная, 1"		0101000020E6100000FD6662BA10B75C40D82E6D382CF74940
33979	5	48	1560	50837	74029	\N	51.929040999999998	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Нарын-Талачинское"", Центральная, 28"	Россия, Забайкальский край, Карымский район, село Нарын-Талача	0101000020E61000005AD6FD6321B75C4052D2C3D0EAF64940
33977	5	48	1560	50837	73886	\N	51.929040999999998	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Нарын-Талачинское"", Иландинская, здание библиотеки"	Россия, Забайкальский край, Карымский район, село Нарын-Талача	0101000020E61000005AD6FD6321B75C4052D2C3D0EAF64940
33988	5	48	1560	51498	\N	\N	51.480273755612799	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Маякинское"", Лесная, здание школы"	Россия, Забайкальский край, Карымский район, село Маяки	0101000020E61000009599D2FA5B955C403F8F519E79BD4940
33987	5	48	1560	51498	27132	\N	51.480642944007997	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Маякинское"", Никифорова, 35"	Россия, Забайкальский край, Карымский район, село Маяки	0101000020E6100000AAD72D0263955C409206B7B585BD4940
94931	5	48	1560	60174	\N	\N	51.197760105592998	"""Забайкальский край, муниципальный район """"Карымский район"""", городское поселение """"Курорт-Дарасунское"""", здание Дома культуры военного санатория"""	Россия, Забайкальский край, Карымский район, поселок городского типа Курорт-Дарасун	0101000020E6100000DA1F28B7ED6D5C407E3A1E3350994940
33991	5	48	1560	59127	67988	\N	51.616625106413501	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Карымское"", Ангарская, 1"	Россия, Забайкальский край, Карымский район, поселок городского типа Карымское	0101000020E61000006C5B94D920965C40B0726891EDCE4940
33993	5	48	1560	51903	28590	\N	51.624746115754697	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Карымское"", Торговый переулок, 24"	Россия, Забайкальский край, Карымский район, поселок городского типа Карымское	0101000020E6100000A626C11BD2955C4046274BADF7CF4940
33992	5	48	1560	51903	67372	\N	51.628729	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Карымское"", Ленинградская, 100"	Россия, Забайкальский край, Карымский район, поселок городского типа Карымское	0101000020E61000006405BF0D31955C40FD851E317AD04940
33990	5	48	1560	60035	73596	\N	51.616624897692802	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Карымское"", Ленинградская, 76"		0101000020E6100000E46723D74D965C40B0726891EDCE4940
33989	5	48	1560	60035	73562	\N	51.629019999999997	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Карымское"", Верхняя, 32"	Россия, Забайкальский край, Карымский район, поселок городского типа Карымское	0101000020E6100000948444DAC6955C40D44334BA83D04940
94930	5	48	1560	51000	24300	\N	51.635192004316501	"""Забайкальский край, муниципальный район """"Карымский район"""", сельское поселение """"Кайдаловское"""", Телевизионная, 9"""	Россия, Забайкальский край, Карымский район, село Кайдалово	0101000020E610000070CFF3A78DA45C402657B1F84DD14940
33983	5	48	1560	51000	73806	\N	51.637321280001501	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Кайдаловское"", Советская, 24"	Россия, Забайкальский край, Карымский район, село Кайдалово	0101000020E6100000871A8524B3A45C40EA060ABC93D14940
33984	5	48	1560	51000	28521	\N	51.633720268605302	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Кайдаловское"", Вокзальная, 3"	Россия, Забайкальский край, Карымский район, село Кайдалово	0101000020E6100000967B8159A1A45C401A69A9BC1DD14940
33994	5	48	1560	51500	27139	\N	51.614962720629201	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Кадахтинское"", Советская, 31"	Россия, Забайкальский край, Карымский район, село Кадахта	0101000020E61000005A0D897B2C905C4002A08A1BB7CE4940
33996	5	48	1560	60209	74037	\N	51.516986285032601	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Жимбиринское"", Новая, 2"	Россия, Забайкальский край, Карымский район, село Жимбира	0101000020E610000069ACFD9DED805C40B43EE5982CC24940
33998	5	48	1560	51508	67187	\N	51.654979912289498	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Дарасунское"", Транспортная, 1"	Россия, Забайкальский край, Карымский район, поселок городского типа Дарасун	0101000020E610000082E673EE767E5C405DC47762D6D34940
34000	5	48	1560	51508	73673	\N	51.663028132957898	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Дарасунское"", Почтовая, 5"		0101000020E6100000522AE109BD7E5C40882AFC19DED44940
33999	5	48	1560	51508	73549	\N	51.651609830119902	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Дарасунское"", Нагорная, 49"		0101000020E610000008C89750C17D5C408FDFDBF467D34940
34007	5	48	1560	51508	27153	\N	51.649574982223101	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Курорт-Дарасунское"", Дорожная, 20"	Россия, Забайкальский край, Карымский район, поселок городского типа Дарасун	0101000020E610000057D11F9A797D5C404CA60A4625D34940
33997	5	48	1560	51508	27153	\N	51.656041072629201	"Забайкальский край, муниципальный район ""Карымский район"", городское поселение ""Дарасунское"", Дорожная, здание Дарасунского лесничества"		0101000020E6100000DDED7A698A7E5C40E6EAC726F9D34940
94932	5	48	1560	20093	\N	\N	51.653270999999997	"""Забайкальский край, муниципальный район """"Карымский район"""", городское поселение """"Курорт-Дарасунское"""", Дом культуры санатория """"Дарасун"""""""		0101000020E61000008463963D097E5C406D3656629ED34940
33995	5	48	1560	50819	23743	\N	51.633749999930501	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Большетуринское"", Железнодорожная, 44"	Россия, Забайкальский край, Карымский район, село Большая Тура	0101000020E610000074F04C6892855C4085EB51B81ED14940
33986	5	48	1560	60105	73800	\N	51.565990739293902	"Забайкальский край, муниципальный район ""Карымский район"", сельское поселение ""Адриановское"", Школьная, 14"	Россия, Забайкальский край, Карымский район, село Адриановка	0101000020E6100000AAD5575705A15C40486AA16472C84940
34088	5	48	1529	50877	23956	\N	51.039551242674897	"Забайкальский край, муниципальный район ""Нерчинско-Заводский район"", сельское поселение ""Явленское"", Советская, 3"	Россия, Забайкальский край, Калганский район, село Явленка	0101000020E61000009CFA40F2CEC55D4016C3D50110854940
33976	5	48	1529	51058	73844	\N	50.885591479321597	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Шивиинское"", Гагарина, 30"		0101000020E6100000A1BAB9F8DBC75D40E350BF0B5B714940
33975	5	48	1529	50754	23533	\N	50.987201488693501	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Чупровское"", Школьная, 15"	Россия, Забайкальский край, Калганский район, село Чупрово	0101000020E610000088DA368C82BF5D400CCA349A5C7E4940
33974	5	48	1529	60212	74042	\N	50.794077667909299	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Чингильтуйское"", Новая, 9"	Россия, Забайкальский край, Калганский район, село Чингильтуй	0101000020E610000069E55E6056C25D408E3C1059A4654940
33973	5	48	1529	50960	24162	\N	50.911753575323402	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Средне-Борзинское"", Советская, 1"	Россия, Забайкальский край, Калганский район, село Средняя Борзя	0101000020E61000007FBF982D59DF5D40A4FFE55AB4744940
33972	5	48	1529	60107	73809	\N	50.743862727790201	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Нижне-Калгуканское"", Центральная, 59"	Россия, Забайкальский край, Калганский район, село Нижний Калгукан	0101000020E61000002463B5F97FBA5D402BDA1CE7365F4940
33971	5	48	1529	51743	27793	\N	51.206409377581899	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Козловское"", Валько, 31"	Россия, Забайкальский край, Калганский район, село Козлово	0101000020E6100000BE89213999BB5D40CF4C309C6B9A4940
33970	5	48	1529	51739	27774	\N	50.922797578582603	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Калганское"", Гаражная, 1"	Россия, Забайкальский край, Калганский район, село Калга	0101000020E61000009BC937DBDCB95D403868AF3E1E764940
33968	5	48	1529	60090	73771	\N	50.933622999999997	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Кадаинское"", Советская, 44"	Россия, Забайкальский край, Калганский район, село Кадая	0101000020E6100000E8BE9CD9AED25D408EE55DF580774940
33967	5	48	1529	60074	73742	\N	50.892598	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Доновское"", Нагорная, 56"	Россия, Забайкальский край, Калганский район, село Доно	0101000020E61000003A933655F7A55D40CD3CB9A640724940
33966	5	48	1529	51047	24589	\N	50.8158263970669	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Верхне-Калгуканское"", Молодёжная, 13а"	Россия, Забайкальский край, Калганский район, село Верхний Калгукан	0101000020E610000058AB764D48B25D40FE9C82FC6C684940
33965	5	48	1529	60179	73977	\N	50.753070999999998	"Забайкальский край, муниципальный район ""Калганский район"", сельское поселение ""Буринское"", В. Козлова, 42"	Россия, Забайкальский край, Калганский район, село Бура	0101000020E61000003EB2B96A9EDC5D4073486AA164604940
33588	5	48	1907	31392	28313	\N	56.902127821261899	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Чарское"",село Чара, Озерная, 35"	Россия, Забайкальский край, Каларский район, село Чара	0101000020E6100000E3FE23D3A1905D40276728EE78734C40
33584	5	48	1907	31392	28313	\N	56.9018930013725	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Чарское"", село Чара, Озерная, 35"	Россия, Забайкальский край, Каларский район, село Чара	0101000020E6100000583B8A73D4905D40E4BED53A71734C40
33587	5	48	1907	31392	73757	\N	56.9067769498403	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Чарское"",село Чара, 60 лет ВЛКСМ, 7"	Россия, Забайкальский край, Каларский район, село Чара	0101000020E610000044FD2E6CCD905D40EBE1CB4411744C40
33585	5	48	1907	31436	73846	\N	57.073042000000001	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Чапо-Ологское"", село Чапо-Олого, Набережная, 1"		0101000020E61000009DD7D825AAB45D40029EB47059894C40
33580	5	48	1907	31183	73836	\N	56.750609460557797	"Забайкальский край, муниципальный район ""Каларский район"", городское поселение ""Новочарское"",село Удокан, Иркутская, 6"	Россия, Забайкальский край, Каларский район, село Удокан	0101000020E61000004EEFE2FDB8935D40A88AA9F413604C40
33576	5	48	1907	60086	73763	\N	56.798290000000001	"Забайкальский край, муниципальный район ""Каларский район"", городское поселение ""Новочарское"",поселок Новая Чара, Магистральная, 22 А"		0101000020E6100000BABA63B14D915D40A75CE15D2E664C40
33581	5	48	1907	30995	24597	\N	56.798290000000001	"Забайкальский край, муниципальный район ""Каларский район"", городское поселение ""Новочарское"", поселение Новая Чара, Центральная, 1"		0101000020E6100000BABA63B14D915D40A75CE15D2E664C40
33579	5	48	1907	30995	24597	\N	56.798290000000001	"Забайкальский край, муниципальный район ""Каларский район"", городское поселение ""Новочарское"",поселок Новая Чара, Центральная, 1"		0101000020E6100000BABA63B14D915D40A75CE15D2E664C40
33578	5	48	1907	30995	28300	\N	56.798290000000001	"Забайкальский край, муниципальный район ""Каларский район"", городское поселение ""Новочарское"",поселок Новая Чара, Юбилейная, 6"		0101000020E6100000BABA63B14D915D40A75CE15D2E664C40
33589	5	48	1907	31641	73854	\N	56.964038000000002	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Чарское"", село Кюсть-Кемда, Беляева, 8"		0101000020E61000009013268C66945D40F60CE198657B4C40
33582	5	48	1907	31287	27516	\N	56.327719999999999	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Куандинское"", село Куанда, Энтузиастов, 4"		0101000020E61000005512D90759065D40601F9DBAF2294C40
33583	5	48	1907	31287	24266	\N	56.327719999999999	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Куандинское"", село Куанда, Советская, 10"		0101000020E61000005512D90759065D40601F9DBAF2294C40
33586	5	48	1907	31495	73896	\N	56.996665999999998	"Забайкальский край, муниципальный район ""Каларский район"", сельское поселение ""Икабьинское"",село Икабья, 1  микрорайон, 8"		0101000020E61000001FF5D72B2CB15D407F8461C0927F4C40
33473	5	48	7086	50730	23475	\N	52.063818079439102	"Забайкальский край, Городской округ ""Город Чита"", Ингодинский административный район, Александро-Заводская, 30"	Россия, Забайкальский край, городской округ Чита	0101000020E6100000E162450DA65A5C40B4722F302B084A40
33958	5	48	1453	51039	73728	\N	50.112558281559402	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Черно-Озерское"", Совхозная, 23"	Россия, Забайкальский край, Забайкальский район, село Черноозерский	0101000020E610000076C075C58C2C5D409B73F04C680E4940
33962	5	48	1453	51672	\N	\N	50.010130616055498	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Степное"", Здание Степнинской основной школы"	Россия, Забайкальский край, Забайкальский район, село Степной	0101000020E6100000653909A52F5E5D4080D6FCF84B014940
33963	5	48	1453	51044	73843	\N	49.7015641005436	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Рудник-Абагайтуйское"", имени Молодой Гвардии, Средняя школа"		0101000020E61000001E15FF7744795D40850662D9CCD94840
33961	5	48	1453	50761	\N	\N	50.0761161881546	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Красновеликанское"", Здание начальной школы"	Россия, Забайкальский край, Забайкальский район, село Красный Великан	0101000020E61000007C7F83F6EA435D40E659492BBE094940
33959	5	48	1453	50761	23550	\N	50.076202066588898	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Красновеликанское"", Центральная, 22"	Россия, Забайкальский край, Забайкальский район, село Красный Великан	0101000020E6100000187D0569C6435D40E5F1B4FCC0094940
33960	5	48	1453	50761	23553	\N	50.076054804028502	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Красновеликанское"", Шоссейная, СДК"	Россия, Забайкальский край, Забайкальский район, село Красный Великан	0101000020E6100000A12B11A8FE435D4040D9942BBC094940
33953	5	48	1453	51610	67667	\N	49.649282999999997	"Забайкальский край, муниципальный район ""Забайкальский район"", городское поселение ""Забайкальское"", Красноармейская, 53"	Россия, Забайкальский край, Забайкальский район, поселок городского типа Забайкальск	0101000020E61000005665DF15C1555D40A46C91B41BD34840
33952	5	48	1453	51610	27340	\N	49.655027108829103	"Забайкальский край, муниципальный район ""Забайкальский район"", городское поселение ""Забайкальское"", Железнодорожная, 14а"	Россия, Забайкальский край, Забайкальский район, поселок городского типа Забайкальск	0101000020E6100000FB592C45F2555D409D7FBBECD7D34840
33951	5	48	1453	60042	73578	\N	49.649282999999997	"Забайкальский край, муниципальный район ""Забайкальский район"", городское поселение ""Забайкальское"", Красноармейская, 32а"		0101000020E61000005665DF15C1555D40A46C91B41BD34840
33954	5	48	1453	60042	73691	\N	49.653243948697202	"Забайкальский край, муниципальный район ""Забайкальский район"", городское поселение ""Забайкальское"", Дружбы, 1А"		0101000020E6100000118E59F624555D407427D87F9DD34840
33956	5	48	1453	51492	\N	\N	49.925525997971498	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Даурское"", Здание Администрации сельского поселения ""Даурское"", ДОС 10"	Россия, Забайкальский край, Забайкальский район, село Даурия	0101000020E610000078B81D1A16365D4081CCCEA277F64840
33936	5	48	1453	51492	\N	\N	49.931952771118603	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Даурское"", Средняя школа с. Даурия, 28"	Россия, Забайкальский край, Забайкальский район, село Даурия	0101000020E6100000AFEAAC16D8365D405D34643C4AF74840
33955	5	48	1453	60110	73817	\N	49.827418611368998	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Билитуйское"", переулок Степной, 4"	Россия, Забайкальский край, Забайкальский район, село Билитуй	0101000020E610000008AD872F13465D40658BA4DDE8E94840
33964	5	48	1453	60076	73746	\N	49.5786638135624	"Забайкальский край, муниципальный район ""Забайкальский район"", сельское поселение ""Абагайтуйское"", Пограничная, 7"	Россия, Забайкальский край, Забайкальский район, село Абагайтуй	0101000020E6100000B323D5777E755D40B0AF75A911CA4840
94940	5	48	631	4733	27354	\N	50.5756712437475	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Чиндалей"""", село Чиндалей, Балданжабона 2"""	Россия, Забайкальский край, Дульдургинский район, село Чиндалей	0101000020E6100000575D876A4A795C40B8205B96AF494940
94941	5	48	631	4778	24310	\N	50.578502999999998	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Узон"""", село Узон, Октябрьская 56"""		0101000020E6100000C3499A3FA6665C40A6D1E4620C4A4940
94939	5	48	631	4668	28121	\N	50.513323999999997	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Токчин"""", село Токчин, Ленина, 17"""		0101000020E6100000344DD87E32885C403E20D099B4414940
94937	5	48	631	4554	22881	\N	50.778593999999998	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Таптанай"""", село Таптанай, Калинина, 54""-а"	Россия, Забайкальский край, Дульдургинский район, село Таптанай	0101000020E610000048895DDBDB735C40506EDBF7A8634940
94934	5	48	631	4455	73951	\N	50.9575386839592	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Бальзино"""", с.Красноярово, Школьная, 7"""	Россия, Забайкальский край, Дульдургинский район, село Красноярово	0101000020E61000009D2ADF3312625C4080D250A3907A4940
94936	5	48	631	4501	73906	\N	50.835856	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Иля"""", село Иля, Новая, 27"""		0101000020E61000007B4B395FEC655C402B155454FD6A4940
94938	5	48	631	4610	28115	\N	50.661761586943598	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Зуткулей"""", село Зуткулей, Ленина, 21"""	Россия, Забайкальский край, Дульдургинский район, село Зуткулей	0101000020E61000001F4DF564FE8B5C4027DE019EB4544940
34339	5	48	631	4095	27478	\N	50.672021840409002	"Забайкальский край, муниципальный район ""Дульдургинский район"", сельское поселение ""Дульдурга"", село Дульдурга, Энергетиков, 17"	Россия, Забайкальский край, Дульдургинский район, село Дульдурга	0101000020E6100000DCD7817346655C40A41820D104564940
34338	5	48	631	4095	27472	\N	50.676875931844698	"Забайкальский край, муниципальный район ""Дульдургинский район"", сельское поселение ""Дульдурга"", село Дульдурга, Кирова, 4"	Россия, Забайкальский край, Дульдургинский район, село Дульдурга	0101000020E6100000035E66D828665C4041B96DDFA3564940
34340	5	48	631	4095	67728	\N	50.678017690644403	"Забайкальский край, муниципальный район ""Дульдургинский район"", сельское поселени е ""Дульдурга"", село Дульдурга, 8 марта, 7"	Россия, Забайкальский край, Дульдургинский район, село Дульдурга	0101000020E6100000B48F15FC36665C40B70C384BC9564940
34343	5	48	631	51046	73748	\N	51.049299702980697	"Забайкальский край, муниципальный район ""Дульдургинский район"", сельское поселение ""Бальзино""село Бальзино, Чкалова, 63"		0101000020E6100000401361C3D3655C40AED85F764F864940
94935	5	48	631	4337	73907	\N	50.937041000000001	"""Забайкальский край, муниципальный район """"Дульдургинский район"""", сельское поселение """"Ара-Иля"""", село Ара-Иля, Советская 1"""		0101000020E6100000AB7B6473D5515C406D01A1F5F0774940
34341	5	48	631	4273	73784	\N	50.730196999999997	"Забайкальский край, муниципальный район ""Дульдургинский район"", сельское поселение ""Алханай"", село Алханай, Далаева, 15"		0101000020E6100000789ACC785B5E5C4093516518775D4940
33938	5	48	1437	16699	73944	\N	51.595731000000001	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Новоширокинское"", село Широкая, Строительная, 4 а"		0101000020E6100000C9CB9A58E0AB5D40501BD5E940CC4940
33942	5	48	1437	16899	27397	\N	51.679687999999999	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Ушмунское"", село Ушмун, Заречная, 2"		0101000020E610000019ADA3AA09975D40E8BD310400D74940
33928	5	48	1437	16184	27335	\N	51.405394999999999	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Трубачевское"", село Трубачево, Центральная, 58"		0101000020E6100000C30E63D2DF8C5D40207BBDFBE3B34940
16527	5	47	\N	59356	69752	\N	52.837870000000002	Алтайский край, Солтонский район, с.Солтон, Демьяна Бедного, 3		0101000020E6100000D68BA19C689E55405726FC523F6B4A40
33937	5	48	1437	16631	73929	\N	51.588937999999999	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Газимуро-Заводское"",  село Тайна, Центральная, 25 а"		0101000020E61000009E95B4E21B9D5D4092AF045262CB4940
33940	5	48	1437	16790	73778	\N	51.525432000000002	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Солонеченское"", село Солонечный, Мира, 42"	Россия, Забайкальский край, Газимуро-Заводский район, село Солонечный	0101000020E610000065E3C116BBB95D40CD22145B41C34940
33939	5	48	1437	51694	\N	\N	51.576979793795502	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Газимуро-Заводское"", пст. Новоширокинский, Здание сельской администрации, 34"		0101000020E61000008FDE701FB9A95D4019390B7BDAC94940
33945	5	48	1437	17033	24381	\N	52.054845	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Батаканское"", село Луговское, Майская, 26"		0101000020E610000037E2C96E66B45D40B0AC342905074A40
33943	5	48	1437	16941	73959	\N	51.800887000000003	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Буруканское"", село Кунгара, Центральная, 4"		0101000020E610000098DEFE5C349C5D405265187783E64940
33930	5	48	1437	16289	23361	\N	51.527694563249703	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Газимуро-Заводское"", село Корабль, Центральная, 9"	Россия, Забайкальский край, Газимуро-Заводский район, село Корабль	0101000020E6100000D80C7041B6925D40A1A17F828BC34940
33941	5	48	1437	16852	74017	\N	51.631244000000002	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Ушмунское"", село Калдага, Центральная, 15"		0101000020E6100000BE2F2E5569975D40EBE5779ACCD04940
33931	5	48	1437	16349	73966	\N	51.566466840041898	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Газимуро-Заводское"", село Игдоча, Центральная, 28"	Россия, Забайкальский край, Газимуро-Заводский район, село Игдоча	0101000020E6100000486E4DBA2D945D40B2A19BFD81C84940
33948	5	48	1437	17171	23429	\N	52.034289000000001	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Зеренское"",  село Зерен, Журавлева, 11"		0101000020E6100000785E2A36E6E25D4068CEFA9463044A40
33947	5	48	1437	17154	23406	\N	52.079011000000001	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Батаканское"", село Закаменная, Журавлева, 30"		0101000020E61000005C59A2B3CCBA5D401B834E081D0A4A40
33929	5	48	1437	16221	24254	\N	51.495123	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Трубачевское"", село Догье, Майская, 7"		0101000020E61000007155D977458E5D40AB3FC23060BF4940
33935	5	48	1437	16441	73954	\N	51.546889	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Газимуро-Заводское"", село Газимурский Завод, Рабочая, 11 а"		0101000020E61000005437177FDB955D4065C5707500C64940
33933	5	48	1437	16441	67184	\N	51.549564546136601	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Газимуро-Заводское"", село Газимурский Завод, Журавлева, 10 а"	Россия, Забайкальский край, Газимуро-Заводский район, село Газимурский Завод	0101000020E61000001B0FB6D8ED955D405C035B2558C64940
33934	5	48	1437	16441	73736	\N	51.546889	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Газимуро-Заводское"", село Газимурский Завод, Волкова, 12 а"		0101000020E61000005437177FDB955D4065C5707500C64940
33927	5	48	1437	16125	24284	\N	51.359352000000001	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Трубачевское"", село Газимурские Кавыкучи, Трактовая, 13"	Россия, Забайкальский край, Газимуро-Заводский район, село Газимурские Кавыкучи	0101000020E6100000904DF2237E8B5D4048E00F3FFFAD4940
33944	5	48	1437	16989	73957	\N	51.841197000000001	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Буруканское"", село Бурукан, Школьная, 8"	Россия, Забайкальский край, Газимуро-Заводский район, село Бурукан	0101000020E6100000DBDFD91EBDA15D40253FE257ACEB4940
33946	5	48	1437	17085	27337	\N	52.073149000000001	"Забайкальский край, муниципальный район ""Газимуро-Заводский район"", сельское поселение ""Батаканское"", село Батакан, Центральная, 47"		0101000020E610000094A12AA6D2B65D40185E49F25C094A40
33823	5	48	1136	60170	\N	\N	50.250438802578401	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Южное"", помещение МОУ: Южнинская ООШ"	Россия, Забайкальский край, Борзинский район, село Южное	0101000020E6100000096B63EC84245D404C5299620E204940
33822	5	48	1136	60208	74036	\N	50.774532099328503	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Шоноктуйское"", Нагорная, 1"	Россия, Забайкальский край, Борзинский район, село Шоноктуй	0101000020E6100000CDE7DCED7A515D404DDA54DD23634940
33827	5	48	1136	59121	67925	\N	50.532325999999998	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Шерловогорское"", Оловянная, 4"	Россия, Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора	0101000020E6100000166C239EEC145D40BE67244223444940
33826	5	48	1136	51516	\N	\N	50.5364582985288	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Шерловогорское"", помещение Дома детского творчества"	Россия, Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора	0101000020E61000000874266DAA155D40BBD6DEA7AA444940
33830	5	48	1136	51516	73882	\N	50.521966279300997	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Шерловогорское"", Шоссейная, 6 А"	Россия, Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора	0101000020E610000032C7F2AE7A145D40DDCF29C8CF424940
33829	5	48	1136	51516	28284	\N	50.537941302729799	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Шерловогорское"", Ленина, 14"	Россия, Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора	0101000020E6100000309DD66D50155D40B9162D40DB444940
33828	5	48	1136	51516	28284	\N	50.534548945724502	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Шерловогорское"", Ленина, 4"	Россия, Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора	0101000020E61000004A09C1AA7A145D40048E041A6C444940
33824	5	48	1136	51516	73770	\N	50.536683193399597	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Шерловогорское"", Горького, 12"	Россия, Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора	0101000020E610000059198D7C5E155D40DAA84E07B2444940
33825	5	48	1136	51516	27169	\N	50.536336715959699	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Шерловогорское"", 50 лет Октября"	Россия, Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора	0101000020E61000009337C0CC77155D404051D9B0A6444940
33821	5	48	1136	60079	\N	\N	50.375987143817902	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Чиндантское"", помещение МОУ: Чиндантская ООШ"	Россия, Забайкальский край, Борзинский район, село Чиндант 2-й	0101000020E61000009F5BE84A04185D404F5C8E5720304940
33820	5	48	1136	51515	\N	\N	50.4729487031872	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Цаган-Олуйское"", помещение МОУ:  Цаган-Олуйская СОШ"	Россия, Забайкальский край, Борзинский район, село Цаган-Олуй	0101000020E61000008787307E1A4A5D4084D6C397893C4940
33819	5	48	1136	60064	\N	\N	50.608958000000001	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Хада-Булакское"", помещение МОУ: Хада-Булакская СОШ"	Россия, Забайкальский край, Борзинский район, село Хада-Булак	0101000020E6100000DFDDCA129D235D409C51F355F24D4940
33818	5	48	1136	60206	\N	\N	50.701931999999999	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Усть-Озерское"", помещение МОУ: Усть-Озерская СОШ"	Россия, Забайкальский край, Борзинский район, село Усть-Озёрная	0101000020E61000003BAA9A20EA455D40080264E8D8594940
33817	5	48	1136	60062	\N	\N	49.897587856478196	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Соловьевское"", помещение МОУ: Соловьевская СОШ"	Россия, Забайкальский край, Борзинский район, село Соловьёвск	0101000020E61000006F10AD156DED5C401AA4E029E4F24840
33816	5	48	1136	51759	\N	\N	50.486713612044298	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Приозерское"", помещение МОУ: Приозернинская ООШ"	Россия, Забайкальский край, Борзинский район, село Приозерное	0101000020E6100000404D2D5BEB115D40AF40F4A44C3E4940
33815	5	48	1136	60091	\N	\N	50.724641357889197	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Переднебыркинское"", помещение МОУ: Перебнебыркинская СОШ"	Россия, Забайкальский край, Борзинский район, село Передняя Бырка	0101000020E6100000F92EA52E19325D409D2B4A09C15C4940
33812	5	48	1136	10707	\N	\N	50.885500999999998	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Курунзулайское"", село Олдонда, помещение МОУ: Олдондинская НОШ"		0101000020E610000012C138B8743C5D40A3C9C51858714940
33814	5	48	1136	51050	\N	\N	50.296473943313003	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Новоборзинское"", помещение администрации СП ""Новоборзинское"""		0101000020E6100000A5BBEB6CC8245D40A20E2BDCF2254940
33811	5	48	1136	51685	27509	\N	50.931476508779198	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Курунзулайское"", Матафонова, 26"	Россия, Забайкальский край, Борзинский район, село Курунзулай	0101000020E6100000430070ECD9475D40F4FC69A33A774940
33810	5	48	1136	50772	23569	\N	50.552027350238298	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Кондуйское"", Центральная, 43 А"	Россия, Забайкальский край, Борзинский район, село Кондуй	0101000020E6100000876F61DD785E5D4027C11BD2A8464940
33813	5	48	1136	50701	23421	\N	50.383263884708597	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Ключевское"", Партизанская, 8"	Россия, Забайкальский край, Борзинский район, село Ключевское	0101000020E6100000AB21718FA5365D40F8DD74CB0E314940
15273	5	47	\N	5685	70060	\N	52.483826000000001	Алтайский край, г. Алейск, Ветеранов, 8		0101000020E61000004582A966D6B154402D7AA702EE3D4A40
33846	5	48	1136	50776	\N	\N	50.379970886244699	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", помещение МОУ: СОШ № 26"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E6100000D61D8B6D52225D40D636C5E3A2304940
33844	5	48	1136	50776	\N	\N	50.379970892944399	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", помещение клуба ОДОРА"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E610000012A452EC68225D40D636C5E3A2304940
33841	5	48	1136	50776	73617	\N	50.379678153500102	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Шамсутдинова, 13"		0101000020E6100000C2C073EFE1215D405E81E84999304940
33836	5	48	1136	50776	24042	\N	50.387141775378701	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Советская, 52"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E610000036E84B6F7F225D403A747ADE8D314940
33842	5	48	1136	50776	67173	\N	50.386535130273003	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Свердлова, 10"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E6100000514A0856D5205D4033E197FA79314940
33835	5	48	1136	50776	73666	\N	50.382556450807897	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Савватеевская, 31"		0101000020E61000004C6F7F2E1A225D40BD715298F7304940
33839	5	48	1136	50776	28279	\N	50.3895074521228	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Оздоровительная, 2"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E61000009E7C7A6CCB215D401348895DDB314940
33837	5	48	1136	50776	24063	\N	50.381727127327103	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Ленина, 26"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E6100000D847A7AE7C215D4006802A6EDC304940
33840	5	48	1136	50776	24688	\N	50.381239296770502	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Лазо, помещение, 33"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E610000012A452EC68225D40D97A8670CC304940
33834	5	48	1136	50776	24688	\N	50.3865564590349	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Лазо, 29"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E610000060CC96AC8A225D404A09C1AA7A314940
33831	5	48	1136	50776	73631	\N	50.3946042397585	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Коновалова, 21"		0101000020E6100000F2B391EBA6205D40766F456282324940
33833	5	48	1136	50776	67170	\N	50.392653409939903	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Карла Маркса, 118"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E6100000B24813EF00215D4091D6187442324940
33832	5	48	1136	50776	67170	\N	50.392625000000002	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Карла Маркса, 204"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E61000004E417E3672215D40C74B378941324940
33838	5	48	1136	50776	27713	\N	50.392625000000002	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Журавлева, 6 А"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E61000004E417E3672215D40C74B378941324940
33843	5	48	1136	50776	34010	\N	50.385629667203602	"Забайкальский край, муниципальный район ""Борзинский район"", городское поселение ""Борзинское"", Дзержинсколго, 31"	Россия, Забайкальский край, Борзинский район, Борзя	0101000020E610000088F546AD30225D40A12DE7525C314940
33809	5	48	1136	60124	73841	\N	50.720247000000001	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Биликтуйское"", Погодаева, 16"	Россия, Забайкальский край, Борзинский район, село Биликтуй	0101000020E61000001155F833BC3A5D406405BF0D315C4940
33808	5	48	1136	60196	74019	\N	50.760857604668601	"Забайкальский край, муниципальный район ""Борзинский район"", сельское поселение ""Акурайское"", Центральная, 2"	Россия, Забайкальский край, Борзинский район, село Акурай	0101000020E61000000F9A5DF7564A5D40327381CB63614940
33904	5	48	1099	51060	73718	\N	51.422972105647702	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Ундино-Посельское"", Советская, 25"		0101000020E61000008A592F86720F5D40D68F4DF223B64940
33916	5	48	1099	60087	73765	\N	51.711400178455698	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Ундинское"", Энэргетиков, 1""А"""	Россия, Забайкальский край, Балейский район, село Унда	0101000020E6100000C8B60C384B3B5D40EC2FBB270FDB4940
33913	5	48	1099	51051	73924	\N	51.650411121710597	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Подойницынское"", Школьная, 9"	Россия, Забайкальский край, Балейский район, село Подойницыно	0101000020E61000005FECBDF8A2325D40B5FAEAAA40D34940
33915	5	48	1099	51051	28077	\N	51.6535461539764	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Подойницынское"", Центральная, 20"	Россия, Забайкальский край, Балейский район, село Подойницыно	0101000020E61000005ED72FD80D335D403F373465A7D34940
33911	5	48	1099	51051	24619	\N	51.650781634984803	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Подойницынское"", Трактовая, 22"	Россия, Забайкальский край, Балейский район, село Подойницыно	0101000020E6100000AF7C96E7C1325D40A96917D34CD34940
33912	5	48	1099	51051	73960	\N	51.651602843395104	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Подойницынское"", Советская, 15"	Россия, Забайкальский край, Балейский район, село Подойницыно	0101000020E6100000821C9430D3325D40DD7C23BA67D34940
33914	5	48	1099	51051	73885	\N	51.650894363018502	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Подойницынское"", Кирова, 11""А"""	Россия, Забайкальский край, Балейский район, село Подойницыно	0101000020E610000061545227A0325D40D1949D7E50D34940
33908	5	48	1099	50880	27332	\N	51.5416112818153	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнекокуйское"", Школьный переулок, 3"		0101000020E61000007714E7A8A3275D40B2135E8253C54940
33910	5	48	1099	50880	74027	\N	51.5426460465034	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнекокуйское"", Первомайская, 26"	Россия, Забайкальский край, Балейский район, село Нижний Кокуй	0101000020E61000003FC6DCB584275D4011A7936C75C54940
33909	5	48	1099	50880	23963	\N	51.542051365098303	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнекокуйское"", Кохозная, 1""А"""	Россия, Забайкальский край, Балейский район, село Нижний Кокуй	0101000020E61000005000C5C892275D40CEE15AED61C54940
33923	5	48	1099	60158	73936	\N	51.610745000000001	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнеильдиканское"", Центральная, 17"	Россия, Забайкальский край, Балейский район, село Нижний Ильдикан	0101000020E61000001DAB949EE9495D40079964E42CCE4940
33920	5	48	1099	60158	73936	\N	51.610745000000001	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнеильдиканское"", Центральная, 11"	Россия, Забайкальский край, Балейский район, село Нижний Ильдикан	0101000020E61000001DAB949EE9495D40079964E42CCE4940
33922	5	48	1099	60158	74033	\N	51.613256333045697	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнеильдиканское"", Специалистов, 1"	Россия, Забайкальский край, Балейский район, село Нижний Ильдикан	0101000020E6100000CF4E0647C9495D40B309302C7FCE4940
33921	5	48	1099	60158	73931	\N	51.606396947027498	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнеильдиканское"", Кишиневская, 9"	Россия, Забайкальский край, Балейский район, село Нижний Ильдикан	0101000020E610000090F7AA95094A5D403EB2B96A9ECD4940
33926	5	48	1099	51520	74016	\N	51.195366999999997	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнегирюнинское"", Трактовая, 20""А"""	Россия, Забайкальский край, Балейский район, село Нижнее Гирюнино	0101000020E6100000CD8FBFB4A83E5D40DBDB2DC901994940
33924	5	48	1099	51520	27179	\N	51.194348159751499	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Нижнегирюнинское"", Заречная, 6"	Россия, Забайкальский край, Балейский район, село Нижнее Гирюнино	0101000020E610000030134548DD3E5D4081053065E0984940
33907	5	48	1099	50995	24240	\N	51.472097256509201	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Матусовское"", Центральная, 7""А"""	Россия, Забайкальский край, Балейский район, село Матусово	0101000020E61000001B48179B56165D4015C5ABAC6DBC4940
33905	5	48	1099	50995	24240	\N	51.472992701862204	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Матусовское"", Центральная, 24"	Россия, Забайкальский край, Балейский район, село Матусово	0101000020E6100000BB44F5D6C0165D40541EDD088BBC4940
33906	5	48	1099	50995	27623	\N	51.471884939691101	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Матусовское"", Кохозная, 1"	Россия, Забайкальский край, Балейский район, село Матусово	0101000020E6100000CF4E0647C9165D408A3C49BA66BC4940
33917	5	48	1099	51432	27020	\N	51.772777285258002	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Казаковское"", Котовского, 2-1"	Россия, Забайкальский край, Балейский район, село Казаковский Промысел	0101000020E610000074ED0BE885415D40ED0C535BEAE24940
33919	5	48	1099	60172	74038	\N	51.768149999999999	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Жидкинское"", Новая, 6""А"""	Россия, Забайкальский край, Балейский район, село Жидка	0101000020E61000001CEBE2361A4E5D4011363CBD52E24940
33918	5	48	1099	60172	73958	\N	51.7677244137505	"Забайкальский край, муниципальный район ""Балейский район"", сельское поселение ""Жидкинское"", Клубная, 4""А"""	Россия, Забайкальский край, Балейский район, село Жидка	0101000020E610000043ACFE08C34D5D405A2DB0C744E24940
33806	5	48	1099	50945	28576	\N	51.578109949868697	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Чернышевского, Помещение поликлиники мкр. Отмахово"	Россия, Забайкальский край, Балейский район, Балей	0101000020E6100000AF5B04C6FA285D40CBBE2B82FFC94940
16566	5	47	\N	59374	70572	\N	51.65578	Алтайский край, Солонешенский район, с. Солонешное, Партизанская, 86		0101000020E6100000E84F1BD5E913554079AF5A99F0D34940
33805	5	48	1099	50945	28576	\N	51.5796667406022	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Чернышевского, Помещение школы №6"	Россия, Забайкальский край, Балейский район, Балей	0101000020E6100000103B53E8BC285D4004C93B8732CA4940
33802	5	48	1099	50945	24119	\N	51.579393405243501	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Советская, 24"	Россия, Забайкальский край, Балейский район, Балей	0101000020E6100000D66F26A60B295D400344C18C29CA4940
33793	5	48	1099	50945	24232	\N	51.578109953132703	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Пролетарская, 8"	Россия, Забайкальский край, Балейский район, Балей	0101000020E61000005D4E098849295D40CBBE2B82FFC94940
33807	5	48	1099	50945	73833	\N	51.579987596813297	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Новоколхозная, Помещение медпункта Подхоза"		0101000020E610000084622B685A295D404609FA0B3DCA4940
33796	5	48	1099	50945	28495	\N	51.579773692925599	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Матросова, 48"	Россия, Забайкальский край, Балейский район, Балей	0101000020E6100000D66F26A60B295D401A89D00836CA4940
33800	5	48	1099	50945	27209	\N	51.574354422038397	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Ленина, 6"	Россия, Забайкальский край, Балейский район, Балей	0101000020E6100000FD8348861C295D40D4298F6E84C94940
33797	5	48	1099	50945	27209	\N	51.576565013163403	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Ленина, 26"	Россия, Забайкальский край, Балейский район, Балей	0101000020E61000008847E2E5E9285D405682C5E1CCC94940
33799	5	48	1099	50945	27417	\N	51.575115078971102	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Кирова, 22"	Россия, Забайкальский край, Балейский район, Балей	0101000020E6100000E9263108AC285D4032384A5E9DC94940
33794	5	48	1099	50945	73686	\N	51.571033999999997	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Дарасунская, 7"	Россия, Забайкальский край, Балейский район, Балей	0101000020E610000091D26C1E87295D40B87361A417C94940
33801	5	48	1099	50945	73807	\N	51.571033999999997	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Ведерникова, 10"	Россия, Забайкальский край, Балейский район, Балей	0101000020E610000091D26C1E87295D40B87361A417C94940
33803	5	48	1099	50945	74007	\N	51.5763510930827	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", Блюхера, 27"		0101000020E61000005D4E098849295D402A029CDEC5C94940
33795	5	48	1099	50945	67878	\N	51.571033999999997	"Забайкальский край, муниципальный район ""Балейский район"", городское поселение ""Город Балей"", 5-ое Декабря, Помещение школы №14"		0101000020E610000091D26C1E87295D40B87361A417C94940
94929	5	48	1302	49682	73946	\N	50.932136	"""Забайкальский край, муниципальный район """"Александрово-Заводский район"""", сельское поселение """"Шаранчинское"""", с.Шаранча, Новая, 11/2"""		0101000020E6100000554FE61F7D575D404EB6813B50774940
33884	5	48	1302	49682	28069	\N	50.935022989441698	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Шаранчинское"", Молодежная, 5"	Россия, Забайкальский край, Александрово-Заводский район, село Шаранча	0101000020E61000007DCA3159DC575D4000016BD5AE774940
33900	5	48	1302	51433	73948	\N	50.765079333485602	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Чиндагатайское"", Школьная, 10"	Россия, Забайкальский край, Александрово-Заводский район, село Чиндагатай	0101000020E6100000C79BFC169D8F5D409EEDD11BEE614940
33902	5	48	1302	51433	27022	\N	50.767095596468103	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Чиндагатайское"", Центральная, 9"	Россия, Забайкальский край, Александрово-Заводский район, село Чиндагатай	0101000020E61000001BF4A5B73F8F5D403B72A43330624940
33898	5	48	1302	51579	73839	\N	50.703248446631299	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Савво-Борзинское"", Школьная, 14"		0101000020E6100000E99E758D96965D401C7DCC07045A4940
33895	5	48	1302	50980	24199	\N	51.0612909882529	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Онон-Борзинское"", Лесная, 4"	Россия, Забайкальский край, Александрово-Заводский район, село Онон-Борзя	0101000020E610000029B3412619555D4002452C62D8874940
33899	5	48	1302	60071	73940	\N	51.055048999999997	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Ново-Акатуйское"", Центральная, 36"	Россия, Забайкальский край, Александрово-Заводский район, село Новый Акатуй	0101000020E6100000C2C1DEC490715D40B8567BD80B874940
33877	5	48	1302	60071	73940	\N	51.055048999999997	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Ново-Акатуйское"", Центральная, 10"	Россия, Забайкальский край, Александрово-Заводский район, село Новый Акатуй	0101000020E6100000C2C1DEC490715D40B8567BD80B874940
74778	3	32	683	45873	58511	\N	57.527634999999997	дер.Красные Горки, Советской Армии, 26		0101000020E6100000BFD7101C97E93D40CB9C2E8B89C34C40
33894	5	48	1302	60071	73731	\N	51.055048999999997	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Ново-Акатуйское"", Лунина, 15"	Россия, Забайкальский край, Александрово-Заводский район, село Новый Акатуй	0101000020E6100000C2C1DEC490715D40B8567BD80B874940
33893	5	48	1302	60135	73879	\N	51.012484494652199	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Николаевское"", Центральная, 37"	Россия, Забайкальский край, Александрово-Заводский район, село Николаевка	0101000020E61000005FD4EE57016A5D4094DC611399814940
33890	5	48	1302	60130	73864	\N	50.856610568132503	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Маньковское"", Кооперативная, 17"	Россия, Забайкальский край, Александрово-Заводский район, село Маньково	0101000020E6100000EE7893DFA26D5D406A32E36DA56D4940
33889	5	48	1302	60125	73955	\N	50.657728272436501	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Манкечурское"", Центральная, 16"	Россия, Забайкальский край, Александрово-Заводский район, село Манкечур	0101000020E61000006DC669882A7A5D40EDD45C6E30544940
33897	5	48	1302	60125	73853	\N	50.654750999999997	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Манкечурское"", Садовая, 5"	Россия, Забайкальский край, Александрово-Заводский район, село Манкечур	0101000020E61000009CC1DF2F667A5D40FB027AE1CE534940
94928	5	48	1302	49681	24303	\N	50.852519999999998	"""Забайкальский край, муниципальный район """"Александрово-Заводский район"""", сельское поселение """"Шаранчинское"""", с.Кутугай, Центральная, 3"""		0101000020E6100000AF42CA4FAA575D40CC9717601F6D4940
33886	5	48	1302	51738	27771	\N	51.096170045900301	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Кузнецовское"", Школьная, 23"	Россия, Забайкальский край, Александрово-Заводский район, село Кузнецово	0101000020E6100000DE73603942945D409C6D6E4C4F8C4940
94926	5	48	1302	50677	73826	\N	51.052287540729402	"""Забайкальский край, муниципальный район """"Александрово-Заводский район"""", сельское поселение """"Бохтинское"""", с Кокуй2 Молодежная, 13-в """		0101000020E61000001B12F758FA7F5D4093FC885FB1864940
33888	5	48	1302	60171	73956	\N	51.1801891396073	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Первококуйское"", Центральная, 16"	Россия, Забайкальский край, Александрово-Заводский район, село Кокуй 1-й	0101000020E61000002463B5F97F965D40AA0CE36E10974940
94927	5	48	1302	51813	28123	\N	50.994234181227803	"""Забайкальский край, муниципальный район """"Александрово-Заводский район"""", сельское поселение """"Онон-Борзинское"""",  с.Клин ул, Нагорная 2"""	Россия, Забайкальский край, Александрово-Заводский район, село Клин	0101000020E61000001BD99596915D5D401F49490F437F4940
33879	5	48	1302	51562	27245	\N	50.658531534034097	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Бутунтайское"", Школьная, 1"	Россия, Забайкальский край, Александрово-Заводский район, село Бутунтай	0101000020E610000036E50AEF72875D404BAFCDC64A544940
33891	5	48	1302	51562	73950	\N	50.656481999999997	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Бутунтайское"", Молодежная, 21"	Россия, Забайкальский край, Александрово-Заводский район, село Бутунтай	0101000020E610000066F7E461A1875D40D234289A07544940
33881	5	48	1302	51727	27708	\N	51.064163539448003	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Бохтинское"", Центральная, 31"	Россия, Забайкальский край, Александрово-Заводский район, село Бохто	0101000020E6100000EEB5A0F7C68B5D404FCAA48636884940
33878	5	48	1302	51727	27706	\N	51.059884695758399	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Бохтинское"", Нагорная, 17"	Россия, Забайкальский край, Александрово-Заводский район, село Бохто	0101000020E610000079793A57948B5D40AF42CA4FAA874940
33903	5	48	1302	51712	73860	\N	50.932660653193402	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Чиндагатайское"", Школьная, 1"	Россия, Забайкальский край, Александрово-Заводский район, село Александровский Завод	0101000020E61000008D093197547C5D4099A0866F61774940
33876	5	48	1302	51712	67954	\N	50.928321396700703	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Александрово-Заводское"", Советская, 35"	Россия, Забайкальский край, Александрово-Заводский район, село Александровский Завод	0101000020E61000002B84D558C27B5D405298F738D3764940
33883	5	48	1302	51712	27617	\N	50.925645285744601	"Забайкальский край, муниципальный район ""Александрово-Заводский район"", сельское поселение ""Александрово-Заводское"", Нагорная, 3"	Россия, Забайкальский край, Александрово-Заводский район, село Александровский Завод	0101000020E6100000DD5B9198A07B5D405C5A0D897B764940
33575	5	48	1888	60164	73938	\N	50.400233	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Усть-Илинское"", Школьная, 37-а"	Россия, Забайкальский край, Акшинский район, село Усть-Иля	0101000020E61000005E807D74EA6D5C40D6E3BED53A334940
33574	5	48	1888	60104	73799	\N	50.297923605323099	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Урейское"", Партизанская, 98"	Россия, Забайкальский край, Акшинский район, село Урейск	0101000020E6100000F241CF66D54D5C40C558A65F22264940
33573	5	48	1888	51839	28269	\N	50.4044594625786	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Улачинское"", Центральная, 7"	Россия, Забайкальский край, Акшинский район, село Улача	0101000020E610000091B8C7D287515C4054C90050C5334940
33572	5	48	1888	51021	24393	\N	50.102979738384001	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Убур-Тохторское"", Мира, 20"	Россия, Забайкальский край, Акшинский район, село Убур-Тохтор	0101000020E6100000252026E142685C403012DA722E0D4940
33571	5	48	1888	60116	73823	\N	50.079224000000004	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Тохторское"", Лесная, 5"	Россия, Забайкальский край, Акшинский район, село Тохтор	0101000020E610000076E3DD91B1565C4077871403240A4940
33570	5	48	1888	30695	73847	\N	50.466796000000002	"Забайкальский край, муниципальный район ""Акшинский район"",  сельское поселение ""Улачинское"", с. Такеча, Школьная, 1"		0101000020E6100000373811FDDA525C40AAF3A8F8BF3B4940
33569	5	48	1888	60182	73980	\N	50.170706141604903	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Оройское"", Молодёжная, 13"	Россия, Забайкальский край, Акшинский район, село Орой	0101000020E6100000C9C6832D766F5C40919DB7B1D9154940
33568	5	48	1888	51018	24384	\N	50.314606485344399	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Новокургатайское"", Центральная, 120-А"	Россия, Забайкальский край, Акшинский район, село Новокургатай	0101000020E61000002444F982165E5C400C90680245284940
33567	5	48	1888	30530	73849	\N	50.408667000000001	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Новокурагатайское"",с. Новоказачинск, им. братьев Макаровых, 40"		0101000020E61000009DD497A59D625C402BFA43334F344940
33566	5	48	1888	60089	73768	\N	50.087326781760297	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Нарасунское"", Ленина, 61"	Россия, Забайкальский край, Акшинский район, село Нарасун	0101000020E6100000535E2BA1BB3E5C406687F8872D0B4940
33565	5	48	1888	51830	28234	\N	50.349334354184798	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Могойтуйское"", Школьная, 6"	Россия, Забайкальский край, Акшинский район, село Могойтуй	0101000020E61000008DD13AAA9A755C40C0B0FCF9B62C4940
33564	5	48	1888	51644	27404	\N	50.119615394472497	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Курулгинское"", Центральная, 1"	Россия, Забайкальский край, Акшинский район, село Курулга	0101000020E6100000D9EBDD1FEF305C40378E588B4F0F4940
33563	5	48	1888	30347	73834	\N	50.314863000000003	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Урейское"", с. Дорожное, Центральная, 8"		0101000020E6100000D2E28C614E4B5C4038DC476E4D284940
33562	5	48	1888	51013	24359	\N	50.152138000000001	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Бытэвское"", Школьная, 3"	Россия, Забайкальский край, Акшинский район, село Бытэв	0101000020E61000001EC4CE143A485C404B3D0B4279134940
33561	5	48	1888	51637	67773	\N	50.277867032511097	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Акшинское"", Партизанская, 22"	Россия, Забайкальский край, Акшинский район, село Акша	0101000020E61000002B685A6265525C409ED1562591234940
33560	5	48	1888	51637	27393	\N	50.278013669441997	"Забайкальский край, муниципальный район ""Акшинский район"", сельское поселение ""Акшинское"", Карла Маркса, 51"	Россия, Забайкальский край, Акшинский район, село Акша	0101000020E61000003FFED2A23E525C4042EA76F695234940
34325	5	48	187	60157	\N	\N	51.1400584959733	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Южный Аргалей"", здание сельского Дома культуры"	Россия, Забайкальский край, Агинский район, село Южный Аргалей	0101000020E6100000583CF54883905C4087C5A86BED914940
34324	5	48	187	51019	24387	\N	51.223398488054698	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Челутай"", Центральная, 15"	Россия, Забайкальский край, Агинский район, село Челутай	0101000020E6100000151F9F909D975C40F4FE3F4E989C4940
34330	5	48	187	60033	\N	\N	50.901215779583602	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Цокто-Хангил"", здание сельского Дома культуры"	Россия, Забайкальский край, Агинский район, село Цокто-Хангил	0101000020E6100000FA7FD59123A85C40E350BF0B5B734940
34326	5	48	187	60102	73792	\N	51.095923670366702	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Хойто-Ага"", Ленина, 18"	Россия, Забайкальский край, Агинский район, село Хойто-Ага	0101000020E61000000A4D124BCA855C406473D53C478C4940
34329	5	48	187	50706	\N	\N	51.007448573351098	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Урда-Ага"", здание сельского клуба"	Россия, Забайкальский край, Агинский район, село Урда-Ага	0101000020E61000001349F4328A925C40A7B1BD16F4804940
16567	5	47	\N	59374	70023	\N	51.65578	Алтайский край, Солонешенский район, с. Солонешное, Красноармейская, 17		0101000020E6100000E84F1BD5E913554079AF5A99F0D34940
34328	5	48	187	50706	27754	\N	51.0083872008057	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Урда-Ага"", Ленина, 2"	Россия, Забайкальский край, Агинский район, село Урда-Ага	0101000020E61000004FCFBBB1A0925C40145B41D312814940
34331	5	48	187	60099	73788	\N	50.760157862398501	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Судунтуй"", Школьная, 1"	Россия, Забайкальский край, Агинский район, село Судунтуй	0101000020E61000004B04AA7F109E5C4079E57ADB4C614940
34327	5	48	187	60111	73818	\N	51.029046572457801	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Сахюрта"", Ленина, 18"	Россия, Забайкальский край, Агинский район, село Сахюрта (Дунда-Ага)	0101000020E6100000FA0D130D528E5C400186E5CFB7834940
34335	5	48	187	51636	\N	\N	51.037585	"Забайкальский край, муниципальный район ""Агинский район"", Городское поселение ""Орловский"", здание конторы агрокооператива ""Хилинский"""	Россия, Забайкальский край, Агинский район, поселок городского типа Орловский	0101000020E610000076A6D0798DB65C40FBE8D495CF844940
34334	5	48	187	51636	\N	\N	51.041033719580199	"Забайкальский край, муниципальный район ""Агинский район"", Городское поселение ""Орловский"", здание Дома культуры"	Россия, Забайкальский край, Агинский район, поселок городского типа Орловский	0101000020E6100000C11A67D311B65C401503249A40854940
34336	5	48	187	60127	\N	\N	51.0373479995203	"Забайкальский край, муниципальный район ""Агинский район"", Городское поселение ""Орловский"", общежитие акционерного общества ""Забота"""	Россия, Забайкальский край, Агинский район, поселок городского типа Орловский	0101000020E6100000FF3C0D1824B65C401749BBD1C7844940
34337	5	48	187	51846	\N	\N	51.0601128826207	"Забайкальский край, муниципальный район ""Агинский район"", Городское поселение ""Новоорловск"", здание молодежного центра"	Россия, Забайкальский край, Агинский район, поселок городского типа Новоорловск	0101000020E610000058AD4CF8A5AE5C40408864C8B1874940
34277	5	48	187	60108	73813	\N	50.578792170568597	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Кункур"", Школьная, 14"	Россия, Забайкальский край, Агинский район, село Кункур	0101000020E610000097715303CDCA5C40DD9733DB154A4940
34332	5	48	187	60112	\N	\N	50.945480000000003	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Гунэй"", здание администрации сельского поселения ""Гунэй"""		0101000020E6100000EE5BAD1397A55C40D482177D05794940
34333	5	48	187	60154	\N	\N	50.5562701237724	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Будалан"", здание сельского Дома культуры"	Россия, Забайкальский край, Агинский район, село Будулан	0101000020E6100000616BB6F292BA5C407ADFF8DA33474940
34323	5	48	187	59488	73602	\N	51.082459999999998	"Забайкальский край, муниципальный район ""Агинский район"", Сельское поселение ""Амитхаша"", пер. Клубный, 1"		0101000020E6100000EC4FE273279E5C40349D9D0C8E8A4940
34118	5	48	187	50842	24047	\N	51.101787978804801	"Забайкальский край, Городской округ ""поселок Агинское"", Ранжурова, 25Е"		0101000020E6100000EEB3CA4C69A25C400890A163078D4940
34005	5	48	187	50842	67380	\N	51.106268999999998	"Забайкальский край, Городской округ ""поселок Агинское"", Ленина, 146"	Россия, Забайкальский край, Агинский район, поселок городского типа Агинское	0101000020E6100000FFCBB56801A25C4010CAFB389A8D4940
33981	5	48	187	50842	23842	\N	51.106268999999998	"Забайкальский край, Городской округ ""поселок Агинское"", Комсомольская, 59"	Россия, Забайкальский край, Агинский район, поселок городского типа Агинское	0101000020E6100000FFCBB56801A25C4010CAFB389A8D4940
33969	5	48	187	60050	73621	\N	51.103040056479799	"Забайкальский край, Городской округ ""поселок Агинское"", Комсомольская, 17"		0101000020E6100000A9F8BF232AA25C4005172B6A308D4940
15442	5	47	\N	59381	70092	\N	53.198430000000002	Алтайский край, город Барнаул, Центральный район, пос.Бельмесево, ул.Отечественная, 22		0101000020E610000004029D499BEC5440CC457C2766994A40
15663	5	47	\N	1063	69841	\N	52.925975999999999	Алтайский край, город Яровое, квартал В, д.19		0101000020E61000002104E44BA8A45340C170AE6186764A40
15660	5	47	\N	1063	70028	\N	52.925975999999999	Алтайский край, город Яровое, квартал Б, дом 31		0101000020E61000002104E44BA8A45340C170AE6186764A40
15658	5	47	\N	1063	69997	\N	52.925975999999999	Алтайский край, город Яровое, квартал А, дом 21		0101000020E61000002104E44BA8A45340C170AE6186764A40
15659	5	47	\N	1063	70128	\N	52.925975999999999	Алтайский край, город Яровое, улица Ленина, дом 9		0101000020E61000002104E44BA8A45340C170AE6186764A40
15661	5	47	\N	1063	69695	\N	52.925975999999999	Алтайский край, город Яровое, улица Гагарина, дом 10		0101000020E61000002104E44BA8A45340C170AE6186764A40
15662	5	47	\N	1063	69714	\N	52.928281109045599	Алтайский край, город Яровое, улица 40 лет Октября, дом 1		0101000020E61000002AA913D044A45340C43F6CE9D1764A40
16795	5	47	\N	59358	69763	\N	51.359346000000002	Алтайский край, Угловский район, с.Угловское, Ленина, 34		0101000020E610000095287B4B390C544066F9BA0CFFAD4940
16726	5	47	\N	59359	69775	\N	52.979849000000002	Алтайский край, Троицкий район, с. Троицкое, ул. Рабочая, 16		0101000020E61000001D76DF313C2B5540580229B16B7D4A40
16665	5	47	\N	59357	69782	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Юбилейная, д.19		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16664	5	47	\N	59357	70064	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Мехзаводская, д.23		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16656	5	47	\N	59357	69756	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Кирова, д.73		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16508	5	47	\N	902	70930	\N	53.001614095044999	Алтайский край, г.Славгород, с.Пановка, Новая, 10	Россия, Алтайский край, город Славгород	0101000020E61000006BD619DF17A953409D9B36E334804A40
15652	5	47	\N	902	70097	\N	53.003270999999998	Алтайский край, г.Славгород,  ул. Ленина, д. 243		0101000020E6100000B796C9703CA953403A03232F6B804A40
16507	5	47	\N	902	70241	\N	53.001578396294398	Алтайский край, г.Славгород, с.Знаменка, Ленина, 31		0101000020E6100000EB39E97DE3A85340513239B533804A40
16987	5	47	\N	902	70040	\N	53.003270999999998	Алтайский край, г.Славгород, Космонавтов, 156		0101000020E6100000B796C9703CA953403A03232F6B804A40
16510	5	47	\N	902	70550	\N	53.141913919533302	Алтайский край, г.Славгород, с.Нововознесеновка, Кооперативный, 9		0101000020E6100000938B31B08ECB53401A6CEA3C2A924A40
16515	5	47	\N	902	69671	\N	53.003270999999998	Алтайский край, г.Славгород, с.Славгородское, Карла Маркса, 285		0101000020E6100000B796C9703CA953403A03232F6B804A40
15651	5	47	\N	902	69671	\N	53.003270999999998	Алтайский край, г.Славгород, Карла Маркса, 169		0101000020E6100000B796C9703CA953403A03232F6B804A40
15648	5	47	\N	902	69691	\N	53.003270999999998	Алтайский край, г.Славгород, 2-ая вокзальная, 27		0101000020E6100000B796C9703CA953403A03232F6B804A40
16991	5	47	\N	576	69811	\N	51.516998000000001	Алтайский край, г.Рубцовск, тр.Новоегорьевский, 4		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15623	5	47	\N	576	69680	\N	51.519568446200701	Алтайский край, г.Рубцовск, пр.Ленина, 36	Россия, Алтайский край, городской округ Рубцовск	0101000020E6100000E012807F4A4C54402906483481C24940
15607	5	47	\N	576	69680	\N	51.516783797380697	Алтайский край, г.Рубцовск, пр.Ленина, 187		0101000020E6100000B8E9CF7EA44C54404C8C65FA25C24940
15611	5	47	\N	576	69989	\N	51.515498669994301	Алтайский край, г.Рубцовск, пр.Рубцовский, 62	Россия, Алтайский край, город Рубцовск	0101000020E6100000B8E9CF7EA44C5440730F09DFFBC14940
15625	5	47	\N	576	69672	\N	51.516998000000001	Алтайский край, г.Рубцовск, пр.Ленина, 7		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15618	5	47	\N	576	69672	\N	51.516998000000001	Алтайский край, г.Рубцовск, пр.Ленина, 48		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15613	5	47	\N	576	69672	\N	51.516998000000001	Алтайский край, г.Рубцовск, пр.Ленина, 171А		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15612	5	47	\N	576	69672	\N	51.516998000000001	Алтайский край, г.Рубцовск, пр.Ленина, 136		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15606	5	47	\N	576	69672	\N	51.516998000000001	Адтайский край, г.Рубцовск, пр.Ленина, 190		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15609	5	47	\N	576	70089	\N	51.516998000000001	Алтайский край, г.Рубцовск, пер.Пионерский, 31		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15638	5	47	\N	576	69865	\N	51.516998000000001	Алтайский край, г.Рубцовск, пер.Станционный, 42В		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15633	5	47	\N	576	69681	\N	51.514856040335403	Алтайский край, г.Рубцовск, ул.Федоренко, 17	Россия, Алтайский край, город Рубцовск	0101000020E6100000A647533D994C54401F1329CDE6C14940
15634	5	47	\N	576	69688	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Тракторная, 158		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
16992	5	47	\N	576	69994	\N	51.518711681587497	Алтайский край, г.Рубцовск, ул.Степана Разина, 196		0101000020E6100000B8E9CF7EA44C54407905A22765C24940
15640	5	47	\N	576	69994	\N	51.516569594582101	Алтайский край, г.Рубцовск, ул.Степана Разина, 200		0101000020E6100000CD5B751DAA4C5440200C3CF71EC24940
15604	5	47	\N	576	69986	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Сельмашская, 38А		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15631	5	47	\N	576	69685	\N	51.517747802031998	Алтайский край, г.Рубцовск, ул.Светлова, 90		0101000020E6100000F46F97FDBA4C5440E2C8039145C24940
15643	5	47	\N	576	69683	\N	51.508174829661897	Алтайский край, г.Рубцовск, ул.Рихарда Зорге, 157	Россия, Алтайский край, городской округ Рубцовск	0101000020E6100000EED0B018754B544089D2DEE00BC14940
15639	5	47	\N	576	69683	\N	51.515605774051402	Алтайский край, г.Рубцовск, ул.Рихарда Зорге, 121		0101000020E6100000A647533D994C544089CF9D60FFC14940
15641	5	47	\N	576	69871	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Рихарада Зорге, 121		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15642	5	47	\N	576	69995	\N	51.516355390770997	Алтайский край, г.Рубцовск, ул.Районная, 14		0101000020E6100000BBB9F8DB9E4C54402310AFEB17C24940
15608	5	47	\N	576	69807	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Пролетарская, 284А		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15602	5	47	\N	576	69807	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Пролетарская, 412А		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15601	5	47	\N	576	69807	\N	51.516997999166598	Алтайский край, г.Рубцовск, ул.Пролетарская, 412		0101000020E6100000E2CD1ABCAF4C5440780C8FFD2CC24940
15603	5	47	\N	576	69821	\N	51.517640703037898	Алтайский край, г.Рубцовск, ул.Осипенко, 182В		0101000020E6100000E2CD1ABCAF4C5440CC086F0F42C24940
16990	5	47	\N	576	69833	\N	51.5182832932054	Алтайский край, г.Рубцовск, ул.Октябрьская, 3А	Россия, Алтайский край, город Рубцовск	0101000020E6100000E2CD1ABCAF4C54405089EB1857C24940
15628	5	47	\N	576	69833	\N	51.515284356526202	Алтайский край, г.Рубцовск, ул.Октябрьская, 68		0101000020E6100000A647533D994C544077137CD3F4C14940
15637	5	47	\N	576	70131	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Одесская, 6		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15605	5	47	\N	576	70120	\N	51.516998000000001	Алтайский край. г.Рубцовск, ул.Красная, 99		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15635	5	47	\N	576	69686	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Кондратюка, 4		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15629	5	47	\N	576	69676	\N	51.5199968224318	Алтайский край, г.Рубцовск, ул.Комсомольская, 21	Россия, Алтайский край, город Рубцовск	0101000020E61000000612143FC64C54405182FE428FC24940
15627	5	47	\N	576	69676	\N	51.5167839019716	Алтайский край, г.Рубцовск, ул.Комсомольская, 97		0101000020E6100000CD5B751DAA4C54404C8C65FA25C24940
15626	5	47	\N	576	69676	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Комсомольская, 99		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15624	5	47	\N	576	69676	\N	51.516997999166598	Алтайский край, г.Рубцовск, ул.Комсомольская, 134		0101000020E6100000CD5B751DAA4C5440780C8FFD2CC24940
15619	5	47	\N	576	69676	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Комсомольская, 158		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15616	5	47	\N	576	69676	\N	51.5191399613337	Алтайский край, г.Рубцовск, ул.Комсомольская, 204	Россия, Алтайский край, городской округ Рубцовск	0101000020E6100000BCCE86FC334C5440D105F52D73C24940
15615	5	47	\N	576	69991	\N	51.514427615499798	Алтайский край, г.Рубцовск, ул.Карла Маркса, 141		0101000020E6100000CD5B751DAA4C5440C712D6C6D8C14940
15621	5	47	\N	576	69863	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Дзержинского, 20		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15622	5	47	\N	576	69658	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул. Громова, 7		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15617	5	47	\N	576	69658	\N	51.518925874259601	Алтайский край, г.Рубцовск, ул.Громова, 29		0101000020E6100000CD5B751DAA4C5440A585CB2A6CC24940
15610	5	47	\N	576	69992	\N	51.533381538771003	Алтайский край, г.Рубцовск, пер.Гражданский, 52	Россия, Алтайский край, городской округ Рубцовск	0101000020E6100000E17F2BD9B14C5440362383DC45C44940
15620	5	47	\N	576	69990	\N	51.516569699173601	Алтайский край, г.Рубцовск, Бульвар Победы, 11		0101000020E6100000E2CD1ABCAF4C5440200C3CF71EC24940
15636	5	47	\N	576	69862	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Брусилова, 41		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15632	5	47	\N	576	69669	\N	51.516998103757103	Алтайский край, г.Рубцовск, ул.Алтайская, 179		0101000020E6100000E2CD1ABCAF4C5440780C8FFD2CC24940
15630	5	47	\N	576	69669	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Алтайская, 112А		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
15581	5	47	\N	576	69669	\N	51.516998000000001	Алтайский край, г.Рубцовск, ул.Алтайская, 169А		0101000020E61000004298DBBDDC4C5440780C8FFD2CC24940
16459	5	47	\N	59370	70015	\N	52.493899999999996	Алтайский край, Родинский район, с. Родино, Рабочий, 20		0101000020E6100000F4A5B73F170D544048BF7D1D383F4A40
16401	5	47	\N	59353	69742	\N	51.779172000000003	Алтайский край, Поспелихинский район, с.Поспелиха, ул.8 Марта, д.48		0101000020E61000000E164ED2FCC45440BEFA78E8BBE34940
15596	5	47	\N	59344	70121	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Энгельса, 1		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15589	5	47	\N	59344	70124	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Трактовая, 88		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15598	5	47	\N	59344	70011	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Союза Республик, 3		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15593	5	47	\N	59344	69690	\N	53.409084635025401	Алтайский край, город Новоалтайск, ул.Прудская, 8	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E6100000A032FE7DC6FC54405F24B4E55CB44A40
15592	5	47	\N	59344	69690	\N	53.415033391818397	Алтайский край, город Новоалтайск, ул.Прудская, 9	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E610000062821ABE85FD544061E124CD1FB54A40
15584	5	47	\N	59344	70127	\N	53.4148282761901	Алтайский край, город Новоалтайск, ул.Попова, 16	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E61000008C6665FB90FD544088BB7A1519B54A40
15599	5	47	\N	59344	69677	\N	53.400262525776697	Алтайский край, город Новоалтайск, ул.Мерзликина, 15	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E610000078094E7D20FD5440416667D13BB34A40
15595	5	47	\N	59344	69689	\N	53.421391483280203	Алтайский край, город Новоалтайск, ул.Менделеева, 48	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E61000009DF3531C07FE544014EAE923F0B54A40
15577	5	47	\N	59344	70116	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Майская, 125		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15594	5	47	\N	59344	69870	\N	53.4004752261093	Алтайский край, город Новоалтайск, ул.Космонавтов, 16	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E6100000073F7100FDFC5440CCEEC9C342B34A40
15590	5	47	\N	59344	69858	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Анатолия, 13		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15586	5	47	\N	59344	69783	\N	53.401493628113002	Алтайский край, город Новоалтайск, ул.8 микрорайон, 24	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E6100000026553AEF0FC544026C5C72764B34A40
15582	5	47	\N	59344	69977	\N	53.416879387742803	Алтайский край, город Новоалтайск, ул.22 Партсъезда, д.9а	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E610000089963C9E96FD5440D1B1834A5CB54A40
15585	5	47	\N	59344	70425	\N	53.416674281060402	Алтайский край, город Новоалтайск, ул.2-Залинейная, д.14	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E6100000B0AA5E7EA7FD5440F88BD99255B54A40
16242	5	47	\N	59351	69731	\N	51.816561999999998	Алтайский край, Михайловский район, с.Михайловское, К.Маркса, д.41		0101000020E610000061FD9FC37CED53400394861A85E84940
16034	5	47	\N	59412	70811	\N	52.426834999999997	Алтайский край, Ключевский район, с. Марковка, Новая, 19		0101000020E610000056293DD34BF15340E2E47E87A2364A40
16222	5	47	\N	59390	70191	\N	52.427712999999997	Алтайский край, Мамонтовский район, с.Крестьянка, Новая, 2		0101000020E610000092AF0452626454407A89B14CBF364A40
16092	5	47	\N	59342	69917	\N	51.667634999999997	Алтайский край, Краснощековский район, с.Краснощеково, Молодежная, 25а		0101000020E61000002C2E8ECA4DAF54401D554D1075D54940
16022	5	47	\N	59369	69893	\N	52.249527999999998	Алтайский край, Ключевский район, с. Ключи, Центральная, 29		0101000020E6100000F7216FB9FACA5340D8B79388F01F4A40
15559	5	47	\N	59340	70295	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Томская, 2		0101000020E6100000AA49F08634545440454772F90FE54A40
15571	5	47	\N	59340	69653	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Терешковой, 21		0101000020E6100000AA49F08634545440454772F90FE54A40
15572	5	47	\N	59340	69655	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Новоярковский тракт, 12а		0101000020E6100000AA49F08634545440454772F90FE54A40
15574	5	47	\N	59340	70645	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, ст.Плотинная, Николаева, 38		0101000020E6100000AA49F08634545440454772F90FE54A40
15562	5	47	\N	59340	69982	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Некрасова, 2		0101000020E6100000AA49F08634545440454772F90FE54A40
15560	5	47	\N	59340	69830	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Громова, 19		0101000020E6100000AA49F08634545440454772F90FE54A40
15569	5	47	\N	59340	69650	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Гагарина, 111		0101000020E6100000AA49F08634545440454772F90FE54A40
15551	5	47	\N	19902	70070	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск, Шумакова, 5		0101000020E6100000863C821B298C54401CD3139678944940
15554	5	47	\N	19902	69834	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск, Чернышевского, 1		0101000020E6100000863C821B298C54401CD3139678944940
15556	5	47	\N	19902	70910	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск, с.Лазурка, Центральная, 3		0101000020E6100000863C821B298C54401CD3139678944940
15549	5	47	\N	19902	69851	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск, Семипалатинская, 3		0101000020E6100000863C821B298C54401CD3139678944940
15555	5	47	\N	19902	69840	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск,  ул.Пугачева, д.18		0101000020E6100000863C821B298C54401CD3139678944940
15552	5	47	\N	19902	69641	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск, Ленина, 30		0101000020E6100000863C821B298C54401CD3139678944940
15550	5	47	\N	19902	69641	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск, Ленина, 3		0101000020E6100000863C821B298C54401CD3139678944940
15553	5	47	\N	19902	69959	\N	51.159930000000003	Алтайский край, Змеиногорский район, г.Змеиногорск, Барнаульский тракт, 46		0101000020E6100000863C821B298C54401CD3139678944940
15547	5	47	\N	59341	69675	\N	53.716894000000003	Алтайский край, город Заринск, пер.2-й Железнодорожный, д.3		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15546	5	47	\N	59341	70066	\N	53.716894000000003	Алтайский край, город Заринск, ул.Центральная, д.24		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15543	5	47	\N	59341	69832	\N	53.716894000000003	Алтайский край, город Заринск, ул.Таратынова, д.13/1		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
16996	5	47	\N	59341	70048	\N	53.709969340218898	Алтайский край, город Заринск, ул.Сыркина, д.43	Россия, Алтайский край, Заринский район, город Заринск	0101000020E6100000CEDE196D553C55404016A243E0DA4A40
15544	5	47	\N	59341	69643	\N	53.716894000000003	Алтайский край, город Заринск, ул.Строителей, д.22/1		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15542	5	47	\N	59341	69646	\N	53.716275386479303	Алтайский край, город Заринск, ул.Союза Республик, д.6	Россия, Алтайский край, Заринский район, город Заринск	0101000020E6100000BCE9961DE23D5540A1F831E6AEDB4A40
15541	5	47	\N	59341	69646	\N	53.716894000000003	Алтайский край, город Заринск, ул.Союза Республик, д.7/2		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15548	5	47	\N	59341	69960	\N	53.710173022921801	Алтайский край, город Заринск, ул.Заринская, д.58	Россия, Алтайский край, Заринский район, город Заринск	0101000020E6100000431B800D883C554048C0E8F2E6DA4A40
15540	5	47	\N	59341	69958	\N	53.716894000000003	Алтайский край, город Заринск, ул.40 лет Победы, д.4/2		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15537	5	47	\N	59341	69956	\N	53.716894000000003	Алтайский край, город Заринск, ул.25 Партсъезда, д.7		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15536	5	47	\N	59341	69956	\N	53.716894000000003	Алтайский край, город Заринск, ул.25 Партсъезда, д.36/2		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
94900	5	47	\N	59372	70012	\N	52.837766999999999	Алтайский край, Завьяловский район, с.Завьялово, Дорожная, 38		0101000020E61000005F5E807D743A54408255F5F23B6B4A40
16256	5	47	\N	59380	70086	\N	53.343015999999999	Алтайский край, Немецкий национальный район, с.Дегтярка, Ленина, 55		0101000020E6100000A8514832ABD653409B00C3F2E7AB4A40
16199	5	47	\N	59355	69929	\N	50.989657000000001	Алтайский край, Локтевский район, город Горняк, Элеваторная, 1		0101000020E6100000D73043E3895F5440F5A0A014AD7E4940
16197	5	47	\N	59355	69927	\N	50.9928662593409	Алтайский край, Локтевский район, город Горняк, Первомайская, 28		0101000020E610000064EAAEEC825E5440B9A7AB3B167F4940
16195	5	47	\N	59355	69923	\N	50.9885326521838	Алтайский край, Локтевский район, город Горняк, Островского, 17	Россия, Алтайский край, Локтевский район, город Горняк	0101000020E61000004DC0AF91246054402502D53F887E4940
16193	5	47	\N	59355	69748	\N	50.989886948118603	Алтайский край, Локтевский район, город Горняк, Ленина, 5	Россия, Алтайский край, Локтевский район, город Горняк	0101000020E610000024253D0CAD5F544027DE019EB47E4940
16198	5	47	\N	59355	71216	\N	50.989657000000001	Алтайский край, Локтевский район, город Горняк, Заводская, 5		0101000020E6100000D73043E3895F5440F5A0A014AD7E4940
16196	5	47	\N	59355	70167	\N	50.988573599057297	Алтайский край, Локтевский район, город Горняк, Больничная, 18	Россия, Алтайский край, Локтевский район, город Горняк	0101000020E610000039B69E211C60544084D6C397897E4940
15512	5	47	\N	15194	\N	\N	52.536873146626299	Алтайский край, город Бийск, клуб Фоминское		0101000020E6100000B9196EC0E74D55407E8D2441B8444A40
15527	5	47	\N	15194	69859	\N	52.526980380780302	Алтайский край, город Бийск, Кутузова, 9/3	Россия, Алтайский край, город Бийск	0101000020E6100000A1F65B3B514E5540B3D2A41474434A40
15520	5	47	\N	15194	69651	\N	52.538547890570896	Алтайский край, город Бийск, Чайковского, д.4/1		0101000020E6100000E5D4CE30B54C5540C1A90F24EF444A40
15490	5	47	\N	15194	70045	\N	52.543990365013101	Алтайский край, город Бийск, Центральный, 10		0101000020E6100000DC48D922694E5540EFACDD76A1454A40
15501	5	47	\N	15194	70387	\N	52.526992999999997	Алтайский край, город Бийск, Урожайная, 19		0101000020E6100000884CF910544E5540471CB28174434A40
15507	5	47	\N	15194	70054	\N	52.546292746225902	Алтайский край, город Бийск, Ударная, 75	Россия, Алтайский край, город Бийск	0101000020E6100000A3923A014D4E55405184D4EDEC454A40
15488	5	47	\N	15194	69591	\N	52.546920647310699	Алтайский край, город Бийск, Тургенева, 215		0101000020E61000002A711DE38A4E5540703FE08101464A40
15484	5	47	\N	15194	69591	\N	52.540013238858101	Алтайский край, город Бийск, Тургенева, 66		0101000020E6100000E257ACE1224D55401A355F251F454A40
15510	5	47	\N	15194	69635	\N	52.544618299198802	Алтайский край, город Бийск, Трофимова, 27	Россия, Алтайский край, город Бийск	0101000020E610000018CFA0A17F4E55400E68E90AB6454A40
15504	5	47	\N	15194	69635	\N	52.5316391579968	Алтайский край, город Бийск, Трофимова, 45		0101000020E6100000E4BF4010204D55409A232BBF0C444A40
15482	5	47	\N	15194	69635	\N	52.516103094267997	Алтайский край, город Бийск, Трофимова, 6		0101000020E610000093C49272F74A55400A2FC1A90F424A40
15460	5	47	\N	15194	69605	\N	52.532057900160297	Алтайский край, город Бийск, Телеграфный, 65	Россия, Алтайский край, город Бийск	0101000020E6100000D2FE0758AB4C55409FC9FE791A444A40
15523	5	47	\N	15194	69639	\N	52.539385238468	Алтайский край, город Бийск, Социалистическая, 30	Россия, Алтайский край, город Бийск	0101000020E61000007D93A641D14D5540FB7953910A454A40
15518	5	47	\N	15194	69639	\N	52.546711347952197	Алтайский край, город Бийск, Социалистическая, 80		0101000020E6100000B804E09F524E554086AE44A0FA454A40
15502	5	47	\N	15194	69639	\N	52.545769488425996	Алтайский край, город Бийск, Социалистическая, 123	Россия, Алтайский край, город Бийск	0101000020E6100000DB148F8B6A4E5540D71533C2DB454A40
15535	5	47	\N	15194	69637	\N	52.548804296400597	Алтайский край, город Бийск, Советская, 199/1		0101000020E610000091F0BDBF414E5540FDF49F353F464A40
15531	5	47	\N	15194	69637	\N	52.526992999999997	Алтайский край, город Бийск, Советская, 219/5		0101000020E6100000884CF910544E5540471CB28174434A40
15530	5	47	\N	15194	69637	\N	52.546920647310699	Алтайский край, город Бийск, Советская, 199/7		0101000020E6100000035DFB027A4E5540703FE08101464A40
15529	5	47	\N	15194	69637	\N	52.526992999999997	Алтайский край, город Бийск, Советская, 212		0101000020E6100000884CF910544E5540471CB28174434A40
15465	5	47	\N	15194	69637	\N	52.526992999999997	Алтайский край, город Бийск, Советская, 78		0101000020E6100000884CF910544E5540471CB28174434A40
15464	5	47	\N	15194	69637	\N	52.545246224357001	Алтайский край, город Бийск, Советская, 58		0101000020E610000051853FC39B4E55402D23F59ECA454A40
15463	5	47	\N	15194	69637	\N	52.526364769158398	Алтайский край, город Бийск, Советская, 30		0101000020E6100000B7990AF1484C55402861A6ED5F434A40
15475	5	47	\N	15194	69874	\N	52.531999014786003	Алтайский край, город Бийск, Смольный, 5	Россия, Алтайский край, город Бийск	0101000020E6100000B4942C27A14C55409A40118B18444A40
15503	5	47	\N	15194	69813	\N	52.526992999999997	Алтайский край, город Бийск, Севастопольская, 39		0101000020E6100000884CF910544E5540471CB28174434A40
15471	5	47	\N	15194	69806	\N	52.529126620746702	Алтайский край, город Бийск, Самарская, 46		0101000020E6100000BB438A01124D55401E37FC6EBA434A40
15459	5	47	\N	15194	70599	\N	52.526992999999997	Алтайский край, город Бийск, Революции, 98		0101000020E6100000884CF910544E5540471CB28174434A40
15519	5	47	\N	15194	69920	\N	52.547548539368002	Алтайский край, город Бийск, Разина, 61	Россия, Алтайский край, город Бийск	0101000020E610000091F0BDBF414E55408FFAEB1516464A40
15511	5	47	\N	15194	69920	\N	52.545455530736902	Алтайский край, город Бийск, Разина, 5		0101000020E6100000062D2460744E554018B49080D1454A40
15483	5	47	\N	15194	70605	\N	52.526992999999997	Алтайский край, город Бийск, Раздольная, 28		0101000020E6100000884CF910544E5540471CB28174434A40
15528	5	47	\N	15194	69831	\N	52.526992999999997	Алтайский край, город Бийск, Радищева, 28		0101000020E6100000884CF910544E5540471CB28174434A40
15526	5	47	\N	15194	69831	\N	52.526992999999997	Алтайский край, город Бийск, Радищева, 20		0101000020E6100000884CF910544E5540471CB28174434A40
15493	5	47	\N	15194	9837	\N	52.526404542368603	Алтайский край, город Бийск, Пушкина, 188-а	Россия, Алтайский край, город Бийск	0101000020E6100000B804E09F524E5540B6B9313D61434A40
15480	5	47	\N	15194	69623	\N	52.5471299456662	Алтайский край, город Бийск, Промышленная, 9		0101000020E61000003FE3C281904E55408B54185B08464A40
15534	5	47	\N	15194	69953	\N	52.526992999999997	Алтайский край, город Бийск, Приречная, 3/2		0101000020E6100000884CF910544E5540471CB28174434A40
15524	5	47	\N	15194	69837	\N	52.543990365013101	Алтайский край, город Бийск, Прибыткова, 9	Россия, Алтайский край, город Бийск	0101000020E6100000789961A3AC4E5540EFACDD76A1454A40
15467	5	47	\N	15194	69804	\N	52.526992999999997	Алтайский край, город Бийск, Подгорная, 78		0101000020E6100000884CF910544E5540471CB28174434A40
15481	5	47	\N	15194	69809	\N	52.526992999999997	Алтайский край, город Бийск, Петрова, 21		0101000020E6100000884CF910544E5540471CB28174434A40
15500	5	47	\N	15194	69633	\N	52.530801661631401	Алтайский край, город Бийск, Нефтебаза, 4		0101000020E6100000AAB69BE09B4C55406153E751F1434A40
15468	5	47	\N	15194	69933	\N	52.547339243018598	Алтайский край, город Бийск, Мухачева, 228/1	Россия, Алтайский край, город Бийск	0101000020E6100000035DFB027A4E5540A56950340F464A40
15469	5	47	\N	15194	69611	\N	52.547967129057703	Алтайский край, город Бийск, Муромцевский, 8	Россия, Алтайский край, город Бийск	0101000020E61000002D414640854E5540C4245CC823464A40
15499	5	47	\N	15194	69631	\N	52.526992999999997	Алтайский край, город Бийск, Моторный, 5		0101000020E6100000884CF910544E5540471CB28174434A40
15521	5	47	\N	15194	69946	\N	52.5471299456662	Алтайский край, город Бийск, Можайского, 6		0101000020E610000018CFA0A17F4E55408B54185B08464A40
15479	5	47	\N	15194	70100	\N	52.526992999999997	Алтайский край, город Бийск, Мерлина, 25		0101000020E6100000884CF910544E5540471CB28174434A40
15505	5	47	\N	15194	69815	\N	52.526992999999997	Алтайский край, город Бийск, Мартьянова, 42		0101000020E6100000884CF910544E5540471CB28174434A40
15533	5	47	\N	15194	70058	\N	52.546083443858201	Алтайский край, город Бийск, Майская, 16	Россия, Алтайский край, город Бийск	0101000020E61000002D414640854E554067F3380CE6454A40
15494	5	47	\N	15194	69628	\N	52.549222874053903	Алтайский край, город Бийск, Льнокомбинат, 22		0101000020E610000018CFA0A17F4E5540029B73F04C464A40
15461	5	47	\N	15194	69607	\N	52.537082493130299	Алтайский край, город Бийск, Льва Толстого, 152		0101000020E6100000B6494563ED4D554098A25C1ABF444A40
15492	5	47	\N	15194	70051	\N	52.530552515632998	Алтайский край, город Бийск, Луговая, 99-а	Россия, Алтайский край, город Бийск	0101000020E61000006747AAEFFC4C5540B8E52329E9434A40
15508	5	47	\N	15194	69827	\N	52.549850733011098	Алтайский край, город Бийск, Липового, 74/3		0101000020E610000018CFA0A17F4E554021567F8461464A40
15496	5	47	\N	15194	70065	\N	52.526992999999997	Алтайский край, город Бийск, Лермонтова, 201		0101000020E6100000884CF910544E5540471CB28174434A40
15522	5	47	\N	15194	70056	\N	52.545874140487498	Алтайский край, город Бийск, Ленинградская, 53		0101000020E610000054556820964E55404CDE0033DF454A40
15462	5	47	\N	15194	69930	\N	52.542943787975197	Алтайский край, город Бийск, Ленина, 139		0101000020E61000003FE3C281904E55409BC761307F454A40
15472	5	47	\N	15194	69939	\N	52.545664836113701	Алтайский край, город Бийск, Л.Толстого, 108		0101000020E6100000DC48D922694E554032C9C859D8454A40
15456	5	47	\N	15194	69797	\N	52.526992999999997	Алтайский край, город Бийск, Кулундинская, 19		0101000020E6100000884CF910544E5540471CB28174434A40
15458	5	47	\N	15194	70281	\N	52.526992999999997	Алтайский край, город Бийск, Куйбышева, 106		0101000020E6100000884CF910544E5540471CB28174434A40
15485	5	47	\N	15194	70049	\N	52.545834384997598	Алтайский край, город Бийск, Крылова, 32	Россия, Алтайский край, город Бийск	0101000020E61000009AEE75525F4E5540BE8575E3DD454A40
15487	5	47	\N	15194	69814	\N	52.536035750578499	Алтайский край, город Бийск, Красноярский, 87		0101000020E61000000742B280094E554045BDE0D39C444A40
15486	5	47	\N	15194	69626	\N	52.5471299456662	Алтайский край, город Бийск, Красильникова, 152	Россия, Алтайский край, город Бийск	0101000020E6100000B804E09F524E55408B54185B08464A40
15473	5	47	\N	15194	69934	\N	52.527202350556799	Алтайский край, город Бийск, Короленко, 53	Россия, Алтайский край, город Бийск	0101000020E6100000685C3810924C55406231EA5A7B434A40
15470	5	47	\N	15194	69934	\N	52.526992999999997	Алтайский край, город Бийск, Короленко, 47/2		0101000020E6100000884CF910544E5540471CB28174434A40
15476	5	47	\N	15194	69616	\N	52.526992999999997	Алтайский край, город Бийск, Железнодорожный, 3		0101000020E6100000884CF910544E5540471CB28174434A40
15457	5	47	\N	15194	70094	\N	52.546083443858201	Алтайский край, город Бийск, Динамовская, 4	Россия, Алтайский край, город Бийск	0101000020E6100000CAA65CE15D4E554067F3380CE6454A40
15525	5	47	\N	15194	70098	\N	52.526992999999997	Алтайский край, город Бийск, Декабристов, д.1		0101000020E6100000884CF910544E5540471CB28174434A40
15489	5	47	\N	15194	69937	\N	52.526992999999997	Алтайский край, город Бийск, Горького, 212		0101000020E6100000884CF910544E5540471CB28174434A40
15515	5	47	\N	15194	69825	\N	52.535303015870397	Алтайский край, город Бийск, Горно-Алтайская, 60		0101000020E6100000A60F5D50DF4D5540B03907CF84444A40
15514	5	47	\N	15194	69825	\N	52.530382907429498	Алтайский край, город Бийск, Горно-Алтайская, 56		0101000020E6100000CEFA9463B24C55405CAD1397E3434A40
15509	5	47	\N	15194	69825	\N	52.537042729638102	Алтайский край, город Бийск, Горно-Алтайская, 52	Россия, Алтайский край, город Бийск	0101000020E610000089618731E94D5540DAC534D3BD444A40
15532	5	47	\N	15194	69948	\N	52.530696973457196	Алтайский край, город Бийск, Гайдара, 5	Россия, Алтайский край, город Бийск	0101000020E610000045F295404A4D5540EC8A19E1ED434A40
15466	5	47	\N	15194	69608	\N	52.530382907429498	Алтайский край, город Бийск, Волочаевская, 6		0101000020E6100000942F6821014D55405CAD1397E3434A40
15506	5	47	\N	15194	69819	\N	52.537291838631297	Алтайский край, город Бийск, Воинов-Интернационалистов, 76	Россия, Алтайский край, город Бийск	0101000020E6100000567F8461C04D55408333F8FBC5444A40
15517	5	47	\N	15194	69636	\N	52.526992999999997	Алтайский край, город Бийск, Васильева, 52		0101000020E6100000884CF910544E5540471CB28174434A40
15513	5	47	\N	15194	69636	\N	52.530173528823802	Алтайский край, город Бийск, Васильева, 61/1		0101000020E610000080D250A3904C55404298DBBDDC434A40
15477	5	47	\N	15194	69613	\N	52.532267269737197	Алтайский край, город Бийск, Вали Максимовой, 91а	Россия, Алтайский край, город Бийск	0101000020E61000005B79C9FFE44C5540B9DE365321444A40
15474	5	47	\N	15194	69613	\N	52.526992999999997	Алтайский край, город Бийск, Вали Максимовой, 13		0101000020E6100000884CF910544E5540471CB28174434A40
15478	5	47	\N	15194	69817	\N	52.526992999999997	Алтайский край, город Бийск, Вагонная, 65		0101000020E6100000884CF910544E5540471CB28174434A40
15516	5	47	\N	15194	69829	\N	52.526992999999997	Алтайский край, город Бийск, 8 Марта, 16		0101000020E6100000884CF910544E5540471CB28174434A40
15497	5	47	\N	15194	69938	\N	52.5494190809477	Алтайский край, город Бийск, 3-я Мало-Угреневская, 18		0101000020E6100000109370218F56554088669E5C53464A40
15447	5	47	\N	59333	69621	\N	51.990969999999997	Алтайский край, город Белокуриха, Академика Мясникова, 25		0101000020E6100000D3F544D7853D554097A8DE1AD8FE4940
15370	5	47	\N	573	\N	\N	53.416722	Алтайский край, город Барнаул, Ленинский район, поселок Научный Городок, 38		0101000020E6100000062FFA0AD2E1544009C3802557B54A40
15287	5	47	\N	573	1961	\N	53.339156000000003	Алтайский край, город Барнаул, Железнодорожный район, ул.Шевченко, д.158	Россия, Алтайский край, Барнаул, улица Шевченко, 158	0101000020E61000006B2DCC423BF05440001FBC7669AB4A40
15307	5	47	\N	573	2241	\N	53.348376000000002	Алтайский край, город Барнаул, Железнодорожный район, Советской Армии, 54а	Россия, Алтайский край, Барнаул, улица Советской Армии, 54а	0101000020E6100000CFDC43C2F7EE54400C5BB39597AC4A40
15355	5	47	\N	573	2962	\N	53.369785999999998	Алтайский край, город Барнаул, Ленинский район, Попова, 66	Россия, Алтайский край, Барнаул, улица Попова, 66	0101000020E6100000FCC7427408EB54406342CC2555AF4A40
15387	5	47	\N	573	3382	\N	53.378413000000002	Алтайский край, город Барнаул, Октябрьский район, Петра Сухова, 11	Россия, Алтайский край, Барнаул, улица Петра Сухова, 11	0101000020E6100000274EEE7728EF5440CDB051D66FB04A40
15425	5	47	\N	573	15456	\N	53.319301000000003	Алтайский край, город Барнаул, ул.Мамонтова, д.218а	Россия, Алтайский край, Барнаул, Центральный район, улица Мамонтова, 218а	0101000020E610000029EACC3D24F15440414AECDADEA84A40
15305	5	47	\N	573	189	\N	53.359774999999999	Алтайский край, город Барнаул, Железнодорожный район, Зеленая Роща, 1	Россия, Алтайский край, Барнаул, улица Зеленая Роща, 1	0101000020E610000029417FA147F054408E75711B0DAE4A40
15363	5	47	\N	573	3043	\N	53.377887000000001	Алтайский край, город Барнаул, Ленинский район, Гущина, 189	Россия, Алтайский край, Барнаул, улица Гущина, 189	0101000020E6100000259529E620EB5440B24AE9995EB04A40
15357	5	47	\N	573	2287	\N	53.365385000000003	Алтайский край, город Барнаул, Ленинский район, Георгия Исакова, 206	Россия, Алтайский край, Барнаул, улица Георгия Исакова, 206	0101000020E6100000FD3383F8C0EC544078B988EFC4AE4A40
15310	5	47	\N	573	2287	\N	53.358581999999998	Алтайский край, город Барнаул, Железнодорожный район, Георгия Исакова, 120а	Россия, Алтайский край, Барнаул, улица Георгия Исакова, 120а	0101000020E61000001C7BF65CA6EE54409677D503E6AD4A40
16979	5	47	\N	573	29015	\N	53.353589999999997	Алтайский край, ЗАТО поселок Сибирский, ул.Строителей, д.5 (ул.Кедровая, д.15А)	Россия, Алтайский край, Барнаул, проспект Строителей, 5	0101000020E6100000AE6708C72CF15440A818E76F42AD4A40
26242	5	44	7505	\N	28957	\N	51.836491652411702	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Строителей пр, 16"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000ADF6B0170AEC5A40CDAE7B2B12EB4940
26240	5	44	7505	\N	28957	\N	51.857542784458097	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Строителей пр, 60"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000007431D56B8EE5A40F5F411F8C3ED4940
26239	5	44	7505	\N	28957	\N	51.857967957878998	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Октябрьский район, Строителей пр, 72"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E610000040F9BB77D4EE5A40DC813AE5D1ED4940
15406	5	47	\N	573	2089	\N	53.341554000000002	Алтайский край, город Барнаул, Центральный район, просп.Ленина, 38		0101000020E6100000D6FD63213AF25440B4E89D0AB8AB4A40
15378	5	47	\N	573	2089	\N	53.350555457204003	Алтайский край, город Барнаул, Октябрьский район, Ленина, 68	Россия, Алтайский край, Барнаул, проспект Ленина, 68а	0101000020E610000023861DC6A4F1544082397AFCDEAC4A40
15302	5	47	\N	573	2089	\N	53.366996999999998	Алтайский край, город Барнаул, Железнодорожный район, Ленина, 145	Россия, Алтайский край, Барнаул, проспект Ленина, 145	0101000020E610000065C405A051F05440745DF8C1F9AE4A40
15301	5	47	\N	573	2089	\N	53.377628999999999	Алтайский край, город Барнаул, Железнодорожный район, Ленина, 148	Россия, Алтайский край, Барнаул, проспект Ленина, 148	0101000020E6100000060FD3BEB9EF5440B682A62556B04A40
15297	5	47	\N	573	2089	\N	53.355186000000003	Алтайский край, город Барнаул, Железнодорожный район, Ленина, 89	Россия, Алтайский край, Барнаул, проспект Ленина, 89	0101000020E61000007F4B00FE29F15440A0FF1EBC76AD4A40
15296	5	47	\N	573	2089	\N	53.350709627831598	Алтайский край, город Барнаул, Железнодорожный район, Ленина, 69	Россия, Алтайский край, Барнаул, проспект Ленина, 69	0101000020E61000009607E92972F15440A930B610E4AC4A40
15398	5	47	\N	573	3519	\N	53.385416999999997	Алтайский край, город Барнаул, Октябрьский район, Космонавтов, 23	Россия, Алтайский край, Барнаул, проспект Космонавтов, 23	0101000020E6100000F52C08E57DEE54404529215855B14A40
15306	5	47	\N	573	2227	\N	53.350112000000003	Алтайский край, город Барнаул, Железнодорожный район, Коммунаров, 100	Россия, Алтайский край, Барнаул, проспект Коммунаров, 100	0101000020E61000003E78EDD286EF5440F5F75278D0AC4A40
15434	5	47	\N	573	70082	\N	53.253211999999998	Алтайский край, город Барнаул, Центральный район, р.п.Южный, просп.Дзержинского, 27		0101000020E6100000C2C2499A3FEC5440357A354069A04A40
15713	5	47	\N	573	7102	\N	53.349150000000002	Алтайский край, Алтайский район, с. Ая, Победы, 1	Россия, Алтайский край, Барнаул, площадь Победы, 1	0101000020E61000002D26361FD7F05440FFB27BF2B0AC4A40
15411	5	47	\N	573	3693	\N	53.335661000000002	Алтайский край, город Барнаул, Центральный район, пер.Ядринцева, 76	Россия, Алтайский край, Барнаул, переулок Ядринцева, 76	0101000020E6100000CE39782634F1544076C58CF0F6AA4A40
26181	5	44	7505	\N	28918	\N	51.859318500277602	"Республика Бурятия, городской округ ""Город Улан-Удэ"", Железнодорожный район, Радищева, 5"	Россия, Республика Бурятия, городской округ Улан-Удэ	0101000020E6100000E1B721C66BE55A406CEA3C2AFEED4940
15421	5	47	\N	573	3588	\N	53.341968000000001	Алтайский край, город Барнаул, Центральный район, пер.Некрасова, 18	Россия, Алтайский край, Барнаул, переулок Некрасова, 18	0101000020E6100000C632FD12F1F25440A723809BC5AB4A40
15404	5	47	\N	573	3588	\N	53.348010000000002	Алтайский край, город Барнаул, Центральный район, пер.Некрасова, 65	Россия, Алтайский край, Барнаул, переулок Некрасова, 65	0101000020E6100000454948A46DF254402A5778978BAC4A40
15381	5	47	\N	573	3314	\N	53.366374	Алтайский край, город Барнаул, Октябрьский район, бульвар 9-го Января, 99	Россия, Алтайский край, Барнаул, бульвар 9 Января, 99	0101000020E61000006A6AD95A5FF25440670DDE57E5AE4A40
15362	5	47	\N	573	70233	\N	53.375098999999999	Алтайский край, город Барнаул, Ленинский район, Юрина, 220		0101000020E610000036E675C421EB544093E1783E03B04A40
15360	5	47	\N	573	70233	\N	53.371032	Алтайский край, город Барнаул, Ленинский район, Юрина, 196		0101000020E61000009A22C0E95DEC54407EE200FA7DAF4A40
15359	5	47	\N	573	70233	\N	53.364966000000003	Алтайский край, город Барнаул, Ленинский район, Юрина, 203		0101000020E61000008E5C37A5BCED54407313B534B7AE4A40
15358	5	47	\N	573	70233	\N	53.367491999999999	Алтайский край, город Барнаул, Ленинский район, Юрина, 239		0101000020E6100000FD3383F8C0EC544054C554FA09AF4A40
15356	5	47	\N	573	70233	\N	53.368957999999999	Алтайский край, город Барнаул, Ленинский район, Юрина, 287		0101000020E6100000F0E0270EA0EB54407DCC07043AAF4A40
16989	5	47	\N	573	70262	\N	53.356782000000003	Алтайский край, город Барнаул, Индустриальный район, ул.Энтузиастов, 34		0101000020E6100000787C7BD7A0EA544097E65608ABAD4A40
15345	5	47	\N	573	70262	\N	53.357137000000002	Алтайский край, город Барнаул, Индустриальный район, Энтузиастов, 26		0101000020E610000076C58CF0F6EA544085984BAAB6AD4A40
15339	5	47	\N	573	70262	\N	53.354239999999997	Алтайский край, город Барнаул, Индустриальный район, Энтузиастов, 5		0101000020E61000002E39EE940EEC5440AF777FBC57AD4A40
15367	5	47	\N	573	70263	\N	53.379911999999997	Алтайский край, город Барнаул, Ленинский район, Эмилии Алексеевой, 84		0101000020E6100000A85489B2B7EC5440D1ADD7F4A0B04A40
15366	5	47	\N	573	70263	\N	53.379809999999999	Алтайский край, город Барнаул, Ленинский район, Эмилии Алексеевой, 60		0101000020E61000003927F6D03EED5440CD58349D9DB04A40
63259	3	31	\N	57342	58014	\N	58.382935000000003	г.Боровичи, С.Перовской, 90		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
15392	5	47	\N	573	69599	\N	53.384929	Алтайский край, город Барнаул, Октябрьский район, Э.Алексеевой, 56		0101000020E61000008A1C226E4EF2544018247D5A45B14A40
15334	5	47	\N	573	70261	\N	53.340463	Алтайский край, город Барнаул, Индустриальный район, Шумакова, 22		0101000020E6100000FF791A3048EB5440C03FA54A94AB4A40
15353	5	47	\N	573	70217	\N	53.365982000000002	Алтайский край, город Барнаул, Ленинский район, Шукшина, 30		0101000020E6100000E02BBAF59AEA54405C76887FD8AE4A40
15352	5	47	\N	573	70217	\N	53.363408	Алтайский край, город Барнаул, Ленинский район, Шукшина, 29		0101000020E61000004EF2237EC5EA5440698D412784AE4A40
16881	5	47	\N	573	15899	\N	53.37086	Алтайский край, Целинный район, с.Верх-Шубинка, ул.Школьная, д.6	Россия, Алтайский край, Барнаул, Октябрьский район, микрорайон ВРЗ, Школьная улица, 6	0101000020E61000006A334E4354F3544081B2295778AF4A40
15440	5	47	\N	573	70091	\N	53.241605999999997	Алтайский край, город Барнаул, Центральный район с.Лебяжье, ул.Школьная, 65		0101000020E6100000520B259353EA5440394206F2EC9E4A40
15369	5	47	\N	573	70212	\N	53.418661911235702	Алтайский край, город Барнаул, Ленинский район, с.Гоньба, Школьная, 12		0101000020E61000008461C092ABE45440FA0967B796B54A40
16988	5	47	\N	573	70593	\N	53.216830999999999	Алтайский край, город Барнаул, Центральный район, пос.Черницк, ул.Школьная, 18		0101000020E610000044C362D4B5E3544026E1421EC19B4A40
15390	5	47	\N	573	70276	\N	53.374217999999999	Алтайский край, город Барнаул, Октябрьский район, Чудненко, 62		0101000020E610000086AFAF75A9EE54408AC91B60E6AF4A40
15415	5	47	\N	573	70236	\N	53.333176999999999	Алтайский край, город Барнаул, Центральный район, ул.Чкалова, 194		0101000020E610000076FD82DDB0F05440C3633F8BA5AA4A40
15408	5	47	\N	573	70236	\N	53.341334000000003	Алтайский край, город Барнаул, Центральный район, ул.Чкалова, 68		0101000020E6100000EA25C632FDF15440A6811FD5B0AB4A40
15303	5	47	\N	573	70257	\N	53.366233999999999	Алтайский край, город Барнаул, Железнодорожный район, Червонная, 9		0101000020E6100000F0879FFF1EF05440755776C1E0AE4A40
15300	5	47	\N	573	70257	\N	53.367454000000002	Алтайский край, город Барнаул, Железнодорожный район, Червонная, 8		0101000020E6100000F209D9791BF05440676490BB08AF4A40
15436	5	47	\N	573	70239	\N	53.256622	Алтайский край, город Барнаул, Центральный район, р.п.Южный, ул.Чайковского, 8		0101000020E61000008109DCBA9BEC544091B75CFDD8A04A40
15430	5	47	\N	573	70239	\N	53.253622695911901	Алтайский край, город Барнаул, Центральный район, р.п.Южный, ул.Чайковского, 21	Россия, Алтайский край, Барнаул, поселок Южный, улица Чайковского, 21а	0101000020E610000069705B5B78EC5440B741EDB776A04A40
15435	5	47	\N	573	70269	\N	53.253982000000001	Алтайский край, город Барнаул, Центральный район, р.п.Южный, ул.Чайковского, 22		0101000020E61000000327DBC01DEC5440E7E26F7B82A04A40
15431	5	47	\N	573	70282	\N	53.252499999999998	Алтайский край, город Барнаул, Центральный район, р.п.Южный, ул.Чайковского, 31		0101000020E6100000ACC5A70018EC5440B81E85EB51A04A40
15331	5	47	\N	573	70709	\N	53.247948000000001	Алтайский край, город Барнаул, Индустриальный район, Новомихайловка поселок, Центральная, 25		0101000020E6100000F2CEA10C55EA5440E78D93C2BC9F4A40
16811	5	47	\N	573	70210	\N	53.247948000000001	Алтайский край, Усть-Калманский район, ул.Центральная, 47е		0101000020E6100000F2CEA10C55EA5440E78D93C2BC9F4A40
15371	5	47	\N	573	70215	\N	53.400015659802499	Алтайский край, город Барнаул, Ленинский район, п.Казенная Заимка, Цветущая, 1		0101000020E61000002E9276A38FE6544039F06AB933B34A40
15318	5	47	\N	573	70255	\N	53.338884308140599	Алтайский край, город Барнаул, Железнодорожный район, Фурманова, 14		0101000020E6100000EB025E66D8EE54409F91088D60AB4A40
15317	5	47	\N	573	70255	\N	53.338909000000001	Алтайский край, город Барнаул, Железнодорожный район, Фурманова, 12		0101000020E6100000865AD3BCE3EE5440F8A8BF5E61AB4A40
15427	5	47	\N	573	70244	\N	53.309085000000003	Алтайский край, город Барнаул, Центральный район, ул.Фомина, 130		0101000020E61000005A626534F2F054409357E71890A74A40
15397	5	47	\N	573	70235	\N	53.384343000000001	Алтайский край, город Барнаул, Октябрьский район, Тимуровская, 33		0101000020E61000005D37A5BC56EE544028B9C32632B14A40
15394	5	47	\N	573	70235	\N	53.381050999999999	Алтайский край, город Барнаул, Октябрьский район, Тимуровская, 23		0101000020E6100000AB22DC6454EE5440D68D7747C6B04A40
15393	5	47	\N	573	70235	\N	53.377312000000003	Алтайский край, город Барнаул, Октябрьский район, Тимуровская, 15		0101000020E61000007007EA9447EE5440B63176C24BB04A40
15311	5	47	\N	573	2290	\N	53.353960000000001	Алтайский край, город Барнаул, Железнодорожный район, Телефонная, 50а	Россия, Алтайский край, Барнаул, Телефонная улица, 50а	0101000020E6100000BC3E73D6A7EE5440CC0BB08F4EAD4A40
15384	5	47	\N	573	70253	\N	53.351719000000003	Алтайский край, город Барнаул, Октябрьский район, Союза республик, 36а		0101000020E61000007D3CF4DDADF15440E030D12005AD4A40
15407	5	47	\N	573	2064	\N	53.342188	Алтайский край, город Барнаул, Центральный район, просп.Социалистический, 68	Россия, Алтайский край, Барнаул, Социалистический проспект, 68	0101000020E6100000FC5069C4CCF15440B58AFED0CCAB4A40
15295	5	47	\N	573	2064	\N	53.349063999999998	Алтайский край, город Барнаул, Железнодорожный район, Социалистический, 126	Россия, Алтайский край, Барнаул, Социалистический проспект, 126	0101000020E6100000765089EB18F15440001B1021AEAC4A40
15294	5	47	\N	573	2064	\N	53.351014999999997	Алтайский край, город Барнаул, Железнодорожный район, Социалистический, 126б	Россия, Алтайский край, Барнаул, Социалистический проспект, 126б	0101000020E610000060764F1E16F15440E5B33C0FEEAC4A40
15332	5	47	\N	573	69795	\N	53.346758000000001	Алтайский край, город Барнаул, Индустриальный район, Спутник микрорайон, Соловьиная, 45		0101000020E610000024B726DD96E454402DD0EE9062AC4A40
15354	5	47	\N	573	70242	\N	53.371321999999999	Алтайский край, город Барнаул, Ленинский район, Солнечная Поляна, 11		0101000020E6100000D449B6BA9CEA54408524B37A87AF4A40
15346	5	47	\N	573	70242	\N	53.358829999999998	Алтайский край, город Барнаул, Индустриальный район, Солнечная поляна, 51		0101000020E61000000EC0064488EA54406E693524EEAD4A40
15316	5	47	\N	573	70225	\N	53.345855	Алтайский край, город Барнаул, Железнодорожный район, Советской Армии, 73		0101000020E6100000261B0FB6D8EE54403C1405FA44AC4A40
15379	5	47	\N	573	3276	\N	53.363661	Алтайский край, город Барнаул, Октябрьский район, Смольная, 46	Россия, Алтайский край, Барнаул, Смольная улица, 46	0101000020E61000006D1CB1169FF2544053EA92718CAE4A40
15304	5	47	\N	573	2188	\N	53.370071000000003	Алтайский край, город Барнаул, Железнодорожный район, Северо-Западная, 37	Россия, Алтайский край, Барнаул, Северо-Западная улица, 37	0101000020E6100000C8091346B3EF544059198D7C5EAF4A40
15336	5	47	\N	573	2676	\N	53.332918999999997	Алтайский край, город Барнаул, Индустриальный район, Северный Власихинский, 34	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 34	0101000020E6100000B056ED9A90EB5440C79BFC169DAA4A40
15335	5	47	\N	573	2676	\N	53.333176999999999	Алтайский край, город Барнаул, Индустриальный район, Северный Власихинский, 64	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 64	0101000020E610000047ACC5A700EB5440C3633F8BA5AA4A40
15329	5	47	\N	573	16178	\N	53.295954999999999	Алтайский край, город Барнаул, Индустриальный район, Власиха село, Ракитная, 2	Россия, Алтайский край, Барнаул, село Власиха, Ракитная улица, 2	0101000020E61000002AADBF2500E45440390B7BDAE1A54A40
15437	5	47	\N	573	70268	\N	53.287816999999997	Алтайский край, город Барнаул, Центральный район, пос.Борзовая Заимка, ул.Радужная, 97		0101000020E6100000473D44A33BE95440CD1DFD2FD7A44A40
15377	5	47	\N	573	70207	\N	53.3542821770993	Алтайский край, город Барнаул, Октябрьский район, Путиловская, 51	Россия, Алтайский край, Барнаул, Путиловская улица	0101000020E6100000DCF5D21401F25440DEC7D11C59AD4A40
15383	5	47	\N	573	70252	\N	53.359065999999999	Алтайский край, город Барнаул, Октябрьский район, Профинтерна, 32а		0101000020E6100000F7E6374C34F15440828DEBDFF5AD4A40
15382	5	47	\N	573	70252	\N	53.356782000000003	Алтайский край, город Барнаул, Октябрьский район, Профинтерна, 53а		0101000020E6100000E469F981ABF1544097E65608ABAD4A40
15416	5	47	\N	573	70326	\N	53.326836999999998	Алтайский край, город Барнаул, Центральный район, ул.Пролетарская, 224		0101000020E6100000E146CA1649F05440B60F79CBD5A94A40
15391	5	47	\N	573	70219	\N	53.376268223522999	Алтайский край, город Барнаул, Октябрьский район, Петра Сухова, 71	Россия, Алтайский край, Барнаул, улица Петра Сухова	0101000020E61000007A6EA12B11EE54400344C18C29B04A40
15328	5	47	\N	573	70505	\N	53.297495745076397	Алтайский край, город Барнаул, Индустриальный район, Власиха село, Первомайская, 50		0101000020E61000003BAC70CB47E554406D58535914A64A40
15414	5	47	\N	573	1540	\N	53.330869999999997	Алтайский край, город Барнаул, Центральный район, ул.Партизанская, 195	Россия, Алтайский край, Барнаул, Партизанская улица, 195	0101000020E6100000FE0C6FD6E0F054401F9DBAF259AA4A40
15343	5	47	\N	573	70250	\N	53.351972000000004	Алтайский край, город Барнаул, Индустриальный район, Панфиловцев, 8		0101000020E6100000378B170B43EB5440CA8D226B0DAD4A40
15342	5	47	\N	573	70250	\N	53.351913000000003	Алтайский край, город Барнаул, Индустриальный район, Панфиловцев, 13		0101000020E61000004F95EF1989EB5440C504357C0BAD4A40
15338	5	47	\N	573	2455	\N	53.345802574354103	Алтайский край, город Барнаул, Индустриальный район, Павловский тракт, 100	Россия, Алтайский край, Барнаул, Павловский тракт, 100	0101000020E6100000DCD440F339EC5440E9EDCF4543AC4A40
15337	5	47	\N	573	2455	\N	53.345108000000003	Алтайский край, город Барнаул, Индустриальный район, Павловский тракт, 112А	Россия, Алтайский край, Барнаул, Павловский тракт, 112а	0101000020E61000003D484F9143EC544043CBBA7F2CAC4A40
15322	5	47	\N	573	2455	\N	53.344107999999999	Алтайский край, город Барнаул, Индустриальный район, Павловский тракт, 68А	Россия, Алтайский край, Барнаул, Павловский тракт, 68а	0101000020E61000004BCD1E6805ED54405F251FBB0BAC4A40
15321	5	47	\N	573	2455	\N	53.344316999999997	Алтайский край, город Барнаул, Индустриальный район, Павловский тракт, 68	Россия, Алтайский край, Барнаул, Павловский тракт, 68	0101000020E6100000242A543717ED5440793A579412AC4A40
15439	5	47	\N	573	69921	\N	53.241605999999997	Алтайский край, город Барнаул, Центральный район с.Лебяжье, ул.Опытная станция, 20		0101000020E6100000520B259353EA5440394206F2EC9E4A40
15325	5	47	\N	573	70103	\N	53.3082722161665	Алтайский край, город Барнаул, Индустриальный район, Новосиликатный микрорайон, Новосибирская, 8Б	Россия, Алтайский край, Барнаул, Индустриальный район, микрорайон Новосиликатный	0101000020E61000006AF816D68DE75440E222F77475A74A40
15327	5	47	\N	573	70256	\N	53.305549999999997	Алтайский край, город Барнаул, Индустриальный район, Пригородный поселок, Новосибирская, 44		0101000020E61000008CF84ECC7AE654407AA52C431CA74A40
15432	5	47	\N	573	70222	\N	53.247479438032499	Алтайский край, город Барнаул, Центральный район, р.п.Южный, ул.Мусоргского, 38		0101000020E610000067F3380CE6EB544030B95164AD9F4A40
15365	5	47	\N	573	70274	\N	53.379976999999997	Алтайский край, город Барнаул, Ленинский район, Монтажников, 14		0101000020E6100000A8380EBC5AEB5440B81D1A16A3B04A40
15290	5	47	\N	573	15989	\N	53.342463000000002	Алтайский край, город Барнаул, Железнодорожный район, Молодежная, 51	Россия, Алтайский край, Барнаул, Железнодорожный район, Молодежная улица, 51	0101000020E61000000A67B796C9F05440878BDCD3D5AB4A40
15288	5	47	\N	573	70254	\N	53.341737000000002	Алтайский край, город Барнаул, Железнодорожный район, Молодежная, 55		0101000020E61000002E03CE52B2F05440A56ABB09BEAB4A40
16796	5	47	1411	16245	70178	\N	51.359346000000002	Алтайский край, Угловский район, с.Угловское, Калинина, 3		0101000020E610000095287B4B390C544066F9BA0CFFAD4940
15441	5	47	\N	573	70199	\N	53.218415999999998	Алтайский край, город Барнаул, Центральный район, пос.Центральный, ул.Мира, 13		0101000020E6100000723271AB20E754402976340EF59B4A40
15399	5	47	\N	573	70238	\N	53.382371999999997	Алтайский край, город Барнаул, Октябрьский район, Маяковского, 25		0101000020E61000003AC9569753F25440FB73D190F1B04A40
15438	5	47	\N	573	70137	\N	53.300898338322398	Алтайский край, город Барнаул, Центральный район, микрорайон Затон, ул.Матросская, 94	Россия, Алтайский край, Барнаул, Матросская улица	0101000020E610000044BFB67EFAF2544045B75ED383A64A40
16985	5	47	\N	573	70285	\N	53.333407999999999	Алтайский край, город Барнаул, Индустриальный район, Малахова, 175		0101000020E610000018D2E1218CEC5440C51C041DADAA4A40
15396	5	47	\N	573	70285	\N	53.380164999999998	Алтайский край, город Барнаул, Октябрьский район, Малахова, 21		0101000020E6100000BEF73768AFED5440BB0A293FA9B04A40
15330	5	47	\N	573	70719	\N	53.340957000000003	Алтайский край, город Барнаул, Индустриальный район, Лесной поселок, 12		0101000020E6100000FD169D2CB5E75440D02B9E7AA4AB4A40
15344	5	47	\N	573	70213	\N	53.35689	Алтайский край, город Барнаул, Индустриальный район, Ленинградская, 8		0101000020E6100000672C9ACE4EEB54407D224F92AEAD4A40
15418	5	47	\N	573	70266	\N	53.316682	Алтайский край, город Барнаул, Центральный район, ул.Кутузова, 18		0101000020E61000002541B8020AEF5440AE9D280989A84A40
15323	5	47	\N	573	70706	\N	53.310763999999999	Алтайский край, город Барнаул, Индустриальный район, поселок Куета, 29		0101000020E61000001BD6541685E954401763601DC7A74A40
15409	5	47	\N	573	2002	\N	53.339882000000003	Алтайский край, город Барнаул, Центральный район, просп.Красноармейский, 62	Россия, Алтайский край, Барнаул, Красноармейский проспект, 62	0101000020E61000002F4E7CB5A3F15440E23FDD4081AB4A40
15293	5	47	\N	573	2002	\N	53.347257999999997	Алтайский край, город Барнаул, Железнодорожный район, Красноармейский, 110	Россия, Алтайский край, Барнаул, Красноармейский проспект, 110	0101000020E6100000CB0F5CE509F154401EA33CF372AC4A40
15292	5	47	\N	573	2002	\N	53.343946000000003	Алтайский край, город Барнаул, Железнодорожный район, Красноармейский, 98	Россия, Алтайский край, Барнаул, Красноармейский проспект, 98	0101000020E6100000B16EBC3B32F1544086CB2A6C06AC4A40
15291	5	47	\N	573	2002	\N	53.345554	Алтайский край, город Барнаул, Железнодорожный район, Красноармейский, 133	Россия, Алтайский край, Барнаул, Красноармейский проспект, 133	0101000020E6100000B58AFED0CCF0544041800C1D3BAC4A40
15289	5	47	\N	573	2002	\N	53.342343999999997	Алтайский край, город Барнаул, Железнодорожный район, Красноармейский, 94	Россия, Алтайский край, Барнаул, Красноармейский проспект, 94	0101000020E61000008B506C054DF15440ACFD9DEDD1AB4A40
15422	5	47	\N	573	70267	\N	53.332611999999997	Алтайский край, город Барнаул, Центральный район, ул.Короленко, 80		0101000020E6100000B62BF4C132F25440EA20AF0793AA4A40
15419	5	47	\N	573	70267	\N	53.337516000000001	Алтайский край, город Барнаул, Центральный район, ул.Короленко, 13		0101000020E610000013471E882CF3544039F06AB933AB4A40
15405	5	47	\N	573	3238	\N	53.343887000000002	Алтайский край, город Барнаул, Центральный район, просп.Комсомольский, 80	Россия, Алтайский край, Барнаул, Комсомольский проспект, 80	0101000020E6100000D8D5E429ABF2544081423D7D04AC4A40
15376	5	47	\N	573	3238	\N	53.347365000000003	Алтайский край, город Барнаул, Октябрьский район, Комсомольский, 71		0101000020E6100000D600A5A146F254403563D17476AC4A40
15413	5	47	\N	573	70243	\N	53.337366000000003	Алтайский край, город Барнаул, Центральный район, ул.Интернациональная, 80		0101000020E61000006DC9AA0837F25440246420CF2EAB4A40
15412	5	47	\N	573	70243	\N	53.337366000000003	Алтайский край, город Барнаул, ул.Интернациональная, д.80		0101000020E61000006DC9AA0837F25440246420CF2EAB4A40
15429	5	47	\N	573	3926	\N	53.274659	Алтайский край, город Барнаул, Центральный район, Змеиногорский тракт, 89	Россия, Алтайский край, Барнаул, Змеиногорский тракт, 89	0101000020E610000052F355F2B1EF5440AA46AF0628A34A40
15428	5	47	\N	573	3926	\N	53.292994999999998	Алтайский край, город Барнаул, Центральный район, Змеиногорский тракт, 49	Россия, Алтайский край, Барнаул, Змеиногорский тракт, 49	0101000020E6100000A723809BC5F054401D7233DC80A54A40
15433	5	47	\N	573	70198	\N	53.268093999999998	Алтайский край, город Барнаул, Центральный район, пос.Садоводов, Змеиногорский тракт, 120\\3		0101000020E6100000137D3ECA88EE54407D2079E750A24A40
15298	5	47	\N	573	2114	\N	53.355454999999999	Алтайский край, город Барнаул, Железнодорожный район, Деповская, 32	Россия, Алтайский край, Барнаул, Деповская улица, 32	0101000020E6100000EFC8586DFEF054408F19A88C7FAD4A40
15299	5	47	\N	573	70271	\N	53.355454999999999	Алтайский край, город Барнаул, ул.Деповская, д.32		0101000020E6100000EFC8586DFEF054408F19A88C7FAD4A40
15364	5	47	\N	573	70232	\N	53.379375000000003	Алтайский край, город Барнаул, Ленинский район, Гущина, 158		0101000020E6100000A4A99ECC3FEB5440C3F5285C8FB04A40
15361	5	47	\N	573	70232	\N	53.374760999999999	Алтайский край, город Барнаул, Ленинский район, Гущина, 177		0101000020E610000098C28366D7EB54407B681F2BF8AF4A40
15388	5	47	\N	573	3362	\N	53.371955999999997	Алтайский край, город Барнаул, Октябрьский район, Горно-Алтайская, 17		0101000020E6100000B7D0950854EF544086C613419CAF4A40
15385	5	47	\N	573	3362	\N	53.374029999999998	Алтайский край, город Барнаул, Октябрьский район, Горно-Алтайская, 7	Россия, Алтайский край, Барнаул, Горно-Алтайская улица, 7	0101000020E61000001E4E603AADEF544087DC0C37E0AF4A40
15386	5	47	\N	573	70501	\N	53.372526000000001	Алтайский край, город Барнаул, Октябрьский район, Горно-Алтайская, 20		0101000020E61000001D76DF313CEF5440717495EEAEAF4A40
15350	5	47	\N	573	70246	\N	53.362838000000004	Алтайский край, город Барнаул, Ленинский район, Георгия Исакова, 195		0101000020E61000000DFAD2DB9FEC54407FDFBF7971AE4A40
63275	3	31	\N	57342	57972	\N	58.382935000000003	г.Боровичи, Пушкинская, 14		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
15313	5	47	\N	573	70246	\N	53.360179000000002	Алтайский край, город Барнаул, Железнодорожный район, Георгия Исакова, 138		0101000020E61000003CDA38622DEE54405EDA70581AAE4A40
15312	5	47	\N	573	70246	\N	53.355325999999998	Алтайский край, город Барнаул, Железнодорожный район, Георгия Исакова, 113а		0101000020E61000001BF67B629DEE544091B586527BAD4A40
15309	5	47	\N	573	70248	\N	53.364026000000003	Алтайский край, город Барнаул, Железнодорожный район, Воронежская, 2		0101000020E6100000D61D8B6D52EF544065726A6798AE4A40
15380	5	47	\N	573	70264	\N	53.367497	Алтайский край, город Барнаул, Октябрьский район, Водопроводная, 87		0101000020E6100000124C35B396F25440663046240AAF4A40
15333	5	47	\N	573	70249	\N	53.34093	Алтайский край, город Барнаул, Индустриальный район, Взлетная, 28		0101000020E6100000E02BBAF59AEA5440D61C2098A3AB4A40
15989	5	47	\N	573	2588	\N	53.318795999999999	Алтайский край, Калманский район, п.Новый, ул.Боровая, д.6	Россия, Алтайский край, Барнаул, Боровая улица, 6	0101000020E61000005969520ABAEF54403D0CAD4ECEA84A40
15324	5	47	\N	573	70071	\N	53.303808016855299	Алтайский край, город Барнаул, Индустриальный район, Новосиликатный микрорайон, Благовещенская, 11	Россия, Алтайский край, Барнаул, Благовещенская улица	0101000020E6100000B62DCA6C90E75440AF21382EE3A64A40
15351	5	47	\N	573	70226	\N	53.362602000000003	Алтайский край, город Барнаул, Ленинский район, Антона Петрова, 218		0101000020E61000008BC058DFC0EB54406BBB09BE69AE4A40
15349	5	47	\N	573	70226	\N	53.359111531042501	Алтайский край, город Барнаул, Ленинский район, Антона Петрова, 150	Россия, Алтайский край, Барнаул, улица Антона Петрова, 150	0101000020E61000001D1EC2F869ED5440F3CCCB61F7AD4A40
15347	5	47	\N	573	70226	\N	53.357008	Алтайский край, город Барнаул, Ленинский район, Антона Петрова, 146г		0101000020E6100000BBED42739DED544087342A70B2AD4A40
15315	5	47	\N	573	70226	\N	53.353267000000002	Алтайский край, город Барнаул, Железнодорожный район, Антона Петрова, 112		0101000020E6100000D4F2035779EE5440C6E061DA37AD4A40
15314	5	47	\N	573	70226	\N	53.355820000000001	Алтайский край, город Барнаул, Железнодорожный район, Антона Петрова, 130		0101000020E6100000CE8B135FEDED5440A1A17F828BAD4A40
15424	5	47	\N	573	70220	\N	53.329875568778803	Алтайский край, город Барнаул, Центральный район, ул.Анатолия, 193		0101000020E6100000FD4B529962F154401EDE736039AA4A40
15417	5	47	\N	573	70220	\N	53.322226999999998	Алтайский край, город Барнаул, Центральный район, ул.Анатолия, 304		0101000020E61000008750A5660FF05440B071FDBB3EA94A40
15426	5	47	\N	573	70259	\N	53.309778999999999	Алтайский край, город Барнаул, Центральный район, ул.Аванесова, 132		0101000020E61000008A1EF818ACF1544069FE98D6A6A74A40
15423	5	47	\N	573	70259	\N	53.309032000000002	Алтайский край, город Барнаул, Центральный район, ул.Аванесова, 134		0101000020E610000079AD84EE92F1544070B54E5C8EA74A40
15368	5	47	\N	573	3152	\N	53.394058000000001	Алтайский край, город Барнаул, Ленинский район, Заводской 9-й проезд, 40	Россия, Алтайский край, Барнаул, 9-й Заводской проезд, 40	0101000020E610000054C37E4FACED5440145D177E70B24A40
15389	5	47	\N	573	70231	\N	53.375765000000001	Алтайский край, город Барнаул, Октябрьский район, 80-й Гвардейской дивизии, 41		0101000020E61000006346787B10EF5440A0FD481119B04A40
15341	5	47	\N	573	70251	\N	53.349601	Алтайский край, город Барнаул, Индустриальный район, 50 лет СССР, 10		0101000020E61000001DC87A6AF5EB54400FD3BEB9BFAC4A40
15340	5	47	\N	573	70251	\N	53.345962	Алтайский край, город Барнаул, Индустриальный район, 50 лет СССР, 53		0101000020E61000002159C0046EEB544052D4997B48AC4A40
15320	5	47	\N	573	70258	\N	53.353907	Алтайский край, город Барнаул, Индустриальный район, 42 Краснознаменной бригады, 8		0101000020E610000033164D6727ED5440A96917D34CAD4A40
15319	5	47	\N	573	70258	\N	53.353907	Алтайский край, город Барнаул, Индустриальный район, 42-й Краснознаменной бригады, 8		0101000020E610000033164D6727ED5440A96917D34CAD4A40
15410	5	47	\N	573	70245	\N	53.338984000000004	Алтайский край, город Барнаул, Центральный район, ул.Папанинцев, 115		0101000020E6100000F4DF83D72EF1544003EFE4D363AB4A40
15725	5	47	\N	59365	69844	\N	53.267786999999998	Алтайский край, Баевский район, с.Баево, Терешковой, 25		0101000020E61000009A40118B18315440A0A52BD846A24A40
15702	5	47	\N	59368	69866	\N	51.939929999999997	Алтайский край, Алтайский район, с. Алтайское, Карла Маркса, 51		0101000020E610000034A1496249555540BF4351A04FF84940
15280	5	47	\N	5685	69652	\N	52.483826000000001	Алтайский край, г. Алейск, Олимпийский, пер.Пляжный, 4		0101000020E61000004582A966D6B154402D7AA702EE3D4A40
15274	5	47	\N	5685	70518	\N	52.483826000000001	Алтайский край, г. Алейск, Энергетиков, 5		0101000020E61000004582A966D6B154402D7AA702EE3D4A40
15275	5	47	\N	5685	69786	\N	52.481834736593598	Алтайский край, г. Алейск, Школьная, 23		0101000020E61000001D3A3DEFC6B15440B988EFC4AC3D4A40
15286	5	47	\N	5685	70061	\N	52.483826000000001	Алтайский край, г. Алейск, Ширшова, 14		0101000020E61000004582A966D6B154402D7AA702EE3D4A40
15285	5	47	\N	5685	70061	\N	52.495208676966001	Алтайский край, г. Алейск, Ширшова, 12	Россия, Алтайский край, город Алейск	0101000020E61000001F0E12A27CB15440AAD72D02633F4A40
15282	5	47	\N	5685	69598	\N	52.483826000000001	Алтайский край, г. Алейск, Ульяновский, 94		0101000020E61000004582A966D6B154402D7AA702EE3D4A40
15279	5	47	\N	5685	69598	\N	52.485293175582299	Алтайский край, г. Алейск, Ульяновский, 5		0101000020E610000083328D2617B1544026FDBD141E3E4A40
15277	5	47	\N	5685	69594	\N	52.4865507220129	Алтайский край, г. Алейск, Первомайская, 2		0101000020E610000008E753C72AB25440056B9C4D473E4A40
15256	5	47	\N	5685	69594	\N	52.481481221903501	Алтайский край, г. Алейск, Первомайская, 84		0101000020E61000006B0C3A2174B254409C525E2BA13D4A40
15281	5	47	\N	5685	69919	\N	52.495418223062799	Алтайский край, г. Алейск, Партизанская, 92		0101000020E6100000462234828DB15440C4EC65DB693F4A40
15278	5	47	\N	5685	69596	\N	52.493322716933903	Алтайский край, г. Алейск, Комсомольская, 18		0101000020E6100000BAF605F4C2B15440ABAE4335253F4A40
15283	5	47	\N	5685	70418	\N	52.478435186676002	Алтайский край, г. Алейск, Дорожная, 6а		0101000020E6100000DA756F4562B154408121AB5B3D3D4A40
15903	5	47	\N	5032	70658	\N	54.024399000000003	Алтайский  край, Заринский район, ст. Аламбай, ул. Ленина д.30		0101000020E6100000088F368E587855400E87A5811F034B40
16949	5	47	458	23902	71065	\N	51.899557999999999	Алтайский край, Шипуновский район, с. Эстония, Мира, 23а		0101000020E61000008176871403A35440766D6FB724F34940
16973	5	47	458	24969	70038	\N	52.157983999999999	Алтайский край, Шипуновский район, с. Шипуново, Южный, 35		0101000020E610000002F4FBFECD8E544048A5D8D138144A40
16965	5	47	458	24969	70696	\N	52.212479405125599	Алтайский край, Шипуновский район. с. Шипуново-2, Школьная, 24	Россия, Алтайский край, Шипуновский район	0101000020E6100000D0F23CB83B9154401C0B0A83321B4A40
16972	5	47	458	24969	70592	\N	52.157983999999999	Алтайский край, Шипуновский район. с. Шипуново, Целинная, 25		0101000020E610000002F4FBFECD8E544048A5D8D138144A40
16971	5	47	458	24969	69769	\N	52.157983999999999	Алтайский край, Шипуновский район, с. Шипуново, Совхозный, 37		0101000020E610000002F4FBFECD8E544048A5D8D138144A40
16975	5	47	458	24969	70633	\N	52.158741170301298	Алтайский край, Шипуновский район. с. Шипуново, Мостовая, 13	Россия, Алтайский край, Шипуновский район, поселок Шипуново	0101000020E610000069AB92C83E8E544065C405A051144A40
16974	5	47	458	24969	70096	\N	52.157403288669201	Алтайский край, Шипуновский район, с. Шипуново, Луначарского, 76	Россия, Алтайский край, Шипуновский район, поселок Шипуново	0101000020E61000008ECC237F308E54406AA510C825144A40
16970	5	47	458	24923	70635	\N	52.072535000000002	Алтайский край, Шипуновский район. с. Хлопуново, Мамонтова, 16		0101000020E610000087E123624A8154405E68AED348094A40
16945	5	47	458	23709	71237	\N	52.126900999999997	Алтайский край, Шипуновский район, с. Усть-Порозиха, Центральная, 13		0101000020E61000001B2D077AA8B45440336ABE4A3E104A40
16969	5	47	458	24886	70517	\N	52.570856999999997	Алтайский край, Шипуновский район. с. Урлапово, Фрунзе, 15		0101000020E61000009D9D0C8E92805440A9D898D711494A40
16967	5	47	458	24804	70044	\N	52.074218000000002	Алтайский край, Шипуновский район, с. Тугозвоново, Ползунова, 1		0101000020E61000003D0B42791FA654402463B5F97F094A40
16966	5	47	458	24744	70628	\N	52.128608999999997	Алтайский край, Шипуновский район, с. Самсоново, Октябрьская, 16		0101000020E6100000C6F8307BD9AC5440527C7C4276104A40
16964	5	47	458	24653	69816	\N	52.373745	Алтайский край, Шипуновский район. с. Родино, Мамонтовская, 10		0101000020E610000017A06D35EB7F544092054CE0D62F4A40
16963	5	47	458	40339	9880	\N	52.268219999999999	Алтайский край, Шипуновский район, с. Порожнее, Центральная, 1		0101000020E61000004B5B5CE3337B54400A11700855224A40
16962	5	47	458	24549	70380	\N	52.3077266438656	Алтайский край, Шипуновский район, п. Первомайское, Тарасова, 36	Россия, Алтайский край, Шипуновский район, поселок Первомайское	0101000020E6100000ADC266800B8A5440508C2C9963274A40
16948	5	47	458	23845	71245	\N	51.801242999999999	Алтайский край, Шипуновский район, п. Озерки, Сергея Качусова, 3		0101000020E6100000A4C4AEEDED995440109370218FE64940
16957	5	47	458	24295	71240	\N	52.169955000000002	Алтайский край, Шипуновский район, п. Новый Путь, Весенняя, 15		0101000020E6100000B0FECF61BE9C54405665DF15C1154A40
16968	5	47	458	24843	71059	\N	52.045744999999997	Алтайский край, Шипуновский район, с. Новосельское, Целинная, 1а		0101000020E610000051A1BAB9F8A354404E7ADFF8DA054A40
16961	5	47	458	24503	71064	\N	52.323580924873802	Алтайский край, Шипуновский район, с. Новоивановка, Советская, 38	Россия, Алтайский край, Шипуновский район, поселок Новоивановка	0101000020E6100000B83B6BB75D805440B14D2A1A6B294A40
16960	5	47	458	24444	70629	\N	52.265447999999999	Алтайский край, Шипуновский район, с. Нечунаево, 1-е Черемушки, 15		0101000020E610000061889CBE9E995440F1643733FA214A40
16939	5	47	458	23423	71443	\N	52.076270999999998	Алтайский край, Шипуновский район, п. Метели, Майская, 26		0101000020E61000007E18213CDA9E54400D51853FC3094A40
16958	5	47	458	24336	71244	\N	51.995927510754697	Алтайский край, Шипуновский район, с. Кузнечиха, Новая, 10	Россия, Алтайский край, Шипуновский район, поселок Кузнечиха	0101000020E6100000336ABE4A3E9F5440D99596917AFF4940
16956	5	47	458	24238	70478	\N	52.192016000000002	Алтайский край, Шипуновский район, с. Красный Яр, Садовая, 40		0101000020E6100000C0AF9124089754408527F4FA93184A40
16944	5	47	458	23666	70881	\N	52.058720999999998	Алтайский край, Шипуновский район, с. Кособоково, Центральная, 6а		0101000020E6100000C24B70EA03B75440514B732B84074A40
16951	5	47	458	23995	71451	\N	52.410879000000001	Алтайский край, Шипуновский район, с. Коробейниково, Школьная, 3		0101000020E6100000F77475C7626C54407DCEDDAE97344A40
16955	5	47	458	24196	70469	\N	51.924447999999998	Алтайский край, Шипуновский район, с. Комариха, Дубинина, 16		0101000020E6100000EA059FE6E4AD5440226DE34F54F64940
16959	5	47	458	24401	71061	\N	51.949584000000002	Алтайский край, Шипуновский район, п. Качусово, Школьная, 28		0101000020E6100000F0DE5163429D54400667F0F78BF94940
16954	5	47	458	24144	71242	\N	51.953397000000002	Алтайский край, Шипуновский район, с. Ильинка, Школьный, 4		0101000020E610000092EC116A86975440618DB3E908FA4940
16950	5	47	458	23944	70588	\N	52.485329	Алтайский край, Шипуновский район, с. Зеркалы, Центральная, 3		0101000020E6100000DD79E2395B7554407366BB421F3E4A40
15860	5	47	458	2677	69972	\N	51.907221	Алтайский край, с.Ельцовка, Садовая, ул.им.Рыжакова, д.24 (ул.Садовая, д.32)		0101000020E6100000E353008C67995440499F56D11FF44940
16947	5	47	458	2677	70589	\N	51.907221	Алтайский край, Шипуновский район, с. Ельцовка, Советская, 42		0101000020E6100000E353008C67995440499F56D11FF44940
16946	5	47	458	23758	70036	\N	52.076104999999998	Алтайский край, Шипуновский район, с. Горьковское, Октябрьская, 40		0101000020E61000006BF294D574885440F20703CFBD094A40
16406	5	47	458	29253	71382	\N	51.970700000000001	Алтайский край, Поспелихинский район, п.Гавриловский, ул.Молодёжная, д.13		0101000020E610000000FF942A51895440151DC9E53FFC4940
16943	5	47	458	23627	71295	\N	52.065587000000001	Алтайский край, Шипуновский район, п. Воробьево, Центральная, 27		0101000020E610000048FB1F60ADBE54407905A22765084A40
16941	5	47	458	23535	70372	\N	52.137039999999999	Алтайский край, Шипуновский район, с. Быково, Главный, 3		0101000020E61000002657B1F84D8B5440361FD7868A114A40
16940	5	47	458	23473	70717	\N	52.412813	Алтайский край, Шипуновский район, с. Бобровка, Молодежная, 26		0101000020E610000010CD3CB9A68854408C2E6F0ED7344A40
16953	5	47	458	24096	71452	\N	52.037480000000002	Алтайский край, Шипуновский район, с.Бестужево, Набережная, 28а		0101000020E6100000E7A90EB9199E544086200725CC044A40
16938	5	47	458	23378	70373	\N	52.115178	Алтайский край, Шипуновский район, с. Белоглазово, Комарова, 30		0101000020E6100000F23FF9BB77A45440FE9B1727BE0E4A40
16937	5	47	458	23338	71239	\N	52.216526999999999	Алтайский край, Шипуновский район, с. Баталово, Рукина, 16		0101000020E6100000A9DC442DCD775440BAD91F28B71B4A40
16952	5	47	458	24047	71438	\N	52.431173000000001	Алтайский край, Шипуновский район, п. Андреевка, Центральная, 24		0101000020E6100000728A8EE4F26E544088F546AD30374A40
16922	5	47	1700	22635	70190	\N	53.413450430260902	Алтайский край, Шелаболихинский район, с.Шелаболиха, Пушкина, 37	Россия, Алтайский край, Шелаболихинский район, поселок Шелаболиха	0101000020E61000006493FC885FA75440FE43FAEDEBB44A40
16921	5	47	1700	22635	70187	\N	53.413502000000001	Алтайский край, Шелаболихинский район, с. Шелаболиха, Ленина, 27		0101000020E6100000890B40A374A75440516A2FA2EDB44A40
16936	5	47	1700	23282	71235	\N	53.499631000000001	Алтайский край, Шелаболихинский район, с. Чайкино, Набережная, 4		0101000020E6100000B534B74258785440AD889AE8F3BF4A40
16932	5	47	1700	23102	71448	\N	53.496391000000003	Алтайский край, Шелаболихинский район, с. Селезнево, Советская, 20		0101000020E6100000973B33C1708A5440AE8383BD89BF4A40
16935	5	47	1700	59476	71523	\N	53.492696858391803	Алтайский край, Шелаболихинский район, пос.Подгорный, Школьная, 38		0101000020E61000000A82C7B7776D54402DEBFEB110BF4A40
16931	5	47	1700	23067	71441	\N	53.481217999999998	Алтайский край, Шелаболихинский район, с. Омутское, Цветочная, 16а		0101000020E6100000D61EF642018E54408E1F2A8D98BD4A40
16923	5	47	1700	59400	70564	\N	53.465048000000003	Алтайский край, Шелаболихинский район,с. Новообинцево, Садовая, 40	Россия, Алтайский край, Шелаболихинский район	0101000020E610000085EB51B81E8B5440FD885FB186BB4A40
16929	5	47	1700	22969	71321	\N	53.290449000000002	Алтайский край, Шелаболихинский район, с. Макарово, ул.Орловская, д.11		0101000020E61000009301A08A1B7F5440F513CE6E2DA54A40
16925	5	47	1700	22787	70621	\N	53.442796000000001	Алтайский край, Шелаболихинский район, с. Кучук, Михайлова, 40		0101000020E6100000AFEDED96E49D54405A66118AADB84A40
16934	5	47	1700	23194	70465	\N	53.461333000000003	Алтайский край, Шелаболихинский район, с. Крутишка, Совхозная, 2		0101000020E6100000921FF12BD674544065C8B1F50CBB4A40
16933	5	47	1700	23147	69802	\N	53.528539000000002	Алтайский край, Шелаболихинский район, с. Киприно, Советская, 30		0101000020E6100000556CCCEB888454408DD47B2AA7C34A40
16924	5	47	1700	59449	71454	\N	53.465048000000003	Алтайский край, Шелаболихинский район, с. Иня, Нагорная, 7	Россия, Алтайский край, Шелаболихинский район	0101000020E610000085EB51B81E8B5440FD885FB186BB4A40
16930	5	47	1700	23011	70284	\N	53.453553999999997	Алтайский край, Шелаболихинский район, с. Ильинка, Школьная, 19		0101000020E61000006475ABE7A4945440287CB60E0EBA4A40
16928	5	47	1700	22916	71215	\N	53.374856999999999	Алтайский край, Шелаболихинский район, с. Ивановка, пер. Клубный, 5		0101000020E6100000D55E44DB318B54409DD66D50FBAF4A40
16927	5	47	1700	22879	70598	\N	53.353611000000001	Алтайский край, Шелаболихинский район, с. Верх-Кучук, Центральная, 32		0101000020E61000006DAD2F12DA8E5440C040102043AD4A40
16926	5	47	1700	22826	71440	\N	53.426489243887502	Алтайский край, Шелаболихинский район, с. Батурово, Новая, 16	Россия, Алтайский край, Шелаболихинский район, поселок Батурово	0101000020E61000006AF816D68D995440478D093197B64A40
16911	5	47	1664	59417	70890	\N	51.226929948461098	Алтайский край, Чарышский район, с.Первомайское, ул.Кузнечная, д.8	Россия, Алтайский край, Чарышский район	0101000020E610000027DA5548F9EF54409B3DD00A0C9D4940
16908	5	47	1664	22020	70876	\N	51.472738999999997	Алтайский край, Чарышский район, с.Щебнюха, ул.Центральная, д.7		0101000020E61000005111A7936CDA5440994528B682BC4940
16903	5	47	1664	21788	70037	\N	51.402310401347499	Алтайский край, Чарышский район, с.Чарышское, ул.Центральная, д.31	Россия, Алтайский край, Чарышский район, поселок Чарышское	0101000020E6100000BD72BD6DA6E35440486DE2E47EB34940
16915	5	47	1664	22352	70879	\N	51.625194999999998	Алтайский край, Чарышский район, с.Чайное, ул.Сосновская, д.16		0101000020E6100000F5D555815AE75440B54FC76306D04940
16901	5	47	1664	21680	71433	\N	51.413732000000003	Алтайский край, Чарышский район, с.Усть-Тулатинка, ул.Центральная, д.46		0101000020E610000098C3EE3B86D9544083A7902BF5B44940
16920	5	47	1664	40342	9883	\N	51.698805	Алтайский край, Чарышский район, с.Усть-Пихтовка, ул.Садовая, д.14		0101000020E6100000F0366F9C14E4544001A4367172D94940
16899	5	47	1664	21591	70442	\N	51.317269000000003	Алтайский край, Чарышский район, с.Тулата, ул.Центральная, д.24		0101000020E610000011A8FE4124DB54406F8445459CA84940
16913	5	47	1664	22258	71432	\N	51.558430999999999	Алтайский край, Чарышский район, с.Сосновка, ул.Лиственная, д.12		0101000020E6100000124E0B5EF4E654404A09C1AA7AC74940
16893	5	47	1664	21305	70436	\N	51.203516999999998	Алтайский край, Чарышский район, с.Сентелек, ул.Центральная, д.48		0101000020E6100000F54883DBDAEF54400B9755D80C9A4940
16895	5	47	1664	21427	71431	\N	51.13382	Алтайский край, Чарышский район, с.Покровка, ул.Рабочая, д.2		0101000020E61000007E384888F2EA54407EC6850321914940
16909	5	47	1664	22088	71063	\N	51.514195000000001	Алтайский край, Чарышский район, с.Озерки, ул.Коммунистическая, д.24		0101000020E6100000C4094CA775DB544024624A24D1C14940
16912	5	47	1664	22237	71066	\N	51.615214000000002	Алтайский край, Чарышский район, с.Маяк, ул.Советская, д.5		0101000020E6100000BB61DBA2CCDB54404B051555BFCE4940
16894	5	47	1664	21363	71427	\N	51.255209000000001	Алтайский край, Чарышский район, с.Машенка, ул.Мараловодов, д.5/1		0101000020E6100000DFC5FB71FBF654408B5242B0AAA04940
16918	5	47	1664	22484	71439	\N	51.731727999999997	Алтайский край, Чарышский район, с.Маральи Рожки, ул.Луговая, д.59		0101000020E6100000C408E1D1C6DF5440A3C85A43A9DD4940
16916	5	47	1664	22389	70445	\N	51.697862000000001	Алтайский край, Чарышский район, с.Маралиха, ул.Центральная, д.59		0101000020E61000006072A3C85AD75440828FC18A53D94940
94922	5	47	1664	21835	70461	\N	51.489325000000001	Алтайский край, Чарышский район, с.Малый Бащелак, ул.Центральная, 43		0101000020E6100000567E198C11F45440BF0E9C33A2BE4940
16919	5	47	1664	22532	71435	\N	51.772870778677003	Алтайский край, Чарышский район, с.Малая Маралиха, ул.Лесная, д.11, кв.2	Россия, Алтайский край, Чарышский район, поселок Малая Маралиха	0101000020E6100000B85A272EC7E654406F83DA6FEDE24940
16896	5	47	1664	21438	70900	\N	51.238492000000001	Алтайский край, Чарышский район, с.Майорка, ул.Центральная, д.15		0101000020E610000025E82FF488E05440C72DE6E7869E4940
16902	5	47	1664	21754	70035	\N	51.375962000000001	Алтайский край, Чарышский район, с.Красный Партизан, ул.Центральная, д.30		0101000020E6100000007157AF22E55440F644D7851FB04940
16914	5	47	1664	22312	71316	\N	51.593727999999999	Алтайский край, Чарышский район,+E2 Чарышский район, с.Красные Орлы, ул.Речная, д.29		0101000020E61000009FE74F1BD5DF5440185C7347FFCB4940
16898	5	47	1664	21536	70873	\N	51.337772000000001	Алтайский край, Чарышский район, с.Комендантка, ул.Центральная, д.32		0101000020E6100000C2340C1F11E6544094C0E61C3CAB4940
16905	5	47	1664	21909	71060	\N	51.540211999999997	Алтайский край, Чарышский район, с.Ивановка, ул.Центральная, д.15		0101000020E61000008D63247B84F454401074B4AA25C54940
16900	5	47	1664	21658	70882	\N	51.384219999999999	Алтайский край, Чарышский район, с.Долинское, ул.Центральная, д.26		0101000020E6100000A94BC63192DB54400C3CF71E2EB14940
16906	5	47	1664	21929	70980	\N	51.406307717417597	Алтайский край, Чарышский район, Чарышский район, с.Боровлянка, ул.Центральная, д.24/2	Россия, Алтайский край, Чарышский район, поселок Боровлянка	0101000020E6100000B610E4A084F05440350D8AE601B44940
16907	5	47	1664	22004	70874	\N	51.535293000000003	Алтайский край, Чарышский район, с.Большой Бащелак, ул.Подгорная, д.1		0101000020E61000007592AD2EA7FD54408D63247B84C44940
16751	5	47	1664	59457	71469	\N	51.567329074262503	Алтайский край, Троицкий район, с. Большая Речка, пер. Клубный, 7А	Россия, Алтайский край, Чарышский район	0101000020E610000031ED9BFBAB0155404489963C9EC84940
16897	5	47	1664	21515	70438	\N	51.274669000000003	Алтайский край, Чарышский район, с.Березовка, ул.Центральная, д.27		0101000020E6100000147B681F2BE75440CE1C925A28A34940
16910	5	47	1664	22144	71208	\N	51.57114	Алтайский край, Чарышский район, с.Алексеевка, ул.Центральная, д.19		0101000020E61000003B8E1F2A8DD95440FEB7921D1BC94940
16892	5	47	1664	21280	71056	\N	51.297134	Алтайский край, Чарышский район, с.Аба, ул.Набережная, д.4а		0101000020E6100000FD67CD8FBFF35440CC43A67C08A64940
16877	5	47	1615	20523	70647	\N	53.114373000000001	Алтайский край, Целинный район,  Целинный район, с.Шалап, ул.Ленина, д.4а		0101000020E61000007C60C77F81755540D04543C6A38E4A40
16887	5	47	1615	21057	70923	\N	53.080606000000003	Алтайский край, Целинный район, с.Чесноково, ул.Первомайская, д.6		0101000020E6100000CB49287D2186554042EE224C518A4A40
16871	5	47	1615	20138	70033	\N	53.076836	Алтайский край, Целинный район, с.Целинное, ул.Советская, д.25		0101000020E61000000113B875376A5540E69315C3D5894A40
16872	5	47	1615	20138	70194	\N	53.076836	Алтайский край, Целинный район, с.Целинное, ул.Победы, д.5		0101000020E61000000113B875376A5540E69315C3D5894A40
16873	5	47	1615	20138	69803	\N	53.076836	Алтайский край, Целинный район, с.Целинное, ул.Ленина, д.52		0101000020E61000000113B875376A5540E69315C3D5894A40
16875	5	47	1615	20382	71204	\N	53.163910769111098	Алтайский край, Целинный район, с.Хомутино, ул.Зеленая, д.21	Россия, Алтайский край, Целинный район, поселок Хомутино	0101000020E610000042D13C80455A5540323A2009FB944A40
16889	5	47	1615	21141	70530	\N	52.723520999999998	Алтайский край, Целинный район, с.Сухая-Чемровка, ул.Молодежная, д.6		0101000020E6100000FF1F274C185955400F7C0C569C5C4A40
16890	5	47	1615	21191	71437	\N	52.777287999999999	Алтайский край, Целинный район, с.Сверчково, ул.Советская, д.3		0101000020E61000002E1F49490F57554060C9552C7E634A40
16885	5	47	1615	59453	71461	\N	53.005281503242401	Алтайский край, Целинный район, с.Поповичево, ул.Центральная, д.22	Россия, Алтайский край, Целинный район, поселок Поповичи	0101000020E6100000C1E3DBBB06915540F5A0A014AD804A40
16886	5	47	1615	20980	70595	\N	53.120317999999997	Алтайский край, Целинный район, с.Победа, ул.Ленина, д.5		0101000020E610000098C0ADBB79825540608F8994668F4A40
16883	5	47	1615	20815	70617	\N	52.929091999999997	Алтайский край, Целинный район, с.Овсянниково, ул.Школьная, д.19		0101000020E610000082C476F700865540D47C957CEC764A40
16882	5	47	1615	20773	70427	\N	52.871616000000003	Алтайский край, Целинный район, с.Марушка, ул.Советская, д.18		0101000020E6100000E08096AE605F5540CE55F31C916F4A40
16884	5	47	1615	20876	71049	\N	53.050747999999999	Алтайский край, Целинный район, с.Локоть, ул.Лесная, д.10		0101000020E61000009E5F94A0BF8D5540302B14E97E864A40
16888	5	47	1615	21069	70402	\N	52.838735	Алтайский край, Целинный район, с.Ложкино, ул.Советская, д.22а		0101000020E6100000CBF3E0EEAC5C55405A8121AB5B6B4A40
16879	5	47	1615	20622	70620	\N	53.188336	Алтайский край, Целинный район, с.Еланда, ул.Коммунистическая, д.14		0101000020E6100000B82231410D6F55406954E0641B984A40
16880	5	47	1615	20673	70618	\N	52.900627	Алтайский край, Целинный район, с.Дружба, ул.Центральная, д.21		0101000020E6100000C64E78094E6155408272DBBE47734A40
16878	5	47	1615	20541	69776	\N	52.791818999999997	Алтайский край, Целинный район, с.Воеводское, пер.Магистральный, д.6		0101000020E6100000DB6E826F9A665540FBAC32535A654A40
16891	5	47	1615	21220	71436	\N	52.995612999999999	Алтайский край, Целинный район, с.Верх-Яминское, ул.Бийская, д.5		0101000020E6100000292499D53B735540793C2D3F707F4A40
16874	5	47	1615	20309	70371	\N	52.916572000000002	Алтайский край, Целинный район, с.Верх-Марушка, ул.Центральная, д.13		0101000020E6100000AEF36F97FD675540F436363B52754A40
16876	5	47	1615	20450	69805	\N	52.888066999999999	Алтайский край, Целинный район, с.Бочкари, ул.Пушкина, д.1		0101000020E61000001A51DA1B7C71554013D4F02DAC714A40
16852	5	47	1581	19035	70615	\N	53.618172999999999	Алтайский край, Хабарский район, с. Хабары, Южная, 2А		0101000020E610000071E6577380E253409622F94A20CF4A40
16791	5	47	1411	16017	71163	\N	51.165436999999997	Алтайский край, Угловский район, с.Шадруха, Кооперативная, 18		0101000020E6100000855E7F129FFD53403046240A2D954940
16853	5	47	1581	19035	69767	\N	53.626692529024602	Алтайский край, Хабарский район, с. Хабары, Ленина, 93	Россия, Алтайский край, Хабарский район, поселок Хабары	0101000020E6100000FCE4284014E25340EAD0E97937D04A40
16850	5	47	1581	19035	69767	\N	53.625316905212998	Алтайский край, Хабарский район, с.Хабары, Ленина, 57	Россия, Алтайский край, Хабарский район, поселок Хабары	0101000020E61000009A779CA223E25340015130630AD04A40
16851	5	47	1581	19035	70183	\N	53.618172999999999	Алтайский край, Хабарский район, с. Хабары, Кайгородова, 1		0101000020E610000071E6577380E253409622F94A20CF4A40
16854	5	47	1581	19226	70424	\N	53.601622999999996	Алтайский край, Хабарский район, с.Утянка, Гагарина, 14А		0101000020E6100000CF2D742502DD5340BDC282FB01CD4A40
16869	5	47	1581	20036	70872	\N	53.665517270482802	Алтайский край, Хабарский район, п. Усть-Курья, Молодежная, 11А	Россия, Алтайский край, Хабарский район, поселок Усть-Курья	0101000020E61000000BCF4BC5C6EE53404DF73AA92FD54A40
16858	5	47	1581	19433	71424	\N	53.548215999999996	Алтайский край, Хабарский район, с. Топольное, Ломоносова, 33		0101000020E6100000B58B69A67BB853406C921FF12BC64A40
16861	5	47	1581	19602	70405	\N	53.327798999999999	Алтайский край, Хабарский район, с. Свердловское, пер. Школьный, 17		0101000020E6100000020EA14ACDEA5340AC545051F5A94A40
16859	5	47	1581	19470	71422	\N	53.501403947986297	Алтайский край, Хабарский район, п. Рассвет, Школьная, 13	Россия, Алтайский край, Хабарский район, поселок Рассвет	0101000020E61000000342EBE1CBD45340B30A9B012EC04A40
16865	5	47	1581	19788	71047	\N	53.467246000000003	Алтайский край, Хабарский район, п. Поперечное, Центральная, 15, 2		0101000020E61000001AFD683865F55340EA9788B7CEBB4A40
16262	5	47	1581	22634	69941	\N	53.383774000000003	Алтайский край, Немецкий национальный район, с.Полевое, Молодежная, 66А		0101000020E61000006AFAEC80EBCE53400E87A5811FB14A40
16868	5	47	1581	19948	71051	\N	53.633617000000001	Алтайский край, Хабарский район, с. Плесо-Курья, Центральная, 4А		0101000020E61000005CAB3DEC85FA53404698A25C1AD14A40
16857	5	47	1581	19373	71052	\N	53.546219999999998	Алтайский край, Хабарский район, п. Пионер Труда, Черемушки, 20		0101000020E6100000ECD973999AC55340E7357689EAC54A40
16261	5	47	1581	22574	69788	\N	53.318807	Алтайский край, Немецкий национальный район, с.Орлово, Ленина, 40		0101000020E610000055F833BC59CF5340315EF3AACEA84A40
16864	5	47	1581	19749	71426	\N	53.514155000000002	Алтайский край, Хабарский район, п. Новоплотава, Школьная, 15А		0101000020E610000048F949B54FF053409609BFD4CFC14A40
16855	5	47	1581	19290	69796	\N	53.5638061230459	Алтайский край, Хабарский район, с. Новоильинка, Славгородская, 33А	Россия, Алтайский край, Хабарский район, поселок Новоильинка	0101000020E61000002BF86D88F1D05340F0A485CB2AC84A40
16863	5	47	1581	19706	70429	\N	53.475499999999997	Алтайский край, Хабарский район, с. Мичуринское, 50 лет Октября, 10		0101000020E610000046D3D9C9E0EE5340BE9F1A2FDDBC4A40
16860	5	47	1581	19540	70370	\N	53.444099000000001	Алтайский край, Хабарский район, с. Мартовка, Ленина, 66		0101000020E61000007EA99F3715E15340D9976C3CD8B84A40
16862	5	47	1581	19633	71201	\N	53.432099999999998	Алтайский край, Хабарский район, п. Малопавловка, Центральная, 37		0101000020E610000090F63FC05AE85340014D840D4FB74A40
16258	5	47	1581	22432	70807	\N	53.244359000000003	Алтайский край, Немецкий национальный район, пос.Красноармейский, Мира, 56		0101000020E6100000DA56B3CEF8CD5340DCBDDC27479F4A40
16870	5	47	1581	20060	69798	\N	53.752160000000003	Алтайский край, Хабарский район, с. Коротояк, Вокзальная, 14Б		0101000020E610000043C5387F13EB534000AE64C746E04A40
16866	5	47	1581	59408	70729	\N	53.4754226053617	Алтайский край, Хабарский район, с. Зятькова Речка, Юбилейная, 16	Россия, Алтайский край, Хабарский район, поселок Зятькова Речка	0101000020E6100000F47002D369FC534013622EA9DABC4A40
16867	5	47	1581	19894	71421	\N	53.579971999999998	Алтайский край, Хабарский район, п. Васильевка, пер. Южный, 5		0101000020E610000066BB421F2CF55340404CC2853CCA4A40
16856	5	47	1581	19347	71153	\N	53.465434000000002	Алтайский край, Хабарский район, п. Богатское, Коваленко, 48		0101000020E61000000AF5F411F8C253402639605793BB4A40
16267	5	47	1581	59430	\N	\N	53.309455387830603	Алтайский край, Немецкий национальный район, с.Александровка, Здание Клуб, 44	Россия, Алтайский край, Хабарский район, поселок Александровка	0101000020E6100000098D60E3FACA5340B64AB0389CA74A40
16840	5	47	1523	59448	71453	\N	52.298614999999998	Алтайский край, Усть-Пристанский район, с.Коловый Мыс, ул.Центральная, д.13		0101000020E6100000307F85CC95EA54402A8C2D0439264A40
16848	5	47	1523	18900	71279	\N	52.368085472763099	Алтайский край, Усть-Пристанский район, с.Чеканиха, ул.Центральная, д.7	Россия, Алтайский край, Усть-Пристанский район, поселок Чеканиха	0101000020E6100000F25CDF8783F65440F792C6681D2F4A40
16836	5	47	1523	59363	69818	\N	52.395784864507398	Алтайский край, Усть-Пристанский район, с.Усть-Чарышская Пристань, ул.Пятилетка, д.18	Россия, Алтайский край, Усть-Пристанский район, поселок Усть-Чарышская Пристань	0101000020E6100000E60297C79AEA5440A99F3715A9324A40
16835	5	47	1523	59363	70214	\N	52.389454302926701	Алтайский край, Усть-Пристанский район, с.Усть-Чарышская Пристань, ул.Пушкина, д.13		0101000020E6100000A79201A08AEA5440F0A5F0A0D9314A40
16837	5	47	1523	59363	70193	\N	52.388824140228998	Алтайский край, Усть-Пристанский район, с.Усть-Чарышская Пристань, ул.Краснооктябрьская, д.35	Россия, Алтайский край, Усть-Пристанский район, поселок Усть-Чарышская Пристань	0101000020E6100000F5BA4560ACEA544030F31DFCC4314A40
16838	5	47	1523	18396	71420	\N	52.334498000000004	Алтайский край, Усть-Пристанский район, с.Усть-Чарыш, ул.Молодежная, д.12		0101000020E6100000139CFA40F2EF5440E94999D4D02A4A40
16842	5	47	1523	18577	71423	\N	52.22343	Алтайский край, Усть-Пристанский район, с.Усть-Журавлиха, ул.Комсомольская, д.1д		0101000020E610000097900F7A36D95440FF78AF5A991C4A40
16834	5	47	1523	18172	71194	\N	52.374822000000002	Алтайский край, Усть-Пристанский район, с.Троицкое, ул.Комсомольская, д.17		0101000020E6100000D28BDAFD2AE1544021E9D32AFA2F4A40
16833	5	47	1523	18126	71184	\N	52.4179175781723	Алтайский край, Усть-Пристанский район, с.Романово, ул.Пушкина, д.1	Россия, Алтайский край, Усть-Пристанский район, поселок Романово	0101000020E610000032CB9E0436D75440723447567E354A40
16843	5	47	1523	18664	70368	\N	52.301434999999998	Алтайский край, Усть-Пристанский район, с.Нижняя Гусиха, ул.Кирова, д.17		0101000020E6100000680932022AD85440546F0D6C95264A40
16846	5	47	1523	18824	70586	\N	52.217796	Алтайский край, Усть-Пристанский район, с.Нижне-Озерное, ул.Юбилейная, д.18		0101000020E6100000B6696CAF05F054408D9944BDE01B4A40
16841	5	47	1523	18567	70419	\N	52.226061000000001	Алтайский край, Усть-Пристанский район, с.Красноярка, ул.50 лет Октября, д.1б		0101000020E61000008849B89047DE544056F31C91EF1C4A40
16847	5	47	1523	18885	71214	\N	52.11598	Алтайский край, Усть-Пристанский район, с.Краснодарское, ул.Комсомольская, д.7		0101000020E6100000FF23D3A1D3F25440BB7EC16ED80E4A40
16844	5	47	1523	18718	69765	\N	52.190603000000003	Алтайский край, Усть-Пристанский район, с.Коробейниково, ул.Комсомольская, д.33а		0101000020E61000007A36AB3E57ED54407FC2D9AD65184A40
16849	5	47	1523	18965	71071	\N	52.538716999999998	Алтайский край, Усть-Пристанский район, с.Клепиково, ул.Советская, д.33		0101000020E6100000C18F6AD8EFF054404D66BCADF4444A40
16839	5	47	1523	18422	70413	\N	52.229106000000002	Алтайский край, Усть-Пристанский район, с.Елбанка, ул.Новая, д.57		0101000020E6100000865AD3BCE3E65440A0A86C58531D4A40
16831	5	47	1523	18041	70590	\N	52.524253999999999	Алтайский край, Усть-Пристанский район, с.Вяткино, ул.Целинная, д.6		0101000020E61000007288B83995E754400A664CC11A434A40
16832	5	47	1523	18090	70597	\N	52.440818999999998	Алтайский край, Усть-Пристанский район, с.Брусенцево, ул.Пушкина, д.49		0101000020E6100000849B8C2AC3DC54404B3ACAC16C384A40
16830	5	47	1523	17976	70870	\N	52.624316	Алтайский край, Усть-Пристанский район, с.Белово, ул.Школьная, д.25		0101000020E610000088307E1AF7E754404D2F3196E94F4A40
16822	5	47	1466	17591	71169	\N	52.053533000000002	Алтайский край, Усть-Калманский район, с.Усть-Камышенка, ул.Центральная, д.5		0101000020E6100000BA30D28BDACC5440DE205A2BDA064A40
16807	5	47	1466	16734	70034	\N	52.120027999999998	Алтайский край, Усть-Калманский район, с.Усть-Калманка, ул.Партизанская, 30		0101000020E6100000F73C7FDAA8D35440594DD7135D0F4A40
16805	5	47	1466	16734	70041	\N	52.120027999999998	Алтайский край, Усть-Калманский район, с.Усть-Калманка, ул.Ленина, д.24		0101000020E6100000F73C7FDAA8D35440594DD7135D0F4A40
16806	5	47	1466	16734	70203	\N	52.120027999999998	Алтайский край, Усть-Калманский район, с.Усть-Калманка, ул.Горького, д.53		0101000020E6100000F73C7FDAA8D35440594DD7135D0F4A40
16819	5	47	1466	17444	70868	\N	52.021794	Алтайский край, Усть-Калманский район, с.Усть-Ермилиха, ул.Центральная, д.2а		0101000020E610000002F2255470B85440E09F5225CA024A40
16813	5	47	1466	17138	71425	\N	52.158729999999998	Алтайский край, Усть-Калманский район, пос.Степной, ул.Овражная, д.8		0101000020E610000094A46B26DFCB54407172BF4351144A40
16828	5	47	1466	17892	70869	\N	51.883417000000001	Алтайский край, Усть-Калманский район, с.Слюдянка, ул.Центральная, д.22		0101000020E6100000008BFCFA21EA54407FDDE9CE13F14940
16810	5	47	1466	16986	71046	\N	52.160508999999998	Алтайский край, Усть-Калманский район, пос.Приозерный, ул.Школьная, д.17		0101000020E610000098512CB7B4DF544059DB148F8B144A40
16814	5	47	1466	17176	71419	\N	52.072268999999999	Алтайский край, Усть-Калманский район, Пономарёво село, пер.Школьный, 3		0101000020E6100000276C3F19E3C95440DFC14F1C40094A40
16825	5	47	1466	17746	70583	\N	51.915627000000001	Алтайский край, Усть-Калманский район, с.Огни, ул.Партизанская, д.40		0101000020E6100000BCCADAA678E25440D42AFA4333F54940
16808	5	47	1466	16890	70878	\N	52.175407	Алтайский край, Усть-Калманский район, пос.Новый Чарыш, ул.Школьная, д.4		0101000020E61000005C59A2B3CCD75440A73E90BC73164A40
16824	5	47	1466	59450	71456	\N	51.840030249280403	Алтайский край, Усть-Калманский район, с.Ново-Троенка, ул.Центральная, д.31	Россия, Алтайский край, Усть-Калманский район, поселок Новотроенка	0101000020E6100000F6EE8FF7AAD4544056D4601A86EB4940
16823	5	47	1466	17635	70582	\N	51.952292999999997	Алтайский край, Усть-Калманский район, с.Новокалманка, ул.Школьная, д.31		0101000020E6100000DFFE5C3464D75440D89AADBCE4F94940
16820	5	47	1466	17473	70584	\N	51.944082999999999	Алтайский край,Усть-Калманский район, с.Новобураново, ул.Октябрьская, д.8		0101000020E61000002463B5F97FC25440D3DA34B6D7F84940
16827	5	47	1466	17796	70362	\N	51.957244000000003	Алтайский край, Усть-Калманский район,с. Михайловка, ул.Ленина, д.75б		0101000020E61000007F30F0DC7BF354406825ADF886FA4940
16826	5	47	1466	17796	70362	\N	51.957244000000003	Алтайский край, Усть-Калманский район, с.Михайловка, ул.Ленина, д.75б		0101000020E61000007F30F0DC7BF354406825ADF886FA4940
16816	5	47	1466	17287	70616	\N	52.040948	Алтайский край, Усть-Калманский район, с.Кабаново, ул.Ползунова, д.21		0101000020E61000003A9160AA99C65440166BB8C83D054A40
16815	5	47	1466	17239	70889	\N	52.131422999999998	Алтайский край, Усть-Калманский район, пос.Западный, ул.Центральная, д.15		0101000020E6100000622EA9DA6EC354409A780778D2104A40
16821	5	47	1466	17544	71053	\N	51.955637547931701	Алтайский край, Усть-Калманский район, Ельцовка село, ул.Центральная, д.33	Россия, Алтайский край, Усть-Калманский район, поселок Ельцовка	0101000020E6100000DC114E0B5ECC54404D68925852FA4940
16812	5	47	1466	17084	71272	\N	52.237775717073802	Алтайский край, Усть-Калманский район, пос.Дружба, ул.Центральная, 4	Россия, Алтайский край, Усть-Калманский район, поселок Дружба	0101000020E6100000B3D30FEA22D3544008E3A7716F1E4A40
16809	5	47	1466	16966	70867	\N	52.052258999999999	Алтайский край, Усть-Калманский район, пос.Восточный, ул.Школьная, д.8		0101000020E6100000EF586C938AE05440F9F5436CB0064A40
16829	5	47	1466	17963	71417	\N	51.789897000000003	Алтайский край, Усть-Калманский район, с.Верх-Слюдянка, ул.Большевистская, д.10		0101000020E6100000BABF7ADCB7F15440B11A4B581BE54940
16817	5	47	1466	17331	71414	\N	52.020440999999998	Алтайский край, Усть-Калманский район, с.Бураново, ул.Нагорная, д.4		0101000020E61000009E279EB305BC5440AF3F89CF9D024A40
16804	5	47	1411	16715	70360	\N	50.938108	Алтайский край, Угловский район, с.Топольное, Кооперативная, 50		0101000020E6100000C16F438CD7065440D80E46EC13784940
16783	5	47	1411	15636	70608	\N	51.686639999999997	Алтайский край, Угловский район, с.Симоново, Центральная, 23		0101000020E61000002497FF907E1854400E10CCD1E3D74940
16789	5	47	1411	15945	70585	\N	51.398007	Алтайский край, Угловский район, с.Павловка, Кооперативная, 42		0101000020E6100000B6494563EDF253401F4AB4E4F1B24940
16788	5	47	1411	59458	71470	\N	51.550888317314701	Алтайский край, Угловский район, пос.Озерно-Кузнецовский лесхоз, Центральная, 2-Б	Россия, Алтайский край, Угловский район, поселок Озерно-Кузнецовский	0101000020E6100000E294B9F94611544022E17B7F83C64940
16787	5	47	1411	15861	69800	\N	51.503337000000002	Алтайский край, Угловский район, с.Озерно-Кузнецово, Советская, 47		0101000020E61000006F641EF983165440F2EEC8586DC04940
16797	5	47	1411	16329	71416	\N	51.447183000000003	Алтайский край, Угловский район, пос.Новоугловский, Школьная, 16		0101000020E6100000DB8651103C125440E129E44A3DB94940
16800	5	47	1411	16481	71165	\N	51.030002419966898	Алтайский край, Угловский район, с.Наумовка, С.Платонова, 32	Россия, Алтайский край, Угловский район, поселок Наумовка	0101000020E61000001B4B581B631C54404568041BD7834940
16792	5	47	1411	16093	70613	\N	51.426302999999997	Алтайский край, Угловский район, пос.Мирный, Комсомольская, 16		0101000020E6100000E4BD6A65C2FD5340E597C11891B64940
16794	5	47	1411	16172	70933	\N	51.291784	Алтайский край, Угловский район, с.Ляпуново, Школьная, 18		0101000020E61000002FA52E19C70854407FBF982D59A54940
16802	5	47	1411	16572	70358	\N	51.057744	Алтайский край, Угловский район, с.Лаптев-Лог, Кооперативная, 52		0101000020E61000007DEBC37AA30B544026C5C72764874940
16799	5	47	1411	32500	70986	\N	51.352539999999998	Алтайский край, Угловский район, с.Куйбышево, Центральная, 72		0101000020E6100000259012BBB62454401344DD0720AD4940
16798	5	47	1411	16393	70385	\N	51.287323000000001	Алтайский край, Угловский район, с.Круглое, Ленина, 8		0101000020E6100000EC866D8B321C5440BE310400C7A44940
16785	5	47	1411	15742	71415	\N	51.694685	Алтайский край, Угловский район, с.Кормиха, Центральная, 40		0101000020E6100000E62329E961225440C9022670EBD84940
16784	5	47	1411	15707	70942	\N	51.779243999999998	Алтайский край, Угловский район, с.Валовой Кордон, Центральная, 76		0101000020E6100000EE96E4805D17544057CD7344BEE34940
16801	5	47	1411	16554	70796	\N	51.126900999999997	Алтайский край, Угловский район, с.Борисовка, Молодежная, 13		0101000020E610000079E75086AA0E5440336ABE4A3E904940
16793	5	47	1411	16116	70953	\N	51.413620000000002	Алтайский край, Угловский район, с.Бор-кособулат, Лесная, 4		0101000020E6100000719010E50BF553405B7C0A80F1B44940
16803	5	47	1411	16651	71418	\N	50.991301	Алтайский край, Угловский район, с.Беленькое, Кооперативная, 43		0101000020E610000070B378B130085440FDBE7FF3E27E4940
16790	5	47	1411	15985	71166	\N	51.375805	Алтайский край, Угловский район, с.Алексеевка, Степная, 13		0101000020E61000002C9B3924B5ED53402E56D4601AB04940
16782	5	47	1360	15602	71407	\N	53.430543999999998	Алтайский край, Тюменцевский район, с.Юдиха, Кузнецова, 19		0101000020E610000009C03FA54A7C544098BED7101CB74A40
16773	5	47	1360	15163	69964	\N	53.140034	Алтайский край, Тюменцевский район, с.Шарчино, Ульяновская, 6		0101000020E6100000A29927D714705440FE2955A2EC914A40
16769	5	47	1360	15001	71411	\N	53.260195495858298	Алтайский край, Тюменцевский район, с.Черемшанка, Центральный, 4	Россия, Алтайский край, Тюменцевский район, поселок Черемшанка	0101000020E6100000A54BFF925450544097CADB114EA14A40
16775	5	47	1360	59467	71491	\N	53.042765429968298	Алтайский край, Тюменцевский район, с.Урывки, Центральная, 22	Россия, Алтайский край, Тюменцевский район, поселок Урывка	0101000020E6100000F530B43A39715440EC34D25279854A40
16765	5	47	1360	14678	69793	\N	53.316574000000003	Алтайский край, Тюменцевский район, с.Тюменцево, Октябрьская, 6		0101000020E6100000D82B2CB81F605440C861307F85A84A40
16764	5	47	1360	14678	70032	\N	53.316574000000003	Алтайский край, Тюменцевский район, с.Тюменцево, Ленина, 104з		0101000020E6100000D82B2CB81F605440C861307F85A84A40
16763	5	47	1360	14678	70030	\N	53.316574000000003	Алтайский край, Тюменцевский район, с.Тюменцево, Барнаульская, 16		0101000020E6100000D82B2CB81F605440C861307F85A84A40
16774	5	47	1360	15208	71323	\N	53.098891000000002	Алтайский край, Тюменцевский район, с.Трубачево, Центральная, 15		0101000020E6100000AB23473A03675440336FD575A88C4A40
16777	5	47	1360	15364	70864	\N	53.293746461055299	Алтайский край, Тюменцевский район, пос.Свободный, Заводская, 12	Россия, Алтайский край, Тюменцевский район, поселок Свободный	0101000020E61000006F2C280CCA66544058AA0B7899A54A40
16781	5	47	1360	15552	70877	\N	53.357050999999998	Алтайский край, Тюменцевский район, с.Мезенцево, Центральная, 5		0101000020E6100000BA9F53909F6C54408600E0D8B3AD4A40
16770	5	47	1360	15035	70775	\N	53.228428000000001	Алтайский край, Тюменцевский район, пос.Кулундинский, Кулундинская, 30		0101000020E6100000D5928E72304B5440CFBEF2203D9D4A40
16771	5	47	1360	15059	70581	\N	53.177208	Алтайский край, Тюменцевский район, пос.Королевский, Центральный, 16		0101000020E6100000C85F5AD4275D5440774B72C0AE964A40
16766	5	47	1360	14840	71145	\N	53.4466422625487	Алтайский край, Тюменцевский район, с.Ключи, Запорожская, 15	Россия, Алтайский край, Тюменцевский район, поселок Ключи	0101000020E610000037A6272CF15A54409082A7902BB94A40
16778	5	47	1360	15412	70866	\N	53.206665999999998	Алтайский край, Тюменцевский район, пос.Карповский, Центральная, 34		0101000020E610000059A65F22DE665440FA980F08749A4A40
16776	5	47	1360	15305	70947	\N	53.301611541806302	Алтайский край, Тюменцевский район, пос.Заводской, Центральная, 23а	Россия, Алтайский край, Тюменцевский район, поселок Заводской	0101000020E6100000F9BEB854A5695440630AD6389BA64A40
16767	5	47	1360	14907	70779	\N	53.382967999999998	Алтайский край, Тюменцевский район, с.Грязново, Центральная, 14		0101000020E61000005073F222135154400FB56D1805B14A40
16772	5	47	1360	15110	70182	\N	53.079588999999999	Алтайский край, Тюменцевский район, с.Вылково, Центральный, 6		0101000020E6100000234910AE805B5440880FECF82F8A4A40
16779	5	47	1360	15453	70578	\N	53.242806999999999	Алтайский край, Тюменцевский район, с.Березовка, Молодежная, 5а		0101000020E6100000A986FD9E58745440B41EBE4C149F4A40
16768	5	47	1360	14925	71403	\N	53.319612999999997	Алтайский край, Тюменцевский район, с.Андроново, Центральная, 3		0101000020E6100000AB5B3D27BD4B54402F302B14E9A84A40
16761	5	47	1138	14589	71109	\N	52.794531722107102	Алтайский край, Троицкий район, с. Южаково, ул. Рабочая, 5	Россия, Алтайский край, Троицкий район, поселок Южаково	0101000020E6100000481ADCD6161E55400FD07D39B3654A40
16729	5	47	1138	13102	71084	\N	52.601127770734301	Алтайский край, Троицкий район, с. Червянка, ул. Центральная, 12	Россия, Алтайский край, Троицкий район, поселок Червянка	0101000020E6100000E065868DB2045540DE5A26C3F14C4A40
16741	5	47	1138	13668	70921	\N	52.961500343345797	Алтайский край, Троицкий район, с. Хайрюзовка, ул. Советская, 54	Россия, Алтайский край, Троицкий район, поселок Хайрюзовка	0101000020E610000054FD4AE7C33A5540508D976E127B4A40
16730	5	47	1138	13120	71090	\N	52.718110000000003	Алтайский край, Троицкий район, пос. Уткуль, ул. Централья, 1		0101000020E6100000C712D6C6D82655401D774A07EB5B4A40
16742	5	47	1138	13683	70985	\N	52.939566999999997	Алтайский край, Троицкий район, с. Усть-Гавриловка, ул. Школьная, д.40, кв.1		0101000020E61000006CEA3C2AFE4155404EB340BB43784A40
16732	5	47	1138	13247	71275	\N	52.939734999999999	Алтайский край, Троицкий район, с. Тюмень, ул. Набережная, 18		0101000020E6100000107A36AB3E2655400AF4893C49784A40
16759	5	47	1138	12871	70184	\N	52.979849000000002	Алтайский край, Троицкий район, с. Троицкое, пер. Лермонтова, 26		0101000020E61000001D76DF313C2B5540580229B16B7D4A40
16725	5	47	1138	12871	70025	\N	52.979849000000002	Алтайский край, Троицкий район, село Троицкое, ул. Комсомольская, 30		0101000020E61000001D76DF313C2B5540580229B16B7D4A40
16724	5	47	1138	12871	70025	\N	52.979849000000002	Алтайский край, Троицкий район, с. Троицкое, ул. Комсомольская, 30		0101000020E61000001D76DF313C2B5540580229B16B7D4A40
16746	5	47	1138	13885	70755	\N	53.130395999999998	Алтайский край, Троицкий район, с. Талдинка, ул. Центральная, 41А		0101000020E6100000A52E19C748455540BDC3EDD0B0904A40
16737	5	47	1138	13464	70778	\N	52.865822000000001	Алтайский край, Троицкий район, пос. Степной, ул. Молодежная, 1А		0101000020E61000007347FFCBB530554023145B41D36E4A40
16016	5	47	1138	10579	71137	\N	53.135815000000001	Алтайский край, Каменский район, п.Раздольный, пер.Школьный, 1		0101000020E6100000452E3883BF38554033A7CB6262914A40
16750	5	47	1138	14087	70408	\N	53.066924	Алтайский край, Троицкий район, с. Петровка, 50 лет Алтая, 30А		0101000020E61000008D63247B84285540A4A833F790884A40
16752	5	47	1138	14162	71128	\N	53.114795000000001	Алтайский край, Троицкий район, с. Песьянка, ул. Школьная, 6А		0101000020E610000016DD7A4D0F235540465F419AB18E4A40
16755	5	47	1138	14317	70789	\N	53.125073999999998	Алтайский край, Троицкий район, пос. Октябрьский, ул. Юбилейная, 9		0101000020E6100000C8B7770DFA2B55403ACAC16C02904A40
16758	5	47	1138	59456	71466	\N	52.950530316866598	Алтайский край, Троицкий район, с. Озеро Петровское, ул. Линейная, 2	Россия, Алтайский край, Троицкий район, поселок Озеро-Петровское	0101000020E610000015C9570229135540F6EE8FF7AA794A40
16743	5	47	1138	13741	71120	\N	53.055159000000003	Алтайский край, Троицкий район, село Новоеловка, ул. Елютина, 146		0101000020E610000009A87004A93D5540408A3A730F874A40
16760	5	47	1138	14551	70927	\N	52.735677000000003	Алтайский край, Троицкий район, пос. Многоозёрный, ул. Октябрьская, 1А		0101000020E6100000FF25A94C31185540AFB5F7A92A5E4A40
16762	5	47	1138	14637	71404	\N	52.845947000000002	Алтайский край, Троицкий район, пос. Лесной, ул. Заречная, 19		0101000020E61000001BF5108DEE1E55401D93C5FD476C4A40
16734	5	47	1138	13317	70904	\N	52.754435000000001	Алтайский край, Троицкий район, пос. Ленинск, ул. Коммунарская, 77		0101000020E61000005649641F6422554098FA795391604A40
16747	5	47	1138	13956	70579	\N	53.164442999999999	Алтайский край, Троицкий район, с. Краснояры, пер. Парковый, 1		0101000020E61000002041F163CC5255402F87DD770C954A40
16756	5	47	1138	14372	71151	\N	53.163502999999999	Алтайский край, Троицкий район, пос. Клюквенный, ул. Центральная, д. 3, кв. 1		0101000020E61000000ABC934F8F3C554021E692AAED944A40
16740	5	47	1138	13598	71397	\N	52.941895000000002	Алтайский край, Троицкий район, с. Кипешино, ул. Сибирская, 10		0101000020E61000005B99F04BFD3355400AA2EE0390784A40
16736	5	47	1138	13401	70355	\N	52.885263000000002	Алтайский край, Троицкий район, с. Зеленая Поляна, ул. Школьная, 22		0101000020E6100000A29A92ACC32F5540EFAD484C50714A40
16735	5	47	1138	13383	9952	\N	52.865358999999998	Алтайский край, Троицкий район, с. Загайново, ул. Школьная, 16		0101000020E6100000F3E49A02992155404E266E15C46E4A40
16757	5	47	1138	14401	70185	\N	53.070050999999999	Алтайский край, Троицкий район, с. Заводское, ул. 50 лет Октября, 2		0101000020E6100000556AF6402B1B5540AB06616EF7884A40
16748	5	47	1138	13975	70784	\N	53.161256999999999	Алтайский край, Троицкий район, с. Еремино, ул. Школьная, 21		0101000020E61000005BB6D617094F554023A0C211A4944A40
16745	5	47	1138	13827	70363	\N	53.055700000000002	Алтайский край, Троицкий район, с. Ельцовка, ул. Ленина, 98		0101000020E610000094A5D6FB8D4755409031772D21874A40
16749	5	47	1138	14038	70357	\N	53.074553000000002	Алтайский край, Троицкий район, с. Горновое, ул. Молодежная, 36		0101000020E610000012BD8C62B9555540CB68E4F38A894A40
16754	5	47	1138	14263	69764	\N	53.109644000000003	Алтайский край, Троицкий район, пос. Гордеевский, ул. Зеленая, 37		0101000020E6100000F10EF0A4852B5540F01989D0088E4A40
16744	5	47	1138	13798	70922	\N	53.079627000000002	Алтайский край, Троицкий район, с. Гордеевка, ул. Алтайская, 33		0101000020E6100000A6F0A0D9753C55407670B037318A4A40
16738	5	47	1138	13516	71413	\N	52.725861000000002	Алтайский край, Троицкий район, с. Вершинино, ул. Центральная, 42		0101000020E6100000B2648EE55D2B55408F386403E95C4A40
16733	5	47	1138	13274	70919	\N	52.863630999999998	Алтайский край, Троицкий район, пос. Боровлянский, ул. Боровлянская, 20А		0101000020E61000006000E143892C5540E867EA758B6E4A40
16727	5	47	1138	12990	70417	\N	52.632182	Алтайский край, Троицкий район, с.Боровлянка, ул. Фефелова, д.64А		0101000020E61000000536E7E0991C5540588FFB56EB504A40
63283	3	31	\N	57342	57995	\N	58.382935000000003	г.Боровичи, Новгородская, 1		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
16728	5	47	1138	12990	70609	\N	52.632182	Алтайский край, Троицкий район, с. Боровлянка, Октябрьская, 61Б		0101000020E61000000536E7E0991C5540588FFB56EB504A40
16739	5	47	1138	13549	70818	\N	52.923473000000001	Алтайский край, Троицкий район, с. Белое, ул. 40 лет Победы, д.13		0101000020E6100000A530EF71A62E554098DEFE5C34764A40
16731	5	47	1138	13188	69792	\N	52.895167999999998	Алтайский край, Троицкий район, пос. Беловский, ул. Советская, 11		0101000020E610000054C8957A162955407E3672DD94724A40
16719	5	47	1217	12666	71086	\N	50.935538788025802	Алтайский край, Третьяковский район, село Шипуниха, Михайлова, 12	Россия, Алтайский край, Третьяковский район, поселок Шипуниха	0101000020E610000027C286A757985440F790F0BDBF774940
16714	5	47	1217	12402	70416	\N	50.864733000000001	Алтайский край, Третьяковский район, станция Третьяково, Центральная, 25		0101000020E6100000D68C0C7217795440D0622992AF6E4940
16984	5	47	1217	25566	70885	\N	50.972825999999998	Алтайский край, Третьяковский район, посёлок Степной, Западная, 12		0101000020E6100000F4893C49BA7854406859F78F857C4940
16709	5	47	1217	12125	70270	\N	51.006390000000003	Алтайский край, Третьяковский район, село Староалейское, Колхозная, 3		0101000020E61000000BF0DDE68D7F5440BF823463D1804940
16708	5	47	1217	12125	69789	\N	51.006390000000003	Алтайский край, Третьяковский район, село Староалейское, Калашникова, 38		0101000020E61000000BF0DDE68D7F5440BF823463D1804940
16720	5	47	1217	12691	71305	\N	50.959819000000003	Алтайский край, Третьяковский район, посёлок Семеновка, Центральная, 22		0101000020E61000009C6D6E4C4F9E54402B8A5759DB7A4940
16710	5	47	1217	12206	70610	\N	50.983618	Алтайский край, Третьяковский район, посёлок Садовый, Дорожная, 10		0101000020E6100000745DF8C1F97A5440E3E0D231E77D4940
16723	5	47	1217	12848	70607	\N	50.850051999999998	Алтайский край, Третьяковский район, село Плоское, Центральная, 71		0101000020E6100000492C29779F8954401FF30181CE6C4940
16716	5	47	1217	12530	70580	\N	50.879761999999999	Алтайский край, Третьяковский район, посёлок Первомайский, Центральная, 8		0101000020E61000008599B67F657B5440BC218D0A9C704940
16718	5	47	1217	12639	70561	\N	50.967357999999997	Алтайский край, Третьяковский район,  с.Первокаменка, ул.Советская, д.1 (Центральная, 38)		0101000020E6100000081D74098791544011C30E63D27B4940
16713	5	47	1217	12378	71320	\N	50.934173999999999	Алтайский край, Третьяковский район, посёлок Новокамышенка, ул.Советская, д.19		0101000020E6100000FF3C0D182487544002637D0393774940
16721	5	47	1217	12748	71089	\N	50.844546999999999	Алтайский край, Третьяковский район, село Новоалейское, Центральная, 86		0101000020E61000007C478D09319A5440AB77B81D1A6C4940
16715	5	47	1217	12462	70752	\N	50.813830000000003	Алтайский край, Третьяковский район, село Михайловка, Центральная, 39 Б		0101000020E6100000581F0F7D777D54407940D9942B684940
16711	5	47	1217	12293	69794	\N	51.102656000000003	Алтайский край, Третьяковский район, село Корболиха, Кирова, 34		0101000020E610000087889B53C97D54407D5EF1D4238D4940
16712	5	47	1217	12299	69791	\N	50.909373000000002	Алтайский край, Третьяковский район, село Екатерининское, Титова, 53		0101000020E61000002DEE3F321D815440C66E9F5566744940
16722	5	47	1217	59461	71479	\N	50.854553513512101	Алтайский край, Третьяковский район,  с.Верхалейское, ул.Центральная, д.10	Россия, Алтайский край, Третьяковский район, поселок Верх-Алейка	0101000020E6100000A9A3E36A649C54403F558506626D4940
16707	5	47	1154	12062	70122	\N	52.678626000000001	Алтайский край, Топчихинский район, с.Чистюнька, Партизанская, 4		0101000020E610000086AC6EF59CCD54408F1B7E37DD564A40
16706	5	47	1154	12054	70914	\N	52.737808999999999	Алтайский край, Топчихинский район, с.Чаузово, Лесная, 53		0101000020E61000008F8CD5E6FFF05440E4D87A86705E4A40
16705	5	47	1154	11967	71292	\N	52.744067000000001	Алтайский край, Топчихинский район, с.Хабазино, Гагарина, 2		0101000020E6100000D447E00F3FD85440348463963D5F4A40
16704	5	47	1154	11911	70026	\N	52.786068	Алтайский край, Топчихинский район, с.Фунтики, Юбилейная, 21		0101000020E6100000B6F468AA27C25440503750E09D644A40
16697	5	47	1154	11589	70739	\N	52.733065000000003	Алтайский край, Топчихинский район, п.Труд, Центральная, 18	Россия, Алтайский край, Топчихинский район	0101000020E6100000857D3B8908D15440CF6BEC12D55D4A40
16684	5	47	1154	10885	70090	\N	52.816971000000002	Алтайский край, Топчихинский район, с.Топчиха, Партизанская, 42		0101000020E6100000BE840A0E2FC75440E563778192684A40
16683	5	47	1154	10885	69784	\N	52.816971000000002	Алтайский край, Топчихинский район, с.Топчиха, Куйбышева, 4		0101000020E6100000BE840A0E2FC75440E563778192684A40
16682	5	47	1154	10885	69784	\N	52.816971000000002	Алтайский край, Топчихинский район, с.Топчиха, Куйбышева, 37		0101000020E6100000BE840A0E2FC75440E563778192684A40
16689	5	47	1154	11197	70745	\N	52.467688000000003	Алтайский край, Топчихинский район, п.Топольный, Центральная, 14		0101000020E6100000E50B5A48C0D05440A75D4C33DD3B4A40
16703	5	47	1154	11895	70352	\N	52.997011999999998	Алтайский край, Топчихинский район, с.Сидоровка, Октябрьская, 24		0101000020E610000023DBF97E6ABF54401ADCD6169E7F4A40
16702	5	47	1154	11833	70915	\N	52.713037	Алтайский край, Топчихинский район, с.Покровка, Школьная, 24		0101000020E6100000E1D1C6116BD8544042EBE1CB445B4A40
16698	5	47	1154	11625	70287	\N	52.662495	Алтайский край, Топчихинский район, п.Победим, Ленина, 12		0101000020E61000007D410B0918C05440BB61DBA2CC544A40
16695	5	47	1154	11497	70887	\N	52.790719000000003	Алтайский край, Топчихинский район, с.Песчаное, Школьная, 26		0101000020E61000007AC8940F41A05440B5A9BA4736654A40
16696	5	47	1154	11541	70577	\N	52.881698	Алтайский край, Топчихинский район, с.Переясловка, Губина, 26		0101000020E61000000EDAAB8F87C654406C79E57ADB704A40
16694	5	47	1154	11451	69785	\N	52.808937	Алтайский край, Топчихинский район, с.Парфеново, Школьная, 18		0101000020E61000002CBB6070CDAE54401EC3633F8B674A40
16693	5	47	1154	11418	70428	\N	52.87285	Алтайский край, Топчихинский район, с.Макарьевка, Центральная, 4		0101000020E610000036B1C05774C2544024287E8CB96F4A40
16692	5	47	1154	11352	71082	\N	52.755198	Алтайский край, Топчихинский район, с.Листвянка, Центральная, 32		0101000020E61000002827DA5548FE54409700FC53AA604A40
16691	5	47	1154	11296	71265	\N	52.754058999999998	Алтайский край, Топчихинский район, с.Красноярка, Центральная, 51		0101000020E6100000C4961E4DF5DD544092205C0185604A40
16700	5	47	1154	11746	71290	\N	52.618361999999998	Алтайский край, Топчихинский район, с.Колпаково, Центральная, 1		0101000020E61000008FA9BBB20BC25440698B6B7C264F4A40
16690	5	47	1154	11260	70603	\N	52.618175999999998	Алтайский край, Топчихинский район, п.Ключи, Молодежная, 5		0101000020E6100000F624B03907D9544007962364204F4A40
16688	5	47	1154	59401	70570	\N	52.548125734259102	Алтайский край, Топчихинский район, п.Кировский, Садовая, 33	Россия, Алтайский край, Топчихинский район, поселок Кировскаий	0101000020E61000009CC0745AB7CA54402D0B26FE28464A40
16687	5	47	1154	11132	70354	\N	52.626097999999999	Алтайский край, Топчихинский район, с.Зимино, Партизанская, 13		0101000020E6100000B6679604A8CA5440A60BB1FA23504A40
16699	5	47	1154	11694	70734	\N	52.683948999999998	Алтайский край, Топчихинский район, п.Зеленый, Московская, 21		0101000020E6100000CE52B29C84BE5440E2900DA48B574A40
16701	5	47	1154	11789	70908	\N	52.690379	Алтайский край, Топчихинский район, п.Дружба, Садовая, 5		0101000020E6100000F12E17F19DC354402F6CCD565E584A40
16686	5	47	1154	11088	70604	\N	52.711471000000003	Алтайский край, Топчихинский район, с.Володарка, Володарского, 3		0101000020E61000007023658BA4E75440B686527B115B4A40
16685	5	47	1154	11014	70400	\N	52.770364000000001	Алтайский край, Топчихинский район, с.Белояровка, Гагарина, 37		0101000020E6100000BEDD921CB0CA544004029D499B624A40
16673	5	47	1119	10453	70912	\N	53.617890000000003	Алтайский край, Тогульский район, с.Шумиха, Новаря, 5		0101000020E61000003DBB7CEBC37F55404243FF0417CF4A40
16675	5	47	1119	10712	70733	\N	53.498833171425701	Алтайский край, Тогульский район, с.Уксунай, Кузнецкая, 45	Россия, Алтайский край, Тогульский район, поселок Уксунай	0101000020E610000021037976F980554031957EC2D9BF4A40
16677	5	47	1119	10662	71300	\N	53.373772000000002	Алтайский край, Тогульский район, с.Топтушка, Новая, 14		0101000020E6100000C0E95DBC1F8655408C14CAC2D7AF4A40
16669	5	47	1119	10158	70073	\N	53.467857000000002	Алтайский край, Тогульский район, с.Тогул, Школьная, 20		0101000020E61000005DFDD8243F7A5540331AF9BCE2BB4A40
16668	5	47	1119	10158	70361	\N	53.467857000000002	Алтайский край, Тогульский район, с.Тогул, Совхозная, 25		0101000020E61000005DFDD8243F7A5540331AF9BCE2BB4A40
16670	5	47	1119	10158	70545	\N	53.467857000000002	Алтайский край, Тогульский район, с.Тогул, Пролетарская, 1		0101000020E61000005DFDD8243F7A5540331AF9BCE2BB4A40
16667	5	47	1119	10158	69781	\N	53.467857000000002	Алтайский край, Тогульский район, с.Тогул, Октябрьская, 4		0101000020E61000005DFDD8243F7A5540331AF9BCE2BB4A40
16672	5	47	1119	10439	71250	\N	53.411951000000002	Алтайский край, Тогульский район, с.Титово, Центральная, 21		0101000020E610000013B70A62A0705540FA4674CFBAB44A40
16678	5	47	1119	10728	70611	\N	53.429851999999997	Алтайский край, Тогульский район, с.Старый Тогул, Центральная, 2		0101000020E610000013D55B035B795540620FED6305B74A40
16674	5	47	1119	10535	70769	\N	53.632987	Алтайский край, Тогульский район, с.Новоиушино, Центральная, 7		0101000020E6100000A7CEA3E2FF73554086E5CFB705D14A40
16671	5	47	1119	10365	70983	\N	53.457709000000001	Алтайский край, Тогульский район, с.Льнозавод, ул.Заводская, 1		0101000020E610000052B81E85EB7C5540DD0A613596BA4A40
16680	5	47	1119	10825	70917	\N	53.327298999999996	Алтайский край, Тогульский район, с.Колонково, Бийская, 15		0101000020E610000055FA0967B7775540BA8102EFE4A94A40
16676	5	47	1119	59452	71459	\N	53.465550173621097	Алтайский край, Тогульский район, с.Верх-Каптелка, Лесная, 12	Россия, Алтайский край, Тогульский район, поселок Верх-Коптелка	0101000020E61000008C135FED288C55408F53742497BB4A40
16681	5	47	1119	10857	71078	\N	53.387205999999999	Алтайский край, Тогульский район, с.Бураново, Молодежная, 10		0101000020E6100000D6C4025FD1735540516859F78FB14A40
16679	5	47	1119	10741	69762	\N	53.301395999999997	Алтайский край, Тогульский район, с.Антипино, Мокарова, 53		0101000020E61000003A22DFA5D47555409692E52494A64A40
16645	5	47	975	59384	70110	\N	53.669848999999999	Алтайский край, Тальменский район, ст.Озерки, ул.Калинина, д.22	Россия	0101000020E610000022FFCC203EEC54401021AE9CBDD54A40
16653	5	47	975	9474	71288	\N	53.592709999999997	Алтайский край, Тальменский район, с.Язово, ул.Центральная, д.80		0101000020E6100000F8C1F9D4B1CB54408E01D9EBDDCB4A40
16652	5	47	975	9423	70905	\N	53.636566519236702	Алтайский край, Тальменский район, с.Шишкино, ул.Советская, д.7	Россия, Алтайский край, Тальменский район, поселок Шишкино	0101000020E61000001424B6BB07CE54403E5B07077BD14A40
16635	5	47	975	8659	70821	\N	53.607590999999999	Алтайский край, Тальменский район, с.Шипицыно, ул.Школьная, д.2		0101000020E610000024D06053E7C75440062CB98AC5CD4A40
16651	5	47	975	9351	70627	\N	53.945734999999999	Алтайский край, Тальменский район, с.Шадринцево, ул.Садовая, д.34		0101000020E61000008ECEF9298EFD54405ED72FD80DF94A40
16642	5	47	975	8983	71286	\N	53.855440999999999	Алтайский край, Тальменский район, с.Таскаево, ул.Клубная, д.6		0101000020E6100000C3F4BD86E0EB54402A5437177FED4A40
16659	5	47	975	9490	69779	\N	53.817169889723502	Алтайский край, Тальменский район, р.п.Тальменка, ул.Учительская, д.2а	Россия, Алтайский край, Тальменский район, поселок Тальменка	0101000020E610000053CBD6FA22E45440DBA2CC0699E84A40
16655	5	47	975	9490	69979	\N	53.817982999999998	Алтайский край, Тальменский район,  р.п.Тальменка, ул.Партизанская, д.53		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16666	5	47	975	9490	70068	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Парковая, д.21		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16662	5	47	975	9490	69757	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Октябрьская, д.57		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16663	5	47	975	9490	70057	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Лисавенко, д.49		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16654	5	47	975	9490	69759	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Куйбышева, д.91		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16187	5	47	775	18795	70321	\N	53.466966999999997	Алтайский край, Кытмановский район, с. Тягун, Лесная, 6		0101000020E61000000D17B9A7AB5E5540D6A71C93C5BB4A40
16657	5	47	975	9490	69755	\N	53.817055611267001	Алтайский край, Тальменский район, р.п.Тальменка, ул.Кирова, д.19	Россия, Алтайский край, Тальменский район, поселок Тальменка	0101000020E6100000A08D5C37A5E3544013807F4A95E84A40
16660	5	47	975	9490	69777	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.Анисимовская, д.24		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16661	5	47	975	9490	69758	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.60 лет СССР, д.3		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16658	5	47	975	9490	69770	\N	53.817982999999998	Алтайский край, Тальменский район, р.п.Тальменка, ул.30 лет ВЛКСМ, д.17		0101000020E61000001807978E39E454408CD7BCAAB3E84A40
16650	5	47	975	9348	71072	\N	53.772269000000001	Алтайский край, Тальменский район, с.Староперуново, ул.Советская, д.13		0101000020E61000009430D3F6AFDD5440795BE9B5D9E24A40
16649	5	47	975	9287	69771	\N	53.748176999999998	Алтайский край, Тальменский район, п.Среднесибирский, ул.Юбилейная, д.2		0101000020E6100000D76CE525FFE85440484F9143C4DF4A40
16634	5	47	975	8606	70920	\N	53.744674000000003	Алтайский край, Тальменский район, с.Сандалово, ул.Новая, д.6		0101000020E6100000EAAF575870C054403C17467A51DF4A40
16648	5	47	975	9230	70735	\N	53.496631999999998	Алтайский край, Тальменский район, с.Речкуново, ул.Школьная, д.11		0101000020E610000001F73C7FDAD55440D3122BA391BF4A40
16644	5	47	975	9045	69754	\N	53.627695000000003	Алтайский край, Тальменский район, с.Озерки, ул.Юбилейная, д.2		0101000020E610000033164D6727ED54406E6E4C4F58D04A40
16646	5	47	975	9045	70052	\N	53.669848999999999	Алтайский край, Тальменский район, ст.Озерки, ул.Промышленная, д.61		0101000020E610000022FFCC203EEC54401021AE9CBDD54A40
16643	5	47	975	9045	70046	\N	53.627695000000003	Алтайский край, Тальменский район, с.Озерки, ул.Новая, д.4		0101000020E610000033164D6727ED54406E6E4C4F58D04A40
16641	5	47	975	8927	70531	\N	53.896065999999998	Алтайский край, Тальменский район, с.Новотроицк, ул.Советская, д.62		0101000020E6100000527DE71725EF54405D876A4AB2F24A40
16640	5	47	975	8876	69768	\N	53.875379000000002	Алтайский край, Тальменский район, с.Новоперуново, ул.Зеленая, д.8		0101000020E61000007AFCDEA63FE05440774D486B0CF04A40
16632	5	47	975	8524	71280	\N	53.907646999999997	Алтайский край, Тальменский район, с.Новоеловка, ул.Школьная, д.19		0101000020E61000006571FF91E9D4544000A8E2C62DF44A40
16630	5	47	975	8454	71087	\N	53.780464000000002	Алтайский край, Тальменский район, с.Наумово, ул.Октябрьская, д.2а		0101000020E6100000151E34BBEEE4544049DA8D3EE6E34A40
16638	5	47	975	8794	71282	\N	54.019294000000002	Алтайский край, Тальменский район, с.Лушниково, ул.Советская, д.43		0101000020E610000035CF11F92EE154402881CD3978024B40
16636	5	47	975	8731	70399	\N	53.792113999999998	Алтайский край, Тальменский район, с.Луговое, ул.Центральная, д.77		0101000020E61000002CB81FF0C0E75440145AD6FD63E54A40
16372	5	47	975	27730	71213	\N	53.570188000000002	Алтайский край, Первомайский район, пос.Лесная Поляна, ул.Центральная, 15а		0101000020E610000070B1A206D3ED54402C499EEBFBC84A40
16633	5	47	975	8577	69751	\N	53.772083000000002	Алтайский край, Тальменский район, с.Ларичиха, ул.Строительная, д.2		0101000020E610000034F790F0BDC254401766A19DD3E24A40
16631	5	47	975	8459	70396	\N	53.869444000000001	Алтайский край, Тальменский район, с.Курочкино, ул.Школьная, д.11		0101000020E6100000EE5A423EE8D454400ADAE4F049EF4A40
16639	5	47	975	8838	70724	\N	53.965712611193197	Алтайский край, Тальменский район, с.Кошелево, ул.Школьная, д.14	Россия, Алтайский край, Тальменский район, поселок Кошелево	0101000020E610000023A30392B0E154403929CC7B9CFB4A40
16629	5	47	975	8371	70391	\N	53.727784	Алтайский край, Тальменский район, с.Кашкарагаиха, ул.Советская, д.1а		0101000020E61000004356B77A4EDE5440AA46AF0628DD4A40
16628	5	47	975	8366	70952	\N	54.023668999999998	Алтайский край, Тальменский район, с.Казанцево, ул.Центральная, д.10		0101000020E6100000AEF36F97FDD15440EA76F69507034B40
16627	5	47	975	8295	70601	\N	53.692328000000003	Алтайский край, Тальменский район, с.Зайцево, ул.Центральная, д.45		0101000020E610000021904B1C79D45440740D33349ED84A40
16626	5	47	975	8222	71147	\N	54.068931999999997	Алтайский край, Тальменский район, с.Загайново, ул.Центральная, д.89а		0101000020E6100000255987A3ABF45440EDD286C3D2084B40
16625	5	47	975	8201	70738	\N	53.804447000000003	Алтайский край, Тальменский район, с.Забродино, мк-р Черемушки, д.18		0101000020E610000052D66F26A6EA5440C32E8A1EF8E64A40
16637	5	47	975	8746	70902	\N	53.842554999999997	Алтайский край, Тальменский район, с.Выползово, ул.Центральная, д.2		0101000020E610000046239F573CEF5440670A9DD7D8EB4A40
16647	5	47	975	9209	70723	\N	53.731251999999998	Алтайский край, Тальменский район, п.Восточный, ул.Береговая, д.37		0101000020E610000028BB99D18FF454403A9160AA99DD4A40
16624	5	47	975	8144	69987	\N	54.022489	Алтайский край, Тальменский район, с.Анисимово, ул.Тальменская, д.4в		0101000020E61000002A0307B474E7544087C267EBE0024B40
16619	5	47	918	7869	70897	\N	52.940497219646197	Алтайский край, Табунский район, с.Хорошее, ул.Молодежная, д.4	Россия, Алтайский край, Табунский район, поселок Хорошее	0101000020E610000050C3B7B06ECD5340397EA83462784A40
16617	5	47	918	7774	70891	\N	52.925030999999997	Алтайский край, Табунский район, с.Успенка, ул.Комсомольская, д.38		0101000020E61000002ACAA5F10BD65340A164726A67764A40
16609	5	47	918	7441	71255	\N	52.819588000000003	Алтайский край, Табунский район, с.Удальное, ул.Мира, д.31		0101000020E61000005FB35C363AB75340D7187442E8684A40
16607	5	47	918	7304	70527	\N	52.772683999999998	Алтайский край, Табунский район, Табунский район, с.Табуны, ул.Московская, д.21		0101000020E6100000705F07CE19B253403C122F4FE7624A40
16606	5	47	918	7304	69905	\N	52.772683999999998	Алтайский край, Табунский район, с.Табуны, ул.Ленина, д.17		0101000020E6100000705F07CE19B253403C122F4FE7624A40
16615	5	47	918	7693	70384	\N	52.885469000000001	Алтайский край, Табунский район, с.Сереброполь, ул.Ленина, д.75		0101000020E61000003ACD02ED0ECD5340984F560C57714A40
16616	5	47	918	7746	71077	\N	52.87959	Алтайский край, Табунский район, с.Саратовка, ул.Целинная, д.37		0101000020E6100000B587BD50C0C75340BFF1B56796704A40
63288	3	31	\N	57342	57958	\N	58.382935000000003	г.Боровичи, Ленинградская, 14		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
16608	5	47	918	7378	71276	\N	52.774079	Алтайский край, Табунский район, с.Самбор, пер.Центральный, д.10		0101000020E61000000BEBC6BB23B953409CC24A0515634A40
16139	5	47	918	16383	71241	\N	52.611898479773501	Алтайский край, Кулундинский район, село Орловка, Озерная, 22а	Россия, Алтайский край, Табунский район, поселок Орловка	0101000020E6100000A12E52280BA65340703E75AC524E4A40
16612	5	47	918	7588	70892	\N	52.733277000000001	Алтайский край, Табунский район, с.Новокиевка, ул.Свердлова, д.19		0101000020E6100000BA675DA3E5AD53405AF44E05DC5D4A40
16618	5	47	918	7851	71270	\N	52.947451999999998	Алтайский край, Табунский район, с.Николаевка, ул.Лермонтова, д.37		0101000020E6100000486C770FD0C75340D0436D1B46794A40
16622	5	47	918	8020	71160	\N	52.786019000000003	Алтайский край, Табунский район, с.Лебедино, ул.Ленина, д.14		0101000020E610000027BD6F7CEDD253406F8445459C644A40
16621	5	47	918	7968	70901	\N	52.893158	Алтайский край, Табунский район, с.Канны, ул.Ленина, д.31		0101000020E6100000AE9CBD33DAB753409414580053724A40
16614	5	47	918	7663	70893	\N	52.758178999999998	Алтайский край, Табунский район, с.Камышенка, ул.Гагарина, д.10		0101000020E6100000787AA52C439C5340CAC16C020C614A40
16610	5	47	918	7489	70710	\N	52.829377999999998	Алтайский край, Табунский район, с.Забавное, пер.Школьный, д.2		0101000020E61000006CCB80B394B25340CD02ED0E296A4A40
16620	5	47	918	7934	70596	\N	52.995234000000004	Алтайский край, Табунский район, с.Большеромановка, ул.Ленина, д.46		0101000020E61000009FE74F1BD5B6534003EFE4D3637F4A40
16611	5	47	918	7512	69965	\N	52.785567	Алтайский край, Табунский район, с.Алтайское, ул.Гагарина, д.5		0101000020E6100000331B649291B053408EE89E758D644A40
16613	5	47	918	7597	71068	\N	52.71416	Алтайский край, Табунский район, с.Александровка, ул.Центральная, д.22		0101000020E6100000501A6A1492AC5340410E4A98695B4A40
16602	5	47	900	7055	71134	\N	53.236642000000003	Алтайский край, Суетский район,  Верх-Суетский район, п.им.Владимира Ильича, ул. Ленина, д.14		0101000020E6100000BCCADAA678ED5340166EF9484A9E4A40
16605	5	47	900	7243	70978	\N	53.253117904574303	Алтайский край, Суетский район, п.Осиновский, ул.Ленина, д.1/а	Россия, Алтайский край, Суетский район, поселок Осиновский	0101000020E6100000737FF5B86F015440B403AE2B66A04A40
16604	5	47	900	7206	71396	\N	53.319510999999999	Алтайский край, Суетский район, п.Октябрьский, Школьная, 1		0101000020E610000072FE261422FB53402BDB87BCE5A84A40
16603	5	47	900	7161	70192	\N	53.222378999999997	Алтайский край, Суетский район, с.Нижняя-Суетка, Школьная, 36		0101000020E6100000AE0CAA0D4EF95340992842EA769C4A40
15796	5	47	900	31655	71327	\N	53.151305999999998	Алтайский край, Благовещенский район, с.Мельниковка, Мичурина, 48		0101000020E61000002DEDD45C6EFD534023D8B8FE5D934A40
16600	5	47	900	7000	70024	\N	53.302585000000001	Алтайский край, Суетский район, с.Верх-Суетка, Целинная, 63		0101000020E6100000747D1F0E120354404DA1F31ABBA64A40
16599	5	47	900	6967	70859	\N	53.171362999999999	Алтайский край, Суетский район, п.Боронск, Центральная, 24		0101000020E6100000D95DA0A4C00554404A5F0839EF954A40
16594	5	47	513	59454	71464	\N	52.858132747296402	Алтайский край, Солтонский район, с.Шатобал, Центральная, 2	Россия, Алтайский край, Солтонский район, поселок Шатабол	0101000020E6100000EBC5504EB4A35540274F594DD76D4A40
16591	5	47	513	6566	71243	\N	52.527025999999999	Алтайский край, Солтонский район, с.Усть-Куют, Заводская, 13/2		0101000020E61000002C9D0FCF12A955402312859675434A40
94921	5	47	513	6668	70713	\N	52.889398	Алтайский край, Солтонский район, с.Урунск, Школьная, 6		0101000020E61000008C2D043928A255405C902DCBD7714A40
16597	5	47	513	6861	70975	\N	52.743853140832101	Алтайский край, Солтонский район, с.Тосток, ул.Центральная, д.5А	Россия, Алтайский край, Солтонский район, поселок Тосток	0101000020E610000081E9B46E83A1554008043A93365F4A40
16596	5	47	513	6803	70350	\N	52.781101	Алтайский край, Солтонский район, с.Сузоп, Центральная, 21		0101000020E6100000B2D991EA3BA85540BBEF181EFB634A40
16592	5	47	513	3147	69903	\N	52.837870000000002	Алтайский край, Солтонский район, с.Солтон, Ленина, 5		0101000020E6100000D68BA19C689E55405726FC523F6B4A40
16590	5	47	513	6511	71231	\N	52.569690999999999	Алтайский край, Солтонский район, с.Сайдып, Центральная, 2		0101000020E6100000C5ABAC6D8AA45540ABE97AA2EB484A40
16595	5	47	513	32835	71494	\N	52.789048156385199	Алтайский край, Солтонский район, Солтонский район, с.Ново-Троицк, ул.Центральная, д.6	Россия, Алтайский край, Солтонский район, поселок Новотроицк	0101000020E610000049A12C7C7DAF5540B37C5D86FF644A40
16587	5	47	513	6339	70862	\N	52.550837000000001	Алтайский край, Солтонский район, с.Новая Ажинка, Боровая, 27А		0101000020E610000004392861A6945540A036AAD381464A40
16588	5	47	513	6430	70576	\N	52.730702999999998	Алтайский край, Солтонский район, с.Нижняя Ненинка, Жданова, 55		0101000020E6100000C26C020CCB995540670B08AD875D4A40
16586	5	47	513	6326	70714	\N	52.671821999999999	Алтайский край, Солтонский район, с.Ненинка, Октябрьская, 47		0101000020E61000004B917C25908C5540DD5D6743FE554A40
16585	5	47	513	6263	71238	\N	52.990898000000001	Алтайский край, Солтонский район, с.Макарьевка, Полевая, 28		0101000020E6100000BEC1172653A35540FED5E3BED57E4A40
16582	5	47	513	6110	71042	\N	52.802533168651301	Алтайский край, Солтонский район, с.Караган, Нагорная, 2	Россия, Алтайский край, Солтонский район, поселок Караган	0101000020E6100000CF49EF1B5F965540FA7ABE66B9664A40
16583	5	47	513	6129	70494	\N	52.688479999999998	Алтайский край, Солтонский район, с.Карабинка, 50 лет Победы, 5		0101000020E610000040BFEFDFBC8F55409CF9D51C20584A40
16584	5	47	513	6216	71394	\N	52.915360999999997	Алтайский край, Солтонский район, с.Излап, Центральная, 10		0101000020E6100000813D26529AA7554055849B8C2A754A40
16780	5	47	513	15514	71048	\N	52.788246999999998	Алтайский край, Тюменцевский район, с.Вознесенка, Луговая, 24		0101000020E61000007C9E3F6D54AC5540C6151747E5644A40
16581	5	47	513	6040	70858	\N	52.881838999999999	Алтайский край, Солтонский район, с.Березово, Центральная, 1		0101000020E6100000F374AE28259455402EABB019E0704A40
16589	5	47	513	6489	70860	\N	52.773246	Алтайский край, Солтонский район, с.Акатьево, Береговая, 4А		0101000020E6100000904AB1A3719D5540A4E194B9F9624A40
16562	5	47	714	5028	71230	\N	51.814140000000002	Алтайский край, Солонешенский район, с. Юртное, Советская, 24		0101000020E6100000419E5DBEF50E5540C72E51BD35E84940
16565	5	47	714	5206	70817	\N	51.749167	Алтайский край, Солонешенский район, с. Черемшанка, ул. Октябрьская, д. 45		0101000020E610000018D2E1218C125540081F4AB4E4DF4940
16575	5	47	714	5738	71234	\N	51.596128	Алтайский край, Солонешенский район, с. Туманово, Советская, 25		0101000020E610000077D7D9907F2955406D1D1CEC4DCC4940
16579	5	47	714	5944	70571	\N	51.509801000000003	Алтайский край, Солонешенский район, с. Топольное, Виталия Табачкова, 32В		0101000020E61000006FD74B53041F5540EB3BBF2841C14940
16570	5	47	714	5448	71310	\N	51.530016000000003	Алтайский край, Солонешенский район, с. Тележиха, ул. Петра Сухова, д. 49		0101000020E610000035CF11F92E125540AA2D7590D7C34940
16564	5	47	714	5134	70808	\N	51.632061	Алтайский край, Солонешенский район, с. Тальменка, ул. Центральная, д. 30		0101000020E61000001A868F8829075540DD09F65FE7D04940
16578	5	47	714	5880	71139	\N	51.503466000000003	Алтайский край, Солонешенский район, с. Степное, ул. Центральная, д. 6, (ул. Подгорная, д.31а)		0101000020E6100000501DAB949E275540F052EA9271C04940
16568	5	47	714	5236	70177	\N	51.65578	Алтайский край, Солонешенский район, с. Солонешное, Советская, 31		0101000020E6100000E84F1BD5E913554079AF5A99F0D34940
16563	5	47	714	5078	70656	\N	51.745375000000003	Алтайский край, Солонешенский район, с. Сибирячиха, ул. Советская, д. 43		0101000020E61000003A5D16139B035540C520B07268DF4940
16580	5	47	714	6001	71041	\N	51.38232	Алтайский край, Солонешенский район, с. Рыбное, Школьная, 9		0101000020E61000005C3AE63C631A5540A94D9CDCEFB04940
16574	5	47	714	5692	71188	\N	51.700926000000003	Алтайский край, Солонешенский район, с. Новая Жизнь, ул. Коммунарская, д. 8		0101000020E610000011E50B5A482C5540437573F1B7D94940
16571	5	47	714	5535	71311	\N	51.885334999999998	Алтайский край, Солонешенский район, с. Лютаево, ул. Центральная, д. 9, (ул. Центральная, д. 3)		0101000020E61000004C6F7F2E1A1B5540888043A852F14940
16572	5	47	714	5556	71133	\N	51.841186	Алтайский край, Солонешенский район, с. Карпово, ул. Набережная, д. 1		0101000020E6100000575D876A4A24554031ED9BFBABEB4940
16569	5	47	714	5392	71233	\N	51.563234999999999	Алтайский край, Солонешенский район, с. Искра, Школьная, 13		0101000020E61000007C992842EA195540357BA01518C84940
16577	5	47	714	5848	71146	\N	51.561858000000001	Алтайский край, Солонешенский район, с. Дёмино, ул. Кокорина, д. 13		0101000020E6100000DF1797AAB42F55407C7F83F6EAC74940
16573	5	47	714	5633	71117	\N	51.791167000000002	Алтайский край, Солонешенский район, с. Большая Тихая, ул. Советская, д. 1		0101000020E61000009D668176872A55405456D3F544E54940
16561	5	47	714	4985	70972	\N	51.835960999999998	Алтайский край, Солонешенский район, с. Березовка, ул. Восточная, д. 4		0101000020E61000008CDCD3D51D035540A0DD21C500EB4940
16598	5	47	714	32610	70351	\N	51.672617000000002	Алтайский край, Суетский район, с.Александровка, Победы, 50		0101000020E6100000FA997ADD22FD5440E8DD585018D64940
16560	5	47	559	4940	\N	\N	52.433278157730399	Алтайский край, Советский район, с.Шульгинка, д.Школьная, д.3, корп.А	Россия, Алтайский край, Советский район, поселок Шульгинка	0101000020E6100000C18BBE8234545540C4094CA775374A40
16552	5	47	559	4513	70348	\N	52.171149	Алтайский край, Советский район, с.Шульгин Лог, ул.Школьная, д.67		0101000020E61000008A93FB1D8A7655401EDFDE35E8154A40
16554	5	47	559	4613	71271	\N	52.260041000000001	Алтайский край, Советский район, с.Хуторки, ул.Центральная, д.36		0101000020E61000006DE525FF93735540404F030649214A40
16553	5	47	559	4544	69962	\N	52.305388999999998	Алтайский край, Советский район, с.Урожайное, ул.Автозаводская, д.17		0101000020E6100000B119E0826C69554071C79BFC16274A40
16556	5	47	559	4731	71045	\N	52.391200741744598	Алтайский край, Советский район, с.Талица, ул.Сибирская, д.35	Россия, Алтайский край, Советский район, поселок Талица	0101000020E6100000C0EC9E3C2C6B5540CD94D6DF12324A40
16544	5	47	559	3992	70021	\N	52.285102999999999	Алтайский край, Советский район, с.Советское, ул.Октябрьская, д.40		0101000020E61000002A91442FA35A5540E97E4E417E244A40
16543	5	47	559	3992	70021	\N	52.285102999999999	Алтайский край, Советский район, с.Советское, ул.Октябрьская, д.2		0101000020E61000002A91442FA35A5540E97E4E417E244A40
16548	5	47	559	4287	70569	\N	52.198270999999998	Алтайский край, Советский район, с.Сетовка, ул.Советская, д.49, корп.Б		0101000020E61000002AE27492AD5E5540635FB2F160194A40
16555	5	47	559	4649	71043	\N	52.299965	Алтайский край, Советский район, с.Семилетка, ул.Садовая, д.3		0101000020E6100000D3C1FA3F87675540EA78CC4065264A40
16549	5	47	559	4354	70707	\N	52.187936000000001	Алтайский край, Советский район, с.Половинка, ул.Центральная, д.40		0101000020E6100000492D944C4E675540DBDE6E490E184A40
16551	5	47	559	4465	71227	\N	52.078834000000001	Алтайский край, Советский район, с.Платово, ул.Молодежная, д.3		0101000020E6100000FA635A9BC67955400CE8853B170A4A40
16545	5	47	559	4128	70349	\N	52.210760999999998	Алтайский край, Советский район, с.Никольское, пер.Школьный, д.4		0101000020E6100000C843DFDDCA505540D9226937FA1A4A40
16533	5	47	559	3474	70950	\N	52.290596000000001	Алтайский край, Смоленский район, с.Ленинское, Красноярская, 11		0101000020E610000058CB9D9960535540992CEE3F32254A40
16559	5	47	559	4881	70575	\N	52.356141999999998	Алтайский край, Советский район, с.Красный Яр, ул.Центральная, д.29		0101000020E610000057B08D78B2555540B35DA10F962D4A40
16550	5	47	559	4368	71402	\N	52.085079161270997	Алтайский край, Советский район, с.Колово, ул.Советская, д.3	Россия, Алтайский край, Советский район, поселок Колово	0101000020E610000018EDF1423A685540C74961DEE30A4A40
16546	5	47	559	4173	71033	\N	52.163342999999998	Алтайский край, Советский район, с.Колбаны, ул.Молодежная, д.2		0101000020E61000009CDEC5FB71505540E883656CE8144A40
16557	5	47	559	4789	70623	\N	52.382480000000001	Алтайский край, Советский район, с.Кокши, ул.Советская, д.35		0101000020E61000000F48C2BE9D625540E2AFC91AF5304A40
16558	5	47	559	4818	71254	\N	52.384898999999997	Алтайский край, Советский район, с.Карасук, ул.Ветеранов, д.21		0101000020E6100000782AE09EE7655540ADA1D45E44314A40
16547	5	47	559	4218	70766	\N	52.196261999999997	Алтайский край, Советский район, с.Глинка, ул.Центральная, д.30, корп.В		0101000020E6100000D7F6764B7255554049B9FB1C1F194A40
16531	5	47	365	3390	71112	\N	52.142516999999998	Смоленский район, пос.Южный, ул.Советская, д.6		0101000020E61000001B4641F0F8325540E00F3FFF3D124A40
16541	5	47	365	3903	71054	\N	51.965412999999998	Алтайский край, Смоленский район, с.Черновая, Нагорная, 3		0101000020E6100000B9C49107223055400E1137A792FB4940
16520	5	47	365	2762	71389	\N	52.418832999999999	Алтайский край, Смоленский район, пос. Усть-Катунь, Комсомольская, 37		0101000020E61000001DE6CB0BB043554027BEDA519C354A40
16540	5	47	365	3869	69848	\N	52.157479071422898	Смоленский район, с.Точильное, ул.Школьная, д.21	Россия, Алтайский край, Смоленский район, поселок Точильное	0101000020E6100000B8CB7EDDE94155404567994528144A40
16539	5	47	365	3784	70020	\N	52.051057	Алтайский край, Смоленский район, с.Сычевка, Центральная, 33		0101000020E6100000DE019EB470315540AE9D280989064A40
16524	5	47	365	2985	71303	\N	52.190057000000003	Смоленский район, с.Степное, ул.Озерная, д.6		0101000020E610000026FC523F6F3955401DB0ABC953184A40
16518	5	47	365	2666	71399	\N	52.350911000000004	Алтайский край, Смоленский район, с.Старотырышкино, Каньшакова, 1а		0101000020E6100000016C4084B83455404167D2A6EA2C4A40
16538	5	47	365	3780	69852	\N	52.000003	Смоленский район, с.Солоновка, ул.Советская, д.64		0101000020E6100000DB368C82E027554071732A1900004A40
16534	5	47	365	3577	69906	\N	52.299804999999999	Алтайский край, Смоленский район, с.Смоленское, Энергетическая, 1		0101000020E6100000E560360186455540B1169F0260264A40
16536	5	47	365	3577	69673	\N	52.3105595235143	Смоленский район, 659600, с.Смоленское, ул.Советская, д.144	Россия, Алтайский край, Смоленский район, поселок Смоленское	0101000020E6100000F415A4198B4455400FB9196EC0274A40
16537	5	47	365	3577	71391	\N	52.299804999999999	Алтайский край, Смоленский район, с.Смоленское, Песчаная, 71а		0101000020E6100000E560360186455540B1169F0260264A40
16535	5	47	365	3577	69778	\N	52.299804999999999	Алтайский край, Смоленский район, с.Смоленское, Красноярская, 94		0101000020E6100000E560360186455540B1169F0260264A40
16526	5	47	365	3135	71236	\N	52.391658999999997	Алтайский край, Смоленский район, с.Песчаное, Онухова, 15а		0101000020E6100000ED461FF3013855408F17D2E121324A40
16532	5	47	365	3470	71390	\N	52.283583	Алтайский край, Смоленский район, с.Первомайское, Совхозная, 9		0101000020E61000009E0B23BDA84D5540CD599F724C244A40
16530	5	47	365	1978	70107	\N	52.087705999999997	Смоленский район, с.Новотырышкино, ул.Советская, д.78		0101000020E6100000D4EFC2D66C3A5540DCD440F3390B4A40
16529	5	47	365	3037	71119	\N	52.368507011936401	Смоленский район, пос.Линевский, ул.им.Волкова, д.10	Россия, Алтайский край, Смоленский район, поселок Линевский	0101000020E61000005F7B6649803E55406DACC43C2B2F4A40
16525	5	47	365	3037	70529	\N	52.365194000000002	Алтайский край, Смоленский район, пос.Линевский, Скорикова, 2		0101000020E6100000FE481119563E554004594FADBE2E4A40
16542	5	47	365	59451	71458	\N	51.978659947811899	Алтайский край, Смоленский район, пос.Красный Городок, Центральная, 20	Россия, Алтайский край, Смоленский район, поселок Красный Городок	0101000020E61000003961C268562A5540A1F31ABB44FD4940
16522	5	47	365	1868	69668	\N	52.292948000000003	Смоленский район, пос.Кировский, ул.Нагорная, д.7		0101000020E61000003D7E6FD39F415540DDB6EF517F254A40
16521	5	47	365	2821	70704	\N	52.409874000000002	Алтайский край, Смоленский район, с.Катунское, Мальцева, 61а		0101000020E61000004D8237A45147554088BD50C076344A40
16519	5	47	365	2676	69901	\N	52.418470999999997	Алтайский край, Смоленский район, пос.Верх-Обский, Центральная, 14г		0101000020E6100000C2DD59BBED40554086A92D7590354A40
15446	5	47	365	8225	70095	\N	51.990969999999997	Алтайский край, город Белокуриха, Шукшина, 1		0101000020E6100000D3F544D7853D554097A8DE1AD8FE4940
15308	5	47	365	8225	70390	\N	51.998053382061201	Алтайский край, город Белокуриха, Соболева, 24	Россия, Алтайский край, Смоленский район, город Белокуриха	0101000020E6100000A7ECF483BA3D55405C566133C0FF4940
15420	5	47	365	8225	70077	\N	51.991059479362498	Алтайский край, город Белокуриха, Объездная, 2	Россия, Алтайский край, Смоленский район, город Белокуриха	0101000020E6100000FB1EF5D72B3D554007B47405DBFE4940
15395	5	47	365	8225	70076	\N	51.990969999999997	Алтайский край, город Белокуриха, Бийская, 40		0101000020E6100000D3F544D7853D554097A8DE1AD8FE4940
15448	5	47	365	8225	69600	\N	51.990969999999997	Алтайский край, город Белокуриха, Академика Мясникова, 24/1		0101000020E6100000D3F544D7853D554097A8DE1AD8FE4940
15445	5	47	365	8225	69600	\N	51.990969999999997	Алтайский край, город Белокуриха, Академика Мясникова, 18/1		0101000020E6100000D3F544D7853D554097A8DE1AD8FE4940
16517	5	47	365	2579	70703	\N	52.300719000000001	Алтайский край, Смоленский район, с.Ануйское, Центральная, 10		0101000020E6100000D237691A143755409624CFF57D264A40
16523	5	47	365	2930	71040	\N	52.226027999999999	Алтайский край, Смоленский район, с.Александровка, Зеленая, 10		0101000020E6100000D46531B1F94255407AFD497CEE1C4A40
16514	5	47	1687	59397	70508	\N	53.090086999999997	Алтайский край, г.Славгород, с.Семеновка, Кулундинская, 10		0101000020E61000005AF44E05DCBE5340BA6587F8878B4A40
16511	5	47	1687	59397	71430	\N	53.002652784231501	Алтайский край, г.Славгород, с.Пригородное, Гагарина, 24а		0101000020E6100000AA6395D233AC53403F1EFAEE56804A40
16512	5	47	1687	59375	70029	\N	52.9783825026419	Алтайский край, г.Славгород, с.Селекционное, Молодежная, 14а	Россия, Алтайский край, Славгородский район, поселок Селекционное	0101000020E610000078D1579066A653402FFB75A73B7D4A40
16513	5	47	1687	59435	71314	\N	52.863861497599601	Алтайский край, г.Славгород, с.Райгород, Первомайская, 41	Россия, Алтайский край, Славгородский район, поселок Райгород	0101000020E6100000EE224C512E9A53401AA54BFF926E4A40
16285	5	47	1687	32590	70346	\N	52.966265	Алтайский край, г.Славгород, с.Покровка, Школьная, 5		0101000020E6100000ECF99AE5B29953407D224F92AE7B4A40
16509	5	47	1687	59416	70880	\N	53.090308999999998	Алтайский край, г.Славгород, с.Максимовка, Центральная, 47	Россия, Алтайский край, Славгородский район, поселок Максимовка	0101000020E61000003AAFB14B54B1534069C4CC3E8F8B4A40
16255	5	47	1687	22318	69588	\N	53.149999000000001	Алтайский край, Немецкий национальный район, с.Гришковка, Ленина, 71		0101000020E61000000AA0185932B0534063B7CF2A33934A40
15656	5	47	1687	59418	\N	\N	53.124623794604403	Алтайский край, г.Славгород, п.Баластный карьер, школа № 23	Россия, Алтайский край, Славгородский район, поселок Балластный Карьер	0101000020E6100000FDDD3B6A4CA15340FA25E2ADF38F4A40
16516	5	47	1687	59424	71055	\N	53.087173261346202	Алтайский край, г.Славгород, с.Архангельское, Красных Партизан, 23	Россия, Алтайский край, Славгородский район, поселок Архангельское	0101000020E61000006BD619DF17A953400F0C207C288B4A40
16506	5	47	160	1974	71277	\N	51.804696	Алтайский край, Рубцовский район, с.Тишинка, Центральная, 47		0101000020E61000000C5BB395975454406B9C4D4700E74940
16505	5	47	160	1875	70622	\N	51.381881999999997	Алтайский край, Рубцовский район, с.Саратовка, Новая, 6		0101000020E61000000DA7CCCD376954402D776682E1B04940
16504	5	47	160	1824	70573	\N	51.372982	Алтайский край, Рубцовский район, с.Самарка, Ленина, 17		0101000020E6100000D65240DAFF50544093FFC9DFBDAF4940
16495	5	47	160	1295	70865	\N	51.379406091014303	Алтайский край, Рубцовский район, с.Романовка, Молодежная, 11	Россия, Алтайский край, Рубцовский район, поселок Романовка	0101000020E6100000ED7F80B56A605440FEF3346090B04940
16503	5	47	160	1777	70493	\N	51.441327999999999	Алтайский край, Рубцовский район, с. Ракиты, Октябрьская, 26в		0101000020E6100000F8FBC56CC92C54409067976F7DB84940
16502	5	47	160	1728	70903	\N	51.529819000000003	Алтайский край, Рубцовский район, п. Пушкино, Новая, 25	Россия, Алтайский край, Рубцовский район, поселок Пушкино	0101000020E610000043FE99417C47544054E6E61BD1C34940
16986	5	47	160	25670	70884	\N	51.573424000000003	Алтайский край, Рубцовский район, пос.Приозерный, Школьная, 2/2		0101000020E6100000A04FE449D24C5440EA5E27F565C94940
16498	5	47	160	1486	70279	\N	51.421835661897802	Алтайский край, Рубцовский район, с.Половинскино, Советская, 70	Россия, Алтайский край, Рубцовский район, поселок Половинкино	0101000020E6100000B476DB85E64E54404223D8B8FEB54940
16497	5	47	160	1436	70705	\N	51.543080000000003	Алтайский край, Рубцовский район, с. Новосклюиха, Мира, 38		0101000020E6100000A4703D0AD75954404C8E3BA583C54940
16494	5	47	160	1284	70174	\N	51.3525610956642	Алтайский край, Рубцовский район, с. Новониколаевка, Вовченко, 4	Россия, Алтайский край, Рубцовский район, поселок Новониколаевка	0101000020E61000005CFFAECF9C5E54402B6C06B820AD4940
16493	5	47	160	1182	69746	\N	51.373303	Алтайский край, Рубцовский район, с.Новоалександровка, Центральная, 21		0101000020E61000002638F581E44A5440D53F8864C8AF4940
16500	5	47	160	1630	71223	\N	51.464759999999998	Алтайский край, Рубцовский район, п. Мичуринский, Центральная, 38		0101000020E6100000E0F60489ED495440963E74417DBB4940
16981	5	47	160	1169	69730	\N	51.753608041206903	Алтайский край, с.Мамонтово, Советская, 19	Россия, Алтайский край, Рубцовский район, поселок Мамонтово	0101000020E61000001E5036E50A5A54408200193A76E04940
16226	5	47	160	1169	69730	\N	51.752172000000002	Алтайский край, с.Мамонтово, Советская, 142		0101000020E6100000849B8C2AC3595440C47B0E2C47E04940
16229	5	47	160	1169	69734	\N	51.752172000000002	Алтайский край, с.Мамонтово, Партизанская, 314		0101000020E6100000849B8C2AC3595440C47B0E2C47E04940
16228	5	47	160	1169	69734	\N	51.751636999059897	Алтайский край, с.Мамонтово, ул.Партизанская, д.162 (ул.Пушкинская, д.12)	Россия, Алтайский край, Рубцовский район, поселок Мамонтово	0101000020E610000048895DDBDB59544056BB26A435E04940
16227	5	47	160	1169	69734	\N	51.752172000000002	Алтайский край, с.Мамонтово, Партизанская, 188		0101000020E6100000849B8C2AC3595440C47B0E2C47E04940
16492	5	47	160	1169	71038	\N	51.750616999999998	Алтайский край, Рубцовский район, ст.Мамонтово, Комсомольская, 19		0101000020E6100000965E9B8D955954402B69C53714E04940
16230	5	47	160	1169	69722	\N	51.752172000000002	Алтайский край, с.Мамонтово, Захарова, 65		0101000020E6100000849B8C2AC3595440C47B0E2C47E04940
16491	5	47	160	1052	70359	\N	51.580267404130801	Алтайский край, Рубцовский район, п.Куйбышево, Центральная, 4	Россия, Алтайский край, Рубцовский район, поселок Куйбышево	0101000020E6100000CCD078228848544059F9653046CA4940
16501	5	47	160	1645	71228	\N	51.423437999999997	Алтайский край, Рубцовский район, п.Колос, Топольная, 10		0101000020E6100000B4739A05DA4854401BF1643733B64940
16485	5	47	160	720	71032	\N	51.655377999999999	Алтайский край, Рубцовский район, с.Катково, Баталова, 25		0101000020E6100000EA961DE21F5D54404A42226DE3D34940
16499	5	47	160	1537	70347	\N	51.456887000000002	Алтайский край, Рубцовский район, п. Зеленая Дубрава, Топольная, 24		0101000020E610000064062AE3DF4B5440D97BF1457BBA4940
16481	5	47	160	471	70852	\N	51.657908999999997	Алтайский край, Рубцовский район, с.Захарово, Ленина, 52		0101000020E61000007590D783495554403D5FB35C36D44940
16490	5	47	160	1046	70699	\N	51.479353000000003	Алтайский край, Рубцовский район, п. Дальний, Центральный, 9		0101000020E610000036ACA92C0A6C5440A81E69705BBD4940
16489	5	47	160	961	70565	\N	51.358935000000002	Алтайский край, Рубцовский район, с. Вишневка, Молодежная, 34		0101000020E61000001AFA27B858625440E4310395F1AD4940
16487	5	47	160	841	69907	\N	51.282280999999998	Алтайский край, Рубцовский район, с. Веселоярск, Центральный, 3		0101000020E61000001B67D311C04654401EA4A7C821A44940
16488	5	47	160	841	70175	\N	51.282280999999998	Алтайский край, Рубцовский район, с.Веселоярск, Куйбышева, 14		0101000020E61000001B67D311C04654401EA4A7C821A44940
16486	5	47	160	788	70701	\N	51.419680999999997	Алтайский край, Рубцовский район, с.Большая Шелковка, Советская, 55		0101000020E610000050340F609129544054E0641BB8B54940
16484	5	47	160	683	70489	\N	51.669735000000003	Алтайский край, Рубцовский район, с. Бобково, Новая, 5		0101000020E6100000C26D6DE17959544048FE60E0B9D54940
16483	5	47	160	570	70566	\N	51.561560999999998	Алтайский край, Рубцовский район, п. Березовка, Молодежная, 1а		0101000020E610000087191A4F04535440C2DA183BE1C74940
16482	5	47	160	565	70181	\N	51.585552	Алтайский край, Рубцовский район, с.Безрукавка, Советская, 20		0101000020E61000006002B7EEE6515440BF0D315EF3CA4940
16480	5	47	43	411	70563	\N	52.653553000000002	Алтайский край, Романовский район, пос.Тамбовский, Центральная, 1А		0101000020E6100000FCE42840143F5440F299EC9FA7534A40
16479	5	47	43	334	70018	\N	52.548011000000002	Алтайский край, Романовский район, с.Сидоровка, Советская, 87		0101000020E610000055849B8C2A305440946C753925464A40
16477	5	47	43	180	69899	\N	52.621259999999999	Алтайский край, Романовский район, с.Романово, Советская, 52		0101000020E61000006C5CFFAECF4E54400F289B72854F4A40
16476	5	47	43	180	69899	\N	52.621259999999999	Алтайский край, Романовский район, с.Романово, Советская, 62		0101000020E61000006C5CFFAECF4E54400F289B72854F4A40
16478	5	47	43	180	69753	\N	52.621259999999999	Алтайский край, Романовский район, с.Романово, Мамонтовская, 59		0101000020E61000006C5CFFAECF4E54400F289B72854F4A40
16475	5	47	43	51	70925	\N	52.735764000000003	Алтайский край, Романовский район, пос.Рассвет, Школьная, 2		0101000020E6100000E6E61BD13D5C54407EC9C6832D5E4A40
16473	5	47	43	32442	71387	\N	52.453069999999997	Алтайский край, Романовский район, с.Мормыши, Захарова, 30		0101000020E61000006859F78F854D54403C66A032FE394A40
16471	5	47	43	32339	71224	\N	52.767688	Алтайский край, Романовский район, пос.Майский, пер.Школьный, 5		0101000020E61000003D1059A4895654400DC4B29943624A40
16472	5	47	43	32371	71035	\N	52.660271999999999	Алтайский край, Романовский район, с.Казанцево, Школьная, 5		0101000020E61000003C50A73CBA5B5440753BFBCA83544A40
16470	5	47	43	32313	70401	\N	52.585856999999997	Алтайский край, Романовский район, с.Закладное, Советская, 6		0101000020E6100000CB64389ECF3F5440FB90B75CFD4A4A40
16469	5	47	43	32265	70863	\N	52.677812000000003	Алтайский край, Романовский район, с.Дубровино, Советская, 45А		0101000020E6100000892991442F3854400E6B2A8BC2564A40
16468	5	47	43	32199	70344	\N	52.551209	Алтайский край, Романовский район, с.Гуселетово, 30 лет Победы, 1		0101000020E61000001D041DAD6A57544064213A048E464A40
16467	5	47	43	32181	71385	\N	52.410099000000002	Алтайский край, Романовский район, с.Грановка, Титова, 12		0101000020E6100000CA501553E93D5440A88FC01F7E344A40
16466	5	47	43	32127	70379	\N	52.773158000000002	Алтайский край, Романовский район, с.Гилев-Лог, Советская, 88		0101000020E6100000C2FC153257455440055262D7F6624A40
16474	5	47	43	32457	70854	\N	52.436394	Алтайский край, Романовский район, пос.Бурановка, Молодежная, 19		0101000020E61000000B26FE28EA495440D71533C2DB374A40
16465	5	47	180	32072	70378	\N	52.269069000000002	Алтайский край, Родинский район, с. Ярославцев Лог, Ленина, 53		0101000020E61000009E0AB8E7F905544008AF5DDA70224A40
16464	5	47	180	32050	70341	\N	52.4011	Алтайский край, Родинский район, с. Шаталовка, Садовая, 22		0101000020E61000007ADE8D0585FD53407A36AB3E57334A40
16462	5	47	180	31941	70558	\N	52.300829	Алтайский край, Родинский район, с. Центральное, Школьная, 2		0101000020E6100000F2B22616F81954401D588E9081264A40
16458	5	47	180	31790	71221	\N	52.591990000000003	Алтайский край, Родинский район, п. Тизек, Комсомольская, 5		0101000020E610000042EBE1CB44F653408FC70C54C64B4A40
16460	5	47	180	31865	70340	\N	52.597000999999999	Алтайский край, Родинский район, с. Степной Кучук, Гагарина, 3а		0101000020E6100000A0DFF76F5E165440F3565D876A4C4A40
16461	5	47	180	31929	70017	\N	52.634193000000003	Алтайский край, Родинский район, с. Степное, Садовая, 9		0101000020E6100000F0FACC599F1E5440132D793C2D514A40
16253	5	47	180	22233	69889	\N	52.493899999999996	Алтайский край, Родинский район, с. Родино, Шевченко, 5а		0101000020E6100000F4A5B73F170D544048BF7D1D383F4A40
16301	5	47	180	22233	69900	\N	52.493797693475997	Алтайский край, Родинский район, с. Родино, Мелиораторов, 5	Россия, Алтайский край, Родинский район, поселок Родино	0101000020E6100000A5BBEB6CC80C5440446ADAC5343F4A40
16269	5	47	180	22233	69944	\N	52.493899999999996	Алтайский край, Родинский район, с. Родино, Ленина, 234		0101000020E6100000F4A5B73F170D544048BF7D1D383F4A40
16457	5	47	180	31721	71018	\N	52.557434000000001	Алтайский край, Родинский район, с. Разумовка, Ленина, 15а		0101000020E6100000B1E1E995B2EE5340D8D64FFF59474A40
16456	5	47	180	567	70634	\N	52.493115000000003	Алтайский край, Родинский район, с. Раздольное, ул.Детсадовская, д.1		0101000020E6100000AE65321CCFFC534062156F641E3F4A40
16454	5	47	180	31591	70697	\N	52.766216999999997	Алтайский край, Родинский район, с. Покровка, Аврамкова, 71		0101000020E61000006E19709692185440D2510E6613624A40
16453	5	47	180	27453	70816	\N	52.654192000000002	Алтайский край, Родинский район, п. Новотроицк, ул.Первомайская, д.9		0101000020E610000044183F8D7B09544005A73E90BC534A40
94920	5	47	180	31514	69745	\N	52.558573000000003	Алтайский край, Родинский район, п. Мирный, Ленина, 19а		0101000020E61000001BBCAFCA850A5440DDB6EF517F474A40
16463	5	47	180	59462	71480	\N	52.2869771584148	Алтайский край, Родинский район, п. Красный Алтай, Новая, 2	Россия, Алтайский край, Родинский район, поселок Красный Алтай	0101000020E61000006AF981AB3C13544023DA8EA9BB244A40
16451	5	47	180	31435	70491	\N	52.389681000000003	Алтайский край, Родинский район, с. Кочки, Партизанская, 1		0101000020E6100000684128EFE3295440B16F2711E1314A40
16449	5	47	180	31337	70846	\N	52.493510000000001	Алтайский край, Родинский район, с. Каяушка, Ленина, 25		0101000020E61000004C8C65FA251D5440DE1FEF552B3F4A40
16448	5	47	180	31272	71030	\N	52.370939999999997	Алтайский край, Родинский район, с. Зелёный Луг, Школьная, 10а		0101000020E6100000E8F4BC1B0B0954409D6340F67A2F4A40
16450	5	47	180	28349	71308	\N	52.488366999999997	Алтайский край, Родинский район, п. Зелёная Дубрава, пер. Восточный д.4 (пер.Восточный д.6)		0101000020E61000001570CFF3A72554400AB952CF823E4A40
16455	5	47	180	31660	71039	\N	52.81973	Алтайский край, Родинский район, п. Вячеславка, Советская, 26		0101000020E6100000416667D13B1C544069C6A2E9EC684A40
16447	5	47	180	31237	71383	\N	52.337833000000003	Алтайский край, Родинский район, с. Вознесенка, Сухова, 85		0101000020E6100000B56D1805C11C54403A419B1C3E2B4A40
16425	5	47	118	59377	70031	\N	53.008785402813899	Алтайский край, Ребрихинский район, ст.Ребриха, ул.Касмалинская, 33	Россия, Алтайский край, Ребрихинский район	0101000020E6100000E3DEFC868993544002D9EBDD1F814A40
16436	5	47	118	328	70643	\N	53.223533000000003	Алтайский край, Ребрихинский район, с.Ясная Поляна, ул.Комсомольская, 2		0101000020E610000093AB58FCA68E5440D449B6BA9C9C4A40
16433	5	47	118	276	70292	\N	53.120924000000002	Алтайский край, Ребрихинский район, с.Шумилиха, ул.Ленина, 84		0101000020E610000030D63730B97C544098A608707A8F4A40
16435	5	47	118	27345	69976	\N	53.255382833663703	Алтайский край, Ребрихинский район, с.Усть-Мосиха, ул.Центральная, 2	Россия, Алтайский край, Ребрихинский район, поселок Усть-Мосиха	0101000020E6100000967A1684F2815440297AE063B0A04A40
16445	5	47	118	27397	70410	\N	52.863309999999998	Алтайский край, Ребрихинский район, с.Рожнев-Лог, ул.Ленина, 40		0101000020E610000091D442C9E49C5440A6272CF1806E4A40
16423	5	47	118	29957	70345	\N	53.073751999999999	Алтайский край, Ребрихинский район, с.Ребриха, пр-т Победы, 73		0101000020E610000041D5E8D500965440DE019EB470894A40
16422	5	47	118	29957	69760	\N	53.074369330055703	Алтайский край, Ребрихинский район, с.Ребриха, пр-т Победы, 47	Россия, Алтайский край, Ребрихинский район, поселок Ребриха	0101000020E6100000EFC7ED974F965440096B63EC84894A40
16442	5	47	118	29957	70186	\N	53.073751999999999	Алтайский край,  Ребрихинский район, с.Ребриха, ул.Партизанская, 68		0101000020E610000041D5E8D500965440DE019EB470894A40
16424	5	47	118	29957	70332	\N	53.073751999999999	Алтайский край,  Ребрихинский район, с.Ребриха, ул.Максима Горького, 50		0101000020E610000041D5E8D500965440DE019EB470894A40
16421	5	47	118	29957	70014	\N	53.073751999999999	Алтайский край, Ребрихинский район, с.Ребриха, ул.Ленина, 134		0101000020E610000041D5E8D500965440DE019EB470894A40
16430	5	47	118	30368	70490	\N	52.965114999999997	Алтайский край, Ребрихинский район, с.Подстепное, ул.50 лет ВЛКСМ, 2		0101000020E6100000FE463B6EF885544084F068E3887B4A40
16444	5	47	118	31119	70839	\N	52.996529000000002	Алтайский край, Ребрихинский район, пос.Плоскосеминский, ул.Школьная, 34а		0101000020E61000001C28F04E3E9F5440FF4124438E7F4A40
16446	5	47	118	31202	71131	\N	52.938465000000001	Алтайский край, Ребрихинский район, пос.Пеньки, пер.Степной, здание сельского клуба		0101000020E6100000956247E35099544067B8019F1F784A40
16431	5	47	118	27305	70648	\N	52.987026999999998	Алтайский край, Ребрихинский район, с.Паново, ул.Кузбасс, 1		0101000020E6100000A3CC0699648954406EA296E6567E4A40
16439	5	47	118	30834	70836	\N	53.115313999999998	Алтайский край, Ребрихинский район, пос.Орел, ул.Почтовая, 11		0101000020E610000079CDAB3AABA75440AE62F19BC28E4A40
16432	5	47	118	30501	71220	\N	52.998404999999998	Алтайский край, Ребрихинский район, пос.Молодежный, ул.Ленина, 6		0101000020E610000019C8B3CBB7885440D9942BBCCB7F4A40
16434	5	47	118	59426	71091	\N	53.200760000000002	Алтайский край, Ребрихинский район, с.Куликово, ул.Партизанская, 32		0101000020E6100000A0A86C5853795440282CF180B2994A40
16441	5	47	118	30960	71248	\N	53.025570000000002	Алтайский край, Ребрихинский район, пос.Ключевка, ул.Центральная, 26		0101000020E6100000787E5182FE9A54401EE1B4E045834A40
16438	5	47	118	30820	70334	\N	53.176237	Алтайский край, Ребрихинский район, с.Клочки, ул.Павловская, 39		0101000020E61000001442075DC2A454402EAC1BEF8E964A40
16443	5	47	118	476	70298	\N	52.954332000000001	Алтайский край, Ребрихинский район, с.Зимино, ул.Центральная, 59		0101000020E6100000DF87838428AD54405DC30C8D277A4A40
16440	5	47	118	59413	70841	\N	53.062559628555597	Алтайский край, Ребрихинский район, с.Зеленая Роща, ул.Зеленорощинская, 32	Россия, Алтайский край, Ребрихинский район, поселок Зеленая Роща	0101000020E6100000A0C03BF9F49F5440D50451F701884A40
16429	5	47	118	30349	70625	\N	52.856236000000003	Алтайский край, Ребрихинский район, с.Георгиевка, ул.Комсомольская, 61		0101000020E6100000849ECDAACF82544035D42824996D4A40
16428	5	47	118	27263	70415	\N	52.756926	Алтайский край, Ребрихинский район, с.Ворониха, ул.Советская, 2А		0101000020E610000023658BA4DD8D5440FDBE7FF3E2604A40
16437	5	47	118	401	70526	\N	53.186943999999997	Алтайский край, Ребрихинский район, с.Боровлянка, ул.Школьная, 29		0101000020E610000070ED4449489D54407A17EFC7ED974A40
16426	5	47	118	213	69853	\N	52.947566000000002	Алтайский край, Ребрихинский район, с.Белово, ул.Быкова, 7		0101000020E6100000D0622992AF9054409966BAD749794A40
16416	5	47	112	29701	70557	\N	52.006562000000002	Алтайский край, Поспелихинский район, пос. Хлебороб, ул.Садовая, д.19		0101000020E61000002D9622F94A6E5440BCB20B06D7004A40
16419	5	47	112	29864	71384	\N	51.994774	Алтайский край, Поспелихинский район, пос.Факел Социализма, ул.Молодежная, д.9		0101000020E610000030D5CC5A0A7954409F7422C154FF4940
16408	5	47	112	29343	70338	\N	51.874521999999999	Алтайский край, Поспелихинский район, п.Поспелихинский, ул.Школьная, д.9		0101000020E6100000A454C2137A765440F6D03E56F0EF4940
16402	5	47	112	29002	69761	\N	51.988190465400102	Алтайский край, Поспелихинский район, с.Поспелиха, ул.Целинная, д.12	Россия, Алтайский край, Поспелихинский район, поселок Поспелиха	0101000020E6100000BFBB95253A755440FC1D8A027DFE4940
16404	5	47	112	29002	69749	\N	51.784290685409999	Алтайский край, Поспелихинский район, с.Поспелиха, ул.Кондратюка, д.28	Россия, Алтайский край, Поспелихинский район, поселок Поспелиха	0101000020E610000055DCB8C5FCC6544009C6C1A563E44940
16400	5	47	112	29002	69975	\N	51.779172000000003	Алтайский край, Поспелихинский район, c.Поспелиха, ул.Коммунистическая, д.21	Россия, Алтайский край, Поспелихинский район, поселок Поспелиха	0101000020E61000000E164ED2FCC45440BEFA78E8BBE34940
16403	5	47	112	29002	69978	\N	51.990310082301001	Алтайский край, Поспелихинский район, с.Поспелиха, ул.Гончарова, д.48	Россия, Алтайский край, Поспелихинский район, поселок Поспелиха	0101000020E6100000990F0874267554406D73637AC2FE4940
16413	5	47	112	29579	70948	\N	51.805408999999997	Алтайский край, Поспелихинский район, с.Поломошное, ул.Школьная, д.2		0101000020E610000048895DDBDB6A5440B87361A417E74940
16414	5	47	112	29605	70523	\N	51.846834000000001	Алтайский край, Поспелихинский район, ст.Озимая, ул.Центральная, д.1		0101000020E6100000A1F7C610006354400892770E65EC4940
16496	5	47	112	1388	70353	\N	51.841197000000001	Алтайский край, Рубцовский район, п.Новороссийский, Центральный, 10		0101000020E61000005A4A969350585440253FE257ACEB4940
16361	5	47	1667	27213	69737	\N	53.506068999999997	Алтайский край, Первомайский район, с.Боровиха, ул.Вокзальная, 8		0101000020E61000006C7A50508AF554407C4276DEC6C04A40
16405	5	47	112	29227	69988	\N	51.8786059136498	Алтайский край, Поспелихинский район, с.Николаевка, ул.Ленинская, д.5	Россия, Алтайский край, Поспелихинский район, поселок Николаевка	0101000020E61000003CA41820D1835440E108522976F04940
16415	5	47	112	59371	69949	\N	51.752010841981402	Алтайский край, Поспелихинский район, с.Мамонтово, ул.Лермонтова, д.10	Россия, Алтайский край, Рубцовский район, поселок Мамонтово	0101000020E6100000751DAA29C9595440BB9D7DE541E04940
16412	5	47	112	26688	70522	\N	51.749602000000003	Алтайский край, Поспелихинский район, с.Красноярское, ул.Советская, д.17		0101000020E61000006F62484E26665440138255F5F2DF4940
16417	5	47	112	29770	71034	\N	52.111167999999999	Алтайский край, Поспелихинский район, пос. Котляровка, ул.Центральная, д.1		0101000020E6100000E4DBBB067D7654404D2EC6C03A0E4A40
16418	5	47	112	29799	70009	\N	52.153801999999999	Алтайский край, Поспелихинский район, с.Клепечиха, пер.Парковый, д.14		0101000020E6100000CEFA9463B26C54409A07B0C8AF134A40
16407	5	47	112	29308	70088	\N	51.891561000000003	Алтайский край, Поспелихинский район, с.Калмыцкие-Мысы, ул.Трактовая, д.35		0101000020E6100000321D3A3DEF915440CDB1BCAB1EF24940
16420	5	47	112	174	71126	\N	51.959969000000001	Алтайский край, Поспелихинский район,  пос.Вавилонский, ул.Дорожная, д.18		0101000020E61000002367614F3B7A54404016A243E0FA4940
16409	5	47	112	29379	70842	\N	51.844503000000003	Алтайский край, Поспелихинский район, п.Большевик, ул.Алейская, д.5		0101000020E61000004C8C65FA256F5440DC2F9FAC18EC4940
16410	5	47	112	29420	70487	\N	51.715347999999999	Алтайский край, Поспелихинский район, п.12 лет Октября, ул.Школьная, д.7		0101000020E610000081B1BE81C974544027A1F48590DB4940
16399	5	47	1848	28952	70698	\N	51.967970999999999	Алтайский край, Петропавловский район, с. Соловьиха, Ленина, 117/1		0101000020E6100000B7B3AF3C48085540FB3C4679E6FB4940
16398	5	47	1848	28864	69974	\N	52.074567000000002	Алтайский край, Петропавловский район, с. Петропавлвское, Партизанская, 21		0101000020E6100000F6EE8FF7AA065540302E55698B094A40
16397	5	47	1848	28864	69743	\N	52.074567000000002	Алтайский край, Петропавловский район, с. Петропавловское, Ленина, 105		0101000020E6100000F6EE8FF7AA065540302E55698B094A40
16396	5	47	1848	28823	70337	\N	52.214275999999998	Алтайский край, Петропавловский район, с. Паутово, Комсомольская, 6		0101000020E6100000CE88D2DEE0105540AA285E656D1B4A40
16395	5	47	1848	28750	70331	\N	52.236633511012698	Алтайский край, Петропавловский район, с. Новообинка, Советская, 82	Россия, Алтайский край, Петропавловский район, поселок Новообинка	0101000020E6100000A2D0B2EE1F045540938FDD054A1E4A40
16394	5	47	1848	28730	70486	\N	52.190150000000003	Алтайский край, Петропавловский район, с. Николаевка, Советская, 50		0101000020E610000017450F7C0C085540CEAACFD556184A40
16393	5	47	1848	28682	69957	\N	52.008823999999997	Алтайский край, Петропавловский район, с. Камышенка, Советская, 96		0101000020E6100000253D0CAD4E195540BFB5132521014A40
16392	5	47	1848	28626	70180	\N	52.120100000000001	Алтайский край, Петропавловский район, с. Зеленый Дол, Фрунзе, 10		0101000020E6100000077AA86DC3085540F31FD26F5F0F4A40
16391	5	47	1848	28557	69954	\N	52.002403999999999	Алтайский край, Петропавловский район, с. Антоньевка, Советская, 21		0101000020E61000004F401361C3FE544096B036C64E004A40
16390	5	47	1848	28541	69898	\N	52.059368999999997	Алтайский край, Петропавловский район, с. Алексеевка, Колхозная, 1Б		0101000020E6100000CAE0287975075540B7B2446799074A40
16383	5	47	1667	28193	70483	\N	53.316617000000001	Алтайский край, Первомайский район, с.Фирсово, ул.Центральная, 33		0101000020E6100000DFA815A6EFFC5440C72DE6E786A84A40
16357	5	47	1667	27044	70831	\N	53.763306999999998	Алтайский край, Первомайский район, с.Таловка, ул.Парковая, 6		0101000020E61000007497C4591108554068E7340BB4E14A40
16345	5	47	1667	26477	71393	\N	53.901477	Алтайский край, Первомайский район, с.Старокрайчиково, ул.Центральная, 20		0101000020E610000047551344DDF95440508C2C9963F34A40
16386	5	47	1667	28354	71026	\N	53.1227404692183	Алтайский край, Первомайский район, с.Сосновка, ул.Лесная, 92	Россия, Алтайский край, Первомайский район, поселок Сосновка	0101000020E610000010069E7B0F0255409DF4BEF1B58F4A40
16367	5	47	1667	27492	70169	\N	53.576765000000002	Алтайский край, Первомайский район, с.Сорочий Лог, ул.Центральная, 5		0101000020E610000081E84999D40955401D3D7E6FD3C94A40
16381	5	47	1667	28116	71380	\N	53.390819999999998	Алтайский край, Первомайский район, с.Солнечное, ул.Первая, 5б		0101000020E6100000C9AEB48CD4FF5440B54FC76306B24A40
16370	5	47	1667	25361	69738	\N	53.578395	Алтайский край, Первомайский район, пос.Сибирский, ул.Советская, 1		0101000020E6100000299485AFAFF05440C095ECD808CA4A40
16977	5	47	1667	25361	70229	\N	53.578395	Алтайский край, ЗАТО поселок Сибирский, Кедровая, ул.Строителей, д.5 (ул.40 лет РВСН, д.15 )		0101000020E6100000299485AFAFF05440C095ECD808CA4A40
16978	5	47	1667	25361	70043	\N	53.579976350208597	Алтайский край, ЗАТО поселок Сибирский, 40 лет РВСН, 9	Россия, Алтайский край, Первомайский район, поселок Сибирский	0101000020E6100000C61858C7F1F05440823B50A73CCA4A40
16976	5	47	1667	25361	70043	\N	53.577826498696702	Алтайский край, ЗАТО поселок Сибирский, 40 лет РВСН, 15	Россия, Алтайский край, Первомайский район, поселок Сибирский	0101000020E6100000D1CFD4EB16F15440A663CE33F6C94A40
16348	5	47	1667	26621	70165	\N	53.829276999999998	Алтайский край, Первомайский район, пос.Северный, ул.Ленина, 17		0101000020E61000006FB88FDC9AFF54409929ADBF25EA4A40
16382	5	47	1667	28163	69744	\N	53.347059000000002	Алтайский край, Первомайский район, с.Санниково, пер.Новый, 1		0101000020E6100000522976340EFE54402864E76D6CAC4A40
16371	5	47	1667	59437	71354	\N	53.645876608313401	Алтайский край, Первомайский район, пос.Рогуличный, ул.Школьная, 20	Россия, Алтайский край, Тальменский район, поселок Рогуличный	0101000020E61000002DB308C556F054408A1EF818ACD24A40
16388	5	47	1667	28440	70833	\N	53.090715000000003	Алтайский край, Первомайский район, с.Рассказиха, ул.Гуляева-Сусанина, 48		0101000020E6100000A7406667D1F55440DA20938C9C8B4A40
16183	5	47	775	18596	71371	\N	53.578277999999997	Алтайский край, Кытмановский район, с.Тяхта, Молодежная, 4		0101000020E6100000FD82DDB06D5E554086FF740305CA4A40
16346	5	47	1667	26533	71020	\N	53.935850972781999	Алтайский край, Первомайский район, с.Пурысево, ул.Молодежная, 3	Россия, Алтайский край, Первомайский район, поселок Пурысево	0101000020E61000009AD18F8653055540E6762FF7C9F74A40
16380	5	47	1667	28083	71225	\N	53.436818261218498	Алтайский край, Первомайский район, пос.Правда, ул.Школьная, 5а	Россия, Алтайский край, Первомайский район, поселок Правда	0101000020E6100000B378B13044085540EE26F8A6E9B74A40
16360	5	47	1667	27177	69736	\N	53.510582999999997	Алтайский край, Первомайский район, с.Повалиха, ул.Школьная, 2		0101000020E610000018CC5F2173F154406072A3C85AC14A40
16352	5	47	1667	26763	70168	\N	53.722073000000002	Алтайский край, Первомайский район, с.Первомайское, ул.Центральная, 1		0101000020E610000059A5F44C2F0155408D2958E36CDC4A40
16351	5	47	1667	26763	69952	\N	53.722073000000002	Алтайский край, Первомайский район, с.Первомайское, ул.Молодежная, 4		0101000020E610000059A5F44C2F0155408D2958E36CDC4A40
16373	5	47	1667	27766	71222	\N	53.574204000000002	Алтайский край, Первомайский район, с.Октябрьское, ул.Приозерная, 12		0101000020E610000032207BBDFBF65440BF9D44847FC94A40
16376	5	47	1667	27906	71029	\N	53.500723999999998	Алтайский край, Первомайский район, с.Новочесноковка, ул.Центральная, 43а		0101000020E610000098E0D407921A554041295AB917C04A40
16354	5	47	1667	26916	71027	\N	53.7305150176092	Алтайский край, Первомайский район, с.Новоповалиха, ул.Школьная, 16	Россия, Алтайский край, Первомайский район, поселок Новоповалиха	0101000020E6100000111D024702065540641EF98381DD4A40
16349	5	47	1667	26683	70830	\N	53.771529999999998	Алтайский край, Первомайский район, с.Новокраюшкино, ул.Школьная, 2		0101000020E61000000938842A35FC544002F1BA7EC1E24A40
16375	5	47	1667	27869	70895	\N	53.504210999999998	Алтайский край, Первомайский район, с.Новокопылово, ул.Лесная, 1а		0101000020E61000005AF0A2AF2015554048A46DFC89C04A40
16358	5	47	1667	27085	70856	\N	53.404891999999997	Алтайский край, Первомайский район, с.Новоберезовка, ул.Интернациональная, 1		0101000020E610000005A568E55E005540BD344580D3B34A40
15579	5	47	1667	21432	69857	\N	53.413187315379801	Алтайский край, город Новоалтайск, пер.Профсоюзный, 55	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E61000005704FF5BC9FB5440F110C64FE3B44A40
16983	5	47	1667	21432	69670	\N	53.422732000000003	г.Новоалтайск, ул.Прудская, д.8		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15591	5	47	1667	21432	69856	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Парковая, 2		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15578	5	47	1667	21432	69667	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.П. Корчагина, 1		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15580	5	47	1667	21432	70074	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Крылова, 5		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15583	5	47	1667	21432	70072	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Коммунистическая, 4		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15588	5	47	1667	21432	69985	\N	53.416263999999998	Алтайский край, город Новоалтайск, ул.Деповская, 19б		0101000020E6100000B37A87DBA1FD54404640852348B54A40
15587	5	47	1667	21432	69985	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Деповская, 14		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
15600	5	47	1667	21432	69678	\N	53.404981557044302	Алтайский край, город Новоалтайск, ул.Геологов, 72	Россия, Алтайский край, Первомайский район, город Новоалтайск	0101000020E610000090D959F44EFC5440FDBB3E73D6B34A40
15597	5	47	1667	21432	69981	\N	53.422732000000003	Алтайский край, город Новоалтайск, ул.Белоярская, 164		0101000020E6100000EF3A1BF2CFFD5440817C09151CB64A40
16389	5	47	1667	28486	71218	\N	52.914144999999998	Алтайский край, Первомайский район, пос.Нижняя Петровка, ул.Школьная, 6		0101000020E610000008CDAE7B2BF65440A5660FB402754A40
16359	5	47	1667	59444	71444	\N	53.749183650446	Алтайский край, Первомайский район, с.Малая Повалиха, ул.Центральная, 9-2	Россия, Алтайский край, Заринский район, поселок Малая Повалиха	0101000020E6100000CA181F662F195540DE57E542E5DF4A40
16368	5	47	1667	27550	69951	\N	53.498758000000002	Алтайский край, Первомайский район, с.Логовское, ул.Титова, 6		0101000020E61000008066101FD80C5540274F594DD7BF4A40
16387	5	47	1667	28404	71028	\N	53.242576	Алтайский край, Первомайский район, пос.лесной, ул.Центральная, 15		0101000020E61000008C6A11514CFE5440B265F9BA0C9F4A40
16350	5	47	1667	26727	71024	\N	53.835594999999998	Алтайский край, Первомайский район, с.Лебяжье, ул.Зеленая, 21		0101000020E61000007FBDC282FB085540BED9E6C6F4EA4A40
16363	5	47	1667	27294	70555	\N	53.5314479260729	Алтайский край, Первомайский район, пос.Казачий, ул.Ленина, 14	Россия, Алтайский край, Первомайский район, поселок Казачий	0101000020E610000033315D88D5F5544026C3F17C06C44A40
16366	5	47	1667	27457	71409	\N	53.548909110722498	Алтайский край, Первомайский район, пос.Ильича, ул.Калинина, 2	Россия, Алтайский край, Первомайский район, поселок Ильича (Черемшаека)	0101000020E61000003CC1FEEBDC00554073BD6DA642C64A40
16364	5	47	1667	27347	69839	\N	53.488284999999998	Алтайский край, Первомайский район, с.Зудилово, ул.Пионерская, 24		0101000020E61000007D3ECA880BF954404D10751F80BE4A40
16356	5	47	1667	26993	70700	\N	53.780937000000002	Алтайский край, Первомайский район, с.Журавлиха, ул.Молодежная, 14		0101000020E6100000BE2D58AA0B0F5540419E5DBEF5E34A40
16374	5	47	1667	27822	70333	\N	53.402873999999997	Алтайский край, Первомайский, с.Жилино, ул.Ленина, 29		0101000020E6100000842EE1D05B13554050340F6091B34A40
16353	5	47	1667	26856	71210	\N	53.680010000000003	Алтайский край, Первомайский район, с.Голышево, ул.Плотникова, 23		0101000020E6100000F3E670ADF6FA5440FB7953910AD74A40
16355	5	47	1667	59446	71449	\N	53.632228052555398	Алтайский край, Первомайский район, пос.Волга, ул.Рабочая, 30	Россия, Алтайский край, Первомайский район, поселок Волга	0101000020E61000002B6A300DC3FF5440C8CEDBD8ECD04A40
16362	5	47	1667	27213	69896	\N	53.506068999999997	Алтайский край, Первомайский район, с.Боровиха, ул.Рабочая, 10		0101000020E61000006C7A50508AF554407C4276DEC6C04A40
63286	3	31	\N	57342	57958	\N	58.382935000000003	г.Боровичи, Ленинградская, 97		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
16385	5	47	1667	28260	69740	\N	53.179091999999997	Алтайский край, Первомайский район, с.Бобровка, ул.Майская, 4б		0101000020E6100000452FA3586EF85440D47C957CEC964A40
16384	5	47	1667	28260	69741	\N	53.179091999999997	Алтайский край, Первомайский район, с.Бобровка, ул.Ленина, 79		0101000020E6100000452FA3586EF85440D47C957CEC964A40
16369	5	47	1667	27598	71212	\N	53.517389000000001	Алтайский край, Первомайский район, с.Бешенцево, ул.Буферная, 56		0101000020E6100000F6402B30640B5540B32781CD39C24A40
16377	5	47	1667	27959	70173	\N	53.330751999999997	Алтайский край, Первомайский район, с.Баюновские Ключи, ул.Центральная, 24а		0101000020E6100000F3ACA415DF0B5540158BDF1456AA4A40
16344	5	47	1667	26444	70485	\N	53.917054999999998	Алтайский край, Первомайский район, с.Акулово, ул.Ленина, 47		0101000020E61000008AC8B08A370155400FD1E80E62F54A40
16337	5	47	381	26117	71014	\N	53.795102999999997	Алтайский край, Панкрушихинский район, с.Урываево, ул.Ленина, д.8		0101000020E61000007D21E4BCFFFB5340CAF962EFC5E54A40
16333	5	47	381	25961	71127	\N	53.967255000000002	Алтайский край, Панкрушихинский район, с.Романово, ул.Школьная, д.34		0101000020E61000006D91B41B7D2054403DF20703CFFB4A40
16327	5	47	381	25671	70329	\N	53.863646000000003	Алтайский край, Панкрушихинский район, с.Подойниково, ул.Советская, д.2		0101000020E610000012DC48D9221E54401EA9BEF38BEE4A40
16328	5	47	381	25733	70857	\N	53.7287294510243	Алтайский край, Панкрушихинский район, пос.Первомайский, пер.Школьный, д.4	Россия, Алтайский край, Панкрушихинский район, поселок Первомайский	0101000020E61000004AD235936F295440CA52EBFD46DD4A40
16324	5	47	381	25529	70164	\N	53.826205000000002	Алтайский край, Панкрушихинский район, с.Панкрушиха, ул.Ленина, д.25		0101000020E6100000E4A25A44141654405665DF15C1E94A40
16325	5	47	381	25529	69897	\N	53.826205000000002	Алтайский край, Панкрушихинский район, с.Панкрушиха, ул.Зеленая, д.2		0101000020E6100000E4A25A44141654405665DF15C1E94A40
16340	5	47	381	26244	\N	\N	53.639302999999998	Алтайский край, Панкрушихинский район, пос.Павловский, д.49		0101000020E610000033A6608DB32054400A9E42AED4D14A40
16331	5	47	381	25859	70689	\N	53.917330999999997	Алтайский край, Панкрушихинский район, с.Луковка, ул.Ленинская, 34		0101000020E6100000CB4C69FD2D115440B14D2A1A6BF54A40
16332	5	47	381	25902	70814	\N	54.006574999999998	Алтайский край, Панкрушихинский район, пос.Ленский, ул.Школьная, д.1		0101000020E6100000CC7EDDE9CE08544050FC1873D7004B40
16334	5	47	381	26004	71211	\N	53.992072999999998	Алтайский край, Панкрушихинский район, пос.Кызылту, ул.Центральная, д.2		0101000020E6100000EA059FE6E41A54404F1F813FFCFE4A40
16342	5	47	381	26340	70828	\N	53.684522000000001	Алтайский край, Панкрушихинский район, с.Кривое, ул.Центральная, д.1		0101000020E61000007C7F83F6EA0954403EB2B96A9ED74A40
16330	5	47	381	25810	70827	\N	53.870258912362203	Алтайский край, Панкрушихинский район, с.Конево, ул.Центральная, д.10	Россия, Алтайский край, Панкрушихинский район, поселок Конево	0101000020E6100000323A2009FB2354405B069CA564EF4A40
16339	5	47	381	26195	70496	\N	53.595975000000003	Алтайский край, Панкрушихинский район, с.Зятьково, ул.Новостройка, д.1		0101000020E610000032C9C859D8155440E71DA7E848CC4A40
16338	5	47	381	26159	71232	\N	53.823335	Алтайский край, Панкрушихинский район, с.Зыково, ул.Школьная, д.10		0101000020E610000004C765DCD40454407A53910A63E94A40
16528	5	47	381	1972	71309	\N	53.813996000000003	Смоленский район, пос.Заречный, ул.Центральная, д.3		0101000020E610000068B3EA73B51B544094895B0531E84A40
16329	5	47	381	25785	71378	\N	53.917558999999997	Алтайский край, Панкрушихинский район, с.Высокая Грива, ул.Центральная, д.21		0101000020E610000049A0C1A6CE2854404293C49272F54A40
16335	5	47	381	26044	70694	\N	53.867012000000003	Алтайский край, Панкрушихинский район, с.Велижанка, ул.Центральная, д.38		0101000020E610000092CF2B9E7A0A5440AA9ECC3FFAEE4A40
16341	5	47	381	26289	71025	\N	53.557155000000002	Алтайский край, Панкрушихинский район, пос.Борисовский, ул.Кузнецова, д.13		0101000020E6100000F5BEF1B5670B5440C5E6E3DA50C74A40
16326	5	47	381	25628	70512	\N	53.748151	Алтайский край, Панкрушихинский район, пос.Березовский, пер.Школьный, д.9		0101000020E610000063F20698F91054401FBC7669C3DF4A40
16343	5	47	381	26399	70949	\N	53.762763999999997	Алтайский край, Панкрушихинский район, с.Береговое, ул.Клубная, д.1		0101000020E61000005E13D21A8308544077483140A2E14A40
16336	5	47	381	26092	70939	\N	53.923471999999997	Алтайский край, Панкрушихинский район, пос.Алексеевский, ул.Центральная, д.3		0101000020E61000007825C9737D015440C7629B5434F64A40
16302	5	47	1693	24509	71259	\N	53.094949	Алтайский край, Павловский район, поселок им.Мамонтова, ул.Центральная, д.6		0101000020E61000000D5531957EB35440DAE4F049278C4A40
16316	5	47	1693	25142	70166	\N	53.335787186391798	Алтайский край, Павловский район, село Шахи, ул.Загайнова, д.32	Россия, Алтайский край, Павловский район, поселок Шахи	0101000020E6100000611BF16437D7544003B68311FBAA4A40
16319	5	47	1693	25272	70482	\N	53.395520824393998	Алтайский край, Павловский райо, село Чернопятово, ул.Молодежная, д.32	Россия, Алтайский край, Павловский район, поселок Чернопятово	0101000020E6100000DF162CD505CB5440CCF09F6EA0B24A40
16308	5	47	1693	24747	69947	\N	53.171322697974503	Алтайский край, Павловский район, село Черемное, ул.Школьная, д.2	Россия, Алтайский край, Павловский район, поселок Черемное	0101000020E61000000229B16B7BCE5440BC067DE9ED954A40
16309	5	47	1693	24747	70688	\N	53.169037000000003	Алтайский край, Павловский район, село Черемное, ул.Центральная, д.18		0101000020E6100000BD8DCD8E54CD544030682101A3954A40
16307	5	47	1693	24747	69943	\N	53.169346436985002	Алтайский край, Павловский район, село Черемное, ул.Ленина, д.9	Россия, Алтайский край, Павловский район, поселок Черемное	0101000020E6100000BEF561BD51CD5440ADDA3521AD954A40
16314	5	47	1693	25063	71017	\N	53.274250000000002	Алтайский край, Павловский район, поселок Урожайный, ул.Целинная, д.14		0101000020E61000006058FE7C5BCA5440C976BE9F1AA34A40
16310	5	47	1693	24887	70481	\N	53.211924000000003	Алтайский край, Павловский район, село Стуково, ул.Центральная, д.91		0101000020E6100000F4C473B680D55440679E5C53209B4A40
16303	5	47	1693	24551	71202	\N	53.152807000000003	Алтайский край, Павловский район, поселок Советский, ул.Центральная, д.14		0101000020E61000008481E7DEC3B95440C9CC052E8F934A40
16322	5	47	1693	25431	70484	\N	53.309154999999997	Алтайский край, Павловский район, поселок Сибирские Огни, ул.Майская, д.4		0101000020E6100000223317B83CC254408B321B6492A74A40
16311	5	47	1693	24929	70813	\N	53.186937999999998	Алтайский край, Павловский район, село Сараи, ул.Сарайская, д.85/1		0101000020E6100000A7E67283A1D0544098309A95ED974A40
16296	5	47	1693	24195	70642	\N	53.255446999999997	Алтайский край, Павловский район, село Рогозиха, ул.Школьная, д.3А		0101000020E61000007C6308008EB154403F6EBF7CB2A04A40
16318	5	47	1693	25231	69973	\N	53.312705999999999	Алтайский край, Павловский район, поселок Прутской, ул.Центральная, д.43		0101000020E61000002B1895D409CF5440A9A10DC006A84A40
16287	5	47	1693	23716	69891	\N	53.321464964357702	Алтайский край, Павловский район, село Павловск, ул.Студенческая, д.12	Россия, Алтайский край, Павловский район, поселок Павловск	0101000020E610000063EE5A423EBF544082E7DEC325A94A40
16288	5	47	1693	23716	69890	\N	53.318080000000002	Алтайский край, Павловский район, село Павловск, ул.Свирина, д.10		0101000020E6100000C993A46B26BE54407FC16ED8B6A84A40
16289	5	47	1693	23716	69894	\N	53.3178673667041	Алтайский край, Павловский район, село Павловск, ул.Пионерская, д.13	Россия, Алтайский край, Павловский район, поселок Павловск	0101000020E6100000DF50F86C1DBF544023BDA8DDAFA84A40
16290	5	47	1693	23716	70170	\N	53.318080000000002	Алтайский край, Павловский район, село Павловск, ул.Малахова, д.109		0101000020E6100000C993A46B26BE54407FC16ED8B6A84A40
16291	5	47	1693	23716	69664	\N	53.318080000000002	Алтайский край, Павловский район, с.Павловск, ул.Ленина, д.11		0101000020E6100000C993A46B26BE54407FC16ED8B6A84A40
16292	5	47	1693	23716	70083	\N	53.318080000000002	Алтайский край, Павловский район, село Павловск, ул..Красный Алтай, д.66		0101000020E6100000C993A46B26BE54407FC16ED8B6A84A40
16286	5	47	1693	23716	69904	\N	53.318080000000002	Алтайский край, Павловский район, село Павловск, ул.Заводская, д.4		0101000020E6100000C993A46B26BE54407FC16ED8B6A84A40
16315	5	47	1693	25107	70800	\N	53.221921935631102	Алтайский край, Павловский район, поселок Озерный, ул.Озерная, д.22	Россия, Алтайский край, Павловский район, поселок Озерный	0101000020E6100000D656EC2FBBC35440A721AAF0679C4A40
16317	5	47	1693	25175	70899	\N	53.433559000000002	Алтайский край, Павловский район, поселок Нагорный, ул.Партизанская, д.11		0101000020E61000008F52094FE8D0544078F17EDC7EB74A40
16306	5	47	1693	24705	70967	\N	53.056809999999999	Алтайский край, Павловский район, поселок Молодежный, ул.Школьная, д.7		0101000020E61000000CB1FA230CAF5440FA0AD28C45874A40
16298	5	47	1693	24294	70551	\N	53.164372	Алтайский край, Павловский район, село Лебяжье, ул.Центральная, д.42		0101000020E61000006939D0436DB25440663046240A954A40
16917	5	47	1693	22434	71297	\N	53.336730785439102	Алтайский край, Чарышский район, с.Красный Май, ул.Совхозная, д.11	Россия, Алтайский край, Павловский район, поселок Красный Май	0101000020E610000074982F2FC0C6544052465C001AAB4A40
16321	5	47	1693	22434	71379	\N	53.338634999999996	Алтайский край, Павловский район, поселок Красный Май, ул.Майская, д.14		0101000020E6100000EB707495EEC65440F623456458AB4A40
16295	5	47	1693	24137	71012	\N	53.280619000000002	Алтайский край, Павловский район, поселок Красная Дубрава, ул.Ленина, д.1		0101000020E61000009B1BD31396B4544070D1C952EBA34A40
16313	5	47	1693	25007	69739	\N	53.269258000000001	Алтайский край, Павловский район, поселок Комсомольский, ул.Московская, д.8		0101000020E610000092AE997CB3D85440DB17D00B77A24A40
16305	5	47	1693	24647	69733	\N	53.030152000000001	Алтайский край, Павловский район, село Колыванское, ул.Гагарина, д.34		0101000020E6100000520DFB3DB1B854405AF44E05DC834A40
16320	5	47	1693	25338	71205	\N	53.440013	Алтайский край, Павловский район, село Касмала, ул.Калинина, д.32		0101000020E61000008A7269FCC2CF54404D68925852B84A40
16323	5	47	1693	25475	70820	\N	53.203795155714502	Алтайский край, Павловский район, село Жуковка, ул.Октябрьская, д.31	Россия, Алтайский край, Павловский район, поселок Жуковка	0101000020E61000001EDC9DB5DBBE54404E0B5EF4159A4A40
16294	5	47	1693	24102	70479	\N	53.437159000000001	Алтайский край, Павловский район, село Елунино, ул.Чкалова, д.23		0101000020E6100000BB9BA73AE4BF544077137CD3F4B74A40
16297	5	47	1693	24246	70480	\N	53.238146	Алтайский край, Павловский район, поселок Бурановка, ул.Школьная, д.1		0101000020E61000006090F46915AF54402CD670917B9E4A40
16293	5	47	1693	24048	71302	\N	53.409647999999997	Алтайский край, Павловский район, село Боровиково, ул.Партизанская, д.4		0101000020E61000006D718DCF64B65440976F7D586FB44A40
16304	5	47	1693	59415	71446	\N	53.096077218460998	Алтайский край, Павловский район, село Арбузовка, ул.Центральная, д.57	Россия, Алтайский край, Павловский район	0101000020E61000000839EFFFE3BA5440EB724A404C8C4A40
16300	5	47	1693	59415	70875	\N	53.093738000000002	Алтайский край, Павловский район, станция Арбузовка, ул.Молодежная, д.11		0101000020E610000056B60F79CBBA54403C32569BFF8B4A40
16299	5	47	1693	59415	71099	\N	53.091825590387103	Алтайский край, Павловский район, станция Арбузовка, ул.Ленина, д.1А		0101000020E6100000A77A32FFE8BA5440147651F4C08B4A40
16280	5	47	1710	23415	70328	\N	52.062786000000003	Алтайский край, Новичихинский район, с. Токарево, ул.Садовая, 84		0101000020E61000002B2FF99FFC4D5440C652245F09084A40
16279	5	47	1710	23382	70687	\N	51.985284999999998	Алтайский край, Новичихинский район, с. Солоновка, ул.Школьная, 1А		0101000020E61000004182E2C798595440A31EA2D11DFE4940
16271	5	47	1710	23009	70335	\N	52.282029000000001	Алтайский край, Новичихинский район, с. Поломошное, ул.Школьная, 1		0101000020E61000003ACC9717605F544005C3B98619244A40
16273	5	47	1710	23104	70823	\N	52.259847999999998	Алтайский край, Новичихинский район, пос. Петровский, ул.Центральная, 1		0101000020E6100000B2852007256854402BF702B342214A40
16276	5	47	1710	23242	71374	\N	52.079205000000002	Алтайский край, Новичихинский район, с.Павловка, ул.Центральная, 77		0101000020E61000000A4AD1CABD6054400057B263230A4A40
16268	5	47	1710	22880	69732	\N	52.205228363196802	Алтайский край, Новичихинский район, с.Новичиха, ул.Морозова, 2	Россия, Алтайский край, Новичихинский район, поселок Новичиха	0101000020E6100000E831CA332F5954409B1C3EE9441A4A40
16270	5	47	1710	22880	70179	\N	52.204490092470003	Алтайский край, Новичихинский район, с. Новичиха, ул.Красноармейская, 18	Россия, Алтайский край, Новичихинский район, поселок Новичиха	0101000020E6100000BF620D17B9585440F52D73BA2C1A4A40
16274	5	47	1710	23155	71200	\N	52.297409000000002	Алтайский край, Новичихинский район, пос. Невский, ул.Партизанская, 4		0101000020E6100000B0C8AF1F626D54409E44847F11264A40
16281	5	47	1710	23469	70554	\N	52.204982999999999	Алтайский край, Новичихинский район, с. Мельниково, ул.Ленинская, 104		0101000020E61000004293C492724D5440349E08E23C1A4A40
16275	5	47	1710	23203	71264	\N	52.153072000000002	Алтайский край, Новичихинский район, пос. Мамонтово, ул.Барнаульская		0101000020E610000028D53E1D8F63544077F700DD97134A40
16272	5	47	1710	23057	71075	\N	52.233021999999998	Алтайский край, Новичихинский район, Новичихинский район, с.Лобаниха, ул.Октябрьская. д.6		0101000020E610000022FAB5F5D36C5440CF9F36AAD31D4A40
16277	5	47	1710	23278	71375	\N	52.089255000000001	Алтайский край, Новичихинский район, пос. Красноярка, ул.Школьная, 8		0101000020E6100000AB3FC230605D5440930035B56C0B4A40
16284	5	47	1710	23623	71206	\N	52.382089999999998	Алтайский край, Новичихинский район, пос. Ильинский, ул.Центральная, 24		0101000020E6100000E62494BE104F544077103B53E8304A40
16283	5	47	1710	23572	70474	\N	52.345562999999999	Алтайский край, Новичихинский район, с. Долгово, ул.Кооперативная, 15		0101000020E6100000B03DB324404C544094DA8B683B2C4A40
16278	5	47	1710	23335	70815	\N	52.011529000000003	Алтайский край, Новичихинский район, с. 10 лет Октября, ул.Островского, 2		0101000020E6100000D13FC1C58A5F544051FA42C879014A40
16260	5	47	7480	59405	70702	\N	53.221483999999997	Алтайский край, Немецкий национальный район, с.Николаевка, Садова, 27		0101000020E61000002906483481AE53402B4B7496599C4A40
16266	5	47	1685	22785	70685	\N	53.259470999999998	Алтайский край, Немецкий национальный район, с.Шумановка, Ленина, 44		0101000020E6100000A3CD716E13BB534055A1815836A14A40
16265	5	47	1685	22749	70159	\N	53.279218999999998	Алтайский край, Немецкий национальный район, с.Редкая Дубрава, Октябрьская, 55		0101000020E6100000AF2479AEEFC25340FEB5BC72BDA34A40
16263	5	47	1685	59399	70533	\N	53.423586	Алтайский край, Немецкий национальный район, с.Протасово, Школьная, 25а		0101000020E6100000D2E0B6B6F0CA53409085E81038B64A40
16264	5	47	1685	22711	69942	\N	53.373133000000003	Алтайский край, Немецкий национальный район, с.Подсосново, Гагарина, 86		0101000020E61000001B9B1DA9BEBA5340790778D2C2AF4A40
16257	5	47	1685	22394	69888	\N	53.222330999999997	Алтайский край, Немецкий национальный район, с.Кусак, Энгельса, 39		0101000020E6100000BD344580D3BB534088F19A57759C4A40
16259	5	47	1685	22469	71372	\N	53.335484000000001	Алтайский край, Немецкий национальный район, с.Камыши, Луговая, 27а		0101000020E6100000BCEB6CC83FB25340672AC423F1AA4A40
16254	5	47	1685	22261	69648	\N	53.226525000000002	Алтайский край, Немецкий национальный район, с.Гальбштадт, Клубная, 4		0101000020E6100000F69B89E942BF5340FB5C6DC5FE9C4A40
16246	5	47	1674	21911	69940	\N	51.845314999999999	Алтайский край, Михайловский район, с.Ракиты, Украинская, д.114 А		0101000020E61000004278B471C4F85340BCE82B4833EC4940
16247	5	47	1674	21926	70684	\N	52.073636999999998	Алтайский край, Михайловский район, с.Полуямки, Советская, д.2		0101000020E6100000185A9D9CA1EC53404563EDEF6C094A40
16251	5	47	1674	22147	70471	\N	51.926074999999997	Алтайский край, Михайловский район, с.Николаевка, Лисевцева, д.14		0101000020E61000001B8524B37ADA5340545227A089F64940
16252	5	47	1674	22163	71373	\N	51.961177999999997	Алтайский край, Михайловский район, с.Неводное, Кравченко, д.38		0101000020E6100000A85489B2B7CE53403DD175E107FB4940
16248	5	47	1674	21995	70806	\N	52.026482000000001	Алтайский край, Михайловский район, с.Назаровка, Ленина, 76 Г		0101000020E6100000D15B3CBCE7E8534062F71DC363034A40
16245	5	47	1674	21649	69970	\N	51.816561999999998	Алтайский край, Михайловский район, с.Михайловское, Шоссейная, 74		0101000020E610000061FD9FC37CED53400394861A85E84940
16244	5	47	1674	21649	69935	\N	51.818692660186798	Алтайский край, Михайловский район, с.Михайловское, Крупской, д.37	Россия, Алтайский край, Михайловский район, поселок Михайловское	0101000020E6100000B03A72A433ED5340693BA6EECAE84940
16243	5	47	1674	21649	69887	\N	51.816561999999998	Алтайский край, Михайловский район, с.Михайловское, К.Маркса, д.38		0101000020E610000061FD9FC37CED53400394861A85E84940
16241	5	47	1674	21649	69887	\N	51.816561999999998	Алтайский край, Михайловский район, с.Михайловское, К.Маркса, д.13		0101000020E610000061FD9FC37CED53400394861A85E84940
16239	5	47	1674	59391	70715	\N	51.674636050381601	Алтайский край, Михайловский район, р.п.Малиновое Озеро, Советская, д.20	Россия, Алтайский край, Михайловский район, поселок Малиновое Озеро	0101000020E61000002B31CF4A5AF45340255AF2785AD64940
16240	5	47	1674	59391	70223	\N	51.671876681154799	Алтайский край, Михайловский район, р.п.Малиновое Озеро, Мамонтова, д.17 А	Россия, Алтайский край, Михайловский район, поселок Малиновое Озеро	0101000020E6100000EA58A5F44CF15340A1F7C61000D64940
16250	5	47	1674	22094	70548	\N	51.857208999999997	Алтайский край, Михайловский район, с.Бастан, Горького, д.2		0101000020E6100000772B4B7496DE53401E6B4606B9ED4940
16249	5	47	1674	22019	71368	\N	52.129106999999998	Алтайский край, Михайловский район, с.Ащегуль, Ленина, д.35		0101000020E610000052103CBEBDF15340A357039486104A40
16238	5	47	1630	21514	70544	\N	52.552819	Алтайский край, Мамонтовский район, с.Черная Курья, Новая, 2-А		0101000020E61000002F151BF33A605440C0CDE2C5C2464A40
16237	5	47	1630	21440	70801	\N	52.845658999999998	Алтайский край, Мамонтовский район, с.Украинка, Центральная, 2		0101000020E61000004ED367075C5E5440B648DA8D3E6C4A40
16236	5	47	1630	21429	71015	\N	52.5863041011619	Алтайский край, Мамонтовский район, с.Травное, Молодежная, 38	Россия, Алтайский край, Мамонтовский район, поселок Травное	0101000020E61000009B030473F4775440CAC16C020C4B4A40
16235	5	47	1630	21359	70541	\N	52.603881999999999	Алтайский край, Мамонтовский район, с.Суслово, Партизанская, 59		0101000020E6100000115663096B695440505260014C4D4A40
16233	5	47	1630	21275	70468	\N	52.774793000000003	Алтайский край, Мамонтовский район, с.Покровка, Победы, 7		0101000020E6100000302FC03E3A785440BA15C26A2C634A40
16234	5	47	1630	21298	70472	\N	52.916463999999998	Алтайский край, Мамонтовский район, пос.Первомайский, Магистральная, 6		0101000020E6100000BB421F2C636A54400DFB3DB14E754A40
16232	5	47	1630	21222	70162	\N	52.689015639822699	Алтайский край, Мамонтовский район, с.Островное, Гребенникова, 34	Россия, Алтайский край, Мамонтовский район, поселок Островное (Семеновка)	0101000020E6100000DE59BBED426E5440DB3521AD31584A40
16231	5	47	1630	21184	70339	\N	52.731749999999998	Алтайский край, Мамонтовский район, с.Малые Бутырки, Советская, 30		0101000020E6100000569A94826E6A54408B6CE7FBA95D4A40
16225	5	47	1630	20873	69883	\N	52.664651999999997	Алтайский край, Мамонтовский район, с.Костин Лог, Советская, 50		0101000020E6100000F54A598638825440499C155113554A40
16223	5	47	1630	20772	70106	\N	52.986229999999999	Алтайский край, Мамонтовский район, с.Корчино, ул.Комсомольская, д.22		0101000020E6100000514A0856D56B5440C32ADEC83C7E4A40
16224	5	47	1630	20819	70397	\N	52.970723	Алтайский край, Мамонтовский район, пос.Комсомольский, Октябрьская, 13-Б		0101000020E6100000EB73B515FB675440CD3CB9A6407C4A40
16221	5	47	1630	20672	70680	\N	52.866259792289	Алтайский край, Мамонтовский район, с.Кадниково, Партизанская, 79	Россия, Алтайский край, Мамонтовский район, поселок Кадниково	0101000020E6100000FEF0F3DF837A54409EEA909BE16E4A40
16220	5	47	1630	20628	70794	\N	53.029859000000002	Алтайский край, Мамонтовский район, с.Ермачиха, Мира, 13		0101000020E6100000874ECFBBB1685440E23E726BD2834A40
16219	5	47	1630	20549	70466	\N	53.008305	Алтайский край, Мамонтовский район, с.Гришенское, Центральная, 104		0101000020E6100000E99E758D965C544057B2632310814A40
16218	5	47	1630	20517	70646	\N	52.797881477186003	Алтайский край, Мамонтовский район, с. Буканское, ул.Победы, д.30	Россия, Алтайский край, Мамонтовский район, поселок Буканское	0101000020E6100000304B3B3597735440C58CF0F620664A40
16214	5	47	1231	20259	70692	\N	51.143403999999997	Алтайский край, Локтевский район, с.Устьянка, Кирова, 49		0101000020E6100000CE8C7E349C665440CB0EF10F5B924940
16201	5	47	1231	19547	70278	\N	50.966042677983502	Алтайский край, Локтевский район, с.Успенка, Юбилейная, 23	Россия, Алтайский край, Локтевский район, поселок Успенка	0101000020E6100000C4EC65DB69625440CEC3094CA77B4940
16209	5	47	1231	19952	70477	\N	51.131542000000003	Алтайский край, Локтевский район, с.Советский путь, Школьнгая, 10б		0101000020E610000045BC75FEED5154407506465ED6904940
16203	5	47	1231	19645	70676	\N	50.906238000000002	Алтайский край, Локтевский район, с.Самарка, Центральная, 67		0101000020E61000005FED28CE516254403C32569BFF734940
16210	5	47	1231	20005	70467	\N	51.126126999999997	Алтайский край, Локтевский район, п.Ремовский, Гагарина, 25		0101000020E61000005E4D9EB29A4E54404012F6ED24904940
16213	5	47	1231	20190	70679	\N	51.183641999999999	Алтайский край, Локтевский район, с.Покровка, Школьная, 4		0101000020E6100000C2DA183BE15B54400516C09481974940
16211	5	47	1231	20075	71016	\N	51.045401496949701	Алтайский край, Локтевский район, с.Новенькое, Школьная, 42	Россия, Алтайский край, Локтевский район, поселок Новенькое	0101000020E6100000EFFE78AF5A495440541A31B3CF854940
16208	5	47	1231	19901	70812	\N	51.073577813962203	Алтайский край, Локтевский район, с.Николаевка, Клочкова, 28	Россия, Алтайский край, Локтевский район, поселок Николаевка	0101000020E6100000151A8865335A544040DAFF006B894940
16205	5	47	1231	19737	69932	\N	50.961441000000001	Алтайский край, Локтевский район, п.Масальский, Советская, 11		0101000020E6100000FBE93F6B7E7254404B04AA7F107B4940
16212	5	47	1231	20142	69931	\N	51.188904000000001	Алтайский край, Локтевский район, с.Локоть, Советская, 34		0101000020E61000004CC2853C824C5440B30A9B012E984940
16717	5	47	1231	12544	71307	\N	50.847152000000001	Алтайский край, Третьяковский район, посёлок Крючки, Центральная, 19		0101000020E6100000522976340E735440D95E0B7A6F6C4940
16200	5	47	1231	19479	70538	\N	51.009450999999999	Алтайский край, Локтевский район, п.Кировский, Школьная, 12		0101000020E6100000710168942E6054400EF5BBB035814940
94919	5	47	1231	19708	70327	\N	50.813614000000001	Алтайский край, Локтевский район, с.Золотуха, Молодежная, 20а		0101000020E6100000D124B1A4DC615440ACC8E88024684940
16206	5	47	1231	19796	71193	\N	50.784038207301997	Алтайский край, Локтевский район, с.Ермошиха, Школьная, 3	Россия, Алтайский край, Локтевский район, поселок Ермошиха	0101000020E61000001DE8A1B60D6C54401F69705B5B644940
16192	5	47	1231	19074	69886	\N	50.992649588644298	Алтайский край, Локтевский район, город Горняк, Усадебная, 15		0101000020E6100000B212F3ACA45E5440EC2FBB270F7F4940
16194	5	47	1231	19074	69729	\N	50.989657000000001	Алтайский край, Локтевский район, город Горняк, Островского, 35		0101000020E6100000D73043E3895F5440F5A0A014AD7E4940
16217	5	47	1231	20442	70540	\N	51.129998999999998	Алтайский край, Локтевский район, с.Гилево, Школьная, 1		0101000020E61000006A15FDA199725440A0C1A6CEA3904940
16207	5	47	1231	19844	71199	\N	51.140827000000002	Алтайский край, Локтевский район, с.Георгиевка, Емцева, 22а		0101000020E61000000740DCD5AB60544068B27F9E06924940
16216	5	47	1231	20391	70323	\N	51.053288000000002	Алтайский край, Локтевский район, с.Вторая Каменка, Трибунского, 69		0101000020E610000095B7239C1670544077A22424D2864940
16215	5	47	1231	20303	70695	\N	51.135311999999999	Алтайский край, Локтевский район, с.Александровка, Советская, 30		0101000020E6100000DE9046054E6C5440D06053E751914940
16181	5	47	775	18478	70888	\N	53.259784000000003	Алтайский край, Кытмановский район, с.Черкасово, Центральная, 40		0101000020E6100000C3F5285C8F5155401503249A40A14A40
16175	5	47	775	18169	70376	\N	53.484046999999997	Алтайский край, Кытмановский район, с. Червово, Молодежная, 30		0101000020E610000076A6D0798D4055400B5D8940F5BD4A40
16172	5	47	775	18040	71367	\N	53.403953000000001	Алтайский край, Кытмановский район, с.Улус-Тараба, Новая, 28		0101000020E6100000D4B6611404655540800F5EBBB4B34A40
16182	5	47	775	18553	70318	\N	53.649402000000002	Алтайский край, Кытмановский район, с.Сунгай, Максакова, 22		0101000020E61000007959130B7C6255407FFACF9A1FD34A40
16171	5	47	775	17983	71105	\N	53.404513724805099	Алтайский край, Кытмановский район, с.Старая Тараба, ул.Черемнова, 16	Россия, Алтайский край, Кытмановский район, поселок Старая Тараба	0101000020E61000002B323A20095F55401763601DC7B34A40
16191	5	47	775	19015	71296	\N	53.328541999999999	Алтайский край, Кытмановский район, с.Сосновый Лог, ул.Садовая, 10а		0101000020E6100000F3C81F0C3C5C554064AE0CAA0DAA4A40
16184	5	47	775	18657	70799	\N	53.559897415065301	Алтайский край, Кытмановский район, с. Семено-Красилово, Черемушки, 11	Россия, Алтайский край, Кытмановский район, поселок Семено-Красилово	0101000020E6100000DDD26A48DC665540731074B4AAC74A40
16179	5	47	775	18366	70795	\N	53.229339000000003	Алтайский край, Кытмановский район, с. Порошино, ул.Центральная, 58		0101000020E61000009A5FCD01824855404359F8FA5A9D4A40
16173	5	47	775	18080	71195	\N	53.498896999999999	Алтайский край, Кытмановский район, с.Петрушиха, Школьная, 12		0101000020E6100000D8F15F200856554048895DDBDBBF4A40
16177	5	47	775	18270	70788	\N	53.686297000000003	Алтайский край, Кытмановский район, с.Отрадное, Черемушки, 44		0101000020E6100000D862B7CF2A6A5540E52B8194D8D74A40
16180	5	47	775	18439	69928	\N	53.285448000000002	Алтайский край, Кытмановский район, п. Октябрьский, Советская, 6		0101000020E610000048F949B54F555540B45A608F89A44A40
15935	5	47	775	6723	71349	\N	53.677359000000003	Алтайский  край, Заринский район,  с.Озерное, ул.Пушкина, д.2		0101000020E61000008A3DB48F154D55405D5320B3B3D64A40
16178	5	47	775	59463	71481	\N	53.616221447367103	Алтайский край, Кытмановский район, с.Ново-Хмелевка, Новая, 10	Россия, Алтайский край, Кытмановский район, поселок Новохмелевка	0101000020E61000007427D87F9D6C5540E10D6954E0CE4A40
16190	5	47	775	18972	70790	\N	53.479562000000001	Алтайский край, Кытмановский район, с.Новоозерное, Центральная, 4		0101000020E6100000ED82C13577675540C233A14962BD4A40
16176	5	47	775	18228	70342	\N	53.383293452825797	Алтайский край, Кытмановский район, с.Новая Тараба, Целинная, 39	Россия, Алтайский край, Кытмановский район, поселок Новая Тараба	0101000020E610000062F888981252554093E4B9BE0FB14A40
16188	5	47	775	18868	71369	\N	53.473871000000003	Алтайский край, Кытмановский район, п.Кытманушка, Республики, 24а		0101000020E61000002D5F97E13F5C5540ECC20FCEA7BC4A40
16169	5	47	775	17874	70084	\N	53.458058000000001	Алтайский край, Кытмановский район, с.Кытманово, Советская, 11		0101000020E6100000438F183DB75C5540E9D500A5A1BA4A40
16170	5	47	775	17874	69912	\N	53.458058000000001	Алтайский край, Кытмановский район, с.Кытманово, Комсомольская, 41		0101000020E6100000438F183DB75C5540E9D500A5A1BA4A40
16174	5	47	775	18147	71190	\N	53.47513	Алтайский край, Кытмановский район, с.Курья, Весенняя, 6		0101000020E61000002B137EA99F5755409BAC510FD1BC4A40
16186	5	47	775	18761	71097	\N	53.540137000000001	Алтайский край, Кытмановский район, с. Каменка, ул.Школьная, 7		0101000020E61000002FA52E19C76D5540062E8F3523C54A40
16167	5	47	775	17782	70776	\N	53.539928000000003	Алтайский край, Кытмановский район, п.Калиновский, Чумышская, 42а		0101000020E6100000ABEAE5779A555540EC18575C1CC54A40
16168	5	47	775	17842	\N	\N	53.590214000000003	Алтайский край, Кытмановский район, с.Заречное, ул.Центральная, 24	Россия, Алтайский край, Кытмановский район, поселок Заречное	0101000020E610000058923CD7F754554018D2E1218CCB4A40
15911	5	47	775	5462	70562	\N	53.786571000000002	Алтайский  край, Заринский район, село Жуланиха, Ленина, 6		0101000020E6100000024A438D42615540B37DC85BAEE44A40
16166	5	47	775	17741	70464	\N	53.583468000000003	Алтайский край, Кытмановский район, с.Дмитро-Титово, Целинная, 30		0101000020E6100000C00644882B4F55409B215514AFCA4A40
16189	5	47	775	18906	70780	\N	53.483887000000003	Алтайский край, Кытмановский район, с.Беспалово, Западная, 38		0101000020E6100000E3A7716F7E595540D3FA5B02F0BD4A40
16151	5	47	1477	17003	71197	\N	51.303091999999999	Алтайский край, Курьинский район, п.8 Марта, Центральная улица, 29		0101000020E6100000D9CF622992A85440F1D6F9B7CBA64940
16157	5	47	1477	17284	70460	\N	51.485517000000002	Алтайский край, Курьинский район, с.Усть-Таловка, Полевая улица, 50		0101000020E61000005DC2A1B7789254407653CA6B25BE4940
16158	5	47	1477	17348	70315	\N	51.706646999999997	Алтайский край, Курьинский район, с.Трусово, Сибирская улица, 7		0101000020E610000060730E9E099F54408368AD6873DA4940
16156	5	47	1477	17229	71366	\N	51.402704	Алтайский край, Курьинский район, с.Ручьево, Центральная улица, 30		0101000020E610000009168733BF955440F4FBFECD8BB34940
16153	5	47	1477	17090	70777	\N	51.332134000000003	Алтайский край, Курьинский район, п.Подхоз, Центральная улица, 17		0101000020E610000035ECF7C43AA25440E1F1ED5D83AA4940
16162	5	47	1477	17529	70320	\N	51.750003	Алтайский край, Курьинский район, с.Новофирсово, Локтевская улица, 20		0101000020E6100000E2B19FC5528C544071732A1900E04940
16164	5	47	1477	17665	70804	\N	51.65954	Алтайский край, Курьинский район, п.Новознаменка, Краснознаменская улица, 22		0101000020E61000005551BCCADA915440B13385CE6BD44940
16165	5	47	1477	17185	69727	\N	51.601053110198201	Алтайский край, Курьинский район, с.Курья, Советская улица, 52	Россия, Алтайский край, Курьинский район, поселок Курья	0101000020E61000009DD843FB58925440D314014EEFCC4940
16155	5	47	1477	17185	70156	\N	51.599663999999997	Алтайский край, Курьинский район, с.Курья, Гагарина улица, 36		0101000020E6100000516B9A779C925440554B3ACAC1CC4940
16161	5	47	1477	17490	70317	\N	51.679107000000002	Алтайский край, Курьинский район, с.Кузнецово, Центральная улица, 51		0101000020E6100000C493DDCCE88054400ABE69FAECD64940
16163	5	47	1477	17582	70462	\N	51.683394369879203	Алтайский край, Курьинский район, с.Краснознаменка, Коммунистическая улица, 14	Россия, Алтайский край, Курьинский район, поселок Краснознаменка	0101000020E610000039B35DA10F9154402D24607479D74940
16152	5	47	1477	17035	70158	\N	51.302439	Алтайский край, Курьинский район, с.Колывань, Ломоносова улица, 2		0101000020E61000007AA9D898D7A3544079043752B6A64940
63285	3	31	\N	57342	57958	\N	58.382935000000003	г.Боровичи, Ленинградская, 95		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
16154	5	47	1477	17125	71362	\N	51.366178132824601	Алтайский край, Курьинский район, с.Казанцево, Школьная улица, 15	Россия, Алтайский край, Курьинский район, поселок Казанцево	0101000020E610000065C746205E975440E141B3EBDEAE4940
16159	5	47	1477	17369	70669	\N	51.561790000000002	Алтайский край, Курьинский район, с.Ивановка, Парковый переулок, 4а		0101000020E61000008940F50F22815440249C16BCE8C74940
16160	5	47	1477	17439	71363	\N	51.504027000000001	Алтайский край, Курьинский район, с.Горновка, Центральная улица, 35		0101000020E610000052499D802686544087A6ECF483C04940
16150	5	47	1477	16955	71006	\N	51.278359999999999	Алтайский край, Курьинский район, с.Бугрышиха, Алтайская улица, 12		0101000020E6100000672C9ACE4EB25440DD41EC4CA1A34940
16140	5	47	1416	16456	71196	\N	52.618400000000001	Алтайский край, Кулундинский район, село Троицк, Молодежная, 14		0101000020E610000076FD82DDB0B1534057EC2FBB274F4A40
16137	5	47	1416	16258	70898	\N	52.52713	Алтайский край, Кулундинский район, село Смирненькое, Ленина, 36		0101000020E6100000328FFCC1C0CF5340C85EEFFE78434A40
16132	5	47	1416	16021	71180	\N	52.651164999999999	Алтайский край, Кулундинский район, село Сергеевка, Юбилейная, 34		0101000020E6100000670DDE57E5D3534061A6ED5F59534A40
16136	5	47	1416	16246	71183	\N	52.558168000000002	Алтайский край, Кулундинский район, село Семеновка, Центральная, 59		0101000020E610000014D1AFAD9FD453403DD68C0C72474A40
16135	5	47	1416	16178	71019	\N	52.467307885494698	Алтайский край, Кулундинский район, село Попасное, Попасновская, 32	Россия, Алтайский край, Кулундинский район, поселок Попасное	0101000020E61000005AF624B039AE53406094A0BFD03B4A40
16138	5	47	1416	16326	70157	\N	52.567568000000001	Алтайский край, Кулундинский район, поселок Октябрьский, Советская, 5		0101000020E6100000A165DD3F16B85340C9207711A6484A40
16141	5	47	1416	16472	71022	\N	52.538290406954701	Алтайский край, Кулундинский район, село Ноовопетровка, Восточная, 3а	Россия, Алтайский край, Кулундинский район, поселок Новопетровка	0101000020E6100000D73043E389BA5340C6E1CCAFE6444A40
16148	5	47	1416	16861	71011	\N	52.565334	Алтайский край, Кулундинский район, село Мирабилит, Садовая, 18		0101000020E6100000B0E2546B61C153408FA850DD5C484A40
16133	5	47	1416	16094	70672	\N	52.444167999999998	Алтайский край, Кулундинский район, село Курск, Ленина, 53		0101000020E61000000C570740DCBA534001F73C7FDA384A40
16130	5	47	1416	15736	69725	\N	52.567951000000001	Алтайский край, Кулундинский район, село Кулунда, Советская, 67		0101000020E6100000E7E104A6D3BB5340815D4D9EB2484A40
16126	5	47	1416	15736	69725	\N	52.565963405508398	Алтайский край, Кулундинский район, село Кулунда, Советская, 28	Россия, Алтайский край, Кулундинский район, поселок Кулунда	0101000020E610000083DF8618AFBB53407FDFBF7971484A40
16982	5	47	1416	15736	70188	\N	52.567951000000001	Алтайский край, Кулундинский район, село Кулунда, Пушкина, 17а		0101000020E6100000E7E104A6D3BB5340815D4D9EB2484A40
16127	5	47	1416	15736	70294	\N	52.564185309120901	Алтайский край, Кулундинский район, село Кулунда, ул.Песчаная, д.19	Россия, Алтайский край, Кулундинский район, поселок Кулунда	0101000020E610000086AFAF75A9BB534067F2CD3637484A40
16993	5	47	1416	15736	69823	\N	52.567951000000001	Алтайский край, Кулундинский район, село Кулунда, Октябрьская, 155		0101000020E6100000E7E104A6D3BB5340815D4D9EB2484A40
16129	5	47	1416	15736	69718	\N	52.567951000000001	Алтайский край, Кулундинский район, село Кулунда, Ломоносова, 10		0101000020E6100000E7E104A6D3BB5340815D4D9EB2484A40
16128	5	47	1416	15736	69885	\N	52.567951000000001	Алтайский край, Кулундинский район, село Кулунда, Ленина, 46		0101000020E6100000E7E104A6D3BB5340815D4D9EB2484A40
16145	5	47	1416	16710	71008	\N	52.616295000000001	Алтайский край, Кулундинский район, село Константиновка, Центральная, 41		0101000020E61000007BBB253960C453401BD82AC1E24E4A40
16149	5	47	1416	16874	71185	\N	52.518331000000003	Алтайский край, Кулундинский район, село Кирей, Амангельды, 1		0101000020E6100000E2067C7E18C5534062C092AB58424A40
16131	5	47	1416	15990	70319	\N	52.630892000000003	Алтайский край, Кулундинский район, село Златополь, Партизанская, 13		0101000020E6100000095053CBD6D053406EA7AD11C1504A40
16143	5	47	1416	16599	71186	\N	52.5650754900661	Алтайский край, Кулундинский район, село Екатериновка, Центральная, 39	Россия, Алтайский край, Кулундинский район, поселок Екатериновка	0101000020E61000001973D712F2E65340C364AA6054484A40
16147	5	47	1416	16808	70943	\N	52.706997000000001	Алтайский край, Кулундинский район, село Городецк, Молодежная, 6		0101000020E6100000D05FE811A3BE534060AFB0E07E5A4A40
16146	5	47	1416	16738	71010	\N	52.758522999999997	Алтайский край, Кулундинский район, село Воздвиженка, Советская, 27		0101000020E6100000C6A2E9EC64C45340C4211B4817614A40
16134	5	47	1416	16122	70924	\N	52.461582	Алтайский край, Кулундинский район, село Виноградовка, Центральная, 39		0101000020E61000001C7DCC0704C553400D36751E153B4A40
16144	5	47	1416	16635	71187	\N	52.726594283945197	Алтайский край, Кулундинский район, село Белоцерковка, Целинная, 19	Россия, Алтайский край, Кулундинский район, поселок Белоцерковка	0101000020E610000022FC8BA031D0534023BC3D08015D4A40
16142	5	47	1416	16540	71299	\N	52.57835	Алтайский край, Кулундинский район, с.Ананьевка, ул.Восточная, д.28а		0101000020E6100000F2E9B12D03E5534020D26F5F074A4A40
16124	5	47	352	15648	71284	\N	53.949931999999997	Алтайский край, Крутихинский район, пос.Радостный, ул.Михайловичей, д.11		0101000020E6100000BB61DBA2CC45544041B62C5F97F94A40
16114	5	47	352	15160	70324	\N	53.962356	Алтайский край, Крутихинский район, с.Прыганка, Крутихинская, д.1		0101000020E61000005B43A9BD88335440008E3D7B2EFB4A40
16125	5	47	352	15418	70782	\N	54.000891000000003	Алтайский край, Крутихинский район, пос.Подборный, Центральная, д.40		0101000020E6100000EC6987BF264054402DEE3F321D004B40
16119	5	47	352	15418	70782	\N	53.996694103135603	Алтайский край, 4Крутихинский район, пос.Подборный, Центральная, д.23	Россия, Алтайский край, Крутихинский район, поселок Подборный	0101000020E6100000F06DFAB31F405440490F43AB93FF4A40
63271	3	31	\N	57342	58103	\N	58.382935000000003	г.Боровичи, Коммунарная, 46		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
16123	5	47	352	15607	71104	\N	54.007823999999999	Алтайский край, Крутихинский район, пос.Московский, ул.Центральная, д.14		0101000020E6100000AD4D637B2D285440DC0F786000014B40
16122	5	47	352	15557	71182	\N	54.053742033107703	Алтайский край, Крутихинский район, с.Масляха, Зеленая, д.16	Россия, Алтайский край, Крутихинский район, поселок Масляха	0101000020E6100000C440D7BE80505440F8359204E1064B40
16121	5	47	352	15517	70314	\N	54.072386999999999	Алтайский край, Крутихинский район, с.Маловолчанка, Ленина, д.98		0101000020E61000009F1D705D313A5440E9D32AFA43094B40
94918	5	47	352	15460	69728	\N	53.967435999999999	Алтайский край, Крутихинский район, с.Крутиха, Ленинградская, 23		0101000020E610000026C808A8704D54408D7C5EF1D4FB4A40
16120	5	47	352	15460	69728	\N	53.967435999999999	Алтайский край, Крутихинский район, с.Крутиха, Ленинградская, д.15		0101000020E610000026C808A8704D54408D7C5EF1D4FB4A40
16118	5	47	352	15362	71003	\N	53.836987000000001	Алтайский край, Крутихинский район, пос.Караси, Карасевская, д.8А		0101000020E610000011346612F54E5440AD16D86322EB4A40
16117	5	47	352	15300	9771	\N	53.892948411378903	Алтайский край, Крутихинский район, с.Заковряшино, ул.Садовая, д.4, (с.Заковряшино, ул.Воронежская, д.40)	Россия, Алтайский край, Крутихинский район, поселок Заковряшино	0101000020E6100000E92ADD5D674C5440A983BC1E4CF24A40
16116	5	47	352	15249	69882	\N	54.128483000000003	Алтайский край, Крутихинский район, с.Долганка, Гагарина, д.5		0101000020E6100000CE5147C7D5425440C68B852172104B40
94917	5	47	352	15207	69720	\N	54.0534825197321	Алтайский край, Крутихинский район, с.Волчно-Бурлинское, Бурлинская, 25	Россия, Алтайский край, Крутихинский район, поселок Волчно-Бурлинская	0101000020E61000006551D845D13154402CF2EB87D8064B40
16113	5	47	352	1816	70644	\N	53.820810000000002	Алтайский край, Крутихинский район, с.Буян, ул.Целинная, д.10		0101000020E6100000D4D51D8B6D405440691D554D10E94A40
94916	5	47	352	15057	71009	\N	54.031322000000003	Алтайский край, Крутихинский район, с.Боровое, Советская, 10		0101000020E610000014B35E0CE54B54409AD2FA5B02044B40
16111	5	47	352	1768	71304	\N	53.880698476155402	Алтайский край, Крутихинский район, пос.Большой Лог, ул.Большелоговская, д.12/1	Россия, Алтайский край, Крутихинский район, поселок Большой Лог	0101000020E6100000F9DA334B0246544089D349B6BAF04A40
16109	5	47	316	14924	70291	\N	51.332358999999997	Алтайский край, Краснощековский район, с.Чинета, ул.Березовая, д. 18		0101000020E6100000AEF204C24EC3544000C45DBD8AAA4940
16099	5	47	316	14456	69711	\N	51.686019999999999	Алтайский край, Краснощековский район, с.Харлово, Колхозная, 28		0101000020E61000005E83BEF4F6B654407233DC80CFD74940
16110	5	47	316	14995	71365	\N	51.430610000000001	Алтайский край. Краснощековский район, с.Усть-Чагырка, Молодежная, 3а		0101000020E610000082AAD1AB01C8544050AA7D3A1EB74940
16108	5	47	316	14901	70770	\N	51.466954000000001	Алтайский край. Краснощековский район, с.Усть-Пустынка, Самакаева, 1		0101000020E6100000DE76A1B94ECC5440425E0F26C5BB4940
16104	5	47	316	14680	70539	\N	51.621605000000002	Алтайский край, Краснощековский район, с.Усть-Козлуха, Советская, 30а		0101000020E6100000B08F4E5DF9C85440DA03ADC090CF4940
16096	5	47	316	1532	70803	\N	51.459676999999999	Алтайский край, Краснощековский район, с.Усть-Белое, ул. Школьная,, д. 11		0101000020E61000000FD594641DBC544098DC28B2D6BA4940
16095	5	47	316	1479	70305	\N	51.461733872302602	Алтайский край, Краснощековский район. с.Суетка, Советская, д. 61	Россия, Алтайский край, Краснощековский район, поселок Суетка	0101000020E610000014048F6FEFAB5440C3B986191ABB4940
16103	5	47	316	1731	70104	\N	51.693708999999998	Алтайский край, Краснощековский район, с.Новошипуново, ул. Мира, д. 38		0101000020E6100000587380608ED054406EF8DD74CBD84940
16105	5	47	316	14735	70172	\N	51.611052999999998	Алтайский край, Краснощековский район, с.Маралиха, Ленина, 1		0101000020E6100000919BE1067CBC5440B48F15FC36CE4940
16107	5	47	316	14844	70290	\N	51.556863	Алтайский край, Краснощековский район, с.Куйбышево, Школьный переулок, 16		0101000020E610000030629F008ABF54401DAD6A4947C74940
16091	5	47	316	1434	69918	\N	51.667634999999997	Алтайский край, Краснощековский район, с.Краснощеково, Садовая, 17		0101000020E61000002C2E8ECA4DAF54401D554D1075D54940
16093	5	47	316	1434	69659	\N	51.665390862408501	Алтайский край, Краснощековский район, с.Краснощеково, ул. Ленина, д. 121	Россия, Алтайский край, Краснощековский район, поселок Краснощеково	0101000020E6100000E0D5726726AF5440C00644882BD54940
16097	5	47	316	14364	69665	\N	51.712591000000003	Алтайский край, Краснощековский район, с.Карпово Второе, ул. Школьная, д. 10		0101000020E6100000813FFCFCF7AB54404436902E36DB4940
16098	5	47	316	1628	\N	\N	51.717714229868598	Алтайский край, Краснощековский район, с.Карпово Первое, д. 12	Россия, Алтайский край, Краснощековский район, поселок Карпово 1-е	0101000020E6100000615111A793A95440D0F0660DDEDB4940
16100	5	47	316	1649	70146	\N	51.846215999999998	Алтайский край, Краснощековский район, с.Березовка, ул. Гагарина, д. 10		0101000020E610000020B41EBE4CBD54400CAD4ECE50EC4940
16379	5	47	316	1649	69909	\N	51.846215999999998	Алтайский край, Первомайский район, с.Березовка, ул.40 лет Победы, 38		0101000020E610000020B41EBE4CBD54400CAD4ECE50EC4940
16378	5	47	316	1649	69909	\N	51.846215999999998	Алтайский край, Первомайский район, с.Березовка, ул.40 лет Победы, 44		0101000020E610000020B41EBE4CBD54400CAD4ECE50EC4940
16094	5	47	316	14234	70682	\N	51.586413999999998	Алтайский край, Краснощековский район, с.Акимовка, Новая, 19		0101000020E6100000B610E4A084A5544051F52B9D0FCB4940
16090	5	47	206	14035	71178	\N	52.584613932212598	Алтайский край, Красногорский район, пос.им.Фрунзе, ул.Центральная, 26	Россия, Алтайский край, Красногорский район, поселок имени Фрунзе	0101000020E6100000F4A62215C69555405264ADA1D44A4A40
16085	5	47	206	1379	70520	\N	52.546100000000003	Алтайский край, Красногорский район, с.Усть-Кажа, ул.Центральная, д.26 (659514, с.Усть-Кажа, ул.Центральная, д.29)		0101000020E6100000A8ACA6EB899555403D2CD49AE6454A40
63763	3	31	371	25098	57997	\N	58.212181000000001	р.п.Шимск, ул.Ленина, д.8а		0101000020E61000004034F3E49AB63E4092EA3BBF281B4D40
16082	5	47	206	1293	69845	\N	52.178671000000001	Алтайский край, Красногорский район, с.Усть-Иша, ул.Советская, д.22 (659507, с.Усть-Иша, ул.Советская, д.20А)		0101000020E61000006C425A63D07D55402FDFFAB0DE164A40
16073	5	47	206	13240	71080	\N	52.251126999999997	Алтайский край, Красногорский район, пос.Ужлеп, ул.Дорожная, 12		0101000020E6100000A3AF20CD588C55404012F6ED24204A40
16076	5	47	206	13387	70767	\N	52.320348000000003	Алтайский край, Красногорский район, пос.Талый, ул.Центральная, 19		0101000020E6100000755776C1E082554065ABCB2901294A40
16075	5	47	206	13320	71004	\N	52.189940999999997	Алтайский край, Красногорский район, с.Тайна, ул.Заречная, 25		0101000020E6100000209BE447FC955540B39597FC4F184A40
94915	5	47	206	12956	71083	\N	52.232664	Алтайский край, Красногорский район, пос.Старая Суртайка, ул.Центральная, 28\\1		0101000020E6100000965984622B785540707A17EFC71D4A40
16079	5	47	206	1279	70382	\N	52.563873000000001	Алтайский край, Красногорский район, с.Соусканиха, ул.Центральная, д.20		0101000020E610000094BF7B478D7D5540780C8FFD2C484A40
16088	5	47	206	59442	71412	\N	52.323574000000001	Алтайский край, Красногорский район, с.Сосновка, ул.Центральная, 3	Россия, Алтайский край, Красногорский район	0101000020E6100000E2EA0088BB925540FFEA71DF6A294A40
16074	5	47	206	831	70374	\N	52.157432	Алтайский край, Красногорский район, с.Новозыково, ул.Центральная, д.25 (659506, с.Новозыково, ул.Подгорная, д.1)		0101000020E6100000BA13ECBFCE8B554004AC55BB26144A40
16068	5	47	206	12985	70918	\N	52.223744000000003	Алтайский край, Красногорский район, с.Новая Суртайка, ул.Береговая, 13 кв. 1		0101000020E6100000C158DFC0E47C55408F56B5A4A31C4A40
16066	5	47	206	12914	70764	\N	52.206533999999998	Алтайский край, Красногорский район, пос.Мост-Иша, ул.Автомобилистов, 10		0101000020E61000004582A966D67855408BC1C3B46F1A4A40
16077	5	47	206	13405	70774	\N	52.308087	Алтайский край, Красногорский район, с.Мануильское, пер.Клубный, 6		0101000020E6100000E6797077D687554050A912656F274A40
16087	5	47	206	13883	70805	\N	52.551139532391304	Алтайский край, Красногорский район, с.Макарьевское, ул.Центральная, д.42 (659515, с.Макарьевка, ул.Центральная, д.15)	Россия, Алтайский край, Красногорский район, поселок Макарьевское	0101000020E610000026547078419D55403BC269C18B464A40
16078	5	47	206	13465	70765	\N	52.342360999999997	Алтайский край, Красногорский район, с.Луговое, ул.Зеленая, 12		0101000020E610000087156EF9488855408236397CD22B4A40
16081	5	47	206	13599	71173	\N	52.5956220834112	Алтайский край, Красногорский район, с.Лебяжье, ул.Центральная, 15	Россия, Алтайский край, Красногорский район, поселок Лебяжье	0101000020E61000007EAB75E272885540996379573D4C4A40
16071	5	47	206	13036	69881	\N	52.296588999999997	Алтайский край, Красногорский район, с.Красногорское, пер.Рабочий, 4		0101000020E61000006325E659498C55403AADDBA0F6254A40
16070	5	47	206	13036	69713	\N	52.296588999999997	Алтайский край, Красногорский район, с.Красногорское, ул.Юбилейная, 14		0101000020E61000006325E659498C55403AADDBA0F6254A40
16069	5	47	206	13036	69911	\N	52.296588999999997	Алтайский край, Красногорский район, с.Красногорское, ул.Советская, 84		0101000020E61000006325E659498C55403AADDBA0F6254A40
16084	5	47	206	13749	71005	\N	52.140256999999998	Алтайский край, Красногорский район, с.Карагуж, ул.Алтухова, 9		0101000020E6100000A5DAA7E3318555407D04FEF0F3114A40
16072	5	47	206	13181	71268	\N	52.251358000000003	Алтайский край, Красногорский район, пос.Карагайка, пер.Школьный, 1		0101000020E6100000E412471E8893554043CBBA7F2C204A40
16080	5	47	206	13543	71001	\N	52.473717000000001	Алтайский край, Красногорский район, пос.Каменка, ул.Центральная, 12		0101000020E6100000FA0E7EE200855540954737C2A23C4A40
16086	5	47	206	13821	71002	\N	52.459189000000002	Алтайский край, Красногорский район, с.Кажа, ул.Центральная, 32		0101000020E6100000177E703E759955406BD784B4C63A4A40
16083	5	47	206	13684	71176	\N	52.160868000000001	Алтайский край, Красногорский район, пос.Горный, ул.Советская, 7А		0101000020E6100000C36169E047845540897C975297144A40
16065	5	47	206	12862	69661	\N	52.282707914671299	Алтайский край, Красногорский район, с.Быстрянка, ул.Победы, д.19 (659511, с.Быстрянка, ул.Победы, д.21)	Россия, Алтайский край, Красногорский район, поселок Быстрянка	0101000020E61000004EED0C535B755540A62897C62F244A40
16064	5	47	206	778	69846	\N	52.350169913629898	Алтайский край, Красногорский район, с.Березовка, ул.Советская, д.49А  (659508, с.Березовка, ул.Советская, д.51А)	Россия, Алтайский край, Красногорский район, поселок Березовка	0101000020E610000069FE98D6A67455402905DD5ED22C4A40
16089	5	47	206	13971	71361	\N	52.544291999999999	Алтайский край, Красногорский район, с.Балыкса, ул.Центральная, 28 кв.2		0101000020E61000000D8B51D7DAA35540BABC395CAB454A40
16054	5	47	188	59439	71386	\N	53.324890000000003	Алтайский край, Косихинский район, с.Филатово, ул.Центральная, 28	Россия, Алтайский край, Косихинский район	0101000020E6100000BBB9F8DB9E2A55401366DAFE95A94A40
16050	5	47	188	12178	70322	\N	53.308112000000001	Алтайский край, Косихинский район, п.Украинский, ул.Центральная, 2		0101000020E6100000904DF2237E155540A9C0C93670A74A40
16056	5	47	188	59471	71505	\N	53.313580366986599	Алтайский край, Косихинский район, с.Сохорево, Советская, 5	Россия, Алтайский край, Косихинский район, поселок Сохарево	0101000020E61000003A3B191C253755400057B26323A84A40
16061	5	47	188	12687	70995	\N	53.247160999999998	Алтайский край, Косихинский район, с.Романово, ул.Советская, 22		0101000020E61000001E3526C45C1755405FECBDF8A29F4A40
16042	5	47	188	11786	70761	\N	53.356116	Алтайский край, Косихинский район, с.Пустынь, ул.Центральная, 3		0101000020E61000008AC8B08A371F55408ACA863595AD4A40
16045	5	47	188	11902	70678	\N	53.211238999999999	Алтайский край, Косихинский район, с.Полковниково, Школьная, 1А		0101000020E6100000A1B94E232D295540E3512AE1099B4A40
16060	5	47	188	12672	70997	\N	53.417033517549598	Алтайский край, Косихинский район, с.Плотниково, ул.Верхняя, 30	Россия, Алтайский край, Косихинский район, поселок Плотниково	0101000020E6100000A5D8D138D42F5540F8A8BF5E61B54A40
16049	5	47	188	12139	71358	\N	53.175395000000002	Алтайский край, Косихинский район, с.Озеро-Красилово, Школьная, 1		0101000020E6100000ACAA97DF69175540E370E65773964A40
16048	5	47	188	12065	70990	\N	53.214852	Алтайский край, Косихинский район, с.Овчинниково, ул.Центральная, 23		0101000020E610000039B9DFA12820554077BD3445809B4A40
16043	5	47	188	685	69666	\N	53.199632999999999	Алтайский край, Косихинский район, с.Налобиха, ул.Тельмана, д.64		0101000020E6100000B29C84D217265540E719FB928D994A40
16044	5	47	188	685	69712	\N	53.199632999999999	Алтайский край, Косихинский район, с.Налобиха, ул.Республики, 5		0101000020E6100000B29C84D217265540E719FB928D994A40
16046	5	47	188	11973	70514	\N	53.355116000000002	Алтайский край, Косихинский район, с.Малахово, ул.Кооперативная, 7		0101000020E61000009146054EB6195540A724EB7074AD4A40
16057	5	47	188	12536	71364	\N	53.327821	Алтайский край, Косихинский район, п.Лучевое, ул.Центральная, 6		0101000020E610000098F8A3A8332B554094F8DC09F6A94A40
16053	5	47	188	12302	70534	\N	53.386808000000002	Алтайский край, Косихинский район, с.Лосиха, ул.Победы, 5		0101000020E6100000E02A4F20EC3D554064EAAEEC82B14A40
16052	5	47	188	12297	71094	\N	53.289449091661702	Алтайский край, Косихинский район, п.Логовое, ул.Садовая, д.4/1	Россия, Алтайский край, Косихинский район, поселок Логовое	0101000020E6100000CD1DFD2FD7175540116E32AA0CA54A40
16039	5	47	188	11629	70311	\N	53.360700000000001	Алтайский край, Косихинский район, с.Косиха, ул.Рабочая, 76		0101000020E61000005A0D897B2C25554067D5E76A2BAE4A40
16041	5	47	188	11629	70404	\N	53.360700000000001	Алтайский край, Косихинский район, с.Косиха, ул.Луговая, 1А		0101000020E61000005A0D897B2C25554067D5E76A2BAE4A40
16040	5	47	188	11629	70152	\N	53.360700000000001	Алтайский край, Косихинский район, с.Косиха, ул.Комсомольская, 2		0101000020E61000005A0D897B2C25554067D5E76A2BAE4A40
16047	5	47	188	12042	70459	\N	53.21922	Алтайский край, Косихинский район, с.Контошино, ул.Центральная, 56		0101000020E61000007D957CEC2E1B55408750A5660F9C4A40
16055	5	47	188	12405	71172	\N	53.340221	Алтайский край, Косихинский район, с.Каркавино, ул.Рабочая, 22		0101000020E6100000BF27D6A9F2315540CA349A5C8CAB4A40
16063	5	47	188	12778	70999	\N	53.457735999999997	Алтайский край, Косихинский район, с.Глушинка, ул.Садовая, 9		0101000020E6100000BC07E8BE9C205540D619DF1797BA4A40
16051	5	47	188	12207	71168	\N	53.342056549154002	Алтайский край, Косихинский район, п.Восход, ул.Школьная, 5	Россия, Алтайский край, Косихинский район, поселок Восход	0101000020E61000007061DD7877175540162F1686C8AB4A40
16058	5	47	188	12539	70993	\N	53.491076999999997	Алтайский край, Косихинский район, с.Верх-Жилино, ул.Молодежная, 38А		0101000020E610000088A06AF46A295540AD68739CDBBE4A40
16059	5	47	188	12640	70763	\N	53.188352000000002	Алтайский край, Косихинский район, с.Верх-Бобровка, ул.Центральная, 57		0101000020E61000005E68AED3483155406F1118EB1B984A40
16062	5	47	188	12744	70996	\N	53.282164000000002	Алтайский край, Косихинский район, ст.Баюново, ул.Элеваторная, 6		0101000020E61000009622F94A20145540E50D30F31DA44A40
16025	5	47	1153	10995	69708	\N	52.254561000000002	Алтайский край, Ключевский район, пос. Целинный, Пушкина, 4		0101000020E61000002E02637D03CF534025EB707495204A40
16026	5	47	1153	11018	69656	\N	52.130178999999998	Алтайский край, Ключевский район, с.Северка, Октябрьская, д.2		0101000020E6100000C7116BF129D1534020D099B4A9104A40
16038	5	47	1153	11586	70994	\N	52.047595000000001	Алтайский край, Ключевский район, с. Покровка, Пролетарская, 56		0101000020E61000009F77634161D75340003ACC9717064A40
16028	5	47	1153	11139	71150	\N	52.351846000000002	Алтайский край, Ключевский район, с. Платовка, Востояная, 18		0101000020E61000007D1F0E12A2C353403D9D2B4A092D4A40
16036	5	47	1153	11484	70662	\N	52.241019000000001	Алтайский край, Ключевский район, с. Петухи, Кирова, 5		0101000020E6100000EC134031B2E25340795BE9B5D91E4A40
16031	5	47	1153	11263	71281	\N	52.457850000000001	Алтайский край, Ключевский район, с. Петровка, Чапаева, 17		0101000020E61000003CF71E2E39D553409F3C2CD49A3A4A40
16030	5	47	1153	11195	70510	\N	52.416400000000003	Алтайский край, Ключевский район, с. Новополтава, Пролетарская, 7		0101000020E6100000FDBFEAC891D55340F7065F984C354A40
16033	5	47	1153	11358	71155	\N	52.460205621670802	Алтайский край, Ключевский район, с. Красный Яр, Западная, 3	Россия, Алтайский край, Ключевский район, поселок Красный Яр	0101000020E61000006F826F9A3EE6534024B6BB07E83A4A40
16023	5	47	1153	10859	69996	\N	52.251213716834101	Алтайский край, Ключевский район, с. Ключи, Урицкого, 50	Россия, Алтайский край, Ключевский район, поселок Ключи	0101000020E610000043E21E4B1FCB53400F26C5C727204A40
16024	5	47	1153	10859	69910	\N	52.254265969978398	Алтайский край, Ключевский район, с. Ключи, Делегатская, 3	Россия, Алтайский край, Ключевский район, поселок Ключи	0101000020E610000068791EDC9DCB53400C3ECDC98B204A40
16035	5	47	1153	11448	70663	\N	52.247591999999997	Алтайский край, Ключевский район, с. Каип, Центральная, 24		0101000020E6100000AF601BF164F2534028603B18B11F4A40
16029	5	47	1153	11158	70509	\N	52.369456	Алтайский край, Ключевский район, с. Истимис, Кирова, 1а		0101000020E6100000105839B4C8D25340CEA78E554A2F4A40
16032	5	47	1153	11295	71252	\N	52.401071999999999	Алтайский край, Ключевский район, с. Зеленая Поляна, Школьный, 1		0101000020E6100000F085C954C1E85340B0ABC95356334A40
16037	5	47	1153	11534	70758	\N	52.127409	Алтайский край, Ключевский район, с. Западный Угол, Центральная, 19		0101000020E61000001D71C806D2E45340A81B28F04E104A40
16027	5	47	1153	11087	70150	\N	52.275723006855102	Алтайский край, Ключевский район, с. Васильчуки, Центральная, 13	Россия, Алтайский край, Ключевский район, поселок Васильчуки	0101000020E6100000CDC8207711BD5340A4E029E44A234A40
16017	5	47	1085	10614	71356	\N	53.631481000000001	Алтайский край, Каменский район, п.Филипповский, Сибирская, 4-б		0101000020E610000036B05582C52B5440CF85915ED4D04A40
94914	5	47	1085	10746	70398	\N	53.679194000000003	Алтайский край, Каменский район, п.Толстовский, Центральная, 47		0101000020E61000006BD784B4C63B5440D9D138D4EFD64A40
16021	5	47	1085	10827	71370	\N	53.714005999999998	Алтайский край, Каменский район, п.Тамбовский, Тамбовская, 58		0101000020E6100000ACE0B721C6385440EA92718C64DB4A40
16001	5	47	1085	9826	70312	\N	53.922325999999998	Алтайский край, Каменский район, с.Столбово, Мичурина, 41		0101000020E610000059880E81235E5440102043C70EF64A40
16012	5	47	1085	10360	71143	\N	53.514353	Алтайский край, Каменский район, п.Самарский, Центральная, 15		0101000020E6100000F6D37FD6FC545440BCCCB051D6C14A40
16011	5	47	1085	10297	70502	\N	53.566653000000002	Алтайский край, Каменский район, с.Рыбное, Гагарина, 8		0101000020E6100000BEDC2747015A54401497E31588C84A40
94912	5	47	1085	10538	70693	\N	53.560352999999999	Алтайский край, Каменский район, с.Поперечное, Центральная, 26		0101000020E61000003927F6D03E315440959BA8A5B9C74A40
16010	5	47	1085	10281	71359	\N	53.542988999999999	Алтайский край, Каменский район, с.Плотниково, Совхозная, 5		0101000020E6100000BE839F38806154403B8BDEA980C54A40
94908	5	47	1085	9744	70973	\N	53.716031000000001	Алтайский край, Каменский район, п.Октябрьский, Центральная, 22а		0101000020E610000027327381CB4754400AF65FE7A6DB4A40
16006	5	47	1085	10059	70989	\N	53.656925999999999	Алтайский край, Каменский район, с.Обское, Озерная, 1-г		0101000020E6100000A6B6D4415E6B544030F2B22616D44A40
94913	5	47	1085	10726	69709	\N	53.597568000000003	Алтайский край, Каменский район, с.Новоярки, Центральная, 72		0101000020E6100000F46C567DAE3754406D91B41B7DCC4A40
16007	5	47	1085	10108	71135	\N	53.689433000000001	Алтайский край, Каменский район, п.Мыски, юбилейная, 2		0101000020E61000000C3ECDC98B6254403FE42D573FD84A40
16004	5	47	1085	9967	71352	\N	54.039920000000002	Алтайский край, Каменский район, с.Малетино, Январская, 33		0101000020E610000094D920938C595440693A3B191C054B40
94909	5	47	1085	10159	70394	\N	53.512168000000003	Алтайский край, Каменский район, с.Луговое, Школьная, 2		0101000020E6100000253FE257AC675440640795B88EC14A40
94911	5	47	1085	10447	70155	\N	53.518374000000001	Алтайский край, Каменский район, с.Корнилово, Каменская, 82		0101000020E61000007D93A641D1445440618C48145AC24A40
16003	5	47	1085	9899	70756	\N	53.969745000000003	Алтайский край, Каменский район, с.Ключи, Центральная, 7		0101000020E6100000A25D85949F5E5440D23AAA9A20FC4A40
15566	5	47	1085	20390	69980	\N	53.7894483938341	Алтайский край, г.Камень-на-Оби, Северная, 56	Россия, Алтайский край, Каменский район, город Камень-на-Оби	0101000020E610000095D74AE82E54544041F2CEA10CE54A40
15561	5	47	1085	20390	69950	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Пушкина, 55		0101000020E6100000AA49F08634545440454772F90FE54A40
15565	5	47	1085	20390	69961	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Первомайская, 115		0101000020E6100000AA49F08634545440454772F90FE54A40
15564	5	47	1085	20390	70108	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Ленина, 53		0101000020E6100000AA49F08634545440454772F90FE54A40
15576	5	47	1085	20390	70421	\N	53.797988550758703	Алтайский край, г.Камень-на-Оби, Кондратюка, 5		0101000020E610000014200A664C535440ACC8E88024E64A40
15567	5	47	1085	20390	70421	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Кондратюка, 32		0101000020E6100000AA49F08634545440454772F90FE54A40
15575	5	47	1085	20390	70552	\N	53.812252061754101	Алтайский край, г.Камень-на-Оби, Колесникова, 362		0101000020E6100000A9BD88B663545440280EA0DFF7E74A40
15558	5	47	1085	20390	70105	\N	53.789549999999998	Алтайский край, г.Камень-на-Оби, Гоголя, 91		0101000020E6100000AA49F08634545440454772F90FE54A40
16009	5	47	1085	10199	71141	\N	53.463982000000001	Алтайский край, Каменский район, п.Калиновка, Рабочая, 8		0101000020E61000005FB2F1608B64544062F71DC363BB4A40
16018	5	47	1085	10656	71269	\N	53.679962000000003	Алтайский край, Каменский район, п.Зеленая Дубрава, Центральная, 10-б		0101000020E610000086E7A562632D5440EA42ACFE08D74A40
15997	5	47	1085	9598	71346	\N	53.799427000000001	Алтайский край, Каменский район, д.Духовая, Весенняя, 21		0101000020E610000044BE4BA94B6C54400B45BA9F53E64A40
16002	5	47	1085	9871	70969	\N	53.878500000000003	Алтайский край, Каменский район, с.Дресвянка, школьная, 9		0101000020E6100000B07614E7A85554409CC420B072F04A40
16005	5	47	1085	10016	70637	\N	53.644182000000001	Алтайский край, Каменский район, с.Гонохово, ул.Советская, д.71		0101000020E610000035EECD6F986254400056478E74D24A40
94910	5	47	1085	59445	71447	\N	53.461010273173201	Алтайский край, Каменский район, с.Ветренно-Телеутское, Центральная, 60	Россия, Алтайский край, Каменский район, поселок Ветренотелеутское	0101000020E610000014967840D94B544082902C6002BB4A40
94907	5	47	1085	9665	71144	\N	53.888696000000003	Алтайский край, Каменский район, с.Верх-Аллак, Школьная, 7		0101000020E6100000431F2C63436A5440030B60CAC0F14A40
15996	5	47	1085	9558	70660	\N	53.799757	Алтайский край, Каменский район, с.Аллак, Тамбовская, 4		0101000020E6100000700B96EA02625440A0DFF76F5EE64A40
15999	5	47	1085	9712	71345	\N	53.880569999999999	Алтайский край, Каменский район, п.3-Интернационал, Интернациональная, 29		0101000020E6100000C51EDAC70A6654405BEB8B84B6F04A40
15995	5	47	1008	9499	70792	\N	52.927697000000002	Алтайский край, Калманский район, с.Шилово, ул.Школьная, д.10		0101000020E610000038F3AB3940D0544075CC79C6BE764A40
15994	5	47	1008	9473	70759	\N	53.115217000000001	Алтайский край, Калманский район, с.Шадрино, ул.Кировская, д.76		0101000020E6100000B0ABC95356E85440BC783F6EBF8E4A40
15993	5	47	1008	9422	70313	\N	52.823180000000001	Алтайский край, Калманский район, с.Усть-Алейка, ул.Партизанская, д.41		0101000020E6100000AD16D86322E55440535C55F65D694A40
15992	5	47	1008	9349	70504	\N	52.887006999999997	Алтайский край, Калманский район,  п.Троицк, ул.Большевистская, д.67		0101000020E6100000102043C70EE354405A29047289714A40
15990	5	47	1008	9293	71357	\N	53.147477000000002	Алтайский край, Калманский район, с.Панфилово, ул.Пензенская, д.11		0101000020E6100000FF5D9F39EBD65440C3F4BD86E0924A40
16312	5	47	1008	24977	70039	\N	53.244289000000002	Алтайский край, Павловский район, поселок Новые Зори, ул.Комсомольская, д.2		0101000020E6100000D4F36E2C28DC5440E3E2A8DC449F4A40
17001	5	47	1008	9210	9874	\N	53.090336000000001	с.Новороманово, ул.Школьная, д.19		0101000020E6100000FA9AE5B2D1D7544063D34A21908B4A40
17000	5	47	1008	9210	71467	\N	53.090336000000001	с. Новороманово, ул.Строителшьная, 5		0101000020E6100000FA9AE5B2D1D7544063D34A21908B4A40
15988	5	47	1008	9210	69710	\N	53.090336000000001	Алтайский край, Калманский район, с.Новороманово, ул.Коммунистическая, д.26		0101000020E6100000FA9AE5B2D1D7544063D34A21908B4A40
15987	5	47	1008	9173	71247	\N	53.040379999999999	Алтайский край, Калманский район, с.Новобарнаулка, ул.Новобарнаульская, д.15		0101000020E61000004EF04DD367C55440CCB4FD2B2B854A40
15986	5	47	1008	9107	70762	\N	52.855817999999999	Алтайский край, Калманский район, п.Логовской, ул.Логовская, д.10		0101000020E610000082548A1D8DD7544000AAB8718B6D4A40
15985	5	47	1008	9097	70506	\N	52.824562	Алтайский край, Калманский район, с.Кубанка, ул.Центральная, д.28		0101000020E610000064B14D2A1AD754401EC3633F8B694A40
15991	5	47	1008	8970	70411	\N	52.901958	Алтайский край, Калманский район, с.Калманка, ул.Чаузова, д.14		0101000020E6100000E9818FC18AE25440CB2E185C73734A40
16999	5	47	1008	8970	69836	\N	52.901958	с.Калманка, ул.Ленина, д.20		0101000020E6100000E9818FC18AE25440CB2E185C73734A40
15983	5	47	1008	8970	69836	\N	52.9005567493546	Алтайский край, Калманский район, с.Калманка, ул.Ленина, д.7	Россия, Алтайский край, Калманский район, поселок Калманка	0101000020E610000037DE1D19ABE254408997A77345734A40
15984	5	47	1008	9040	70395	\N	52.986891999999997	Алтайский край, Калманский район, с.Калистратиха, ул.Школьная, д.14		0101000020E61000009737876BB5E554408E57207A527E4A40
15982	5	47	1008	8929	70965	\N	53.0110490538924	Алтайский край, Калманский район, с.Ивановка, ул.Ивановская, д.4	Россия, Алтайский край, Калманский район, поселок Ивановка	0101000020E6100000A83AE466B8CB5440A6D3BA0D6A814A40
15981	5	47	1008	8883	70503	\N	53.18553	Алтайский край, Калманский район, с.Зимари, ул.Центральная, д.56		0101000020E610000096B20C71ACDD5440A4367172BF974A40
15980	5	47	1008	8848	70309	\N	53.049388999999998	Алтайский край, Калманский район, с.Бураново, ул.Ерушева, д.18		0101000020E610000055C1A8A44EE654401DE4F56052864A40
15979	5	47	1008	59410	70732	\N	53.003872359966003	Алтайский край, Калманский район, п.Алтай, ул.Советская, д.27	Россия, Алтайский край, Калманский район, поселок Алтай	0101000020E6100000EFAD484C50D8544060AFB0E07E804A40
15978	5	47	1008	8743	71129	\N	53.049968	Алтайский край, Калманский район, с.Александровка, ул.Молодежная, д.28	Россия, Алтайский край, Калманский район, поселок Александровка	0101000020E6100000B972F6CE68D954405BECF65965864A40
15833	5	47	277	1170	70451	\N	52.651088999999999	Алтайский край, Зональный район, с.Шубенка, Ленина, 43		0101000020E610000056D7A19A9246554086E464E256534A40
15968	5	47	277	8286	71123	\N	52.711716000000003	Алтайский край, Зональный район, пос.Урожайный, Школьная, 8		0101000020E6100000053411363C3B55401D058882195B4A40
15975	5	47	277	8602	69884	\N	52.530573269334198	Алтайский край, Зональный район, с.Соколово, Кирова, 38	Россия, Алтайский край, Зональный район, поселок Соколово	0101000020E61000003B00E2AE5E325540FF91E9D0E9434A40
15974	5	47	277	8585	71351	\N	52.516292	Алтайский край, Зональный район, с.Савиново, Садовая, 17А		0101000020E61000005AF44E05DC365540DD9733DB15424A40
15972	5	47	277	8461	69706	\N	52.744176000000003	Алтайский край, Зональный район, с.Плешково, Почтовый, 12		0101000020E610000071AAB5300B335540EB3BBF28415F4A40
15971	5	47	277	8455	70389	\N	52.735115	Алтайский край, Зональный район, пос.Октябрьский, Советская, 16		0101000020E610000074417DCB9C40554047E6913F185E4A40
15970	5	47	277	8368	69880	\N	52.604418000000003	Алтайский край, Зональный район, с.Новая Чемровка, Бийская, 4А		0101000020E6100000EE23B726DD4255408F8EAB915D4D4A40
15967	5	47	277	8226	71132	\N	52.658693	Алтайский край, Зональный район, с.Новая Михайловка, Школьная, 15		0101000020E610000038BA4A77D7365540548D5E0D50544A40
15976	5	47	277	2531	69971	\N	52.577298999999996	Алтайский край, Зональный район, пос.Мирный, ул.Ленина, д.2Г		0101000020E6100000386A85E97B415540BA8102EFE4494A40
15969	5	47	277	8354	70149	\N	52.761617999999999	Алтайский край, Зональный район, с.Луговское, Парковая, 24		0101000020E61000007C992842EA4A5540C005D9B27C614A40
15973	5	47	277	8527	70754	\N	52.561490999999997	Алтайский край, Зональный район, с.Комарово, Школьная, 15А		0101000020E6100000D0B7054B752E5540C9FFE4EFDE474A40
15966	5	47	277	8199	70151	\N	52.666612999999998	Алтайский край, Зональный район, с.Зональное, Ленина, 16		0101000020E61000002D7AA702EE3B5540520B259353554A40
15965	5	47	277	8133	69715	\N	52.801766999999998	Алтайский край, Зональный район, с.Буланиха, Советская, 36		0101000020E6100000F645425BCE3B55408A01124DA0664A40
15964	5	47	48	59455	71465	\N	51.187895813822003	Алтайский край, Змеиногорский район, п.Черепановский, Центральная, 36	Россия, Алтайский край, Змеиногорский район, поселок Черепановск	0101000020E610000016DEE522BE9454404D86E3F90C984940
15953	5	47	48	7585	71116	\N	51.338822912720097	Алтайский край, Змеиногорский район, п.Утка, Речная, 20б	Россия, Алтайский край, Змеиногорский район, поселок Утка	0101000020E61000004E98309A95835440F910548D5EAB4940
15956	5	47	48	7689	71350	\N	51.259335	Алтайский край, Змеиногорский район, п.Тушканиха, Пролетарская, 29		0101000020E6100000F7E80DF7916D5440A5DAA7E331A14940
15962	5	47	48	56	70641	\N	51.449215000000002	Алтайский край, Змеиногорский район, с.Таловка, ул.Советская, 63 (ул.Заводская, д.37)		0101000020E61000000BD3F71A827A5440B3EF8AE07FB94940
15960	5	47	48	7864	69826	\N	51.353166871246501	Алтайский край, Змеиногорский район, c. Саввушка, ул.Центральная, 41, (ул.Центральная, д.71)	Россия, Алтайский край, Змеиногорский район, поселок Саввушка	0101000020E61000009949D40B3E8954406283859334AD4940
15954	5	47	48	7595	70749	\N	51.229011999999997	Алтайский край, Змеиногорский район, п.Предгорный, Декабристов, 2		0101000020E61000009FCBD424787954401E32E543509D4940
15959	5	47	48	7841	70751	\N	51.304305712927999	Алтайский край, Змеиногорский район, п.Отрада, Зеленая, 25	Россия, Алтайский край, Змеиногорский район, поселок Отрада	0101000020E610000096EB6D331573544000FDBE7FF3A64940
15957	5	47	48	7738	70636	\N	51.281081	Алтайский край, Змеиногорский район, п. Октябрьский, ул.40 лет Победы,10 (ул. Комсомольская, д.1)		0101000020E61000000F289B72856D544074435376FAA34940
15961	5	47	48	7939	70787	\N	51.299995000000003	Алтайский край, Змеиногорский район,  п. Новохарьковка, Школьная, 6		0101000020E61000001B9B1DA9BE89544055FB743C66A64940
15950	5	47	48	7447	70744	\N	51.233224999999997	Алтайский край, Змеиногорский район, п. Новокузнецовка, Центральная, 36		0101000020E61000008978EBFCDB83544007CE1951DA9D4940
15883	5	47	48	3943	71335	\N	51.355257000000002	Алтайский край, Залесовский район, с. Никольск, Центральная, 5		0101000020E61000001CCEFC6A0E7A54406956B60F79AD4940
15955	5	47	48	3943	70964	\N	51.357861122860797	Алтайский край, Змеиногорский район, с.Никольск, ул.Парковая,25 (ул.Центральная, д.4)	Россия, Алтайский край, Змеиногорский район, поселок Никольск	0101000020E6100000A9DA6E826F7A5440C6C1A563CEAD4940
15958	5	47	48	7776	70946	\N	51.257593	Алтайский край, Змеиногорский район, п.Локоток, Новая, 1А		0101000020E61000008D60E3FA77745440DA56B3CEF8A04940
15952	5	47	48	7514	70500	\N	51.314166999999998	Алтайский край, Змеиногорский район, с.Кузьминка, ул.Центральная, д.18, (ул.Молодежная, д.2а)		0101000020E6100000419C8713987C5440C03DCF9F36A84940
15948	5	47	48	7368	70079	\N	51.176257	Алтайский край, Змеиногорский район, с.Карамышево, Советская, 1		0101000020E6100000C3D50110778554407558E1968F964940
15947	5	47	48	7309	70742	\N	51.065448000000004	Алтайский край, Змеиногорский район, с. Гальцовка, Косачева, 20		0101000020E6100000DD611399B995544058CB9D9960884940
15951	5	47	48	7492	71342	\N	51.194175999999999	Алтайский край, Змеиногорский район, п.Воронеж, Центральная, 7		0101000020E6100000983446EBA880544084D558C2DA984940
15963	5	47	48	8017	70638	\N	51.198912	Алтайский край, Змеиногорский район, п.Беспаловский, ул.Центральная, 1, (ул.Нагорная, д.16)		0101000020E6100000E6762FF7C98F54401764CBF275994940
15949	5	47	48	7380	70743	\N	51.147117000000001	Алтайский край, Змеиногорский район, с.Березовка, Молодежная, 2		0101000020E6100000753FA7203F855440C3D7D7BAD4924940
15946	5	47	48	7241	69968	\N	51.054448999999998	Алтайский край, Змеиногорский район, с. Барановка, ул.Центральная, 51 (ул.Центральная, д.92)		0101000020E6100000E0D57267268D54406326512FF8864940
15942	5	47	730	59428	71114	\N	53.5443718817979	Алтайский  край, Заринский район, станция Шпагино, Привокзальная, 10а	Россия, Алтайский край, Заринский район	0101000020E61000002507EC6AF2205540D76D50FBADC54A40
15944	5	47	730	7165	71344	\N	53.897137999999998	Алтайский  край, Заринский район, село Яново, Центральная, 12		0101000020E610000088D9CBB6D34D5540DAFF006BD5F24A40
15929	5	47	730	6439	71258	\N	53.587082000000002	Алтайский  край, Заринский район, село Шпагино, Центральная, 5-2		0101000020E610000005C24EB16A235540FF08C38025CB4A40
15918	5	47	730	5847	70906	\N	53.862248999999998	Алтайский  край, Заринский район, поселок Широкий Луг, Победы, 21		0101000020E61000004A99D4D0064055401D01DC2C5EEE4A40
15939	5	47	730	6920	70377	\N	53.953895000000003	Алтайский  край, Заринский район, село Хмелевка, Коммунистическая, 52		0101000020E61000004E29AF95D04B5540B2683A3B19FA4A40
15937	5	47	730	6802	70963	\N	53.947076000000003	Алтайский  край, Заринский район,  ст.Тягун, ул.Титова, д.1		0101000020E6100000003620425C6A5540CB694FC939F94A40
15938	5	47	730	6802	69914	\N	53.950113508776703	Алтайский  край, Заринский район, станция Тягун, Советская, 12	Россия, Алтайский край, Заринский район, поселок Тягун	0101000020E6100000D9CEF753E369554062BCE6559DF94A40
15919	5	47	730	5883	70928	\N	53.796107999999997	Алтайский  край, Заринский район, село Старокопылово, Мира, 55		0101000020E6100000EE5EEE93A3325540BF0AF0DDE6E54A40
15933	5	47	730	6654	70454	\N	53.683763999999996	Алтайский  край, Заринский район,  с. Стародраченино, ул.Ленина, д.2а		0101000020E6100000A99F3715A94455405017299485D74A40
15908	5	47	730	5301	70962	\N	53.794890000000002	Алтайский  край, Заринский район, село Староглушинка, ул. Центральная д.39		0101000020E6100000A08CF161F62B55406FF59CF4BEE54A40
15907	5	47	730	5237	70726	\N	53.796002997570298	Алтайский  край, Заринский район, село Среднекрасилово, Центральная, 44	Россия, Алтайский край, Заринский район, поселок Среднекрасилово	0101000020E6100000ECF99AE5B22655404A42226DE3E54A40
15930	5	47	730	6481	71111	\N	53.881706000000001	Алтайский  край, Заринский район, село Сосновка, Фрунзе, 7		0101000020E6100000698EACFC32585540EF5701BEDBF04A40
15925	5	47	730	6223	70712	\N	53.686047000000002	Алтайский  край, Заринский район, село Смирново, Лесная, 2		0101000020E6100000ABCDFFAB8E2A55406C425A63D0D74A40
15936	5	47	730	59379	70078	\N	53.840223000000002	Алтайский край, Заринский район, Смазневский сельсовет, Первая Майская, 1	Россия, Алтайский край, Заринский район, поселок Смазнево	0101000020E6100000A75D4C33DD4C55406B2C616D8CEB4A40
15926	5	47	730	6252	70307	\N	53.616421000000003	Алтайский  край, Заринский район, село Новоманошкино, Молодежная, 2		0101000020E61000005AF5B9DA8A1F5540A8C821E2E6CE4A40
15909	5	47	730	5376	71278	\N	53.773201	Алтайский  край, Заринский район, село Новокрасилово, ул.Зелёная, д.21/1		0101000020E61000009F94490D6D2E5540041E1840F8E24A40
15924	5	47	730	6137	70652	\N	53.664743000000001	Алтайский  край, Заринский район, село Новокопылово, Центральная, 45		0101000020E6100000F6D1A92B9F2F55405A9F724C16D54A40
15917	5	47	730	5778	71338	\N	53.808546	Алтайский  край, Заринский район, село Новозыряново, Калинина, 39		0101000020E6100000C4060B27693A5540E3A7716F7EE74A40
15940	5	47	730	6959	70961	\N	53.987933439850302	Алтайский  край, Заринский район, поселок Новодресвянка, Новодресвянская, 2а	Россия, Алтайский край, Заринский район, поселок Новодресвянка	0101000020E61000006A6AD95A5F4B5540D0D1AA9674FE4A40
15920	5	47	730	5935	70386	\N	53.795316	Алтайский  край, Заринский район, село Новодраченино, Центральная, 28		0101000020E610000092205C018547554026FE28EACCE54A40
15914	5	47	730	59459	71471	\N	53.754129674188498	Алтайский  край, Заринский район, поселок Мостовая, Партизанская, 30а	Россия, Алтайский край, Заринский район, поселок Мостовой	0101000020E6100000CBF78C44685B55405C77F35487E04A40
15915	5	47	730	5681	70711	\N	53.809578000000002	Алтайский  край, Заринский район, поселок Мироновка, Школьная, 8		0101000020E6100000DD96C805675C5540D2C77C40A0E74A40
15932	5	47	730	6573	71103	\N	53.912934999999997	Алтайский  край, Заринский район, поселок Малиновка, Центральная, 1		0101000020E61000009F0436E7E0595540D72FD80DDBF44A40
15890	5	47	598	4123	70998	\N	53.987785000000002	Алтайский край, Залесовский район, с.Залесово, Крупской, 4		0101000020E610000078D15790662E55405C3D27BD6FFE4A40
15916	5	47	730	5739	70498	\N	53.640841578646302	Алтайский  край, Заринский район, село Комарское, Молодежная, 21	Россия, Алтайский край, Заринский район, поселок Комарское	0101000020E6100000950ED6FF394555409DF3531C07D24A40
15934	5	47	730	6667	71118	\N	53.745146694748797	Алтайский  край, Заринский район, поселок Кокорское, Новая, 7а	Россия, Алтайский край, Заринский район, поселок Кокорское	0101000020E6100000809F71E14042554034DB15FA60DF4A40
15941	5	47	730	7004	70940	\N	54.071494999999999	Алтайский  край, Заринский район, село Клабуковка, Лесная, 1		0101000020E61000000CB265F9BA505540EC6987BF26094B40
15945	5	47	730	7214	71115	\N	53.903556999999999	Алтайский  край, Заринский район, поселок Каменушка, Школьная, 3		0101000020E61000007769C3616949554033897AC1A7F34A40
15922	5	47	730	6045	70720	\N	53.859053000000003	Алтайский  край, Заринский район, село Казанцево, Центральная, 14		0101000020E6100000079ACFB9DB4C5540EE43DE72F5ED4A40
15927	5	47	730	6317	71260	\N	53.635277000000002	Алтайский  край, Заринский район, село Инюшово, Центральная, 34		0101000020E6100000DD09F65FE71555405473B9C150D14A40
15913	5	47	730	5554	71174	\N	53.777558999999997	Алтайский  край, Заринский район, село Зыряновка, Советская, 10		0101000020E6100000876BB587BD5A5540F0DAA50D87E34A40
15923	5	47	730	6122	70791	\N	53.809438999999998	Алтайский  край, Заринский район,  п.Змазнево, ул.Новая, д.9		0101000020E6100000AE9CBD33DA4D5540B08D78B29BE74A40
15538	5	47	730	19237	69638	\N	53.716894000000003	Алтайский край, город Заринск, ул.Союза Республик, д.14/2		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15545	5	47	730	19237	69963	\N	53.716894000000003	Алтайский край, город Заринск, ул.Мира, д.14		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
16995	5	47	730	19237	69589	\N	53.716894000000003	Алтайский край, город Заринск, ул.Комсомольская, д.13		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15539	5	47	730	19237	70063	\N	53.716894000000003	Алтайский край, город Заринск, ул.25 Партсъезда, д.3		0101000020E6100000A7CAF78C443C55406D59BE2EC3DB4A40
15910	5	47	730	5395	70725	\N	53.584750999999997	Алтайский  край, Заринский район, село Гришино, Центральная, 3		0101000020E6100000C32973F38D3A5540D2A6EA1ED9CA4A40
15906	5	47	730	5203	71108	\N	53.764834999999998	Алтайский  край, Заринский район, село Гоношиха, Новая, 38а		0101000020E61000002594BE107233554007EBFF1CE6E14A40
15912	5	47	730	5540	69849	\N	53.846938000000002	Алтайский  край, Заринский район, станция Голуха, ул.Привокзальная. д.2		0101000020E6100000DB1324B6BB5B5540ADDEE17668EC4A40
15928	5	47	730	6337	70931	\N	53.563460999999997	Алтайский  край, Заринский район, село Голубцово, Центральная, 13-2		0101000020E61000006FD39FFD4818554025C9737D1FC84A40
15905	5	47	730	5138	70913	\N	53.908814	Алтайский  край, Заринский район, село Воскресенка, Германа Титова, 1/2		0101000020E61000009276A38FF93F5540CF12640454F44A40
16102	5	47	730	5073	70536	\N	53.595312	Алтайский край, Краснощековский район, с.Верх-Камышенка, Юбилейная, 13		0101000020E6100000643E20D0993355404B75012F33CC4A40
15904	5	47	730	5073	70306	\N	53.595312	Алтайский  край, Заринский район, село Верх-Камышенка, Центральная, 34		0101000020E6100000643E20D0993355404B75012F33CC4A40
16101	5	47	730	5073	70519	\N	53.595312	Алтайский край, Краснощековский район, с.Верх-Камышенка, ул. Молодежная, д.22а		0101000020E6100000643E20D0993355404B75012F33CC4A40
15931	5	47	730	6506	70716	\N	53.875390000000003	Алтайский  край, Заринский район, село Боровлянка, Центральная, 14		0101000020E6100000C8258E3C105E55406B9F8EC70CF04A40
15943	5	47	730	7075	71113	\N	53.664977999999998	Алтайский  край, Заринский район, поселок Батунный, Школьная, 6		0101000020E61000004B2025766D3455409D47C5FF1DD54A40
15921	5	47	730	5990	70785	\N	53.769086999999999	Алтайский  край, Заринский район,  с.Афонино, ул. Центральная, д.17а		0101000020E6100000D93D7958A84F5540AE635C7171E24A40
15901	5	47	598	4944	70649	\N	53.901949999999999	Алтайский край, Залесовский район, с. Шатуново, Партизанская, 14		0101000020E6100000909E2287882155404850FC1873F34A40
15898	5	47	598	4796	70393	\N	54.012521999999997	Алтайский край, Залесовский район, с. Черемушкино, Николаева, 30		0101000020E6100000DF8B2FDAE3125540813D26529A014B40
15895	5	47	598	4604	70849	\N	53.995128000000001	Алтайский край, Залесовский район, с. Тундриха, Комсомольская, 18		0101000020E610000097A8DE1AD8225540BDAAB35A60FF4A40
15881	5	47	598	3873	70850	\N	54.098691868158298	Алтайский край, Залесовский район, с. Талица, Центральная, 23	Россия, Алтайский край, Залесовский район, поселок Талица	0101000020E6100000C190D5AD9E1355403C3080F0A10C4B40
15884	5	47	598	3988	71337	\N	54.011935000000001	Алтайский край, Залесовский район, с. Пролетарская Крепость, Мира, 6		0101000020E6100000E76ED74B53365540C156091687014B40
15893	5	47	598	4516	70683	\N	54.091751000000002	Алтайский край, Залесовский район, с. Пещерка, Совхозная, 4		0101000020E6100000274D83A2793255400A302C7FBE0B4B40
15891	5	47	598	4379	71355	\N	53.893169	Алтайский край, Залесовский район, с. Муравей, Центральная, 24		0101000020E61000009B8D9598672E554088669E5C53F24A40
15900	5	47	598	4886	71263	\N	53.991015678526402	Алтайский край, Залесовский район, с. Малый Калтай, Молодежная, 16	Россия, Алтайский край, Залесовский район, поселок Малый Калтай	0101000020E6100000E200FA7DFF0A554008E8BE9CD9FE4A40
15892	5	47	598	4458	70458	\N	54.183644000000001	Алтайский край, Залесовский район, с. Кордон, Школьная, 22		0101000020E6100000BA84436FF13D5540A60D87A581174B40
15902	5	47	598	4993	70935	\N	53.860560999999997	Алтайский край, Залесовский район, с. Калиновка, Коммунаров, 13		0101000020E610000067D311C0CD235540459BE3DC26EE4A40
15896	5	47	598	4654	71339	\N	53.936995000000003	Алтайский край, Залесовский район, с. Заплывино, 50 лет Алтая, 33		0101000020E610000085ECBC8DCD245540FDC1C073EFF74A40
15888	5	47	598	4123	69843	\N	53.987785000000002	Алтайский край, Залесовский район, с. Залесово, пер. Школьный, 6		0101000020E610000078D15790662E55405C3D27BD6FFE4A40
15887	5	47	598	4123	70013	\N	53.987785000000002	Алтайский край, Залесовский район, с.Залесово, Партизанская, 63		0101000020E610000078D15790662E55405C3D27BD6FFE4A40
15889	5	47	598	4123	69705	\N	53.987785000000002	Алтайский край, Залесовский район, с.Залесово, Ленинская, 3		0101000020E610000078D15790662E55405C3D27BD6FFE4A40
15886	5	47	598	4123	70148	\N	53.987785000000002	Алтайский край, Залесовский район, с. Залесово, Коммунистическая, 51		0101000020E610000078D15790662E55405C3D27BD6FFE4A40
15885	5	47	598	4085	70639	\N	53.955706999999997	Алтайский край, Залесовский район, с. Думчево, ул.Школьная, д.37		0101000020E6100000FDDD3B6A4C12554075C7629B54FA4A40
15894	5	47	598	4542	71287	\N	54.198957999999998	Алтайский край, Залесовский район, с. Гуниха, ул.Октябрьская, д.23		0101000020E6100000159161156F29554087A3AB7477194B40
15899	5	47	598	4820	70736	\N	53.983756999999997	Алтайский край, Залесовский район, с. Видоново, Заречная, 19		0101000020E6100000B2F50CE198035540041BD7BFEBFD4A40
15882	5	47	598	3909	70455	\N	54.035758999999999	Алтайский край, Залесовский район, с. Борисово, Коммунистическая, 14а		0101000020E6100000520FD1E80E405540D2C43BC093044B40
15879	5	47	598	3779	70848	\N	54.127634	Алтайский край, Залесовский район, c. Большой Калтай, Нагорная, 25		0101000020E610000029B000A60C105540C8ED974F56104B40
94903	5	47	504	59393	70234	\N	52.776919347221401	Алтайский край, Завьяловский район, с.Чистоозёрка, Советская, 54	Россия, Алтайский край, Завьяловский район	0101000020E6100000386BF0BE2A3254400D52F01472634A40
15869	5	47	504	3255	70675	\N	52.663035000000001	Алтайский край, Завьяловский район, с.Чернавка, Юбилейная, 21		0101000020E610000068E6C935052754403B8DB454DE544A40
15874	5	47	504	3482	69701	\N	53.034933000000002	Алтайский край, Завьяловский район, с.Харитоново, Советская, 20		0101000020E61000000400C79E3D3C54408D463EAF78844A40
15871	5	47	504	3335	71330	\N	52.855817999999999	Алтайский край, Завьяловский район, п.Тумановский, Молодежная, 1		0101000020E61000005DA3E5400F2C544000AAB8718B6D4A40
94905	5	47	504	59409	70731	\N	52.906742041298003	Алтайский край, Завьяловский район, с.Светлое, Центральная, 40	Россия, Алтайский край, Завьяловский район, поселок Светлый	0101000020E61000007CD45FAFB04354406FF4311F10744A40
15875	5	47	504	3573	70473	\N	52.996909000000002	Алтайский край, Завьяловский район, с.Овечкино, Центральная, 3		0101000020E6100000A01518B2BA4D5440460BD0B69A7F4A40
15872	5	47	504	3391	70145	\N	52.961703999999997	Алтайский край, Завьяловский район, п.Малиновский, Целинная, 16		0101000020E610000031B77BB94F3454405837DE1D197B4A40
15868	5	47	504	3146	70567	\N	52.703989999999997	Алтайский край, Завьяловский район, с.Камышенка, Куйбышева, 22	Россия, Алтайский край, Завьяловский район, поселок Камышенка	0101000020E610000093C5FD47A6265440035B25581C5A4A40
15867	5	47	504	3040	70959	\N	52.837766999999999	Алтайский край, Завьяловский район, с.Завьялово, пер.Школьный, д.1		0101000020E61000005F5E807D743A54408255F5F23B6B4A40
94901	5	47	504	3040	69878	\N	52.837766999999999	Алтайский край, Завьяловский район, с.Завьялово, Центральная, 13		0101000020E61000005F5E807D743A54408255F5F23B6B4A40
94902	5	47	504	3040	69702	\N	52.837766999999999	Алтайский край, Завьяловский район, с.Завьялово, Комунаров, 20		0101000020E61000005F5E807D743A54408255F5F23B6B4A40
94906	5	47	504	3664	69810	\N	52.944609	Алтайский край, Завьяловский район, с.Гонохово, Центральная, 91		0101000020E6100000E67805A227535440EE409DF2E8784A40
94904	5	47	504	3467	70047	\N	52.989277000000001	Алтайский край, Завьяловский район, с.Глубокое, Центральная, 32		0101000020E6100000BE141E34BB2B5440AED7F4A0A07E4A40
15878	5	47	504	3702	70007	\N	52.863044000000002	Алтайский край, Завьяловский район, с.Гилёвка, Центральная, 9		0101000020E61000007BF83251844654402881CD39786E4A40
15862	5	47	470	2827	70845	\N	53.205074436749399	Алтайский край, Ельцовский район, с.Черемшанка, Береговая, 15	Россия, Алтайский край, Ельцовский район, поселок Черемшанка	0101000020E610000021753BFBCA8A554045A165DD3F9A4A40
15864	5	47	470	2917	70673	\N	53.201180999999998	Алтайский край, Ельцовский район, с.Пуштулим, ул.Советская, 25		0101000020E610000090DB2F9FAC9B5540CDC98B4CC0994A40
15863	5	47	470	2877	70988	\N	53.362178	Алтайский край, Ельцовский район, с.Новокаменка, Новая, 15		0101000020E61000002191B6F12794554054AA44D95BAE4A40
15861	5	47	470	2772	69662	\N	53.258760000000002	Алтайский край, Ельцовский район, с.Мартыново, пер.Партизанский, д.5		0101000020E61000006E6E4C4F587A5540A9C1340C1FA14A40
15865	5	47	470	2993	70797	\N	53.072685999999997	Алтайский край, Ельцовский район, с.Верх-Неня, ул.им.Леухина, д.1		0101000020E610000017BB7D56999B554043705CC64D894A40
15851	5	47	385	2185	70524	\N	51.600513999999997	Алтайский край, Егорьевский район, с.Шубинка, ул.Молодежная, д.60		0101000020E6100000EC8497E0D432544023658BA4DDCC4940
15859	5	47	385	2661	70671	\N	52.004727000000003	Алтайский край, Егорьевский район, с.Титовка, ул.Советская, д.2		0101000020E6100000C58CF0F6204954404034F3E49A004A40
15858	5	47	385	2582	69967	\N	51.884585000000001	Алтайский край, Егорьевский район, с.Сросты, ул.Советская, д.171		0101000020E61000001615713AC94054401EC4CE143AF14940
15853	5	47	385	2324	71329	\N	51.723599999999998	Алтайский край, Егорьевский район, п.Перешеечный, ул.Лесхозная, д.67		0101000020E6100000179AEB34D23554405BB1BFEC9EDC4940
15856	5	47	385	2475	70343	\N	51.738393000000002	Алтайский край, Егорьевский район, с.Первомайское, ул.Ленина, д.36		0101000020E61000009679ABAE434C5440344C6DA983DE4940
15855	5	47	385	2336	70142	\N	51.756687999999997	Алтайский край, Егорьевский район, с.Новоегорьевское, ул.Машинцева, д.18		0101000020E6100000234DBC033C39544048A30227DBE04940
15854	5	47	385	2336	70142	\N	51.756687999999997	Алтайский край, Егорьевский район, с.Новоегорьевское, ул.Машинцева, д.16		0101000020E6100000234DBC033C39544048A30227DBE04940
15857	5	47	385	59419	70896	\N	51.787171979353801	Алтайский край, Егорьевский район, п.Мирный, ул.Центральная, д.19а	Россия, Алтайский край, Рубцовский район, поселок Мирный	0101000020E610000010CB660E49515440D829560DC2E44940
15850	5	47	385	2134	70560	\N	51.497069000000003	Алтайский край, Егорьевский район, с.Малая Шелковка, ул.Масловского, 68		0101000020E6100000CF81E508193054407F6DFDF49FBF4940
15852	5	47	385	2235	70141	\N	51.691446999999997	Алтайский край, Егорьевский район, с.Лебяжье, ул.Молодежная, д.20/1		0101000020E6100000D4F36E2C283654406AF5D55581D84940
15803	5	47	111	31940	70945	\N	53.266156000000002	Алтайский край, Бурлинский район, с.Притыка, ул.Набережная, 22А		0101000020E6100000118B1876188F53402DD1596611A24A40
15848	5	47	385	1981	71079	\N	51.530536990122499	Алтайский край, Егорьевский район, с.Кругло-Семенцы, ул.Центральная, 80	Россия, Алтайский край, Егорьевский район, поселок Кругло-Семенцы	0101000020E6100000FF93BF7B47395440B328ECA2E8C34940
15849	5	47	385	2092	71069	\N	51.558142242836297	Алтайский край, Егорьевский район, с.Борисовка, ул.Центральная, 28а	Россия, Алтайский край, Егорьевский район, поселок Борисовка	0101000020E61000000919C8B3CB3154401343723271C74940
15847	5	47	242	1973	70937	\N	51.825414000000002	Алтайский край, Волчихинский район, с.Усть-Кормиха, Набережная, 46		0101000020E6100000DB4DF04DD31654408DD47B2AA7E94940
15846	5	47	242	1863	70674	\N	51.897030000000001	Алтайский край, Волчихинский район, с.Усть-Волчиха, Почтовая, 11		0101000020E61000004FCC7A3194105440F4C308E1D1F24940
15838	5	47	242	1424	70553	\N	52.216549999999998	Алтайский край, Волчихинский район, с.Солоновка, Мамонтова, 11		0101000020E61000000F5F268A9033544072F90FE9B71B4A40
15840	5	47	242	1540	70450	\N	52.294699000000001	Алтайский край, Волчихинский район, с.Селиверстово, Центральная, 53		0101000020E6100000B709F7CABC3C5440FB9463B2B8254A40
15841	5	47	242	1635	71328	\N	52.226602	Алтайский край, Волчихинский район, с.Пятков Лог, Ленина, 76		0101000020E6100000C11A67D311125440A69A594B011D4A40
15837	5	47	242	1385	70757	\N	52.155166999999999	Алтайский край, Волчихинский район, с.Приборовое, Партизанская, 91		0101000020E61000005AA148F7732B54408F352383DC134A40
15835	5	47	242	1274	70630	\N	52.089979999999997	Алтайский край, Волчихинский район, п.Правда, ул.Береговая, д.60		0101000020E61000005891D10149205440A4A5F276840B4A40
16998	5	47	242	26199	71472	\N	51.996192999999998	Волчихинский район, п.Плодосовхоз, ул.Молодежная, д.10/А	Россия, Алтайский край, Волчихинский район, поселок Плодосовхоз	0101000020E6100000CBBBEA01F312544087C0914083FF4940
15843	5	47	242	1733	70308	\N	52.163575000000002	Алтайский край, Волчихинский район, с.Новокормиха, Центральная, 13		0101000020E6100000E355D636C5055440BBB88D06F0144A40
15839	5	47	242	1476	70668	\N	52.164990000000003	Алтайский край, Волчихинский район, с.Малышев Лог, Октябрьская, 44/Б		0101000020E61000001557957D573A544062156F641E154A40
15842	5	47	242	1640	71007	\N	52.176913838460202	Алтайский край, Волчихинский район, п.Коминтерн, Гагарина, 11	Россия, Алтайский край, Волчихинский район, поселок Коминтерн	0101000020E610000056116E32AA0D54402E1A321EA5164A40
15836	5	47	242	1297	69877	\N	52.139068000000002	Алтайский край, Волчихинский район, с.Вострово, Советская, 15/В		0101000020E6100000AFCF9CF529285440C7F5EFFACC114A40
15831	5	47	242	960	70006	\N	52.018301999999998	Алтайский край, Волчихинский район, с.Волчиха, Свердлова, 6		0101000020E61000008B53AD8559175440C7B94DB857024A40
15832	5	47	242	960	70143	\N	52.018301999999998	Алтайский край, Волчихинский район, с.Волчиха, Матросова, 4		0101000020E61000008B53AD8559175440C7B94DB857024A40
15830	5	47	242	960	70144	\N	52.022117471125398	Алтайский край, Волчихинский район, с.Волчиха, Ленина, 63		0101000020E61000001232906797175440C3D7D7BAD4024A40
15834	5	47	242	960	70139	\N	52.018301999999998	Алтайский край, Волчихинский район, с.Волчиха, 30 лет Октября, 70		0101000020E61000008B53AD8559175440C7B94DB857024A40
16282	5	47	242	59440	71406	\N	52.265579183809699	Алтайский край, Новичихинский район, пос. Веселая Дубрава, ул.Боровская	Россия, Алтайский край, Волчихинский район, поселок Веселая Дубрава	0101000020E61000004850FC187342544090C01F7EFE214A40
15845	5	47	242	1823	70456	\N	51.872608999999997	Алтайский край, Волчихинский район, с.Бор-Форпост, Сидорова, 10		0101000020E6100000D53DB2B96A075440FE98D6A6B1EF4940
15844	5	47	242	1785	71333	\N	52.074423000000003	Алтайский край, Волчихинский район, п.Березовский, Кошевого, 8/А		0101000020E6100000A933F790F0065440FD885FB186094A40
15828	5	47	142	840	70138	\N	52.215788000000003	Алтайский край, Быстроистокский район, с. Хлеборобное, Целинная, 10		0101000020E6100000C26D6DE179285540446FF1F09E1B4A40
15829	5	47	142	901	71331	\N	52.388202	Алтайский край, Быстроистокский район, с. Усть-Ануй, Центральная, 51		0101000020E6100000B2D47ABFD1305540F31E679AB0314A40
15824	5	47	142	59406	70718	\N	52.345627641278902	Алтайский край, Быстроистокский район, с. Приобское, Молодежная, 2	Россия, Алтайский край, Быстроистокский район, поселок Приобский	0101000020E61000004487C091401D55407B4ACE893D2C4A40
15826	5	47	142	734	70667	\N	52.220483000000002	Алтайский край, Быстроистокский район, с. Новопокровка, Советская, 120		0101000020E61000009E42AED4B31B5540782975C9381C4A40
15825	5	47	142	675	70840	\N	52.327443000000002	Алтайский край, Быстроистокский район, с. Верх-Озерное, Центральная, 7а		0101000020E6100000B517D1764C115540EE26F8A6E9294A40
15827	5	47	142	792	70004	\N	52.210186999999998	Алтайский край, Быстроистокский район, с. Верх-Ануйское, Советская, 20		0101000020E6100000772B4B7496255540AD855968E71A4A40
94899	5	47	142	415	69586	\N	52.369813000000001	Алтайский край, с. Быстрый Исток, Советская, 55		0101000020E610000005A3923A011755405D514A08562F4A40
15823	5	47	142	415	69586	\N	52.365852109657702	Алтайский край, с.Быстрый Исток, Советская, 13	Россия, Алтайский край, Быстроистокский район, поселок Быстрый Исток	0101000020E610000017618A72691855408D96033DD42E4A40
15822	5	47	142	415	69586	\N	52.369813000000001	Алтайский край, с. Быстрый Исток, Советская, 24		0101000020E610000005A3923A011755405D514A08562F4A40
15820	5	47	142	339	70453	\N	52.434686999999997	Алтайский край, Быстроистокский район, c. Акутиха, Коммунистическая, 39		0101000020E610000037AAD381AC1D5540887FD8D2A3374A40
15807	5	47	111	32129	71246	\N	53.172556719245001	Алтайский край, Бурлинский район, с.Чернавка, ул.Центральная, 38	Россия, Алтайский край, Бурлинский район, поселок Чернавка	0101000020E610000066BB421F2C8A534012D9075916964A40
15805	5	47	111	32047	70835	\N	53.195370368367499	Алтайский край, Бурлинский район, с.Цветополь, ул.Центральная, 31А	Россия, Алтайский край, Бурлинский район, поселок Цветополь	0101000020E61000009C189293898F53404C4F58E201994A40
15818	5	47	111	212	70452	\N	53.451345000000003	Алтайский край, Бурлинский район, с.Устьянка, ул.Советская, 57		0101000020E6100000AA656B7D91AF5340481B47ACC5B94A40
15811	5	47	111	32302	71347	\N	53.366550406091498	Алтайский край, Бурлинский район, с.Петровка, пер.Школьный, 5А	Россия, Алтайский край, Бурлинский район, поселок Петровка	0101000020E61000007C46223482835340A52C431CEBAE4A40
15810	5	47	111	22170	71167	\N	53.353890999999997	Алтайский край, Бурлинский район, с.Первомайское, ул.Школьная, 13А		0101000020E61000005BB39597FC8F5340A3ACDF4C4CAD4A40
15813	5	47	111	32370	70825	\N	53.336160999999997	Алтайский край, Бурлинский район, с.Партизанское, ул.Жуковского, 5		0101000020E6100000DC2A8881AE9653406798DA5207AB4A40
15806	5	47	111	32070	70670	\N	53.131801000000003	Алтайский край, Бурлинский район, с.Орехово, ул.Чапаева, 42		0101000020E610000087359545618D5340414AECDADE904A40
15809	5	47	111	32198	70310	\N	53.519765999999997	Алтайский край, Бурлинский район, с.Новосельское, ул.Гагарина, 9		0101000020E610000045F5D6C0568953404FC939B187C24A40
15815	5	47	111	32456	70304	\N	53.415374999999997	Алтайский край, Бурлинский район, с.Новопесчаное, ул.Центральная, 12		0101000020E6100000319413ED2AA15340BA490C022BB54A40
15808	5	47	111	32178	71267	\N	53.039383999999998	Алтайский край, Бурлинский район, с.Новоандреевка, ул.Вишневская, 24		0101000020E61000008099EFE0279853402AFEEF880A854A40
15817	5	47	111	170	70987	\N	53.384687	Алтайский край, Бурлинский район, с.Новоалексеевка, ул.Школьная, 6А		0101000020E61000001348895DDBA453402219726C3DB14A40
15804	5	47	111	31998	70302	\N	53.247166999999997	Алтайский край, Бурлинский район, с.Михайловка, ул.Ленина, 17Б		0101000020E61000008CF50D4C6E89534041D3122BA39F4A40
15819	5	47	111	288	71336	\N	53.528570999999999	Алтайский край, Бурлинский район, с.Лесное, ул.Школьная, 12		0101000020E6100000EFFE78AF5AAD5340984EEB36A8C34A40
15814	5	47	111	32445	70834	\N	53.406647999999997	Алтайский край, Бурлинский район, с.Гусиная Ляга, пер.Школьный, 2		0101000020E6100000ECA353573E995340ED7DAA0A0DB44A40
15802	5	47	111	31801	70003	\N	53.334138847940601	Алтайский край, Бурлинский район, с.Бурла, ул.Первомайская, 42	Россия, Алтайский край, Бурлинский район, поселок Бурла	0101000020E610000093382BA226955340B9A81611C5AA4A40
15800	5	47	111	31801	69879	\N	53.334704000000002	Алтайский край, Бурлинский район, с.Бурла, ул.Ленина, 12		0101000020E61000006B0F7BA18095534092EBA694D7AA4A40
15801	5	47	111	31801	70665	\N	53.334704000000002	Алтайский край, Бурлинский район, с.Бурла, ул.Гоголя, 68		0101000020E61000006B0F7BA18095534092EBA694D7AA4A40
15812	5	47	111	32335	71171	\N	53.267733999999997	Алтайский край, Бурлинский район, с.Асямовка, ул.Титова, 19		0101000020E6100000BED9E6C6F49D53407D03931B45A24A40
15797	5	47	968	31673	70559	\N	52.747028	Алтайский край, Благовещенский район, с.Яготино, Мира, 30		0101000020E6100000C503CAA65CE8534020990E9D9E5F4A40
15795	5	47	968	31583	70632	\N	53.002268999999998	Алтайский край, Благовещенский район, с.Шимолино, Центральная, 1		0101000020E61000003D27BD6F7CFE5340B665C0594A804A40
15798	5	47	968	31728	70851	\N	52.797504000000004	Алтайский край, Благовещенский район, п.Тельманский, Калинина, 32		0101000020E610000039252026E1E25340F0366F9C14664A40
15790	5	47	968	31336	70982	\N	52.983210999999997	Алтайский край, Благовещенский район, с.Татьяновка, Комсомольская, 36		0101000020E6100000B5352218070F5440A208A9DBD97D4A40
15794	5	47	968	31530	70449	\N	52.801527999999998	Алтайский край, Благовещенский район, с.Суворовка, Советская, 18		0101000020E61000005340DAFF00085440056A317898664A40
15775	5	47	968	59347	69875	\N	52.777293	Алтайский край, Благовещенский район, р.п.Степное Озеро, Химиков, 2	Россия, Алтайский край, Благовещенский район, поселок Степное Озеро	0101000020E6100000228C9FC6BDF65340723447567E634A40
15772	5	47	968	59347	70273	\N	52.7817467004595	Алтайский край, Благовещенский район, р.п.Степное Озеро, Мира, 17	Россия, Алтайский край, Благовещенский район, поселок Степное Озеро	0101000020E61000003E23111AC1F65340815F234910644A40
15774	5	47	968	59347	70209	\N	52.782237243036597	Алтайский край, Благовещенский район, р.п.Степное Озеро, Мира, 12	Россия, Алтайский край, Благовещенский район, поселок Степное Озеро	0101000020E61000009A07B0C8AFF653404F5C8E5720644A40
15773	5	47	968	59347	69699	\N	52.782787546724201	Алтайский край, Благовещенский район, р.п.Степное Озеро, Микитона, 13	Россия, Алтайский край, Благовещенский район, поселок Степное Озеро	0101000020E61000001ADF1797AAF65340C2D9AD6532644A40
15792	5	47	968	31442	70822	\N	52.684457000000002	Алтайский край, Благовещенский район, с.Орлеан, Ленина, 19а		0101000020E6100000E7559DD502E65340574277499C574A40
15791	5	47	968	31387	70447	\N	53.044668000000001	Алтайский край, Благовещенский район, с.Новокулундинка, Мира, 42		0101000020E6100000D4F02DAC1B0A5440C09657AEB7854A40
15789	5	47	968	31278	70448	\N	52.958557999999996	Алтайский край, Благовещенский район, с.Николаевка, Школьный, 17		0101000020E610000010B22C98F80A5440DAA84E07B27A4A40
15788	5	47	968	31247	70798	\N	52.705502000000003	Алтайский край, Благовещенский район, с.Нижний Кучук, Центральная, 24		0101000020E61000005D1ABFF04AFC53409DA1B8E34D5A4A40
15785	5	47	968	30378	70299	\N	52.934730999999999	Алтайский край, Благовещенский район, с.Леньки, Центральная, 7		0101000020E610000001DA56B3CE1C544058C7F143A5774A40
15786	5	47	968	30378	70444	\N	52.934730999999999	Алтайский край, Благовещенский район, с.Леньки, Маяковского, 75		0101000020E610000001DA56B3CE1C544058C7F143A5774A40
15771	5	47	968	30378	70444	\N	52.934730999999999	Благовещенский район, с.Леньки, ул.Маяковского, 75		0101000020E610000001DA56B3CE1C544058C7F143A5774A40
15784	5	47	968	30378	70002	\N	52.934730999999999	Алтайский край, Благовещенский район, с.Леньки, Ленина, 4		0101000020E610000001DA56B3CE1C544058C7F143A5774A40
16623	5	47	968	8064	71073	\N	52.785012000000002	Алтайский край, Табунский район, с.Елизаветград, ул.Интернациональная, д.43		0101000020E610000089450C3B8CD75340D97BF1457B644A40
15787	5	47	968	31190	\N	\N	53.042892999999999	Алтайский край, Благовещенский район, с.Дмитриевка, Здание сельского Дома культуры	Россия, Алтайский край, Благовещенский район, поселок Дмитриевка	0101000020E6100000153B1A87FA1A5440191D90847D854A40
15708	5	47	409	2181	70001	\N	51.939929999999997	Алтайский край, Алтайский район, с. Алтайское, Ленина, 87		0101000020E610000034A1496249555540BF4351A04FF84940
15783	5	47	968	30978	69704	\N	52.765175999999997	Алтайский край, Благовещенский район, с.Глядень-1, Школьный, 4		0101000020E6100000B5F97FD59110544090D78349F1614A40
15778	5	47	968	29803	69698	\N	52.831363000000003	Алтайский край, Благовещенский район, р.п.Благовещенка, Урицкого, 2		0101000020E6100000E8A562635EF953405F0D501A6A6A4A40
15779	5	47	968	29803	70136	\N	52.831363000000003	Алтайский край, Благовещенский район, р.п.Благовещенка, Советская, 47		0101000020E6100000E8A562635EF953405F0D501A6A6A4A40
15781	5	47	968	29803	69700	\N	52.831363000000003	Алтайский край, Благовещенский район, р.п.Благовещенка, Ленина, 82		0101000020E6100000E8A562635EF953405F0D501A6A6A4A40
15780	5	47	968	29803	69700	\N	52.831363000000003	Алтайский край, Благовещенский район, р.п.Благовещенка, Ленина, 95		0101000020E6100000E8A562635EF953405F0D501A6A6A4A40
15777	5	47	968	29803	70102	\N	52.831363000000003	Алтайский край, Благовещенский район, р.п.Благовещенка, пер.Колхозный, 114		0101000020E6100000E8A562635EF953405F0D501A6A6A4A40
15776	5	47	968	29803	69707	\N	52.831363000000003	Алтайский край, Благовещенский район, р.п.Благовещенка, Клубная, 18		0101000020E6100000E8A562635EF953405F0D501A6A6A4A40
15793	5	47	968	31506	71192	\N	52.640504999999997	Алтайский край, Благовещенский район, п.Байгамут, Абая, 3		0101000020E610000093A7ACA6EBEC534055F65D11FC514A40
15782	5	47	968	30962	70443	\N	52.895032	Алтайский край, Благовещенский район, с.Алексеевка, Центральная, 10		0101000020E61000003D0D18247D225440CE6F986890724A40
15758	5	47	1833	29764	70970	\N	52.680582223019101	Алтайский край, Бийский район, поселок Ясная Поляна, Школьная, 1	Россия, Алтайский край, Бийский район, поселок Ясная Поляна	0101000020E61000008CA37213B55B5540861F9C4F1D574A40
94898	5	47	1833	30022	69876	\N	52.714564000000003	Алтайский край, Бийский район, село Шебалино, Ленина, 23		0101000020E6100000890AD5CDC5725540117349D5765B4A40
15741	5	47	1833	28997	70750	\N	52.441192000000001	Алтайский край, Бийский район, поселок Чуйский, Центральная, 11		0101000020E6100000BE6C3B6D8D5F5540E0A0BDFA78384A40
15770	5	47	1833	30359	70440	\N	52.565415999999999	Алтайский край, Бийский район, село Усятское, Советская, 6		0101000020E61000009C16BCE82B7155404C512E8D5F484A40
15743	5	47	1833	29099	71262	\N	52.458306	Алтайский край, Бийский район, село Усть-Катунь, Школьный, 14		0101000020E61000008EE733A0DE4A5540C1C760C5A93A4A40
15747	5	47	1833	29259	71157	\N	52.606458000000003	Алтайский край, Бийский район, поселок Студенческий, Фермерская, 23		0101000020E6100000B1E07EC0034D5540E4326E6AA04D4A40
15746	5	47	1833	29235	70968	\N	52.6586304318676	Алтайский край, Бийский район, село Старая Чемровка, Советская, 64	Россия, Алтайский край, Бийский район, поселок Старая Чемровка	0101000020E6100000C0046EDDCD4B55400E15E3FC4D544A40
94896	5	47	1833	29319	70771	\N	52.602257999999999	Алтайский край, Бийский район, село Стан-Бехтемир, Колхозная, 32а		0101000020E610000038BA4A77D76755408FE046CA164D4A40
15762	5	47	1833	29949	69869	\N	52.417904999999998	Алтайский край, Бийский район, село Сростки, Советская, 104		0101000020E610000097E315889E6C5540DDEA39E97D354A40
15752	5	47	1833	29493	71343	\N	52.547392000000002	Алтайский край, Бийский район, поселок Семеновод, Латунина, 1к		0101000020E6100000145FED28CE5A5540C80BE9F010464A40
15764	5	47	1833	29766	69822	\N	52.527185000000003	Алтайский край, Бийский район, с.Светлоозерское, ул.Центральная, 26		0101000020E6100000C74CA25EF06155408CF84ECC7A434A40
15755	5	47	1833	29614	71377	\N	52.573605000000001	Алтайский край, Бийский район, поселок Пригородный, Новая, 15		0101000020E61000009E45EF54C04F55403AE97DE36B494A40
15767	5	47	1833	28038	70907	\N	52.424588999999997	Алтайский край, Бийский район, поселок Полеводка, ул.Трактовая, 1		0101000020E6100000C47762D68B645540E49EAEEE58364A40
15760	5	47	1833	29861	69868	\N	52.593401999999998	Алтайский край, Бийский район, село Первомайское, Степная, 24а		0101000020E61000009752978C63505540C4B0C398F44B4A40
15761	5	47	1833	29861	69647	\N	52.593401999999998	Алтайский край, Бийский район, село Первомайское, Мира, 4		0101000020E61000009752978C63505540C4B0C398F44B4A40
15756	5	47	1833	29667	69872	\N	52.618625000000002	Алтайский край, Бийский район, село Новиково, Советская, 30		0101000020E6100000BD8FA339B27D554077BE9F1A2F4F4A40
15769	5	47	1833	30287	70826	\N	52.578578999999998	Алтайский край, Бийский район, село Мальцева-Курья, Озерная, 29а		0101000020E6100000FD101B2C9C6C554081936DE00E4A4A40
15753	5	47	1833	59386	70133	\N	52.554264396170197	Алтайский край, Бийский район, с.Малоугренево, пл.Щигорева, 4		0101000020E6100000D7BD158909565540D2AC6C1FF2464A40
94897	5	47	1833	29424	70134	\N	52.567036999999999	Алтайский край, Бийский район, село Малоенисейское, Советская, 98		0101000020E6100000446D1B46416055409C4F1DAB94484A40
15749	5	47	1833	29339	70130	\N	52.468522	Алтайский край, Бийский район, село Лесное, Советская, 20		0101000020E61000009031772D215055406FBA6587F83B4A40
15768	5	47	1833	30220	70976	\N	52.591087999999999	Алтайский край, Бийский район, село Ключи, Советская, 17		0101000020E6100000016DAB59676955406E8786C5A84B4A40
94895	5	47	1833	29176	70543	\N	52.596662000000002	Алтайский край, Бийский район, поселок Заря, Центральная, 18а		0101000020E61000003CBD5296214B55400B62A06B5F4C4A40
15765	5	47	1833	30098	70916	\N	52.533244000000003	Алтайский край, Бийский район, поселок Заозерный, Лесная, 6		0101000020E61000003BA6EECA2E5F5540E564E25641444A40
15744	5	47	1833	29124	69873	\N	52.577291935318001	Алтайский край, Бийский район, село Енисейское, В.Максимовой, 24А	Россия, Алтайский край, Бийский район, поселок Енисейское	0101000020E61000003F390A1005605540081F4AB4E4494A40
15759	5	47	1833	29801	71161	\N	52.636536999999997	Алтайский край, Бийский район, поселок Восточный, Школьная, 13		0101000020E6100000F2D3B837BF565540D3D85E0B7A514A40
94894	5	47	1833	29040	69998	\N	52.449761000000002	Алтайский край, Бийский район, село Верх-Катунское, Ленина, 23б		0101000020E6100000C7681D554D5B55401502B9C491394A40
94893	5	47	1833	28956	70303	\N	52.763148999999999	Алтайский край, Бийский район, село Верх-Бехтемир, Советский, 12		0101000020E610000045F30016F9795540D07CCEDDAE614A40
15754	5	47	1833	32506	70793	\N	52.572948520611497	Алтайский край, Бийский район, поселок Боровой, Пионерская, 9	Россия, Алтайский край, Бийский район, поселок Боровой	0101000020E610000091D442C9E453554051A3906456494A40
94892	5	47	1833	28917	70549	\N	52.602060999999999	Алтайский край, Бийский район, село Большеугренево, Смирнова, 11		0101000020E6100000A08A1BB7987055403999B855104D4A40
15757	5	47	1833	33048	71273	\N	52.655004143004298	Алтайский край, Бийский район, поселок Б-Аникино, ул. Аникинская, 40	Россия, Алтайский край, Бийский район, поселок Бехтемир-Аникино	0101000020E610000047CB811E6A735540E55FCB2BD7534A40
15750	5	47	1833	29395	71162	\N	52.481067000000003	Алтайский край, Бийский район, поселок Амурский, Катунская, 18		0101000020E61000001BF67B629D535540A9177C9A933D4A40
15738	5	47	1839	28866	70958	\N	53.509459	Алтайский край, Баевский район, с.Чуманка, Ленина, 28		0101000020E6100000F0315871AA1D544091D3D7F335C14A40
15730	5	47	1839	28481	70661	\N	53.133502999999997	Алтайский край, Баевский район, с.Ситниково, Почтовая, 8		0101000020E61000003DB9A640663C54407D7555A016914A40
15729	5	47	1839	28444	70977	\N	53.190284370980699	Алтайский край, Баевский район, с.Сафроново, Школьная, 3	Россия, Алтайский край, Баевский район, поселок Сафроново	0101000020E610000015ADDC0BCC465440DD79E2395B984A40
15727	5	47	1839	28348	70431	\N	53.338382000000003	Алтайский край, Баевский район, с.Прослауха, Центральная, 22		0101000020E6100000992D5915E13D54400DC7F31950AB4A40
15732	5	47	1839	28563	70740	\N	53.129494000000001	Алтайский край, Баевский район, с.Покровка, Центральная, 31		0101000020E61000008F34B8AD2D1F54409D83674293904A40
15737	5	47	1839	28822	70664	\N	53.462341000000002	Алтайский край, Баевский район, с.Плотава, Центральная, 21		0101000020E610000053060E68E92E5440CB4C69FD2DBB4A40
15728	5	47	1839	28409	70979	\N	53.142335000000003	Алтайский край, Баевский район, с.Паклино, Береговая, 11		0101000020E6100000390F27309D465440C009850838924A40
15733	5	47	1839	28628	70746	\N	53.232292999999999	Алтайский край, Баевский район, с.Павловка, Пушкина, 9		0101000020E61000006D1E87C1FC1754407C0BEBC6BB9D4A40
15731	5	47	1839	28543	70532	\N	53.218578000000001	Алтайский край, Баевский район, с.Нижнечуманка, Кулундинская, 39		0101000020E61000007EA7C98CB725544003D0285DFA9B4A40
15734	5	47	1839	28680	70781	\N	53.317897000000002	Алтайский край, Баевский район, с.Нижнепайва, Центральный переулок, 3		0101000020E61000003830B951641654408E3F51D9B0A84A40
15736	5	47	1839	28756	70666	\N	53.398809999999997	Алтайский край, Баевский район, с.Верх-Чуманка, Набережная, 22а		0101000020E6100000E31A9FC9FE255440ACA8C1340CB34A40
15735	5	47	1839	28735	70446	\N	53.404758000000001	Алтайский край, Баевский район, с.Верх-Пайва, Советская, 6		0101000020E61000003E3E213B6F135440AE65321CCFB34A40
15726	5	47	1839	28199	69847	\N	53.270054049215403	Алтайский край, Баевский район, с.Баево, ул.Терешковой, 21, (ул.Больничная,41)	Россия, Алтайский край, Баевский район, поселок Баево	0101000020E61000000F0EF62686315440B613252191A24A40
15724	5	47	1839	28199	70005	\N	53.267786999999998	Алтайский край, Баевский район, с.Баево, Мира, 30		0101000020E61000009A40118B18315440A0A52BD846A24A40
15722	5	47	409	28119	71257	\N	51.573177999999999	Алтайский край, Алтайский район, с. Тоурак, Центральная, 11		0101000020E6100000DD7BB8E4B8405540B2648EE55DC94940
15711	5	47	409	27637	70129	\N	52.055029846845201	Алтайский край, Алтайский район, с. Старобелокуриха, Советская, 85	Россия, Алтайский край, Алтайский район, поселок Старобелокуриха	0101000020E61000008A20CEC309465540422619390B074A40
15720	5	47	409	28029	70432	\N	51.871100671718303	Алтайский край, Алтайский район, с. Сараса, Кузьмина, 48	Россия, Алтайский край, Алтайский район, поселок Сараса	0101000020E610000039B874CC79565540A741D13C80EF4940
15710	5	47	409	27592	70300	\N	52.085143000000002	Алтайский край, Алтайский район, с. Россоши, Ленина, 19		0101000020E6100000B7B3AF3C484F5540DE3D40F7E50A4A40
15719	5	47	409	28007	71324	\N	51.798268999999998	Алтайский край, Алтайский район, с. Пролетарка, Школьная, 2		0101000020E61000009FC9FE791A5755408F34B8AD2DE64940
15716	5	47	409	27862	70960	\N	51.861887000000003	Алтайский край, Алтайский район, с Нижнекаянча, Школьная, 11		0101000020E61000001DAF40F4A46D55407DEC2E5052EE4940
15709	5	47	409	27549	69654	\N	52.041640999999998	Алтайский край, Алтайский район, с. Нижнекаменка, 60 лет октября, 80		0101000020E6100000E43098BF425855401C96067E54054A40
15712	5	47	409	27678	71315	\N	51.982832999999999	Алтайский край, Алтайский район, с. Макарьевка, Центральная, 47		0101000020E6100000CFF41263994E5540FC36C478CDFD4940
15723	5	47	409	28168	71325	\N	51.667065000000001	Алтайский край, Алтайский район, с. Куяча, Центральная, 20		0101000020E610000095F0845E7F45554033A7CB6262D54940
15721	5	47	409	28084	70537	\N	51.699877000000001	Алтайский край, Алтайский район, с. Куяган, Октябрьская, 2		0101000020E6100000DBE044F46B3A55407E1CCD9195D94940
15718	5	47	409	27961	70721	\N	51.715141000000003	Алтайский край, Алтайский район, с. Комар, Кедровая, 5		0101000020E61000001F4AB4E4F1585540AE8383BD89DB4940
15714	5	47	409	27770	71319	\N	51.91386	Алтайский край, Алтайский район, п. Катунь, Центральная, 6		0101000020E6100000C8957A1684765540B08F4E5DF9F44940
15715	5	47	409	27820	70974	\N	51.957126206300103	Алтайский край, Алтайский район, с. Верх-Ая, ул. Школьная, 7	Россия, Алтайский край, Алтайский район, поселок Верх-Ая	0101000020E610000048F8DEDFA06A55405E13D21A83FA4940
15717	5	47	409	27908	70941	\N	51.625016000000002	Алтайский край, Алтайский район, с. Белое, Центральная, 18		0101000020E61000007AC2120F2856554006BD378600D04940
15707	5	47	409	2181	70301	\N	51.939929999999997	Алтайский край, Алтайский район, с. Алтайское, Целинная, 28		0101000020E610000034A1496249555540BF4351A04FF84940
15705	5	47	409	2181	69867	\N	51.939929999999997	Алтайский край, Алтайский район, с. Алтайское, Советская, 211		0101000020E610000034A1496249555540BF4351A04FF84940
15704	5	47	409	2181	69867	\N	51.939508215365201	Алтайский край, Алтайский район, с. Алтайское, Советская, 97	Россия, Алтайский край, Алтайский район, поселок Алтайское	0101000020E61000000FD6FF39CC555540492A53CC41F84940
15703	5	47	409	2181	69867	\N	51.9448128564214	Алтайский край, Алтайский район, с. Алтайское, Советская, 3	Россия, Алтайский край, Алтайский район, поселок Алтайское	0101000020E61000005DDF878384555540F7EAE3A1EFF84940
15701	5	47	409	2181	70936	\N	51.939929999999997	Алтайский край, Алтайский район, с. Алтайское, Лесная, 9		0101000020E610000034A1496249555540BF4351A04FF84940
15706	5	47	409	2181	69850	\N	51.941415368580003	Алтайский край, Алтайский район, с. Алтайское, пер. Автомобильный, 5	Россия, Алтайский край, Алтайский район, поселок Алтайское	0101000020E6100000821C9430D35555405F7B664980F84940
15693	5	47	278	26816	71159	\N	52.616148000000003	Алтайский край, Алейский район, п.Чернышевский, Степная, 31		0101000020E6100000C6A2E9EC6496544077BF0AF0DD4E4A40
15698	5	47	278	27046	70441	\N	52.422386000000003	Алтайский край, Алейский район, с.Урюпино, Школьная, 22		0101000020E6100000BE326FD575AC5440E62494BE10364A40
15679	5	47	278	26157	70730	\N	52.240941999999997	Алтайский край, Алейский район, с.Уржум, Садовая, 18		0101000020E61000009F3A56293DC25440CD1DFD2FD71E4A40
15682	5	47	278	26293	70938	\N	52.593707999999999	Алтайский край, Алейский район, п.Троицкий, Молодежная, 7а		0101000020E610000094DDCCE847AC5440D1AFAD9FFE4B4A40
15677	5	47	278	27604	71124	\N	52.2587608866883	Алтайский край, Алейский район, с. Т.Дуброва ул. Молодежная, 36	Россия, Алтайский край, Алейский район, поселок Толстая Дуброва	0101000020E61000009C89E942ACCA5440793D98141F214A40
15681	5	47	278	26245	70433	\N	52.513294000000002	Алтайский край, Алейский район, п.Солнечный, Школьная, 1		0101000020E6100000F48B12F417B15440D49D279EB3414A40
94891	5	47	278	26996	70737	\N	52.380198999999998	Алтайский край, Алейский район, п.Совхозный, Гагарина, 8		0101000020E610000053944BE317B55440677C5F5CAA304A40
15674	5	47	278	25958	70992	\N	52.7258126389804	Алтайский край, Алейский район, с.Серебренниково, Садовая, 6	Россия, Алтайский край, Алейский район, поселок Серебренниково	0101000020E6100000E3C3EC65DB9554407E01BD70E75C4A40
15696	5	47	278	2093	70956	\N	52.647412000000003	Алтайский край, Алейский район, с.Савинка, ул. Центральная, 37		0101000020E6100000F2EA1C03B2A75440DC847B65DE524A40
15678	5	47	278	26119	70926	\N	52.213371000000002	Алтайский край, Алейский район, п.Приятельский, Центральная, 34		0101000020E6100000D4F2035779C554401975ADBD4F1B4A40
15695	5	47	278	26913	70934	\N	52.286244000000003	Алтайский край, Алейский район, с.Плотава, Советская, 13		0101000020E610000009E1D1C611B154408F56B5A4A3244A40
15668	5	47	278	25673	71152	\N	52.489463999999998	Алтайский край, Алейский район, п.Первомайский, Луговая, 4		0101000020E6100000BAA46ABB09A85440E048A0C1A63E4A40
15694	5	47	278	26846	70657	\N	52.320363999999998	Алтайский край, Алейский район, с.Осколково, Советская, 82		0101000020E6100000DBFD2AC077CA54406A6803B001294A40
15667	5	47	278	25630	70911	\N	52.343868999999998	Алтайский край, Алейский район, п.Октябрьский, Мира, 3		0101000020E6100000919A7631CDB05440DA8D3EE6032C4A40
15689	5	47	278	26615	71317	\N	52.765295999999999	Алтайский край, Алейский район, п.Новоникольский, Береговая, 6		0101000020E610000068942EFD4BB554403BE12538F5614A40
15672	5	47	278	25858	71313	\N	52.564895999999997	Алтайский край, Алейский район, с.Новоколпаково, Приозерная, 1		0101000020E610000052D32EA699BE544013D21A834E484A40
15692	5	47	278	26768	70654	\N	52.623000027014498	Алтайский край, Алейский район, с.Моховское, Центральная, 16	Россия, Алтайский край, Алейский район, поселок Моховское	0101000020E61000005055A181589E544039B4C876BE4F4A40
15666	5	47	278	25569	70955	\N	52.326726999999998	Алтайский край, Алейский район, п.Мамонтовский, ул. Мира, 1		0101000020E6100000BD00FBE8D4AC54402FDCB930D2294A40
15691	5	47	278	26735	70944	\N	52.479016000000001	Алтайский край, Алейский район, с.Малиновка, Центральная, 32г		0101000020E610000076FBAC32538F544060217365503D4A40
15665	5	47	278	25521	71318	\N	52.409225999999997	Алтайский край, Алейский район, с.Малахово, Школьный, 1		0101000020E6100000994A3FE1ECAF544021567F8461344A40
15700	5	47	278	2138	71093	\N	52.386004	Алтайский край, Алейский район, с.Красный Яр, Молодежная,33а		0101000020E6100000E84A04AA7FA7544006103E9468314A40
15688	5	47	278	26582	70951	\N	52.688208972180398	Алтайский край, Алейский район, п.Краснодубровский, Юбилейная, 8	Россия, Алтайский край, Алейский район, поселок Краснодубровский	0101000020E6100000B2463D44A3B054400CE8853B17584A40
15687	5	47	278	26531	71107	\N	52.710024468277297	Алтайский край, Алейский район, п.Кондратьевский, Первомайская, 13а	Россия, Алтайский край, Алейский район, поселок Кондратьевский	0101000020E610000065C405A051B7544003B00111E25A4A40
15685	5	47	278	26441	71154	\N	52.730905	Алтайский край, Алейский район, с.Кировское, Советская, 1		0101000020E6100000D95DA0A4C0AE5440CFBD874B8E5D4A40
15684	5	47	278	26403	70650	\N	52.368746999999999	Алтайский край, Алейский район, с.Кашино, Октябрьская, 52		0101000020E6100000E86C01A1F5A35440C2BF081A332F4A40
15683	5	47	278	26345	70297	\N	52.307492000000003	Алтайский край, Алейский район, с.Кабаково, Центральная, 2б		0101000020E61000007E8E8F16679F54400DE4D9E55B274A40
15680	5	47	278	26193	70655	\N	52.508473993861003	Алтайский край, Алейский район, п.Заветы Ильича, Школьная, 8	Россия, Алтайский край, Алейский район, поселок Заветы Ильича	0101000020E6100000A27F828B15AC5440E36E10AD15414A40
15686	5	47	278	1185	71000	\N	52.652251999999997	Алтайский край, Алейский район, п.Дубровский, ул. Центральная, 24		0101000020E6100000CE55F31C91B65440136058FE7C534A40
15676	5	47	278	26038	70132	\N	52.576723999999999	Алтайский край, Алейский район, с.Дружба, Пионерская, 36		0101000020E61000009A7ADD2230A05440BE688F17D2494A40
15675	5	47	278	26007	70954	\N	52.223569319552702	Алтайский край, Алейский район, с.Ветелки, Центральная, 29	Россия, Алтайский край, Алейский район, поселок Ветелки	0101000020E61000007E8E8F1667B9544020B3B3E89D1C4A40
15699	5	47	278	59403	70659	\N	52.467491000000003	Алтайский край, Алейский район, с.Вавилон, Комсомольская, 34		0101000020E61000002219726C3DAA54405116BEBED63B4A40
15673	5	47	278	25904	70528	\N	52.650865000000003	Алтайский край, Алейский район, с.Боровское, Кирова, 56		0101000020E610000052B9895A9A8B5440378E588B4F534A40
15690	5	47	278	26685	70296	\N	52.287515999999997	Алтайский край, Алейский район, п.Бориха, Центральная, 1		0101000020E6100000179E978A8DA95440D2890453CD244A40
15671	5	47	278	25807	70932	\N	52.518166000000001	Алтайский край, Алейский район, с.Большепанюшево, Садовая, 2б		0101000020E61000003065E08096B7544017F3734353424A40
12249	8	80	1303	40441	61251	\N	43.124491999999996	с. Гансолчу, МОУ «СОШ с. Гансолчу», ул. А.А. Кадырова, д. №7		0101000020E610000074B515FBCB1E47408B4E965AEF8F4540
15670	5	47	278	25783	70546	\N	52.520242228309201	Алтайский край, Алейский район, с.Безголосово, Центральная, 24	Россия, Алтайский край, Алейский район, поселок Безголосово	0101000020E6100000D23AAA9A20BE5440B900344A97424A40
15669	5	47	278	25727	71156	\N	52.388421999999998	Алтайский край, Алейский район, п.Александровский, Центральная, 1		0101000020E6100000105CE50984BB54400186E5CFB7314A40
15664	5	47	278	1173	70288	\N	52.470214030309201	Алтайский край, Алейский район, п. Алейский ул. Мира,2	Россия, Алтайский край, Алейский район, поселок Алейский	0101000020E61000000DC2DCEEE5AE5440880FECF82F3C4A40
12137	8	80	\N	57828	61441	\N	68.635360000000006	с. Нижний Нойбер, ул. К.Л. Тепсуева, 40, СОШ № 2	Россия	0101000020E6100000D8648D7A88F45840F14BFDBCA9285140
12136	8	80	\N	57828	61441	\N	68.635360000000006	с. Нижний Нойбер, ул. К.Л. Тепсуева, 26, СОШ № 1	Россия	0101000020E6100000D8648D7A88F45840F14BFDBCA9285140
12169	8	80	\N	57767	61169	\N	43.207047300012803	Чеченская Республика, Курчалоевский муниципальный район, Аллеройское сельское поселение, С.Абуева	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E61000005114E813790C474012DE1E84809A4540
12124	8	80	\N	57768	\N	\N	43.353447000000003	г. Гудермес, СШ №10, ул. Еременко		0101000020E61000006CEEE87FB90C474046EF54C03DAD4540
12118	8	80	\N	57768	61181	\N	43.353447000000003	г. Гудермес, ДДТ, пр-кт им.А-Х.Кадырова 14		0101000020E61000006CEEE87FB90C474046EF54C03DAD4540
12119	8	80	\N	57768	61224	\N	43.353447000000003	г. Гудермес, Здание ДРСУ, ул.Школьная, 20		0101000020E61000006CEEE87FB90C474046EF54C03DAD4540
12109	8	80	\N	57768	61252	\N	43.351994628716596	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, Свободы, 68, ГУП «Чеводоканал»		0101000020E61000004F5AB8ACC20E474082AD122C0EAD4540
12122	8	80	\N	57768	61211	\N	43.353447000000003	г. Гудермес, ул. Партизанская, 4, СОШ № 1		0101000020E61000006CEEE87FB90C474046EF54C03DAD4540
12120	8	80	\N	57768	61182	\N	43.353447000000003	г. Гудермес, СШ №2, ул.Нурадилова, 22		0101000020E61000006CEEE87FB90C474046EF54C03DAD4540
12453	8	80	\N	28733	\N	\N	43.272956863318299	Чеченская Республика, Грозненский муниципальный район, Ярыш-Мардинское сельское поселение, б/у, Здание администрации		0101000020E6100000971AA19FA9DB46406D1B4641F0A24540
12443	8	80	\N	28733	\N	\N	43.365057947532897	гор. Иванова, б/н, СОШ №26	Россия, республика Чеченская, Грозный	0101000020E6100000E4DBBB067DCD464053927538BAAE4540
12094	8	80	\N	28733	62330	\N	43.303703536058201	Чеченская Республика, Грозненский муниципальный район, Чишкинское сельское поселение, Кадырова, 51		0101000020E610000075C7629B54DA46400BD5CDC5DFA64540
12447	8	80	\N	28733	61101	\N	43.335959854244798	"Чеченская Республика, муниципальное образование город Грозный, гор.Маяковского, УКК ОАО ""Грознефтегаз"""	Россия, республика Чеченская, Грозный	0101000020E61000007808E3A771D74640D061BEBC00AB4540
12450	8	80	\N	28733	61281	\N	43.336711659882702	Грозный, г-к. Маяковского, д.109, СОШ №44	Россия, республика Чеченская, Грозный	0101000020E6100000A2EC2DE57CD74640DB15FA6019AB4540
12451	8	80	\N	28733	61261	\N	43.3294438127148	Чеченская Республика, муниципальное образование город Грозный, г-к Нефтемайск, б/н, СОШ №17	Россия, республика Чеченская, Грозный	0101000020E610000094A46B26DFDA464085EE92382BAA4540
12449	8	80	\N	28733	61064	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, г-к Маяковского, СОШ №10		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12445	8	80	\N	28733	61255	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Яблочная, Гимназия №4		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12082	8	80	\N	28733	60989	\N	43.278977326888203	Чеченская Республика, Грозненский муниципальный район, Беркат-Юртовское сельское поселение, Школьная, СОШ	Россия, республика Чеченская, Грозный	0101000020E61000001F0E12A27CDB464008ABB184B5A34540
12078	8	80	\N	28733	60989	\N	43.277973957951801	Чеченская Республика, Грозненский муниципальный район, Толстой-Юртовское сельское поселение, Школьная, СОШ №2	Россия, республика Чеченская, Грозный	0101000020E610000090DB2F9FACD84640B491EBA694A34540
12095	8	80	\N	28733	61019	\N	43.280984014770503	Чеченская Республика, Грозненский муниципальный район, Дачу-Борзойское сельское поселение, Шерипова, 17	Россия, республика Чеченская, Грозный	0101000020E61000000F27309DD6DB46408159A148F7A34540
12403	8	80	\N	28733	61070	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Ш.А.Митаева, 97		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12100	8	80	\N	28733	61076	\N	43.288592132075202	Чеченская Республика, Грозненский муниципальный район, Алхан-Калинское сельское поселение, Ц.Уадьба, 1	Россия, республика Чеченская, Грозный	0101000020E6100000AB4198DBBDD2464091F12895F0A44540
12419	8	80	\N	28733	75505	\N	43.334209000000001	Октябрьский р-н, ул. Ханкальская, 87, СОШ № 23,	Россия, республика Чеченская, Грозный	0101000020E610000055185B0872D44640B2834A5CC7AA4540
12426	8	80	\N	28733	61059	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Фонтанная, 7		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12390	8	80	\N	28733	61015	\N	43.316409617392701	Чеченская Республика, муниципальное образование город Грозный, Фасадная, 22	Россия, республика Чеченская, Грозный	0101000020E6100000FED137691AD846404D10751F80A84540
12375	8	80	\N	28733	61012	\N	43.316910984674401	Чеченская Республика, муниципальное образование город Грозный, Ученическая, 2	Россия, республика Чеченская, Грозный	0101000020E61000008C65FA25E2D746400F5F268A90A84540
12399	8	80	\N	28733	61020	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Урожайная, 23		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12260	8	80	1303	40450	61177	\N	43.174131000000003	с. Галайты, МОУ «СОШ с. Галайты», ул. А.А. Кадырова, д. № 19		0101000020E6100000A4DE5339ED314740221CB3EC49964540
12446	8	80	\N	28733	60999	\N	43.315657558658799	Чеченская Республика, муниципальное образование город Грозный, Угольная, 320	Россия, республика Чеченская, Грозный	0101000020E6100000703E75AC52D84640425C397B67A84540
12448	8	80	\N	28733	61100	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Турбинная, 1а		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12087	8	80	\N	28733	61074	\N	43.296032049269797	Чеченская Республика, Грозненский муниципальный район, Гикаловское сельское поселение, Трудовая, 1	Россия, республика Чеченская, Грозный	0101000020E6100000483140A209D64640E4486760E4A54540
12408	8	80	\N	28733	61053	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Субботников, 60		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12073	8	80	\N	28733	61241	\N	43.2797298426552	Чеченская Республика, Грозненский муниципальный район, Правобережненское сельское поселение, с.Газ-Городок, Сторителей, СДК		0101000020E6100000A8A78FC01FDC4640E4DA5031CEA34540
12436	8	80	\N	28733	61039	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Старопромысловское шоссе, 38		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12389	8	80	\N	28733	60972	\N	43.338904372783603	Чеченская Республика, муниципальное образование город Грозный, Социалистическая, 10	Россия, республика Чеченская, Грозный	0101000020E61000009F1C058882D74640E63DCE3461AB4540
12101	8	80	\N	28733	61077	\N	43.324111681895602	Чеченская Республика, Грозненский муниципальный район, Октябрьское сельское поселение, Советская, СОШ		0101000020E6100000B0CBF09F6EDA4640DE1E84807CA94540
12424	8	80	\N	28733	61161	\N	43.319668430253699	Чеченская Республика, муниципальное образование город Грозный, ул. Сайханова, № 93 ПУ-7 (бывшее общежитие)	Россия, республика Чеченская, Грозный	0101000020E610000087C5A86BEDD74640F3C98AE1EAA84540
12091	8	80	\N	28733	61150	\N	43.3356406032145	Чеченская Республика, Грозненский муниципальный район, Старо-Атагинское сельское поселение, Нурадилова, 179а	Россия, республика Чеченская, Грозный	0101000020E61000004CA7751BD4D646402F19C748F6AA4540
12437	8	80	\N	28733	61063	\N	43.293592998890396	Чеченская Республика, муниципальное образование город Грозный, Новаторов, 29	Россия, республика Чеченская, Грозный	0101000020E6100000A2EC2DE57CD74640D2AA967494A54540
12393	8	80	\N	28733	61091	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Николаева, 50		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12423	8	80	\N	28733	60997	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Нахимова, 161		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12407	8	80	\N	28733	61050	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Моздокская, 34		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12089	8	80	\N	28733	61022	\N	43.295028963616602	Чеченская Республика, Грозненский муниципальный район, Чечен-Аульское сельское поселение, Митаева, 41	Россия, республика Чеченская, Грозный	0101000020E6100000185A9D9CA1D44640902FA182C3A54540
12074	8	80	\N	28733	60987	\N	43.277973957951801	Чеченская Республика, Грозненский муниципальный район, Правобережненское сельское поселение, Маяковского, 3а	Россия, республика Чеченская, Грозный	0101000020E610000090DB2F9FACD84640B491EBA694A34540
12092	8	80	\N	28733	61118	\N	43.283997228317197	Чеченская Республика, Грозненский муниципальный район, Старо-Атагинское сельское поселение, Майская, 51	Россия, республика Чеченская, Грозный	0101000020E61000004568041BD7D34640C09481035AA44540
12418	8	80	\N	28733	61276	\N	43.319167085885802	Чеченская Республика, муниципальное образование город Грозный, ул. М.Х. Митаева, 4, СОШ №16	Россия, республика Чеченская, Грозный	0101000020E6100000231631EC30D84640317BD976DAA84540
12417	8	80	\N	28733	61276	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, ул. М.Х. Митаева, 30, ГПТУ №13	Россия, республика Чеченская, Грозный	0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12401	8	80	\N	28733	61096	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Ляпидевского, 9		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12402	8	80	\N	28733	61085	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Лермонтова, 2		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12400	8	80	\N	28733	61287	\N	43.331699445231301	Чеченская Республика, муниципальное образование город Грозный, Л. Яшина, 20, СОШ № 60	Россия, республика Чеченская, Грозный	0101000020E61000007808E3A771D74640D68EE21C75AA4540
12406	8	80	\N	28733	61097	\N	43.328942549587403	Чеченская Республика, муниципальное образование город Грозный, Кутузова, 5	Россия, республика Чеченская, Грозный	0101000020E6100000605793A7ACD84640C39FE1CD1AAA4540
12429	8	80	\N	28733	61027	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Крупская, 10		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12391	8	80	\N	28733	61117	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Коперника, СОШ №63		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12088	8	80	\N	28733	61202	\N	43.291016454364502	Чеченская Республика, Грозненский муниципальный район, Чечен-Аульское сельское поселение, Комсомольская, 5	Россия, республика Чеченская, Грозный	0101000020E6100000889CBE9EAFD546406E4E250340A54540
12440	8	80	\N	28733	61216	\N	43.336711659882702	г.Грозный, ул.Кольцова, д.101, РДКБ	Россия, республика Чеченская, Грозный	0101000020E6100000A2EC2DE57CD74640DB15FA6019AB4540
63698	3	31	667	4716	58035	\N	57.992184000000002	г.Старая Русса, пер.Комсомольский, 1/38		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
12404	8	80	\N	28733	61036	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, пр.Кирова, 29		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12420	8	80	\N	28733	61024	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, пр.Кадырова, СШ №18		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12422	8	80	\N	28733	61120	\N	43.297479955410402	Чеченская Республика, муниципальное образование город Грозный, ул. Кадырова, 256 а, СОШ №25	Россия, республика Чеченская, Грозный	0101000020E6100000A0F99CBB5DDB4640679B1BD313A64540
12084	8	80	\N	28733	61120	\N	43.2824889869404	Чеченская Республика, Грозненский муниципальный район, Комсомольское сельское поселение, Кадырова, 6	Россия, республика Чеченская, Грозный	0101000020E610000073D6A71C93DB4640683D7C9928A44540
12442	8	80	\N	28733	61309	\N	43.344996563577297	Старопромысловский район, ул. З. Ильича, д. 1, СОШ №37	Россия, республика Чеченская, Грозный	0101000020E6100000ECFA05BB61D34640EB1B98DC28AC4540
12439	8	80	\N	28733	61309	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Заветы Ильича, , д. 48, СОШ № 54	Россия, республика Чеченская, Грозный	0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12085	8	80	\N	28733	61009	\N	43.2769705723519	Чеченская Республика, Грозненский муниципальный район, Комсомольское сельское поселение, З. Умаровой, 5	Россия, республика Чеченская, Грозный	0101000020E6100000E02D90A0F8D74640607825C973A34540
12093	8	80	\N	28733	61288	\N	43.285502125418503	Чеченская Республика, Грозненский муниципальный район, Лаха-Варандинское сельское поселение, З. Умаровой, 5	Россия, республика Чеченская, Грозный	0101000020E6100000CCB4FD2B2BD94640A7785C548BA44540
12388	8	80	\N	28733	60998	\N	43.287072380907397	Чеченская Республика, муниципальное образование город Грозный, Донецкая, 1	Россия, республика Чеченская, Грозный	0101000020E6100000605793A7ACD8464075CC79C6BEA44540
12398	8	80	\N	28733	60995	\N	43.330446326470998	Чеченская Республика, муниципальное образование город Грозный, Дарвина, 17	Россия, республика Чеченская, Грозный	0101000020E6100000BE66B96C74D84640098CF50D4CAA4540
12392	8	80	\N	28733	61017	\N	43.316910984674401	Чеченская Республика, муниципальное образование город Грозный, Д.Бедного, 26	Россия, республика Чеченская, Грозный	0101000020E6100000B0A9F3A8F8D746400F5F268A90A84540
12385	8	80	\N	28733	60992	\N	43.327940010833899	Чеченская Республика, муниципальное образование город Грозный, Гурьевская, 11, Гимназия №2	Россия, республика Чеченская, Грозный	0101000020E61000000C8FFD2C96D846406E861BF0F9A94540
12384	8	80	\N	28733	60992	\N	43.316158932189602	Чеченская Республика, муниципальное образование город Грозный, Гурьевская, 11	Россия, республика Чеченская, Грозный	0101000020E6100000B0A9F3A8F8D7464004ABEAE577A84540
12394	8	80	\N	28733	61095	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Грибоедова, 88		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12441	8	80	\N	28733	61031	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Галкина, 139		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12107	8	80	\N	28733	61079	\N	43.278977326888203	Чеченская Республика, Грозненский муниципальный район, Первомайское сельское поселение, Ворошилова, 3	Россия, республика Чеченская, Грозный	0101000020E6100000D7851F9C4FDB464008ABB184B5A34540
12387	8	80	\N	28733	61090	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Воронежская, 140		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12083	8	80	\N	28733	61160	\N	43.286505369323102	Чеченская Республика, Грозненский муниципальный район, Центора-Юртовское сельское поселение, Возрождения, 35	Россия, республика Чеченская, Грозный	0101000020E6100000E882FA9639D34640FB912232ACA44540
12386	8	80	\N	28733	61016	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Верхоянская, 6		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12430	8	80	\N	28733	61029	\N	43.328441282293703	Чеченская Республика, муниципальное образование город Грозный, Буровиков, 13	Россия, республика Чеченская, Грозный	0101000020E6100000D2C3D0EAE4D8464030D5CC5A0AAA4540
12427	8	80	\N	28733	75576	\N	43.312050753486197	Октябрьский район, ул. Батумская, 47, СОШ № 91	Россия, республика Чеченская, Грозный	0101000020E6100000C3F0113125DC464090D78349F1A74540
12428	8	80	\N	28733	61108	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, пос.Воровского, Баррикадная, 1		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12421	8	80	\N	28733	61056	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Алексеева, 160		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12396	8	80	\N	28733	60993	\N	43.328441282293703	Чеченская Республика, муниципальное образование город Грозный, Агрономическая, 74		0101000020E6100000AE7FD767CED8464030D5CC5A0AAA4540
12397	8	80	\N	28733	61094	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, Абухова, 2		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12405	8	80	\N	28733	61275	\N	43.339718788693403	Чеченская Республика, муниципальное образование город Грозный, ул. А. Айдамирова, 133, ГКОУ Президентский лицей	Россия, республика Чеченская, Грозный	0101000020E6100000D717096D39D74640386A85E97BAB4540
12425	8	80	\N	28733	61026	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, 8-Марта, 35		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12433	8	80	\N	28733	61061	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, 56-участок, СШ №9		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12432	8	80	\N	28733	61060	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, 20-й участок, СШ №29		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12431	8	80	\N	28733	61098	\N	43.331829999999997	Чеченская Республика, муниципальное образование город Грозный, 12-участок, ПУ №4		0101000020E6100000122F4FE78AD2464074EACA6779AA4540
12266	8	80	\N	60679	75551	\N	43.247467	ст.Ассиновская, СШ №2, ул. Ц\\усадьба г\\з «Ассинский»	Россия, республика Чеченская, Грозненский район	0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12012	8	80	\N	32988	61073	\N	43.285187999999998	Чеченская Республика, муниципальное образование город Аргун, пер. Свободы, 1		0101000020E61000009AEC9FA701F14640179B560A81A44540
12014	8	80	\N	32988	61213	\N	43.285187999999998	Чеченская Республика, муниципальное образование город Аргун, Шоссейная, 59	Россия, республика Чеченская, Аргун	0101000020E61000009AEC9FA701F14640179B560A81A44540
12008	8	80	\N	32988	61213	\N	43.285187999999998	Чеченская Республика, муниципальное образование город Аргун, Шоссейная, 59, СОШ №1		0101000020E61000009AEC9FA701F14640179B560A81A44540
12009	8	80	\N	32988	61034	\N	43.285187999999998	Чеченская Республика, муниципальное образование город Аргун, Титова, 2а		0101000020E61000009AEC9FA701F14640179B560A81A44540
12011	8	80	\N	32988	60963	\N	43.296034253297101	Чеченская Республика, муниципальное образование город Аргун, Ленина, 133	Россия, республика Чеченская, Аргун городской округ	0101000020E6100000CE39782634F1464085402E71E4A54540
12013	8	80	\N	32988	61200	\N	43.285187999999998	Чеченская Республика, муниципальное образование город Аргун, Кутузова, 6		0101000020E61000009AEC9FA701F14640179B560A81A44540
12015	8	80	\N	32988	61013	\N	43.285187999999998	Чеченская Республика, муниципальное образование город Аргун, А.Х. Кадырова, СОШ №3		0101000020E61000009AEC9FA701F14640179B560A81A44540
12010	8	80	\N	32988	61013	\N	43.285187999999998	Чеченская Республика, муниципальное образование город Аргун, А.Х. Кадырова, СОШ№3		0101000020E61000009AEC9FA701F14640179B560A81A44540
12379	8	80	972	57745	61001	\N	43.514337636329799	Чеченская Республика, Шелковской муниципальный район, Червленское сельское поселение, Школьная, 35	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E6100000069E7B0F972C4740878BDCD3D5C14540
12376	8	80	972	57745	61001	\N	43.515087214237099	Чеченская Республика, Шелковской муниципальный район, Каршыга-Аульское сельское поселение, Школьная, 4	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E6100000069E7B0F972C474021CCED5EEEC14540
12361	8	80	972	57745	61001	\N	43.5039675132792	Чеченская Республика, Шелковской муниципальный район, Сары-Суйское сельское поселение, Школьная, 1	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E610000056F0DB10E32B4740821DFF0582C04540
12369	8	80	972	57745	61214	\N	43.507091233149502	Чеченская Республика, Шелковской муниципальный район, Шелковское сельское поселение, Ткачева, 11	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E6100000CB2C42B1152C4740488C9E5BE8C04540
12360	8	80	972	57745	61221	\N	43.514587496674103	Чеченская Республика, Шелковской муниципальный район, Каргалинское сельское поселение, Советской, 19		0101000020E610000000FE2955A22C47402FF99FFCDDC14540
12368	8	80	972	57745	61028	\N	43.513837912515797	Чеченская Республика, Шелковской муниципальный район, Шелковское сельское поселение, Советская, 3	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E6100000A41820D1042C474095B88E71C5C14540
12365	8	80	972	57745	61028	\N	43.506091660502001	Чеченская Республика, Шелковской муниципальный район, Гребенское сельское поселение, Советская, 62	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E6100000DB1324B6BB2B47403562669FC7C04540
12357	8	80	972	57745	61313	\N	43.514587496674103	Чеченская Республика, Шелковской муниципальный район, Бороздиновское сельское поселение, Орджоникидзе, 62	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E610000016855D143D2C47402FF99FFCDDC14540
12366	8	80	972	57745	61032	\N	43.512588584748499	Чеченская Республика, Шелковской муниципальный район, Гребенское сельское поселение, Октябрская, 9	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E610000040C39B35782B474009A52F849CC14540
12367	8	80	972	57745	61054	\N	43.513514968664303	Чеченская Республика, Шелковской муниципальный район, Шелковское сельское поселение, Озерная, 3	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E61000009A42E735762B4740B28009DCBAC14540
12380	8	80	972	57745	61460	\N	43.514837355976503	Чеченская Республика, Шелковской муниципальный район, Ораз-Аульское сельское поселение, ул. Мира, 4, ООШ	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E6100000B5FF01D6AA2B4740A8E2C62DE6C14540
12377	8	80	972	57745	61268	\N	43.515343537473598	Чеченская Республика, Шелковской муниципальный район, Червленно-Узловское сельское поселение, Ленина, 5	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E61000004F745DF8C12B47404C18CDCAF6C14540
12370	8	80	972	57745	61058	\N	43.515836782767998	Чеченская Республика, Шелковской муниципальный район, Шелкозаводское сельское поселение, Маркелова, 14	Россия, республика Чеченская, Шелковской район, село Шелковская	0101000020E610000016855D143D2C47408B8862F206C24540
38908	8	78	\N	188	61529	\N	44.2183827385903	Карачаево-Черкесская Республика, город Черкесск, Ленина, 66		0101000020E6100000BE175FB4C70545404E8061F9F31B4640
12371	8	80	972	32589	61203	\N	43.476140000000001	Чеченская Республика, Шелковской муниципальный район, Харьковское сельское поселение, Советская, 5		0101000020E6100000CBF5B6990A2B4740A228D027F2BC4540
12374	8	80	972	57754	61092	\N	43.464672719942598	ст. Старо-Щедринская, ул. Советская, 52, Администрация	Россия, республика Чеченская, Шелковской район, село Старощедринская	0101000020E610000080608E1EBF0D4740C72AA5677ABB4540
12363	8	80	972	57806	61339	\N	43.637565071194302	Чеченская Республика, Шелковской муниципальный район, ст. Старогладовская, ул. Советская,15, СДК	Россия, республика Чеченская, Шелковской район, село Старогладковская	0101000020E6100000CB660E492D3647408109DCBA9BD14540
12378	8	80	972	8126	61010	\N	43.905465999999997	Чеченская Республика, Шелковской муниципальный район, Червленское сельское поселение, Ленина, 62		0101000020E61000004278B471C4064740E9D1544FE6F34540
12373	8	80	972	8126	61010	\N	43.905465999999997	Чеченская Республика, Шелковской муниципальный район, Ново-Щедринское сельское поселение, Ленина, 52		0101000020E61000004278B471C4064740E9D1544FE6F34540
12359	8	80	972	8126	61010	\N	43.905465999999997	Чеченская Республика, Шелковской муниципальный район, Каргалинское сельское поселение, Ленина, 45		0101000020E61000004278B471C4064740E9D1544FE6F34540
12291	8	80	972	8126	61153	\N	43.905465999999997	Чеченская Республика, Урус-Мартановский муниципальный район, Гойтинское сельское поселение, Ленина, 35		0101000020E61000004278B471C4064740E9D1544FE6F34540
12372	8	80	972	32597	61234	\N	43.509665129198702	Чеченская Республика, Шелковской муниципальный район, Кобинское сельское поселение, Хетагурова, 81	Россия, республика Чеченская, Шелковской район, село Коби	0101000020E610000096E99788B71E47403A75E5B33CC14540
12358	8	80	972	24966	61164	\N	43.791794000000003	Чеченская Республика, Шелковской муниципальный район, ст. Дубовская, ул. Дружбы, 11-а, НШ		0101000020E61000008410902FA1464740A3957B8159E54540
12364	8	80	972	32548	61233	\N	43.554402000000003	Чеченская Республика, Шелковской муниципальный район, Воскресеновское сельское поселение, Комарова, 14		0101000020E61000004529215855314740236B0DA5F6C64540
12381	8	80	972	57766	61154	\N	43.860483343408703	с. Бурунская, ул. Школьная, 1, СОШ	Россия, республика Чеченская, Шелковской район, село Бурунское	0101000020E610000058E36C3A02E44640CAE1934E24EE4540
12343	8	80	1728	24245	61171	\N	42.851387000000003	Чеченская Республика, Шатойский муниципальный район, с. Юкерч-Келой, ул. Шатойская б/н, в частный дом Дундулова И.Я.		0101000020E6100000325A475513DE4640AA9ECC3FFA6C4540
12329	8	80	1728	57821	61408	\N	42.6245110696157	с. Шикарой, ул. Школьная, 2,   Администрация	Россия, республика Чеченская, Шатойский район, разруш.,полуразруш.нас.пункты Шикарой	0101000020E61000008FFCC1C073E14640027FF8F9EF4F4540
12345	8	80	1728	23937	61302	\N	42.876333238530599	Чеченская Республика, Шатойский муниципальный район, Нихалойское сельское поселение, Эштиева, 29	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E6100000AA436E861BD84640EAB303AE2B704540
12346	8	80	1728	23937	61262	\N	42.873110992861598	Чеченская Республика, Шатойский муниципальный район, Асланбек-Шериповское сельское поселение, Школьная, 4	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E6100000205ED72FD8D746409163EB19C26F4540
12341	8	80	1728	23937	61262	\N	42.869957136274301	Чеченская Республика, Шатойский муниципальный район, с. Вярды, ул. Школьная 5, СОШ	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E6100000419AB1683AD9464090F63FC05A6F4540
12351	8	80	1728	23937	61320	\N	42.876577729706597	Чеченская Республика, Шатойский муниципальный район, Больше-Варандинское сельское поселение, Центральная, 48	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E6100000A60BB1FA23D84640513239B533704540
12348	8	80	1728	23937	61314	\N	42.872495228000801	Чеченская Республика, Шатойский муниципальный район, Хал-Келойское сельское поселение, Халида Асуева, 10	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E61000009B00C3F2E7D74640367689EAAD6F4540
12337	8	80	1728	23937	61037	\N	42.875777999999997	с. Шатой, ул. Советская, 22, СОШ		0101000020E61000004BAE62F19BD846403447567E19704540
12354	8	80	1728	23937	61305	\N	42.877280127823497	Чеченская Республика, Шатойский муниципальный район, Нохчи-Келойское сельское поселение, Подгорная, 8	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E6100000A5A31CCC26D84640AAB706B64A704540
12355	8	80	1728	23937	61282	\N	42.8705884631214	Чеченская Республика, Шатойский муниципальный район, Вашендаройское сельское поселение, Лесная, 55	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E61000007995B54DF1D846402025766D6F6F4540
12339	8	80	1728	23937	61282	\N	42.8760176055142	Чеченская Республика, Шатойский муниципальный район, Вашендаройское сельское поселение, Лесная, 57	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E6100000815F234910D846408A5A9A5B21704540
12349	8	80	1728	23937	61300	\N	42.877785129462403	Чеченская Республика, Шатойский муниципальный район, Зонинское сельское поселение, Ленина, Здании ОСШ	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E6100000D15790662CD84640AEF545425B704540
12353	8	80	1728	23937	61315	\N	42.869199535472099	Чеченская Республика, Шатойский муниципальный район, Шаро-Аргунское сельское поселение, Заречная, 55	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E61000005281936DE0D8464073D712F2416F4540
63305	3	31	44	2508	58109	\N	58.418863000000002	д.Починная Сопка, Советская, 67		0101000020E610000083161230BA3041409240834D9D354D40
12352	8	80	1728	23937	61317	\N	42.873239964854001	Чеченская Республика, Шатойский муниципальный район, Дайское сельское поселение, С,Ахмадова, 60	Россия, республика Чеченская, Шатойский район, село Шатой	0101000020E61000000C23BDA8DDD746408FC70C54C66F4540
12328	8	80	1728	23536	61217	\N	42.629930999999999	с. Шарой, ул. Кадырова, 6, ФАП		0101000020E61000007A7077D66EE7464048DE3994A1504540
12325	8	80	1728	23536	61312	\N	42.6306681746265	Чеченская Республика, Шаройский муниципальный район, Химойское сельское поселение, А-Кадырова, 16	Россия, республика Чеченская, Шатойский район, поселок Шарой	0101000020E6100000965CC5E237E746401E51A1BAB9504540
12330	8	80	1728	23628	61226	\N	42.554834999999997	с. Хуландой, ул. Эрзи-Ара, 3,  администрации		0101000020E61000002E3883BF5FE046408CD651D504474540
12327	8	80	1728	23477	61267	\N	42.624119999999998	с. Хакмадой, ул. Центральная, 19, Администрация	Россия, республика Чеченская, Шатойский район, поселок Хакмадой	0101000020E6100000A91611C5E4E94640C763062AE34F4540
12342	8	80	1728	57803	61333	\N	42.843939705842097	Чеченская Республика, Шатойский муниципальный район, с. Урд-Юхой, ул. Школьная, 12, ООШ	Россия, республика Чеченская, Шатойский район, село Урдюхой	0101000020E61000006E5166834CDA4640A4E4D539066C4540
12350	8	80	1728	60633	75486	\N	42.987626950331297	Чеченская Республика, Шатойский муниципальный район, Улус-Кертское сельское поселение, Ленина, 23	Россия, республика Чеченская, Шатойский район, село Улус-Керт	0101000020E6100000C7B94DB857E24640C4D2C08F6A7E4540
12340	8	80	1728	24097	61156	\N	42.854705000000003	с. Памятой (с. Бекум-Кали), ул. Центральная, б/н СОШ		0101000020E6100000D7C1C1DEC4D84640255D33F9666D4540
12347	8	80	1728	24448	61129	\N	42.833849000000001	с. Мусолт-Аул, ул. А. Агаевой, 4, НСШ		0101000020E6100000BD378600E0E24640B2666490BB6A4540
12331	8	80	1728	23674	61205	\N	42.674450999999998	с. Кири, ул. Мира,8, Администрация		0101000020E6100000C7F143A511F5464093E00D6954564540
12333	8	80	1728	23753	61189	\N	42.640590000000003	с. Кенхи, ул. Школьная 1, СОШ №-1		0101000020E610000033A7CB6262F94640841266DAFE514540
12335	8	80	1728	23753	61277	\N	42.640590000000003	с. Кенхи, ул. Подгорная, 104, СОШ №-3	Россия, республика Чеченская, Шатойский район, село Кенхи	0101000020E610000033A7CB6262F94640841266DAFE514540
12334	8	80	1728	23753	61434	\N	42.640590000000003	с. Кенхи, ул. А-Х. Кадырова, 5, Администрация	Россия, республика Чеченская, Шатойский район, село Кенхи	0101000020E610000033A7CB6262F94640841266DAFE514540
12332	8	80	1728	57772	61175	\N	42.660975700489097	с. Бути, ул. Мира, 16, Администрация	Россия, республика Чеченская, Шатойский район, село Бутти	0101000020E6100000C0ED0912DBFD46406FB88FDC9A544540
12344	8	80	1728	24881	61199	\N	42.841667020900601	Чеченская Республика, Шатойский муниципальный район, Борзойское сельское поселение, В. Мучарова, 37	Россия, республика Чеченская, Шатойский район, село Борзой	0101000020E61000003DD2E0B6B6D04640AC8F87BEBB6B4540
12326	8	80	7450	57795	61552	\N	42.630224520117999	Чеченская Республика, Шаройский муниципальный район, Цесинское сельское поселение, Мира, 3	Россия, республика Чеченская, Шатойский район, поселок Шарой	0101000020E61000005A29047289E74640910F7A36AB504540
12323	8	80	1161	23331	\N	\N	43.141261367971801	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, пос. Кавказ СОШ №10	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000855CA96741F44640A29927D714924540
12316	8	80	1161	23331	61005	\N	43.138495781553502	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, Школьная СОШ №1	Россия, республика Чеченская, Шалинский район, Шали	0101000020E610000029779FE3A3F346403C50A73CBA914540
12315	8	80	1161	23331	61005	\N	43.141512778671597	Чеченская Республика, Шалинский муниципальный район, Чири-Юртовское сельское поселение, Школьная, СОШ №1	Россия, республика Чеченская, Шалинский район, Шали	0101000020E61000006B662D05A4F14640BC7A15191D924540
12312	8	80	1161	23331	61005	\N	43.144026828402197	Чеченская Республика, Шалинский муниципальный район, Ново-Атагинское сельское поселение, Школьная, №1 СОШ		0101000020E6100000A80183A44FF14640D95E0B7A6F924540
12308	8	80	1161	23331	61005	\N	43.140507129625099	Чеченская Республика, Шалинский муниципальный район, Дуба-Юртовское сельское поселение, Школьная, СОШ	Россия, республика Чеченская, Шалинский район, Шали	0101000020E610000094A46B26DFF04640F6ED2422FC914540
12321	8	80	1161	23331	61007	\N	43.1398194191109	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, Учительская СОШ №1	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000ECDB4944F8F34640022EC896E5914540
12307	8	80	1161	23331	61148	\N	43.140007981712202	Чеченская Республика, Шалинский муниципальный район, Герменчукское сельское поселение, Терская, 33	Россия, республика Чеченская, Шалинский район, Шали	0101000020E61000003DD4B66114F44640D5963AC8EB914540
12306	8	80	1161	23331	61148	\N	43.1485518555277	Чеченская Республика, Шалинский муниципальный район, Герменчукское сельское поселение, Терская, 33, СОШ №2	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000F1D58EE21CF34640B1E07EC003934540
12317	8	80	1161	23331	61084	\N	43.148300473982303	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, Речная СОШ №3	Россия, республика Чеченская, Шалинский район, Шали	0101000020E610000004E78C28EDF1464097FF907EFB924540
12322	8	80	1161	23331	61008	\N	43.145786601260603	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, Моздокская, СОШ №9	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000F629C76471F146404A97FE25A9924540
12303	8	80	1161	23331	61055	\N	43.142267004523603	Чеченская Республика, Шалинский муниципальный район, Автуринское сельское поселение, Ленина, СОШ №3	Россия, республика Чеченская, Шалинский район, Шали	0101000020E61000007E1D386744F14640672618CE35924540
12302	8	80	1161	23331	61055	\N	43.142616002670202	Чеченская Республика, Шалинский муниципальный район, Автуринское сельское поселение, Ленина, СОШ №2	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000255987A3ABF4464073F1B73D41924540
12301	8	80	1161	23331	61055	\N	43.1387472037067	Чеченская Республика, Шалинский муниципальный район, Автуринское сельское поселение, Ленина, СОШ №1	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000B98E71C5C5F1464085B53176C2914540
12305	8	80	1161	23331	61030	\N	43.149054615494698	Чеченская Республика, Шалинский муниципальный район, Белгатойское сельское поселение, Кирова, СОШ	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000D2E5CDE15AF146401327F73B14934540
12320	8	80	1161	23331	60990	\N	43.142518411058496	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, Кадырова, СОШ №6	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000373465A71FF44640B18BA2073E924540
12319	8	80	1161	23331	60990	\N	43.148803236031803	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, Кадырова №120	Россия, республика Чеченская, Шалинский район, Шали	0101000020E610000044520B2593F14640FA4509FA0B934540
12318	8	80	1161	23331	61065	\N	43.146540774010099	Чеченская Республика, Шалинский муниципальный район, Шалинское городское поселение, Баумана, СОШ №4	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000BB5E9A22C0F14640F64201DBC1924540
12314	8	80	1161	23331	61000	\N	43.1334671198344	Чеченская Республика, Шалинский муниципальный район, Сержень-Юртовское сельское поселение, А-Х.Кадырова, здание гимназии	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000395E81E849F34640310C587215914540
12313	8	80	1161	23331	61000	\N	43.138914798075803	Чеченская Республика, Шалинский муниципальный район, Сержень-Юртовское сельское поселение, А-Х.Кадырова, СОШ	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000C5C72764E7F3464040F67AF7C7914540
12310	8	80	1161	23331	61062	\N	43.141135662231498	Чеченская Республика, Шалинский муниципальный район, Мескер-Юртовское сельское поселение, А-Х. Кадырова, ООШ	Россия, республика Чеченская, Шалинский район, Шали	0101000020E61000005709168733F14640E62494BE10924540
12309	8	80	1161	23331	61062	\N	43.148049091395698	Чеченская Республика, Шалинский муниципальный район, Мескер-Юртовское сельское поселение, А-Х. Кадырова, СОШ	Россия, республика Чеченская, Шалинский район, Шали	0101000020E6100000CC457C2766F146404E9A0645F3924540
12304	8	80	1161	23331	61062	\N	43.1402557147604	Чеченская Республика, Шалинский муниципальный район, Агиштинское сельское поселение, А-Х. Кадырова,31, СДК	Россия, республика Чеченская, Шалинский район, Шали	0101000020E61000004DBB9866BAF34640AD889AE8F3914540
12180	8	80	1161	60634	75495	\N	43.245223288874101	Чеченская Республика, Курчалоевский муниципальный район, Цоци-Юртовское сельское поселение,  Гагарина, СОШ №2	Россия, республика Чеченская, Шалинский район, село Цоцкин-Юрт	0101000020E61000000A302C7FBEFF46400F9D9E77639F4540
12181	8	80	1161	60634	75490	\N	43.238821000000002	Чеченская Республика, Курчалоевский муниципальный район, Цоци-Юртовское сельское поселение, А-Х. Кадырова, СОШ №3	Россия, республика Чеченская, Шалинский район, село Цоцкин-Юрт	0101000020E6100000BC404981050047408C4CC0AF919E4540
12171	8	80	1161	57770	61170	\N	43.220105099492201	Чеченская Республика, Курчалоевский муниципальный район, Центаройское сельское поселение, Сакказова, 25	Россия, республика Чеченская, Шалинский район, село Центора-Юрт	0101000020E610000090C18A53AD1F4740D15790662C9C4540
12071	8	80	1161	10997	60980	\N	43.262103000000003	Чеченская Республика, Грозненский муниципальный район, Кень-Юртовское сельское поселение, Южная, Здание администрации		0101000020E610000002F4FBFECDEB46407D9752978CA14540
12168	8	80	1161	10997	61111	\N	43.262103000000003	Чеченская Республика, Курчалоевский муниципальный район, Курчалойское сельское поселение, Южная, 6		0101000020E610000002F4FBFECDEB46407D9752978CA14540
12311	8	80	1161	60636	75493	\N	43.133533295601801	Чеченская Республика, Шалинский муниципальный район, Ново-Атагинское сельское поселение, А-К. Кадырова, 176, СОШ №1	Россия, республика Чеченская, Шалинский район, село Новые Атаги	0101000020E6100000B30C71AC8BE34640E8F7FD9B17914540
12189	8	80	1161	16602	\N	\N	43.115634	с. Ники-Хита, СОШ		0101000020E610000000AC8E1CE908474020274C18CD8E4540
12182	8	80	1161	57747	61082	\N	43.203544011382697	Чеченская Республика, Курчалоевский муниципальный район, Джугуртинское сельское поселение, Школьная, СДК	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E610000057056A31780A474005A6D3BA0D9A4540
12166	8	80	1161	57747	61082	\N	43.202602179825398	Чеченская Республика, Курчалоевский муниципальный район, Курчалойское сельское поселение, Школьная, 1	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000F2ED5D83BE0A4740560DC2DCEE994540
12040	8	80	1069	9453	61122	\N	43.311033000000002	Чеченская Республика, Веденский муниципальный район, Веденское сельское поселение, с.Октябрьское, Береговая, 15		0101000020E61000001D007157AFC84640077DE9EDCFA74540
12185	8	80	1161	57747	61128	\N	43.2075495751373	Чеченская Республика, Курчалоевский муниципальный район, Ялхой-Мохкское сельское поселение, Шидиева, 1	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000CD74AF93FA0A4740742497FF909A4540
12186	8	80	1161	57747	61310	\N	43.208286548432	Чеченская Республика, Курчалоевский муниципальный район, Ялхой-Мохкское сельское поселение с.Бельты, Центральная, 19	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000B11A4B581B0B47404A97FE25A99A4540
12170	8	80	1161	57747	61138	\N	43.208302980013798	Чеченская Республика, Курчалоевский муниципальный район, Аллеройское сельское поселение, Майская, 47	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000F758FAD0050B4740505436ACA99A4540
12167	8	80	1161	57747	61442	\N	43.200864914208303	Чеченская Республика, Курчалоевский муниципальный район, Курчалойское сельское поселение, М.Шотаева, 1	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E61000002D211FF46C0A47409DF4BEF1B5994540
12187	8	80	1161	57747	61331	\N	43.201647579356496	Чеченская Республика, Курчалоевский муниципальный район, Регитинское сельское поселение, Восточная, 11	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000CCB22781CD0B4740E3A6069ACF994540
12174	8	80	1161	57747	61176	\N	43.200894091693499	Чеченская Республика, Курчалоевский муниципальный район, Бачи-Юртовское сельское поселение, А-Х.Кадырова, 85	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000E3FBE252950A474037FB03E5B6994540
12179	8	80	1161	57747	61048	\N	43.199651012786099	Чеченская Республика, Курчалоевский муниципальный район, Цоци-Юртовское сельское поселение, А-Х.Кадырова, СОШ №1		0101000020E6100000015130630A0C47408ECEF9298E994540
12173	8	80	1161	57747	61038	\N	43.2006556815358	Чеченская Республика, Курчалоевский муниципальный район, Бачи-Юртовское сельское поселение, А.Р.Кадырова, СОШ №3	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000043DD4B6610A474083DF8618AF994540
12178	8	80	1161	57747	61179	\N	43.199588220435999	Чеченская Республика, Курчалоевский муниципальный район, Гелдаганское сельское поселение, А.Кадырова, 27	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E610000087DC0C37E00B474047567E198C994540
12184	8	80	1161	57747	61035	\N	43.2027777932785	Чеченская Республика, Курчалоевский муниципальный район, Ахкинчу-Барзойское сельское поселение, А-Х.Кадырова, 5	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000DFA7AAD0400C4740952C27A1F4994540
12176	8	80	1161	57747	61035	\N	43.202664969051497	Чеченская Республика, Курчалоевский муниципальный район, Майртупское сельское поселение, З.А.Кадырова, 17	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E610000004E3E0D2310B47409D853DEDF0994540
12175	8	80	1161	57747	61193	\N	43.200969637103299	Чеченская Республика, Курчалоевский муниципальный район, Майртупское сельское поселение, А.Кадырова, 64	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000D8D47954FC0B474012BD8C62B9994540
12298	8	80	1644	57757	61112	\N	43.090989999999998	Чеченская Республика, Урус-Мартановский муниципальный район, Шалажинское сельское поселение, Л.Д.Магомадова, 63	Россия, республика Чеченская, Урус-Мартановский район, село Шалажи	0101000020E6100000C1ADBB79AAAD4640AB21718FA58B4540
12297	8	80	1644	22260	61244	\N	43.1155834132189	Чеченская Республика, Урус-Мартановский муниципальный район, Танги-Чуйское сельское поселение, пер.Школьный, СОШ	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000000987DEE2E1C546409E7C7A6CCB8E4540
12274	8	80	1644	22260	61046	\N	43.139430997948402	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Эльсанукаева, 1	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000ADA1D45E44C54640388600E0D8914540
12289	8	80	1644	22260	61047	\N	43.1429507591196	Чеченская Республика, Урус-Мартановский муниципальный район, Гехи-Чуйское сельское поселение, Школьная, 8а	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000895DDBDB2DC546401AF7E6374C924540
12277	8	80	1644	22260	61240	\N	43.123841031096902	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Степная, 3, ЦЗН	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E610000081936DE00EC64640B4739A05DA8F4540
12299	8	80	1644	22260	61049	\N	43.112271695177	Чеченская Республика, Урус-Мартановский муниципальный район, Шалажинское сельское поселение, Сайдаева, 45	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000005D4F745DF8C54640D520CCED5E8E4540
12295	8	80	1644	22260	61206	\N	43.113026284240597	Чеченская Республика, Урус-Мартановский муниципальный район, Мартан-Чуйское сельское поселение, Сааева, 2	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000F3FFAA2347C6464081CCCEA2778E4540
12283	8	80	1644	22260	61167	\N	43.107240861951702	Чеченская Республика, Урус-Мартановский муниципальный район, Алхан-Юртовское сельское поселение, Пролетарская, 42	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E610000081936DE00EC646402AE5B512BA8D4540
12286	8	80	1644	22260	61114	\N	43.110758804306798	Чеченская Республика, Урус-Мартановский муниципальный район, Гехинское сельское поселение, Надречная, 11	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E610000015C78157CBC546406C5ED5592D8E4540
12273	8	80	1644	22260	61044	\N	43.138425314415599	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Маяковского, 10	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E610000049F25CDF87C5464072F90FE9B7914540
12280	8	80	1644	22260	61145	\N	43.106985624498101	Чеченская Республика, Урус-Мартановский муниципальный район, Алхазуровское сельское поселение, М-Мерзоева, 1	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000C57421567FC646409F909DB7B18D4540
12278	8	80	1644	22260	61239	\N	43.139933833467502	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Куйбышева, 129	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000ADA1D45E44C546409ACC785BE9914540
12275	8	80	1644	22260	61239	\N	43.114786955614797	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Куйбышева, 216, СОШ № 4	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000D7851F9C4FC54640C3802557B18E4540
12279	8	80	1644	22260	60985	\N	43.139430997948402	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Кирова, 82	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000D2E5CDE15AC54640388600E0D8914540
12276	8	80	1644	22260	60986	\N	43.121326145483302	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Калинина, 2а	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000005D4F745DF8C54640C713419C878F4540
12272	8	80	1644	22260	60984	\N	43.125475650912001	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Каланчакская, 76	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000009AEAC9FCA3C546406937FA980F904540
12271	8	80	1644	22260	60984	\N	43.141945133895099	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, Каланчакская, 40	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000006D3656629EC54640556AF6402B924540
12294	8	80	1644	22260	61089	\N	43.141442315035498	Чеченская Республика, Урус-Мартановский муниципальный район, Гой-Чуйское сельское поселение, Кадырова, 39	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000002A029CDEC5C34640F2237EC51A924540
12287	8	80	1644	22260	61089	\N	43.109756330622503	Чеченская Республика, Урус-Мартановский муниципальный район, Гехинское сельское поселение, Кадырова, СОШ №2		0101000020E610000071AC8BDB68C6464017450F7C0C8E4540
12288	8	80	1644	22260	61142	\N	43.112268010637102	Чеченская Республика, Урус-Мартановский муниципальный район, Гехинское сельское поселение, Кавказская, 120	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000009B90D61874C6464094313ECC5E8E4540
12290	8	80	1644	22260	61105	\N	43.126355812591598	Чеченская Республика, Урус-Мартановский муниципальный район, Гойтинское сельское поселение, Дадарова, 243	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000D2E5CDE15AC54640A2D3F36E2C904540
12296	8	80	1644	22260	61196	\N	43.113780863933698	Чеченская Республика, Урус-Мартановский муниципальный район, Рошни-Чуйское сельское поселение, Героев В.В, 54-А	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000006D3656629EC54640FEF33460908E4540
12292	8	80	1644	22260	61143	\N	43.140688078937004	Чеченская Республика, Урус-Мартановский муниципальный район, Гойтинское сельское поселение, Ганчарова, 79	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000D2E5CDE15AC5464046787B1002924540
12282	8	80	1644	22260	61045	\N	43.127361696036097	Чеченская Республика, Урус-Мартановский муниципальный район, Алхан-Юртовское сельское поселение, Вахитова, 54	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E6100000EA961DE21FC446406760E4654D904540
12270	8	80	1644	22260	60982	\N	43.126607285014501	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, 1-я  А.Шерипова, 47	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E610000049F25CDF87C54640EB387EA834904540
12269	8	80	1644	22260	60982	\N	43.125349912487998	Чеченская Республика, Урус-Мартановский муниципальный район, Урус-Мартановское городское поселение, 1-я А.Шерипова, 27	Россия, республика Чеченская, Урус-Мартановский район, Урус-Мартан	0101000020E61000003D5FB35C36C44640DC4603780B904540
12293	8	80	1644	57760	61124	\N	43.0918893340843	Чеченская Республика, Урус-Мартановский муниципальный район, Гойское сельское поселение, М.Дадаева, 59	Россия, республика Чеченская, Урус-Мартановский район, село Гойское	0101000020E61000006A300DC347CC46405BEECC04C38B4540
35032	8	76	767	5401	60954	\N	43.50835	Республика Ингушетия, город Малгобек, Пушкина 27, Средняя школа №11		0101000020E610000096D05D12674B4640F775E09C11C14540
12285	8	80	1644	57835	61499	\N	43.164002211195701	Чеченская Республика, Урус-Мартановский муниципальный район, Гехинское сельское поселение,Эльдарханова, 11, ГУП «госхоз Гехинский»	Россия, республика Чеченская, Урус-Мартановский район, село Гехи	0101000020E61000006A300DC347BC4640433D7D04FE944540
12284	8	80	1644	32698	61232	\N	43.230384999999998	Чеченская Республика, Урус-Мартановский муниципальный район, Алхан-Юртовское сельское поселение, Х.Нурадилова, 53		0101000020E61000001155F833BCC74640963E74417D9D4540
12281	8	80	1644	60645	75501	\N	43.062679308957897	Чеченская Республика, Урус-Мартановский муниципальный район, Алхазуровское сельское поселение, А. Кадырова, СОШ № 2	Россия, республика Чеченская, Урус-Мартановский район, село Алхазурово	0101000020E61000009ED32CD0EED24640B0928FDD05884540
12190	8	80	1303	16625	\N	\N	43.074317999999998	с. Эникали, СОШ		0101000020E6100000290989B48D13474087C0914083894540
12256	8	80	1303	57812	61350	\N	43.114857000000001	с. Шовхал-Берды, МОУ «СОШ с. Шовхал-Берды», ул. Молодежная, д. №16	Россия, республика Чеченская, Ножай-Юртовский район, село Шовхол-Берди	0101000020E6100000522976340E294740BC5B59A2B38E4540
12233	8	80	1303	18796	61107	\N	43.081259000000003	Чеченская Республика, Ножай-Юртовский муниципальный район, Ножай-Юртовское сельское поселение, с.Чурч-Ирзу, Школьная, №3		0101000020E61000006FF25B74B2324740BAC0E5B1668A4540
12245	8	80	1303	40437	61229	\N	43.007371999999997	с. Центарой, МОУ «НОШ с. Центарой», ул. А. Митаева, д. №3		0101000020E61000004B06802A6E1C4740FB73D190F1804540
12254	8	80	1303	60658	75517	\N	43.049596999999999	с. Хочи-Ара, МОУ «ООШ с. Хочи-Ара»,ул. Речная, д. №8	Россия, республика Чеченская, Ножай-Юртовский район, село Хочч-Ара	0101000020E6100000F44D9A0645294740677DCA3159864540
12191	8	80	1303	16709	\N	\N	43.113442999999997	с. Хиди-Хутор, СОШ		0101000020E6100000919A7631CD124740E57ADB4C858E4540
12250	8	80	1303	60660	75519	\N	43.091002000000003	с. Турты-Хутор,  МОУ «СОШ с. Турты-Хутор», ул. Кункуева, д. №18	Россия, республика Чеченская, Ножай-Юртовский район, село Турни-Хутор	0101000020E610000089EAAD81AD22474070EF1AF4A58B4540
12238	8	80	1303	57796	61321	\N	43.022019999999998	Чеченская Республика, Ножай-Юртовский муниципальный район, с. Татай-Хутор, ул. А.А. Кадырова, 48, СОШ		0101000020E61000000936AE7FD7254740D0ED258DD1824540
12251	8	80	1303	40443	61246	\N	43.061191999999998	с. Саясан, МОУ «СОШ с. Саясан», ул. А.А. Кадырова, д. №10		0101000020E61000003FA9F6E9782447406F63B323D5874540
12253	8	80	1303	40445	61163	\N	43.075991000000002	с. Рогун-Кажа, МОУ «СОШ с. Рогун-Кажа», ул. А.А. Кадырова, д. №3		0101000020E610000094A5D6FB8D2C47402AE5B512BA894540
12236	8	80	1303	57748	61264	\N	43.0907511559789	Чеченская Республика, Ножай-Юртовский муниципальный район, Байтаркинское сельское поселение, Нурадилова, №15	Россия, республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт	0101000020E6100000A0C211A452304740268A90BA9D8B4540
12235	8	80	1303	57748	61260	\N	43.092386174582899	Чеченская Республика, Ножай-Юртовский муниципальный район, Гилянинское сельское поселение, Кадырова, №26	Россия, республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт	0101000020E6100000096CCEC1332F4740DB4DF04DD38B4540
12241	8	80	1303	57748	61266	\N	43.090436138326702	Чеченская Республика, Ножай-Юртовский муниципальный район, Симсирское сельское поселение, Гези-Хаджи, №7	Россия, республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт	0101000020E61000002B86AB0320304740C6302768938B4540
12232	8	80	1303	57748	61042	\N	43.089492549946897	Чеченская Республика, Ножай-Юртовский муниципальный район, Ножай-Юртовское сельское поселение, А.А.Кадырова, №152	Россия, республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт	0101000020E6100000540262122E304740471CB281748B4540
12053	8	80	1303	57763	61137	\N	43.0850346340698	Чеченская Республика, Веденский муниципальный район, Гунинское сельское поселение, с.Марзой-Мохк, М.Кишиева, 27	Россия, республика Чеченская, Ножай-Юртовский район, село Морзой-Мохк	0101000020E61000008CF50D4C6E0C4740F701486DE28A4540
12258	8	80	1303	40448	61259	\N	43.159343	с. Мескеты, МОУ «СОШ с. Мескеты», ул. А.А. Кадырова, д. № 19	Россия, республика Чеченская, Ножай-Юртовский район, село Мескеты	0101000020E6100000F91400E3192E47405BECF65965944540
12146	8	80	1303	14507	61174	\N	43.073810999999999	с. Шуани, ул. Дружбы, 21, Администрация		0101000020E6100000616F62484E1E4740E38A8BA372894540
12247	8	80	1303	14507	61197	\N	43.073810999999999	с. Шуани, МОУ «ООШ с. Шуани», ул. А.А. Кадырова, д. №2		0101000020E6100000616F62484E1E4740E38A8BA372894540
12234	8	80	1303	60641	75499	\N	43.022019999999998	Чеченская Республика, Ножай-Юртовский муниципальный район, Зандакское сельское поселение, А.А. Кадырова, 57, СОШ №2		0101000020E61000000936AE7FD7254740D0ED258DD1824540
12246	8	80	1303	40438	61204	\N	43.150542999999999	с. Замай-Юрт, МОУ «СОШ с. Замай-Юрт», ул. И. Цабаева, д. №5		0101000020E610000081B053AC1A30474024D236FE44934540
12188	8	80	1303	16542	61147	\N	43.106749000000001	Чеченская Республика, Курчалоевский муниципальный район, Регитинское сельское поселение, с.Джагларги, Центральная, 5		0101000020E6100000D4BB783F6E0D4740BBF083F3A98D4540
12239	8	80	1303	57784	61254	\N	43.010952800970301	с. Даттах, ул. А.А. Кадырова, 36, СОШ	Россия, республика Чеченская, Ножай-Юртовский район, село Даттых	0101000020E61000006CD097DEFE32474084656CE866814540
12130	8	80	1303	13734	61210	\N	43.042119	с.Гордали, ул СШ,.Мамакаева, 18		0101000020E61000009DD9AED0071D474026C5C72764854540
12244	8	80	1303	13734	61183	\N	43.042119	с. Гордали, МОУ «СОШ с. Гордали», ул. А.А. Кадырова, д. № 1		0101000020E61000009DD9AED0071D474026C5C72764854540
12242	8	80	1303	19286	61289	\N	43.023826	с. Гендерген, ул. А.А. Кадырова, 21, СОШ	Россия, республика Чеченская, Ножай-Юртовский район, село Гендерген	0101000020E6100000A0185932C72A4740B265F9BA0C834540
12240	8	80	1303	57756	61110	\N	42.983129697248302	Чеченская Республика, Ножай-Юртовский муниципальный район, Даттахское сельское поселение, с. Булгат-Ирзу, школьная, №1	Россия, республика Чеченская, Ножай-Юртовский район, село Булгат-Изру	0101000020E610000036E50AEF722F4740B6DB2E34D77D4540
12131	8	80	1303	57822	61410	\N	43.058442540574497	с.Бильтой-Юрт, СШ, ул.Школьная 1	Россия, республика Чеченская, Ножай-Юртовский район, село Бильты	0101000020E61000003387A4164A2C47400ED76A0F7B874540
12257	8	80	1303	57814	61355	\N	43.125224000000003	с. Бешил-Ирзу, МОУ «ООШ с. Бешил-Ирзу, ул. Кадырова, д. №24	Россия, республика Чеченская, Ножай-Юртовский район, село Бешил-Ирзой	0101000020E610000061FF756EDA26474050560C5707904540
12259	8	80	1303	40449	61236	\N	43.112515000000002	с. Бетти-Мохк, МОУ «СОШ с. Бетти-Мохк», ул. А.А. Кадырова, д. №6		0101000020E6100000FB90B75CFD2A47409CA73AE4668E4540
12262	8	80	1303	40451	61173	\N	42.953927999999998	с. Беной-Ведено, МОУ «СОШ с. Беной-Ведено», ул. А.А. Кадырова, д.№93		0101000020E61000003E26529ACD2347408D5E0D501A7A4540
12243	8	80	1303	57825	61429	\N	42.9763050941892	с. Беной, МОУ «СОШ с. Беной», ул. А.А. Кадырова, д. № 34	Россия, республика Чеченская, Ножай-Юртовский район, село Беной	0101000020E6100000CC96AC8A70274740EDF5EE8FF77C4540
12261	8	80	1303	20308	61159	\N	43.120175000000003	с. Балансу, ул. А.А. Кадырова, 19, СОШ		0101000020E6100000A2D45E44DB314740FE65F7E4618F4540
12248	8	80	1303	40439	61178	\N	43.088158999999997	с. Аллерой, МОУ «СОШ с. Аллерой», ул. Аллероева, д. №1		0101000020E61000002D95B7239C2647408DEC4ACB488B4540
12255	8	80	1303	40446	61230	\N	43.090108000000001	с. Айти-Мохк, МОУ «СОШ с. Айти-Мохк», ул.  А.А. Кадырова, д. №31		0101000020E610000064E76D6C762C4740D28DB0A8888B4540
12206	8	80	1109	9930	\N	\N	43.942799000000001	Чеченская Республика, Надтеречный муниципальный район, Гвардейское сельское поселение, Центральная усадьба, 1		0101000020E6100000E3E2A8DC44B94640CBD93BA3ADF84540
12200	8	80	1109	9930	61043	\N	43.942799000000001	Чеченская Республика, Надтеречный муниципальный район, Знаменское сельское поселение, Центральная, 23		0101000020E6100000E3E2A8DC44B94640CBD93BA3ADF84540
12215	8	80	1109	32961	61225	\N	43.636631999999999	Чеченская Республика, Наурский муниципальный район, Фрунзенское сельское поселение, Гагарина, 14		0101000020E6100000CB9E0436E7D4464025CB49287DD14540
12221	8	80	1109	57777	61209	\N	43.630561895902702	Чеченская Республика, Наурский муниципальный район, Савельевское сельское поселение, Бектамирова, 1 а	Россия, республика Чеченская, Наурский район, село Савельевская	0101000020E6100000D44334BA83BA4640D80C7041B6D04540
12217	8	80	1109	60650	75508	\N	43.603237310483998	Чеченская Республика, Наурский муниципальный район, Новотерское сельское поселение, . Победы, 4, СДК	Россия, республика Чеченская, Наурский район, село Новотерское	0101000020E61000000B444FCAA4CC46405B5EB9DE36CD4540
12213	8	80	1109	60635	75491	\N	43.762868862706704	Чеченская Республика, Наурский муниципальный район, Николаевское сельское поселение, . Чехова, 1, СОШ	Россия, республика Чеченская, Наурский район	0101000020E610000080F3E2C457BB4640ED10FFB0A5E14540
12228	8	80	1109	57751	61195	\N	43.6493909333605	Чеченская Республика, Наурский муниципальный район, Ищерское сельское поселение, Советская, 34	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E6100000BC02D19332A946408BA8893E1FD34540
12222	8	80	1109	57751	61093	\N	43.654781860229001	Чеченская Республика, Наурский муниципальный район, Мекенское сельское поселение, Северная, 118 а	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E6100000DD96C80567A84640360186E5CFD34540
12219	8	80	1109	57751	61135	\N	43.649754648003302	Чеченская Республика, Наурский муниципальный район, Калиновское сельское поселение, Пролетарская, 34	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E610000052D32EA699A84640CCB4FD2B2BD34540
12224	8	80	1109	57751	61099	\N	43.651624330446197	Чеченская Республика, Наурский муниципальный район, Наурское сельское поселение, Октябрьская, 30 а	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E61000004146408523A84640F4A44C6A68D34540
12223	8	80	1109	57751	61140	\N	43.652039777466001	Чеченская Республика, Наурский муниципальный район, Чернокозовское сельское поселение, Мира, 17	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E61000004146408523A8464088D7F50B76D34540
12227	8	80	1109	57751	61075	\N	43.654456025408003	Чеченская Республика, Наурский муниципальный район, Рубежненское сельское поселение, Ленина, 25	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E6100000DC2A8881AEA74640E355D636C5D34540
12218	8	80	1109	57751	61075	\N	43.655203848365304	Чеченская Республика, Наурский муниципальный район, Ульяновское сельское поселение, Ленина, СОШ	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E610000053910A630BA74640AC1A84B9DDD34540
12214	8	80	1109	57751	61075	\N	43.654580663218802	Чеченская Республика, Наурский муниципальный район, Ново-Солкушинское сельское поселение, Ленина, 30 а		0101000020E610000075ABE7A4F7A746409FCA694FC9D34540
12220	8	80	1109	57751	61152	\N	43.652818669352499	Чеченская Республика, Наурский муниципальный район, Калиновское сельское поселение, Кооперативная, 2 а	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E6100000118DEE2076A846408D9AAF928FD34540
12216	8	80	1109	57751	61192	\N	43.645277390123198	Чеченская Республика, Наурский муниципальный район, Левобережненское сельское поселение, Гагарина, 40	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E610000026AC8DB113A8464035EECD6F98D24540
12225	8	80	1109	57751	61155	\N	43.652413705267101	Чеченская Республика, Наурский муниципальный район, Наурское сельское поселение, Алленова, 33	Россия, республика Чеченская, Наурский район, село Наурская	0101000020E610000052D32EA699A84640EDB94C4D82D34540
12229	8	80	1109	60651	75509	\N	43.722609324280597	Чеченская Республика, Наурский муниципальный район, Ищерское сельское поселение,Л. Голикова, 7, СОШ	Россия, республика Чеченская, Наурский район, село Ищерская	0101000020E61000009A7B48F8DE8F4640CB65A3737EDC4540
12226	8	80	1109	57785	61257	\N	43.700506190803203	Чеченская Республика, Наурский муниципальный район, Алпатовское сельское поселение, Клубная, 1 б	Россия, республика Чеченская, Наурский район, село Алпатово	0101000020E61000007C8159A1489F46406D533C2EAAD94540
12207	8	80	1417	57746	61003	\N	43.655352949314697	с. Братское, ул. им. Лаудаева, дом № 1, СОШ		0101000020E61000002FFD4B5299704640F12A6B9BE2D34540
12205	8	80	1417	57774	61191	\N	43.620148941599403	Чеченская Республика, Надтеречный муниципальный район, Гвардейское сельское поселение, А.А.Кадырова, 18	Россия, республика Чеченская, Надтеречный район, село Лакха-Невре	0101000020E6100000FED5E3BED59E4640D4D2DC0A61CF4540
12209	8	80	1417	57774	61228	\N	43.613663688971201	Чеченская Республика, Надтеречный муниципальный район, Калаусское сельское поселение, А.А.Кадырова, 4	Россия, республика Чеченская, Надтеречный район, село Лакха-Невре	0101000020E610000062855B3E929E4640C45DBD8A8CCE4540
12194	8	80	1417	45555	\N	\N	43.681474547688801	Чеченская Республика, Надтеречный муниципальный район, Мекен-Юртовское сельское поселение, Октябрьская, 9, СОШ	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E6100000FCDEA63FFB8F46405305A3923AD74540
12210	8	80	1417	45555	61369	\N	43.680780342678197	Чеченская Республика, Надтеречный муниципальный район, Комаровское сельское поселение, Школьная, 1	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E61000006478EC67B18E4640ACE28DCC23D74540
12202	8	80	1417	45555	61072	\N	43.678790999999997	с. Знаменское, ул. Центральная, 17, СОШ № 3		0101000020E61000002783A3E4D58F4640D9E89C9FE2D64540
12197	8	80	1417	45555	61127	\N	43.673666911922197	Чеченская Республика, Надтеречный муниципальный район, Надтеречненское сельское поселение, Пионерская, 7 а	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E61000009605137F149146407DB262B83AD64540
12212	8	80	1417	\N	61290	\N	43.587712000000003	Чеченская Республика, Надтеречный муниципальный район, Горагорское сельское поселение, Новый городок, 10 а	Россия, республика Чеченская, Надтеречный район	0101000020E610000000CADFBDA3944640BFBB95253ACB4540
12201	8	80	1417	45555	61041	\N	43.678790999999997	с. Знаменское, ул. Московская, 10, Гимназия № 10		0101000020E61000002783A3E4D58F4640D9E89C9FE2D64540
12193	8	80	1417	45555	61303	\N	43.672504007592799	Чеченская Республика, Надтеречный муниципальный район, Подгорненское сельское поселение, Мира, 31	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E6100000D0D03FC1C5904640F0366F9C14D64540
12196	8	80	1417	45555	61109	\N	43.672068876796402	Чеченская Республика, Надтеречный муниципальный район, Надтеречненское сельское поселение, Ленина, 30	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E61000001074B4AA25914640E5D3635B06D64540
12203	8	80	1417	45555	61186	\N	43.6802820089626	Чеченская Республика, Надтеречный муниципальный район, Бено-Юртовское сельское поселение, А.А.Кадырова, 41	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E6100000AA7CCF48849046405B07077B13D74540
12192	8	80	1417	45555	61186	\N	43.674497577656403	Чеченская Республика, Надтеречный муниципальный район, Зебир-Юртовское сельское поселение, А.А.Кадырова, 6	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E6100000D670917BBA904640D49B51F355D64540
12198	8	80	1417	45555	61131	\N	43.682898214468302	Чеченская Республика, Надтеречный муниципальный район, Верхненаурское сельское поселение, А-Х.Кадырова, 74	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E610000097C5C4E6E39046407D40A03369D74540
12199	8	80	1417	45555	61258	\N	43.6731685187114	Чеченская Республика, Надтеречный муниципальный район, Верхненаурское сельское поселение, 40 лет Победы, 36	Россия, республика Чеченская, Надтеречный район, село Знаменское	0101000020E6100000D670917BBA9046402CD7DB662AD64540
12211	8	80	1417	57833	61494	\N	43.508679387047401	Чеченская Республика, Надтеречный муниципальный район, Горагорское сельское поселение, Центральная, 38	Россия, республика Чеченская, Надтеречный район, поселок городского типа Горагорский	0101000020E61000008C81751C3F8A4640BC94BA641CC14540
12208	8	80	1417	60688	75565	\N	43.587712000000003	с. Братское, ул. им. Лаудаева, б/н, СДК	Россия, республика Чеченская, Надтеречный район	0101000020E610000000CADFBDA3944640BFBB95253ACB4540
12204	8	80	1417	60630	75483	\N	43.587712000000003	Чеченская Республика, Надтеречный муниципальный район, Бено-Юртовское сельское поселение, им.Х. Исаева, 20, Участковая больница		0101000020E610000000CADFBDA3944640BFBB95253ACB4540
12195	8	80	1417	57749	61051	\N	43.558303473745603	Чеченская Республика, Надтеречный муниципальный район, Надтеречненское сельское поселение, Ленина, 33 а	Россия, республика Чеченская, Надтеречный район, село Банкин-Юрт	0101000020E610000098A608707A8D46401D21037976C74540
12153	8	80	1363	14831	61136	\N	42.750422	с. Кокадой, ул. А. Кадырова, 10, ООШ		0101000020E6100000E886A6ECF4C946407619FED30D604540
12156	8	80	1363	57790	61292	\N	42.7299532847045	Чеченская Республика, Итум-Калинский муниципальный район, Гучум-Калинское сельское поселение, Ченты-Аргунская, 14	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E61000002810768A55C94640FD4E93196F5D4540
12152	8	80	1363	57790	61278	\N	42.734129000000003	Чеченская Республика, Итум-Калинский муниципальный район, Ведучинское сельское поселение, Хачероева, 7	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E6100000FF93BF7B47C94640C90567F0F75D4540
12158	8	80	1363	57790	61293	\N	42.734762153472303	Чеченская Республика, Итум-Калинский муниципальный район, Зумсойское сельское поселение, Ушкалоевская, 1а	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E6100000200890A163C94640FA2B64AE0C5E4540
12157	8	80	1363	57790	61293	\N	42.735015241424897	Чеченская Республика, Итум-Калинский муниципальный район, Бугаройское сельское поселение, Ушкалоевская, 1а	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E61000004DBC033C69C94640E388B5F8145E4540
12154	8	80	1363	57790	61293	\N	42.735394871403301	Чеченская Республика, Итум-Калинский муниципальный район, Ушкалойское сельское поселение, Ушкалоевская, 13	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E610000023D8B8FE5DC946402A52616C215E4540
12160	8	80	1363	57790	61286	\N	42.734382519592501	Чеченская Республика, Итум-Калинский муниципальный район, Баулойское сельское поселение, М.Я.Узуева, 8	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E610000074D0251C7AC9464083DE1B43005E4540
12155	8	80	1363	57790	61316	\N	42.735394871403301	Чеченская Республика, Итум-Калинский муниципальный район, Гухойское сельское поселение, Дадаева, 25	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E61000009EB4705985C946402A52616C215E4540
12161	8	80	1363	57790	61294	\N	42.7288142870934	Чеченская Республика, Итум-Калинский муниципальный район, Тусхаройское сельское поселение, А.Кадырова, 9	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E61000009A3E3BE0BAC84640F86EF3C6495D4540
12159	8	80	1363	57790	61294	\N	42.725650294304302	Чеченская Республика, Итум-Калинский муниципальный район, Хилдехаройское сельское поселение, А.Кадырова, 38	Россия, республика Чеченская, Итум-Калинский район, село Итум-Кале	0101000020E61000009A3E3BE0BAC84640D42B6519E25C4540
12134	8	80	1178	13878	61299	\N	43.325547999999998	с.Энгель-Юрт, СШ №1, ул. Школьная	Россия, республика Чеченская, Гудермесский район, село Энгель-Юрт	0101000020E6100000CD5A0A48FB2D47409CA38E8EABA94540
12133	8	80	1178	13878	61188	\N	43.325547999999998	с. Энгель-Юрт, ул. А. Кадырова, 15, СОШ № 2		0101000020E6100000CD5A0A48FB2D47409CA38E8EABA94540
12143	8	80	1178	57807	61342	\N	43.412086615331503	с.Хангиш-Юрт, СШ, ул.Терская	Россия, республика Чеченская, Гудермесский район, село Хангаш-Юрт	0101000020E6100000B309302C7F1E4740AA0D4E44BFB44540
12140	8	80	1178	60662	75522	\N	43.312260000000002	с.Новый Энгеной, Админ, ул.Мартовская	Россия, республика Чеченская, Гудермесский район	0101000020E61000009FCC3FFA26034740ABECBB22F8A74540
12125	8	80	1178	57810	61345	\N	43.266286999999998	пос.Ойсхара, СШ №1, ул.Жукова	Россия, республика Чеченская, Гудермесский район, поселок городского типа Новогрозненский	0101000020E61000006B7D91D0961F4740CB2C42B115A24540
12138	8	80	1178	57801	\N	\N	43.311430848477698	с.Мелчхи, Администрация села	Россия, республика Чеченская, Гудермесский район, село Мелчу-Хе	0101000020E610000087C1FC1532174740F4FA93F8DCA74540
12129	8	80	1178	13656	61198	\N	43.254019999999997	с. Кошкельды, ул. Х. Нурадилова, 70, Спорткомлекс Кошкельдинский		0101000020E6100000115663096B2D4740D44334BA83A04540
12128	8	80	1178	13656	61158	\N	43.254019999999997	с. Кошкельды, ул. А. Кадырова, 9 контора госхоза «Кошкельдинский»		0101000020E6100000115663096B2D4740D44334BA83A04540
12145	8	80	1178	48959	61223	\N	43.388945999999997	с. Комсомольское, ул. А.А. Кадырова, 65, СОШ № 1		0101000020E61000000C040132741447407BF486FBC8B14540
12132	8	80	1178	13848	61212	\N	43.317768999999998	с.Кади-Юрт, СШ, ул.Школьная		0101000020E6100000F33AE2900D284740605793A7ACA84540
12052	8	80	1178	57779	61220	\N	43.211944304796504	с. Ишхой-юрт, ул. М. Эсембаева, 2, СОШ № 1,	Россия, республика Чеченская, Гудермесский район, село Ишхойюрт	0101000020E6100000BC3B32569B314740AE4A22FB209B4540
12139	8	80	1178	57829	\N	\N	43.281840364209302	с.Илсхан-Юрт, СШ №1	Россия, республика Чеченская, Гудермесский район, село Ислахан-Юрт	0101000020E6100000494A7A185A0D4740325A475513A44540
12142	8	80	1178	14290	61194	\N	43.320596000000002	с. Джалка, ул. А. Кадырова, 3, СОШ № 1		0101000020E61000009911DE1E84FE46403D9D2B4A09A94540
12141	8	80	1178	14290	61194	\N	43.320596000000002	с. Джалка, ул. А. Кадырова, 3, НШ при СОШ № 1		0101000020E61000009911DE1E84FE46403D9D2B4A09A94540
12148	8	80	1178	14584	\N	\N	43.395975	с.Дарбанхи, СОШ,	Россия, республика Чеченская, Гудермесский район, село Дарбанхи	0101000020E61000000C91D3D7F30347404D840D4FAFB24540
12115	8	80	1178	13174	61081	\N	43.350992473232402	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, пр. А. Кадырова, 110	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E610000005508C2C990D47402D944C4EEDAC4540
12117	8	80	1178	13174	60970	\N	43.353497830695197	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, Школьная, 9	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E6100000B309302C7F0E4740C899266C3FAD4540
35026	8	76	767	5401	60903	\N	43.50835	Республика Ингушетия, город Малгобек, Орджоникидзе 7, Средняя школа №3		0101000020E610000096D05D12674B4640F775E09C11C14540
12113	8	80	1178	13174	61023	\N	43.353497830695197	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, Центральная, / Дружба, СОШ №8	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E61000003F73D6A71C0F4740C899266C3FAD4540
12126	8	80	1178	13174	61604	\N	43.352532521948902	пос.Ойсхара, СШ №2, ул.Победы, 54	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E610000098BED7101C0F474061E124CD1FAD4540
12110	8	80	1178	13174	60979	\N	43.353998889688597	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, Октябрьская, 35	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E6100000FF0758AB760F47408AE8D7D64FAD4540
12112	8	80	1178	13174	61080	\N	43.353497830695197	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, Котовского, 3	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E6100000CF30B5A50E0E4740C899266C3FAD4540
12123	8	80	1178	13174	61078	\N	43.353447000000003	г. Гудермес, ГУП «Чечавтотранс», ул.Кирова, 2	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E61000006CEEE87FB90C474046EF54C03DAD4540
12111	8	80	1178	13174	61078	\N	43.352495700209097	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, Кирова, 173	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E61000003F73D6A71C0F474044FCC3961EAD4540
12114	8	80	1178	13174	61025	\N	43.353497830695197	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, Интернациональная, 56	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E610000063B7CF2A330F4740C899266C3FAD4540
12121	8	80	1178	13174	61243	\N	43.353447000000003	г. Гудермес, ул. А. Кадырова, 20, СОШ № 9		0101000020E61000006CEEE87FB90C474046EF54C03DAD4540
12116	8	80	1178	13174	61033	\N	43.351493553057601	Чеченская Республика, Гудермесский муниципальный район, Гудермесское городское поселение, 84-й Морской бригады, 28	Россия, республика Чеченская, Гудермесский район, Гудермес	0101000020E6100000B309302C7F0E4740C05E61C1FDAC4540
12076	8	80	1178	11207	\N	\N	43.247579000000002	с.Герзель-Аул, контора г\\з «Восточный»	Россия, республика Чеченская, Гудермесский район, село Герзель-Аул	0101000020E610000063B664558433474094162EABB09F4540
12127	8	80	1178	11207	61272	\N	43.247579000000002	с. Герзель-Аул, ул. Мира 36 а, СОШ № 2	Россия, республика Чеченская, Гудермесский район, село Герзель-Аул	0101000020E610000063B664558433474094162EABB09F4540
12135	8	80	1178	57817	61387	\N	43.256626864203703	с.Верхний Нойбер, СШ №2, ул.Школьная, 3	Россия, республика Чеченская, Гудермесский район, село Верхний Суворов-Юрт	0101000020E610000005DB8827BB234740A3224E27D9A04540
12147	8	80	1178	14559	61283	\N	43.438125999999997	с. Брагуны, ул. Химикова, 1, СОШ № 1	Россия, республика Чеченская, Гудермесский район, село Брагуны	0101000020E6100000A52E19C7480C47407EC3448314B84540
12144	8	80	1178	14420	61291	\N	43.417568000000003	с. Азамат-Юрт, ул.Кадырова, 7, СОШ № 1	Россия, республика Чеченская, Гудермесский район, село Азамат-Юрт	0101000020E6100000C98FF8156B24474096ED43DE72B54540
12267	8	80	1069	57830	61448	\N	43.247467	ст.Ассиновская, СШ №3, ул. Заводская 66		0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12268	8	80	1069	57830	75496	\N	43.247467	ст.Ассиновская, СШ №1, ул. Бакина, 58		0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12183	8	80	1069	60646	75510	\N	43.247467	с.Серноводск, СШ №4, ул. Гагарина, 10		0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12263	8	80	1069	60646	75502	\N	43.247467	с.Серноводск, СШ №1, ул. Бр. Гайтукаевых, 55		0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12264	8	80	1069	60646	75531	\N	43.247467	с.Серноводск, СШ №3, 2-ой пер. Мичурина, 6	Россия, республика Чеченская, Грозненский район	0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12410	8	80	1069	27326	61218	\N	43.334511999999997	Чеченская Республика, муниципальное образование город Грозный, Старая Сунжа, ул. У.Р. Даудова, 94, МУК «Старосунженский»,		0101000020E61000000A83328D26DF46404D0F0A4AD1AA4540
12409	8	80	1069	27326	61284	\N	43.334511999999997	Чеченская Республика, муниципальное образование город Грозный, Старая Сунжа, ул. И.Х. Хаджиханова, СОШ № 65	Россия, республика Чеченская, Грозненский район, село Старая Сунжа	0101000020E61000000A83328D26DF46404D0F0A4AD1AA4540
12265	8	80	1069	60656	75515	\N	43.247467	с.Серноводск, СШ №2, ул. Кадырова, б\\н		0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12452	8	80	1069	57750	61068	\N	43.410399722031997	Чеченская Республика, Грозненский муниципальный район, Пролетарское сельское поселение, с.Садовое, Черкаская, 35	Россия, республика Чеченская, Грозненский район, село Садовое	0101000020E6100000D5264EEE77CC4640A323B9FC87B44540
12103	8	80	1069	12524	60978	\N	43.399300341403801	Чеченская Республика, Грозненский муниципальный район, Побединское сельское поселение, с.Радужное, Шоссейная, 17	Россия, республика Чеченская, Грозненский район, село Радужное	0101000020E6100000657094BC3AB146407AA52C431CB34540
12438	8	80	1069	60653	75511	\N	43.247467	Старопромысловский район, ул. Шефская, д. 23, ПУ №11	Россия, республика Чеченская, Грозненский район	0101000020E6100000B77EFACF9ADF46406CEBA7FFAC9F4540
12102	8	80	1069	40254	9646	\N	43.401103667165302	Чеченская Республика, Грозненский муниципальный район, Побединское сельское поселение, Школьный, 1	Россия, республика Чеченская, Грозненский район, село Побединское	0101000020E6100000191C25AFCEB74640BB25396057B34540
38896	8	78	\N	188	61529	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Ленина, 8	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
12106	8	80	1069	12652	61104	\N	43.417064000000003	Чеченская Республика, Грозненский муниципальный район, Побединское сельское поселение, с.Нагорное, Тракторная, 1		0101000020E610000002BC051214974640632B685A62B54540
12105	8	80	1069	57761	61126	\N	43.398639528097199	Чеченская Республика, Грозненский муниципальный район, Побединское сельское поселение, Керла-Юрт, Школьная, 4	Россия, республика Чеченская, Грозненский район, село Керлаюрт	0101000020E61000006C79E57ADBA646405070B1A206B34540
12104	8	80	1069	12556	61102	\N	43.405892000000001	Чеченская Республика, Грозненский муниципальный район, Побединское сельское поселение, пос.Долинский, Молодежная, 1		0101000020E610000009FEB7921DB14640A1DAE044F4B34540
12096	8	80	1069	57755	61103	\N	43.281318477959097	Чеченская Республика, Грозненский муниципальный район, Куларинское сельское поселение, Школьная, 1	Россия, республика Чеченская, Грозный	0101000020E61000007C7E18213CD8464058E36C3A02A44540
12090	8	80	1069	57755	61113	\N	43.293607928332897	Чеченская Республика, Грозненский муниципальный район, Старо-Атагинское сельское поселение, Нурадилова, 100	Россия, республика Чеченская, Грозный	0101000020E61000004792205C01D3464007EC6AF294A54540
12080	8	80	1069	57755	61151	\N	43.292521176578802	Чеченская Республика, Грозненский муниципальный район, Петропавловское сельское поселение, Нагорная, 2	Россия, республика Чеченская, Грозный	0101000020E6100000554FE61F7DD346405532005471A54540
12077	8	80	1069	57755	61125	\N	43.3178450394145	Чеченская Республика, Грозненский муниципальный район, Толстой-Юртовское сельское поселение, Кадырова, 1		0101000020E61000007C7E18213CD846403B191C25AFA84540
12079	8	80	1069	57755	61242	\N	43.264932000000002	Чеченская Республика, Грозненский муниципальный район, Горячеисточненское сельское поселение, Арсаханова, 15		0101000020E6100000130F289B72C74640FAD4B14AE9A14540
12108	8	80	1069	57755	61245	\N	43.264932000000002	Чеченская Республика, Грозненский муниципальный район, Пролетарское сельское поселение, 50-лет Октября, СОШ		0101000020E6100000130F289B72C74640FAD4B14AE9A14540
12081	8	80	1069	57783	61247	\N	43.224269427302197	Чеченская Республика, Грозненский муниципальный район, Ильиновское сельское поселение, Октябрьская, 1	Россия, республика Чеченская, Грозненский район, село Гикаловский	0101000020E6100000F1D58EE21CDD4640D940BAD8B49C4540
12075	8	80	1069	57753	61088	\N	43.465128999999997	Чеченская Республика, Грозненский муниципальный район, Виноградненское сельское поселение, Ленина, 50а		0101000020E6100000228B34F10EEE4640E9B5D95889BB4540
12411	8	80	1069	57794	61304	\N	43.368028562145597	Чеченская Республика, муниципальное образование город Грозный, Алхан-Чурт, ул. Садовая 1, СОШ № 64	Россия, республика Чеченская, Грозненский район, село Алхан-Чуртский	0101000020E6100000A03715A930DC4640637D03931BAF4540
12099	8	80	1069	12221	61166	\N	43.260293583963502	Чеченская Республика, Грозненский муниципальный район, Алхан-Калинское сельское поселение, Шерипова, 92	Россия, республика Чеченская, Грозненский район, село Алхан-Кала	0101000020E6100000511553E927C446402AAC545051A14540
12097	8	80	1069	12221	61168	\N	43.258662000000001	с. Алхан-Кала, ул. Нурадилова, 56, СОШ № 1		0101000020E610000047904AB1A3C34640E65B1FD61BA14540
12068	8	80	1066	10838	\N	\N	42.750984000000003	Чеченская Республика, Веденский муниципальный район, Хойское сельское поселение, с.Хой, Здание администрации	Россия, республика Чеченская, Веденский район, поселок разрушенный Хой	0101000020E61000004626E0D748104740DEE8633E20604540
12042	8	80	1066	57769	61165	\N	42.965386309208697	Чеченская Республика, Веденский муниципальный район, Веденское сельское поселение, с.Эшилхатой, Школьная, 8	Россия, республика Чеченская, Веденский район, село Эшилхотой	0101000020E61000003B18B14F000747401502B9C4917B4540
12057	8	80	1066	57771	61172	\N	42.996265457780602	Чеченская Республика, Веденский муниципальный район, Эрсинойское сельское поселение, с.Эрсиной, Школьная, 3	Россия, республика Чеченская, Веденский район, село Эрсеной	0101000020E610000083F8C08EFF12474021938C9C857F4540
12058	8	80	1066	10353	\N	\N	42.9736727051895	Чеченская Республика, Веденский муниципальный район, Элистанжинское сельское поселение, с.Элистанжи, СОШ	Россия, республика Чеченская, Веденский район, село Элистанжи	0101000020E6100000C2DF2F664B024740C5FF1D51A17C4540
12049	8	80	1066	9844	61157	\N	43.025113885226297	Чеченская Республика, Веденский муниципальный район, Ца-Веденское сельское поселение, с.Верхнее Ца-Ведено, Центральная, 15	Россия, республика Чеченская, Веденский район, село Ца-Ведено	0101000020E6100000F4DDAD2CD1054740FC5580EF36834540
12047	8	80	1066	9844	61121	\N	43.020780406173998	Чеченская Республика, Веденский муниципальный район, Ца-Веденское сельское поселение, с.Ца-Ведено, А.А.Кадырова, 24	Россия, республика Чеченская, Веденский район, село Ца-Ведено	0101000020E610000027C286A757064740983446EBA8824540
12059	8	80	1066	57741	60969	\N	42.983059665427902	Чеченская Республика, Веденский муниципальный район, Хаттунинское сельское поселение, с.Хаттуни, Школьная, 25	Россия, республика Чеченская, Веденский район, село Хатуни	0101000020E610000053B131AF23F84640BD00FBE8D47D4540
12060	8	80	1066	10457	61069	\N	42.977466999999997	Чеченская Республика, Веденский муниципальный район, Тевзанинское сельское поселение, с.Тевзана, Школьная, 14		0101000020E61000000DC4B29943F44640A9F57EA31D7D4540
38942	8	78	\N	3363	61536	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Ленина, 29		0101000020E61000006F7F2E1A32F64440338B506C05E34540
12062	8	80	1066	10555	61123	\N	42.945518312698702	Чеченская Республика, Веденский муниципальный район, Сельментаузенское сельское поселение, с.Сельментаузен, А.А.Кадырова, 33	Россия, республика Чеченская, Веденский район, село Сельментаузен	0101000020E6100000D3C1FA3F87ED4640C1E3DBBB06794540
12051	8	80	1066	10036	61133	\N	43.041077999999999	Чеченская Республика, Веденский муниципальный район, Гунинское сельское поселение, с.Первомайское, Школьная, 1		0101000020E61000005E8429CAA5094740E44A3D0B42854540
12066	8	80	1066	10748	61295	\N	43.024672458120499	Чеченская Республика, Веденский муниципальный район, Курчалинское сельское поселение, с. Нижние Курчали, ул. Новая, 2, СОШ	Россия, республика Чеченская, Веденский район, село Нижние Курчали	0101000020E6100000DD7C23BA671547403F90BC7328834540
12041	8	80	1066	9526	61144	\N	42.956645999999999	Чеченская Республика, Веденский муниципальный район, Веденское сельское поселение, с.Нефтянка, Школьная, 11		0101000020E61000007E52EDD3F10A4740B3EC4960737A4540
12055	8	80	1066	10221	\N	\N	43.014752727159497	Чеченская Республика, Веденский муниципальный район, Гунинское сельское поселение, с.Меседой, Частный дом	Россия, республика Чеченская, Веденский район, село Меседой	0101000020E6100000A036AAD3811047404A42226DE3814540
12061	8	80	1066	10534	\N	\N	42.966318999999999	Чеченская Республика, Веденский муниципальный район, Махкетинское сельское поселение, с.Махкеты, СОШ		0101000020E6100000DCF5D21401F4464070404B57B07B4540
12045	8	80	1066	9684	60977	\N	42.955517999999998	Чеченская Республика, Веденский муниципальный район, Дышне-Веденское сельское поселение, с.Дышне-Ведено, Х.Бекбулатова, СОШ №2		0101000020E61000009F3E027FF80F4740A25EF0694E7A4540
12044	8	80	1066	9684	61002	\N	42.955517999999998	Чеченская Республика, Веденский муниципальный район, Дышне-Веденское сельское поселение, с.Дышне-Ведено, А.А.Кадырова, СОШ №1		0101000020E61000009F3E027FF80F4740A25EF0694E7A4540
12065	8	80	1066	10650	61115	\N	42.957999609893101	Чеченская Республика, Веденский муниципальный район, Даргинское сельское поселение, с.Дарго, А.А.Кадырова, 154	Россия, республика Чеченская, Веденский район, село Дарго	0101000020E61000001F80D4264E1E4740B4C876BE9F7A4540
12064	8	80	1066	10650	61115	\N	42.958125694227299	Чеченская Республика, Веденский муниципальный район, Даргинское сельское поселение, с.Дарго, А.А.Кадырова, 62	Россия, республика Чеченская, Веденский район, село Дарго	0101000020E6100000E5B4A7E49C1E474041B96DDFA37A4540
12054	8	80	1066	10152	61146	\N	43.055151000000002	Чеченская Республика, Веденский муниципальный район, Гунинское сельское поселение, с.Гуни, Школьная, СОШ		0101000020E6100000F44D9A06450D4740BDAB1E300F874540
12048	8	80	1066	9860	\N	\N	43.030870999999998	Чеченская Республика, Веденский муниципальный район, Ца-Веденское сельское поселение, с.Верхатой, СОШ		0101000020E6100000008C67D0D003474089B2B794F3834540
12063	8	80	1066	9416	61559	\N	42.967778376539698	Чеченская Республика, Веденский муниципальный район, Сельментаузенское сельское поселение, с.Дуц-Хутор, Школьная, 1	Россия, республика Чеченская, Веденский район, село Ведено	0101000020E6100000F9653046240E4740E7E44526E07B4540
12046	8	80	1066	9416	61271	\N	42.965197205088202	Чеченская Республика, Веденский муниципальный район, Харачойское сельское поселение, Школьная, 10	Россия, республика Чеченская, Веденский район, село Ведено	0101000020E6100000C1E09A3BFA0D4740429946938B7B4540
12043	8	80	1066	9416	61066	\N	42.966770469523603	Чеченская Республика, Веденский муниципальный район, Дышне-Веденское сельское поселение, с.Ведено, Ш.Мугуева, 8	Россия, республика Чеченская, Веденский район, село Ведено	0101000020E61000009128B4ACFB0D474080608E1EBF7B4540
12067	8	80	1066	9416	61134	\N	42.961601000000002	Чеченская Республика, Веденский муниципальный район, Макажойское сельское поселение, с.Ведено, ул. Х.Нурадилова, 15		0101000020E610000021020EA14A0D47408466D7BD157B4540
12070	8	80	1066	9416	60975	\N	42.961601000000002	Чеченская Республика, Веденский муниципальный район, Белгатойское сельское поселение, с.Ведено, А.А.Кадырова, 49		0101000020E610000021020EA14A0D47408466D7BD157B4540
12069	8	80	1066	9416	60975	\N	42.961601000000002	Чеченская Республика, Веденский муниципальный район, Тазен-Калинское сельское поселение, с.Ведено, А.А.Кадырова, 8		0101000020E610000021020EA14A0D47408466D7BD157B4540
12039	8	80	1066	9416	60975	\N	42.965824964494303	Чеченская Республика, Веденский муниципальный район, Веденское сельское поселение, с.Ведено, А.А.Кадырова, 22	Россия, республика Чеченская, Веденский район, село Ведено	0101000020E6100000E22021CA170E474061545227A07B4540
12050	8	80	1066	9959	61130	\N	43.060625000000002	Чеченская Республика, Веденский муниципальный район, Бенойское сельское поселение, с.Беной, А,А.Кадырова, ООШ		0101000020E6100000D28BDAFD2A024740F6285C8FC2874540
12056	8	80	1066	10271	61139	\N	43.012521	Чеченская Республика, Веденский муниципальный район, Агишбатойское сельское поселение, с.Агишбатой, Центральная, 8		0101000020E610000024624A24D10D4740B1C1C2499A814540
12032	8	80	990	57764	61141	\N	43.16778	Чеченская Республика, Ачхой-Мартановский муниципальный район, Катар-Юртовское сельское поселение, А.Кадырова, 118-а	Россия, республика Чеченская, Ачхой-Мартановский район, село Катыр-Юрт	0101000020E6100000EFAD484C50AF46402176A6D079954540
89714	8	79	\N	1856	60698	\N	43.018678000000001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Маркова, 26		0101000020E6100000D4D347E00F574640CD936B0A64824540
12086	8	80	990	57758	61116	\N	43.261917788756001	Чеченская Республика, Грозненский муниципальный район, Пригородненское сельское поселение, Школьная, 13	Россия, республика Чеченская, Ачхой-Мартановский район, село Закан-Юрт	0101000020E6100000B4E6C75F5AB64640EB1D6E8786A14540
12036	8	80	990	57775	61201	\N	43.174653043471501	Чеченская Республика, Ачхой-Мартановский муниципальный район, Яндинское сельское поселение, Школьная, 9	Россия, республика Чеченская, Ачхой-Мартановский район, село Бамут	0101000020E610000054C554FA099B4640FB928D075B964540
12035	8	80	990	33028	61018	\N	43.179029671479199	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ново-Шаройское сельское поселение, Школьная, 17	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000209BE447FCA446405E807D74EA964540
12025	8	80	990	33028	61018	\N	43.192887215863401	Чеченская Республика, Ачхой-Мартановский муниципальный район, Закан-Юртовское сельское поселение, Школьная, 10	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000D93EE42D57A546406A696E85B0984540
12027	8	80	990	33028	61011	\N	43.194017593217701	Чеченская Республика, Ачхой-Мартановский муниципальный район, Самашкинское сельское поселение, Шерипова, Здание СОШ №3	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E61000009B3BFA5FAEA54640EC6AF294D5984540
12021	8	80	990	33028	61021	\N	43.199817436727201	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, Чапаева, 66	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000D542C9E4D4A44640A9177C9A93994540
12022	8	80	990	33028	61256	\N	43.185310714789502	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, Х.Нурадилова, 150	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E610000060066344A2A44640664B5645B8974540
12018	8	80	990	33028	61256	\N	43.1872263034792	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, Х.Нурадилова, 185	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E61000004A41B79734A44640FF7A8505F7974540
12034	8	80	990	33028	61250	\N	43.180034682143301	Чеченская Республика, Ачхой-Мартановский муниципальный район, Давыденковское сельское поселение, Садовая, 28	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E61000006EC328081EA5464053910A630B974540
12033	8	80	990	33028	61040	\N	43.181793410715599	Чеченская Республика, Ачхой-Мартановский муниципальный район, Катар-Юртовское сельское поселение, Орджоникидзе, 64	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E610000012DE1E8480A4464024D236FE44974540
12031	8	80	990	33028	61087	\N	43.181039676146703	Чеченская Республика, Ачхой-Мартановский муниципальный район, Шаами-Юртовское сельское поселение, Мамакаева, 42, Здание СОШ	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000FC56EBC4E5A4464049A297512C974540
12020	8	80	990	33028	61087	\N	43.181458398923397	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, Мамакаева, 6	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000CFA2772AE0A446407DCC07043A974540
12019	8	80	990	33028	61087	\N	43.181542166900599	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, Мамакаева, 19	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000D272A087DAA44640DB6CACC43C974540
12016	8	80	990	33028	61083	\N	43.1978708489588	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, Им.Кунтаева, 1	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000DE054A0A2CA64640D5E940D653994540
12038	8	80	990	33028	61106	\N	43.198122025088601	Чеченская Республика, Ачхой-Мартановский муниципальный район, Бамутское сельское поселение, Грейдерная, 23	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000A6643909A5A546401E4FCB0F5C994540
12030	8	80	990	33028	61067	\N	43.181793410715599	Чеченская Республика, Ачхой-Мартановский муниципальный район, Валерикское сельское поселение, Гайрбекова, 39	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000C4B5DAC35EA4464024D236FE44974540
12037	8	80	990	33028	61307	\N	43.180788429207801	Чеченская Республика, Ачхой-Мартановский муниципальный район, Старо-Ачхойское сельское поселение, Гагарина, 3	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E610000073637AC212A546402FC1A90F24974540
12029	8	80	990	33028	61190	\N	43.190963097322403	Чеченская Республика, Ачхой-Мартановский муниципальный район, Самашкинское сельское поселение, А.Кадырова, Здание СОШ	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000D1B01875ADA546407FDFBF7971984540
12026	8	80	990	33028	60991	\N	43.198624374224103	Чеченская Республика, Ачхой-Мартановский муниципальный район, Хамби-Ирзинское сельское поселение, А.Кадырова, 14	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000E3A59BC420A64640B119E0826C994540
12024	8	80	990	33028	60991	\N	43.182547135912898	Чеченская Республика, Ачхой-Мартановский муниципальный район, Закан-Юртовское сельское поселение, А.Кадырова, 9	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E61000004A7F2F8507A54640D07D39B35D974540
12023	8	80	990	33028	60991	\N	43.185059240211103	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, А.Кадырова, 130	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E610000014ECBFCE4DA546404D6A6803B0974540
12017	8	80	990	33028	60991	\N	43.193954795029001	Чеченская Республика, Ачхой-Мартановский муниципальный район, Ачхой-Мартановское сельское поселение, А.Кадырова, 13	Россия, республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан	0101000020E6100000276728EE78A54640A6F27684D3984540
12177	8	80	7448	57765	61149	\N	43.208805122102099	Чеченская Республика, Курчалоевский муниципальный район, Гелдаганское сельское поселение, М.Даудова, СОШ №1	Россия, республика Чеченская, Шалинский район, село Курчалой	0101000020E6100000F488D1730B0B4740E21E4B1FBA9A4540
89533	8	79	\N	57688	60614	\N	43.756290138594103	г. Моздок, ул. Кирова, 100		0101000020E6100000357EE195245546405B25581CCEE04540
89556	8	79	\N	57686	\N	\N	43.754925	г. Моздок, мкр-н Моздок-1, 21		0101000020E610000060E63BF88953464066F7E461A1E04540
89551	8	79	\N	57686	60604	\N	43.754925	г. Моздок, ул. Мира, 1		0101000020E610000060E63BF88953464066F7E461A1E04540
89548	8	79	\N	57686	60669	\N	43.754925	г. Моздок, ул. Кирова, 91		0101000020E610000060E63BF88953464066F7E461A1E04540
89723	8	79	\N	1856	\N	\N	43.018678000000001	Республика Северная Осетия - Алания, г. Владикавказ, с. Редант, Средняя школа с. Редант		0101000020E6100000D4D347E00F574640CD936B0A64824540
89692	8	79	\N	1856	\N	\N	43.015365584398701	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, поселок Спутник, ул. Спутник	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000D09D60FF7554464034BC5983F7814540
89756	8	79	\N	1856	60730	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, проспект Коста, 283А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89753	8	79	\N	1856	60730	\N	43.018678000000001	город Владикавказ, проспект Коста, 286		0101000020E6100000D4D347E00F574640CD936B0A64824540
89742	8	79	\N	1856	60730	\N	43.021449045487302	город Владикавказ, проспект Коста, 172	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000008D2958E36C54464015C440D7BE824540
89728	8	79	\N	1856	60730	\N	43.018678000000001	город Владикавказ, проспект Коста, 195		0101000020E6100000D4D347E00F574640CD936B0A64824540
89727	8	79	\N	1856	60730	\N	42.999280777672404	Республика Северная Осетия - Алания, город Владикавказ, проспект Коста, 38	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000073F4F8BD4D554640D1419770E87F4540
89724	8	79	\N	1856	60730	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, проспект Коста, 11		0101000020E6100000D4D347E00F574640CD936B0A64824540
89733	8	79	\N	1856	60683	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, проспект Доватора, 11А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89746	8	79	\N	1856	60733	\N	43.018678000000001	город Владикавказ, площадь Победы, 1		0101000020E6100000D4D347E00F574640CD936B0A64824540
89688	8	79	\N	1856	60720	\N	43.004783521473698	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Шмулевича, 41	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000006D718DCF64594640A4C519C39C804540
89687	8	79	\N	1856	60720	\N	42.999617800087101	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Шмулевича, 10а	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000A304FD851E594640183F8D7BF37F4540
89713	8	79	\N	1856	60648	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, Чкалова, 8		0101000020E6100000D4D347E00F574640CD936B0A64824540
89712	8	79	\N	1856	60648	\N	43.047604354956299	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Чкалова, 8	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000A6D425E31859464053944BE317864540
89674	8	79	\N	1856	60773	\N	43.022923076521998	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Церетели, 25	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000F7B182DF86544640C1A90F24EF824540
89686	8	79	\N	1856	60804	\N	43.030227761673501	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Церетели, 7	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000AA285E656D57464035B6D782DE834540
89737	8	79	\N	1856	60653	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Цейская, 1		0101000020E6100000D4D347E00F574640CD936B0A64824540
89654	8	79	\N	1856	60768	\N	43.018678000000001	город Владикавказ, улица Тогоева, 48		0101000020E6100000D4D347E00F574640CD936B0A64824540
89761	8	79	\N	1856	60708	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Весенняя, 6		0101000020E6100000D4D347E00F574640CD936B0A64824540
89709	8	79	\N	1856	60697	\N	43.045086315206802	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Тельмана, 2	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000B2F2CB608C564640F4C0C760C5854540
89702	8	79	\N	1856	60697	\N	43.024434462520098	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Тельмана, 31в	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000CAA31B61515546408A743FA720834540
89684	8	79	\N	1856	60721	\N	43.0004367850958	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Тамаева, 15	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000F564FED137594640AB5AD2510E804540
89720	8	79	\N	1856	60657	\N	43.0223353862186	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Севастопольская, 7а	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000029F1F460855464030478FDFDB824540
89676	8	79	\N	1856	60799	\N	42.972017879485101	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Революции, 34	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000005AD6FD6321584640C98FF8156B7C4540
89681	8	79	\N	1856	60647	\N	42.992183433324001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Пушкинская, 47	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000BF2B82FFAD584640D65240DAFF7E4540
89679	8	79	\N	1856	60798	\N	42.980210939181497	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Пушкинская, 40	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000D2E28C614E584640F816D68D777D4540
89652	8	79	\N	1856	60820	\N	42.998623338665901	Республика Северная Осетия - Алания, Пригородный муниципальный район, Гизельское сельское поселение, Пролетарская, 43	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000008F537424975546404704E3E0D27F4540
89701	8	79	\N	1856	60695	\N	43.028716519333202	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Пожарского, 21	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000952C27A1F45346406CEBA7FFAC834540
89670	8	79	\N	1856	60684	\N	43.019396363454597	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Павленко, 69	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000066F4A3E1945546402CD670917B824540
89666	8	79	\N	1856	60689	\N	42.980084900436403	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, Осетинская горка, 1		0101000020E6100000D2E28C614E5846406C26DF6C737D4540
89665	8	79	\N	1856	60770	\N	43.0282537184681	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, Осетинская горка,1	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000DF6DDE382954464097FDBAD39D834540
89707	8	79	\N	1856	60788	\N	43.061199970672099	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Огурцова, 2		0101000020E6100000DE0033DFC1554640F241CF66D5874540
89703	8	79	\N	1856	60722	\N	43.023467834144299	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Николаева, 44		0101000020E610000051DA1B7C615446405340DAFF00834540
89700	8	79	\N	1856	60722	\N	43.018678000000001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Николаева, 42		0101000020E6100000D4D347E00F574640CD936B0A64824540
89754	8	79	\N	1856	60625	\N	43.018678000000001	город Владикавказ, улица Московская, 16		0101000020E6100000D4D347E00F574640CD936B0A64824540
89719	8	79	\N	1856	60726	\N	43.016709228810598	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Молодежная, 7	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000002452C62D85546404146408523824540
89699	8	79	\N	1856	60821	\N	43.018678000000001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Мичурина / ул. Остаева, 8/5		0101000020E6100000D4D347E00F574640CD936B0A64824540
89711	8	79	\N	1856	60676	\N	43.017884852538003	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Миллеров (ул. Советов), 30	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000002E5393E00D554640630B410E4A824540
89710	8	79	\N	1856	60816	\N	43.018678000000001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Миллера (ул. Советов), 32		0101000020E6100000D4D347E00F574640CD936B0A64824540
89718	8	79	\N	1856	60698	\N	43.012006360159802	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Маркова, 44	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000A1BFD023465546408AADA06989814540
89683	8	79	\N	1856	60698	\N	43.018678000000001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Маркова, 2а		0101000020E6100000D4D347E00F574640CD936B0A64824540
89763	8	79	\N	1856	60737	\N	43.018678000000001	город Владикавказ, улица М. Пехотинцев, 5		0101000020E6100000D4D347E00F574640CD936B0A64824540
89762	8	79	\N	1856	60737	\N	43.018678000000001	город Владикавказ, улица М. Пехотинцев, 7А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89752	8	79	\N	1856	60703	\N	43.018678000000001	город Владикавказ, улица Леонова, 5/5		0101000020E6100000D4D347E00F574640CD936B0A64824540
89751	8	79	\N	1856	60703	\N	43.018678000000001	город Владикавказ, улица Леонова, 2		0101000020E6100000D4D347E00F574640CD936B0A64824540
89675	8	79	\N	1856	60755	\N	43.009527567682397	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Ленина, 4	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000D7DB662AC4594640BA32A83638814540
89755	8	79	\N	1856	60655	\N	43.018678000000001	город Владикавказ, улица Леваневского, 279		0101000020E6100000D4D347E00F574640CD936B0A64824540
89744	8	79	\N	1856	60655	\N	43.018678000000001	город Владикавказ, улица Леваневского, 53		0101000020E6100000D4D347E00F574640CD936B0A64824540
89743	8	79	\N	1856	60655	\N	43.018678000000001	город Владикавказ, улица Леваневского, 49		0101000020E6100000D4D347E00F574640CD936B0A64824540
89734	8	79	\N	1856	60782	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Кырджалийская, 19		0101000020E6100000D4D347E00F574640CD936B0A64824540
89671	8	79	\N	1856	60690	\N	43.014861718279001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Кутузова, 74а	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000F487669E5C55464001FA7DFFE6814540
89669	8	79	\N	1856	60690	\N	43.0324945549159	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Кутузова, 72	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000001BF67B629D5446404A24D1CB28844540
89691	8	79	\N	1856	60642	\N	43.003397639162799	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Куйбышева126б, 88672	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000001EE1B4E045594640976F7D586F804540
89690	8	79	\N	1856	60642	\N	43.021411653048197	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Куйбышева, 126б	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000093020B60CA544640F8DEDFA0BD824540
89689	8	79	\N	1856	60642	\N	42.987772787670103	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Куйбышева, 75	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000006B63EC8497584640976F7D586F7E4540
89682	8	79	\N	1856	60642	\N	43.0051614839116	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Куйбышева, 66	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000BD0166BE835946407A1B9B1DA9804540
89740	8	79	\N	1856	60658	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Коцоева, 66		0101000020E6100000D4D347E00F574640CD936B0A64824540
89739	8	79	\N	1856	60658	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Коцоева, 43		0101000020E6100000D4D347E00F574640CD936B0A64824540
89745	8	79	\N	1856	60706	\N	43.018678000000001	город Владикавказ, проспект Коста, 221		0101000020E6100000D4D347E00F574640CD936B0A64824540
89667	8	79	\N	1856	60753	\N	43.026994311659898	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Коста Хетагурова/ ул. Кантемирова, 23/23а	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000DF6DDE38295446401898158A74834540
89705	8	79	\N	1856	60693	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Коблова, 5		0101000020E6100000D4D347E00F574640CD936B0A64824540
89678	8	79	\N	1856	60811	\N	43.018678000000001	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Кирова, 46		0101000020E6100000D4D347E00F574640CD936B0A64824540
89750	8	79	\N	1856	60738	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Кесаева, 135		0101000020E6100000D4D347E00F574640CD936B0A64824540
89749	8	79	\N	1856	60785	\N	43.018678000000001	город Владикавказ, улица Калоева, 408		0101000020E6100000D4D347E00F574640CD936B0A64824540
89747	8	79	\N	1856	60659	\N	43.018678000000001	город Владикавказ, улица Калинина, 2		0101000020E6100000D4D347E00F574640CD936B0A64824540
89618	8	79	\N	1856	60823	\N	43.0250777249762	Республика Северная Осетия - Алания, Пригородный муниципальный район, Черменское сельское поселение, К. Хетагурова, 44 а	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000000514EAE923544640AFEC82C135834540
89741	8	79	\N	1856	60727	\N	43.014398812214601	город Владикавказ, улица К. Маркса, 36	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000006FA0C03BF95646402C0C91D3D7814540
89738	8	79	\N	1856	60727	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица  К. Маркса, 19		0101000020E6100000D4D347E00F574640CD936B0A64824540
89506	8	79	1040	26067	60812	\N	43.195231999999997	Республика Северная Осетия - Алания, Ирафский муниципальный район, Чиколинское сельское поселение, Бр.Албегоновых, 89		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
89708	8	79	\N	1856	60702	\N	43.0028086542533	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Иристонская, 3	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000004FB0FF3A375546403691990B5C804540
89706	8	79	\N	1856	60734	\N	43.001255759109398	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Иристонская, 25	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000C2D9AD65325646403E76172829804540
89698	8	79	\N	1856	60734	\N	43.019396363454597	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Иристонская, 43	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000001BF67B629D5446402CD670917B824540
89697	8	79	\N	1856	60734	\N	43.029975890552599	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Иристонская, 70	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000062A06B5F405746401BD5E940D6834540
89715	8	79	\N	1856	60724	\N	43.008815000060899	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Интернациональная, 24	Россия, А-301 шоссе	0101000020E61000009E95B4E21B5646406C5B94D920814540
89748	8	79	\N	1856	60660	\N	43.018678000000001	город Владикавказ, улица З. Космодемьянской, 3		0101000020E6100000D4D347E00F574640CD936B0A64824540
89735	8	79	\N	1856	60680	\N	43.023436346818897	Республика Северная Осетия - Алания, город Владикавказ, проспект Доватора, 35А	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000000A4D124BCA53464047C66AF3FF824540
89732	8	79	\N	1856	60650	\N	43.018678000000001	город Владикавказ, проспект Доватора, 7А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89772	8	79	\N	1856	60709	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Дзусова, 28А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89771	8	79	\N	1856	60709	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Дзусова, 36		0101000020E6100000D4D347E00F574640CD936B0A64824540
89770	8	79	\N	1856	60709	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Дзусова, 24А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89655	8	79	\N	1856	60825	\N	43.001143298485403	Республика Северная Осетия - Алания, Пригородный муниципальный район, Нижнесанибанское сельское поселение, Джимиева, 48	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000008F5374249755464046CF2D7425804540
89685	8	79	\N	1856	60644	\N	43.006421341789299	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Джанаева, 36	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000904DF2237E594640FA804067D2804540
89668	8	79	\N	1856	60640	\N	43.0163733041461	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Гэсовская, 3	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000002C29779FE3554640CAC4AD8218824540
89664	8	79	\N	1856	60640	\N	42.963193354881099	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, п. Южный, ул. Гэсовская, 3	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000D34A21904B584640395E81E8497B4540
89757	8	79	\N	1856	60641	\N	43.018678000000001	город Владикавказ, улица Гугкаева, 24		0101000020E6100000D4D347E00F574640CD936B0A64824540
89726	8	79	\N	1856	60675	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Грибоедова, 1		0101000020E6100000D4D347E00F574640CD936B0A64824540
89725	8	79	\N	1856	60756	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Герцена, 7		0101000020E6100000D4D347E00F574640CD936B0A64824540
89731	8	79	\N	1856	60701	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Гастелло, 67		0101000020E6100000D4D347E00F574640CD936B0A64824540
89760	8	79	\N	1856	60707	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Галковского, 221		0101000020E6100000D4D347E00F574640CD936B0A64824540
89759	8	79	\N	1856	60707	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Галковского, 227А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89758	8	79	\N	1856	60707	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Галковского, 235А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89730	8	79	\N	1856	60646	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Гадиева, 77		0101000020E6100000D4D347E00F574640CD936B0A64824540
89729	8	79	\N	1856	60646	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Гадиева, 10		0101000020E6100000D4D347E00F574640CD936B0A64824540
89629	8	79	\N	1856	60643	\N	43.012523800272902	Республика Северная Осетия - Алания, Пригородный муниципальный район, Октябрьское сельское поселение, Гагарина, 18	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E6100000DCD5ABC8E85446402235ED629A814540
89766	8	79	\N	1856	60679	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Владикавказская, 12/2		0101000020E6100000D4D347E00F574640CD936B0A64824540
89775	8	79	\N	1856	60708	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Весенняя, 17		0101000020E6100000D4D347E00F574640CD936B0A64824540
89680	8	79	\N	1856	60776	\N	43.022419272861399	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Ватутина, 46	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000093020B60CA5446408EE733A0DE824540
89677	8	79	\N	1856	60774	\N	43.018388693674197	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. В. Баллаева, 17		0101000020E610000002452C62D855464096CD1C925A824540
89639	8	79	\N	1856	60665	\N	42.963585117937399	Республика Северная Осетия - Алания, Пригородный муниципальный район, Сунженское сельское поселение, Бибилова, 27		0101000020E6100000AC58FCA6B052464045F5D6C0567B4540
89704	8	79	\N	1856	60781	\N	43.024434462520098	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, ул. Бзарова, 29	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000005B61FA5E435446408A743FA720834540
89736	8	79	\N	1856	60652	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица Барбашова, 43Б		0101000020E6100000D4D347E00F574640CD936B0A64824540
89672	8	79	\N	1856	60656	\N	43.004572516034003	Республика Северная Осетия - Алания, городской округ город Владикавказ, Иристонский муниципальный округ, ул. Армянская, 30/1	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000025CCB4FD2B554640E9B81AD995804540
89774	8	79	\N	1856	60661	\N	43.009482294296703	Республика Северная Осетия - Алания, город Владикавказ, улица А. Кесаева, 28	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E61000003A07CF842655464049F3C7B436814540
89773	8	79	\N	1856	60661	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица  А. Кесаева, 28		0101000020E6100000D4D347E00F574640CD936B0A64824540
89769	8	79	\N	1856	60661	\N	43.018678000000001	город Владикавказ, улица А. Кесаева, 12А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89768	8	79	\N	1856	60661	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица А. Кесаева, 12А		0101000020E6100000D4D347E00F574640CD936B0A64824540
89767	8	79	\N	1856	60661	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица А. Кесаева, 7		0101000020E6100000D4D347E00F574640CD936B0A64824540
89765	8	79	\N	1856	60661	\N	43.018678000000001	Республика Северная Осетия - Алания, город Владикавказ, улица А. Кесаева, 23		0101000020E6100000D4D347E00F574640CD936B0A64824540
89764	8	79	\N	1856	60661	\N	43.018678000000001	город Владикавказ, улица А. Кесаева, 23		0101000020E6100000D4D347E00F574640CD936B0A64824540
89483	8	79	\N	57689	60618	\N	43.178267314631299	Республика Северная Осетия - Алания, Ардонский муниципальный район, Кировское сельское поселение, Ленина, 40	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E610000078D49810732546405F7AFB73D1964540
89621	8	79	8	32573	60834	\N	43.142282000000002	Республика Северная Осетия - Алания, Пригородный муниципальный район, Черменское сельское поселение, Орджоникидзе, 31		0101000020E6100000D784B4C6A05B46409D67EC4B36924540
89637	8	79	8	57707	60817	\N	43.062023782768101	Республика Северная Осетия - Алания, Пригородный муниципальный район, Сунженское сельское поселение, Бибилова, 48	Россия, республика Северная Осетия-Алания, Пригородный район, село Сунжа	0101000020E6100000F30181CEA467464097C80567F0874540
89663	8	79	8	57725	\N	\N	43.156167000000003	Республика Северная Осетия - Алания, Пригородный муниципальный район, Михайловское сельское поселение, поселок Первомайский, Клуб воинской части		0101000020E610000067F162618852464073DBBE47FD934540
89626	8	79	8	57693	60754	\N	43.046610676119101	Республика Северная Осетия - Алания, Пригородный муниципальный район, Камбилеевское сельское поселение, Ю. Кучиева, 39	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000F10EF0A4855F464022516859F7854540
89625	8	79	8	57693	60754	\N	43.045225744544403	"Республика Северная Осетия - Алания, Пригородный муниципальный район, Камбилеевское сельское поселение, Ю. Кучиева, 96 ""а"""	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000637B2DE8BD5F4640E6762FF7C9854540
89620	8	79	8	57693	60758	\N	43.0447221252549	Республика Северная Осетия - Алания, Пригородный муниципальный район, Черменское сельское поселение, Школьная, 17	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000C72AA5677A5F4640B3B45373B9854540
89627	8	79	8	57693	60747	\N	43.046778514055703	Республика Северная Осетия - Алания, Пригородный муниципальный район, Ирское сельское поселение, Ф. Кастро, 4	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000F10EF0A4855F4640DE91B1DAFC854540
89628	8	79	8	57693	60793	\N	43.046149015908298	Республика Северная Осетия - Алания, Пригородный муниципальный район, Ирское сельское поселение, Терешковой, 56	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E61000004F1E166A4D5F46401EDFDE35E8854540
89659	8	79	8	\N	60751	\N	42.990810801709401	Республика Северная Осетия - Алания, Пригородный муниципальный район, Михайловское сельское поселение, Р. Люксембург, 2Г	Россия, республика Северная Осетия-Алания, Пригородный район	0101000020E61000000F62670A9D5146402FC214E5D27E4540
89503	8	79	1040	26067	60812	\N	43.195231999999997	село Чикола, Бр.Албегоновых, 1		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
89651	8	79	8	\N	60735	\N	42.989466567453299	Республика Северная Осетия - Алания, Пригородный муниципальный район, Гизельское сельское поселение, Пролетарская, 1	Россия, республика Северная Осетия-Алания, Пригородный район	0101000020E6100000D2C6116BF151464051BCCADAA67E4540
89634	8	79	8	57693	60682	\N	43.054845966823898	Республика Северная Осетия - Алания, Пригородный муниципальный район, Октябрьское сельское поселение, Павла Тедеева, 2	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000F6234564585F46408028983105874540
89632	8	79	8	57693	60682	\N	43.047352555666002	Республика Северная Осетия - Алания, Пригородный муниципальный район, Октябрьское сельское поселение, Павла Тедеева, 72	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E61000009DA1B8E34D6046400A2FC1A90F864540
89630	8	79	8	57693	60682	\N	43.052905422743002	Республика Северная Осетия - Алания, Пригородный муниципальный район, Октябрьское сельское поселение, Павла Тедеева, 58	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E61000009D465A2A6F5F4640BF654E97C5864540
89636	8	79	8	57693	60766	\N	43.0447221252549	Республика Северная Осетия - Алания, Пригородный муниципальный район, Тарское сельское поселение, Октябрьская, 3	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E61000003997E2AAB25F4640B3B45373B9854540
89644	8	79	8	57693	60796	\N	43.046904425583598	Республика Северная Осетия - Алания, Пригородный муниципальный район, Архонское сельское поселение, Мира, 37	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000C72AA5677A5F46409A0645F300864540
89633	8	79	8	57693	60778	\N	43.045225744544403	Республика Северная Осетия - Алания, Пригородный муниципальный район, Октябрьское сельское поселение, Маяковского, 12	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000C72AA5677A5F4640E6762FF7C9854540
89650	8	79	8	57693	60704	\N	43.045897200035	Республика Северная Осетия - Алания, Пригородный муниципальный район, Ногирское сельское поселение, Ленина, 120	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000F10EF0A4855F464004FEF0F3DF854540
89648	8	79	8	\N	60704	\N	42.986568050037697	Республика Северная Осетия - Алания, Пригородный муниципальный район, Ногирское сельское поселение, Ленина, 107	Россия, республика Северная Осетия-Алания, Пригородный район	0101000020E6100000344C6DA983524640DBA337DC477E4540
89640	8	79	8	57693	60704	\N	43.046232970630903	Республика Северная Осетия - Алания, Пригородный муниципальный район, Сунженское сельское поселение, Ленина, 24	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000EB6E9EEA905F46407C7F83F6EA854540
89635	8	79	8	57693	60704	\N	43.053138635522998	Республика Северная Осетия - Алания, Пригородный муниципальный район, Тарское сельское поселение, Ленина, 16	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000977329AE2A5F464032923D42CD864540
89617	8	79	8	57693	60771	\N	43.044973935420202	Республика Северная Осетия - Алания, Пригородный муниципальный район, Майское сельское поселение, Коммунальная, 38	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E61000009D465A2A6F5F4640CD9541B5C1854540
89641	8	79	8	57693	60760	\N	43.044008637614397	Республика Северная Осетия - Алания, Пригородный муниципальный район, Комгаронское сельское поселение, Кирова, 1	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000F10EF0A4855F464066DD3F16A2854540
89622	8	79	8	57693	60760	\N	43.045477552627602	Республика Северная Осетия - Алания, Пригородный муниципальный район, Донгаронское сельское поселение, Кирова, 5	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E61000001553E9279C5F464000581D39D2854540
89619	8	79	8	57693	60744	\N	43.046107068281003	Республика Северная Осетия - Алания, Пригородный муниципальный район, Черменское сельское поселение, Калинина, 16	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E610000018231285965F4640EF8E8CD5E6854540
89660	8	79	8	57693	60784	\N	43.0447221252549	Республика Северная Осетия - Алания, Пригородный муниципальный район, Михайловское сельское поселение, Гагарина, 6	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000C72AA5677A5F4640B3B45373B9854540
89646	8	79	8	57693	60822	\N	43.046232970630903	Республика Северная Осетия - Алания, Пригородный муниципальный район, Архонское сельское поселение, Владикавказская, 58	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000EE3EC7478B5F46407C7F83F6EA854540
89661	8	79	8	57693	60792	\N	43.045225744544403	Республика Северная Осетия - Алания, Пригородный муниципальный район, Михайловское сельское поселение, Вильямса, 1	Россия, республика Северная Осетия-Алания, Пригородный район, село Октябрьское	0101000020E6100000EE3EC7478B5F4640E6762FF7C9854540
89623	8	79	8	\N	60743	\N	42.984635669640703	Республика Северная Осетия - Алания, Пригородный муниципальный район, Куртатское сельское поселение, 50 Лет Октября, 10	Россия, республика Северная Осетия-Алания, Пригородный район	0101000020E6100000632AFD84B35146406D3B6D8D087E4540
89656	8	79	8	57719	\N	\N	42.920200631794202	Республика Северная Осетия - Алания, Пригородный муниципальный район, Кобанское сельское поселение, АМС Кобанского сельского поселения	Россия, республика Северная Осетия-Алания, Пригородный район, село Кобан	0101000020E610000045F12A6B9B3E46408D5F7825C9754540
89658	8	79	8	57717	\N	\N	42.8376347501015	Республика Северная Осетия - Алания, Пригородный муниципальный район, Кармадонское сельское поселение, АМС Кармадонского сельского поселен	Россия, республика Северная Осетия-Алания, Пригородный район, село Кармадон	0101000020E61000003D0B42791F414640137EA99F376B4540
89624	8	79	8	57695	60849	\N	43.069583000000002	Республика Северная Осетия - Алания, Пригородный муниципальный район, Камбилеевское сельское поселение, Ю. Кучиева, 85	Россия, республика Северная Осетия-Алания, Пригородный район, село Камбилеевское	0101000020E6100000F085C954C1604640C5AD8218E8884540
89647	8	79	8	57692	60678	\N	43.028100352643897	Республика Северная Осетия - Алания, Пригородный муниципальный район, Архонское сельское поселение, Некрасова, 2	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000040A03369535946404182E2C798834540
89638	8	79	8	57692	60713	\N	43.028855986138403	Республика Северная Осетия - Алания, Пригородный муниципальный район, Сунженское сельское поселение, Комсомольская, 41	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000006D50627A25946408D25AC8DB1834540
89642	8	79	8	57692	60688	\N	43.028855986138403	Республика Северная Осетия - Алания, Пригородный муниципальный район, Архонское сельское поселение, Коминтерна, 55	Россия, республика Северная Осетия-Алания, Владикавказ	0101000020E610000040A03369535946408D25AC8DB1834540
89649	8	79	8	57692	60673	\N	43.0303672250202	Республика Северная Осетия - Алания, Пригородный муниципальный район, Ногирское сельское поселение, Калоева, 35		0101000020E61000002A1900AAB859464056F0DB10E3834540
89653	8	79	8	32826	60845	\N	43.012	Республика Северная Осетия - Алания, Пригородный муниципальный район, Верхнесанибанское сельское поселение, Губа Губиева, 48	Россия, республика Северная Осетия-Алания, Пригородный район, село Верхняя Саниба	0101000020E6100000FED30D1478474640A8C64B3789814540
89645	8	79	8	57734	60870	\N	43.1115201725082	Республика Северная Осетия - Алания, Пригородный муниципальный район, Архонское сельское поселение, Крупской, 45	Россия, республика Северная Осетия-Алания, Пригородный район, село Архонская	0101000020E61000004D309C6B98414640CA6C9049468E4540
89662	8	79	8	2332	\N	\N	43.139822000000002	Республика Северная Осетия - Алания, Пригородный муниципальный район, Михайловское сельское поселение, поселок Алханчурт, Алханчуртская	Россия, республика Северная Осетия-Алания, Пригородный район, село Алханчурт	0101000020E610000095F3C5DE8B4B464073A1F2AFE5914540
89590	8	79	1004	57713	60840	\N	43.241221318093302	Республика Северная Осетия - Алания, Правобережный муниципальный район, Хумалагское сельское поселение, Советская, 3		0101000020E61000007EC85BAE7E3C4640E10D6954E09E4540
89593	8	79	1004	57738	60938	\N	43.3574183592794	Республика Северная Осетия - Алания, Правобережный муниципальный район, Раздзогское сельское поселение, Ленина, 10	Россия, республика Северная Осетия-Алания, Правобережный район, село Раздзог	0101000020E6100000200BD121703C464039807EDFBFAD4540
89586	8	79	1004	\N	60749	\N	43.172003946109903	Республика Северная Осетия - Алания, Правобережный муниципальный район, Зильгинское сельское поселение, Школьная, 1	Россия, республика Северная Осетия-Алания, Пригородный район	0101000020E610000059A31EA2D14B4640FE63213A04964540
89606	8	79	1004	33012	60731	\N	43.1886492169536	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Цаликова, 2		0101000020E6100000B9AB5791D145464028B682A625984540
89614	8	79	1004	33012	60759	\N	43.192354523131499	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Хлебный, 3	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E610000047AF06280D4546406D1CB1169F984540
89585	8	79	1004	33012	60752	\N	43.197880660545898	Республика Северная Осетия - Алания, Правобережный муниципальный район, Ольгинское сельское поселение, Суджаева, 58	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000AB5E7EA7C9444640F9BF232A54994540
89602	8	79	1004	33012	60729	\N	43.187769958501903	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Сигова, 11	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E610000030B8E68EFE454640C095ECD808984540
89604	8	79	1004	33012	60757	\N	43.1833106656848	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Привокзальная, 5	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000FE261422E0444640A0FF1EBC76974540
89607	8	79	1004	33012	60630	\N	43.187267519373798	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Подгорная, 87	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E610000006D49B51F34546402ECBD765F8974540
89598	8	79	1004	33012	60662	\N	43.196059602757998	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Октябрьская, 15	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000003B376DC6434640E2067C7E18994540
89616	8	79	1004	33012	60635	\N	43.176181396447603	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Окружная, 7	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000E9D32AFA434546409A9658198D964540
89601	8	79	1004	33012	60671	\N	43.187832763100097	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Ленина, 14	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E610000073BD6DA642444640060E68E90A984540
89596	8	79	1004	33012	60671	\N	43.186325434781999	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Ленина, 70	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000354415FE0C454640AEB6627FD9974540
89589	8	79	1004	33012	60671	\N	43.1967503552587	Республика Северная Осетия - Алания, Правобережный муниципальный район, Хумалагское сельское поселение, Ленина, 71	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000F986C267EB44464077BE9F1A2F994540
89588	8	79	1004	\N	60671	\N	43.267416629891301	Республика Северная Осетия - Алания, Правобережный муниципальный район, Заманкульское сельское поселение, Ленина, 45	Россия, республика Северная Осетия-Алания, Правобережный район	0101000020E61000007B87DBA1614346407DB262B83AA24540
89600	8	79	1004	33012	60623	\N	43.198131836635	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Котовского, 2	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E610000021E7FD7F9C4446404225AE635C994540
89603	8	79	1004	33012	60622	\N	43.193394201216201	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Кооперативная, 10	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E61000009C8BBFED094446400E9F7422C1984540
89612	8	79	1004	33012	60633	\N	43.185822983678797	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Коминтерна, 128	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E61000001D93C5FD474646401CEC4D0CC9974540
89611	8	79	1004	33012	60633	\N	43.185822983678797	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Коминтерна, 130		0101000020E610000047AF06280D4546401CEC4D0CC9974540
89599	8	79	1004	33012	60674	\N	43.195368842382301	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Иристонская, 84А	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E610000081423D7D044646407CD3F4D901994540
89613	8	79	1004	33012	60677	\N	43.195180451822203	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Дзарахохова, 39	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E61000004B9352D0ED434640A96A82A8FB984540
89595	8	79	1004	33012	60772	\N	43.201899353011697	Республика Северная Осетия - Алания, Правобережный муниципальный район, Фарновское сельское поселение, Джимиева, 48	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E61000002041F163CC4546402C0C91D3D7994540
89615	8	79	1004	33012	60636	\N	43.202150512439403	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Гагарина, 36	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000068200193A46464046ED7E15E0994540
89608	8	79	1004	33012	60626	\N	43.191914922378999	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Вокзальная, 1	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000E7E3DA5031444640514EB4AB90984540
89610	8	79	1004	33012	60654	\N	43.181716859976	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Бр.ногаевых, 132	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E610000013640454384646404910AE8042974540
89587	8	79	1004	33012	60769	\N	43.203071493607602	Республика Северная Осетия - Алания, Правобережный муниципальный район, Новобатакоевское сельское поселение, Бзарова, 35А	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000984D8061F94546400DE2033BFE994540
38915	8	78	\N	188	61529	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Ленина, 149		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
89609	8	79	1004	33012	60637	\N	43.194803668944701	Республика Северная Осетия - Алания, Правобережный муниципальный район, Бесланское городское поселение, Бесланская, 1	Россия, республика Северная Осетия-Алания, Правобережный район, Беслан	0101000020E6100000AD18AE0E80444640A3906456EF984540
89594	8	79	1004	57712	60837	\N	43.378233000000002	Республика Северная Осетия - Алания, Правобережный муниципальный район, Батакоевское сельское поселение, Плиева, 80	Россия, республика Северная Осетия-Алания, Правобережный район, село Батако	0101000020E61000008B6F287CB64446404DA25EF069B04540
89582	8	79	1592	47622	\N	\N	43.764577911698602	"пос. Черноярский, Красный уголок ж.д. станции ""Черноярская"""	Россия, республика Северная Осетия-Алания, Моздокский район, село Черноярский	0101000020E6100000B83CD68C0C2C4640DC9E20B1DDE14540
89581	8	79	1592	47622	60802	\N	43.764094251083897	ст. Черноярская, ул. Красная, 51	Россия, республика Северная Осетия-Алания, Моздокский район, село Черноярский	0101000020E6100000BF7FF3E2C42B4640F0880AD5CDE14540
89579	8	79	1592	30409	60803	\N	43.455450999999996	с. Хурикау, ул. Гагарина, 28-А		0101000020E61000000072C284D13A46401AF7E6374CBA4540
89562	8	79	1592	47239	60627	\N	43.763415000000002	с. Троицкое, ул. Октябрьская, 44		0101000020E61000000ABABDA4315646404F232D95B7E14540
89563	8	79	1592	47239	60628	\N	43.763352776286403	с. Троицкое, ул. Виноградная, 34	Россия, республика Северная Осетия-Алания, Моздокский район, село Троицкое	0101000020E6100000BB29E5B512564640D926158DB5E14540
89566	8	79	1592	47321	60603	\N	43.720483000000002	ст. Терская, ул. Ленина, 19		0101000020E6100000882AFC19DE5C4640782975C938DC4540
89543	8	79	1592	57710	60835	\N	43.805739624191098	пос. Тельмана, ул. Никулиной, 7	Россия, республика Северная Осетия-Алания, Моздокский район, село Тельман	0101000020E6100000E49EAEEE582A46401E8A027D22E74540
89577	8	79	1592	30258	60801	\N	43.677571	с. Сухотское, ул. Садовая, 50		0101000020E6100000BEDBBC7152384640E8DB82A5BAD64540
89572	8	79	1592	30936	60852	\N	43.729694000000002	пос. Советский, ул. Центральная, 19		0101000020E6100000A06B5F402F464640310BED9C66DD4540
89571	8	79	1592	32974	60789	\N	43.818604999999998	пос. Садовый, ул. Театральная, 5		0101000020E6100000295DFA97A4484640C9AB730CC8E84540
89575	8	79	1592	57704	60795	\N	43.698721594073	с. Раздольное, ул. Октябрьская, 7	Россия, республика Северная Осетия-Алания, Моздокский район, село Раздольное	0101000020E6100000B5368DEDB5444640737FF5B86FD94540
89584	8	79	1592	30620	60750	\N	43.742584000000001	пос. Притеречный, ул. Кирова, 24		0101000020E6100000F321A81ABD264640354415FE0CDF4540
89570	8	79	1592	32969	60794	\N	43.564115999999999	с. Предгорное, ул. Коркмасова, 1-А		0101000020E6100000486FB88FDC5846403E93FDF334C84540
89574	8	79	1592	30124	60664	\N	43.720514999999999	ст. Павлодольская, пер. Уварова, 1		0101000020E61000009031772D213D464083A3E4D539DC4540
89573	8	79	1592	30124	60765	\N	43.720514999999999	ст. Павлодольская, пер. К. Хетагурова, 18		0101000020E61000009031772D213D464083A3E4D539DC4540
89580	8	79	1592	57705	60800	\N	43.705166131159601	ст. Ново-Осетинская, ул. Октябрьская, 57	Россия, республика Северная Осетия-Алания, Моздокский район, село Новоосетинская	0101000020E6100000423EE8D9AC324640252026E142DA4540
89550	8	79	1592	28278	60717	\N	43.754925	г. Моздок, пл. 50 лет Октября, 43-А		0101000020E610000060E63BF88953464066F7E461A1E04540
89549	8	79	1592	28278	60620	\N	43.7470819823372	г. Моздок, ул. Юбилейная, 13	Россия, республика Северная Осетия-Алания, Моздокский район, Моздок	0101000020E6100000965D30B8E654464013B70A62A0DF4540
89557	8	79	1592	28278	60814	\N	43.754925	г. Моздок, ул. Элеваторная, 1		0101000020E610000060E63BF88953464066F7E461A1E04540
89547	8	79	1592	28278	60716	\N	43.754925	г. Моздок, ул. Чкалова, 2-Б		0101000020E610000060E63BF88953464066F7E461A1E04540
89552	8	79	1592	28278	60718	\N	43.754925	г. Моздок, ул. Фрунзе, 12		0101000020E610000060E63BF88953464066F7E461A1E04540
89553	8	79	1592	28278	60719	\N	43.754925	г. Моздок, ул. Первомайская, 130		0101000020E610000060E63BF88953464066F7E461A1E04540
89558	8	79	1592	28278	60686	\N	43.754925	г. Моздок, ул. Лебедева-Кумача, 58		0101000020E610000060E63BF88953464066F7E461A1E04540
89554	8	79	1592	28278	60715	\N	43.754925	г. Моздок, ул. Кирова, 110		0101000020E610000060E63BF88953464066F7E461A1E04540
89546	8	79	1592	28278	60715	\N	43.754925	г. Моздок, ул. Кирова, 41		0101000020E610000060E63BF88953464066F7E461A1E04540
89545	8	79	1592	28278	60715	\N	43.754925	г. Моздок, ул. Кирова, 20		0101000020E610000060E63BF88953464066F7E461A1E04540
89544	8	79	1592	28278	60715	\N	43.754925	г. Моздок, ул. Кирова, 7		0101000020E610000060E63BF88953464066F7E461A1E04540
89559	8	79	1592	28278	60681	\N	43.754925	г. Моздок, ул. Гастелло, 4		0101000020E610000060E63BF88953464066F7E461A1E04540
89555	8	79	1592	28278	60761	\N	43.754925	г. Моздок, ул. Вокзальная, 17		0101000020E610000060E63BF88953464066F7E461A1E04540
89578	8	79	1592	30322	60815	\N	43.617010000000001	с. Малгобек, ул. Советская, 33		0101000020E6100000E8F4BC1B0B3A464009A7052FFACE4540
89561	8	79	1592	47207	60762	\N	43.728014000000002	ст. Луковская, ул. Усанова, 35		0101000020E610000059198D7C5E514640DC8310902FDD4540
89560	8	79	1592	47207	60762	\N	43.728014000000002	ст. Луковская, ул. Усанова, 33		0101000020E610000059198D7C5E514640DC8310902FDD4540
89568	8	79	1592	19306	60745	\N	43.704838000000002	с. Кизляр, ул. Первомайская, 39		0101000020E61000009C4EB2D5E54A4640317DAF2138DA4540
89569	8	79	1592	19306	60629	\N	43.704838000000002	с. Кизляр, ул. Мира, 52		0101000020E61000009C4EB2D5E54A4640317DAF2138DA4540
88686	8	79	1592	19306	60629	\N	43.704838000000002	с. Кизляр, ул. Мира, 54		0101000020E61000009C4EB2D5E54A4640317DAF2138DA4540
89567	8	79	1592	29837	60741	\N	43.707118000000001	с. Киевское, ул. Кирова, 1		0101000020E6100000EDF0D7648D524640DB34B6D782DA4540
89565	8	79	1592	47299	60739	\N	43.726228999999996	пос. Калининский, ул. Береговая, 26		0101000020E6100000D26F5F07CE57464011346612F5DC4540
89583	8	79	1592	30567	60843	\N	43.805216999999999	с. Елбаево, ул. Бегиева, 1		0101000020E61000000874266DAA2E46407497C45911E74540
89576	8	79	1592	47519	60746	\N	43.697304000000003	с. Виноградное, ул. Советская, 3		0101000020E61000002619390B7B3E46405CAFE94141D94540
89564	8	79	1592	57698	60763	\N	43.7716999384037	с. Веселое, ул. Х. Хугаева, 2	Россия, республика Северная Осетия-Алания, Моздокский район, село Веселовское	0101000020E6100000978C63247B5C46405F29CB10C7E24540
32212	8	75	\N	28634	33002	\N	43.845865000000003	Республика Дагестан, город Кизляр, Мичурина, 6		0101000020E6100000F04C6892585A474060EAE74D45EC4540
89529	8	79	1834	55030	60742	\N	43.333549226827898	Республика Северная Осетия - Алания, Кировский муниципальный район, Дарг-Кохское сельское поселение, пер. Школьный, 1	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E610000013F1D6F9B7194640874ECFBBB1AA4540
89531	8	79	1834	55030	60740	\N	43.331627856628401	Республика Северная Осетия - Алания, Кировский муниципальный район, Карджинское сельское поселение, Чшиева, 68А	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E61000005C1FD61BB51A46400D384BC972AA4540
89530	8	79	1834	55030	41481	\N	43.340476420539197	Республика Северная Осетия - Алания, Кировский муниципальный район, Карджинское сельское поселение, Мира, 66	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E610000069C70DBF9B1A46405589B2B794AB4540
89538	8	79	1834	55030	60819	\N	43.334134019007301	Республика Северная Осетия - Алания, Кировский муниципальный район, Змейское сельское поселение, Ленина, 44	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E6100000247EC51A2E1A4640A73D25E7C4AA4540
89532	8	79	1834	55030	60826	\N	43.329372466190897	Республика Северная Осетия - Алания, Кировский муниципальный район, Эльхотовское сельское поселение, Ленина, 19	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E61000001497E315881A4640EB1B98DC28AA4540
89535	8	79	1834	55030	60732	\N	43.330875987604301	Республика Северная Осетия - Алания, Кировский муниципальный район, Эльхотовское сельское поселение, Зортова, 13	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E61000004E621058391A464002840F255AAA4540
89534	8	79	1834	55030	60645	\N	43.340816571558598	Республика Северная Осетия - Алания, Кировский муниципальный район, Эльхотовское сельское поселение, Бр. Бароевых, 5	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E61000009EB4705985194640DE7536E49FAB4540
89536	8	79	1834	55030	60723	\N	43.339396620974597	Республика Северная Осетия - Алания, Кировский муниципальный район, Эльхотовское сельское поселение, А.Карсанова, 1	Россия, республика Северная Осетия-Алания, Кировский район, село Эльхотово	0101000020E61000002C4833164D19464025AE635C71AB4540
89537	8	79	1834	32728	60839	\N	43.371844000000003	Республика Северная Осетия - Алания, Кировский муниципальный район, Комсомольское сельское поселение, Ленина, 46		0101000020E61000006458C51B992546405F9B8D9598AF4540
89542	8	79	1834	57728	60853	\N	43.308670705703399	Республика Северная Осетия - Алания, Кировский муниципальный район, Иранское сельское поселение, Плиева, 13Б		0101000020E610000076A911FA990A46409F1C058882A74540
89541	8	79	1834	57729	60854	\N	43.340505	Республика Северная Осетия - Алания, Кировский муниципальный район, Змейское сельское поселение, Таболова, 36А	Россия, республика Северная Осетия-Алания, Кировский район, село Змейская	0101000020E61000002A8C2D0439144640EF8FF7AA95AB4540
89539	8	79	1834	57729	60880	\N	43.332379716278403	Республика Северная Осетия - Алания, Кировский муниципальный район, Змейское сельское поселение, Ленина, 101	Россия, республика Северная Осетия-Алания, Кировский район, село Змейская	0101000020E610000079AF5A99F013464018EC866D8BAA4540
89540	8	79	1834	57729	75470	\N	43.338268959221203	Республика Северная Осетия - Алания, Кировский муниципальный район, Змейское сельское поселение, Бондаря, 49	Россия, республика Северная Осетия-Алания, Кировский район, село Змейская	0101000020E610000028B7ED7BD413464014200A664CAB4540
89520	8	79	1040	26067	60841	\N	43.189286936419897	Республика Северная Осетия - Алания, Ирафский муниципальный район, Лескенское сельское поселение, Хидирова, 22	Россия, республика Северная Осетия-Алания, Ирафский район, село Чикола	0101000020E6100000B0E2546B61F645406B47718E3A984540
89510	8	79	1040	26067	60807	\N	43.203081436567601	Республика Северная Осетия - Алания, Ирафский район, село Чикола, Хасцаева, 125	Россия, республика Северная Осетия-Алания, Ирафский район, село Чикола	0101000020E6100000034356B77AF6454030B8E68EFE994540
89509	8	79	1040	26067	60807	\N	43.195231999999997	Республика Северная Осетия - Алания, Ирафский район, село Чикола, Хасцаева, 75		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
89507	8	79	1040	26067	60809	\N	43.203520956305901	Республика Северная Осетия - Алания, Ирафский район, село Чикола, М.Будтуева, 97	Россия, республика Северная Осетия-Алания, Ирафский район, село Чикола	0101000020E6100000FE0A992B83F645404D86E3F90C9A4540
89504	8	79	1040	26067	60809	\N	43.195231999999997	село Чикола, М.Будтуева, 35		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
89496	8	79	1040	26067	60809	\N	43.195231999999997	Республика Северная Осетия - Алания, Ирафский район, село Чикола, М.Будтуева, 195		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
89505	8	79	1040	26067	60806	\N	43.195231999999997	Республика Северная Осетия - Алания, Ирафский район, село Чикола, ул.М.Баликоева, 67		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
89508	8	79	1040	26067	60787	\N	43.195231999999997	Республика Северная Осетия - Алания, Ирафский район, село Чикола, Ленина, 57		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
89484	8	79	1040	26067	60847	\N	43.195231999999997	Республика Северная Осетия - Алания, Ирафский район, село Чикола, Дедегкаева, 57		0101000020E6100000C16F438CD7F64540FB90B75CFD984540
63302	3	31	44	2358	58308	\N	58.215026000000002	Боровичский район ,д.Перелучи, Новая, 15		0101000020E610000084F1D3B8373F414015E5D2F8851B4D40
89517	8	79	1040	57706	\N	\N	43.206100985684799	Республика Северная Осетия - Алания, Ирафский муниципальный район, Хазнидонское сельское поселение, Здание Хазнидонской СОШ	Россия, республика Северная Осетия-Алания, Ирафский район, село Хазнидон	0101000020E6100000378AAC3594EC454021567F84619A4540
89518	8	79	1040	57722	\N	\N	43.2294214792567	Республика Северная Осетия - Алания, Ирафский муниципальный район, Толдзгунское сельское поселение, Здание АМС	Россия, республика Северная Осетия-Алания, Ирафский район, село Толдзгун	0101000020E6100000C4D155BABBE845400002D6AA5D9D4540
89513	8	79	1040	32560	\N	\N	43.171666000000002	Республика Северная Осетия - Алания, Ирафский муниципальный район, Сурх-Дигорское сельское поселение, Здание сельской амбулатории	Россия, республика Северная Осетия-Алания, Ирафский район, село Сурх-Дигора	0101000020E61000000796236420FF4540E6EAC726F9954540
89512	8	79	1040	32560	\N	\N	43.171188372342499	Республика Северная Осетия - Алания, Ирафский муниципальный район, Сурх-Дигорское сельское поселение, Здание СДК	Россия, республика Северная Осетия-Алания, Ирафский район, село Сурх-Дигора	0101000020E610000085950A2AAAFE4540DCBB067DE9954540
89528	8	79	1040	57718	\N	\N	42.904996167911001	Республика Северная Осетия - Алания, Ирафский муниципальный район, Стур-Дигорское сельское поселение, Здание АМС	Россия, республика Северная Осетия-Алания, Ирафский район, село Стур-Дигора	0101000020E6100000A7406667D1D345406281AFE8D6734540
89516	8	79	1040	57715	\N	\N	43.2691504038118	Республика Северная Осетия - Алания, Ирафский муниципальный район, Средне-Урухское сельское поселение, Здание СДК	Россия, республика Северная Осетия-Алания, Ирафский район, село Средний Урух	0101000020E6100000AAF1D24D62FE4540F5DBD78173A24540
89511	8	79	1040	52154	\N	\N	43.190785609733503	Республика Северная Осетия - Алания, Ирафский муниципальный район, Советское сельское поселение, здание АМС	Россия, республика Северная Осетия-Алания, Ирафский район, село Советский	0101000020E61000001D1F2DCE18F245407044F7AC6B984540
89591	8	79	1040	52154	60651	\N	43.1922989599312	Республика Северная Осетия - Алания, Правобережный муниципальный район, Брутское сельское поселение, Советская, 68	Россия, республика Северная Осетия-Алания, Ирафский район, село Советский	0101000020E61000003E92921E86F24540D906EE409D984540
89515	8	79	1040	57732	\N	\N	43.236864382702898	Республика Северная Осетия - Алания, Ирафский муниципальный район, Ново-Урухское сельское поселение, Здание СДК	Россия, республика Северная Осетия-Алания, Ирафский район, село Новый Урух	0101000020E6100000A4A99ECC3FF84540C4CC3E8F519E4540
89525	8	79	1040	27946	\N	\N	42.980527000000002	Республика Северная Осетия - Алания, Ирафский муниципальный район, Задалеское сельское поселение, село Мацута, Здание АМС	Россия, республика Северная Осетия-Алания, Ирафский район, село Мацута	0101000020E610000031074147ABE2454029ECA2E8817D4540
89524	8	79	1040	57720	\N	\N	42.961683036768001	Республика Северная Осетия - Алания, Ирафский муниципальный район, Махческое сельское поселение, Здание АМС	Россия, республика Северная Осетия-Алания, Ирафский район, село Махческ	0101000020E610000006BCCCB051E44540410FB56D187B4540
89519	8	79	1040	32596	60810	\N	43.274541999999997	Республика Северная Осетия - Алания, Ирафский муниципальный район, Лескенское сельское поселение, Тубеева,70		0101000020E6100000849A215514E9454070B0373124A34540
89523	8	79	1040	27801	\N	\N	42.909286000000002	Республика Северная Осетия - Алания, Ирафский муниципальный район, Галиатское сельское поселение, село Камунта, Здание АМС	Россия, республика Северная Осетия-Алания, Ирафский район, село Камунта	0101000020E6100000225514AFB2EC4540F75AD07B63744540
89527	8	79	1040	28022	\N	\N	42.900820000000003	Республика Северная Осетия - Алания, Ирафский район, село Дзинага, село Ахсау, Здание СДК	Россия, республика Северная Осетия-Алания, Ирафский район, село Дзинага	0101000020E6100000A5DB12B9E0DA454097CADB114E734540
89514	8	79	1040	57716	\N	\N	43.228559361209697	Республика Северная Осетия - Алания, Ирафский муниципальный район, Ново-Урухское сельское поселение, село Дзагебарз, Здание  СДК	Россия, республика Северная Осетия-Алания, Ирафский район, село Дзагепбарз	0101000020E6100000BFF38B12F4F745406D1ADB6B419D4540
89526	8	79	1040	27947	\N	\N	42.956778	Республика Северная Осетия - Алания, Ирафский муниципальный район, Гуларское сельское поселение, село Ахсау, Здание АМС	Россия, республика Северная Осетия-Алания, Ирафский район, село Ахсау	0101000020E61000006440F67AF7DB454022C495B3777A4540
89522	8	79	1040	57726	\N	\N	43.140397872316697	Республика Северная Осетия - Алания, Ирафский муниципальный район, Ахсарисарское сельское поселение, Здание Ахсарисарской СОШ	Россия, республика Северная Осетия-Алания, Ирафский район, село Ахсарисар	0101000020E6100000F180B22957E845403F36C98FF8914540
89498	8	79	1061	33098	60838	\N	43.125321	Республика Северная Осетия - Алания, Дигорский муниципальный район, Дур-Дурское сельское поселение, Ул. Маяковского, 45		0101000020E61000009AEB34D2520346404240BE840A904540
38910	8	78	\N	188	61529	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Ленина, 71		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
89492	8	79	1061	26265	60670	\N	43.155760220158101	Республика Северная Осетия - Алания, Дигорский муниципальный район, Дигорское городское поселение, Ул. Сталина, 20	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E6100000B9533A58FF134640320395F1EF934540
89491	8	79	1061	26265	60670	\N	43.162758866402001	Республика Северная Осетия - Алания, Дигорский муниципальный район, Дигорское городское поселение, Ул. Сталина, 32	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E610000023BC3D080115464099107349D5944540
89494	8	79	1061	26265	60824	\N	43.145453947216097	Республика Северная Осетия - Алания, Дигорский муниципальный район, Карман-Синдзикауское сельское поселение, Ул. Плиева, 128	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E6100000338AE596561346404489963C9E924540
89500	8	79	1061	26265	60692	\N	43.1670725451756	Республика Северная Осетия - Алания, Дигорский муниципальный район, Николаевское сельское поселение, Ул. Партизанская, 15	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E61000008F37F92D3A154640B685E7A562954540
89495	8	79	1061	26265	60829	\N	43.166064742760199	Республика Северная Осетия - Алания, Дигорский муниципальный район, Кора-Урсдонское сельское поселение, Ул. Мира, 45	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E6100000B189CC5CE01446405001309E41954540
89499	8	79	1061	26265	60851	\N	43.146710903481299	Республика Северная Осетия - Алания, Дигорский муниципальный район, Мостиздахское сельское поселение, Ул. Ленина, 35	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E610000059F8FA5A97124640537B116DC7924540
89489	8	79	1061	26265	60621	\N	43.156542000000002	г. Дигора, Ул. Кокиева, 7		0101000020E6100000F22213F06B144640A839799109944540
89490	8	79	1061	26265	60712	\N	43.157268308407403	Республика Северная Осетия - Алания, Дигорский муниципальный район, Дигорское городское поселение, Ул. Кесаева, 32	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E6100000DD9733DB151446408A5A9A5B21944540
89502	8	79	1061	26265	60613	\N	43.156765616489302	Республика Северная Осетия - Алания, Дигорский муниципальный район, Дигорское городское поселение, Ул. Калицова, 79	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E61000006901DA56B3144640F78F85E810944540
89501	8	79	1061	26265	60714	\N	43.154754807166903	Республика Северная Осетия - Алания, Дигорский муниципальный район, Дигорское городское поселение, Ул. К. Маркса, 25	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E610000003CE52B29C1446403DF20703CF934540
89497	8	79	1061	26265	60828	\N	43.143694164713096	Республика Северная Осетия - Алания, Дигорский муниципальный район, Дур-Дурское сельское поселение, Ул. Дзотова, 30	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E610000059F8FA5A97124640D350A39064924540
89493	8	79	1061	26265	60827	\N	43.143694164713096	Республика Северная Осетия - Алания, Дигорский муниципальный район, Карман-Синдзикауское сельское поселение, Ул. Бр. Тахоховых, 32	Россия, республика Северная Осетия-Алания, Дигорский район, Дигора	0101000020E6100000C93A1C5DA5134640D350A39064924540
89721	8	79	628	57703	\N	\N	42.8562303349063	Республика Северная Осетия - Алания, город Владикавказ, с. Чми, Средняя школа с. Чми	Россия, республика Северная Осетия-Алания, Владикавказ городской округ	0101000020E610000076A911FA9950464052EDD3F1986D4540
89693	8	79	628	52304	60705	\N	43.096896458771702	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, поселок Заводской, ул. Эльхотовская, 40	Россия, республика Северная Осетия-Алания, Владикавказ городской округ, поселок городского типа Заводской	0101000020E61000008DB7955E9B5346407E8E8F16678C4540
89696	8	79	628	52304	60775	\N	43.098008	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, поселок Заводской, Остаева, 5		0101000020E61000009087BEBB95534640895FB1868B8C4540
89694	8	79	628	52304	60649	\N	43.098008	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, поселок Заводской, ул. Бульварная, 73		0101000020E61000009087BEBB95534640895FB1868B8C4540
89722	8	79	628	57701	\N	\N	42.924959013305298	Республика Северная Осетия - Алания, г. Владикавказ, с. Балта, Средняя школа с. Балта		0101000020E61000001092054CE05046400892770E65764540
89479	8	79	1777	25843	\N	\N	43.262608	Республика Северная Осетия - Алания, Ардонский муниципальный район, Ардонское городское поселение, поселок Бекан, Беканская, б/н	Россия, республика Северная Осетия-Алания, Ардонский район, село Бекан	0101000020E610000059350873BB21464080D591239DA14540
89488	8	79	1777	33055	60850	\N	43.1677135640793	Республика Северная Осетия - Алания, Ардонский муниципальный район, Рассветское сельское поселение, Хетагурова, 50	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E61000002BF86D88F1264640698A00A777954540
89474	8	79	1777	33055	60736	\N	43.176759748439601	Республика Северная Осетия - Алания, Ардонский муниципальный район, Ардонское городское поселение, ул. Тогузова, 50	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E6100000A4E2FF8EA8244640D89E5912A0964540
89477	8	79	1777	33055	60668	\N	43.183794736615901	Республика Северная Осетия - Алания, Ардонский муниципальный район, Ардонское городское поселение, Советов, 5	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E6100000B3EBDE8AC42646408C15359886974540
89478	8	79	1777	33055	60609	\N	43.175014853915499	Республика Северная Осетия - Алания, Ардонский муниципальный район, Ардонское городское поселение, Пролетарская, 83	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E61000007E74EACA672546409CA73AE466964540
89485	8	79	1777	33055	60767	\N	43.1845484369288	Республика Северная Осетия - Алания, Ардонский муниципальный район, Костаевское сельское поселение, Мамиева, 51	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E6100000B3EBDE8AC42646406745D4449F974540
89486	8	79	1777	33055	60610	\N	43.171416000000001	Республика Северная Осетия - Алания, Ардонский муниципальный район, Нартское сельское поселение, Ленина, 38		0101000020E610000094F947DFA42546406D01A1F5F0954540
89482	8	79	1777	33055	60610	\N	43.186307034546502	Республика Северная Осетия - Алания, Ардонский муниципальный район, Мичуринское сельское поселение, Ленина, 24	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E6100000D72FD80DDB264640080264E8D8974540
89480	8	79	1777	33055	60610	\N	43.183292264534202	Республика Северная Осетия - Алания, Ардонский муниципальный район, Красногорское сельское поселение, Ленина, 37	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E6100000C4D2C08F6A26464029CFBC1C76974540
89476	8	79	1777	33055	60666	\N	43.1822873078751	Республика Северная Осетия - Алания, Ардонский муниципальный район, Ардонское городское поселение, Кирова, 180	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E6100000D72FD80DDB26464034BE2F2E55974540
89475	8	79	1777	33055	60608	\N	43.182915407739401	Республика Северная Осетия - Алания, Ардонский муниципальный район, Ардонское городское поселение, ул. Зангиева, 90	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E610000015713AC95627464053793BC269974540
89487	8	79	1777	33055	60848	\N	43.170854753253302	Республика Северная Осетия - Алания, Ардонский муниципальный район, Фиагдонское сельское поселение, Бритаева, 27	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E61000008FA7E507AE264640D6AD9E93DE954540
89481	8	79	1777	33055	60748	\N	43.1822873078751	Республика Северная Осетия - Алания, Ардонский муниципальный район, Кадгаронское сельское поселение, Абациевых, 6	Россия, республика Северная Осетия-Алания, Ардонский район, Ардон	0101000020E61000001CEF8E8CD524464034BE2F2E55974540
89471	8	79	754	57723	\N	\N	42.803382150537402	Республика Северная Осетия - Алания, Алагирский муниципальный район, Цейское сельское поселение, Здание АМС с.Цей	Россия, республика Северная Осетия-Алания, Алагирский район, село Нижний Цей	0101000020E61000008F1B7E37DDF84540F818AC38D5664540
89455	8	79	754	57714	60842	\N	43.068553162485898	Республика Северная Осетия - Алания, Алагирский муниципальный район, Ногкауское сельское поселение, село Цаликова, Комсомольская, 24	Россия, республика Северная Осетия-Алания, Алагирский район, село Цаликово	0101000020E6100000CD0182397A22464077853E58C6884540
89457	8	79	754	32899	60805	\N	43.033349000000001	Республика Северная Осетия - Алания, Алагирский муниципальный район, Хаталдонское сельское поселение, Кцоева, 50		0101000020E61000008A3C49BA662E46405A2DB0C744844540
89449	8	79	754	32836	\N	\N	43.124288	Республика Северная Осетия - Алания, Алагирский муниципальный район, Рамоновское сельское поселение, ДК с.Рамоново		0101000020E61000003D44A33B8821464083A44FABE88F4540
89466	8	79	754	25178	\N	\N	42.826872999999999	Республика Северная Осетия - Алания, Алагирский муниципальный район, Мизурское сельское поселение, поселок Нузал, Здание конторы СМУ	Россия, республика Северная Осетия-Алания, Алагирский район, поселок Нузал	0101000020E6100000CB13083BC5024640037976F9D6694540
89463	8	79	754	57727	\N	\N	42.860650599378502	Республика Северная Осетия - Алания, Алагирский муниципальный район, Унальское сельское поселение, ДК с.Унал	Россия, республика Северная Осетия-Алания, Алагирский район, село Нижний Унал	0101000020E61000006ABFB513251346408522DDCF296E4540
89472	8	79	754	57735	\N	\N	42.695942736193601	Республика Северная Осетия - Алания, Алагирский муниципальный район, Зарамагское сельское поселение, Здание АМС с.Зарамаг	Россия, республика Северная Осетия-Алания, Алагирский район, поселок Нижний Зарамах	0101000020E61000007FF5B86FB5FC4540A87004A914594540
89453	8	79	754	24580	\N	\N	43.034792000000003	Республика Северная Осетия - Алания, Алагирский муниципальный район, Бирагзангское сельское поселение, село Нижний Бирагзанг, Новая, 17	Россия, республика Северная Осетия-Алания, Алагирский район, село Нижний Бирагзанг	0101000020E6100000D13DEB1A2D1F4640CB14731074844540
89473	8	79	754	57709	\N	\N	42.6794319227686	Республика Северная Осетия - Алания, Алагирский муниципальный район, Нарское сельское поселение, Здание АМС с.Нар		0101000020E6100000DBBE47FDF50246408DEDB5A0F7564540
89465	8	79	754	32954	\N	\N	42.849528999999997	Республика Северная Осетия - Алания, Алагирский муниципальный район, Мизурское сельское поселение, ДК п.Мизур		0101000020E61000005CE84A04AA0746407500C45DBD6C4540
89464	8	79	754	32954	\N	\N	42.849528999999997	Республика Северная Осетия - Алания, Алагирский муниципальный район, Мизурское сельское поселение, поселок Мизур1, Нач.школа при д/с п.Мизур		0101000020E61000005CE84A04AA0746407500C45DBD6C4540
89459	8	79	754	32913	60833	\N	43.019238000000001	Республика Северная Осетия - Алания, Алагирский муниципальный район, Майрамадагское сельское поселение, Дзуцева, 32	Россия, республика Северная Осетия-Алания, Алагирский район, село Майрамадаг	0101000020E61000003509DE90463D4640946B0A6476824540
89716	8	79	754	5321	60779	\N	42.923461000000003	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, поселок Карца, ул. Карцинская, 82		0101000020E610000002F566D47C254640D41055F833764540
89717	8	79	754	5321	60725	\N	42.923461000000003	Республика Северная Осетия - Алания, городской округ город Владикавказ, Промышленный муниципальный округ, поселок Карца, ул. Дружбы, 66		0101000020E610000002F566D47C254640D41055F833764540
89462	8	79	754	25002	\N	\N	42.883778	Республика Северная Осетия - Алания, Алагирский муниципальный район, Унальское сельское поселение, село Зинцар, ДК с.Зинцар		0101000020E6100000D76D50FBAD1546404F7633A31F714540
89458	8	79	754	57711	60836	\N	42.844926323180701	Республика Северная Осетия - Алания, Алагирский муниципальный район, Дзуарикауское сельское поселение, Бр.Газдановых, 15	Россия, республика Северная Осетия-Алания, Алагирский район, поселок Дзуарикау	0101000020E6100000D3669C86A82A464022C50089266C4540
89461	8	79	754	57694	\N	\N	42.835261279834498	Республика Северная Осетия - Алания, Алагирский муниципальный район, Фиагдонское сельское поселение, ДК п.В.Фиагдон	Россия, республика Северная Осетия-Алания, Алагирский район, поселок городского типа Верхний Фиагдон	0101000020E61000005C3CBCE7C0264640E84F1BD5E96A4540
89470	8	79	754	32981	\N	\N	42.791857999999998	Республика Северная Осетия - Алания, Алагирский муниципальный район, Буронское сельское поселение, ДК п.Бурон		0101000020E6100000C3633F8BA5004640B9895A9A5B654540
89469	8	79	754	32857	\N	\N	43.049407246805202	Республика Северная Осетия - Алания, Алагирский муниципальный район, Згидское сельское поселение, Административное здание	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E610000047E7FC14C71D4640C498F4F752864540
89467	8	79	754	32857	\N	\N	43.038663234474697	Республика Северная Осетия - Алания, Алагирский муниципальный район, Садонское сельское поселение, Рудоуправление	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E6100000AFEAAC16D81B46405A48C0E8F2844540
89460	8	79	754	32857	\N	\N	43.033626311610099	Республика Северная Осетия - Алания, Алагирский муниципальный район, Горно-Карцинское сельское поселение, Здание АМС с.Г.Карца	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E6100000C571E0D5721B4640CC2555DB4D844540
89454	8	79	754	32857	60813	\N	43.033059000000002	Республика Северная Осетия - Алания, Алагирский муниципальный район, Ногкауское сельское поселение, Цаликова, 73		0101000020E6100000A4AB74779D1B464053EBFD463B844540
89444	8	79	754	32857	60615	\N	43.038915074490497	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, Сталина, 74	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E61000008BA6B393C11B46407429AE2AFB844540
89456	8	79	754	\N	60632	\N	42.842356249292401	Республика Северная Осетия - Алания, Алагирский муниципальный район, Суадагское сельское поселение, Ленина, 23	Россия, республика Северная Осетия-Алания, Алагирский район	0101000020E6100000CE37A27BD60F464071CB4752D26B4540
89450	8	79	754	32857	60632	\N	43.040593913118897	Республика Северная Осетия - Алания, Алагирский муниципальный район, Црауское сельское поселение, Ленина, 63	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E6100000B58AFED0CC1B4640F834272F32854540
89445	8	79	754	32857	60611	\N	43.032408961390502	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, ЛЕНИНА, 109	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E61000006762BA10AB1B46404C8C65FA25844540
89442	8	79	754	32857	60667	\N	43.043112138587098	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, Л.Толстого, 69	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E610000051DB8651101C46405708ABB184854540
89446	8	79	754	32857	60710	\N	43.036060844937602	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, Комсомольская, 78	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E6100000392A37514B1D46409DD497A59D844540
89452	8	79	754	32857	60832	\N	43.032660822455099	Республика Северная Осетия - Алания, Алагирский муниципальный район, Бирагзангское сельское поселение, Кирова, 80	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E6100000ED2B0FD2531C4640656D533C2E844540
89448	8	79	754	32857	60711	\N	43.039082927868598	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, Калаева, 2	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E610000051DB8651101C46402F6AF7AB00854540
89447	8	79	754	32857	60711	\N	43.034297894000098	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, Калаева, 7	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E6100000B58AFED0CC1B4640BB287AE063844540
89443	8	79	754	32857	60616	\N	43.035389281979	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, К.Хетагурова, 138	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E61000008BA6B393C11B4640AFD172A087844540
89441	8	79	754	32857	60616	\N	43.043615771188399	Республика Северная Осетия - Алания, Алагирский муниципальный район, Алагирское городское поселение, К.Хетагурова, 231	Россия, республика Северная Осетия-Алания, Алагирский район, Алагир	0101000020E6100000FF5E0A0F9A1D46408ACA863595854540
89451	8	79	754	32857	60846	\N	43.049910827354601	Республика Северная Осетия - Алания, Алагирский муниципальный район, Красноходское сельское поселение, Алагирская, 4а		0101000020E61000006B2BF697DD1D4640F75AD07B63864540
38927	8	78	\N	57861	61594	\N	44.224898758798503	Карачаево-Черкесская Республика, город Черкесск, Космонавтов, 3	Россия, республика Карачаево-Черкесская, Черкесск городской округ	0101000020E6100000C4E9245B5D08454099F38C7DC91C4640
38931	8	78	\N	188	\N	\N	44.215609192265397	Карачаево-Черкесская Республика, город Черкесск, пос. Юбилейный, СОШ №12	Россия, республика Карачаево-Черкесская, Черкесск городской округ	0101000020E6100000ED0BE8853B09454094DC6113991B4640
38928	8	78	\N	188	\N	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Доватора, 70	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38923	8	78	\N	188	61533	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Фабричная, 139	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38914	8	78	\N	188	61587	\N	44.220087912987701	Карачаево-Черкесская Республика, город Черкесск, Тургеневская, 75		0101000020E61000000DE198654F064540FB1EF5D72B1C4640
94956	8	78	\N	188	61566	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Тихая,29		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38919	8	78	\N	188	61676	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Строителей, 3		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38922	8	78	\N	188	61584	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Ставропольская, 36		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38918	8	78	\N	188	61584	\N	44.214100294062099	Карачаево-Черкесская Республика, город Черкесск, Ставропольская, 35		0101000020E6100000E5B8533A580545406C09F9A0671B4640
38917	8	78	\N	188	61584	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Ставропольская, 117		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38916	8	78	\N	188	61584	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Ставропольская, 107		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38913	8	78	\N	188	61584	\N	44.217368459335503	Карачаево-Черкесская Республика, город Черкесск, Ставропольская, 41	Россия, республика Карачаево-Черкесская, Черкесск городской округ	0101000020E610000070287CB60E0645403599F1B6D21B4640
94957	8	78	\N	188	61689	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Советская,27		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38906	8	78	\N	188	61530	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Подгорная, 124	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38904	8	78	\N	188	61530	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Подгорная, 7	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38907	8	78	7452	\N	61531	\N	44.225241712493599	Карачаево-Черкесская Республика, город Черкесск, Первомайская, 26	Россия, республика Карачаево-Черкесская, Черкесск городской округ	0101000020E6100000F833BC5983074540C3D7D7BAD41C4640
38903	8	78	\N	188	61531	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Первомайская, 99		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38929	8	78	\N	188	61534	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Парковая, 15	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38926	8	78	\N	188	61534	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Парковая, 1а		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38905	8	78	\N	188	61577	\N	44.219162032606597	Карачаево-Черкесская Республика, город Черкесск, Октябрьская, 186	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E61000006D7022FAB507454052431B800D1C4640
38890	8	78	\N	188	61577	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Октябрьская, 56		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38888	8	78	\N	188	61577	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Октябрьская, 3		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38891	8	78	\N	188	61640	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Международная, 8	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38912	8	78	\N	188	61667	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Леонова, 1		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38932	8	78	\N	188	61529	\N	44.202181463632797	Карачаево-Черкесская Республика, город Черкесск, Ленина, 387	Россия, республика Карачаево-Черкесская, Черкесск городской округ	0101000020E6100000FBEB1516DC054540B16F2711E1194640
38889	8	78	\N	188	61527	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Крупской, 84	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38886	8	78	\N	188	61527	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Крупской, 29		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38909	8	78	\N	188	61657	\N	44.219779287822902	Карачаево-Черкесская Республика, город Черкесск, Красноармейская, 66	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E61000009816F549EE0645407EACE0B7211C4640
38900	8	78	\N	188	61657	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Красноармейская, 49		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38898	8	78	\N	188	61657	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Красноармейская, 50		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38921	8	78	\N	188	61532	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Кочубея, 172		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38920	8	78	\N	188	61532	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Кочубея, 28	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38934	8	78	\N	188	61600	\N	44.219347209855599	Карачаево-Черкесская Республика, город Черкесск, Космонавтов, 30	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000310917F208084540E4BCFF8F131C4640
38930	8	78	\N	188	61600	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Космонавтов, 31, СОШ №17		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
94958	8	78	\N	188	61681	\N	44.223911233793999	Карачаево-Черкесская Республика, город Черкесск, Кирова, 19	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E61000002E39EE940E0845407A1B9B1DA91C4640
38887	8	78	\N	188	61694	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Карла Маркса, 160а		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38901	8	78	\N	188	61582	\N	44.2214423483071	Карачаево-Черкесская Республика, город Черкесск, Кавказская, 58	Россия, республика Карачаево-Черкесская, Черкесск городской округ	0101000020E610000030BDFDB968064540FDFA2136581C4640
38895	8	78	\N	188	61582	\N	44.231351616710299	Карачаево-Черкесская Республика, город Черкесск, Кавказская, 126		0101000020E610000054E0641BB80745409EEE3CF19C1D4640
38933	8	78	\N	188	61535	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Доватора, 84	Россия, республика Карачаево-Черкесская, Черкесск	0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38925	8	78	\N	188	61535	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Доватора, 64		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38924	8	78	\N	188	61535	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Доватора, 19		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38885	8	78	\N	188	61631	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Демиденко, 157		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38884	8	78	\N	188	61654	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Гутякулова, 2		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38899	8	78	\N	188	61693	\N	44.224898758798503	Карачаево-Черкесская Республика, город Черкесск, Горького, 5		0101000020E61000003C50A73CBA07454099F38C7DC91C4640
38897	8	78	\N	188	61693	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Горького, 1		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38911	8	78	\N	188	61664	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Ворошилова, 1		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38894	8	78	\N	188	61690	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Балахонова, 73		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
38892	8	78	\N	188	61732	\N	44.219841000000002	Карачаево-Черкесская Республика, город Черкесск, Кавказская, 17		0101000020E6100000F697DD9387074540F4A8F8BF231C4640
39118	8	78	\N	57856	61560	\N	44.042764244207397	Карачаево-Черкесская Республика, Хабезский муниципальный район, Хабезское сельское поселение, аул Хабез, Хабекова, 95	Россия, республика Карачаево-Черкесская, Хабезский район, Хабез	0101000020E6100000D2A755F487E244401BB96E4A79054640
39093	8	78	\N	57854	61624	\N	44.082881591279602	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, м-н Московский, Гимназия №6	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E6100000B8CEBF5DF6FB4440AAB69BE09B0A4640
39092	8	78	\N	57854	61624	\N	44.099212876781699	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, м-н Московский, МДШИ	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E610000038F8C264AAFC4440452BF702B30C4640
39091	8	78	\N	57854	61624	\N	44.0967387314655	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, м-н Московский, ДК	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E610000014B4C9E193FC4440B69F8CF1610C4640
39090	8	78	\N	57854	61624	\N	44.082634112638502	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, м-н Московский, Гимназия №4	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E61000006AA67B9DD4FB4440D2C43BC0930A4640
32219	8	75	\N	28634	33076	\N	43.845865000000003	Республика Дагестан, город Кизляр, Махачкалинская, ЦГСЭН		0101000020E6100000F04C6892585A474060EAE74D45EC4540
39101	8	78	\N	57854	61718	\N	44.0831290688783	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Школьная, филиал МОУ СОШ №2	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E61000002A3BFDA02EFC4440B22C98F8A30A4640
39100	8	78	\N	57854	61717	\N	44.107376816715501	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Первомайская, МОУ СОШ №2	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E6100000F10EF0A485FF4440DAAB8F87BE0D4640
39099	8	78	\N	57854	61699	\N	44.095501619716003	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Морозова, ЦКиД	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E61000003D98141F9FFC4440EF59D768390C4640
39102	8	78	\N	57854	61556	\N	44.095501619716003	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Курортная, 58, здание Лесничества	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E61000006614CB2DADFC4440EF59D768390C4640
39096	8	78	\N	57854	61556	\N	44.083624020948399	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Курортная, ООО""Триз"""	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E61000002A3BFDA02EFC44409294F430B40A4640
39095	8	78	\N	57854	61715	\N	44.074219218598699	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Коммунистическая, МОУ СОШ №3	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E6100000C8B5A1629CFB4440F4DE180280094640
39097	8	78	\N	57854	61716	\N	44.085603787531703	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Богатырева, МКОУ ""Лицей №1 г.Усть-Джегуты"""	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E6100000DC12B9E00CFC444011346612F50A4640
39094	8	78	\N	57854	61714	\N	44.082634112638502	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Балахонова, МОУ СОШ №5	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E610000006F7031E18FC4440D2C43BC0930A4640
38950	8	78	\N	57851	61537	\N	43.450620999999998	Карачаево-Черкесская Республика, Карачаевский городской округ, город Теберда, Тебердинская, 4	Россия, республика Карачаево-Черкесская, Карачаевский район, Теберда	0101000020E61000004FCE50DCF1DE444006F2ECF2ADB94540
38952	8	78	\N	57851	61744	\N	43.450620999999998	Карачаево-Черкесская Республика, Карачаевский городской округ, город Теберда, Орджоникидзе, 24		0101000020E61000004FCE50DCF1DE444006F2ECF2ADB94540
38938	8	78	\N	3363	61695	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Эркенова, 5		0101000020E61000006F7F2E1A32F64440338B506C05E34540
38951	8	78	\N	3363	61719	\N	43.450620999999998	Карачаево-Черкесская Республика, Карачаевский городской округ, город Теберда, Советская, 2		0101000020E61000004FCE50DCF1DE444006F2ECF2ADB94540
38947	8	78	\N	3363	61719	\N	43.8425364194498	Карачаево-Черкесская Республика, Карачаевский городской округ, рабочий поселок Орджоникидзевский, Советская, 56		0101000020E6100000DFA63FFB91F24440F1D93A38D8EB4540
38945	8	78	\N	3363	61733	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Речной, 1		0101000020E61000006F7F2E1A32F64440338B506C05E34540
38944	8	78	\N	3363	61746	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Пушкина, 52		0101000020E61000006F7F2E1A32F64440338B506C05E34540
38953	8	78	\N	3363	61756	\N	43.283392099211603	Карачаево-Черкесская Республика, Карачаевский городской округ, курортный поселок Домбай, Пихтовый Мыс, 2	Россия, республика Карачаево-Черкесская, Карачаевский район	0101000020E6100000CA501553E9CF444059F9653046A44540
38937	8	78	\N	3363	61688	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Мира, 13		0101000020E61000006F7F2E1A32F64440338B506C05E34540
38936	8	78	\N	3363	61688	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Мира, 31		0101000020E61000006F7F2E1A32F64440338B506C05E34540
38940	8	78	\N	3363	9872	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Магометова, 8		0101000020E61000006F7F2E1A32F64440338B506C05E34540
39020	8	78	\N	3363	61536	\N	43.766782095575302	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Верхне-Тебердинское сельское поселение, Ленина, 3а	Россия, республика Карачаево-Черкесская, Карачаевск	0101000020E6100000EB1F4432E4F44440AB949EE925E24540
38943	8	78	\N	3363	61536	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Ленина, 45 А	Россия, республика Карачаево-Черкесская, Карачаевск	0101000020E61000006F7F2E1A32F64440338B506C05E34540
38939	8	78	\N	3363	61536	\N	43.773603000000001	Карачаево-Черкесская Республика, Карачаевский городской округ, город Карачаевск, Ленина, 27		0101000020E61000006F7F2E1A32F64440338B506C05E34540
39026	8	78	\N	3363	61761	\N	43.781708571667401	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Хумаринское сельское поселение, Курортная, 75	Россия, республика Карачаево-Черкесская, Карачаевск	0101000020E610000039EE940ED6F5444093FE5E0A0FE44540
39016	8	78	\N	3363	61745	\N	43.772442159340699	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Каменномостское сельское поселение, Курджиева, 38	Россия, республика Карачаево-Черкесская, Карачаевск	0101000020E610000061C43E0114F5444046072461DFE24540
39021	8	78	\N	3363	61760	\N	43.771695808179402	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Коста Хетагуровское сельское поселение, Колиева, 14а	Россия, республика Карачаево-Черкесская, Карачаевск	0101000020E6100000384888F205F544401D3A3DEFC6E24540
38946	8	78	\N	3363	61692	\N	43.779576725265201	Карачаево-Черкесская Республика, Карачаевский городской округ, поселок Мара-Аягъы, Калинина, 2	Россия, республика Карачаево-Черкесская, Карачаевск	0101000020E61000000DFAD2DB9FF544405EDBDB2DC9E34540
39023	8	78	\N	3363	61777	\N	43.772877526519999	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Верхне-Маринское сельское поселение, Гагарина, 132а	Россия, республика Карачаево-Черкесская, Карачаевск	0101000020E61000005F5CAAD216F5444021E692AAEDE24540
38955	8	78	645	4338	62382	\N	44.083586077992898	Карачаево-Черкесская Республика, Абазинский муниципальный район, Эльбурганское сельское поселение, аул Эльбурган, ул. Ленина, 30	Россия, республика Карачаево-Черкесская, Хабезский район, село Эльбурган	0101000020E6100000121615713AE74440A43330F2B20A4640
39119	8	78	645	57870	61682	\N	44.049078904868502	Карачаево-Черкесская Республика, Хабезский муниципальный район, Хабезское сельское поселение, аул Хабез, Советская, 42	Россия, республика Карачаево-Черкесская, Хабезский район, Хабез	0101000020E6100000473EAF78EAE14440CFF57D3848064640
39126	8	78	645	57871	61683	\N	44.216247463176302	Карачаево-Черкесская Республика, Хабезский муниципальный район, Псаучье-Дахское сельское поселение, аул Псаучье-Дахе, Школьная, 1	Россия, республика Карачаево-Черкесская, Хабезский район, село Псаучье-Дахе	0101000020E61000001C40BFEFDFF04440D76D50FBAD1B4640
39124	8	78	645	57962	62484	\N	44.222157829512	Карачаево-Черкесская Республика, Хабезский муниципальный район, Бавуковское сельское поселение, аул Новохумаринский, Хапсирокова, 34	Россия, республика Карачаево-Черкесская, Хабезский район, село Новохумаринский	0101000020E6100000A0C6BDF90DF34440BB4560AC6F1C4640
39122	8	78	645	57857	61561	\N	44.1587960605681	Карачаево-Черкесская Республика, Хабезский муниципальный район, Мало-Зеленчукское сельское поселение, аул Малый Зеленчук, Калмыкова, 10	Россия, республика Карачаево-Черкесская, Хабезский район, село Малый Зеленчук	0101000020E61000002CD7DB662AEE4440295E656D53144640
39127	8	78	645	57988	62561	\N	44.182641967081402	Карачаево-Черкесская Республика, Хабезский муниципальный район, Псаучье-Дахское сельское поселение, аул Кызыл-Юрт, Булатукова, 4	Россия, республика Карачаево-Черкесская, Хабезский район, село Кызыл-Юрт	0101000020E610000074435376FAEF4440227024D060174640
39121	8	78	645	57867	61643	\N	44.1434708558876	Карачаево-Черкесская Республика, Хабезский муниципальный район, Кош-Хабльское сельское поселение, аул Кош-Хабль, хАБЕКОВА, 14	Россия, республика Карачаево-Черкесская, Хабезский район, село Кош-Хабль	0101000020E6100000570A815CE2EC44405376FA415D124640
39129	8	78	645	4266	61753	\N	44.060483695596297	Карачаево-Черкесская Республика, Хабезский муниципальный район, Инжичишховское сельское поселение, аул Инжичишхо, С.Дерева, 47	Россия, республика Карачаево-Черкесская, Хабезский район, село Инжич-Чукун	0101000020E6100000765089EB18E5444034F790F0BD074640
38954	8	78	645	4266	62411	\N	44.053633953517	Карачаево-Черкесская Республика, Абазинский муниципальный район, Инжич-Чукунское сельское поселение, аул Инжич-Чукун, ул. Ленина, 50	Россия, республика Карачаево-Черкесская, Хабезский район, село Инжич-Чукун	0101000020E61000006C5CFFAECFE4444012FA997ADD064640
39120	8	78	645	57881	61710	\N	44.116250000000001	Карачаево-Черкесская Республика, Хабезский муниципальный район, Зеюковское сельское поселение, аул Зеюко, Атажукина, 82	Россия, республика Карачаево-Черкесская, Хабезский район, село Зеюко	0101000020E61000001822A7AFE7E944407B14AE47E10E4640
39114	8	78	645	57880	61709	\N	43.957155356218003	Карачаево-Черкесская Республика, Хабезский муниципальный район, Жаковское сельское поселение, аул Жако, Акова, 8	Россия, республика Карачаево-Черкесская, Хабезский район, село Жако	0101000020E61000008B16A06D35DF4440F819170E84FA4540
39128	8	78	645	57873	61685	\N	44.2443890782477	Карачаево-Черкесская Республика, Хабезский муниципальный район, Бесленеевское сельское поселение, аул Бесленей, Гутякулова, 44	Россия, республика Карачаево-Черкесская, Хабезский район, село Бесленей	0101000020E61000002A91442FA3DE444046408523481F4640
35138	8	76	767	5401	60930	\N	43.50835	Республика Ингушетия, городской округ Малгобек,Оздоева, 82 (частный дом)		0101000020E610000096D05D12674B4640F775E09C11C14540
39123	8	78	645	12562	62442	\N	44.206150000000001	Карачаево-Черкесская Республика, Хабезский муниципальный район, Бавуковское сельское поселение, поселок Бавуко, Набережная, 10		0101000020E6100000C896E5EB32F2444003098A1F631A4640
39117	8	78	645	57855	61558	\N	43.989341360462802	Карачаево-Черкесская Республика, Хабезский муниципальный район, Али-Бердуковское сельское поселение, аул Али-Бердуковский, Ленина, 40	Россия, республика Карачаево-Черкесская, Хабезский район, село Али-Бердуковский	0101000020E610000062F9F36DC1DE4440C5CBD3B9A2FE4540
39115	8	78	645	57855	61557	\N	43.990208905390901	Карачаево-Черкесская Республика, Хабезский муниципальный район, Али-Бердуковское сельское поселение, аул Али-Бердуковский, Кушхова, 12	Россия, республика Карачаево-Черкесская, Хабезский район, село Али-Бердуковский	0101000020E6100000B2F1608BDDDE4440399A232BBFFE4540
39125	8	78	645	57981	62553	\N	44.253751303977097	Карачаево-Черкесская Республика, Хабезский муниципальный район, Псаучье-Дахское сельское поселение, аул Абазакт, Центральная, 32	Россия, республика Карачаево-Черкесская, Хабезский район, село Абазакт	0101000020E61000003EE76ED74BF34440E529ABE97A204640
39109	8	78	1159	57875	\N	\N	43.957414999999997	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Джегутинское сельское поселение, аул Джегута, МОУ ""СОШ а.Джегута"""	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, село Джегута	0101000020E6100000BE69FAEC8005454094D920938CFA4540
39112	8	78	1159	57884	\N	\N	43.973150494356197	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Эльтаркачское сельское поселение, МОУ ""СОШ а.Эльтаркач"""	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, село Эльтаркач	0101000020E61000003AB01C21031145401B0DE02D90FC4540
39098	8	78	1159	32983	61570	\N	44.0806582338179	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Морозова, МОУ Лицей №7	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута	0101000020E61000005E66D828EBFB444094145800530A4640
39103	8	78	1159	32983	61743	\N	44.088253000000002	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Усть-Джегутинское городское поселение, Краснопартизанская, ДК цемпоселка		0101000020E610000001F9122A38FE44400F63D2DF4B0B4640
39110	8	78	1159	57878	\N	\N	44.007604068032002	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Джегутинское сельское поселение, аул Новая Джегута, МОУ ""СОШ а.Новая Джегута"""		0101000020E61000008E20956247054540CEA8F92AF9004640
39108	8	78	1159	57868	\N	\N	43.912972854352503	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Джегутинское сельское поселение, аул Кызыл-Кала, МОУ ""СОШ а.Кызыл-Кала"""	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, село Кызыл-Кала	0101000020E6100000615111A793024540C5909C4CDCF44540
38960	8	78	1159	57876	61696	\N	44.059581999999999	Карачаево-Черкесская Республика, Абазинский муниципальный район, Кубинское сельское поселение, аул Кубина, Джегутанова, 36	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, село Кубина	0101000020E61000002CBCCB457CF9444013B70A62A0074640
39105	8	78	1159	57894	\N	\N	43.939975214838697	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Красногорское сельское поселение, МОУ ""СОШ ст.Красногорская"""		0101000020E6100000A565A4DE53F144405F07CE1951F84540
39113	8	78	1159	12076	\N	\N	44.105984999999997	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Койданское сельское поселение, МОУ ""СОШ с.Койдан"""		0101000020E610000074B4AA251D154540EB6E9EEA900D4640
39104	8	78	1159	57993	\N	\N	43.972650617352699	Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Сары-Тюзское сельское поселение, ДК	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, село Гюрюльдеук	0101000020E61000003750E09D7C084540FAB5F5D37FFC4540
39111	8	78	1159	57879	\N	\N	43.970671000000003	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Гюрюльдеукское сельское поселение, МОУ ""СОШ а.Гюрюльдеук"""		0101000020E6100000B779E3A4300945407B1684F23EFC4540
39107	8	78	1159	11813	\N	\N	43.9875292541698	"Карачаево-Черкесская Республика, Усть-Джегутинский муниципальный район, Важненское сельское поселение, МОУ ""СОШ с.Важное"""	Россия, республика Карачаево-Черкесская, Усть-Джегутинский район, село Важное	0101000020E6100000BBD6DEA7AAF84440016DAB5967FE4540
39076	8	78	796	10328	61726	\N	43.841762000000003	Карачаево-Черкесская Республика, Урупский муниципальный район, Урупское сельское поселение, село Уруп, Красная, 30		0101000020E610000050FD834886944440FE8172DBBEEB4540
39083	8	78	796	10675	62435	\N	43.590304000000003	Карачаево-Черкесская Республика, Урупский муниципальный район, Загеданское сельское поселение, поселок Пхия, Центральная, 8		0101000020E6100000E7559DD5027944405859DB148FCB4540
39085	8	78	796	10757	62453	\N	43.980556999999997	Карачаево-Черкесская Республика, Урупский муниципальный район, Курджиновское сельское поселение, село Псемен, Ставропольская, 3		0101000020E6100000AE8383BD897D4440936E4BE482FD4540
32966	8	75	\N	953	33050	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Кандауровская, 96		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
39089	8	78	796	10941	62439	\N	44.063819000000002	Карачаево-Черкесская Республика, Урупский муниципальный район, Предгорненское сельское поселение, село Предгорное, Садовая, 40		0101000020E610000038BA4A77D777444085EE92382B084640
39080	8	78	796	10410	62491	\N	43.949354999999997	Карачаево-Черкесская Республика, Урупский муниципальный район, Преградненское сельское поселение, станица Преградная, Прогонная, 15		0101000020E6100000CBD58F4DF2974440A4A5F27684F94540
39081	8	78	796	10410	61528	\N	43.949354999999997	Карачаево-Черкесская Республика, Урупский муниципальный район, Преградненское сельское поселение, станица Преградная, Подгорная, 22	Россия, республика Карачаево-Черкесская, Урупский район, село Преградная	0101000020E6100000CBD58F4DF2974440A4A5F27684F94540
39079	8	78	796	10410	61554	\N	43.949482016184596	Карачаево-Черкесская Республика, Урупский муниципальный район, Преградненское сельское поселение, станица Преградная, Пионерская, 19	Россия, республика Карачаево-Черкесская, Урупский район, село Преградная	0101000020E6100000D82AC1E27098444002124DA088F94540
39078	8	78	796	10410	61553	\N	43.949354999999997	Карачаево-Черкесская Республика, Урупский муниципальный район, Преградненское сельское поселение, станица Преградная, Красная, 111		0101000020E6100000CBD58F4DF2974440A4A5F27684F94540
38979	8	78	796	5609	61565	\N	43.915959999999998	рабочий поселок Медногорский, Спортивная, 1		0101000020E610000098DA520779974440DA38622D3EF54540
39077	8	78	796	5609	61708	\N	43.915959999999998	Карачаево-Черкесская Республика, Урупский муниципальный район, Медногорское городское поселение, рабочий поселок Медногорский, Бардина, 5-Б		0101000020E610000098DA520779974440DA38622D3EF54540
39082	8	78	796	57890	61741	\N	44.008623309709897	Карачаево-Черкесская Республика, Урупский муниципальный район, Кызыл-Урупское сельское поселение, аул Кызыл-Уруп, Пионерская, 4	Россия, республика Карачаево-Черкесская, Урупский район, село Кызыл-Уруп	0101000020E610000082E7DEC3259D4440287FF78E1A014640
39086	8	78	796	57853	61555	\N	43.994905142067097	Карачаево-Черкесская Республика, Урупский муниципальный район, Курджиновское сельское поселение, село Курджиново, Н. Василенко, 58	Россия, республика Карачаево-Черкесская, Урупский район, поселок городского типа Курджиново	0101000020E610000081768714037A44403ED00A0C59FF4540
39088	8	78	796	10706	62455	\N	43.995987	Карачаево-Черкесская Республика, Урупский муниципальный район, Курджиновское сельское поселение, село Курджиново, Школьная, 35		0101000020E61000004CA60A4625794440DE1E84807CFF4540
39087	8	78	796	10706	9934	\N	43.995987	Карачаево-Черкесская Республика, Урупский муниципальный район, Курджиновское сельское поселение, село Курджиново, Крайняя, 1		0101000020E61000004CA60A4625794440DE1E84807CFF4540
39084	8	78	796	10706	62548	\N	43.995987	Карачаево-Черкесская Республика, Урупский муниципальный район, Курджиновское сельское поселение, село Курджиново, Гагарина, 62		0101000020E61000004CA60A4625794440DE1E84807CFF4540
39075	8	78	656	10226	61706	\N	44.298634999999997	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Чапаевское сельское поселение, село Чапаевское, Центральная, 130		0101000020E6100000B85A272EC70745407138F3AB39264640
39074	8	78	656	10226	61706	\N	44.298634999999997	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Чапаевское сельское поселение, село Чапаевское, Центральная, 111		0101000020E6100000B85A272EC70745407138F3AB39264640
39064	8	78	656	9686	61720	\N	44.134684999999998	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Счастливенское сельское поселение, село Холоднородниковское, Садовая, 6		0101000020E61000006971C630272245408121AB5B3D114640
39059	8	78	656	9444	61739	\N	44.349578999999999	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Ударненское городское поселение, рабочий поселок Ударный, Мира, 2		0101000020E6100000789B374E0A414540272F3201BF2C4640
39063	8	78	656	32680	61740	\N	44.151367	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Таллыкское сельское поселение, аул Таллык, Шоссейная, 25в		0101000020E6100000CFD8976C3C2C4540C9586DFE5F134640
39065	8	78	656	9766	61550	\N	44.163667697361298	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Счастливенское сельское поселение, село Счастливое, Школьная, 1	Россия, республика Карачаево-Черкесская, Прикубанский район, село Счастливое	0101000020E610000017821C94302145406CB3B112F3144640
39061	8	78	656	9563	62541	\N	44.211939000000001	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Октябрьское сельское поселение, поселок Солнечный, Луговая, 3		0101000020E6100000E57CB1F7E23B45409CDF30D1201B4640
39066	8	78	656	9823	61722	\N	44.155085999999997	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Счастливенское сельское поселение, село Светлое, Байчорова, 23		0101000020E61000003C6A4C88B91C4540A208A9DBD9134640
39058	8	78	656	9436	62538	\N	44.287260000000003	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Майское сельское поселение, хутор Родниковский, Лесная, 7а		0101000020E61000004DDA54DD2331454078B988EFC4244640
94962	8	78	656	4451	61774	\N	44.232401451123003	Карачаево-Черкесская Республика, Абазинский муниципальный район, Псыжское сельское поселение, аул Псыж, ул. Кунижева, 173	Россия, республика Карачаево-Черкесская, Прикубанский район, село Псыж	0101000020E6100000971E4DF5640245406347E350BF1D4640
94961	8	78	656	4451	61774	\N	44.236943726297703	Карачаево-Черкесская Республика, Абазинский муниципальный район, Псыжское сельское поселение, аул Псыж, ул. Кунижева, 51	Россия, республика Карачаево-Черкесская, Прикубанский район, село Псыж	0101000020E61000008201840F25024540E17D552E541E4640
39068	8	78	656	9934	61747	\N	44.102581316031703	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Николаевское сельское поселение, село Пристань, Джегутинская, 1	Россия, республика Карачаево-Черкесская, Прикубанский район, село Пристань	0101000020E61000008718AF79551945407218CC5F210D4640
39070	8	78	656	10042	61730	\N	44.238308000000004	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Ильичевское сельское поселение, село Пригородное, Центральная, 32		0101000020E6100000F452B131AF0F4540063065E0801E4640
39067	8	78	656	57891	61750	\N	44.163164731590598	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Николаевское сельское поселение, село Привольное, Космонавтов, 21	Россия, республика Карачаево-Черкесская, Прикубанский район, село Привольный	0101000020E6100000825660C8EA124540096D3997E2144640
39060	8	78	656	9509	61705	\N	44.254593	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Октябрьское сельское поселение, поселок Октябрьский, Интернациональная, 1в		0101000020E610000028F04E3E3D3E45403065E08096204640
39062	8	78	656	40393	62635	\N	44.256307	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Октябрьское сельское поселение, поселок Новый, Дружбы, 1а	Россия, республика Карачаево-Черкесская, Прикубанский район, село Новый	0101000020E6100000E4F90CA837454540315EF3AACE204640
39069	8	78	656	9947	61551	\N	44.119049022412	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Николаевское сельское поселение, село Николаевское, Школьная, 17	Россия, республика Карачаево-Черкесская, Прикубанский район, село Николаевское	0101000020E61000008A0629780A1145408DCF64FF3C0F4640
39055	8	78	656	9295	61731	\N	44.275998000000001	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Мичуринское сельское поселение, поселок Мичуринский, Центральная, 45		0101000020E6100000C0EB33677D28454076E107E753234640
39057	8	78	656	9368	61729	\N	44.301951000000003	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Майское сельское поселение, поселок Майский, Шоссейная, 1		0101000020E61000004DF4F928233645404CFF9254A6264640
94960	8	78	656	4406	62564	\N	44.134049318056398	Карачаево-Черкесская Республика, Абазинский муниципальный район, Кара-Пагское сельское поселение, аул Кара-Паго, ул. Колмсомольская, 13	Россия, республика Карачаево-Черкесская, Прикубанский район, село Кара-Паго	0101000020E61000007FFB3A70CEF84440DF87838428114640
39054	8	78	656	9231	61680	\N	44.268408000000001	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Кавказское сельское поселение, поселок Кавказский, Татаркулова, 3		0101000020E6100000679DF17D711D45400DFE7E315B224640
39071	8	78	656	10075	61724	\N	44.188687999999999	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Ильичевское сельское поселение, село Ильичевское, Школьная, 2		0101000020E610000074D2FBC6D7124540E692AAED26184640
39072	8	78	656	10109	61704	\N	44.145003000000003	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Знаменское сельское поселение, село Знаменка, Мира, 110		0101000020E61000002733DE567A074540346953758F124640
39073	8	78	656	10167	61687	\N	44.198453000000001	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Дружбинское сельское поселение, село Дружба, 50 лет Октября, 155		0101000020E61000003ECDC98B4C02454084656CE866194640
39056	8	78	656	9323	62448	\N	44.248787999999998	Карачаево-Черкесская Республика, Прикубанский муниципальный район, Мичуринское сельское поселение, поселок Водораздельный, Советская, 4		0101000020E6100000B60E0EF6262C454091D10149D81F4640
39047	8	78	7455	58036	62916	\N	44.368724530497701	Карачаево-Черкесская Республика, Ногайский муниципальный район, Эркен-Шахарское сельское поселение, Некрасова, 2	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, поселок городского типа Эркен-Шахар	0101000020E610000050C3B7B06EFA4440DA1B7C61322F4640
39030	8	78	967	8148	62488	\N	43.863832000000002	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Элькушское сельское поселение, село Элькуш, Центральная, 35		0101000020E610000047C9AB730C524540809E060C92EE4540
39037	8	78	967	8343	61546	\N	43.937665000000003	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Учкекенское сельское поселение, село Учкекен, Школьная, 7		0101000020E6100000EBC9FCA36F4245404BCD1E6805F84540
39036	8	78	967	8343	61703	\N	43.937665000000003	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Учкекенское сельское поселение, село Учкекен, Хабова, 23		0101000020E6100000EBC9FCA36F4245404BCD1E6805F84540
39035	8	78	967	8343	61609	\N	43.937665000000003	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Учкекенское сельское поселение, село Учкекен, Ленина, 128		0101000020E6100000EBC9FCA36F4245404BCD1E6805F84540
39034	8	78	967	8343	61609	\N	43.937665000000003	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Учкекенское сельское поселение, село Учкекен, Ленина, 114		0101000020E6100000EBC9FCA36F4245404BCD1E6805F84540
39038	8	78	967	8343	61547	\N	43.937665000000003	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Учкекенское сельское поселение, село Учкекен, Ижаева, 1		0101000020E6100000EBC9FCA36F4245404BCD1E6805F84540
39042	8	78	967	8670	61549	\N	43.931426000000002	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Терезинское сельское поселение, село Терезе, Ленина, 109		0101000020E61000001844A4A65D384540725298F738F74540
39041	8	78	967	8670	61549	\N	43.931426000000002	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Терезинское сельское поселение, село Терезе, Ленина, 13		0101000020E61000001844A4A65D384540725298F738F74540
39033	8	78	967	57869	61652	\N	43.952590904237702	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Римгорское сельское поселение, село Римгорское, Школьная, 42	Россия, республика Карачаево-Черкесская, Малокарачаевский район, село Рим-Горский	0101000020E6100000CAC342AD6942454062BB7B80EEF94540
39040	8	78	967	8575	61679	\N	43.936114000000003	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Первомайское сельское поселение, село Первомайское, Шоссейная, 73		0101000020E6100000F4C29D0B233B4540F4A96395D2F74540
39039	8	78	967	8575	61548	\N	43.936736043617501	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Первомайское сельское поселение, село Первомайское, Совхозная, 4	Россия, республика Карачаево-Черкесская, Малокарачаевский район, село Первомайское	0101000020E61000009A266C3F193D4540317E1AF7E6F74540
39043	8	78	967	57886	61728	\N	43.928902668633498	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Кызыл-Покунское сельское поселение, аул Кызыл-Покун, Советская, 33б	Россия, республика Карачаево-Черкесская, Малокарачаевский район, село Кызыл-Покун	0101000020E61000004BC8073D9B2945400114234BE6F64540
94975	8	78	967	49683	61650	\N	43.943480999999998	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, с.Красный Курган, Боташева, 1		0101000020E6100000BB7B80EECB4D4540DDB243FCC3F84540
39044	8	78	967	57946	62400	\N	43.966230774055497	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Красновосточное сельское поселение, аул Красный Восток, Школьная, 17	Россия, республика Карачаево-Черкесская, Малокарачаевский район, село Красновосточный	0101000020E610000083161230BA264540D1B01875ADFB4540
39045	8	78	967	57946	62390	\N	43.967222641592301	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Красновосточное сельское поселение, аул Красный Восток, Макова, 15	Россия, республика Карачаево-Черкесская, Малокарачаевский район, село Красновосточный	0101000020E6100000FB22A12DE7264540317898F6CDFB4540
94974	8	78	967	8063	62565	\N	43.790590000000002	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Кичи-Балыкское сельское поселение, село Кичи-Балык, Центральная, 2		0101000020E6100000A437DC476E534540B745990D32E54540
39032	8	78	967	8238	61702	\N	43.95223	Карачаево-Черкесская Республика, Малокарачаевский муниципальный район, Джагинское сельское поселение, село Джага, Школьная, 47		0101000020E610000027840EBA84474540922232ACE2F94540
38935	8	78	534	3259	62485	\N	43.577560162330798	Карачаево-Черкесская Республика, Карачаевский городской округ, рабочий поселок Эльбрусский, Горняцкая, 25	Россия, республика Карачаево-Черкесская, Карачаевский район, поселок городского типа Эльбрусский	0101000020E61000005859DB148F11454027BD6F7CEDC94540
39013	8	78	534	58010	62609	\N	43.432181999999997	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Хурзукское сельское поселение, Дж.Байрамукова, 58		0101000020E61000006D54A70359134540BEF561BD51B74540
39014	8	78	534	58001	62590	\N	43.452610999999997	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Учкуланское сельское поселение, Учкуланская, 25	Россия, республика Карачаево-Черкесская, Карачаевский район, село Учкулан	0101000020E61000007D7901F6D1094540A9674128EFB94540
38949	8	78	534	3972	\N	\N	43.450620999999998	Карачаево-Черкесская Республика, Карачаевский городской округ, город Теберда, Микрорайон	Россия, республика Карачаево-Черкесская, Карачаевский район, Теберда	0101000020E61000004FCE50DCF1DE444006F2ECF2ADB94540
39028	8	78	534	57852	\N	\N	43.919104278303301	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Правокубанское городское поселение, нет улицы, здание №19	Россия, республика Карачаево-Черкесская, Карачаевский район, поселок городского типа Правокубанский	0101000020E61000005A47551344F14440B7CF2A33A5F54540
39024	8	78	534	57943	62368	\N	43.822985606448803	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Ново-Карачаевское городское поселение, Тоторкулова, 52		0101000020E61000006A50340F60F344406E88F19A57E94540
39018	8	78	534	33063	61721	\N	43.672975000000001	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Ново-Тебердинское сельское поселение, Шоссейная, 19а		0101000020E61000009B38B9DFA1F244404703780B24D64540
39019	8	78	534	33063	62940	\N	43.676023129623701	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Нижне-Тебердинское сельское поселение, Центральная, 27	Россия, республика Карачаево-Черкесская, Карачаевский район, село Новая Теберда	0101000020E6100000A14B38F416F34440022CF2EB87D64540
39022	8	78	534	33082	62584	\N	43.762250000000002	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Нижне-Маринское сельское поселение, Хапаева, 8		0101000020E61000007F2F8507CD0A454021B0726891E14540
39027	8	78	534	60659	75518	\N	43.558916000000004	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Кумышское сельское поселение, Комсомольская, 18а	Россия, республика Карачаево-Черкесская, Карачаевский район	0101000020E61000001C5E10919AFC4440079B3A8F8AC74540
39025	8	78	534	7892	62487	\N	43.838251	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Хумаринское сельское поселение, поселок Кубрань, Садовая, без номера		0101000020E6100000DBA6785C54F744406E6B0BCF4BEB4540
39015	8	78	534	58034	62894	\N	43.505689361972003	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Карт-Джуртское сельское поселение, Алиева, 30	Россия, республика Карачаево-Черкесская, Карачаевский район, село Карт-Джурт	0101000020E6100000880E8123810E45403579CA6ABAC04540
39017	8	78	534	60665	75525	\N	43.7304453320561	Карачаево-Черкесская Республика, Карачаевский муниципальный район, Джингирикское сельское поселение, Центральная, 27	Россия, республика Карачаево-Черкесская, Карачаевский район, село Джингирик	0101000020E61000008201840F25F244406C43C5387FDD4540
94959	8	78	612	3882	\N	\N	43.842705000000002	Карачаево-Черкесская Республика, Карачаевский городской округ, рабочий поселок Орджоникидзевский, Шоссейная,54	Россия, республика Карачаево-Черкесская, Карачаевск городской округ, поселок Орджоникидзевский	0101000020E610000056BABBCE86F244407D96E7C1DDEB4540
39002	8	78	747	57995	62579	\N	43.7878551774157	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Даусузское сельское поселение, аул Хуса-Кардоник, Октябрьская, 11	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Хусы-Кардоник	0101000020E6100000E9B985AE44CA4440BB7EC16ED8E44540
39010	8	78	747	7194	62506	\N	43.713771999999999	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Хасаут-Греческое сельское поселение, село Хасаут-Греческое, Надежды Кецеровой, 65-Б		0101000020E610000073D6A71C93D54440776682E15CDB4540
38996	8	78	747	57969	62503	\N	44.165938712647304	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Исправненское сельское поселение, хутор Фроловский, Шоссейная, 19	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Фроловский	0101000020E61000005C76887FD8D84440C310397D3D154640
39012	8	78	747	57888	61780	\N	43.881033000000002	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Сторожевское сельское поселение, станица Сторожевая 2, Горная, 4		0101000020E610000005A2276552B9444030D978B0C5F04540
38989	8	78	747	6009	61542	\N	43.881033000000002	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Сторожевское сельское поселение, станица Сторожевая, Ленина, 102	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Сторожевая	0101000020E610000005A2276552B9444030D978B0C5F04540
38987	8	78	747	6009	61542	\N	43.871968422236002	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Сторожевское сельское поселение, станица Сторожевая, Ленина, 46	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Сторожевая	0101000020E610000005E09F5225BA44404B94BDA59CEF4540
38986	8	78	747	6009	61541	\N	43.881033000000002	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Сторожевское сельское поселение, станица Сторожевая, Карачаевская, 27	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Сторожевая	0101000020E610000005A2276552B9444030D978B0C5F04540
38988	8	78	747	6009	61700	\N	43.881033000000002	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Сторожевское сельское поселение, станица Сторожевая, Заводская, 1		0101000020E610000005A2276552B9444030D978B0C5F04540
39000	8	78	747	58015	62663	\N	43.974766560816903	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Исправненское сельское поселение, хутор Ново-Исправненский, Октябрьская, 56	Россия	0101000020E6100000FE62B66455C644402A1C412AC5FC4540
39003	8	78	747	6845	62508	\N	43.7492849924515	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Даусузское сельское поселение, село Нижняя Ермоловка, Асфальтная, 57	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Нижняя Ермоловка	0101000020E6100000AC3AAB05F6C0444012312592E8DF4540
39005	8	78	747	6965	\N	\N	43.679712010332203	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Архызское сельское поселение, поселок Нижний Архыз, САО РАН, холл лабораторного корпуса	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Нижний Архыз	0101000020E610000064E597C118BB4440715985CD00D74540
39008	8	78	747	7104	61701	\N	43.764932000000002	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Марухское сельское поселение, село Маруха, Белана, 192		0101000020E61000005B7B9FAA42D14440FAD4B14AE9E14540
38975	8	78	747	5280	61540	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Ленина, 47		0101000020E6100000486FB88FDCCA4440649126DE01EE4540
38984	8	78	747	57996	62581	\N	43.787872786812201	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, хутор Лесо-Кяфарь, Школьная, сельский клуб	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Лесо-Кефарь	0101000020E6100000CD9541B5C1B944406133C005D9E44540
39007	8	78	747	57896	61776	\N	43.820180870536397	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Кызыл-Октябрьское сельское поселение, аул Кызыл-Октябрь, Школьная, 7	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Кызыл-Октябрьский	0101000020E610000077A22424D2E4444079E6E5B0FBE84540
39006	8	78	747	57896	62398	\N	43.828880605457499	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Кызыл-Октябрьское сельское поселение, аул Кызыл-Октябрь, Алиева, 21	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Кызыл-Октябрьский	0101000020E61000009EB64604E3E444404DA3C9C518EA4540
38990	8	78	747	57892	61752	\N	43.931362310052698	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Сторожевское сельское поселение, аул Кобу-Баши, Школьная, 13	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Кобу-Баши	0101000020E61000001FD7868A71A844405B5EB9DE36F74540
38994	8	78	747	6233	61675	\N	43.864007000000001	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Кардоникское сельское поселение, станица Кардоникская, Советская, 190		0101000020E6100000236937FA98DB4440EE4108C897EE4540
38992	8	78	747	6233	61603	\N	43.864007000000001	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Кардоникское сельское поселение, станица Кардоникская, Октябрьская, 38		0101000020E6100000236937FA98DB4440EE4108C897EE4540
38995	8	78	747	6233	61543	\N	43.864007000000001	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Кардоникское сельское поселение, станица Кардоникская, Ленина, 76	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Кардоникская	0101000020E6100000236937FA98DB4440EE4108C897EE4540
38993	8	78	747	6233	61674	\N	43.864007000000001	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Кардоникское сельское поселение, станица Кардоникская, Красная, 49		0101000020E6100000236937FA98DB4440EE4108C897EE4540
38991	8	78	747	6233	61698	\N	43.864007000000001	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Кардоникское сельское поселение, станица Кардоникская, Заводская, 31		0101000020E6100000236937FA98DB4440EE4108C897EE4540
38999	8	78	747	6553	61737	\N	44.067420633756399	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Исправненское сельское поселение, станица Исправная, Красная, 129	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Исправная	0101000020E6100000C921E2E654CE444025085740A1084640
38998	8	78	747	6553	61544	\N	44.071784999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Исправненское сельское поселение, станица Исправная, Кооперативная, 20	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Исправная	0101000020E610000056B60F79CBCD4440F3AB394030094640
38997	8	78	747	6553	61742	\N	44.078715279925902	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Исправненское сельское поселение, станица Исправная, Казачья, 86	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Исправная	0101000020E6100000F5D6C05609CE4440325A4755130A4640
38985	8	78	747	57978	62523	\N	43.9552553101881	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Сторожевское сельское поселение, аул Ильич, Красноармейская, 14	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Ильич	0101000020E61000005CE84A04AAC34440952BBCCB45FA4540
38983	8	78	747	5280	\N	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Казачья, 70	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская	0101000020E6100000486FB88FDCCA4440649126DE01EE4540
38982	8	78	747	5280	61697	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Советская, 110		0101000020E6100000486FB88FDCCA4440649126DE01EE4540
38977	8	78	747	5280	61601	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Набережная, 3		0101000020E6100000486FB88FDCCA4440649126DE01EE4540
38980	8	78	747	5280	61540	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Ленина, 100	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская	0101000020E6100000486FB88FDCCA4440649126DE01EE4540
38976	8	78	747	5280	61540	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Ленина, 74		0101000020E6100000486FB88FDCCA4440649126DE01EE4540
94966	8	78	576	4866	62567	\N	44.348526798604702	а.Баралки, Октябрьская,37а	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Баралки	0101000020E6100000E014562AA8E64440F16261889C2C4640
38981	8	78	747	5280	61725	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Красноармейская, 65	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская	0101000020E6100000486FB88FDCCA4440649126DE01EE4540
38973	8	78	747	5280	62496	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Карбышева, контора ХРУ № 6200, кабинет		0101000020E6100000486FB88FDCCA4440649126DE01EE4540
94973	8	78	747	5280	61564	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Калинина,190а		0101000020E6100000486FB88FDCCA4440649126DE01EE4540
38974	8	78	747	5280	61539	\N	43.859431999999998	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Зеленчукское сельское поселение, станица Зеленчукская, Заводская, 58-А	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская	0101000020E6100000486FB88FDCCA4440649126DE01EE4540
39001	8	78	747	6766	61545	\N	43.789037181385801	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Даусузское сельское поселение, село Даусуз, Юрия Хатуевва, 104	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Даусуз	0101000020E610000036E49F19C4C54440BF2A172AFFE44540
39004	8	78	747	6898	62446	\N	43.564514000000003	Карачаево-Черкесская Республика, Зеленчукский муниципальный район, Архызское сельское поселение, село Архыз, Мостовая, 3		0101000020E6100000586FD40AD3A344402C11A8FE41C84540
94946	8	78	576	5121	61712	\N	44.4278937381616	а.Эрсакон, Ленина, 70	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Эрсакон	0101000020E6100000BB6070CD1DE34440CB13083BC5364640
94977	8	78	576	57874	61686	\N	44.449179999999998	Карачаево-Черкесская Республика, Ногайский муниципальный район, Эркен-Юртское сельское поселение, аул Эркен-Юрт, Ленина, 80	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Эркен-Юрт	0101000020E6100000658EE55DF5F444403602F1BA7E394640
39046	8	78	576	57994	62574	\N	44.373759	Карачаево-Черкесская Республика, Ногайский муниципальный район, Эркен-Шахарское сельское поселение, К.Мижевой, 15	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, поселок городского типа Эркен-Шахар	0101000020E610000009A9DBD957FA4440F7CABC55D72F4640
39053	8	78	576	57889	61738	\N	44.371986999999997	Карачаево-Черкесская Республика, Ногайский муниципальный район, Эркен-Халкское сельское поселение, аул Эркен-Халк, Ахлова, 66	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Эркен-Халк	0101000020E61000008411FB0450F84440C1C41F459D2F4640
94969	8	78	576	24644	62575	\N	44.351975688115097	а.Тапанта, Ворошилова, 23	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Тапанта	0101000020E6100000336ABE4A3ED644400B7DB08C0D2D4640
94948	8	78	576	57898	61795	\N	44.3461863643467	а.Старо-Кувинск, Октябрьская,51	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Старокувинский	0101000020E61000006E861BF0F9E34440A22AA6D24F2C4640
94965	8	78	576	4844	62543	\N	44.415728000000001	с.Спарта, Кирова,38а		0101000020E6100000946B0A6476E6444008043A9336354640
94964	8	78	576	57885	61723	\N	44.332757844327602	с.Садовое, Полевая,14	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Садовое	0101000020E610000001A777F17E044540BEBD6BD0972A4640
94971	8	78	576	58004	62596	\N	44.396570662391802	а.Ново-Кувинск, Широкая,17	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Новокувинский	0101000020E61000005C8FC2F528E4444061C5A9D6C2324640
39050	8	78	576	57893	61754	\N	44.329960999999997	Карачаево-Черкесская Республика, Ногайский муниципальный район, Икон-Халкское сельское поселение, аул Кызыл-Тогай, Победы, 10	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Кызыл-Тогай	0101000020E61000000A4966F50EE544404CFA7B293C2A4640
94972	8	78	576	58002	62591	\N	44.467664999999997	Киево-Жураки, Школьная,7	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Киево-Жураковский	0101000020E61000000C3D62F4DCE44440EE3D5C72DC3B4640
94976	8	78	576	60670	75529	\N	44.314407000000003	Карачаево-Черкесская Республика, Ногайский муниципальный район, Икон-Халкское сельское поселение, Ленина,108	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Икон-Халк	0101000020E610000092B06F2711F544401651137D3E284640
94950	8	78	576	57980	62534	\N	44.491975486527998	Карачаево-Черкесская Республика, Ногайский муниципальный район, Эркен-Юртское сельское поселение, хутор Евсеевский, Гагарина, 22б	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Евсеевский	0101000020E6100000B727486C77F544408CB96B09F93E4640
94967	8	78	576	4937	62572	\N	44.4767370617867	х.Дубянский, Школьная,1	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Дубянский	0101000020E6100000D84AE82E89E7444086E5CFB7053D4640
94968	8	78	576	3594	62570	\N	44.3764815515922	х.Грушка, Гагарина, 44	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Грушка	0101000020E6100000EBFD463B6ED444402FC4EA8F30304640
94949	8	78	576	5103	61749	\N	44.306394216352899	а.Вако-Жиле, Первомайская,43	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Вако-Жиле	0101000020E6100000ACADD85F76DF444066D828EB37274640
94947	8	78	576	4776	61751	\N	44.4479712031209	а.Апсуа, Школьная,13	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Апсуа	0101000020E610000088A1D5C919E6444039471D1D57394640
38961	8	78	576	4684	61538	\N	44.333798275482501	Адыге-Хабль, Советская, 15	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Адыге-Хабль	0101000020E6100000A9DC442DCDF7444030BC92E4B92A4640
39048	8	78	576	58005	62597	\N	44.359182187477003	Карачаево-Черкесская Республика, Ногайский муниципальный район, Адиль-Халкское сельское поселение, Джелябиева, 76	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Адиль-Халк	0101000020E6100000F20A444FCAF64440EBA7FFACF92D4640
94970	8	78	576	4989	62573	\N	44.372664733983001	а.Абаза-Хабль, Первомайская, 36	Россия, республика Карачаево-Черкесская, Адыге-Хабльский район, село Абаза-Хабль	0101000020E61000001A5245F12AD1444092AE997CB32F4640
94963	8	78	7454	58021	62707	\N	44.243306921884901	Карачаево-Черкесская Республика, Абазинский муниципальный район, Кунижева, 259	Россия, республика Карачаево-Черкесская, Прикубанский район, село Псыж	0101000020E610000068942EFD4B024540A6F10BAF241F4640
37047	8	77	\N	57961	62482	\N	43.483617009780502	ст. Александровская, Октябрьская, 36	Россия, Р-290 шоссе	0101000020E61000005C8E57207A08464013656F29E7BD4540
37056	8	77	\N	57944	62371	\N	43.438345597660799	Кабардино-Балкарская Республика, Городской округ Нальчик, Дружбы	Россия, республика Кабардино-Балкарская, Нальчик городской округ, село Хасанья	0101000020E6100000952C27A1F4C945408D2AC3B81BB84540
37300	8	77	\N	57837	62345	\N	43.399899052039501	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, пр. Эльбрусский, 24		0101000020E6100000047289230F764540FF59F3E32FB34540
37306	8	77	\N	57837	62457	\N	43.396394224368201	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, Баксанская, 15	Россия, республика Кабардино-Балкарская, Эльбрусский район, Тырныауз	0101000020E6100000069CA56439754540522AE109BDB24540
37213	8	77	\N	57845	62432	\N	43.478607745233198	Кабардино-Балкарская Республика, Терский муниципальный район, Городское поселение Терек, Теунова, 2	Россия, республика Кабардино-Балкарская, Терский район, Терек	0101000020E6100000130F289B721146404FCDE50643BD4540
37214	8	77	\N	57845	61518	\N	43.4893572034375	Кабардино-Балкарская Республика, Терский муниципальный район, Городское поселение Терек, Терская, 98		0101000020E61000003753211E89114640CA880B40A3BE4540
37211	8	77	\N	57845	62396	\N	43.4835326628723	Кабардино-Балкарская Республика, Терский муниципальный район, Городское поселение Терек, Ленина, 49		0101000020E6100000C13A8E1F2A134640B5C4CA68E4BD4540
37209	8	77	\N	57836	62550	\N	43.755288047932098	Кабардино-Балкарская Республика, Городской округ Прохладный, разъезд Шарданово, Клуб путевой машинной станции № 143	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E61000007E74EACA67034640D787F546ADE04540
37191	8	77	\N	57836	61514	\N	43.756781396219701	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Строительная, 272 а		0101000020E6100000226DE34F54024640F99D2633DEE04540
37190	8	77	\N	57836	62369	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Остапенко, 14		0101000020E610000070952710760246400DA5F622DAE04540
37200	8	77	\N	57836	62374	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Ленина, 21		0101000020E610000070952710760246400DA5F622DAE04540
37205	8	77	\N	57836	62388	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Кавказская, 2 Б		0101000020E610000070952710760246400DA5F622DAE04540
37208	8	77	\N	57836	62427	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Дзержинского, 35		0101000020E610000070952710760246400DA5F622DAE04540
37201	8	77	\N	57836	62428	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Головко, 70		0101000020E610000070952710760246400DA5F622DAE04540
37193	8	77	\N	57836	61515	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, пер. Агрономический, 11		0101000020E610000070952710760246400DA5F622DAE04540
37132	8	77	\N	32538	62537	\N	43.4916491971235	"Кабардино-Балкарская Республика, Городской округ Нальчик, им. братьев Кушховых, 79 ""А"""	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000A86DC32808D04540390EBC5AEEBE4540
37108	8	77	\N	32538	61379	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Эльбрусская, 4	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37131	8	77	\N	32538	62511	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Щорса, 6	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37074	8	77	7453	\N	62422	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Шортанова, 14		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37118	8	77	\N	32538	61383	\N	43.482610698268402	Кабардино-Балкарская Республика, Городской округ Нальчик, Шогенцукова, 28	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000D2E28C614ECE45404DD87E32C6BD4540
37117	8	77	\N	32538	61383	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Шогенцукова, 14	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
32573	8	75	\N	953	33073	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Калинина, 4		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
37085	8	77	\N	32538	61383	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Шогенцукова, 7	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37057	8	77	\N	32538	61383	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Шогенцукова, 5А	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37102	8	77	\N	32538	61378	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Шогенова, 26	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37145	8	77	\N	32538	62370	\N	43.489610097183302	Кабардино-Балкарская Республика, Городской округ Нальчик, Чеченская, 17	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E610000066F4A3E194CB4540B4E55C8AABBE4540
37104	8	77	\N	32538	61463	\N	43.492649	Кабардино-Балкарская Республика, Городской округ Нальчик, Чернышевского, 165		0101000020E6100000CDB1BCAB1ED045401CB4571F0FBF4540
37103	8	77	\N	32538	61463	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Чернышевского, 173	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37080	8	77	\N	32538	61457	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Чайковского, 26	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37055	8	77	\N	32538	62414	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Ульбашева, 11		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37123	8	77	\N	32538	61353	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Тырныаузская, 1	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37097	8	77	\N	32538	61462	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Туриста, 7Б	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37095	8	77	\N	32538	61462	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Туриста, 54		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37091	8	77	\N	32538	62566	\N	43.4861964298807	Кабардино-Балкарская Республика, Городской округ Нальчик, Тимошенко, 60	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000E8667FA0DCD0454017B9A7AB3BBE4540
37147	8	77	\N	32538	62425	\N	43.484860594135803	Кабардино-Балкарская Республика, Городской округ Нальчик, Тимирязева, 7	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000C64FE3DEFCCC45408D0DDDEC0FBE4540
37122	8	77	\N	32538	61384	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Тепличный, 17	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37066	8	77	\N	32538	61373	\N	43.481446656520497	Кабардино-Балкарская Республика, Городской округ Нальчик, Тарчокова, 52Б	Россия, республика Кабардино-Балкарская, Чегемский район	0101000020E6100000889E94490DC94540F0E0270EA0BD4540
37065	8	77	\N	32538	61373	\N	43.481860714226997	Кабардино-Балкарская Республика, Городской округ Нальчик, Тарчокова, 52	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000004704E3E0D2C94540E31B0A9FADBD4540
37058	8	77	\N	32538	61373	\N	43.481970087483703	Кабардино-Балкарская Республика, Городской округ Нальчик, Тарчокова, 32	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000438D429259C9454099D36531B1BD4540
37086	8	77	\N	32538	62418	\N	43.496358744029898	Кабардино-Балкарская Республика, Городской округ Нальчик, Революционная, 8	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000C879FF1F27CC4540A20914B188BF4540
37115	8	77	\N	32538	62355	\N	43.476860581007401	Кабардино-Балкарская Республика, Городской округ Нальчик, Пушкина, 85	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000C879FF1F27CC454072DEFFC709BD4540
37099	8	77	\N	32538	61461	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Профсоюзная, 185		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37096	8	77	\N	32538	61461	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Профсоюзная, 122	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37107	8	77	\N	32538	61464	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Пачева, 55	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37121	8	77	\N	32538	61466	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Огоньянца, 25	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37144	8	77	\N	32538	62373	\N	43.517849371804701	"Кабардино-Балкарская Республика, Городской округ Нальчик, Неделина, 8 ""А"""	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000029D499BAAD7454016A243E048C24540
37141	8	77	\N	32538	62373	\N	43.478610675035398	Кабардино-Балкарская Республика, Городской округ Нальчик, Неделина, 20	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000ECDFF599B3CE4540C040102043BD4540
37142	8	77	\N	32538	61335	\N	43.507768790431797	"Кабардино-Балкарская Республика, Городской округ Нальчик, Мусукаева, 26 ""А"""	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000D998D71187D2454019761893FEC04540
32967	8	75	\N	953	33138	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Казбекова, 92		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
37059	8	77	\N	32538	62339	\N	43.4898600606099	Кабардино-Балкарская Республика, Городской округ Нальчик, Московская, 6А	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000002C29779FE3CB45402DCF83BBB3BE4540
37106	8	77	\N	32538	62352	\N	43.4833606729336	Кабардино-Балкарская Республика, Городской округ Нальчик, Мечникова, 130А	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000679AB0FD64CC4540B894F3C5DEBD4540
37077	8	77	\N	32538	61456	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Матросова, 5	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37120	8	77	\N	32538	62358	\N	43.4753604597825	"Кабардино-Балкарская Республика, Городской округ Нальчик, Мальбахова, 17 ""А"""	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000008EAED2DD75CC4540CDE9B298D8BC4540
37111	8	77	\N	32538	62358	\N	43.492649	Кабардино-Балкарская Республика, Городской округ Нальчик, Мальбахова, 117		0101000020E6100000CDB1BCAB1ED045401CB4571F0FBF4540
37114	8	77	\N	32538	61382	\N	43.486048005155901	Кабардино-Балкарская Республика, Городской округ Нальчик, Ленина, 69	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000003B8C497F2FCD4540A22424D236BE4540
37113	8	77	\N	32538	61382	\N	43.492649	Кабардино-Балкарская Республика, Городской округ Нальчик, Ленина, 53		0101000020E6100000CDB1BCAB1ED045401CB4571F0FBF4540
37075	8	77	\N	32538	61374	\N	43.484114056011798	Кабардино-Балкарская Республика, Городской округ Нальчик, Кулиева, 12	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000F549EEB089CA454093C49272F7BD4540
37073	8	77	\N	32538	61374	\N	43.4777434473216	Кабардино-Балкарская Республика, Городской округ Нальчик, Кулиева, 28А	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000B39602D2FEC945404B72C0AE26BD4540
37061	8	77	\N	32538	61374	\N	43.492649	Кабардино-Балкарская Республика, Городской округ Нальчик, Кулиева, 5		0101000020E6100000CDB1BCAB1ED045401CB4571F0FBF4540
37060	8	77	\N	32538	61374	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Кулиева, 9	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37116	8	77	\N	32538	62357	\N	43.4833606729336	Кабардино-Балкарская Республика, Городской округ Нальчик, Коммунаров, 20	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000F25D4A5D32CC4540B894F3C5DEBD4540
37110	8	77	\N	32538	61380	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Комарова, 51	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37155	8	77	\N	32538	62365	\N	43.494109279467203	Кабардино-Балкарская Республика, Городской округ Нальчик, Коллонтай, 6	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000B41CE8A1B6CB454063D4B5F63EBF4540
37128	8	77	\N	32538	61455	\N	43.484364042343699	Кабардино-Балкарская Республика, Городской округ Нальчик, Кирова, 341	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E610000053978C6324CB45400CAEB9A3FFBD4540
37072	8	77	\N	32538	61455	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Кирова, 8	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37062	8	77	\N	32538	62340	\N	43.4898600606099	Кабардино-Балкарская Республика, Городской округ Нальчик, Катханова, 91	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000B8921D1B81CC45402DCF83BBB3BE4540
37076	8	77	\N	32538	62409	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Карашаева, 17		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37149	8	77	\N	32538	61471	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Канкошева, 97	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37064	8	77	\N	32538	61453	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Каменская, 4	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37109	8	77	\N	32538	61465	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Калюжного, 15	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37094	8	77	\N	32538	61459	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Калмыкова, 246	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37154	8	77	\N	32538	62367	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Калинина, 262		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37153	8	77	\N	32538	62367	\N	43.484113999999998	"Кабардино-Балкарская Республика, Городской округ Нальчик, Калинина, 262 ""А"""		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37148	8	77	\N	32538	62367	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Калинина, 99		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37136	8	77	\N	32538	62356	\N	43.4893635502048	Кабардино-Балкарская Республика, Городской округ Нальчик, Кабардинская, 198	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000E63FA4DFBECE45407DEBC37AA3BE4540
37119	8	77	\N	32538	62356	\N	43.480110715001402	Кабардино-Балкарская Республика, Городской округ Нальчик, Кабардинская, 55	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000C64FE3DEFCCC454095B9F94674BD4540
32970	8	75	\N	953	33114	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Имама Шамиля, 117		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
37079	8	77	\N	32538	62576	\N	43.491996424268599	Кабардино-Балкарская Республика, Городской округ Нальчик, Инессы Арманд, 43	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000E0F60489EDCA4540A4E194B9F9BE4540
37143	8	77	\N	32538	61386	\N	43.517349677277103	"Кабардино-Балкарская Республика, Городской округ Нальчик, Ингушская, 9 ""А"""	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000004A253CA1D7D74540F54A598638C24540
37139	8	77	\N	32538	61386	\N	43.516600127671701	Кабардино-Балкарская Республика, Городской округ Нальчик, Ингушская, 2	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000B47405DB88D745408A8EE4F21FC24540
37126	8	77	\N	32538	61385	\N	43.510353516318801	"Кабардино-Балкарская Республика, Городской округ Нальчик, Идарова, 139 ""А"""	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000BB99D18F86CF4540FFB0A54753C14540
37125	8	77	\N	32538	61385	\N	43.504606058784802	"Кабардино-Балкарская Республика, Городской округ Нальчик, Идарова, 160 ""А"""	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E610000093C3279D48D04540C5AEEDED96C04540
37088	8	77	\N	32538	62350	\N	43.492859540469098	Кабардино-Балкарская Республика, Городской округ Нальчик, Захарова, 77	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000323ECC5EB6CF4540D7C0560916BF4540
37089	8	77	\N	32538	62417	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Залиханова, 4		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37087	8	77	\N	32538	61376	\N	43.5200979456082	Кабардино-Балкарская Республика, Городской округ Нальчик, Заводская, 6	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000CAFB389A23D74540855B3E9292C24540
37146	8	77	\N	32538	61377	\N	43.502106992304199	Кабардино-Балкарская Республика, Городской округ Нальчик, Дагестанская, 148	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000006AA0F99CBBD54540DD0BCC0A45C04540
37090	8	77	\N	32538	61377	\N	43.504855959702802	Кабардино-Балкарская Республика, Городской округ Нальчик, Дагестанская, 89	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E610000021CCED5EEED345403D98141F9FC04540
37112	8	77	\N	32538	61458	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Горького, 17	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37084	8	77	\N	32538	61458	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Горького, 11	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37078	8	77	\N	32538	62429	\N	43.488313395187902	Кабардино-Балкарская Республика, Городской округ Нальчик, Головко, 89	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000ACC612D6C6CA4540179B560A81BE4540
37134	8	77	\N	32538	61469	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Гагарина, 10	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37071	8	77	\N	32538	61375	\N	43.486735442897697	Кабардино-Балкарская Республика, Городской округ Нальчик, Ватутина, 6	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000D105F52D73CA4540C7681D554DBE4540
37067	8	77	\N	32538	61375	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Ватутина, 28		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37100	8	77	\N	32538	62354	\N	43.4871138232362	Кабардино-Балкарская Республика, Городской округ Нальчик, Будаева, 13	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000278925E5EECB45403DB665C059BE4540
37069	8	77	\N	32538	61454	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Байсултанова, 74-11-40	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37068	8	77	\N	32538	61454	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Байсултанова, 33		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37052	8	77	\N	32538	61371	\N	43.495109051913097	Кабардино-Балкарская Республика, Городской округ Нальчик, Бабаева, 33	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E610000080F10C1AFACB4540467A51BB5FBF4540
37133	8	77	\N	32538	61467	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Б. Хмельницкого, 17	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37127	8	77	\N	32538	61467	\N	43.492649	"Кабардино-Балкарская Республика, Городской округ Нальчик, Б. Хмельницкого, 34 ""А"""		0101000020E6100000CDB1BCAB1ED045401CB4571F0FBF4540
37137	8	77	\N	32538	61470	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Ашурова, 3	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37124	8	77	\N	32538	61470	\N	43.516849978582002	Кабардино-Балкарская Республика, Городской округ Нальчик, Ашурова, 22	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E610000026E1421EC1D7454003780B2428C24540
37063	8	77	\N	32538	62361	\N	43.484301545858401	Кабардино-Балкарская Республика, Городской округ Нальчик, Ахметова, 58	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007D3D5FB35CCA454096B1A19BFDBD4540
37053	8	77	\N	32538	61372	\N	43.501607166506197	Кабардино-Балкарская Республика, Городской округ Нальчик, Аттоева, 15	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000DAACFA5C6DCD4540EB387EA834C04540
37130	8	77	\N	32538	62366	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, 9-е Января, 1		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37151	8	77	\N	32538	61472	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, 2-я Надречная, 127	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37150	8	77	\N	32538	61472	\N	43.492109684568597	Кабардино-Балкарская Республика, Городской округ Нальчик, 2-я Надречная, 120	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000006840BD1935CD45406C04E275FDBE4540
37101	8	77	\N	32538	61419	\N	43.4833606729336	Кабардино-Балкарская Республика, Городской округ Нальчик, 2-ой Таманской дивизии, 422	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E610000064CA87A06ACC4540B894F3C5DEBD4540
37093	8	77	\N	32538	61419	\N	43.481360719657197	Кабардино-Балкарская Республика, Городской округ Нальчик, 2-ой Таманской дивизии, 450	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E6100000C879FF1F27CC4540F148BC3C9DBD4540
37092	8	77	\N	32538	61419	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, 2-ой Таманской дивизии, 27	Россия, республика Кабардино-Балкарская, Нальчик	0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37040	8	77	\N	57824	62403	\N	43.630127000000002	г. Майский, Ленина, 24		0101000020E61000001E6B4606B9074640CEA96400A8D04540
37045	8	77	\N	57824	61422	\N	43.630127000000002	г. Майский, Железнодорожная, 54		0101000020E61000001E6B4606B9074640CEA96400A8D04540
35045	8	77	\N	57824	62468	\N	43.630127000000002	г. Майский, Горького, 112		0101000020E61000001E6B4606B9074640CEA96400A8D04540
35273	8	77	\N	57824	61447	\N	43.630127000000002	г. Майский, 9 Мая, 1		0101000020E61000001E6B4606B9074640CEA96400A8D04540
36996	8	77	\N	57839	62346	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, переулок Куашева, д.16		0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36986	8	77	\N	57839	61505	\N	43.687902433707201	Кабардино-Балкарская Республика, Городской округ Баксан, улица Эльбрусская, д.15		0101000020E6100000B6300BED9CC245402F6D382C0DD84540
36991	8	77	\N	57839	61507	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Шукова, д.1		0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36990	8	77	\N	57839	61507	\N	43.683103330634601	Кабардино-Балкарская Республика, Городской округ Баксан, улица Шукова, д.2	Россия, Р-289 шоссе	0101000020E610000098DEFE5C34CA454056664AEB6FD74540
36980	8	77	\N	57839	61507	\N	43.684881582765897	Кабардино-Балкарская Республика, Городской округ Баксан, улица Шукова, д.142	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E6100000B7CF2A33A5C545403ECF9F36AAD74540
36998	8	77	\N	57839	62462	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Кокова, д.223		0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36997	8	77	\N	57839	62464	\N	43.683757361808098	Кабардино-Балкарская Республика, Городской округ Баксан, улица Баксанова, д.86	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000000A14B18861C545409EB4705985D74540
37309	8	77	1604	52917	62547	\N	43.256580999999997	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Эльбрус, Эльбрусская, 23		0101000020E6100000BDC804FC1A53454032E36DA5D7A04540
37311	8	77	1604	32679	\N	\N	43.256580999999997	"Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Эльбрус, Здание ЦАО ""Терскол"""	Россия, республика Кабардино-Балкарская, Эльбрусский район, поселок Эльбрус	0101000020E6100000BDC804FC1A53454032E36DA5D7A04540
37310	8	77	1604	32679	\N	\N	43.256580999999997	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Эльбрус, Здание Дома Культуры		0101000020E6100000BDC804FC1A53454032E36DA5D7A04540
37303	8	77	1604	32613	62412	\N	43.402339793562597	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, пр. Эльбрусский, 21		0101000020E61000003E3DB665C0754540B3EF8AE07FB34540
37307	8	77	1604	32613	61492	\N	43.395392807533703	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, пр. Эльбрусский, 89	Россия, республика Кабардино-Балкарская, Эльбрусский район, Тырныауз	0101000020E61000008E8F16670C7545409E08E23C9CB24540
37305	8	77	1604	32613	62404	\N	43.402210718365801	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, Энеева, 29	Россия, республика Кабардино-Балкарская, Эльбрусский район, Тырныауз	0101000020E6100000AAD72D0263754540B58B69A67BB34540
37301	8	77	1604	32613	62454	\N	43.399892000000001	"Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, Мичурина, 1 ""А"""		0101000020E6100000C6DB4AAFCD7645404DF73AA92FB34540
37304	8	77	1604	32613	62490	\N	43.399892000000001	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, Мизиева, 5		0101000020E6100000C6DB4AAFCD7645404DF73AA92FB34540
37302	8	77	1604	32613	62515	\N	43.399892000000001	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, Гызыева, 5		0101000020E6100000C6DB4AAFCD7645404DF73AA92FB34540
37299	8	77	1604	32613	62549	\N	43.395142450721004	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Городское поселение Тырныауз, Автогаражная, 2	Россия, республика Кабардино-Балкарская, Эльбрусский район, Тырныауз	0101000020E6100000100533A66077454055A3570394B24540
37295	8	77	1604	57992	62569	\N	43.386567101083401	"Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Кенделен, Ленина, 294 ""Г"""	Россия, республика Кабардино-Балкарская, Эльбрусский район	0101000020E610000047938B31B06A45403E5B07077BB14540
37293	8	77	1604	57976	62520	\N	43.5937225581607	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Кенделен, Энеева, 78	Россия, республика Кабардино-Балкарская, Эльбрусский район, село Гунделен	0101000020E61000000305DEC9A797454006F1811DFFCB4540
37294	8	77	1604	57976	62571	\N	43.398648000000001	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Кенделен, Ленина, 241		0101000020E610000090831266DA6A4540D34ECDE506B34540
37292	8	77	1604	57979	62524	\N	43.595594001010099	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Кенделен, 800-Погибших, 7	Россия, республика Кабардино-Балкарская, Эльбрусский район, село Гунделен	0101000020E6100000757808E3A7954540CFD8976C3CCC4540
37308	8	77	1604	57984	62557	\N	43.307805000000002	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Верхний Баксан, Школьная, 2		0101000020E6100000B285200725604540CC457C2766A74540
37298	8	77	1604	52890	62397	\N	43.457912	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Былым, Тебердиева, 47		0101000020E6100000EB5223F433854540153944DC9CBA4540
37297	8	77	1604	52889	62545	\N	43.512005000000002	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Бедык, Байсултанова, 18		0101000020E610000026512FF834934540BA313D6189C14540
37171	8	77	1563	57990	62563	\N	43.3108266063456	сельское поселение Советское, ул. Угнич, д.12		0101000020E6100000136058FE7CCD45405EDBDB2DC9A74540
37291	8	77	1563	57958	62519	\N	43.322651196231902	Кабардино-Балкарская Республика, Черекский муниципальный район, Городское поселение Кашхатау, Мечиева К.Б, 1	Россия, республика Кабардино-Балкарская, Черекский район, поселок городского типа Советское	0101000020E61000005B41D3122BCF4540C782C2A04CA94540
37290	8	77	1563	57958	62472	\N	43.311746555240397	Кабардино-Балкарская Республика, Черекский муниципальный район, Городское поселение Кашхатау, Мечиева К.Б, 143	Россия, республика Кабардино-Балкарская, Черекский район, поселок городского типа Советское	0101000020E6100000B08D78B29BCD454024D06053E7A74540
37289	8	77	1563	57942	62362	\N	43.313000062498197	Кабардино-Балкарская Республика, Черекский муниципальный район, Городское поселение Кашхатау, Мечиева К.Б, 193	Россия, республика Кабардино-Балкарская, Черекский район, поселок городского типа Советское	0101000020E6100000274EEE7728CC4540F2D24D6210A84540
37286	8	77	1563	52886	62556	\N	43.296350040595897	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Карасу, Школьная, 21	Россия, республика Кабардино-Балкарская, Черекский район, село Карасу	0101000020E61000002CD49AE61DB54540B515FBCBEEA54540
37277	8	77	1563	52831	62461	\N	43.333404000000002	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Зарагиж, Ленина, 82		0101000020E6100000E54526E0D7DA4540842D76FBACAA4540
37279	8	77	1563	52834	62394	\N	43.282280999999998	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Жемтала, Сталина, 50		0101000020E61000007B2FBE688FD345401EA4A7C821A44540
37278	8	77	1563	52834	62459	\N	43.282280999999998	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Жемтала, Ленина, 82		0101000020E61000007B2FBE688FD345401EA4A7C821A44540
37274	8	77	1563	33089	62499	\N	43.373175000000003	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Герпегеж, ул.Холамкая, 42		0101000020E610000052B81E85EBD34540A857CA32C4AF4540
37280	8	77	1563	32774	61421	\N	43.235508000000003	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Верхняя Жемтала, Настуева, 80	Россия, республика Кабардино-Балкарская, Черекский район, село Верхняя Жемтала	0101000020E6100000A2B77878CFD5454023F94A20259E4540
37282	8	77	1563	33122	62516	\N	43.126071000000003	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Верхняя Балкария, Таулуева, 112	Россия, республика Кабардино-Балкарская, Черекский район, село Верхняя Балкария	0101000020E61000004FCAA48636BA4540ADFC321823904540
37281	8	77	1563	33122	62516	\N	43.126071000000003	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Верхняя Балкария, Таулуева, 93		0101000020E61000004FCAA48636BA4540ADFC321823904540
37284	8	77	1563	33122	62477	\N	43.126071000000003	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Верхняя Балкария, Настуева, 25		0101000020E61000004FCAA48636BA4540ADFC321823904540
37283	8	77	1563	33122	62530	\N	43.126071000000003	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Верхняя Балкария, Асанова, 41		0101000020E61000004FCAA48636BA4540ADFC321823904540
37285	8	77	1563	33144	62525	\N	43.214953000000001	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Безенги, Османова Э.Х, 69		0101000020E610000063EDEF6C8FA44540AB967494839B4540
37288	8	77	1563	52864	62433	\N	43.27214	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Бабугент, Тогузаева, 26		0101000020E610000048A5D8D138C645407BF7C77BD5A24540
37287	8	77	1563	52864	61490	\N	43.27214	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Бабугент, Мокаева, 34	Россия, республика Кабардино-Балкарская, Черекский район, село Бабугент	0101000020E610000048A5D8D138C645407BF7C77BD5A24540
37276	8	77	1563	33092	61489	\N	43.394095	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Аушигер, Кушхова, 7	Россия, республика Кабардино-Балкарская, Черекский район, село Аушигер	0101000020E6100000FBCDC47421DE4540314278B471B24540
37275	8	77	1563	33092	62470	\N	43.394095	Кабардино-Балкарская Республика, Черекский муниципальный район, Сельское поселение Аушигер, Бицуева, 194		0101000020E6100000FBCDC47421DE4540314278B471B24540
37269	8	77	1519	52841	62395	\N	43.542006999999998	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Яникой, с объединенными территориями села Яникой и села Каменка, Ленина, 96		0101000020E61000003D0D18247DC04540FE99417C60C54540
37268	8	77	1519	52801	62444	\N	43.530183999999998	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Шалушка, переулок Колхозный, 8		0101000020E61000001405FA449EC84540656EBE11DDC34540
37266	8	77	1519	52801	61415	\N	43.530183999999998	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Шалушка, Ленина, 60б	Россия, республика Кабардино-Балкарская, Чегемский район, село Шалушка	0101000020E61000001405FA449EC84540656EBE11DDC34540
37267	8	77	1519	52801	61418	\N	43.530183999999998	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Шалушка, А.Г.Юанова, 1	Россия, республика Кабардино-Балкарская, Чегемский район, село Шалушка	0101000020E61000001405FA449EC84540656EBE11DDC34540
37261	8	77	1519	52792	62385	\N	43.591099393558601	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Чегем - Второй, Ленина, 169	Россия, республика Кабардино-Балкарская, Чегемский район, село Чегем 2-й	0101000020E6100000CE52B29C84CC454062D9CC21A9CB4540
37260	8	77	1519	52792	62385	\N	43.589103000000001	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Чегем - Второй, Ленина, 72		0101000020E6100000F296AB1F9BCC4540DD7C23BA67CB4540
37265	8	77	1519	33017	61413	\N	43.562545036387398	Кабардино-Балкарская Республика, Чегемский муниципальный район, Городское поселение Чегем, Свободы, 160	Россия, республика Кабардино-Балкарская, Чегемский район, Чегем 1-й	0101000020E61000004FEB36A8FDCA4540A0C37C7901C84540
37256	8	77	1519	33017	62492	\N	43.567630000000001	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Верхне-Чегемское, кулиева, 38		0101000020E6100000A2B437F8C2CA45403F1D8F19A8C84540
37263	8	77	1519	33017	61486	\N	43.566539459337001	Кабардино-Балкарская Республика, Чегемский муниципальный район, Городское поселение Чегем, Баксанское шоссе, 7	Россия, республика Кабардино-Балкарская, Чегемский район, Чегем 1-й	0101000020E61000006EDBF7A8BFCC45404B74965984C84540
37264	8	77	1519	33017	61414	\N	43.562295376096898	Кабардино-Балкарская Республика, Чегемский муниципальный район, Городское поселение Чегем, Баксанское Шоссе, 25а	Россия, республика Кабардино-Балкарская, Чегемский район, Чегем 1-й	0101000020E6100000CDEA1D6E87CC454027DA5548F9C74540
37262	8	77	1519	33017	61412	\N	43.5638229443028	Кабардино-Балкарская Республика, Чегемский муниципальный район, Городское поселение Чегем, А.С. Кярова, 6	Россия, республика Кабардино-Балкарская, Чегемский район, Чегем 1-й	0101000020E6100000406D54A703CB4540C6DD205A2BC84540
37257	8	77	1519	57972	62510	\N	43.437334740092801	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Хушто-Сырт, Балкарская, 22	Россия, республика Кабардино-Балкарская, Чегемский район, село Хуштосырт	0101000020E610000027C286A7579E4540B532E197FAB74540
37273	8	77	1519	57951	62440	\N	43.508594221288199	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Звездный, Ленина, 16		0101000020E610000055336B2920BF45408E78B29B19C14540
37258	8	77	1519	52790	61409	\N	43.496377000000003	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Нижний Чегем, К.Кулиева, 84	Россия, республика Кабардино-Балкарская, Чегемский район, село Нижний Чегем	0101000020E6100000D32EA699EEA5454049BE124889BF4540
37271	8	77	1519	52814	61487	\N	43.505907899360999	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Нартан, с объединенными территориями села Нартан и дорожный разъезд Нартан, Ленина, 141	Россия, республика Кабардино-Балкарская, Чегемский район, село Нартан	0101000020E6100000D8D5E429ABD945407364E597C1C04540
37270	8	77	1519	52814	61487	\N	43.512135999999998	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Нартан, с объединенными территориями села Нартан и дорожный разъезд Нартан, Ленина, 100		0101000020E61000008C648F5033DA4540588D25AC8DC14540
37272	8	77	1519	52814	61493	\N	43.512135999999998	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Нартан, с объединенными территориями села Нартан и дорожный разъезд Нартан, А.Тухужева, 1	Россия, республика Кабардино-Балкарская, Чегемский район, село Нартан	0101000020E61000008C648F5033DA4540588D25AC8DC14540
37259	8	77	1519	52791	62443	\N	43.562776999999997	Кабардино-Балкарская Республика, Чегемский муниципальный район, Сельское поселение Лечинкай, Канукоева Н.Т, 66		0101000020E61000004E0B5EF415B8454072F8A41309C84540
32975	8	75	\N	953	33017	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Заречная проез1, 2		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
37156	8	77	1519	57948	62401	\N	43.513851698897597	Кабардино-Балкарская Республика, Городской округ Нальчик, село Адиюх, Нарткалинское шоссе, 167	Россия, республика Кабардино-Балкарская, Чегемский район	0101000020E6100000AA807B9E3FD94540FA7DFFE6C5C14540
37236	8	77	1461	32900	62531	\N	43.553682999999999	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Шитхала, Мира, 51		0101000020E610000047ACC5A700E64540F3ACA415DFC64540
37234	8	77	1461	16753	62436	\N	43.606214000000001	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Черная Речка, Ленина, 100		0101000020E610000058E542E55FEB45404D309C6B98CD4540
37035	8	77	1461	52372	62402	\N	43.341271999999996	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Хатуей, Бараова, 16		0101000020E6100000A8FE4124430246402F8507CDAEAB4540
37036	8	77	1461	52374	62333	\N	43.294257000000002	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Урух, Кирова, 27		0101000020E610000037A5BC56420346403ECF9F36AAA54540
37238	8	77	1461	52741	61478	\N	43.489379	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Урвань, Школьная, 24	Россия, республика Кабардино-Балкарская, Урванский район, село Урвань	0101000020E61000003F1A4E999BE14540B22C98F8A3BE4540
37237	8	77	1461	52741	62392	\N	43.489379	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Урвань, Братьев Кафоевых, 132		0101000020E61000003F1A4E999BE14540B22C98F8A3BE4540
37030	8	77	1461	52369	62540	\N	43.145550999999998	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Ташлы - Тала, Ленина, 38		0101000020E6100000209A79724DD945403673486AA1924540
37242	8	77	1461	52752	62450	\N	43.4709	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Старый Черек, Ленина, 134		0101000020E61000000F289B7285ED4540DCD7817346BC4540
37241	8	77	1461	52752	62452	\N	43.4709	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Старый Черек, Куашева, 3		0101000020E61000000F289B7285ED4540DCD7817346BC4540
37245	8	77	1461	52762	61406	\N	43.536301000000002	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Псынабо, Пролетарская, 24	Россия, республика Кабардино-Балкарская, Урванский район, село Псынабо	0101000020E6100000C974E8F4BCF54540F3E7DB82A5C44540
37244	8	77	1461	52759	61404	\N	43.604126000000001	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Псыкод, Ленина, 3	Россия, республика Кабардино-Балкарская, Урванский район, село Псыкод	0101000020E610000009E066F162FF4540E754320054CD4540
37239	8	77	1461	52747	61402	\N	43.413305000000001	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Псыгансу, Ленина, 109	Россия, республика Кабардино-Балкарская, Урванский район, село Псыгансу	0101000020E610000042CF66D5E7E44540FB22A12DE7B44540
37240	8	77	1461	52747	61479	\N	43.413305000000001	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Псыгансу, Грейдерная, 4	Россия, республика Кабардино-Балкарская, Урванский район, село Псыгансу	0101000020E610000042CF66D5E7E44540FB22A12DE7B44540
37034	8	77	1461	32932	62480	\N	43.403508000000002	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Озрек, Кабалоева, 1		0101000020E61000001059A4897702464052D66F26A6B34540
37243	8	77	1461	52755	61403	\N	43.509369999999997	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Нижний Черек, Ленина, 69	Россия, республика Кабардино-Балкарская, Урванский район, село Нижний Черек	0101000020E61000007974232C2AF6454021C8410933C14540
37251	8	77	1461	57832	62387	\N	43.550376542427003	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Тарчокова, 17	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E61000006BD8EF8975EC45403CBCE7C072C64540
37255	8	77	1461	57832	61485	\N	43.557617710162802	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Пушкина, 76	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E610000012BC218D0AEE454099D4D00660C74540
37249	8	77	1461	57832	62437	\N	43.552840000000003	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Массаева, 31	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E6100000B9E00CFE7EED4540D8F50B76C3C64540
37250	8	77	1461	57832	62463	\N	43.550252052811203	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Ленина, 72	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E61000008C14CAC2D7ED4540804754A86EC64540
37253	8	77	1461	57832	62434	\N	43.549377691905804	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Кабардинская, 115	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E61000001AE0826C59EC45402992AF0452C64540
37252	8	77	1461	57832	62434	\N	43.552840000000003	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Кабардинская, 131	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E6100000B9E00CFE7EED4540D8F50B76C3C64540
37248	8	77	1461	57832	62447	\N	43.5563358902765	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Жамборова, 4	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E6100000CBD58F4DF2ED454032CB9E0436C74540
37254	8	77	1461	57832	61483	\N	43.550875961436198	Кабардино-Балкарская Республика, Урванский муниципальный район, Городское поселение Нарткала, Гурфова, 4	Россия, республика Кабардино-Балкарская, Урванский район, Нарткала	0101000020E6100000D8F0F44A59EE45405E13D21A83C64540
37235	8	77	1461	32881	62505	\N	43.567067999999999	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Морзох, Комсомольская, 1		0101000020E610000009C21550A8EB4540D74D29AF95C84540
37246	8	77	1461	52764	62384	\N	43.536876999999997	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Кахун, Октябрьская, 100		0101000020E6100000EECD6F9868F04540BF7CB262B8C44540
37247	8	77	1461	52764	61480	\N	43.536876999999997	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Кахун, Кирова, 140	Россия, республика Кабардино-Балкарская, Урванский район, село Кахун	0101000020E6100000EECD6F9868F04540BF7CB262B8C44540
37029	8	77	1461	32884	62478	\N	43.317120000000003	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Ерокко, Массаева, 55		0101000020E61000005114E81379F045402A745E6397A84540
37233	8	77	1461	52733	61401	\N	43.587980000000002	Кабардино-Балкарская Республика, Урванский муниципальный район, Сельское поселение Герменчик, Центральная, 10	Россия, республика Кабардино-Балкарская, Урванский район, село Герменчик	0101000020E6100000467EFD101BE24540DE59BBED42CB4540
37031	8	77	1461	40382	62546	\N	43.216911000000003	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Верхний Лескен, Ленина, 19		0101000020E61000008D28ED0DBEDE4540439259BDC39B4540
37026	8	77	1461	52367	61370	\N	43.416691	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Аргудан, Суншева, 28	Россия, республика Кабардино-Балкарская, Урванский район, село Аргудан	0101000020E610000071CADC7C23F44540CEC4742156B54540
37027	8	77	1461	52367	61431	\N	43.416691	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Аргудан, Жигунова, 105	Россия, республика Кабардино-Балкарская, Урванский район, село Аргудан	0101000020E610000071CADC7C23F44540CEC4742156B54540
37033	8	77	1461	52370	62405	\N	43.355446000000001	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Анзорей, Хамгокова, 27		0101000020E610000092CA147310F845403CBF28417FAD4540
37032	8	77	1461	52370	61443	\N	43.355446000000001	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Анзорей, Степная, б/н	Россия, республика Кабардино-Балкарская, Урванский район, село Анзорей	0101000020E610000092CA147310F845403CBF28417FAD4540
37229	8	77	1408	52722	62386	\N	43.699806000000002	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Урожайное, Ленина, 55		0101000020E610000009A69A594B1B4640B5C5353E93D94540
37230	8	77	1408	52726	62393	\N	43.673437999999997	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Терекское, Ленина, 1		0101000020E61000005B7C0A80F12646401BF1643733D64540
37212	8	77	1408	57819	62378	\N	43.488875945646797	Кабардино-Балкарская Республика, Терский муниципальный район, Городское поселение Терек, Ленина, 14	Россия, республика Кабардино-Балкарская, Терский район, Терек	0101000020E6100000838769DFDC1146404FE61F7D93BE4540
37210	8	77	1408	57819	62430	\N	43.479542000000002	Кабардино-Балкарская Республика, Терский муниципальный район, Городское поселение Терек, Карданова, 66	Россия, республика Кабардино-Балкарская, Терский район, Терек	0101000020E610000089B3226AA21146407B87DBA161BD4540
37221	8	77	1408	52696	61398	\N	43.506748000000002	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Тамбовское, Дружбы, 166	Россия, республика Кабардино-Балкарская, Терский район, село Тамбовское	0101000020E61000004DA1F31ABB1A46401EA8531EDDC04540
37224	8	77	1408	57974	62517	\N	43.5696198149571	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Нижний Курп, Ногмова, 2	Россия, республика Кабардино-Балкарская, Терский район, село Инаркой	0101000020E610000017B6662B2F354640E292E34EE9C84540
37217	8	77	1408	52681	61520	\N	43.3937506776711	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Плановское, Гагарина, 2	Россия, республика Кабардино-Балкарская, Терский район, село Плановское	0101000020E61000007E8CB96B0919464037E2C96E66B24540
37231	8	77	1408	32864	62451	\N	43.675446000000001	"Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Хамидие, Кудаева, 54 ""б"""		0101000020E61000000589EDEE01304640651BB80375D64540
37232	8	77	1408	57966	62500	\N	43.667086815815203	"Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Ново-Хамидие, Матросова, 10 ""а"""	Россия, республика Кабардино-Балкарская, Терский район	0101000020E61000001409A69A592F46401B4B581B63D54540
37228	8	77	1408	32837	62479	\N	43.651290000000003	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Новая Балкария, Центральная, 24		0101000020E610000000917EFB3A1646401E1B81785DD34540
37226	8	77	1408	52711	62383	\N	43.636006000000002	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Красноармейское, Центральная, 45	Россия, республика Кабардино-Балкарская, Терский район, село Красноармейское	0101000020E6100000C898BB96900F4640A70705A568D14540
37215	8	77	1408	40363	9948	\N	43.538848510680701	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Интернациональное, Парковая, 1	Россия, республика Кабардино-Балкарская, Терский район, река Терек	0101000020E6100000E2AFC91AF5224640BC3D0801F9C44540
37223	8	77	1408	32804	62497	\N	43.555604000000002	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Инаркой, Дышекова, 10		0101000020E610000030D461855B3446406EC328081EC74540
37227	8	77	1408	52714	62529	\N	43.614927999999999	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Джулат, Сибилова, 1		0101000020E6100000A48E8EAB910B464085B2F0F5B5CE4540
37216	8	77	1408	52677	62381	\N	43.475485999999997	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Дейское, Мальбахова, 149		0101000020E61000001555BFD2F914464059DAA9B9DCBC4540
37222	8	77	1408	52698	62458	\N	43.478126401195098	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Верхний Курп, Ашхотова, 54	Россия, республика Кабардино-Балкарская, Терский район, село Верхний Курп	0101000020E61000002828452BF72E464004AF963B33BD4540
37219	8	77	1408	52692	61476	\N	43.472797	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Верхний Акбаш, Ленина, 25	Россия, республика Кабардино-Балкарская, Терский район, село Верхний Акбаш	0101000020E610000084D89942E71D4640CE52B29C84BC4540
37220	8	77	1408	52692	62528	\N	43.472797	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Верхний Акбаш, Гоголя, 1		0101000020E610000084D89942E71D4640CE52B29C84BC4540
37218	8	77	1408	52685	62527	\N	43.457172	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Белоглинское, Пачева, 10		0101000020E61000008179C8940F1B4640CE52B29C84BA4540
37225	8	77	1408	52705	61338	\N	43.585036029886901	Кабардино-Балкарская Республика, Терский муниципальный район, Сельское поселение Арик, Дружбы, 16	Россия, республика Кабардино-Балкарская, Терский район, село Арик	0101000020E61000006E8B321B640E4640C87DAB75E2CA4540
37168	8	77	669	13408	62535	\N	43.843316000000002	железнодорожная станция Солдатская, ул. Зенковского, д.14	Россия, республика Кабардино-Балкарская, Прохладненский район, село старая Солдатская	0101000020E6100000A912656F29EB4540C61858C7F1EB4540
37158	8	77	669	58011	62639	\N	43.829303301402099	сельское поселение Малакановское, ул. Интернациональная, д.1	Россия, республика Кабардино-Балкарская, Прохладненский район	0101000020E6100000B2A19BFD81044640C3BCC79926EA4540
37178	8	77	669	57968	62502	\N	43.762002716809498	сельское поселение Янтарное, ул. Ленина, д.7	Россия, республика Кабардино-Балкарская, Прохладненский район, село Янтарное	0101000020E6100000B56FEEAF1EF14540193A765089E14540
37176	8	77	669	57985	62558	\N	43.761716347658002	сельское поселение Черниговское, ул. Кравченко, б/н	Россия, республика Кабардино-Балкарская, Прохладненский район, село Черниговское	0101000020E61000004E999B6F44ED4540836BEEE87FE14540
37180	8	77	669	57973	62513	\N	43.776916	сельское поселение Учебное, ул. Школьная, д.1	Россия, республика Кабардино-Балкарская, Прохладненский район, село Учебный	0101000020E610000005DEC9A7C7F645409CDEC5FB71E34540
37161	8	77	669	57997	62603	\N	43.879484377845401	сельское поселение Ульяновское, ул. Школьная, д.2а		0101000020E61000005798BED7100E464079AD84EE92F04540
37166	8	77	669	57844	61513	\N	43.810642999999999	станица Солдатская, ул. Пилипенко, д.56	Россия, республика Кабардино-Балкарская, Прохладненский район, село Солдатская	0101000020E6100000C15774EB35E945409CDD5A26C3E74540
37165	8	77	669	57940	62348	\N	43.811303227784201	станица Солдатская, ул. Пилипенко, д.40	Россия, республика Кабардино-Балкарская, Прохладненский район, село Солдатская	0101000020E61000000FED6305BFE94540C712D6C6D8E74540
37177	8	77	669	48293	62539	\N	43.730561000000002	хутор Саратовский, ул. Садовая, б/н		0101000020E6100000D784B4C6A0E34540D55DD90583DD4540
37187	8	77	669	57991	62568	\N	43.755536536885501	сельское поселение Псыншоко, ул. Центральная, д.34	Россия, республика Кабардино-Балкарская, Прохладненский район, село Псыншоко	0101000020E610000095D6DF1280DB45407FF5B86FB5E04540
37189	8	77	669	14545	61389	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Строительная, 284		0101000020E610000070952710760246400DA5F622DAE04540
37194	8	77	669	14545	61337	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Свободы, 178	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E610000070952710760246400DA5F622DAE04540
37192	8	77	669	14545	62380	\N	43.760490424232302	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Пролетарская, 220	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E61000009BCAA2B08B024640AF777FBC57E14540
37202	8	77	669	14545	62431	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, Привокзальная площадь, 15-я дистанция сигнализации и связи		0101000020E610000070952710760246400DA5F622DAE04540
32471	8	75	\N	6655	32944	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ШАМИЛЯ, 47корпус 2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
37203	8	77	669	14545	62331	\N	43.748549166016602	"Кабардино-Балкарская Республика, Городской округ Прохладный, Привокзальная Площадь ж/д ст.Прохладная, ""Красный уголок"""	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E6100000DFFB1BB4570746400C3A2174D0DF4540
37198	8	77	669	14545	61395	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Петренко, 48	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E610000070952710760246400DA5F622DAE04540
37207	8	77	669	14545	61474	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Овчарова, 66/1	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E610000070952710760246400DA5F622DAE04540
37197	8	77	669	14545	62389	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, Ленина, 76		0101000020E610000070952710760246400DA5F622DAE04540
37196	8	77	669	14545	62389	\N	43.752675023431003	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Ленина, 104	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E610000069C70DBF9B04464027C286A757E04540
37199	8	77	669	14545	62379	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Головко, 309		0101000020E610000070952710760246400DA5F622DAE04540
37195	8	77	669	14545	61439	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, пер.Гагарина, 16	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E610000070952710760246400DA5F622DAE04540
37206	8	77	669	14545	62376	\N	43.756656999999997	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Боронтова, 99		0101000020E610000070952710760246400DA5F622DAE04540
37204	8	77	669	14545	62376	\N	43.760358231969398	Кабардино-Балкарская Республика, Городской округ Прохладный, ул.Боронтова, 275	Россия, республика Кабардино-Балкарская, Прохладненский район, Прохладный	0101000020E6100000A9C0C9367003464040A0336953E14540
37182	8	77	669	57964	62493	\N	43.849238999999997	сельское поселение Пролетарское, ул. Ленина, д.193	Россия, республика Кабардино-Балкарская, Прохладненский район, село Пролетарское	0101000020E6100000560F98874C0546406EBE11DDB3EC4540
37184	8	77	669	57947	62481	\N	43.744236833404699	сельское поселение Прималкинское, ул. Октябрьская, д.206	Россия, республика Кабардино-Балкарская, Прохладненский район, село Прималкинское	0101000020E610000078616BB6F200464090BC732843DF4540
37183	8	77	669	57947	62391	\N	43.746035999999997	сельское поселение Прималкинское, ул. Кныш, д.150		0101000020E61000007E3B8908FF004640BFD18E1B7EDF4540
37070	8	77	669	8924	62416	\N	43.769489	станица Приближная, пер. Кооперативный, д.7а		0101000020E6100000CCB22781CD0F4640DDD0949D7EE24540
37186	8	77	669	57970	62504	\N	43.692446559902898	сельское поселение Ново-Полтавское, ул. Третьякова, д.128	Россия, республика Кабардино-Балкарская, Прохладненский район, село Новополтавское	0101000020E61000005DC5E23785FD45404E9B711AA2D84540
37185	8	77	669	57963	62486	\N	43.737290675730698	хутор Ново-Покровский, пер. Широкий, д.34	Россия, республика Кабардино-Балкарская, Прохладненский район, село Новопокровский	0101000020E6100000DB899290480546404C512E8D5FDE4540
37181	8	77	669	57965	62494	\N	43.775589996235901	сельское поселение Лесное, ул. Ивановского, д.5	Россия, республика Кабардино-Балкарская, Прохладненский район, село Лесное	0101000020E6100000137D3ECA88F14540658D7A8846E34540
37159	8	77	669	57955	62467	\N	43.934463308855101	сельское поселение Красносельское, ул. Театральная, б/н	Россия, республика Кабардино-Балкарская, Прохладненский район, село Красносельское	0101000020E6100000A9143B1A870446403929CC7B9CF74540
37179	8	77	669	57989	62562	\N	43.862662	сельское поселение Комсомольское, ул. Виноградная, д.3	Россия, республика Кабардино-Балкарская, Прохладненский район, село Комсомольское	0101000020E6100000897956D28AF7454040C05AB56BEE4540
37170	8	77	669	57939	62342	\N	43.802608684053901	ельское поселение Карагач, ул. Абубекирова, д.111	Россия, республика Кабардино-Балкарская, Прохладненский район, село Карагач	0101000020E6100000D95A5F24B4E34540D53C47E4BBE64540
37169	8	77	669	57939	62342	\N	43.806305016387697	сельское поселение Карагач, ул. Абубекирова, д.100	Россия, республика Кабардино-Балкарская, Прохладненский район, село Карагач	0101000020E6100000BDFBE3BD6AE34540F7CC920035E74540
37164	8	77	669	57977	62521	\N	43.9346965101753	сельское поселение Заречное, ул. Зеленая, б/н	Россия, республика Кабардино-Балкарская, Прохладненский район, село Заречное	0101000020E6100000E38920CEC3ED4540AC55BB26A4F74540
37152	8	77	669	12835	62332	\N	43.765635000000003	станица Екатериноградская, ул. Ленина, д.50а	Россия, республика Кабардино-Балкарская, Прохладненский район, село Екатериноградская	0101000020E61000006B7EFCA5451D464024D6E25300E24540
37157	8	77	669	57975	62518	\N	43.928140999999997	сельское поселение Дальнее, ул. Школьная, д.8	Россия, республика Кабардино-Балкарская, Прохладненский район, село Дальное	0101000020E6100000F27B9BFEEC254640D2890453CDF64540
37160	8	77	669	57998	62585	\N	43.950220558452898	сельское поселение Граничное, ул. Свободы, д.2	Россия, республика Кабардино-Балкарская, Прохладненский район, село Граничное	0101000020E610000029AE2AFBAE044640787C7BD7A0F94540
37173	8	77	669	13777	62526	\N	43.676378	хутор Грабовец, ул. Красноармейская, д.29/1		0101000020E61000009B374E0AF3DE4540F0DDE68D93D64540
32213	8	75	\N	28634	33061	\N	43.845865000000003	Республика Дагестан, город Кизляр, Октябрьская, 47		0101000020E6100000F04C6892585A474060EAE74D45EC4540
37162	8	77	669	57986	62559	\N	43.925284136949799	сельское поселение Гвардейское, ул. Центральная, д.5	Россия, республика Кабардино-Балкарская, Прохладненский район, село Гвардейское	0101000020E61000005322895E460D46408BC1C3B46FF64540
37163	8	77	669	57982	62554	\N	43.8476072817489	сельское поселение Виноградное, ул. Мира, б/н	Россия, республика Кабардино-Балкарская, Прохладненский район, село Виноградное	0101000020E61000004BCD1E68050E46402B6EDC627EEC4540
37172	8	77	669	57967	62512	\N	43.691265310205402	сельское поселение Благовещенка, ул. Ленина, д.98	Россия, республика Кабардино-Балкарская, Прохладненский район, село Благовещенка	0101000020E6100000782AE09EE7E145404AEF1B5F7BD84540
37174	8	77	669	57956	62469	\N	43.717146999999997	сельское поселение Алтуд, ул. Комсомольская, д.25	Россия, республика Кабардино-Балкарская, Прохладненский район, село Алтуд	0101000020E61000005455682096EF454056B60F79CBDB4540
37175	8	77	669	57956	62473	\N	43.717457982213197	сельское поселение Алтуд, ул. Аптечная, д.54	Россия, республика Кабардино-Балкарская, Прохладненский район, село Алтуд	0101000020E61000007CED992501F045407520EBA9D5DB4540
37135	8	77	969	57950	62423	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Кабардинская, 191		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37129	8	77	969	57938	62360	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Ю. Фучика, 5		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37140	8	77	969	57938	62364	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Неделина, 9		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37083	8	77	969	57938	62349	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Инессы Арманд, 30		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37081	8	77	969	57938	62363	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Балкарская, 3		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37054	8	77	969	57938	62344	\N	43.484113999999998	Кабардино-Балкарская Республика, Городской округ Нальчик, Аттоева, 43		0101000020E61000007FA5F3E159CA454093C49272F7BD4540
37048	8	77	346	40233	9620	\N	43.6206936912115	ст. Котляревская, Лебедевых, 93	Россия, республика Кабардино-Балкарская, Майский район, Майский	0101000020E61000005680EF366F0846406669A7E672CF4540
37046	8	77	346	7785	62552	\N	43.718631999999999	п.Сарский, Мичурина, 6		0101000020E61000003048FAB48A0C4640F6ED2422FCDB4540
37050	8	77	346	45731	61346	\N	43.640188021614598	с. Ново-Ивановское, Ленина, 162	Россия, республика Кабардино-Балкарская, Майский район, село Новоивановское	0101000020E6100000EB54F99E91FA454055A52DAEF1D14540
37041	8	77	346	1725	\N	\N	43.630127000000002	"г. Майский, Административное здание Зверохозяйства ""Майский"""		0101000020E61000001E6B4606B9074640CEA96400A8D04540
35082	8	77	346	1725	62507	\N	43.630127000000002	г. Майский, Трудовая, 46		0101000020E61000001E6B4606B9074640CEA96400A8D04540
36931	8	77	346	1725	61348	\N	43.630127000000002	г. Майский, Октябрьская, 46	Россия, республика Кабардино-Балкарская, Майский район, Майский	0101000020E61000001E6B4606B9074640CEA96400A8D04540
37042	8	77	346	1725	61481	\N	43.630127000000002	г. Майский, Медведева, 10	Россия, республика Кабардино-Балкарская, Майский район, Майский	0101000020E61000001E6B4606B9074640CEA96400A8D04540
37043	8	77	346	1725	61436	\N	43.630127000000002	г. Майский, Кирова, 227	Россия, республика Кабардино-Балкарская, Майский район, Майский	0101000020E61000001E6B4606B9074640CEA96400A8D04540
37044	8	77	346	1725	61482	\N	43.630127000000002	г. Майский, Калинина, 125	Россия, республика Кабардино-Балкарская, Майский район, Майский	0101000020E61000001E6B4606B9074640CEA96400A8D04540
37038	8	77	346	1725	62359	\N	43.6300302653652	г. Майский, Горького, 116	Россия, республика Кабардино-Балкарская, Майский район, Майский	0101000020E6100000F299EC9FA7074640DBBFB2D2A4D04540
37039	8	77	346	1725	62335	\N	43.630127000000002	г. Майский, Гагарина, 10		0101000020E61000001E6B4606B9074640CEA96400A8D04540
37037	8	77	346	1725	61424	\N	43.630127000000002	г. Майский, 9 Мая, 181	Россия, республика Кабардино-Балкарская, Майский район, Майский	0101000020E61000001E6B4606B9074640CEA96400A8D04540
37051	8	77	346	57983	62555	\N	43.6177459190341	х. Колдрасинский, Центральная, 18	Россия, республика Кабардино-Балкарская, Майский район, село Колдрасинский	0101000020E6100000575EF23FF9F545400E9E094D12CF4540
37028	8	77	7451	57850	61526	\N	43.354935061257699	Кабардино-Балкарская Республика, Лескенский муниципальный район, Сельское поселение Второй Лескен, Шортанова, 46	Россия, Р-295 шоссе	0101000020E610000078094E7D20F54540569A94826EAD4540
36999	8	77	774	32651	62466	\N	43.945641999999999	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Этоко, Школьный, 1		0101000020E6100000DD5CFC6D4F964540ADDC0BCC0AF94540
37001	8	77	774	57960	62476	\N	43.882546510436001	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Шордаково, Ленина, 64	Россия, республика Кабардино-Балкарская, Зольский район, село Шардаково	0101000020E61000001211FE45D08E45406A17D34CF7F04540
37021	8	77	774	32800	62410	\N	43.728749999999998	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Хабаз, Ленина, 67		0101000020E6100000DD088B8A38774540E17A14AE47DD4540
37017	8	77	774	32788	62551	\N	43.801859999999998	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Совхозное, Школьная, 1а		0101000020E6100000064CE0D6DD9245403BFC3559A3E64540
37007	8	77	774	57957	62471	\N	43.653834000000003	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Камлюково, Школьная, 2	Россия, республика Кабардино-Балкарская, Зольский район	0101000020E6100000A2630795B8744540A6811FD5B0D34540
37000	8	77	774	52314	61364	\N	43.8969464963115	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Светловодское, ул.Октябрьская, д.94а	Россия, республика Кабардино-Балкарская, Зольский район, село Светловодское	0101000020E6100000DD5ED218AD99454096236420CFF24540
37015	8	77	774	32710	61366	\N	43.743510302659303	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Сармаково, Ленина, 211	Россия, республика Кабардино-Балкарская, Зольский район, село Сармаково	0101000020E61000001FBE4C14219B4540DE1FEF552BDF4540
37014	8	77	774	32710	61366	\N	43.738630999999998	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Сармаково, Ленина, 152		0101000020E610000074B33F506E994540E867EA758BDE4540
37013	8	77	774	32710	61366	\N	43.738630999999998	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Сармаково, Ленина, 51		0101000020E610000074B33F506E994540E867EA758BDE4540
37006	8	77	774	57959	62475	\N	43.859770728410801	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Псынадаха, Ленина, 108	Россия, республика Кабардино-Балкарская, Зольский район, село Псынодаха	0101000020E61000001E882CD2C49F45404D86E3F90CEE4540
37008	8	77	774	32730	62489	\N	43.801769	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Приречное, Буденного, 9		0101000020E610000088D860E124A745402BF9D85DA0E64540
37049	8	77	774	57971	62509	\N	43.892401999498396	с. Октябрьское, 50 Лет Октября, 42	Россия, республика Кабардино-Балкарская, Зольский район, село Октябрьское	0101000020E6100000028063CF9E93454047718E3A3AF24540
37011	8	77	774	52335	61365	\N	43.798397999999999	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Малка, Ленина, 60	Россия, республика Кабардино-Балкарская, Зольский район, село Малка	0101000020E610000072A3C85A43A945408D98D9E731E64540
37010	8	77	774	52335	61365	\N	43.798397999999999	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Малка, Ленина, 173	Россия, республика Кабардино-Балкарская, Зольский район, село Малка	0101000020E610000072A3C85A43A945408D98D9E731E64540
37009	8	77	774	52335	61365	\N	43.800387374386098	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Малка, Ленина, 371	Россия, республика Кабардино-Балкарская, Зольский район, село Малка	0101000020E610000072A3C85A43A945406092CA1473E64540
37022	8	77	774	52362	61367	\N	43.792217000000001	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Кичмалка, Чкалова, 34	Россия, республика Кабардино-Балкарская, Зольский район, село Кичмалка	0101000020E6100000AF963B33C1784540E92ADD5D67E54540
37018	8	77	774	32726	62399	\N	43.734800999999997	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Каменномостское, Ленина, 46		0101000020E61000000F2BDCF291864540B7088CF50DDE4540
37019	8	77	774	32726	61427	\N	43.734800999999997	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Каменномостское, Кумыкова, 5	Россия, республика Кабардино-Балкарская, Зольский район, село Каменномостское	0101000020E61000000F2BDCF291864540B7088CF50DDE4540
37020	8	77	774	32726	61428	\N	43.734800999999997	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Каменномостское, Куважукова, 101	Россия, республика Кабардино-Балкарская, Зольский район, село Каменномостское	0101000020E61000000F2BDCF291864540B7088CF50DDE4540
37005	8	77	774	32708	62483	\N	43.840071999999999	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Зольское, Советская, 96		0101000020E61000000BEF7211DF9945408524B37A87EB4540
37025	8	77	774	57849	62413	\N	43.901058523676397	Кабардино-Балкарская Республика, Зольский муниципальный район, Городское поселение Залукокоаже, Пятигорская, 1		0101000020E6100000253E7782FD9B45401B62BCE655F34540
37023	8	77	774	57849	62408	\N	43.902544446419498	Кабардино-Балкарская Республика, Зольский муниципальный район, Городское поселение Залукокоаже, Комсомольская, 34		0101000020E6100000E8BE9CD9AE9C4540BB99D18F86F34540
37024	8	77	774	57849	61525	\N	43.8976300559778	Кабардино-Балкарская Республика, Зольский муниципальный район, Городское поселение Залукокоаже, Кавказская, 8	Россия, республика Кабардино-Балкарская, Зольский район, поселок городского типа Залукокоаже	0101000020E6100000CF6BEC12D59B454049F4328AE5F24540
37004	8	77	774	52324	61420	\N	43.831553	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Залукодес, Школьная, 6	Россия, республика Кабардино-Балкарская, Зольский район, село Залукодес	0101000020E6100000A18499B67F93454002F2255470EA4540
37003	8	77	774	52319	62542	\N	43.823768999999999	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Дженал, Центральная, 1		0101000020E6100000A94F72874D8E4540B43A394371E94540
37002	8	77	774	40234	9625	\N	43.8816269415329	Кабардино-Балкарская Республика, Зольский муниципальный район, Сельское поселение Белокаменское, Центральная, 2	Россия, республика Кабардино-Балкарская, Зольский район, село Белокаменское	0101000020E6100000AA6400A8E2824540A3224E27D9F04540
35121	8	76	719	52932	60923	\N	43.305922000000002	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Троицкая, Ленина, 45		0101000020E61000001B65FD66627E46403F90BC7328A74540
36977	8	77	533	32748	62533	\N	43.716768999999999	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Псычох, ленина, 11	Россия, республика Кабардино-Балкарская, Баксанский район, село Псычох	0101000020E6100000E1EF17B325C34540B0E42A16BFDB4540
36976	8	77	533	32740	61435	\N	43.836964000000002	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Псыхурей, Катханова, 128	Россия, республика Кабардино-Балкарская, Баксанский район, село Псыхурей	0101000020E610000046CD57C9C7C84540F5F6E7A221EB4540
36973	8	77	533	52275	62343	\N	43.738605	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Нижний Куркужин, Октябрьская, 185		0101000020E61000005857056A31AC4540BFD4CF9B8ADE4540
36972	8	77	533	52275	62343	\N	43.738605	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Нижний Куркужин, Октябрьская, 260		0101000020E61000005857056A31AC4540BFD4CF9B8ADE4540
37296	8	77	533	32588	62522	\N	43.554485999999997	Кабардино-Балкарская Республика, Эльбрусский муниципальный район, Сельское поселение Лашкута, Мира, 12		0101000020E6100000E23AC615179B4540800BB265F9C64540
36982	8	77	533	32700	62474	\N	43.7732536112239	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Куба - Таба, Советская, 3а	Россия, республика Кабардино-Балкарская, Баксанский район, село Куба-Таба	0101000020E610000097E65608ABB9454027C0B0FCF9E24540
36981	8	77	533	32759	61473	\N	43.858924999999999	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Куба, Комсомольская, 80		0101000020E61000002310AFEB17BA4540C05B2041F1ED4540
36979	8	77	533	32759	61473	\N	43.858902721433502	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Куба, Комсомольская здание СДК	Россия, республика Кабардино-Балкарская, Баксанский район, село Куба	0101000020E61000009082A7902BBB4540D8B79388F0ED4540
36983	8	77	533	52293	61357	\N	43.796519705211601	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Кременчуг-Константиновское, Садовая, 56	Россия, республика Кабардино-Балкарская, Баксанский район, село Кременчуг-Константиновское	0101000020E61000009A79724D81D24540124E0B5EF4E54540
36984	8	77	533	32705	61358	\N	43.647852999999998	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Кишпек, Школьная, 4	Россия, республика Кабардино-Балкарская, Баксанский район, село Кишпек	0101000020E6100000F17F4754A8D24540C8CEDBD8ECD24540
36957	8	77	533	52250	62419	\N	43.672114000000001	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Исламей, переулок Алихбердова, дом 13		0101000020E6100000E9297288B8B945408597E0D407D64540
36959	8	77	533	52250	61425	\N	43.672114000000001	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Исламей, улица Эльбрусская, 129	Россия, республика Кабардино-Балкарская, Баксанский район, село Исламей	0101000020E6100000E9297288B8B945408597E0D407D64540
36961	8	77	533	52250	61433	\N	43.672114000000001	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Исламей, улица Надречная, 96	Россия, республика Кабардино-Балкарская, Баксанский район, село Исламей	0101000020E6100000E9297288B8B945408597E0D407D64540
36960	8	77	533	52250	61433	\N	43.672114000000001	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Исламей, улица Надречная, 127	Россия, республика Кабардино-Балкарская, Баксанский район, село Исламей	0101000020E6100000E9297288B8B945408597E0D407D64540
36966	8	77	533	52257	61352	\N	43.6103393098578	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Заюково, Кирова, 413	Россия, республика Кабардино-Балкарская, Баксанский район, село Заюково	0101000020E6100000B8AE9811DEA64540973C9E961FCE4540
36964	8	77	533	52257	61352	\N	43.611960779308198	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Заюково, Кирова, 242	Россия, республика Кабардино-Балкарская, Баксанский район, село Заюково	0101000020E6100000ECFB709010A94540B7B6F0BC54CE4540
36963	8	77	533	52257	61468	\N	43.6249309500758	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Заюково, Казаноко, 135	Россия, республика Кабардино-Балкарская, Баксанский район, село Заюково	0101000020E6100000EB707495EEAC4540D7A02FBDFDCF4540
36962	8	77	533	52257	61468	\N	43.625055649580403	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Заюково, улица Казаноко, б/н	Россия, республика Кабардино-Балкарская, Баксанский район, село Заюково	0101000020E6100000664D2CF015AD45409415C3D501D04540
36965	8	77	533	52257	62338	\N	43.613661999999998	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Заюково, Дикинова, 5		0101000020E61000002634492C29A945402366F6798CCE4540
36978	8	77	533	32681	62514	\N	43.562685000000002	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Жанхотеко, Пролетарская, 34		0101000020E6100000B686527B119B45409279E40F06C84540
35017	8	76	719	5003	60872	\N	43.305613999999998	Республика Ингушетия, городской округ Карабулак, Джабагиева, 139		0101000020E61000007A6D36566274464091990B5C1EA74540
36975	8	77	533	33139	62498	\N	43.692695000000001	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Верхний Куркужин, Октябрьская, 158		0101000020E610000019E25817B7A34540268DD13AAAD84540
36974	8	77	533	33139	62498	\N	43.692695000000001	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Верхний Куркужин, Октябрьская, 10		0101000020E610000019E25817B7A34540268DD13AAAD84540
36968	8	77	533	52263	62438	\N	43.684697	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Баксаненок, Березгова, 122		0101000020E61000008066101FD8D34540AC55BB26A4D74540
36967	8	77	533	52263	62420	\N	43.684697	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Баксаненок, Баксанская, 68		0101000020E61000008066101FD8D34540AC55BB26A4D74540
36969	8	77	533	52263	62334	\N	43.684697	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Баксаненок, Ахметова, 4	Россия, республика Кабардино-Балкарская, Баксанский район, село Баксаненок	0101000020E61000008066101FD8D34540AC55BB26A4D74540
36988	8	77	533	3280	61362	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Угнич, д.1	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36987	8	77	533	3280	62341	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Р.Калмыкова, д.1		0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36992	8	77	533	3280	61445	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Панаиоти, д.9	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36989	8	77	533	3280	61444	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Николаева, д.2	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36985	8	77	533	3280	62329	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, проспект Ленина, д.23	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36993	8	77	533	3280	61477	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, переулок Иванова, д.1	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36958	8	77	533	3280	62336	\N	43.685628999999999	"Кабардино-Балкарская Республика, Городской округ Баксан, улица  Бесланеева, д.7""Б"""	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36995	8	77	533	3280	62460	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Баксанова, д.24		0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36994	8	77	533	3280	61450	\N	43.685628999999999	Кабардино-Балкарская Республика, Городской округ Баксан, улица Апанасова, д.72	Россия, республика Кабардино-Балкарская, Баксанский район, Баксан	0101000020E61000001E4FCB0F5CC545403718EAB0C2D74540
36970	8	77	533	52269	62445	\N	43.644734999999997	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Атажукино, Катанчиева, 56		0101000020E61000003140A20914B3454014CB2DAD86D24540
36971	8	77	533	52269	61354	\N	43.643071989539997	Кабардино-Балкарская Республика, Баксанский муниципальный район, Сельское поселение Атажукино, Апшева, 85	Россия, республика Кабардино-Балкарская, Баксанский район, село Атажукино	0101000020E6100000B0FECF61BEB24540957CEC2E50D24540
35031	8	76	\N	57730	60950	\N	43.50835	Республика Ингушетия, город Малгобек, Осканова 14, Культурно-досуговый центр гМалгобек		0101000020E610000096D05D12674B4640F775E09C11C14540
35033	8	76	\N	57730	60961	\N	43.50835	Республика Ингушетия, город Малгобек, Обороны Кавказа 9, Средняя школа  №9		0101000020E610000096D05D12674B4640F775E09C11C14540
35029	8	76	\N	57730	60859	\N	43.50835	"Республика Ингушетия, город Малгобек, Нурадилова 108, Издательство газеты  "" Сердало"""		0101000020E610000096D05D12674B4640F775E09C11C14540
35035	8	76	\N	57730	60905	\N	43.50835	Республика Ингушетия, город Малгобек, Калинина 11, Средняя школа №1		0101000020E610000096D05D12674B4640F775E09C11C14540
35027	8	76	\N	57730	60913	\N	43.50835	Республика Ингушетия, город Малгобек, Гоголя 2, Средняя школа №18		0101000020E610000096D05D12674B4640F775E09C11C14540
35028	8	76	\N	57730	60858	\N	43.50835	Республика Ингушетия, город Малгобек, Гарданова 108, Детский сад №5		0101000020E610000096D05D12674B4640F775E09C11C14540
35024	8	76	\N	57730	60858	\N	43.50835	Республика Ингушетия, город Малгобек, Гарданова 54, Школа детского техн,творчества		0101000020E610000096D05D12674B4640F775E09C11C14540
35135	8	76	719	52961	60964	\N	43.176992977073198	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Чемульга, Широкая, 1	Россия, республика Ингушская, Сунженский район, село Чемульга	0101000020E6100000062E8F35239146407B4FE5B4A7964540
35137	8	76	719	52932	\N	\N	43.300363052498298	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Троицкое	Россия, республика Ингушская, Сунженский район, село Троицкая	0101000020E6100000772E8CF4A27E4640D7F6764B72A64540
35122	8	76	719	52932	60958	\N	43.305922000000002	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Троицкая, Шоссейная 1		0101000020E61000001B65FD66627E46403F90BC7328A74540
35120	8	76	719	52932	60924	\N	43.305922000000002	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Троицкая, Колхозная, 112 Дом культуры		0101000020E61000001B65FD66627E46403F90BC7328A74540
35115	8	76	719	57736	60902	\N	43.316241903690702	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Энгельса, 68	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E6100000685BCD3AE385464092CF2B9E7AA84540
35136	8	76	719	57736	60973	\N	43.317312956322098	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Аршты, Шерипова, 98	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E610000038F7578FFB8646403ECC5EB69DA84540
35119	8	76	719	57736	60932	\N	43.320419827011598	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Трудовая, 1	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E6100000C8B60C384B874640FE7DC68503A94540
35117	8	76	719	57736	60916	\N	43.318163772646301	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Рабочая, 85	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E6100000CC0A45BA9F854640DD611399B9A84540
35130	8	76	719	57736	60945	\N	43.3209211609691	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Мужичи, Осканова, 24	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E610000050AA7D3A1E874640C0CC77F013A94540
35112	8	76	719	57736	60945	\N	43.319918488887801	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Осканова, 73 ДК	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E610000050AA7D3A1E8746406CB3B112F3A84540
35118	8	76	719	57736	60988	\N	43.319500735172603	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Новая Кирова, 10	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E6100000A8C64B37898546400805A568E5A84540
35124	8	76	719	57736	60927	\N	43.3093894259138	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Нестеровская, Мира, 9	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E6100000685BCD3AE3854640FF5E0A0F9AA74540
35110	8	76	719	57736	60885	\N	43.3179966853899	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Менделеева, 36	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E6100000CC0A45BA9F854640F19C2D20B4A84540
35123	8	76	719	57736	60895	\N	43.320921160969199	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Нестеровская, Ленина, 68	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E6100000A47213B534874640C0CC77F013A94540
35111	8	76	719	57736	60895	\N	43.318623377356097	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Ленина, 157	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E61000006EFB1EF5D7854640706072A3C8A84540
35116	8	76	719	57736	60922	\N	43.318748714968102	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Демченко, 68	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E610000020D3DA34B6854640FC5069C4CCA84540
35113	8	76	719	57736	60983	\N	43.317119312873203	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Грозненская, 1	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E61000002C0C91D3D787464059F8FA5A97A84540
35114	8	76	719	57736	60933	\N	43.307132959103797	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Орджоникидзевское, Висаитова, 20	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E610000093C3279D48864640DD42572250A74540
35126	8	76	719	57736	60886	\N	43.320503414196999	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Алхасты, Ленина, 46	Россия, республика Ингушская, Сунженский район, село Орджоникидзевская	0101000020E61000001A33897AC18546408CA2073E06A94540
35125	8	76	719	52940	60908	\N	43.234470000000002	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Нестеровская, Шоссейная 1		0101000020E6100000129F3BC1FE85464052F2EA1C039E4540
35014	8	76	719	5003	60909	\N	43.305613999999998	Республика Ингушетия, городской округ Карабулак, Фрунзе, 12		0101000020E61000007A6D36566274464091990B5C1EA74540
35019	8	76	719	5003	60877	\N	43.305613999999998	Республика Ингушетия, городской округ Карабулак, Осканова, 139		0101000020E61000007A6D36566274464091990B5C1EA74540
35018	8	76	719	5003	60877	\N	43.305613999999998	Республика Ингушетия, городской округ Карабулак, Осканова, 120		0101000020E61000007A6D36566274464091990B5C1EA74540
35016	8	76	719	5003	60877	\N	43.305613999999998	Республика Ингушетия, городской округ Карабулак, Осканова, 65		0101000020E61000007A6D36566274464091990B5C1EA74540
35015	8	76	719	5003	60877	\N	43.305613999999998	Республика Ингушетия, городской округ Карабулак, Осканова, 76		0101000020E61000007A6D36566274464091990B5C1EA74540
35013	8	76	719	5003	60877	\N	43.305613999999998	Республика Ингушетия, городской округ Карабулак, Осканова, 1		0101000020E61000007A6D36566274464091990B5C1EA74540
35132	8	76	719	57740	60952	\N	43.0299547372665	Республика Ингушетия, Сунженский район, село Датых, Кавказская, 1	Россия, республика Ингушская, Сунженский район, село Даттых	0101000020E610000065A6B4FE968C464004ADC090D5834540
35129	8	76	719	32554	60947	\N	43.0937678219479	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Галашки, Шоссейная, 43	Россия, республика Ингушская, Сунженский район, село Галашки	0101000020E61000009E42AED4B37E4640A6B4FE96008C4540
35127	8	76	719	32554	60906	\N	43.095888000000002	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Галашки, Школьная, 48		0101000020E610000043E21E4B1F7E4640180AD80E468C4540
35128	8	76	719	32554	60953	\N	43.095888000000002	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Галашки, Исламская, 31		0101000020E610000043E21E4B1F7E4640180AD80E468C4540
35131	8	76	719	52956	60962	\N	42.967123000000001	Республика Ингушетия, Сунженский муниципальный район, сельское поселение Алкун, Мира, 30		0101000020E610000059897956D2824640CE1ABCAFCA7B4540
35133	8	76	719	57743	60976	\N	43.217996100471503	село Берд-Юрт, 6-Линия, 1		0101000020E61000006B47718E3A8E46405454FD4AE79B4540
35080	8	76	762	57733	60867	\N	43.270901890050602	Республика Ингушетия, Назрановский район, село Яндаре, Орджоникидзе, 69	Россия, республика Ингушская, Назрановский район, село Яндырка	0101000020E61000008333F8FBC5744640E335AFEAACA24540
35079	8	76	762	57733	60867	\N	43.272751810111501	Республика Ингушетия, Назрановский район, село Яндаре, Орджоникидзе, 9	Россия, республика Ингушская, Назрановский район, село Яндырка	0101000020E6100000A3C85A43A975464094F59B89E9A24540
35081	8	76	762	57733	60912	\N	43.267389556506302	Республика Ингушетия, Назрановский район, село Яндаре, Мальсагова, 14	Россия, республика Ингушская, Назрановский район, село Яндырка	0101000020E610000091F0BDBF4175464083A3E4D539A24540
35102	8	76	762	9289	60864	\N	43.205537	Республика Ингушетия, Назрановский район, село Экажево, Осканова, 68		0101000020E6100000B3F0F5B52E694640198F52094F9A4540
35101	8	76	762	9289	60864	\N	43.205540572276597	Республика Ингушетия, Назрановский район, село Экажево, Осканова, 65	Россия, республика Ингушская, Назрановский район, село Экажево	0101000020E6100000FEEE1D35266A46405A7EE02A4F9A4540
35100	8	76	762	\N	60869	\N	43.088893707748099	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Экажево, Ингушская, 47	Россия, республика Ингушская, Сунженский район	0101000020E6100000D0ECBAB722754640C367EBE0608B4540
35099	8	76	762	9289	60981	\N	43.199737352161101	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Экажево, Бекова, 7	Россия, республика Ингушская, Назрановский район, село Экажево	0101000020E6100000FEB7921D1B6946408C6665FB90994540
35087	8	76	762	32980	60929	\N	43.184905999999998	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Сурхахи, Школьная, 1		0101000020E61000009DF3531C07744640C66AF3FFAA974540
35086	8	76	762	32980	60934	\N	43.184905999999998	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Сурхахи, Т.Аушева, 34		0101000020E61000009DF3531C07744640C66AF3FFAA974540
35105	8	76	762	52894	60926	\N	43.280430000000003	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Плиево, Осканова, 44		0101000020E61000002DB0C7444A6B46409D685721E5A34540
35011	8	76	762	52651	61057	\N	42.799632000000003	Республика Ингушетия, Джейрахский муниципальный район, сельское поселение Ольгети, Путина, 37		0101000020E6100000F699B33EE5604640E46A64575A664540
35064	8	76	762	57731	60893	\N	43.210014660457198	Республика Ингушетия, городской округ Назрань, Насыр-кортский административный округ, Почтовая, 32	Россия, республика Ингушская, Назрановский район, село Насыр Корт	0101000020E6100000DF87838428674640B05582C5E19A4540
35067	8	76	762	57731	60897	\N	43.213844215429098	Республика Ингушетия, городской округ Назрань, Насыр-кортский административный округ, Партизанская, 4	Россия, республика Ингушская, Назрановский район, село Насыр Корт	0101000020E6100000DB4FC6F83067464011397D3D5F9B4540
35066	8	76	762	57731	60861	\N	43.210851701782097	Республика Ингушетия, городской округ Назрань, Насыр-кортский административный округ, Муталиева, 24	Россия, республика Ингушская, Назрановский район, село Насыр Корт	0101000020E610000003CC7C073F674640EA25C632FD9A4540
35065	8	76	762	7390	60868	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Насыр-кортский административный округ, Эсмурзиева, 23		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35063	8	76	762	7390	60889	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Насыр-кортский административный округ, Школьная, 21		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35077	8	76	762	7390	60875	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Фабричная, 3		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35085	8	76	762	7390	60873	\N	43.223511194762899	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Сурхахи, Т.Аушева, 65	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E6100000E7C75F5AD4634640ECA529029C9C4540
35084	8	76	762	7390	60873	\N	43.2104110904707	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Сурхахи, Т.Аушева, 6	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E610000066A032FE7D624640FDDB65BFEE9A4540
35062	8	76	762	7390	60888	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Гамурзиевский административный округ, Суворова, 4		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35107	8	76	762	7390	60876	\N	43.221439829134297	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Плиево, Осканова, 97	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E610000004577902616346405C035B25589C4540
35106	8	76	762	7390	60876	\N	43.232757060471002	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Плиево, Осканова, 94	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E6100000B4C876BE9F62464021753BFBCA9D4540
35078	8	76	762	7390	60876	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Осканова, 29		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35070	8	76	762	7390	60876	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Осканова, 27		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35073	8	76	762	7390	60862	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Муталиева, 24		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35075	8	76	762	7390	60874	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Московская, 35		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35069	8	76	762	7390	60910	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Альтиевский административный округ, Коммунальная, 1		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35071	8	76	762	7390	60896	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Картоева, 98		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35074	8	76	762	7390	60898	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Кавказская, 10		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35076	8	76	762	7390	60863	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Ингушская, 27		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35103	8	76	762	7390	60904	\N	43.230748771359302	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Барсуки, Зязикова, 5	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E61000001878EE3D5C624640D84AE82E899D4540
35098	8	76	762	7390	60879	\N	43.2204552435959	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Экажево, Джабагиева, 1 а	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E6100000FA264D83A2634640AE9E93DE379C4540
35097	8	76	762	7390	60879	\N	43.215182270956099	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Экажево, Джабагиева, 2	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E610000052431B800D6246400C5872158B9B4540
35096	8	76	762	7390	60878	\N	43.2320039598645	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Долаково, Дахкильгова, 9	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E6100000EE93A3005162464046459C4EB29D4540
35094	8	76	762	7390	60878	\N	43.223092778849001	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Долаково, Дахкильгова, 36	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E61000002463B5F97F634640B77BB94F8E9C4540
35092	8	76	762	7390	60894	\N	43.220204160074303	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Кантышево, Базоркино, 7	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E6100000C05B2041F1634640653909A52F9C4540
35072	8	76	762	7390	60871	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Центральный административный округ, Базоркина, 68		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35061	8	76	762	7390	60887	\N	43.222757999999999	Республика Ингушетия, городской округ Назрань, Гамурзиевский административный округ, Албогачиева, 143		0101000020E6100000CB2BD7DB6662464010768A55839C4540
35108	8	76	762	7390	60918	\N	43.214763792685098	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Плиево, Осканова, 14	Россия, республика Ингушская, Назрановский район, Назрань	0101000020E6100000D80C7041B6624640D82D02637D9B4540
35088	8	76	762	5358	60957	\N	43.171558060452298	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Али-Юрт, Зязикова, 28	Россия, республика Ингушская, Назрановский район, Магас	0101000020E610000010070951BE684640FFAECF9CF5954540
35020	8	76	762	5358	60856	\N	43.173073000000002	Республика Ингушетия, городской округ Магас, А.Бокова, 1		0101000020E6100000BA4BE2AC886846400A698D4127964540
35009	8	76	762	52647	60967	\N	42.808416000000001	Республика Ингушетия, Джейрахский муниципальный район, сельское поселение Ляжги, Точиева, 8		0101000020E6100000BB7B80EECB5D464015C8EC2C7A674540
35090	8	76	762	52857	60935	\N	43.226647	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Кантышево, Школьная, 14		0101000020E61000007714E7A8A3514640465ED6C4029D4540
35093	8	76	762	52857	61006	\N	43.223257794640801	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Кантышево, Шерипова, 1	Россия, республика Ингушская, Назрановский район, село Кантышево	0101000020E6100000103B53E8BC5046400249D8B7939C4540
35091	8	76	762	52857	60928	\N	43.226647	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Кантышево, Дзаурова, 33		0101000020E61000007714E7A8A3514640465ED6C4029D4540
35012	8	76	762	33110	60949	\N	42.810069549362197	Республика Ингушетия, Джейрахский муниципальный район, сельское поселение Гули, Укурова, 17	Россия, республика Ингушская, Назрановский район, село Гули	0101000020E610000045A165DD3F66464041BCAE5FB0674540
35060	8	76	762	57737	60907	\N	43.214220879885403	Республика Ингушетия, городской округ Назрань, Гамурзиевский административный округ, Албогачиева, 7	Россия, республика Ингушская, Назрановский район, село Гамурзиево	0101000020E610000035D4282499654640E78EFE976B9B4540
35109	8	76	762	60643	75500	\N	43.401005636475702	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Гейрбек-Юрт, Центральная, 1		0101000020E610000034643C4A254C4640F9BF232A54B34540
35083	8	76	762	32968	60955	\N	43.260185999999997	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Гази-Юрт, Школьная, 10		0101000020E61000001CEDB8E1776B464043705CC64DA14540
35010	8	76	762	52649	60960	\N	42.834192999999999	Республика Ингушетия, Джейрахский муниципальный район, сельское поселение Бейни, Центральная, 12		0101000020E6100000C3D4963AC85B4640ACC612D6C66A4540
35104	8	76	762	33062	60943	\N	43.261288999999998	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Барсуки, Левобережная, 27		0101000020E61000001CEC4D0CC9674640FBE6FEEA71A14540
35068	8	76	762	57739	60940	\N	43.237784355246298	Республика Ингушетия, городской округ Назрань, Альтиевский административный округ, ул. Школьная, б/н	Россия, республика Ингушская, Назрановский район, село Альтиево	0101000020E6100000D105F52D736446408BC1C3B46F9E4540
35089	8	76	762	52853	60925	\N	43.141768999999996	Республика Ингушетия, Назрановский муниципальный район, сельское поселение Али-Юрт, Ахриева, 58		0101000020E6100000CC0BB08F4E6D4640164B917C25924540
35048	8	76	767	52761	60968	\N	43.517234999999999	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Южный, ул.Базоркина, 6		0101000020E6100000A81B28F04E5E46405CACA8C134C24540
35056	8	76	767	32767	60941	\N	43.369897999999999	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Средние Ачалуки, ул.Школьная, 2		0101000020E6100000C780ECF5EE5D46408B6D52D158AF4540
35055	8	76	767	32767	60901	\N	43.369897999999999	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Средние Ачалуки, ул.Рабочая, 6		0101000020E6100000C780ECF5EE5D46408B6D52D158AF4540
35039	8	76	767	52734	60911	\N	43.482793000000001	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Сагопши, ул.Школьная, 80		0101000020E61000006281AFE8D64B46406EDE3829CCBD4540
35038	8	76	767	52734	60911	\N	43.483546212094097	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Сагопши, ул.Школьная, 73	Россия, республика Ингушская, Малгобекский район, село Сагопши	0101000020E61000009755D80C704B4640490ED8D5E4BD4540
35040	8	76	767	52734	60921	\N	43.482793000000001	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Сагопши, ул.Гарданова, 38		0101000020E61000006281AFE8D64B46406EDE3829CCBD4540
35043	8	76	767	52742	60951	\N	43.466515999999999	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Пседах, ул.Фрунзе, 2а		0101000020E6100000F41ABB44F5484640C687D9CBB6BB4540
35051	8	76	767	52766	60915	\N	43.471659000000002	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Новый Редант, ул.Шоссейная		0101000020E6100000F705F4C29D6746409AEE75525FBC4540
35053	8	76	767	52767	60899	\N	43.400979	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Нижние Ачалуки, ул.Шоссейная, 17		0101000020E6100000DC2BF3565D614640FFB0A54753B34540
35054	8	76	767	52767	60900	\N	43.400979	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Нижние Ачалуки, ул.Кооперативная, 15		0101000020E6100000DC2BF3565D614640FFB0A54753B34540
35021	8	76	767	5401	60939	\N	43.50835	Республика Ингушетия, город Малгобек, пер.Осканова 2, школа-гимназия №1		0101000020E610000096D05D12674B4640F775E09C11C14540
35058	8	76	767	5401	60936	\N	43.514099487219497	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Верхние Ачалуки, ул.Эсамбаева, 45	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E610000039F24064914A464002F4FBFECDC14540
35052	8	76	767	5401	60920	\N	43.503854275376497	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Новый Редант, ул. Шоссейная, 24	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E6100000CEC47421564D4640B9FAB1497EC04540
35047	8	76	767	5401	60855	\N	43.495731826543	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Вознесенское, ул.Школьная, 30	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E6100000286552431B4A464053CA6B2574BF4540
35042	8	76	767	5401	60855	\N	43.504354082439001	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Пседах, ул.Школьная, 20	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E6100000164D6727834D4640ABCDFFAB8EC04540
35025	8	76	767	5401	60855	\N	43.50835	Республика Ингушетия, город Малгобек, Школьная 9, Школа-интернат №4		0101000020E610000096D05D12674B4640F775E09C11C14540
35044	8	76	767	5401	60890	\N	43.514099487219497	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Инарки, ул.Укурова, 13	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E610000012DE1E84804A464002F4FBFECDC14540
32215	8	75	\N	28634	33060	\N	43.845865000000003	Республика Дагестан, город Кизляр, Набережная, 44		0101000020E6100000F04C6892585A474060EAE74D45EC4540
35041	8	76	767	5401	60866	\N	43.503104556969099	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Пседах, ул.Нурадилова, 35	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E610000049D92269374A46401FBAA0BE65C04540
35022	8	76	767	5401	60866	\N	43.509411953995901	Республика Ингушетия, город Малгобек, Нурадилова 64, Станция скорой помощи	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E6100000E622BE13B34A46405018946934C14540
35049	8	76	767	5401	60974	\N	43.510018241048499	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Аки-Юрт, ул.Молодежная, 13	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E610000049D92269374A4640882F134548C14540
35050	8	76	767	5401	60882	\N	43.5078204030713	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Зязиков-Юрт, ул.Кавказская, 1	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E61000007F6B274A424C46409B20EA3E00C14540
35037	8	76	767	5401	60881	\N	43.506071161279102	Республика Ингушетия, городской округ Малгобек, Кабардинская 48, Частный кафе	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E6100000069D103AE84C46401D3A3DEFC6C04540
35030	8	76	767	5401	60931	\N	43.511318733507402	Республика Ингушетия, город Малгобек, Железнодорожная 16, Средняя школа №6	Россия, республика Ингушская, Малгобекский район, Малгобек	0101000020E6100000C7F319506F4C46406669A7E672C14540
35023	8	76	767	5401	60884	\N	43.50835	Республика Ингушетия, город Малгобек, ул.Горданова 23, ОСШ №20		0101000020E610000096D05D12674B4640F775E09C11C14540
35036	8	76	767	5401	60944	\N	43.50835	Республика Ингушетия, городской округ Малгобек, ул.Гарданова, 39		0101000020E610000096D05D12674B4640F775E09C11C14540
35034	8	76	767	5401	60942	\N	43.50835	Республика Ингушетия, город Малгобек, Вокзальная, 25, Средняя школа №13		0101000020E610000096D05D12674B4640F775E09C11C14540
35046	8	76	767	52751	60966	\N	43.470756000000002	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Инарки, ул.Укурова, 47	Россия, республика Ингушская, Малгобекский район, село Инарки	0101000020E6100000B0ABC95356454640A9328CBB41BC4540
35057	8	76	767	52777	60917	\N	43.345475	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Верхние Ачалуки, ул.Чапанова, 7		0101000020E610000067EDB60BCD594640F54A598638AC4540
35059	8	76	767	52785	60956	\N	43.596809676427	Республика Ингушетия, Малгобекский муниципальный район, сельское поселение Вежарий, ул.Советская, 1	Россия, республика Ингушская, Малгобекский район, село Вежарий	0101000020E610000024B9FC87F44946407FF6234564CC4540
35007	8	76	7446	57762	61132	\N	42.820976202062099	Республика Ингушетия, Джейрахский муниципальный район, сельское поселение Джейрах, Льянова, 35	Россия, республика Ингушская, Назрановский район, село Джайрах	0101000020E61000005B99F04BFD5646408466D7BD15694540
35008	8	76	7446	57742	60971	\N	43.117220000000003	Республика Ингушетия, Джейрахский район, село Армхи, Льянова, 53		0101000020E6100000662FDB4E5B714640F437A110018F4540
33273	8	75	\N	16348	33051	\N	44.662647999999997	Республика Дагестан, город Южно-Сухокумск, площадь Имама Шамиля, ГЦК городской дворец кудьтуры		0101000020E6100000FD84B35BCBD24640416150A6D1544640
33272	8	75	\N	16348	32989	\N	44.662647999999997	Республика Дагестан, город Южно-Сухокумск, Комарова, школа №4		0101000020E6100000FD84B35BCBD24640416150A6D1544640
33274	8	75	\N	16348	33091	\N	44.662647999999997	Республика Дагестан, город Южно-Сухокумск, Горького, ПУ №28   (политехническое училище)		0101000020E6100000FD84B35BCBD24640416150A6D1544640
32982	8	75	\N	953	33037	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, фабричная, 48		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32974	8	75	\N	953	32968	\N	43.251881006949397	город Хасавюрт, Ярыксувская, 5	Россия, республика Дагестан, Хасавюрт	0101000020E610000071AAB5300B4B4740ECBDF8A23DA04540
32973	8	75	\N	953	32968	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Ярыксувская, 5		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32984	8	75	\N	953	33006	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Хизроева, 35		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32968	8	75	\N	953	33001	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Тотурбиева, 65		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32559	8	75	\N	953	33001	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Тотурбиева, 61		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32977	8	75	\N	953	33159	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Стальского, 27		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32762	8	75	\N	953	33049	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Нурадилова, 53		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32979	8	75	\N	953	33161	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Новая, 1		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32981	8	75	\N	953	33089	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Махачкалинское шоссе, 29 А		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32980	8	75	\N	953	33089	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Махачкалинское шоссе, 29		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32972	8	75	\N	953	33089	\N	43.254547809929299	Республика Дагестан, город Хасавюрт, Махачкалинское шоссе, 10	Россия, республика Дагестан, Хасавюрт	0101000020E61000001B6327BC044B474090A1630795A04540
32965	8	75	\N	953	32962	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Коркмасова, 1		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32847	8	75	\N	953	33136	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Кандуровская, 96		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32964	8	75	7293	\N	33113	\N	43.263141947460802	Республика Дагестан, город Хасавюрт, Завокзальная, 71	Россия, республика Дагестан, Хасавюрт городской округ	0101000020E6100000977329AE2A4B47401E1A16A3AEA14540
32969	8	75	\N	953	33158	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Даибова, 6		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32971	8	75	\N	953	33088	\N	43.2541478704985	Республика Дагестан, город Хасавюрт, Буйнакская, 95	Россия, республика Дагестан, Хасавюрт	0101000020E61000006EC328081E4B4740022CF2EB87A04540
32983	8	75	\N	953	33162	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Бригадная, 15		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32682	8	75	\N	953	33077	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Батырмурзаева, 65		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32978	8	75	\N	953	33139	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, Автобусная, 27		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32976	8	75	\N	953	33140	\N	43.253323999999999	Республика Дагестан, город Хасавюрт, 40 лет Октября, 2		0101000020E61000006EDA8CD3104B47405DA5BBEB6CA04540
32985	8	75	7293	\N	32967	\N	43.232884537510699	Республика Дагестан, город Хасавюрт, Датуева, 70	Россия, республика Дагестан, Хасавюрт городской округ	0101000020E6100000183E22A6444C47404F5DF92CCF9D4540
32511	8	75	\N	6655	\N	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Танкаева, 58 корп.1	Россия, республика Дагестан, Махачкала	0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32448	8	75	\N	6655	\N	\N	42.976722000000002	"Республика Дагестан, город Махачкала, Кировский район, Буйнакского, Центр - помещение ж/д вокзала ""г. Махачкала"""		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32439	8	75	\N	6655	\N	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, поселок Шамхал, Центр - помещение МОУ СОШ № 49		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32435	8	75	\N	6655	\N	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, поселок Ленинкент, Центр - помещение МОУ СОШ № 35	Россия, республика Дагестан, Махачкала	0101000020E61000001F4DF564FEBD474051A4FB39057D4540
31772	8	75	\N	6655	\N	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ругуджинский кутан, здание АФ		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32510	8	75	\N	6655	32943	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, пр. Акушинского, 13		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32553	8	75	7299	\N	33098	\N	42.928584562083003	Республика Дагестан, город Махачкала, Советский район, поселок Тарки, п.Тарки, 85	Россия, республика Дагестан, Махачкала городской округ, поселок городского типа Альбурикент	0101000020E61000006A32E36DA5C3474030478FDFDB764540
32465	8	75	\N	6655	32937	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЯРАГСКОГО, 67		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32459	8	75	\N	6655	32937	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЯРАГСКОГО, 15		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32499	8	75	\N	6655	32936	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Ярагского, 78		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32468	8	75	\N	6655	32936	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЯРАГСКОГО, 75		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32467	8	75	\N	6655	32938	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЮСУПОВА, 70		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32551	8	75	\N	6655	33028	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Энгельса, 3-в		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32544	8	75	\N	6655	33028	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Энгельса, 12-б		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32540	8	75	\N	6655	33028	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, энгельса, 11		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32537	8	75	\N	6655	33028	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Энгельса, 48а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32536	8	75	\N	6655	33028	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Энгельса, 48-а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32530	8	75	\N	6655	33028	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Энгельса, 23		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32410	8	75	\N	6655	33130	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Эмирова, 7		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32529	8	75	\N	6655	32928	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, школьная, 22		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32542	8	75	\N	6655	32999	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Шамиля, 14-а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32535	8	75	\N	6655	32999	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Шамиля, 44а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32532	8	75	\N	6655	32999	\N	42.9725539824354	Республика Дагестан, город Махачкала, Советский район, Шамиля, 42-б	Россия, республика Дагестан, Махачкала	0101000020E61000002B357BA015BE474008CC43A67C7C4540
32512	8	75	\N	6655	32999	\N	42.961570503215199	Республика Дагестан, город Махачкала, Советский район, Шамиля, 70		0101000020E610000038A27BD635C0474019E42EC2147B4540
32470	8	75	\N	6655	32999	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ШАМИЛЯ, 47 корпус !		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32473	8	75	\N	6655	32944	\N	42.957528022625702	Республика Дагестан, город Махачкала, Ленинский район, ШАМИЛЯ, 85А	Россия, республика Дагестан, Махачкала	0101000020E61000001E5036E50AC147408D800A47907A4540
32487	8	75	\N	6655	33003	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ХУШЕТ, МДОУ 21		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32485	8	75	\N	6655	33003	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ХУШЕТ, ДОМ КУЛЬТУРЫ		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32546	8	75	\N	6655	33069	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Хуршилова, 3		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32547	8	75	\N	6655	33071	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Хуршилова, 14		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32486	8	75	\N	6655	33148	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ХУШЕТ, МОУ 16		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32509	8	75	\N	6655	33103	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Танкаева, 58 КОРП.2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32549	8	75	\N	6655	33075	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Североосетинская, 87, корпус 2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32548	8	75	\N	6655	33075	\N	42.977210432518802	Республика Дагестан, город Махачкала, Советский район, Североосетинская, 87	Россия, республика Дагестан, Махачкала	0101000020E6100000242713B70ABE47407EA99F37157D4540
32463	8	75	\N	6655	33085	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, СТУДЕНЧЕСКИЙ ПЕРЕУЛОК, 3 корпус 2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32462	8	75	\N	6655	33085	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, СТУДЕНЧЕСКИЙ ПЕРЕУЛОК, 3 корпус 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32534	8	75	\N	6655	33150	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Проспект шамиля, 46		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32541	8	75	\N	6655	32994	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Проспект Шамиля, 14		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32533	8	75	\N	6655	32994	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Проспект Шамиля, 24		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32531	8	75	\N	6655	32994	\N	42.972735185399301	Республика Дагестан, город Махачкала, Советский район, Проспект Шамиля, 42-б	Россия, республика Дагестан, Махачкала	0101000020E61000006AA510C825BE474058569A94827C4540
32476	8	75	\N	6655	32994	\N	42.954549181546398	Республика Дагестан, город Махачкала, Ленинский район, ШАМИЛЯ, 89Д	Россия, республика Дагестан, Махачкала	0101000020E61000009702D2FE07C24740FAB660A92E7A4540
32415	8	75	\N	6655	33121	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Островского, 18		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32477	8	75	\N	6655	33147	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, О.КОШЕВОГО, 34А		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32466	8	75	\N	6655	33142	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, НИКОЛАЕВА, 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32494	8	75	\N	6655	32972	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, НАСРУТДИНОВА, 44Д корпус 2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32493	8	75	\N	6655	32972	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, НАСРУТДИНОВА, 44Д корпус !		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32451	8	75	\N	6655	32972	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, НАСРУТДИНОВА, 63-Б		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32450	8	75	\N	6655	32972	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, НАСРУТДИНОВА, 53-Б		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32449	8	75	\N	6655	32972	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, НАСРУТДИНОВА, 61		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32492	8	75	\N	6655	32984	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, Н-КЯХУЛАЙ, МОУ48		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32491	8	75	\N	6655	32984	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, Н-КЯХУЛАЙ, МОУ 32		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32416	8	75	\N	6655	32909	\N	42.999775667193497	Республика Дагестан, город Махачкала, Кировский район, Маяковского, 52	Россия, республика Дагестан, Махачкала	0101000020E6100000056EDDCD53B94740B0A9F3A8F87F4540
32508	8	75	\N	6655	33149	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Ляхова, 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32522	8	75	\N	6655	32992	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Ломоносова, 13-а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32500	8	75	\N	6655	32911	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Ленина, 12		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32497	8	75	\N	6655	32911	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Ленина, 16		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32496	8	75	\N	6655	32911	\N	42.981511560134699	Республика Дагестан, город Махачкала, Советский район, Ленина, 43	Россия, республика Дагестан, Махачкала	0101000020E61000003080F0A144BF4740D7506A2FA27D4540
32409	8	75	\N	6655	33166	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Левина, 39		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32455	8	75	\N	6655	33031	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЛАПТИЕВА, 45 корпус 2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32454	8	75	\N	6655	33031	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЛАПТИЕВА, 45 корпус 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32453	8	75	\N	6655	33031	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЛАПТИЕВА, 51		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32456	8	75	\N	6655	33035	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЛАПТИЕВА, 28		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32452	8	75	\N	6655	33033	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ЛАПТИЕВА, 59-А		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32417	8	75	\N	6655	33122	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Л. Чайкиной, 30		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32504	8	75	\N	6655	32985	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Коркмасова, 8		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32418	8	75	\N	6655	33167	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Каммаева, 8		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32426	8	75	\N	6655	32970	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, казбекова, 39-А		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32424	8	75	\N	6655	32970	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Казбекова, 153		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32423	8	75	\N	6655	32970	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Казбекова, 155		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32421	8	75	\N	6655	32970	\N	42.972577617634997	Республика Дагестан, город Махачкала, Кировский район, Казбекова, 39-А	Россия, республика Дагестан, Махачкала	0101000020E6100000EA07759142BF47409067976F7D7C4540
32506	8	75	\N	6655	33123	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, И.Казака, 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32505	8	75	\N	6655	33123	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, И. Казака, 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32474	8	75	\N	6655	33068	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, И-КАЗАКА, 32А корпус !		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32475	8	75	\N	6655	33144	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, И-КАЗАКА, 32А корпус 2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32469	8	75	\N	6655	33144	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, И-КАЗАКА, 14 А		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32502	8	75	\N	6655	33141	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Дзержинского, 21		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32507	8	75	\N	6655	32986	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Дахадаева, 90		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32458	8	75	\N	6655	32932	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ДАНИЯЛОВА, 77		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32495	8	75	\N	6655	33101	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Горького, 5		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32472	8	75	\N	6655	33039	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ГАМИДОВА, 59В		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32460	8	75	\N	6655	33039	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ГАМИДОВА, 10 корпус 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32412	8	75	\N	6655	32979	\N	42.977517173609598	Республика Дагестан, город Махачкала, Кировский район, Гаджиева, 170	Россия, республика Дагестан, Махачкала	0101000020E61000001A1A4F0471BE47405B24ED461F7D4540
32411	8	75	\N	6655	32979	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Гаджиева, 162		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32420	8	75	\N	6655	33133	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Гаджиева, 180		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32413	8	75	\N	6655	33133	\N	42.979289644111503	Республика Дагестан, город Махачкала, Кировский район, Гаджиева, 174	Россия, республика Дагестан, Махачкала	0101000020E6100000E78BBD175FBE474061A6ED5F597D4540
32523	8	75	\N	6655	32934	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Гагарина, 54-в		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32519	8	75	\N	6655	32934	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, гагарина, туп.6 д.3		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32518	8	75	\N	6655	32934	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Гагарина, 11-а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32484	8	75	\N	6655	32934	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ГАГАРИНА, 120		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32483	8	75	\N	6655	32934	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ГАГАРИНА, 116		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32481	8	75	\N	6655	32934	\N	42.953099111111797	Республика Дагестан, город Махачкала, Ленинский район, ГАГАРИНА, 90	Россия, республика Дагестан, Махачкала	0101000020E6100000CA52EBFD46C14740D76CE525FF794540
32480	8	75	\N	6655	32934	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ГАГАРИНА, 51		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32520	8	75	\N	6655	33108	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Гагарина, туп.6		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32479	8	75	\N	6655	33027	\N	42.9678031215742	Республика Дагестан, город Махачкала, Ленинский район, ГАМИДОВА, 81	Россия, республика Дагестан, Махачкала	0101000020E610000097E2AAB2EFBC474040FCFCF7E07B4540
32208	8	75	\N	28634	33060	\N	43.845865000000003	Республика Дагестан, город Кизляр, Набережная, 1		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32461	8	75	\N	6655	33027	\N	42.974720504390902	Республика Дагестан, город Махачкала, Ленинский район, ГАМИДОВА, 10 корпус 2	Россия, республика Дагестан, Махачкала	0101000020E61000002BDB87BCE5BE4740BADC60A8C37C4540
32478	8	75	\N	6655	33066	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, ГАГАРИНА, 80А		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32464	8	75	\N	6655	33090	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, Г.ЦАДАСА, 51		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32524	8	75	\N	6655	33014	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Г. Омарова, 9 корп.1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32525	8	75	\N	6655	33025	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Г.Омарова, 9 корп.2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32408	8	75	\N	6655	33164	\N	42.991089046994503	Республика Дагестан, город Махачкала, Кировский район, Буйнакского, 11	Россия, республика Дагестан, Махачкала	0101000020E61000008D0C721761BA474072361D01DC7E4540
32457	8	75	\N	6655	33131	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, БЕЙБУЛАТОВА, 28		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32503	8	75	\N	6655	32948	\N	42.973048350123499	Республика Дагестан, город Махачкала, Советский район, Батырая, 4	Россия, республика Дагестан, Махачкала	0101000020E6100000878BDCD3D5C1474017B83CD68C7C4540
32552	8	75	\N	6655	33048	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Акушинского 1-а линия, 5-а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32433	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 94		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32432	8	75	\N	6655	32947	\N	42.9744053787024	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 98-Д	Россия, республика Дагестан, Махачкала	0101000020E6100000B519A721AAB647408907944DB97C4540
32431	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 92-б		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32430	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 92-Б		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32429	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 90		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32428	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 86		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32427	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 7-линия		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32425	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 26		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32414	8	75	\N	6655	32947	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Акушинского, 16		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32545	8	75	\N	6655	33134	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Айвазовского, 7		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32543	8	75	\N	6655	33110	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Агасиева, 5		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32515	8	75	\N	6655	33100	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Абубакарова, 119		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32501	8	75	\N	6655	33100	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Абубакарова, 8		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32521	8	75	\N	6655	33067	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Акаева, 13		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32482	8	75	\N	6655	33067	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, АКАЕВА, 69		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32527	8	75	\N	6655	32976	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, А-Султана, 30		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32489	8	75	\N	6655	32976	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, А-СУЛТАНА, 1 корпус 2		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32488	8	75	\N	6655	33020	\N	42.976722000000002	Республика Дагестан, город Махачкала, Ленинский район, А-СУЛТАНА, 1 корпус 1		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32517	8	75	\N	6655	32950	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, А-Алиева, пр.4 д.4		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32550	8	75	\N	6655	33046	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, 6-магистральная, 3		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32419	8	75	\N	6655	33082	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, Громова, 6-а		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32514	8	75	\N	6655	33104	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, Аскерханова, 12		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32526	8	75	\N	6655	33109	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, А-Султана, 8-г		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32223	8	75	\N	28634	33087	\N	43.845865000000003	Республика Дагестан, город Кизляр, Циолковского, Гимназия № 6		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32222	8	75	\N	28634	32974	\N	43.845865000000003	"Республика Дагестан, город Кизляр, Победы, ДК ""КЭМЗ"""		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32221	8	75	\N	28634	32974	\N	43.845865000000003	Республика Дагестан, город Кизляр, Победы, 93		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32217	8	75	\N	28634	33120	\N	43.845865000000003	Республика Дагестан, город Кизляр, Коммунистическая, 53		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32209	8	75	\N	28634	33120	\N	43.845445530200003	Республика Дагестан, город Кизляр, Коммунистическая, школа № 4	Россия, республика Дагестан, Кизляр	0101000020E61000001FF46C567D5A47405B44149337EC4540
32216	8	75	\N	28634	32963	\N	43.845865000000003	Республика Дагестан, город Кизляр, Грозненская, 103		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32214	8	75	\N	28634	32963	\N	43.845865000000003	Республика Дагестан, город Кизляр, Грозненская, 29		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32211	8	75	\N	28634	32966	\N	43.845865000000003	Республика Дагестан, город Кизляр, Горького, 4а		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32218	8	75	\N	28634	33074	\N	43.845865000000003	Республика Дагестан, город Кизляр, Герцена, 57		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32210	8	75	\N	28634	33165	\N	43.845865000000003	Республика Дагестан, город Кизляр, Багратиона, 23		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32220	8	75	\N	28634	33129	\N	43.845865000000003	Республика Дагестан, город Кизляр, 40 лет Дагестана, филиал ДГУ		0101000020E6100000F04C6892585A474060EAE74D45EC4540
32153	8	75	\N	25217	32945	\N	43.199182	Республика Дагестан, город Кизилюрт, Омара Чохского, 1		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32137	8	75	\N	25217	32988	\N	43.199182	Республика Дагестан, город Кизилюрт, Молодёжная, 7		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32152	8	75	\N	25217	33026	\N	43.199182	Республика Дагестан, город Кизилюрт, Магомедгаджиева, 19		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32141	8	75	\N	25217	33172	\N	43.202742474412702	"Республика Дагестан, город Кизилюрт, Ленина, 101""А"""	Россия, республика Дагестан, Кизилюрт	0101000020E6100000DE550F98876E474048C32973F3994540
32150	8	75	\N	25217	33163	\N	43.199182	Республика Дагестан, город Кизилюрт, Заводская, 3		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32151	8	75	\N	25217	33119	\N	43.199182	Республика Дагестан, город Кизилюрт, Дахадаева, 28		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32147	8	75	\N	25217	32919	\N	43.2003250453199	Республика Дагестан, город Кизилюрт, Гамзата  Цадаса, 80	Россия, республика Дагестан, Кизилюрт	0101000020E61000001077F52A326E47401DC9E53FA4994540
32146	8	75	\N	25217	32919	\N	43.199182	"Республика Дагестан, город Кизилюрт, Гамзата Цадаса, 73 ""Б"""		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32143	8	75	\N	25217	32919	\N	43.199182	"Республика Дагестан, город Кизилюрт, Гамзата Цадаса, 40""А"""		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32140	8	75	\N	25217	32919	\N	43.201215894862798	"Республика Дагестан, город Кизилюрт, Гамзата  Цадаса, 2""А"""	Россия, республика Дагестан, Кизилюрт	0101000020E61000007E1B62BCE66D47404AB72572C1994540
32136	8	75	\N	25217	33059	\N	43.199182	Республика Дагестан, город Кизилюрт, Газимагомедова (Первомайская), 59 А		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32135	8	75	\N	25217	33059	\N	43.199182	Республика Дагестан, город Кизилюрт, Газимагомедова (Первомайская ), 124		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32149	8	75	\N	25217	32990	\N	43.2004741752312	"Республика Дагестан, город Кизилюрт, Гагарина, 40""А"""		0101000020E610000032CA332F876F474062D9CC21A9994540
32148	8	75	\N	25217	32990	\N	43.199182	"Республика Дагестан, город Кизилюрт, Гагарина, 74""А"""		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32145	8	75	\N	25217	32990	\N	43.199182	Республика Дагестан, город Кизилюрт, Гагарина, 54		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32144	8	75	\N	25217	32990	\N	43.199182	"Республика Дагестан, город Кизилюрт, Гагарина, 42""А"""		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32142	8	75	\N	25217	32990	\N	43.200411383734298	Республика Дагестан, город Кизилюрт, Гагарина, 40	Россия, республика Дагестан, Кизилюрт	0101000020E61000007F501729946F47401C615111A7994540
32139	8	75	\N	25217	32990	\N	43.199182	Республика Дагестан, город Кизилюрт, Гагарина, 16		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32138	8	75	\N	25217	33022	\N	43.199182	Республика Дагестан, город Кизилюрт, Вишневского, 9		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32134	8	75	\N	25217	33160	\N	43.199182	Республика Дагестан, город Кизилюрт, Алиева, 92		0101000020E61000006F6589CE326F4740D7F9B7CB7E994540
32083	8	75	\N	18679	\N	\N	42.878731000000002	"Республика Дагестан, город Каспийск, АЭРОПОРТ, ""МАХАЧКАЛА"""		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32068	8	75	\N	18679	\N	\N	42.878731000000002	Республика Дагестан, город Каспийск, ПО. КИРПИЧНЫЙ ЗАВОД, МОУ №5		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32064	8	75	\N	18679	\N	\N	42.878731000000002	Республика Дагестан, город Каспийск, А-АЛИЕВА, МЕД. УЧИЛИЩЕ		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32065	8	75	\N	18679	32915	\N	42.878731000000002	Республика Дагестан, город Каспийск, ХИЗРОЕВА, ДОМ КУЛЬТУРЫ		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32069	8	75	\N	18679	32949	\N	42.878731000000002	Республика Дагестан, город Каспийск, ХАЛИЛОВА		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32062	8	75	\N	18679	32949	\N	42.878731000000002	Республика Дагестан, город Каспийск, ХАЛИЛОВА, 7		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32079	8	75	\N	18679	32980	\N	42.878731000000002	Республика Дагестан, город Каспийск, ТРУДОВАЯ, 13		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32066	8	75	\N	18679	33125	\N	42.878731000000002	Республика Дагестан, город Каспийск, ОРДЖОНИКИДЗЕ, 8		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32067	8	75	\N	18679	33012	\N	42.878731000000002	Республика Дагестан, город Каспийск, ОРДЖОНИКИДЗЕ, 3		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32000	8	75	\N	18679	33012	\N	42.878731000000002	Республика Дагестан, город Каспийск, ОРДЖОНИКИДЗЕ, 16		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32078	8	75	\N	18679	33070	\N	42.878731000000002	Республика Дагестан, город Каспийск, ОКТЯБРЬСКАЯ, ГОУ ОБЩЕОБРАЗОВАТЕЛЬНАЯ ШК.-ИН.№2		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32072	8	75	\N	18679	33127	\N	42.878731000000002	Республика Дагестан, город Каспийск, НАЗАРОВА, 3		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32070	8	75	\N	18679	32921	\N	42.878731000000002	Республика Дагестан, город Каспийск, МИРА, 7		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32077	8	75	\N	18679	33058	\N	42.878731000000002	Республика Дагестан, город Каспийск, МАТРОСОВА, 3		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32075	8	75	\N	18679	32917	\N	42.888527017500799	Республика Дагестан, город Каспийск, ЛЕНИНА, МОУ КОДЕТСКАЯ МОРСКАЯ Ш-И		0101000020E6100000D7BD158909D24740774EB340BB714540
32063	8	75	\N	18679	32917	\N	42.878731000000002	Республика Дагестан, город Каспийск, ЛЕНИНА, 74	Россия, республика Дагестан, Каспийск	0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32081	8	75	\N	18679	33157	\N	42.878731000000002	Республика Дагестан, город Каспийск, ДАХАДАЕВА, 58		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32080	8	75	\N	18679	32931	\N	42.878731000000002	Республика Дагестан, город Каспийск, ГАМЗАТОВА, 35		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32082	8	75	\N	18679	32935	\N	42.878731000000002	Республика Дагестан, город Каспийск, БУЙНАКСКОГО, 100А		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32074	8	75	\N	18679	33118	\N	42.878731000000002	Республика Дагестан, город Каспийск, АЛФЕРОВА, 4		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32073	8	75	\N	18679	33118	\N	42.878731000000002	Республика Дагестан, город Каспийск, АЛФЕРОВА, ЛИЦЕЙ№1		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
32076	8	75	\N	18679	32975	\N	42.878731000000002	Республика Дагестан, город Каспийск, АБДУЛМАНАПОВА, 10		0101000020E61000005D15A8C5E0D147409E7DE5417A704540
31941	8	75	\N	15675	33156	\N	42.565871999999999	Республика Дагестан, город Избербаш, пр.Ленина, 6, Здание СШ №10		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31954	8	75	\N	15675	33064	\N	42.565871999999999	Республика Дагестан, город Избербаш, пл. Ленина, 2, Здание ГДК		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31953	8	75	\N	15675	32991	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Шевченко, 2, Административное здание Педколледжа		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31960	8	75	\N	15675	33124	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Свободы, 10, Здание СШ №1		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31958	8	75	\N	15675	33044	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Октябрьская, 2-а, Горпромкомбмнат им.И.Шамиля		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31949	8	75	\N	15675	33063	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Нефтяников, 1, Здание института Финансов и права		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31956	8	75	\N	15675	32995	\N	42.566811212685899	Республика Дагестан, город Избербаш, ул.Маяковского, 119, Здание СШ №11	Россия, республика Дагестан, Избербаш	0101000020E6100000ECDADE6E49F04740AC014A438D484540
31955	8	75	\N	15675	33065	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Дербентская, 4, Административное здание Избербашгаз		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31952	8	75	\N	15675	33023	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Гамидова, 14, Узел почтовой связи		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31950	8	75	\N	15675	33023	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Гамидова, 7, Здание СШ №2		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31957	8	75	\N	15675	32978	\N	42.565871999999999	Республика Дагестан, город Избербаш, Буйнакского, 111, общежитие Радиозавода		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31951	8	75	\N	15675	32978	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Буйнакского, 30, административное здание ИГЭС		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31959	8	75	\N	15675	33045	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Абубакарова, 4, Здание ПУ		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31962	8	75	\N	15675	32927	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул.Геолога Брода, 12/2		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31961	8	75	\N	15675	32927	\N	42.565871999999999	Республика Дагестан, город Избербаш, ул. Геолога Брода, 29, Здание СШ №12		0101000020E6100000E9D66B7A50F047406EDC627E6E484540
31936	8	75	\N	12017	\N	\N	42.062362	Республика Дагестан, город Дербент, Р-н Аэропорт,СОШ №17, Здание СОШ №17		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31923	8	75	\N	12017	\N	\N	42.062362	Республика Дагестан, город Дербент, Расулбекова, 18	Россия, республика Дагестан, Дербент	0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31920	8	75	\N	12017	\N	\N	42.0650769099542	Республика Дагестан, город Дербент, С/х Ленинский, СОШ №20, Здание СОШ №20	Россия, республика Дагестан, Дербент городской округ	0101000020E6100000B40584D6C3234840645C717154084540
31922	8	75	\N	12017	33081	\N	42.062362	Республика Дагестан, город Дербент, Шахбазова, 63		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31934	8	75	\N	12017	33043	\N	42.062362	Республика Дагестан, город Дербент, Х.Тагиева, 35		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31929	8	75	\N	12017	33043	\N	42.062362	Республика Дагестан, город Дербент, Х.Тагиева, 1		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31904	8	75	\N	12017	33143	\N	42.062362	Республика Дагестан, город Дербент, Тахо-Годи, 1		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31908	8	75	\N	12017	32918	\N	42.062362	Республика Дагестан, город Дербент, Таги-Заде, 2		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31931	8	75	\N	12017	33097	\N	42.062362	Республика Дагестан, город Дербент, Советская, 11		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31926	8	75	\N	12017	33097	\N	42.065284766730201	Республика Дагестан, город Дербент, Советская, 6	Россия, республика Дагестан, Дербент	0101000020E6100000018A912573264840AEF545425B084540
31919	8	75	7292	\N	33097	\N	42.061911006629799	Республика Дагестан, город Дербент, Советская, 41	Россия, республика Дагестан, Дербент городской округ	0101000020E61000007F86376BF02448409F211CB3EC074540
31928	8	75	\N	12017	33030	\N	42.062362	Республика Дагестан, город Дербент, Свердлова, 8		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31937	8	75	\N	12017	33019	\N	42.062362	Республика Дагестан, город Дербент, Сальмана, 38		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31913	8	75	\N	12017	33019	\N	42.062362	Республика Дагестан, город Дербент, Сальмана, 48		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31932	8	75	\N	12017	32983	\N	42.062362	Республика Дагестан, город Дербент, С.Габиева, 20		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31935	8	75	\N	12017	33018	\N	42.062362	Республика Дагестан, город Дербент, Приморская, 42		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31924	8	75	\N	12017	33021	\N	42.062362	Республика Дагестан, город Дербент, Оскара, 26		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31933	8	75	\N	12017	33032	\N	42.062362	Республика Дагестан, город Дербент, Новокарьерная, 2		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31903	8	75	\N	12017	33062	\N	42.062362	Республика Дагестан, город Дербент, Маскина, 55		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31915	8	75	\N	12017	32933	\N	42.062362	Республика Дагестан, город Дербент, Ленина, 66		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31914	8	75	\N	12017	32933	\N	42.062362	Республика Дагестан, город Дербент, Ленина, 103		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31910	8	75	\N	12017	32933	\N	42.062362	Республика Дагестан, город Дербент, Ленина, 35		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31905	8	75	\N	12017	32933	\N	42.062362	Республика Дагестан, город Дербент, Ленина, 2		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31918	8	75	\N	12017	32926	\N	42.062362	Республика Дагестан, город Дербент, Крупской, 20		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31917	8	75	\N	12017	32926	\N	42.062362	Республика Дагестан, город Дербент, Крупской, 4		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31912	8	75	\N	12017	32981	\N	42.062362	Республика Дагестан, город Дербент, Красноармейский, 56		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31921	8	75	\N	12017	33145	\N	42.063917696130801	Республика Дагестан, город Дербент, Гоголя, 2А	Россия, республика Дагестан, Дербент	0101000020E6100000EA5BE6745926484018D00B772E084540
31930	8	75	\N	12017	33155	\N	42.064988970342597	Республика Дагестан, город Дербент, Генриха Гасанова, 10	Россия, республика Дагестан, Дербент	0101000020E6100000A86F99D365254840C4CC3E8F51084540
31906	8	75	\N	12017	33042	\N	42.062362	Республика Дагестан, город Дербент, Вокзальная, 54		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31911	8	75	\N	12017	32987	\N	42.062362	Республика Дагестан, город Дербент, Буйнакского, 51		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31927	8	75	\N	12017	33005	\N	42.062362	Республика Дагестан, город Дербент, 345 ДСД, 6		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31925	8	75	\N	12017	33005	\N	42.062362	Республика Дагестан, город Дербент, 345 ДСД, 8		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31909	8	75	\N	12017	33029	\N	42.062362	Республика Дагестан, город Дербент, 3 Интернационала, 2		0101000020E6100000BD1C76DF31264840AF415F7AFB074540
31916	8	75	7292	\N	32941	\N	42.058117309492701	Республика Дагестан, город Дербент, пл. Свободы, 18	Россия, республика Дагестан, Дербент городской округ	0101000020E6100000643DB5FAEA244840BB2BBB6070074540
31796	8	75	\N	41025	12140	\N	42.118685347523098	Республика Дагестан, город Дагестанские Огни, Кирова, 21	Россия, республика Дагестан, Дагестанские Огни городской округ	0101000020E6100000B1169F02601A48404CC3F011310F4540
31801	8	75	\N	41025	32907	\N	42.116052000000003	Республика Дагестан, город Дагестанские Огни, Аллея Дружбы, 13	Россия, республика Дагестан, поселок городского типа Дагестанские Огни	0101000020E610000017F032C3461948405551BCCADA0E4540
31792	8	75	\N	8650	33128	\N	42.116005000000001	Республика Дагестан, город Дагестанские Огни, Революции, 9		0101000020E6100000F94A20257619484014967840D90E4540
31794	8	75	\N	8650	33099	\N	42.116005000000001	"Республика Дагестан, город Дагестанские Огни, Некрасова, 3 ""а"""		0101000020E6100000F94A20257619484014967840D90E4540
31799	8	75	\N	8650	33054	\N	42.116005000000001	Республика Дагестан, город Дагестанские Огни, М.Горького, 6		0101000020E6100000F94A20257619484014967840D90E4540
31797	8	75	\N	8650	33154	\N	42.116005000000001	Республика Дагестан, город Дагестанские Огни, Лермонтова, 35		0101000020E6100000F94A20257619484014967840D90E4540
31795	8	75	\N	8650	33053	\N	42.116005000000001	"Республика Дагестан, город Дагестанские Огни, Леваневского переулок, 2 ""а"""		0101000020E6100000F94A20257619484014967840D90E4540
31800	8	75	\N	8650	33055	\N	42.116005000000001	Республика Дагестан, город Дагестанские Огни, Козленко, 26		0101000020E6100000F94A20257619484014967840D90E4540
31793	8	75	\N	8650	33096	\N	42.116005000000001	Республика Дагестан, город Дагестанские Огни, Кирова площадь, 1		0101000020E6100000F94A20257619484014967840D90E4540
31802	8	75	\N	53419	33000	\N	42.115438263379801	Республика Дагестан, город Дагестанские Огни, Школьная, 67	Россия, республика Дагестан, поселок городского типа Дагестанские Огни	0101000020E6100000815A0C1EA61948409A5B21ACC60E4540
31798	8	75	\N	53419	32997	\N	42.1162570396368	"Республика Дагестан, город Дагестанские Огни, М.Гаджиева, 45 ""а"""	Россия, республика Дагестан, поселок городского типа Дагестанские Огни	0101000020E6100000460BD0B69A1948402D776682E10E4540
31691	8	75	\N	2445	\N	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Пос. Южный, СОШ №10		0101000020E610000071732A19008E4740AE2EA704C4684540
31687	8	75	\N	2445	\N	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Жил Массив Западный, СОШ №6		0101000020E610000071732A19008E4740AE2EA704C4684540
31695	8	75	\N	2445	33084	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Ярагского, 2-а		0101000020E610000071732A19008E4740AE2EA704C4684540
31679	8	75	\N	2445	32969	\N	42.819476934300603	Республика Дагестан, город Буйнакск, Шамхалова, 3	Россия, республика Дагестан, Буйнакск	0101000020E61000004777103B538E47407F69519FE4684540
31551	8	75	\N	2445	33016	\N	42.821751551870399	Республика Дагестан, город Буйнакск, Чкалова, 7	Россия, республика Дагестан, Буйнакск	0101000020E6100000E1270EA0DF8F474017B6662B2F694540
31689	8	75	\N	2445	33011	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Циалковского, 13		0101000020E610000071732A19008E4740AE2EA704C4684540
31688	8	75	\N	2445	33146	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Хизроева, 57		0101000020E610000071732A19008E4740AE2EA704C4684540
31671	8	75	\N	2445	33146	\N	42.818835208371397	Республика Дагестан, город Буйнакск, Хизроева, 18	Россия, республика Дагестан, Буйнакск	0101000020E61000009AEB34D2528F4740FBE8D495CF684540
31680	8	75	\N	2445	33117	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Фрунзе, 2		0101000020E610000071732A19008E4740AE2EA704C4684540
31681	8	75	\N	2445	33151	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Салаватова, 56		0101000020E610000071732A19008E4740AE2EA704C4684540
31693	8	75	\N	2445	33126	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Мр. Дружба, СОШ №9		0101000020E610000071732A19008E4740AE2EA704C4684540
31690	8	75	\N	2445	33015	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Ленина, 62		0101000020E610000071732A19008E4740AE2EA704C4684540
31684	8	75	\N	2445	33015	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Ленина, 6		0101000020E610000071732A19008E4740AE2EA704C4684540
31627	8	75	\N	2445	33015	\N	42.818770048132698	Республика Дагестан, город Буйнакск, Ленина, 51	Россия, республика Дагестан, Буйнакск	0101000020E61000007FA65EB7088E474014799274CD684540
31610	8	75	\N	2445	33015	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Ленина, 42		0101000020E610000071732A19008E4740AE2EA704C4684540
31692	8	75	\N	2445	33040	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Имама Шамиля, 134		0101000020E610000071732A19008E4740AE2EA704C4684540
31682	8	75	\N	2445	33004	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Имама Газимагомеда, 46		0101000020E610000071732A19008E4740AE2EA704C4684540
31683	8	75	\N	2445	33008	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Дж. Казикумухского, 84		0101000020E610000071732A19008E4740AE2EA704C4684540
31567	8	75	\N	2445	33052	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Буйнакского, 29		0101000020E610000071732A19008E4740AE2EA704C4684540
31685	8	75	\N	2445	33095	\N	42.818482000000003	Республика Дагестан, город Буйнакск, Аскерханова, 18		0101000020E610000071732A19008E4740AE2EA704C4684540
31694	8	75	\N	2445	32973	\N	42.814271849934499	Республика Дагестан, город Буйнакск, Гамзата Цадаса, 32	Россия, республика Дагестан, Буйнакск	0101000020E6100000F4177AC4E88F474036069D103A684540
31989	8	75	\N	53672	\N	\N	43.119010000000003	Республика Дагестан, прикутанного хозяйства Алтунчик, здание школы		0101000020E61000003E92921E866C4740D0F23CB83B8F4540
33271	8	75	1330	16290	\N	\N	42.425815999999998	Республика Дагестан, Шамильский район, село Цекоб	Россия, республика Дагестан, Шамильский район, село Цекоб	0101000020E610000031276893C3394740880E812381364540
33270	8	75	1330	16216	\N	\N	42.401632999999997	Республика Дагестан, Шамильский район, село Хучада	Россия, республика Дагестан, Шамильский район, село Хучада	0101000020E6100000F3AE7AC03C3C474047FFCBB568334540
33268	8	75	1330	16128	\N	\N	42.394568999999997	Республика Дагестан, Шамильский район, село Хотода	Россия, республика Дагестан, Шамильский район, село Хотода	0101000020E6100000B1F7E28BF6464740F981AB3C81324540
33269	8	75	1330	16173	\N	\N	42.415061000000001	Республика Дагестан, Шамильский район, село Хорода	Россия, республика Дагестан, Шамильский район, село Хорода	0101000020E61000000B24287E8C5547402B6C06B820354540
33267	8	75	1330	16097	\N	\N	42.316547999999997	Республика Дагестан, Шамильский район, село Хонох	Россия, республика Дагестан, Шамильский район, село Хонох	0101000020E6100000C32D1F49494147409ECE15A584284540
33266	8	75	1330	16034	\N	\N	42.443803000000003	Республика Дагестан, Шамильский район, село Хебда	Россия, республика Дагестан, Шамильский район, село Хебда	0101000020E6100000DD0BCC0A45464740F06E6589CE384540
33265	8	75	1330	15969	\N	\N	42.327173999999999	Республика Дагестан, Шамильский район, село Урчух	Россия, республика Дагестан, Шамильский район, село Урчух	0101000020E610000083143C855C3F4740FE0C6FD6E0294540
33264	8	75	1330	15949	\N	\N	42.456363000000003	Республика Дагестан, Шамильский район, село Уриб	Россия, республика Дагестан, Шамильский район, село Уриб	0101000020E6100000601E32E5435647405F0D501A6A3A4540
33263	8	75	1330	15891	\N	\N	42.386198	Республика Дагестан, Шамильский район, село Урада	Россия, республика Дагестан, Шамильский район, село Урада	0101000020E610000003EE79FEB4474740EBE3A1EF6E314540
33261	8	75	1330	15797	\N	\N	42.388002999999998	Республика Дагестан, Шамильский район, село Тлях	Россия, республика Дагестан, Шамильский район, село Тлях	0101000020E6100000B40584D6C3454740FCDF1115AA314540
33260	8	75	1330	15745	\N	\N	42.436078000000002	Республика Дагестан, Шамильский район, село Тлянуб	Россия, республика Дагестан, Шамильский район, село Тлянуб	0101000020E6100000ABEAE5779A3A4740A7406667D1374540
33259	8	75	1330	15680	\N	\N	42.393563	Республика Дагестан, Шамильский район, село Тидиб	Россия, республика Дагестан, Шамильский район, село Тидиб	0101000020E6100000BE2EC37FBA49474034F5BA4560324540
33258	8	75	1330	15666	\N	\N	42.429502999999997	Республика Дагестан, Шамильский район, село Телетль	Россия, республика Дагестан, Шамильский район, село Телетль	0101000020E6100000B476DB85E65E474056444DF4F9364540
33257	8	75	1330	15614	\N	\N	42.302951999999998	Республика Дагестан, Шамильский район, село Сомода	Россия, республика Дагестан, Шамильский район, село Сомода	0101000020E6100000F8AA9509BF444740FF209221C7264540
33256	8	75	1330	15528	\N	\N	42.316701375860099	Республика Дагестан, Шамильский район, село Ругельда-Хиндах	Россия, республика Дагестан, Шамильский район, село Ругельда	0101000020E6100000D36A48DC6343474025CE8AA889284540
33255	8	75	1330	15528	\N	\N	42.316634000000001	Республика Дагестан, Шамильский район, село Ругельда	Россия, республика Дагестан, Шамильский район, село Ругельда	0101000020E6100000508D976E124347409D66817687284540
33254	8	75	1330	15480	\N	\N	42.361272999999997	Республика Дагестан, Шамильский район, село Ратлуб	Россия, республика Дагестан, Шамильский район, село Ратлуб	0101000020E6100000C9E4D4CE30374740C2F693313E2E4540
33251	8	75	1330	15320	\N	\N	42.518979999999999	Республика Дагестан, Шамильский район, село Нитаб	Россия, республика Дагестан, Шамильский район, село Нитаб	0101000020E6100000F44F70B1A250474098A3C7EF6D424540
33252	8	75	1330	15379	\N	\N	42.487473999999999	Республика Дагестан, Шамильский район, село Нижний Батлух	Россия, республика Дагестан, Шамильский район, село Нижний Батлух	0101000020E6100000D33252EFA94247403DD34B8C653E4540
33250	8	75	1330	15250	\N	\N	42.397950999999999	Республика Дагестан, Шамильский район, село Накитль	Россия, республика Дагестан, Шамильский район, село Накитль	0101000020E6100000D943FB58C14D47408B34F10EF0324540
33249	8	75	1330	15216	\N	\N	42.32996	Республика Дагестан, Шамильский район, село Мусрух	Россия, республика Дагестан, Шамильский район, село Мусрух	0101000020E610000077871403244247407C7E18213C2A4540
33248	8	75	1330	15188	\N	\N	42.500582999999999	Республика Дагестан, Шамильский район, село Могох	Россия, республика Дагестан, Шамильский район, село Могох	0101000020E61000007976F9D6874947407FF78E1A13404540
33247	8	75	1330	53852	\N	\N	42.441573519766898	Республика Дагестан, Шамильский район, село Митилиуриб	Россия, республика Дагестан, Шамильский район, село Митлиуриб	0101000020E610000006BEA25BAF574740C861307F85384540
33246	8	75	1330	15085	\N	\N	42.375495999999998	Республика Дагестан, Шамильский район, село Мачада	Россия, республика Дагестан, Шамильский район, село Мачада	0101000020E6100000AC1E300F99444740B0E3BF4010304540
33245	8	75	1330	15024	\N	\N	42.509278000000002	Республика Дагестан, Шамильский район, село Куаниб	Россия, республика Дагестан, Шамильский район, село Куаниб	0101000020E6100000DBA337DC474E47404149810530414540
33243	8	75	1330	14935	\N	\N	42.429456999999999	Республика Дагестан, Шамильский район, село Кахиб	Россия, республика Дагестан, Шамильский район, село Кахиб	0101000020E610000012A452EC684C4740E6046D72F8364540
33242	8	75	1330	14898	\N	\N	42.418509	Республика Дагестан, Шамильский район, село Зиуриб	Россия, республика Дагестан, Шамильский район, село Зиуриб	0101000020E6100000C879FF1F275A4740740AF2B391354540
33241	8	75	1330	14828	\N	\N	42.484309000000003	Республика Дагестан, Шамильский район, село Заната	Россия, республика Дагестан, Шамильский район, село Заната	0101000020E6100000ED9DD1562547474049145AD6FD3D4540
33240	8	75	1330	14814	\N	\N	42.475850999999999	Республика Дагестан, Шамильский район, село Датуна	Россия, республика Дагестан, Шамильский район, село Датуна	0101000020E6100000B83B6BB75D5247406B6281AFE83C4540
33239	8	75	1330	14756	\N	\N	42.378478999999999	Республика Дагестан, Шамильский район, село Дагбаш	Россия, республика Дагестан, Шамильский район, село Дагбаш	0101000020E6100000232D95B7232C4740849CF7FF71304540
33238	8	75	1330	14712	\N	\N	42.447747999999997	Республика Дагестан, Шамильский район, село Гоор-Хиндах	Россия, республика Дагестан, Шамильский район, село Гоор-Хиндах	0101000020E61000009B02999D45494740B96C74CE4F394540
33237	8	75	1330	14631	\N	\N	42.435606	Республика Дагестан, Шамильский район, село Гоор	Россия, республика Дагестан, Шамильский район, село Гоор	0101000020E6100000800BB265F94847407FF8F9EFC1374540
33236	8	75	1330	14613	\N	\N	42.487740000000002	Республика Дагестан, Шамильский район, село Голотль	Россия, республика Дагестан, Шамильский район, село Голотль	0101000020E6100000ADDF4C4C175E4740BC79AA436E3E4540
33235	8	75	1330	14562	\N	\N	42.452750999999999	Республика Дагестан, Шамильский район, село Гоготль	Россия, республика Дагестан, Шамильский район, село Гоготль	0101000020E61000003A048E041A6247409B1DA9BEF3394540
33234	8	75	1330	14490	\N	\N	42.372432000000003	Республика Дагестан, Шамильский район, село Гента	Россия, республика Дагестан, Шамильский район, село Гента	0101000020E6100000662E7079AC474740F0FD0DDAAB2F4540
33233	8	75	1330	53955	\N	\N	42.365537000000003	Республика Дагестан, Шамильский район, село Геницориб		0101000020E6100000FE7E315BB24447402E3D9AEAC92E4540
33262	8	75	1330	15827	\N	\N	42.429583000000001	Республика Дагестан, Шамильский район, село Тогох	Россия, республика Дагестан, Шамильский район, село Верхний Тогох	0101000020E610000057B1F84D6159474073F56393FC364540
33232	8	75	1330	14404	\N	\N	42.424059	Республика Дагестан, Шамильский район, село Верхний Колоб	Россия, республика Дагестан, Шамильский район, село Верхний Колоб	0101000020E61000008D5F7825C95547408849B89047364540
33231	8	75	1330	14347	\N	\N	42.496926999999999	Республика Дагестан, Шамильский район, село Верхний Батлух	Россия, республика Дагестан, Шамильский район, село Верхний Батлух	0101000020E61000004069A85148404740ECBFCE4D9B3F4540
33229	8	75	1330	53766	\N	\N	42.468060639415803	Республика Дагестан, Шамильский район, село Ассаб	Россия, республика Дагестан, Шамильский район, село Асаб	0101000020E6100000747E8AE3C03F47403BC43F6CE93B4540
33228	8	75	1330	14235	\N	\N	42.514156	Республика Дагестан, Шамильский район, село Андых	Россия, республика Дагестан, Шамильский район, село Андых	0101000020E61000005EDA70581A4C4740668522DDCF414540
33221	8	75	1208	13871	\N	\N	42.090122999999998	Республика Дагестан, Чародинский район, село Шалиб	Россия, республика Дагестан, Чародинский район, село Шалиб	0101000020E6100000D5AE09698D75474007CF8426890B4540
33211	8	75	1208	13414	\N	\N	42.207267999999999	Республика Дагестан, Чародинский район, сельсовет Магарский, село Чуниб	Россия, республика Дагестан, Чародинский район, село Чуниб	0101000020E61000002A1A6B7F67694740F0C000C2871A4540
63300	3	31	44	2262	\N	\N	58.411222000000002	Боровичский район ,д.Перёдки, 16А		0101000020E61000001D0247020D064140A7B228ECA2344D40
33200	8	75	1208	12924	\N	\N	42.103169000000001	Республика Дагестан, Чародинский район, сельсовет Дусрахский, село Читаб	Россия, республика Дагестан, Чародинский район, село Читаб	0101000020E6100000A80183A44F6F4740037B4CA4340D4540
32841	8	75	1208	53491	\N	\N	42.139289241389797	Республика Дагестан, Тляратинский район, сельсовет Хидибский, селение Чильда	Россия, республика Дагестан, Чародинский район, село Чильдаб	0101000020E6100000C39FE1CD1A764740A5D8D138D4114540
33199	8	75	1208	12867	\N	\N	42.153300999999999	Республика Дагестан, Чародинский район, сельсовет Дусрахский, село Чвадаб	Россия, республика Дагестан, Чародинский район, село Чвадаб	0101000020E61000003315E291786F4740D8B8FE5D9F134540
33225	8	75	1208	13838	\N	\N	42.279955000000001	Республика Дагестан, Чародинский район, село Чарода, кутан прикутанский	Россия, республика Дагестан, Чародинский район, село Чарода	0101000020E6100000C79BFC169D66474004ADC090D5234540
33220	8	75	1208	13838	\N	\N	42.279955000000001	Республика Дагестан, Чародинский район, село Чарода	Россия, республика Дагестан, Чародинский район, село Чарода	0101000020E6100000C79BFC169D66474004ADC090D5234540
33216	8	75	1208	13666	\N	\N	42.238649000000002	Республика Дагестан, Чародинский район, сельсовет Цурибский, село Цуриб	Россия, республика Дагестан, Чародинский район, село Цуриб	0101000020E61000002829B000A66A47408F1CE90C8C1E4540
33213	8	75	1208	13501	\N	\N	42.273116999999999	Республика Дагестан, Чародинский район, сельсовет Суметинский, село Цулда	Россия, республика Дагестан, Чародинский район, село Цулда	0101000020E6100000917F66101F5C4740A67D737FF5224540
33206	8	75	1208	13191	\N	\N	42.206580000000002	Республика Дагестан, Чародинский район, сельсовет Магарский, село Ценеб	Россия, республика Дагестан, Чародинский район, село Ценеб	0101000020E6100000BC067DE9ED6B4740FC00A436711A4540
33184	8	75	1208	12187	\N	\N	42.152914000000003	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Цемер	Россия, республика Дагестан, Чародинский район, село Цемер	0101000020E610000028EFE3688E604740DF8C9AAF92134540
33210	8	75	1208	13391	\N	\N	42.185023999999999	Республика Дагестан, Чародинский район, сельсовет Магарский, село Хурух	Россия, республика Дагестан, Чародинский район, село Хурух	0101000020E6100000A3CEDC43C26D4740D07CCEDDAE174540
33181	8	75	1208	12031	\N	\N	42.076096999999997	Республика Дагестан, Чародинский район, сельсовет Арчибский, село Хитаб	Россия, республика Дагестан, Чародинский район, село Хитаб	0101000020E6100000394371C79B6E47406F29E78BBD094540
33202	8	75	1208	13004	\N	\N	42.174954999999997	Республика Дагестан, Чародинский район, сельсовет Ирибский, село  Хинуб	Россия, республика Дагестан, Чародинский район, село Хинуб	0101000020E61000001764CBF275694740C6A2E9EC64164540
33179	8	75	1208	11929	\N	\N	42.059175000000003	Республика Дагестан, Чародинский район, сельсовет Арчибский, село Хилих	Россия, республика Дагестан, Чародинский район, село Хилих	0101000020E6100000F88903E8F7714740D3DEE00B93074540
33214	8	75	1208	13565	\N	\N	42.268514000000003	Республика Дагестан, Чародинский район, сельсовет Суметинский, село Утлух		0101000020E6100000768A5583305D47405342B0AA5E224540
33193	8	75	1208	12637	\N	\N	42.277279999999998	Республика Дагестан, Чародинский район, сельсовет Гочадинский,село Тлярош	Россия, республика Дагестан, Чародинский район, село Тлярош	0101000020E6100000DBDFD91EBD5F4740DDEA39E97D234540
33185	8	75	1208	53430	\N	\N	42.141354599310397	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Тлярабазутль		0101000020E610000009A69A594B6347402310AFEB17124540
33192	8	75	1208	12551	\N	\N	42.251745	Республика Дагестан, Чародинский район, сельсовет Гочадинский, село Талух	Россия, республика Дагестан, Чародинский район, село Талух	0101000020E61000002BDA1CE7365F47403CF71E2E39204540
33212	8	75	1208	13479	\N	\N	42.263883	Республика Дагестан, Чародинский район, сельсовет Суметинский, село Сумета	Россия, республика Дагестан, Чародинский район, село Сумета	0101000020E6100000C3651536035A4740357C0BEBC6214540
33217	8	75	1208	13787	\N	\N	42.214953999999999	Республика Дагестан, Чародинский район, сельсовет Цурибский, село Содаб	Россия, республика Дагестан, Чародинский район, село Содаб	0101000020E610000084A0A3552D6747407B12D89C831B4540
33195	8	75	1208	53427	\N	\N	42.249038189756	Республика Дагестан, Чародинский район, сельсовет Гочобский, село Урух-сота	Россия, республика Дагестан, Чародинский район	0101000020E6100000537B116DC75647400ABB287AE01F4540
33215	8	75	1208	13595	\N	\N	42.258578	Республика Дагестан, Чародинский район, сельсовет Суметинский, село Сачада	Россия, республика Дагестан, Чародинский район, село Сачада	0101000020E6100000AF230ED94058474088BB7A1519214540
33189	8	75	1208	12431	\N	\N	42.049092999999999	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Ритляб	Россия, республика Дагестан, Чародинский район, село Ритляб	0101000020E6100000BE16F4DE185C474034BBEEAD48064540
33203	8	75	1208	13026	\N	\N	42.152954000000001	Республика Дагестан, Чародинский район, сельсовет Ирибский, село Нукуш	Россия, республика Дагестан, Чародинский район, село Нукуш	0101000020E6100000D9B45208E46647406DE525FF93134540
33207	8	75	1208	13215	\N	\N	42.193221000000001	Республика Дагестан, Чародинский район, сельсовет Магарский, село Муккутль	Россия, республика Дагестан, Чародинский район, село Мукутль	0101000020E61000002D98F8A3A86D474041F33977BB184540
33132	8	75	1090	9660	\N	\N	42.192894000000003	Республика Дагестан, Цунтинский район, с.Кидеро, здание школы		0101000020E6100000F33E8EE6C8FA46401DCC26C0B0184540
33224	8	75	1208	12731	\N	\N	42.260967000000001	Республика Дагестан, Чародинский район, село Мугурух, кутан Уйташ	Россия, республика Дагестан, Чародинский район, село Мугурух	0101000020E6100000FCC56CC9AA6E4740E92ADD5D67214540
33196	8	75	1208	12731	\N	\N	42.260967000000001	Республика Дагестан, Чародинский район, село Мугурух	Россия, республика Дагестан, Чародинский район, село Мугурух	0101000020E6100000FCC56CC9AA6E4740E92ADD5D67214540
33218	8	75	1208	53564	\N	\N	42.223085173752203	Республика Дагестан, Чародинский район, сельсовет Цурибский, село Мощоб	Россия, республика Дагестан, Чародинский район, село Мошоб	0101000020E61000003A5D16139B674740349D9D0C8E1C4540
33205	8	75	1208	13117	\N	\N	42.194977999999999	Республика Дагестан, Чародинский район, сельсовет Магарский, село Магар	Россия, республика Дагестан, Чародинский район, село Магар	0101000020E6100000649291B3B06B474041B8020AF5184540
33209	8	75	1208	13313	\N	\N	42.175702999999999	Республика Дагестан, Чародинский район, сельсовет Магарский, село Кучраб		0101000020E6100000956247E3507347409067976F7D164540
33183	8	75	1208	12127	\N	\N	42.126263999999999	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Кутих	Россия, республика Дагестан, Чародинский район, село Кутих	0101000020E6100000BB270F0BB5644740C154336B29104540
33177	8	75	1208	11829	\N	\N	42.031917	Республика Дагестан, Чародинский район, сельсовет Арчибский, село Кубатль	Россия, республика Дагестан, Чародинский район, село Кубатль	0101000020E61000008429CAA5F16D4740DD9733DB15044540
33198	8	75	1208	12847	\N	\N	42.133071000000001	Республика Дагестан, Чародинский район, сельсовет Дусрахский, село Косрода	Россия, республика Дагестан, Чародинский район, село Косрода	0101000020E6100000CCF10A444F6E4740E485747808114540
33180	8	75	1208	11980	\N	\N	42.063178999999998	Республика Дагестан, Чародинский район, сельсовет Арчибский, село Кесериб	Россия, республика Дагестан, Чародинский район, село Кесериб	0101000020E610000049BBD1C77C704740A165DD3F16084540
33187	8	75	1208	12316	\N	\N	42.122044000000002	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Карануб	Россия, республика Дагестан, Чародинский район, село Карануб	0101000020E61000003F6EBF7CB2684740265646239F0F4540
33201	8	75	1208	12946	\N	\N	42.160206000000002	Республика Дагестан, Чародинский район, сельсовет Ирибский, село Ириб	Россия, республика Дагестан, Чародинский район, село Ириб	0101000020E61000007009C03FA5684740BE4F55A181144540
33226	8	75	1208	12792	\N	\N	42.1275553133245	Республика Дагестан, Чародинский район, сельсовет Дусрахский, кутан Шамильский	Россия, республика Дагестан, Чародинский район, село Дусрах	0101000020E6100000615111A7937047407CB8E4B853104540
33197	8	75	1208	12792	\N	\N	42.127808999999999	Республика Дагестан, Чародинский район, сельсовет Дусрахский, село Дусрах	Россия, республика Дагестан, Чародинский район, село Дусрах	0101000020E610000033C170AE617047403691990B5C104540
33186	8	75	1208	12273	\N	\N	42.125394999999997	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Доронуб	Россия, республика Дагестан, Чародинский район, село Доронуб	0101000020E6100000BDA94885B16747407C0A80F10C104540
33191	8	75	1208	53967	\N	\N	42.2585899859642	Республика Дагестан, Чародинский район, сельсовет Гочадинский, село Гунух - Мурух	Россия, республика Дагестан, Чародинский район	0101000020E6100000FD868906296C47404C89247A19214540
33194	8	75	1208	12643	\N	\N	42.239724000000002	Республика Дагестан, Чародинский район, сельсовет Гочобский, село Гочоб	Россия, республика Дагестан, Чародинский район, село Гочоб	0101000020E6100000F7730AF2B35547407D08AA46AF1E4540
33190	8	75	1208	53918	\N	\N	42.271129000000002	Республика Дагестан, Чародинский район, сельсовет Гочадинский, село Гачада	Россия, республика Дагестан, Чародинский район, село Гочада	0101000020E6100000A662635E47624740A4FFE55AB4224540
33188	8	75	1208	12368	\N	\N	42.097656000000001	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Гоаб		0101000020E6100000492F6AF7AB5E47400C21E7FD7F0C4540
33227	8	75	1208	12092	\N	\N	42.117012151586501	Республика Дагестан, Чародинский район, сельсовет Гилибский, кутан Ногайский	Россия, республика Дагестан, Чародинский район, село Гилиб	0101000020E61000005ED6C4025F634740AA9ECC3FFA0E4540
33182	8	75	1208	12092	\N	\N	42.116841000000001	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Гилиб	Россия, республика Дагестан, Чародинский район, село Гилиб	0101000020E61000004FCDE506436347407DEA58A5F40E4540
33219	8	75	1208	13780	\N	\N	42.230170999999999	Республика Дагестан, Чародинский район, сельсовет Цурибский, село Гидиб	Россия, республика Дагестан, Чародинский район, село Гидиб	0101000020E6100000AA6395D2336747406ABE4A3E761D4540
33208	8	75	1208	13284	\N	\N	42.174514000000002	Республика Дагестан, Чародинский район, сельсовет Магарский, село Багинуб	Россия, республика Дагестан, Чародинский район, село Багинуб	0101000020E610000076525F9676704740DA58897956164540
33176	8	75	1208	11795	\N	\N	42.066263999999997	Республика Дагестан, Чародинский район, сельсовет Арчибский, село Арчиб	Россия, республика Дагестан, Чародинский район, село Арчиб	0101000020E6100000884CF910546F47407973B8567B084540
33178	8	75	1208	11870	\N	\N	42.052312999999998	Республика Дагестан, Чародинский район, сельсовет Арчибский, село Алчуниб	Россия, республика Дагестан, Чародинский район, село Алчуниб	0101000020E610000032E884D0416F4740EC134031B2064540
33164	8	75	1090	53941	\N	\N	42.246845999999998	Республика Дагестан, Цунтинский район, с.Мекали		0101000020E6100000F3E32F2DEAF74640FF9254A6981F4540
33155	8	75	1090	53938	\N	\N	42.242796859323001	Республика Дагестан, Цунтинский район, с.Азильта	Россия, республика Дагестан, Цунтинский район	0101000020E6100000D0807A336AF846409148DBF8131F4540
33135	8	75	1090	9817	\N	\N	42.182651999999997	Республика Дагестан, Цунтинский район, с.Эльбок, здание школы	Россия, республика Дагестан, Цунтинский район, село Эльбок	0101000020E6100000B24B546F0DF446404546072461174540
33154	8	75	1090	10762	\N	\N	42.270549000000003	Республика Дагестан, Цунтинский район, с.Шаури	Россия, республика Дагестан, Цунтинский район, село Шаури	0101000020E61000000C3ECDC98BF84640967B8159A1224540
33140	8	75	1090	10046	\N	\N	42.224148999999997	Республика Дагестан, Цунтинский район, с.Шапих, здание школы		0101000020E6100000B33F506EDBED46402E3718EAB01C4540
33167	8	75	1090	11339	\N	\N	42.239370000000001	Республика Дагестан, Цунтинский район, с.Шаитли	Россия, республика Дагестан, Цунтинский район, село Шаитли	0101000020E610000071E65773800647405FD218ADA31E4540
33152	8	75	1090	53579	\N	\N	42.205826628638	Республика Дагестан, Цунтинский район, с.Чатли	Россия, республика Дагестан, Цунтинский район	0101000020E610000007CE1951DAF1464020D1048A581A4540
33143	8	75	1090	10210	\N	\N	42.240057999999998	Республика Дагестан, Цунтинский район, с.Чалях	Россия, республика Дагестан, Цунтинский район, село Чалях	0101000020E61000005ED6C4025FEB464053927538BA1E4540
33142	8	75	1090	53552	\N	\N	42.219257828566299	Республика Дагестан, Цунтинский район, с.Хутрах	Россия, республика Дагестан, Цунтинский район, село Цутрах	0101000020E6100000077B134372E6464075B169A5101C4540
33151	8	75	1090	53843	\N	\N	42.276293000000003	Республика Дагестан, Цунтинский район, с.Цокох	Россия, республика Дагестан, Цунтинский район, село Цохок	0101000020E610000052616C21C8E546408F8EAB915D234540
33158	8	75	1090	53513	\N	\N	42.253793534208199	Республика Дагестан, Цунтинский район, с.Цебари	Россия, республика Дагестан, Цунтинский район, село Цибари	0101000020E61000001FD7868A71F04640E4F560527C204540
33160	8	75	1090	53854	\N	\N	42.247799414422602	Республика Дагестан, Цунтинский район, с.Цихок	Россия, республика Дагестан, Цунтинский район, село Цехок	0101000020E61000005DC30C8D27FE4640A27DACE0B71F4540
33139	8	75	1090	53814	\N	\N	42.200304441412598	Республика Дагестан, Цунтинский район, с.Н.Хупри, здание школы	Россия, республика Дагестан, Цунтинский район, село Хупри	0101000020E6100000AD32535A7FEB464006A1BC8FA3194540
33138	8	75	1090	53814	\N	\N	42.201311349520502	Республика Дагестан, Цунтинский район, сХупри, здание школы	Россия, республика Дагестан, Цунтинский район, село Хупри	0101000020E6100000AE9AE7887CEB46409BA9108FC4194540
33136	8	75	1090	53850	\N	\N	42.186631181455901	Республика Дагестан, Цунтинский район, с.Хибятли, здание школы	Россия, республика Дагестан, Цунтинский район, село Хибиятль	0101000020E61000003067B62BF4EF4640BBB54C86E3174540
33161	8	75	1090	53591	\N	\N	42.261891061290797	Республика Дагестан, Цунтинский район, с.Хетох	Россия, республика Дагестан, Цунтинский район, село Хенох	0101000020E6100000A182C30B22FC4640F10EF0A485214540
33156	8	75	1090	10841	\N	\N	42.282496999999999	Республика Дагестан, Цунтинский район, с.Хебатли	Россия, республика Дагестан, Цунтинский район, село Хебатли	0101000020E6100000DDED7A698AF64640EB1B98DC28244540
33166	8	75	1090	11304	\N	\N	42.309994000000003	Республика Дагестан, Цунтинский район, с.Хамаитли	Россия, республика Дагестан, Цунтинский район, село Хамаитли	0101000020E610000026E4839ECDFA464066FA25E2AD274540
33150	8	75	1090	10566	\N	\N	42.269233999999997	Республика Дагестан, Цунтинский район, с.Удок	Россия, республика Дагестан, Цунтинский район, село Удок	0101000020E6100000AE2990D959E64640527C7C4276224540
33163	8	75	1090	11174	\N	\N	42.349387	Республика Дагестан, Цунтинский район, с.Тляцуда	Россия, республика Дагестан, Цунтинский район, село Тляцуда	0101000020E6100000314278B471F64640E35295B6B82C4540
33148	8	75	1090	10486	\N	\N	42.288727000000002	Республика Дагестан, Цунтинский район, с.Терутли	Россия, республика Дагестан, Цунтинский район, село Терутли	0101000020E610000006D50627A2E54640713C9F01F5244540
33159	8	75	1090	53503	\N	\N	42.246845999999998	Республика Дагестан, Цунтинский район, с.Берих		0101000020E6100000F3E32F2DEAF74640FF9254A6981F4540
33165	8	75	1090	11274	\N	\N	42.389747999999997	Республика Дагестан, Цунтинский район, с.Сагада	Россия, республика Дагестан, Цунтинский район, село Сагада	0101000020E6100000B03DB32440F5464038D73043E3314540
33145	8	75	1090	10331	\N	\N	42.244475999999999	Республика Дагестан, Цунтинский район, с.Ретлоб	Россия, республика Дагестан, Цунтинский район, село Ретлоб	0101000020E61000003CA41820D1EA4640155454FD4A1F4540
33157	8	75	1090	10911	\N	\N	42.263328999999999	Республика Дагестан, Цунтинский район, с.Мокок	Россия, республика Дагестан, Цунтинский район, село Мокок	0101000020E61000000C01C0B167F34640508BC1C3B4214540
33149	8	75	1090	53544	\N	\N	42.3002603641837	Республика Дагестан, Цунтинский район, с.Махалатли	Россия, республика Дагестан, Цунтинский район, село Махалотли	0101000020E61000007FDAA84E07E64640032670EB6E264540
33169	8	75	1090	11458	\N	\N	42.245089999999998	Республика Дагестан, Цунтинский район, с.Китури	Россия, республика Дагестан, Цунтинский район, село Китури	0101000020E61000002619390B7B024740CF49EF1B5F1F4540
33141	8	75	1090	53909	\N	\N	42.2083697498473	Республика Дагестан, Цунтинский район, с.Китлярата	Россия, республика Дагестан, Цунтинский район, село Китлярта	0101000020E610000077DA1A118CEB4640D8BB3FDEAB1A4540
33144	8	75	1090	10282	\N	\N	42.249555999999998	Республика Дагестан, Цунтинский район, с.Кимятли	Россия, республика Дагестан, Цунтинский район, село Кимятли	0101000020E6100000C898BB9690E94640A2427573F11F4540
51865	3	29	120	47677	66269	\N	59.157449	Гатчинский район, п.Чаща, ул.Лесная, д.7		0101000020E6100000C05E61C1FD443E40DAE4F04927944D40
33175	8	75	1090	53767	\N	\N	42.246845999999998	Республика Дагестан, Бежтинский участок в составе Цунтинского района, село Качалайский		0101000020E6100000F3E32F2DEAF74640FF9254A6981F4540
33146	8	75	1090	10355	\N	\N	42.244889999999998	Республика Дагестан, Цунтинский район, с.Ицирах	Россия, республика Дагестан, Цунтинский район, село Ицирах	0101000020E610000052F01472A5EC4640088F368E581F4540
33133	8	75	1090	9697	\N	\N	42.196005999999997	Республика Дагестан, Цунтинский район, с.Зехида, здание школы		0101000020E6100000158F8B6A11F94640EEE87FB916194540
33134	8	75	1090	9775	\N	\N	42.207661999999999	Республика Дагестан, Цунтинский район, с.Гутатли, здание школы		0101000020E6100000412AC58EC6F746409C4F1DAB941A4540
33131	8	75	1090	9617	\N	\N	42.176371000000003	Республика Дагестан, Цунтинский район, Генух, здание школы		0101000020E61000006F675F7990FE46403E7B2E5393164540
33168	8	75	1090	11408	\N	\N	42.237321000000001	Республика Дагестан, Цунтинский район, с.Гениятль	Россия, республика Дагестан, Цунтинский район, село Гениятль	0101000020E61000006F2D93E178044740B7D3D688601E4540
33137	8	75	1090	9904	\N	\N	42.196874999999999	Республика Дагестан, Цунтинский район, с.Вициятль, здание школы		0101000020E6100000EDB94C4D82F146403333333333194540
33171	8	75	1090	53420	\N	\N	42.135527031399803	Республика Дагестан, Бежтинский участок в составе Цунтинского района	Россия, республика Дагестан, Бежтинский Участок район	0101000020E610000085285FD0420E4740CD5CE0F258114540
33170	8	75	1090	53929	\N	\N	42.246845999999998	Республика Дагестан, Цунтинский район, с.Ачи-Чунгур		0101000020E6100000F3E32F2DEAF74640FF9254A6981F4540
33153	8	75	1090	53660	\N	\N	42.258575665027301	Республика Дагестан, Цунтинский район, с.Акди	Россия, республика Дагестан, Цунтинский район, село Акды	0101000020E6100000FA2B64AE0CEA4640E7C3B30419214540
33108	8	75	894	8571	\N	\N	42.436956000000002	368900 Республика Дагестан, Цумадинский район, село Эчеда  школа		0101000020E61000001749BBD1C7FE46403FE5982CEE374540
33101	8	75	894	60668	\N	\N	42.448979000000001	368900 Республика Дагестан, Цумадинский район, село Эгдада  администрация		0101000020E6100000823B50A73C0247409FCBD42478394540
33103	8	75	894	8358	\N	\N	42.475093000000001	368900 Республика Дагестан, Цумадинский район, село Цумада-Урух  школа		0101000020E6100000A306D3307C0847407EC7F0D8CF3C4540
33124	8	75	894	8275	\N	\N	42.482878999999997	368900 Республика Дагестан, Цумадинский район, село Ново-Цумада  школа		0101000020E61000004278B471C40647406C76A4FACE3D4540
33102	8	75	894	8275	\N	\N	42.482878999999997	368900 Республика Дагестан, Цумадинский район, село Цумада  школа		0101000020E61000004278B471C40647406C76A4FACE3D4540
33099	8	75	894	60640	\N	\N	42.448979000000001	368900 Республика Дагестан, Цумадинский район, село Цедатли  школа		0101000020E6100000823B50A73C0247409FCBD42478394540
33082	8	75	894	32629	\N	\N	42.518276	368900 Республика Дагестан, Цумадинский район, село Хуштада-Урух  редакция		0101000020E61000004D874ECFBB1547409E2633DE56424540
33081	8	75	894	32629	\N	\N	42.518276	Республика Дагестан, Цумадинский район, село Хуштада  администрация		0101000020E61000004D874ECFBB1547409E2633DE56424540
33121	8	75	894	60669	\N	\N	42.397978742877299	368900 Республика Дагестан, Цумадинский район, село Хушет  администрация	Россия, республика Дагестан, Цумадинский район, село Хушет	0101000020E610000073BA2C2636E3464055BFD2F9F0324540
33117	8	75	894	8987	\N	\N	42.331919999999997	368900 Республика Дагестан, Цумадинский район, село Хонох  школа	Россия, республика Дагестан, Цумадинский район, село Хонох	0101000020E6100000F03499F1B6104740B471C45A7C2A4540
33116	8	75	894	8936	\N	\N	42.352452	368900 Республика Дагестан, Цумадинский район, село Хварщи  школа	Россия, республика Дагестан, Цумадинский район, село Хварши	0101000020E6100000FC8EE1B19F0D474074B4AA251D2D4540
33109	8	75	894	8630	\N	\N	42.415007000000003	368900 Республика Дагестан, Цумадинский район, село Хвайни  школа	Россия, республика Дагестан, Цумадинский район, село Хвайни	0101000020E6100000A0FD481119FC4640384E0AF31E354540
33130	8	75	894	60638	\N	\N	42.448979000000001	368900 Республика Дагестан, Цумадинский район, село Ургалай  школа		0101000020E6100000823B50A73C0247409FCBD42478394540
33080	8	75	894	32621	\N	\N	42.525007000000002	368900 Республика Дагестан, Цумадинский район, село Тлондода  клуб		0101000020E610000021CEC3094C194740E695EB6D33434540
33084	8	75	894	60622	\N	\N	42.448979000000001	368900 Республика Дагестан, Цумадинский район, село Тленхора  вет.лечебница		0101000020E6100000823B50A73C0247409FCBD42478394540
33093	8	75	894	7834	\N	\N	42.502344999999998	368900 Республика Дагестан, Цумадинский район, село Тисси-Ахитли  школа		0101000020E610000061DF4E22C20D4740912749D74C404540
33125	8	75	894	32965	\N	\N	42.491109999999999	368900 Республика Дагестан, Цумадинский район, село Ново-Тисси  школа		0101000020E6100000CDEA1D6E87124740895E46B1DC3E4540
33085	8	75	894	32965	\N	\N	42.491047080262	368900 Республика Дагестан, Цумадинский район, село Тиссинский  школа	Россия, республика Дагестан, Цумадинский район, село Тисси	0101000020E610000044F7AC6BB412474043E6CAA0DA3E4540
33126	8	75	894	32669	\N	\N	42.457335	368900 Республика Дагестан, Цумадинский район, село Ново-Тинди  школа		0101000020E6100000554E7B4ACE11474078280AF4893A4540
33087	8	75	894	32669	\N	\N	42.457335	368900 Республика Дагестан, Цумадинский район, село Нижнее Тинди  спортзал		0101000020E6100000554E7B4ACE11474078280AF4893A4540
33086	8	75	894	32669	\N	\N	42.459585795224903	368900 Республика Дагестан, Цумадинский район, село Верхне-Тиндинский  школа	Россия, республика Дагестан, Цумадинский район, село Тинди	0101000020E61000000AF65FE7A611474088D9CBB6D33A4540
33089	8	75	894	60618	\N	\N	42.448979000000001	368900 Республика Дагестан, Цумадинский район, село Тенли  школа		0101000020E6100000823B50A73C0247409FCBD42478394540
33111	8	75	894	8729	\N	\N	42.452604999999998	368900 Республика Дагестан, Цумадинский район, село Сильди  школа		0101000020E6100000737FF5B86FF74640C780ECF5EE394540
33127	8	75	894	8443	\N	\N	42.495538000000003	368900 Республика Дагестан, Цумадинский район, село Ново-Саситли  школа		0101000020E6100000BEA3C68498FF46406FF607CA6D3F4540
33105	8	75	894	8443	\N	\N	42.495538000000003	368900 Республика Дагестан, Цумадинский район, село Саситли  школа	Россия, республика Дагестан, Цумадинский район, село Саситли	0101000020E6100000BEA3C68498FF46406FF607CA6D3F4540
33114	8	75	894	8847	\N	\N	42.385458999999997	368900 Республика Дагестан, Цумадинский район, село Сантлада  школа		0101000020E6100000DBFB54151A0A4740747973B856314540
33104	8	75	894	8396	\N	\N	42.498382999999997	368900 Республика Дагестан, Цумадинский район, село Ричаганих  школа		0101000020E61000001D38674469074740F1F09E03CB3F4540
33083	8	75	894	60619	\N	\N	42.518276	368900 Республика Дагестан, Цумадинский район, село Ново-Хуштада  школа		0101000020E61000004D874ECFBB1547409E2633DE56424540
33119	8	75	894	32925	\N	\N	42.407764999999998	368900 Республика Дагестан, Цумадинский район, село Нижнее Хварщини  администрация		0101000020E6100000274BADF71BEF46400ABABDA431344540
33098	8	75	894	32758	\N	\N	42.537956999999999	368900 Республика Дагестан, Цумадинский район, село Нижнее Гаквари  клуб	Россия, республика Дагестан, Цумадинский район, село Нижние Гаквари	0101000020E6100000B66455849B064740BFD364C6DB444540
33118	8	75	894	32912	\N	\N	42.393735999999997	368900 Республика Дагестан, Цумадинский район, село Метрада  администрация		0101000020E6100000AE0FEB8D5AF1464001A1F5F065324540
33074	8	75	894	60625	\N	\N	42.540182000000001	368900 Республика Дагестан, Цумадинский район, село Маштихи  школа		0101000020E6100000210725CCB40F4740A6F10BAF24454540
33076	8	75	894	7044	\N	\N	42.526933999999997	368900 Республика Дагестан, Цумадинский район, село Кочали	Россия, республика Дагестан, Цумадинский район, село Кочали	0101000020E6100000DDB243FCC30E47404293C49272434540
33075	8	75	894	60667	\N	\N	42.443954342405497	368900 Республика Дагестан, Цумадинский район, село Колих  гостиница		0101000020E6100000A609DB4FC6024740D576137CD3384540
33128	8	75	894	8513	\N	\N	42.525472999999998	368900 Республика Дагестан, Цумадинский район, село Ново-Кеди  школа		0101000020E6100000FDD98F1491FB46402BF702B342434540
33107	8	75	894	8513	\N	\N	42.525472999999998	368900 Республика Дагестан, Цумадинский район, село Кеди  школа		0101000020E6100000FDD98F1491FB46402BF702B342434540
33115	8	75	894	8887	\N	\N	42.391879000000003	368900 Республика Дагестан, Цумадинский район, село Квантлада  школа		0101000020E61000008F006E162F0847409E7E501729324540
33078	8	75	894	32608	\N	\N	42.562206000000003	368900 Республика Дагестан, Цумадинский район, село Кванада  администрация		0101000020E610000017450F7C0C164740B8CEBF5DF6474540
33113	8	75	894	32868	\N	\N	42.413136999999999	368900 Республика Дагестан, Цумадинский район, село Нижнее Инхоквари  администрация		0101000020E6100000E7C8CA2F830747403FE257ACE1344540
33112	8	75	894	32868	\N	\N	42.411641136099298	368900 Республика Дагестан, Цумадинский район, село Верхнее Инхоквари  школа	Россия, республика Дагестан, Цумадинский район, село Инхоквари	0101000020E6100000BE4C142175074740AC58FCA6B0344540
33079	8	75	894	7191	\N	\N	42.561262999999997	368900 Республика Дагестан, Цумадинский район, село Гимерсо  школа	Россия, республика Дагестан, Цумадинский район, село Гимерсо	0101000020E610000034BF9A03041D474038BA4A77D7474540
33077	8	75	894	32607	\N	\N	42.532296000000002	368900 Республика Дагестан, Цумадинский район, село Гигих  клуб		0101000020E61000003ECA880B400D474054E57B4622444540
33096	8	75	894	57895	\N	\N	42.583061000000001	368900 Республика Дагестан, Цумадинский район, село Гигатли  школа	Россия, республика Дагестан, Цумадинский район, село Гигатль	0101000020E6100000A7CAF78C440C47405A492BBEA14A4540
33123	8	75	894	7979	\N	\N	42.583505136116003	368900 Республика Дагестан, Цумадинский район, село Ново-Гигатли  школа	Россия, республика Дагестан, Цумадинский район, село Гигатли-Урух	0101000020E6100000A391CF2B9E124740B806B64AB04A4540
33097	8	75	894	7979	\N	\N	42.586613	368900 Республика Дагестан, Цумадинский район, село Гигатли-Урух  школа		0101000020E6100000C3EFA65B7612474048348122164B4540
33091	8	75	894	60632	\N	\N	42.448979000000001	368900 Республика Дагестан, Цумадинский район, село Гвинайчи  школа		0101000020E6100000823B50A73C0247409FCBD42478394540
33095	8	75	894	7921	\N	\N	42.550789999999999	368900 Республика Дагестан, Цумадинский район, село Гачитли  школа	Россия, республика Дагестан, Цумадинский район, село Гачитли	0101000020E6100000D8101C97710B47405F7B664980464540
33110	8	75	894	8652	\N	\N	42.471162	368900 Республика Дагестан, Цумадинский район, село Гакко  школа		0101000020E610000073637AC212F14640198F52094F3C4540
33129	8	75	894	7879	\N	\N	42.567107	368900 Республика Дагестан, Цумадинский район, село Ново-Гадири  школа	Россия, республика Дагестан, Цумадинский район, село Гадири	0101000020E6100000FCE1E7BF07094740952A51F696484540
33094	8	75	894	7879	\N	\N	42.567107	368900 Республика Дагестан, Цумадинский район, село Гадири  школа	Россия, республика Дагестан, Цумадинский район, село Гадири	0101000020E6100000FCE1E7BF07094740952A51F696484540
33088	8	75	894	60671	\N	\N	42.465757940529897	368900 Республика Дагестан, Цумадинский район, село Гадайчи  школа	Россия, республика Дагестан, Цумадинский район, село Гадаичи	0101000020E6100000B3D30FEA22094740D9EC48F59D3B4540
33120	8	75	894	32930	\N	\N	42.413077000000001	368900 Республика Дагестан, Цумадинский район, село Верхнее Хварщини  школа		0101000020E610000089B3226AA2EB46406ADD06B5DF344540
33100	8	75	894	8197	\N	\N	42.547449	368900 Республика Дагестан, Цумадинский район, село Верхнее Гаквари  школа		0101000020E6100000D80E46EC130447402C9D0FCF12464540
33092	8	75	894	7775	\N	\N	42.400362000000001	368900 Республика Дагестан, Цумадинский район, село Акнада  школа		0101000020E610000042CC2555DB154740D447E00F3F334540
32349	8	75	341	3464	\N	\N	42.380884000000002	Левашинский район, село Наскент, Здание спортзала		0101000020E6100000F77475C762AB4740EBC891CEC0304540
33073	8	75	894	6904	\N	\N	42.540182000000001	368900 Республика Дагестан, Цумадинский район, село Агвали  школа		0101000020E6100000210725CCB40F4740A6F10BAF24454540
33058	8	75	621	53603	\N	\N	42.620829536636997	"Республика Дагестан, Хунзахский район, кутан СПК ""Тлайлухский"", здание НШ"	Россия, республика Дагестан, Хунзахский район, село Тлайлух	0101000020E6100000D9B45208E44247401630815B774F4540
33044	8	75	621	5404	\N	\N	42.592182000000001	Республика Дагестан, Хунзахский район, село Эбута, здание НШ		0101000020E6100000001FBC7669554740D3A3A99ECC4B4540
33051	8	75	621	53893	\N	\N	42.5833915366537	Республика Дагестан, Хунзахский район, село Шотода, здание с/адм	Россия, республика Дагестан, Хунзахский район, село Шотота	0101000020E61000006878B306EF494740C05FCC96AC4A4540
33057	8	75	621	6103	\N	\N	42.622017	Республика Дагестан, Хунзахский район, село Цельмес, здание СДК		0101000020E6100000F850A2258F4547402C47C8409E4F4540
33049	8	75	621	5670	\N	\N	42.618035999999996	Республика Дагестан, Хунзахский район, село Цалкита, здание СДК		0101000020E6100000DAACFA5C6D49474015E0BBCD1B4F4540
33017	8	75	621	3966	\N	\N	42.542712999999999	Республика Дагестан, Хунзахский район, село Хунзах, здание РДНТ		0101000020E6100000C18EFF02415A4740990E9D9E77454540
33021	8	75	621	4194	\N	\N	42.529207	Республика Дагестан, Хунзахский район, село Хини, здание НШ		0101000020E610000026DF6C73635A47403AE8120EBD434540
33067	8	75	621	6647	\N	\N	42.661504000000001	Республика Дагестан, Хунзахский район, село Хиндах, здание с/адм		0101000020E6100000BD344580D34947402B16BF29AC544540
33048	8	75	621	5610	\N	\N	42.585697000000003	Республика Дагестан, Хунзахский район, село Химакоро, здание НШ	Россия, республика Дагестан, Хунзахский район, село Химакоро	0101000020E610000061A8C30AB74A4740C32E8A1EF84A4540
33045	8	75	621	53439	\N	\N	43.184282000000003	Республика Дагестан, Хунзахский район, село Хачта, здание СПК		0101000020E6100000BB25396057894740E99E758D96974540
33029	8	75	621	4605	\N	\N	42.545430000000003	Республика Дагестан, Хунзахский район, село Хариколо, здание СДК		0101000020E610000008C9022670674740EF2076A6D0454540
33064	8	75	621	6437	\N	\N	42.643982049236797	"Республика Дагестан, Хунзахский район, кутан МУП ""Харахинский"", здание НШ"	Россия, республика Дагестан, Хунзахский район, село Харахи	0101000020E61000003B8DB454DE424740399B8E006E524540
33063	8	75	621	6437	\N	\N	42.644435999999999	Республика Дагестан, Хунзахский район, село Харахи, здание СДК		0101000020E610000086C954C1A8424740BA2EFCE07C524540
33037	8	75	621	5027	\N	\N	42.486083999999998	Республика Дагестан, Хунзахский район, село Уздалросо, здание с/адм	Россия, республика Дагестан, Хунзахский район, село Уздалросо	0101000020E61000007BBB2539606D4740EF8D2100383E4540
33056	8	75	621	6031	\N	\N	42.620769000000003	Республика Дагестан, Хунзахский район, село Тлайлух, здание СДК		0101000020E61000000932022A1C43474071AFCC5B754F4540
33043	8	75	621	5365	\N	\N	42.582444000000002	Республика Дагестан, Хунзахский район, село Тануси, здание с/адм		0101000020E6100000365CE49EAE5847402FE065868D4A4540
33071	8	75	621	53972	\N	\N	42.582719350617403	Республика Дагестан, Хунзахский район, село Тадколо, здание НШ	Россия, республика Дагестан, Хунзахский район, село Тануси	0101000020E610000093FC885FB158474000E14389964A4540
33038	8	75	621	5087	\N	\N	42.498556000000001	Республика Дагестан, Хунзахский район, село Тагада, здание с/библиотеки		0101000020E6100000EA42ACFE086F4740BF9CD9AED03F4540
33053	8	75	621	5832	\N	\N	42.598231782043001	Республика Дагестан, Хунзахский район, село Сентух, здание СПК	Россия, республика Дагестан, Хунзахский район, село Сиух	0101000020E610000018B14F00C5464740D9B5BDDD924C4540
33052	8	75	621	5832	\N	\N	42.600146000000002	Республика Дагестан, Хунзахский район, село Сиух, здание с/адм		0101000020E61000001F6ADB300A464740A1698995D14C4540
33070	8	75	621	6774	\N	\N	42.642167999999998	Республика Дагестан, Хунзахский район, село Очло, здание СДК		0101000020E6100000FF03AC55BB524740D4449F8F32524540
33065	8	75	621	6522	\N	\N	42.659554999999997	Республика Дагестан, Хунзахский район, село Орота, здание СДК		0101000020E6100000390F27309D444740E674594C6C544540
33034	8	75	621	4880	\N	\N	42.604804999999999	Республика Дагестан, Хунзахский район, село Оркачи, здание с/адм		0101000020E6100000AB5FE97C7868474088BA0F406A4D4540
33055	8	75	621	53786	\N	\N	42.583644999999997	Республика Дагестан, Хунзахский район, село Ондокоро, здание СПК		0101000020E61000000C06D7DCD1574740A9BC1DE1B44A4540
33040	8	75	621	5191	\N	\N	42.577159000000002	Республика Дагестан, Хунзахский район, село Обода, здание СДК		0101000020E610000040C39B3578554740C9CB9A58E0494540
33023	8	75	621	4269	\N	\N	42.506791999999997	Республика Дагестан, Хунзахский район, село Накитль, здание НШ	Россия, республика Дагестан, Хунзахский район, село Накитль	0101000020E6100000EE5F596952544740EDEF6C8FDE404540
33059	8	75	621	6218	\N	\N	42.633645000000001	Республика Дагестан, Хунзахский район, село Мушули, здание СДК		0101000020E61000003E3C4B9011404740102384471B514540
33069	8	75	621	6722	\N	\N	42.631410000000002	Республика Дагестан, Хунзахский район, село Мочох, здание СДК		0101000020E6100000B70DA320784E4740062FFA0AD2504540
33036	8	75	621	5004	\N	\N	42.503528000000003	Республика Дагестан, Хунзахский район, село Малый Гоцатль, здание СДК		0101000020E6100000F816D68D77714740664F029B73404540
33062	8	75	621	53459	\N	\N	42.646533042356403	Республика Дагестан, Хунзахский район, село Малое Амущи, здание с/библиотеки	Россия, республика Дагестан, Хунзахский район, село Малая Амуша	0101000020E61000005ED905836B3E47407364E597C1524540
33068	8	75	621	6673	\N	\N	42.656650999999997	Республика Дагестан, Хунзахский район, село Коло, здание СДК		0101000020E6100000FBE8D495CF4847405EF1D4230D544540
33039	8	75	621	53939	\N	\N	42.495615906235599	Республика Дагестан, Хунзахский район, село Кахилкал, здание СДК	Россия, республика Дагестан, Хунзахский район, село Кахикал	0101000020E6100000A968ACFD9D6F4740EAAF5758703F4540
33031	8	75	621	4730	\N	\N	42.557451	Республика Дагестан, Хунзахский район, село Ках, здание СДК		0101000020E610000011FFB0A547654740AE0FEB8D5A474540
33022	8	75	621	4203	\N	\N	42.491309999999999	Республика Дагестан, Хунзахский район, село Заиб, здание ОШ		0101000020E61000009A3E3BE0BA5A47405019FF3EE33E4540
33041	8	75	621	5253	\N	\N	42.574046000000003	Республика Дагестан, Хунзахский район, село Гортколо, здание НШ	Россия, республика Дагестан, Хунзахский район, село Гортколо	0101000020E61000006D3656629E5147402733DE567A494540
33020	8	75	621	4094	\N	\N	42.559928999999997	Республика Дагестан, Хунзахский район, село Гонох, здание НШ		0101000020E6100000D9B0A6B2285847407E8AE3C0AB474540
33019	8	75	621	4084	\N	\N	42.563873000000001	Республика Дагестан, Хунзахский район, село Геничутль, здание СДК	Россия, республика Дагестан, Хунзахский район, село Геничутль	0101000020E61000009C6C0377A05E4740780C8FFD2C484540
33046	8	75	621	5520	\N	\N	42.592308000000003	Республика Дагестан, Хунзахский район, село Гацалух, здание СДК		0101000020E6100000C2DCEEE53E5347406094A0BFD04B4540
33033	8	75	621	4773	\N	\N	42.587450513038	Республика Дагестан, Хунзахский район, село Новая Буцра, здание СОШ	Россия, республика Дагестан, Хунзахский район, село Буцра	0101000020E6100000F48AA71E6962474052802898314B4540
33032	8	75	621	4773	\N	\N	42.588292000000003	Республика Дагестан, Хунзахский район, село Буцра, здание СДК		0101000020E6100000FCC6D79E59624740CD3FFA264D4B4540
33035	8	75	621	4933	\N	\N	42.519658	Республика Дагестан, Хунзахский район, село Большой Гоцатль, здание СДК		0101000020E61000004757E9EE3A714740698D412784424540
33027	8	75	621	4500	\N	\N	42.553234000000003	Республика Дагестан, Хунзахский район, село Батлаич, здание СДК		0101000020E61000008BDF14562A6047408484285FD0464540
33018	8	75	621	3980	\N	\N	42.546665936744603	Республика Дагестан, Хунзахский район, село Байитль, здание НШ	Россия, республика Дагестан, Хунзахский район, село Баитль	0101000020E61000002062838593564740E6EAC726F9454540
33050	8	75	621	53802	\N	\N	42.582376689021601	Республика Дагестан, Хунзахский район, село Ахтини, здание СПК	Россия, республика Дагестан, Хунзахский район	0101000020E6100000AF08FEB792574740A7785C548B4A4540
33047	8	75	621	5561	\N	\N	42.594935999999997	Республика Дагестан, Хунзахский район, село Ахалчи, здание СДК		0101000020E6100000ED9E3C2CD4504740459BE3DC264C4540
33026	8	75	621	4450	\N	\N	42.555439	Республика Дагестан, Хунзахский район, село Арани, здание с/адм		0101000020E61000005C76887FD85C474023F609A018474540
33028	8	75	621	53935	\N	\N	43.309798999999998	Республика Дагестан, Хунзахский район, село Арада, здание СДК		0101000020E6100000F9BF232A54934740B0AA5E7EA7A74540
33061	8	75	621	53599	\N	\N	42.583644999999997	Республика Дагестан, Хунзахский район, село Амущи, здание с/адм		0101000020E61000000C06D7DCD1574740A9BC1DE1B44A4540
33054	8	75	621	53449	\N	\N	42.628304167428801	Республика Дагестан, Хунзахский район, село Амишта, здание с/адм	Россия, республика Дагестан, Хунзахский район, село Амишти	0101000020E6100000FC6D4F90D846474016F9F5436C504540
33016	8	75	416	53829	\N	\N	41.836457000000003	сельсовет Юхари-Яракский, Сельский дом культуры	Россия, республика Дагестан, Хивский район, село Юхари-Ярак	0101000020E6100000467A51BB5FF9474051C1E10511EB4440
31970	8	75	416	17157	\N	\N	41.696876469454899	"село Захит, Зд. админ ""с/с Захитский"""	Россия, республика Дагестан, Хивский район, село Юхари-Захит	0101000020E6100000D7A6B1BD16F8474004AF963B33D94440
33015	8	75	416	3863	\N	\N	41.739780000000003	село Юхари-Архит, Начальная школа	Россия, республика Дагестан, Хивский район, село Юхари-Архит	0101000020E610000099F38C7DC9FA4740111E6D1CB1DE4440
33013	8	75	416	3767	\N	\N	41.809015000000002	село Чувек, Сельский дом культуры		0101000020E610000011E2CAD93BF347409A7CB3CD8DE74440
33012	8	75	416	3700	\N	\N	41.743366000000002	село Чиликар, Сельский дом культуры		0101000020E6100000F75AD07B63084840AB7AF99D26DF4440
33011	8	75	416	3674	\N	\N	41.807281281196701	село Чере, Общеобразовательная школа	Россия, республика Дагестан, Хивский район, село Чере	0101000020E6100000821ABE857505484052D7DAFB54E74440
33010	8	75	416	3593	\N	\N	41.782947	село Цудук, Общеобразовательная школа		0101000020E610000015562AA8A8F247402BC0779B37E44440
32289	8	75	416	32423	\N	\N	41.696254000000003	село Цнал, Сельский дом культуры		0101000020E6100000FA43334FAEFF4740C7DADFD91ED94440
33009	8	75	416	3567	\N	\N	41.711983182967799	село Цлак, Сельская библиотека	Россия, республика Дагестан, Хивский район, село Цлак	0101000020E6100000BF60376C5BF847406B274A4222DB4440
33007	8	75	416	3459	\N	\N	41.749293000000002	село  Хоредж, Спортзал средней школы	Россия, республика Дагестан, Хивский район, село Хоредж	0101000020E610000069FF03AC55EF4740950F41D5E8DF4440
33006	8	75	416	3387	\N	\N	41.755125	село Хив, Спортзал ДЮСШ		0101000020E610000091F12895F0F647402DB29DEFA7E04440
33014	8	75	416	3804	\N	\N	41.863404000000003	село Фурдаг, Сельский дом культуры		0101000020E61000003387A4164AEE4740289EB30584EE4440
33005	8	75	416	3364	\N	\N	41.891091000000003	село Уртиль, Сельский клуб село Уртиль	Россия, республика Дагестан, Хивский район, село Уртиль	0101000020E6100000E0A0BDFA78F24740466117450FF24440
33004	8	75	416	53584	\N	\N	41.772556615741799	село Урга, Общеобразовательная школа	Россия, республика Дагестан, Хивский район	0101000020E610000036E9B6442EF24740DFA5D425E3E24440
33000	8	75	416	3038	\N	\N	41.807576653682602	село Межгюль, Средняя школа село Межгюль	Россия, республика Дагестан, Хивский район, село Межгюль	0101000020E6100000558A1D8D430148403B00E2AE5EE74440
32999	8	75	416	3008	\N	\N	41.882424999999998	"село Ляхля, Здан.адм. мо ""сельсовет Ляхлинский"""		0101000020E6100000DD5ED218ADEF47401E166A4DF3F04440
32998	8	75	416	2916	\N	\N	41.757263999999999	село Лака, Общеобразователья школа  село Лака	Россия, республика Дагестан, Хивский район, село Лака	0101000020E61000006327BC04A7F047401538D906EEE04440
37702	3	28	\N	7525	23201	\N	55.072916999999997	город Советск, Тимирязева, 20		0101000020E610000020EC14AB06E135404529215855894B40
32997	8	75	416	2882	\N	\N	41.828090583829798	село Куштиль, Сельский дом культуры село Куштиль	Россия, республика Дагестан, Хивский район, село Куштиль	0101000020E61000005682C5E1CCF14740548EC9E2FEE94440
32996	8	75	416	53510	\N	\N	41.771594333370203	"село Куг, Здание админ. мо ""село Куг"""	Россия, республика Дагестан, Хивский район, село Куг	0101000020E6100000B954A52DAEFB474019E59997C3E24440
32995	8	75	416	2774	\N	\N	41.884008999999999	село Кувиг, Сельский клуб село Кувиг		0101000020E6100000205F420587F14740512FF83427F14440
32994	8	75	416	2686	\N	\N	41.740963999999998	село Кошкент, Сельский дом культуры село Кошкент		0101000020E6100000B037312427054840B5C189E8D7DE4440
32993	8	75	416	2671	\N	\N	41.753013000000003	село Конциль, Сельский дом культуры село Конциль		0101000020E6100000225514AFB20248403F3BE0BA62E04440
32992	8	75	416	53788	\N	\N	41.797640598672899	село Кондикский, Кондикский сельский дом культуры	Россия, республика Дагестан, Хивский район, село Конди	0101000020E61000000DA661F888F047407079AC1919E64440
32991	8	75	416	2549	\N	\N	41.812348999999998	село Зильдик, Сельский дом культуры село Зильдик		0101000020E6100000F17F4754A8FE47401AF8510DFBE74440
31594	8	75	416	53927	\N	\N	41.741606958158897	село Дардаркент, Сельский клуб село Дардаркент	Россия, республика Дагестан, Хивский район, село Дардакент	0101000020E6100000527C7C42760248400ABE69FAECDE4440
31436	8	75	416	23361	\N	\N	41.872233999999999	село Вертиль, Сельская библиотека		0101000020E6100000F0DFBC38F1ED4740C93A1C5DA5EF4440
33008	8	75	416	3489	\N	\N	41.723897716244998	село Ашага-Цинит, Средняя общеобразовательная школа	Россия, республика Дагестан, Хивский район, село Ашага-Цинит	0101000020E610000052B9895A9A014840E5D18DB0A8DC4440
32989	8	75	416	2431	\N	\N	41.736665000000002	село Ашага-Архит, Сельский дом культуры	Россия, республика Дагестан, Хивский район, село Ашага-Архит	0101000020E610000017618A7269FC4740CE8DE9094BDE4440
32986	8	75	416	2224	\N	\N	41.880209999999998	село Атрик, Сельский дом культуры село Атрик		0101000020E61000006CB07092E6E347405BCEA5B8AAF04440
32988	8	75	416	2339	\N	\N	41.756255000000003	село Асакент, Начальная школа село Асакент		0101000020E61000006090F46915014840DF37BEF6CCE04440
32987	8	75	416	2317	\N	\N	41.784056	село Арчуг, Начальная школа село Арчуг		0101000020E610000075E5B33C0FEE4740C51D6FF25BE44440
32962	8	75	22	706	\N	\N	43.168134999999999	Республика Дагестан, Хасавюртовский район, село Эндирей, Здание школы №2		0101000020E6100000A94BC631925347400F289B7285954540
32961	8	75	22	706	\N	\N	43.168134999999999	Республика Дагестан, Хасавюртовский район, село Эндирей, Здание школы №1		0101000020E6100000A94BC631925347400F289B7285954540
32960	8	75	22	706	\N	\N	43.168134999999999	Республика Дагестан, Хасавюртовский район, село Эндирей, Здание дома культуры		0101000020E6100000A94BC631925347400F289B7285954540
32936	8	75	22	31910	\N	\N	43.478265999999998	Республика Дагестан, Хасавюртовский район, село Шагада, Здание школы		0101000020E61000009DF7FF71C25C4740F564FED137BD4540
32914	8	75	22	30844	\N	\N	43.468957000000003	Республика Дагестан, Хасавюртовский район, село Чагаротар, Здание школы		0101000020E610000043E73576894447407A1D71C806BC4540
32931	8	75	22	53640	\N	\N	43.384598280484902	Республика Дагестан, Хасавюртовский район, село Цияб Ичичали, Здание дома культуры		0101000020E610000010069E7B0F4F4740B20DDC813AB14540
32919	8	75	22	31105	\N	\N	43.272074000000003	Республика Дагестан, Хасавюртовский район, село Хамавюрт, Здание дома культуры		0101000020E61000006E162F1686364740C40B2252D3A24540
32924	8	75	22	31326	\N	\N	43.489353000000001	Республика Дагестан, Хасавюртовский район, село Тукита, Здание дома культуры		0101000020E6100000D3DB9F8B864E474089997D1EA3BE4540
32904	8	75	22	30329	\N	\N	43.434728999999997	Республика Дагестан, Хасавюртовский район, село Теречное, Здание дома культуры		0101000020E6100000A2ED98BA2B334740B7CF2A33A5B74540
32955	8	75	22	53705	\N	\N	43.251990308482299	Республика Дагестан, Хасавюртовский район, сельсовет Темираульский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Темир-Аул	0101000020E6100000967840D994694740A375543541A04540
32937	8	75	22	31950	\N	\N	43.471462000000002	Республика Дагестан, Хасавюртовский район, село Сулевкент, Здание дома культуры		0101000020E610000045B75ED38360474044A7E7DD58BC4540
32923	8	75	22	53549	\N	\N	43.325913221129802	Республика Дагестан, Хасавюртовский район, село Солнечное, Здание школы	Россия, республика Дагестан, Хасавюртовский район	0101000020E6100000D20149D8B7554740AE2B6684B7A94540
32922	8	75	22	53549	\N	\N	43.326226771577801	Республика Дагестан, Хасавюртовский район, село Солнечное, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район	0101000020E61000007D93A641D15647403E096CCEC1A94540
32906	8	75	22	30429	\N	\N	43.409979	Республика Дагестан, Хасавюртовский район, село Советское, Здание школы		0101000020E610000045B9347EE12B4740FD851E317AB44540
32932	8	75	22	31727	\N	\N	43.407319999999999	Республика Дагестан, Хасавюртовский район, село Сиух, Здание школы		0101000020E61000008CF4A276BF4C4740DC80CF0F23B44540
32963	8	75	22	53643	\N	\N	43.330236999999997	Республика Дагестан, Хасавюртовский район, село Тотурбийкала, Здание школы		0101000020E61000000D51853FC3554740EE76BD3445AA4540
32944	8	75	22	32260	\N	\N	43.330236999999997	Республика Дагестан, Хасавюртовский район, село Садовое, Здание школы		0101000020E61000000D51853FC3554740EE76BD3445AA4540
32947	8	75	22	53695	\N	\N	43.285984767174703	Республика Дагестан, Хасавюртовский район, сельсовет Покровский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Покровское	0101000020E610000097900F7A36554740C2120F289BA44540
32907	8	75	22	30479	\N	\N	43.439076	Республика Дагестан, Хасавюртовский район, село Первомайское, Здание дома культуры		0101000020E6100000C5C72764E72B4740B03A72A433B84540
32927	8	75	22	53661	\N	\N	43.301658423951601	Республика Дагестан, Хасавюртовский район, сельсовет Османюртовский, Здание библиотеки	Россия, республика Дагестан, Хасавюртовский район, село Османюрт	0101000020E61000002D7B12D89C434740D449B6BA9CA64540
32909	8	75	22	53454	\N	\N	43.483440000000002	Республика Дагестан, Хасавюртовский район, сельсовет Октябрьский, Здание сельской администрации	Россия, республика Дагестан, Хасавюртовский район, село Октябрьское	0101000020E61000006534F279C537474004CAA65CE1BD4540
32920	8	75	22	31140	\N	\N	43.282884000000003	Республика Дагестан, Хасавюртовский район, село Нурадилово, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район, село Нурадилово	0101000020E6100000A5F9635A9B3A4740E547FC8A35A44540
32943	8	75	22	32204	\N	\N	43.333129	Республика Дагестан, Хасавюртовский район, село Новый Костек, Здание школы		0101000020E6100000DE1D19ABCD694740B22C98F8A3AA4540
32929	8	75	22	53700	\N	\N	43.386330400975702	Республика Дагестан, Хасавюртовский район, село Новососитли, Здание сельской администрации	Россия, республика Дагестан, Хасавюртовский район, село отделение № 3 совхоза Дагестан	0101000020E6100000C2DCEEE53E4B47405ABBED4273B14540
32912	8	75	22	53734	\N	\N	43.430965396565199	Республика Дагестан, Хасавюртовский район, сельсовет Новосельский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Новосельское	0101000020E61000008124ECDB493C47403E5C72DC29B74540
32910	8	75	22	53423	\N	\N	43.4642982275045	Республика Дагестан, Хасавюртовский район, село Новогагатли, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Новогагатлинское	0101000020E6100000A774B0FECF3D474092CCEA1D6EBB4540
32954	8	75	22	53621	\N	\N	43.330236999999997	Республика Дагестан, Хасавюртовский район, село Муцалаул, Здание школы №2		0101000020E61000000D51853FC3554740EE76BD3445AA4540
32953	8	75	22	53692	\N	\N	43.274070312131997	Республика Дагестан, Хасавюртовский район, село Муцалаул, Здание школы №1	Россия, республика Дагестан, Хасавюртовский район, село Муцал-Аул	0101000020E610000010B1C1C2495E47404968CBB914A34540
32952	8	75	22	53692	\N	\N	43.275637925090102	Республика Дагестан, Хасавюртовский район, село Муцалаул, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район, село Муцал-Аул	0101000020E6100000AE0FEB8D5A5D474076C4211B48A34540
32913	8	75	22	30806	\N	\N	43.433832000000002	Республика Дагестан, Хасавюртовский район, село Моксоб, Здание школы		0101000020E6100000081EDFDE353E4740A9FA95CE87B74540
32941	8	75	22	15831	\N	\N	43.384509999999999	Республика Дагестан, Хасавюртовский район, село Куруш, Здание дома культуры		0101000020E6100000FAD005F52D614740137EA99F37B14540
32940	8	75	22	15831	\N	\N	43.384509999999999	Республика Дагестан, Хасавюртовский район, село Куруш, Здание школы №2		0101000020E6100000FAD005F52D614740137EA99F37B14540
32942	8	75	22	53730	\N	\N	43.340762120644598	Республика Дагестан, Хасавюртовский район, сельсовет Костекский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Костек	0101000020E6100000AC74779D0D6D47401ADCD6169EAB4540
32957	8	75	22	53509	\N	\N	43.232914935841997	Республика Дагестан, Хасавюртовский район, сельсовет Кокрекский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Кокрек	0101000020E6100000641F6459305D4740B9DFA128D09D4540
32956	8	75	22	53509	\N	\N	43.237481512434798	Республика Дагестан, Хасавюртовский район, сельсовет Кокрекский, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район, село Кокрек	0101000020E61000003B70CE88D25C4740C0B167CF659E4540
32959	8	75	22	53704	\N	\N	43.242025534564	Республика Дагестан, Хасавюртовский район, сельсовет Карланюртовский, Здание сельского клуба	Россия, республика Дагестан, Хасавюртовский район, поселок Карланюрт	0101000020E61000000B43E4F4F55C47400F643DB5FA9E4540
32958	8	75	22	53704	\N	\N	43.2429553554649	Республика Дагестан, Хасавюртовский район, сельсовет Карланюртовский, Здание сельской администрации	Россия, республика Дагестан, Хасавюртовский район, поселок Карланюрт	0101000020E61000007AA69718CB5C474029B34126199F4540
32930	8	75	22	31642	\N	\N	43.341495000000002	Республика Дагестан, Хасавюртовский район, село Кандаураул, Здание школы		0101000020E6100000629D2ADF33484740AF5FB01BB6AB4540
32939	8	75	22	53486	\N	\N	43.4281239754052	Республика Дагестан, Хасавюртовский район, сельсовет Казмааульский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Казма-Аул	0101000020E61000007993DFA293614740FC5069C4CCB64540
32938	8	75	22	53486	\N	\N	43.428605476056397	Республика Дагестан, Хасавюртовский район, сельсовет Казмааульский, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район, село Казма-Аул	0101000020E61000005FCFD72C9761474077F35487DCB64540
32908	8	75	22	30526	\N	\N	43.517463999999997	Республика Дагестан, Хасавюртовский район, село Дзержинское, Здание дома культуры		0101000020E61000006631B1F9B83C4740BD6DA6423CC24540
32946	8	75	22	53595	\N	\N	43.3071437323662	Республика Дагестан, Хасавюртовский район, сельсовет Батаюртовский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Боташ-Юрт	0101000020E61000007C6473D53C414740D1949D7E50A74540
32945	8	75	22	53589	\N	\N	43.316199937897103	Республика Дагестан, Хасавюртовский район, сельсовет Батаюртовский, Здание спортивного зала школы	Россия, республика Дагестан, Хасавюртовский район, село Бота-Юрт	0101000020E610000007793D9814574740637FD93D79A84540
32921	8	75	22	31184	\N	\N	43.308796000000001	Республика Дагестан, Хасавюртовский район, село Борагангечув, Здание школы		0101000020E610000052616C21C83747405C9198A086A74540
32918	8	75	22	53731	\N	\N	43.3091803341201	Республика Дагестан, Хасавюртовский район, село Баташюрт, Здание дома культуры		0101000020E61000002312859675414740E449D23593A74540
32928	8	75	22	53652	\N	\N	43.341513866402003	Республика Дагестан, Хасавюртовский район, село Бамматюрт, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район, село Баммат-Юрт	0101000020E61000008F368E588B4D4740259012BBB6AB4540
32951	8	75	22	53694	\N	\N	43.2976660276288	Республика Дагестан, Хасавюртовский район, сельсовет Байрамаульский, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район, село Байрамаул	0101000020E6100000408A3A730F5D4740C99063EB19A64540
32950	8	75	22	53694	\N	\N	43.296643296418502	Республика Дагестан, Хасавюртовский район, сельсовет Байрамаульский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Байрамаул	0101000020E61000004E98309A955D47402ECBD765F8A54540
33072	8	75	22	6859	\N	\N	43.429622999999999	Республика Дагестан, Хунзахский район, село Архида, здание СДК		0101000020E61000004227840EBA644740014EEFE2FDB64540
32917	8	75	22	30904	\N	\N	43.372217999999997	Республика Дагестан, Хасавюртовский район, село Аксай, Здание школы - интернат		0101000020E6100000FE62B66455384740C37DE4D6A4AF4540
32916	8	75	22	30904	\N	\N	43.372217999999997	Республика Дагестан, Хасавюртовский район, село Аксай, Здание школы  №2		0101000020E6100000FE62B66455384740C37DE4D6A4AF4540
32915	8	75	22	30904	\N	\N	43.372217999999997	Республика Дагестан, Хасавюртовский район, село Аксай, Здание школы №1		0101000020E6100000FE62B66455384740C37DE4D6A4AF4540
32905	8	75	22	53958	\N	\N	43.459698000000003	Республика Дагестан, Хасавюртовский район, село Акбулатюрт, Здание сельской администрации	Россия, республика Дагестан, Хасавюртовский район, село Акбулатьюрт	0101000020E61000003B51121269314740B0045262D7BA4540
32935	8	75	22	53625	\N	\N	43.329942868886903	Республика Дагестан, Хасавюртовский район, сельсовет Адильотарский, Здание ФАП		0101000020E610000080D767CEFA564740A6457D923BAA4540
32934	8	75	22	53625	\N	\N	43.461922521022601	Республика Дагестан, Хасавюртовский район, сельсовет Адильотарский, Здание школы	Россия, республика Дагестан, Хасавюртовский район, село Адиль-Отар	0101000020E610000058CB9D99605647409622F94A20BB4540
32933	8	75	22	53625	\N	\N	43.457170826003001	Республика Дагестан, Хасавюртовский район, сельсовет Адильотарский, Здание дома культуры	Россия, республика Дагестан, Хасавюртовский район, село Адиль-Отар	0101000020E6100000E0BE0E9C33564740FED64E9484BA4540
32925	8	75	22	31397	\N	\N	43.349460999999998	Республика Дагестан, Хасавюртовский район, село Аджимажагатюрт, Здание дома культуры		0101000020E61000009C31CC09DA4047401D1D5723BBAC4540
32880	8	75	1858	53473	\N	\N	42.726337999999998	Республика Дагестан, Унцукульский район, с.Хинтлимита, здание филиала художественной фабрики		0101000020E6100000F7562426A8714740C8EBC1A4F85C4540
32876	8	75	1858	28966	\N	\N	42.687879000000002	Республика Дагестан, Унцукульский район, поселок Шамилькала, здание дома кольтуры поселка		0101000020E61000004ACFF412636F4740774D486B0C584540
32875	8	75	1858	28966	\N	\N	42.687879000000002	Республика Дагестан, Унцукульский район, поселок Шамилькала, здание ДОУ №8		0101000020E61000004ACFF412636F4740774D486B0C584540
32874	8	75	1858	28966	\N	\N	42.687879000000002	Республика Дагестан, Унцукульский район, поселок Шамилькала, здание поселковой средней школы		0101000020E61000004ACFF412636F4740774D486B0C584540
32903	8	75	1858	30223	\N	\N	42.672058	Республика Дагестан, Унцукульский район, село Цатаних, село Новоцатаних, здание школы		0101000020E61000009D2ADF33125D4740F1811DFF05564540
32902	8	75	1858	30223	\N	\N	42.672058	Республика Дагестан, Унцукульский район, село Цатаних, здание администрации села		0101000020E61000009D2ADF33125D4740F1811DFF05564540
32881	8	75	1858	29261	\N	\N	42.677897999999999	Республика Дагестан, Унцукульский район, село Харачи, здание ФАП	Россия, республика Дагестан, Унцукульский район, село Харачи	0101000020E61000004E7D2079E76847400C03965CC5564540
32879	8	75	1858	29118	\N	\N	42.711011869830301	"Республика Дагестан, Унцукульский район, сельсовет Унцукульский, здание ДОУ №2 ""Ласточка"""	Россия, республика Дагестан, Унцукульский район, село Унцукуль	0101000020E610000062838593346547402288F370025B4540
32878	8	75	1858	29118	\N	\N	42.712024	Республика Дагестан, Унцукульский район, сельсовет Унцукульский,село Унцукуль, здание районного дома культуры		0101000020E61000008BFF3BA242654740CAFB389A235B4540
32877	8	75	1858	29118	\N	\N	42.712024	Республика Дагестан, Унцукульский район, сельсовет Унцукульский, здание средней школы №1		0101000020E61000008BFF3BA242654740CAFB389A235B4540
32882	8	75	1858	29300	\N	\N	42.655239000000002	Республика Дагестан, Унцукульский район, с.Моксох, здание основной школы		0101000020E6100000E4D6A4DB1267474029081EDFDE534540
32885	8	75	1858	53729	\N	\N	42.598375078693202	Республика Дагестан, Унцукульский район, сельсовет Майданский,село Майданское, здание средней школы	Россия, республика Дагестан, Унцукульский район, село Майданский	0101000020E6100000FE2C9622F97A47403BDF4F8D974C4540
32899	8	75	1858	30061	\N	\N	42.677969402501702	Республика Дагестан, Унцукульский район, с.Колоб прикутанный, здание сельского дома культуры	Россия, республика Дагестан, Унцукульский район, село Колоб	0101000020E61000009F3E027FF8574740D5592DB0C7564540
32348	8	75	341	3464	\N	\N	42.380884000000002	Левашинский район, село Наскент, Здание дома культуры		0101000020E6100000F77475C762AB4740EBC891CEC0304540
32898	8	75	1858	30061	\N	\N	42.678229999999999	Республика Дагестан, Унцукульский район, сельсовет Иштибуринский, с.Колоб, здание начальной школы		0101000020E61000002DB5DE6FB457474042959A3DD0564540
32895	8	75	1858	29920	\N	\N	42.736597000000003	Республика Дагестан, Унцукульский район, сельсовет Кахабросинский, село Кахабросо, здание администрации с\\с		0101000020E61000007BDD2230D659474076AA7CCF485E4540
32900	8	75	1858	30002	\N	\N	42.679237000000001	"Республика Дагестан, Унцукульский район, сельсовет Иштибуринский, с.Иштибури прикутанный, здание МУП ""колхоз Иштибуринский"""	Россия, республика Дагестан, Унцукульский район, село Иштибури	0101000020E6100000FF058200195A4740D89DEE3CF1564540
32897	8	75	1858	30002	\N	\N	42.679237000000001	Республика Дагестан, Унцукульский район, сельсовет Иштибуринский, село Иштибури, здание администрации с\\с		0101000020E6100000FF058200195A4740D89DEE3CF1564540
32890	8	75	1858	29620	\N	\N	42.648235999999997	Республика Дагестан, Унцукульский район, село старый Ирганай, здание спорткомплекса	Россия, республика Дагестан, Унцукульский район, село Ирганай	0101000020E6100000F0A31AF67B744740800BB265F9524540
32889	8	75	1858	29620	\N	\N	42.648235999999997	Республика Дагестан, Унцукульский район, село Ирганай, здание администрации села		0101000020E6100000F0A31AF67B744740800BB265F9524540
32901	8	75	1858	30184	\N	\N	42.700702	Республика Дагестан, Унцукульский район, с.Инквалита, здание начальной школы		0101000020E61000009355116E32584740F31E679AB0594540
32884	8	75	1858	29377	\N	\N	42.617857000000001	Республика Дагестан, Унцукульский район,сельсовет Майданский, с.Зирани, здание начальной школы		0101000020E6100000774A07EBFF784740664D2CF0154F4540
32893	8	75	1858	29715	\N	\N	42.758927999999997	Республика Дагестан, Унцукульский район, село Гимры, вр.пос. Гимры, здание поселковой средней школы	Россия, республика Дагестан, Унцукульский район, село Гимры	0101000020E6100000DF8C9AAF926B474064027E8D24614540
32892	8	75	1858	29715	\N	\N	42.758927999999997	Республика Дагестан, Унцукульский район, село Гимры, здание сельского дома культуры		0101000020E6100000DF8C9AAF926B474064027E8D24614540
32891	8	75	1858	29715	\N	\N	42.758927999999997	Республика Дагестан, Унцукульский район, село Гимры, здание средней школы		0101000020E6100000DF8C9AAF926B474064027E8D24614540
32896	8	75	1858	29929	\N	\N	42.723483999999999	Республика Дагестан, Унцукульский район, сельсовет Кахабросинский, с.Бетли, здание библиотеки		0101000020E6100000774D486B0C5E4740F296AB1F9B5C4540
32883	8	75	1858	29351	\N	\N	42.633101000000003	Республика Дагестан, Унцукульский район, сельсовет Балаханский, село Балахани, здание администрации с\\с		0101000020E61000004DBB9866BA7147404F081D7409514540
32894	8	75	1858	29845	\N	\N	42.770822000000003	Республика Дагестан, Унцукульский район, село Ашильта, здание администрации села		0101000020E6100000107A36AB3E5D4740C784984BAA624540
32888	8	75	1858	29485	\N	\N	42.608946000000003	"Республика Дагестан, Унцукульский район, сельсовет Араканский, с.Аракани прикутанный, здание МУП ""совхоз Араканский"""	Россия, республика Дагестан, Унцукульский район, село Аракани	0101000020E610000030BB270F0B7F4740D88349F1F14D4540
32887	8	75	1858	29485	\N	\N	42.608203173391203	Республика Дагестан, Унцукульский район, сельсовет Араканский, с.Аракани-завод, здание консервного завода	Россия, республика Дагестан, Унцукульский район, село Аракани	0101000020E61000002A560DC2DC7E4740202A8D98D94D4540
32886	8	75	1858	29485	\N	\N	42.608946000000003	Республика Дагестан, Унцукульский район, сельсовет Араканский, село Аракани, здание администрации с\\с		0101000020E610000030BB270F0B7F4740D88349F1F14D4540
32842	8	75	1782	53656	\N	\N	42.081449999999997	Республика Дагестан, Тляратинский район, сельсовет Чадаколобский, селение Чадаколоб	Россия, республика Дагестан, Тляратинский район	0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32858	8	75	1782	53484	\N	\N	42.081449999999997	Республика Дагестан, Тляратинский район, сельсовет Гиндибский, селение Калининаул		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32857	8	75	1782	53658	\N	\N	42.081449999999997	Республика Дагестан, Тляратинский район, сельсовет Гиндибский, селение Ибрагимотар		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32821	8	75	1782	53657	\N	\N	42.081449999999997	Республика Дагестан, Тляратинский район, сельсовет Тохотинский, селение Верхняя-Тохота		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32849	8	75	1782	53819	\N	\N	42.081449999999997	Республика Дагестан, Тляратинский район, сельсовет Начадинский, селение Бежуда		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32855	8	75	1782	53635	\N	\N	42.081449999999997	Республика Дагестан, Тляратинский район, сельсовет Кособский, селение Акнада		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32859	8	75	1782	53959	\N	\N	42.002371955188799	"Республика Дагестан, Тляратинский район, сельсовет Колобский, населенный пункт ""Тельмана"""	Россия, республика Дагестан, Тляратинский район	0101000020E6100000AF95D05D124947408B36C7B94D004540
32862	8	75	1782	53585	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Камилухский, населенный пункт ""Гутанаул"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32863	8	75	1782	53641	\N	\N	43.563521846641699	"Республика Дагестан, Тляратинский район, сельсовет Чородинский, населенный пункт ""Дахадаева"""	Россия, республика Дагестан, Бабаюртовский район, село колхоза имени Дахадаева	0101000020E61000000342EBE1CB784740CB49287D21C84540
32872	8	75	1782	53604	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Гведышский, населенный пункт ""Янгибина"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32866	8	75	1782	53653	\N	\N	42.232694000000002	Республика Дагестан, Тляратинский район, сельсовет Шидибский, селение Шедрин	Россия, республика Дагестан, Тляратинский район, село Шидиб	0101000020E610000030F65E7CD1304740DBFCBFEAC81D4540
32844	8	75	1782	53653	\N	\N	42.213921384664602	Республика Дагестан, Тляратинский район, сельсовет Шидибский, селение Шидиб	Россия, республика Дагестан, Тляратинский район	0101000020E61000007E703E75AC264740BC7669C3611B4540
32814	8	75	1782	53957	\N	\N	42.195345000000003	Республика Дагестан, Тляратинский район, сельсовет Чородинский, селение Чорода	Россия, республика Дагестан, Тляратинский район, село Чодода	0101000020E6100000A9DBD9571E284740F437A11001194540
32823	8	75	1782	53525	\N	\N	42.054334503283499	Республика Дагестан, Тляратинский район, сельсовет Саниортинский, селение Цумилюх	Россия, республика Дагестан, Тляратинский район, село Цумилух	0101000020E610000089997D1EA33447409B030473F4064540
32818	8	75	1782	53811	\N	\N	42.012318750306399	Республика Дагестан, Тляратинский район, сельсовет Колобский, селение Цимгуда	Россия, республика Дагестан, Тляратинский район, село Цимгуда	0101000020E61000000AB952CF82484740490F43AB93014540
32856	8	75	1782	53946	\N	\N	42.2965274666958	Республика Дагестан, Тляратинский район, сельсовет Хиндахский, селение Хиндах	Россия, республика Дагестан, Тляратинский район, село Хиндах	0101000020E610000002B9C49107324740C4B0C398F4254540
32840	8	75	1782	53469	\N	\N	42.179904217908899	Республика Дагестан, Тляратинский район, сельсовет Хидибский, селение Хидиб		0101000020E6100000C07971E2AB2F4740B535221807174540
32846	8	75	1782	53947	\N	\N	42.222433000000002	Республика Дагестан, Тляратинский район, сельсовет Шидибский, селение Харада	Россия, республика Дагестан, Тляратинский район, село Харада	0101000020E6100000F775E09C112147408D463EAF781C4540
32835	8	75	1782	53499	\N	\N	42.093362611276298	Республика Дагестан, Тляратинский район, сельсовет Тляратинский, селение Хамар	Россия, республика Дагестан, Тляратинский район, село Хамар	0101000020E61000002A1A6B7F6731474006D49B51F30B4540
32830	8	75	1782	53516	\N	\N	42.101332670359902	Республика Дагестан, Тляратинский район, сельсовет Хадияльский, селение Хадиял	Россия, республика Дагестан, Тляратинский район, село Хадиял	0101000020E6100000BB99D18F863B4740B680D07AF80C4540
32873	8	75	1782	53847	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Тляратинский, населенный пункт ""Фрунзе"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32834	8	75	1782	53954	\N	\N	42.122839999999997	Республика Дагестан, Тляратинский район, сельсовет Тляратинский, селение Укал	Россия, республика Дагестан, Тляратинский район, село Укал	0101000020E6100000DAAA24B20F2C474000529B38B90F4540
32820	8	75	1782	53504	\N	\N	42.017350772720299	Республика Дагестан, Тляратинский район, сельсовет Тохотинский, селение Тохота	Россия, республика Дагестан, Тляратинский район, село Тохота	0101000020E61000006EA5D766633B4740C5C6BC8E38024540
32804	8	75	1782	53541	\N	\N	42.106126430095799	Республика Дагестан, Тляратинский район, сельсовет Тляратинский, селение Тлярата	Россия, республика Дагестан, Тляратинский район, село Тлярата	0101000020E610000068E89FE0622D4740AEA06989950D4540
32819	8	75	1782	53914	\N	\N	42.027566156045403	Республика Дагестан, Тляратинский район, сельсовет Колобский, селение Тлянада	Россия, республика Дагестан, Тляратинский район, село Тлянада	0101000020E6100000E7FD7F9C30414740A33D5E4887034540
32861	8	75	1782	53601	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Колобский, населенный пункт ""Тельмана-Теречный"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32826	8	75	1782	53444	\N	\N	42.046530053962798	Республика Дагестан, Тляратинский район, сельсовет Саниортинский, селение Талцух	Россия, республика Дагестан, Тляратинский район, село Талсух	0101000020E610000000000000003447403524EEB1F4054540
32832	8	75	1782	53841	\N	\N	42.0799160858245	Республика Дагестан, Тляратинский район, сельсовет Хадияльский, селение Сикар	Россия, республика Дагестан, Тляратинский район, село Сикар	0101000020E6100000ED48F59D5F344740AC36FFAF3A0A4540
32822	8	75	1782	53951	\N	\N	42.033096	Республика Дагестан, Тляратинский район, сельсовет Тохотинский, селение Саниорта	Россия, республика Дагестан, Тляратинский район, село Саниорта	0101000020E6100000BE4EEACBD238474070D05E7D3C044540
32815	8	75	1782	53445	\N	\N	41.974566061874597	Республика Дагестан, Тляратинский район, сельсовет Чородинский, селение Салда		0101000020E61000003FFED2A23E41474093E52494BEFC4440
32827	8	75	1782	53662	\N	\N	42.254129167027102	Республика Дагестан, Тляратинский район, сельсовет Саниортинский, селение Росноб	Россия, республика Дагестан, Тляратинский район, село Росноб	0101000020E6100000D82E6D382C2F47408BFB8F4C87204540
32871	8	75	1782	53822	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Гведышский, населенный пункт ""Орджоникидзе"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32853	8	75	1782	53678	\N	\N	42.195748348841903	Республика Дагестан, Тляратинский район, сельсовет Мазадинский, селение Нурух	Россия, республика Дагестан, Тляратинский район, село Нойрух	0101000020E61000002C45F29540304740F3203D450E194540
32824	8	75	1782	53919	\N	\N	42.0475761341268	Республика Дагестан, Тляратинский район, сельсовет Саниортинский, селение Нитиицух	Россия, республика Дагестан, Тляратинский район, село Нитилсух	0101000020E61000004C4F58E20137474089096AF816064540
32852	8	75	1782	53812	\N	\N	42.199422220283502	Республика Дагестан, Тляратинский район, сельсовет Мазадинский, селение Никлида	Россия, республика Дагестан, Тляратинский район, село Никлида	0101000020E6100000BDC799266C3347402C0DFCA886194540
32831	8	75	1782	53902	\N	\N	42.081449999999997	Республика Дагестан, Тляратинский район, сельсовет Хадияльский, селение Никар		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32848	8	75	1782	53460	\N	\N	42.196436439629203	Республика Дагестан, Тляратинский район, сельсовет Начадинский, селение Начада	Россия, республика Дагестан, Тляратинский район, село Начада	0101000020E610000097715303CD394740E7E099D024194540
32833	8	75	1782	53648	\N	\N	42.098200550131303	Республика Дагестан, Тляратинский район, сельсовет Тляратинский, селение Надар	Россия, республика Дагестан, Тляратинский район, село Надар	0101000020E6100000EBE1CB44112E47409EB7B1D9910C4540
32851	8	75	1782	53639	\N	\N	42.199053110162303	Республика Дагестан, Тляратинский район, сельсовет Мазадинский, селение Мазада	Россия, республика Дагестан, Тляратинский район, село Мазада	0101000020E6100000B9FB1C1F2D324740D99596917A194540
32865	8	75	1782	53762	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Герельский, населенный пункт ""Ленина"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32845	8	75	1782	53969	\N	\N	42.218426437888297	Республика Дагестан, Тляратинский район, сельсовет Шидибский, селение Ланда		0101000020E61000000DDE57E5422347404D4C1762F51B4540
32837	8	75	1782	27260	\N	\N	42.096626000000001	Республика Дагестан, Тляратинский район, село Кутлаб	Россия, республика Дагестан, Тляратинский район, село Кутлаб	0101000020E6100000399B8E006E2A4740BEF8A23D5E0C4540
32869	8	75	1782	53447	\N	\N	42.242963272978898	"Республика Дагестан, Тляратинский район, сельсовет Кособский, населенный пункт ""Кособ-кутан"""	Россия, республика Дагестан, Тляратинский район, село Кособ	0101000020E61000000DC347C4942E4740AC915D69191F4540
32854	8	75	1782	53447	\N	\N	42.242244303024499	Республика Дагестан, Тляратинский район, сельсовет Кособский, селение Кособ	Россия, республика Дагестан, Тляратинский район, село Кособ	0101000020E6100000C40B2252D32E47407CD3F4D9011F4540
32867	8	75	1782	53663	\N	\N	42.081194892348499	"Республика Дагестан, Тляратинский район, сельсовет Мазадинский, населенный пункт ""Качалай"""	Россия, республика Дагестан, Тляратинский район	0101000020E61000009D11A5BDC1394740A3CC0699640A4540
32828	8	75	1782	53903	\N	\N	42.111597000000003	Республика Дагестан, Тляратинский район, сельсовет Кардибский, селение Кардиб	Россия, республика Дагестан, Тляратинский район, село Кардиб	0101000020E610000046EC13403142474076AA7CCF480E4540
32868	8	75	1782	53815	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Хиндахский, населенный пункт ""Каратюбе"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32864	8	75	1782	53899	\N	\N	41.906654210963602	"Республика Дагестан, Тляратинский район, сельсовет Камилухский, населенный пункт ""Караузек"""	Россия, республика Дагестан, Тляратинский район, село Камилух	0101000020E61000008C497F2F85514740D064FF3C0DF44440
32809	8	75	1782	53899	\N	\N	41.909050000000001	Республика Дагестан, Тляратинский район, сельсовет Камилухский, селение Камилюх	Россия, республика Дагестан, Тляратинский район, село Камилух	0101000020E610000070EA03C93B514740E3361AC05BF44440
32860	8	75	1782	53851	\N	\N	42.017734798241499	"Республика Дагестан, Тляратинский район, сельсовет Колобский, населенный пункт ""Теречный"""		0101000020E61000004A7F2F85074347404E7FF62345024540
32817	8	75	1782	53851	\N	\N	42.017774300734203	Республика Дагестан, Тляратинский район, сельсовет Колобский, селение Колоб	Россия, республика Дагестан, Тляратинский район, село Калоб	0101000020E6100000A4A65D4C334347400C5C1E6B46024540
32870	8	75	1782	53910	\N	\N	42.081449999999997	"Республика Дагестан, Тляратинский район, сельсовет Саниортинский, населенный пункт ""Жданова"""		0101000020E6100000D6FECEF6E83947402D211FF46C0A4540
32850	8	75	1782	53844	\N	\N	42.1992225068986	Республика Дагестан, Тляратинский район, сельсовет Начадинский, селение Жажада	Россия, республика Дагестан, Тляратинский район, село Жажада	0101000020E6100000E95F92CA1437474036CEA62380194540
32813	8	75	1782	53424	\N	\N	41.962987609587003	Республика Дагестан, Тляратинский район, сельсовет Герельский, селение Гортноб	Россия, республика Дагестан, Тляратинский район, село Гортноб	0101000020E6100000990F0874264347406138D73043FB4440
32829	8	75	1782	53489	\N	\N	42.112900987816801	Республика Дагестан, Тляратинский район, сельсовет Кардибский, селение Гиндиб	Россия, республика Дагестан, Тляратинский район, село Гиндиб	0101000020E6100000F5BD86E0B8404740C5573B8A730E4540
32811	8	75	1782	53897	\N	\N	41.941652185873203	Республика Дагестан, Тляратинский район, сельсовет Герельский, селение Герель	Россия, республика Дагестан, Тляратинский район, село Герель	0101000020E6100000EEB4352218474740431B800D88F84440
32810	8	75	1782	53631	\N	\N	41.916912031103003	Республика Дагестан, Тляратинский район, сельсовет Камилухский, селение Генеколоб		0101000020E6100000168A743FA74C4740ADA7565F5DF54440
32839	8	75	1782	53615	\N	\N	42.1349445817891	Республика Дагестан, Тляратинский район, сельсовет Гведышский, селение Гиндух		0101000020E6100000B6F3FDD4783347401EE1B4E045114540
32838	8	75	1782	53472	\N	\N	42.134881320548999	Республика Дагестан, Тляратинский район, сельсовет Гведышский, селение Гведыш	Россия, республика Дагестан, Тляратинский район, село Гведыш	0101000020E610000083F92B64AE34474007EDD5C743114540
32825	8	75	1782	53433	\N	\N	42.0503684284432	Республика Дагестан, Тляратинский район, сельсовет Саниортинский, селение Гараколоб	Россия, республика Дагестан, Тляратинский район, село Гараколоб	0101000020E6100000596E6935243A4740E961687572064540
32816	8	75	1782	53813	\N	\N	41.999707999999998	Республика Дагестан, Тляратинский район, сельсовет Колобский, селение Гагар	Россия, республика Дагестан, Тляратинский район, село Гагар	0101000020E6100000350D8AE6014C474058C6866EF6FF4440
32812	8	75	1782	53578	\N	\N	41.950206440451701	Республика Дагестан, Тляратинский район, сельсовет Герельский, селение Бетельда	Россия, республика Дагестан, Тляратинский район, село Бетельда	0101000020E6100000A4E029E44A454740433BA759A0F94440
32836	8	75	1782	53816	\N	\N	42.079659197437003	Республика Дагестан, Тляратинский район, сельсовет Тляратинский, селение Барнаб	Россия, республика Дагестан, Тляратинский район, село Барнаб	0101000020E6100000317C444C8930474081EA1F44320A4540
32843	8	75	1782	53651	\N	\N	42.189670883114303	Республика Дагестан, Тляратинский район, сельсовет Чадаколобский, селение Анцух	Россия, республика Дагестан, Тляратинский район, село Анцух	0101000020E6100000386BF0BE2A2B4740F3FFAA2347184540
33147	8	75	535	53924	\N	\N	44.2621214153247	Республика Дагестан, Цунтинский район, с.40-лет Октярбя	Россия, республика Дагестан, Тарумовский район	0101000020E6100000263ACB2C42454740234C512E8D214640
32808	8	75	535	53642	\N	\N	44.173784260238897	Республика Дагестан, Тарумовский район, сельсовет Юрковский, здание администрации, Здание администрации	Россия, республика Дагестан, Тарумовский район, село Юрковка	0101000020E610000060C9552C7E574740B648DA8D3E164640
32807	8	75	535	25861	\N	\N	44.075029999999998	Республика Дагестан, Тарумовский район, село Тарумовка, здание Новой школы, Новая Школа		0101000020E61000001329CDE671444740041C42959A094640
32806	8	75	535	25861	\N	\N	44.075029999999998	Республика Дагестан, Тарумовский район, село Тарумовка, здание Дом культуры, Дом культуры		0101000020E61000001329CDE671444740041C42959A094640
32805	8	75	535	53723	\N	\N	44.238734168201901	Республика Дагестан, Тарумовский район, сельсовет Таловский, здание Дом культуры, Дом культуры	Россия, республика Дагестан, Тарумовский район, село Таловка	0101000020E61000002C465D6BEF4B4740BD38F1D58E1E4640
32803	8	75	535	25739	32965	\N	43.978377999999999	Республика Дагестан, Тарумовский район, с-с Уллубиевский, с Рассвет, здание администрации, здание администрации		0101000020E61000004F029B73F05A47401D90847D3BFD4540
32802	8	75	535	25653	\N	\N	44.196702000000002	Республика Дагестан, Тарумовский район, село Раздолье, здание Дома культуры, Дом культуры		0101000020E61000009143C4CDA94A47406687F8872D194640
32801	8	75	535	53898	\N	\N	44.100242999999999	Республика Дагестан, Тарумовский район, с-с Юрковский, п.Привольненски, здание школы, Школа	Россия, республика Дагестан, Тарумовский район, село Привольный	0101000020E6100000C5A9D6C22C54474093533BC3D40C4640
32800	8	75	535	32845	\N	\N	43.957759000000003	Республика Дагестан, Тарумовский район, селение Новоромановка, здание Дома культуры, Дом культуры		0101000020E6100000E1EB6B5D6A5247408F39CFD897FA4540
32799	8	75	535	53434	\N	\N	43.994860848829603	Республика Дагестан, Тарумовский р-н, с-с Уллубиевский,с.Н-Николаевка, здание Школы, Школа	Россия, республика Дагестан, Тарумовский район, село Новониколаевка	0101000020E6100000930035B56C5947406E88F19A57FF4540
32798	8	75	535	25484	\N	\N	44.088318000000001	Республика Дагестан, Тарумовский район, село Новодмитриевка, здание школы, Школа	Россия, республика Дагестан, Тарумовский район, село Новодмитриевка	0101000020E6100000598B4F01303E4740F6D214014E0B4640
32797	8	75	535	53699	\N	\N	43.931025026263001	Республика Дагестан, Тарумовский район, сельсовет Новогеоргиевский, здание Дом культуры, Дом культуры	Россия, республика Дагестан, Тарумовский район, село Новогеоргиевка	0101000020E6100000CF108E59F65047401361C3D32BF74540
33003	8	75	535	3260	\N	\N	44.673057999999997	"Кутан Сюгют Ашага-Яракский, Общежитие СПК ""Юзбековский"""		0101000020E6100000514A0856D54D4740D427B9C326564640
33002	8	75	535	3260	\N	\N	44.673057999999997	Кутан Сюгют Кондикский, Средняя общеобразовательня школа	Россия, республика Дагестан, Тарумовский район, село Кутан	0101000020E6100000514A0856D54D4740D427B9C326564640
32796	8	75	535	25270	\N	\N	44.390032212280197	село Кочубей, Тарумовский район, Республика Дагестан, станция Кочубей, Школа	Россия, республика Дагестан, Тарумовский район, село Кочубей	0101000020E6100000A3AD4A22FB4647405D328E91EC314640
32795	8	75	535	25270	\N	\N	44.387326999999999	Республика Дагестан, Тарумовский район, село Кочубей, здание школы, Школа №1		0101000020E61000004FADBEBA2A484740CCED5EEE93314640
32794	8	75	535	25270	\N	\N	44.387326999999999	Республика Дагестан, Тарумовский район, село Кочубей, Здание отгонного животноводства, Здание отгонного животноводства		0101000020E61000004FADBEBA2A484740CCED5EEE93314640
31547	8	75	535	25270	\N	\N	44.387326999999999	Республика Дагестан, Тарумовский район, село Кочубей	Россия, республика Дагестан, Тарумовский район, село Кочубей	0101000020E61000004FADBEBA2A484740CCED5EEE93314640
33244	8	75	535	25270	75520	\N	44.392001625616103	Кочубейская зона		0101000020E6100000C7F143A511474740B9FB1C1F2D324640
32793	8	75	535	25219	\N	\N	44.266162000000001	Республика Дагестан, Тарумовский район, село Коктюбей, здание Дом культуры, Дом культуры		0101000020E610000098A25C1ABF5E47400FB8AE9811224640
32792	8	75	535	25182	\N	\N	44.0082386763006	с. Карабаглы, здание Дом культуры, Дом культуры	Россия, республика Дагестан, Тарумовский район, село Карабаглы	0101000020E6100000EF1B5F7B664B4740A0C6BDF90D014640
32791	8	75	535	53634	\N	\N	43.9651128447668	Республика Дагестан, Тарумовский район, сельсовет Калиновский, здание Дом культуры, Дом культуры	Россия, республика Дагестан, Тарумовский район, село Калиновка	0101000020E6100000E86B96CB46494740E4F8A1D288FB4540
32789	8	75	535	27682	\N	\N	44.036750031578897	Республика Дагестан, Тарумовский район, с-с Уллубиевский Вышеталовка, здание Школы, Школа	Россия, республика Дагестан, Тарумовский район, село Вышеталовка	0101000020E6100000D3307C444C5D474062105839B4044640
32788	8	75	535	24996	\N	\N	43.920946999999998	Александро-Невское, здание Дом культуры, Дом культуры		0101000020E6100000959C137B68474740B62C5F97E1F54540
32754	8	75	1447	53839	\N	\N	41.949672459129701	Республика Дагестан, Табасаранский район, сельсовет Аракский,с Ново-Лидже, здание Школы	Россия, республика Дагестан, Табасаранский район	0101000020E610000081E84999D4024840A5F622DA8EF94440
32741	8	75	1447	53773	\N	\N	41.950701000000002	Республика Дагестан, Табасаранский район, сельсовет Куркакский,с Джугдиль, здание Школы		0101000020E61000008B36C7B94D02484023A30392B0F94440
32732	8	75	1447	53468	\N	\N	41.950701000000002	Республика Дагестан, Табасаранский район, сельсовет Марагинский,с Гелинбатан		0101000020E61000008B36C7B94D02484023A30392B0F94440
32787	8	75	1447	24980	\N	\N	41.979019999999998	Республика Дагестан, Табасаранский район, сельсовет Хучнинский, с Ягдыг	Россия, республика Дагестан, Табасаранский район, село Ягдыг	0101000020E610000053758F6CAEFA4740A110018750FD4440
32786	8	75	1447	24919	\N	\N	41.953859000000001	Республика Дагестан, Табасаранский район, сельсовет Кужникский, с Чурдаф	Россия, республика Дагестан, Табасаранский район, село Чурдаф	0101000020E6100000CAC2D7D7BAEE474065FF3C0D18FA4440
32785	8	75	1447	24892	\N	\N	41.880916579463701	Республика Дагестан, Табасаранский район, село Чулат	Россия, республика Дагестан, Табасаранский район, село Чулат	0101000020E6100000F8FE06EDD5134840C6BE64E3C1F04440
32784	8	75	1447	24842	\N	\N	41.940306	Республика Дагестан, Табасаранский район, сельсовет Аракский, с Цухтыг		0101000020E61000000490DAC4C9FD4740C51D6FF25BF84440
32783	8	75	1447	24794	\N	\N	41.916324000000003	Республика Дагестан, Табасаранский район, сельсовет Хучнинский, с Цуртиль	Россия, республика Дагестан, Табасаранский район, село Цуртиль	0101000020E61000007B6AF5D555F747401C45D61A4AF54440
32755	8	75	1447	53474	\N	\N	41.950701000000002	Республика Дагестан, Табасаранский район, сельсовет Хурикский,с Цантиль, здание Школы		0101000020E61000008B36C7B94D02484023A30392B0F94440
32782	8	75	1447	53862	\N	\N	41.935967232229601	Республика Дагестан, Табасаранский район, сельсовет Хурикский, с Цантиль	Россия, республика Дагестан, Табасаранский район	0101000020E6100000C7D63384630448404F9143C4CDF74440
32781	8	75	1447	24702	\N	\N	41.942821000000002	Республика Дагестан, Табасаранский район, сельсовет Аркитский, с Цанак	Россия, республика Дагестан, Табасаранский район, село Цанак	0101000020E610000051D845D103054840B37DC85BAEF84440
32780	8	75	1447	24702	\N	\N	41.942821000000002	Республика Дагестан, Табасаранский район, сельсовет Хучнинский, с Цалак	Россия, республика Дагестан, Табасаранский район, село Цанак	0101000020E610000051D845D103054840B37DC85BAEF84440
32779	8	75	1447	24602	\N	\N	41.948307	Республика Дагестан, Табасаранский район, сельсовет Хучнинский, с Хучни	Россия, республика Дагестан, Табасаранский район, село Хучни	0101000020E610000075E8F4BC1BF94740B0C8AF1F62F94440
32778	8	75	1447	24539	\N	\N	42.003568000000001	Республика Дагестан, Табасаранский район, сельсовет Дюбекский, с Xустиль		0101000020E610000071E82D1EDEF74740F4A78DEA74004540
32777	8	75	1447	24513	\N	\N	41.882257000000003	Республика Дагестан, Табасаранский район, сельсовет Бурганкентский, с Хуряк	Россия, республика Дагестан, Табасаранский район, село Хуряк	0101000020E6100000F209D9791B09484063D520CCEDF04440
32776	8	75	1447	24430	\N	\N	41.986178000000002	Республика Дагестан, Табасаранский район, сельсовет Хурикский, с Хурик	Россия, республика Дагестан, Табасаранский район, село Хурик	0101000020E61000000CCEE0EF17F347407104A9143BFE4440
32748	8	75	1447	53613	\N	\N	41.955438768461498	Республика Дагестан, Табасаранский район, сельсовет Кужникский,с Кужник, здание СДК	Россия, республика Дагестан, Табасаранский район, село Хужник	0101000020E6100000840F255AF2E8474056293DD34BFA4440
32775	8	75	1447	53535	\N	\N	41.965999837566997	Республика Дагестан, Табасаранский район, сельсовет Хели-Пенджинский, см Хели-Пенджик	Россия, республика Дагестан, Табасаранский район, село Хели-Пенжик	0101000020E6100000FD9FC37C79074840CFF753E3A5FB4440
32774	8	75	1447	24342	\N	\N	41.989006000000003	Республика Дагестан, Табасаранский район, сельсовет Хапильский, с Хапиль	Россия, республика Дагестан, Табасаранский район, село Хапиль	0101000020E6100000CA703C9F01FD47401EC6A4BF97FE4440
32773	8	75	1447	24254	\N	\N	41.912325000000003	Республика Дагестан, Табасаранский район, сельсовет Гуминский, с Ханак	Россия, республика Дагестан, Табасаранский район, село Ханак	0101000020E61000003046240A2DEF47405F29CB10C7F44440
32772	8	75	1447	24254	\N	\N	41.912325000000003	Республика Дагестан, Табасаранский район, сельсовет Хурикский, с Ханаг	Россия, республика Дагестан, Табасаранский район, село Ханак	0101000020E61000003046240A2DEF47405F29CB10C7F44440
32771	8	75	1447	24197	\N	\N	41.906335881434003	Республика Дагестан, Табасаранский район, сельсовет Халагский, с Халаг	Россия, республика Дагестан, Табасаранский район, село Халаг	0101000020E6100000310A82C7B7F14740FF976BD102F44440
32770	8	75	1447	53952	\N	\N	41.950701000000002	Республика Дагестан, Табасаранский район, сельсовет Тинитский, с Фиргиль		0101000020E61000008B36C7B94D02484023A30392B0F94440
32769	8	75	1447	24105	\N	\N	41.926273000000002	Республика Дагестан, Табасаранский район, сельсовет Аракский,с Ушниг	Россия, республика Дагестан, Табасаранский район, село Ушниг	0101000020E6100000454948A46D0048407B15191D90F64440
32768	8	75	1447	53949	\N	\N	41.947636000000003	Республика Дагестан, Табасаранский район, сельсовет Кужникский,с Ургиз	Россия, республика Дагестан, Табасаранский район, село Урзиг	0101000020E61000001590F63FC0EC47409241EE224CF94440
32767	8	75	1447	53488	\N	\N	41.956783000000001	Республика Дагестан, Табасаранский район, сельсовет КужникскийСс Улуз	Россия, республика Дагестан, Табасаранский район, село Улуз	0101000020E6100000A471A8DF85EB4740342F87DD77FA4440
32766	8	75	1447	23950	\N	\N	41.905413000000003	Республика Дагестан, Табасаранский район, сельсовет Тинитский,с Туруф	Россия, республика Дагестан, Табасаранский район, село Туруф	0101000020E610000035B39602D2004840C72FBC92E4F34440
32765	8	75	1447	23888	\N	\N	41.860570000000003	Республика Дагестан, Табасаранский район, сельсовет Турагский,с Тураг	Россия, республика Дагестан, Табасаранский район, село Тураг	0101000020E61000001F85EB51B8FC474099F5622827EE4440
32764	8	75	1447	23847	\N	\N	41.910808000000003	Республика Дагестан, Табасаранский район, сельсовет Тинитский,с Тинит	Россия, республика Дагестан, Табасаранский район, село Тинит	0101000020E61000002A745E6397064840B477465B95F44440
32763	8	75	1447	23790	\N	\N	41.992913000000001	Республика Дагестан, Табасаранский район, сельсовет Хапильский,с Татиль	Россия, республика Дагестан, Табасаранский район, село Татиль	0101000020E61000009D2B4A09C1FE4740FA62EFC517FF4440
32761	8	75	1447	23659	\N	\N	41.832647999999999	Республика Дагестан, Табасаранский район, село Сиртич, Ниже административного здания с/а, здание Школы		0101000020E610000034BF9A03041D4840378AAC3594EA4440
32760	8	75	1447	23659	\N	\N	41.832837900851501	Республика Дагестан, Табасаранский район, село Сиртич, Выше административного здания с/а, здание СДК	Россия, республика Дагестан, Табасаранский район, село Сиртич	0101000020E6100000CF691668771C4840DB6E826F9AEA4440
31554	8	75	1447	23659	\N	\N	41.832647999999999	Республика Дагестан, Табасаранский район, село Сиртич	Россия, республика Дагестан, Табасаранский район, село Сиртич	0101000020E610000034BF9A03041D4840378AAC3594EA4440
32759	8	75	1447	23636	\N	\N	41.903944000000003	Республика Дагестан, Табасаранский район, сельсовет Гуминский, с Сикух, здание ДК		0101000020E61000000327DBC01DEC47402DB5DE6FB4F34440
32757	8	75	1447	23522	\N	\N	41.956991000000002	Республика Дагестан, Табасаранский район, сельсовет Аркитский,с Рушуль, здание Школа		0101000020E61000004D13B69F8C0148407EC85BAE7EFA4440
32756	8	75	1447	23491	\N	\N	41.973061000000001	Республика Дагестан, Табасаранский район, сельсовет Хурикский,с Пилиг, здание Школы		0101000020E6100000BD361B2B31EF4740AC014A438DFC4440
32753	8	75	1447	53550	\N	\N	41.842708411259999	Республика Дагестан, Табасаранский район, сельсовет Турагский,с Ничрас, здание Школы	Россия, республика Дагестан, Табасаранский район, село Ниграс	0101000020E6100000EA9106B7B5014840EE0912DBDDEB4440
32752	8	75	1447	23277	\N	\N	41.963507999999997	Республика Дагестан, Табасаранский район, сельсовет Марагинский,с Марага	Россия, республика Дагестан, Табасаранский район, село Марага	0101000020E610000051853FC39B0F484099B7EA3A54FB4440
32613	8	75	1447	23277	\N	\N	41.963379597698101	Республика Дагестан, Табасаранский район, сельсовет Марагинский,с Гумрал	Россия, республика Дагестан, Табасаранский район, село Марага	0101000020E61000006F0D6C95600F48406CCF2C0950FB4440
32751	8	75	1447	23263	\N	\N	41.973140999999998	Республика Дагестан, Табасаранский район, сельсовет Аракский,с Лидже, здание СДК		0101000020E61000000667F0F78BFD4740C8B260E28FFC4440
32750	8	75	1447	23202	\N	\N	41.906157931775198	Республика Дагестан, Табасаранский район, сельсовет Гуминский,с Кюряг, здание СДК	Россия, республика Дагестан, Табасаранский район, село Кюряг	0101000020E6100000B16A10E676ED47401F813FFCFCF34440
32749	8	75	1447	53888	\N	\N	41.910704069532301	Республика Дагестан, Табасаранский район, сельсовет Куркакский,с Куркаг, здание ДК	Россия, республика Дагестан, Табасаранский район, село Куркак	0101000020E61000005CE333D93FFD47400F2BDCF291F44440
32746	8	75	1447	53493	\N	\N	41.931796940310697	Республика Дагестан, Табасаранский район, сельсовет Кужникский,с Караг, здание Школы	Россия, республика Дагестан, Табасаранский район	0101000020E6100000D2E0B6B6F004484066C1C41F45F74440
32745	8	75	1447	22979	\N	\N	41.995775000000002	Республика Дагестан, Табасаранский район, сельсовет Ерсинский,с Зиль, здание Школы		0101000020E610000015E29178790448405396218E75FF4440
32744	8	75	1447	22920	\N	\N	42.021802999999998	Республика Дагестан, Табасаранский район, сельсовет Ерсинский,с Ерси, здание Школы		0101000020E6100000D1B2EE1F0B01484033FAD170CA024540
32743	8	75	1447	22871	\N	\N	42.024199877149996	Республика Дагестан, Табасаранский район, сельсовет Дюбекский,с Дюбек, здание администрации	Россия, республика Дагестан, Табасаранский район, село Дюбек	0101000020E61000006878B306EFFB4740174850FC18034540
32740	8	75	1447	22740	\N	\N	41.956252999999997	Республика Дагестан, Табасаранский район, сельсовет Джульджагский,с Джульджаг, здание Библиотеки		0101000020E6100000B954A52DAEF14740D7D9907F66FA4440
32657	8	75	1539	18543	\N	\N	42.417943000000001	Республика Дагестан, Сергокалинский район, сельсовет Дегвинский, село Дегва, СДК		0101000020E610000082A966D652C44740CB4BFE277F354540
32742	8	75	1447	22843	\N	\N	41.881512000000001	Республика Дагестан, Табасаранский район, сельсовет Халагский,с Джули	Россия, республика Дагестан, Табасаранский район, село Джули	0101000020E6100000CB86359545ED47400A849D62D5F04440
32739	8	75	1447	22678	\N	\N	42.016196999999998	Республика Дагестан, Табасаранский район, село Дарваг, Ниже административного здания с/а, здание СДК		0101000020E61000006EC493DDCC0848408BA548BE12024540
32738	8	75	1447	22678	\N	\N	42.016196999999998	Республика Дагестан, Табасаранский район, село Дарваг, Выше административного здания с/а		0101000020E61000006EC493DDCC0848408BA548BE12024540
32737	8	75	1447	22617	\N	\N	41.931606000000002	Республика Дагестан, Табасаранский район, сельсовет Гурикский,с Дагни	Россия, республика Дагестан, Табасаранский район, село Дагни	0101000020E61000006E50FBAD9DF44740F2608BDD3EF74440
32736	8	75	1447	22591	\N	\N	41.936126999999999	Республика Дагестан, Табасаранский район, село Гюхряг	Россия, республика Дагестан, Табасаранский район, село Гюхряг	0101000020E610000067B96C74CEF3474088F37002D3F74440
32735	8	75	1447	53560	\N	\N	42.019601514020501	Республика Дагестан, Табасаранский район, сельсовет Дюбекский,с Гурхун	Россия, республика Дагестан, Табасаранский район, село Гурхунь	0101000020E6100000B398D87C5CF54740D5777E5182024540
32707	8	75	1447	21236	\N	\N	41.961188	Республика Дагестан, Табасаранский район, сельсовет Гурикский,с Гурик		0101000020E61000008CA19C6857F5474061A7583508FB4440
32758	8	75	1447	22463	\N	\N	41.893984000000003	Республика Дагестан, Табасаранский район, сельсовет Гуминский,с Гуми, здание Клуба		0101000020E61000001478279F1EEF4740DA9255116EF24440
32747	8	75	1447	22463	\N	\N	41.893984000000003	Республика Дагестан, Табасаранский район, сельсовет Гуминский,с Гуми, здание ДК		0101000020E61000001478279F1EEF4740DA9255116EF24440
32734	8	75	1447	22463	\N	\N	41.893984000000003	Республика Дагестан, Табасаранский район, сельсовет Гуминский,с Гуми	Россия, республика Дагестан, Табасаранский район, село Гуми	0101000020E61000001478279F1EEF4740DA9255116EF24440
32733	8	75	1447	22449	\N	\N	41.943471000000002	Республика Дагестан, Табасаранский район, сельсовет Гурикский,с Гисик	Россия, республика Дагестан, Табасаранский район, село Гисик	0101000020E61000006EA6423C12F54740BADC60A8C3F84440
32731	8	75	1447	53478	\N	\N	41.922948367597698	Республика Дагестан, Табасаранский район, сельсовет Джульджагский,с Гасик		0101000020E6100000676325E659F147404DF4F92823F64440
32730	8	75	1447	22337	\N	\N	41.917544999999997	Республика Дагестан, Табасаранский район, сельсовет Куркакский,с Вечрик	Россия, республика Дагестан, Табасаранский район, село Вечрик	0101000020E61000006AA2CF4719FB4740DDCD531D72F54440
32729	8	75	1447	22257	\N	\N	41.899419999999999	Республика Дагестан, Табасаранский район, сельсовет Бурганкентский,с Бурганкент, здание ДК		0101000020E61000003BA6EECA2E08484025AFCE3120F34440
32728	8	75	1447	22231	\N	\N	41.901736	Республика Дагестан, Табасаранский район, сельсовет Гуминский,с Афна, здание ДК		0101000020E610000004E621533EEE47401CD0D2156CF34440
32727	8	75	1447	22179	\N	\N	41.946724000000003	Республика Дагестан, Табасаранский район, сельсовет Аркитский,с Аркит, здание СДК	Россия, республика Дагестан, Табасаранский район, село Аркит	0101000020E6100000C26C020CCB0148404E2B85402EF94440
32726	8	75	1447	22130	\N	\N	41.960878999999998	Республика Дагестан, Табасаранский район, сельсовет Аракский, с Арак, здание СДК		0101000020E6100000016C4084B8FE4740E3344415FEFA4440
32725	8	75	1447	22111	\N	\N	41.925427999999997	Республика Дагестан, Табасаранский район, сельсовет Хучнинский,с Акка, Здание  СДК		0101000020E6100000D33252EFA9F64740BE66B96C74F64440
32691	8	75	782	20364	\N	\N	41.707779000000002	Республика Дагестан, Сулейман-Стальский район, село Юхари-Стал, здание сельского клуба		0101000020E6100000C899266C3F134840D6E5948098DA4440
32715	8	75	782	21602	\N	\N	41.623781999999999	Республика Дагестан, Сулейман-Стальский район, село Юхари-Картас, здание сельского клуба		0101000020E610000098BF42E6CA0C4840AFEAAC16D8CF4440
32694	8	75	782	53724	\N	\N	41.765090388998999	Республика Дагестан, Сулейман-Стальский район, село Эминхюр, здание сельской администрации	Россия, республика Дагестан, Сулейман-Стальский район, село Аламише	0101000020E610000093C5FD47A6294840923F1878EEE14440
32704	8	75	782	21070	\N	\N	41.755763999999999	Республика Дагестан, Сулейман-Стальский район, село Экендиль, здание сельского клуба		0101000020E610000019E59997C310484040BFEFDFBCE04440
32717	8	75	782	21707	\N	\N	41.605021000000001	Республика Дагестан, Сулейман-Стальский район, село Шихикент, здание сельского клуба		0101000020E6100000E5D022DBF91448405532005471CD4440
32696	8	75	782	53702	\N	\N	41.649348005494502	Республика Дагестан, Сулейман-Стальский район, село Чухверкент, здание сельского клуба		0101000020E6100000CA6ABA9EE80248408CDCD3D51DD34440
32708	8	75	782	21281	\N	\N	41.684503999999997	Республика Дагестан, Сулейман-Стальский район, село Цмур, здание сельского клуба	Россия, республика Дагестан, Сулейман-Стальский район, село Цмур	0101000020E6100000F437A1100107484097FDBAD39DD74440
32721	8	75	782	21873	\N	\N	41.582565000000002	Республика Дагестан, Сулейман-Стальский район, село Хтун, здание сельского клуба		0101000020E6100000B421FFCC20164840AA656B7D91CA4440
32711	8	75	782	21397	\N	\N	41.606807000000003	Республика Дагестан, Сулейман-Стальский район, село Уллугатаг, здание школы		0101000020E6100000DEE8633E20104840F0FD0DDAABCD4440
32714	8	75	782	53435	\N	\N	41.585039654328099	Республика Дагестан, Сулейман-Стальский район, село Татархан, здание школы	Россия, республика Дагестан, Сулейман-Стальский район, село Татарханкент	0101000020E610000072158BDF140C4840096D3997E2CA4440
32686	8	75	782	20091	\N	\N	41.703342999999997	Республика Дагестан, Сулейман-Стальский район, село Сийидкент, здание школы	Россия, республика Дагестан, Сулейман-Стальский район, село Сийидкент	0101000020E610000076FC1708020E48406D6FB72407DA4440
32706	8	75	782	21171	\N	\N	41.724142000000001	Республика Дагестан, Сулейман-Стальский район, село Сардаркент, здание сельского клуба		0101000020E6100000BA313D61890748407CD45FAFB0DC4440
32712	8	75	782	21443	\N	\N	41.587569000000002	Республика Дагестан, Сулейман-Стальский район, село Сайтаркент, здание сельского клуба		0101000020E6100000EBAD81AD121048405C92037635CB4440
32713	8	75	782	21518	\N	\N	41.584426000000001	Республика Дагестан, Сулейман-Стальский район, село Птикент, здание сельского клуба		0101000020E610000007B13385CE0D48404F779E78CECA4440
32720	8	75	782	21850	\N	\N	41.592444999999998	Республика Дагестан, Сулейман-Стальский район, село Пиперкент, здание сельского клуба	Россия, республика Дагестан, Сулейман-Стальский район, село Пиперкент	0101000020E610000061A92EE065124840E0D6DD3CD5CB4440
32690	8	75	782	20332	\N	\N	41.704816999999998	Республика Дагестан, Сулейман-Стальский район, село Орта-Стал, здание сельской администрации	Россия, республика Дагестан, Сулейман-Стальский район, село Орта Стал	0101000020E61000003E3F8C101E1548401955867137DA4440
32702	8	75	782	20982	\N	\N	41.755420999999998	Республика Дагестан, Сулейман-Стальский район, село Нютюг, здание сельского клуба		0101000020E61000001D3A3DEFC60E484016DBA4A2B1E04440
32723	8	75	782	22001	\N	\N	41.636068000000002	Республика Дагестан, Сулейман-Стальский район, село Новый Испик, здание сельской администрации		0101000020E61000003BC3D4963A1848401D041DAD6AD14440
32695	8	75	782	53722	\N	\N	41.685811000000001	Республика Дагестан, Сулейман-Стальский район, село Новомака, здание сельского клуба		0101000020E61000001689096AF80E4840581EA4A7C8D74440
32699	8	75	782	20791	\N	\N	41.712491	Республика Дагестан, Сулейман-Стальский район, село Куркент, здание школы №2		0101000020E61000009A0B5C1E6B0E4840E0D8B3E732DB4440
32698	8	75	782	20791	\N	\N	41.712491	Республика Дагестан, Сулейман-Стальский район, село Куркент, здание школы №1		0101000020E61000009A0B5C1E6B0E4840E0D8B3E732DB4440
32709	8	75	782	21312	\N	\N	41.669384999999998	Республика Дагестан, Сулейман-Стальский район, село Качалкент, здание школы	Россия, республика Дагестан, Сулейман-Стальский район, село Качалкент	0101000020E6100000CD72D9E89C0548406BB75D68AED54440
32687	8	75	782	20160	\N	\N	41.600490000000001	Республика Дагестан, Сулейман-Стальский район, село Кахцуг, здание школы		0101000020E61000006DAB59677C0748409BC937DBDCCC4440
32683	8	75	782	19801	33153	\N	41.678989000000001	Республика Дагестан, Сулейман-Стальский район, село Касумкент, ул.Школьная, Здание школы		0101000020E61000006953758F6C14484000AC8E1CE9D64440
32681	8	75	782	19801	33078	\N	41.678989000000001	Республика Дагестан, Сулейман-Стальский район, село Касумкент, ул.Мира, здание ветлечебницы		0101000020E61000006953758F6C14484000AC8E1CE9D64440
32684	8	75	782	19801	32925	\N	41.678989000000001	Республика Дагестан, Сулейман-Стальский район, село Касумкент, ул.Ленина, здание дворца культцры		0101000020E61000006953758F6C14484000AC8E1CE9D64440
32685	8	75	782	19801	33111	\N	41.678989000000001	Республика Дагестан, Сулейман-Стальский район, село Касумкент, ул.Аминова, здание школы		0101000020E61000006953758F6C14484000AC8E1CE9D64440
32701	8	75	782	20922	\N	\N	41.776088000000001	Республика Дагестан, Сулейман-Стальский район, село Карчаг, здание сельского клуба		0101000020E61000004C8BFA2477144840B66801DA56E34440
32387	8	75	782	5515	\N	\N	41.811394999999997	Республика Дагестан, Магарамкентский район, село Картас-Казмаляр, Здание дома культуры, -	Россия, республика Дагестан, Сулейман-Стальский район, село Картас-Казмаляр	0101000020E6100000BFB5132521334840A79196CADBE74440
32710	8	75	782	21373	\N	\N	41.682867999999999	Республика Дагестан, Сулейман-Стальский район, село Ичин, здание школы		0101000020E6100000DCD5ABC8E8FE474012BEF73768D74440
32722	8	75	782	21933	\N	\N	41.613427999999999	Республика Дагестан, Сулейман-Стальский район, село Испик, здание школы		0101000020E61000002BFA43334F184840B03907CF84CE4440
32719	8	75	782	21787	\N	\N	41.566119	Республика Дагестан, Сулейман-Стальский район, село Зухрабкент, здание сельского клуба		0101000020E6100000676325E65913484076525F9676C84440
32703	8	75	782	21053	\N	\N	41.768025000000002	Республика Дагестан, Сулейман-Стальский район, село Зизик, здание сельского клуба		0101000020E6100000F7E7A221E30D484055C1A8A44EE24440
32697	8	75	782	53696	\N	\N	41.803828519662197	Республика Дагестан, Сулейман-Стальский район, село Даркуш-Казмаляр, здание сельской администрации	Россия, республика Дагестан, Сулейман-Стальский район, село Даркуш	0101000020E610000020B6F468AA314840C74961DEE3E64440
32693	8	75	782	20459	\N	\N	41.685332752444097	Республика Дагестан, Сулейман-Стальский район, сельсовет Герейхановский, зданире сельского клуба	Россия, республика Дагестан, Сулейман-Стальский район, село Герейхановское	0101000020E61000007CED9925011E48404EEFE2FDB8D74440
32692	8	75	782	20459	\N	\N	41.684114000000001	Республика Дагестан, Сулейман-Стальский район, село Герейхановское, здание сельского клуба		0101000020E6100000861F9C4F1D1D48402D5E2C0C91D74440
32718	8	75	782	21758	\N	\N	41.598939000000001	Республика Дагестан, Сулейман-Стальский район, село Буткент, здание сельского клуба	Россия, республика Дагестан, Сулейман-Стальский район, село Буткент	0101000020E6100000655419C6DD16484044A67C08AACC4440
32990	8	75	782	20176	\N	\N	41.694974999999999	село Ашага-Ярак, Сельский дом культуры		0101000020E6100000C13BF9F4D8184840D044D8F0F4D84440
32688	8	75	782	20176	\N	\N	41.694974999999999	Республика Дагестан, Сулейман-Стальский район, село Ашага-Стал, здание сельской администрации		0101000020E6100000C13BF9F4D8184840D044D8F0F4D84440
32716	8	75	782	21624	\N	\N	41.631250000000001	Республика Дагестан, Сулейман-Стальский район, село Ашага-Картас, здание сельского клуба	Россия, республика Дагестан, Сулейман-Стальский район, село Ашага-Картас	0101000020E6100000444DF4F9280F4840CDCCCCCCCCD04440
32724	8	75	782	22018	\N	\N	41.630414000000002	Республика Дагестан, Сулейман-Стальский район, село Асаликент, здание сельского клуба		0101000020E610000001A5A146211548406478EC67B1D04440
32705	8	75	782	21148	\N	\N	41.716577000000001	Республика Дагестан, Сулейман-Стальский район, село Алкадар, здание сельского клуба		0101000020E6100000064CE0D6DD0A48406C088ECBB8DB4440
32528	8	75	7291	53718	\N	\N	42.976722000000002	Республика Дагестан, город Махачкала, Советский район, поселок Тарки, Здание администрации		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
32679	8	75	1539	19723	\N	\N	42.334141439021501	Республика Дагестан, Сергокалинский район, сельсовет Урахинский, село Урахи, СДК	Россия, республика Дагестан, Сергокалинский район, село Урахи	0101000020E6100000810A47904ACD47405AA0DD21C52A4540
32672	8	75	1539	19250	\N	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, Урахинская	Россия, республика Дагестан, Сергокалинский район, село Сергокала	0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32670	8	75	1539	19250	\N	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, контора ГУП им.Х.Магомедовой		0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32675	8	75	1539	19250	32908	\N	42.449420391180396	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, Матросова, здание ЦБС	Россия, республика Дагестан, Сергокалинский район, село Сергокала	0101000020E6100000B64B1B0E4BD547408C15359886394540
32673	8	75	1539	19250	33152	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, Буйнакского, здание РЕРЦ		0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32677	8	75	1539	19250	33169	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, Буденного, здание МДОУ №3		0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32671	8	75	1539	19250	32939	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, 50 лет Октября		0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32676	8	75	1539	19250	33047	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, 50 лет Октября, здание Райпо		0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32674	8	75	1539	19250	32940	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Сергокала, 317 стрелковой дивизии, 7		0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32669	8	75	1539	19166	\N	\N	42.473396999999999	Республика Дагестан, Сергокалинский район, сельсовет Новомугринский, село Новое Мугри, СДК		0101000020E61000002ACAA5F10BE147402383DC45983C4540
32667	8	75	1539	53438	\N	\N	42.328201166278397	Республика Дагестан, Сергокалинский район, сельсовет Нижнемулебкинский, село Нижнемулебки, здание СОШ	Россия, республика Дагестан, Сергокалинский район, село Нижние Мулебки	0101000020E610000017D4B7CCE9C84740DBC1887D022A4540
32655	8	75	1539	18434	\N	\N	42.328679999999999	Республика Дагестан, Сергокалинский район, сельсовет Бурдекинский, село Нижнее Махаргимахи, СДК		0101000020E610000032384A5E9DD14740B56CAD2F122A4540
32666	8	75	1539	18917	\N	\N	42.406041000000002	"Республика Дагестан, Сергокалинский район, село Мюрего, здание ГУП ""Красный Октябрь"""		0101000020E61000003D997FF44DD84740E6EAC726F9334540
32665	8	75	1539	18917	\N	\N	42.406041000000002	Республика Дагестан, Сергокалинский район, село Мюрего, СОШ		0101000020E61000003D997FF44DD84740E6EAC726F9334540
32664	8	75	1539	18917	\N	\N	42.406041000000002	Республика Дагестан, Сергокалинский район, село Мюрего, СДК		0101000020E61000003D997FF44DD84740E6EAC726F9334540
32663	8	75	1539	18860	\N	\N	42.266606000000003	Республика Дагестан, Сергокалинский район, село Мургук, СДК		0101000020E6100000CFF3A78DEAD847406D75392520224540
32662	8	75	1539	18811	\N	\N	42.335872000000002	Республика Дагестан, Сергокалинский район, сельсовет Миглакасимахинский, село Миглакасимахи, СДК		0101000020E6100000F73AA92F4BC7474031D28BDAFD2A4540
32661	8	75	1539	53507	\N	\N	42.316576961531702	Республика Дагестан, Сергокалинский район, село Мамааул, СДК	Россия, республика Дагестан, Сергокалинский район, село Мамаул	0101000020E610000072C3EFA65BE0474039D55A9885284540
32680	8	75	1539	53764	\N	\N	42.449038999999999	Республика Дагестан, Сергокалинский район, сельсовет Урахинский, село Краснопартизанск, СДК		0101000020E6100000CC0BB08F4ED5474074D0251C7A394540
32659	8	75	1539	18683	\N	\N	42.312187000000002	"Республика Дагестан, Сергокалинский район, сельсовет Кичи-Гамринский, село Кичи- Гамри, контора колхоза ""Гамринский"""		0101000020E610000097FF907EFBDA4740419E5DBEF5274540
32658	8	75	1539	18590	\N	\N	42.254454000000003	Республика Дагестан, Сергокалинский район, село Канасираги, СДК		0101000020E6100000E8DEC325C7D147400F2BDCF291204540
32678	8	75	1539	19657	\N	\N	42.496070000000003	Республика Дагестан, Сергокалинский район, сельсовет Сергокалинский, село Кадиркент, СДК	Россия, республика Дагестан, Сергокалинский район, село Кадиркент	0101000020E610000052F2EA1C03CE47406C43C5387F3F4540
32656	8	75	1539	53617	\N	\N	42.402974972551803	Республика Дагестан, Сергокалинский район, сельсовет Ванашимахинский, село Ванашимахи	Россия, республика Дагестан, Сергокалинский район, село Ванаши-Махи	0101000020E6100000B1355B79C9CD4740840D4FAF94334540
32668	8	75	1539	19142	\N	\N	42.305073	Республика Дагестан, Сергокалинский район, сельсовет Нижнемулебкинский, село Бурхимахи, здание СОШ		0101000020E61000009DF6949C13CB474041F2CEA10C274540
32654	8	75	1539	18378	\N	\N	42.304706000000003	Республика Дагестан, Сергокалинский район, сельсовет Бурдекинский, село Бурдеки, СДК		0101000020E61000002B4EB51666D547408F72309B00274540
32660	8	75	1539	18699	\N	\N	42.297217000000003	Республика Дагестан, Сергокалинский район, сельсовет Кичи-Гамринский, село Балтамахи, СДК		0101000020E6100000D40E7F4DD6DC47405A68E7340B264540
32653	8	75	1539	53475	\N	\N	42.374580764818297	Республика Дагестан, Сергокалинский район, село Аялизимахи, СДК	Россия, республика Дагестан, Сергокалинский район, село Аялизмахи	0101000020E610000087A3AB7477CD4740FB592C45F22F4540
32652	8	75	1539	18291	\N	\N	42.361400000000003	Республика Дагестан, Сергокалинский район, сельсовет Аймаумахинский, село Аймаумахи, здание СДК		0101000020E6100000E5D2F88557CA47402063EE5A422E4540
32632	8	75	1410	53950	\N	\N	41.654113000000002	Республика Дагестан, Рутульский район, сельсовет Цахурский с. Согют, Здание школы		0101000020E6100000CBF78C4468944740B9718BF9B9D34440
32636	8	75	1410	53649	\N	\N	41.654113000000002	Республика Дагестан, Рутульский район, сельсовет Кальяльский с. Дженых, Зданиие школы		0101000020E6100000CBF78C4468944740B9718BF9B9D34440
32620	8	75	1410	53553	\N	\N	41.654113000000002	Республика Дагестан, Рутульский район, сельсовет Ихрекский с. Асталай, Здание школы		0101000020E6100000CBF78C4468944740B9718BF9B9D34440
32649	8	75	1410	53789	\N	\N	41.654113000000002	РД, Рутульский район, сельсовет Цахурский, прикутан Правда, Здание школы		0101000020E6100000CBF78C4468944740B9718BF9B9D34440
32641	8	75	1410	53463	\N	\N	41.655437684414103	РД, Рутульский район, сельсовет Кальяльский, прикутан Камбулат, Здание школы	Россия, республика Дагестан, Рутульский район	0101000020E6100000E7ABE463779547401F477364E5D34440
32609	8	75	1410	16115	\N	\N	41.607819386377201	Республика Дагестан, Рутульский район, сельсовет Шиназский, с. Шиназ, Здание школы		0101000020E610000021B1DD3D40AF474097715303CDCD4440
32608	8	75	1410	16115	\N	\N	41.610022999999998	Республика Дагестан, Рутульский район, сельсовет Шиназский с. Шиназ, Здание сельского клуба		0101000020E6100000C5707500C4AF47406667D13B15CE4440
32631	8	75	1410	53626	\N	\N	41.651702599244899	Республика Дагестан, Рутульский район, сельсовет Цахурский с. Цахур, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Цахур	0101000020E6100000FC54151A8891474040DAFF006BD34440
32630	8	75	1410	53810	\N	\N	41.648069999999997	Республика Дагестан, Рутульский район, сельсовет Цахурский с. Хиях, Здание школы	Россия, республика Дагестан, Рутульский район, село Хнях	0101000020E6100000C460FE0A9993474065C22FF5F3D24440
32606	8	75	1410	53810	\N	\N	41.654113000000002	Республика Дагестан, Рутульский район, сельсовет Рутульский с. Хнюх, Здание школы		0101000020E6100000CBF78C4468944740B9718BF9B9D34440
32600	8	75	1410	32882	\N	\N	41.496282000000001	Республика Дагестан, Рутульский район, сельсовет Хлютский с. Хлют, Здание дома культуры		0101000020E6100000EF71A609DBC34740F7CB272B86BF4440
32599	8	75	1410	32882	\N	\N	41.496466735164198	Республика Дагестан, Рутульский район, сельсовет Хлютский с. Хлют, Здание администрации	Россия, республика Дагестан, Рутульский район, село Хлют	0101000020E6100000ABEB504D49C4474089450C3B8CBF4440
32598	8	75	1410	32882	\N	\N	41.496282000000001	Республика Дагестан, Рутульский район, сельсовет Хлютский с. Хлют, Здание школы	Россия, республика Дагестан, Рутульский район, село Хлют	0101000020E6100000EF71A609DBC34740F7CB272B86BF4440
32605	8	75	1410	32905	\N	\N	41.538823000000001	Республика Дагестан, Рутульский район, сельсовет Рутульский с. Рутул, Здание школы №2		0101000020E6100000AA0EB9196EB6474093AAED26F8C44440
32604	8	75	1410	32905	\N	\N	41.538823000000001	Республика Дагестан, Рутульский район, сельсовет Рутульский с. Рутул, Здание райадминистрации	Россия, республика Дагестан, Рутульский район, село Рутул	0101000020E6100000AA0EB9196EB6474093AAED26F8C44440
32603	8	75	1410	32905	\N	\N	41.534528130884702	Республика Дагестан, Рутульский район, сельсовет Рутульский с. Рутул, Здание РАЙПО	Россия, республика Дагестан, Рутульский район, село Рутул	0101000020E610000054A86E2EFEB64740ED65DB696BC44440
32602	8	75	1410	32905	\N	\N	41.538823000000001	Республика Дагестан, Рутульский район, сельсовет Рутульский с. Рутул, Здание шклоы №1		0101000020E6100000AA0EB9196EB6474093AAED26F8C44440
32645	8	75	1410	53849	\N	\N	41.451442810323698	РД, Рутульский район, сельсовет Борчский, с. Новый Борч, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Борч	0101000020E6100000183F8D7BF3A947400A815CE2C8B94440
32623	8	75	1410	16849	\N	\N	41.744059	Республика Дагестан, Рутульский район, село Нижний Катрух, Здание школы		0101000020E6100000BDC5C37B0E9A4740B1A547533DDF4440
32639	8	75	1410	53806	\N	\N	41.700250856418002	Республика Дагестан, Рутульский район, сельсовет Кальяльский с. Мухах, Здание школы	Россия, республика Дагестан, Рутульский район, село Мухух	0101000020E610000045BC75FEED7E4740E3FE23D3A1D94440
32651	8	75	1410	17330	\N	\N	41.658472000000003	Республика Дагестан, Рутульский район, село Муслах, прикутан Кочубей, Здание школы		0101000020E6100000DCF4673F528E474076AA7CCF48D44440
32111	8	75	653	53713	\N	\N	43.245063999999999	Республика Дагестан, Кизилюртовский район, cело Гельбах		0101000020E6100000768BC058DF764740A6B6D4415E9F4540
32647	8	75	1410	17330	\N	\N	41.658472000000003	Республика Дагестан, Рутульский район, село Муслах, прикутан Свердлова, Здание школы		0101000020E6100000DCF4673F528E474076AA7CCF48D44440
32633	8	75	1410	17330	\N	\N	41.658472000000003	Республика Дагестан, Рутульский район, село Муслах, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Муслах	0101000020E6100000DCF4673F528E474076AA7CCF48D44440
32648	8	75	1410	17387	\N	\N	41.665323000000001	РД, Рутульский район, село Мишлеш, прикутан 20 партсъезд, Здание школы		0101000020E61000005396218E758B47406823D74D29D54440
32635	8	75	1410	17387	\N	\N	41.665323000000001	Республика Дагестан, Рутульский район, село Мишлеш, Здание сельского клуба		0101000020E61000005396218E758B47406823D74D29D54440
32634	8	75	1410	17387	\N	\N	41.665323000000001	Республика Дагестан, Рутульский район, село Мишлеш, Здание сельской больницы		0101000020E61000005396218E758B47406823D74D29D54440
32618	8	75	1410	53925	\N	\N	41.667243609265199	Республика Дагестан, Рутульский район, сельсовет Мюхрекский с. Мюхрек, Здание школы	Россия, республика Дагестан, Рутульский район, село Михрек	0101000020E61000001971016894A44740E2395B4068D54440
32617	8	75	1410	53925	\N	\N	41.668716667629802	Республика Дагестан, Рутульский район, сельсовет Мюхрекский с. Цудик, Здание школы	Россия, республика Дагестан, Рутульский район, село Михрек	0101000020E610000016FBCBEEC9A34740BEA3C68498D54440
32629	8	75	1410	53647	\N	\N	41.636472966630002	Республика Дагестан, Рутульский район, сельсовет Цахурский с. Микик, Здание школы	Россия, республика Дагестан, Рутульский район, село Миких	0101000020E61000004F75C8CD70954740BDE47FF277D14440
32612	8	75	1410	53593	\N	\N	41.613030997326597	Республика Дагестан, Рутульский район, сельсовет Лучекский с. лучек, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Лучек	0101000020E610000074D2FBC6D7A647409337C0CC77CE4440
32607	8	75	1410	53655	\N	\N	41.562382386639698	Республика Дагестан, Рутульский район, сельсовет Рутульский с. Куфа, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Куфа	0101000020E61000005DA3E5400FB14740F6ED2422FCC74440
32640	8	75	1410	53646	\N	\N	41.781602212355502	Республика Дагестан, Рутульский район, сельсовет Кальяльский с. Кусур, Здание школы	Россия, республика Дагестан, Рутульский район, село Кусур	0101000020E61000001DC9E53FA47947407D3ECA880BE44440
32628	8	75	1410	53576	\N	\N	41.581460941315697	РД, Рутульский район, сельсовет Гельмецинский с. Курдул, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Курдул	0101000020E610000061A8C30AB7964740217365506DCA4440
32637	8	75	1410	53455	\N	\N	41.668986411629398	Республика Дагестан, Рутульский район, сельсовет Кальяльский с. Корш, Здание школы	Россия, республика Дагестан, Рутульский район, село Корш	0101000020E6100000EE43DE72F5874740ADBD4F55A1D54440
32601	8	75	1410	53628	\N	\N	41.532528856142498	Республика Дагестан, Рутульский район, сельсовет Рутульский с. Киче, Здание дома культуры	Россия, республика Дагестан, Рутульский район, село Кича	0101000020E610000016A4198BA6BD4740F69507E929C44440
32615	8	75	1410	16434	\N	\N	41.617384999999999	Республика Дагестан, Рутульский район, село Кина, Здание сельского клуба		0101000020E610000076FBAC3253A247403E05C07806CF4440
32650	8	75	1410	53458	\N	\N	41.684360607595501	РД, Рутульский район, сельсовет Кальяльский, прикутан Уланхол, Здание колхоза		0101000020E61000001684F23E8E80474035D4282499D74440
32643	8	75	1410	53458	\N	\N	41.684072077786503	РД, Рутульский район, сельсовет Кальяльский, прикутан Кальяльский, Здание школы	Россия, республика Дагестан, Рутульский район, село Кальял	0101000020E61000004B57B08D78804740FE0DDAAB8FD74440
32610	8	75	1410	53418	\N	\N	41.577559999999998	Республика Дагестан, Рутульский район, сельсовет Амсарский с. Кала, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Кала	0101000020E610000022C154336BAD474027BD6F7CEDC94440
32622	8	75	1410	53630	\N	\N	41.673228645155	Республика Дагестан, Рутульский район, сельсовет Ихрекский с. Ихрек, Здание школы	Россия, республика Дагестан, Рутульский район, поселок Ихрек	0101000020E6100000EE0912DBDD9F474001DC2C5E2CD64440
32621	8	75	1410	33018	\N	\N	41.695748999999999	Республика Дагестан, Рутульский район, сельсовет Ихрекский с. Ихрек, Здание сельского клуба		0101000020E61000007C0DC171199B4740C39CA04D0ED94440
32627	8	75	1410	53571	\N	\N	41.625261091770199	РД, Рутульский район, сельсовет Гельмецинский с. Гельмец, Здание сельадминистрации	Россия, республика Дагестан, Рутульский район, село Гельмец	0101000020E6100000FDF84B8BFA9647406D3B6D8D08D04440
32626	8	75	1410	53571	\N	\N	41.624688654266599	РД, Рутульский район, сельсовет Гельмецинский с. Гельмец, Здание школы	Россия, республика Дагестан, Рутульский район, село Гельмец	0101000020E61000002575029A08974740E19524CFF5CF4440
32614	8	75	1410	53818	\N	\N	41.647096305612401	Республика Дагестан, Рутульский район, сельсовет Лучекский с. Вруш, Здание школы	Россия, республика Дагестан, Рутульский район, село Вруш	0101000020E6100000B760A92EE0A74740ABAFAE0AD4D24440
32625	8	75	1410	16933	\N	\N	41.746346000000003	Республика Дагестан, Рутульский район, село Верхний Катрух, Здание сельского клуба		0101000020E610000026E5EE737C9C47400EC0064488DF4440
32646	8	75	1410	53797	\N	\N	41.452516000000003	РД, Рутульский район, сельсовет Борчский, прикутан Казан-Кулак, Здание сельского клуба	Россия, республика Дагестан, Рутульский район, село Борч	0101000020E6100000CC7EDDE9CEA947405875560BECB94440
90904	8	81	\N	16251	59537	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Кочубея, 5		0101000020E610000037FC6EBA65BB45406EA6423C12134640
32644	8	75	1410	53797	\N	\N	41.453023410150003	РД, Рутульский район, сельсовет Борчский, с. Новый Борч, Здание школы		0101000020E61000002A1900AAB8A94740FCAA5CA8FCB94440
32619	8	75	1410	53901	\N	\N	41.684103117423398	Республика Дагестан, Рутульский район, сельсовет Ихрекский с. Аран, Здание школы	Россия, республика Дагестан, Рутульский район	0101000020E6100000ADA580B4FF9B4740390CE6AF90D74440
32611	8	75	1410	40251	\N	\N	41.591128910166198	Республика Дагестан, Рутульский район, сельсовет Амсарский с. Амсар, Здание сельского клуба	Россия, республика Дагестан, Рутульский район	0101000020E61000007C7F83F6EAAB4740CD5B751DAACB4440
32594	8	75	1355	15400	\N	\N	44.072738000000001	Республика Дагестан, Ногайский район, село Эдиге, Здание  дома культуры		0101000020E6100000F1F09E03CB2D47409696917A4F094640
32588	8	75	1355	53768	\N	\N	44.40795	Республика Дагестан, Ногайский район, село Шумлелик, Здание школы		0101000020E6100000791F477364E346409C33A2B437344640
32585	8	75	1355	14824	\N	\N	44.160583000000003	Республика Дагестан, Ногайский район, село Червленные Буруны,Ферма №3, Здание школы	Россия, республика Дагестан, Ногайский район, село Червленные Буруны	0101000020E6100000F241CF66D5CF464094A5D6FB8D144640
32584	8	75	1355	14824	\N	\N	44.160583000000003	Республика Дагестан, Ногайский район, село Червленные Буруны,Ферма №2, Здание школы		0101000020E6100000F241CF66D5CF464094A5D6FB8D144640
32583	8	75	1355	14824	\N	\N	44.160583000000003	Республика Дагестан, Ногайский район, село Червленные Буруны ,Ферма №1, Здание школы		0101000020E6100000F241CF66D5CF464094A5D6FB8D144640
32582	8	75	1355	14824	\N	\N	44.160583000000003	Республика Дагестан, Ногайский район, село Червленные Буруны, Здание дома культуры		0101000020E6100000F241CF66D5CF464094A5D6FB8D144640
32577	8	75	1355	53623	\N	\N	44.219744687946999	Республика Дагестан, Ногайский район, село Уйсалган, Здание сельского дома культуры	Россия, республика Дагестан, Ногайский район, село Уй-Салган	0101000020E6100000AE484C50C3934640D23AAA9A201C4640
32597	8	75	1355	15483	\N	\N	44.165925000000001	Республика Дагестан, Ногайский район, село Терекли-Мектеб, Здание школы		0101000020E6100000ABEAE5779AEE46405E4BC8073D154640
32596	8	75	1355	15483	\N	\N	44.165925000000001	Республика Дагестан, Ногайский район, село Терекли-Мектеб, Здание детской юношеско-спортивной школы		0101000020E6100000ABEAE5779AEE46405E4BC8073D154640
32595	8	75	1355	15483	\N	\N	44.165925000000001	Республика Дагестан, Ногайский район, село Терекли-Мектеб, Здание районного дома культуры		0101000020E6100000ABEAE5779AEE46405E4BC8073D154640
32578	8	75	1355	53778	\N	\N	44.243194487340602	Республика Дагестан, Ногайский район, село Орта-тюбе, Здание сельского дома культуры	Россия, республика Дагестан, Ногайский район, село Ортатюбе	0101000020E61000000A9E42AED4A34640AE4A22FB201F4640
32586	8	75	1355	15027	\N	\N	44.190297000000001	Республика Дагестан, Ногайский район, село Нариман, Здание сельской администрации		0101000020E61000001EFF058200EB464072C3EFA65B184640
32592	8	75	1355	15312	\N	\N	44.197671	Республика Дагестан, Ногайский район, село Ленинаул, Здание школы		0101000020E61000004D2CF015DD0247400E2F88484D194640
31982	8	75	1355	15312	\N	\N	44.197671	Республика Дагестан Казбековский район,село Ленинаул, здание СШ №2		0101000020E61000004D2CF015DD0247400E2F88484D194640
31981	8	75	1355	15312	\N	\N	44.197671	Республика Дагестан Казбековский район, село Ленинаул, здание дома культуры		0101000020E61000004D2CF015DD0247400E2F88484D194640
31980	8	75	1355	15312	\N	\N	44.197671	Республика Дагестан, Казбековский район, село Ленинаул, здание школы №1	Россия, республика Дагестан, Ногайский район, село Ленинаул	0101000020E61000004D2CF015DD0247400E2F88484D194640
32581	8	75	1355	14812	\N	\N	44.293272999999999	Республика Дагестан, Ногайский район, село Кунбатар, Здание сельской администрации		0101000020E6100000E5284014CCCA464060E63BF889254640
32589	8	75	1355	15177	\N	\N	43.989994000000003	Республика Дагестан, Ногайский район, село Кумли, Здание дома культуры		0101000020E6100000111956F1460847403D9E961FB8FE4540
32590	8	75	1355	53779	\N	\N	44.084093230694002	Республика Дагестан, Ногайский район, село Кара-сув, Здание школы	Россия, республика Дагестан, Ногайский район, село Карасу	0101000020E6100000ECDCB419A7F346404969368FC30A4640
32579	8	75	1355	14710	\N	\N	44.254263999999999	Республика Дагестан, Ногайский район, село Карагас, Здание сельской администрации		0101000020E610000013D6C6D809B146406B4606B98B204640
32593	8	75	1355	15381	\N	\N	44.161301000000002	Республика Дагестан, Ногайский район, село Калининаул, Здание школы		0101000020E6100000C6C1A563CEFF4640F3E7DB82A5144640
32790	8	75	1355	53975	\N	\N	44.018288531962199	Республика Дагестан, Тарумовский район, с-с Новогеоргиевский, с. Иммун, здание Дом культуры, Дом культуры	Россия, республика Дагестан, Ногайский район, село Солнечный	0101000020E61000000F9C33A2B42747403370404B57024640
33275	8	75	1355	53470	\N	\N	44.688372378194103	Республика Дагестан, город Южно-Сухокумск, п.Восточный-Сухокумск, школа №3	Россия, республика Дагестан, Ногайский район, село Восточно-Сухокумск	0101000020E61000002CB7B41A12F94640B6BDDD921C584640
32580	8	75	1355	14751	\N	\N	44.218238999999997	Республика Дагестан, Ногайский район, село Боранчи, Здание школы		0101000020E6100000A054FB743CC446401ADB6B41EF1B4640
32587	8	75	1355	15090	\N	\N	44.176231000000001	Республика Дагестан, Ногайский район, село Батыр-Мурза, Здание школы		0101000020E61000003E22A64412D946404CC5C6BC8E164640
32576	8	75	1287	53750	\N	\N	43.172521000000003	Республика Дагестан, Новолакский район, село Ямансу, Здание дома культуры		0101000020E6100000390F27309D3E4740C66F0A2B15964540
32575	8	75	1287	14498	\N	\N	43.135460000000002	Республика Дагестан, Новолакский район, село Шушия, Здание школы		0101000020E61000002F89B3226A36474045F5D6C056914540
32572	8	75	1287	13562	\N	\N	43.109822999999999	Республика Дагестан, Новолакский район, село Чапаево, Здание школы		0101000020E61000002028B7ED7B3E47409FAC18AE0E8E4540
32555	8	75	1287	13562	\N	\N	43.109822999999999	Республика Дагестан, Новолакский район, село Чапаево, Здание администрации с/с	Россия, республика Дагестан, Новолакский район, село Чапаево	0101000020E61000002028B7ED7B3E47409FAC18AE0E8E4540
32574	8	75	1287	13959	\N	\N	43.221477	Республика Дагестан, Новолакский район, село Тухчар, Здание школы		0101000020E6100000E370E6577334474079E8BB5B599C4540
32570	8	75	1287	13959	\N	\N	43.221477	Республика Дагестан, Новолакский район, село Тухчар, Здание дома культуры		0101000020E6100000E370E6577334474079E8BB5B599C4540
32563	8	75	1287	13959	\N	\N	43.221477	Республика Дагестан, Новолакский район, село Тухчар, Зданипе школы		0101000020E6100000E370E6577334474079E8BB5B599C4540
32567	8	75	1287	13863	\N	\N	43.208902000000002	Республика Дагестан, Новолакский район, село Новочуртах, Здание администрации с/с		0101000020E6100000C7F2AE7AC0444740D508FD4CBD9A4540
32562	8	75	1287	13863	\N	\N	43.208902000000002	Республика Дагестан, Новолакский район, село Новочуртах, Здание дома культуры		0101000020E6100000C7F2AE7AC0444740D508FD4CBD9A4540
32569	8	75	1287	13768	\N	\N	43.120175000000003	Республика Дагестан, Новолакский район, село Новолакское, Здание школы		0101000020E6100000F7AE415F7A3D4740FE65F7E4618F4540
32565	8	75	1287	13768	\N	\N	43.120175000000003	Республика Дагестан, Новолакский район, село Новолакское, Здание администрации с/с		0101000020E6100000F7AE415F7A3D4740FE65F7E4618F4540
32560	8	75	1287	13768	\N	\N	43.120175000000003	Республика Дагестан, Новолакский район, село Новолакское, Здание дома культуры		0101000020E6100000F7AE415F7A3D4740FE65F7E4618F4540
32566	8	75	1287	53592	\N	\N	43.164727320273599	Республика Дагестан, Новолакский район, сельсовет Новокулинский, Здание школы	Россия, республика Дагестан, Новолакский район, село Новокули	0101000020E6100000C617EDF14242474054E23AC615954540
32561	8	75	1287	53592	\N	\N	43.166235185621296	Республика Дагестан, Новолакский район, сельсовет Новокулинский, Здание администрации с/с	Россия, республика Дагестан, Новолакский район, село Новокули	0101000020E6100000DC9E20B1DD414740AC39403047954540
32557	8	75	1287	53573	\N	\N	43.172521000000003	Республика Дагестан, Новолакский район, сельсовет Дучинский, Здание администрации с/с		0101000020E6100000390F27309D3E4740C66F0A2B15964540
32571	8	75	1287	13682	\N	\N	43.207737999999999	Республика Дагестан, Новолакский район, село Гамиях, Здание администрации с/с		0101000020E6100000C4CC3E8F513E47407711A628979A4540
32564	8	75	1287	13682	\N	\N	43.207737999999999	Республика Дагестан, Новолакский район, село Гамиях, Здание дома культуры		0101000020E6100000C4CC3E8F513E47407711A628979A4540
32558	8	75	1287	13682	\N	\N	43.207737999999999	Республика Дагестан, Новолакский район, село Гамиях, Здание школы		0101000020E6100000C4CC3E8F513E47407711A628979A4540
32556	8	75	1287	53787	\N	\N	43.149458072446201	Республика Дагестан, Новолакский район, село Банайюрт, Здание  дома культуры		0101000020E6100000670A9DD7D83547401310937021934540
32554	8	75	1287	13484	\N	\N	43.148063999999998	Республика Дагестан, Новолакский район, село Ахар, Здание администрации с/с		0101000020E6100000454AB3791C3A474083DBDAC2F3924540
32441	8	75	7294	53721	\N	\N	43.0359343067014	Республика Дагестан, город Махачкала, Кировский район, село Шамхал-Термен, Центр - помещение МОУ СОШ № 44	Россия, республика Дагестан, Махачкала городской округ, село Шамхал Термен	0101000020E6100000F37684D382A7474040683D7C99844540
32440	8	75	7294	53629	\N	\N	43.057861463119401	Республика Дагестан, город Махачкала, Кировский район, поселок Шамхал, Центр - помещение МОУ СОШ № 47		0101000020E61000000A2DEBFEB1AA4740605B3FFD67874540
32438	8	75	7294	53629	\N	\N	43.058490999999997	Республика Дагестан, город Махачкала, Кировский район, поселок Шамхал, Центр - помещение МОУ СОШ № 45	Россия, республика Дагестан, Махачкала городской округ, поселок городского типа Шамхал	0101000020E61000001B9E5E29CBAA47401F0E12A27C874540
32437	8	75	7294	53629	\N	\N	43.057987341168598	Республика Дагестан, город Махачкала, Кировский район, поселок Шамхал, Центр - помещение Дом культуры		0101000020E6100000B8CCE9B298AA4740EC4B361E6C874540
32445	8	75	7294	53691	\N	\N	43.274436999999999	Республика Дагестан, город Махачкала, Кировский район, поселок Сулак, Центр - помещение МОУ СОШ № 21	Россия, республика Дагестан, Махачкала городской округ, поселок городского типа Сулак	0101000020E610000058E4D70FB1C14740FBE769C020A34540
32447	8	75	7294	53732	\N	\N	42.973696339956099	Республика Дагестан, город Махачкала, Кировский район, поселок Семендер, Центр - помещение МОУ СОШ № 54	Россия, республика Дагестан, Махачкала городской округ	0101000020E6100000F3716DA818AF47407D1F0E12A27C4540
32436	8	75	7294	53726	\N	\N	42.967129999999997	Республика Дагестан, город Махачкала, Кировский район, поселок Ленинкент, Центр - помещение МОУ СОШ № 35 Спортзал	Россия, республика Дагестан, Махачкала городской округ, поселок городского типа Ленинкент	0101000020E6100000DE02098A1FAD4740807D74EACA7B4540
32444	8	75	7294	53737	\N	\N	43.015715311290897	Республика Дагестан, город Махачкала, Кировский район, село Красноармейское, Центр - помещение МОУ СОШ № 25	Россия, республика Дагестан, Махачкала городской округ, село Красноармейское	0101000020E61000005340DAFF00B547404087F9F202824540
32319	8	75	341	53912	\N	\N	42.3887538240567	Левашинский район, село Нижнее Аршимахи, Здание дома культуры	Россия, республика Дагестан, Левашинский район, село Нижняя Арши	0101000020E6100000B8E4B8533A9247403718EAB0C2314540
32538	8	75	7294	53719	33135	\N	42.931454789752799	Республика Дагестан, город Махачкала, Советский район, поселок Альбурикент, Лесная, 12 корп.1	Россия, республика Дагестан, Махачкала городской округ, поселок городского типа Альбурикент	0101000020E610000024624A24D1C147400C59DDEA39774540
32539	8	75	7301	53720	33137	\N	42.926787459977099	Республика Дагестан, город Махачкала, Советский район, поселок Альбурикент, Лесная, 12 корп. 2		0101000020E6100000321F10E84CC24740D1ADD7F4A0764540
32395	8	75	674	5926	\N	\N	41.797643000000001	Республика Дагестан, Магарамкентский район, село Яруквалар, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Яруквалар	0101000020E6100000CBD93BA3AD3448401171732A19E64440
32382	8	75	674	5260	\N	\N	41.646431999999997	Республика Дагестан, Магарамкентский район, село Яраг-Казмаляр, Здание дома культуры, -		0101000020E6100000A5828AAA5F3148403F8BA548BED24440
32400	8	75	674	6226	\N	\N	41.787652999999999	Республика Дагестан, Магарамкентский район, село Чахчах-Казмаляр, Здание дома культуры, -		0101000020E610000033315D88D53F484053CC41D0D1E44440
32385	8	75	674	5386	\N	\N	41.657710999999999	Республика Дагестан, Магарамкентский район, село Целягюн, Здание школы, -		0101000020E610000013B875374F254840179CC1DF2FD44440
32403	8	75	674	6372	\N	\N	41.809398000000002	Республика Дагестан, Магарамкентский район, село Хтун-Казмаляр, Здание дома культуры, -		0101000020E6100000AF963B33C142484052B9895A9AE74440
32374	8	75	674	4843	\N	\N	41.5405540459438	Республика Дагестан, Магарамкентский район, село Хорель, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Хорель	0101000020E610000041D3122BA31948406ADC9BDF30C54440
32393	8	75	674	53741	\N	\N	41.726629451883497	Республика Дагестан, Магарамкентский район, село Ходжа-Казмаляр, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Ходжаказмаляр	0101000020E61000008B87F71C58384840A0A9D72D02DD4440
32397	8	75	674	6050	\N	\N	41.483981999999997	Республика Дагестан, Магарамкентский район, село Филя, Здание дома культуры, -		0101000020E6100000F5F75278D0FC474024ED461FF3BD4440
32402	8	75	674	6242	\N	\N	41.815548	Республика Дагестан, Магарамкентский район, село Тагиркент-Казмаляр, Здание школы, -		0101000020E61000002C0FD253E4404840BB287AE063E84440
32401	8	75	674	6242	\N	\N	41.815548	Республика Дагестан, Магарамкентский район, село Тагиркент-Казмаляр, Здание дома культуры, -		0101000020E61000002C0FD253E4404840BB287AE063E84440
32381	8	75	674	5171	\N	\N	41.607239	Республика Дагестан, Магарамкентский район, село Тагиркент, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Тагиркент	0101000020E610000051C1E1051127484089EDEE01BACD4440
32386	8	75	674	5460	\N	\N	41.725211999999999	Республика Дагестан, Магарамкентский район, село Советское, Здание дома культуры, -		0101000020E610000009E1D1C61129484058552FBFD3DC4440
32405	8	75	674	6420	\N	\N	41.825646999999996	Республика Дагестан, Магарамкентский район, село Самур, Здание дома культуры, -		0101000020E61000002F8B89CDC73D48402F8507CDAEE94440
32404	8	75	674	6420	\N	\N	41.825646999999996	Республика Дагестан, Магарамкентский район, село Самур, Здание школы, -		0101000020E61000002F8B89CDC73D48402F8507CDAEE94440
32407	8	75	674	6558	\N	\N	41.844203	Республика Дагестан, Магарамкентский район, поселок Приморский, Здание дома культуры, -		0101000020E6100000A2293BFDA04A4840B1170AD80EEC4440
32394	8	75	674	5909	\N	\N	41.774259000000001	Республика Дагестан, Магарамкентский район, село Оружба, Здание дома культуры, -		0101000020E61000004F57772CB63748401CD13DEB1AE34440
32392	8	75	674	5688	\N	\N	41.729297000000003	Республика Дагестан, Магарамкентский район, село Новый Аул, Здание дома культуры, -		0101000020E61000008B8D791D713248401409A69A59DD4440
32390	8	75	674	5688	\N	\N	41.729297000000003	Республика Дагестан, Магарамкентский район, село Новый Ааул, Здание школы, -		0101000020E61000008B8D791D713248401409A69A59DD4440
32372	8	75	674	4741	\N	\N	41.525688000000002	Республика Дагестан, Магарамкентский район, село Мугерган, Здание дома культуры, -		0101000020E6100000A79542209716484028F38FBE49C34440
32371	8	75	674	4647	\N	\N	41.475686000000003	Республика Дагестан, Магарамкентский район, село Мака-Казмаляр, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Мака-Казмаляр	0101000020E6100000CFA44DD53D02484021956247E3BC4440
32380	8	75	674	5049	\N	\N	41.615706000000003	Республика Дагестан, Магарамкентский район, село Магарамкент, Здание школы №1, -		0101000020E6100000AD69DE718A2C4840BAF94674CFCE4440
32379	8	75	674	5049	\N	\N	41.615706000000003	Республика Дагестан, Магарамкентский район, село Магарамкент, Здание ДЮСШ, -		0101000020E6100000AD69DE718A2C4840BAF94674CFCE4440
32378	8	75	674	5049	\N	\N	41.615706000000003	Республика Дагестан, Магарамкентский район, село Магарамкент, Здание дома культуры, -		0101000020E6100000AD69DE718A2C4840BAF94674CFCE4440
32399	8	75	674	53757	\N	\N	41.760958312388098	Республика Дагестан, Магарамкентский район, село  Кчу-Казмаляр, Здание школы, -	Россия, республика Дагестан, Магарамкентский район, село КчунКазмаляр	0101000020E6100000F86BB2463D3E484096D05D1267E14440
32377	8	75	674	4916	\N	\N	41.572763999999999	Республика Дагестан, Магарамкентский район, село Куйсун, Здание дома культуры, -		0101000020E6100000795C548B88244840BF29AC5450C94440
32376	8	75	674	4916	\N	\N	41.572763999999999	Республика Дагестан, Магарамкентский район, село Куйсун, Здание школы, -		0101000020E6100000795C548B88244840BF29AC5450C94440
32373	8	75	674	4758	\N	\N	41.536886000000003	Республика Дагестан, Магарамкентский район, село Кирка, Здание дома культуры, -		0101000020E6100000B0A9F3A8F817484013D731AEB8C44440
32391	8	75	674	53840	\N	\N	41.757840815651697	Республика Дагестан, Магарамкентский район, село Кличхан, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Киличхай	0101000020E6100000B4CA4C69FD354840B24813EF00E14440
32398	8	75	674	6083	\N	\N	41.745168999999997	Республика Дагестан, Магарамкентский район, село Кабир-Казмаляр, Здание дома культуры, -		0101000020E61000000A68226C783E48401B7FA2B261DF4440
32375	8	75	674	4896	\N	\N	41.550755000000002	Республика Дагестан, Магарамкентский район, село Джепель, Здание дома культуры, -		0101000020E6100000FD135CACA81B4840E38DCC237FC64440
32370	8	75	674	4626	\N	\N	41.482211999999997	Республика Дагестан, Магарамкентский район, село Гарах, Здание администрации, -		0101000020E6100000815F2349100648408FDE701FB9BD4440
32384	8	75	674	5271	\N	\N	41.668011	Республика Дагестан, Магарамкентский район, село Гапцах, Здание дома культуры, -		0101000020E6100000F7C9518028304840232F6B6281D54440
32383	8	75	674	5271	\N	\N	41.668011	Республика Дагестан, Магарамкентский район, село Гапцах, Здание дома культуры		0101000020E6100000F7C9518028304840232F6B6281D54440
32389	8	75	674	53689	\N	\N	41.6994263103118	Республика Дагестан, Магарамкентский район, село Бут-Казмаляр, Здание школы	Россия, республика Дагестан, Магарамкентский район, село Бутказмаляр	0101000020E610000038691A14CD3348406EFC89CA86D94440
32388	8	75	674	53689	\N	\N	41.699940914768703	Республика Дагестан, Магарамкентский район, село Бут-Казмаляр, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Бутказмаляр	0101000020E610000000C80913463348409510ACAA97D94440
32406	8	75	674	6536	\N	\N	41.818128000000002	Республика Дагестан, Магарамкентский район, село Бильбиль, Здание дома культуры, -		0101000020E6100000378E588B4F45484090F8156BB8E84440
32396	8	75	674	53680	\N	\N	41.827948274191598	Республика Дагестан, Магарамкентский район, село Азадоглы, Здание дома культуры, -	Россия, республика Дагестан, Магарамкентский район, село Азад-Оглы	0101000020E6100000E831CA332F394840F1643733FAE94440
32368	8	75	341	4487	\N	\N	42.367029000000002	Левашинский район, село Эбдалая, Здание администрации с\\с		0101000020E6100000A4703D0AD7AB474080D767CEFA2E4540
32367	8	75	341	4473	\N	\N	42.350686000000003	Левашинский район, село Чуни, Здание дома культуры		0101000020E610000044F7AC6BB4A6474021956247E32C4540
32325	8	75	341	2117	\N	\N	42.414867999999998	Левашинский район, село Чахимахи, Здание начальной школы		0101000020E61000004CA59F7076C74740161406651A354540
32362	8	75	341	4200	\N	\N	42.340063999999998	Левашинский район, село Цудахар, Здание СПТУ		0101000020E610000068CEFA946394474002469737872B4540
32361	8	75	341	4114	\N	\N	42.466706000000002	Левашинский район, село Хахита, Здание дома культуры	Россия, республика Дагестан, Левашинский район, село Хахита	0101000020E6100000A0C211A452A247406A6CAF05BD3B4540
32357	8	75	341	53739	\N	\N	42.420859560573902	Левашинский район, село Хаджалмахи, Здание фруктово-консервного завода	Россия, республика Дагестан, Левашинский район, село Хаджал-Махи	0101000020E61000004DD9E90775974740E71890BDDE354540
32356	8	75	341	53769	\N	\N	42.461292	Левашинский район, село Хаджалмахи, Здание средней школы		0101000020E61000007E6FD39FFDA8474006F4C29D0B3B4540
32358	8	75	341	53558	\N	\N	42.419863167517597	Левашинский район, село Хаджалмахи, Здание основной школы	Россия, республика Дагестан, Левашинский район, село Хаджал-Махи	0101000020E6100000A9FA95CE8797474075E61E12BE354540
32355	8	75	341	3763	\N	\N	42.53783	Левашинский район, село Урма, Здание начальной школы		0101000020E61000006150A6D1E4A4474062670A9DD7444540
32354	8	75	341	3763	\N	\N	42.53783	Левашинский район, село Урма, Здание средней школы		0101000020E61000006150A6D1E4A4474062670A9DD7444540
32353	8	75	341	53703	\N	\N	42.373846029849602	Левашинский район, село Уллуая, Здание администрации с\\с	Россия, республика Дагестан, Левашинский район, село Уллу-Ая	0101000020E6100000D63730B951B04740C6DE8B2FDA2F4540
32352	8	75	341	53703	\N	\N	42.372700467410297	Левашинский район, село Уллуая, Здание основной школы	Россия, республика Дагестан, Левашинский район, село Уллу-Ая	0101000020E6100000679B1BD313B047400F9C33A2B42F4540
32338	8	75	341	2898	\N	\N	42.461292	Левашинский район, село Телагу, Здание начальной школы		0101000020E61000007E6FD39FFDA8474006F4C29D0B3B4540
32360	8	75	341	4072	\N	\N	42.406472999999998	Левашинский район, село Ташкапур, Здание средней школы		0101000020E6100000CF6A813D269647407FDAA84E07344540
32365	8	75	341	4325	\N	\N	42.356076999999999	Левашинский район, село Тарлимахи, Здание начальной школы		0101000020E6100000BB9D7DE541964740CCED5EEE932D4540
32369	8	75	341	4583	\N	\N	42.364077999999999	Левашинский район, село Тагзиркент, Здание начальной школы		0101000020E610000062F4DC4257AE4740B7989F1B9A2E4540
32334	8	75	341	2649	\N	\N	42.358874999999998	Левашинский район, село Сулейбакент, Здание средней школы		0101000020E6100000D462F030EDAF47400E2DB29DEF2D4540
32351	8	75	341	3601	\N	\N	42.555672000000001	Левашинский район, село Охли, Здание дома культуры		0101000020E61000004BCCB392569A4740C6A6954220474540
32317	8	75	341	1656	\N	\N	42.493077999999997	Левашинский район, село Орада Чугли, Здание дома культуры		0101000020E61000006E6DE179A99C474044300E2E1D3F4540
32350	8	75	341	3561	\N	\N	42.463526999999999	Левашинский район, село Нижнее Чугли, Здание дома культуры		0101000020E6100000AFB5F7A92AA6474010E84CDA543B4540
32359	8	75	341	4006	\N	\N	42.392038209790101	Левашинский район, село Нижнее Убекимахи, Здание основной школы	Россия, республика Дагестан, Левашинский район, село Нижние Убекимахи	0101000020E610000081EB8A19E199474006651A4D2E324540
32327	8	75	341	2229	\N	\N	42.350293000000001	Левашинский район, село Нижнее-Лабкомахи, Здание начальной школы		0101000020E6100000C636A968ACB547404582A966D62C4540
32345	8	75	341	3276	\N	\N	42.360267	Левашинский район, село Мусультемахи, Здание СПК им. Нурова		0101000020E6100000070C923EAD984740FD69A33A1D2E4540
32344	8	75	341	3160	\N	\N	42.397438999999999	Левашинский район, село Мекеги, Здание средней школы		0101000020E6100000BDAB1E300FBB4740D593F947DF324540
32343	8	75	341	3160	\N	\N	42.397566224159597	Левашинский район, село Мекеги, Здание дома культуры	Россия, республика Дагестан, Левашинский район, село Мекеги	0101000020E6100000E4BF401020BB474032005471E3324540
32342	8	75	341	3004	\N	\N	42.433422999999998	Левашинский район, село Леваши, Здание средней школы № 1		0101000020E6100000E9297288B8A94740C72AA5677A374540
32341	8	75	341	3004	\N	\N	42.433422999999998	Левашинский район, село Леваши, Здание средней школы № 2		0101000020E6100000E9297288B8A94740C72AA5677A374540
32340	8	75	341	3004	\N	\N	42.433422999999998	Левашинский район, село Леваши, Здание спортивного зала	Россия, республика Дагестан, Левашинский район, село Леваши	0101000020E6100000E9297288B8A94740C72AA5677A374540
32339	8	75	341	2928	\N	\N	42.422915000000003	Левашинский район, село Кутиша, Здание дома культуры	Россия, республика Дагестан, Левашинский район, село Кутиша	0101000020E61000008E3BA583F5A3474072FE261422364540
32336	8	75	341	2771	\N	\N	42.423361	Левашинский район, село Куппа, Здание основной школы	Россия, республика Дагестан, Левашинский район, село Куппа	0101000020E610000086E28E37F98F474070B378B130364540
32364	8	75	341	4291	\N	\N	42.315348	Левашинский район, село Кулибухна, Здание дома культуры	Россия, республика Дагестан, Левашинский район, село Кулибухна	0101000020E61000002EE3A6069A974740F46DC1525D284540
32335	8	75	341	2689	\N	\N	42.557206000000001	Левашинский район, село Кулецма, Здание средней школы		0101000020E6100000B91798158AA047404791B58652474540
32333	8	75	341	2571	\N	\N	42.354757999999997	Левашинский район, село Карлабко, Здание дома культуры		0101000020E610000025085740A1B2474047FFCBB5682D4540
32363	8	75	341	4207	\N	\N	42.354964000000002	Левашинский район, село Карекадани, Здание дома культуры		0101000020E61000001C412AC58E904740F1A0D9756F2D4540
32331	8	75	341	2458	\N	\N	42.398390999999997	Левашинский район, село Какамахи, Здание дома культуры	Россия, республика Дагестан, Левашинский район, село Какамахи	0101000020E610000091291F82AAA74740A702EE79FE324540
32337	8	75	341	2796	\N	\N	42.412678	Левашинский район, село Иргали, Здание основной школы		0101000020E61000006CB07092E6914740ACE3F8A1D2344540
32324	8	75	341	53882	\N	\N	42.461292	Левашинский район, село Зуримахи, Здание дома культуры		0101000020E61000007E6FD39FFDA8474006F4C29D0B3B4540
32332	8	75	341	2532	\N	\N	42.381169999999997	Левашинский район, село Дитуншимахи, Здание начальной школы		0101000020E61000002FFB75A73BA54740B01BB62DCA304540
32330	8	75	341	2433	\N	\N	42.445267000000001	Левашинский район, село Джангамахи, Здание дома культуры		0101000020E6100000E23AC61517B14740787E5182FE384540
32347	8	75	341	3383	\N	\N	42.363757999999997	Левашинский район, село Гургумахи, Здание администрации с\\с		0101000020E610000043E38920CE97474045D4449F8F2E4540
32366	8	75	341	4394	\N	\N	42.341909999999999	Левашинский район, село Цухта, Здание дома культуры		0101000020E61000000BCF4BC5C6AA47407216F6B4C32B4540
32326	8	75	341	2203	\N	\N	42.340032643234103	Левашинский район, село Верхнее-Лабкомахи, Здание дома культуры	Россия, республика Дагестан, Левашинский район, село Верхние Лабкомахи	0101000020E61000003D2CD49AE6B74740C7478B33862B4540
32328	8	75	341	53644	\N	\N	43.119010000000003	Левашинский район, село Верхнее-Убекимахи, Здание основной школы		0101000020E61000003E92921E866C4740D0F23CB83B8F4540
32318	8	75	341	53745	\N	\N	42.461292	Левашинский район, село Верхнее Аршимахи, Здание дома культуры		0101000020E61000007E6FD39FFDA8474006F4C29D0B3B4540
32320	8	75	341	1837	\N	\N	42.370327000000003	Левашинский район, село Буртанимахи, Здание начальной школы		0101000020E6100000A5828AAA5F934740B4E908E0662F4540
32323	8	75	341	1993	\N	\N	42.421996	Левашинский район, село Аялакаб, Здание дома культуры		0101000020E6100000C500892650BA47407B8505F703364540
32322	8	75	341	1969	\N	\N	42.573070000000001	Левашинский район, село Ахкент, Здание СПК		0101000020E6100000ACCABE2B82974740CC28965B5A494540
32346	8	75	341	53744	\N	\N	42.461292	Левашинский район, село Аллатемахи, Здание спортивного зала		0101000020E61000007E6FD39FFDA8474006F4C29D0B3B4540
32329	8	75	341	53514	\N	\N	42.461292	Левашинский район, село Айнакаб, Здание начальной школы		0101000020E61000007E6FD39FFDA8474006F4C29D0B3B4540
32307	8	75	9	1119	\N	\N	42.139142	Республика Дагестан,Лакский район, село, Шовкра, Здание сельского клуба		0101000020E6100000F01989D00890474001C0B167CF114540
32298	8	75	9	647	\N	\N	42.250844000000001	Республика Дагестан,Лакский район, село, Шахува, Контора колхоза	Россия, республика Дагестан, Лакский район, село Шахува	0101000020E6100000999CDA19A6944740EC32FCA71B204540
32308	8	75	9	1206	\N	\N	42.114834000000002	Республика Дагестан,Лакский район, село, Шара, Здание дома культуры		0101000020E6100000438D429259914740043C69E1B20E4540
32274	8	75	9	31776	\N	\N	42.111978000000001	Республика Дагестан,Лакский район, село Чуртах, Здание сельского клуба		0101000020E610000022A5D93C0E8B47408DEF8B4B550E4540
32295	8	75	9	367	\N	\N	42.300485000000002	Республика Дагестан,Лакский район, село, Чукна, Здание школы		0101000020E6100000D7DCD1FF728F474023F8DF4A76264540
32316	8	75	9	1648	\N	\N	42.105845000000002	Республика Дагестан,Лакский район, село, Хурхи, Здание сельской библиотеки		0101000020E61000007F1475E61E904740FAB836548C0D4540
32310	8	75	9	1312	\N	\N	42.156002000000001	Республика Дагестан,Лакский район, село, Хурукра, Здание школы		0101000020E610000008E753C72A914740280EA0DFF7134540
32309	8	75	9	1275	\N	\N	42.170304000000002	Республика Дагестан,Лакский район, село, Хури, Здание сельадминистрации	Россия, республика Дагестан, Лакский район, село Хури	0101000020E610000059147651F490474062307F85CC154540
32313	8	75	9	1501	\N	\N	42.178415999999999	Республика Дагестан,Лакский район, село, Хуна, Здание сельадминистрации	Россия, республика Дагестан, Лакский район, село Хуна	0101000020E610000083BF5FCC96944740A48AE255D6164540
32284	8	75	9	32208	\N	\N	42.093254000000002	Республика Дагестан,Лакский район,  село Хулисма, Здание сельадминистрации	Россия, республика Дагестан, Лакский район, село Хулисма	0101000020E6100000D34D621058874740501C40BFEF0B4540
32297	8	75	9	53860	\N	\N	42.123041000000001	Республика Дагестан,Лакский район, село,Харазма, Здание дома культуры		0101000020E610000049D74CBED98C47409888B7CEBF0F4540
32303	8	75	9	908	\N	\N	42.205458	Республика Дагестан,Лакский район, село, Ури, Здание сельадминистрации		0101000020E61000008F52094FE8814740CD599F724C1A4540
32299	8	75	9	666	\N	\N	42.220669999999998	Республика Дагестан,Лакский район, село, Унчукатль, Здание сельадминистрации		0101000020E61000006FF607CA6D934740AA9A20EA3E1C4540
32314	8	75	9	1542	\N	\N	42.197642999999999	Республика Дагестан,Лакский район, село, Курла, Здание сельского клуба	Россия, республика Дагестан, Лакский район, село Курла	0101000020E6100000F8A6E9B30398474044A4A65D4C194540
32294	8	75	9	380	\N	\N	42.282417000000002	Республика Дагестан,Лакский район, село, Куркли, Здание школы		0101000020E6100000FA5E43705C904740CF6A813D26244540
32296	8	75	9	472	\N	\N	42.269841	Республика Дагестан,Лакский район, село, Кунды, Здание дома культуры		0101000020E61000004084B872F69447405A0F5F268A224540
32312	8	75	9	11	\N	\N	42.168771238917302	Республика Дагестан,Лакский район, село, Хуты, Контора колхоза	Россия, республика Дагестан, Лакский район, село Кумух	0101000020E6100000799274CDE48F4740B1C1C2499A154540
32291	8	75	9	11	\N	\N	42.169260999999999	Республика Дагестан,Лакский район, село Кумух, Здание дома культуры		0101000020E6100000DA73999A048F47407FBE2D58AA154540
32292	8	75	9	207	\N	\N	42.272463999999999	Республика Дагестан,Лакский район, село, Кума, Здание дома культуры		0101000020E61000008928266F809147402EABB019E0224540
32288	8	75	9	32374	\N	\N	42.129240000000003	Республика Дагестан,Лакский район, село Кулушац, Здание сельадминистрации		0101000020E6100000664F029B738C4740E3AAB2EF8A104540
32311	8	75	9	1339	\N	\N	42.127642000000002	Республика Дагестан,Лакский район, село, Кукни, Здание школы		0101000020E610000063EDEF6C8F9447404BCCB39256104540
32290	8	75	9	32478	\N	\N	42.144029000000003	Республика Дагестан,Лакский район, село Кубра, Здание сельадминистрации	Россия, республика Дагестан, Лакский район, село Кубра	0101000020E61000007786A92D758A47407A56D28A6F124540
32286	8	75	9	32291	\N	\N	42.323694000000003	Республика Дагестан,Лакский район, село Куба, Здание дома культуры	Россия, республика Дагестан, Лакский район, село Куба	0101000020E6100000884677103B8F4740AAF413CE6E294540
32301	8	75	9	757	\N	\N	42.221465000000002	Республика Дагестан,Лакский район, село, Караша, Здание дома культуры	Россия, республика Дагестан, Лакский район, село Караша	0101000020E6100000F4893C49BA964740B51A12F7581C4540
32285	8	75	9	32266	\N	\N	42.285972000000001	Республика Дагестан,Лакский район,  село Кара, Здание сельадминистрации		0101000020E61000004D4C1762F59547402EC901BB9A244540
32304	8	75	9	1001	\N	\N	42.227660999999998	Республика Дагестан,Лакский район, село, Камахал, Здание сельадминистрации		0101000020E6100000C7293A92CB7F47408EC9E2FE231D4540
32315	8	75	9	1623	\N	\N	42.149991999999997	Республика Дагестан,Лакский район, село, Иниша, Здание сельской библиотеки		0101000020E6100000E38E37F92D9A4740B05417F032134540
32282	8	75	9	32125	\N	\N	42.032372000000002	Республика Дагестан,Лакский район,  село Бурши, Здание сельской библиотеки		0101000020E6100000AA436E861B8847402FA704C424044540
32300	8	75	9	53872	\N	\N	42.123041000000001	Республика Дагестан,Лакский район, село, Балисма, Здание дома культуры		0101000020E610000049D74CBED98C47409888B7CEBF0F4540
32293	8	75	9	244	\N	\N	42.253459999999997	Республика Дагестан,Лакский район, село, Багикла, Здание школы	Россия, республика Дагестан, Лакский район, село Багикла	0101000020E6100000ECFB7090109147400D6C956071204540
32302	8	75	9	53857	\N	\N	42.123041000000001	Республика Дагестан,Лакский район, село, Арусси, Контора колхоза		0101000020E610000049D74CBED98C47409888B7CEBF0F4540
32281	8	75	1648	32033	\N	\N	41.560600000000001	Республика Дагестан, Курахский район, сельсовет Штульский, село Штул, Здание библиотеки		0101000020E6100000CD0182397AF647409D11A5BDC1C74440
32280	8	75	1648	32033	\N	\N	41.560600000000001	Республика Дагестан, Курахский район, сельсовет Штульский, село Штул, Здание СДК		0101000020E6100000CD0182397AF647409D11A5BDC1C74440
32279	8	75	1648	31996	\N	\N	41.653748999999998	Республика Дагестан, Курахский район, сельсовет Шимихюрский, село Шимихюр, Здание СДК		0101000020E61000007427D87F9DD947407765170CAED34440
32278	8	75	1648	31943	\N	\N	41.559541000000003	Республика Дагестан, Курахский район, сельсовет Курахский, село Хюрехюр, Здание библиотеки	Россия, республика Дагестан, Курахский район, село Хюрехюр	0101000020E610000058C9C7EE02DF4740B5E21B0A9FC74440
32700	8	75	1648	20890	\N	\N	41.672510000000003	Республика Дагестан, Сулейман-Стальский район, село Хпюк, здание сельской администрации		0101000020E610000093FE5E0A0FD64740D21DC4CE14D64440
32277	8	75	1648	20890	\N	\N	41.672510000000003	Республика Дагестан, Курахский район, село Хпюк, Здание школы		0101000020E610000093FE5E0A0FD64740D21DC4CE14D64440
32276	8	75	1648	31862	\N	\N	41.619677000000003	Республика Дагестан, Курахский район, сельсовет Шимихюрский, село Хпедж, Здание СДК		0101000020E6100000D177B7B244DD4740AD8A709351CF4440
32275	8	75	1648	31810	\N	\N	41.700704000000002	Республика Дагестан, Курахский район, сельсовет Усугский, село Хвередж, Здание СДК		0101000020E6100000A37895B54DC9474094162EABB0D94440
32273	8	75	1648	31731	\N	\N	41.672341000000003	Республика Дагестан, Курахский район, сельсовет Усугский, село Усуг, Здание администрации	Россия, республика Дагестан, Курахский район, село Усуг	0101000020E61000009DB98784EFCB4740466117450FD64440
32272	8	75	1648	31683	\N	\N	41.661140000000003	Республика Дагестан, Курахский район, сельсовет Шимихюрский, село Урсун, Здание библиотеки		0101000020E610000084F4143944D84740EA094B3CA0D44440
32271	8	75	1648	53858	\N	\N	41.614783000000003	Республика Дагестан, Курахский район, сельсовет Усугский, село УКУЗ, Здание библиотеки		0101000020E6100000C7D45DD905E5474082919735B1CE4440
32270	8	75	1648	31602	\N	\N	41.601750000000003	Республика Дагестан, Курахский район, сельсовет Икринский, село Сараг, Здание библиотеки	Россия, республика Дагестан, Курахский район, село Сараг	0101000020E6100000CD77F013070248401B2FDD2406CD4440
32269	8	75	1648	31548	\N	\N	41.596761000000001	Республика Дагестан, Курахский район, сельсовет Икринский, село Ругун, Здание Школы	Россия, республика Дагестан, Курахский район, село Ругун	0101000020E6100000D3307C444CFF47409E4319AA62CC4440
32268	8	75	1648	53746	\N	\N	41.614783000000003	Республика Дагестан, Курахский район, сельсовет Моллакентский, село Моллакент, Здание СДК		0101000020E6100000C7D45DD905E5474082919735B1CE4440
32267	8	75	1648	31448	\N	\N	41.54757	Республика Дагестан, Курахский район, сельсовет Кутульский, село Кутул, Здание СДК		0101000020E61000004E9D47C5FFFB4740A72215C616C64440
32265	8	75	1648	31286	\N	\N	41.584978999999997	Республика Дагестан, Курахский район, сельсовет Курахский, село Курах, Здание Школы №2		0101000020E6100000F50F221972E4474063EC8497E0CA4440
32264	8	75	1648	31286	\N	\N	41.584978999999997	Республика Дагестан, Курахский район, сельсовет Курахский, село Курах, Здание РДК		0101000020E6100000F50F221972E4474063EC8497E0CA4440
32263	8	75	1648	53436	\N	\N	41.544842452008801	Республика Дагестан, Курахский район, село Кумук, Здание СДК	Россия, республика Дагестан, Курахский район, разруш.,полуразруш.нас.пункты Кумук	0101000020E6100000861DC6A4BFF147405EBEF561BDC54440
32262	8	75	1648	31200	\N	\N	41.598494000000002	Республика Дагестан, Курахский район, сельсовет Ашарский, село Кукваз, Здание СДК		0101000020E6100000D099B4A9BAD94740166D8E739BCC4440
32256	8	75	1648	53759	\N	\N	41.522668618951997	Республика Дагестан, Курахский район, сельсовет Кочхюрский, село Бугдатепе, Здание СДК	Россия, республика Дагестан, Курахский район, село Кочхюр	0101000020E6100000A8C821E2E6EE474007D15AD1E6C24440
32261	8	75	1648	31144	\N	\N	41.680011999999998	Республика Дагестан, Курахский район, сельсовет Гельхенский, село Квардал, Здание библиотеки		0101000020E61000007EC3448314C847409B711AA20AD74440
32259	8	75	1648	31039	\N	\N	41.558812000000003	Республика Дагестан, Курахский район, село Кабир, Здание СДК		0101000020E610000063416150A6054840624ED02687C74440
32258	8	75	1648	31076	\N	\N	41.561442999999997	Республика Дагестан, Курахский район, сельсовет Икринский, село Икра, Здание СДК		0101000020E6100000BF620D17B9014840B8C83D5DDDC74440
32257	8	75	1648	53808	\N	\N	41.659461999999998	Республика Дагестан, Курахский район, сельсовет Гельхенский, Здание СДК	Россия, республика Дагестан, Курахский район, село Гельхен	0101000020E6100000425A63D009CD4740357A354069D44440
32255	8	75	1648	30850	\N	\N	41.509504	Республика Дагестан, Курахский район, сельсовет Икринский, село Бахцуг, Здание школы		0101000020E6100000CDC98B4CC0F947403197546D37C14440
32254	8	75	1648	30802	\N	\N	41.616197999999997	Республика Дагестан, Курахский район, сельсовет Ашарский, село Ашар, Здание СДК		0101000020E6100000F698486936D5474028EE7893DFCE4440
32253	8	75	1648	30741	\N	\N	41.595075000000001	Республика Дагестан, Курахский район, сельсовет Штульский, село Ашакент, Здание СДК		0101000020E6100000E659492BBEEF474067D5E76A2BCC4440
32252	8	75	1648	53809	\N	\N	41.524344999999997	Республика Дагестан, Курахский район, сельсовет Кутульский, село Ахниг, Здание школы	Россия, республика Дагестан, Курахский район, село Ахнит	0101000020E6100000AD8A709351FF47401A69A9BC1DC34440
31788	8	75	650	53895	\N	\N	43.134551999999999	Республика Дагестан,Кумторкалинский район, с. Ново-Шангода, здание школы		0101000020E6100000F94D61A5829C474042CEFBFF38914540
32249	8	75	650	30535	\N	\N	43.295959193878403	Республика Дагестан, Кумторкалинский район, село Шамхал-янги-юрт, Здание СОШ	Россия, республика Дагестан, Кумторкалинский район, село Шамхал-Янги-Юрт	0101000020E61000005EBA490C029D47407BFA08FCE1A54540
32245	8	75	650	30332	\N	\N	43.114220000000003	Республика Дагестан, Кумторкалинский район, село Учкент, Здание Дома культуры		0101000020E61000002409C215508A47404A46CEC29E8E4540
31785	8	75	650	8355	\N	\N	43.143045000000001	Республика Дагестан,Кумторкалинский район, Уллубиевка, здание школы		0101000020E6100000AFB48CD47B9247409C6D6E4C4F924540
32244	8	75	650	30280	\N	\N	43.051225000000002	Республика Дагестан, Кумторкалинский район, поселок Тюбе, Здание СОШ	Россия, республика Дагестан, Кумторкалинский район, село Тюбе	0101000020E61000001E32E54350A547406ADE718A8E864540
32247	8	75	650	30419	\N	\N	43.127532000000002	Республика Дагестан, Кумторкалинский район, село Темиргое, Здание СОШ		0101000020E610000068EC4B361E924740C498F4F752904540
31784	8	75	650	53524	\N	\N	43.1223560577615	Республика Дагестан,Кумторкалинский район, пос. Сафарали, СДК	Россия, республика Дагестан, Кумторкалинский район, село Сафар-Али	0101000020E61000003465A71FD49B4740153C855CA98F4540
33024	8	75	650	4334	\N	\N	43.318472100157202	Республика Дагестан, Хунзахский район, село Самилах, здание СДК	Россия, республика Дагестан, Кумторкалинский район, село Самилах	0101000020E61000002E01F8A7548747408A58C4B0C3A84540
33253	8	75	650	53562	\N	\N	43.077370560433003	кутан Нов.Урада	Россия, республика Дагестан, Кумторкалинский район, село Новая Урада	0101000020E610000050189469349147405454FD4AE7894540
33030	8	75	650	53527	\N	\N	43.262447909364802	Республика Дагестан, Хунзахский район, село Красное, здание СДК	Россия, республика Дагестан, Кумторкалинский район, село Красное Село	0101000020E61000007BDAE1AFC98C4740477364E597A14540
32243	8	75	650	53428	32916	\N	43.027281616129301	Республика Дагестан, Кумторкалинский район, сельсовет Коркмаскалинский, Свердлова, Школа		0101000020E61000008D9B1A683EA547407EE200FA7D834540
32242	8	75	650	53428	32916	\N	43.026840819676003	Республика Дагестан, Кумторкалинский район, сельсовет Коркмаскалинский, Свердлова, Клуб	Россия, республика Дагестан, Кумторкалинский район, село Коркмаскала	0101000020E61000001327F73B14A547409198A0866F834540
33042	8	75	650	5296	\N	\N	43.293227000000002	Республика Дагестан, Хунзахский район, село Квами, здание правления СПК	Россия, республика Дагестан, Кумторкалинский район, село Квами	0101000020E6100000E3FC4D2844824740F0A65B7688A54540
32246	8	75	650	30392	\N	\N	43.099324000000003	Республика Дагестан, Кумторкалинский район, село Алмало, Здание СОШ		0101000020E610000072FE2614229C47409DDA19A6B68C4540
32248	8	75	650	4839	\N	\N	43.285272999999997	Республика Дагестан, Кумторкалинский район, село Аджидада, Здание СОШ		0101000020E6100000357C0BEBC689474045B75ED383A44540
31715	8	75	650	4839	\N	\N	43.285272999999997	Республика Дагестан, Кумторкалинский район, село Аджидада, здание клуба		0101000020E6100000357C0BEBC689474045B75ED383A44540
32232	8	75	1867	53517	\N	\N	42.105416876808299	Республика Дагестан, Кулинский район, село Цыйша, здание СДК, здание СДК	Россия, республика Дагестан, Кулинский район, село Цыйши	0101000020E610000022E010AAD49C4740A2B8E34D7E0D4540
32237	8	75	1867	53855	\N	\N	42.078504872710504	Республика Дагестан, Кулинский район, село Цушар, здание Администрации, здание Администрации	Россия, республика Дагестан, Кулинский район, село Цущар	0101000020E6100000596DFE5F7592474047C9AB730C0A4540
32238	8	75	1867	29993	\N	\N	42.040053999999998	Республика Дагестан, Кулинский район, село Цовкра-2, здание СДК, здание СДК		0101000020E610000005BF0D315E93474078094E7D20054540
32228	8	75	1867	29539	\N	\N	42.059061999999997	Республика Дагестан, Кулинский район, село Цовкра-1, здание СДК, здание СДК		0101000020E6100000D881734694A24740DA37F7578F074540
32240	8	75	1867	29389	\N	\N	41.992317	Республика Дагестан, Кулинский район, село Хосрех, ферма №3 здание Ветучастка, ферма №3 здание Ветучастка		0101000020E6100000AA46AF0628A34740E621533E04FF4440
32225	8	75	1867	29389	\N	\N	41.992317	Республика Дагестан, Кулинский район, село Хосрех, здание СДК, здание СДК		0101000020E6100000AA46AF0628A34740E621533E04FF4440
32236	8	75	1867	29913	\N	\N	42.120238999999998	Республика Дагестан, Кулинский район, село Хойхи, здание СДК, здание СДК		0101000020E61000006475ABE7A4974740145AD6FD630F4540
32231	8	75	1867	53501	\N	\N	42.093721327444499	Республика Дагестан, Кулинский район, сельсовет Каялинский, село Хайми, здание СДК, здание СДК	Россия, республика Дагестан, Кулинский район, село Хойми	0101000020E610000029CC7B9C699A474066F9BA0CFF0B4540
32227	8	75	1867	53807	\N	\N	42.046909403719901	Республика Дагестан, Кулинский район, село Сумбатль, здание СДК, здание СДК	Россия, республика Дагестан, Кулинский район, село Сумбаталь	0101000020E6100000842D76FBAC9C4740AC71361D01064540
32234	8	75	1867	29808	\N	\N	42.121543000000003	Республика Дагестан, Кулинский район, сельсовет Вихлинский, село Сукиях, здание СДК, здание СДК		0101000020E6100000098CF50D4C9E4740640795B88E0F4540
32241	8	75	1867	29437	\N	\N	42.017167999999998	Республика Дагестан, Кулинский район, село Кули, здание СПК племхоз Кулинский, здание СПК племхоз Кулинский		0101000020E6100000018750A5669F4740D4449F8F32024540
32226	8	75	1867	29437	\N	\N	42.017167999999998	Республика Дагестан, Кулинский район, село Кули, здание СДК, здание СДК		0101000020E6100000018750A5669F4740D4449F8F32024540
32230	8	75	1867	53894	\N	\N	42.075284066244897	Республика Дагестан, Кулинский район, сельсовет Каялинский, здание СДК, здание СДК		0101000020E610000072A774B0FE994740BFF4F6E7A2094540
32235	8	75	1867	29848	\N	\N	42.139603999999999	Республика Дагестан, Кулинский район, село Кани, здание СДК, здание СДК	Россия, республика Дагестан, Кулинский район, село Кани	0101000020E6100000CD1FD3DA3498474005323B8BDE114540
32233	8	75	1867	53583	\N	\N	42.126571209922901	Республика Дагестан, Кулинский район, сельсовет Вихлинский, здание СДК, здание СДК	Россия, республика Дагестан, Кулинский район, село Вихли	0101000020E610000049BC3C9D2B9C47409ECF807A33104540
32229	8	75	1867	29573	\N	\N	42.074371334764102	Республика Дагестан, Кулинский район, село Вачи, здание Администрации, здание Администрации	Россия, республика Дагестан, Кулинский район, село Вачи	0101000020E6100000A0FF1EBC769B4740AA622AFD84094540
32434	8	75	7297	53738	\N	\N	42.968150289657999	"Республика Дагестан, город Махачкала, Кировский район, поселок Ленинкент, Центр - помещение школы ""Перспектива"""	Россия, республика Дагестан, Махачкала городской округ, поселок городского типа Ленинкент	0101000020E6100000B03DB32440AD4740ABCFD556EC7B4540
32443	8	75	7297	53682	\N	\N	42.976722000000002	Республика Дагестан, город Махачкала, Кировский район, село Богатыревка, Центр - помещение Клуб		0101000020E61000001F4DF564FEBD474051A4FB39057D4540
31749	8	75	677	53890	\N	\N	43.905699559946903	Кизлярский район,сельсовет Александрийский, кутан Арбакол, Здание агрофирмы	Россия, республика Дагестан, Кизлярский район	0101000020E610000034D8D479548E47405DFE43FAEDF34540
32205	8	75	677	28495	\N	\N	43.862603	Республика Дагестан, Кизлярский район,  село им.Кирова, Здание СДК	Россия, республика Дагестан, Кизлярский район, село имени Кирова	0101000020E6100000D384ED27635A47403B376DC669EE4540
32178	8	75	677	27252	\N	\N	43.848861999999997	Республика Дагестан, Кизлярский район, село им. Жданова, здание Администрации		0101000020E6100000973C9E961F58474098689082A7EC4540
32206	8	75	677	28522	\N	\N	43.951417999999997	Республика Дагестан, Кизлярский район, село Ясная Поляна, Здание СДК		0101000020E6100000572250FD83624740B169A510C8F94540
32203	8	75	677	28388	\N	\N	43.816347	Республика Дагестан, Кизлярский район, село Южное, Здание школы		0101000020E6100000BB7F2C44875C47400798F90E7EE84540
32172	8	75	677	53563	\N	\N	44.018594999999998	Республика Дагестан, Кизлярский район, село Юбилейное, Здание СДК		0101000020E61000000DE36E10AD7D47403F6F2A5261024640
32197	8	75	677	28103	\N	\N	43.944474	Республика Дагестан, Кизлярский район, село Черняевка, Здание Администрации		0101000020E6100000FF06EDD5C78347400EF62686E4F84540
32201	8	75	677	28294	\N	\N	43.940728999999997	Республика Дагестан, Кизлярский район, село Цветковка, Здание СДК		0101000020E6100000F8AA9509BF6A47400BB3D0CE69F84540
32207	8	75	677	28571	\N	\N	43.928984999999997	Республика Дагестан, Кизлярский район,  село Хуцеевка	Россия, республика Дагестан, Кизлярский район, село Хуцеевка	0101000020E6100000E44EE960FD634740BEBC00FBE8F64540
32195	8	75	677	28024	\N	\N	44.310988000000002	Республика Дагестан, Кизлярский район, село Тушиловка, Здание Администрации		0101000020E6100000BDFDB968C870474067B96C74CE274640
32192	8	75	677	27897	\N	\N	43.895021	Республика Дагестан, Кизлярский район, село Степное, Здание школы		0101000020E6100000793C2D3F703F4740DA1D520C90F24540
32176	8	75	677	53846	\N	\N	43.943508704272297	Республика Дагестан, Кизлярский район, село Старый Терек, Здание конторы колхоза		0101000020E6100000AED7F4A0A0A44740A73D25E7C4F84540
32202	8	75	677	53848	\N	\N	43.983497202529399	Республика Дагестан, Кизлярский район, село Старая Серебряковка, Здание школы	Россия, республика Дагестан, Кизлярский район, село Серебряковка	0101000020E610000031B610E4A06A4740685BCD3AE3FD4540
32199	8	75	677	28206	\N	\N	43.972538999999998	Республика Дагестан, Кизлярский район, село Сар-Сар, Здание клуба		0101000020E6100000FCDF1115AA894740D28A6F287CFC4540
32157	8	75	677	26297	\N	\N	43.900081	Республика Дагестан, Кизлярский район,  село Сангиши, Здание школы, Здание школы		0101000020E61000001B48179B568447402060ADDA35F34540
32181	8	75	677	27381	\N	\N	43.779629999999997	Республика Дагестан, Кизлярский район, село Рыбалко, Здание школы		0101000020E6100000B08C0DDDEC534740807D74EACAE34540
32204	8	75	677	28445	\N	\N	43.786867999999998	Республика Дагестан, Кизлярский район, село Речное, Здание д/сада		0101000020E6100000DE3829CC7B5C47406C223317B8E44540
32173	8	75	677	53679	\N	\N	44.018594999999998	Республика Дагестна, Кизлярский район, ссело Пролетарское, Здание СДК		0101000020E61000000DE36E10AD7D47403F6F2A5261024640
32165	8	75	677	53834	\N	\N	43.882924000000003	Республика Дагестан, Кизлярский район, хутор Персидский, Здание школы	Россия, республика Дагестан, Кизлярский район, село Персидское	0101000020E61000008DEE2076A6724740406D54A703F14540
32169	8	75	677	26871	\N	\N	43.918545000000002	Республика Дагестан, Кизлярский район, село Первомайское, Здание школы		0101000020E610000055336B29205B4740C173EFE192F54540
32171	8	75	677	26949	\N	\N	43.885770000000001	Республика Дагестан, Кизлярский район, село Первокизлярское, Здание школы		0101000020E6100000A60F5D50DF56474093E34EE960F14540
32193	8	75	677	27962	\N	\N	44.050311999999998	Республика Дагестан, Кизлярский район, село Огузер, Здание СДК		0101000020E6100000C5E40D30F3874740554CA59F70064640
32177	8	75	677	27221	\N	\N	43.769188999999997	Республика Дагестан, Кизлярский район, село Новый Бирюзяк, Здание СДК		0101000020E6100000BB97FBE428A64740B2B8FFC874E24540
31751	8	75	677	6715	\N	\N	44.143915999999997	сел.Новый Бухты, СДК		0101000020E61000005DE15D2EE27B474081AFE8D66B124640
32190	8	75	677	53747	\N	\N	43.864916283185302	Республика Дагестан, Кизлярский район, село Номонастырское, Здание школы	Россия, республика Дагестан, Кизлярский район, село Новомонастырское	0101000020E61000006364C91CCB4D4740C1E44691B5EE4540
32191	8	75	677	53776	\N	\N	43.885628382048601	Республика Дагестан, Кизлярский район, село Нокрестьяновка, Здание школы	Россия, республика Дагестан, Кизлярский район, село Новокрестьяновское	0101000020E610000003999D45EF484740003620425CF14540
32188	8	75	677	32883	\N	\N	43.864643999999998	Республика Дагестан, Кизлярский район, село Новокохановка, Здание Администрации		0101000020E61000000C3CF71E2E534740605793A7ACEE4540
32164	8	75	677	53937	\N	\N	43.849024	Республика Дагестан, Кизлярский район, село Новогладовка, Здание школы	Россия, республика Дагестан, Кизлярский район, село Новогладковка	0101000020E6100000F11131259272474072C284D1ACEC4540
32200	8	75	677	53963	\N	\N	43.907992308304102	Республика Дагестан, Кизлярский район, село Нововладимировка, Здание школы	Россия, республика Дагестан, Кизлярский район, село Нововладимирское	0101000020E61000009E7E5017297A4740CB83F41439F44540
32194	8	75	677	28013	\N	\N	43.991728530605002	"Республика Дагестан, Кизлярский район, село Новая Серебярковка, Здание совхоза ""Мареновский"""	Россия, республика Дагестан, Кизлярский район, село Новая Серебряковка	0101000020E6100000B491EBA6947D474055BFD2F9F0FE4540
32185	8	75	677	27615	\N	\N	43.828541999999999	Республика Дагестан, Кизлярский район, село Некрасовка, Здание СДК		0101000020E61000005CAFE9414179474064AE0CAA0DEA4540
32099	8	75	1709	53736	\N	\N	42.414901	Республика Дагестан, Каякентский район, сельсовет Сагаси-Дейбукский, с.Сагаси-Дейбук, здание школы		0101000020E610000047E7FC14C7F34740F209D9791B354540
32170	8	75	677	53835	\N	\N	43.928531	Республика Дагестан, Кизлярский район,  село Михеевка, Здание школы	Россия, республика Дагестан, Кизлярский район, село Михеевское	0101000020E6100000C9AF1F62835547403D29931ADAF64540
32160	8	75	677	53597	\N	\N	43.901433432088801	Республика Дагестан, Кизлярский район, село Малая Козыревка, Здание школы	Россия, республика Дагестан, Кизлярский район, село Малое Козыревское	0101000020E61000003AB2F2CB606847408044132862F34540
32186	8	75	677	27633	\N	\N	44.021349999999998	Республика Дагестан, Кизлярский район, село Малая Арешевка, Здание СДК		0101000020E610000057B5A4A31C68474082E2C798BB024640
32162	8	75	677	53833	\N	\N	44.122585451006103	Республика Дагестан, Кизлярский район, село Макаровка, Здание школы	Россия, республика Дагестан, Кизлярский район, село Макаровское	0101000020E61000001405FA449E72474076FD82DDB00F4640
32198	8	75	677	53605	\N	\N	43.937770441502401	Республика Дагестан, Кизлярский район,  село Курдюки, Здание СДК	Россия, республика Дагестан, Кизлярский район, село Курдюковское	0101000020E610000066DD3F16A2794740C095ECD808F84540
32179	8	75	677	27297	\N	\N	43.860146999999998	Республика Дагестан,  Кизлярский район, село Красный Восход, Здание Администрации		0101000020E61000007156444DF45747405260014C19EE4540
32189	8	75	677	32830	\N	\N	43.846125000000001	Республика Дагестан, Кизлярский район, село Краснооктябрское, Здание почты		0101000020E61000002FE1D05B3C544740FCA9F1D24DEC4540
32180	8	75	677	32830	\N	\N	43.846125000000001	Республика Дагестан, Кизлярский район, село им. Шаумяна, Здание школы		0101000020E61000002FE1D05B3C544740FCA9F1D24DEC4540
32174	8	75	677	7544	\N	\N	43.975769999999997	Республика Дагестан, Кизлярский район, село Крайновка, Здание Администрации		0101000020E61000004C530438BDAF47407E350708E6FC4540
31770	8	75	677	7544	\N	\N	43.979131256423003	Республика Дагестан, Кизлярский район, селение Крайновка, здание агрофирмы	Россия, республика Дагестан, Кизлярский район, село Крайновка	0101000020E61000009B3C65355DAF4740F9BF232A54FD4540
31768	8	75	677	7544	\N	\N	43.975769999999997	Республика Дагестан, Кизлярский район,с.Крайновка, СДК		0101000020E61000004C530438BDAF47407E350708E6FC4540
32167	8	75	677	26759	\N	\N	43.900121908922998	"Республика Дагестан, Кизлярский район, село Косякино, Здание конторы АО ""Дружба"""	Россия, республика Дагестан, Кизлярский район, село Косякино	0101000020E6100000075DC2A1B75647407F349C3237F34540
32224	8	75	677	53685	33079	\N	43.976787999999999	Республика Дагестан, город Кизляр, рабочий поселок Комсомольский, Советская, 19	Россия, республика Дагестан, Кизлярский район, поселок городского типа Комсомольский	0101000020E61000000A48FB1F605947400890A16307FD4540
32175	8	75	677	27110	\N	\N	43.958719000000002	Республика Дагестан, Кизлярский район, село Коллективизатор, Здание рыбконторы	Россия, республика Дагестан, Кизлярский район, село Коллективизатор	0101000020E61000000EBE30992AB24740E486DF4DB7FA4540
32183	8	75	677	27474	\N	\N	43.816268999999998	Республика Дагестан, Кизлярский район, село Кардоновка, Здание СДК		0101000020E61000005E143DF0316C47408BDEA9807BE84540
31791	8	75	677	53928	\N	\N	44.018594999999998	Республика Дагестан, Кизлярский район, Калантар, здание агрофирмы		0101000020E61000000DE36E10AD7D47403F6F2A5261024640
32159	8	75	677	26402	\N	\N	43.893799999999999	Республика Дагестан, Кизлярский район, село им.К.Маркса, Здание школы, Здание школы		0101000020E61000002C9ACE4E066547401895D40968F24540
31714	8	75	677	53889	\N	\N	44.018594999999998	Республика Дагестан, Кизлярский район, село Зеленый бугор, здание клуба		0101000020E61000000DE36E10AD7D47403F6F2A5261024640
32182	8	75	677	27450	\N	\N	43.763069999999999	Республика Дагестан, Кизлярский район, село Заречное, Здание СДК		0101000020E6100000D120054F214B474084471B47ACE14540
32155	8	75	677	26184	\N	\N	43.841053000000002	Республика Дагестан, Кизлярский район, село Ефимовка, Здание школы, Здание школы		0101000020E61000008BA548BE12664740F299EC9FA7EB4540
32184	8	75	677	53529	\N	\N	44.018594999999998	Республика Дагестан, Кизлярский район, село Дагестанское, Здание школы		0101000020E61000000DE36E10AD7D47403F6F2A5261024640
32187	8	75	677	53743	\N	\N	44.037913161059002	Республика Дагестан, Кизлярский район, село Вышеталовка, Здание школы	Россия, республика Дагестан, Тарумовский район, село Вышеталовка	0101000020E61000003602F1BA7E5D4740F08B4B55DA044640
32166	8	75	677	26741	\N	\N	43.899464000000002	Республика Дагестан, Кизлярский район, село Вперед, Здание школы		0101000020E6100000EB7420EBA95B4740F5F6E7A221F34540
32196	8	75	677	28089	\N	\N	44.329123000000003	Республика Дагестан, Кизлярский район, село Брянск, Здание Администрации		0101000020E6100000B2BAD573D27D474043AED4B3202A4640
32168	8	75	677	53609	\N	\N	44.017218890469799	Республика Дагестан, Кизлярский район, село Бондареновка, Здание школы	Россия, республика Дагестан, Кизлярский район	0101000020E610000069C36169E07D474056EF703B34024640
32158	8	75	677	53708	\N	\N	43.898628046173599	Республика Дагестан, Кизлярский район, село Б.Бредихин, Здание СДК, Здание СДК	Россия, республика Дагестан, Кизлярский район, село Большебредихинское	0101000020E61000007825C9737D6D47408CA2073E06F34540
32163	8	75	677	53735	\N	\N	43.866315062227102	Республика Дагестан, Кизлярский район, село Большая Задоевка, Здание д/сада	Россия, республика Дагестан, Кизлярский район, село Большезадоевское	0101000020E6100000A54FABE80F6947406284F068E3EE4540
32161	8	75	677	26469	\N	\N	44.11504	Республика Дагестан, Кизлярский район село Б.Арешевка, Здание школы		0101000020E61000004754A86E2E764740ADDD76A1B90E4640
32090	8	75	1709	53674	\N	\N	42.414901	Республика Дагестан, Каякентский район, сельсовет Каякентский, с.Кулкам, здание школы		0101000020E610000047E7FC14C7F34740F209D9791B354540
31763	8	75	677	26469	\N	\N	44.11504	Республика Дагестан, Кизлярский район, селение Большая Арешевка, здание агрофирмы	Россия, республика Дагестан, Кизлярский район, село Большая Арешевка	0101000020E61000004754A86E2E764740ADDD76A1B90E4640
32156	8	75	677	53686	\N	\N	43.905013669486301	Республика Дагестан, Кизлярский район, село Александрия, Здание совхоза, Здание совхоза	Россия, республика Дагестан, Кизлярский район, село Александрийская	0101000020E6100000855B3E92929047400936AE7FD7F34540
32154	8	75	677	25857	\N	\N	43.844589999999997	Республика Дагестан, Кизлярский район, село Аверьяновка, Здание СДК, Здание СДК		0101000020E610000042D0D1AA96604740AA436E861BEC4540
31488	8	75	677	25857	\N	\N	43.844589999999997	Республика Дагестан, с. Аверьяновка Кизлярский район, дом. пред СПК		0101000020E610000042D0D1AA96604740AA436E861BEC4540
32130	8	75	653	25066	\N	\N	43.200063	Республика Дагестан, Кизилюртовский район, cело Шушановка	Россия, республика Дагестан, Кизилюртовский район, село Шушановка	0101000020E6100000DFE17668587E4740E01115AA9B994540
32133	8	75	653	25185	\N	\N	43.304932000000001	Республика Дагестан, Кизилюртовский район, cело Чонтаул	Россия, республика Дагестан, Кизилюртовский район, село Чонтаул	0101000020E610000036E9B6442E6E47407FC0030308A74540
32132	8	75	653	53532	\N	\N	42.2071032497403	Республика Дагестан, Кизилюртовский район, cело  Ханар	Россия, республика Дагестан, Лакский район, разрушен.,полуразр.нас.пункты Ханар	0101000020E61000000FB6D8EDB38A4740A5F3E159821A4540
32131	8	75	653	53684	\N	\N	43.2174492837092	Республика Дагестан, Кизилюртовский район, cело Султанянгиюрт	Россия, республика Дагестан, Кизилюртовский район, село Султан-Янгиюрт	0101000020E61000005704FF5BC96E474022C66B5ED59B4540
32116	8	75	653	24414	\N	\N	43.080910000000003	Республика Дагестан, Кизилюртовский район, cело ст. Миатли	Россия, республика Дагестан, Кизилюртовский район, село Старый Миатли	0101000020E61000008505F7031E6A4740AEF545425B8A4540
32129	8	75	653	53556	\N	\N	43.183918759235503	Республика Дагестан, Кизилюртовский район, cело Стальск (Келеб)	Россия, республика Дагестан, Кизилюртовский район, село Стальское	0101000020E610000044F81741637C4740780E65A88A974540
32128	8	75	653	53556	\N	\N	43.185175409328998	Республика Дагестан, Кизилюртовский район, cело Ново-Стальск	Россия, республика Дагестан, Кизилюртовский район, село Стальское	0101000020E6100000118FC4CBD37B4740B6847CD0B3974540
32127	8	75	653	53556	\N	\N	43.185174918646801	Республика Дагестан, Кизилюртовский район, cело Стальск	Россия, республика Дагестан, Кизилюртовский район, село Стальское	0101000020E6100000D28BDAFD2A7C4740B6847CD0B3974540
32125	8	75	653	24833	\N	\N	43.158067000000003	Республика Дагестан, Кизилюртовский район, cело Новый Чиркей	Россия, республика Дагестан, Кизилюртовский район, село Новый Чиркей	0101000020E6100000F38FBE49D3864740D6C9198A3B944540
32124	8	75	653	24833	\N	\N	43.158255761899298	Республика Дагестан, Кизилюртовский район, cело Новочиркей	Россия, республика Дагестан, Кизилюртовский район, село Новый Чиркей	0101000020E61000003E5E488787864740A9328CBB41944540
32113	8	75	653	24255	\N	\N	43.193497000000001	Республика Дагестан, Кизилюртовский район, cело Гадари	Россия, республика Дагестан, Кизилюртовский район, село Новые Гадари	0101000020E6100000F2D1E28C61624740E36F7B82C4984540
32121	8	75	653	24667	\N	\N	43.268241000000003	Республика Дагестан, Кизилюртовский район, cело Нечаевка	Россия, республика Дагестан, Кизилюртовский район, село Нечаевка	0101000020E6100000CFF4126399744740223999B855A24540
32122	8	75	653	24687	\N	\N	43.271405000000001	Республика Дагестан, Кизилюртовский район, cело Мацеевка	Россия, республика Дагестан, Кизилюртовский район, село Мацеевка	0101000020E6100000732D5A80B67D4740467C2766BDA24540
32120	8	75	653	24610	\N	\N	43.174242999999997	Республика Дагестан, Кизилюртовский район, cело Кульзеб	Россия, республика Дагестан, Кизилюртовский район, село Кульзеб	0101000020E6100000244223D8B8804740494739984D964540
32118	8	75	653	53557	\N	\N	43.199124388990398	Республика Дагестан, Кизилюртовский район, cело Комсомольская	Россия, республика Дагестан, Кизилюртовский район, село Комсомольское	0101000020E6100000AB4203B16C724740A2EC2DE57C994540
32117	8	75	653	24439	\N	\N	43.239283999999998	Республика Дагестан, Кизилюртовский район, cело Кироваул	Россия, республика Дагестан, Кизилюртовский район, село Кироваул	0101000020E6100000001B1021AE6C4740603AADDBA09E4540
33060	8	75	653	6256	\N	\N	43.207110329883498	Республика Дагестан, Хунзахский район, село Аркида, здание НШ	Россия, республика Дагестан, Кизилюртовский район, село Аркида	0101000020E610000018EAB0C22D87474058569A94829A4540
32110	8	75	653	24121	\N	\N	43.378771	Республика Дагестан, Кизилюртовский район, cело Акнада, Акнадинская СОШ		0101000020E6100000FDA204FD857447402CD670917BB04540
33025	8	75	653	4382	\N	\N	43.353689000000003	Республика Дагестан, Хунзахский район, село Акаро, здание ОШ		0101000020E61000008A9125732C7D47403CFA5FAE45AD4540
32114	8	75	653	53566	\N	\N	43.245063999999999	Республика Дагестан, Кизилюртовский район, cело Новозубутли		0101000020E6100000768BC058DF764740A6B6D4415E9F4540
32123	8	75	653	53683	\N	\N	43.245063999999999	Республика Дагестан, Кизилюртовский район, cело Нижнечирюрт		0101000020E6100000768BC058DF764740A6B6D4415E9F4540
32119	8	75	653	53554	\N	\N	43.245251720224097	Республика Дагестан, Кизилюртовский район, cело Комсомолец	Россия, республика Дагестан, Кизилюртовский район	0101000020E610000049D74CBED9764740A9A3E36A649F4540
32112	8	75	653	53587	\N	\N	43.245063999999999	Республика Дагестан, Кизилюртовский район, cело Зубутли-Миатли		0101000020E6100000768BC058DF764740A6B6D4415E9F4540
32098	8	75	1709	23516	\N	\N	42.407206000000002	"Республика Дагестан, Каякентский район, село Утамыш, здание ГУП ""Утамышский"""		0101000020E61000005C7347FFCBDF4740145E82531F344540
32095	8	75	1709	23362	\N	\N	42.385525999999999	"Республика Дагестан, Каякентский район, село Усемикент, здание ГУП ""Усемикентский"""		0101000020E6100000118B187618EF4740FCE07CEA58314540
32103	8	75	1709	23661	\N	\N	42.49494	Республика Дагестан, Каякентский район, село Первомайское, здание ПСШ №1		0101000020E6100000A987687407F34740BABDA4315A3F4540
32102	8	75	1709	23661	\N	\N	42.49494	Республика Дагестан, Каякентский район, село Первомайское, здание ПСШ №2	Россия, республика Дагестан, Каякентский район, село Первомайское	0101000020E6100000A987687407F34740BABDA4315A3F4540
32101	8	75	1709	23661	\N	\N	42.49494	Республика Дагестан, Каякентский район, село Первомайское, здание СДЮСШ		0101000020E6100000A987687407F34740BABDA4315A3F4540
32100	8	75	1709	23649	\N	\N	42.410494	Республика Дагестан, Каякентский район, сельсовет Сагаси-Дейбукский, с.Дейбук, здание СДК		0101000020E6100000FF7A8505F7F94740249A40118B344540
32105	8	75	1709	23844	\N	\N	42.297336999999999	Республика Дагестан, Каякентский район, сельсовет Нововикринский, с.Новые Викри, здание СДК		0101000020E61000008FDFDBF467FF4740047289230F264540
32085	8	75	1709	22875	\N	\N	42.387419640477198	Республика Дагестан, Каякентский район, сельсовет Новокаякентский, здание ЖДС	Россия, республика Дагестан, Каякентский район, село Новокаякент	0101000020E6100000BEA59C2FF6FC47407DE882FA96314540
32088	8	75	1709	22875	33174	\N	42.386963999999999	Республика Дагестан, Каякентский район, сельсовет Новокаякентский, с.Новокаякент, мкр.Гоктёбе, здание школы		0101000020E610000003EACDA8F9FC47405B5D4E0988314540
32086	8	75	1709	22875	33171	\N	42.386963999999999	Республика Дагестан, Каякентский район, сельсовет Новокаякентский, с.Новокаякент, мкр. Сельхозтехника, здание Ясли-сада		0101000020E610000003EACDA8F9FC47405B5D4E0988314540
32084	8	75	1709	22875	33038	\N	42.386963999999999	Республика Дагестан, Каякентский район, сельсовет Новокаякентский, с.Новокаякент, Новая, здание РДК		0101000020E610000003EACDA8F9FC47405B5D4E0988314540
31442	8	75	1709	53793	\N	\N	42.414901	"Республика Дагестан, Каякентский район, кутан МУП ""Тпигский"", кутан МУП ""Тпигский"""		0101000020E610000047E7FC14C7F34740F209D9791B354540
31443	8	75	1709	53859	\N	\N	42.414901	"Республика Дагестан, Каякентский район, кутан МУП ""Агульский"""		0101000020E610000047E7FC14C7F34740F209D9791B354540
32094	8	75	1709	23201	\N	\N	42.387183999999998	Республика Дагестан, Каякентский район, сельсовет Каякентский, с.Каякент, здание КСШ №3		0101000020E61000007FA0DCB6EFF3474069C4CC3E8F314540
32093	8	75	1709	23201	\N	\N	42.386738992042503	Республика Дагестан, Каякентский район, сельсовет Каякентский, с.Каякент, здание КСШ №2	Россия, республика Дагестан, Каякентский район, село Каякент	0101000020E61000005B5CE333D9F347403B8BDEA980314540
32092	8	75	1709	23201	\N	\N	42.387183999999998	Республика Дагестан, Каякентский район, сельсовет Каякентский, с.Каякент, здание СДК		0101000020E61000007FA0DCB6EFF3474069C4CC3E8F314540
32091	8	75	1709	23201	\N	\N	42.387183999999998	Республика Дагестан, Каякентский район, сельсовет Каякентский, с.Каякент, здание КСШ №1		0101000020E61000007FA0DCB6EFF3474069C4CC3E8F314540
32087	8	75	1709	53612	\N	\N	42.5144185306957	Республика Дагестан, Каякентский район, село Каранайаул, здание школы	Россия, республика Дагестан, Каякентский район, село Каранай-Аул	0101000020E61000000C01C0B167ED474073B8567BD8414540
32109	8	75	1709	24040	\N	\N	42.249628999999999	Республика Дагестан, Каякентский район, село Капкайкент, здание школы		0101000020E6100000F6D4EAABABE647400C91D3D7F31F4540
32089	8	75	1709	23124	\N	\N	42.469465999999997	Республика Дагестан, Каякентский район, сельсовет Новокаякентский, с.Инчхе, здание школы		0101000020E6100000101FD8F15FF84740BE4A3E76173C4540
32106	8	75	1709	23886	\N	\N	42.241833	Республика Дагестан, Каякентский район, село Дружба, здание СДК		0101000020E6100000359A5C8C81FF4740FA0B3D62F41E4540
32108	8	75	1709	24016	\N	\N	42.263002	Республика Дагестан, Каякентский район, село Джаванкент, здание СДК	Россия, республика Дагестан, Каякентский район, село Джаванкент	0101000020E61000002F34D769A4E747402C64AE0CAA214540
32104	8	75	1709	23793	\N	\N	42.347295000000003	Республика Дагестан, Каякентский район, село Герга, здание СДК		0101000020E61000001E6CB1DB67FB47403C889D29742C4540
32107	8	75	1709	23951	\N	\N	42.258550634512297	Республика Дагестан, Каякентский район, село Башлыкент, здание СДК	Россия, республика Дагестан, Каякентский район, село Башлыкент	0101000020E6100000DE3B6A4C88EB47408EACFC3218214540
32097	8	75	1709	23430	\N	\N	42.342576999999999	"Республика Дагестан, Каякентский район, сельсовет Алхаджакентский, с.Алхаджакент, здание СПК ""Алходжакентский"""		0101000020E61000002C4833164DE547404FAE2990D92B4540
32096	8	75	1709	23430	\N	\N	42.339441023141703	Республика Дагестан, Каякентский район, сельсовет Алхаджакентский, с.Алхаджакент, здание СДК	Россия, республика Дагестан, Каякентский район, село Алхаджакент	0101000020E6100000D9B3E73235E54740F5F57CCD722B4540
32054	8	75	1621	53676	\N	\N	42.688729940236797	Республика Дагестан, Карабудахкентский район, село Уллубийаул, Дом Культура	Россия, республика Дагестан, Карабудахкентский район	0101000020E61000000B410E4A98C5474015E3FC4D28584540
32041	8	75	1621	20782	\N	\N	42.740271999999997	Республика Дагестан, Карабудахкентский район, село Параул, Школа		0101000020E6100000DCD5ABC8E8AC47407F129F3BC15E4540
32040	8	75	1621	20782	33007	\N	42.740271999999997	Республика Дагестан, Карабудахкентский район, село Параул, изиева, Школа		0101000020E6100000DCD5ABC8E8AC47407F129F3BC15E4540
32039	8	75	1621	20782	33115	\N	42.740271999999997	Республика Дагестан, Карабудахкентский район, село Параул, Изиева, Школа		0101000020E6100000DCD5ABC8E8AC47407F129F3BC15E4540
32058	8	75	1621	21687	\N	\N	42.734986999999997	Республика Дагестан, Карабудахкентский район, село Манаскент, Школа		0101000020E6100000F7ADD689CBD7474019FED30D145E4540
32057	8	75	1621	53677	\N	\N	42.727546979184403	Республика Дагестан, Карабудахкентский район, поселок Манас, Дом кульиура	Россия, республика Дагестан, Карабудахкентский район, поселок городского типа Манаскент	0101000020E6100000117349D576D74740C6A69542205D4540
32056	8	75	1621	53677	\N	\N	42.728987931210902	Республика Дагестан, Карабудахкентский район, поселок Манас, Школа	Россия, республика Дагестан, Карабудахкентский район, поселок городского типа Манаскент	0101000020E6100000B22FD978B0D747409696917A4F5D4540
32053	8	75	1621	21450	\N	\N	42.486796667360103	Республика Дагестан, Карабудахкентский район, сельсовет Губденский, село Ленинскент, Администрация	Россия, республика Дагестан, Карабудахкентский район, село Ленинкент	0101000020E6100000CB13083BC5E047403D65355D4F3E4540
32033	8	75	1621	20322	\N	\N	42.701656	Республика Дагестан, Карабудахкентский район, село Карабудахкент, Райгаз		0101000020E6100000EEEBC03923C84740668522DDCF594540
32035	8	75	1621	20322	33036	\N	42.701656	Республика Дагестан, Карабудахкентский район, село Карабудахкент, Дахадаева, Дворец культура		0101000020E6100000EEEBC03923C84740668522DDCF594540
32032	8	75	1621	20322	33168	\N	42.708053057364197	Республика Дагестан, Карабудахкентский район, село Карабудахкент, Дауда Карабудахкентского, Школа		0101000020E610000087F8872D3DC84740D76A0F7BA15A4540
32031	8	75	1621	20322	33034	\N	42.701656	Республика дагестан, Карабудахкентский, село Карабудахкент, Гамзатова, Здание УОС		0101000020E6100000EEEBC03923C84740668522DDCF594540
32036	8	75	1621	20322	33102	\N	42.701656	Республика Дагестан, Карабудахкентский район, село Карабудахкент, Абдуллаева, Автошкола		0101000020E6100000EEEBC03923C84740668522DDCF594540
32034	8	75	1621	20322	33057	\N	42.701656	Республика Дагестан, Карабудахкентский район, село Карабудахкент, Абакарова А, Школа		0101000020E6100000EEEBC03923C84740668522DDCF594540
32047	8	75	1621	21170	\N	\N	42.636196382358797	Республика Дагестан, Карабудахкентский район, сельсовет Кака-Шуринский, село Какамахи, Клуб	Россия, республика Дагестан, Карабудахкентский район, село Какамахи	0101000020E610000011C5E40D30B747404AECDADE6E514540
32046	8	75	1621	53675	\N	\N	42.651878544918098	Республика Дагестан, Карабудахкентский район, сельсовет Кака-Шуринский, село Какашура, Школа	Россия, республика Дагестан, Карабудахкентский район, село Кака-Шура	0101000020E61000009351651877B147407FF964C570534540
32045	8	75	1621	53675	\N	\N	42.647685317201599	Республика Дагестан, Карабудахкентский район, сельсовет Кака-Шуринский, село Какашура, Дом культура	Россия, республика Дагестан, Карабудахкентский район, село Кака-Шура	0101000020E610000049F4328AE5B047400D8E9257E7524540
32059	8	75	1621	21753	\N	\N	42.768070234245599	Республика Дагестан, Карабудахкентский район, село Зеленоморск, Школа	Россия, республика Дагестан, Карабудахкентский район, село Зеленоморск	0101000020E6100000D13FC1C58AD84740F584251E50624540
32044	8	75	1621	20933	\N	\N	42.665734	Республика Дагестан, Карабудахкентский район, село Дургели, Дом культура		0101000020E6100000DAE6C6F484A54740EAEA8EC536554540
32042	8	75	1621	20933	\N	\N	42.665734	Республика Дагестан, Карабудахкентский район, село Дургели, Школа		0101000020E6100000DAE6C6F484A54740EAEA8EC536554540
32051	8	75	1621	21375	\N	\N	42.515300924678499	Республика Дагестан, Карабудахкентский район, сельсовет Губденский, село Джанга, Клуб	Россия, республика Дагестан, Карабудахкентский район, село Джанга	0101000020E610000095F25A09DDE147404D4C1762F5414540
32049	8	75	1621	21231	\N	\N	42.609616000000003	Республика Дагестан, Карабудахкентский район, село Гурбуки, Клуб	Россия, республика Дагестан, Карабудахкентский район, село Гурбуки	0101000020E6100000456458C51BCD4740268FA7E5074E4540
32048	8	75	1621	21231	\N	\N	42.609616000000003	Республика Дагестан, Карабудахкентский район, село Гурбуки, Админисрация		0101000020E6100000456458C51BCD4740268FA7E5074E4540
32052	8	75	1621	21309	\N	\N	42.568772507179098	Республика Дагестан, Карабудахкентский район, сельсовет Губденский, село Сираги, Клуб	Россия, республика Дагестан, Карабудахкентский район, село Губден	0101000020E610000037514B732BC8474085ECBC8DCD484540
32050	8	75	1621	21309	\N	\N	42.565472999999997	Республика Дагестан, Карабудахкентский район, сельсовет Губденский, село Губден, Школа		0101000020E6100000D3BD4EEACBC84740B0E2546B61484540
32038	8	75	1621	53522	\N	\N	42.727901000000003	Республика Дагестан, Карабудахкентский район, село Гели, Дом культура	Россия, республика Дагестан, Карабудахкентский район, село Гелли	0101000020E6100000D717096D39B34740E4DC26DC2B5D4540
32061	8	75	1621	53588	\N	\N	42.650853312499798	Республика Дагестан, Карабудахкентский район, поселок Ачи-Су, Администрация	Россия, республика Дагестан, Карабудахкентский район, поселок городского типа Ачису	0101000020E61000007A8EC87729D7474072C0AE264F534540
32037	8	75	1621	20652	\N	\N	42.752679000000001	Республика Дагестан, Карабудахкентский район, село Аданак, Администрация		0101000020E61000002D5BEB8B84BA474068B114C957604540
32027	8	75	1533	20086	\N	\N	42.206201778216801	Р.Д. Кайтагский район, сельсовет Янгикентский, село Янгикент, Дом культуры	Россия, республика Дагестан, Кайтагский район, село Янгикент	0101000020E61000003E07962364EA4740552FBFD3641A4540
32022	8	75	1533	19808	\N	\N	42.049287	Р.Д. Кайтагский район, сельсовет Шилягинский, село Шиляги, Дом культуры		0101000020E6100000E6AC4F3926E54740198F52094F064540
32021	8	75	1533	19727	\N	\N	42.203901000000002	Р.Д. Республика Дагестан, Кайтагский район, село Чумли, Дом культуры		0101000020E610000087889B53C9E24740944F8F6D191A4540
31992	8	75	1533	18238	\N	\N	42.141041000000001	Р.Д. Кайтагский район, сельсовет Ахмедкентский, село Чахдикна, Здание библиотеки		0101000020E61000007E74EACA67E147409432A9A10D124540
32018	8	75	1533	19584	\N	\N	42.094417999999997	Р.Д. Кайтагский район, сельсовет Маджалисский, село Хунгия, Здание школы		0101000020E6100000DE3D40F7E5E64740AD1397E3150C4540
32002	8	75	1533	18769	\N	\N	42.081611000000002	Р.Д. Кайтагский район, сельсовет Джибахнинский, село Хадаги, Дом культуры		0101000020E61000007CD3F4D901F3474037FFAF3A720A4540
32029	8	75	1533	20178	\N	\N	42.184189000000003	Р.Д. Кайтагский район, сельсовет Янгикентский, село Тумеллер, Дом культуры		0101000020E610000065E42CEC69EB474038A4518193174540
31991	8	75	1533	53930	\N	\N	42.158631003747097	Республика Дагестан, Кайтагский район, сельсовет Ахмедкентск с.Сурхачи, Дом культуры	Россия, республика Дагестан, Кайтагский район, село Сурхачи	0101000020E610000000AC8E1CE9DE4740DE9046054E144540
32008	8	75	1533	19080	\N	\N	42.077060000000003	Р.Д. Кайтагский район, сельсовет Джирабачинский, село Сургия, Здание школы	Россия, республика Дагестан, Кайтагский район, село Сургия	0101000020E61000000F0F61FC34DC474036EA211ADD094540
32020	8	75	1533	19719	\N	\N	42.131166	Республика Дагестан, Кайтагский район, село Санчи, Дом культуры		0101000020E61000000FD1E80E62E947406F2C280CCA104540
31999	8	75	1533	18597	\N	\N	42.047339000000001	Р.Д. Кайтагский район, сельсовет Джавгатский, село Рука, Здание школы		0101000020E6100000B9FB1C1F2DF64740A56950340F064540
32019	8	75	1533	19651	\N	\N	42.150226000000004	Р.Д. Кайтагский район, сельсовет Маджалисский, село Родниковый, Дом культуры		0101000020E61000009E616A4B1DFA47402481069B3A134540
32014	8	75	1533	19393	\N	\N	42.005102000000001	Р.Д. Кайтагский район, сельсовет Кирцикский, село Пиляки, Здание школы		0101000020E6100000410DDFC2BAED47407592AD2EA7004540
32028	8	75	1533	20152	\N	\N	42.178463000000001	Р.Д. Кайтагский район, сельсовет Янгикентский, село Новая Барша, Здание школы		0101000020E610000062F4DC4257EA4740E54526E0D7164540
32023	8	75	1533	19873	\N	\N	42.069764999999997	Р.Д. Кайтагский район, сельсовет Шилягинский, село Мижигли, Здание школы		0101000020E6100000FA980F0874E64740E5B33C0FEE084540
32003	8	75	1533	18817	\N	\N	42.054682999999997	Р.Д. Кайтагский район, сельсовет Джибахнинский, село Машаты, Дом культуры		0101000020E61000007E18213CDAF04740D65240DAFF064540
32030	8	75	1533	20268	\N	\N	42.172449	Р.Д. Кайтагский район, сельсовет Янгикентский, село Маллакент, Здание школы		0101000020E61000000BB6114F76E547402C9D0FCF12164540
32016	8	75	1533	33071	\N	\N	42.122395275482504	Р.Д. Кайтагский район, сельсовет Маджалисский, село Н-Маджалис, Дом культуры	Россия, республика Дагестан, Кайтагский район, село Маджалис	0101000020E6100000EFC682C2A0EA4740D218ADA3AA0F4540
32015	8	75	1533	33071	\N	\N	42.121048000000002	Р.Д. Кайтагский район, сельсовет Маджалисский, село В-Маджалис, Дом культуры		0101000020E6100000C3802557B1EA4740849F38807E0F4540
32007	8	75	1533	19007	\N	\N	42.073881	Р.Д. Кайтагский район, сельсовет Джирабачинский, село Лища, Здание библиотеки		0101000020E610000044C362D4B5DE4740DC65BFEE74094540
32026	8	75	1533	20007	\N	\N	42.053283999999998	Р.Д. Кайтагский район, сельсовет Шилягинский, село Кулиджа, Дом культуры		0101000020E6100000D06053E751E3474035B39602D2064540
32013	8	75	1533	19334	\N	\N	42.002107000000002	Р.Д. Кайтагский район, сельсовет Кирцикский, село Кирцик, Дом культуры		0101000020E610000066F4A3E194EB4740DD0BCC0A45004540
32012	8	75	1533	19296	\N	\N	41.969386999999998	Р.Д. Кайтагский район, сельсовет Киркинский, село Кирки, Дом культуры		0101000020E6100000F20C1AFA27E8474072158BDF14FC4440
32011	8	75	1533	19264	\N	\N	42.087245000000003	Р.Д. Кайтагский район, сельсовет Карацанский, село Карталай, Дом культуры		0101000020E610000052D66F26A6ED4740A9DE1AD82A0B4540
32010	8	75	1533	19168	\N	\N	42.088196000000003	Р.Д. Кайтагский район, сельсовет Карацанский, село Карацан, Дом культуры		0101000020E6100000CBF5B6990AEF4740ABD1AB014A0B4540
32025	8	75	1533	19988	\N	\N	42.036302999999997	Р.Д. Кайтагский район, сельсовет Шилягинский, село Дуреги, Здание школы		0101000020E610000093C49272F7E1474093DFA293A5044540
32005	8	75	1533	18914	\N	\N	42.090797999999999	Р.Д. Кайтагский район, сельсовет Джирабачинский, село Джирабачи, Здание школы		0101000020E610000073F1B73D41DE47406745D4449F0B4540
32004	8	75	1533	18847	\N	\N	42.073199000000002	Республика Дагестан, Кайтагский район, село Джинаби, Дом культуры		0101000020E61000003387A4164AEE4740CA8CB7955E094540
32001	8	75	1533	18695	\N	\N	42.061157000000001	Р.Д. Кайтагский район, сельсовет Джибахнинский, село Джибахни, Дом культуры		0101000020E6100000A796ADF545F44740F37519FED3074540
31998	8	75	1533	18534	\N	\N	42.051155000000001	Р.Д. Кайтагский район, сельсовет Джавгатский, село Джавгат, Дом культуры		0101000020E61000002C47C8409EF7474071033E3F8C064540
32006	8	75	1533	18980	\N	\N	42.087398999999998	Р.Д. Кайтагский район, сельсовет Джибахнинский, село Дакниса, Здание школы		0101000020E61000000BEBC6BB23DD4740FF59F3E32F0B4540
31997	8	75	1533	18488	\N	\N	42.231420017763497	Республика Дагестан, Кайтагский район, село Гулли, Дом культуры	Россия, республика Дагестан, Кайтагский район, село Гулли	0101000020E6100000E085ADD9CAE14740F6D1A92B9F1D4540
32009	8	75	1533	53933	\N	\N	42.096063999999998	Р.Д. Кайтагский район, сельсовет Джирабачинский, село Гулды, Здание школы		0101000020E61000008CBD175FB4EB474056293DD34B0C4540
31994	8	75	1533	18320	\N	\N	42.091588000000002	Р.Д. Кайтагский район, сельсовет Баршамайский, село Газия, Здание сельской библиотеки	Россия, республика Дагестан, Кайтагский район, село Газия	0101000020E61000000B444FCAA4E84740605AD427B90B4540
31995	8	75	1533	18369	\N	\N	41.993637	Р.Д. Кайтагский район, сельсовет Варситский, село Варсит, Дом культуры		0101000020E61000009E98F56228E947403B8C497F2FFF4440
31993	8	75	1533	18286	\N	\N	42.108494	Р.Д. Кайтагский район, сельсовет Баршамайский, село Баршамай, Дом культуры		0101000020E6100000029A081B9EEC4740F7E7A221E30D4540
31996	8	75	1533	18435	\N	\N	42.039431	Р.Д. Кайтагский район, сельсовет Варситский, село Бажлук, Здание школы		0101000020E6100000F697DD9387E747406BB933130C054540
31990	8	75	1533	18149	\N	\N	42.123643000000001	Р.Д. Кайтагский район, сельсовет Ахмедкентский, село Ахмедкент, Дом культуры		0101000020E6100000B22FD978B0E747408EB0A888D30F4540
32024	8	75	1533	19906	\N	\N	42.009149000000001	Р.Д. Кайтагский район, сельсовет Шилягинский, село Адага, Здание школы		0101000020E6100000FB95CE8767DB474043E55FCB2B014540
32017	8	75	1533	53711	\N	\N	42.096063999999998	Р.Д. Кайтагский район, сельсовет Маджалисский, село Абдашка, Дом культуры		0101000020E61000008CBD175FB4EB474056293DD34B0C4540
31988	8	75	1469	18048	\N	\N	43.050922	Республика Дагестан, Казбековский район, село Хубар, здание клуба		0101000020E610000039B874CC79604740CE52B29C84864540
31979	8	75	1469	17561	\N	\N	43.073686000000002	Республика Дагестан Казбековский район, село Калининаул, здание школы №2		0101000020E610000036069D103A4847402716F88A6E894540
31978	8	75	1469	17561	\N	\N	43.073686000000002	Республика Дагестан, Казбековский район, село Калининаул, здание СПК		0101000020E610000036069D103A4847402716F88A6E894540
31977	8	75	1469	17479	\N	\N	43.094644000000002	Республика Дагестан, Казбековский район, село Инчха, здание СОШ		0101000020E6100000062CB98AC56147409E616A4B1D8C4540
31976	8	75	1469	53878	\N	\N	42.859854405523897	Республика Дагестан, Казбековский район, сельсовет Артлухский село Имросов, здание клуба	Россия, республика Дагестан, Казбековский район, село Артлух	0101000020E6100000CF31207BBD554740DAAA24B20F6E4540
31975	8	75	1469	17274	\N	\N	43.071393999999998	Республика Дагестан Казбековский район, село Дылым, здание школы		0101000020E610000050C8CEDBD8504740B890477023894540
31974	8	75	1469	17274	\N	\N	43.071393999999998	Республика Дагестан Казбековский район, село Дылым, здание РДК		0101000020E610000050C8CEDBD8504740B890477023894540
31973	8	75	1469	17274	\N	\N	43.071393999999998	Республика Дагестан, Казбековский район, село Дылым, здание школы		0101000020E610000050C8CEDBD8504740B890477023894540
31972	8	75	1469	17167	\N	\N	43.021644000000002	Республика Дагестан Казбековский район, поселок Дубки, здание дома культуры	Россия, республика Дагестан, Казбековский район, поселок Дубки	0101000020E6100000485167EE216B4740CB13083BC5824540
31971	8	75	1469	17167	\N	\N	43.021644000000002	Республика Дагестан, Казбековский район, поселок Дубки, здание школы		0101000020E6100000485167EE216B4740CB13083BC5824540
31969	8	75	1469	17082	\N	\N	43.031740999999997	"Республика Дагестан, Казбековский район, село Гуни, СПК ""Новая жиззнь"""		0101000020E6100000942EFD4B525947409E78CE1610844540
31968	8	75	1469	17034	\N	\N	43.073824000000002	Республика Дагестан, Казбековский район, село Гостала, здание сельского дома культуры		0101000020E610000002D4D4B2B558474078D4981073894540
31967	8	75	1469	16994	\N	\N	42.996710999999998	Республика Дагестан, Казбековский район, село Гертма, здание сельского дома культуры		0101000020E6100000C1A8A44E405F47401F48DE39947F4540
31966	8	75	1469	16943	\N	\N	42.990676999999998	Республика Дагестан, Казбековский район, село Буртунай, здание сельского дома культуры		0101000020E61000005ABDC3EDD05047401FF30181CE7E4540
31965	8	75	1469	53636	\N	\N	43.119010000000003	Республика Дагестан Казбековский район,село Ахтачикан, здание Клуба		0101000020E61000003E92921E866C4740D0F23CB83B8F4540
31984	8	75	1469	53545	\N	\N	42.863895451016297	Республика Дагестан, Казбековский район,  новый Артлух, здание СПК	Россия, республика Дагестан, Казбековский район, село Артлух	0101000020E610000097900F7A36554740C616821C946E4540
31964	8	75	1469	53545	\N	\N	42.8628852146188	Республика Дагестан, Казбековский район, сельсовет Артлухский село Артлух, здание библиотеки	Россия, республика Дагестан, Казбековский район, село Артлух	0101000020E610000045D61A4AED554740BF9A0304736E4540
31963	8	75	1469	16785	\N	\N	42.983528	Республика Дагестан, Казбековский район, село Алмак, здании сельского клуба		0101000020E61000001B118C834B494740A359D93EE47D4540
31945	8	75	1407	15885	\N	\N	41.422015000000002	Республика Дагестан, Докузпаринский район, село Усухчай, Здание сельского дома культуры		0101000020E61000008196AE601BF54740F2B5679604B64440
31940	8	75	1407	53948	\N	\N	41.343045917903801	Республика Дагестан, Докузпаринский район, селение Текипиркент, Здание сельского дома культуры	Россия, республика Дагестан, Докузпаринский район, село Текипиркент	0101000020E610000007280D350AF1474006836BEEE8AB4440
31939	8	75	1407	53758	\N	\N	41.333559999999999	Республика Дагестан, Докузпаринский район, село Новое Каракюре, Здание школы		0101000020E6100000DA58897956EE47407BA01518B2AA4440
31948	8	75	1407	53466	\N	\N	41.423417079018101	Республика Дагестан, Докузпаринский район, село Мискинджа, Здание школы	Россия, республика Дагестан, Докузпаринский район, село Мискинджи	0101000020E61000005E9F39EB53EC474004C93B8732B64440
31947	8	75	1407	53530	\N	\N	41.371002567768699	Республика Дагестан, Докузпаринский район, сельсовет Микрахский, Здание администрации	Россия, республика Дагестан, Докузпаринский район, село Микрах	0101000020E61000008466D7BD15F14740E4DBBB067DAF4440
31944	8	75	1407	53800	\N	\N	41.276600942976302	Республика Дагестан, Докузпаринский район, село Куруш, Здание сельского дома культуры	Россия, республика Дагестан, Докузпаринский район	0101000020E610000055F833BC59E947403C855CA967A34440
31544	8	75	1817	28386	\N	\N	41.495998	Республика Дагестан, Ахтынский район, село Зрых, клуб		0101000020E610000031D120054FC74740D270CADC7CBF4440
31946	8	75	1407	53569	\N	\N	41.380635554956598	Республика Дагестан, Докузпаринский район, сельсовет Килерский, Здание сельского дома культуры		0101000020E6100000A0C4E74EB0F3474013D731AEB8B04440
31943	8	75	1407	15802	\N	\N	41.419363730008897	Республика Дагестан, Докузпаринский район, село Каракюре, Здание школы	Россия, республика Дагестан, Докузпаринский район, село Кара-Кюре	0101000020E61000006F826F9A3EFB4740548F34B8ADB54440
31942	8	75	1407	15750	\N	\N	41.366424000000002	Республика Дагестан, Докузпаринский район, село Каладжух, Здание сельского дома культуры	Россия, республика Дагестан, Докузпаринский район, село Каладжух	0101000020E61000008AABCABE2BF44740193C4CFBE6AE4440
31938	8	75	1407	53495	\N	\N	41.331615216984403	Республика Дагестан, Докузпаринский район, село Авадан, Здание администрации	Россия, республика Дагестан, Докузпаринский район	0101000020E6100000DEACC1FBAAEE474078EE3D5C72AA4440
31879	8	75	1122	12800	\N	\N	42.107858	Республика Дагестан, Дербентский район, сельсовет Чинарский, село Чинар, Здание СДК		0101000020E6100000C2DF2F664B124840554E7B4ACE0D4540
31888	8	75	1122	13187	\N	\N	42.001786000000003	Республика Дагестан, Дербентский район, сельсовет Хазарский, село Хазар, Здание СДК		0101000020E6100000904FC8CEDB2A48409BCB0D863A004540
31864	8	75	1122	53760	\N	\N	42.213214543437097	Республика Дагестан, Дербентский район, село Уллу-Теркеме, Здание СДК	Россия, республика Дагестан, Дербентский район, село Уллутеркеме	0101000020E6100000BC5AEECC0401484021020EA14A1B4540
31866	8	75	1122	12196	\N	\N	42.199460000000002	"Республика Дагестан, Дербентский район, сельсовет Татлярский, село Татляр, Здание агрофирмы ""Татляр"""		0101000020E610000089D2DEE00B0348401A6EC0E787194540
31870	8	75	1122	12361	\N	\N	42.176405000000003	"Республика Дагестан, Дербентский район, село Салик, Здание агрофирмы ""Шейхляр"""		0101000020E6100000062FFA0AD20A4840EAEC647094164540
31883	8	75	1122	12944	\N	\N	42.072248000000002	Республика Дагестан, Дербентский район, село Сабнова, Здание школы		0101000020E6100000FEBAD39D27204840C899266C3F094540
31868	8	75	1122	53943	\N	\N	42.144522247894997	Республика Дагестан, Дербентский район, сельсовет Первомайский, село Рыбзавод - 51, Здание бывшей школы	Россия, республика Дагестан, Дербентский район	0101000020E610000038D906EE401D4840B9C667B27F124540
31887	8	75	1122	13113	\N	\N	41.985877000000002	Республика Дагестан, Дербентский район, село Рукель, Здание школы		0101000020E61000006AFB57569A1C48407670B03731FE4440
31891	8	75	1122	13324	\N	\N	41.892138000000003	"Республика Дагестан, Дербентский район, сельсовет Рубасский, село Рубас, Здание агрофирмы ""Рубас"""		0101000020E61000005FEB5223F42948406AC2F69331F24440
31871	8	75	1122	12426	\N	\N	42.200662000000001	Республика Дагестан, Дербентский район, село Падар, Здание СДК		0101000020E610000053910A630B07484065C6DB4AAF194540
31901	8	75	1122	13769	\N	\N	41.860295000000001	Республика Дагестан, Дербентский район, село Нюгди, Здание администрации		0101000020E6100000DE019EB470374840C7F484251EEE4440
33001	8	75	1122	53725	\N	\N	41.850974214433101	село Новый Фриг, Средняя школа село Ново-Фриг	Россия, республика Дагестан, Дербентский район, село Новофриг	0101000020E6100000807D74EACA2D484087DF4DB7ECEC4440
31885	8	75	1122	53441	\N	\N	42.069363000000003	Республика Дагестан, Дербентский район, сельсовет Хазарский, село Нижний Джалган, Здание школы		0101000020E6100000397F130A111E4840B74604E3E0084540
31890	8	75	1122	13283	\N	\N	41.910204999999998	Республика Дагестан, Дербентский район, село Музаим, Здание школы		0101000020E6100000D594641D8E244840EDD3F19881F44440
31886	8	75	1122	13092	\N	\N	41.993611911496799	Республика Дагестан, Дербентский район, село Мугарты, Здание школы	Россия, республика Дагестан, Дербентский район, село Мугарты	0101000020E6100000554D10751F144840E27492AD2EFF4440
31880	8	75	1122	12843	\N	\N	42.037100804973498	Республика Дагестан, Дербентский район, село Митаги-Казмаляр, Здание СДК	Россия, республика Дагестан, Дербентский район, село Митаги-Казмаляр	0101000020E610000095607138F31948400FD3BEB9BF044540
31881	8	75	1122	12868	\N	\N	42.016860000000001	Республика Дагестан, Дербентский район, село Митаги, Здание администрации		0101000020E610000061A92EE065184840274EEE7728024540
31875	8	75	1122	12527	\N	\N	42.173679	Республика Дагестан, Дербентский район, поселок Мамедкала, Здание школы №1		0101000020E610000035D07CCEDD10484041800C1D3B164540
31874	8	75	1122	53487	\N	\N	42.174320268159498	Республика Дагестан, Дербентский район, поселок Мамедкала, Здание школы №2	Россия, республика Дагестан, Дербентский район, поселок городского типа Мамедкала	0101000020E6100000753BFBCA83104840F584251E50164540
31873	8	75	1122	53487	\N	\N	42.170234051426597	Республика Дагестан, Дербентский район, поселок Мамедкала, Здание клуба	Россия, республика Дагестан, Дербентский район, поселок городского типа Мамедкала	0101000020E6100000249D8191970F484069554B3ACA154540
31902	8	75	1122	13832	\N	\N	41.831049	Республика Дагестан, Дербентский район, село Куллар, Здание СДК		0101000020E6100000022EC896E5314840CF2F4AD05FEA4440
31892	8	75	1122	13385	\N	\N	41.879404000000001	Республика Дагестан, Дербентский район, сельсовет Рубасский, село Коммуна, Здание школы		0101000020E61000008449F1F1092748405DFC6D4F90F04440
31865	8	75	1122	12124	\N	\N	42.192585999999999	Республика Дагестан, Дербентский район, сельсовет Татлярский, село Карадаглы, Здание магазина		0101000020E6100000B1E1E995B20448406FD575A8A6184540
31869	8	75	1122	12319	\N	\N	42.159745000000001	Республика Дагестан, Дербентский район, село Кала, Здание школы	Россия, республика Дагестан, Дербентский район, село Кала	0101000020E61000008E06F016480E48408A592F8672144540
31867	8	75	1122	12240	\N	\N	42.179544999999997	"Республика Дагестан, Дербентский район, сельсовет Первомайский, село имени Мичурина, Здание агрофирмы ""Каспий"""		0101000020E6100000736891ED7C19484085949F54FB164540
31882	8	75	1122	12927	\N	\N	42.078031000000003	Республика Дагестан, Дербентский район, сельсовет Зидьян-Казмалярский, село Зидьян-Казмаляр, Здание СДК		0101000020E61000000A815CE2C81348407F8978EBFC094540
31889	8	75	1122	53519	\N	\N	41.942691243081597	Сельсовет Хазарский, село Дюзляр, Здание школы	Россия, республика Дагестан, Дербентский район	0101000020E6100000779D0DF9671E4840E59D4319AAF84440
31861	8	75	1122	11930	\N	\N	42.237186999999999	Республика Дагестан, Дербентский район, село Джемикент, Здание администрации		0101000020E61000008CBE823463054840A704C4245C1E4540
31884	8	75	1122	12997	\N	\N	42.025044999999999	Республика Дагестан, Дербентский район, село Джалган, Здание СДК		0101000020E61000008ACA863595214840D3F6AFAC34034540
31825	8	75	1122	10204	\N	\N	42.200521999999999	Республика Дагестан, Дербентский район, село Деличобан, Здание СДК		0101000020E61000007D5BB054170C4840731074B4AA194540
31877	8	75	1122	12645	\N	\N	42.127420999999998	Республика Дагестан, Дербентский район, село Геджух, Здание СДК		0101000020E61000008FFAEB15160848406CE9D1544F104540
31876	8	75	1122	12645	\N	\N	42.127420999999998	Республика Дагестан, Дербентский район, село Геджух, Здание музыкальной школы		0101000020E61000008FFAEB15160848406CE9D1544F104540
31862	8	75	1122	11984	\N	\N	42.185966000000001	Республика Дагестан, Дербентский район, село Великент, Здание СДК		0101000020E6100000ACC8E880240848407F15E0BBCD174540
31878	8	75	1122	53891	\N	\N	42.085251	Республика Дагестан, Дербентский район, сельсовет Чинарский, село Бильгади, Здание СДК	Россия, республика Дагестан, Дербентский район, село Бильгады	0101000020E6100000B22AC24D46114840C4793881E90A4540
31872	8	75	1122	12451	\N	\N	42.224957000000003	Республика Дагестан, Дербентский район, сельсовет Берикеевский, село Берикей, Здание СДК	Россия, республика Дагестан, Дербентский район, село Берикей	0101000020E61000005BCEA5B8AA084840CE001764CB1C4540
31898	8	75	1122	13490	\N	\N	41.874409	Республика Дагестан, Дербентский район, поселок Белиджи, Здание школы имени Лезгинцева		0101000020E61000008750A5660F324840FE2955A2ECEF4440
31897	8	75	1122	13490	\N	\N	41.874409	Республика Дагестан, Дербентский район, поселок Белиджи, Здание школы №2		0101000020E61000008750A5660F324840FE2955A2ECEF4440
31896	8	75	1122	13490	\N	\N	41.874409	Республика Дагестан, Дербентский район, поселок Белиджи, Здание СДК		0101000020E61000008750A5660F324840FE2955A2ECEF4440
31899	8	75	1122	53600	\N	\N	41.874409	Республика Дагестан, Дербентский район, поселок Белиджи, Здание школы-гимназии	Россия, республика Дагестан, Дербентский район, поселок городского типа Белиджи	0101000020E61000008750A5660F324840FE2955A2ECEF4440
31895	8	75	1122	53600	\N	\N	41.875852494467701	Республика Дагестан, Дербентский район, поселок Белиджи, Здание школы №1	Россия, республика Дагестан, Дербентский район, поселок городского типа Белиджи	0101000020E6100000B77EFACF9A3148406F1118EB1BF04440
31900	8	75	1122	13754	\N	\N	41.887847109346197	Республика Дагестан, Дербентский район, село Белиджи, Здание СДК	Россия, республика Дагестан, Дербентский район, село Белиджи	0101000020E6100000F964C57075344840056D72F8A4F14440
32251	8	75	1122	30645	\N	\N	41.935578954550898	Республика Дагестан, Курахский район, сельсовет Моллакентский, село Арабляр, Здание школы	Россия, республика Дагестан, Дербентский район, село Арабляр	0101000020E6100000EA9788B7CE2F484085E97B0DC1F74440
31894	8	75	1122	53559	\N	\N	41.964584073254002	"Республика Дагестан, Дербентский район, село Араблинское, Здание агрофирмы ""Араблинское"""	Россия, республика Дагестан, Дербентский район, поселок Араблинский	0101000020E61000009F03CB11322A4840581F0F7D77FB4440
32250	8	75	1122	53770	\N	\N	41.906714999999998	Республика Дагестан, Курахский район, село Аладаш, Школа	Россия, республика Дагестан, Дербентский район, село Аладаш	0101000020E61000009B594B01692D484075E5B33C0FF44440
31893	8	75	1122	13402	\N	\N	41.900359999999999	Республика Дагестан, Дербентский район, село Аглоби, Здание школы		0101000020E6100000EFAA07CC432C4840335019FF3EF34440
31863	8	75	7292	53716	33132	\N	42.0549910355181	Республика Дагестан, город Дербент, Буйнакского, 17		0101000020E610000085D21742CE2548408449F1F109074540
31828	8	75	1047	10357	\N	\N	42.137016000000003	Республика Дагестан, Дахадаевский район, сельсовет Кищинский, село Шулерчи, Помещение начальной школы		0101000020E6100000384BC97212C84740AE8383BD89114540
31820	8	75	1047	9977	\N	\N	42.192084999999999	Республика Дагестан, Дахадаевский район, сельсовет Цизгаринский, село Шадни, Помещение сельского клуба		0101000020E6100000959D7E5017D34740AD86C43D96184540
31807	8	75	1047	53618	\N	\N	42.152219255532003	Республика Дагестан, Дахадаевский район, село Чишили, Помещение дома культуры	Россия, республика Дагестан, Дахадаевский район, село Чищили	0101000020E6100000CA6E66F4A3D54740386A85E97B134540
31822	8	75	1047	10057	\N	\N	42.235885000000003	Республика Дагестан, Дахадаевский район, сельсовет Цизгаринский, село Цураи, Помещение Дома Культуры		0101000020E6100000B48EAA2688D44740F94ECC7A311E4540
31821	8	75	1047	10040	\N	\N	42.221231000000003	Республика Дагестан, Дахадаевский район, сельсовет Цизгаринский, село Цизгари, Помещение дома культуры		0101000020E61000007CB60E0EF6D2474042EE224C511C4540
31830	8	75	1047	10481	\N	\N	42.141536000000002	Республика Дагестан, Дахадаевский район, село Хуршни, Помещение средней школы	Россия, республика Дагестан, Дахадаевский район, село Хуршни	0101000020E61000007E1B62BCE6BF4740749A05DA1D124540
31840	8	75	1047	10963	\N	\N	42.053973999999997	Республика Дагестан, Дахадаевский район, сельсовет Дуакарский, село Хулабаркмахи, Помещение средней школы		0101000020E6100000BE326FD575BA4740CA6ABA9EE8064540
31849	8	75	1047	11350	\N	\N	41.966906999999999	Республика Дагестан, Дахадаевский район, сельсовет Аштынский, село Худуц, Помещение дома культуры		0101000020E6100000A29927D714C2474001A3CB9BC3FB4440
31829	8	75	1047	10435	\N	\N	42.157004000000001	Республика Дагестан, Дахадаевский район, село Харбук, Помещение дома культуры	Россия, республика Дагестан, Дахадаевский район, село Харбук	0101000020E6100000211D1EC2F8C34740ACAB02B518144540
31856	8	75	1047	11700	\N	\N	42.098412000000003	Республика Дагестан, Дахадаевский район, сельсовет Сутбукский, село Урцаки, Помещение дома культуры		0101000020E6100000259529E620C8474059C4B0C3980C4540
31836	8	75	1047	53876	\N	\N	42.065555000000003	Республика Дагестан, Дахадаевский район, сельсовет Ураринский, село Урхнища, Помещение сельской библиотеки		0101000020E610000048C32973F3C947406E8B321B64084540
31837	8	75	1047	53932	\N	\N	42.065555000000003	Республика Дагестан, Дахадаевский район, сельсовет Ураринский, село Уркудта, Помещение сельской библиотеки		0101000020E610000048C32973F3C947406E8B321B64084540
31842	8	75	1047	9178	\N	\N	42.163674999999998	Республика Дагестан, Дахадаевский район, сельсовет Дуакарский, село Муркарах, Помещение начальной школы		0101000020E61000007FDE54A4C2D047401E166A4DF3144540
31804	8	75	1047	9178	\N	\N	42.163674999999998	Республика Дагестан, Дахадаевский район, сельсовет Уркарахский, село Уркарах, Верхний, Спортзал УМГ		0101000020E61000007FDE54A4C2D047401E166A4DF3144540
31803	8	75	1047	9178	\N	\N	42.163674999999998	Республика Дагестан, Дахадаевский район, сельсовет Уркарахский, село Уркарах, Центральный, Районный Дом Культуры		0101000020E61000007FDE54A4C2D047401E166A4DF3144540
31805	8	75	1047	9178	33056	\N	42.163674999999998	Республика Дагестан, Дахадаевский район, сельсовет Уркарахский, село Уркарах, Пироговский, Здание УМЛицея		0101000020E61000007FDE54A4C2D047401E166A4DF3144540
31833	8	75	1047	10646	\N	\N	42.098967999999999	Республика Дагестан, Дахадаевский район, сельсовет Ураринский, село Урари, Помещение Дома Культуры		0101000020E61000005BECF65965BA4740DEACC1FBAA0C4540
31853	8	75	1047	11554	\N	\N	42.065655	Республика Дагестан, Дахадаевский район, сельсовет Урагинский, село Ураги, Помещение дома культуры		0101000020E6100000A112D731AEC84740D1E80E6267084540
31810	8	75	1047	9451	\N	\N	42.117308999999999	Республика Дагестан, Дахадаевский район, сельсовет Трисанчинский, село Трисанчи, Здание средней школы		0101000020E6100000D73043E389DA4740634337FB030F4540
31857	8	75	1047	11750	\N	\N	42.103195999999997	Республика Дагестан, Дахадаевский район, сельсовет Сутбукский, село Сутбук, Помещение Дома Культуры	Россия, республика Дагестан, Дахадаевский район, село Сутбук	0101000020E61000005B7C0A80F1C44740FC89CA86350D4540
31806	8	75	1047	53751	\N	\N	42.065555000000003	Республика Дагестан, Дахадаевский район, сельсовет Уркарахский, село Новый Уркарах, Здание школы		0101000020E610000048C32973F3C947406E8B321B64084540
31823	8	75	1047	53596	\N	\N	42.065555000000003	Республика Дагестан, Дахадаевский район, село Морское, Помещение Дома Культуры	Россия, республика Дагестан, Дахадаевский район	0101000020E610000048C32973F3C947406E8B321B64084540
31831	8	75	1047	53883	\N	\N	42.065555000000003	Республика Дагестан, Дахадаевский район, сельсовет Гуладтынский, село Мирзидты, Помешение начальной школы		0101000020E610000048C32973F3C947406E8B321B64084540
31824	8	75	1047	10164	\N	\N	42.200515000000003	Республика Дагестан, Дахадаевский район, село Меусиша, Помещение Дома Культуры		0101000020E6100000F627F1B913CC4740C1ADBB79AA194540
31846	8	75	1047	11187	\N	\N	41.959451000000001	Республика Дагестан, Дахадаевский район, село Кунки, Помещение дома культуры		0101000020E6100000EF92382BA2BC4740A88E554ACFFA4440
31813	8	75	1047	9636	\N	\N	42.133645999999999	Республика Дагестан, Дахадаевский район, сельсовет Кудагинский, село Кудагу, Помещение Дома Культуры		0101000020E6100000D68BA19C68DD4740E09EE74F1B114540
31854	8	75	1047	11596	\N	\N	42.087138000000003	Республика Дагестан, Дахадаевский район, поселок Кубачи, Старый, Помещение средней школы		0101000020E6100000A3737E8AE3CC4740931E8656270B4540
31855	8	75	1047	11596	33094	\N	42.087138000000003	Республика Дагестан, Дахадаевский район, поселок Кубачи, Новый, Помещение администрации поселка		0101000020E6100000A3737E8AE3CC4740931E8656270B4540
31841	8	75	1047	10988	\N	\N	42.051811000000001	Республика Дагестан, Дахадаевский район, сельсовет Дуакарский, село Кищамахи, Помещение начальной школы		0101000020E610000018EC866D8BB847405A492BBEA1064540
31827	8	75	1047	10291	\N	\N	42.173979000000003	Республика Дагестан, Дахадаевский район, сельсовет Кищинский, село Кища, Нижний, Здание Кищинской МГ		0101000020E610000080D8D2A3A9CA47406C98A1F144164540
31826	8	75	1047	10291	\N	\N	42.173979000000003	Республика Дагестан, Дахадаевский район, сельсовет Кищинский, село Кища, Верхний, Помещение Дома Культуры		0101000020E610000080D8D2A3A9CA47406C98A1F144164540
31844	8	75	1047	53794	\N	\N	42.005920443759102	Республика Дагестан, Дахадаевский район, сельсовет Карбучимахинский, село Карбачимахи, Помещение дома культуры		0101000020E610000041B7973446B7474038328FFCC1004540
31817	8	75	1047	9811	\N	\N	42.177040108506802	Республика Дагестан, Дахадаевский район, село Калкни, Помещение Дома Культуры	Россия, республика Дагестан, Дахадаевский район, село Калкни	0101000020E6100000467D923B6CDA4740BB0A293FA9164540
31543	8	75	1817	28352	\N	\N	41.423414000000001	Республика Дагестан, Ахтынский район, село Джаба, клуб		0101000020E6100000B1DEA815A6E347409355116E32B64440
31850	8	75	1047	53575	\N	\N	41.995164833931099	Республика Дагестан, Дахадаевский район, сельсовет Ицаринский, село Ицари, Помещение сельского клуба	Россия, республика Дагестан, Агульский район, село Ицари	0101000020E610000046990D32C9CA4740DA8F149161FF4440
31815	8	75	1047	9705	\N	\N	42.162906	Республика Дагестан, Дахадаевский район, сельсовет Дибгашинский, село Ираки, Помещение сельского клуба		0101000020E61000002F6EA301BCDB47403D29931ADA144540
31814	8	75	1047	9661	\N	\N	42.119998000000002	Республика Дагестан, Дахадаевский район, сельсовет Кудагинский, село Ираги, Помещение Дома Культуры		0101000020E61000002BA1BB24CEE04740EFCA2E185C0F4540
31811	8	75	1047	9518	\N	\N	42.133820843063098	Республика Дагестан, Дахадаевский район, село Зубанчи, Помещение дома культуры	Россия, республика Дагестан, Дахадаевский район, село Зубанчи	0101000020E6100000429770E82DDA47404E42E90B21114540
31812	8	75	1047	9547	\N	\N	42.140619999999998	Республика Дагестан, Дахадаевский район, село Зильбачи, Сельский Дом Культуры		0101000020E610000063635E471CDC4740EE940ED6FF114540
31843	8	75	1047	10922	\N	\N	42.062997180224698	Республика Дагестан, Дахадаевский район, сельсовет Дуакарский, село Сурсбук, Помещение начальной школы	Россия, республика Дагестан, Дахадаевский район, село Дуакар	0101000020E6100000AA471ADCD6BA4740815F234910084540
31839	8	75	1047	10922	\N	\N	42.063065000000002	Республика Дагестан, Дахадаевский район, сельсовет Дуакарский, село Дуакар, Помещение администрации с/с		0101000020E610000081E84999D4BA4740D942908312084540
31848	8	75	1047	53521	\N	\N	42.0651714698826	Республика Дагестан, Дахадаевский район, сельсовет Аштынский, село Дирбакмахи, Помещение неполной средней школы	Россия, республика Дагестан, Дахадаевский район	0101000020E610000072A774B0FEC94740E5D2F88557084540
31816	8	75	1047	9778	\N	\N	42.163487000000003	Республика Дагестан, Дахадаевский район, сельсовет Дибгашинский, село Дибгаши, Помещение Дома Культуры		0101000020E6100000323A2009FBD847401C295B24ED144540
31808	8	75	1047	9352	\N	\N	42.118118000000003	Республика Дагестан, Дахадаевский район, село Дибгалик, Сельский Дом Культуры		0101000020E6100000618E1EBFB7D34740D388997D1E0F4540
31851	8	75	1047	11465	\N	\N	42.048658000000003	Республика Дагестан, Дахадаевский район, сельсовет Урагинский, село Дзилебки, Помещение сельского клуба	Россия, республика Дагестан, Дахадаевский район, село Дзилебки	0101000020E6100000C0AE264F59C747402A58E36C3A064540
31809	8	75	1047	9431	\N	\N	42.092525000000002	Республика Дагестан, Дахадаевский район, сельсовет Трисанчинский, село Джурмачи, Сельский Дом Культуры		0101000020E6100000C13A8E1F2AD94740FD87F4DBD70B4540
31818	8	75	1047	9879	\N	\N	42.178615999999998	Республика Дагестан, Дахадаевский район, сельсовет Бускринский, село Гунакари, Помещение сельского клуба		0101000020E6100000724EECA17DD847406B459BE3DC164540
31832	8	75	1047	10574	\N	\N	42.114801	Республика Дагестан, Дахадаевский район, сельсовет Гуладтынский, село Гуладты, Помещение дома культуры		0101000020E610000005C58F3177B94740284696CCB10E4540
31860	8	75	1047	53590	\N	\N	42.065555000000003	"Республика Дагестан, Дахадаевский район, сельсовет Карбучимахинский, село Губа-Кутан, Помещение конторы СПК ""Карбачимахи"""		0101000020E610000048C32973F3C947406E8B321B64084540
31819	8	75	1047	9911	\N	\N	42.170637999999997	Республика Дагестан, Дахадаевский район, сельсовет Бускринский, село Бускри, Помещение дома культуры		0101000020E6100000ACAC6D8AC7D5474038BA4A77D7154540
31858	8	75	1047	11797	\N	\N	42.115617	Республика Дагестан, Дахадаевский район, сельсовет Сутбукский, село Бакни, Помещение Дома Культуры		0101000020E61000006458C51B99C347404AEEB089CC0E4540
31834	8	75	1047	10664	\N	\N	42.072783999999999	Республика Дагестан, Дахадаевский район, сельсовет Ураринский, село Аяцури, Помещение неполной средней школы		0101000020E61000008D2441B802BA474006D671FC50094540
31845	8	75	1047	11184	\N	\N	42.005021999999997	Республика Дагестан, Дахадаевский район, сельсовет Карбучимахинский, село Аяцимахи, Помещение начальной школы	Россия, республика Дагестан, Дахадаевский район, село Аяцимахи	0101000020E610000003249A4011BB474058E1968FA4004540
31847	8	75	1047	11268	\N	\N	41.957915999999997	Республика Дагестан, Дахадаевский район, сельсовет Аштынский, село Ашты, Помещение Дома Культуры	Россия, республика Дагестан, Дахадаевский район, село Ашты	0101000020E610000027309DD66DC047405628D2FD9CFA4440
31789	8	75	870	53832	\N	\N	42.306759018990398	Республика Дагестан, Гунибский район, селение Шулани, здание школы	Россия, республика Дагестан, Гунибский район, село Шулани	0101000020E6100000D5CDC5DFF6764740786000E143274540
31773	8	75	870	7728	\N	\N	42.348827	Республика Дагестан, Гунибский район, село Хутни, здание школы		0101000020E610000070287CB60E7A47401C7BF65CA62C4540
31780	8	75	870	8078	\N	\N	42.407511999999997	Республика Дагестан, Гунибский район, село Хоточ, СДК		0101000020E6100000FA2B64AE0C7A4740205D6C5A29344540
31779	8	75	870	8011	\N	\N	42.400587999999999	Республика Дагестан, Гунибский район, село Хиндах, СДК		0101000020E6100000FDFA2136587C4740C495B37746334540
31790	8	75	870	53870	\N	\N	42.308619999999998	Республика Дагестан, Гунибский район, сел. Унты, здание школы	Россия, республика Дагестан, Гунибский район, село Унты	0101000020E61000001250E108527947401D7233DC80274540
31764	8	75	870	7356	\N	\N	42.419693000000002	Республика Дагестан, Гунибский район, село Тлогоб, СДК		0101000020E610000056D80C704168474019AE0E80B8354540
31776	8	75	870	32885	\N	\N	42.282969999999999	Республика Дагестан, Гунибский район, селение Согратль, СДК		0101000020E6100000C4961E4DF57E4740E3DF675C38244540
31762	8	75	870	53669	\N	\N	42.337904999999999	Республика Дагестан, Гунибский район, селение Силта, здание Силтинской школы		0101000020E6100000F0F8F6AE41774740D3139678402B4540
31774	8	75	870	7790	\N	\N	42.395806999999998	Республика Дагестан, Гунибский район, село Салта, СДК		0101000020E61000003BC780ECF58847409143C4CDA9324540
31771	8	75	870	32853	\N	\N	42.361493000000003	Республика Дагестан, Гунибский район, селение Ругуджа, СДК		0101000020E6100000CB80B3942C754740D15D1267452E4540
31769	8	75	870	7591	\N	\N	42.284804999999999	Республика Дагестан, Гунибский район, село Обох, здание администрации села		0101000020E61000009B8F6B43C58447405F5E807D74244540
31777	8	75	870	7944	\N	\N	42.263055999999999	Республика Дагестан, Гунибский район, село Наказух, СДК		0101000020E6100000333509DE907447401F82AAD1AB214540
31757	8	75	870	53622	\N	\N	42.337904999999999	Республика Дагестан, Гунибский район, село Н.Кегер, СДК		0101000020E6100000F0F8F6AE41774740D3139678402B4540
31767	8	75	870	7485	\N	\N	42.252172000000002	Республика Дагестан, Гунибский район, село Мегеб, СДК		0101000020E61000000B7BDAE1AF854740C47B0E2C47204540
31761	8	75	870	7208	\N	\N	42.369633999999998	Республика Дагестан, Гунибский район, село Кудали, СДК		0101000020E61000006153E751F1894740ADBEBA2A502F4540
31758	8	75	870	7052	\N	\N	42.451180999999998	Республика Дагестан, Гунибский район, село Корода, здание администрации села	Россия, республика Дагестан, Гунибский район, село Корода	0101000020E6100000EB8D5A61FA6C4740CDC98B4CC0394540
31783	8	75	870	53452	\N	\N	42.365404346784999	Республика Дагестан, Гунибский район, село Чох-Коммуна, СДК	Россия, республика Дагестан, Гунибский район, село Коммуна	0101000020E610000035D3BD4EEA7B4740EEE9EA8EC52E4540
31755	8	75	870	6916	\N	\N	42.376468000000003	Республика Дагестан, Гунибский район, село Кегер, СДК		0101000020E6100000B22AC24D46834740CAFE791A30304540
31759	8	75	870	7112	\N	\N	42.469593000000003	Республика Дагестан, Гунибский район, село Карадах, СДК		0101000020E61000009D668176876E47401CB7989F1B3C4540
31753	8	75	870	53432	32920	\N	42.387194456899202	Республика Дагестан, Гунибский район, селение Гуниб, Площадь Шамиля, СДК	Россия, республика Дагестан, Гунибский район, село Гуниб	0101000020E610000022718FA50F7B47408D9AAF928F314540
31754	8	75	870	53432	32924	\N	42.3898413066986	Республика Дагестан, Гунибский район, селение Гуниб, Пирогова, здание больницы	Россия, республика Дагестан, Гунибский район, село Гуниб	0101000020E610000033C51C041D7B4740E9D1544FE6314540
31752	8	75	870	32701	\N	\N	42.469166999999999	Республика Дагестан, Гунибский район, селение Гонода, здание администрации		0101000020E6100000D5EB1681B164474064AE0CAA0D3C4540
31750	8	75	870	6682	\N	\N	42.241425999999997	Республика Дагестан,Гунибский район,с.Бухты, СДК	Россия, республика Дагестан, Гунибский район, село Бухты	0101000020E610000098C3EE3B867D4740B933130CE71E4540
31748	8	75	870	32667	\N	\N	42.303818999999997	Республика Дагестан, Гунибский район,селение Бацада, Сельский дом культуры		0101000020E6100000B6300BED9C744740A3737E8AE3264540
31765	8	75	870	53754	\N	\N	42.337904999999999	Республика Дагестан, Гунибский район, село Агада, здание школы		0101000020E6100000F0F8F6AE41774740D3139678402B4540
31731	8	75	704	53526	\N	\N	42.798368000000004	Республика Дагестан, Гумбетовский район, село Шпрингель		0101000020E610000034DB15FA604F4740231631EC30664540
31735	8	75	704	5912	\N	\N	42.756279999999997	Республика Дагестан, Гумбетовский район, село Шабдух	Россия, республика Дагестан, Гумбетовский район, село Шабдух	0101000020E6100000D9B11188D7354740374F75C8CD604540
31746	8	75	704	6473	\N	\N	42.721708999999997	Республика Дагестан, Гумбетовский район, село Читль	Россия, республика Дагестан, Гумбетовский район, село Читль	0101000020E61000000EBE30992A4047404B1DE4F5605C4540
31747	8	75	704	6541	\N	\N	42.785533000000001	Республика Дагестан, Гумбетовский район, село Чирката	Россия, республика Дагестан, Гумбетовский район, село Чирката	0101000020E6100000F8E3F6CB275B4740E27668588C644540
31741	8	75	704	53624	\N	\N	42.798368000000004	Республика Дагестан, Гумбетовский район, село Цияб-Цилитль		0101000020E610000034DB15FA604F4740231631EC30664540
31740	8	75	704	6153	\N	\N	42.810994999999998	Республика Дагестан, Гумбетовский район, село Цилитль	Россия, республика Дагестан, Гумбетовский район, село Цилитль	0101000020E61000006939D0436D354740191C25AFCE674540
31724	8	75	704	5281	\N	\N	42.720323999999998	Республика Дагестан, Гумбетовский район, село Цанатль	Россия, республика Дагестан, Гумбетовский район, село Цанатль	0101000020E61000001536035C904F47400F43AB93335C4540
31720	8	75	704	5085	\N	\N	42.795093000000001	Республика Дагестан, Гумбетовский район, село Тлярата	Россия, республика Дагестан, Гумбетовский район, село Тлярата	0101000020E610000080F10C1AFA434740A723809BC5654540
31723	8	75	704	5267	\N	\N	42.762582000000002	Республика Дагестан, Гумбетовский район, село Тантари	Россия, республика Дагестан, Гумбетовский район, село Тантари	0101000020E61000006F2C280CCA524740574277499C614540
31730	8	75	704	5607	\N	\N	42.678634000000002	Республика Дагестан, Гумбетовский район, село Средний Арадирих	Россия, республика Дагестан, Гумбетовский район, село Средний Арадирих	0101000020E61000008E5C37A5BC4A474012FA997ADD564540
31737	8	75	704	53923	\N	\N	42.798368000000004	Республика Дагестан, Гумбетовский район, село Первомайск		0101000020E610000034DB15FA604F4740231631EC30664540
31739	8	75	704	53965	\N	\N	42.798368000000004	Республика Дагестан, Гумбетовский район, село Отавтюбе		0101000020E610000034DB15FA604F4740231631EC30664540
31726	8	75	704	5398	\N	\N	42.782111999999998	Республика Дагестан, Гумбетовский район, село Новое  Аргвани	Россия, республика Дагестан, Гумбетовский район, село Новые Аргвани	0101000020E6100000E5D53906644D474092E7FA3E1C644540
31542	8	75	1817	28292	\N	\N	41.538100999999997	Республика Дагестан, Ахтынский район, село Гогаз, клуб		0101000020E6100000A25D85949FD64740F2785A7EE0C44440
31729	8	75	704	5584	\N	\N	42.692658000000002	Республика Дагестан, Гумбетовский район, село Нижний  Арадирих	Россия, республика Дагестан, Гумбетовский район, село Нижний Арадирих	0101000020E6100000B13385CE6B48474009A87004A9584540
31744	8	75	704	6366	\N	\N	42.703457999999998	Республика Дагестан, Гумбетовский район, село Нижнее Инхо	Россия, республика Дагестан, Гумбетовский район, село Нижнее Инхо	0101000020E6100000F1457BBC90404740060E68E90A5A4540
31719	8	75	704	53602	\N	\N	42.798368000000004	Республика Дагестан, Гумбетовский район, сельсовет Мехельтинский,село Нарыш		0101000020E610000034DB15FA604F4740231631EC30664540
31727	8	75	704	53761	\N	\N	43.605150000000002	Республика Дагестан, Гумбетовский район, село Нанибика	Россия, республика Дагестан, Бабаюртовский район, село Нанибика	0101000020E6100000CE5147C7D56E47405396218E75CD4540
31717	8	75	704	4906	\N	\N	42.791678996266199	сельсовет Мехельтинский, Мехельта сельский	Россия, республика Дагестан, Гумбетовский район, село Мехельта	0101000020E6100000B7D5AC33BE3F47400AF7CABC55654540
31716	8	75	704	4906	\N	\N	42.792187419142302	сельсовет Мехельтинский, Мехельта райцентр		0101000020E61000001669E21DE03F47407EA8346266654540
31732	8	75	704	53616	\N	\N	42.798368000000004	Республика Дагестан, Гумбетовский район, село Кучкаркум		0101000020E610000034DB15FA604F4740231631EC30664540
31722	8	75	704	5176	\N	\N	42.745668000000002	Республика Дагестан, Гумбетовский район, село Кунзах	Россия, республика Дагестан, Гумбетовский район, село Кунзах	0101000020E6100000BEBED6A5465447403DD68C0C725F4540
31743	8	75	704	53742	\N	\N	42.705127979604399	Республика Дагестан, Гумбетовский район, село Килятль	Россия, республика Дагестан, Гумбетовский район, село Килятли	0101000020E61000005DE2C803913B474038BF61A2415A4540
31736	8	75	704	5923	\N	\N	42.734476999999998	Республика Дагестан, Гумбетовский район, село Ичичали	Россия, республика Дагестан, Гумбетовский район, село Ичичали	0101000020E6100000EBC5504EB43347400455A357035E4540
31738	8	75	704	6059	\N	\N	42.777540000000002	Республика Дагестан, Гумбетовский район, село Ингиши	Россия, республика Дагестан, Гумбетовский район, село Ингиши	0101000020E6100000B6BFB33D7A4547407AAA436E86634540
31721	8	75	704	5149	\N	\N	42.722701999999998	Республика Дагестан, Гумбетовский район, село Игали	Россия, республика Дагестан, Гумбетовский район, село Игали	0101000020E6100000C7F2AE7AC04A47407C60C77F815C4540
31734	8	75	704	5781	\N	\N	42.843102092519899	Республика Дагестан, Гумбетовский район, село Новый Данух	Россия, республика Дагестан, Гумбетовский район, село Данух	0101000020E6100000F7E5CC76855047409A982EC4EA6B4540
31733	8	75	704	5781	\N	\N	42.843620000000001	Республика Дагестан, Гумбетовский район, село Данух	Россия, республика Дагестан, Гумбетовский район, село Данух	0101000020E6100000730E9E094D50474032207BBDFB6B4540
31742	8	75	704	6234	\N	\N	42.812814000000003	Республика Дагестан, Гумбетовский район, село Гадари	Россия, республика Дагестан, Гумбетовский район, село Гадари	0101000020E61000006E6DE179A950474090DD054A0A684540
31728	8	75	704	53542	\N	\N	42.672645209347998	Республика Дагестан, Гумбетовский район, село Верхний Арадерих	Россия, республика Дагестан, Гумбетовский район, село Верхний Арадирих	0101000020E610000064B0E2546B4D4740B2683A3B19564540
31745	8	75	704	53498	\N	\N	42.707156348295001	Республика Дагестан, Гумбетовский район, село Верхнее Инхо	Россия, республика Дагестан, Гумбетовский район, село Верннее Инхо	0101000020E610000035B401D880404740C8957A16845A4540
31725	8	75	704	5372	\N	\N	42.808025999999998	Республика Дагестан, Гумбетовский район, село Аргвани	Россия, республика Дагестан, Гумбетовский район, село Аргвани	0101000020E61000000BD12170244A4740AA285E656D674540
31701	8	75	609	4064	\N	\N	42.538773999999997	Республика Дагестан, Гергебильский район, село Чалда, здание школы		0101000020E61000004030478FDF754740B1F7E28BF6444540
31711	8	75	609	4627	\N	\N	42.457667000000001	Республика Дагестан, Гергебильский район, село  Хвартикуни, здание клуба		0101000020E610000067D311C0CD804740AEBA0ED5943A4540
31713	8	75	609	4749	\N	\N	42.467543999999997	Республика Дагестан, Гергебильский район, село  Хварада, здание библиотеки		0101000020E6100000944BE3175E7F474073B8567BD83B4540
31712	8	75	609	53875	\N	\N	42.469822264985098	Республика Дагестан, Гергебильский район, село Тунзи, здание клуба	Россия, республика Дагестан, Гергебильский район, село Тунзы	0101000020E610000058FE7C5BB07C47407D789620233C4540
31709	8	75	609	4482	\N	\N	42.448314000000003	Республика Дагестан, Гергебильский район, село Мурада, здание клуба		0101000020E6100000A7EB89AE0B794740632B685A62394540
31706	8	75	609	4313	\N	\N	42.561833999999998	Республика Дагестан, Гергебильский район, село Могох, здание клуба		0101000020E610000097AE601BF1744740F3E32F2DEA474540
31705	8	75	609	4281	\N	\N	42.487281000000003	Республика Дагестан, Гергебильский район, село Маали, здание школы		0101000020E610000066F9BA0CFF754740297B4B395F3E4540
31703	8	75	609	53668	\N	\N	42.523871	Республика Дагестан, Гергебильский район, село Курми, здание клуба		0101000020E61000005B43A9BD88824740522976340E434540
31704	8	75	609	4209	\N	\N	42.577837000000002	Республика Дагестан, Гергебильский район, село Кудутль, здание клуба	Россия, республика Дагестан, Гергебильский район, село Кудутль	0101000020E61000009CC420B0728247409AB51490F6494540
31700	8	75	609	53574	\N	\N	42.523871	Республика Дагестан, Гергебильский район, сельсовет Кикунинский, здание школы		0101000020E61000005B43A9BD88824740522976340E434540
31702	8	75	609	4117	\N	\N	42.478371000000003	Республика Дагестан, Гергебильский район,село Ипута, здание библиотеки		0101000020E610000066BFEE74E77B47406B2DCC423B3D4540
37700	3	28	\N	7525	23200	\N	55.072916999999997	город Советск, Победы, 2		0101000020E610000020EC14AB06E135404529215855894B40
31708	8	75	609	4472	\N	\N	42.462809	Республика Дагестан, Гергебильский район, село Дарада, здание клуба		0101000020E610000078279F1EDB784740B1A547533D3B4540
31707	8	75	609	4389	\N	\N	42.591067000000002	Республика Дагестан, Гергебильский район, село Гоцоб, здание библиотеки		0101000020E610000000FDBE7FF36E4740575F5D15A84B4540
31710	8	75	609	53867	\N	\N	42.523871	Республика Дагестан, Гергебильский район, село Горбони, здание клуба		0101000020E61000005B43A9BD88824740522976340E434540
31698	8	75	609	3876	\N	\N	42.505037000000002	Республика Дагестан, Гергебильский район, село Гергебиль, здание клуба		0101000020E6100000AB764D486B8847408E226B0DA5404540
31699	8	75	609	3960	\N	\N	42.536394999999999	Республика Дагестан, Гергебильский район, село Аймаки, здание школы		0101000020E6100000E754320054914740745E6397A8444540
31678	8	75	223	53479	\N	\N	42.807597623683797	Республика Дагестан, Буйнакский район, сельсовет Эрпелинский, здание средней школы, школа	Россия, республика Дагестан, Буйнакский район, село Эрпели	0101000020E610000099107349D57E474052280B5F5F674540
31677	8	75	223	2638	\N	\N	42.961990999999998	Республика Дагестан, Буйнакский район, село Чиркей, здание дом культуры		0101000020E61000004CE141B3EB7C4740EE056685227B4540
31676	8	75	223	2638	\N	\N	42.961990999999998	Республика Дагестан, Буйнакский район, село Чиркей, здании средней школы		0101000020E61000004CE141B3EB7C4740EE056685227B4540
31675	8	75	223	2638	\N	\N	42.961990999999998	Республика Дагестан, Буйнакский район, село Чиркей, здание администрации села, администрация		0101000020E61000004CE141B3EB7C4740EE056685227B4540
31674	8	75	223	2586	\N	\N	42.630361999999998	Республика Дагестан, Буйнакский район, село Чанкурбе, в здании сельского клуба	Россия, республика Дагестан, Буйнакский район, село Чанкурбе	0101000020E61000000306499F56A747401152B7B3AF504540
31664	8	75	223	2010	\N	\N	42.635522000000002	Республика Дагестан, Буйнакский район, село Чабанмахи, здание администрации		0101000020E61000006859F78F85A24740BBF1EEC858514540
31673	8	75	223	2551	\N	\N	42.841954000000001	Республика Дагестан, Буйнакский район, село Халимбекаул, здание средней школы		0101000020E61000001BD9959691924740425E0F26C56B4540
32490	8	75	223	53483	\N	\N	42.870056767974503	Республика Дагестан, город Махачкала, Ленинский район, СЕЛО ТАЛГИ	Россия, республика Дагестан, Буйнакский район, село Талги	0101000020E6100000ECC1A4F8F8BA4740F4531C075E6F4540
31662	8	75	223	1896	\N	\N	42.899425999999998	Республика Дагестан, Буйнакский район, село Такалай, здание средней школы		0101000020E6100000B69DB646049547400796236420734540
31661	8	75	223	1849	\N	\N	42.854757999999997	Республика Дагестан, Буйнакский район, село Новый-Кумух, здание администрации, администрация		0101000020E6100000813D26529A97474047FFCBB5686D4540
31655	8	75	223	1510	\N	\N	42.845610000000001	Республика Дагестан, Буйнакский район, село Нижний-Каранай, бывшее здание медпункта, здание медпункта		0101000020E610000090DB2F9FAC784740D595CFF23C6C4540
31667	8	75	223	2107	\N	\N	42.700861000000003	Республика Дагестан, Буйнакский район, село Нижний Дженгутай, здание сльского клуба		0101000020E6100000B821C66B5E9F47405C0531D0B5594540
31666	8	75	223	2107	\N	\N	42.700861000000003	Республика Дагестан, Буйнакский район, село Нижний Дженгутай, здание средней школы		0101000020E6100000B821C66B5E9F47405C0531D0B5594540
31672	8	75	223	2244	\N	\N	42.762250999999999	Республика Дагестан, Буйнакский район, село Нижнее Казанище, здание средней школы №3, школа №3		0101000020E61000002366F6798C944740F12BD67091614540
31670	8	75	223	2244	\N	\N	42.762250999999999	Республика Дагестан, Буйнакский район, село Нижнее Казанище, здание средней школы №4, школа №4		0101000020E61000002366F6798C944740F12BD67091614540
31669	8	75	223	2244	\N	\N	42.762250999999999	Республика Дагестан, Буйнакский район, село Нижнее Казанище, здание средней школы №1		0101000020E61000002366F6798C944740F12BD67091614540
31668	8	75	223	2244	\N	\N	42.762250999999999	Республика Дагестан, Буйнакский район, село Нижнее Казанище, здание дома культуры		0101000020E61000002366F6798C944740F12BD67091614540
31665	8	75	223	53771	\N	\N	42.854664999999997	Республика Дагестан, Буйнакский район, село Манасаул, здание дома культуры, дом культуры		0101000020E61000001AFA27B8588B47409604A8A9656D4540
31660	8	75	223	1748	\N	\N	42.836143	Республика Дагестан, Буйнакский район, село Кафыр-Кумух, бывшее здание магазина сельпо		0101000020E61000003ECE3461FB934740C1E3DBBB066B4540
31663	8	75	223	53568	\N	\N	42.614287363311099	Республика Дагестан, Буйнакский район, село Карамахи, здание средней школы	Россия, республика Дагестан, Буйнакский район, село Кара-Махи	0101000020E6100000FA2AF9D85DA24740D1ADD7F4A04E4540
31659	8	75	223	1736	\N	\N	42.618912000000002	Республика Дагестан, Буйнакский район, село Кадар, здание дома культуры, дом культуры		0101000020E610000032AF230ED9A447400D8D2782384F4540
31656	8	75	223	1544	\N	\N	42.634712999999998	Республика Дагестан, Буйнакский район, село Дуранги, здание средней школы, школа		0101000020E610000057D0B4C4CA9C47404BAC8C463E514540
31654	8	75	223	53627	\N	\N	42.8243426028816	Республика Дагестан, Буйнакский район, сельсовет Верхне-Каранаевский, здание сельского клуба, клуб	Россия, республика Дагестан, Буйнакский район, село Верхний Каранай	0101000020E6100000533E0455A3734740E0D7481284694540
31653	8	75	223	1391	\N	\N	42.676107999999999	Республика Дагестан, Буйнакский район, село Верхний Дженгутай, здание сельского клуба, клуб		0101000020E6100000E1B20A9B019E47403048FAB48A564540
31658	8	75	223	53782	\N	\N	42.849478151942797	Республика Дагестан, Буйнакский район, сельсовет Ишкартынский, здание сельского клуба, клуб	Россия, республика Дагестан, Буйнакский район, село Верхние Ишкарты	0101000020E61000000D6C9560717A4740F355F2B1BB6C4540
31652	8	75	223	1197	\N	\N	42.7327533545281	Республика Дагестан, Буйнакский район, сельсовет Верхнеказанищенский, здание сельского клуба, клуб	Россия, республика Дагестан, Буйнакский район, село Верхнее Казанище	0101000020E6100000630D17B9A7914740E085ADD9CA5D4540
31651	8	75	223	1197	\N	\N	42.730286	Республика Дагестан, Буйнакский район, село Верхне-Казанище, здание средней школы №2, школа №2		0101000020E6100000CA8CB7955E914740035DFB027A5D4540
31650	8	75	223	1197	\N	\N	42.730286	Республика Дагестан, Буйнакский район, село Верхний-Казанище, Здание средней школы №1, школ №1		0101000020E6100000CA8CB7955E914740035DFB027A5D4540
31649	8	75	223	1138	\N	\N	42.756081999999999	Республика Дагестан, Буйнакский район, село Буглен, Здание средней школы, школа		0101000020E6100000C3F352B131994740118C834BC7604540
31647	8	75	223	1017	\N	\N	42.803654000000002	Республика Дагестан, Буйнакский район, село Атланаул, Здание средней школы, школа		0101000020E61000009A7D1EA33C93474059A65F22DE664540
31644	8	75	223	854	\N	\N	42.651864000000003	Республика Дагестан, Буйнакский район, село Аркас, Здание сельского клуба, сельский клуб		0101000020E61000005F9B8D95989147404AB8904770534540
31648	8	75	223	53572	\N	\N	42.855801623459897	Республика Дагестан, Буйнакский район, село Акайтала, Здание сельского клуба, клуб	Россия, республика Дагестан, Буйнакский район	0101000020E6100000F3E505D8478B4740FAEC80EB8A6D4540
32060	8	75	223	53707	\N	\N	42.923326768640997	Республика Дагестан, Карабудахкентский район, село Агачаул, Школа	Россия, республика Дагестан, Буйнакский район, село Агачаул	0101000020E6100000DC2C5E2C0CBB4740C44142942F764540
31603	8	75	21	53482	\N	\N	42.745117999999998	Республика Дагестан, Ботлихский район, сельсовет Ботлихский, участок Чиртинский		0101000020E6100000336C94F59B21474099D4D006605F4540
31599	8	75	21	53451	\N	\N	42.745117999999998	Республика Дагестан, Ботлихский район, сельсовет Ансалтинский, кутан Старокаратюбинский		0101000020E6100000336C94F59B21474099D4D006605F4540
31639	8	75	21	53887	\N	\N	42.745117999999998	Республика Дагестан, Ботлихский район, сельсовет Чанковский, кутан Прикутанский		0101000020E6100000336C94F59B21474099D4D006605F4540
31614	8	75	21	53966	\N	\N	42.640144463393703	Республика Дагестан, Ботлихский район, сельсовет Годоберинский, кутан Комархуторский	Россия, республика Дагестан, Ботлихский район	0101000020E6100000B3B6291E170D4740855D143DF0514540
31631	8	75	21	53477	\N	\N	42.745117999999998	Республика Дагестан, Ботлихский район, сельсовет Рикванинский, кутан Джугутский		0101000020E6100000336C94F59B21474099D4D006605F4540
31638	8	75	21	53826	\N	\N	42.718669531118003	Республика Дагестан, Ботлихский район, сельсовет Чанковский, участок Шивортинский	Россия, республика Дагестан, Ботлихский район, село Чанко	0101000020E6100000E8137992741F4740E44EE960FD5B4540
31637	8	75	21	53826	\N	\N	42.718481766252502	Республика Дагестан, Ботлихский район, сельсовет Чанковский	Россия, республика Дагестан, Ботлихский район, село Чанко	0101000020E6100000BE69FAEC801F4740E161DA37F75B4540
31593	8	75	21	53620	\N	\N	42.737526662804598	Республика Дагестан, Ботлихский район, село Цибильта	Россия, республика Дагестан, Ботлихский район, село Цибилта	0101000020E6100000BE2F2E55691F47406075E448675E4540
31635	8	75	21	53905	\N	\N	42.612482661988103	Республика Дагестан, Ботлихский район, сельсовет Хелетуринский	Россия, республика Дагестан, Ботлихский район, село Хелетури	0101000020E6100000AD84EE92381D4740902DCBD7654E4540
31634	8	75	21	172	\N	\N	42.671965999999998	Республика Дагестан, Ботлихский район, село Тлох, участок Тлох 2		0101000020E610000088F4DBD7813B474010035DFB02564540
31633	8	75	21	172	\N	\N	42.671965999999998	Республика Дагестан, Ботлихский район, село Тлох	Россия, республика Дагестан, Ботлихский район, село Тлох	0101000020E610000088F4DBD7813B474010035DFB02564540
31605	8	75	21	31279	\N	\N	42.718536	Республика Дагестан, Ботлихский район, село Тасута	Россия, республика Дагестан, Ботлихский район, село Тасута	0101000020E6100000F8FBC56CC91C4740D47FD6FCF85B4540
31632	8	75	21	26	\N	\N	42.706617999999999	Республика Дагестан, Ботлихский район, село Тандо	Россия, республика Дагестан, Ботлихский район, село Тандо	0101000020E6100000F7E5CC7685164740E9616875725A4540
31613	8	75	21	53555	\N	\N	42.745117999999998	Республика Дагестан, Ботлихский район, беледи		0101000020E6100000336C94F59B21474099D4D006605F4540
31624	8	75	21	32174	\N	\N	42.71425	Республика Дагестан, Ботлихский район, село Рушуха	Россия, республика Дагестан, Ботлихский район, село Рушуха	0101000020E6100000A69D9ACB0D2447408195438B6C5B4540
31630	8	75	21	53827	\N	\N	42.781092999999998	Республика Дагестан, Ботлихский район, сельсовет Рикванинский	Россия, республика Дагестан, Ботлихский район, село Риквани	0101000020E61000000664AF777F2847403811FDDAFA634540
31629	8	75	21	32267	\N	\N	42.688251000000001	Республика Дагестан, Ботлихский район, село Рахата 3	Россия, республика Дагестан, Ботлихский район, село Рахата	0101000020E61000003A03232F6B1247403B38D89B18584540
31628	8	75	21	32267	\N	\N	42.688251000000001	Республика Дагестан, Ботлихский район, село Рахата, участок Рахата 2		0101000020E61000003A03232F6B1247403B38D89B18584540
31626	8	75	21	32267	\N	\N	42.688251000000001	Республика Дагестан, Ботлихский район, село Рахата	Россия, республика Дагестан, Ботлихский район, село Рахата	0101000020E61000003A03232F6B1247403B38D89B18584540
31623	8	75	21	53880	\N	\N	42.672704834146799	Республика Дагестан, Ботлихский район, село Ортоколо	Россия, республика Дагестан, Ботлихский район, село Ортаколо	0101000020E61000004D2F3196E9314740876D8B321B564540
31541	8	75	1817	28257	\N	\N	41.457659	Республика Дагестан, Ахтынский район, село Гдынк, клуб		0101000020E61000007AA86DC328D447402BDCF29194BA4440
31625	8	75	21	32197	\N	\N	42.646306000000003	Республика Дагестан, Ботлихский район, село Нижнее-Инхело	Россия, республика Дагестан, Ботлихский район, село Нижнее Инхело	0101000020E610000082ACA7565F214740B39AAE27BA524540
31622	8	75	21	53465	\N	\N	42.684055000000001	Республика Дагестан, Ботлихский район, сельсовет Мунинский, участок Заречный	Россия, республика Дагестан, Ботлихский район, село Муни	0101000020E61000005CFFAECF9C27474028D53E1D8F574540
31621	8	75	21	53465	\N	\N	42.683597639572596	Республика Дагестан, Ботлихский район, сельсовет Мунинский		0101000020E61000002BDF3312A127474036CEA62380574540
31620	8	75	21	32009	\N	\N	42.661974999999998	Республика Дагестан, Ботлихский район, село Миарсо	Россия, республика Дагестан, Ботлихский район, село Миарсо	0101000020E61000002F6EA301BC17474082E2C798BB544540
31619	8	75	21	31925	\N	\N	42.742376999999998	Республика Дагестан, Ботлихский район, село Кижани, кутан Стареартезианский	Россия, республика Дагестан, Ботлихский район, село Кижани	0101000020E6100000D89B1892932F4740BB26A435065F4540
31618	8	75	21	31925	\N	\N	42.742376999999998	Республика Дагестан, Ботлихский район, село Кижани	Россия, республика Дагестан, Ботлихский район, село Кижани	0101000020E6100000D89B1892932F4740BB26A435065F4540
31617	8	75	21	53869	\N	\N	42.652940883062698	Республика Дагестан, Ботлихский район, село Кванхидатли	Россия, республика Дагестан, Ботлихский район	0101000020E61000000A2E56D460204740D89B189293534540
31616	8	75	21	31773	\N	\N	42.732405	Республика Дагестан, Ботлихский район, село Зило, кутан Каплановский	Россия, республика Дагестан, Ботлихский район, село Зило	0101000020E61000006EBE11DDB3284740A4367172BF5D4540
31615	8	75	21	31773	\N	\N	42.732405	Республика Дагестан, Ботлихский район, село Зило	Россия, республика Дагестан, Ботлихский район, село Зило	0101000020E61000006EBE11DDB3284740A4367172BF5D4540
31612	8	75	21	53881	\N	\N	42.669534991098303	Республика Дагестан, Ботлихский район, село Зибирхали	Россия, республика Дагестан, Ботлихский район, разрушен.,полуразр.нас.пункты Зиберхали	0101000020E61000006A6803B0010947408143A852B3554540
31592	8	75	21	30631	\N	\N	42.789760999999999	Республика Дагестан, Ботлихский район, село Гунха	Россия, республика Дагестан, Ботлихский район, село Гунха	0101000020E6100000BC7A15191D244740005471E316654540
31609	8	75	21	31394	\N	\N	42.799407000000002	Республика Дагестан, Ботлихский район, село Гагатли, кутан Алибеготарский	Россия, республика Дагестан, Ботлихский район, село Гагатли	0101000020E61000004B21904B1C254740C498F4F752664540
31608	8	75	21	31394	\N	\N	42.799407000000002	Республика Дагестан, Ботлихский район, село Гагатли, участок Бочонаевский	Россия, республика Дагестан, Ботлихский район, село Гагатли	0101000020E61000004B21904B1C254740C498F4F752664540
31607	8	75	21	31394	\N	\N	42.799407000000002	Республика Дагестан, Ботлихский район, село Гагатли	Россия, республика Дагестан, Ботлихский район, село Гагатли	0101000020E61000004B21904B1C254740C498F4F752664540
31604	8	75	21	32647	\N	\N	42.665198460251403	Республика Дагестан, Ботлихский район, сельсовет Ботлихский, участок Новоботлихский	Россия, республика Дагестан, Ботлихский район, село Ботлих	0101000020E61000002FA704C4241C4740ABAE433525554540
31602	8	75	21	32647	\N	\N	42.6647240003186	Республика Дагестан, Ботлихский район, сельсовет Ботлихский	Россия, республика Дагестан, Ботлихский район, село Ботлих	0101000020E6100000CAA7C7B60C1C4740E36E10AD15554540
31606	8	75	21	31330	\N	\N	42.682265999999998	Республика Дагестан, Ботлихский район, село Ашино	Россия, республика Дагестан, Ботлихский район, село Ашино	0101000020E6100000F23FF9BB771447401C96067E54574540
31601	8	75	21	31040	\N	\N	42.766865000000003	Республика Дагестан, Ботлихский район, село Ашали, кутан Айтхан	Россия, республика Дагестан, Ботлихский район, село Ашали	0101000020E61000001EC2F869DC27474039B9DFA128624540
31600	8	75	21	31040	\N	\N	42.766865000000003	Республика Дагестан, Ботлихский район, село Ашали	Россия, республика Дагестан, Ботлихский район, село Ашали	0101000020E61000001EC2F869DC27474039B9DFA128624540
31598	8	75	21	53502	\N	\N	42.690183053956297	Республика Дагестан, Ботлихский район, сельсовет Ансалтинский, кутан Чубутлинский	Россия, республика Дагестан, Ботлихский район, село Ансалта	0101000020E6100000C45C52B5DD0E4740A9A0A2EA57584540
31597	8	75	21	53502	\N	\N	42.6891699590524	Республика Дагестан, Ботлихский район, сельсовет Ансалтинский, участок Байчовский	Россия, республика Дагестан, Ботлихский район, село Ансалта	0101000020E61000000FB56D18050F474031B1F9B836584540
31591	8	75	21	53710	\N	\N	42.782682746751597	Республика Дагестан, Ботлихский район, сельсовет Андийский, участок Саталалский	Россия, республика Дагестан, Ботлихский район, село Анди	0101000020E6100000895C70067F2147404D11E0F42E644540
31590	8	75	21	53710	\N	\N	42.782178567148797	Республика Дагестан, Ботлихский район, сельсовет Андийский	Россия, республика Дагестан, Ботлихский район, село Анди	0101000020E6100000513239B5332247401A4F04711E644540
31589	8	75	21	30425	\N	\N	42.611758999999999	Республика Дагестан, Ботлихский район, село Алак, кутан Бурукутан	Россия, республика Дагестан, Ботлихский район, село Алак	0101000020E6100000A8E15B58371847404F04711E4E4E4540
31588	8	75	21	30425	\N	\N	42.611758999999999	Республика Дагестан, Ботлихский район, село Алак	Россия, республика Дагестан, Ботлихский район, село Алак	0101000020E6100000A8E15B58371847404F04711E4E4E4540
31540	8	75	1817	28211	\N	\N	41.308767000000003	Республика Дагестан, Ахтынский район, село Гдым, клуб		0101000020E610000085B53176C2BB4740C28A53AD85A74440
33173	8	75	1200	11646	\N	\N	42.123193999999998	Республика Дагестан, Бежтинский участок в составе Цунтинского района, село Тлядал	Россия, республика Дагестан, Бежтинский Участок район, село Тлядал	0101000020E610000047AB5AD2511E47401E882CD2C40F4540
33174	8	75	1200	53962	\N	\N	42.139238960294698	Республика Дагестан, Бежтинский участок в составе Цунтинского района, сельсовет Гунзибский	Россия, республика Дагестан, Бежтинский Участок район, село Гунзиб	0101000020E61000001A868F8829214740F4A96395D2114540
33172	8	75	1200	11599	\N	\N	42.133519	Республика Дагестан, Бежтинский участок в составе Цунтинского района, село Бежта	Россия, республика Дагестан, Бежтинский Участок район, село Бежта	0101000020E6100000C7116BF12910474083328D2617114540
31565	8	75	256	29352	\N	\N	43.570093	Республика Дагестан, Бабаюртовский район, сельсовет Адиль-Янгиюртовский, село Чанкаюрт, Здание школы		0101000020E610000051F701486D484740DA56B3CEF8C84540
33222	8	75	256	53538	\N	\N	43.586693645962399	Республика Дагестан, Чародинский район, сельсовет Гилибский, село Цадах	Россия, республика Дагестан, Бабаюртовский район	0101000020E61000008577B988EF8647403561FBC918CB4540
31570	8	75	256	29577	\N	\N	43.630752999999999	Республика Дагестан, Бабаюртовский район, сельсовет Хасанайский, село Хасанай, Здание СДК		0101000020E6100000CFBA46CB815A47404C6DA983BCD04540
31987	8	75	256	53828	\N	\N	43.450081932410498	при кутанное хозяйство Хамзаюрт, здание школы		0101000020E6100000483140A2097E4740574277499CB94540
31564	8	75	256	53464	\N	\N	43.609168979133102	Республика Дагестан, Бабаюртовский район, село Хамаматюрт, Здание СДК	Россия, республика Дагестан, Бабаюртовский район, село Хамамат-Юрт	0101000020E6100000C2887D0228404740575EF23FF9CD4540
31563	8	75	256	29264	\N	\N	43.534379999999999	Республика Дагестан, Бабаюртовский район, село Уцмиюрт, Здание СДК		0101000020E6100000787B1002F23B474078D1579066C44540
31580	8	75	256	53476	\N	\N	43.583685214876603	Республика Дагестан, Бабаюртовский район, сельсовет Геметюбинский, село Алимпашаюрт, Здание школы	Россия, республика Дагестан, Бабаюртовский район, село Тюпкутан	0101000020E6100000EB8CEF8B4B6947403815A930B6CA4540
31985	8	75	256	17868	\N	\N	43.596729000000003	Республика Дагестан Казбековский район, село Турщунай, здание школы		0101000020E610000078EC67B11455474093C9A99D61CC4540
31568	8	75	256	17868	\N	\N	43.601204444965902	Республика Дагестан, Бабаюртовский район, сельсовет Туршунайский, село Туршунай, Здание сельского клуба	Россия, республика Дагестан, Бабаюртовский район, село Турщунай	0101000020E61000006AA164726A554740B91CAF40F4CC4540
31986	8	75	256	30135	\N	\N	43.559983652738502	Республика Дагестан, прикутанного хозяйства Учтюбе, здание школы	Россия, республика Дагестан, Бабаюртовский район, село Татаюрт	0101000020E6100000438CD7BCAA7F47404224438EADC74540
31582	8	75	256	30135	\N	\N	43.560667000000002	Республика Дагестан, Бабаюртовский район, село Татаюрт, Здание школы		0101000020E610000055F7C8E6AA7F47402579AEEFC3C74540
31584	8	75	256	53537	\N	\N	43.578963032691597	Республика Дагестан, Бабаюртовский район, сельсовет Тамазатюбинский, село Тамазатюбе, Здание сельской администрации	Россия, республика Дагестан, Бабаюртовский район, село Тамаза-Тюбе	0101000020E6100000F5B86FB54E9447400A4CA7751BCA4540
31585	8	75	256	30226	\N	\N	43.662579999999998	Республика Дагестан, Бабаюртовский район, сельсовет Тамазатюбинский, село Тамазатюбе Старое, Здание сельского клуба		0101000020E61000009D9CA1B8E3954740E97DE36BCFD44540
31569	8	75	256	29540	\N	\N	43.599033111773302	Республика Дагестан, Бабаюртовский район, сельсовет Туршунайский, село Советское, Здание сельского клуба	Россия, республика Дагестан, Бабаюртовский район, село Советское	0101000020E61000008B6EBDA607594740C51C041DADCC4540
32306	8	75	256	1071	\N	\N	43.592348000000001	Республика Дагестан,Лакский район, село, Сангар, Здание сельского клуба	Россия, республика Дагестан, Бабаюртовский район, село Сангар	0101000020E6100000FDD8243FE2954740EEEC2B0FD2CB4540
31583	8	75	256	30183	\N	\N	43.600875000000002	Республика Дагестан, Бабаюртовский район, село Новокаре, Здание школы		0101000020E6100000AA27F38FBE7B4740F4FDD478E9CC4540
31586	8	75	256	30339	\N	\N	43.551504496771202	Республика Дагестан, Бабаюртовский район, сельсовет Новокосинский, село Новая Коса, Здание сельской администрации	Россия, республика Дагестан, Бабаюртовский район, село Новая Коса	0101000020E61000002922C32ADEAE47407DCEDDAE97C64540
31579	8	75	256	29999	\N	\N	43.628241000000003	Республика Дагестан, Бабаюртовский район, сельсовет Мужукайский, село Мужукай, Здание сельского клуба	Россия, республика Дагестан, Бабаюртовский район, село Мужукай	0101000020E6100000D1B2EE1F0B734740D0807A336AD04540
31571	8	75	256	29627	\N	\N	43.663226000000002	Республика Дагестан, Бабаюртовский район, село Люксембург, Здание школы		0101000020E6100000C1A8A44E405F4740AFEDED96E4D44540
33066	8	75	256	53633	\N	\N	43.431838186930101	Республика Дагестан, Хунзахский район, кутан Львовский 7, здание НШ	Россия, республика Дагестан, Бабаюртовский район, село Львовский 7-й	0101000020E61000008369183E229A4740C495B37746B74540
31983	8	75	256	53508	\N	\N	43.366483405864201	Республика Дагестан, прикутанного хозяйства Львовское №6, здание школы №2	Россия, республика Дагестан, Бабаюртовский район, село Львовский 6-й	0101000020E6100000624A24D1CBA047401EC539EAE8AE4540
31756	8	75	256	6979	\N	\N	43.388350000000003	Республика Дагестан, Бабаюртовский район, село Львовский, Здание СХПК	Россия, республика Дагестан, Бабаюртовский район, село Львовский 1-й	0101000020E6100000EB8D5A61FA92474068B3EA73B5B14540
31587	8	75	256	6979	\N	\N	43.388350000000003	Республика Дагестан, Бабаюртовский район, село Львовский, Здание сельской администрации	Россия, республика Дагестан, Бабаюртовский район, село Львовский 1-й	0101000020E6100000EB8D5A61FA92474068B3EA73B5B14540
31595	8	75	256	53765	\N	\N	42.745117999999998	Республика Дагестан, Ботлихский район,сельсовет Андийский, кутан Бутуш		0101000020E6100000336C94F59B21474099D4D006605F4540
31760	8	75	256	53874	\N	\N	43.586210000000001	Республика Дагестан, Бабаюртовский район,Кородинский кутан, здание АФ		0101000020E6100000FD6B79E57A854740494BE5ED08CB4540
31572	8	75	256	29655	\N	\N	43.540196000000002	Республика Дагестан, Бабаюртовский район, село Герменчик, Здание СДК		0101000020E6100000B9C5FCDCD05C47400BB77C2425C54540
31581	8	75	256	53664	\N	\N	43.586210000000001	Республика Дагестан, Бабаюртовский район, сельсовет Геметюбинский, село Геметюбе, Здание школы		0101000020E6100000FD6B79E57A854740494BE5ED08CB4540
33230	8	75	256	29708	75513	\N	43.601828187652103	Бабаюртовская зона	Россия, республика Дагестан, Бабаюртовский район, село Бабаюрт	0101000020E61000002E73BA2C2664474096E82CB308CD4540
31578	8	75	256	29708	33083	\N	43.605195999999999	Республика Дагестан, Бабаюртовский район, село Бабаюрт, Мира 129, Здание ПМК-1 Газпром		0101000020E6100000A471A8DF85634740C3D5011077CD4540
31575	8	75	256	29708	33093	\N	43.605195999999999	Республика Дагестан, Бабаюртовский район, село Бабаюрт, Ленина 1, Здание школы		0101000020E6100000A471A8DF85634740C3D5011077CD4540
31573	8	75	256	29708	33013	\N	43.605195999999999	Республика Дагестан, Бабаюртовский район, село Бабаюрт, Ирчи-Казака 80, Здание школы		0101000020E6100000A471A8DF85634740C3D5011077CD4540
31577	8	75	256	29708	33024	\N	43.605195999999999	Республика Дагестан, Бабаюртовский район, село Бабаюрт, Дж. Алиева 61, Здание школы		0101000020E6100000A471A8DF85634740C3D5011077CD4540
31574	8	75	256	29708	33024	\N	43.605195999999999	"Республика Дагестан, Бабаюртовский район, село Бабаюрт, Дж. Алиева 24, Здание МУ ""Управление Культуры"""		0101000020E6100000A471A8DF85634740C3D5011077CD4540
31576	8	75	256	29708	33080	\N	43.605195999999999	Республика Дагестан, Бабаюртовский район, село Бабаюрт, Дж. Алиева 49, Здание Дзержинского филиала ФГУ		0101000020E6100000A471A8DF85634740C3D5011077CD4540
33162	8	75	256	53913	\N	\N	43.650716000000003	Республика Дагестан, Цунтинский район, с.Ахай-Отар	Россия, республика Дагестан, Бабаюртовский район, село Ахайотар	0101000020E6100000C05FCC96AC684740F27D71A94AD34540
32283	8	75	256	53942	\N	\N	43.376059336333803	Республика Дагестан,Лакский район, село Арцалу, Контора колхоза	Россия, республика Дагестан, Бабаюртовский район, село Арцалу	0101000020E6100000066344A2D09A4740E82E89B322B04540
31641	8	75	256	53671	\N	\N	43.653700524821197	Республика Дагестан, Ботлихский район, сельсовет Шодродинский, кутан Анхвала	Россия, республика Дагестан, Бабаюртовский район, село Анхвала	0101000020E6100000D6C56D3480734740662E7079ACD34540
31566	8	75	256	53715	\N	\N	43.5628317543419	Республика Дагестан, Бабаюртовский район, сельсовет Адиль-Янгиюртовский, село Адиль-Янгиюрт, Здание школы	Россия, республика Дагестан, Бабаюртовский район, село Адиль-Янги-Юрт	0101000020E610000079EA9106B74B4740369204E10AC84540
31562	8	75	1817	29217	\N	\N	41.531412000000003	Республика Дагестан,  Ахтынский район, село Ялак, клуб		0101000020E6100000100533A660CD4740DA59F44E05C44440
31561	8	75	1817	29121	\N	\N	41.486623000000002	Республика Дагестан, Ахтынский район, село Хрюг, школа		0101000020E6100000B2D826158DCD47409F3D97A949BE4440
31560	8	75	1817	29121	\N	\N	41.486623000000002	Республика Дагестан, Ахтынский район, село Хрюг, клуб		0101000020E6100000B2D826158DCD47409F3D97A949BE4440
31559	8	75	1817	29037	\N	\N	41.377209999999998	Республика Дагестан, Ахтынский район, село Хнов	Россия, республика Дагестан, Ахтынский район, село Хнов	0101000020E610000033DDEBA4BEB84740B1DCD26A48B04440
31558	8	75	1817	29037	\N	\N	41.377209999999998	Республика Дагестан, Ахтынский район, село Хнов, клуб		0101000020E610000033DDEBA4BEB84740B1DCD26A48B04440
31555	8	75	1817	28912	\N	\N	41.353036000000003	Республика Дагестан, Ахтынский район, село Ухул, клуб	Россия, республика Дагестан, Ахтынский район, село Ухул	0101000020E6100000E99AC937DBDE4740C4279D4830AD4440
31552	8	75	1817	53582	\N	\N	41.525341432982103	Республика Дагестан, Ахтынский район, село Ново-Усур, клуб		0101000020E61000008B53AD8559D84740BC1FB75F3EC34440
31557	8	75	1817	28994	\N	\N	41.489271000000002	Республика Дагестан, Ахтынский район, сельсовет Ахтынский, село Хкем, клуб		0101000020E6100000E88711C2A3E34740CCF09F6EA0BE4440
31553	8	75	1817	28830	\N	\N	41.380749000000002	Республика Дагестан, Ахтынский район, село Смугул, клуб		0101000020E61000006D382C0DFCD047400B7E1B62BCB04440
31556	8	75	1817	53546	\N	\N	41.403964999999999	Республика Дагестан, Ахтынский район, село Фий, клуб		0101000020E6100000E294B9F946C6474044DD0720B5B34440
31521	8	75	1817	27373	\N	\N	41.395490000000002	Республика Дагестан, Ахтынский район, село Миджах, клуб		0101000020E610000022C5008926D2474091F2936A9FB24440
31550	8	75	1817	28638	\N	\N	41.483893999999999	Республика Дагестан, Ахтынский район, село Луткун, клуб		0101000020E6100000193A765089D74740855D143DF0BD4440
31549	8	75	1817	28638	\N	\N	41.483893999999999	Республика Дагестан, Ахтынский район, село Луткун, школа		0101000020E6100000193A765089D74740855D143DF0BD4440
31548	8	75	1817	32724	\N	\N	41.434387000000001	Республика Дагестан, Ахтынский район, село Курукал, школа	Россия, республика Дагестан, Ахтынский район, село Куркал	0101000020E610000060E5D022DBD747405E6743FE99B74440
31546	8	75	1817	28490	\N	\N	41.471423000000001	Республика Дагестан, Ахтынский район, село Калук, клуб		0101000020E610000015FE0C6FD6D4474086CABF9657BC4440
31545	8	75	1817	28446	\N	\N	41.478828	Республика Дагестан, Ахтынский район, село Кака, клуб		0101000020E6100000A724EB7074D147405D34643C4ABD4440
31539	8	75	1817	27823	\N	\N	41.459186000000003	Республика Дагестан, Ахтынский район, село Ахты, здание сырзавода		0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31536	8	75	1817	27823	\N	\N	41.459186000000003	Республика Дагестан, Ахтынский раон, село Ахты	Россия, республика Дагестан, Ахтынский район, село Ахты	0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31535	8	75	1817	27823	\N	\N	41.459186000000003	Республика Дагестан, Ахтынский раон, село Ахты, ул. Агасиева, Спортзал	Россия, республика Дагестан, Ахтынский район, село Ахты	0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31533	8	75	1817	27823	33170	\N	41.459186000000003	Республика Дагестан, Ахтынский район, село Ахты, ул.Самурского, Музыкальная школа		0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31532	8	75	1817	27823	32923	\N	41.459186000000003	Республика Дагестан, Ахтынский район, село Ахты, ул.Ленина, Кантора Агасиева		0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31531	8	75	1817	27823	32923	\N	41.459186000000003	Республика Дагестан, Ахтынский район,  село Ахты, ул. Ленина, Районный дом культуры		0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31538	8	75	1817	27823	32982	\N	41.459186000000003	Республика Дагестан, Ахтынский район, село Ахты, ул. Байрамова, Ахтынская СОШ №2		0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31537	8	75	1817	27823	32982	\N	41.459186000000003	Республика Дагестан, Ахтынский район, село Ахты, ул. Байрамова, Ахтынская ООШ №3		0101000020E6100000757286E28EDD4740FA635A9BC6BA4440
31534	8	75	1817	27823	32977	\N	41.459150163870703	Республика Дагестан, Ахтынский район, село Ахты, ул. Аливердиева, Ахтынская СОШ №1	Россия, республика Дагестан, Ахтынский район, село Ахты	0101000020E6100000E7A6CD380DDF4740ADFA5C6DC5BA4440
31529	8	75	1796	32586	\N	\N	42.637186999999997	Республика Дагестан, Ахвахский район, сельсовет Цолодинский, кутан Цияб Цолода Верхний Тугай, здание школы	Россия, республика Дагестан, Ахвахский район, село Цолода	0101000020E6100000AD4B8DD0CF2E4740DA37F7578F514540
31528	8	75	1796	32586	\N	\N	42.637186999999997	Республика Дагестан, Ахвахский район, сельсовет Цолодинский, кутан Цияб Цолода, здание школы		0101000020E6100000AD4B8DD0CF2E4740DA37F7578F514540
31512	8	75	1796	53539	\N	\N	42.552205000000001	Республика Дагестан, Ахвахский район, сельсовет Тад-Магитлинский, участок Цвакилколо, здание школы	Россия, республика Дагестан, Ахвахский район, село Цвакилколо	0101000020E610000055BE6724422D474006D847A7AE464540
31508	8	75	1796	26760	\N	\N	42.573467999999998	Республика Дагестан, Ахвахский район, село Тукита, здание Администрации		0101000020E610000036AB3E575B2F4740B9A6406667494540
31516	8	75	1796	53670	\N	\N	42.5616168526441	Республика Дагестан, Ахвахский район, сельсовет Тлибишинский, участок Тлиси, здание школы	Россия, республика Дагестан, Ахвахский район, село Тлиси	0101000020E61000009FAEEE586C23474056F0DB10E3474540
31524	8	75	1796	53511	\N	\N	42.560084125258101	Республика Дагестан, Ахвахский район, сельсовет Тлибишинский, кутан Тлибишо, здание сельхозкооператива	Россия, республика Дагестан, Ахвахский район, село Тлибишо	0101000020E61000004A7B832F4C264740A6811FD5B0474540
31515	8	75	1796	53511	\N	\N	42.5603383018681	Республика Дагестан, Ахвахский район, сельсовет Тлибишинский, участок Гинцох, здание сельхозкооператива	Россия, республика Дагестан, Ахвахский район, село Тлибишо	0101000020E6100000A8C821E2E6264740605AD427B9474540
31514	8	75	1796	53511	\N	\N	42.560274478975401	Республика Дагестан, Ахвахский район, сельсовет Тлибишинский, здание школы	Россия, республика Дагестан, Ахвахский район, село Тлибишо	0101000020E61000002575029A082747404966F50EB7474540
31523	8	75	1796	53440	\N	\N	42.549879764696797	Республика Дагестан, Ахвахский район, сельсовет Тад-Магитлинский, кутан Тад-Магитль, здание школы		0101000020E61000002DEDD45C6E2C4740BC5CC47762464540
31511	8	75	1796	53440	\N	\N	42.549816302876103	Республика Дагестан, Ахвахский район, сельсовет Тад-Магитлинский, здание школы	Россия, республика Дагестан, Ахвахский район, село Тад-Магитль	0101000020E6100000CD751A69A92C4740A568E55E60464540
31499	8	75	1796	53533	\N	\N	42.618063630991301	Республика Дагестан, Ахвахский район, сельсовет Каратинский, участок Рачабулда, здание библиотеки	Россия, республика Дагестан, Ахвахский район, село Рачабулда	0101000020E6100000723788D68A264740DF6A9DB81C4F4540
31504	8	75	1796	53805	\N	\N	42.638945	Республика Дагестан, Ахвахский район, сельсовет Верхнеинхелинский, участок Рацитль, здание школы	Россия, республика Дагестан, Ахвахский район, село Рацитль	0101000020E610000092037635792A4740AB7823F3C8514540
31517	8	75	1796	26747	\N	\N	42.575738999999999	Республика Дагестан, Ахвахский район, село Местерух, кутан Местерух, здание сельхозкооператива		0101000020E610000096986725AD3247401004C8D0B1494540
31507	8	75	1796	26747	\N	\N	42.575738999999999	Республика Дагестан, Ахвахский район, село Местерух, здание клуба		0101000020E610000096986725AD3247401004C8D0B1494540
31522	8	75	1796	27013	\N	\N	42.514195999999998	Республика Дагестан, Ахвахский район, село Лологонитль, кутан Лологонитль, здание школы		0101000020E610000080F0A1444B2A4740F4DDAD2CD1414540
31513	8	75	1796	27013	\N	\N	42.514195999999998	Республика Дагестан, Ахвахский район, село Лологонитль, здание школы		0101000020E610000080F0A1444B2A4740F4DDAD2CD1414540
31519	8	75	1796	26872	\N	\N	42.540081999999998	Республика Дагестан, Ахвахский район, село Кудиябросо, кутан Кудиябросо, здание сельхозкооператива		0101000020E610000085ED27637C30474042942F6821454540
31510	8	75	1796	26872	\N	\N	42.540081999999998	Республика Дагестан, Ахвахский район, село Кудиябросо, здание школы		0101000020E610000085ED27637C30474042942F6821454540
31525	8	75	1796	53506	\N	\N	42.594949	Республика Дагестан, Ахвахский район, сельсовет Каратинский, кутан Карата, здание сельхозкооператива	Россия, республика Дагестан, Ахвахский район, село Карата	0101000020E61000002237C30DF82A4740DAE4F049274C4540
31497	8	75	1796	53506	\N	\N	42.595707502013497	Республика Дагестан, Ахвахский район, сельсовет Каратинский, участок Бокох, здание гимназии	Россия, республика Дагестан, Ахвахский район, село Карата	0101000020E6100000EA95B20C712A474098FBE428404C4540
31496	8	75	1796	53506	\N	\N	42.5940968433367	Республика Дагестан, Ахвахский район, сельсовет Каратинский, здание школы	Россия, республика Дагестан, Ахвахский район, село Карата	0101000020E610000097FE25A94C2B47406BD3D85E0B4C4540
31530	8	75	1796	53443	\N	\N	42.589401863528302	Республика Дагестан, Ахвахский район, сельсовет Ингердахский, кутан Ингердах, здание школы	Россия, республика Дагестан, Ахвахский район, село Ингердах	0101000020E61000007769C3616932474037195586714B4540
31506	8	75	1796	53443	\N	\N	42.588260269644003	Республика Дагестан, Ахвахский район, сельсовет Ингердахский, здание школы	Россия, республика Дагестан, Ахвахский район, село Ингердах	0101000020E61000007A39ECBE63324740C1C58A1A4C4B4540
31520	8	75	1796	26809	\N	\N	42.526961	Республика Дагестан, Ахвахский район, село Изано, кутан Изано, здание школы		0101000020E6100000412AC58EC63347403CA2427573434540
31509	8	75	1796	26809	\N	\N	42.526961	Республика Дагестан, Ахвахский район, село Изано, здание школы	Россия, республика Дагестан, Ахвахский район, село Изано	0101000020E6100000412AC58EC63347403CA2427573434540
31518	8	75	1796	32524	\N	\N	42.620046000000002	Республика Дагестан, Ахвахский район, сельсовет Верхнеинхелинский, кутан Инхело, здание сельхозкооператива		0101000020E61000004837C2A2222A47400002D6AA5D4F4540
31503	8	75	1796	32524	\N	\N	42.620930562897897	Республика Дагестан, Ахвахский район, сельсовет Верхнеинхелинский, здание Администрации	Россия, республика Дагестан, Ахвахский район, село Верхнее Инхело	0101000020E61000004583143C852A47404A09C1AA7A4F4540
31526	8	75	1796	26304	\N	\N	42.598945000000001	Республика Дагестан, Ахвахский район, село Арчо, кутан Арчо, здание сельхозкооператива		0101000020E610000079211D1EC2264740268DD13AAA4C4540
31498	8	75	1796	26304	\N	\N	42.598945000000001	Республика Дагестан, Ахвахский район, село Арчо	Россия, республика Дагестан, Ахвахский район, село Арчо	0101000020E610000079211D1EC2264740268DD13AAA4C4540
31500	8	75	1796	53518	\N	\N	42.6102790595356	Республика Дагестан, Ахвахский район, сельсовет Анчикский, здание школы	Россия, республика Дагестан, Ахвахский район, село Анчик	0101000020E61000003A03232F6B244740C1374D9F1D4E4540
31448	8	75	1736	53688	\N	\N	42.179685999999997	Республика Дагестан, Акушинский район, сельсовет Акушинский с. Панжи, здание СШ		0101000020E6100000643A747ADEAF474047C66AF3FF164540
31468	8	75	1736	53437	\N	\N	42.292643498407699	Республика Дагестан, Акушинский район, сельсовет Дубримахинский с. Шумхримахи, здание СШ	Россия, республика Дагестан, Акушинский район, село Шумхримахи	0101000020E6100000BE88B663EAA24740A033695375254540
31495	8	75	1736	53667	\N	\N	42.2241577255039	Республика Дагестан, Акушинский район, сельсовет Шуктынский с. Шукты, здание сельский клуб	Россия, республика Дагестан, Акушинский район, село Шукты	0101000020E610000059DFC0E446A7474082919735B11C4540
31493	8	75	1736	33040	\N	\N	42.1083	Республика Дагестан, Акушинский район, сельсовет Цугнинский с. Цугни, здание с/адм		0101000020E6100000EE77280AF4B3474012143FC6DC0D4540
31478	8	75	1736	53598	\N	\N	42.066411603341102	Республика Дагестан, Акушинский район, сельсовет Нахкинский с. Уцулимахи, здание сельский клуб	Россия, республика Дагестан, Акушинский район, село Уцулимахи	0101000020E6100000016DAB5967B64740EE073C3080084540
31491	8	75	1736	33031	\N	\N	42.248495278869697	Республика Дагестан, Акушинский район, сельсовет Усишинский с.Усиша, здание СШ	Россия, республика Дагестан, Акушинский район, село Усиша	0101000020E6100000267156444DB24740191C25AFCE1F4540
31490	8	75	1736	33031	\N	\N	42.247985120189	Республика Дагестан, Акушинский район, сельсовет Усишинский с. Усиша, здание СШ	Россия, республика Дагестан, Акушинский район, село Усиша	0101000020E610000011363CBD52B247400473F4F8BD1F4540
31487	8	75	1736	33015	\N	\N	42.309933999999998	Республика Дагестан, Акушинский район, сельсовет Урхучимахинский с. Урхучимахи, здание сельский клуб		0101000020E610000018CDCAF621A1474090F5D4EAAB274540
31450	8	75	1736	53795	\N	\N	42.288707000000002	Республика Дагестан, Акушинский район, сельсовет Акушинский с. Ургубамахи, здание СШ	Россия, республика Дагестан, Акушинский район, село Ургубамахи	0101000020E61000004AED45B41DA947402A90D959F4244540
31492	8	75	1736	53865	\N	\N	42.137756211358202	Республика Дагестан, Акушинский район, сельсовет Цугнинский с. Ургани, здание СШ	Россия, республика Дагестан, Акушинский район, село Ургани	0101000020E610000062D7F6764BAE4740F56915FDA1114540
31485	8	75	1736	25741	\N	\N	42.202252000000001	Республика Дагестан, Акушинский район, село Уллучара, здание с/адм		0101000020E610000000AB23473AA347407AC6BE64E3194540
31460	8	75	1736	53697	\N	\N	42.297788799049897	Республика Дагестан, Акушинский район, сельсовет Бургимакмахинский с. Узнимахи, здание СШ	Россия, республика Дагестан, Акушинский район, село Узнимахи	0101000020E6100000121615713AB14740E50D30F31D264540
90872	8	81	\N	818	7445	\N	45.064310999999996	Ставропольский край, Буденновский район, Покойненский сельсовет, Кочубея, 153		0101000020E610000035EECD6F98F84440F3E2C4573B884640
31484	8	75	1736	53528	\N	\N	42.345329737521702	Республика Дагестан, Акушинский район, сельсовет Тебекмахинский с. Тебекмахи, здание сельский клуб	Россия, республика Дагестан, Акушинский район, село Тебекмахи	0101000020E6100000DF313CF6B39A4740F12900C6332C4540
31481	8	75	1736	25512	\N	\N	42.164343000000002	Республика Дагестан, Акушинский район, село Танты, здание с/адм		0101000020E610000002F2255470A84740CC29013109154540
31449	8	75	1736	53421	\N	\N	42.283652954223697	Республика Дагестан, Акушинский район, сельсовет Акушинский с. Семгамахи, здание  СШ	Россия, республика Дагестан, Акушинский район, село Семгамахи	0101000020E6100000A4367172BFAD4740C634D3BD4E244540
31480	8	75	1736	53804	\N	\N	42.074356000000002	Республика Дагестан, Акушинский район, сельсовет Нацинский с. Наци, здание СШ	Россия, республика Дагестан, Акушинский район, село Наци	0101000020E610000072A8DF85ADB147407521567F84094540
31477	8	75	1736	53803	\N	\N	42.074725000000001	Республика Дагестан, Акушинский район, сельсовет Нахкинский с. Нахки, здание сельский клуб	Россия, республика Дагестан, Акушинский район, село Нахки	0101000020E61000007AC8940F41B34740C898BB9690094540
31476	8	75	1736	25213	\N	\N	42.296196999999999	Республика Дагестан, Акушинский район, село Муги, здание гимназии		0101000020E6100000F8E12021CAB547402F1686C8E9254540
31475	8	75	1736	25213	\N	\N	42.296196999999999	Республика Дагестан, Акушинский район, село Муги, здание СШ		0101000020E6100000F8E12021CAB547402F1686C8E9254540
31474	8	75	1736	25213	32946	\N	42.296531200326903	Республика Дагестан, Акушинский район, село Муги Кутан Аралык, спец. дом		0101000020E6100000EBC4E57805B6474006A051BAF4254540
31486	8	75	1736	25126	\N	\N	42.214486999999998	Республика Дагестан, Акушинский район, сельсовет Урхучимахинский с. Курьимахи, здание СШ		0101000020E610000071FF91E9D0B5474065355D4F741B4540
31483	8	75	1736	25126	\N	\N	42.214486999999998	Республика Дагестан, Акушинский район, сельсовет Тебекмахинский с. Куркебимахи, здание СШ	Россия, республика Дагестан, Акушинский район, село Куркимахи	0101000020E610000071FF91E9D0B5474065355D4F741B4540
31473	8	75	1736	25126	\N	\N	42.214486999999998	Республика Дагестан, Акушинский район, село Куркимахи, здание СШ		0101000020E610000071FF91E9D0B5474065355D4F741B4540
31479	8	75	1736	53594	\N	\N	42.079441147453899	Республика Дагестан, Акушинский район, сельсовет Нацинский с. Кулиямахи, здание сельский клуб	Россия, республика Дагестан, Акушинский район, село Кулиямахи	0101000020E6100000B1C398F4F7AA4740147B681F2B0A4540
31457	8	75	1736	53920	\N	\N	42.300096965134998	Республика Дагестан, Акушинский район, сельсовет Балхарский с. Кули, здание библиотека	Россия, республика Дагестан, Акушинский район, село Кули	0101000020E610000068CBB914579B47405950189469264540
31472	8	75	1736	53494	\N	\N	42.043943642480698	Республика Дагестан, Акушинский район, сельсовет Кассагумахинский с. Кассагумахи, здание с/адм	Россия, республика Дагестан, Акушинский район, село Кассагумахи	0101000020E610000014268C6665AF47407F6DFDF49F054540
31447	8	75	1736	53608	\N	\N	42.269060951505701	Республика Дагестан, Акушинский район, сельсовет Акушинский с. Карша, Здание СШ	Россия, республика Дагестан, Акушинский район, село Карша	0101000020E6100000D3DD7536E4AB474085D0419770224540
31470	8	75	1736	24981	\N	\N	42.320498008764403	Республика Дагестан, Акушинский район, село Кавкамахи Львовский №8, Кутан спец. дом	Россия, республика Дагестан, Акушинский район, село Кавкамахи	0101000020E610000064CF9ECBD4A647407A37161406294540
31469	8	75	1736	24981	\N	\N	42.319374000000003	Республика Дагестан, Акушинский район, село Кавкамахи, здание сельский клуб		0101000020E610000085CE6BEC12A74740AB984A3FE1284540
31489	8	75	1736	53922	\N	\N	42.284030999999999	Республика Дагестан, Акушинский район, сельсовет Усишинский с. Зильмук, здание СШ	Россия, республика Дагестан, Акушинский район, село Зильмукмахи	0101000020E6100000A41CCC26C0B247406C06B8205B244540
31467	8	75	1736	53442	\N	\N	42.268507	Республика Дагестан, Акушинский район, сельсовет Дубримахинский с. Дубримахи, здание сельский кулуб	Россия, республика Дагестан, Акушинский район, село Дубримахи	0101000020E61000004E7D2079E7A44740A0DFF76F5E224540
31445	8	75	1736	53792	\N	\N	42.249963000000001	Республика Дагестан, Акушинский район, сельсовет Акушинский с. Гумрамахи, здание СШ	Россия, республика Дагестан, Акушинский район, село Гумрамахи	0101000020E61000009293895B05AD4740E31A9FC9FE1F4540
31482	8	75	1736	53496	\N	\N	42.347608665499202	Республика Дагестан, Акушинский район, сельсовет Тебекмахинский с. Гуладтымахи, здание сельский клуб		0101000020E6100000A75A0BB3D09E4740CB65A3737E2C4540
31466	8	75	1736	24836	\N	\N	42.202519000000002	Республика Дагестан, Акушинский район, село Гинта, здание СШ		0101000020E6100000DDCD531D72B54740C9E88024EC194540
31464	8	75	1736	53490	\N	\N	42.212682413348503	Республика Дагестан, Акушинский район, село Геба, здание с/адм	Россия, республика Дагестан, Акушинский район, село Гиба	0101000020E6100000E71725E82FB247405439ED29391B4540
31465	8	75	1736	24790	\N	\N	42.26435	Республика Дагестан, Акушинский район, село Герхмахи, здание СШ		0101000020E6100000668522DDCFC347404B598638D6214540
31463	8	75	1736	24692	\N	\N	42.210881000000001	Республика Дагестан, Акушинский район, село Гапшима, здание спортзал		0101000020E61000009E978A8D79A94740842C0B26FE1A4540
31462	8	75	1736	24658	\N	\N	42.309699999999999	Республика Дагестан, Акушинский район, село Мулебки Верхние, здание с/адм		0101000020E6100000CFA3E2FF8EC247401DC9E53FA4274540
31461	8	75	1736	53748	\N	\N	42.179685999999997	Республика Дагестан, Акушинский район, село Бутри, здание с/адм		0101000020E6100000643A747ADEAF474047C66AF3FF164540
31459	8	75	1736	53712	\N	\N	42.2950649862427	Республика Дагестан, Акушинский район, сельсовет Бургимакмахинский с. Бургимакмахи, здание с/адм	Россия, республика Дагестан, Акушинский район, село Бургимакмахи	0101000020E61000003CA2427573AF4740DD989EB0C4254540
31458	8	75	1736	32812	\N	\N	42.277492633542401	Республика Дагестан, Акушинский район, сельсовет Балхарский Львовский №9, кутан спец дом	Россия, республика Дагестан, Акушинский район, село Балхар	0101000020E61000008F71C5C5519D474039EFFFE384234540
31456	8	75	1736	32812	\N	\N	42.275959	Республика Дагестан, Акушинский район, сельсовет Балхарский с. Балхар, здание с/адм		0101000020E610000041EF8D21009E4740B804E09F52234540
31455	8	75	1736	53534	\N	\N	42.3309302517604	Республика Дагестан, Акушинский район, село Аметеркмахи, здание СШ	Россия, республика Дагестан, Акушинский район, село Аметеркамахи	0101000020E6100000AF264F594D9B4740F5A10BEA5B2A4540
31454	8	75	1736	53534	\N	\N	42.330548137218599	Республика Дагестан, Акушинский район, село Аметеркмахи с. Аметеркмахи, здание сельский клуб	Россия, республика Дагестан, Акушинский район, село Аметеркамахи	0101000020E610000061FE0A992B9B47400DE198654F2A4540
31453	8	75	1736	32789	\N	\N	42.330913000000002	Республика Дагестан, Акушинский район, сельсовет Алиханмахинский с Алиханмахи, здание СШ		0101000020E6100000580053060EA247401F69705B5B2A4540
31452	8	75	1736	32764	\N	\N	42.273921471106497	Республика Дагестан, Акушинский район, сельсовет Акушинский   Кутан Ног р-н, ДОМ СПЕЦ КУТАН Ног Р-Н	Россия, республика Дагестан, Акушинский район, село Акуша	0101000020E6100000DB4C857824AC47400458E4D70F234540
31451	8	75	1736	32764	\N	\N	42.275072000000002	Республика Дагестан, Акушинский район, сельсовет Акушинский с. Акуша, здание с/адм		0101000020E61000008CBCAC8905AC4740CD052E8F35234540
31446	8	75	1736	32764	\N	\N	42.275116778117201	Республика Дагестан, Акушинский район, сельсовет Акушинский  с Акуша, Здание СПК	Россия, республика Дагестан, Акушинский район, село Акуша	0101000020E61000007366BB421FAC47406DC9AA0837234540
31441	8	75	1706	23643	\N	\N	41.798912999999999	Республика Дагестан, Агульский район, сельсовет Дулдугский, село Яркуг, Клуб		0101000020E6100000BFEE74E789D74740B4ACFBC742E64440
31852	8	75	1706	53570	\N	\N	42.060841678860001	Республика Дагестан, Дахадаевский район, сельсовет Урагинский, село Шири, Помещение сельского клуба	Россия, республика Дагестан, Агульский район, село Шари	0101000020E61000001C96067E54CB4740931CB0ABC9074540
31439	8	75	1706	23519	\N	\N	41.836793	Республика Дагестан, Агульский район, село Чираг, Клуб		0101000020E61000001EE1B4E045B74740C84274081CEB4440
31440	8	75	1706	23596	\N	\N	41.915224000000002	Республика Дагестан, Агульский район, сельсовет Амухский, село Цирхе, Школа		0101000020E6100000B7F0BC546CCC4740D5415E0F26F54440
31437	8	75	1706	23440	\N	\N	41.784796	Республика Дагестан, Агульский район, сельсовет Хутхульский, село Хутхул, Администрация		0101000020E61000009833DB15FACE47400C04013274E44440
31435	8	75	1706	53480	\N	\N	41.852653716572803	"Республика Дагестан, Агульский район, ""сельсовет Курагский"" село Худиг, Клуб"		0101000020E6100000F5F23B4D66D44740DC662AC423ED4440
31438	8	75	1706	23490	\N	\N	41.791511999999997	Республика Дагестан, Агульский район, село Фите, Клуб		0101000020E6100000F355F2B1BBDE47401E32E54350E54440
31434	8	75	1706	23269	\N	\N	41.781945	Республика Дагестан, Агульский район, село Тпиг, Школа		0101000020E6100000739CDB847BCB4740A72215C616E44440
31433	8	75	1706	32625	\N	\N	41.761456480176797	Республика Дагестан, Агульский район, сельсовет Ричинский. село Рича, Школа		0101000020E6100000CB811E6ADBC04740E7ABE46377E14440
31432	8	75	1706	53907	\N	\N	41.809792844237201	Республика Дагестан, Агульский район, сельсовет Хутхульский. село Мисси, Школа	Россия, республика Дагестан, Агульский район, село Миси	0101000020E6100000666A12BC21CD4740CEC3094CA7E74440
31431	8	75	1706	23151	\N	\N	41.836202	Республика Дагестан, Агульский район, сельсовет Курагский, село Кураг, Администрация		0101000020E6100000A4A833F790D44740C66CC9AA08EB4440
31430	8	75	1706	53873	\N	\N	41.771270933955797	Республика Дагестан, Агульский район, сельсовет Дулдугский. село Дулдуг, Школа	Россия, республика Дагестан, Агульский район, село Дулдуг	0101000020E6100000B77C24253DD6474036AD1402B9E24440
31429	8	75	1706	23073	\N	\N	41.753799999999998	Республика Дагестан, Агульский район, сельсовет Дулдугский, село Гоа, Клуб		0101000020E6100000B4AED172A0D94740C6DCB5847CE04440
31428	8	75	1706	23002	\N	\N	41.895622000000003	Республика Дагестан, Агульский район, сельсовет Буршагский, село Буршаг, Администрация	Россия, республика Дагестан, Агульский район, село Буршаг	0101000020E6100000BC7A15191DD2474000CADFBDA3F24440
31427	8	75	1706	22985	\N	\N	41.804929000000001	Республика Дагестан, Агульский район, село Буркихан, Администрация		0101000020E610000056B8E52329C547400E4DD9E907E74440
31426	8	75	1706	22921	\N	\N	41.715136999999999	Республика Дагестан, Агульский район, сельсовет Ричинский, село Бедюк, Клуб		0101000020E6100000A8C64B3789C347406C94F59B89DB4440
31425	8	75	1706	53960	\N	\N	41.8642107451032	Республика Дагестан, Агульский район, сельсовет Курагский село Арсуг, Клуб	Россия, республика Дагестан, Агульский район, село Арсуг	0101000020E610000011C5E40D30D34740F6EB4E779EEE4440
31424	8	75	1706	53879	\N	\N	41.914749036434202	Республика Дагестан, Агульский район, сельсовет Амухский село Амух, Администрация	Россия, республика Дагестан, Агульский район, село Амух	0101000020E6100000E7AA798EC8C547403C86C77E16F54440
90615	8	81	\N	818	60235	\N	45.041730999999999	Ставропольский край, город Ставрополь, Ленинский район, Комсомольская, 64		0101000020E6100000401361C3D3FD44405C1D007157854640
32442	8	75	7288	53429	\N	\N	43.031778689271903	Республика Дагестан, город Махачкала, Кировский район, село Шамхал-Термен, Центр - помещение Клуб	Россия, республика Дагестан, Махачкала городской округ, село Шамхал Термен	0101000020E610000099B7EA3A54A747408CD9925511844540
90710	8	81	\N	818	5785	\N	45.021085999999997	Ставропольский край, город Ставрополь, Промышленный район, ул. Шпаковская, д. 109	Россия, Ставропольский край, Ставрополь, улица Шпаковская, 109	0101000020E61000002ACAA5F10BF74440A43330F2B2824640
91491	8	81	\N	818	7276	\N	45.035821336756101	"х.Верный, Широкая, МУККТ ""Долина"""	Россия, Ставропольский край, Ставрополь, улица Широкая	0101000020E6100000F8DF4A766C02454048C153C895844640
91014	8	81	\N	818	1125	\N	45.024647999999999	Ставропольский край, город-курорт Железноводск, Чайковского, 1	Россия, Ставропольский край, Ставрополь, улица Чайковского, 1	0101000020E61000002FFD4B5299F84440B6F468AA27834640
90657	8	81	\N	818	4689	\N	45.046087	Ставропольский край, город Ставрополь, Октябрьский район, ул. Советская, 12А	Россия, Ставропольский край, Ставрополь, улица Советская, 12а	0101000020E61000003FC7478B33FC4440A8E2C62DE6854640
90708	8	81	\N	818	4041	\N	45.026488999999998	Ставропольский край, город Ставрополь, Промышленный район, ул. Серова, д. 4/2	Россия, Ставропольский край, Ставрополь, улица Серова, 4к2	0101000020E610000034BBEEAD48F84440145AD6FD63834640
90647	8	81	\N	818	4041	\N	45.031875200106697	Ставропольский край, город Ставрополь, Ленинский район, Серова, 422	Россия, Ставропольский край, Ставрополь, улица Серова	0101000020E6100000B9C2BB5CC4FF4440AE47E17A14844640
91704	8	81	\N	818	1616	\N	45.003709999999998	Ставропольский край, город-курорт Пятигорск, Сельская, 40	Россия, Ставропольский край, Ставрополь, улица Сельская	0101000020E61000005038BBB54CF444408655BC9179804640
90670	8	81	\N	818	5348	\N	45.070906000000001	Ставропольский край, город Ставрополь, Октябрьский район, Репина, 146	Россия, Ставропольский край, Ставрополь, улица Репина, 146	0101000020E6100000BB26A43506FF44408B8BA37213894640
91027	8	81	\N	818	913	\N	45.04289	Ставропольский край, город-курорт Железноводск, Пушкина, 1	Россия, Ставропольский край, Ставрополь, улица Пушкина, 1	0101000020E61000006A85E97B0DFB4440A8A9656B7D854640
90672	8	81	\N	818	3647	\N	45.071376999999998	Ставропольский край, город Ставрополь, Октябрьский район, Пригородная, 70	Россия, Ставропольский край, Ставрополь, улица Пригородная, 70	0101000020E610000056F0DB10E3FD4440E257ACE122894640
90639	8	81	\N	818	4970	\N	45.023654000000001	Ставропольский край, город Ставрополь, Ленинский район, Пономарева, 1	Россия, Ставропольский край, Ставрополь, улица Пономарева, 1	0101000020E610000083C2A04CA3FB4440B535221807834640
90733	8	81	\N	818	5942	\N	45.005066999999997	Ставропольский край, город Ставрополь, Промышленный район, Пирогова, 58	Россия, Ставропольский край, Ставрополь, улица Пирогова, 58	0101000020E6100000D3D9C9E028F54440F8A41309A6804640
91005	8	81	\N	818	583	\N	45.059696445449397	Ставропольский край, город-курорт Железноводск, Октябрьская, 21	Россия, Ставропольский край, Ставрополь, улица Октябрьская, 21	0101000020E6100000FAF19716F5FB4440DCD9571EA4874640
90682	8	81	\N	818	583	\N	45.066507000000001	Ставропольский край, город Ставрополь, Октябрьский район, Октябрьская, 164 А	Россия, Ставропольский край, Ставрополь, улица Октябрьская, 164а	0101000020E61000000D71AC8BDBF8444040FA264D83884640
90678	8	81	\N	818	583	\N	45.071829000000001	Ставропольский край, город Ставрополь, Октябрьский район, Октябрьская, 184	Россия, Ставропольский край, Ставрополь, улица Октябрьская, 184	0101000020E61000003B8908FF22F84440C3F352B131894640
90673	8	81	\N	818	5380	\N	45.073751000000001	Ставропольский край, город Ставрополь, Октябрьский район, Огородная, 2	Россия, Ставропольский край, Ставрополь, улица Огородная, 2	0101000020E610000057EA5910CAFD44400E863AAC70894640
90622	8	81	\N	818	4755	\N	45.047215000000001	Ставропольский край, город Ставрополь, Ленинский район, Объездная, 8	Россия, Ставропольский край, Ставрополь, улица Объездная, 8	0101000020E6100000B9FE5D9F39014540B97020240B864640
90702	8	81	\N	818	15855	\N	45.040317000000002	Ставропольский край, город Ставрополь, Промышленный район, ул. М.Морозова, д. 95	Россия, Ставропольский край, Ставрополь, улица Михаила Морозова, 95	0101000020E6100000A5BC564277F94440863C821B29854640
90703	8	81	\N	818	1720	\N	45.035980000000002	Ставропольский край, город Ставрополь, Промышленный район, ул. Мира, д. 365	Россия, Ставропольский край, Ставрополь, улица Мира, 365	0101000020E6100000CAA8328CBBF94440B1A71DFE9A844640
90636	8	81	\N	818	1720	\N	45.035904000000002	Ставропольский край, город Ставрополь, Ленинский район, Мира, 310	Россия, Ставропольский край, Ставрополь, улица Мира, 310	0101000020E61000009FE40E9BC8FA4440D6E5948098844640
90633	8	81	\N	818	4893	\N	45.039833000000002	Ставропольский край, город Ставрополь, Ленинский район, Маяковского, 16	Россия, Ставропольский край, Ставрополь, улица Маяковского, 16	0101000020E610000097C79A9141FE44409A266C3F19854640
90610	8	81	\N	818	4635	\N	45.040458000000001	Ставропольский край, город Ставрополь, Ленинский район, Маршала Жуккова, 9	Россия, Ставропольский край, Ставрополь, улица Маршала Жукова, 9	0101000020E6100000130D52F014FC4440486E4DBA2D854640
90604	8	81	\N	818	4027	\N	45.041789000000001	Ставропольский край, город Ставрополь, Ленинский район, Ломоносова, 5	Россия, Ставропольский край, Ставрополь, улица Ломоносова, 5	0101000020E61000008FA850DD5CFA4440912A8A5759854640
14641	3	28	\N	7525	23200	\N	55.072916999999997	город Советск, Победы, 36		0101000020E610000020EC14AB06E135404529215855894B40
91017	8	81	\N	818	595	\N	45.043081000000001	Ставропольский край, город-курорт Железноводск, Ленина, 10	Россия, Ставропольский край, Ставрополь, улица Ленина, 10	0101000020E6100000F1A0D9756F0145401C0A9FAD83854640
90870	8	81	\N	818	595	\N	45.042845999999997	Ставропольский край, Буденновский район, Орловский сельсовет, Ленина, 63	Россия, Ставропольский край, Ставрополь, улица Ленина, 67	0101000020E610000084F068E388FF4440D8614CFA7B854640
90707	8	81	\N	818	595	\N	45.036597999999998	Ставропольский край, город Ставрополь, Промышленный район, ул.Ленина, д. 384	Россия, Ставропольский край, Ставрополь, улица Ленина, 384	0101000020E6100000EB8EC536A9F84440AC8C463EAF844640
90696	8	81	\N	818	595	\N	45.035030999999996	Ставропольский край, город Ставрополь, Промышленный район, ул. Ленина, д. 456	Россия, Ставропольский край, Ставрополь, улица Ленина, 456	0101000020E6100000B03907CF84F644404FAC53E57B844640
90605	8	81	\N	818	595	\N	45.040253999999997	Ставропольский край, город Ставрополь, Ленинский район, Ленина, 251	Россия, Ставропольский край, Ставрополь, улица Ленина, 251	0101000020E6100000446CB07092FA44403FC4060B27854640
90954	8	81	\N	818	213	\N	45.067543999999998	Ставропольский край, Грачевский район, Красный сельсовет, Красная, 38д	Россия, Ставропольский край, Ставрополь, улица Красная, 38	0101000020E61000009D2B4A09C1FE444040852348A5884640
90617	8	81	\N	818	3778	\N	45.043303999999999	Ставропольский край, город Ставрополь, Ленинский район, Комсомольская, 65	Россия, Ставропольский край, Ставрополь, улица Комсомольская, 65	0101000020E610000015A930B610FE44409BE447FC8A854640
90725	8	81	\N	818	5867	\N	45.009162533633699	Ставропольский край, город Ставрополь, Промышленный район, ул. Доваторцев, д. 53, корп. 3	Россия, Ставропольский край, Ставрополь, улица Доваторцев, 53к3	0101000020E6100000B1A71DFE9AF64440A8AAD0402C814640
90655	8	81	\N	818	643	\N	45.044623000000001	Ставропольский край, город Ставрополь, Октябрьский район, Дзержинского, 137	Россия, Ставропольский край, Ставрополь, улица Дзержинского, 137	0101000020E61000001FBC7669C3FB444020D3DA34B6854640
90674	8	81	\N	818	5400	\N	45.059542	Ставропольский край, город Ставрополь, Октябрьский район, Гоголя, 36	Россия, Ставропольский край, Ставрополь, улица Гоголя, 36	0101000020E6100000FCA886FD9EFC4440855E7F129F874640
90663	8	81	\N	818	4693	\N	45.052086000000003	Ставропольский край, город Ставрополь, Октябрьский район, Голенева, 18	Россия, Ставропольский край, Ставрополь, улица Геннадия Голенева, 18	0101000020E6100000AE2B6684B7FD44402C4A09C1AA864640
91096	8	81	\N	818	2289	\N	45.037846000000002	Ставропольский край, Ипатовский район, Гагарина, 21	Россия, Ставропольский край, Ставрополь, улица Гагарина, 21	0101000020E610000078431A1538F7444068244223D8844640
90656	8	81	\N	818	5174	\N	45.056212000000002	Ставропольский край, город Ставрополь, Октябрьский район, Вавилова, 40	Россия, Ставропольский край, Ставрополь, улица Вавилова, 40	0101000020E6100000FA25E2ADF3FB444046D26EF431874640
90684	8	81	\N	818	5523	\N	45.063113999999999	Ставропольский край, город Ставрополь, Промышленный район, ул.Бруснева, д. 10	Россия, Ставропольский край, Ставрополь, улица Бруснева, 10	0101000020E6100000F834272F32F74440BAF59A1E14884640
90650	8	81	\N	818	5101	\N	45.025775000000003	Ставропольский край, город Ставрополь, Ленинский район, Биологическая, 20	Россия, Ставропольский край, Ставрополь, улица Биологическая, 20	0101000020E6100000534145D5AF004540F7065F984C834640
90643	8	81	\N	818	5023	\N	45.022928	Ставропольский край, город Ставрополь, Ленинский район, Ашихина, 63		0101000020E6100000C3D5011077FD4440D314014EEF824640
90727	8	81	\N	818	5868	\N	45.003594999999997	Ставропольский край, город Ставрополь, Промышленный район, ул. 50 лет ВЛКСМ, д. 48	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 48	0101000020E61000000261A75835F64440EDB60BCD75804640
90722	8	81	\N	818	5868	\N	45.008547	Ставропольский край, город Ставрополь, Промышленный район, ул. 50 лет ВЛКСМ, д. 49	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 49	0101000020E61000003D7E6FD39FF544404DBD6E1118814640
90717	8	81	\N	818	5868	\N	45.016945	Ставропольский край, город Ставрополь, Промышленный район, 50 лет ВЛКСМ, 19	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 19	0101000020E6100000BDC5C37B0EF64440556AF6402B824640
90716	8	81	\N	818	5868	\N	45.017938999999998	Ставропольский край, город Ставрополь, Промышленный район, 50 лет ВЛКСМ, 14	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 14	0101000020E61000003352EFA99CF6444056293DD34B824640
90714	8	81	\N	818	5868	\N	45.013911999999998	Ставропольский край, город Ставрополь, Промышленный район, ул. 50 лет ВЛКСМ, 16/3	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 16к3	0101000020E61000008A93FB1D8AF64440CF8250DEC7814640
90735	8	81	\N	818	6092	\N	45.000080969317899	Ставропольский край, город Ставрополь, Промышленный район, 45-я паралель квартал 529, 64А	Россия, Ставропольский край, Ставрополь, улица 45-я Параллель	0101000020E610000096EA025E66F44440ED2C7AA702804640
90692	8	81	\N	818	5535	\N	45.059606000000002	Ставропольский край, город Ставрополь, Промышленный район, просп. Юности, д. 42	Россия, Ставропольский край, Ставрополь, Юности проспект, 42	0101000020E6100000D8F2CAF5B6F744409C525E2BA1874640
90688	8	81	\N	818	5535	\N	45.059866070019403	Ставропольский край, город Ставрополь, Промышленный район, ул. Юности, д. 20	Россия, Ставропольский край, Ставрополь, Юности проспект, 20	0101000020E610000092EBA694D7F64440381268B0A9874640
90687	8	81	\N	818	5535	\N	45.061349065573403	Ставропольский край, город Ставрополь, Промышленный район, ул.Юности, д. 3	Россия, Ставропольский край, Ставрополь, Юности проспект, 3	0101000020E6100000AED7F4A0A0F644403752B648DA874640
90686	8	81	\N	818	5535	\N	45.061782999999998	Ставропольский край, город Ставрополь, Промышленный район, просп. Юности, д. 7	Россия, Ставропольский край, Ставрополь, Юности проспект, 7	0101000020E610000026E318C91EF7444071395E81E8874640
90685	8	81	\N	818	5535	\N	45.060994000000001	Ставропольский край, город Ставрополь, Промышленный район, просп. Юности, д. 5	Россия, Ставропольский край, Ставрополь, Юности проспект, 5	0101000020E6100000CE5147C7D5F6444049A0C1A6CE874640
90706	8	81	\N	818	60262	\N	45.021188000000002	Ставропольский край, город Ставрополь, Промышленный район, ул. Шпаковская, д.85		0101000020E61000009DD5027B4CF84440A988D349B6824640
90883	8	81	\N	818	60605	\N	45.069721168969501	Ставропольский край, Буденновский район, Стародубский сельсовет, Шевченко, 9	Россия, Ставропольский край, Ставрополь, улица Шевченко	0101000020E6100000D27135B22BFF4440166C239EEC884640
90995	8	81	\N	818	828	\N	45.044373999999998	Ставропольский край, город-курорт Ессентуки, Чкалова, 1	Россия, Ставропольский край, Ставрополь, Чкалова переулок, 3	0101000020E6100000A77686A92DFF44407765170CAE854640
90635	8	81	\N	818	828	\N	45.041088000000002	Ставропольский край, город Ставрополь, Ленинский район, Чкалова, 27/А	Россия, Ставропольский край, Ставрополь, Чкалова переулок, 27а	0101000020E6100000E603029D49FF44400821205F42854640
90640	8	81	\N	818	4973	\N	45.029668000000001	Ставропольский край, город Ставрополь, Ленинский район, Черняховского, 3	Россия, Ставропольский край, Ставрополь, Черняховского проезд, 3	0101000020E6100000168A743FA7FC44406EDE3829CC834640
90668	8	81	\N	818	5325	\N	45.073261000000002	Ставропольский край, город Ставрополь, Октябрьский район, проезд Чапаевский, 21		0101000020E6100000CE548847E20145404089CF9D60894640
90667	8	81	\N	818	60167	\N	45.077141836861699	Ставропольский край, город Ставрополь, Октябрьский район, Чапаева, 4	Россия, Ставропольский край, Ставрополь, улица Чапаева	0101000020E61000003F53AF5B04024540F392FFC9DF894640
90712	8	81	\N	818	5844	\N	45.017187	Ставропольский край, город Ставрополь, Промышленный район, Фестивальный, 17		0101000020E6100000789961A3ACF744404B75012F33824640
90711	8	81	\N	818	5844	\N	45.017114045001001	Ставропольский край, город Ставрополь, Промышленный район, пр.Фестивальный, д. 17	Россия, Ставропольский край, Ставрополь, Фестивальный переулок	0101000020E610000017D7F84CF6F74440E126A3CA30824640
90732	8	81	\N	818	60178	\N	45.012115198536698	Ставропольский край, город Ставрополь, Промышленный район, Тухачевского, 18	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 18	0101000020E610000076C6F7C5A5F644404165FCFB8C814640
90731	8	81	\N	818	60178	\N	45.016314000000001	Ставропольский край, город Ставрополь, Промышленный район, Тухачевского, 17		0101000020E6100000EC6AF294D5F44440C53BC09316824640
90723	8	81	\N	818	60178	\N	45.012987174531297	Ставропольский край, город Ставрополь, Промышленный район, ул. Тухачевского, д. 2	Россия, Ставропольский край, Ставрополь, улица Тухачевского	0101000020E6100000BC74931804F64440F722DA8EA9814640
90624	8	81	\N	818	60249	\N	45.044992000000001	Ставропольский край, город Ставрополь, Ленинский район, Туапсинская, 6		0101000020E6100000F29A577556014540734A404CC2854640
90671	8	81	\N	818	60232	\N	45.066138000000002	Ставропольский край, город Ставрополь, Октябрьский район, Трунова, 71		0101000020E61000009D685721E5FD4440ED82C13577884640
90709	8	81	\N	818	59945	\N	45.0263281791282	Ставропольский край, город Ставрополь, Промышленный район, пр. Серова, д. 4/2	Россия, Ставропольский край, Ставрополь, улица Серова, 4к2	0101000020E61000003F0114234BF844400B7C45B75E834640
90648	8	81	\N	818	59945	\N	45.030195999999997	Ставропольский край, город Ставрополь, Ленинский район, Серова, 523		0101000020E610000034D8D47954024540293C6876DD834640
90646	8	81	\N	818	59945	\N	45.032324000000003	Ставропольский край, город Ставрополь, Ленинский район, Серова, 420		0101000020E6100000E272BC02D1FF44401E705D3123844640
90645	8	81	\N	818	59945	\N	45.030476999999998	Ставропольский край, город Ставрополь, Ленинский район, Серова, 451		0101000020E6100000643BDF4F8DFF4440DD239BABE6834640
90641	8	81	\N	818	59945	\N	45.029228000000003	Ставропольский край, город Ставрополь, Ленинский район, Серова, 278		0101000020E610000073124A5F08FD444052103CBEBD834640
91710	8	81	\N	818	60184	\N	45.041717921972598	Ставропольский край, город-курорт Пятигорск, Розы Люксембург, 68а	Россия, Ставропольский край, Ставрополь, улица Розы Люксембург	0101000020E61000007C9DD497A5FD4440C8D3F20357854640
90609	8	81	\N	818	60220	\N	45.040174155215297	Ставропольский край, город Ставрополь, Ленинский район, Пушкина, 8	Россия, Ставропольский край, Ставрополь, улица Пушкина, 8а/8	0101000020E610000092921E8656FB44402313F06B24854640
90669	8	81	\N	818	60258	\N	45.075220999999999	Ставропольский край, город Ставрополь, Октябрьский район, Пригородная, 226		0101000020E6100000649126DE01004540787C7BD7A0894640
90679	8	81	\N	818	5465	\N	45.057333	Ставропольский край, город Ставрополь, Октябрьский район, Попова, 16 А	Россия, Ставропольский край, Ставрополь, Попова переулок, 16а	0101000020E6100000BC7669C361F94440A4FD0FB056874640
90886	8	81	\N	818	60234	\N	45.052563999999997	Ставропольский край, Буденновский район, Терский сельсовет, Победы, 1		0101000020E61000009E7C7A6CCBFC44403579CA6ABA864640
90721	8	81	\N	818	60256	\N	45.008400000000002	Ставропольский край, город Ставрополь, Промышленный район, ул. Пирогова, д. 34, корп. 4		0101000020E610000055151A8865F54440A9A44E4013814640
90734	8	81	\N	818	60264	\N	45.004593746751098	Ставропольский край, город Ставрополь, Промышленный район, Пирогова улица, 64А	Россия, Ставропольский край, Ставрополь, улица Пирогова, 64к1	0101000020E6100000A514747B49F5444000E1438996804640
90698	8	81	\N	818	60244	\N	45.040317000000002	Ставропольский край, город Ставрополь, Промышленный район, ул. Осетинская, д. 3		0101000020E6100000028063CF9EF74440863C821B29854640
90659	8	81	\N	818	4650	\N	45.045064408546402	Ставропольский край, город Ставрополь, Октябрьский район, проспект Октябрьской революции, 4	Россия, Ставропольский край, Ставрополь, Октябрьской Революции проспект	0101000020E6100000FC8BA03193FC44400D1D3BA8C4854640
90612	8	81	\N	818	4650	\N	45.042610000000003	Ставропольский край, город Ставрополь, Ленинский район, проспект Октябрьской революции, 29	Россия, Ставропольский край, Ставрополь, Октябрьской Революции проспект, 27	0101000020E610000010768A5583FC4440C53D963E74854640
90677	8	81	\N	818	60259	\N	45.067225999999998	Ставропольский край, город Ставрополь, Октябрьский район, Октябрьская, 180		0101000020E610000033349E08E2F844406FB88FDC9A884640
90676	8	81	\N	818	60200	\N	45.060090030731203	Ставропольский край, город Ставрополь, Октябрьский район, Октябрьская, 101	Россия, Ставропольский край, Ставрополь, улица Октябрьская	0101000020E61000004B2366F679FA444088687407B1874640
90623	8	81	\N	818	60218	\N	45.045742880570899	Ставропольский край, город Ставрополь, Ленинский район, Объездная, 3/1		0101000020E6100000D42AFA4333014540AE8218E8DA854640
90697	8	81	\N	818	60195	\N	45.032451000000002	Ставропольский край, город Ставрополь, Промышленный район, ул. Мира, д. 458		0101000020E6100000E78EFE976BF744407BDCB75A27844640
90632	8	81	\N	818	60195	\N	45.037069000000002	Ставропольский край, город Ставрополь, Ленинский район, Мира, 262		0101000020E6100000CD902A8A57FD444004594FADBE844640
90630	8	81	\N	818	60195	\N	45.036853000000001	Ставропольский край, город Ставрополь, Ленинский район, Мира, 284		0101000020E61000006E35EB8CEFFB444037E15E99B7844640
90629	8	81	\N	818	60195	\N	45.036216000000003	Ставропольский край, город Ставрополь, Ленинский район, Мира, 306		0101000020E61000009335EA211AFB4440C5CBD3B9A2844640
90628	8	81	\N	818	60195	\N	45.036798973008402	Ставропольский край, город Ставрополь, Ленинский район, Мира, 347	Россия, Ставропольский край, Ставрополь, улица Мира	0101000020E61000005BD2510E66FB444044C362D4B5844640
90625	8	81	\N	818	60195	\N	45.037087999999997	Ставропольский край, город Ставрополь, Ленинский район, Мира, 349		0101000020E610000071C6302768FB44407A89B14CBF844640
90681	8	81	\N	818	5502	\N	45.067818000000003	Ставропольский край, город Ставрополь, Октябрьский район, Макарова переулок, 1	Россия, Ставропольский край, Ставрополь, Макарова переулок, 1	0101000020E61000001135D1E7A3F84440420A9E42AE884640
90653	8	81	\N	818	59951	\N	44.994265114681298	Ставропольский край, город Ставрополь, Ленинский район, Магистральная, 16/1	Россия	0101000020E61000003012DA722E0545405A475513447F4640
90631	8	81	\N	818	60224	\N	45.035266999999997	Ставропольский край, город Ставрополь, Ленинский район, Лермонтова, 189/А		0101000020E6100000B3D0CE6916FC444063D009A183844640
91095	8	81	\N	818	60182	\N	45.042552999999998	Ставропольский край, Ипатовский район, Ленина, 111		0101000020E6100000B2B8FFC874FE444060AC6F6072854640
90694	8	81	\N	818	60182	\N	45.037750562432102	Ставропольский край, город Ставрополь, Промышленный район, ул. Ленина, д. 419	Россия, Ставропольский край, Ставрополь, улица Ленина	0101000020E61000007B116DC7D4F5444016325706D5844640
90619	8	81	\N	818	60182	\N	45.043247000000001	Ставропольский край, город Ставрополь, Ленинский район, Ленина, 73		0101000020E61000001FBDE13E72FF44403753211E89854640
90614	8	81	\N	818	60182	\N	45.039839999999998	Ставропольский край, город Ставрополь, Ленинский район, Ленина, 274		0101000020E6100000A48AE255D6FC44404C89247A19854640
90613	8	81	\N	818	60182	\N	45.039074999999997	Ставропольский край, город Ставрополь, Ленинский район, Ленина, 292		0101000020E6100000F33AE2900DFC4440AC8BDB6800854640
90608	8	81	\N	818	60182	\N	45.043805963510501	Ставропольский край, город Ставрополь, Ленинский район, Ленина, 3/А	Россия, Ставропольский край, Ставрополь, улица Ленина	0101000020E6100000E4A25A44140145402DAF5C6F9B854640
90606	8	81	\N	818	60182	\N	45.038642000000003	Ставропольский край, город Ставрополь, Ленинский район, Ленина, 267		0101000020E61000004930D5CC5AFA444043209738F2844640
90690	8	81	\N	818	3672	\N	45.041094000000001	Ставропольский край, город Ставрополь, Промышленный район, просп. Кулакова, д. 2	Россия, Ставропольский край, Ставрополь, Кулакова проспект, 2	0101000020E6100000721AA20A7FF44440EA07759142854640
90689	8	81	\N	818	3672	\N	45.059210999999998	Ставропольский край, город Ставрополь, Промышленный район, просп. Кулакова, д. 23	Россия, Ставропольский край, Ставрополь, Кулакова проспект, 23	0101000020E61000005401F73C7FF644401F48DE3994874640
91185	8	81	\N	818	28735	\N	45.033413000000003	Ставропольский край, город-курорт Кисловодск, ул.Крылова, 16		0101000020E6100000E36BCF2C09FC444071218FE046844640
90642	8	81	\N	818	4996	\N	45.031458000000001	Ставропольский край, город Ставрополь, Ленинский район, Крупской, 31	Россия, Ставропольский край, Ставрополь, Крупской переулок, 31	0101000020E61000008B6CE7FBA9FD44404A99D4D006844640
90705	8	81	\N	818	60197	\N	45.026986665050103	Ставропольский край, город Ставрополь, Промышленный район, ул. Краснофлотская, д. 185	Россия, Ставропольский край, Ставрополь, Петрова проезд	0101000020E6100000A14B38F416F9444065355D4F74834640
90704	8	81	\N	818	60197	\N	45.033839999999998	Ставропольский край, город Ставрополь, Промышленный район, ул. Краснофлотская, д. 88		0101000020E61000005726FC523FF94440F8A57EDE54844640
90902	8	81	\N	16251	59537	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Кочубея, 9		0101000020E610000037FC6EBA65BB45406EA6423C12134640
91009	8	81	\N	818	1057	\N	45.050882999999999	Ставропольский край, город-курорт Железноводск, Карла Маркса, 37	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 37	0101000020E6100000C98FF8156BFE444010768A5583864640
90662	8	81	\N	818	1057	\N	45.053677999999998	Ставропольский край, город Ставрополь, Октябрьский район, К.Маркса, 11	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 11	0101000020E6100000F4C29D0B23FF4440E141B3EBDE864640
90661	8	81	\N	818	1057	\N	45.053677999999998	Ставропольский край, город Ставрополь, Октябрьский район, проспект К. Маркса, 11	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 11	0101000020E6100000F4C29D0B23FF4440E141B3EBDE864640
90660	8	81	\N	818	1057	\N	45.054473999999999	Ставропольский край, город Ставрополь, Октябрьский район, проспект К.Маркса, 7	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 7	0101000020E6100000FB03E5B67DFF4440BC3D0801F9864640
90654	8	81	\N	818	60238	\N	45.048112000000003	Ставропольский край, город Ставрополь, Октябрьский район, проспект К.Маркса, 64		0101000020E6100000758F6CAE9AFD4440C845B58828864640
90626	8	81	\N	818	4802	\N	45.039622999999999	Ставропольский край, город Ставрополь, Ленинский район, Зоотехнический, 6	Россия, Ставропольский край, Ставрополь, Зоотехнический переулок, 6	0101000020E6100000F16778B306FB4440AF95D05D12854640
90737	8	81	\N	818	60227	\N	44.996335999999999	Ставропольский край, город Ставрополь, Промышленный район, Доваторцев улица, 66		0101000020E6100000A75B76887FF64440EAE923F0877F4640
90724	8	81	\N	818	60227	\N	45.011783999999999	Ставропольский край, город Ставрополь, Промышленный район, ул. Доваторцев, д. 47		0101000020E61000004E4354E1CFF64440DB4E5B2382814640
90634	8	81	\N	818	60363	\N	45.041145	Ставропольский край, город Ставрополь, Ленинский район, Добролюбова, 18		0101000020E6100000BF0D315EF3FE44406CB2463D44854640
90665	8	81	\N	818	60236	\N	45.049729999999997	Ставропольский край, город Ставрополь, Октябрьский район, ул.Дзержинского, 1		0101000020E6100000994A3FE1ECFE4440A6D0798D5D864640
90699	8	81	\N	818	60233	\N	45.042368000000003	Ставропольский край, город Ставрополь, Промышленный район, ул. Дзержинского, д. 231		0101000020E6100000C28A53AD85F94440CF328B506C854640
90621	8	81	\N	818	4736	\N	45.043604000000002	Ставропольский край, город Ставрополь, Ленинский район, Гризодуюовой, 9/А	Россия, Ставропольский край, Ставрополь, Гризодубовой переулок, 9а	0101000020E6100000E886A6ECF4FF4440C6FCDCD094854640
90620	8	81	\N	818	4736	\N	45.043604000000002	Ставропольский край, город Ставрополь, Ленинский район, Гризодубовой, 9/А	Россия, Ставропольский край, Ставрополь, Гризодубовой переулок, 9а	0101000020E6100000E886A6ECF4FF4440C6FCDCD094854640
90618	8	81	\N	818	4716	\N	45.044725	Ставропольский край, город Ставрополь, Ленинский район, Готвальда, 6	Россия, Ставропольский край, Ставрополь, Готвальда проезд, 6	0101000020E610000068CC24EA05FF444024287E8CB9854640
90616	8	81	\N	818	60229	\N	45.046883000000001	Ставропольский край, город Ставрополь, Ленинский район, Голенева, 46		0101000020E6100000DD3F16A243FE444083DE1B4300864640
91776	8	81	\N	818	60361	\N	45.037719000000003	Ставропольский край, Труновский район, село Новая Кугульта, Гагарина, 14		0101000020E61000003DF372D87DF744400BB8E7F9D3844640
90720	8	81	\N	818	5902	\N	45.016033999999998	Ставропольский край, город Ставрополь, Промышленный район, Ворошилова, 10/1	Россия, Ставропольский край, Ставрополь, Ворошилова проспект, 10к1	0101000020E610000010CAFB389AF54440E1CFF0660D824640
90719	8	81	\N	818	5902	\N	45.017467000000003	Ставропольский край, город Ставрополь, Промышленный район, Ворошилова, 7/2А		0101000020E61000002F6F0ED76AF544402FE1D05B3C824640
90718	8	81	\N	818	5902	\N	45.017237999999999	Ставропольский край, город Ставрополь, Промышленный район, Ворошилова, 8	Россия, Ставропольский край, Ставрополь, Ворошилова проспект, 8	0101000020E610000028D4D347E0F54440CD1FD3DA34824640
90691	8	81	\N	818	60228	\N	45.054588000000003	Ставропольский край, город Ставрополь, Промышленный район, ул.Васякина, д. 127/а		0101000020E61000004AB20E4757F74440856055BDFC864640
90683	8	81	\N	818	60242	\N	45.063113999999999	Ставропольский край, город Ставрополь, Промышленный район, ул. Бруснева, д. 10		0101000020E6100000F834272F32F74440BAF59A1E14884640
90693	8	81	\N	818	5627	\N	45.035260000000001	Ставропольский край, город Ставрополь, Промышленный район, пр. Ботанический, д. 7	Россия, Ставропольский край, Ставрополь, Ботанический проезд, 7	0101000020E6100000460C3B8C49F54440B16D516683844640
90651	8	81	\N	818	60255	\N	45.027610000000003	Ставропольский край, город Ставрополь, Ленинский район, Биологическая, 18		0101000020E61000009B594B0169014540738577B988834640
90666	8	81	\N	818	60241	\N	45.057077999999997	Ставропольский край, город Ставрополь, Октябрьский район, Бабушкина, 2 А		0101000020E61000007590D7834901454019A9F7544E874640
90726	8	81	\N	818	60246	\N	45.006520000000002	Ставропольский край, город Ставрополь, Промышленный район, ул. 50 лет ВЛКСМ, д. 38		0101000020E61000004EED0C535BF644408D62B9A5D5804640
90729	8	81	\N	818	60237	\N	45.005360000000003	Ставропольский край, город Ставрополь, Промышленный район, ул. 50 лет ВЛКСМ, д. 65		0101000020E6100000B4571F0F7DF54440715AF0A2AF804640
90736	8	81	\N	818	60223	\N	44.999408000000003	Ставропольский край, город Ставрополь, Промышленный район, 45 Параллель, 3/1		0101000020E61000008048BF7D1DF644402EAEF199EC7F4640
90664	8	81	\N	818	60254	\N	45.053460999999999	Ставропольский край, город Ставрополь, Октябрьский район, Фрунзе, 2		0101000020E6100000F3203D450EFD4440444E5FCFD7864640
90637	8	81	\N	818	59935	\N	45.028877999999999	Ставропольский край, город Ставрополь, Ленинский район, Серова, 272		0101000020E61000000D6C956071FC444075C93846B2834640
90739	8	81	\N	818	60600	\N	45.002875000000003	Ставропольский край, г. Ставрополь, Промышленнйый район, ул. Родосская, 3		0101000020E61000005FD4EE5701F44440EE7C3F355E804640
90675	8	81	\N	818	60240	\N	45.059356999999999	Ставропольский край, город Ставрополь, Октябрьский район, Октябрьская, 66		0101000020E61000004E44BFB67EFA4440F3E49A0299874640
90644	8	81	\N	818	60239	\N	45.016671000000002	Ставропольский край, город Ставрополь, Ленинский район, Мичурина, 55		0101000020E6100000B72A89EC83FC444054E57B4622824640
90607	8	81	\N	818	60192	\N	45.041515757351803	Ставропольский край, город Ставрополь, Ленинский район, М.Морозова, 5	Россия, Ставропольский край, Ставрополь, улица Михаила Морозова	0101000020E61000008A3F8A3A73FB44406021736550854640
90649	8	81	\N	818	60151	\N	45.037827	Ставропольский край, город Ставрополь, Ленинский район, Мимоз, 24		0101000020E6100000A80018CFA0034540F1F3DF83D7844640
90713	8	81	\N	818	60217	\N	45.01446	Ставропольский край, город Ставрополь, Промышленный район, Доваторцев, 50/1		0101000020E610000021020EA14AF74440D28C45D3D9814640
90638	8	81	\N	818	60230	\N	45.023890000000002	Ставропольский край, город Ставрополь, Ленинский район, Абрамовой, 2		0101000020E6100000B6F468AA27FB4440C959D8D30E834640
91695	8	81	\N	57588	59696	\N	44.023592999999998	Ставропольский край, город-курорт Пятигорск, рабочий поселок Свободы, Калинина, 150		0101000020E61000004B02D4D4B28545400FB56D1805034640
91548	8	81	\N	57585	59642	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Тургенева, дом 27		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91553	8	81	\N	57585	60110	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Кузнечная, дом 285, учебный корпус		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91546	8	81	\N	57585	59828	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Гагарина, дом 1		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91651	8	81	\N	2177	59840	\N	44.050554573723097	Пятигорск, пр. Калинина, 11	Россия, Ставропольский край, Пятигорск	0101000020E610000041BAD8B4528245401CD3139678064640
91667	8	81	\N	2177	59844	\N	44.022044000000001	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, Шоссейная, 103		0101000020E61000008E226B0DA58C454059897956D2024640
91688	8	81	\N	2177	59936	\N	44.052844999999998	Ставропольский край, город Пятигорск, Школьная, 47		0101000020E6100000888043A852834540E960FD9FC3064640
91655	8	81	\N	2177	59837	\N	44.047892902140703	Ставропольский край, город-курорт Пятигорск, Фучика, 4, корп.3	Россия, Ставропольский край, Пятигорск	0101000020E6100000102384471B8545408A5A9A5B21064640
91687	8	81	\N	2177	59847	\N	44.051362578926899	Ставропольский край, город-курорт Пятигорск, Февральская, 283	Россия, Ставропольский край, Пятигорск	0101000020E610000003D2FE0758854540BB9C121093064640
91686	8	81	\N	2177	59847	\N	43.955369145133801	Ставропольский край, город-курорт Пятигорск, Февральская, 54	Россия, Ставропольский край, Предгорный район	0101000020E61000009F56D11F9A8F45405D4E098849FA4540
91646	8	81	\N	2177	59652	\N	44.055324219052501	Ставропольский край, город Пятигорск, Университетская, 41	Россия, Ставропольский край, Пятигорск	0101000020E61000003BFE0B04018245408A5759DB14074640
91643	8	81	\N	2177	59652	\N	44.054058724235603	Ставропольский край, город-курорт Пятигорск, Университетская, 6	Россия, Ставропольский край, Пятигорск	0101000020E6100000946B0A6476844540F986C267EB064640
91705	8	81	\N	2177	60171	\N	44.044296540325703	Ставропольский край, город-курорт Пятигорск, Украинская, 57	Россия, Ставропольский край, Пятигорск	0101000020E6100000D0436D1B46854540CC272B86AB054640
91635	8	81	\N	2177	59883	\N	44.053591034333301	Ставропольский край, город-курорт Пятигорск, Теплосерная, 52	Россия, Ставропольский край, Пятигорск	0101000020E6100000401361C3D3854540122EE411DC064640
91672	8	81	\N	2177	59659	\N	44.022044000000001	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, Советская, 164		0101000020E61000008E226B0DA58C454059897956D2024640
91691	8	81	\N	2177	60366	\N	44.046151999999999	Ставропольский край, город-курорт Пятигорск, село Золотушка, Прогонная, 3		0101000020E61000009146054EB67B45408F52094FE8054640
91648	8	81	\N	2177	59654	\N	44.042197240996799	Ставропольский край, город-курорт Пятигорск, Подстанционная, 23	Россия, Ставропольский край, Пятигорск	0101000020E6100000AF44A0FA07854540A27E17B666054640
91680	8	81	\N	2177	59932	\N	44.051857798536297	Ставропольский край, город-курорт Пятигорск, Пестова, 32	Россия, Ставропольский край, Пятигорск	0101000020E610000064575A46EA8545409B046F48A3064640
91649	8	81	\N	2177	59925	\N	44.052102384222103	Ставропольский край, город-курорт Пятигорск, Панагюриште, 14а	Россия, Ставропольский край, Пятигорск	0101000020E6100000E57CB1F7E285454031074147AB064640
91682	8	81	\N	2177	59689	\N	44.052844999999998	Ставропольский край, город-курорт Пятигорск, Нежнова, 19	Россия, Ставропольский край, Пятигорск	0101000020E6100000888043A852834540E960FD9FC3064640
91656	8	81	\N	2177	60211	\N	44.051114967558597	Ставропольский край, город-курорт Пятигорск, Московская, 76		0101000020E6100000176536C824854540E3AAB2EF8A064640
91712	8	81	\N	2177	60187	\N	44.0479307472296	Ставропольский край, город-курорт Пятигорск, Мира, 187	Россия, Ставропольский край, Пятигорск	0101000020E6100000CFBF5DF6EB86454077BB5E9A22064640
91641	8	81	\N	2177	60410	\N	44.051381681713799	Ставропольский край, город Пятигорск, п. Средний Подкумок, ул. Механизаторов, 12	Россия, Ставропольский край, Пятигорск	0101000020E61000002ECBD765F881454031CD74AF93064640
91709	8	81	\N	2177	60160	\N	44.051148941641102	Ставропольский край, город-курорт Пятигорск, Матвеева, 35а	Россия, Ставропольский край, Пятигорск	0101000020E6100000D976DA1A118245408F1CE90C8C064640
91340	8	81	\N	13776	59806	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Красная, д.45		0101000020E6100000E88711C2A391454066A3737E8A194640
91698	8	81	\N	2177	59698	\N	44.022292438149201	Ставропольский край, город-курорт Пятигорск, рабочий поселок Свободы, Маршала Жукова, 39а		0101000020E61000001137A79201864540317BD976DA024640
91693	8	81	\N	2177	60546	\N	44.053960017390899	Ставропольский край, город-курорт Пятигорск, Лесная, 1а	Россия, Ставропольский край, Пятигорск	0101000020E6100000BE839F388084454065A54929E8064640
91665	8	81	\N	2177	60144	\N	44.020895293438201	Ставропольский край, город Пятигорск, рабочий поселок Горячеводский, Ленина, 116а		0101000020E6100000147AFD497C8C454031D3F6AFAC024640
91663	8	81	\N	2177	59655	\N	44.065474703820598	Пятигорск, Ленина, 51	Россия, Ставропольский край, Пятигорск	0101000020E6100000ED4ACB48BD85454051DA1B7C61084640
91653	8	81	\N	2177	60248	\N	44.051336342810799	Ставропольский край, город-курорт Пятигорск, Кучуры, 24	Россия, Ставропольский край, Пятигорск	0101000020E610000020B6F468AA874540C18D942D92064640
91652	8	81	\N	2177	60248	\N	44.039473034217004	Ставропольский край, город-курорт Пятигорск, Кучуры, 8	Россия, Ставропольский край, Пятигорск	0101000020E610000059130B7C458545409A0986730D054640
91708	8	81	\N	2177	60250	\N	44.0569328337738	Ставропольский край, город-курорт Пятигорск, Куйбышева, 4	Россия, Ставропольский край, Пятигорск	0101000020E6100000224F92AE9982454016889E9449074640
91700	8	81	\N	2177	59704	\N	44.022664036771097	Ставропольский край, город-курорт Пятигорск, рабочий поселок Свободы, Крутой переулок, 5	Россия, Ставропольский край, Пятигорск городской округ, поселок городского типа Свободы	0101000020E6100000232C2AE274864540F56569A7E6024640
91711	8	81	\N	2177	60147	\N	44.057054330393001	Ставропольский край, город-курорт Пятигорск, Краснознаменная, 32	Россия, Ставропольский край, Пятигорск	0101000020E610000018096D3997824540910DA48B4D074640
91684	8	81	\N	2177	59842	\N	44.034352349861599	Ставропольский край, город Пятигорск, Кочубея, 21	Россия, Ставропольский край, Пятигорск	0101000020E61000008D28ED0DBE844540AE4676A565044640
91685	8	81	\N	2177	59661	\N	44.044426043637301	Ставропольский край, город-курорт Пятигорск, Комарова, 7	Россия, Ставропольский край, Пятигорск	0101000020E6100000DE3D40F7E5824540CA8B4CC0AF054640
91683	8	81	\N	2177	60162	\N	44.0545787721192	Ставропольский край, город-курорт Пятигорск, Коллективная, 3	Россия, Ставропольский край, Пятигорск	0101000020E6100000CAA5F10BAF8445403106D671FC064640
91644	8	81	\N	2177	59890	\N	44.0520618819668	Ставропольский край, город-курорт Пятигорск, Кирова, 68	Россия, Ставропольский край, Пятигорск	0101000020E610000097C9703C9F854540A3AEB5F7A9064640
91636	8	81	\N	2177	59890	\N	44.052844999999998	Пятигорск, пр. Кирова, 30		0101000020E6100000888043A852834540E960FD9FC3064640
91650	8	81	\N	2177	60188	\N	44.0543338340388	Ставропольский край, город-курорт Пятигорск, Калинина, 9		0101000020E6100000562AA8A8FA834540CA87A06AF4064640
91647	8	81	\N	2177	60188	\N	44.053834282926204	Ставропольский край, город-курорт Пятигорск, Калинина, 50	Россия, Ставропольский край, Пятигорск	0101000020E61000006728EE7893854540D9B45208E4064640
91654	8	81	\N	2177	59653	\N	44.055571812699903	Ставропольский край, город-курорт Пятигорск, Зорге, 8	Россия, Ставропольский край, Пятигорск	0101000020E610000049BBD1C77C8245406249B9FB1C074640
91694	8	81	\N	2177	60124	\N	44.049378394282499	Ставропольский край, город Пятигорск, Железнодорожная, 121	Россия, Ставропольский край, Пятигорск	0101000020E6100000FD169D2CB58245402992AF0452064640
91702	8	81	\N	2177	60163	\N	44.041657319232897	Ставропольский край, город-курорт Пятигорск, Ессентукская, 76а	Россия, Ставропольский край, Пятигорск	0101000020E6100000B6813B50A786454022533E0455054640
91689	8	81	\N	2177	59964	\N	44.054083212725899	Ставропольский край, город-курорт Пятигорск, Ермолова, 213	Россия, Ставропольский край, Пятигорск	0101000020E61000007B2DE8BD3186454081221631EC064640
91642	8	81	\N	2177	60210	\N	44.049918607908197	Ставропольский край, город-курорт Пятигорск, Дзержинского, 12	Россия, Ставропольский край, Пятигорск	0101000020E61000007A71E2AB1D8545407A39ECBE63064640
91706	8	81	\N	2177	9886	\N	44.048017077468998	Ставропольский край, город-курорт Пятигорск, Бештаугорская, 45а	Россия, Ставропольский край, Пятигорск	0101000020E6100000740CC85EEF8445407653CA6B25064640
91658	8	81	\N	2177	59971	\N	44.050124511661501	Ставропольский край, город-курорт Пятигорск, Аллея строителей, 2	Россия, Ставропольский край, Пятигорск	0101000020E6100000401361C3D385454023DBF97E6A064640
91657	8	81	\N	2177	59971	\N	44.058867803823297	Ставропольский край, город-курорт Пятигорск, Аллея Строителей, 7	Россия, Ставропольский край, Пятигорск	0101000020E610000043AD69DE71884540F56393FC88074640
91703	8	81	\N	2177	59947	\N	44.052844999999998	Ставропольский край, город Пятигорск, Адмиральского, 8 корп. 4		0101000020E6100000888043A852834540E960FD9FC3064640
91690	8	81	\N	2177	59766	\N	44.046781599874699	Ставропольский край, город-курорт Пятигорск, 5-й переулок, 1, корп.1, литер А		0101000020E6100000EF74E789E78445404F05DCF3FC054640
91645	8	81	\N	2177	59933	\N	44.0556925867619	Ставропольский край, город-курорт Пятигорск, 40 лет Октября, 99	Россия, Ставропольский край, Пятигорск	0101000020E61000001F48DE3994854540DDCEBEF220074640
91659	8	81	\N	2177	60002	\N	44.052844999999998	Ставропольский край, город Пятигорск, ул. 295 стрелковой дивизии, 14		0101000020E6100000888043A852834540E960FD9FC3064640
91681	8	81	\N	2177	59658	\N	44.042447912955701	Ставропольский край, город-курорт Пятигорск, 1-я Набережная, 26	Россия, Ставропольский край, Пятигорск	0101000020E61000000E65A88AA9864540EBE3A1EF6E054640
91707	8	81	\N	2177	9705	\N	44.048638796543699	Ставропольский край, город Пятигорск, 50 лет ВЛКСМ, 48	Россия, Ставропольский край, Пятигорск	0101000020E61000005E807D74EA824540B32781CD39064640
91130	8	81	\N	57604	60064	\N	43.963611999999998	Ставропольский край, Кировский район, город Новопавловск, Комсомольская, 75		0101000020E6100000FDBB3E73D6D145403E0455A357FB4540
91443	8	81	\N	57596	59852	\N	44.741162000000003	"Ставропольский край, Нефтекумский район, город Нефтекумск, м-он № 2, МОУ ""СОШ № 3"""		0101000020E61000008C648F50337E4640DC847B65DE5E4640
91252	8	81	\N	6327	60528	\N	44.525300125496102	Ставропольский край, Кочубеевский район, Новодеревенский сельсовет, хутор Харьковский, пер. Садовый, 6	Россия, Ставропольский край, Невинномысск городской округ, село Харьковский	0101000020E6100000D3A414747BF344405E4BC8073D434640
91412	8	81	\N	6327	59814	\N	44.631475000000002	Ставропольский край, город Невинномысск, бульвар Мира, 24		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91410	8	81	\N	6327	59814	\N	44.631475000000002	Ставропольский край, город Невинномысск, бульвар Мира, 17		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91409	8	81	\N	6327	59814	\N	44.639609882449399	Ставропольский край, город Невинномысск, бульвар Мира, 9	Россия, Ставропольский край, Невинномысск	0101000020E610000067F2CD3637F84440E71890BDDE514640
91432	8	81	\N	6327	59624	\N	44.638583426711399	Ставропольский край, город Невинномысск, Школьная, 52	Россия, Ставропольский край, Невинномысск	0101000020E61000007AE2395B40F844400A647616BD514640
91436	8	81	\N	6327	59996	\N	44.631475000000002	Ставропольский край, город Невинномысск, Шевченко, 6/А		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91416	8	81	\N	6327	60077	\N	44.631475000000002	Ставропольский край, город Невинномысск, Чкалова, 67		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91214	8	81	\N	6327	59578	\N	44.577278	Ставропольский край, Кочубеевский район,  с. Ивановское, ул. Чапаева, д. 169/а		0101000020E610000076E107E753EF4440A359D93EE4494640
91407	8	81	\N	6327	59874	\N	44.631475000000002	Ставропольский край, город Невинномысск, Чайковского, 2а		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91248	8	81	\N	6327	60444	\N	44.568129543870803	Ставропольский край, Кочубеевский район, х. Сотникова, ул. Центральная, д. 3	Россия, Ставропольский край, Невинномысск городской округ, село Сотникова	0101000020E610000093718C648FFE444030F0DC7BB8484640
91240	8	81	\N	6327	60430	\N	44.769517999999998	Ставропольский край, Кочубеевский район, Стародворцовский сельсовет, станица Новоекатериновская, Центральная, 6		0101000020E6100000124BCADDE704454077D7D9907F624640
91433	8	81	\N	6327	59625	\N	44.6235521827413	Ставропольский край, город Невинномысск, Социалистическая, 184	Россия, Ставропольский край, Невинномысск	0101000020E6100000CB80B3942CF944407DAD4B8DD04F4640
91413	8	81	\N	6327	59813	\N	44.631475000000002	Ставропольский край, город Невинномысск, Северная, 14		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91411	8	81	\N	6327	59813	\N	44.632822679201603	Ставропольский край, город Невинномысск, Северная, 9/А	Россия, Ставропольский край, Невинномысск	0101000020E61000008C15359886F944400C94145800514640
91247	8	81	\N	6327	60412	\N	44.518461000000002	Ставропольский край, Кочубеевский район, Усть-Невинский сельсовет, хутор Родниковский, ул. Садовая, д. 43/б		0101000020E610000025C9737D1F02454030A017EE5C424640
91417	8	81	\N	6327	60092	\N	44.634293563089898	Ставропольский край, город Невинномысск, Революционная, 9	Россия, Ставропольский край, Невинномысск	0101000020E610000056444DF4F9F844404606B98B30514640
91428	8	81	\N	6327	59623	\N	44.641769975847701	Ставропольский край, город Невинномысск, Пушкина, 2	Россия, Ставропольский край, Невинномысск	0101000020E6100000BD1DE1B4E0F74440E7C6F48425524640
91408	8	81	\N	6327	60094	\N	44.631475000000002	Ставропольский край, город Невинномысск, Павлова, 17		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91242	8	81	\N	6327	60447	\N	44.668401479600398	Ставропольский край, Кочубеевский район, Стародворцовский сельсовет, село Дворцовское, пер. Молодежный, 4		0101000020E610000093E4B9BE0F1145408ECEF9298E554640
91403	8	81	\N	6327	60091	\N	44.624241775115898	Ставропольский край, город Невинномысск, ул. Мичурина, 1	Россия, Ставропольский край, Невинномысск	0101000020E6100000D76D50FBADF9444013656F29E74F4640
91415	8	81	\N	6327	59816	\N	44.631475000000002	Ставропольский край, город Невинномысск, бульвар Мира, 27		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91234	8	81	\N	6327	60456	\N	44.8388288575998	Ставропольский край, Кочубеевский район, с. Галицино, ул. Мира, д.8		0101000020E6100000904B1C7920D44440DBF7A8BF5E6B4640
91406	8	81	\N	6327	59855	\N	44.631475000000002	Ставропольский край, город Невинномысск, Менделеева, 25		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91405	8	81	\N	6327	59855	\N	44.631475000000002	Ставропольский край, город Невинномысск, Менделеева, 68		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91397	8	81	\N	6327	59855	\N	44.631475000000002	Ставропольский край, город Невинномысск, Менделеева, 5/А		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91053	8	81	\N	6327	59855	\N	44.631475000000002	Ставропольский край, город Невинномысск, Менделеева, 16/А		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91435	8	81	\N	6327	59871	\N	44.628165350875001	Ставропольский край, город Невинномысск, Маяковского, 24	Россия, Ставропольский край, Невинномысск	0101000020E6100000691D554D10F94440F5BEF1B567504640
91434	8	81	\N	6327	59626	\N	44.631475000000002	Ставропольский край, город Невинномысск, Матросова, 165		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91439	8	81	\N	6327	59875	\N	44.631475000000002	Ставропольский край, город Невинномысск, Луначарского, 149		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91438	8	81	\N	6327	59875	\N	44.628287935869203	Ставропольский край, город Невинномысск, Луначарского, 28	Россия, Ставропольский край, Невинномысск	0101000020E61000001825E82FF4F84440103CBEBD6B504640
91430	8	81	\N	6327	59877	\N	44.631475000000002	Ставропольский край, город Невинномысск, Ленина, 107		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91225	8	81	\N	6327	60305	\N	44.603467999999999	Ставропольский край, Кочубеевский район, Мищенский сельсовет, хутор Мищенский, Ленина, 44/а		0101000020E6100000D828EB3713CD44405D177E703E4D4640
91233	8	81	\N	6327	60343	\N	44.843885724208697	Ставропольский край, Кочубеевский район, Балахоновский сельсовет, аул Карамурзинский, ул. Кумукова, д. 20	Россия, Ставропольский край, Невинномысск городской округ, село Карамурзинский	0101000020E6100000CEC29E76F8DD4440B0C6D974046C4640
91236	8	81	\N	6327	60342	\N	44.918860000000002	Ставропольский край, Кочубеевский район, Надзорненский сельсовет, поселок Тоннельный, Королева, 4/а		0101000020E6100000234BE658DED7444021CD58349D754640
91422	8	81	\N	6327	59873	\N	44.631475000000002	Ставропольский край, город Невинномысск, Кооперативная, 98		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91425	8	81	\N	6327	59818	\N	44.628410520602699	Ставропольский край, город Невинномысск, Калинина, 182/1	Россия, Ставропольский край, Невинномысск	0101000020E61000004209336DFFF844402CB98AC56F504640
91423	8	81	\N	6327	59818	\N	44.628778273239398	Ставропольский край, город Невинномысск, Калинина, 159А	Россия, Ставропольский край, Невинномысск	0101000020E610000026E2ADF36FF94440DE3829CC7B504640
91437	8	81	\N	6327	59876	\N	44.623506209622803	Ставропольский край, город Невинномысск, Зои Космодемьянской, 1	Россия, Ставропольский край, Невинномысск	0101000020E61000003B1DC87A6AF944400D6E6B0BCF4F4640
91223	8	81	\N	6327	60428	\N	44.6661488316687	Ставропольский край, Кочубеевский район, Васильевский сельсовет, хутор Васильевский, Гайнулина, 82А		0101000020E6100000952A51F696D24440ADA1D45E44554640
91427	8	81	\N	6327	59621	\N	44.631475000000002	Ставропольский край, город Невинномысск, Гагарина, 114		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91421	8	81	\N	6327	59621	\N	44.631475000000002	Ставропольский край, город Невинномысск, Гагарина, 53Б		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91420	8	81	\N	6327	59621	\N	44.627796876051697	Ставропольский край, город Невинномысск, Гагарина, 43Б	Россия, Ставропольский край, Невинномысск	0101000020E6100000514A0856D5F9444072C3EFA65B504640
91419	8	81	\N	6327	59621	\N	44.631475000000002	Ставропольский край, город Невинномысск, Гагарина, 56		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91418	8	81	\N	6327	59621	\N	44.628042765620201	Ставропольский край, город Невинномысск, Гагарина, 62/А	Россия, Ставропольский край, Невинномысск	0101000020E61000001555BFD2F9F84440A9BD88B663504640
91431	8	81	\N	6327	60093	\N	44.625345105761497	Ставропольский край, город Невинномысск, Апанасенко, 82А	Россия, Ставропольский край, Невинномысск	0101000020E610000040BD19355FF94440CBDB114E0B504640
91213	8	81	\N	6327	59586	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, ул. 60 лет Октября, д. 1		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91404	8	81	\N	6327	59812	\N	44.6273065303346	Ставропольский край, город Невинномысск, 30 лет Победы, 6	Россия, Ставропольский край, Невинномысск	0101000020E610000065A71FD445FA4440A4C684984B504640
91429	8	81	\N	6327	60095	\N	44.631475000000002	Ставропольский край, город Невинномысск, Ленина, 85-а		0101000020E610000029B2D6506AF94440ED9E3C2CD4504640
91812	8	81	\N	57587	59680	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, переулок Транспортный, 13		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91797	8	81	\N	57587	59991	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Войкова, 567/4		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91354	8	81	\N	13776	59865	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, пр-т 22 партсъезда, д.94		0101000020E6100000E88711C2A391454066A3737E8A194640
91347	8	81	\N	13776	59866	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, пр-т К. Маркса, д.64		0101000020E6100000E88711C2A391454066A3737E8A194640
91355	8	81	\N	13776	59841	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, пр-т 22 партсъезда, д.133		0101000020E6100000E88711C2A391454066A3737E8A194640
91351	8	81	\N	13776	59841	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, пр-т 22 партсъезда, д.42		0101000020E6100000E88711C2A391454066A3737E8A194640
91350	8	81	\N	13776	59841	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, пр-т 22 партсъезда, д.12		0101000020E6100000E88711C2A391454066A3737E8A194640
91339	8	81	\N	13776	59612	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Фрунзе, д.52		0101000020E6100000E88711C2A391454066A3737E8A194640
91211	8	81	\N	13776	59577	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Толстого, д.43		0101000020E6100000E88711C2A391454066A3737E8A194640
91346	8	81	\N	13776	59804	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Ставропольская, д.37		0101000020E6100000E88711C2A391454066A3737E8A194640
91345	8	81	\N	13776	59804	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Ставропольская, д.25		0101000020E6100000E88711C2A391454066A3737E8A194640
91322	8	81	\N	13776	60073	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Советская, д.32		0101000020E6100000E88711C2A391454066A3737E8A194640
91359	8	81	\N	13776	59614	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул.Пушкина, д.10		0101000020E6100000E88711C2A391454066A3737E8A194640
91356	8	81	\N	13776	59809	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Новоселов, д.8		0101000020E6100000E88711C2A391454066A3737E8A194640
91361	8	81	\N	13776	59995	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Новая, д.2		0101000020E6100000E88711C2A391454066A3737E8A194640
91343	8	81	\N	13776	59803	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, Московская, д.37		0101000020E6100000E88711C2A391454066A3737E8A194640
91342	8	81	\N	13776	59803	\N	44.1958680638487	Ставропольский край, г.Минеравльные Воды, ул. Московская, д. 29	Россия, Ставропольский край, Минеральные Воды	0101000020E6100000815A0C1EA69145409D2ADF3312194640
91360	8	81	\N	13776	60090	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Линейная, д.2		0101000020E6100000E88711C2A391454066A3737E8A194640
91341	8	81	\N	13776	59613	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Калинина, д.111		0101000020E6100000E88711C2A391454066A3737E8A194640
91344	8	81	\N	13776	59864	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Железноводская, ДК авиаработников		0101000020E6100000E88711C2A391454066A3737E8A194640
91338	8	81	\N	13776	60086	\N	44.199539000000001	"Ставропольский край, город Минеральные Воды, здание ФГУП ""Совхоз Железнодорожник"", ул. Желатиновая, д.9"		0101000020E6100000E88711C2A391454066A3737E8A194640
91362	8	81	\N	13776	59616	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Дружбы, д.35		0101000020E6100000E88711C2A391454066A3737E8A194640
91352	8	81	\N	13776	59805	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул.Гагарина, д.90а		0101000020E6100000E88711C2A391454066A3737E8A194640
91358	8	81	\N	13776	59810	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Анджиевского, д.1		0101000020E6100000E88711C2A391454066A3737E8A194640
91357	8	81	\N	13776	59810	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул.Анджиевского, д.33		0101000020E6100000E88711C2A391454066A3737E8A194640
91353	8	81	\N	13776	59992	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. 50 лет Октября, д.48а		0101000020E6100000E88711C2A391454066A3737E8A194640
91363	8	81	\N	13776	59620	\N	44.175082459358102	"Ставропольский край, город Минеральные Воды, 5 км, МУП ""Маршрут"""	Россия, Ставропольский край, Минеральные Воды городской округ	0101000020E61000005C74B2D47A914540240F441669164640
91349	8	81	\N	13776	59863	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул.Ленина, д.67		0101000020E6100000E88711C2A391454066A3737E8A194640
91348	8	81	\N	13776	59863	\N	44.199539000000001	Ставропольский край, город Минеральные Воды, ул. Ленина, д. 27а		0101000020E6100000E88711C2A391454066A3737E8A194640
91331	8	81	\N	19616	59860	\N	44.082355577081202	Ставропольский край, город Лермонтов, проезд Химиков, 5	Россия, Ставропольский край, Лермонтов	0101000020E610000099D6A6B1BD8445408F5033A48A0A4640
91333	8	81	\N	19616	59610	\N	44.100295000000003	Ставропольский край, город Лермонтов, Решетника, 3		0101000020E6100000ADF6B0170A7E4540E6797077D60C4640
91332	8	81	\N	19616	59610	\N	44.100295000000003	Ставропольский край, город Лермонтов, Решетника, 2Б		0101000020E6100000ADF6B0170A7E4540E6797077D60C4640
91330	8	81	\N	19616	59859	\N	44.100295000000003	Ставропольский край, город Лермонтов, Нагорная, 6		0101000020E6100000ADF6B0170A7E4540E6797077D60C4640
91336	8	81	\N	19616	59715	\N	44.100295000000003	Ставропольский край, город Лермонтов, Ленина, 18		0101000020E6100000ADF6B0170A7E4540E6797077D60C4640
91335	8	81	\N	19616	59611	\N	44.100295000000003	Ставропольский край, город Лермонтов, Комсомольская, 6		0101000020E6100000ADF6B0170A7E4540E6797077D60C4640
91329	8	81	\N	19616	59609	\N	44.100295000000003	Ставропольский край, город Лермонтов, Горняков, 54		0101000020E6100000ADF6B0170A7E4540E6797077D60C4640
91334	8	81	\N	19616	59807	\N	44.100295000000003	Ставропольский край, город Лермонтов, ул.Гагарина, д.12		0101000020E6100000ADF6B0170A7E4540E6797077D60C4640
91639	8	81	\N	57620	60257	\N	44.043190853385397	Ставропольский край, город-курорт Пятигорск, станица Константиновская, Ленина, 11		0101000020E6100000B5FAEAAA40934540A33D5E4887054640
91179	8	81	\N	10968	60158	\N	43.914113705834197	Ставропольский край, город-курорт Кисловодск, ул.Горького, 27	Россия, Ставропольский край, Кисловодск	0101000020E61000009FE8BAF0835B45406A6803B001F54540
91181	8	81	\N	10968	60263	\N	43.9144859865741	Ставропольский край, город-курорт Кисловодск, ул.Вокзальная, 2	Россия, Ставропольский край, Кисловодск	0101000020E6100000A4A5F276845D45402E5393E00DF54540
91169	8	81	\N	10968	60075	\N	43.911759000000004	Ставропольский край, город Кисловодск, проспект Победы, 37		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91165	8	81	\N	10968	60006	\N	43.911759000000004	Ставропольский край, город Кисловодск, проезд Цандера, 17		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91151	8	81	\N	10968	60070	\N	43.911759000000004	Ставропольский край, город Кисловодск, пр.Победы, 157		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91186	8	81	\N	10968	59811	\N	43.912872753097197	Ставропольский край, город-курорт Кисловодск, пр.Мира, 12	Россия, Ставропольский край, Кисловодск	0101000020E610000091EEE714E45D45406133C005D9F44540
91193	8	81	\N	10968	60401	\N	43.9118179227832	Ставропольский край, город-курорт Кисловодск, пр.Ленина, 30	Россия, Ставропольский край, Кисловодск	0101000020E6100000D5EB1681B15C4540BAF3C473B6F44540
91187	8	81	\N	10968	59854	\N	43.902481296371903	Ставропольский край, город-курорт Кисловодск, пер.Саперный, 10	Россия, Ставропольский край, Кисловодск	0101000020E610000096B4E21B0A5D45407521567F84F34540
91174	8	81	\N	10968	59573	\N	43.907288143321999	Ставропольский край, город-курорт Кисловодск, ул.Щербакова, 20	Россия, Ставропольский край, Кисловодск	0101000020E61000009148DBF8135D4540D106600322F44540
91159	8	81	\N	10968	60071	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. Школьная, 13		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91183	8	81	\N	10968	60177	\N	43.911759000000004	Ставропольский край, город-курорт Кисловодск, ул.Чкалова, 71		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91156	8	81	\N	10968	60069	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул.Челюскинцев, 5		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91152	8	81	\N	10968	59782	\N	43.911759000000004	Ставропольский край, город Кисловодск, Чапаева, 87		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91196	8	81	\N	10968	60537	\N	43.907412251494101	Ставропольский край, город-курорт Кисловодск, ул.Урицкого, 1	Россия, Ставропольский край, Кисловодск	0101000020E61000005C1D0071575D4540BDFF8F1326F44540
91164	8	81	\N	10968	59785	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. У.Алиева, 37		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91155	8	81	\N	10968	59785	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. У.Алиева, 91		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91153	8	81	\N	10968	59570	\N	43.918991948707998	Ставропольский край, город Кисловодск, ул.Терская, 12	Россия, Ставропольский край, Кисловодск	0101000020E61000002A1DACFF735C454090A4A487A1F54540
91163	8	81	\N	10968	59784	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. Седлогорская, 157		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91162	8	81	\N	10968	59784	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. Седлогорская, 112		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91161	8	81	\N	10968	59784	\N	43.907908681576501	Ставропольский край, город Кисловодск, ул. Седлогорская, 42	Россия, Ставропольский край, Кисловодск	0101000020E61000008CF4A276BF5E45403D5FB35C36F44540
91191	8	81	\N	10968	60375	\N	43.9214683608051	Ставропольский край, город-курорт Кисловодск, ул.Пятигорская, 4	Россия, Ставропольский край, Кисловодск	0101000020E6100000A417B5FB555E4540BF27D6A9F2F54540
91197	8	81	\N	10968	60551	\N	43.913120945729197	Ставропольский край, город-курорт Кисловодск, ул.Прудная, 107	Россия, Ставропольский край, Кисловодск	0101000020E6100000931804560E5D454039252026E1F44540
91200	8	81	\N	10968	60493	\N	43.914113705834197	Ставропольский край, город-курорт Кисловодск, ул.Профинтерна, 35	Россия, Ставропольский край, Кисловодск	0101000020E6100000C25087156E5B45406A6803B001F54540
91178	8	81	\N	10968	60003	\N	43.912376364706297	Ставропольский край, город-курорт Кисловодск, ул.Островского, 3		0101000020E61000002F698CD6515D4540E1D39CBCC8F44540
91166	8	81	\N	10968	60003	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. Островского, 27		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91190	8	81	\N	10968	60131	\N	43.911724848616302	Ставропольский край, город-курорт Кисловодск, ул.Ольховская, 80	Россия, Ставропольский край, Кисловодск	0101000020E6100000D3838252B45C454009F9A067B3F44540
91160	8	81	\N	10968	60000	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. Октябрьская, 43		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91170	8	81	\N	10968	59574	\N	43.910220129246497	Ставропольский край, город Кисловодск, ул.Одесская, 3	Россия, Ставропольский край, Кисловодск	0101000020E61000008718AF79555B45402315C61682F44540
91173	8	81	\N	10968	60023	\N	43.9129683704016	Ставропольский край, город-курорт Кисловодск, ул.Нелюбина, 5	Россия, Ставропольский край, Кисловодск	0101000020E6100000D57954FCDF5B4540B325AB22DCF44540
91157	8	81	\N	10968	60005	\N	43.909152889630597	Ставропольский край, город Кисловодск, ул.Набережная, 43-а	Россия, Ставропольский край, Кисловодск	0101000020E61000000B7F86376B5C4540B80721205FF44540
91167	8	81	\N	10968	59703	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул. Ленинградская, 22		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91182	8	81	\N	10968	60165	\N	43.911759000000004	Ставропольский край, город-курорт Кисловодск, ул.Кутузова, 44	Россия, Ставропольский край, Кисловодск	0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91198	8	81	\N	10968	60490	\N	43.921964672826398	Ставропольский край, город-курорт Кисловодск, ул.Коминтерна, 10	Россия, Ставропольский край, Кисловодск	0101000020E6100000DD43C2F7FE5A45404087F9F202F64540
91172	8	81	\N	10968	59572	\N	43.910204616476101	Ставропольский край, город Кисловодск, ул.Кирова, 70	Россия, Ставропольский край, Кисловодск	0101000020E6100000EA3E00A94D5C4540EDD3F19881F44540
91194	8	81	\N	10968	60477	\N	43.9045912714192	Ставропольский край, город-курорт Кисловодск, ул.К.Цеткин, 2	Россия, Ставропольский край, Кисловодск	0101000020E6100000E9D66B7A505C4540C3A04CA3C9F34540
91158	8	81	\N	10968	59575	\N	43.911759000000004	Ставропольский край, город Кисловодск, пер.Зеркальный, 21		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91192	8	81	\N	10968	60559	\N	43.908562784867598	Ставропольский край, город-курорт Кисловодск, пр.Дзержинского, 14	Россия, Ставропольский край, Кисловодск	0101000020E6100000E9D66B7A505C454086ADD9CA4BF44540
91199	8	81	\N	10968	60524	\N	43.917249540292801	Ставропольский край, город-курорт Кисловодск, ул.Герцена, 18		0101000020E61000008F1B7E37DD5A4540C520B07268F54540
91180	8	81	\N	10968	60355	\N	43.907536359405498	Ставропольский край, город-курорт Кисловодск, ул.Б.Хмельницкого, 7	Россия, Ставропольский край, Кисловодск	0101000020E61000001F82AAD1AB5D4540A9F8BF232AF44540
91168	8	81	\N	10968	59795	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул.А.Губина, 53		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91184	8	81	\N	10968	59988	\N	43.907536359405498	Ставропольский край, город-курорт Кисловодск, ул.Авиации, 23	Россия, Ставропольский край, Кисловодск	0101000020E61000002F698CD6515D4540A9F8BF232AF44540
91171	8	81	\N	10968	59571	\N	43.913524256533101	Ставропольский край, город Кисловодск, ул.8 Марта, 1	Россия, Ставропольский край, Кисловодск	0101000020E6100000BDFC4E93195D4540390EBC5AEEF44540
91176	8	81	\N	10968	60016	\N	43.905584174796203	Ставропольский край, город-курорт Кисловодск, ул.40 лет Октября, 25	Россия, Ставропольский край, Кисловодск	0101000020E610000091BA9D7DE55D4540F3E32F2DEAF34540
91189	8	81	\N	10968	59706	\N	43.913961133069598	Ставропольский край, город-курорт Кисловодск, ул.Ярошенко, 11	Россия, Ставропольский край, Кисловодск	0101000020E6100000F92F1004C85C4540E4688EACFCF44540
91188	8	81	\N	10968	60216	\N	43.911879972146302	Ставропольский край, город-курорт Кисловодск, ул.Мира, 9		0101000020E6100000BA2C26361F5D454030F0DC7BB8F44540
91154	8	81	\N	10968	59990	\N	43.911759000000004	Ставропольский край, город Кисловодск, ул.М.Расковой, 5		0101000020E6100000A7CF0EB8AE5C4540B66AD784B4F44540
91175	8	81	\N	10968	60193	\N	43.9070018693766	Ставропольский край, город-курорт Кисловодск, ул.Жуковского, 11	Россия, Ставропольский край, Кисловодск	0101000020E61000006BBB09BE695C45400BB43BA418F44540
91718	8	81	\N	57586	\N	\N	44.406156142560498	"Ставропольский край, Советский район, город Зеленокумск, х.Рог, МУК ""Зеленокумское гор. социально-культурное объединение"", д.1"	Россия, Ставропольский край, Советский район, Зеленокумск	0101000020E6100000304AD05FE8EF45407F8978EBFC334640
91734	8	81	\N	57586	60405	\N	44.443649881378697	Ставропольский край, Советский район, город Зеленокумск, хутор Тихомировка, ул.Степная, д.60	Россия, Ставропольский край, Советский район, село Тихомировка	0101000020E6100000992CEE3F32EF4540696FF085C9384640
91730	8	81	\N	57586	59665	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.Советская, 14		0101000020E61000006745D4449FEF4540F69672BED8334640
91727	8	81	\N	57586	59727	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.Первомайская, д.69		0101000020E61000006745D4449FEF4540F69672BED8334640
91723	8	81	\N	57586	59663	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.Мельничная, д.40		0101000020E61000006745D4449FEF4540F69672BED8334640
91722	8	81	\N	57586	59718	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.З.Космодемьянской, д.13		0101000020E61000006745D4449FEF4540F69672BED8334640
91608	8	81	\N	3652	59956	\N	44.136369531247297	Ставропольский край, Предгорный район, Пригородный сельсовет, поселок Железноводский, Юбилейная, 2		0101000020E610000040DB6AD619814540E813799274114640
91008	8	81	\N	3652	60207	\N	44.144452999999999	Ставропольский край, город-курорт Железноводск, Энгельса, 29		0101000020E61000002B2FF99FFC8145409067976F7D124640
91025	8	81	\N	3652	59551	\N	44.143704209493798	Ставропольский край, город-курорт Железноводск, Шоссейная, 137	Россия, Ставропольский край, Железноводск	0101000020E61000002E5915E126814540F62686E464124640
91022	8	81	\N	3652	59551	\N	44.135981507397098	Ставропольский край, город-курорт Железноводск, Шоссейная, 211в	Россия, Ставропольский край, Железноводск	0101000020E6100000724F57772C8045401E6CB1DB67114640
91020	8	81	\N	3652	59551	\N	44.138948484514501	Ставропольский край, город-курорт Железноводск, Шоссейная, 207Б	Россия, Ставропольский край, Железноводск	0101000020E61000006CAF05BD378045401CEC4D0CC9114640
91010	8	81	\N	3652	60203	\N	44.143787729918998	Ставропольский край, город-курорт Железноводск, Чапаева, 29	Россия, Ставропольский край, Железноводск	0101000020E61000004FEB36A8FD80454054C72AA567124640
91003	8	81	\N	3652	59556	\N	44.144452999999999	Железноводск, Суворова, 55		0101000020E61000002B2FF99FFC8145409067976F7D124640
91032	8	81	\N	3652	60587	\N	44.144452999999999	г.Железноводск,п. Капельница, Спортивная, 9		0101000020E61000002B2FF99FFC8145409067976F7D124640
91013	8	81	\N	3652	60507	\N	44.142783987821602	Ставропольский край, город-курорт Железноводск, Семашко, 33		0101000020E610000092088D60E38045402F3201BF46124640
91024	8	81	\N	3652	60599	\N	44.097233000000003	Ставропольский край, город-курорт Железноводск, п. Иноземцево, Свободы, 102А		0101000020E610000078D2C265158C4540C68B8521720C4640
91021	8	81	\N	3652	60307	\N	44.143683607635403	Ставропольский край, город-курорт Железноводск, Свободы, 14	Россия, Ставропольский край, Железноводск	0101000020E6100000E198654F02814540AF7AC03C64124640
91030	8	81	\N	3652	60592	\N	44.097233000000003	Ставропольский край, город-курорт Железноводск,п. Иноземцево, Свердлова, 15		0101000020E610000078D2C265158C4540C68B8521720C4640
91011	8	81	\N	3652	59972	\N	44.144699955425999	Ставропольский край, город-курорт Железноводск, Проскурина, 56	Россия, Ставропольский край, Железноводск	0101000020E61000006EC493DDCC80454098DD938785124640
91007	8	81	\N	3652	59972	\N	44.139195725831598	Ставропольский край, город-курорт Железноводск, Проскурина, 37	Россия, Ставропольский край, Железноводск	0101000020E6100000D53DB2B96A804540F4DDAD2CD1114640
91004	8	81	\N	3652	60278	\N	44.145132584606699	Ставропольский край, город-курорт Железноводск, Октябрьская, 53	Россия, Ставропольский край, Железноводск	0101000020E6100000F38DE89E758145400249D8B793124640
91015	8	81	\N	3652	60538	\N	44.136973896822397	Ставропольский край, город-курорт Железноводск, Лермонтова, 2а	Россия, Ставропольский край, Железноводск	0101000020E610000063D009A1838245407F33315D88114640
91018	8	81	\N	3652	60531	\N	44.144885368322903	Ставропольский край, город-курорт Железноводск, Ленина, 2а	Россия, Ставропольский край, Железноводск	0101000020E6100000573D601E328145402A5778978B124640
91006	8	81	\N	3652	60155	\N	44.140364796143999	Ставропольский край, город-курорт Железноводск, Космонавтов, 35	Россия, Ставропольский край, Железноводск	0101000020E6100000901150E1088045406440F67AF7114640
91031	8	81	\N	3652	60040	\N	44.144205518167396	Ставропольский край, город-курорт Железноводск, Колхозная, 68	Россия, Ставропольский край, Железноводск	0101000020E6100000DD60A8C30A81454088F19A5775124640
91028	8	81	\N	3652	60251	\N	44.137530207052201	Ставропольский край, город-курорт Железноводск, Клары Цеткин, 1	Россия, Ставропольский край, Железноводск	0101000020E61000003083312251804540041C42959A114640
91029	8	81	\N	3652	60536	\N	44.139361236892597	Ставропольский край, город-курорт Железноводск, Кирова, 6	Россия, Ставропольский край, Железноводск	0101000020E61000002EE23B31EB7F45403FABCC94D6114640
91019	8	81	\N	3652	60373	\N	44.144823564089101	Ставропольский край, город-курорт Железноводск, Глинки, 1а		0101000020E610000005DD5ED21881454084D6C39789124640
91023	8	81	\N	3652	59999	\N	44.144452999999999	Ставропольский край, город-курорт Железноводск, Шоссейная, 211б	Россия, Ставропольский край, Железноводск	0101000020E61000002B2FF99FFC8145409067976F7D124640
90982	8	81	\N	1708	60039	\N	44.042997	Ставропольский край, город Ессентуки, Ямпольского, 15		0101000020E610000009A87004A96E4540BE69FAEC80054640
90981	8	81	\N	1708	59700	\N	44.042997	Ставропольский край, город Ессентуки, ул. Энгельса, 34-А		0101000020E610000009A87004A96E4540BE69FAEC80054640
90992	8	81	\N	1708	59961	\N	44.042997	Ставропольский край, город Ессентуки, Шоссейная, 24		0101000020E610000009A87004A96E4540BE69FAEC80054640
90980	8	81	\N	1708	59765	\N	44.042997	Ставропольский край, город Ессентуки, Ул. Чкалова, 14		0101000020E610000009A87004A96E4540BE69FAEC80054640
37519	3	28	\N	1269	24286	\N	54.697718999999999	город Калининград, Б.Хмельницкого, 115		0101000020E6100000560E2DB29D8334401F662FDB4E594B40
90999	8	81	\N	1708	60485	\N	44.0492083976524	Ставропольский край, город-курорт Ессентуки, Пятигорская, 8	Россия, Ставропольский край, Ессентуки	0101000020E6100000AF7C96E7C16F4540CD599F724C064640
91001	8	81	\N	1708	60253	\N	44.038490121830698	Ставропольский край, город-курорт Ессентуки, Пушкина, 22	Россия, Ставропольский край, Ессентуки	0101000020E610000048F8DEDFA06D45408D9C853DED044640
90996	8	81	\N	1708	60464	\N	44.041012429701397	Ставропольский край, город-курорт Ессентуки, Привокзальная площадь, 1А	Россия, Ставропольский край, Ессентуки	0101000020E61000002429E961686D45402D5F97E13F054640
90993	8	81	\N	1708	59774	\N	44.042997	Ставропольский край, город Ессентуки, Правды, 11		0101000020E610000009A87004A96E4540BE69FAEC80054640
90976	8	81	\N	1708	59767	\N	44.042997	Ставропольский край, город Ессентуки, ул. Первомайская, 67-А		0101000020E610000009A87004A96E4540BE69FAEC80054640
90983	8	81	\N	1708	59912	\N	44.042997	Ставропольский край, город Ессентуки, Ул. Октябрьская, 333		0101000020E610000009A87004A96E4540BE69FAEC80054640
90989	8	81	\N	1708	59549	\N	44.042997	Ставропольский край, город Ессентуки, Ул. Октябрьская, 441		0101000020E610000009A87004A96E4540BE69FAEC80054640
90988	8	81	\N	1708	59549	\N	44.042997	Ставропольский край, город Ессентуки, Ул. Октябрьская, 419		0101000020E610000009A87004A96E4540BE69FAEC80054640
90986	8	81	\N	1708	59549	\N	44.0468320206367	Ставропольский край, город Ессентуки, Ул. Октябрьская, 444	Россия, Ставропольский край, Ессентуки	0101000020E6100000732EC5556571454001344A97FE054640
90984	8	81	\N	1708	59549	\N	44.042997	Ставропольский край, город Ессентуки, ул. Октябрьская, 333		0101000020E610000009A87004A96E4540BE69FAEC80054640
90974	8	81	\N	1708	59963	\N	44.042997	Ставропольский край, город Ессентуки, ул. Оборонная, 45		0101000020E610000009A87004A96E4540BE69FAEC80054640
90978	8	81	\N	1708	59955	\N	44.042997	Ставропольский край, город Ессентуки, Ул. Маркова, 65		0101000020E610000009A87004A96E4540BE69FAEC80054640
91000	8	81	\N	1708	60517	\N	44.050670159166998	Ставропольский край, город-курорт Ессентуки, Ленина, 30	Россия, Ставропольский край, Ессентуки	0101000020E61000004419AA622A6F4540B471C45A7C064640
90977	8	81	\N	1708	59548	\N	44.042997	Ставропольский край, город Ессентуки, ул. Кисловодская, 203		0101000020E610000009A87004A96E4540BE69FAEC80054640
90969	8	81	\N	1708	59548	\N	44.042997	Ставропольский край, город Ессентуки, Кисловодская, 11		0101000020E610000009A87004A96E4540BE69FAEC80054640
90990	8	81	\N	1708	60042	\N	44.048317781389201	Ставропольский край, город Ессентуки, Иглина, 4	Россия, Ставропольский край, Ессентуки	0101000020E6100000DAC9E028796F454071E7C2482F064640
90985	8	81	\N	1708	59958	\N	44.042997	Ставропольский край, город Ессентуки, Ул. Ермолова, 137		0101000020E610000009A87004A96E4540BE69FAEC80054640
90987	8	81	\N	1708	60038	\N	44.042997	Ставропольский край, город Ессентуки, Долина Роз, 7		0101000020E610000009A87004A96E4540BE69FAEC80054640
90973	8	81	\N	1708	59950	\N	44.042997	Ставропольский край, город Ессентуки, ул. Гагарина, 58		0101000020E610000009A87004A96E4540BE69FAEC80054640
90970	8	81	\N	1708	59950	\N	44.042997	Ставропольский край, город Ессентуки, Гагарина, 34		0101000020E610000009A87004A96E4540BE69FAEC80054640
90972	8	81	\N	1708	59949	\N	44.030926177854496	Ставропольский край, город-курорт Ессентуки, Вокзальная, 45-А		0101000020E61000005A9D9CA1B86D45404D4C1762F5034640
90971	8	81	\N	1708	59949	\N	44.042997	Ставропольский край, город Ессентуки, Вокзальная, 45-а		0101000020E610000009A87004A96E4540BE69FAEC80054640
90979	8	81	\N	1708	60046	\N	44.042997	Ставропольский край, город Ессентуки, Буачидзе, 1-5		0101000020E610000009A87004A96E4540BE69FAEC80054640
90975	8	81	\N	1708	60011	\N	44.042997	Ставропольский край, город Ессентуки, ул. Большая Боргустанская, 80-А		0101000020E610000009A87004A96E4540BE69FAEC80054640
90991	8	81	\N	1708	59959	\N	44.042997	Ставропольский край, город Ессентуки, Белоугольная, 6		0101000020E610000009A87004A96E4540BE69FAEC80054640
90997	8	81	\N	1708	60487	\N	44.040463669457701	Ставропольский край, город-курорт Ессентуки, Баталинская, 9	Россия, Ставропольский край, Ессентуки	0101000020E6100000CDC82077116E45402A55A2EC2D054640
90998	8	81	\N	1708	60518	\N	44.048402901962397	Ставропольский край, город-курорт Ессентуки, Анджиевского, 8	Россия, Ставропольский край, Ессентуки	0101000020E610000011E50B5A486E45409F03CB1132064640
90715	8	81	\N	16251	60008	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Шоссейная, 14		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90627	8	81	\N	16251	59720	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Чугурина, 18		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90890	8	81	\N	16251	59927	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Урицкого, 41		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90903	8	81	\N	16251	60050	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Тургенева/Гагарина, 28/242		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90901	8	81	\N	16251	59535	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Тургенева, 9		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90900	8	81	\N	16251	59535	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Тургенева, 16		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90909	8	81	\N	16251	59697	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Тронина, 10/1		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90896	8	81	\N	16251	60049	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Тимирязева, 34		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90892	8	81	\N	16251	59760	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Советская/Гагарина, 26/8		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90908	8	81	\N	16251	60031	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Салогубова, 5/1		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90603	8	81	\N	16251	59684	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Пушкина, 25		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90895	8	81	\N	16251	60149	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Луначарского, 41		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90898	8	81	\N	16251	59753	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Кирова, 124		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90905	8	81	\N	16251	59534	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Калинина, 152		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90897	8	81	\N	16251	59534	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Калинина/Маяковского, 51/81		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90899	8	81	\N	16251	60033	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Ермолова, 35		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90907	8	81	\N	16251	59929	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Дружбы, 31		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90701	8	81	\N	16251	59892	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Горийская/Пушкина, 5/25а		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90894	8	81	\N	16251	59536	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Гагарина, 76		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90893	8	81	\N	16251	59536	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Гагарина, 66		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90891	8	81	\N	16251	60032	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Володарского, 120		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90910	8	81	\N	16251	59754	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Быкова, 81		0101000020E610000037FC6EBA65BB45406EA6423C12134640
90906	8	81	\N	16251	59755	\N	44.148994000000002	Ставропольский край, г.Георгиевск, Батакская, 10		0101000020E610000037FC6EBA65BB45406EA6423C12134640
91816	8	81	\N	57610	60170	\N	45.136016634819804	Ставропольский край, Шпаковский район, Верхнерусский сельсовет, село Верхнерусское, улица Подгорная, 154	Россия	0101000020E6100000CB82893F8AF844409B594B0169914640
90848	8	81	\N	25611	\N	\N	44.793483999999999	город Буденновск, микрорайон 8, МОУ лицей № 8		0101000020E61000004FCC7A31941346401BF33AE290654640
90844	8	81	\N	25611	\N	\N	44.801059087438901	"город Буденновск, микрорайон ""Северный"", Гимназия № 9"	Россия, Ставропольский край, Буденновск городской округ	0101000020E610000051F69672BE1446404F95EF1989664640
90850	8	81	\N	25611	60024	\N	44.793483999999999	город Буденновск, проспект Космонавтов, 1		0101000020E61000004FCC7A31941346401BF33AE290654640
90871	8	81	\N	25611	59970	\N	44.796157999999998	Ставропольский край, Буденновский район, Орловский сельсовет, пер.Центральный, 1		0101000020E61000000D8AE6012C10464071395E81E8654640
90859	8	81	\N	25611	59976	\N	44.793483999999999	"город Буденновск, парк  им. ""Гагарина"", МУ культуры ""Центр досуга ""Радуга"""		0101000020E61000004FCC7A31941346401BF33AE290654640
90845	8	81	\N	25611	60030	\N	44.793483999999999	"город Буденновск, микрорайон 8, ГОУ СПО ""Региональный политехническ"		0101000020E61000004FCC7A31941346401BF33AE290654640
90849	8	81	\N	25611	60025	\N	44.793483999999999	"город Буденновск, микрорайон 7, ул. Менделеева, ОУ СК ""Полимер"""		0101000020E61000004FCC7A31941346401BF33AE290654640
90851	8	81	\N	25611	59761	\N	44.793483999999999	город Буденновск, микрорайон 3, 16		0101000020E61000004FCC7A31941346401BF33AE290654640
90860	8	81	\N	25611	59921	\N	44.793483999999999	город Буденновск, Пушкинская, 111		0101000020E61000004FCC7A31941346401BF33AE290654640
90853	8	81	\N	25611	59917	\N	44.793728465997802	город Буденновск, Прикумская, 56	Россия, Ставропольский край, Буденновск	0101000020E610000066BB421F2C134640B2F50CE198654640
90818	8	81	\N	25611	59525	\N	44.779132228516403	город Буденновск, Октябрьская, 52	Россия, Ставропольский край, Буденновск городской округ	0101000020E61000008121AB5B3D1546402FA2ED98BA634640
90854	8	81	\N	25611	59924	\N	44.793483999999999	"город Буденновск, Микрорайон 1, МУП Гостиничный комплекс ""Прикумье"""		0101000020E61000004FCC7A31941346401BF33AE290654640
90856	8	81	\N	25611	59691	\N	44.793300650355903	город Буденновск, Льва Толстого, 123	Россия, Ставропольский край, Буденновск	0101000020E61000008BFF3BA2421346402A711DE38A654640
90855	8	81	\N	25611	59691	\N	44.802403458138798	город Буденновск, Льва Толстого, 16	Россия, Ставропольский край, Буденновск городской округ	0101000020E6100000CB2C42B1151446402C9B3924B5664640
90793	8	81	7439	\N	59523	\N	44.7934811354692	город Буденновск, Лопатина, 152	Россия, Ставропольский край, Буденновск городской округ	0101000020E6100000BFF38B12F4114640AA7F10C990654640
90862	8	81	\N	25611	59783	\N	44.791280897231701	город Буденновск, Кумская, 47	Россия, Ставропольский край, Буденновск	0101000020E610000008C89750C11346401C7920B248654640
90861	8	81	\N	25611	59533	\N	44.793908949764102	город Буденновск, Кирова, 125	Россия, Ставропольский край, Буденновск	0101000020E6100000B6679604A8134640028063CF9E654640
90858	8	81	\N	25611	59748	\N	44.793483999999999	город Буденновск, Водопроводная, 2		0101000020E61000004FCC7A31941346401BF33AE290654640
90847	8	81	\N	57578	59560	\N	44.801838215209699	город Буденновск, микрорайон 7, ул. Менделеева, МОУ СОШ № 6		0101000020E61000001BBD1AA0341446405358A9A0A2664640
91231	8	81	\N	57589	59717	\N	44.776933999999997	Ставропольский край, Кочубеевский район, Балахоновский сельсовет, село Балахоновское, ул. Первомайская, д. 8/б		0101000020E61000005DA79196CAE344404293C49272634640
91843	8	81	1126	12540	60139	\N	44.881464999999999	Ставропольский край, Шпаковский район, Цимлянский сельсовет, поселок Цимлянский, улица Школьная, 2		0101000020E6100000DF8AC40435124540C9C859D8D3704640
91820	8	81	1126	11472	60496	\N	44.958717	Ставропольский край, Шпаковский район, Деминский сельсовет, хутор Холодногорский, улица Подгорная, 25/1		0101000020E61000006326512FF80C4540438F183DB77A4640
91839	8	81	1126	12354	60316	\N	44.871003936141797	Ставропольский край, Шпаковский район, Татарский сельсовет, хутор Темнореченский, улица Невинномысская, 31	Россия, Ставропольский край, Шпаковский район, село Темнореченский	0101000020E6100000093543AA28F64440B4571F0F7D6F4640
91841	8	81	1126	12482	59687	\N	44.858257000000002	Ставропольский край, Шпаковский район, Темнолесский сельсовет, станица Темнолесская, улица Центральная, 129		0101000020E61000001497E315880645401348895DDB6D4640
37518	3	28	\N	1269	24286	\N	54.6971539485669	город Калининград, Б.Хмельницкого, 27/31		0101000020E6100000B247A8195281344046239F573C594B40
91826	8	81	1126	11720	60411	\N	45.080681849256102	Ставропольский край, Шпаковский район, Надеждинский сельсовет, хутор Ташла, улица Центральная, 83А	Россия, Ставропольский край, Шпаковский район, село Ташла	0101000020E6100000C1E61C3C131045401DB0ABC9538A4640
91836	8	81	1126	12254	59789	\N	44.958794290951097	Ставропольский край, Шпаковский район, Татарский сельсовет, село Татарка, улица Ленина, 112	Россия	0101000020E610000031444E5FCFF34440EECC04C3B97A4640
91837	8	81	1126	12254	59989	\N	44.957604519269502	Ставропольский край, Шпаковский район, Татарский сельсовет, село Татарка, улица З. Космодемьянской, 24	Россия	0101000020E61000001C06F357C8F4444038BEF6CC927A4640
91834	8	81	1126	12117	59747	\N	45.047393	Ставропольский край, Шпаковский район, Сенгилеевский сельсовет, село Сенгилеевское, улица Пирогова, 34Б		0101000020E61000000FD4298F6ECE444098874CF910864640
91840	8	81	1126	57675	60522	\N	44.980321938493901	Ставропольский край, Шпаковский район, Татарский сельсовет, хутор Садовый, улица Островского, 3В		0101000020E6100000354580D3BBE0444050C6F8307B7D4640
91835	8	81	1126	12156	60429	\N	45.018105795306603	Ставропольский край, Шпаковский район, Сенгилеевский сельсовет, поселок Приозерный, улица Школьная, 1	Россия, Ставропольский край, Шпаковский район, село Приозерный	0101000020E6100000AF963B33C1D4444042EE224C51824640
91825	8	81	1126	11718	60498	\N	45.283470999999999	Ставропольский край, Шпаковский район, Казинский сельсовет, село Петропавловка, улица Октябрьская, 17Б		0101000020E6100000A3586E6935104540A52E19C748A44640
91831	8	81	1126	11999	59987	\N	45.218235	Ставропольский край, Шпаковский район, Пелагиадский сельсовет, село Пелагиада, улица Школьная, 24		0101000020E6100000155454FD4A014540D9EBDD1FEF9B4640
91833	8	81	1126	11999	59683	\N	45.2090104765294	Ставропольский край, Шпаковский район, Пелагиадский сельсовет, село Пелагиада, улица Садовая, 26	Россия, Ставропольский край, Шпаковский район, село Пелагиада	0101000020E61000009B1DA9BEF3014540BB44F5D6C09A4640
91832	8	81	1126	11999	59692	\N	45.2165332964437	Ставропольский край, Шпаковский район, Пелагиадский сельсовет, село Пелагиада, улица Партизанская, 17	Россия, Ставропольский край, Шпаковский район, село Пелагиада	0101000020E610000089EAAD81AD0045409CC0745AB79B4640
91844	8	81	1126	12605	60397	\N	44.943306	Ставропольский край, Шпаковский район, Цимлянский сельсовет, поселок Новый Бешпагир, улица Школьная, 1		0101000020E61000005CAB3DEC852E45406F0F4240BE784640
91830	8	81	1126	11903	59745	\N	45.134037232931902	Ставропольский край, Шпаковский район, станица Новомарьевская, улица Свердлова, 44	Россия, Ставропольский край, Шпаковский район, село Новомарьевская	0101000020E6100000CC457C2766E744401BBAD91F28914640
91817	8	81	1126	11321	59714	\N	45.167955269072003	Ставропольский край, Шпаковский район, Верхнерусский сельсовет, хутор Нижнерусский, улица Центральная, 20	Россия, Ставропольский край, Шпаковский район, село Нижнерусский	0101000020E6100000A05225CADEEE44408F19A88C7F954640
91828	8	81	1126	11781	59682	\N	45.043596999999998	Ставропольский край, Шпаковский район, Надеждинский сельсовет, село Надежда, улица Раздольная, 1А		0101000020E61000005871AAB5300D4540139A249694854640
91827	8	81	1126	11781	60585	\N	45.043596999999998	Ставропольский край, Шпаковский район, Надеждинский сельсовет, село Надежда, улица Рабочая, 13А		0101000020E61000005871AAB5300D4540139A249694854640
91829	8	81	1126	11781	59994	\N	45.043596999999998	Ставропольский край, Шпаковский район, Надеждинский сельсовет, село Надежда, улица Комсомольская, 13		0101000020E61000005871AAB5300D4540139A249694854640
91803	8	81	1126	10340	\N	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, Отделение №1		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91802	8	81	1126	10340	59721	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Шпака, 24		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91807	8	81	1126	10340	59742	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Розы Люксембург, 316		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91811	8	81	1126	10340	60143	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Пушкина, 50		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91796	8	81	1126	10340	60191	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Орджоникидзе, 246		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91808	8	81	1126	10340	59679	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Октябрьская, 116/2		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91806	8	81	1126	10340	59679	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Октябрьская, 318		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91800	8	81	1126	10340	59679	\N	45.139783000000001	Ставропольский край, Шпаковский район, г.Михайловск, Октябрьская 319/3		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91805	8	81	1126	10340	59979	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Новая, 10		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91799	8	81	1126	10340	60548	\N	45.139783000000001	Ставропольский край, Шпаковский район, г.Михайловск, ул. Никонова, 49/1		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91813	8	81	1126	10340	59738	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Ленина, 1		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91804	8	81	1126	10340	59738	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Ленина, 152А		0101000020E610000074CE4F711C044540B5C4CA68E4914640
43285	3	25	\N	19420	57623	\N	63.577820000000003	Республика Коми, г.Ухта, набережная Нефтяников, 18		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
91798	8	81	1126	10340	60137	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Кузьминовская, 2		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91801	8	81	1126	10340	59677	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Кирова, 13		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91814	8	81	1126	10340	59733	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Гагарина, 171/2		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91809	8	81	1126	10340	59733	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Гагарина, 79		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91810	8	81	1126	10340	60020	\N	45.139783000000001	Ставропольский край, Шпаковский район, город Михайловск, улица Вокзальная, 2		0101000020E610000074CE4F711C044540B5C4CA68E4914640
91842	8	81	1126	57681	60549	\N	44.817438233669698	Ставропольский край, Шпаковский район, Темнолесский сельсовет, хутор Липовчансикй, улица Лесная, 31	Россия, Ставропольский край, Шпаковский район, село Липовчанский	0101000020E61000008A03E8F7FD094540FB40F2CEA1684640
91815	8	81	1126	57659	\N	\N	45.189470141103797	Ставропольский край, Шпаковский район, город Михайловск, хутор Кожевников, дом Культуры	Россия, Ставропольский край, Шпаковский район, село Кожевников	0101000020E6100000D6E429ABE91445405CC98E8D40984640
91822	8	81	1126	57657	60461	\N	45.207886849435603	Ставропольский край, Шпаковский район, Дубовский сельсовет, хутор Калиновка, улица Кавказская, 57	Россия, Ставропольский край, Шпаковский район, село Калиновка	0101000020E6100000944C4EED0C1F4540BC218D0A9C9A4640
91824	8	81	1126	11658	59981	\N	45.297915000000003	Ставропольский край, Шпаковский район, Казинский сельсовет, село Казинка, улица Ленина, 119		0101000020E6100000AE64C746201A454072FE261422A64640
91821	8	81	1126	11476	60566	\N	45.221701000000003	Ставропольский край, Шпаковский район, Дубовский сельсовет, село Дубовка, улица Кирова, 1А		0101000020E610000050FBAD9D28154540C93EC8B2609C4640
91819	8	81	1126	11388	59681	\N	44.983637999999999	Ставропольский край, Шпаковский район, Деминский сельсовет, хутор Демино, переулок Школьный, 1		0101000020E6100000317DAF21380445402A8D98D9E77D4640
91818	8	81	1126	11342	60161	\N	45.114975999999999	Ставропольский край, Шпаковский район, Верхнерусский сельсовет, хутор Вязники, заезд Весенний, 1		0101000020E6100000368FC360FEFC444096E99788B78E4640
91838	8	81	1126	57685	60602	\N	44.921155913062798	Ставропольский край, Шпаковский район, Татарский сельсовет, хутор Верхний Егорлык, улица Шолохова, 28	Россия, Ставропольский край, Шпаковский район, село Верхнеегорлыкский	0101000020E610000036ACA92C0AED4440D1419770E8754640
91823	8	81	1126	11577	60399	\N	45.242432000000001	Ставропольский край, Шпаковский район, Дубовский сельсовет, поселок Верхнедубовский, улица Ленина, 10		0101000020E6100000ED9E3C2CD42445407FC00303089F4640
91590	8	81	100	46379	60360	\N	45.614804999999997	поселок Ясный, Школьная, 4		0101000020E610000086032159C0C44540693524EEB1CE4640
91791	8	81	100	57608	60169	\N	45.415151601736497	аул Шарахалсун, Краснознаменская, 94 а		0101000020E6100000185E49F25CD945403B6F63B323B54640
91147	8	81	100	57642	60376	\N	45.411135888042203	аул Чур, Советская, 20	Россия, Ставропольский край, Туркменский район, село Чур	0101000020E61000008F8B6A1151B64540A81ABD1AA0B44640
91792	8	81	100	10099	60572	\N	45.315353999999999	Ставропольский край, Туркменский район,поселок Троицкий, Западная, 11		0101000020E6100000E71A66683CE34540D65416855DA84640
91794	8	81	100	10202	60595	\N	45.293013999999999	Ставропольский край, Туркменский район, поселок Таврический, Победы, 58		0101000020E610000067BAD7497DCB454094A2957B81A54640
91789	8	81	100	57636	60362	\N	45.503382973466898	аул Сабан-Антуста, Мира, 57а	Россия, Ставропольский край, Туркменский район, село Сабан-Антуста	0101000020E6100000F168E388B5EA4540622EA9DA6EC04640
91450	8	81	100	48160	60497	\N	45.422150000000002	поселок Поперечный, Набережная, 19		0101000020E610000006BAF605F4A04540D200DE0209B64640
91462	8	81	100	26077	59820	\N	45.368847000000002	село Овощи, Красная, 75		0101000020E61000008B34F10EF0A84540261DE56036AF4640
91602	8	81	100	135	60435	\N	45.575767999999997	поселок Новокучерлинский, Школьная, 12		0101000020E61000002DE92807B3E34540AA0A0DC4B2C94640
91524	8	81	100	28935	59636	\N	45.442281999999999	село Малые Ягуры, Пионерская, 29		0101000020E610000001857AFA0882454003CE52B29CB84640
91016	8	81	100	4357	59716	\N	45.429949000000001	село Летняя Ставка, Советская, 17		0101000020E6100000E97DE36BCFB8454055F99E9108B74640
90658	8	81	100	4357	59716	\N	45.426984543238603	село Летняя Ставка, Советская, 114	Россия, Ставропольский край, Туркменский район, село Летняя Ставка	0101000020E61000000C76C3B645B94540F870C971A7B64640
91790	8	81	100	10041	60138	\N	45.368011000000003	село Кучерла, Стадионная, 29		0101000020E610000066DCD440F3D74540BDC804FC1AAF4640
91793	8	81	100	57615	60196	\N	45.317579373271798	аул Куликовы-Копани, Горького, 14	Россия, Ставропольский край, Туркменский район, село Куликовы Копани	0101000020E6100000A857CA32C4C74540BD72BD6DA6A84640
91701	8	81	100	5710	59942	\N	45.573270000000001	поселок Красный Маныч, Школьная, 1		0101000020E61000002D6002B7EEF2454093E34EE960C94640
91500	8	81	100	57670	60511	\N	45.335662999999997	поселок Красная Поляна, Степная, 9/1	Россия, Ставропольский край, Туркменский район, село Красная Поляна	0101000020E61000005F950B957FB1454016BD5301F7AA4640
91743	8	81	100	7758	60336	\N	45.464671501371399	село Кендже-Кулак, Ленина, 49	Россия, Ставропольский край, Туркменский район, село Кендже-Кулак	0101000020E6100000D0D03FC1C5E84540F7AE415F7ABB4640
91512	8	81	100	49222	59632	\N	45.379199	село Камбулат, Свободы, 55		0101000020E610000052B81E85EB87454084D6C39789B04640
91538	8	81	100	29550	59639	\N	45.504795000000001	село Казгулак, Ленина, 117		0101000020E610000038876BB5879D45409817601F9DC04640
91195	8	81	100	47683	60481	\N	45.478025000000002	поселок Березовский, Советская, 14		0101000020E6100000C539EAE8B8AA4540D0D556EC2FBD4640
43282	3	25	\N	19420	57511	\N	63.577820000000003	Республика Коми, г.Ухта, набережная Газовиков, 4/2		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
91777	8	81	874	9307	59975	\N	45.490802000000002	Ставропольский край, Труновский район, Труновский сельсовет, село Труновское, ленина, 4в		0101000020E6100000F6B2EDB435104540DC679599D2BE4640
91778	8	81	874	9307	60136	\N	45.481017897328897	Ставропольский край, Труновский район, Труновский сельсовет, село Труновское, Ленина, 130	Россия, Ставропольский край, Труновский район, село Труновское	0101000020E61000002BDEC83CF2114540C76471FF91BD4640
91775	8	81	874	9307	60554	\N	45.488628695498399	Ставропольский край, Труновский район, Труновский сельсовет, село Труновское, ул.Гагарина, 171	Россия, Ставропольский край, Труновский район, село Труновское	0101000020E61000008176871403104540487023658BBE4640
91788	8	81	874	9894	60395	\N	45.427084000000001	Ставропольский край, Труновский район, Кировский сельсовет, поселок Сухой Лог, Спортивная, 2/1		0101000020E6100000BDE3141DC91F45408B5242B0AAB64640
91785	8	81	874	9737	60473	\N	45.591607000000003	Ставропольский край, Труновский район, Кировский сельсовет, поселок Правоегорлыкский, Советская, 5		0101000020E610000083DDB06D512A4540D78A36C7B9CB4640
91717	8	81	874	6563	59946	\N	45.756129999999999	Ставропольский край, Труновский район, село Подлесное, Садовая, 18А		0101000020E610000042942F68210D454022C32ADEC8E04640
91786	8	81	874	9810	60415	\N	45.553677	Ставропольский край, Труновский район, Кировский сельсовет, поселок Новотерновский, Зои Космодемьянской, 19		0101000020E61000008E76DCF0BB23454011C64FE3DEC64640
91787	8	81	874	9887	60484	\N	45.491711000000002	Ставропольский край, Труновский район, Кировский сельсовет, поселок Нижняя Терновка, Луговая, 12		0101000020E6100000F486FBC8AD294540AF0AD462F0BE4640
91767	8	81	874	8960	60475	\N	45.524223156731203	Ставропольский край, Труновский район, Донской сельсовет, хутор Невдахин, Невдахина, 35	Россия, Ставропольский край, Труновский район, село Невдахин	0101000020E61000002A560DC2DCFC4440CF6740BD19C34640
91774	8	81	874	9229	60540	\N	45.357796	Ставропольский край, Труновский район, Труновский сельсовет, село Ключевское, ул.Ленина, 1		0101000020E6100000FB3E1C24440D4540DF516342CCAD4640
91784	8	81	874	9730	59678	\N	45.500921446687798	Ставропольский край, Труновский район, Кировский сельсовет, поселок имени Кирова, Комарова, 22	Россия, Ставропольский край, Труновский район, село Имени Кирова	0101000020E61000002BF697DD931F45409770E82D1EC04640
91773	8	81	874	8965	59675	\N	45.439872000000001	Ставропольский край, Труновский район, Донской сельсовет, село Донское, Трунова, 27		0101000020E6100000FDF84B8BFAFC44408B36C7B94DB84640
91768	8	81	874	8965	59671	\N	45.453402114130299	Ставропольский край, Труновский район, Донской сельсовет, село Донское, Садовая, 60а	Россия, Ставропольский край, Труновский район, село Донское	0101000020E61000002CD7DB662AFC444072F8A41309BA4640
91770	8	81	874	8965	60571	\N	45.439872000000001	Ставропольский край, Труновский район, Донской сельсовет, село Донское, ул.Пролетарская, 93 А/1		0101000020E6100000FDF84B8BFAFC44408B36C7B94DB84640
91771	8	81	874	8965	59673	\N	45.439872000000001	Ставропольский край, Труновский район, Донской сельсовет, село Донское, Первомайская, 2		0101000020E6100000FDF84B8BFAFC44408B36C7B94DB84640
91772	8	81	874	8965	59763	\N	45.439872000000001	Ставропольский край, Труновский район, Донской сельсовет, село Донское, Ленина, 225А		0101000020E6100000FDF84B8BFAFC44408B36C7B94DB84640
91769	8	81	874	8965	59672	\N	45.439872000000001	Ставропольский край, Труновский район, Донской сельсовет, село Донское, Комарова, 6а		0101000020E6100000FDF84B8BFAFC44408B36C7B94DB84640
91780	8	81	874	9487	60486	\N	45.634281999999999	Ставропольский край, Труновский район, Безопасненский сельсовет, село Безопасное, переулок Степной, 1		0101000020E610000075AC527AA6F7444082380F2730D14640
91779	8	81	874	9487	60338	\N	45.634281999999999	Ставропольский край, Труновский район, Безопасненский сельсовет, село Безопасное, Ставропольская, 1		0101000020E610000075AC527AA6F7444082380F2730D14640
91783	8	81	874	9487	60313	\N	45.634281999999999	Ставропольский край, Труновский район, Безопасненский сельсовет, село Безопасное, Партизанская, 56		0101000020E610000075AC527AA6F7444082380F2730D14640
91782	8	81	874	9487	59730	\N	45.634281999999999	Ставропольский край, Труновский район, Безопасненский сельсовет, село Безопасное, Ленина 116 а		0101000020E610000075AC527AA6F7444082380F2730D14640
91781	8	81	874	9487	59676	\N	45.636446788152298	Ставропольский край, Труновский район, Безопасненский сельсовет, село Безопасное, Ленина, 20	Россия, Ставропольский край, Труновский район, село Безопасное	0101000020E6100000EAB0C22D1FF944409351651877D14640
91752	8	81	980	8217	\N	\N	44.18788	Ставропольский край, Степновский район, Богдановский сельсовет, хутор Сунженский, здание Сунженского сельского Дома культуры	Россия, Ставропольский край, Степновский район, село Сунженский	0101000020E6100000D2C3D0EAE466464047C9AB730C184640
91244	8	81	980	8217	60440	\N	44.1908471283772	Ставропольский край, Кочубеевский район, Георгиевский сельсовет, станица Сунженская, Лысенко, 18	Россия, Ставропольский край, Степновский район, село Сунженский	0101000020E6100000E2CCAFE60067464015C5ABAC6D184640
91763	8	81	980	8770	60150	\N	44.271416000000002	Ставропольский край, Степновский район, Степновский сельсовет, село Степное, пл. Ленина, 19		0101000020E610000008C72C7B124A46403ACE6DC2BD224640
91765	8	81	980	8770	60576	\N	44.271416000000002	Ставропольский край, Степновский район, Степновский сельсовет, село Степное, ул. Садовая, 93		0101000020E610000008C72C7B124A46403ACE6DC2BD224640
91764	8	81	980	8770	59728	\N	44.271416000000002	Ставропольский край, Степновский район, Степновский сельсовет, село Степное, ул. Додонова, 40		0101000020E610000008C72C7B124A46403ACE6DC2BD224640
91762	8	81	980	8698	60135	\N	44.214309999999998	Ставропольский край, Степновский район, село Соломенское, пл. Административная, 14		0101000020E610000094F59B89E92C4640569A94826E1B4640
91760	8	81	980	8600	59977	\N	44.324889094801598	Ставропольский край, Степновский район, Ольгинский сельсовет, село Ольгино, ул. Шоссейная, 34	Россия, Ставропольский край, Степновский район, село Ольгино	0101000020E610000048FE60E0B933464042EA76F695294640
91757	8	81	980	8499	60597	\N	44.099440000000001	Ставропольский край, Степновский район, Верхнестепновский сельсовет, село Озёрное, ул. Мира, 24		0101000020E610000008AA46AF062A464006F52D73BA0C4640
91755	8	81	980	8373	60459	\N	44.381793999999999	Ставропольский край, Степновский район, Варениковский сельсовет, хутор Новоникольский, ул. Центральная, 64		0101000020E61000000DE2033BFE2D46408EE733A0DE304640
91759	8	81	980	8595	60403	\N	44.354697000000002	Ставропольский край, Степновский район, Иргаклинский сельсовет, посёлок Новоиргаклинский, ул. Мира, 9		0101000020E61000007A7077D66E594640A27E17B6662D4640
91754	8	81	980	8367	60564	\N	44.430895	Ставропольский край, Степновский район, Варениковский сельсовет, село Никольское, ул. Шоссейная, 40		0101000020E610000001309E414323464045813E9127374640
91758	8	81	980	8504	60133	\N	44.353524	Ставропольский край, Степновский район, Иргаклинский сельсовет, село Иргаклы, ул. Молодежная, 2-Б		0101000020E61000001763601DC75F4640F12C4146402D4640
91761	8	81	980	8661	60331	\N	44.289982999999999	Ставропольский край, Степновский район, Ольгинский сельсовет, село Зелёная Роща, пер. Школьный, 3		0101000020E61000000CCC0A45BA374640AFB2B6291E254640
91766	8	81	980	8873	\N	\N	44.241621000000002	Ставропольский край, Степновский район, Степновский сельсовет, хутор Восточный, здание Учреждение культуры	Россия, Ставропольский край, Степновский район, село Восточный	0101000020E6100000A0C1A6CEA35C46406F83DA6FED1E4640
91756	8	81	980	8432	59670	\N	44.188777999999999	Ставропольский край, Степновский район, Верхнестепновский сельсовет, посёлок Верхнестепной, пл. Ленина, 18		0101000020E61000001BBCAFCA85364640261AA4E029184640
91753	8	81	980	8306	60312	\N	44.460484999999998	Ставропольский край, Степновский район, Варениковский сельсовет, село Варениковское, пер. Школьный, 7		0101000020E61000004EF1B8A8162B464037A6272CF13A4640
91751	8	81	980	8210	60311	\N	44.142985000000003	Ставропольский край, Степновский район, Богдановский сельсовет, село Богдановка, Мира, 21		0101000020E6100000B2D47ABFD15C4640C7681D554D124640
91747	8	81	857	7756	59669	\N	44.268988999999998	Ставропольский край, Советский район, Солдато-Александровский сельсовет, село Солдато-Александровское, ул.Пролетарская, д.87		0101000020E610000009FCE1E7BFDF4540EBFD463B6E224640
91746	8	81	857	7756	59724	\N	44.268988999999998	Ставропольский край, Советский район, Солдато-Александровский сельсовет, село Солдато-Александровское, пл.Ленина, д.1		0101000020E610000009FCE1E7BFDF4540EBFD463B6E224640
91745	8	81	857	7756	59674	\N	44.266895193181099	Ставропольский край, Советский район, Солдато-Александровский сельсовет, село Солдато-Александровское, ул.Культурная, д.83	Россия, Ставропольский край, Советский район, село Солдато-Александровское	0101000020E6100000427BF5F1D0DF4540A33B889D29224640
91742	8	81	857	7756	60308	\N	44.268988999999998	Ставропольский край, Советский район, Солдато-Александровский сельсовет, село Солдато-Александровское, ул.25 партсъезда, д.16		0101000020E610000009FCE1E7BFDF4540EBFD463B6E224640
91744	8	81	857	7756	60148	\N	44.268988999999998	Ставропольский край, Советский район, Солдато-Александровский сельсовет, село Солдато-Александровское, ул.17 партсъезда, д. 119		0101000020E610000009FCE1E7BFDF4540EBFD463B6E224640
91739	8	81	857	7630	60334	\N	44.498713000000002	Ставропольский край, Советский район, Нинский сельсовет, поселок Селивановка, ул.Шоссейная, д.1		0101000020E6100000DEAF027CB7034640878BDCD3D53F4640
91741	8	81	857	7683	59960	\N	44.378849000000002	Ставропольский край, Советский район, Правокумский сельсовет, село Правокумское, ул.Ленина, д.45		0101000020E61000000F80B8AB570B4640A88FC01F7E304640
91740	8	81	857	7637	59723	\N	44.324132391228197	Ставропольский край, Советский район, село Отказное, ул.Мостовая, д.5	Россия, Ставропольский край, Советский район, село Отказное	0101000020E61000002769FE98D6EC454025CB49287D294640
91738	8	81	857	7508	60619	\N	44.486013999999997	Ставропольский край, Советский район, Нинский сельсовет, село Нины, ул. Октябрьская, 9		0101000020E6100000371B2B31CFF84540F6B2EDB4353E4640
91737	8	81	857	7508	60132	\N	44.486013999999997	Ставропольский край, Советский район, Нинский сельсовет, село Нины, ул.Кирова, д.29		0101000020E6100000371B2B31CFF84540F6B2EDB4353E4640
91749	8	81	857	8045	60340	\N	44.218096000000003	Ставропольский край, Советский район, поселок Михайловка, Шоссейная, 59		0101000020E61000004C361E6CB1DB4540B8B1D991EA1B4640
91715	8	81	857	57668	60521	\N	44.234216378698001	Ставропольский край, Советский район, Восточный сельсовет, хутор Кононов, ул.Школьная, 28	Россия, Ставропольский край, Советский район, село Кононов	0101000020E6100000F0DE516342184640981936CAFA1D4640
91748	8	81	857	57651	60442	\N	44.248975999999999	Ставропольский край, Советский район, хутор Колесников, пер.1-й Ленинский, д.15	Россия, Ставропольский край, Советский район, село Колесников	0101000020E6100000C79DD2C1FAE5454094BE1072DE1F4640
91735	8	81	857	57646	60404	\N	44.370524157279398	Ставропольский край, Советский район, город Зеленокумск, хутор Ковганский, ул.Фестивальная, д.37	Россия, Ставропольский край, Советский район, село Ковганский	0101000020E61000000B42791F47E345400A3197546D2F4640
37491	3	28	\N	1269	24251	\N	54.727370000000001	город Калининград, Ал. Невского, 32		0101000020E610000003EFE4D363873440B70BCD751A5D4B40
91721	8	81	857	6603	60129	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, пл.Ленина, д.14		0101000020E61000006745D4449FEF4540F69672BED8334640
91724	8	81	857	6603	60125	\N	44.399633794097802	Ставропольский край, Советский район, город Зеленокумск, пл.Ленина, д.52	Россия, Ставропольский край, Советский район, Зеленокумск	0101000020E6100000D8D30E7F4DF24540512FF83427334640
91720	8	81	857	6603	60128	\N	44.405051999999998	"Ставропольский край, Советский район, город Зеленокумск, пл.1 Мая, 4""а"""		0101000020E61000006745D4449FEF4540F69672BED8334640
91728	8	81	857	6603	59957	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.Семенова, д.12		0101000020E61000006745D4449FEF4540F69672BED8334640
91719	8	81	857	6603	59701	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.Пугачева, 209		0101000020E61000006745D4449FEF4540F69672BED8334640
91725	8	81	857	6603	59954	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул. Ленина, д.237		0101000020E61000006745D4449FEF4540F69672BED8334640
91732	8	81	857	6603	59666	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, пер.Кумской, д.4		0101000020E61000006745D4449FEF4540F69672BED8334640
91731	8	81	857	6603	75119	\N	44.407017530074903	Ставропольский край, Советский район, город Зеленокумск, ул.Крайнева, д.72	Россия, Ставропольский край, Советский район, Зеленокумск	0101000020E6100000016C4084B8F045401171732A19344640
91726	8	81	857	6603	9822	\N	44.405294742274499	Ставропольский край, Советский район, город Зеленокумск, ул.Ессентукская, 180	Россия, Ставропольский край, Советский район, Зеленокумск	0101000020E61000003CDD79E239F14540BD1DE1B4E0334640
91736	8	81	857	6603	59667	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.50 лет Октября, д.27		0101000020E61000006745D4449FEF4540F69672BED8334640
91733	8	81	857	6603	59667	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.50 лет Октября, 63		0101000020E61000006745D4449FEF4540F69672BED8334640
91729	8	81	857	6603	59667	\N	44.405051999999998	Ставропольский край, Советский район, город Зеленокумск, ул.50 лет Октября, д.35		0101000020E61000006745D4449FEF4540F69672BED8334640
91716	8	81	857	6499	60130	\N	44.269047	Ставропольский край, Советский район, село Горькая Балка, ул.Октябрьская, 16		0101000020E6100000A2B3CC2214FD4540200BD12170224640
91714	8	81	857	6406	60134	\N	44.315779999999997	Ставропольский край, Советский район, Восточный сельсовет, хутор Восточный, ул.Октябрьская, 18		0101000020E6100000BEBED6A5461846408D5DA27A6B284640
91750	8	81	857	8122	60323	\N	44.225344999999997	Ставропольский край, Советский район, Солдато-Александровский сельсовет, хутор Андреевский, ул. Школьная, 1		0101000020E610000036E9B6442ED0454097A8DE1AD81C4640
91696	8	81	437	4599	59872	\N	44.021177628211099	Ставропольский край, город-курорт Пятигорск, рабочий поселок Свободы, Энгельса, 61	Россия, Ставропольский край, Пятигорск городской округ, поселок городского типа Свободы	0101000020E6100000BFD6A546E885454085B2F0F5B5024640
91699	8	81	437	4599	60096	\N	44.022478237753297	Ставропольский край, город-курорт Пятигорск, рабочий поселок Свободы, Пащенко, 112	Россия, Ставропольский край, Пятигорск городской округ, поселок городского типа Свободы	0101000020E61000004B02D4D4B28545409370218FE0024640
91697	8	81	437	57598	59868	\N	44.025017440245797	Ставропольский край, город Пятигорск, рабочий поселок Свободы, Энгельса, 104	Россия, Ставропольский край, Пятигорск городской округ, поселок городского типа Свободы	0101000020E6100000E9BAF083F3854540096CCEC133034640
91640	8	81	437	2411	59907	\N	44.076357999999999	Ставропольский край, город-курорт Пятигорск, поселок Нижнеподкумский, Зубалова, 35а		0101000020E6100000850838842A9B4540DC645419C6094640
91638	8	81	437	57614	60194	\N	44.042200264061101	Ставропольский край, город-курорт Пятигорск, станица Константиновская, Октябрьская, 108	Россия, Ставропольский край, Пятигорск городской округ, село Констатиновская	0101000020E610000017B6662B2F93454013F241CF66054640
91671	8	81	437	3540	\N	\N	44.022044000000001	"Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, 8-я линия, Станкоремонтный завод ""Пятигорский"	Россия, Ставропольский край, Пятигорск городской округ, поселок Горячеводский	0101000020E61000008E226B0DA58C454059897956D2024640
91662	8	81	437	3540	59657	\N	44.022044000000001	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, Советская, 87		0101000020E61000008E226B0DA58C454059897956D2024640
91664	8	81	437	3540	59836	\N	44.022044000000001	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, Ленина, 55		0101000020E61000008E226B0DA58C454059897956D2024640
91661	8	81	437	3540	59836	\N	44.022044000000001	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, Ленина, 25		0101000020E61000008E226B0DA58C454059897956D2024640
91670	8	81	437	3540	59930	\N	44.022044000000001	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, Кабардинская, 1		0101000020E61000008E226B0DA58C454059897956D2024640
91666	8	81	437	3540	59845	\N	44.022353645635597	Ставропольский край, город Пятигорск, рабочий поселок Горячеводский, Георгиевская, 174/1		0101000020E61000003E92921E868C4540A777F17EDC024640
91669	8	81	437	3540	59693	\N	44.022044000000001	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, 8-я линия, 54		0101000020E61000008E226B0DA58C454059897956D2024640
91612	8	81	18	768	60458	\N	44.003560999999998	Ставропольский край, Предгорный район, Пятигорский сельсовет, поселок Нижнеэтокский, Шоссейная, б/н		0101000020E610000090F46915FDAF45404145D5AF74004640
91660	8	81	437	57595	60127	\N	44.029103618354398	Ставропольский край, город-курорт Пятигорск, рабочий поселок Горячеводский, Советской Армии, 32	Россия, Ставропольский край, Пятигорск городской округ, поселок городского типа Горячеводский	0101000020E6100000F33977BB5E8C454065170CAEB9034640
91668	8	81	437	57595	59931	\N	44.027369661067901	Ставропольский край, город Пятигорск, п. Горячеводский, Больничная, 1	Россия, Ставропольский край, Пятигорск городской округ, поселок городского типа Горячеводский	0101000020E6100000CE33F6251B8D45401D7233DC80034640
91633	8	81	18	1982	\N	\N	44.025064	Ставропольский край, Предгорный район, Яснополянский сельсовет, поселок Ясная Поляна, Спортивная, 9	Россия, Ставропольский край, Предгорный район, село Ясная Поляна	0101000020E6100000C5025FD1AD5F45404A27124C35034640
91634	8	81	18	1982	59922	\N	44.025064	Ставропольский край, Предгорный район, Яснополянский сельсовет, поселок Ясная Поляна, Спортивная, 27		0101000020E6100000C5025FD1AD5F45404A27124C35034640
91629	8	81	18	1749	60004	\N	43.957053150072703	"Ставропольский край, Предгорный район, Юцкий сельсовет, село Юца, переулок Почтовый, здание участка ГУП ""Водоканал"""	Россия, Ставропольский край, Предгорный район, село Юца	0101000020E61000008F368E588B814540F4C473B680FA4540
91630	8	81	18	1749	60118	\N	43.953890999999999	Ставропольский край, Предгорный район, Юцкий сельсовет, село Юца, Луценко, 115		0101000020E61000009AEC9FA7017F45407079AC1919FA4540
91631	8	81	18	1749	59713	\N	43.957472508994798	Ставропольский край, Предгорный район, Юцкий сельсовет, село Юца, Канищева, 2	Россия, Ставропольский край, Предгорный район, село Юца	0101000020E6100000389ECF807A814540C9E6AA798EFA4540
91627	8	81	18	1589	59650	\N	43.913393980657901	Ставропольский край, Предгорный район, Этокский сельсовет, село Этока, 50 лет Октября, 458	Россия, Ставропольский край, Предгорный район, село Этока	0101000020E610000034BBEEAD488645406A2E3718EAF44540
91626	8	81	18	1589	59650	\N	43.917940999999999	Ставропольский край, Предгорный район, Этокский сельсовет, село Этока, 50 лет Октября, 144		0101000020E6100000D120054F218745402A5437177FF54540
91622	8	81	18	1357	60306	\N	44.115512000000003	Ставропольский край, Предгорный район, Тельмановский сельсовет, поселок Урожайный, переулок Садовый, 1		0101000020E61000002CEFAA07CC614540D525E318C90E4640
91625	8	81	18	1517	60281	\N	43.930380999999997	Ставропольский край, Предгорный район, Этокский сельсовет, хутор Тамбукан, Кирова, 16В		0101000020E61000008597E0D407924540EEE87FB916F74540
91620	8	81	18	894	60116	\N	44.1898854438667	Ставропольский край, Предгорный район, Суворовский сельсовет, станица Суворовская, Шоссейная, здание ООШ №24	Россия, Ставропольский край, Предгорный район, село Суворовская	0101000020E6100000C7D8092FC15545401F80D4264E184640
91616	8	81	18	894	59664	\N	44.184454000000002	Ставропольский край, Предгорный район, Суворовский сельсовет, станица Суворовская, Советская, здание ООШ №20		0101000020E6100000677DCA3159544540E6CE4C309C174640
91614	8	81	18	894	59664	\N	44.184450598175701	Ставропольский край, Предгорный район, Суворовский сельсовет, станица Суворовская, Советская, 30	Россия, Ставропольский край, Предгорный район, село Суворовская	0101000020E61000008D0DDDEC0F564540755B22179C174640
91618	8	81	18	894	60117	\N	44.184454000000002	Ставропольский край, Предгорный район, Суворовский сельсовет, станица Суворовская, Нагорная, 255		0101000020E6100000677DCA3159544540E6CE4C309C174640
91617	8	81	18	894	59904	\N	44.184454000000002	Ставропольский край, Предгорный район, Суворовский сельсовет, станица Суворовская, Карла Маркса, здание СОШ №8		0101000020E6100000677DCA3159544540E6CE4C309C174640
91615	8	81	18	894	59649	\N	44.194825774830598	Ставропольский край, Предгорный район, Суворовский сельсовет, станица Суворовская, Заводская, 42Б		0101000020E61000004609FA0B3D5445408B34F10EF0184640
91619	8	81	18	1177	60328	\N	44.156736574356998	Ставропольский край, Предгорный район, Суворовский сельсовет, село Свобода, Гагарина, здание ООШ №23	Россия, Ставропольский край, Предгорный район, село Свобода	0101000020E610000081936DE00E6245405D8940F50F144640
91621	8	81	18	1296	60557	\N	44.075794000000002	Ставропольский край, Предгорный район, Тельмановский сельсовет, п.Санамер, ул. Тельмана, 60		0101000020E6100000E10B93A9826D4540D49D279EB3094640
91632	8	81	18	1938	60120	\N	44.016027999999999	Ставропольский край, Предгорный район, Юцкий сельсовет, село Садовое, Мира, 127		0101000020E6100000B4AB90F2937C4540FFE89B340D024640
91610	8	81	18	652	60115	\N	43.977859000000002	Ставропольский край, Предгорный район, Пятигорский сельсовет, поселок Пятигорский, Красноармейская, 20		0101000020E6100000508C2C9963A14540B58CD47B2AFD4540
91692	8	81	18	57655	60452	\N	44.002714874789604	Ставропольский край, город-курорт Пятигорск, село Привольное, Школьная, 6	Россия, Ставропольский край, Предгорный район, село Привольное	0101000020E6100000029B73F04C784540B51A12F758004640
91607	8	81	18	443	59858	\N	43.968608000000003	Ставропольский край, Предгорный район, Подкумский сельсовет, поселок Подкумок, Крупской, 3		0101000020E6100000E9263108AC6245406E52D158FBFB4540
91624	8	81	18	1474	60460	\N	44.053019999999997	Ставропольский край, Предгорный район, Тельмановский сельсовет, хутор Новоборгустанский, Кубанская, 37		0101000020E61000000264E8D8415345405704FF5BC9064640
91606	8	81	18	396	59694	\N	44.138673234165701	Ставропольский край, Предгорный район, Новоблагодарненский сельсовет, село Новоблагодарное, Ленина, 54	Россия, Ставропольский край, Предгорный район, село Новоблагодарное	0101000020E61000009337C0CC777045404AEB6F09C0114640
91605	8	81	18	323	\N	\N	43.929634999999998	Ставропольский край, Предгорный район, Нежинский сельсовет, поселок Нежинский, Дом культуры		0101000020E6100000F9156BB8C8574540C51B9947FEF64540
91603	8	81	18	179	59647	\N	43.942812000000004	Ставропольский край, Предгорный район, поселок Мирный, Шоссейная, 25А		0101000020E610000075E61E12BE53454060234910AEF84540
91604	8	81	18	267	\N	\N	43.866874000000003	Ставропольский край, Предгорный район, Нежинский сельсовет, поселок Левоберезовский, здание ФАП	Россия, Ставропольский край, Предгорный район, село Левоберезовский	0101000020E610000015562AA8A854454059E02BBAF5EE4540
91623	8	81	18	1404	60434	\N	44.095407000000002	Ставропольский край, Предгорный район, Тельмановский сельсовет, поселок имени Чкалова, Якорная, 11		0101000020E6100000F870C971A75A45409D67EC4B360C4640
91599	8	81	18	32237	60122	\N	44.025790000000001	Ставропольский край, Предгорный район, Ессентукский сельсовет, станица Ессентукская, Юцкий переулок, 1		0101000020E610000063B66455846F45402C4833164D034640
91598	8	81	18	32237	60112	\N	44.025790000000001	Ставропольский край, Предгорный район, Ессентукский сельсовет, станица Ессентукская, Этокская, 4		0101000020E610000063B66455846F45402C4833164D034640
91600	8	81	18	32237	59908	\N	44.025790000000001	Ставропольский край, Предгорный район, Ессентукский сельсовет, станица Ессентукская, Садовое Кольцо, 5		0101000020E610000063B66455846F45402C4833164D034640
91596	8	81	18	32237	59648	\N	44.025790000000001	Ставропольский край, Предгорный район, Ессентукский сельсовет, станица Ессентукская, Гагарина, 72		0101000020E610000063B66455846F45402C4833164D034640
91595	8	81	18	32237	59648	\N	44.025790000000001	Ставропольский край, Предгорный район, Ессентукский сельсовет, станица Ессентукская, Гагарина, 52	Россия, Ставропольский край, Предгорный район, село Ессентукская	0101000020E610000063B66455846F45402C4833164D034640
91597	8	81	18	32237	59835	\N	44.025790000000001	Ставропольский край, Предгорный район, Ессентукский сельсовет, станица Ессентукская, Гагарина, 101		0101000020E610000063B66455846F45402C4833164D034640
91628	8	81	18	1707	59651	\N	43.986742280160101	Ставропольский край, Предгорный район, Этокский сельсовет, поселок Джуца, Ореховая, 12/1	Россия, Ставропольский край, Предгорный район, село Джуца	0101000020E61000008BDF14562A84454079CBD58F4DFE4540
91601	8	81	18	22	\N	\N	43.955844585310103	Ставропольский край, Предгорный район, Ессентукский сельсовет, поселок Горный, здание Дома культуры	Россия, Ставропольский край, Предгорный район, село Горный	0101000020E6100000EB1B98DC286E4540C685032159FA4540
91594	8	81	18	13717	59685	\N	44.079084000000002	Ставропольский край, Предгорный район, Винсадский сельсовет, село Винсады, Ленина, 41		0101000020E6100000E4D70FB1C17A454085D1AC6C1F0A4640
91593	8	81	18	13717	59685	\N	44.079084000000002	Ставропольский край, Предгорный район, Винсадский сельсовет, село Винсады, Ленина, 27		0101000020E6100000E4D70FB1C17A454085D1AC6C1F0A4640
91592	8	81	18	13717	59685	\N	44.079084000000002	Ставропольский край, Предгорный район, Винсадский сельсовет, село Винсады, ул.Ленина, 30		0101000020E6100000E4D70FB1C17A454085D1AC6C1F0A4640
91611	8	81	18	696	60466	\N	43.982768999999998	Ставропольский край, Предгорный район, Пятигорский сельсовет, поселок Верхнетамбуканский, Зеленая, 2		0101000020E610000060200890A1A94540E542E55FCBFD4540
91609	8	81	18	580	59833	\N	44.185241442051101	Ставропольский край, Предгорный район, Пригородный сельсовет, хутор Быкогорка, Кошевого, 31	Россия, Ставропольский край, Предгорный район, село Быкогорка	0101000020E61000004F029B73F07845406D7022FAB5174640
91591	8	81	18	31982	59834	\N	44.059910214439597	Ставропольский край, Предгорный район, станица Боргустанская, Кооперативная, 18А	Россия, Ставропольский край, Предгорный район, село Боргустанская	0101000020E61000000727A25F5B454540085A8121AB074640
91589	8	81	18	31982	59897	\N	44.051859999999998	Ставропольский край, Предгорный район, станица Боргустанская, Буденного, 12А		0101000020E6100000E31A9FC9FE4345403BFC3559A3064640
91588	8	81	18	13675	60598	\N	44.112431000000001	Ставропольский край, Предгорный район, станица Бекешевская, ул.Московская, 9		0101000020E61000001E6CB1DB673745403E079623640E4640
91577	8	81	1295	31434	60109	\N	45.409154000000001	Ставропольский край, Петровский район, село Шведино, улица Ленина, дом 39		0101000020E61000003080F0A144714540888384285FB44640
91574	8	81	1295	31310	59645	\N	45.526159999999997	Ставропольский край, Петровский район, село Шангала, улица 60 лет Октября, дом 31А		0101000020E610000024B55032395545404F3BFC3559C34640
91581	8	81	1295	31663	60114	\N	45.156413000000001	Ставропольский край, Петровский район, село Сухая Буйвола, улица Красная, дом 9		0101000020E6100000C5AC1743397F4540AAD5575705944640
91567	8	81	1295	57622	60282	\N	45.267661385514401	Ставропольский край, Петровский район, хутор Соленое Озеро, улица Курортная, дом 7А	Россия, Ставропольский край, Петровский район, село Соленое Озеро	0101000020E6100000EACBD24ECD6B454013B534B742A24640
91559	8	81	1295	13588	59887	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, площадь Выставочная, дом 25		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91549	8	81	1295	13588	60145	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, площадь 50-лет Октября, дом 10		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91547	8	81	1295	13588	59831	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Транспортная, дом 25		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91558	8	81	1295	13588	59878	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Садовая, дом 28 А		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91565	8	81	1295	13588	60146	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Матросова, 195А		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91564	8	81	1295	13588	60146	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Матросова, дом 2		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91561	8	81	1295	13588	60104	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Малыгина, дом 31		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91562	8	81	1295	13588	60103	\N	45.311859804562303	Ставропольский край, Петровский район, город Светлоград, улица Комсомольская, дом 14	Россия, Ставропольский край, Петровский район, Светлоград	0101000020E610000026A60BB1FA6D45401D774A07EBA74640
91557	8	81	1295	13588	59891	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Коминтерна, дом 13		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91555	8	81	1295	13588	59884	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Кисличанская, дом 241		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91554	8	81	1295	13588	59884	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Кисличанская, 90		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91550	8	81	1295	13588	60565	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Горная, дом 11-Н		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91560	8	81	1295	13588	59731	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, площадь Выставочная, дом б/н		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91563	8	81	1295	13588	59641	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Высотная, дом 9		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91552	8	81	1295	13588	59838	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Бассейная, дом 143		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91551	8	81	1295	13588	59838	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица Бассейная, дом 93		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91556	8	81	1295	13588	60580	\N	45.323726000000001	Ставропольский край, Петровский район, город Светлоград, улица 60 лет Октября, 4		0101000020E61000008061F9F36D6F4540B56E83DA6FA94640
91578	8	81	1295	31525	60108	\N	45.207775812725103	Ставропольский край, Петровский район, село Рогатая Балка, улица Первомайская, дом 75	Россия, Ставропольский край, Петровский район, село Рогатая Балка	0101000020E610000019E42EC21485454065726A67989A4640
91579	8	81	1295	31527	60503	\N	45.1885354386934	Ставропольский край, Петровский район, поселок Пшеничный, улица Пролетарская, дом б/н	Россия, Ставропольский край, Петровский район, село Пшеничный	0101000020E6100000E8F86871C6904540609335EA21984640
91587	8	81	1295	31934	60113	\N	45.122594999999997	Ставропольский край, Петровский район, село Просянка, улица Мира, дом 58		0101000020E610000018B2BAD5736C454099D36531B18F4640
91575	8	81	1295	31321	59899	\N	45.47889	Ставропольский край, Петровский район, поселок Прикалаусский, улица Почтовая, дом 1		0101000020E61000008656276728684540D3307C444CBD4640
91585	8	81	1295	31797	59646	\N	45.034419	Ставропольский край, Петровский район, село Ореховка, улица Толстого, дом 1А		0101000020E6100000CE8B135FED78454036AE7FD767844640
91566	8	81	1295	30928	60413	\N	45.442951999999998	Ставропольский край, Петровский район, хутор Носачев, улица Урожайная, дом 75		0101000020E6100000A4E029E44A5F454051D9B0A6B2B84640
91576	8	81	1295	31366	59898	\N	45.468275494869602	Ставропольский край, Петровский район, село Николина Балка, улица Шоссейная, дом 28	Россия, Ставропольский край, Петровский район, село Николина Балка	0101000020E61000007BFA08FCE16F45406744696FF0BB4640
91571	8	81	1295	31135	60454	\N	45.222177000000002	Ставропольский край, Петровский район, село Кугуты, улица Железнодорожная, дом 120		0101000020E6100000D74B5304385545403276C24B709C4640
91569	8	81	1295	31022	59926	\N	45.2989025493886	Ставропольский край, Петровский район, село Константиновское, улица Октябрьская, дом 1А	Россия, Ставропольский край, Петровский район, село Константиновское	0101000020E61000002922C32ADE50454091D6187442A64640
91568	8	81	1295	31022	59893	\N	45.302052379137798	Ставропольский край, Петровский район, село Константиновское, улица Ленина, дом 94	Россия, Ставропольский край, Петровский район, село Константиновское	0101000020E61000003F8D7BF31B52454080D8D2A3A9A64640
91570	8	81	1295	31022	59643	\N	45.298656999999999	Ставропольский край, Петровский район, село Константиновское, улица Ледовского, дом 2Б		0101000020E610000006465ED6C450454059DC7F643AA64640
91586	8	81	1295	31884	59711	\N	45.194586000000001	Ставропольский край, Петровский район, село Донская Балка, улица Ленина, дом 106		0101000020E610000010B22C98F86F45403621AD31E8984640
91582	8	81	1295	31666	60111	\N	45.077601999999999	Ставропольский край, Петровский район, село Гофицкое, улица Советская, дом 71		0101000020E61000004F20EC14AB844540560DC2DCEE894640
91583	8	81	1295	31666	59644	\N	45.077601999999999	Ставропольский край, Петровский район, село Гофицкое, улица Ленина, дом 194		0101000020E61000004F20EC14AB844540560DC2DCEE894640
91580	8	81	1295	31614	60391	\N	45.332814526785498	Ставропольский край, Петровский район, поселок Горный, улица Степная, дом 2А	Россия, Ставропольский край, Петровский район, село Горный	0101000020E61000009DF3531C07924540224F92AE99AA4640
91584	8	81	1295	31796	59832	\N	45.023870000000002	Ставропольский край, Петровский район, село Высоцкое, улица Центральная, дом 68		0101000020E610000057957D570473454082AD122C0E834640
91572	8	81	1295	31209	60106	\N	45.398454000000001	Ставропольский край, Петровский район, село Благодатное, улица Советская, дом 34		0101000020E6100000BF0D315EF34A4540EE7A698A00B34640
91573	8	81	1295	31209	60126	\N	45.398454000000001	Ставропольский край, Петровский район, село Благодатное, улица Петровская, дом 1		0101000020E6100000BF0D315EF34A4540EE7A698A00B34640
91540	8	81	1866	29603	60332	\N	44.884127999999997	Ставропольский край, Новоселицкий район, поселок Щелкан, улица Школьная, 3		0101000020E61000006EA296E656BA45402BBD361B2B714640
91535	8	81	1866	29381	59870	\N	44.716822000000001	Ставропольский край, Новоселицкий район, село Чернолесское, улица Ленина, 43		0101000020E6100000B2A03028D3DA4540D386C3D2C05B4640
91536	8	81	1866	29381	59824	\N	44.716822000000001	Ставропольский край, Новоселицкий район, село Чернолесское, переулок Карла Маркса, 7 В		0101000020E6100000B2A03028D3DA4540D386C3D2C05B4640
91543	8	81	1866	29734	59640	\N	44.843899	Ставропольский край, Новоселицкий район, село Падинское, улица Красная, 119		0101000020E6100000B4E73235099445404510E7E1046C4640
91544	8	81	1866	29833	60352	\N	44.819077	Ставропольский край, Новоселицкий район, поселок Новый Маяк, улица Школьная, 4		0101000020E6100000A852B3075A994540F1F3DF83D7684640
91534	8	81	1866	29284	59637	\N	44.753549999999997	Ставропольский край, Новоселицкий район, село Новоселицкое, улица Шоссейная, 43		0101000020E610000035F10EF0A4B745404DF38E5374604640
91532	8	81	1866	29284	59829	\N	44.753549999999997	Ставропольский край, Новоселицкий район, село Новоселицкое, улица Школьная, 26		0101000020E610000035F10EF0A4B745404DF38E5374604640
91533	8	81	1866	29284	60099	\N	44.753549999999997	Ставропольский край, Новоселицкий район, село Новоселицкое, улица Ставропольская, 94		0101000020E610000035F10EF0A4B745404DF38E5374604640
91539	8	81	1866	29567	59826	\N	44.783735	Ставропольский край, Новоселицкий район, село Китаевское, улица Ленина, 86		0101000020E61000007DCB9C2E8BA9454083DDB06D51644640
91541	8	81	1866	29657	60101	\N	44.843688	Ставропольский край, Новоселицкий район, село Журавское, улица Шоссейная, 8		0101000020E6100000BB97FBE428A645408A03E8F7FD6B4640
91545	8	81	1866	29843	60451	\N	44.768507316545502	Ставропольский край, Новоселицкий район, хутор Жуковский, улица Веселая, 4	Россия, Ставропольский край, Новоселицкий район, село Жуковский	0101000020E61000005709168733934540A0DFF76F5E624640
91537	8	81	1866	29470	60102	\N	44.606375	Ставропольский край, Новоселицкий район, село Долиновка, улица Байрамова, 150		0101000020E6100000221CB3EC49B04540560E2DB29D4D4640
91542	8	81	1866	29731	60393	\N	44.850940999999999	Ставропольский край, Новоселицкий район, поселок Артезианский, улица Веселая, 19		0101000020E61000002CBCCB457CAD4540ABE97AA2EB6C4640
91519	8	81	1413	28654	\N	\N	45.481006999999998	Ставропольский край, Новоалександровский район, Темижбекский сельсовет, поселок Южный, 55,МУЗ НЦРБ фельдшерский пункт		0101000020E6100000ED45B41D538B4440D3122BA391BD4640
91517	8	81	1413	28570	60432	\N	45.407464572189497	Ставропольский край, Новоалександровский район, Красночервонный сельсовет, хутор Чапцев, Заречная, 22, МУК СДК	Россия, Ставропольский край, Новоалександровский район, село Чапцев	0101000020E6100000D9B3E73235974440E0A128D027B44640
91505	8	81	1413	28032	60279	\N	45.347529000000002	Ставропольский край, Новоалександровский район, Раздольненский сельсовет, хутор Фельдмаршальский, Ленина, 164, СДК		0101000020E61000002C4A09C1AA9A4440AFB48CD47BAC4640
91496	8	81	1413	27657	60499	\N	45.408250000000002	Ставропольский край, Новоалександровский район, Присадовый сельсовет, поселок Ударный, Центральная, 11, МУК СДК		0101000020E61000008388D4B48BA54440C74B378941B44640
91523	8	81	1413	28858	59635	\N	45.446100999999999	Ставропольский край, Новоалександровский район, Темижбекский сельсовет, поселок Темижбекский, Момотова, 7, МУК СДК		0101000020E6100000D27135B22B85444040DB6AD619B94640
91518	8	81	1413	28652	\N	\N	45.478592999999996	Ставропольский край, Новоалександровский район, Темижбекский сельсовет, поселок Славенский, МОУ СОШ № 4 фельдшерский пункт		0101000020E6100000C00644882B7D4440198C118942BD4640
91492	8	81	1413	27426	59825	\N	45.546785	Ставропольский край, Новоалександровский район, Светлинский сельсовет, поселок Светлый, Советская, 9А, СДК		0101000020E610000033C005D9B2A84440C078060DFDC54640
91502	8	81	1413	27940	60433	\N	45.247264923257298	Ставропольский край, Новоалександровский район, Раздольненский сельсовет, хутор Румяная Балка, Южная, 26а, СДК	Россия, Ставропольский край, Новоалександровский район, село Румяная Балка	0101000020E6100000B6F5D37FD6AC444004392861A69F4640
91501	8	81	1413	27846	60491	\N	45.261840999999997	Ставропольский край, Новоалександровский район, Краснозоринский сельсовет, хутор Родионов, Степная, 18а, МУК СДК		0101000020E61000007CB60E0EF6BC44403FE0810184A14640
91528	8	81	1413	29031	60154	\N	45.581508999999997	Ставропольский край, Новоалександровский район, станица Расшеватская, Советская, 3, МОУ СОШ № 9		0101000020E6100000E1B721C66B84444032AA0CE36ECA4640
91527	8	81	1413	29031	59638	\N	45.581508999999997	Ставропольский край, Новоалександровский район, станица Расшеватская, Ленина, 54, МУК СДК		0101000020E6100000E1B721C66B84444032AA0CE36ECA4640
91530	8	81	1413	29197	60388	\N	45.635845000000003	Ставропольский край, Новоалександровский район, Горьковский сельсовет, поселок Рассвет, Красная, 10, МУК СДК		0101000020E6100000E63FA4DFBE9844409E29745E63D14640
91504	8	81	1413	27989	59888	\N	45.330930000000002	Ставропольский край, Новоалександровский район, Раздольненский сельсовет, село Раздольное, Ленина, 72, СДК		0101000020E610000003D0285DFAA54440F5A10BEA5BAA4640
91525	8	81	1413	28946	60105	\N	45.571958000000002	Ставропольский край, Новоалександровский район, Радужский сельсовет, поселок Радуга, Ленина, 9, МУК СДК		0101000020E61000001DC87A6AF5734440C15774EB35C94640
91447	8	81	1312	25044	59627	\N	44.758777441857603	"Ставропольский край, Нефтекумский район, город Нефтекумск, ул.Ленина, МОУ ДОД ""ЦВР"""		0101000020E6100000124E0B5EF47D46407FFACF9A1F614640
91499	8	81	1413	27768	60327	\N	45.272917	"Ставропольский край, Новоалександровский район, Краснозоринский сельсовет, поселок Равнинный, Молодежная, 18А, МДОУ ""Д/с ""Теремок"""		0101000020E6100000EE08A7052FB24440DFC2BAF1EEA24640
91495	8	81	1413	27576	60304	\N	45.452272000000001	Ставропольский край, Новоалександровский район, Присадовый сельсовет, поселок Присадовый, Школьная, 11, МУК СДК		0101000020E6100000F7562426A8A74440C172840CE4B94640
91372	8	81	1413	46644	60431	\N	45.424229220358903	пос. Первомайский, ул. Школьная, д.13	Россия, Ставропольский край, Новоалександровский район, село Первомайский	0101000020E61000004E97C5C4E6854440E481C8224DB64640
91514	8	81	1413	46644	60533	\N	45.4208947853474	Ставропольский край, Новоалександровский район, Григорополисский сельсовет, хутор Первомайский, Широкая, 46, МУК СДК		0101000020E61000002AADBF250085444064062AE3DFB54640
91522	8	81	1413	28796	\N	\N	45.449905599777502	Ставропольский край, Новоалександровский район, Темижбекский сельсовет, поселок Озерный, МУЗ НЦРБ фельдшерский пункт	Россия, Ставропольский край, Новоалександровский район, село Озерный	0101000020E61000005FD218ADA37E44401823128596B94640
91482	8	81	1413	15684	59823	\N	45.494560999999997	Ставропольский край, Новоалександровский район, город Новоалександровск, пер.Красноармейский, 77, МОУ СОШ № 12		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91480	8	81	1413	15684	59823	\N	45.494560999999997	"Ставропольский край, Новоалександровский район, город Новоалександровск, пер.Красноармейский, 5, ГДК ""Строитель"""		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91488	8	81	1413	15684	60152	\N	45.494560999999997	"Ставропольский край, Новоалександровский район, город Новоалександровск, пер. Энгельса, 4, МДОу ""Д/с ""Красная шапочка"""		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91479	8	81	1413	15684	59889	\N	45.494560999999997	"Ставропольский край, Новоалександровский район, город Новоалександровск, Тургенева, 29/1, здание МДОУ ""Д/с Одуванчик"""		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91487	8	81	1413	15684	59886	\N	45.490332027300703	Ставропольский край, Новоалександровский район, город Новоалександровск, Советская, 150а, МОУ СОШ № 3	Россия, Ставропольский край, Новоалександровский район, Новоалександровск	0101000020E61000002AC6F99B509C44405517F032C3BE4640
91485	8	81	1413	15684	59634	\N	45.494560999999997	"Ставропольский край, Новоалександровский район, город Новоалександровск, Мичурина, 1, МДОУ ""Д/с ""Чебурашка"""		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91484	8	81	1413	15684	59885	\N	45.494560999999997	Ставропольский край, Новоалександровский район, город Новоалександровск, Лермонтова, 20, МОУ СОШ № 5		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91490	8	81	1413	15684	59633	\N	45.494560999999997	Ставропольский край, Новоалександровский район, город Новоалександровск, Ленина, 70, ДЮЦ		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91489	8	81	1413	15684	59633	\N	45.494560999999997	Ставропольский край, Новоалександровский район, город Новоалександровск, Ленина, 101, РДК		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91486	8	81	1413	15684	59822	\N	45.494560999999997	Ставропольский край, Новоалександровский район, город Новоалександровск, Калинина, 124, Магазин райпотребсоюза		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91481	8	81	1413	15684	59882	\N	45.494560999999997	"Ставропольский край, Новоалександровский район, город Новоалександровск, Железнодорожная, 139А, УП ""Рынок ""Центральный"""		0101000020E61000002D9622F94A9C444043705CC64DBF4640
91483	8	81	1413	15684	60553	\N	45.4917238016684	"""Ставропольский край, Новоалександровский район, город Новоалександровск, ул.Ворошилова, 50"	Россия, Ставропольский край, Новоалександровский район, Новоалександровск	0101000020E6100000DE054A0A2C9C44404354E1CFF0BE4640
91493	8	81	1413	27483	60390	\N	45.488773000000002	Ставропольский край, Новоалександровский район, Светлинский сельсовет, хутор Мокрая Балка, Центральная, 27, МОУ СОШ № 13		0101000020E6100000D47C957CECAE44407B15191D90BE4640
91526	8	81	1413	29023	60450	\N	45.540686999999998	Ставропольский край, Новоалександровский район, Радужский сельсовет, поселок Лиманный, Карла Маркса, 31, МУК СДК		0101000020E61000001763601DC7754440A92F4B3B35C54640
91506	8	81	1413	28100	60387	\N	45.284733709468199	Ставропольский край, Новоалександровский район, Раздольненский сельсовет, поселок Курганный, Социалистическая, 1, СДК	Россия, Ставропольский край, Новоалександровский район, село Курганный	0101000020E61000001FF46C567D9A44409607E92972A44640
91516	8	81	1413	28512	59843	\N	45.444208341358703	Ставропольский край, Новоалександровский район, Красночервонный сельсовет, хутор Красночервонный, Ленина, 16, МУК СДК	Россия, Ставропольский край, Новоалександровский район, село Красночервонный	0101000020E6100000B534B74258914440904FC8CEDBB84640
91521	8	81	1413	57652	\N	\N	45.438904799229597	Ставропольский край, Новоалександровский район, Темижбекский сельсовет, поселок Краснокубанский, МУК СДК	Россия	0101000020E610000042959A3DD07844408386FE092EB84640
91498	8	81	1413	27713	60354	\N	45.361677999999998	Ставропольский край, Новоалександровский район, Краснозоринский сельсовет, поселок Краснозоринский, пер.Юбилейный, 1А, МУК СДК		0101000020E61000003526C45C52AF444062D7F6764BAE4640
91507	8	81	1413	28107	60453	\N	45.392473000000003	Ставропольский край, Новоалександровский район, Раздольненский сельсовет, хутор Краснодарский, Калинина, 28, СДК		0101000020E61000004C35B396029C444011C8258E3CB24640
37744	3	28	962	9603	23137	\N	54.623747999999999	пос.  Заовражное, Калининградская, 17		0101000020E6100000A9DC442DCD9D3540037976F9D64F4B40
91513	8	81	1413	28375	60389	\N	45.355097999999998	Ставропольский край, Новоалександровский район, Григорополисский сельсовет, хутор Керамик, Заводская, 38, МУК СДК		0101000020E610000047C66AF3FF8244400070ECD973AD4640
91497	8	81	1413	27673	59827	\N	45.414748000000003	Ставропольский край, Новоалександровский район, станица Кармалиновская, Красная, 80/1, здание администрации		0101000020E610000098E0D40792AD44406C0A647616B54640
91531	8	81	1413	29196	60492	\N	45.642543000000003	Ставропольский край, Новоалександровский район, Горьковский сельсовет, поселок Заречный, Восточная, 6а, СДК		0101000020E6100000B8E7F9D346A544400AA359D93ED24640
91511	8	81	1413	28188	60098	\N	45.299670999999996	Ставропольский край, Новоалександровский район, Григорополисский сельсовет, станица Григорополисская, Шмидта, 39, МОУ СОШ № 2		0101000020E610000098BD6C3B6D874440A1478C9E5BA64640
91509	8	81	1413	28188	60121	\N	45.447514407693703	"Ставропольский край, Новоалександровский район, Григорополисский сельсовет, станица Григорополисская, Тимирязева, 92, ГОУ НПО ""Лицей им.М.И.Платова"""		0101000020E6100000BB26A435068544404640852348B94640
91510	8	81	1413	28188	60100	\N	45.298826475225098	Ставропольский край, Новоалександровский район, Григорополисский сельсовет, станица Григорополисская, Р.Люксембург, 13А, МУК СДК	Россия, Ставропольский край, Новоалександровский район, село Григорополисская	0101000020E61000005952EE3EC7874440E5982CEE3FA64640
91508	8	81	1413	28188	60298	\N	45.299670999999996	"Ставропольский край, Новоалександровский район, Григорополисский сельсовет, станица Григорополисская, Д.Бедного, 17, СДК ""Южный"""	Россия, Ставропольский край, Новоалександровский район, село Григорополисская	0101000020E610000098BD6C3B6D874440A1478C9E5BA64640
91529	8	81	1413	29127	60346	\N	45.656371999999998	Ставропольский край, Новоалександровский район, Горьковский сельсовет, поселок Горьковский, Комсомольская, 33, МУК СДК		0101000020E6100000094FE8F5279944404B0169FF03D44640
91520	8	81	1413	28739	\N	\N	45.418854000000003	Ставропольский край, Новоалександровский район, Темижбекский сельсовет, поселок Восточный, МУЗ НЦРБ фельдшерский пункт		0101000020E610000096CCB1BCAB8844403FE603029DB54640
91503	8	81	1413	27948	60386	\N	45.266782999999997	Ставропольский край, Новоалександровский район, Раздольненский сельсовет, станица Воскресенская, Школьная, 18, МОУ ООШ № 13		0101000020E61000001366DAFE95A544407B1002F225A24640
91515	8	81	1413	57690	60624	\N	45.418319598761997	Ставропольский край, Новоалександровский район, Григорополисский сельсовет, хутор Воровской, пер. Школьный, 1а,  Филиал МОУ СОШ № 4	Россия, Ставропольский край, Новоалександровский район, село Воровский	0101000020E61000002922C32ADE804440A1A17F828BB54640
91494	8	81	1413	27573	60385	\N	45.481071	Ставропольский край, Новоалександровский район, Присадовый сельсовет, поселок Виноградный, Заречная, 4, МУК СДК		0101000020E61000008D4127840EA44440EA060ABC93BD4640
91468	8	81	1312	57679	60532	\N	44.4132566803613	"Ставропольский край, Нефтекумский район, аул Ямангой, ул.Ленина, МОУ ""ООШ № 19"""	Россия, Ставропольский край, Нефтекумский район, село Ямангой	0101000020E6100000B760A92EE06B4640EAEBF99AE5344640
91473	8	81	1312	57680	60545	\N	44.396889891375501	"Ставропольский край, Нефтекумский район, аул Уч-Тюбе, ул.Ленина, 19, отделение МОУ ""СОШ № 16"""	Россия, Ставропольский край, Нефтекумский район, село Уч-Тюбе	0101000020E61000009DF17D71A9804640020EA14ACD324640
91474	8	81	1312	57629	60309	\N	44.475973811064598	"Ставропольский край, Нефтекумский район, аул Уллуби-Юрт, ул.60-лет Октября, 42, МОУ ""СОШ № 11"""	Россия, Ставропольский край, Нефтекумский район, село Уллуби-Юрт	0101000020E61000004660AC6F607E464087DF4DB7EC3C4640
91477	8	81	1312	57599	59895	\N	44.329959645671103	Ставропольский край, Нефтекумский район, аул Тукуй-Мектеб, ул.Эдиге, 35-А, ДК а.Тукуй-Мектеб	Россия, Ставропольский край, Нефтекумский район, село Тукуй-Мектеб	0101000020E6100000BA9F53909F9746407C7E18213C2A4640
91454	8	81	1312	25751	60341	\N	44.823264999999999	Ставропольский край, Нефтекумский район, село Озек-Суат, ул.О.Сеитова, 92, ДК с.Озек-Суат (нижний)		0101000020E610000014234BE65890464081785DBF60694640
91455	8	81	1312	25751	60462	\N	44.829931175173598	Ставропольский край, Нефтекумский район, село Озек-Суат, ул.Мира, 53-А, ДК с.Озек-Суат (верхний)	Россия, Ставропольский край, Нефтекумский район, село Озек-Суат	0101000020E61000002810768A55914640E277D32D3B6A4640
91466	8	81	1312	57609	60172	\N	44.437004068300197	Ставропольский край, Нефтекумский район, аул Новкус-Артезиан, ул.Кирова, ДК а.Новкус-Артезиан		0101000020E6100000D47C957CEC624640501C40BFEF374640
91446	8	81	1312	25044	\N	\N	44.741162000000003	"Ставропольский край, Нефтекумский район, город Нефтекумск, м-он № 1, МОУ ""СОШ № 2"""		0101000020E61000008C648F50337E4640DC847B65DE5E4640
91442	8	81	1312	25044	59879	\N	44.741162000000003	"Ставропольский край, Нефтекумский район, город Нефтекумск, пл.Ленина, ДК ""Нефтяник"""		0101000020E61000008C648F50337E4640DC847B65DE5E4640
91444	8	81	1312	25044	59821	\N	44.741162000000003	Ставропольский край, Нефтекумский район, город Нефтекумск, м-он № 2, дом № 14, администрация города		0101000020E61000008C648F50337E4640DC847B65DE5E4640
91445	8	81	1312	25044	59881	\N	44.743854037009697	"Ставропольский край, Нефтекумский район, город Нефтекумск, м-он № 1, дом № 17, МУП ""ЖХ"""		0101000020E6100000FD6CE4BA297F4640D87F9D9B365F4640
91448	8	81	1312	25044	59627	\N	44.741162000000003	"Ставропольский край, Нефтекумский район, город Нефтекумск, ул.Ленина, 42, МОУ ДОД ""ДХШ"""		0101000020E61000008C648F50337E4640DC847B65DE5E4640
37593	3	28	361	1858	23050	\N	54.630102000000001	г. Нестеров, Черняховского, 8		0101000020E610000095B9F946749336407592AD2EA7504B40
91441	8	81	1312	25044	59628	\N	44.744342912602903	Ставропольский край, Нефтекумский район, город Нефтекумск, ул.Анны Шилиной, 26, бывшее МУ Межшкольный комбинат	Россия, Ставропольский край, Нефтекумский район, Нефтекумск	0101000020E6100000EEE9EA8EC57E4640D600A5A1465F4640
91440	8	81	1312	25044	59628	\N	44.7586551346363	"Ставропольский край, Нефтекумский район, город Нефтекумск, ул.Анны Шилиной, 3, МОУ ""СОШ № 1"""		0101000020E6100000C2FBAA5CA87E464033F9669B1B614640
91476	8	81	1312	57613	60179	\N	44.440169316525797	"Ставропольский край, Нефтекумский район, аул Махмуд-Мектеб, ул.Советская, 63-В, МОУ ""СОШ № 15"""	Россия, Ставропольский край, Нефтекумский район, село Махмуд-Мектеб	0101000020E61000006CE9D1544F9A464044DB317557384640
91475	8	81	1312	57650	60438	\N	44.4075965079764	Ставропольский край, Нефтекумский район, аул Кунай, ул.Степная, ДК а.Кунай		0101000020E6100000B9C32632738D46404F7974232C344640
91467	8	81	1312	57674	60525	\N	44.402428042822898	Ставропольский край, Нефтекумский район, аул Кок-Бас, ул.Ленина, ДК а.Кок-Бас	Россия, Ставропольский край, Нефтекумский район, село Кок-Бас	0101000020E6100000F31FD26F5F614640527FBDC282334640
91472	8	81	1312	26511	59710	\N	44.325720157726501	Ставропольский край, Нефтекумский район, село Каясула, ул.Советская, 43-Г, ДК с.Каясула (танц.зал)	Россия, Ставропольский край, Нефтекумский район, село Каясула	0101000020E610000061C43E01147F464099D36531B1294640
91471	8	81	1312	26511	59710	\N	44.325904999999999	Ставропольский край, Нефтекумский район, село Каясула, ул.Советская, 43-Г, ДК с.Каясула (большой зал)		0101000020E6100000014D840D4F7F46402B4D4A41B7294640
91464	8	81	1312	57618	60221	\N	44.518732755625599	Ставропольский край, Нефтекумский район, село Кара-Тюбе, ул.Ленина, 44-Б, здание отдела культуры	Россия, Ставропольский край, Нефтекумский район, село Каратюбе	0101000020E6100000FD6838656E544640902DCBD765424640
91470	8	81	1312	26417	60292	\N	44.304312000000003	Ставропольский край, Нефтекумский район, поселок Зункарь, ул.Молодежная, администрация МО		0101000020E6100000B8020AF5F4714640E3E313B2F3264640
91457	8	81	1312	13858	60535	\N	44.914991999999998	"""Ставропольский край, Нефтекумский район, поселок Зимняя Ставка, ул.Новая 16"		0101000020E61000002A01310917AA4640020D36751E754640
91449	8	81	1312	25456	59819	\N	44.792217999999998	Ставропольский край, Нефтекумский район, поселок Затеречный, ул.Строительная, помещение казачьей управы		0101000020E6100000FA449E245D9B4640B9A6406667654640
91453	8	81	1312	25456	60337	\N	44.7715560349668	"Ставропольский край, Нефтекумский район, поселок Затеречный, ул.Котельная, 20/1, МОУ ДОД ""ЗДМШ"""	Россия, Ставропольский край, Нефтекумский район	0101000020E6100000A089B0E1E99946402B84D558C2624640
91452	8	81	1312	25456	59630	\N	44.792217999999998	"Ставропольский край, Нефтекумский район, поселок Затеречный, ул.Комсомольская, 10, МУ ""ДК"""		0101000020E6100000FA449E245D9B4640B9A6406667654640
91451	8	81	1312	25456	59629	\N	44.792217999999998	Ставропольский край, Нефтекумский район, поселок Затеречный, ул.Горького, помещение бывшего кафе		0101000020E6100000FA449E245D9B4640B9A6406667654640
91463	8	81	1312	57643	60383	\N	44.597083323649201	"Ставропольский край, Нефтекумский район, аул Бияш, ул.Степная, 36-Б, контора ПУ № 4 СПКк ""Восток"""	Россия, Ставропольский край, Нефтекумский район, село Бияш	0101000020E6100000C45BE7DF2E594640B0FF3A376D4C4640
91469	8	81	1312	57647	60419	\N	44.411434704340202	Ставропольский край, Нефтекумский район, аул Бейсей, ул.А.Шабанова, 42/1, ДК а.Бейсей	Россия, Ставропольский край, Нефтекумский район, село Бейсей	0101000020E61000007978CF81E576464002B7EEE6A9344640
91460	8	81	1312	13868	59910	\N	44.548802000000002	"Ставропольский край, Нефтекумский район, село Ачикулак, пл.Ленина, МУ ""ДК с.Ачикулак"" (фойе)"		0101000020E6100000CA198A3BDE6A46405DFDD8243F464640
91461	8	81	1312	13868	59880	\N	44.548802000000002	"Ставропольский край, Нефтекумский район, село Ачикулак, пл.Ленина, МУ ""ДК с.Ачикулак"" (зал)"		0101000020E6100000CA198A3BDE6A46405DFDD8243F464640
91459	8	81	1312	13868	60579	\N	44.548802000000002	"""Ставропольский край, Нефтекумский район, село Ачикулак, ул.Червонная, 40"		0101000020E6100000CA198A3BDE6A46405DFDD8243F464640
91465	8	81	1312	57677	60534	\N	44.510836029437897	Ставропольский край, Нефтекумский район, аул Артезиан-Мангит, ул.Ленина, ДК а.Артезиан-Мангит	Россия, Ставропольский край, Нефтекумский район, село Артезиан-Мангит	0101000020E610000082CAF8F7196146404ACFF41263414640
91458	8	81	1312	25935	59631	\N	44.607780654542204	Ставропольский край, Нефтекумский район, хутор Андрей-Курган, ул.Правобережная, 4-А, ДК х.Андрей-Курган	Россия, Ставропольский край, Нефтекумский район, село Андрей-Курган	0101000020E610000087C5A86BED714640AA108FC4CB4D4640
91478	8	81	1312	57633	60351	\N	44.308593968138801	"Ставропольский край, Нефтекумский район, аул Абрам-Тюбе, ул.Курманалиева, 32, МОУ ""СОШ № 17"""	Россия, Ставропольский край, Нефтекумский район, село Абрам-Тюбе	0101000020E610000035CF11F92EA34640F4DE180280274640
91456	8	81	1312	57666	60501	\N	44.729713194059997	Ставропольский край, Нефтекумский район, аул Абдул-Газы, ул.А.Эюпова, 58, ДК а.Абдул-Газы	Россия, Ставропольский край, Нефтекумский район, село Абдул-Газы	0101000020E6100000187959130B8E4640A73B4F3C675D4640
91249	8	81	216	15597	60275	\N	44.544352300593403	Ставропольский край, Кочубеевский район, Усть-Невинский сельсовет, хутор Усть-Невинский, ул. Набережная, д. 69/б	Россия, Ставропольский край, Невинномысск городской округ, село Усть-Невинский	0101000020E610000055F833BC59F9444090C18A53AD454640
91289	8	81	1268	17585	59808	\N	44.043055000000003	Ставропольский край, Курский район, село Эдиссия, Свердлова, 18		0101000020E6100000F1BBE9961D464640F37684D382054640
91227	8	81	216	57662	60468	\N	44.663759947599999	Ставропольский край, Кочубеевский район, Мищенский сельсовет, хутор Степной, Центральная, 37/а	Россия, Ставропольский край, Невинномысск городской округ, село Степной	0101000020E6100000A0E1CD1ABCC944404D327216F6544640
91241	8	81	216	15204	60368	\N	44.721459000000003	Ставропольский край, Кочубеевский район, Стародворцовский сельсовет, хутор Стародворцовский, Ленина, 50		0101000020E6100000BC02D19332114540D333BDC4585C4640
91239	8	81	216	15098	60494	\N	44.744472000000002	Ставропольский край, Кочубеевский район, Барсуковский сельсовет, поселок Свистуха, Казачья, 2		0101000020E61000005AF10D85CFF24440D464C6DB4A5F4640
91219	8	81	216	57676	60523	\N	44.581856397335699	Ставропольский край, Кочубеевский район, х. Саратовский, ул. Мира, д. 59/а	Россия, Ставропольский край, Невинномысск городской округ, село Саратовский	0101000020E6100000D7187442E8E244409E7DE5417A4A4640
91245	8	81	216	15406	60437	\N	44.377827309638697	Ставропольский край, Кочубеевский район, Георгиевский сельсовет, хутор Рощинский, Мира, 57	Россия, Ставропольский край, Невинномысск городской округ, село Рощинский	0101000020E6100000CF328B506C134540DD4598A25C304640
91613	8	81	216	825	60457	\N	44.518461000000002	"Ставропольский край, Предгорный район, Пятигорский сельсовет, поселок Родниковский, Шоссейная, здание конторы СПК ""Поречье"""		0101000020E610000025C9737D1F02454030A017EE5C424640
91218	8	81	216	57667	60505	\N	44.530745203795398	Ставропольский край, Кочубеевский район, х. Петровский, ул. 40 лет Победы, д. 1/а	Россия, Ставропольский край, Невинномысск городской округ, поселок Петровский	0101000020E610000004AF963B33E74440FDC1C073EF434640
91253	8	81	216	57631	60315	\N	44.534919984307997	Ставропольский край, Кочубеевский район, Новодеревенский сельсовет, село Новая Деревня, Ленина, 64	Россия, Ставропольский край, Невинномысск городской округ, село Новая Деревня	0101000020E61000003A419B1C3EED4440F8FC304278444640
91205	8	81	216	57579	59576	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, Вокзальная, 50		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91235	8	81	216	14932	60288	\N	44.871980000000001	Ставропольский край, Кочубеевский район, Надзорненский сельсовет, село Надзорное, Ленина, 24		0101000020E6100000F9307BD976D844400F62670A9D6F4640
91209	8	81	216	13025	60079	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, Фабричная, 42		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91207	8	81	216	13025	60074	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, Скрипникова, 67		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91202	8	81	216	13025	60089	\N	44.668869583853301	Ставропольский край, Кочубеевский район, село Кочубеевское, Партизанская, 56	Россия, Ставропольский край, Невинномысск городской округ, село Кочубеевское	0101000020E6100000F3CAF5B699EA444044A33B889D554640
91206	8	81	216	13025	59851	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, Октябрьской революции, 63		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91204	8	81	216	13025	59851	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, Октябрьской революции, 11		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91210	8	81	216	13025	59690	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, ул. Гагарина, д.83		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91203	8	81	216	13025	59791	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, Бульварная, 144		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91212	8	81	216	13025	59786	\N	44.670462000000001	Ставропольский край, Кочубеевский район, село Кочубеевское, ул.Балахонова, д.1		0101000020E610000092EBA694D7EA4440FA9AE5B2D1554640
91221	8	81	216	14246	59923	\N	44.586292	Ставропольский край, Кочубеевский район, Казьминский сельсовет, село Казьминское, Советская, 70		0101000020E61000001D91EF52EAD6444006F4C29D0B4B4640
91220	8	81	216	14246	59850	\N	44.586292	Ставропольский край, Кочубеевский район, с. Казьминское, ул. Революционная, д.60		0101000020E61000001D91EF52EAD6444006F4C29D0B4B4640
91230	8	81	216	14640	59849	\N	44.745753000000001	Ставропольский край, Кочубеевский район, Заветненский сельсовет, село Заветное, Баркова, 17		0101000020E61000005E9D6340F6CE44406BF294D5745F4640
91251	8	81	216	15681	60333	\N	44.540328000000002	Ставропольский край, Кочубеевский район, Новодеревенский сельсовет, хутор Дегтяревский, Ленина, 36		0101000020E61000001E520C9068F644407A8EC87729454640
91246	8	81	216	15451	60322	\N	44.437554161778102	Ставропольский край, Кочубеевский район, Георгиевский сельсовет, станица Георгиевская, Молодежная, 4	Россия, Ставропольский край, Невинномысск городской округ, село Георгиевская	0101000020E610000060048D99440D4540F31DFCC401384640
91217	8	81	216	14074	60076	\N	44.49962	Ставропольский край, Кочубеевский район, с. Веселое, ул. Зеленая, д. 15		0101000020E6100000368FC360FEE64440B936548CF33F4640
91222	8	81	216	14296	60422	\N	44.636138000000003	Ставропольский край, Кочубеевский район, Васильевский сельсовет, хутор Беловский, Центральная, 75		0101000020E6100000540262122ED4444016DF50F86C514640
91243	8	81	216	15288	60425	\N	44.631045	Ставропольский край, Кочубеевский район, Стародворцовский сельсовет, хутор Барсуковский, Центральная, 7		0101000020E6100000C87BD5CA840F4540F4A62215C6504640
91238	8	81	216	57625	60291	\N	44.7642561557943	Ставропольский край, Кочубеевский район, Барсуковский сельсовет, станица Басуковская, Ленина, 37	Россия, Ставропольский край, Невинномысск городской округ, село Барсуковская	0101000020E61000004F965AEF37E84440CAE2FE23D3614640
91232	8	81	216	14724	60080	\N	44.776933999999997	Ставропольский край, Кочубеевский район, Балахоновский сельсовет, село Балахоновское, пл. Гетало, д. 3		0101000020E61000005DA79196CAE344404293C49272634640
91224	8	81	216	14434	60423	\N	44.703600000000002	Ставропольский край, Кочубеевский район, Васильевский сельсовет, хутор Андреевский, Центральная, 8		0101000020E6100000E2E995B20CD3444099BB96900F5A4640
91228	8	81	7442	57597	59856	\N	44.706936332946398	Ставропольский край, Кочубеевский район, с. Вревское, ул. Почтовая, д.62	Россия, Ставропольский край, Невинномысск городской округ, село Вревское	0101000020E61000003543AA285EC54440BA2EFCE07C5A4640
91400	8	81	1320	15728	60556	\N	44.252411000000002	Ставропольский край, Минераловодский район, пос. Фруктовый, ул.Королева 1		0101000020E6100000E9D500A5A15E45404913EF004F204640
91396	8	81	1320	22991	\N	\N	44.303066999999999	Ставропольский край, Минераловодский район, с.Ульяновка, Дом культуры		0101000020E6100000CDCCCCCCCC76454098BF42E6CA264640
91377	8	81	1320	22116	\N	\N	44.399591000000001	Ставропольский край, Минераловодский район, с. Сухая Падина, Дом культуры		0101000020E6100000575D876A4A9C4540526342CC25334640
91402	8	81	1320	23261	\N	\N	44.234161	Ставропольский край, Минераловодский район, с. Сунжа, Дом культуры		0101000020E61000004C33DDEBA4684540D47FD6FCF81D4640
91376	8	81	1320	57649	\N	\N	44.392550999999997	Ставропольский край, Минераловодский район, х. Старотарский, Дом культуры	Россия, Ставропольский край, Минераловодский район, село Старотарский	0101000020E6100000923B6C22338945408C81751C3F324640
91374	8	81	1320	57623	\N	\N	44.245042941631702	Ставропольский край, Минераловодский район, х.Славянский, Дом культуры	Россия, Ставропольский край, Минераловодский район, село Славянский	0101000020E6100000713D0AD7A38A45408F8EAB915D1F4640
91378	8	81	1320	22198	\N	\N	44.444971000000002	Ставропольский край, Минераловодский район, с.Розовка, Дом культуры		0101000020E610000001F8A754899245408F554ACFF4384640
91394	8	81	1320	13965	60578	\N	44.237152000000002	Ставропольский край, Минераловодский район, c. Прикумское, ул.Ленина, 56		0101000020E610000010B3976DA77345402B172AFF5A1E4640
91389	8	81	1320	22655	\N	\N	44.240192999999998	Ставропольский край, Минераловодский район, с.Побегайловка, Дом культуры		0101000020E6100000C7BB2363B581454033DDEBA4BE1E4640
91382	8	81	1320	57594	\N	\N	44.395478948515297	Ставропольский край, Минераловодский район, х.Перевальный, Дом культуры	Россия, Ставропольский край, Минераловодский район, село Перевальный	0101000020E6100000D2E28C614E6645409DA04D0E9F324640
91370	8	81	1320	21822	\N	\N	44.233902999999998	Ставропольский край, Минераловодский район, пос.Первомайский, Дом культуры		0101000020E61000000B42791F478F4540D8B79388F01D4640
91371	8	81	1320	21822	60339	\N	44.233902999999998	Ставропольский край, Минераловодский район, пос.Первомайский, ул. Московская, 18А		0101000020E61000000B42791F478F4540D8B79388F01D4640
91393	8	81	1320	22828	\N	\N	44.232093999999996	Ставропольский край, Минераловодский район, с. Орбельяновка, библиотека		0101000020E61000004E7FF6234570454085CC9541B51D4640
91388	8	81	1320	22381	\N	\N	44.148412	Ставропольский край, Минераловодский район, пос. Новотерский, Дворец культуры, фойе		0101000020E6100000077DE9EDCF8B4540BF2A172AFF124640
91383	8	81	1320	22381	\N	\N	44.148412	Ставропольский край, Минераловодский район, пос. Новотерский, Дом культуры, спорт зал		0101000020E6100000077DE9EDCF8B4540BF2A172AFF124640
91381	8	81	1320	22310	\N	\N	44.489621	Ставропольский край, Минераловодский район, с.Нижняя Александровка, Дом культуры		0101000020E6100000A33A1DC87A744540A837A3E6AB3E4640
91401	8	81	1320	23183	\N	\N	44.287634933881698	Ставропольский край, Минераловодский район, пос. Нижнебалковский, Дом культуры	Россия, Ставропольский край, Минераловодский район, село Нижнебалковский	0101000020E61000009BC6F65AD0614540AD174339D1244640
91380	8	81	1320	22254	\N	\N	44.441889000000003	Ставропольский край, Минераловодский район, с.Нагутское, Дом культуры		0101000020E61000006A4DF38E5370454028BB99D18F384640
91375	8	81	1320	22031	\N	\N	44.384512000000001	Ставропольский край, Минераловодский район, с.Марьины Колодцы, сельсовет, административное здание		0101000020E61000000F98874CF9904540B47570B037314640
91385	8	81	1320	22465	\N	\N	44.189928999999999	Ставропольский край, Минераловодский район, пос.Ленинский, Дом культуры		0101000020E6100000E4BF401020934540EFC7ED974F184640
91368	8	81	1320	21626	59619	\N	44.232016999999999	Ставропольский край, Минераловодский район, с. Левокумка, Дом культуры, ул. Степная, д.6		0101000020E6100000CE1951DA1B924540DA8EA9BBB21D4640
91367	8	81	1320	21626	59867	\N	44.232016999999999	Ставропольский край, Минераловодский район, с.Левокумка, ул. Мостовая, д.2А		0101000020E6100000CE1951DA1B924540DA8EA9BBB21D4640
91387	8	81	1320	22569	\N	\N	44.249395	Ставропольский край, Минераловодский район, пос. Кумской, здание медпункта	Россия, Ставропольский край, Минераловодский район, село Кумской	0101000020E6100000EC3026FDBD8845409964E42CEC1F4640
91392	8	81	1320	22779	\N	\N	44.287550000000003	Ставропольский край, Минераловодский район, пос. Кумагорск, помешение бывшей библиотеки, д.1		0101000020E61000007CEE04FBAF8345407FFB3A70CE244640
91386	8	81	1320	22513	59622	\N	44.199804	Ставропольский край, Минераловодский район, х. Красный Пахарь, ул. 9 Мая, д.26		0101000020E6100000630E828E568D454014CE6E2D93194640
91390	8	81	1320	22730	\N	\N	44.2545108488465	Ставропольский край, Минераловодский район, с. Канглы, Дом культуры	Россия, Ставропольский край, Минераловодский район, село Канглы	0101000020E610000030B8E68EFE83454073BC02D193204640
91326	8	81	1275	19515	60296	\N	44.828423999999998	Ставропольский край, Левокумский район, Бургун-Маджарский сельсовет, село Бургун-Маджары, Ленина, 75		0101000020E610000030F5F3A6223D46405A9C31CC096A4640
91391	8	81	1320	22730	60508	\N	44.253955649507198	Ставропольский край, Минераловодский район, Побегайловский сельсовет, село Канглы, ул. Ключевая/ул.Шоссейная, д.2 / д.11		0101000020E6100000C8B4368DED834540BE4F55A181204640
91373	8	81	1320	21931	\N	\N	44.256929999999997	"Ставропольский край, Минераловодский район, пос. Загорский, МОУ ""Средняя образ.школа № 18"""		0101000020E61000008EB0A888D38F45403EAE0D15E3204640
91337	8	81	1320	57626	\N	\N	44.213577746847697	Ставропольский край, город Минеральные Воды, поселок Евдокимовский, ДК	Россия, Ставропольский край, Минераловодский район, село Евдокимовский	0101000020E61000001DAED51EF698454092921E86561B4640
91395	8	81	1320	22901	\N	\N	44.235406452690903	Ставропольский край, Минераловодский район, с. Долина, библиотека	Россия, Ставропольский край, Минераловодский район, село Долина	0101000020E6100000ABECBB22F87745401EA4A7C8211E4640
91379	8	81	1320	22211	\N	\N	44.425835999999997	Ставропольский край, Минераловодский район, с.Греческое, Дом культуры		0101000020E6100000D2A755F487804540CFBA46CB81364640
91398	8	81	1320	14015	\N	\N	44.230389000000002	"Ставропольский край, Минераловодский район, с. Гражданское, МБУ ""Гражданское социально-культурное объединение"""		0101000020E6100000F2EA1C03B2634540D82D02637D1D4640
91399	8	81	1320	14015	60583	\N	44.230389000000002	Ставропольский край, Минераловодский район, с.Гражданское, ул.Пролетарская 23А		0101000020E6100000F2EA1C03B2634540D82D02637D1D4640
91384	8	81	1320	22455	\N	\N	44.143625	Ставропольский край, Минераловодский район, пос. Бородыновка, Дом культуры		0101000020E6100000FCC401F4FB904540AAF1D24D62124640
91366	8	81	1320	21528	\N	\N	44.237281000000003	"Ставропольский край, Минераловодский район, поселок Анджиевский, административное здание ООО ""Стройтранс"""		0101000020E61000002BC3B81B448B4540297B4B395F1E4640
91365	8	81	1320	21528	\N	\N	44.237281000000003	Ставропольский край, Минераловодский район, поселок Анджиевский, Дом культуры		0101000020E61000002BC3B81B448B4540297B4B395F1E4640
91364	8	81	1320	21528	60277	\N	44.237281000000003	Ставропольский край, Минераловодский район, поселок Анджиевский, ул. Береговая, д. 2б		0101000020E61000002BC3B81B448B4540297B4B395F1E4640
91328	8	81	7443	57593	59817	\N	44.119589441128703	Ставропольский край, город Лермонтов, село Острогорка, Комсомольская, 15-в	Россия, Ставропольский край, Лермонтов городской округ, село Острогорка	0101000020E610000048DFA469507E45400DFB3DB14E0F4640
91317	8	81	1275	19010	60085	\N	44.789971999999999	Ставропольский край, Левокумский район, село Урожайное, площадь Ленина, 1		0101000020E61000002E1D739EB1754640BB6070CD1D654640
91320	8	81	1275	19203	59606	\N	45.217511000000002	Ставропольский край, Левокумский район, Турксадский сельсовет, село Турксад, Шоссейная, 24		0101000020E61000000553CDACA570464098C28366D79B4640
91321	8	81	1275	19211	59607	\N	45.248632000000001	Ставропольский край, Левокумский район, село Приозерское, Мира, 35		0101000020E6100000CEE15AED616946409A5E622CD39F4640
91314	8	81	1275	18894	60088	\N	44.771841000000002	Ставропольский край, Левокумский район, село Правокумское, Советская, 2		0101000020E61000004DA088450C534640215B96AFCB624640
91315	8	81	1275	18894	59602	\N	44.771841000000002	Ставропольский край, Левокумский район, село Правокумское, Гагарина, 10		0101000020E61000004DA088450C534640215B96AFCB624640
91313	8	81	1275	18797	59798	\N	44.797238999999998	Ставропольский край, Левокумский район, поселок Новокумский, Мичурина, 1		0101000020E6100000F2B0506B9A594640410C74ED0B664640
91323	8	81	1275	19352	60019	\N	44.940300999999998	Ставропольский край, Левокумский район, Николо-Александровский сельсовет, село Николо-Александровское, Кооперативная, 116		0101000020E6100000711FB935E9424640B3B27DC85B784640
91324	8	81	1275	13304	60663	\N	45.101305000000004	Ставропольский край, Левокумский район, Николо-Александровский сельсовет, поселок Ленинский, Мира, 1		0101000020E61000005915E126A3424640EDF5EE8FF78C4640
91311	8	81	1275	18579	59601	\N	44.822504000000002	Ставропольский край, Левокумский район, село Левокумское, Пролетарская, 177		0101000020E6100000C5FF1D51A1544640236AA2CF47694640
91309	8	81	1275	18579	59601	\N	44.822504000000002	Ставропольский край, Левокумский район, село Левокумское, Пролетарская, 46		0101000020E6100000C5FF1D51A1544640236AA2CF47694640
91310	8	81	1275	18579	59857	\N	44.822504000000002	Ставропольский край, Левокумский район, село Левокумское, Комсомольская, 62		0101000020E6100000C5FF1D51A1544640236AA2CF47694640
91312	8	81	1275	18579	60087	\N	44.822504000000002	Ставропольский край, Левокумский район, село Левокумское, Борцов Революции, 22		0101000020E6100000C5FF1D51A1544640236AA2CF47694640
91325	8	81	1275	13306	59608	\N	44.826948000000002	Ставропольский край, Левокумский район, Бургун-Маджарский сельсовет, поселок Кумская Долина, Гагарина, 17		0101000020E610000041BCAE5FB03546400EBF9B6ED9694640
91327	8	81	1275	19526	59861	\N	44.818713000000002	Ставропольский край, Левокумский район, Заринский сельсовет, поселок Заря, Красная, 10		0101000020E61000004051D9B0A6424640B0E76B96CB684640
91316	8	81	1275	18996	59604	\N	44.747571000000001	Ставропольский край, Левокумский район, Владимировский сельсовет, село Владимировка, Лыхова, 16		0101000020E6100000C5E6E3DA5063464011381268B05F4640
91795	8	81	1275	18996	60159	\N	44.747571000000001	село Владимировка, Ленина, 78		0101000020E6100000C5E6E3DA5063464011381268B05F4640
91319	8	81	1275	19055	59799	\N	44.949941942259102	Ставропольский край, Левокумский район, Величаевский сельсовет, село Величаевское, Сестер Антоновых, 2	Россия, Ставропольский край, Левокумский район, село Величаевское	0101000020E6100000D1B2EE1F0B914640658C0FB397794640
91318	8	81	1275	19055	60084	\N	44.949576243998003	Ставропольский край, Левокумский район, Величаевский сельсовет, село Величаевское, Пушкина, 65	Россия, Ставропольский край, Левокумский район, село Величаевское	0101000020E610000081221631EC9046408388D4B48B794640
91290	8	81	1268	17585	60067	\N	44.043055000000003	Ставропольский край, Курский район, село Эдиссия, Исаакяна, 21		0101000020E6100000F1BBE9961D464640F37684D382054640
91292	8	81	1268	17768	60290	\N	43.814357000000001	Ставропольский край, Курский район, Русский сельсовет, село Уваровское, Колхозная, 2		0101000020E61000007730629F003846406422A5D93CE84540
91298	8	81	1268	18064	59800	\N	43.721688	Ставропольский край, Курский район, станица Стодеревская, Советская, 1		0101000020E610000013F241CF666B464034F5BA4560DC4540
91297	8	81	1268	17977	60326	\N	43.861915000000003	Ставропольский край, Курский район, Серноводский сельсовет, село Серноводское, Октябрьская, 1		0101000020E6100000ED45B41D536546404777103B53EE4540
91294	8	81	1268	17777	59600	\N	43.834356	Ставропольский край, Курский район, Русский сельсовет, село Русское, Школьная, 12		0101000020E6100000CFF753E3A5494640569C6A2DCCEA4540
91293	8	81	1268	17777	59599	\N	43.834356	Ставропольский край, Курский район, Русский сельсовет, село Русское, Кооперативная, 120 А		0101000020E6100000CFF753E3A5494640569C6A2DCCEA4540
91308	8	81	1268	18576	60276	\N	44.149427000000003	Ставропольский край, Курский район, Рощинский сельсовет, поселок Рощино, Ленина, 20		0101000020E61000001EC2F869DC994640D811876C20134640
91286	8	81	1268	17456	59597	\N	43.979123999999999	Ставропольский край, Курский район, Ростовановский сельсовет, село Ростовановское, Ленина, 14		0101000020E6100000B24CBF44BC1D4640465D6BEF53FD4540
91284	8	81	1268	17363	60371	\N	43.980888	Ставропольский край, Курский район, Курский сельсовет, хутор Ровный, Крестьянская, 3		0101000020E6100000488C9E5BE83C4640F984ECBC8DFD4540
91285	8	81	1268	57616	60205	\N	44.009338486450297	Ставропольский край, Курский район, Ростовановский сельсовет, хутор Пролетарский, Мира, 9	Россия, Ставропольский край, Курский район, село Пролетарский	0101000020E6100000355F251FBB0F4640164ED2FC31014640
91300	8	81	1268	57653	60446	\N	44.0394012028394	Ставропольский край, Курский район, Полтавский сельсовет, хутор Привольный, Центральная, 45	Россия, Ставропольский край, Курский район, село Привольный	0101000020E61000002E55698B6B50464000378B170B054640
91302	8	81	1268	18256	59797	\N	44.020242000000003	Ставропольский край, Курский район, Полтавский сельсовет, село Полтавское, Кооперативная, 1 Б		0101000020E6100000AE9AE7887C614640B900344A97024640
91282	8	81	1268	57635	60359	\N	44.032837815100301	Ставропольский край, Курский район, Курский сельсовет, хутор Новая Деревня, Зеленого, 50	Россия, Ставропольский край, Курский район, село Новая Деревня	0101000020E610000021B1DD3D4035464074081C0934044640
91305	8	81	1268	18365	59862	\N	44.084451999999999	Ставропольский край, Курский район, Мирненский сельсовет, поселок Мирный, Мира, 21		0101000020E610000086AFAF75A9794640780AB952CF0A4640
91277	8	81	1268	16928	59594	\N	44.045192295960703	Ставропольский край, Курский район, Курский сельсовет, станица Курская, Школьный переулок, 14	Россия, Ставропольский край, Курский район, село Курская	0101000020E6100000EE23B726DD3A46403A05F9D9C8054640
91276	8	81	1268	16928	59594	\N	44.042594999999999	Ставропольский край, Курский район, Курский сельсовет, станица Курская, Школьный переулок, 2		0101000020E61000000CEA5BE6743B46408FFCC1C073054640
91280	8	81	1268	16928	59595	\N	44.042594999999999	Ставропольский край, Курский район, Курский сельсовет, станица Курская, Титова, 12		0101000020E61000000CEA5BE6743B46408FFCC1C073054640
91281	8	81	1268	16928	59869	\N	44.042594953993799	Ставропольский край, Курский район, Курский сельсовет, станица Курская, Кондратенко, 60	Россия, Ставропольский край, Курский район, село Курская	0101000020E610000086200725CC3A46408FFCC1C073054640
91278	8	81	1268	16928	59802	\N	44.042594999999999	Ставропольский край, Курский район, Курский сельсовет, станица Курская, Калинина, 226		0101000020E61000000CEA5BE6743B46408FFCC1C073054640
91279	8	81	1268	16928	59801	\N	44.042594999999999	Ставропольский край, Курский район, Курский сельсовет, станица Курская, Акулова, 56		0101000020E61000000CEA5BE6743B46408FFCC1C073054640
91301	8	81	1268	13212	60398	\N	44.111558000000002	Ставропольский край, Курский район, Полтавский сельсовет, хутор Кировский, Комсомольская, 19А		0101000020E6100000D3BCE3141D5D4640B8CD5488470E4640
91288	8	81	1268	17524	60066	\N	44.015931000000002	Ставропольский край, Курский район, Кановский сельсовет, село Каново, Ленина, 32 В		0101000020E6100000DBC2F352B12946400DFFE9060A024640
91287	8	81	1268	57661	60465	\N	43.992450689828402	Ставропольский край, Курский район, Кановский сельсовет, хутор Зайцев, Школьная, 55	Россия, Ставропольский край, Курский район, село Зайцев	0101000020E610000053AEF02E17234640F6F065A208FF4540
91303	8	81	1268	18261	60347	\N	43.944487000000002	Ставропольский край, Курский район, хутор Дыдымкин, Тивилева, 3		0101000020E6100000A80018CFA06B4640A33F34F3E4F84540
91283	8	81	1268	17270	60502	\N	44.133125	Ставропольский край, Курский район, Курский сельсовет, село Добровольное, Миропольская, 35		0101000020E610000090A1630795424640D7A3703D0A114640
91296	8	81	1268	17967	60319	\N	43.863045	Ставропольский край, Курский район, Серноводский сельсовет, хутор Графский, Школьная, 5		0101000020E6100000F6CFD380415C4640F8FC304278EE4540
91299	8	81	1268	18077	59707	\N	43.695445999999997	Ставропольский край, Курский район, Галюгаевский сельсовет, станица Галюгаевская, Бражненко, 11		0101000020E6100000327381CB637746402711E15F04D94540
91306	8	81	1268	18419	60381	\N	44.039652491349699	Ставропольский край, Курский район, Мирненский сельсовет, поселок Бурунный, Кооперативная, 9	Россия, Ставропольский край, Курский район, село Бурунный	0101000020E6100000A662635E47864640499C155113054640
91295	8	81	1268	17876	60335	\N	43.857734999999998	Ставропольский край, Курский район, Серноводский сельсовет, хутор Бугулов, Школьная, 25		0101000020E61000001492CCEA1D56464039D1AE42CAED4540
91307	8	81	1268	18480	60445	\N	44.248821	Ставропольский край, Курский район, Мирненский сельсовет, хутор Березкин, Школьная, 8		0101000020E61000007CB8E4B8538846406DC7D45DD91F4640
91291	8	81	1268	17674	59598	\N	43.865105999999997	Ставропольский край, Курский район, Балтийский сельсовет, поселок Балтийский, Школьная, 1 А		0101000020E6100000465ED6C40229464064C91CCBBBEE4540
91304	8	81	1268	18353	60274	\N	44.011814000000001	Ставропольский край, Курский район, Полтавский сельсовет, поселок Ага-Батыр, Южная, 21		0101000020E6100000336FD575A868464046D1031F83014640
91275	8	81	745	16882	60320	\N	45.793061999999999	Ставропольский край, Красногвардейский район, Штурмовский сельсовет, поселок Штурм, Партизанская, 9		0101000020E6100000158E209562A34440A5D93C0E83E54640
91268	8	81	745	57673	60514	\N	45.9721978013797	Ставропольский край, Красногвардейский район, Родыковский сельсовет, хутор Средний, 60 лет Октября,61	Россия, Ставропольский край, Красногвардейский район, село Средний	0101000020E61000003E92921E86E84440499EEBFB70FC4640
91267	8	81	745	16473	59593	\N	45.946694000000001	Ставропольский край, Красногвардейский район, Родыковский сельсовет, село Родыки, Памяти 11, 5		0101000020E6100000F6CFD38041FA4440E3A8DC442DF94640
91265	8	81	745	5220	59591	\N	45.923856788553501	Ставропольский край, Красногвардейский район, Привольненский сельсовет, село Привольное, Шоссейная, 2а	Россия, Ставропольский край, Красногвардейский район, село Привольное	0101000020E6100000B7F0BC546CA64440209738F240F64640
91266	8	81	745	5220	59592	\N	45.920023	Ставропольский край, Красногвардейский район, Привольненский сельсовет, село Привольное, Пролетарская, 108		0101000020E61000004B5B5CE333A74440AE484C50C3F54640
91270	8	81	745	13159	59794	\N	45.815308999999999	Ставропольский край, Красногвардейский район, село Преградное, Красная, 78А		0101000020E6100000BB9C121093DE44403691990B5CE84640
91273	8	81	745	16786	60081	\N	45.976489999999998	Ставропольский край, Красногвардейский район, село Покровское, Шоссейная, 107		0101000020E610000021C9ACDEE1CA44407E6FD39FFDFC4640
91272	8	81	745	16773	59853	\N	45.715915000000003	Ставропольский край, Красногвардейский район, село Новомихайловское, Ленина, 74		0101000020E61000009161156F64BA4440A1DB4B1AA3DB4640
91271	8	81	745	16680	59993	\N	45.729360999999997	Ставропольский край, Красногвардейский район, Медвеженский сельсовет, поселок Медвеженский, Красногвардейская, 27		0101000020E610000003B68311FBCC44402AFD84B35BDD4640
91264	8	81	745	16261	59590	\N	45.627935000000001	Ставропольский край, Красногвардейский район, село Ладовская Балка, Мира, 22		0101000020E6100000792288F370B24440C381902C60D04640
91263	8	81	745	16261	59790	\N	45.627935000000001	Ставропольский край, Красногвардейский район, село Ладовская Балка, Кооперативная, 7		0101000020E6100000792288F370B24440C381902C60D04640
91262	8	81	745	12811	59589	\N	45.844943000000001	Ставропольский край, Красногвардейский район, село Красногвардейское, Ярмарочная, 11		0101000020E610000031444E5FCFC14440F8FD9B1727EC4640
91259	8	81	745	12811	59585	\N	45.844943000000001	Ставропольский край, Красногвардейский район, село Красногвардейское, Школьная, 12		0101000020E610000031444E5FCFC14440F8FD9B1727EC4640
91258	8	81	745	12811	59584	\N	45.844943000000001	Ставропольский край, Красногвардейский район, село Красногвардейское, Первомайская, 2		0101000020E610000031444E5FCFC14440F8FD9B1727EC4640
91257	8	81	745	12811	59793	\N	45.844943000000001	Ставропольский край, Красногвардейский район, село Красногвардейское, Микояна, 69		0101000020E610000031444E5FCFC14440F8FD9B1727EC4640
91260	8	81	745	12811	59788	\N	45.844943000000001	Ставропольский край, Красногвардейский район, село Красногвардейское, Ленина, 44		0101000020E610000031444E5FCFC14440F8FD9B1727EC4640
91261	8	81	745	12811	59588	\N	45.845179890066703	Ставропольский край, Красногвардейский район, село Красногвардейское, Красная, 262		0101000020E610000018EDF1423AC24440DC9DB5DB2EEC4640
91256	8	81	745	12811	60356	\N	45.844943000000001	Ставропольский край, Красногвардейский район, село Красногвардейское, Колпаковская, 42/1		0101000020E610000031444E5FCFC14440F8FD9B1727EC4640
91274	8	81	745	16871	59796	\N	45.857548999999999	Ставропольский край, Красногвардейский район, Коммунаровский сельсовет, поселок Коммунар, Мира, 1		0101000020E6100000B6D8EDB3CAA24440D7DB662AC4ED4640
91269	8	81	745	16578	59792	\N	45.812475999999997	Ставропольский край, Красногвардейский район, село Дмитриевское, Октябрьская, 27		0101000020E61000005D15A8C5E0F144407764AC36FFE74640
91226	8	81	7441	57687	60606	\N	44.6923587907444	Ставропольский край, Кочубеевский район, Мищенский сельсовет, село Цветное, Садовая, 20	Россия, Ставропольский край, Александровский район	0101000020E6100000F8FD9B17277C4540AF0B3F389F584640
91254	8	81	7441	57658	60463	\N	44.554070996755897	Ставропольский край, Кочубеевский район, Новодеревенский сельсовет, хутор Прогресс, Мира, 38	Россия, Ставропольский край, Невинномысск городской округ, село Прогресс	0101000020E61000004F0647C9ABED4440BD546CCCEB464640
91250	8	81	7441	57582	59603	\N	44.417853000000001	Ставропольский край, Кочубеевский район, станица Беломечетская, Красная, 19/а		0101000020E610000084674293C4F844408BC404357C354640
91208	8	81	7441	57581	59617	\N	44.682343086051603	Ставропольский край, Кочубеевский район, село Кочубеевское, Восточная, 63		0101000020E610000055F65D11FCE94440C8D3F20357574640
91215	8	81	7441	57606	60119	\N	44.577278	Ставропольский край, Кочубеевский район, с. Ивановское, ул. Калинина, д.117		0101000020E610000076E107E753EF4440A359D93EE4494640
91229	8	81	7441	57584	59618	\N	44.7513220777169	Ставропольский край, Кочубеевский район, Заветненский сельсовет, село Заветное, Почтовая, 1	Россия, Ставропольский край, Невинномысск городской округ, село Заветное	0101000020E61000005E64027E8DCE4440F661BD512B604640
91216	8	81	7441	57627	60300	\N	44.530805880325303	Ставропольский край, Кочубеевский район, Ивановский сельсовет, село Воронежское, пер. Школьный, 9	Россия, Ставропольский край, Невинномысск городской округ, село Воронежское	0101000020E6100000782634492CEB4440A2427573F1434640
91237	8	81	7441	57621	60260	\N	44.766752050604197	Ставропольский край, Кочубеевский район, Барсуковский сельсовет, станица Басуковская, Ленина, 43	Россия, Ставропольский край, Невинномысск городской округ, село Барсуковская	0101000020E6100000FF06EDD5C7E744404012F6ED24624640
91177	8	81	1221	12255	60009	\N	43.912875999999997	Ставропольский край, город-курорт Кисловодск, поселок Аликоновка, ул.Прямая, 4		0101000020E6100000C66AF3FFAA574540D2A6EA1ED9F44540
91150	8	81	1087	10961	60286	\N	44.038195000000002	Ставропольский край, Кировский район, п. Фазанный, Рабочая, 4		0101000020E61000006DAB59677CCB454074EFE192E3044640
91140	8	81	1087	10497	59569	\N	43.845384000000003	Ставропольский край, Кировский район, ст.Старопавловская, Ленинская, здание Дома культуры		0101000020E61000000A48FB1F60D14540E547FC8A35EC4540
91135	8	81	1087	57602	60007	\N	44.026249383323503	Ставропольский край, Кировский район, ст.Советская, пер.Шилиной, 21		0101000020E6100000E8A1B60DA3044640BF4692205C034640
91136	8	81	1087	57602	60212	\N	44.025630088700296	Ставропольский край, Кировский район, ст.Советская, Кирова, 9	Россия, Ставропольский край, Кировский район, село Советская	0101000020E61000007365506D70044640F3E505D847034640
91148	8	81	1087	10870	60325	\N	43.814522809026599	Ставропольский край, Кировский район, п.Прогресс, пер.Зеленый, 1	Россия, Ставропольский край, Кировский район, село Прогресс	0101000020E61000000D897B2C7DAA45407F6B274A42E84540
91138	8	81	1087	10398	59983	\N	43.991979000000001	Ставропольский край, Кировский район, Орловский сельсовет, село Орловка, Октябрьская, 31		0101000020E6100000AE9D280989E44540CEA8F92AF9FE4540
91133	8	81	1087	9803	\N	\N	43.959830212167098	"Ставропольский край, Кировский район, город Новопавловск, промзона, здание МОУ ""СОШ №33"""	Россия, Ставропольский край, Кировский район, Новопавловск	0101000020E6100000C8EA56CF49D145401EDC9DB5DBFA4540
91129	8	81	1087	9803	59780	\N	43.963611999999998	Ставропольский край, Кировский район, город Новопавловск, пл.Ленина, Дворец культуры им.С.М.Романько		0101000020E6100000FDBB3E73D6D145403E0455A357FB4540
91132	8	81	1087	9803	60062	\N	43.963611999999998	Ставропольский край, Кировский район, город Новопавловск, Центральная, 12		0101000020E6100000FDBB3E73D6D145403E0455A357FB4540
91131	8	81	1087	9803	60550	\N	43.9613185319038	Ставропольский край, Кировский район, город Новопавловск, Садовая, 109	Россия, Ставропольский край, Кировский район, Новопавловск	0101000020E6100000E99B340D8AD04540000341800CFB4540
91128	8	81	1087	9803	59787	\N	43.963611999999998	Ставропольский край, Кировский район, город Новопавловск, Октябрьская, 80		0101000020E6100000FDBB3E73D6D145403E0455A357FB4540
91134	8	81	1087	9803	59778	\N	43.963611999999998	Ставропольский край, Кировский район, город Новопавловск, Кирова, 33, фойе №2		0101000020E6100000FDBB3E73D6D145403E0455A357FB4540
91127	8	81	1087	9803	59778	\N	43.963611999999998	Ставропольский край, Кировский район, город Новопавловск, Кирова, 33		0101000020E6100000FDBB3E73D6D145403E0455A357FB4540
91143	8	81	1087	10547	59986	\N	43.880845000000001	"Ставропольский край, Кировский район, ст.Марьинская, ул.Победы, 54 ""Е"""		0101000020E610000006668522DDBD45402DEC6987BFF04540
91142	8	81	1087	10547	59986	\N	43.880845000000001	Ставропольский край, Кировский район, ст. Марьинская, Победы, 54 Ж		0101000020E610000006668522DDBD45402DEC6987BFF04540
91141	8	81	1087	10547	60065	\N	43.880845000000001	Ставропольский край, Кировский район, ст. Марьинская, Кутузова, Средняя школа		0101000020E610000006668522DDBD45402DEC6987BFF04540
91149	8	81	1087	10874	60068	\N	44.016345999999999	Ставропольский край, Кировский район, п.Комсомолец, Клубная, 22		0101000020E610000079AF5A99F0C74540D0B52FA017024640
91139	8	81	1087	10399	59568	\N	44.105893999999999	Ставропольский край, Кировский район, п.Коммаяк, Ленина, 31		0101000020E6100000EFC8586DFEED4540DB6B41EF8D0D4640
91144	8	81	1087	10685	60588	\N	43.904985000000003	Ставропольский край, Кировский район, ст.Зольская, Первомайская 5		0101000020E6100000BB97FBE428A645406F2F698CD6F34540
91145	8	81	1087	10685	60590	\N	43.904985000000003	Ставропольский край, Кировский район, ст.Зольская, ул.Октябрьская 1		0101000020E6100000BB97FBE428A645406F2F698CD6F34540
91146	8	81	1087	10685	60558	\N	43.904985000000003	Ставропольский край, Кировский район, ст.Зольская, 30 лет Победы 2		0101000020E6100000BB97FBE428A645406F2F698CD6F34540
91137	8	81	1087	10338	59982	\N	44.026400000000002	Ставропольский край, Кировский район, с.Горнозаводское, Калинина, 78		0101000020E61000005F984C158CF84540A54E401361034640
91116	8	81	965	57632	60350	\N	45.630902015344901	Ставропольский край, Ипатовский район, Лиманский сельсовет, аул Юсуп-Кулакский, Центральная, 62	Россия, Ставропольский край, Ипатовский район, село Юсуп-Кулакский	0101000020E610000063B7CF2A33974540917D9065C1D04640
91126	8	81	965	9738	59566	\N	45.899852722273899	Ставропольский край, Ипатовский район, Тахтинский сельсовет, село Тахта, Ленина, 115	Россия, Ставропольский край, Ипатовский район, село Тахта	0101000020E6100000522B4CDF6B1045408F1A13622EF34640
91110	8	81	965	9055	60593	\N	45.695120000000003	Ставропольский край, Ипатовский район, Золотаревский сельсовет, поселок Софиевский городок, Дорожный, 25		0101000020E6100000622EA9DA6E304540D46531B1F9D84640
91109	8	81	965	8963	60380	\N	45.671785	Ставропольский край, Ипатовский район, Золотаревский сельсовет, село Софиевка, Пролетарская, 44		0101000020E610000076FA415DA43C4540C078060DFDD54640
91125	8	81	965	9731	60051	\N	45.713982999999999	Ставропольский край, Ипатовский район, Советскорунный сельсовет, поселок Советское Руно, Центральная площадь, 2		0101000020E61000003A9160AA999D4540327381CB63DB4640
91107	8	81	965	8875	60402	\N	45.628286382559097	Ставропольский край, Ипатовский район, Золотаревский сельсовет, село Родники, Новая, 33	Россия, Ставропольский край, Ипатовский район, село Родники	0101000020E610000020D099B4A94A45407044F7AC6BD04640
91124	8	81	965	9642	60060	\N	46.056244	Ставропольский край, Ипатовский район, Первомайский сельсовет, село Первомайское, Попова, 37		0101000020E6100000BDE2A9471A1C4540514CDE0033074740
91123	8	81	965	9586	59779	\N	45.618774318511299	Ставропольский край, Ипатовский район, Октябрьский сельсовет, село Октябрьское, Калинина, 122/1	Россия, Ставропольский край, Ипатовский район, село Октябрьское	0101000020E6100000B9E177D32D6B4540BCCE86FC33CF4640
91120	8	81	965	57641	60372	\N	45.620026085378001	Ставропольский край, Ипатовский район, Мало-Барханчакский сельсовет, аул Нижний Барханчак, Буденного, 29Б	Россия, Ставропольский край, Ипатовский район, село Нижний Барханчак	0101000020E6100000904FC8CEDB7C4540B95510035DCF4640
91117	8	81	965	9309	60471	\N	45.647413999999998	Ставропольский край, Ипатовский район, Лиманский сельсовет, хутор Мелиорация, Шоссейная, 6		0101000020E6100000244223D8B87A45407C7C4276DED24640
91118	8	81	965	57634	60357	\N	45.587366130662197	Ставропольский край, Ипатовский район, Мало-Барханчакский сельсовет, аул Малый Барханчак, Центральная, 14	Россия, Ставропольский край, Ипатовский район, село Малый Барханчак	0101000020E6100000B01EF7ADD6894540246420CF2ECB4640
91115	8	81	965	9225	59565	\N	45.740797999999998	Ставропольский край, Ипатовский район, Лиманский сельсовет, село Лиман, Ленина, 71		0101000020E610000093567C43E18145409A780778D2DE4640
91113	8	81	965	9148	60489	\N	45.800657999999999	Ставропольский край, Ипатовский район, Леснодачненский сельсовет, село Лесная Дача, Мира, 10		0101000020E6100000C37FBA81021D4540F0A31AF67BE64640
91121	8	81	965	9488	60467	\N	45.572651999999998	Ставропольский край, Ипатовский район, Мало-Барханчакский сельсовет, село Крестьянское, Почтовая, 58		0101000020E61000004240BE840A76454097FE25A94CC94640
91112	8	81	965	9112	59563	\N	45.825723000000004	Ставропольский край, Ипатовский район, Красочный сельсовет, поселок Красочный, Центральная, 8		0101000020E6100000CE6E2D93E14245400B47904AB1E94640
91114	8	81	965	9214	60382	\N	45.821796999999997	Ставропольский край, Ипатовский район, Леснодачненский сельсовет, село Красная Поляна, Ленина, 55		0101000020E610000063EE5A423E0A4540B779E3A430E94640
91099	8	81	965	57640	\N	\N	45.761978988771297	Ставропольский край, Ипатовский район, город Ипатово, хутор Кочержинский	Россия, Ставропольский край, Ипатовский район, село Кочержинский	0101000020E6100000D027F224E97C4540909E228788E14640
91111	8	81	965	9060	59562	\N	45.799967000000002	Ставропольский край, Ипатовский район, Кевсалинский сельсовет, село Кевсала, Ленина, 165		0101000020E61000000A4CA7751B5845408B70935165E64640
91093	8	81	965	8050	60057	\N	45.716122629553603	Ставропольский край, Ипатовский район, Орджоникидзе, 76	Россия, Ставропольский край, Ипатовский район, Ипатово	0101000020E6100000BE16F4DE18724540EB7420EBA9DB4640
91092	8	81	965	8050	60057	\N	45.709811000000002	Ставропольский край, Ипатовский район, город Ипатово, Орджоникидзе, 116		0101000020E6100000821C9430D3724540A8AB3B16DBDA4640
91091	8	81	965	8050	59559	\N	45.709811000000002	Ставропольский край, Ипатовский район, город Ипатово, Ленина, 347		0101000020E6100000821C9430D3724540A8AB3B16DBDA4640
91098	8	81	965	8050	60123	\N	45.718046598526897	Ставропольский край, Ипатовский район, Заречная, 37	Россия, Ставропольский край, Ипатовский район, Ипатово	0101000020E61000004ED4D2DC0A714540D6FECEF6E8DB4640
91094	8	81	965	8050	59978	\N	45.726703868592701	Ставропольский край, Ипатовский район, Голубовского, 137	Россия, Ставропольский край, Ипатовский район, Ипатово	0101000020E61000002B14E97E4E714540AAEFFCA204DD4640
91090	8	81	965	8050	59978	\N	45.709811000000002	Ставропольский край, Ипатовский район, город Ипатово, Голубовского, 295		0101000020E6100000821C9430D3724540A8AB3B16DBDA4640
91108	8	81	965	8958	60324	\N	45.644181000000003	Ставропольский край, Ипатовский район, Золотаревский сельсовет, село Золотаревка, Юбилейная, 39		0101000020E6100000DDCF29C8CF44454030DAE38574D24640
91105	8	81	965	8817	60426	\N	45.864834999999999	Ставропольский край, Ипатовский район, Винодельненский сельсовет, поселок Дружный, Новая, 3		0101000020E6100000255D33F966734540D4B7CCE9B2EE4640
91106	8	81	965	8819	60310	\N	45.594400999999998	Ставропольский край, Ипатовский район, Добровольно-Васильевский сельсовет, село Добровольное, Ленина, 126		0101000020E61000002025766D6F334540D7DAFB5415CC4640
91104	8	81	965	8769	59776	\N	45.818255000000001	Ставропольский край, Ипатовский район, Винодельненский сельсовет, поселок Винодельненский, Советская, 1		0101000020E6100000834E081D74854540ED647094BCE84640
91119	8	81	965	9396	60495	\N	45.598875436419902	Ставропольский край, Ипатовский район, Мало-Барханчакский сельсовет, аул Верхний Барханчак, Гагарина, 38А	Россия, Ставропольский край, Ипатовский район, село Верхний Барханчак	0101000020E6100000130D52F0148445402DB29DEFA7CC4640
91103	8	81	965	8695	59567	\N	45.908661000000002	Ставропольский край, Ипатовский район, село Бурукшун, Музыкальный, 7		0101000020E6100000AB7AF99D264545404913EF004FF44640
91100	8	81	965	8596	59985	\N	45.865348325790798	Ставропольский край, Ипатовский район, Большевистский сельсовет, поселок Большевик, Ленина, 1		0101000020E6100000266E15C4402745405AD427B9C3EE4640
91102	8	81	965	8599	60272	\N	45.971384999999998	Ставропольский край, Ипатовский район, село Большая Джалга, Ленина, 55		0101000020E6100000459C4EB2D55745409869FB5756FC4640
91101	8	81	965	8599	60058	\N	45.971384999999998	Ставропольский край, Ипатовский район, село Большая Джалга, Базарная, 6		0101000020E6100000459C4EB2D55745409869FB5756FC4640
91065	8	81	744	6880	60267	\N	45.343431000000002	Ставропольский край, Изобильненский район, хутор Широбоков, Победы, 35		0101000020E61000009E42AED4B3E244405FB7088CF5AB4640
91077	8	81	744	7502	60271	\N	45.150081999999998	Ставропольский край, Изобильненский район, Каменнобродский сельсовет, станица Филимоновская, Пушкина, 9		0101000020E61000004012F6ED24D44440F0DB10E335934640
91066	8	81	744	6952	59967	\N	45.460951547113702	Ставропольский край, Изобильненский район, село Тищенское, Мира, 14	Россия, Ставропольский край, Изобильненский район, село Тищенское	0101000020E61000008884EFFD0DD644404D83A27900BB4640
91080	8	81	744	57665	60500	\N	45.264627069241897	Ставропольский край, Изобильненский район, Староизобильненский сельсовет, хутор Сухой, Тюльпина, 27-А	Россия, Ставропольский край, Изобильненский район, село Сухой	0101000020E61000002F698CD651D74440BD512B4CDFA14640
91078	8	81	744	7507	60594	\N	45.294859355089301	Ставропольский край, Изобильненский район, станица Староизобильная, Мира, 60	Россия, Ставропольский край, Изобильненский район, село Староизобильная	0101000020E610000054FCDF1115D8444034F790F0BDA54640
91081	8	81	744	57619	60231	\N	45.3187591239139	Ставропольский край, Изобильненский район, хутор Спорный, Мира, 92	Россия, Ставропольский край, Изобильненский район, село Спорный	0101000020E61000005393E00D69E2444020274C18CDA84640
91058	8	81	744	6407	60053	\N	45.307690000000001	Ставропольский край, Изобильненский район, поселок Солнечнодольск, б-р Школьный, 2		0101000020E61000006D718DCF64C1444033A7CB6262A74640
91056	8	81	744	6407	59555	\N	45.307690000000001	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Школьный б-р, 4		0101000020E61000006D718DCF64C1444033A7CB6262A74640
91055	8	81	744	6407	59555	\N	45.297161099675499	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Школьный б-р, 6	Россия, Ставропольский край, Изобильненский район, поселок городского типа Солнечнодольск	0101000020E61000008509A359D9BE4440C652245F09A64640
91060	8	81	744	6407	59557	\N	45.307690000000001	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Молодежная, 3		0101000020E61000006D718DCF64C1444033A7CB6262A74640
91059	8	81	744	6407	59557	\N	45.307690000000001	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Молодежная, 4		0101000020E61000006D718DCF64C1444033A7CB6262A74640
91057	8	81	744	6407	59557	\N	45.307690000000001	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Молодежная, 6		0101000020E61000006D718DCF64C1444033A7CB6262A74640
91079	8	81	744	7563	60488	\N	45.268610000000002	Ставропольский край, Изобильненский район, Староизобильненский сельсовет, хутор Смыков, Центральная, 43		0101000020E6100000E63BF88903C6444075B0FECF61A24640
91062	8	81	744	6700	60054	\N	45.272708000000002	Ставропольский край, Изобильненский район, поселок Рыздвяный, Южная, 19		0101000020E610000041649126DEEB4440C5AD8218E8A24640
91061	8	81	744	6700	59968	\N	45.272708000000002	Ставропольский край, Изобильненский район, поселок Рыздвяный, Советская, 21		0101000020E610000041649126DEEB4440C5AD8218E8A24640
91063	8	81	744	6700	59973	\N	45.268708063637497	Ставропольский край, Изобильненский район, поселок Рыздвяный, Восточная, 4	Россия, Ставропольский край, Изобильненский район, поселок городского типа Рыздвяный	0101000020E6100000422619390BEB44403716140665A24640
91083	8	81	744	7681	59558	\N	45.218530547742802	Ставропольский край, Изобильненский район, станица Рождественская, Ленина, 174	Россия, Ставропольский край, Изобильненский район, село Рождественская	0101000020E6100000782634492CE94440C214E5D2F89B4640
91082	8	81	744	7681	59558	\N	45.217727248182101	Ставропольский край, Изобильненский район, станица Рождественская, Ленина, 125	Россия, Ставропольский край, Изобильненский район, село Рождественская	0101000020E610000059897956D2E84440643A747ADE9B4640
91068	8	81	744	7027	60289	\N	45.523097999999997	Ставропольский край, Изобильненский район, село Птичье, Кошевого, 1-Б		0101000020E6100000C30FCEA78EDB44402F4D11E0F4C24640
91067	8	81	744	7027	60056	\N	45.523097999999997	Ставропольский край, Изобильненский район, село Птичье, К. Маркса, 31		0101000020E6100000C30FCEA78EDB44402F4D11E0F4C24640
91084	8	81	744	7762	59775	\N	45.275378000000003	Ставропольский край, Изобильненский район, село Подлужное, Калинина, 3		0101000020E610000018213CDA38FC4440DA0418963FA34640
91070	8	81	744	7128	59770	\N	45.442060479653101	Ставропольский край, Изобильненский район, поселок Передовой, Октября, 55	Россия, Ставропольский край, Изобильненский район, село Передовой	0101000020E610000002840F255AC44440546F0D6C95B84640
91072	8	81	744	7234	60055	\N	45.363754999999998	Ставропольский край, Изобильненский район, станица Новотроицкая, Шоссейная, 8		0101000020E610000054C8957A16C44440D4601A868FAE4640
91073	8	81	744	7234	59773	\N	45.363754999999998	Ставропольский край, Изобильненский район, станица Новотроицкая, Первомайская, 164		0101000020E610000054C8957A16C44440D4601A868FAE4640
91074	8	81	744	7234	59777	\N	45.363754999999998	Ставропольский край, Изобильненский район, станица Новотроицкая, ул. Мещерякова, д. 120		0101000020E610000054C8957A16C44440D4601A868FAE4640
91075	8	81	744	7234	60273	\N	45.363754999999998	Ставропольский край, Изобильненский район, станица Новотроицкая, Ленина, 306		0101000020E610000054C8957A16C44440D4601A868FAE4640
91064	8	81	744	6877	60269	\N	45.419840999999998	Ставропольский край, Изобильненский район, поселок Новоизобильный, Школьная, 18		0101000020E6100000B804E09F52DB44408D429259BDB54640
90945	8	81	5	270	60299	\N	44.1170883777543	Ставропольский край, Георгиевский район, поселок Нижнезольский, Школьная, 24	Россия, Ставропольский край, Георгиевский район, село Нижнезольский	0101000020E61000005D4E098849D24540856055BDFC0E4640
91089	8	81	744	57682	60561	\N	45.3357384069133	Ставропольский край, Изобильненский район, Московский сельсовет, село Найденовское, Ленина, 1	Россия, Ставропольский край, Изобильненский район, село Найденовка	0101000020E6100000B686527B11E7444021037976F9AA4640
91086	8	81	744	7820	59974	\N	45.287788999999997	Ставропольский край, Изобильненский район, село Московское, Мира, 51		0101000020E610000027A3CA30EEF6444003931B45D6A44640
91085	8	81	744	7820	60083	\N	45.287788999999997	Ставропольский край, Изобильненский район, село Московское, Ленина, 175		0101000020E610000027A3CA30EEF6444003931B45D6A44640
91087	8	81	744	7820	60470	\N	45.287788999999997	Ставропольский край, Изобильненский район, село Московское, Гоголя, 73		0101000020E610000027A3CA30EEF6444003931B45D6A44640
91069	8	81	744	7091	59702	\N	45.297370000000001	Ставропольский край, Изобильненский район, станица Баклановская, Красная, 135		0101000020E6100000174A26A776FC4440E0675C3810A64640
91076	8	81	744	7415	60001	\N	45.183577999999997	Ставропольский край, Изобильненский район, станица Каменнобродская, Мира, 13		0101000020E6100000357BA01518C24440EE21E17B7F974640
91038	8	81	744	5219	\N	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, поселок Газопровода, 5-Б		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91049	8	81	744	5219	60555	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, ул. Южная, 97А		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91034	8	81	744	5219	59550	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Электронная, 8		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91039	8	81	744	5219	60044	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Школьная, 1		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91040	8	81	744	5219	60048	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Промышленная, 118/3		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91052	8	81	744	5219	60575	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Привокзальная площадь, здание Ж/Д вокзала		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91048	8	81	744	5219	59554	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Новотроицкое шоссе, 1		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91044	8	81	744	5219	59552	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Ленина, 63		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91043	8	81	744	5219	59552	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, ул. Ленина, д. 16		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91042	8	81	744	5219	59552	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Ленина, 61		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91041	8	81	744	5219	59552	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Ленина, 16		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91037	8	81	744	5219	60047	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Крупской, 2-А		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91054	8	81	744	5219	59969	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Красноармейская, 69		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91036	8	81	744	5219	60059	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, ул. Красная, 6		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91035	8	81	744	5219	60059	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Красная, 6		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91045	8	81	744	5219	60034	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Колхозная, 2-А		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91047	8	81	744	5219	59772	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Заводская, 1		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91050	8	81	744	5219	59771	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Доватора, 388		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91033	8	81	744	5219	59771	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Доватора, 1		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91046	8	81	744	5219	60052	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, Бонивура, 1		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91051	8	81	744	5219	59553	\N	45.370651000000002	Ставропольский край, Изобильненский район, город Изобильный, 50 лет Октября, 29		0101000020E6100000505436ACA9DA4440679DF17D71AF4640
91071	8	81	744	7216	60406	\N	45.553223000000003	Ставропольский край, Изобильненский район, станица Гаевская, Красная, 32-б		0101000020E6100000DC9E20B1DDBD44409032E202D0C64640
91088	8	81	744	57663	60476	\N	45.353098364034501	Ставропольский край, Изобильненский район, хутор Беляев, Пролетарская, 107	Россия, Ставропольский край, Изобильненский район, село Беляев	0101000020E6100000340F60915FED44403A24B55032AD4640
91026	8	81	686	4767	60570	\N	44.097233000000003	Ставропольский край, город-курорт Железноводск,п. Иноземцево, 8 марта, 5А		0101000020E610000078D2C265158C4540C68B8521720C4640
90968	8	81	157	1644	59948	\N	45.332476	Тугулук, Гагарина, 10		0101000020E6100000CE397826341F45403A5AD5928EAA4640
90965	8	81	157	1401	59941	\N	45.089132999999997	Ставропольский край, Грачевский район, Старомарьевский сельсовет, село Старомарьевка, Свердлова, 65		0101000020E6100000D6ABC8E8801E454047FFCBB5688B4640
90964	8	81	157	1401	60377	\N	45.093721870035601	Ставропольский край, Грачевский район, Старомарьевский сельсовет, село Старомарьевка, Красная, 50	Россия, Ставропольский край, Грачевский район, село Старомарьевка	0101000020E610000067B8019F1F1E454036751E15FF8B4640
90966	8	81	157	1401	60303	\N	45.092112188258902	Ставропольский край, Грачевский район, Старомарьевский сельсовет, село Старомарьевка, Войкова, 95	Россия, Ставропольский край, Грачевский район, село Старомарьевка	0101000020E610000089450C3B8C1D4540DAC87553CA8B4640
90961	8	81	157	1254	60061	\N	45.122455000000002	Ставропольский край, Грачевский район, Спицевский сельсовет, село Спицевка, пл.Революции, 16		0101000020E61000006C79E57ADB404540A81DFE9AAC8F4640
90959	8	81	157	1127	59943	\N	44.958104545387798	Ставропольский край, Грачевский район, Сергиевский сельсовет, село Сергиевское, Карла Маркса, 11	Россия, Ставропольский край, Грачевский район, село Сергиевское	0101000020E6100000BDC458A65F5A45402A91442FA37A4640
90960	8	81	157	57671	60512	\N	45.015434890625798	Ставропольский край, Грачевский район, Сергиевский сельсовет, хутор Октябрь, Садовая, 31а	Россия, Ставропольский край, Грачевский район, село Октябрь	0101000020E610000003D0285DFA6745405C1B2AC6F9814640
90963	8	81	157	1358	60420	\N	45.111038999999998	Ставропольский край, Грачевский район, Спицевский сельсовет, поселок Новоспицевский, Центральная, 8		0101000020E6100000102384471B5345404FCAA486368E4640
90955	8	81	157	891	60479	\N	45.074922000000001	Ставропольский край, Грачевский район, Красный сельсовет, хутор Нагорный, Октябрьская		0101000020E6100000C85C19541B3445401EE0490B97894640
90956	8	81	157	941	59764	\N	45.364052999999998	Ставропольский край, Грачевский район, Кугультинский сельсовет, село Кугульта, Советская, 55		0101000020E610000007CF8426893145405E81E84999AE4640
90957	8	81	157	941	59781	\N	45.364052999999998	Ставропольский край, Грачевский район, Кугультинский сельсовет, село Кугульта, Красная, 113		0101000020E610000007CF8426893145405E81E84999AE4640
90967	8	81	157	1585	60416	\N	45.156851000000003	Ставропольский край, Грачевский район, Старомарьевский сельсовет, хутор Кизилов, Центральная, 1		0101000020E61000007AABAE43351B454026AC8DB113944640
90950	8	81	157	569	59688	\N	45.202601000000001	Ставропольский край, Грачевский район, Грачевский сельсовет, село Грачевка, Шоссейная, 8		0101000020E6100000AF3E1EFAEE34454086915ED4EE994640
90952	8	81	157	569	59944	\N	45.202601000000001	"Ставропольский край, Грачевский район, Грачевский сельсовет, село Грачевка, Ставропольская, 75""Б"""		0101000020E6100000AF3E1EFAEE34454086915ED4EE994640
90951	8	81	157	569	60036	\N	45.202601000000001	Ставропольский край, Грачевский район, Грачевский сельсовет, село Грачевка, Советская, 13		0101000020E6100000AF3E1EFAEE34454086915ED4EE994640
90958	8	81	157	1055	59547	\N	45.346097	Ставропольский край, Грачевский район, Кугультинский сельсовет, поселок Верхняя Кугульта, Ленина, 17		0101000020E6100000B62E35423F314540321F10E84CAC4640
90949	8	81	157	451	59546	\N	45.021481000000001	Ставропольский край, Грачевский район, село Бешпагир, Ленина, 59А		0101000020E6100000CCCF0D4DD92F4540213EB0E3BF824640
90948	8	81	157	451	59546	\N	45.021481000000001	Бешпагир, Ленина, 10в		0101000020E6100000CCCF0D4DD92F4540213EB0E3BF824640
90962	8	81	157	57672	60513	\N	45.051131388727399	х.Базовый, Красная, 15	Россия, Ставропольский край, Грачевский район, село Базовый	0101000020E6100000E449D235933B4540E867EA758B864640
90946	8	81	5	315	59545	\N	44.161507999999998	Ставропольский край, Георгиевский район, поселок Шаумянский, Советская, 1		0101000020E6100000D1950854FFC445406C054D4BAC144640
90944	8	81	5	186	59940	\N	44.152234	Ставропольский край, Георгиевский район, станица Урухская, Ленина, 20		0101000020E610000084BC1E4C8AD545406DAB59677C134640
90914	8	81	5	31219	\N	\N	44.195810000000002	Ставропольский край, Георгиевский район, поселок Терский	Россия, Ставропольский край, Георгиевский район, село Терский	0101000020E6100000917F66101FA84540691D554D10194640
90935	8	81	5	32202	60482	\N	43.979039	Ставропольский край, Георгиевский район, поселок Приэтокский, Центральная, 2		0101000020E61000005F28603B18B745401841632651FD4540
90942	8	81	5	8	59686	\N	44.200082000000002	Ставропольский край, Георгиевский район, станица Подгорная, Ленина, 51		0101000020E6100000E63BF88903B64540574277499C194640
90941	8	81	5	8	60045	\N	44.200082000000002	Ставропольский край, Георгиевский район, станица Подгорная, Ленина, 66		0101000020E6100000E63BF88903B64540574277499C194640
90923	8	81	5	31674	59757	\N	44.389297999999997	Ставропольский край, Георгиевский район, поселок Падинский, 40 лет Победы, 17		0101000020E6100000C092AB58FCA44540F8325184D4314640
90939	8	81	5	32365	59934	\N	44.245282000000003	Ставропольский край, Георгиевский район, село Обильное, Советская, 46		0101000020E6100000D3DB9F8B86C6454014268C66651F4640
90940	8	81	5	32365	59543	\N	44.245282000000003	Ставропольский край, Георгиевский район, село Обильное, Ленина, 75		0101000020E6100000D3DB9F8B86C6454014268C66651F4640
90936	8	81	5	57628	60301	\N	44.153477091890998	Ставропольский край, Георгиевский район, поселок Новый, 60 лет СССР, 14	Россия, Ставропольский край, Георгиевский район, село Новый	0101000020E6100000BF4351A04FB8454017D86322A5134640
90943	8	81	5	124	59984	\N	44.457479999999997	Ставропольский край, Георгиевский район, поселок Новоульяновский, Кооперативная, 1		0101000020E61000006118B0E42AB245407B4963B48E3A4640
90947	8	81	5	389	60414	\N	44.194265999999999	Ставропольский край, Георгиевский район, хутор Новомихайловский, Продольная, 34		0101000020E6100000E34F5436ACC94540C45C52B5DD184640
90937	8	81	5	32283	59542	\N	44.258254000000001	Ставропольский край, Георгиевский район, село Новозаведенное, Школьная, 31 а		0101000020E61000006ADAC534D3D14540D50792770E214640
90938	8	81	5	32283	59938	\N	44.258254000000001	Ставропольский край, Георгиевский район, село Новозаведенное, Кооперативная, 3 г		0101000020E61000006ADAC534D3D14540D50792770E214640
90826	8	81	1234	12647	59532	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, ул.Первомайская, 22		0101000020E61000005323F433F5B64540E256410C748D4640
90932	8	81	5	31885	60035	\N	44.113081623556901	Ставропольский край, Георгиевский район, станица Незлобная, Юбилейная, 141	Россия, Ставропольский край, Георгиевский район, село Незлобная	0101000020E610000061A8C30AB7B6454015E29178790E4640
90929	8	81	5	31885	59762	\N	44.112586999999998	Ставропольский край, Георгиевский район, станица Незлобная, Школьная, 18		0101000020E6100000FA0D130D52B24540357A3540690E4640
90927	8	81	5	31885	59762	\N	44.112586999999998	Ставропольский край, Георгиевский район, станица Незлобная, Школьная, 20		0101000020E6100000FA0D130D52B24540357A3540690E4640
90933	8	81	5	31885	59965	\N	44.112586999999998	Ставропольский край, Георгиевский район, станица Незлобная, Упорная, 43		0101000020E6100000FA0D130D52B24540357A3540690E4640
90931	8	81	5	31885	59541	\N	44.112586999999998	Ставропольский край, Георгиевский район, станица Незлобная, Степная, 229		0101000020E6100000FA0D130D52B24540357A3540690E4640
90934	8	81	5	31885	59937	\N	44.112586999999998	Ставропольский край, Георгиевский район, станица Незлобная, Незлобненская-2, 3а		0101000020E6100000FA0D130D52B24540357A3540690E4640
90930	8	81	5	31885	59564	\N	44.112586999999998	Ставропольский край, Георгиевский район, станица Незлобная, Ленина, 224		0101000020E6100000FA0D130D52B24540357A3540690E4640
90925	8	81	5	31748	59540	\N	44.101725000000002	Ставропольский край, Георгиевский район, станица Лысогорская, Школьная, 73		0101000020E61000006D3CD862B7A34540C2172653050D4640
90924	8	81	5	31748	59540	\N	44.101725000000002	Ставропольский край, Георгиевский район, станица Лысогорская, Школьная, 114		0101000020E61000006D3CD862B7A34540C2172653050D4640
90926	8	81	5	31748	59759	\N	44.101725000000002	Ставропольский край, Георгиевский район, станица Лысогорская, Ленина, 190		0101000020E61000006D3CD862B7A34540C2172653050D4640
90918	8	81	5	31425	59758	\N	44.171219999999998	Ставропольский край, Георгиевский район, село Краснокумское, Юбилейная, 4		0101000020E6100000BD70E7C248BD4540E7357689EA154640
90919	8	81	5	31425	59538	\N	44.171219999999998	Ставропольский край, Георгиевский район, село Краснокумское, Пионерская, 23		0101000020E6100000BD70E7C248BD4540E7357689EA154640
90920	8	81	5	31425	59928	\N	44.171219999999998	Ставропольский край, Георгиевский район, село Краснокумское, Курченко, 1		0101000020E6100000BD70E7C248BD4540E7357689EA154640
90922	8	81	5	31425	59544	\N	44.171219999999998	Ставропольский край, Георгиевский район, село Краснокумское, Кирова, 1/2		0101000020E6100000BD70E7C248BD4540E7357689EA154640
90921	8	81	5	31425	59544	\N	44.176877329087702	Ставропольский край, Георгиевский район, село Краснокумское, Кирова, 16	Россия, Ставропольский край, Георгиевский район, село Краснокумское	0101000020E6100000D829560DC2BE45401135D1E7A3164640
90916	8	81	5	16014	60567	\N	44.109848999999997	Ставропольский край, Георгиевский район, станица Георгиевская, Кооперативный, 9А		0101000020E610000082AB3C81B0BB4540C83F33880F0E4640
90917	8	81	5	16014	60043	\N	44.109848999999997	Ставропольский край, Георгиевский район, станица Георгиевская, Выгонная, 85		0101000020E610000082AB3C81B0BB4540C83F33880F0E4640
90915	8	81	5	31313	60297	\N	44.519823000000002	Ставропольский край, Георгиевский район, поселок Балковский, Новая, 18		0101000020E610000027309DD66DC04540B45A608F89424640
90913	8	81	5	31121	59539	\N	44.222405000000002	Ставропольский край, Георгиевский район, станица Александрийская, Комсомольский, 13		0101000020E610000048FE60E0B9AB4540C3BB5CC4771C4640
90912	8	81	5	31121	59539	\N	44.222405000000002	Ставропольский край, Георгиевский район, станица Александрийская, Комсомольский, 11		0101000020E610000048FE60E0B9AB4540C3BB5CC4771C4640
90911	8	81	5	31121	59769	\N	44.222405000000002	Ставропольский край, Георгиевский район, станица Александрийская, Гагарина, 308		0101000020E610000048FE60E0B9AB4540C3BB5CC4771C4640
90882	8	81	1382	29654	60480	\N	44.677739996175198	Ставропольский край, Буденновский район, Преображенский сельсовет, поселок Херсонский, Октябрьская, 107	Россия, Ставропольский край, Буденновский район, село Херсонский	0101000020E61000005DA45016BEF6454074982F2FC0564640
90887	8	81	1382	29925	60293	\N	45.005220000000001	Ставропольский край, Буденновский район, село Толстово-Васюковское, Школьная, 2а		0101000020E6100000E9818FC18A1346407FA4880CAB804640
90884	8	81	1382	15148	60544	\N	44.585752999999997	Ставропольский край, Буденновский район, Стародубский сельсовет, поселок Терек, Школьная, 5		0101000020E61000007E198C118904464056444DF4F94A4640
90881	8	81	1382	16978	60568	\N	44.683762000000002	Ставропольский край, Буденновский район, Преображенский сельсовет, село Преображенское, Артезианская, 19		0101000020E610000020B8CA1308FD4540B01F628385574640
90880	8	81	1382	15101	\N	\N	44.7403329823508	Ставропольский край, Буденновский район, село Прасковея, корпус сельхозтехникума, 1		0101000020E6100000D1E638B7091B46402593533BC35E4640
90879	8	81	1382	15101	60589	\N	44.741553000000003	Ставропольский край, Буденновский район, село Прасковея, Ленина, 33А		0101000020E61000000D1AFA27B81A464017A06D35EB5E4640
90877	8	81	1382	15101	59751	\N	44.741553000000003	Ставропольский край, Буденновский район, село Прасковея, Дзержинского, 66		0101000020E61000000D1AFA27B81A464017A06D35EB5E4640
90876	8	81	1382	15101	59751	\N	44.741553000000003	Ставропольский край, Буденновский район, село Прасковея, Дзержинского, 92		0101000020E61000000D1AFA27B81A464017A06D35EB5E4640
90878	8	81	1382	15101	60563	\N	44.741553000000003	Ставропольский край, Буденновский район, село Прасковея, Борцов Революции, 18		0101000020E61000000D1AFA27B81A464017A06D35EB5E4640
90889	8	81	1382	29976	60478	\N	44.684376999999998	Ставропольский край, Буденновский район, Томузловский сельсовет, поселок Правобережный, Октябрьская, 91		0101000020E6100000BCEA01F390ED45403A9160AA99574640
90885	8	81	1382	29836	60384	\N	44.628177000000001	Ставропольский край, Буденновский район, Стародубский сельсовет, поселок Плаксейка, Железнодорожная, 1		0101000020E6100000F3599E0777034640B98C9B1A68504640
90869	8	81	1382	57591	\N	\N	44.710877109554801	Ставропольский край, Буденновский район, Новожизненский сельсовет, контора бригады, 3	Россия, Ставропольский край, Буденновский район	0101000020E6100000EE409DF2E8264640433D7D04FE5A4640
90873	8	81	1382	57591	60199	\N	45.047035999999999	Ставропольский край, Буденновский район, Покойненский сельсовет, Советская, 81		0101000020E6100000CEC7B5A162FC444009DE904605864640
90866	8	81	1382	57591	59756	\N	44.796157999999998	Ставропольский край, Буденновский район, Искровский сельсовет, Почтовая, 14		0101000020E61000000D8AE6012C10464071395E81E8654640
90868	8	81	1382	57591	59997	\N	44.796157999999998	Ставропольский край, Буденновский район, Новожизненский сельсовет, Кировская, 18г		0101000020E61000000D8AE6012C10464071395E81E8654640
90865	8	81	1382	60666	75526	\N	44.564521270027903	Ставропольский край, Буденновский район, Архиповский сельсовет, Советская, 147	Россия, Ставропольский край, Буденновский район, село Архиповское	0101000020E6100000147651F4C00B4640DE73603942484640
90863	8	81	1382	45588	59749	\N	44.618516	село Архангельское, Советская, 71		0101000020E61000000B0C59DDEA0B4640C00644882B4F4640
90864	8	81	1382	45588	60266	\N	44.618516	село Архангельское, Румянцева, 254		0101000020E61000000B0C59DDEA0B4640C00644882B4F4640
90875	8	81	7439	57611	60396	\N	44.784764679017499	Ставропольский край, Буденновский район, Покойненский сельсовет, Совхозная, 55		0101000020E6100000D97745F0BF134640D105F52D73644640
90874	8	81	7439	57611	60174	\N	44.785742684254203	Ставропольский край, Буденновский район, Покойненский сельсовет, Советская, 130	Россия, Ставропольский край, Буденновск городской округ	0101000020E6100000EDD45C6E30144640CC07043A93644640
90888	8	81	7439	57611	60181	\N	44.7995924652516	Ставропольский край, Буденновский район, Томузловский сельсовет, Ленина, 121	Россия, Ставропольский край, Буденновск городской округ	0101000020E6100000B2D5E594801446405512D90759664640
90867	8	81	7439	57611	60607	\N	44.798455234322802	Ставропольский край, Буденновский район, Краснооктябрьский сельсовет, Виноградная, 6А	Россия, Ставропольский край, Буденновск городской округ	0101000020E610000025766D6FB7144640F12900C633664640
90852	8	81	7439	57577	\N	\N	44.795314602823701	город Буденновск, микрорайон 1, МОУ СОШ № 2		0101000020E6100000A96C5853591246405682C5E1CC654640
90846	8	81	7439	57577	59939	\N	44.800081343484401	город Буденновск, микрорайон 8, 33-А		0101000020E610000016855D143D1446405393E00D69664640
90843	8	81	1234	57624	60284	\N	45.322602869739299	Ставропольский край, Благодарненский район, аул Эдельбай, ул.Манкаева, 70	Россия, Ставропольский край, Благодарненский район, село Эдельбай	0101000020E61000006ADB300A82F14540B64B1B0E4BA94640
90842	8	81	1234	27850	60348	\N	45.093237999999999	Ставропольский край, Благодарненский район, село Шишкино, ул.Дьякова, 55		0101000020E610000022FC8BA0319545404A5F0839EF8B4640
90841	8	81	1234	27844	59962	\N	44.944383999999999	Ставропольский край, Благодарненский район, Ставропольский сельсовет, поселок Ставропольский, ул.Советская, 3		0101000020E6100000B58CD47B2AC74540CE6E2D93E1784640
90840	8	81	1234	27771	59530	\N	45.073056999999999	Ставропольский край, Благодарненский район, село Спасское, ул.Красная, 171		0101000020E61000009FE5797077D8454037DF88EE59894640
90838	8	81	1234	15588	60541	\N	45.003646000000003	Ставропольский край, Благодарненский район, село Сотниковское, Советская, 290/1		0101000020E6100000E38920CEC3E345407061DD7877804640
90839	8	81	1234	15588	59744	\N	45.007908407363097	Ставропольский край, Благодарненский район, село Сотниковское, ул.Красная, 162	Россия, Ставропольский край, Благодарненский район, село Сотниковское	0101000020E6100000E197FA7953E345403AB01C2103814640
90837	8	81	1234	27662	60321	\N	45.284751999999997	Ставропольский край, Благодарненский район, село Мирное, ул.Красная, 46 б		0101000020E610000029594E42E9D745403CBCE7C072A44640
90835	8	81	1234	27571	60026	\N	45.251570000000001	Ставропольский край, Благодарненский район, Каменнобалковский сельсовет, село Каменная Балка, ул.Школьная, 22		0101000020E610000038DBDC989EAC4540CE531D7233A04640
90834	8	81	1234	27486	59915	\N	45.008419000000004	Ставропольский край, Благодарненский район, село Елизаветинское, ул.Ленина, 136		0101000020E610000073672618CEAD454020D5B0DF13814640
90833	8	81	1234	27431	60027	\N	45.059249000000001	Ставропольский край, Благодарненский район, село Бурлацкое, ул.Красная, 91		0101000020E610000038A27BD635D245400DA9A27895874640
90832	8	81	1234	57638	60365	\N	45.0164704265406	Ставропольский край, Благодарненский район, хутор Большевик, ул.Зеленая, 44	Россия, Ставропольский край, Благодарненский район, село Большевик	0101000020E6100000E57ADB4C859A4540BCAE5FB01B824640
90824	8	81	1234	12647	59529	\N	45.109358436852403	Ставропольский край, Благодарненский район, город Благодарный, пл.Строителей, 2	Россия, Ставропольский край, Благодарненский район, Благодарный	0101000020E6100000429605137FB645402AC76471FF8D4640
90819	8	81	1234	12647	59528	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, пер.Школьный, 5 а		0101000020E61000005323F433F5B64540E256410C748D4640
90825	8	81	1234	12647	59531	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, пер.Кочубея, 25		0101000020E61000005323F433F5B64540E256410C748D4640
90822	8	81	1234	12647	59527	\N	45.1024292238166	Ставропольский край, Благодарненский район, город Благодарный, ул.Советская, 209	Россия, Ставропольский край, Благодарненский район, Благодарный	0101000020E6100000CEFFAB8E1CB74540BC94BA641C8D4640
90820	8	81	1234	12647	59527	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, ул.Советская, 396		0101000020E61000005323F433F5B64540E256410C748D4640
90828	8	81	1234	12647	59532	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, ул.Первомайская, 1		0101000020E61000005323F433F5B64540E256410C748D4640
91845	8	81	1234	12647	60573	\N	45.103158654536401	Ставропольский край, Благодарненский район, г. Благодарный,  ул. Московская, 250	Россия, Ставропольский край, Благодарненский район, Благодарный	0101000020E6100000A41B615111B74540DFA46950348D4640
90823	8	81	1234	12647	60573	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, ул.Московская, 112		0101000020E61000005323F433F5B64540E256410C748D4640
90827	8	81	1234	12647	59918	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, ул.Ленина, 251		0101000020E61000005323F433F5B64540E256410C748D4640
90821	8	81	1234	12647	60029	\N	45.105103999999997	Ставропольский край, Благодарненский район, город Благодарный, ул.Комсомольская, 16		0101000020E61000005323F433F5B64540E256410C748D4640
90836	8	81	1234	27578	60268	\N	45.174073	Ставропольский край, Благодарненский район, Красноключевский сельсовет, хутор Алтухов, ул.Чапаева, 33		0101000020E61000005E13D21A839E4540ED0E290648964640
90831	8	81	1234	27378	59743	\N	45.205280999999999	Ставропольский край, Благодарненский район, село Алексеевское, ул.Ленина, 117		0101000020E6100000B66455849BCA4540BEBED6A5469A4640
90829	8	81	1234	15508	59914	\N	45.084761999999998	Ставропольский край, Благодарненский район, Александрийский сельсовет, село Александрия, ул.Пролетарская, 121/1		0101000020E6100000FFCC203EB09F4540C6F8307BD98A4640
90830	8	81	1234	15508	60560	\N	45.084761999999998	Ставропольский край, Благодарненский район, Александрийский сельсовет, село Александрия, ул.Красная, 240		0101000020E6100000FFCC203EB09F4540C6F8307BD98A4640
90817	8	81	1797	26751	60344	\N	45.347034999999998	Ставропольский край, Арзгирский район, Чограйский сельсовет, поселок Чограйский, переулок Сквозной, 2		0101000020E610000002F390291F4A46409FC893A46BAC4640
90816	8	81	1797	26661	59695	\N	45.214444	Ставропольский край, Арзгирский район, село Серафимовское, Ленина, 46А		0101000020E610000029B16B7BBBF545406669A7E6729B4640
90815	8	81	1797	26652	59916	\N	45.283090000000001	Ставропольский край, Арзгирский район, село Садовое, Школьная, 38		0101000020E6100000D218ADA3AA5346408EE9094B3CA44640
90814	8	81	1797	26566	60349	\N	45.4333061566767	Ставропольский край, Арзгирский район, село Родниковское, Бульварная, 79	Россия, Ставропольский край, Арзгирский район, село Родниковское	0101000020E610000088635DDC460D46408E942D9276B74640
90813	8	81	1797	32517	59740	\N	45.087192999999999	Ставропольский край, Арзгирский район, село Петропавловское, Студенческая, 78		0101000020E6100000862172FA7A24464056B8E523298B4640
90812	8	81	1797	26501	59737	\N	45.023035999999998	Ставропольский край, Арзгирский район, Новоромановский сельсовет, село Новоромановское, Ленина, 130		0101000020E6100000207BBDFBE3334640B950F9D7F2824640
90811	8	81	1797	26419	60317	\N	45.546999999999997	Ставропольский край, Арзгирский район, село Каменная Балка, Бульварная, 21		0101000020E610000072A8DF85ADFD4540BC74931804C64640
90810	8	81	1797	57648	60427	\N	45.263156020545402	Ставропольский край, Арзгирский район, Арзгирский сельсовет, аул Башанта, Оджаева, 16	Россия, Ставропольский край, Арзгирский район, село Башанта	0101000020E61000000F9A5DF7560C464083DF8618AFA14640
90809	8	81	1797	26190	59911	\N	45.374747999999997	Ставропольский край, Арзгирский район, Арзгирский сельсовет, село Арзгир, имени Оджаева, 51		0101000020E61000003ECE3461FB1B4640E61E12BEF7AF4640
90806	8	81	1797	26190	59909	\N	45.374747999999997	Ставропольский край, Арзгирский район, Арзгирский сельсовет, село Арзгир, Энгельса, 23		0101000020E61000003ECE3461FB1B4640E61E12BEF7AF4640
90807	8	81	1797	26190	59524	\N	45.374747999999997	Ставропольский край, Арзгирский район, Арзгирский сельсовет, село Арзгир, Пети Базалеева, 8		0101000020E61000003ECE3461FB1B4640E61E12BEF7AF4640
90808	8	81	1797	26190	59736	\N	45.374747999999997	Ставропольский край, Арзгирский район, Арзгирский сельсовет, село Арзгир, Горького, 18		0101000020E61000003ECE3461FB1B4640E61E12BEF7AF4640
90788	8	81	1420	25368	60472	\N	45.653272999999999	Ставропольский край, Апанасенковский район, Айгурский сельсовет, поселок Хлебный, Каменная, 2 а		0101000020E61000000723F609A0B245400E2E1D739ED34640
90805	8	81	1420	26150	60574	\N	45.645690690031202	Ставропольский край, Апанасенковский район, с. Рагули ул. Советская, 56	Россия, Ставропольский край, Апанасенковский район, село Рагули	0101000020E6100000E65C8AABCADC45402829B000A6D24640
90803	8	81	1420	26076	59952	\N	46.075933999999997	Ставропольский край, Апанасенковский район, село Манычское, Октябрьская, 48		0101000020E61000009677D503E68B4540C5538F34B8094740
90802	8	81	1420	17360	60577	\N	46.000648816078602	Ставропольский край, Апанасенковский район, село Малая Джалга, Красная, 59	Россия, Ставропольский край, Апанасенковский район, село Малая Джалга	0101000020E6100000DB6B41EF8D63454037E3344415004740
90801	8	81	1420	32516	59719	\N	46.080722999999999	Ставропольский край, Апанасенковский район, село Киевка, Октябрьская, 82		0101000020E61000000E315EF3AA7645407B849A21550A4740
90797	8	81	1420	15783	60022	\N	45.917070000000002	Ставропольский край, Апанасенковский район, село Дивное, Советская, 43		0101000020E6100000583A1F9E25AC45404512BD8C62F54640
90795	8	81	1420	15783	60022	\N	45.917070000000002	Ставропольский край, Апанасенковский район, село Дивное, Советская, 197		0101000020E6100000583A1F9E25AC45404512BD8C62F54640
90800	8	81	1420	15783	60601	\N	45.917070000000002	Ставропольский край, Апанасенковский район, село Дивное, О.Кошевого, 180		0101000020E6100000583A1F9E25AC45404512BD8C62F54640
90798	8	81	1420	15783	60596	\N	45.917070000000002	Ставропольский край, Апанасенковский район, село Дивное, Кашубы, 4		0101000020E6100000583A1F9E25AC45404512BD8C62F54640
90796	8	81	1420	15783	60021	\N	45.917070000000002	Ставропольский край, Апанасенковский район, село Дивное, Вокзальная, 16		0101000020E6100000583A1F9E25AC45404512BD8C62F54640
90763	8	81	1714	48223	60037	\N	44.670430000000003	село Садовое, Ленина улица, 165		0101000020E610000062D9CC21A9694540EF2076A6D0554640
90799	8	81	1420	15783	60569	\N	45.917070000000002	Ставропольский край, Апанасенковский район, село Дивное, 8 марта, 58		0101000020E6100000583A1F9E25AC45404512BD8C62F54640
90794	8	81	1420	25665	60017	\N	45.805540000000001	Ставропольский край, Апанасенковский район, с. Дербетовка, Красная, 27		0101000020E610000020EBA9D5578B454057CF49EF1BE74640
90792	8	81	1420	25560	59903	\N	45.811501999999997	Ставропольский край, Апанасенковский район, село Вознесеновское, Шоссейная, 15		0101000020E6100000DB5031CEDFB44540BD512B4CDFE74640
90791	8	81	1420	17172	60562	\N	45.830119000000003	Ставропольский край, Апанасенковский район, село Воздвиженское, Октябрьская, 89		0101000020E61000008BE07F2BD9D54540E564E25641EA4640
90787	8	81	1420	25308	60418	\N	45.676005000000004	Ставропольский край, Апанасенковский район, Айгурский сельсовет, поселок Водный, Пушкина, 16 а		0101000020E61000002FDB4E5B23B045405C77F35487D64640
90790	8	81	1420	25455	60141	\N	45.954574435162201	Ставропольский край, Апанасенковский район, село Белые Копани, Советская, 38	Россия, Ставропольский край, Апанасенковский район, село Белые Копани	0101000020E6100000C4EE3B86C782454053CE177B2FFA4640
90789	8	81	1420	25450	60014	\N	45.755023999999999	Ставропольский край, Апанасенковский район, село Апанасенковское, пер. Комсомольский, 12		0101000020E610000038D89B1892C74540F9D85DA0A4E04640
90786	8	81	1420	25263	60261	\N	45.675852999999996	Ставропольский край, Апанасенковский район, Айгурский сельсовет, поселок Айгурский, Садовая, 26		0101000020E61000004298DBBDDCA94540A5F3E15982D64640
90777	8	81	1374	24913	59739	\N	44.664698999999999	Ставропольский край, Андроповский район, село Янкуль, пер. Клубный, 2		0101000020E6100000D270CADC7C4545408A5759DB14554640
90765	8	81	1374	24323	60345	\N	44.478186999999998	Ставропольский край, Андроповский район, село Суркуль, Горького, 55		0101000020E61000000BF0DDE68D3B4540A92F4B3B353D4640
90781	8	81	1374	25038	60283	\N	44.590066	Ставропольский край, Андроповский район, село Султан, Ленина, 102		0101000020E610000037E2C96E66544540A33D5E48874B4640
90783	8	81	1374	25160	60015	\N	44.402495000000002	Ставропольский край, Андроповский район, село Солуно-Дмитриевское, Совхозная, 2		0101000020E61000003C6BB75D685C4540DAE6C6F484334640
90784	8	81	1374	25160	60018	\N	44.402495000000002	Ставропольский край, Андроповский район, село Солуно-Дмитриевское, Советская, 35		0101000020E61000003C6BB75D685C4540DAE6C6F484334640
90773	8	81	1374	24727	60469	\N	44.511550999999997	Ставропольский край, Андроповский район, село Подгорное, Цветочная, 5		0101000020E61000005C2041F163204540389ECF807A414640
90780	8	81	1374	24999	60013	\N	44.777228000000001	Ставропольский край, Андроповский район, поселок Новый Янкуль, Победы, 15 Б		0101000020E61000006D1FF296AB4145408BC404357C634640
90779	8	81	1374	24995	60417	\N	44.686216000000002	Ставропольский край, Андроповский район, хутор Нижнеколонский, Центральная, 65		0101000020E6100000EB6F09C03F334540F8FE06EDD5574640
90785	8	81	1374	25253	59905	\N	44.431887000000003	Ставропольский край, Андроповский район, село Куршава, Красная, 49		0101000020E610000034F8FBC56C494540A648BE1248374640
90738	8	81	1374	23003	60318	\N	44.461369289021299	Ставропольский край, Андроповский район, село Курсавка, Октябрьская, 148	Россия, Ставропольский край, Андроповский район, село Курсавка	0101000020E6100000401878EE3D404540B131AF230E3B4640
90764	8	81	1374	23003	59734	\N	44.457434999999997	Ставропольский край, Андроповский район, село Курсавка, Красная, 27		0101000020E6100000C6E1CCAFE6404540DB85E63A8D3A4640
90767	8	81	1374	23003	59906	\N	44.457434999999997	Ставропольский край, Андроповский район, село Курсавка, Войтика, 205		0101000020E6100000C6E1CCAFE6404540DB85E63A8D3A4640
90766	8	81	1374	23003	59913	\N	44.457434999999997	Ставропольский край, Андроповский район, село Курсавка, 1-е Мая, 12		0101000020E6100000C6E1CCAFE6404540DB85E63A8D3A4640
90782	8	81	1374	25093	59902	\N	44.538465000000002	Ставропольский край, Андроповский район, село Крымгиреевское, Кирова, 76		0101000020E6100000629E95B4E25B45403485CE6BEC444640
90771	8	81	1374	24630	60295	\N	44.445351000000002	Ставропольский край, Андроповский район, село Красноярское, Подтенная, 4		0101000020E610000034D8D479542E4540D61EF64201394640
90778	8	81	1374	24914	60441	\N	44.625354999999999	Ставропольский край, Андроповский район, село Кианкиз, Титова, 1а		0101000020E61000002C4487C091384540EEB1F4A10B504640
90776	8	81	1374	14930	60591	\N	44.606253000000002	Ставропольский край, Андроповский район, поселок Каскадный, Центральная, 7А		0101000020E6100000895C70067F1D45400B0DC4B2994D4640
90772	8	81	1374	17068	60584	\N	44.467103999999999	Ставропольский край, Андроповский район, село Казинка, Школьная, 34		0101000020E61000007958A835CD25454057EA5910CA3B4640
90775	8	81	1374	17163	60581	\N	44.556618999999998	Ставропольский край, Андроповский район, село Дубовая Балка, Школьная, 36Б		0101000020E6100000C0B167CF6534454086AA984A3F474640
90768	8	81	1374	24435	60012	\N	44.381180999999998	Ставропольский край, Андроповский район, станица Воровсколесская, Красная, 93		0101000020E610000007077B1343344540A46DFC89CA304640
90769	8	81	1374	24435	60409	\N	44.381180999999998	Ставропольский край, Андроповский район, станица Воровсколесская, Грековская, 31/2		0101000020E610000007077B1343344540A46DFC89CA304640
90774	8	81	1374	24736	59735	\N	44.514977701904002	Ставропольский край, Андроповский район, село Водораздел, Школьная, 1	Россия, Ставропольский край, Андроповский район, село Водораздел	0101000020E61000002FF7C951802E45406A1492CCEA414640
90770	8	81	1374	24545	60367	\N	44.417504999999998	Ставропольский край, Андроповский район, село Алексеевское, Красная, 66		0101000020E6100000C443183F8D3145404F75C8CD70354640
90761	8	81	1714	57603	60028	\N	44.555072586623702	Ставропольский край, Александровский район, хутор Средний, Клубная улица, 1	Россия, Ставропольский край, Александровский район, село Средний	0101000020E6100000F5B9DA8AFD79454041F2CEA10C474640
90754	8	81	1714	23744	59521	\N	44.832093999999998	Ставропольский край, Александровский район, село Северное, Мира улица, 16/А		0101000020E6100000605793A7AC6C45405299620E826A4640
90759	8	81	1714	24032	59522	\N	44.519064999999998	Ставропольский край, Александровский район, село Саблинское, Окиябрьская улица, 47		0101000020E6100000792288F3709C4540C6BFCFB870424640
90760	8	81	1714	24034	59732	\N	44.584558000000001	Ставропольский край, Александровский район, поселок Новокавказский, Средняя улица, 3		0101000020E610000097C80567F08F4540BE4EEACBD24A4640
90762	8	81	1714	24130	59896	\N	44.662522397772101	Ставропольский край, Александровский район, село Круглолесское, Советская улица, 46	Россия, Ставропольский край, Александровский район, село Круглолесское	0101000020E61000008DB454DE8E684540B5705985CD544640
90756	8	81	1714	23823	59729	\N	44.866754	Ставропольский край, Александровский район, село Калиновское, Глазкова улица, 366		0101000020E6100000361E6CB1DB7B4540AED689CBF16E4640
90755	8	81	1714	23823	59729	\N	44.866754	Ставропольский край, Александровский район, село Калиновское, Глазкова улица, 206		0101000020E6100000361E6CB1DB7B4540AED689CBF16E4640
90753	8	81	1714	23735	60439	\N	44.721183000000003	Ставропольский край, Александровский район, поселок Дубовая Роща, Маяковского улица, 1		0101000020E6100000CB2E185C736D454031B77BB94F5C4640
90757	8	81	1714	23876	59900	\N	44.946479023750797	Ставропольский край, Александровский район, село Грушевское, Кирова улица, 69/5	Россия, Ставропольский край, Александровский район, село Грушевское	0101000020E61000000C056C0723864540E6AC4F3926794640
90758	8	81	1714	23936	60408	\N	44.604289999999999	Ставропольский край, Александровский район, хутор Всадник, 60 лет Октября улица, 12		0101000020E61000009701672959A6454061A6ED5F594D4640
90750	8	81	1714	23101	59741	\N	44.7195164648004	Ставропольский край, Александровский район, село Александровское, Энгельса улица, 26	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E61000003A2009FB768045407079AC19195C4640
90747	8	81	1714	23101	60265	\N	44.723096282201098	Ставропольский край, Александровский район, село Александровское, Щорса улица, 47	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E61000009012BBB6B77F454028EFE3688E5C4640
90746	8	81	1714	23101	59722	\N	44.711835933223703	Ставропольский край, Александровский район, село Александровское, Речной переулок, 9	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E61000005725917D907D4540C70E2A711D5B4640
90742	8	81	1714	23101	60010	\N	44.7304591195348	Ставропольский край, Александровский район, село Александровское, Р.Люксембург улица, 1	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E61000007C9A9317997A4540D10836AE7F5D4640
90744	8	81	1714	23101	59901	\N	44.732396999999999	Ставропольский край, Александровский район, село Александровское, Ленинская улица, 171		0101000020E61000004FE61F7D937A45402158552FBF5D4640
90752	8	81	1714	23101	59517	\N	44.721627666142197	Ставропольский край, Александровский район, село Александровское, Красноармейская улица, 616	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E6100000027FF8F9EF7F45405FF0694E5E5C4640
90741	8	81	1714	23101	59517	\N	44.720770956107998	Ставропольский край, Александровский район, село Александровское, Красноармейская улица, 230	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E6100000A81DFE9AAC7D4540DE736039425C4640
90740	8	81	1714	23101	59517	\N	44.713304799506801	Ставропольский край, Александровский район, село Александровское, Красноармейская улица, 296	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E6100000E5B8533A587D4540618907944D5B4640
90751	8	81	1714	23101	59520	\N	44.712815181582798	Ставропольский край, Александровский район, село Александровское, Калинина улица, 352	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E61000005DC5E237857D4540938C9C853D5B4640
90749	8	81	1714	23101	59520	\N	44.709877386460597	Ставропольский край, Александровский район, село Александровское, Калинина улица, 200	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E6100000A2EF6E65897E45405F97E13FDD5A4640
90748	8	81	1714	23101	59519	\N	44.711835933223703	Ставропольский край, Александровский район, село Александровское, К.Маркса улица, 108	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E6100000734C16F71F7D4540C70E2A711D5B4640
90743	8	81	1714	23101	59519	\N	44.732396999999999	Ставропольский край, Александровский район, село Александровское, К.Маркса улица, 44		0101000020E61000004FE61F7D937A45402158552FBF5D4640
90745	8	81	1714	23101	59518	\N	44.7177111731542	Ставропольский край, Александровский район, село Александровское, Виноградная улица, 2	Россия, Ставропольский край, Александровский район, село Александровское	0101000020E6100000662E7079AC7F45405F7D3CF4DD5B4640
43291	3	25	\N	19420	57509	\N	63.571199749819797	Республика Коми, г.Ухта, Ленина проспект, 40	Россия, республика Коми, Ухта городской округ	0101000020E6100000DD5F3DEE5BD34A40D3BCE3141DC94F40
43265	3	25	\N	19420	57509	\N	63.577820000000003	Республика Коми, г.Ухта, Ленина проспект, 6а		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43295	3	25	\N	19420	57615	\N	63.577820000000003	Республика Коми, г.Ухта, Космонавтов проспект, 21а		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43286	3	25	\N	19420	57623	\N	63.569593078691803	Республика Коми, г.Ухта, набережная Нефтяников, 19	Россия, республика Коми, Ухта городской округ	0101000020E6100000C0EB33677DD24A40E883656CE8C84F40
37599	3	28	361	47579	23149	\N	54.510511000000001	п. Невское, Садовая, 18		0101000020E610000004E3E0D231A73640C79FA86C58414B40
43263	3	25	\N	19420	57567	\N	63.577820000000003	Республика Коми, г.Ухта, Юбилейная, 14А	Россия, республика Коми, Ухта	0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43262	3	25	\N	19420	57567	\N	63.567188207843799	Республика Коми, г.Ухта, Юбилейная, 22	Россия, республика Коми, Ухта городской округ	0101000020E61000003049658A39D84A408257CB9D99C84F40
43277	3	25	\N	19420	57628	\N	63.544036712654602	Республика Коми, г.Ухта, Школьная, 7	Россия, республика Коми, Ухта городской округ	0101000020E61000004E7CB5A338DB4A4030682101A3C54F40
43279	3	25	\N	19420	57518	\N	63.552870657616701	Республика Коми, г.Ухта, Тихоновича, 3	Россия, республика Коми, Ухта городской округ	0101000020E61000000A9E42AED4E74A4013F4177AC4C64F40
43284	3	25	\N	19420	57513	\N	63.566895962547797	Республика Коми, г.Ухта, Строителей проезд, 25	Россия, республика Коми, Ухта городской округ	0101000020E61000000C570740DCD34A40DA1D520C90C84F40
43283	3	25	\N	19420	57513	\N	63.577820000000003	Республика Коми, г.Ухта, Строителей проезд, 15		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43281	3	25	\N	19420	57513	\N	63.577820000000003	Республика Коми, г.Ухта, Строителей проезд, 1		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43301	3	25	\N	19420	57617	\N	63.577820000000003	Республика Коми, г.Ухта, Совхозная, 4		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43293	3	25	\N	19420	57514	\N	63.577820000000003	Республика Коми, г.Ухта, Советская, 14		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43287	3	25	\N	19420	57514	\N	63.577820000000003	Республика Коми, г.Ухта, Советская, 5		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43218	3	25	\N	19420	57514	\N	63.577820000000003	Республика Коми, г.Ухта, Советская, 2	Россия, республика Коми, Ухта	0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43297	3	25	\N	19420	57662	\N	63.577820000000003	Республика Коми, г.Ухта, Сенюкова, 47	Россия, республика Коми, Ухта	0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43296	3	25	\N	19420	57662	\N	63.573284984274899	Республика Коми, г.Ухта, Сенюкова, 49	Россия, республика Коми, Ухта городской округ	0101000020E61000001AA4E029E4D64A40C824236761C94F40
43261	3	25	\N	19420	57559	\N	63.577820000000003	Республика Коми, г.Ухта, Севастопольская, 11		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43292	3	25	\N	19420	57572	\N	63.577820000000003	Республика Коми, г.Ухта, Пионергорский проезд, 5		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43270	3	25	\N	19420	57660	\N	63.577820000000003	Республика Коми, г.Ухта, Первомайская, 44		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43269	3	25	\N	19420	57560	\N	63.577820000000003	Республика Коми, г.Ухта, Оплеснина, 13		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43267	3	25	\N	19420	57560	\N	63.577820000000003	Республика Коми, г.Ухта, Оплеснина, 28		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43272	3	25	\N	19420	57512	\N	63.577820000000003	Республика Коми, г.Ухта, Октябрьская, 7		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43264	3	25	\N	19420	57512	\N	63.577820000000003	Республика Коми, г.Ухта, Октябрьская, 28/2		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43278	3	25	\N	19420	57508	\N	63.577820000000003	Республика Коми, г.Ухта, Озерная, 10		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43288	3	25	\N	19420	57565	\N	63.577820000000003	Республика Коми, г.Ухта, Ленина проспект, 26		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43276	3	25	\N	19420	57583	\N	63.575962370515597	Республика Коми, г.Ухта, Кольцевая, 19	Россия, республика Коми, Ухта	0101000020E610000069E388B5F8DC4A408FDE701FB9C94F40
43275	3	25	\N	19420	57611	\N	63.577820000000003	Республика Коми, г.Ухта, Кирпичная, 23		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43290	3	25	\N	19420	57566	\N	63.577820000000003	Республика Коми, г.Ухта, Интернациональная, 56		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43289	3	25	\N	19420	57566	\N	63.577820000000003	Республика Коми, г.Ухта, Интернациональная, 72		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43268	3	25	\N	19420	57659	\N	63.577820000000003	Республика Коми, г.Ухта, Дзержинского, 17		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43260	3	25	\N	19420	79468	\N	63.577705000000002	Республика Коми, г.Ухта, Дежнева, 16	Россия, республика Коми, Ухта	0101000020E610000058C9C7EE02DD4A402BDEC83CF2C94F40
43271	3	25	\N	19420	57661	\N	63.577820000000003	Республика Коми, г.Ухта, Горького, 13		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43259	3	25	\N	19420	57507	\N	63.577820000000003	Республика Коми, г.Ухта, Бушуева, 2		0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43280	3	25	\N	19420	57522	\N	63.577820000000003	Республика Коми, г.Ухта, Авиационная, 5	Россия, республика Коми, Ухта	0101000020E61000007C0DC17119DD4A40C47C7901F6C94F40
43266	3	25	\N	19420	57568	\N	63.577986976232197	Республика Коми, г.Ухта, 30 лет Октября, 1б	Россия, республика Коми, Ухта	0101000020E6100000676325E659DD4A40AF415F7AFBC94F40
43171	3	25	\N	16244	57490	\N	66.019740036017694	Республика Коми, г.Усинск, пст.Усадор, Строителей, 11	Россия, республика Коми, Усинск городской округ, село Усадор	0101000020E61000007DCD72D9E8C24C40139B8F6B43815040
43164	3	25	\N	16244	57490	\N	65.993138000000002	Республика Коми, г.Усинск, Строителей, 12		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43163	3	25	\N	16244	57490	\N	65.993138000000002	Республика Коми, г.Усинск, Строителей, 4А		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43162	3	25	\N	16244	57490	\N	65.990844525495405	Республика Коми, г.Усинск, Строителей, 10		0101000020E61000000937195586C74C40ED9925016A7F5040
43169	3	25	\N	16244	57556	\N	65.993138000000002	Республика Коми, г.Усинск, Нефтяников, 37		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43166	3	25	\N	16244	57556	\N	65.993138000000002	Республика Коми, г.Усинск, Нефтяников, 44А		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43161	3	25	\N	16244	57491	\N	65.993138000000002	Республика Коми, г.Усинск, Молодежная, 10		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43160	3	25	\N	16244	57491	\N	65.993138000000002	Республика Коми, г.Усинск, Молодежная, 16/1		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43159	3	25	\N	16244	57491	\N	65.983181850410304	Республика Коми, г.Усинск, Молодежная, 30	Россия, республика Коми, Усинск городской округ	0101000020E61000003B376DC669C84C4004013274EC7E5040
43158	3	25	\N	16244	57491	\N	65.993138000000002	Республика Коми, г.Усинск, Молодежная, 31		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43156	3	25	\N	16244	57489	\N	65.993138000000002	Республика Коми, г.Усинск, Комсомольская, 5А		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43155	3	25	\N	16244	57489	\N	65.993138000000002	Республика Коми, г.Усинск, Комсомольская, 28		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43168	3	25	\N	16244	57492	\N	65.993627401679504	Республика Коми, г.Усинск, Возейская, 9	Россия, республика Коми, Усинск	0101000020E61000005858703FE0BF4C400C5BB395977F5040
43167	3	25	\N	16244	57492	\N	65.993138000000002	Республика Коми, г.Усинск, Возейская, 9А		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43165	3	25	\N	16244	57545	\N	65.993138000000002	Республика Коми, г.Усинск, 60 лет Октября, 3А		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
43157	3	25	\N	16244	57545	\N	65.993138000000002	Республика Коми, г.Усинск, 60 лет Октября, 2А		0101000020E61000006B0F7BA180BF4C408D9AAF928F7F5040
42965	3	25	\N	669	\N	\N	61.708787589468699	Республика Коми, г.Сыктывкар, пст. Трехозерка, дом культуры п.Трехозерка	Россия, республика Коми, поселок Трехозерка	0101000020E61000004D83A279006F49400CE6AF90B9DA4E40
42971	3	25	\N	669	1157	\N	61.653683000000001	Республика Коми, г.Сыктывкар, Школьная, 16	Россия, республика Коми, Сыктывкар, улица Школьная, 16	0101000020E610000033DE567A6D704940C07971E2ABD34E40
42973	3	25	\N	669	2076	\N	61.666547000000001	Республика Коми, г.Сыктывкар, Советская, 59	Россия, республика Коми, Сыктывкар, улица Советская, 59	0101000020E6100000FFE7305F5E6C49409B1F7F6951D54E40
42980	3	25	\N	669	2155	\N	61.649833999999998	Республика Коми, г.Сыктывкар, Морозова, 118	Россия, республика Коми, Сыктывкар, улица Морозова, 118	0101000020E6100000D49AE61DA766494018EAB0C22DD34E40
42996	3	25	\N	669	2408	\N	61.675043000000002	Республика Коми, г.Сыктывкар, Красных партизан, 68	Россия, республика Коми, Сыктывкар, улица Красных Партизан, 68	0101000020E61000005B09DD257168494066321CCF67D64E40
42992	3	25	\N	669	2198	\N	61.664530999999997	Республика Коми, г.Сыктывкар, Коммунистическая, 25	Россия, республика Коми, Сыктывкар, улица Коммунистическая, 25	0101000020E6100000DA907F6610694940CE16105A0FD54E40
42986	3	25	\N	669	2236	\N	61.666285999999999	Республика Коми, г.Сыктывкар, Катаева, 14	Россия, республика Коми, Сыктывкар, улица Катаева, 14	0101000020E6100000BF9A0304736649402EE411DC48D54E40
42994	3	25	\N	669	57686	\N	61.671073	Республика Коми, г.Сыктывкар, Юхнина, 22		0101000020E610000014B4C9E193684940431D56B8E5D54E40
43026	3	25	\N	669	57638	\N	61.669587	Республика Коми, г.Сыктывкар, Юности, 4/1		0101000020E610000015C95702296B4940D369DD06B5D54E40
42977	3	25	\N	669	57684	\N	61.659612000000003	Республика Коми, г.Сыктывкар, Южная, 15		0101000020E610000036C82423676B49404B06802A6ED44E40
43018	3	25	\N	669	57598	\N	61.669587	Республика Коми, г.Сыктывкар, Школьный переулок, 6		0101000020E610000015C95702296B4940D369DD06B5D54E40
42972	3	25	\N	669	57690	\N	61.653320000000001	Республика Коми, г.Сыктывкар, Школьная, 13		0101000020E610000031242713B77049404FE960FD9FD34E40
42993	3	25	\N	669	57672	\N	61.667205431126497	Республика Коми, г.Сыктывкар, Чернова, 12	Россия, республика Коми, Сыктывкар, улица Чернова, 10	0101000020E6100000A14CA3C9C5684940255D33F966D54E40
42966	3	25	\N	669	57558	\N	61.669587	Республика Коми, г.Сыктывкар, Ухтинская, 4		0101000020E610000015C95702296B4940D369DD06B5D54E40
43011	3	25	\N	669	57688	\N	61.703425000000003	Республика Коми, г.Сыктывкар, Тентюковская, 425		0101000020E610000019FF3EE3C26749402B1895D409DA4E40
43009	3	25	\N	669	57688	\N	61.698844999999999	Республика Коми, г.Сыктывкар, Тентюковская, 353		0101000020E61000005932C7F2AE6849408FFCC1C073D94E40
42989	3	25	\N	669	57678	\N	61.664881999999999	Республика Коми, г.Сыктывкар, Старовского, 53		0101000020E6100000217711A6286749407BD976DA1AD54E40
42974	3	25	\N	669	57773	\N	61.675942999999997	Республика Коми, г.Сыктывкар, Сплавная, 1А		0101000020E6100000FFB0A547536D4940E57ADB4C85D64E40
42961	3	25	\N	669	57674	\N	61.642058931842499	Республика Коми, г.Сыктывкар, Снежная, 41	Россия, республика Коми, Сыктывкар, улица Снежная	0101000020E6100000931B45D61A7049401E8D43FD2ED24E40
43017	3	25	\N	669	57530	\N	61.669587	Республика Коми, г.Сыктывкар, Славы, 18		0101000020E610000015C95702296B4940D369DD06B5D54E40
43016	3	25	\N	669	57530	\N	61.692292245300003	Республика Коми, г.Сыктывкар, Славы, 30	Россия, республика Коми, Сыктывкар	0101000020E6100000EEB5A0F7C666494027A435069DD84E40
42984	3	25	\N	669	57689	\N	61.670487999999999	Республика Коми, г.Сыктывкар, Ручейная, 27		0101000020E610000094128255F5624940232E008DD2D54E40
42976	3	25	\N	669	57687	\N	61.659337999999998	Республика Коми, г.Сыктывкар, Пушкина, 75		0101000020E6100000DE736039426A49404981053065D44E40
43005	3	25	\N	669	57683	\N	61.686915999999997	Республика Коми, г.Сыктывкар, Печорская, 30		0101000020E6100000E272BC02D1674940B08C0DDDECD74E40
43004	3	25	\N	669	57683	\N	61.685443999999997	Республика Коми, г.Сыктывкар, Печорская, 12		0101000020E610000001BEDBBC71684940A59E05A1BCD74E40
43008	3	25	\N	669	57680	\N	61.695538999999997	Республика Коми, г.Сыктывкар, Петрозаводская, 44		0101000020E61000008EAED2DD75684940D80B056C07D94E40
42997	3	25	\N	669	57691	\N	61.673347999999997	Республика Коми, г.Сыктывкар, Первомайская, 32		0101000020E610000047FFCBB568694940DB696B4430D64E40
42999	3	25	\N	669	57693	\N	61.672263999999998	Республика Коми, г.Сыктывкар, Орджоникидзе, 21		0101000020E61000000E32C9C8596A49409A232BBF0CD64E40
42963	3	25	\N	669	57706	\N	61.669587	Республика Коми, г.Сыктывкар, Олега Кошевого, 1	Россия, республика Коми, Сыктывкар, Стефановская площадь	0101000020E610000015C95702296B4940D369DD06B5D54E40
42991	3	25	\N	669	2338	\N	61.661833000000001	Республика Коми, г.Сыктывкар, Октябрьский проспект, 24	Россия, республика Коми, Сыктывкар, Октябрьский проспект, 24	0101000020E6100000E15E99B7EA684940F03499F1B6D44E40
43025	3	25	\N	669	57579	\N	61.669996352173698	Республика Коми, г.Сыктывкар, Набережный проезд, 11	Россия, республика Коми, Сыктывкар, улица Ленина, 53	0101000020E610000073BA2C26366B4940B439CE6DC2D54E40
43024	3	25	\N	669	57579	\N	61.669587	Республика Коми, г.Сыктывкар, адрес помещения для голосования: Набережный проезд, 11, адрес УИК: Мира, 21		0101000020E610000015C95702296B4940D369DD06B5D54E40
42981	3	25	\N	669	57682	\N	61.650483999999999	Республика Коми, г.Сыктывкар, Морозова, 114		0101000020E61000004BAE62F19B6649401F49490F43D34E40
42979	3	25	\N	669	57682	\N	61.640101000000001	Республика Коми, г.Сыктывкар, Морозова, 175		0101000020E6100000AAB9DC60A867494086915ED4EED14E40
43023	3	25	\N	669	57487	\N	61.667452359913497	Республика Коми, г.Сыктывкар, Мира, 10/1	Россия, республика Коми, Сыктывкар, улица Карла Маркса, 229а	0101000020E6100000C66AF3FFAA6949402CD32F116FD54E40
43021	3	25	\N	669	57487	\N	61.668594628792	Республика Коми, г.Сыктывкар, Мира, 14А	Россия, республика Коми, Сыктывкар, Стефановская площадь	0101000020E61000002026E1421E6B494073A25D8594D54E40
43019	3	25	\N	669	57487	\N	61.668574231504998	Республика Коми, г.Сыктывкар, Мира, 42/1	Россия, республика Коми, Сыктывкар	0101000020E6100000D9D138D4EF6A49405B7A34D593D54E40
42978	3	25	\N	669	57685	\N	61.649086980415497	Республика Коми, г.Сыктывкар, Маркова, 13	Россия, республика Коми, Сыктывкар, улица Маркова, 13	0101000020E610000073A1F2AFE56949401FA1664815D34E40
43007	3	25	\N	669	57677	\N	61.690674999999999	Республика Коми, г.Сыктывкар, Малышева, 6		0101000020E6100000C05FCC96AC6849401895D40968D84E40
43013	3	25	\N	669	57502	\N	61.669587	Республика Коми, г.Сыктывкар, Магистральная, 13		0101000020E610000015C95702296B4940D369DD06B5D54E40
43002	3	25	\N	669	57694	\N	61.679319999999997	Республика Коми, г.Сыктывкар, Кутузова, 11		0101000020E61000000951BEA0856A494065C22FF5F3D64E40
42967	3	25	\N	669	57497	\N	61.669587	Республика Коми, г.Сыктывкар, Корабельная, 1В		0101000020E610000015C95702296B4940D369DD06B5D54E40
42983	3	25	\N	669	57673	\N	61.661897000000003	Республика Коми, г.Сыктывкар, Коммунистическая, 74		0101000020E61000004C35B396026649400729780AB9D44E40
43020	3	25	\N	669	57599	\N	61.669587	Республика Коми, г.Сыктывкар, Комарова, 9		0101000020E610000015C95702296B4940D369DD06B5D54E40
42988	3	25	\N	669	57675	\N	61.665320999999999	Республика Коми, г.Сыктывкар, Катаева, 29		0101000020E61000001F2DCE18E6664940C72B103D29D54E40
42987	3	25	\N	669	57675	\N	61.666397000000003	Республика Коми, г.Сыктывкар, Катаева, 9		0101000020E6100000FA0967B7966749408693347F4CD54E40
42985	3	25	\N	669	57675	\N	61.664745000000003	Республика Коми, г.Сыктывкар, Катаева, 37А		0101000020E61000002A8C2D0439664940FB96395D16D54E40
43003	3	25	\N	669	57679	\N	61.682141000000001	Республика Коми, г.Сыктывкар, Карла Маркса, 145		0101000020E61000003F6EBF7CB26849406021736550D74E40
42998	3	25	\N	669	57679	\N	61.669880999999997	Республика Коми, г.Сыктывкар, Карла Маркса, 202		0101000020E61000002009FB76126949401B9B1DA9BED54E40
43001	3	25	\N	669	57692	\N	61.674582000000001	Республика Коми, г.Сыктывкар, Интернациональная, 95		0101000020E61000001CEBE2361A6A4940323CF6B358D64E40
42975	3	25	\N	669	57692	\N	61.665841999999998	Республика Коми, г.Сыктывкар, Интернациональная, 167		0101000020E61000000ABE69FAEC6A4940D026874F3AD54E40
42995	3	25	\N	669	57483	\N	61.6913439253794	Республика Коми, г.Сыктывкар, местечко Дырнос, 1	Россия, республика Коми, Сыктывкар	0101000020E6100000062E8F35235F49409624CFF57DD84E40
42990	3	25	\N	669	57671	\N	61.660666999999997	Республика Коми, г.Сыктывкар, Димитрова, 8		0101000020E61000006CAF05BD37684940F1457BBC90D44E40
42982	3	25	\N	669	57671	\N	61.657335000000003	Республика Коми, г.Сыктывкар, Димитрова, 44/1		0101000020E6100000FC8A355CE466494012C2A38D23D44E40
43012	3	25	\N	669	57640	\N	61.669587	Республика Коми, г.Сыктывкар, Верхний Чов, 60		0101000020E610000015C95702296B4940D369DD06B5D54E40
42962	3	25	\N	669	57493	\N	61.669587	Республика Коми, г.Сыктывкар, Большая, 6/1		0101000020E610000015C95702296B4940D369DD06B5D54E40
42968	3	25	\N	669	57582	\N	61.669594079308602	Республика Коми, г.Сыктывкар, Белинского, 15	Россия, Р-26 шоссе	0101000020E61000000B462575027C494085CC9541B5D54E40
42970	3	25	\N	669	57591	\N	61.669587	Республика Коми, г.Сыктывкар, Банбана, 21		0101000020E610000015C95702296B4940D369DD06B5D54E40
43000	3	25	\N	669	57681	\N	61.672066999999998	Республика Коми, г.Сыктывкар, Бабушкина, 4		0101000020E6100000568330B77B6B494044DC9C4A06D64E40
42964	3	25	\N	669	57616	\N	61.669517033901101	Республика Коми, г.Сыктывкар, Лесовозная, 22А	Россия, республика Коми, Сыктывкар, Стефановская площадь	0101000020E610000061FE0A992B6B4940DA8EA9BBB2D54E40
43022	3	25	\N	669	57622	\N	61.690738110291001	Республика Коми, г.Сыктывкар, Космонавтов, 14	Россия, республика Коми, Сыктывкар, улица Малышева, 6	0101000020E61000007E703E75AC6849405F0D501A6AD84E40
43240	3	25	\N	57211	57554	\N	63.573684999999998	Республика Коми, г.Сосногорск, Пионерская, 13		0101000020E6100000DEE7F86871F64A40569A94826EC94F40
43231	3	25	\N	57211	57663	\N	63.604465878376203	Республика Коми, г.Сосногорск, Первомайская, 1А	Россия, республика Коми, Сосногорск городской округ	0101000020E61000006D8C9DF012F04A40A0C552245FCD4F40
43242	3	25	\N	57211	57606	\N	63.573684999999998	Республика Коми, г.Сосногорск, Орджоникидзе, 23		0101000020E6100000DEE7F86871F64A40569A94826EC94F40
43235	3	25	\N	57211	57550	\N	63.596684671301702	Республика Коми, г.Сосногорск, Лермонтова, 12	Россия, республика Коми, Сосногорск городской округ	0101000020E610000039622D3E05F04A40C381902C60CC4F40
43234	3	25	\N	57211	57550	\N	63.573684999999998	Республика Коми, г.Сосногорск, Лермонтова, 6		0101000020E6100000DEE7F86871F64A40569A94826EC94F40
43238	3	25	\N	57211	57505	\N	63.5898427065259	Республика Коми, г.Сосногорск, 6 микрорайон, 18Б	Россия, республика Коми, Сосногорск городской округ	0101000020E610000019AA622AFDF44A402463B5F97FCB4F40
43237	3	25	\N	57211	57505	\N	63.573684999999998	Республика Коми, г.Сосногорск, 6 микрорайон, 35		0101000020E6100000DEE7F86871F64A40569A94826EC94F40
43236	3	25	\N	57211	57495	\N	63.573684999999998	Республика Коми, г.Сосногорск, 5 микрорайон, 39		0101000020E6100000DEE7F86871F64A40569A94826EC94F40
43096	3	25	\N	57207	57541	\N	65.1508589491865	Республика Коми, г.Печора, Советская, 16а	Россия, республика Коми, Печора городской округ	0101000020E61000005DC136E2C99C4C40AAD381ACA7495040
43095	3	25	\N	57207	57541	\N	65.1521396811317	Республика Коми, г.Печора, Советская, 12а	Россия, республика Коми, Печора городской округ	0101000020E610000009151C5E109D4C40761A69A9BC495040
43098	3	25	\N	57207	57654	\N	65.144429000000002	Республика Коми, г.Печора, Советская, 33		0101000020E610000033315D88D5A14C4004E621533E495040
43120	3	25	\N	57207	57488	\N	65.110142239137105	Республика Коми, г.Печора, Печорский проспект, 3	Россия, республика Коми, Печора городской округ	0101000020E6100000982F2FC03E924C40A0FA07910C475040
43117	3	25	\N	57207	57488	\N	65.144429000000002	Республика Коми, г.Печора, Печорский проспект, 31а		0101000020E610000033315D88D5A14C4004E621533E495040
43116	3	25	\N	57207	57488	\N	65.144429000000002	Республика Коми, г.Печора, Печорский проспект, 65		0101000020E610000033315D88D5A14C4004E621533E495040
43113	3	25	\N	57207	57479	\N	65.144429000000002	Республика Коми, г.Печора, Московская, 28		0101000020E610000033315D88D5A14C4004E621533E495040
43102	3	25	\N	57207	57657	\N	65.144429000000002	Республика Коми, г.Печора, Ленина, 30а		0101000020E610000033315D88D5A14C4004E621533E495040
43121	3	25	\N	57207	57482	\N	65.129633680361593	Республика Коми, г.Печора, Гагарина, 44	Россия, республика Коми, Печора городской округ	0101000020E61000008CD8278062944C40C79C67EC4B485040
43118	3	25	\N	57207	57482	\N	65.144429000000002	Республика Коми, г.Печора, Гагарина, 17		0101000020E610000033315D88D5A14C4004E621533E495040
43115	3	25	\N	57207	57484	\N	65.127130828822004	Республика Коми, г.Печора, Булгаковой, 11	Россия, республика Коми, Печора городской округ	0101000020E6100000FED64E9484944C40B3D30FEA22485040
43079	3	25	\N	57206	57534	\N	66.028661999999997	Республика Коми, г.Инта, Южная, 8а		0101000020E61000000A48FB1F60134E40D4282499D5815040
43086	3	25	\N	57206	57475	\N	66.035874066557298	Республика Коми, г.Инта, Куратова, 20	Россия, республика Коми, Интинский район, Инта	0101000020E6100000C8258E3C100F4E40B63176C24B825040
43083	3	25	\N	57206	57475	\N	66.028661999999997	Республика Коми, г.Инта, Куратова, 32		0101000020E61000000A48FB1F60134E40D4282499D5815040
43080	3	25	\N	57206	57766	\N	66.028661999999997	Республика Коми, г.Инта, Коммунистическая, 22		0101000020E61000000A48FB1F60134E40D4282499D5815040
43093	3	25	\N	57206	57767	\N	66.033549213115606	Республика Коми, г.Инта, Восточная, 100	Россия, республика Коми, Интинский район, Инта	0101000020E6100000D07CCEDDAE134E401074B4AA25825040
43327	3	25	\N	57225	57577	\N	62.595147689508799	Республика Коми, Княжпогостский район, г.Емва, Пионерская, 20	Россия, Р-25 шоссе	0101000020E6100000D656EC2FBB714940D12346CF2D4C4F40
43145	3	25	\N	15656	9788	\N	63.859201392964302	Республика Коми, г.Вуктыл, Коммунистическая, 4	Россия, республика Коми, Вуктыл	0101000020E6100000C153C8957AA84C4062D8614CFAED4F40
43149	3	25	\N	40318	57543	\N	63.839279602210297	Республика Коми, г.Вуктыл, Таёжная, 4	Россия, республика Коми, Вуктыл городской округ	0101000020E6100000C6A70018CFA64C40EC17EC866DEB4F40
43146	3	25	\N	40318	57542	\N	63.845568890013801	Республика Коми, г.Вуктыл, Комсомольская, 1		0101000020E6100000D23AAA9A20A84C4076C1E09A3BEC4F40
43148	3	25	\N	40318	9811	\N	63.842128718251402	Республика Коми, г.Вуктыл, Коммунистическая, 11	Россия, республика Коми, Вуктыл городской округ	0101000020E61000008F352383DCA54C40B00111E2CAEB4F40
43055	3	25	\N	3457	57645	\N	67.501109	Республика Коми, г.Воркута, Яновского, 5		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43053	3	25	\N	3457	57532	\N	67.501109	Республика Коми, г.Воркута, Шахтерская набережная, 12А		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43051	3	25	\N	3457	57587	\N	67.508185080737405	Республика Коми, г.Воркута, Чернова, 7		0101000020E6100000B309302C7F03504056D4601A86E05040
43056	3	25	\N	3457	57646	\N	67.501109	Республика Коми, г.Воркута, Центральная площадь, 9		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43048	3	25	7422	\N	57539	\N	67.513599306207396	Республика Коми, г.Воркута, Тиманская, 6А	Россия, республика Коми, Воркута городской округ	0101000020E6100000651D8EAED2035040881057CEDEE05040
43047	3	25	\N	3457	57539	\N	67.500928120691199	Республика Коми, г.Воркута, Тиманская, 12	Россия, республика Коми, Воркута	0101000020E6100000BD344580D3015040A56950340FE05040
43043	3	25	\N	3457	57586	\N	67.501109	Республика Коми, г.Воркута, Суворова, 25А		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43063	3	25	\N	3457	57641	\N	67.501109	Республика Коми, г.Воркута, Советский микрорайон, Строительная, 13		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43070	3	25	\N	3457	57652	\N	67.501109	Республика Коми, г.Воркута, адрес помещения для голосования: Привокзальный переулок, 2, адрес УИК: Привокзальная, 25А		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43049	3	25	\N	3457	57593	\N	67.501522405569105	Республика Коми, г.Воркута, Пищевиков бульвар, 20А	Россия, республика Коми, Воркута городской округ	0101000020E61000009E0C8E92570450405E0EBBEF18E05040
43046	3	25	\N	3457	57473	\N	67.501109	Республика Коми, г.Воркута, Пирогова, 9Б		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43045	3	25	\N	3457	57473	\N	67.516425056470993	Республика Коми, г.Воркута, Пирогова, 1		0101000020E61000008EC9E2FE230550408E75711B0DE15040
43067	3	25	\N	3457	57650	\N	67.501109	Республика Коми, г.Воркута, Пионерская, 30		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43065	3	25	\N	3457	57648	\N	67.501109	Республика Коми, г.Воркута, Парковая, 20А		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43068	3	25	\N	3457	57588	\N	67.501109	Республика Коми, г.Воркута, Московская, 8А		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43069	3	25	\N	3457	57651	\N	67.483670021186597	Республика Коми, г.Воркута, Матвеева, 37А	Россия, республика Коми, Воркута городской округ	0101000020E6100000DAC9E028790150409B030473F4DE5040
43064	3	25	\N	3457	57592	\N	67.501109	Республика Коми, г.Воркута, Ломоносова, 15А		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43044	3	25	\N	3457	57585	\N	67.501109	Республика Коми, г.Воркута, Лермонтова, 10		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43061	3	25	\N	3457	57478	\N	67.501109	Республика Коми, г.Воркута, Ленина, 34А	Россия, республика Коми, Воркута	0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43059	3	25	\N	3457	57478	\N	67.501405283505505	Республика Коми, г.Воркута, Ленина, 47		0101000020E6100000EEB1F4A10B0450404243FF0417E05040
43058	3	25	\N	3457	57478	\N	67.501109	Республика Коми, г.Воркута, Ленина, 44		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43057	3	25	\N	3457	57478	\N	67.498959136032894	Республика Коми, г.Воркута, Ленина, 46	Россия, республика Коми, Воркута городской округ	0101000020E61000001538D906EE035040DFC2BAF1EEDF5040
43050	3	25	\N	3457	57478	\N	67.501996602521601	Республика Коми, г.Воркута, Ленина, 58	Россия, республика Коми, Воркута городской округ	0101000020E610000024473A03230450402B6C06B820E05040
42892	3	25	\N	3457	57478	\N	67.499761403959198	Республика Коми, г.Воркута, Ленина, 51	Россия, республика Коми, Воркута городской округ	0101000020E610000015E0BBCD1B0450403EB48F15FCDF5040
43062	3	25	\N	3457	57581	\N	67.501109	Республика Коми, г.Воркута, Коммунальная, 6		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43066	3	25	\N	3457	57643	\N	67.501109	Республика Коми, г.Воркута, Дончука, 16	Россия, республика Коми, Воркута	0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43060	3	25	\N	3457	57643	\N	67.501109	Республика Коми, г.Воркута, Дончука, 9Б		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43054	3	25	\N	3457	57474	\N	67.501060078264899	Республика Коми, г.Воркута, Димитрова, 9	Россия, республика Коми, Воркута городской округ	0101000020E6100000302DEA93DC0250405C55F65D11E05040
43052	3	25	\N	3457	57474	\N	67.501109	Республика Коми, г.Воркута, Димитрова, 13		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43033	3	25	\N	3457	57639	\N	67.501109	Республика Коми, г.Воркута, Возейская, 8		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43042	3	25	\N	3457	57647	\N	67.501109	Республика Коми, г.Воркута, 3-я Линейная, 22		0101000020E6100000E36C3A02B8015040CDAE7B2B12E05040
43306	3	25	1830	57218	57516	\N	63.433208999999998	Республика Коми, г.Ухта, пгт.Ярега, Шахтинская, 9	Россия, республика Коми, Ухтинский район, поселок Ярега	0101000020E6100000670E492D94CA4A409BAA7B6473B74F40
43308	3	25	1830	57218	57665	\N	63.433208999999998	Республика Коми, г.Ухта, пгт.Ярега, Строительная, 10	Россия, республика Коми, Ухтинский район, поселок Ярега	0101000020E6100000670E492D94CA4A409BAA7B6473B74F40
43307	3	25	1830	57218	57649	\N	63.436375929908003	Республика Коми, г.Ухта, пгт.Ярега, Советская, 31	Россия, республика Коми, Ухтинский район, поселок Ярега	0101000020E6100000D7DAFB5415CC4A403161342BDBB74F40
43309	3	25	1830	57218	57525	\N	63.433208999999998	Республика Коми, г.Ухта, пгт.Ярега, Октябрьская, 45	Россия, республика Коми, Ухтинский район, поселок Ярега	0101000020E6100000670E492D94CA4A409BAA7B6473B74F40
43298	3	25	1830	57217	57515	\N	63.527899515352097	Республика Коми, г.Ухта, пгт.Шудаяг, Шахтинская, 9	Россия, республика Коми, Ухтинский район, поселок Шудаяг	0101000020E610000037A968ACFDCD4A407AC7293A92C34F40
43300	3	25	1830	57217	57733	\N	63.528895591569899	Республика Коми, г.Ухта, пгт.Шудаяг, Павлова, 13	Россия, республика Коми, Ухтинский район, поселок Шудаяг	0101000020E61000001157CEDE19CD4A401C7E37DDB2C34F40
43273	3	25	1830	57254	57771	\N	63.396273473124303	Республика Коми, г.Ухта, пст.Седъю, Центральная, 5	Россия, республика Коми, Ухтинский район, село Седью	0101000020E6100000C0EAC891CEFA4A40D7A4DB12B9B24F40
43274	3	25	1830	57247	\N	\N	63.181255334762596	"Республика Коми, г.Ухта, пст.Кэмдин, Здание МОУ ""СОШ №31"", 44"	Россия, республика Коми, Ухтинский район, село Кэмдин	0101000020E6100000BD8DCD8E54394B40459E245D33974F40
43302	3	25	1830	57307	57891	\N	64.225646777968805	Республика Коми, г.Ухта, пст.Кедвавом, Центральная, 1	Россия, республика Коми, Ухтинский район, село Кедвавом	0101000020E6100000397B67B455C94A40315C1D00710E5040
43305	3	25	1830	57224	57618	\N	63.503737999999998	Республика Коми, г.Ухта, пгт.Водный, Октябрьская, 5а	Россия, республика Коми, Ухтинский район, поселок Водный	0101000020E610000096CCB1BCABB44A4050E09D7C7AC04F40
43303	3	25	1830	57224	57569	\N	63.5068073961042	Республика Коми, г.Ухта, пгт.Водный, Ленина, 16а	Россия, республика Коми, Ухтинский район, поселок Водный	0101000020E6100000302B14E97EB44A402331410DDFC04F40
43304	3	25	1830	27900	57664	\N	63.232190000000003	Республика Коми, г.Ухта, пгт.Боровой, Советская, 5а	Россия, республика Коми, Ухтинский район, поселок Боровой	0101000020E6100000299831056B724A40A83AE466B89D4F40
43183	3	25	778	57253	57760	\N	65.423390951351493	"""Республика Коми, Усть-Цилемский район, дер.Чукчино, Здание ООО """"Судоходная компания """"Печора"""""", ул.Сельхозтехника, д.72"	Россия, республика Коми, Усть-Цилемский район, село Коровий Ручей	0101000020E61000004B5B5CE3331B4A40ED9A90D6185B5040
43201	3	25	778	57321	\N	\N	66.923641000000003	Республика Коми, Усть-Цилемский район, пст.Харъяга, Здание Харъяжской основной общеобразовательной школы	Россия, республика Коми, Усть-Цилемский район, село Харъяга	0101000020E61000007EA99F3715154A40AA0F24EF1CBB5040
43196	3	25	778	18282	\N	\N	65.821658999999997	Республика Коми, Усть-Цилемский район, с.Хабариха, Здание администрации сельского поселения	Россия, республика Коми, Усть-Цилемский район, село Хабариха	0101000020E61000002EFEB62748284A40B35DA10F96745040
43192	3	25	778	18072	\N	\N	65.436079000000007	Республика Коми, Усть-Цилемский район, дер.Филиппово, Здание Филипповского Дома культуры	Россия, республика Коми, Усть-Цилемский район, село Филиппово	0101000020E6100000F1811DFF058E49403CDEE4B7E85B5040
43185	3	25	778	5484	57602	\N	65.439653000000007	Республика Коми, Усть-Цилемский район, с.Усть-Цильма, Здание Усть-Цилемского культурного центра, ул.Советская, д.134		0101000020E6100000234E27D9EA144A40A7255646235C5040
43184	3	25	778	5484	57551	\N	65.433786278807702	Республика Коми, Усть-Цилемский район, с.Усть-Цильма, Здание Усть-Цилемской средней общеобразовательной школы, ул.Батманова, д.84	Россия, республика Коми, Усть-Цилемский район, село Усть-Цильма	0101000020E61000007138F3AB39144A409CDD5A26C35B5040
43195	3	25	778	18227	\N	\N	65.735416999999998	Республика Коми, Усть-Цилемский район, с.Уег, Здание Уежного клуба	Россия, республика Коми, Усть-Цилемский район, село Уег	0101000020E6100000D82C978DCE074A4009FB7612116F5040
43193	3	25	778	18155	\N	\N	65.458329000000006	Республика Коми, Усть-Цилемский район, с.Трусово, Здание администрации сельского поселения	Россия, республика Коми, Усть-Цилемский район, село Трусово	0101000020E610000017B7D100DEB04940BD732843555D5040
43188	3	25	778	17889	\N	\N	64.974890000000002	Республика Коми, Усть-Цилемский район, дер.Степановская, Здание Степановского Дома культуры	Россия, республика Коми, Усть-Цилемский район, село Степановская	0101000020E61000007496598462F14940A3CC0699643E5040
43197	3	25	778	18308	\N	\N	65.992596000000006	Республика Коми, Усть-Цилемский район, с.Среднее Бугаево, Здание Бугаевского Дома культуры	Россия, республика Коми, Усть-Цилемский район, село Среднее Бугаево	0101000020E610000094F59B89E9424A40FD885FB1867F5040
43187	3	25	778	57269	\N	\N	65.448583999999997	Республика Коми, Усть-Цилемский район, пст.Синегорье, Здание Синегорской средней общеобразовательной школы	Россия, республика Коми, Усть-Цилемский район, село Синегорье	0101000020E61000004A95287B4BFD49409160AA99B55C5040
43186	3	25	778	17772	\N	\N	65.521235000000004	Республика Коми, Усть-Цилемский район, дер.Сергеево-Щелья, Здание Сергеево-Щельского клуба	Россия, республика Коми, Усть-Цилемский район, село Сергеево-Щелья	0101000020E61000003F1C2444F9144A40F5A10BEA5B615040
43194	3	25	778	18184	\N	\N	65.472864000000001	Республика Коми, Усть-Цилемский район, дер.Рочево, Здание Рочевской начальной школы-детского сада	Россия, республика Коми, Усть-Цилемский район, село Рочево	0101000020E6100000FE48111956C749402BDD5D67435E5040
43198	3	25	778	18391	\N	\N	66.256829999999994	Республика Коми, Усть-Цилемский район, с.Окунев Нос, Здание Окуневского Дома культуры	Россия, республика Коми, Усть-Цилемский район, село Окунев Нос	0101000020E6100000DB334B02D4484A406DA818E76F905040
43200	3	25	778	57234	\N	\N	66.723697826058	Республика Коми, Усть-Цилемский район, пст.Новый Бор, Здание Новоборского Дома культуры	Россия, республика Коми, Усть-Цилемский район, село Новый Бор	0101000020E610000072361D01DC264A408F8B6A1151AE5040
43181	3	25	778	17554	\N	\N	65.301603999999998	Республика Коми, Усть-Цилемский район, с.Нерица, Здание администрации сельского поселения	Россия, республика Коми, Усть-Цилемский район, село Нерица	0101000020E6100000D13C80457E574A40F015DD7A4D535040
43199	3	25	778	57294	\N	\N	66.458906999999996	Республика Коми, Усть-Цилемский район, пст.Медвежка, Здание Межвежской начальной школы-детского сада	Россия, республика Коми, Усть-Цилемский район, село Медвежка	0101000020E610000081785DBF602D4A40F33977BB5E9D5040
43182	3	25	778	57257	57776	\N	65.421484616536404	Республика Коми, Усть-Цилемский район, с.Коровий Ручей, Здание администрации сельского поселения, ул.Школьная, д.2	Россия, республика Коми, Усть-Цилемский район, село Коровий Ручей	0101000020E6100000E2CD1ABCAF1C4A404BB0389CF95A5040
43189	3	25	778	17923	\N	\N	65.040414999999996	Республика Коми, Усть-Цилемский район, с.Замежная, Здание Замеженского Дома культуры	Россия, республика Коми, Усть-Цилемский район, село Замежная	0101000020E61000002CB7B41A12FD494024D1CB2896425040
43190	3	25	778	17985	\N	\N	65.089526000000006	Республика Коми, Усть-Цилемский район, дер.Загривочная, Здание Загривочного Дома культуры	Россия, республика Коми, Усть-Цилемский район, село Загривочная	0101000020E6100000D9AF3BDD79F84940128942CBBA455040
43202	3	25	778	18602	\N	\N	66.916387999999998	Республика Коми, Усть-Цилемский район, с.Ёрмица, Здание администрации сельского поселения	Россия, республика Коми, Усть-Цилемский район, село Ермица	0101000020E6100000D236FE44652B4A40999CDA19A6BA5040
43439	3	25	850	29908	57753	\N	62.091276999999998	Республика Коми, Усть-Куломский район, п.Ярашъю, Центральная, 12		0101000020E6100000B1DCD26A482E4B4041F0F8F6AE0B4F40
43447	3	25	850	30234	57831	\N	62.290083000000003	Республика Коми, Усть-Куломский район, п.Ягкедж, Парковая, 3 А		0101000020E61000002A7288B8391B4B401310937021254F40
43425	3	25	850	29271	57576	\N	61.631397999999997	Республика Коми, Усть-Куломский район, п.Югыдъяг, адрес помещения для голосования: Комсомольская, 40, адрес УИК: Школьная, 4		0101000020E6100000C1A7397991774B40416150A6D1D04E40
43430	3	25	850	29499	57781	\N	61.598284999999997	Республика Коми, Усть-Куломский район, п.Шэръяг, Центральная, 10		0101000020E6100000CE531D72332A4B40FB57569A94CC4E40
43427	3	25	850	29353	57711	\N	61.634774999999998	Республика Коми, Усть-Куломский район, с.Усть-Нем, Совхозная, 15В		0101000020E6100000F183F3A9636F4B40C1A8A44E40D14E40
43419	3	25	850	28967	57529	\N	61.687600461038997	Республика Коми, Усть-Куломский район, с.Усть-Кулом, адрес помещения для голосования: Советская, 35, адрес УИК: Гагарина, 1	Россия, республика Коми, Усть-Куломский район, село Усть-Кулом	0101000020E61000008461C092ABD84A40645DDC4603D84E40
43418	3	25	850	28967	57633	\N	61.689737000000001	Республика Коми, Усть-Куломский район, с.Усть-Кулом, адрес помещения для голосования: Ленина, 5, адрес УИК: Гагарина, 1		0101000020E6100000ADDA3521ADD94A40ABEB504D49D84E40
43436	3	25	850	29695	57744	\N	61.898806999999998	Республика Коми, Усть-Куломский район, п.Тимшер, адрес помещения для голосования: Советская,3, адрес УИК: Советская, 9		0101000020E6100000C286A757CA8E4B403B35971B0CF34E40
43426	3	25	850	29297	57728	\N	61.601528999999999	Республика Коми, Усть-Куломский район, п.Смолянка, Школьная, 2		0101000020E61000006021736550674B403C4CFBE6FECC4E40
43440	3	25	850	29926	\N	\N	62.14367	Республика Коми, Усть-Куломский район, д.Скородум, Здание дома культуры, 124		0101000020E6100000569BFF571D1D4B404AB54FC763124F40
43410	3	25	850	28582	57702	\N	61.810684999999999	Республика Коми, Усть-Куломский район, с.Руч, Центральная, 213		0101000020E610000010ECF82F10964A40CB2DAD86C4E74E40
43449	3	25	850	30403	57782	\N	62.429290000000002	Республика Коми, Усть-Куломский район, д.Пузла, адрес помещения для голосования: Г.Тимушева, 3А, адрес УИК: Г.Тимушева, 7А		0101000020E610000098874CF910564B40FB3F87F9F2364F40
43442	3	25	850	30035	57635	\N	62.194982000000003	Республика Коми, Усть-Куломский район, с.Помоздино, адрес помещения для голосования: В.Т.Чисталева, 1, адрес УИК: А.В.Уляшева, 41		0101000020E6100000C503CAA65C174B4083A7902BF5184F40
43438	3	25	850	29842	57887	\N	62.006321	Республика Коми, Усть-Куломский район, д.Пожегдин, Центральная, 49		0101000020E61000000C040132742A4B4096236420CF004F40
43437	3	25	850	29830	57747	\N	61.974291999999998	Республика Коми, Усть-Куломский район, с.Пожег, адрес помещения для голосования: Школьная, 21, адрес УИК: Центральная, 9		0101000020E610000090BC7328432B4B409160AA99B5FC4E40
43417	3	25	850	28896	57851	\N	61.678055999999998	Республика Коми, Усть-Куломский район, п.Паспом, Школьная, 14		0101000020E6100000156F641EF9CD4A40A46DFC89CAD64E40
43429	3	25	850	29400	57888	\N	61.607446000000003	Республика Коми, Усть-Куломский район, с.Парч, Сельская, 40		0101000020E61000006005F86EF35A4B40030B60CAC0CD4E40
43414	3	25	850	28775	57854	\N	61.821643000000002	Республика Коми, Усть-Куломский район, п.Озъяг, Школьная, 9А		0101000020E610000007F0164850B84A4061FE0A992BE94E40
43416	3	25	850	28861	57890	\N	61.707394999999998	Республика Коми, Усть-Куломский район, с.Носим, Совхозная, 26		0101000020E6100000D8463CD9CDD04A404D2D5BEB8BDA4E40
43423	3	25	850	29188	57885	\N	61.203601999999997	Республика Коми, Усть-Куломский район, с.Нижний Воч, адрес помещения для голосования: Центральная, 191, адрес УИК: Центральная, 25А		0101000020E610000044F9821612164B4039B35DA10F9A4E40
43432	3	25	850	29561	57799	\N	61.749408000000003	Республика Коми, Усть-Куломский район, с.Мыёлдино, адрес помещения для голосования: Здание дома культуры, Центральная 89, адре УИК: Здание администрации сельского поселения, Центральная 90		0101000020E61000001FBC7669C3734B402EAEF199ECDF4E40
43434	3	25	850	29670	57834	\N	61.744484999999997	Республика Коми, Усть-Куломский район, п.Лопъювад, Комсомольская, 4		0101000020E6100000D68D7747C6984B4068AED3484BDF4E40
43421	3	25	850	57341	57950	\N	61.300882000000001	Республика Коми, Усть-Куломский район, п.Логинъяг, Центральная, 6		0101000020E6100000438D429259F94A4040FA264D83A64E40
43413	3	25	850	28715	57883	\N	61.756506000000002	Республика Коми, Усть-Куломский район, с.Кужба, адрес помещения для голосования: Центральная, 44А, адрес УИК: Центральная, 138		0101000020E6100000404E98309ADB4A40289D4830D5E04E40
43420	3	25	850	6314	57743	\N	61.475931192816503	"Республика Коми, Усть-Куломский район, с.Керчомъя, адрес помещения для голосования: Центральная, 22 ""О"", адрес УИК: Центральная, 9 ""О"""	Россия, республика Коми, Усть-Куломский район, село Керчомъя	0101000020E6100000936FB6B931F74A408813984EEBBC4E40
43415	3	25	850	57220	57536	\N	61.727387999999998	Республика Коми, Усть-Куломский район, п.Кебанъёль, адрес помещения для голосования: Гагарина, 1А, адрес УИК: Ленина, 6	Россия, республика Коми, Усть-Куломский район, село Кебаньель	0101000020E610000008228B34F1DA4A405DC0CB0C1BDD4E40
43422	3	25	850	29117	57669	\N	61.258971000000003	Республика Коми, Усть-Куломский район, п.Зимстан, Интернациональная, 1		0101000020E610000081EA1F4432EE4A4064CE33F625A14E40
43431	3	25	850	57258	57777	\N	61.635487519922897	Республика Коми, Усть-Куломский район, с.Дон, Центральная, 73	Россия, республика Коми, Усть-Куломский район, село Дон	0101000020E61000007AC2120F28F34A400F80B8AB57D14E40
43443	3	25	850	30114	57855	\N	62.378076999999998	Республика Коми, Усть-Куломский район, п.Диасёръя, адрес помещения для голосования: Школьный переулок, 1, адрес УИК: Домны Каликовой, 28		0101000020E6100000ABCDFFAB8EE44A40552FBFD364304F40
43424	3	25	850	29211	57928	\N	60.891418000000002	Республика Коми, Усть-Куломский район, с.Дзёль, адрес помещения для голосования: Центральная, 88, адрес УИК: Центральная, 81		0101000020E6100000ADDD76A1B9D44A406A882AFC19724E40
94978	3	25	850	28615	57774	\N	61.760809999999999	Республика Коми, Усть-Куломский район, с.Деревянск, адрес помещения для голосования: Центральная, 246 А, адрес УИК: Центральная, 196 А		0101000020E61000006C96CB46E7A84A40213CDA3862E14E40
43412	3	25	850	28615	57828	\N	61.760809999999999	Республика Коми, Усть-Куломский район, с.Деревянск, Подгорная, 12		0101000020E61000006C96CB46E7A84A40213CDA3862E14E40
43444	3	25	850	30152	57857	\N	62.259115000000001	Республика Коми, Усть-Куломский район, с.Вольдино, адрес помещения для голосования: Центральная, 49В, адрес УИК: Центральная, 61А		0101000020E610000061E0B9F770174B40977329AE2A214F40
43441	3	25	850	30013	\N	\N	62.258062844567803	Республика Коми, Усть-Куломский район, д.Бадьёльск, Здание дома культуры, 111А	Россия, республика Коми, Усть-Куломский район, село Бадъельск	0101000020E61000000E4DD9E907054B4061A7583508214F40
43409	3	25	850	28520	57816	\N	61.871903000000003	Республика Коми, Усть-Куломский район, с.Аныб, Центральная, 184		0101000020E610000038328FFCC1804A4064247B849AEF4E40
43368	3	25	824	57281	57838	\N	62.118493194300903	Республика Коми, Усть-Вымский район, дер.Яг, Молодежная, 17	Россия, республика Коми, Усть-Вымский район, село Яг	0101000020E6100000A6D590B8C7D2484008E753C72A0F4F40
43373	3	25	824	26894	\N	\N	62.219684999999998	Республика Коми, Усть-Вымский район, пос.Черный Яр, 11		0101000020E61000006B49473998254940FC3559A31E1C4F40
43374	3	25	824	26963	57772	\N	62.227873000000002	Республика Коми, Усть-Вымский район, с.Усть-Вымь, Центральная, 64		0101000020E610000003249A40113349401A5245F12A1D4F40
43378	3	25	824	27127	57827	\N	62.161572	Республика Коми, Усть-Вымский район, дер.Туискерес, Школьная, 91		0101000020E6100000D7D9907F6622494083F92B64AE144F40
43375	3	25	824	26991	57731	\N	62.166818999999997	Республика Коми, Усть-Вымский район, пос.Студенец, адрес помещения для голосования: Клубная, 2, адрес УИК: Клубная, 7		0101000020E61000007E3672DD94404940FBAC32535A154F40
43380	3	25	824	27220	57875	\N	62.181756	Республика Коми, Усть-Вымский район, дер.Семуково, Береговая, 45		0101000020E61000009067976F7D12494007EDD5C743174F40
43382	3	25	824	27248	57626	\N	62.365349000000002	Республика Коми, Усть-Вымский район, г.Микунь, Пионерская, 31		0101000020E6100000CAE2FE23D30949402B508BC1C32E4F40
43381	3	25	824	27248	57580	\N	62.365349000000002	Республика Коми, Усть-Вымский район, г.Микунь, Комсомольская, 6		0101000020E6100000CAE2FE23D30949402B508BC1C32E4F40
43383	3	25	824	27248	57575	\N	62.365349000000002	Республика Коми, Усть-Вымский район, г.Микунь, Гоголя, 19		0101000020E6100000CAE2FE23D30949402B508BC1C32E4F40
43361	3	25	824	26322	57726	\N	62.026778	Республика Коми, Усть-Вымский район. пос.Мадмас, Школьная, 32		0101000020E6100000EE2422FC8BA848404B2025766D034F40
43379	3	25	824	27157	\N	\N	62.117171999999997	Республика Коми, Усть-Вымский район, дер.Лыаты, 53		0101000020E6100000EBA9D55757174940E200FA7DFF0E4F40
43376	3	25	824	27049	\N	\N	62.146856	Республика Коми, Усть-Вымский район, дер.Коквицы, 70		0101000020E610000067D311C0CD2E4940569C6A2DCC124F40
43377	3	25	824	27074	57923	\N	62.143191000000002	Республика Коми, Усть-Вымский район, с.Кожмудор, Центральная, 42		0101000020E6100000F5BBB0355B214940700A2B1554124F40
43363	3	25	824	26428	57765	\N	62.106605000000002	Республика Коми, Усть-Вымский район, пос.Казлук, Центральная, 10А		0101000020E61000008198840B79AA4840884B8E3BA50D4F40
43371	3	25	824	26796	57884	\N	62.215851999999998	Республика Коми, Усть-Вымский район, пос.Илья-Шор, Центральная, 31		0101000020E610000023A12DE752E448405A63D009A11B4F40
43365	3	25	824	26498	57666	\N	62.072571000000003	Республика Коми, Усть-Вымский район, пос.Жешарт, Свердлова, 13		0101000020E6100000271422E010CA4840ABD1AB014A094F40
43364	3	25	824	26498	57624	\N	62.072571000000003	Республика Коми, Усть-Вымский район, пос.Жешарт, Первомайская, 23		0101000020E6100000271422E010CA4840ABD1AB014A094F40
43367	3	25	824	26498	57625	\N	62.072571000000003	Республика Коми, Усть-Вымский район, пос.Жешарт, Мира, 2		0101000020E6100000271422E010CA4840ABD1AB014A094F40
43366	3	25	824	26498	57625	\N	62.072571000000003	Республика Коми, Усть-Вымский район, пос.Жешарт, Мира, 7		0101000020E6100000271422E010CA4840ABD1AB014A094F40
43362	3	25	824	57325	57929	\N	62.095682138410098	Республика Коми, Усть-Вымский район, пос.Донаель, Северная, 1	Россия, республика Коми, Усть-Вымский район, село Донаелв	0101000020E610000087BF266BD4B548406E68CA4E3F0C4F40
43370	3	25	824	26773	57898	\N	62.165252000000002	Республика Коми, Усть-Вымский район, дер.Вездино, Центральная, 25		0101000020E61000001EDC9DB5DBF048409FCC3FFA26154F40
43384	3	25	824	5910	57876	\N	62.563585000000003	Республика Коми, Усть-Вымский район, пос.Вежайка, Станционная, д.5		0101000020E610000040BFEFDFBCDE484012C2A38D23484F40
43369	3	25	824	26713	57821	\N	62.125551000000002	Республика Коми, Усть-Вымский район, дер.Арабач, пер.Клубный, 26А		0101000020E61000002B2FF99FFCE94840747D1F0E12104F40
43372	3	25	824	26864	57630	\N	62.218800999999999	Республика Коми, Усть-Вымский район, с.Айкино, адрес помещения для голосования: Центральная, 131, адрес УИК, Центральная, 126	Россия, республика Коми, Усть-Вымский район, село Айкино	0101000020E6100000BA1457957DFF484082AAD1AB011C4F40
43177	3	25	7429	57316	57913	\N	66.289820000000006	Республика Коми, г.Усинск, с.Щельябож, адрес помещения для голосования: Центральная, 36, адрес УИК: Молодежная, 55	Россия, республика Коми, Усинский район, село Щельябож	0101000020E6100000E674594C6C3A4C40836E2F698C925040
43173	3	25	7429	57250	57740	\N	65.978433549862103	Республика Коми, г.Усинск, с.Усть-Уса, адрес помещения для голосования: Советская, 36, адрес УИК: Пушкина, 13	Россия, республика Коми, Усинский район, село Усть-Уса	0101000020E61000007E74EACA67754C40D8D2A3A99E7E5040
43175	3	25	7429	57278	57823	\N	65.682779417190702	Республика Коми, г.Усинск, с.Усть-Лыжа, адрес помещения для голосования: Центральная, 16, адрес УИК: Центральная, 60	Россия, республика Коми, Усинский район, село Усть-Лыжа	0101000020E6100000349F73B7EB554C4051D9B0A6B26B5040
43170	3	25	7429	57222	57549	\N	65.956943822098907	Республика Коми, г.Усинск, пгт.Парма, Школьная, 13А	Россия, республика Коми, Усинский район, поселок Парма	0101000020E6100000A1F65B3B51BC4C409E060C923E7D5040
43174	3	25	7429	57268	57798	\N	66.028012820254801	Республика Коми, г.Усинск, дер.Новикбож, адрес помещения для голосования: Школьная, 7, адрес УИК : Школьная, 26	Россия, республика Коми, Усинский район, село Новикбож	0101000020E610000001A4367172714C4039B709F7CA815040
43179	3	25	7429	57252	57750	\N	65.9507551787203	Республика Коми, г.Усинск, с.Мутный Материк, адрес помещения для голосования: Центральная, 56, адрес УИК: Центральная, 49	Россия, республика Коми, Усинский район, село Мутный Материк	0101000020E610000099D53BDC0E914B408BE07F2BD97C5040
43172	3	25	7429	57318	57916	\N	65.965666999999996	Республика Коми, г.Усинск, с.Колва, адрес помещения для голосования: Центральная, 35, адрес УИК: Молодежная, 22	Россия, республика Коми, Усинский район, село Колва	0101000020E61000007BA2EBC20FAE4C40E4F4F57CCD7D5040
43178	3	25	7429	57261	57783	\N	66.330813815535905	Республика Коми, г.Усинск, дер.Захарвань, Школьный переулок, 1	Россия, республика Коми, Усинский район, село Захарвань	0101000020E61000000AA359D93EF04B40C6C37B0E2C955040
43176	3	25	7429	57310	\N	\N	65.841145075717904	Республика Коми, г.Усинск, дер.Акись, адрес помещения для голосования: здание дома культуры, адрес УИК: здание библиотеки	Россия, республика Коми, Усинский район, село Акись	0101000020E6100000253E7782FD5F4C40698CD651D5755040
43338	3	25	756	25291	57865	\N	63.449413	Республика Коми, Удорский район, п.Ыджыдъяг, Лесная, 7		0101000020E61000000BD0B69A75724840D9B27C5D86B94F40
43349	3	25	756	52918	\N	\N	64.223202999999998	Республика Коми, Удорский район, адрес помещения для голосования: с.Чупрово, 152, адрес УИК: с.Чупрово, 153		0101000020E6100000E8BF07AF5D4847409F573CF5480E5040
43343	3	25	756	5333	57814	\N	63.42859	Республика Коми, Удорский район, п.Чим, адрес помещения для голосования: Школьный переулок, 10, адрес УИК: Строителей, 8		0101000020E610000012D90759161E484042B28009DCB64F40
43340	3	25	756	25378	\N	\N	63.763666000000001	Республика Коми, Удорский район, с.Чернутьево, 64		0101000020E6100000AB09A2EE035248409888B7CEBFE14F40
43352	3	25	756	25875	57869	\N	63.436379000000002	Республика Коми, Удорский район, пгт.Усогорск, Привокзальная, 9		0101000020E6100000ED832C0B26584840A2D45E44DBB74F40
43351	3	25	756	25875	57574	\N	63.436379000000002	Республика Коми, Удорский район, пгт.Усогорск, адрес помещения для голосования: Ленина, 18, адрес УИК: Дружбы, 17		0101000020E6100000ED832C0B26584840A2D45E44DBB74F40
43350	3	25	756	25875	57573	\N	63.436379000000002	Республика Коми, Удорский район, пгт.Усогорск, Дружбы, 17		0101000020E6100000ED832C0B26584840A2D45E44DBB74F40
43355	3	25	756	26084	57815	\N	63.448017999999998	Республика Коми, Удорский район, п.Солнечный, Таежная, 7		0101000020E61000004B75012F33F84740790261A758B94F40
43357	3	25	756	5774	57812	\N	63.305466000000003	Республика Коми, Удорский район, п.Селэгвож, ул.Привокзальная, д.16		0101000020E610000049D8B793884448401D05888219A74F40
43339	3	25	756	25320	\N	\N	63.693505000000002	Республика Коми, Удорский, д.Сельыб, 84		0101000020E61000007BA35698BE494840664E97C5C4D84F40
43353	3	25	756	25993	\N	\N	63.479165000000002	Республика Коми, Удорский район, д.Разгорт, 31		0101000020E61000003CDC0E0D8B594840A5315A4755BD4F40
43348	3	25	756	25793	\N	\N	64.153389000000004	Республика Коми, Удорский район, д.Муфтюга, 106		0101000020E61000009FE925C6325F47403CA41820D1095040
43359	3	25	756	26243	57810	\N	62.928139000000002	Республика Коми, Удорский район, п.Мозындор, Ленина, 14		0101000020E61000002DCF83BBB398484032923D42CD764F40
43356	3	25	756	7035	57668	\N	63.222068	Республика Коми, Удорский район, пгт.Междуреченск, 5, ул.Интернациональная, д.5		0101000020E61000007A51BB5F054848407BBE66B96C9C4F40
43342	3	25	756	25482	\N	\N	64.167663000000005	Республика Коми, Удорский район, д.Малая Пысса, 40		0101000020E6100000FCC3961E4D6D4840F46F97FDBA0A5040
43345	3	25	756	25615	\N	\N	63.964945999999998	Республика Коми, Удорский район, д.Кривое, 12		0101000020E61000002C45F295408E4740F833BC5983FB4F40
43336	3	25	756	25164	57520	\N	63.458900999999997	Республика Коми, Удорский район, с.Кослан, адрес помещения для голосования: Центральная, 140а, адрес УИК: Трофимовой, 3		0101000020E610000075E4486760724840048D9944BDBA4F40
43344	3	25	756	25576	\N	\N	63.547106999999997	Республика Коми, Удорский район, с.Ёртом, 45/1		0101000020E61000004F029B73F0E84740D234289A07C64F40
43358	3	25	756	5499	57768	\N	63.061613000000001	Республика Коми, Удорский район, п.Ёдва, Комсомольская, 1		0101000020E6100000C6BFCFB87070484015014EEFE2874F40
43334	3	25	756	52883	\N	\N	63.479790000000001	Республика Коми, Удорский район, адрес помещения для голосования: с.Глотово, 48, адрес УИК: с.Глотово, 16		0101000020E61000001FF7ADD689BD484053793BC269BD4F40
43360	3	25	756	26302	57924	\N	62.830866999999998	Республика Коми, Удорский район, п.Вожский, Административный переулок, 1		0101000020E6100000ACC43C2B69A74840AE2990D9596A4F40
43346	3	25	756	25679	\N	\N	64.013232000000002	Республика Коми, Удорский район, с.Важгорт, 211		0101000020E61000003C6C223317864740AFD007CBD8005040
43335	3	25	756	52885	\N	\N	63.364117999999998	Республика Коми, Удорский район, адрес помещения для голосования: с.Буткан, 133, адрес УИК: с.Буткан, 131		0101000020E61000002F6D382C0D8C484045F12A6B9BAE4F40
43341	3	25	756	25413	57880	\N	64.167361999999997	Республика Коми, Удорский район, с.Пысса, Центральная, 19/1		0101000020E6100000DA8CD310556A4840F6251B0FB60A5040
43347	3	25	756	52914	\N	\N	64.070344000000006	Республика Коми, Удорский район, адрес помещения для голосования: с.Пучкома, 129, адрес УИК: с.Пучкома, 131		0101000020E610000055DB4DF04D73474012DE1E8480045040
95162	3	25	756	26054	57477	\N	63.424106999999999	Республика Коми, Удорский район, пгт.Благоево, Дружбы, 8		0101000020E6100000E3A6069ACFF9474099805F2349B64F40
43386	3	25	833	32658	57754	\N	61.822068000000002	Республика Коми, Троицко-Печорский район, пст.Якша, Школьная, 25		0101000020E610000053EA92718C6A4C40488B338639E94E40
43393	3	25	833	57297	57868	\N	62.517079000000003	Республика Коми, Троицко-Печорский район, пст.Усть-Илыч, Центральная, 82	Россия, республика Коми, Троицко-Печорский район, село Усть-Илыч	0101000020E6100000F564FED1375F4C40653909A52F424F40
43397	3	25	833	6027	\N	\N	62.714745000000001	Республика Коми, пгт.Троицко-Печорск, Красногвардейская, 19	Россия, республика Коми, Троицко-Печорский район, поселок Троицко-Печорск	0101000020E61000000CCB9F6F0B144C4061FD9FC37C5B4F40
43401	3	25	833	6027	57670	\N	62.714745000000001	Республика Коми, пгт.Троицко-Печорск, кв.южный, 13		0101000020E61000000CCB9F6F0B144C4061FD9FC37C5B4F40
43402	3	25	833	6027	57813	\N	62.714745000000001	Республиуа Коми, пгт.Троицко-Печорск, кв.Южный, 13		0101000020E61000000CCB9F6F0B144C4061FD9FC37C5B4F40
43399	3	25	833	6027	57667	\N	62.714745000000001	Республика Коми, пгт.Троицко-Печорск, Портовая, 4		0101000020E61000000CCB9F6F0B144C4061FD9FC37C5B4F40
43407	3	25	833	57339	57945	\N	63.127583000000001	Республика Коми, Троицко-Печорский район, пст.Тимушбор, Лесная, 13	Россия, республика Коми, Троицко-Печорский район, село Тимушбор	0101000020E6100000215B96AFCBFC4B404643C6A354904F40
43406	3	25	833	57331	57935	\N	62.929516	Республика Коми, Троицко-Печорский район, пст.Русаново, Школьная, 16	Россия, республика Коми, Троицко-Печорский район, село Русаново	0101000020E610000073A1F2AFE5154C40EB8D5A61FA764F40
43390	3	25	833	57335	57941	\N	62.622432000000003	Республика Коми, Троицко-Печорский район, пст.Приуральский, Лесная, 4	Россия, республика Коми, Троицко-Печорский район, село Приуральский	0101000020E6100000CF49EF1B5FBB4C40F0FD0DDAAB4F4F40
43405	3	25	833	28346	57877	\N	62.944825000000002	Республика Коми, Троицко-Печорский район, с.Покча, Центральная, 13		0101000020E6100000AE7E6C921F0F4C40BBB88D06F0784F40
43391	3	25	833	57336	57942	\N	62.512630000000001	Республика Коми, Троицко-Печорский район, пст.Палью, Школьная, 1	Россия, республика Коми, Троицко-Печорский район, село Палью	0101000020E610000085CD0017646F4C4068791EDC9D414F40
43403	3	25	833	32803	57735	\N	62.757347000000003	Республика Коми, Троицко-Печорский район, пст.Нижняя-Омра, Советская, 6а		0101000020E6100000E57FF277EFEA4B40A35C1ABFF0604F40
43408	3	25	833	57272	\N	\N	63.187730117708099	Республика Коми, Троицко-Печорский район, пст.Митрофан-Дикост, Здание Дома  культуры	Россия, республика Коми, Троицко-Печорский район, село Митрофан-Дикост	0101000020E6100000575C1C959B104C40323D618907984F40
43385	3	25	833	27444	57879	\N	61.681927000000002	Республика Коми, Троицко-Печорский район, с.Курья, Школьная, 21		0101000020E61000007F85CC95419F4C4034A1496249D74E40
43387	3	25	833	32664	57758	\N	62.140551000000002	Республика Коми, Троицко-Печорский район, пст.Комсомольск-на-Печоре, Комсомольская, 12		0101000020E610000022C66B5ED54D4C40C6353E93FD114F40
43388	3	25	833	57334	57938	\N	61.970534999999998	Республика Коми, Троицко-Печорский район, пст.Знаменка, Сплавная, 15	Россия, республика Коми, Троицко-Печорский район, село Знаменка	0101000020E6100000810A47904A6D4C40CA4FAA7D3AFC4E40
43389	3	25	833	27629	57925	\N	62.626705000000001	Республика Коми, Троицко-Печорский район, д.Еремеево, Попова, 53		0101000020E610000025ADF886C2C54C40AE9E93DE37504F40
43394	3	25	833	57338	57944	\N	62.554290000000002	Республика Коми, Троицко-Печорский район, пст.Белый Бор, Комсомольская, 17	Россия, республика Коми, Троицко-Печорский район, село Белый Бор	0101000020E61000001764CBF275334C40FB3F87F9F2464F40
43404	3	25	833	62096	81134	\N	62.768856085171301	Республика Коми, Троицко-Печорский район, пст.Бадь-Ёль, Почтовая, 8	Россия, республика Коми, Троицко-Печорский район, село Бадъель	0101000020E610000024809BC58BD14B40ACAA97DF69624F40
43398	3	25	7428	57219	57527	\N	62.714745000000001	Республика Коми, пгт.Троицко-Печорск, Ленина, 17		0101000020E61000000CCB9F6F0B144C4061FD9FC37C5B4F40
43519	3	25	199	1602	57895	\N	60.952776	Республика Коми,Сысольский район,п.Щугрэм, Центральная, 1а		0101000020E61000008D9B1A683EB94840F4346090F4794E40
43507	3	25	199	32813	\N	\N	61.152815380563901	Республика Коми,Сысольский район,с.Межадор, адрес помещения для голосования:дер.Шорсай, 28, адрес УИК:дер.Шорсай, 51	Россия, республика Коми, Сысольский район, село Шорсай	0101000020E610000009C556D0B42A49404BAB21718F934E40
43505	3	25	199	756	57921	\N	61.222293000000001	Республика Коми,Сысольский район,с.Чухлэм, местечко Чоййыв, 31		0101000020E6100000B2135E82531749409B90D618749C4E40
43520	3	25	199	1685	\N	\N	60.941338000000002	Республика Коми,Сысольский район,с.Пыелдино, адрес помещения для голосования:дер.Вичкодор,16, адрес УИК:дер.Кузивансикт, 34а		0101000020E61000001C7E37DDB21D4940B43D7AC37D784E40
43509	3	25	199	1032	57708	\N	61.120353999999999	Республика Коми,Сысольский район,п.Первомайский, Центральная, 11а		0101000020E61000004434BA83D8234940ADF886C2678F4E40
43526	3	25	199	2037	57785	\N	60.711692999999997	Республика Коми,Сысольский район,с.Палауз, адрес помещения для голосования:Большая,48, адрес УИК:Большая, 18		0101000020E610000023BC3D080123494064E597C1185B4E40
43516	3	25	199	1431	\N	\N	60.907963000000002	Республика Коми,Сысольский район,с.Куратово, 57	Россия, республика Коми, Сысольский район, село Куратово	0101000020E6100000E4310395F1DB4840317DAF2138744E40
43510	3	25	199	1074	\N	\N	61.115769	Республика Коми,Сысольский район,с.Куниб, 34		0101000020E610000032569BFF572149400072C284D18E4E40
43523	3	25	199	1804	57784	\N	60.998600000000003	Республика Коми,Сысольский район,п.Исанево, Центральная, 5		0101000020E6100000AB402D060F2B49408FE4F21FD27F4E40
43517	3	25	199	57301	\N	\N	60.893453000000001	Республика Коми,Сысольский район,с.Куратово, дер.Заречное, 60а	Россия, республика Коми, Сысольский район, село Заречное	0101000020E6100000F81BEDB8E1D54840ADC1FBAA5C724E40
43522	3	25	199	1792	57718	\N	60.909576999999999	Республика Коми,Сысольский район,п.Заозерье, адрес помещения для голосования:Центральная,25, адрес УИК:Лесная, 16		0101000020E61000000DE02D90A0264940CE18E6046D744E40
43506	3	25	199	874	57870	\N	61.310074999999998	Республика Коми,Сысольский район,п.Ельбаза, Новосельская, 7		0101000020E610000043588D25AC1149405227A089B0A74E40
43180	3	25	199	57299	57871	\N	61.216538868006403	Республика Коми, г.Усинск, дер.Денисовка, Центральная, 12		0101000020E6100000E1B4E0455F1B49407EA7C98CB79B4E40
43525	3	25	199	1930	\N	\N	60.792532999999999	Республика Коми,Сысольский район,с.Гагшор, 92		0101000020E61000004DD6A887681849401900AAB871654E40
43508	3	25	199	981	\N	\N	61.084296999999999	Республика Коми,Сысольский район,с.Вотча, дер.Ляпин, 2а		0101000020E61000000B96EA025E2C494051137D3ECA8A4E40
43518	3	25	199	1556	57899	\N	60.967830999999997	Республика Коми,Сысольский район,п.Визиндор, Комсомольская, 3а		0101000020E6100000CEC64ACCB3D848400987DEE2E17B4E40
43513	3	25	199	1156	\N	\N	61.072470000000003	Республика Коми,Сысольский район,с.Визинга, дер.Горьковская, 114		0101000020E61000003579CA6ABA0C494077F86BB246894E40
43514	3	25	199	1156	57535	\N	61.072470000000003	Республика Коми,Сысольский район,сВизинга, адрес помещения для голосования:Советская,17, адрес УИК:Советская, 28		0101000020E61000003579CA6ABA0C494077F86BB246894E40
43512	3	25	199	1156	57535	\N	61.072470000000003	Республика Коми,Сысольский район,с.Визинга, адрес помещения для голосования:Советская, 17, адрес УИК:Советская, 28		0101000020E61000003579CA6ABA0C494077F86BB246894E40
43511	3	25	199	1156	57535	\N	61.072470000000003	Республика Коми,Сысольский район,с.Визинга, адрес помещения для голосования:Советская,37а, адрес УИК:Советская, 28		0101000020E61000003579CA6ABA0C494077F86BB246894E40
43515	3	25	199	1156	57555	\N	61.072470000000003	Сысольский район,с.Визинга, адрес помещения для голосования:Оплеснина,47, адрес УИК:Советская, 28		0101000020E61000003579CA6ABA0C494077F86BB246894E40
43521	3	25	199	1905	\N	\N	60.914423999999997	Республика Коми,Сысольский район,с.Пыелдино, адрес помещения для голосования:дер.Бортом,20, адрес УИК:дер.Кузивансикт, 34а	Россия, республика Коми, Сысольский район, село Бортом	0101000020E6100000A9A0A2EA571A4940B8567BD80B754E40
43524	3	25	199	1905	57896	\N	60.914423999999997	Республика Коми,Сысольский район,п.Бортом, Центральная, 28		0101000020E6100000A9A0A2EA571A4940B8567BD80B754E40
43483	3	25	86	32624	57748	\N	61.179839000000001	Республика Коми, Сыктывдинский район, пст.Яснэг, Ленина, 13		0101000020E610000040F9BB77D4504940CEC5DFF604974E40
43497	3	25	86	289	\N	\N	61.957125018365403	"Республика Коми, Сыктывдинский район, пст.Язель, железнодорожная станция ""Язель"", д. 8"	Россия, республика Коми, Сыктывдинский район, село Язель	0101000020E610000087527B116D4F49408D976E1283FA4E40
43485	3	25	86	57240	57737	\N	61.280020258497998	Республика Коми, Сыктывдинский район, с.Ыб, м.Погост, 133	Россия, республика Коми, Сыктывдинский район, село Ыб	0101000020E6100000FB22A12DE7484940EB1C03B2D7A34E40
43490	3	25	86	6237	57863	\N	61.501604999999998	Республика Коми, Сыктывдинский район, с.Шошка, м.Педегрезд, 11		0101000020E610000028F224E99A5B49404A41B79734C04E40
43498	3	25	86	371	57752	\N	62.013474000000002	Республика Коми, Сыктывдинский район, с.Часово, Береговая, 18Б		0101000020E61000000A4B3CA06C54494054AC1A84B9014F40
43502	3	25	86	598	57713	\N	61.951897000000002	Республика Коми, Сыктывдинский район, с.Слудка, Новоселов, 8		0101000020E6100000842C0B26FE1649408C14CAC2D7F94E40
43496	3	25	86	240	57864	\N	61.932152000000002	Республика Коми, Сыктывдинский район, дер.Парчег, ул. Боровая, д. 17		0101000020E6100000A835CD3B4E6349405473B9C150F74E40
43501	3	25	86	551	57757	\N	61.994022000000001	Республика Коми, Сыктывдинский район, с.Палевицы, Набережная, 9		0101000020E610000002D71533C22D494094C0E61C3CFF4E40
43487	3	25	86	6227	57637	\N	61.389633000000003	Республика Коми, Сыктывдинский район, с.Пажга, 1 микрорайон, д. 22		0101000020E61000005E488787304A4940A038807EDFB14E40
43482	3	25	86	31960	57841	\N	61.774143000000002	Республика Коми, Сыктывдинский район, с.Озёл, клуб села Озёл, Озёльская, 55А		0101000020E6100000740CC85EEF8A4940B3B6291E17E34E40
43489	3	25	86	57340	57946	\N	61.395574000000003	Республика Коми, Сыктывдинский район, пст.Нювчим, Первомайская, 12	Россия, республика Коми, Сыктывдинский район, поселок Нювчим	0101000020E61000006F48A302275F4940EF92382BA2B24E40
43503	3	25	86	57323	57926	\N	61.691960000000002	Республика Коми, Сыктывдинский район, пст.Мандач, Лесная, 44	Россия, республика Коми, Сыктывдинский район, село Мандач	0101000020E61000006B11514CDE164940F111312592D84E40
43499	3	25	86	375	\N	\N	62.020684000000003	Республика Коми, Сыктывдинский район, дер.Красная, 69		0101000020E6100000B4AED172A067494076C6F7C5A5024F40
43500	3	25	86	506	57893	\N	61.998942999999997	Республика Коми, Сыктывдинский район, дер.Ивановка, Северная, 20		0101000020E6100000E8C1DD59BB394940B8C83D5DDDFF4E40
43495	3	25	86	110	57524	\N	61.889754000000003	Республика Коми, Сыктывдинский район, с.Зеленец, адрес помещения для голосования: 2 квартал, 17А, адрес УИК: 2 квартал, 12А		0101000020E6100000D4484BE5ED5E49401BBE8575E3F14E40
43484	3	25	86	32074	\N	\N	61.225658000000003	Республика Коми, Сыктывдинский район, дер.Захарово, 49		0101000020E61000002861A6ED5F474940570A815CE29C4E40
43486	3	25	86	32639	\N	\N	61.378459999999997	Республика Коми, Сыктывдинский район, пст.Гарьинский, Набережная, 15	Россия, республика Коми, Сыктывдинский район, село Гарьинский	0101000020E6100000745DF8C1F94C49400D6C956071B04E40
43491	3	25	86	103	57528	\N	61.624110259308402	Республика Коми, Сыктывдинский район, с.Выльгорт, Тимирязева, 36	Россия, республика Коми, Сыктывдинский район, село Выльгорт	0101000020E6100000CC7F48BF7D614940A48D23D6E2CF4E40
43476	3	25	86	103	57749	\N	61.618465	Республика Коми, Сыктывдинский район, с.Выльгорт, Северная, 22		0101000020E610000085949F54FB6049403E5C72DC29CF4E40
43494	3	25	86	103	57546	\N	61.618465	Республика Коми, Сыктывдинский район, с.Выльгорт, Домны Каликовой, 60		0101000020E610000085949F54FB6049403E5C72DC29CF4E40
43493	3	25	86	103	57546	\N	61.618465	Республика Коми, Сыктывдинский район, с.Выльгорт, Домны Каликовой, 57		0101000020E610000085949F54FB6049403E5C72DC29CF4E40
43229	3	25	895	57245	57732	\N	63.619608999999997	Республика Коми, г.Сосногорск, с.Усть-Ухта, Лесная, 8А	Россия, республика Коми, Сосногорский район, село Усть-Ухта	0101000020E61000004A0D6D0036F04A4054A703594FCF4F40
43241	3	25	895	6907	79494	\N	63.573456	Республика Коми, г.Сосногорск, ул. Спортивная,  д.6	Россия, республика Коми, Сосногорский район, Сосногорск	0101000020E6100000DEE7F86871F64A40F5D8960167C94F40
43239	3	25	895	6907	57610	\N	63.573684999999998	Республика Коми, г.Сосногорск, Куратова, 4	Россия, республика Коми, Сосногорский район, Сосногорск	0101000020E6100000DEE7F86871F64A40569A94826EC94F40
43230	3	25	895	57298	\N	\N	63.916654830878699	Республика Коми, г.Сосногорск, дер.Порожск, Дом фольклорного творчества	Россия, республика Коми, Сосногорский район, село Порожок	0101000020E61000006F2A52616CDF4A40815B77F354F54F40
43251	3	25	895	57251	57742	\N	63.542648458139801	Республика Коми, г.Сосногорск, пст.Поляна, Мира, 12		0101000020E6100000BB0ED59464094B40B29E5A7D75C54F40
43247	3	25	895	57215	57621	\N	63.6376493533337	Республика Коми, г.Сосногорск, пгт.Нижний Одес, пл.Ленина, 3	Россия, республика Коми, Сосногорский район, поселок Нижний Одес	0101000020E6100000FC8C0B07426C4B40DFA9807B9ED14F40
43246	3	25	895	57215	57504	\N	63.641130959138501	Республика Коми, г.Сосногорск, пгт.Нижний Одес, Северная, 4А	Россия, республика Коми, Сосногорский район, поселок Нижний Одес	0101000020E61000003B342C465D6B4B40D4B9A29410D24F40
43244	3	25	895	57215	57504	\N	63.644106999999998	Республика Коми, г.Сосногорск, пгт.Нижний Одес, Северная, 8	Россия, республика Коми, Сосногорский район, поселок Нижний Одес	0101000020E6100000B4E6C75F5A6A4B40F50F221972D24F40
43243	3	25	895	57215	57607	\N	63.644106999999998	Республика Коми, г.Сосногорск, пгт.Нижний Одес, Пионерская, 3А	Россия, республика Коми, Сосногорский район, поселок Нижний Одес	0101000020E6100000B4E6C75F5A6A4B40F50F221972D24F40
43245	3	25	895	57215	57510	\N	63.644069000000002	Республика Коми, г.Сосногорск, пгт.Нижний Одес, Ленина, 1А	Россия, республика Коми, Сосногорский район, поселок Нижний Одес	0101000020E610000090A2CEDC436A4B4008AF5DDA70D24F40
43255	3	25	895	57223	57557	\N	64.180718999999996	Республика Коми, г.Сосногорск, пст.Малая Пера, Советская, 10	Россия, республика Коми, Сосногорский район, село Малая Пера	0101000020E61000005BEB8B84B66A4B4003B16CE6900B5040
43253	3	25	895	57242	57724	\N	63.725095000000003	Республика Коми, г.Сосногорск, пст.Керки, Лесная, 16А	Россия, республика Коми, Сосногорский район, село Керки	0101000020E6100000C64FE3DEFC184B401FBFB7E9CFDC4F40
43256	3	25	895	57243	57725	\N	64.406227999999999	Республика Коми, г.Сосногорск, пст.Ираёль, 40 лет Победы, 5	Россия, республика Коми, Сосногорский район, село Ирасль	0101000020E6100000F0F78BD992994B400CAEB9A3FF195040
43249	3	25	895	57237	57722	\N	62.8911494447023	Республика Коми, г.Сосногорск, пгт.Войвож, Октябрьская, 23	Россия, республика Коми, Сосногорский район, поселок Войвож	0101000020E610000077499C15517B4B407A6EA12B11724F40
43250	3	25	895	57237	57704	\N	62.891443190247003	Республика Коми, г.Сосногорск, пгт.Войвож, Кирова, 2А	Россия, республика Коми, Сосногорский район, поселок Войвож	0101000020E6100000711B0DE02D7C4B40C39FE1CD1A724F40
43254	3	25	895	57236	57701	\N	63.914337000000003	Республика Коми, г.Сосногорск, пст.Вис, Ленина, 14	Россия, республика Коми, Сосногорский район, село Вис	0101000020E61000006B4AB20E47394B40EA42ACFE08F54F40
43248	3	25	895	57249	57738	\N	62.998191200208097	Республика Коми, г.Сосногорск, пст.Верхнеижемский, Садовая, 107	Россия, республика Коми, Сосногорский район, село Верхнеижемский	0101000020E6100000C119FCFD62584B40AD1402B9C47F4F40
43252	3	25	7426	57304	\N	\N	63.593108388726101	Республика Коми, г.Сосногорск, дер.Пожня, Дом культуры	Россия, республика Коми, Сосногорск городской округ	0101000020E6100000503A9160AAFB4A407C7F83F6EACB4F40
43233	3	25	7426	57213	57500	\N	63.598203295734898	Республика Коми, г.Сосногорск, Гоголя, 7	Россия, республика Коми, Сосногорск городской округ	0101000020E610000001F73C7FDAF24A403EAF78EA91CC4F40
43583	3	25	420	57327	57931	\N	59.375869236362298	Республика Коми, Прилузский район, пст.Якуньель, Первомайская, 9	Россия, республика Коми, Прилузский район, село Якуньель	0101000020E610000009C1AA7AF9E34840454AB3791CB04D40
43552	3	25	420	3520	57881	\N	60.472940999999999	Республика Коми, Прилузский район, с.Читаево, Центральная, 22		0101000020E6100000C9224DBC03C8484001F8A754893C4E40
43563	3	25	420	4062	57911	\N	60.215943000000003	Республика Коми, Прилузский район, с.Черныш, Центральная, 59		0101000020E61000008E3C1059A4CD48406B662D05A41B4E40
43577	3	25	420	4804	57908	\N	59.529490000000003	Республика Коми, Прилузский район, с.Черемуховка, Центральная, 74		0101000020E6100000494739984DBE48408FC70C54C6C34D40
43576	3	25	420	4804	57709	\N	59.529490000000003	Республика Коми, Прилузский район, с.Черемуховка, Октябрьская, 22		0101000020E6100000494739984DBE48408FC70C54C6C34D40
43565	3	25	420	57287	57846	\N	60.15748	Республика Коми, Прилузский район, пст.Чекша, Центральная, 13	Россия, республика Коми, Прилузский район, село Чекша	0101000020E610000097A8DE1AD8C2484015E3FC4D28144E40
43562	3	25	420	57309	57900	\N	60.224812999999997	Республика Коми, Прилузский район, пст.Усть-Лопью, Центральная, 26	Россия, республика Коми, Прилузский район, село Усть-Лопью	0101000020E6100000882B67EF8CD048409A5B21ACC61C4E40
43550	3	25	420	3408	57714	\N	60.644947000000002	Республика Коми, Прилузский район, с.Спаспоруб, Лобанова, 2		0101000020E61000001F48DE3994854840A053909F8D524E40
43584	3	25	420	5178	57796	\N	59.38364	Республика Коми, Прилузский район, с.Слудка, Центральная, 2		0101000020E61000006ADB300A82DB4840FEB7921D1BB14D40
43585	3	25	420	5247	57795	\N	59.280760999999998	Республика Коми, Прилузский район, с.Прокопьевка, Центральная, 17		0101000020E61000003D2AFEEF88D64840027FF8F9EFA34D40
43549	3	25	420	3325	\N	\N	60.769457000000003	Республика Коми, Прилузский район, д.Поруб-Кеповская, 19		0101000020E6100000728C648F507F4840D25625917D624E40
43578	3	25	420	57289	57847	\N	59.526539	Республика Коми, Прилузский район, пст.Пожемаяг, Центральная, 7	Россия, республика Коми, Прилузский район, село Пожемаяг	0101000020E6100000045ABA826DC24840C68844A165C34D40
43564	3	25	420	57282	57839	\N	60.183114000000003	Республика Коми, Прилузский район, пст.Орысь, Центральная, 14	Россия, республика Коми, Прилузский район, село Орысь	0101000020E6100000AED3484BE5B148404AB8904770174E40
43571	3	25	420	57313	57907	\N	59.927778033878802	Республика Коми, Прилузский район, пст.Оньмесь, Лесная, 2	Россия, республика Коми, Прилузский район, село Оньмесь	0101000020E610000070B378B1306C484062F9F36DC1F64D40
43543	3	25	420	2257	57526	\N	60.337701000000003	Республика Коми, Прилузский район, с.Объячево, Центральная, 9		0101000020E610000010786000E1CD4840CB694FC9392B4E40
43559	3	25	420	2257	57629	\N	60.332947649925998	Республика Коми, Прилузский район, с.Объячево, Мира, 69	Россия, республика Коми, Прилузский район, село Объячево	0101000020E61000001157CEDE19CF484062A2410A9E2A4E40
43557	3	25	420	2257	57629	\N	60.337701000000003	Республика Коми, Прилузский район, с.Объячево, Мира, 132		0101000020E610000010786000E1CD4840CB694FC9392B4E40
43530	3	25	420	2257	57629	\N	60.337701000000003	Республика Коми, Прилузский район, с.Объячево, Мира, 81		0101000020E610000010786000E1CD4840CB694FC9392B4E40
43567	3	25	420	4237	57717	\N	60.147392000000004	Республика Коми, Прилузский район, с.Ношуль, Советская, 29		0101000020E61000001844A4A65DC0484095D8B5BDDD124E40
43566	3	25	420	4237	57910	\N	60.147392000000004	Республика Коми, Прилузский район, с.Ношуль, Калинина, 10		0101000020E61000001844A4A65DC0484095D8B5BDDD124E40
43580	3	25	420	4960	57882	\N	59.481195	Республика Коми, Прилузский район, с.Мутница, Дуговая, 18		0101000020E6100000BAF3C473B6C24840D6FF39CC97BD4D40
43547	3	25	420	3210	57906	\N	60.551115000000003	Республика Коми, Прилузский район, с.Лойма, Центральная, 20		0101000020E6100000823CBB7CEB674840E3AAB2EF8A464E40
43568	3	25	420	57330	57934	\N	60.147712986837199	Республика Коми, Прилузский район, д.Лихачевка, Школьная, 6	Россия, республика Коми, Прилузский район, село Лихачевская	0101000020E610000002A08A1BB7B04840D7187442E8124E40
43575	3	25	420	4683	57631	\N	59.611955000000002	Республика Коми, Прилузский район, с.Летка, Советская, 61		0101000020E61000001FF5D72B2CB64840D5CF9B8A54CE4D40
43574	3	25	420	4683	57631	\N	59.611955000000002	Республика Коми, Прилузский район, с.Летка, Советская, 62	Россия, республика Коми, Прилузский район, село Летка	0101000020E61000001FF5D72B2CB64840D5CF9B8A54CE4D40
43553	3	25	420	57312	57905	\N	60.491948000000001	Республика Коми, Прилузский район, пст.Кыддзявидзь, Гагарина, 12	Россия, республика Коми, Прилузский район, село Кыддзявидзь	0101000020E6100000554D10751FCC484093AAED26F83E4E40
43561	3	25	420	57311	57903	\N	60.415093840646598	Республика Коми, Прилузский район, пст.Изъяшор, Набережная, 2	Россия, республика Коми, Прилузский район, село Коржинский	0101000020E61000000D6D0036204A48400762D9CC21354E40
43545	3	25	420	57311	57903	\N	60.413927000000001	Республика Коми, Прилузский район, пст.Коржинский, Лесная, 15	Россия, республика Коми, Прилузский район, село Коржинский	0101000020E6100000A03369537549484038F7578FFB344E40
43546	3	25	420	3190	\N	\N	60.533653999999999	Республика Коми, Прилузский район, д.Козловская, 21		0101000020E610000003D19332A963484096B036C64E444E40
43556	3	25	420	3728	\N	\N	60.356309000000003	Республика Коми, Прилузский район, д.Калининская, 55		0101000020E6100000F60CE19865C348409F2287889B2D4E40
43551	3	25	420	3438	57790	\N	60.642361999999999	Республика Коми, Прилузский район, с.Занулье, Центральная, 29		0101000020E610000002D6AA5D13B24840B91803EB38524E40
43579	3	25	420	57292	57850	\N	60.211282178155002	Республика Коми, Прилузский район, пст.Гуляшор, Мира, 4	Россия, республика Коми, Прилузский район, село Гыркашор	0101000020E6100000895C70067FDB4840E21DE0490B1B4E40
43582	3	25	420	5065	57751	\N	59.429640999999997	Республика Коми, Прилузский район, с.Гурьевка, Школьная, 9		0101000020E610000042B456B439CC4840A702EE79FEB64D40
43573	3	25	420	4606	\N	\N	59.685766000000001	Республика Коми, Прилузский район, д.Гостиногорка, 16а		0101000020E6100000003B376DC6B34840B85A272EC7D74D40
43548	3	25	420	3303	\N	\N	60.579715	Республика Коми, Прилузский район, д.Галахтионовская, 22		0101000020E61000008733BF9A036E48401500E319344A4E40
43554	3	25	420	57283	57840	\N	60.451824199841703	Республика Коми, Прилузский район, пст.Вухтым, Центральная, 22	Россия, республика Коми, Прилузский район, село Вухтым	0101000020E6100000954737C2A2D4484022C66B5ED5394E40
43555	3	25	420	57283	57940	\N	60.455446062017998	Республика Коми, Прилузский район, пст.Вухтым, Спортивная, 2	Россия, республика Коми, Прилузский район, село Вухтым	0101000020E61000000B9C6C0377D44840098CF50D4C3A4E40
43572	3	25	420	4577	57878	\N	59.910437999999999	Республика Коми, Прилузский район, с.Верхолузье, Центральная, 21		0101000020E6100000990F08742659484090847D3B89F44D40
43570	3	25	420	57266	57792	\N	60.051466398193597	Республика Коми, Прилузский район, пст.Велдорья, Молодежная, 1а	Россия, республика Коми, Прилузский район, село Велодоръя	0101000020E61000001F65C405A08B48408F6D197096064E40
43569	3	25	420	57326	57930	\N	60.130775999999997	Республика Коми, Прилузский район, пст.Ваймес, Школьная, 6	Россия, республика Коми, Прилузский район, село Ваймес	0101000020E6100000F4A62215C69C4840048D9944BD104E40
43560	3	25	420	3918	57852	\N	60.310499999999998	Республика Коми, Прилузский район, д.Беляевская, 51		0101000020E610000047382D78D1D1484039B4C876BE274E40
43581	3	25	420	5036	57886	\N	59.499313999999998	Республика Коми, Прилузский район, д.Архиповка, Школьная, 5		0101000020E61000006EFAB31F29B84840AC376A85E9BF4D40
43133	3	25	1277	57337	57943	\N	65.019200551030295	Республика Коми, г.Печора, пос.Новая Березовка, Лесная, 34, кв.1	Россия, республика Коми, Печорский район, поселок Березовка	0101000020E61000008656276728464C403BC3D4963A415040
43134	3	25	1277	57239	57719	\N	64.899259757300698	Республика Коми, г.Печора, пос.Чикшино, Центральная, 2	Россия, республика Коми, Печорский район, село Чикшино	0101000020E610000078EFA83121364C4076A6D0798D395040
43130	3	25	1277	57273	57817	\N	65.144152415451401	Республика Коми, г.Печора, дер.Усть-Кожва, Речная, 12	Россия, республика Коми, Печорский район, село Усть-Кожва	0101000020E6100000C57421567F804C40CB694FC939495040
43137	3	25	1277	57291	57849	\N	64.615539886787701	Республика Коми, г.Печора, пос.Талый, Центральная, 1	Россия, республика Коми, Печорский район, село Талый	0101000020E6100000B403AE2B66D84B404F58E20165275040
43101	3	25	1277	57320	57919	\N	65.37106	Республика Коми, г.Печора, пос.Сыня, Восточная, 5	Россия, республика Коми, Печорский район, поселок Сыня	0101000020E61000002444F98216064D40A4367172BF575040
43131	3	25	1277	57286	57845	\N	65.346610545392195	Республика Коми, г.Печора, с.Соколово, Центральная, 23	Россия, республика Коми, Печорский район, село Соколово	0101000020E610000020D3DA34B6814C40C45BE7DF2E565040
43140	3	25	1277	57277	57822	\N	64.554301795621598	Республика Коми, г.Печора, пос.Рыбница, Лесная, 17	Россия, республика Коми, Печорский район, село Рыбница	0101000020E6100000FCFD62B664BD4B40E08618AF79235040
43124	3	25	1277	57235	57698	\N	65.173840841949101	Республика Коми, г.Печора, пос.Путеец, Парковая, 2а	Россия, республика Коми, Печорский район, поселок Путеец	0101000020E6100000D7338463968B4C400D6D0036204B5040
43136	3	25	1277	57275	57819	\N	64.567971	Республика Коми, г.Печора, пос.Причал, Набережная, 3	Россия, республика Коми, Печорский район, село Причал	0101000020E6100000B16CE690D4284C40E48409A359245040
43110	3	25	1277	57314	57909	\N	64.731033999999994	Республика Коми, г.Печора, с.Приуральское, Школьная, 15	Россия, республика Коми, Печорский район, село Приуральское	0101000020E610000086E464E256EF4C40E690D442C92E5040
43103	3	25	1277	13361	57548	\N	65.144429000000002	Республика Коми, г.Печора, Советская, 47		0101000020E610000033315D88D5A14C4004E621533E495040
43123	3	25	1277	13361	57481	\N	65.144429000000002	Республика Коми, г.Печора, Печорский проспект, 47		0101000020E610000033315D88D5A14C4004E621533E495040
43114	3	25	1277	13361	57481	\N	65.144429000000002	Республика Коми, г.Печора, Печорский проспект, 75		0101000020E610000033315D88D5A14C4004E621533E495040
43139	3	25	1277	13361	79429	\N	65.144255000000001	Республика Коми, г.Печора, пос.Трубоседъельск, Набережная, 2а	Россия, республика Коми, Печорский район, Печора	0101000020E61000004983DBDAC2A14C4035D252793B495040
43119	3	25	1277	13361	57594	\N	65.144429000000002	Республика Коми, г.Печора, Ленинградская, 10		0101000020E610000033315D88D5A14C4004E621533E495040
43097	3	25	1277	13361	57547	\N	65.144429000000002	Республика Коми, г.Печора, Комсомольская, 27	Россия, республика Коми, Печорский район, Печора	0101000020E610000033315D88D5A14C4004E621533E495040
43099	3	25	1277	13361	57729	\N	65.144429000000002	Республика Коми, г.Печора, Деповская, 19		0101000020E610000033315D88D5A14C4004E621533E495040
43109	3	25	1277	57244	57730	\N	65.091817468302693	Республика Коми, г.Печора, пос.Озерный, Центральная, 31	Россия, республика Коми, Печорский район, село Озерный	0101000020E6100000E2B034F0A3944C40E10D6954E0455040
43129	3	25	1277	57276	57820	\N	65.129535634811106	Республика Коми, г.Печора, пос.Набережный, Школьная, 44	Россия, республика Коми, Печорский район, село Набережный	0101000020E61000000F7BA180ED844C40E6E95C514A485040
43106	3	25	1277	57319	57917	\N	64.940844999228304	Республика Коми, г.Печора, дер.Медвежская, Молодежная, 27	Россия, республика Коми, Печорский район, село Медвежская	0101000020E6100000EAEC647094CA4C40BA66F2CD363C5040
43125	3	25	1277	57290	57848	\N	65.158756689837105	Республика Коми, г.Печора, пос.Луговой, Русанова, 1	Россия, республика Коми, Печорский район, село Луговой	0101000020E61000009A79724D818E4C40B5C01E13294A5040
43107	3	25	1277	57260	57779	\N	65.080197999999996	Республика Коми, г.Печора, пос.Красный Яг, Свободы, 7	Россия, республика Коми, Печорский район, село Красный Яг	0101000020E61000005DA9674128A54C4018CDCAF621455040
43100	3	25	1277	57280	57835	\N	65.613016850495697	Республика Коми, г.Печора, пос.Косью, Лесная, 6, кв.5	Россия, республика Коми, Печорский район, поселок Косью	0101000020E6100000D36BB3B1127B4D4017B9A7AB3B675040
43105	3	25	1277	57315	57912	\N	64.844790768803705	Республика Коми, г.Печора, дер.Конецбор, Почтовая, 29	Россия, республика Коми, Печорский район, село Конецбор	0101000020E610000081CEA44DD5DD4C40213D450E11365040
43127	3	25	1277	57227	57595	\N	65.109513000000007	Республика Коми, г.Печора, пос.Кожва, Мира, 14	Россия, республика Коми, Печорский район, поселок Кожва	0101000020E6100000C8B5A1629C874C40295FD04202475040
43104	3	25	1277	57285	57843	\N	64.886626863307896	Республика Коми, г.Печора, пос.Кедровый Шор, Речная, 15	Россия, республика Коми, Печорский район, село Кедровый Шор	0101000020E610000010CD3CB9A6CE4C400A302C7FBE385040
43135	3	25	1277	57209	57486	\N	64.692086379417105	Республика Коми, г.Печора, пос.Каджером, Театральная, 23	Россия, республика Коми, Печорский район, поселок Каджером	0101000020E61000000569C6A2E9F44B403F0114234B2C5040
43128	3	25	1277	57208	57485	\N	65.105390779728907	Республика Коми, г.Печора, пос.Изъяю, Центральная, 7	Россия, республика Коми, Печорский район, поселок Изъяю	0101000020E6100000F92CCF83BB7D4C40BC92E4B9BE465040
43141	3	25	1277	57267	57797	\N	64.479984000000002	Республика Коми, г.Печора, пос.Зеленоборск, Рабочая, 7	Россия, республика Коми, Печорский район, село Зеленоборск	0101000020E61000001B649291B3A64B409CA6CF0EB81E5040
43112	3	25	1277	57308	57892	\N	64.703808249210994	Республика Коми, г.Печора, дер.Даниловка, Центральная, 46	Россия, республика Коми, Печорский район, село Даниловка	0101000020E6100000B4E4F1B4FCEE4C4071AAB5300B2D5040
43108	3	25	1277	57262	57786	\N	65.01934	Республика Коми, г.Печора, дер.Бызовая, Совхозная, 12	Россия, республика Коми, Печорский район, село Бызовая	0101000020E6100000A73E90BC73B04C404CE0D6DD3C415040
43132	3	25	1277	57264	57794	\N	65.018899000000005	Республика Коми, г.Печора, пос.Березовка, Таёжная, 2		0101000020E61000006478EC67B1464C4056BB26A435415040
43126	3	25	1277	57263	57793	\N	65.276368000000005	Республика Коми, г.Печора, пос.Белый Ю, Лесная, 3, кв.17		0101000020E61000005A457F68E68F4C404D6A6803B0515040
43111	3	25	1277	57274	57818	\N	64.832319550841405	Республика Коми, г.Печора, дер.Аранец, Центральная, 39	Россия, республика Коми, Печорский район, село Аранец	0101000020E6100000844BC79C67EC4C40A1F31ABB44355040
43122	3	25	7427	57216	57506	\N	65.121907510826901	Республика Коми, г.Печора, Спортивная, 42	Россия, республика Коми, Печора городской округ	0101000020E6100000766C04E275934C40BB473657CD475040
43455	3	25	795	30702	57705	\N	61.780759000000003	Республика Коми, Корткеросский район, пос.Усть-Лэкчим, Школьная, 1А		0101000020E61000007B2FBE688FD94940628731E9EFE34E40
43472	3	25	795	31545	57947	\N	61.837405399774099	Республика Коми, Корткеросский район, п.Уръель, ул.Центральная, д.12	Россия, республика Коми, Корткеросский район, село Уръель	0101000020E6100000C80BE9F010404A40E140481630EB4E40
43478	3	25	795	6559	\N	\N	62.229298	Республика Коми, Корткеросский район, д.Троицк д.119		0101000020E61000004089CF9D605B4A40E48409A3591D4F40
43479	3	25	795	31869	\N	\N	62.223593000000001	Республика Коми, Корткеросский район, дер.Сюзяыб, 30а		0101000020E610000033A31F0DA73C4A40A94E07B29E1C4F40
43468	3	25	795	6539	57627	\N	61.939948000000001	Республика Коми, Корткеросский район, с.Сторожевск, адрес помещения для голосования: Дружбы, 27, адрес УИК: Интернациональная, 51		0101000020E6100000338B506C05294A4066F84F3750F84E40
43465	3	25	795	31203	57712	\N	61.838954999999999	Республика Коми, Корткеросский район, пос.Приозёрный, адрес помещения для голосования: Центральная, 6, адрес УИК: Станционная, 3		0101000020E6100000075DC2A1B7E8494068E89FE062EB4E40
43454	3	25	795	30622	57856	\N	61.566079000000002	Республика Коми, Корткеросский район, с.Позтыкерес, Светлая, 20		0101000020E61000002BC1E270E6C54940E8F9D34675C84E40
43470	3	25	795	31452	57755	\N	61.919106999999997	Республика Коми, Корткеросский район, с.Подъельск, Восточная, 11		0101000020E6100000666A12BC21594A402843554CA5F54E40
43542	3	25	394	2954	57715	\N	60.332718	Республика Коми, Койгородский район, пос.Кажым, Набережная, 1		0101000020E6100000B83EAC376AC549403065E080962A4E40
43474	3	25	795	31628	57540	\N	61.909360999999997	Республика Коми, Корткеросский район, пос.Подтыбок, адрес помещения для голосования: Центральная, 9, адрес УИК: Советская, 49		0101000020E61000008388D4B48B6F4A4001A1F5F065F44E40
43464	3	25	795	31149	57853	\N	61.825482999999998	Республика Коми, Корткеросский район, с.Пезмег, адрес помещения для голосования: Братьев Покровских, 53, адрес УИК: Братьев Покровских, 66		0101000020E61000005017299485DB4940B5334C6DA9E94E40
43480	3	25	795	31890	\N	\N	62.346282000000002	Республика Коми, Корткеросский район, с.Нившера, 729		0101000020E61000008FE4F21FD2734A40C498F4F7522C4F40
43467	3	25	795	31293	57833	\N	61.910352000000003	Республика Коми, Корткеросский район, с.Нёбдино, Центральная, 90		0101000020E6100000481ADCD616104A4092EC116A86F44E40
43451	3	25	795	30477	57745	\N	61.182535999999999	Республика Коми, Корткеросский район, пос.Намск, Школьная, 19А		0101000020E610000018247D5A450D4A40DC2BF3565D974E40
43452	3	25	795	30543	57634	\N	61.357532999999997	Республика Коми, Корткеросский район, с.Мордино, Пушкина, 7		0101000020E610000057772CB649F34940D11E2FA4C3AD4E40
43462	3	25	795	31053	57780	\N	61.850591000000001	Республика Коми, Корткеросский район, с.Маджа, Центральная, 5А		0101000020E6100000F1F62004E4BB4940CFA2772AE0EC4E40
43458	3	25	795	30754	57746	\N	61.806680999999998	Республика Коми, Корткеросский район, с.Корткерос, адрес помещения для голосования: Советская, 213, адрес УИК: Советская, 188, каб.8		0101000020E6100000EB3A545392C94940FCA6B05241E74E40
43456	3	25	795	30754	57746	\N	61.806680999999998	Республика Коми, Корткеросский район, с.Корткерос, Советская, 187		0101000020E6100000EB3A545392C94940FCA6B05241E74E40
43457	3	25	795	30754	57533	\N	61.806680999999998	Республика Коми, Корткеросский район, с.Корткерос, адрес помещения для голосования: Набережная, 2, адрес УИК: Советская, 188, каб.2		0101000020E6100000EB3A545392C94940FCA6B05241E74E40
43459	3	25	795	30754	57830	\N	61.806680999999998	Республика Коми, Корткеросский район, с.Корткерос, Дорожная, 11		0101000020E6100000EB3A545392C94940FCA6B05241E74E40
43471	3	25	795	31486	57741	\N	61.865696999999997	Республика Коми, Корткеросский район, с.Керес, Центральная, 40		0101000020E6100000FA9AE5B2D1554A40669FC728CFEE4E40
43460	3	25	795	30933	57858	\N	61.777939000000003	Республика Коми, Корткеросский район, с.Додзь, адрес помещения для голосования: Центральная, 90, адрес УИК:  Центральная, 74		0101000020E6100000FF243E7782AD494038A4518193E34E40
43475	3	25	795	31701	\N	\N	62.147756000000001	Республика Коми, Корткеросский район, дер.Выльыб, 66		0101000020E610000037177FDB133C4A40D6E429ABE9124F40
43469	3	25	795	31388	\N	\N	61.941234426568101	Республика Коми,Корткеросский район, с.Вомын, 125	Россия, республика Коми, Корткеросский район, село Вомын	0101000020E61000001D1F2DCE18464A400FF10F5B7AF84E40
43461	3	25	795	31019	57710	\N	61.749523000000003	Республика Коми, Корткеросский район, пос.Визябож, Школьная, 1		0101000020E610000014048F6FEF9E4940C74CA25EF0DF4E40
43453	3	25	795	30600	57894	\N	61.470677999999999	Республика Коми, Корткеросский район, пос.Веселовка, Советская, 10		0101000020E61000008DB454DE8ECA49402D793C2D3FBC4E40
43466	3	25	795	57305	\N	\N	61.857354999999998	Республика Коми, Корткеросский район, дер.Важкурья, 74/1	Россия, республика Коми, Корткеросский район, село Важкуръя	0101000020E6100000C6BE64E3C1F44940F20703CFBDED4E40
43473	3	25	795	31597	57763	\N	62.129811984282597	Республика Коми, Корткеросский район, с.Большелуг, Центральная, 13	Россия, республика Коми, Корткеросский район, село Большелуг	0101000020E61000007B15191D90404A406E50FBAD9D104F40
43477	3	25	795	5602	57889	\N	62.257917999999997	Республика Коми, Корткеросский район, с.Богородск, адрес помещения для голосования: Школьная, 59, адрес УИК: Михайлова, 18		0101000020E6100000D7DF12807F3E4A405D86FF7403214F40
43463	3	25	795	31099	57707	\N	61.852687000000003	Республика Коми, Корткеросский район, пос. Аджером, Школьная, 1		0101000020E6100000A9C1340C1FD74940B85CFDD824ED4E40
43533	3	25	394	2393	57901	\N	60.518937999999999	Республика Коми, Койгородский район, с.Ужга, Ягдорская, 9		0101000020E61000002E20B41EBE8649406953758F6C424E40
43534	3	25	394	2495	57867	\N	60.558010000000003	Республика Коми, Койгородский район, пос.Седтыдор, Центральная, 34		0101000020E61000003DF19C2D207E4940A56B26DF6C474E40
43528	3	25	394	2154	57756	\N	60.672638999999997	Республика Коми, Койгородский район, пос.Подзь, адрес помещения для голосования: Советская, 15, адрес УИК: Советская, 9		0101000020E61000005CAFE941412D4940CF81E50819564E40
43536	3	25	394	2608	57897	\N	60.680756000000002	Республика Коми, Койгородский район, пос.Нючпас, Центральная, 20		0101000020E61000002CD32F116FBD494024473A0323574E40
43544	3	25	394	3058	57788	\N	60.335875000000001	Республика Коми, Койгородский район, пос.Нижний Турунъю, адрес помещения для голосования: Заречная, 1, адрес УИК: Красноармейская, 7		0101000020E610000032AB77B81D084A40A245B6F3FD2A4E40
43540	3	25	394	2837	57844	\N	60.346916999999998	Республика Коми, Койгородский район, пос.Кузьель, Смоленская, 15		0101000020E6100000726C3D433864494095B6B8C6672C4E40
43541	3	25	394	57270	57802	\N	60.264785853920102	Республика Коми, Койгородский район, пос.Ком, Центральная, 9	Россия, республика Коми, Койгородский район, село Ком	0101000020E6100000AD3594DA8B9649402638F581E4214E40
43539	3	25	394	2727	57632	\N	60.418990999999998	Республика Коми, Койгородский район, пос.Койдин, адрес помещения для голосования: Центральная, 12, адрес УИК: Набережная, 26		0101000020E6100000EE5A423EE87D4940BF28417FA1354E40
43537	3	25	394	2631	57644	\N	60.449328000000001	Республика Коми, Койгородский район, с.Койгородок, адрес помещения для голосования: Советская, 44А, адрес УИК: Советская, 30		0101000020E61000003A799109F87F4940AB96749483394E40
43538	3	25	394	2631	57874	\N	60.449328000000001	Республика Коми, Койгородский район, с.Койгородок, Интернациональная, 55		0101000020E61000003A799109F87F4940AB96749483394E40
39178	3	24	\N	1518	59247	\N	61.765594	город Петрозаводск, Березовая аллея, 23		0101000020E6100000E1270EA0DF274140C501F4FBFEE14E40
43527	3	25	394	2060	57836	\N	60.674728000000002	Республика Коми, Койгородский район, пос.Иван-Чомья, Центральная, 17		0101000020E610000038F3AB394038494006D9B27C5D564E40
43529	3	25	394	2160	57837	\N	60.564511000000003	Республика Коми, Койгородский район, пос.Зимовка, Ленина, 8А		0101000020E6100000E9B5D95889494940BB9D7DE541484E40
43531	3	25	394	2272	57902	\N	60.579599999999999	Республика Коми, Койгородский район, с.Грива, адрес помещения для голосования: Советская, 23, адрес УИК: Советская, 35		0101000020E610000018062CB98A7149407C613255304A4E40
43535	3	25	394	57296	57866	\N	60.646940248492797	Республика Коми, Койгородский район, пос.Вежью, Пушкина, 14	Россия, республика Коми, Койгородский район, село Вежъю	0101000020E61000005875560BEC914940B43C0FEECE524E40
43314	3	25	901	24147	57918	\N	62.696812999999999	Республика Коми, Княжпогостский район, с.Шошка, Центральная, 26		0101000020E6100000490F43AB93594940BD361B2B31594F40
43310	3	25	901	57228	57597	\N	63.214091000000003	Республика Коми, Княжпогостский район, пст. Чиньяворык, Дзержинского, 4	Россия, республика Коми, Княжпогостский район, село Чиньяворык	0101000020E6100000EB1C03B2D7554A4019AF7955679B4F40
43319	3	25	901	32953	57826	\N	62.761749566089897	Республика Коми, Княжпогостский район, пст.Чернореченский, пер. Клубный, д. 10		0101000020E6100000F2D24D6210BE49402FDD240681614F40
43313	3	25	901	57300	\N	\N	62.821497574868097	Республика Коми, Княжпогостский район, с.Турья, 81	Россия, республика Коми, Княжпогостский район, село Туръя	0101000020E6100000698F17D2E15349405DDDB1D826694F40
43321	3	25	901	57255	57775	\N	62.699244999999998	Республика Коми, Княжпогостский район, пст.Тракт, Лесная, 20	Россия, республика Коми, Княжпогостский район, село Тракт	0101000020E6100000EC866D8B32A549401D7233DC80594F40
43318	3	25	901	24343	57517	\N	62.840350000000001	Республика Коми, Княжпогостский район, пгт.Синдор, Строителей, 15		0101000020E610000035CF11F92EF74940C898BB96906B4F40
43332	3	25	901	25003	57762	\N	62.326605000000001	Республика Коми, Княжпогостский район, с.Серегово, Советская, 30		0101000020E610000057410C74ED594940E4DA5031CE294F40
43317	3	25	901	32927	\N	\N	63.033349000000001	"Республика Коми, Княжпогостский район, пст.Ропча, помещение МОУ ""ООШ"" пст.Ропча"	Россия, республика Коми, Княжпогостский район, село Ропча	0101000020E610000054FEB5BC72274A405A2DB0C744844F40
43323	3	25	901	32964	57811	\N	62.680777949260502	Республика Коми, Княжпогостский район, пст.Ракпас, ул. Дзержинского, д. 11	Россия, республика Коми, Княжпогостский район, село Ракпас	0101000020E610000051BEA085048E49400BEBC6BB23574F40
43311	3	25	901	57332	57936	\N	63.340909371299396	Республика Коми, Княжпогостский район, пст.Мещура, Пионерская, 3	Россия, республика Коми, Княжпогостский район, село Мещура	0101000020E610000001DA56B3CE744940BFF4F6E7A2AB4F40
43333	3	25	901	57322	57920	\N	62.280517000000003	Республика Коми, Княжпогостский район, пст.Ляли, Центральная, 10	Россия, республика Коми, Княжпогостский район, село Ляли	0101000020E6100000CAE02879755649406C7C26FBE7234F40
43315	3	25	901	24179	57807	\N	62.601782	Республика Коми, Княжпогостский район, с.Княжпогост, Центральная, 42		0101000020E6100000D3F6AFAC346D494026A94C31074D4F40
43316	3	25	901	57303	57873	\N	62.986712709043601	Республика Коми, Княжпогостский район, пст.Иоссер, Центральная, 10	Россия, республика Коми, Княжпогостский район, село Иоссер	0101000020E61000004F081D7409174A40DFC4909C4C7E4F40
43324	3	25	901	24632	57570	\N	62.6073797499741	Республика Коми, Княжпогостский район, г.Емва, Чапаева, 1	Россия, республика Коми, Княжпогостский район, Емва	0101000020E61000006BF0BE2A177449404B1FBAA0BE4D4F40
43330	3	25	901	24632	57519	\N	62.577762	Республика Коми, Княжпогостский район, г.Емва, Московская, 10	Россия, республика Коми, Княжпогостский район, Емва	0101000020E61000007BDD2230D66F49408F6FEF1AF4494F40
43326	3	25	901	24632	57619	\N	62.577762	Республика Коми, Княжпогостский район, г.Емва, Коммунистическая, 9		0101000020E61000007BDD2230D66F49408F6FEF1AF4494F40
43328	3	25	901	24632	57620	\N	62.577762	Республика Коми, Княжпогостский район, г.Емва, Дзержинского, 100		0101000020E61000007BDD2230D66F49408F6FEF1AF4494F40
43325	3	25	901	24632	57620	\N	62.600167249952598	Республика Коми, Княжпогостский район, г.Емва, Дзержинского, 72	Россия, республика Коми, Княжпогостский район, Емва	0101000020E610000011C30E63D2714940B891B245D24C4F40
43329	3	25	901	24632	57769	\N	62.577762	Республика Коми, Княжпогостский район, г.Емва, Волгоградская, 2а		0101000020E61000007BDD2230D66F49408F6FEF1AF4494F40
43331	3	25	901	24632	57521	\N	62.577762	Республика Коми, Княжпогостский район, г.Емва, 60 лет Октября, 57		0101000020E61000007BDD2230D66F49408F6FEF1AF4494F40
43312	3	25	901	57333	57939	\N	62.943668000000002	Республика Коми, Княжпогостский район, пст.Ветью, Школьная, 6	Россия, республика Коми, Княжпогостский район, село Ветью	0101000020E61000007C7BD7A02F6549401024EF1CCA784F40
43092	3	25	1225	57246	\N	\N	66.054331000000005	Республика Коми, г.Инта, пст.Юсьтыдор, 18	Россия, республика Коми, Интинский район, село Юсьтыдор	0101000020E610000030630AD6380B4E402D0ABB287A835040
43077	3	25	1225	57259	57778	\N	66.4721596505957	Республика Коми, г.Инта, с.Петрунь, Центральная, 38	Россия, республика Коми, Интинский район, село Петрунь	0101000020E6100000A036AAD3815E4E40AE9E93DE379E5040
43076	3	25	1225	57256	\N	\N	66.284713999999994	Республика Коми, г.Инта, с.Косьювом, 70	Россия, республика Коми, Интинский район, село Косьювом	0101000020E61000000A4966F50EF14D40A7AD11C138925040
43074	3	25	1225	12419	\N	\N	66.028661999999997	Республика Коми, г.Инта, пст.Абезь, Центральная, 20	Россия, республика Коми, Интинский район, Инта	0101000020E61000000A48FB1F60134E40D4282499D5815040
43090	3	25	1225	12419	57476	\N	66.028661999999997	Республика Коми, г.Инта, Мира, 2		0101000020E61000000A48FB1F60134E40D4282499D5815040
43089	3	25	1225	12419	57476	\N	66.028661999999997	Республика Коми, г.Инта, Мира, 16		0101000020E61000000A48FB1F60134E40D4282499D5815040
43088	3	25	1225	12419	57476	\N	66.028661999999997	Республика Коми, г.Инта, Мира, 14	Россия, республика Коми, Интинский район, Инта	0101000020E61000000A48FB1F60134E40D4282499D5815040
43082	3	25	1225	12419	57476	\N	66.033610296012995	Республика Коми, г.Инта, Мира, 51	Россия, республика Коми, Интинский район, Инта	0101000020E61000004BAFCDC64A0C4E4063B48EAA26825040
43085	3	25	1225	12419	57537	\N	66.028661999999997	Республика Коми, г.Инта, Куратова, 19		0101000020E61000000A48FB1F60134E40D4282499D5815040
43081	3	25	1225	12419	57537	\N	66.028661999999997	Республика Коми, г.Инта, Куратова, 66		0101000020E61000000A48FB1F60134E40D4282499D5815040
43091	3	25	1225	12419	57589	\N	66.028661999999997	Республика Коми, г.Инта, Кирова, 14		0101000020E61000000A48FB1F60134E40D4282499D5815040
43087	3	25	1225	12419	57564	\N	66.028661999999997	Республика Коми, г.Инта, Горького, 8		0101000020E61000000A48FB1F60134E40D4282499D5815040
43084	3	25	1225	12419	57564	\N	66.028661999999997	Республика Коми, г.Инта, Горького, 16		0101000020E61000000A48FB1F60134E40D4282499D5815040
43078	3	25	1225	57229	57603	\N	65.990459000000001	Республика Коми, г.Инта, пгт.Верхняя Инта, Советской армии, 2	Россия, республика Коми, Интинский район, поселок Верхняя Инта	0101000020E61000000C7558E196294E40D94125AE637F5040
43075	3	25	1225	57306	\N	\N	66.592875000000006	Республика Коми, г.Инта, с.Адзьвавом, 55	Россия, республика Коми, Интинский район, село Адзьвавом	0101000020E610000035B39602D2A44D406DE7FBA9F1A55040
43215	3	25	1528	19292	57860	\N	65.264044365886406	Республика Коми,Ижемский район, дер.Ыргеншар, Центральная, 19	Россия, республика Коми, Ижемский район, село Ыргеншар	0101000020E61000006F8104C58FB54A401F2DCE18E6505040
43223	3	25	1528	19710	\N	\N	65.322627999999995	Республика Коми, Ижемский район, пос.Щельяюр, адрес помещения для голосования:Заводская, 12, адрес УИК: Заводская, 10	Россия, республика Коми, Ижемский район, поселок Щельяюр	0101000020E61000003A77BB5E9AB44A408731E9EFA5545040
43227	3	25	1528	19916	\N	\N	65.487223	Республика Коми, Ижемский район, д.Чика, 57	Россия, республика Коми, Ижемский район, село Чика	0101000020E61000009E62D520CC294B40FAB660A92E5F5040
43222	3	25	1528	19631	57809	\N	65.306425585764003	Республика Коми, Ижемский район, дер.Усть-Ижма, Центральная, 100	Россия, республика Коми, Ижемский район, село Усть-Ижма	0101000020E6100000828DEBDFF5754A403929CC7B9C535040
43206	3	25	1528	18807	57700	\N	64.496142000000006	Республика Коми,Ижемский район, пос.Том, Речная, 84		0101000020E6100000552FBFD364AE4A40030B60CAC01F5040
43211	3	25	1528	19094	57761	\N	65.065918999999994	Республика Коми,Ижемский район, с.Сизябск, 60 лет Октября, 18		0101000020E6100000D7F84CF6CFED4A40D74B530438445040
43224	3	25	1528	19728	57803	\N	65.430308999999994	Республика Коми, Ижемский район, дер.Пиль-Егор, Центральная, 24		0101000020E6100000B9C7D2872ECC4A402A8BC22E8A5B5040
43225	3	25	1528	19810	57703	\N	65.465029999999999	Республика Коми, Ижемский район, с.Няшабож, Центральная, 220	Россия, республика Коми, Ижемский район, село Няшабож	0101000020E610000093C5FD47A6EB4A402B6A300DC35D5040
43207	3	25	1528	18850	\N	\N	64.855600999999993	Республика Коми, Ижемский район, д.Мошъюга, 87		0101000020E61000009F0436E7E0DF4A40315BB22AC2365040
43209	3	25	1528	18959	57697	\N	65.002135999999993	Республика Коми, Ижемский район, с.Мохча, Центральная, 150		0101000020E61000007898F6CDFDE94A403B8908FF22405040
43221	3	25	1528	19587	57806	\N	65.286451	Республика Коми, Ижемский район, дер.Малое Галово, Центральная, 17		0101000020E61000002B1213D4F0774A40043A933655525040
43212	3	25	1528	19103	57800	\N	64.927305000000004	Республика Коми,Ижемский район, дер.Ласта, Центральная, 19		0101000020E6100000166A4DF38EE74A40B51A12F7583B5040
43217	3	25	1528	19383	57829	\N	65.293071999999995	Республика Коми,Ижемский район, с.Краснобор, им.братьев Семяшкиных, 110		0101000020E6100000535E2BA1BBA44A40E4D70FB1C1525040
43204	3	25	1528	18700	57805	\N	64.346103999999997	Республика Коми, Ижемский район, пос.Койю, адрес помещения для голосования:Центральная, 412, адрес УИК: Центральная, 409 а		0101000020E6100000A6D3BA0D6AD34A40F240649126165040
43228	3	25	1528	19931	57727	\N	65.665014999999997	Республика Коми, Ижемский район, с.Кипиево, адрес помещения для голосования: Лесная, 115, адрес УИК: Чупрова, 71		0101000020E61000006CB3B112F3404B405D16139B8F6A5040
43220	3	25	1528	19532	57825	\N	65.276684000000003	Республика Коми, Ижемский район, с.Кельчиюр, Центральная, 129		0101000020E6100000F86EF3C6497F4A40E5D4CE30B5515040
43205	3	25	1528	18753	57801	\N	64.522931999999997	Республика коми, Ижемский район, дер.Картаёль, Лесная, 92		0101000020E61000004E64E60297A94A400A82C7B777215040
43214	3	25	1528	19188	57658	\N	65.012170999999995	Республика Коми, с.Ижма, адрес помещения для голосования: Советская, 49, адрес УИК: Советская, 67		0101000020E61000004BE7C3B304F54A406ABDDF68C7405040
43213	3	25	1528	19188	57658	\N	65.012170999999995	Республика Коми, с.Ижма, Советская, 49		0101000020E61000004BE7C3B304F54A406ABDDF68C7405040
43216	3	25	1528	19318	57861	\N	65.275744000000003	Республика Коми, Ижемский район, дер.Диюр, Клубная, 50		0101000020E6100000AE9D280989AE4A405E8429CAA5515040
43208	3	25	1528	18908	57915	\N	64.984848	Республика Коми, Ижемский район, дер.Гам, Центральная, 40		0101000020E61000002079E75086E64A40FCE1E7BF073F5040
43191	3	25	1528	18056	57764	\N	65.300852000000006	Республика коми, Ижемский район, дер.Вертеп, Школьная, 27		0101000020E610000085798F334D9A4A40EB3BBF2841535040
43226	3	25	1528	19831	57904	\N	65.474839000000003	Республика Коми, Ижемский район, с.Брыкаланск, адрес помещения для голосования: Набережная, 39, адрес УИК: Административная, 17		0101000020E610000001DA56B3CE224B4062F71DC3635E5040
43219	3	25	1528	19487	57804	\N	65.284356000000002	Республика Коми, Ижемский район, дер.Большое Галово, Центральная, 31		0101000020E6100000A2B8E34D7E8D4A40F81A82E332525040
43210	3	25	1528	19034	57723	\N	65.045444000000003	Республика Коми, Ижемский район, дер.Бакур, Центральная, 50		0101000020E6100000A6B73F170DED4A402A73F38DE8425040
43153	3	25	7430	57279	57824	\N	63.475610722483097	Республика Коми, г.Вуктыл, пст.Шердино, Мира, 8	Россия, республика Коми, Вуктыльский район, село Шердино	0101000020E6100000FB743C66A03A4C40164F3DD2E0BC4F40
43143	3	25	7430	57271	57808	\N	64.361142999999998	Республика Коми, г.Вуктыл, пст.Усть-Соплеск, Школьная, 12	Россия, республика Коми, Вуктыльский район, село Усть-Соплеск	0101000020E6100000BA6A9E23F2D74C407A8B87F71C175040
43144	3	25	7430	57241	57721	\N	63.939025330782002	Республика Коми, г.Вуктыл, с.Подчерье, Зарубина, 1	Россия, республика Коми, Вуктыльский район, село Подчерье	0101000020E6100000166EF9484AC84C402E90A0F831F84F40
43150	3	25	7430	57293	57859	\N	63.8565507438121	Республика Коми, г.Вуктыл, пст.Лемтыбож, адрес помещения для голосования: ул.Лесная, д.11, адрес УИК: Печорская, 2	Россия, республика Коми, Вуктыльский район, село Лемтыбож	0101000020E61000007E8E8F1667784C40952D9276A3ED4F40
43151	3	25	7430	57317	57914	\N	63.870491431442403	Республика Коми, г.Вуктыл, пст.Лемты, 40 лет Победы, 6	Россия, республика Коми, Вуктыльский район, село Лемты	0101000020E61000003694DA8B686B4C402E3BC43F6CEF4F40
43152	3	25	7430	57232	57695	\N	63.801928516490896	Республика Коми, г.Вуктыл, с.Дутово, Советская, 1	Россия, республика Коми, Вуктыльский район, село Дутово	0101000020E61000003B18B14F00594C40645B069CA5E64F40
43147	3	25	6897	40316	57562	\N	63.844195596535201	Республика Коми, г.Вуктыл, Комсомольская, 14	Россия, республика Коми, Вуктыл городской округ	0101000020E6100000543BC3D496A64C40FEB4519D0EEC4F40
43071	3	25	7423	57233	57696	\N	66.672250900298195	Республика Коми, г.Воркута, пос.Сивомаскинский, адрес помещения для голосования: Лесная, 1, адрес УИК: Школьная, 19	Россия, республика Коми, Воркутинский район, поселок Сивомаскинский	0101000020E6100000BAA3FFE55A484F4003ED0E2906AB5040
43040	3	25	7423	57214	57503	\N	67.602107179542301	Республика Коми, г.Воркута, пос.Северный, Юго-Западная, 5	Россия, республика Коми, Воркутинский район, поселок Северный	0101000020E61000007DCD72D9E8065040556CCCEB88E65040
43039	3	25	7423	57214	57503	\N	67.602415809638899	Республика Коми, г.Воркута, пос.Северный, Юго-Западная, 17	Россия, республика Коми, Воркутинский район, поселок Северный	0101000020E610000041D5E8D50008504094A5D6FB8DE65040
43038	3	25	7423	57214	57720	\N	67.599490087082899	Республика Коми, г.Воркута, пос.Северный, Спортивная, 3	Россия, республика Коми, Воркутинский район, поселок Северный	0101000020E6100000A4C2D84290065040DC114E0B5EE65040
43041	3	25	7423	57214	57614	\N	67.599880999999996	Республика Коми, г.Воркута, пос.Северный, Карла Маркса, 9	Россия, республика Коми, Воркутинский район, поселок Северный	0101000020E610000090847D3B89065040791F477364E65040
43029	3	25	7423	57231	57642	\N	67.556029849512797	Республика Коми, г.Воркута, пос.Комсомольский, Свердлова, 3А	Россия, республика Коми, Воркутинский район, поселок Комсомольский	0101000020E6100000234BE658DEE54F401366DAFE95E35040
43028	3	25	7423	57226	57590	\N	67.493204000000006	Республика Коми, г.Воркута, пос.Заполярный, Фрунзе, 26	Россия, республика Коми, Воркутинский район, поселок Заполярный	0101000020E610000084BBB376DBDD4F40699082A790DF5040
43072	3	25	7423	57284	57842	\N	67.043455704574598	Республика Коми, г.Воркута, пос.Елецкий, адрес помещения для голосования: Школьная, 4, адрес УИК: Советская, 7	Россия, республика Коми, Воркутинский район, поселок Елецкий	0101000020E61000005053CBD6FA0D504029B4ACFBC7C25040
43034	3	25	7423	57210	57494	\N	67.583352062181405	Республика Коми, г.Воркута, пос.Воргашор, Юбилейный переулок, 10	Россия, республика Коми, Воркутинский район, поселок Воргашор	0101000020E6100000B0592E1B9DE54F409983A0A355E55040
43031	3	25	7423	57210	57499	\N	67.582238105220696	Республика Коми, г.Воркута, пос.Воргашор, Энтузиастов, 26Б	Россия, республика Коми, Воркутинский район, поселок Воргашор	0101000020E61000008675E3DD91E54F40431F2C6343E55040
43030	3	25	7423	57210	57499	\N	67.582828000000006	Республика Коми, г.Воркута, пос.Воргашор, Энтузиастов, 15А	Россия, республика Коми, Воркутинский район, поселок Воргашор	0101000020E6100000234A7B832FE64F405CCCCF0D4DE55040
43037	3	25	7423	57210	57584	\N	67.582828000000006	Республика Коми, г.Воркута, пос.Воргашор, Ленинского Комсомола, 2А	Россия, республика Коми, Воркутинский район, поселок Воргашор	0101000020E6100000234A7B832FE64F405CCCCF0D4DE55040
43035	3	25	7423	57210	57608	\N	67.580166577220297	Республика Коми, г.Воркута, пос.Воргашор, Катаева, 29	Россия, республика Коми, Воркутинский район, поселок Воргашор	0101000020E610000004ABEAE577E44F40FBCDC47421E55040
43036	3	25	7423	57210	57613	\N	67.582270869411502	Республика Коми, г.Воркута, пос.Воргашор, Есенина, 2А	Россия, республика Коми, Воркутинский район, поселок Воргашор	0101000020E6100000514A0856D5E54F40319A95ED43E55040
43032	3	25	7423	57210	57601	\N	67.583548637361005	Республика Коми, г.Воркута, пос.Воргашор, Воргашорская, д. 10,	Россия, республика Коми, Воркутинский район, поселок Воргашор	0101000020E61000008C15359886E54F4044A7E7DD58E55040
39362	3	24	\N	57535	59133	\N	61.941582369290799	ст. Шуйская, Петровское шоссе, 2 А	Россия, М-18 шоссе	0101000020E610000079944A78421F41404A404CC285F84E40
39414	3	24	\N	26698	59436	\N	61.721724000000002	д.Ужесельга, Центральная, 12 А		0101000020E6100000C9569753023E4140815EB87361DC4E40
39503	3	24	\N	57532	59111	\N	62.088351000000003	г. Суоярви, Суоярвское шоссе, 164		0101000020E61000005680EF366F2E4040D2C8E7154F0B4F40
39501	3	24	\N	57532	59161	\N	62.078384371335098	г. Суоярви, Ленина, 11		0101000020E61000003E3F8C101E2D4040CC43A67C080A4F40
39211	3	24	\N	57530	\N	\N	61.745298355331101	Республика Карелия, город Сортавала, поселок Хелюля, здание школы	Россия, республика Карелия, Сортавала городской округ, поселок Хелюля	0101000020E610000051C1E10511AD3E4019E3C3EC65DF4E40
39217	3	24	\N	57530	59342	\N	61.933447556163898	Республика Карелия, город Сортавала, Рускеала, Школьная, здание школы	Россия, республика Карелия, Сортавала городской округ, село Рускеала	0101000020E61000004084B872F6963E4020425C397BF74E40
39221	3	24	\N	57530	59367	\N	62.050151119231998	Республика Карелия, город Сортавала, поселок Пуйккола, Центральная, здание школы	Россия, республика Карелия, Сортавала городской округ, село Пуйккола	0101000020E61000000C3ECDC98BAC3E404C6E14596B064F40
39218	3	24	\N	57530	59229	\N	62.181919760763897	Республика Карелия, город Сортавала, поселок Вяртсиля, Мира, 3-А		0101000020E6100000DD7A4D0F0AB23E40813E912749174F40
39223	3	24	\N	3053	\N	\N	61.654370456972202	Республика Карелия, город Сортавала, поселок Куокканиэми, здание железнодорожной станции	Россия, республика Карелия, Сортавала городской округ, село Куокканиэми	0101000020E6100000B43D7AC37D603E40E4BD6A65C2D34E40
39220	3	24	\N	3053	\N	\N	61.972954145465103	Республика Карелия, город Сортавала, поселок Маткаселькя, здание фельдшерско-акушерского пункта	Россия, республика Карелия, Сортавала городской округ, село Маткаселькя	0101000020E61000001F4B1FBAA08A3E409641B5C189FC4E40
39214	3	24	\N	3053	\N	\N	61.712800426326602	Республика Карелия, город Сортавала, поселок Заозерный, здание школы		0101000020E61000009CA56439099D3E405E4BC8073DDB4E40
39213	3	24	\N	3053	59432	\N	61.807232329602797	Республика Карелия, город Сортавала, поселок Рюттю, здание библиотеки		0101000020E6100000A64412BD8C9A3E407024D06053E74E40
39205	3	24	\N	3053	59086	\N	61.708103000000001	Республика Карелия, город Сортавала, Промышленная, 17		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39207	3	24	\N	3053	59087	\N	61.708103000000001	Республика Карелия, город Сортавала, Победы, 12		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39203	3	24	\N	3053	59088	\N	61.708103000000001	Республика Карелия, город Сортавала, Набережная Ладожской флотилии, 2		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39210	3	24	\N	3053	59462	\N	61.708103000000001	"г. Сортавала, ул. Локомотивная, д. 4, детский сад ""Ивушка"""		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39202	3	24	\N	3053	59320	\N	61.708103000000001	Республика Карелия, город Сортавала, Комсомольская, 5		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39206	3	24	\N	3053	59189	\N	61.708103000000001	Республика Карелия, город Сортавала, Карельская, 86-А		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39224	3	24	\N	3053	59285	\N	61.708103000000001	Республика Карелия, город Сортавала, поселок Хаапалампи, Выборгское шоссе, 9		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39208	3	24	\N	3053	59170	\N	61.708103000000001	Республика Карелия, город Сортавала, Выборгское Шоссе, 3		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39204	3	24	\N	3053	59141	\N	61.708103000000001	Республика Карелия, город Сортавала, Бондарева, 3-а		0101000020E61000002AA8A8FA95AE3E4089997D1EA3DA4E40
39201	3	24	\N	3053	59085	\N	61.704479450999699	Республика Карелия, город Сортавала, Гагарина, 13	Россия, республика Карелия, Сортавала	0101000020E6100000A699EE7552AF3E4001DC2C5E2CDA4E40
39476	3	24	\N	57538	59214	\N	63.741973999999999	город Сегежа, Строителей, 27		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39479	3	24	\N	57538	59303	\N	63.741973999999999	город Сегежа, Лейгубская		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39470	3	24	\N	57538	59171	\N	63.741973999999999	город Сегежа, Кирова, 30		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39480	3	24	\N	57538	59315	\N	63.741973999999999	город Сегежа, Гористая, 83а		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39442	3	24	\N	57537	59169	\N	61.806973999999997	г.Пудож, ул.Комсомольская, д.43		0101000020E61000000307B47405434240745C8DEC4AE74E40
39441	3	24	\N	57537	59169	\N	61.806973999999997	г.Пудож, Комсомольская, 5		0101000020E61000000307B47405434240745C8DEC4AE74E40
39228	3	24	\N	57527	59184	\N	61.569021999999997	Республика Карелия, г. Питкяранта, ул. Ленина, д. 30		0101000020E61000007024D06053773F402D5A80B6D5C84E40
39229	3	24	\N	57527	59192	\N	61.569021999999997	Республика Карелия, г. Питкяранта, ул. Горького, д. 3		0101000020E61000007024D06053773F402D5A80B6D5C84E40
39225	3	24	\N	57527	59094	\N	61.569021999999997	Республика Карелия, г. Питкяранта, ул. Гоголя, д. 9/а		0101000020E61000007024D06053773F402D5A80B6D5C84E40
39268	3	24	\N	1518	747	\N	61.793697000000002	Калевальский муниципальный район, п.Новое Юшкозеро, Железнодорожная, 8	Россия, республика Карелия, Петрозаводск, улица Железнодорожная, 8	0101000020E61000009CC0745AB72B414077F700DD97E54E40
39187	3	24	\N	1518	59278	\N	61.777631999999997	город Петрозаводск, Чернышевского, 14А		0101000020E6100000193A7650893341405A29047289E34E40
39491	3	24	\N	1518	67651	\N	61.785310753226803	УЛ. ЦЕНТРАЛЬНАЯ, Д 5	Россия, республика Карелия, Петрозаводск, улица Герцена	0101000020E6100000B1F9B836542E41403318231285E44E40
39139	3	24	\N	1518	59279	\N	61.848548999999998	город Петрозаводск, Трудовых резервов, 7		0101000020E61000002E7590D7832B4140D906EE409DEC4E40
39130	3	24	\N	1518	59283	\N	61.842343	город Петрозаводск, Сулажгорского кирпичного завода, 11		0101000020E6100000A27A6B60AB1C4140DC813AE5D1EB4E40
39154	3	24	\N	1518	3956	\N	61.790657000000003	город Петрозаводск, Студенческий пер, 14	Россия, республика Карелия, Петрозаводск, Студенческий переулок, 14	0101000020E61000006B65C22FF52B41403FADA23F34E54E40
39239	3	24	\N	1518	59254	\N	61.798026	Республика Карелия, Питкярантский район, д. Ряймяля, ул. Советская, д. 11		0101000020E6100000B41EBE4C142B4140C9AD49B725E64E40
39149	3	24	\N	1518	59254	\N	61.798740000000002	город Петрозаводск, Советская, 15		0101000020E610000043ACFE08C32A4140E700C11C3DE64E40
39135	3	24	\N	1518	59254	\N	61.798026	город Петрозаводск, Советская, 11		0101000020E6100000B41EBE4C142B4140C9AD49B725E64E40
39193	3	24	\N	1518	59253	\N	61.725448999999998	город Петрозаводск, Птицефабрика, 2		0101000020E6100000A1BDFA78E83741403CF54883DBDC4E40
39200	3	24	\N	1518	59465	\N	61.777309000000002	г.Петрозаводск, ул.Промышленная, 9 (общежитие ГОУ ВПО "Карельская государственная педагогическая академия") УИК №130		0101000020E6100000D8BCAAB35A32414078F17EDC7EE34E40
39146	3	24	\N	1518	3844	\N	61.768867	город Петрозаводск, Попова, 8	Россия, республика Карелия, Петрозаводск, Попова переулок, 8	0101000020E61000004792205C01274140A0FCDD3B6AE24E40
39192	3	24	\N	1518	59240	\N	61.756565000000002	город Петрозаводск, Петрова, 7Б		0101000020E6100000BC04A73E903841402D26361FD7E04E40
39148	3	24	\N	1518	3658	\N	61.799888000000003	город Петрозаводск, Первомайский пр, 38	Россия, республика Карелия, Петрозаводск, Первомайский проспект, 38	0101000020E61000007E737FF5B82941403F3BE0BA62E64E40
39145	3	24	\N	1518	3658	\N	61.800136831575202	город Петрозаводск, Первомайский пр, 46	Россия, республика Карелия, Петрозаводск, Первомайский проспект	0101000020E6100000E7A7380EBC284140E7A8A3E36AE64E40
39136	3	24	\N	1518	3658	\N	61.796236	город Петрозаводск, Первомайский пр, 37а	Россия, республика Карелия, Петрозаводск, Первомайский проспект, 37а	0101000020E61000000EF7915B932A4140EDF2AD0FEBE54E40
39133	3	24	\N	1518	3658	\N	61.802306999999999	город Петрозаводск, Первомайский пр, 56	Россия, республика Карелия, Петрозаводск, Первомайский проспект, 56	0101000020E61000003F373465A72741400A2DEBFEB1E64E40
39138	3	24	\N	1518	59257	\N	61.777963999999997	город Петрозаводск, Пархоменко, 48		0101000020E610000077D844662E2A414090BB085394E34E40
39106	3	24	\N	1518	59257	\N	61.778339000000003	город Петрозаводск, Пархоменко, 28		0101000020E61000003A92CB7F48294140C619C39CA0E34E40
39182	3	24	\N	1518	59277	\N	61.767352000000002	город Петрозаводск, Парфенова, 8А		0101000020E6100000C11A67D3113041409642209738E24E40
39144	3	24	\N	1518	3816	\N	61.808266000000003	город Петрозаводск, Октябрьский пр, 64	Россия, республика Карелия, Петрозаводск, Октябрьский проспект, 64	0101000020E610000078EC67B114294140003CA24275E74E40
39191	3	24	\N	1518	59263	\N	61.758375000000001	город Петрозаводск, Нойбранденбургская, 15		0101000020E61000000ED8D5E429394140508D976E12E14E40
39147	3	24	\N	1518	59265	\N	61.799734999999998	город Петрозаводск, Мурманская, 30		0101000020E6100000FBB0DEA8152A4140B83B6BB75DE64E40
39181	3	24	\N	1518	4285	\N	61.760840000000002	город Петрозаводск, Лососинское шоссе, 33/5	Россия, республика Карелия, Петрозаводск, Лососинское шоссе, 33к5	0101000020E6100000BF28417FA12741408CBE823463E14E40
39188	3	24	\N	1518	59238	\N	61.763229079091801	город Петрозаводск, Ломоносова, 65		0101000020E6100000BDDF68C70D334140ED2DE57CB1E14E40
39134	3	24	\N	1518	59236	\N	61.796044000000002	город Петрозаводск, Локомотивная, 49		0101000020E61000001D05888219274140A91611C5E4E54E40
39174	3	24	\N	1518	59284	\N	61.773650000000004	город Петрозаводск, Лесная, 17		0101000020E610000030D461855B2E4140744694F606E34E40
39529	3	24	\N	1518	59250	\N	61.796402	Республика Карелия, Костомукшский городской округ, Ленинградская ул, 11		0101000020E61000001C615111A72D4140083C3080F0E54E40
39153	3	24	\N	1518	59250	\N	61.791814000000002	город Петрозаводск, Ленинградская, 19		0101000020E61000000307B474052D4140EA4141295AE54E40
39151	3	24	\N	1518	59250	\N	61.796402	город Петрозаводск, Ленинградская, 11		0101000020E61000001C615111A72D4140083C3080F0E54E40
39159	3	24	\N	1518	4020	\N	61.786093000000001	город Петрозаводск, Ленина пр, 33	Россия, республика Карелия, Петрозаводск, Ленина проспект, 33	0101000020E6100000C2A2224E272D4140A94E07B29EE44E40
39171	3	24	\N	1518	4163	\N	61.776803000000001	город Петрозаводск, наб. Ла-Рошель, 11	Россия, республика Карелия, Петрозаводск, Ла-Рошель набережная, 11	0101000020E6100000AF9811DE1E2E4140A437DC476EE34E40
39170	3	24	\N	1518	59244	\N	61.775751999999997	город Петрозаводск, Кузьмина, 50		0101000020E61000000CAD4ECE503041403EE76ED74BE34E40
39162	3	24	\N	1518	59268	\N	61.783163000000002	город Петрозаводск, Красноармейская, 31		0101000020E6100000CA1AF5108D2C4140F83768AF3EE44E40
39156	3	24	\N	1518	59270	\N	61.791775000000001	город Петрозаводск, Красная, 8		0101000020E6100000357BA015182E41402C6519E258E54E40
39185	3	24	\N	1518	4342	\N	61.759808999999997	город Петрозаводск, проспект Комсомольский, 21А	Россия, республика Карелия, Петрозаводск, Комсомольский проспект, 21а	0101000020E6100000003961C2682E41406D1ADB6B41E14E40
39165	3	24	\N	1518	59264	\N	61.776837	город Петрозаводск, Коммунистов, 51		0101000020E61000007008556AF632414050A912656FE34E40
39190	3	24	\N	1518	59262	\N	61.758246999999997	город Петрозаводск, Ключевая, 20		0101000020E6100000CA17B4908037414022A5D93C0EE14E40
39155	3	24	\N	1518	59274	\N	61.790993	город Петрозаводск, Кирова, 12		0101000020E6100000C1ADBB79AA2F4140B62E35423FE54E40
39168	3	24	\N	1518	59276	\N	61.773708999999997	город Петрозаводск, Калинина, 54		0101000020E6100000E57FF277EF30414078CF81E508E34E40
39166	3	24	\N	1518	59276	\N	61.776223999999999	город Петрозаводск, Калинина, 41		0101000020E610000011346612F5304140662FDB4E5BE34E40
39179	3	24	\N	1518	4252	\N	61.759327999999996	город Петрозаводск, Интернационалистов бульвар, 2	Россия, республика Карелия, Петрозаводск, Интернационалистов бульвар, 2	0101000020E610000059C4B0C398284140F277EFA831E14E40
39141	3	24	\N	1518	59243	\N	61.810982000000003	город Петрозаводск, Зайцева, 57б		0101000020E6100000344B02D4D428414085D21742CEE74E40
39140	3	24	\N	1518	59243	\N	61.808067000000001	город Петрозаводск, Зайцева, 24		0101000020E6100000C18D942D922A414009FD4CBD6EE74E40
39132	3	24	\N	1518	59256	\N	61.810200000000002	город Петрозаводск, Жуковского, 32		0101000020E61000001C412AC58E2241400F9C33A2B4E74E40
39167	3	24	\N	1518	4085	\N	61.785544999999999	город Петрозаводск, набережная Гюллинга, 3	Россия, республика Карелия, Петрозаводск, Гюллинга набережная, 3	0101000020E61000009548A29751324140A64412BD8CE44E40
39164	3	24	\N	1518	4085	\N	61.785544999999999	город Петрозаводск, наб. Гюллинга, 3	Россия, республика Карелия, Петрозаводск, Гюллинга набережная, 3	0101000020E61000009548A29751324140A64412BD8CE44E40
39184	3	24	\N	1518	59249	\N	61.765177000000001	город Петрозаводск, Генерала Фролова, 12		0101000020E6100000286211C30E2F41406153E751F1E14E40
39169	3	24	\N	1518	59269	\N	61.778036	город Петрозаводск, Варламова, 34		0101000020E610000009168733BF3041402A8E03AF96E34E40
39152	3	24	\N	1518	3782	\N	61.800542999999998	город Петрозаводск, Варкауса наб, 5	Россия, республика Карелия, Петрозаводск, Варкауса набережная, 5	0101000020E610000091477023652D414057056A3178E64E40
39142	3	24	\N	1518	3782	\N	61.804326000000003	город Петрозаводск, Варкауса наб, 15	Россия, республика Карелия, Петрозаводск, Варкауса набережная, 15	0101000020E61000006D6FB724072C414048A98427F4E64E40
39177	3	24	\N	1518	59245	\N	61.769212000000003	город Петрозаводск, Березовая аллея, 31		0101000020E6100000117349D5762741406BD8EF8975E24E40
39173	3	24	\N	1518	4076	\N	61.776977000000002	город Петрозаводск, проспект Александра Невского, 57	Россия, республика Карелия, Петрозаводск, Александра Невского проспект, 57	0101000020E61000007825C9737D2F4140425F7AFB73E34E40
39172	3	24	\N	1518	4076	\N	61.775058000000001	город Петрозаводск, проспект Александра Невского, 64	Россия, республика Карелия, Петрозаводск, Александра Невского проспект, 64	0101000020E610000066666666662E41406840BD1935E34E40
39163	3	24	\N	1518	4076	\N	61.784086000000002	город Петрозаводск, проспект Александра Невского, 8	Россия, республика Карелия, Петрозаводск, Александра Невского проспект, 8	0101000020E61000005BB22AC24D32414030A017EE5CE44E40
39180	3	24	\N	1518	59224	\N	61.759878297930697	город Петрозаводск, Хейкконена, 41	Россия, республика Карелия, Петрозаводск, Лососинское шоссе, 41	0101000020E610000083143C855C2741409679ABAE43E14E40
39186	3	24	\N	1518	59248	\N	61.760465000000003	город Петрозаводск, Сортавальская, 7Б		0101000020E610000051853FC39B2F41405760C8EA56E14E40
39150	3	24	\N	1518	59239	\N	61.797311999999998	город Петрозаводск, Советская, 12		0101000020E6100000E542E55FCB2B4140AB5AD2510EE64E40
39157	3	24	\N	1518	59258	\N	61.792791999999999	город Петрозаводск, Пушкинская, 17		0101000020E6100000AD4D637B2D304140E54350357AE54E40
39137	3	24	\N	1518	59237	\N	61.784765999999998	город Петрозаводск, Островского, 26		0101000020E6100000338D2617632A4140A181583673E44E40
39009	3	24	\N	1518	59233	\N	61.781928999999998	город Петрозаводск, Олонецкая, 75		0101000020E610000095F1EF332E284140A165DD3F16E44E40
39131	3	24	\N	1518	59222	\N	61.809438796997	город Петрозаводск, Новосулажгорская, 29	Россия, республика Карелия, Петрозаводск, Ветеринарный переулок, 29	0101000020E6100000E89FE06245234140B08D78B29BE74E40
39143	3	24	\N	1518	59230	\N	61.799419999999998	город Петрозаводск, Московская, 12		0101000020E61000005F43705CC62B414058E2016553E64E40
39509	3	24	\N	1518	59353	\N	61.813999000000003	п. Лахколампи, Клубная, 1		0101000020E6100000D5E940D65321414005FD851E31E84E40
39116	3	24	\N	1518	59235	\N	61.785254999999999	город Петрозаводск, Зеленая, 7		0101000020E6100000317E1AF7E62741409F02603C83E44E40
39158	3	24	\N	1518	59241	\N	61.781928999999998	город Петрозаводск, Антикайнена, 4		0101000020E610000033C170AE612E4140A165DD3F16E44E40
39161	3	24	\N	1518	59259	\N	61.784382999999998	город Петрозаводск, Анохина, 37а		0101000020E610000063601DC70F2D4140E94482A966E44E40
39410	3	24	\N	26478	59127	\N	61.814793999999999	п. Новая Вилга, Нововилговское шоссе, 15		0101000020E6100000C11F7EFE7B1641400F7D772B4BE84E40
39405	3	24	\N	3356	59118	\N	61.864131	п. Меллиоративный, кл. Петрозаводская, д. 33а здание МОУ СОШ № 2		0101000020E61000000B9A9658191F4140DA3A38D89BEE4E40
39335	3	24	\N	57528	59121	\N	62.917468	г.Медвежьегорск, ул.Советская, д.6		0101000020E610000030A017EE5C3A4140329067976F754F40
39334	3	24	\N	57528	59121	\N	62.917468	г.Медвежьегорск, ул.Советская, д.15		0101000020E610000030A017EE5C3A4140329067976F754F40
39336	3	24	\N	57528	59103	\N	62.917468	г.Медвежьегорск, ул.Куйбышева, д.19		0101000020E610000030A017EE5C3A4140329067976F754F40
39333	3	24	\N	57528	59099	\N	62.917468	г.Медвежьегорск, ул.К.Либкнехта, д.8		0101000020E610000030A017EE5C3A4140329067976F754F40
39331	3	24	\N	57528	59098	\N	62.917468	г.Медвежьегорск, ул.Дзержинского, д.18		0101000020E610000030A017EE5C3A4140329067976F754F40
39330	3	24	\N	57528	59098	\N	62.917468	г.Медвежьегорск, ул.Дзержинского, д.29		0101000020E610000030A017EE5C3A4140329067976F754F40
39289	3	24	\N	57536	59185	\N	61.527827000000002	Республика Карелия, г.Лахденпохья, Фанерная, 8		0101000020E6100000FDBCA948852D3E401079CBD58FC34E40
39291	3	24	\N	57536	59327	\N	61.527827000000002	Республика Карелия, г.Лахденпохья, Садовая, 22		0101000020E6100000FDBCA948852D3E401079CBD58FC34E40
39293	3	24	\N	57536	59288	\N	61.527827000000002	Республика Карелия, г.Лахденпохья, Ленинградское шоссе, 5		0101000020E6100000FDBCA948852D3E401079CBD58FC34E40
39292	3	24	\N	57536	59286	\N	61.527827000000002	Республика Карелия, г.Лахденпохья, Ленина, 45		0101000020E6100000FDBCA948852D3E401079CBD58FC34E40
39288	3	24	\N	57536	59148	\N	61.527827000000002	Республика Карелия, г.Лахденпохья, Ладожской флотилии, 1		0101000020E6100000FDBCA948852D3E401079CBD58FC34E40
39290	3	24	\N	57536	59345	\N	61.527827000000002	Республика Карелия, г.Лахденпохья, Заходского, 2		0101000020E6100000FDBCA948852D3E401079CBD58FC34E40
39354	3	24	\N	3252	59139	\N	64.590315124546706	Костомукша г. Строителей ул., 5, здание администрации городского округа	Россия, республика Карелия, Костомукша	0101000020E6100000ED0F94DBF6993E40A6D590B8C7255040
39520	3	24	\N	3252	59175	\N	64.591089480151595	Республика Карелия, город Костомукша, Советская, 14	Россия, республика Карелия, Костомукша	0101000020E61000003CBCE7C072983E409F01F566D4255040
39521	3	24	\N	3252	59419	\N	64.587327000000002	Костомукша г., Вокнаволок дер., Перттунена ул., 14		0101000020E6100000A0F99CBB5D973E40B343FCC396255040
39523	3	24	\N	3252	59216	\N	64.591458213153402	Республика Карелия, город Костомукша, Первооткрывателей, 1	Россия, республика Карелия, Костомукша	0101000020E6100000484F9143C4993E4049BDA772DA255040
39526	3	24	\N	3252	59151	\N	64.587327000000002	Республика Карелия, город Костомукша, Первомайская, 3		0101000020E6100000A0F99CBB5D973E40B343FCC396255040
39524	3	24	\N	3252	9648	\N	64.587512510135596	Республика Карелия, город Костомукша, Октябрьская, 4	Россия, республика Карелия, Костомукша	0101000020E610000018D2E1218C973E40643E20D099255040
39525	3	24	\N	3252	59217	\N	64.591605704951903	Республика Карелия, город Костомукша, Ленина пл, 1	Россия, республика Карелия, Костомукша	0101000020E61000005B069CA564993E40838769DFDC255040
39522	3	24	\N	3252	59150	\N	64.587327000000002	Республика Карелия, город Костомукша, Ленина, 19		0101000020E6100000A0F99CBB5D973E40B343FCC396255040
39527	3	24	\N	3252	59176	\N	64.591642577776298	Республика Карелия, город Костомукша, Калевала, 7	Россия, республика Карелия, Костомукша	0101000020E6100000BDE5EAC726993E4012FA997ADD255040
39541	3	24	\N	57533	59157	\N	62.197037999999999	Республика Карелия,г.Кондопога, пр.Калинина, д.10 (ПУ-15)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39537	3	24	\N	57533	59114	\N	62.197037999999999	г. Кондопога, пр. Калинина 13 А, Помещение ср. шк. №8		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39539	3	24	\N	57533	59179	\N	62.197037999999999	Республика Карелия, г.Кондопога, б.Юности, д.9 (СОШ №3)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39547	3	24	\N	57533	59156	\N	62.197037999999999	Республика Карелия, Кондопожский район, г.Кондопога, ул.Советов, д.36 (Помещение Лицея)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39544	3	24	\N	57533	59156	\N	62.197037999999999	Республика Карелия, г.Кондопога, ул.Советов, д.19 (Помещение Библиотеки)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39532	3	24	\N	57533	59455	\N	62.197037999999999	Республика Карелия, г.Кондопога, Сандальская набережная, д.33		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39545	3	24	\N	57533	59153	\N	62.197037999999999	Республика Карелия, г.Кондопога, ул.Пролетарская, д.29 (Детская библиотека)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39536	3	24	\N	57533	59153	\N	62.197037999999999	Республика Карелия, г.Кондопога, ул.Пролетарская, д.1 (ДДТ)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39533	3	24	\N	57533	59153	\N	62.197037999999999	"Республика Карелия, г.Кондопога, ул.Пролетарская, д.40 ""ДЮСШ№2"""		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39531	3	24	\N	57533	59435	\N	62.197037999999999	Республика Карелия, г.Кондопога, ул.Кондопожская, д.102б Помещение здравпункта		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39534	3	24	\N	57533	59113	\N	62.197037999999999	"Республика Карелия, г.Кондопога, ул.Комсомольская, д.27 ""СОШ №7"""		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39546	3	24	\N	57533	59116	\N	62.197037999999999	Республика Карелия, г.Кондопога, ул.Заводская, д.24 (СОШ №6)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39543	3	24	\N	57533	59116	\N	62.197037999999999	Республика Карелия, г.Кондопога, ул.Заводская, д.38 (СОШ №2)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39538	3	24	\N	57533	59115	\N	62.197037999999999	Республика Карелия, г.Кондопога, Б.Юности, д.9 (СОШ№3)		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39272	3	24	\N	57539	59201	\N	64.953275000000005	г. Кемь, Пролетарский пр, 18		0101000020E6100000B60E0EF6264C41400B462575023D5040
39274	3	24	\N	57539	59195	\N	64.953275000000005	г. Кемь, Пролетарский пр, 38а		0101000020E6100000B60E0EF6264C41400B462575023D5040
39276	3	24	\N	57539	59182	\N	64.953275000000005	г. Кемь, пл. Кирова, 6		0101000020E6100000B60E0EF6264C41400B462575023D5040
39219	3	24	\N	57531	59108	\N	61.903128665054503	Республика Карелия, город Сортавала, поселок Кааламо, 40 лет Победы, здание школы	Россия, республика Карелия, Сортавала городской округ, село Кааламо	0101000020E61000001D5723BBD27E3E40DB8827BB99F34E40
39222	3	24	\N	57566	\N	\N	61.389223662032201	"Республика Карелия, город Сортавала, поселок Валаам, здание ""Пиродного парка ""Валаамский архипелаг"""	Россия, республика Карелия, поселок Валаам	0101000020E6100000EF39B01C21F33E40BE688F17D2B14E40
39232	3	24	\N	57541	59198	\N	64.528998006271706	г.Беломорск, ул.Мерецкова, д.8		0101000020E6100000C2A4F8F88462414090696D1ADB215040
39506	3	24	1897	30949	59418	\N	62.323813999999999	п. Тойвола, Школьная, 1		0101000020E6100000205F4205874D404054FEB5BC72294F40
39502	3	24	1897	30637	59220	\N	62.088351000000003	г. Суоярви, Суоярвское шоссе, 2		0101000020E61000005680EF366F2E4040D2C8E7154F0B4F40
39500	3	24	1897	30637	59142	\N	62.088351000000003	г.Суоярви, Гагарина, 15		0101000020E61000005680EF366F2E4040D2C8E7154F0B4F40
39505	3	24	1897	30886	59420	\N	62.20055	п.Суоеки, Ленина, 4		0101000020E61000005073F222134E40403D9B559FAB194F40
39518	3	24	1897	31546	\N	\N	61.912787999999999	п. Суйстамо, Здание Дома культуры	Россия, республика Карелия, Суоярвский район, село Суйстамо	0101000020E61000008693347F4C273F403317B83CD6F44E40
39516	3	24	1897	31424	59306	\N	61.925640999999999	п. Райконкоски, Советская, 12		0101000020E6100000CD0182397A903F401A6B7F677BF64E40
39511	3	24	1897	31138	59149	\N	62.708698797611198	п. Поросозеро, Заводская, 11	Россия, республика Карелия, Суоярвский район, поселок Поросозеро	0101000020E61000004F5DF92CCF5940409DDA19A6B65A4F40
39510	3	24	1897	31138	59215	\N	62.7096287757266	п. Поросозеро, Больничная, 18	Россия, республика Карелия, Суоярвский район, поселок Поросозеро	0101000020E61000008E01D9EBDD59404087A5811FD55A4F40
39519	3	24	1897	31578	59316	\N	62.029161059333497	п. Пийтсиёки, Центральная, 16-а	Россия, республика Карелия, Суоярвский район, село Пийтсиеки	0101000020E610000064027E8D240D4040CAA8328CBB034F40
39507	3	24	1897	30980	59112	\N	62.302810000000001	п. Найстенъярви, Заводская, 1		0101000020E61000001B62BCE6555740406D73637AC2264F40
39508	3	24	1897	31047	\N	\N	62.430131000000003	ст. Найстенъярви, Здание Дома культуры	Россия, республика Карелия, Суоярвский район, Найстенъярви	0101000020E610000074ED0BE88551404076FF58880E374F40
39515	3	24	1897	31405	59334	\N	61.978243999999997	п. Лоймола, Суоярское шоссе, 16		0101000020E610000069006F8104BD3F400DC1711937FD4E40
39517	3	24	1897	31496	59387	\N	61.857716000000003	п. Леппясюрья, Центральная, 29		0101000020E6100000DFA9807B9E5B3F40C3A04CA3C9ED4E40
39504	3	24	1897	30846	\N	\N	62.205458999999998	п. Леппяниэми, ФАП		0101000020E610000017467A51BB3940409DD5027B4C1A4F40
39512	3	24	1897	31230	\N	\N	62.965150000000001	п. Гумарино, Здание школы	Россия, республика Карелия, Суоярвский район, село Гумарино	0101000020E6100000B13385CE6B8E404001DE02098A7B4F40
39513	3	24	1897	31271	\N	\N	62.296407000000002	п. Вегарус, Здание администрации	Россия, республика Карелия, Суоярвский район, село Вегарус	0101000020E61000006BD784B4C60C40401AA721AAF0254F40
39209	3	24	7433	57554	\N	\N	61.680059590192499	"Республика Карелия, город Сортавала, поселок Хюмпеля, здание детского сада ""Росинка"""	Россия, республика Карелия, Сортавала городской округ, село Хюмпеля	0101000020E61000002C11A8FE41A83E40ACA8C1340CD74E40
39212	3	24	7433	57553	59355	\N	61.745888556008602	"Республика Карелия, город Сортавала, село Хелюля, Центральная, здание детского сада ""Колосок"""	Россия, республика Карелия, Сортавала городской округ, поселок Хелюля	0101000020E6100000F20698F90EAE3E401BB96E4A79DF4E40
39215	3	24	7433	57556	\N	\N	61.6935142402845	Республика Карелия, город Сортавала, поселок Туокслахти, здание библиотеки	Россия, республика Карелия, Сортавала городской округ, село Туокслахти	0101000020E610000093A9825149913E40B9A81611C5D84E40
39216	3	24	7433	57565	\N	\N	62.055703625728697	Республика Карелия, город Сортавала, поселок Партала, здание дома-интерната	Россия, республика Карелия, Сортавала городской округ, село Партала	0101000020E610000074B33F506E973E40D120054F21074F40
39488	3	24	400	30051	59440	\N	63.994911999999999	пос.Черный Порог, Болотная, 9		0101000020E61000001EE21FB6F4D44040F032C34659FF4F40
39474	3	24	400	29216	59172	\N	63.741973999999999	город Сегежа, пр-д Бумажников, 7		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39478	3	24	400	29216	59110	\N	63.741973999999999	город Сегежа, Спиридонова, 27		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39472	3	24	400	29216	59135	\N	63.741973999999999	город Сегежа, Советская, 8		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39471	3	24	400	29216	59135	\N	63.741973999999999	город Сегежа, Советская, 20		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39477	3	24	400	29216	59140	\N	63.741973999999999	город Сегежа, пр-д Монтажников, 4		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39473	3	24	400	29216	59136	\N	63.741973999999999	город Сегежа, Мира, 23		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39475	3	24	400	29216	59137	\N	63.741973999999999	город Сегежа, Лесокультурная, 14		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39481	3	24	400	29216	59389	\N	63.741973999999999	город Сегежа, Анохина, 15		0101000020E61000002E8ECA4DD42C4140BC3D0801F9DE4F40
39485	3	24	400	29886	59395	\N	63.862026	пристань Надвоицы, Набережная, 15		0101000020E6100000F6234564582941409E2633DE56EE4F40
39495	3	24	400	30373	59394	\N	63.408662	пос.Попов Порог, Кирова, 4		0101000020E610000098A59D9ACB014140198F52094FB44F40
39497	3	24	400	2102	59451	\N	63.694025813265597	дер.Полга, Центральная, 8	Россия, республика Карелия, Сегежский район, село Полга	0101000020E6100000E46A64575A7441406F490ED8D5D84F40
39490	3	24	400	57571	59469	\N	64.001827504222405	пос.Олений, Набережная, 21	Россия, республика Карелия, Сегежский район	0101000020E61000009D465A2A6FC94040E50D30F31D005040
39484	3	24	400	48411	59174	\N	63.897756999999999	пгт.Надвоицы, Ленина, 14		0101000020E6100000655419C6DD204140A6608DB3E9F24F40
39483	3	24	400	48411	59165	\N	63.897756999999999	пгт.Надвоицы, Строителей, 8	Россия, республика Карелия, Сегежский район, поселок Надвоицы	0101000020E6100000655419C6DD204140A6608DB3E9F24F40
39482	3	24	400	29744	59160	\N	63.874766999999999	пгт.Надвоицы, Строителей, 1		0101000020E61000001F1494A2952941405D4F745DF8EF4F40
39494	3	24	400	30335	59450	\N	64.034158792527606	пос.Кочкома, Центральная, 42а	Россия, республика Карелия, Сегежский район, село Кочкома	0101000020E6100000FE45D098491E41404DF73AA92F025040
39486	3	24	400	29946	59308	\N	63.9291769558209	дер.Каменный Бор, Комсомольская, 1а	Россия, республика Карелия, Сегежский район, поселок Каменный Бор	0101000020E61000009A779CA22317414003999D45EFF64F40
39492	3	24	400	30240	59391	\N	64.132249000000002	пос.Идель, Школьная, 1		0101000020E6100000211D1EC2F81F4140707B82C476085040
39496	3	24	400	30435	59449	\N	63.720332999999997	пос.Волдозеро, Центральная, 8		0101000020E610000011C4793881FF4040629D2ADF33DC4F40
39499	3	24	400	30578	\N	\N	63.458602999999997	пос.Вожмогора	Россия, республика Карелия, Сегежский район, село Вожмогора	0101000020E6100000A9DE1AD82AB541407A6CCB80B3BA4F40
39487	3	24	400	48474	\N	\N	63.907274000000001	пос.Верхний, штаб ФКУ ЛИУ-4 УФСИН России по Республике Карелия		0101000020E61000007138F3AB391841406C41EF8D21F44F40
39489	3	24	400	48510	59400	\N	63.975782000000002	пос.Вача, Центральная, 1		0101000020E6100000A1496249B9BB40404303B16CE6FC4F40
39498	3	24	400	30528	59173	\N	63.431547000000002	пос.Валдай, Школьная, 7		0101000020E61000000C1EA67D73C14140EDD79DEE3CB74F40
39456	3	24	1828	28532	59347	\N	61.799385999999998	п.Шальский, ул.Стеклянская, д.74		0101000020E610000095826E2F69004240AC70CB4752E64E40
39455	3	24	1828	28532	59131	\N	61.799385999999998	п.Шальский, ул.Октябрьская, д.20		0101000020E610000095826E2F69004240AC70CB4752E64E40
39463	3	24	1828	28924	59370	\N	62.666497	п.Тамбичозеро, ул.Центральная, д.4		0101000020E6100000CEE0EF17B30D4240E9F010C64F554F40
39462	3	24	1828	28851	59444	\N	62.492130000000003	п.Тамбицы, ул.Школьная, д.4		0101000020E61000002B4CDF6B08144240B4B0A71DFE3E4F40
39457	3	24	1828	47895	\N	\N	61.824885000000002	д.Семеново, д.82		0101000020E6100000A48B4D2B8510424001FBE8D495E94E40
39447	3	24	1828	28160	59369	\N	62.005898999999999	п.Рагнукса, ул.Школьная, д.5а		0101000020E6100000DE718A8EE4364240200A664CC1004F40
39460	3	24	1828	47966	59132	\N	62.446240000000003	п.Пяльма, Школьная, 24		0101000020E61000001901158E20F1414062156F641E394F40
39461	3	24	1828	28836	59333	\N	62.318674000000001	пос.Пудожгорский, ул.Молодежная, д.2		0101000020E61000009DBCC804FCF64140F20A444FCA284F40
39440	3	24	1828	27864	59212	\N	61.806973999999997	г.Пудож, ул.Пионерская, 21		0101000020E61000000307B47405434240745C8DEC4AE74E40
39443	3	24	1828	27864	59109	\N	61.806973999999997	г.Пудож, К.Маркса, 79		0101000020E61000000307B47405434240745C8DEC4AE74E40
39469	3	24	1828	48145	59392	\N	61.798476000000001	п.Приречный, ул.Центральная, д.14		0101000020E610000094162EABB0CD42400952297634E64E40
39450	3	24	1828	32531	59332	\N	61.822454344788603	п.Подпорожье, ул.Школьная, д.24	Россия, республика Карелия, Пудожский район, село Подпорожье	0101000020E6100000D0420246972F4240713B342C46E94E40
39468	3	24	1828	48121	\N	\N	61.783903000000002	д.Погост, 13		0101000020E6100000D714C8EC2CDE42403F1EFAEE56E44E40
39459	3	24	1828	47942	\N	\N	62.161127	д.Песчаное, 27		0101000020E610000025B37A87DBE5414055C03DCF9F144F40
39458	3	24	1828	28667	59417	\N	61.986142999999998	п.Онежский, ул.Советская, д.13		0101000020E610000091ED7C3F35F24140F4160FEF39FE4E40
39449	3	24	1828	28216	\N	\N	62.223847999999997	д.Куганаволок, д.114		0101000020E6100000319A95ED4370424033A31F0DA71C4F40
39466	3	24	1828	29054	\N	\N	61.955449999999999	д.Кубовская, д.52		0101000020E6100000C1E61C3C139E42404A7B832F4CFA4E40
39465	3	24	1828	32615	59313	\N	61.949824	п.Кубово, ул.Победы, д.4а		0101000020E61000009817601F9D9642405B7A34D593F94E40
39464	3	24	1828	48029	59134	\N	61.805464999999998	п.Кривцы, ул.Горького, д.5		0101000020E610000050FC1873D77A42404C89247A19E74E40
39453	3	24	1828	47821	59388	\N	61.655597	п.Красноборский, ул.Центральная, д.1		0101000020E6100000F4C473B6802C4240882D3D9AEAD34E40
39445	3	24	1828	33132	\N	\N	61.797145999999998	д.Колово, д.5		0101000020E6100000B4739A05DA634240901150E108E64E40
39446	3	24	1828	33132	59305	\N	61.797145999999998	п.Колово, ул.Школьная, д.3		0101000020E6100000B4739A05DA634240901150E108E64E40
39452	3	24	1828	28382	59438	\N	61.683245074961803	д.Каршево, ул.Школьная, д.47	Россия, республика Карелия, Пудожский район, село Каршево	0101000020E6100000A4C519C39C264240E813799274D74E40
39408	3	24	1828	46963	59167	\N	61.778410563757298	с. Заозерье, Центральная, 7	Россия, республика Карелия, Пудожский район, село Заозерье	0101000020E61000002060ADDA35E142405FECBDF8A2E34E40
95095	3	24	1828	28358	59439	\N	61.849982766472301	п.Бочилово ,ул. Лесная, д. 29	Россия, республика Карелия, Пудожский район, село Бочилово	0101000020E61000006AC020E9D31E4240F793313ECCEC4E40
39388	3	24	1828	46554	\N	\N	62.015360999999999	д.Авдеево, д.68		0101000020E6100000B64DF1B8A806424022516859F7014F40
39429	3	24	550	27355	59158	\N	61.849186000000003	пос.Эссойла, ул.Октябрьская, д.11		0101000020E61000000282397AFC9640404C1C7920B2EC4E40
39407	3	24	550	27001	\N	\N	61.887053719437297	п.Чална-1, Здание Гарнизонного дома офицеров	Россия, республика Карелия, Пряжинский район, село Чална	0101000020E6100000FA7B293C680841409BE447FC8AF14E40
39421	3	24	550	27001	59107	\N	61.883535000000002	пос.Чална, ул.Школьная, д.17А		0101000020E6100000DEACC1FBAA08414089EFC4AC17F14E40
39432	3	24	550	27496	59354	\N	61.922342	пос.Сяпся, ул.Школьная, д.11		0101000020E6100000BF28417FA1AF404016DD7A4D0FF64E40
39430	3	24	550	27408	59371	\N	61.808802	пос.Соддер, ул.Школьная, д.5		0101000020E61000004B3ACAC16C6C40403E78EDD286E74E40
39426	3	24	550	27199	59309	\N	61.558748999999999	с.Святозеро, ул.Олонецкая, д.5		0101000020E6100000950C0055DCCE40401BD6541685C74E40
39435	3	24	550	47514	\N	\N	61.673566000000001	д.Савиново, здание школы-сада	Россия, республика Карелия, Пряжинский район, село Савиново	0101000020E6100000DA571EA4A77C404049D9226937D64E40
39419	3	24	550	26908	59106	\N	61.696404999999999	пгт.Пряжа, ул.Советская, д.89		0101000020E61000008FC70C54C6CF4040ACE28DCC23D94E40
39431	3	24	550	47433	\N	\N	61.831747999999997	пос.Новые Пески, здание библиотеки	Россия, республика Карелия, Пряжинский район, село Новые Пески	0101000020E6100000C173EFE192774040B741EDB776EA4E40
39425	3	24	550	27186	59291	\N	61.780585000000002	пос.Матросы, Пряжинское шоссе, 20		0101000020E61000001E37FC6EBAE74040C45F9335EAE34E40
39424	3	24	550	27122	\N	\N	61.872683000000002	пос.Кутижма, здание сельского клуба	Россия, республика Карелия, Пряжинский район, село Кутижма	0101000020E610000005FC1A4982C8404039639813B4EF4E40
39433	3	24	550	3398	59356	\N	62.021282999999997	п. Кудама, ул. Пионерская, д.1		0101000020E61000002A58E36C3A924040FA7ABE66B9024F40
39428	3	24	550	27291	59396	\N	61.631271144733397	с.Крошнозеро, ул.Магистральная, д.14	Россия, республика Карелия, Пряжинский район, село Крошнозеро	0101000020E6100000CBB9145795954040E4F4F57CCDD04E40
39439	3	24	550	27808	\N	\N	61.677005999999999	с.Колатсельга, здание дома культуры	Россия, республика Карелия, Пряжинский район, село Колатсельга	0101000020E6100000E44D7E8B4E1E40400F99F221A8D64E40
39438	3	24	550	27780	59373	\N	61.524272314822099	пос.Койвусельга, ул.Гагарина, д.1	Россия, республика Карелия, Пряжинский район, село Койвусельга	0101000020E6100000C007AF5DDA3A4040B11A4B581BC34E40
39437	3	24	550	27739	59384	\N	61.389612	пос.Кинелахта, ул.Центральная, д.16		0101000020E6100000A79196CADB4D4040881057CEDEB14E40
39423	3	24	550	27071	\N	\N	61.889822000000002	пос.Виллагора, здание фельдшерско-акушерского пункта	Россия, республика Карелия, Пряжинский район, село Виллагора	0101000020E61000001A1538D906DA404073A1F2AFE5F14E40
39422	3	24	550	27056	\N	\N	61.869594999999997	д.Виданы, здание детского сада	Россия, республика Карелия, Пряжинский район, село Виданы	0101000020E61000008C648F5033004140EFE192E34EEF4E40
39514	3	24	550	31332	59456	\N	61.918340000000001	с. Вешкелица, Стойкина, 6		0101000020E6100000B69DB64604694040E84D452A8CF54E40
39427	3	24	550	27261	\N	\N	61.382196	пос.Верхние Важины, здание фельдшерско-акушерского пункта	Россия, республика Карелия, Пряжинский район, село Верхние Важины	0101000020E61000005323F433F5D64040BD546CCCEBB04E40
39436	3	24	550	57552	59348	\N	61.570680850525797	с.Ведлозеро, ул.Школьная, д.2	Россия, республика Карелия, Пряжинский район, село Велдозеро	0101000020E6100000AF44A0FA076B40406BB933130CC94E40
39416	3	24	536	57564	\N	\N	61.413633354342501	д. Вехручей, 23 А	Россия, республика Карелия, Прионежский район, село Верхручей	0101000020E6100000F3C98AE1EAA04140EFC517EDF1B44E40
39409	3	24	536	26420	\N	\N	61.881490999999997	д. Ялгуба, Здание дома культуры	Россия, республика Карелия, Прионежский район, село Ялгуба	0101000020E6100000427BF5F1D0474140F25B74B2D4F04E40
39328	3	24	536	49590	59202	\N	61.906609420596098	п. Шуя, Школьная, 10 А	Россия, республика Карелия, Прионежский район, село Шуя	0101000020E610000055C03DCF9F1E414030A182C30BF44E40
39417	3	24	536	26824	59330	\N	61.372093999999997	с. Шелтозеро, Лисицыной, 3		0101000020E6100000B4588AE42BAD4140D784B4C6A0AF4E40
39418	3	24	536	26838	\N	\N	61.279316879144197	с. Рыбрека, Здание школы	Россия, республика Карелия, Прионежский район, село Рыбрека	0101000020E61000006B2DCC423BC34140C11BD2A8C0A34E40
14673	3	24	536	9317	\N	\N	61.498372363641103	д. Пухта, 39	Россия, республика Карелия, Прионежский район, село Пухта	0101000020E6100000378AAC3594544140FE9E58A7CABF4E40
39413	3	24	536	26632	59385	\N	61.541302193854399	д. Педасельга, Радиоцентр, 5	Россия, республика Карелия, Прионежский район, село Педасельга	0101000020E6100000611A868F8857414034A1496249C54E40
39404	3	24	536	26200	59350	\N	61.206324000000002	п. Пай, Кировская, 10		0101000020E61000008FFAEB1516384140A13028D3689A4E40
39403	3	24	536	3262	59206	\N	61.356067000000003	п. Ладва-Ветка, ул. Молодежная, 4б, Администрация сельского поселения		0101000020E6100000A3E6ABE463394140A9177C9A93AD4E40
39402	3	24	536	26128	59209	\N	61.358632999999998	п. Ладва, Советская, 129		0101000020E610000062BA10AB3F5241401822A7AFE7AD4E40
39415	3	24	536	47097	\N	\N	61.497866000000002	п. Кварцитный, 25		0101000020E61000006BF0BE2A178641402AE5B512BABF4E40
39412	3	24	536	26580	59129	\N	61.619250999999998	с. Деревянное, Набережная, 21		0101000020E6100000B1DD3D40F7514140F581E49D43CF4E40
39406	3	24	536	26271	\N	\N	61.566495000000003	п. Деревянка, Здание школы	Россия, республика Карелия, Прионежский район, село Деревянка	0101000020E610000040321D3A3D3B41407C2C7DE882C84E40
39411	3	24	536	26558	59312	\N	61.823844000000001	д. Вилга, Прионежское шоссе, 17		0101000020E6100000A27BD6355A0A4140BF805EB873E94E40
39242	3	24	326	57558	59390	\N	61.347298346609897	Республика Карелия, Питкярантский район, д. Мансила, ул.Совхозная, д. 3	Россия, республика Карелия, Питкярантский район	0101000020E6100000D09D60FF75BE3F40ADFBC74274AC4E40
39256	3	24	459	19013	\N	\N	64.23740978619	с.Колежма, д.161	Россия, республика Карелия, Беломорский район, село Колежма	0101000020E61000004A42226DE3EF4140936FB6B9310F5040
39237	3	24	326	18029	\N	\N	61.890076000000001	Республика Карелия, Питкярантский район, ст. Янисъярви, помещение ж/д вокзала, д. 8/А		0101000020E6100000CCD4247843F23E402D7AA702EEF14E40
39233	3	24	326	57570	59467	\N	61.768737110279801	"Республика Карелия, Питкярантский район, д. Янис, ул. Полевая, Адм. здание ООО ""Ладожское"""	Россия, республика Карелия, Питкярантский район, поселок Ляскеля	0101000020E6100000ECA529029C023F40D21C59F965E24E40
39235	3	24	326	57549	59352	\N	61.711798400018303	Республика Карелия, Питкярантский район, д. Хийденсельга, ул. Ладожская, д. 4	Россия, республика Карелия, Питкярантский район, Ляскеля	0101000020E61000009946938B31FC3E40DAAD65321CDB4E40
39236	3	24	326	57555	59362	\N	61.809711471348997	Питкярантский муниципальный район, д.Харлу, ул.2-Речная, дом 2	Россия, республика Карелия, Питкярантский район, поселок Харлу	0101000020E61000002CD7DB662AF03E40111B2C9CA4E74E40
39230	3	24	326	17675	59374	\N	61.495950999999998	Республика Карелия, Питкярантский район, д. Ууксу, ул. Геологическая, д. 9		0101000020E61000006DFFCA4A939A3F4091B586527BBF4E40
39240	3	24	326	1507	59322	\N	61.349355000000003	Республика Карелия, Питкярантский район, п. Салми, ул. Свирских дивизий, д.2		0101000020E6100000CEE33098BFC23F40D8D825AAB7AC4E40
39238	3	24	326	18081	59375	\N	61.756420132391497	Республика Карелия, Питкярантский район, д. Рауталахти, ул. Центральная, д. 16	Россия, республика Карелия, Питкярантский район, село Рауталахти	0101000020E6100000C520B07268E53E402905DD5ED2E04E40
39226	3	24	326	17448	\N	\N	61.569021999999997	Республика Карелия, г. Питкяранта, ул. Победы, д. 3	Россия, республика Карелия, Питкярантский район, Питкяранта	0101000020E61000007024D06053773F402D5A80B6D5C84E40
39241	3	24	326	2906	59365	\N	61.343893999999999	Республика Карелия, Питкярантский район, д. Мийнала, ул. Совхозная, д. 3		0101000020E6100000D1AE42CA4FE23F4033A5F5B704AC4E40
39234	3	24	326	17864	59341	\N	61.763559999999998	Республика Карелия, Питкярантский район, п. Ляскеля, ул. Советская, д. 33		0101000020E6100000B6662B2FF9033F4052448655BCE14E40
39231	3	24	326	17764	59321	\N	61.671615000000003	Республика Карелия, Питкярантский район, п. Импилахти, ул. Советская, д. 3		0101000020E6100000FE9C82FC6C283F406440F67AF7D54E40
39393	3	24	1761	25747	59300	\N	61.181382999999997	п.Устье Видлицы, ул.Привокзальная, д.13, бывш. фельдшерско-акушерский пункт		0101000020E6100000B7EEE6A90E3140407286E28E37974E40
39384	3	24	1761	25281	59404	\N	61.118625000000002	д.Устье Тулоксы, ул.Мурзанова, библиотека		0101000020E610000069AA27F38F48404077BE9F1A2F8F4E40
39389	3	24	1761	25533	59128	\N	61.010039999999996	"д.Тукса, ул.Новая, д.1а, администрация ""Агрофирма ""Тукса"""		0101000020E61000006E4DBA2D916B40406FD39FFD48814E40
39387	3	24	1761	25444	\N	\N	60.967460000000003	д.Рыпушкалицы, д.20б, школа		0101000020E610000030A182C30B7440401618B2BAD57B4E40
39380	3	24	1761	24984	59125	\N	60.976824999999998	г.Олонец, ул.Урицкого, д.9, детская музыкальная школа		0101000020E6100000EE7A698A007D40402575029A087D4E40
39378	3	24	1761	24984	59125	\N	60.976824999999998	г.Олонец, ул.Урицкого, д.4а, СОШ №1		0101000020E6100000EE7A698A007D40402575029A087D4E40
39386	3	24	1761	24984	59433	\N	60.976824999999998	г.Олонец, ул.Полевая, д.41, СОШ № 2		0101000020E6100000EE7A698A007D40402575029A087D4E40
39377	3	24	1761	24984	59126	\N	60.976824999999998	г.Олонец, ул.Красноармейская, д.19, Детско-юношеская спортшкола		0101000020E6100000EE7A698A007D40402575029A087D4E40
39379	3	24	1761	24984	59210	\N	60.976824999999998	г.Олонец, ул.Карла Маркса, д.3а, СОШ № 1		0101000020E6100000EE7A698A007D40402575029A087D4E40
39395	3	24	1761	25824	\N	\N	61.074285000000003	д.Нурмолицы, д.32а, администрация поселения		0101000020E6100000261E5036E5764040ACCABE2B82894E40
39400	3	24	1761	46789	59386	\N	61.009245999999997	с.Михайловское, ул.Новая, д.15а, дом культуры		0101000020E61000000FD07D39B3DF404035CF11F92E814E40
39401	3	24	1761	26102	59317	\N	60.932181	"д.Мегрега, пер.Школьный, д.3, администрация ""Племсовхоз ""Мегрега"""		0101000020E610000053927538BA8C4040EE79FEB451774E40
39399	3	24	1761	26015	59349	\N	60.993944999999997	д.Куйтежа, ул.Ленина, д.12а, школа		0101000020E6100000A3E6ABE4639B4040E882FA96397F4E40
39397	3	24	1761	25894	59299	\N	61.274611	д.Коткозеро, ул.Олонецкая, д.10, дом культуры		0101000020E6100000F69A1E14949A4040990F087426A34E40
39396	3	24	1761	25874	59363	\N	61.141409000000003	п.Ковера, ул.60-летия Великого Октября, д.25, школа		0101000020E6100000CB9E0436E7824040172EABB019924E40
39382	3	24	1761	32716	59307	\N	61.011374000000004	"п.Ильинский, ул.Леселидзе, д.46, ""Центр клубных инициатив"""		0101000020E61000002ECBD765F85740402A0307B474814E40
39381	3	24	1761	32716	59166	\N	61.011374000000004	п.Ильинский, ул.Заводская, д.15, детская музыкальная школа		0101000020E61000002ECBD765F85740402A0307B474814E40
39392	3	24	1761	57563	\N	\N	61.1919398925275	д.Гавриловка, магазин сельпо	Россия, республика Карелия, Олонецкий район, село Гавриловка	0101000020E61000000932022A1C394040AA656B7D91984E40
39390	3	24	1761	25579	59211	\N	61.194659999999999	с.Видлица, ул.Школьная, д.28, школа		0101000020E6100000AFB2B6291E33404070EB6E9EEA984E40
39385	3	24	1761	32790	\N	\N	60.992348	"д.Верховье, д.22а, бывш д/с ""Ивушка"""		0101000020E61000008E210038F682404021205F42057F4E40
39398	3	24	1761	25967	59434	\N	61.459409000000001	п.Верхнеолонецкий, ул.Школьная, д.4, школа		0101000020E610000016DD7A4D0FA04040793E03EACDBA4E40
39394	3	24	1761	46670	\N	\N	61.309885000000001	д.Большие Горы, дом культуры		0101000020E61000000FED6305BF3B4040AF42CA4FAAA74E40
39383	3	24	1761	25215	\N	\N	60.977753999999997	"д.Алексала, столовая  ""Плем хоз ""Ильиское"""		0101000020E6100000C347C494486640403FC4060B277D4E40
39368	3	24	1745	24537	59428	\N	63.251286	Республика Карелия, Муезерский муниципальный район, Суккозерское сельское поселение, Тумба, Первомайская, 3		0101000020E610000091B6F1272A034040A9F8BF232AA04F40
39374	3	24	1745	24855	59431	\N	64.111610999999996	Республика Карелия, Муезерский муниципальный район, Ледмозерское сельское поселение, Тикша, Школьная, 1		0101000020E61000005BCD3AE3FB344040EDB776A224075040
39326	3	24	1619	57543	59319	\N	66.272132148346003	п.Чупа, ул.Коргуева, д.7а	Россия, республика Карелия, Лоухский район, поселок Чупа	0101000020E6100000F1D8CF62298640407C0C569C6A915040
39365	3	24	1745	24386	59122	\N	63.168792556614797	Республика Карелия, Муезерский муниципальный район, Суккозерское сельское поселение, Суккозеро, Советская, 23	Россия, республика Карелия, Муезерский район, поселок Суккозеро	0101000020E6100000A0C552245F2B404099654F029B954F40
39376	3	24	1745	24924	59329	\N	64.082329999999999	Республика Карелия, Муезерский муниципальный район, Ругозерское сельское поселение, Ругозеро, Еремеева, 30		0101000020E6100000B77D8FFAEB634040B35E0CE544055040
39373	3	24	1745	24797	59346	\N	63.833103999999999	Республика Карелия, Муезерский муниципальный район, Ребольское сельское поселение, Реболы, Моккиева, 1		0101000020E6100000C8ED974F56CC3E405915E126A3EA4F40
39364	3	24	1745	24352	59340	\N	63.552350690088801	Республика Карелия, Муезерский муниципальный район, Пенингское сельское поселение, Пенинга, Ленина, 26	Россия, республика Карелия, Муезерский район, село Пенинга	0101000020E6100000C30E63D2DF054040DA740470B3C64F40
39366	3	24	1745	24447	59399	\N	63.875571000000001	Республика Карелия, Муезерский муниципальный район, Ругозерское сельское поселение, Ондозеро, Рабочая, 1А		0101000020E6100000DBC01DA8538E4040BB29E5B512F04F40
39361	3	24	1745	24209	59162	\N	63.962553999999997	Республика Карелия, Муезерский муниципальный район, Муезерское городское поселение, Муезерский, Октябрьская, 27		0101000020E6100000FA415DA450FE3F4026512FF834FB4F40
39369	3	24	1745	24621	59361	\N	63.291876999999999	Республика Карелия, Муезерский муниципальный район, Лендерское сельское поселение, Мотко, Комсомольская, 15		0101000020E610000005A3923A01B93F4030BABC395CA54F40
39371	3	24	1745	24637	59204	\N	63.409826000000002	Республика Карелия, Муезерский муниципальный район, Лендерское сельское поселение, Лендеры, Первомайская, 4		0101000020E6100000D86322A5D9383F407786A92D75B44F40
39375	3	24	1745	24877	59207	\N	64.251807999999997	Республика Карелия, Муезерский муниципальный район, Ледмозерское сельское поселение, Ледмозеро, 50 лет ВЛКСМ, 9Б		0101000020E6100000618E1EBFB7034040C1374D9F1D105040
39372	3	24	1745	24755	59415	\N	63.644278999999997	Республика Карелия, Муезерский муниципальный район, Лендерское сельское поселение, Кимоваара, Советская, 5		0101000020E6100000B0373124270B3F40F23FF9BB77D24F40
39367	3	24	1745	24521	59416	\N	62.935817999999998	Республика Карелия, Муезерский муниципальный район, Суккозерское сельское поселение, Гимолы, Ленина, 17		0101000020E610000055302AA9134440400A815CE2C8774F40
39363	3	24	1745	24298	59105	\N	63.744103000000003	Республика Карелия, Муезерский муниципальный район, Воломское сельское поселение, Волома, 23 съезда, 1А		0101000020E61000001399B9C0E5ED3F4081ED60C43EDF4F40
39355	3	24	1704	32581	59311	\N	62.592942000000001	д.Шуньга, ул.Совхозная, д.15		0101000020E61000003ECE3461FB77414061360186E54B4F40
39342	3	24	1704	57561	\N	\N	63.191205379368299	пос.9-й шлюз, школа	Россия, республика Карелия, Медвежьегорский район, село Шлюз 9	0101000020E6100000E7E3DA503172414074EACA6779984F40
39352	3	24	1704	23765	59360	\N	63.511446794529498	пос.Шалговаара, ул.Советская, д.20	Россия, республика Карелия, Медвежьегорский район, село Шалговаара	0101000020E6100000888384285FA040409351651877C14F40
39347	3	24	1704	23542	59351	\N	62.585400999999997	д.Челмужи, ул.Гагарина, д.60		0101000020E6100000028063CF9ECB4140D905836BEE4A4F40
39349	3	24	1704	23630	59358	\N	62.913479000000002	д.Чебино, ул.Центральная, д.52		0101000020E6100000AD1402B9C4134140994A3FE1EC744F40
39357	3	24	1704	23981	59102	\N	62.507927000000002	д.Толвуя, ул.Гористая, д.7		0101000020E6100000C8B60C384BA54140B1E07EC003414F40
39341	3	24	1704	57562	59430	\N	62.829043631336098	с.Сосновка, ул.Конституции, д.3	Россия, республика Карелия, Медвежьегорский район, село Повенец	0101000020E6100000247EC51A2E624140F778211D1E6A4F40
39348	3	24	1704	45696	59413	\N	62.902897000000003	пос.Сергиево, ул.Гагарина, д.5		0101000020E61000000ABB287AE00142400954FF2092734F40
39340	3	24	1704	23185	59164	\N	62.857047890635002	пос.Повенец, ул.Копейкина, д.4	Россия, республика Карелия, Медвежьегорский район, поселок Повенец	0101000020E61000006495D233BD6A4140158DB5BFB36D4F40
39337	3	24	1704	23058	59100	\N	62.927360999999998	пос.Пиндуши, ул.Ленина, д.8-а		0101000020E61000008B6CE7FBA9494140FD4AE7C3B3764F40
39338	3	24	1704	23058	59205	\N	62.927360999999998	пос.Пиндуши, ул.Конституции, д.19		0101000020E61000008B6CE7FBA9494140FD4AE7C3B3764F40
39351	3	24	1704	23706	59123	\N	63.288105000000002	с.Паданы, ул.Гористая, д.5		0101000020E61000009F93DE37BEB440403468E89FE0A44F40
39345	3	24	1704	45647	59410	\N	63.012044000000003	пос.Огорелыши, ул.Центральная, д.17		0101000020E6100000F5A10BEA5BDA4140780E65A88A814F40
39343	3	24	1704	23334	59425	\N	62.804690000000001	пос.Новая Габсельга, ул.Дорожная, д.10-а		0101000020E61000002769FE98D68A414089B5F81400674F40
39332	3	24	1704	22739	59097	\N	62.917468	г.Медвежьегорск, ул.К.Либкнехта, д.20-а		0101000020E610000030A017EE5C3A4140329067976F754F40
39353	3	24	1704	23816	59402	\N	63.529443000000001	пос.Маслозеро, ул.Школьная, д.19		0101000020E6100000014EEFE2FD6C40404E0CC9C9C4C34F40
39339	3	24	1704	23161	59295	\N	62.915674000000003	д.Лумбуши, ул.Совхозная, д.10		0101000020E61000001FD61BB5C246414015E63DCE34754F40
39360	3	24	1704	24138	59336	\N	62.287785999999997	пос.Ламбасручей, ул.Школьная, д.5		0101000020E6100000E811A3E716704140921FF12BD6244F40
39350	3	24	1704	23688	59429	\N	62.954120653671502	пос.Кумса-2, ул.Лесная, д.2	Россия, республика Карелия, Медвежьегорский район, село Кумса 2	0101000020E6100000B284B53176E64040A2B60DA3207A4F40
39356	3	24	1704	23943	\N	\N	62.550255999999997	д.Кажма, Дом досуга		0101000020E61000009D9E7763416B4140C136E2C96E464F40
39344	3	24	1704	23391	59426	\N	62.772967000000001	пос.Верхнее Волозеро, ул.Центральная, школа		0101000020E610000042CEFBFF38B5414091F12895F0624F40
39358	3	24	1704	45864	59427	\N	62.358175000000003	д.Великая Нива, ул.Ригачина, д.3		0101000020E6100000DC82A5BA809B4140569FABADD82D4F40
39359	3	24	1704	24082	59124	\N	62.248342999999998	с.Великая Губа, ул.Рябова, д.25-а		0101000020E6100000355F251FBB894140639813B4C91F4F40
39315	3	24	1619	22105	59292	\N	65.788220999999993	п.Энгозеро, ул.Советская, д.12		0101000020E6100000F0DFBC38F1F740404E417E3672725040
39327	3	24	1619	57543	59219	\N	66.268536053011005	п.Чупа, ул.Пионерская, д.94	Россия, республика Карелия, Лоухский район, поселок Чупа	0101000020E6100000B83CD68C0C8640401D739EB12F915040
39329	3	24	1619	22725	59401	\N	66.353352974109995	п.Хетоламбина, ул.Новая, д.1	Россия, республика Карелия, Лоухский район, село Хетоламбина	0101000020E610000083F8C08EFFA4404062BCE6559D965040
39324	3	24	1619	22462	59424	\N	66.467198999999994	п.Тэдино, ул.Слюдяная, д.10		0101000020E61000008F19A88C7F5F4040546EA296E69D5040
39318	3	24	1619	22199	59382	\N	65.752981000000005	п.Тунгозеро, ул.Комсомольская, д.12		0101000020E6100000B728B341264D3F409A6038D730705040
39319	3	24	1619	22276	59421	\N	65.802965999999998	п.Софпорог, ул.Центральная, д.1		0101000020E61000009758198D7C6A3F40327381CB63735040
39321	3	24	1619	57548	59310	\N	66.000745649238397	п.Сосновый, ул.Школьная, д.1	Россия, республика Карелия, Лоухский район, село Сосновый	0101000020E610000059C345EEE92840409566F3380C805040
39317	3	24	1619	22183	59120	\N	65.764373000000006	п.Пяозерский, ул.Дружбы, д.23		0101000020E61000002E573F36C9133F40823CBB7CEB705040
39323	3	24	1619	49509	59383	\N	66.197646000000006	п.Плотина, ул.Клубная, д.2		0101000020E6100000EF54C03DCFAD4040DB8B683BA68C5040
39279	3	24	1619	20276	59445	\N	66.296390000000002	п.Малиновая Варакка, ул.Слюдяная, д.3		0101000020E61000001CEBE2361A9A40402237C30DF8925040
39313	3	24	1619	21975	59117	\N	66.076666342625899	п.Лоухи, ул.Советская, д.46	Россия, республика Карелия, Лоухский район, поселок Лоухи	0101000020E61000003196E99788834040C5AD8218E8845040
39314	3	24	1619	21975	59159	\N	66.072590000000005	п.Лоухи, ул.Железнодорожная, д.1		0101000020E6100000BBD6DEA7AA80404011018750A5845040
39325	3	24	1619	21975	59304	\N	66.075377077822495	п.Лоухи, переулок Дачный, д.6	Россия, республика Карелия, Лоухский район, поселок Лоухи	0101000020E61000004BAFCDC64A824040B8770DFAD2845040
39320	3	24	1619	22329	59095	\N	65.892178000000001	п.Кестеньга, ул.Набережная, д.41		0101000020E61000004A438D4292D53F407C0DC17119795040
39316	3	24	1619	22124	59318	\N	65.896974999999998	п.Амбарный, ул.Ленина, д.18		0101000020E61000002E573F36C9DB40401895D40968795040
39301	3	24	1642	21408	59411	\N	61.406202999999998	Республика Карелия, Лахденпохский район,  пос.Эстерло, Центральная, 13		0101000020E6100000F5D6C05609BE3D40BF44BC75FEB34E40
39300	3	24	1642	21372	59331	\N	61.410345	Республика Карелия, Лахденпохский район,  пос.Элисенваара, Петровского, 1		0101000020E6100000B37A87DBA1C53D40DF89592F86B44E40
39308	3	24	1642	21721	59357	\N	61.394798000000002	Республика Карелия, Лахденпохский район,  пос.Хухтерву, Центральная, здание бывшей школы		0101000020E610000007B7B585E7193E405B43A9BD88B24E40
39309	3	24	1642	21801	59290	\N	61.239002999999997	Республика Карелия, Лахденпохский район,  пос.Хийтола, Ленина, 16		0101000020E6100000A08D5C37A5B03D40AC527AA6979E4E40
39310	3	24	1642	21855	59381	\N	61.315193000000001	Республика Карелия, Лахденпохский район,  пос.Тоунан, Правды, 2а		0101000020E6100000DA56B3CEF88A3D40CD76853E58A84E40
39311	3	24	1642	21879	59359	\N	61.216068	Республика Карелия, Лахденпохский район, пос.Тиурула, Солнечная, 6а		0101000020E610000021020EA14ADD3D4027DBC01DA89B4E40
39307	3	24	1642	21713	59398	\N	61.312153000000002	Республика Карелия, Лахденпохский район, пос.Терву, Школьная, 14		0101000020E6100000F06DFAB31F1D3E40952C27A1F4A74E40
39299	3	24	1642	21317	59377	\N	61.532786304078599	Республика Карелия, Лахденпохский район,  пос.Раухала, Центральная, 2	Россия, республика Карелия, Лахденпохский район, село Раухала	0101000020E6100000662D05A4FD373E4022E2E65432C44E40
39295	3	24	1642	21155	59453	\N	61.552269000000003	Республика Карелия, Лахденпохский район, пос. Мийнала, Школьная, 4		0101000020E6100000E256410C74513E401DCC26C0B0C64E40
39297	3	24	1642	21242	59448	\N	61.438958	Республика Карелия, Лахденпохский район,  пос.Лумиваара, Центральная, 22		0101000020E6100000377172BF43253E40A62897C62FB84E40
39294	3	24	1642	20760	59093	\N	61.527827000000002	Республика Карелия, г.Лахденпохья, Трубачева, 1		0101000020E6100000FDBCA948852D3E401079CBD58FC34E40
39305	3	24	1642	21614	59407	\N	61.270698000000003	Республика Карелия, Лахденпохский район, пос.Ласанен, Ленинградская, 3		0101000020E61000004339D1AE42DA3D40DB8B683BA6A24E40
39303	3	24	1642	21490	\N	\N	61.374507999999999	Лахденпохский район, п. Ламминкюля (здание бывшей школы)	Россия, республика Карелия, Лахденпохский район, село Ламминкюля	0101000020E610000039B35DA10F963D40910BCEE0EFAF4E40
39304	3	24	1642	21553	59335	\N	61.302411999999997	Республика Карелия, Лахденпохский район, пос.Куркиеки, Ленина, 25		0101000020E61000006B813D2652E23D407FF5B86FB5A64E40
39312	3	24	1642	21954	59380	\N	61.195383999999997	Республика Карелия, Лахденпохский район,  пос.Куликово, Ленина, 4		0101000020E6100000C26856B60FBD3D40B114C95702994E40
39298	3	24	1642	21261	59325	\N	61.498561000000002	Республика Карелия, Лахденпохский район,  пос.Ихала, Центральная, 46		0101000020E6100000AD872F1345003E40D107CBD8D0BF4E40
39302	3	24	1642	21458	59423	\N	61.438755999999998	Республика Карелия, Лахденпохский район, пос.Вялимяки, Зеленая, 9		0101000020E61000002F4D11E0F4D23D403E76172829B84E40
39306	3	24	1642	21627	59406	\N	61.320301000000001	Республика Карелия, Лахденпохский район, пос.Алхо, Лесная, 5		0101000020E6100000632B685A62B93D4024F0879FFFA84E40
39561	3	24	19	1389	\N	\N	62.114193	Республика Карелия, Кондопожский район, с. Янишполе, помещение Администрации с/п	Россия, республика Карелия, Кондопожский район, село Янишполе	0101000020E6100000BF0E9C33A2224140503750E09D0E4F40
39554	3	24	19	943	\N	\N	62.710096999999998	Республика Карелия, Кондопожский район, п.Эльмус, помещение ФАП	Россия, республика Карелия, Кондопожский район, село Эльмус	0101000020E6100000D3A414747BD140406DFE5F75E45A4F40
39558	3	24	19	1210	59405	\N	62.600760111762	Кондопожский район, п.Уница, ул.Заречная, помещение ФАП	Россия, республика Карелия, Кондопожский район, село Уница	0101000020E6100000336FD575A83A41405B5F24B4E54C4F40
39560	3	24	19	52004	\N	\N	62.151865999999998	Республика Карелия, Кондопожский район, д.Улитина Новинка, помещение Администрвции с/п	Россия, республика Карелия, Кондопожский район, село Улитина-Новинка	0101000020E610000066F50EB743354140EAAF575870134F40
39555	3	24	19	51985	\N	\N	62.559368999999997	Республика Карелия, Кондопожский район, д. Тивдия, Помещение ФАП	Россия, республика Карелия, Кондопожский район, село Тивдия	0101000020E61000003CF4DDAD2CFB4040B7B2446799474F40
39551	3	24	19	796	\N	\N	62.214635999999999	Кондопожский район, с.Спасская губа, помещение Спасогубской СОШ	Россия, республика Карелия, Кондопожский район, село Спасская Губа	0101000020E6100000B4C876BE9FE84040AA454431791B4F40
39552	3	24	19	820	\N	\N	62.193933000000001	Республика Карелия, Кондопожский район, п.Нелгомозеро, помещение Дома Культуры	Россия, республика Карелия, Кондопожский район, село Нелгомозеро	0101000020E6100000E4A25A4414B94040BE4EEACBD2184F40
39557	3	24	19	1165	\N	\N	62.670830000000002	Республика Карелия, Кондопожский район, п.Кяппесельга, помещение Дома культуры	Россия, республика Карелия, Кондопожский район, село Кяппесельга	0101000020E6100000B8770DFAD22141407D96E7C1DD554F40
39549	3	24	19	684	\N	\N	62.125487999999997	Кондопожский район, с.Кончезеро, помещение Кончезерской СОШ	Россия, республика Карелия, Кондопожский район, село Кончезеро	0101000020E6100000E4BED53A710141402D05A4FD0F104F40
39540	3	24	19	24	59178	\N	62.197037999999999	"Республика Карелия, г.Кондопога, ул.Строительная, д.2 (Дворец спорта"")"		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39535	3	24	19	24	59163	\N	62.197037999999999	"Республика Карелия, г.Кондопога, ул.Пролетарская, д.14 ""СОШ №1"""		0101000020E6100000F9DB9E20B1214140DD088B8A38194F40
39556	3	24	19	1050	\N	\N	62.366655000000002	Кондопожский район, п.Кедрозеро, помещение школы	Россия, республика Карелия, Кондопожский район, село Кедрозеро	0101000020E61000003929CC7B9C3D41401BF5108DEE2E4F40
39553	3	24	19	921	\N	\N	62.471102000000002	Республика Карелия, Кондопожский район, п.Гирвас, Средняя школа		0101000020E61000006DE179A9D8D64040448A01124D3C4F40
39548	3	24	19	574	\N	\N	62.231205000000003	Республика Карелия, Кондопожский район, п.Березовка, помещение библиотеки	Россия, республика Карелия, Кондопожский район, село Березовка	0101000020E6100000B3976DA7AD154140FAD51C20981D4F40
39283	3	24	430	20488	59091	\N	64.983608000000004	п.Рабочеостровск, ул.Советская, 11		0101000020E61000009D9B36E3346041406005F86EF33E5040
39285	3	24	430	20600	59457	\N	64.972969964236697	п.Панозеро, ул.Ленина, 2	Россия, республика Карелия, Кемский район, село Панозеро	0101000020E61000000C207C28D16E40404E7FF623453E5040
39286	3	24	430	3156	59368	\N	65.359795000000005	П. КУЗЕМА, УЛ. ВОКЗАЛЬНАЯ, Д.4		0101000020E6100000A8A9656B7D1F4140EB909BE106575040
39284	3	24	430	20554	59144	\N	65.035647999999995	п.Кривой Порог, ул.Кольцевая, 16-а		0101000020E610000017F549EEB0D34040BD8A8C0E48425040
39278	3	24	430	3106	59393	\N	64.950453089709498	г.Кемь, ул.Шоссе 1 Мая, 24		0101000020E6100000B1F9B83654484140A5D8D138D43C5040
39280	3	24	430	3106	59200	\N	64.953275000000005	г. Кемь,  пр. Пролетарский, д.18 (МОУ средняя общеобразовательная школа № 1)		0101000020E6100000B60E0EF6264C41400B462575023D5040
39275	3	24	430	3106	59146	\N	64.953275000000005	г. Кемь, Пролетарский пр, 55		0101000020E6100000B60E0EF6264C41400B462575023D5040
39277	3	24	430	3106	59188	\N	64.953275000000005	г. Кемь, ул.Октябрьская, 1		0101000020E6100000B60E0EF6264C41400B462575023D5040
39273	3	24	430	3106	59090	\N	64.953275000000005	г. Кемь, ул.Каменева, 6		0101000020E6100000B60E0EF6264C41400B462575023D5040
39281	3	24	430	57567	59447	\N	64.946131834681097	г. Кемь, Гайжево, ул.Ломоносова, 15-б	Россия, республика Карелия, Кемский район, поселок Гайжево	0101000020E61000006DC7D45DD9514140BE6C3B6D8D3C5040
39282	3	24	430	57550	59328	\N	64.967182572540295	г. Кемь, Бабгуба, ул.Ручьевая, 1-а	Россия, республика Карелия, Кемский район, поселок Бабгуба	0101000020E6100000C32973F38D5A4140D28F8653E63D5040
39287	3	24	430	32833	\N	\N	64.921792999999994	п.14 км. дороги Кемь-Калевала	Россия, республика Карелия, Кемский район, село 14-й километр	0101000020E6100000D4D4B2B5BE2E4140A12B11A8FE3A5040
39269	3	24	349	1747	59460	\N	64.755791000000002	Калевальский муниципальный район, .Юшкозеро, Советская, 10		0101000020E6100000B9AAECBB221240401DE736E15E305040
39271	3	24	349	57568	59458	\N	65.058345739718007	Республика Карелия, Калевальский муниципальный район, пос.Луусалми, Советская, 15	Россия, республика Карелия, Калевальский район, село Луусалма	0101000020E6100000D36A48DC63913F408E76DCF0BB435040
39266	3	24	349	1744	59376	\N	65.173220000000001	Калевальский муниципальный район, п.Куусиниеми, Набережная, 12		0101000020E610000046D09849D4773F40D7C05609164B5040
39270	3	24	349	19734	59442	\N	65.153270000000006	Республика Карелия, Калевальский муниципальный район, п.Кепа, Карельская, 1		0101000020E61000000FBA84436F1540404F5DF92CCF495040
39264	3	24	349	2777	59194	\N	65.199532000000005	Калевальский район, пгт.Калевала, Советская, 15а		0101000020E6100000AEF545425B2E3F405AA0DD21C54C5040
39265	3	24	349	2777	59186	\N	65.199532000000005	Республика Карелия, Калевальский муниципальный район, пгт.Калевала, Ленина, 42		0101000020E6100000AEF545425B2E3F405AA0DD21C54C5040
39267	3	24	349	2788	59089	\N	64.612971000000002	Калевальский муниципальный район, п.Боровой, Советская, 13		0101000020E6100000129F3BC1FE1D40405F99B7EA3A275040
39263	3	24	459	19331	59403	\N	64.742482536332105	с.Шуерецкое, ул.Советская, д.5	Россия, республика Карелия, Беломорский район, село Шуерецкое	0101000020E610000035423F53AF59414080B56AD7842F5040
39257	3	24	459	48471	59441	\N	64.038597999999993	п.Хвойный, ул.Набережная, д.19		0101000020E610000097361C960698414039ECBE6378025040
39253	3	24	459	18870	\N	\N	64.242382000000006	с.Сумский Посад, д.57		0101000020E61000005B79C9FFE4B34140E7C8CA2F830F5040
39255	3	24	459	18870	59412	\N	64.242382000000006	с.Сумский Посад, ул.Школьная, д.4		0101000020E61000005B79C9FFE4B34140E7C8CA2F830F5040
39254	3	24	459	18870	59397	\N	64.242382000000006	с.Сумский Посад, ул.Набережная, д.16		0101000020E61000005B79C9FFE4B34140E7C8CA2F830F5040
39260	3	24	459	48524	59183	\N	64.424156959798495	п.Сосновец, ул.Кирова, д.22	Россия, республика Карелия, Беломорский район, поселок Сосновец	0101000020E6100000F7764B72C03C4140A5D76663251B5040
39259	3	24	459	48517	59366	\N	64.400752999999995	п.Пушной, ул.Пионерская, д.9		0101000020E61000003EB0E3BF401241408731E9EFA5195040
39252	3	24	459	48383	\N	\N	63.918024000000003	с.Нюхча, д.161		0101000020E6100000FA62EFC517214240B87878CF81F54F40
39261	3	24	459	19259	59408	\N	64.409208000000007	п.Новое Машезеро, ул.Почтовая, д.2		0101000020E6100000643DB5FAEAB44040BE50C076301A5040
39250	3	24	459	18688	59343	\N	64.017841503357403	п.Вирандозеро, ул.Советская, д.21	Россия, республика Карелия, Беломорский район, поселок Вирандозеро	0101000020E6100000637C98BD6C014240B29FC55224015040
39244	3	24	459	2679	59446	\N	64.530457802589197	г.Беломорск, пер. Школьный, д.4	Россия, республика Карелия, Беломорский район, Беломорск	0101000020E61000008D614ED026614140B3791C06F3215040
39245	3	24	459	2679	59180	\N	64.520126674952607	г.Беломорск, ул.Строительная, д.18	Россия, республика Карелия, Беломорский район, Беломорск	0101000020E610000000C45DBD8A60414010B1C1C249215040
39247	3	24	459	2679	59193	\N	64.516059682131598	г.Беломорск, ул.Ленинская, д.29	Россия, республика Карелия, Беломорский район, Беломорск	0101000020E61000004F92AE997C61414085B1852007215040
39246	3	24	459	2679	59193	\N	64.519341053207498	г.Беломорск, ул.Ленинская, д.15А	Россия, республика Карелия, Беломорский район, Беломорск	0101000020E61000007FDAA84E07624140349E08E23C215040
39248	3	24	459	2679	59339	\N	64.515246210696404	г.Беломорск, ул.Водников, д.29	Россия, республика Карелия, Беломорский район, Беломорск	0101000020E6100000E8120EBDC561414045D95BCAF9205040
75108	3	32	\N	57387	58416	\N	56.288621199458603	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", город Себеж, Шоссейная, 1-б"	Россия, М-9 шоссе	0101000020E61000008C0FB3976D7B3C402BF86D88F1244C40
75109	3	32	\N	57387	58507	\N	56.286377999999999	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", город Себеж, Первомайская, 56"		0101000020E61000005CAE7E6C927B3C409E25C808A8244C40
74679	3	32	\N	51947	58361	\N	57.831235999999997	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Завеличенская волость"", д.Родина, Школьная, д.3"		0101000020E6100000083C3080F0413C4001A1F5F065EA4C40
74861	3	32	\N	57373	58468	\N	57.066054000000001	г.Пыталово, ул.Победы, д.77а		0101000020E6100000569C6A2DCCEA3B408FE21C7574884C40
74860	3	32	\N	57373	58351	\N	57.066054000000001	г.Пыталово, ул.М.Горького, д.16		0101000020E6100000569C6A2DCCEA3B408FE21C7574884C40
74859	3	32	\N	57373	58501	\N	57.066054000000001	г.Пыталово, ул.Красноармейская, д.51		0101000020E6100000569C6A2DCCEA3B408FE21C7574884C40
74858	3	32	\N	57373	58479	\N	57.065576030254903	г.Пыталово, ул.Белорусская, д.18а	Россия, Псковская область, Пыталовский район, Пыталово	0101000020E61000007863416150EA3B4085B35BCB64884C40
74601	3	32	\N	4697	2020	\N	57.812111999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Юбилейная, д.67А"	Россия, Псковская область, Псков, улица Юбилейная, 67а	0101000020E610000092CF2B9E7A4C3C4036583849F3E74C40
75031	3	32	\N	4697	1621	\N	57.817697000000003	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование городское поселение ""Струги Красные"", Советская, 28"	Россия, Псковская область, Псков, улица Советская, 20	0101000020E6100000CBD6FA22A1553C40C784984BAAE84C40
74582	3	32	\N	4697	1774	\N	57.803581000000001	"Псковская область, Муниципальное образование ""Город Псков"", ул.Пригородная, д.9"	Россия, Псковская область, Псков, улица Пригородная, 9	0101000020E61000005F268A90BA693C40EF5701BEDBE64C40
74650	3	32	\N	4697	2760	\N	57.826549999999997	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Пионерская, д.4"	Россия, Псковская область, Псков, улица Пионерская, 4	0101000020E610000090D8EE1EA0573C402041F163CCE94C40
74903	3	32	\N	4697	16191	\N	57.810111999999997	"д. Петровская, здание администрации СП ""Пригородная волость"""	Россия, Псковская область, Псков, улица Петровская, 1	0101000020E61000002FC03E3A75513C406F0C01C0B1E74C40
74600	3	32	\N	4697	2001	\N	57.811934000000001	"Псковская область, Муниципальное образование ""Город Псков"", ул.Народная, д.55"	Россия, Псковская область, Псков, улица Народная, 55	0101000020E6100000A7E8482EFF4D3C4057410C74EDE74C40
74614	3	32	\N	4697	2059	\N	57.820658999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Коммунальная, д.19"	Россия, Псковская область, Псков, улица Коммунальная, 19	0101000020E6100000F9484A7A184E3C408315A75A0BE94C40
74613	3	32	\N	4697	2059	\N	57.819263999999997	"Псковская область, Муниципальное образование ""Город Псков"", ул.Коммунальная, д.30"	Россия, Псковская область, Псков, улица Коммунальная, 30	0101000020E6100000E7A6CD380D4D3C4023658BA4DDE84C40
74608	3	32	\N	4697	2059	\N	57.817874000000003	"Псковская область, Муниципальное образование ""Город Псков"", ул.Коммунальная, д.48"	Россия, Псковская область, Псков, улица Коммунальная, 48	0101000020E610000042EBE1CB44493C40D61F6118B0E84C40
74604	3	32	\N	4697	2059	\N	57.816110000000002	"Псковская область, Муниципальное образование ""Город Псков"", ул.Коммунальная, д.71А"	Россия, Псковская область, Псков, улица Коммунальная, 71а	0101000020E6100000E5B33C0FEE463C4023F8DF4A76E84C40
74592	3	32	\N	4697	1896	\N	57.806209000000003	"Псковская область, Муниципальное образование ""Город Псков"", ул.Комдива Кирсанова, д.5"	Россия, Псковская область, Псков, улица Комдива Кирсанова, 5	0101000020E6100000A8C64B3789513C40D55E44DB31E74C40
74574	3	32	\N	4697	1660	\N	57.809086000000001	"Псковская область, Муниципальное образование ""Город Псков"", ул.Заводская, д.3"	Россия, Псковская область, Псков, улица Заводская, 3	0101000020E6100000C1012D5DC15A3C4063D34A2190E74C40
74577	3	32	\N	4697	1693	\N	57.808022000000001	"Псковская область, Муниципальное образование ""Город Псков"", ул.Вокзальная, д.48"	Россия, Псковская область, Псков, улица Вокзальная, 48	0101000020E6100000F986C267EB5C3C406939D0436DE74C40
37596	3	28	361	47518	24188	\N	54.671888000000003	п. Луговое, Нестеровская, 21		0101000020E6100000F9A23D5E48AF364095490D6D00564B40
74591	3	32	\N	4697	58365	\N	57.797051389215902	"Псковская область, Муниципальное образование ""Город Псков"", ул.Я.Райниса, д.41"	Россия, Псковская область, Псков, улица Яна Райниса, 41	0101000020E61000009CBF098508543C403F1F65C405E64C40
74573	3	32	\N	4697	58386	\N	57.819268999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.Я.Фабрициуса, д.16"		0101000020E61000006E313F3734553C4035D07CCEDDE84C40
74575	3	32	\N	4697	58438	\N	57.809421999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.Ю.Гагарина, д.5А"		0101000020E6100000772CB649455B3C40DA54DD239BE74C40
74610	3	32	\N	4697	58443	\N	57.819082000000002	"Псковская область, Муниципальное образование ""Город Псков"", ул.Юбилейная, д.87А"		0101000020E6100000C16ED8B6284B3C40035FD1ADD7E84C40
74602	3	32	\N	4697	58443	\N	57.811593999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Юбилейная, д.34"		0101000020E61000003755F7C8E64A3C409ED0EB4FE2E74C40
75023	3	32	\N	4697	58563	\N	57.825048539969799	Школьная,15 - помещение медецинского пункта	Россия, Псковская область, Псков, улица Школьная	0101000020E610000091442FA358563C407B4CA4349BE94C40
74626	3	32	\N	4697	58432	\N	57.834786999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Труда, д.49А"		0101000020E6100000D7F9B7CB7E593C401F10E84CDAEA4C40
74625	3	32	\N	4697	58432	\N	57.836247999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.Труда, д.51"		0101000020E6100000B20DDC813A593C4036ACA92C0AEB4C40
74621	3	32	\N	4697	58432	\N	57.826272000000003	"Псковская область, Муниципальное образование ""Город Псков"", ул.Труда, д.25"		0101000020E6100000C4D155BABB563C40DECCE847C3E94C40
74627	3	32	\N	4697	58461	\N	57.832194999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Текстильная, д.18"		0101000020E610000088B9A46ABB593C408672A25D85EA4C40
74588	3	32	\N	4697	58436	\N	57.790573234166303	"Псковская область, Муниципальное образование ""Город Псков"", ул.Советской Армии, д.54"		0101000020E6100000E813799274593C40E10CFE7E31E54C40
74571	3	32	\N	4697	58455	\N	57.802760999999997	"Псковская область, Муниципальное образование ""Город Псков"", ул.Советская, д.106"		0101000020E6100000315F5E807D583C408BC058DFC0E64C40
74623	3	32	\N	4697	2325	\N	57.838777999999998	"Псковская область, Муниципальное образование ""Город Псков"", Сиреневый бульвар, д.15"	Россия, Псковская область, Псков, Сиреневый бульвар, 15	0101000020E61000005BCD3AE3FB563C40594DD7135DEB4C40
74567	3	32	\N	4697	58437	\N	57.816896	"Псковская область, Муниципальное образование ""Город Псков"", ул.Свердлова, д.56"		0101000020E6100000417E3672DD583C40DA1D520C90E84C40
74598	3	32	\N	4697	58373	\N	57.814732336030602	"Псковская область, Муниципальное образование ""Город Псков"", ул.Р.Люксембург, д.18"	Россия, Псковская область, Псков, улица Розы Люксембург, 18	0101000020E61000002157EA5910523C4099805F2349E84C40
74611	3	32	\N	4697	2150	\N	57.814225999999998	"Псковская область, Муниципальное образование ""Город Псков"", Рижский пр, д.64"	Россия, Псковская область, Псков, Рижский проспект, 64	0101000020E6100000DBDE6E490E4C3C40C5C6BC8E38E84C40
74590	3	32	\N	4697	58425	\N	57.806635999999997	"Псковская область, Муниципальное образование ""Город Псков"", ул.Рельсовая, д.2"		0101000020E61000002D78D157905E3C405CE333D93FE74C40
74570	3	32	\N	4697	1615	\N	57.807605000000002	"Псковская область, Муниципальное образование ""Город Псков"", пл.Победы, д.1"		0101000020E61000002828452BF7563C40058BC3995FE74C40
74603	3	32	\N	4697	58444	\N	57.812916963679697	"Псковская область, Муниципальное образование ""Город Псков"", ул.Печорская, д.3"		0101000020E6100000D6AD9E93DE473C4064AE0CAA0DE84C40
74616	3	32	\N	4697	58445	\N	57.819961430490302	"Псковская область, Муниципальное образование ""Город Псков"", ул.Пароменская, д.9"	Россия, Псковская область, Псков, улица Пароменская	0101000020E610000026DF6C7363523C406B7F677BF4E84C40
74730	3	32	\N	4697	58560	\N	57.799433000000001	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Палкинская волость"", ул.Островская, д.23"		0101000020E61000000A48FB1F60653C40ED2B0FD253E64C40
74596	3	32	\N	4697	1956	\N	57.820673999999997	"Псковская область, Муниципальное образование ""Город Псков"", Ольгинская набережная, д.13/2"		0101000020E6100000529E7939EC523C40B8567BD80BE94C40
74581	3	32	\N	4697	58440	\N	57.825116999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Н.Васильева, д.79"		0101000020E6100000058C2E6F0E673C40D32F116F9DE94C40
74599	3	32	\N	4697	58451	\N	57.812558000000003	"Псковская область, Муниципальное образование ""Город Псков"", ул.Народная, д.20"		0101000020E6100000B9A7AB3B164F3C40350D8AE601E84C40
74620	3	32	\N	4697	58460	\N	57.827843999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Набат, д.5"		0101000020E61000001346B3B27D543C404C18CDCAF6E94C40
74594	3	32	\N	4697	58447	\N	57.812826000000001	"Псковская область, Муниципальное образование ""Город Псков"", ул.М.Горького, д.28"		0101000020E610000093FC885FB1523C4054ABAFAE0AE84C40
74593	3	32	\N	4697	58447	\N	57.808529999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.М.Горького, д.61"		0101000020E6100000226DE34F54523C40DDEA39E97DE74C40
74579	3	32	\N	4697	58439	\N	57.813229	"Псковская область, Муниципальное образование ""Город Псков"", ул.Л.Толстого, д.18"		0101000020E610000023D8B8FE5D5B3C4053944BE317E84C40
74578	3	32	\N	4697	58439	\N	57.814672000000002	"Псковская область, Муниципальное образование ""Город Псков"", ул.Л.Толстого, д.4"		0101000020E61000003DB665C0595A3C40C47B0E2C47E84C40
74619	3	32	\N	4697	58452	\N	57.829521	"Псковская область, Муниципальное образование ""Город Псков"", ул.Л.Поземского, д.65"		0101000020E6100000DB17D00B77523C40302C7FBE2DEA4C40
74803	3	32	\N	59077	\N	\N	57.345852999999998	деревня Нефедино, помещение Нефедкинского медпункта		0101000020E610000067B96C74CE6B3D409B1C3EE944AC4C40
74618	3	32	\N	4697	58452	\N	57.840018999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.Л.Поземского, д.124"		0101000020E6100000B83EAC376A4D3C4062821ABE85EB4C40
74585	3	32	\N	4697	1791	\N	57.760759999999998	"Псковская область, Муниципальное образование ""Город Псков"", Ленинградское ш, д.49"	Россия, Псковская область, Псков, Ленинградское шоссе, 49	0101000020E610000077F4BF5C8B623C406F0D6C9560E14C40
74584	3	32	\N	4697	1791	\N	57.795509000000003	"Псковская область, Муниципальное образование ""Город Псков"", Ленинградское ш, д.24"	Россия, Псковская область, Псков, Ленинградское шоссе, 24	0101000020E610000052D66F26A66B3C403B56293DD3E54C40
74566	3	32	\N	4697	58417	\N	57.817775524897897	"Псковская область, Муниципальное образование ""Город Псков"", ул.Ленина, д.10"	Россия, Псковская область, Псков, улица Ленина, 8	0101000020E6100000B3CF639467563C4013BA4BE2ACE84C40
74565	3	32	\N	4697	58417	\N	57.819234360599701	"Псковская область, Муниципальное образование ""Город Псков"", ул.Ленина, д.2"	Россия, А-212 шоссе	0101000020E61000003A57941282553C40B9E2E2A8DCE84C40
74569	3	32	\N	4697	58472	\N	57.806454000000002	"Псковская область, Муниципальное образование ""Город Псков"", ул.Кузнецкая, д.13"		0101000020E610000084674293C4563C403CDD79E239E74C40
74595	3	32	\N	4697	58441	\N	57.814303000000002	"Псковская область, Муниципальное образование ""Город Псков"", ул.Красноармейская, д.1"	Россия, Псковская область, Псков, улица Красноармейская, 1	0101000020E61000003A4030478F533C407104A9143BE84C40
74597	3	32	\N	4697	58450	\N	57.816661000000003	"Псковская область, Муниципальное образование ""Город Псков"", ул.Конная, д.6"		0101000020E61000000589EDEE01523C409775FF5888E84C40
74615	3	32	\N	4697	58431	\N	57.819650227057103	"Псковская область, Муниципальное образование ""Город Псков"", ул.Киселева, д.8"	Россия, Псковская область, Псков, улица Киселёва, 12	0101000020E61000002C80290307503C404D158C4AEAE84C40
74586	3	32	\N	4697	58442	\N	57.753979999999999	"Псковская область, Муниципальное образование ""Город Псков"", ул.Карбышева, д.4"		0101000020E6100000116E32AA0C673C4046EBA86A82E04C40
74568	3	32	\N	4697	58422	\N	57.809726531608	"Псковская область, Муниципальное образование ""Город Псков"", ул.Калинина, д.5"	Россия, Псковская область, Псков, улица Калинина	0101000020E6100000629F008A91553C4017D86322A5E74C40
74631	3	32	\N	4697	58454	\N	57.825226999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.Инженерная, д.16А"		0101000020E6100000C7B8E2E2A85C3C405A63D009A1E94C40
74628	3	32	\N	4697	58454	\N	57.835717000000002	"Псковская область, Муниципальное образование ""Город Псков"", ул.Инжененерная, д.90А"		0101000020E6100000ABB4C5353E5B3C400ADB4FC6F8EA4C40
74633	3	32	\N	4697	58456	\N	57.823008000000002	"Псковская область, Муниципальное образование ""Город Псков"", ул.Индустриальная, д.1А"		0101000020E6100000615111A7935C3C40562C7E5358E94C40
74580	3	32	\N	4697	1738	\N	57.812778000000002	"Псковская область, Муниципальное образование ""Город Псков"", Зональное ш, д.11"	Россия, Псковская область, Псков, Зональное шоссе, 11	0101000020E6100000D993C0E61C643C404374081C09E84C40
74624	3	32	\N	4697	58449	\N	57.838869000000003	"Псковская область, Муниципальное образование ""Город Псков"", ул.Звездная, д.12"		0101000020E610000049A0C1A6CE573C406A50340F60EB4C40
74609	3	32	\N	4697	58458	\N	57.815376999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.Западная, д.5"		0101000020E6100000807EDFBF79493C408E7406465EE84C40
74607	3	32	\N	4697	58458	\N	57.81879	"Псковская область, Муниципальное образование ""Город Псков"", ул.Западная, д.19"		0101000020E6100000D192C7D3F2473C405B25581CCEE84C40
74605	3	32	\N	4697	58457	\N	57.817740000000001	"Псковская область, Муниципальное образование ""Город Псков"", ул.Байкова, д.6"		0101000020E610000083177D0569463C40C6504EB4ABE84C40
74629	3	32	\N	4697	58459	\N	57.830891000000001	"Псковская область, Муниципальное образование ""Город Псков"", ул.Алтаева, д.2"		0101000020E6100000AD510FD1E85A3C4037C5E3A25AEA4C40
74617	3	32	\N	4697	58448	\N	57.838352	"Псковская область, Муниципальное образование ""Город Псков"", ул.Алехина, д.20"		0101000020E61000000B0DC4B2994B3C40A2444B1E4FEB4C40
74572	3	32	\N	4697	58342	\N	57.819268999999998	"Псковская область, Муниципальное образование ""Город Псков"", ул.23 июля, д.9"		0101000020E61000006E313F3734553C4035D07CCEDDE84C40
74589	3	32	\N	4697	58429	\N	57.796695322070597	"Псковская область, Муниципальное образование ""Город Псков"", ул.1-я Поселочная, д.15"	Россия, Псковская область, Псков, улица 1-я Посёлочная	0101000020E6100000E3E2A8DC44593C4080F10C1AFAE54C40
75079	3	32	\N	57388	58421	\N	57.766692911031797	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование городское поселение ""Порхов"", Ленина, 5"	Россия, Псковская область, Порховский район, Порхов	0101000020E61000007F129F3BC18E3D403B8908FF22E24C40
75076	3	32	\N	57388	58421	\N	57.766532375747801	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование городское поселение ""Порхов"", Ленина, 32-А"		0101000020E6100000CFA2772AE08E3D4032AB77B81DE24C40
74674	3	32	\N	57376	58526	\N	57.811022999999999	г.Печоры, Свободы, 34		0101000020E610000058535914769D3B40E3A6069ACFE74C40
74587	3	32	\N	57376	58369	\N	57.811022999999999	г.Печоры, Вокзальная, 11		0101000020E610000058535914769D3B40E3A6069ACFE74C40
74786	3	32	\N	57384	58401	\N	57.348343999999997	город Остров, ул.25 Октября, д.23		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74899	3	32	\N	57391	58505	\N	56.707324369157398	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Пролетарская, 56"		0101000020E6100000ED80EB8A19A93C4084D6C397895A4C40
74836	3	32	\N	57378	58381	\N	57.030552999999998	Псковская область, Новоржевский район, город Новоржев, Германа, 65		0101000020E610000038143E5B07573D40B8E52329E9834C40
75140	3	32	\N	57377	58374	\N	56.015391949274402	г.Невель, ул.Ленина, д.5 А	Россия, Р-28 шоссе	0101000020E610000079EBFCDB65EB3D405D4F745DF8014C40
74747	3	32	\N	57375	58366	\N	57.825178999999999	г.Дно, Петрова, 55		0101000020E610000088F6B182DFF63D40492C29779FE94C40
74639	3	32	\N	4310	1154	\N	57.818722999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Парковая, д.4"	Россия, Псковская область, деревня Голубово, улица Парковая, 4	0101000020E61000009510ACAA975B3C40D3BD4EEACBE84C40
74698	3	32	\N	4310	58561	\N	57.844832253966601	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Писковичская волость"", д.Голубово, Парковая, д.11"	Россия, Псковская область, деревня Голубово	0101000020E610000036221807976A3C40A04E797423EC4C40
75051	3	32	\N	57400	58497	\N	58.740941999999997	г.Гдов, пер.Школьный		0101000020E6100000C47C7901F6D13B40CD1DFD2FD75E4D40
74670	3	32	\N	9096	58339	\N	56.340681499693197	"Псковская область, Муниципальное образование ""Город Великие Луки"", пр.Гагарина, д.81"	Россия, Псковская область, Великие Луки	0101000020E6100000520C9068028D3E402DAF5C6F9B2B4C40
74659	3	32	\N	9096	58339	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", пр.Гагарина, д.9 корп.2"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74656	3	32	\N	9096	58339	\N	56.344516165802297	"Псковская область, Муниципальное образование ""Город Великие Луки"", пр.Гагарина, д.5"	Россия, Псковская область, Великие Луки	0101000020E6100000876F61DD78873E407079AC19192C4C40
74677	3	32	\N	9096	58399	\N	56.343825007650601	Псковская область, Муниципальное образование "Город Великие Луки", МОУ СОШ №6, пр. Гагарина, д 128	Россия, Псковская область, Великие Луки	0101000020E61000003C122F4FE7923E400B462575022C4C40
74676	3	32	\N	9096	58399	\N	56.343229171565497	"Псковская область, Муниципальное образование ""Город Великие Луки"", пр. Гагарина, д.128"	Россия, Псковская область, Великие Луки	0101000020E610000019028063CF923E40F70489EDEE2B4C40
74642	3	32	\N	9096	58398	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", пл.Юбилейная, д.4"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74661	3	32	\N	9096	58327	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", пл.Калинина, д.6а"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74660	3	32	\N	9096	58327	\N	56.339561232621499	"Псковская область, Муниципальное образование ""Город Великие Луки"", пл. Калинина, д.6а"	Россия, Псковская область, Великие Луки	0101000020E6100000D0D1AA9674883E40A0FF1EBC762B4C40
74647	3	32	\N	9096	58344	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", пер.Некрасова, д.7"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74651	3	32	\N	9096	58462	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", пер.Некрасова, д.10"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74636	3	32	\N	9096	58334	\N	56.341726999999999	Псковская область, г. Великие Луки, Строительный коледж, наб.Новослоболдская, д.24		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
94995	3	32	\N	9096	58418	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", СОШ№1, ул. Юбилейная, д.2"	Россия, Псковская область, Великие Луки	0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74668	3	32	\N	9096	58360	\N	56.330520462464101	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Щорса, д.90"	Россия, Псковская область, Великие Луки	0101000020E610000003D0285DFA8B3E404356B77A4E2A4C40
74665	3	32	\N	9096	58360	\N	56.344301669790397	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Щорса, д.59"	Россия, Псковская область, Великие Луки	0101000020E6100000274BADF71B893E4044F98216122C4C40
74663	3	32	\N	9096	58329	\N	56.321823161054603	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Фурманова, д.67"	Россия, Псковская область, Великие Луки	0101000020E6100000C8B7770DFA8A3E40E10CFE7E31294C40
74644	3	32	\N	9096	58324	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Третьей Ударной Армии, д.69 корп.1"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74648	3	32	\N	9096	58371	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Половская, д.3"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74655	3	32	\N	9096	58435	\N	56.3424420019102	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Первомайская, д.16/2"	Россия, Псковская область, Великие Луки	0101000020E610000012D89C83678A3E406F63B323D52B4C40
74638	3	32	\N	9096	58363	\N	56.347256189942399	Псковская область, Муниципальное образование "Город Великие Луки", МОУ "Кадетская школа" ул.Парковая, д 2	Россия, Псковская область, Великие Луки	0101000020E610000034D769A4A5863E407EAB75E2722C4C40
74657	3	32	\N	9096	58446	\N	56.327518910384001	Псковская область, Муниципальное образование "Город Великие Луки", пр.Октябрьский, д.28/13	Россия, Р-51 шоссе	0101000020E6100000C9E88024EC833E40C9E88024EC294C40
74653	3	32	\N	9096	58446	\N	56.345438466234199	"Псковская область, Муниципальное образование ""Город Великие Луки"", пр.Октябрьский, д.50"	Россия, Псковская область, Великие Луки	0101000020E610000038F92D3A59963E40D865F84F372C4C40
74640	3	32	\N	9096	58508	\N	56.341965968160103	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Новосокольническая, д.1"	Россия, Псковская область, Великие Луки	0101000020E6100000917F66101F843E40062CB98AC52B4C40
74827	3	32	543	18248	58491	\N	57.068232000000002	Псковская область, Бежаницкий район, поселок Красный Луч, Советская, 26		0101000020E6100000F25F200890153E40354580D3BB884C40
74664	3	32	\N	9096	58359	\N	56.338557492830901	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Малышева, д.13"	Россия, Псковская область, Великие Луки	0101000020E61000009207228B34953E407B6AF5D5552B4C40
74667	3	32	\N	9096	58362	\N	56.347638137317396	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.М.Кузьмина, д.20"	Россия, Псковская область, Великие Луки	0101000020E6100000978DCEF9298A3E40666CE8667F2C4C40
74649	3	32	\N	9096	58464	\N	56.343825007650601	"Псковская область, Муниципальное образование ""Город Великие Луки"", пл.Ленина, д.3"	Россия, Псковская область, Великие Луки	0101000020E61000002ECBD765F8833E400B462575022C4C40
74658	3	32	\N	9096	58328	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.К.Зверева, д.29"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74654	3	32	\N	9096	58328	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.К.Зверева, д.24/27"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74637	3	32	\N	9096	58453	\N	56.341346268115203	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Зеленая, д.7"	Россия, Псковская область, Великие Луки	0101000020E610000003931B45D67E3E406A4FC939B12B4C40
74669	3	32	\N	9096	58326	\N	56.341726999999999	Псковская область, Муниципальное образование "Город Великие Луки", Детский сад  № 16 «Березка», улица Заслонова, дом 42а		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74662	3	32	\N	9096	58326	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Заслонова, д.42а"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74672	3	32	\N	9096	58419	\N	56.334099794496503	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Дружбы, д.23 корп.2"	Россия, Псковская область, Великие Луки	0101000020E6100000CBDAA6785C8C3E40FBCBEEC9C32A4C40
74671	3	32	\N	9096	58419	\N	56.338294637970797	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Дружбы, д.33/20"	Россия, Псковская область, Великие Луки	0101000020E61000009432A9A10D883E403EB324404D2B4C40
74646	3	32	\N	9096	58396	\N	56.340583546492198	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Горная, д.3"	Россия, Псковская область, Великие Луки	0101000020E61000007B13437232893E403BC5AA41982B4C40
74675	3	32	\N	9096	58372	\N	56.341726999999999	Псковская область, Муниципальное образование "Город Великие Луки",ГОУ НПО ПЛ №8 ул. Глинки, д.38		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74673	3	32	\N	9096	58372	\N	56.353380941466	Псковская область, Муниципальное образование "Город Великие Луки", ГОУ НПО ПЛ №5 ул. Глинки	Россия, Псковская область, Великие Луки	0101000020E610000041BCAE5FB0933E408E03AF963B2D4C40
74645	3	32	\N	9096	58394	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Гастелло, д.8"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74666	3	32	\N	9096	58397	\N	56.342394985347198	"Псковская область, Муниципальное образование ""Город Великие Луки"", пр.Гагарина, д.61"	Россия, Псковская область, Великие Луки	0101000020E610000056444DF4F98C3E402FA86F99D32B4C40
74652	3	32	\N	9096	58356	\N	56.341726999999999	"Псковская область, Муниципальное образование ""Город Великие Луки"", ул.Витебская, д.2"		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
74641	3	32	\N	9096	58370	\N	56.341726999999999	Псковская область, Муниципальное образование "Город Великие Луки", ВГСХА, ул.Винатовского, д.10/2		0101000020E6100000D8666325E6893E408194D8B5BD2B4C40
75173	3	32	423	49092	\N	\N	55.657499000000001	д. Шершни, Бывшее здание администрации с/п		0101000020E6100000107A36AB3EBF3E408C135FED28D44B40
75165	3	32	423	48960	\N	\N	55.827489	д. Чурилово, Здание библиотеки	Россия, Псковская область, Усвятский район, село Чурилово	0101000020E610000022FDF675E0783E405E66D828EBE94B40
75169	3	32	423	49022	\N	\N	55.895004999999998	д. Церковище, Здание администрации с/п	Россия, Псковская область, Усвятский район, село Церковище	0101000020E6100000E8667FA0DCDA3E40D4601A868FF24B40
75163	3	32	423	2271	58411	\N	55.742747000000001	п. Усвяты, Карла Маркса, 17		0101000020E6100000CEFC6A0E10C43E40DF196D5512DF4B40
75164	3	32	423	2271	58536	\N	55.742747000000001	п. Усвяты, 25 Октября, 77		0101000020E6100000CEFC6A0E10C43E40DF196D5512DF4B40
75166	3	32	423	40409	\N	\N	55.774765000000002	д. Узкое, Здание сельского клуба	Россия, Псковская область, Усвятский район, село Узкое	0101000020E61000001F2C6343378F3E40F08AE07F2BE34B40
75167	3	32	423	2504	\N	\N	55.746339999999996	д. Удвяты, Здание дома культуры	Россия, Псковская область, Усвятский район, село Удвяты	0101000020E61000001EDE736039DE3E402BD9B11188DF4B40
75171	3	32	423	2725	\N	\N	55.913722	д. Стеревнево, Здание администрации с/п	Россия, Псковская область, Усвятский район, село Стеревнево	0101000020E6100000C4D155BABBA23E405FD1ADD7F4F44B40
75172	3	32	423	2800	\N	\N	55.830897	д. Северики, Здание дома культуры	Россия, Псковская область, Усвятский район, село Северики	0101000020E6100000C1C93670079A3E4019AC38D55AEA4B40
74804	3	32	423	46455	\N	\N	55.864328	деревня Алексеевка, помещение медпункта д.Алексеевка	Россия, Псковская область, Усвятский район, село Алексеевка	0101000020E61000002BDCF291946C3E403082C64CA2EE4B40
75168	3	32	423	49008	\N	\N	55.942140999999999	д. Адамово, Здание медпункта	Россия, Псковская область, Усвятский район, село Адамово	0101000020E6100000E6779ACC78E33E40419C871398F84B40
75043	3	32	1837	28613	58547	\N	58.0455523577224	деревня Цапелька, Новосельская, 16	Россия, Псковская область, Стругокрасненский район, село Цапелька	0101000020E6100000EAD0E97937F23C403A22DFA5D4054D40
75047	3	32	1837	28831	58538	\N	58.113936000000002	деревня Хредино, Заречная, 10		0101000020E6100000535A7F4B006A3D4025EB7074950E4D40
75028	3	32	1837	57389	58558	\N	58.273899065717302	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование городское поселение ""Струги Красные"", Сосновая, 1А"	Россия, Псковская область, Стругокрасненский район, поселок Струги-Красные	0101000020E610000046088F368E1C3D401CB4571F0F234D40
75030	3	32	1837	57389	58426	\N	58.270281362585202	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование городское поселение ""Струги Красные"", Советская, 14"	Россия, Псковская область, Стругокрасненский район, поселок Струги-Красные	0101000020E6100000C03E3A75E51B3D4076DD5B9198224D40
75029	3	32	1837	57389	58424	\N	58.266437146681497	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование городское поселение ""Струги Красные"", Мира, 8А"	Россия, Псковская область, Стругокрасненский район, поселок Струги-Красные	0101000020E6100000B1BFEC9E3C1C3D40E1B88C9B1A224D40
75032	3	32	1837	57389	58495	\N	58.272271145197202	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование городское поселение ""Струги Красные"", Жертв Революции, 7А"	Россия, Псковская область, Стругокрасненский район, поселок Струги-Красные	0101000020E6100000E25817B7D11C3D401A53B0C6D9224D40
75039	3	32	1837	28459	58535	\N	58.430117000000003	деревня Сиковицы, Центральная, 7		0101000020E610000069A7E67283B13C40113AE8120E374D40
75044	3	32	1837	28679	\N	\N	58.010426000000002	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование сельское поселение ""Цапельская волость"", деревня Ротный Двор"	Россия, Псковская область, Стругокрасненский район, село Ротный Двор	0101000020E610000030F31DFCC4D93C409983A0A355014D40
75036	3	32	1837	57438	58550	\N	58.341866343102303	деревня Ровное, Народная, 20-а	Россия, Псковская область, Стругокрасненский район, село Ровное	0101000020E61000008BE255D636CD3C40A3CEDC43C22B4D40
75037	3	32	1837	46524	58556	\N	58.375388272075	деревня Пятчино, Владимира Ислентьева, 6	Россия, Псковская область, Стругокрасненский район, село Пятчино	0101000020E61000003FC91D3691393D40CAA7C7B60C304D40
74811	3	32	1837	46620	\N	\N	58.478693999999997	"деревня Погорелка, помещение конторы СПК ""Правда"""	Россия, Псковская область, Стругокрасненский район, село Погорелка	0101000020E61000001C7920B248BF3C404D6551D8453D4D40
75064	3	32	1837	46594	\N	\N	58.105007000000001	деревня Новоселье, здание Новосельского сельского клуба	Россия, Псковская область, Стругокрасненский район, село Новоселье	0101000020E6100000D120054F21DF3C40F06C8FDE700D4D40
75040	3	32	1837	46594	58502	\N	58.105007000000001	село Новоселье, Евстафьева, 1		0101000020E6100000D120054F21DF3C40F06C8FDE700D4D40
74951	3	32	1837	49214	58565	\N	58.021619999999999	деревня Молоди, Молодейская, дом 51		0101000020E610000075594C6C3EB63C404278B471C4024D40
75046	3	32	1837	28779	58542	\N	58.222250000000003	деревня Лудони, Школьная, 3		0101000020E61000001F9F909DB7593D409CC420B0721C4D40
75045	3	32	1837	28714	\N	\N	58.089990999999998	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование сельское поселение ""Цапельская волость"", деревня Катежно"	Россия, Псковская область, Стругокрасненский район, село Катежно	0101000020E61000004948A46DFC0D3D4098F738D3840B4D40
75041	3	32	1837	46615	58567	\N	58.256912	деревня Заполье, Школьная, дом 2		0101000020E61000002BC3B81B44F33C4098F90E7EE2204D40
74758	3	32	1837	59091	\N	\N	58.148656449035897	"д. Заклинье, помещение МОУ ""Заклинская основная общеобразовательная школа"	Россия, Псковская область, Стругокрасненский район, село Заклинье	0101000020E6100000DB6B41EF8DDD3C40562DE92807134D40
74970	3	32	1837	40389	\N	\N	58.468862999999999	д. Загорье, здание Дома культуры	Россия, Псковская область, Стругокрасненский район, село Загорье	0101000020E6100000C2C2499A3FB63C40F8A6E9B3033C4D40
75038	3	32	1837	46556	58533	\N	58.400123000000001	деревня Ждани, Труда, 7		0101000020E6100000513239B533F43C404FB0FF3A37334D40
75119	3	32	72	57413	\N	\N	56.248668175825898	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"", деревня Чернея"	Россия, Псковская область, Себежский район, село Чернея	0101000020E6100000882B67EF8C8A3C40E7C75F5AD41F4C40
75111	3	32	72	31866	\N	\N	56.295140000000004	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", деревня Ульяновщина"	Россия, Псковская область, Себежский район, село Ульяновщина	0101000020E61000002F6B6281AF843C40E8DEC325C7254C40
75122	3	32	72	52753	\N	\N	56.450155000000002	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"",ь деревня Томсино"	Россия, Псковская область, Себежский район, село Томсино	0101000020E6100000F792C6681D893C40C190D5AD9E394C40
75112	3	32	72	31886	\N	\N	56.300330000000002	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", деревня Техомичи"	Россия, Псковская область, Себежский район, село Техомичи	0101000020E610000058FE7C5BB0743C40FC00A43671264C40
75132	3	32	72	453	\N	\N	56.235695999999997	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование сельское поселение ""Красная волость"", деревня Сутоки"	Россия, Псковская область, Себежский район, село Сутоки	0101000020E6100000F646AD307D1F3D4025E659492B1E4C40
75106	3	32	72	31561	58475	\N	56.286377999999999	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", город Себеж, пер.Почтовый, 7-а"		0101000020E61000005CAE7E6C927B3C409E25C808A8244C40
75107	3	32	72	31561	58483	\N	56.286377999999999	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", город Себеж, Ленинская, 51"		0101000020E61000005CAE7E6C927B3C409E25C808A8244C40
75105	3	32	72	31561	58498	\N	56.278322128219898	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", город Себеж, Красноармейская, 15"	Россия, Псковская область, Себежский район, Себеж	0101000020E6100000994528B6827A3C40F0E0270EA0234C40
75104	3	32	72	31561	57957	\N	56.286377999999999	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", город Себеж, 7-го Ноября, 21-а"		0101000020E61000005CAE7E6C927B3C409E25C808A8244C40
75118	3	32	72	52740	\N	\N	56.148463	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"", деревня Осыно"	Россия, Псковская область, Себежский район, село Осыно	0101000020E6100000232E008DD2AD3C4041D5E8D500134C40
75136	3	32	72	704	\N	\N	56.290365000000001	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование сельское поселение ""Мостищенская волость"", деревня Мостище"	Россия, Псковская область, Себежский район, село Мостище	0101000020E6100000EFAB72A1F2C33C40977329AE2A254C40
74687	3	32	72	51966	\N	\N	56.144537	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Карамышевская волость"", д.Лопатово, д.76"		0101000020E61000005DA3E5400F2D3D40EE073C3080124C40
75110	3	32	72	31813	\N	\N	56.310147999999998	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Себеж"", деревня Кузнецовка"	Россия, Псковская область, Себежский район, село Кузнецовка	0101000020E6100000209A79724D8D3C40BC75FEEDB2274C40
75121	3	32	72	57461	\N	\N	56.249647000000003	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"", деревня Кортеньки"		0101000020E610000034BDC458A6B33C40B345D26EF41F4C40
75135	3	32	72	632	\N	\N	56.408642	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование сельское поселение ""Максютинская волость"", деревня Кицково"	Россия, Псковская область, Себежский район, село Кицково	0101000020E61000008FC360FE0ACD3C40D2E28C614E344C40
75133	3	32	72	522	\N	\N	56.324246000000002	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование сельское поселение ""Красноармейская волость"", деревня Исаково"	Россия, Псковская область, Себежский район, село Исаково	0101000020E6100000B8C9A8328C0F3D40EEED96E480294C40
75130	3	32	72	191	\N	\N	56.332821000000003	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Идрица"", п.Идрица, Учебный городок"		0101000020E6100000AE122C0E67E23C400536E7E0992A4C40
75131	3	32	72	191	58471	\N	56.332821000000003	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Идрица"", п.Идрица, Островского, 1-а"		0101000020E6100000AE122C0E67E23C400536E7E0992A4C40
75129	3	32	72	191	58415	\N	56.332821000000003	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Идрица"", п.Идрица, Ленина, 18"		0101000020E6100000AE122C0E67E23C400536E7E0992A4C40
75128	3	32	72	191	58415	\N	56.332821000000003	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Идрица"", п.Идрица, Ленина, 28"		0101000020E6100000AE122C0E67E23C400536E7E0992A4C40
75116	3	32	72	52738	\N	\N	56.361533999999999	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Сосновый Бор"", деревня Заситино"	Россия, Псковская область, Себежский район, село Заситино	0101000020E6100000AAD55757053E3C402F3201BF462E4C40
75125	3	32	72	45659	\N	\N	56.389287367045199	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"", деревня Дубровка"	Россия, Псковская область, Себежский район, село Дубровка	0101000020E610000009DD257156A03C4005E10A28D4314C40
74766	3	32	72	45659	58572	\N	56.389432999999997	дер.Дубровка, Центральная, 27		0101000020E61000005F44DB3175A33C40D87DC7F0D8314C40
75117	3	32	72	4217	\N	\N	56.054707852141597	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"", деревня Долосцы"	Россия, Псковская область, Себежский район, село Долосцы	0101000020E61000006249B9FB1CB73C402F6AF7AB00074C40
75115	3	32	72	52735	\N	\N	56.243605000000002	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Сосновый Бор"", деревня Дедино"	Россия, Псковская область, Себежский район, село Дедино	0101000020E61000009757AEB7CD403C403012DA722E1F4C40
75120	3	32	72	52750	\N	\N	56.186383999999997	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"", деревня Глембочино"		0101000020E61000001AA3755435613C40B33F506EDB174C40
75137	3	32	72	763	\N	\N	56.248601000000001	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование сельское поселение ""Мостищенская волость"", деревня Галузино"	Россия, Псковская область, Себежский район, село Галузино	0101000020E61000007898F6CDFDE93C405F605628D21F4C40
75126	3	32	72	87	\N	\N	56.140448999999997	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование сельское поселение ""Бояриновская волость"", деревня Бояриново"	Россия, Псковская область, Себежский район, село Бояриново	0101000020E6100000FBAF73D366E03C40C1E09A3BFA114C40
75146	3	32	72	48631	58513	\N	56.270006000000002	д.Борки, ул.Ленина, д.19		0101000020E6100000B285200725C83C40A5DC7D8E8F224C40
75123	3	32	72	52754	\N	\N	56.422016999999997	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование ""Себежское"", деревня Борисенки"		0101000020E6100000944BE3175E493C4092AD2EA704364C40
75127	3	32	72	107	\N	\N	56.102111999999998	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование сельское поселение ""Бояриновская волость"", деревня Александрово"	Россия, Псковская область, Себежский район, село Александрово	0101000020E6100000EFAB72A1F20F3D40BB438A01120D4C40
74872	3	32	735	57462	\N	\N	57.1037484043297	д.Скорды,административное здание с/п "Носовская волость"	Россия, Псковская область, Пыталовский район	0101000020E6100000E08618AF79CD3B4041834D9D478D4C40
74868	3	32	735	20448	\N	\N	57.123353000000002	"д.Стехны, Административное здание с/п ""Утроинская волость"""		0101000020E610000076C1E09A3B063C40876EF607CA8F4C40
74864	3	32	735	20212	\N	\N	56.899890999999997	д.Скангали, Здание Заутроинского дома культуры	Россия, Псковская область, Пыталовский район, село Скангали	0101000020E610000074D4D17135BE3B407C7BD7A02F734C40
74869	3	32	735	19855	58469	\N	57.063838826328002	г.Пыталово, ул.Пушкинская, д.6	Россия, Псковская область, Пыталовский район, Пыталово	0101000020E61000001C98DC28B2EA3B40CC9A58E02B884C40
74874	3	32	735	47844	\N	\N	57.316347	"д.Мирный, Административное здание с/п  ""Линовская волость"""		0101000020E61000008DF0F62004F83B400798F90E7EA84C40
74873	3	32	735	52307	\N	\N	57.252786	д.Линово, Помещение Линовской библиотеки	Россия, Псковская область, Пыталовский район, село Линово	0101000020E6100000E0826C59BEFA3B407E71A94A5BA04C40
74802	3	32	735	46431	\N	\N	57.118408000000002	деревня Карпово, помещение сельского Дома культуры д.Карпово	Россия, Псковская область, Пыталовский район, село Карпово	0101000020E6100000D1031F8315CF3B40DACA4BFE278F4C40
74866	3	32	735	20333	\N	\N	57.003647000000001	"д.Емилово, административное здание с/п ""Гавровская волость"""		0101000020E61000004C8DD0CFD4FB3B4040DD408177804C40
74862	3	32	735	20103	\N	\N	57.036597	"д.Вышгородок, Здание администрации с/п ""Вышгородская волость"""	Россия, Псковская область, Пыталовский район, село Вышгородок	0101000020E61000008E075BECF6013C40DC10E335AF844C40
74867	3	32	735	20413	\N	\N	57.007804	"д.Бороусы, Здание администрации с/п ""Скадинская волость"""	Россия, Псковская область, Пыталовский район, село Бороусы	0101000020E6100000A29BFD81721B3C409563B2B8FF804C40
74870	3	32	735	20582	\N	\N	57.003343000000001	"п.Белорусский, Здание администрации сельского поселения ""Тулинская волость"""	Россия, Псковская область, Пыталовский район, село Белорусский	0101000020E6100000B9A7AB3B16D73B40D4D51D8B6D804C40
74764	3	32	1618	45615	58529	\N	56.915750000000003	дер.Сорокино, Лесная, 1		0101000020E61000002F6EA301BCA53C40F0A7C64B37754C40
74882	3	32	1618	20226	58540	\N	57.021182000000003	р.п. Пушкинские Горы, ул. Совхозный переулок, д.13		0101000020E6100000BE874B8E3BE93C40C7A17E17B6824C40
74878	3	32	1618	20226	58474	\N	57.021182000000003	р.п. Пушкинские Горы, ул. Садовая, д.1		0101000020E6100000BE874B8E3BE93C40C7A17E17B6824C40
74865	3	32	1618	20226	58482	\N	57.021182000000003	р.п. Пушкинские Горы, ул. Пушкинская, д.42		0101000020E6100000BE874B8E3BE93C40C7A17E17B6824C40
74876	3	32	1618	20226	58480	\N	57.0214884006473	р.п. Пушкинские Горы, ул. Новоржевская, д.23	Россия, Псковская область, Пушкиногорский район, поселок Пушкинские Горы	0101000020E610000003ECA35357EE3C40D3A0681EC0824C40
74877	3	32	1618	20226	58466	\N	57.021182000000003	р.п. Пушкинские Горы, ул. Лермонтова, д.13		0101000020E6100000BE874B8E3BE93C40C7A17E17B6824C40
74875	3	32	1618	20226	58467	\N	57.021182000000003	р.п. Пушкинские Горы, ул. Ленина, д.5		0101000020E6100000BE874B8E3BE93C40C7A17E17B6824C40
74879	3	32	1618	20226	58504	\N	57.021182000000003	р.п. Пушкинские Горы, ул. Больничный городок, д.14		0101000020E6100000BE874B8E3BE93C40C7A17E17B6824C40
74885	3	32	1618	21337	58524	\N	56.881408999999998	д. Поляне, ул. Советская, д.7		0101000020E6100000713D0AD7A3E43C4035B39602D2704C40
74883	3	32	1618	21210	\N	\N	56.987850000000002	д. Подкрестье, д.14		0101000020E6100000EBFEB1101DDE3C4043AD69DE717E4C40
74871	3	32	1618	47780	\N	\N	57.072448999999999	"д.Носово, Здание администрации сельского поселения ""Носовская волость"""	Россия, Псковская область, Пушкиногорский район, село Носово	0101000020E6100000143DF03158E13C405FD0420246894C40
74881	3	32	1618	21134	\N	\N	57.045597999999998	"д. Козляки, административное здание ОАО ""Белогуль"""		0101000020E610000029CDE67118F83C40AA61BF27D6854C40
74886	3	32	1618	48069	58551	\N	56.915053	д. Исса, ул. Центральная, д.2		0101000020E61000007619FED30DAC3C40A88DEA7420754C40
74884	3	32	1618	21291	\N	\N	56.942632000000003	д. Горелик, д.85		0101000020E610000034D93F4F03E63C40E014562AA8784C40
74963	3	32	1618	49365	\N	\N	56.882387999999999	"д. Богданово, здание правления ООО ""Экосельхозинвест-4"""	Россия, Псковская область, Пушкиногорский район, село Богданово	0101000020E61000006C5D6A847EEE3C4001310917F2704C40
74880	3	32	1618	21089	\N	\N	57.08399	"д. Блажи, здание МОУ ""Зарецкая средняя общеобразовательная школа"""	Россия, Псковская область, Пушкиногорский район, село Блажи	0101000020E610000009185DDE1CE23C4074982F2FC08A4C40
74921	3	32	515	52895	\N	\N	56.417659999999998	Пустошкинский район.д.Яссы. Помещение библиотеки.	Россия, Псковская область, Пустошкинский район, село Яссы	0101000020E61000008C67D0D03F3D3D40766C04E275354C40
74933	3	32	515	23534	\N	\N	56.585230000000003	д.Щукино, Пустошкинский район, здание администрации сельского поселения.	Россия, Псковская область, Пустошкинский район, село Щукино	0101000020E61000005531957EC2493D40AD510FD1E84A4C40
74924	3	32	515	3933	\N	\N	56.137560000000001	Пустошкинский район, д.Шалахово,здание администрации.	Россия, Псковская область, Пустошкинский район, село Шалахово	0101000020E61000007347FFCBB54C3D406F9EEA909B114C40
74928	3	32	515	23310	\N	\N	56.514619000000003	Пустошкинский район, д.Чурилово,здание администрации сельского поселения.	Россия, Псковская область, Пустошкинский район, село Чурилово	0101000020E6100000E5B512BA4BAA3D403B730F09DF414C40
75027	3	32	515	46303	\N	\N	56.544226999999999	деревня Сопки, здание Сопкинской сельской библиотеки	Россия, Псковская область, Пустошкинский район, село Сопки	0101000020E6100000073F7100FD9E3D40D34CF73AA9454C40
74930	3	32	515	23381	\N	\N	56.345823000000003	д.Соино.Пустошкинский район.Сельский Дом  культуры.		0101000020E6100000BC0853944B433D40319A95ED432C4C40
74932	3	32	515	3481	\N	\N	56.249752000000001	д.Сергейцево, Пустошкинский район, Администрация сельского поселения .	Россия, Псковская область, Пустошкинский район, село Сергейцево	0101000020E6100000622D3E05C0483D40280EA0DFF71F4C40
74927	3	32	515	23227	\N	\N	56.318491000000002	д.Ребле. Пустошкинский район, помещение бывшей библиотеки.	Россия, Псковская область, Пустошкинский район, село Ребле	0101000020E61000003A3FC571E0A13D4001892650C4284C40
74917	3	32	515	5169	58407	\N	56.334612	Пустошка.ул.Октябрьская д.55		0101000020E610000030B95164AD5D3D40B16CE690D42A4C40
74919	3	32	515	5169	58509	\N	56.334612	г.Пустошка, ул.Октябрьская д.34а, МОУ ДО «Детско-юношеская спортивная школа»		0101000020E610000030B95164AD5D3D40B16CE690D42A4C40
74922	3	32	515	23027	\N	\N	56.445816999999998	д.Поддубье.Пустошкинский район, помещение сельского Дома Культуры	Россия, Псковская область, Пустошкинский район, село Поддубье	0101000020E610000070404B57B0513D401B800D8810394C40
75066	3	32	515	29680	\N	\N	56.206702	деревня Ореховно, Здание Ореховенской библиотеки-филлиала	Россия, Псковская область, Пустошкинский район, село Ореховно	0101000020E61000007DAF21382E833D4047020D36751A4C40
74935	3	32	515	3154	\N	\N	56.511505	д.Криуха, Пустошкинский район, здание администрации сельского поселения.	Россия, Псковская область, Пустошкинский район, село Криуха	0101000020E610000004711E4E606A3D40C85EEFFE78414C40
74934	3	32	515	23598	\N	\N	56.586519000000003	д.Красное, Пустошкинский район, здание школы.	Россия, Псковская область, Пустошкинский район, село Красное	0101000020E6100000BDAB1E300F593D40C7BDF90D134B4C40
74931	3	32	515	3423	\N	\N	56.402386	д.Копылок.Пустошкинский район, здание Дома культуры.	Россия, Псковская область, Пустошкинский район, село Копылок	0101000020E61000006B10E6762F773D40232F6B6281334C40
74925	3	32	515	3990	\N	\N	56.352108000000001	Пустошкинский район, д.Забелевица.здание администрации.		0101000020E61000004C33DDEBA49A3D407A54FCDF112D4C40
74929	3	32	515	23352	\N	\N	56.327205999999997	д.Долосцы Пустошкинский район, здание администрации сельского поселения.	Россия, Псковская область, Пустошкинский район, село Долосцы	0101000020E6100000C5724BAB21553D400987DEE2E1294C40
74923	3	32	515	23061	\N	\N	56.236066000000001	д.Гультяи	Россия, Псковская область, Пустошкинский район, село Гультяи	0101000020E61000002AC76471FF793D4049D92269371E4C40
74926	3	32	515	4032	\N	\N	56.405071	д.Алушково.Пустошкинский район, здание бывшего сельского клуба.	Россия, Псковская область, Пустошкинский район, село Алушково	0101000020E610000077F700DD979F3D406DC7D45DD9334C40
74920	3	32	515	22915	\N	\N	56.454293999999997	д.Алоль.Пустошкинский район.Здание администрации.		0101000020E6100000880D164ED21C3D406F62484E263A4C40
75162	3	32	1171	45724	\N	\N	57.774239999999999	д.Чернецово, помещение сельского клуба, д.95		0101000020E6100000CB0F5CE509303C40A5A0DB4B1AE34C40
74770	3	32	1171	45724	\N	\N	57.774239999999999	дер.Чернецово, Административный центр, 4		0101000020E6100000CB0F5CE509303C40A5A0DB4B1AE34C40
75058	3	32	1171	46965	\N	\N	57.972524999999997	с.Чернево	Россия, Псковская область, Псковский район, село Чернево	0101000020E610000098689082A7343C406DC5FEB27BFC4C40
74715	3	32	1171	57386	\N	\N	57.747520000000002	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Ядровская волость"", д.Череха, Здание Администрации с/п ""Ядровская волость"""		0101000020E6100000B68311FB04603C408F8D40BCAEDF4C40
74711	3	32	1171	52044	58380	\N	57.743687000000001	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Тямшанская волость"", д.Тямша, Солнечная, д.1"		0101000020E610000059DDEA39E9253C40EDBAB72231DF4C40
74710	3	32	1171	52044	58377	\N	57.743687000000001	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Тямшанская волость"", д.Тямша, Молодежная, д.2"		0101000020E610000059DDEA39E9253C40EDBAB72231DF4C40
74962	3	32	601	49351	\N	\N	58.054774000000002	д. Иваньково, здание Дома культуры	Россия, Псковская область, Порховский район, село Иваньково	0101000020E6100000D942908312A23D40E7559DD502074D40
74707	3	32	1171	52036	\N	\N	57.934615999999998	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Торошинская волость"", д.Торошино, Здание сельского дома культуры"	Россия, Псковская область, Псковский район, село Торошино	0101000020E6100000A06B5F402F983C40BF28417FA1F74C40
74706	3	32	1171	57430	\N	\N	57.978251999999998	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Середкинская волость"", д.Теребище, Здание Администрации с/п ""Середкинская волость"""	Россия, Псковская область, Псковский район, село Теребище	0101000020E6100000096EA46C91443C40909F8D5C37FD4C40
74718	3	32	1171	52066	\N	\N	57.657133000000002	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Ядровская волость"", д.Стремутка, Здание Дома Культуры"	Россия, Псковская область, Псковский район, село Стремутка	0101000020E6100000630E828E56513C40AA0F24EF1CD44C40
74701	3	32	1171	52016	\N	\N	58.211199999999998	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Середкинская волость"", д.Спасовщина, Здание сельского клуба"	Россия, Псковская область, Псковский район, село Спасовщина	0101000020E61000002B33A5F5B7343C402575029A081B4D40
74717	3	32	1171	52063	\N	\N	57.684708999999998	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Ядровская волость"", д.Соловьи, Здание культурно-досугового центра"	Россия, Псковская область, Псковский район, село Соловьи	0101000020E61000006C770FD07D553C407023658BA4D74C40
74704	3	32	1171	52026	58470	\N	58.160167999999999	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Середкинская волость"", с.Середка, Родионова, д.10"		0101000020E6100000772CB649452F3C40D0EE906280144D40
74703	3	32	1171	52026	58330	\N	58.160167999999999	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Середкинская волость"", с.Середка, Пушкинская, д.42"		0101000020E6100000772CB649452F3C40D0EE906280144D40
74689	3	32	1171	57440	\N	\N	57.693120428392497	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Карамышевская волость"", д.Селихново, Здание Селихновской библиотеки"	Россия, Псковская область, Псковский район, село Селихново	0101000020E61000001286014BAEEA3C400D1AFA27B8D84C40
74680	3	32	1171	48560	58378	\N	57.829889999999999	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Завеличенская волость"", д.Родина, Юбилейная, д.3"		0101000020E61000002383DC4598423C4083A3E4D539EA4C40
74682	3	32	1171	48560	58382	\N	57.829889999999999	д. Родина, Владимирская, д.3 В		0101000020E61000002383DC4598423C4083A3E4D539EA4C40
74716	3	32	1171	52060	\N	\N	57.714320999999998	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Ядровская волость"", д.Похвальщина, Здание правления СХПК колхоза ""Передовик"""	Россия, Псковская область, Псковский район, село Похвальщина	0101000020E6100000603DEE5BAD733C404AECDADE6EDB4C40
74709	3	32	1171	57432	\N	\N	57.8487175430935	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Торошинская волость"", д.Подборовье-3, Здание фельдшерско-акушерского пункта"	Россия, Псковская область, Псковский район, село Подборовье	0101000020E6100000B5C2F4BD86843C4065C39ACAA2EC4C40
74696	3	32	1171	51995	\N	\N	57.861517999999997	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Писковичская волость"", д.Писковичи, Здание МОУ Писковская средняя общеобразовательная школа"	Россия, Псковская область, Псковский район, село Писковичи	0101000020E6100000350708E6E8353C402975C93846EE4C40
74694	3	32	1171	51995	\N	\N	57.861517999999997	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Писковичская волость"", д.Писковичи, Здание культурно-досугового центра"	Россия, Псковская область, Псковский район, село Писковичи	0101000020E6100000350708E6E8353C402975C93846EE4C40
74719	3	32	1171	57456	\N	\N	58.011932999999999	"Псковская область, Муниципальное образование ""Псковский район"", Межселенная территория-территория Талабских островов (о.Нижний, о.Талабск, о.Верхний), о.им.Залита, Здание отдела по работе с межселенными территориями"	Россия, Псковская область, Псковский район, село Остров Залит	0101000020E610000079245E9ECE113C40205F420587014D40
74692	3	32	1171	51988	58333	\N	57.796832999999999	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Логозовская волость"", д.Неелово, Юбилейная, д.7"		0101000020E6100000998235CEA6333C40D1AFAD9FFEE54C40
74702	3	32	1171	52021	\N	\N	58.159674000000003	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Середкинская волость"", д.Мельницы, Здание Мельницкой школы"	Россия, Псковская область, Псковский район, село Мельницы	0101000020E610000051D845D103473C40C102983270144D40
74708	3	32	1171	52039	\N	\N	57.961368	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Торошинская волость"", д.Крипецкое-1, Здание фельдшерско-акушерского пункта"	Россия, Псковская область, Псковский район, село Крипецкое 1	0101000020E6100000A795422097943C40E1B54B1B0EFB4C40
74690	3	32	1171	51979	\N	\N	57.602195000000002	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Краснопрудская волость"", д. Кирово, Здание Администрации с/п ""Краснопрудская волость"""	Россия, Псковская область, Псковский район, село Кирово	0101000020E61000004D124BCADD7B3C404968CBB914CD4C40
74688	3	32	1171	48663	58520	\N	57.761360000000003	с. Карамышево, Советская, д.3		0101000020E6100000EAEBF99AE5C23C40C53D963E74E14C40
74691	3	32	1171	51980	\N	\N	57.643706000000002	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Краснопрудская волость"", д.Зайцево, д.29"		0101000020E6100000B7B41A12F7943C40971E4DF564D24C40
74678	3	32	1171	57385	58403	\N	57.942256095839802	МОУ Остенская средняя общеобразовательная школа д. Ершово, ул.Коровина, д.11	Россия, Псковская область, Псковский район, село Ершово	0101000020E6100000772B4B7496393C40DA3A38D89BF84C40
74693	3	32	1171	57374	\N	\N	57.804213803669697	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Логозовская волость"", д.Дуброво, Здание сельского дома культуры"	Россия, Псковская область, Псковский район, село Дуброво	0101000020E6100000E46A64575A223C40207EFE7BF0E64C40
74713	3	32	1171	57410	\N	\N	57.789233301871299	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Ядровская волость"", д.Горнево, Здание коллективного хозяйства ""Пуск"""	Россия, Псковская область, деревня Горнево	0101000020E6100000DD42572250753C4045F6419605E54C40
74967	3	32	1171	49420	\N	\N	57.710051	"д. Гоголево, здание правления СПК ""Гоголево"""	Россия, Псковская область, Псковский район, село Гоголево	0101000020E61000003FE3C28190F83C40FDBE7FF3E2DA4C40
74700	3	32	1171	52015	58553	\N	58.117516000000002	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Середкинская волость"", д.Гверздонь, Центральная, д.19"		0101000020E610000026E5EE737C603C40DD60A8C30A0F4D40
74684	3	32	1171	57417	58527	\N	57.755085582930299	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Карамышевская волость"", д.Выставка, Центральная, д.14"	Россия, Псковская область, Псковский район, село Выставка	0101000020E610000065C6DB4AAFF53C406FD575A8A6E04C40
74699	3	32	1171	52011	58485	\N	58.020338000000002	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Середкинская волость"", д.Верхолино, Красных Партизан, д.10"		0101000020E6100000E02F664B56413C40DB6E826F9A024D40
74697	3	32	1171	52005	58514	\N	57.872642999999997	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Писковичская волость"", д.Ваулино, Строителей, д.26, к.1"		0101000020E6100000FA60191BBA513C40AA0A0DC4B2EF4C40
74686	3	32	1171	51962	\N	\N	57.704517000000003	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Карамышевская волость"", д.Быстрецово, Здание Быстрецовской основной школы"	Россия, Псковская область, Псковский район, село Быстрецово	0101000020E6100000E8DCED7A69D63C40EF3CF19C2DDA4C40
74683	3	32	1171	51955	\N	\N	57.853541	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование ""Карамышевская волость"", д.Большое Загорье, Здание Администрации с/п ""Карамышевская волость"""	Россия, Псковская область, Псковский район, село Большое Загорье	0101000020E61000008ACC5CE0F2EC3C40C765DCD440ED4C40
74712	3	32	1171	52049	58528	\N	57.717857195919002	"Псковская область, Муниципальное образование ""Псковский район"", Муниципальное образование сельское поселение ""Тямшанская волость"", д.Адворицы, Школьная, д.1"	Россия, Псковская область, Псковский район, село Адворицы	0101000020E6100000F9A3A833F7003C40331AF9BCE2DB4C40
75092	3	32	601	57434	\N	\N	57.614425213946298	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Красноармейская волость""д.Ясно, здание администрации волости"	Россия, Псковская область, Порховский район, село Ясно	0101000020E6100000E20511A969773D40226C787AA5CE4C40
75083	3	32	601	52639	\N	\N	57.589267999999997	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование сельское поселение ""Верхнемостская волость"", д.Шмойлово, здание медицинского пункта"	Россия, Псковская область, Порховский район, село Шмойлово	0101000020E6100000A662635E47F03C40274A42226DCB4C40
75102	3	32	601	57406	\N	\N	57.772117999999999	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Туготинская волость"",д.Хилово, здание школы"	Россия, Псковская область, Порховский район, село Хилово	0101000020E6100000EA07759142613D4093533BC3D4E24C40
74763	3	32	683	15052	58537	\N	57.386256000000003	дер.Навережье, Центральная, 18		0101000020E61000003DB83B6BB77D3D4020F12BD670B14C40
75103	3	32	601	52699	\N	\N	57.703665999999998	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Красноармейская волость"",д.Турово, здание администрации волости"	Россия, Псковская область, Порховский район, село Турово	0101000020E61000006FF3C64961AE3D4050A73CBA11DA4C40
75095	3	32	601	52670	\N	\N	57.427075000000002	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Славковская волость"", д.Тинеи, здание администрации волости"	Россия, Псковская область, Порховский район, село Тинеи	0101000020E61000001C446B459B3F3D4038F8C264AAB64C40
75090	3	32	601	52659	\N	\N	57.560374000000003	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Туготинская волость"",д.Терептино, здание администрации"		0101000020E6100000508BC1C3B4473D40ADC3D155BAC74C40
75114	3	32	601	57383	\N	\N	57.758791000000002	"Псковская область, Муниципальное образование ""Себежский район"", Муниципальное образование городское поселение ""Сосновый Бор"", пгт Сосновый Бор"	Россия, Псковская область, Порховский район, село Сосновый Бор	0101000020E610000014B4C9E1936E3D40E4BF401020E14C40
75101	3	32	601	52693	\N	\N	57.644818999999998	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Славковская волость"",село Славковичи, здание дома культуры"	Россия, Псковская область, Порховский район, село Славковичи	0101000020E6100000CC96AC8A700F3D40726BD26D89D24C40
75100	3	32	601	57394	\N	\N	57.687908881854398	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Славковская волость"",д.Пуково, здание СПК ""Строитель"""	Россия, Псковская область, Порховский район, село Пуково	0101000020E6100000F7730AF2B31D3D40E1CFF0660DD84C40
75081	3	32	601	57371	58463	\N	57.766511999999999	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование городское поселение ""Порхов"", Порховская, 3"	Россия, Псковская область, Порховский район, Порхов	0101000020E6100000AAD4EC81568C3D40EBFEB1101DE24C40
75077	3	32	601	57371	58364	\N	57.766511999999999	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование городское поселение ""Порхов"", Плеханова, 6"	Россия, Псковская область, Порховский район, Порхов	0101000020E6100000AAD4EC81568C3D40EBFEB1101DE24C40
75080	3	32	601	57371	58343	\N	57.763504915301702	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование городское поселение ""Порхов"", Мебельная, 7"	Россия, Псковская область, Порховский район, Порхов	0101000020E61000004C8C65FA258E3D408FAA2688BAE14C40
75078	3	32	601	57371	58428	\N	57.767610241775003	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование городское поселение ""Порхов"", Ленина, 14-А"	Россия, Псковская область, Порховский район, Порхов	0101000020E6100000D8817346948E3D40910A630B41E24C40
75091	3	32	601	57404	\N	\N	57.748297128207497	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Красноармейская волость""д.Попадинка, здание администрации волости"	Россия, Псковская область, Порховский район, село Попадинка	0101000020E61000000667F0F78B8D3D40F3583332C8DF4C40
75098	3	32	601	52679	\N	\N	57.779615	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование сельское поселение ""Полонская волость"", д.Полоное, здание администрации волости"	Россия, Псковская область, Порховский район, село Полоное	0101000020E610000019CA897615A23D404B3CA06CCAE34C40
75097	3	32	601	52672	\N	\N	58.0483919835074	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Павская волость"",село Павы, здание администрации волости"	Россия, Псковская область, Порховский район, село Павы	0101000020E6100000D882DE1B43803D40ABB184B531064D40
75096	3	32	601	52674	\N	\N	57.547224999999997	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Славковская волость"",д.Моньшино, здание администрации волости"	Россия, Псковская область, Порховский район, село Моньшино	0101000020E610000002D53F88642C3D40DC4603780BC64C40
75089	3	32	601	52657	\N	\N	57.672562999999997	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Туготинская волость"",д.Молочище, здание администрации"	Россия, Псковская область, Порховский район, село Молочище	0101000020E61000009012BBB6B7473D40F4BF5C8B16D64C40
75085	3	32	601	52644	\N	\N	57.403075999999999	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Славковская волость"",д.Махновка, здание медицинского пункта"	Россия, Псковская область, Порховский район, село Махновка	0101000020E6100000D34F38BBB5583D40B8E68EFE97B34C40
75093	3	32	601	57447	\N	\N	57.655289381509697	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование сельское поселение ""Логовинская волость"",д.Логовино, здание администрации волости"	Россия, Псковская область, Порховский район, село Логовино	0101000020E6100000D61EF64201A73D40DB368C82E0D34C40
75088	3	32	601	52652	\N	\N	57.925389000000003	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Дубровенская волость"", д.Дубровно, здание администрации"	Россия, Псковская область, Порховский район, село Дубровно	0101000020E61000007D224F92AE5D3D40018A912573F64C40
75067	3	32	601	47144	\N	\N	57.992331999999998	деревня Должицы, Здание Должицкой библиотеки-филлиала	Россия, Псковская область, Порховский район, село Должицы	0101000020E6100000ECC1A4F8F8D83D401B6327BC04FF4C40
75086	3	32	601	57455	\N	\N	57.521277113078	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование сельское поселение ""Верхнемостская волость"",д.Гора, здание медицинского пункта"	Россия, Псковская область, Порховский район, село Гора	0101000020E6100000429946938BC53C4018946934B9C24C40
75094	3	32	601	52668	\N	\N	57.624288999999997	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование сельское поселение ""Логовинская волость"",д.Волышово, здание детского сада"	Россия, Псковская область, Порховский район, село Волышово	0101000020E6100000E36BCF2C09B03D405320B3B3E8CF4C40
75084	3	32	601	52641	\N	\N	57.511192000000001	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование сельское поселение ""Верхнемостская волость"",д.Верхний Мост, здание дома культуры"	Россия, Псковская область, Порховский район, село Верхний Мост	0101000020E6100000778192020BE03C4009FD4CBD6EC14C40
75087	3	32	601	57393	\N	\N	57.956353735279997	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование ""Дубровенская волость"".д.Боровичи, здание администрации"		0101000020E6100000F9A3A833F7A43D400BB3D0CE69FA4C40
75082	3	32	601	57448	\N	\N	58.025595882971501	деревня Береза сельского поселения «Павская волость», здание Администрации Павской  волости	Россия, Псковская область, Порховский район, село Береза	0101000020E6100000960854FF20B23D404774CFBA46034D40
75099	3	32	601	52683	\N	\N	57.855522999999998	"Псковская область, Муниципальное образование ""Порховский район"", Муниципальное образование сельское поселение ""Полонская волость"",д.Арбузова Щилинка, здание  школы"	Россия, Псковская область, Порховский район, село Арбузова-Щилинка	0101000020E6100000BB25396057AF3D40E7FC14C781ED4C40
75069	3	32	1870	29783	58481	\N	58.429291999999997	поселок Плюсса, улица Победы, дом 46		0101000020E61000005D34643C4A613D409B374E0AF3364D40
75068	3	32	1870	29783	58346	\N	58.424138644282998	поселок Плюсса, улица Ленина, дом 16	Россия, Псковская область, Плюсский район, поселок Плюсса	0101000020E610000053AF5B04C65E3D40A4FACE2F4A364D40
75070	3	32	1870	29858	\N	\N	58.567124	деревня Нежадово, здание Нежадовской начальной школы	Россия, Псковская область, Плюсский район, село Нежадово	0101000020E610000024ED461FF34D3D406B63EC8497484D40
75065	3	32	1870	29613	\N	\N	58.627948000000004	"село Ляды, здание Администрации сельского поселения ""Лядская волость"""	Россия, Псковская область, Плюсский район, село Ляды	0101000020E6100000A8C64B3789C93C4058CB9D9960504D40
75072	3	32	1870	29947	58534	\N	58.387464000000001	деревня Курея, улица Центральная, дом 6		0101000020E6100000A2D45E44DB5D3D404D309C6B98314D40
75071	3	32	1870	29907	\N	\N	58.494804999999999	деревня Кошелевицы, здание Кошелевецкой библиотеки-филлиала	Россия, Псковская область, Плюсский район, село Кошелевицы	0101000020E61000005EB9DE3653693D40DA722EC5553F4D40
75063	3	32	1870	29519	\N	\N	58.777496999999997	деревня Заянье, здание Заянской начальной школы	Россия, Псковская область, Плюсский район, село Заянье	0101000020E6100000E294B9F946A03C407ADE8D0585634D40
75075	3	32	1870	30081	\N	\N	58.437485000000002	поселок Заплюсье, Дом культуры		0101000020E61000000A12DBDD03BC3D40CBBE2B82FF374D40
75073	3	32	1870	29988	\N	\N	58.361466	деревня Андромер, сельский клуб		0101000020E6100000309B00C3F28F3D40D74E9484442E4D40
74723	3	32	488	13203	\N	\N	57.643315999999999	д.Ротово, Дом культуры		0101000020E6100000581D39D2198C3B402C7FBE2D58D24C40
74685	3	32	488	40473	\N	\N	57.763932446537503	д.Подлесье, Митковицкая основная школа	Россия, Псковская область, Печорский район, село Подлесье	0101000020E6100000503A9160AAB53B40162F1686C8E14C40
74576	3	32	488	2921	58389	\N	57.8126060570902	г.Печоры, Свободы, 27	Россия, Псковская область, Печорский район, Печоры	0101000020E61000000F7F4DD6A89B3B404644317903E84C40
74726	3	32	488	2921	58405	\N	57.811022999999999	г.Печоры, Мира, 19		0101000020E610000058535914769D3B40E3A6069ACFE74C40
74606	3	32	488	2921	58506	\N	57.811022999999999	г.Печоры, Мелиораторов, 11а		0101000020E610000058535914769D3B40E3A6069ACFE74C40
74725	3	32	488	2921	58331	\N	57.811022999999999	г.Печоры, Ленина, 7		0101000020E610000058535914769D3B40E3A6069ACFE74C40
74622	3	32	488	2921	58325	\N	57.821331534375702	г.Печоры, Индустриальная, 13	Россия, Псковская область, Печорский район, Печоры	0101000020E610000089D00836AE9F3B4042942F6821E94C40
75174	3	32	488	2921	58388	\N	57.811022999999999	"г.Печоры, ул. Заводская, дом 1   здание административно-бытового корпуса ООО ""Евро-Керамика"""		0101000020E610000058535914769D3B40E3A6069ACFE74C40
74630	3	32	488	2921	58388	\N	57.811022999999999	г.Печоры, Заводская, 6		0101000020E610000058535914769D3B40E3A6069ACFE74C40
74695	3	32	488	11897	\N	\N	57.690635999999998	д.Паниковичи, Дом культуры	Россия, Псковская область, Печорский район, село Паниковичи	0101000020E61000005A9E077767913B405AB8ACC266D84C40
74721	3	32	488	57379	\N	\N	57.772579367149199	д.Новый Изборск, Новоизборская средняя школа	Россия, Псковская область, Печорский район, поселок Новый Изборок	0101000020E6100000490F43AB93F73B40C74961DEE3E24C40
74722	3	32	488	57379	58517	\N	57.773634122938198	Ясли-сад «Сказка» д. Новый Изборск, ул. Октябрьская, 21		0101000020E6100000D6C4025FD1F93B406E895C7006E34C40
74727	3	32	488	49287	58489	\N	57.577215000000002	д. Лавры , Дом культуры ,ул  Комсомольская дом 6	Россия, Псковская область, Печорский район, село Лавры	0101000020E61000006EDDCD531D7A3B405DE15D2EE2C94C40
74720	3	32	488	40477	\N	\N	57.907930999999998	д.Крупп, Круппская основная школа	Россия, Псковская область, Печорский район, село Крупп	0101000020E6100000B0C56E9F55D63B402503401537F44C40
74728	3	32	488	49309	\N	\N	58.012013000000003	д.Киршино, Дом культуры	Россия, Псковская область, Печорский район, село Киршино	0101000020E61000006E8B321B64BA3B403D1059A489014D40
74724	3	32	488	57390	58427	\N	57.707634763769697	"Изборский лицей д. Изборск,,ул. Псковская, д.31а		0101000020E6100000431EC18D94DD3B40A3409FC893DA4C40
74887	3	32	488	48096	58515	\N	57.639805000000003	с. Велье, ул. Центральная, д.28		0101000020E6100000221807978ECD3B409D685721E5D14C40
74743	3	32	1291	57397	\N	\N	57.5147915643958	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Черская волость"" д.Вернявино, помещение администрации Черской волости"	Россия, Псковская область, Палкинский район	0101000020E610000027DD96C805FF3B40081F4AB4E4C14C40
75026	3	32	1291	46301	\N	\N	57.589928999999998	"деревня Шейкино, здание администрации СП ""Назимовская волость"""	Россия, Псковская область, Палкинский район, село Шейкино	0101000020E6100000825660C8EAEA3B4022FB20CB82CB4C40
74731	3	32	1291	57429	\N	\N	57.5788440458048	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Палкинская волость""д.Слопыгино, помещение сельского дома культуры"	Россия, Псковская область, Палкинский район, село Слопыгино	0101000020E6100000B5FF01D6AA193C402FBE688F17CA4C40
74742	3	32	1291	57392	\N	\N	57.539052043157298	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Родовская волость"" д.Горбунова Гора, Сельский  дом культуры"	Россия, Псковская область, Палкинский район, поселок Палкино	0101000020E6100000AF9811DE1E043C40F46BEBA7FFC44C40
74741	3	32	1291	57392	\N	\N	57.5389597292723	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Родовская волость"" д.Родовое, Сельский дом культуры"	Россия, Псковская область, Палкинский район, поселок Палкино	0101000020E6100000B9DFA128D0033C4014ED2AA4FCC44C40
74729	3	32	1291	57392	58465	\N	57.542493182266497	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование городское поселение ""Палкино"", Островская, 14"	Россия, Псковская область, Палкинский район, поселок Палкино	0101000020E61000000D535BEA20033C408BA71E6970C54C40
74737	3	32	1291	57443	\N	\N	57.459817042378802	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Новоуситовская волость"" д. Новая Уситва, помещение администрации Новоуситовской волости"	Россия, Псковская область, Палкинский район, село Новая Уситва	0101000020E6100000DD240681951F3C408A929048DBBA4C40
74735	3	32	1291	57407	\N	\N	57.466221798003097	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Качановская волость"" с. Качаново, помещение администрации Качановской волости"	Россия, Псковская область, Палкинский район, село Качаново	0101000020E6100000A7AFE76B96C33B407E569929ADBB4C40
74733	3	32	1291	57439	\N	\N	57.6199253095727	"Псковская область, Муниципальное образование ""Палкинский район"", Муниципальное образование сельское поселение ""Васильевская волость"" д. Васильево, помещение администрации Васильевской волости"	Россия, Псковская область, Палкинский район, село Васильево	0101000020E6100000B2BD16F4DEEC3B40857CD0B359CF4C40
74814	3	32	1421	17596	\N	\N	57.285232000000001	деревня Шики, помещение администрации Шиковской волости	Россия, Псковская область, Островский район, село Шики	0101000020E610000039D2191879F93C40E7E26F7B82A44C40
74795	3	32	1421	16626	\N	\N	57.265861000000001	деревня Черепягино, помещение медпункта д.Черепягмно	Россия, Псковская область, Островский район, село Черепягино	0101000020E6100000A913D044D86C3C401424B6BB07A24C40
74816	3	32	1421	17700	\N	\N	57.343031000000003	"деревня Спиры, здание правления СПК ""Труженик"""	Россия, Псковская область, Островский район, село Спиры	0101000020E610000008AF5DDA700C3D40D1419770E8AB4C40
74782	3	32	1421	40375	\N	\N	57.257371999999997	деревня Рублово, здание администрации Бережанской волости	Россия, Псковская область, Островский район, село Рублево	0101000020E610000039454772F97B3C40FB73D190F1A04C40
74888	3	32	1421	21454	\N	\N	57.368414000000001	"д. Рубилово, админ. здание сельского поселения ""Новгородкинская волость"""	Россия, Псковская область, Островский район, село Рубилово	0101000020E610000093E00D6954403C40BCB1A03028AF4C40
74796	3	32	1421	16711	\N	\N	57.280543000000002	деревня Покаты, помещение Федосинского клуба	Россия, Псковская область, Островский район, село Покаты	0101000020E6100000E35295B6B8363C40950F41D5E8A34C40
74815	3	32	1421	17655	\N	\N	57.326479999999997	деревня Подмогилье, помещение библиотеки д.Подмогилье	Россия, Псковская область, Островский район, село Подмогилье	0101000020E6100000E3E0D231E7ED3C402766BD18CAA94C40
74965	3	32	1421	49393	\N	\N	57.423265999999998	с. Подберезье, здание Дома культуры	Россия, Псковская область, Островский район, село Подберезье	0101000020E6100000134548DDCE923C401EC18D942DB64C40
74784	3	32	1421	15838	\N	\N	57.348343999999997	город Остров, помещение детского сада №4	Россия, Псковская область, Островский район, Остров	0101000020E6100000C0232A5437573C4000E1438996AC4C40
74781	3	32	1421	15838	58340	\N	57.348343999999997	город Остров, ул.Фестивальная, 28-а		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74779	3	32	1421	15838	58340	\N	57.348343999999997	город Остров, ул.Фестивальная, Дом офицеров Острова-3		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74793	3	32	1421	15838	58347	\N	57.348343999999997	город Остров, ул.Тимура Апакидзе, д.3		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74787	3	32	1421	15838	58402	\N	57.348343999999997	город Остров, ул.Пригородная, д.3		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74785	3	32	1421	15838	58367	\N	57.352668446745497	город Остров, ул.Освобождения, д.1	Россия, Псковская область, Островский район, Остров	0101000020E6100000027FF8F9EF553C40412C9B3924AD4C40
74790	3	32	1421	15838	58539	\N	57.348343999999997	город Остров, ул.Ветеранов войны, д.60		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74791	3	32	1421	15838	58395	\N	57.348343999999997	город Остров, ул.Б.Пионерская, д.47		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74794	3	32	1421	15838	58376	\N	57.348343999999997	город Остров, ул.Авиационная, д.8		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74788	3	32	1421	15838	58406	\N	57.348343999999997	город Остров, ул.25 Октября, д.51		0101000020E6100000C0232A5437573C4000E1438996AC4C40
74789	3	32	1421	15838	58368	\N	57.348343999999997	город Остров, ул.Б.Пионерская, д.2		0101000020E6100000C0232A5437573C4000E1438996AC4C40
75025	3	32	1421	46259	\N	\N	57.345357999999997	"деревня Наумово, здание ФГОУ СПО ""Наумовский сельскохозяйственный техникум"""	Россия, Псковская область, Островский район, село Наумово	0101000020E6100000B9E2E2A8DCD43C40BBB4E1B034AC4C40
74792	3	32	1421	16491	\N	\N	57.336007000000002	деревня Малая Губа, помещение сельского Дома культуры	Россия, Псковская область, Островский район, село Малая Губа	0101000020E6100000CF13CFD902363C40111D024702AB4C40
74813	3	32	1421	57464	\N	\N	57.249840287336802	деревня Лаврово, помещение медпункта д.Лаврово	Россия, Псковская область, Островский район, село Лаврово	0101000020E610000075CC79C6BED03C40C79DD2C1FA9F4C40
74805	3	32	1421	46486	\N	\N	57.182588000000003	село Крюки, помещение Крюковской школы	Россия, Псковская область, Островский район, село Крюки	0101000020E6100000973B33C1707A3C402F52280B5F974C40
74799	3	32	1421	46370	\N	\N	57.228580000000001	деревня Заборовье, помещение Заборовского сельского Дома культуры	Россия, Псковская область, Островский район, село Заборовье	0101000020E6100000FBCBEEC9C34E3C408542041C429D4C40
74798	3	32	1421	16806	\N	\N	57.212332000000004	деревня Елины, помещение Дома культуры д.Елины	Россия, Псковская область, Островский район, село Елины	0101000020E6100000D49AE61DA7303C4078F2E9B12D9B4C40
74801	3	32	1421	16927	\N	\N	57.508161000000001	деревня Дуловка, помещение Дуловской начальной школы	Россия, Псковская область, Островский район, село Дуловка	0101000020E61000007171546EA2563C40240D6E6B0BC14C40
74797	3	32	1421	46319	\N	\N	57.177743	деревня Дубки, здание сельского Дома культуры	Россия, Псковская область, Островский район, село Дубки	0101000020E6100000C423F1F274223C40E50B5A48C0964C40
74807	3	32	1421	46522	\N	\N	57.165641999999998	деревня Дарьино, помещение сельского Дома культуры д.Дарьино	Россия, Псковская область, Островский район, село Дарьино	0101000020E610000073D712F241A33C40096CCEC133954C40
74806	3	32	1421	17205	\N	\N	57.130164000000001	деревня Гораи, помещение Горайской средней школы	Россия, Псковская область, Островский район, село Гораи	0101000020E610000006802A6EDC863C40EB8EC536A9904C40
74812	3	32	1421	57463	\N	\N	57.281601880036703	село Воронцово, помещение администрации Воронцовской волости	Россия, Псковская область, Островский район, село Воронцово	0101000020E61000007E74EACA67BD3C407D3ECA880BA44C40
74809	3	32	1421	17333	\N	\N	57.346299999999999	"деревня Влазово, помещение с/кооператива""Искра"""	Россия, Псковская область, Островский район, село Влазово	0101000020E6100000E7FF55478E943C406A4DF38E53AC4C40
74808	3	32	1421	57431	\N	\N	57.1805004907445	"деревня Большое Приезжево, помещение конторы совхоза ""Великорецкий"""	Россия, Псковская область, Островский район, село Большое Приезживо	0101000020E6100000272F3201BF7E3C40C976BE9F1A974C40
74902	3	32	1432	22160	\N	\N	56.689101000000001	д. Разувайка, административное здание Пригородного лесничества		0101000020E610000090DB2F9FACA43C400952297634584C40
74907	3	32	1432	48472	\N	\N	56.791679999999999	п. Приозерный, здание бывшей начальной школы	Россия, Псковская область, Опочецкий район, село Приозерный	0101000020E61000008D9B1A683EA33C40DA722EC555654C40
74896	3	32	1432	57372	58345	\N	56.7054360334634	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Стученко, 45"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E6100000E0F42EDE8FAB3C40E5B512BA4B5A4C40
74890	3	32	1432	57372	58516	\N	56.7112785100663	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Набережная, 3"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E61000009CDCEF5014AC3C4071AAB5300B5B4C40
74894	3	32	1432	57372	58420	\N	56.711915765756203	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Ленина, 64"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E6100000807EDFBF79A93C40E4BF4010205B4C40
74893	3	32	1432	57372	58420	\N	56.711100939492802	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Ленина, 20"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E61000001C7A8B87F7AC3C409293895B055B4C40
74898	3	32	1432	57372	58486	\N	56.712505999999998	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Красногородская, 31А"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E61000005A47551344AD3C40151A8865335B4C40
74891	3	32	1432	57372	58430	\N	56.714829929192099	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Коммунальная, 4А"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E61000006077BAF3C4AB3C408F19A88C7F5B4C40
74895	3	32	1432	57372	58352	\N	56.708268547425	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Дзержинского, 62"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E6100000C85EEFFE78AB3C40A4E2FF8EA85A4C40
74897	3	32	1432	57372	58522	\N	56.689805548218096	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Гагарина, 65"	Россия, А-117 шоссе	0101000020E61000005DA8FC6B79A53C40D34A21904B584C40
74900	3	32	1432	57372	58488	\N	56.707324369157398	"Псковская область, Муниципальное образование ""Опочецкий район"", Муниципальное образование городское поселение ""Опочка"", Басковская, 50"	Россия, Псковская область, Опочецкий район, Опочка	0101000020E61000005D70067FBFA83C4084D6C397895A4C40
74912	3	32	1432	41361	\N	\N	56.671062999999997	"д. Норкино, административное здание СП ""Глубоковская волость"""		0101000020E6100000730F09DFFB073D401F477364E5554C40
74906	3	32	1432	48456	\N	\N	56.864192000000003	"д. Матюшкино, административное здание СП ""Матюшкинская волость"""		0101000020E6100000D5CF9B8A54A03C4080BBECD79D6E4C40
74892	3	32	1432	48197	\N	\N	56.688256000000003	д. Макушино, здание Макушинского сельского клуба	Россия, Псковская область, Опочецкий район, село Макушино	0101000020E6100000C3633F8BA5783C404DA3C9C518584C40
74901	3	32	1432	22100	\N	\N	56.737194000000002	д. Ляпуны, здание Ляпуновской сельской библиотеки	Россия, Псковская область, Опочецкий район, село Ляпуны	0101000020E6100000C5E57805A2B73C405A677C5F5C5E4C40
74915	3	32	1432	48605	\N	\N	56.530076999999999	д. Лобово, здание Лобовского сельского клуба	Россия, Псковская область, Опочецкий район, село Лобово	0101000020E610000069A9BC1DE1D83C404FAE2990D9434C40
74909	3	32	1432	57442	\N	\N	56.742441642399299	"д. Лаптево, административное здание СП ""Болгатовская волость"""	Россия, Псковская область, Опочецкий район, село Лаптево	0101000020E6100000E9297288B8D53C40A296E656085F4C40
74783	3	32	1432	16012	\N	\N	56.667580999999998	деревня Кахново, здание медпункта деревни Кахново	Россия, Псковская область, Опочецкий район, село Кахново	0101000020E6100000B7B3AF3C48A73C402A37514B73554C40
74914	3	32	1432	22692	\N	\N	56.625008999999999	"д. Звоны, административное здание СП ""Звонская волость"""		0101000020E6100000179B560A81D03C40535A7F4B00504C40
74911	3	32	1432	22530	\N	\N	56.787084999999998	"д. Духново, административное здание СП ""Болгатовская волость"""		0101000020E6100000E90B21E7FD233D4009168733BF644C40
74913	3	32	1432	48574	\N	\N	56.610731000000001	"д. Глубокое, административное здание СП ""Глубоковская волость"""		0101000020E6100000635E471CB2053D40A2D3F36E2C4E4C40
74905	3	32	1432	48436	\N	\N	56.761023000000002	д. Варыгино, здание Варыгинского сельского клуба	Россия, Псковская область, Опочецкий район, село Варыгино	0101000020E610000044C2F7FE06893C407D40A03369614C40
74910	3	32	1432	22503	\N	\N	56.799438000000002	"д. Болгатово, административное здание СП ""Болгатовская волость"""		0101000020E610000009FF2268CCF03C40FF9600FC53664C40
74908	3	32	1432	57409	\N	\N	56.797930000000001	"д. Белки, помещение бывшего админ. здания СПК ""Колос"""	Россия, Псковская область, Опочецкий район, село Белки	0101000020E6100000B9162D40DBB23C40A73FFB9122664C40
74966	3	32	1432	49403	\N	\N	56.778672	д. Барсуки, здание сельского клуба	Россия, Псковская область, Опочецкий район, село Барсуки	0101000020E6100000541A31B3CF133D40CC272B86AB634C40
74904	3	32	1432	22252	\N	\N	56.717950000000002	"д. Барсаново, административное здание СПК ""Опочецкий"""		0101000020E6100000853FC39B35903C40E4141DC9E55B4C40
75155	3	32	1432	52823	\N	\N	56.621443999999997	д.Барканы, помещение сельского клуба, д.10		0101000020E6100000AF27BA2EFC303D40D0251C7A8B4F4C40
74916	3	32	1432	22769	\N	\N	56.574095	"д. Балахи, административное здание СП ""Звонская волость"""		0101000020E6100000E3FC4D2844B43C4008E6E8F17B494C40
74948	3	32	502	24250	\N	\N	56.347014999999999	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Новосокольническая волость"", дер. Шахниха, здание админи страции с/п ""Новосокольническая волость"""	Россия, Псковская область, Новосокольнический район, село Шахниха	0101000020E6100000882D3D9AEA213E40581CCEFC6A2C4C40
74941	3	32	502	23892	\N	\N	56.573638000000003	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Бологовская волость"", дер. Бор, здание администрации с/п ""Бологовская волость"""	Россия, Псковская область, Новосокольнический район, село Харино-Бор	0101000020E6100000C90567F0F7873D4016DF50F86C494C40
74952	3	32	502	24471	\N	\N	56.345584000000002	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Окнийская волость"", дер. Старосокольники, здание сельской библиотеки-клуба"	Россия, Псковская область, Новосокольнический район, село Старосокольники	0101000020E61000005725917D90013E40AC02B5183C2C4C40
74956	3	32	502	24674	\N	\N	56.458716000000003	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Руновская волость"", дер. Руново, здание администрации с/п ""Руновская волость"""	Россия, Псковская область, Новосокольнический район, село Руново	0101000020E61000005723BBD232CE3D407313B534B73A4C40
74944	3	32	502	57446	\N	\N	56.4485506747682	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Горожанская волость"", дер. Раменье, здание Раменского сельского клуба"	Россия, Псковская область, Новосокольнический район, село Ременье	0101000020E6100000359BC76130FF3D4047CB811E6A394C40
74955	3	32	502	24581	\N	\N	56.539473000000001	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Руновская волость"", дер. Островки, здание МОУ ""Островская основная общеобразовательная школа"""	Россия, Псковская область, Новосокольнический район, село Островки	0101000020E6100000AD8A709351C93D409A0986730D454C40
74949	3	32	502	24296	\N	\N	56.284129	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Окнийская волость"", дер. Окни, здание администрации с/п ""Окнийская волость"""	Россия, Псковская область, Новосокольнический район, село Окни	0101000020E6100000765089EB18133E402F6CCD565E244C40
74938	3	32	502	57381	58385	\N	56.337021999999997	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование городское поселение ""Новосокольники"", Тихмянова, 10"	Россия, Псковская область, Новосокольнический район, Новосокольники	0101000020E6100000ED10FFB0A5273E4029047289232B4C40
74936	3	32	502	57381	58385	\N	56.330479485324602	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование городское поселение ""Новосокольники"", Тихмянова, 8"	Россия, Псковская область, Новосокольнический район, Новосокольники	0101000020E610000024ED461FF3253E40E481C8224D2A4C40
74937	3	32	502	57381	58433	\N	56.337021999999997	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование городское поселение ""Новосокольники"", Партизанская, 14"	Россия, Псковская область, Новосокольнический район, Новосокольники	0101000020E6100000ED10FFB0A5273E4029047289232B4C40
74940	3	32	502	57381	58500	\N	56.337021999999997	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование городское поселение ""Новосокольники"", Загородная, 3а"		0101000020E6100000ED10FFB0A5273E4029047289232B4C40
74939	3	32	502	57381	58423	\N	56.337021999999997	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование городское поселение ""Новосокольники"", Воровского, 23"	Россия, Псковская область, Новосокольнический район, Новосокольники	0101000020E6100000ED10FFB0A5273E4029047289232B4C40
74946	3	32	502	24141	\N	\N	56.578051000000002	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Насвинская волость"", дер. Насва, здание администрации с/п ""Насвинская волость"""	Россия, Псковская область, Новосокольнический район, село Насва	0101000020E6100000D2AC6C1FF2263E40C6353E93FD494C40
74947	3	32	502	24207	\N	\N	56.554850999999999	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Насвинская волость"", дер. Назимово, здание Назимовского фельдшерско-акушерского пункта"	Россия, Псковская область, Новосокольнический район, село Назимово	0101000020E6100000FD8348861C273E409293895B05474C40
74945	3	32	502	24119	\N	\N	56.359867999999999	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Маевская волость"", дер. Маево, здание администрации с/п ""Маевская волость"""	Россия, Псковская область, Новосокольнический район, село Маево	0101000020E6100000B9E177D32DCB3D403F709527102E4C40
74971	3	32	502	25332	\N	\N	56.602437000000002	д. Липшани, здание фельдшерско-акушерского пункта	Россия, Псковская область, Новосокольнический район, село Липшани	0101000020E6100000DF8AC40435183E403F73D6A71C4D4C40
74953	3	32	502	24510	\N	\N	56.343328999999997	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Первомайская волость"", дер. Захарино, здание администрации с/п ""Первомайская волость"""	Россия, Псковская область, Новосокольнический район, село Захарино	0101000020E61000003EEB1A2D07323E405A626534F22B4C40
74954	3	32	502	24571	\N	\N	56.312703999999997	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Первомайская волость"", дер. Демя, здание сельской библиотеки-клуба"	Россия, Псковская область, Новосокольнический район, село Демя	0101000020E610000038BD8BF7E3523E4008AA46AF06284C40
74943	3	32	502	23976	\N	\N	56.565182999999998	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Горожанская волость"", дер. Горожане, здание Горожанского сельского клуба"	Россия, Псковская область, Новосокольнический район, село Горожане	0101000020E6100000AF43352559073E40A9A0A2EA57484C40
74942	3	32	502	23968	\N	\N	56.610923999999997	"Псковская область, Муниципальное образование ""Новосокольнический район"", Муниципальное образование сельское поселение ""Вязовская волость"", дер. Вяз, здание администрации с\\п ""Вязовская волость"""	Россия, Псковская область, Новосокольнический район, село Вяз	0101000020E61000000113B87537A73D40B62BF4C1324E4C40
74846	3	32	685	19244	\N	\N	57.149034999999998	"Псковская область, Новоржевский район, д. Стехново, здание Администрации с/поселения ""Стехновская волость"""	Россия, Псковская область, Новоржевский район, село Стехново	0101000020E610000064EB19C231373D40CC7A319413934C40
74845	3	32	685	19160	\N	\N	57.043297000000003	"Псковская область, Новоржевский район, д. Орша, здание Администрации сельского поселения ""Оршанская волость"""	Россия, Псковская область, Новоржевский район, село Орша	0101000020E6100000CAC0012D5D553D40E9818FC18A854C40
74837	3	32	685	18720	58337	\N	57.030552999999998	Псковская область, Новоржевский район, город Новоржев, Некрасова, 28		0101000020E610000038143E5B07573D40B8E52329E9834C40
74844	3	32	685	19154	\N	\N	56.992150000000002	"Псковская область, Новоржевский район, д. Макарово, здание Администрации с/поселения ""Макаровская волость"""	Россия, Псковская область, Новоржевский район, село Макарово	0101000020E610000039268BFB8F643D40FB5C6DC5FE7E4C40
74843	3	32	685	19089	\N	\N	56.926744999999997	"Псковская область, Новоржевский район, д. Жадрицы, здание Администрации сельского поселения ""Жадрицкая волость"""	Россия, Псковская область, Новоржевский район, село Жадрицы	0101000020E61000000EA2B5A2CD293D40A25D85949F764C40
74810	3	32	685	46592	\N	\N	57.270099999999999	деревня Городище, помещение администрации Городищенской волости	Россия, Псковская область, Новоржевский район, село Городище	0101000020E61000006760E4654D703D40265305A392A24C40
74842	3	32	685	4760	\N	\N	57.227079276125998	МОУ «Выборская общеобразовательная школа», Новоржевский раон,  д.Выбор ул.Школьная д.8	Россия, Псковская область, Новоржевский район, село Выбор	0101000020E610000010EA2285B2283D40E04DB7EC109D4C40
74841	3	32	685	18986	\N	\N	57.071662449079	"Псковская область, Новоржевский район, д. Вехно, здание МОУ ""Вехнянская общеобразовательная школа"""	Россия, Псковская область, Новоржевский район, село Вехно	0101000020E61000004641F0F8F6323D40D82E6D382C894C40
74840	3	32	685	18915	\N	\N	57.252873000000001	"Псковская область, Новоржевский район, д. Веска, здание Администрации сельского поселения ""Вескинская волость"	Россия, Псковская область, Новоржевский район, село Веска	0101000020E610000051BB5F05F8623D404D8578245EA04C40
74839	3	32	685	18886	\N	\N	57.057558	"Псковская область, Новоржевский район, д. Барута, здание Администрации сельского поселения ""Барутская волость"""	Россия, Псковская область, Новоржевский район, село Барута	0101000020E6100000BFB854A52D963D40C4CF7F0F5E874C40
75154	3	32	220	57408	\N	\N	56.008612189924399	д.Урочище Дубровка, помещение сельского Дома культуры, д.43	Россия, Псковская область, Невельский район	0101000020E6100000DE21C50089CE3D40342DB1321A014C40
75149	3	32	220	57437	\N	\N	56.127283842738201	д.Щербино, помещение библиотеки, д.26	Россия, Псковская область, Невельский район, село Щербино	0101000020E61000006B47718E3AF63D40ECA694D74A104C40
75124	3	32	220	57414	\N	\N	56.1511635908656	д.Чернуха, помещение клуба, д.46	Россия, Псковская область, Невельский район, село Чернуха	0101000020E610000036AE7FD767223E40912A8A5759134C40
75156	3	32	220	57423	\N	\N	56.009143999999999	д.Ушаково, помещение сельского клуба, д.2		0101000020E6100000FCFECD8B13C73D40317A6EA12B014C40
75161	3	32	220	2162	58350	\N	56.135624	д.Усть-Долыссы, ул.Ленинградская, д.19 А		0101000020E61000005B9544F641A63D40BF4692205C114C40
75160	3	32	220	2110	58476	\N	55.856957000000001	д.Туричино, ул.Центральная, д.53		0101000020E61000008F8CD5E6FF913D40058A58C4B0ED4B40
75158	3	32	220	2006	\N	\N	56.199230999999997	"д.Трехалево, здание Администрации с.п. ""Трехалевская волость"", д.29"		0101000020E610000050FC1873D7D23D40B8ACC26680194C40
75148	3	32	220	57425	\N	\N	56.019986861482202	д.Рыкалево, помещение библиотеки, д.3	Россия, Псковская область, Невельский район, село Рыколево	0101000020E6100000E7C589AF760C3E402EAC1BEF8E024C40
75159	3	32	220	52835	\N	\N	56.230617000000002	д.Рукавец, помещение сельского клуба, д.1		0101000020E61000001A8BA6B393C53D4069739CDB841D4C40
75113	3	32	220	31975	\N	\N	56.092396000000001	"д.Опухлики, здание Администрации с.п. ""Голобоозерская волость"", д.41"		0101000020E610000060066344A2283E40FF23D3A1D30B4C40
75153	3	32	220	1694	58499	\N	55.936570000000003	д.Новохованск, ул.Ленина, д.22		0101000020E610000072C0AE264FB53D4016359886E1F74B40
75139	3	32	220	833	58357	\N	56.012353164616002	г.Невель, ул.М.Маметовой, д.5	Россия, Псковская область, Невельский район, Невель	0101000020E6100000DCD440F339EF3D40F58079C894014C40
75138	3	32	220	833	58357	\N	56.023108000000001	г.Невель, у.М.Маметовой, д.78		0101000020E610000001F73C7FDAEC3D405323F433F5024C40
75145	3	32	220	833	58358	\N	56.023108000000001	г.Невель, ул.Ленина, д.7		0101000020E610000001F73C7FDAEC3D405323F433F5024C40
75142	3	32	220	833	58358	\N	56.023108000000001	г.Невель, ул.Ленина, д.5		0101000020E610000001F73C7FDAEC3D405323F433F5024C40
75141	3	32	220	833	58341	\N	56.023108000000001	г.Невель, пер.Красный, д.3		0101000020E610000001F73C7FDAEC3D405323F433F5024C40
75143	3	32	220	833	58412	\N	56.016858294869202	г.Невель, ул.Комсомольская, д.4	Россия, Псковская область, Невельский район, Невель	0101000020E610000096E7C1DD59EB3D408656276728024C40
75157	3	32	220	52830	\N	\N	56.030039000000002	д.Ловец, помещение сельского Дома культуры, д.9		0101000020E6100000F4A8F8BF239E3D40624D6551D8034C40
75151	3	32	220	1578	\N	\N	55.867787999999997	"д.Лобок, здание Администрации с.п. ""Лобковская волость"", д.21"		0101000020E61000008A0453CDACF53D403DEE5BAD13EF4B40
75150	3	32	220	57450	58557	\N	55.868987924546197	д.Лехово, ул.Центральная, д.10	Россия, Псковская область, Невельский район, село Лехово	0101000020E6100000D6FCF84B8B5E3E40E84EB0FF3AEF4B40
75021	3	32	220	45407	\N	\N	55.790140000000001	"деревня Кресты, здание администрации СП ""Долговицкая волость"""	Россия, Псковская область, Невельский район, село Кресты	0101000020E6100000F2EEC8586D7E3D4077A1B94E23E54B40
74918	3	32	1747	48672	\N	\N	56.905577999999998	д. Юхово, здание Дома культуры	Россия, Псковская область, Локнянский район, село Юхово	0101000020E610000074EB353D286C3E4011FDDAFAE9734C40
74961	3	32	1747	24894	\N	\N	56.841403999999997	д. Рысино, здание Администрации Локнянской волости	Россия, Псковская область, Локнянский район, село Рысино	0101000020E61000001D1EC2F869243E409E5C5320B36B4C40
74969	3	32	1747	25251	\N	\N	56.628039999999999	д. Прискуха, здание фельдшерско-акушерского пункта	Россия, Псковская область, Локнянский район, село Прискуха	0101000020E6100000DD06B5DFDA293E40384A5E9D63504C40
74950	3	32	1747	24371	\N	\N	56.645648000000001	д. Миритиницы, здание Миритиницкой основной школы	Россия, Псковская область, Локнянский район, село Миритиницы	0101000020E6100000AF415F7AFBD33D40295DFA97A4524C40
74957	3	32	1747	24813	58353	\N	56.825251999999999	пос. Локня, Социалистическая, 32		0101000020E61000006405BF0D31263E40B37A87DBA1694C40
74958	3	32	1747	24813	58409	\N	56.825251999999999	пос. Локня, Первомайская, 44		0101000020E61000006405BF0D31263E40B37A87DBA1694C40
74959	3	32	1747	24813	58408	\N	56.825251999999999	пос. Локня, Октябрьская, 14		0101000020E61000006405BF0D31263E40B37A87DBA1694C40
74960	3	32	1747	24846	\N	\N	56.740935999999998	д. Крестилово, здание Администрации Алексеевской волости	Россия, Псковская область, Локнянский район, село Крестилово	0101000020E61000002B172AFF5A2E3E40EB36A8FDD65E4C40
74889	3	32	1747	48147	58543	\N	56.593105999999999	д. Васильевское, ул. Центральная, д.18		0101000020E6100000F9BD4D7FF6033E40DB87BCE5EA4B4C40
74968	3	32	1747	25201	\N	\N	56.641035000000002	д. Башово, здание Администрации Самолуковской волости	Россия, Псковская область, Локнянский район, село Башово	0101000020E610000084D558C2DA283E40B24B546F0D524C40
75016	3	32	1776	57401	\N	\N	56.278370617737899	"деревня Ущицы, здание администрации СП ""Ущицкая волость"""	Россия, Псковская область, Куньинский район, село Ушицы	0101000020E6100000C993A46B26CB3E40D19332A9A1234C40
75019	3	32	1776	27534	\N	\N	55.858074000000002	село Усмынь, здание бывшей администрации Усмынской волости	Россия, Псковская область, Куньинский район, село Усмынь	0101000020E6100000C18C2958E3283F4022C66B5ED5ED4B40
74993	3	32	1776	26341	\N	\N	56.086404000000002	"деревня Слепнево, здание администрации СП ""Слепневская волость"""	Россия, Псковская область, Куньинский район, село Слепнево	0101000020E61000003D0CAD4ECE043F402E1F49490F0B4C40
75017	3	32	1776	27435	\N	\N	55.967708000000002	"деревня Пухново, здание администрации СП ""Пухновская волость"""	Россия, Псковская область, Куньинский район, село Пухново	0101000020E6100000D926158DB5173F40EE0912DBDDFB4B40
75018	3	32	1776	46093	\N	\N	55.938637	деревня Прихабы, здание Прихабского сельского клуба	Россия, Псковская область, Куньинский район, село Прихабы	0101000020E6100000F5F3A62215463F4064E8D84125F84B40
74838	3	32	1776	57426	\N	\N	56.219773026867799	"д.Лукино, здание администрации МО ""Красногородская волость"""	Россия, Псковская область, Куньинский район, село Лукино	0101000020E61000004850FC1873D73E409CC58B85211C4C40
75013	3	32	1776	27045	58523	\N	56.286793864508297	поселок Кунья, переулок Новый, 1	Россия, Псковская область, Куньинский район, поселок Кунья	0101000020E610000037FC6EBA65F73E40325871AAB5244C40
75010	3	32	1776	27045	58532	\N	56.284359000000002	поселок Кунья, Полевая, 8а		0101000020E61000004CFF9254A6F83E4061A92EE065244C40
75012	3	32	1776	27045	58473	\N	56.284359000000002	поселок Кунья, Дзержинского, 22		0101000020E61000004CFF9254A6F83E4061A92EE065244C40
75009	3	32	1776	27045	58473	\N	56.284359000000002	поселок Кунья, Дзержинского, 108		0101000020E61000004CFF9254A6F83E4061A92EE065244C40
75008	3	32	1776	27045	58473	\N	56.284359000000002	поселок Кунья, Дзержинского, 17		0101000020E61000004CFF9254A6F83E4061A92EE065244C40
75011	3	32	1776	27045	58494	\N	56.284359000000002	поселок Кунья, Больничная, 9		0101000020E61000004CFF9254A6F83E4061A92EE065244C40
94997	3	32	1776	49286	\N	\N	56.202426000000003	"Куньинский район, д. Каськово, админисирация сельского поселения ""Каськовская волость"" "		0101000020E6100000ED0E290648303F4018EE5C18E9194C40
75024	3	32	1776	27774	\N	\N	56.283119999999997	"деревня Жижица, здание МОУ ""Жижицкая средняя общеобразовательная школа"""	Россия, Псковская область, Куньинский район, село Жижица	0101000020E610000083DBDAC2F35A3F40F86BB2463D244C40
75020	3	32	1776	27605	\N	\N	55.810445000000001	деревня Долговица, здание фельдшерско-акушерского пункта	Россия, Псковская область, Куньинский район, село Долговица	0101000020E6100000832F4CA60A4E3F40761A69A9BCE74B40
74975	3	32	1776	25538	\N	\N	56.166536000000001	деревня Встеселово, здание Октябрьского медпункта	Россия, Псковская область, Куньинский район, село Встеселово	0101000020E6100000A2D3F36E2CF83E40A7CD380D51154C40
75015	3	32	1776	57436	\N	\N	56.286587154482	д.Боталово,д36,зд.ООО"Кр. знамя"	Россия, Псковская область, Куньинский район, село Боталово	0101000020E6100000B9E34D7E8BE63E40B83A00E2AE244C40
94996	3	32	1776	49686	\N	\N	56.352487000000004	Куньиннский район, д. Борок ,д.  64, фельдшерско-акушерский пункт		0101000020E61000002EAD86C43DEE3E40F1A1444B1E2D4C40
75152	3	32	696	57415	\N	\N	56.904938573649702	д.Усово, помещение сельской библиотеки, д.56	Россия, Псковская область, Пушкиногорский район	0101000020E6100000E7374C3448013D40FEEF880AD5734C40
74855	3	32	696	5054	\N	\N	56.804372000000001	Здание сельской библиотеки Красногородский район, д. Треньки		0101000020E61000004E7B4ACE89053C40B8E864A9F5664C40
74850	3	32	696	47415	\N	\N	56.830399	"д.Саурово, здание ГУСО ""Красногогродский ПНИ"""	Россия, Псковская область, Красногородский район, село Саурово	0101000020E6100000DB8AFD65F7583C40C8D0B1834A6A4C40
74856	3	32	696	19769	\N	\N	56.690851000000002	Администрация муниципального образования «Пограничная волость»Красногородский район, д. Покровское		0101000020E6100000005471E316433C4057B439CE6D584C40
74825	3	32	696	46897	58510	\N	56.812477999999999	д.Мыза, Центральная, 14		0101000020E6100000948444DAC64F3C40185C7347FF674C40
74854	3	32	696	19672	\N	\N	56.780349000000001	Администрация муниципального образования «Пограничная волость»Красногородский район, д. Кресты		0101000020E610000001FC53AA44153C40B03BDD79E2634C40
74849	3	32	696	19302	58530	\N	56.834602254760703	р.п.Красногородск, Школьная, 7	Россия, Псковская область, Красногородский район, поселок Красногородск	0101000020E61000005FB7088CF5493C408D96033DD46A4C40
74848	3	32	696	19302	58348	\N	56.834510999999999	р.п.Красногородск, Советская, 50		0101000020E6100000A724EB7074493C407D93A641D16A4C40
74847	3	32	696	19302	58390	\N	56.830791086958499	р.п.Красногородск, Синерецкая, 39	Россия, Псковская область, Красногородский район, поселок Красногородск	0101000020E61000005793A7ACA64B3C40D367075C576A4C40
74853	3	32	696	45378	\N	\N	56.922108000000001	д. Ильинское, здание Администрации муниципального образования "Партизанская волость"	Россия, Псковская область, Красногородский район, село Ильинское	0101000020E61000006DCA15DEE5863C40A3B08BA207764C40
74857	3	32	696	47542	\N	\N	56.737628999999998	Здание фельдшерско-акушерского пункта Красногородский район, д. Золотово		0101000020E61000004CA7751BD4523C4064CA87A06A5E4C40
74863	3	32	696	20118	\N	\N	56.871163000000003	"д.Гавры, Здание администрации с/п  ""Гавровская волость"""	Россия, Псковская область, Красногородский район, село Гавры	0101000020E61000004D310741472B3C401D3EE944826F4C40
74852	3	32	696	4912	\N	\N	56.944464000000004	д. Блясино, здание Анкудиновской основной общеобразовательной школы филиал МОУ "Красногородская средняя общеобразовательная школа"	Россия, Псковская область, Красногородский район, село Блясино	0101000020E61000006E4C4F58E24D3C40EB1F4432E4784C40
74748	3	32	880	14382	\N	\N	57.847893999999997	д. Скугры, здание СПК им. Мичурина	Россия, Псковская область, Дновский район, село Скугры	0101000020E6100000E95F92CA14E73D40C03C64CA87EC4C40
74752	3	32	880	57441	\N	\N	57.820263865046101	"д, Панкратово, административное здание ООО ""Панкратовское"""	Россия, Псковская область, Дновский район, село Панкратово	0101000020E6100000C74961DEE33C3E40070B2769FEE84C40
74751	3	32	880	57399	\N	\N	57.8911397861932	д, Морино, помещение Администрации Моринской волости	Россия, Псковская область, Дновский район, село Морино	0101000020E61000003BA8C4758C5B3E40271422E010F24C40
74964	3	32	880	49373	\N	\N	57.831403999999999	д. Михайлов Погост, здание Михайловской основной школы	Россия, Псковская область, Дновский район, село Михайлов Погост	0101000020E61000006B2C616D8C413E40BDE13E726BEA4C40
74749	3	32	880	55035	\N	\N	57.920144999999998	д, Лукомо, помещение Администрации Лукомской волости	Россия, Псковская область, Дновский район, село Лукомо	0101000020E61000003718EAB0C2093E40F949B54FC7F54C40
74759	3	32	880	57449	\N	\N	57.773309799573298	д. Искра, помещение Администрации Искровской волости	Россия, Псковская область, Дновский район, село Искра	0101000020E6100000774A07EBFFE03D40BBD573D2FBE24C40
74746	3	32	880	6658	58335	\N	57.825178999999999	г. Дно, Энергетиков, 3		0101000020E610000088F6B182DFF63D40492C29779FE94C40
74744	3	32	880	6658	58332	\N	57.825178999999999	г. Дно, Омельянюка, 10		0101000020E610000088F6B182DFF63D40492C29779FE94C40
74745	3	32	880	6658	58383	\N	57.829300125113498	г. Дно, Ленина, 19	Россия, Псковская область, Дновский район, Дно	0101000020E6100000FEF3346090FC3D4052499D8026EA4C40
74753	3	32	880	6658	58552	\N	57.825178999999999	г. Дно, Космонавтов, 84		0101000020E610000088F6B182DFF63D40492C29779FE94C40
14615	3	32	880	6658	58392	\N	57.827792510654497	г. Дно, Бисениек, 10	Россия, Псковская область, Дновский район, Дно	0101000020E6100000622F14B01DF83D40CA6DFB1EF5E94C40
74754	3	32	880	45435	58554	\N	57.819034000000002	п. Дачное, Шоссейная, 42		0101000020E6100000278925E5EE033E40F2272A1BD6E84C40
74756	3	32	880	57460	\N	\N	57.730176713758397	д. Гаврово, помещение Администрации Гавровской волости	Россия, Псковская область, Дновский район, село Гаврово	0101000020E6100000D591239D81253E404CA59F7076DD4C40
74755	3	32	880	52123	\N	\N	57.773547999999998	д. Выскодь, помещение Администрации Выскодской волости	Россия, Псковская область, Дновский район, село Выскодь	0101000020E6100000745C8DEC4A133E406FF1F09E03E34C40
74750	3	32	880	57419	\N	\N	57.9324748873725	"д. Юрково, помещение МОУ ""Юрковская основная общеобразовательная школа"""	Россия, Псковская область, Дновский район, село Большое Юрково	0101000020E6100000774EB340BBD73D4036AB3E575BF74C40
74757	3	32	880	57451	\N	\N	57.670253859900299	"д. Белая, помещение МОУ ""Бельская основная общеобразовательная школа"""	Россия, Псковская область, Дновский район, село Белая	0101000020E610000053927538BA023E40B00111E2CAD54C40
74772	3	32	683	15523	58545	\N	57.550108999999999	дер.Ясски, пер.Школьный, 2		0101000020E61000000D384BC9721E3E401D1EC2F869C64C40
74771	3	32	683	45749	58546	\N	57.553657999999999	дер.Станки, Центральная, 36		0101000020E6100000A2B77878CF593E409A95ED43DEC64C40
74767	3	32	683	15272	58490	\N	57.461860999999999	дер.Пожеревицы, 1-ая Советская, 44а		0101000020E6100000ACFF73982FCB3D402026E1421EBB4C40
74776	3	32	683	45844	58531	\N	57.562874999999998	дер.Погостище, Мира, 22		0101000020E6100000D6389B8E00DE3D40355EBA490CC84C40
74775	3	32	683	57457	58562	\N	57.591388367197297	дер.Дубишно, Центральная, 23	Россия, Псковская область, Дедовичский район, село Дубишино	0101000020E6100000519FE40E9BF43D40999F1B9AB2CB4C40
74774	3	32	683	14954	58414	\N	57.54795	пос.Дедовичи ул.Энергетиков д.6		0101000020E610000023F94A2025F23D40EEEBC03923C64C40
74761	3	32	683	14954	58414	\N	57.54795	пос.Дедовичи, Энергетиков, 6		0101000020E610000023F94A2025F23D40EEEBC03923C64C40
74760	3	32	683	14954	58400	\N	57.54795	пос.Дедовичи, Пионерская, 10		0101000020E610000023F94A2025F23D40EEEBC03923C64C40
74762	3	32	683	14954	58336	\N	57.54795	пос.Дедовичи, Октябрьская, 11		0101000020E610000023F94A2025F23D40EEEBC03923C64C40
74765	3	32	683	57453	58559	\N	57.520515053479002	дер.Горушка, Озёрная, 16	Россия, Псковская область, Дедовичский район, село Горушка	0101000020E61000006B9E23F25D923D40EA094B3CA0C24C40
74769	3	32	683	15354	58555	\N	57.396030000000003	дер.Городовик, Торфяников, 1		0101000020E6100000B6BE4868CB213E40111E6D1CB1B24C40
74777	3	32	683	57411	58519	\N	57.633001299667498	дер.Вязье, Школьная, 7	Россия, Псковская область, Дедовичский район, село Вязье	0101000020E6100000C156091687D33D40EBAA402D06D14C40
71387	3	32	596	11244	\N	\N	58.420710999999997	с.Ямм	Россия, Псковская область, Гдовский район, поселок Ямм	0101000020E6100000EFE192E34E113C40A208A9DBD9354D40
75059	3	32	596	46970	\N	\N	58.617778999999999	д.Трутнево	Россия, Псковская область, Гдовский район, село Трутнево	0101000020E6100000AAEFFCA204F13B40EA93DC61134F4D40
75056	3	32	596	59082	\N	\N	58.730231959487703	м.Смуравьево-2, д.16	Россия, Псковская область, Гдовский район	0101000020E6100000AA0D4E44BFEA3B40103FFF3D785D4D40
74705	3	32	596	12348	\N	\N	58.291262000000003	д.Самолва	Россия, Псковская область, Гдовский район, село Самолва	0101000020E61000000D36751E159F3B40A648BE1248254D40
74851	3	32	596	19484	\N	\N	58.314087999999998	д.Ремда	Россия, Псковская область, Гдовский район, село Ремда	0101000020E610000023D74D29AFC93B4074081C0934284D40
75061	3	32	596	29454	\N	\N	58.452292	д.Полна	Россия, Псковская область, Гдовский район, село Полна	0101000020E6100000A5BBEB6CC8273C40081F4AB4E4394D40
75052	3	32	596	29065	\N	\N	58.801876999999998	д.Полично	Россия, Псковская область, Гдовский район, село Полично	0101000020E6100000A08D5C37A5D03B401135D1E7A3664D40
75057	3	32	596	46948	\N	\N	58.770802000000003	д.Плесна	Россия, Псковская область, Гдовский район, село Плесна	0101000020E6100000BF60376C5B4C3C4080D8D2A3A9624D40
75062	3	32	596	57454	\N	\N	58.437205802483	д.Первомайская	Россия, Псковская область, Гдовский район, село Первомайское	0101000020E610000006D671FC505D3C40B8CEBF5DF6374D40
75060	3	32	596	57452	\N	\N	58.453614447442199	д.Партизанская	Россия, Псковская область, Гдовский район, село Партизанская	0101000020E6100000137EA99F370D3C40FE800706103A4D40
75042	3	32	596	46627	\N	\N	58.407280999999998	д.Островцы	Россия, Псковская область, Гдовский район, село Островцы	0101000020E6100000315F5E807DB43B401EA4A7C821344D40
75053	3	32	596	29084	\N	\N	58.843913999999998	д.Кануновщина	Россия, Псковская область, Гдовский район, село Кануновщина	0101000020E6100000E8BD310400DF3B407A51BB5F056C4D40
74714	3	32	596	49112	\N	\N	58.934963000000003	д.Залесье, Дом культуры		0101000020E61000005EDA70581A103C402BFC19DEAC774D40
75048	3	32	596	28860	58410	\N	58.740941999999997	г.Гдов, ул.Ленина, д.14		0101000020E6100000C47C7901F6D13B40CD1DFD2FD75E4D40
75050	3	32	596	28860	58355	\N	58.740941999999997	г.Гдов, ул.Колхозная, д.54		0101000020E6100000C47C7901F6D13B40CD1DFD2FD75E4D40
75049	3	32	596	28860	58413	\N	58.740941999999997	г.Гдов, ул.Карла Маркса, д.53		0101000020E6100000C47C7901F6D13B40CD1DFD2FD75E4D40
75055	3	32	596	46885	\N	\N	58.957408000000001	д.Вейно	Россия, Псковская область, Гдовский район, село Вейно	0101000020E6100000DA54DD239B1B3C40E27668588C7A4D40
75054	3	32	596	46885	\N	\N	58.957408000000001	д. Вейно,помещение Вейнскогосельского клуба	Россия, Псковская область, Гдовский район, село Вейно	0101000020E6100000DA54DD239B1B3C40E27668588C7A4D40
74990	3	32	537	57418	\N	\N	56.332042849302098	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Переслегинская волость"", пос. Нагорный, Лицей № 24"	Россия, Псковская область, Великолукский район	0101000020E61000005CE509849D763E40D0EE9062802A4C40
74980	3	32	537	57428	\N	\N	56.161625468255103	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Купуйская волость"", д. Колюбаки, Мишагинский ФАП"	Россия, Псковская область, Великолукский район	0101000020E610000005A73E90BC973E40A69BC420B0144C40
75005	3	32	537	52499	\N	\N	56.347783999999997	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Шелковская волость"", д. Шелково, Администрация сельского поселения"		0101000020E6100000768A5583309F3E403909A52F842C4C40
74999	3	32	537	52489	\N	\N	56.687223000000003	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Черпесская волость"", д. Черпесса, Дом культуры"		0101000020E61000001DE90C8CBCA43E408E075BECF6574C40
74998	3	32	537	57433	\N	\N	56.173890763962298	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Успенская волость"", д. Федорково, Плаксинский ФАП"	Россия, Псковская область, Великолукский район, село Федорково	0101000020E6100000996379573DB03E40CC086F0F42164C40
74997	3	32	537	52485	\N	\N	56.091009999999997	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Успенская волость"", д. Успенское, Администрация сельского поселения"		0101000020E6100000BA66F2CD36C33E40F2CD3637A60B4C40
75147	3	32	543	59089	\N	\N	56.897171614652102	д.Кошелево, помещение клуба, д.30 А	Россия, Псковская область, Бежаницкий район, село Кошелево	0101000020E6100000F9D9C87553D23D4086713788D6724C40
74995	3	32	537	52484	\N	\N	56.019258999999998	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Пореченская волость"", д. Урицкое, Дом культуры"		0101000020E61000000A83328D26933E40AB93331477024C40
74996	3	32	537	57445	\N	\N	56.035859000000002	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Пореченская волость"", д. Троица, школа"	Россия, Псковская область, Великолукский район, село Троица	0101000020E6100000F450DB8651AC3E403622180797044C40
74976	3	32	537	25604	\N	\N	56.519734	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Букровская волость"", пос. Тарасы, Библиотека"		0101000020E61000001781B1BE81F13E40444FCAA486424C40
75001	3	32	537	52494	\N	\N	56.326717000000002	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Шелковская волость"", д. Суханово, Сухановский ФАП"		0101000020E61000004CC5C6BC8EAC3E400C06D7DCD1294C40
75006	3	32	537	58954	\N	\N	56.334807332580397	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Шелковская волость"", пос. Мелиораторов, Детский сад ""Ленок"""	Россия, Псковская область, Великолукский район, село Рыжково	0101000020E610000026732CEFAAA33E4066BCADF4DA2A4C40
74977	3	32	537	57405	\N	\N	56.392326460372402	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Горицкая волость"", д. Русаново, Администрация сельского поселения"	Россия, Псковская область, Великолукский район, село Русаново	0101000020E6100000F84F3750E05D3E406CAF05BD37324C40
74994	3	32	537	57403	\N	\N	56.095047000000001	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Пореченская волость"", д. Поречье, Администрация сельского поселения"	Россия, Псковская область, Великолукский район, село Поречье	0101000020E610000057EE0566857A3E409D4A06802A0C4C40
74992	3	32	537	57403	\N	\N	56.0949989784705	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Пореченская волость"", д. Поречье, Дом культуры"	Россия, Псковская область, Великолукский район, село Поречье	0101000020E6100000EA7B0DC171793E408C135FED280C4C40
74973	3	32	537	52436	\N	\N	56.133437000000001	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Борковская волость"", д. Полибино, Полибинский Дом культуры"		0101000020E61000005072874D64663E40C689AF7614114C40
75000	3	32	537	57422	\N	\N	56.325254999999999	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Шелковская волость"", д. Першино, школа"	Россия, Псковская область, Великолукский район, село Першино	0101000020E61000007CF0DAA50DB73E4024EEB1F4A1294C40
74989	3	32	537	52467	\N	\N	56.384345000000003	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Переслегинская волость"", д. Переслегино, Дом культуры"		0101000020E61000003C139A2496703E40C9B08A3732314C40
74988	3	32	537	52467	\N	\N	56.384345000000003	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Переслегинская волость"", д. Переслегино, Администрация сельского поселения"		0101000020E61000003C139A2496703E40C9B08A3732314C40
75034	3	32	537	46456	58484	\N	56.493422000000002	деревня Марьино, Центральная, дом 5		0101000020E6100000ACE28DCC239B3E403F90BC73283F4C40
74991	3	32	537	52473	\N	\N	56.377552000000001	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Переслегинская волость"", д. Майкино, Детский сад ""Росинка"""		0101000020E61000004C50C3B7B07E3E400B45BA9F53304C40
74985	3	32	537	52464	\N	\N	56.332191999999999	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Лычевская волость"", д. Лычево, администрация сельского поселения"		0101000020E6100000EF8CB62A899C3E4015FF7744852A4C40
74984	3	32	537	57396	\N	\N	56.257204085651402	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Лычевская волость"", д. Липец, бывшая школа"	Россия, Псковская область, Великолукский район, село Липец	0101000020E6100000030B60CAC0AD3E404033880FEC204C40
74979	3	32	537	52451	\N	\N	56.227926562263498	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Купуйская волость"", д. Купуй, Администрация сельского поселения"		0101000020E61000008DB800344A833E400D7041B62C1D4C40
75035	3	32	537	28254	\N	\N	55.962547999999998	"Псковская область, Муниципальное образование ""Струго-Красненский район"", Муниципальное образование сельское поселение ""Марьинская волость"", деревня Костелево"	Россия, Псковская область, Великолукский район, село Костелево	0101000020E6100000CB2F8331227D3E40446ADAC534FB4B40
74987	3	32	537	52468	\N	\N	56.487836000000001	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Марьинская волость"", д. Карцево, Администрация сельского поселения"	Россия, Псковская область, Великолукский район, село Карцево	0101000020E6100000815A0C1EA69D3E40DEE7F868713E4C40
75134	3	32	537	48419	\N	\N	56.463554999999999	"д.Иваново, здание Администрации с.п. ""Ивановская волость"", д.31"		0101000020E6100000AE2AFBAE08423E40DA722EC5553B4C40
74978	3	32	537	48419	\N	\N	56.463554999999999	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Горицкая волость"", д. Иваново, школа"	Россия, Псковская область, Великолукский район, село Иваново	0101000020E6100000AE2AFBAE08423E40DA722EC5553B4C40
74983	3	32	537	25903	\N	\N	56.319848999999998	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Лычевская волость"", пос. Дубрава-1, школа"		0101000020E6100000D044D8F0F4963E404354E1CFF0284C40
74982	3	32	537	25849	\N	\N	56.296474000000003	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Лычевская волость"", пос. Дорожный, ДЭП № 276"		0101000020E6100000CAE2FE23D3813E40A20E2BDCF2254C40
74986	3	32	537	57444	\N	\N	56.393063111245297	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Марьинская волость"", д. Демидово, школа"	Россия, Псковская область, Великолукский район, село Демидово	0101000020E6100000D8B8FE5D9FA13E4042226DE34F324C40
75170	3	32	537	49048	\N	\N	56.127958999999997	д. Глазуново, Здание дома культуры	Россия, Псковская область, Великолукский район, село Глазуново	0101000020E61000000A9DD7D825723E404B1DE4F560104C40
75007	3	32	537	57424	\N	\N	56.3625307174065	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Шелковская волость"", д. Великополье, ФАП"	Россия, Псковская область, Великолукский район, село Великополье	0101000020E6100000710168942ED13E40A164726A672E4C40
74981	3	32	537	52453	\N	\N	56.283045000000001	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Лычевская волость"", д. Булынино, Дом культуры"		0101000020E61000008A592F8672863E40EE258DD13A244C40
74974	3	32	537	52439	\N	\N	56.482225	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Букровская волость"", д. Букрово-2, Администрация сельского поселения"		0101000020E610000006D50627A2CB3E4024287E8CB93D4C40
74972	3	32	537	57395	\N	\N	56.0791549129789	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Борковская волость"", д.Борки, администрация сельского поселения"	Россия, Псковская область, Великолукский район, село Борки	0101000020E6100000814067D2A63E3E404E2844C0210A4C40
75004	3	32	537	57402	\N	\N	56.364598945977001	"Псковская область, Муниципальное образование ""Великолукский район"", Муниципальное образование сельское поселение ""Шелковская волость"", д. Баландино, Баландинский ФАП"	Россия, Псковская область, Великолукский район, село Баландино	0101000020E6100000CB68E4F38A9B3E40C093162EAB2E4C40
74835	3	32	543	18637	\N	\N	57.138798999999999	"Псковская область, Бежаницкий район, деревня Шилово, помещение Администрации с/п ""Добрывичская волость"""	Россия, Псковская область, Бежаницкий район, село Шилово	0101000020E61000005F605628D2E53D40D7DB662AC4914C40
74834	3	32	543	18628	58493	\N	57.282839000000003	Псковская область, Бежаницкий район, село Чихачёво, Первомайская, 15		0101000020E6100000179D2CB5DEE73D4045847F1134A44C40
74833	3	32	543	18558	58521	\N	57.046337000000001	Псковская область, Бежаницкий район, деревня Цевло, Советская, 1		0101000020E61000008C14CAC2D7473E4021CCED5EEE854C40
74831	3	32	543	18448	\N	\N	57.216557999999999	"Псковская область, Бежаницкий район, деревня Ублиска, помещение Администрации с/п ""Ашевское"""	Россия, Псковская область, Бежаницкий район, село Ублиска	0101000020E6100000A10F96B1A1C33D40F5D72B2CB89B4C40
75003	3	32	543	45791	\N	\N	56.924937999999997	д.Спицино	Россия, Псковская область, Бежаницкий район, село Спицино	0101000020E6100000C9CA2F8331123E40F0694E5E64764C40
74768	3	32	543	15333	58544	\N	57.423436000000002	дер.Сосонка, Центральная, 1		0101000020E6100000695721E527FD3D407BF99D2633B64C40
74832	3	32	543	18492	\N	\N	57.066132000000003	"Псковская область, Бежаницкий район, деревня Сапрыгино, помещение конторы ОАО ""Ударник"""	Россия, Псковская область, Бежаницкий район, село Сапрыгино	0101000020E6100000876D8B321BC03D400B9C6C0377884C40
74830	3	32	543	18372	\N	\N	56.959833000000003	"Псковская область, Бежаницкий район, деревня Махново, помещение Администрации с/п ""Пореченское"""	Россия, Псковская область, Бежаницкий район, село Махново	0101000020E6100000193735D07CD23D40904FC8CEDB7A4C40
74829	3	32	543	18333	58492	\N	57.012498999999998	Псковская область, Бежаницкий район, деревня Лющик, Октябрьская, 9		0101000020E6100000FC7266BB42E73D40C91D369199814C40
74828	3	32	543	18278	58512	\N	56.772807999999998	Псковская область, Бежаницкий район, село Кудеверь, Школьная, 4-а		0101000020E61000007A54FCDF11693D40280B5F5FEB624C40
63488	3	31	\N	1808	58075	\N	58.541156000000001	город Великий Новгород, ул.Менделеева, д.3		0101000020E610000052EFA99CF6403F4060048D9944454D40
75074	3	32	543	57459	\N	\N	57.0219390647975	"деревня Заполье, здание Администрации сельского поселения ""Запольская волость"	Россия, Псковская область, Бежаницкий район, село Заполье	0101000020E61000002096CD1C92EE3D40E4C0ABE5CE824C40
74826	3	32	543	18196	\N	\N	57.217143	"Псковская область, Бежаницкий район, деревня Добрывичи, помещение Администрации с/п ""Добрывичская волость"""	Россия, Псковская область, Бежаницкий район, село Добрывичи	0101000020E6100000A35C1ABFF0DE3D4015C78157CB9B4C40
74824	3	32	543	18092	\N	\N	56.916103999999997	"Псковская область, Бежаницкий район, деревня Дворцы, помещение Администрации с/п ""Пореченское"""	Россия, Псковская область, Бежаницкий район, село Дворцы	0101000020E6100000BA84436FF1CC3D400DDE57E542754C40
74800	3	32	543	16908	\N	\N	57.346761000000001	деревня Гривы, помещение школы	Россия, Псковская область, Бежаницкий район, поселок Гривы	0101000020E61000003D44A33B88013E409E4319AA62AC4C40
74823	3	32	543	18059	\N	\N	57.090274000000001	"Псковская область, Бежаницкий район, деревня Гора, помещение конторы Горского отделения ОАО ""Ударник"""	Россия, Псковская область, Бежаницкий район, село Гора	0101000020E6100000AD6A494739D43D40EDD632198E8B4C40
75002	3	32	543	45773	\N	\N	56.988805999999997	"деревня Быково, здание СХПК ""Поляна"""	Россия, Псковская область, Бежаницкий район, село Быково	0101000020E610000098874CF910C43D40560BEC31917E4C40
74821	3	32	543	17910	58338	\N	56.991056999999998	Псковская область, поселок Бежаницы, Смольная, 16		0101000020E6100000033E3F8C10E63D4066BCADF4DA7E4C40
74822	3	32	543	17910	58404	\N	56.991056999999998	Псковская область, поселок Бежаницы, Лары Михеенко, 20-а		0101000020E6100000033E3F8C10E63D4066BCADF4DA7E4C40
74820	3	32	543	17910	58379	\N	56.991056999999998	Псковская область, поселок Бежаницы, Зелёная, 16		0101000020E6100000033E3F8C10E63D4066BCADF4DA7E4C40
74819	3	32	543	17847	\N	\N	56.676977999999998	"Псковская область, Бежаницкий район, деревня Бардово, помещение Администрации с/п ""Кудеверская волость"""	Россия, Псковская область, Бежаницкий район, село Бардово	0101000020E6100000780E65A88A5D3D40450E1137A7564C40
74818	3	32	543	17788	\N	\N	57.112065000000001	"Псковская область, Бежаницкий район, село Ашево, помещение Администрации с/п ""Ашевское"""	Россия, Псковская область, Бежаницкий район, село Ашево	0101000020E61000000E32C9C859BC3D405C035B25588E4C40
74817	3	32	543	17757	\N	\N	56.880130000000001	Псковская область, Бежаницкий район, деревня Аполье, помещение сельского клуба	Россия, Псковская область, Бежаницкий район, село Аполье	0101000020E6100000ADBD4F55A1E53D403F1D8F19A8704C40
63545	3	31	\N	146	\N	\N	58.515957999999998	"Новгородский район , деревня Шолохово, МАУ """"Шолоховский сельский дом культуры"""""""	Россия, Новгородская область, деревня Шолохово	0101000020E6100000272EC72B105D3F40060E68E90A424D40
63615	3	31	1083	\N	15850	\N	58.6443572841264	Пестовский муниципальный район, ул. Центральная, д.68, здание муниципального бюджетного дошкольного образовательного учреждения детского сада д. Брякуново.	Россия, Новгородская область, Пестовский район	0101000020E610000097E4805D4DD841406EF9484A7A524D40
63560	3	31	\N	15086	4231	\N	58.578995999999997	Новгородский район , деревня Сырково, Пролетарская, 7А	Россия, Новгородская область, деревня Сырково, улица Пролетарская, 7а	0101000020E6100000618C48145A3A3F40E5417A8A1C4A4D40
63707	3	31	\N	57344	57985	\N	57.992184000000002	г.Старая Русса, пер.Пищевиков, 8		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63704	3	31	\N	57344	58038	\N	57.995728012969003	г.Старая Русса, Ленинградская, 11	Россия, Р-51 шоссе	0101000020E61000002CBB6070CD593F4012DBDD0374FF4C40
63705	3	31	\N	57344	58037	\N	57.997995290822203	г.Старая Русса, Клары Цеткин, 41	Россия, Новгородская область, Старорусский район, Старая Русса	0101000020E610000072FA7ABE66593F402849D74CBEFF4C40
63693	3	31	\N	57344	58040	\N	57.991149583308598	г.Старая Русса, Карла Маркса, 24	Россия, Р-48 шоссе	0101000020E6100000B4CBB73EAC5F3F4017B7D100DEFE4C40
63700	3	31	\N	57344	57993	\N	57.992184000000002	г.Старая Русса, Карла Либкнехта, 22		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63695	3	31	\N	57344	58113	\N	57.993489077101103	г.Старая Русса, Володарского,д.22	Россия, Р-48 шоссе	0101000020E6100000CCF10A444F5E3F40C6F7C5A52AFF4C40
63690	3	31	\N	57344	58113	\N	57.992184000000002	г.Старая Русса, Володарского, 10		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63661	3	31	\N	57350	58118	\N	58.118951000000003	г.Сольцы, просп.Советский, д.11		0101000020E6100000259012BBB6533E40CB694FC9390F4D40
63551	3	31	\N	1338	\N	\N	58.627305999999997	Новгородский район , деревня Слутка, 44	Россия, Новгородская область, деревня Слутка	0101000020E6100000F52F49658A6D3F40D34A21904B504D40
63634	3	31	\N	57345	58032	\N	58.593733999999998	г. Пестово, ул. Устюженское шоссе, д. 5, здание муниципального автономного  общеобразовательного учреждения «Средняя общеобразовательная школа № 6 г.Пестово».		0101000020E61000009E95B4E21BE84140FA42C879FF4B4D40
63630	3	31	\N	57345	58032	\N	58.599735881945897	г. Пестово, ул.Устюженское шоссе, д. 27, здание муниципального автономного учреждения культуры «Центр народной культуры и досуга имени А.У.Барановского» ( ДК «Энергетик»).		0101000020E6100000AF601BF164E94140EF1D3526C44C4D40
63636	3	31	\N	57345	57987	\N	58.593733999999998	г. Пестово, ул. Новгородская, д. 77,  здание муниципального автономного  общеобразовательного учреждения  «Средняя общеобразовательная школа № 1 с углубленным изучением биологии и русского языка имени Н.И. Кузнецова» г. Пестово.		0101000020E61000009E95B4E21BE84140FA42C879FF4B4D40
63476	3	31	\N	1808	58123	\N	58.524591000000001	город Великий Новгород, ул.Людогощая, д.4		0101000020E6100000C43F6CE9D1443F40526342CC25434D40
63505	3	31	\N	1808	58079	\N	58.530709000000002	город Великий Новгород, ул.Ломоносова, д.22а		0101000020E61000000188BB7A153D3F40B058C345EE434D40
63637	3	31	\N	57345	57989	\N	58.586712006311103	г. Пестово, ул. Боровичская, д. 92, административное здание филиала общества с ограниченной ответственностью «Межмуниципальное предприятие  жилищно-коммунального хозяйства Новжилкоммунсервис» «Жилищно-коммунальное хозяйство Пестовского района».	Россия, Р-8 шоссе	0101000020E61000005E4D9EB29AE44140DB15FA60194B4D40
63576	3	31	\N	57347	58029	\N	58.396171000000002	г.Окуловка, ул.Театральная, д.3		0101000020E61000006C0723F609A64040D34F38BBB5324D40
63573	3	31	\N	57347	58012	\N	58.396171000000002	г.Окуловка, ул.Советская, д.32А		0101000020E61000006C0723F609A64040D34F38BBB5324D40
63571	3	31	\N	57347	58028	\N	58.396171000000002	г.Окуловка, ул.Николая Николаева, д.34		0101000020E61000006C0723F609A64040D34F38BBB5324D40
63414	3	31	\N	57343	58116	\N	58.845016999999999	г.Малая Вишера, ул.Карла Маркса, д.18		0101000020E6100000967B8159A11C404032C85D84296C4D40
63557	3	31	\N	14948	4201	\N	58.551355999999998	Новгородский район , деревня Григорово, Центральная, 6	Россия, Новгородская область, деревня Григорово, улица Центральная, 6	0101000020E610000022AAF06778373F40083A5AD592464D40
63520	3	31	\N	1808	3698	\N	58.507435000000001	город Великий Новгород, ул.Псковская, д.50, корп.2	Россия, Новгородская область, Великий Новгород, улица Псковская, 50к2	0101000020E61000009A42E73576393F4042EC4CA1F3404D40
63496	3	31	\N	1808	3384	\N	58.544946000000003	город  Великий Новгород, ул.Коровникова, д.9, корп.1	Россия, Новгородская область, Великий Новгород, улица Коровникова, 9к1	0101000020E61000007BBE66B96C383F40030B60CAC0454D40
63485	3	31	\N	1808	3224	\N	58.570587000000003	город Великий Новгород, Большая Санкт-Петербургская ул, д.161	Россия, Новгородская область, Великий Новгород, улица Большая Санкт-Петербургская, 161	0101000020E6100000FA997ADD22483F40EA42ACFE08494D40
63475	3	31	\N	1808	3143	\N	58.520437000000001	город Великий Новгород, Дворцовая ул, д.3	Россия, Новгородская область, Великий Новгород, улица Большая Дворцовая, 3	0101000020E6100000AF963B33C1483F406E50FBAD9D424D40
63528	3	31	\N	1808	58322	\N	58.618253000000003	город Великий Новгород,  микрорайон Кречевицы, д.79		0101000020E61000003C4CFBE6FE663F40B3D30FEA224F4D40
63487	3	31	\N	1808	58084	\N	58.618179813906799	город Великий Новгород, микрорайон Кречевицы, д.79		0101000020E6100000836C59BE2E673F404985B185204F4D40
63466	3	31	\N	1808	58309	\N	58.539873	"город Великий Новгород, Антоново, ГУ ФГБОУ ВПО """"НГУ им.Я.Мудрого"""""""		0101000020E6100000B537F8C2644E3F40287FF78E1A454D40
63478	3	31	\N	1808	58069	\N	58.528734999999998	город Великий Новгород, Яковлева ул, д.15		0101000020E61000003B55BE6724463F4012A0A696AD434D40
63484	3	31	\N	1808	58070	\N	58.563191000000003	город Великий Новгород, ул.Щусева, д.12, корп.2		0101000020E610000095B88E71C5493F40663387A416484D40
63480	3	31	\N	1808	58071	\N	58.538764999999998	город Великий Новгород, Чудовская ул, д.3		0101000020E6100000DC63E94317443F405E9D6340F6444D40
63514	3	31	\N	1808	58062	\N	58.522283999999999	город Великий Новгород, Чудинцева ул, д.3		0101000020E6100000151DC9E53F443F40AE9CBD33DA424D40
63473	3	31	\N	1808	58068	\N	58.523660999999997	город Великий Новгород, ул.Федоровский Ручей, д. 19а		0101000020E610000097CADB114E4B3F406798DA5207434D40
63516	3	31	\N	1808	58063	\N	58.514567	город Великий Новгород, Троицкая ул, д.13		0101000020E6100000D6E1E82ADD453F40E84CDA54DD414D40
63469	3	31	\N	1808	58048	\N	58.536575999999997	город Великий Новгород, Студенческая ул, д.19		0101000020E6100000187959130B4C3F40C4E8B985AE444D40
63467	3	31	\N	1808	58048	\N	58.538234000000003	город Великий Новгород, Студенческая ул, д.5/1		0101000020E610000025E659492B4A3F4032CC09DAE4444D40
63497	3	31	\N	1808	58065	\N	58.543089557187798	город  Великий Новгород, ул.Свободы, д.14, корп.2		0101000020E61000006BF3FFAA233B3F406F641EF983454D40
63493	3	31	\N	1808	58065	\N	58.543011	город Великий Новгород, ул.Свободы, д.14, корп.2		0101000020E610000082E7DEC3253B3F40232F6B6281454D40
63490	3	31	\N	1808	58065	\N	58.541358000000002	город Великий Новгород, ул.Свободы, д.6		0101000020E61000001958C7F1433D3F40C8B60C384B454D40
63474	3	31	\N	1808	58045	\N	58.520629	город Великий Новгород, ул.Рогатица, д.27/56		0101000020E610000079AF5A99F04B3F40B22C98F8A3424D40
63463	3	31	\N	1808	58074	\N	58.541775999999999	город Великий Новгород, ул.Рахманинова, д.7		0101000020E61000005567B5C01E4F3F40FCE07CEA58454D40
63522	3	31	\N	1808	58055	\N	58.522889999999997	город Великий Новгород, ул.Псковская, д.1		0101000020E6100000B554DE8E70423F40E5B33C0FEE424D40
63519	3	31	\N	1808	58055	\N	58.511158999999999	город Великий Новгород, ул Псковская, д.44, корп.2		0101000020E6100000971AA19FA93B3F402D077AA86D414D40
63518	3	31	\N	1808	58055	\N	58.511158999999999	город Великий Новгород, ул.Псковская, д.44, корп.2		0101000020E6100000971AA19FA93B3F402D077AA86D414D40
63517	3	31	\N	1808	58059	\N	58.518062999999998	город Великий Новгород, Прусская ул, д.24		0101000020E6100000685C381092413F4042226DE34F424D40
63515	3	31	\N	1808	58059	\N	58.520023000000002	город Великий Новгород, Прусская ул, д.4		0101000020E6100000E78BBD175F443F407B15191D90424D40
63465	3	31	\N	1808	58053	\N	58.540911999999999	город Великий Новгород, Парковая ул, д.7		0101000020E6100000F9F4D896014B3F40C901BB9A3C454D40
63529	3	31	\N	1808	58060	\N	58.521005000000002	город Великий Новгород, ул.Октябрьская д.14		0101000020E61000004030478FDF3F3F40B806B64AB0424D40
63524	3	31	\N	1808	58060	\N	58.528115	город Великий Новгород, ул.Октябрьская, д.30		0101000020E61000001DAD6A4947413F4076C3B64599434D40
63521	3	31	\N	1808	58060	\N	58.521005000000002	город Великий Новгород, ул.Октябрьская, д.14		0101000020E61000004030478FDF3F3F40B806B64AB0424D40
63525	3	31	\N	1808	58078	\N	58.527673	город Великий Новгород, Новолучанская ул, д.17		0101000020E61000008AE6012CF2433F40B9FDF2C98A434D40
63477	3	31	\N	1808	58078	\N	58.528308000000003	город Великий Новгород, Новолучанская ул, д.27		0101000020E6100000A6811FD5B0433F408B1BB7989F434D40
63486	3	31	\N	1808	58043	\N	58.580155598986003	город Великий Новгород, Новгородская ул, д.6		0101000020E6100000710514EAE94F3F40024A438D424A4D40
63509	3	31	\N	1808	58077	\N	58.524036000000002	город Великий Новгород, Нехинская ул, д.24		0101000020E6100000EBC9FCA36F3E3F409DF6949C13434D40
63470	3	31	\N	1808	58066	\N	58.533090000000001	город Великий Новгород, Московская ул, д.30		0101000020E6100000105A0F5F264E3F408EE9094B3C444D40
63500	3	31	\N	1808	58079	\N	58.527453000000001	город Великий Новгород, ул.Ломоносова, д.30		0101000020E61000005D70067FBF3C3F40AB96749483434D40
63489	3	31	\N	1808	58079	\N	58.541254000000002	город Великий Новгород, ул.Ломоносова, д.7а		0101000020E6100000C4B29943523F3F40236AA2CF47454D40
63512	3	31	\N	1808	58046	\N	58.536136616749502	город Великий Новгород, ул.Кочетова, д.23, корп.2	Россия, Новгородская область, Великий Новгород, улица Кочетова, 23	0101000020E61000003FE603029D393F4078962023A0444D40
63511	3	31	\N	1808	58046	\N	58.536256999999999	город  Великий Новгород, ул.Кочетова, д.23, корп.2		0101000020E6100000D655815A0C3A3F4023A0C211A4444D40
63510	3	31	\N	1808	58046	\N	58.527419999999999	город  Великий Новгород, ул.Кочетова, д.28		0101000020E6100000586FD40AD3373F40CFA0A17F82434D40
63508	3	31	\N	1808	58046	\N	58.527766999999997	город  Великий Новгород, ул.Кочетова, д.35, корп.4		0101000020E6100000630CACE3F8393F403A747ADE8D434D40
63506	3	31	\N	1808	58046	\N	58.534419999999997	город Великий Новгород, ул.Кочетова, д.29, корп.3		0101000020E610000004E78C28ED393F40062AE3DF67444D40
63501	3	31	\N	1808	58046	\N	58.543875	город Великий Новгород, ул.Кочетова, д.5, корп.4		0101000020E61000000B444FCAA43A3F40560E2DB29D454D40
63527	3	31	\N	1808	58131	\N	58.532409000000001	город Великий Новгород, ул.Космонавтов, д.28		0101000020E61000005D6BEF5355403F404C8C65FA25444D40
63513	3	31	\N	1808	58050	\N	58.540883000000001	город Великий Новгород, ул.Коровникова, д.15, корп.2		0101000020E6100000C190D5AD9E373F402FFB75A73B454D40
63495	3	31	\N	1808	58050	\N	58.540883000000001	город  Великий Новгород, ул.Коровникова, д.15, корп.2		0101000020E6100000C190D5AD9E373F402FFB75A73B454D40
63494	3	31	\N	1808	58050	\N	58.543174999999998	город Великий Новгород, ул.Коровникова, д.11		0101000020E6100000D7A6B1BD16383F409D8026C286454D40
63507	3	31	\N	1808	58051	\N	58.537247999999998	город  Великий Новгород, ул.Зелинского, д.30		0101000020E6100000F46BEBA7FF3C3F40B3EBDE8AC4444D40
63504	3	31	\N	1808	58051	\N	58.534331000000002	город Великий Новгород, ул.Зелинского, д.15		0101000020E61000004C1AA375543D3F40971E4DF564444D40
63503	3	31	\N	1808	58051	\N	58.534799999999997	город Великий Новгород, ул.Зелинского, д.6		0101000020E6100000DCF63DEAAF3F3F404DF38E5374444D40
63492	3	31	\N	1808	58051	\N	58.538572000000002	город  Великий Новгород, ул.Зелинского, д.42		0101000020E6100000C5E23785953A3F404A4563EDEF444D40
63464	3	31	\N	1808	58082	\N	58.543016000000001	город Великий Новгород, ул.Державина, д.6		0101000020E6100000B30C71AC8B4F3F40359A5C8C81454D40
63526	3	31	\N	1808	58085	\N	58.535322000000001	город Великий Новгород, ул.Германа, д.31		0101000020E61000008A5759DB14433F40276A696E85444D40
63523	3	31	\N	1808	58064	\N	58.524811999999997	город Великий Новгород, ул.Великолукская, д.17		0101000020E61000008F56B5A4A3403F403046240A2D434D40
63479	3	31	\N	1808	58073	\N	58.528077000000003	город Великий Новгород, Великая ул, д.10		0101000020E6100000E272BC02D1473F408962F20698434D40
63483	3	31	\N	1808	58080	\N	58.560575999999998	город Великий Новгород, Большая Санкт-Петербургская ул, д.118, корп.3		0101000020E610000073BD6DA642483F40147651F4C0474D40
63482	3	31	\N	1808	58080	\N	58.553722	город Великий Новгород, Большая Санкт-Петербургская ул, д.94		0101000020E6100000E17A14AE47453F40B189CC5CE0464D40
63481	3	31	\N	1808	58080	\N	58.540759296545097	город Великий Новгород, Большая Санкт-Петербургская ул, д.46	Россия, Новгородская область, Великий Новгород, улица Большая Санкт-Петербургская, 44	0101000020E61000005A80B6D5AC433F404302469737454D40
63472	3	31	\N	1808	58057	\N	58.528856389302398	город Великий Новгород, Большая Московская ул, д.37/9		0101000020E6100000035E66D8284B3F408D25AC8DB1434D40
63471	3	31	\N	1808	58057	\N	58.531036999999998	город Великий Новгород, Большая Московская ул, д.70		0101000020E610000065C57075004C3F40A4FB3905F9434D40
63468	3	31	\N	1808	58057	\N	58.538366000000003	город Великий Новгород, Большая Московская ул, д.53, корп.2		0101000020E610000047AAEFFCA24C3F40A1A3552DE9444D40
63461	3	31	\N	1808	58083	\N	58.570864	город Великий Новгород, Береговая ул, д.48,  корп.3		0101000020E61000003C16DBA4A2553F405C3B511212494D40
63499	3	31	\N	1808	3338	\N	58.548191000000003	город Великий Новгород, просп.Александра Корсунова, д.38	Россия, Новгородская область, Великий Новгород, Александра Корсунова проспект, 38	0101000020E6100000C40B2252D33A3F40147B681F2B464D40
63498	3	31	\N	1808	3338	\N	58.548191000000003	город  Великий Новгород, просп.Александра Корсунова, д.38	Россия, Новгородская область, Великий Новгород, Александра Корсунова проспект, 38	0101000020E6100000C40B2252D33A3F40147B681F2B464D40
63491	3	31	\N	1808	3338	\N	58.547162	город  Великий Новгород, просп.Александра Корсунова, д.36, корп.3	Россия, Новгородская область, Великий Новгород, Александра Корсунова проспект, 36к3	0101000020E6100000F31FD26F5F3B3F4096CE876709464D40
63462	3	31	\N	1808	58067	\N	58.560938	город Великий Новгород, ул.20-го Января, д.14		0101000020E6100000670C738236513F40B58AFED0CC474D40
63320	3	31	\N	57346	58030	\N	57.977591996088101	г.Валдай, просп.Комсомольский, д.19/21	Россия, Р-8 шоссе	0101000020E6100000C59272F739A04040666A12BC21FD4C40
63316	3	31	\N	57346	58047	\N	57.979816999999997	г.Валдай, Студгородок, учебный корпус агротехнического техникума		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63331	3	31	\N	57346	58143	\N	57.979816999999997	Валдайский р-он , г.Валдай-5, ул.Озерная, д.19		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63325	3	31	\N	57346	58027	\N	57.979816999999997	г.Валдай, ул.Молотковская, д.2	Россия, Р-8 шоссе	0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63323	3	31	\N	57346	58112	\N	57.976776924296502	г.Валдай, просп.Комсомольский, д.17	Россия, Р-8 шоссе	0101000020E61000008F006E162FA04040143E5B0707FD4C40
63319	3	31	\N	57346	58021	\N	57.979816999999997	г.Валдай, просп.Васильева, д.32а		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63270	3	31	\N	57342	58008	\N	58.382935000000003	г.Боровичи, пл.им.Кирова, 9		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63282	3	31	\N	57342	58018	\N	58.382935000000003	г.Боровичи, пл.Спасская, 1		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63268	3	31	\N	57342	58090	\N	58.382935000000003	г.Боровичи, пл.Володарского, 15		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63278	3	31	\N	57342	58106	\N	58.382935000000003	г.Боровичи, Школьный Бульвар, 10		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63770	3	31	371	57367	58317	\N	58.2824392070467	Шимский район ,жд.ст.Уторгош, ул.Пионерская, д.49а	Россия, Новгородская область, Шимский район, село Уторгош	0101000020E61000007D03931B453E3E40B60E0EF626244D40
63771	3	31	371	2159	58240	\N	58.370415999999999	Шимский район ,д.Турская Горка, ул.Молодежная, д.1		0101000020E6100000C4245CC8233C3E4023F59ECA692F4D40
63768	3	31	371	2062	\N	\N	58.295405000000002	Шимский район ,д.Старый Медведь	Россия, Новгородская область, Шимский район, село Старый Медведь	0101000020E610000014B4C9E1937E3E409609BFD4CF254D40
63760	3	31	371	6948	58298	\N	58.162028999999997	Шимский район ,с.Подгощи, ул.Заречная, д.42		0101000020E6100000C55565DF15BD3E407500C45DBD144D40
63765	3	31	371	1904	58257	\N	58.202821	Шимский район ,д.Мшага Ямская, ул.Никольская, д.1		0101000020E6100000FA449E245D973E4094F8DC09F6194D40
63767	3	31	371	2016	\N	\N	58.377509000000003	Шимский район ,д.Менюша, д.98		0101000020E6100000F7AC6BB41CB43E400C79043752304D40
63766	3	31	371	1958	58274	\N	58.302149	Шимский район ,с.Медведь, ул.Театральная, д.2		0101000020E6100000EED11BEE23833E4072C284D1AC264D40
63761	3	31	371	7016	58302	\N	58.098371999999998	Шимский район ,д.Любыни, ул.Солецкая, д.3		0101000020E6100000FA298E03AF9E3E40CA6B2574970C4D40
63762	3	31	371	25077	58196	\N	58.188203000000001	Шимский район ,д.Красный Двор, ул.Центральная, д.19		0101000020E6100000D63730B951A83E402A01310917184D40
63757	3	31	371	6860	58291	\N	58.187207000000001	Шимский район , д.Коростынь, ул.Садовая, д.4		0101000020E6100000EA40D653ABFB3E40884A2366F6174D40
63769	3	31	371	2153	58316	\N	58.343398999999998	Шимский район ,д.Закибье, ул.Новая, д.27		0101000020E610000083177D0569663E40533D997FF42B4D40
63759	3	31	371	24942	\N	\N	58.175618999999998	Шимский район ,д.Горцы, д.25		0101000020E61000003F53AF5B04DE3E4032C7F2AE7A164D40
63773	3	31	371	25595	\N	\N	58.248567999999999	Шимский район ,д.Городище, ул.Шоссейная, д.10	Россия, Новгородская область, Шимский район, село Городище	0101000020E610000099D36531B1E53D40836A8313D11F4D40
63758	3	31	371	6922	58200	\N	58.159461	Шимский район ,д.Веряжа, ул.Центральная, д.23		0101000020E61000004D840D4FAF003F4065FED13769144D40
63764	3	31	371	57370	58320	\N	58.200732903386402	Шимский район ,д.Бор, ул.Сосновая, д.6	Россия, Новгородская область, Шимский район, село Бор	0101000020E6100000912C6002B7AA3E402E1D739EB1194D40
63772	3	31	371	2263	58264	\N	58.270007	Шимский район ,д.Большая Уторгош, ул.Центральная, д.41		0101000020E610000000732D5A801E3E407558E1968F224D40
63751	3	31	477	24483	41857	\N	59.126052999999999	Новгородская область, Чудовский муниципальный район, городское поселениег.Чудово, ул.Титова, д.10,  помещение МАОУ «Средняя общеобразовательная школа № 1 им.Н.А.Нек-расова»,	Россия, Новгородская область, Чудовский район, Чудово	0101000020E61000006C054D4BACB03F400648348122904D40
63754	3	31	477	24483	41864	\N	59.126052999999999	г.Чудово, ул.Новопарковая,    д.1-а, помещение местного отделения ДОСААФ России Чудовского района Новгородской области		0101000020E61000006C054D4BACB03F400648348122904D40
63753	3	31	477	24483	41859	\N	59.126052999999999	Новгородская область, Чудовский муниципальный район, городское поселениег.Чудово, ул.Некрасова, д.29-а,  помещение МБУ «Межпоселенческое coциально-культурное объединение «Светоч»	Россия, Новгородская область, Чудовский район, Чудово	0101000020E61000006C054D4BACB03F400648348122904D40
63752	3	31	477	24483	41859	\N	59.126052999999999	г.Чудово, ул.Некрасова, д.19,  помещение МАОУ ДОД «Дом детского творчества»		0101000020E61000006C054D4BACB03F400648348122904D40
63756	3	31	477	24483	41869	\N	59.126052999999999	г.Чудово, Малый переулок, д.9,  помещение МАОУ «Средняя общеобразовательная школа № 4»		0101000020E61000006C054D4BACB03F400648348122904D40
63755	3	31	477	24483	41867	\N	59.126052999999999	г.Чудово, ул.Замкова, д.1, помещение МАОУ «Средняя общеобразовательная школа № 4		0101000020E61000006C054D4BACB03F400648348122904D40
63750	3	31	477	24483	41851	\N	59.126052999999999	г.Чудово, Базовский переулок, д.1, помещение ООО «Чудовское АТП»		0101000020E61000006C054D4BACB03F400648348122904D40
63749	3	31	477	24470	58290	\N	59.116802	Чудовский район, с.Успенское,  ул.Советская, д.3, помещение Администрации Успенского сельского поселения,		0101000020E6100000A3CD716E13A63F40BF0D315EF38E4D40
63746	3	31	477	4981	58242	\N	58.989085000000003	Чудовский район, д.Трегубово, ул.Школьная, д.6, помещение МАОУ «Средняя общеобразовательная школа» д.Трегубово,		0101000020E61000007575C7629B8C3F406AFB57569A7E4D40
63741	3	31	477	24063	58222	\N	59.023539	Чудовский район, д.Суворовка, ул.Советская, д.14, помещение отдела по работе с населением Администрации Грузинского сельского поселения		0101000020E6100000600322C495DB3F401C97715303834D40
63745	3	31	477	3195	58241	\N	58.923802000000002	Чудовский район, д.Спасская Полисть, ул.Барсукова, д.51, помещение Спасско-Полистского центра досуга, тел. 43-341).		0101000020E610000003B5183C4C833F405DFDD8243F764D40
63744	3	31	477	24214	58230	\N	58.890647000000001	Чудовский район, д.Селищи, ул.Школьная, д.2, помещение отдела по работе с населением Администрации Трегубовского сельского поселения,		0101000020E6100000B5A4A31CCCAA3F40E8A38CB800724D40
63740	3	31	477	2947	\N	\N	59.115595999999996	Чудовский район, д.Переход,  ул.Центральная, д.17, помещение клуба,	Россия, Новгородская область, Чудовский район, село Переход	0101000020E6100000BFF1B56796E83F4032C687D9CB8E4D40
63742	3	31	477	3045	58313	\N	59.275514244404299	Чудовский район, с.Оскуй, ул.Малая Набережная, д.30, помещение отдела по работе с населением Администрации Грузинского сельского поселения	Россия, Новгородская область, Чудовский район, село Оскуй	0101000020E6100000431D56B8E50B40408ACBF10A44A34D40
63743	3	31	477	3090	58220	\N	59.135292	Чудовский район, пос.Краснофарфорный, ул.Октябрьская, д.1, помещение Администрации Грузинского сельского поселения		0101000020E6100000535BEA20AFDB3F4089B48D3F51914D40
63747	3	31	477	24369	58306	\N	59.255519	Чудовский район, д.Карловка, ул.Центральная, д.2, помещение отдела по работе с населением Администрации Успенского сельского поселения		0101000020E6100000B3412619399F3F40D940BAD8B4A04D40
63748	3	31	477	24381	58293	\N	59.187713955485002	Чудовский район, д.Зуево,  ул.Парковая, д.1, помещение Зуевской сельской библиотеки	Россия, Новгородская область, Чудовский район, село Зуево	0101000020E6100000EFAA07CC438A3F402C80290307984D40
63739	3	31	477	2850	58199	\N	59.149217999999998	Чудовский район, с.Грузино, ул.Школьная, д.12, помещение МАОУ «Средняя общеобразовательная школа» с.Грузино, тел. 42-555).»		0101000020E6100000BAA46ABB09E23F40BDFC4E9319934D40
63732	3	31	445	2512	58205	\N	57.195082999999997	Холмский район, Чекуново, Центральная, 10		0101000020E6100000F304C24EB1223F40B680D07AF8984C40
63425	3	31	445	8724	58125	\N	57.142150000000001	Холм, Старорусская, 53		0101000020E6100000B517D1764C2D3F402E90A0F831924C40
63729	3	31	445	8724	58100	\N	57.142150000000001	Холм, Октябрьская, 88		0101000020E6100000B517D1764C2D3F402E90A0F831924C40
63728	3	31	445	8724	58100	\N	57.142150000000001	Холм, Октябрьская, 49		0101000020E6100000B517D1764C2D3F402E90A0F831924C40
63727	3	31	445	8724	58098	\N	57.142150000000001	Холм, Красноармейская, 26а		0101000020E6100000B517D1764C2D3F402E90A0F831924C40
63734	3	31	445	2700	58210	\N	57.037610608820003	Холмский район, Тухомичи, Центральная, 4	Россия, Новгородская область, Холмский район, село Тухомичи	0101000020E610000095D40968228C3F40247CEF6FD0844C40
63738	3	31	445	23880	58271	\N	57.099432999999998	Холмский район, Тогодь, Молодежная, 5		0101000020E61000002DEE3F321DB63F4053927538BA8C4C40
63731	3	31	445	23577	58195	\N	57.105251000000003	Холмский район, Сопки, Центральная, 8		0101000020E6100000B35C363AE7F33E40876F61DD788D4C40
63736	3	31	445	23788	58246	\N	57.163372000000003	Холмский район, Наход, Центральная, 14		0101000020E6100000E10CFE7E31673F40838AAA5FE9944C40
63733	3	31	445	2647	58243	\N	57.004621999999998	Холмский район, Морхово, Звездная, 5		0101000020E6100000CA6FD1C9524B3F40CA6B257497804C40
63737	3	31	445	23859	58201	\N	57.121482	Холмский район, Мамоново, Молодежная, 30		0101000020E61000006344A2D0B27E3F40BE86E0B88C8F4C40
63730	3	31	445	23547	58284	\N	56.991523000000001	Холмский район, Красный Бор, Центральная, 20		0101000020E6100000D921FE614BCF3E40AC1DC539EA7E4C40
63735	3	31	445	23779	58296	\N	57.120221000000001	Холмский район, Залесье, Комсомольская, 25		0101000020E61000001283C0CAA1393F406EA5D766638F4C40
63726	3	31	938	23345	58236	\N	58.836272999999998	Хвойнинский район,п.Юбилейный, пер.Спортивный, д.1		0101000020E6100000381268B0A97F41408FC360FE0A6B4D40
63709	3	31	938	7571	58192	\N	58.896338	п.Хвойная, ул.Советская, д.3		0101000020E610000034D93F4F03424140BE141E34BB724D40
63711	3	31	938	7571	58213	\N	58.896338	Хвойнинский район,п.Хвойная, ул.Связи, д.41		0101000020E610000034D93F4F03424140BE141E34BB724D40
63620	3	31	938	7571	57968	\N	58.896338	п.Хвойная, ул.Денисова, д.1		0101000020E610000034D93F4F03424140BE141E34BB724D40
63724	3	31	938	9392	58204	\N	58.918571	Хвойнинский район,с.Песь, пер.Школьный, д.1-а		0101000020E61000002FBFD364C6154140EA060ABC93754D40
63723	3	31	938	9383	58211	\N	58.928452	Хвойнинский район,д.Остахново, ул.Новая, д.1-а		0101000020E6100000FAEC80EB8A414140F1F3DF83D7764D40
63722	3	31	938	9329	58323	\N	58.938780000000001	Хвойнинский район,с.Минцы, ул.Первомайская, д.10	Россия, Новгородская область, Хвойнинский район, село Минцы	0101000020E61000007214200A66604140C7116BF129784D40
63721	3	31	938	9278	58202	\N	58.83155	Хвойнинский район,д.Миголощи, ул.Денисова, д.23-а		0101000020E61000006281AFE8D61F4140917EFB3A706A4D40
63725	3	31	938	23297	58244	\N	58.938738000000001	Хвойнинский район,п.Лесной,ул.Строительная ,д.22		0101000020E61000008E3D7B2E5317414098C1189128784D40
63720	3	31	938	9263	58261	\N	58.819093000000002	Хвойнинский район,с.Левоча, ул.Никольская, д.7		0101000020E6100000042159C004844140F7B0170AD8684D40
63716	3	31	938	57366	58314	\N	58.861732000000003	Хвойнинский район,ст.Кушавера, ул.Советская, д.1	Россия, Новгородская область, Хвойнинский район, село Кушавера	0101000020E61000003F8F519E7955414056F5F23B4D6E4D40
63380	3	31	938	57349	58081	\N	58.83653709339	п.г.т.Крестцы, ул.Московская, д.2а	Россия, Новгородская область, Хвойнинский район, село Крестцы	0101000020E6100000999A046F488D41406D72F8A4136B4D40
63719	3	31	938	45399	58289	\N	58.799709	Хвойнинский район,ст.Кабожа, ул.Линейная, д.9	Россия, Новгородская область, Хвойнинский район, село Кабожа	0101000020E6100000EA3F6B7EFC8341408FA850DD5C664D40
63718	3	31	938	22987	58189	\N	58.773055999999997	Хвойнинский район,д.Звягино, ул.Школьная, д.6		0101000020E610000081B229577893414000FDBE7FF3624D40
63715	3	31	938	22856	58215	\N	58.810825999999999	Хвойнинский район,д.Дворищи, ул.Советская, д.4		0101000020E61000006F66F4A3E15641408D5F7825C9674D40
63713	3	31	938	22753	58245	\N	58.959736999999997	Хвойнинский район,п.Горный, ул.Песчаная, д.10		0101000020E61000003927F6D03EEA40406DE179A9D87A4D40
63717	3	31	938	57361	58269	\N	58.759864062170898	Хвойнинский район,ст.Бугры, ул.Молодежная, д.5	Россия, Новгородская область, Хвойнинский район, село Бугры	0101000020E6100000A8A78FC01FA0414031B43A3943614D40
63714	3	31	938	22797	58239	\N	58.813958	Хвойнинский район,д.Боровское, ул.Молодежная, д.13		0101000020E6100000B35C363AE72D4140A62897C62F684D40
63712	3	31	938	7648	58263	\N	58.938704999999999	Хвойнинский район,с.Анциферово, ул.Октябрьская, д.22		0101000020E610000049BE124889FD4040BCCB457C27784D40
63687	3	31	667	57365	58283	\N	57.956999000000003	Старорусский район,ст.Тулебля, Кольцевая, 25		0101000020E61000008EAF3DB324103F4001A777F17EFA4C40
63686	3	31	667	51918	\N	\N	57.955471000000003	Старорусский район,д.Сусолово, Помещение администрации с/п, 5		0101000020E6100000F7578FFB563F3F4062A3ACDF4CFA4C40
63708	3	31	667	4716	\N	\N	57.9723543460168	г.Старая Русса, Городок, Помещение дома культуры	Россия, Новгородская область, Старорусский район, Старая Русса	0101000020E610000050FBAD9D285D3F4041118B1876FC4C40
63692	3	31	667	4716	\N	\N	57.992184000000002	г.Старая Русса, Минеральная, 36	Россия, Новгородская область, Старорусский район, Старая Русса	0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63691	3	31	667	4716	58044	\N	57.992184000000002	г.Старая Русса, пл.Революции, 3		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63696	3	31	667	4716	58035	\N	57.982522745134801	г.Старая Русса,пер.Комсомольский,д.1/38	Россия, Новгородская область, Старорусский район, Старая Русса	0101000020E610000053E751F17F5B3F40AE484C50C3FD4C40
63702	3	31	667	4716	57994	\N	57.992184000000002	г.Старая Русса, Якутских Стрелков, 35		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63689	3	31	667	4716	58042	\N	58.003111629209798	г.Старая Русса, Яковлева, 28	Россия, Новгородская область, Старорусский район, Старая Русса	0101000020E6100000F22213F06B603F40D21C59F965004D40
63699	3	31	667	4716	57992	\N	57.992184000000002	г.Старая Русса, Трибуны, 4 А		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63701	3	31	667	4716	58141	\N	57.992184000000002	г.Старая Русса, Строителей, д. 6		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63706	3	31	667	4716	58036	\N	57.992184000000002	г.Старая Русса, Пролетарской Победы, 19 корп.1		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63598	3	31	667	4716	58105	\N	57.992184000000002	г.Старая Русса, Минеральная, 62		0101000020E6100000C2C2499A3F5A3F40A7CEA3E2FFFE4C40
63694	3	31	667	4716	58235	\N	57.994007520045002	г.Старая Русса, Володарского, д.34,корп.№2	Россия, Новгородская область, Старорусский район, Старая Русса	0101000020E610000021CCED5EEE5F3F402FFB75A73BFF4C40
63697	3	31	667	4716	58115	\N	57.9875830697083	г.Старая Русса, Возрождения, 36 А	Россия, Новгородская область, Старорусский район, Старая Русса	0101000020E61000001904560E2D5A3F40F48AA71E69FE4C40
63685	3	31	667	21472	\N	\N	57.786543000000002	Старорусский район,д.Святогорша, Начальная школа-детский сад ,д. 5		0101000020E61000007172BF4351343F40E9F2E670ADE44C40
63684	3	31	667	51915	\N	\N	57.762993000000002	Старорусский район,д.Пробуждение, Помещение фельдшерско-акушерского пункта, 7		0101000020E61000006D3CD862B7633F40D9092FC1A9E14C40
63683	3	31	667	4548	58193	\N	57.656137000000001	Старорусский район,д.Пинаевы Горки, Центральная, 31		0101000020E61000000E83F92B649A3F400859164CFCD34C40
63682	3	31	667	21297	\N	\N	57.858074999999999	Старорусский район,пос.Новосельский, Алексеева, 2	Россия, Новгородская область, Старорусский район, село Новосельский	0101000020E610000048C32973F35D3F40F241CF66D5ED4C40
63681	3	31	667	10982	58297	\N	58.045935	Старорусский район,д.Нагово, Школьная, 3		0101000020E6100000C47C7901F62D3F40F25EB532E1054D40
63680	3	31	667	21216	58209	\N	57.982342000000003	Старорусский район,д.Медниково, Молодежная, 1 А		0101000020E61000000745F30016693F405EBEF561BDFD4C40
63679	3	31	667	52721	\N	\N	58.092621999999999	Старорусский район,д.Луньшино, Помещение администрации с/п, 72		0101000020E6100000FE9B1727BE0E3F40EF71A609DB0B4D40
63678	3	31	667	10860	58203	\N	57.780501999999998	Старорусский район,д.Коровитчино, Центральная, 22		0101000020E6100000E7E099D024A93F40363B527DE7E34C40
63688	3	31	667	21595	58286	\N	57.878323999999999	Старорусский район,д.Ивановское, Центральная, 31		0101000020E610000059C0046EDD413F405DA5BBEB6CF04C40
63677	3	31	667	10791	58310	\N	57.668894999999999	Старорусский район,с.Залучье, Рендакова, 12		0101000020E6100000EE9579ABAEC33F409DBAF2599ED54C40
63703	3	31	667	22340	58253	\N	58.003526000000001	Старорусский район,д.Дубовицы, Школьная, 5		0101000020E6100000BFD4CF9B8A503F40C5573B8A73004D40
63676	3	31	667	52949	\N	\N	57.912702000000003	Старорусский район,д.Давыдово, Помещение администрации с/п, 31		0101000020E61000009B215514AF823F40357F4C6BD3F44C40
63675	3	31	667	10721	58294	\N	58.159992000000003	Старорусский район,д.Взвад, Заводская, 1		0101000020E61000005DA3E5400F793F4092CF2B9E7A144D40
63674	3	31	667	20964	\N	\N	57.921225999999997	Старорусский район,д.Великое Село, Помещение администрации с/п, 28		0101000020E610000001310917F21C3F40C91CCBBBEAF54C40
63673	3	31	667	20892	58233	\N	58.148192000000002	Старорусский район,д.Буреги, Соборная, 1		0101000020E61000007D410B09180D3F40B1C398F4F7124D40
63672	3	31	667	20812	58260	\N	58.130052999999997	Старорусский район,д.Борисово, Центральная, 8		0101000020E610000083A279008B283F4093DFA293A5104D40
63669	3	31	667	20670	58305	\N	58.068404999999998	Старорусский район,д.Большое Вороново, Центральная, 1		0101000020E610000085268925E5423F4002F1BA7EC1084D40
63670	3	31	667	52937	\N	\N	57.850709999999999	Старорусский район,Большие Боры, Помещение дома культуры, 83		0101000020E61000006A2E3718EA183F40A930B610E4EC4C40
63671	3	31	667	52215	\N	\N	57.955080000000002	Старорусский район,д.Большая Козона, Помещение фельдшерско-акушерского пункта, 11 А		0101000020E6100000F18288D4B45B3F402788BA0F40FA4C40
63668	3	31	667	52924	\N	\N	57.773246	Старорусский район,д.Астрилово, Помещение МАОУ начальная школа-детский сад, 28		0101000020E61000004B8FA67A32133F40A4E194B9F9E24C40
63666	3	31	667	20509	58311	\N	58.026333000000001	Старорусский район,д. Анишино-1, Зеленая, 5 Б		0101000020E61000000EA0DFF76F423F401DE736E15E034D40
63648	3	31	908	11289	58156	\N	58.173408000000002	Солецкий муниципальный район, дер.Толчино, ул.Ветеранов, д.18		0101000020E610000090F7AA9509133E40B16EBC3B32164D40
63502	3	31	908	7236	\N	\N	58.118951000000003	г.Сольцы-2, 128 Дом офицеров	Россия, Новгородская область, Солецкий район, Сольцы	0101000020E6100000259012BBB6533E40CB694FC9390F4D40
63662	3	31	908	7236	58094	\N	58.118951000000003	г.Сольцы, просп.Советский, д.44-б		0101000020E6100000259012BBB6533E40CB694FC9390F4D40
63659	3	31	908	7236	58104	\N	58.117406814230399	г.Сольцы, ул.Новгородская, д.69-а	Россия, Новгородская область, Солецкий район, Сольцы	0101000020E6100000849F38807E533E4026A94C31070F4D40
63398	3	31	908	7236	58096	\N	58.118951000000003	г.Сольцы, ул.Молодежная, д.16		0101000020E6100000259012BBB6533E40CB694FC9390F4D40
63660	3	31	908	7236	58056	\N	58.118951000000003	г.Сольцы, ул.Красных Партизан, д.4		0101000020E6100000259012BBB6533E40CB694FC9390F4D40
63663	3	31	908	7236	58039	\N	58.118951000000003	г.Сольцы, ул.Комсомола, д.107		0101000020E6100000259012BBB6533E40CB694FC9390F4D40
63664	3	31	908	7236	58089	\N	58.118951000000003	г.Сольцы, ул.А.Матросова, д.58-б		0101000020E6100000259012BBB6533E40CB694FC9390F4D40
63650	3	31	908	19586	58140	\N	58.006798000000003	Солецкий муниципальный район, дер.Светлицы, ул.Первомайская, д.11		0101000020E610000093567C43E15B3E40D0D6C1C1DE004D40
63655	3	31	908	19878	58191	\N	57.991143999999998	Солецкий муниципальный район, дер.Ретно, ул.В.Козлова, д.11		0101000020E6100000D3DB9F8B86343E4035D07CCEDDFE4C40
63657	3	31	908	19953	58183	\N	58.169995	Солецкий муниципальный район, д.Песочки, ул.Молодёжная , д.18		0101000020E6100000A13193A817843E40E4BD6A65C2154D40
63656	3	31	908	7202	58159	\N	58.126237000000003	Солецкий муниципальный район, дер.Невское, ул.Невская, д.69		0101000020E6100000DBDC989EB0703E40C845B58828104D40
63654	3	31	908	19785	58162	\N	58.062663999999998	Солецкий муниципальный район, дер.Куклино, ул.Центральная, д.29-а		0101000020E6100000CFF8BEB8543D3E407A51BB5F05084D40
63653	3	31	908	19778	58138	\N	58.062559	Солецкий муниципальный район, дер.Жильско, ул.Центральная, д.60		0101000020E61000005187156EF9FC3D400589EDEE01084D40
63652	3	31	908	7127	58174	\N	58.081316999999999	Солецкий муниципальный район, дер.Дуброво, ул.Ветеранов, д.11		0101000020E61000003CA583F57F1A3E40EECD6F98680A4D40
63651	3	31	908	7118	58119	\N	57.987603999999997	Солецкий муниципальный район, дер.Горки, ул.Молодёжная, д.12		0101000020E6100000471D1D57230B3E400BB3D0CE69FE4C40
63649	3	31	908	11357	58091	\N	58.068001000000002	Солецкий муниципальный район, дер.Выбити, ул.Центральная, д.79		0101000020E61000002C280CCA346E3E40338CBB41B4084D40
63647	3	31	908	19444	58173	\N	58.140667999999998	Солецкий муниципальный район, дер.Вшели, ул.Центральная, д.17		0101000020E6100000F5D901D715DF3D40FFCBB56801124D40
63658	3	31	908	20004	58093	\N	58.120443999999999	Солецкий муниципальный район, дер.Большие Заборовье, ул.Вольная, д.56		0101000020E6100000E71725E82F403E40ED7F80B56A0F4D40
63646	3	31	1107	19382	58282	\N	57.392591000000003	Поддорский район, дер.Селеево, ул.Комсомольская, д.5		0101000020E6100000FE614B8FA6663F401BDA006C40B24C40
63644	3	31	1107	11171	58214	\N	57.470317000000001	с.Поддорье, ул.Горького, д.10		0101000020E610000073A087DA361C3F405DE0F25833BC4C40
63640	3	31	1107	19081	58254	\N	57.502827000000003	Поддорский район, дер.Переезд, ул.Центральная, д.44		0101000020E610000065E42CEC69BB3E40DD4598A25CC04C40
63645	3	31	1107	11188	58255	\N	57.448027000000003	Поддорский район, дер.Перегино, ул.Центральная, д.4		0101000020E6100000C824236761633F40CD5CE0F258B94C40
63643	3	31	1107	19238	58312	\N	57.418438999999999	Поддорский район, дер.Нивки, ул.Новая, д.18		0101000020E61000003EE94482A9EE3E407B2FBE688FB54C40
63642	3	31	1107	19176	58218	\N	57.465007	Поддорский район, с.Масловское, ул.Центральная, д.30		0101000020E6100000F56393FC881F3F409EB4705985BB4C40
63639	3	31	1107	19023	58208	\N	57.672258999999997	Поддорский район, дер.Заозерье, ул.Центральная, д.23		0101000020E6100000FF5BC98E8D043F4088B839950CD64C40
63641	3	31	1107	19122	58229	\N	57.586475	Поддорский район, дер.Бураково, ул.Октябрьская, д.11		0101000020E6100000E883656CE8263F40F775E09C11CB4C40
63638	3	31	1107	9920	58285	\N	57.575589000000001	Поддорский район, с.Белебелка, ул.Советская, д.48		0101000020E6100000541C075E2DEF3E40FB777DE6ACC94C40
63628	3	31	1083	28969	\N	\N	58.505604055919498	Пестовский муниципальный район, Центр - д. Устюцкое, д.56, здание муниципального бюджетного образова-тельного учреждения для детей дошкольного и младшего школьного возраста «Начальная школа – детский сад д. Устюцкое».	Россия, Новгородская область, Пестовский район, село Устюцкое	0101000020E610000045B9347EE1A94140075DC2A1B7404D40
63626	3	31	1083	18339	\N	\N	58.493304999999999	Пестовский муниципальный район, д. Семытино, д.85, здание муниципального бюджетного образовательного учреждения для детей дошкольного и младшего школьного возраста «Началь-ная школа – детский сад д. Семытино».		0101000020E610000049DBF81395E7414005FA449E243F4D40
63624	3	31	1083	18222	58095	\N	58.579554000000002	Пестовский муниципальный район,д. Русское  Пестово, ул. Лесная, д.1а, здание муниципального образовательного бюджетного учреждения дополнительного образования детей «Детско-юношеская спортивная школа».		0101000020E61000002AA73D25E7E041400C2252D32E4A4D40
63629	3	31	1083	17950	\N	\N	58.459311999999997	Пестовский муниципальный район, д. Погорелово,  д. 105, здание муниципального бюджетного образовательного учреждения для детей дошкольного и младшего школьного возраста «Начальная школа-детский сад д. Погорелово-2».		0101000020E6100000AAB8718BF9994140865451BCCA3A4D40
63618	3	31	1083	17950	\N	\N	58.459311999999997	Пестовский муниципальный район, д. Погорелово, д.25, здание муниципального бюджетного дошкольного об-разовательного учреждения детского сада д. Погорелово-1.		0101000020E6100000AAB8718BF9994140865451BCCA3A4D40
63631	3	31	1083	9620	58015	\N	58.593733999999998	г. Пестово, ул.Чапаева, д.19, здание муниципального бюджетного учреждения «Физкультурно-спортивный комплекс «Молога», спортивный корпус  «Энерге-тик».		0101000020E61000009E95B4E21BE84140FA42C879FF4B4D40
63635	3	31	1083	9620	57967	\N	58.592914297857298	г. Пестово, ул. Советская, д.15, здание муниципального автономного учреждения дополнительного образования детей центра внешкольной работы.	Россия, Новгородская область, Пестовский район, Пестово	0101000020E61000004913EF004FE6414097AB1F9BE44B4D40
63633	3	31	1083	9620	57967	\N	58.593733999999998	г. Пестово, ул. Советская, д. 11, здание муниципального бюджетного учреждения культуры «Пестовский межпоселенческий культурно-досуговый центр» (РДК).		0101000020E61000009E95B4E21BE84140FA42C879FF4B4D40
63632	3	31	1083	9620	57965	\N	58.603031037287103	г. Пестово, ул. Почтовая, д. 5, здание муниципального автономного общеобразовательного учреждения  «Средняя общеобразовательная школа №2 г.Пестого» .	Россия, Новгородская область, Пестовский район, Пестово	0101000020E610000068EA758BC0E64140B2BCAB1E304D4D40
63623	3	31	1083	18192	58111	\N	58.567706000000001	Пестовский муниципальный район, д.Охона, ул.Центральная, д.24, здание муниципального бюджетного общеобразовательного учреждения «Средняя общеобразовательная школа д. Охона».		0101000020E61000007F17B6662BD141401ADF1797AA484D40
63621	3	31	1083	18114	58158	\N	58.625788	Пестовский муниципальный район, д. Лаптево, ул. Советская, д. 28, административное здание Лаптевского сельского поселения.		0101000020E61000002D98F8A3A8A34140581D39D219504D40
63617	3	31	1083	17883	\N	\N	58.600068999999998	Пестовский муниципальный район, д. Карпелово,  д. 25,  административное здание территориального отделения Быковского сельского поселения		0101000020E6100000CD94D6DF12FC4140F52B9D0FCF4C4D40
63619	3	31	1083	18003	58142	\N	58.468501000000003	Пестовский муниципальный район, д. Вятка, ул. Соловьева, д. 51, здание филиала муниципального бюджетного учреждения культуры «Межпоселенческий культурно-досуговый центр» Вятского сельского дома культуры.		0101000020E6100000074147AB5AD6414058923CD7F73B4D40
63625	3	31	1083	18292	\N	\N	58.721991000000003	Пестовский муниципальный район, д. Вотроса, д.57,  административное здание территориального отделения Пестовского сельского поселения.		0101000020E610000065C22FF5F3E84140D0807A336A5C4D40
63616	3	31	1083	29438	58194	\N	58.556863464814903	Пестовский муниципальный район, ул. Школьная, д. 92, административное здание Быковского сельского поселения.	Россия, Новгородская область, Пестовский район, село Быково	0101000020E6100000C636A968AC0D42401DAD6A4947474D40
63614	3	31	1083	29396	58198	\N	58.767528454806701	Пестовский муниципальный район, ул.Советская, д.6, административное здание Богословского сельского поселения.	Россия, Новгородская область, Пестовский район, село Богослово	0101000020E61000008AC91B60E6B54140D461855B3E624D40
63622	3	31	1083	18117	\N	\N	58.628093	Пестовский муниципальный район, д. Беззубцево, д. 33, здание муниципального бюджетного обще-образовательного учреждения основной общеобразовательной школы д. Без-зубцево.		0101000020E6100000143FC6DCB5BC41405BECF65965504D40
63627	3	31	1083	18402	58126	\N	58.516159999999999	Пестовский муниципальный район, д. Барсаниха, ул. Молодежная, д.17в, здание муниципального бюджетного дошкольного образовательного учреждения детского сада д. Барсаниха.		0101000020E61000004DDBBFB2D2BC41406EC0E78711424D40
63613	3	31	1083	57352	58160	\N	58.711458	Пестовский муниципальный район, ст.Абросово, ул. Ветеранов, д. 1а, здание филиала муниципального бюджетного учреждения культуры «Межпоселенческий культурно-досуговый центр» Абросовского сельского дома культуры.		0101000020E6100000E129E44A3DB74140213D450E115B4D40
63605	3	31	1475	17225	58122	\N	57.985571999999998	Парфинский район,дер.Федорково, адрес помещения для голосования: ул.Старорусская. д.5, адрес УИК: ул.Профсоюзная, д.2		0101000020E6100000E883656CE89E3F4039ED293927FE4C40
63604	3	31	1475	17225	58086	\N	57.985571999999998	Парфинский район,дер.Федорково, улица Профсоюзная, дом 2		0101000020E6100000E883656CE89E3F4039ED293927FE4C40
63603	3	31	1475	17195	58102	\N	57.949530000000003	Парфинский район,дер.Сергеево, улица Строительная, дом 2		0101000020E6100000EBFF1CE6CB9B3F401349F4328AF94C40
63610	3	31	1475	17501	58013	\N	57.935026999999998	Парфинский район,пос.Пола, ул.Пионерская, д.10		0101000020E6100000CC5F217365D43F4041F0F8F6AEF74C40
63609	3	31	1475	17501	58009	\N	57.935026999999998	Парфинский район,пос.Пола, адрес помещения для голосования: ул.Мира, д.12, адрес УИК: ул.Пионерская, д.10		0101000020E6100000CC5F217365D43F4041F0F8F6AEF74C40
63601	3	31	1475	16903	58004	\N	57.972420966656699	пос.Парфино, адрес помещения для голосования: ул.Мира, д.30а, адрес УИК: ул.Карла Маркса, д.60, каб.10, 17	Россия, Новгородская область, Парфинский район, поселок Парфино	0101000020E6100000A438471D1DA73F40C878944A78FC4C40
63599	3	31	1475	16903	57991	\N	57.969135999999999	пос.Парфино, адрес помещения для голосования: ул.Крупнова, д.5, адрес УИК: ул.Карла Маркса, д.70, каб.10, 17		0101000020E6100000CD04C3B986A53F4029B000A60CFC4C40
63602	3	31	1475	16903	57990	\N	57.969135999999999	пос.Парфино, адрес помещения для голосования: ул. Карла Маркса, д.62, адрес УИК: ул.Карла Маркса, д.60, каб.10, 17		0101000020E6100000CD04C3B986A53F4029B000A60CFC4C40
63600	3	31	1475	16903	57990	\N	57.969135999999999	пос.Парфино, адрес помещения для голосования: ул.Карла Маркса, д.65, адрес УИК: ул.Карла Маркса, д.60, каб.10, 17		0101000020E6100000CD04C3B986A53F4029B000A60CFC4C40
63597	3	31	1475	16903	57990	\N	57.969135999999999	пос.Парфино, адрес помещения для голосования: ул.Карла Маркса, д.70, адрес  УИК: ул.Карла Маркса, д.60, каб.10, 17		0101000020E6100000CD04C3B986A53F4029B000A60CFC4C40
63611	3	31	1475	17606	58182	\N	57.836680000000001	Парфинский район,дер.Новая Деревня, улица Центральная, дом 6		0101000020E6100000758F6CAE9AE33F40D09B8A5418EB4C40
63608	3	31	1475	17441	58154	\N	58.155476999999998	Парфинский район,дер.Лажины, улица Советская, дом 5		0101000020E61000000113B87537D33F40DD239BABE6134D40
63612	3	31	1475	17628	\N	\N	57.850020999999998	Парфинский район,дер.Кузьминское, дом 46		0101000020E6100000C405A051BA024040E4F4F57CCDEC4C40
63607	3	31	1475	17392	58181	\N	58.045257999999997	Парфинский район,дер.Городок, ул.Советская, дом 15		0101000020E6100000740B5D89409D3F40F1F09E03CB054D40
63606	3	31	1475	17354	58172	\N	58.037303000000001	Парфинский район,дер.Березицко, улица Школьная, дом 22		0101000020E61000005E9F39EB53963F4077853E58C6044D40
63574	3	31	1409	57362	58272	\N	58.406128861293197	Окуловский район, дер.Шуркино, ул.Мира, д.2Б	Россия, Новгородская область, Окуловский район	0101000020E6100000E9EE3A1BF29F4040857AFA08FC334D40
63591	3	31	1409	57351	58153	\N	58.585028240525098	Окуловский район, дер.Козловка, ул.Новопокровская, д.5	Россия, Новгородская область, Окуловский район	0101000020E6100000CCD24ECDE59C4040459F8F32E24A4D40
63582	3	31	1409	16083	57983	\N	58.236024999999998	Окуловский район, пос.Угловка, ул.Центральная, д.9		0101000020E610000000E65AB400C14040EA043411361E4D40
63581	3	31	1409	16083	58117	\N	58.236024999999998	Окуловский , пос.Угловка, ул.Молодежная, д.11		0101000020E610000000E65AB400C14040EA043411361E4D40
63592	3	31	1409	57355	58188	\N	58.581698000000003	Окуловский район, ст.Торбино, ул.Луначарского, д.42		0101000020E610000060915F3FC470404006137F14754A4D40
63594	3	31	1409	16758	58114	\N	58.549384446119198	Окуловский район, пос.Топорок, ул.Дзержинского, д.6Б	Россия, Новгородская область, Окуловский район, село Топорок	0101000020E61000007521567F84BD40400C79043752464D40
63583	3	31	1409	16199	\N	\N	58.173270000000002	Окуловский район, дер.Селище, д.31		0101000020E61000002E8ECA4DD4CA404060B01BB62D164D40
63596	3	31	1409	16823	\N	\N	58.283532000000001	Окуловский район, дер.Пузырёво, д.57		0101000020E6100000834E081D74AB40404BAFCDC64A244D40
63580	3	31	1409	16047	58152	\N	58.446759	Окуловский  район, дер.Полищи, ул.Центральная, д.29		0101000020E61000005F950B957FAB4040CA181F662F394D40
63575	3	31	1409	15569	57962	\N	58.396171000000002	г.Окуловка, ул.Парфёнова, д.10		0101000020E61000006C0723F609A64040D34F38BBB5324D40
63572	3	31	1409	15569	58010	\N	58.3874105096493	г.Окуловка, ул.Новгородская, д.32	Россия, Новгородская область, Окуловский район, Окуловка	0101000020E61000001AA721AAF0A540402A8E03AF96314D40
63570	3	31	1409	15569	57980	\N	58.396171000000002	г.Окуловка, ул.Ленина, д.51		0101000020E61000006C0723F609A64040D34F38BBB5324D40
63577	3	31	1409	15569	58121	\N	58.396171000000002	г.Окуловка, ул.Грибоедова, д.31		0101000020E61000006C0723F609A64040D34F38BBB5324D40
63585	3	31	1409	16297	\N	\N	58.355564000000001	Окуловский район, дер.Озерки, д.9, кв.13		0101000020E61000009010E50B5AB6404046D1031F832D4D40
63595	3	31	1409	16821	58151	\N	58.254430999999997	Окуловский район, дер.Мельница, ул.Центральная, д.19		0101000020E610000091EEE714E4A34040560BEC3191204D40
63579	3	31	1409	15922	57963	\N	58.453018	Окуловский  район, пос.Кулотино, ул.Кирова, д.13		0101000020E6100000BD72BD6DA6AE4040EA3F6B7EFC394D40
63578	3	31	1409	15922	57963	\N	58.453018	Окуловский район, пос.Кулотино, ул.Кирова, д.13		0101000020E6100000BD72BD6DA6AE4040EA3F6B7EFC394D40
63593	3	31	1409	16694	58026	\N	58.483615	Окуловский район, пос.Котово, ул.Ленина, д.4		0101000020E6100000B517D1764CBF4040726DA818E73D4D40
63587	3	31	1409	16385	\N	\N	58.344225999999999	Окуловский район, дер.Завод, д.8		0101000020E610000055DE8E705A8E40406937FA980F2C4D40
63589	3	31	1409	16508	\N	\N	58.527194000000001	Окуловский район, дер.Дерняки, д.62		0101000020E6100000D90A9A96589D4040DF52CE177B434D40
63590	3	31	1409	16511	\N	\N	58.701669000000003	Окуловский район, дер.Висленев Остров, д.2		0101000020E6100000FDBE7FF3E28A4040FBCE2F4AD0594D40
63588	3	31	1409	16452	57966	\N	58.487406999999997	Окуловский  район, пос.Боровёнка, ул.Кооперативная, д.7		0101000020E610000026A60BB1FA894040B56B425A633E4D40
63584	3	31	1409	16209	\N	\N	58.219946	Окуловский район, дер.Березовка, д.66		0101000020E61000008DEF8B4B55BC40406971C630271C4D40
63586	3	31	1409	16345	58169	\N	58.378914999999999	Окуловский район, с.Берёзовик, ул.Центральная, д.9А		0101000020E61000001CEBE2361A9A40405F7B664980304D40
63562	3	31	51	15155	\N	\N	58.664154000000003	Новгородский район , деревня Чечулино, 11		0101000020E6100000C6C37B0E2C5F3F40F9C08EFF02554D40
63544	3	31	51	60	58267	\N	58.611907000000002	Новгородский район , деревня Частова, Центральная, 63		0101000020E6100000A8FDD64E94084040C498F4F7524E4D40
63543	3	31	51	14275	\N	\N	58.479559000000002	Новгородский район , деревня Холынья, 8Б		0101000020E6100000111C9771538B3F4051C07630623D4D40
63569	3	31	51	57359	\N	\N	58.599268000000002	Новгородский район , деревня Трубичино, 2Б		0101000020E6100000BE6BD097DE4E3F4009C556D0B44C4D40
63531	3	31	51	13707	\N	\N	58.418925000000002	"Новгородский район , деревня Толстиково, помещение """"Толстиковский центр досуга""""-филиал МАУ """"Серговски"""	Россия, Новгородская область, Новгородский район, село Толстиково	0101000020E61000003DF03158711E3F40083D9B559F354D40
63568	3	31	51	15476	58250	\N	58.791401	Новгородский район , поселок Тёсовский, Центральная, 5А		0101000020E61000003B71395E81E03E40C782C2A04C654D40
63563	3	31	51	15229	58212	\N	58.883353120706502	Новгородский район , поселок Тёсово-Нетыльский, Советская, 17	Россия, Новгородская область, Новгородский район, поселок Тесово-Нетыльский	0101000020E6100000967840D994073F4068E90AB611714D40
63564	3	31	51	15229	58276	\N	58.929712669042502	Новгородский район , поселок Тёсово-Нетыльский, Матросова, 11	Россия, Новгородская область, Новгородский район, поселок Тесово-Нетыльский	0101000020E61000005DC136E2C90E3F4041D5E8D500774D40
63536	3	31	51	13947	58275	\N	58.448402999999999	Новгородский район , деревня Старое Ракомо, Школьная, 17		0101000020E6100000354415FE0C3B3F40D236FE4465394D40
63532	3	31	51	13725	\N	\N	58.338009	Новгородский район , деревня Сергово, 3		0101000020E61000006F10AD156D163F40786000E1432B4D40
63550	3	31	51	14577	58262	\N	58.545198999999997	Новгородский район , деревня Савино, Школьная, 3		0101000020E61000000BED9C6681723F40EC67B114C9454D40
63553	3	31	51	14755	58277	\N	58.432563973656499	Новгородский район , поселок Пролетарий, Парковая, 5	Россия, Новгородская область, Новгородский район, поселок Пролетарий	0101000020E61000006A6803B001B53F40A6B6D4415E374D40
63554	3	31	51	14755	58300	\N	58.432699	Новгородский район , поселок Пролетарий, Ленина, 10		0101000020E61000000C59DDEA39B53F4086014BAE62374D40
63558	3	31	51	15000	58206	\N	58.690114999999999	Новгородский район , деревня Подберезье, Центральная, 110		0101000020E6100000533E0455A3633F4051BD35B055584D40
63539	3	31	51	57360	58251	\N	58.499099544457103	Новгородский район , поселок Панковка, Пионерская, 12		0101000020E610000071218FE046363F4080B74082E23F4D40
63538	3	31	51	14049	58315	\N	58.496869198902203	Новгородский район , поселок Панковка, Октябрьская, 3	Россия, Новгородская область, поселок Панковка	0101000020E6100000BB473657CD333F40B7B24467993F4D40
63567	3	31	51	15430	\N	\N	58.755527999999998	"Новгородский район , деревня Осия, помещение конторы ПУ ООО """"Новгородский бекон"""""""	Россия, Новгородская область, Новгородский район, село Осия	0101000020E61000008D2441B8023E3F402C9B3924B5604D40
63547	3	31	51	14473	58278	\N	58.525094000000003	Новгородский район , деревня Новоселицы, Школьная, 3		0101000020E61000009DB98784EFB13F40B5A9BA4736434D40
63534	3	31	51	13845	\N	\N	58.519562999999998	Новгородский район , деревня Новая Мельница, 26		0101000020E61000000A65E1EB6B293F40179B560A81424D40
63541	3	31	51	14192	\N	\N	58.365752000000001	Новгородский район , деревня Наволок, 9А		0101000020E61000001F4C8A8F4FA03F402A3927F6D02E4D40
63548	3	31	51	263	58288	\N	58.676254999999998	Новгородский район , деревня Мытно, Евстигнеева, 23		0101000020E610000079EBFCDB65BF3F40D4601A868F564D40
63535	3	31	51	13882	58258	\N	58.301833000000002	Новгородский район , деревня Лесная, 60 лет СССР, 17		0101000020E61000000C8FFD2C96E23E4042EDB776A2264D40
63556	3	31	51	14871	58234	\N	58.403098999999997	Новгородский район , деревня Красные Станки, Центральная, 106		0101000020E6100000A6B915C26AD43F4070067FBF98334D40
63565	3	31	51	15307	58354	\N	58.907963000000002	Новгородский район , поселок Кересть, Центральная, 28	Россия, Новгородская область, Новгородский район, село Кересть	0101000020E6100000DE205A2BDA183F40317DAF2138744D40
63537	3	31	51	14004	58265	\N	58.395954000000003	Новгородский район , деревня Ильмень, Зеленая, 2А		0101000020E61000006781768714333F40365CE49EAE324D40
63559	3	31	51	15028	58197	\N	58.795802000000002	Новгородский район , деревня Захарьино, Рахманинова, 8		0101000020E610000020459DB987903F40B30B06D7DC654D40
63533	3	31	51	13799	\N	\N	58.532122999999999	Новгородский район , деревня Ермолино, 33А		0101000020E6100000AFCE31207B153F408639419B1C444D40
63552	3	31	51	14708	\N	\N	58.704320000000003	Новгородский район , деревня Дубровка, 46/3		0101000020E6100000960A2AAA7E813F4099F56228275A4D40
63555	3	31	51	14859	58301	\N	58.320459999999997	Новгородский район , деревня Гостцы, Школьная, 2		0101000020E61000002FDFFAB0DEB43F408CD651D504294D40
63566	3	31	51	15383	58303	\N	58.805588	Новгородский район , деревня Село-Гора, Черепанова, 99		0101000020E61000000EBBEF181E0F3F406806F1811D674D40
63546	3	31	51	57363	58279	\N	58.545576709024097	Новгородский район , поселок Волховец, Пионерская, 1Г		0101000020E6100000D2510E6613543F4093399677D5454D40
63540	3	31	51	14140	58299	\N	58.452914	Новгородский район , село Бронница, Бронницкая, 168		0101000020E610000022718FA50FA93F4045F30016F9394D40
63530	3	31	51	13655	58247	\N	58.380146000000003	Новгородский район , деревня Борки, Заверяжская, 1		0101000020E61000000E492D944C023F4045DAC69FA8304D40
63561	3	31	51	15131	\N	\N	58.635907000000003	Новгородский район , деревня Болотная, 7		0101000020E61000007FA31D37FC2A3F4014268C6665514D40
63549	3	31	51	14555	58259	\N	58.502009999999999	Новгородский район , деревня Божонка, Новая, 15		0101000020E6100000FCE1E7BF07A73F40EA211ADD41404D40
63542	3	31	51	14208	\N	\N	58.495792999999999	Новгородский район , деревня Белая Гора, 37		0101000020E61000004E637B2DE8B53F40F94A2025763F4D40
63460	3	31	257	1796	\N	\N	58.343919	Мошенской р-н,дер.Чувашева Гора, д.37		0101000020E610000007616EF7727941408CBCAC89052C4D40
63455	3	31	257	1567	\N	\N	58.628481999999998	Мошенской р-н,дер.Устрека,адрес помещения для голосования д.131а,адрес УИК:д.132		0101000020E6100000ECDADE6E49464140F50F221972504D40
63454	3	31	257	1470	\N	\N	58.501342000000001	Мошенской р-н,дер.Слоптово, д.1а		0101000020E61000001059A489774841403D0E83F92B404D40
63459	3	31	257	10322	\N	\N	58.373465000000003	Мошенской р-н,дер.Петрово, д.73		0101000020E610000080B6D5AC33924140AF997CB3CD2F4D40
63453	3	31	257	10023	\N	\N	58.550417000000003	Мошенской р-н,дер.Осташево,адрес помещения для голосования: д.56,адрес УИК:д.49		0101000020E61000004436902E36354140CB14731074464D40
63458	3	31	257	10244	\N	\N	58.309417000000003	Мошенской р-н,дер.Ореховно, д.95		0101000020E610000046088F368E844140C9E9EBF99A274D40
63450	3	31	257	9851	58273	\N	58.521898	Мошенской р-н,дер.Новый Поселок, ул.Молодежная, д.3		0101000020E6100000FED64E94844C414085ECBC8DCD424D40
63456	3	31	257	10137	58238	\N	58.509653999999998	с.Мошенское, адрес помещения для голосования: ул.Советская, д.11, адрес УИК: ул. 1 Мая, д.10,каб.2		0101000020E6100000C13A8E1F2A4B414046239F573C414D40
63452	3	31	257	1430	58307	\N	58.425795999999998	Мошенской р-н,дер.Меглецы, ул.Софьи Лешерн, д.6		0101000020E6100000D2DF4BE1414741404162BB7B80364D40
63448	3	31	257	9751	\N	\N	58.401099000000002	Мошенской р-н,дер.Красная Гора, д.9		0101000020E6100000B2135E8253634140AABA473657334D40
63449	3	31	257	1266	\N	\N	58.577443000000002	Мошенской р-н,дер.Кабожа, д.30		0101000020E6100000A46FD234287C4140EE26F8A6E9494D40
63457	3	31	257	1620	\N	\N	58.252954000000003	Мошенской р-н,дер.Дубишки, д.12		0101000020E610000024B9FC87F48941403AB2F2CB60204D40
63447	3	31	257	9710	\N	\N	58.463327999999997	Мошенской р-н,дер.Долгое, д.2		0101000020E61000009EEA909BE172414019A9F7544E3B4D40
63446	3	31	257	1082	\N	\N	58.462947	Мошенской р-н,дер.Броди, д.39		0101000020E6100000F9A1D288998F41400264E8D8413B4D40
63451	3	31	257	9915	\N	\N	58.306178000000003	Мошенской р-н,дер.Барышово, д.64		0101000020E6100000DE3EABCC945641409A6038D730274D40
63445	3	31	163	9622	\N	\N	57.399371000000002	Маревский  р-н, п.Первомайский, помещение для голосования: ул.Молодежная д.15, пом.6,адрес УИК:с.Молвотицы,ул.Школьная д.14		0101000020E61000009C51F355F229404044FCC3961EB34C40
63444	3	31	163	1024	58207	\N	57.418889999999998	Маревский  р-н, д.Новая Русса, ул.Центральная, д.34		0101000020E6100000BB9D7DE5411840408B4F01309EB54C40
63440	3	31	163	57369	58319	\N	57.406651383029903	Маревский  р-н, д.Новая Деревня, ул.Новая, д.13	Россия, Новгородская область, Маревский район, село Новая Деревня	0101000020E6100000E9995E622CF33F405EF1D4230DB44C40
63441	3	31	163	870	58224	\N	57.413168503702302	Маревский  р-н, д.Молвотицы, ул.Школьная, д.14	Россия, Новгородская область, Маревский район, село Молвотицы	0101000020E610000022A98592C92940404B5CC7B8E2B44C40
63439	3	31	163	9334	58227	\N	57.328200000000002	Маревский  р-н, д.Моисеево, ул.Садовая, д.6(8)		0101000020E610000033F9669B1B0B40400B46257502AA4C40
63435	3	31	163	518	58268	\N	57.312201000000002	Маревский  р-н, с.Марево, адрес помещения для голосования :ул.Советов, д.44,адрес УИК:ул.Советов д.27		0101000020E610000067B8019F1F0A4040A663CE33F6A74C40
63436	3	31	163	518	58295	\N	57.312201000000002	Маревский  р-н, с.Марево,адрес помещения для голосования: ул.Мудрова, д.19,адрес УИК:ул.Советов д.27		0101000020E610000067B8019F1F0A4040A663CE33F6A74C40
63443	3	31	163	966	58281	\N	57.348970999999999	Маревский  р-н, д.Мамоновщина, ул.Центральная, д.1		0101000020E6100000DC63E943174840404F20EC14ABAC4C40
63437	3	31	163	640	58292	\N	57.340291999999998	Маревский  р-н, д.Липье, ул.Строителей, д.1	Россия, Р-50 шоссе	0101000020E6100000F0DE5163421A4040938B31B08EAB4C40
63442	3	31	163	9454	58228	\N	57.375461000000001	Маревский  р-н, д.Горное, пер.Кленовый, д.4		0101000020E6100000F7CB272B8631404034F6251B0FB04C40
63434	3	31	163	501	58219	\N	57.213994999999997	Маревский  р-н, с.Велилы, ул.Советов, д.7		0101000020E6100000459F8F32E2E63F40F6402B30649B4C40
63438	3	31	163	737	58287	\N	57.313231999999999	Маревский  р-н, д.Афаносово, ул.Центральная, д.37		0101000020E6100000776682E15C2D4040C40776FC17A84C40
63432	3	31	149	52415	\N	\N	58.770493999999999	Маловишерский р-н,д.Подгорное, помещение школы	Россия, Новгородская область, Маловишерский район, село Подгорное	0101000020E6100000D07F0F5EBB664040D2E1218C9F624D40
63433	3	31	149	384	58155	\N	58.657910000000001	Маловишерский р-н,д.Оксочи, ул.Советов, д.1		0101000020E6100000AABA4736576540400EDB166536544D40
63429	3	31	149	8904	58170	\N	58.690565091712102	Маловишерский р-н,д.Мстинский Мост, ул.Воровского, д.5	Россия, Новгородская область, Маловишерский район, село Мстинский Мост	0101000020E610000084BA48A12C4A40409161156F64584D40
63415	3	31	149	8130	58024	\N	58.845016999999999	г.Малая Вишера, ул.Московская, д.23		0101000020E6100000967B8159A11C404032C85D84296C4D40
63420	3	31	149	8130	57978	\N	58.8580610411625	г.Малая Вишера, ул.Заводской Домострой, д.4 А	Россия, Новгородская область, Маловишерский район, Малая Вишера	0101000020E6100000C8957A16841A40408D7C5EF1D46D4D40
63419	3	31	149	8130	57978	\N	58.845016999999999	г.Малая Вишера, ул.Заводской Домострой, д.10		0101000020E6100000967B8159A11C404032C85D84296C4D40
63418	3	31	149	8130	57978	\N	58.857860943328497	г.Малая Вишера, ул.Заводской Домострой, д.4а	Россия, Новгородская область, Маловишерский район, Малая Вишера	0101000020E6100000C6F99B50881A4040C6C1A563CE6D4D40
63416	3	31	149	8130	57959	\N	58.845016999999999	г.Малая Вишера, ул.Гагарина, д.14		0101000020E6100000967B8159A11C404032C85D84296C4D40
63413	3	31	149	8130	58006	\N	58.845016999999999	г.Малая Вишера, ул.50 Лет Октября, д.16		0101000020E6100000967B8159A11C404032C85D84296C4D40
63417	3	31	149	8130	57977	\N	58.8470978797058	г.Малая Вишера, ул.Школьная, д.1	Россия, Новгородская область, Маловишерский район, Малая Вишера	0101000020E61000001F65C405A01D4040E6400FB56D6C4D40
63426	3	31	149	4158	58280	\N	58.771819999999998	Маловишерский р-н,д.Красненка, ул.Первомайская, д.9		0101000020E6100000D9EE1EA0FB2E404009336DFFCA624D40
63428	3	31	149	4300	\N	\N	58.635696000000003	Маловишерский р-н,д.Карпина Гора, д.38		0101000020E610000092E7FA3E1C3E404059198D7C5E514D40
63427	3	31	149	4240	58150	\N	58.649693999999997	Маловишерский р-н,д.Дворищи, ул.Школьная, д.2		0101000020E6100000E17EC003032C40402634492C29534D40
63423	3	31	149	57353	58171	\N	58.973568	Маловишерский р-н,ст.Гряды, ул.Ленинградская, д.12		0101000020E6100000F225547078F53F40503750E09D7C4D40
63421	3	31	149	8548	58180	\N	58.809688999999999	Маловишерский р-н,д.Глутно, ул.Славная, д.5		0101000020E6100000253E7782FD19404029779FE3A3674D40
63431	3	31	149	8995	58256	\N	58.813952999999998	Маловишерский р-н,д.Гарь, ул.Северная, д.3		0101000020E61000002CB81FF0C06C404094BDA59C2F684D40
63430	3	31	149	4396	58137	\N	58.679006000000001	Маловишерский р-н,д.Веребье, ул.1 Мая, д.47		0101000020E6100000CE8AA8893E594040D6E429ABE9564D40
63424	3	31	149	8685	58087	\N	58.722149999999999	Маловишерский р-н,д.Бурга,  ул.Новгородская, д.3,		0101000020E610000073BA2C26363B4040386744696F5C4D40
63422	3	31	149	8560	58011	\N	58.908659999999998	Маловишерский р-н,п.Большая Вишера, ул.Поболотина, д.3		0101000020E610000008CC43A67C0A404078978BF84E744D40
63403	3	31	549	7641	\N	\N	58.740447000000003	Любытинский р-он ,  дер. Ярцево, здание сельского клуба, д.43		0101000020E6100000C631923D42974040EEB5A0F7C65E4D40
63393	3	31	549	7213	\N	\N	58.795583000000001	с.Шереховичи, Здание территориального отдела	Россия, Новгородская область, Любытинский район, село Шереховичи	0101000020E6100000D61EF64201C740407520EBA9D5654D40
63392	3	31	549	7129	\N	\N	58.776297999999997	Любытинский р-он ,  дер.Слобода, Здание территориального отдела	Россия, Новгородская область, Любытинский район, село Слобода	0101000020E610000079EBFCDB65D34040A0F99CBB5D634D40
63396	3	31	549	52379	\N	\N	58.773266	Любытинский р-он ,  адрес помещения для голосования: дер.Никольское, здание библиотеки, адрес УИК: дер Артем, здание территориального отдела	Россия, Новгородская область, Любытинский район, село Никольское	0101000020E6100000D36A48DC63B74040EB8D5A61FA624D40
63412	3	31	549	8037	58031	\N	59.12209	Любытинский р-он ,  р.п. Неболчи, адрес помещения для голосования: ул.Комсомольская, д.3		0101000020E6100000DFF94509FAAB4040969526A5A08F4D40
63411	3	31	549	8037	58031	\N	59.12209	Любытинский р-он ,  р.п.Неболчи адрес помещения для голосования п.Неболчи ул.Комсомольская д.3 ,адрес УИК: ул.Советская д.14		0101000020E6100000DFF94509FAAB4040969526A5A08F4D40
63405	3	31	549	3669	57961	\N	58.815173999999999	пос.Любытино     адрес помещения для голосования: ул.Советов, д.16, УИК: ул.Советов д. 10		0101000020E61000007364E597C1B240405646239F57684D40
63402	3	31	549	3669	57961	\N	58.815173999999999	пос.Любытино,    ул.Советов, д.10		0101000020E61000007364E597C1B240405646239F57684D40
63400	3	31	549	3669	58135	\N	58.815173999999999	Любытинский р-он ,  помещение для голосования: дер. Большой Городок, ул.Магистральная д.6, УИК: р.п.Любытино, ул.Советов, д.10		0101000020E61000007364E597C1B240405646239F57684D40
63397	3	31	549	7408	58185	\N	58.648383000000003	Любытинский р-он ,  с.Комарово, ул.Речная, д.11		0101000020E61000004B75012F33B640402524D236FE524D40
63404	3	31	549	57348	58054	\N	58.736066000000001	Любытинский р-он ,  с.Зарубино адрес помещения для голосования: ул.Пролетарская д.5, УИК:ул.Коммунарная д.7	Россия, Новгородская область, Любытинский район, поселок Зарубино	0101000020E6100000EFA83121E6BC404049D92269375E4D40
63407	3	31	549	7838	\N	\N	59.289135000000002	Любытинский р-он ,  дер.Заполье, здание территориального отдела	Россия, Новгородская область, Любытинский район, село Заполье	0101000020E61000006CB1DB679579404082902C6002A54D40
63406	3	31	549	3826	\N	\N	59.242474000000001	Любытинский р-он ,  дер.Дрегли, здание территориального отдела	Россия, Новгородская область, Любытинский район, село Дрегли	0101000020E6100000F8FF71C284C34040AE105663099F4D40
63362	3	31	773	5626	58007	\N	57.650241999999999	п.Демянск, адрес помещения для голосования: ул.Ленина, д.24, адрес УИК: ул.1 Мая, д.63		0101000020E610000084A0A3552D3B4040293E3E213BD34C40
63401	3	31	549	3627	\N	\N	58.847135999999999	Любытинский р-он ,  дер.Вычерема, здание сельского библиотечного филиала	Россия, Новгородская область, Любытинский район, село Вычерема	0101000020E610000036ACA92C0A8F4040D3A1D3F36E6C4D40
63399	3	31	549	7494	\N	\N	58.910713999999999	Любытинский р-он ,  дер.Высочка, Здание сельского клуба, д.39		0101000020E610000057ED9A90D6B640403201BF4692744D40
63408	3	31	549	3919	\N	\N	59.169714999999997	Любытинский р-он ,  дер.Водогон, здание территориального отдела	Россия, Новгородская область, Любытинский район, село Водогон	0101000020E6100000EB71DF6A9D80404000529B38B9954D40
63395	3	31	549	52377	\N	\N	58.702894000000001	Любытинский р-он ,  адрес помещения для голосования: дер.Васильково,  здание бывшего фельдшерско-акушерского пункта, адрес УИК: дер.Артем, здание территориального отдела	Россия, Новгородская область, Любытинский район, село Васильково	0101000020E61000006D73637AC2C24040FE463B6EF8594D40
63410	3	31	549	52399	58168	\N	59.042375999999997	Любытинский р-он ,  адрес помещения для голосования дер.Ваган, здание здание сельского клуба, УИК п. Неболчи, ул.Советская, д.14		0101000020E6100000221ADD41ECB240405111A7936C854D40
63394	3	31	549	3395	\N	\N	58.740932999999998	Любытинский р-он ,  дер.Артем, Здание территориального отдела	Россия, Новгородская область, Любытинский район, село Артем	0101000020E61000000B45BA9F53C040407AC37DE4D65E4D40
63382	3	31	528	6662	57982	\N	58.262768999999999	Крестецкий р-н ,село Ямская Слобода, ул.Ямская, д.23		0101000020E6100000717500C45D43404089B3226AA2214D40
63386	3	31	528	6816	58178	\N	58.466124000000001	Крестецкий р-н ,д.Усть-Волма, ул.Советская, д.1		0101000020E6100000A9BEF38B12384040BBF083F3A93B4D40
63390	3	31	528	3309	58179	\N	58.061987999999999	Крестецкий р-н ,д.Соменка, ул.Зеленая, д.58		0101000020E61000000E15E3FC4D6440404A5F0839EF074D40
63387	3	31	528	6925	58133	\N	58.353887999999998	Крестецкий р-н ,д.Ручьи, ул.Лесная, д.1		0101000020E6100000D36BB3B1125940403239B5334C2D4D40
63385	3	31	528	6821	\N	\N	58.440123	Крестецкий р-н ,д.Ольховка, д.17		0101000020E610000009FA0B3D62244040D49B51F355384D40
63389	3	31	528	3207	\N	\N	58.145532000000003	Крестецкий р-н ,д.Новое Рахино, д.26		0101000020E6100000D8D7BAD408614040C042E6CAA0124D40
63388	3	31	528	6936	\N	\N	58.291513000000002	Крестецкий р-н ,д.Лякова, д.66		0101000020E6100000A67D737FF54E4040EFAD484C50254D40
63391	3	31	528	7119	\N	\N	58.223742999999999	Крестецкий р-н ,д.Локотско, д.44		0101000020E610000074D3669C86784040BEDA519CA31C4D40
63378	3	31	528	47070	58061	\N	58.249573478236798	п.г.т. Крестцы, ул. Строителей, д. 7		0101000020E61000005C04C6FA06424040787B1002F21F4D40
63379	3	31	528	47070	57976	\N	58.245161314454101	п.г.т.Крестцы, адрес ул.Островская, д.19	Россия, Новгородская область, Крестецкий район, поселок Крестцы	0101000020E6100000ACAB02B51842404099A0866F611F4D40
63381	3	31	528	47070	58052	\N	58.243713099564602	п.г.т.Крестцы, ул.Валдайская, д.2	Россия, Новгородская область, Крестецкий район, поселок Крестцы	0101000020E6100000D0EFFB372F424040164ED2FC311F4D40
63383	3	31	528	6738	58110	\N	58.367871999999998	Крестецкий р-н ,д.Зайцево, ул.Молодежная, д.6а		0101000020E610000088484DBB980840409B8E006E162F4D40
63384	3	31	528	6781	58148	\N	58.359614999999998	Крестецкий р-н ,д.Вины, ул.Центральная, д.94		0101000020E61000008F34B8AD2D1C4040551344DD072E4D40
63377	3	31	773	6424	58097	\N	57.841667000000001	Демянский  район, д.Ямник, адрес помещения для голосования: ул.Садовая, д2а, адрес УИК: ул.Садовая д.2а, каб.№2		0101000020E6100000D9E89C9FE23E4040AC8F87BEBBEB4C40
63376	3	31	773	6352	58136	\N	57.592500000000001	Демянский  район, д.Шишково, ул.Центральная, д.33		0101000020E610000025B37A87DB474040A4703D0AD7CB4C40
63375	3	31	773	6325	58147	\N	57.743806999999997	Демянский  район, д.Черный Ручей, адрес помещения для голосования:ул.Центральная, д.56а, адрес УИК:ул.Лесная, д.34а		0101000020E610000014AFB2B6294A404097C4591135DF4C40
63374	3	31	773	6254	58177	\N	57.638517999999998	Демянский  район, д.Филиппова Гора, ул.Центральная, д.23		0101000020E610000069554B3ACA61404023F433F5BAD14C40
63373	3	31	773	6199	\N	\N	57.535173	Демянский  район, д.Тарасово, д.117		0101000020E61000008C2C996379394040E259828C80C44C40
63372	3	31	773	6165	\N	\N	57.534332999999997	Демянский  район,с.Полново,адрес помещения для голосования  ул.Набережная д.13 -адрес УИК: ул.Набережная, д.13а	Россия, Новгородская область, Демянский район, село Полново	0101000020E610000098158A743F7940403716140665C44C40
63371	3	31	773	6123	58184	\N	57.645383000000002	Демянский  район, д.Пески,  ул.Центральная, д.29\\2		0101000020E6100000730F09DFFB4D40407B32FFE89BD24C40
63370	3	31	773	6037	58166	\N	57.508696999999998	Демянский район, д.Новый Скребель, ул.Береговая, д.15		0101000020E6100000B2D7BB3FDE8740406249B9FB1CC14C40
63369	3	31	773	5968	58165	\N	57.728898999999998	Демянский район, с.Никольское, ул.Центральная, д.25		0101000020E6100000C47B0E2C47804040268BFB8F4CDD4C40
63359	3	31	773	52330	\N	\N	57.640802000000001	Демянский  район,  д.Малые Луки, помещение для голосования: ул.Молодежная, д.7, адрес УИК: д.Большие Луки, ул.Центральная, д.24		0101000020E6100000E8154F3DD24240400F9BC8CC05D24C40
63368	3	31	773	5963	58025	\N	57.912911999999999	Демянский  район, с.Лычково, адрес помещения для голосования: ул. 1 Мая, д.20, адрес УИК: ул.1 Мая, д30		0101000020E6100000034015376E3340401F10E84CDAF44C40
63367	3	31	773	5898	57955	\N	57.927447999999998	Демянский  район, п.Кневицы, адрес помещения для голосования: ул.Центральная, д.58, адрес УИК: ул.Центральная, д.49		0101000020E610000005C1E3DBBB1C4040CC5EB69DB6F64C40
63366	3	31	773	5818	58145	\N	57.580975000000002	Демянский  район, д.Ильина Гора, ул.Молодежная, д.5\\2		0101000020E6100000DDB6EF517F534040956588635DCA4C40
63365	3	31	773	5792	58157	\N	57.665593000000001	Демянский район, д.Жирково, адрес помещения для голосования: ул.Центральная, д.15, адрес УИК:ул.Центральная, д.9		0101000020E610000077F52A323A34404028B9C32632D54C40
63363	3	31	773	5626	\N	\N	57.650241999999999	п.Демянск, помещение для голосования: ул.Школьная, д.10, адрес УИК: ул.1Мая, д.63		0101000020E610000084A0A3552D3B4040293E3E213BD34C40
63361	3	31	773	5553	58132	\N	57.506149000000001	Демянский район, дер.Вотолино, адрес помещения для голосования: пер.Школьный, д.4, адрес УИК:ул.Центральная, д.1		0101000020E61000007B12D89C835B404099F38C7DC9C04C40
63360	3	31	773	57357	58216	\N	57.612568241471998	Демянский  район, дер.Великий Заход  ул.Центральная, д.32	Россия, Новгородская область, Демянский район, село Великий Завод	0101000020E61000002A8E03AF960F4040BF49D3A068CE4C40
63358	3	31	702	5416	58130	\N	57.765835000000003	Волотовский р-н  ,дер.Соловьёво, ул.Зеленая, д.47		0101000020E6100000D3A23EC91D9A3E40EB909BE106E24C40
63356	3	31	702	5307	58163	\N	57.816628000000001	Волотовский р-н  ,дер.Славитино, ул.Центральная, д.18		0101000020E6100000D1915CFE43B23E40BB7F2C4487E84C40
63351	3	31	702	5050	58161	\N	57.956502999999998	Волотовский р-н  ,дер.Раглицы, ул.Волотовская, д.6		0101000020E6100000079ACFB9DBBD3E4050C3B7B06EFA4C40
63349	3	31	702	4923	\N	\N	57.914504000000001	Волотовский р-н  ,дер.Порожки, д.2		0101000020E61000002497FF907EDB3E40D50792770EF54C40
63352	3	31	702	5071	\N	\N	57.881971	Волотовский р-н  ,дер.Дерглец, д.47		0101000020E6100000AB7B6473D5A03E409D82FC6CE4F04C40
63355	3	31	702	5231	58146	\N	57.979850999999996	Волотовский р-н  ,дер.Горки Ратицкие, ул.Центральная, д.17		0101000020E6100000AA7F10C9908F3E40F8F9EFC16BFD4C40
63354	3	31	702	5198	\N	\N	58.025599	Волотовский р-н  ,дер.Горицы, д.50		0101000020E6100000AC1A84B9DDD33E40B8E7F9D346034D40
63353	3	31	702	57358	58217	\N	57.987485397077897	Волотовский р-н  ,дер.Городцы, ул.Центральная, д.11	Россия, Новгородская область, Волотовский район, село Геородцы	0101000020E6100000404B57B08DC43E40312592E865FE4C40
63350	3	31	702	4899	58134	\N	57.927205000000001	Волотовский р-н  ,дер.Волот, ул.Победы, д.13		0101000020E6100000D1B2EE1F0BB53E4006D847A7AEF64C40
63348	3	31	702	4899	58005	\N	57.927205000000001	пос.Волот, ул.Комсомольская, д.38		0101000020E6100000D1B2EE1F0BB53E4006D847A7AEF64C40
63357	3	31	702	5328	\N	\N	57.778582999999998	Волотовский р-н  ,дер.Верехново, д.37		0101000020E6100000B3CEF8BEB8D43E405C1C959BA8E34C40
63343	3	31	526	4630	58022	\N	58.035302000000001	Валдайский р-он , с.Яжелбицы, ул.Усадьба, д.22		0101000020E6100000AC014A438D7A4040E0BDA3C684044D40
63340	3	31	526	4445	\N	\N	58.014031000000003	Валдайский р-он , д.Шуя, д.59		0101000020E6100000D8F15F2008B24040AA108FC4CB014D40
63341	3	31	526	4520	58144	\N	57.924084000000001	Валдайский р-он , д.Семёновщина, ул.Центральная, д.104		0101000020E61000000BD12170245A4040E1606F6248F64C40
63339	3	31	526	4398	\N	\N	58.024565000000003	Валдайский р-он , п.Рощино, д.11		0101000020E61000003E213B6F63A9404029D027F224034D40
63335	3	31	526	4162	58176	\N	58.132106	Валдайский р-он , п.Приозерный, ул.Центральная, д.36		0101000020E610000024624A24D18F40407DCD72D9E8104D40
63330	3	31	526	3917	\N	\N	57.843510999999999	Валдайский р-он , д.Наволок, д.20		0101000020E6100000D53C47E4BBB440407B681F2BF8EB4C40
63336	3	31	526	4245	58092	\N	57.969188000000003	Валдайский р-он , д.Любница, ул.Молодежная, д.79		0101000020E6100000827170E9985940407CD6355A0EFC4C40
63337	3	31	526	4297	58139	\N	58.010826999999999	Валдайский р-он , д.Лутовенка, ул.Школьная д.3		0101000020E61000001A6A1492CC644040F77475C762014D40
63329	3	31	526	3831	\N	\N	57.689	Валдайский р-он , д.Красилово, д.5		0101000020E6100000944E24986AAA4040D578E92631D84C40
63334	3	31	526	4137	58124	\N	58.121921999999998	Валдайский р-он , д.Костково, ул.Центральная, д.4		0101000020E6100000ACE122F774854040DA54DD239B0F4D40
63333	3	31	526	4036	58164	\N	57.938591000000002	Валдайский р-он , п.Короцко, ул.Центральная, д.8а		0101000020E6100000B4006DAB599F4040F4A8F8BF23F84C40
63332	3	31	526	4025	58187	\N	57.794894999999997	Валдайский р-он , д.Ивантеево, ул.Зеленая, д.1		0101000020E61000004776A565A492404080608E1EBFE54C40
63326	3	31	526	3707	58088	\N	57.956516999999998	Валдайский р-он , с.Зимогорье, ул.Почтовая, д.3		0101000020E6100000B6114F7633A34040B58828266FFA4C40
63327	3	31	526	3751	57996	\N	57.913333000000002	Валдайский р-он , с.Едрово, ул.Сосновая, д.54		0101000020E6100000ADA3AA09A2CE4040C5AD8218E8F44C40
63328	3	31	526	3825	\N	\N	57.940430999999997	Валдайский р-он , д.Добывалово, д.6		0101000020E61000009F3E027FF8B740408192020B60F84C40
63345	3	31	526	4708	\N	\N	57.943196999999998	Валдайский р-он , д.Дворец, д.30		0101000020E61000006F48A302277F4040B857E6ADBAF84C40
63338	3	31	526	3192	58120	\N	57.979816999999997	г.Валдай ,  Энергетиков д.16		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63321	3	31	526	3192	57998	\N	57.979757837285298	г.Валдай, ул.Труда, д.63а	Россия, Новгородская область, Валдайский район, Валдай	0101000020E610000059C2DA183B9F404047FFCBB568FD4C40
63318	3	31	526	3192	57973	\N	57.979816999999997	г.Валдай, ул.Молодежная, д.14		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63317	3	31	526	3192	58108	\N	57.979816999999997	г.Валдай, ул.Мелиораторов, д.1а		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63324	3	31	526	3192	57986	\N	57.979816999999997	г.Валдай, ул.Луначарского, д.27		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63322	3	31	526	3192	57988	\N	57.979816999999997	г.Валдай, ул.Гагарина, д.42а		0101000020E610000030849CF7FF9F40404C88B9A46AFD4C40
63342	3	31	526	4540	58149	\N	57.790137000000001	Валдайский р-он , д.Большое Замошье, ул.Четвертая, д.8		0101000020E610000057E883656C684040062E8F3523E54C40
63315	3	31	44	3093	58223	\N	58.659861999999997	Боровичский район ,п.Удино, Садовая, 9		0101000020E61000002619390B7B284140C3EFA65B76544D40
63301	3	31	44	46389	\N	\N	58.465958999999998	Боровичский район ,п.Тухун, 25		0101000020E61000000B7C45B75E0B41407023658BA43B4D40
63312	3	31	44	2953	58266	\N	58.307521000000001	Боровичский район ,д.Травково, Новая, 1		0101000020E6100000BD8C62B9A5D94040A7EA1ED95C274D40
63311	3	31	44	2847	\N	\N	58.418854000000003	Боровичский район ,д.Сушилово, 2		0101000020E6100000D6C6D8092FCF40403FE603029D354D40
63314	3	31	44	3042	\N	\N	58.268383	Боровичский район ,д.Сутоко-Рядок, 14		0101000020E6100000362383DC45DA4040B4E6C75F5A224D40
63308	3	31	44	57364	\N	\N	58.1801097148767	Боровичский район ,д.Речка, 53	Россия, Новгородская область, Боровичский район, село Речка	0101000020E6100000A6D3BA0D6AED40405ED72FD80D174D40
63304	3	31	44	2498	\N	\N	58.308976999999999	"Боровичский район ,""д.Прошково, здание ГУСО Боровичский интернат """"Прошково"""""""	Россия, Новгородская область, Боровичский район, село Прошково	0101000020E61000006397A8DE1AF04040AC1BEF8E8C274D40
63306	3	31	44	2605	58248	\N	58.401448000000002	Боровичский район ,п.Прогресс, Зеленая, 11		0101000020E6100000A9674128EFF74040B685E7A562334D40
63299	3	31	44	2171	58270	\N	58.275748	Боровичский район ,с.Опеченский Посад, 1 линия, 18		0101000020E6100000CA3505323B0F4140FDF7E0B54B234D40
63303	3	31	44	41058	58321	\N	58.341209897693503	Боровичский район ,д.Круппа, Новая, 24	Россия, Новгородская область, Боровичский район, село Круппа	0101000020E6100000D369DD06B5F14040B988EFC4AC2B4D40
63298	3	31	44	57368	58318	\N	58.654906209172999	Боровичский район ,с.Кончанское -Суворовское, Молодежная, 4	Россия, Новгородская область, Боровичский район, село Кончанско-Суворовское	0101000020E6100000E2AFC91AF508414022FAB5F5D3534D40
63309	3	31	44	2742	58221	\N	58.423457999999997	Боровичский район ,д.Коегоща,ул.Центральная д. 18		0101000020E6100000D388997D1EF14040629D2ADF33364D40
63297	3	31	44	2063	58304	\N	58.588782000000002	Боровичский район ,п.Кировский, Маяковского, 2		0101000020E61000000CCA349A5CDE40409B3C65355D4B4D40
63313	3	31	44	2994	\N	\N	58.380533	Боровичский район ,п.Желомля, 1		0101000020E61000008DEF8B4B55E840403E062B4EB5304D40
63295	3	31	44	1956	\N	\N	58.286143000000003	Боровичский район ,д.Железково, д. 16,		0101000020E61000007C80EECB99F740405B7D7555A0244D40
63293	3	31	44	1802	\N	\N	58.625543999999998	Боровичский район ,д.Елигово, здание Елиговского сельского клуба	Россия, Новгородская область, Боровичский район, село Елигово	0101000020E610000043E55FCB2BCF4040C11A67D311504D40
63294	3	31	44	1903	58226	\N	58.318725000000001	Боровичский район ,д.Ёгла, Советская, 90		0101000020E6100000A1BE654E97FF404074B515FBCB284D40
63292	3	31	44	1798	58252	\N	58.514932999999999	Боровичский район ,д.Волок, Центральная, 1		0101000020E6100000A016838769E14040CA501553E9414D40
63310	3	31	44	2838	58225	\N	58.44585	Боровичский район ,п.Волгино, Центральная, 2е		0101000020E61000007100FDBE7FEF4040F775E09C11394D40
63280	3	31	44	52	58019	\N	58.382935000000003	г.Боровичи, пл.Труда, 15		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63269	3	31	44	52	57981	\N	58.382935000000003	г.Боровичи, пл.Володарского, 32		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63263	3	31	44	52	57951	\N	58.382935000000003	г.Боровичи, Энгельса, 22		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63279	3	31	44	52	58017	\N	58.382935000000003	г.Боровичи, Школьный бульвар, 10		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63262	3	31	44	52	57956	\N	58.405439211132098	г.Боровичи, Сушанская, 11	Россия, Новгородская область, Боровичский район, Боровичи	0101000020E6100000B114C95702F34040F0C2D66CE5334D40
63261	3	31	44	52	57956	\N	58.404211568652201	г.Боровичи, Сушанская, 3	Россия, Новгородская область, Боровичский район, Боровичи	0101000020E61000005F46B1DCD2F240404C530438BD334D40
63277	3	31	44	52	58107	\N	58.382935000000003	г.Боровичи, Советская, 124		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63260	3	31	44	52	58002	\N	58.382935000000003	г.Боровичи, С.Перовской, 92А		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63291	3	31	44	52	58232	\N	58.382935000000003	"г.Боровичи, 1 Раздолье, здание столовой ЗАО """"Боровичская ПМК"""""""		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63281	3	31	44	52	58034	\N	58.390135664782299	г.Боровичи, Р.Люксембург, 16	Россия, Новгородская область, Боровичский район, Боровичи	0101000020E61000002882380F27F64040027FF8F9EF314D40
63267	3	31	44	52	57979	\N	58.394938102686297	г.Боровичи, Подбельского, 47	Россия, Новгородская область, Боровичский район, Боровичи	0101000020E61000003E3DB665C0F540404DF910548D324D40
63274	3	31	44	52	58020	\N	58.382935000000003	г.Боровичи, Парковая, 1		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63289	3	31	44	52	58231	\N	58.382935000000003	г.Боровичи, ул.Молодой Гвардии д.11а		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63284	3	31	44	52	57960	\N	58.382935000000003	г.Боровичи, Ленинградская, 99		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63276	3	31	44	52	57954	\N	58.382935000000003	г.Боровичи, Красноармейская, 2А		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63265	3	31	44	52	57953	\N	58.382935000000003	г.Боровичи, Кооперативная, 51		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63272	3	31	44	52	57964	\N	58.382935000000003	г.Боровичи, Коммунарная, 2		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63266	3	31	44	52	57971	\N	58.382935000000003	г.Боровичи, Декабристов, 55		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63287	3	31	44	52	57969	\N	58.382935000000003	г.Боровичи, Гончарная, 33		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63290	3	31	44	52	58033	\N	58.382935000000003	г.Боровичи, В.Бианки, 35		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63264	3	31	44	52	57952	\N	58.382935000000003	г.Боровичи, Ботаническая, 9		0101000020E61000009DF7FF71C2F4404034BF9A0304314D40
63307	3	31	44	2655	\N	\N	58.491470999999997	Боровичский район ,д.Березник,д.14 здание сельской библиотеки		0101000020E6100000B62E35423FEF404059F78F85E83E4D40
63296	3	31	44	2014	\N	\N	58.302740999999997	Боровичский район ,д.Ануфриево, 82А		0101000020E610000082548A1D8DFD404044149337C0264D40
63252	3	31	952	32006	\N	\N	58.644534	Батецкий р-он ,д.Черное, д.46		0101000020E610000044DD0720B5AD3E407D94111780524D40
63257	3	31	952	9502	58101	\N	58.491762000000001	Батецкий р-он ,д.Новое Овсино, адрес помещения для голосования: ул.Школьная, д.2, адрес УИК: ул.Центральная,д.2		0101000020E6100000F1D6F9B7CB4A3E4031B5A50EF23E4D40
63253	3	31	952	32042	58167	\N	58.624251000000001	Батецкий р-он ,д.Мойка, ул.Ветеранов, 6		0101000020E6100000A70705A568A13E4066BFEE74E74F4D40
63258	3	31	952	7778	58128	\N	58.435163000000003	Батецкий р-он ,д.Мелковичи, ул.Молодежная, д.20		0101000020E6100000751E15FF77303E40F2B6D26BB3374D40
63256	3	31	952	11611	58175	\N	58.474454000000001	Батецкий р-он ,д.Косицкое, ул.Центральная, д.28		0101000020E6100000583849F3C7743E406BBA9EE8BA3C4D40
63251	3	31	952	31968	58129	\N	58.681148999999998	Батецкий р-он ,д.Городня, адрес помещения для голосования: ул.Юбилейная,д.36 , адрес УИК: ул.Юбилейная, д.36 (Адм.Бат.с.пос.)		0101000020E61000003F390A10053B3E40FF59F3E32F574D40
63255	3	31	952	32151	\N	\N	58.564945999999999	Батецкий р-он ,д.Воронино, д.31		0101000020E61000000342EBE1CB983E40C500892650484D40
63254	3	31	952	11516	\N	\N	58.719163999999999	Батецкий р-он ,д.Вольная Горка, адрес помещения для голосования: д.90, адрес УИК: д.92		0101000020E6100000C18EFF0241D83E40F33AE2900D5C4D40
63249	3	31	952	31839	58023	\N	58.645460999999997	п.Батецкий, адрес помещения для голосования: ул.Советская, д.4, адрес УИК: ул.Советская, д.39а		0101000020E6100000A2F14410E74D3E40F6EB4E779E524D40
63250	3	31	952	31839	57999	\N	58.645460999999997	п.Батецкий, адрес помещения для голосования: ул.Первомайская, д.24, адрес УИК: ул.Советская, д39а		0101000020E6100000A2F14410E74D3E40F6EB4E779E524D40
60711	3	60	\N	4831	\N	\N	67.121341000000001	Великовисочный сельсовет, деревня Щелино, Здание дома культуры	Россия, Ненецкий автономный округ, село Щелино	0101000020E61000005F5E807D74044A407EAA0A0DC4C75040
60693	3	60	\N	3864	\N	\N	67.877731999999995	Шоинский сельсовет, село Шойна, Дом культуры		0101000020E61000001172DEFFC7134640C5A9D6C22CF85040
60695	3	60	\N	3931	\N	\N	67.085357999999999	Канинский сельсовет, деревня Чижа, Здание школы	Россия, Ненецкий автономный округ, село Чижа	0101000020E61000001C60E63BF82F4640ED9C668176C55040
60725	3	60	\N	5588	\N	\N	67.421120999999999	Хорей-Верский сельсовет, поселок Хорей-Вер, Здание Администрации МО	Россия, Ненецкий автономный округ, село Хорей-Вер	0101000020E6100000A04E797423064D402AAA7EA5F3DA5040
60714	3	60	\N	5009	\N	\N	67.557648999999998	Пустозерский сельсовет, поселок Хонгурей, Здание дома культуры	Россия, Ненецкий автономный округ, село Хонгурей	0101000020E61000005CCAF962EFF949406A696E85B0E35040
60727	3	60	\N	5700	\N	\N	69.244187999999994	Карский сельсовет, поселок Усть-Кара, Здание дома культуры	Россия, Ненецкий автономный округ, село Усть-Кара	0101000020E6100000647616BD533B5040D784B4C6A04F5140
60710	3	60	\N	4774	\N	\N	67.121373000000006	Великовисочный сельсовет, деревня Тошвиска, Здание дома культуры	Россия, Ненецкий автономный округ, село Тошвиска	0101000020E610000000AE64C746264A4084674293C4C75040
60717	3	60	\N	5135	\N	\N	67.633684000000002	Тельвисочный сельсовет, село Тельвиска, Здание дома культуры	Россия, Ненецкий автономный округ, село Тельвиска	0101000020E6100000D8D47954FC714A40E7FF55478EE85040
60700	3	60	\N	4252	\N	\N	66.742542	Омский сельсовет, деревня Снопа, Здание школы	Россия, Ненецкий автономный округ, село Снопа	0101000020E61000000DA7CCCD37824740037AE1CE85AF5040
60713	3	60	\N	4941	\N	\N	67.410757000000004	Великовисочный сельсовет, деревня Пылемец, Здание киновидеопоказа	Россия, Ненецкий автономный округ, село Пылемец	0101000020E6100000B11A4B581B214A409966BAD749DA5040
60699	3	60	\N	4177	\N	\N	66.643709000000001	Омский сельсовет, село Ома, Здание дома культуры	Россия, Ненецкий автономный округ, село Ома	0101000020E6100000BDC799266C3F474004C93B8732A95040
60716	3	60	\N	5081	\N	\N	67.585801000000004	Пустозерский сельсовет, село Оксино, Здание дома культуры	Россия, Ненецкий автономный округ, село Оксино	0101000020E610000075E61E12BE174A40B43D7AC37DE55040
60701	3	60	\N	4259	\N	\N	66.752571000000003	Пешский сельсовет, село Нижняя Пеша, Здание дома культуры	Россия, Ненецкий автономный округ, село Нижняя Пеша	0101000020E6100000B3EC496073E24740C13A8E1F2AB05040
60696	3	60	\N	4021	\N	\N	66.602588740701293	Канинский сельсовет, село Несь, Здание дома народного творчества		0101000020E610000053CDACA5805646407AFB73D190A65040
60721	3	60	\N	5344	\N	\N	67.982192999999995	Малоземельский сельсовет, поселок Нельмин-Нос, Здание дома культуры	Россия, Ненецкий автономный округ, село Нельмин Нос	0101000020E6100000FDDB65BFEE7A4A400C570740DCFE5040
60739	3	60	\N	5949	39580	\N	67.639926209667607	город Нарьян-Мар, проезд капитана Матросова, 1	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E6100000AEB8382A377F4A400C772E8CF4E85040
60732	3	60	\N	5949	39626	\N	67.645276999999993	город Нарьян-Мар, Юбилейная, 22		0101000020E6100000F12900C633864A401AF7E6374CE95040
60741	3	60	\N	5949	39571	\N	67.635537963328304	город Нарьян-Мар, Студенческая, 3	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E610000021205F42057F4A40605793A7ACE85040
60740	3	60	\N	5949	39571	\N	67.634818768547703	город Нарьян-Мар, Студенческая, 1	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E610000001E0D8B3E77E4A4048F8DEDFA0E85040
60734	3	60	\N	5949	40318	\N	67.645276999999993	город Нарьян-Мар, Строительная, 13		0101000020E6100000F12900C633864A401AF7E6374CE95040
60737	3	60	\N	5949	39604	\N	67.641200854059704	город Нарьян-Мар, Смидовича, 20А	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E6100000D5B14AE999804A40664AEB6F09E95040
60735	3	60	\N	5949	39600	\N	67.640988418124294	город Нарьян-Мар, Рабочая, 22	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E61000004C1762F547864A40384888F205E95040
60738	3	60	\N	5949	39566	\N	67.636208102315095	город Нарьян-Мар, Ленина, 23Б	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E61000007496598462834A40075DC2A1B7E85040
60736	3	60	\N	5949	39566	\N	67.636224446929901	город Нарьян-Мар, Ленина, 25	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E61000008A22A46E67834A408A3BDEE4B7E85040
60733	3	60	\N	5949	39598	\N	67.645338886768499	город Нарьян-Мар, Заводская, 9	Россия, Ненецкий автономный округ, Нарьян-Мар	0101000020E6100000E4D9E55B1F864A4056F5F23B4DE95040
60718	3	60	\N	49588	\N	\N	67.684782999999996	Тельвисочный сельсовет, деревня Макарово, Здание дома культуры	Россия, Ненецкий автономный округ, село Макарово	0101000020E61000008C4CC0AF91704A40D576137CD3EB5040
60712	3	60	\N	4865	\N	\N	67.330994000000004	"Великовисочный сельсовет, деревня Лабожское, Здание правления СПК РК ""Родина"""	Россия, Ненецкий автономный округ, село Лабожское	0101000020E61000001FD95C35CF0B4A40064B75012FD55040
60719	3	60	\N	5264	\N	\N	67.771330000000006	Приморско-Куйский сельсовет, деревня Куя, Здание дома культуры	Россия, Ненецкий автономный округ, село Куя	0101000020E610000001F9122A38A24A401E1B81785DF15040
60720	3	60	\N	45357	\N	\N	67.834939000000006	Приморско-Куйский сельсовет, поселок Красное, Здание дома культуры		0101000020E6100000EFFFE38409CD4A40EBC9FCA36FF55040
60708	3	60	\N	4660	\N	\N	67.031728999999999	Коткинский сельсовет, село Коткино, Здание Администрации МО	Россия, Ненецкий автономный округ, село Коткино	0101000020E6100000A6F0A0D9759149406D5512D907C25040
60619	3	30	\N	358	32682	\N	69.066434999999998	Мурманская область,  г.Североморск, ул.Колышкина, д.11		0101000020E610000048C153C895B64040D313967840445140
60694	3	60	\N	49257	\N	\N	67.655443000000005	"Шоинский сельсовет, деревня Кия, Здание правления СПК ""Северный полюс"""	Россия, Ненецкий автономный округ, село Кия	0101000020E6100000BFF2203D450C4640195932C7F2E95040
60724	3	60	\N	5508	\N	\N	68.761829000000006	Юшарский сельсовет, поселок Каратайка, Здание дома культуры	Россия, Ненецкий автономный округ, село Каратайка	0101000020E6100000A0DE8C9AAFB44E403E096CCEC1305140
60715	3	60	\N	49533	\N	\N	67.486980000000003	Пустозерский сельсовет, деревня Каменка, Здание дома культуры	Россия, Ненецкий автономный округ, село Каменка	0101000020E610000072361D01DCF04940977329AE2ADF5040
60730	3	60	\N	3080	\N	\N	67.674439000000007	п.Искателей ул.Ардалина, 15		0101000020E610000025E659492B904A40680932022AEB5040
95201	3	60	\N	3080	40319	\N	67.674439000000007	пос.Искателей, ул.Юбилейная, д.80А		0101000020E610000025E659492B904A40680932022AEB5040
60731	3	60	\N	3080	59468	\N	67.674439000000007	"пос.Искателей, ул.Тиманская, д.24А, помещение ООО ""Нефтестройсервис"""		0101000020E610000025E659492B904A40680932022AEB5040
60679	3	60	\N	3080	39577	\N	67.674439000000007	п. Искателей, Ардалина,15		0101000020E610000025E659492B904A40680932022AEB5040
60729	3	60	\N	3080	59470	\N	67.675691244844103	ул. Губкина, 5б Здание ДЮСШ	Россия, Ненецкий автономный округ, поселок Искателей	0101000020E610000096404AECDA8E4A40E6CC76853EEB5040
60706	3	60	\N	4560	\N	\N	67.689831999999996	Тиманский сельсовет, поселок Индига, Здание дома культуры	Россия, Ненецкий автономный округ, село Индига	0101000020E610000015AB06616E574840FEEE1D3526EC5040
60707	3	60	\N	4641	\N	\N	67.569103999999996	Тиманский сельсовет, поселок Выучейский, Здание дома культуры	Россия, Ненецкий автономный округ, село Выучейский	0101000020E610000003E962D34A87484075012F336CE45040
60705	3	60	\N	49385	\N	\N	67.129932999999994	Пешский сельсовет, деревня Волонга, Здание дома культуры	Россия, Ненецкий автономный округ, село Волонга	0101000020E610000042B0AA5E7EE34740F46A80D250C85040
60703	3	60	\N	49357	\N	\N	66.483958000000001	Пешский сельсовет, деревня Волоковая, Здание дома культуры	Россия, Ненецкий автономный округ, село Волоковая	0101000020E6100000207EFE7BF01E4840CEA8F92AF99E5040
60698	3	60	\N	4121	\N	\N	66.642253999999994	Омский сельсовет, деревня Вижас, Здание дома культуры	Россия, Ненецкий автономный округ, село Вижас	0101000020E6100000C9C9C4AD82F24640696E85B01AA95040
60702	3	60	\N	4333	\N	\N	66.608806999999999	Пешский сельсовет, деревня Верхняя Пеша, Здание дома культуры	Россия, Ненецкий автономный округ, село Верхняя Пеша	0101000020E6100000E960FD9FC3FA4740DBA4A2B1F6A65040
60709	3	60	\N	4737	\N	\N	67.256401999999994	Великовисочный сельсовет, село Великовисочное, Здание дома культуры	Россия, Ненецкий автономный округ, село Великовисочное	0101000020E61000000EDB166536044A404128EFE368D05040
60697	3	60	\N	54901	\N	\N	68.782921000000002	Колгуевский сельсовет, поселок Бугрино, Здание Администрации МО		0101000020E6100000B6BFB33D7AA748408196AE601B325140
60704	3	60	\N	4442	\N	\N	66.893424999999993	Пешский сельсовет, деревня Белушье, Здание дома культуры	Россия, Ненецкий автономный округ, село Белушье	0101000020E610000027158DB5BFCD4740711B0DE02DB95040
60722	3	60	\N	5423	\N	\N	67.889527000000001	Андегский сельсовет, деревня Андег, Здание дома культуры	Россия, Ненецкий автономный округ, село Андег	0101000020E6100000938AC6DADF9B4A402D7AA702EEF85040
60723	3	60	\N	54900	\N	\N	69.758802000000003	Сельское поселение Рабочий поселок Амдерма, Здание дома культуры	Россия, Ненецкий автономный округ, поселок Амдерма	0101000020E6100000A9328CBB41D64E40EC88433690705140
60726	3	60	3735	35594	\N	\N	66.840411000000003	Хоседа-Хардский сельсовет, поселок Харута, Здание сельского культурного центра	Россия, республика Коми, Интинский район, село Харута	0101000020E61000003ECF9F36AAC34D40B70C384BC9B55040
60506	3	30	\N	53309	\N	\N	68.086178000000004	ж-д ст. Лопарская, 16 "Б"		0101000020E6100000E2CD1ABCAF7441409FE8BAF083055140
60649	3	30	\N	1028	32738	\N	69.194131999999996	г.Снежногорск, мкр.Скальный, 5		0101000020E6100000516A2FA2ED9E4040DAC69FA86C4C5140
60644	3	30	\N	1028	32189	\N	69.194131999999996	г.Снежногорск, Флотская, 10		0101000020E6100000516A2FA2ED9E4040DAC69FA86C4C5140
60647	3	30	\N	1028	32156	\N	69.194131999999996	г.Снежногорск, Павла Стеблина, 19		0101000020E6100000516A2FA2ED9E4040DAC69FA86C4C5140
60643	3	30	\N	1028	32156	\N	69.194131999999996	г.Снежногорск, Павла Стеблина, 5		0101000020E6100000516A2FA2ED9E4040DAC69FA86C4C5140
60646	3	30	\N	1028	32680	\N	69.194131999999996	г.Снежногорск, Октябрьская, 12		0101000020E6100000516A2FA2ED9E4040DAC69FA86C4C5140
60648	3	30	\N	1028	32712	\N	69.194131999999996	г.Снежногорск, Мира, 3		0101000020E6100000516A2FA2ED9E4040DAC69FA86C4C5140
60645	3	30	\N	1028	32811	\N	69.194131999999996	г.Снежногорск, Валентина Бирюкова, 21		0101000020E6100000516A2FA2ED9E4040DAC69FA86C4C5140
60616	3	30	\N	358	32699	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Советская, д.23а		0101000020E610000048C153C895B64040D313967840445140
60615	3	30	\N	358	32809	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Северная Застава, д.1		0101000020E610000048C153C895B64040D313967840445140
60614	3	30	\N	358	32746	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Саши Ковалева, д.7		0101000020E610000048C153C895B64040D313967840445140
60618	3	30	\N	358	32184	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Полярная, д.11		0101000020E610000048C153C895B64040D313967840445140
60617	3	30	\N	358	32162	\N	69.067781536059996	Мурманская область, г.Североморск, ул.Падорина, д.2	Россия, Мурманская область, Североморск	0101000020E6100000E42CEC6987B340407A50508A56445140
60623	3	30	\N	358	32770	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Кортик, д.14		0101000020E610000048C153C895B64040D313967840445140
60621	3	30	\N	358	32177	\N	69.069020631096194	Мурманская область,  г.Североморск, ул.Комсомольская, д.33	Россия, Мурманская область, Североморск	0101000020E61000006D1B4641F0B240402F6F0ED76A445140
60620	3	30	\N	358	32177	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Комсомольская, д.33		0101000020E610000048C153C895B64040D313967840445140
60613	3	30	\N	358	32676	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Кирова, д.19		0101000020E610000048C153C895B64040D313967840445140
60612	3	30	\N	358	32174	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Душенова, д.13а		0101000020E610000048C153C895B64040D313967840445140
60610	3	30	\N	358	32174	\N	69.071721078043893	город Североморск, ул.Душенова, д.10 а		0101000020E610000094BF7B478DB54040EE5BAD1397445140
60609	3	30	\N	358	32174	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Душенова, д.19а		0101000020E610000048C153C895B64040D313967840445140
60622	3	30	\N	358	32193	\N	69.066434999999998	Мурманская область, г.Североморск, ул.Гвардейская, д.26		0101000020E610000048C153C895B64040D313967840445140
60607	3	30	\N	53417	32884	\N	68.960559020840904	нп Африканда-1, Кирова, 2, ЖКХ	Россия, Мурманская область, Мурманск, Октябрьский административный округ	0101000020E6100000A4C2D842908F404039B874CC793D5140
60598	3	30	\N	30878	32185	\N	69.199110000000005	г.Полярный, Лунина, 6		0101000020E6100000BFB67EFACFB840409F93DE37BE4C5140
60596	3	30	\N	30878	32747	\N	69.199110000000005	г.Полярный, Красный Горн, 6		0101000020E6100000BFB67EFACFB840409F93DE37BE4C5140
60593	3	30	\N	30878	32801	\N	69.199110000000005	г.Полярный, Котельникова, 6		0101000020E6100000BFB67EFACFB840409F93DE37BE4C5140
60595	3	30	\N	30878	32683	\N	69.199110000000005	г.Полярный, Душенова, 4		0101000020E6100000BFB67EFACFB840409F93DE37BE4C5140
60592	3	30	\N	30878	32790	\N	69.199110000000005	г.Полярный, Героев Североморцев, 3		0101000020E6100000BFB67EFACFB840409F93DE37BE4C5140
60594	3	30	\N	30878	32202	\N	69.199899426250695	Мурманская область, закрытое административно-территориальное образование Александровск, город Полярный, улица Гаджиева, дом 3		0101000020E6100000F4C0C760C5B9404033E02C25CB4C5140
60597	3	30	\N	30878	32787	\N	69.199110000000005	г.Полярный, Гагарина, 1		0101000020E6100000BFB67EFACFB840409F93DE37BE4C5140
60642	3	30	\N	53412	32843	\N	69.214584000000002	н.п. Оленья Губа, Строителей, 26/1	Россия, Мурманская область, село Оленья Губа	0101000020E6100000E22021CA17A64040AC8F87BEBB4D5140
60558	3	30	\N	3431	32744	\N	68.138013000000001	Мурманская область, г.Оленегорск, ул.Южная, д.11а		0101000020E610000064B14D2A1AA34040105B7A34D5085140
60560	3	30	\N	3431	32719	\N	68.138013000000001	Мурманская область, г.Оленегорск, ул. Энергетиков, д. 3		0101000020E610000064B14D2A1AA34040105B7A34D5085140
60559	3	30	\N	3431	32167	\N	68.138013000000001	Мурманская область, г.Оленегорск, ул.Строительная, д.61		0101000020E610000064B14D2A1AA34040105B7A34D5085140
60554	3	30	\N	3431	32167	\N	68.141771607327399	Мурманская область, г.Оленегорск, ул.Строительная, д.22	Россия, Мурманская область, Оленегорск	0101000020E61000003753211E89A5404044DFDDCA12095140
60481	3	30	\N	3431	32706	\N	68.138013000000001	Мурманская область, г.Оленегорск, ул.Парковая, д.26		0101000020E610000064B14D2A1AA34040105B7A34D5085140
60555	3	30	\N	3431	32168	\N	68.1443298115733	Мурманская область, г.Оленегорск, ул.Мира, д.48	Россия, Мурманская область, Оленегорск	0101000020E610000081785DBF60A140403A75E5B33C095140
60552	3	30	\N	3431	32168	\N	68.138013000000001	Мурманская область, г.Оленегорск, ул.Мира, д.38а		0101000020E610000064B14D2A1AA34040105B7A34D5085140
60551	3	30	\N	3431	32168	\N	68.138906657177102	Мурманская область, муниципальное образование город Оленегорск с подведомственной территорией, ул.Мира, д.38а	Россия, Мурманская область, Оленегорск	0101000020E61000008061F9F36DA34040DF8B2FDAE3085140
60557	3	30	\N	3431	32170	\N	68.138013000000001	Мурманская область, г.Оленегорск, Ленинградский проспект, д.5		0101000020E610000064B14D2A1AA34040105B7A34D5085140
60391	3	30	\N	2533	701	\N	69.024889000000002	город Мурманск, Лобова,47	Россия, Мурманская область, Мурманск, улица адмирала Лобова, 47	0101000020E6100000D8F50B76C38A4040EE4108C897415140
60319	3	30	\N	2533	4886	\N	68.999510000000001	Мурманская область, город Мурманск, Халатина, 17	Россия, Мурманская область, Мурманск, улица Халатина, 17	0101000020E6100000A88DEA74208B40409981CAF8F73F5140
60329	3	30	\N	2533	5014	\N	68.983857999999998	Мурманская область, город Мурманск, Туристов, 34, а	Россия, Мурманская область, Мурманск, улица Туристов, 34а	0101000020E610000084471B47AC8B40401C7A8B87F73E5140
60306	3	30	\N	2533	647	\N	69.024817999999996	Мурманская область, город Мурманск, Торцева, 14	Россия, Мурманская область, Мурманск, улица Торцева, 15	0101000020E6100000E564E256418A404089963C9E96415140
60345	3	30	\N	2533	5212	\N	68.973607999999999	Мурманская область, город Мурманск, Скальная, 12	Россия, Мурманская область, Мурманск, улица Скальная, 12	0101000020E61000006B48DC63E98D4040EFC7ED974F3E5140
60342	3	30	\N	2533	5181	\N	68.971502000000001	Мурманская область, город Мурманск, Папанина, 3	Россия, Мурманская область, Мурманск, улица Папанина, 3	0101000020E610000078280AF4898C4040E97FB9162D3E5140
60308	3	30	\N	2533	4759	\N	69.02216	Мурманская область, город Мурманск, Нахимова, 21	Россия, Мурманская область, Мурманск, улица Нахимова, 21	0101000020E6100000A6608DB3E98A4040E1D1C6116B415140
60396	3	30	\N	2533	5830	\N	68.889425000000003	Мурманская область, город Мурманск, Крупской, 13	Россия, Мурманская область, Мурманск, улица Крупской, 13	0101000020E6100000B6BFB33D7A8B4040ABCFD556EC385140
60341	3	30	\N	2533	5169	\N	68.967859000000004	Мурманская область, город Мурманск, Комсомольская, 13	Россия, Мурманская область, Мурманск, улица Комсомольская, 13	0101000020E6100000C6504EB4AB884040EA08E066F13D5140
60337	3	30	\N	2533	5119	\N	68.970688999999993	Мурманская область, город Мурманск, Карла Маркса, 13	Россия, Мурманская область, Мурманск, улица Карла Маркса, 13	0101000020E610000091291F82AA8B40409065C1C41F3E5140
60330	3	30	\N	2533	5039	\N	68.980649	Мурманская область, город Мурманск, Карла Либкнехта, 34, а	Россия, Мурманская область, Мурманск, улица Карла Либкнехта, 34	0101000020E61000004EF2237EC58A4040BAF605F4C23E5140
60380	3	30	\N	2533	5630	\N	68.937965000000005	Мурманская область, город Мурманск, Зои Космодемьянской, 13	Россия, Мурманская область, Мурманск, улица Зои Космодемьянской, 13	0101000020E6100000D906EE409D8E4040BBF2599E073C5140
60322	3	30	\N	2533	4930	\N	68.999481000000003	Мурманская область, город Мурманск, Александрова, 32, 2	Россия, Мурманская область, Мурманск, улица Александрова, 32/2	0101000020E61000004792205C018940404CFE277FF73F5140
60315	3	30	\N	2533	662	\N	69.006218000000004	Мурманская область, город Мурманск, Александра Невского, 86	Россия, Мурманская область, Мурманск, улица Александра Невского, 86	0101000020E610000041D3122BA38B404061A92EE065405140
60654	3	30	\N	2533	28864	\N	68.951464000000001	Мурманская область, Терский район, п.г.т. Умба, ул. Кирова, д.15	Россия, Мурманская область, Мурманск, проспект Кирова, 15	0101000020E6100000132D793C2D89404091D442C9E43C5140
60351	3	30	\N	2533	32859	\N	68.963275999999993	Мурманская область, город Мурманск, Капитана Тарана, 1		0101000020E610000088821953B08A404063416150A63D5140
60395	3	30	\N	2533	32892	\N	68.893789999999996	Мурманская область, город Мурманск, Капитана Копытова, 36		0101000020E6100000AB97DF69328B40407ADFF8DA33395140
60389	3	30	\N	2533	5752	\N	68.911006999999998	Мурманская область, город Мурманск, Якорный, 5	Россия, Мурманская область, Мурманск, Якорный переулок, 5	0101000020E6100000EA3D95D39E8C404055DB4DF04D3A5140
60316	3	30	\N	2533	32839	\N	69.002964000000006	Мурманская область, город Мурманск, Чумбарова-Лучинского, 3, б		0101000020E6100000EE7893DFA28B40402FC4EA8F30405140
60362	3	30	\N	2533	32858	\N	68.954014999999998	Мурманская область, город Мурманск, Чехова, 11		0101000020E61000007C2AA73D258F40402E39EE940E3D5140
60331	3	30	\N	2533	32887	\N	68.977356999999998	Мурманская область, город Мурманск, Челюскинцев, 14		0101000020E61000000283A44FAB8A404011E15F048D3E5140
60320	3	30	\N	2533	32881	\N	68.998465999999993	Мурманская область, город Мурманск, Халатина, 7		0101000020E61000005DC47762D68B4040BF0AF0DDE63F5140
60307	3	30	\N	2533	32825	\N	69.025593999999998	Мурманская область, город Мурманск, Торцева, 1		0101000020E6100000842EE1D05B8A4040533E0455A3415140
60372	3	30	\N	2533	32898	\N	68.953944000000007	Мурманская область, город Мурманск, Спортивная, 13		0101000020E610000062D7F6764B884040CA8D226B0D3D5140
60383	3	30	\N	2533	32891	\N	68.931447000000006	Мурманская область, город Мурманск, Спартака, 11		0101000020E6100000D07EA4880C8F404045BDE0D39C3B5140
60338	3	30	\N	2533	32867	\N	68.968294999999998	Мурманская область, город Мурманск, Софьи Перовской, 3		0101000020E6100000E76ED74B538A40405778978BF83D5140
60347	3	30	\N	2533	5232	\N	68.967872	Мурманская область, город Мурманск, Связи, 30	Россия, Мурманская область, Мурманск, Связи проезд, 30	0101000020E61000002EC55565DF8D4040B4AD669DF13D5140
60311	3	30	\N	2533	32866	\N	69.017214999999993	Мурманская область, город Мурманск, Сафонова, 11		0101000020E6100000F1B913ECBF8A40400A80F10C1A415140
60310	3	30	\N	2533	32866	\N	69.019974000000005	Мурманская область, город Мурманск, Сафонова, 18		0101000020E6100000C328081EDF8A40404D31074147415140
60309	3	30	\N	2533	32866	\N	69.022802999999996	Мурманская область, город Мурманск, Сафонова, 37		0101000020E6100000E1270EA0DF8940400BD0B69A75415140
60354	3	30	\N	2533	32875	\N	68.963785999999999	Мурманская область, город Мурманск, Самойловой, 2		0101000020E6100000BB9BA73AE4884040EE9579ABAE3D5140
60361	3	30	\N	2533	32886	\N	68.953203999999999	Мурманская область, город Мурманск, Рылеева, 6		0101000020E6100000D15B3CBCE78E4040A69A594B013D5140
60339	3	30	\N	2533	32868	\N	68.969414	Мурманская область, город Мурманск, Пушкинская, 3		0101000020E6100000C6BFCFB8708A4040369204E10A3E5140
60399	3	30	\N	2533	32821	\N	68.927930000000003	Мурманская область, город Мурманск, Прибрежная, 2		0101000020E61000009430D3F6AF8040408CBE8234633B5140
60359	3	30	\N	2533	32872	\N	68.952764999999999	Мурманская область, город Мурманск, Полярные Зори, 1		0101000020E61000008E791D71C88A404080F10C1AFA3C5140
60348	3	30	\N	2533	32872	\N	68.967585	Мурманская область, город Мурманск, Полярные Зори, 60		0101000020E6100000AD6A4947398C404069C6A2E9EC3D5140
60357	3	30	\N	2533	32841	\N	68.953918000000002	Мурманская область, город Мурманск, Полярной Дивизии, 1/16		0101000020E61000009FB0C403CA884040354415FE0C3D5140
60326	3	30	\N	2533	32894	\N	68.996210000000005	Мурманская область, город Мурманск, Подстаницкого, 1		0101000020E6100000959C137B688D4040AF7C96E7C13F5140
60371	3	30	\N	2533	32829	\N	68.949888981334794	Мурманская область, город Мурманск, Подгорная, 80		0101000020E610000022533E045585404021753BFBCA3C5140
60328	3	30	\N	2533	32827	\N	68.994517814330706	Мурманская область, город Мурманск, Павлика Морозова, 3	Россия, Мурманская область, Мурманск, улица Павлика Морозова	0101000020E6100000FE0DDAAB8F8D40402252D32EA63F5140
60381	3	30	\N	2533	32880	\N	68.937228000000005	Мурманская область, город Мурманск, Олега Кошевого, 12а		0101000020E61000004415FE0C6F8E40405039268BFB3B5140
60317	3	30	\N	2533	32879	\N	68.998827000000006	Мурманская область, город Мурманск, Миронова, 5		0101000020E61000007BBB2539608D404028D714C8EC3F5140
60344	3	30	\N	2533	32830	\N	68.979023999999995	Мурманская область, город Мурманск, Мира, 12		0101000020E610000006483481228E4040F17F4754A83E5140
60350	3	30	\N	2533	5272	\N	68.944427000000005	Мурманская область, город Мурманск, Лыжный, 8	Россия, Мурманская область, Мурманск, Лыжный проезд, 8	0101000020E6100000B8B1D991EA8D4040679DF17D713C5140
60377	3	30	\N	2533	32834	\N	68.979107999999997	Мурманская область, город Мурманск, Лесная, 39		0101000020E610000012DBDD037481404020D099B4A93E5140
60358	3	30	\N	2533	5316	\N	68.952465000000004	Мурманская область, город Мурманск, Ленина, 14	Россия, Мурманская область, Мурманск, Ленина проспект, 14	0101000020E6100000E0A0BDFA788A40406B65C22FF53C5140
60353	3	30	\N	2533	32873	\N	68.964360999999997	Мурманская область, город Мурманск, Ленина, 59		0101000020E610000077A04E79748940406C223317B83D5140
60387	3	30	\N	2533	5722	\N	68.913876582889003	Мурманская область, город Мурманск, Ледокольный, 23	Россия, Мурманская область, Мурманск, Ледокольный проезд, 23	0101000020E61000007A71E2AB1D8D404043E4F4F57C3A5140
60398	3	30	\N	2533	32861	\N	68.885651999999993	Мурманская область, город Мурманск, Крупской, 26		0101000020E6100000E3A6069ACF8B4040C4E8B985AE385140
94993	3	30	\N	2533	57949	\N	68.971710999999999	г. Мурманск, ул. Коминтерна, 14		0101000020E6100000E4688EACFC884040768A5583303E5140
37603	3	28	361	2443	23316	\N	54.394095	п. Краснолесье, Центральная, 2		0101000020E61000004CC2853C825F3640314278B471324B40
60379	3	30	\N	2533	730	\N	68.944080999999997	Мурманская область, город Мурманск, Кольский, 27, а	Россия, Мурманская область, Мурманск, Кольский проспект, 27а	0101000020E61000002BBF0CC6888C404099F1B6D26B3C5140
60356	3	30	\N	2533	32844	\N	68.959802999999994	Мурманская область, город Мурманск, Книповича, 48, кабинет 109		0101000020E6100000A8FC6B79E58C404092E68F696D3D5140
60355	3	30	\N	2533	32844	\N	68.957275999999993	Мурманская область, город Мурманск, Книповича, 35/2		0101000020E6100000E65AB4006D8B4040B94F8E02443D5140
60352	3	30	\N	2533	32844	\N	68.961449999999999	Мурманская область, город Мурманск, Книповича, 36, а		0101000020E610000096ED43DE728B40404FAF9465883D5140
60375	3	30	\N	2533	712	\N	68.951160000000002	Мурманская область, город Мурманск, Кирова, 36/27		0101000020E61000006D1E87C1FC894040DB5031CEDF3C5140
60374	3	30	\N	2533	32897	\N	68.951102000000006	Мурманская область, город Мурманск, Кирова, 17а		0101000020E61000001C0B0A8332894040414AECDADE3C5140
60335	3	30	\N	2533	32855	\N	68.977836999999994	Мурманская область, город Мурманск, Карла Либкнехта, 18, а		0101000020E6100000CCECF318E58B404066F4A3E1943E5140
60376	3	30	\N	2533	32876	\N	68.944390999999996	Мурманская область, город Мурманск, Капитана Орликовой, 35		0101000020E6100000A67D737FF58A4040C0E8F2E6703C5140
60346	3	30	\N	2533	32856	\N	68.970521000000005	Мурманская область, город Мурманск, Капитана Маклакова, 39		0101000020E6100000C3D32B65198E404033C51C041D3E5140
60340	3	30	\N	2533	32889	\N	68.965486999999996	Мурманская область, город Мурманск, Капитана Егорова, 5		0101000020E61000009DA04D0E9F884040A46DFC89CA3D5140
60349	3	30	\N	2533	32902	\N	68.965749000000002	Мурманская область, город Мурманск, Капитана Буркова, 31		0101000020E61000002B508BC1C38A404043C9E4D4CE3D5140
60318	3	30	\N	2533	4884	\N	69.003366999999997	Мурманская область, город Мурманск, Казарменный, 2	Россия, Мурманская область, Мурманск, Казарменный переулок, 2	0101000020E6100000C2DCEEE53E894040AEB8382A37405140
60323	3	30	\N	2533	32885	\N	69.010204999999999	Мурманская область, город Мурманск, Ивченко, 15		0101000020E610000058923CD7F78D40405D50DF32A7405140
60382	3	30	\N	2533	32850	\N	68.935755	Мурманская область, город Мурманск, Зои Космодемьянской, 2, а		0101000020E6100000CC7A3194138F40406284F068E33B5140
60516	3	30	\N	2533	32816	\N	68.945486000000002	ЗАТО Видяево, Заречная, 60		0101000020E6100000AD31E884D0854040DB34B6D7823C5140
60327	3	30	\N	2533	4819	\N	68.987114000000005	Мурманская область, город Мурманск, Героев-североморцев, 5, 3	Россия, Мурманская область, Мурманск, Героев Североморцев проспект, 5к3	0101000020E610000095D39E92738C40401FDB32E02C3F5140
60314	3	30	\N	2533	4819	\N	69.012005000000002	Мурманская область, город Мурманск, Героев-североморцев, 76,3	Россия, Мурманская область, Мурманск, Героев Североморцев проспект, 76/3	0101000020E6100000FD101B2C9C8C4040DD989EB0C4405140
60313	3	30	\N	2533	4819	\N	69.012005000000002	Мурманская область, город Мурманск, Героев-североморцев, 76, 3	Россия, Мурманская область, Мурманск, Героев Североморцев проспект, 76/3	0101000020E6100000FD101B2C9C8C4040DD989EB0C4405140
60397	3	30	\N	2533	32863	\N	68.888664000000006	Мурманская область, город Мурманск, Героев Рыбачьего, 58		0101000020E610000002486DE2E48C40407C48F8DEDF385140
60390	3	30	\N	2533	32863	\N	68.898214999999993	Мурманская область, город Мурманск, Героев Рыбачьего, 15		0101000020E61000006DE34F54368C4040B471C45A7C395140
60343	3	30	\N	2533	32895	\N	68.981001000000006	Мурманская область, город Мурманск, Седова, 8		0101000020E61000006B2920ED7F8C4040F9156BB8C83E5140
60373	3	30	\N	2533	32851	\N	68.949083999999999	Мурманская область, город Мурманск, Генералова, 1/13		0101000020E610000045B9347EE18740400A4AD1CABD3C5140
60360	3	30	\N	2533	32899	\N	68.955018999999993	Мурманская область, город Мурманск, Гвардейская, 14		0101000020E6100000CFBF5DF6EB8C4040C00303081F3D5140
60324	3	30	\N	2533	32835	\N	69.006001999999995	Мурманская область, город Мурманск, Гаджиева, 6, а		0101000020E61000009A6038D7308D40407A6D365662405140
60325	3	30	\N	2533	32854	\N	68.997915000000006	Мурманская область, город Мурманск, Гагарина, 21		0101000020E6100000936FB6B9318D4040064CE0D6DD3F5140
60336	3	30	\N	2533	32869	\N	68.975121000000001	Мурманская область, город Мурманск, Володарского, 5		0101000020E6100000B05582C5E18A40402429E961683E5140
60384	3	30	\N	2533	32870	\N	68.914125999999996	Мурманская область, город Мурманск, Бочкова, 15		0101000020E61000008B19E1ED418A4040179B560A813A5140
60386	3	30	\N	2533	32888	\N	68.916460999999998	Мурманская область, город Мурманск, Беринга, 18 (было 16)		0101000020E61000008F386403E98C4040CEC3094CA73A5140
60394	3	30	\N	2533	32819	\N	68.905256684635802	Мурманская область, город Мурманск, Баумана, 44	Россия, Мурманская область, Мурманск, улица Баумана, 44	0101000020E6100000DF89592F868A4040685E0EBBEF395140
60393	3	30	\N	2533	32819	\N	68.906532999999996	Мурманская область, город Мурманск, Баумана, 39		0101000020E6100000AA7EA5F3E1894040AAEFFCA2043A5140
60392	3	30	\N	2533	32819	\N	68.907117999999997	Мурманская область, город Мурманск, Баумана, 40		0101000020E6100000BCE7C072848A40403AE7A7380E3A5140
60385	3	30	\N	2533	32819	\N	68.914533000000006	Мурманская область, город Мурманск, Баумана, 11		0101000020E6100000DBBFB2D2A48A404038876BB5873A5140
60321	3	30	\N	2533	32901	\N	68.998569000000003	Мурманская область, город Мурманск, Аскольдовцев, 9		0101000020E610000029232E008D8A40402A73F38DE83F5140
60312	3	30	\N	2533	32860	\N	69.020206000000002	Мурманская область, город Мурманск, Адмирала Лобова, 18		0101000020E61000000E846401138C4040B64B1B0E4B415140
60541	3	30	\N	3240	32806	\N	67.935120999999995	Мурманская область, г.Мончегорск, пр.Металлургов, д.30		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60548	3	30	\N	3240	9789	\N	67.936750650765404	Мурманская область, г.Мончегорск, пр.Металлургов, д.1	Россия, Мурманская область, Мончегорск	0101000020E61000008B1A4CC3F0714040B35F77BAF3FB5040
60546	3	30	\N	3240	32229	\N	67.940994055182202	Мурманская область, г.Мончегорск, ул.Царевского, д.4а	Россия, Мурманская область, Мончегорск	0101000020E61000001C0B0A8332734040DDEEE53E39FC5040
60535	3	30	\N	3240	32753	\N	67.935120999999995	Мурманская область, г.Мончегорск, ул.Ферсмана, д.7		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60547	3	30	\N	3240	32231	\N	67.9350724860209	Мурманская область, г.Мончегорск, Строительный проезд, д.1	Россия, Мурманская область, Мончегорск	0101000020E6100000D942908312724040F1D93A38D8FB5040
60545	3	30	\N	3240	32767	\N	67.940679340113604	Мурманская область, г.Мончегорск, ул.Строительная, д.3	Россия, Мурманская область, Мончегорск	0101000020E61000005F79909E227340402D42B11534FC5040
60539	3	30	\N	3240	32180	\N	67.935120999999995	Мурманская область, г.Мончегорск, пр.Кирова, д.7		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60543	3	30	\N	3240	32765	\N	67.9371379022989	Мурманская область, г.Мончегорск, ул.Новопроложенная, д.7	Россия, Мурманская область, Мончегорск	0101000020E61000002541B8020A734040B075A911FAFB5040
60527	3	30	\N	3240	32208	\N	67.940106615782895	Мурманская область, г.Мончегорск, ул.Лесная, д.10	Россия, Мурманская область, Мончегорск	0101000020E6100000732A1900AA78404067EF8CB62AFC5040
60538	3	30	\N	3240	32759	\N	67.935120999999995	Мурманская область, г.Мончегорск, Ленинградская наб, д.43, корп.3		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60536	3	30	\N	3240	32698	\N	67.9371379022989	Мурманская область, г.Мончегорск, ул.Котульского, д.1	Россия, Мурманская область, Мончегорск	0101000020E61000007B336ABE4A724040B075A911FAFB5040
60530	3	30	\N	3240	32213	\N	67.939461275634102	Мурманская область, г.Мончегорск, ул.Кондрикова, д.8	Россия, Мурманская область, Мончегорск	0101000020E6100000986E1283C078404084B7072120FC5040
60529	3	30	\N	3240	32213	\N	67.935120999999995	Мурманская область, г.Мончегорск, ул.Кондрикова, д.30		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60544	3	30	\N	3240	32696	\N	67.938170541424199	Мурманская область, г.Мончегорск, ул.Комсомольская, д.24	Россия, Мурманская область, Мончегорск	0101000020E6100000D5AF743E3C7940408FC360FE0AFC5040
60532	3	30	\N	3240	32696	\N	67.935120999999995	Мурманская область, г.Мончегорск, ул.Комсомольская, д.31/16		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60537	3	30	\N	3240	32711	\N	67.935120999999995	Мурманская область, г.Мончегорск, пр.Кирова, д.17		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60531	3	30	\N	3240	32165	\N	67.931150915932093	Мурманская область, г.Мончегорск, ул.Бредова, д.1	Россия, Мурманская область, Мончегорск	0101000020E6100000C078060DFD774040D0285DFA97FB5040
60528	3	30	\N	3240	32758	\N	67.935120999999995	Мурманская область, г.Мончегорск, ул.3-я Нагорная, д.42		0101000020E6100000BCAFCA85CA7140406133C005D9FB5040
60483	3	30	\N	1613	32831	\N	68.882873000000004	Мурманская область, Кольский район, г. Кола, Победы, 7		0101000020E6100000EC17EC866D8140405F61C1FD80385140
60482	3	30	\N	1613	6685	\N	68.883139	Мурманская область, Кольский район, г. Кола, Защитников Заполярья, 7	Россия, Мурманская область, Кола, Защитников Заполярья проспект, 7	0101000020E61000001B9FC9FE798240409EB4705985385140
60659	3	30	\N	53399	\N	\N	67.646514999999994	н.п. Коашва, СДК н.п. Коашва, 2		0101000020E61000002FFCE07CEA044140E657738060E95040
60281	3	30	\N	45752	32743	\N	67.610215577545702	город Кировск, Ленина, 25	Россия, Мурманская область, Кировск	0101000020E6100000CAA65CE15DD44040BDDF68C70DE75040
60439	3	30	\N	45752	32785	\N	67.606766891153697	город Кировск, Советской Конституции, 10	Россия, Мурманская область, Кировск	0101000020E6100000DCBDDC2747D54040B1524145D5E65040
60467	3	30	\N	45752	32697	\N	67.613416000000001	город Кировск, Олимпийская, 57А		0101000020E6100000971E4DF564D64040F6B52E3542E75040
60466	3	30	\N	45752	32697	\N	67.613416000000001	город Кировск, Олимпийская, 8А		0101000020E6100000971E4DF564D64040F6B52E3542E75040
60107	3	30	\N	45752	32737	\N	67.613416000000001	город Кировск, Мира, 7		0101000020E6100000971E4DF564D64040F6B52E3542E75040
59882	3	30	\N	45752	32737	\N	67.613416000000001	город Кировск, Мира, 9		0101000020E6100000971E4DF564D64040F6B52E3542E75040
60449	3	30	\N	45752	32774	\N	67.613416000000001	город Кировск, Ленинградская, 2		0101000020E6100000971E4DF564D64040F6B52E3542E75040
60468	3	30	\N	45752	32779	\N	67.613416000000001	город Кировск, Кондрикова, 5		0101000020E6100000971E4DF564D64040F6B52E3542E75040
60465	3	30	\N	45752	32161	\N	67.613416000000001	город Кировск, Кирова, 27А		0101000020E6100000971E4DF564D64040F6B52E3542E75040
60440	3	30	\N	2080	32776	\N	67.173101415021094	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Спекова, д. 50	Россия, Мурманская область, Кандалакша	0101000020E6100000774EB340BB354040EA79371614CB5040
60435	3	30	\N	2080	32769	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Пронина, д. 22а	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60430	3	30	\N	2080	32837	\N	67.172963400774705	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Первомайская, д. 32	Россия, Мурманская область, Кандалакша	0101000020E6100000E0675C3810364040C11A67D311CB5040
60429	3	30	\N	2080	32837	\N	67.169549053956899	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, Первомайская, 9	Россия, Мурманская область, Кандалакша	0101000020E61000008A929048DB34404073840CE4D9CA5040
60436	3	30	\N	2080	32865	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Новая, д. 1	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60433	3	30	\N	2080	32814	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Набережная, д. 151	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60661	3	30	\N	2080	57948	\N	67.162841999999998	г. Кандалакша, ул. Мурманская, 24		0101000020E61000007E5358A9A0344040931ADA006CCA5040
60443	3	30	\N	2080	32812	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Высокая, д. 2	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60428	3	30	\N	2080	32810	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Восточная, д. 7	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60427	3	30	\N	2080	32773	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Беломорская, д. 19	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60431	3	30	\N	2080	32761	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Аэронавтов, д. 4а	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60445	3	30	\N	2080	32154	\N	67.170710401601795	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. 3-я Линия, д.3	Россия, Мурманская область, Кандалакша	0101000020E6100000D0F1D1E28C35404069C6A2E9ECCA5040
60442	3	30	\N	2080	32730	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. 2-я Парковая, д. 11	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60441	3	30	\N	2080	32905	\N	67.171501442788497	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Кировская аллея, д. 1а	Россия, Мурманская область, Кандалакша	0101000020E6100000A8FC6B79E5344040CE8E54DFF9CA5040
60533	3	30	\N	40322	9815	\N	67.934814296045502	Мурманская область, г.Мончегорск, пр.Металлургов, д.39А	Россия, Мурманская область, Мончегорск	0101000020E61000007B336ABE4A724040F37519FED3FB5040
94435	3	30	\N	621	32757	\N	69.256027000000003	г.Гаджиево, ул. Советская, 74/2		0101000020E6100000815EB87361AA404027F911BF62505140
60639	3	30	\N	621	32728	\N	69.256027000000003	г.Гаджиево, Колышкина, 114-А		0101000020E6100000815EB87361AA404027F911BF62505140
60640	3	30	\N	621	32687	\N	69.256027000000003	г.Гаджиево, Душенова, 90-А		0101000020E6100000815EB87361AA404027F911BF62505140
60637	3	30	\N	621	32144	\N	69.256027000000003	г.Гаджиево, Гаджиева, 40		0101000020E6100000815EB87361AA404027F911BF62505140
60636	3	30	\N	621	32144	\N	69.256027000000003	г.Гаджиево, Гаджиева, 33/1		0101000020E6100000815EB87361AA404027F911BF62505140
60599	3	30	\N	47582	\N	\N	69.081576953542594	с.Белокаменка, Детский сад	Россия, Мурманская область, село Белокаменка	0101000020E6100000D367075C57964040C5C6BC8E38455140
60415	3	30	\N	2005	32141	\N	67.576147000000006	Мурманская область, г. Апатиты, Ферсмана, 24		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60412	3	30	\N	2005	32141	\N	67.576147000000006	Мурманская область, г. Апатиты, Ферсмана, 40а		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60404	3	30	\N	2005	32141	\N	67.576147000000006	Мурманская область, г. Апатиты, Ферсмана, 14		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60419	3	30	\N	2005	32685	\N	67.576210831832299	Мурманская область, г. Апатиты, Строителей, 97	Россия, Мурманская область, Апатиты	0101000020E6100000191C25AFCEB140401C261AA4E0E45040
60402	3	30	1913	\N	32677	\N	67.554735022729901	Мурманская область, г. Апатиты, Сидоренко, 22а	Россия, Мурманская область, Апатиты городской округ	0101000020E6100000C0266BD443B6404094BC3AC780E35040
60410	3	30	\N	2005	32183	\N	67.576147000000006	Мурманская область, г. Апатиты, Ленина, 24		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60407	3	30	\N	2005	32183	\N	67.576147000000006	Мурманская область, г. Апатиты, Ленина, 19а		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60406	3	30	\N	2005	32183	\N	67.576147000000006	Мурманская область, г. Апатиты, Ленина, 11		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60405	3	30	\N	2005	32191	\N	67.576147000000006	Мурманская область, г. Апатиты, Космонавтов, 19		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60417	3	30	\N	2005	32708	\N	67.567057312705799	Мурманская область, г. Апатиты, Кирова, 18	Россия, Мурманская область, Апатиты	0101000020E61000000B7DB08C0DAD4040F27D71A94AE45040
60421	3	30	\N	2005	32718	\N	67.576147000000006	Мурманская область, г. Апатиты, Зиновьева, 18		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60414	3	30	\N	2005	32718	\N	67.576147000000006	Мурманская область, г. Апатиты, Зиновьева, 5		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60411	3	30	\N	2005	32718	\N	67.576147000000006	Мурманская область, г. Апатиты, Зиновьева, 5а		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60420	3	30	\N	2005	32750	\N	67.576147000000006	Мурманская область, г. Апатиты, Жемчужная, 38		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60418	3	30	\N	2005	32150	\N	67.576147000000006	Мурманская область, г. Апатиты, Дзержинского, 34		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60403	3	30	\N	2005	32150	\N	67.576147000000006	Мурманская область, г. Апатиты, Дзержинского, 53		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60413	3	30	\N	2005	32748	\N	67.576147000000006	Мурманская область, г. Апатиты, Бредова, 2а		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60408	3	30	\N	2005	32748	\N	67.576147000000006	Мурманская область, г. Апатиты, Бредова, 27а		0101000020E6100000F7730AF2B3B1404011ACAA97DFE45040
60653	3	30	314	53395	32818	\N	66.685827000000003	Мурманская область, Терский район, п.г.т. Умба, ул. Приморская, д.43	Россия, Мурманская область, Терский район, поселок Умба	0101000020E6100000809C3061342B4140AFEDED96E4AB5040
94434	3	29	\N	59022	67288	\N	59.345565265138099	"Гатчинский район, д.Выра, Большой пр.,д 32-а помещение музея ""Дом станционного смотрителя"""		0101000020E610000096CE876709F63D4035D252793BAC4D40
60656	3	30	314	53395	32764	\N	66.686303059653198	Мурманская область, Терский район, п.г.т. Умба, ул. Беломорская, д.1а	Россия, Мурманская область, Терский район, поселок Умба	0101000020E6100000BB0D6ABFB52B414063096B63ECAB5040
60655	3	30	314	53395	32764	\N	66.686116232645702	Мурманская область, Терский район, п.г.т. Умба, ул. Беломорская, д.1в	Россия, Мурманская область, Терский район, поселок Умба	0101000020E61000009F909DB7B12B4140CA501553E9AB5040
60652	3	30	314	53301	32172	\N	66.689004999999995	Мурманская область, Терский район, п.г.т. Умба, ул. Совхозная, д.12а		0101000020E61000005665DF15C1514240F3716DA818AC5040
60651	3	30	314	1480	32695	\N	66.398927999999998	Мурманская область, Терский район, село Варзуга, ул. Успенская, д.75		0101000020E610000042CC2555DB4B42405B5D4E0988995040
60630	3	30	53	247	32160	\N	69.035488000000001	Мурманская область, нп.Щукозеро, ул.Агеева, д.7а		0101000020E6100000068195438BD04040A1D9756F45425140
60625	3	30	53	32341	32815	\N	69.032156466386098	Мурманская область, пгт.Сафоново-1, ул.Панина, д.11а	Россия, Мурманская область, Североморск городской округ, поселок Сафоново	0101000020E6100000F98557923CA54040B1170AD80E425140
60627	3	30	53	63	32190	\N	69.048872000000003	пгт.Росляково, ул. Приморская, 2		0101000020E610000045D7851F9C9B40402B6C06B820435140
60629	3	30	53	63	32784	\N	69.048872000000003	Мурманская область, пгт.Росляково, ул.Молодежная, д.14		0101000020E610000045D7851F9C9B40402B6C06B820435140
60628	3	30	53	63	32778	\N	69.048872000000003	Мурманская область, пгт.Росляково, ул.Заводская, д.1		0101000020E610000045D7851F9C9B40402B6C06B820435140
60556	3	30	435	26381	32717	\N	69.411659999999998	п.Никель, пр.Гвардейский, 33		0101000020E6100000D236FE4465373E4091442FA3585A5140
60572	3	30	435	26381	32679	\N	69.411659999999998	п.Никель, Спортивная, 13		0101000020E6100000D236FE4465373E4091442FA3585A5140
60571	3	30	435	26381	32700	\N	69.411659999999998	п.Никель, Сидоровича, 16		0101000020E6100000D236FE4465373E4091442FA3585A5140
60570	3	30	435	26381	32700	\N	69.411659999999998	п.Никель, Сидоровича, 13		0101000020E6100000D236FE4465373E4091442FA3585A5140
60542	3	30	435	26381	32808	\N	69.411314207841599	п.Никель, Печенгская, 1 А	Россия, Мурманская область, Печенгский район, поселок Никель	0101000020E61000001364045438363E40C498F4F7525A5140
60496	3	30	435	26381	32751	\N	69.411659999999998	п.Никель, Октябрьская, 1		0101000020E6100000D236FE4465373E4091442FA3585A5140
60569	3	30	435	26381	32723	\N	69.411659999999998	п.Никель, пр.Гвардейский, 21		0101000020E6100000D236FE4465373E4091442FA3585A5140
60511	3	30	435	26381	32714	\N	69.411659999999998	п.Никель, Бредова, 2		0101000020E6100000D236FE4465373E4091442FA3585A5140
60591	3	30	435	30795	\N	\N	69.399800999999997	п.Корзуново, Филиал школы №7		0101000020E610000068CEFA9463023F401EFAEE5696595140
60578	3	30	435	2388	32681	\N	69.423377000000002	г.Заполярный, Стрельцова, 1 А		0101000020E610000028F4FA93F8D03E403B38D89B185B5140
60582	3	30	435	2388	32725	\N	69.423377000000002	г.Заполярный, Сафонова, 9 А		0101000020E610000028F4FA93F8D03E403B38D89B185B5140
60579	3	30	435	2388	32726	\N	69.423377000000002	г.Заполярный, Мира, 2 А		0101000020E610000028F4FA93F8D03E403B38D89B185B5140
60577	3	30	435	2388	32771	\N	69.423377000000002	г.Заполярный, Ленинградская, 4 А		0101000020E610000028F4FA93F8D03E403B38D89B185B5140
60576	3	30	435	2388	32722	\N	69.423377000000002	г.Заполярный, Ленина, 4		0101000020E610000028F4FA93F8D03E403B38D89B185B5140
60581	3	30	435	2388	32729	\N	69.427437334093696	г.Заполярный, Крупской, 2 А	Россия, Мурманская область, Печенгский район, Заполярный	0101000020E6100000116DC7D45DD13E406C06B8205B5B5140
60580	3	30	435	2388	32800	\N	69.423377000000002	г.Заполярный, Космонавтов, 6 А		0101000020E610000028F4FA93F8D03E403B38D89B185B5140
60583	3	30	435	2388	32788	\N	69.423656039920701	г.Заполярный, Юбилейная, 14		0101000020E6100000A73CBA1116D13E4044300E2E1D5B5140
60561	3	30	573	3611	32793	\N	68.138480999999999	Мурманская область, нп Высокий, ул. Сыромятникова, д. 13а	Россия, Мурманская область, Мончегорск городской округ, село Высокий	0101000020E6100000062E8F3523B54040838769DFDC085140
60550	3	30	573	53382	32720	\N	67.9711388518635	Мурманская область, г.Мончегорск, н.п. 27км. железной дороги Мончегорск-Оленья, ул.Октябрьская, 14а	Россия, Мурманская область, Мончегорск городской округ, село 27 километр	0101000020E610000062D68BA19C784040B037312427FE5040
60549	3	30	573	53387	\N	\N	67.981719284041503	город Мончегорск, Красный уголок н. п. 25 км.	Россия, Мурманская область, Мончегорск городской округ, село 25 километр	0101000020E610000040683D7C997E404028B7ED7BD4FE5040
60522	3	30	524	45970	32804	\N	67.946028999999996	п.Ревда, Победы, 16а		0101000020E6100000D74D29AF95464140530438BD8BFC5040
60524	3	30	524	45970	32796	\N	67.946028999999996	п.Ревда, Металлургов, 6		0101000020E6100000D74D29AF95464140530438BD8BFC5040
60523	3	30	524	45970	32796	\N	67.946028999999996	п.Ревда, Металлургов, 5		0101000020E6100000D74D29AF95464140530438BD8BFC5040
60518	3	30	524	27552	32782	\N	68.004683	с.Ловозеро, Советская, 30		0101000020E61000009085E8103882414038F6ECB94C005140
60513	3	30	408	53300	32169	\N	68.649610999999993	"Мурманская область, Кольский район, п.г.т. Туманный, Энергетиков, 2 ""А"""		0101000020E6100000452E3883BF274040CC07043A93295140
60498	3	30	408	53407	32826	\N	68.752363703962004	Мурманская область, Кольский район, н.п. Шонгуй, Комсомольская, 5	Россия, Мурманская область, Кольский район, поселок Шонгуй	0101000020E6100000F6402B306493404004AC55BB26305140
60512	3	30	408	27144	32731	\N	69.287969000000004	Мурманская область, Кольский район, с. Ура-Губа, Рыбацкая, 35		0101000020E610000002D53F8864664040C25087156E525140
60500	3	30	408	2175	32686	\N	68.818048000000005	Мурманская область, Кольский район, с. Тулома, Мира, 6		0101000020E61000007A17EFC7ED574040BAA3FFE55A345140
60631	3	30	408	53393	32760	\N	68.879375744164307	Мурманская область, нп.Североморск-3, ул.Школьная, д.7	Россия, Мурманская область, Кольский район, село Североморск 2I	0101000020E6100000C0779B374EDE4040C93846B247385140
60503	3	30	408	53302	32195	\N	68.480734373685095	Мурманская область, Кольский район, н.п. Пушной, Центральная, 14		0101000020E610000060CC96AC8AA84040D1048A58C41E5140
60504	3	30	408	53371	32678	\N	68.483861952407494	Мурманская область, Кольский район, н.п. Песчаный, Ткачёва, д.1, кв.4		0101000020E61000000F7BA180ED9E4040BD715298F71E5140
52236	3	29	97	6612	66076	\N	60.714632999999999	Приозерский район, п.Ромашки, ул.Новостроек, д.14 школа		0101000020E6100000BCB376DB85CE3D4039D21918795B4E40
60486	3	30	408	25966	32739	\N	68.817356638896598	Мурманская область, Кольский район, п.г.т. Мурмаши, Энергетиков, 19	Россия, Мурманская область, Кольский район, поселок Мурмаши	0101000020E6100000CA8B4CC0AF654040070ABC934F345140
60487	3	30	408	25966	32780	\N	68.817226000000005	Мурманская область, Кольский район, п.г.т. Мурмаши, Советская, 18		0101000020E61000007157AF22A365404038DC476E4D345140
60492	3	30	408	25966	32139	\N	68.812575727011406	Мурманская область, Кольский район, п.г.т. Мурмаши, Причальная, 30	Россия, Мурманская область, Кольский район, поселок Мурмаши	0101000020E610000013BA4BE2AC664040EE60C43E01345140
60490	3	30	408	25966	32704	\N	68.817226000000005	Мурманская область, Кольский район, п.г.т. Мурмаши, Гвардейская, 6		0101000020E61000007157AF22A365404038DC476E4D345140
60494	3	30	408	26225	32724	\N	68.854731999999998	"Мурманская область, Кольский район, п.г.т. Молочный, Торговая, 1 ""А"""		0101000020E61000001077F52A328240400FB6D8EDB3365140
60493	3	30	408	26225	32724	\N	68.854731999999998	Мурманская область, Кольский район, п.г.т. Молочный, Торговая, 8		0101000020E61000001077F52A328240400FB6D8EDB3365140
60509	3	30	408	53380	32703	\N	69.043349000000006	Мурманская область, Кольский район, н.п. Мишуково, Почтовая, 19	Россия, Мурманская область, Кольский район, село Мишуково	0101000020E6100000B56D1805C18340401E54E23AC6425140
60507	3	30	408	26902	\N	\N	68.986873000000003	Мурманская область, Кольский район, с. Минькино, 135		0101000020E6100000672B2FF99F8240408C135FED283F5140
60508	3	30	408	26955	32221	\N	69.036437000000006	"Мурманская область, Кольский район, с. Междуречье, Строительная, 5 ""А"""		0101000020E610000004E275FD8277404052D7DAFB54425140
60499	3	30	408	53406	32824	\N	68.679840931250695	Мурманская область, Кольский район, ж-д ст. Магнетиты, Набережная, 14	Россия, Мурманская область, Кольский район, село Магнетиты	0101000020E610000060E4654D2C904040B75ED383822B5140
60484	3	30	408	53414	32862	\N	68.880317000000005	"Мурманская область, Кольский район, г. Кола, проспект Советский, 41 ""А"""		0101000020E6100000FB3F87F9F282404039471D1D57385140
60485	3	30	408	53414	32877	\N	68.889279000000002	Мурманская область, Кольский район, г. Кола, Приморская, 2		0101000020E6100000C2DB831090854040418177F2E9385140
60497	3	30	408	53409	32833	\N	68.801998674820993	Мурманская область, Кольский район, п.г.т. Кильдинстрой, Советская, 2	Россия, Мурманская область, Кольский район, поселок Кильдинстрой	0101000020E610000034F8FBC56C8D40402E1B9DF353335140
60510	3	30	408	53310	32237	\N	69.086160735583107	Мурманская область, Кольский район, н.п. Килпъявр, Небольсина, 12	Россия, Мурманская область, Кольский район, село Килпъявр	0101000020E61000000E84640113364040344C6DA983455140
60495	3	30	408	53411	32852	\N	68.846922090928601	Мурманская область, Кольский район, н.п. Зверосовхоз, Зелёная, 14	Россия, Мурманская область, Кольский район, село Зверосовхоз	0101000020E610000051DA1B7C61904040D41055F833365140
60424	3	30	408	22939	32236	\N	69.409627	Мурманская область,  г. Заозерск, переулок Школьный, дом 6		0101000020E610000016A6EF3504394040C0232A54375A5140
60426	3	30	408	22939	32152	\N	69.409627	город Заозерск, ул. Мира, дом 5А		0101000020E610000016A6EF3504394040C0232A54375A5140
60425	3	30	408	22939	32152	\N	69.402819987131295	Мурманская область,  г. Заозерск, ул.Мира, дом 5А	Россия, Мурманская область, Кольский район, Заозерск	0101000020E61000007D5D86FF743740402F8B89CDC7595140
60422	3	30	408	22939	32794	\N	69.409627	Мурманская область,  г. Заозерск, ул.Колышкина, дом 16		0101000020E610000016A6EF3504394040C0232A54375A5140
60517	3	30	408	53416	32883	\N	69.318420351673595	ЗАТО Видяево, Нагорная, 5	Россия, Мурманская область, Кольский район, село Видяево	0101000020E6100000C634D3BD4E6640401C9947FE60545140
60502	3	30	408	53386	32734	\N	68.607787917050203	Мурманская область, Кольский район, п.г.т. Верхнетуломский, Дружбы, 20	Россия, Мурманская область, Кольский район, поселок Верхнетуломский	0101000020E6100000AFD007CBD8CC3F40AEB9A3FFE5265140
60480	3	30	491	3071	32692	\N	67.495716999999999	Мурманская область, Ковдорский район, н.п. Риколатва, н.п. Риколатва, место для голосования - помещение ЖЭУ МУП, ул. Победы, 3а		0101000020E61000002E8D5F7825513F408FC4CBD3B9DF5040
60477	3	30	491	25522	\N	\N	67.485292999999999	"Мурманская область, Ковдорский район, н.п. Куропта, центр - н.п. Куропта, место для голосования - МУК ""Сельский"		0101000020E61000009642209738D63E4093FE5E0A0FDF5040
60470	3	30	491	2984	32713	\N	67.562484999999995	Мурманская область, Ковдор, ул. Чехова, д. 8		0101000020E61000000DDFC2BAF17A3E4065DF15C1FFE35040
60476	3	30	491	2984	32158	\N	67.562268957170005	Мурманская область, Ковдор, ул. Комсомольская, д. 6а	Россия, Мурманская область, Ковдорский район, Ковдор	0101000020E6100000096D3997E27A3E407FA31D37FCE35040
60472	3	30	491	2984	32158	\N	67.562484999999995	Мурманская область, Ковдор, ул. Комсомольская, д.14		0101000020E61000000DDFC2BAF17A3E4065DF15C1FFE35040
60471	3	30	491	2984	32158	\N	67.562484999999995	Мурманская область, Ковдор, ул. Комсомольская, д. 15		0101000020E61000000DDFC2BAF17A3E4065DF15C1FFE35040
60474	3	30	491	2984	32159	\N	67.562484999999995	Мурманская область, Ковдор, ул. Кирова, д. 24		0101000020E61000000DDFC2BAF17A3E4065DF15C1FFE35040
60475	3	30	491	2984	32715	\N	67.562484999999995	Мурманская область, Ковдор, ул. Школьная, д. 2		0101000020E61000000DDFC2BAF17A3E4065DF15C1FFE35040
60479	3	30	491	25625	\N	\N	67.584491433177107	Мурманская область, Ковдорский район, н.п. Енский, центр - н.п. Енский, место для голосования - МОУ ДОД	Россия, Мурманская область, Ковдорский район, село Енский	0101000020E610000072C0AE264F253F409B73F04C68E55040
60478	3	30	491	25596	\N	\N	67.607147999999995	"Мурманская область, Ковдорский район, с.Ена, центр - село Ена, место для голосования -МУК  ""Сельский дом"		0101000020E61000004983DBDAC2273F403CF54883DBE65040
60658	3	30	370	1902	\N	\N	67.562241	н.п. Титан, СДК н.п. Титан, 14		0101000020E6100000910DA48B4DD140401ADEACC1FBE35040
52195	3	29	438	2412	67582	\N	60.924700999999999	Подпорожский район, г. Подпорожье, ул.Северная,д.40		0101000020E61000007C0BEBC6BB1541400CCA349A5C764E40
60438	3	30	7286	53398	32777	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Спекова, д. 15		0101000020E61000007E5358A9A0344040931ADA006CCA5040
60437	3	30	7279	53383	32721	\N	67.162841999999998	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Спекова, д. 7	Россия, Мурманская область, Кандалакша	0101000020E61000007E5358A9A0344040931ADA006CCA5040
60434	3	30	7279	53383	32817	\N	67.162379127035905	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Первомайская, д. 67	Россия, Мурманская область, Кандалакша	0101000020E610000094861A85242F4040A9A3E36A64CA5040
60432	3	30	7279	53383	32882	\N	67.157953145369106	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, ул. Комсомольская, д. 10	Россия, Мурманская область, Кандалакша	0101000020E61000002104E44BA83440408753E6E61BCA5040
60456	3	30	7279	53372	32684	\N	66.854012999999995	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Зеленоборский Кандалакшского района, ул. Школьная, д. 1а	Россия, Мурманская область, Кандалакша городской округ, поселок Зеленоборский	0101000020E6100000A9893E1F65304040F7562426A8B65040
60457	3	30	7279	53372	32786	\N	66.862869900061199	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Зеленоборский Кандалакшского района, н.п. Лесозаводский, ул. Центральная, д. 11а	Россия, Мурманская область, Кандалакша городской округ, поселок Зеленоборский	0101000020E61000008A90BA9D7D314040C5AC174339B75040
60452	3	30	7279	53374	32689	\N	66.681051372679207	Мурманская область, муниципальное образование Кандалакшский район, сельское поселение Зареченск Кандалакшского района, ул. Кумская, д. 2	Россия, Мурманская область, Кандалакша городской округ, поселок Зареченск	0101000020E61000003E40F7E5CC6E3F401EFAEE5696AB5040
60448	3	30	1741	53377	32694	\N	67.299954582322897	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, н.п. Нивский, ул. Букина, д.1	Россия, Мурманская область, Кандалакша городской округ, поселок Нивский	0101000020E6100000F88903E8F73D404063D1747632D35040
60447	3	30	1741	24107	32752	\N	67.103547000000006	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Кандалакша Кандалакшского района, с.Лувеньга, ул. Молодежная, д. 11		0101000020E61000009E08E23C9C5A404055A69883A0C65040
60453	3	30	1741	24378	32736	\N	66.761358000000001	Мурманская область, муниципальное образование Кандалакшский район, сельское поселение Зареченск Кандалакшского района, с. Ковдозеро, ул. Первомайская		0101000020E6100000B6DAC35E28903F4012A3E716BAB05040
60455	3	30	1741	53394	32799	\N	66.855701071773396	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Зеленоборский Кандалакшского района, ул. Энергетическая, д. 24а	Россия, Мурманская область, Кандалакша городской округ, поселок Зеленоборский	0101000020E6100000DE58501894314040E38920CEC3B65040
60454	3	30	1741	53394	32762	\N	66.8543839782308	Мурманская область, муниципальное образование Кандалакшский район, городское поселение Зеленоборский Кандалакшского района, ул. Озерная, д. 27а	Россия, Мурманская область, Кандалакша городской округ, поселок Зеленоборский	0101000020E6100000DAE21A9FC9304040718E3A3AAEB65040
60458	3	30	1741	53384	32789	\N	66.963067956030102	Мурманская область, муниципальное образование Кандалакшский район, сельское поселение Алакуртти Кандалакшского района, ул. Содружества, д. 1	Россия, Мурманская область, Кандалакша городской округ, село Алакуртти	0101000020E6100000F38DE89E755D3E40BFF4F6E7A2BD5040
60459	3	30	1741	53384	32832	\N	66.965033000000005	Мурманская область, муниципальное образование Кандалакшский район, сельское поселение Алакуртти Кандалакшского района, ул. Набережная, д. 37	Россия, Мурманская область, Кандалакша городской округ, село Алакуртти	0101000020E610000037C2A2224E5B3E40E4A3C519C3BD5040
60601	3	30	1913	31224	32187	\N	67.374576000000005	г. Полярные Зори, Сивко, 5		0101000020E6100000524832AB7740404075779D0DF9D75040
60600	3	30	1913	31224	32705	\N	67.374576000000005	г. Полярные Зори, Пушкина, 18		0101000020E6100000524832AB7740404075779D0DF9D75040
60605	3	30	1913	31224	32710	\N	67.374576000000005	г. Полярные Зори, Партизан Заполярья, 5а (гимназия)	Россия, Мурманская область, Апатиты городской округ, Полярные Зори	0101000020E6100000524832AB7740404075779D0DF9D75040
60604	3	30	1913	31224	32149	\N	67.371546560467195	г. Полярные Зори, Курчатова, 25 (шк.№4)	Россия, Мурманская область, Апатиты городской округ, Полярные Зори	0101000020E6100000732EC555653F4040537B116DC7D75040
60602	3	30	1913	31224	32792	\N	67.367562904155093	г. Полярные Зори, ул. Белова, 7А (шк.№3)	Россия, Мурманская область, Апатиты городской округ, Полярные Зори	0101000020E61000004F1E166A4D3F40400F0EF62686D75040
60606	3	30	1913	40412	\N	\N	67.407758999999999	нп Зашеек, Северная аллея, 8 (ДДТ)	Россия, Мурманская область, Апатиты городской округ, поселок Зашеек	0101000020E6100000D5D0066003464040946934B918DA5040
60608	3	30	1913	31630	32749	\N	67.430783000000005	пгт. Африканда-2, Советская, 8		0101000020E61000004BAE62F19B5A40400F2BDCF291DB5040
52322	3	29	\N	59066	67507	\N	59.545274999999997	"Тосненский район, город Тосно, ул.Чехова, 8, МОУ ""Средняя общеобразовательная школа №4"" (правая рекреация)"		0101000020E6100000E8154F3DD2DC3E40C7293A92CBC54D40
52321	3	29	\N	59066	67507	\N	59.545274999999997	"Тосненский район, город Тосно, ул.Чехова, 8, МОУ ""Средняя общеобразовательная школа №4"" (левая рекреация)"		0101000020E6100000E8154F3DD2DC3E40C7293A92CBC54D40
52323	3	29	\N	59066	67461	\N	59.549567000000003	"Тосненский район, город Тосно, ул.Островского, 3А, МОУ ДОД ""Тосненская школа искусств"""		0101000020E6100000FD3383F8C0DA3E40FDFA213658C64D40
51707	3	29	\N	59066	67518	\N	59.546753000000002	г. СПб, ул. Октябрьская наб. д.35 ВНИИ пожаоной охраны.		0101000020E6100000BFEE74E789E33E40B5FE9600FCC54D40
52328	3	29	\N	59066	67560	\N	59.557578999999997	"Тосненский район, г.Тосно, ул.Октябрьская, д.125, ООО ТПК ""ИСКОЖ-Тосно"" (помещение столовой)"		0101000020E6100000D8D64FFF59E73E40DBF7A8BF5EC74D40
52320	3	29	\N	59066	67494	\N	59.540613	"Тосненский район, город Тосно, ул.Максима Горького, 5, МОУ ""Тосненская средняя общеобразовательная школа №3"" (правая рекреация)"		0101000020E61000005B0BB3D0CEDD3E406F6589CE32C54D40
52331	3	29	\N	59066	67607	\N	59.533579000000003	"Тосненский район, г.Тосно, ул.Гоголя 8, МОУ ""Гимназия №2 г.Тосно"" (1 этаж, рекреация)"		0101000020E610000009E1D1C611E33E408C6A11514CC44D40
52291	3	29	\N	59047	\N	\N	59.647455999999998	"Тихвинский район, Тихвин, 4 микрорайон, д. 38, МОУ ""Лицей №7"""		0101000020E61000005A0F5F268AC44040ABCC94D6DFD24D40
52300	3	29	\N	59047	67367	\N	59.620862000000002	Тихвинский район, Тихвин, ул. Центролитовская, д. 5, Тихвинский промышленно-гуманитарный техникум		0101000020E61000003F541A31B3BF404022AAF06778CF4D40
52292	3	29	\N	59047	67424	\N	59.643841000000002	"Тихвинский район, Тихвин, ул.К.Маркса, д.43, МОУ ""Средняя общеобразовательная школа №3"""		0101000020E6100000C09657AEB7C340407769C36169D24D40
52293	3	29	\N	59047	67473	\N	59.645054999999999	"Тихвинский район, Тихвин, 5 микрорайон, д.37, МОУ ""Гимназия №2"""		0101000020E610000084A0A3552DC34040868F882991D24D40
52288	3	29	\N	59047	67483	\N	59.647655999999998	"Тихвинский район, Тихвин, 1 микрорайон, д. 37, МОУ ""Средняя общеобразовательная школа №6"" "		0101000020E610000033DE567A6DC6404072874D64E6D24D40
51639	3	29	\N	58989	67182	\N	60.136418534020898	Волховский район, г.Сясьстрой, ул. Кирова,162-а	Россия, Ленинградская область, Волховский район	0101000020E61000001BD9959691424040C9C6832D76114E40
52385	3	29	\N	4047	1087	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор пр.Героев, д.62 , Шахматный клуб		0101000020E61000009D84D21742163D4005172B6A30F34D40
52383	3	29	\N	4047	1087	\N	59.905802473228199	г.Сосновый Бор, г.Сосновый Бор пр.Героев, д.36 , школа №4	Россия, Ленинградская область, Сосновый Бор, проспект Героев, 36	0101000020E61000001C959BA8A5153D406153E751F1F34D40
52384	3	29	\N	4047	24369	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Солнечная, д.31 ,Гимназия №5		0101000020E61000009D84D21742163D4005172B6A30F34D40
52166	3	29	\N	4047	24369	\N	59.895619000000003	"Ленинградская область, Лужский район, дер.Почап,ул.Солнечная д.1 кв.1 ОАО ""УК Надежда"""		0101000020E6100000070C923EAD163D408F56B5A4A3F24D40
52388	3	29	\N	4047	66556	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Молодежная, д.32 , школа №7		0101000020E61000009D84D21742163D4005172B6A30F34D40
52387	3	29	\N	4047	66556	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Молодежная, д.31 , школа №6		0101000020E61000009D84D21742163D4005172B6A30F34D40
52337	3	29	\N	4047	67240	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Малая Земля, д.5 , школа №3		0101000020E61000009D84D21742163D4005172B6A30F34D40
52390	3	29	\N	4047	1113	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор Липовский пр., д.13 , школа№9		0101000020E61000009D84D21742163D4005172B6A30F34D40
52389	3	29	\N	4047	67156	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Ленинградская, д.64 , Лицей №8		0101000020E61000009D84D21742163D4005172B6A30F34D40
52381	3	29	\N	4047	66995	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Космонавтов, д.14 , школа №2		0101000020E61000009D84D21742163D4005172B6A30F34D40
52370	3	29	\N	4047	66995	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Космонавтов, д.22 ,		0101000020E61000009D84D21742163D4005172B6A30F34D40
52380	3	29	\N	4047	66380	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Комсомольская, д.11 , школа №1		0101000020E61000009D84D21742163D4005172B6A30F34D40
52379	3	29	\N	4047	66380	\N	59.899915	г.Сосновый Бор, г.Сосновый Бор ул.Комсомольская 2А ,		0101000020E61000009D84D21742163D4005172B6A30F34D40
52386	3	29	\N	4047	67274	\N	59.899915	"г.Сосновый Бор, г.Сосновый Бор пр.Героев, д.63А , ЦРЛ ""Гармония"""		0101000020E61000009D84D21742163D4005172B6A30F34D40
52276	3	29	\N	59004	67591	\N	59.089213999999998	"Сланцевский район, г. Сланцы пл.Ленина, д.1, Дворец культуры ОАО ""Завод Сланцы"""		0101000020E6100000A2258FA7E52B3C40342C465D6B8B4D40
52271	3	29	\N	59004	67464	\N	59.115110999999999	Сланцевский район, г. Сланцы  ш.Славы д.9-б   Театр кукол		0101000020E6100000B18BA2073E1A3C4076340EF5BB8E4D40
52267	3	29	\N	59004	67490	\N	59.113767000000003	Сланцевский район, г. Сланцы,  ул.М.Горького, д.9 МОУ СОШ №1		0101000020E6100000562B137EA9173C40992EC4EA8F8E4D40
52275	3	29	\N	59004	67554	\N	59.094104999999999	"Сланцевский район, г. Сланцы ул.Ломоносова, д.39 МОУ ""Сланцевская СОШ №2"""		0101000020E6100000A724EB7074293C40EEB1F4A10B8C4D40
52262	3	29	\N	59004	67612	\N	59.118075926987999	"Сланцевский район, г. Сланцы, ул. Ленина, д.25, кор. 8, Театр""Бумс"""	Россия, Ленинградская область, Сланцевский район, Сланцы, улица Ленина, 25	0101000020E6100000D6355A0EF4183C40A438471D1D8F4D40
52256	3	29	\N	59004	67431	\N	59.113979999999998	Сланцевский район, г. Сланцы  Комсомольское ш.21, ГП Сланцевское ДРСУ,		0101000020E6100000FC389A232B133C40F4328AE5968E4D40
52277	3	29	\N	59004	67617	\N	59.092289000000001	"Сланцевский район, г. Сланцы ул. Декабристов, д.13,  МУ ""Центр социального обслуживания пожилого возраста и инвалидоа ""Надежда"", "		0101000020E610000010751F80D42A3C40E9633E20D08B4D40
52261	3	29	\N	59004	67541	\N	59.121290999999999	"Сланцевский район, г. Сланцы ул. Грибоедова д.19 -б МОУ ""Сланцевская общеобразовательная школа №3"", "		0101000020E6100000F7CB272B86173C404A26A776868F4D40
51651	3	29	\N	59068	67465	\N	60.141886999999997	Всеволожский район, г.Сертолово, ул.Молодцова, д.4, корп.2, школа №2, столовая,		0101000020E6100000506EDBF7A8373E40205D6C5A29124E40
51808	3	29	\N	58979	\N	\N	60.757493957460603	"Выборгский район, п. Селезнёво,Детский сад ""Веселый ручеек"""		0101000020E6100000E9D500A5A19E3C4047753A90F5604E40
52220	3	29	\N	59015	67427	\N	61.0362552764593	"Приозерский район, г.Приозерск, ул.Чапаева,д.19, ГОУ СПО ""Приозерский политехнический колледж №5, холл, "		0101000020E610000085285FD042223E4082A8FB00A4844E40
52227	3	29	\N	59015	67501	\N	61.036951000000002	Приозерский район, г.Приозерск, ул.Ленина 22 школа №5		0101000020E610000010C99063EB1D3E40FA4674CFBA844E40
52226	3	29	\N	59015	67272	\N	61.035277369390499	Приозерский район, г.Приозерск, ул.Исполкомовская, д.5, киноконцертный зал, холл 2-го этажа		0101000020E6100000BD8C62B9A51D3E4087A6ECF483844E40
52224	3	29	\N	59015	67479	\N	61.040976000000001	"Приозерский район, г.Приозерск, ул.Гастелло, д.3, МОУ ""Приозерская начальная школа-сад компенсирующего вида"" холл"		0101000020E6100000D7DB662AC41F3E40E0F599B33E854E40
52186	3	29	\N	59057	67517	\N	60.906317999999999	Подпорожский район, г. Подпорожье,  ул. Исакова д.19 помещение филиала Санкт-Петерб.инст. Внешнеэкон.связей,Экономики и права.		0101000020E610000092B1DAFCBF16414058E36C3A02744E40
52191	3	29	\N	59057	67476	\N	60.916024999999998	Подпорожский район, г. Подпорожье,  ул. Волкова, д. 29А		0101000020E61000006A50340F60134140C1A8A44E40754E40
52193	3	29	\N	59057	67398	\N	60.921233000000001	Подпорожский район, г. Подпорожье,  ул. Горького д 13		0101000020E61000009BABE639221341407C7F83F6EA754E40
52029	3	29	\N	59051	67381	\N	59.786676999999997	Кировский район, г.Отрадное, 1-ый Советский пр., д18, МОУ СШ №3		0101000020E6100000C68B852172CE3E40F8C1F9D4B1E44D40
52376	3	29	\N	59048	67368	\N	59.695783087631	"Тосненский район, город Никольское, ул.Октябрьская, 9А, МОУ ""СОШ №3 г.Никольское"", 1 этаж (начальная школа)"		0101000020E6100000CB660E492DC83E406F0ED76A0FD94D40
52149	3	29	\N	58933	\N	\N	58.689292000000002	Лужский район, г. Луга, Городок , МОУ СОШ		0101000020E61000004852D2C3D0D63D407DB262B83A584D40
52147	3	29	\N	58933	\N	\N	58.689292000000002	Лужский район, г. Луга, Городок , СОШ		0101000020E61000004852D2C3D0D63D407DB262B83A584D40
52139	3	29	\N	58933	67321	\N	58.731014682330198	Лужский район, г. Луга, проспект Кирова, дом № 74 МОУ  СОШ №3	Россия, Ленинградская область, Лужский район, Луга, проспект Кирова	0101000020E6100000669FC728CFD83D4056F146E6915D4D40
52137	3	29	\N	58933	67321	\N	58.734589999999997	"Лужский район, г. Луга, проспект Кирова, дом № 75 МУК  Лужский городской ДК"		0101000020E610000058207A5226D93D40FCFB8C0B075E4D40
52135	3	29	\N	58933	67321	\N	58.743118963729401	Лужский район, г. Луга, проспект Кирова, дом № 39 МОУ ДОД Лужская школа искуссств		0101000020E6100000158BDF1456DA3D40A304FD851E5F4D40
52146	3	29	\N	58933	67350	\N	58.721271361532303	Лужский район, г. Луга, проспект Володарского, дом № 52, Лужский аграрно-промышленный колледж		0101000020E610000062A3ACDF4CD83D40D046AE9B525C4D40
52145	3	29	\N	58933	67350	\N	58.725754521905998	Лужский район, г. Луга, проспект Володарского, дом № 15, ГУ Лужский центр занятости населения	Россия, Ленинградская область, Лужский район, Луга, проспект Володарского, 15	0101000020E6100000AF22A30392D83D4049F4328AE55C4D40
52143	3	29	\N	58933	67350	\N	58.723089000000002	Лужский район, г. Луга, проспект Володарского, дом № 30, Жилкомсервис №2		0101000020E61000001616DC0F78D83D40768C2B2E8E5C4D40
52138	3	29	\N	58933	67322	\N	58.726756999999999	Лужский район,  г. Луга, улица Красной Артиллерии, дом № 1, помещение  МОУ  СОШ №2		0101000020E61000006A334E4354D93D40CD91955F065D4D40
52134	3	29	\N	58933	67458	\N	58.736122000000002	"Лужский район, г. Луга, пр.Комсомольский,18 университет им. Кирилла и Мефодия"		0101000020E61000005EF58079C8DC3D40DDEEE53E395E4D40
52075	3	29	\N	359	67470	\N	60.725872000000003	"Лодейнопольский р-н, г. Лодейное Поле, ул.Свердлова, д.4  МКОУ Лодейнопольская основная общеобразовательная школа № 1"""		0101000020E610000083F755B950C74040838AAA5FE95C4E40
52076	3	29	\N	359	267	\N	60.725026999999997	Лодейнопольский р-н, г. Лодейное Поле, пр.Октябрьский, д. 40 здание Лодейнопольского представительства Ленинградского Государственного университета им. А.С. Пушкина	Россия, Ленинградская область, Лодейное Поле, Октябрьский проспект, 40	0101000020E6100000DC2E34D769C84040C6DB4AAFCD5C4E40
52071	3	29	\N	359	102	\N	60.734977999999998	Лодейнопольский р-н, г. Лодейное Поле, пр.Ленина, д. 94  ОВО при ОМВО ОМВД по Лодейнопольскому р-ну, спортзал		0101000020E610000070B0373124C34040C6A354C2135E4E40
52070	3	29	\N	359	102	\N	60.735691000000003	"Лодейнопольский р-н, г. Лодейное Поле, пр.Ленина, д.54  МКОУ ""Лодейнопольская СОШ № 2 "" "		0101000020E6100000B37DC85BAEC44040147B681F2B5E4E40
52069	3	29	\N	359	102	\N	60.735691000000003	"Лодейнопольский р-н, г. Лодейное Поле, пр.Ленина, д. 54-а  МКОУ ""Лодейнопольская начальная общеобразовательная школа"" "		0101000020E6100000B37DC85BAEC44040147B681F2B5E4E40
52065	3	29	\N	359	102	\N	60.734631	"Лодейнопольский район, г. Лодейное Поле, пр. Ленина, д. 10, помещение МКОУ ДОД ""Детский центр эстетического развития"""	Россия, Ленинградская область, Лодейное Поле, Ленина проспект, 10	0101000020E61000001C7A8B87F7C640405BD07B63085E4E40
52068	3	29	\N	359	66994	\N	60.7366769331001	"Лодейнопольский район, г. Лодейное Поле, ул.Гагарина, д. 10, корп.2, помещение ГБОУ СПО ""Лодейнопольский техникум промышленных технологий"""		0101000020E610000099F1B6D26BC54040925B936E4B5E4E40
52042	3	29	\N	59067	67564	\N	59.885069999999999	"Кировский район, г.Кировск, б-р Партизанской Славы, д.10, МОУ ""Кировская СОШ № 2"""		0101000020E6100000A2D5C9198AFF3E40DA5548F949F14D40
52043	3	29	\N	59067	67457	\N	59.887529999999998	"Кировский район, г.Кировск, ул.Молодежная, д.4а      МОУ ДОД ""ЦДТ"" Юность"""		0101000020E61000007FF78E1A13FE3E40041C42959AF14D40
52005	3	29	\N	59052	67386	\N	59.451849000000003	"Киришский район, г.Кириши, пр Победы, д.1, ГОУСПО ЛО ""Киришский политехнический колледж"""		0101000020E61000003E75AC527A0440407BDD2230D6B94D40
52006	3	29	\N	59052	67485	\N	59.448121	"Киришский район, г.Кириши, ул. Строителей, д.12, МОУ ""Киришская средняя общеобразовательная школа №6"		0101000020E6100000F6CFD380410440404ED367075CB94D40
52002	3	29	\N	59052	67553	\N	59.453175000000002	"Киришский район, г. Кириши, ул. Пионерская, д.6 , МОУ ""Киришская общеобразовательная школа №1"		0101000020E6100000A81ABD1AA0024040B22E6EA301BA4D40
51997	3	29	\N	59052	67539	\N	59.443876000000003	"Киришский район, г.Кириши, бульвар Молодежный,д.30 МОУ  ""Киришская Средняя общеобразовательная школа №7"" "		0101000020E6100000F6419605130140405ABDC3EDD0B84D40
51995	3	29	\N	59052	67632	\N	59.443876000000003	"Киришский район, г.Кириши, бульвар Молодежный,д.30 МОУ       ""Киришская Средняя общеобразовательная школа №7"""		0101000020E6100000F6419605130140405ABDC3EDD0B84D40
51792	3	29	\N	59024	67292	\N	60.949441857055703	Выборгский район, г. Каменногорск, Ленинградское шоссе д.93  МОУ «Каменногорская средняя общеобразовательная школа»	Россия, Ленинградская область, Каменногорск, улица Майская, 93	0101000020E6100000E2067C7E18213D4073B9C15087794E40
51991	3	29	\N	59071	67516	\N	59.359231999999999	"Кингисеппский район,  клуб ""Парусинка"" г. Ивангород  ул. Льнопрядильная, 8,  (г. Ивангород)"		0101000020E61000003D29931ADA343C409DD66D50FBAD4D40
51881	3	29	\N	59064	67596	\N	59.562424999999998	г.Гатчина, ул.Чехова, д.11		0101000020E610000088F6B182DF223E40F5B9DA8AFDC74D40
51894	3	29	\N	59064	67486	\N	59.557022000000003	г. Гатчина,  ул.Слепнева, д.25		0101000020E6100000FE9C82FC6C183E408693347F4CC74D40
51875	3	29	\N	59064	67551	\N	59.573796999999999	г.Гатчина, ул.Киргетова, д.28		0101000020E6100000342DB1321A213E407EC51A2E72C94D40
51883	3	29	\N	59064	67463	\N	59.559817000000002	Ленинградская область, Гатчинский муниципальный район, город Гатчина, К.Маркса д.17А Институт ГИЭФПТ		0101000020E610000062DBA2CC06213E40575F5D15A8C74D40
51891	3	29	\N	59064	67445	\N	59.560710999999998	г. Гатчина , ул.Ген.Кныша, д.7 к.2		0101000020E6100000425E0F26C5173E40F4C0C760C5C74D40
51888	3	29	\N	59064	67445	\N	59.558477000000003	г. Гатчина , ул.Ген.Кныша, д.14а		0101000020E610000045BB0A293F193E40BB48A12C7CC74D40
51882	3	29	\N	59064	67547	\N	59.565069000000001	г.Гатчина, ул.Володарского д.17		0101000020E6100000B090B932A8223E40E17D552E54C84D40
51753	3	29	\N	58966	67454	\N	60.710442099267297	Выборгский район, г. Выборг, Школьная пл., д.2		0101000020E61000007B4D0F0A4AC13C4038DA71C3EF5A4E40
51754	3	29	\N	58966	67404	\N	60.709879000000001	Выборгский район, г. Выборг, Школьная пл., д.4, МОУ «Средняя общеобразовательная школа  №7»		0101000020E61000006CCEC133A1C13C40008FA850DD5A4E40
51758	3	29	\N	58966	67469	\N	60.703465000000001	Выборгский район, г. Выборг, ул. Сухова, д.7а, МДОУ  Детский сад компенсирующего вида		0101000020E61000000856D5CBEFC43C40B97020240B5A4E40
51749	3	29	\N	58966	67107	\N	60.713506000000002	Выборгский район, г. Выборг, Суворова пр. (Суворовский пр.) д.4		0101000020E6100000C05E61C1FDBC3C40F9BF232A545B4E40
51764	3	29	\N	58966	67602	\N	60.698881	Выборгский район, г. Выборг, ул. Спортивная, д.14, МБДОУ «Детский сад комбинированного вида «Улыбка»»		0101000020E6100000FAB660A92EC43C40DC65BFEE74594E40
51750	3	29	\N	58966	67511	\N	60.709822000000003	Выборгский район, г. Выборг, ул. Советская, д.16		0101000020E6100000E76D6C76A4BE3C409CFD8172DB5A4E40
51780	3	29	\N	58966	67521	\N	60.695028000000001	Выборгский район, г. Выборг, ул. Рубежная, д.28а, Комплексный центр социального обслуживания «Выборг»		0101000020E6100000BB9866BAD7C53C40F3E670ADF6584E40
51748	3	29	\N	58966	67378	\N	60.708030000000001	Выборгский район, г. Выборг, ул. Пушкина, д.10, 2-ой  корпус   МОУ  « Гимназия»		0101000020E610000047938B31B0BE3C401F4B1FBAA05A4E40
51769	3	29	\N	58966	67114	\N	60.713506000000002	Выборгский район, г. Выборг, ул. Промышленная, д.1, ГАОУ НПО ЛО «Профессиональное училище № 46»		0101000020E6100000C05E61C1FDBC3C40F9BF232A545B4E40
51771	3	29	\N	58966	67545	\N	60.717616999999997	Выборгский район, г. Выборг, ул. Офицерская, д.2, Выборгский филиал ФГОУ ВПО «Санкт-Петербургского университета гражданской авиации»		0101000020E610000040F7E5CC76C13C40DD06B5DFDA5B4E40
51759	3	29	\N	58966	67583	\N	60.702285000000003	Выборгский район, г. Выборг, Ленинградское шоссе, д.45а, МОУ  «Средняя общеобразовательная  школа № 8»		0101000020E61000005C02F04FA9C63C4056BC9179E4594E40
51772	3	29	\N	58966	67422	\N	60.719604530723501	Выборгский район, г. Выборг, ул. Горная, д.10/3, МОУ «Средняя общеобразовательная школа №37»		0101000020E61000003318231285C23C40E08442041C5C4E40
51745	3	29	\N	58966	67562	\N	60.712533999999998	Выборгский район, г. Выборг, ул. Выборгская, д.2, Выборгский институт (филиал) АОУ ВПО «ЛГУ им. А.С. Пушкина»		0101000020E6100000EE409DF2E8BA3C40DFA46950345B4E40
51783	3	29	\N	58966	67421	\N	60.691377035027202	Выборгский район, г. Выборг, ул. Макарова, д.6, МДОУ «Детский сад комбинированного вида № 25, «Золотая рыбка»		0101000020E610000007CF842689C93C40721AA20A7F584E40
51725	3	29	\N	59050	67523	\N	60.024481999999999	Всеволожский район, г.Всеволожск, ул.Межевая, д.10, средняя школа №2,		0101000020E61000000858AB764DA03E409BABE63922034E40
51726	3	29	\N	59050	67438	\N	60.026918000000002	"Всеволожский район, г.Всеволожск, ул.Ленинградская, д.14/1, ЗАО ""Труд"", "		0101000020E6100000A5D8D138D49F3E403DD68C0C72034E40
51721	3	29	\N	59050	67575	\N	60.024819000000001	Всеволожский район, г.Всеволожск, Колтушское ш., д.110, Дом культуры,		0101000020E6100000FC1C1F2DCEA43E40E3A8DC442D034E40
51731	3	29	\N	59050	67379	\N	60.010295301258701	"Всеволожский район, г.Всеволожск, ул.Советская  д.2,моложежно-подростковый клуб ""Пульс"", "		0101000020E6100000EF8CB62A899C3E40FA27B85851014E40
13059	7	66	939	26909	62130	\N	55.995019999999997	деревня Саваткино, Новая, 26		0101000020E6100000F7E6374C34404740D66EBBD05CFF4B40
51604	3	29	\N	59075	67574	\N	59.928564000000001	Волховский район, пр.Державина,65 неполная коррекционная школа №4		0101000020E6100000151F9F909D294040191F662FDBF64D40
51613	3	29	\N	59075	67616	\N	59.895854	Волховский район, ул.Ломоносова,7 гор.Гимназия		0101000020E6100000317BD976DA2C4040D2FE0758ABF24D40
51530	3	29	\N	59062	67452	\N	59.471995	Бокситогорский район, г. Бокситогорск  ул. Социалистическая д26-А, МОУ СОШ №3		0101000020E61000003274ECA012ED4040117008556ABC4D40
51529	3	29	\N	59062	67606	\N	59.477251000000003	Бокситогорский район, г. Бокситогорск  ул. Павлова,20 , МОУ СОШ №2		0101000020E61000007842AF3F89ED4040DD7D8E8F16BD4D40
51532	3	29	\N	59062	67436	\N	59.473526	Бокситогорский район, г. Бокситогорск  ул. Косомольская д 5-А, Культурный досуговый центр.		0101000020E6100000E2B034F0A3EC404021E7FD7F9CBC4D40
52366	3	29	564	3512	67333	\N	59.642353477046399	"Тосненский район, посёлок Ульяновка, ул.Колпинская, 6, МОУ ДОД ""Ульяновская детская музыкальная школа"""		0101000020E61000003BC780ECF5C23E4066BE839F38D24D40
52339	3	29	564	14227	67230	\N	59.416077000000001	"Тосненский район, посёлок Рябово, ул.Мысленская, 7, филиал МУК ""Пельгорский ДК"" (Рябовский досуговый центр)"		0101000020E6100000EA211ADD41203F4014CFD90242B54D40
52354	3	29	564	14945	67195	\N	59.598502000000003	Тосненский район, посёлок Шапки, ул.Нины Куковеровой, 4, помещение администрации		0101000020E61000001C40BFEFDF303F40994BAAB69BCC4D40
52352	3	29	564	10993	24392	\N	59.351526	Тосненский район, дер Чудской Бор, ул.Новая 1, помещение Социально-учебного центра		0101000020E610000027A3CA30EE6A3F40CBD8D0CDFEAC4D40
52356	3	29	564	11076	67336	\N	59.662918829364401	"Тосненский район,  дер. Федоровское, ул. Шоссейная, д.7 МУК ""Федоровский Дом культуры"""	Россия, Ленинградская область, Тосненский район, деревня Фёдоровское	0101000020E6100000DE59BBED42873E40D272A087DAD44D40
52355	3	29	564	50500	67175	\N	59.570180821146202	"Тосненский район, г. п. Форносово, Павловское шоссе 29-а МУК ""Форносовский Дом культуры"""	Россия, Ленинградская область, Тосненский район, городской посёлок Форносово	0101000020E61000005D6E30D4618D3E4079E6E5B0FBC84D40
52332	3	29	564	13892	\N	\N	59.515404066682798	"Тосненский район, посёлок Ушаки, 19, МОУ ""Ушакинская средняя общеобразовательная школа №1"""		0101000020E6100000EA78CC4065E83E40211D1EC2F8C14D40
52334	3	29	564	13892	66285	\N	59.516049000000002	"Тосненский район, с.Ушаки, пр.Кирова, д.200а, МОУ ""Ушакинская средняя общеобразовательная школа №2"""		0101000020E6100000C0CC77F013E73E401711C5E40DC24D40
52333	3	29	564	13892	66285	\N	59.516790443235898	"Тосненский район, с.Ушаки пр.Кирова 143, МУК ""Ушакинский центр досуга и нар.творчества в селе Ушаки"""	Россия, Ленинградская область, Тосненский район, поселок Ушаки	0101000020E6100000D923D40CA9E63E402E73BA2C26C24D40
52367	3	29	564	59038	67341	\N	59.6474029984835	"Тосненский район,  пос.Ульяновка, Советский пр.,3 МУК ТКЦ ""Саблино"""		0101000020E6100000F871344756C63E40882AFC19DED24D40
52369	3	29	564	58965	67113	\N	59.641725999999998	"Тосненский район,  пос. Ульяновка, пр. Володарского,70 МОУ СОШ №1, правая рекреация СОШ, "		0101000020E61000000EBDC5C37BCA3E40177FDB1324D24D40
52368	3	29	564	58965	67113	\N	59.638174328548097	" Тосненский район, посёлок Ульяновка, пр.Володарского, 70, МОУ ""Ульяновская средняя общеобразовательная школа №1"" (столовая)"		0101000020E61000002EE23B31EBC53E40299485AFAFD14D40
52365	3	29	564	58965	67314	\N	59.638759999999998	"Тосненский район, посёлок Ульяновка, ул.2-я Футбольная, 1, МОУ ""Саблинская основная общеобразовательная школа"" (2 этаж)"		0101000020E6100000910BCEE0EFBF3E4019FF3EE3C2D14D40
52364	3	29	564	58965	67314	\N	59.638759999999998	"Тосненский район, посёлок Ульяновка, ул.2-я Футбольная, 1, МОУ ""Саблинская основная общеобразовательная школа"" (1 этаж)"		0101000020E6100000910BCEE0EFBF3E4019FF3EE3C2D14D40
52349	3	29	564	10898	66443	\N	59.264851999999998	" Тосненский район, деревня Трубников Бор, ул.Мира, 1А, МОУ ""Трубниковская основная общеобразовательная школа"""		0101000020E61000008BDD3EABCC643F40DD239BABE6A14D40
52327	3	29	564	13080	3767	\N	59.540471915156601	Тосненский район, г. Тосно, ул. М. Горького, д.5, помещени МОУ  СОШ № 3 (левая рекреация )	Россия, Ленинградская область, Тосненский район, Тосно, улица Максима Горького, 5	0101000020E610000088F37002D3DD3E40AD33BE2F2EC54D40
52325	3	29	564	13080	3767	\N	59.537311000000003	"Тосненский район, город Тосно, ул.Максима Горького, 15, МОУ ""Гимназия №2 г.Тосно"""	Россия, Ленинградская область, Тосненский район, Тосно, улица Максима Горького, 15	0101000020E6100000A33B889D29E03E40FA635A9BC6C44D40
52329	3	29	564	13080	3710	\N	59.541302000000002	"Тосненский район, город Тосно, пр.Ленина, 40, МУ СКК ""Космонавт"""	Россия, Ленинградская область, Тосненский район, Тосно, проспект Ленина, 44	0101000020E610000061C3D32B65E13E4034A1496249C54D40
52324	3	29	564	13080	3710	\N	59.541302000000002	"Тосненский район, город Тосно, пр.Ленина, 42, МОУ ДОД ""Дом детского творчества"" (актовый зал)"		0101000020E610000061C3D32B65E13E4034A1496249C54D40
52317	3	29	564	13080	3710	\N	59.544130000000003	"Тосненский район,город Тосно, пр.Ленина, 24, МОУ ""Средняя общеобразовательная школа №1 г.Тосно"" (рекреация, 1 этаж)"		0101000020E61000000D17B9A7ABDF3E40E162450DA6C54D40
52316	3	29	564	13080	3710	\N	59.544130000000003	"Тосненский район,город Тосно, пр.Ленина, 24, МОУ ""Средняя общеобразовательная школа №1 г.Тосно"" (актовый зал)"		0101000020E61000000D17B9A7ABDF3E40E162450DA6C54D40
52326	3	29	564	13080	67598	\N	59.539610000000003	"Тосненский район, город Тосно, ул.Советская, 10А, Комитет образования МО ""Тосненский район"""		0101000020E61000004F2157EA59E03E401B4CC3F011C54D40
52330	3	29	564	13080	3905	\N	59.542566000000001	"Тосненский район, г. Тосно, Пушкинская набережная, д.1, помещение ООО ""Авангард"""		0101000020E6100000209A79724DE53E40F5F57CCD72C54D40
52315	3	29	564	13080	3692	\N	59.557875000000003	"Тосненский район, г. Тосно, мкр. Тосно-2, Московское шоссе д.40,  аптека МУЗ ""Тосненская ЦРБ"""		0101000020E61000002E5393E00DD93E40C520B07268C74D40
52359	3	29	564	11123	\N	\N	59.718639000000003	Тосненский район, поселок Тельмана, 50, помещение администрации (1 этаж)		0101000020E610000076DEC666479E3E40A950DD5CFCDB4D40
52348	3	29	564	11123	65892	\N	59.720975450012901	"Тосненский район, поселок Тельмана, ул.Октябрьская, д.5, помещение №3 ООО ""Форт Линк"""	Россия, Ленинградская область, Тосненский район, посёлок Тельмана	0101000020E610000093C83EC8B29C3E40E71DA7E848DC4D40
52357	3	29	564	11123	66555	\N	59.718639000000003	"Тосненский район, посёлокТельмана, ул.Ленинградская, 7, МОУ ""Тельмановская средняя общеобразовательная школа"" (1 этаж)"		0101000020E610000076DEC666479E3E40A950DD5CFCDB4D40
52358	3	29	564	11123	67123	\N	59.722828652491302	"Тосненский район, посёлок Тельмана, ул.Красноборская, 5, помещение Тельмановской врачебной амбулатории МУЗ ""Тосненская ЦРБ"""	Россия, Ленинградская область, Тосненский район, посёлок Тельмана	0101000020E6100000BF4868CBB99C3E40D9CC21A985DC4D40
52335	3	29	564	14025	\N	\N	59.420563999999999	Тосненский район, дер.Тарасово д.1, помещение МУК Тарасовский СДК		0101000020E6100000DD4598A25CEA3E40FEEF880AD5B54D40
52341	3	29	564	58967	\N	\N	59.335076000000001	"Тосненский район, п.Сельцо 16, МОУ ""Сельцовская средняя общеобразовательная школа им.Е.М.Мелашенко"""		0101000020E61000009D8026C286333F4056D636C5E3AA4D40
52343	3	29	564	10802	\N	\N	59.335076000000001	"Тосненский район, п.Сельцо 18, МОУ ""Сельцовская средняя общеобразовательная школа им.Е.М.Мелашенко"" (начальная школа)"		0101000020E61000009D8026C286333F4056D636C5E3AA4D40
52340	3	29	564	58970	67128	\N	59.416077000000001	"Тосненский район, посёлок Рябово, ул.Рычина, 8, МУК ""Пельгорский Дом культуры"""		0101000020E6100000EA211ADD41203F4014CFD90242B54D40
52338	3	29	564	14182	67164	\N	59.149152999999998	"Тосненский район, посёлок Радофинниково, ул.Комсомольская, 6, МОУ ""Радофинниковская основная общеобразовательная школа"""		0101000020E6100000DF313CF6B3E03E40D68C0C7217934D40
52351	3	29	564	14797	24371	\N	59.306474999999999	Тосненский район, деревня Померанье, Московское шоссе, 27А, помещение фельдшерско-акушерского пункта		0101000020E6100000B2F2CB608C503F405305A3923AA74D40
52353	3	29	564	11029	\N	\N	59.556328999999998	"Тосненский район, деревня Нурма, 8, МОУ ДОД ""Центр внешкольной работы д.Нурма"""		0101000020E6100000EFE53E390A043F407F68E6C935C74D40
52319	3	29	564	13272	66440	\N	59.564019999999999	Тосненский район, дер.Новолисино, ул. Заводская, 11, Новолисинская школа-интернат среднего (полного) общего образования (правая рекреация 1 этаж)		0101000020E610000015527E52EDC33E401C25AFCE31C84D40
52374	3	29	564	9079	67478	\N	59.703420999999999	" Тосненский район, город Никольское, ул.Школьная, 11, МОУ Гимназия №1 г.Никольское"""		0101000020E61000000C207C28D1CA3E40E92807B309DA4D40
52373	3	29	564	9079	4446	\N	59.704464999999999	"Тосненский район, город Никольское, Советский пр, 166А, МУК ""Никольский ДК"""		0101000020E61000007EE36BCF2CC93E409C16BCE82BDA4D40
52371	3	29	564	9079	2531	\N	59.708995000000002	"Тосненский район, город Никольское, ул.Первомайская, 10, МОУ ""СОШ №2 г.Никольское"" (вход со двора)"	Россия, Ленинградская область, Тосненский район, Никольское, Первомайская улица, 12	0101000020E61000004D66BCADF4C63E4086032159C0DA4D40
52372	3	29	564	9079	67369	\N	59.708995000000002	"Тосненский район, город Никольское, ул.Первомайская, 10, МОУ ""СОШ №2 г.Никольское"" (главный вход)"		0101000020E61000004D66BCADF4C63E4086032159C0DA4D40
52377	3	29	564	9079	67357	\N	59.695853586108797	"Тосненский район, город Никольское, ул.Октябрьская, 9А, МОУ ""СОШ №3 г.Никольское"", 1 этаж (главное фойе)"	Россия, Ленинградская область, Тосненский район, Никольское, Октябрьская улица	0101000020E6100000772CB64945C73E4038656EBE11D94D40
52375	3	29	564	9079	67409	\N	59.697183000000003	" Тосненский район, город Hикольское, ул.Дачная, 6, МУ ""Спортивно-досуговый Центр ""Надежда"""		0101000020E6100000056C0723F6C93E40E129E44A3DD94D40
52347	3	29	564	14369	4063	\N	59.367784454829099	"Тосненский район, пос. Любань, пр. Мельникова, д.18, МДОУ №17 ""Детский сад общеразвивающего вида пос.Любань"", музыкальный зал"	Россия, Ленинградская область, Тосненский район, посёлок Любань, проспект Мельникова, 16	0101000020E61000007100FDBE7F3F3F40FCFECD8B13AF4D40
52342	3	29	564	14369	4063	\N	59.366948999999998	Тосненский район, посёлок Любань, пр.Мельникова, 15, (помещение бывшей администрации)	Россия, Ленинградская область, Тосненский район, посёлок Любань, проспект Мельникова, 15	0101000020E61000000DC51D6FF23F3F406326512FF8AE4D40
52346	3	29	564	14369	67416	\N	59.352032239168601	Тосненский район, г. Любань, ул.Торговая 16, магазин №69 Тосненского РАЙПО	Россия, Ленинградская область, Тосненский район, Любань, Торговая улица	0101000020E6100000FBCDC47421423F409F9273620FAD4D40
52344	3	29	564	14369	67309	\N	59.340900626252797	"Тосненский район, г. Любань, ул. Заводская 1, помещение продовольственного магазина ООО ""Альянс"""	Россия, Ленинградская область, Тосненский район, Любань, Заводская улица	0101000020E6100000F0332E1C083D3F403C16DBA4A2AB4D40
52345	3	29	564	14369	67592	\N	59.346474999999998	"Тосненский район, г. Любань, ул.Алексеенко, д.24а, МОУ ""Любанская средняя общеобразовательная школа им.А.Н.Радищева"""		0101000020E6100000A54FABE80F413F40D8F0F44A59AC4D40
52336	3	29	564	14092	\N	\N	59.428085000000003	Тосненский район, посёлок Лисино-Корпус, ул.Турского, 3, (помещение администрации)	Россия, Ленинградская область, Тосненский район, посёлок Лисино-Корпус	0101000020E6100000338CBB41B4AA3E403F74417DCBB64D40
52362	3	29	564	11202	67119	\N	59.67306	"Тосненский район, посёлок Красный Бор, Советский пр, 47, МОУ ""Красноборская средняя общеобразовательная школа"""		0101000020E6100000205F420587AB3E40751F80D426D64D40
52363	3	29	564	11202	67362	\N	59.678034002675403	Тосненский район, посёлок Красный Бор, ул.Культуры, 62А, помещение администрации	Россия, Ленинградская область, Тосненский район, посёлок Красный Бор, улица Культуры	0101000020E6100000FE63213A04AE3E40BCC96FD1C9D64D40
52361	3	29	564	11202	3186	\N	59.671874247697197	" Тосненский район, посёлок Красный Бор, ул.Комсомольская, 6, корпус государственного предприятия радиовещания ""Радиоцентр-11"""	Россия, Ленинградская область, Тосненский район, посёлок Красный Бор, Комсомольская улица	0101000020E6100000C826F911BFB23E4030849CF7FFD54D40
52378	3	29	564	58925	67030	\N	59.643977	Тосненский район, посёлок Гладкое, ул.Школьная, 5, Гладковская сельская библиотека		0101000020E61000002E02637D03DB3E4027309DD66DD24D40
52360	3	29	564	15227	66986	\N	59.690894	" Тосненский район, посёлок Войскорово, 3, МОУ ""Войскоровская средняя общеобразовательная школа"" (1 этаж)"		0101000020E61000005B087250C2903E405680EF366FD84D40
52350	3	29	564	10937	66981	\N	59.220182999999999	Тосненский район, деревня Бабино, Московское шоссе, 63, помещение фельдшерско-акушерского пункта		0101000020E61000003A3DEFC6827A3F404D11E0F42E9C4D40
52313	3	29	1194	12998	66992	\N	59.927860000000003	Тихвинский район, пос.Шугозеро, ул.Советская, д.43, Администрация Шугозерского сельского поселения		0101000020E6100000F8C5A52A6D1B41401FA2D11DC4F64D40
52307	3	29	1194	12699	\N	\N	59.654330000000002	Тихвинский район, пос.Цвылево, д.2, Цвылёвский культурно-спортивный комплекс		0101000020E610000048FB1F60AD9A40405665DF15C1D34D40
52306	3	29	1194	12699	\N	\N	59.654330000000002	"Тихвинский район, деревня Цвылёво, д.46а, МОУ ""Ильинская СОШ"""		0101000020E610000048FB1F60AD9A40405665DF15C1D34D40
52299	3	29	1194	11445	3481	\N	59.645845999999999	"Тихвинский район, Тихвин, пл.Свободы, д.1, МУ ""Тихвинский районный Дом Культуры"""		0101000020E6100000085A8121ABC140404F20EC14ABD24D40
51858	3	29	1194	11445	3451	\N	59.642957911887898	Московская ул. Помещение участка электросети	Россия, Ленинградская область, Тихвинский район, Тихвин, Школьная улица	0101000020E61000005B5B785E2AC24040CD599F724CD24D40
52297	3	29	1194	11445	67550	\N	59.642867000000003	"Ленинградская область, Тихвин, ул.Школьная, д.33, МОУ ""Средняя общеобразовательная школа №1"""		0101000020E610000092B3B0A71DC24040BD56427749D24D40
52296	3	29	1194	11445	67392	\N	59.641795710295398	"Тихвинский район, Тихвин, ул.Пролетарской Диктатуры, д.47, МОУ ""СОШ №9"""	Россия, Ленинградская область, Тихвинский район, Тихвин, улица Пролетарской Диктатуры, 43	0101000020E610000055F833BC59C14040105A0F5F26D24D40
52295	3	29	1194	11445	67373	\N	59.639462443634898	"Тихвинский район, Тихвин, ул.Машиностроителей, д.41, МОУ ""СОШ №1"" (помещение начальной школы)"		0101000020E6100000569929ADBFC1404073840CE4D9D14D40
52301	3	29	1194	11445	67595	\N	59.652689000000002	"Тихвинский район,  Тихвин, ул.Зайцева, д.1, ООО ""Тихвинский лесхимзавод"""		0101000020E6100000C19140834DC14040BFBA2A508BD34D40
52289	3	29	1194	11445	67471	\N	59.641325999999999	"Тихвинский район, Тихвин ,ул. Борисова, д.4, ""Медицинский колледж в городе Тихвине"""		0101000020E6100000BB6070CD1DC7404089096AF816D24D40
52294	3	29	1194	11445	67544	\N	59.641579999999998	"Тихвинский район,  Тихвин, 6 микрорайон, д.13, МОУ ""Средняя общеобразовательная школа №4"""		0101000020E6100000780E65A88AC3404043E21E4B1FD24D40
52280	3	29	1194	11445	67604	\N	59.642595	"Тихвинский район, г.Тихвин, 3 микрорайон, д. 43,  МОУ ""Лицей №8"""		0101000020E610000080D8D2A3A9C440405CC98E8D40D24D40
52287	3	29	1194	11445	67482	\N	59.644672999999997	"Тихвинский район, г.Тихвин, 1 микрорайон, д. 32, МОУ ""Средняя общеобразовательная школа №5""  "		0101000020E61000004E9CDCEF50C640409ECE15A584D24D40
52304	3	29	1194	12609	67291	\N	59.677209941613597	Тихвинский район, поселок Сарка, улица Лесная дом 8 \\11, Саркский фельдшерско-акушерский пункт		0101000020E61000008B54185B08D44040184339D1AED64D40
52314	3	29	1194	13050	67032	\N	60.030603999999997	"Тихвинский район, дер.Пашозеро,ул.Центральная,д.1 , МОУ ""Пашозерская основная общеобразовательная школа"""		0101000020E61000000C789961A34E41403A90F5D4EA034E40
52305	3	29	1194	12673	\N	\N	59.569395606825204	Тихвинский район, деревня Мелегежская Горка дом 23, Андреевский центр культуры и отдыха	Россия, Ленинградская область, Тихвинский район, деревня Мелегежская Горка	0101000020E6100000789B374E0AB54040923CD7F7E1C84D40
52302	3	29	1194	12513	67258	\N	59.556676000000003	"Тихвинский район, пос.Красава, ул.Комсомольская, д.16, МОУ ""Красавская ООШ"""		0101000020E610000055DAE21A9FCB4040EB3BBF2841C74D40
52310	3	29	1194	12870	67298	\N	60.030210856394397	"Тихвинский район, дер.Коськово,ул.Школьная, д.4, МОУ ""Коськовская основная общеобразовательная школа"""	Россия, Ленинградская область, Тихвинский район, деревня Коськово	0101000020E61000009ED0EB4FE2A340405F7D3CF4DD034E40
52312	3	29	1194	58987	67174	\N	59.989854999999999	"Тихвинский район, дер.Еремина Гора, ул.Народная, д.77, МОУ ""Ерёминогорская средняя общеобразовательная школа"""		0101000020E61000007575C7629BF240401B649291B3FE4D40
52309	3	29	1194	12837	67221	\N	59.812817000000003	"Тихвинский район, дер.Горка,ул.Центральная д.33, МОУ ""Горская основная общеобразовательная школа"""		0101000020E6100000E0BDA3C684AA4040015130630AE84D40
52311	3	29	1194	12913	67062	\N	59.893908000000003	"Тихвинский район, дер.Ганьково,пер.Клубный, д.8, МУ ""Ганьковский культурный центр"""		0101000020E61000005F7CD11E2FE64040FFD0CC936BF24D40
52308	3	29	1194	58990	\N	\N	59.821430999999997	"Тихвинский район, д.Бор, д.21, МОУ ""Борская средняя общеобразовательная школа"""		0101000020E6100000C9CC052E8FF74040D575A8A624E94D40
52303	3	29	1194	12558	66386	\N	59.690181000000003	Тихвинский район, поселок Берёзовик, ул. Лесная, д.1, Березовский фельдшерско-акушерский пункт		0101000020E61000008577B988EFBC404009A9DBD957D84D40
52285	3	29	1125	11688	\N	\N	59.218221	Сланцевский район, п. Черновское,  Дом культуры		0101000020E6100000AB4203B16C6E3C4074266DAAEE9B4D40
52282	3	29	1125	58949	\N	\N	59.044657999999998	Сланцевский район, д. Старополье,  Дом культуры		0101000020E610000003965CC5E2973C409CC0745AB7854D40
52260	3	29	1125	10320	2953	\N	59.122584393031303	"Сланцевский район, г. Сланцы ул. Кирова д.18 , ГУНПО ""Профессиональный лицей №15"", "	Россия, Ленинградская область, Сланцевский район, Сланцы, улица Кирова, 18	0101000020E61000003411363CBD163C40A6811FD5B08F4D40
52258	3	29	1125	10320	2953	\N	59.123240000000003	"Сланцевский район, г. Сланцы ул. Кирова д.11 МОУ ""Сланцевская СОШ №3"""	Россия, Ленинградская область, Сланцевский район, Сланцы, улица Кирова, 11	0101000020E6100000BB29E5B512163C408FC70C54C68F4D40
52274	3	29	1125	10320	3172	\N	59.093375000000002	Сланцевский район, г. Сланцы ул.Дзержинского, д.4 ЗАГС		0101000020E6100000F2ED5D83BE283C40CBA145B6F38B4D40
52269	3	29	1125	10320	67477	\N	59.116233999999999	"Сланцевский район, г. Сланцы,  ул.Спортивная,2  МОУ ДОД ""Сланцевская ДЮСШ"""		0101000020E610000088BB7A1519153C40755776C1E08E4D40
52272	3	29	1125	10320	3148	\N	59.113615000000003	"Сланцевский район, г. Сланцы пр.Молодежный д.9 МОУ ""Сланцевская СОШ №6"""		0101000020E6100000D3DA34B6D71A3C40E3AAB2EF8A8E4D40
52273	3	29	1125	10320	67549	\N	59.113767000000003	"Сланцевский район, г. Сланцы ул. М.Горького д 9,  МОУ ""Сланцевская СОШ №1"" "		0101000020E6100000562B137EA9173C40992EC4EA8F8E4D40
52270	3	29	1125	10320	67310	\N	59.118108999999997	"Сланцевский район, г. Сланцы ул. Ленина д.25 /4, МОУ ДОД ""Сланцевская  детская музыкальная школа"""		0101000020E61000007AFD497CEE183C407F2E1A321E8F4D40
52264	3	29	1125	10320	67310	\N	59.118181000294499	"Сланцевский район, г. Сланцы,  ул. Ленина д 5,  МУК ""Городской Дом культуры"", "	Россия, Ленинградская область, Сланцевский район, Сланцы, улица Ленина, 5	0101000020E6100000C47C7901F6153C401901158E208F4D40
52265	3	29	1125	10320	67597	\N	59.111151409213498	"Сланцевский район, г. Сланцы, ул.Климчука д.1,  ФГОУ ""Сланцевский  индустриальный техникум"""		0101000020E61000002235ED629A153C4077F52A323A8E4D40
52259	3	29	1125	10320	67530	\N	59.123240000000003	"Сланцевский район, г. Сланцы, ул. Кирова д.11, МОУ  ""Сланцевская СОШ №3"""		0101000020E6100000BB29E5B512163C408FC70C54C68F4D40
52263	3	29	1125	10320	67491	\N	59.122186999999997	"Сланцевский район, г. Сланцы ул. Грибоедова  д.8  МОУ ДОД ""Сланцевский центр информационных технологий"", "		0101000020E610000082700514EA153C40887FD8D2A38F4D40
52266	3	29	1125	10320	67498	\N	59.111230999999997	Сланцевский район, г. Сланцы,  ул.Гагарина, д.2  поликлиника		0101000020E6100000EA03C93B87163C4093A641D13C8E4D40
52255	3	29	1125	10246	\N	\N	59.071851000000002	Сланцевский район, п. Сельхозтехника, Дом культуры		0101000020E610000048533D997F103C40AB97DF6932894D40
52283	3	29	1125	59012	\N	\N	59.056010999999998	Сланцевский район, д. Овсище,  Дом культуры		0101000020E610000099A0866F61B93C40AE9B525E2B874D40
52281	3	29	1125	11503	\N	\N	58.908126000000003	"Сланцевский район, д. Новоселье,  МОУ ""Новосельская основная образовательная школа"""		0101000020E61000000E4A9869FB573C40DB5207793D744D40
52284	3	29	1125	11631	65951	\N	59.153776999999998	Сланцевский район,  д.Ложголово,  ул. Загорская,8   МУК СДК		0101000020E6100000A016838769B73C4041F0F8F6AE934D40
52254	3	29	1125	10243	\N	\N	59.107298999999998	"Сланцевский район, д. Загривье, МОУ ""Загривская СОШ"""		0101000020E61000007F2F8507CDDA3B405EF23FF9BB8D4D40
52279	3	29	1125	11400	\N	\N	58.950623	Сланцевский район, д. Гусева Гора, МУК СДК Рудно		0101000020E61000007A5567B5C0463C40A7E9B303AE794D40
52278	3	29	1125	11356	\N	\N	59.020774000000003	Сланцевский район, д. Выскатка,   Дом культуры		0101000020E6100000F6B704E09F2E3C40B64DF1B8A8824D40
52257	3	29	1125	59011	\N	\N	59.133762575336597	"Сланцевский район, г. Сланцы,  д. Б. Поля, ГБУ ""Сланцевская специальная общеобразовательная школа закрытого типа"", "	Россия, Ленинградская область, Сланцевский район, деревня Большие Поля	0101000020E6100000D15966118A113C401A355F251F914D40
52247	3	29	97	59032	67323	\N	60.505745940064799	"Приозерский район, п.пл.69 км, ул.Заводская, д..1, административное здание завода ""ВНИИЗЕММАШ"", 2-й этаж, "	Россия, Ленинградская область, Приозерский район	0101000020E6100000329067976F3D3E409A0AF148BC404E40
52238	3	29	97	6676	\N	\N	60.714770000000001	Приозерский район, п.Суходолье, МОУ Громовская СОШ (спортивный зал),		0101000020E610000046088F368E083E40BA1457957D5B4E40
52244	3	29	97	9709	67237	\N	60.562327000000003	Приозерский район, п.Сосново, ул.Связи, д.13а, МОУ Сосновская СОШ (холл)		0101000020E6100000CEE33098BF3A3E403354C554FA474E40
52246	3	29	97	9709	67244	\N	60.562327000000003	Приозерский район, п.Сосново, ул. Мичуринская,2 Сосновский Дом творчества, зал		0101000020E6100000CEE33098BF3A3E403354C554FA474E40
52245	3	29	97	9709	67179	\N	60.557494829697603	Приозерский район, п.Сосново, ул.Механизаторов, д.11  обменный пункт ЗАО «Сосновоагропромтехника»	Россия, Ленинградская область, Приозерский район, посёлок Сосново	0101000020E61000000491459A78373E407E5704FF5B474E40
52243	3	29	97	9639	67039	\N	60.553415000000001	"Приозерский район, д.Снегиревка, ул.Центральная, д.19, КСК ""Снегиревский"", холл"		0101000020E6100000E606431D564C3E40D40E7F4DD6464E40
52250	3	29	97	10020	67308	\N	61.057082543535799	Приозерский район, п.Севастьяново, ул.Новая, д.4, Дом культуры,зал ,	Россия, Ленинградская область, Приозерский район, посёлок Севастьяново	0101000020E610000001F6D1A92BCB3D402B14E97E4E874E40
52237	3	29	97	9374	67157	\N	60.721559999999997	Приозерский район, п.Саперное, ул.Школьная, д.28, МОУ Шумиловская СОШ, кабинет литературы		0101000020E6100000AEF02E17F1F53D40060DFD135C5C4E40
13047	7	66	939	26342	62116	\N	56.024118999999999	село Пошнары, Ленина, 25		0101000020E610000068B27F9E063647402A1BD65416034C40
52240	3	29	97	59023	\N	\N	60.575153414766802	Приозерский район, д.Раздолье, Дом культуры (холл 2-го этажа)	Россия, Ленинградская область, Приозерский район, деревня Раздолье	0101000020E6100000F2608BDD3E273E4020990E9D9E494E40
52222	3	29	97	125	67558	\N	61.040348999999999	"Приозерский район, г.Приозерск, ул.Северопарковая, д.5 МОУ ""средняя общеобразовательная школа №1,холл"		0101000020E61000004A29E8F692223E4091B6F1272A854E40
52219	3	29	97	125	67234	\N	61.029656000000003	Приозерский район, г.Приозерск, Леншоссе,33, контора Приозерского потребительского общества,		0101000020E6100000CA1AF5108D223E40AA108FC4CB834E40
52221	3	29	97	125	67414	\N	61.043207000000002	"Приозерский район, г.Приозерск, ул.Ленина, д.45, МУК Культурный центр ""Карнавал"" холл"		0101000020E6100000BFD364C6DB263E40A9FA95CE87854E40
52225	3	29	97	125	67536	\N	61.037079566745497	Приозерский район, г.Приозерск, ул.Калинина, д.27, МОУ СОШ №4 актовый зал	Россия, Ленинградская область, Приозерский район, Приозерск, улица Чапаева	0101000020E610000001A3CB9BC3213E40F8AA9509BF844E40
52223	3	29	97	125	67536	\N	61.03848	"Приозерский район, г.Приозерск, ул.Калинина, д.20, МУК ""Приозерская межпоселенческая районнная библиотека"" холл."		0101000020E6100000793D98141F233E4069C6A2E9EC844E40
52229	3	29	97	6409	22371	\N	60.969079999999998	Приозерский район, п.Починок, Леншоссе, д.15, Дом культуры (фойе)		0101000020E6100000878C47A984333E40959A3DD00A7C4E40
52232	3	29	97	9167	\N	\N	60.831808220191498	Приозерский район, п.Плодовое, Дом культуры, зал 2-й этаж	Россия, Ленинградская область, Приозерский район, посёлок Плодовое	0101000020E6100000635E471CB2313E408D463EAF786A4E40
52239	3	29	97	6724	67268	\N	60.635554999999997	Приозерский район, п.Петровское, ул.Шоссейная, д.12, Дом культуры (зал)		0101000020E61000005BB4006DAB253E4096E7C1DD59514E40
52231	3	29	97	9135	67146	\N	60.960233000000002	Приозерский район, п.Моторное, Приладожское шоссе, д.5а, Дом культуры		0101000020E6100000A4198BA6B34B3E401EC539EAE87A4E40
52248	3	29	97	9936	67271	\N	60.568300533943898	Приозерский район, п.Мичуринское, ул.Первомайская, МОУ Мичуринская СОШ(1-й этаж, рекреация)	Россия, Ленинградская область, Приозерский район, посёлок Мичуринское	0101000020E6100000D2E5CDE15AD93D405DA45016BE484E40
52233	3	29	97	6525	66265	\N	60.917301999999999	Приозерский район, п.Мельниково. Ул. Калинина,3, Дом Культуры, фойе.		0101000020E6100000AAD5575705C63D401747E5266A754E40
52228	3	29	97	6462	67229	\N	61.001260000000002	Приозерский район, п.Ларионово, ул.Ленинградская, д.16, Дом культуры		0101000020E61000007A185A9D9C313E408065A54929804E40
52253	3	29	97	10082	67296	\N	61.119627999999999	"Приозерский район, п.Кузнечное, ул.Юбилейная, д.7а, Дом культуры ""Юбилейный"", малый зал."		0101000020E610000077853E58C6DE3D40CBD765F84F8F4E40
52251	3	29	97	10082	65112	\N	61.119627999999999	Приозерский район, п.Кузнечное, ул.Центральная, д.4, МОУ Кузнеченская начальная школа-сад №12(зал),		0101000020E610000077853E58C6DE3D40CBD765F84F8F4E40
52252	3	29	97	59035	67332	\N	61.1199601502977	"Приозерский район, п.Кузнечное, ул.Юбилейная, д.7а, Дом культуры ""Юбилейный"", танцевальный зал."		0101000020E6100000DB34B6D782DE3D40016A6AD95A8F4E40
52242	3	29	97	59019	67282	\N	60.588437999999996	Приозерский район, д.Кривко, ул.Фестивальная, д.1, Дом культуры (холл)		0101000020E6100000056D72F8A43F3E40A0DCB6EF514B4E40
52249	3	29	97	9963	67228	\N	60.58211	Приозерский район, д.Красноозерное, ул.Школьная. Д.9, МОУ Красноозерненская ООШ-детский сад (рекреация, 2-ой этаж),		0101000020E61000000C04013274A83D4058569A94824A4E40
52230	3	29	97	6369	66972	\N	60.907021999999998	Приозерский район, п.Коммунары, ул.Школьная, МОУ Коммунарская СОШ,холл 1-го этажа,		0101000020E61000008B51D7DAFB103E405260014C19744E40
52241	3	29	97	1005	66426	\N	60.574826000000002	Приозерский район, п.Запорожское, ул.Советская, д.14, Дом культуры( фойе)		0101000020E6100000E65B1FD61B853E40FC71FBE593494E40
52235	3	29	97	58916	\N	\N	60.696190999999999	Приозерский район, п.Громово, Дом культуры (зал)		0101000020E61000004F0306499F2E3E40806264C91C594E40
52234	3	29	97	6595	\N	\N	60.693780616064899	Приозерский район, п.Ст.Громово, Центр досуга, зал.	Россия, Ленинградская область, Приозерский район, посёлок Громово	0101000020E610000066D828EB372F3E4008CBD8D0CD584E40
52200	3	29	438	7607	67205	\N	60.917600493761398	Подпорожский район, п. Никольский,ул.Новая д.6	Россия, Ленинградская область, Подпорожский район, городской посёлок Никольский	0101000020E6100000293E3E213B094140A167B3EA73754E40
52216	3	29	438	8434	24357	\N	60.495623999999999	Подпорожский район, д. Ярославичи,ул. Школьнаяд.8		0101000020E6100000696FF085C94041406D8E739B703F4E40
52197	3	29	438	2830	67226	\N	60.878030000000003	Подпорожский район,  с. Шеменичи,ул.Деловая д.3, библиотека		0101000020E610000009A9DBD95736414015747B4963704E40
52196	3	29	438	2738	66984	\N	61.100033000000003	Подпорожский район, п.Токари  ул.Исакова д.20		0101000020E61000006DAE9AE788324140A9C29FE1CD8C4E40
52203	3	29	438	7782	67222	\N	60.930415000000004	Подпорожский район, д. Радионово, ул.Георгиевская д.31		0101000020E6100000F33977BB5E8041409B5AB6D617774E40
52194	3	29	438	2412	668	\N	60.920048000000001	"Подпорожский район, г. Подпорожье,  пр.Ленина, д 53""А"""		0101000020E61000000F9C33A2B411414007600322C4754E40
52189	3	29	438	2412	668	\N	60.913618999999997	Подпорожский район, г. Подпорожье,  пр. Ленина, д. 26	Россия, Ленинградская область, Подпорожский район, Подпорожье, проспект Ленина, 26	0101000020E6100000B8C9A8328C1341408A00A777F1744E40
52188	3	29	438	2412	668	\N	60.913269	Подпорожский район, г. Подпорожье,  пр. Ленина д.2	Россия, Ленинградская область, Подпорожский район, Подпорожье, проспект Ленина, 2	0101000020E61000001EA67D737F154140AEB9A3FFE5744E40
52187	3	29	438	2412	67522	\N	60.908881999999998	Подпорожский район, г. Подпорожье,  ул. Строителей д.2 помещение школы №8		0101000020E61000009DBAF2599E15414027F6D03E56744E40
52192	3	29	438	2412	67504	\N	60.910505000000001	"Подпорожский район, г. Подпорожье,  ул. Свирская д.82""А"""		0101000020E610000027BF45274B13414018EC866D8B744E40
52184	3	29	438	2412	67504	\N	60.908881999999998	Подпорожский район, г. Подпорожье,  ул. Свирская,д. 21, помещение художественной школы		0101000020E61000005F79909E2217414027F6D03E56744E40
52183	3	29	438	2412	67295	\N	60.9159964300664	"Подпорожский район, г. Подпорожье, Промывные, д.7 помещение управления ЗАО""Погранское объединение карьеров"""	Россия, Ленинградская область, Подпорожский район, Подпорожье	0101000020E6100000969526A5A013414027A25F5B3F754E40
52185	3	29	438	2412	67499	\N	60.906405999999997	Подпорожский район, г. Подпорожье,  ул. Гнаровской, д. 9 помещение   школы №1,		0101000020E6100000053411363C174140F7729F1C05744E40
52199	3	29	438	58959	67096	\N	60.915407999999999	Подпорожский район, п. Никольский,ул.Лисициной д.18.		0101000020E6100000DBA2CC0699084140963FDF162C754E40
52212	3	29	438	8237	67236	\N	60.459285000000001	Подпорожский район,  д. Лукинская  ул. Покровскя д.17		0101000020E6100000BCCADAA6786A41408D45D3D9C93A4E40
52202	3	29	438	7734	66361	\N	60.973292999999998	Подпорожский район, д. Курпово, ул.Клубная д.8		0101000020E61000006170CD1DFD0541407E3672DD947C4E40
52214	3	29	438	8331	24376	\N	60.400539000000002	Подпорожский район,  д. Курба, ул. Школьная д.8 Детский сад		0101000020E61000000856D5CBEF764140E3E2A8DC44334E40
52217	3	29	438	8477	9795	\N	60.546749241673702	Подпорожский район, д. Кузра,ул. Центральная д.13	Россия, Ленинградская область, Подпорожский район, посёлок Кузра	0101000020E6100000CD3B4ED1914C4140730F09DFFB454E40
52208	3	29	438	59001	67233	\N	61.051735000000001	Подпорожский район, д. Красный Бор, ул.Школьная д.12а		0101000020E610000000E31934F4B541407F87A2409F864E40
52204	3	29	438	7829	66976	\N	60.942954	Подпорожский район, д. Кипрушино, ул.Школьная д.3		0101000020E61000008B6F287CB6B64140F2D077B7B2784E40
52213	3	29	438	58996	67224	\N	60.558784000000003	Подпорожский район,  д. Кармановская ул. Немжинская д.25		0101000020E6100000F1F3DF83D76E414098C3EE3B86474E40
52215	3	29	438	8400	67238	\N	60.396267441486998	Подпорожский район, д. Казыченская,ул. Раздольная д.19	Россия, Ленинградская область, Подпорожский район, деревня Казыченская	0101000020E6100000BBB6B75B92874140F5BD86E0B8324E40
52205	3	29	438	7873	66406	\N	61.151907999999999	Подпорожский район, д. Гимрека, ул.Петрозаводский тракт д.35		0101000020E6100000AF264F594DCF41401900AAB871934E40
52206	3	29	438	58948	67081	\N	61.020451000000001	Подпорожский район, п. Вознесенье ул.Пионерская д.49		0101000020E6100000AC1BEF8E8CBB4140D3156C239E824E40
52207	3	29	438	58948	67082	\N	61.020451000000001	Подпорожский район, п. Вознесенье ул. Лесозаводская д.8		0101000020E6100000AC1BEF8E8CBB4140D3156C239E824E40
52209	3	29	438	8071	66061	\N	60.629443000000002	Подпорожский район,  с. Винницы ул. Советская д.66		0101000020E610000080828B15356241401BD9959691504E40
52210	3	29	438	8071	66407	\N	60.629443000000002	Подпорожский район,  с. Винницы ул. Лесная д.9 Районная больница		0101000020E610000080828B15356241401BD9959691504E40
52211	3	29	438	8071	66084	\N	60.629443000000002	Подпорожский район,  с. Винницы ул. Гражданская д.39		0101000020E610000080828B15356241401BD9959691504E40
52201	3	29	438	7691	67204	\N	60.961530000000003	Подпорожский район, п. Важины,ул.Школьная д.13		0101000020E610000026529ACDE3024140BB0F406A137B4E40
52169	3	29	261	6168	67122	\N	58.854812000000003	Лужский район, посёлок  Толмачёво, ул.Толмачёва 10, помешение МОУ СОШ		0101000020E610000053094FE8F5E33D403B1DC87A6A6D4D40
52170	3	29	261	6168	66978	\N	58.854812000000003	"Лужский район,  посёлок Толмачёво, ул.Прохорова,43 помещение  ООО ""Областная управляющая компания"""		0101000020E610000053094FE8F5E33D403B1DC87A6A6D4D40
52175	3	29	261	6470	67260	\N	59.099764962762102	Лужский район, дер.Низовская ул.Дзержинского помещение библиотеки	Россия, Ленинградская область, Лужский район, посёлок при ж/д станции Низовская	0101000020E61000000685419946FB3D4089247A19C58C4D40
52124	3	29	261	3753	\N	\N	58.8193206921474	"Лужский район, г. Луга  поселок-пансионат ""Зеленый Бор"" корп.2"	Россия, Ленинградская область, Лужский район, детский лагерь Зелёный Бор	0101000020E6100000ED4ACB48BDEF3D4088F6B182DF684D40
52167	3	29	261	6034	67177	\N	58.894120000000001	Лужский район, деревня  Ям-Тесово, ул.Центральная,6-а помещение ДК		0101000020E61000004B5645B8C9943E408A592F8672724D40
52165	3	29	261	1889	67242	\N	58.799503999999999	"Лужский район, посёлок  Тесово-4, ул.20-го съезда КПСС,7а помещение администрации  Тёсовского сельского поселения"		0101000020E61000009207228B34913E40B682A62556664D40
52158	3	29	261	5567	\N	\N	58.740577999999999	Лужский район, дер.Турово,1 помещение фельдшерско - акушерского пункта		0101000020E61000005E11FC6F25EF3D408C118942CB5E4D40
52156	3	29	261	1562	67266	\N	58.566673000000002	Лужский район,  д.Торошковичи, ул.Торговая, 3 помещение Дома культуры.		0101000020E61000000DE02D90A01C3E405B43A9BD88484D40
52182	3	29	261	59026	67297	\N	58.855528999999997	"Лужский район, посёлок  Торковичи,  ул.Стахановская,1 помещение администрации  Торковичского  сельского поселения"		0101000020E6100000DD989EB0C4573E40C9E369F9816D4D40
52163	3	29	261	1814	24361	\N	58.601658999999998	Лужский район,  посёлок  Скреблово, ул.Центральная,31 помещение администрации  Скребловского сельского поселения		0101000020E6100000726C3D4338E23D400A2C8029034D4D40
52181	3	29	261	6773	67003	\N	58.579014999999998	"Лужский район, посёлок  Серебрянский,  ул.Совхозная,18-а помещение администрации Серебрянского сельского поселения"		0101000020E61000001B2E724F579B3D405C72DC291D4A4D40
52180	3	29	261	6730	\N	\N	58.562354999999997	Лужский район,  деревня    Ретюнь, 12  помещение администрации  Ретюнского   сельского     поселения	Россия, Ленинградская область, Лужский район, деревня Ретюнь	0101000020E61000002E910BCEE0CB3D40FCDEA63FFB474D40
52020	3	29	1304	14403	66512	\N	59.613061000000002	Киришский район, п.Тихорицы, ул. Новая, д.2,  здание библиотеки		0101000020E6100000069FE6E4450A4040FEB968C878CE4D40
52179	3	29	261	2246	\N	\N	58.960251326762602	Лужский район, деревня  Рель,6 кв.11 помещение администрации Осьминского сельского поселения	Россия, Ленинградская область, Лужский район, деревня Ставотино, Н171	0101000020E61000007521567F84ED3C40C4793881E97A4D40
52159	3	29	261	1674	67172	\N	58.662277000000003	Ленинградская область, Лужский район, дер.Раковно, ул.Нагорная д.9 Клуб		0101000020E61000003563D17476063E404EF2237EC5544D40
52168	3	29	261	6096	66348	\N	58.924118	Лужский район,  посёлок   Приозерный, ул.Центральная,4-а помещение администрации  Ям-Тёсовского сельского поселения		0101000020E6100000BE4A3E7617A83E408DD2A57F49764D40
52172	3	29	261	6308	\N	\N	58.821618000000001	Лужский район,  посёлок  Плоское, помещение бывшей  начальной школы	Россия, Ленинградская область, Лужский район, посёлок Плоское	0101000020E6100000C6C37B0E2CF73D4008E753C72A694D40
52177	3	29	261	6586	66153	\N	58.981229999999996	Лужский район, деревня  Пехенец, ул.Молодежная,1-а  помещение Дома  культуры		0101000020E6100000ED7DAA0A0D0C3E4052EDD3F1987D4D40
52178	3	29	261	2180	66553	\N	59.012425999999998	"Лужский район,  посёлок  Осьмино,  ул.Ленина,51-а помещение администрации Осьминского сельского поселения"		0101000020E610000099BC0166BE173D405FCFD72C97814D40
52162	3	29	261	1789	67265	\N	58.817960999999997	Лужский район, посёлок  Оредеж, ул.Комсомола,7 помещение     администрации      Оредежского сельского поселения.		0101000020E61000008B1BB7989F573E40A43330F2B2684D40
52174	3	29	261	6416	67290	\N	59.010982477356897	Лужский район, посёлок  Мшинская ул.Пролетарская д.1 помещение МОУ СОШ	Россия, Ленинградская область, Лужский район	0101000020E61000003F00A94D9CF03D401E6CB1DB67814D40
52161	3	29	261	5725	\N	\N	58.763201000000002	Лужский район, п.Мерево помещение фельдшерско - акушерского пункта		0101000020E6100000373465A71F103E4023A30392B0614D40
52164	3	29	261	5877	\N	\N	58.629722999999998	Лужский район, посёлок  Межозерный, помещение фельшерско-акушерского пункта	Россия, Ленинградская область, Лужский район, посёлок Межозёрный	0101000020E6100000C11A67D311D43D40FE4465C39A504D40
52152	3	29	261	58994	\N	\N	58.746008000000003	"Лужский район, г.Луга-3 здание административного военного лесхоза ""Мичуринский"""		0101000020E6100000B0C91AF510D13D40F646AD307D5F4D40
52151	3	29	261	1097	\N	\N	58.746008000000003	Лужский район, г.Луга-3 ,д.3/132 МДОУ детсад №13		0101000020E6100000B0C91AF510D13D40F646AD307D5F4D40
52150	3	29	261	1097	\N	\N	58.746010710456098	"Лужский район, г.Луга-3   Дом офицеров"	Россия, Ленинградская область, Лужский район, Луга, Луга 3	0101000020E6100000FD4FFEEE1DD13D4067BAD7497D5F4D40
52142	3	29	261	1097	802	\N	58.724173214235897	Лужский район,  г. Луга, улица Красной Артиллерии, дом № 38, помещение  МДУ  детсад №9	Россия, Ленинградская область, Лужский район, Луга, улица Красной Артиллерии	0101000020E610000080F44D9A06D93D40B7D26BB3B15C4D40
52132	3	29	261	1097	1117	\N	58.745438999999998	"Лужский район, г. Луга, проспект Урицкого,16 МОУ СОШ №4"		0101000020E61000001D93C5FD47DA3D40DB148F8B6A5F4D40
52133	3	29	261	1097	284	\N	58.7442733909296	"Лужский район, г. Луга, проспект Кирова, дом № 31 клуб ""Радуга"""	Россия, Ленинградская область, Лужский район, Луга, проспект Кирова, 31	0101000020E6100000AE9E93DE37DA3D40DD257156445F4D40
52131	3	29	261	1097	284	\N	58.748351999999997	"Лужский район, г. Луга пр.Кирова,2  ЗАО Лужский трикотаж"		0101000020E6100000DBE044F46BDB3D40B6F292FFC95F4D40
52144	3	29	261	\N	831	\N	58.723161547538801	Лужский район, г. Луга, проспект Володарского, дом № 44, МОУ СОШ №6	Россия, Ленинградская область, Лужский район, Е18, М20	0101000020E61000006B4606B98BD83D40E0DA8992905C4D40
52141	3	29	261	1097	831	\N	58.728349999999999	Лужский район, г. Луга, проспект Володарского, дом № 13-а помещение МУК  Районная библиотека		0101000020E6100000E6CAA0DAE0D83D405305A3923A5D4D40
52128	3	29	261	1097	67512	\N	58.735478000000001	Лужский район, г. Луга, ул.Смоленская,110 Лужское лесничество- филиал ЛОГБУ		0101000020E61000002FA86F99D3D53D40B876A224245E4D40
52136	3	29	261	1097	67565	\N	58.739718000000003	Лужский район, г. Луга, ул.Смоленская,85 МДОУ детсад №17		0101000020E610000034D93F4F03D63D409B215514AF5E4D40
52127	3	29	261	1097	67620	\N	58.741455999999999	Лужский район, г. Луга, ул.Свободы,23 МОУ СОШ №5		0101000020E61000009546CCECF3D43D4024B6BB07E85E4D40
52126	3	29	261	1097	299	\N	58.725290000000001	Лужский район, г. Луга, ул.Нижегороская, 126, помещение ГП Лужское ДРСУ	Россия, Ленинградская область, Лужский район, Луга, Нижегородская улица, 126	0101000020E61000007AE2395B40D43D40D40E7F4DD65C4D40
52125	3	29	261	1097	67439	\N	58.706611000000002	"Лужский район, г. Луга ул. Мелиораторов,3 Здание ОАО ""Спецстрой"""		0101000020E61000004C37894160D53D4037FFAF3A725A4D40
52140	3	29	261	1097	67355	\N	58.725674224566603	Лужский район,  г. Луга, улица Красной Артиллерии, дом № 24, помещение  МДУ  детсад №5	Россия, Ленинградская область, Лужский район, Луга, улица Красной Артиллерии	0101000020E61000002E01F8A754D93D405CC7B8E2E25C4D40
52129	3	29	261	1097	67610	\N	58.745083999999999	Лужский район, г. Луга, ул.Красноармейская,32 Клуб ОАО Лужский абразивный завод		0101000020E61000007061DD7877D83D40ED629AE95E5F4D40
52148	3	29	261	1097	760	\N	58.732959999999999	Лужский район, г. Луга, пр.Комсомольский,21/74 МДОУ детсад №1		0101000020E610000040A374E95FDE3D4059A31EA2D15D4D40
52176	3	29	261	2139	\N	\N	59.167408999999999	Лужский район, посёлок Красный Маяк, помещение  МБДОУ «Красномаякския детский сад»	Россия, Ленинградская область, Лужский район, посёлок Красный Маяк	0101000020E61000007730629F00F23D402D077AA86D954D40
52160	3	29	261	58988	67185	\N	58.819419000000003	Лужский район, д.Каменка микрорайон Центральный, д 14 МОУ СОШ		0101000020E610000024D5777E511A3E404B5CC7B8E2684D40
52157	3	29	261	1586	67434	\N	58.727961999999998	Лужский район,  деревня Заклинье, ул.Новая,36  МОУ СОШ		0101000020E6100000DA740470B3E43D40895DDBDB2D5D4D40
52171	3	29	261	58898	\N	\N	58.840784630812799	Лужский район, дер Жильцы, помещение конторы ООО Стройтехнология	Россия, Ленинградская область, Лужский район, деревня Жельцы	0101000020E6100000838593347FEC3D40D2FBC6D79E6B4D40
52154	3	29	261	1464	24362	\N	58.671258000000002	Лужский район, п.Дзержинского,ул.Центральная,4 администрация Дзержинскогосельского поселения		0101000020E6100000AC545051F5E33D40D5963AC8EB554D40
52173	3	29	261	2061	67169	\N	58.732937	Лужский район, посёлок Волошово,ул.Школьная,22 МОУ СОШ		0101000020E610000087C09140834D3D40A1832EE1D05D4D40
52153	3	29	261	5303	\N	\N	58.522419999999997	Лужский район,  п.Володарское,помещение МОУ СОШ	Россия, Ленинградская область, Лужский район, посёлок Володарское	0101000020E61000008C4AEA0434E13D405E6397A8DE424D40
51553	3	29	261	58919	\N	\N	58.6543851728172	д.Бор, д.44	Россия, Ленинградская область, Лужский район, деревня Бор	0101000020E610000051853FC39BF53D4019FF3EE3C2534D40
52121	3	29	356	3622	\N	\N	59.729368000000001	Ломоносовский  район, дер. Яльгелево, школа		0101000020E6100000725303CDE7F03D40DD5F3DEE5BDD4D40
52099	3	29	356	2377	66007	\N	59.976297000000002	Ломоносовский  район, дер. Шепелево, ул. Ветеранов, д.16, Дом культуры		0101000020E6100000F5143944DC283D406A17D34CF7FC4D40
52122	3	29	356	3656	\N	\N	59.699280999999999	Ломоносовский  район, село Русско-Высоцкое, школа		0101000020E61000007D957CEC2EF03D406ADB300A82D94D40
52120	3	29	356	3552	\N	\N	59.729672000000001	Ломоносовский  район, пос. Ропша, Стрельнинское шоссе, д.9А, администрация поселения	Россия, Ленинградская область, Ломоносовский район, посёлок Ропша	0101000020E6100000AE6708C72CDF3D40496760E465DD4D40
52106	3	29	356	2736	\N	\N	59.791155000000003	Ломоносовский  район, дер. Разбегаево, Дом культуры		0101000020E61000003C33C170AEED3D409088299144E54D40
52118	3	29	356	59039	67343	\N	59.917375	Ломоносовский  район, дер. Пеники, ул. Новая, школа		0101000020E61000009AEAC9FCA3A33D408195438B6CF54D40
52117	3	29	356	3400	\N	\N	59.752077	Ломоносовский  район, дер. Оржицы, Дом культуры,		0101000020E6100000A5DAA7E331B73D407289230F44E04D40
52101	3	29	356	2482	\N	\N	59.809699000000002	"Ломоносовский  район, п. Новоселье, здание бывшего детского сада, "	Россия, Ленинградская область, Ломоносовский район, посёлок Новоселье	0101000020E610000033C005D9B2103E404D4D8237A4E74D40
52115	3	29	356	59013	67267	\N	59.834871999999997	Ломоносовский  район, дер. Низино, ул. Центральная, д.48, школа		0101000020E6100000ED0BE8853BDF3D404D2CF015DDEA4D40
52116	3	29	356	3294	\N	\N	59.834871999999997	Ломоносовский  район, дер. Низино, здание бывшего кафе школы техников.	Россия, Ленинградская область, Ломоносовский район, деревня Низино	0101000020E6100000ED0BE8853BDF3D404D2CF015DDEA4D40
52090	3	29	356	1813	\N	\N	59.719396000000003	Ломоносовский  район, дер. Малое Карлино, Дом культуры,		0101000020E6100000BF49D3A068423E40C66F0A2B15DC4D40
52113	3	29	356	58950	\N	\N	59.732098999999998	"Ломоносовский  район, дер. Лопухинка, Дом культуры,"		0101000020E61000008658FD1186653D409737876BB5DD4D40
52097	3	29	356	59044	67349	\N	59.961435000000002	"Ломоносовский  район, г.п. Лебяжье,  ул. Степаняна, д.16, школа, "		0101000020E61000007A8EC87729693D40691D554D10FB4D40
52112	3	29	356	58921	\N	\N	59.703474999999997	"Ломоносовский  район, дер. Лаголово, Дом культуры,"		0101000020E6100000E63FA4DFBE063E40DC4603780BDA4D40
52111	3	29	356	3056	\N	\N	59.707419999999999	Ломоносовский  район, село Копорье, Дом культуры,		0101000020E6100000AB5AD2510E0A3D40A64412BD8CDA4D40
52109	3	29	356	2942	66964	\N	59.675013999999997	Ломоносовский  район, дер. Кипень, Ропшинское шоссе, д. 23, школа,		0101000020E61000005D514A0856D93D40CB2BD7DB66D64D40
52110	3	29	356	2980	\N	\N	59.662672000000001	Ломоносовский  район, дер. Келози, школа		0101000020E610000052B648DA8DD23D40CAFCA36FD2D44D40
52107	3	29	356	2833	\N	\N	59.743290999999999	"Ломоносовский  район, дер. Гостилицы, Дом культуры, "		0101000020E61000000E4C6E14599B3D40A034D42824DF4D40
52105	3	29	356	32515	\N	\N	59.816231519593003	Ломоносовский  район, дер.Горбунки Дом Культуры ,	Россия, Ленинградская область, Ломоносовский район, деревня Горбунки	0101000020E6100000E5D2F88557FA3D406EF9484A7AE84D40
52104	3	29	356	32515	\N	\N	59.817917669416403	Ломоносовский  район, дер. Горбунки Дом культуры ,	Россия, Ленинградская область, Ломоносовский район, деревня Горбунки	0101000020E6100000A3B08BA207FA3D40A5677A89B1E84D40
52098	3	29	356	2286	\N	\N	59.967930000000003	Ломоносовский  район, дер. Гора-Валдай, д.27, помещение медпункта,		0101000020E6100000B2135E8253333D409D685721E5FB4D40
52114	3	29	356	3218	66271	\N	59.743353999999997	Ломоносовский  район, дер. Глобицы, ул. Школьная, д.6, школа,		0101000020E6100000A73E90BC73383D40E6AC4F3926DF4D40
52000	3	29	356	2869	\N	\N	59.697878000000003	"Ломоносовский  район, дер. Виллози, д. 1а, Дом культуры, "		0101000020E610000049D6E1E82A1D3E40884CF91054D94D40
52096	3	29	356	2178	67348	\N	59.943962999999997	Ломоносовский  район, г.п. Большая Ижора, ул. Астанина, д.2, школа,		0101000020E6100000F2D077B7B2903D4028D192C7D3F84D40
52100	3	29	356	2410	67359	\N	59.775769003774897	"Ломоносовский  район, пос. Аннино, ул. Садовая, д. 2,  школа, "	Россия, Ленинградская область, Ломоносовский район, посёлок Аннино, Садовая улица	0101000020E6100000D978B0C56E0B3E4014200A664CE34D40
52092	3	29	225	1933	\N	\N	60.473117999999999	"Лодейнопольский р-н, д.Яровщина,д.1 помещение МКДОУ ""Яровщинская начальная школа-детский сад"""		0101000020E610000094F59B89E9C44040109370218F3C4E40
52082	3	29	225	1354	67257	\N	60.745612000000001	Лодейнопольский р-н, п. Янега, ул. Пионерская, д. 4,  административного здания Янегского сельского поселения		0101000020E61000004B00FE2955DA4040A9C0C936705F4E40
52091	3	29	225	1888	67203	\N	60.391097000000002	Лодейнопольский р-н, п.Шархиничи, ул. Прудовая, д. 2 а, помещение сельского клуба		0101000020E61000002E71E481C8E0404028486C770F324E40
52011	3	29	1304	30155	66000	\N	59.246473000000002	Киришский район, д.Среднее Село, ул. Центральная, д.3, здание библиотеки		0101000020E6100000F38E5374245740406B2C616D8C9F4D40
52073	3	29	225	8074	\N	\N	60.659584067034899	Лодейнопольский р-н, д. Шамокша, д. 24,  Дом культуры, зал 1-этаж	Россия, Ленинградская область, Лодейнопольский район, деревня Шамокша	0101000020E6100000FDDAFAE93FAD4040817B9E3F6D544E40
52081	3	29	225	1329	24344	\N	60.754840000000002	Лодейнопольский р-н, д. Харевщина, ул. Молодежная, д. 5, помещение сельского клуба		0101000020E610000010AFEB17ECD6404038DBDC989E604E40
52083	3	29	225	1444	67198	\N	60.324081	Лодейнопольский р-н, д. Тервеничи, ул. Центральная, д. 3, сельский Дом Культуры		0101000020E6100000BD715298F70C4140A320787C7B294E40
52079	3	29	225	1209	\N	\N	60.778435999999999	"Лодейнопольский р-н, д. Старая Слобода, д. 61, гостиница Старая Слобода"" холл"		0101000020E6100000BB6246787BA84040B80375CAA3634E40
52077	3	29	225	59060	67415	\N	60.800116000063802	"Лодейнопольский р-н, г.п. Свирьстрой, пр. Кирова, д. 2,МКУ ""Свирьстройский центр культуры и досуга"""	Россия, Ленинградская область, Лодейнопольский район, городской посёлок Свирьстрой	0101000020E6100000F5F75278D0DC4040D0807A336A664E40
52086	3	29	225	1597	\N	\N	60.216287000000001	Лодейнопольский р-н, п.Ребовичи, д.50  административное здание Алеховщинского сельского поселения		0101000020E61000001B65FD66622C414065C6DB4AAF1B4E40
52094	3	29	225	2064	\N	\N	60.458668000000003	"Лодейнопольский р-н, п.Рассвет, д.8 МКУ ""Оятский Культурно-спортивный центр"		0101000020E6100000BC218D0A9C94404062DC0DA2B53A4E40
52085	3	29	225	59009	\N	\N	60.230406664872298	Лодейнопольский р-н, д. Пирозеро, д.28 помещение сельской библиотеки		0101000020E6100000508BC1C3B4F940407EE200FA7D1D4E40
52087	3	29	225	58978	\N	\N	60.471525999999997	Лодейнопольский р-н, д.Надпорожье, д. 71 помещение административного здания Алеховщинского сельского поселения		0101000020E61000004C18CDCAF62341405A9BC6F65A3C4E40
52066	3	29	225	59074	67533	\N	60.732410014396102	"Лодейнопольский район, г. Лодейное Поле, ул.Титова, д. 48  МОУ ""Лодейнопольская средняя общеобразовательная школа № 68"""	Россия, Ленинградская область, Лодейное Поле, улица Титова, 48	0101000020E6100000A20DC00644C64040B6A1629CBF5D4E40
52093	3	29	225	2031	\N	\N	60.483555000000003	Лодейнопольский р-н, д.Имоченицы,д.11 помещение Дома культуры		0101000020E6100000A305685BCDC240409D685721E53D4E40
52095	3	29	225	2145	67213	\N	60.469920999999999	Лодейнопольский р-н, д.Доможирово,ул.Школьная д.67 СДК		0101000020E61000008524B37A878B4040105A0F5F263C4E40
52084	3	29	225	1473	\N	\N	60.367674000000001	Лодейнопольский р-н, д. Вонозеро, д.39  Сельский клуб		0101000020E61000000DFAD2DB9F35414075CB0EF10F2F4E40
51549	3	29	225	58451	\N	\N	60.3391917578343	д.Анисимово, д.12	Россия, Ленинградская область, Лодейнопольский район, деревня Анисимово	0101000020E6100000F9D85DA0A42C41404C88B9A46A2B4E40
52080	3	29	225	1256	\N	\N	60.833233999999997	Лодейнопольский р-н, д. Андреевщина,  административное здание Янегского сельского поселения		0101000020E6100000D6E253008CB5404027F56569A76A4E40
52089	3	29	225	1700	67208	\N	60.406666999999999	"Лодейнопольский р-н, с.Алеховщина, ул. Набережная, д. 23,  МКОУ ""Алеховщинская средняя общеобразовательная школа"""		0101000020E610000014799274CDEC404064AE0CAA0D344E40
52088	3	29	225	1700	67216	\N	60.406666999999999	Лодейнопольский р-н, с.Алеховщина, Лодейнопольское шоссе, д. 2, помещение Дома культуры		0101000020E610000014799274CDEC404064AE0CAA0D344E40
52060	3	29	69	58946	67077	\N	59.890303681308097	Кировский район, ст.Новый Быт, ул.Волховская, д.16 ФАП	Россия, Ленинградская область, Кировский район, посёлок при ж/д станции Новый Быт	0101000020E6100000CB4C69FD2DED3F40BEBF417BF5F14D40
52054	3	29	69	9443	\N	\N	59.846874999999997	Кировский район, п.Назия, ул.Парковая, д.4  МОУ СОШ	Россия, Ленинградская область, Кировский район, городской посёлок Назия	0101000020E610000050A73CBA119A3F406666666666EC4D40
52032	3	29	69	12357	62021	\N	59.74821	"Кировский район, п.Мга,ул.Спортивная, д.4 МУК  КДЦ"" Мга"""	Россия, Ленинградская область, Кировский район, городской посёлок Мга	0101000020E6100000E17D552E540E3F4024456458C5DF4D40
52034	3	29	69	12357	67276	\N	59.74821	"Кировский район, п.Мга, Советский пр. д.55, МОУ ""Мгинская СОШ"""		0101000020E6100000E17D552E540E3F4024456458C5DF4D40
51702	3	29	69	11450	67338	\N	59.984515040406997	Всеволожский район, п. им. Морозова пл.Культуры д.3 Дом культуры	Россия, Ленинградская область, Кировский район, посёлок имени Морозова	0101000020E610000078D0ECBAB7023F40F2B5679604FE4D40
51705	3	29	69	11450	67406	\N	59.984215916161503	Всеволожский район, п. им. Морозова ул. Хесина д.20 СОШ им. Морозова здание 2	Россия, Ленинградская область, Кировский район, посёлок имени Морозова	0101000020E610000053AF5B04C6023F40981936CAFAFD4D40
51704	3	29	69	11450	67406	\N	59.971415040840697	Всеволожский район, п. им. Морозова ул. Хесина д.20 СОШ им. Морозова здание 1	Россия, Ленинградская область, Кировский район, посёлок имени Морозова, улица Хесина	0101000020E6100000747973B8560B3F4003ECA35357FC4D40
52059	3	29	69	9510	67144	\N	59.873784999999998	Кировский район, с.Шум, ул.Советская.д.22, администрация		0101000020E6100000E90B21E7FDC73F40205ED72FD8EF4D40
52058	3	29	69	9510	67144	\N	59.873784999999998	"Кировский район, с.Шум, ул.Советская.д.3-а, МУК ""Сельский культурно-досуговый центр"""		0101000020E6100000E90B21E7FDC73F40205ED72FD8EF4D40
52044	3	29	69	12703	3563	\N	59.940334	"Кировский район, г.Шлиссельбург, Малоневский канал,д.2   МНУК Культурно-спортивный комплекс ""Невский"", "	Россия, Ленинградская область, Кировский район, Шлиссельбург, улица Малоневский Канал, 6	0101000020E61000000F971C774A0B3F408FA850DD5CF84D40
52047	3	29	69	12703	3591	\N	59.939959999999999	"Кировский район, г.Шлиссельбург, Красный пр.50, МОУ ДОД"" Шлиссельбурская музыкальная школа"""		0101000020E6100000988922A46E073F402AC6F99B50F84D40
52046	3	29	69	12703	67388	\N	59.942500816600202	"Кировский район, г.Шлиссельбург, ул.Затонная, д.1,  клуб"" Парус"""	Россия, Ленинградская область, Кировский район, Шлиссельбург, Затонная улица	0101000020E6100000A626C11BD2083F4041B96DDFA3F84D40
52045	3	29	69	12703	67466	\N	59.938293000000002	Кировский район, г.Шлиссельбург, ул. 18 Января, д.3а, СШ №1		0101000020E610000072F8A413090A3F406A882AFC19F84D40
52063	3	29	69	223	\N	\N	60.013838	Кировский район, с.Сухое, д.32 администрация МО Суховское сельское поселение		0101000020E610000050C763062ABB3F4095B88E71C5014E40
52035	3	29	69	12430	62013	\N	59.638629000000002	Кировский район, п.Старая Малукса, ул.Новоселов, д.1, помещение администрации МО Мгинское городское поселение		0101000020E6100000774CDD955D603F407BA35698BED14D40
52036	3	29	69	59005	\N	\N	59.702826000000002	Кировский район, дер.Сологубовка, д.95, ФАП		0101000020E6100000BBF083F3A91F3F40A663CE33F6D94D40
52049	3	29	69	12877	67600	\N	59.874042399983203	"Кировский район, мкр.Синявино-2, ул.Победы, д.5 МКУ КДЦ ""Синявино"""	Россия, Ленинградская область, Кировский район, деревня Синявино-2	0101000020E6100000DB519CA38E363F404CAAB69BE0EF4D40
52048	3	29	69	59041	67344	\N	59.9059808926201	Кировский район, п.Синявино,ул.Лесная,д.17, МОУ СОШ	Россия, Ленинградская область, Кировский район, городской посёлок Синявино, Лесная улица	0101000020E61000002E1D739EB1133F4010E6762FF7F34D40
52053	3	29	69	12960	22377	\N	59.868121000000002	Кировский район, с.Путилово,ул.Дорофеева,д.5  МБУ Сельский ДК,		0101000020E61000008ACC5CE0F2703F4044FCC3961EEF4D40
52052	3	29	69	12960	67180	\N	59.868121000000002	Кировский район, с.Путилово, ул.Братьев Пожарских, д.2  администрация МО Путиловское сельское поселение,		0101000020E61000008ACC5CE0F2703F4044FCC3961EEF4D40
52050	3	29	69	58947	67080	\N	59.877189999999999	Кировский район, п.Приладожский,д.24  ДК,		0101000020E61000007EC51A2E72533F406A300DC347F04D40
52030	3	29	69	58963	67102	\N	59.808771999999998	"Кировский район, п.Павлово,ул.Спортивная,д1  МУК ""ДК п. Павлово"", 2-й этаж"		0101000020E6100000838AAA5FE9E43E40D3F544D785E74D40
52023	3	29	69	14697	67513	\N	59.763122000000003	"Кировский район, г.Отрадное, ул.Комсомольская, д.5, МОУ ДОД ""Детская Школа искусств"""		0101000020E61000000457790261C73E40D76D50FBADE14D40
52026	3	29	69	14697	67410	\N	59.766624	"Кировский район, г.Отрадное, ул.Железнодоржная д.20 ,  МОУ ""Отрадненская СШ№2"""		0101000020E6100000083BC5AA41CC3E40132A38BC20E24D40
52028	3	29	69	14697	67335	\N	59.767360521022702	Ленинградская область, Кировский район, г.Отрадное, ул.Железнодорожная д.20-аДЮСШ	Россия, Ленинградская область, Кировский район, Отрадное, Железнодорожная улица	0101000020E6100000FB04508C2CCD3E40E99C9FE238E24D40
52025	3	29	69	14697	67335	\N	59.766624	"Кировский район, г.Отрадное, ул.Железнодоржная д.20 ,  МОУ ""Отрадненская СШ№2"", "		0101000020E6100000083BC5AA41CC3E40132A38BC20E24D40
52024	3	29	69	14697	67353	\N	59.764195999999998	"Кировский район, г.Отрадное, ул.Дружбы, д.1, МОУ ""Лицей г.Отрадное"""		0101000020E61000008BDF14562AC83E40F4DDAD2CD1E14D40
52027	3	29	69	14697	67401	\N	59.7733974958781	"Кировский район, г.Отрадное, ул.Гагарина д.1, МУК КЦ ""Фортуна"""	Россия, Ленинградская область, Кировский район, Отрадное, улица Гагарина	0101000020E6100000CEFC6A0E10CC3E408AE942ACFEE24D40
52051	3	29	69	28422	67307	\N	59.898159999999997	Кировский район, д.Назия,Староладожский канал, д.3 ФАП	Россия, Ленинградская область, Кировский район, деревня Назия	0101000020E610000027DBC01DA8573F40A54929E8F6F24D40
52055	3	29	69	28422	67138	\N	59.896866211895102	"Кировский район, п.Назия, Комсомольский пр.,д.15, МОК ""Культурно-Спортивный Комплекс ""Назия"" "	Россия, Ленинградская область, Кировский район, деревня Назия	0101000020E61000001424B6BB07583F407A724D81CCF24D40
52057	3	29	69	58956	67091	\N	59.846874999999997	"Кировский район, п.Назия, ул.Октябрская, д.14  ГОУ ЛО ""Назийский центр социальной адаптации"""		0101000020E610000050A73CBA119A3F406666666666EC4D40
52056	3	29	69	58956	67097	\N	59.846874999999997	"Кировский район, п.Назия, Волховское шоссе, д.1-а ОАО ""ПО ""Баррикада"", завод ЖБИ-2"		0101000020E610000050A73CBA119A3F406666666666EC4D40
52037	3	29	69	12456	\N	\N	59.826379000000003	"Кировский район, п.Молодцово д.9, МОУ ""Молодцовая основная общеобразовательная школа"" "		0101000020E610000028B682A6251A3F40F48C7DC9C6E94D40
52033	3	29	69	59014	67270	\N	59.74821	"Кировский район, п.Мга, Комсомольский пр.,д.40, НОУ СОШ № 37 ОАО "" РЖД"","		0101000020E6100000E17D552E540E3F4024456458C5DF4D40
52064	3	29	69	277	67165	\N	59.948067999999999	Кировский район,д. Лаврово, ул. Староладожский канал, д. 68, Сельский клуб		0101000020E61000003D27BD6F7C953F402B31CF4A5AF94D40
52061	3	29	69	84	67303	\N	59.880223485094099	Кировский район, п.Концы, ул.Плитная, д.12 ФАП	Россия, Ленинградская область, Кировский район, посёлок Концы	0101000020E6100000E84D452A8CBD3F40F017B325ABF04D40
52040	3	29	69	12502	3539	\N	59.875149	"Кировский район, г.Кировск, ул.Горького,д.16, МОУ ""Кировская гимназия им.Султана Баймагамбетова"" "		0101000020E6100000FFCEF6E80DFF3E404510E7E104F04D40
52041	3	29	69	12502	7204	\N	59.880535999999999	Кировский район, г.Кировск, ул.Новая,д.32, СШ №1	Россия, Ленинградская область, Кировский район, Кировск, Новая улица, 32к2	0101000020E610000088821953B0FE3E40AF795567B5F04D40
52039	3	29	69	12502	67363	\N	59.868361	"Кировский район, г.Кировск, ул.Набережная,д.27 МБУК ""Районный Дом Культуры"""		0101000020E6100000D1EAE40CC5F93E40990F087426EF4D40
52038	3	29	69	12502	67624	\N	59.874313999999998	"Кировский район, г.Кировск,ул.Кирова д.8, МОУ ""Кировская гимназия им.Султана Баймагамбетова"" прогимназия, "		0101000020E6100000289D4830D5FC3E40AC376A85E9EF4D40
52031	3	29	69	14845	\N	\N	59.757551999999997	Кировский район, д.Горы, ПМС-28		0101000020E6100000C8B3CBB73EF83E407B82C476F7E04D40
52062	3	29	69	128	\N	\N	59.907775999999998	Кировский район, д.Горка, д.1 ФАП		0101000020E61000006D0377A04EC93F40FE0B040132F44D40
52015	3	29	1304	14375	65106	\N	59.357787000000002	Киришский район, п. Пчевжа, ул. Клубная, д.6, здание Дома культуры		0101000020E610000040C1C58A1A2C40408CF7E3F6CBAD4D40
52016	3	29	1304	59025	67293	\N	59.564877000000003	Киришский район, д. Пчева, ул. Героев д.13 Дом культуры		0101000020E610000011FFB0A5470D40409DA1B8E34DC84D40
52018	3	29	1304	30484	\N	\N	59.524721	Киришский район, д. Мотохово, здание клуба	Россия, Ленинградская область, Киришский район, деревня Мотохово	0101000020E6100000A3CB9BC3B53040402043C70E2AC34D40
52013	3	29	1304	30228	67162	\N	59.315201395237601	Киришский район, д. Могилево, ул. Центральная, д.4, здание Могилевского сельского Дома культуры	Россия, Ленинградская область, Киришский район, деревня Могилёво	0101000020E6100000F44E05DCF33C40405055A18158A84D40
52021	3	29	1304	14502	24377	\N	59.3785152908181	Киришский район, д.Кусино, ул. Центральная, д.20, здание администрации муниципального образования Кусинское сельское поселение	Россия, Ленинградская область, Киришский район, деревня Кусино	0101000020E6100000253B3602F1CE3F40D105F52D73B04D40
52012	3	29	1304	30206	67278	\N	59.351759999999999	Киришский район, д. Кукуй, ул. Песочная, д.14, здание Кукуйскогосельского клуба		0101000020E610000011DF89592F4440403E05C07806AD4D40
52001	3	29	1304	13736	3991	\N	59.455027999999999	"Киришский район, г.Кириши, пр. Ленина д.1, МОУ ""Киришская средняя общеобразовательная школа №3"		0101000020E610000007616EF772014040D461855B3EBA4D40
51998	3	29	1304	13736	3991	\N	59.447823999999997	Киришский район, г.Кириши, пр. Ленина д.21, ЗАГС		0101000020E6100000317E1AF7E6014040942EFD4B52B94D40
52003	3	29	1304	13736	67212	\N	59.4461476884277	"Киришский район, г.Кириши, площадь 60-летия Октября,д.1 МОУ ""Киришский образовательный центр"""	Россия, Ленинградская область, Киришский район, Кириши	0101000020E61000007D3F355EBA0140408196AE601BB94D40
51993	3	29	1304	13736	67519	\N	59.442585999999999	"Киришский район, г.Кириши,ул.Энергетиков,д.29,МОУ""Киришский лицей"""		0101000020E610000009707A17EF0340406FD575A8A6B84D40
52007	3	29	1304	13736	67384	\N	59.450192214283902	"Киришский район, г.п. Будогощь, ул. Советская, д.37, здание  МП ""Комбинат коммунальныхпредприятий г.п.Будогощь"", 2-этаж"		0101000020E6100000973C9E961F024040DE7536E49FB94D40
51996	3	29	1304	13736	3889	\N	59.442275000000002	"Киришский район, г.Кириши, бульвар Молодежный,д.25 ГОУЛО ""Киришская специальная общеобразовательная (коррекционная) школа- интернат"""	Россия, Ленинградская область, Киришский район, Кириши, Молодёжный бульвар, 25	0101000020E6100000C6504EB4AB004040516B9A779CB84D40
52004	3	29	1304	13736	67614	\N	59.451729999999998	"Киришский район, г.Кириши, ул.Комсомольская, д.5, МОУ ""Киришская средняя общеобразовательная школа №2"""		0101000020E6100000A06F0B96EA024040A04FE449D2B94D40
51994	3	29	1304	13736	67605	\N	59.442082999999997	"Киришский район, г.Кириши,ул. Декабристов Бестужевых,д.15, МОУ ""Киришская средняя общеобразовательная школа №8"""		0101000020E6100000817A336ABE0240400C8FFD2C96B84D40
51999	3	29	1304	13736	3907	\N	59.453349000000003	"Киришский район, г.Кириши, ул.Волховская набережная д.10, МОУ ""Гимназия"""		0101000020E610000033E202D02801404050560C5707BA4D40
52010	3	29	1304	58991	67186	\N	59.216411000000001	Киришский район, д. Гремячево, ул.Центральная, д.37, Дом культуры		0101000020E610000053B3075A8133404051BF0B5BB39B4D40
52017	3	29	1304	58971	67135	\N	59.631267999999999	Киришский район, д. Городище, ул.Песочная д.1-Г, здание фельдшерско-акушерского пункта		0101000020E610000044DC9C4A061040407381CB63CDD04D40
52019	3	29	1304	21471	\N	\N	59.652025000000002	"Киришский район, п.Глажево, Дом Культуры ""Юбилейный"""		0101000020E6100000E2CCAFE6000F40405396218E75D34D40
52009	3	29	1304	59033	67329	\N	59.285007999999998	Киришский район, г.п. Будогощь, ул. Советская, д.79, здание администрации МО Будогощьское городское поселение	Россия, Ленинградская область, Киришский район, городской посёлок Будогощь	0101000020E6100000BBD39D279E394040978C63247BA44D40
52008	3	29	1304	59033	67496	\N	59.286413474774299	Киришский район, г.п. Будогощь, ул. Исполкомская, д.1, Дом культуры		0101000020E6100000902DCBD7653A40401B13622EA9A44D40
51986	3	29	1405	28993	\N	\N	59.535299000000002	Кингисеппский район, д.Фалилеево, дом 34 здание Фалилеевского досугого центра, Фалилеевская библиотека,		0101000020E6100000562AA8A8FAED3C406F4A79AD84C44D40
51981	3	29	1405	15830	67214	\N	59.659928802115303	Кингисеппский район, посёлок Усть-Луга, квартал Ленрыба, дом 7,	Россия, Ленинградская область, Кингисеппский район, посёлок Усть-Луга	0101000020E6100000D174763238463C404B57B08D78D44D40
51974	3	29	1405	15625	\N	\N	59.438802347928302	ДК дер. Ополье		0101000020E6100000A9C1340C1FD53C40AFB5F7A92AB84D40
51983	3	29	1405	15933	\N	\N	59.689636	Кингисеппский район, д.Нежново сельский клуб дом 13а	Россия, Н116 шоссе	0101000020E61000000DFCA886FDC63C40771211FE45D84D40
51989	3	29	1405	59049	67370	\N	59.432714752093403	Кингисеппский район, клуб дер. Кошкино, ул. Парковая дом 12	Россия, Ленинградская область, Кингисеппский район, деревня Кошкино	0101000020E610000028452BF702633C408CBE823463B74D40
51985	3	29	1405	15995	\N	\N	59.603287000000002	Кингисеппский район, дер.Котлы, помещение Котельской сельской библиотеки,	Россия, Ленинградская область, Кингисеппский район, деревня Котлы	0101000020E6100000AB984A3FE1C03C400D8D278238CD4D40
51984	3	29	1405	24397	\N	\N	59.581857608580101	Котельский сельский Дом культуры	Россия, Ленинградская область, Кингисеппский район, посёлок Котельский	0101000020E6100000DE770C8FFDC03C403E75AC527ACA4D40
51987	3	29	1405	16084	\N	\N	59.400818000000001	Кингисеппский район, п. Кингисеппский, дом 22 Дом культуры поселка Кингисепский,		0101000020E61000001DE736E15E913C40F6D214014EB34D40
94427	3	29	120	19037	\N	\N	59.557865999999997	Гатчинский район, д.Черново, д.31		0101000020E610000042E8A04B38FC3D4071C6302768C74D40
51988	3	29	1405	15461	\N	\N	59.3608390062927	"Административное здание ЗАО ""Кингисеппская ПМК-12"" (деревня Новопятницкое дом 18) "	Россия, Ленинградская область, Кингисеппский район, Кингисепп, улица Николая Микулина, 54	0101000020E6100000DB31755776993C40880FECF82FAE4D40
51972	3	29	1405	15461	\N	\N	59.389304544998303	"Кингисеппский район, микрорайон ""Касколовка""      (помещение МДОУ № 21 ""Детский сад""), "	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Касколовка	0101000020E61000006C96CB46E7A43C40AB9509BFD4B14D40
51971	3	29	1405	15461	5224	\N	59.390056000000001	Кингисеппский район, ул. Ковалевского 11 (Гимназия),	Россия, Ленинградская область, Кингисеппский район, Кингисепп, улица Ковалевского, 9	0101000020E61000006CD097DEFE9C3C40E6CDE15AEDB14D40
51958	3	29	1405	15461	6309	\N	59.373341000000003	Кингисеппский район, ул. Иванова 26 (СОШ №2),	Россия, Ленинградская область, Кингисеппский район, Кингисепп, улица Иванова, 26	0101000020E6100000BF9EAF592E9B3C40C3A04CA3C9AF4D40
51970	3	29	1405	15461	4339	\N	59.377301000000003	Кингисеппский район, пр. Карла Маркса 63 (Профессиональный политехнический лицей №18),	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 63	0101000020E610000059350873BB9F3C40C2DF2F664BB04D40
51965	3	29	1405	15461	4339	\N	59.375922000000003	Кингисеппский район, пр. Карла Маркса 59    (СОШ №4),	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 59	0101000020E6100000FF03AC55BB9E3C4068EC4B361EB04D40
51959	3	29	1405	15461	4339	\N	59.369522000000003	Кингисеппский район, пр. Карла Маркса 40 (ГДК),	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 40	0101000020E61000002A00C633689C3C408693347F4CAF4D40
51960	3	29	1405	15461	67171	\N	59.337769999999999	Кингисеппский район, п.Лесобиржа,специально-учебно-производственная школа-интернат, ул. Школьная д. 30		0101000020E6100000ABE97AA2EB9E3C40F3C81F0C3CAB4D40
51963	3	29	1405	15461	67437	\N	59.378832000000003	"Кингисеппский район, ул. Октябрьская, дом 1/10-б (МБУК ""Кингисеппский культурно-досуговый комплекс (Химик)"		0101000020E610000006483481229A3C40D25625917DB04D40
51962	3	29	1405	15461	67437	\N	59.378832000000003	"Кингисеппский район, ул. Октябрьская, дом 1/10-б (МБУК ""Кингисеппский культурно-досуговый комплекс (Химик),"		0101000020E610000006483481229A3C40D25625917DB04D40
51957	3	29	1405	15461	5307	\N	59.371136	Кингисеппский район, ул. Железнодорожная 8                            (Дом творчества юных)	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Железнодорожная улица, 8	0101000020E6100000938C9C853D993C40232F6B6281AF4D40
51969	3	29	1405	15461	4357	\N	59.385451000000003	Кингисеппский район, ул. Восточная 4 (СОШ №6),	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Восточная улица, 4	0101000020E61000000EF7915B939E3C40F29A577556B14D40
51964	3	29	1405	15461	5335	\N	59.379753999999998	Кингисеппский район, ул. Б. Советская 34      (СОШ №3),	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Большая Советская улица, 34	0101000020E61000000D8E9257E79C3C40394371C79BB04D40
51966	3	29	1405	15461	65036	\N	59.379753999999998	Ленинградская область, Кингисеппский район, город Кингисепп, ул. Большая Советская, д. 34		0101000020E61000000D8E9257E79C3C40394371C79BB04D40
51961	3	29	1405	15461	65036	\N	59.374684000000002	Кингисеппский район, ул. Б. Советская 7а(СОШ №1),		0101000020E6100000DC476E4DBA993C40D02A33A5F5AF4D40
51967	3	29	1405	15461	67543	\N	59.381802	Кингисеппский район, ул. Химиков 6 (СОШ №5),		0101000020E6100000A35A4414939B3C4011C64FE3DEB04D40
51956	3	29	1405	59070	67515	\N	59.370992999999999	Кингисеппский район, ул.Театральная 1 (Кингисеппский институт  управления бизнеса и права ЛГОУ им.А.С.Пушкина),		0101000020E610000069554B3ACA993C40C005D9B27CAF4D40
51978	3	29	1405	15739	\N	\N	59.286294424233603	Кингисеппский район, п.Ивановское здание библиотеки,		0101000020E6100000F296AB1F9BE03C4040852348A5A44D40
51992	3	29	1405	16226	67453	\N	59.375261999999999	Кингисеппский район, г. Ивангород ул. Гагарина, 6, (г. Ивангород)		0101000020E6100000B8019F1F46383C403DB7D09508B04D40
51979	3	29	1405	16226	67538	\N	59.364564999999999	"МОУ ""Ивангородская СОШ №1"" ул. Восточная дом11"	Россия, Ленинградская область, Кингисеппский район, Ивангород, улица Юрия Гагарина	0101000020E6100000143E5B0707373C401422E010AAAE4D40
51990	3	29	1405	19171	\N	\N	59.38454117117	Кингисеппский район, клуб д. Захонье-2,	Россия, Ленинградская область, Кингисеппский район, деревня Захонье-2	0101000020E6100000130B7C45B7423C404E7CB5A338B14D40
51982	3	29	1405	15907	67000	\N	59.779702999999998	Кингисеппский район, дер. Вистино, ул.Ижорская, дом 6 (Вистинский сельский Дом культуры)		0101000020E61000005CE509849D7A3C40EACBD24ECDE34D40
51980	3	29	1405	24353	66399	\N	59.583069999999999	Кингисеппский район,  д. Большое Кузёмкино, микрорайон Центральный, дом 16,		0101000020E610000067B96C74CE2F3C40ADA3AA09A2CA4D40
51976	3	29	1405	24284	\N	\N	59.386042406357603	ДК дер. Большая Пустомержа	Россия, Ленинградская область, Кингисеппский район, деревня Большая Пустомержа	0101000020E6100000F31C91EF52E23C40F47002D369B14D40
51973	3	29	1405	24264	\N	\N	59.435087000000003	Кингисеппский район, Дом культуры п.Алексеевка,	Россия, Ленинградская область, Кингисеппский район, посёлок Алексеевка	0101000020E61000004ED4D2DC0AC53C4017F549EEB0B74D40
51896	3	29	120	59016	67275	\N	59.276457158925901	Гатчинский район, п. Др.Горка, ул.Введенского, д.20  2эт	Россия, Ленинградская область, Гатчинский район, городской посёлок Дружная Горка	0101000020E6100000E29178793A233E4009E066F162A34D40
51932	3	29	120	19042	67149	\N	59.496774000000002	Гатчинский район, д.Шпаньково, ул. им. Алексея Рыкунова д.39		0101000020E61000008DD31055F8D73D4066C0594A96BF4D40
51940	3	29	120	3851	\N	\N	59.547117999999998	Гатчинский район, п.Торфяное д.43а  сельский клуб		0101000020E6100000902FA182C32B3E40C6866EF607C64D40
51922	3	29	120	18800	\N	\N	59.416328999999998	"Гатчинский район, д.Тихковицы,  д.58-б, христианский центр ""Источник"""		0101000020E6100000EF02250516F43D402DB0C7444AB54D40
94430	3	29	120	27090	67356	\N	59.671027224344897	Гатчинский район, п.Терволово,ул. Ленинградская д.14	Россия, Ленинградская область, Гатчинский район, посёлок Терволово, Ленинградская улица	0101000020E61000003755F7C8E6E63D40D3DD7536E4D54D40
51915	3	29	120	25821	7928	\N	59.664362812138499	Гатчинский район, д.Большие Тайцы, ул.Советская д.7 КДЦ	Россия, Ленинградская область, Гатчинский район, садоводство Тайцы, Советская улица, 7	0101000020E610000007EDD5C7431B3E4013D6C6D809D54D40
51916	3	29	120	59055	67391	\N	59.666535665970599	Гатчинский район, п.Тайцы, ул.Комсомольская д.26 Центр социально-диаконического обслуживания	Россия, Ленинградская область, Гатчинский район, садоводство Тайцы, Комсомольская улица	0101000020E6100000A0FF1EBC76213E40A7CD380D51D54D40
51952	3	29	120	27167	\N	\N	59.548946999999998	Гатчинский район, д.Сяськелево д10-а  2 эт		0101000020E610000053B131AF23D63D40601E32E543C64D40
51951	3	29	120	27167	\N	\N	59.548946999999998	Гатчинский район, д.Сяськелево д10-а  1 эт		0101000020E610000053B131AF23D63D40601E32E543C64D40
51947	3	29	120	18770	66130	\N	59.491407000000002	Гатчинский район, п.Сусанино, Петровский пр., д.22		0101000020E61000009F01F566D45C3E404303B16CE6BE4D40
51934	3	29	120	3726	67277	\N	59.464506999999998	Гатчинский район, п. Суйда,  ул.Центральная, д.2-а		0101000020E610000002D9EBDD1F1F3E40ACE122F774BB4D40
51955	3	29	120	19375	\N	\N	59.604599	"Гатчинский район, д. Ст.Низковицы,   помещение магазина    ООО ""Пламенское"""	Россия, Ленинградская область, Гатчинский район, деревня Старые Низковицы	0101000020E61000002E54FEB5BCB63D40DF18028063CD4D40
51913	3	29	120	59010	\N	\N	59.355172000000003	Гатчинский район, п. Сиверский-2,  ул.Военный городок, помещение клуба офицеров		0101000020E610000010E9B7AF03133E403B3AAE4676AD4D40
51912	3	29	120	357	176	\N	59.346432171830401	Гатчинский район, п.Сиверский, пр.Героев,д.1	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, проспект Героев	0101000020E61000006B7D91D0960B3E40D9243FE257AC4D40
51911	3	29	120	357	67385	\N	59.351379000000001	Гатчинский район, п. Сиверский, ул. Строителей, д.2		0101000020E6100000FE60E0B9F7103E4027C0B0FCF9AC4D40
51908	3	29	120	357	4794	\N	59.350140000000003	Гатчинский район, п.Сиверский, Республиканский пр., д.60 Столовая	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Республиканский проспект, 62	0101000020E61000008AAC3594DA133E40BF823463D1AC4D40
51905	3	29	120	357	121	\N	59.360750000000003	Гатчинский район, п.Сиверский, ул. Красная, д.19	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Красная улица, 19	0101000020E6100000ED65DB696B143E401904560E2DAE4D40
51902	3	29	120	357	67005	\N	59.355172000000003	Гатчинский район, п.Сиверский, Кезевская дорога, д.64Е		0101000020E610000010E9B7AF03133E403B3AAE4676AD4D40
51910	3	29	120	357	167	\N	59.358888259857103	Гатчинский район, п.Сиверский, ул.Заводская, д.7	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Заводская улица, 7к1к	0101000020E61000006D205D6C5A113E40A376BF0AF0AD4D40
51904	3	29	120	357	66547	\N	59.355172000000003	Гатчинский район, п.Сиверский, ул.Достоевского, д.13		0101000020E610000010E9B7AF03133E403B3AAE4676AD4D40
51906	3	29	120	357	4782	\N	59.342671000000003	Гатчинский район, п.Сиверский, ул. Восточная, д.2	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Восточная улица, 1	0101000020E6100000682101A3CB173E40D124B1A4DCAB4D40
51901	3	29	120	357	67118	\N	59.3692872045402	Гатчинский район, д.Старосиверская, Большой пр., д.97	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Большой проспект, 97	0101000020E610000035F10EF0A4153E4042EBE1CB44AF4D40
51909	3	29	120	357	67376	\N	59.3559888489089	Гатчинский район, п.Сиверский, ул. 123 Дивизии, д.10		0101000020E6100000051A6CEA3C123E402D5E2C0C91AD4D40
51948	3	29	120	22048	67058	\N	59.538573999999997	Гатчинский район, п.Семрино, Большой пр., д.4-а		0101000020E61000007D5C1B2AC6613E40EA3C2AFEEFC44D40
94431	3	29	120	19124	66996	\N	59.319389999999999	Гатчинский район, с.Рождествено, Большой пр., д.106		0101000020E61000001C45D61A4AF13D40B05582C5E1A84D40
94428	3	29	120	27032	24368	\N	59.615833000000002	Гатчинский район, д. Пудость ул. Половинкиной д.89		0101000020E6100000F3CB608C480C3E401766A19DD3CE4D40
51943	3	29	120	58951	\N	\N	59.603710999999997	Гатчинский район, д.Пудомяги, д.7		0101000020E6100000E525FF93BF533E40239EEC6646CD4D40
51941	3	29	120	3913	66435	\N	59.538269	Гатчинский район, п. Пригородный,   ул. Садовая, д.10		0101000020E6100000EA78CC4065243E40AEB9A3FFE5C44D40
51937	3	29	120	3822	67253	\N	59.433017999999997	Гатчинский район, п. Прибытково, ул. Школьная, д.2		0101000020E6100000A779C7293A163E40274A42226DB74D40
51944	3	29	120	23030	67366	\N	59.642656120176198	Гатчинский район, д.Покровская, д.154	Россия, Ленинградская область, Гатчинский район, деревня Покровская	0101000020E610000017F3734353663E40024A438D42D24D40
51928	3	29	120	26349	66989	\N	59.543145000000003	Гатчинский район, п.Новый Учхоз,  пл. Усова  д.28		0101000020E6100000486DE2E47EEF3D4033FE7DC685C54D40
51939	3	29	120	17042	\N	\N	59.559547999999999	Гатчинский район, п. Новый Свет,  д.82  МУК НКДЦ Лидер		0101000020E610000057AF22A303323E406745D4449FC74D40
51864	3	29	120	23316	24342	\N	59.232711999999999	Гатчинский район, п.Новинка, ул. Вокзальная, д.1		0101000020E6100000F3E7DB82A55E3E4081B1BE81C99D4D40
51920	3	29	120	18701	66971	\N	59.460572031896902	Гатчинский район, с. Никольское,  ул. Шипунова, д.5	Россия, Ленинградская область, Гатчинский район, село Никольское	0101000020E61000003D2B69C537003E4006BAF605F4BA4D40
94425	3	29	120	27019	\N	\N	59.606256000000002	Гатчинский район, п. Мыза-Ивановка , помещение ДРСУ, красный уголок		0101000020E6100000F4160FEF39143E407C80EECB99CD4D40
51863	3	29	120	59056	67393	\N	59.422724000000002	Гатчинский район, д.Мины, ул. Школьная, д.1 помещение Минской начальной школы-детский сад		0101000020E61000004BE9995E62643E40FE9DEDD11BB64D40
51938	3	29	120	58509	\N	\N	59.426265769154099	Гатчинский район, д. Меньково     помещение Меньковской опытной станции	Россия, Ленинградская область, Гатчинский район, деревня Меньково	0101000020E6100000880FECF82F083E40C8B260E28FB64D40
51923	3	29	120	26116	67305	\N	59.541069999999998	Гатчинский район, д. Малые Колпаны, ул. Западная д.21		0101000020E6100000713C9F01F5123E40616C21C841C54D40
51925	3	29	120	22850	\N	\N	59.613670999999997	Гатчинский район, д. Малое Верево, ул. Крайняя, д.1		0101000020E61000006E3480B7402A3E4076C075C58CCE4D40
51926	3	29	120	22850	24398	\N	59.613670999999997	Ленинградская область, Гатчинский муниципальный район, Веревское сельское поселение, деревня Малое Верево, Кутышева,1-а СКДЦ		0101000020E61000006E3480B7402A3E4076C075C58CCE4D40
51942	3	29	120	22953	65121	\N	59.597076000000001	Ленинградская область, Гатчинский муниципальный район,Лукашевскоесельское поселение, п.Лукаши, Школная д.5 Ср. школа		0101000020E61000000B2AAA7EA54B3E40FE9C82FC6CCC4D40
51897	3	29	120	3654	66379	\N	59.291736	"Гатчинский район, д.Лампово, ул.Совхозная, д.11 , МДОУ ""ДС комбинированного вида №28"""		0101000020E61000004BCADDE7F8103E406E88F19A57A54D40
49479	3	29	120	236	844	\N	59.61891	г.Коммунар, ул.Садовая, д.3	Россия, Ленинградская область, Гатчинский район, Коммунар, Садовая улица, 2	0101000020E6100000C0CFB87020643E406C95607138CF4D40
51692	3	29	120	236	66969	\N	59.635466999999998	г.Коммунар, ул. Просвещения, д.1		0101000020E610000072A43330F2663E40F7578FFB56D14D40
51900	3	29	120	236	2478	\N	59.621203999999999	"Ленинградская область, Гатчинский муниципальный район, город Коммунар, Ленинградское шоссе,3 ФОК ""Олимп"""		0101000020E6100000E8323509DE643E407B12D89C83CF4D40
51568	3	29	120	236	2478	\N	59.625858999999998	г.Коммунар, Ленинградское шоссе, д.22	Россия, Ленинградская область, Гатчинский район, Коммунар, Ленинградское шоссе, 22	0101000020E610000040DEAB5626643E402174D0251CD04D40
51899	3	29	120	236	67360	\N	59.627752000000001	г.Коммунар,   ул.Ижорская, д.14		0101000020E61000003BA8C4758C673E40D2FF722D5AD04D40
49427	3	29	120	236	67534	\N	59.620271049372001	г.Коммунар, ул.Гатчинская. д.12	Россия, Ленинградская область, Гатчинский район, Коммунар, Гатчинская улица, 12	0101000020E6100000CE55F31C91633E4020D4450A65CF4D40
51898	3	29	120	236	6526	\N	59.632165000000001	Гатчинский район, г.Коммунар,   ул.Антропшинская, д.293	Россия, Ленинградская область, Гатчинский район, Коммунар, Антропшинская улица, 293	0101000020E6100000F7216FB9FA693E40825660C8EAD04D40
51935	3	29	120	16946	67412	\N	59.425222296016997	Гатчинский район, п. Кобринская, ул.Центральная д.16	Россия, Ленинградская область, Гатчинский район, посёлок Кобринское	0101000020E6100000C37FBA81021F3E4015C5ABAC6DB64D40
51949	3	29	120	727	66988	\N	59.587366000000003	Гатчинский район, п.Кобралово, ул. Центральная, д.22		0101000020E6100000381092054C643E40246420CF2ECB4D40
51936	3	29	120	3749	65744	\N	59.408346999999999	Гатчинский район, п.Карташевская,  ул.Красная, д.24		0101000020E610000049D9226937123E40B935E9B644B44D40
94429	3	29	120	59036	\N	\N	59.627303585121901	Гатчинский район, д..Ивановка	Россия, Ленинградская область, Гатчинский район, деревня Ивановка	0101000020E610000097FF907EFBFE3D4033535A7F4BD04D40
51953	3	29	120	58984	67160	\N	59.602204	Гатчинский район, д.Жабино, ул. Поселковая, д.25		0101000020E6100000B0592E1B9DAB3D409CC24A0515CD4D40
51931	3	29	120	18936	67130	\N	59.493023999999998	Ленинградская область, Гатчинский муниципальный район, Елизаветинское сельское поселение, п.Елизаветино, пл.Дружбы д.41 Дом Культуры		0101000020E61000008461C092ABC83D40511212691BBF4D40
51930	3	29	120	18936	67054	\N	59.493023999999998	Гатчинский район, п.Елизаветино, ул. Парковая д.17		0101000020E61000008461C092ABC83D40511212691BBF4D40
51895	3	29	120	51010	24353	\N	59.277611999999998	Гатчинский район, п. Др.Горка, ул.Введенского, д.20 1 эт		0101000020E61000001364045438223E40137D3ECA88A34D40
94433	3	29	120	27150	67218	\N	59.210760000000001	Гатчинский район, п. Дивенский, ул. Володарского, д.28		0101000020E6100000B9A7AB3B16033E4009A7052FFA9A4D40
51879	3	29	120	867	5894	\N	59.563209000000001	г.Гатчина, ул.Чкалова д.66	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Чкалова, 66	0101000020E6100000245F09A4C41E3E400CE8853B17C84D40
51890	3	29	120	867	257	\N	59.568810999999997	"г.Гатчина,  ул.Рысева д.32а, здание ФОК ""Мариенбург"""		0101000020E61000003E9468C9E3113E40724D81CCCEC84D40
51876	3	29	120	867	5537	\N	59.571855999999997	г.Гатчина, ул. К.Подрядчикова, д.2	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Коли Подрядчикова, 2	0101000020E6100000C45F9335EA1D3E40BC02D19332C94D40
51878	3	29	120	867	6142	\N	59.570647999999998	г.Гатчина, ул.Киргетова, д.8	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Киргетова, 8	0101000020E610000034643C4A25203E408FC360FE0AC94D40
51869	3	29	120	867	321	\N	59.584148999999996	г.Гатчина, ул. Изотова, д.17	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Изотова, 17	0101000020E6100000DB3521AD31203E40DC7EF964C5CA4D40
51877	3	29	120	867	330	\N	59.571992000000002	г.Гатчина, пр. 25 Октября, д.30А	Россия, Ленинградская область, Гатчинский район, Гатчина, проспект 25-го Октября, 30а	0101000020E61000000C1EA67D731F3E406DC9AA0837C94D40
51871	3	29	120	867	330	\N	59.573518999999997	г.Гатчина, пр. 25 Октября, д.40	Россия, Ленинградская область, Гатчинский район, Гатчина, проспект 25-го Октября, 40	0101000020E61000002882380F27203E403B51121269C94D40
51870	3	29	120	867	330	\N	59.578520122178602	г.Гатчина, пр. 25 Октября, д.46/2	Россия, Ленинградская область, Гатчинский район, Гатчина, проспект 25-го Октября, 46к2	0101000020E610000006D49B51F3213E407C0A80F10CCA4D40
13499	7	66	939	16175	61912	\N	55.874116999999998	деревня Персирланы, Шоссейная, 32		0101000020E61000006B60AB048B1F474056F0DB10E3EF4B40
51886	3	29	120	867	220	\N	59.551819999999999	г. Гатчина , ул.Школьная, д.1	Россия, Ленинградская область, Гатчинский район, Гатчина, Школьная улица, 1	0101000020E6100000FBE6FEEA711B3E40ADA3AA09A2C64D40
51885	3	29	120	867	67487	\N	59.556821999999997	г.Гатчина,  ул.Чкалова д.2		0101000020E61000007845F0BF95203E40BED87BF145C74D40
51884	3	29	120	867	67487	\N	59.555235000000003	г.Гатчина, ул.Чкалова д.7		0101000020E61000002060ADDA35213E401B4CC3F011C74D40
51892	3	29	120	867	67586	\N	59.559995000000001	г. Гатчина ул. Слепнева д.15А		0101000020E61000005839B4C876163E40367689EAADC74D40
51873	3	29	120	867	300	\N	59.575933999999997	г.Гатчина, ул.Рощинская, д.5	Россия, Ленинградская область, Гатчинский район, Гатчина, Рощинская улица, 5	0101000020E6100000D28BDAFD2A243E40C5538F34B8C94D40
51872	3	29	120	867	300	\N	59.576326000000002	г.Гатчина, ул.Рощинская, д.7	Россия, Ленинградская область, Гатчинский район, Гатчина, Рощинская улица, 7	0101000020E6100000983270404B233E40D1EAE40CC5C94D40
51866	3	29	120	867	67442	\N	59.5792870116072	г.Гатчина, ул.Крупской, д.11	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Крупской, 11к3	0101000020E61000001E3526C45C1E3E40BDFF8F1326CA4D40
51887	3	29	120	867	5908	\N	59.563454999999998	г. Гатчина ,Красноармейский пр., д.8	Россия, Ленинградская область, Гатчинский район, Гатчина, Красноармейский проспект, 8	0101000020E6100000BF44BC75FE193E4043E21E4B1FC84D40
51868	3	29	120	867	67529	\N	59.577055000000001	г.Гатчина, ул. К.Подрядчикова, д.9		0101000020E6100000431A1538D91E3E40247F30F0DCC94D40
51880	3	29	120	867	67443	\N	59.568719999999999	Ленинградская область, Гатчинский муниципальный район, город Гатчина, Володарского д.32 Средняя школа № 1		0101000020E61000006747AAEFFC223E40624A24D1CBC84D40
51874	3	29	120	867	67443	\N	59.569290000000002	г.Гатчина, ул.Володарского, д.39А		0101000020E6100000168733BF9A233E404DF8A57EDEC84D40
51104	3	29	120	867	67443	\N	59.568719999999999	г.Гатчина, ул.Володарского, д.32		0101000020E61000006747AAEFFC223E40624A24D1CBC84D40
51889	3	29	120	867	67514	\N	59.572338999999999	г.Гатчина , ул. Беляева д.14		0101000020E6100000A4A7C821E2123E40D89C836742C94D40
51893	3	29	120	867	67206	\N	59.555028690268898	г. Гатчина , ул.Ав.Зверевой, д.15А Библиотека		0101000020E61000005B26C3F17C163E4071AAB5300BC74D40
51933	3	29	120	18704	67192	\N	59.477836000000003	Гатчинский район, п. Высокоключевой, Большой пр., д. 35 здание средней школы		0101000020E6100000BF982D5915193E40FD6CE4BA29BD4D40
51862	3	29	120	8475	4830	\N	59.382636523072399	п. Вырица, ул. Урицкого, д.88  помещение газового участка	Россия, Ленинградская область, Гатчинский район, поселок Вырица, проспект Урицкого	0101000020E6100000FF092E56D44C3E40AA9ECC3FFAB04D40
51641	3	29	120	8475	3496	\N	59.393483000000003	п. Вырица, ул.Ушаковская, д.5	Россия, Ленинградская область, Гатчинский район, поселок Вырица, Ушаковская улица, 5	0101000020E6100000785F950B954B3E401844A4A65DB24D40
51737	3	29	120	8475	4719	\N	59.402580999999998	п. Вырица, Сиверское ш.,д.168	Россия, Ленинградская область, Гатчинский район, поселок Вырица, Сиверское шоссе, 168	0101000020E61000006B48DC63E9533E40D87E32C687B34D40
51857	3	29	120	8475	6121	\N	59.422463999999998	Гатчинский район, п.Вырица,Павловский пр., д.6		0101000020E6100000AC545051F55B3E4061DEE34C13B64D40
51859	3	29	120	8475	6141	\N	59.4011112685074	п. Вырица, пр.Майский, д.41	Россия, Ленинградская область, Гатчинский район, поселок Вырица, Майский проспект	0101000020E6100000BCE6559DD54E3E406E88F19A57B34D40
51860	3	29	120	8475	67566	\N	59.405192	п.Вырица, ул. Жертв Революции, д.20		0101000020E6100000232C2AE2745A3E40E84CDA54DDB34D40
51558	3	29	120	8475	67418	\N	59.408117755121197	п. Вырица, ул. Ефимова, д. 14	Россия, Ленинградская область, Гатчинский район, поселок Вырица, улица Ефимова, 12	0101000020E6100000B41D537765573E405874EB353DB44D40
51861	3	29	120	8475	67570	\N	59.405192	п.Вырица,  ул. Жертв Революции, д.20		0101000020E6100000232C2AE2745A3E40E84CDA54DDB34D40
51927	3	29	120	26290	67196	\N	59.528582	Гатчинский район, п.Войсковицы, ул. Молодежная д.1		0101000020E61000002FA4C34318F33D408CA03193A8C34D40
94426	3	29	120	18947	\N	\N	59.596721000000002	Гатчинский район, д.Большое Рейзино помещение конторы	Россия, Ленинградская область, Гатчинский район, деревня Большое Рейзино	0101000020E6100000C59272F7390E3E4010EB8D5A61CC4D40
51914	3	29	120	59065	67447	\N	59.659585	Гатчинский район, д.Большие Тайцы, ул.Ягодная, д.12А		0101000020E6100000D120054F211B3E4051F701486DD44D40
51919	3	29	120	18668	66987	\N	59.527659999999997	Ленинградская область, Гатчинский муниципальный район, Большеколпанское сельское поселение, д.Большие Колпаны, Садовая, 4 Средняя школа		0101000020E6100000F110C64FE3123E4024B4E55C8AC34D40
51918	3	29	120	18668	66987	\N	59.527659999999997	Ленинградская область, Гатчинский муниципальный район, Большеколпанское сельское поселение, д.Большие Колпаны, Садовая, 8 Дом Культуры		0101000020E6100000F110C64FE3123E4024B4E55C8AC34D40
51924	3	29	120	18668	66578	\N	59.527659999999997	Ленинградская область, Гатчинский муниципальный район, Большеколпанское сельское поселение, д.Большие Колпаны ул.30 лет Победы д.1 Администрация		0101000020E6100000F110C64FE3123E4024B4E55C8AC34D40
51917	3	29	120	18668	65128	\N	59.527659999999997	Гатчинский район, д. Большие Колпаны, ул. Садовая д.8		0101000020E6100000F110C64FE3123E4024B4E55C8AC34D40
51903	3	29	120	59063	67435	\N	59.3476560778373	Гатчинский район, д.Белогорка, ул. Институтская, д.1		0101000020E6100000E204A6D3BA213E400C21E7FD7FAC4D40
94432	3	29	120	59006	\N	\N	59.318311000000001	Гатчинский район, д.Батово, д.12, ДК		0101000020E610000051BD35B055E23D40817A336ABEA84D40
51853	3	29	644	22775	67235	\N	60.175091999999999	Выборгский район, п. Приветнинское, ул. Военных строителей, д.11, МОУ «Приветнинская средняя общеобразовательная  школа»		0101000020E6100000D026874F3A6D3D4047E5266A69164E40
51785	3	29	644	5400	66973	\N	60.663172000000003	Выборгский район, п. Черкасово,  ул. Железнодорожная, д.38-а		0101000020E61000005532005471DF3C40BCCFF1D1E2544E40
51842	3	29	644	4795	67262	\N	60.394227000000001	Ленинградская область, Выборгский район, п. Цвелодубово, Центральная д.19 Общеобразовательная школа		0101000020E610000011FDDAFAE98F3D40A019C40776324E40
51812	3	29	644	11595	\N	\N	60.591509000000002	Выборгский район, п. Торфяновка	Россия, Ленинградская область, Выборгский район, посёлок Торфяновка	0101000020E6100000034356B77AEE3B4014252191B64B4E40
51818	3	29	644	21229	66551	\N	60.524380000000001	Выборгский район, п. Токарево, уд. Кленовая, д.5а		0101000020E61000005649641F64C93C40975643E21E434E40
51856	3	29	644	22954	\N	\N	60.263519000000002	Выборгский район, п. Тарасово, МОУ «Тарасовская начальная общеобразовательная школа»		0101000020E6100000213F1BB96E4E3D40F46F97FDBA214E40
51819	3	29	644	11753	67167	\N	60.654636000000004	Выборгский район, п. Соколинское, ул. Приморская, д.21, помещение администрация МО «Советское городское поселение»		0101000020E6100000209C4F1DABC03C406364C91CCB534E40
51817	3	29	644	21154	67446	\N	60.529287146880201	Выборгский район, п. Советский, ул. Школьная, д.17, МУ ЦКД «Движение», спортивный зал	Россия, Ленинградская область, Выборгский район, посёлок Советский, Школьная улица	0101000020E61000002B357BA015AC3C40569929ADBF434E40
51643	3	29	644	21154	67286	\N	60.540137000000001	"Советская. 15-а (здание администрации МО ""Сясьстройское городское поселение"")"		0101000020E6100000D595CFF23CAC3C40062E8F3523454E40
51815	3	29	644	21154	67347	\N	60.535122999999999	Выборгский район, п. Советский, ул. Садовая, д.32	Россия, Ленинградская область, Выборгский район, посёлок Советский, Садовая улица, 32	0101000020E6100000742502D53FAC3C40302B14E97E444E40
51845	3	29	644	22502	65805	\N	60.319572000000001	Выборгский район, п. Семиозерье,ул. Центральная, д.58, МОУ «Семиозерская основная общеобразовательная школа»		0101000020E6100000F7C95180284C3D40D15B3CBCE7284E40
51804	3	29	644	5980	67425	\N	61.114483729198099	Выборгский район, г. Светогорск, ул. Рощинская, д.6, МОУ «Средняя общеобразовательная школа № 1»	Россия, Ленинградская область, Выборгский район, Светогорск, Рощинская улица	0101000020E6100000126BF12900DE3C4027F56569A78E4E40
51806	3	29	644	5980	67581	\N	61.109983999999997	Выборгский район, г. Светогорск, ул. Лесная, д.15, МУ КСК «Бассейн «Дельфин»		0101000020E61000008FA850DD5CE03C40A88AA9F4138E4E40
51805	3	29	644	5980	67581	\N	61.114252	Выборгский район, г. Светогорск, ул. Лесная, д.7а, Центр досуга «Заря»		0101000020E6100000CA4FAA7D3ADE3C4055C03DCF9F8E4E40
51807	3	29	644	5980	1674	\N	61.107163	Выборгский район, г. Светогорск, ул. Красноармейская, д.3, ГБОУ СПО ЛО «Политехнический колледж»		0101000020E6100000DA8EA9BBB2DF3C40AE2B6684B78D4E40
51803	3	29	644	5980	66509	\N	61.100240999999997	"Выборгский район, г. Светогорск, ул. Коробицына д.4 Детский сад ""Лучик"""		0101000020E6100000DDED7A698ADC3C40F25B74B2D48C4E40
51826	3	29	644	4276	\N	\N	60.344749	Выборгский район, п. Рябово, контора  СПК  “Рябовский”		0101000020E6100000BE326FD575FC3C40132A38BC202C4E40
51840	3	29	644	4979	5950	\N	60.243648	Выборгский район, п. Рощино, ул. Социалистическая д.119а, МДОУ Детский сад «Аистенок»		0101000020E610000074CFBA46CBA13D402FDE8FDB2F1F4E40
51837	3	29	644	4979	5910	\N	60.256515999999998	Выборгский район, п. Рощино, ул. Советская, д.35, Дом Культуры		0101000020E6100000EA793716149A3D404B732B84D5204E40
51839	3	29	644	4979	67488	\N	60.255935000000001	Выборгский район, п. Рощино, ул. Советская, д.39		0101000020E61000001B48179B569A3D406D73637AC2204E40
51838	3	29	644	4979	67526	\N	60.256475000000002	Выборгский район, п. Рощино, ул. Железнодорожная, д.57,  МОУ  «Рощинская средняя общеобразовательная школа»		0101000020E61000005EF7562426983D40ED9E3C2CD4204E40
51834	3	29	644	21983	\N	\N	60.237529000000002	Выборгский район, п. Решетниково, д.5		0101000020E6100000E6E95C514AB43D40016DAB59671E4E40
51843	3	29	644	4833	67254	\N	60.406926730115998	Выборгский район, п. Пушное,  ул.Школьная. Д.13, МОУ «Пушновская средняя общеобразовательная школа»	Россия, Ленинградская область, Выборгский район, посёлок Пушное	0101000020E61000000745F30016793D40016E162F16344E40
51794	3	29	644	5684	\N	\N	61.019653831577301	Выборгский район, п. Пруды, МОУ «Прудовская начальная общеобразовательная школа»	Россия, Ленинградская область, Выборгский район, посёлок Пруды	0101000020E61000008E209562470B3D40289EB30584824E40
51823	3	29	644	4242	5753	\N	60.365836000000002	Выборгский район, г. Приморск, наб. Лебедева, д.7, МОУД «Центр дополнительного образования»		0101000020E610000098A77345299D3C4088D9CBB6D32E4E40
51822	3	29	644	4242	5753	\N	60.366698999999997	г. Приморск, наб. Лебедева д.4 библиотека		0101000020E610000054C6BFCFB89C3C40EA3C2AFEEF2E4E40
51824	3	29	644	4242	67601	\N	60.368523000000003	Выборгский район, г. Приморск, ул. Школьная, д.16		0101000020E6100000B5E21B0A9F9D3C407369FCC22B2F4E40
51852	3	29	644	58974	67139	\N	60.175091999999999	Выборгский район, п. Приветнинское, ул. Лесная, д.4,  контора  участка  СПК  “Поляны”		0101000020E6100000D026874F3A6D3D4047E5266A69164E40
51849	3	29	644	4938	67148	\N	60.314591	Выборгский район, п. Поляны, Выборгское шоссе, д.73,  МОУ «Полянская средняя общеобразовательная школа»		0101000020E6100000600322C495433D40D74E948444284E40
51561	3	29	644	58443	65040	\N	60.676128707155598	п.Подборовье, ул.Советская, д.1	Россия, Ленинградская область, Выборгский район, посёлок Подборовье	0101000020E6100000102043C70E863C40487023658B564E40
51844	3	29	644	4875	\N	\N	60.378576000000002	"Ленинградская область, Выборгский район, п. Победа, Птицефабрика ""Ударник"" Дом культуры"		0101000020E61000008942CBBA7F8C3D407786A92D75304E40
51854	3	29	644	5025	67232	\N	60.166856000000003	Выборгский район, п. Песочное, ул. Литвинова, д.25, здание штаба НИЦ-26 МО РФ		0101000020E610000002284696CC5D3D40199293895B154E40
51784	3	29	644	5348	\N	\N	60.680486999999999	"Выборгский район, п. Перово, Начальная школа-сад""Теремок"""		0101000020E61000002AFD84B35BF33C40342DB1321A574E40
51841	3	29	644	58943	67070	\N	60.356563532418498	Выборгский район, п. Первомайское-1, д.1 помещение бывшего магазина	Россия, Ленинградская область, Выборгский район, А122	0101000020E6100000876C205D6CBE3D4029779FE3A32D4E40
51833	3	29	644	4628	67264	\N	60.359496	Выборгский район, п. Первомайское, ул. Ленина, д.72, МУК КИЦ «Кивеннапа» Дворец Культуры		0101000020E61000000473F4F8BDBD3D407B8505F7032E4E40
51798	3	29	644	20150	65927	\N	61.007444999999997	Выборгский район, п. Михалево,  ул. Новая		0101000020E61000002AFF5A5EB9663D4065C22FF5F3804E40
51810	3	29	644	58997	\N	\N	60.806224999999998	"Выборгский район, п. Лужайка, ОЛГБУ ""Ленобллес"""		0101000020E6100000087767EDB67B3C40DA1B7C6132674E40
51802	3	29	644	59045	67354	\N	61.081777252047097	Выборгский район, дер. Лосево, ул. Новая, «Лосевская начальная школа – детский сад» (помещение детского сада)	Россия, Ленинградская область, Выборгский район, посёлок Лосево	0101000020E6100000B554DE8E70FA3C40524832AB778A4E40
51800	3	29	644	5882	1605	\N	61.091138999999998	"Выборгский район, п. Лесогорский, Школьный пер. д.2, МОУ ""Лесогорская СОШ"""		0101000020E6100000064B75012FE73C40F0315871AA8B4E40
51801	3	29	644	5882	24356	\N	61.049252000000003	Выборгский район, п. Лесогорский, ул. Летчиков, д.9, МДОУ «Детский сад «Чебурашка»		0101000020E61000007193516518EB3C409DA1B8E34D864E40
51835	3	29	644	4666	5884	\N	60.225912999999998	Выборгский район, п. Ленинское,  ул. Заречная, д.24,  МОУ «Ленинская основная общеобразовательная школа»		0101000020E61000004C6DA983BCDA3D40E15E99B7EA1C4E40
51797	3	29	644	20088	\N	\N	60.902467999999999	Выборгский район, п. Красный Сокол, библиотека,		0101000020E610000027C286A757463D40E0D7481284734E40
51829	3	29	644	21756	66218	\N	60.546070999999998	Выборгский район, п. Красносельское ул. Советская, д. 9а,  Дом Культуры		0101000020E6100000349E08E23C7C3D40A2258FA7E5454E40
51827	3	29	644	4393	\N	\N	60.361173000000001	Выборгский район, п. Красная  Долина,  Средняя школа		0101000020E6100000CC7A319413FD3C405F99B7EA3A2E4E40
51830	3	29	644	4497	\N	\N	60.515151986563303	Выборгский район, п. Коробицыно, МДОУ  «Детский  сад «Рябинушка» пос. Коробицыно»	Россия, Ленинградская область, Выборгский район, посёлок Коробицыно	0101000020E6100000EEED96E480B93D40083C3080F0414E40
51813	3	29	644	11640	\N	\N	60.631962999999999	Выборгский район, п. Кондратьево	Россия, Ленинградская область, Выборгский район, посёлок Кондратьево	0101000020E6100000AED51EF642293C401AA4E029E4504E40
51851	3	29	644	22766	67153	\N	60.311760999999997	Выборгский район, п. Клеверное,  ул. Центральная, д.6,  сельский Клуб		0101000020E61000006616A1D80A2A3D408995D1C8E7274E40
51831	3	29	644	4564	24370	\N	60.469490999999998	Выборгский район, п. Кирпичное, ул. Комсомольская, МОУ «Кирилловская средняя общеобразовательная школа»		0101000020E610000070067FBF985D3D401762F547183C4E40
51832	3	29	644	21890	67269	\N	60.470971731305902	Выборгский район, п. Кирилловское, ул. Советская, д.30,  помещение администрации МО «Красносельское сельское поселение»	Россия, Ленинградская область, Выборгский район, посёлок Кирилловское	0101000020E61000003F3BE0BA62463D4076AA7CCF483C4E40
51793	3	29	644	5615	67251	\N	60.945773000000003	Выборгский район, г. Каменногорск, Ленинградское шоссе, д.93, МОУ «Каменногорская  средняя                                            общеобразовательная школа»		0101000020E61000001F645930F11F3D404C38F4160F794E40
51836	3	29	644	4736	67223	\N	60.265255000000003	Выборгский район, п. Ильичёво, ул. Садовая, д.3		0101000020E61000005BCF108E59C63D40DD0C37E0F3214E40
51799	3	29	644	5836	\N	\N	61.059846999999998	Выборгский район, п. Зайцево	Россия, Ленинградская область, Выборгский район, посёлок Зайцево	0101000020E6100000F94A202576713D40C1E10511A9874E40
51789	3	29	644	5503	\N	\N	60.696539000000001	Выборгский район, п. Житково,Сельский ДК		0101000020E6100000EA20AF0793523D40BCB1A03028594E40
51825	3	29	644	20351	\N	\N	60.358409999999999	Выборгский район, п. Ермилово,Основная школа		0101000020E6100000D02B9E7AA4C53C409947FE60E02D4E40
51855	3	29	644	5083	66396	\N	60.268476999999997	Выборгский район, п. Горьковское, ул. Центральная, д.6, сельский Клуб		0101000020E61000009DF6949C136F3D40355D4F745D224E40
51786	3	29	644	19475	\N	\N	60.703817000000001	"Выборгский район, п. Гончарово,КИЦ ""Гармония"""		0101000020E6100000E606431D56F03C4036AFEAAC165A4E40
51821	3	29	644	6763	\N	\N	60.454653	Выборгский район, п. Глебычево, МОУ  «Глебычевская средняя общеобразовательная школа»		0101000020E6100000CA8B4CC0AFB93C409F03CB11323A4E40
51820	3	29	644	6763	67302	\N	60.454653	Выборгский район, п. Глебычево, ул. Мира		0101000020E6100000CA8B4CC0AFB93C409F03CB11323A4E40
51787	3	29	644	5453	\N	\N	60.803007999999998	Ленинградская область, Выборгский район, пос.Гвардейское,Сельский ДК		0101000020E6100000D8F4A0A014F53C40933655F7C8664E40
51788	3	29	644	18461	67217	\N	60.590277392032498	Выборгский район, п. Гаврилово, ул. Центральная, д.35	Россия, Ленинградская область, Выборгский район, посёлок Гаврилово	0101000020E6100000CC9A58E02B0A3D405E4A5D328E4B4E40
51814	3	29	644	11681	67561	\N	60.627921905883703	Выборгский район, г. Высоцк,ул.Ленинская, д.4	Россия, Ленинградская область, Выборгский район, Высоцк, Ленинская улица, 4	0101000020E6100000051A6CEA3C923C402E3883BF5F504E40
51767	3	29	644	5146	1949	\N	60.695763999999997	Выборгский район, г. Выборг, ул. Гагарина, д.38/14, МОУ «Средняя общеобразовательная школа № 12»		0101000020E610000049145AD6FDC33C40F8DD74CB0E594E40
51752	3	29	644	5146	2960	\N	60.710324	Выборгский район, г. Выборг, пр. Ленина, д.20	Россия, Ленинградская область, Выборгский район, Выборг, проспект Ленина, 20	0101000020E6100000A79201A08ABF3C402EC896E5EB5A4E40
51776	3	29	644	5146	67337	\N	60.747089000000003	Выборгский район, г. Выборг,  ул. им. А.К. Харитонова, д.14, МБДОУ «Детский сад «Ромашка»		0101000020E6100000815CE2C803993C40C619C39CA05F4E40
51682	3	29	623	13278	67178	\N	60.259166999999998	Всеволожский район, п.Осельки, ул. Ленинградская д.1а  Осельковская ООШ,		0101000020E6100000747D1F0E126E3E40E9995E622C214E40
51777	3	29	644	5146	67407	\N	60.710226714955603	Выборгский район, г. Выборг,  ул. Школьная, д.8, МОУ «Средняя  общеобразовательная  школа № 9»	Россия, Ленинградская область, Выборгский район, Выборг, Школьная улица, 4	0101000020E6100000DC476E4DBAC13C403CDEE4B7E85A4E40
51744	3	29	644	5146	67495	\N	60.731603999999997	Выборгский район, г. Выборг,  ул. Шестакова, д.28		0101000020E6100000100874266DB23C40B7CF2A33A55D4E40
51757	3	29	644	5146	67542	\N	60.704456	Выборгский район, г. Выборг, ул. Сухова, д.2, ОАО «Выборгтеплоэнерго»		0101000020E61000008E210038F6C43C4049BC3C9D2B5A4E40
51774	3	29	644	5146	5162	\N	60.723605999999997	Выборгский район, г. Выборг, пос. Выборгский, ул. Судостроительная, д.16а, МБДОУ «Детский сад комбинированного  вида № 14	Россия, Ленинградская область, Выборгский район, Выборг, Судостроительная улица, 16	0101000020E6100000E658DE550FBC3C403D98141F9F5C4E40
51770	3	29	644	5146	2055	\N	60.722446375601301	Выборгский район, г. Выборг, Смирновское шоссе, д.15, ГП «Выборгское  ДРЭУ»		0101000020E6100000F834272F32C93C4021904B1C795C4E40
51781	3	29	644	5146	67387	\N	60.692640901891998	Выборгский район, г. Выборг, ул. Рубежная, д.38, МДОУ Детский сад  № 32  «Росинка»	Россия, Ленинградская область, Выборгский район, Выборг, Рубежная улица, 36	0101000020E610000016DD7A4D0FC63C40336FD575A8584E40
51778	3	29	644	5146	67387	\N	60.690994000000003	Выборгский район, г. Выборг, ул. Рубежная, д.31, МОУ «Средняя общеобразовательная школа № 10»		0101000020E610000027BD6F7CEDC53C40BADDCB7D72584E40
51768	3	29	644	5146	67387	\N	60.690994000000003	Выборгский район, г. Выборг, ул. Рубежная, д.31, МОУ «Средняя общеобразовательная школа №10»		0101000020E610000027BD6F7CEDC53C40BADDCB7D72584E40
51746	3	29	644	5146	67492	\N	60.713577000000001	Выборгский район, г. Выборг, ул. Прогонная, д.9, Клуб «Балтика» МАУК «Культурно-досуговый комплекс»		0101000020E61000006C5ED5592DBC3C40C216BB7D565B4E40
51766	3	29	644	5146	5060	\N	60.695579000000002	Выборгский район, г. Выборг, Приморское шоссе, д.12а, МДОУ Детский сад комбинированного вида № 31 «Кораблик»		0101000020E610000010751F80D4C23C40676490BB08594E40
51762	3	29	644	5146	67400	\N	60.696798999999999	Выборгский район, г. Выборг, ул. Приморская, д.34, МБОУ ДОД «Центр детского творчества»		0101000020E610000088F37002D3C53C405871AAB530594E40
51761	3	29	644	5146	67400	\N	60.697785000000003	Выборгский район, г. Выборг, ул. Приморская, д.41, МАУ «Спортивно-зрелищный комплекс «Фаворит»		0101000020E6100000ECDB4944F8C73C40D751D50451594E40
51751	3	29	644	5146	67433	\N	60.714078999999998	"Ленинградская область, г.Выборг,Пограничеая д.3 Детский сад ""Солнышко"""		0101000020E61000009622F94A20C13C4054E1CFF0665B4E40
51756	3	29	644	5146	67573	\N	60.708995000000002	Выборгский район, г. Выборг, ул. Первомайская, д.12, МОУ «Средняя общеобразовательная школа  № 6»		0101000020E610000014CFD90242C33C4086032159C05A4E40
51747	3	29	644	5146	2906	\N	60.705913000000002	Выборгский район, г. Выборг, Морская  набережная, д.5	Россия, Ленинградская область, Выборгский район, Выборг, Морская набережная, 5	0101000020E6100000FC54151A88BD3C401F69705B5B5A4E40
51760	3	29	644	5146	2974	\N	60.702285000000003	Ленинградская область, г.Выборг, Ленинградское шоссе, 45А	Россия, Ленинградская область, Выборгский район, Выборг, Ленинградское шоссе, 45а	0101000020E61000005C02F04FA9C63C4056BC9179E4594E40
51755	3	29	644	5146	2974	\N	60.710116999999997	Выборгский район, г. Выборг, Ленинградское шоссе, д.26а	Россия, Ленинградская область, Выборгский район, Выборг, Ленинградское шоссе, 26а	0101000020E6100000E466B8019FC33C40B4AA251DE55A4E40
51773	3	29	644	5146	67375	\N	60.737634999999997	Выборгский район, г. Выборг, ул. Кировские Дачи, д.2, МБДОУ «Детский сад комбинированного вида «Рябинка»		0101000020E61000003D49BA66F2C13C4046B1DCD26A5E4E40
51779	3	29	644	5146	67456	\N	60.697543000000003	"Ленинградская область, г.Выборг, Гагарина, 17А Детский сад №19 ""Колосок"""		0101000020E6100000D8F50B76C3C23C40E146CA1649594E40
51765	3	29	644	5146	67456	\N	60.696688000000002	Выборгский район, г. Выборг, ул. Гагарина, д.36, МОУ «Средняя общеобразовательная школа № 14», спортивный зал		0101000020E61000002F336C94F5C33C4001C287122D594E40
51763	3	29	644	5146	67456	\N	60.696688000000002	Выборгский район, г. Выборг, ул. Гагарина, д.36, МОУ «Средняя общеобразовательная школа №14», актовый зал		0101000020E61000002F336C94F5C33C4001C287122D594E40
51782	3	29	644	5146	67584	\N	60.697088999999998	Выборгский район, г. Выборг, ул. Большая Каменная, д.6 ГАОУ СПО ЛО ВПК «Александровский», общежитие		0101000020E6100000750470B378C93C405FB35C363A594E40
51775	3	29	644	5146	67603	\N	60.730623000000001	Выборгский район, г. Выборг, ул. Большая  Гвардейская, д.33, МОУ «Выборгская вечерняя  (сменная) общеобразовательная  школа»		0101000020E61000004E62105839B83C404B5AF10D855D4E40
51795	3	29	644	19969	\N	\N	60.855314	Выборгский район, п. Возрождение, МОУ «Возрожденская средняя общеобразовательная школа»		0101000020E6100000EFE4D3635BF63C40CDE7DCED7A6D4E40
51791	3	29	644	58969	67125	\N	60.723667715763497	Выборгский район, п.ст. Вещево, ул. Воинской  Славы	Россия, Ленинградская область, Выборгский район, посёлок Вещево	0101000020E6100000884CF910542D3D40B4942C27A15C4E40
51811	3	29	644	20899	67285	\N	60.692000796579499	Выборгский район, п. Большое Поле, ул. Римского-Корсакова, д.17	Россия, Ленинградская область, Выборгский район, посёлок Большое Поле	0101000020E61000003D80457EFD803C404FE61F7D93584E40
51790	3	29	644	5560	\N	\N	60.697560000000003	Выборгский район, п. Барышево, Барышевский сельский Дом Культуры		0101000020E61000001327F73B14953D40B77F65A549594E40
51706	3	29	623	59061	67430	\N	59.8758699793635	Всеволожский район, п.Дубровка, ул.Школьная, д.17а,	Россия	0101000020E6100000452A8C2D04ED3E4015C616821CF04D40
37706	3	28	\N	7525	23224	\N	55.072916999999997	город Советск, Тургенева, 3д		0101000020E610000020EC14AB06E135404529215855894B40
51708	3	29	623	11783	\N	\N	59.797452	"Всеволожский район, п.им.Свердлова, мкр-н №1, МОБУ ""Свердловская СОЩ №1"", "		0101000020E6100000CEC4742156AB3E409D103AE812E64D40
51710	3	29	623	11783	67279	\N	59.797452	Всеволожский район, п.им.Свердлова, мкр-н №2,МОБУ СОШ №2 неполная средняя школа,		0101000020E6100000CEC4742156AB3E409D103AE812E64D40
51709	3	29	623	11783	67181	\N	59.793553980357302	"Всеволожский район, п.им.Свердлова, мкр-н №1, Дои Культуры ""Нева"", "		0101000020E610000096986725ADA83E4014CE6E2D93E54D40
51703	3	29	623	59076	67580	\N	59.973478659775999	Всеволожский район, п. им. Морозова пл.Культуры д4 Музыкальная школа	Россия, Ленинградская область, Кировский район, посёлок имени Морозова, Первомайская улица	0101000020E6100000B30A9B012E083F40E02BBAF59AFC4D40
51714	3	29	623	11916	\N	\N	59.949883999999997	"Всеволожский район, д.Янино-1, Администрация МО ""Заневское сельское поселение"" ул. Заневская д.1а ,актовый зал"		0101000020E610000094F8DC09F68F3E40307F85CC95F94D40
51715	3	29	623	11916	67383	\N	59.948369999999997	Всеволожский район, д.Янино-1,ул. Новая д.16 Янинская средняя общеобразовательная школа,		0101000020E6100000B9382A37518F3E40F6402B3064F94D40
51656	3	29	623	17334	4796	\N	60.1101896424315	Всеволожский район, д.Юкки Ленинградское шоссе д.26 Администрация	Россия, Ленинградская область, Всеволожский район, деревня Юкки, Ленинградское шоссе	0101000020E61000008481E7DEC3493E40522CB7B41A0E4E40
51663	3	29	623	58926	\N	\N	60.328108	"Всеволожский район, д.Энтолово Конно-спортивный клуб ""Дерби"""		0101000020E6100000056F48A302EB3E402AC76471FF294E40
51701	3	29	623	13698	\N	\N	60.027467000000001	"Всеволожский район, п.Щеглово, д.11, МУ ""Щегловский сельский Дом культуры"", "		0101000020E610000010751F80D4C23E40105CE50984034E40
51700	3	29	623	13698	\N	\N	60.029153238660399	"Всеволожский район, п.Щеглово, д.58, МОУ ""Щегловская средняя школа"", "	Россия, Ленинградская область, Всеволожский район, посёлок Щеглово	0101000020E6100000793A579412C23E4047CA1649BB034E40
51712	3	29	623	58939	\N	\N	59.882992999999999	"Всеволожский район, д.Хапо-ОеЮ МДОУ ""Детский сад № 26"""	Россия, Ленинградская область, Всеволожский район, деревня Хапо-Ое	0101000020E61000007BA180ED60C03E4068CC24EA05F14D40
51691	3	29	623	14758	\N	\N	60.071078999999997	Всеволожский район, п.Углово, клуб в/ч 11703,		0101000020E6100000863C821B29BB3E405837DE1D19094E40
51684	3	29	623	13366	67509	\N	60.160262000000003	"Всеволожский район, п.Токсово, ул. Буланова д.18 МУЗ ""Районная больница""Поликлиника "		0101000020E6100000B6BFB33D7A873E405265187783144E40
51686	3	29	623	13366	67371	\N	60.145966999999999	"Всеволожский район, п.Токсово, ул. Дорожников д.1 МОБУ ""Токсовская СОШ"""		0101000020E6100000FE0DDAAB8F833E40CAA5F10BAF124E40
51713	3	29	623	11864	24366	\N	59.945464097280997	"Всеволожский район, д.Суоранда, ул.Строителей, д.19, ООО ""Оптен-кабель"", "	Россия, Ленинградская область, Всеволожский район, деревня Суоранда	0101000020E6100000E4D6A4DB129D3E40CEC5DFF604F94D40
51679	3	29	623	13172	\N	\N	60.384064000000002	Всеволожский район, п.Стеклянный, неполная средняя общеобразовательная школа,		0101000020E6100000069D103AE83A3E4015C9570229314E40
51740	3	29	623	52211	67316	\N	59.930152663838903	"Всеволожский район, д.Старая, ул.Верхняя МДОУ ""Детский сад № 62"" "	Россия, Ленинградская область, Всеволожский район, деревня Старая, Верхняя улица	0101000020E610000073BD6DA642A03E405DA3E5400FF74D40
51655	3	29	623	12757	3622	\N	60.144247	Ленинградская область, г.Сертолово, мкр-н Сертолово1, ул.Молодцова, д.18	Россия, Ленинградская область, Всеволожский район, Сертолово, улица Молодцова, 18	0101000020E61000008E3BA583F5373E40E7C589AF76124E40
51652	3	29	623	12757	3622	\N	60.141886999999997	Ленинградская область, г.Сертолово, мкр-н Сертолово1, ул.Молодцова, д.4, корп.2	Россия, Ленинградская область, Всеволожский район, Сертолово, улица Молодцова, 4	0101000020E6100000506EDBF7A8373E40205D6C5A29124E40
51653	3	29	623	12757	66506	\N	60.145178999999999	Всеволожский район, г.Сертолово, мкр-н Черная речка д.55 , общеобразовательная школа, 1 этаж,		0101000020E61000002AC6F99B50303E407288B83995124E40
51654	3	29	623	12757	65017	\N	60.144247	Всеволожский район, г.Сертолово, ул.Молодцова, д.18, школа №3, 1 этаж, столовая,		0101000020E61000008E3BA583F5373E40E7C589AF76124E40
51690	3	29	623	13427	\N	\N	60.046598000000003	"Всеволожский район, п.Романовка,д 24 МОУ №Романовка СОШ"""		0101000020E61000008786C5A86BB53E408E075BECF6054E40
51689	3	29	623	13427	\N	\N	60.046598000000003	Ленинградская область, Всеволожский район, пос.Романовка, д.20		0101000020E61000008786C5A86BB53E408E075BECF6054E40
51688	3	29	623	13427	\N	\N	60.046598000000003	"Всеволожский район, п.Романовка,д.20 ДК ""Свеча"", "		0101000020E61000008786C5A86BB53E408E075BECF6054E40
51694	3	29	623	58952	67088	\N	60.090997000000002	Всеволожский район, п.Рахья, ул. Севастьянова д.1 средняя школа.	Россия, Ленинградская область, Всеволожский район, городской посёлок Рахья	0101000020E6100000FACF9A1F7FD53E405E8429CAA50B4E40
51693	3	29	623	58924	67028	\N	60.090997000000002	Всеволожский район, п.Рахья, Октябрьское ш., д.1, Дом культуры,		0101000020E6100000FACF9A1F7FD53E405E8429CAA50B4E40
51687	3	29	623	14557	67345	\N	60.158439213288403	Всеволожский район, д. Рапполово.  ул. Овражная д.21а Библиотека	Россия, Ленинградская область, Всеволожский район, деревня Рапполово, Овражная улица	0101000020E61000009A40118B18723E409AB4A9BA47144E40
51711	3	29	623	15692	\N	\N	59.905633000000002	"Всеволожский район, д.Разметелево,МОБУ ""Разметелевская СОШ""  "		0101000020E61000009CA5643909AD3E40D5963AC8EBF34D40
51664	3	29	623	13455	\N	\N	60.112141000000001	Всеволожский район, д.Порошкино д.19-а		0101000020E6100000FD82DDB06D593E4037C5E3A25A0E4E40
51742	3	29	623	10098	\N	\N	59.935701000000002	Всеволожский район, с.Павлово, ин-т физиологии им.И.П.Павлова, главный корпус,		0101000020E6100000E162450DA6A93E40D1EAE40CC5F74D40
51673	3	29	623	13737	\N	\N	60.056970746883898	Всеволожский район, д.Новое Девяткино д.96а Детский Сад №59		0101000020E61000006AC2F693317A3E4003E962D34A074E40
51670	3	29	623	13737	\N	\N	60.056305999999999	Всеволожский район, д.Новое Девяткино д93а Моложежный клуб		0101000020E61000007B116DC7D4793E40C748F60835074E40
51672	3	29	623	13737	67246	\N	60.059449318364898	"Всеволожский район, д.Новое Девяткиноул. Школьная д1. МОУ ""Новодевяткинская СОШ №1"	Россия, Ленинградская область, Всеволожский район, деревня Новое Девяткино	0101000020E610000012C2A38D237A3E40D4635B069C074E40
51671	3	29	623	58982	\N	\N	60.056305999999999	"Всеволожский район, д.Новое Девяткино д.19/1 Культурно-досуговый центр ""Рондо"""		0101000020E61000007B116DC7D4793E40C748F60835074E40
51677	3	29	623	14088	\N	\N	60.352068000000003	Всеволожский район, д.Ненимяки,д.83 пом.11 (бывший военторг)		0101000020E61000006A4C88B9A4623E40ECFB7090102D4E40
51717	3	29	623	15979	67525	\N	60.045448	Всеволожский район, п.Мурино, ул.Центральная , д46, Помещение банка		0101000020E61000000729780AB9723E4095D5743DD1054E40
51719	3	29	623	15979	67444	\N	60.041642000000003	"Всеволожский район, п.Мурино, ул.Оборонная, д.32а, администрация МО ""Муринское сельское поселение"", Конференц-зал"		0101000020E6100000357EE19524773E40ED116A8654054E40
51720	3	29	623	15979	67450	\N	60.041642000000003	"Всеволожский район, п.Мурино, ул.Оборонная, д.32а,помещение МБУ ""Центр муниципальных услуг"""		0101000020E6100000357EE19524773E40ED116A8654054E40
51657	3	29	623	59020	67283	\N	60.1513966526879	"Всеволожский район, д.Лупполово МДУ ""Детский Сад № 28"" "		0101000020E6100000325871AAB5483E4034DB15FA60134E40
51680	3	29	623	14222	\N	\N	60.378909999999998	Всеволожский район, п.Лесное, Лесновская средняя общеобразовательная школа,		0101000020E610000020425C397B333E404D10751F80304E40
51683	3	29	623	13333	66145	\N	60.267173999999997	Всеволожский район, д.Лесколово, ул.Красноборская, Дом культуры,		0101000020E61000004FB0FF3A37753E40B62BF4C132224E40
51718	3	29	623	59002	\N	\N	60.0735054940032	"Всеволожский район, д. Лаврики МДОУ №Детский сад № 61"""	Россия, Ленинградская область, Всеволожский район, деревня Лаврики	0101000020E610000046787B1002723E40D68BA19C68094E40
51674	3	29	623	29981	67194	\N	60.316513205387501	"Всеволожский район, д.Куйвози, ул.Александрова, д.6, администрация МО ""Куйвозовское сельское поселение"","	Россия, Ленинградская область, Всеволожский район, деревня Куйвози	0101000020E6100000776A2E3718723E4022E17B7F83284E40
51666	3	29	623	13521	3830	\N	60.109797	Всеволожский район, п.Кузьмоловский, ул.Школьная д.9 Музыкальная школа	Россия, Ленинградская область, Всеволожский район, посёлок Кузьмоловский, Школьная улица	0101000020E6100000A39410ACAA7F3E407619FED30D0E4E40
51669	3	29	623	13521	67365	\N	60.110134000000002	"Всеволожский район, п.Кузьмоловский, ул.Строителей д.7-а МОБ№ ""СОШ №1"""	Россия, Ленинградская область, Всеволожский район, посёлок Кузьмоловский, улица Строителей	0101000020E6100000971DE21FB67C3E40BE16F4DE180E4E40
51668	3	29	623	13521	67313	\N	60.109265999999998	"Всеволожский район, п.Кузьмоловский, ул.Спортивная д.10 МОБУ ""СОШ №2"""	Россия, Ленинградская область, Всеволожский район, посёлок Кузьмоловский, Спортивная улица	0101000020E6100000FBB0DEA8157E3E404948A46DFC0D4E40
51665	3	29	623	13521	67207	\N	60.108939999999997	Всеволожский район, п.Кузьмоловский,Леншоссе д.8 Дом культуры.	Россия, Ленинградская область, Всеволожский район, посёлок Кузьмоловский, Ленинградское шоссе	0101000020E61000003C1570CFF37F3E40F59CF4BEF10D4E40
51667	3	29	623	58995	67215	\N	60.120109999999997	Всеволожский район, п.Кузьмоловский, ул.Заозерная д.5 (кафе	Россия, Ленинградская область, Всеволожский район, деревня Кузьмолово, Заозерная улица	0101000020E6100000C26C020CCB7F3E4016F6B4C35F0F4E40
51741	3	29	623	10026	\N	\N	59.931187882476699	Всеволожский район, д.Колтуши Колтушская средняя школа им.И.П.Павлова,	Россия, Ленинградская область, Всеволожский район, деревня Суоранда, Колтушское шоссе	0101000020E61000000CCB9F6F0BA63E40BD361B2B31F74D40
51698	3	29	623	59003	67239	\N	60.077584231873502	Всеволожский район, д.Ириновка, Ленинградское ш., Дом культуры,	Россия, Ленинградская область, Всеволожский район, деревня Ириновка	0101000020E61000009B92ACC3D1ED3E40B058C345EE094E40
51716	3	29	623	11968	\N	\N	59.935479999999998	Всеволожский район, д.Заневка, д.48, библиотека,		0101000020E6100000666A12BC21853E40F20703CFBDF74D40
51676	3	29	623	13078	\N	\N	60.312959999999997	Всеволожский район, п.Заводской, д.3, кв.18 (ЖЭУ),		0101000020E61000001077F52A327E3E40637AC2120F284E40
51675	3	29	623	13051	\N	\N	60.340569527256498	Всеволожский район, д.Гарболово, школа,	Россия, Ленинградская область, Всеволожский район, деревня Гарболово	0101000020E6100000C9E7154F3D7E3E40D6FF39CC972B4E40
51736	3	29	623	9960	3471	\N	60.017944	Всеволожский район, г.Всеволожск, ул.Грибоедова, д.10, средняя школа №5,		0101000020E61000007C48F8DEDFA43E4068942EFD4B024E40
51730	3	29	623	9960	67500	\N	60.035679000000002	Всеволожский район, г.Всеволожск, ул.Шишканя, д.1, Сельскохозяйственный колледж,		0101000020E61000001B2FDD2406A53E40B613252191044E40
51738	3	29	623	9960	4730	\N	60.007686	Всеволожский район, г.Всеволожск, Торговый пр., д.144, станция юных техников,		0101000020E610000008B0C8AF1FAE3E408B51D7DAFB004E40
51735	3	29	623	9960	67340	\N	60.018780999999997	"Всеволожский район, г.Всеволожск, ул.Пушкинская, д.61-а, Молодежно-подростковый клуб ""Энергия"", "		0101000020E61000000F2A711DE3AE3E40A164726A67024E40
51734	3	29	623	9960	67631	\N	60.009872000000001	Всеволожский район, г.Всеволожск, ул.Приютинская, д.13, ПУ-56,		0101000020E61000007842AF3F89973E40B492567C43014E40
51739	3	29	623	9960	67326	\N	59.993298000000003	Всеволожский район, г.Всеволожск, мкр-н Южный, ул.Московская, общественный центр,		0101000020E6100000BDE13E726BA63E4053978C6324FF4D40
51723	3	29	623	9960	3209	\N	60.025179000000001	Ленинградская область, г.Всеволожск, Межевая, 14	Россия, Ленинградская область, Всеволожский район, Всеволожск, Межевая улица, 14	0101000020E6100000DBF813950DA33E40E3C5C21039034E40
51722	3	29	623	9960	67559	\N	60.025179000000001	Всеволожский район, г.Всеволожск, ул.Межевая, д.14, лицей №1,		0101000020E6100000DBF813950DA33E40E3C5C21039034E40
51724	3	29	623	9960	65033	\N	60.023578000000001	Всеволожский район, г.Всеволожск, ул.Александровская, д.74, управление ЗАГС,		0101000020E61000009D9CA1B8E3A13E40DA73999A04034E40
51743	3	29	623	17304	\N	\N	59.952933999999999	Всеволожский район, п.Воейково, Дом культуры,		0101000020E61000008F71C5C551B53E408C9FC6BDF9F94D40
51681	3	29	623	13228	65921	\N	60.253484	"Всеволожский район, д.Верхние Осельки, ул.Ленинградская, д.32, администрация МО ""Лесколовское сельское поселение"","		0101000020E6100000DA54DD239B733E409607E92972204E40
51678	3	29	623	13139	66552	\N	60.375245	Всеволожский район, д. Васкелово ул. Коробицына д.10б Дом культуры		0101000020E61000008C81751C3F583E40677E350708304E40
51658	3	29	623	58942	67069	\N	60.171281661866097	"Всеволожский район, д.Вертимяги Токсовское шоссе д.2 МОБУ ""Агалатовская СОШ"""	Россия, Ленинградская область, Всеволожский район, деревня Вартемяги	0101000020E6100000FF092E56D4503E405D328E91EC154E40
51695	3	29	623	13641	\N	\N	60.085427244671401	Всеволожский район, д.Ваганово, школа,	Россия, Ленинградская область, Всеволожский район, деревня Ваганово	0101000020E610000084D382177D053F4003999D45EF0A4E40
51662	3	29	623	13368	3772	\N	60.066263945142602	"Всеволожский район, п.Бугры, ул.Полевая д.3 МОБУ ""Бугровская СОШ"" актовый зал"	Россия, Ленинградская область, Всеволожский район, посёлок Бугры, Полевая улица	0101000020E6100000570A815CE2643E407973B8567B084E40
51697	3	29	623	13553	\N	\N	60.096905999999997	"Ленинградская область, Всеволожский район, дер.Борисова Грива, п/о Грибное, ООО ""ЖилКомСервис-Рахья"""		0101000020E61000003123BC3D08F53E40A164726A670C4E40
51696	3	29	623	13553	67273	\N	60.096905999999997	Ленинградская область, Всеволожский район, дер.Борисова Грива, Центральная, 65/1 магазин № 29		0101000020E61000003123BC3D08F53E40A164726A670C4E40
51660	3	29	623	13265	\N	\N	60.224814000000002	Всеволожский район, д.Агалатово,военный городок д.161 Дом офицеров		0101000020E610000060C8EA56CF453E406BD784B4C61C4E40
51635	3	29	953	17032	\N	\N	59.951929999999997	Волховский район, дер.Хвалово Хваловский досуговый центр	Россия, Ленинградская область, Волховский район, деревня Хвалово	0101000020E610000011363CBD525E4040670A9DD7D8F94D40
51634	3	29	953	12078	\N	\N	60.101773000000001	Волховский район, дер.Усадище,134 ДК		0101000020E6100000309E4143FF684040D34ECDE5060D4E40
51644	3	29	953	7783	\N	\N	60.147019999999998	Волховский район, г.Сясьстрой, ДК ул. 25 Октября, д.3	Россия, Ленинградская область, Волховский район, Сясьстрой	0101000020E6100000A0FEB3E6C7454040D0ED258DD1124E40
51638	3	29	953	7783	\N	\N	60.147019999999998	Волховский район, г.Сясьстрой, , ПУ-24, Центр, 13		0101000020E6100000A0FEB3E6C7454040D0ED258DD1124E40
51645	3	29	953	7783	67022	\N	60.147019999999998	"Волховский район, г.Сясьстрой, МУП ""Сясьстройский коммунальные системы, 2 этаж, ул. Культуры, д.1а "		0101000020E6100000A0FEB3E6C7454040D0ED258DD1124E40
51640	3	29	953	7783	66127	\N	60.147019999999998	Волховский район, г.Сясьстрой, ул. Космонавтов, д9, дом детского творчества		0101000020E6100000A0FEB3E6C7454040D0ED258DD1124E40
51628	3	29	953	7783	66127	\N	60.147019999999998	Волховский район, г.Сясьстрой, средняя школа № 1, ул. Космонавтов, 11		0101000020E6100000A0FEB3E6C7454040D0ED258DD1124E40
51642	3	29	953	7783	67037	\N	60.147019999999998	Волховский район, г.Сясьстрой, ул. 25 Октября, д.17, средняя школа № 2 Со		0101000020E6100000A0FEB3E6C7454040D0ED258DD1124E40
51544	3	29	953	7783	64960	\N	60.147019999999998	город Сясьстрой, улица Советская, дом 15а	Россия, Ленинградская область, Волховский район, Сясьстрой	0101000020E6100000A0FEB3E6C7454040D0ED258DD1124E40
51597	3	29	953	10324	24397	\N	60.000456	Волховский район, с.Старая Ладога. ул.Советская, д.1		0101000020E6100000396403E962254040228B34F10E004E40
51627	3	29	953	11752	67259	\N	60.231707999999998	Волховский район, д. Сорзуй, ул. Лесная, д.2, администрация		0101000020E6100000556CCCEB88BD40405C1C959BA81D4E40
51636	3	29	953	12190	66241	\N	60.203952999999998	Волховский район, пос.Селиваново, ул. Школьная д.13 (здание муниципального образования бюджетного учреждения Селивановская основная общеобразовательная школа)		0101000020E61000006E895C7006574040E675C4211B1A4E40
51647	3	29	953	12708	67042	\N	60.463512000000001	Волховский район, пос.Свирица ул.Новая Свирица,38 помещение досувого центра		0101000020E6100000DD5F3DEE5B754040DBA6785C543B4E40
51625	3	29	953	11638	\N	\N	60.346302999999999	Волховский район, пос. Рыбежно, Рыбеский СДК		0101000020E6100000E82D1EDE738C4040DBC01DA8532C4E40
51637	3	29	953	12227	\N	\N	60.271917999999999	"Волховский район, дер.Потанино,13-а , МУКиС ""Потанинский СДК"""		0101000020E61000001B84B9DDCB634040CC988235CE224E40
51623	3	29	953	11403	67289	\N	60.398288517610297	Волховский район, село Паша,ул.Юбилейная,4 Пашская средняя школа		0101000020E61000005055A18158824040A3AD4A22FB324E40
51621	3	29	953	11403	24365	\N	60.398033712683102	Волховский район, село Паша,ул.Советская,85 администр Пашский ДУК92	Россия, Ленинградская область, Волховский район, село Паша	0101000020E6100000F20703CFBD814040195932C7F2324E40
51620	3	29	953	11403	24365	\N	60.392538662806899	Волховский район, село Паша,ул.Советская,195 администр Пашского сельского поселения	Россия, Ленинградская область, Волховский район, село Паша	0101000020E6100000CFF57D3848824040C8B3CBB73E324E40
51618	3	29	953	11257	24388	\N	60.104681228875897	город Новая Ладога, проспект Карла Маркса, дом 21	Россия, Ленинградская область, Волховский район, Новая Ладога	0101000020E610000033C2DB83102840409CC1DF2F660D4E40
51617	3	29	953	11257	67104	\N	60.101745999999999	Волховский район, г.Новая Ладога, пр.К.Маркса, д38 ДК		0101000020E6100000B1A6B228EC264040D93F4F03060D4E40
51619	3	29	953	11257	66338	\N	60.101745999999999	Волховский район, г.Новая Ладога, ул. Ленинградская, д.2, Новоладожская  средняя школа № 2		0101000020E6100000B1A6B228EC264040D93F4F03060D4E40
51626	3	29	953	58999	\N	\N	60.312314000000001	Волховский район, д. Николаевщина,д.51		0101000020E6100000A3E6ABE4639B40409E0AB8E7F9274E40
51630	3	29	953	11940	66548	\N	60.107880999999999	Волховский район,  д.Немятово-2 ул.Петровская д.26. (фельшерско-акушерский пункт)		0101000020E6100000ED832C0B262C40400D6E6B0BCF0D4E40
51622	3	29	953	11500	\N	\N	60.421197999999997	Волховский район, д. Надкопанье, Надкопанский клуб		0101000020E6100000634337FB037F4040FF91E9D0E9354E40
51624	3	29	953	58985	\N	\N	60.380607259922598	Волховский район, Лесозаводской филиал Пашского детского сада	Россия, Ленинградская область, Волховский район, посёлок Лесозавод	0101000020E6100000B07614E7A887404078D0ECBAB7304E40
51632	3	29	953	8521	66090	\N	60.025942999999998	"Волховский район, село Колчаново ул. Центральная, д.41, детский санаторий ""Колчаново"" лечебный корпус (1 этаж)"		0101000020E61000006F46CD57C94B4040B247A81952034E40
51631	3	29	953	8521	67202	\N	60.025942999999998	Волховский район, село Колчаново м-н Алексино , д.17, ДК		0101000020E61000006F46CD57C94B4040B247A81952034E40
51596	3	29	953	18948	\N	\N	60.004585949349497	Волховский район, Кисельнинской средней школы	Россия, Ленинградская область, Волховский район, деревня Кисельня	0101000020E610000040F67AF7C71140407E02284696004E40
51629	3	29	953	11830	67248	\N	60.064982000000001	"Волховский район,  д. Иссад, микрорайон ""Центральный"", Д.6 (помещение МУКиС Иссадовского ДК)"		0101000020E6100000AB251DE5602C4040126A865451084E40
51598	3	29	953	10371	65966	\N	59.805472999999999	Волховский район, д.Вындин Остров,ул.Школьная,1а		0101000020E6100000F1660DDE572D4040CF6740BD19E74D40
51600	3	29	953	10401	\N	\N	59.921690151589097	Волховский район, красный уголок станции Волховстрой-1	Россия, Ленинградская область, Волховский район, Волхов, улица Дзержинского	0101000020E6100000D3F9F02C412640406E861BF0F9F54D40
51603	3	29	953	\N	67108	\N	60.217918613429497	"Волховский район, Культурно-спортивный центр""Железнодорожник""пр.Державина,28"	Россия, Ленинградская область, Волховский район	0101000020E6100000EFE6A90EB9554040A91611C5E41B4E40
51609	3	29	953	10401	3086	\N	59.900542999999999	Волховский район, пл.Ленина,1 Дворец Культуры		0101000020E61000000C022B87162D404024D236FE44F34D40
51607	3	29	953	10401	67577	\N	59.934739999999998	Волховский район, ул.Островского,6 дом детского творчества филиал		0101000020E6100000DEE8633E20304040AB21718FA5F74D40
51605	3	29	953	10401	67590	\N	59.925894	Волховский район, ул.Нахимова,1		0101000020E6100000FC6EBA658728404004C8D0B183F64D40
51610	3	29	953	10401	67508	\N	59.898612272315503	Волховский район, ул.Лукьянова ,4 школа №3	Россия, Ленинградская область, Волховский район, Волхов, улица Александра Лукьянова, 4	0101000020E61000004F779E78CE2C404086E5CFB705F34D40
51602	3	29	953	10401	67342	\N	59.924693419152902	Волховский район, Детская школа искусств,ул.Коммунаров,31	Россия, Ленинградская область, Волховский район, Волхов, улица Коммунаров, 31	0101000020E6100000CF66D5E76A27404089EB18575CF64D40
51608	3	29	953	10401	3071	\N	59.902312000000002	Волховский район, Кировский пр.,36 дом детского творчества	Россия, Ленинградская область, Волховский район, Волхов, Кировский проспект, 36	0101000020E610000035CF11F92E2D4040E964A9F57EF34D40
51611	3	29	953	10401	67572	\N	59.898327000000002	"Волховский район, ул.Калинина ,27 унитарное муниципальное предприятие ЖКХ ""Отдых"", "		0101000020E6100000499EEBFB702E4040910E0F61FCF24D40
51606	3	29	953	10401	67585	\N	59.913193999999997	Волховский район, ул.Зеленая,21 типография		0101000020E61000005E4D9EB29A2A4040A3737E8AE3F44D40
51599	3	29	953	10401	67352	\N	59.930187076292697	Волховский район, Волховский строительный колледж,ул.Воронежская,4		0101000020E610000032384A5E9D25404009151C5E10F74D40
51612	3	29	953	10401	3130	\N	59.896639	"Волховский район, ул.Волгоградская,23 гостиница ""Званка"""	Россия, Ленинградская область, Волховский район, Волхов, Волгоградская улица, 23	0101000020E6100000A33D5E48872D4040B9A81611C5F24D40
51616	3	29	953	10401	3155	\N	59.891348999999998	Волховский район, ул.Авиационная,40 курсы управления Го и ЧС		0101000020E6100000F5108DEE202E404041295AB917F24D40
51614	3	29	953	10401	3155	\N	59.894061999999998	Волховский район, ул.Авиационная,33 школа №1,	Россия, Ленинградская область, Волховский район, Волхов, Авиационная улица, 33	0101000020E61000009010E50B5A2E4040554CA59F70F24D40
51633	3	29	953	12019	24340	\N	59.752906000000003	Волховский район, дер.Бережки ул.Песочная ,10 (помещение администрации МО Бережевское)		0101000020E610000082E3326E6A2A4040297B4B395FE04D40
51646	3	29	953	12681	67188	\N	60.098166999999997	Волховский район, пос.Аврово ул.Центральная,5, дом детского творчества	Россия, Ленинградская область, Волховский район, посёлок Аврово, Н37	0101000020E6100000807D74EACA494040F1457BBC900C4E40
51584	3	29	1020	9641	\N	\N	59.464199999999998	Ленинградская область, Волосовский муниципальный район, Каложицкое сельское поселение, д.Ущевицы, Ущевицкая начальная школа - сад		0101000020E6100000334FAE2990013D40CF66D5E76ABB4D40
51579	3	29	1020	9421	\N	\N	59.513345999999999	Ленинградская область, Волосовский муниципальный район, Губаницкое сельское поселение, д.Торосово, Торосовский дом культуры		0101000020E6100000782AE09EE78F3D4026C45C52B5C14D40
51594	3	29	1020	10156	\N	\N	59.487743000000002	Волосовский район, Деревня Терпилицы, здание администрации Терпилицкого сельского поселения.,	Россия, Ленинградская область, Волосовский район, деревня Терпилицы	0101000020E6100000DC9BDF30D15C3D402DEDD45C6EBE4D40
51578	3	29	1020	9378	\N	\N	59.472534000000003	"Ленинградская область, Волосовский муниципальный район, Губаницкое сельское поселение, п.Сумино, здание ЗАО ""Сумино"""	Россия, Ленинградская область, Волосовский район, посёлок Сумино	0101000020E6100000A14D0E9F747A3D40C11F7EFE7BBC4D40
51593	3	29	1020	17662	\N	\N	59.592312	Поселок Сельцо, Сельцовский  Дом   культуры.		0101000020E6100000B0AF75A911863D40A1832EE1D0CB4D40
51582	3	29	1020	9544	\N	\N	59.263038999999999	Ленинградская область, Волосовский муниципальный район, Изварское сельское поселение, д.Реполка, Репольский ДК		0101000020E610000040A20914B1983D4049490F43ABA14D40
51591	3	29	1020	58469	\N	\N	59.406534000000001	Ленинградская область, Волосовский муниципальный район, Рабитицкое сельское поселение, д.Рабитицы, Рабитицкий дом культуры		0101000020E610000062DA37F757633D40255B5D4E09B44D40
51590	3	29	1020	58914	\N	\N	59.385624999999997	"Ленинградская область, Волосовский муниципальный район, Курское сельское поселение, п.Остроговицы, диспетчерская ОАО ""Остроговицы"""		0101000020E61000005F9A22C0E9153D408FC2F5285CB14D40
51589	3	29	1020	9933	\N	\N	59.314228	Ленинградская область, Волосовский муниципальный район, Курское сельское поселение, п.Курск, помещении администрации		0101000020E610000087FA5DD89A213D4066BE839F38A84D40
51586	3	29	1020	9787	\N	\N	59.426478000000003	Ленинградская область, Волосовский муниципальный район, Калитинское сельское поселение, д.Курковицы, здание администрации		0101000020E6100000D26EF4311FAC3D40543BC3D496B64D40
51588	3	29	1020	52928	\N	\N	59.532108999999998	Ленинградская область, Волосовский муниципальный район, Клопицкое сельское поселение, д.Клопицы, помещение администрации	Россия, Ленинградская область, Волосовский район, деревня Клопицы	0101000020E6100000F758FAD005793D402174D0251CC44D40
51587	3	29	1020	9800	64969	\N	59.464182000000001	Ленинградская область, Волосовский муниципальный район, Кикеринское сельское поселение, п.Кикерино, Курковицкое шоссе, Кикеринский дом культуры		0101000020E6100000E8DB82A5BAA03D4029B2D6506ABB4D40
51583	3	29	1020	9621	\N	\N	59.412066000000003	Ленинградская область, Волосовский муниципальный район, Каложицкое сельское поселение, п.Каложицы, Детский дом №1		0101000020E610000068942EFD4B023D4093E52494BEB44D40
51585	3	29	1020	9717	\N	\N	59.408149999999999	Ленинградская область, Волосовский муниципальный район, Калитинское сельское поселение, п.Калитино, Калитинский дом культуры		0101000020E61000002E1EDE7360A53D4063EE5A423EB44D40
51581	3	29	1020	52911	\N	\N	59.345176000000002	Ленинградская область, Волосовский муниципальный район, Изварское сельское поселение, д.Извара, помещение администрации	Россия, Ленинградская область, Волосовский район, деревня Извара	0101000020E6100000BF0D315EF3823D409BAE27BA2EAC4D40
51580	3	29	1020	9446	\N	\N	59.5471	Ленинградская область, Волосовский муниципальный район, Зимитицкое сельское поселение, п.Зимитицы, Зимитицкий дом культуры		0101000020E6100000D845D1031F1F3D4020D26F5F07C64D40
51572	3	29	1020	8888	65048	\N	59.443913000000002	Ленинградская область, Волосовский муниципальный район, Волосовское городское поселение, г.Волосово, усадьба Сельхозтехники, 1		0101000020E610000032AD4D637B7D3D4077A22424D2B84D40
51571	3	29	1020	8888	2534	\N	59.447709000000003	Ленинградская область, Волосовский муниципальный район, Волосовское городское поселение, г.Волосово, проспект Вингиссара, 57	Россия, Ленинградская область, Волосовский район, Волосово, проспект Вингиссара, 57	0101000020E6100000789961A3AC7B3D40FC8F4C874EB94D40
51570	3	29	1020	8888	65002	\N	59.447321000000002	Ленинградская область, Волосовский муниципальный район, Волосовское городское поселение, Красных Партизан, 10/5		0101000020E6100000008BFCFA217E3D4032E884D041B94D40
51567	3	29	1020	8888	65027	\N	59.452987999999998	Ленинградская область, Волосовский муниципальный район, Волосовское городское поселение, г.Волосово, Красных Командиров, 11		0101000020E61000003BC780ECF57E3D407FBDC282FBB94D40
51569	3	29	1020	8888	2504	\N	59.453618255829198	Ленинградская область, Волосовский муниципальный район, Волосовское городское поселение, г.Волосово, Гатчинское шоссе, 10	Россия, Ленинградская область, Волосовский район, Волосово, Гатчинское шоссе, 10	0101000020E61000008672A25D85803D403F70952710BA4D40
51592	3	29	1020	10092	\N	\N	59.136012000000001	Ленинградская область, Волосовский муниципальный район, Сабское сельское поселение, д.Большой Сабск, Сабский дом культуры		0101000020E6100000E4F4F57CCD023D4089EE59D768914D40
51577	3	29	1020	52900	\N	\N	59.4051571803776	Ленинградская область, Волосовский муниципальный район, Большеврудское сельское поселение, д.Большая Вруда, Большеврудская музыкальная школа	Россия, Ленинградская область, Волосовский район, деревня Большая Вруда	0101000020E6100000B6DB2E34D73D3D406C5F402FDCB34D40
51576	3	29	1020	52900	\N	\N	59.405242000000001	Ленинградская область, Волосовский муниципальный район, Большеврудское сельское поселение, д.Большая Вруда, помещение администрации	Россия, Ленинградская область, Волосовский район, деревня Большая Вруда	0101000020E6100000BB7B80EECB3D3D409A7B48F8DEB34D40
51575	3	29	1020	9254	\N	\N	59.359001999999997	Ленинградская область, Волосовский муниципальный район, Беседское сельское поселение, п.Беседа, здание администрации	Россия, Ленинградская область, Волосовский район, посёлок Беседа	0101000020E6100000E4688EACFCF63C406B990CC7F3AD4D40
51574	3	29	1020	9170	\N	\N	59.586418000000002	Ленинградская область, Волосовский муниципальный район, Бегуницкое сельское поселение, д.Бегуницы, Бегуницкая детская школа искусств		0101000020E6100000CCD3B9A294503D4093E4B9BE0FCB4D40
51573	3	29	1020	9170	\N	\N	59.586418000000002	Ленинградская область, Волосовский муниципальный район, Бегуницкое сельское поселение, д.Бегуницы, Бегуницкий ДК		0101000020E6100000CCD3B9A294503D4093E4B9BE0FCB4D40
51551	3	29	906	8118	\N	\N	59.601779999999998	д.Большой Двор, д.30		0101000020E6100000BDA94885B1F9404085B1852007CD4D40
51556	3	29	906	8399	67256	\N	59.517175999999999	Бокситогорский район, Пос. Утишье. Ул. Центральная д17, муниципальный фонд.		0101000020E6100000A070766B99BA41405723BBD232C24D40
51535	3	29	906	58957	\N	\N	59.516519000000002	Бокситогорский район, Дер. Сегла. Д 7 кв25, муниципальный фонд.		0101000020E6100000ECDADE6E49F440409E616A4B1DC24D40
51548	3	29	906	7967	67176	\N	59.34413	Бокситогорский район, С. Сомино. Ул. Ярославская д55, муниципальный фонд.		0101000020E6100000A3EA573A1F6E414047C9AB730CAC4D40
51565	3	29	906	32501	\N	\N	59.505158999999999	Бокситогорский район, пос. Совхозный, д. 11 здание администрации Самойловского сельского поселения		0101000020E61000008481E7DEC3234140D923D40CA9C04D40
51564	3	29	906	58983	\N	\N	59.910465000000002	Бокситогорский район, дер. Сидорово, администрация.		0101000020E6100000770FD07D398B41408A93FB1D8AF44D40
51552	3	29	906	58977	\N	\N	59.486179999999997	Бокситогорский район, п. Сельхозтехника. Д.16 здание детского дома.		0101000020E6100000CB86359545E7404011FC6F253BBE4D40
51563	3	29	906	46215	\N	\N	59.781143	д.Радогощь, д.9		0101000020E61000009702D2FE076E4140EA3F6B7EFCE34D40
51538	3	29	906	7425	66133	\N	59.518185000000003	Бокситогорский район, г. Пикалево. Ул. Школьная д 40, школа №4 им. А.П Румянцева.		0101000020E6100000E7C3B304191541408E23D6E253C24D40
51537	3	29	906	7425	66133	\N	59.518185000000003	"Бокситогорский район, г. Пикалево. Ул. Школьная д 38, АОУВПО ""ЛГУ им А.С. Пушкина"		0101000020E6100000E7C3B304191541408E23D6E253C24D40
51540	3	29	906	7425	65674	\N	59.518318679501903	Бокситогорский район, г. Пикалево. Ул. Советская д 21, МАУ Хоз.-экспл.служба.		0101000020E61000007CF0DAA50D1541409DF2E84658C24D40
51536	3	29	906	7425	65674	\N	59.518185000000003	Бокситогорский район, г. Пикалево. Ул. Советская д 24, Пикалевкий дом детского творчества.		0101000020E6100000E7C3B304191541408E23D6E253C24D40
51539	3	29	906	7425	67200	\N	59.518185000000003	Бокситогорский район, г. Пикалево. Пл. Комсомола д1, Дворец культуры г. Пикалево.		0101000020E6100000E7C3B304191541408E23D6E253C24D40
51543	3	29	906	7425	65816	\N	59.518185000000003	Бокситогорский район, г. Пикалево. Ул. Металлургов д13, Детская библиотека.		0101000020E6100000E7C3B304191541408E23D6E253C24D40
51541	3	29	906	7425	66376	\N	59.518185000000003	Бокситогорский район, г. Пикалево. Ул. Заводская д21, школа №2		0101000020E6100000E7C3B304191541408E23D6E253C24D40
51542	3	29	906	7425	67252	\N	59.518185000000003	Бокситогорский район, г.Пикалево. 5-й микрорайон д5, школа №3		0101000020E6100000E7C3B304191541408E23D6E253C24D40
51557	3	29	906	8436	\N	\N	59.696071435632	Бокситогорский район, Дер. Ольеши. Д22, Здание Админ. Посиления.	Россия, Ленинградская область, Бокситогорский район, деревня Ольеши	0101000020E61000003C6BB75D68B44140D658C2DA18D94D40
51562	3	29	906	59000	\N	\N	59.465417000000002	Лен.обл, Бокситогорский район, д.Озеро-Село, адрес помещения для голосования: д.1, адрес УИК:ул.Советская, д.1		0101000020E610000049B9FB1C1F8941405000C5C892BB4D40
51566	3	29	906	8837	\N	\N	59.4980367187026	Бокситогорский район, Пос Коли. Д11, школа.	Россия, Ленинградская область, Бокситогорский район, посёлок Коли	0101000020E6100000AC55BB26A43F4140569929ADBFBF4D40
51559	3	29	906	8529	\N	\N	59.194904999999999	Лен.обл, Бокситогорский район, д.Климово, адрес помещения для голосования: д.33, адрес УИК:, д.38		0101000020E6100000098B8A389D584140D769A4A5F2984D40
51555	3	29	906	8329	24395	\N	59.518149000000001	п.Заборье, ул.Школьная, д.24		0101000020E6100000DF32A7CB629C414041BAD8B452C24D40
94424	3	29	906	8329	67006	\N	59.518149000000001	"Бокситогорский район, пос. Заборье ул. Киевская д2-А., Админ. Здание ЛОГУ ""ЛенОблЛес"""		0101000020E6100000DF32A7CB629C414041BAD8B452C24D40
51560	3	29	906	8572	\N	\N	59.351970999999999	Лен.обл, Бокситогорский район, д.Журавлево, адрес помещения для голосования: д.44, адрес УИК:, д.38		0101000020E61000006C76A4FACE5B4140F911BF620DAD4D40
51546	3	29	906	59007	67247	\N	59.496792999999997	Бокситогорский район, Пос. Ефимовский. Ул. Школьная д5, Школа интернат для дитей-сирот.		0101000020E61000004DBB9866BA554140DCF0BBE996BF4D40
51547	3	29	906	59007	67618	\N	59.498756865161099	Бокситогорский район, г. Пос. Ефимовский. Ул. Сенная д15, Ефимовская средне образовательная.	Россия, Ленинградская область, Бокситогорский район, городской посёлок Ефимовский	0101000020E610000071FF91E9D055414056D3F544D7BF4D40
51545	3	29	906	51017	24374	\N	59.496792999999997	Бокситогорский район, Пос. Ефимовский. Ул. Комсомольская д13, Культурно-досуговый центр.		0101000020E61000004DBB9866BA554140DCF0BBE996BF4D40
51550	3	29	906	8082	\N	\N	59.569805000000002	Бокситогорский район, Дер. Дыми д4 кв.1, муницыпальный фонд.		0101000020E61000007099D36531E54040740CC85EEFC84D40
51531	3	29	906	7109	1944	\N	59.465828000000002	Бокситогорский район, г. Бокситогорск  ул. Южная д23. ГОУ ПУ-№27		0101000020E61000005456D3F544ED4040D2C77C40A0BB4D40
51533	3	29	906	7109	67608	\N	59.474001000000001	Бокситогорский район, г. Бокситогорск  ул.Школьная д13, Бокситогорская гимназия.		0101000020E6100000B08C0DDDECEB4040BAA29410ACBC4D40
51534	3	29	906	7109	67535	\N	59.475853000000001	Бокситогорский район, г. Бокситогорск  ул. Вишнякова д22, Лен. Гос. Университет им. Пушкина.		0101000020E61000008655BC9179EC40400C5A48C0E8BC4D40
37704	3	28	\N	7525	23161	\N	55.072916999999997	город Советск, Школьная, 13		0101000020E610000020EC14AB06E135404529215855894B40
37697	3	28	\N	7525	23018	\N	55.072916999999997	город Советск, Чапаева, 17		0101000020E610000020EC14AB06E135404529215855894B40
37703	3	28	\N	7525	23114	\N	55.062329413472902	город Советск, Липовая, 2	Россия, Калининградская область, Советск	0101000020E61000007976F9D687E93540D34B8C65FA874B40
37698	3	28	\N	7525	23249	\N	55.082854311198403	город Советск, Кировоградская, 6	Россия, Калининградская область, Советск	0101000020E610000028486C770FE03540E02BBAF59A8A4B40
37709	3	28	\N	7525	23164	\N	55.072916999999997	город Советск, Калининградское шоссе, 16		0101000020E610000020EC14AB06E135404529215855894B40
37699	3	28	\N	7525	23302	\N	55.072916999999997	город Советск, К.Маркса, 2		0101000020E610000020EC14AB06E135404529215855894B40
37708	3	28	\N	7525	23258	\N	55.072916999999997	город Советск, К.Лямина, 4		0101000020E610000020EC14AB06E135404529215855894B40
37705	3	28	\N	7525	23041	\N	55.072916999999997	город Советск, Искры, 5		0101000020E610000020EC14AB06E135404529215855894B40
37707	3	28	\N	7525	23256	\N	55.072916999999997	город Советск, Бурова, 4		0101000020E610000020EC14AB06E135404529215855894B40
37701	3	28	\N	7525	23113	\N	55.077364076850699	город Советск, Баумана, 6	Россия, Калининградская область, Советск	0101000020E610000005E10A28D4E33540A2F14410E7894B40
37668	3	28	\N	5894	23223	\N	54.680211999999997	Калининградская область, город Светлый, ул.Советская, д.3		0101000020E6100000E08442041C223440622CD32F11574B40
37672	3	28	\N	5894	23332	\N	54.680211999999997	Калининградская область, город Светлый, ул.Рыбацкая, д.1		0101000020E6100000E08442041C223440622CD32F11574B40
37676	3	28	\N	5894	23071	\N	54.680211999999997	Калининградская область, город Светлый, ул.Пионерская, д.26		0101000020E6100000E08442041C223440622CD32F11574B40
37675	3	28	\N	5894	23150	\N	54.6705624052045	Калининградская область, город Светлый, ул.Парковая, д.4	Россия, Калининградская область, Светлый	0101000020E610000000E48409A32134405DF8C1F9D4554B40
37667	3	28	\N	5894	23056	\N	54.680211999999997	Калининградская область, город Светлый, ул.Молодежная, д.6		0101000020E6100000E08442041C223440622CD32F11574B40
37678	3	28	\N	5894	24177	\N	54.698208000000001	Калининградская область, поселокВзморье, ул.Лопатина, д.10		0101000020E61000005610035DFB3E34401DE736E15E594B40
37674	3	28	\N	5894	23259	\N	54.6712389322037	Калининградская область, город Светлый, ул.Коммунистическая, д.7	Россия, Калининградская область, Светлый	0101000020E61000000BD3F71A821F34405E66D828EB554B40
37670	3	28	\N	5894	23160	\N	54.680211999999997	Калининградская область, город Светлый, ул.Калининградская, д.11		0101000020E6100000E08442041C223440622CD32F11574B40
37671	3	28	\N	5894	23040	\N	54.680211999999997	Калининградская область, город Светлый, ул. Калинина, д.2		0101000020E6100000E08442041C223440622CD32F11574B40
37666	3	28	\N	5894	23040	\N	54.680211999999997	Калининградская область, город Светлый, ул.Калинина, д.2		0101000020E6100000E08442041C223440622CD32F11574B40
37669	3	28	\N	5894	23331	\N	54.680211999999997	Калининградская область, город Светлый, ул.Заводская, д.2		0101000020E6100000E08442041C223440622CD32F11574B40
37673	3	28	\N	5894	23255	\N	54.680211999999997	Калининградская область, город Светлый, ул.Восточная, д.1		0101000020E6100000E08442041C223440622CD32F11574B40
37659	3	28	\N	50985	24334	\N	54.9451306316912	"Калининградская область, Светлогорский муниципальный район, городское поселение ""Город Светлогорск"", Яблоневая (МАУ ""Дворец спорта"" ""Аквамарин""), 13"	Россия, Калининградская область, Светлогорск	0101000020E610000042226DE34F283440C8B7770DFA784B40
37658	3	28	\N	50985	24335	\N	54.940922494567999	"Калининградская область, Светлогорский муниципальный район, городское поселение ""Город Светлогорск"", Новая (МОУ СОШ №1), 3"	Россия, Калининградская область, Светлогорск	0101000020E61000008BE1EA0088273440200BD12170784B40
37361	3	28	\N	47440	67635	\N	54.735506000000001	г.Приморск ул.Железнодорожная 8,  Дом культур		0101000020E61000001E4FCB0F5C0134408201840F255E4B40
37628	3	28	\N	3708	23086	\N	54.951467407063703	Калининградская область, Пионерский городской округ, Флотская, 20	Россия, Калининградская область, Пионерский	0101000020E61000005B0C1EA67D3B3440931CB0ABC9794B40
37627	3	28	\N	3708	23086	\N	54.944968339743397	Калининградская область, Пионерский городской округ, Флотская, 2	Россия, Калининградская область, Пионерский	0101000020E61000000C3B8C497F3734401EE21FB6F4784B40
37630	3	28	\N	3708	22974	\N	54.950007590012298	Калининградская область, Пионерский городской округ, Рензаева, 26	Россия, Калининградская область, Пионерский	0101000020E61000008CBAD6DEA73A34401C78B5DC99794B40
37626	3	28	\N	3708	24332	\N	54.952982265738697	Калининградская область, Пионерский городской округ, Комсомольская, 4	Россия, Калининградская область, Пионерский	0101000020E610000072FE2614223C34409DD66D50FB794B40
37629	3	28	\N	3708	24257	\N	54.947490449242999	Калининградская область, Пионерский городской округ, Гагарина, 14	Россия, Калининградская область, Пионерский	0101000020E6100000B935E9B6443A3440BEA4315A47794B40
37625	3	28	\N	3708	23186	\N	54.949947000000002	Калининградская область, город Пионерский, ул.Армейская, 1		0101000020E610000057EC2FBB273B344077F700DD97794B40
37580	3	28	\N	50968	24172	\N	55.033155999999998	Калининградская область, Неманский район, г.Неман, Первомайская, 10		0101000020E6100000FFD0CC936B0A364045D5AF743E844B40
37677	3	28	\N	6464	23122	\N	54.753700000000002	Калининградская область, ,поселок Люблино, ул.Гарнизонная, д.2		0101000020E610000076FF58880E493440637FD93D79604B40
14642	3	28	\N	56665	55468	\N	54.629246999999999	Коса, начальная школа    ул.Школьная 18-А	Россия, Калининградская область, поселок Коса	0101000020E6100000D0EE906280E03340950D6B2A8B504B40
37528	3	28	\N	1269	24181	\N	54.681298203925699	город Калининград, Подполковника Емельянова, 312	Россия, Калининградская область, Калининград, улица Емельянова	0101000020E6100000284701A260963440446ADAC534574B40
37468	3	28	\N	1269	7195	\N	54.698348000000003	город Калининград, Багратиона, 105А	Россия, Калининградская область, Калининград, улица Багратиона, 105	0101000020E610000046B1DCD26A8034400F9D9E7763594B40
37532	3	28	\N	1269	24308	\N	54.719492000000002	Калининградская область, город Калининград, Центральный район, Бассейная, 40		0101000020E610000055A4C2D842743440E8DD5850185C4B40
37497	3	28	\N	1269	7491	\N	54.732391999999997	город Калининград, Артиллерийская, 18	Россия, Калининградская область, Калининград, улица Артиллерийская, 16	0101000020E610000073B9C150878934400FED6305BF5D4B40
37500	3	28	\N	1269	7422	\N	54.735157000000001	город Калининград, Ал. Невского, 89	Россия, Калининградская область, Калининград, улица Александра Невского, 89	0101000020E6100000B63176C24B8834407636E49F195E4B40
37530	3	28	\N	1269	24238	\N	54.717942999999998	Калининградская область, город Калининград, Центральный район, сержанта Колоскова, 10		0101000020E6100000494739984D7C344031B2648EE55B4B40
37534	3	28	\N	1269	23334	\N	54.723175192466599	Калининградская область, город Калининград, Центральный район, проспект Мира, 136	Россия, Калининградская область, Калининград, улица Карла Маркса, 142	0101000020E6100000FFE89B340D763440742497FF905C4B40
37510	3	28	\N	1269	24279	\N	54.744976000000001	город Калининград, Полковника Ефремова, 10		0101000020E610000044C02154A98134400727A25F5B5F4B40
37490	3	28	\N	1269	24255	\N	54.717403729305602	город Калининград, Подполковника Иванникова, 6	Россия, Калининградская область, Калининград, улица подполковника Иванникова	0101000020E61000002235ED629A8134408202EFE4D35B4B40
37478	3	28	\N	1269	7277	\N	54.707841999999999	город Калининград, наб. Маршала Баграмяна, 34	Россия, Калининградская область, Калининград, маршала Баграмяна набережная, 34	0101000020E61000004B5CC7B8E27E34401C5E10919A5A4B40
37477	3	28	\N	1269	7277	\N	54.707213000000003	город Калининград, наб. Маршала Баграмяна, 2	Россия, Калининградская область, Калининград, маршала Баграмяна набережная, 2	0101000020E6100000F6D37FD6FC8034402D27A1F4855A4B40
37556	3	28	\N	1269	24312	\N	54.729568999999998	Калининградская область, город Калининград, Центральный район, лейтенанта Яналова, 42		0101000020E61000003A9677D5037A344074965984625D4B40
14655	3	28	\N	1269	67678	\N	54.716658000000002	город Калининград, Соммера, 23		0101000020E610000096CCB1BCAB82344059350873BB5B4B40
37486	3	28	\N	1269	23244	\N	54.7264798143813	город Калининград, Ген.-лейт. Озерова, 57	Россия, Калининградская область, Калининград, улица генерал-Лейтенанта Озерова, 57	0101000020E6100000C58EC6A17E8334405B99F04BFD5C4B40
37493	3	28	\N	1269	24329	\N	54.721387024759302	город Калининград, Ю. Гагарина, 55	Россия, Калининградская область, Калининград, улица Юрия Гагарина, 55	0101000020E6100000713C9F01F58A34403961C268565C4B40
37520	3	28	\N	1269	24294	\N	54.703482999999999	город Калининград, Эпроновская, 31		0101000020E61000002A711DE38A8334405F251FBB0B5A4B40
37522	3	28	\N	1269	24297	\N	54.686394999999997	город Калининград, Черниговская, 37		0101000020E6100000C687D9CBB6873440A79196CADB574B40
37551	3	28	\N	1269	24285	\N	54.725717000000003	Калининградская область, город Калининград, Центральный район, Чайковского, 50/52		0101000020E6100000BD732843557C34405C936E4BE45C4B40
37606	3	28	\N	1269	15846	\N	54.710360000000001	п. Садовое, Центральная, 34а	Россия, Калининградская область, Калининград, Ленинградский район, Центральная площадь	0101000020E6100000A12E52280B8334407B319413ED5A4B40
37479	3	28	\N	1269	24256	\N	54.712128	город Калининград, Фрунзе, 46		0101000020E61000004CFE277FF78634406F48A302275B4B40
37525	3	28	\N	1269	23065	\N	54.666811002360603	город Калининград, У.Громовой, 67	Россия, Калининградская область, Калининград, улица Ульяны Громовой, 67	0101000020E6100000844BC79C6780344079CE16105A554B40
37471	3	28	\N	1269	23065	\N	54.674260435142102	город Калининград, У.Громовой, 1	Россия, Калининградская область, Калининград, улица Ульяны Громовой	0101000020E610000054008C67D08034401F80D4264E564B40
14653	3	28	\N	1269	2323	\N	54.693966265491099	город Калининград, Транспортный тупик, 10	Россия, Калининградская область, Калининград, Транспортный тупик	0101000020E6100000BAF94674CF7234409A44BDE0D3584B40
37481	3	28	\N	1269	24280	\N	54.7145297714195	город Калининград, Томская, 19	Россия, Калининградская область, Калининград, улица Угловая, 19	0101000020E6100000D042024697873440650113B8755B4B40
37535	3	28	\N	1269	7907	\N	54.715155000000003	Калининградская область, город Калининград, Центральный район, Тенистая аллея, 35	Россия, Калининградская область, Калининград, Тенистая аллея, 35	0101000020E61000003A24B550326D34401349F4328A5B4B40
37503	3	28	\N	1269	24293	\N	54.736291000000001	город Калининград, Тельмана, 48		0101000020E610000017F373435386344069AB92C83E5E4B40
37466	3	28	\N	1269	24248	\N	54.681083731726801	город Калининград, Судостроительная, 2	Россия, Калининградская область, Калининград, улица Судостроительная	0101000020E6100000D26EF4311F7C344018EAB0C22D574B40
37470	3	28	\N	1269	23235	\N	54.692610775819603	город Калининград, А.Суворова, 37	Россия, Калининградская область, Калининград, улица Суворова	0101000020E6100000917D9065C1783440C8EC2C7AA7584B40
37456	3	28	\N	1269	23235	\N	54.672444840133799	город Калининград, А.Суворова, 139А		0101000020E6100000FE47A643A76F3440EBAD81AD12564B40
37537	3	28	\N	1269	24220	\N	54.717283680664501	Калининградская область, город Калининград, Центральный район, Карташева, 111	Россия, Калининградская область, Калининград, Октябрьский район	0101000020E6100000105839B4C85E3440D7F84CF6CF5B4B40
37540	3	28	\N	1269	24265	\N	54.724572999999999	Калининградская область, город Калининград, Центральный район, Спортивная, 11		0101000020E6100000FB213658387534404548DDCEBE5C4B40
37559	3	28	\N	1269	24269	\N	54.738301999999997	Калининградская область, город Калининград, Центральный район, Солдатская, 7		0101000020E61000005C57CC086F7B3440234910AE805E4B40
37515	3	28	\N	1269	24261	\N	54.743650000000002	город Калининград, Согласия, 39		0101000020E6100000A69883A0A37D3440D0D556EC2F5F4B40
37554	3	28	\N	1269	2065	\N	54.728982000000002	Калининградская область, город Калининград, Центральный район, проспект Советский, 48	Россия, Калининградская область, Калининград, Советский проспект, 48	0101000020E6100000DBC01DA8537E3440B4AF3C484F5D4B40
37552	3	28	\N	1269	2065	\N	54.724729000000004	Калининградская область, город Калининград, Центральный район, проспект Советский, 13	Россия, Калининградская область, Калининград, Советский проспект, 13	0101000020E6100000687A89B14C7F34403DBB7CEBC35C4B40
37548	3	28	\N	1269	2065	\N	54.720647	Калининградская область, город Калининград, Центральный район, проспект Советский, 1	Россия, Калининградская область, Калининград, Советский проспект, 1	0101000020E6100000F2CD3637A67F3440F27A30293E5C4B40
37523	3	28	\N	1269	7800	\N	54.678598999999998	город Калининград, Аллея Смелых, 118	Россия, Калининградская область, Калининград, Смелых аллея, 118	0101000020E610000049DBF81395853440950C0055DC564B40
37484	3	28	\N	1269	24323	\N	54.717548000000001	город Калининград, Сергеева, 10		0101000020E6100000354580D3BB843440B5A7E49CD85B4B40
37472	3	28	\N	1269	24277	\N	54.710448	город Калининград, Свердлова, 27		0101000020E6100000A4897780279134401AC1C6F5EF5A4B40
37533	3	28	\N	1269	24326	\N	54.712263999999998	Калининградская область, город Калининград, Центральный район, Радищева, 81		0101000020E6100000BBB72231417534401F0F7D772B5B4B40
37531	3	28	\N	1269	24301	\N	54.717319000000003	Калининградская область, город Калининград, Центральный район, Пушкина, 10		0101000020E61000003FC4060B2779344054E6E61BD15B4B40
37485	3	28	\N	1269	24317	\N	54.717418000000002	город Калининград, Пролетарская, 66а		0101000020E6100000AF93FAB2B4833440E7C75F5AD45B4B40
14657	3	28	\N	1269	23127	\N	54.681625738076903	город Калининград, Подполковника Емельянова, 156	Россия, Калининградская область, Калининград, улица Емельянова, 156	0101000020E61000006138D730438F3440390D51853F574B40
37482	3	28	\N	1269	24267	\N	54.715621031883103	город Калининград, Пионерская, 9	Россия, Калининградская область, Калининград, улица Пионерская	0101000020E61000008D2782380F87344058AA0B78995B4B40
37459	3	28	\N	1269	16399	\N	54.679327000000001	город Калининград, Октябрьская площадь, 36	Россия, Калининградская область, Калининград, Балтийский район, Октябрьская площадь, 35	0101000020E6100000D0285DFA977834401825E82FF4564B40
37506	3	28	\N	1269	24324	\N	54.739555000000003	город Калининград, Озерная, 31		0101000020E61000005E4D9EB29A823440F14BFDBCA95E4B40
37516	3	28	\N	1269	24313	\N	54.703108999999998	город Калининград, Новый вал, 23		0101000020E610000016DBA4A2B1823440FA42C879FF594B40
37526	3	28	\N	1269	24318	\N	54.666665999999999	город Калининград, Н.Карамзина, 11		0101000020E6100000670C73823681344075ADBD4F55554B40
37488	3	28	\N	1269	7260	\N	54.710134635718802	город Калининград, Московский проспект, 39	Россия, Калининградская область, Калининград, Московский проспект, 39	0101000020E6100000029EB470598134405B5F24B4E55A4B40
37476	3	28	\N	1269	7260	\N	54.708347000000003	город Калининград, Московский проспект, 60-62	Россия, Калининградская область, Калининград, Московский проспект, 62	0101000020E61000005F45460724853440209C4F1DAB5A4B40
37475	3	28	\N	1269	7260	\N	54.708919000000002	город Калининград, Московский проспект, 98а	Россия, Калининградская область, Калининград, Московский проспект, 98	0101000020E61000003D62F4DC42873440AB4198DBBD5A4B40
37494	3	28	\N	1269	24311	\N	54.726756000000002	город Калининград, Молодой Гвардии, 2		0101000020E6100000297AE063B08E3440FD153257065D4B40
37505	3	28	\N	1269	24305	\N	54.739581000000001	город Калининград, Молодежная, 7		0101000020E6100000D61F6118B08434401ADF1797AA5E4B40
37561	3	28	\N	1269	24170	\N	54.718882214688598	Калининградская область, город Калининград, Центральный район, Мира, 1		0101000020E6100000F9484A7A187E34406FD74B53045C4B40
37524	3	28	\N	1269	24299	\N	54.678244999999997	город Калининград, Машиностроительная, 66		0101000020E6100000E7FD7F9C3081344077D66EBBD0564B40
37446	3	28	\N	1269	24328	\N	54.679889000000003	город Калининград, Маршала Новикова, 5		0101000020E6100000CC46E7FC147B344080F44D9A06574B40
37539	3	28	\N	1269	23130	\N	54.747917000000001	Калининградская область, город Калининград, Центральный район, Магнитогорская, 4		0101000020E6100000E544BB0A296F3440AC8F87BEBB5F4B40
37529	3	28	\N	1269	2362	\N	54.671925000000002	город Калининград, Л.Шевцовой, 49	Россия, Калининградская область, Калининград, Любы Шевцовой бульвар, 49	0101000020E61000008867093202823440B22E6EA301564B40
14656	3	28	\N	1269	2362	\N	54.671810000000001	город Калининград, Л.Шевцовой, 39	Россия, Калининградская область, Калининград, Любы Шевцовой бульвар, 39	0101000020E6100000C4CE143AAF8134401990BDDEFD554B40
37474	3	28	\N	1269	24258	\N	54.718952000000002	город Калининград, Литовский вал, 27а	Россия, Калининградская область, Калининград, улица Литовский Вал, 32	0101000020E61000009E7B0F971C87344068B27F9E065C4B40
37460	3	28	\N	1269	24249	\N	54.672418999999998	город Калининград, Летняя, 48		0101000020E610000088F71C588E7C3440C11A67D311564B40
37492	3	28	\N	1269	24252	\N	54.727245000000003	город Калининград, Куйбышева, 15		0101000020E61000006117450F7C883440FB96395D165D4B40
37560	3	28	\N	1269	24239	\N	54.745458439796799	Калининградская область, город Калининград, Центральный район, Красная, 301	Россия, Калининградская область, Калининград, улица Красная	0101000020E6100000234DBC033C7934405245F12A6B5F4B40
37557	3	28	\N	1269	24239	\N	54.737147999999998	Калининградская область, город Калининград, Центральный район, Красная, 119	Россия, Калининградская область, Калининград, улица Красная, 119	0101000020E6100000FA62EFC517793440E9279CDD5A5E4B40
37555	3	28	\N	1269	24302	\N	54.731394000000002	Калининградская область, город Калининград, Центральный район, Комсомольская, 67		0101000020E6100000971E4DF5647A3440CD3E8F519E5D4B40
37480	3	28	\N	1269	24321	\N	54.713755999999997	город Калининград, Клиническая, 21		0101000020E6100000DBF97E6ABC84344071A94A5B5C5B4B40
37550	3	28	\N	1269	24229	\N	54.726855	Калининградская область, город Калининград, Центральный район, Кирова, 26		0101000020E610000044FCC3961E7D344090F7AA95095D4B40
37496	3	28	\N	1269	24251	\N	54.725673429317503	город Калининград, Ал. Невского, 14	Россия, Калининградская область, Калининград, улица Александра Невского	0101000020E610000020D5B0DF138734408C4B55DAE25C4B40
37549	3	28	\N	1269	24229	\N	54.7244426204172	Калининградская область, город Калининград, Центральный район, Кирова, 7	Россия, Калининградская область, Калининград, улица Кирова	0101000020E61000006C21C841097F34407768588CBA5C4B40
37467	3	28	\N	1269	24245	\N	54.686155999999997	город Калининград, Киевская, 17		0101000020E6100000399D64ABCB7D344022FAB5F5D3574B40
37558	3	28	\N	1269	24276	\N	54.733432000000001	Калининградская область, город Калининград, Центральный район, Каштановая аллея, 147		0101000020E6100000F22895F08476344081EB8A19E15D4B40
37542	3	28	\N	1269	24276	\N	54.730437000000002	Калининградская область, город Калининград, Центральный район, Каштановая аллея, 141		0101000020E6100000774B72C0AE763440E964A9F57E5D4B40
37543	3	28	\N	1269	24325	\N	54.723813999999997	Калининградская область, город Калининград, Центральный район, Карла Маркса, 65		0101000020E61000002C9FE579707734408731E9EFA55C4B40
37457	3	28	\N	1269	23335	\N	54.6805194740244	город Калининград, Камская, 4	Россия, Калининградская область, Калининград, улица Камская	0101000020E61000004D4BAC8C467634403FA7203F1B574B40
37461	3	28	\N	1269	24272	\N	54.673315000000002	город Калининград, Л.Иванихиной, 9		0101000020E6100000D9CF6229927F34400074982F2F564B40
37547	3	28	\N	1269	24274	\N	54.721234000000003	Калининградская область, город Калининград, Центральный район, Зоологическая, 2		0101000020E610000011AB3FC2307C3440B3614D65515C4B40
37521	3	28	\N	1269	24307	\N	54.684569000000003	город Калининград, З.Космодемьянской, 26		0101000020E610000008E6E8F17B8734407F6DFDF49F574B40
14647	3	28	\N	1269	24264	\N	54.6786300421535	город Калининград, поселок Прибрежный, Заводская, 26		0101000020E6100000FBCA83F414713440D00A0C59DD564B40
37553	3	28	\N	1269	8084	\N	54.727255999999997	Калининградская область, город Калининград, Центральный район, переулок Желябова, 9	Россия, Калининградская область, Калининград, Желябова переулок, 7	0101000020E610000055A18158367F3440EEE87FB9165D4B40
37462	3	28	\N	1269	24268	\N	54.686269890535399	город Калининград, Дюнная, 18	Россия, Калининградская область, Калининград, улица Дюнная, 14	0101000020E61000000762D9CC21853440EB1C03B2D7574B40
37463	3	28	\N	1269	24250	\N	54.678629999999998	город Калининград, Дрожжевая, 1		0101000020E610000066A3737E8A7F3440D00A0C59DD564B40
37527	3	28	\N	1269	24291	\N	54.671937395506703	город Калининград, Дзержинского, 163	Россия, Калининградская область, Калининград, улица Дзержинского	0101000020E6100000774EB340BB8B344076FC170802564B40
37511	3	28	\N	1269	24271	\N	54.742195000000002	город Калининград, Горького, 166		0101000020E61000006FBDA607058134409B20EA3E005F4B40
37504	3	28	\N	1269	24271	\N	54.735812000000003	город Калининград, Горького, 113		0101000020E61000001A4F04711E8234408F006E162F5E4B40
37487	3	28	\N	1269	24271	\N	54.729194999999997	город Калининград, Горького, 66		0101000020E61000001A187959138334400FB40243565D4B40
37509	3	28	\N	1269	24270	\N	54.751314999999998	город Калининград, Герцена, 35		0101000020E610000070D05E7D3C88344043FF04172B604B40
37514	3	28	\N	1269	24330	\N	54.736829045388802	город Калининград, Гайдара, 87		0101000020E61000008CBAD6DEA77E344048DFA469505E4B40
37489	3	28	\N	1269	24228	\N	54.712035	город Калининград, Вагнера, 51		0101000020E6100000433D7D04FE803440BE4D7FF6235B4B40
37458	3	28	\N	1269	24202	\N	54.679402105908402	город Калининград, Березовая, 2	Россия, Калининградская область, Калининград, улица Камская	0101000020E6100000B70C384BC9763440236B0DA5F6564B40
37464	3	28	\N	1269	24292	\N	54.678645000000003	город Калининград, Батальная, 11		0101000020E610000097E2AAB2EF7E3440064CE0D6DD564B40
37536	3	28	\N	1269	24196	\N	54.747917000000001	Калининградская область, город Калининград, Центральный район, Балтийское шоссе, 110		0101000020E6100000E544BB0A296F3440AC8F87BEBB5F4B40
37473	3	28	\N	1269	24352	\N	54.706952999999999	город Калининград, Бакинская, 13		0101000020E610000006DA1D520C9034409067976F7D5A4B40
37502	3	28	\N	1269	24242	\N	54.747323120885	город Калининград, Ал. Невского, 165	Россия, Калининградская область, Калининград, улица Александра Невского	0101000020E6100000043BFE0B048934403946B247A85F4B40
37499	3	28	\N	1269	24242	\N	54.725841000000003	город Калининград, Ал.Невского, 14		0101000020E61000001E6D1CB116873440488C9E5BE85C4B40
37546	3	28	\N	1269	24309	\N	54.722549999999998	Калининградская область, город Калининград, Центральный район, космонавта Леонова, 6		0101000020E61000002E008DD2A57B3440C6DCB5847C5C4B40
37498	3	28	\N	1269	24304	\N	54.721311999999998	город Калининград, Ю.Гагарина, 55		0101000020E6100000C93CF207038B34402E1B9DF3535C4B40
37435	3	28	\N	1269	24315	\N	54.683132000000001	город Калининград, Школьная, 3		0101000020E6100000A9DDAF027C7B3440F06C8FDE70574B40
37544	3	28	\N	1269	24289	\N	54.726194999999997	Калининградская область, город Калининград, Центральный район, Чернышевского, 56а		0101000020E610000037AAD381AC77344065C22FF5F35C4B40
37469	3	28	\N	1269	24316	\N	54.701355	город Калининград, Серпуховская, 23		0101000020E61000001E17D522A28034406BF12900C6594B40
14654	3	28	\N	1269	67675	\N	54.711348000000001	город Калининград, С. Тюленина, 4		0101000020E610000099F221A81A8534409A0986730D5B4B40
37517	3	28	\N	1269	24314	\N	54.701059000000001	город Калининград, Мореходная, 3		0101000020E610000037DE1D19AB81344082C8224DBC594B40
14627	3	28	\N	1269	67679	\N	54.713552999999997	Калининградская область, город Калининград, Центральный район, Менделеева, 13		0101000020E6100000828E56B5A46F3440397B67B4555B4B40
37495	3	28	\N	1269	24287	\N	54.726213285088697	город Калининград, Куйбышева, 91а		0101000020E61000009D121093708934400C772E8CF45C4B40
37541	3	28	\N	1269	24283	\N	54.729101	Калининградская область, город Калининград, Центральный район, Кропоткина, 8/10		0101000020E610000073BD6DA6427834408E3D7B2E535D4B40
14631	3	28	\N	1269	67672	\N	54.721656000000003	Калининградская область, город Калининград, Центральный район, ул. Комсомольская, 4		0101000020E6100000444DF4F9287B3440297B4B395F5C4B40
37513	3	28	\N	1269	24290	\N	54.738739000000002	город Калининград, Зеленая, 18а		0101000020E610000055302AA913803440CFA3E2FF8E5E4B40
37512	3	28	\N	1269	24290	\N	54.739294999999998	город Калининград, Зеленая, 45		0101000020E610000008E412471E803440548CF337A15E4B40
37538	3	28	\N	1269	24319	\N	54.731144	Калининградская область, город Калининград, Центральный район, Войнич, 1		0101000020E610000011C8258E3C7C344054556820965D4B40
37414	3	28	\N	50975	24180	\N	54.591190770205401	г.Гусев, пр.Ленина, 21	Россия, Калининградская область, Гусевский район, Гусев	0101000020E6100000CFD8976C3C34364043588D25AC4B4B40
37419	3	28	\N	50975	24184	\N	54.595841	"г.Гусев, ул.Победы, 51 ""А"""		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
37352	3	28	\N	7926	67658	\N	54.652355	г.Балтийск пр.Ленина 41  лицей №1		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37359	3	28	\N	7926	67652	\N	54.652355	г. Балтийск ул . Ю.Иванова, 1   ранее школа №		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37353	3	28	\N	7926	67630	\N	54.652355	г.Балтийск ул.Чехова 7   Детская поликлиника		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37356	3	28	\N	7926	67623	\N	54.652355	г. Балтийск ул.Ушакова 32  гимназия №7		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37355	3	28	\N	7926	67623	\N	54.652355	г.Балтийск ул.Ушакова 32  гимназия №7		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37357	3	28	\N	7926	67638	\N	54.652355	г. Балтийск ул.Советская  19  средняя школа №5		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37351	3	28	\N	7926	67646	\N	54.652355	г.Балтийск ул.Сенявина 12  библиотека им.Белинского		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37350	3	28	\N	7926	67644	\N	54.652355	г.Балтийск Дом детского творчества   ул.Московская 18		0101000020E61000005DDC460378EB3340E8305F5E80534B40
14643	3	28	\N	7926	67629	\N	54.652355	г. Балтийск ул. Мечникова, 5   ранее Вечерняя школа		0101000020E61000005DDC460378EB3340E8305F5E80534B40
94421	3	28	\N	7926	67627	\N	54.652355	г.Балтийск ул.Красной Армии 31 ДОФ		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37349	3	28	\N	7926	67627	\N	54.652355	г.Балтийск ул.Красной Армии 31  средняя школа №6		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37354	3	28	\N	7926	67625	\N	54.652355	г.Балтийск ул.Гоголя 20  средняя школа №4		0101000020E61000005DDC460378EB3340E8305F5E80534B40
37738	3	28	962	45690	23135	\N	54.770318000000003	пос. Щеглы, Школьная, 5		0101000020E61000007FF78E1A130E364094C2BCC799624B40
37404	3	28	962	25139	23319	\N	54.619900999999999	Калининградская область, Гурьевский муниципальный район, пос.Шоссейное, ул.Калининградское шоссе, д.7		0101000020E6100000EF8D210038E63540FCE07CEA584F4B40
37719	3	28	962	8015	67621	\N	54.635423000000003	город Черняховск, пер. Советский, 2		0101000020E610000075E5B33C0FD235402810768A55514B40
37716	3	28	962	8015	23147	\N	54.635423000000003	город Черняховск, Тольятти, 6		0101000020E610000075E5B33C0FD235402810768A55514B40
37722	3	28	962	8015	22985	\N	54.633516829519301	город Черняховск, Театральная площадь, 1	Россия, Калининградская область, Черняховский район, Черняховск	0101000020E610000064C91CCBBBCE3540E23AC61517514B40
37721	3	28	962	8015	23070	\N	54.633219343435798	город Черняховск, Суворова, 11	Россия, Калининградская область, Черняховский район, Черняховск	0101000020E6100000C51F459DB9CF3540581AF8510D514B40
37729	3	28	962	8015	23140	\N	54.637115356434201	город Черняховск, Победы, 50	Россия, Калининградская область, Черняховский район, Черняховск	0101000020E61000003E97A949F0D235404165FCFB8C514B40
37724	3	28	962	8015	23140	\N	54.635423000000003	город Черняховск, Победы, 40-а		0101000020E610000075E5B33C0FD235402810768A55514B40
37715	3	28	962	8015	23140	\N	54.635423000000003	город Черняховск, Победы, 32-г		0101000020E610000075E5B33C0FD235402810768A55514B40
37730	3	28	962	8015	23141	\N	54.635423000000003	город Черняховск, Октябрьская, 5		0101000020E610000075E5B33C0FD235402810768A55514B40
37713	3	28	962	8015	22983	\N	54.643039564892199	город Черняховск, Ленинградская, 18/2	Россия, Калининградская область, Черняховский район, Черняховск	0101000020E61000004F2157EA59D035408A027D224F524B40
37712	3	28	962	8015	22983	\N	54.635423000000003	город Черняховск, Ленинградская, 14		0101000020E610000075E5B33C0FD235402810768A55514B40
37711	3	28	962	8015	22983	\N	54.6475546844337	город Черняховск, Ленинградская, 2-а	Россия, Калининградская область, Черняховский район, Черняховск	0101000020E610000039F06AB933D335403EAE0D15E3524B40
37714	3	28	962	8015	23126	\N	54.635423000000003	город Черняховск, Ленина, 17		0101000020E610000075E5B33C0FD235402810768A55514B40
37723	3	28	962	8015	23208	\N	54.635423000000003	город Черняховск, Курчатова, 1		0101000020E610000075E5B33C0FD235402810768A55514B40
37725	3	28	962	8015	23174	\N	54.635423000000003	город Черняховск, Каретная, 1		0101000020E610000075E5B33C0FD235402810768A55514B40
37728	3	28	962	8015	23029	\N	54.635423000000003	город Черняховск, Калининградская, 23		0101000020E610000075E5B33C0FD235402810768A55514B40
37726	3	28	962	8015	23029	\N	54.635423000000003	город Черняховск, Калининградская, 9		0101000020E610000075E5B33C0FD235402810768A55514B40
37710	3	28	962	8015	23024	\N	54.635423000000003	город Черняховск, Горького, 2		0101000020E610000075E5B33C0FD235402810768A55514B40
37718	3	28	962	8015	23026	\N	54.635423000000003	город Черняховск, Гагарина, 26		0101000020E610000075E5B33C0FD235402810768A55514B40
37717	3	28	962	8015	23026	\N	54.635423000000003	город Черняховск, Гагарина, 6		0101000020E610000075E5B33C0FD235402810768A55514B40
37727	3	28	962	8015	23066	\N	54.640117424814903	город Черняховск, 2-й Дачный переулок, 14-б	Россия, Калининградская область, Черняховский район, Черняховск	0101000020E61000005F5FEB5223CC35408B4E965AEF514B40
37740	3	28	962	45725	23030	\N	54.646014999999998	пос. Тимофеевка, Центральная, 2		0101000020E610000079758E01D9E33540DBDC989EB0524B40
37327	3	28	962	46718	24187	\N	54.648521000000002	пос. Совхозное, Центральная, 1		0101000020E610000045F30016F9AD354076E272BC02534B40
37742	3	28	962	45759	23303	\N	54.539724999999997	пос. Свобода, Школьная, 12		0101000020E6100000FE463B6EF8B93540B3EA73B515454B40
37745	3	28	962	45813	23267	\N	54.569262000000002	пос. Пеньки, Детский переулок, 1		0101000020E61000005E30B8E68E9E3540836DC493DD484B40
37345	3	28	962	47098	24214	\N	54.711463000000002	пос. Партизанское, Центральная, 31		0101000020E6100000E3E0D231E785354033A83638115B4B40
37746	3	28	962	45843	24212	\N	54.621777999999999	пос. Междуречье, Школьная, 5-а		0101000020E6100000020D36751E853540A7AFE76B964F4B40
37741	3	28	962	9449	23067	\N	54.600378999999997	пос. Краснополянское, Молодежная, 1		0101000020E61000009FAC18AE0EF83540431A1538D94C4B40
37732	3	28	962	45560	23170	\N	54.659469000000001	пос. Каменское, Почтовая, 14		0101000020E610000063450DA6618C3540E8DCED7A69544B40
37736	3	28	962	9239	23134	\N	54.805436999999998	пос. Калужское, Советская, 14		0101000020E6100000BF2CEDD45CEA354082FE428F18674B40
37735	3	28	962	45641	23266	\N	54.804642999999999	пос. Калиновка, Черняховского, 20		0101000020E61000001409A69A59C7354048FAB48AFE664B40
37739	3	28	962	45712	\N	\N	54.745520999999997	пос. Загорское, Октябрьская, 25	Россия, Калининградская область, Черняховский район, село Загорское	0101000020E61000008257CB9D99F8354098BD6C3B6D5F4B40
37648	3	28	962	48496	24210	\N	54.621975999999997	пос. Железнодорожный, Коммунистическая, 27		0101000020E6100000BEA59C2FF6DA3540CD72D9E89C4F4B40
37649	3	28	962	48496	23011	\N	54.621975999999997	пос. Железнодорожный, Вокзальная, 1		0101000020E6100000BEA59C2FF6DA3540CD72D9E89C4F4B40
37731	3	28	962	9041	22969	\N	54.651554354845402	пос. Доваторовка, Мира, 8-а	Россия, Калининградская область, Черняховский район, село Доваторовка	0101000020E610000018963FDF16BC3540FBC9181F66534B40
37733	3	28	962	45602	23171	\N	54.659922000000002	пос. Глушково, Советской Конституции, 25		0101000020E6100000BB7F2C44876C354099F4F75278544B40
37743	3	28	962	45778	\N	\N	54.497456999999997	пос. Володаровка, здание дома культуры		0101000020E61000003FA88B14CAAE35404815C5ABAC3F4B40
14630	3	28	7463	59079	67642	\N	54.747917000000001	Калининградская область, город Калининград, Центральный район, Лужская, 27		0101000020E6100000E544BB0A296F3440AC8F87BEBB5F4B40
14640	3	28	879	7766	\N	\N	55.187317	Калининградская область,Славский район, п.Яснополянка, В помещении сельского клуба		0101000020E61000007714E7A8A36735400F7EE200FA974B40
37694	3	28	879	7303	\N	\N	55.171765999999998	Калининградская область, Славский район,  п.Ясное, В помещении  Дома культуры		0101000020E6100000CAFCA36FD29035404948A46DFC954B40
37692	3	28	879	7193	\N	\N	55.082452000000004	Калининградская область, Савский район, п.Тимирязево, В помещении адиминистрации поселения		0101000020E61000005473B9C1509B3540B2BE81C98D8A4B40
14649	3	28	879	50608	\N	\N	54.8498551961587	Калининградская область, Славский район,  п.Советское, в помещении библиотеки	Россия, Калининградская область, Славский район, село Советское	0101000020E61000000281CEA44DA13540C9AB730CC86C4B40
37681	3	28	879	6643	23091	\N	55.043349999999997	Калининградская область, Славский район, г.Славск, Советская, 23		0101000020E610000016DC0F7860AC35400B24287E8C854B40
37680	3	28	879	6643	23091	\N	55.043349999999997	Калининградская область, Славский район, г. Славск, Советская, 50		0101000020E610000016DC0F7860AC35400B24287E8C854B40
37693	3	28	879	7253	\N	\N	55.082842999999997	Калининградская область, Славский район, п.Ржевское, в помещении административного здания		0101000020E61000005FD0420246BF3540ECD973999A8A4B40
37691	3	28	879	7162	\N	\N	55.156703	Калининградская область, Славский район, п.Прохладное, В помещении сельского клуба		0101000020E6100000444FCAA486523540B1170AD80E944B40
37689	3	28	879	7041	\N	\N	55.003136397268001	Калининградская область, Славский район,  п.Приозерье, В помещении сельского клуба	Россия, Калининградская область, Славский район, село Приозерье	0101000020E610000081B4FF01D6BE35405AB8ACC266804B40
37683	3	28	879	6776	\N	\N	54.850300982575099	Калининградская область,  Славский район, п.Придорожное, В помещении библиотеки	Россия, Калининградская область, Славский район, село Придорожное	0101000020E610000074266DAAEEB53540C860C5A9D66C4B40
37688	3	28	879	7002	\N	\N	54.925094999999999	Калининградская область, Славский район, п.Охотное, В помещении библиотеки		0101000020E6100000DE04DF347D9E3540B858518369764B40
37696	3	28	879	7383	\N	\N	55.194923000000003	Калининградская область, Славский район,  п.Мысовка, В помещении Дома культуры		0101000020E6100000F92D3A596A4535407E1EA33CF3984B40
37423	3	28	879	48565	\N	\N	55.029895000000003	пос.Майское	Россия, Калининградская область, Славский район, село Майское	0101000020E61000001B2D077AA8A135402FA86F99D3834B40
37617	3	28	879	47914	24193	\N	55.069375999999998	пос. Лужки, Школьная, 6		0101000020E6100000745E6397A8C235404B901150E1884B40
37686	3	28	879	6896	\N	\N	54.775962999999997	Калининградская область,Славский район,  п.Красное, в помещении сельского клуба		0101000020E61000005E49F25CDFAF3540F9F36DC152634B40
37656	3	28	879	6896	24217	\N	54.777813109871097	пос. Красное, Центральная, 14	Россия, Калининградская область, Славский район, село Красное	0101000020E6100000DB696B4430B23540ABB35A608F634B40
37690	3	28	879	7093	\N	\N	55.045434	Калининградская область, Славский район, п.Заповедное, В помещении административного здания		0101000020E6100000C79E3D97A9613540301004C8D0854B40
37684	3	28	879	6815	\N	\N	54.965817000000001	Калининградская область , Славский район, п.Громово, В помещении административного здания ПНИ		0101000020E61000001CB62DCA6C6C3540DE7536E49F7B4B40
37687	3	28	879	6973	\N	\N	55.013236548475803	Калининградская область, Славский район, п.Гастеллово, В помещении административного здания	Россия, Калининградская область, Славский район, село Гастеллово	0101000020E61000007FDAA84E078E35406F0C01C0B1814B40
37685	3	28	879	6856	\N	\N	54.790120999999999	"Калининградская область,Славский район,  п.Высокое, в помещении МБОУ ""Высоковская СОШ"""		0101000020E610000072C0AE264FA93540007157AF22654B40
37695	3	28	879	7345	\N	\N	55.130291999999997	"Калининградская область, Славский район,  п.Вишневка, В конторе сельхозартели ""Бережки"""		0101000020E61000007FA1478C9E6F354018778368AD904B40
37682	3	28	879	6729	23025	\N	54.880924	Калининградская область, Славский район, п.Большаково, улица Черняховского, 2 В		0101000020E6100000986E1283C0A6354079211D1EC2704B40
14639	3	28	865	6524	67639	\N	54.698208000000001	Калининградская область,  поселок Взморье, ул.Советская, д.72		0101000020E61000005610035DFB3E34401DE736E15E594B40
37660	3	28	7096	50987	24211	\N	54.9394523520536	"Калининградская область, Светлогорский муниципальный район, городское поселение ""Город Светлогорск"", Калининградский проспект (МОУ ДОД ""Детский юношеский центр""), 14"		0101000020E6100000B80721205F263440B61490F63F784B40
37616	3	28	6960	47873	24225	\N	54.941642000000002	пос. Отрадное, Центральная, 16/2		0101000020E610000013F1D6F9B71B344020459DB987784B40
37612	3	28	680	47807	\N	\N	54.431097000000001	пос. Чистополье, Центральная, 25	Россия, Калининградская область, Правдинский район, село Чистополье	0101000020E6100000C4AF58C345F23440AD33BE2F2E374B40
37647	3	28	680	4873	23013	\N	54.396746999999998	пос. Севское, Центральная, 7		0101000020E61000001844A4A65D1C35409FE40E9BC8324B40
37644	3	28	680	4713	23222	\N	54.444431125197802	г. Правдинск, Кутузова, 28	Россия, Калининградская область, Правдинский район, Правдинск	0101000020E6100000508F6D19700235400F2A711DE3384B40
37645	3	28	680	4713	23143	\N	54.442335	г. Правдинск, Дзержинского, 1		0101000020E61000006823D74D290335402670EB6E9E384B40
37657	3	28	680	50981	24204	\N	54.507408757540503	пос. Ново-Бобруйск, Фрунзенская, 24	Россия, Калининградская область, Правдинский район, село Новобобруйск	0101000020E6100000062FFA0AD2543540195932C7F2404B40
37655	3	28	680	5292	23107	\N	54.443497000000001	пос. Мозырь, Октябрьская, 11		0101000020E6100000AF5B04C6FA7A3540E36F7B82C4384B40
37650	3	28	680	5034	23247	\N	54.402822	пос. Липняки, Пионерская, 1		0101000020E6100000A0C03BF9F4483540FE0DDAAB8F334B40
37652	3	28	680	48552	23159	\N	54.332344999999997	пос. Крылово, Центральная, 41		0101000020E6100000683C11C4798C35409BFEEC478A2A4B40
37651	3	28	680	48545	\N	\N	54.364587999999998	пос. Знаменка, Центральная, 13	Россия, Калининградская область, Правдинский район, село Знаменка	0101000020E6100000A98592C9A95D3540CC41D0D1AA2E4B40
37654	3	28	680	48585	23062	\N	54.407240000000002	пос. Ермаково, Школьная, 10		0101000020E6100000CFDC43C2F7EE3440C0CFB87020344B40
37653	3	28	680	5182	23199	\N	54.427483000000002	пос. Домново, Калининградская, 6		0101000020E6100000DC2E34D769D43440494C50C3B7364B40
37640	3	28	451	61710	79590	\N	54.813761999999997	поселок Февральское, Центральная, 10	Россия, Калининградская область, Полесский район, село Февральское	0101000020E6100000338D261763483540205D6C5A29684B40
37636	3	28	451	48275	\N	\N	54.863953000000002	поселок Тургенево, зданин детского сада		0101000020E610000019541B9C88023540FB230C03966E4B40
14636	3	28	451	51015	24364	\N	54.829962534358899	Калининградская область, Полесский р-он, поселок Саранское, Школьная, 1	Россия, Калининградская область, Полесский район, село Саранск	0101000020E6100000789B374E0A3B3540EDF1423A3C6A4B40
37633	3	28	451	3974	23296	\N	54.864553999999998	город Полесск, Театральная, 19		0101000020E610000098F738D38419354020D099B4A96E4B40
37631	3	28	451	3974	23329	\N	54.864553999999998	город Полесск, Советская, 12		0101000020E610000098F738D38419354020D099B4A96E4B40
37632	3	28	451	3974	23104	\N	54.864553999999998	город Полесск, Калининградская, 38		0101000020E610000098F738D38419354020D099B4A96E4B40
14637	3	28	451	60709	75636	\N	54.76023	Калининградская область, Полесский р-он, поселок Новая Деревня, Гвардейская, д. 28, здание школы	Россия, Калининградская область, Полесский район, село Новая-Деревня	0101000020E61000006092CA147348354013B875374F614B40
37635	3	28	451	4231	23198	\N	54.803761000000002	поселок Нахимово, Прохладная, здание библиотеки		0101000020E6100000D8F2CAF5B60D35406F66F4A3E1664B40
37637	3	28	451	48290	22993	\N	54.829470999999998	поселок Зеленое, переулок Торговый, 2		0101000020E61000003D0FEECEDA1935407EFD101B2C6A4B40
37641	3	28	451	48375	23233	\N	54.895921000000001	поселок Заливино, переулок Школьный, 5		0101000020E61000005439ED29390F35405A66118AAD724B40
37643	3	28	451	48398	23328	\N	54.844352000000001	поселок Залесье, Большаковская, 18		0101000020E61000001AC39CA04D863540F627F1B9136C4B40
14628	3	28	451	7248	24194	\N	54.761462000000002	Калининградская область, Полесский р-он, поселок Дальнее, Полесская, 14		0101000020E6100000BCCCB051D6873540C992399677614B40
37642	3	28	451	48387	\N	\N	54.979325000000003	поселок Головкино, здание школы		0101000020E6100000D1CABDC0AC443540DE9387855A7D4B40
37610	3	28	472	47771	24190	\N	54.422328999999998	пос. Суворовка, Центральная, 12а		0101000020E6100000C806D2C5A60D364081936DE00E364B40
37426	3	28	472	48637	\N	\N	54.490972999999997	пос.Первомайское	Россия, Калининградская область, Озерский район, село Первомайское	0101000020E610000019E3C3EC65C73540081C0934D83E4B40
37615	3	28	472	47861	23327	\N	54.390787000000003	пос. Олехово, Суворова, 67		0101000020E610000049111956F1D23540DA59F44E05324B40
37624	3	28	472	3590	23301	\N	54.408869000000003	г. Озерск, пл. Победы, 1А		0101000020E61000005A83F755B904364093ACC3D155344B40
37623	3	28	472	3590	23138	\N	54.408869000000003	г. Озерск, Московская, 1		0101000020E61000005A83F755B904364093ACC3D155344B40
37614	3	28	472	3111	23008	\N	54.437956999999997	пос. Новостроево, Центральная, 6		0101000020E6100000D00EB8AE98D53540F20698F90E384B40
37622	3	28	472	60686	75564	\N	54.466128661977599	пос. Ново-Гурьевское, Гурьевская, 7г	Россия, Калининградская область, Озерский район, село Новогурьевское	0101000020E6100000E256410C74FD3540CD5B751DAA3B4B40
37619	3	28	472	3376	23232	\N	54.385455	пос. Нилово, Центральная, 14		0101000020E610000051BD35B055AA3540338AE59656314B40
37618	3	28	472	47924	23157	\N	54.373919000000001	пос. Мальцево, Советская, 62		0101000020E61000001AFCFD62B6B83540302DEA93DC2F4B40
37611	3	28	472	47796	23193	\N	54.405039000000002	пос. Львовское, Центральная, 24		0101000020E6100000B58CD47B2AF33540624D6551D8334B40
37621	3	28	472	47972	23190	\N	54.523131999999997	пос. Красноярское, Центральная, 14		0101000020E6100000359886E123F23540DBBE47FDF5424B40
14608	3	28	472	47747	23283	\N	54.425089999999997	пос. Карамышево, Садовая, 16		0101000020E6100000D87DC7F0D83B3640A6ED5F5969364B40
37607	3	28	472	47715	23102	\N	54.396469000000003	пос. Гаврилово, Дзержинского, 40		0101000020E6100000842C0B26FE3C36405D70067FBF324B40
37609	3	28	472	2794	23231	\N	54.373693000000003	пос. Багратионово, Центральная, 38		0101000020E61000008B89CDC7B51D364040DF162CD52F4B40
37604	3	28	361	47658	23230	\N	54.565539999999999	п. Ясная поляна, Центральная, 33		0101000020E6100000F14A92E7FA723640384A5E9D63484B40
37602	3	28	361	50991	24231	\N	54.459451999999999	п. Чистые пруды, Центральная, 33	Россия, Калининградская область, Нестеровский район, село Чистые-Пруды	0101000020E61000007B14AE47E16E3640780AB952CF3A4B40
37594	3	28	361	1971	23205	\N	54.638835999999998	п. Чернышевское, Калининградская, 24		0101000020E6100000A320787C7BBB3640F4C0C760C5514B40
37605	3	28	361	47675	24227	\N	54.667520000000003	п. Фурмановка, Центральная, 38а		0101000020E61000003A3E5A9C316C364085B69C4B71554B40
37620	3	28	361	47961	\N	\N	54.717568	пос. Садовое, Центральная, 40б	Россия, Калининградская область, Нестеровский район, село Садовое	0101000020E6100000D0D556EC2F733640FC53AA44D95B4B40
37600	3	28	361	47597	23228	\N	54.576181525354897	п. Илюшино, Коммунальная, 3	Россия, Калининградская область, Нестеровский район, село Илюшино	0101000020E6100000CC2555DB4D8436409E45EF54C0494B40
14625	3	28	361	48048	23105	\N	54.504143999999997	п. Ильинское, Шоссейная, 5а		0101000020E61000000D39B69E21843640C03C64CA87404B40
37597	3	28	361	47539	23325	\N	54.682845999999998	п. Бабушкино, Куйбышева, 61		0101000020E6100000ACFE08C380A136402A1A6B7F67574B40
37601	3	28	7094	50969	24173	\N	54.451056999999999	п. Калинино, Центральная, 15		0101000020E61000007FF8F9EFC1933640E1D05B3CBC394B40
37585	3	28	189	1409	23279	\N	54.825867000000002	Калининградская область, Неманский муниципальный район, п.Ульяново, Школьная, 8		0101000020E61000003B8DB454DE1636403EEC8502B6694B40
37588	3	28	189	1629	23139	\N	55.007255999999998	Калининградская область, Неманский район, п.Ракитино, Центральная, 4		0101000020E6100000EE224C512EFD35409259BDC3ED804B40
37591	3	28	189	1751	23163	\N	54.992234000000003	Калининградская область, Неманский муниципальный район, п.Новоколхозное, Катаева, 3		0101000020E6100000715AF0A2AFC8354059FD1186017F4B40
37577	3	28	189	695	22999	\N	55.033155999999998	Калининградская область, Неманский район, г.Неман, Черняховского, 10		0101000020E6100000FFD0CC936B0A364045D5AF743E844B40
37581	3	28	189	695	23093	\N	55.033155999999998	Калининградская область, Неманский район, г.Неман, Советская, 35		0101000020E6100000FFD0CC936B0A364045D5AF743E844B40
37579	3	28	189	695	23093	\N	55.036209855774601	Калининградская область, Неманский район, г.Неман, Советская, 17	Россия, Калининградская область, Неманский район, Неман	0101000020E6100000624B8FA67A063640E2E47E87A2844B40
37574	3	28	189	695	23093	\N	55.033155999999998	Калининградская область, Неманский район, г.Неман, Советская, 2		0101000020E6100000FFD0CC936B0A364045D5AF743E844B40
37576	3	28	189	695	23276	\N	55.033155999999998	Калининградская область, Неманский район, г.Неман, Полевая, 7		0101000020E6100000FFD0CC936B0A364045D5AF743E844B40
37575	3	28	189	695	23037	\N	55.033155999999998	Калининградская область, Неманский район, г.Неман, Победы, 83		0101000020E6100000FFD0CC936B0A364045D5AF743E844B40
37578	3	28	189	695	23204	\N	55.033155999999998	Калининградская область, Неманский район, г.Неман, Октябрьская, 11		0101000020E6100000FFD0CC936B0A364045D5AF743E844B40
37584	3	28	189	1395	23096	\N	54.930103000000003	Калининградская область, Неманский район, п.Маломожайское, Центральная, 30		0101000020E6100000A032FE7DC6453640AC74779D0D774B40
37586	3	28	189	1498	23092	\N	54.915455999999999	Калининградская область, Неманский район, п.Лунино, Жилинская, 6		0101000020E610000023BA675DA3153640A77686A92D754B40
14624	3	28	189	7058	\N	\N	55.016342000000002	Калининградская область, Неманский район, п.Лесное, Здание дома культуры		0101000020E610000064CC5D4BC83336408FC6A17E17824B40
37592	3	28	189	1843	23152	\N	54.950878000000003	Калининградская область, Неманский район, п.Канаш, Школьная, 10		0101000020E6100000B51B7DCC07D43540323ECC5EB6794B40
37587	3	28	189	1515	23001	\N	54.911780999999998	Калининградская область, Неманский район, п.Жилино, Комсомольская, 17		0101000020E6100000C3B81B446BED35409D0E643DB5744B40
37589	3	28	189	1637	\N	\N	55.011845999999998	Калининградская область, Неманский район, п.Ветрово, Здание дома культуры		0101000020E610000020B41EBE4CF43540514B732B84814B40
37582	3	28	189	50998	24273	\N	55.0194872047175	Калининградская область, Неманский район, п.Большое Село, Школьная, 2	Россия, Калининградская область, Неманский район, село Большое	0101000020E61000009816F549EE2436403CD9CD8C7E824B40
37590	3	28	189	1732	\N	\N	55.043933000000003	Калининградская область, Неманский район, п.Акулово, Здание дома культуры, 13		0101000020E6100000EDF318E599FB35408B1BB7989F854B40
37567	3	28	23	46944	23212	\N	54.935735999999999	поселок Хлебниково, Молодежная, 15-а		0101000020E6100000737FF5B86F7536404DD87E32C6774B40
14634	3	28	23	7517	24262	\N	54.860098196809403	Калининградская область, Краснознаменский муниципальный район, п.Узловое, Советская, 6	Россия, Калининградская область, Краснознаменский район, село Узловое	0101000020E610000047AAEFFCA24C364071ADF6B0176E4B40
37570	3	28	23	47007	23146	\N	54.980663	поселок Тимофеево, Садовая, 2		0101000020E610000015527E52ED4B3640D9B27C5D867D4B40
37564	3	28	23	46870	24223	\N	54.841816999999999	поселок Правдино, Советская, 3-а		0101000020E610000093382BA2269A3640C11BD2A8C06B4B40
37565	3	28	23	61724	79604	\N	54.893183000000001	поселок Победино, Победы, 22	Россия, Калининградская область, Краснознаменский район, село Победино	0101000020E6100000026729594EBA3640ED2B0FD253724B40
37566	3	28	23	50999	24288	\N	54.926738575673703	поселок Острогожское, Краснознаменская, 23-а	Россия, Калининградская область, Краснознаменский район	0101000020E6100000C5573B8A73943640C07630629F764B40
14635	3	28	23	10710	9662	\N	54.813757000000003	Калининградская область, Краснознаменский муниципальный район, п.Новоуральское, Советская, 11	Россия, Калининградская область, Краснознаменский район, село Ново-Уральское	0101000020E6100000E736E15E998336400FF27A3029684B40
37571	3	28	23	582	23295	\N	55.049694000000002	поселок Неманское, Советская, 23		0101000020E610000037195586716336405A677C5F5C864B40
37563	3	28	23	28	22968	\N	54.944937000000003	Калининградская область, Краснознаменский район, г.Краснознаменск, ул.Калининградская, 29		0101000020E610000097361C96067E3640E3E313B2F3784B40
14632	3	28	23	28	22968	\N	54.944937000000003	Калининградская область, Краснознаменский муниципальный район, г. Краснознаменск, Калининградская, 39		0101000020E610000097361C96067E3640E3E313B2F3784B40
37572	3	28	23	690	23110	\N	54.759680000000003	поселок Добровольск, площадь Героев, 5		0101000020E6100000C7F65AD07B7F364070B6B9313D614B40
14633	3	28	23	7487	24407	\N	54.758172999999999	Калининградская область, Краснознаменский муниципальный район, п.Весново, Советская, 7		0101000020E6100000AF795567B5583640E8DA17D00B614B40
37399	3	28	641	24930	23000	\N	54.706057999999999	Калининградская область, Гурьевский муниципальный район, пос.Родники, ул.Марьина, д.21		0101000020E6100000927A4FE5B4AB3440228AC91B605A4B40
14652	3	28	991	8381	67654	\N	54.720239345749597	Калининградская область, Гурьевский муниципальный район, пос.Большое Исаково, ул.Бариновой, 1	Россия, Калининградская область, Калининград городской округ, поселок Большое Исаково	0101000020E6100000215C01857A9A3440E126A3CA305C4B40
37665	3	28	816	5829	24192	\N	54.872911000000002	Калининградская область, городской округ Янтарный, Советская (спортивный зал), 74		0101000020E6100000E5284014CCF03340CAA8328CBB6F4B40
14638	3	28	816	5829	24192	\N	54.872911000000002	Калининградская область, городской округ Янтарный, Советская (актовый зал), 114		0101000020E6100000E5284014CCF03340CAA8328CBB6F4B40
37437	3	28	816	26696	23175	\N	55.156965	Калининградская область, Зеленоградский муниципальный район, п.Рыбачий, Победы, 2		0101000020E6100000635E471CB2D93440EECEDA6D17944B40
37448	3	28	816	27181	23192	\N	54.895553	Калининградская область, Зеленоградский муниципальный район, п.Романово, Школьная, 16а		0101000020E6100000FC8F4C874E473440D76A0F7BA1724B40
37663	3	28	816	50992	24233	\N	54.940240942775702	"Калининградская область, Светлогорский муниципальный район, городское поселение ""Поселок Приморье"", Балтийский проспект (МОУ ОШ), 14"	Россия, Калининградская область, Зеленоградский район, поселок Приморье	0101000020E6100000AA9B8BBFED093440DEAD2CD159784B40
37737	3	28	816	45669	24200	\N	54.905999999999999	пос. Привольное, Центральная, 23		0101000020E6100000139A2496949F34408716D9CEF7734B40
37452	3	28	816	27352	23194	\N	54.834164000000001	Калининградская область, Зеленоградский муниципальный район, п.Поваровка, Балтийская, 2а		0101000020E6100000B8EA3A545302344012C0CDE2C56A4B40
37445	3	28	816	27053	23052	\N	54.819344001936699	Калининградская область, Зеленоградский муниципальный район, п.Переславское, Гвардейская, 5	Россия, Калининградская область, Зеленоградский район, село Переславское	0101000020E61000002713B70A624834404016A243E0684B40
14646	3	28	816	8061	23116	\N	54.809126999999997	Калининградская область, Зеленоградский муниципальный район, п.Откосово, Прохладная, 19		0101000020E61000002C6519E258573440C1A7397991674B40
37337	3	28	816	46940	24219	\N	54.907336000000001	пос. Надеждино, Советская, 7		0101000020E61000009697FC4FFE963440E23D079623744B40
37441	3	28	816	26836	23188	\N	54.896220999999997	Калининградская область, Зеленоградский муниципальный район, п.Муромское, Садовая, 2		0101000020E6100000EF8D2100387E3440847EA65EB7724B40
37440	3	28	816	26820	23187	\N	54.924951	Калининградская область, Зеленоградский муниципальный район, п.Моховое, Дорожная, 23		0101000020E6100000E46A64575A7A344085B35BCB64764B40
37438	3	28	816	26721	23289	\N	55.228973000000003	Калининградская область, Зеленоградский муниципальный район, п.Морское, Дачная, 9		0101000020E6100000645A9BC6F6EA34406155BDFC4E9D4B40
37443	3	28	816	26936	23006	\N	54.875360999999998	Калининградская область, Зеленоградский муниципальный район, п.Мельниково, Новая, 6		0101000020E610000001193A7650753440D09849D40B704B40
37442	3	28	816	26914	23101	\N	54.909049000000003	Калининградская область, Зеленоградский муниципальный район, п.Луговское, Кольцевая, 9а		0101000020E610000035F0A31AF697344013BBB6B75B744B40
14645	3	28	816	8018	23003	\N	54.766511000000001	Калининградская область, Зеленоградский муниципальный район, п.Логвино, Молодёжная, 2а		0101000020E610000026E5EE737C3434401B834E081D624B40
37436	3	28	816	26622	23154	\N	55.011583000000002	Калининградская область, Зеленоградский муниципальный район, п.Лесной, ул.Центральная, д.9		0101000020E6100000B7990AF1489C344044183F8D7B814B40
37451	3	28	816	27283	23326	\N	54.895755000000001	Калининградская область, Зеленоградский муниципальный район, п.Красноторовка, Школьная, 5		0101000020E61000000055DCB8C50434403F1D8F19A8724B40
37453	3	28	816	27407	23055	\N	54.737127999999998	Калининградская область, Зеленоградский муниципальный район, п.Кострово, Школьная, 10		0101000020E610000071A94A5B5C173440A27BD6355A5E4B40
37447	3	28	816	27119	23191	\N	54.799568000000001	Калининградская область, Зеленоградский муниципальный район, п.Колосовка, Центральная, 3		0101000020E610000013D38558FD4D3440CD76853E58664B40
37439	3	28	816	26765	23155	\N	54.914478000000003	Калининградская область, Зеленоградский муниципальный район, п.Коврово, Балтийская, 53		0101000020E61000006688635DDC663440AC74779D0D754B40
37454	3	28	816	10052	23197	\N	54.959383094723897	Калининградская область, Зеленоградский муниципальный район, г.Зеленоградск, Тургенева, 5б	Россия, Калининградская область, Зеленоградский район, Зеленоградск	0101000020E610000003D19332A979344050ABE80FCD7A4B40
37455	3	28	816	10052	23196	\N	54.960709173764201	Калининградская область, Зеленоградский муниципальный район, г.Зеленоградск, Октябрьская, 7	Россия, Калининградская область, Зеленоградский район, Зеленоградск	0101000020E6100000593332C85D7C344087FC3383F87A4B40
37432	3	28	816	10052	23179	\N	54.957676024152804	Калининградская область, Зеленоградский муниципальный район, г.Зеленоградск, Ленина, 20	Россия, Калининградская область, Зеленоградский район, Зеленоградск	0101000020E6100000CEC29E76F877344001158E20957A4B40
37434	3	28	816	10052	23153	\N	54.958781999999999	Калининградская область, Зеленоградский муниципальный район, г.Зеленоградск, Курортный проспект, 11		0101000020E61000007C0E2C47C87834402AFF5A5EB97A4B40
37431	3	28	816	10052	23153	\N	54.961348788457499	Калининградская область, Зеленоградский муниципальный район, г.Зеленоградск, Курортный проспект, 5	Россия, Калининградская область, Зеленоградский район, Зеленоградск	0101000020E61000004AD05FE8117B34406A85E97B0D7B4B40
37394	3	28	641	24711	23271	\N	54.806921000000003	Калининградская область, Гурьевский муниципальный район, Добринское сельское поселение, п.Рассвет, ул.Центральная, д.17		0101000020E61000004D31074147A3344052BAF42F49674B40
37433	3	28	816	10052	23099	\N	54.9612969027785	Калининградская область, Зеленоградский муниципальный район, г.Зеленоградск, Крымская, 5 А администрация	Россия, Калининградская область, Зеленоградский район, Зеленоградск	0101000020E6100000240C03965C793440185FB4C70B7B4B40
37449	3	28	816	27202	23156	\N	54.952030999999998	Калининградская область, Зеленоградский муниципальный район, пос.Заостровье, Пионерская, 11		0101000020E6100000D26EF4311F4434409BE3DC26DC794B40
37646	3	28	816	48460	\N	\N	54.858497	пос. Дружба, Почтовый переулок, 1	Россия, Калининградская область, Зеленоградский район, село Дружба	0101000020E61000007CED9925011E3440685BCD3AE36D4B40
37664	3	28	816	61677	79554	\N	54.939982000000001	"Калининградская область, Светлогорский муниципальный район, городское поселение ""Поселок Донское"", Садовая (МОУ СОШ), 7"	Россия, Калининградская область, Зеленоградский район, село Донское	0101000020E6100000DF162CD505F83340126A865451784B40
37450	3	28	816	27265	23290	\N	54.900094000000003	Калининградская область, Зеленоградский муниципальный район, п.Грачевка, Центральная, 12а		0101000020E610000049F7730AF21F3440B5A9BA4736734B40
37413	3	28	816	50983	24205	\N	54.890620197398398	Калининградская область, Гурьевский муниципальный район, Большеисаковское сельское поселение, п.Васильково, ул.Западная, д.2	Россия, Калининградская область, Зеленоградский район, село Васильково	0101000020E61000006F62484E26663440EE940ED6FF714B40
37569	3	28	816	46988	23145	\N	54.834771000000003	поселек Алексеевка, Шоссейная, 3		0101000020E6100000DF8AC404355834401A53B0C6D96A4B40
37613	3	28	1115	47820	24215	\N	54.640169	пос. Юдино, Новая, 1а		0101000020E61000002733DE567A3D3640DE74CB0EF1514B40
37420	3	28	1115	48527	\N	\N	54.603915000000001	пос.Фурманово	Россия, Калининградская область, Гусевский район, село Фурманово	0101000020E6100000514A0856D52736402C4833164D4D4B40
37430	3	28	1115	47066	\N	\N	54.634656999999997	пос.Северный	Россия, Калининградская область, Гусевский район, село Северное	0101000020E61000009483D90418363640B796C9703C514B40
37343	3	28	1115	47066	\N	\N	54.634656999999997	пос. Северный, 21		0101000020E61000009483D90418363640B796C9703C514B40
14650	3	28	1115	48526	23260	\N	54.645265000000002	пос. Покровское, Героев, 2		0101000020E6100000645DDC46032836407120240B98524B40
37421	3	28	1115	25964	\N	\N	54.60416	пос.Поддубы	Россия, Калининградская область, Гусевский район, село Поддубы	0101000020E6100000A3CD716E1312364093C6681D554D4B40
37428	3	28	1115	50990	\N	\N	54.4994600775237	пос.Ольховатка	Россия, Калининградская область, Гусевский район	0101000020E61000002D9622F94A4C364080D4264EEE3F4B40
37422	3	28	1115	50988	\N	\N	54.647539314686199	пос.Михайлово	Россия, Калининградская область, Гусевский район, село Михайловка	0101000020E61000003E5A9C31CC21364039F1D58EE2524B40
37429	3	28	1115	26268	\N	\N	54.522489	пос.Маяковское	Россия, Калининградская область, Гусевский район, село Маяковское	0101000020E6100000CB9E0436E710364087C267EBE0424B40
37425	3	28	1115	48620	\N	\N	54.678561999999999	пос.Кубановка	Россия, Калининградская область, Гусевский район, село Кубановка	0101000020E6100000D9EDB3CA4C4D364078279F1EDB564B40
37424	3	28	1115	48596	\N	\N	54.662547000000004	пос.Красногорское	Россия, Калининградская область, Гусевский район, село Красногорское	0101000020E6100000519FE40E9B4036400E881057CE544B40
37427	3	28	1115	48653	\N	\N	54.557825000000001	пос.Калининское	Россия, Калининградская область, Гусевский район, село Калининское	0101000020E61000007AA69718CB44364013F241CF66474B40
37417	3	28	1115	10024	23048	\N	54.595841	г.Гусев, пер.Павлова, 4		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
37358	3	28	1115	10024	22975	\N	54.594396969959597	г.Гусев, ул.Юрия Смирнова, 20	Россия, Калининградская область, Гусевский район, Гусев	0101000020E61000001FDB32E02C35364096EB6D33154C4B40
37415	3	28	1115	10024	23317	\N	54.595841	г.Гусев, ул. Ю. Смирнова, 20		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
37396	3	28	1115	10024	22997	\N	54.595841	г.Гусев, ул.Ульяновых, 1		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
37385	3	28	1115	10024	23082	\N	54.595841	г.Гусев, ул.Тимирязева, 3		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
35300	3	28	1115	10024	23036	\N	54.595841	г.Гусев, ул.Советская, 10		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
37418	3	28	1115	10024	23049	\N	54.595841	г.Гусев, ул.Железнодорожная, 46		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
37416	3	28	1115	10024	23098	\N	54.595841	г.Гусев, ул.Артиллерийская, 2		0101000020E61000009E3F6D54A7333640D74E9484444C4B40
37402	3	28	641	25074	23280	\N	54.601354000000001	Калининградская область, Гурьевский муниципальный район, пос.Яблоневка, ул.Центральная, д.9		0101000020E61000002AE09EE74F6F3440CEA8F92AF94C4B40
37747	3	28	641	7965	\N	\N	54.897975107239603	"Калининградская область, Гурьевский муниципальный район, Храбровское сельское поселение, аэропорт ""Храброво"", здание аэровокзала ""Храброво"""	Россия, Калининградская область, Гурьевский район, село Храброво	0101000020E6100000F4C132367493344014D044D8F0724B40
14644	3	28	641	7965	23020	\N	54.898220000000002	Калининградская область, Гурьевский муниципальный район, пос.Храброво, ул. А. Невского, д.7		0101000020E610000020D099B4A99234407B4E7ADFF8724B40
37405	3	28	641	25187	23185	\N	54.610705000000003	Калининградская область, Гурьевский район, пос.Ушаково, ул.Победы, д.7		0101000020E6100000D9AF3BDD793E34407940D9942B4E4B40
37639	3	28	641	48340	24224	\N	54.637022000000002	поселок Сосновка, Центральная, 14		0101000020E6100000FFB3E6C75FAE3440906AD8EF89514B40
37634	3	28	641	4201	\N	\N	54.676822999999999	поселок Славянское, Калининградская, здание школы		0101000020E610000047205ED72FB834401E17D522A2564B40
37336	3	28	641	25461	24189	\N	54.829627000000002	пос. Рябиновка, Мирная, 2		0101000020E610000011FE45D0988134407670B037316A4B40
14648	3	28	641	8193	\N	\N	54.657823999999998	Калининградская область, Пионерский городской округ, пос.Рыбное, здание РГУ		0101000020E610000099A0866F61AD34400F43AB9333544B40
37409	3	28	641	25366	23183	\N	54.805467999999998	Калининградская область, Гурьевский муниципальный район, пос.Петрово, ул.Октябрьская, д.2		0101000020E61000008B5242B0AA6A3440BDFC4E9319674B40
37408	3	28	641	25323	23053	\N	54.793655999999999	Калининградская область, Гурьевский муниципальный район, пос.Орловка, ул.Центральная, д.24		0101000020E61000009FC728CFBC8834401823128596654B40
37398	3	28	641	24872	23219	\N	54.700991000000002	Калининградская область, Гурьевский муниципальный район, пос.Низовье, ул.Калининградская, д.18		0101000020E610000079B29B19FDBC34402AE5B512BA594B40
14651	3	28	641	8364	23038	\N	54.902324999999998	Калининградская область, Гурьевский муниципальный район, пос.Некрасово, ул.Центральная, д.17		0101000020E6100000D7DEA7AAD0AC34407DAEB6627F734B40
37388	3	28	641	24395	23218	\N	54.815849999999998	Калининградская область, Гурьевский район, пос.Моргуново, ул.Гурьева, д.14А		0101000020E610000069519FE40ECB34408638D6C56D684B40
37410	3	28	641	25449	23045	\N	54.860419	Калининградская область, Гурьевский муниципальный район, пос.Матросово, ул.Центральная, д.20		0101000020E6100000D25625917D983440B3EDB435226E4B40
37391	3	28	641	24535	23216	\N	54.877085999999998	Калининградская область, Гурьевский муниципальный район, пос.Маршальское, ул.Центральная, д.5А		0101000020E61000002B1213D4F0BD3440C5E3A25A44704B40
37407	3	28	641	24998	23005	\N	54.744990999999999	Калининградская область, Гурьевский муниципальный район, Кутузовское сельское поселение, п.Малое Васильково, ул. Степная, д.1А		0101000020E610000023A12DE7529C34403C6876DD5B5F4B40
37401	3	28	641	24998	23315	\N	54.744990999999999	Калининградская область, Гурьевский муниципальный район, пос.Васильково, ул.Западная, д.2		0101000020E610000023A12DE7529C34403C6876DD5B5F4B40
37395	3	28	641	24763	23277	\N	54.720407999999999	Калининградская область, Гурьевский муниципальный район, пос.Малинники, ул.Молодежная, д.15		0101000020E61000000A664CC11ABF34406DE34F54365C4B40
37406	3	28	641	25222	23100	\N	54.646389999999997	Калининградская область, Гурьевский муниципальный район, Луговское сельское поселение, п.Луговое, ул.Центральная, д.2		0101000020E6100000632AFD84B3A33440103B53E8BC524B40
37403	3	28	641	25084	23002	\N	54.635036999999997	Калининградская область, Гурьевский муниципальный район, пос.Лесное, ул.Багратионовская, д.25		0101000020E6100000B8921D1B818C3440FE5F75E448514B40
37393	3	28	641	24643	23221	\N	54.799821999999999	Калининградская область, Гурьевский муниципальный район, Гурьевское городское поселение, п.Константиновка, ул.Зеленая, д.4		0101000020E6100000AAF1D24D62B03440874F3A9160664B40
37390	3	28	641	24516	\N	\N	54.787115999999997	"Калининградская область, Гурьевский муниципальный район, Добринское сельское поселение, п.Заречье, Административное здание ОАО ""Добрино"", д.20"		0101000020E6100000E657738060E2344044149337C0644B40
37400	3	28	641	24987	23042	\N	54.725075899132698	Калининградская область, Гурьевский муниципальный район, пос.Заозерье, ул.Центральная, д.4	Россия, Калининградская область, Гурьевский район, село Заозерье	0101000020E6100000978BF84ECCA63440A88E554ACF5C4B40
37392	3	28	641	24627	23112	\N	54.914566000000001	Калининградская область, Гурьевский муниципальный район, Храбровское сельское поселение, п.Заливное, ул.Центральная, д.6		0101000020E61000005E9CF86A47D134404B04AA7F10754B40
37389	3	28	641	24443	22981	\N	54.811072000000003	Калининградская область, Гурьевский район, пос.Добрино, ул.Калининградская, д.26		0101000020E610000033FD12F1D6DD3440C5591135D1674B40
37412	3	28	641	24148	23108	\N	54.778596	Калининградская область, Гурьевский муниципальный район, Гурьевское городское поселение, г.Гурьевск, ул.Садовая, д.19		0101000020E6100000CB9D9960389B3440F165A208A9634B40
37386	3	28	641	24148	23108	\N	54.778596	Калининградская область, г.Гурьевск, ул.Садовая, Гимназия № 2		0101000020E6100000CB9D9960389B3440F165A208A9634B40
37384	3	28	641	24148	23181	\N	54.778596	Калининградская область, г. Гурьевск, ул.Ленина, СОШ № 1		0101000020E6100000CB9D9960389B3440F165A208A9634B40
37383	3	28	641	24148	23181	\N	54.778596	Калининградская область, г.Гурьевск, ул.Ленина, СОШ №1		0101000020E6100000CB9D9960389B3440F165A208A9634B40
37387	3	28	641	24148	23330	\N	54.778596	Калининградская область,г. Гурьевск, ул.Заречная, ПУ-19		0101000020E6100000CB9D9960389B3440F165A208A9634B40
37397	3	28	641	24852	22998	\N	54.703353	Калининградская область, Гурьевский муниципальный район, пос.Высокое, ул.Полевая, д.18		0101000020E6100000BDE3141DC9CD344091459A78075A4B40
37608	3	28	386	47742	23103	\N	54.70429	пос. Яблоновка, Центральная, 29		0101000020E6100000E202D0285DEA34402E73BA2C265A4B40
37376	3	28	386	51011	24354	\N	54.648082062459302	Калининградская область, Гвардейский район, поселок Талпаки, Мира, 12	Россия, Калининградская область, Гвардейский район, село Толпаки	0101000020E6100000ADDC0BCC0A5535402A90D959F4524B40
37379	3	28	386	23948	23180	\N	54.750520000000002	Калининградская область, Гвардейский район, поселок Славинск, Ст.Козака, 7		0101000020E61000006C7C26FBE7153540397F130A11604B40
37595	3	28	386	1991	24222	\N	54.663317999999997	п. Пригородное, Пригородная, 7		0101000020E6100000A8ACA6EB890A35408F6CAE9AE7544B40
37373	3	28	386	23686	23177	\N	54.621589999999998	Калининградская область, Гвардейский район, поселок Озерки, Школьная, 1		0101000020E6100000F816D68D77E33440A4C2D842904F4B40
37382	3	28	386	23686	23274	\N	54.621589999999998	Калининградская область, Гвардейский район, поселок Озерки, Садовая, 8		0101000020E6100000F816D68D77E33440A4C2D842904F4B40
37381	3	28	386	24044	\N	\N	54.702406000000003	Калининградская область, Гвардейский район, поселок Малиновка, Здание Дома культуры		0101000020E610000074EFE192E3E63440D1419770E8594B40
37377	3	28	386	23854	23273	\N	54.685187999999997	Калининградская область, Гвардейский район, поселок Красный Яр, Школьная, 7		0101000020E6100000700B96EA025A35404ACE893DB4574B40
37374	3	28	386	23703	23178	\N	54.628267000000001	Калининградская область, Гвардейский район, поселок Комсомольск, Школьная, 7		0101000020E6100000ACC77DAB75C23440F913950D6B504B40
37378	3	28	386	23889	23034	\N	54.658313	Калининградская область, Гвардейский район, поселок Зорино, Центральная, 17		0101000020E610000083893F8A3A3735400DC4B29943544B40
37372	3	28	386	23543	23313	\N	54.612926000000002	Калининградская область, Гвардейский район, поселок Знаменск, Шоссейная, Здание клуба маргаринового завода		0101000020E6100000D8D5E429AB3935401E6FF25B744E4B40
37371	3	28	386	23543	23169	\N	54.6128059432708	Калининградская область, Гвардейский район, поселок Знаменск, Советская, 5	Россия, Калининградская область, Гвардейский район, поселок Знаменск	0101000020E61000002C9E7AA4C13935407365506D704E4B40
37370	3	28	386	23543	23144	\N	54.606050221662699	Калининградская область, Гвардейский район, поселок Знаменск, Железнодорожная, 9	Россия, Калининградская область, Гвардейский район, поселок Знаменск	0101000020E61000001FBFB7E9CF363540D3DEE00B934D4B40
37375	3	28	386	23756	23132	\N	54.614187000000001	Калининградская область, Гвардейский район, поселок Заречье, Центральная, 18		0101000020E61000007974232C2A0635406E50FBAD9D4E4B40
37362	3	28	386	60861	76482	\N	54.670962127926103	п.Дивное,ул.Молодежная 12 А    детский сад	Россия, Калининградская область, Гвардейский район, село Дивное	0101000020E61000001A355F251F5F3540EC6D3315E2554B40
37367	3	28	386	9954	22984	\N	54.654949000000002	Калининградская область, Гвардейский район, город Гварейск, Юбилейная, 4		0101000020E61000000A68226C7812354022C66B5ED5534B40
37366	3	28	386	9954	22984	\N	54.654949000000002	Калининградская область, Гвардейский район, город Гвардейск, Юбилейная, 4		0101000020E61000000A68226C7812354022C66B5ED5534B40
37365	3	28	386	9954	23031	\N	54.654949000000002	Калининградская область, Гвардейский район, город Гвардейск, Тельмана, 6		0101000020E61000000A68226C7812354022C66B5ED5534B40
37363	3	28	386	9954	23031	\N	54.654949000000002	Калининградская область, Гвардейский район, город Гвардейск, Тельмана, 30 А		0101000020E61000000A68226C7812354022C66B5ED5534B40
37369	3	28	386	9954	23307	\N	54.650594083915401	Калининградская область, Гвардейский район, город Гвардейск, Красноармейская, 24	Россия, Калининградская область, Гвардейский район, Гвардейск	0101000020E6100000D865F84F37143540A67C08AA46534B40
37364	3	28	386	9954	23173	\N	54.654949000000002	Калининградская область, Гвардейский район, город Гвардейск, Калининградская, 16		0101000020E61000000A68226C7812354022C66B5ED5534B40
37368	3	28	386	9954	23033	\N	54.654949000000002	Калининградская область, Гвардейский район, город Гвардейск, Вокзальная, Здание ж/д вокзала		0101000020E61000000A68226C7812354022C66B5ED5534B40
37380	3	28	386	23985	\N	\N	54.667223	Калининградская область, Гвардейский район, поселок Борское, 50		0101000020E6100000E6CB0BB08FF63440CB11329067554B40
37342	3	28	1103	50982	\N	\N	54.547968432317496	пос. Южный-1, 57	Россия, Калининградская область, Багратионовский район, село Южный	0101000020E6100000A323B9FC8798344094A0BFD023464B40
37340	3	28	1103	47000	23166	\N	54.538701000000003	пос. Чехово, Клубная, 3		0101000020E610000050C58D5BCCB7344048A98427F4444B40
37339	3	28	1103	50996	24246	\N	54.498763322095797	пос. Тишино, Центральная, 4	Россия, Калининградская область, Багратионовский район, село Тишоно	0101000020E610000026016A6AD9C2344038BA4A77D73F4B40
37332	3	28	1103	21806	23299	\N	54.495057000000003	пос. Славское, Тхоржевского, 12		0101000020E610000068226C787A713440F4531C075E3F4B40
37326	3	28	1103	21493	23206	\N	54.500897000000002	пос. Пятидорожное, Красноармейская, 4		0101000020E610000009FD4CBD6E1934400FD594641D404B40
37598	3	28	1103	47572	24186	\N	54.461587000000002	п. Пушкино, Центральная, 5		0101000020E6100000766EDA8CD38C34401FA16648153B4B40
37328	3	28	1103	61670	79547	\N	54.416904000000002	пос. Пограничный, Молодежная, 12	Россия, Калининградская область, Багратионовский район, село Пограничное	0101000020E610000067D7BD15897134402AC93A1C5D354B40
37329	3	28	1103	51001	24306	\N	54.572643724319803	пос. Ново-Московское, Школьная, 1	Россия, Калининградская область, Багратионовский район, село Новомосковский	0101000020E6100000594E42E90B3D344014200A664C494B40
37341	3	28	1103	22202	23028	\N	54.580325999999999	пос. Нивенское, Калининградская, 20		0101000020E61000007AC37DE4D69034405E82531F484A4B40
37331	3	28	1103	21725	23022	\N	54.531894000000001	пос. Медовое, Школьная, 7		0101000020E6100000F5BBB0355B5D34402578431A15444B40
37750	3	28	1103	9827	23312	\N	54.465591000000003	гор. Мамоново, Центральная, 3		0101000020E6100000FE98D6A6B1F13340EE27637C983B4B40
37749	3	28	1103	9827	23309	\N	54.465591000000003	гор. Мамоново, Калининградское шоссе, 5		0101000020E6100000FE98D6A6B1F13340EE27637C983B4B40
37748	3	28	1103	9827	23167	\N	54.465591000000003	гор. Мамоново, Евсеева, 2		0101000020E6100000FE98D6A6B1F13340EE27637C983B4B40
37734	3	28	1103	45609	24197	\N	54.447192999999999	пос. Липовка, Советская, 1		0101000020E6100000253B3602F10E34400400C79E3D394B40
37347	3	28	1103	22444	23261	\N	54.573855000000002	гор. Ладушкин, Сосновая, 12		0101000020E6100000E04C4C1762293440B3D2A41474494B40
37346	3	28	1103	22444	23079	\N	54.5730722488181	гор. Ладушкин, Победы, 12	Россия, Калининградская область, Багратионовский район, Ладушкин	0101000020E6100000A3409FC8932C34406D205D6C5A494B40
37167	3	28	1103	48092	24218	\N	54.480978	пос. Краснознаменское, Центральная, 21		0101000020E6100000376F9C14E6893440390CE6AF903D4B40
37330	3	28	1103	46784	23210	\N	54.443030999999998	пос. Корнево, Центральная, 3		0101000020E6100000EC3191D26C4A34409D0E643DB5384B40
37568	3	28	1103	46956	\N	\N	54.573656999999997	поселок Заречное, Центральная, 35-а	Россия, Калининградская область, Багратионовский район, село Заречное	0101000020E61000006E4C4F58E26D34408C0FB3976D494B40
37138	3	28	1103	47554	23119	\N	54.443649000000001	пос. Долгоруково, 1-я Народная, 1		0101000020E61000003A765089EB84344099F38C7DC9384B40
37338	3	28	1103	46951	23128	\N	54.487358999999998	пос. Гвардейское, Школьная, 8 А		0101000020E6100000FC6D4F90D8A23440A4349BC7613E4B40
37344	3	28	1103	47082	22967	\N	54.564177999999998	пос. Владимирово, Школьная, 8 А		0101000020E6100000C66D3480B7883440B48F15FC36484B40
37334	3	28	1103	21847	23121	\N	54.382830679211203	гор. Багратионовск, Пограничная, 57	Россия, Калининградская область, Багратионовский район, Багратионовск	0101000020E6100000D80FB1C1C2A134408F72309B00314B40
37333	3	28	1103	21847	23121	\N	54.386504000000002	гор. Багратионовск, Пограничная, 62		0101000020E6100000AFB0E07EC0A33440F8E28BF678314B40
37335	3	28	1103	21847	23125	\N	54.386504000000002	гор. Багратионовск, Калининградская, 10		0101000020E6100000AFB0E07EC0A33440F8E28BF678314B40
29517	3	27	\N	26113	32071	\N	59.153795000000002	Вологодская область, Череповецкий муниципальный район, д. Ясная Поляна, Механизаторов, 3-б		0101000020E61000001BD9959691F44240E8A4F78DAF934D40
29605	3	27	\N	164	7685	\N	59.122149999999998	Вологодская область, город Череповец, выставочный зал, ул.Юбилейная, д.36	Россия, Вологодская область, Череповец, улица Юбилейная, 36	0101000020E61000006FF085C954FF42406B9A779CA28F4D40
29572	3	27	\N	164	6936	\N	59.175511999999998	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 36"", ул.Центральная, д.18"	Россия, Вологодская область, Череповец, улица Центральная, 18	0101000020E610000038F8C264AAE242401C075E2D77964D40
29576	3	27	\N	164	7342	\N	59.145252999999997	Вологодская область, город Череповец, общежитие, ул.Пионерская, д.19	Россия, Вологодская область, Череповец, улица Пионерская, 19	0101000020E61000002D26361FD7F84240AC527AA697924D40
29596	3	27	\N	164	31983	\N	59.128089000000003	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 2"", ул.Олимпийская, д.59"	Россия, Вологодская область, Череповец, улица Олимпийская, 59	0101000020E6100000E5284014CC0043401AFD683865904D40
29550	3	27	\N	164	6859	\N	59.133293000000002	"Вологодская область, город Череповец, ""Женская гуманитарная гимназия"", ул.Металлургов, д.40"	Россия, Вологодская область, Череповец, улица Металлургов, 40	0101000020E610000089230F4416F1424093E4B9BE0F914D40
29547	3	27	\N	164	7045	\N	59.128642999999997	Вологодская область, город Череповец, общежитие, ул.Ленина, д.149		0101000020E6100000452E3883BFF14240FEEDB25F77904D40
29612	3	27	\N	164	31715	\N	59.127315452871997	Вологодская область, город Череповец, "Детско-юношеская спортивная школа № 4", ул.Краснодонцев, д.26-а	Россия, Вологодская область, Череповец, улица Краснодонцев, 26а	0101000020E610000026C45C52B5FB424027A5A0DB4B904D40
29598	3	27	\N	164	3250	\N	59.125185000000002	"Вологодская область, город Череповец, ""Центр детского творчества"", ул.К. Беляева, д.32"	Россия, Вологодская область, Череповец, улица Космонавта Беляева, 32	0101000020E61000006D3CD862B7FF42409279E40F06904D40
29537	3	27	\N	164	32028	\N	59.101129999999998	"Вологодская область, город Череповец, ""Начальная общеобразовательная школа № 41"", ул.Батюшкова, д.10"	Россия, Вологодская область, Череповец, Красная Горка микрорайон, улица Батюшкова, 10	0101000020E6100000BF7FF3E2C4F542407E52EDD3F18C4D40
29542	3	27	\N	164	31850	\N	59.124625999999999	"Вологодская область, город Череповец, библиотека №10 МБУК ""Объединение библиотек"", пр.Строителей, д.30"		0101000020E6100000CB10C7BAB8F142409B1DA9BEF38F4D40
29607	3	27	\N	164	26409	\N	59.118166260744303	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 5"", ул.Юбилейная, д.9"	Россия, Вологодская область, Череповец, улица Юбилейная, 9	0101000020E61000002AA8A8FA95FE4240E4BF4010208F4D40
29606	3	27	\N	164	26409	\N	59.119104062721398	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 9"", ул.Юбилейная, д.11"	Россия, Вологодская область, Череповец, улица Юбилейная, 11	0101000020E6100000AE635C7171FE42405169C4CC3E8F4D40
29536	3	27	\N	164	32067	\N	59.094396000000003	Вологодская область, город Череповец, Центр профилактики правонарушений, Шекснинский пр, д.27А	Россия, Вологодская область, Череповец, Шекснинский проспект, 27а	0101000020E6100000693A3B191CF74240C66F0A2B158C4D40
29546	3	27	\N	164	31854	\N	59.127577935189301	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 18"", ул.Чкалова, д.20А"	Россия, Вологодская область, Череповец, улица Чкалова, 20а	0101000020E6100000986A662D05F0424034D8D47954904D40
29609	3	27	\N	164	26571	\N	59.119909448565799	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 19"", ул.Суворова, д.5"	Россия, Вологодская область, Череповец, улица Суворова, 5	0101000020E61000001FD7868A71FC42407FBF982D598F4D40
29544	3	27	\N	164	15975	\N	59.124062000000002	"Вологодская область, город Череповец, ДК ""Строитель"" имени Д.Н. Мамлеева, пл.Строителей, д.1"	Россия, Вологодская область, Череповец, Индустриальный район, Строителей площадь, 1	0101000020E610000094FB1D8A02F1424093567C43E18F4D40
95161	3	27	\N	164	32065	\N	59.121487498088598	"""Вологодская область, город Череповец, ул. Сталеваров, д.32"	Россия, Вологодская область, Череповец, улица Сталеваров	0101000020E6100000A8FFACF9F1F34240D0F1D1E28C8F4D40
29555	3	27	\N	164	32065	\N	59.136727999999998	Вологодская область, город Череповец, общежитие, ул.Сталеваров, д.78		0101000020E6100000BDAC8905BEF442404739984D80914D40
29570	3	27	\N	164	899	\N	59.125982328657201	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 1"", Советский пр, д.60А"	Россия, Вологодская область, Череповец, Советский проспект, 64	0101000020E6100000EB8CEF8B4BF742403DF19C2D20904D40
29569	3	27	\N	164	899	\N	59.123964999999998	"Вологодская область, город Череповец, ""Городское филармоническое собрание"", Советский пр, д.35А"	Россия, Вологодская область, Череповец, Советский проспект, 35а	0101000020E6100000BD8E386403F74240A06CCA15DE8F4D40
29568	3	27	\N	164	899	\N	59.120781009102998	Вологодская область, город Череповец, учебный корпус № 6 ЧГУ, Советский пр, д.10	Россия, Вологодская область, Череповец, Советский проспект, 10	0101000020E610000048FAB48AFEF64240357D76C0758F4D40
29054	3	27	\N	164	899	\N	59.122149999999998	Вологодская область, Вытегорский муниципальный район, муниципальное образование город Вытегра, Проспект Советский, 21	Россия, Вологодская область, Череповец, Советский проспект, 21	0101000020E6100000FAEE5696E8F642406B9A779CA28F4D40
29579	3	27	\N	164	7315	\N	59.148934006484801	"Вологодская область, город Череповец, библиотека № 4 МБУК ""Объединение библиотек"", Северное шоссе, д.29"	Россия, Вологодская область, Череповец, Северное шоссе, 29	0101000020E6100000541F48DE39FA424098A1F14410934D40
29611	3	27	\N	164	7129	\N	59.123205781694303	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 34"", пр.Победы, д.116"	Россия, Вологодская область, Череповец, Победы проспект, 116	0101000020E61000008369183E22FC4240E355D636C58F4D40
29588	3	27	\N	164	7129	\N	59.124399402249502	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 27"", пр.Победы, д.147"	Россия, Вологодская область, Череповец, Победы проспект, 147	0101000020E61000008B53AD8559FE4240DA53724EEC8F4D40
29554	3	27	\N	164	7129	\N	59.132679000000003	"Вологодская область, город Череповец, ""Череповецкий технологический техникум"", пр.Победы, д.18"	Россия, Вологодская область, Череповец, Победы проспект, 18	0101000020E6100000331AF9BCE2F34240D9EE1EA0FB904D40
29577	3	27	\N	164	31742	\N	59.144873792556602	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 33"", ул.Пионерская, д.14"	Россия, Вологодская область, Череповец, улица Пионерская	0101000020E61000008FE046CA16F942403605323B8B924D40
29575	3	27	\N	164	31742	\N	59.143653066804497	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 13"", ул.Пионерская, д.11"		0101000020E6100000A48AE255D6F84240747CB43863924D40
29616	3	27	\N	164	32119	\N	59.121518000000002	Вологодская область, город Череповец, Институт менеджмента и информац. технологий, ул.Первомайская, д.48		0101000020E6100000E0F42EDE8FFB42400BF0DDE68D8F4D40
29578	3	27	\N	164	31673	\N	59.1477608796122	"Вологодская область, город Череповец, ""Череповецкий химико-технологический колледж"", ул.П. Окинина, д.5"	Россия, Вологодская область, Череповец, улица Партизана Окинина, 5	0101000020E610000089B5F81400F94240E84F1BD5E9924D40
29597	3	27	\N	164	26737	\N	59.1279125412049	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 21"", ул.Олимпийская, д.59"	Россия, Вологодская область, Череповец, улица Олимпийская, 59	0101000020E6100000E124CD1FD3004340DBDD03745F904D40
29595	3	27	\N	164	26737	\N	59.1280436750042	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 2"", ул. Олимпийская, д.59"	Россия, Вологодская область, Череповец, улица Олимпийская, 59	0101000020E6100000EDD286C3D20043407A39ECBE63904D40
29534	3	27	\N	164	6923	\N	59.089302000000004	"Вологодская область, город Череповец, ""Ледовый дворец"", Октябрьский пр, д.70"	Россия, Вологодская область, Череповец, Октябрьский проспект, 70	0101000020E610000036936FB6B9F54240D4BB783F6E8B4D40
29532	3	27	\N	164	6923	\N	59.095600913129203	"Вологодская область, город Череповец, ""Детско-юнош. спорт. школа боевых искусств"", Октябрьский пр, д.56"		0101000020E6100000936FB6B931F54240823B50A73C8C4D40
29527	3	27	\N	164	6923	\N	59.086050921247299	"Вологодская область, город Череповец, ""Начальная общеобразовательная школа № 43"", Октябрьский пр, д.67"	Россия, Вологодская область, Череповец, Октябрьский проспект, 67	0101000020E61000009D64ABCB29F54240E0641BB8038B4D40
29526	3	27	\N	164	6923	\N	59.081304651351999	"Вологодская область, город Череповец, клуб ""Звезда"" МБУК ""Дворец металлургов"", Октябрьский пр, д.85"	Россия, Вологодская область, Череповец, Октябрьский проспект, 85	0101000020E61000002EE23B31EBF542402A00C633688A4D40
29571	3	27	\N	164	31861	\N	59.1314806350344	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 25"", ул.Набережная, д.55"	Россия, Вологодская область, Череповец, улица Набережная	0101000020E6100000069E7B0F97F84240CF85915ED4904D40
29581	3	27	\N	164	26506	\N	59.146591999999998	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 29"", ул.Моченкова, д.10"		0101000020E6100000744012F6EDFA424078EDD286C3924D40
29582	3	27	\N	164	32109	\N	59.142775	Вологодская область, город Череповец, общежитие, ул.Молодежная, д.3		0101000020E6100000F86C1D1CECF94240DCD7817346924D40
29541	3	27	\N	164	31906	\N	59.1259657827677	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 12"", ул.Менделеева, д.14"	Россия, Вологодская область, Череповец, улица Менделеева, 14	0101000020E61000007AE063B0E2F24240373465A71F904D40
29538	3	27	\N	164	31804	\N	59.104691996005499	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 8"", ул.Матуринская, д.58"	Россия, Вологодская область, Череповец, улица Матуринская, 58	0101000020E61000003EB14E95EFF542409013268C668D4D40
29565	3	27	\N	164	31737	\N	59.124511609053698	Вологодская область, город Череповец, учебный корпус № 3 ЧГУ, ул.М. Горького, д.14	Россия, Вологодская область, Череповец, улица Максима Горького, 14	0101000020E6100000F1F09E03CBF54240D3FA5B02F08F4D40
29564	3	27	\N	164	31737	\N	59.128025000000001	"Вологодская область, город Череповец, ""Дом музыки и кино"", ул.М. Горького, д.22А"		0101000020E6100000F73E558506F6424003098A1F63904D40
29531	3	27	\N	164	26520	\N	59.094687307277603	"Вологодская область, город Череповец, ""Начальная общеобразовательная школа № 39"", ул.Любецкая, д.19А"	Россия, Вологодская область, Череповец, улица Любецкая, 19а	0101000020E61000002A1F82AAD1F342409D2D20B41E8C4D40
29530	3	27	\N	164	26520	\N	59.094322962180499	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 40"", ул.Любецкая, д.19"	Россия, Вологодская область, Череповец, улица Любецкая, 19	0101000020E610000037DE1D19ABF342405C21ACC6128C4D40
29562	3	27	\N	164	865	\N	59.132737896609399	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 11"", пр.Луначарского, д.44"	Россия, Вологодская область, Череповец, Луначарского проспект	0101000020E61000005BB1BFEC9EF64240DE770C8FFD904D40
29560	3	27	\N	164	865	\N	59.138142594303403	Вологодская область, город Череповец, общежитие, пр. Луначарского, д.53	Россия, Вологодская область, Череповец, Индустриальный район	0101000020E61000006F0F4240BEF64240EE9579ABAE914D40
29533	3	27	\N	164	26523	\N	59.097284999999999	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 32"", ул.Ленинградская, д.14"		0101000020E610000074ED0BE885F5424018B2BAD5738C4D40
29557	3	27	\N	164	31734	\N	59.12585	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 20"", ул.Ленина, д.111"		0101000020E6100000F85278D0ECF44240CE1951DA1B904D40
29549	3	27	\N	164	31734	\N	59.131174000000001	Вологодская область, город Череповец, общежитие, ул.Ленина, д.134		0101000020E610000044882B67EFF04240F20A444FCA904D40
29583	3	27	\N	164	32127	\N	59.133178000000001	"Вологодская область, город Череповец, ""Общеобразовательный лицей ""АМТЭК"", ул.Леднева, д.7"		0101000020E61000004F95EF1989FE4240FA4509FA0B914D40
29594	3	27	\N	164	31667	\N	59.128821467282101	"Вологодская область, город Череповец, ""Центр детского творчества"", ул.Краснодонцев, д.106"	Россия, Вологодская область, Череповец, улица Краснодонцев, 106	0101000020E6100000ED9E3C2CD4004340DE04DF347D904D40
29592	3	27	\N	164	31667	\N	59.130796841749401	"Вологодская область, город Череповец, ""Череповецкая автомобильная школа ДОСААФ"", ул.Краснодонцев, д.118"	Россия, Вологодская область, Череповец, улица Краснодонцев, 118а	0101000020E6100000331B6492910143401CB5C2F4BD904D40
29591	3	27	\N	164	31667	\N	59.129561567537003	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 10"", ул.Краснодонцев, д.66"	Россия, Вологодская область, Череповец, улица Краснодонцев, 66	0101000020E61000007364E597C1FE4240F566D47C95904D40
29590	3	27	\N	164	31667	\N	59.1284475765599	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 24"", ул.Краснодонцев, д.68"	Россия, Вологодская область, Череповец, улица Краснодонцев, 68	0101000020E61000007768588CBAFE4240499EEBFB70904D40
29587	3	27	\N	164	31667	\N	59.127587241813501	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 28"", ул.Краснодонцев, д.40А"	Россия, Вологодская область, Череповец, улица Краснодонцев, 40а	0101000020E61000007D24253D0CFD4240873254C554904D40
29585	3	27	\N	164	31667	\N	59.131112977217697	"Вологодская область, город Череповец, библиотека № 3 МБУК ""Объединение библиотек"", ул.Краснодонцев, д.17"		0101000020E6100000931B45D61AFE42404C8A8F4FC8904D40
29617	3	27	\N	164	31876	\N	59.119019851225197	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 7"", ул.Красная, д.5А"	Россия, Вологодская область, Череповец, улица Красная, 5а	0101000020E6100000C311A452ECFA4240F3C81F0C3C8F4D40
29600	3	27	\N	164	31806	\N	59.1237154670861	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 17"", ул.К. Беляева, д.48"	Россия, Вологодская область, Череповец, улица Космонавта Беляева, 48	0101000020E610000044317903CC0043402783A3E4D58F4D40
29599	3	27	\N	164	31806	\N	59.123780106080702	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 17"", ул.К.Беляева, д.48"	Россия, Вологодская область, Череповец, улица Космонавта Беляева, 48	0101000020E61000004B732B84D50043400EF3E505D88F4D40
29589	3	27	\N	164	31806	\N	59.124410433349503	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 26"", ул.К. Беляева, д.16"	Россия, Вологодская область, Череповец, улица Космонавта Беляева, 16	0101000020E61000004EB857E6ADFE4240CEA5B8AAEC8F4D40
29561	3	27	\N	164	32115	\N	59.136437000000001	Вологодская область, город Череповец, общежитие индустриального колледжа, ул.Комсомольская, д.8		0101000020E61000004A6249B9FBF64240707B82C476914D40
29601	3	27	\N	164	31704	\N	59.115634497758798	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 30"", ул.К. Белова, д.51"	Россия, Вологодская область, Череповец, улица Командарма Белова	0101000020E6100000611BF16437FF424020274C18CD8E4D40
29548	3	27	\N	164	31848	\N	59.126859249320802	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 16"", Клубный проезд, д.2"	Россия, Вологодская область, Череповец, Клубный проезд, 2	0101000020E61000008675E3DD91F14240051A6CEA3C904D40
29540	3	27	\N	164	31914	\N	59.1214319068904	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 21"", пр.Строителей, д.11"	Россия, Вологодская область, Череповец, Доменщиков бульвар, 11	0101000020E61000000ADCBA9BA7F242400C5872158B8F4D40
29016	3	27	\N	17	341	\N	59.205632000000001	Вологодская область, город Вологда, Тендрякова, 46	Россия, Вологодская область, Вологда, улица Тендрякова, 46	0101000020E61000004982700514EC43406B813D26529A4D40
29539	3	27	\N	164	31914	\N	59.120448832111798	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 3"", пр.Строителей, д.11Б"	Россия, Вологодская область, Череповец, Доменщиков бульвар, 11а	0101000020E6100000A48B4D2B85F24240FFEA71DF6A8F4D40
29529	3	27	\N	164	32025	\N	59.088901835004798	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 14"", ул.Городецкая, д.20"	Россия, Вологодская область, Череповец, улица Городецкая, 20	0101000020E6100000978DCEF929F4424045460724618B4D40
29528	3	27	\N	164	32025	\N	59.089543764663503	"Вологодская область, город Череповец, ""Детско-юношеская спортивная школа № 4"", ул.Городецкая, д.26"	Россия, Вологодская область, Череповец, улица Городецкая, 26	0101000020E6100000AE65321CCFF34240C9C6832D768B4D40
29615	3	27	\N	164	31999	\N	59.121254999999998	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 31"", ул.Гоголя, д.34"		0101000020E610000089EAAD81ADFA4240FDBCA948858F4D40
29614	3	27	\N	164	31999	\N	59.121980000000001	"Вологодская область, город Череповец, ""Череповецкий техникум сферы обслуживания"", ул.Гоголя, д.21"		0101000020E61000004C1762F547FA42400F62670A9D8F4D40
29613	3	27	\N	164	31999	\N	59.121882999999997	Вологодская область, город Череповец, общежитие, ул.Гоголя, д.36		0101000020E61000004B3ACAC16CFA42401C78B5DC998F4D40
29551	3	27	\N	164	31793	\N	59.133609129652903	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 15"", ул.Гагарина, д.41"		0101000020E61000000EA2B5A2CDF14240C3B986191A914D40
29559	3	27	\N	164	31794	\N	59.134526000000001	Вологодская область, город Череповец, "Средняя общеобразовательная школа № 4", ул.Вологодская, д.23		0101000020E61000009A43520B25F54240193BE12538914D40
29558	3	27	\N	164	31794	\N	59.133580956226602	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 22"", ул.Вологодская, д.21"	Россия, Вологодская область, Череповец, улица Вологодская, 21	0101000020E6100000BBF2599E07F54240F92EA52E19914D40
29556	3	27	\N	164	31794	\N	59.1277416624674	"Вологодская область, город Череповец, ""Детская школа искусств"", ул.Вологодская, д.3"	Россия, Вологодская область, Череповец, улица Вологодская, 3	0101000020E610000015E126A3CAF44240AE2990D959904D40
29608	3	27	\N	164	32014	\N	59.117151198989497	Вологодская область, город Череповец, библиотека № 8 МБУК "Объединение библиотек",ул.Архангельская, д.7-а	Россия, Вологодская область, Череповец, улица Архангельская, 7а	0101000020E6100000F793313ECCFC4240CBD8D0CDFE8E4D40
29586	3	27	\N	164	32014	\N	59.174782999999998	"Вологодская область, город Череповец, ""Центр детского творчества"", ул.Архангельская, д.100Б"		0101000020E6100000876BB587BDE24240C972124A5F964D40
29553	3	27	\N	164	31736	\N	59.130744	"Вологодская область, город Череповец, ""Средняя общеобразовательная школа № 6"", ул.Металлургов, д.19"		0101000020E610000046072461DFF24240F9122A38BC904D40
29408	3	27	\N	53270	31872	\N	58.842053107380202	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Ленина, 6		0101000020E6100000CC608C4814364240D53F8864C86B4D40
29437	3	27	\N	53270	31887	\N	58.833732691898398	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Коммунистический, 41	Россия, Вологодская область, Устюженский район, Устюжна	0101000020E610000054C6BFCFB8364240494C50C3B76A4D40
29277	3	27	\N	53263	31835	\N	59.456728704248498	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Суворова, д.6	Россия, Вологодская область, Сокольский район, Сокол	0101000020E61000001AA88C7F9F0F444041118B1876BA4D40
29293	3	27	\N	53263	31833	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Кооперативная, д.14а		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29286	3	27	\N	53263	32048	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Беляева, д.11/2		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29213	3	27	\N	53266	31812	\N	59.532808851059301	Вологодская область, Никольский муниципальный район, муниципальное образование город Никольск, ул.25 Октября, д.1	Россия, Вологодская область, Никольский район, Никольск	0101000020E61000004D309C6B98BB4640DA01D71533C44D40
28930	3	27	\N	29401	26479	\N	59.257832999999998	Вологодская область, Вологодский район, п. Кувшиново, Дачная, 1		0101000020E61000006AA33A1DC8E843402F6AF7AB00A14D40
29096	3	27	\N	53249	31689	\N	58.875537000000001	Грязовецкий район г.Грязовец, ул. Румянцевой, 43-Б Детская консультация БУЗ "Грязовецкая ЦРБ".		0101000020E610000077853E58C61E44400FB8AE9811704D40
29099	3	27	\N	53249	31842	\N	58.875537000000001	Грязовецкий район г.Грязовец, ул. Комсомольская, д.49 Управление образования		0101000020E610000077853E58C61E44400FB8AE9811704D40
29094	3	27	\N	53249	31769	\N	58.875537000000001	Вологодская область, Грязовецкий район, г.Грязовец, ул.Газовиков, 26-А		0101000020E610000077853E58C61E44400FB8AE9811704D40
28949	3	27	\N	17	7716	\N	59.195025000000001	Вологодская область, город Вологда, Ярославская, 34а	Россия, Вологодская область, Вологда, улица Ярославская, 34а	0101000020E610000085CD001764EF434082734694F6984D40
29017	3	27	\N	17	371	\N	59.208216999999998	Вологодская область, город Вологда, Щетинина, 2а	Россия, Вологодская область, Вологда, улица Щетинина, 2а	0101000020E6100000E2AE5E4546EB434051BCCADAA69A4D40
28980	3	27	\N	17	722	\N	59.242179999999998	Вологодская область, город Вологда, Чернышевского, 114	Россия, Вологодская область, Вологда, улица Чернышевского, 114	0101000020E6100000A629029CDEF3434065DF15C1FF9E4D40
13484	7	66	939	15469	61831	\N	55.949496000000003	село Ойкас-Асламасы, Школьная, 1/3		0101000020E6100000965AEF37DA3F474067D7BD1589F94B40
29022	3	27	\N	17	437	\N	59.209820000000001	Вологодская область, город Вологда, Солодунова, 54	Россия, Вологодская область, Вологда, улица Солодунова, 54	0101000020E61000006C95607138EB4340FB05BB61DB9A4D40
28997	3	27	\N	17	41	\N	59.208097000000002	Вологодская область, город Вологда, Пугачёва, 40а	Россия, Вологодская область, Вологда, улица Пугачева, 40а	0101000020E6100000B35C363AE7F74340A7B228ECA29A4D40
29002	3	27	\N	17	136	\N	59.229737999999998	Вологодская область, город Вологда, Пролетарская, 18	Россия, Вологодская область, Вологда, улица Пролетарская, 20	0101000020E6100000F9DC09F65FEF43400053060E689D4D40
28970	3	27	\N	17	7661	\N	59.193836331441901	Вологодская область, город Вологда, Пригородная, 12	Россия, Вологодская область, Вологда, улица Пригородная	0101000020E610000007B5DFDA89F44340CB64389ECF984D40
28966	3	27	\N	17	7661	\N	59.194408000000003	Вологодская область, город Вологда, Пригородная, 14	Россия, Вологодская область, Вологда, улица Пригородная, 8	0101000020E6100000BFD364C6DBF44340570A815CE2984D40
29020	3	27	\N	17	400	\N	59.219548000000003	Вологодская область, город Вологда, Преображенского, 49	Россия, Вологодская область, Вологда, улица Преображенского, 49	0101000020E6100000D9EA724A40EA43407CF31B261A9C4D40
28962	3	27	\N	17	7850	\N	59.174473999999996	Вологодская область, город Вологда, Пионерская, 20	Россия, Вологодская область, Вологда, улица Пионерская, 20	0101000020E6100000B18BA2073EFE43404B00FE2955964D40
28946	3	27	\N	17	6061	\N	59.208747000000002	Вологодская область, город Вологда, Первомайская, 42	Россия, Вологодская область, Вологда, улица Первомайская, 42	0101000020E61000005B5B785E2AF24340AE11C138B89A4D40
28788	3	27	\N	17	6061	\N	59.211865000000003	Вологодская область, Вашкинский муниципальный район, с.Липин Бор, Первомайская,3	Россия, Вологодская область, Вологда, улица Первомайская, 3	0101000020E61000006F47382D78F3434062156F641E9B4D40
29019	3	27	\N	17	392	\N	59.216014999999999	Вологодская область, город Вологда, Панкратова, 75	Россия, Вологодская область, Вологда, улица Панкратова, 75	0101000020E6100000861DC6A4BFE9434004392861A69B4D40
28982	3	27	\N	17	8044	\N	59.226726999999997	Вологодская область, город Вологда, Некрасова, 51	Россия, Вологодская область, Вологда, улица Некрасова, 51/18	0101000020E6100000310C587215F54340620FED63059D4D40
28974	3	27	\N	17	7963	\N	59.200532000000003	Вологодская область, город Вологда, Медуницинская, 21	Россия, Вологодская область, Вологда, улица Медуницинская, 21	0101000020E61000004A9BAA7B64ED434097E65608AB994D40
29057	3	27	\N	17	958	\N	59.214734999999997	Вологодская область, Вытегорский муниципальный район, муниципальное образование город Вытегра, Кирпичная, 1	Россия, Вологодская область, Вологда, улица Кирпичная, 3	0101000020E61000003291D26C1EED43403D27BD6F7C9B4D40
28987	3	27	\N	17	8091	\N	59.222822000000001	Вологодская область, город Вологда, Карла Маркса, 66а	Россия, Вологодская область, Вологда, улица Карла Маркса, 66а	0101000020E6100000D8666325E6F54340276A696E859C4D40
29023	3	27	\N	17	460	\N	59.209009000000002	Вологодская область, город Вологда, Ильюшина, 15	Россия, Вологодская область, Вологда, улица Ильюшина, 15	0101000020E61000003317B83CD6E84340EBC891CEC09A4D40
29175	3	27	\N	17	2691	\N	59.228167999999997	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Городецкое, с.Кичменгский Городок, Заречная, 50	Россия, Вологодская область, Вологда, улица Заречная, 52	0101000020E6100000A8C5E061DAF5434032FFE89B349D4D40
29009	3	27	\N	17	238	\N	59.238920999999998	Вологодская область, город Вологда, Залинейная, 24в	Россия, Вологодская область, Вологда, улица Залинейная, 24в	0101000020E6100000FE9B1727BEEC4340EFA99CF6949E4D40
28992	3	27	\N	17	7986	\N	59.218243999999999	Вологодская область, город Вологда, Горького, 140	Россия, Вологодская область, Вологда, улица Горького, 140	0101000020E6100000E9B6442E38F543402C465D6BEF9B4D40
28990	3	27	\N	17	7986	\N	59.221601999999997	Вологодская область, город Вологда, Горького, 105	Россия, Вологодская область, Вологда, улица Горького, 105	0101000020E6100000293E3E213BF54340355D4F745D9C4D40
28951	3	27	\N	17	7729	\N	59.208917	Вологодская область, город Вологда, Герцена, 60	Россия, Вологодская область, Вологда, улица Герцена, 60	0101000020E610000003B68311FBF243400A4AD1CABD9A4D40
29005	3	27	\N	17	32104	\N	59.225714000000004	Вологодская область, город Вологда, Проспект Победы, 50		0101000020E6100000DA0418963FEF4340EB1F4432E49C4D40
28960	3	27	\N	17	32120	\N	59.191642000000002	Вологодская область, город Вологда, Беляева, 22а		0101000020E610000000ADF9F197F6434020459DB987984D40
28973	3	27	\N	17	32112	\N	59.196232999999999	Вологодская область, город Вологда, Ярославская, 26а		0101000020E610000016325706D5EE4340AFB2B6291E994D40
28957	3	27	\N	17	32107	\N	59.200491	Вологодская область, город Вологда, Элеваторная, 37		0101000020E61000005FEE93A300F94340381268B0A9994D40
29024	3	27	\N	17	32076	\N	59.208196931151797	Вологодская область, город Вологда, Щетинина,2-а,Институт права и экономики ФСИН	Россия, Вологодская область, Вологда, улица Щетинина, 2а	0101000020E6100000492D944C4EEB43400A100533A69A4D40
29444	3	27	\N	17	6048	\N	59.203937000000003	Вологодская область, Харовский муниципальный район, муниципальное образование город Харовск, переулок Школьный, 5	Россия, Вологодская область, Вологда, Школьный переулок, 5	0101000020E610000012F758FAD0EF4340E1B88C9B1A9A4D40
28979	3	27	\N	17	32053	\N	59.235469000000002	Вологодская область, город Вологда, Чернышевского, 78		0101000020E61000008C15359886F34340651C23D9239E4D40
28978	3	27	\N	17	32053	\N	59.230745014610697	Вологодская область, город Вологда, Чернышевского, 53	Россия, Вологодская область, Вологда, улица Чернышевского, 53	0101000020E61000005534D6FECEF24340965B5A0D899D4D40
28977	3	27	\N	17	32053	\N	59.234765000000003	Вологодская область, город Вологда, Чернышевского, 73		0101000020E610000091D3D7F335F343406B9F8EC70C9E4D40
28948	3	27	\N	17	7704	\N	59.207245	Вологодская область, город Вологда, Техникумовский переулок, 4	Россия, Вологодская область, Вологда, Техникумовский переулок, 4	0101000020E6100000AB5B3D27BDF1434038A11001879A4D40
29018	3	27	\N	17	32096	\N	59.205632000000001	Вологодская область, город Вологда, ул.Тендрякова,46 Школа№28		0101000020E61000004982700514EC43406B813D26529A4D40
28981	3	27	\N	17	32129	\N	59.269753999999999	Вологодская область, город Вологда, Строителей, 10		0101000020E61000002098A3C7EFF143408BFB8F4C87A24D40
28956	3	27	\N	17	625	\N	59.205401999999999	Вологодская область, город Вологда, Советский проспект, 120	Россия, Вологодская область, Вологда, Советский проспект, 120	0101000020E6100000ECC039234AF543403944DC9C4A9A4D40
28954	3	27	\N	17	625	\N	59.213123000000003	Вологодская область, город Вологда, Советский проспект, 54	Россия, Вологодская область, Вологда, Советский проспект, 54	0101000020E6100000A3C9C51858F3434041834D9D479B4D40
28998	3	27	\N	17	32132	\N	59.218589999999999	Вологодская область, город Вологда, Северная, 17		0101000020E6100000B97020240BF84340C79DD2C1FA9B4D40
28994	3	27	\N	17	32132	\N	59.214758000000003	Вологодская область, город Вологда, Северная, 6а		0101000020E6100000E38E37F92DF64340F646AD307D9B4D40
28988	3	27	\N	17	32130	\N	59.225183999999999	Вологодская область, город Вологда, Саммера, 1		0101000020E61000001AFCFD62B6F443408ECA4DD4D29C4D40
29006	3	27	\N	17	32087	\N	59.221545999999996	Вологодская область, город Вологда, Пролетарская, 73		0101000020E6100000419C871398EE4340A1478C9E5B9C4D40
28944	3	27	\N	17	32079	\N	59.194408000000003	Вологодская область, город Вологда, Пригородная,14 школа №36	Россия, Вологодская область, Вологда, улица Пригородная, 8	0101000020E6100000BFD364C6DBF44340570A815CE2984D40
28975	3	27	\N	17	756	\N	59.195196000000003	Вологодская область, город Вологда, Пошехонское шоссе, 26	Россия, Вологодская область, Вологда, Пошехонское шоссе, 26	0101000020E6100000F9BD4D7FF6ED4340AF27BA2EFC984D40
29004	3	27	\N	17	156	\N	59.225714000000004	Вологодская область, город Вологда, Проспект  Победы, 50	Россия, Вологодская область, Вологда, Победы проспект, 50	0101000020E6100000DA0418963FEF4340EB1F4432E49C4D40
29003	3	27	\N	17	156	\N	59.222850000000001	Вологодская область, город Вологда, Проспект Победы, 37	Россия, Вологодская область, Вологда, Победы проспект, 37	0101000020E6100000919BE1067CF04340F1F44A59869C4D40
28952	3	27	\N	17	32105	\N	59.207557999999999	Вологодская область, город Вологда, Пирогова, 26		0101000020E6100000C4E8B985AEF24340F702B342919A4D40
28961	3	27	\N	17	32094	\N	59.174473999999996	Вологодская область, город Вологда, п.Лоста, Пионерская, 20		0101000020E6100000B18BA2073EFE43404B00FE2955964D40
28965	3	27	\N	17	32110	\N	59.188347	Вологодская область, город Вологда, Петрозаводская, 20		0101000020E61000002C67EF8CB6F643405DA626C11B984D40
28964	3	27	\N	17	32110	\N	59.186028	Вологодская область, город Вологда, Петрозаводская, 24а		0101000020E6100000E7C589AF76F64340F511F8C3CF974D40
29026	3	27	\N	17	32116	\N	59.213132000000002	Вологодская область, город Вологда, Первый МКР ГПЗ-23, 2б		0101000020E6100000AFEE586C93E8434094DDCCE8479B4D40
29025	3	27	\N	17	32116	\N	59.212178999999999	Вологодская область, город Вологда, Первый МКР ГПЗ-23, 17		0101000020E610000004594FADBEE84340F1F274AE289B4D40
28953	3	27	\N	17	32092	\N	59.210189	Вологодская область, город Вологда, Первомайская, 30		0101000020E610000062A2410A9EF243404E7D2079E79A4D40
28983	3	27	\N	17	32118	\N	59.226914999999998	Вологодская область, город Вологда, Открытая, 9		0101000020E61000005A48C0E8F2F6434065FCFB8C0B9D4D40
28971	3	27	\N	17	26527	\N	59.180007000000003	Вологодская область, город Вологда, Осаново, 14а		0101000020E6100000427A8A1C22F243408A0629780A974D40
29028	3	27	\N	17	520	\N	59.196804	Вологодская область, город Вологда, Окружное шоссе, 23а	Россия, Вологодская область, Вологда, Окружное шоссе, 23а	0101000020E61000005DC30C8D27EA43406ADC9BDF30994D40
28984	3	27	\N	17	8064	\N	59.229787999999999	Вологодская область, город Вологда, Некрасовский переулок, 15а	Россия, Вологодская область, Вологда, Некрасовский переулок, 15а	0101000020E610000038842A357BF44340B28174B1699D4D40
28963	3	27	\N	17	7870	\N	59.182087000000003	Вологодская область, город Вологда, Московское шоссе, 34	Россия, Вологодская область, Вологда, Московское шоссе, 34	0101000020E610000064AE0CAA0DFA43406D0377A04E974D40
28972	3	27	\N	17	32099	\N	59.203780000000002	Вологодская область, город Вологда, Можайского, 15а		0101000020E61000000F9C33A2B4F1434019CA8976159A4D40
29000	3	27	\N	17	32136	\N	59.215029999999999	Вологодская область, город Вологда, Мира, 56		0101000020E6100000494C50C3B7F0434056D4601A869B4D40
28996	3	27	\N	17	32089	\N	59.208784000000001	Вологодская область, город Вологда, Машиностроительная, 26		0101000020E61000007D3ECA880BF64340CBF6216FB99A4D40
29443	3	27	\N	17	6033	\N	59.213068	Вологодская область, Харовский муниципальный район, муниципальное образование город Харовск, переулок Майский, 4	Россия, Вологодская область, Вологда, Майский переулок, 4	0101000020E6100000C172840CE4EB43407DE9EDCF459B4D40
29008	3	27	\N	17	32101	\N	59.222558999999997	Вологодская область, город Вологда, Ленинградская, 5		0101000020E6100000D6C9198A3BF04340193735D07C9C4D40
28945	3	27	\N	17	32091	\N	59.221772000000001	Вологодская область, город Вологда, Ленина, 17		0101000020E6100000E200FA7DFFF2434092955F06639C4D40
29029	3	27	\N	17	32113	\N	59.201982999999998	Вологодская область, город Вологда, Костромская, 6		0101000020E6100000EC866D8B32EB43408AAC3594DA994D40
28967	3	27	\N	17	32095	\N	59.195062	Вологодская область, город Вологда, Беляева, 9		0101000020E610000009FCE1E7BFF543409F58A7CAF7984D40
28958	3	27	\N	17	32095	\N	59.194195999999998	Вологодская область, город Вологда, Беляева, 13		0101000020E6100000ADFC321823F64340CB811E6ADB984D40
12896	7	66	215	19018	62129	\N	55.221209000000002	д.Старые Высли, Калинина, 46		0101000020E61000002E1F49490FA947405A4A9693509C4B40
28955	3	27	\N	17	32090	\N	59.206263999999997	Вологодская область, город Вологда, Козлёнская, 99		0101000020E6100000BF60376C5BF44340CB2BD7DB669A4D40
28947	3	27	\N	17	32090	\N	59.212634999999999	Вологодская область, город Вологда, Козленская, 57		0101000020E6100000433D7D04FEF24340137EA99F379B4D40
29007	3	27	\N	17	32134	\N	59.216991999999998	Вологодская область, город Вологда, Кирова, 35		0101000020E6100000882D3D9AEAEF43402FBFD364C69B4D40
28999	3	27	\N	17	32114	\N	59.215260000000001	Вологодская область, город Вологда, Канифольная, 1		0101000020E6100000923F1878EEF943408811C2A38D9B4D40
29027	3	27	\N	17	32126	\N	59.208719000000002	Вологодская область, город Вологда, Ильюшина, 23		0101000020E6100000BA86191A4FE84340E486DF4DB79A4D40
29031	3	27	\N	17	32012	\N	59.289980508594198	Вологодская область, город Вологда, с.Молочное, Емельянова, 1		0101000020E61000004DDA54DD23D743400EBBEF181EA54D40
28995	3	27	\N	17	32131	\N	59.220717	Вологодская область, город Вологда, Дальняя, 32а		0101000020E6100000D925AAB706F84340EB556474409C4D40
28993	3	27	\N	17	32084	\N	59.217485000000003	Вологодская область, город Вологда, Горького, 115		0101000020E61000000FED6305BFF543406F2F698CD69B4D40
28986	3	27	\N	17	32084	\N	59.225506000000003	Вологодская область, город Вологда, Горького, 93		0101000020E61000000BD0B69A75F44340A1866F61DD9C4D40
28985	3	27	\N	17	32084	\N	59.225746000000001	Вологодская область, город Вологда, Горького, 86а		0101000020E61000008751103CBEF34340F699B33EE59C4D40
28943	3	27	\N	17	32123	\N	59.217267999999997	Вологодская область, город Вологда, Городской вал, 26а		0101000020E610000032022A1C41F64340D13B1570CF9B4D40
28942	3	27	\N	17	32123	\N	59.217852999999998	Вологодская область, город Вологда, Городской вал, 26		0101000020E6100000F965304624F64340F12A6B9BE29B4D40
28950	3	27	\N	17	32103	\N	59.210892999999999	Вологодская область, город Вологда, Герцена, 53		0101000020E610000070B1A206D3F2434048FAB48AFE9A4D40
29021	3	27	\N	17	32122	\N	59.206401999999997	Вологодская область, город Вологда, Гагарина, 81		0101000020E610000057AF22A303EA43401CEA77616B9A4D40
29014	3	27	\N	17	32122	\N	59.210714000000003	Вологодская область, город Вологда, Гагарина, 46		0101000020E6100000774A07EBFFEA4340996725ADF89A4D40
29010	3	27	\N	17	32122	\N	59.213422000000001	Вологодская область, город Вологда, Гагарина, 40		0101000020E6100000207C28D192EB43409B1F7F69519B4D40
29013	3	27	\N	17	32088	\N	59.246541999999998	Вологодская область, город Вологда, Вологодская, 6а		0101000020E61000006090F46915EB4340938B31B08E9F4D40
29015	3	27	\N	17	32124	\N	59.208691000000002	Вологодская область, город Вологда, Возрождения, 1		0101000020E6100000FB5A971AA1ED43401AFCFD62B69A4D40
28969	3	27	\N	17	32121	\N	59.198905000000003	Вологодская область, город Вологда, Болонина, 32		0101000020E6100000077AA86DC3F24340650113B875994D40
28959	3	27	\N	17	32121	\N	59.199236999999997	Вологодская область, город Вологда, Болонина, 25		0101000020E6100000B56FEEAF1EF343409A93179980994D40
29001	3	27	\N	17	32055	\N	59.220989000000003	Вологодская область, город Вологда, Батюшкова, 2		0101000020E610000063601DC70FF143404CE3175E499C4D40
28968	3	27	\N	17	32125	\N	59.185147999999998	Вологодская область, город Вологда, Архангельская, 11б		0101000020E6100000E9BAF083F3F34340BC75FEEDB2974D40
29012	3	27	\N	17	32054	\N	59.231459000000001	Вологодская область, город Вологда, Ананьинская, 41а		0101000020E61000001A34F44F70E14340B4AED172A09D4D40
29011	3	27	\N	17	32102	\N	59.238714000000002	Вологодская область, город Вологда, Клубова, 56		0101000020E6100000C91CCBBBEAE74340768C2B2E8E9E4D40
28989	3	27	\N	17	31677	\N	59.218742039966301	Вологодская область, город Вологда, Набережная VI Армии, 199	Россия, Вологодская область, Вологда, 6 Армии набережная, 199	0101000020E61000000D8E9257E7F443407D21E4BCFF9B4D40
28991	3	27	\N	17	32106	\N	59.220565000000001	Вологодская область, город Вологда, Горького, 107		0101000020E61000001F662FDB4EF5434035D252793B9C4D40
28976	3	27	\N	17	32106	\N	59.227536999999998	Вологодская область, город Вологда, Горького, 57		0101000020E6100000FC1A498270F34340A2D0B2EE1F9D4D40
28703	3	27	\N	53250	31695	\N	59.396777	Вологодская область, Бабаевский муниципальный район,  город Бабаево, Мира, 1		0101000020E6100000CE70033E3FF841400A67B796C9B24D40
29648	3	27	1561	32194	31825	\N	59.058005000000001	Вологодская область, Шекснинский муниципальный район, д. Юрочкино, ул. Школьная, 11		0101000020E6100000DFDFA0BDFA444340930035B56C874D40
29638	3	27	1561	31775	\N	\N	59.376764999999999	Вологодская область, Шекснинский муниципальный район, д. Шигоево, 20		0101000020E610000075E789E76C41434083A3E4D539B04D40
29625	3	27	1561	53276	31941	\N	59.233317376153899	Вологодская область, Шекснинский муниципальный район, п. Шексна, ул. Юбилейная, 10	Россия, Вологодская область, Шекснинский район, поселок Шексна 2-я	0101000020E6100000C03E3A75E5414340E84CDA54DD9D4D40
29626	3	27	1561	30890	31885	\N	59.2077368228057	Вологодская область, Шекснинский муниципальный район, п. Шексна, ул. Шлюзовая, 20	Россия, Вологодская область, Шекснинский район, поселок Шексна	0101000020E6100000143FC6DCB5424340A7954220979A4D40
29624	3	27	1561	30890	26607	\N	59.219110000000001	Вологодская область, Шекснинский муниципальный район, п. Шексна, ул. Труда, 16		0101000020E6100000FF791A3048424340001DE6CB0B9C4D40
29622	3	27	1561	30890	31676	\N	59.219110000000001	Вологодская область, Шекснинский муниципальный район, п. Шексна, ул. Октябрьская, 54		0101000020E6100000FF791A3048424340001DE6CB0B9C4D40
29623	3	27	1561	30890	31933	\N	59.219110000000001	Вологодская область, Шекснинский муниципальный район, п. Шексна, ул. Зеленая, 15		0101000020E6100000FF791A3048424340001DE6CB0B9C4D40
29620	3	27	1561	30890	31950	\N	59.2191627244081	Вологодская область, Шекснинский муниципальный район, п. Шексна, ул. Дзержинского, 6	Россия, Вологодская область, Шекснинский район, поселок Шексна	0101000020E61000003CBD52962142434023BF7E880D9C4D40
29621	3	27	1561	30890	31934	\N	59.219110000000001	Вологодская область, Шекснинский муниципальный район, п. Шексна, ул. Гагарина, 16		0101000020E6100000FF791A3048424340001DE6CB0B9C4D40
29642	3	27	1561	31937	\N	\N	59.257952000000003	Вологодская область, Шекснинский муниципальный район, с. Чуровское, 17		0101000020E6100000BE6C3B6D8D4C43400AF8359204A14D40
29365	3	27	1561	18687	\N	\N	59.132401999999999	Вологодская область, Шекснинский муниципальный район, д. Чернеево, 2		0101000020E6100000170FEF39B076434066F6798CF2904D40
29627	3	27	1561	31236	31938	\N	59.146056000000002	Вологодская область, Шекснинский муниципальный район, п. Чебсара, ул. Ленина, 4		0101000020E610000043E6CAA0DA6043403AB187F6B1924D40
29639	3	27	1561	31822	26445	\N	59.339675	Вологодская область, Шекснинский муниципальный район, с. Чаромское, ул. Шоссейная, 14		0101000020E6100000B74604E3E04E434068226C787AAB4D40
29650	3	27	1561	32284	\N	\N	58.982917999999998	Вологодская область, Шекснинский муниципальный район, д. Фоминское, 2		0101000020E6100000DC2BF3565D8743402A53CC41D07D4D40
29636	3	27	1561	31698	\N	\N	59.418334000000002	Вологодская область, Шекснинский муниципальный район, д. Сыромяткино, 4		0101000020E6100000E1968FA4A46543400667F0F78BB54D40
29644	3	27	1561	32025	\N	\N	59.214711999999999	Вологодская область, Шекснинский муниципальный район, д. Слизово, 21а		0101000020E61000006405BF0D315043408507CDAE7B9B4D40
29635	3	27	1561	31647	31939	\N	59.414470000000001	Вологодская область, Шекснинский муниципальный район, с. Сизьма, ул. Ветеранов, 12а		0101000020E61000005BEA20AF075B434029965B5A0DB54D40
29634	3	27	1561	31574	\N	\N	59.483964	Вологодская область, Шекснинский муниципальный район, д. Раменье, 37		0101000020E6100000683D7C99283E43407E384888F2BD4D40
29628	3	27	1561	31305	31997	\N	59.193845000000003	Вологодская область, Шекснинский муниципальный район, д. Прогресс, ул. Центральная, 54		0101000020E6100000856055BDFC4043401FBFB7E9CF984D40
29630	3	27	1561	31393	31869	\N	59.179385000000003	Вологодская область, Шекснинский муниципальный район, д. Пача, ул. Центральная, 28		0101000020E6100000EC4FE273272843404D327216F6964D40
29629	3	27	1561	31318	31903	\N	59.210616999999999	Вологодская область, Шекснинский муниципальный район, д. Нифантово, ул. Нифантовская, 1а		0101000020E61000000E315EF3AA3A4340A67D737FF59A4D40
29610	3	27	1561	30397	26413	\N	59.12191	Вологодская область, Шекснинский муниципальный район, д. Нестерово, 3		0101000020E610000058207A5226814340168733BF9A8F4D40
29640	3	27	1561	31843	\N	\N	59.311903999999998	Вологодская область, Шекснинский муниципальный район, д. Медвежье, 18а		0101000020E61000007DCA3159DC534340ECBE6378ECA74D40
29643	3	27	1561	32015	\N	\N	59.277321999999998	Вологодская область, Шекснинский муниципальный район, д. Малинуха, 65		0101000020E6100000053411363C4343400C3B8C497FA34D40
29646	3	27	1561	32115	26619	\N	59.103496	Вологодская область, Шекснинский муниципальный район, с. Любомирово, ул. Школьная, 11		0101000020E61000000ED76A0F7B61434027A25F5B3F8D4D40
29637	3	27	1561	31713	32026	\N	59.383045000000003	Вологодская область, Шекснинский муниципальный район, д. Княже, ул. Зеленая, 2		0101000020E6100000FF04172B6A504340BBF2599E07B14D40
29641	3	27	1561	31921	\N	\N	59.324399	Вологодская область, Шекснинский муниципальный район, д. Квасюнино, 11		0101000020E6100000DC662AC42343434074ED0BE885A94D40
29633	3	27	1561	31538	\N	\N	59.560696999999998	Вологодская область, Шекснинский муниципальный район, д. Камешник, 9		0101000020E6100000454772F90F2F43408FFB56EBC4C74D40
29632	3	27	1561	31482	\N	\N	59.361479000000003	Вологодская область, Шекснинский муниципальный район, д. Игнатовское, 30	Россия, Вологодская область, Шекснинский район, село Игнатовское	0101000020E61000006B9C4D47002B43406C98A1F144AE4D40
29602	3	27	1561	29989	\N	\N	59.359909999999999	Вологодская область, Шекснинский муниципальный район, д. Ершово, 79		0101000020E61000009BCB0D863A3443406EC0E78711AE4D40
29574	3	27	1561	28721	\N	\N	59.160060999999999	Вологодская область, Шекснинский муниципальный район, д. Добрец, 61		0101000020E610000015CAC2D7D72C4340BA2EFCE07C944D40
29584	3	27	1561	29185	\N	\N	59.272880999999998	Вологодская область, Шекснинский муниципальный район, д. Демидово, 80		0101000020E6100000C154336B292443409259BDC3EDA24D40
29647	3	27	1561	32167	31757	\N	59.136251999999999	Вологодская область, Шекснинский муниципальный район, с. Братково, ул. Центральная, 8		0101000020E61000009065C1C41F674340DE019EB470914D40
29649	3	27	1561	32277	32004	\N	59.131594	Вологодская область, Шекснинский муниципальный район, д. Большое Ивановское, ул. Сосновая, 4		0101000020E6100000A6D425E318594340C72C7B12D8904D40
29522	3	27	296	26354	31961	\N	58.739148999999998	Вологодская область, Череповецкий муниципальный район, д. Ягница, Журавлевская, 23		0101000020E61000007F315BB22AC6424080EF366F9C5E4D40
29521	3	27	296	26281	26509	\N	59.333877999999999	Вологодская область, Череповецкий муниципальный район, с. Яганово, Центральная, 15		0101000020E610000039F06AB9331143404C6DA983BCAA4D40
29519	3	27	296	26210	26507	\N	58.817593000000002	Вологодская область, Череповецкий муниципальный район, с. Щетинское, Рыбинская, 83		0101000020E6100000F75AD07B6328434022382EE3A6684D40
29484	3	27	296	24591	31878	\N	59.230086999999997	Вологодская область, Череповецкий муниципальный район, с. Шухободь, Центральная, 6		0101000020E61000006E88F19A57DB42400C1EA67D739D4D40
29501	3	27	296	25389	31956	\N	59.204940999999998	Вологодская область, Череповецкий муниципальный район, д. Шулма, Центральная, 15		0101000020E610000034828DEBDFC54240054EB6813B9A4D40
29498	3	27	296	25244	\N	\N	58.853909000000002	Вологодская область, Череповецкий муниципальный район, д. Шишовка, 66		0101000020E61000003FE08101846F43404A61DEE34C6D4D40
29518	3	27	296	26173	32021	\N	58.963704999999997	Вологодская область, Череповецкий муниципальный район, д. Шалимово, Молодежная, 2 а		0101000020E610000070EB6E9EEA4E4340EFFE78AF5A7B4D40
29490	3	27	296	24898	\N	\N	59.084077999999998	Вологодская область, Череповецкий муниципальный район, п. Шайма, клуб воинской части		0101000020E6100000A1DB4B1AA30F434013286211C38A4D40
29494	3	27	296	25047	31718	\N	58.928089	Вологодская область, Череповецкий муниципальный район, д. Чаево, Центральная, 5		0101000020E61000008DD2A57F499C42408063CF9ECB764D40
29505	3	27	296	25557	\N	\N	58.803103	Вологодская область, Череповецкий муниципальный район, д. Харламовская, 94		0101000020E6100000BDAAB35A609B4240E5284014CC664D40
29421	3	27	296	21630	\N	\N	59.560108999999997	Вологодская область, Череповецкий муниципальный район, п. Улазорский, 13		0101000020E6100000F27C06D49BB14240FE98D6A6B1C74D40
29515	3	27	296	26045	31726	\N	59.195577999999998	Вологодская область, Череповецкий муниципальный район, п. Тоншалово, Труда, 3		0101000020E61000009AEAC9FCA3F9424096E82CB308994D40
29516	3	27	296	26045	26446	\N	59.195577999999998	Вологодская область, Череповецкий муниципальный район, п. Тоншалово, Рабочая, 14-а		0101000020E61000009AEAC9FCA3F9424096E82CB308994D40
29512	3	27	296	25918	26662	\N	58.992840000000001	Вологодская область, Череповецкий муниципальный район, д. Сурково, Центральная, 75		0101000020E610000043739D465A2A434090149161157F4D40
29507	3	27	296	25635	26660	\N	59.151636000000003	Вологодская область, Череповецкий муниципальный район, п. Суда, Пушкина, 6		0101000020E6100000309C6B98A1C94240B972F6CE68934D40
29508	3	27	296	25635	31774	\N	59.139443198572202	Вологодская область, Череповецкий муниципальный район, п. Суда, Заводская, 4	Россия, Вологодская область, Череповецкий район, поселок Суда	0101000020E6100000BF9A030473CC4240FC53AA44D9914D40
29506	3	27	296	25635	26493	\N	59.151636000000003	Вологодская область, Череповецкий муниципальный район, п. Суда, Гагарина, 35		0101000020E6100000309C6B98A1C94240B972F6CE68934D40
29486	3	27	296	24694	26646	\N	59.381490999999997	Вологодская область, Череповецкий муниципальный район, д. Романово, Центральная, 16		0101000020E6100000A4FE7A8505FB4240F25B74B2D4B04D40
29475	3	27	296	24156	31698	\N	59.021495999999999	Вологодская область, Череповецкий муниципальный район, д. Починок, Новая, 7а		0101000020E6100000672AC423F1064340567F8461C0824D40
29411	3	27	296	21167	31920	\N	59.498834000000002	Вологодская область, Череповецкий муниципальный район, д. Поповка, Центральная, 5		0101000020E610000052D66F26A6C142400211E2CAD9BF4D40
29493	3	27	296	25020	31952	\N	59.025998000000001	Вологодская область, Череповецкий муниципальный район, д. Песье, Березовая, 34		0101000020E61000007FF6234564B2424076E107E753834D40
29432	3	27	296	22176	\N	\N	59.042765000000003	Вологодская область, Череповецкий муниципальный район, д. Новое Домозерово, 48		0101000020E6100000FA2B64AE0C124340EC34D25279854D40
29504	3	27	296	25536	\N	\N	58.810550999999997	Вологодская область, Череповецкий муниципальный район, д. Николо-Раменье, 15		0101000020E610000000E65AB400B14240BB5E9A22C0674D40
29502	3	27	296	25409	31721	\N	59.190508999999999	Вологодская область, Череповецкий муниципальный район, с. Нелазское, Центральная, 1		0101000020E6100000B189CC5CE0D04240FD4B529962984D40
29500	3	27	296	25259	26484	\N	58.889178000000001	162646  Череповецкий район, с. Мякса, ул. Советская, д. 37МУ «Мяксинское СКО»-  Мяксинский ДК.		0101000020E6100000ED0BE8853B1943404E29AF95D0714D40
29499	3	27	296	25259	26484	\N	58.889178000000001	Вологодская область, Череповецкий муниципальный район, с. Мякса, Советская, 37		0101000020E6100000ED0BE8853B1943404E29AF95D0714D40
29520	3	27	296	26233	31841	\N	58.764091244712098	Вологодская область, Череповецкий муниципальный район, д. Музга, Школьная, 14	Россия, Вологодская область, Череповецкий район, село Музга	0101000020E610000019E59997C33243407F15E0BBCD614D40
29495	3	27	296	25106	\N	\N	59.213749	Вологодская область, Череповецкий муниципальный район, п. Малечкино, Дом культуры		0101000020E6100000ABCDFFAB8EEE4240BF4692205C9B4D40
29492	3	27	296	24974	31813	\N	58.953601999999997	Вологодская область, Череповецкий муниципальный район, д. Коротово, Ленина, 12		0101000020E6100000D3DEE00B93BB424039B35DA10F7A4D40
29491	3	27	296	24918	\N	\N	59.345598000000003	Вологодская область, Череповецкий муниципальный район, д. Климовское, 21		0101000020E61000000A2E56D46002434011C8258E3CAC4D40
29489	3	27	296	24830	31930	\N	59.114736999999998	Вологодская область, Череповецкий муниципальный район, д. Ирдоматка, Новая, 10		0101000020E61000005EDBDB2DC90D43401152B7B3AF8E4D40
29488	3	27	296	24811	31717	\N	59.496592	Вологодская область, Череповецкий муниципальный район, с. Ивановское, Весенняя, 1		0101000020E6100000C93EC8B260FA424045BA9F5390BF4D40
29454	3	27	296	23135	31784	\N	59.060364999999997	Вологодская область, Череповецкий муниципальный район, д. Городище, Лесная, 23		0101000020E610000006A051BAF4ED42405969520ABA874D40
29513	3	27	296	25971	31780	\N	59.398893999999999	Вологодская область, Череповецкий муниципальный район, д.Горка, Старая Горка, 2		0101000020E6100000060FD3BEB9FF42400A4966F50EB34D40
29496	3	27	296	3019	\N	\N	59.431837000000002	Вологодская область, Череповецкий муниципальный район, с. Воскресенское, 173, школа		0101000020E61000005111A7936CF54240F419506F46B74D40
29485	3	27	296	3019	31765	\N	59.431837000000002	Вологодская область, Череповецкий муниципальный район, с. Воскресенское, Советская, 38		0101000020E61000005111A7936CF54240F419506F46B74D40
29525	3	27	296	26492	31847	\N	59.258063	Вологодская область, Череповецкий муниципальный район, д. Ботово, Ленина, 15		0101000020E610000089B3226AA2FB424061A7583508A14D40
29523	3	27	296	26380	\N	\N	58.542363000000002	Вологодская область, Череповецкий муниципальный район, д. Борок, 44		0101000020E6100000158DB5BFB3C54240BDC799266C454D40
29524	3	27	296	26455	26670	\N	58.711742999999998	Вологодская область, Череповецкий муниципальный район, д. Большой Двор, Центральная, 5		0101000020E610000044149337C0DC4240161406651A5B4D40
29510	3	27	296	25834	32017	\N	59.125753000000003	Вологодская область, Череповецкий муниципальный район, д. Большое Ново, Большеновская, 25		0101000020E6100000C91EA16648C94240DC2F9FAC18904D40
29514	3	27	296	25990	\N	\N	58.962108999999998	Вологодская область, Череповецкий муниципальный район, д. Батран, 31		0101000020E610000012859675FF344340F8174163267B4D40
29503	3	27	296	25478	32016	\N	59.196362000000001	Вологодская область, Череповецкий муниципальный район, п. Андогский, Бумажников, 13		0101000020E6100000350A4966F5B24240AD16D86322994D40
29497	3	27	296	25174	\N	\N	58.908771999999999	Вологодская область, Череповецкий муниципальный район, д. Аксеново, 19		0101000020E6100000242A543717414340A0C211A452744D40
29483	3	27	296	24559	9742	\N	59.2866903428596	Вологодская область, Череповецкий муниципальный район, с. Абаканово, Школьная, 11	Россия, Вологодская область, Череповецкий район, село Абаканово	0101000020E6100000C7629B5434D442408D0B0742B2A44D40
29468	3	27	1734	23641	26483	\N	59.137222000000001	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Чагода, п.Чагода, Школьная, 15А		0101000020E6100000558A1D8D43A541405725917D90914D40
29470	3	27	1734	23641	31898	\N	59.137222000000001	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Чагода, п.Чагода, Воззвания, 21А		0101000020E6100000558A1D8D43A541405725917D90914D40
29469	3	27	1734	23926	31852	\N	59.167986800141797	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Чагода, п.Чагода, Цнгтральная, 9	Россия, Вологодская область, Чагодощенский район, поселок Чагода	0101000020E61000001C40BFEFDFAA41409A93179980954D40
29467	3	27	1734	23926	26460	\N	59.164617999999997	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Чагода, п.Чагода, Кирова, 5	Россия, Вологодская область, Чагодощенский район, поселок Чагода	0101000020E610000099BC0166BEA941409D2ADF3312954D40
29466	3	27	1734	23926	26460	\N	59.162877793550003	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Чагода, п.Чагода, Кирова, 5А	Россия, Вологодская область, Чагодощенский район, поселок Чагода	0101000020E6100000D0436D1B46A94140739EB12FD9944D40
29464	3	27	1734	23926	26460	\N	59.164821929944601	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Чагода, п.Чагода, Кирова, 7	Россия, Вологодская область, Чагодощенский район, поселок Чагода	0101000020E6100000CCEF3499F1A84140A6D425E318954D40
29471	3	27	1734	23926	31801	\N	59.158667714756199	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Чагода, п.Чагода, Высоцкого, 73	Россия, Вологодская область, Чагодощенский район, поселок Чагода	0101000020E6100000359BC76130A94140FB75A73B4F944D40
29482	3	27	1734	24500	31948	\N	59.177066000000003	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Первомайское, п.Смердомский, Центральная, 14		0101000020E61000008C31B08EE3874140E59D4319AA964D40
29472	3	27	1734	24000	31697	\N	59.091349999999998	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Сазоново, п.Сазоново, Строителей, 5		0101000020E6100000D236FE44659D4140AB3E575BB18B4D40
29474	3	27	1734	24000	26603	\N	59.091349999999998	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Сазоново, п.Сазоново, Советская, 14		0101000020E6100000D236FE44659D4140AB3E575BB18B4D40
29473	3	27	1734	24000	26603	\N	59.091349999999998	Вологодская область, Чагодощенский муниципальный район, муниципальное образование поселок Сазоново, п.Сазоново, Советская, 47		0101000020E6100000D236FE44659D4140AB3E575BB18B4D40
29651	3	27	1734	32351	31709	\N	58.954622999999998	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Покровское, с.Покровское, Центральная, 4А		0101000020E6100000D0F23CB83BC9414034812216317A4D40
29481	3	27	1734	24432	31986	\N	59.173777999999999	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Первомайское, п.Первомайский, Центральная, 1		0101000020E6100000FB5B02F04F8F4140D461855B3E964D40
29480	3	27	1734	24402	32038	\N	59.147145000000002	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Мегринское, д.Мегрино, Северная, 6		0101000020E6100000BD8E386403CB41408D62B9A5D5924D40
29478	3	27	1734	24312	31763	\N	58.987582000000003	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Избоищское, д.Избоищи, Набережная, 1		0101000020E61000006ADE718A8EA44140240F4416697E4D40
29477	3	27	1734	24244	31908	\N	59.105759999999997	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Борисовское, п.Борисово, Спортивная, 2		0101000020E61000008F6D197096B04140CB9C2E8B898D4D40
29476	3	27	1734	24184	31767	\N	59.074733000000002	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Белокрестское, с.Белые Кресты, Кооперативная, 23А		0101000020E6100000FCC74274089C41404B77D7D990894D40
29479	3	27	1734	24328	26498	\N	58.886690000000002	Вологодская область, Чагодощенский муниципальный район, муниципальное образование Лукинское, д.Анишино, Мира, 7		0101000020E61000004B033FAA61A941405AD8D30E7F714D40
29463	3	27	499	23587	31828	\N	60.154919999999997	Вологодская область, Харовский муниципальный район, муниципальное образование Шапшинское, село Шапша, Центральная, 14		0101000020E6100000A5DC7D8E8FEE434087BF266BD4134E40
29441	3	27	499	51299	32066	\N	59.950774192511702	Вологодская область, Харовский муниципальный район, муниципальное образование город Харовск, Энергетиков, 11	Россия, Вологодская область, Харовский район, Харовск	0101000020E610000043572250FD1B44408DF161F6B2F94D40
29445	3	27	499	51299	32064	\N	59.970252087083502	Вологодская область, Харовский муниципальный район, муниципальное образование город Харовск, Школьная, 7	Россия, Вологодская область, Харовский район, Харовск	0101000020E6100000ED4960730E1844407670B03731FC4D40
29395	3	27	1616	20170	26557	\N	59.631627999999999	Вологодская область, Усть-Кубинский район, с.Устье, ул.Первомайская, д.16		0101000020E61000008A05BEA25BDD4340739EB12FD9D04D40
29442	3	27	499	51299	32052	\N	59.955170567119602	Вологодская область, Харовский муниципальный район, муниципальное образование город Харовск, Свободы, 5	Россия, Вологодская область, Харовский район, Харовск	0101000020E61000003E062B4EB51A4440378B170B43FA4D40
29446	3	27	499	51299	26586	\N	59.957432175020102	Вологодская область, Харовский муниципальный район, муниципальное образование город Харовск, Клубная, 18	Россия, Вологодская область, Харовский район, Харовск	0101000020E610000043024697371B44406A12BC218DFA4D40
29451	3	27	499	23005	\N	\N	60.060352000000002	Вологодская область, Харовский муниципальный район, муниципальное образование Кубенское, деревня Сорожино, Центр досуга, 34		0101000020E61000009351651877074440C51F459DB9074E40
29461	3	27	499	23496	26451	\N	59.994135	Вологодская область, Харовский муниципальный район, муниципальное образование Харовское, поселок Ситинский, Мира, 12		0101000020E6100000A48CB800341444408C67D0D03FFF4D40
29458	3	27	499	23268	31943	\N	59.811794540762001	Вологодская область, Харовский муниципальный район, муниципальное образование Семигороднее, станция Семигородняя, Спортивная, 25	Россия, Вологодская область, Харовский район, поселок Семигородняя	0101000020E610000030F488D173154440350708E6E8E74D40
29457	3	27	499	23268	31752	\N	59.811793999999999	Вологодская область, Харовский муниципальный район, муниципальное образование Семигороднее, станция Семигородняя, Комсомольская, 4		0101000020E6100000166EF9484A164440658BA4DDE8E74D40
29448	3	27	499	22870	\N	\N	60.000582000000001	Вологодская область, Харовский муниципальный район, муниципальное образование Ильинское, деревня Семениха, Дом культуры, 22		0101000020E6100000E353008C673A4440AF7B2B1213004E40
29447	3	27	499	22844	\N	\N	60.265526999999999	Вологодская область, Харовский муниципальный район, муниципальное образование Азлецкое, деревня Поповка, библиотека, 70		0101000020E61000000CCC0A45BAD543403D9AEAC9FC214E40
29462	3	27	499	53296	32111	\N	60.1581091636317	Вологодская область, Харовский муниципальный район, муниципальное образование Харовское, село Погост Никольский, Центральная, 4	Россия, Вологодская область, Харовский район, село Никольский	0101000020E6100000DCF4673F52F04340051A6CEA3C144E40
29456	3	27	499	23259	\N	\N	60.247644000000001	Вологодская область, Харовский муниципальный район, муниципальное образование Разинское, село Никулинское, администрация Разинского сельского поселения, 12		0101000020E61000007DEA58A5F40C44407B8670CCB21F4E40
29450	3	27	499	53295	32100	\N	59.972447538679802	Вологодская область, Харовский муниципальный район, муниципальное образование Кубенское, поселок Нижне-Кубенский, Торговая, 7	Россия, Вологодская область, Харовский район, село Нижнекубенский	0101000020E61000009983A0A355F94340C287122D79FC4D40
29453	3	27	499	3010	31705	\N	59.966993000000002	Вологодская область, Харовский муниципальный район, муниципальное образование Михайловское, село Михайловское, Советская, 5		0101000020E610000048DC63E9433D4440003B376DC6FB4D40
29452	3	27	499	23072	\N	\N	60.140180000000001	Вологодская область, Харовский муниципальный район, муниципальное образование Кумзерское, село Кумзеро, администрация Кумзерского сельского поселения, 5		0101000020E6100000D3DA34B6D7D24340D2C6116BF1114E40
29449	3	27	499	22917	\N	\N	60.022427	Вологодская область, Харовский муниципальный район, муниципальное образование Ильинское, деревня Золотава, Дом культуры, 21		0101000020E61000009372F7393E4C444011C64FE3DE024E40
29455	3	27	499	23207	\N	\N	60.012683000000003	Вологодская область, Харовский муниципальный район, муниципальное образование Разинское, деревня Гора, Дом культуры, 68		0101000020E6100000D06394675EFE43408B1BB7989F014E40
29460	3	27	499	23429	32003	\N	59.956854	Вологодская область, Харовский муниципальный район, муниципальное образование Харовское, деревня Бараниха, Лесная, 11		0101000020E6100000139ED0EB4F204440FD851E317AFA4D40
29459	3	27	499	23364	\N	\N	60.160186000000003	Вологодская область, Харовский муниципальный район, муниципальное образование Слободское, деревня Арзубиха, администрация Слободского сельского поселения, 100		0101000020E6100000AF25E4839E49444077A38FF980144E40
29417	3	27	489	21446	\N	\N	58.749659999999999	Вологодская область, Устюженский муниципальный район, муниципальное образование Залесское, д. Ярцево, 2		0101000020E61000002F151BF33A064240478FDFDBF45F4D40
29440	3	27	489	22551	31924	\N	58.818626999999999	Вологодская область, Устюженский муниципальный район, муниципальное образование Устюженское, д. Яковлевское, Центральная, 3		0101000020E61000008D5F7825C9134240B14F00C5C8684D40
29414	3	27	489	2932	31862	\N	58.841586	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Терешковой, 50		0101000020E6100000FE45D09849384240BF620D17B96B4D40
29412	3	27	489	2932	31862	\N	58.841586	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Терешковой, 6-А		0101000020E6100000FE45D09849384240BF620D17B96B4D40
29438	3	27	489	2932	31754	\N	58.8378178055465	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Пролетарская, 13	Россия, Вологодская область, Устюженский район, Устюжна	0101000020E6100000A4DFBE0E9C3542400400C79E3D6B4D40
29394	3	27	1616	20170	31744	\N	59.631627999999999	Вологодская область, Усть-Кубинский район, с.Устье, ул.Октябрьская, д.19		0101000020E61000008A05BEA25BDD4340739EB12FD9D04D40
29415	3	27	489	2932	26663	\N	58.846170599246499	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Набережная Декабристов, 42	Россия, Вологодская область, Устюженский район, Устюжна	0101000020E6100000F279C5538F3642406CE9D1544F6C4D40
29407	3	27	489	2932	26728	\N	58.841586	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Ленина, 50		0101000020E6100000FE45D09849384240BF620D17B96B4D40
29413	3	27	489	2932	31670	\N	58.841586	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Карла Маркса, 53		0101000020E6100000FE45D09849384240BF620D17B96B4D40
29410	3	27	489	2932	31670	\N	58.841586	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Карла Маркса, 14		0101000020E6100000FE45D09849384240BF620D17B96B4D40
29409	3	27	489	2932	26404	\N	58.840802454008198	Вологодская область, Устюженский муниципальный район, муниципальное образование город Устюжна, г. Устюжна, Интернациональная, 4	Россия, Вологодская область, Устюженский район, Устюжна	0101000020E6100000DFDE35E84B354240A83462669F6B4D40
29418	3	27	489	21512	31981	\N	58.776195999999999	Вологодская область, Устюженский муниципальный район, муниципальное образование Залесское, д. Степачево, Центральная, 19_А		0101000020E6100000C972124A5F2442409CA4F9635A634D40
29428	3	27	489	22002	31925	\N	58.686059999999998	Вологодская область, Устюженский муниципальный район, муниципальное образование Никифоровское, п. Спасское, Центральная, 23		0101000020E6100000E76F4221022C4240008C67D0D0574D40
29433	3	27	489	22238	31935	\N	58.828122	Вологодская область, Устюженский муниципальный район, муниципальное образование Сошневское, д. Соболево, Центральная, 28		0101000020E610000009C6C1A5634642408F8CD5E6FF694D40
29425	3	27	489	21849	26421	\N	58.876508999999999	Вологодская область, Устюженский муниципальный район, муниципальное образование Моденское, д. Слуды, Школьная, 2		0101000020E6100000C68503215970424028D3687231704D40
29434	3	27	489	22263	31701	\N	58.743411999999999	Вологодская область, Устюженский муниципальный район, муниципальное образование Сошневское, д. Славынево, Центральная, 66		0101000020E6100000D6E3BED53A6742401BBAD91F285F4D40
29431	3	27	489	22128	31993	\N	58.553486999999997	Вологодская область, Устюженский муниципальный район, муниципальное образование Никольское, д. Расторопово, Школьная, 4		0101000020E6100000645A9BC6F62642406DE179A9D8464D40
29436	3	27	489	22346	31996	\N	58.917780999999998	Вологодская область, Устюженский муниципальный район, муниципальное образование поселок имени Желябова, д. Оснополье, Центральная, 3		0101000020E61000004CA4349BC74B4240F1F109D979754D40
29430	3	27	489	22099	31751	\N	58.544176	Вологодская область, Устюженский муниципальный район, муниципальное образование Никольское, д. Никола, Корелякова, 103		0101000020E61000006D5853591432424051A2258FA7454D40
29424	3	27	489	21785	31688	\N	58.928823000000001	Вологодская область, Устюженский муниципальный район, муниципальное образование Моденское, с. Модно, Центральная, 15		0101000020E610000082E50819C8734240E5620CACE3764D40
29422	3	27	489	21690	31685	\N	59.027304000000001	Вологодская область, Устюженский муниципальный район, муниципальное образование Лентьевское, д. Мережа, Школьная, 8-А		0101000020E61000001EA8531EDD32424066868DB27E834D40
29429	3	27	489	22017	31990	\N	58.663648999999999	Вологодская область, Устюженский муниципальный район, муниципальное образование Никифоровское, д. Мелечино, Административный, 1		0101000020E610000036ACA92C0A2D4240F5824F73F2544D40
29416	3	27	489	21406	\N	\N	58.686556000000003	Вологодская область, Устюженский муниципальный район, муниципальное образование Залесское, д. Малое Восное, 57		0101000020E6100000AED4B32094194240B16F2711E1574D40
29419	3	27	489	21535	26568	\N	58.965680999999996	Вологодская область, Устюженский муниципальный район, муниципальное образование Лентьевское, д. Лентьево, Советская, 26		0101000020E6100000CE548847E24D42402DAF5C6F9B7B4D40
29435	3	27	489	22332	31936	\N	58.954808999999997	Вологодская область, Устюженский муниципальный район, муниципальное образование поселок имени Желябова, п. им. Желябова, Советская, 12		0101000020E6100000041E1840F84C424096766A2E377A4D40
29423	3	27	489	21752	26417	\N	58.967899000000003	Вологодская область, Устюженский муниципальный район, муниципальное образование Мезженское, д. Долоцкое, Южный, 4		0101000020E6100000E4DBBB067DFB4140626A4B1DE47B4D40
29427	3	27	489	21941	31922	\N	58.717247999999998	Вологодская область, Устюженский муниципальный район, муниципальное образование Никифоровское, п. Даниловское, Центральная, 14-А		0101000020E6100000E4A08499B63942408A8F4FC8CE5B4D40
29426	3	27	489	21885	31691	\N	58.667589	Вологодская область, Устюженский муниципальный район, муниципальное образование Никифоровское, д. Веницы, Школьная, 5		0101000020E6100000F0694E5E643E4240AD156D8E73554D40
29420	3	27	489	21600	31945	\N	58.938862999999998	Вологодская область, Устюженский муниципальный район, муниципальное образование Лентьевское, д. Ванское, Центральная, 52		0101000020E610000066F9BA0CFF6F42405436ACA92C784D40
29439	3	27	489	22464	31998	\N	58.753706999999999	Вологодская область, Устюженский муниципальный район, муниципальное образование Устюженское, д. Брилино, Центральная, 4		0101000020E610000088BD50C07636424015E2917879604D40
29393	3	27	1616	20170	26395	\N	59.631627999999999	Вологодская область, Усть-Кубинский район, с.Устье, ул.Профсоюзная, д.6		0101000020E61000008A05BEA25BDD4340739EB12FD9D04D40
29406	3	27	1616	20935	31978	\N	59.658175999999997	Вологодская область, Усть-Кубинский район, д.Порохово, ул.Полевая, д.15		0101000020E610000076C3B64599EB43408C81751C3FD44D40
29401	3	27	1616	20651	26559	\N	59.847318000000001	Вологодская область, Усть-Кубинский район, с.Никольское, ул.Садовая, д.15		0101000020E61000004B1DE4F560AE4340F4A78DEA74EC4D40
29405	3	27	1616	20898	31977	\N	59.694462999999999	Вологодская область, Усть-Кубинский район, с.Никола-Корень, ул.Курлаково, д.4		0101000020E6100000115322895ED043401AA4E029E4D84D40
29398	3	27	1616	20499	31974	\N	60.133271000000001	Вологодская область, Усть-Кубинский район, д.Никифоровская, ул.Никольская, д.5		0101000020E610000001A3CB9BC3AB4340AB402D060F114E40
29400	3	27	1616	20631	\N	\N	59.580277000000002	Вологодская область, Усть-Кубинский район, д.Митенское, ул.Административная, д.2	Россия, Вологодская область, Усть-Кубинский район, село Митенское	0101000020E6100000B7973446EBE043407DCF488446CA4D40
29396	3	27	1616	20379	31805	\N	60.062420206682503	Вологодская область, Усть-Кубинский район, д.Марковская, ул.Центральная, д.15	Россия, Вологодская область, Усть-Кубинский район, село Марковская	0101000020E61000005D514A0856894340E44EE960FD074E40
29402	3	27	1616	20728	31931	\N	59.876626000000002	Вологодская область, Усть-Кубинский район, д.Королиха, ул.Центральная, д.8		0101000020E6100000C0E95DBC1FD543406269E04735F04D40
29399	3	27	1616	20575	31858	\N	59.771486000000003	Вологодская область, Усть-Кубинский район, с.Заднее, ул.Яковлева, д.14		0101000020E6100000EE04FBAF73D9434033A9A10DC0E24D40
29404	3	27	1616	20820	26400	\N	59.630063	Вологодская область, Усть-Кубинский район, п.Высокое, ул.Нагорная, д.23		0101000020E61000004A5F0839EFEB4340B7B585E7A5D04D40
29397	3	27	1616	20461	31976	\N	59.988028	Вологодская область, Усть-Кубинский район, с.Богородское, ул.Парковая, д.8		0101000020E6100000A6423C122FA3434022C495B377FE4D40
29403	3	27	1616	20783	31975	\N	59.907969999999999	Вологодская область, Усть-Кубинский район, с.Бережное, ул.Совхозная, д.6		0101000020E61000003E5B07077BA34340E3DF675C38F44D40
29380	3	27	1544	19476	31792	\N	59.669125000000001	Вологодская область, Тотемский муниципальный район, муниципальное образование Погореловское, п. Юбилейный, Школьная, 4		0101000020E61000003DBA111615074540CFF753E3A5D54D40
29368	3	27	1544	18856	\N	\N	59.834916999999997	Вологодская область, Тотемский муниципальный район, муниципальное образование Великодворское, п. Чуриловка, 82		0101000020E6100000276BD44334564540EDEF6C8FDEEA4D40
29373	3	27	1544	19139	\N	\N	59.784348999999999	Вологодская область, Тотемский муниципальный район, муниципальное образование Калининское, д. Устье, 63		0101000020E6100000A796ADF5455045403DD34B8C65E44D40
29371	3	27	1544	19004	\N	\N	59.890031	Вологодская область, Тотемский муниципальный район, муниципальное образование Калининское, п. Царева, 31		0101000020E6100000E065868DB25645408DB62A89ECF14D40
29390	3	27	1544	19996	32045	\N	59.404032999999998	Вологодская область, Тотемский муниципальный район, муниципальное образование Толшменское, с. Успенье, Центральная, 11		0101000020E6100000605969520A6445409CC0745AB7B34D40
29361	3	27	1544	18374	31731	\N	59.970402	Вологодская область, Тотемский муниципальный район, муниципальное образование Город Тотьма, г. Тотьма, Осипенко, 5		0101000020E6100000D07CCEDDAE6145408BFCFA2136FC4D40
29364	3	27	1544	18374	26712	\N	59.970402	Вологодская область, Тотемский муниципальный район, муниципальное образование Город Тотьма, г. Тотьма, Набережная им. Кускова, 14		0101000020E6100000D07CCEDDAE6145408BFCFA2136FC4D40
29362	3	27	1544	18374	31788	\N	59.975791023497301	Вологодская область, Тотемский муниципальный район, муниципальное образование Город Тотьма, г. Тотьма, Ленина, 61	Россия, Вологодская область, Тотемский район, Тотьма	0101000020E6100000F1BC546CCC614540965D30B8E6FC4D40
29360	3	27	1544	18374	31788	\N	59.975123798837402	Вологодская область, Тотемский муниципальный район, муниципальное образование Город Тотьма, г. Тотьма, Ленина, 21	Россия, Вологодская область, Тотемский район, Тотьма	0101000020E6100000BFB67EFACF604540B9C5FCDCD0FC4D40
29366	3	27	1544	18374	31787	\N	59.979437881283197	Вологодская область, Тотемский муниципальный район, муниципальное образование Город Тотьма, г. Тотьма, Загородная, 99б	Россия, Вологодская область, Тотемский район, Тотьма	0101000020E61000001BDA006C40624540D63A71395EFD4D40
29363	3	27	1544	18374	31787	\N	59.978802231034301	Вологодская область, Тотемский муниципальный район, муниципальное образование Город Тотьма, г. Тотьма, Загородная, 66	Россия, Вологодская область, Тотемский район, Тотьма	0101000020E61000009B5AB6D6175F454034A1496249FD4D40
29359	3	27	1544	18374	31907	\N	59.970402	Вологодская область, Тотемский муниципальный район, муниципальное образование Город Тотьма, г. Тотьма, Володарского, 5		0101000020E6100000D07CCEDDAE6145408BFCFA2136FC4D40
29387	3	27	1544	19857	31913	\N	59.960619999999999	Вологодская область, Тотемский муниципальный район, муниципальное образование Пятовское, п. Текстильщики, Энергетиков, 2а		0101000020E6100000F30016F9F569454017F19D98F5FA4D40
29382	3	27	1544	52410	32044	\N	59.926174000000003	Вологодская область, Тотемский муниципальный район, муниципальное образование Пятовское, п. Советский, Октябрьская, 6		0101000020E61000004CC11A67D35B4540E833A0DE8CF64D40
29379	3	27	1544	19451	\N	\N	60.323692999999999	Вологодская область, Тотемский муниципальный район, муниципальное образование Мосеевское, д. Середская, 39		0101000020E6100000588D25AC8D094540D978B0C56E294E40
29381	3	27	1544	19556	31678	\N	59.707847000000001	Вологодская область, Тотемский муниципальный район, муниципальное образование Погореловское, д. Погорелово, Мира, 21		0101000020E61000000BD3F71A820545402EC901BB9ADA4D40
29386	3	27	1544	19804	31740	\N	60.125630000000001	Вологодская область, Тотемский муниципальный район, муниципальное образование Пятовское, п. Октябрьский, Механизаторов, 5		0101000020E61000002B8881AE7D574540C0B2D2A414104E40
29391	3	27	1544	20077	31675	\N	59.491844999999998	Вологодская область, Тотемский муниципальный район, муниципальное образование Толшменское, с. Никольское, Рубцова, 30		0101000020E6100000529D0E643D434540BED9E6C6F4BE4D40
29377	3	27	1544	19313	\N	\N	60.153759999999998	Вологодская область, Тотемский муниципальный район, муниципальное образование Мосеевское, д. Мосеево, 17		0101000020E6100000C0CB0C1B653945406BB75D68AE134E40
29376	3	27	1544	19297	\N	\N	60.082467000000001	Вологодская область, Тотемский муниципальный район, муниципальное образование Медведевское, п. Михайловка, 68		0101000020E6100000D3F71A82E3BC4540E7FF55478E0A4E40
29375	3	27	1544	19246	\N	\N	60.026913999999998	Вологодская область, Тотемский муниципальный район, муниципальное образование Медведевское, д. Медведево, 58		0101000020E6100000FD101B2C9C824540FBE6FEEA71034E40
29385	3	27	1544	19732	31823	\N	60.090077999999998	Вологодская область, Тотемский муниципальный район, муниципальное образование Пятовское, д. Матвеево, Садовая, 9		0101000020E6100000CAA5F10BAF664540670B08AD870B4E40
29369	3	27	1544	18920	\N	\N	59.985061000000002	Вологодская область, Тотемский муниципальный район, муниципальное образование Вожбальское, д. Кудринская, 36		0101000020E610000043A9BD88B625454054C8957A16FE4D40
29370	3	27	1544	18990	\N	\N	60.069800000000001	Вологодская область, Тотемский муниципальный район, муниципальное образование Вожбальское, п. Крутая Осыпь, 46		0101000020E6100000F08B4B55DA14454062A1D634EF084E40
29372	3	27	1544	51296	26582	\N	59.8687328723693	Вологодская область, Тотемский муниципальный район, муниципальное образование Калининское, п. Красный Бор, Пролетарская, 1а	Россия, Вологодская область, Тотемский район, село Красный Бор	0101000020E6100000D8B628B3411E45405DFA97A432EF4D40
29389	3	27	1544	19963	31912	\N	59.308371999999999	Вологодская область, Тотемский муниципальный район, муниципальное образование Толшменское, п. Карица, Пролетарская, 3		0101000020E61000002829B000A66A45404580D3BB78A74D40
29374	3	27	1544	19170	31970	\N	60.047410999999997	Вологодская область, Тотемский муниципальный район, муниципальное образование Медведевское, п. Камчуга, Школьная, 29	Россия, Вологодская область, Тотемский район, поселок Камчуга	0101000020E6100000618907944D9545403E3C4B9011064E40
29383	3	27	1544	19658	32042	\N	59.942376000000003	Вологодская область, Тотемский муниципальный район, муниципальное образование Пятовское, д. Задняя, Школьная, 6		0101000020E61000000B7C45B75E5D45408544DAC69FF84D40
29378	3	27	1544	19378	\N	\N	60.273341000000002	Вологодская область, Тотемский муниципальный район, муниципальное образование Мосеевское, д. Данилов Починок, 81		0101000020E6100000062FFA0AD2204540F6D37FD6FC224E40
29367	3	27	1544	18810	\N	\N	59.677684999999997	Вологодская область, Тотемский муниципальный район, муниципальное образование Великодворское, д. Великий Двор, 46		0101000020E6100000AFD172A087604540B0FECF61BED64D40
29392	3	27	1544	53287	32074	\N	59.595183834710802	Вологодская область, Тотемский муниципальный район, муниципальное образование Толшменское, д. Бор, Центральная, 24	Россия, Вологодская область, Тотемский район, село Бор	0101000020E6100000B5FF01D6AA2745401E8D43FD2ECC4D40
29342	3	27	274	53291	32082	\N	60.418422	Вологодская область, Тарногский район, с. Шебеньгский Погост, Центральная, 5	Россия, Вологодская область, Тарногский район, село Шебенгский Погост	0101000020E6100000C24B70EA03CD4540A5F622DA8E354E40
29353	3	27	274	18076	\N	\N	60.439234999999996	Вологодская область, Тарногский район, д. Тюприха, 28		0101000020E6100000B3D30FEA22A5454018213CDA38384E40
29337	3	27	274	53283	32062	\N	60.495552468572797	Вологодская область, Тарногский район, с. Тарногский Городок, Советская, 30	Россия, Вологодская область, Тарногский район, село Тарногский Городок	0101000020E61000000E84640113CA4540D4BB783F6E3F4E40
29336	3	27	274	53283	32062	\N	60.499362839399403	Вологодская область, Тарногский район, с. Тарногский Городок, Советская, 41	Россия, Вологодская область, Тарногский район, село Тарногский Городок	0101000020E61000009BAF928FDDC945408EEA7420EB3F4E40
29338	3	27	274	17339	32022	\N	60.536805000000001	Вологодская область, Тарногский район, д. Слуда, Центральная, 1		0101000020E6100000FA9CBB5D2FCF454026AAB706B6444E40
29356	3	27	274	18231	\N	\N	60.245894	Вологодская область, Тарногский район, д. Сергиевская, 22а		0101000020E610000030DAE38574F845402D246074791F4E40
29351	3	27	274	17980	26707	\N	60.498269999999998	Вологодская область, Тарногский район, с. Ромашевский Погост, Молодежная, 2		0101000020E6100000F59D5F94A0AB4540F949B54FC73F4E40
29355	3	27	274	2098	\N	\N	60.270780000000002	Вологодская область, Тарногский район, д. Раменье, 2-а, сельский клуб		0101000020E6100000A2293BFDA0E24540983446EBA8224E40
29384	3	27	274	19717	31783	\N	60.425694816001403	Вологодская область, Тотемский муниципальный район, муниципальное образование Пятовское, д. Пятовская, Центральная, 4	Россия, Вологодская область, Тарногский район, село Пятовская	0101000020E610000072F90FE9B7D345400D897B2C7D364E40
29346	3	27	274	17735	\N	\N	60.656616	Вологодская область, Тарногский район, д. Никифоровская, 25		0101000020E610000004AE2B6684994540E2033BFE0B544E40
29344	3	27	274	17663	\N	\N	60.609552000000001	Вологодская область, Тарногский район, д. Нижнепаунинская, 2		0101000020E610000066DAFE9595AA45400F9BC8CC054E4E40
29350	3	27	274	17956	32034	\N	60.511232	Вологодская область, Тарногский район, с. Красное, Красная, 12		0101000020E6100000E486DF4DB79C45409755D80C70414E40
29358	3	27	274	18313	\N	\N	60.828327000000002	Вологодская область, Тарногский район, п. Конторка, 17		0101000020E6100000A3AEB5F7A910464068B27F9E066A4E40
29349	3	27	274	17869	\N	\N	60.484903000000003	Вологодская область, Тарногский район, д. Каплинская, 35	Россия, Вологодская область, Тарногский район, село Каплинская	0101000020E61000004359F8FA5A874540BC5D2F4D113E4E40
29347	3	27	274	17794	\N	\N	60.744323999999999	Вологодская область, Тарногский район, д.Ильинская, 14		0101000020E6100000179B560A818E45405FD04202465F4E40
29357	3	27	274	18287	\N	\N	60.684081999999997	Вологодская область, Тарногский район, с. Илезский Погост, 20		0101000020E610000072A609DB4FF6454021E4BCFF8F574E40
29343	3	27	274	17570	26521	\N	60.50853	Вологодская область, Тарногский район, д. Игумновская, Центральная, 52		0101000020E6100000CC26C0B0FCC145407784D38217414E40
29354	3	27	274	18148	\N	\N	60.421900000000001	Вологодская область, Тарногский район, д. Заречье, 60		0101000020E61000006E6DE179A9EE45405917B7D100364E40
29340	3	27	274	17421	\N	\N	60.610616	Вологодская область, Тарногский район, д. Евсеевская, 22		0101000020E61000004354E1CFF0D64540093543AA284E4E40
29345	3	27	274	2787	\N	\N	60.690328999999998	Вологодская область, Тарногский район, п. Вощар, 1, дом культуры		0101000020E610000024B9FC87F4AF45407D3D5FB35C584E40
29348	3	27	274	53262	\N	\N	60.462482946342	Вологодская область, Тарногский район, с. Верховский Погост, 4		0101000020E61000008CDCD3D51D7B45405DFA97A4323B4E40
29341	3	27	274	53254	\N	\N	60.684429999999999	Вологодская область, Тарногский район, с. Верхнекокшеньгский Погост, 10	Россия, Вологодская область, Тарногский район, село Верхнекокшенгский Погост	0101000020E61000004030478FDFE745405D33F9669B574E40
29339	3	27	274	17386	\N	\N	60.577452000000001	Вологодская область, Тарногский район, д. Афанасьевская, 31		0101000020E610000023F94A2025C04540418177F2E9494E40
29333	3	27	259	17080	31844	\N	60.029376999999997	Вологодская область, Сямженский муниципальный район, д.Шокша, Центральная, 16		0101000020E61000007A8B87F71C724440962023A0C2034E40
29328	3	27	259	16853	\N	\N	60.170575999999997	Вологодская область, Сямженский муниципальный район, п.Ширега, 60		0101000020E6100000392861A6EDA14440C2BD326FD5154E40
29319	3	27	259	16369	31932	\N	59.885236999999996	Вологодская область, Сямженский муниципальный район, д.Филинская, Центральная, 20		0101000020E610000096CE8767097A4440C51A2E724FF14D40
29334	3	27	259	17145	31845	\N	60.034717000000001	Вологодская область, Сямженский муниципальный район, с.Усть-Река, Центральная, 20		0101000020E6100000C440D7BE80624440C0CE4D9B71044E40
29330	3	27	259	2701	26665	\N	60.014741999999998	Вологодская область, Сямженский муниципальный район, с.Сямжа, Советская, 10		0101000020E61000001DC87A6AF589444056F0DB10E3014E40
29331	3	27	259	2701	31725	\N	60.014741999999998	Вологодская область, Сямженский муниципальный район, с.Сямжа, Славянская,1		0101000020E61000001DC87A6AF589444056F0DB10E3014E40
29332	3	27	259	2701	31843	\N	60.014741999999998	Вологодская область, Сямженский муниципальный район, с.Сямжа, Парковая, 4		0101000020E61000001DC87A6AF589444056F0DB10E3014E40
29320	3	27	259	16442	32015	\N	59.797094999999999	Вологодская область, Сямженский муниципальный район, пос.Согорки, Школьная, 7		0101000020E61000003A02B859BCA644400E677E3507E64D40
29316	3	27	259	2583	\N	\N	60.247796000000001	Вологодская область, Сямженский муниципальный район, д.Самсоновская,  5		0101000020E610000047E4BB94BAD24440310A82C7B71F4E40
29327	3	27	259	16787	32020	\N	60.244599000000001	Вологодская область, Сямженский муниципальный район, д.Раменье, Молодежная, 19		0101000020E6100000E5F04927128C444031D120054F1F4E40
29325	3	27	259	16698	\N	\N	60.14564	Вологодская область, Сямженский муниципальный район, д.Пигилинская, 17		0101000020E61000009B9141EE228C4440A67EDE54A4124E40
29324	3	27	259	16622	32019	\N	60.004438	Вологодская область, Сямженский муниципальный район, д.Ногинская, Поспелова, 3		0101000020E610000065FED13769884440096EA46C91004E40
29317	3	27	259	16280	31818	\N	60.180045	Вологодская область, Сямженский муниципальный район, п.Мирный, Подлесная, 3		0101000020E6100000ABEB504D49DC44407767EDB60B174E40
29323	3	27	259	16580	\N	\N	60.033140000000003	Вологодская область, Сямженский муниципальный район, д.Коростелево, 34		0101000020E610000024624A24D1BB4440401878EE3D044E40
29329	3	27	259	16902	31840	\N	60.146953000000003	Вологодская область, Сямженский муниципальный район, д.Копылово,ул.Центральная,17, Режская школа		0101000020E61000005725917D90CF444049861C5BCF124E40
29335	3	27	259	17170	31851	\N	60.090643	Вологодская область, Сямженский муниципальный район, д.Истоминская, Истоминская, 2		0101000020E6100000A9A0A2EA57664440404E98309A0B4E40
29318	3	27	259	16355	31775	\N	59.905943999999998	Вологодская область, Сямженский муниципальный район, д.Житьево, Зеленая, 13		0101000020E610000063F19BC24A8D4440F30016F9F5F34D40
29326	3	27	259	16764	31724	\N	60.2134	Вологодская область, Сямженский муниципальный район, п.Гремячий, Набережная, 4		0101000020E61000007AE3A430EF8F4440B37BF2B0501B4E40
29388	3	27	259	16764	26555	\N	60.2134	Вологодская область, Тотемский муниципальный район, муниципальное образование Толшменское, п. Гремячий, Мира, 29		0101000020E61000007AE3A430EF8F4440B37BF2B0501B4E40
29321	3	27	259	16501	\N	\N	59.896372999999997	Вологодская область, Сямженский муниципальный район, д.Голузино, 7		0101000020E6100000C05E61C1FDC644403A02B859BCF24D40
29322	3	27	259	16527	31957	\N	60.013722000000001	Вологодская область, Сямженский муниципальный район, д.Георгиевская, Школьная, 5		0101000020E61000005F29CB10C7CA44402C9E7AA4C1014E40
29305	3	27	450	53258	\N	\N	59.511916745457803	Вологодская область, Сокольский муниципальный район, д.Шера, д.55	Россия, Вологодская область, Сокольский район, село Щера	0101000020E6100000849A215514EF43401AA20A7F86C14D40
29313	3	27	450	2554	26486	\N	59.599361999999999	Вологодская область, Сокольский муниципальный район, д.Чучково, ул.Сельская, д.1		0101000020E6100000D9960167299F44408A3BDEE4B7CC4D40
29310	3	27	450	15953	31895	\N	59.658976000000003	Вологодская область, Сокольский муниципальный район, д.Чекшино, ул.Молодежная, д.10		0101000020E610000039807EDFBF474440A96C585359D44D40
29275	3	27	450	14256	31762	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Школьная, д.5		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29295	3	27	450	14256	26640	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Шатенево, д.43а		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29285	3	27	450	14256	26490	\N	59.476428992309401	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.115	Россия, Вологодская область, Сокольский район, Сокол	0101000020E6100000BDE0D39CBC0A4440D9EE1EA0FBBC4D40
29284	3	27	450	14256	26490	\N	59.4745020613761	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.106	Россия, Вологодская область, Сокольский район, Сокол	0101000020E61000002810768A550B44407CF1457BBCBC4D40
29283	3	27	450	14256	26490	\N	59.469545029749199	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.86	Россия, Вологодская область, Сокольский район, Сокол	0101000020E61000007286E28E370D44400A80F10C1ABC4D40
29282	3	27	450	14256	26490	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.83		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29281	3	27	450	14256	26490	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.52		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29280	3	27	450	14256	26490	\N	59.460639101487303	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.55а	Россия, Вологодская область, Сокольский район, Сокол	0101000020E610000032CB9E04360F44408E210038F6BA4D40
29278	3	27	450	14256	26490	\N	59.457455111246396	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.30	Россия, Вологодская область, Сокольский район, Сокол	0101000020E61000006FB88FDC9A1044402332ACE28DBA4D40
29276	3	27	450	14256	26490	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Советская, д.16		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29291	3	27	450	14256	31797	\N	59.4593447884114	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Призводственная, д.16	Россия, Вологодская область, Сокольский район, Сокол	0101000020E61000004209336DFF0A4440624A24D1CBBA4D40
29288	3	27	450	14256	32039	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Первая Глушицкая, д.31		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29290	3	27	450	14256	31711	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Мусинского, д.4		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29289	3	27	450	14256	31995	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Менделеева, д.37а		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29292	3	27	450	14256	31919	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Колхозная, д.14а		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29279	3	27	450	14256	32011	\N	59.474243999999999	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Кирова, д.19		0101000020E61000002DEA93DC610D444080290307B4BC4D40
29294	3	27	450	14256	31894	\N	59.442628937723597	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Калинина, д.21	Россия, Вологодская область, Сокольский район, Сокол	0101000020E610000078F2E9B12D1344406EA12B11A8B84D40
29287	3	27	450	14256	31764	\N	59.480435345476302	Вологодская область, Сокольский муниципальный район, г.Сокол, ул.Беднякова, д.33	Россия, Вологодская область, Сокольский район, Сокол	0101000020E6100000823B50A73C0A4440486DE2E47EBD4D40
29307	3	27	450	15792	\N	\N	59.364835746516597	Вологодская область, Сокольский муниципальный район, д.Оларево, д.21	Россия, Вологодская область, Сокольский район, село Оларево	0101000020E61000005551BCCADA084440A43330F2B2AE4D40
29312	3	27	450	16040	\N	\N	59.616056	Вологодская область, Сокольский муниципальный район, д.Огарово, д.24		0101000020E6100000A301BC051294444096404AECDACE4D40
29304	3	27	450	15659	\N	\N	59.474229999999999	Вологодская область, Сокольский муниципальный район, д.Обросово, д.65		0101000020E6100000D49AE61DA7FE43401B649291B3BC4D40
29301	3	27	450	15526	\N	\N	59.680760999999997	Вологодская область, Сокольский муниципальный район, д.Нестерово, д.16		0101000020E61000009ACDE33098FF434035B22B2D23D74D40
29303	3	27	450	15612	26475	\N	59.619311000000003	Вологодская область, Сокольский муниципальный район, д.Морженга, ул.Центральная, д.8		0101000020E610000018EDF1423A184440CB86359545CF4D40
29308	3	27	450	15824	26480	\N	59.431818999999997	Вологодская область, Сокольский муниципальный район, д.Марковское, ул.Центральная, д.11		0101000020E6100000095053CBD63A44404D6551D845B74D40
29306	3	27	450	15754	\N	\N	59.422975999999998	Вологодская область, Сокольский муниципальный район, д.Литега, д.14		0101000020E6100000558847E2E51B4440177FDB1324B64D40
29296	3	27	450	15253	26644	\N	59.503607000000002	Вологодская область, Сокольский муниципальный район, г.Кадников, ул.Р.Люксембург, д.58		0101000020E61000003ECE3461FB2B4440B284B53176C04D40
29297	3	27	450	15253	32008	\N	59.503323371824003	Вологодская область, Сокольский муниципальный район, г.Кадников, ул.Р.Люксембург, д.34	Россия, Вологодская область, Сокольский район, Кадников	0101000020E6100000F146E6913F2C44408D2958E36CC04D40
29298	3	27	450	15253	31832	\N	59.503607000000002	Вологодская область, Сокольский муниципальный район, г.Кадников, ул.Парковая, д.8		0101000020E61000003ECE3461FB2B4440B284B53176C04D40
12738	7	66	215	11366	61932	\N	55.162571	с.Старочелны-Сюрбеево, Мирная, 31		0101000020E61000001C9AB2D30FC8474096236420CF944B40
29309	3	27	450	15887	26655	\N	59.494244000000002	Вологодская область, Сокольский муниципальный район, д.Замошье, ул.Школьная, д.5		0101000020E610000032C687D9CB464440431F2C6343BF4D40
29311	3	27	450	15960	31771	\N	59.627388000000003	Вологодская область, Сокольский муниципальный район, д.Воробьево, ул.Центральная, д.2		0101000020E6100000C40776FC1772444091F3FE3F4ED04D40
29302	3	27	450	15554	31951	\N	59.637014000000001	Вологодская область, Сокольский муниципальный район, с.Великий Двор, ул.Центральная, д.46		0101000020E6100000DA1F28B7ED0744400D8CBCAC89D14D40
29300	3	27	450	15472	\N	\N	59.603259999999999	Вологодская область, Сокольский муниципальный район, д.Василево, д.12		0101000020E6100000E38920CEC3F94340137EA99F37CD4D40
29314	3	27	450	16117	31874	\N	59.584988000000003	Вологодская область, Сокольский муниципальный район, с.Биряково, ул.Н.Рубцова, д.6		0101000020E61000006825ADF886BE4440B74604E3E0CA4D40
29299	3	27	450	15399	\N	\N	59.543104	Вологодская область, Сокольский муниципальный район, с.Архангельское, д.43		0101000020E61000008EAED2DD75FA4340D4298F6E84C54D40
29259	3	27	298	13496	\N	\N	60.205567000000002	Вологодская область, Нюксенский район, д.Юшково, 28		0101000020E6100000E25AED612F2E46408411FB04501A4E40
29255	3	27	298	53279	\N	\N	60.2384457343734	Вологодская область, Нюксенский район, д.Пустыня, 17	Россия, Вологодская область, Нюксенский район, село Пустыня	0101000020E61000009F758D9603F9454057EE0566851E4E40
29261	3	27	298	13585	\N	\N	60.175682999999999	Вологодская область, Нюксенский район, п.Пески, 43		0101000020E6100000EFC9C342ADE1454049BBD1C77C164E40
29266	3	27	298	13840	31758	\N	60.469920999999999	Вологодская область, Нюксенский район, п.Озерки, Набережная, 45		0101000020E6100000800D8810574A4640105A0F5F263C4E40
29271	3	27	298	2447	31782	\N	60.415486000000001	Вологодская область, Нюксенский район, с.Нюксеница, Юбилейная, 14-а, клуб газовиков		0101000020E610000071E82D1EDE1D464012F92EA52E354E40
29269	3	27	298	2447	26551	\N	60.415486000000001	Вологодская область, Нюксенский район, с.Нюксеница, Школьная, 1		0101000020E610000071E82D1EDE1D464012F92EA52E354E40
29267	3	27	298	2447	31879	\N	60.415486000000001	Вологодская область, Нюксенский район, с.Нюксеница, Советская, 14		0101000020E610000071E82D1EDE1D464012F92EA52E354E40
29268	3	27	298	2447	31700	\N	60.415486000000001	Вологодская область, Нюксенский район, с.Нюксеница, Первомайская, 13 А		0101000020E610000071E82D1EDE1D464012F92EA52E354E40
29270	3	27	298	2447	31708	\N	60.415486000000001	Вологодская область, Нюксенский район, с.Нюксеница, Культуры, 2		0101000020E610000071E82D1EDE1D464012F92EA52E354E40
29260	3	27	298	13568	\N	\N	60.230815	Вологодская область, Нюксенский район, д.Матвеевская, 43		0101000020E61000006E4DBA2D913546408F368E588B1D4E40
29264	3	27	298	13751	26583	\N	60.473486999999999	Вологодская область, Нюксенский район, п.Матвеево, Школьная, 6		0101000020E6100000FDA4DAA7E34F4640630AD6389B3C4E40
29274	3	27	298	14242	31759	\N	60.490501000000002	Вологодская область, Нюксенский район, д.Лесютино, Лесная, 1		0101000020E61000003F8BA548BE104640E1D39CBCC83E4E40
29254	3	27	298	13287	31883	\N	60.521222999999999	Вологодская область, Нюксенский район, п.Леваш, Школьная, 5		0101000020E61000000DC171193771464025766D6FB7424E40
29265	3	27	298	13775	32037	\N	60.467083000000002	Вологодская область, Нюксенский район, д.Красавино, Культуры, 8		0101000020E6100000F29A5775563D464040C23060C93B4E40
29253	3	27	298	13209	31822	\N	60.581871	Вологодская область, Нюксенский район, п.Копылово, Молодежная, 18		0101000020E6100000E294B9F9468A4640D3BEB9BF7A4A4E40
29262	3	27	298	13659	32001	\N	60.169041	Вологодская область, Нюксенский район, п.Игмас, Октябрьская, 31		0101000020E61000000002D6AA5DE345407157AF22A3154E40
29257	3	27	298	2359	31985	\N	60.231980999999998	Вологодская область, Нюксенский район, с.Городищна, ул.Школьная,7		0101000020E61000002FF7C951802E46408D25AC8DB11D4E40
29258	3	27	298	2359	31772	\N	60.228273584728399	Вологодская область, Нюксенский район,с.Городишна, ул.Октябрьская, 26	Россия, Вологодская область, Нюксенский район, село Городищна	0101000020E61000002A6F47382D2E464078431A15381D4E40
29252	3	27	298	13197	26411	\N	60.538150000000002	Вологодская область, Нюксенский район, д.Вострое, Полевая, 3		0101000020E61000006495D233BD764640D42B6519E2444E40
29256	3	27	298	2293	31824	\N	60.220934999999997	Вологодская область, Нюксенский район, д.Брусноволовский Погост, Школьная, 8		0101000020E61000002E7590D7830B464058C51B99471C4E40
29263	3	27	298	13680	26449	\N	60.480581000000001	Вологодская область, Нюксенский район, д.Бобровское, Болотная, 12		0101000020E6100000B5A4A31CCC6246401C0A9FAD833D4E40
29272	3	27	298	14131	31819	\N	60.419781999999998	Вологодская область, Нюксенский район, д.Березово, Луговая, 17		0101000020E6100000C72FBC92E423464088B9A46ABB354E40
29273	3	27	298	14160	26432	\N	60.392417999999999	Вологодская область, Нюксенский район, д.Березовая Слободка, Полевая, 5		0101000020E6100000066344A2D01446404D2EC6C03A324E40
29238	3	27	413	12537	\N	\N	59.942695999999998	Вологодская область, Никольский муниципальный район, п.Шарженга	Россия, Вологодская область, Никольский район, село Шарженга	0101000020E6100000B43A394371734640F6083543AAF84D40
29240	3	27	413	53256	\N	\N	59.715086140854801	Вологодская область, Никольский муниципальный район, д.Филинский починок, д.54		0101000020E6100000BE4D7FF623974640EAE923F087DB4D40
29228	3	27	413	12083	\N	\N	59.597991	Вологодская область, Никольский муниципальный район, д.Старина, д.40		0101000020E610000061DD787764584640B32616F88ACC4D40
29244	3	27	413	12850	26437	\N	59.378988	Вологодская область, Никольский муниципальный район, д.Скочково, ул.Центральная, д.9А		0101000020E61000001492CCEA1DB84640C9C9C4AD82B04D40
29233	3	27	413	12308	\N	\N	59.847982000000002	Вологодская область, Никольский муниципальный район, д.Рокуново, д.62		0101000020E610000047C66AF3FF72464060CC96AC8AEC4D40
29242	3	27	413	12739	\N	\N	59.424765999999998	Вологодская область, Никольский муниципальный район, д.Путилово, д.48		0101000020E61000002383DC4598584640F33977BB5EB64D40
12874	7	66	215	49516	62730	\N	55.24409	д.Старый Сундырь, Ленина, 29		0101000020E610000018E945ED7ED34740ECA353573E9F4B40
29226	3	27	413	11979	\N	\N	59.781962999999998	Вологодская область, Никольский муниципальный район, д.Половина, д.28		0101000020E610000020274C18CD7646404DD7135D17E44D40
29248	3	27	413	13006	\N	\N	59.511839999999999	Вологодская область, Никольский муниципальный район, д.Полежаево, д.48		0101000020E610000072361D01DC7846406F641EF983C14D40
29245	3	27	413	12863	\N	\N	59.331992	Вологодская область, Никольский муниципальный район, д.Пермас, д.51		0101000020E610000035289A07B0CC46404E44BFB67EAA4D40
29243	3	27	413	12786	31756	\N	59.470540999999997	Вологодская область, Никольский муниципальный район, д.Осиново, ул.Городской край, д.17А		0101000020E61000007BDD2230D6B54640AC36FFAF3ABC4D40
29241	3	27	413	12718	31750	\N	59.383274	Вологодская область, Никольский муниципальный район, с.Никольское, ул.50-летия Победы, д.14А		0101000020E61000001572A59E054B46401CB4571F0FB14D40
29215	3	27	413	53252	32060	\N	59.528105921508804	Вологодская область, Никольский муниципальный район, муниципальное образование город Никольск, ул.Конева, д.133 В		0101000020E610000030DAE38574BC4640236937FA98C34D40
29214	3	27	413	53252	32050	\N	59.529735233422997	Вологодская область, Никольский муниципальный район, муниципальное образование город Никольск, ул.Советская, д.161	Россия, Вологодская область, Никольский район, Никольск	0101000020E610000053EC681CEAB94640F645425BCEC34D40
29217	3	27	413	53252	31706	\N	59.527858173452699	Вологодская область, Никольский муниципальный район, муниципальное образование город Никольск, ул.Кузнецова, д.46	Россия, Вологодская область, Никольский район, Никольск	0101000020E61000005760C8EA56BB46404B77D7D990C34D40
29212	3	27	413	53252	32051	\N	59.5320678910632	Вологодская область, Никольский муниципальный район, муниципальное образование город Никольск, ул.Володарского, 10, ЦРБ	Россия, Вологодская область, Никольский район, Никольск	0101000020E6100000A9C0C93670BB4640C39FE1CD1AC44D40
29216	3	27	413	53252	32108	\N	59.5282747918247	Вологодская область, Никольский муниципальный район, муниципальное образование город Никольск, ул.Беляева, д.53	Россия, Вологодская область, Никольский район, Никольск	0101000020E6100000D0D4EB1681BB4640AF25E4839EC34D40
29218	3	27	413	53252	32069	\N	59.5280567846008	Вологодская область, Никольский муниципальный район, муниципальное образование город Никольск, ул.Энергетиков, д.21	Россия, Вологодская область, Никольский район, Никольск	0101000020E610000031B43A3943BB464041B62C5F97C34D40
29239	3	27	413	12623	31692	\N	59.652244000000003	Вологодская область, Никольский муниципальный район, д.Нигино, ул.Школьная, д.11		0101000020E61000004F1E166A4DA3464091813CBB7CD34D40
29249	3	27	413	13024	\N	\N	59.543076999999997	Вологодская область, Никольский муниципальный район, п.Молодежный, д.42 кв.2		0101000020E610000029B000A60C904640DA1A118C83C54D40
28898	3	27	413	13024	\N	\N	59.543076999999997	"Вологодская область, Вожегодский район, поселок Молодежный, ""Сельский клуб Молодежный"" филиал МБУК ""ВР КДО"", 4 А"		0101000020E610000029B000A60C904640DA1A118C83C54D40
29237	3	27	413	2253	\N	\N	59.899807000000003	Вологодская область, Никольский муниципальный район, д.Милофаново, д.65		0101000020E610000046274BADF77546401FDB32E02CF34D40
29246	3	27	413	53272	\N	\N	59.295601663388297	Вологодская область, Никольский муниципальный район, п.Кудангский, д.162	Россия, Вологодская область, Никольский район, село Куданский	0101000020E610000047054EB681B14640EC504D49D6A54D40
29223	3	27	413	11820	\N	\N	59.588067000000002	Вологодская область, Никольский муниципальный район, д.Кривяцкое, д.4А		0101000020E6100000435376FA41D34640AD6D8AC745CB4D40
29225	3	27	413	11920	\N	\N	59.760148999999998	Вологодская область, Никольский муниципальный район, д.Котельное, д.57		0101000020E6100000E0BC38F1D5864640268BFB8F4CE14D40
29234	3	27	413	12359	31687	\N	59.476849000000001	Вологодская область, Никольский муниципальный район, д.Кожаево, ул.Школьная, д.1		0101000020E6100000D28E1B7E37C14640AE10566309BD4D40
29250	3	27	413	53271	\N	\N	59.696334276687601	Вологодская область, Никольский муниципальный район, с.Кипшеньга, д.60	Россия, Вологодская область, Никольский район, село Кипшенга	0101000020E6100000B0FF3A376DAE4640E38BF67821D94D40
29251	3	27	413	13121	\N	\N	59.760131000000001	Вологодская область, Никольский муниципальный район, д.Калинино, д.86		0101000020E61000006EDE3829CCAB464080D6FCF84BE14D40
29220	3	27	413	11689	\N	\N	59.834108000000001	Вологодская область, Никольский муниципальный район, д.Ильинское, д.103		0101000020E61000001D774A07EB8B46407EAA0A0DC4EA4D40
29232	3	27	413	12271	\N	\N	59.875587000000003	Вологодская область, Никольский район, д.Зеленцово, здание администрации Зеленцовского сельского поселения, д.139		0101000020E6100000713D0AD7A37C4640C1E61C3C13F04D40
29222	3	27	413	11787	\N	\N	59.635795000000002	Вологодская область, Никольский муниципальный район, д. Займище, д.1		0101000020E6100000CADFBDA3C6D84640ECFA05BB61D14D40
29229	3	27	413	12123	31747	\N	59.442141999999997	Вологодская область, Никольский муниципальный район, д.Завражье, ул.Молодежная, д.16		0101000020E6100000698CD651D5EE46401118EB1B98B84D40
29231	3	27	413	12242	31877	\N	59.330798000000001	Вологодская область, Никольский муниципальный район, п.Дуниловский, ул.Центральная, д.4Б		0101000020E61000001F813FFCFCED464086CABF9657AA4D40
29230	3	27	413	12181	31982	\N	59.478895999999999	Вологодская область, Никольский муниципальный район, п.Высокинский, ул.Центральная, д.6А		0101000020E6100000AC55BB26A4074740B517D1764CBD4D40
29224	3	27	413	11858	\N	\N	59.784435000000002	Вологодская область, Никольский муниципальный район, д.Вахнево, д.31		0101000020E6100000AA9D616A4B9746403C6BB75D68E44D40
29236	3	27	413	12449	\N	\N	59.597076000000001	Вологодская область, Никольский муниципальный район, д.Бутова Курья, д.79		0101000020E6100000C90391459A9A4640FE9C82FC6CCC4D40
29227	3	27	413	12023	31865	\N	59.501488000000002	Вологодская область, Никольский муниципальный район, п.Борок, ул.Советская, д.21		0101000020E610000064AE0CAA0D62464011AB3FC230C04D40
29247	3	27	413	12942	\N	\N	59.258380000000002	Вологодская область, Никольский муниципальный район, д.Большое Сверчково, д.17		0101000020E6100000533F6F2A52E9464062F8889812A14D40
29221	3	27	413	11739	\N	\N	59.649183999999998	Вологодская область, Никольский муниципальный район, д.Байдарово, д.2		0101000020E6100000874F3A9160C64640118B187618D34D40
29219	3	27	413	11651	26593	\N	59.857923999999997	Вологодская область, Никольский муниципальный район, д.Аргуново, ул.Березовая, д.27		0101000020E610000036CD3B4ED18D46400C3A2174D0ED4D40
29235	3	27	413	12416	\N	\N	59.544221999999998	Вологодская область, Никольский муниципальный район, д.Абатурово, д.64А		0101000020E6100000C72AA5677ABF4640C1E10511A9C54D40
29171	3	27	213	9335	31730	\N	59.374129000000003	Вологодская область, Междуреченский район, с. Шуйское, Советская, 12		0101000020E6100000A5A2B1F6778244401BBE8575E3AF4D40
29208	3	27	213	2012	31681	\N	59.395736999999997	Вологодская область, Междуреченский район, посёлок Шиченга, Первомайская, 20		0101000020E6100000BF654E97C594444098689082A7B24D40
29211	3	27	213	11264	26635	\N	59.254897999999997	Вологодская область, Междуреченский район, село Шейбухта, Шейбухтовская, 1		0101000020E61000000A647616BD7544406CE8667FA0A04D40
29210	3	27	213	11190	31926	\N	59.575474	Вологодская область, Междуреченский район, поселок Туровец, Комсомольская, 83		0101000020E6100000105CE50984F7444062D9CC21A9C94D40
29207	3	27	213	11089	31859	\N	59.270043000000001	Вологодская область, Междуреченский район, село Старое, Кооперативная, 4		0101000020E6100000321EA5129E544440C2C1DEC490A24D40
29206	3	27	213	11027	31802	\N	59.280240999999997	Вологодская область, Междуреченский район, село Спас-Ямщики, Новая, 8		0101000020E6100000C15774EB355B4440C9FFE4EFDEA34D40
29209	3	27	213	809	26397	\N	59.307288	Вологодская область, Междуреченский район, посёлок Пионерский, ул.Свободы, 1, начальная школа		0101000020E6100000C93A1C5DA5734440043A933655A74D40
29204	3	27	213	10958	31679	\N	59.191043000000001	Вологодская область, Междуреченский район, деревня Игумницево, Юбилейная, 10		0101000020E610000048A7AE7C965544409B90D61874984D40
28882	3	27	213	27207	\N	\N	59.147089999999999	Вологодская область, Вожегодский район, деревня Иваньково, администрация сельского поселения Бекетовское, 6		0101000020E610000079B29B19FD804440C9C859D8D3924D40
29199	3	27	213	2109	31672	\N	59.141427	Вологодская область, Междуреченский район, деревня Гаврилково, Центральная, 6, дом культуры		0101000020E610000021037976F9724440BDE2A9471A924D40
29205	3	27	213	10971	31917	\N	59.302346	Вологодская область, Междуреченский район, деревня Врагово, Октябрьская, 2		0101000020E610000071C806D2C58A4440C8091346B3A64D40
29203	3	27	233	10915	26556	\N	59.964272999999999	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Югское, п.Югский, Центральная, 17		0101000020E6100000E17F2BD9B1F9464039B5334C6DFB4D40
29202	3	27	233	10835	\N	\N	59.939982999999998	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Шонгское, с.Шонга, 10		0101000020E610000058CB9D9960D64640E2E5E95C51F84D40
29201	3	27	233	10830	31915	\N	59.906025	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Шонгское, ,д.Шатенево, Центральная, 1		0101000020E6100000B62DCA6C90BB4640E02D90A0F8F34D40
29177	3	27	233	9611	\N	\N	59.997604000000003	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Городецкое, Торопово, 45		0101000020E61000000FEECEDA6DE34640ED2DE57CB1FF4D40
29182	3	27	233	53269	\N	\N	59.971981754811502	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Енангское, с.Слободка, 12	Россия, Вологодская область, Кичменгско-Городецкий район, село Слободка	0101000020E61000005A1135D1E71B47407C26FBE769FC4D40
29188	3	27	233	51281	\N	\N	60.031139850928298	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Кичменгское, д.Слобода, 21, сельский клуб	Россия, Вологодская область, Кичменгско-Городецкий район, село Слобода	0101000020E6100000F1660DDE57ED464079CC4065FC034E40
29197	3	27	233	10637	\N	\N	60.214708999999999	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Трофимовское, с.Светица, 4		0101000020E6100000876D8B321B8846401494A2957B1B4E40
29196	3	27	233	10563	\N	\N	60.139099999999999	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Сараевское, с.Сараево, 25		0101000020E610000046B5882826A54640D26F5F07CE114E40
29178	3	27	233	9655	\N	\N	59.904535827870802	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Городецкое, д.Подол, 40	Россия, Вологодская область, Кичменгско-Городецкий район, село Подол	0101000020E6100000397CD28904DB4640FF06EDD5C7F34D40
29198	3	27	233	10641	31699	\N	60.062210999999998	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Шестаковское, д.Подволочье, Спортивная, 1		0101000020E61000008FE1B19FC5F04640C939B187F6074E40
29181	3	27	233	9821	\N	\N	60.082681999999998	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Енангское, д.Олятово, 26		0101000020E610000011C7BAB88D3C4740E3FBE252950A4E40
29184	3	27	233	9973	\N	\N	59.970587000000002	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Енангское, Нижняя Ентала, 40		0101000020E61000007808E3A7715147401D76DF313CFC4D40
29183	3	27	233	9907	26714	\N	59.992092	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Енангское, с.Нижний Енангск, Центральная, 39		0101000020E6100000F8510DFB3D334740C64FE3DEFCFE4D40
29187	3	27	233	10129	\N	\N	60.168968999999997	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Кичменгское, п.Лаптюг, 60 А		0101000020E6100000952BBCCB45FC4640D784B4C6A0154E40
29190	3	27	233	10287	\N	\N	59.799112999999998	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Куриловское, д.Курилово, 33		0101000020E61000004485EAE6E2BF46407B67B45549E64D40
29192	3	27	233	1019	31795	\N	59.891114000000002	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Плосковское, с.Косково, ул.Почтовая, 13, сельский клуб		0101000020E61000006077BAF3C4FF4640FE80070610F24D40
28894	3	27	233	27772	\N	\N	59.930831641581598	Вологодская область, Вожегодский район, деревня Коряковская, д.1, Тавенгская начальная школа	Россия, Вологодская область, Кичменгско-Городецкий район, село Коряковская	0101000020E6100000A46DFC89CAF44640FF08C38025F74D40
29193	3	27	233	10434	31911	\N	60.003644620513498	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Погосское, с.Кобыльск, Центральная, 9	Россия, Вологодская область, Кичменгско-Городецкий район, село Кобыльск	0101000020E61000007C2AA73D250F47409FE5797077004E40
29179	3	27	233	51315	\N	\N	60.050962916429903	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Захаровское, с.Кичменга, 23	Россия, Вологодская область, Кичменгско-Городецкий район, село Кичменьга	0101000020E61000009697FC4FFECC46402D27A1F485064E40
29174	3	27	233	53285	32164	\N	59.990572877632502	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Городецкое, с.Кичменгский Городок, Центральная, 8	Россия, Вологодская область, Кичменгско-Городецкий район, село Кичменский Городок	0101000020E6100000AA471ADCD6E646407AA69718CBFE4D40
29173	3	27	233	53285	32073	\N	59.9912178704637	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Городецкое, с.Кичменгский Городок, Лесная, 15		0101000020E6100000394371C79BE64640709A3E3BE0FE4D40
29200	3	27	233	1954	31674	\N	60.066549000000002	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Шестаковское, с.Кильченга, ул.Советская, 109, администрация		0101000020E6100000F44F70B1A22A47406F4A79AD84084E40
29195	3	27	233	1880	\N	\N	60.089987999999998	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Сараевское, д.Исады, 15/2, ФАП		0101000020E610000006802A6EDCAC464027840EBA840B4E40
29191	3	27	233	10318	32041	\N	59.801811000000001	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Плосковское, д.Еловино, Центральная, 14		0101000020E610000017450F7C0CEA46405A492BBEA1E64D40
29186	3	27	233	10053	\N	\N	60.029938999999999	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Кичменгское, с.Дорожково, 21		0101000020E610000079573D601EFC4640FEEF880AD5034E40
29180	3	27	233	9777	\N	\N	60.106208000000002	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Захаровское, п.Гаражи, 61		0101000020E61000004F5DF92CCFBF46406B494739980D4E40
29172	3	27	233	53286	32072	\N	59.8750845160491	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Верхнеентальское, с.Верхняя Ентала, Центральная, 25	Россия, Вологодская область, Кичменгско-Городецкий район, село Верняя Ентала	0101000020E6100000452A8C2D045347402E1C08C902F04D40
29189	3	27	233	10198	\N	\N	60.059454000000002	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Кичменгское, д. Ваганово, 28, дом культуры		0101000020E6100000B70C384BC9D24640E6CE4C309C074E40
29185	3	27	233	10034	\N	\N	59.894021000000002	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Кичменгское, д.Березовая Гора, 68		0101000020E61000007782FDD7B9DD4640F777B6476FF24D40
29176	3	27	233	9549	31968	\N	59.983342	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Городецкое, д.Ананино, Дорожная, 1		0101000020E61000005CCB64389EE7464041649126DEFD4D40
29194	3	27	233	10490	26543	\N	60.036527999999997	Вологодская область, Кичменгско-Городецкий муниципальный район, муниципальное образование Погосское, д.Алферово, Центральная, 31		0101000020E61000001212691B7F144740B3B112F3AC044E40
29154	3	27	949	8579	\N	\N	59.773736999999997	Вологодская область, Кирилловский район, п.Шиндалово, Здание Дома культуры, 8 А		0101000020E6100000FE0C6FD6E0214340425A63D009E34D40
29168	3	27	949	9191	31729	\N	60.457723000000001	Вологодская область, Кирилловский район, с.Чарозеро, Центральная, 36		0101000020E6100000A9DC442DCD51434042D0D1AA963A4E40
29166	3	27	949	9109	31728	\N	59.953722999999997	Вологодская область, Кирилловский район, с.Ферапонтово, Слободская, 6		0101000020E6100000543A58FFE7484340B438639813FA4D40
29155	3	27	949	8629	26700	\N	59.763126	Вологодская область, Кирилловский район, м.Топорня, Клубный переулок, 4		0101000020E610000008E9297288304340185DDE1CAEE14D40
29163	3	27	949	8990	32031	\N	59.645432	Вологодская область, Кирилловский район, с.Талицы, Советская, 31		0101000020E6100000BF7D1D38676643405CE509849DD24D40
29165	3	27	949	9095	32029	\N	59.852514999999997	Вологодская область, Кирилловский район, д.Суховерхово, Центральная, 29		0101000020E61000008F56B5A4A33E4340BA2C26361FED4D40
29161	3	27	949	8880	\N	\N	59.859622999999999	Вологодская область, Кирилловский район, с.Рукино, Здание библиотеки-клуба, 9		0101000020E61000003E23111AC17A4340D8F15F2008EE4D40
29159	3	27	949	53251	\N	\N	59.983569610370097	Вологодская область, Кирилловский район, м.Пустынь, Здание администрации Пустынского ПНИ, 13	Россия, Вологодская область, Кирилловский район, село Пустынь	0101000020E61000006D6FB72407264340D2A92B9FE5FD4D40
29157	3	27	949	8732	31964	\N	59.993937000000003	Вологодская область, Кирилловский район, п.Новостройка, Ленина, 1		0101000020E610000030F0DC7BB83A434066A4DE5339FF4D40
29160	3	27	949	8835	31965	\N	59.875546	Вологодская область, Кирилловский район, с.Никольский Торжок, Захарьинская, 15		0101000020E6100000CCB4FD2B2B63434062122EE411F04D40
28888	3	27	949	27476	\N	\N	59.955916999999999	"Вологодская область, Вожегодский район, деревня Лукьяновская, сельский филиал МБУК ""Вожегодская ЦБС"", 17"		0101000020E61000000E9E094D126B43406058FE7C5BFA4D40
29169	3	27	949	9249	26532	\N	60.301251000000001	Вологодская область, Кирилловский район, д.Коротецкая, Головинская, 1		0101000020E6100000D8F15F200856434093718C648F264E40
29170	3	27	949	9284	\N	\N	60.644610999999998	Вологодская область, Кирилловский район, д.Королево, Здание Администрации поселения Чарозерское, 7		0101000020E6100000C45F9335EA63434028D2FD9C82524E40
29164	3	27	949	9032	\N	\N	59.693578000000002	Вологодская область, Кирилловский район, с.Колкач, Здание Администрации Талицкого поселения, 107		0101000020E61000008B4E965AEF714340D09CF529C7D84D40
29145	3	27	949	8124	31753	\N	60.150218000000002	Вологодская область, Кирилловский район, д.Коварзино, Центральная, 8		0101000020E61000003849F3C7B4484340A1A2EA573A134E40
29152	3	27	949	8398	31680	\N	59.865074464975798	Вологодская область, Кирилловский район, город Кириллов, Уверова, 23	Россия, Вологодская область, Кирилловский район, Кириллов	0101000020E6100000E90E62670A314340594FADBEBAEE4D40
29153	3	27	949	8398	31849	\N	59.854033999999999	Вологодская область, Кирилловский район, город Кириллов, Советская, 19		0101000020E6100000B55208E4122F434006D671FC50ED4D40
29151	3	27	949	8398	26694	\N	59.854497729582903	Вологодская область, Кирилловский район, город Кириллов, Гагарина, 108	Россия, Вологодская область, Кирилловский район, Кириллов	0101000020E6100000C58CF0F620304340AB3FC23060ED4D40
29150	3	27	949	8398	26694	\N	59.849704710182202	Вологодская область, Кирилловский район, город Кириллов, Гагарина, 30 А	Россия, Вологодская область, Кирилловский район, Кириллов	0101000020E6100000EDD45C6E30304340B41F2922C3EC4D40
29156	3	27	949	8643	31808	\N	59.76831	Вологодская область, Кирилловский район, д.Иванов Бор, Центральная, 18		0101000020E6100000CBD58F4DF21F43404A9869FB57E24D40
29167	3	27	949	9174	\N	\N	59.927134000000002	Вологодская область, Кирилловский район, п.Запань Нова, Здание Дома культуры, 19		0101000020E610000010070951BE5643403D81B053ACF64D40
29136	3	27	949	7713	31723	\N	59.870573999999998	Вологодская область, Кирилловский район, с.Горицы, Центральная, 38		0101000020E61000005281936DE0204340BB5F05F86EEF4D40
29162	3	27	949	8933	31967	\N	59.917704999999998	Вологодская область, Кирилловский район, с.Волокославинское, Преображенского, 49		0101000020E6100000CF31207BBD6343401630815B77F54D40
29158	3	27	949	8766	31790	\N	59.977553	Вологодская область, Кирилловский район, с.Вогнема, Центральная, 38		0101000020E610000013B534B742144340A88DEA7420FD4D40
29139	3	27	191	7857	31873	\N	59.14817	Вологодская область, Кадуйский муниципальный район, муниципальное образование поселок Хохлово, п.Хохлово, Школьная площадь, 2		0101000020E6100000058C2E6F0EB34240C91F0C3CF7924D40
29144	3	27	191	8080	31900	\N	59.278337999999998	Вологодская область, Кадуйский муниципальный район, муниципальное образование Бойловское, п.Фанерный Завод, Заводская, 25		0101000020E61000007DE882FA96A34240F59D5F94A0A34D40
29142	3	27	191	53289	32078	\N	59.582674754058502	Вологодская область, Кадуйский муниципальный район, муниципальное образование Барановское, п.Сосновка, Центральная, 5А	Россия, Вологодская область, Кадуйский район, село Сосновка	0101000020E610000073F1B73D4140424031992A1895CA4D40
29148	3	27	191	8267	26672	\N	59.352809999999998	Вологодская область, Кадуйский муниципальный район, муниципальное образование Никольское, с.Никольское, Городская, 4		0101000020E6100000B6494563ED954240D3D9C9E028AD4D40
29149	3	27	191	8361	26517	\N	59.196038999999999	Вологодская область, Кадуйский муниципальный район, муниципальное образование Рукавицкое, д.Малая Рукавицкая, переулок Рабочий, 11		0101000020E61000006404543882984240CADE52CE17994D40
29147	3	27	191	8252	26671	\N	59.327865000000003	Вологодская область, Кадуйский муниципальный район, муниципальное образование Мазское, д.Маза, Центральная, 66		0101000020E6100000AF0793E2E35B42406440F67AF7A94D40
29133	3	27	191	53267	31837	\N	59.208584390510403	Вологодская область, Кадуйский муниципальный район, муниципальное образование поселок Кадуй, п.Кадуй, Строителей, 2	Россия, Вологодская область, Кадуйский район, село Крюково	0101000020E6100000F910548D5E8D4240043C69E1B29A4D40
29511	3	27	191	52618	31777	\N	59.176369000000001	Вологодская область, Череповецкий муниципальный район, п. Кривец, Новая, 32-а		0101000020E6100000FF5BC98E8DB642409D83674293964D40
29138	3	27	191	702	26552	\N	59.206268000000001	Вологодская область, Кадуйский муниципальный район, муниципальное образование поселок Кадуй, п.Кадуй, Энтузиастов, 8А		0101000020E6100000782AE09EE79342400D1B65FD669A4D40
29089	3	27	27	5379	\N	\N	58.852972999999999	Грязовецкий район д.Жерноково, д.86  Жерноковский СДК		0101000020E6100000191D90847D4F44407DAF21382E6D4D40
29137	3	27	191	702	26552	\N	59.206268000000001	Вологодская область, Кадуйский муниципальный район, муниципальное образование поселок Кадуй, п.Кадуй, Энтузиастов, 3,школа № 3		0101000020E6100000782AE09EE79342400D1B65FD669A4D40
29135	3	27	191	702	26552	\N	59.206268000000001	Вологодская область, Кадуйский муниципальный район, муниципальное образование поселок Кадуй, п.Кадуй, Энтузиастов, 3		0101000020E6100000782AE09EE79342400D1B65FD669A4D40
29134	3	27	191	702	26552	\N	59.206358523798798	Кадуйский район, п. Кадуй, ул. Энтузиастов, д. 3, МОУ Кадуйская средняя общеобразовательная школа № 3 (столовая)	Россия, Вологодская область, Кадуйский район, поселок Кадуй	0101000020E610000007EA9447379442401D1EC2F8699A4D40
29132	3	27	191	702	31937	\N	59.206268000000001	Вологодская область, Кадуйский муниципальный район, муниципальное образование поселок Кадуй, п.Кадуй, Чехова, 1А		0101000020E6100000782AE09EE79342400D1B65FD669A4D40
29131	3	27	191	702	26461	\N	59.200175786632798	Кадуйский муниципальный район, муниципальное образование поселок Кадуй, п.Кадуй, Кирова, 49	Россия, Вологодская область, Кадуйский район, поселок Кадуй	0101000020E6100000EAAEEC82C1934240D8B8FE5D9F994D40
29130	3	27	191	702	26461	\N	59.206268000000001	Вологодская область, Кадуйский муниципальный район, муниципальное образование поселок Кадуй, п.Кадуй, Кирова, 49, школа № 1		0101000020E6100000782AE09EE79342400D1B65FD669A4D40
28737	3	27	191	20412	\N	\N	59.271101000000002	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Миньковское, д. В-Двор, 72		0101000020E6100000BF81C98D22494240DA740470B3A24D40
29146	3	27	191	8190	26668	\N	59.523302000000001	Вологодская область, Кадуйский муниципальный район, муниципальное образование Никольское, с.Великое, Ветеранов, 8		0101000020E6100000637B2DE8BD81424038F7578FFBC24D40
29143	3	27	191	7999	26511	\N	59.284543999999997	Вологодская область, Кадуйский муниципальный район, муниципальное образование Бойловское, д.Бойлово, Центральная, 18		0101000020E6100000A703594FADAC4240F22213F06BA44D40
29141	3	27	191	7940	26430	\N	59.532919457222697	Вологодская область, Кадуйский муниципальный район, муниципальное образование Барановское, д.Барановская, Центральная, 15	Россия, Вологодская область, Кадуйский район, село Барановская	0101000020E61000004CE141B3EB404240613596B036C44D40
29140	3	27	191	7865	\N	\N	59.402906000000002	Вологодская область, Кадуйский муниципальный район, муниципальное образование Андроновское,д.Андроново, Надежды, 13	Россия, Вологодская область, Кадуйский район, село Андроново	0101000020E61000007F50172994A142405CAE7E6C92B34D40
29126	3	27	27	596	31889	\N	58.968640999999998	Грязовецкий район д.Юрово, ул.Центральная, д.2  Администрация МО Юровское		0101000020E610000066F9BA0CFFFD43404948A46DFC7B4D40
29110	3	27	27	1551	31860	\N	59.021180999999999	Грязовецкий район д.Хорошево, ул.Сосновая, д.2  Администрация МО Комьянское		0101000020E6100000C02500FF94224440F6251B0FB6824D40
29111	3	27	27	1551	31696	\N	59.021180999999999	Грязовецкий район д.Хорошево, ул.Сосновая, д.1  Администрация МО Комьянское		0101000020E6100000C02500FF94224440F6251B0FB6824D40
29113	3	27	27	6656	\N	\N	58.919179999999997	Грязовецкий район д.Фрол, д.26  Администрация МО Перцевское		0101000020E6100000BAD7497D593E44409291B3B0A7754D40
29127	3	27	27	692	31890	\N	58.933379000000002	Грязовецкий район д.Степурино, ул.Полевая, д. 13  Степуринский сельский клуб		0101000020E61000004F745DF8C1054440F8E28BF678774D40
29122	3	27	27	483	\N	\N	58.925363305044101	Вологодская область, Грязовецкий район, лежский СДК, д.Спасская, 32	Россия, Вологодская область, Грязовецкий район, село Спасское	0101000020E6100000F85278D0EC5E4440D7F6764B72764D40
29067	3	27	27	53288	32075	\N	58.823535137285504	Грязовецкий район д.Слобода, ул.Школьная, д.11А   Администрация МО Перцевское	Россия, Вологодская область, Грязовецкий район	0101000020E6100000A73FFB91225A4440410E4A9869694D40
29128	3	27	27	7354	26567	\N	58.863886999999998	Грязовецкий район д.Скородумка, ул.Центральная, д.47  Чернецкий СДК		0101000020E61000004391EEE714024440433866D9936E4D40
29116	3	27	27	187	26467	\N	58.718786000000001	Грязовецкий район д.Сидоровское, ул.Центральная, д.8   Сидоровский СДК		0101000020E6100000C76647AAEF3244404D69FD2D015C4D40
29120	3	27	27	410	26628	\N	58.757717	Грязовецкий район с.Сидорово, ул.Советская, д.15 Администрация МО Сидоровское		0101000020E6100000CE88D2DEE07D4440C64FE3DEFC604D40
29114	3	27	27	33	31716	\N	58.7986581875683	Грязовецкий район д.Ростилово, ул.Молодежная, д.5  Администрация МО Ростиловское.		0101000020E610000064CF9ECBD42244402A58E36C3A664D40
29118	3	27	27	307	26402	\N	58.637106000000003	Грязовецкий район п.Плоское, ул.Школьная, д.11  Плосковский сельский филиал БУК «Межпоселенческая центральная библиотека»		0101000020E61000004754A86E2E244440EE0A7DB08C514D40
29125	3	27	27	7151	\N	\N	58.980018999999999	Грязовецкий район д.Панфилово, д.61  Панфиловский сельский клуб		0101000020E61000007714E7A8A3EF4340B43A3943717D4D40
29078	3	27	27	1844	31888	\N	59.007806000000002	Грязовецкий район д.Палкино, ул.Центральная, д.15  Палкинский сельский клуб		0101000020E6100000EA2285B2F0114440365B79C9FF804D40
29123	3	27	27	548	31761	\N	58.965193999999997	Вологодская область, Грязовецкий район, с.Минькино, ул.Новая, 61		0101000020E61000002733DE567AE14340D0251C7A8B7B4D40
29115	3	27	27	53278	31980	\N	58.832556823091203	Грязовецкий район п.Льнозавод, ул.Речная,33	Россия, Вологодская область, Грязовецкий район, поселок Льнозавода	0101000020E6100000464431790320444027874F3A916A4D40
29117	3	27	27	6823	\N	\N	58.737887999999998	Грязовецкий район д.Заемье, д.19 Заемский сельский клуб		0101000020E6100000F33B4D66BC254440300E2E1D735E4D40
28926	3	27	27	29210	\N	\N	59.006332	Вологодская область, Вологодский район, п. Дорожный, 2		0101000020E6100000D61EF642011944408A75AA7CCF804D40
29108	3	27	27	4652	\N	\N	58.890591000000001	Грязовецкий район д.Демьяново д. 11  Администрация Вохтожского городского поселения		0101000020E61000004E2A1A6B7F934440548EC9E2FE714D40
29093	3	27	27	4103	31768	\N	58.875537000000001	Грязовецкий район г.Грязовец,ул. Революции,104 спортивный комплекс "Атлант",		0101000020E610000077853E58C61E44400FB8AE9811704D40
29101	3	27	27	4103	31960	\N	58.875537000000001	Грязовецкий район г.Грязовец, ул. Рабочая, д.1, здание ФАП		0101000020E610000077853E58C61E44400FB8AE9811704D40
29098	3	27	27	4103	31947	\N	58.880749894836597	Грязовецкий район г.Грязовец, ул. К.Маркса, д.71  БОУ ДОД «Центр дополнительного образования детей»	Россия, Вологодская область, Грязовецкий район, Грязовец	0101000020E610000014E7A8A3E3204440DBF97E6ABC704D40
29097	3	27	27	4103	31738	\N	58.875537000000001	Грязовецкий район г.Грязовец, ул. К.Маркса,78 БОУ ДОД "Грязовецкая детская школа искусств"		0101000020E610000077853E58C61E44400FB8AE9811704D40
29095	3	27	27	4103	26704	\N	58.873161108124897	Грязовецкий район г.Грязовец, ул. Горького, д.109  МОУ Средняя общеобразовательная школа № 1	Россия, Вологодская область, Грязовецкий район, Грязовец	0101000020E6100000CE6DC2BD32214440439259BDC36F4D40
29100	3	27	27	4103	26528	\N	58.875537000000001	Грязовецкий район г.Грязовец, ул. Гагарина,46, МОУ "Средняя  общеобразовательная школа №2"		0101000020E610000077853E58C61E44400FB8AE9811704D40
29106	3	27	27	4566	\N	\N	58.768650999999998	Грязовецкий район д.Вохтога, д.76  Вохтожский СДК		0101000020E6100000295AB91798894440D384ED2763624D40
29102	3	27	27	4384	31962	\N	58.818306	Грязовецкий район п.Вохтога, пер.Свободы, д. 3   МОУ Вохтожская средняя общеобразовательная школа № 1	Россия, Вологодская область, Грязовецкий район, поселок Вохтога	0101000020E61000005072874D648644406F0F4240BE684D40
29104	3	27	27	4384	26500	\N	58.818306	Грязовецкий район п.Вохтога, ул.Юбилейная, д.25, школа №2		0101000020E61000005072874D648644406F0F4240BE684D40
29103	3	27	27	4384	26500	\N	58.818306	Грязовецкий район п.Вохтога, ул.Юбилейная, д.23  МУК «Вохтожский ПДК»		0101000020E61000005072874D648644406F0F4240BE684D40
29105	3	27	27	4384	31686	\N	58.818306	Грязовецкий район п.Вохтога, ул.24 партсъезда, д.10  Клуб п.Вохтога		0101000020E61000005072874D648644406F0F4240BE684D40
29109	3	27	27	1508	\N	\N	59.152285999999997	Грязовецкий район п.Вострогский, д.17  МОУ «Каменская общеобразовательная школа»		0101000020E6100000E7C8CA2F83B54440BFD18E1B7E934D40
29119	3	27	27	53260	\N	\N	58.605502999999999	Грязовецкий район д.Вараксино, д.66 Администрация МО Ростиловское		0101000020E6100000FB027AE1CE374440A0504F1F814D4D40
29112	3	27	27	1669	31710	\N	59.019888999999999	Грязовецкий район п.Бушуиха, ул.Центральная, д.9  Ведерковский СДК		0101000020E6100000FB3A70CE883A44406B4606B98B824D40
29056	3	27	27	1669	31710	\N	59.019888999999999	Грязовецкий район п.Бушуиха, ул.Центральная, д.7 Здание бывшей совхозной школы		0101000020E6100000FB3A70CE883A44406B4606B98B824D40
29121	3	27	27	6985	31796	\N	58.798631999999998	Вологодская область, Грязовецкий район, д.Анохино, ул.Центральная, д.42		0101000020E6100000DA1EBDE13E66444000C5C89239664D40
29107	3	27	27	4615	\N	\N	58.836593999999998	Грязовецкий район д.Аксеново, д.30  Аксеновский сельский клуб		0101000020E61000004700378B177D4440D1031F83156B4D40
29082	3	27	547	3963	26696	\N	61.222895000000001	Вытегорский район, п. Янишево, ул.Школьная, дом 5МОУ «Янишевская основная общеобразовательная школа»		0101000020E61000004BAFCDC64AC6424091B8C7D2879C4E40
29055	3	27	547	3554	\N	\N	60.990816000000002	Вологодская область, Вытегорский муниципальный район, муниципальное образование город Вытегра, Шестово, 1		0101000020E61000002828452BF73A4240412D060FD37E4E40
29069	3	27	547	4293	31817	\N	61.111949000000003	Вологодская область, Вытегорский муниципальный район, муниципальное образование Андомское, д. Тудозерский Погост, Молодежная, 4		0101000020E610000044300E2E1D454240F3E84658548E4E40
29070	3	27	547	4320	31749	\N	61.259452000000003	Вологодская область, Вытегорский муниципальный район, муниципальное образование Андомское, д. Сорокополье, Набережная, 1		0101000020E610000073F38DE89E474240DF701FB935A14E40
29073	3	27	547	4483	\N	\N	61.345877999999999	Вологодская область, Вытегорский муниципальный район, муниципальное образование Саминское, д.Саминский Погост, 7		0101000020E6100000BF2CEDD45C4C4240F433F5BA45AC4E40
29092	3	27	547	5511	26454	\N	60.782640000000001	Вологодская область, Вытегорский муниципальный район, муниципальное образование Кемское, д. Прокшино, Архангельская, 8		0101000020E6100000C6A354C213E642404E452A8C2D644E40
29066	3	27	547	4111	31820	\N	61.010463000000001	Вологодская область, Вытегорский муниципальный район, муниципальное образование Казаковское, д. Палтога, Школьная, 11		0101000020E6100000359BC76130134240B66801DA56814E40
29068	3	27	547	4210	31741	\N	60.992645000000003	Вологодская область, Вытегорский муниципальный район, муниципальное образование Казаковское, д. Палозеро, Архангельский тракт, 14		0101000020E61000001557957D572C4240DBC4C9FD0E7F4E40
29090	3	27	547	5391	31720	\N	60.840604999999996	Вологодская область, Вытегорский муниципальный район, муниципальное образование Анненское, п. Павшозеро, Школьная, 13		0101000020E6100000F3AACE6A8189424052EDD3F1986B4E40
29058	3	27	547	3694	31866	\N	60.852496000000002	Вологодская область, Вытегорский муниципальный район, муниципальное образование Оштинское, с. Ошта, Архангельский тракт, 52		0101000020E6100000B9196EC0E7C7414044FCC3961E6D4E40
29074	3	27	547	4574	31669	\N	61.381998000000003	Вологодская область, Вытегорский муниципальный район, муниципальное образование Саминское, п. Октябрьский, Гагарина, 13		0101000020E6100000D787F546AD50424097917A4FE5B04E40
29084	3	27	547	5075	31707	\N	60.752580000000002	Вологодская область, Вытегорский муниципальный район, муниципальное образование Алмозерское, п. Новостройка, Центральная, 3-а		0101000020E6100000AB5FE97C78624240D5CF9B8A54604E40
29059	3	27	547	3777	31703	\N	60.830703999999997	Вологодская область, Вытегорский муниципальный район, муниципальное образование Оштинское, д. Нижняя Водлица, Архангельский тракт, 48		0101000020E6100000BB48A12C7CDF414004543882546A4E40
29085	3	27	547	5143	\N	\N	60.595176000000002	Вологодская область, Вытегорский муниципальный район, муниципальное образование Алмозерское, д. Митино, 25		0101000020E6100000529D0E643D6942409BAE27BA2E4C4E40
29091	3	27	547	5478	31897	\N	60.840713999999998	Вологодская область, Вытегорский муниципальный район, муниципальное образование Кемское, п.Мирный, Калинина, 10		0101000020E6100000C51C041DADD6424009A52F849C6B4E40
29064	3	27	547	4005	26441	\N	60.560195	Вологодская область, Вытегорский муниципальный район, муниципальное образование Коштугское, п. Межозерье, Почтовая, 5		0101000020E610000028D3687231024240FD304278B4474E40
29061	3	27	547	3870	26614	\N	60.867300999999998	Вологодская область, Вытегорский муниципальный район, муниципальное образование Мегорское, с Мегра, Центральная, 14		0101000020E610000003780B2428004240E0641BB8036F4E40
29072	3	27	547	4471	32000	\N	61.164493999999998	Вологодская область, Вытегорский муниципальный район, муниципальное образование Андомское, д.Макачево, Школьная, 12		0101000020E6100000CC7B9C69C25C4240B131AF230E954E40
29063	3	27	547	3957	31856	\N	60.697116000000001	Вологодская область, Вытегорский муниципальный район, муниципальное образование Коштугское, с. Коштуги, Мира, 48		0101000020E61000003046240A2DFF414059C2DA183B594E40
29065	3	27	547	4056	32049	\N	60.929828999999998	Вологодская область, Вытегорский муниципальный район, муниципальное образование Казаковское, д. Кондушский Погост, Центральная, 22		0101000020E610000019028063CF0A4240AAEFFCA204774E40
29080	3	27	547	4895	26610	\N	60.915080000000003	Вологодская область, Вытегорский муниципальный район, муниципальное образование Девятинское, п. Депо, Спортивная, 15		0101000020E61000005AF3E32F2D6C4240A29C685721754E40
29081	3	27	547	4895	26621	\N	60.915080000000003	Вытегорский район, п. Депо, Архангельский тракт, д.7  МОУ «Белоручейская средняя общеобразовательная школа»		0101000020E61000005AF3E32F2D6C4240A29C685721754E40
29079	3	27	547	4837	31827	\N	60.920743000000002	Вологодская область, Вытегорский муниципальный район, муниципальное образование Девятинское, с. Девятины, Архангельский тракт, 118		0101000020E6100000B24AE9995E624240AE8218E8DA754E40
29060	3	27	547	53293	32093	\N	60.704792833963197	Вологодская область, Вытегорский муниципальный район, муниципальное образование Оштинское, п. Горный Ручей, Школьная, 2	Россия, Вологодская область, Вытегорский район, село Горнручей	0101000020E61000007E71A94A5BDC414091B932A8365A4E40
29053	3	27	547	51294	31702	\N	61.011995521510997	Вологодская область, Вытегорский муниципальный район, муниципальное образование город Вытегра, Шевченко, 51	Россия, Вологодская область, Вытегорский район, Вытегра	0101000020E6100000C72B103D2939424067D7BD1589814E40
29051	3	27	547	51294	26578	\N	61.004703889969001	Вологодская область, Вытегорский муниципальный район, муниципальное образование город Вытегра, Проспект Ленина, 52	Россия, Вологодская область, Вытегорский район, Вытегра	0101000020E6100000C095ECD8083A4240871403249A804E40
29052	3	27	547	51294	32077	\N	61.012962513067002	Вологодская область, Вытегорский муниципальный район, муниципальное образование город Вытегра, Луночарского, 35	Россия, Вологодская область, Вытегорский район, Вытегра	0101000020E610000018946934B93842406E8786C5A8814E40
29050	3	27	547	51294	32063	\N	61.008662412684401	Вологодская область, Вытегорский муниципальный район, муниципальное образование город Вытегра, Ленинградский тракт, 12	Россия, Вологодская область, Вытегорский район, Вытегра	0101000020E6100000105A0F5F263A4240E65B1FD61B814E40
29083	3	27	547	51278	26473	\N	60.8546224845906	Вологодская область, Вытегорский муниципальный район, муниципальное образование Алмозерское, п. Волоков Мост, Болотная, 22-а		0101000020E610000032CC09DAE47242409738F240646D4E40
29062	3	27	547	3883	26438	\N	60.894722000000002	Вологодская область, Вытегорский муниципальный район, муниципальное образование Мегорское, д. Верхнее Понизовье, Школьная, 2		0101000020E610000096CFF23CB80542408081204086724E40
29077	3	27	547	53257	\N	\N	61.013497000000001	Вологодская область, Вытегорский муниципальный район, муниципальное образование Анхимовское,д. Боярская, 33	Россия, Вологодская область, Вытегорский район	0101000020E6100000EAB46E83DA6542400CCC0A45BA814E40
29076	3	27	547	4655	31743	\N	60.956187999999997	Вологодская область, Вытегорский муниципальный район, муниципальное образование Анхимовское, п. Белоусово, Школьная, 2-а		0101000020E6100000A73FFB9122464240F0694E5E647A4E40
29075	3	27	547	4617	\N	\N	60.951894000000003	Вологодская область, Вытегорский муниципальный район, муниципальное образование Анхимовское, д.Анхимово, 2-б		0101000020E6100000F661BD512B4242401BA19FA9D7794E40
29087	3	27	547	53281	32058	\N	60.737848567851202	Вологодская область, Вытегорский муниципальный район, муниципальное образование Анненское, с.Анненский Мост, Лесная, 47 Дом культуры	Россия, Вологодская область, Вытегорский район, село Анненский Мост	0101000020E61000008C9FC6BDF98D4240723106D6715E4E40
18051	3	26	\N	1382	58786	\N	64.600374000000002	Архангельская область, город Архангельск, ул. Ильича, д.41		0101000020E6100000560DC2DCEE49444099D711876C265040
29086	3	27	547	53281	32138	\N	60.739529409200998	Вологодская область, Вытегорский муниципальный район, муниципальное образование Анненское, с.Анненский Мост, Проспект Советский, 10	Россия, Вологодская область, Вытегорский район, село Анненский Мост	0101000020E61000008C9FC6BDF98D4240C7B8E2E2A85E4E40
29071	3	27	547	4403	31942	\N	61.249651	Вологодская область, Вытегорский муниципальный район, муниципальное образование Андомское, с.Андомский Погост, Центральная, 44-а		0101000020E6100000E7C3B30419514240F4346090F49F4E40
29088	3	27	547	5284	31892	\N	60.797960000000003	Вологодская область, Вытегорский муниципальный район, муниципальное образование Анненское, с.Александровское, Заречная, 3		0101000020E61000001C7E37DDB28F424012C2A38D23664E40
28920	3	27	587	28957	32010	\N	59.555655000000002	Вологодская область, Вологодский район, д. Шолохово, Школьная, 2		0101000020E610000013EE9579ABB84340F06DFAB31FC74D40
28923	3	27	587	29082	\N	\N	59.157449	Вологодская область, Вологодский район, п. Харачево, 12		0101000020E6100000A1A3552DE9FC4340DAE4F04927944D40
28924	3	27	587	29141	\N	\N	59.325955	Вологодская область, Вологодский район, д. Фофанцево, 24		0101000020E6100000ECA4BE2CEDFE4340DD7BB8E4B8A94D40
28929	3	27	587	29336	\N	\N	59.363565000000001	Вологодская область, Вологодский район, п. Фетинино, 4		0101000020E6100000ED48F59D5FE24340317C444C89AE4D40
28941	3	27	587	29897	\N	\N	59.197679999999998	Вологодская область, Вологодский район, п. Федотово, 38	Россия, Вологодская область, Вологодский район, поселок Федотово	0101000020E61000005534D6FECE944340618907944D994D40
28940	3	27	587	29839	31773	\N	59.140988	Вологодская область, Вологодский район, п. Уткино, Центральная, 19-а		0101000020E61000001FBFB7E9CFB44340719010E50B924D40
28937	3	27	587	29723	26491	\N	59.194758	Вологодская область, Вологодский район, д. Стризнево, Зеленая, 12		0101000020E6100000BB473657CDA54340335184D4ED984D40
28931	3	27	587	61538	79358	\N	59.195230000000002	Вологодская область, Вологодский район, п. Сосновка, Молодежная, 3	Россия, Вологодская область, Вологодский район, село Сосновка	0101000020E61000009128B4ACFBC943405B99F04BFD984D40
28925	3	27	587	29193	\N	\N	59.319389999999999	Вологодская область, Вологодский район, д. Семенково-2, 46		0101000020E6100000041BD7BFEBF54340B05582C5E1A84D40
28927	3	27	587	29269	26650	\N	59.418325000000003	Вологодская область, Вологодский район, п. Семенково, Первомайская, 9		0101000020E6100000B41CE8A1B6AB4340B30C71AC8BB54D40
28893	3	27	587	27721	26448	\N	59.413393999999997	Вологодская область, Вологодский район, с. Северная ферма, Центральная, 1		0101000020E61000006EC2BD326F8943406A2E3718EAB44D40
28919	3	27	587	28895	\N	\N	59.559817000000002	Вологодская область, Вологодский район, д. Севастьяново, 44		0101000020E6100000C3D5011077954340575F5D15A8C74D40
28932	3	27	587	62099	\N	\N	59.380392543945597	"Вологодская область, Вологодский район, п. Новый Источник, здание санатория ""Новый Источник"""	Россия, Вологодская область, Вологодский район, село Помыгалово	0101000020E6100000ACC612D6C6C643404C50C3B7B0B04D40
28933	3	27	587	29549	31834	\N	59.147916000000002	Вологодская область, Вологодский район, с. Погорелово, Центральная, 1		0101000020E61000001B84B9DDCBCB43400F4757E9EE924D40
28936	3	27	587	29665	31896	\N	59.047255	Вологодская область, Вологодский район, п. Перьево, Школьный переулок, 3-б		0101000020E610000025CB49287DE3434047C9AB730C864D40
28907	3	27	587	28367	32005	\N	59.377636000000003	Вологодская область, Вологодский район, с. Остахово, Центральная, 1		0101000020E61000007F6DFDF49FC1434069E55E6056B04D40
28780	3	27	587	22491	\N	\N	59.143918999999997	Вологодская область, Вологодский район, п. Огарково, 35		0101000020E61000000AA2EE0390064440F22213F06B924D40
28905	3	27	587	53259	\N	\N	59.377718999999999	Вологодская область, Вологодский район, д. Новое, 61		0101000020E610000072FBE59315C74340F609A01859B04D40
28916	3	27	587	28758	31853	\N	59.617849999999997	Вологодская область, Вологодский район, с. Новленское, Советская, 24		0101000020E61000005053CBD6FAAA4340B3EA73B515CF4D40
28918	3	27	587	28874	31830	\N	59.765455000000003	Вологодская область, Вологодский район, д. Нефедово, Центральная, 25		0101000020E6100000E92CB308C5884340A4C7EF6DFAE14D40
28934	3	27	587	29587	\N	\N	59.147168999999998	Вологодская область, Вологодский район, п. Непотягово, 50		0101000020E610000000FF942A51E8434015FE0C6FD6924D40
28922	3	27	587	29052	\N	\N	59.098652999999999	Вологодская область, Вологодский район, д. Надеево, 23		0101000020E61000000135B56CADF943407E5358A9A08C4D40
28707	3	27	587	18774	\N	\N	59.463208000000002	Вологодская область, Вологодский район, д. Мынчаково, 122		0101000020E61000006B48DC63E99343406F9F55664ABB4D40
29042	3	27	587	53246	31666	\N	59.297777360722598	Вологодская область, город Вологда, с.Молочное, Парковая, 9а, корпус 1	Россия, Вологодская область, Вологодский район, поселок Молочное	0101000020E6100000731074B4AAD543402140868E1DA64D40
29033	3	27	587	53246	31666	\N	59.292439390733698	Вологодская область, город Вологда, с.Молочное, Парковая, 3	Россия, Вологодская область, Вологодский район, поселок Молочное	0101000020E6100000EA92718C64D74340988922A46EA54D40
29032	3	27	587	53246	32137	\N	59.293222418763001	Вологодская область, город Вологда, с.Молочное, Мира, 8	Россия, Вологодская область, Вологодский район, поселок Молочное	0101000020E6100000B285200725D64340DE3B6A4C88A54D40
29030	3	27	587	53246	31839	\N	59.291246591024098	Вологодская область, город Вологда, с.Молочное, Емельянова, 7	Россия, Вологодская область, Вологодский район, поселок Молочное	0101000020E61000005EF6EB4E77D643407007EA9447A54D40
28935	3	27	587	29610	\N	\N	59.124879999999997	Вологодская область, Вологодский район, п. Можайское, 5 а		0101000020E61000008E942D9276E5434055F65D11FC8F4D40
28906	3	27	587	28298	31959	\N	59.394134000000001	Вологодская область, Вологодский район, с. Макарово, Центральная, 4		0101000020E61000007505DB8827A14340EF1EA0FB72B24D40
28910	3	27	587	3688	\N	\N	59.257313000000003	Вологодская область, Вологодский район, п. Майский, 14, Дом культуры		0101000020E61000004242942F68DF4340F7EAE3A1EFA04D40
28908	3	27	587	28376	\N	\N	59.201025000000001	Вологодская область, Вологодский район, п. Лесково, 39		0101000020E61000005917B7D100D24340D656EC2FBB994D40
28911	3	27	587	28527	31829	\N	59.364486999999997	Вологодская область, Вологодский район, с. Куркино, Школьная, 7		0101000020E61000000186E5CFB7D1434098689082A7AE4D40
28904	3	27	587	28181	26494	\N	59.434277000000002	Вологодская область, Вологодский район, с. Кубенское, Ленина, 50		0101000020E61000008DF0F62004D64340D733846396B74D40
28903	3	27	587	28181	26494	\N	59.434277000000002	Вологодская область, Вологодский район, с. Кубенское, Ленина, 77		0101000020E61000008DF0F62004D64340D733846396B74D40
28938	3	27	587	29742	26658	\N	59.235598000000003	Вологодская область, Вологодский район, п. Кипелово, Железнодорожная, 14		0101000020E61000001E705D312392434063804413289E4D40
28912	3	27	587	28572	32006	\N	59.288215999999998	Вологодская область, Вологодский район, д. Ильинское, Садовая, 16		0101000020E6100000252191B6F1D343408B170B43E4A44D40
28913	3	27	587	28624	\N	\N	59.302202999999999	Вологодская область, Вологодский район, п. Заря, 41		0101000020E6100000C53A55BE67BE434065E08096AEA64D40
28909	3	27	587	28449	31735	\N	59.190567999999999	Вологодская область, Вологодский район, п. Ермаково, Строителей, 17		0101000020E6100000AB59677C5FDA434002D53F8864984D40
28928	3	27	587	29315	31954	\N	59.345166999999996	Вологодская область, Вологодский район, п. Дубровское, Центральная, 8		0101000020E610000029594E42E9E743404754A86E2EAC4D40
28914	3	27	587	53248	\N	\N	59.243865948075999	Вологодская область, Вологодский район, ст. Дикая, 24	Россия, Вологодская область, Вологодский район, поселок Дикая	0101000020E6100000DE54A4C2D8BE43409C4D4700379F4D40
28921	3	27	587	28991	\N	\N	59.117426000000002	Вологодская область, Вологодский район, п. Грибково, 14		0101000020E61000009FB0C403CA0644409DD9AED0078F4D40
28939	3	27	587	29824	\N	\N	59.283946	Вологодская область, Вологодский район, д. Горка, 37		0101000020E6100000016C4084B89643403EEAAF5758A44D40
28915	3	27	587	28711	32007	\N	59.085988	Вологодская область, Вологодский район, п. Васильевское, Торговая площадь, 2		0101000020E6100000E2CCAFE6001544409AEC9FA7018B4D40
28917	3	27	587	28817	\N	\N	59.703167000000001	Вологодская область, Вологодский район, д. Березник, 56		0101000020E6100000F2EA1C03B29943402F50526001DA4D40
28886	3	27	309	53292	32083	\N	60.327931097748099	Вологодская область, Вожегодский район, поселок Яхренга, Октябрьская, 31	Россия, Вологодская область, Вожегодский район, село Яхреньга	0101000020E61000004BC972124A0144401B2C9CA4F9294E40
28896	3	27	309	27853	26627	\N	60.465508	Вологодская область, Вожегодский район, поселок Ючка, Октябрьская, 10		0101000020E6100000BCADF4DA6C604440600322C4953B4E40
28887	3	27	309	27466	\N	\N	60.352196999999997	Вологодская область, Вожегодский район, деревня Сосновица, администрация сельского поселения Митюковское, 109		0101000020E61000000DDE57E5426B4440E95F92CA142D4E40
28880	3	27	309	27108	\N	\N	60.475921	"Вологодская область, Вожегодский район, деревня Савинская, ""Ухтомский сельский Дом культуры"" филиал МБУК ""ВР КДО"", 49"		0101000020E610000083F92B64AEEA4340643DB5FAEA3C4E40
28902	3	27	309	28115	\N	\N	60.601787999999999	Вологодская область, Вожегодский район, село Покровское, администрация сельского поселения Явенгское, 67		0101000020E6100000BE13B35E0C1544400890A163074D4E40
28899	3	27	309	28000	\N	\N	60.596983000000002	Вологодская область, Вожегодский район, деревня Олеховская, кабинет в здании начальной образовательной школы, 14 А		0101000020E610000094C151F2EA4844404DA25EF0694C4E40
28890	3	27	309	27582	26452	\N	60.521134000000004	Вологодская область, Вожегодский район, поселок Озерный, Центральная, 7		0101000020E6100000B6BB07E8BEA84440B66AD784B4424E40
28895	3	27	309	27839	\N	\N	60.564563999999997	Вологодская область, Вожегодский район, деревня Огибалово, администрация сельского поселения Тигинское, 75		0101000020E6100000A8C7B60C38D74340DD3F16A243484E40
28889	3	27	309	27557	\N	\N	60.456099000000002	Вологодская область, Вожегодский район, деревня Мишутинская, администрация сельского поселения Мишутинское, 19		0101000020E61000005E2BA1BB249C4440815EB873613A4E40
28900	3	27	309	28045	\N	\N	60.598657000000003	Вологодская область, Вожегодский район, деревня Михайловская, администрация сельского поселения Явенгское, 1		0101000020E6100000C7D79E5912264440C042E6CAA04C4E40
28897	3	27	309	27911	\N	\N	60.538747999999998	Вологодская область, Вожегодский район, деревня Марьинская, администрация сельского поселения Явенгское, 9		0101000020E61000002A3A92CB7F3244408864C8B1F5444E40
28885	3	27	309	27334	31875	\N	60.317790000000002	Вологодская область, Вожегодский район, поселок Кадниковский, Первомайская, 7		0101000020E61000008FC70C54C6214440787FBC57AD284E40
28891	3	27	309	27648	\N	\N	60.489570000000001	Вологодская область, Вожегодский район, деревня Деревенька, администрация сельского поселения Нижнеслободское, 63		0101000020E6100000B74604E3E07A4440268DD13AAA3E4E40
28892	3	27	309	27706	\N	\N	60.475012	"Вологодская область, Вожегодский район, деревня Гридино, ""Тигинский сельский Дом культуры"" филиал МБУК ""ВР КДО"", 36"		0101000020E61000008FFB56EBC4EF4340919A7631CD3C4E40
28883	3	27	309	27269	\N	\N	60.361151	"Вологодская область, Вожегодский район, село Воскресенское, ""Пунемский сельский Дом культуры"" филиал МБУК ""ВР КДО"", 20"		0101000020E61000008D4468041B99434077F52A323A2E4E40
28877	3	27	309	26984	26443	\N	60.474631000000002	Вологодская область, Вожегодский район, поселок Вожега, Советская, 23		0101000020E6100000AF601BF1641B44407A5567B5C03C4E40
28879	3	27	309	26984	31668	\N	60.4718578929727	Вологодская область, Вожегодский район, поселок Вожега, Свободы, 3	Россия, Вологодская область, Вожегодский район, поселок Вожега	0101000020E61000005B0A48FB1F1C4440902DCBD7653C4E40
28878	3	27	309	26984	31821	\N	60.474631000000002	Вологодская область, Вожегодский район, поселок Вожега, Садовая, 10		0101000020E6100000AF601BF1641B44407A5567B5C03C4E40
28881	3	27	309	27191	\N	\N	60.502935000000001	"Вологодская область, Вожегодский район, деревня Бекетовская, ""Бекетовский сельский Дом культуры"" филиал МБУК ""ВР КДО"", 159"		0101000020E6100000F2785A7EE0B24340C381902C60404E40
28884	3	27	309	27314	32002	\N	60.435820999999997	Вологодская область, Вожегодский район, поселок Бекетово, Школьная, 1		0101000020E6100000486DE2E47ED343407BF486FBC8374E40
28901	3	27	309	28076	31955	\N	60.606226999999997	Вологодская область, Вожегодский район, поселок База, Советская, 60		0101000020E6100000E21DE0490B134440E179A9D8984D4E40
28876	3	27	563	26956	31884	\N	60.370564999999999	Вологодская область, Верховажский муниципальный район,   с. Шелота, ул. Полевая, д. 2		0101000020E61000009C86A8C29FD54440680586AC6E2F4E40
28872	3	27	563	3602	26516	\N	60.502212999999998	Вологодская область, Верховажский муниципальный район, с. Чушевицы, ул. Восточная, д. 14, дом детского творчества		0101000020E6100000B4E386DF4DE144402250FD8348404E40
28858	3	27	563	26109	31988	\N	60.629651000000003	Вологодская область, Верховажский муниципальный район,   п. Феклуха, ул. Школьная, 2		0101000020E6100000B8CCE9B29876454065726A6798504E40
28866	3	27	563	3563	31810	\N	60.709862000000001	Вологодская область, Верховажский муниципальный район, д. Урусовская, ул.новая, 34, ФОК		0101000020E6100000E0DBF4673F4C45402A560DC2DC5A4E40
28852	3	27	563	53264	31778	\N	60.743974267393099	Вологодская область, Верховажский муниципальный район,  п. Теплый Ручей, Новая, д. 15	Россия, Вологодская область, Верховажский район, село Теплый Ручей	0101000020E6100000F7C8E6AA790A454083893F8A3A5F4E40
28867	3	27	563	26518	\N	\N	60.668664	Вологодская область, Верховажский муниципальный район,   д. Средняя, д. 37		0101000020E6100000C6FA062637C444409B012EC896554E40
28853	3	27	563	25920	31867	\N	60.636344000000001	Вологодская область, Верховажский муниципальный район,   д. Сметанино, Советская, д. 37		0101000020E610000089EAAD81ADEA4440BF805EB873514E40
28870	3	27	563	26669	31864	\N	60.493926999999999	Вологодская область, Верховажский муниципальный район,   п. Рогна, ул. Лесная, д. 15		0101000020E61000001A3048FAB44A454042CEFBFF383F4E40
28875	3	27	563	26917	26442	\N	60.488635000000002	Вологодская область, Верховажский муниципальный район,   с. Плосково, ул. Центральная, д. 8		0101000020E61000007FDFBF7971E444402A5778978B3E4E40
28861	3	27	563	26240	26424	\N	60.852851000000001	Вологодская область, Верховажский муниципальный район,   п. Пежма, ул. Центральная, д. 1		0101000020E6100000EB6E9EEA90DD444032AEB8382A6D4E40
28869	3	27	563	26633	\N	\N	60.631146999999999	Вологодская область, Верховажский муниципальный район,   д. Осташевская, д. 17		0101000020E6100000C40AB77C24574540F8FBC56CC9504E40
28857	3	27	563	26098	26418	\N	60.785454999999999	Вологодская область, Верховажский муниципальный район,   д. Ногинская, ул. Центральная, 18		0101000020E6100000A87004A9145B454066BD18CA89644E40
28863	3	27	563	26357	\N	\N	60.755543000000003	Вологодская область, Верховажский муниципальный район,   д. Наумиха, д. 18 А		0101000020E610000097C9703C9F05454062DC0DA2B5604E40
28860	3	27	563	26217	26576	\N	60.793942999999999	Вологодская область, Верховажский муниципальный район,   с. Морозово, ул. Мира, д. 25		0101000020E6100000E46723D74DD74440AEF199EC9F654E40
28854	3	27	563	25977	31989	\N	60.579338999999997	Вологодская область, Верховажский муниципальный район,  п. Макарцево, Центральная, д. 8		0101000020E6100000E31934F44FF444400F26C5C7274A4E40
28859	3	27	563	26179	31809	\N	60.429361	Вологодская область, Верховажский муниципальный район,   д. Леушинская, ул. Центральная, д.26		0101000020E6100000BFB9BF7ADCD94440C4961E4DF5364E40
28871	3	27	563	26743	31719	\N	60.671061999999999	Вологодская область, Верховажский муниципальный район,   д. Куколовская, ул. Куколовская, д. 14		0101000020E61000000DC51D6FF20745404FCB0F5CE5554E40
28856	3	27	563	26040	31871	\N	60.815022999999997	Вологодская область, Верховажский муниципальный район,   д. Климушино, Стебенева, д. 15		0101000020E6100000A4A7C821E20C4540703E75AC52684E40
28874	3	27	563	26847	31940	\N	60.463214999999998	Вологодская область, Верховажский муниципальный район,   п. Каменка, пер. Школьный, д. 7		0101000020E6100000B16B7BBB25E3444021020EA14A3B4E40
28868	3	27	563	26583	\N	\N	60.566372999999999	Вологодская область, Верховажский муниципальный район,   д. Елисеевская, д. 29		0101000020E61000006F8104C58F4F4540302B14E97E484E40
28873	3	27	563	26827	\N	\N	60.503293999999997	Вологодская область, Верховажский муниципальный район,  д. Владыкина Гора, д. 7		0101000020E61000008351499D80F24440F22213F06B404E40
28851	3	27	563	25718	31748	\N	60.741588	Вологодская область, Верховажский муниципальный район,  с. Верховажье, пер. Лесной, д. 5		0101000020E6100000BA69334E43044540938D075BEC5E4E40
28849	3	27	563	25718	31684	\N	60.7443805378104	Вологодская область, Верховажский муниципальный район, с. Верховажье, Стебенева, д. 41	Россия, Вологодская область, Верховажский район, село Верховажье	0101000020E610000015713AC956054540C36169E0475F4E40
28850	3	27	563	25718	31746	\N	60.741588	Вологодская область, Верховажский муниципальный район,  с. Верховажье, Пионерская, 27А		0101000020E6100000BA69334E43044540938D075BEC5E4E40
28855	3	27	563	25995	31870	\N	60.430230999999999	Вологодская область, Верховажский муниципальный район,   д. Великодворская, Центральная, д. 3		0101000020E6100000404B57B08D164540D95C35CF11374E40
28865	3	27	563	3507	\N	\N	60.711855999999997	Вологодская область, Верховажский муниципальный район, д. Большое Ефимово, д. 13, дом культуры		0101000020E61000004F029B73F0F844400EBBEF181E5B4E40
28864	3	27	563	26387	\N	\N	60.727139000000001	Вологодская область, Верховажский муниципальный район,   д. Безымянная, д. 11		0101000020E6100000FAB836548C274540B55208E4125D4E40
28862	3	27	563	26286	\N	\N	60.743043999999998	Вологодская область, Верховажский муниципальный район,   д. Артемьевская, д. 53		0101000020E61000003D98141F9FCE444098BED7101C5F4E40
28822	3	27	1717	53273	\N	\N	60.954633000000001	Вологодская область, Великоустюгский район, город Красавино, дер.Бухинино, дом-интернат		0101000020E61000008D4468041B3D47405857056A317A4E40
28847	3	27	1717	25644	\N	\N	60.783434999999997	Вологодская область, Великоустюгский район, дер.Юдино, д.10		0101000020E61000009FAEEE586C2B474058C51B9947644E40
28842	3	27	1717	25383	31979	\N	60.648338000000003	Вологодская область, Великоустюгский район, дер.Щекино, ул.Центральная, д.19		0101000020E610000081B053AC1A1A4740856055BDFC524E40
28831	3	27	1717	24893	\N	\N	60.640107999999998	Вологодская область, Великоустюгский район, дер.Чучеры, д.22		0101000020E6100000569A94826E4F474038F4160FEF514E40
28829	3	27	1717	24816	\N	\N	60.501007999999999	Вологодская область, Великоустюгский район, дер.Чернево, д.85		0101000020E61000009696917A4F5147406684B70721404E40
28843	3	27	1717	25407	31918	\N	60.465091000000001	Вологодская область, Великоустюгский район, с.Усть-Алексеево, ул.Школьная, д.1		0101000020E6100000CB13083BC53E4740FC54151A883B4E40
28840	3	27	1717	25265	31745	\N	60.458489999999998	Вологодская область, Великоустюгский район, дер.Теплогорье, ул.Проезжая, д.11		0101000020E61000007FBF982D5957474082C5E1CCAF3A4E40
28838	3	27	1717	25184	31760	\N	60.817655000000002	Вологодская область, Великоустюгский район, пос.Сусоловка, пер.Советский, д.5		0101000020E61000005A84622B68864740983446EBA8684E40
28846	3	27	1717	25561	\N	\N	60.795873999999998	Вологодская область, Великоустюгский район, дер.Стрига, д.6А		0101000020E61000002B323A20092B47404CDE0033DF654E40
28839	3	27	1717	25254	31921	\N	60.777351000000003	Вологодская область, Великоустюгский район, пос.Северный, ул.Колотова, д.4А		0101000020E6100000B9C7D2872E7A4740A741D13C80634E40
28828	3	27	1717	24751	26558	\N	60.593204999999998	Вологодская область, Великоустюгский район, пос.Полдарса, ул.Гагарина, д.1А		0101000020E6100000D23AAA9A20B246406E693524EE4B4E40
28836	3	27	1717	25109	\N	\N	60.721608000000003	Вологодская область, Великоустюгский район, дер.Подсосенье, д.13		0101000020E610000049861C5BCF1647401844A4A65D5C4E40
28820	3	27	1717	61559	79386	\N	60.868395	Вологодская область, Великоустюгский район, д.Полутово, ул.Рабочая, д.7А		0101000020E61000005E6919A9F736474045813E91276F4E40
28818	3	27	1717	24248	31909	\N	60.609808000000001	Вологодская область, Великоустюгский район, дер.Первомайское, ул.Полевая, д.15		0101000020E61000009692E524946E47406A6B44300E4E4E40
28827	3	27	1717	24688	31857	\N	60.558239999999998	Вологодская область, Великоустюгский район, дер.Пеганово, ул.Центральная, д.53		0101000020E6100000DCA16131EA1A4740D6A8876874474E40
28835	3	27	1717	25023	31807	\N	60.747815000000003	Вологодская область, Великоустюгский район, пос.Новатор, ул.Советская, д.36	Россия, Вологодская область, Великоустюгский район, поселок Новатор	0101000020E61000000F290648341B4740A83AE466B85F4E40
28834	3	27	1717	25023	31807	\N	60.747815000000003	Вологодская область, Великоустюгский район, пос.Новатор, ул.Советская, д.1	Россия, Вологодская область, Великоустюгский район, поселок Новатор	0101000020E61000000F290648341B4740A83AE466B85F4E40
28817	3	27	1717	24187	\N	\N	60.334820000000001	Вологодская область, Великоустюгский район, дер.Мякинницыно, д.9		0101000020E610000080828B1535524740FB05BB61DB2A4E40
28841	3	27	1717	25346	31682	\N	60.713827999999999	Вологодская область, Великоустюгский район, дер.Морозовица, ул.Центральная, д.27		0101000020E61000001AF9BCE2A92547400B7C45B75E5B4E40
28823	3	27	1717	24505	32043	\N	61.130121000000003	Вологодская область, Великоустюгский район, пос.Ломоватка, ул.Железнодорожная, д.27		0101000020E6100000556CCCEB88C34640ECC20FCEA7904E40
28826	3	27	1717	24660	\N	\N	60.696468000000003	Вологодская область, Великоустюгский район, дер.Лодейка, д.18		0101000020E610000088A06AF46AE04640F35A09DD25594E40
28812	3	27	1717	23929	31973	\N	60.734335999999999	Вологодская область, Великоустюгский район, поселок Кузино, ул.Лермонтова, д.10		0101000020E61000001EC022BF7E3047404223D8B8FE5D4E40
28813	3	27	1717	23999	31739	\N	60.954633000000001	Вологодская область, Великоустюгский район, город Красавино, ул.Текстильщиков, д.10		0101000020E61000008D4468041B3D47405857056A317A4E40
28814	3	27	1717	23999	26727	\N	60.954633000000001	Вологодская область, Великоустюгский район, город Красавино, Советский пр-кт, д.152		0101000020E61000008D4468041B3D47405857056A317A4E40
28816	3	27	1717	23999	31958	\N	60.954633000000001	Вологодская область, Великоустюгский район, город Красавино, ул.Революции, д.18		0101000020E61000008D4468041B3D47405857056A317A4E40
28815	3	27	1717	23999	26542	\N	60.954633000000001	Вологодская область, Великоустюгский район, город Красавино, ул.Культуры, д.3		0101000020E61000008D4468041B3D47405857056A317A4E40
28830	3	27	1717	24829	\N	\N	60.669747999999998	Вологодская область, Великоустюгский район, дер.Карасово, д.5		0101000020E6100000A48CB800342A4740DC476E4DBA554E40
28825	3	27	1717	24593	\N	\N	60.772976	Вологодская область, Великоустюгский район, дер.Ишутино, д.24		0101000020E61000002AA73D25E71C4740E44BA8E0F0624E40
28832	3	27	1717	24916	\N	\N	60.601674000000003	Вологодская область, Великоустюгский район, с.Ильинское, д.1		0101000020E6100000DA58897956604740406D54A7034D4E40
28833	3	27	1717	53275	\N	\N	60.718876000000002	Вологодская область, Великоустюгский район, дер.Измарухово, д.31		0101000020E6100000EA3E00A94D0E47408DF0F620045C4E40
28845	3	27	1717	25541	\N	\N	60.796866999999999	Вологодская область, Великоустюгский район, дер.Золотавцево, д.13А		0101000020E610000061DEE34C132047407D21E4BCFF654E40
28819	3	27	1717	24301	\N	\N	60.396329999999999	Вологодская область, Великоустюгский район, с.Верхняя Шарденьга, д.73		0101000020E6100000A5F44C2F312847403B3602F1BA324E40
28837	3	27	1717	25134	\N	\N	60.593228000000003	Вологодская область, Великоустюгский район, дер.Верхнее Анисимово, д.1		0101000020E61000000C923EADA2CB4640278925E5EE4B4E40
12875	7	66	215	17946	62613	\N	55.271507999999997	д.Починок Инели, Комсомольская, 49		0101000020E61000009758198D7CD647401A4D2EC6C0A24B40
28809	3	27	1717	23172	26537	\N	60.743768381263202	Вологодская область, Великоустюгский район, город Великий Устюг, Советский пр-кт, д.200	Россия, Вологодская область, Великоустюгский район, Великий Устюг	0101000020E6100000280B5F5FEB2A4740DAE731CA335F4E40
28808	3	27	1717	23172	26537	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, Советский пр-кт, д.221		0101000020E61000009886E12362264740933A014D84614E40
28803	3	27	1717	23172	26537	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, Советский пр-кт, д.87		0101000020E61000009886E12362264740933A014D84614E40
28806	3	27	1717	23172	32036	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, пл.Коммуны, д.14		0101000020E61000009886E12362264740933A014D84614E40
28801	3	27	1717	23172	31969	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, ул.П.Покровского, д.2А		0101000020E61000009886E12362264740933A014D84614E40
28802	3	27	1717	23172	31994	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, ул.Набережная, д.47		0101000020E61000009886E12362264740933A014D84614E40
28796	3	27	1717	23172	31863	\N	60.774177569487399	Вологодская область, Великоустюгский район, город Великий Устюг, ул.Московская, д.7	Россия, Вологодская область, Великоустюгский район, Великий Устюг	0101000020E61000003F00A94D9C2447402FA4C34318634E40
28798	3	27	1717	23172	26534	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, ул.Кузнецова, д.2		0101000020E61000009886E12362264740933A014D84614E40
28797	3	27	1717	23172	26534	\N	60.7719790834755	Вологодская область, Великоустюгский район, город Великий Устюг, ул.Кузнецова, д.22	Россия, Вологодская область, Великоустюгский район, Великий Устюг	0101000020E61000005589B2B79427474072193735D0624E40
28807	3	27	1717	23172	26720	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, ул.Кооперативная, д.7		0101000020E61000009886E12362264740933A014D84614E40
28804	3	27	1717	23172	31971	\N	60.760916147680803	Вологодская область, Великоустюгский район, город Великий Устюг, ул.Дежнёва, д.4	Россия, Вологодская область, Великоустюгский район, Великий Устюг	0101000020E610000052F2EA1C0328474067800BB265614E40
28795	3	27	1717	23172	31966	\N	60.772718925009798	Вологодская область, Великоустюгский район, город Великий Устюг, ул.Гледенская, д.18	Россия, Вологодская область, Великоустюгский район, Великий Устюг	0101000020E6100000A587A1D5C9214740B9FFC874E8624E40
28810	3	27	1717	23172	31800	\N	60.7547112509573	Вологодская область, Великоустюгский район, город Великий Устюг, Дымково, ул.Вторая, д.5		0101000020E610000034BF9A03042547403A77BB5E9A604E40
28805	3	27	1717	23172	26715	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, ул.А.Угловского, д.14		0101000020E61000009886E12362264740933A014D84614E40
28800	3	27	1717	23172	31732	\N	60.761850000000003	Вологодская область, Великоустюгский район, город Великий Устюг, ул.2-я Пролетарская, д.8		0101000020E61000009886E12362264740933A014D84614E40
28799	3	27	1717	23172	31732	\N	60.771060816613598	Вологодская область, Великоустюгский район, город Великий Устюг, ул.2-я Пролетарская, д.36	Россия, Вологодская область, Великоустюгский район, Великий Устюг	0101000020E6100000CA87A06AF42647404C1C7920B2624E40
28821	3	27	1717	24404	31803	\N	60.927005000000001	Вологодская область, Великоустюгский район, с.Васильевское, ул.Парковая, д.33		0101000020E6100000B0C7444AB33B47403F1D8F19A8764E40
28848	3	27	1717	25682	\N	\N	60.821536999999999	Вологодская область, Великоустюгский район, дер.Бобровниково, д.45		0101000020E6100000454948A46D3647401BBAD91F28694E40
28824	3	27	1717	24555	31855	\N	60.728864000000002	Вологодская область, Великоустюгский район, дер.Благовещенье, ул.Школьная, д.9		0101000020E61000009CFC169D2C0D4740AA9D616A4B5D4E40
28844	3	27	1717	25477	31683	\N	60.764820999999998	Вологодская область, Великоустюгский район, дер.Аристово, ул.П.Виноградова, д.8		0101000020E61000008F1A13622E334740A2258FA7E5614E40
28785	3	27	1690	22721	31916	\N	60.330874000000001	Вологодская область, Вашкинский муниципальный район, с.Троицкое, Мира, 2		0101000020E6100000E622BE13B3DA4240618C48145A2A4E40
28792	3	27	1690	23028	26450	\N	60.437894	Вологодская область, Вашкинский муниципальный район, д.Покровское, Набережная Кемы, 9		0101000020E6100000A5C0029832A64240AC8E1CE90C384E40
28782	3	27	1690	22575	\N	\N	60.283279999999998	Вологодская область, Вашукинский муниципальный район, д.Пиньшино, 18		0101000020E6100000672C9ACE4E24434031CEDF8442244E40
28791	3	27	1690	22986	31904	\N	60.459347000000001	Вологодская область,Вашкинский муниципальный район, д.Пиксимово, Молодежная, 12		0101000020E6100000CBD58F4DF2D342400342EBE1CB3A4E40
28779	3	27	1690	22440	26524	\N	60.459142999999997	Вологодская область, Вашкинский муниципальный район, п.Первомайский, Гагарина, 32А		0101000020E61000002AFEEF880AFB4240FA97A432C53A4E40
28794	3	27	1690	23110	\N	\N	60.413229000000001	Вологодская область, Вашкинский муниципальный район, д.Парфеново, 5		0101000020E6100000CE8DE9094B184340206118B0E4344E40
28790	3	27	1690	53294	32098	\N	60.5544533752484	Вологодская область,Вашкинский муниципальный район, д.Остров, Центральная, 7	Россия, Вологодская область, Вашкинский район, село Остров	0101000020E61000009413ED2AA4F04240A515DF50F8464E40
28784	3	27	1690	22664	31785	\N	60.642574000000003	Вологодская область, Вашкинский муниципальный район, п.Октябрьский, Лесная, 1		0101000020E6100000A79196CADB11434045A165DD3F524E40
28786	3	27	1690	22762	32030	\N	60.353175999999998	Вологодская область, Вашкинский муниципальный район, п.Новокемский, Чумакова, 2		0101000020E610000068E7340BB49F4240B5DD04DF342D4E40
18745	3	26	\N	9494	58666	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Кирилкина, д.3А		0101000020E6100000A795422097EA4340CBF6216FB9245040
28787	3	27	1690	53280	32117	\N	60.265137648149	Вологодская область, Вашкинский муниципальный район,с.Липин Бор, Первомайская,3	Россия, Вологодская область, Вашкинский район, село Липин Бор	0101000020E6100000B6D617096DFB4240A376BF0AF0214E40
28783	3	27	1690	22648	31786	\N	60.654516999999998	Вологодская область, Вашкинский муниципальный район, д.Ивановская, Советская, 1		0101000020E6100000B98C9B1A68FE424088D68A36C7534E40
28789	3	27	1690	22890	32035	\N	60.273077999999998	Вологодская область, Вашкинский муниципальный район, п.Заречный, Механизаторов, 2		0101000020E610000002D8800871FF4240E8A04B38F4224E40
28781	3	27	1690	22525	31902	\N	60.276473000000003	Вологодская область, Вашкинский муниципальный район, д. Васильевская, Центральная, 16		0101000020E610000056478E74060243400F9D9E7763234E40
28793	3	27	1690	23056	26711	\N	60.508946999999999	Вологодская область, Вашкинский муниципальный район, п.Бонга, Юбилейная, 15		0101000020E6100000A7CD380D51C74240DB32E02C25414E40
28778	3	27	1690	22385	31727	\N	60.487606999999997	Вологодская область, Вашкинский муниципальный район, д. Андреевская, Центральная, 16		0101000020E6100000307F85CC95F542407C26FBE7693E4E40
28765	3	27	540	21817	\N	\N	60.059930000000001	Вологодская область, Белозерский район, деревня Панинская, дом 34		0101000020E6100000A48B4D2B857242404F0647C9AB074E40
28772	3	27	540	22139	26692	\N	59.824344000000004	Вологодская область, Белозерский район, деревня Никоновская, Школьный переулок, дом 7	Россия, Вологодская область, Белозерский район, село Никоновская	0101000020E61000006F1283C0CAE54240B153AC1A84E94D40
28777	3	27	540	22359	32023	\N	60.033474845787701	Вологодская область, Белозерский район, поселок Нижняя Мондома, улица Советская, дом 22	Россия, Вологодская область, Белозерский район, село Нижняя Мондома	0101000020E6100000BE30992A18C14240E71DA7E848044E40
28771	3	27	540	22081	26690	\N	60.182671999999997	Вологодская область, Белозерский район, поселок Мегринский, улица Центральная, дом154		0101000020E6100000D68EE21C759042408CF2CCCB61174E40
28757	3	27	540	21417	31927	\N	60.031745999999998	Вологодская область, Белозерский район, село Маэкса, улица Труда, дом 4		0101000020E61000006FD8B628B3DB4240B0E3BF4010044E40
28774	3	27	540	22217	31901	\N	59.862107999999999	Вологодская область, Белозерский район, поселок Лаврово, улица Сельсоветская, дом 15		0101000020E610000060E63BF889AF42405BCF108E59EE4D40
28776	3	27	540	22308	32024	\N	60.019021774611097	Вологодская область, Белозерский район, село Куность, улица Центральная, дом 36	Россия, Вологодская область, Белозерский район, село Куность	0101000020E6100000EB8EC536A9D04240C7F319506F024E40
28773	3	27	540	22186	\N	\N	59.904541000000002	Вологодская область, Белозерский район, деревня Кукшево, дом 9		0101000020E6100000E4F38AA71EF942401172DEFFC7F34D40
28768	3	27	540	21956	26594	\N	59.903156000000003	Вологодская область, Белозерский район, деревня Климшин Бор, улица Центральная, дом 1		0101000020E6100000BF654E97C57E4240D597A59D9AF34D40
28764	3	27	540	21726	\N	\N	59.954492999999999	Вологодская область, Белозерский район, деревня Карл-Либкнехт, дом 1		0101000020E61000002AAA7EA5F399424066A19DD32CFA4D40
28755	3	27	540	21259	32018	\N	60.319215999999997	Вологодская область, Белозерский район, село Зубово, улица Спортивная, дом 1		0101000020E6100000D7A6B1BD167E4240122EE411DC284E40
28754	3	27	540	21259	31779	\N	60.320748492332299	Вологодская область, Белозерский район, село Зубово, улица Набережная, дом 23	Россия, Вологодская область, Белозерский район, село Зубово	0101000020E6100000643A747ADE7D4240F3203D450E294E40
28770	3	27	540	22043	31928	\N	60.028528000000001	Вологодская область, Белозерский район, деревня Глушково, улица Молодежная, дом 35		0101000020E61000002907B30930F64240998235CEA6034E40
28769	3	27	540	3362	31814	\N	59.720512999999997	Вологодская область, Белозерский район, село Георгиевское, улица Центральная, дом 10		0101000020E6100000A9BD88B663704240E2AB1DC539DC4D40
28767	3	27	540	3273	26667	\N	59.8977	Вологодская область, Белозерский район, поселок Визьма, улица Центральная, дом 46-а, дом культуры		0101000020E6100000F4FA93F8DC89424042CF66D5E7F24D40
28766	3	27	540	21828	31929	\N	59.734779000000003	Вологодская область, Белозерский район, село Бечевинка, улица Молодежная, дом 1		0101000020E6100000F25D4A5D32D64240D064FF3C0DDE4D40
28775	3	27	540	22286	26427	\N	59.750942999999999	Вологодская область, Белозерский район, поселок  Белый Ручей, улица Центральная, дом 31-а		0101000020E61000000C0742B280B742407F1475E61EE04D40
28756	3	27	540	21350	31899	\N	60.028694000000002	Вологодская область, Белозерский район, город Белозерск, улица Энгельса, дом 12		0101000020E61000003BC780ECF5E44240B4CBB73EAC034E40
28758	3	27	540	21350	31781	\N	60.028694000000002	Вологодская область, Белозерский район, город Белозерск, улица Фрунзе, дом 35		0101000020E61000003BC780ECF5E44240B4CBB73EAC034E40
28761	3	27	540	21350	31992	\N	60.028694000000002	Вологодская область, Белозерский район, город Белозерск, Советский проспект, дом 52		0101000020E61000003BC780ECF5E44240B4CBB73EAC034E40
28759	3	27	540	21350	31987	\N	60.028694000000002	Вологодская область, Белозерский район, город Белозерск, улица С.Дмитриева, дом 8		0101000020E61000003BC780ECF5E44240B4CBB73EAC034E40
28760	3	27	540	21350	31846	\N	60.029360184778	Вологодская область, Белозерский район, город Белозерск, улица Карла Маркса, дом 35-а	Россия, Вологодская область, Белозерский район, Белозерск	0101000020E610000035D252793BE64240C0E78711C2034E40
28763	3	27	540	21706	\N	\N	60.001342999999999	Вологодская область, Белозерский район, село  Артюшино, дом 20		0101000020E610000095F430B43AAB42400D8AE6012C004E40
28762	3	27	540	21643	\N	\N	59.902903000000002	Вологодская область, Белозерский район, село  Антушево, дом 102		0101000020E61000008EEA7420EBD54240EB3A545392F34D40
18092	3	26	\N	1382	58777	\N	64.513864999999996	Архангельская область, город Архангельск, ул. Калинина, д.21		0101000020E61000000D6FD6E07D534440C763062AE3205040
28730	3	27	519	19940	32009	\N	59.782193999999997	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Бабушкинское, п. Юрманга, 26		0101000020E6100000778368AD688F45404F90D8EE1EE44D40
28753	3	27	519	21249	\N	\N	59.486156999999999	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Юркинское, д. Юркино, 48		0101000020E61000005B5F24B4E5CA454059DC7F643ABE4D40
28741	3	27	519	20639	\N	\N	59.673619000000002	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Миньковское, п. Тиноватка, 21		0101000020E6100000519FE40E9BB245406C7BBB2539D64D40
28750	3	27	519	21100	\N	\N	59.938490999999999	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Тимановское, д. Тиманова Гора, 4		0101000020E610000030630AD638D94540904B1C7920F84D40
28745	3	27	519	20840	\N	\N	59.857979	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Подболотное, д. Скоково, 1		0101000020E61000000ED940BAD8424640D0D38041D2ED4D40
28749	3	27	519	21031	31722	\N	59.765501	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Рослятинское, с. Рослятино, Советская, 17		0101000020E61000001C615111A71D46401407D0EFFBE14D40
28744	3	27	519	20761	\N	\N	59.871169999999999	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Подболотное, д.Подболотье, 77		0101000020E610000042942F6821494640CFA0A17F82EF4D40
28740	3	27	519	61542	79365	\N	59.701155999999997	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Миньковское, Советская, 61	Россия, Вологодская область, Бабушкинский район, село Миньково	0101000020E61000006F63B323D5BD454074B2D47ABFD94D40
28736	3	27	519	20326	\N	\N	59.993729999999999	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Логдузское, д. Логдуз, 22		0101000020E61000005358A9A0A25C4640EC866D8B32FF4D40
28751	3	27	519	3225	\N	\N	59.269799999999996	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Юркинское, п. Кунож, 115		0101000020E61000008483BD8921DF4540FB3A70CE88A24D40
28739	3	27	519	20512	\N	\N	59.729095999999998	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Миньковское, д. Кулибарово, 5		0101000020E6100000008E3D7B2ECF45407CD2890453DD4D40
28748	3	27	519	21000	32013	\N	59.755054999999999	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Рослятинское, п. Красота, Школьная, 3		0101000020E61000004C6DA983BC16464034D769A4A5E04D40
28733	3	27	519	20130	\N	\N	59.868180000000002	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Демьяновское, д. Косиково, 13		0101000020E61000007E3B8908FFB445404985B18520EF4D40
28738	3	27	519	20435	\N	\N	59.812336999999999	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Миньковское, п. Комсомольский, 23		0101000020E61000008BDEA9807BBE4540562AA8A8FAE74D40
28743	3	27	519	20741	\N	\N	59.855200000000004	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Подболотное, д. Кокшарка, 1		0101000020E6100000AC74779D0D45464005C58F3177ED4D40
28735	3	27	519	20245	\N	\N	59.87509	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Логдузское, д. Козлец, 6		0101000020E61000007099D365315D46404087F9F202F04D40
28729	3	27	519	19858	26642	\N	59.757294000000002	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Бабушкинское, с.им. Бабушкина, Бабушкина, 65		0101000020E610000072FBE5931591454080BA8102EFE04D40
28728	3	27	519	19858	26642	\N	59.757294000000002	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Бабушкинское, с.им.Бабушкина, Бабушкина, 63		0101000020E610000072FBE5931591454080BA8102EFE04D40
28734	3	27	519	20211	31893	\N	59.336081	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Идское, п. Ида, Гагарина, 17		0101000020E610000009FCE1E7BF9345404BE7C3B304AB4D40
28747	3	27	519	20939	26487	\N	59.597836999999998	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Рослятинское, п. Зайчики, Школьная, 15А		0101000020E6100000F9669B1BD30F46405CAB3DEC85CC4D40
28746	3	27	519	20862	\N	\N	59.779508	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Рослятинское, д. Жубрино, 6А		0101000020E61000000454388254284640357C0BEBC6E34D40
28732	3	27	519	3168	\N	\N	59.911952999999997	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Демьяновское, д. Демьяновский Погост, 15		0101000020E6100000D3872EA86FB745409A3E3BE0BAF44D40
28731	3	27	519	20017	31714	\N	59.470897999999998	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Березниковское, с. Воскресенское, Центральная, 26		0101000020E6100000A94E07B29EFC45403BE0BA6246BC4D40
28742	3	27	519	20653	\N	\N	59.876444999999997	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Подболотное, д. Безгачиха, 7		0101000020E6100000E7012CF2EB43464011DF89592FF04D40
28752	3	27	519	21179	\N	\N	59.387604000000003	Вологодская область, Бабушкинский муниципальный район, муниципальное образование Юркинское, п. Аниково, 10		0101000020E6100000CC7EDDE9CEDF45403FE603029DB14D40
28726	3	27	311	19760	26636	\N	59.498227	Вологодская область, Бабаевский муниципальный район, деревня Торопово, Западная, 1		0101000020E6100000A2D11DC4CED44140FA7DFFE6C5BF4D40
28710	3	27	311	18901	31770	\N	59.382105000000003	Вологодская область, Бабаевский муниципальный район, поселок Тимошкино, Школьная, 3	Россия, Вологодская область, Бабаевский район, поселок Тимошкино	0101000020E6100000014C1938A0134240AD510FD1E8B04D40
28723	3	27	311	19612	31946	\N	60.108477000000001	Вологодская область, Бабаевский муниципальный район, деревня Тимошино, Солнечная, 1		0101000020E61000000E15E3FC4D18424021AF0793E20D4E40
28725	3	27	311	19683	31713	\N	59.490099999999998	Вологодская область, Бабаевский муниципальный район, поселок Смородинка, Набережная, 14		0101000020E610000079043752B6D4414082E2C798BBBE4D40
28721	3	27	311	19501	\N	\N	59.606332999999999	Вологодская область, Бабаевский муниципальный район, деревня Санинская, 30		0101000020E610000010E9B7AF0307424027BEDA519CCD4D40
28720	3	27	311	19441	26464	\N	60.147885000000002	Вологодская область, Бабаевский муниципальный район, поселок Пяжелка, Центральная, 1		0101000020E6100000F92EA52E19E14140D4484BE5ED124E40
28717	3	27	311	19267	32040	\N	59.955542999999999	Вологодская область, Бабаевский муниципальный район, деревня Пожара, Школьная, 2		0101000020E610000027A3CA30EE0C4240FB75A73B4FFA4D40
28716	3	27	311	19252	\N	\N	59.785612999999998	Вологодская область, Бабаевский муниципальный район, поселок Плесо, 9		0101000020E61000008F56B5A4A3DC4140FE277FF78EE44D40
28714	3	27	311	19108	\N	\N	59.884984000000003	Вологодская область, Бабаевский муниципальный район, деревня Новое Лукино, 13		0101000020E61000002313F06B24114240DCBDDC2747F14D40
28715	3	27	311	19178	\N	\N	59.992370999999999	Вологодская область, Бабаевский муниципальный район, деревня Новая Старина, 62		0101000020E610000023F59ECA69FD4140D93F4F0306FF4D40
28704	3	27	311	18609	\N	\N	59.801146000000003	Вологодская область, Бабаевский муниципальный район, деревня Малое Борисово, 10		0101000020E6100000CF4D9B711A0842401EA9BEF38BE64D40
28718	3	27	311	19346	\N	\N	60.168602	Вологодская область, Бабаевский муниципальный район, поселок Колошма, 61		0101000020E61000001901158E20B54140250516C094154E40
28727	3	27	311	19091	\N	\N	60.044271000000002	Вологодская область, Бабаевский муниципальный район, деревня Киино, 64		0101000020E61000001FA2D11DC4E04140A39410ACAA054E40
28713	3	27	311	19091	\N	\N	60.044271000000002	Вологодская область, Бабаевский муниципальный район, деревня Кийно, 48		0101000020E61000001FA2D11DC4E04140A39410ACAA054E40
28722	3	27	311	19529	\N	\N	59.283141999999998	Вологодская область, Бабаевский муниципальный район, деревня Заполье, 48		0101000020E6100000030AF5F411384240E00F3FFF3DA44D40
28711	3	27	311	18982	\N	\N	59.209392000000001	Вологодская область, Бабаевский муниципальный район, деревня Дубровка, 16		0101000020E6100000C2D9AD65321C4240A305685BCD9A4D40
28719	3	27	311	19370	\N	\N	60.248372000000003	Вологодская область, Бабаевский муниципальный район, деревня Григорьевская, 2		0101000020E61000007636E49F19D64140FE9E58A7CA1F4E40
28712	3	27	311	19005	\N	\N	60.096420999999999	Вологодская область, Бабаевский муниципальный район, деревня Горка, 65		0101000020E6100000BFF1B56796284240E5D2F885570C4E40
28709	3	27	311	18887	31712	\N	59.406185999999998	Вологодская область, Бабаевский муниципальный район, деревня Володино, Набережная, 7-А		0101000020E6100000E1455F419AE94140E90B21E7FDB34D40
28705	3	27	311	18649	31991	\N	59.897148999999999	Вологодская область, Бабаевский муниципальный район, село Борисово-Судское, Комсомольская, 2		0101000020E610000029B4ACFBC7004240CE5147C7D5F24D40
28696	3	27	311	18166	31886	\N	59.396777	Вологодская область, Бабаевский муниципальный район,  город Бабаево, Ухтомского, 18		0101000020E6100000CE70033E3FF841400A67B796C9B24D40
28697	3	27	311	18166	31755	\N	59.396777	Вологодская область, Бабаевский муниципальный район,  город Бабаево, Советская, 31		0101000020E6100000CE70033E3FF841400A67B796C9B24D40
28701	3	27	311	18166	31880	\N	59.396777	Вологодская область, Бабаевский муниципальный район,  город Бабаево, Садовая, 14		0101000020E6100000CE70033E3FF841400A67B796C9B24D40
28698	3	27	311	18166	31826	\N	59.396777	Вологодская область, Бабаевский муниципальный район,  город Бабаево, Производственный переулок, 7		0101000020E6100000CE70033E3FF841400A67B796C9B24D40
28702	3	27	311	18166	31944	\N	59.391865496896301	Вологодская область, Бабаевский муниципальный район,  город Бабаево, Интернациональная, 42	Россия, Вологодская область, Бабаевский район, Бабаево	0101000020E6100000BB9866BAD7F9414039B9DFA128B24D40
28700	3	27	311	18166	26618	\N	59.396777	Вологодская область, Бабаевский муниципальный район,  город Бабаево, Гайдара, 9		0101000020E6100000CE70033E3FF841400A67B796C9B24D40
28699	3	27	311	18166	26618	\N	59.390519289826898	Вологодская область, Бабаевский муниципальный район, город  Бабаево, Гайдара, 9	Россия, Вологодская область, Бабаевский район, Бабаево	0101000020E6100000F226BF4527F94140BABBCE86FCB14D40
28708	3	27	311	18792	\N	\N	59.924596000000001	Вологодская область, Бабаевский муниципальный район, деревня Александровская, 8		0101000020E61000002A37514B730142409701672959F64D40
28706	3	27	311	18707	\N	\N	60.080146999999997	Вологодская область, Бабаевский муниципальный район, деревня Аксентьевская, 22		0101000020E6100000807D74EACAC14140AEEFC341420A4E40
28724	3	27	7278	53297	32178	\N	59.527232942966002	Вологодская область, Бабаевский муниципальный район, поселок Верхневольский, Железнодорожная, 1		0101000020E61000006F0ED76A0FB741409D2FF65E7CC34D40
18869	3	26	\N	57526	59084	\N	62.105705	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"Шенкурское"""", г. Шенкурск, ул. К.Либкнехта, д. 9"		0101000020E6100000EAB298D87C7445400803CFBD870D4F40
18749	3	26	\N	9494	\N	\N	64.573818000000003	Архангельская область, город Северодвинск, д.Солза, здание медпункта	Россия, Архангельская область, Северодвинск	0101000020E6100000A795422097EA4340CBF6216FB9245040
18744	3	26	\N	9494	\N	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Кирилкина, д.7А	Россия, Архангельская область, Северодвинск	0101000020E6100000A795422097EA4340CBF6216FB9245040
18724	3	26	\N	9494	58614	\N	64.573818000000003	Архангельская область, город Северодвинск, Труда проспект, д.25		0101000020E6100000A795422097EA4340CBF6216FB9245040
18746	3	26	\N	9494	58651	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Юбилейная, д.17		0101000020E6100000A795422097EA4340CBF6216FB9245040
18717	3	26	\N	9494	58723	\N	64.552906815722395	Архангельская область, город Северодвинск, ул.Тургенева, д.8	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000B4CBB73EACE74340B0AE0AD462235040
18736	3	26	\N	9494	58733	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Трухинова, д.10		0101000020E6100000A795422097EA4340CBF6216FB9245040
18727	3	26	\N	9494	58689	\N	64.572783876252302	Архангельская область, город Северодвинск, Труда проспект, д.14А	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000DB8827BB99EB434003EB387EA8245040
18725	3	26	\N	9494	58689	\N	64.573818000000003	Архангельская область, город Северодвинск, Труда проспект, д.7Б		0101000020E6100000A795422097EA4340CBF6216FB9245040
18721	3	26	\N	9494	58649	\N	64.564618876400303	Архангельская область, город Северодвинск, ул.Торцева, д.59	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000B03907CF84E84340D0ECBAB722245040
18715	3	26	\N	9494	58649	\N	64.570865091152498	Архангельская область, город Северодвинск, ул.Торцева, д.36	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000691CEA7761EB4340965B5A0D89245040
18708	3	26	\N	9494	58649	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Торцева, д.12		0101000020E6100000A795422097EA4340CBF6216FB9245040
18706	3	26	\N	9494	58649	\N	64.568641713969996	Архангельская область, город Северодвинск, ул.Торцева, д.6	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000DCB75A272EEB434073486AA164245040
18711	3	26	\N	9494	58731	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Строителей, д.43А		0101000020E6100000A795422097EA4340CBF6216FB9245040
18738	3	26	\N	9494	58617	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Советских Космонавтов, д.18		0101000020E6100000A795422097EA4340CBF6216FB9245040
18709	3	26	\N	9494	71953	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Республиканская, д.21А		0101000020E6100000A795422097EA4340CBF6216FB9245040
18712	3	26	\N	9494	58625	\N	64.560654924932393	Архангельская область, город Северодвинск, ул.Профсоюзная, д.21	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000CA349A5C8CEB4340B05582C5E1235040
18704	3	26	\N	9494	58712	\N	64.573521834444307	Архангельская область, город Северодвинск, Приморский бульвар, д.50	Россия, Архангельская область, Северодвинск	0101000020E6100000C72B103D29EB434056629E95B4245040
18714	3	26	\N	9494	58732	\N	64.563747379914304	Архангельская область, город Северодвинск, ул.Полярная, д.12А	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000B03A72A433EA4340F60D4C6E14245040
18728	3	26	\N	9494	58660	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Серго Орджоникидзе, д.15		0101000020E6100000A795422097EA4340CBF6216FB9245040
18705	3	26	\N	9494	58618	\N	64.564812650574297	Архангельская область, город Северодвинск, ул.Октябрьская, д31	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000DFDC5F3DEEE94340C3D66CE525245040
18664	3	26	\N	9494	58618	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Октябрьская, д.2	Россия, Архангельская область, Северодвинск	0101000020E6100000A795422097EA4340CBF6216FB9245040
18631	3	26	\N	9494	58618	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Октябрьская, д.31		0101000020E6100000A795422097EA4340CBF6216FB9245040
18739	3	26	\N	9494	56915	\N	64.573818000000003	Архангельская область, город Северодвинск, Морской проспект, д.56А		0101000020E6100000A795422097EA4340CBF6216FB9245040
18732	3	26	\N	9494	56915	\N	64.573818000000003	Архангельская область, город Северодвинск, Морской проспект, д.12А		0101000020E6100000A795422097EA4340CBF6216FB9245040
18731	3	26	\N	9494	56915	\N	64.573818000000003	Архангельская область, город Северодвинск, Морской проспект, д.9		0101000020E6100000A795422097EA4340CBF6216FB9245040
18700	3	26	\N	9494	56907	\N	64.571570301549002	Архангельская область, город Северодвинск, ул.Мира, д.11	Россия, Архангельская область, Северодвинск	0101000020E6100000155454FD4AEB4340FB57569A94245040
18653	3	26	\N	9494	56907	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Мира, д.23В		0101000020E6100000A795422097EA4340CBF6216FB9245040
18737	3	26	\N	9494	58740	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Ломоносова, д.83		0101000020E6100000A795422097EA4340CBF6216FB9245040
18720	3	26	\N	9494	58721	\N	64.573375253328294	Архангельская область, город Северодвинск, Ленина проспект, д.14	Россия, Архангельская область, Северодвинск	0101000020E610000051A3906456EB434004560E2DB2245040
18713	3	26	\N	9494	58721	\N	64.573818000000003	Архангельская область, город Северодвинск, Ленина проспект, д.31		0101000020E6100000A795422097EA4340CBF6216FB9245040
18740	3	26	\N	9494	58658	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Лебедева, д.10А		0101000020E6100000A795422097EA4340CBF6216FB9245040
18699	3	26	\N	9494	58615	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Корабельная, д.1		0101000020E6100000A795422097EA4340CBF6216FB9245040
18710	3	26	\N	9494	58613	\N	64.559331076552496	Архангельская область, город Северодвинск, ул.Комсомольская, д.7	Россия, Архангельская область, Северодвинск городской округ	0101000020E610000036785F950BED4340E5284014CC235040
18730	3	26	\N	9494	58571	\N	64.556058633827803	Архангельская область, город Северодвинск, ул.Карла Маркса, д.33	Россия, Архангельская область, Северодвинск городской округ	0101000020E6100000BAA3FFE55AE4434060E97C7896235040
18729	3	26	\N	9494	58571	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Карла Маркса, д.36		0101000020E6100000A795422097EA4340CBF6216FB9245040
18722	3	26	\N	9494	58657	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Капитана Воронина, д.24		0101000020E6100000A795422097EA4340CBF6216FB9245040
18707	3	26	\N	9494	59062	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Железнодорожная, д.23В		0101000020E6100000A795422097EA4340CBF6216FB9245040
18703	3	26	\N	9494	58626	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Дзержинского, д.11А		0101000020E6100000A795422097EA4340CBF6216FB9245040
18701	3	26	\N	9494	58701	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Гоголя, д.4		0101000020E6100000A795422097EA4340CBF6216FB9245040
18723	3	26	\N	9494	58634	\N	64.557697464474103	Архангельская область, город Северодвинск, ул.Гагарина, д.24	Россия, Архангельская область, Северодвинск городской округ	0101000020E61000001F9DBAF259E84340F304C24EB1235040
18719	3	26	\N	9494	58634	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Гагарина, д.15		0101000020E6100000A795422097EA4340CBF6216FB9245040
18733	3	26	\N	9494	58665	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Арктическая, д.16	Россия, Архангельская область, Северодвинск	0101000020E6100000A795422097EA4340CBF6216FB9245040
18735	3	26	\N	9494	58703	\N	64.573818000000003	Архангельская область, город Северодвинск, ул.Коновалова, д.3А		0101000020E6100000A795422097EA4340CBF6216FB9245040
18692	3	26	\N	51983	59003	\N	64.635801000000001	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Повракульское"", дер. Повракульская, ул. 70 лет Октября, д.8"		0101000020E61000000E828E56B54E4440E770ADF6B0285040
18541	3	26	\N	57458	58643	\N	63.919744999999999	Архангельская область, Онежский муниципальный район, г.Онега, ул.Матросова, д.34		0101000020E6100000DBF7A8BF5E0B43406BD44334BAF54F40
18538	3	26	\N	57458	58642	\N	63.919744999999999	Архангельская область, Онежский муниципальный район, г.Онега, ул.Коминтерна, д.64		0101000020E6100000DBF7A8BF5E0B43406BD44334BAF54F40
18543	3	26	\N	57458	58564	\N	63.919744999999999	Архангельская область, Онежский муниципальный район, г.Онега, ул.Гутина, д.5		0101000020E6100000DBF7A8BF5E0B43406BD44334BAF54F40
18540	3	26	\N	57458	58640	\N	63.919744999999999	Архангельская область, Онежский муниципальный район, г. Онега, ул.Архангельская, д.38		0101000020E6100000DBF7A8BF5E0B43406BD44334BAF54F40
18510	3	26	\N	57467	58694	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Строителей, д.3		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18506	3	26	\N	57467	58694	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Строителей, д.23А		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18505	3	26	\N	57467	58637	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Первомайская, д.4		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18512	3	26	\N	57467	58696	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Красноармейская, д.57А		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18498	3	26	\N	2333	58690	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.Фронтовых бригад, д.6		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18500	3	26	\N	2333	58624	\N	64.409272938076896	Архангельская область, город Новодвинск, ул.Уборевича, д.43	Россия, Архангельская область, Новодвинск	0101000020E6100000AE10566309694440B1886187311A5040
18396	3	26	\N	2333	58624	\N	64.410396821280898	Архангельская область, город Новодвинск, ул.Уборевича, д.12	Россия, Архангельская область, Новодвинск	0101000020E61000008C868C47A96A44401958C7F1431A5040
18493	3	26	\N	2333	58597	\N	64.4149749510498	Архангельская область, город Новодвинск, ул.Солнечная, д.1 корп.1	Россия, Архангельская область, Новодвинск	0101000020E6100000C366800BB2654440166A4DF38E1A5040
18490	3	26	\N	2333	58597	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.Солнечная, д.15		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18499	3	26	\N	2333	58616	\N	64.410715951927799	Архангельская область, город Новодвинск, ул.Советов, д.24	Россия, Архангельская область, Новодвинск	0101000020E61000003DB83B6BB769444069FCC22B491A5040
18494	3	26	\N	2333	58632	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.Мельникова, д.14		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18491	3	26	\N	2333	58633	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.Космонавтов, д.5		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18502	3	26	\N	2333	58691	\N	64.412882649775298	Архангельская область, город Новодвинск, ул.Двинская, д.45	Россия, Архангельская область, Новодвинск	0101000020E61000007EE02A4F20684440C284D1AC6C1A5040
18501	3	26	\N	2333	58691	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.Двинская, д.43		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18496	3	26	\N	2333	58708	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.Ворошилова, д.24		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18497	3	26	\N	2333	58636	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.50 лет Октября, д.15		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18495	3	26	\N	2333	58631	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.3-й Пятилетки, д.13		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
18492	3	26	\N	2333	58631	\N	64.413066000000001	Архангельская область, город Новодвинск, ул.3-й Пятилетки, д.26		0101000020E610000034D93F4F03684440BB4560AC6F1A5040
12878	7	66	215	18082	62063	\N	55.218553999999997	д.Починок-Быбыть, Московская, 72		0101000020E6100000AE2990D959D047407A34D593F99B4B40
18476	3	26	\N	57473	58635	\N	62.764935965427	Архангельская область, ЗАТО город Мирный, ул.Овчинникова, д.11	Россия, Архангельская область, Мирный	0101000020E6100000710168942E2B44403BC43F6CE9614F40
18480	3	26	\N	57473	58724	\N	62.758351502000203	Архангельская область, ЗАТО город Мирный, улица Неделина, д. 35	Россия, Архангельская область, Мирный	0101000020E61000007EC34483142C4440986DA7AD11614F40
18477	3	26	\N	57473	58724	\N	62.766666662588598	Архангельская область, ЗАТО город Мирный, ул.Неделина, д.28	Россия, Архангельская область, Мирный	0101000020E61000000A82C7B7772B444012F6ED2422624F40
18479	3	26	\N	57473	58756	\N	62.762732999999997	Архангельская область, ЗАТО город Мирный, ул.Ленина, д.38	Россия, Архангельская область, Мирный	0101000020E6100000904B1C79202C44403C4A253CA1614F40
18475	3	26	\N	57473	58756	\N	62.7662732544458	Архангельская область, ЗАТО город Мирный, ул.Ленина, д.22	Россия, Архангельская область, Мирный	0101000020E6100000444DF4F9282B44406667D13B15624F40
18474	3	26	\N	57473	58763	\N	62.767689222578497	Архангельская область, ЗАТО город Мирный, ул.Дзержинского, д.8	Россия, Архангельская область, Мирный	0101000020E6100000BF29AC54502B4440DD3F16A243624F40
17972	3	26	\N	57475	58682	\N	64.421201999999994	Архангельская область, город Архангельск, Лахтинское шоссе, д.135	Россия, Архангельская область, поселок Лесная Речка, Лахтинское шоссе, 133	0101000020E610000088F19A5775504440A0C03BF9F41A5040
18329	3	26	\N	22794	58729	\N	61.241469241568304	Архангельская область, город Котлас, ул. им. 28-й Невельской дивизии, д.1	Россия, Архангельская область, Котлас	0101000020E6100000739CDB847B534740B9FFC874E89E4E40
18349	3	26	\N	22794	58798	\N	61.244007000000003	Архангельская область, город Котлас, ул. Школьная, д.5		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18346	3	26	\N	22794	58693	\N	61.247992979865202	Архангельская область, город Котлас, ул. Ушакова, д.6 корп.1	Россия, Архангельская область, Котлас	0101000020E61000008524B37A875347408751103CBE9F4E40
18324	3	26	\N	22794	58674	\N	61.244007000000003	Архангельская область, город Котлас, ул. С-Щедрина, 2		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18337	3	26	\N	22794	58650	\N	61.253724684525501	Архангельская область, город Котлас, ул. Мелентьева, д.18	Россия, Архангельская область, Котлас	0101000020E61000002CD670917B524740BC96900F7AA04E40
18334	3	26	\N	22794	58588	\N	61.244007000000003	Архангельская область, город Котлас, ул. Маяковского, д.14		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18333	3	26	\N	22794	58588	\N	61.248287027437698	Архангельская область, город Котлас, ул. Маяковского, д.23 корп.1	Россия, Архангельская область, Котлас	0101000020E61000009BABE63922534740CF8250DEC79F4E40
18331	3	26	\N	22794	58588	\N	61.244007000000003	Архангельская область, город Котлас, ул. Маяковского, д.30		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18327	3	26	\N	22794	58588	\N	61.244007000000003	Архангельская область, город Котлас, ул. Маяковского, д.34		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18326	3	26	\N	22794	58588	\N	61.245780078542303	Архангельская область, город Котлас, ул. Маяковского, д. 31	Россия, Архангельская область, Котлас	0101000020E6100000306475ABE7504740650113B8759F4E40
18341	3	26	\N	22794	58858	\N	61.244007000000003	Архангельская область, город Котлас, ул. Мартемьяновская, д.38		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18338	3	26	\N	22794	58600	\N	61.244007000000003	Архангельская область, город Котлас, ул. Ленина, д.103		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18323	3	26	\N	22794	58688	\N	61.244007000000003	Архангельская область, город Котлас, ул. Кузнецова, д.7		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18328	3	26	\N	22794	58590	\N	61.244007000000003	Архангельская область, город Котлас, ул. Кедрова, д.9		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18336	3	26	\N	22794	58736	\N	61.244007000000003	Архангельская область, город Котлас, ул. Карла Маркса, д.31		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18335	3	26	\N	22794	58586	\N	61.2504055981357	Архангельская область, город Котлас, ул. Калинина, д.21	Россия, Архангельская область, Котлас	0101000020E61000000342EBE1CB504740705CC64D0DA04E40
18348	3	26	\N	22794	58711	\N	61.244007000000003	Архангельская область, город Котлас, ул. Заполярная, д.20		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18347	3	26	\N	22794	58711	\N	61.244007000000003	Архангельская область, город Котлас,  ул.Заполярная, д.19		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18345	3	26	\N	22794	58595	\N	61.244007000000003	Архангельская область, город Котлас, ул. Герцена, д.8 корп.1		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18342	3	26	\N	22794	58677	\N	61.244007000000003	Архангельская область, город Котлас, ул. Володарского, д.115		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18340	3	26	\N	22794	58623	\N	61.244007000000003	Архангельская область, город Котлас, ул. Виноградова, д.38		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18339	3	26	\N	22794	58623	\N	61.256479044226303	Архангельская область, город Котлас, ул. Виноградова, д.3	Россия, Архангельская область, Котлас	0101000020E6100000F81BEDB8E14F47402E8ECA4DD4A04E40
18343	3	26	\N	22794	58592	\N	61.244007000000003	Архангельская область, город Котлас, ул. Багратиона, д.64		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18330	3	26	\N	22794	58591	\N	61.244007000000003	Архангельская область, город Котлас, ул. 70-летия Октября, д.21		0101000020E6100000B0AF75A9115447405F7F129F3B9F4E40
18320	3	26	\N	15561	58584	\N	61.3124792784078	Архангельская область, город Коряжма, просп. Ленина, д.37	Россия, Архангельская область, Коряжма	0101000020E6100000A374E95F92984740E9D7D64FFFA74E40
18319	3	26	\N	15561	58584	\N	61.307927999999997	Архангельская область, город Коряжма, просп. Ленина, д.29		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18314	3	26	\N	15561	58584	\N	61.307927999999997	Архангельская область, город Коряжма, просп. Ленина, д.8		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18313	3	26	\N	15561	58671	\N	61.315935072996602	Архангельская область, город Коряжма, площадь им.В.И.Ленина, д.1	Россия, Архангельская область, Коряжма	0101000020E61000002D5BEB8B84944740B554DE8E70A84E40
18297	3	26	\N	15561	58673	\N	61.310529422699702	Архангельская область, город Коряжма, ул. Советская, д.15Г	Россия, Архангельская область, Коряжма	0101000020E6100000CEA5B8AAEC934740D4BA0D6ABFA74E40
18318	3	26	\N	15561	58589	\N	61.312675288919699	Архангельская область, город Коряжма, ул. Пушкина, д.11	Россия, Архангельская область, Коряжма	0101000020E610000007978E39CF9247406EA301BC05A84E40
18311	3	26	\N	15561	58570	\N	61.310676153357299	Архангельская область, город Коряжма, ул. Набережная им.Н.Островского, д.22	Россия, Архангельская область, Коряжма	0101000020E6100000D76839D04395474078D32D3BC4A74E40
18317	3	26	\N	15561	58705	\N	61.307927999999997	Архангельская область, город Коряжма, просп. Ленина, д.23		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18312	3	26	\N	15561	58704	\N	61.307927999999997	Архангельская область, город Коряжма, ул. Кутузова, д.7Б		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18322	3	26	\N	15561	58685	\N	61.307927999999997	Архангельская область, город Коряжма, ул. Космонавтов, д.1		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18316	3	26	\N	15561	58622	\N	61.307927999999997	Архангельская область, город Коряжма, ул. Кирова, д.13		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18315	3	26	\N	15561	58672	\N	61.307927999999997	Архангельская область, город Коряжма, ул. Гоголя, д.22		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18099	3	26	\N	15561	58655	\N	61.307927999999997	Архангельская область, город Коряжма, ул. Архангельская, д.17		0101000020E610000031EC3026FD934740E7C2482F6AA74E40
18685	3	26	\N	12131	58700	\N	64.391354000000007	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Катунинское"", пос. Катунино, ул. Катунина, д.11"		0101000020E6100000EA77616BB65044402ACAA5F10B195040
18241	3	26	\N	57469	58743	\N	61.506473	Архангельская область, Каргопольский муниципальный район, г.Каргополь, ул.Ленинградская, д.63 корп.1		0101000020E610000091D26C1E877743404CA7751BD4C04E40
18240	3	26	\N	57469	58610	\N	61.505128370139303	Архангельская область, Каргопольский муниципальный район, г.Каргополь, ул.Ленина, д.53	Россия, Р-1 шоссе	0101000020E61000005B24ED461F7943409E25C808A8C04E40
18242	3	26	\N	57469	58684	\N	61.506473	Архангельская область, Каргопольский муниципальный район, г.Каргополь, ул.III Интернационала, д.31		0101000020E610000091D26C1E877743404CA7751BD4C04E40
18101	3	26	\N	57465	59078	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование """"Вельское"""", г.Вельск, ул.Некрасова, д.11"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18112	3	26	\N	57465	58836	\N	61.056659367376199	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Заводская, д.25"	Россия, Архангельская область, Вельский район, Вельск	0101000020E61000004A253CA1D71145401503249A40874E40
18104	3	26	\N	57465	58579	\N	61.058032231604599	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Дзержинского, д.88"	Россия, Архангельская область, Вельский район, Вельск	0101000020E610000023111AC1C61145408C0FB3976D874E40
18111	3	26	\N	57465	58661	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Климовского, д.5"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18678	3	26	\N	11790	\N	\N	64.410454999999999	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Васьковское"", пос. Васьково, д.50"		0101000020E610000012FB04508C3A4440B35E0CE5441A5040
18668	3	26	\N	11301	\N	\N	64.483311999999998	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Заостровское"", дер. Большое Анисимово, д.18"		0101000020E61000009032E202D0404440EB707495EE1E5040
18026	3	26	\N	1382	\N	\N	64.5442721135163	Архангельская область, город Архангельск, остров Кего, здание средней школы № 70		0101000020E6100000FA2B64AE0C3644403A083A5AD5225040
18371	3	26	\N	1382	58747	\N	64.661434	ул. Школьная д.10		0101000020E610000007D0EFFB37454440999D45EF542A5040
17986	3	26	\N	1382	2901	\N	64.530698999999998	Архангельская область, город Архангельск, ул.Смольный буян, д.18 корп. 2	Россия, Архангельская область, Архангельск, улица Смольный Буян, 18к2	0101000020E610000068B3EA73B54944404641F0F8F6215040
18012	3	26	\N	1382	15806	\N	64.549170000000004	Архангельская область, город Архангельск, ул.Садовая, д.61	Россия, Архангельская область, Архангельск, Октябрьский район, улица Садовая, 61	0101000020E6100000E179A9D898454440707CED9925235040
18043	3	26	\N	1382	3581	\N	64.681773000000007	Архангельская область, город Архангельск, ул. Победы, д.128 корп.1	Россия, Архангельская область, Архангельск, улица Победы, 128к1	0101000020E61000009A0AF148BC404440EF92382BA22B5040
17982	3	26	\N	1382	2843	\N	64.526700000000005	Архангельская область, город Архангельск, ул. Первомайская, д.3	Россия, Архангельская область, Архангельск, улица Первомайская, 3	0101000020E610000022C32ADEC84C444068B3EA73B5215040
17966	3	26	\N	1382	2587	\N	64.478120000000004	Архангельская область, город Архангельск, ул. Нахимова, д.6 корп.1	Россия, Архангельская область, Архангельск, улица Нахимова, 6к1	0101000020E61000007C2B1213D44C444011E4A084991E5040
18045	3	26	\N	1382	3657	\N	64.706186000000002	Архангельская область, город Архангельск, ул. Мудьюгская, д.25	Россия, Архангельская область, Архангельск, улица Мудьюгская, 25	0101000020E6100000EA2285B2F04D444028B9C326322D5040
18062	3	26	\N	1382	3903	\N	64.580860999999999	Архангельская область, город Архангельск, ул. Маяковского, д.41	Россия, Архангельская область, Архангельск, улица Маяковского, 41	0101000020E6100000B8019F1F4642444066A19DD32C255040
12533	7	66	215	817	61848	\N	55.178125999999999	д.Полевые Яуши, Подгорная, 8		0101000020E61000007B15191D90BE47409D4830D5CC964B40
18071	3	26	\N	1382	4023	\N	64.626324999999994	Архангельская область, город Архангельск, ул. Маймаксанская, д.98	Россия, Архангельская область, Архангельск, улица Маймаксанская, 98	0101000020E61000005C566133C0414440B3EA73B515285040
18061	3	26	\N	1382	3891	\N	64.578332000000003	Архангельская область, город Архангельск, ул. Литейная, д.19	Россия, Архангельская область, Архангельск, улица Литейная, 19	0101000020E61000007FF78E1A13444440BD8E386403255040
18473	3	26	\N	1382	369	\N	64.520838999999995	Архангельская область, ЗАТО город Мирный, ул.Ленина, д.9	Россия, Архангельская область, Архангельск, улица Ленина, 5	0101000020E6100000AEA0698995514440CEDE196D55215040
18056	3	26	\N	1382	3814	\N	64.590892999999994	Архангельская область, город Архангельск, ул. Кутузова, д.8	Россия, Архангельская область, Архангельск, улица Кутузова, 8	0101000020E6100000562C7E53584B4440DC9BDF30D1255040
18024	3	26	\N	1382	3397	\N	64.563274000000007	Архангельская область, город Архангельск, ул.Комсомольская, д.5	Россия, Архангельская область, Архангельск, улица Комсомольская, 5	0101000020E6100000F4DDAD2CD1434440FA2B64AE0C245040
18054	3	26	\N	1382	3779	\N	64.592714999999998	Архангельская область, город Архангельск, ул. Кировская, д.27	Россия, Архангельская область, Архангельск, улица Кировская, 27	0101000020E6100000B5FE9600FC4B44405036E50AEF255040
18074	3	26	\N	1382	4062	\N	64.490960000000001	Архангельская область, город Архангельск, ул. Кирова, д.7	Россия, Архангельская область, Архангельск, улица Кирова, 7	0101000020E6100000A089B0E1E95944403AE97DE36B1F5040
18066	3	26	\N	1382	3948	\N	64.587029999999999	Архангельская область, город Архангельск, ул. Кедрова, д.17	Россия, Архангельская область, Архангельск, улица Кедрова, 17	0101000020E61000009833DB15FA40444056F146E691255040
18044	3	26	\N	1382	3652	\N	64.697961000000006	Архангельская область, город Архангельск, ул. Капитана Хромцова, д.5 корп.1	Россия, Архангельская область, Архангельск, улица Капитана Хромцова, 5к1	0101000020E6100000EB8D5A61FA4044408B389D64AB2C5040
18047	3	26	\N	1382	58773	\N	64.614652000000007	Архангельская область, город Архангельск, ул. Юнг ВМФ, д.13		0101000020E6100000B804E09F523D4440F29A577556275040
18049	3	26	\N	1382	59054	\N	64.678696000000002	Архангельская область, город Архангельск, ул. Чупрова, д.6		0101000020E610000044BE4BA94B3E444044FB58C16F2B5040
18001	3	26	\N	1382	58575	\N	64.535261642829795	Архангельская область, город Архангельск, ул. Чумбарова-Лучинского, д.28	Россия, Архангельская область, Архангельск, Чумбарова-Лучинского проспект, 28	0101000020E610000087342A70B2434440A9328CBB41225040
17970	3	26	\N	1382	58893	\N	64.618804521482204	Архангельская область, город Архангельск, ул. Центральная, д.28		0101000020E61000000C923EADA24B44407B6649809A275040
18086	3	26	\N	1382	58668	\N	64.528573998150705	Архангельская область, город Архангельск, ул. Ф.Абрамова, д.14	Россия, Архангельская область, Архангельск, улица Фёдора Абрамова, 14	0101000020E61000009561DC0DA24D444005E10A28D4215040
17998	3	26	\N	1382	58776	\N	64.539334999999994	Архангельская область, город Архангельск, ул. Урицкого, д.68 корп.3		0101000020E61000008A3F8A3A73494440A4A5F27684225040
18020	3	26	\N	1382	3277	\N	64.557382000000004	Архангельская область, город Архангельск, просп.Троицкий, д.162	Россия, Архангельская область, Архангельск, Троицкий проспект, 162	0101000020E6100000FD3218231243444043588D25AC235040
18019	3	26	\N	1382	3277	\N	64.552018000000004	Архангельская область, город Архангельск, просп.Троицкий, д.130	Россия, Архангельская область, Архангельск, Троицкий проспект, 130	0101000020E61000009FB0C403CA4244406A334E4354235040
18016	3	26	\N	1382	3277	\N	64.550329000000005	Архангельская область, город Архангельск, просп.Троицкий, д.93	Россия, Архангельская область, Архангельск, Троицкий проспект, 93	0101000020E610000075B0FECF614244409642209738235040
18015	3	26	\N	1382	3277	\N	64.541802000000004	Архангельская область, город Архангельск, просп.Троицкий, д.51	Россия, Архангельская область, Архангельск, Троицкий проспект, 51	0101000020E6100000626A4B1DE441444013BA4BE2AC225040
18007	3	26	\N	1382	58772	\N	64.55283	Архангельская область, город Архангельск, ул.Тимме, д.22, корп.3		0101000020E61000006B48DC63E9474440DA8F149161235040
18063	3	26	\N	1382	58761	\N	64.577478999999997	Архангельская область, город Архангельск, ул. Терехина, д.3		0101000020E6100000FCA6B052414144401DC87A6AF5245040
17963	3	26	\N	1382	58880	\N	64.516412000000003	Архангельская область, город Архангельск, ул. Сурповская, д.26		0101000020E6100000352A70B20D464440C4D0EAE40C215040
18025	3	26	\N	1382	58784	\N	64.560303000000005	Архангельская область, город Архангельск, ул.Суворова, д.2		0101000020E6100000A4A7C821E242444072361D01DC235040
17979	3	26	\N	1382	58787	\N	64.537042	Архангельская область, город Архангельск, ул. Стивидорская, д.11		0101000020E6100000B0912408572A444005A568E55E225040
18050	3	26	\N	1382	59043	\N	64.696354999999997	Архангельская область, город Архангельск, ул. Стадионная, д.14		0101000020E61000007B2FBE688F354440FDD98F14912C5040
18023	3	26	\N	1382	3082	\N	64.555352999999997	Архангельская область, город Архангельск, просп.Советских космонавтов, д.178	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 178	0101000020E6100000AE7E6C921F454440122F4FE78A235040
18022	3	26	\N	1382	3082	\N	64.557389999999998	Архангельская область, город Архангельск, просп.Советских космонавтов, д.188, корп.1	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 188к1	0101000020E6100000B21188D7F545444084471B47AC235040
18013	3	26	\N	1382	3082	\N	64.550985999999995	Архангельская область, город Архангельск, просп.Советских космонавтов, д.153	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 153	0101000020E61000008351499D8044444072A3C85A43235040
18000	3	26	\N	1382	3082	\N	64.539075999999994	Архангельская область, город Архангельск, пр. Советских космонавтов, д.69	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 69	0101000020E61000004FB2D5E594444440BE839F3880225040
17991	3	26	\N	1382	58754	\N	64.530698999999998	Архангельская область, город Архангельск, ул.Смольный Буян, д.18 корп.2		0101000020E610000068B3EA73B54944404641F0F8F6215040
17987	3	26	\N	1382	58754	\N	64.538600000000002	Архангельская область, город Архангельск, ул.Смольный буян, д.25 корп.1		0101000020E6100000A911FA997A4944400A68226C78225040
18073	3	26	\N	1382	58771	\N	64.483583936453002	Архангельская область, город Архангельск, ул. Силикатчиков, д.10	Россия, Архангельская область, Архангельск, улица Силикатчиков, 9	0101000020E6100000D464C6DB4A6344409B374E0AF31E5040
17977	3	26	\N	1382	58748	\N	64.526470462201402	Архангельская область, город Архангельск, ул. Севстрой, д.2	Россия, Архангельская область, Архангельск, улица Севстрой	0101000020E6100000D7C1C1DEC42C4440CF143AAFB1215040
18017	3	26	\N	1382	2979	\N	64.551070999999993	Архангельская область, город Архангельск, наб.Северной Двины, д.111	Россия, Архангельская область, Архангельск, Северной Двины набережная, 111	0101000020E6100000EA7937161442444089B14CBF44235040
17999	3	26	\N	1382	2979	\N	64.532970000000006	Архангельская область, город Архангельск, набережная Северной Двины, д.73	Россия, Архангельская область, Архангельск, Северной Двины набережная, 73	0101000020E6100000147AFD497C424440F2EF332E1C225040
17992	3	26	\N	1382	2979	\N	64.528959	Архангельская область, город Архангельск, набережная Северной Двины, д.25		0101000020E6100000ABD0402C9B454440317BD976DA215040
17984	3	26	\N	1382	58769	\N	64.532617999999999	Архангельская область, город Архангельск, ул.Розы Шаниной, д.6 корп.1		0101000020E610000063D009A183484440B3D0CE6916225040
18042	3	26	\N	1382	58778	\N	64.68535	Архангельская область, город Архангельск, ул. Родионова, д.14		0101000020E61000000533A6608D3F444012143FC6DC2B5040
17968	3	26	\N	1382	58757	\N	64.459154999999996	Архангельская область, город Архангельск, ул. Речников, д.46		0101000020E6100000B39602D2FE534440DF32A7CB621D5040
18325	3	26	\N	1382	58865	\N	64.527860000000004	ул. Пугачева, д. 20		0101000020E6100000DDEBA4BE2C51444076374F75C8215040
18096	3	26	\N	1382	58653	\N	64.545817999999997	Архангельская область, город Архангельск, ул. П.Галушина, д.25 корп.1		0101000020E6100000DD5B9198A04644405CE49EAEEE225040
18089	3	26	\N	1382	58653	\N	64.525671000000003	Архангельская область, город Архангельск, ул. П.Галушина, д.6	Россия, Архангельская область, Архангельск, улица Прокопия Галушина, 6	0101000020E6100000D3DB9F8B864E4440295DFA97A4215040
18087	3	26	\N	1382	58653	\N	64.535134123950598	Архангельская область, город Архангельск, ул. П.Галушина, д.25, корп.1	Россия, Архангельская область, Архангельск, улица Прокопия Галушина, 25	0101000020E6100000D6390664AF4F4440923EADA23F225040
18011	3	26	\N	1382	3236	\N	64.547078999999997	Архангельская область, город Архангельск, пр-д Приорова, д.2	Россия, Архангельская область, Архангельск, Приорова проезд, 2	0101000020E6100000425C397B674644400455A35703235040
18065	3	26	\N	1382	58785	\N	64.583629000000002	Архангельская область, город Архангельск, ул. Приморская, д.13		0101000020E61000002A3BFDA02E3C4440D2FF722D5A255040
18069	3	26	\N	1382	58788	\N	64.585339000000005	Архангельская область, город Архангельск, ул. Полярная, д.4		0101000020E6100000149337C0CC434440B284B53176255040
18039	3	26	\N	1382	58864	\N	64.649074999999996	Архангельская область, город Архангельск, ул. Победы, д.18 корп.4		0101000020E610000072C119FCFD444440AD69DE718A295040
17962	3	26	\N	1382	58871	\N	64.516153000000003	Архангельская область, город Архангельск, ул. Пирсовая, д.19		0101000020E610000080D4264EEE434440DEAE97A608215040
18040	3	26	\N	1382	58751	\N	64.540305000000004	Архангельская область, город Архангельск, ул. Пионерская, д.82 корп.1		0101000020E61000006E6C76A4FA36444061376C5B94225040
18052	3	26	\N	1382	58792	\N	64.602857999999998	Архангельская область, город Архангельск, ул. Партизанская, д.51		0101000020E6100000DAFE9595264B44407288B83995265040
17993	3	26	\N	1382	2924	\N	64.539485999999997	Архангельская область, город Архангельск, пр.Обводный канал, д.30	Россия, Архангельская область, Архангельск, Обводный Канал проспект, 30	0101000020E6100000E7E3DA503146444097A949F086225040
17989	3	26	\N	1382	2924	\N	64.536636000000001	Архангельская область, город Архангельск, пр.Обводный канал, д.12	Россия, Архангельская область, Архангельск, Обводный Канал проспект, 12	0101000020E61000003E9468C9E3474440CD76853E58225040
17988	3	26	\N	1382	2924	\N	64.535827999999995	Архангельская область, город Архангельск, пр.Обводный канал, д.2	Россия, Архангельская область, Архангельск, Обводный Канал проспект, 2	0101000020E6100000D34ECDE506494440FD1186014B225040
17994	3	26	\N	1382	2830	\N	64.536195000000006	Архангельская область, город Архангельск, пр.Новгородский, д.66	Россия, Архангельская область, Архангельск, Новгородский проспект, 66	0101000020E610000011C5E40D30454440D751D50451225040
17990	3	26	\N	1382	2830	\N	64.532471000000001	Архангельская область, город Архангельск, пр.Новгородский, д.21	Россия, Архангельская область, Архангельск, Новгородский проспект, 21	0101000020E610000068757286E246444061C43E0114225040
17981	3	26	\N	1382	2830	\N	64.533805000000001	Архангельская область, город Архангельск, пр.Новгородский,34,корп.2		0101000020E610000006BCCCB0514644403E5C72DC29225040
18067	3	26	\N	1382	3969	\N	64.588497000000004	Архангельская область, город Архангельск, пр. Никольский, д.152	Россия, Архангельская область, Архангельск, Никольский проспект, 152	0101000020E6100000546F0D6C95404440D33252EFA9255040
18081	3	26	\N	1382	58779	\N	64.508651999999998	Архангельская область, город Архангельск, ул. Никитова, д.1		0101000020E6100000B779E3A430554440E1421EC18D205040
18088	3	26	\N	1382	4220	\N	64.534080000000003	Архангельская область, город Архангельск, пр. Московский, д.43 корп.2	Россия, Архангельская область, Архангельск, Московский проспект, 43к2	0101000020E6100000BC218D0A9C4E4440A75CE15D2E225040
18038	3	26	\N	1382	58783	\N	64.642388999999994	Архангельская область, город Архангельск, ул. Менделеева, д.19		0101000020E61000001DCA501553454440D993C0E61C295040
17978	3	26	\N	1382	58755	\N	64.530103999999994	Архангельская область, город Архангельск, ул. Матросова, д.1		0101000020E610000016FBCBEEC92B4440A4DE5339ED215040
18070	3	26	\N	1382	58768	\N	64.613245000000006	Архангельская область, город Архангельск, ул. Маслова, д.22		0101000020E6100000963D096CCE3F4440E0DBF4673F275040
18053	3	26	\N	1382	58774	\N	64.599127999999993	Архангельская область, город Архангельск, ул. Малиновского, д.4		0101000020E610000066DB696B444C44408B87F71C58265040
18046	3	26	\N	1382	58758	\N	64.625495168262404	Архангельская область, город Архангельск, ул. Луганская, д.6	Россия, Архангельская область, Архангельск, улица Луганская	0101000020E610000079CC4065FC3B4440F0332E1C08285040
18478	3	26	\N	1382	2889	\N	64.529944999999998	Архангельская область, ЗАТО город Мирный, ул.Ломоносова, д.18 А	Россия, Архангельская область, Архангельск, Ломоносова проспект, 18	0101000020E61000000FD07D39B347444070EB6E9EEA215040
18021	3	26	\N	1382	2889	\N	64.557027000000005	Архангельская область, город Архангельск, просп.Ломоносова, д.269	Россия, Архангельская область, Архангельск, Ломоносова проспект, 269	0101000020E6100000906AD8EF894344404CFF9254A6235040
18018	3	26	\N	1382	2889	\N	64.548084000000003	Архангельская область, город Архангельск, просп.Ломоносова, д.211	Россия, Архангельская область, Архангельск, Ломоносова проспект, 211	0101000020E6100000B69DB646044344407FDDE9CE13235040
17985	3	26	\N	1382	2889	\N	64.533291000000006	Архангельская область, город Архангельск, пр.Ломоносова, д.80	Россия, Архангельская область, Архангельск, Ломоносова проспект, 80	0101000020E6100000732EC555654544401310937021225040
18041	3	26	\N	1382	58770	\N	64.658727999999996	Архангельская область, город Архангельск, ул. Лесотехническая, д.1 корп.1		0101000020E61000008AE8D7D64F454440683D7C99282A5040
18095	3	26	\N	1382	58749	\N	64.503320332408805	Архангельская область, город Архангельск, ул. М.Лермонтова, д.15	Россия, Архангельская область, Архангельск, улица Лермонтова, 15	0101000020E61000002905DD5ED25044400EDB166536205040
18091	3	26	\N	1382	2862	\N	64.513176000000001	Архангельская область, город Архангельск, пр. Ленинградский, д.169	Россия, Архангельская область, Архангельск, Ленинградский проспект, 169	0101000020E6100000C95A43A9BD524440E54526E0D7205040
18090	3	26	\N	1382	2862	\N	64.514814000000001	Архангельская область, город Архангельск, пр. Ленинградский, д.165 корп.1	Россия, Архангельская область, Архангельск, Ленинградский проспект, 165к1	0101000020E61000001F69705B5B52444078616BB6F2205040
18085	3	26	\N	1382	2862	\N	64.525868000000003	Архангельская область, город Архангельск, пр. Ленинградский, д.75	Россия, Архангельская область, Архангельск, Ленинградский проспект, 75	0101000020E6100000C153C8957A4C4440D48041D2A7215040
18078	3	26	\N	1382	2862	\N	64.500456	Архангельская область, город Архангельск, пр. Ленинградский, д.322	Россия, Архангельская область, Архангельск, Ленинградский проспект, 322	0101000020E610000049F3C7B43657444091459A7807205040
18076	3	26	\N	1382	2862	\N	64.500366999999997	Архангельская область, город Архангельск, пр. Ленинградский, д.324	Россия, Архангельская область, Архангельск, Ленинградский проспект, 324	0101000020E610000094A2957B81574440D93F4F0306205040
17983	3	26	\N	1382	2862	\N	64.527964999999995	Архангельская область, город Архангельск, пр.Ленинградский, д.17	Россия, Архангельская область, Архангельск, Ленинградский проспект, 17	0101000020E61000009D853DEDF0494440B01BB62DCA215040
18014	3	26	\N	1382	15817	\N	64.540383000000006	Архангельская область, город Архангельск, пл.Ленина, д.1	Россия, Архангельская область, Архангельск, Октябрьский район, Ленина площадь, 1	0101000020E6100000A114ADDC0B4244401F1494A295225040
18060	3	26	\N	1382	58752	\N	64.574776	Архангельская область, город Архангельск, ул. Краснофлотская, д.3		0101000020E61000000C569C6A2D424440A5A14621C9245040
17974	3	26	\N	1382	58759	\N	64.431568999999996	Архангельская область, город Архангельск, ул. Клепача, д.3		0101000020E6100000AF78EA91064F4440EA3D95D39E1B5040
17973	3	26	\N	1382	58759	\N	64.430913000000004	Архангельская область, город Архангельск, ул. Клепача, д.3 корп.2		0101000020E610000017A06D35EB4E4440F69A1E14941B5040
95164	3	26	\N	1382	58764	\N	64.547531000000006	Архангельская область, город Архангельск, ул. Кирпичного завода, д.28		0101000020E610000072E14048162A4440F5A276BF0A235040
18057	3	26	\N	1382	58780	\N	64.593513999999999	Архангельская область, город Архангельск, ул. Кировская, д.21		0101000020E61000002B4F20EC144B4440F6ED2422FC255040
18055	3	26	\N	1382	58780	\N	64.591322000000005	Архангельская область, город Архангельск, ул. Кировская, д.12		0101000020E6100000CEC29E76F84B4440F1D93A38D8255040
18068	3	26	\N	1382	58775	\N	64.586864000000006	Архангельская область, город Архангельск, ул. Кедрова, д.34		0101000020E61000007EAB75E272424440C9CC052E8F255040
18694	3	26	\N	1382	59051	\N	64.535729928596695	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Вознесенское"", дер. Кегостров, ул. Кегостровская, д.85"	Россия, Архангельская область, Архангельск, улица Кегостровская	0101000020E61000004337FB03E53644401C5F7B6649225040
18077	3	26	\N	1382	58753	\N	64.504667999999995	Архангельская область, город Архангельск, ул. Квартальная, д.10		0101000020E6100000B1169F02605844409DD5027B4C205040
18075	3	26	\N	1382	58753	\N	64.504543999999996	Архангельская область, город Архангельск, ул. Квартальная, д.15		0101000020E61000003DB7D0950858444027D9EA724A205040
17976	3	26	\N	1382	58867	\N	64.515951000000001	Архангельская область, город Архангельск, ул. Зеленец, д.26		0101000020E6100000FCC6D79E59364440AAD5575705215040
18374	3	26	\N	1382	59057	\N	64.431740000000005	ул. Железнадорожная д.17		0101000020E61000004F401361C34D44400118CFA0A11B5040
18048	3	26	\N	1382	58767	\N	64.646609999999995	Архангельская область, город Архангельск, ул. Емецкая, д.19 корп.2		0101000020E610000086915ED4EE3F44400FD1E80E62295040
17975	3	26	\N	1382	58875	\N	64.508399999999995	Архангельская область, город Архангельск, ул. Дрейера, д.9 корп.3		0101000020E6100000A62A6D718D494440545227A089205040
18006	3	26	\N	1382	3173	\N	64.556455	Архангельская область, город Архангельск, просп.Дзержинского, д.23	Россия, Архангельская область, Архангельск, Дзержинского проспект, 23	0101000020E6100000F27A30293E48444086AC6EF59C235040
17965	3	26	\N	1382	58760	\N	64.497342000000003	Архангельская область, город Архангельск, ул. Дежневцев, д.12		0101000020E61000001E3691990B4C4440583B8A73D41F5040
17964	3	26	\N	1382	58760	\N	64.498171934524905	Архангельская область, город Архангельск, ул. Дежневцев, д.14	Россия, Архангельская область, Архангельск, улица Дежнёвцев	0101000020E6100000FCC8AD49B74B44401BF2CF0CE21F5040
18093	3	26	\N	1382	58789	\N	64.519817000000003	Архангельская область, город Архангельск, ул. Дачная, д.57 корп.3		0101000020E6100000F25F200890554440E9B985AE44215040
18064	3	26	\N	1382	58728	\N	64.579719099496501	Архангельская область, город Архангельск, наб. Г. Седова, д.14	Россия, Архангельская область, Архангельск, Георгия Седова набережная, 14	0101000020E610000089096AF816404440AB77B81D1A255040
18028	3	26	\N	1382	58619	\N	64.563451999999998	Архангельская область, город Архангельск, ул.Гагарина, д.8, корп.1		0101000020E6100000EBABAB02B54444406937FA980F245040
18010	3	26	\N	1382	58766	\N	64.548439000000002	Архангельская область, город Архангельск, ул.Воскресенская, д.95, корп.3		0101000020E6100000A8DF85ADD94644407636E49F19235040
18008	3	26	\N	1382	58766	\N	64.550529999999995	Архангельская область, город Архангельск, ул.Воскресенская, д.103, корп.1		0101000020E61000002C11A8FE41484440E15D2EE23B235040
17996	3	26	\N	1382	58766	\N	64.545157000000003	Архангельская область, город Архангельск, ул. Воскресенская, д.106 корп.2		0101000020E61000009CA38E8EAB474440DF8B2FDAE3225040
18094	3	26	\N	1382	58762	\N	64.515955000000005	Архангельская область, город Архангельск, ул. Воронина, д.40		0101000020E6100000C1C41F459D5544404BCD1E6805215040
18082	3	26	\N	1382	58762	\N	64.512541999999996	Архангельская область, город Архангельск, ул. Воронина, д.30 корп.1		0101000020E61000001D39D21918574440E4F4F57CCD205040
18080	3	26	\N	1382	58762	\N	64.508736999999996	Архангельская область, город Архангельск, ул. Воронина, д.37 корп.4		0101000020E61000008AABCABE2B564440F850A2258F205040
18079	3	26	\N	1382	58762	\N	64.506201000000004	Архангельская область, город Архангельск, ул. Воронина, д.27		0101000020E61000003D0B42791F574440F60CE19865205040
17967	3	26	\N	1382	58781	\N	64.474574000000004	Архангельская область, город Архангельск, ул. Адмирала Макарова, д.33		0101000020E6100000376DC669884C44400B62A06B5F1E5040
18027	3	26	\N	1382	58702	\N	64.545817999999997	Архангельская область, город Архангельск, ул.Авиационная, д.23		0101000020E6100000DD5B9198A04644405CE49EAEEE225040
17997	3	26	\N	1382	58765	\N	64.545868999999996	Архангельская область, город Архангельск, ул. 23-й Гвардейской дивизии, д.9		0101000020E6100000FDF84B8BFA4844409DB98784EF225040
17995	3	26	\N	1382	58765	\N	64.545025999999993	Архангельская область, город Архангельск, ул. 23-й Гвардейской дивизии, д.8		0101000020E610000083F8C08EFF4844400F5EBBB4E1225040
17971	3	26	\N	1382	2678	\N	64.433660619824906	Архангельская область, город Архангельск, ул. Вторая линия, д.10 корп.1		0101000020E6100000D862B7CF2A4D44403E23111AC11B5040
17969	3	26	\N	1382	58782	\N	64.456096000000002	Архангельская область, город Архангельск, ул. 100-й дивизии, д.12		0101000020E610000030134548DD50444088F546AD301D5040
18059	3	26	\N	1382	3864	\N	64.5708992534	Архангельская область, город Архангельск, пер. 1-й Банный, д.2	Россия, Архангельская область, Архангельск, 1-й Банный переулок	0101000020E61000009E9ACB0D864244406C94F59B89245040
18344	3	26	\N	57498	\N	\N	61.252623906453799	Архангельская область, город Котлас, д.Антоново, здание Котласского завода силикатного кирпича		0101000020E61000007CF1457BBC5A4740A417B5FB55A04E40
18841	3	26	1595	19758	58811	\N	62.108752000000003	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Никольское"", дер. Шипуновская, ул. Школьная, д. 6"		0101000020E610000028D2FD9C82664540F3AFE595EB0D4F40
18867	3	26	1595	21176	58676	\N	62.105900381343503	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Шенкурское"", г. Шенкурск, ул. Мира, д. 20"	Россия, Архангельская область, Шенкурский район, Шенкурск	0101000020E610000071A94A5B5C734540BD5296218E0D4F40
18868	3	26	1595	21176	58663	\N	62.105705	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Шенкурское"", г. Шенкурск, ул. Кудрявцева, д.18"		0101000020E6100000EAB298D87C7445400803CFBD870D4F40
18856	3	26	1595	57483	58866	\N	61.961049847389802	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Усть-Паденьгское"", пос. Шелашский, ул. Школьная, д. 22А"	Россия, Архангельская область, Шенкурский район, село Шелаша	0101000020E61000001842CEFBFF5C454010E9B7AF03FB4E40
18863	3	26	1595	20986	58842	\N	62.374639999999999	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Шеговарское"", с. Шеговары, ул. Новая, д. 8"		0101000020E6100000CA6DFB1EF579454000E31934F42F4F40
18864	3	26	1595	21043	58964	\N	62.304105999999997	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Шеговарское"", дер. Чушевская, ул. Ивановская, д. 15"		0101000020E6100000DE770C8FFD784540394206F2EC264F40
18852	3	26	1595	20376	58909	\N	61.907801999999997	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"Усть-Паденьгское"""", дер. Усть-Паденьга, ул. Новостроек, д.28"		0101000020E610000073F6CE68AB524540279F1EDB32F44E40
18834	3	26	1595	19363	58963	\N	62.337967999999996	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Верхоледское"", пос. Уколок, ул. Школьная, д. 29"		0101000020E610000064744012F6EF4440198C1189422B4F40
18854	3	26	1595	20501	\N	\N	61.818061999999998	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Усть-Паденьгское"", дер. Тронинская, д. 44"		0101000020E61000000EBBEF181E554540D80C7041B6E84E40
18217	3	26	1595	21599	58795	\N	61.885336000000002	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Борецкое"",п.Сельменьга, ул.Набережная, д.10"		0101000020E6100000B7ED7BD45F59454059FCA6B052F14E40
18851	3	26	1595	20321	\N	\N	62.089176000000002	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Тарнянское"", дер. Рыбогорская, д. 50"		0101000020E610000098A77345292F454047CB811E6A0B4F40
18844	3	26	1595	19896	59069	\N	61.685707999999998	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Ровдинское"", с. Ровдино, ул. Пионерская, д. 4"		0101000020E6100000F4A62215C6444540834D9D47C5D74E40
18848	3	26	1595	20143	\N	\N	61.708171999999998	"Архангельская область, Шенкурский муниципальнальный район, муниципальное образование ""Ровдинское"", п.Плесо, д.14"		0101000020E6100000CDE9B298D8244540B1F84D61A5DA4E40
18839	3	26	1595	19624	\N	\N	62.023671999999998	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Никольское"", дер. Петровская, здание клуба"	Россия, Архангельская область, Шенкурский район, село Петровская	0101000020E6100000E2218C9FC66345405BEA20AF07034F40
18866	3	26	1595	21137	\N	\N	62.260325999999999	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Ямскогорское"", дер. Одинцовская, д. 57"		0101000020E610000062A2410A9E6A45403526C45C52214F40
18862	3	26	1595	20940	\N	\N	61.673344	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Шахановское"", дер. Носовская, здание администрации"	Россия, Архангельская область, Шенкурский район, село Носовская	0101000020E610000003CFBD874B4045409A7ADD2230D64E40
18842	3	26	1595	57504	\N	\N	62.154459000000003	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Никольское"", дер. Никольский Погост, здание ФАП"		0101000020E6100000749659846253454054C90050C5134F40
18847	3	26	1595	20051	\N	\N	61.681820999999999	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Ровдинское"", дер. Никольская, здание школы"	Россия, Архангельская область, Шенкурский район, село Никольская	0101000020E61000002C9E7AA4C1314540EE5C18E945D74E40
18857	3	26	1595	20660	58847	\N	62.112005000000003	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"Федорогорское"""", дер. Никифоровская, пер. Лесной, д.2"		0101000020E610000033897AC1A77D454087FE092E560E4F40
18850	3	26	1595	20234	\N	\N	62.503163999999998	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Сюмское"", дер. Куликовская, здание детского сада"	Россия, Архангельская область, Шенкурский район, село Куликовская	0101000020E610000055DD239BAB64454024438EAD67404F40
18843	3	26	1595	19851	\N	\N	62.314883000000002	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Никольское"", дер. Красковская, здание ФАП"	Россия, Архангельская область, Шенкурский район, село Красковская	0101000020E6100000E4326E6AA07D45407F880D164E284F40
94411	3	26	1595	20723	\N	\N	62.066768000000003	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"""""Федорогорское"""""""", д. Копалинская, д. 14"		0101000020E6100000520E661360784540AD3594DA8B084F40
18837	3	26	1595	19542	\N	\N	61.91751	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"Верхопаденьгское"""", с. Ивановское, д. 18"		0101000020E6100000EF37DA71C305454061E0B9F770F54E40
18835	3	26	1595	19434	\N	\N	62.274090000000001	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Верхоледское"", дер. Дывлевская, д. 25"		0101000020E6100000D65240DAFF2245409014916115234F40
18846	3	26	1595	20028	\N	\N	61.651226999999999	"Архангельская область, Шенкурский муниципальнальный район, муниципальное образование ""Ровдинское"", с.Демидовское, д.5"		0101000020E61000007F17B6662B394540D7A205685BD34E40
18865	3	26	1595	21085	\N	\N	62.258127000000002	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Ямскогорское"", дер. Данковская, д. 28"		0101000020E610000018CFA0A17F564540789B374E0A214F40
18840	3	26	1595	52251	\N	\N	62.066026999999998	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Никольское"", дер. Гребеневская, здание клуба"	Россия, Архангельская область, Шенкурский район, село Гребневская	0101000020E610000012A3E716BA6E454095D39E9273084F40
18860	3	26	1595	57493	58925	\N	62.154459000000003	"Архангельская область, Шенкурский муниципальный район, муниципальное образование ""Федорогорское"", дер. Бобыкинская, ул. 50 лет МТС, д. 8"		0101000020E6100000749659846253454054C90050C5134F40
94410	3	26	1595	19946	\N	\N	61.728445000000001	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"""""Ровдинское"""""""", д. Барановская, д. 53"		0101000020E6100000541A31B3CF434540A5F78DAF3DDD4E40
18836	3	26	1595	19474	\N	\N	61.952852999999998	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"Верхопаденьгское"""", дер. Артемьевская, д. 80"		0101000020E6100000CDCAF6216FF744409F724C16F7F94E40
18853	3	26	1595	20445	\N	\N	61.859260999999996	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"Усть-Паденгское"""", д. Алешковская, д. 15"		0101000020E6100000DE205A2BDA32454037DDB243FCED4E40
18825	3	26	1487	18892	\N	\N	63.44265	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Хаврогорское"", дер.Часовня, д.71"		0101000020E6100000FD86890629F0444086C954C1A8B84F40
18815	3	26	1487	18394	\N	\N	63.813526000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ракульское"", дер.Часовенская, д.19"		0101000020E61000007044F7AC6BC244400D39B69E21E84F40
18792	3	26	1487	17243	\N	\N	64.306956999999997	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Койдокурское"", дер. Хомяковская, д.90"		0101000020E610000018963FDF169C4440CF11F92EA5135040
18796	3	26	1487	17430	58725	\N	64.225150468555995	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Холмогорское"", с.Холмогоры, ул.Октябрьская, д.15"	Россия, Архангельская область, Холмогорский район, село Холмогоры	0101000020E610000038D89B1892D3444071AC8BDB680E5040
18804	3	26	1487	17835	58662	\N	64.187800999999993	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Матигорское"", дер.Харлово, ул. им. А.Д.Шиловского, д.62А"		0101000020E61000000ADAE4F049D34440FD497CEE040C5040
18808	3	26	1487	18038	\N	\N	64.146844000000002	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Усть-Пинежское"", пос.Усть-Пинега, ул.Гаражная, д.30"	Россия, Архангельская область, Холмогорский район, село Усть-Пинега	0101000020E6100000E2E82ADD5DF54440496760E465095040
18800	3	26	1487	17636	\N	\N	64.266625000000005	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Луковецкое"", дер.Среднепогостская, д.20"		0101000020E610000025EA059FE6EA4440F2D24D6210115040
18810	3	26	1487	18133	\N	\N	64.04374	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Светлозерское"", пос.Светлый, д.16"		0101000020E6100000F20698F90E5A4540BB61DBA2CC025040
18861	3	26	1487	20877	58970	\N	63.321007999999999	"Архангельская область, Шенкурский муниципальный район, муниципальное образование """"Федорогорское"""", пос. Россохи, ул. Сосновая, д. 18"		0101000020E6100000F0A485CB2A0045408FE046CA16A94F40
18799	3	26	1487	17587	\N	\N	64.322632999999996	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ухтостровское"", дер.Рембуево, здание школы"	Россия, Архангельская область, Холмогорский район, село Рембуево	0101000020E610000097AB1F9BE4CB444010E7E104A6145040
18824	3	26	1487	18884	\N	\N	63.524731000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Хаврогорское"", дер.Погост, д.31"		0101000020E6100000DB519CA38EF444404419AA622AC34F40
18833	3	26	1487	18884	58967	\N	63.524731000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Селецкое"", дер.Погост, ул.Почтовая, д.10"		0101000020E6100000DB519CA38EF444404419AA622AC34F40
18817	3	26	1487	18499	58962	\N	63.874957000000002	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ракульское"", пос.Палово, ул.Кольцевая, д.1"		0101000020E610000023F433F5BABD444001344A97FEEF4F40
18822	3	26	1487	18752	\N	\N	63.474330999999999	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Емецкое"", дер.Осередок, д.3"		0101000020E6100000BB9C121093DE44404F3DD2E0B6BC4F40
18812	3	26	1487	18249	\N	\N	64.000551000000002	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Копачевское"", пос.Орлецы, д.19"		0101000020E610000082A8FB00A4E64440BABE0F0709005040
18806	3	26	1487	17959	\N	\N	64.110884999999996	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Матигорское"", пос.Малая Товра, д.2"		0101000020E61000008ACDC7B5A1DA44407C2766BD18075040
18801	3	26	1487	17696	58587	\N	64.296980000000005	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Луковецкое"", пос.Луковецкий, ул.Советская, д.8"		0101000020E61000008429CAA5F1F544403BE466B801135040
18803	3	26	1487	17793	\N	\N	64.230238999999997	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ломоносовское"", с.Ломоносово, д.45А"		0101000020E610000024287E8CB9DD4440E1D05B3CBC0E5040
18811	3	26	1487	18183	\N	\N	64.274895000000001	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Леуновское"", дер.Кузомень, д.27"		0101000020E6100000FF9600FC537845405FB532E197115040
18814	3	26	1487	18346	\N	\N	63.956074000000001	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Копачевское"", дер.Копачево, д.53"		0101000020E6100000ACE63922DFD94440284701A260FA4F40
18508	3	26	511	3132	58599	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Североморская, д.7А		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18793	3	26	1487	17280	\N	\N	64.294538000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Койдокурское"", дер.Калитинская, д.321"		0101000020E6100000DC847B65DEA84440795BE9B5D9125040
18818	3	26	1487	18565	58961	\N	63.849505000000001	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ракульское"", пос.Казенщина, ул.Гаражная, д.1"		0101000020E61000007711A62897D44440ED647094BCEC4F40
18813	3	26	1487	18262	\N	\N	63.934719999999999	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Копачевское"", дер.Ичково, д.47"		0101000020E6100000CE6F986890DE44406475ABE7A4F74F40
18830	3	26	1487	19194	\N	\N	63.403821999999998	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Зачачьевское"", дер.Заболотье, д.106А"		0101000020E6100000637B2DE8BDE94440E1B37570B0B34F40
18821	3	26	1487	18711	58620	\N	63.474428000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Емецкое"", с.Емецк, ул.Горончаровского, д.53"		0101000020E610000030BC92E4B9E444404227840EBABC4F40
18797	3	26	1487	17477	\N	\N	64.199023999999994	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Холмогорское"", дер.Демидово, д.3"		0101000020E6100000971E4DF564CC44409FC728CFBC0C5040
18832	3	26	1487	19287	58846	\N	63.347337000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Двинское"", пос.Двинской, ул.Лесная, д.87"		0101000020E6100000AB4198DBBD0245406BD8EF8975AC4F40
18828	3	26	1487	19068	\N	\N	63.456670000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Зачачьевское"", дер.Горка Рудаковская, д.25"		0101000020E610000071E6577380DA44403C889D2974BA4F40
18798	3	26	1487	57510	\N	\N	63.854917260070003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ухтостровское"", дер.Горка-Кузнечевская, д.32"	Россия, Архангельская область, Холмогорский район	0101000020E6100000CAE1934E24384540B0E595EB6DED4F40
18807	3	26	1487	17979	\N	\N	64.178976000000006	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Матигорское"", дер.Горка, д.43А"		0101000020E6100000BB09BE69FAD8444036B1C057740B5040
18829	3	26	1487	19126	\N	\N	63.443381000000002	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Зачачьевское"", дер.Верхняя Горка, д.7"		0101000020E610000019761893FEE244407A5567B5C0B84F40
18791	3	26	1487	17181	\N	\N	64.323922999999994	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Кехотское"", дер.Васильевская, д.165"		0101000020E610000085268925E588444005DB8827BB145040
18823	3	26	1487	57501	\N	\N	63.825892000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Емецкое"", пос.Ваймужский, д.40"		0101000020E6100000B39597FC4F14454097033DD4B6E94F40
18826	3	26	1487	57503	\N	\N	63.825892000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Хаврогорское"",  дер.Бушковы, д.4"		0101000020E6100000B39597FC4F14454097033DD4B6E94F40
18819	3	26	1487	18586	58790	\N	63.733325000000001	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ракульское"", пос.Брин-Наволок, ул.Набережная, д.31"		0101000020E61000005951836918B644406B2BF697DDDD4F40
18802	3	26	1487	17743	\N	\N	64.225925000000004	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Ломоносовское"", дер.Боярская, д.16"		0101000020E610000071C806D2C5EC44405396218E750E5040
18820	3	26	1487	18673	\N	\N	63.625335999999997	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Емецкое"", дер.Большая Гора, д.18"		0101000020E610000018CFA0A17FCE4440778192020BD04F40
18809	3	26	1487	18095	58831	\N	64.188287000000003	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Белогорское"", пос.Белогорский, ул.Советская, д.26"		0101000020E6100000F6D214014E2B4540C4D0EAE40C0C5040
18794	3	26	1487	17338	\N	\N	64.267758000000001	"Архангельская область, Холмогорский муниципальный район, муниципальное образование """"Холмогорское"""", дер.Анашкино, д.49А"		0101000020E61000003BC269C18BC24440834F73F222115040
18756	3	26	1387	57515	59050	\N	61.378029668409397	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Плосское"", д.Левоплосская, ул. Центральная, д.39"	Россия, Архангельская область, Устьянский район	0101000020E61000005F61C1FD8009464015747B4963B04E40
18765	3	26	1387	15871	\N	\N	61.135247	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Шангальское"", д. Юрятинская, д.8Б"	Россия, Архангельская область, Устьянский район, село Юрятинская	0101000020E6100000FEB8FDF2C9B04540E9F010C64F914E40
18781	3	26	1387	16718	58959	\N	61.037761000000003	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Илезское"", пос. Шурай, ул. Первомайская, д.13"		0101000020E61000009AD024B1A4D445403A083A5AD5844E40
18767	3	26	1387	15947	58859	\N	61.129474000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Шангальское"", с. Шангалы, ул. Ленина, д.40"		0101000020E6100000416150A6D1AA454056D7A19A92904E40
18766	3	26	1387	15947	58715	\N	61.129474000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Шангальское"", с. Шангалы, ул. 50 лет Октября, д.1"		0101000020E6100000416150A6D1AA454056D7A19A92904E40
18773	3	26	1387	16262	\N	\N	61.200178000000001	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Октябрьское"", д. Чадрома, д.46"		0101000020E6100000698B6B7C2673454079B0C56E9F994E40
18780	3	26	1387	16650	\N	\N	60.808529	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Ростовско-Минское"", д. Филинская, ул. Административная, д.5"		0101000020E610000064CBF275198245400D6FD6E07D674E40
18779	3	26	1387	16567	58808	\N	60.888761000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Ростовско-Минское"", д. Ульяновская, ул. Строительная, д.2"		0101000020E61000004AF086342A8E4540EA7AA2EBC2714E40
18757	3	26	1387	15511	59030	\N	61.474957000000003	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Плосское"", пос. Студенец, ул. Школьная, д.3"		0101000020E6100000A0E238F06ADD4540CE001764CBBC4E40
18759	3	26	1387	15610	58874	\N	61.404006000000003	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Строевское"", с. Строевское, ул. Центральная, д.35"		0101000020E610000093E52494BEDA4540A3B1F677B6B34E40
18768	3	26	1387	16025	58821	\N	61.110754	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Шангальское"", пос. Советский, ул. Набережная, д.4"		0101000020E6100000253D0CAD4EA445405AF3E32F2D8E4E40
18770	3	26	1387	16126	58741	\N	61.090622000000003	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Октябрьское"", пос. Октябрьский, ул. Магистральная, д.13"		0101000020E61000002716F88A6E95454029266F80998B4E40
18772	3	26	1387	16126	58678	\N	61.090622000000003	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Октябрьское"", пос. Октябрьский, ул. Ленина, д.58"		0101000020E61000002716F88A6E95454029266F80998B4E40
18771	3	26	1387	16126	58678	\N	61.090622000000003	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Октябрьское"", пос. Октябрьский, ул. Ленина, д.43"		0101000020E61000002716F88A6E95454029266F80998B4E40
18764	3	26	1387	15852	59028	\N	61.095097000000003	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Шангальское"", д. Нижнеборская, ул. Сосновая, д.18"		0101000020E6100000B5E0455F41B045404F7974232C8C4E40
18778	3	26	1387	16557	58966	\N	60.920943999999999	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Ростовско-Минское"", д. Нагорская, ул. Школьная, д.6"		0101000020E61000008A9466F33898454045B9347EE1754E40
18789	3	26	1387	17083	58861	\N	61.333438000000001	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Лихачевское"", пос. Мирный, ул. Центральная, д.18"		0101000020E61000009F9273620F454640309FAC18AEAA4E40
18775	3	26	1387	16394	\N	\N	60.935411000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Малодорское"",д.Маренинская, д.70"		0101000020E6100000C1ABE5CE4CB64540CAA8328CBB774E40
18777	3	26	1387	57525	\N	\N	61.029736707103901	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Малодорское"",д.Малый Дор, д.10"	Россия, Архангельская область, Устьянский район, село Малый Дор	0101000020E610000046D09849D4A54540963D096CCE834E40
18776	3	26	1387	16430	58827	\N	60.962316000000001	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Малодорское"", с. Малодоры, ул. Центральная, д. 15"		0101000020E6100000091B9E5E29AB45407235B22B2D7B4E40
18784	3	26	1387	16842	58706	\N	61.078837	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Лойгинское"", пос. Лойга, ул. Садовая, д.19"		0101000020E61000001ADB6B41EF4D46407D5BB054178A4E40
18769	3	26	1387	16078	59029	\N	61.069580000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Октябрьское"", пос. Костылево, ул. Гайдара, д.7"		0101000020E6100000395E81E8499D4540543A58FFE7884E40
18785	3	26	1387	16894	58745	\N	61.112344	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Киземское"", пос. Кизема, ул. Спортивная, здание Киземского Дома культуры"		0101000020E610000053CE177B2F6846406FF3C649618E4E40
18786	3	26	1387	16894	58904	\N	61.112344	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Киземское"", пос. Кизема, ул. Советов, д.2"		0101000020E610000053CE177B2F6846406FF3C649618E4E40
18787	3	26	1387	16894	58863	\N	61.112344	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Киземское"", пос. Кизема, ул. Северная, д.5"		0101000020E610000053CE177B2F6846406FF3C649618E4E40
18790	3	26	1387	17137	58960	\N	61.456162999999997	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Синицкое"", п. Кидюга, ул. Новая, д.31"		0101000020E6100000102384471B7946409752978C63BA4E40
18751	3	26	1387	15217	58915	\N	61.482886999999998	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Череновское"", пос. Квазеньга, ул. Пионерская, д.5"		0101000020E61000000954FF2092234640EF54C03DCFBD4E40
18753	3	26	1387	15304	\N	\N	61.542754000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Череновское"", д. Кадыевская, д.44"		0101000020E610000065E1EB6B5D164640F8E28BF678C54E40
18783	3	26	1387	16739	58860	\N	61.051333999999997	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Илезское"", пос. Илеза, ул. Школьная, д.1"		0101000020E61000000F0F61FC34F245402096CD1C92864E40
18782	3	26	1387	16739	58902	\N	61.051333999999997	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Илезское"", пос. Илеза, ул. Комсомольская, д.4"		0101000020E61000000F0F61FC34F245402096CD1C92864E40
18760	3	26	1387	15644	58807	\N	61.309224	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Березницкое"", д. Едьма, пер. Школьный, д.1"		0101000020E6100000A1D79FC4E7DA4540B491EBA694A74E40
18762	3	26	1387	15731	59008	\N	61.167558	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Орловское"", д. Дубровская, ул. Орловская, д.23"		0101000020E61000006FF25B74B2D045407217618A72954E40
18758	3	26	1387	15551	\N	\N	61.431364018269598	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Строевское"", д. Грунцовская, д.1Б"	Россия, Архангельская область, Устьянский район, село Грунцовская	0101000020E6100000B16F2711E1CD4540FC5580EF36B74E40
18754	3	26	1387	15355	59058	\N	61.570765000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Бестужевское"", пос. Глубокий, ул. Школьная, д.15"		0101000020E610000050ABE80FCD044640C959D8D30EC94E40
18755	3	26	1387	15411	\N	\N	60.893023999999997	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Бестужевское"", д. Веригинская, д.22"		0101000020E6100000861C5BCF109A45408445459C4E724E40
18761	3	26	1387	15706	58809	\N	61.233817000000002	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Березницкое"", с. Березник, ул. Центральная, д.8А"		0101000020E61000003A57941282CF4540DA1F28B7ED9D4E40
18788	3	26	1387	17045	58905	\N	61.234462000000001	"Архангельская область, Устьянский муниципальный район, муниципальное образование ""Дмитриевское"", д. Алферовская, ул. Школьная, д.6"		0101000020E6100000657094BC3A594640CF13CFD9029E4E40
18750	3	26	7432	57545	59267	\N	65.021212221985607	п.Соловецкий, ул. Приморская, д.7, школа		0101000020E6100000CC9A58E02BDA4140199293895B415040
18682	3	26	1176	11974	58906	\N	64.877581000000006	Архангельская область, Приморский муниципальный район,д. Яреньга, ул. Пионерская, д.10		0101000020E6100000CD936B0A64F84240D3A57F492A385040
18671	3	26	1176	57491	\N	\N	64.412362999999999	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Лисестровское"", пос. Ширшинский, д.1"		0101000020E610000061A92EE0655E444026C5C727641A5040
18670	3	26	1176	57491	\N	\N	64.412269441232496	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Лисестровское"", пос. Ширшинский, д.21"	Россия, Архангельская область, поселок Ширшинский	0101000020E6100000FB75A73B4F5E4440E509849D621A5040
18676	3	26	1176	11691	\N	\N	64.381163000000001	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Лявленское"", дер. Хорьково, д.2"		0101000020E6100000088F368E588344407FDC7EF964185040
18672	3	26	1176	11490	58699	\N	64.475106890147103	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Уемское"", пос. Уемский, ул. Заводская, д.49"	Россия, Архангельская область, Приморский район, поселок Уемский	0101000020E6100000F833BC59836D444071C63027681E5040
18690	3	26	1176	57476	\N	\N	64.625723608641295	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Талажское"", пос. Талаги, д.5"	Россия, Архангельская область, деревня Талаги	0101000020E6100000BCCCB051D64F4440A114ADDC0B285040
18689	3	26	1176	57472	\N	\N	64.623943510536094	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Талажское"", пос. Талаги, д.29"		0101000020E6100000B4AD669DF14F444044A2D0B2EE275040
18666	3	26	1176	11199	\N	\N	64.540362999999999	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Приморское"", дер. Рикасиха, д.66"		0101000020E610000021567F8461164440FB3DB14E95225040
18684	3	26	1176	12058	\N	\N	64.809755999999993	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Летне-Золотицкое"", дер. Пушлахта, д.61"		0101000020E6100000F7ADD689CB494240586FD40AD3335040
18693	3	26	1176	57478	\N	\N	64.586814000000004	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Пустошинское"", дер. Пустошь, д. 53"		0101000020E6100000EB1C03B2D737444070B54E5C8E255040
18679	3	26	1176	28114	59052	\N	64.794917156717403	пПертоминск ул.Беломорская,д.2	Россия, Архангельская область, Приморский район, село Пертоминск	0101000020E61000003927F6D03E34434034828DEBDF325040
18691	3	26	1176	12401	\N	\N	64.964359999999999	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Патракеевское"", дер. Патракеевка, д.10"		0101000020E610000002BB9A3C6531444084640113B83D5040
18669	3	26	1176	57485	\N	\N	64.464347843094899	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Лисестровское"", дер. Окулово, д.1"		0101000020E61000007FF8F9EFC1514440A27DACE0B71D5040
18675	3	26	1176	11634	\N	\N	64.385105999999993	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Лявленское"", дер. Новинки, помещение филиала №1 МОУ ""Бобровская СОШ"""	Россия, Архангельская область, Приморский район, село Новинки	0101000020E6100000C9570229B183444093DFA293A5185040
18651	3	26	1059	10460	58670	\N	62.591152999999998	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Североонежское"", пос.Североонежск, мкр.2, д.13"		0101000020E61000002D27A1F485EC434055F7C8E6AA4B4F40
18688	3	26	1176	12291	\N	\N	65.691084000000004	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Зимне-Золотицкое"", дер. Нижняя Золотица, помещение общежития СПК РК ""Зимняя Золотица"""	Россия, Архангельская область, Приморский район, село Нижняя Золотица	0101000020E6100000E141B3EBDE1644407DB262B83A6C5040
18748	3	26	1176	57481	\N	\N	64.621927623463193	Архангельская область, город Северодвинск, село Ненокса, здание музея	Россия, Архангельская область, Приморский район, село Ненокса	0101000020E6100000F3E7DB82A5984340DE1D19ABCD275040
18680	3	26	1176	11888	\N	\N	64.644812000000002	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Пертоминское"", д. Луда, д.14"		0101000020E61000005646239F5714434060048D9944295040
18667	3	26	1176	57495	\N	\N	64.510161825011807	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Заостровское"", пос. Луговой, д.8, кв.2, помещение библиотеки"	Россия, Архангельская область, деревня Луговой	0101000020E610000053D0ED258D3744405D6A847EA6205040
18681	3	26	1176	11906	59007	\N	64.972283000000004	Архангельская область, Приморский муниципальный район д. Лопшеньга, ул. Советская, д. 62		0101000020E610000043739D465AD842403CDD79E2393E5040
18683	3	26	1176	12055	59079	\N	64.950640000000007	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Летне-Золотицкое"", дер. Летняя Золотица, ул. Нижняя, д.8"		0101000020E61000007B6649809A6A42403F912749D73C5040
18686	3	26	1176	57479	58824	\N	64.386268999999999	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Катунинское"", дер. Лахта, ул. Геологов, д.18"		0101000020E6100000C3EFA65B764E44405A9D9CA1B8185040
18697	3	26	1176	12696	58903	\N	64.598476000000005	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Ластольское"", дер. Ластола, ул. Северодвинская, д.5"		0101000020E6100000DC627E6E6824444038DC476E4D265040
18665	3	26	1176	11164	58843	\N	64.536360999999999	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Приморское"", пос. Лайский Док, ул. Хуторская, д.30"		0101000020E6100000DFF8DA334B204440647616BD53225040
18673	3	26	1176	11540	\N	\N	64.383223999999998	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Лявленское"", дер. Кузьмино, д.63"		0101000020E61000006D91B41B7D7A4440B5C2F4BD86185040
18698	3	26	1176	12747	\N	\N	64.570598000000004	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Ластольское"", дер. Конецдворье, д.61"		0101000020E6100000A92EE065861D44406F4A79AD84245040
18695	3	26	1176	57482	58828	\N	64.572861852859802	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Вознесенское"", с. Вознесенье, ул. Центральная, д.75"	Россия, Архангельская область, деревня Вознесенье	0101000020E61000006F29E78BBD2B4440C1C760C5A9245040
18687	3	26	1176	12210	\N	\N	65.689295999999999	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Зимне-Золотицкое"", дер. Верхняя Золотица, помещение основной школы"	Россия, Архангельская область, Приморский район, село Верхняя Золотица	0101000020E61000000F98874CF92E4440DF50F86C1D6C5040
18677	3	26	1176	11744	\N	\N	64.354951764709796	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Коскогорское"", пос. Боброво, МОУ Бобровская СОШ"	Россия, Архангельская область, Приморский район, село Боброво	0101000020E61000007D2079E75094444096E99788B7165040
18696	3	26	1176	12667	\N	\N	64.293409999999994	"Архангельская область, Приморский муниципальный район, муниципальное образование ""Катунинское"", пос. Беломорье, д.13"		0101000020E6100000759483D9047244407094BC3AC7125040
18747	3	26	1176	57505	\N	\N	64.266577794244796	"Архангельская область, город Северодвинск, пос.Белое Озеро, здание МОУ ""Школа №26"""	Россия, Архангельская область, Приморский район, село Белое Озеро	0101000020E6100000E5EFDE5163EC434051F52B9D0F115040
18637	3	26	1059	9833	58958	\N	62.895499999999998	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Савинское"", пос.Шелекса, ул.Привокзальная, д.15"		0101000020E6100000C2DCEEE53E274440B4C876BE9F724F40
18652	3	26	1059	10581	59067	\N	62.394826999999999	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Федовское"", п.Федово , ул.Чапыгина, д.13"		0101000020E6100000CBDB114E0BEA4340F549EEB089324F40
94409	3	26	1059	37053	\N	\N	62.156913000000003	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Кенозерское"", пос.Усть-Поча, д.61"		0101000020E6100000E1D231E7191543409CA8A5B915144F40
18662	3	26	1059	11019	59027	\N	62.6896800011585	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Ундозерское"", пос.Ундозеро, ул.Школьная, д.10"	Россия, Архангельская область, Плесецкий район, село Ундозеро	0101000020E6100000A4FCA4DAA7694340475A2A6F47584F40
18663	3	26	1059	11079	58823	\N	62.973940894371999	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Ярнемское"",  пос.Улитино, ул.Стахановская, д.16"	Россия, Архангельская область, Плесецкий район, село Улитино	0101000020E61000008507CDAE7BA94340E59D4319AA7C4F40
18650	3	26	1059	10460	\N	\N	62.591152999999998	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Североонежское"", пос.Североонежск, мкр.2, д.14"		0101000020E61000002D27A1F485EC434055F7C8E6AA4B4F40
18626	3	26	1059	57470	58612	\N	63.6095300990103	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Самодедское"" пос.Самодед, ул.Самодедская, д.12"	Россия, Архангельская область, Плесецкий район, поселок Самодед	0101000020E6100000522AE109BD40444027F73B1405CE4F40
18658	3	26	1059	10864	58804	\N	62.145153999999998	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Кенорецкое"", пос.Самково, ул.Школьная, д.11"		0101000020E6100000E107E753C75843401971016894124F40
18635	3	26	1059	9595	\N	\N	62.933371000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Савинское"", пос.Савинский, ул.40 лет Победы, д.17"	Россия, Архангельская область, Плесецкий район, поселок Савинский	0101000020E61000000C59DDEA39114440750470B378774F40
18633	3	26	1059	9595	58697	\N	62.933371000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Савинское"", пос.Савинский, ул.Цементников, д.8"		0101000020E61000000C59DDEA39114440750470B378774F40
18634	3	26	1059	9595	58713	\N	62.933371000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Савинское"", пос.Савинский, ул.40 лет Победы, д.14"		0101000020E61000000C59DDEA39114440750470B378774F40
18636	3	26	1059	9748	59001	\N	62.964024999999999	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Савинское"", пос.Река Емца, ул.Набережная, д.3"		0101000020E6100000693BA6EECA26444061C3D32B657B4F40
18647	3	26	1059	10295	58611	\N	62.592582	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Пуксоозерское"", пос.Пуксоозеро, ул.Ленина, д.5"		0101000020E610000005E10A28D44D444061191BBAD94B4F40
18644	3	26	1059	10155	58900	\N	62.602246000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Плесецкое"",  пос.Пукса, ул.Центральная, д.25Б"		0101000020E6100000180AD80E46284440CB129D65164D4F40
18660	3	26	1059	10944	58901	\N	62.192349615958598	пос.Поча, ул.Школьная, д.78	Россия, Архангельская область, Плесецкий район, село Поча	0101000020E6100000836A8313D11543405BB1BFEC9E184F40
18645	3	26	1059	10208	\N	\N	62.814276	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Тарасовское"", дер.Подволочье, д.57"		0101000020E61000007A1A3048FA94444077F52A323A684F40
18643	3	26	1059	9872	58698	\N	62.711075000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Плесецкое"",  пос.Плесецк, ул.Южная, д.2"		0101000020E61000006EE00ED42925444069006F81045B4F40
18639	3	26	1059	9872	58654	\N	62.711075000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Плесецкое"",  пос.Плесецк, ул.Фокина, д.19"		0101000020E61000006EE00ED42925444069006F81045B4F40
18641	3	26	1059	9872	9944	\N	62.711075000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Плесецкое"",  пос.Плесецк, ул.Партизанская, д.17"		0101000020E61000006EE00ED42925444069006F81045B4F40
18640	3	26	1059	9872	9944	\N	62.711075000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Плесецкое"",  пос.Плесецк, ул.Партизанская, д.6"		0101000020E61000006EE00ED42925444069006F81045B4F40
18638	3	26	1059	9872	58628	\N	62.711075000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Плесецкое"",  пос.Плесецк, ул.Ленина, д.85"		0101000020E61000006EE00ED42925444069006F81045B4F40
18630	3	26	1059	57492	\N	\N	63.583188558958099	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Обозерское"" пос.Первомайский, д.6"	Россия, Архангельская область, Плесецкий район, село Первомайский	0101000020E6100000C6DE8B2FDA0344408731E9EFA5CA4F40
18648	3	26	1059	10373	58680	\N	62.601252000000002	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Оксовское"", пос.Оксовский, ул.Школьная, д.11"		0101000020E61000006C5CFFAECFF44340CA5356D3F54C4F40
18627	3	26	1059	9343	58647	\N	63.446570000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Обозерское"", пос.Обозерский, ул.Школьная, д.11"		0101000020E610000096AFCBF09F264440F7AFAC3429B94F40
18628	3	26	1059	9343	58645	\N	63.446570000000001	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Обозерское"", пос.Обозерский, ул.Ломоносова, д.68"		0101000020E610000096AFCBF09F264440F7AFAC3429B94F40
18661	3	26	1059	10998	9868	\N	62.331530999999998	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Почезерское"", дер.Нижнее Устье, ул.Набережная, д.6А"		0101000020E610000060394206F21C43401A4E999B6F2A4F40
18625	3	26	1059	57517	59056	\N	64.009459739297597	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Холмогорское"" пос.Ломовое, ул.Школьная, д.10"		0101000020E61000005AD6FD6321544440B1A71DFE9A005040
18654	3	26	1059	10652	58857	\N	62.406322000000003	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Федовское"", пос.Липаково, ул.Октябрьская, д.12"		0101000020E6100000EA77616BB6D843409AD2FA5B02344F40
18629	3	26	1059	9430	58895	\N	63.377443	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Обозерское"", пос.Летнеозерский, ул.Лесная, д.27А"		0101000020E6100000A7CEA3E2FF2C4440548D5E0D50B04F40
18503	3	26	511	3132	58692	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Советская, д.18		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18657	3	26	1059	10826	59002	\N	62.102994000000002	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Кенорецкое"", дер.Корякино, ул.Молодёжная, д.12"		0101000020E61000001A53B0C6D970434095D74AE82E0D4F40
18655	3	26	1059	10729	59073	\N	62.124809573074302	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Коневское"", с. Конево , ул.Ленинградская, д.33"	Россия, Архангельская область, Плесецкий район, село Конево	0101000020E610000068D0D03FC1A943405C1B2AC6F90F4F40
18656	3	26	1059	10745	\N	\N	62.245280999999999	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Коневское"", пос.Коковка, здание школы"	Россия, Архангельская область, Плесецкий район, село Коковка	0101000020E6100000DC291DACFFBB434043AA285E651F4F40
18632	3	26	1059	9556	58608	\N	63.075021	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Емцовское"", пос.Емца, ул.Партизанская, д.10"		0101000020E6100000726A6798DA2A4440B1C1C2499A894F40
18659	3	26	1059	10891	\N	\N	62.078586999999999	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Кенозерское"", дер.Вершинино, здание школы"	Россия, Архангельская область, Плесецкий район, село Вершинино	0101000020E610000021B1DD3D40194340047289230F0A4F40
94408	3	26	1059	37018	59068	\N	63.190998999999998	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Емцовское"", пос.Верховский, ул.Островского, д.29"		0101000020E61000003F726BD26D0F4440CB48BDA772984F40
18649	3	26	1059	10448	58917	\N	62.615146000000003	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Оксовское"", пос.Булатово, ул.Линейная, д.18"		0101000020E61000002B69C53714FE4340F321A81ABD4E4F40
18646	3	26	1059	57514	\N	\N	62.967855999999998	"Архангельская область, Плесецкий муниципальный район, муниципальное образование ""Тарасовское"", дер.Бархатиха, д.18"		0101000020E61000002D211FF46CD04340629E95B4E27B4F40
18592	3	26	904	57486	58882	\N	64.171474909129202	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Кушкопальское"", дер.Кушкопала, ул.Советская, д.28"	Россия, Архангельская область, Пинежский район, река Пинега	0101000020E61000007A354069A841464039454772F90A5040
18607	3	26	904	8449	59082	\N	64.035932000000003	"Архангельская область, Пинежский муниципальный район, муниципальное образование """"Шилегское"""", пос.Ясный, ул.Октября, д.12"		0101000020E61000007898F6CDFD0946405038BBB54C025040
18589	3	26	904	7584	\N	\N	63.709462000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Лавельское"", дер.Явзора, д.28"		0101000020E610000063D34A2190B546409CE09BA6CFDA4F40
18583	3	26	904	7299	58862	\N	63.520488	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сурское"", пос.Шуйга, ул.Строительная, д.8Б"		0101000020E6100000F38FBE49D3D84640F0FACC599FC24F40
18610	3	26	904	8581	59000	\N	64.174361000000005	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пиринемское"", дер.Шотогорка, ул.Центральная, д.5"		0101000020E6100000DCA0F65B3B174640AA2C0ABB280B5040
18601	3	26	904	8139	59034	\N	64.014505	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Карпогорское"", дер.Шотова, ул.Боровая, д.11"		0101000020E610000082548A1D8D294640392861A6ED005040
18612	3	26	904	8667	58890	\N	64.294842000000003	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пиринемское"", пос.Широкое, ул.Центральная, д.28"		0101000020E61000005B5EB9DE364F46402FDFFAB0DE125040
18596	3	26	904	7859	58899	\N	63.907609999999998	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Карпогорское"", дер.Шардонемь, ул.Центральная, д.139"		0101000020E610000094BC3AC7804C4640E3C281902CF44F40
18614	3	26	904	8748	59026	\N	64.319320000000005	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пиринемское"", дер.Чакола, ул.Центральная, д.23"		0101000020E61000009CA56439092946405C3D27BD6F145040
18615	3	26	904	8798	58891	\N	64.480720000000005	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Труфаногорское"", дер.Труфанова, ул.Центральная, д.27"		0101000020E6100000718DCF64FF0A46401FA2D11DC41E5040
18616	3	26	904	8839	58892	\N	64.769419999999997	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пинежское"", пос.Тайга, ул.Лесная, д.4А"		0101000020E6100000EEB1F4A10BBE4540DA38622D3E315040
18608	3	26	904	8464	\N	\N	64.045208000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Шилегское"", пос.Таежный, д.8А"		0101000020E6100000098D60E3FA034640206118B0E4025040
18604	3	26	904	8288	58817	\N	63.824601999999999	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сийское"", пос.Сылога, ул.Северная, д.7"		0101000020E610000048A98427F4D44540AC1BEF8E8CE94F40
18585	3	26	904	7372	58816	\N	63.574506	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сурское"", с.Сура, пер.Школьный, д.9"		0101000020E6100000C51F459DB9D146408AADA06989C94F40
18581	3	26	904	7212	58889	\N	63.442923	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сосновское"", дер.Сульца, ул.Южная, д.37А"		0101000020E610000096B377465BFF4640B7D26BB3B1B84F40
12881	7	66	215	18226	62733	\N	55.172860999999997	д.Полевой Сундырь, Набережная, 8		0101000020E6100000986C3CD862D547407EE02A4F20964B40
18579	3	26	904	7076	58841	\N	63.418101999999998	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сосновское"", пос.Сосновка, ул.Школьная, д.3"		0101000020E610000013807F4A951247403332C85D84B54F40
18605	3	26	904	8363	\N	\N	64.028969000000004	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сийское"", пос.Сия, д.15"		0101000020E61000005A84622B6896454043E6CAA0DA015040
18606	3	26	904	8372	58802	\N	63.896301000000001	"Архангельская область, Пинежский муниципальный район, муниципальное образование """"Шилегское"""", пос.Русковера, ул.Пионерская, д.9"		0101000020E6100000C00303081F104640A12FBDFDB9F24F40
18611	3	26	904	57511	59048	\N	64.229705703265694	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пиринемское"", дер.Пиринемь, ул.Школьная, д.1"	Россия, Архангельская область, Пинежский район, село Пиринем	0101000020E6100000D74B5304381D46407A6CCB80B30E5040
18621	3	26	904	8967	58644	\N	64.697400000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пинежское"", пос.Пинега, ул.Первомайская, д.111"		0101000020E6100000A530EF71A6B14540BF0E9C33A22C5040
18619	3	26	904	8967	58644	\N	64.697400000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пинежское"", пос.Пинега, ул.Первомайская, д.36"		0101000020E6100000A530EF71A6B14540BF0E9C33A22C5040
18623	3	26	904	9172	\N	\N	64.584181000000001	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пинежское"", дер.Петрово, д.4"		0101000020E6100000289EB30584AE4540747CB43863255040
18591	3	26	904	57490	58898	\N	63.621772108352097	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Кушкопальское"", пос.Пачиха, ул.Лесная, д.1"	Россия, Архангельская область, Пинежский район, село Пачиха	0101000020E610000082E7DEC325334640C5C8923996CF4F40
18586	3	26	904	7442	59077	\N	63.613630000000001	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Лавельское"", пос.Новолавела, ул.Советская, д.1"		0101000020E610000091EF52EA92C3464018EC866D8BCE4F40
18595	3	26	904	7848	\N	\N	63.978935	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Кеврольское"", дер.Немнюга, д.41А"		0101000020E61000000917F2086E34464073F4F8BD4DFD4F40
18602	3	26	904	8198	58573	\N	64.049809999999994	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Междуреченское"", пос.Междуреченский, ул.Центральная, д.11"		0101000020E61000007E02284696364640E140481630035040
18580	3	26	904	7160	59023	\N	63.413967999999997	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сосновское"", пос.Мамониха, ул.Ленина, д.10"		0101000020E6100000EE3EC7478B0F474096CB46E7FCB44F40
18582	3	26	904	7251	58999	\N	63.44209	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сосновское"", пос.Кулосега, ул.Садовая, д.8"		0101000020E61000000E881057CEF24640BFF1B56796B84F40
18617	3	26	904	8882	58896	\N	64.883285999999998	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пинежское"", пос.Кривые Озера, ул.Центральная, д.18"		0101000020E61000003D81B053AC9E4540F0C000C287385040
18622	3	26	904	9106	\N	\N	64.593394000000004	"Архангельская область, Пинежский муниципальный район, муниципальное образование """"Пинежское"""", пос. Красная Горка, д.6"		0101000020E6100000990F087426A5454021E9D32AFA255040
18603	3	26	904	8233	\N	\N	63.991737000000001	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Покшеньгское"", дер.Кобелево, д.43А"		0101000020E6100000CF488446B0214640D89DEE3CF1FE4F40
18594	3	26	904	7769	\N	\N	63.953494999999997	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Кеврольское"", дер.Кеврола, д.67"		0101000020E61000005051F52B9D41464023F3C81F0CFA4F40
18600	3	26	904	8024	58606	\N	64.005257999999998	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Карпогорское"", с.Карпогоры, ул.Ф.Абрамова, д.49"		0101000020E610000057772CB649394640B682A62556005040
18599	3	26	904	8024	58606	\N	64.005257999999998	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Карпогорское"", с.Карпогоры, ул.Ф.Абрамова, д.45А"		0101000020E610000057772CB649394640B682A62556005040
18624	3	26	904	9206	\N	\N	64.513694999999998	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пинежское"", дер.Заозерье, д.3"		0101000020E6100000FE0A992B83A245409947FE60E0205040
18578	3	26	904	7057	58953	\N	63.434621	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Нюхченское"", дер.Занюхча, ул.Школьная, д.2"		0101000020E6100000F7065F984C454740D19332A9A1B74F40
18588	3	26	904	7519	\N	\N	63.627988999999999	"Архангельская область, Пинежский муниципальный район, муниципальное образование """"Лавельское"""", дер.Заедовье, д.25"		0101000020E61000005FB7088CF5C34640B69F8CF161D04F40
18593	3	26	904	7743	59024	\N	63.892296000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Кушкопальское"", дер.Ёркино, ул.Новая, д.37А"		0101000020E61000002DB5DE6FB4574640022D5DC136F24F40
18584	3	26	904	7357	59025	\N	63.570703000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Сурское"", дер.Городецк, ул.Лесная, д.4"		0101000020E61000001C40BFEFDFD84640535DC0CB0CC94F40
12880	7	66	215	18174	62731	\N	55.1937	д.Полевое Шептахово, Кооперативная, 2		0101000020E6100000F31E679AB0CF47401B9E5E29CB984B40
18618	3	26	904	8925	58955	\N	64.720873999999995	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пинежское"", дер.Воепала, ул.Окружная, д.10"		0101000020E6100000D927806264B3454059A2B3CC222E5040
18590	3	26	904	7599	58919	\N	63.805962999999998	"Архангельская область, Пинежский муниципальный район, муниципальное образование """"Веркольское"""", дер.Веркола, ул.Советская, д.7"		0101000020E6100000F5F6E7A2219146409D64ABCB29E74F40
18613	3	26	904	8733	\N	\N	64.287604000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Пиринемское"", дер.Веегора, д.75"		0101000020E610000051DCF126BF294640B98C9B1A68125040
18597	3	26	904	7931	58819	\N	63.972332000000002	"Архангельская область, Пинежский муниципальный район, муниципальное образование ""Карпогорское"", дер.Ваймуша, ул.Гагарина, д.15"		0101000020E610000006F2ECF2AD414640596DFE5F75FC4F40
18559	3	26	715	6115	58954	\N	63.180055000000003	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", пос.Шомокша, ул.Комсомольская, д.7А"		0101000020E6100000FA25E2ADF39343409B3DD00A0C974F40
18563	3	26	715	6321	58887	\N	63.704859999999996	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Нименьгское"", пос.Шаста, ул.Школьная, д.10"		0101000020E6100000CDAE7B2B12EB424018213CDA38DA4F40
18555	3	26	715	5885	58894	\N	63.413344000000002	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Хачела, ул.Набережная, д.12"		0101000020E61000006D1E87C1FC894340B9FFC874E8B44F40
18551	3	26	715	5686	59018	\N	63.632171999999997	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Порожское"", дер.Усть-Кожа, ул.Школьная, д.8"		0101000020E6100000A7255646235D434034B91803EBD04F40
18570	3	26	715	6670	58997	\N	63.790993999999998	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Золотухское"", пос.Унежма, ул.Горная, д.1"		0101000020E610000083F6EAE3A151424086AA984A3FE54F40
18572	3	26	715	6791	58976	\N	64.163701000000003	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Покровское"", с.Тамица, ул.Мира, д.39"		0101000020E6100000904C874ECF034340A454C2137A0A5040
18574	3	26	715	6852	58998	\N	64.381209999999996	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Покровское"", дер.Пурнема, ул.Победы, д.30"		0101000020E6100000FA0AD28C45B742401FBAA0BE65185040
18561	3	26	715	6219	58884	\N	63.041514999999997	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Прошково, ул.Набережная, д.5"		0101000020E6100000C84274081CA743408FA50F5D50854F40
18558	3	26	715	6036	58886	\N	63.231392	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Прилуки, ул.Школьная, д.1"		0101000020E61000002DEDD45C6E9043402C47C8409E9D4F40
18560	3	26	715	6136	59020	\N	63.1107171968386	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Посад, ул.Молодежная, д.14"	Россия, Архангельская область, Онежский район, село Посад	0101000020E610000076887FD8D29D43403D0E83F92B8E4F40
18550	3	26	715	52676	58974	\N	63.833001000000003	"Архангельская область, Онежский район, Онежский муниципальный район, муниципальное образование ""Порожское"", с.Порог, ул.Победы, д.39"		0101000020E6100000842C0B26FE3C43408544DAC69FEA4F40
18571	3	26	715	6731	58933	\N	64.015895999999998	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Покровское"", пос.Покровское, ул.Усачёва, д.3"		0101000020E6100000357BA015180E4340C808A87004015040
18577	3	26	715	6731	59063	\N	64.016651375160905	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Покровское"", пос. Верхнеозерский, ул.Мира, д.10"	Россия, Архангельская область, Онежский район, село Покровское	0101000020E6100000211E8997A70D4340861C5BCF10015040
18539	3	26	715	4987	58605	\N	63.903568819845702	Архангельская область, Онежский муниципальный район, г. Онега, просп.Октябрьский, д.147	Россия, Архангельская область, Онежский район, Онега	0101000020E6100000D3C1FA3F870D4340F7562426A8F34F40
18545	3	26	715	4987	58956	\N	63.9167878970404	Архангельская область, Онежский муниципальный район, г.Онега, ул.Целинная, д.3/11	Россия, Архангельская область, Онежский район, Онега	0101000020E610000043C6A354C20D4340C0AE264F59F54F40
18542	3	26	715	4987	58726	\N	63.930694210981301	Архангельская область, Онежский муниципальный район, г.Онега, ул.Приморская, д.1	Россия, Архангельская область, Онежский район, Онега	0101000020E61000007B2E5393E0074340AE4A22FB20F74F40
18544	3	26	715	4987	58601	\N	63.919744999999999	Архангельская область, Онежский муниципальный район, г.Онега, ул.Онежская, д.14		0101000020E6100000DBF7A8BF5E0B43406BD44334BAF54F40
18562	3	26	715	6258	58805	\N	63.717874999999999	"Архангельская область,  Онежский муниципальный район, муниципальное образование ""Нименьгское"", пос.Нименьга, ул.Центральная, д.29"		0101000020E610000012C2A38D23D24240D9CEF753E3DB4F40
18547	3	26	715	5454	58803	\N	63.780273999999999	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Кодинское"", пос.Мудьюга, ул.Железнодорожная, д.32"		0101000020E6100000234C512E8D9F4340A5F5B704E0E34F40
18565	3	26	715	6434	58604	\N	63.706840999999997	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Малошуйское"", пос.Малошуйка, ул.Ленина, д.69"		0101000020E6100000D829560DC2BA4240683C11C479DA4F40
18575	3	26	715	6914	\N	\N	64.154882999999998	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Покровское"",пос.Маложма, д.22А"		0101000020E61000000CCD751A6925434035ED629AE9095040
18573	3	26	715	6800	58907	\N	64.300111999999999	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Покровское"", дер.Кянда, ул.Школьная, д.15"		0101000020E6100000603FC4060B0D4340C748F60835135040
18568	3	26	715	6513	59021	\N	63.721654999999998	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Золотухское"", пос.Куша, ул.Набережная, д.22"		0101000020E6100000FF942A51F686424058FFE7305FDC4F40
18546	3	26	715	5385	58638	\N	63.720742999999999	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Кодинское"", пос.Кодино, ул.Пролетарская, д.25"		0101000020E61000002AA913D044D2434014E97E4E41DC4F40
18556	3	26	715	5938	59004	\N	63.392994000000002	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", пос.Ковкула, ул.Первомайская, д.26"		0101000020E6100000B306EFAB728F43401AC39CA04DB24F40
18557	3	26	715	5994	59019	\N	63.272998000000001	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Клещёво, ул.Набережная, д.4"		0101000020E61000005951836918904340CCEF3499F1A24F40
18554	3	26	715	5852	\N	\N	63.483412999999999	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Каска, д.35"		0101000020E6100000B6DAC35E288443400ABB287AE0BD4F40
18569	3	26	715	6653	58957	\N	63.696451000000003	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Золотухское"", пос.Золотуха, ул.Октябрьская, д.2"		0101000020E6100000F1D6F9B7CB7442401D226E4E25D94F40
18548	3	26	715	5538	59022	\N	63.787312	"Архангельская область, Онежский муниципальный район,муниципальное образование ""Кодинское"", пос.Глазаниха, ул.Центральная, д.2"		0101000020E610000001F73C7FDA7E4340CADFBDA3C6E44F40
18564	3	26	715	6331	58996	\N	63.891554999999997	"Архангельская область, Онежский муниципальный район,муниципальное образование ""Нименьгское"",  дер.Ворзогоры, ул.Никольская, д.11"		0101000020E61000001D91EF52EAD64240EACA67791EF24F40
18549	3	26	715	5550	59017	\N	63.857619	"Архангельская область, Онежский муниципальный район,муниципальное образование ""Порожское"", дер.Вонгуда, ул.Центральная, д.33А"		0101000020E610000037DF88EE59434340D0B69A75C6ED4F40
18552	3	26	715	5735	58975	\N	63.613146	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Большой Бор, ул.Школьная, д.3"		0101000020E61000007C478D09318F43402CD670917BCE4F40
18553	3	26	715	5782	58995	\N	63.572496000000001	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Чекуевское"", дер.Анциферовский Бор, ул.Придорожная"		0101000020E61000006A2FA2ED98824340A08B868C47C94F40
18566	3	26	715	6483	58951	\N	63.742206690037399	"Архангельская область, Онежский муниципальный район, муниципальное образование ""Малошуйское"", дер.Абрамовская, ул.Победы, д.6"	Россия, Архангельская область, Онежский район, село Абрамовская	0101000020E6100000AF7B2B1213B442405FEE93A300DF4F40
18524	3	26	511	57507	59016	\N	61.932468211854101	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", ж.-д.ст.Шожма, ул.Школьная, д.14"	Россия, Архангельская область, Няндомский район, село Шожма	0101000020E6100000A6F27684D32044408448861C5BF74E40
18517	3	26	511	3872	58948	\N	61.810085000000001	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Няндомское"", пос.Шестиозерский, ул.Вокзальная, д.13"		0101000020E6100000CB0F5CE5091A444076FD82DDB0E74E40
18528	3	26	511	4373	58710	\N	62.225386999999998	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", пос.Шалакуша, ул.Заводская, д.12"		0101000020E6100000D8800871E5204440C6F8307BD91C4F40
18527	3	26	511	4373	58710	\N	62.225386999999998	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", пос.Шалакуша, ул.Заводская, д.10"		0101000020E6100000D8800871E5204440C6F8307BD91C4F40
18526	3	26	511	4352	59013	\N	62.12323	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", дер.Федосеевская, ул.Центральная, д.40"		0101000020E6100000014C1938A05544406BF12900C60F4F40
18531	3	26	511	57488	58883	\N	62.497710826873401	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", л/пос.Тарза, ул.Строителей, д.8"	Россия, Архангельская область, Няндомский район, село Тарза	0101000020E61000006534F279C537444003EE79FEB43F4F40
18532	3	26	511	4653	58950	\N	62.255119999999998	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", дер.Ступинская, ул.Советская, д.7"		0101000020E61000003B70CE88D26844401B47ACC5A7204F40
18520	3	26	511	3999	58812	\N	61.791159	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Мошинское"", дер.Петариха, ул.Школьная, д.2"		0101000020E6100000B8921D1B816C4440D177B7B244E54E40
18514	3	26	511	3132	58609	\N	61.633062085774	Архангельская область, Няндомский муниципальный район, г.Няндома, мкр.Каргополь-2, ул.Школьная, д.1		0101000020E6100000232E008DD2254440912BF52C08D14E40
12899	7	66	215	19175	62790	\N	55.233598000000001	д.Подлесные Чурачики, Колхозная, 35		0101000020E6100000925D6919A9B147409C340D8AE69D4B40
18513	3	26	511	3132	59015	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Песочная, д.7		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18511	3	26	511	3132	79527	\N	61.664534904083098	ул. Морозова д.13	Россия, Архангельская область, Няндомский район, Няндома	0101000020E6100000BE6BD097DE18444010069E7B0FD54E40
18509	3	26	511	3132	58695	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.Ленина, д.49		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18507	3	26	511	3132	58639	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.60-летия Октября, д.20А		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18504	3	26	511	3132	58639	\N	61.667636000000002	Архангельская область, Няндомский муниципальный район, г.Няндома, ул.60-летия Октября, д.14		0101000020E6100000681F2BF86D1A4440EED0B01875D54E40
18523	3	26	511	4181	58949	\N	61.879781999999999	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Мошинское"", дер.Наволок, ул.Молодежная, д.7"		0101000020E610000025CB49287D71444003CE52B29CF04E40
18529	3	26	511	57484	58870	\N	62.2964776786255	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", л/пос.Лепша-Новый, ул.Советская, д.5"	Россия, Архангельская область, Няндомский район, село Лепша-Новый	0101000020E6100000A22424D2362A4440E3FDB8FDF2254F40
18525	3	26	511	57489	58885	\N	62.042661000000003	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", ж.-д.ст.Лельма, ул. Лесная, д. 2"	Россия, Архангельская область, Няндомский район, село Лельма	0101000020E61000004757E9EE3A1F444047E867EA75054F40
18530	3	26	511	4546	58994	\N	62.412712999999997	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Шалакушское"", пос.Ивакша, пер.Клубный, д.2"		0101000020E61000003961C2685630444028D192C7D3344F40
18521	3	26	511	40301	9757	\N	61.835681726841898	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Мошинское"", пос.Заозерный, ул.Лесная д.18"	Россия, Архангельская область, Няндомский район, село Заозерный	0101000020E6100000A54DD53DB26B44408DEDB5A0F7EA4E40
18518	3	26	511	3908	58947	\N	61.690108000000002	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Мошинское"", дер.Волковская, ул.Центральная, д.9"		0101000020E6100000307F85CC957D44409F5A7D7555D84E40
18516	3	26	511	57477	58806	\N	61.509425	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Няндомское"", ж.-д.ст.Бурачиха, пер.Лесной, д.19"	Россия, Архангельская область, Няндомский район, село Бурачиха	0101000020E6100000D9B0A6B2281C4440E561A1D634C14E40
18519	3	26	511	3950	58993	\N	61.75582	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Мошинское"", дер.Большой Двор, ул.Центральная, д.1"		0101000020E610000032056B9C4D794440D4D4B2B5BEE04E40
18515	3	26	511	3782	58920	\N	61.613489999999999	"Архангельская область, Няндомский муниципальный район, муниципальное образование ""Няндомское"", дер.Андреевская, ул.Новая, д.4А"		0101000020E6100000895C70067F07444026361FD786CE4E40
18466	3	26	41	954	58991	\N	65.287654000000003	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Совпольское"", д.Чижгора, ул.Центральная, д.8"		0101000020E6100000AF0B3F389FF8454012A452EC68525040
18461	3	26	41	676	\N	\N	65.328999999999994	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Целегорское"", д.Целегора, д.49"		0101000020E61000009E0B23BDA8914640931804560E555040
18468	3	26	41	1061	58992	\N	65.777242000000001	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Соянское"", д.Сояна, ул.Октябрьская, д.25"		0101000020E61000005455682096B34540F8C43A55BE715040
18465	3	26	41	905	58990	\N	65.670248000000001	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Сафоновское"", д.Сафоново, ул.Новая, д.12"		0101000020E61000007EFD101B2CD84740670DDE57E56A5040
18472	3	26	41	1294	58946	\N	66.040176000000002	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Ручьевское"", с.Ручьи, ул.Советская, д.40"		0101000020E6100000DFC2BAF1EE9C444062855B3E92825040
18464	3	26	41	837	\N	\N	65.773604000000006	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Мосеевское"", д.Мосеево, д.13"		0101000020E61000000114234BE616474082035ABA82715040
18447	3	26	41	32308	58596	\N	65.854118999999997	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Мезенское"",г.Мезень, ул.Садовая, д.9"		0101000020E6100000FCDEA63FFB1D46401AF9BCE2A9765040
18449	3	26	41	32308	58815	\N	65.854118999999997	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Мезенское"", г.Мезень, ул.Набережная, д.17"		0101000020E6100000FCDEA63FFB1D46401AF9BCE2A9765040
18450	3	26	41	32448	\N	\N	65.693157999999997	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Мезенское"", д.Лампожня, д.23"		0101000020E6100000643C4A253C2946407D3D5FB35C6C5040
18471	3	26	41	1167	\N	\N	66.381260999999995	Архангельская область, Мезенский муниципальный район, с.Койда, дом №121-а, здание МУК "Соянский Дом Культуры"		0101000020E6100000537B116DC7464540608F899466985040
13129	7	66	\N	61	61787	\N	56.107236999999998	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Баумана, д.4		0101000020E610000000C974E8F4A64740E8F527F1B90D4C40
18458	3	26	41	468	58988	\N	65.512591	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Козьмогородское"", д.Козьмогородское, ул.Набережная, д.11"		0101000020E61000003A2174D025724640554E7B4ACE605040
18456	3	26	41	332	\N	\N	65.570589999999996	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Дорогорское"", д.Кимжа, д.40"		0101000020E61000000F26C5C7274E46402D5BEB8B84645040
18453	3	26	41	178	58675	\N	65.886640999999997	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Каменское"", п.Каменка, ул.Федоркова, д.12"		0101000020E610000026A8E15B580F4640BC92E4B9BE785040
18454	3	26	41	178	58854	\N	65.886640999999997	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Каменское"", п.Каменка, ул.Свободы, д.1"		0101000020E610000026A8E15B580F4640BC92E4B9BE785040
18452	3	26	41	49	\N	\N	65.657056999999995	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Мезенское"", д.Заозерье, д.23, корп.1"		0101000020E61000003F390A1005354640E7A6CD380D6A5040
18451	3	26	41	32459	\N	\N	65.722370999999995	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Мезенское"", д.Заакакурье, д.5"		0101000020E6100000E04C4C17622F46400B2593533B6E5040
18457	3	26	41	422	58945	\N	65.570627999999999	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Жердское"", с.Жердь, ул.Торцева, д.31"		0101000020E6100000ADBF2500FF584640A48B4D2B85645040
18455	3	26	41	285	58916	\N	65.605422000000004	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Дорогорское"", с.Дорогорское, ул.Советская, д.32"		0101000020E61000004AF1F109D93F4640DA91EA3BBF665040
18467	3	26	41	1048	58799	\N	66.043312999999998	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Долгощельское"", с.Долгощелье, ул.Октябрьская, д.8"		0101000020E61000009AB67F65A5B94540779FE3A3C5825040
18463	3	26	41	794	59014	\N	65.789570999999995	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Быченское"", д.Бычье, ул.Советская, д.4"		0101000020E61000009FE5797077864640AEB7CD5488725040
18459	3	26	41	564	58989	\N	65.479806999999994	Архангельская область, Мезенский муниципальный район, д.Березник, ул.Набережная, д.8 здание Дома Культуры		0101000020E6100000950B957F2D7F464014596B28B55E5040
18462	3	26	41	733	\N	\N	65.291481000000005	"Архангельская область, Мезенский муниципальный район, муниципальное образование ""Целегорское"", д.Азаполье, д.26"		0101000020E6100000F33977BB5E964640F299EC9FA7525040
18436	3	26	1566	31800	\N	\N	65.147022000000007	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Юромское"", с.Юрома, здание администрации МО ""Юромское"""	Россия, Архангельская область, Лешуконский район, село Юрома	0101000020E610000036CD3B4ED1C94640B972F6CE68495040
18443	3	26	1566	32131	\N	\N	64.633447000000004	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Олемское"", д.Чуласа, здание медпункта"	Россия, Архангельская область, Лешуконский район, село Чуласа	0101000020E6100000CA367007EA024740F52F49658A285040
18430	3	26	1566	31532	\N	\N	64.882339000000002	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Ценогорское"", с.Ценогора, здание администрации МО ""Ценогорское"""	Россия, Архангельская область, Лешуконский район, село Ценогора	0101000020E6100000D4D4B2B5BE5A4740103FFF3D78385040
18444	3	26	1566	32184	\N	\N	64.608030999999997	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Олемское"", п.Усть-Чуласа, здание клуба"	Россия, Архангельская область, Лешуконский район, село Усть-Чуласа	0101000020E61000009BE271512D08474011FDDAFAE9265040
18428	3	26	1566	31432	\N	\N	64.834481999999994	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Койнасское"", д.Усть-Кыма, здание клуба"	Россия, Архангельская область, Лешуконский район, село Усть-Кыма	0101000020E6100000E9EDCF4543BE474071C6302768355040
18433	3	26	1566	31670	\N	\N	64.926496999999998	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Лешуконское"", д.Смоленец, здание клуба"	Россия, Архангельская область, Лешуконский район, село Смоленец	0101000020E61000003410CB660EDF4640E5B512BA4B3B5040
18431	3	26	1566	52445	\N	\N	64.954583999999997	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Ценогорское"", д.Селище, здание клуба-медпункта"	Россия, Архангельская область, Лешуконский район, село Селище	0101000020E61000004792205C012D47403B527DE7173D5040
18165	3	26	1566	57506	58978	\N	64.816703000000004	"Архангельская область,Верхнетоемский муниципальный район, муниципальное образование ""Выйское"", пос.Северный, ул.Центральная, д.2А"		0101000020E61000006346787B10544840E3E2A8DC44345040
18421	3	26	1566	31120	\N	\N	64.508857000000006	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Вожгорское"",д.Родома, здание библиотеки-клуба"	Россия, Архангельская область, Лешуконский район, село Родома	0101000020E610000033897AC1A7474840CE55F31C91205040
18380	3	26	1643	29126	58856	\N	61.569172000000002	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Алексеевское"", дер.Фроловская, ул.Придорожная, д.12"		0101000020E6100000535E2BA1BBF0464043E6CAA0DAC84E40
18432	3	26	1566	31653	\N	\N	64.981945999999994	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Лешуконское"", д.Пылема, здание медпункта"	Россия, Архангельская область, Лешуконский район, село Пылема	0101000020E610000050A912656FFD4640081C0934D83E5040
18438	3	26	1566	21940	\N	\N	65.229743999999997	"Архангельская область, Лешуконский муниципальный район, муниципальное образование """"Юромское"""", д.Палуга, здание клуба"	Россия, Архангельская область, Лешуконский район, село Палуга	0101000020E6100000EB3713D385A24640F19C2D20B44E5040
18445	3	26	1566	32196	\N	\N	64.488438000000002	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Олемское"", с.Олема, здание администрации МО ""Олемское"""	Россия, Архангельская область, Лешуконский район, село Олема	0101000020E6100000399B8E006E144740EA077591421F5040
18442	3	26	1566	29223	58569	\N	64.900704085164605	"Архангельская область, Лешуконский муниципальный район, муниципальное образование """"Лешуконское"""", с.Лешуконское, ул.Победы, д.35"	Россия, Архангельская область, Лешуконский район, село Лешуконское	0101000020E610000003CDE7DCEDE0464017D86322A5395040
18439	3	26	1566	29223	58569	\N	64.898787999999996	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Лешуконское"", с.Лешуконское, ул.Победы, д.12"		0101000020E61000000EDDEC0F94DF464062821ABE85395040
18440	3	26	1566	29223	58576	\N	64.898787999999996	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Лешуконское"", с.Лешуконское, ул.Октябрьская, д.28"		0101000020E61000000EDDEC0F94DF464062821ABE85395040
18424	3	26	1566	31241	\N	\N	64.637539000000004	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Койнасское"", д.Кысса, здание клуба"	Россия, Архангельская область, Лешуконский район, село Кысса	0101000020E6100000EF3A1BF2CFF047402CBB6070CD285040
18426	3	26	1566	31345	\N	\N	64.748148999999998	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Койнасское"", с.Койнас, здание администрации МО ""Койнасское"""	Россия, Архангельская область, Лешуконский район, село Койнас	0101000020E6100000D384ED2763D247403FE257ACE12F5040
18437	3	26	1566	31857	\N	\N	65.211213000000001	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Юромское"", д.Кеслома, здание клуба"	Россия, Архангельская область, Лешуконский район, село Кеслома	0101000020E6100000F6EE8FF7AAAF46405DDF8783844D5040
18446	3	26	1566	32262	\N	\N	64.351986999999994	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Олемское"", д.Кеба, здание клуба"	Россия, Архангельская область, Лешуконский район, село Кеба	0101000020E6100000FC1D8A027D1A47407F677BF486165040
18422	3	26	1566	31126	\N	\N	64.500834999999995	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Вожгорское"", п.Зубово, здание клуба"	Россия, Архангельская область, Лешуконский район, село Зубово	0101000020E61000002FE1D05B3C3E48404C6C3EAE0D205040
18425	3	26	1566	31273	\N	\N	64.672044	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Койнасское"", д.Засулье, здание школы-библиотеки"	Россия, Архангельская область, Лешуконский район, село Засулье	0101000020E61000006DE4BA29E5E74740465ED6C4022B5040
18423	3	26	1566	31199	\N	\N	64.540305000000004	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Вожгорское"",с.Вожгора, здание клуба"	Россия, Архангельская область, Лешуконский район, село Вожгора	0101000020E61000007C80EECB9939484061376C5B94225040
18435	3	26	1566	31789	\N	\N	64.989110999999994	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Лешуконское"", д.Большая Нисогора, здание школы"	Россия, Архангельская область, Лешуконский район, село Большая Нисогора	0101000020E610000038BEF6CC92C84640494739984D3F5040
18434	3	26	1566	31723	\N	\N	64.955658	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Лешуконское"", д.Березник, здание школы"	Россия, Архангельская область, Лешуконский район, село Березник	0101000020E6100000C136E2C96ECA46404A0A2C80293D5040
18429	3	26	1566	31509	\N	\N	64.920680000000004	"Архангельская область, Лешуконский муниципальный район, муниципальное образование ""Ценогорское"", д.Белощелье, здание клуба-библиотеки"	Россия, Архангельская область, Лешуконский район, село Белощелье	0101000020E6100000E8137992747D47403485CE6BEC3A5040
18401	3	26	1854	30037	58630	\N	62.179102999999998	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сафроновское"", с. Яренск, ул. Трудовая, д.32"		0101000020E6100000C976BE9F1A8B4840C8CEDBD8EC164F40
18400	3	26	1854	30037	58742	\N	62.179102999999998	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сафроновское"", с. Яренск, ул. Дубинина, д.4А"		0101000020E6100000C976BE9F1A8B4840C8CEDBD8EC164F40
18404	3	26	1854	30216	\N	\N	62.406455000000001	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сафроновское"", п. Очея, здание Очейской МОО школы"	Россия, Архангельская область, Ленский район, село Усть-Очея	0101000020E610000097AE601BF14E4840D925AAB706344F40
18418	3	26	1854	57468	58881	\N	61.785950030872797	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Урдомское"", п. Урдома, ул. Нянда, д. 26"	Россия, Архангельская область, Ленский район, село Урдома	0101000020E610000035255987A32F4840462575029AE44E40
18417	3	26	1854	57468	58607	\N	61.786631855923702	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Урдомское"", п. Урдома, ул. Мира, д.11А"	Россия, Архангельская область, Ленский район, село Урдома	0101000020E61000000DA9A278952F484058FE7C5BB0E44E40
18416	3	26	1854	30838	58714	\N	61.754359999999998	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Урдомское"", п. Урдома, ул. Вычегодская, д.45"		0101000020E6100000F5A0A014AD4448408DB454DE8EE04E40
18415	3	26	1854	30821	\N	\N	61.804904000000001	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Урдомское"", п. Тыва, здание детского сада"	Россия, Архангельская область, Ленский район, село Тыва	0101000020E6100000E9465854C4574840B535221807E74E40
18410	3	26	1854	30525	\N	\N	61.655271999999997	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сойгинское"", п. Сойга, здание Сойгинской МСО школы"	Россия, Архангельская область, Ленский район, село Сойга	0101000020E6100000D95BCAF9620F484004FEF0F3DFD34E40
18413	3	26	1854	30675	\N	\N	61.514038999999997	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сойгинское"", д. Селивановская, здание Рябовской МОО школы"	Россия, Архангельская область, Ленский район, село Селивановская	0101000020E6100000CAC0012D5DE747402CEFAA07CCC14E40
18403	3	26	1854	28871	58972	\N	62.230259540738203	п. Лысимо ул.Центральная, д.7	Россия, Архангельская область, Ленский район, село Лысимо	0101000020E61000008104C58F31774840DAC9E028791D4F40
18420	3	26	1854	31065	\N	\N	61.552171000000001	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Урдомское"", п. Лупья, здание Лупьинского клуба"	Россия, Архангельская область, Ленский район, село Лупья	0101000020E61000004968CBB9142948405A66118AADC64E40
18411	3	26	1854	30598	\N	\N	61.568773999999998	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сойгинское"", п. Литвино, здание Литвиновского клуба"	Россия, Архангельская область, Ленский район, село Литвино	0101000020E6100000FA7B293C6802484055682096CDC84E40
18406	3	26	1854	30353	\N	\N	62.076901999999997	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Козьминское"", с. Лена, здание Ленского клуба"	Россия, Архангельская область, Ленский район, село Лена	0101000020E6100000195932C7F25048409D7FBBECD7094F40
18407	3	26	1854	30372	\N	\N	61.916443000000001	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Козьминское"", с. Козьмино, здание Козьминского клуба"	Россия, Архангельская область, Ленский район, село Козьмино	0101000020E61000004A24D1CB28304840F6D214014EF54E40
18405	3	26	1854	30290	\N	\N	62.090721000000002	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сафроновское"", с. Ирта, здание Иртовского клуба"	Россия, Архангельская область, Ленский район, село Ирта	0101000020E6100000938E72309B6E4840BC07E8BE9C0B4F40
18402	3	26	1854	30131	\N	\N	62.105939999999997	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сафроновское"", п. Запань Яреньга, здание Яреньгского клуба"	Россия, Архангельская область, Ленский район, село Запань Яреньга	0101000020E61000002A00C633688048404BAB21718F0D4F40
18412	3	26	1854	30669	\N	\N	61.580542000000001	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сойгинское"", п. Запань Лупья, здание КДЦ ""На огонек"""	Россия, Архангельская область, Ленский район, село Запань Лупья	0101000020E6100000D33252EFA90648402BFA43334FCA4E40
18408	3	26	1854	30449	\N	\N	61.956921999999999	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Козьминское"", п. Гыжег, здание начальной Гыжегской школы"	Россия, Архангельская область, Ленский район, село Гыжег	0101000020E6100000B4C9E1934E34484055698B6B7CFA4E40
18419	3	26	1854	30981	\N	\N	61.476478	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Урдомское"", п. Витюнино, здание Витюнинского клуба"	Россия, Архангельская область, Ленский район, село Витюнино	0101000020E61000000E4B033FAA654840BAA1293BFDBC4E40
18414	3	26	1854	57496	\N	\N	62.083472518488001	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Урдомское"", д. Бор, здание Ошлапецкой МОО школы"	Россия, Архангельская область, Ленский район, поселок Бор	0101000020E610000073DA53724E624840AC8C463EAF0A4F40
18409	3	26	1854	30507	\N	\N	61.645612999999997	"Архангельская область, Ленский муниципальный район, муниципальное образование ""Сойгинское"", д. Белопашино, здание КДЦ ""От мала до велика"""	Россия, Архангельская область, Ленский район, село Белопашино	0101000020E610000060E811A3E70E4840AC6F6072A3D24E40
18394	3	26	1643	29763	58594	\N	61.781117000000002	"Архангельская область,  Красноборский муниципальный район, муниципальное образование ""Черевковское"",  с.Черевково, ул.Первомайская, д.36"		0101000020E6100000C6A52A6D71A14640C1AC50A4FBE34E40
18393	3	26	1643	29697	\N	\N	61.725858000000002	"Архангельская область,  Красноборский муниципальный район, муниципальное образование ""Черевковское"",  дер.Сакулинская, здание Сакулинского Дома культуры"	Россия, Архангельская область, Красноборский район, село Сакулинская	0101000020E6100000F47002D369AB46401EC539EAE8DC4E40
18397	3	26	1643	29800	\N	\N	61.839277000000003	"Архангельская область,  Красноборский муниципальный район, муниципальное образование ""Черевковское"",  дер.Савинская, здание Ракульской библиотеки-клуба"	Россия, Архангельская область, Красноборский район, село Савинская	0101000020E6100000B4E908E066AB46407BA4C16D6DEB4E40
18395	3	26	1643	29800	\N	\N	61.839277000000003	"Архангельская область,  Красноборский муниципальный район, муниципальное образование ""Черевковское"",  дер. Савинская 1, здание Фоминского ФАП"		0101000020E6100000B4E908E066AB46407BA4C16D6DEB4E40
18388	3	26	1643	29491	\N	\N	61.505940000000002	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Телеговское"", дер.Монастырская Пашня, здание Телеговской начальной школы"	Россия, Архангельская область, Красноборский район, село Монастырская Пашня	0101000020E61000000E12A27C411347407FDE54A4C2C04E40
18385	3	26	1643	29342	58849	\N	61.711739999999999	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Куликовское"", пос. Куликово, ул.Центральная, д.14"		0101000020E61000004E9D47C5FF574740A5A0DB4B1ADB4E40
18379	3	26	1643	29043	58709	\N	61.555934000000001	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Алексеевское"", с.Красноборск, ул.Плакидина, д.26"		0101000020E6100000E333D93F4FF94640035E66D828C74E40
18378	3	26	1643	29043	58568	\N	61.555934000000001	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Алексеевское"", с.Красноборск, ул.Гагарина, д.42"		0101000020E6100000E333D93F4FF94640035E66D828C74E40
18387	3	26	1643	29426	\N	\N	61.400212000000003	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Алексеевское"", пос.Комсомольский, здание Библиотеки-клуба"	Россия, Архангельская область, Красноборский район, село Комсомольский	0101000020E61000007D96E7C1DDB74640BFBB95253AB34E40
18386	3	26	1643	29385	58986	\N	61.776674999999997	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Куликовское"", пос.Комарово, ул.Терешковой, д.5"		0101000020E6100000FA6184F0686F4740764F1E166AE34E40
18389	3	26	1643	29525	58800	\N	61.537042999999997	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Телеговское"", дер.Ершевская, ул.Мира, д.10"		0101000020E6100000CD21A98592014740DAC534D3BDC44E40
18398	3	26	1643	23538	\N	\N	61.578042000000003	"Архангельская область,  Красноборский муниципальный район, муниципальное образование ""Черевковское"",  дер.Емельяновская, с/п ""Ляховский клуб"", МУК ""Черевковский центр культуры"""		0101000020E6100000BCE9961DE20F474073DBBE47FDC94E40
18381	3	26	1643	29179	58985	\N	61.582062000000001	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Алексеевское"", пос.Дябрино, ул.Первомайская, д.6А"		0101000020E61000009E7AA4C16DFB4640471FF30181CA4E40
18399	3	26	1643	20766	\N	\N	61.936706000000001	"Архангельская область,  Красноборский муниципальный район, муниципальное образование """"Черевковское"""",  дер.Демьяновская, здание клуба"	Россия, Архангельская область, Красноборский район, село Демьяновская	0101000020E6100000C77F812040964640C6FB71FBE5F74E40
18384	3	26	1643	29314	58944	\N	61.642707000000001	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Верхнеуфтюгское"",с.Верхняя Уфтюга, ул.Центральная, д.5"		0101000020E61000003CF9F4D8964F474084F4143944D24E40
18392	3	26	1643	29668	\N	\N	61.695931000000002	"Архангельская область,  Красноборский муниципальный район, муниципальное образование ""Черевковское"",  дер.Верхняя Сергиевская, здание Сергиевского Дома культуры"	Россия, Архангельская область, Красноборский район, село Верхняя Сергиевская	0101000020E610000067D7BD1589B54640E4A25A4414D94E40
18391	3	26	1643	29621	58987	\N	61.675823999999999	"Архангельская область,  Красноборский муниципальный район, муниципальное образование ""Пермогорское"",  дер.Верхнее Шилово, ул.Быстрова, д.4"		0101000020E61000008A3A730F09C546400BED9C6681D64E40
18382	3	26	1643	29231	\N	\N	61.625959999999999	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Белослудское"", дер.Большая Слудка, д.150"		0101000020E61000003CA3AD4A220D4740554D10751FD04E40
18390	3	26	1643	57524	59081	\N	61.633695044607499	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Пермогорское"", д.Большая, ул.Советская, д.7"	Россия, Архангельская область, Красноборский район, село Большая	0101000020E6100000473B6EF8DDD04640C251F2EA1CD14E40
18383	3	26	1643	29254	58913	\N	61.606825999999998	"Архангельская область, Красноборский муниципальный район, муниципальное образование ""Верхнеуфтюгское"", дер.Березонаволок, ул.Центральная, д.3"		0101000020E6100000CD052E8F35314740662E7079ACCD4E40
18293	3	26	1743	25156	59006	\N	60.943762999999997	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Мирный"", пос.Сосновка, ул.Чкалова, д.12"		0101000020E61000006C257497C40B44406116DA39CD784E40
18372	3	26	1457	24650	59080	\N	61.276211000000004	"Архангельская область, Котласский муниципальнальный район, муниципальное образование ""Шипицынское"", п.Шипицыно,ул.Первомайская, д.54"		0101000020E61000009813B4C9E1414740D2E5CDE15AA34E40
18375	3	26	1457	22930	59075	\N	61.269970999999998	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Черемушское"", пос. Черемушский, ул. Южная, д.21"		0101000020E61000009B728577B9A0474028EFE3688EA24E40
18357	3	26	1457	28097	58669	\N	61.401504000000003	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Сольвычегодское"", пос. Харитоново, ул. Кирова, д.30"		0101000020E610000023F3C81F0CC047404A9BAA7B64B34E40
18369	3	26	1457	28736	58813	\N	61.408167876697703	ул. Рубцова, д.28	Россия, Архангельская область, Котласский район, село Федотовская	0101000020E61000007364E597C12247400AA359D93EB44E40
18367	3	26	1457	28471	58797	\N	61.140149999999998	п. Удимский, ул. Советская, д. 49		0101000020E6100000D787F546ADF446406744696FF0914E40
18366	3	26	1457	28471	58797	\N	61.140149999999998	п. Удимский,ул. Советская, д. 26		0101000020E6100000D787F546ADF446406744696FF0914E40
18358	3	26	1457	22825	59076	\N	61.334443	"Архангельская область, Котласский муниципальнальный район, муниципальное образование ""Сольвычегодское"", г.Сольвычегодск, ул.Ленина, д.23"		0101000020E6100000A530EF71A675474025B03907CFAA4E40
18365	3	26	1457	28468	58877	\N	61.155467000000002	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Приводинское"", пос. Реваж, ул. Пролетарская, д.2"		0101000020E6100000CE548847E22D4740BA4DB857E6934E40
94407	3	26	1457	28299	58621	\N	61.079675999999999	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Приводинское"", пос.Приводино, ул.Рощинская, д.42"		0101000020E610000069C36169E03F47405723BBD2328A4E40
94406	3	26	1457	28299	58627	\N	61.079675999999999	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Приводинское"", пос.Приводино, ул.Мира, д.1"		0101000020E610000069C36169E03F47405723BBD2328A4E40
18370	3	26	1457	28663	58942	\N	61.394036	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Шипицынское"", дер. Печерино, ул. Южная, д.1А"		0101000020E6100000917C2590122B47402CB98AC56FB24E40
18364	3	26	1457	28396	58878	\N	61.165374999999997	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Приводинское"", дер. Медведка, ул. Центральная, д.23"		0101000020E610000027840EBA84314740BA490C022B954E40
18363	3	26	1457	28345	58876	\N	61.156635000000001	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Приводинское"", дер. Курцево, ул. Центральная, д.48"		0101000020E6100000210725CCB445474059349D9D0C944E40
18121	3	26	1457	16644	58845	\N	61.180706000000001	д.Куимиха,ул. Школьная, д. 27		0101000020E6100000FEEDB25F774647407218CC5F21974E40
18360	3	26	1457	28205	\N	\N	61.375267662348499	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Сольвычегодское"", дер. Григорово, 32"	Россия, Архангельская область, Котласский район, село Григорово	0101000020E61000000CB08F4E5D4347401F9E25C808B04E40
18352	3	26	1457	57474	58641	\N	61.251212589729398	Архангельская область, город Котлас, поселок Вычегодский, ул. Ульянова, д.27	Россия, Архангельская область, Котласский район, поселок Вычегодский	0101000020E6100000195932C7F27047403FAA61BF27A04E40
18350	3	26	1457	57474	58641	\N	61.249018999999997	Архангельская область, город Котлас, поселок Вычегодский, ул. Ульянова, д.31	Россия, Архангельская область, Котласский район, поселок Вычегодский	0101000020E61000005308E41247724740938AC6DADF9F4E40
18353	3	26	1457	57474	58681	\N	61.2493497675204	Архангельская область, город Котлас, поселок Вычегодский, ул. Ленина, д.39	Россия, Архангельская область, Котласский район, поселок Вычегодский	0101000020E61000006BB933130C714740F9A067B3EA9F4E40
18354	3	26	1457	57474	58707	\N	61.250675082362797	Архангельская область, город Котлас, поселок Вычегодский, ул. Медицинская, д.12	Россия, Архангельская область, Котласский район, поселок Вычегодский	0101000020E6100000EBE2361AC071474060764F1E16A04E40
18373	3	26	1457	24485	59041	\N	61.308709947386703	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Черемушское"", дер. Выставка, ул. Молодежная, д.12"	Россия, Архангельская область, Котласский район, село Выставка	0101000020E6100000E3FE23D3A15547405DF92CCF83A74E40
18377	3	26	1457	29014	58984	\N	61.334632999999997	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Черемушское"", пос. Борки, ул. Центральная, д.4"		0101000020E6100000D34D621058AD4740C8940F41D5AA4E40
18359	3	26	1457	28177	\N	\N	61.341853	"Архангельская область, Котласский муниципальнальный район, муниципальное образование ""Сольвычегодское"", д.Андреевская, д.42"		0101000020E610000041BB438A015847400E85CFD6C1AB4E40
18273	3	26	1743	24219	59011	\N	61.189436000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Вохтомское"", пос.Фоминский, ул.Школьная, д.8"		0101000020E6100000CD599F724C244440B05758703F984E40
18294	3	26	1743	25169	\N	\N	61.067025000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Мирный"", дер.Топоровская, здание клуба"	Россия, Архангельская область, Коношский район, село Топоровская	0101000020E6100000A01518B2BAE34340D881734694884E40
13127	7	66	\N	61	61787	\N	56.103608000000001	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Баумана, д.10		0101000020E6100000711E4E603AA747404FCDE506430D4C40
18309	3	26	1743	25909	\N	\N	60.831892000000003	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Тавреньгское"", дер.Пономаревская, здание клуба"	Россия, Архангельская область, Коношский район, село Пономаревская	0101000020E6100000B665C0594A7C4440EBE6E26F7B6A4E40
18300	3	26	1743	25462	58686	\N	61.092627	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Подюжское"", пос.Подюга, ул.Школьная, д.6"		0101000020E610000084D558C2DA6E444001DD9733DB8B4E40
18301	3	26	1743	25462	58687	\N	61.092627	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Подюжское"", пос.Подюга, ул.Советская, д.22"		0101000020E610000084D558C2DA6E444001DD9733DB8B4E40
18305	3	26	1743	25728	\N	\N	60.902647000000002	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Тавреньгское"", дер. Першинская, здание ФАП"	Россия, Архангельская область, Коношский район, село Першинская	0101000020E610000022FDF675E06C4440906AD8EF89734E40
18307	3	26	1743	25814	\N	\N	60.987364999999997	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Тавреньгское"", дер.Папинская, здание администрации"	Россия, Архангельская область, Коношский район, село Папинская	0101000020E610000074B515FBCB904440861BF0F9617E4E40
18298	3	26	1743	57516	59053	\N	61.054935727255703	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Подюжское"", пос.Норменга, ул. Центральная, д.6 кв.2"	Россия, Архангельская область, Коношский район, село Норминга	0101000020E6100000BD0166BE835D4440C0AF912408874E40
18296	3	26	1743	57520	59060	\N	61.048857300714602	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Подюжское"", пос.Новый, ул.Центральная, д.9"	Россия, Архангельская область, Коношский район, село Новый	0101000020E61000002B357BA015724440209738F240864E40
18302	3	26	1743	25563	58982	\N	61.091126000000003	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Подюжское"", дер.Николаевка, ул.Зеленая, д.10"		0101000020E61000007C2C7DE8827644405CE84A04AA8B4E40
18292	3	26	1743	25090	58897	\N	61.068758000000003	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Мирный"", пос.Мирный, ул.Юношеская, д.10"		0101000020E610000059DAA9B9DC08444050ABE80FCD884E40
18274	3	26	1743	24237	58929	\N	61.084401	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Вохтомское"", пос.Мелентьевский, ул.Школьная, д.5"		0101000020E6100000E7E44526E0234440F65FE7A6CD8A4E40
18291	3	26	1743	25045	\N	\N	60.879435999999998	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", дер.Кремлево, здание ФАП"	Россия, Архангельская область, Коношский район, село Кремлево	0101000020E6100000B378B130442A44406876DD5B91704E40
18310	3	26	1743	25947	\N	\N	60.818852999999997	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Тавреньгское"", пос.Красивое, здание клуба"	Россия, Архангельская область, Коношский район, село Красивое	0101000020E6100000AFCC5B751D744440A19DD32CD0684E40
18308	3	26	1743	25844	\N	\N	60.812254000000003	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Тавреньгское"", дер.Кощеевская, здание клуба"	Россия, Архангельская область, Коношский район, село Кощеевская	0101000020E610000074982F2FC0804440C90567F0F7674E40
18285	3	26	1743	24562	58646	\N	60.979312411342903	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", р.п. Коноша, ул.Тельмана, д.4А"	Россия, Архангельская область, Коношский район, поселок Коноша	0101000020E6100000F5F57CCD721F4440494A7A185A7D4E40
18281	3	26	1743	24562	58717	\N	60.973638000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", р.п.Коноша, ул.Советская, д.86"		0101000020E61000007E350708E62044404912842BA07C4E40
18283	3	26	1743	24562	58834	\N	60.973638000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", р.п.Коноша, ул.Садовая, д.1А"		0101000020E61000007E350708E62044404912842BA07C4E40
18284	3	26	1743	24562	58719	\N	60.973638000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", р.п.Коноша, просп.Октябрьский, д.105"		0101000020E61000007E350708E62044404912842BA07C4E40
18288	3	26	1743	24562	58818	\N	60.9737214533924	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", р.п.Коноша, ул.Новолесная, д.13"		0101000020E61000005721E527D5204440D636C5E3A27C4E40
18280	3	26	1743	24562	58716	\N	60.973638000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", р.п.Коноша, ул.Молодежная, д.8"		0101000020E61000007E350708E62044404912842BA07C4E40
18282	3	26	1743	24562	58722	\N	60.973638000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование """"Коношское"""", р.п.Коноша, ул.Лесная, д.1"	Россия, Архангельская область, Коношский район, поселок Коноша	0101000020E61000007E350708E62044404912842BA07C4E40
18287	3	26	1743	24562	58648	\N	60.973638000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", р.п.Коноша, ул.Вологодская, д.25"		0101000020E61000007E350708E62044404912842BA07C4E40
18278	3	26	1743	24456	58930	\N	60.864089999999997	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Климовское"", дер.Климовская, ул.Центральная, д.28"		0101000020E610000069E04735ECC143407B6649809A6E4E40
18304	3	26	1743	25654	\N	\N	61.162627999999998	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Подюжское"", пос.Кварзонгский, д.15, кв.1"		0101000020E6100000B7B8C667B2774440FAB48AFED0944E40
18275	3	26	1743	24307	58918	\N	61.060617000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Вохтомское"", дер.Ивакинская, ул.Победы, д.39"		0101000020E610000053B131AF23424440734A404CC2874E40
18277	3	26	1743	24326	58931	\N	60.797744000000002	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Ерцевское"", пос. Ерцево, ул.Комсомольская, д.4"		0101000020E6100000FB1F60ADDA0B4440454AB3791C664E40
18276	3	26	1743	24326	58718	\N	60.797744000000002	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Ерцевское"", пос.Ерцево, ул.Гагарина, д.20"		0101000020E6100000FB1F60ADDA0B4440454AB3791C664E40
18272	3	26	1743	57480	58826	\N	61.331771712981599	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Волошское"" пос.Волошка, ул.им. Павла Корякина, д.1"	Россия, Архангельская область, Коношский район, поселок Волошка	0101000020E610000023A46E675F0B444040DD408177AA4E40
18290	3	26	1743	57494	58928	\N	60.997655940938003	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", ст.Вересово, ул.Бовы, д.24Б, кв.2"	Россия, Архангельская область, Коношский район, село Вересово	0101000020E6100000AC1F9BE4473644403F541A31B37F4E40
18299	3	26	1743	25427	59012	\N	61.150149999999996	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Подюжское"", дер .Вельцы, ул.Новосельская, д.23"		0101000020E6100000EA25C632FD5E444048BF7D1D38934E40
18271	3	26	1743	57521	59070	\N	61.328975	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Волошское"" пос. Вандыш, ул.Юбилейная, д.2"		0101000020E61000007D08AA46AF204440CE1951DA1BAA4E40
18306	3	26	1743	25764	\N	\N	60.756225000000001	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Тавреньгское"", дер.Бор, здание клуба"	Россия, Архангельская область, Коношский район, село Бор	0101000020E61000000ABFD4CF9B8E444074B515FBCB604E40
18279	3	26	1743	24497	\N	\N	60.898026999999999	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Климовское"", дер.Ануфриево, здание конторы к\\х ""Надежда"""	Россия, Архангельская область, Коношский район, село Ануфриево	0101000020E6100000239EEC6646D3434066F6798CF2724E40
18250	3	26	1570	57512	\N	\N	61.850245733233699	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", пос.Зелёный Бор, д.13"		0101000020E6100000D6726726186E434004C765DCD4EC4E40
18264	3	26	1570	23751	59042	\N	61.871138999999999	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ошевенское"", дер.Ширяиха, ул.Центральная, д.18 Б"		0101000020E610000015C440D7BE62434094A2957B81EF4E40
18260	3	26	1570	23594	58855	\N	61.910755000000002	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Приозерное"", дер.Шелоховская, ул.Советская, д.13"		0101000020E61000002B8881AE7D8D434091D5AD9E93F44E40
18262	3	26	1570	23670	58981	\N	61.720488000000003	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Приозерное"", дер.Усачевская, ул.Молодёжная, д.10"		0101000020E610000005A568E55E9E43408A9466F338DC4E40
18263	3	26	1570	23723	59040	\N	61.788772999999999	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Приозерное"", дер.Трофимовская, ул.Архангельская, д.34"		0101000020E61000002D077AA86D954340E17B7F83F6E44E40
18256	3	26	1570	23369	59010	\N	61.217740999999997	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Тимошинская, ул.1-линия, д.1"		0101000020E610000022FE614B8F704340C9FFE4EFDE9B4E40
18261	3	26	1570	23612	58924	\N	61.945698999999998	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Приозерное"", дер.Семеновская, пер.Садовый, д.1"		0101000020E61000004CDF6B088E7F4340116E32AA0CF94E40
18246	3	26	1570	57546	59287	\N	61.3503321814134	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", пос.Пригородный, ул.Труда, д.10"	Россия, Архангельская область, Каргопольский район	0101000020E6100000917D9065C17C4340035FD1ADD7AC4E40
18265	3	26	1570	23801	\N	\N	61.755378	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ошевенское"", дер.Погост Наволочный, д.32"		0101000020E61000004B3ACAC16C5C4340170FEF39B0E04E40
18252	3	26	1570	23221	58923	\N	61.611680999999997	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Петровская, ул.Петровская, д.53"	Россия, Архангельская область, Каргопольский район, село Петровская	0101000020E610000002D4D4B2B5684340D34A21904BCE4E40
18266	3	26	1570	23831	58853	\N	61.188673000000001	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ухотское"", дер.Песок, ул.Центральная, д.3"		0101000020E6100000F1660DDE57494340B151D66F26984E40
18269	3	26	1570	23984	\N	\N	61.270615999999997	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ухотское"", дер.Патровская, д.112"		0101000020E610000037FE4465C34A43401DE38A8BA3A24E40
18270	3	26	1570	24056	\N	\N	61.422096000000003	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ухотское"", дер.Осташевская, д.14"		0101000020E6100000469A7807784A4340DFE2E13D07B64E40
18259	3	26	1570	23531	58914	\N	61.220708000000002	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Печниковское"", дер.Морщихинская, ул.Западная, д.24"		0101000020E6100000A0353FFED270434098FBE428409C4E40
18247	3	26	1570	22964	59032	\N	61.133065999999999	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Лукино, ул.9 Мая, д.13"		0101000020E6100000CBF44BC45B5D4340D21A834E08914E40
18254	3	26	1570	23287	58973	\N	61.483775999999999	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Лазаревская, ул.Береговая, д.8"		0101000020E61000006021736550BD43407B4B395FECBD4E40
18268	3	26	1570	23964	58830	\N	60.948293999999997	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ухотское"", дер.Кречетово, ул.Советская, д.15"		0101000020E61000003D0B42791F4143401B7FA2B261794E40
18249	3	26	1570	23079	\N	\N	61.550525	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Кипрово, д.56"		0101000020E610000060048D9944774340B1506B9A77C64E40
18239	3	26	1570	22640	58744	\N	61.506473	Архангельская область, Каргопольский муниципальный район, г.Каргополь, пр.Октябрьский, д.1		0101000020E610000091D26C1E877743404CA7751BD4C04E40
18244	3	26	1570	22640	58840	\N	61.506473	Архангельская область, Каргопольский муниципальный район, г.Каргополь, пр.Октябрьский, д.112 корп.3		0101000020E610000091D26C1E877743404CA7751BD4C04E40
18245	3	26	1570	22640	58593	\N	61.506473	Архангельская область, Каргопольский муниципальный район, г.Каргополь, ул.Чеснокова, д.6		0101000020E610000091D26C1E877743404CA7751BD4C04E40
18243	3	26	1570	22640	58664	\N	61.506497237530297	Архангельская область, Каргопольский муниципальный район, г.Каргополь, ул.Семенковская, д.79	Россия, Архангельская область, Каргопольский район, Каргополь	0101000020E6100000E84CDA54DD774340D542C9E4D4C04E40
18255	3	26	1570	23353	\N	\N	61.3951138384964	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Калитинка, д.61"	Россия, Архангельская область, Каргопольский район, село Калитинка	0101000020E61000007044F7AC6B7A43408B18761893B24E40
18253	3	26	1570	23234	59009	\N	61.514750999999997	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Казаково, ул.Октябрьская, д.1"		0101000020E610000072DEFFC709914340A94A5B5CE3C14E40
18267	3	26	1570	23897	59033	\N	61.116585999999998	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ухотское"", дер.Ишуково, ул.Ишуковская, д.21"		0101000020E6100000A304FD851E634340F295404AEC8E4E40
18289	3	26	1570	24956	59035	\N	61.501303703052699	"Архангельская область, Коношский муниципальный район, муниципальное образование ""Коношское"", пос.Заречный, ул.Заречная, д.4А"	Россия, Архангельская область, Каргопольский район, поселок Заречный	0101000020E61000008718AF79557B43404FADBEBA2AC04E40
18248	3	26	1570	23013	58971	\N	61.485804000000002	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Жуковская, ул.Молодёжная, д.5"		0101000020E6100000FDF84B8BFA5843400C2252D32EBE4E40
18258	3	26	1570	23475	\N	\N	61.561413999999999	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Печниковское"", дер.Дудкинская, д.20"		0101000020E6100000B796C9703C2943401EC2F869DCC74E40
18234	3	26	1570	22395	\N	\N	61.003616000000001	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Ухотское"", дер.Григорьево, д.41"		0101000020E6100000CB8635954539434005DF347D76804E40
18257	3	26	1570	23426	58910	\N	61.557001	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Печниковское"", дер.Ватамановская, ул.Центральная, д.32"		0101000020E610000081B3942C274B43406E6B0BCF4BC74E40
18251	3	26	1570	23174	58911	\N	61.586951999999997	"Архангельская область, Каргопольский муниципальный район, муниципальное образование ""Павловское"", дер.Абакумово, ул.Центральная, д.9"		0101000020E61000007CEF6FD05E87434030293E3E21CB4E40
18238	3	26	1587	22556	\N	\N	62.522986000000003	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Заостровское"", дер.Яковлевская, д.52"		0101000020E6100000ECDADE6E49D4454008228B34F1424F40
18237	3	26	1587	22544	58869	\N	62.783999000000001	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Шидровское"", пос.Шидрово, ул.Сплавщиков, д.3"		0101000020E610000074CFBA46CB6F4540618C48145A644F40
18227	3	26	1587	22086	58927	\N	63.033737000000002	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Моржегорское"", пос.Хетово, ул.Южная, д.13"		0101000020E61000008ACDC7B5A12C454024D5777E51844F40
18224	3	26	1587	21943	58968	\N	63.005555999999999	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Усть-Ваеньгское"",  пос.Усть-Ваеньга, ул.Советская, д.10"		0101000020E6100000F75965A6B4504540F6251B0FB6804F40
18225	3	26	1587	21943	58820	\N	63.005555999999999	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Усть-Ваеньгское"", пос.Усть-Ваеньга, ул.Песочная, д.11"		0101000020E6100000F75965A6B4504540F6251B0FB6804F40
18235	3	26	1587	22429	\N	\N	62.742144000000003	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Березниковское"", дер.Усть-Вага, д.93"		0101000020E6100000D388997D1E69454019761893FE5E4F40
18229	3	26	1587	22177	58912	\N	63.009858999999999	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Моржегорское"", дер.Уйта, ул.Новая, д.1"		0101000020E6100000BBB54C86E34145401F49490F43814F40
18218	3	26	1587	21634	\N	\N	62.598557	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Рочегодское"", с.Топса, д.179"		0101000020E61000004415FE0C6FD045405CE509849D4C4F40
18228	3	26	1587	22135	58969	\N	63.029978999999997	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Моржегорское"", пос.Рязаново, ул.Центральная, д.29"		0101000020E6100000309DD66D502F45408C48145AD6834F40
18219	3	26	1587	21684	59071	\N	62.674151000000002	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Рочегодское"", пос.Рочегда, ул.Комсомольская, д.45"		0101000020E61000003882548A1DB1454069C878944A564F40
18230	3	26	1587	22219	58810	\N	62.963289000000003	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Березниковское"", пос.Пянда, ул.Школьная, д.5"		0101000020E6100000655419C6DD4C45405CCCCF0D4D7B4F40
18831	3	26	1587	19222	\N	\N	63.157406999999999	"Архангельская область, Холмогорский муниципальный район, муниципальное образование ""Зачачьевское"",  пос.Почтовое, д.7"		0101000020E61000001AE1ED4108024540AB949EE925944F40
18221	3	26	1587	21804	\N	\N	62.863931999999998	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Осиновское"", дер.Осиново, д.68"		0101000020E61000002F50526001664540E3FBE252956E4F40
18226	3	26	1587	22028	\N	\N	63.050913000000001	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Моржегорское"", дер.Моржегоры, д.84 А"		0101000020E610000045F0BF95EC1445407BF8325184864F40
18220	3	26	1587	21743	\N	\N	62.758167	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Осиновское"", дер.Конецгорье, д.42"		0101000020E610000083A44FABE89B454006F4C29D0B614F40
18222	3	26	1587	21836	58921	\N	62.915551000000001	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Осиновское"", пос.Квахтюга, ул.Зеленая, д.1"		0101000020E61000008388D4B48B8F4540F96871C630754F40
18216	3	26	1587	21548	\N	\N	62.476444999999998	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Борецкое"",  дер.Гридинская, д.33"		0101000020E61000005F79909E22F74540DEAB5626FC3C4F40
18223	3	26	1587	21541	58908	\N	62.947043000000001	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Осиновское"",  пос.Воронцы, ул.Школьная, д.13"		0101000020E6100000B7088CF50D884540EF737CB438794F40
18236	3	26	1587	22483	58825	\N	62.644331999999999	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Кицкое"", пос.Важский, ул.Школьная, д.6"		0101000020E6100000D5CC5A0A4879454015E2917879524F40
18233	3	26	1587	22267	58583	\N	62.851025	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Березниковское"", пос.Березник, ул.П.Виноградова, д.85"		0101000020E610000037C2A2224E5F4540098A1F63EE6C4F40
18232	3	26	1587	22267	58583	\N	62.851025	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Березниковское"", пос.Березник, ул.П.Виноградова, д.119"		0101000020E610000037C2A2224E5F4540098A1F63EE6C4F40
18231	3	26	1587	22267	59066	\N	62.851025	"Архангельская область, Виноградовский муниципальный район, муниципальное образование ""Березниковское"", пос.Березник, ул.Восьмое Марта, д.13"		0101000020E610000037C2A2224E5F4540098A1F63EE6C4F40
18199	3	26	1635	20725	58922	\N	61.122275000000002	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Вилегодское"", п. Широкий Прилук, ул. Ленина, д.15"		0101000020E6100000D53DB2B96A6C4840280F0BB5A68F4E40
18215	3	26	1635	21502	58980	\N	61.204312999999999	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Беляевское"", с. Шалимово, ул. Центральная, д.3"		0101000020E61000006283859334BB4740E692AAED269A4E40
18196	3	26	1635	20559	58793	\N	61.266934999999997	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Селянское"", п. Фоминский, ул. Комсомольская, д.10"		0101000020E61000000BB43BA418564840319413ED2AA24E40
18200	3	26	1635	20771	\N	\N	61.206969000000001	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Вилегодское"", д.Теринская, д.9"		0101000020E6100000FF40B96DDF2B48409624CFF57D9A4E40
18197	3	26	1635	20624	\N	\N	61.286470473233898	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Селянское"", д.Стафоровская, д.55"	Россия, Архангельская область, Вилегодский район, село Стафоровская	0101000020E610000031EE06D15A5348407FA4880CABA44E40
18195	3	26	1579	20440	58829	\N	61.995550999999999	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Федьковское"",  пос.Авнюгский, ул.Строительная, д.16"		0101000020E61000008D093197548B4640034015376EFF4E40
18198	3	26	1635	20662	58833	\N	61.263869127203598	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Селянское"", п.Сорово, ул. Профсоюзная, д.22"	Россия, Архангельская область, Вилегодский район, село Сорово	0101000020E61000006A4FC939B12F4840D0B69A75C6A14E40
18204	3	26	1635	57487	\N	\N	61.010095790152498	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Павловское"", с. Слобода, д.34 Г"	Россия, Архангельская область, Вилегодский район, село Слобода	0101000020E6100000267156444D2A484003E962D34A814E40
18207	3	26	1635	21142	58943	\N	61.100724	"Архангельская область, Вилегодский муниципальный район,муниципальное образование ""Ильинское"",  д. Сидоровская, ул. Южная, д.2"		0101000020E61000008599B67F65FB47400EF62686E48C4E40
18206	3	26	1635	21074	\N	\N	61.103881000000001	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Ильинское"", д. Подомо, здание производственной базы"	Россия, Архангельская область, Вилегодский район, село Подомо	0101000020E61000009A95ED43DE02484080D6FCF84B8D4E40
18202	3	26	1635	20872	\N	\N	61.066445999999999	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Павловское"", с.Павловск, д.26"		0101000020E61000006954E0641B1848409A79724D81884E40
18211	3	26	1635	21316	58844	\N	61.253714000000002	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Никольское"",с. Никольск, ул. Октябрьская, д.10"		0101000020E61000000B45BA9F53DC4740C8444AB379A04E40
18209	3	26	1635	21232	58750	\N	61.120632000000001	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Ильинское"", д. Мухонская, Спортивная, д.7"		0101000020E6100000EC33677DCAFB4740F06C8FDE708F4E40
18210	3	26	1635	21268	\N	\N	61.153744000000003	"Архангельская область, Вилегодский муниципальный район,муниципальное образование ""Ильинское"",  д. Кошкино, д.15Б Ф1"		0101000020E6100000946C753925EA474066FA25E2AD934E40
18213	3	26	1635	21419	58941	\N	61.387264000000002	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Никольское"", ст. Кивер, ул. Школьная, д.3"		0101000020E6100000A4FE7A8505DB47408675E3DD91B14E40
18208	3	26	1635	21183	58582	\N	61.113008999999998	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Ильинское"", с. Ильинско-Подомское, ул. Советская, д.32"		0101000020E610000093E4B9BE0FFD4740AB933314778E4E40
18212	3	26	1635	21356	\N	\N	61.306455	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Никольское"",ст. Виледь, здание клуба"	Россия, Архангельская область, Вилегодский район, поселок Виледь	0101000020E6100000583A1F9E25C247400C59DDEA39A74E40
18201	3	26	1635	20831	\N	\N	61.156664999999997	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Вилегодское"", с.Вилегодск, д.83"		0101000020E6100000EA944737C2244840C3B645990D944E40
18205	3	26	1635	21038	\N	\N	61.060063999999997	"Архангельская область, Вилегодский муниципальный район, муниципальное образование ""Павловское"", д. Быково, д. 54 А"		0101000020E6100000CB2E185C730B48405ED5592DB0874E40
18185	3	26	1579	59094	\N	\N	62.440713000000002	"Архангельская область, Верхнетоемский муниципальный район,муниципальное образование ""Тимошинское"", д.Скрипчинская, ""Тимошенский культурный центр"""		0101000020E6100000804A95287BC7464006F6984869384F40
18175	3	26	1579	19371	\N	\N	62.405988999999998	"Архангельская область, Верхнетоемский муниципальный район,муниципальное образование ""Верхнетоемское"", дер.Черный Ручей, здание Вершинской основной школы"	Россия, Архангельская область, Верхнетоемский район, село Черный Ручей	0101000020E6100000F4F8BD4D7F98464093C49272F7334F40
18179	3	26	1579	19610	\N	\N	62.447096999999999	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Двинское"", пос.Ухменьга, здание Ухменьгской основной школы"	Россия, Архангельская область, Верхнетоемский район, село Ухменьга	0101000020E6100000F6ECB94C4DA84640E29178793A394F40
18184	3	26	1579	19845	\N	\N	62.098717000000001	"Архангельская область, Верхнетоемский муниципальный район,муниципальное образование ""Тимошинское"", пос.Усть-Ерга, здание Устьерогодской начальной школы"	Россия, Архангельская область, Верхнетоемский район, село Усть-Ерга	0101000020E610000036CAFACDC4924640954737C2A20C4F40
18368	3	26	1579	19845	58952	\N	62.098717000000001	"Архангельская область, Котласский муниципальный район, муниципальное образование ""Приводинское"", пос. Ерга, ул. Северная, д.3"		0101000020E610000036CAFACDC4924640954737C2A20C4F40
18177	3	26	1579	19460	58940	\N	62.303469999999997	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Верхнетоемское"", пос.Сосновый, ул.Двинская, д.14"		0101000020E6100000910E0F61FC62464097A8DE1AD8264F40
18176	3	26	1579	19445	\N	\N	62.229629000000003	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Верхнетоемское"", пос.Сойга, д.16"		0101000020E6100000789961A3AC6F46404A9BAA7B641D4F40
18171	3	26	1579	19202	59065	\N	62.674686999999999	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование """"Горковское"""", дер.Согра, ул.Набережная, д.39"		0101000020E61000001EFB592C45184740A704C4245C564F40
12882	7	66	215	18276	61842	\N	55.15446	д.Нюргечи, Советская, 48		0101000020E6100000E9D66B7A50DA474024456458C5934B40
18182	3	26	1579	19751	\N	\N	62.01699	"Архангельская область, Верхнетоемский муниципальный район,муниципальное образование ""Тимошинское"", дер.Семеновская 1-я, здание Тимошинской основной школы"	Россия, Архангельская область, Верхнетоемский район, село Семеновская 1-я	0101000020E61000003543AA285E994640F52D73BA2C024F40
18192	3	26	1579	20311	\N	\N	62.021599000000002	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Федьковское"",  пос.Поперечка, здание центра досуга"	Россия, Архангельская область, Верхнетоемский район, село Поперечка	0101000020E61000008D5DA27A6B4E46402B508BC1C3024F40
18170	3	26	1579	19132	59039	\N	62.486288000000002	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Горковское"",п.Палова, ул.Лесная, д.29"		0101000020E610000005172B6A30134740F83768AF3E3E4F40
18167	3	26	1579	18974	58983	\N	62.738909999999997	"Архангельская область,Верхнетоемский муниципальный район, муниципальное образование ""Выйское"", пос.Осяткино, ул.Центральная, д.27"		0101000020E6100000AED9CA4BFE6D4740FB57569A945E4F40
18166	3	26	1579	57509	\N	\N	62.402511050528098	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Выйское"",дер.Окуловская, д.17Б"	Россия, Архангельская область, Верхнетоемский район, село Окулово	0101000020E610000082C7B7770D9A4640DFA3FE7A85334F40
18180	3	26	1579	19625	\N	\N	61.962533999999998	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Тимошинское"", пос.Лахома, здание Лахомской основной школы"	Россия, Архангельская область, Верхнетоемский район, поселок Лахома	0101000020E6100000A94C310741F54640DFA4695034FB4E40
18172	3	26	1579	19229	58873	\N	62.583478999999997	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Горковское"",п.Ламбас, ул.Школьная, д.7"		0101000020E61000002E573F36C9F746408E739B70AF4A4F40
18168	3	26	1579	19028	\N	\N	62.462269999999997	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Горковское"",пос.Красная, д.72Б"		0101000020E6100000A9F92AF9D861474001F6D1A92B3B4F40
18189	3	26	1579	20136	\N	\N	62.379896000000002	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Пучужское"", дер.Кондратовская, д.58"		0101000020E6100000C093162EABFA4540CCF09F6EA0304F40
18191	3	26	1579	20248	\N	\N	62.283375999999997	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Пучужское"",  пос.Кодимский, д.82"		0101000020E6100000C1FF56B263F14540533C2EAA45244F40
18193	3	26	1579	20381	58939	\N	61.780887	"Архангельская область,Верхнетоемский муниципальный район, муниципальное образование ""Федьковское"", пос.Каменное, ул.Центральная, д.13"		0101000020E61000001424B6BB076846408F6FEF1AF4E34E40
18183	3	26	1579	19794	\N	\N	62.258240000000001	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Тимошинское"",  дер.Исаковская, д.40"		0101000020E61000003082C64CA2624640704221020E214F40
18186	3	26	1579	19947	58796	\N	62.346156999999998	"Архангельская область, Верхнетоемский муниципальный район,муниципальное образование ""Сефтренское"", пос.Зеленник, ул.Набережная, д.30"		0101000020E6100000C214E5D2F8554640072461DF4E2C4F40
18181	3	26	1579	57508	\N	\N	62.089139786666003	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Тимошинское"", пос.Заруба, здание Зарубской основной школы"	Россия, Архангельская область, Верхнетоемский район, село Заруба	0101000020E6100000A99F3715A9E44640FA6184F0680B4F40
18190	3	26	1579	20196	\N	\N	62.406001000000003	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Пучужское"",  дер.Евдокимовская, д.87"		0101000020E61000002219726C3DF1454058923CD7F7334F40
18178	3	26	1579	19543	58738	\N	62.154833000000004	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Двинское"",пос.Двинской, ул.Лесная, д.20"		0101000020E6100000728C648F508F4640B9AB5791D1134F40
18187	3	26	1579	20030	\N	\N	62.335842	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Афанасьевское"",  с.Вознесенское, д.72"		0101000020E6100000A1478C9E5B1C4640C64FE3DEFC2A4F40
18174	3	26	1579	19281	58737	\N	62.241070000000001	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Верхнетоемское"",с.Верхняя  Тойма, ул.Ломоносова, д.4"		0101000020E6100000EAE8B81AD97F4640FB05BB61DB1E4F40
18173	3	26	1579	19281	58566	\N	62.241070000000001	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Верхнетоемское"", с.Верхняя  Тойма, ул.Кулижского, д.20Б"		0101000020E6100000EAE8B81AD97F4640FB05BB61DB1E4F40
18188	3	26	1579	20059	\N	\N	62.359468999999997	"Архангельская область, Верхнетоемский муниципальный район,муниципальное образование ""Афанасьевское"", дер.Бурцевская, д.55"		0101000020E61000000ADB4FC6F822464081768714032E4F40
18169	3	26	1579	19058	\N	\N	62.394077000000003	"Архангельская область, Верхнетоемский муниципальный район, муниципальное образование ""Горковское"", пос.Белореченский, здание Белореченской основной школы"	Россия, Архангельская область, Верхнетоемский район, село Белореченский	0101000020E610000054707841441E47408B8D791D71324F40
12893	7	66	215	18872	61849	\N	55.187995000000001	д.Новые Мураты, Школьная, 1		0101000020E6100000D15AD1E638A74740E0675C3810984B40
18194	3	26	1579	20440	58829	\N	61.995550999999999	"Архангельская область,Верхнетоемский муниципальный район,муниципальное образование ""Федьковское"",  пос.Авнюгский, ул.Строительная, д.30"		0101000020E61000008D093197548B4640034015376EFF4E40
18150	3	26	1404	57499	58965	\N	61.343002686966202	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Ракуло-Кокшеньгское"", дер.Выселок Новинки, д.26"	Россия, Архангельская область, Шенкурский район, река Вага	0101000020E6100000973AC8EBC124454007B7B585E7AB4E40
18164	3	26	1404	18812	58839	\N	61.207701999999998	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Шадреньгское"", пос.Шунема, ул.Центральная, д.12"		0101000020E610000066FA25E2ADEB44402AA8A8FA959A4E40
18140	3	26	1404	17594	58872	\N	61.414292000000003	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пакшеньгское"", пос.Шокша, ул.Центральная, д.8"		0101000020E610000026AC8DB1130845404A7F2F8507B54E40
18159	3	26	1404	18559	\N	\N	61.014007999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Усть-Вельское"", дер.Шиловская, д.40А"		0101000020E6100000EE0A7DB08C054540F1F09E03CB814E40
18158	3	26	1404	18491	\N	\N	61.078288000000001	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Усть-Вельское"", дер.Хорошевская, д.16В"		0101000020E6100000485167EE21094540AAD55757058A4E40
18162	3	26	1404	18713	58794	\N	61.197620999999998	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Хозьминское"", пос.Хозьмино, ул.Центральная, д.23"		0101000020E6100000CEFC6A0E10CE44405C001AA54B994E40
18138	3	26	1404	17470	58938	\N	61.147432000000002	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Шоношское"", дер.Усть-Шоноша, пер.Торговый, д.14"		0101000020E61000000803CFBD87AD44402331410DDF924E40
18160	3	26	1404	17470	58580	\N	61.146737665519701	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Усть-Шоношское"", пос.Усть-Шоноша, ул.Ломоносова, д.3"	Россия, Архангельская область, Вельский район, поселок Усть-Шоноша	0101000020E610000061DEE34C13AE44404C8A8F4FC8924E40
18134	3	26	1404	17286	58934	\N	61.516171	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Липовское"", пос.Тимонино, ул.Советская, д.3"		0101000020E610000020990E9D9EFB444062122EE411C24E40
18137	3	26	1404	17434	58832	\N	60.865701999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Низовское"", дер.Теребино, ул.Дальняя, д.4"		0101000020E6100000EBA86A82A80D4540780AB952CF6E4E40
18154	3	26	1404	18259	58851	\N	61.663497999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Тёгринское"", пос.Тёгрозеро, ул.Мира, д.16"		0101000020E6100000CEA96400A8C244400F7BA180EDD44E40
18125	3	26	1404	16831	59036	\N	61.187618999999998	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Верхнешоношское"", пос.Средний, ул.Гагарина, д.5"		0101000020E6100000605793A7AC924440DA8D3EE603984E40
18151	3	26	1404	18122	58735	\N	61.050161991585703	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Солгинское"", пос.Солгинский, ул.Советская, д.29"		0101000020E610000049A12C7C7DAB444040C05AB56B864E40
18161	3	26	1404	18689	\N	\N	61.290597683908402	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Хозьминское"", дер.Смольянская, д.14"	Россия, Архангельская область, Вельский район, село Смольянская	0101000020E6100000CE8B135FEDC844403A24B55032A54E40
18157	3	26	1404	18420	58937	\N	61.078319	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Усть-Вельское"", пос.Синега, ул.Школьная, д.22"		0101000020E6100000570740DCD5E14440E5D3635B068A4E40
18145	3	26	1404	17833	58977	\N	61.660193	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Попонаволоцкое"", пос.Саргино, ул.Центральная, д.3"		0101000020E6100000054F2157EA7145402906483481D44E40
18141	3	26	1404	17650	59031	\N	60.945821000000002	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пежемское"", дер.Притыкинская (берег), ул.Центральная, д.27"		0101000020E6100000F6D37FD6FCE244405D6F9BA910794E40
18156	3	26	1404	18380	59046	\N	61.076264999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Усть-Вельское"", дер.Прилуцкая, ул.Солнечная, д.54"		0101000020E61000007172BF4351FC44402B6A300DC3894E40
18152	3	26	1404	18170	58850	\N	61.279449999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Судромское"", пос.Погост, ул.Центральная, д.29"		0101000020E6100000825660C8EA304540006F8104C5A34E40
18142	3	26	1404	17690	9673	\N	60.982642828202202	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пежемское"", с.Пежма, ул.Центральная, д.8А"		0101000020E6100000A60BB1FA23E644405952EE3EC77D4E40
18143	3	26	1404	17750	59064	\N	61.583286999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Попонаволоцкое"", пос.Пасьва, ул.Свердлова, д.16"		0101000020E6100000AA66D652405C45404A97FE25A9CA4E40
18144	3	26	1404	17790	\N	\N	61.589122000000003	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Попонаволоцкое"", с.Павловское, д.49"		0101000020E610000039807EDFBF47454054AD855968CB4E40
12618	7	66	215	49169	62117	\N	55.154594000000003	д.Новые Высли, Новая, 32		0101000020E6100000711FB935E9BA4740341477BCC9934B40
18113	3	26	1404	16241	58935	\N	61.035843999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пежемское"", пос.Новый Куваш, ул.Железнодорожная, д.2"		0101000020E6100000CF4D9B711AD2444000E1438996844E40
18155	3	26	1404	40349	\N	\N	61.020032999999998	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Усть-Вельское"", дер.Никифорово, д.47"		0101000020E610000064E8D84125F444409EEBFB7090824E40
18122	3	26	1404	16702	\N	\N	60.996347209930398	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Верхнеустькулойское"", дер.Нестюковская, д.57"	Россия, Архангельская область, Вельский район, село Нестюковская	0101000020E6100000A9FB00A4361D4540DE3B6A4C887F4E40
18119	3	26	1404	16546	\N	\N	60.982281	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Верхнеустькулойское"", дер.Мелединская, д.179"		0101000020E610000033C2DB8310384540B83D4162BB7D4E40
18133	3	26	1404	17233	59047	\N	61.506124999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Липовское"", дер.Малая Липовка, ул.Школьная, д.4"		0101000020E610000052B5DD04DFEE4440105839B4C8C04E40
18123	3	26	1404	16740	58936	\N	61.253791999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Шоношское"", дер.Лодейное, ул.Новая, д.27"		0101000020E610000033A5F5B704B0444043FE99417CA04E40
18120	3	26	1404	16575	\N	\N	60.830125000000002	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Верхнеустькулойское"", дер.Лиходиевский Погост, д.45"		0101000020E61000003546EBA86A3C4540C74B3789416A4E40
18163	3	26	1404	18744	\N	\N	61.162050999999998	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Шадреньгское"", дер.Леушинская, д.42"		0101000020E61000004698A25C1AF744405DA45016BE944E40
18128	3	26	1404	16889	58837	\N	61.031677999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Кулойское"", пос.Кулой, ул.Пионерская, д.5"		0101000020E610000010ECF82F103E4540580053060E844E40
18129	3	26	1404	16889	58801	\N	61.031677999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Кулойское"", пос.Кулой, ул.Мира, д.16"		0101000020E610000010ECF82F103E4540580053060E844E40
18130	3	26	1404	16889	58659	\N	61.031677999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Кулойское"", пос.Кулой, ул.Ленина, д.43"	Россия, Архангельская область, Вельский район, поселок Кулой	0101000020E610000010ECF82F103E4540580053060E844E40
18127	3	26	1404	16889	58683	\N	61.028846594447202	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Кулойское"", пос.Кулой, ул.Комсомольская, д.58"	Россия, Архангельская область, Вельский район, поселок Кулой	0101000020E6100000B94F8E02443F45403ACB2C42B1834E40
18126	3	26	1404	16889	58683	\N	61.031677999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Кулойское"", пос.Кулой, ул.Комсомольская, д.50"		0101000020E610000010ECF82F103E4540580053060E844E40
18124	3	26	1404	16801	58791	\N	61.323250000000002	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Верхнешоношское"", пос.Комсомольский, ул.Комсомольская, д.36"		0101000020E6100000292504ABEA9144404C37894160A94E40
18149	3	26	1404	18047	58879	\N	61.102941000000001	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Ракуло-Кокшеньгское"", дер.Козловская, ул.Центральная, д.26"		0101000020E6100000CBA2B08BA26B45407235B22B2D8D4E40
18147	3	26	1404	17958	59038	\N	61.478608999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пуйское"", дер.Игнатовка, ул.Почтовая, д.1"		0101000020E6100000F33E8EE6C83645401F49490F43BD4E40
18139	3	26	1404	17533	58979	\N	61.341076000000001	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пакшеньгское"", дер.Ефремковская, ул.Почтовая, д.1А"		0101000020E61000009A931799800B4540AAB9DC60A8AB4E40
18105	3	26	1404	15854	\N	\N	61.089143	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", дер.Дюковская, д.2А"		0101000020E61000000FEF39B01C0D45406BD5AE09698B4E40
18146	3	26	1404	17886	58852	\N	61.544381071776499	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пуйское"", с.Долматово, ул.Партизанская, д.55"	Россия, Архангельская область, Вельский район, село Долматово	0101000020E610000027A1F485902B45402AC8CF46AEC54E40
18136	3	26	1404	17373	58734	\N	61.103693999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Муравьевское"", дер.Горка Муравьевская, ул.Школьная, д.3"		0101000020E6100000261DE560361145404D6551D8458D4E40
18131	3	26	1404	17142	59045	\N	61.535542	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Липовское"", с.Георгиевское, ул.Центральная, д.29"		0101000020E610000006A051BAF4C7444035D1E7A38CC44E40
18118	3	26	1404	16486	\N	\N	61.471760000000003	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Благовещенское"", с.Воскресенское, д.12"		0101000020E610000051F69672BE3E4540CEC7B5A162BC4E40
18135	3	26	1404	17327	\N	\N	61.095171000000001	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Муравьевское"", дер.Вороновская, 1Б"		0101000020E61000006308008E3D0F4540894336902E8C4E40
18153	3	26	1404	18251	59037	\N	61.606158000000001	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Тёгринское"", пос.Верхопуйский, ул.Титова, д.26"		0101000020E61000008B54185B08B44440B91AD99596CD4E40
18107	3	26	1404	15459	58667	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, пер.Школьный, д.3"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18098	3	26	1404	15459	58848	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Революционная, д.17А"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18106	3	26	1404	15459	58679	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Макаренко, д.12"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18103	3	26	1404	15459	58578	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Ломоносова, д.37"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18110	3	26	1404	15459	58835	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Кирова, д.6"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18109	3	26	1404	15459	58581	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Дзержинского, д.201"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18108	3	26	1404	15459	58581	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Дзержинского, д.126А"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18100	3	26	1404	15459	58581	\N	61.076014361027198	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Дзержинского, д.38"	Россия, Архангельская область, Вельский район, Вельск	0101000020E610000076A8A624EB0E4540E204A6D3BA894E40
18102	3	26	1404	15459	58577	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Горького, д.1А"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18097	3	26	1404	15459	58720	\N	61.060043	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Вельское"", г.Вельск, ул.Дзержинского, д.25"		0101000020E61000009AEE75525F0E454047AD307DAF874E40
18148	3	26	1404	17973	58926	\N	61.531858	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Пуйское"", пос.Великое, ул.Школьная, д.3"		0101000020E610000083A279008B1C4540D80E46EC13C44E40
18117	3	26	1404	16422	59044	\N	61.359231999999999	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Благовещенское"", пос.Боровое, Культурная, д.10"		0101000020E61000004CFA7B293C6245409DD66D50FBAD4E40
18116	3	26	1404	16403	59074	\N	61.460057999999997	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Благовещенское"", с.Благовещенское, ул.Центральная, д.10"		0101000020E61000006DE34F5436464540AF21382EE3BA4E40
18115	3	26	1404	16332	58838	\N	61.080807999999998	"Архангельская область, Вельский муниципальный район, муниципальное образование ""Аргуновское"", пос.Аргуновский, ул.60 лет Октября, д.11"		0101000020E6100000E34F5436AC154540A9A0A2EA578A4E40
82220	3	\N	\N	2	\N	\N	59.919694667082901	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Константина Заслонова, дом 6	Россия, Санкт-Петербург, улица Константина Заслонова, 6	0101000020E61000004147AB5AD2593E40B9A5D590B8F54D40
82216	3	\N	\N	2	\N	\N	59.925662414839103	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Коломенская, дом 6	Россия, Санкт-Петербург, Коломенская улица, 6	0101000020E61000004FEB36A8FD5A3E403293A8177CF64D40
82215	3	\N	\N	2	\N	\N	59.926958999999997	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Марата, дом 27	Россия, Санкт-Петербург, Центральный район, улица Марата, 27	0101000020E6100000E57B4622345A3E40CEDDAE97A6F64D40
82214	3	\N	\N	2	\N	\N	59.926867999999999	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, переулок Кузнечный, дом 20	Россия, Санкт-Петербург, Кузнечный переулок, 20	0101000020E6100000B0C8AF1F625B3E40BEDA519CA3F64D40
82213	3	\N	\N	2	\N	\N	59.929519999999997	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Пушкинская, дом 9		0101000020E61000009EEFA7C64B5B3E402C7DE882FAF64D40
82212	3	\N	\N	2	\N	\N	59.926017860415399	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Большая Московская, дом 10	Россия, Санкт-Петербург, Большая Московская улица, 10	0101000020E61000009546CCECF3583E40F0C000C287F64D40
82209	3	\N	\N	2	\N	\N	59.927162000000003	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Ломоносова, дом 9		0101000020E61000003EE94482A9563E40070C923EADF64D40
81582	3	\N	\N	2	13286	\N	59.734137829421101	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, проспект Заводской, дом 18, корп. 2		0101000020E610000083A279008B903E401C60E63BF8DD4D40
82208	3	\N	\N	2	\N	\N	59.928563594011798	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, набережная реки Фонтанки, дом 62	Россия, Санкт-Петербург, набережная реки Фонтанки, 62	0101000020E610000050FC1873D7563E40191F662FDBF64D40
82206	3	\N	\N	2	\N	\N	59.930509070793498	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, переулок Графский, дом 8	Россия, Санкт-Петербург, Графский переулок, 8	0101000020E61000009DBD33DAAA583E401CD13DEB1AF74D40
82205	3	\N	\N	2	\N	\N	59.930991425645097	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, переулок Графский, дом 1	Россия, Санкт-Петербург, Графский переулок, 1	0101000020E61000007BC03C64CA573E4067EF8CB62AF74D40
82196	3	\N	\N	2	\N	\N	59.936219000000001	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Маяковского, дом 9/16		0101000020E6100000C64FE3DEFC5A3E4069723106D6F74D40
82194	3	\N	\N	2	\N	\N	59.938031000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Маяковского, дом 26		0101000020E6100000E7E104A6D35A3E402DD1596611F84D40
82191	3	\N	\N	2	\N	\N	59.942981314373696	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Пестеля, дом 16б	Россия, Санкт-Петербург, улица Пестеля, 16б	0101000020E6100000F81C588E90593E40ECDFF599B3F84D40
82189	3	\N	\N	2	\N	\N	59.9486840109453	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Шпалерная, дом 33	Россия, Санкт-Петербург, Шпалерная улица, 33	0101000020E610000094347F4C6B5B3E40861E317A6EF94D40
82186	3	\N	\N	2	\N	\N	59.938153	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, проспект Литейный, дом 42	Россия, Санкт-Петербург, Литейный проспект, 42	0101000020E61000008599B67F65593E4078D2C26515F84D40
82183	3	\N	\N	2	\N	\N	59.9435169774695	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, переулок Соляной, дом 12	Россия, Санкт-Петербург, Соляной переулок, 12	0101000020E61000007AC7293A92573E402A1C412AC5F84D40
82178	3	\N	\N	2	\N	\N	59.942884340679001	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Дворцовый округ, улица Миллионная, дом 14	Россия, Санкт-Петербург, Миллионная улица, 14	0101000020E6100000DAC534D3BD523E40F9F5436CB0F84D40
82134	3	\N	\N	2	\N	\N	59.863979848462698	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Южное шоссе, дом 54а	Россия, Санкт-Петербург, Фрунзенский район, Южное шоссе	0101000020E6100000EE409DF2E86A3E40F4328AE596EE4D40
82129	3	\N	\N	2	\N	\N	59.873099000000003	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Софийская улица, дом 39, корп. 1		0101000020E610000091990B5C1E673E40CD9541B5C1EF4D40
82128	3	\N	\N	2	\N	\N	59.870900598855798	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Софийская улица, дом 42, корп.3	Россия, Санкт-Петербург, Колпинский район, Софийская улица, 42к3	0101000020E610000076711B0DE0693E40E08618AF79EF4D40
82109	3	\N	\N	2	\N	\N	59.65408	ПоселокДинамо, Клубная пл.,1, (подростково-молодежный клуб«Павловчанин»)		0101000020E6100000AD342905DD663E40DD7BB8E4B8D34D40
82102	3	\N	\N	2	\N	\N	59.685725530154102	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Павловск, Березовая улица, дом 18	Россия, Санкт-Петербург, Павловск, Берёзовая улица, 18	0101000020E6100000FD9FC37C796D3E402A029CDEC5D74D40
82101	3	\N	\N	2	\N	\N	59.701669000000003	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Тярлево, Большая улица, дом 1	Россия, Санкт-Петербург, посёлок Тярлево, Большая улица, 1	0101000020E61000007AE063B0E2703E40FBCE2F4AD0D94D40
82099	3	\N	\N	2	\N	\N	59.704914000000002	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Кадетский бульвар, дом 22А	Россия, Санкт-Петербург, Пушкин, Кадетский бульвар, 22а	0101000020E61000003049658A39683E400C3F389F3ADA4D40
82095	3	\N	\N	2	\N	\N	59.729193256046997	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Ленинградская улица, дом 36	Россия, Санкт-Петербург, Пушкин, Ленинградская улица, 36	0101000020E610000027A435069D683E406FBC3B3256DD4D40
82093	3	\N	\N	2	\N	\N	59.730444175385102	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, бульвар Алексея Толстого, дом 42	Россия, Санкт-Петербург, Пушкин, бульвар Алексея Толстого, 42	0101000020E6100000D446753A90693E409BC761307FDD4D40
82090	3	\N	\N	2	\N	\N	59.738798854980203	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, улица Генерала Хазова, дом 18	Россия, Санкт-Петербург, Пушкин, улица Генерала Хазова, 18	0101000020E61000000932022A1C693E40A4A833F790DE4D40
82086	3	\N	\N	2	\N	\N	59.731963	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Александровская, Волхонское шоссе, дом 32	Россия, Санкт-Петербург, посёлок Александровская, Пионерский переулок	0101000020E610000090BE49D3A0583E40E770ADF6B0DD4D40
82085	3	\N	\N	2	\N	\N	59.755534833040699	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Шушары, Ленсоветовский, здание школы №460	Россия, Санкт-Петербург, Пушкинский район, МО посёлок Шушары	0101000020E61000001DE8A1B60D7F3E40DFFDF15EB5E04D40
82084	3	\N	\N	2	\N	\N	59.761524566183098	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Шушары, Пулковское, дом 30, под. 10	Россия, Санкт-Петербург, Пулковское район, 30	0101000020E61000007845F0BF955C3E400F0BB5A679E14D40
82080	3	\N	\N	2	\N	\N	59.666452999999997	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Лесное, здание школы №607	Россия, Санкт-Петербург, Пушкинский район, район Лесное	0101000020E6100000DC9E20B1DD413E4019A9F7544ED54D40
82079	3	\N	\N	2	\N	\N	59.705819063803901	г. Пушкин, Красносельское шоссе, 29, (Филиал № 4 Территориальной центральной библиотечной системы)	Россия, Санкт-Петербург, Пушкин, Лицейский переулок, 3	0101000020E61000002A3BFDA02E5E3E409DF2E84658DA4D40
82077	3	\N	\N	2	\N	\N	59.718246259248197	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Леонтьевская улица, дом 10	Россия, Санкт-Петербург, Пушкин, Средняя улица, 10	0101000020E610000067994528B6663E40CD3D247CEFDB4D40
82075	3	\N	\N	2	\N	\N	59.717618798290502	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Госпитальная улица, дом 24	Россия, Санкт-Петербург, Пушкин, Госпитальная улица, 24	0101000020E610000058569A94826A3E407EFE7BF0DADB4D40
82073	3	\N	\N	2	\N	\N	59.736471000000002	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, улица Генерала Хазова, дом 7	Россия, Санкт-Петербург, Пушкин, улица Генерала Хазова, 7	0101000020E61000007A8F334DD8663E40E9B985AE44DE4D40
82044	3	\N	\N	2	\N	\N	\N	ул. Маршала Новикова д.15 муз. Школа № 33		\N
82038	3	\N	\N	2	\N	\N	60.010980111945798	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, улица Ильюшина, дом 15, корп. 3	Россия, Санкт-Петербург, улица Ильюшина, 15к3	0101000020E61000001F0E12A27C3D3E407E74EACA67014E40
82037	3	\N	\N	2	\N	\N	60.013744000000003	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, проспект Авиаконструкторов, дом 15, корп. 2	Россия, Санкт-Петербург, проспект Авиаконструкторов, 15к2	0101000020E61000003672DD94F23E3E401442075DC2014E40
82035	3	\N	\N	2	\N	\N	60.011324000000002	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, проспект Комендантский, дом 22, корп. 3	Россия, Санкт-Петербург, Комендантский проспект, 22к3	0101000020E6100000664F029B73403E4078D4981073014E40
82034	3	\N	\N	2	\N	\N	60.014139999999998	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, проспект Комендантский, дом 21, корп. 3	Россия, Санкт-Петербург, Комендантский проспект, 21к3	0101000020E6100000A20E2BDCF2413E4060C8EA56CF014E40
82033	3	\N	\N	2	\N	\N	60.012384940707499	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, проспект Комендантский, дом 17, корп. 3	Россия, Санкт-Петербург, Приморский район, район Озеро Долгое	0101000020E6100000ECA012D731423E4001FBE8D495014E40
82030	3	\N	\N	2	\N	\N	60.0091082008028	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, улица Маршала Новикова, дом 1, корп. 3	Россия, Санкт-Петербург, улица Маршала Новикова, 1к3	0101000020E6100000742843554C453E40E41071732A014E40
82027	3	\N	\N	2	\N	\N	59.988930020553198	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, улица Сердобольская, дом 50/52	Россия, Санкт-Петербург, Сердобольская улица, 52	0101000020E61000004D486B0C3A513E4043041C4295FE4D40
82026	3	\N	\N	2	\N	\N	59.992234044514497	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, улица Торжковская, дом 30А		0101000020E610000033E202D028513E4059FD118601FF4D40
82024	3	\N	\N	2	\N	\N	59.998140503066899	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, шоссе Ланское, дом 24, корп. 5	Россия, Санкт-Петербург, Ланское шоссе, 24к5	0101000020E6100000207BBDFBE3513E40FBE59315C3FF4D40
82022	3	\N	\N	2	\N	\N	59.9916183811482	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, улица Новосибирская, дом 16/2	Россия, Санкт-Петербург, Новосибирская улица, 16к2	0101000020E61000003D0AD7A3704D3E40FE0FB056EDFE4D40
82020	3	\N	\N	2	\N	\N	59.988675999999998	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, улица Школьная, дом 13	Россия, Санкт-Петербург, Приморский район, Школьная улица, 13	0101000020E6100000D49B51F3554A3E40882B67EF8CFE4D40
82019	3	\N	\N	2	\N	\N	59.988194	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, улица Школьная, дом 19		0101000020E6100000C9C7EE0225493E403D0D18247DFE4D40
82016	3	\N	\N	2	\N	\N	59.986722	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, улица Школьная, дом 66		0101000020E6100000ECA353573E433E40321F10E84CFE4D40
81989	3	\N	\N	2	\N	\N	59.897476989788899	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, улица Победы, дом 28, корп. 2, литер А	Россия, Санкт-Петербург, Ломоносов, улица Победы	0101000020E61000001AC231CB9EC43D40C3F4BD86E0F24D40
81985	3	\N	\N	2	\N	\N	59.9093630169275	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, Александровская улица, дом 38	Россия, Санкт-Петербург, Ломоносов, Александровская улица, 38	0101000020E6100000CE8AA8893EC73D40A298BC0166F44D40
81979	3	\N	\N	2	\N	\N	59.882417001736499	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, улица Халтурина, дом 15/2	Россия, Санкт-Петербург, Петергоф, улица Халтурина, 15к2	0101000020E61000004B0169FF03DC3D409B374E0AF3F04D40
81977	3	\N	\N	2	\N	\N	59.889650397811998	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Собственный проспект, дом 1	Россия, Санкт-Петербург, Петергоф, Собственный проспект, 1	0101000020E6100000522635B401E03D4076711B0DE0F14D40
81976	3	\N	\N	2	\N	\N	59.869881531349698	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, улица Шахматова, дом 10/1	Россия, Санкт-Петербург, Петергоф, улица Шахматова, 10к1	0101000020E6100000EF91CD55F3DC3D4085B01A4B58EF4D40
81975	3	\N	\N	2	\N	\N	59.869013571312003	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Ботаническая улица, дом 8	Россия, Санкт-Петербург, Петергоф, Ботаническая улица, 8	0101000020E61000008FA850DD5CDC3D4011E2CAD93BEF4D40
81972	3	\N	\N	2	\N	\N	59.876069207655704	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Блан-Менильская улица, дом 5	Россия, Санкт-Петербург, Петергоф, Блан-Менильская улица, 5	0101000020E6100000AD8905BEA2E33D400C056C0723F04D40
81971	3	\N	\N	2	\N	\N	59.874725573342197	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Разводная улица, дом 27	Россия, Санкт-Петербург, Петергоф, Разводная улица, 27	0101000020E6100000E06932E36DE53D40FF7A8505F7EF4D40
81969	3	\N	\N	2	\N	\N	59.8710959797654	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Эрлеровский бульвар, дом 20	Россия, Санкт-Петербург, Петергоф, Эрлеровский бульвар, 20	0101000020E6100000A19E3E027FE83D4095D6DF1280EF4D40
81966	3	\N	\N	2	\N	\N	59.861213999999997	"ул. Юты Бондаровской, дом 13/1,  (филиал торгово-экономического лицея № 148), тел. 427-14-22 "		0101000020E6100000A4C684984BEE3D40BD6DA6423CEE4D40
81962	3	\N	\N	2	\N	\N	59.854536099954899	Город Санкт-Петербург, Петродворцовый район, муниципальное образование поселок Стрельна, Санкт-Петербургское шоссе, дом 77	Россия, Санкт-Петербург, посёлок Стрельна, Санкт-Петербургское шоссе, 77	0101000020E610000068942EFD4B063E4099A0866F61ED4D40
81946	3	\N	\N	2	\N	\N	59.957425999999998	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ округ Петровский, улица Малая Разночинная, дом 2/4	Россия, Санкт-Петербург, Малая Разночинная улица, 2	0101000020E61000009D82FC6CE44A3E40882B67EF8CFA4D40
81944	3	\N	\N	2	\N	\N	59.963281068870003	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ округ Петровский, проспект Чкаловский, дом 30	Россия, Санкт-Петербург, Чкаловский проспект, 30	0101000020E6100000179F02603C4B3E40D9EDB3CA4CFB4D40
81933	3	\N	\N	2	\N	\N	59.9642985238359	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Посадский, улица Льва Толстого, дом 8	Россия, Санкт-Петербург, Петроградский район, улица Льва Толстого, 8	0101000020E6100000596ABDDF68533E4062484E266EFB4D40
81932	3	\N	\N	2	\N	\N	59.960728000000003	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Посадский, улица Мира, дом 18		0101000020E61000009753026212523E40FE2C9622F9FA4D40
81931	3	\N	\N	2	\N	\N	59.961728000000001	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Посадский, улица Мира, дом 26		0101000020E61000004AED45B41D533E40E1D231E719FB4D40
81890	3	\N	\N	2	\N	\N	59.894924000000003	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невская застава, Большой Смоленский проспект, дом 36	Россия, Санкт-Петербург, Большой Смоленский проспект, 36	0101000020E6100000D34F38BBB5683E40E833A0DE8CF24D40
81886	3	\N	\N	2	\N	\N	59.736733612367203	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Школьная улица, дом 55	Россия, Санкт-Петербург, Пушкин, Школьная улица, 55	0101000020E6100000FB07910C396A3E40F6ECB94C4DDE4D40
81869	3	\N	\N	2	\N	\N	59.914976226590298	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Коллонтай, дом 19, корп.5	Россия, Санкт-Петербург, улица Коллонтай, 19к5	0101000020E6100000D9B27C5D86773E40FD4FFEEE1DF54D40
81864	3	\N	\N	2	\N	\N	59.9119805791861	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Белышева, дом 6	Россия, Санкт-Петербург, улица Белышева, 6	0101000020E6100000A5DB12B9E0743E4064C91CCBBBF44D40
81244	3	\N	\N	2	2823	\N	59.904383000000003	ул.Бумажная, д.5, ГОУ СОШ № 287	Россия, Санкт-Петербург, Бумажная улица, 5	0101000020E610000071581AF851453E40790778D2C2F34D40
81861	3	\N	\N	2	\N	\N	59.90607	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Дыбенко, дом 20, корп.4	Россия, Санкт-Петербург, улица Дыбенко, 20к4	0101000020E6100000E94317D4B7783E4080F10C1AFAF34D40
81829	3	\N	\N	2	\N	\N	59.860297000000003	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, улица Победы, дом 10		0101000020E6100000384888F205513E4068EC4B361EEE4D40
81805	3	\N	\N	2	\N	\N	59.854233000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, Авиационная улица, дом 38		0101000020E61000002EC72B103D553E40FD14C78157ED4D40
81780	3	\N	\N	2	\N	\N	60.194984452828201	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Молодежное, улица Правды, дом 6А	Россия, Санкт-Петербург, посёлок Молодёжное, улица Правды, 6а	0101000020E6100000F5F6E7A221833D40239F573CF5184E40
81777	3	\N	\N	2	\N	\N	60.213296999999997	Город Санкт-Петербург, Курортный район, муниципальное образование город Зеленогорск, Красавица, жилгородок 7 км	Россия, Санкт-Петербург, Курортный район, МО город Зеленогорск	0101000020E6100000640795B88EB53D40DEAAEB504D1B4E40
81776	3	\N	\N	2	\N	\N	60.237888269357697	"Город Санкт-Петербург, Курортный район, муниципальное образование город Зеленогорск, Решетниково, подстанция №41 ОАО ""Ленэнерго"""	Россия, Санкт-Петербург, Курортный район, МО город Зеленогорск	0101000020E610000092CA147310B03D40300E2E1D731E4E40
81775	3	\N	\N	2	\N	\N	60.200819000000003	Город Санкт-Петербург, Курортный район, муниципальное образование город Зеленогорск, проспект Ленина, дом 25	Россия, Санкт-Петербург, Зеленогорск, проспект Ленина, 25	0101000020E6100000C8B1F50CE1B43D402DB5DE6FB4194E40
81772	3	\N	\N	2	\N	\N	60.1851576027316	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Комарово, Цветочная улица, дом 22	Россия, Санкт-Петербург, посёлок Комарово, Цветочная улица, 22	0101000020E610000026C5C72764D33D40E04BE141B3174E40
81769	3	\N	\N	2	\N	\N	60.115873581676503	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Песочный, Военно-морской городок, 8 квартал, дом 140	Россия, Санкт-Петербург, Курортный район, МО посёлок Песочный	0101000020E61000005D52B5DD041F3E40753A90F5D40E4E40
81768	3	\N	\N	2	\N	\N	60.149748000000002	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Солнечное, Приморское шоссе, дом 374	Россия, Санкт-Петербург, Зеленогорск, Приморское шоссе, 374	0101000020E61000001E15FF7744ED3D401A5245F12A134E40
81767	3	\N	\N	2	\N	\N	60.144766608653399	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Белоостров, Восточная улица, дом 6	Россия, Санкт-Петербург, посёлок Белоостров, Восточная улица, 6	0101000020E6100000CE55F31C91FF3D4020459DB987124E40
81762	3	\N	\N	2	\N	\N	60.092841	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, Советский переулок, дом 10	Россия, Санкт-Петербург, Сестрорецк, Советский переулок, 10	0101000020E6100000F6ED2422FCF33D402D5DC136E20B4E40
81761	3	\N	\N	2	\N	\N	60.091263837451699	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, Токарева улица, дом 20	Россия, Санкт-Петербург, Сестрорецк, улица Токарева	0101000020E61000008B19E1ED41F43D40ADA6EB89AE0B4E40
81760	3	\N	\N	2	\N	\N	60.087434999999999	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, Токарева улица, дом 10	Россия, Санкт-Петербург, Сестрорецк, улица Токарева, 10	0101000020E6100000124F7633A3F33D404CC3F011310B4E40
81754	3	\N	\N	2	\N	\N	60.008544999999998	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Станюковича, дом 4	Россия, Санкт-Петербург, Кронштадт, улица Станюковича, 4	0101000020E610000052EFA99CF6B83D40ACC5A70018014E40
81753	3	\N	\N	2	\N	\N	59.990211743325503	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Коммунистическая, дом 16	Россия, Санкт-Петербург, Кронштадт, Коммунистическая улица, 16	0101000020E610000091EF52EA92C53D40AA0D4E44BFFE4D40
81750	3	\N	\N	2	\N	\N	59.995994539941897	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Андреевская, дом 3	Россия, Санкт-Петербург, Кронштадт, Андреевская улица, 3	0101000020E6100000ABE7A4F78DC33D4061FD9FC37CFF4D40
81749	3	\N	\N	2	\N	\N	59.9962503969304	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Андреевская, дом 7	Россия, Санкт-Петербург, Кронштадт, Андреевская улица, 7	0101000020E61000004985B18520C33D40EC51B81E85FF4D40
81746	3	\N	\N	2	\N	\N	59.994790717502497	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Советская, дом 43	Россия, Санкт-Петербург, Кронштадт, Советская улица, 43	0101000020E61000006F641EF983C53D4075ADBD4F55FF4D40
81743	3	\N	\N	2	\N	\N	59.986216830192198	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Алексея Лебедева, дом 5	Россия, Санкт-Петербург, Кронштадт, улица Лебедева, 5	0101000020E610000002BB9A3C65C93D402FE1D05B3CFE4D40
13138	7	66	\N	61	61768	\N	56.082777999999998	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Ашмарина, д.33		0101000020E61000005FF0694E5EA44740056A3178980A4C40
81740	3	\N	\N	2	\N	\N	59.697074000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Театральная, дом 15	Россия, Санкт-Петербург, Красное Село, Театральная улица, 15	0101000020E6100000ABE7A4F78D1F3E402A7288B839D94D40
81739	3	\N	\N	2	\N	\N	59.729760568767801	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Первого Мая, дом 2	Россия, Санкт-Петербург, Красное Село, улица 1-го Мая, 19	0101000020E61000008368AD6873183E40B972F6CE68DD4D40
81736	3	\N	\N	2	\N	\N	59.719287000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Красногородская, дом 17, корп. 3	Россия, Санкт-Петербург, Красное Село, Красногородская улица, 17к3	0101000020E6100000D923D40CA9123E400FB8AE9811DC4D40
81735	3	\N	\N	2	\N	\N	59.720770999999999	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, шоссе Кингисеппское, дом 10, корп. 4	Россия, Санкт-Петербург, Красное Село, Кингисеппское шоссе, 10к4	0101000020E61000006A34B91803133E40DE73603942DC4D40
81731	3	\N	\N	2	\N	\N	59.740826567801001	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Спирина, дом 13, лит.Б	Россия, Санкт-Петербург, Красное Село, улица Спирина, 13к1	0101000020E610000082A966D652143E40357F4C6BD3DE4D40
81728	3	\N	\N	2	\N	\N	59.746008936334498	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Спирина, дом 2, корп. 3	Россия, Санкт-Петербург, Красное Село, улица Спирина, 2к3	0101000020E610000096CCB1BCAB163E40C6C210397DDF4D40
81726	3	\N	\N	2	\N	\N	59.753117896979198	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Горелово, улица Геологическая, дом 75, корп. 5	Россия, Санкт-Петербург, Красное Село, Геологическая улица, 75к5	0101000020E610000015527E52ED133E40B403AE2B66E04D40
81722	3	\N	\N	2	\N	\N	59.821662000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Горелово, шоссе Красносельское, дом 34		0101000020E61000001DCBBBEA01133E40D82E6D382CE94D40
81721	3	\N	\N	2	\N	\N	59.817960999999997	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Горелово, улица Поселковая, дом 26А	Россия, Санкт-Петербург, Красносельский район, Поселковая улица, 26	0101000020E6100000C9772975C92C3E40A43330F2B2E84D40
81680	3	\N	\N	2	\N	\N	59.723016999999999	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Пушкинская улица, дом 3	Россия, Санкт-Петербург, Пушкин, Пушкинская улица, 3	0101000020E6100000F46C567DAE663E40DCB930D28BDC4D40
81627	3	\N	\N	2	\N	\N	59.924415000000003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Казанская улица  (Малая Охта), дом 3		0101000020E61000003F389F3A566D3E404777103B53F64D40
81615	3	\N	\N	2	\N	\N	59.9547844111597	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Большая Пороховская улица, дом 38	Россия, Санкт-Петербург, Большая Пороховская улица, 38	0101000020E6100000D3C1FA3F876D3E403D5FB35C36FA4D40
81613	3	\N	\N	2	\N	\N	59.956888162374597	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Петра Смородина улица, дом 10	Россия, Санкт-Петербург, улица Петра Смородина, 10	0101000020E6100000309C6B98A1713E40A9F7544E7BFA4D40
81600	3	\N	\N	2	\N	\N	59.807315000000003	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Петро-Славянка, улица Труда, дом 1	Россия, Санкт-Петербург, посёлок Петро-Славянка, улица Труда, 1	0101000020E6100000709A3E3BE0823E40FE48111956E74D40
81597	3	\N	\N	2	\N	\N	59.808315973977301	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Металлострой, улица Центральная, дом 12		0101000020E61000008CBFED0912933E40B16A10E676E74D40
81593	3	\N	\N	2	\N	\N	59.785819956635599	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Понтонный, улица Фанерная, дом 5	Россия, Санкт-Петербург, посёлок Понтонный, Фанерный переулок, 5	0101000020E6100000EB36A8FDD69E3E407845F0BF95E44D40
81592	3	\N	\N	2	\N	\N	59.784539425790101	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Понтонный, улица Александра Товпеко, дом 14	Россия, Санкт-Петербург, посёлок Понтонный, улица Александра Товпеко, 14	0101000020E61000008F34B8AD2DA03E40E1B721C66BE44D40
81591	3	\N	\N	2	\N	\N	59.781741489113898	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Понтонный, улица Южная, дом 31	Россия, Санкт-Петербург, посёлок Понтонный, Южная улица, 31	0101000020E610000007EBFF1CE6A33E409E78CE1610E44D40
81590	3	\N	\N	2	\N	\N	59.779047702282497	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Понтонный, улица Южная, дом 13	Россия, Санкт-Петербург, посёлок Понтонный, Южная улица, 13	0101000020E6100000F9BEB854A5A53E40D20149D8B7E34D40
81587	3	\N	\N	2	\N	\N	59.772996451382603	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Загородная, дом 41	Россия, Санкт-Петербург, Колпино, Загородная улица, 41	0101000020E6100000E294B9F946983E402BF86D88F1E24D40
81586	3	\N	\N	2	\N	\N	59.731358930158898	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, проспект Заводской, дом 50	Россия, Санкт-Петербург, Колпино, Заводской проспект, 50	0101000020E610000067BAD7497D953E405051F52B9DDD4D40
81585	3	\N	\N	2	\N	\N	59.736987999999997	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Раумская, дом 9	Россия, Санкт-Петербург, Колпино, Раумская улица, 9	0101000020E6100000AA9B8BBFED953E40B0C56E9F55DE4D40
81583	3	\N	\N	2	\N	\N	59.734107999999999	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Машиностроителей, дом 7	Россия, Санкт-Петербург, Колпино, улица Машиностроителей, 7	0101000020E61000001B13622EA9923E40B1DD3D40F7DD4D40
81581	3	\N	\N	2	\N	\N	59.736888	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, проспект Заводской, дом 10	Россия, Санкт-Петербург, Колпино, Заводской проспект, 10	0101000020E6100000C460FE0A998F3E404D68925852DE4D40
81579	3	\N	\N	2	\N	\N	59.736694174838199	г.Колпино, бульвар Трудящихся, 10 (Школа № 401), тел. 482-99-30	Россия, Санкт-Петербург, Колпино, бульвар Трудящихся	0101000020E61000009E95B4E21B923E4068942EFD4BDE4D40
81576	3	\N	\N	2	\N	\N	59.746654999999997	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Братьев Радченко, дом 21	Россия, Санкт-Петербург, Колпино, улица Братьев Радченко, 21	0101000020E61000009813B4C9E1933E408B321B6492DF4D40
81573	3	\N	\N	2	\N	\N	59.751309859284603	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, проспект Ленина, дом 31	Россия, Санкт-Петербург, Колпино, проспект Ленина, 31	0101000020E61000008BE1EA0088933E40319413ED2AE04D40
81572	3	\N	\N	2	\N	\N	59.748229184912503	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Павловская, дом 21	Россия, Санкт-Петербург, Колпино, Павловская улица, 21	0101000020E6100000AD68739CDB943E409B75C6F7C5DF4D40
81571	3	\N	\N	2	\N	\N	59.742913999999999	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Вавилова, дом 9	Россия, Санкт-Петербург, Колпино, улица Вавилова, 9	0101000020E6100000A8E15B5837963E40CADE52CE17DF4D40
81569	3	\N	\N	2	\N	\N	59.7327586501914	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Анисимова, дом 4	Россия, Санкт-Петербург, Колпино, улица Анисимова, 4	0101000020E6100000909E2287889B3E40C26C020CCBDD4D40
81568	3	\N	\N	2	\N	\N	59.732686113686498	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Тверская, дом 62		0101000020E6100000187C9A93179D3E40581EA4A7C8DD4D40
81566	3	\N	\N	2	\N	\N	59.738796999999998	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Октябрьская, дом 71, корп. 2	Россия, Санкт-Петербург, Колпино, Октябрьская улица, 71к2	0101000020E6100000E17F2BD9B19D3E4003B16CE690DE4D40
81563	3	\N	\N	2	\N	\N	59.744755893768101	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Тверская, дом 18	Россия, Санкт-Петербург, Колпино, Тверская улица, 18	0101000020E6100000EC3026FDBD9C3E40F9BF232A54DF4D40
81562	3	\N	\N	2	\N	\N	59.7488701977855	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Труда, дом 1	Россия, Санкт-Петербург, Колпино, улица Труда, 1	0101000020E6100000A374E95F929A3E404E7ADFF8DADF4D40
81546	3	\N	\N	2	\N	\N	59.831453000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, прспект Ветеранов, дом 114, корп. 2	Россия, Санкт-Петербург, проспект Ветеранов, 114к2	0101000020E610000092088D60E3323E409F94490D6DEA4D40
81529	3	\N	\N	2	\N	\N	59.854874600609598	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Красненькая речка, проспект Стачек, дом 107, корп. 4	Россия, Санкт-Петербург, проспект Стачек, 107к3	0101000020E6100000C5AEEDED963C3E408195438B6CED4D40
81528	3	\N	\N	2	\N	\N	59.854291000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Красненькая речка, Ленинский проспект, дом 110, корп. 3	Россия, Санкт-Петербург, Ленинский проспект, 110к3	0101000020E61000006E30D461853B3E403222516859ED4D40
81526	3	\N	\N	2	\N	\N	59.860681195580803	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Красненькая речка, улица Маршала Казакова, дом 3, крп. 2	Россия, Санкт-Петербург, улица Маршала Казакова, 3к2	0101000020E610000062DC0DA2B53E3E40F0A485CB2AEE4D40
81525	3	\N	\N	2	\N	\N	59.860752104261401	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Красненькая речка, улица Маршала Казакова, дом 3, корп. 2	Россия, Санкт-Петербург, улица Маршала Казакова, 3к2	0101000020E6100000D97A8670CC3E3E40B9FB1C1F2DEE4D40
81524	3	\N	\N	2	\N	\N	59.861598000000001	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Красненькая речка, улица Морской Пехоты, дом 8, корп. 3	Россия, Санкт-Петербург, улица Морской Пехоты, 8к3	0101000020E610000036ACA92C0A3F3E404626E0D748EE4D40
81857	3	\N	\N	2	2120	\N	59.901490000000003	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, улица Дыбенко, дом 17, корп.3	Россия, Санкт-Петербург, улица Дыбенко, 17к3	0101000020E6100000E28FA2CEDC773E40E5D5390664F34D40
81497	3	\N	\N	2	\N	\N	59.877046	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, улица Маршала Говорова, дом 9	Россия, Санкт-Петербург, улица Маршала Говорова, 9	0101000020E6100000EC89AE0B3F443E40378B170B43F04D40
81494	3	\N	\N	2	\N	\N	59.8856144122134	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, переулок Огородный, дом 9	Россия, Санкт-Петербург, Огородный переулок, 9	0101000020E61000000954FF2092453E409B70AFCC5BF14D40
81491	3	\N	\N	2	\N	\N	59.887300913677699	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, улица Турбинная, дом 50	Россия, Санкт-Петербург, Турбинная улица, 50	0101000020E6100000187959130B443E40A35A441493F14D40
81490	3	\N	\N	2	\N	\N	59.897717999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, улица Промышленная, дом 18	Россия, Санкт-Петербург, Промышленная улица, 18	0101000020E6100000DBF97E6ABC443E40E883656CE8F24D40
81489	3	\N	\N	2	\N	\N	59.892695658763202	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, улица Зои Космодемьянской, дом 4	Россия, Санкт-Петербург, улица Зои Космодемьянской, 4	0101000020E6100000390CE6AF90453E4090A2CEDC43F24D40
81488	3	\N	\N	2	\N	\N	59.897226000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, проспект Стачек, дом 5	Россия, Санкт-Петербург, проспект Стачек, 5	0101000020E6100000624B8FA67A463E407A8F334DD8F24D40
81485	3	\N	\N	2	\N	\N	59.899490999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, улица Ивана Черных, дом 11	Россия, Санкт-Петербург, улица Ивана Черных, 11	0101000020E610000022AAF06778473E40EE05668522F34D40
81477	3	\N	\N	2	\N	\N	59.976389506070397	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Лабораторная улица, дом 15	Россия, Санкт-Петербург, Лабораторная улица, 15	0101000020E6100000F6CFD38041623E401B12F758FAFC4D40
81465	3	\N	\N	2	\N	\N	59.968419799258598	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Полюстровский проспект, дом 33, корп. 3	Россия, Санкт-Петербург, Полюстровский проспект, 33к3	0101000020E6100000876C205D6C663E406B65C22FF5FB4D40
81462	3	\N	\N	2	\N	\N	59.973017764139499	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Кондратьевский проспект, дом 51	Россия, Санкт-Петербург, Кондратьевский проспект, 51	0101000020E61000006BB75D68AE633E40AD3594DA8BFC4D40
81395	3	\N	\N	2	\N	\N	60.075291401985602	Город Санкт-Петербург, Выборгский район, муниципальное образование поселок Парголово, Кооперативная улица (Торфяное), дом 27	Россия, Санкт-Петербург, посёлок Парголово, Кооперативная улица	0101000020E6100000C7D45DD905533E407157AF22A3094E40
81389	3	\N	\N	2	\N	\N	60.076566416748697	Город Санкт-Петербург, Выборгский район, муниципальное образование поселок Парголово, Выборгское шоссе, дом 369, корп. 3	Россия, Санкт-Петербург, посёлок Парголово, Выборгское шоссе, 369	0101000020E61000001895D40968463E4026FE28EACC094E40
81386	3	\N	\N	2	\N	\N	60.088426768094699	Город Санкт-Петербург, Выборгский район, муниципальное образование поселок Парголово, улица Шишкина, дом 30	Россия, Санкт-Петербург, посёлок Парголово, улица Шишкина, 30	0101000020E610000027A25F5B3F453E40AD8A7093510B4E40
81385	3	\N	\N	2	\N	\N	60.042367916556202	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, Выборгское шоссе, дом 7, корп. 2	Россия, Санкт-Петербург, посёлок Парголово, Выборгское шоссе, 7к2	0101000020E6100000350C1F1153523E40CF328B506C054E40
81369	3	\N	\N	2	\N	\N	60.042774597879998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, Поэтический будьвар, дом 5, корп. 3	Россия, Санкт-Петербург, Поэтический бульвар, 5к3	0101000020E6100000689599D2FA573E400F0BB5A679054E40
81312	3	\N	\N	2	\N	\N	59.983000239254103	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, улица Александра Матросова, дом 11	Россия, Санкт-Петербург, Выборгский район, улица Александра Матросова, 11	0101000020E610000046239F573C593E40E7FBA9F1D2FD4D40
81284	3	\N	\N	2	\N	\N	59.942233440491698	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ округ Морской, улица Кораблестроителей, дом 18	Россия, Санкт-Петербург, улица Кораблестроителей, 18	0101000020E6100000BEBF417BF5353E40221B48179BF84D40
81283	3	\N	\N	2	\N	\N	59.943548	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ округ Морской, улица Кораблестроителей, дом 20, корп. 3	Россия, Санкт-Петербург, улица Кораблестроителей, 20к3	0101000020E61000009FC893A46B363E40651A4D2EC6F84D40
82244	3	\N	\N	2	6844	\N	59.919432	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Лиговка-Ямская, улица Черняховского, дом 30	Россия, Санкт-Петербург, улица Черняховского, 30	0101000020E6100000884B8E3BA55B3E40AC72A1F2AFF54D40
81282	3	\N	\N	2	\N	\N	59.940999983532798	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ округ Морской, Морская набережная, дом 15, корп.2	Россия, Санкт-Петербург, Василеостровский район, МО Морской округ	0101000020E6100000F965304624363E409CC420B072F84D40
81281	3	\N	\N	2	\N	\N	59.944062808306398	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ округ Морской, улица Наличная, дом 32, корп. 2	Россия, Санкт-Петербург, Наличная улица, 32к2	0101000020E61000005BE9B5D958393E408C2E6F0ED7F84D40
81264	3	\N	\N	2	\N	\N	59.945138999999998	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Васильевский, 14-я линия В.О, дом 77	Россия, Санкт-Петербург, Василеостровский район, 14-я линия В.О., 77	0101000020E61000009D6340F67A433E404A969350FAF84D40
81259	3	\N	\N	2	\N	\N	59.945121	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Васильевский, 7-я линия В.О, дом 66		0101000020E6100000486AA16472463E40A4E194B9F9F84D40
81257	3	\N	\N	2	\N	\N	59.945751999999999	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Васильевский, 2-я линия В.О, дом 43		0101000020E6100000217365506D483E403410CB660EF94D40
81254	3	\N	\N	2	\N	\N	59.934930000000001	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, Большой проспект В.О, дом 65		0101000020E610000045D5AF743E443E404F0647C9ABF74D40
81249	3	\N	\N	2	\N	\N	59.936683000000002	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, 9-я линия В.О, дом 6		0101000020E61000007D957CEC2E483E400EDC813AE5F74D40
81247	3	\N	\N	2	\N	\N	59.940365999999997	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, 5-я линия В.О, дом 16		0101000020E6100000D8463CD9CD483E409A22C0E95DF84D40
81209	3	\N	\N	2	\N	\N	59.925902999999998	Театральная пл., д.3, ФГОУ ВПО «Санкт-Петербургская Государственная Консерватория (академия) им.Н.А.Римского-Корсакова		0101000020E610000059164CFC514C3E40572250FD83F64D40
81191	3	\N	\N	2	\N	\N	59.919991000000003	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Коломна, Садовая улица, дом 75/14	Россия, Санкт-Петербург, Адмиралтейский район, Садовая улица, 75	0101000020E61000008B1BB7989F4B3E40A3CEDC43C2F54D40
81614	3	\N	\N	2	7112	\N	59.958404000000002	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Революции шоссе, дом 35, корп. 5	Россия, Санкт-Петербург, шоссе Революции, 35к5	0101000020E6100000CF68AB92C86E3E40842D76FBACFA4D40
82165	3	\N	\N	2	6013	\N	59.840808000000003	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N75, улица Ярослава Гашека, дом 28, корп. 2	Россия, Санкт-Петербург, улица Ярослава Гашека, 28к2	0101000020E610000054909F8D5C6B3E408B1BB7989FEB4D40
82162	3	\N	\N	2	6013	\N	59.830876433788902	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Ярослава Гашека, дом 9, корп. 2	Россия, Санкт-Петербург, улица Ярослава Гашека, 9к2	0101000020E61000004A0856D5CB633E4002840F255AEA4D40
81217	3	\N	\N	2	2389	\N	59.931201000000001	"ул.Якубовича, д.26, ФГБОУ ВПО  «Санкт-Петербургский  государственный университет аэрокосмического приборостроения» -приемная  комиссия"	Россия, Санкт-Петербург, улица Якубовича, 26	0101000020E6100000E4839ECDAA4B3E405280289831F74D40
82069	3	\N	\N	2	4921	\N	60.026828999999999	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N70, улица Щербакова, дом 16	Россия, Санкт-Петербург, улица Щербакова, 16	0101000020E6100000923D42CD904A3E40CDCAF6216F034E40
82068	3	\N	\N	2	4921	\N	60.026626	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N70, улица Щербакова, дом 18		0101000020E610000077F69507E9493E40959C137B68034E40
81379	3	\N	\N	2	4589	\N	60.057025897193803	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Шостаковича, дом 3, корп. 2	Россия, Санкт-Петербург, улица Шостаковича, 3к2	0101000020E6100000C685032159543E40C782C2A04C074E40
81271	3	\N	\N	2	3193	\N	59.934105000000002	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, Шкиперский проток, дом 5	Россия, Санкт-Петербург, улица Шкиперский Проток, 5	0101000020E6100000EA5C514A083E3E40DA03ADC090F74D40
81240	3	\N	\N	2	2761	\N	59.908132000000002	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Екатерингофский, Шкапина улица, дом 2		0101000020E610000097546D37C14B3E40BD395CAB3DF44D40
81900	3	\N	\N	2	2764	\N	59.866571999999998	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Шелгунова, дом 23		0101000020E610000053AF5B04C6723E408DD0CFD4EBEE4D40
81267	3	\N	\N	2	3137	\N	59.929831	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Шевченко, дом 3А		0101000020E6100000687A89B14C3F3E404BE7C3B304F74D40
81648	3	\N	\N	2	7471	\N	59.841911000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Урицк, улица Добровольцев, дом 8		0101000020E6100000EFA83121E62A3E40439259BDC3EB4D40
81420	3	\N	\N	2	5024	\N	60.025880000000001	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Черкасова, дом 4, корп. 2	Россия, Санкт-Петербург, улица Черкасова, 4к2	0101000020E6100000D72FD80DDB6A3E406CCF2C0950034E40
81419	3	\N	\N	2	5024	\N	60.028644999999997	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Черкасова, дом 8, корп. 2		0101000020E6100000F3936A9F8E6B3E40D218ADA3AA034E40
81418	3	\N	\N	2	5024	\N	60.027057999999997	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Черкасова, дом 15		0101000020E61000008E959867256D3E402E8CF4A276034E40
81417	3	\N	\N	2	5024	\N	60.024401592705999	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Черкасова, дом 7, корп. 2	Россия, Санкт-Петербург, Калининский район, район Гражданка	0101000020E6100000A3AF20CD586C3E407FFACF9A1F034E40
81702	3	\N	\N	2	8047	\N	59.841589999999997	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Урицк, улица Чекистов, дом 18		0101000020E61000007B116DC7D42D3E4000529B38B9EB4D40
81237	3	\N	\N	2	2712	\N	59.912345999999999	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Екатерингофский, Циолковского улица, дом 8		0101000020E610000054A703594F493E407651F4C0C7F44D40
81313	3	\N	\N	2	3725	\N	59.986916000000001	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, улица Харченко, дом 27	Россия, Санкт-Петербург, улица Харченко, 27	0101000020E61000001E6CB1DB67593E4017F3734353FE4D40
81795	3	\N	\N	2	1172	\N	59.862130999999998	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, улица Фрунзе, дом 12		0101000020E61000007C8159A148533E4013EF004F5AEE4D40
81794	3	\N	\N	2	1172	\N	59.860753000000003	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, улица Фрунзе, дом 13	Россия, Санкт-Петербург, улица Фрунзе, 13	0101000020E6100000C310397D3D533E408A7780272DEE4D40
81446	3	\N	\N	2	5372	\N	60.001162999999998	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Фаворского улица, дом 16	Россия, Санкт-Петербург, улица Фаворского, 16	0101000020E6100000718FA50F5D643E408D7BF31B26004E40
81424	3	\N	\N	2	5072	\N	60.039634	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Ушинского, дом 33, корп. 2	Россия, Санкт-Петербург, улица Ушинского, 33к2	0101000020E6100000187D0569C66A3E40A3E716BA12054E40
81423	3	\N	\N	2	5072	\N	60.034277000000003	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Ушинского, дом 21	Россия, Санкт-Петербург, улица Ушинского, 21	0101000020E6100000EEB3CA4C69693E40A400513063044E40
81422	3	\N	\N	2	5072	\N	60.031601999999999	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Ушинского, дом 13		0101000020E610000086200725CC683E407D3ECA880B044E40
82138	3	\N	\N	2	5708	\N	59.864714999999997	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, улица Турку, дом 21, корп. 2	Россия, Санкт-Петербург, улица Турку, 21к2	0101000020E61000007F2E1A321E653E4029AE2AFBAEEE4D40
82137	3	\N	\N	2	5708	\N	59.868555000000001	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, улица Турку, дом 16		0101000020E6100000AA656B7D91643E407EE36BCF2CEF4D40
82135	3	\N	\N	2	5708	\N	59.865167	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, улица Турку, дом 29, корп. 2		0101000020E61000000FB743C362683E400A4AD1CABDEE4D40
82132	3	\N	\N	2	5708	\N	59.867379999999997	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, улица Турку, дом 30	Россия, Санкт-Петербург, улица Турку, 30	0101000020E610000051F86C1D1C683E402C9ACE4E06EF4D40
81891	3	\N	\N	2	2631	\N	59.893841000000002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невская застава, улица Ткачей, дом 9	Россия, Санкт-Петербург, улица Ткачей, 9к1	0101000020E6100000D90A9A96586D3E407769C36169F24D40
81855	3	\N	\N	2	1981	\N	59.892338000000002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, улица Тельмана, дом 34	Россия, Санкт-Петербург, улица Тельмана, 34	0101000020E6100000C1C6F5EFFA783E40317DAF2138F24D40
81847	3	\N	\N	2	1981	\N	59.891015000000003	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, улица Тельмана, дом 47		0101000020E610000054A9D903AD7C3E406B9F8EC70CF24D40
81718	3	\N	\N	2	50	\N	59.831774000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, улица Тамбасова, дом 26, корп. 1	Россия, Санкт-Петербург, улица Тамбасова, 26	0101000020E6100000698EACFC32283E40E1D4079277EA4D40
81699	3	\N	\N	2	50	\N	59.842463349908002	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица Тамбасова, дом 2, корп. 4	Россия, Санкт-Петербург, улица Тамбасова, 2к4	0101000020E61000009087BEBB95293E40878BDCD3D5EB4D40
12642	7	66	215	6820	62040	\N	55.150534999999998	с.Новочелны-Сюрбеево, Центральная, 57		0101000020E610000044DC9C4A06CA4740A1F31ABB44934B40
81543	3	\N	\N	2	6369	\N	59.825431949769801	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Стойкости, дом 28, корп. 2	Россия, Санкт-Петербург, улица Стойкости, 28к2	0101000020E610000019C8B3CBB7323E4033897AC1A7E94D40
81542	3	\N	\N	2	6369	\N	59.828442000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Стойкости, дом 33		0101000020E61000005281936DE0323E40015130630AEA4D40
81541	3	\N	\N	2	6369	\N	59.826309828755299	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Стойкости, дом 30, корп. 2	Россия, Санкт-Петербург, улица Стойкости, 30к2	0101000020E61000003868AF3E1E323E40CB2DAD86C4E94D40
81537	3	\N	\N	2	6369	\N	59.829673002028599	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Стойкости, дом 17, корп. 2	Россия, Санкт-Петербург, улица Стойкости, 17к2	0101000020E6100000DB8651103C363E40E6AF90B932EA4D40
81605	3	\N	\N	2	7015	\N	59.970262759654098	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Полюстрово, Стасовой улица, дом 4, корп. 2	Россия, Санкт-Петербург, улица Стасовой, 4к2	0101000020E61000003961C268566E3E406AC2F69331FC4D40
81200	3	\N	\N	2	2134	\N	59.922170000000001	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Коломна, Союза Печатников улица, дом 26		0101000020E6100000D4D2DC0A61493E4019ADA3AA09F64D40
81452	3	\N	\N	2	4993	\N	60.0152854733334	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Софьи Ковалевской улица, дом 13, корп. 6	Россия, Санкт-Петербург, улица Софьи Ковалевской, 13к6	0101000020E6100000BEA3C684986B3E40478FDFDBF4014E40
81415	3	\N	\N	2	4993	\N	60.013755719883399	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, улица Софьи Ковалевской, дом 8, корп. 3	Россия, Санкт-Петербург, улица Софьи Ковалевской, 8к3	0101000020E61000008D9944BDE0673E40D80FB1C1C2014E40
81534	3	\N	\N	2	6338	\N	59.827142614909	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Солдата Корзуна, дом 15, корп. 2	Россия, Санкт-Петербург, улица Солдата Корзуна, 15к2	0101000020E6100000DB6FED4449383E40C30E63D2DFE94D40
81309	3	\N	\N	2	3671	\N	59.970578000000003	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, Смолячкова улица, дом 13		0101000020E6100000A2258FA7E5573E40CA1B60E63BFC4D40
81381	3	\N	\N	2	4591	\N	60.059274000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Симонова, дом 8, корп. 1	Россия, Санкт-Петербург, улица Симонова, 8	0101000020E610000078279F1EDB523E4066C0594A96074E40
81380	3	\N	\N	2	4591	\N	60.059274000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Симонова, дом 8, корп. 2	Россия, Санкт-Петербург, улица Симонова, 8	0101000020E610000078279F1EDB523E4066C0594A96074E40
81344	3	\N	\N	2	4094	\N	60.033421668998997	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, улица Сикейроса, дом 5, корп. 2	Россия, Санкт-Петербург, улица Сикейроса, 5к2	0101000020E6100000C79FA86C58533E40C47B0E2C47044E40
81342	3	\N	\N	2	4094	\N	60.034613999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, улица Сикейроса, дом 19, корп. 1	Россия, Санкт-Петербург, улица Сикейроса, 19к1	0101000020E6100000527C7C4276563E40EBFD463B6E044E40
81341	3	\N	\N	2	4094	\N	60.034528000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, улица Сикейроса, дом 17, корп. 1	Россия, Санкт-Петербург, улица Сикейроса, 17к1	0101000020E61000004240BE840A563E40ED65DB696B044E40
81895	3	\N	\N	2	2649	\N	59.879381413176802	ул. Седова, д. 66 (школа 336) тел. 417-24-49	Россия, Санкт-Петербург, улица Седова, 66	0101000020E61000004510E7E1046E3E40A5DC7D8E8FF04D40
81894	3	\N	\N	2	2649	\N	59.879537999999997	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Седова, дом 66		0101000020E61000000D33349E086E3E406CCB80B394F04D40
81893	3	\N	\N	2	2649	\N	59.885553000000002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Седова, дом 56	Россия, Санкт-Петербург, улица Седова, 56	0101000020E6100000850A0E2F886C3E40F6EFFACC59F14D40
81351	3	\N	\N	2	4145	\N	60.034326501455503	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, улица Сантьяго-де-Куба, дом 4, корп.2	Россия, Санкт-Петербург, улица Сантьяго-де-Куба, 4к2	0101000020E6100000EACBD24ECD593E40552FBFD364044E40
81346	3	\N	\N	2	4145	\N	60.034367000000003	Сантьяго-де-Куба ул., дом № 4 корп. 2, Дворец детского и юношеского творчества, тел. 510-63-09	Россия, Санкт-Петербург, улица Сантьяго-де-Куба, 4к2	0101000020E6100000BC41B456B4593E40E4874A2366044E40
82021	3	\N	\N	2	4192	\N	59.987622999999999	"Савушкина ул., д. 5  (Медицинское училище № 9) 430-84-51 "	Россия, Санкт-Петербург, улица Савушкина, 5	0101000020E61000002D9622F94A4C3E4082E3326E6AFE4D40
13135	7	66	\N	61	61768	\N	56.081045000000003	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Ашмарина, д.15		0101000020E6100000412C9B3924A347408E40BCAE5F0A4C40
82009	3	\N	\N	2	4192	\N	59.986564999999999	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Савушкина, дом 111, корп. 2	Россия, Санкт-Петербург, улица Савушкина, 111к2	0101000020E6100000BEF6CC92003D3E406A300DC347FE4D40
82008	3	\N	\N	2	4192	\N	59.986564999999999	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Савушкина, дом 111, корп.2	Россия, Санкт-Петербург, улица Савушкина, 111к2	0101000020E6100000BEF6CC92003D3E406A300DC347FE4D40
81481	3	\N	\N	2	5562	\N	60.008319999999998	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Руставели улица, дом 26	Россия, Санкт-Петербург, улица Руставели, 26	0101000020E6100000E318C91EA16E3E408CF337A110014E40
81461	3	\N	\N	2	5562	\N	60.008319999999998	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Руставели улица, дом 26	Россия, Санкт-Петербург, улица Руставели, 26	0101000020E6100000E318C91EA16E3E408CF337A110014E40
81356	3	\N	\N	2	3936	\N	60.040443000000003	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ N15, улица Руднева, дом 5, корп. 3		0101000020E6100000DB317557765D3E40132D793C2D054E40
81329	3	\N	\N	2	3936	\N	60.049239999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ N15, улица Руднева, дом 23		0101000020E61000000E4C6E14595F3E40D8D30E7F4D064E40
81684	3	\N	\N	2	7877	\N	59.849344396103398	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, улица Рихарда Зорге, дом 13, корп. 2	Россия, Санкт-Петербург, улица Рихарда Зорге, 13к2	0101000020E6100000081EDFDE35303E40E486DF4DB7EC4D40
81953	3	\N	\N	2	3251	\N	59.971632	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, улица Профессора Попова, дом 37-Б	Россия, Санкт-Петербург, улица Профессора Попова, 37б	0101000020E6100000105B7A34D54B3E40A0DFF76F5EFC4D40
82226	3	\N	\N	2	6656	\N	59.944941	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Пролетарской Диктатуры, дом 1	Россия, Санкт-Петербург, улица Пролетарской Диктатуры, 1	0101000020E610000040A4DFBE0E643E4024D3A1D3F3F84D40
81509	3	\N	\N	2	6090	\N	59.869128000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Примакова, дом 10		0101000020E61000002FE065868D463E40DA0418963FEF4D40
81723	3	\N	\N	2	149	\N	59.781723	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Горелово, улица Политрука Пасечника, дом 3	Россия, Санкт-Петербург, улица Политрука Пасечника, 3	0101000020E61000001C7C6132551C3E40F8C3CF7F0FE44D40
81874	3	\N	\N	2	2371	\N	59.920045000000002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Оккервиль, улица Подвойского, дом 50, корп.4	Россия, Санкт-Петербург, улица Подвойского, 50к1	0101000020E61000009CDCEF5014803E4096ECD808C4F54D40
81520	3	\N	\N	2	6205	\N	59.84225	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, улица Подводника Кузьмина, дом 52	Россия, Санкт-Петербург, улица Подводника Кузьмина, 52	0101000020E6100000850838842A453E402B8716D9CEEB4D40
81717	3	\N	\N	2	4	\N	59.832453000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, улица Пограничника Гарькавого, дом 36, корп. 1	Россия, Санкт-Петербург, улица Пограничника Гарькавого, 36к1	0101000020E6100000F3AFE595EB253E40823AE5D18DEA4D40
81716	3	\N	\N	2	4	\N	59.8322689338572	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, улица Пограничника Гарькавого, дом 36, корп. 6	Россия, Санкт-Петербург, улица Пограничника Гарькавого, 36к6	0101000020E6100000546EA296E6263E40C03C64CA87EA4D40
81697	3	\N	\N	2	4	\N	59.841119999999997	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица Пограничника Гарькавого, дом 14	Россия, Санкт-Петербург, улица Пограничника Гарькавого, 14к1	0101000020E61000008597E0D407263E407901F6D1A9EB4D40
81695	3	\N	\N	2	4	\N	59.838692999999999	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица Пограничника Гарькавого, дом 22	Россия, Санкт-Петербург, улица Пограничника Гарькавого, 22к1	0101000020E6100000A60C1CD0D2253E402B31CF4A5AEB4D40
81692	3	\N	\N	2	7013	\N	59.8405094040424	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица Пионерстроя, дом 10, корп. 2	Россия, Санкт-Петербург, улица Пионерстроя, 10к2	0101000020E61000003ECE3461FB213E40307F85CC95EB4D40
81691	3	\N	\N	2	7013	\N	59.844116999999997	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица Пионерстроя, дом 9, корп. 1	Россия, Санкт-Петербург, улица Пионерстроя, 9	0101000020E6100000F4A5B73F17213E40B27F9E060CEC4D40
13109	7	66	\N	21149	61394	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Пионерская, д.3		0101000020E61000006C257497C4BF474031B2648EE50B4C40
81397	3	\N	\N	2	16098	\N	60.073575276834703	Город Санкт-Петербург, Выборгский район, муниципальное образование поселок Парголово, улица Первого Мая, дом 109	Россия, Санкт-Петербург, посёлок Парголово, улица Первого Мая	0101000020E610000005F9D9C8753B3E40CF66D5E76A094E40
81604	3	\N	\N	2	7002	\N	59.951433999999999	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Панфилова улица, дом 23	Россия, Санкт-Петербург, улица Панфилова, 23	0101000020E6100000F1B913ECBF6A3E40B726DD96C8F94D40
81639	3	\N	\N	2	7352	\N	59.947655815418003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Осипенко, дом 5, корп. 2	Россия, Санкт-Петербург, улица Осипенко, 5к2	0101000020E6100000A2B60DA3207C3E40D9EDB3CA4CF94D40
81638	3	\N	\N	2	7352	\N	59.947709635229998	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Осипенко, дом 5, кор. 2	Россия, Санкт-Петербург, улица Осипенко, 5к2	0101000020E6100000A58636001B7C3E40CC0BB08F4EF94D40
81807	3	\N	\N	2	1439	\N	59.844926999999998	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, улица Орджоникидзе, дом 18	Россия, Санкт-Петербург, улица Орджоникидзе, 18	0101000020E61000002D5E2C0C91533E40F240649126EC4D40
81304	3	\N	\N	2	3596	\N	60.005225000000003	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Орбели улица, дом 24		0101000020E610000087C1FC1532573E40910F7A36AB004E40
82004	3	\N	\N	2	4127	\N	60.001805539167002	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Оптиков, дом 46, корп. 3	Россия, Санкт-Петербург, улица Оптиков	0101000020E6100000C85EEFFE78333E40E277D32D3B004E40
82003	3	\N	\N	2	4127	\N	60.004996371388103	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Оптиков, дом 47, корп. 5	Россия, Санкт-Петербург, Камышовая улица, 47к5	0101000020E6100000C289E8D7D6333E402F4E7CB5A3004E40
81436	3	\N	\N	2	5241	\N	60.043328347215301	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Ольги Форш, дом 17, корп. 2	Россия, Санкт-Петербург, улица Ольги Форш, 17к2	0101000020E6100000861E317A6E653E4024809BC58B054E40
81889	3	\N	\N	2	2583	\N	59.895009999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невская застава, улица Ольги Берггольц, дом 15	Россия, Санкт-Петербург, улица Ольги Берггольц, 15	0101000020E6100000F836FDD98F6C3E40E6CB0BB08FF24D40
82173	3	\N	\N	2	6071	\N	59.828727779591702	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Олеко Дундича, дом 25, корп. 3	Россия, Санкт-Петербург, улица Олеко Дундича, 25к3	0101000020E61000001B7FA2B261693E40C6A354C213EA4D40
82171	3	\N	\N	2	6071	\N	59.832116446091497	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Олеко Дундича, дом 26, корп. 2	Россия, Санкт-Петербург, улица Олеко Дундича, 26к2	0101000020E61000008DB454DE8E683E403A3DEFC682EA4D40
82167	3	\N	\N	2	6071	\N	59.832729	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N75, улица Олеко Дундича, дом 37, корп. 2	Россия, Санкт-Петербург, улица Олеко Дундича, 37к2	0101000020E610000072FA7ABE666D3E4024B726DD96EA4D40
82166	3	\N	\N	2	6071	\N	59.836895216298103	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N75, улица Олеко Дундича, дом 38, корп. 3	Россия, Санкт-Петербург, улица Олеко Дундича, 38к3	0101000020E610000069C878944A6C3E40CC9717601FEB4D40
81838	3	\N	\N	2	1861	\N	59.882510000000003	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, улица Новоселов, дом 21		0101000020E6100000853E58C686763E404D327216F6F04D40
81277	3	\N	\N	2	3248	\N	59.9428638188893	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Нахимова, дом 8, корп. 2	Россия, Санкт-Петербург, улица Нахимова, 8к2	0101000020E6100000810706103E3C3E40B2497EC4AFF84D40
82233	3	\N	\N	2	6732	\N	59.937274000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Моисеенко, дом 19		0101000020E6100000CFD90242EB613E4010B22C98F8F74D40
81606	3	\N	\N	2	7000	\N	59.967416999999998	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Полюстрово, Маршала Тухачевского улица, дом 17	Россия, Санкт-Петербург, улица Маршала Тухачевского, 17	0101000020E610000065E1EB6B5D6E3E40164CFC51D4FB4D40
81603	3	\N	\N	2	7000	\N	59.970861999999997	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Полюстрово, Маршала Тухачевского улица, дом 29		0101000020E61000007D76C075C56C3E40EE76BD3445FC4D40
82053	3	\N	\N	2	4738	\N	60.015659999999997	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, улица Маршала Новикова, дом 15, корп. 1	Россия, Санкт-Петербург, улица Маршала Новикова, 15к1	0101000020E6100000E2900DA48B453E407CED992501024E40
13475	7	66	939	48061	\N	\N	55.999329000000003	село Никольское, Солнечная, 20	Россия, республика Чувашская, Ядринский район, село Никольское	0101000020E610000018B0E42A16194740E2783E03EAFF4B40
81678	3	\N	\N	2	7823	\N	59.858783000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, улица Маршала Казакова, дом 30	Россия, Санкт-Петербург, улица Маршала Казакова, 30	0101000020E61000006BD26D895C383E402EAEF199ECED4D40
81690	3	\N	\N	2	7669	\N	59.855308000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, улица Маршала Захарова, дом 28	Россия, Санкт-Петербург, улица Маршала Захарова, 28	0101000020E6100000F355F2B1BB303E40EB0088BB7AED4D40
81686	3	\N	\N	2	7669	\N	59.855308000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, улица маршала Захарова, дом 28	Россия, Санкт-Петербург, улица Маршала Захарова, 28	0101000020E6100000F355F2B1BB303E40EB0088BB7AED4D40
81674	3	\N	\N	2	7669	\N	59.851187000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, улица Маршала Захарова, дом 58		0101000020E61000000A4D124BCA353E40E3E313B2F3EC4D40
81673	3	\N	\N	2	7669	\N	59.851187000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, улица Маршала  Захарова, дом 58	Россия, Санкт-Петербург, улица Маршала Захарова, 58	0101000020E61000000A4D124BCA353E40E3E313B2F3EC4D40
81672	3	\N	\N	2	7669	\N	59.851837000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, улица Маршала Захарова, дом 52, корп. 1	Россия, Санкт-Петербург, улица Маршала Захарова, 52	0101000020E6100000FDA19927D7343E40EA42ACFE08ED4D40
81501	3	\N	\N	2	5973	\N	59.877046	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Маршала Говорова, дом 9	Россия, Санкт-Петербург, улица Маршала Говорова, 9	0101000020E6100000EC89AE0B3F443E40378B170B43F04D40
81498	3	\N	\N	2	5973	\N	59.882731	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Маршала Говорова, дом 18	Россия, Санкт-Петербург, улица Маршала Говорова, 18	0101000020E6100000782634492C453E402B155454FDF04D40
81508	3	\N	\N	2	6072	\N	59.867873000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Маринеско, дом 7	Россия, Санкт-Петербург, улица Маринеско, 7	0101000020E610000002BA2F67B6433E406C0A647616EF4D40
81712	3	\N	\N	2	8138	\N	59.828496000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, улица Летчика Пилютова, дом 50		0101000020E6100000DF6DDE3829243E40F46E2C280CEA4D40
81554	3	\N	\N	2	6487	\N	59.844639289758298	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, улица Лени Голикова, дом 15, корп. 2	Россия, Санкт-Петербург, улица Лёни Голикова, 15к2	0101000020E6100000878BDCD3D5393E408CF678211DEC4D40
81549	3	\N	\N	2	6487	\N	59.837679999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, улица Лени Голикова, дом 78		0101000020E61000003672DD94F23E3E40B341261939EB4D40
81812	3	\N	\N	2	1479	\N	59.836916000000002	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, улица Ленсовета, дом 68		0101000020E610000078B471C45A583E40E4BF401020EB4D40
81809	3	\N	\N	2	1479	\N	59.8421575393712	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, улица Ленсовета, дом 43А	Россия, Санкт-Петербург, улица Ленсовета, 43а	0101000020E610000071917BBABA533E404A0856D5CBEB4D40
81879	3	\N	\N	2	2426	\N	59.929552080821502	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, улица Латышских Стрелков, дом 9, корп.3	Россия, Санкт-Петербург, улица Латышских Стрелков, 9к3	0101000020E610000075AC527AA6773E4038F7578FFBF64D40
81878	3	\N	\N	2	2426	\N	59.928077000000002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, улица Латышских Стрелков, дом 9, корп.1	Россия, Санкт-Петербург, улица Латышских Стрелков, 9к1	0101000020E6100000A6D3BA0D6A773E40BC95253ACBF64D40
81854	3	\N	\N	2	2033	\N	59.895958	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, улица Крыленко, дом 25, корп. 5	Россия, Санкт-Петербург, улица Крыленко, 25к5	0101000020E6100000E99E758D967B3E40774B72C0AEF24D40
81851	3	\N	\N	2	2033	\N	59.896635356477503	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, улица Крыленко, дом 33, корп.2	Россия, Санкт-Петербург, улица Крыленко, 33к2	0101000020E6100000D0285DFA977C3E4078B988EFC4F24D40
81679	3	\N	\N	2	7838	\N	59.857451443735997	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, улица Котина, дом 6, корп. 3	Россия, Санкт-Петербург, улица Котина, 6к3	0101000020E6100000C7F0D8CF62353E40147651F4C0ED4D40
81826	3	\N	\N	2	1668	\N	59.846209999999999	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Костюшко, дом 62	Россия, Санкт-Петербург, улица Костюшко, 62	0101000020E61000002CB7B41A124F3E402AC6F99B50EC4D40
13488	7	66	939	33121	61834	\N	55.784643000000003	село Николаевское, Ленина, 2		0101000020E61000006BD44334BA33474086048C2E6FE44B40
81824	3	\N	\N	2	1668	\N	59.848573999999999	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Костюшко, дом 34	Россия, Санкт-Петербург, улица Костюшко, 34	0101000020E6100000CCD42478434E3E40321EA5129EEC4D40
81292	3	\N	\N	2	3412	\N	59.9583227021092	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, улица Кораблестроителей, дом 42, корп. 2	Россия, Санкт-Петербург, улица Кораблестроителей, 42к2	0101000020E61000007C9BFEEC473A3E409700FC53AAFA4D40
81291	3	\N	\N	2	3412	\N	59.957364079352097	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, улица Кораблестроителей, дом 38, корп. 2	Россия, Санкт-Петербург, улица Кораблестроителей, 38к2	0101000020E61000007A6EA12B11383E40122F4FE78AFA4D40
81394	3	\N	\N	2	4667	\N	60.06024	"Композиторов ул., дом № 22 корп. 2, школа № 494, тел. 515-74-81,  515-86-35,"	Россия, Санкт-Петербург, улица Композиторов, 22к2	0101000020E6100000CFC0C8CB9A503E409DF4BEF1B5074E40
81388	3	\N	\N	2	4667	\N	60.0600352205742	Композиторов ул., дом № 22 к. 2, школа № 494, тел. 515-86-35,   515-74-81		0101000020E6100000A323B9FC87503E40C4CE143AAF074E40
81387	3	\N	\N	2	4667	\N	60.0536687678945	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Композиторов, дом 11, корп. 2	Россия, Санкт-Петербург, улица Композиторов, 11к2	0101000020E61000001349F4328A513E408EE733A0DE064E40
81651	3	\N	\N	2	16660	\N	59.953743289328699	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, улица Коммуны, дом 42, корп. 3	Россия, Санкт-Петербург, улица Коммуны, 42к2	0101000020E61000009F3C2CD49A7E3E40FCE4284014FA4D40
81307	3	\N	\N	2	3644	\N	59.962142999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, Комиссара Смирнова улица, дом 17	Россия, Санкт-Петербург, улица Комиссара Смирнова, 17	0101000020E61000004A404CC285583E40A489778027FB4D40
81533	3	\N	\N	2	6326	\N	59.828933999999997	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Козлова, дом 47, корп. 1	Россия, Санкт-Петербург, улица Козлова, 47к2	0101000020E61000007C9DD497A5393E406F4562821AEA4D40
81532	3	\N	\N	2	6326	\N	59.831792999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Козлова, дом 37, корп. 1	Россия, Санкт-Петербург, улица Козлова, 37к1	0101000020E6100000D0F1D1E28C393E4057056A3178EA4D40
81899	3	\N	\N	2	2762	\N	59.866143000000001	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Кибальчича, дом 8/2	Россия, Санкт-Петербург, улица Кибальчича, 8к2	0101000020E6100000F163CC5D4B703E40655419C6DDEE4D40
81453	3	\N	\N	2	5478	\N	60.013137	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Карпинского улица, дом 38, корп. 8	Россия, Санкт-Петербург, улица Карпинского, 38	0101000020E6100000882D3D9AEA6D3E400CAF2479AE014E40
81559	3	\N	\N	2	6544	\N	59.849246472991197	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, улица Зины Портновой, дом 21, корп. 4	Россия, Санкт-Петербург, улица Зины Портновой, 21к4	0101000020E61000008352B4722F403E402121CA17B4EC4D40
81556	3	\N	\N	2	6544	\N	59.854467999999997	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, улица Зины Портновой, дом 15	Россия, Санкт-Петербург, улица Зины Портновой, 15	0101000020E61000005E9ECE15A5403E4040BD19355FED4D40
81719	3	\N	\N	2	71	\N	59.826930179197497	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, улица Здоровцева, дом 33, корп. 2	Россия, Санкт-Петербург, улица Здоровцева, 33к2	0101000020E610000044882B67EF283E40670A9DD7D8E94D40
81499	3	\N	\N	2	5984	\N	59.879268000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Зайцева, дом 28		0101000020E61000009B3BFA5FAE453E40AD3594DA8BF04D40
81376	3	\N	\N	2	4483	\N	60.047344000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, улица Есенина, дом 24		0101000020E610000000E2AE5E45563E40B7D4415E0F064E40
81375	3	\N	\N	2	4483	\N	60.046818581523702	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, улица Есенина, дом 22, корп. 3	Россия, Санкт-Петербург, улица Есенина, 22к3	0101000020E61000002CF52C08E5553E406CEA3C2AFE054E40
81373	3	\N	\N	2	4483	\N	60.053820488160198	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, улица Есенина, дом 34, корп. 2	Россия, Санкт-Петербург, улица Есенина, 34к2	0101000020E61000008E942D9276573E4074EFE192E3064E40
81372	3	\N	\N	2	4483	\N	60.054947638855197	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, улица Есенина, дом 36, корп. 2	Россия, Санкт-Петербург, улица Есенина, 36к2	0101000020E6100000377007EA94573E40857D3B8908074E40
81232	3	\N	\N	2	2618	\N	59.910862000000002	ул.Егорова, д.24, ГОУ СОШ № 564	Россия, Санкт-Петербург, улица Егорова, 24	0101000020E6100000CFA3E2FF8E503E40A795422097F44D40
13483	7	66	939	48216	62804	\N	55.894807999999998	деревня Никиткино, Ленина, 20		0101000020E61000001FD61BB5C23C47407E198C1189F24B40
82155	3	\N	\N	2	5916	\N	59.848627999999998	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Димитрова, дом 15, корп. 3	Россия, Санкт-Петербург, улица Димитрова, 15к1	0101000020E61000006CB587BD50643E40253CA1D79FEC4D40
82154	3	\N	\N	2	5916	\N	59.844811206037299	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Димитрова, дом 9, корп. 3	Россия, Санкт-Петербург, улица Димитрова, 9к3	0101000020E61000006D3997E2AA623E40892650C422EC4D40
81881	3	\N	\N	2	2448	\N	59.920834999999997	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, улица Джона Рида, дом 6	Россия, Санкт-Петербург, улица Джона Рида, 6	0101000020E610000008AC1C5A64733E408E01D9EBDDF54D40
81880	3	\N	\N	2	2448	\N	59.919522000000001	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, улица Джона Рида, дом 3, корп.1	Россия, Санкт-Петербург, улица Джона Рида, 3к1	0101000020E6100000B0C91AF510753E40ECF99AE5B2F54D40
81433	3	\N	\N	2	5147	\N	60.044622796367797	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Северный, улица Демьяна Бедного, дом 22, корп. 5	Россия, Санкт-Петербург, улица Демьяна Бедного, 22к5	0101000020E610000059F8FA5A97623E4020D3DA34B6054E40
81428	3	\N	\N	2	5147	\N	60.036764090963601	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Северный, улица Демьяна Бедного, дом 6, корп. 2	Россия, Санкт-Петербург, улица Демьяна Бедного, 6к2	0101000020E6100000A77686A92D613E40C7D5C8AEB4044E40
81755	3	\N	\N	2	16580	\N	60.011339424129702	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Гидростроителей, дом 6	Россия, Санкт-Петербург, Кронштадт, улица Гидростроителей, 4	0101000020E610000003CE52B29CB83D40AD156D8E73014E40
82230	3	\N	\N	2	6700	\N	59.933428999999997	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Восстания, дом 8	Россия, Санкт-Петербург, улица Восстания, 8	0101000020E6100000FED137691A5C3E40A911FA997AF74D40
81480	3	\N	\N	2	5422	\N	60.002892663058603	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Верности улица, дом 38, корп.4	Россия, Санкт-Петербург, улица Верности, 38к4	0101000020E61000001D1CEC4D0C6D3E4094313ECC5E004E40
81479	3	\N	\N	2	5422	\N	60.002817441183701	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Верности улица, дом 38, корп. 4	Россия, Санкт-Петербург, улица Верности, 38к4	0101000020E6100000187C9A93176D3E40B96FB54E5C004E40
81450	3	\N	\N	2	5422	\N	60.006381392617499	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Верности улица, дом 14, корп. 4	Россия, Санкт-Петербург, улица Верности, 14к4	0101000020E6100000F564FED137693E406B28B517D1004E40
81449	3	\N	\N	2	5422	\N	60.005762467661199	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Верности улица, дом 28, корп. 4	Россия, Санкт-Петербург, улица Верности, 28к4	0101000020E6100000514EB4AB906A3E409FC728CFBC004E40
81411	3	\N	\N	2	4923	\N	60.0167640500079	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, улица Вавиловых, дом 5, корп. 5	Россия, Санкт-Петербург, улица Вавиловых, 5к5	0101000020E6100000938E72309B643E4005E09F5225024E40
81410	3	\N	\N	2	4923	\N	60.019795264593398	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, улица Вавиловых, дом 8, корп. 2	Россия, Санкт-Петербург, улица Вавиловых, 8к2	0101000020E610000087C3D2C08F623E40EACF7EA488024E40
81447	3	\N	\N	2	5396	\N	60.003794999999997	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Бутлерова улица, дом 22, корп. 1	Россия, Санкт-Петербург, улица Бутлерова, 22	0101000020E61000008EB0A888D3653E40B471C45A7C004E40
81539	3	\N	\N	2	6370	\N	59.835546000000001	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Бурцева, дом 9		0101000020E610000027D9EA724A343E40DD26DC2BF3EA4D40
81538	3	\N	\N	2	6370	\N	59.836829999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, улица Бурцева, дом 12		0101000020E6100000CF4A5AF10D353E40E527D53E1DEB4D40
81444	3	\N	\N	2	5293	\N	60.035177547998799	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Брянцева, дом 10	Россия, Санкт-Петербург, улица Брянцева, 6	0101000020E6100000FF942A51F6663E40F4C473B680044E40
81439	3	\N	\N	2	5293	\N	60.040725999999999	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Брянцева, дом 24	Россия, Санкт-Петербург, улица Брянцева, 24	0101000020E6100000DECB7D7214683E40670C738236054E40
81916	3	\N	\N	2	2988	\N	59.952705000000002	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Введенский, улица Блохина, дом 31		0101000020E6100000D63BDC0E0D4B3E402BDEC83CF2F94D40
81821	3	\N	\N	2	1564	\N	59.855086999999997	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Кубинская, дом 62		0101000020E610000017299485AF4B3E400C1EA67D73ED4D40
82123	3	\N	\N	2	5585	\N	59.877693160094097	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, улица Белы Куна, дом 24, корп. 2	Россия, Санкт-Петербург, улица Белы Куна, 24к2	0101000020E6100000483140A209643E40CD76853E58F04D40
81905	3	\N	\N	2	2699	\N	59.862212	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Обуховский, улица Бабушкина, дом 119	Россия, Санкт-Петербург, улица Бабушкина, 119	0101000020E610000016DD7A4D0F763E40001C7BF65CEE4D40
81901	3	\N	\N	2	2699	\N	59.869475999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Бабушкина, дом 56, корп. 1		0101000020E6100000F4FBFECD8B733E40155454FD4AEF4D40
81898	3	\N	\N	2	2699	\N	59.874096999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Бабушкина, дом 50		0101000020E6100000E9279CDD5A723E400F441669E2EF4D40
81896	3	\N	\N	2	2699	\N	59.878616999999998	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Бабушкина, дом 65		0101000020E61000002A1DACFF73703E40D55A988576F04D40
81384	3	\N	\N	2	4624	\N	60.049742999999999	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Асафьева, дом 6	Россия, Санкт-Петербург, улица Асафьева, 6к1	0101000020E61000000A664CC11A533E403B1A87FA5D064E40
81406	3	\N	\N	2	4874	\N	60.020858301199503	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, улица академика Константинова, дом 10, корп. 2	Россия, Санкт-Петербург, улица Академика Константинова, 10к2	0101000020E610000005DD5ED218613E4013EE9579AB024E40
81408	3	\N	\N	2	4897	\N	60.026617000000002	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, улица академика Байкова, дом 15	Россия, Санкт-Петербург, улица Академика Байкова, 15	0101000020E6100000200BD12170603E404242942F68034E40
81808	3	\N	\N	2	1264	\N	59.847208999999999	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, проспект Юрия Гагарина, дом 51	Россия, Санкт-Петербург, проспект Юрия Гагарина, 51	0101000020E61000000490DAC4C9553E403DF0315871EC4D40
81798	3	\N	\N	2	1264	\N	59.857332	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, проспект Юрия Гагарина, дом 22, корп. 3	Россия, Санкт-Петербург, проспект Юрия Гагарина, 22к1	0101000020E61000000B2769FE98563E403AE8120EBDED4D40
81797	3	\N	\N	2	1264	\N	59.860787769331203	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, проспект Юрия Гагарина, дом 16, корп. 2		0101000020E6100000FC8A355CE4563E4006651A4D2EEE4D40
81653	3	\N	\N	2	7492	\N	59.953452630301697	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, проспект Энтузиастов, дом 46, корп. 3	Россия, Санкт-Петербург, проспект Энтузиастов, 46к3	0101000020E61000006BB8C83D5D7D3E40F5A276BF0AFA4D40
81650	3	\N	\N	2	7492	\N	59.950513105731503	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, проспект Энтузиастов, дом 47, корп. 2	Россия, Санкт-Петербург, проспект Энтузиастов, 47к2	0101000020E610000002D6AA5D137E3E4020B6F468AAF94D40
81617	3	\N	\N	2	7145	\N	59.934897999999997	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Энергетиков проспект, дом 4, корп. 2	Россия, Санкт-Петербург, проспект Энергетиков, 4к2	0101000020E6100000F7AB00DF6D6E3E40438CD7BCAAF74D40
81348	3	\N	\N	2	3573	\N	60.039215336956801	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, проспект Энгельса, дом 115, корп. 2	Россия, Санкт-Петербург, проспект Энгельса, 115к2	0101000020E6100000A2427573F1533E409E4143FF04054E40
81334	3	\N	\N	2	3573	\N	60.010424999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, проспект Энгельса, дом 42	Россия, Санкт-Петербург, проспект Энгельса, 42	0101000020E61000009E077767ED523E40C8073D9B55014E40
81328	3	\N	\N	2	3573	\N	60.041336999999999	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, проспект Энгельса, дом 119	Россия, Санкт-Петербург, проспект Энгельса, 119	0101000020E610000053EA92718C543E40B08EE3874A054E40
81322	3	\N	\N	2	3573	\N	60.003591999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, проспект Энгельса, дом 23	Россия, Санкт-Петербург, проспект Энгельса, 23	0101000020E6100000C8D0B1834A543E407C43E1B375004E40
81303	3	\N	\N	2	3573	\N	60.003591999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Энгельса проспект, дом 23	Россия, Санкт-Петербург, проспект Энгельса, 23	0101000020E6100000C8D0B1834A543E407C43E1B375004E40
81626	3	\N	\N	2	7238	\N	59.928496000000003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Шаумяна проспект, дом 36	Россия, Санкт-Петербург, проспект Шаумяна, 36	0101000020E61000003F8C101E6D6C3E40C13BF9F4D8F64D40
13479	7	66	939	15193	62124	\N	55.936715999999997	деревня Нижние Мочары, Садовая, 49		0101000020E6100000EF6FD05E7D344740E9D1544FE6F74B40
81366	3	\N	\N	2	4143	\N	60.046086000000003	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, проспект Художников, дом 24, корп. 2	Россия, Санкт-Петербург, проспект Художников, 24к1	0101000020E61000008ECD8E54DF593E40D8666325E6054E40
81362	3	\N	\N	2	4143	\N	60.044302000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ N15, проспект Художников, дом 29, корп. 3	Россия, Санкт-Петербург, проспект Художников, 29к3	0101000020E610000015731074B45A3E40DE921CB0AB054E40
81345	3	\N	\N	2	4143	\N	60.035257979859402	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, проспект Художников, дом 9, корп. 3	Россия, Санкт-Петербург, проспект Художников, 9к3	0101000020E61000008928266F80593E4010768A5583044E40
81645	3	\N	\N	2	7372	\N	59.948480930779198	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, проспект Ударников, дом 17, корп. 2	Россия, Санкт-Петербург, проспект Ударников, 17к2	0101000020E61000009CA4F9635A773E404EF04DD367F94D40
81644	3	\N	\N	2	7372	\N	59.951685835869299	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, проспект Ударников, дом 22, корп. 3		0101000020E6100000A5BDC11726773E40D107CBD8D0F94D40
81640	3	\N	\N	2	7372	\N	59.952199999999998	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, проспект Ударников, дом 31	Россия, Санкт-Петербург, проспект Ударников, 31	0101000020E61000004852D2C3D07A3E4027A089B0E1F94D40
81338	3	\N	\N	2	3807	\N	60.017350999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, проспект Тореза, дом 94	Россия, Санкт-Петербург, проспект Тореза, 94	0101000020E61000001F48DE3994553E40C5C6BC8E38024E40
81319	3	\N	\N	2	3807	\N	60.008750878802502	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, проспект Тореза, дом 37, корп. 1	Россия, Санкт-Петербург, проспект Тореза, 37	0101000020E6100000643F8BA5485A3E405567B5C01E014E40
81557	3	\N	\N	2	6519	\N	59.854182999999999	пр. Стачек д.158 СПб ГБУ Центр досуга Кировец	Россия, Санкт-Петербург, проспект Стачек, 158	0101000020E6100000C79FA86C583F3E404BE658DE55ED4D40
81553	3	\N	\N	2	6519	\N	59.848502000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, проспект Стачек, дом 206	Россия, Санкт-Петербург, проспект Стачек, 206	0101000020E6100000F8C610001C3B3E40994BAAB69BEC4D40
81527	3	\N	\N	2	6519	\N	59.857101999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Красненькая речка, проспект Стачек, дом 103, корп. 2	Россия, Санкт-Петербург, проспект Стачек, 103к2	0101000020E610000044A852B3073E3E4008ABB184B5ED4D40
81877	3	\N	\N	2	2308	\N	59.927576592252002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, проспект Солидарности, дом 1, корп.2	Россия, Санкт-Петербург, проспект Солидарности, 1к2	0101000020E6100000EC34D252797B3E40CAC2D7D7BAF64D40
81876	3	\N	\N	2	2308	\N	59.925558574193502	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, проспект Солидарности, дом 3, корп.4	Россия, Санкт-Петербург, проспект Солидарности, 3к4	0101000020E61000000C5872158B7B3E405DC2A1B778F64D40
81871	3	\N	\N	2	2308	\N	59.9194414987385	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Оккервиль, проспект Солидарности, дом 11, корп.2	Россия, Санкт-Петербург, проспект Солидарности, 11к2	0101000020E6100000C64E78094E7D3E40FFCC203EB0F54D40
82148	3	\N	\N	2	5786	\N	59.8552710315873	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, проспект Славы, дом 35, корп. 2	Россия, Санкт-Петербург, проспект Славы, 35к2	0101000020E6100000E4839ECDAA633E40CE1B278579ED4D40
82147	3	\N	\N	2	5786	\N	59.856890269254897	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Купчино, проспект Славы, дом 6, корп. 2	Россия, Санкт-Петербург, проспект Славы, 6к2	0101000020E6100000F35487DC0C5F3E407D224F92AEED4D40
82139	3	\N	\N	2	5786	\N	59.862293999999999	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, проспект Славы, дом 40, корп. 5	Россия, Санкт-Петербург, проспект Славы, 40к5	0101000020E6100000BA4DB857E6653E40BDC458A65FEE4D40
82028	3	\N	\N	2	15316	\N	60.015586162074101	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, проспект Сизова, дом 32, корп. 3		0101000020E6100000302B14E97E463E404223D8B8FE014E40
81205	3	\N	\N	2	13285	\N	59.9240095932103	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Сенной округ, Римского-Корсакова проспект, дом 4/38		0101000020E61000001C3F541A314F3E40A796ADF545F64D40
81318	3	\N	\N	2	3780	\N	60.014139999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, проспект Раевского, дом 18	Россия, Санкт-Петербург, проспект Раевского, 18	0101000020E610000047C7D5C8AE5C3E4060C8EA56CF014E40
13477	7	66	939	15102	62801	\N	56.057544	деревня Малые Тюмерли, Школьная, 1		0101000020E61000009C6D6E4C4F3C47405F0A0F9A5D074C40
81883	3	\N	\N	2	2508	\N	59.919891191040797	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, проспект Пятилеток, дом 6, корп.3	Россия, Санкт-Петербург, проспект Пятилеток, 6к3	0101000020E6100000FA264D83A2753E403F7100FDBEF54D40
81427	3	\N	\N	2	4457	\N	60.035068000000003	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, проспект Просвещения, дом 106, корп. 2	Россия, Санкт-Петербург, проспект Просвещения, 106к2	0101000020E61000007D3F355EBA6D3E406D91B41B7D044E40
81378	3	\N	\N	2	4457	\N	60.056210870129597	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, проспект Просвещения, дом 32, корп. 4	Россия, Санкт-Петербург, проспект Просвещения, 32к4	0101000020E6100000C11F7EFE7B543E4075560BEC31074E40
81370	3	\N	\N	2	4457	\N	60.050573999999997	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, проспект Просвещения, дом 46	Россия, Санкт-Петербург, проспект Просвещения, 46	0101000020E6100000A27DACE0B7593E409203763579064E40
81324	3	\N	\N	2	3572	\N	60.000047000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, проспект Пархоменко, дом 24/9	Россия, Санкт-Петербург, проспект Пархоменко, 24	0101000020E61000000DAA0D4E44573E4041BB438A01004E40
81321	3	\N	\N	2	3572	\N	59.998953999999998	Пархоменко пр., дом № 17, школа № 117, тел. 552-88-28		0101000020E610000061E124CD1F573E40AC1A84B9DDFF4D40
81906	3	\N	\N	2	2860	\N	59.859383999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Обуховский, проспект Обуховской Обороны, дом 257	Россия, Санкт-Петербург, проспект Обуховской Обороны, 257	0101000020E6100000234910AE807A3E40535A7F4B00EE4D40
81445	3	\N	\N	2	4844	\N	59.995961999999999	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Непокоренных проспект, дом 16, корп. 1	Россия, Санкт-Петербург, проспект Непокорённых, 16к1	0101000020E61000004FCE50DCF1623E408507CDAE7BFF4D40
81403	3	\N	\N	2	4844	\N	59.996997803694001	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, проспект Непокорённых, дом 12, корп. 2	Россия, Санкт-Петербург, проспект Непокорённых, 12к2	0101000020E610000012876C205D603E40B51666A19DFF4D40
81456	3	\N	\N	2	4870	\N	60.007802701856399	"пр.Науки, д.38 (помещение клуба ""Прожектор""), тел.298-74-86"		0101000020E61000005471E316F36B3E40C5E74EB0FF004E40
81455	3	\N	\N	2	4870	\N	60.009508074529599	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Науки проспект, дом 30, корп. 3	Россия, Санкт-Петербург, проспект Науки, 30к3	0101000020E6100000A3E6ABE4636B3E407286E28E37014E40
81454	3	\N	\N	2	4870	\N	60.010522593845302	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Науки проспект, дом 24, корп. 3	Россия, Санкт-Петербург, проспект Науки, 24к3	0101000020E61000000E83F92B646A3E408B6D52D158014E40
81414	3	\N	\N	2	4870	\N	60.011910404340902	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, проспект Науки, дом 16, корп. 2	Россия, Санкт-Петербург, проспект Науки, 16к2	0101000020E61000000F43AB9333683E40683F524486014E40
81405	3	\N	\N	2	4870	\N	60.0149963630952	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, проспект Науки, дом 13, корп. 4	Россия, Санкт-Петербург, проспект Науки, 13к4	0101000020E61000003E93FDF334603E4010C99063EB014E40
81641	3	\N	\N	2	7308	\N	59.955159637446201	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, проспект Наставников, дом 40, корп. 2	Россия, Санкт-Петербург, проспект Наставников, 40к2	0101000020E61000002DEC6987BF7A3E404339D1AE42FA4D40
81633	3	\N	\N	2	7308	\N	59.941460999999997	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, проспект Наставников, дом 11, корп. 2	Россия, Санкт-Петербург, проспект Наставников, 11к1	0101000020E6100000FA264D83A27D3E40CFBA46CB81F84D40
81662	3	\N	\N	2	74851	\N	59.941578	ул.Наставников д.11 к.2 школа №182	Россия, Санкт-Петербург, проспект Наставников, 11к2	0101000020E6100000BE16F4DE187E3E400951BEA085F84D40
81720	3	\N	\N	2	90	\N	59.825465999999999	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, проспект Народного Ополчения, дом 223	Россия, Санкт-Петербург, проспект Народного Ополчения, 223	0101000020E61000004948A46DFC293E40DFFAB0DEA8E94D40
81548	3	\N	\N	2	90	\N	59.835559000000003	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, проспект Народного ополчения, дом 135	Россия, Санкт-Петербург, проспект Народного Ополчения, 135	0101000020E61000006344A2D0B2423E407270E998F3EA4D40
81521	3	\N	\N	2	90	\N	59.840066999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, проспект Народного Ополчения, дом 103	Россия, Санкт-Петербург, проспект Народного Ополчения, 103	0101000020E61000005DA5BBEB6C443E4073B9C15087EB4D40
81473	3	\N	\N	2	5680	\N	59.984497904466203	пр.Мечникова, д.5 (помещение школы № 653), тел.543-59-15	Россия, Санкт-Петербург, проспект Мечникова, 5к1	0101000020E610000052EE3EC7476B3E401C7DCC0704FE4D40
81472	3	\N	\N	2	5680	\N	59.984237999999998	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Мечникова проспект, дом 2	Россия, Санкт-Петербург, проспект Мечникова, 2	0101000020E6100000D9AF3BDD796A3E407FBDC282FBFD4D40
81471	3	\N	\N	2	5680	\N	59.985439999999997	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Мечникова проспект, дом 16	Россия, Санкт-Петербург, проспект Мечникова, 16	0101000020E610000098309A95ED673E40CA15DEE522FE4D40
81616	3	\N	\N	2	7133	\N	59.956353999999997	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Металлистов проспект, дом 23	Россия, Санкт-Петербург, проспект Металлистов, 23	0101000020E6100000A6B915C26A6C3E400BB3D0CE69FA4D40
81677	3	\N	\N	2	7806	\N	59.857156986424698	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, проспект Маршала Жукова, дом 33, корп. 2	Россия, Санкт-Петербург, проспект Маршала Жукова, 33к2	0101000020E6100000CDCAF6216F393E40CC441152B7ED4D40
81602	3	\N	\N	2	6982	\N	59.976058000000002	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Полюстрово, Маршала Блюхера проспект, дом 44, корп. 2	Россия, Санкт-Петербург, проспект Маршала Блюхера, 44к1	0101000020E6100000D0B9DBF5D26C3E40E57FF277EFFC4D40
81400	3	\N	\N	2	7513	\N	60.043795000000003	Луначарского пр., дом № 5, РЭУ № 6, тел. 510-86-15	Россия, Санкт-Петербург, проспект Луначарского, 5	0101000020E6100000D449B6BA9C523E403A5D16139B054E40
81774	3	\N	\N	2	13250	\N	60.194193796135401	Город Санкт-Петербург, Курортный район, муниципальное образование город Зеленогорск, проспект Ленина, дом 2		0101000020E6100000EB8B84B69CB33D402B8A5759DB184E40
81773	3	\N	\N	2	13250	\N	60.197933999999997	Город Санкт-Петербург, Курортный район, муниципальное образование город Зеленогорск, проспект Ленина, дом 15	Россия, Санкт-Петербург, Зеленогорск, проспект Ленина, 15к2	0101000020E6100000F2B1BB4049B53D401B62BCE655194E40
81751	3	\N	\N	2	13250	\N	59.991570007710799	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, проспект Ленина, дом 51		0101000020E6100000BB9BA73AE4C23D40EDD808C4EBFE4D40
81747	3	\N	\N	2	13250	\N	59.9968415390587	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, проспект Ленина, дом 15	Россия, Санкт-Петербург, Кронштадт, проспект Ленина, 15	0101000020E61000009B5775560BC43D40BEA3C68498FF4D40
81732	3	\N	\N	2	13250	\N	59.729186145530903	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, проспект Ленина, дом 85		0101000020E610000075ADBD4F55153E40BC5983F755DD4D40
81727	3	\N	\N	2	13250	\N	59.8258159033523	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, проспект Ленина, дом 43, корп. 1		0101000020E61000007E350708E6143E40BC41B456B4E94D40
81432	3	\N	\N	2	5170	\N	60.0471437991485	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Северный, проспект Культуры, дом 27, корп. 3	Россия, Санкт-Петербург, проспект Культуры, 27к3	0101000020E61000003065E08096623E40F01989D008064E40
81429	3	\N	\N	2	5170	\N	60.038649693907097	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Северный, проспект Культуры, дом 11, корп. 4	Россия, Санкт-Петербург, проспект Культуры, 11к4	0101000020E6100000533E0455A35F3E40C5FEB27BF2044E40
81688	3	\N	\N	2	7619	\N	59.857323000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, проспект Кузнецова, дом 19	Россия, Санкт-Петербург, проспект Кузнецова, 19	0101000020E6100000DC9F8B868C2F3E40E78D93C2BCED4D40
81687	3	\N	\N	2	7619	\N	59.852367303136198	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, проспект Кузнецова, дом 25, корп. 3	Россия, Санкт-Петербург, проспект Кузнецова, 25к3	0101000020E610000015C5ABAC6D2E3E404698A25C1AED4D40
81685	3	\N	\N	2	7619	\N	59.852302999999999	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, проспект Кузнецова, дом 25, корп. 2	Россия, Санкт-Петербург, проспект Кузнецова, 25к1	0101000020E61000008B16A06D352F3E402FA4C34318ED4D40
81668	3	\N	\N	2	7619	\N	59.852105691974103	проспект Кузнецова,д.25 к.3 гимназия № 271	Россия, Санкт-Петербург, проспект Кузнецова, 25к3	0101000020E61000001F80D4264E2E3E40D95C35CF11ED4D40
81756	3	\N	\N	2	13270	\N	60.053099000000003	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, проспект Красных Командиров, дом 9	Россия, Санкт-Петербург, Сестрорецк, проспект Красных Командиров, 15	0101000020E61000006F10AD156DFA3D40A439B2F2CB064E40
81646	3	\N	\N	2	7350	\N	59.946693771488	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, проспект Косыгина, дом 28, корп. 3	Россия, Санкт-Петербург, проспект Косыгина, 28к3	0101000020E6100000C4EE3B86C77E3E40E3A8DC442DF94D40
81637	3	\N	\N	2	7350	\N	59.943194184512997	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, проспект Косыгина, дом 25, корп. 2	Россия, Санкт-Петербург, проспект Косыгина, 25к2	0101000020E61000008F1CE90C8C7C3E4047E4BB94BAF84D40
13503	7	66	939	16378	62015	\N	55.820737999999999	деревня Малое Кумаркино, Шоссейная, 1		0101000020E61000004BAE62F19B244740CF4A5AF10DE94B40
81800	3	\N	\N	2	1262	\N	59.858802776999603	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, проспект Космонавтов, дом 28, корп. 4	Россия, Санкт-Петербург, проспект Космонавтов, 28к4	0101000020E610000052F01472A55A3E40755AB741EDED4D40
81799	3	\N	\N	2	1262	\N	59.862068482462099	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, проспект Космонавтов, дом 20, корп. 4	Россия, Санкт-Петербург, проспект Космонавтов, 20к4	0101000020E61000005F419AB1685A3E40CD76853E58EE4D40
81796	3	\N	\N	2	1262	\N	59.860888000000003	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, проспект Космонавтов, дом 21	Россия, Санкт-Петербург, проспект Космонавтов, 21к1	0101000020E61000001327F73B14593E406AC2F69331EE4D40
82052	3	\N	\N	2	4513	\N	60.023266515666599	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Королева, дом 47, корп. 2	Россия, Санкт-Петербург, проспект Королёва, 47к2	0101000020E6100000676325E659413E40BB09BE69FA024E40
82050	3	\N	\N	2	4513	\N	60.011147892170698	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, проспект Королева, дом 11	Россия, Санкт-Петербург, проспект Королёва, 11	0101000020E6100000617138F3AB493E4039B5334C6D014E40
82032	3	\N	\N	2	4513	\N	60.009740999999998	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, проспект Королева, дом 8	Россия, Санкт-Петербург, проспект Королёва, 8	0101000020E61000000684D6C397493E4015376E313F014E40
82017	3	\N	\N	2	16861	\N	60.023259000000003	пр. Королева д.47 корп.2 школа № 595	Россия, Санкт-Петербург, проспект Королёва, 47к2	0101000020E6100000E02F664B56413E40392BA226FA024E40
82012	3	\N	\N	2	16861	\N	60.011018999999997	пр.Королева д.11 школа № 58	Россия, Санкт-Петербург, проспект Королёва, 11	0101000020E610000079CDAB3AAB493E403B51121269014E40
81294	3	\N	\N	2	3476	\N	59.953133000000001	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, проспект КИМа, дом 11Б	Россия, Санкт-Петербург, проспект КИМа, 11	0101000020E61000001FA2D11DC43E3E4083DE1B4300FA4D40
81888	3	\N	\N	2	2582	\N	59.897271000000003	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невская застава, проспект Елизарова, дом 7	Россия, Санкт-Петербург, проспект Елизарова, 7	0101000020E610000062A1D634EF6C3E401A53B0C6D9F24D40
81952	3	\N	\N	2	3449	\N	59.968583000000002	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, проспект Динамо, дом 14	Россия, Санкт-Петербург, проспект Динамо, 14	0101000020E6100000F6ECB94C4D463E40153B1A87FAFB4D40
81715	3	\N	\N	2	6158	\N	59.83475	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, проспект Ветеранов, дом 166	Россия, Санкт-Петербург, проспект Ветеранов, 166	0101000020E6100000EA5BE67459243E40022B8716D9EA4D40
81708	3	\N	\N	2	6158	\N	59.830864534712298	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Урицк, проспект Ветеранов, дом 140, корп. 2	Россия, Санкт-Петербург, проспект Ветеранов, 140к2	0101000020E61000000C5872158B2B3E400E32C9C859EA4D40
81698	3	\N	\N	2	6158	\N	59.83569	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, проспект Ветеранов, дом 135	Россия, Санкт-Петербург, проспект Ветеранов, 135к1	0101000020E6100000915F3FC406273E4010CCD1E3F7EA4D40
81693	3	\N	\N	2	6158	\N	59.8373348086809	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, проспект Ветеранов, дом 151, корп. 3	Россия, Санкт-Петербург, проспект Ветеранов, 151к3	0101000020E6100000A41820D104223E40E96514CB2DEB4D40
81555	3	\N	\N	2	6158	\N	59.840012999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, проспект Ветеранов, дом 57	Россия, Санкт-Петербург, проспект Ветеранов, 57	0101000020E6100000C284D1AC6C3B3E40809BC58B85EB4D40
81551	3	\N	\N	2	6158	\N	59.843316999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, проспект Ветеранов, дом 39	Россия, Санкт-Петербург, проспект Ветеранов, 39	0101000020E6100000F5D89601673D3E409694BBCFF1EB4D40
81540	3	\N	\N	2	6158	\N	59.831366570770598	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, проспект Ветеранов, дом 114, корп. 2	Россия, Санкт-Петербург, проспект Ветеранов, 114к2	0101000020E610000082397AFCDE323E40A0FCDD3B6AEA4D40
81535	3	\N	\N	2	6158	\N	59.831873999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, проспект Ветеранов, дом 80	Россия, Санкт-Петербург, проспект Ветеранов, 80	0101000020E6100000DA0418963F373E404432E4D87AEA4D40
81531	3	\N	\N	2	6158	\N	59.835755370843302	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Ульянка, проспект Ветеранов, дом 87, корп. 2	Россия, Санкт-Петербург, проспект Ветеранов, 87к2	0101000020E61000000C73823639383E40F73B1405FAEA4D40
13476	7	66	939	15081	61895	\N	56.090145999999997	село Малое Карачкино, Центральная, 3		0101000020E61000007558E1968F3A4740BFEE74E7890B4C40
81517	3	\N	\N	2	6158	\N	59.844891933835299	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, проспетк Ветеранов, дом 14	Россия, Санкт-Петербург, проспект Ветеранов, 14	0101000020E6100000030B60CAC0413E407653CA6B25EC4D40
81515	3	\N	\N	2	6158	\N	59.844926999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, проспект Ветеранов, дом 14	Россия, Санкт-Петербург, проспект Ветеранов, 14	0101000020E610000048C32973F3413E40F240649126EC4D40
81870	3	\N	\N	2	2021	\N	59.917695999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Оккервиль, проспект Большевиков, дом 4, корп.2	Россия, Санкт-Петербург, проспект Большевиков, 4к1	0101000020E6100000B6A1629CBF793E40C3D5011077F54D40
81858	3	\N	\N	2	2021	\N	59.904269999999997	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, проспект Большевиков, дом 23	Россия, Санкт-Петербург, проспект Большевиков, 23	0101000020E6100000EA58A5F44C7B3E4080608E1EBFF34D40
81850	3	\N	\N	2	2021	\N	59.898403999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, проспект Большевиков, дом 28	Россия, Санкт-Петербург, проспект Большевиков, 28	0101000020E61000006211C30E637E3E403C4CFBE6FEF24D40
81904	3	\N	\N	2	2840	\N	59.862912000000001	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Обуховский, проспект Александровской фермы, дом 11	Россия, Санкт-Петербург, проспект Александровской Фермы, 11	0101000020E61000007DAF21382E733E40B9A981E673EE4D40
82061	3	\N	\N	2	4555	\N	60.020620000000001	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Авиаконструкторов, дом 22, корп. 1	Россия, Санкт-Петербург, проспект Авиаконструкторов, 22	0101000020E6100000FB20CB82893B3E405FD218ADA3024E40
82060	3	\N	\N	2	4555	\N	60.021113999999997	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Авиаконструкторов, дом 35, корп. 2	Россия, Санкт-Петербург, проспект Авиаконструкторов, 35к1	0101000020E61000007FA65EB7083C3E406EBE11DDB3024E40
82058	3	\N	\N	2	4555	\N	60.020395000000001	"пр. Авиаконструкторов, д. 29, корп. 3 (школа № 580) 307-49-44 "	Россия, Санкт-Петербург, проспект Авиаконструкторов, 29к3	0101000020E6100000A67B9DD4973D3E403F00A94D9C024E40
82057	3	\N	\N	2	4555	\N	60.0182194840284	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Авиаконструкторов, дом 21, корп. 2	Россия, Санкт-Петербург, проспект Авиаконструкторов, 21к2	0101000020E6100000CD785BE9B53D3E403A950C0055024E40
82049	3	\N	\N	2	4555	\N	60.016725999999998	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Авиаконструкторов, дом 14	Россия, Санкт-Петербург, проспект Авиаконструкторов, 14	0101000020E610000080290307B43C3E40177FDB1324024E40
82036	3	\N	\N	2	4555	\N	60.020395000000001	пр. Авиаконструкторов, д. 29, корп. 3 (школа № 580) 307-49-44	Россия, Санкт-Петербург, проспект Авиаконструкторов, 29к3	0101000020E6100000A67B9DD4973D3E403F00A94D9C024E40
82067	3	\N	\N	2	16558	\N	60.043432488614499	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N70, поселок Большая Каменка, дом 83	Россия, Санкт-Петербург, посёлок Большая Каменка	0101000020E61000004ED367075C2F3E40C9CC052E8F054E40
81765	3	\N	\N	2	13274	\N	60.093733377890103	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, площадь Свободы, дом 1	Россия, Санкт-Петербург, Сестрорецк, площадь Свободы, 1	0101000020E6100000E59CD843FBF83D402AC76471FF0B4E40
81763	3	\N	\N	2	13274	\N	60.0935947348922	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, площадь Свободы, дом 6	Россия, Санкт-Петербург, Сестрорецк, проспект Свободы	0101000020E61000001AFCFD62B6F83D40D908C4EBFA0B4E40
81744	3	\N	\N	2	13284	\N	59.995860186937598	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, площадь Рошаля, дом 4/11 литер А		0101000020E610000049D576137CC73D4081B2295778FF4D40
82181	3	\N	\N	2	13300	\N	59.936860816546201	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Дворцовый округ, площадь Искусств, дом 2	Россия, Санкт-Петербург, Центральный район, площадь Искусств, 2	0101000020E6100000A18499B67F553E40EDF2AD0FEBF74D40
81741	3	\N	\N	2	13287	\N	59.727379855992197	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, поселок Хвойный	Россия, Санкт-Петербург, Красное Село, переулок Щуппа, 7	0101000020E610000033E02C25CB153E40DAE1AFC91ADD4D40
81296	3	\N	\N	2	3489	\N	59.951532999999998	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, переулок Каховского, дом 2	Россия, Санкт-Петербург, переулок Каховского, 2	0101000020E6100000E6CB0BB08F3E3E404A0856D5CBF94D40
81295	3	\N	\N	2	3489	\N	59.951970000000003	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, переулок Каховского, дом 9	Россия, Санкт-Петербург, переулок Каховского, 9	0101000020E6100000FDA36FD2343C3E40F6622827DAF94D40
13492	7	66	939	15839	61911	\N	55.853036000000003	деревня Лапракасы, Центральная, 1-А		0101000020E6100000FFCF61BEBC384740C4279D4830ED4B40
82210	3	\N	\N	2	13381	\N	59.926028631433802	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, переулок Джамбула, дом 3		0101000020E6100000C19140834D553E40E412471E88F64D40
81201	3	\N	\N	2	2159	\N	59.922002999999997	пер.Бойцова, д.3, ГОУ СОШ № 229	Россия, Санкт-Петербург, переулок Бойцова, 3	0101000020E61000002AE09EE74F4F3E402DE8BD3104F64D40
82187	3	\N	\N	2	2192	\N	59.937396410616103	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, набережная реки Фонтанки, дом 32	Россия, Санкт-Петербург, набережная реки Фонтанки	0101000020E610000036E9B6442E583E405BB39597FCF74D40
82185	3	\N	\N	2	2192	\N	59.940292691058303	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ N78, набережная реки Фонтанки, дом 22	Россия, Санкт-Петербург, набережная реки Фонтанки, 22	0101000020E6100000A647533D99573E4030D461855BF84D40
81226	3	\N	\N	2	2192	\N	59.916688504554202	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Измайловское, Фонтанки реки набережная, дом 134А	Россия, Санкт-Петербург, набережная реки Фонтанки, 134а	0101000020E61000007845F0BF954C3E402DCDAD1056F54D40
81204	3	\N	\N	2	2192	\N	59.921790999999999	"наб. реки Фонтанки, д.113, ФГБОУ ВПО ""Петербургский государственный университет путей сообщения"""		0101000020E61000002C6684B707513E40A25F5B3FFDF54D40
81198	3	\N	\N	2	2119	\N	59.926476130488901	наб.реки Пряжки, д.2-4-6,            ГОУ СОШ № 235	Россия, Санкт-Петербург, набережная реки Пряжки, 2	0101000020E6100000D20149D8B7473E40B343FCC396F64D40
81882	3	\N	\N	2	2490	\N	59.925196	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Правобережный, Набережная реки Оккервиль, дом 10	Россия, Санкт-Петербург, набережная реки Оккервиль, 10	0101000020E61000001CEE23B726753E40EC3191D26CF64D40
82180	3	\N	\N	2	13299	\N	59.937423328889103	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Дворцовый округ, набережная реки Мойки, дом 38	Россия, Санкт-Петербург, набережная реки Мойки, 38	0101000020E610000034130CE71A523E4055C2137AFDF74D40
81935	3	\N	\N	2	3245	\N	59.968384999999998	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, набережная реки Карповки, дом 11А	Россия, Санкт-Петербург, набережная реки Карповки, 11	0101000020E6100000C2FBAA5CA8503E40EE77280AF4FB4D40
82202	3	\N	\N	2	6432	\N	59.931344289886098	"наб. канала Грибоедова, д. 30-32, Санкт-Петербургский Государственный университет экономики и финансов, тел.: 710-57-40 "	Россия, Санкт-Петербург, набережная канала Грибоедова, 30	0101000020E610000008556AF640533E40B5A9BA4736F74D40
81252	3	\N	\N	2	2939	\N	59.935484000000002	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, набережная Лейтенанта Шмидта, дом 15/1	Россия, Санкт-Петербург, набережная Лейтенанта Шмидта, 15	0101000020E6100000172EABB019483E4034F790F0BDF74D40
81195	3	\N	\N	2	2083	\N	59.922277999999999	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Коломна, Крюкова канала набережная, дом 15	Россия, Санкт-Петербург, набережная Крюкова канала, 15	0101000020E6100000156F641EF94B3E40FFE89B340DF64D40
81584	3	\N	\N	2	15321	\N	59.734674081550303	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, бульвар Трудящихся, дом 29	Россия, Санкт-Петербург, Колпино, бульвар Трудящихся, 29	0101000020E6100000DDB3AED172943E405A9C31CC09DE4D40
81580	3	\N	\N	2	15321	\N	59.738692904819402	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, бульвар Трудящихся, дом 9		0101000020E6100000FAB48AFED0903E405E64027E8DDE4D40
81578	3	\N	\N	2	15321	\N	59.736633325855401	г.Колпино, бульвар Трудящихся,10 (Школа № 401), тел. 482-99-30	Россия, Санкт-Петербург, Колпино, бульвар Трудящихся	0101000020E61000006211C30E63923E40C2137AFD49DE4D40
81577	3	\N	\N	2	15321	\N	59.736562913541903	г.Колпино, бульвар Трудящихся, 10(Школа № 401), тел. 482-99-30	Россия, Санкт-Петербург, Колпино, бульвар Трудящихся	0101000020E610000091D5AD9E93923E40C93846B247DE4D40
81547	3	\N	\N	2	6135	\N	59.839998999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, бульвар Новаторов, дом 104	Россия, Санкт-Петербург, бульвар Новаторов, 104	0101000020E6100000971DE21FB6403E401BD6541685EB4D40
81519	3	\N	\N	2	6135	\N	59.846575999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, бульвар Новаторов, дом 40	Россия, Санкт-Петербург, бульвар Новаторов, 40	0101000020E61000005B608F8994463E400CCA349A5CEC4D40
81514	3	\N	\N	2	6135	\N	59.847037	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, бульвар Новаторов, дом 43	Россия, Санкт-Петербург, бульвар Новаторов, 43	0101000020E61000000FD6FF39CC433E4040C05AB56BEC4D40
81902	3	\N	\N	2	2804	\N	59.8697282049162	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Обуховский, Бульвар Красных Зорь, дом 6, корп. 2	Россия, Санкт-Петербург, бульвар Красных Зорь, 6к2	0101000020E61000004982700514723E402F35423F53EF4D40
82113	3	\N	\N	2	15370	\N	59.730519999999999	Пушкинский район, бул. А.Толстого д.42 школа № 530	Россия, Санкт-Петербург, Пушкин, бульвар Алексея Толстого, 42	0101000020E6100000CD3E8F519E693E407689EAAD81DD4D40
82048	3	\N	\N	2	3726	\N	60.008374000000003	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, аллея Поликарпова, дом 7	Россия, Санкт-Петербург, аллея Поликарпова, 7	0101000020E61000002E01F8A754493E408011346612014E40
82047	3	\N	\N	2	3726	\N	60.008374000000003	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, Поликарпова аллея, дом 7	Россия, Санкт-Петербург, аллея Поликарпова, 7	0101000020E61000002E01F8A754493E408011346612014E40
82046	3	\N	\N	2	3726	\N	60.008374000000003	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, аллея Поликарпова аллея, дом 7	Россия, Санкт-Петербург, аллея Поликарпова, 7	0101000020E61000002E01F8A754493E408011346612014E40
81973	3	\N	\N	2	3726	\N	60.008374000000003	Аллея Поликарпова д.7 школа № 57	Россия, Санкт-Петербург, аллея Поликарпова, 7	0101000020E61000002E01F8A754493E408011346612014E40
82010	3	\N	\N	2	4093	\N	59.988337999999999	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Яхтенная, дом 7/3	Россия, Санкт-Петербург, Яхтенная улица, 7к3	0101000020E6100000191BBAD91F383E4070B20DDC81FE4D40
82000	3	\N	\N	2	4093	\N	60.006494000000004	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Яхтенная, дом 33, корп. 3	Россия, Санкт-Петербург, Яхтенная улица, 33к3	0101000020E6100000F67D3848883A3E4064CF9ECBD4004E40
81336	3	\N	\N	2	4030	\N	60.014400999999999	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Ярославский проспект, дом 20	Россия, Санкт-Петербург, Ярославский проспект, 20	0101000020E6100000F88903E8F7513E40CD0358E4D7014E40
82170	3	\N	\N	2	15304	\N	59.8357963786205	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Ярослава Гашека, дом 10, корп. 2		0101000020E6100000E2900DA48B653E405610035DFBEA4D40
82161	3	\N	\N	2	15304	\N	59.833487629387001	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Ярослава Гашека, дом 4, корп. 4		0101000020E6100000938D075BEC623E40E2CD1ABCAFEA4D40
81968	3	\N	\N	2	16588	\N	59.870464822789501	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Эрлеровский бульвар, дом 1/35		0101000020E61000009AEC9FA701EB3D4005A8A9656BEF4D40
82224	3	\N	\N	2	6631	\N	59.949091000000003	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Шпалерная, дом 50А	Россия, Санкт-Петербург, Шпалерная улица, 50а	0101000020E6100000EBFCDB65BF5E3E40C7F65AD07BF94D40
81595	3	\N	\N	2	56765	\N	59.803482835099302	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Усть-Ижора, шоссе Шлиссельбургское, дом 219		0101000020E610000037FE4465C39A3E402CF2EB87D8E64D40
81914	3	\N	\N	2	2897	\N	59.836522950402298	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Рыбацкое, Шлиссельбургский проспект, дом 24, корп. 2		0101000020E6100000C51A2E724F833E4008AD872F13EB4D40
81913	3	\N	\N	2	2897	\N	59.832982000000001	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Рыбацкое, Шлиссельбургский проспект, дом 43	Россия, Санкт-Петербург, Шлиссельбургский проспект, 43	0101000020E61000009609BFD4CF833E400E1478279FEA4D40
81909	3	\N	\N	2	2897	\N	59.841256000000001	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Рыбацкое, Шлиссельбургский проспект, дом 10	Россия, Санкт-Петербург, Шлиссельбургский проспект, 10	0101000020E610000094C2BCC7997E3E402AC8CF46AEEB4D40
81398	3	\N	\N	2	16672	\N	60.110511053779703	Город Санкт-Петербург, Выборгский район, муниципальное образование поселок Парголово, Школьный переулок (Осиновая Роща), дом 1	Россия, Санкт-Петербург, посёлок Парголово, Школьный переулок	0101000020E6100000EDD808C4EB3E3E40946C7539250E4E40
82245	3	\N	\N	2	15288	\N	60.109493170645599	пос.Парголово Осиновая Роща Школьнай перю д.1 щкола № 471		0101000020E610000045132862113F3E400A12DBDD030E4E40
82011	3	\N	\N	2	13377	\N	59.989849999999997	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Школьная, дом 114, корп. 3		0101000020E61000009AB4A9BA47363E4009F9A067B3FE4D40
81598	3	\N	\N	2	78837	\N	59.801786492415602	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Металлострой, улица Школьная, дом 8	Россия, Санкт-Петербург, посёлок Усть-Ижора, Школьная улица	0101000020E61000000F0F61FC34963E40013274ECA0E64D40
81612	3	\N	\N	2	7083	\N	59.945937000000001	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Шепетовская улица, дом 5	Россия, Санкт-Петербург, Шепетовская улица, 5	0101000020E6100000620FED63056B3E40C689AF7614F94D40
81274	3	\N	\N	2	13256	\N	59.941004357276697	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Шевченко, дом 36А	Россия, Санкт-Петербург, улица Шевченко, 36	0101000020E610000080F44D9A063D3E40DDB3AED172F84D40
81273	3	\N	\N	2	13256	\N	59.936151000000002	ул.Шевченко д.23 корп.2 Лицей № 30	Россия, Санкт-Петербург, улица Шевченко, 23к2	0101000020E61000002B84D558C23E3E40118FC4CBD3F74D40
81676	3	\N	\N	2	7795	\N	59.960299999999997	"ул. Шамшева, 8, ДК им. Шелгунова тел. 235-56-49 "		0101000020E6100000BB09BE69FA4C3E40A52C431CEBFA4D40
81950	3	\N	\N	2	3291	\N	59.962434999999999	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, Чкаловский проспект, дом 22	Россия, Санкт-Петербург, Чкаловский проспект, 22	0101000020E6100000EAEBF99AE54A3E404CC3F01131FB4D40
81942	3	\N	\N	2	3291	\N	59.962371006377502	"Чкаловский пр., д.22, школа №51 тел. 235-46-89 "	Россия, Санкт-Петербург, Чкаловский проспект, 22	0101000020E61000009E077767ED4A3E4035CF11F92EFB4D40
81938	3	\N	\N	2	3291	\N	59.967899000000003	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, проспект Чкаловский, дом 35	Россия, Санкт-Петербург, Чкаловский проспект, 35	0101000020E6100000574277499C4D3E40626A4B1DE4FB4D40
82066	3	\N	\N	2	16556	\N	60.039357899275601	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N70, улица Чистяковская, дом 4	Россия, Санкт-Петербург, Чистяковская улица	0101000020E6100000060DFD135C4C3E40016BD5AE09054E40
81887	3	\N	\N	2	2560	\N	59.911583999999998	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невская застава, улица Хрустальная, дом 12	Россия, Санкт-Петербург, Хрустальная улица, 12	0101000020E6100000DEE522BE13673E4047C7D5C8AEF44D40
82238	3	\N	\N	2	16675	\N	59.929203993459602	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Херсонская, дом 9		0101000020E61000007862D68BA1603E40FCA71B28F0F64D40
81631	3	\N	\N	2	7295	\N	59.936766600891502	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Хасанская, дом 18, корп. 3	Россия, Санкт-Петербург, Хасанская улица, 18к3	0101000020E610000059349D9D0C7E3E406C7C26FBE7F74D40
81661	3	\N	\N	2	67085	\N	59.936971999999997	Хасанская д.18 к.3 Школа здоровья и развития		0101000020E6100000BEF90D130D7E3E4044A2D0B2EEF74D40
81663	3	\N	\N	2	15325	\N	59.937264999999996	ул. Хасанская д.14 к.2 школа 151		0101000020E6100000C972124A5F7C3E40BC57AD4CF8F74D40
81634	3	\N	\N	2	15325	\N	59.9373499765438	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Хасанская, дом 14, корп. 2		0101000020E6100000EB1A2D077A7C3E40EB73B515FBF74D40
82242	3	\N	\N	2	6830	\N	59.926264000000003	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Лиговка-Ямская, улица Харьковская, дом 13		0101000020E6100000336FD575A85E3E4028BB99D18FF64D40
81978	3	\N	\N	2	15919	\N	59.882427786954302	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, улица Халтурина, дом 7		0101000020E6100000B96E4A79ADDC3D408F899466F3F04D40
82222	3	\N	\N	2	6620	\N	59.944687999999999	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Фурштатская, дом 29А	Россия, Санкт-Петербург, Фурштатская улица, 29а	0101000020E61000005663096B635C3E403A765089EBF84D40
81791	3	\N	\N	2	13297	\N	59.862132811908801	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, улица Фрунзе, дом 22		0101000020E6100000236AA2CF47553E40B4E6C75F5AEE4D40
81213	3	\N	\N	2	2346	\N	59.929529952099003	Фонарный пер., д.4, ГОУ СОШ № 255	Россия, Санкт-Петербург, Фонарный переулок, 2	0101000020E61000003F8D7BF31B4E3E405053CBD6FAF64D40
81459	3	\N	\N	2	5545	\N	59.956394247289602	Финский пер., д.7, (помещение Совета ветеранов), тел.542-56-00	Россия, Санкт-Петербург, Финский переулок, 7	0101000020E610000025085740A15A3E409A0B5C1E6BFA4D40
81988	3	\N	\N	2	16667	\N	59.898043204182898	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, улица Федюнинского, дом 6		0101000020E6100000CB2E185C73C73D406CB3B112F3F24D40
81463	3	\N	\N	2	15324	\N	59.974527000000002	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Федосеенко улица, дом 28		0101000020E61000000C022B8716653E40D508FD4CBDFC4D40
81443	3	\N	\N	2	13253	\N	60.033234	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Ушинского, дом 10		0101000020E6100000A3586E6935683E40C18EFF0241044E40
81442	3	\N	\N	2	13253	\N	60.040654000000004	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Ушинского, дом 16		0101000020E61000000DA9A27895693E40CE39782634054E40
81425	3	\N	\N	2	13253	\N	60.040971326247004	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ N21, улица Ушинского, дом 35, корп. 2		0101000020E6100000A6423C122F6B3E40CE8AA8893E054E40
81435	3	\N	\N	2	5220	\N	60.035231309045201	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Учительская, дом 3	Россия, Санкт-Петербург, Учительская улица, 3к1	0101000020E6100000F6D4EAABAB623E4017670C7382044E40
81434	3	\N	\N	2	5220	\N	60.033210554622897	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Учительская, дом 9, корп. 3	Россия, Санкт-Петербург, Учительская улица, 9к3	0101000020E610000039EE940ED6633E40096F0F4240044E40
81350	3	\N	\N	2	4155	\N	60.039157724832798	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, Учебный переулок, дом 8, корп. 2	Россия, Санкт-Петербург, Учебный переулок, 8к2	0101000020E6100000C5FF1D51A1563E403AB01C2103054E40
13497	7	66	939	7574	61913	\N	55.877474999999997	деревня Кукшумы, Шоссейная, 6		0101000020E610000055320054712B47405F07CE1951F04B40
81347	3	\N	\N	2	4155	\N	60.039709999999999	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сосновское, Учебный переулок, дом 2	Россия, Санкт-Петербург, Учебный переулок, 2	0101000020E61000000D350A4966553E407EA99F3715054E40
81928	3	\N	\N	2	15290	\N	59.953187865195702	"Троицкая пл., 3, ЛенНИИпроект тел. 233-20-25 "		0101000020E61000004772F90FE9533E4046787B1002FA4D40
81512	3	\N	\N	2	6112	\N	59.854806000000004	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, Трамвайный проспект, дом 22	Россия, Санкт-Петербург, Трамвайный проспект, 22	0101000020E6100000C878944A78463E40593673486AED4D40
81396	3	\N	\N	2	16587	\N	60.081503920321303	Город Санкт-Петербург, Выборгский район, муниципальное образование поселок Парголово, Торфяная улица (Михайловка), дом 23	Россия, Санкт-Петербург, посёлок Парголово, Торфяная улица	0101000020E6100000E31A9FC9FE3D3E40213F1BB96E0A4E40
82025	3	\N	\N	2	16087	\N	59.989842878341797	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, улица Торжковская, дом 10А	Россия, Санкт-Петербург, Торжковская улица, 10	0101000020E6100000C5E57805A24F3E405796E82CB3FE4D40
82204	3	\N	\N	2	6453	\N	59.928992000000001	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ N78, переулок Торговый, дом 2а	Россия, Санкт-Петербург, Торговый переулок, 2а	0101000020E6100000EE224C512E553E40711FB935E9F64D40
81758	3	\N	\N	2	16668	\N	60.087649999999996	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, Токарева улица, дом 5		0101000020E61000003AB2F2CB60F43D4048BF7D1D380B4E40
81873	3	\N	\N	2	2344	\N	59.912824937090498	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Оккервиль, Товарищеский проспект, дом 28, корп.2	Россия, Санкт-Петербург, Товарищеский проспект, 28к2	0101000020E6100000A9F92AF9D87D3E4050FC1873D7F44D40
81872	3	\N	\N	2	2344	\N	59.918869337875002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Оккервиль, Товарищеский проспект, дом 10, корп.2	Россия, Санкт-Петербург, Товарищеский проспект, 10к2	0101000020E61000007FC16ED8B67C3E407427D87F9DF54D40
81310	3	\N	\N	2	3674	\N	59.972830000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, Тобольская улица, дом 12А	Россия, Санкт-Петербург, Тобольская улица, 12	0101000020E610000075779D0DF9573E40AA4885B185FC4D40
81437	3	\N	\N	2	5264	\N	60.046991712729401	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, улица Тимуровская, дом 8, корп. 2	Россия, Санкт-Петербург, Тимуровская улица, 8к2	0101000020E6100000E57D1CCD91653E403A9677D503064E40
81438	3	\N	\N	2	67079	\N	60.0470085646771	улица Тимуровская д.8.к.2 школа № 119	Россия, Санкт-Петербург, Тимуровская улица, 8к2	0101000020E61000002F17F19D98653E4010CF126404064E40
81958	3	\N	\N	2	13288	\N	59.847269730675002	Город Санкт-Петербург, Петродворцовый район, муниципальное образование поселок Стрельна, Театральная аллея, дом 19	Россия, Санкт-Петербург, посёлок Стрельна, Театральная аллея, 19	0101000020E6100000E9F17B9BFE0C3E40E370E65773EC4D40
81567	3	\N	\N	2	13357	\N	59.737831835705201	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Тверская, дом 54, корп. 2	Россия, Санкт-Петербург, Колпино, Тверская улица, 54к4	0101000020E61000003D618907949D3E409CF86A4771DE4D40
81565	3	\N	\N	2	13373	\N	59.7403502415468	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Тверская, дом 23	Россия, Санкт-Петербург, Колпино, Тверская улица, 23	0101000020E610000092AD2EA7049C3E40FBCBEEC9C3DE4D40
81564	3	\N	\N	2	13373	\N	59.744146446235099	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Тверская, дом 13	Россия, Санкт-Петербург, Колпино, Тверская улица, 13	0101000020E610000014596B28B59B3E4080B9162D40DF4D40
81624	3	\N	\N	2	7179	\N	59.924312	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Таллинская улица, дом 18		0101000020E6100000A4C16D6DE1693E4072A609DB4FF64D40
81622	3	\N	\N	2	7179	\N	59.925272	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Таллинская улица, дом 21		0101000020E6100000ED7F80B56A6B3E40C7F319506FF64D40
81620	3	\N	\N	2	7179	\N	59.925880999999997	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Таллинская улица, дом 26	Россия, Санкт-Петербург, Таллинская улица, 26к1	0101000020E6100000E831CA332F6B3E406F7EC34483F64D40
81925	3	\N	\N	2	3105	\N	59.957685977266799	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Кронверкское, улица Сытнинская, дом 5/7	Россия, Санкт-Петербург, Сытнинская улица, 7	0101000020E61000000820B589934F3E4025EB707495FA4D40
81919	3	\N	\N	2	3042	\N	59.95384	"ул. Съезжинская, 15/17,  Финансово-экономический колледж тел. 232-49-31  "	Россия, Санкт-Петербург, Съезжинская улица, 15	0101000020E610000038842A357B4C3E40EECEDA6D17FA4D40
81440	3	\N	\N	2	5295	\N	60.045439000000002	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Прометей, Суздальский проспект, дом 93, корп. 2	Россия, Санкт-Петербург, Суздальский проспект, 93к1	0101000020E6100000A14ACD1E68693E40427BF5F1D0054E40
81623	3	\N	\N	2	13303	\N	59.924219724346003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Стахановцев улица, дом 15, корп. 2		0101000020E6100000CFD8976C3C683E40912749D74CF64D40
81242	3	\N	\N	2	2775	\N	59.904508999999997	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Екатерингофский, Старо-Петергофский проспект, дом 33	Россия, Санкт-Петербург, Старо-Петергофский проспект, 33	0101000020E6100000A0FB7266BB463E4005F86EF3C6F34D40
81729	3	\N	\N	2	15315	\N	59.741552256246003	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Спирина, дом 10	Россия, Санкт-Петербург, Красное Село, улица Спирина	0101000020E61000003946B247A8153E4046240A2DEBDE4D40
82211	3	\N	\N	2	16031	\N	59.9230006590413	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Социалистическая, дом 7/11	Россия, Санкт-Петербург, Центральный район, Социалистическая улица	0101000020E6100000F31FD26F5F573E40709692E524F64D40
81416	3	\N	\N	2	16649	\N	60.0184575467702	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, улица Софьи Ковалевской, дом 16, корп. 6	Россия, Санкт-Петербург, улица Софьи Ковалевской, 16к6	0101000020E6100000D1782288F3683E40BF2CEDD45C024E40
82097	3	\N	\N	2	13247	\N	59.717173000000003	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Софийский бульвар, дом 9		0101000020E6100000D94125AE636C3E4080492A53CCDB4D40
82127	3	\N	\N	2	13279	\N	59.871084000000003	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Софийская улица, дом 42, корп. 3		0101000020E61000007EE19524CF693E40D10836AE7FEF4D40
82126	3	\N	\N	2	13279	\N	59.874091999999997	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Софийская улица, дом34, корп. 3		0101000020E61000001ADF1797AA683E40FDD8243FE2EF4D40
82125	3	\N	\N	2	13279	\N	59.873951797967798	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Софийская улица, дом 34, корп. 3		0101000020E6100000116F9D7FBB683E400C23BDA8DDEF4D40
81570	3	\N	\N	2	16630	\N	59.747189596033998	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, бульвар Советский, дом 29	Россия, Санкт-Петербург, Колпино, Советский бульвар	0101000020E610000086E8103812983E40FAF202ECA3DF4D40
81987	3	\N	\N	2	15300	\N	59.903847543289999	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, улица Скуридина, дом 6А	Россия, Санкт-Петербург, Ломоносов, Швейцарская улица, 6	0101000020E6100000309FAC18AEC63D400B47904AB1F34D40
81998	3	\N	\N	2	4055	\N	60.000532999999997	Ситцевая ул., д. 15 (школа № 598) 341-58-14	Россия, Санкт-Петербург, Ситцевая улица, 15	0101000020E61000007C98BD6C3B3D3E40CDC8207711004E40
81997	3	\N	\N	2	4055	\N	60.000532999999997	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Ситцевая, дом 15		0101000020E61000007C98BD6C3B3D3E40CDC8207711004E40
81377	3	\N	\N	2	4377	\N	60.054513999999998	Сиреневый бульвар. Д.8 корп.2 СШ № 110	Россия, Санкт-Петербург, Сиреневый бульвар, 8к2	0101000020E6100000D314014EEF5A3E404A969350FA064E40
81371	3	\N	\N	2	4377	\N	60.054341612605597	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, Сиреневый бульвар, дом 8, корп. 2	Россия, Санкт-Петербург, Сиреневый бульвар, 8к2	0101000020E61000007C992842EA5A3E404D66BCADF4064E40
81364	3	\N	\N	2	4377	\N	60.053331999999997	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ N15, Сиреневый бульвар, дом 16, корп. 2	Россия, Санкт-Петербург, Сиреневый бульвар, 16к2	0101000020E6100000C972124A5F5C3E4046EA3D95D3064E40
81360	3	\N	\N	2	4377	\N	60.052109999999999	Сиреневый бул., дом № 18 к. 2,  школа № 83, тел. 592-43-66	Россия, Санкт-Петербург, Сиреневый бульвар, 18к1	0101000020E61000000F9D9E77635D3E40B4E55C8AAB064E40
81359	3	\N	\N	2	4377	\N	60.052109999999999	Сиреневый бул., дом № 18 к. 2, школа № 83, тел. 517-50-53	Россия, Санкт-Петербург, Сиреневый бульвар, 18к1	0101000020E61000000F9D9E77635D3E40B4E55C8AAB064E40
81358	3	\N	\N	2	4377	\N	60.052109999999999	Сиреневый бул., дом № 18 к. 2, школа № 83, тел. 517-12-89	Россия, Санкт-Петербург, Сиреневый бульвар, 18к1	0101000020E61000000F9D9E77635D3E40B4E55C8AAB064E40
81609	3	\N	\N	2	7061	\N	59.957093	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Синявинская улица, дом 15		0101000020E6100000A8AAD0402C6B3E40821DFF0582FA4D40
81221	3	\N	\N	2	74860	\N	59.912053	ул.Серпуховская, д.39, ГОУ СОШ № 317	Россия, Санкт-Петербург, Серпуховская улица, 39	0101000020E61000009A93179980533E40FE9B1727BEF44D40
82045	3	\N	\N	2	4636	\N	60.002746000000002	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, бульвар Серебристый, дом 16, корп. 3	Россия, Санкт-Петербург, Серебристый бульвар, 16к1	0101000020E6100000FF40B96DDF473E40F0181EFB59004E40
82043	3	\N	\N	2	4636	\N	60.001001000000002	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, бульвар Серебристый, дом 9, корп. 2	Россия, Санкт-Петербург, Серебристый бульвар, 9	0101000020E6100000EEB089CC5C483E40B421FFCC20004E40
6203	7	65	\N	11375	52654	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.20 лет Победы, д.7		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
81409	3	\N	\N	2	3947	\N	60.024699933020997	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, Светлановский проспект, дом 40, корп. 3	Россия, Санкт-Петербург, Светлановский проспект, 40к3	0101000020E6100000554D10751F603E40091B9E5E29034E40
81407	3	\N	\N	2	3947	\N	60.023837876505297	Светлановский пр., д.38, к.2 (помещение школы № 150), тел.556-83-08	Россия, Санкт-Петербург, Светлановский проспект, 38к2	0101000020E6100000D71533C2DB5F3E407633A31F0D034E40
81404	3	\N	\N	2	3947	\N	60.023874540584799	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, Светлановский проспект, дом 38, корп. 2		0101000020E6100000355F251FBB5F3E40931804560E034E40
81330	3	\N	\N	2	3947	\N	60.006939000000003	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Светлановский проспект, дом 31	Россия, Санкт-Петербург, Светлановский проспект, 31	0101000020E61000006F2C280CCA583E4092088D60E3004E40
81982	3	\N	\N	2	16596	\N	59.911146000000002	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, улица Сафронова, дом 5		0101000020E61000000ABB287AE0C73D40CCF09F6EA0F44D40
81961	3	\N	\N	2	13364	\N	59.8529752754581	Город Санкт-Петербург, Петродворцовый район, муниципальное образование поселок Стрельна, Санкт-Петербургское шоссе, дом 102а	Россия, Санкт-Петербург, посёлок Стрельна, Санкт-Петербургское шоссе, 102	0101000020E610000059DDEA39E9053E401EA7E8482EED4D40
81959	3	\N	\N	2	13364	\N	59.852592057692902	Город Санкт-Петербург, Петродворцовый район, муниципальное образование поселок Стрельна, Санкт-Петербургское шоссе, дом 88	Россия, Санкт-Петербург, посёлок Стрельна, Санкт-Петербургское шоссе, 88	0101000020E6100000E8DB82A5BA083E40666A12BC21ED4D40
81970	3	\N	\N	2	16590	\N	59.8799901541908	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Санкт-Петербургский проспект, дом 43		0101000020E610000056F0DB10E3E93D404D672783A3F04D40
81965	3	\N	\N	2	16590	\N	59.8761501964795	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Санкт-Петербургский проспект, дом 4	Россия, Санкт-Петербург, Петергоф, Санкт-Петербургский проспект, 4	0101000020E610000014ED2AA4FCEC3D40F931E6AE25F04D40
81993	3	\N	\N	2	77275	\N	59.998066999999999	"пос. Ольгино, Садовая ул., д. 6 (Дом культуры) 498-36-29, 417-21-61  "	Россия, Санкт-Петербург, Приморский район, Садовая улица, 6	0101000020E61000002D23F59ECA253E40C11BD2A8C0FF4D40
81202	3	\N	\N	2	74847	\N	59.922651999999999	Садовая ул., д.52, ГОУ СОШ № 229		0101000020E6100000CFF753E3A54F3E4064CBF27519F64D40
81994	3	\N	\N	2	79417	\N	59.998066999999999	"пос. Ольгино, Садовая ул., д. 6 (Дом культуры) 417-21-61 "		0101000020E61000002D23F59ECA253E40C11BD2A8C0FF4D40
82107	3	\N	\N	2	13268	\N	59.684295947976601	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Павловск, Садовая улица, дом 49	Россия, Санкт-Петербург, Павловск, Садовая улица, 49	0101000020E610000028D53E1D8F793E404E64E60297D74D40
82015	3	\N	\N	2	15313	\N	59.988076999999997	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Савушкина, дом 134, корп. 4		0101000020E61000007C7E18213C323E400377A04E79FE4D40
81868	3	\N	\N	2	15313	\N	59.988076999999997	ул. Савушкина д.134 корп.4 школа № 357		0101000020E61000007C7E18213C323E400377A04E79FE4D40
81657	3	\N	\N	2	7569	\N	59.985519577382597	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, Рябовское шоссе, дом 126	Россия, Санкт-Петербург, Рябовское шоссе, 124к1	0101000020E6100000BA6A9E23F2853E40E7C6F48425FE4D40
81655	3	\N	\N	2	7569	\N	59.975895999999999	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, Рябовское шоссе, дом 75	Россия, Санкт-Петербург, Рябовское шоссе, 75	0101000020E61000005EA10F96B1813E400B26FE28EAFC4D40
82193	3	\N	\N	2	13376	\N	59.942254719638399	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Рылеева, дом 9	Россия, Санкт-Петербург, улица Рылеева	0101000020E6100000EC6B5D6A845A3E400ABFD4CF9BF84D40
81912	3	\N	\N	2	2948	\N	59.839185926529296	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Рыбацкое, Рыбацкий проспект, дом 29, корп. 2	Россия, Санкт-Петербург, Рыбацкий проспект, 29к2	0101000020E610000024B5503239813E406AA164726AEB4D40
81710	3	\N	\N	2	8123	\N	59.832411999999998	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, бульвар Российский, дом 4	Россия, Санкт-Петербург, Российский бульвар, 4	0101000020E6100000280B5F5FEB163E402366F6798CEA4D40
81964	3	\N	\N	2	3614	\N	59.8551	Ропшинское шоссе, дом 4 домоуправление №4	Россия, Санкт-Петербург, Ропшинское шоссе, 4	0101000020E61000007A7077D66EF33D40A167B3EA73ED4D40
81238	3	\N	\N	2	77241	\N	59.913432999999998	"Рижский пр., д.31, Государственное образовательное учреждение дополнительного образования детей специализированная детско-юношеская спортивная школа Олимпийского резерва № 1 Адмиралтейского района Санкт-Петербурга"	Россия, Санкт-Петербург, Рижский проспект, 31	0101000020E6100000A38FF98040473E40280B5F5FEBF44D40
81659	3	\N	\N	2	7603	\N	59.979795000000003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, Ржевская улица, дом 18	Россия, Санкт-Петербург, Ржевская улица, 18	0101000020E6100000118C834BC7803E4065E42CEC69FD4D40
81770	3	\N	\N	2	13294	\N	60.122848493278198	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Песочный, Речная улица, дом 24/26	Россия, Санкт-Петербург, посёлок Песочный, Речная улица, 22	0101000020E610000021C8410933253E408330B77BB90F4E40
82116	3	\N	\N	2	16508	\N	59.906649935723401	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Расстанная улица, дом 20, литер А	Россия, Санкт-Петербург, Днепропетровская улица	0101000020E61000001CEA77616B5A3E408E75711B0DF44D40
82100	3	\N	\N	2	16570	\N	59.705939999999998	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, улица Радищева, дом 22		0101000020E610000037FDD98F14693E401878EE3D5CDA4D40
82087	3	\N	\N	2	16046	\N	59.805267094146501	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Шушары, Пушкинская улица, дом 12	Россия, Санкт-Петербург, посёлок Шушары, Пушкинская улица, 12	0101000020E61000001D740987DE623E4026C632FD12E74D40
81835	3	\N	\N	2	16046	\N	59.727600462539897	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Пушкинская улица, дом 28/21	Россия, Санкт-Петербург, посёлок Александровская, Пушкинская улица	0101000020E6100000B2F4A10BEA573E40E9482EFF21DD4D40
81837	3	\N	\N	2	1522	\N	59.753638533400597	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, Пулковское шоссе, дом 91, корп. 2	Россия, Санкт-Петербург, Пулковское шоссе, 91к2	0101000020E6100000467C2766BD503E40BDFE243E77E04D40
81836	3	\N	\N	2	1522	\N	59.767235999999997	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, Пулковское шоссе, дом 65	Россия, Санкт-Петербург, Пулковское шоссе, 65	0101000020E61000002D27A1F485543E402C280CCA34E24D40
81813	3	\N	\N	2	1522	\N	59.823449905521898	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, Пулковское шоссе, дом 34, корп. 2	Россия, Санкт-Петербург, Пулковское шоссе, 34к2	0101000020E6100000213B6F63B3533E4013F241CF66E94D40
81992	3	\N	\N	2	16656	\N	59.923905158296598	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, улица Пулеметчиков, дом 6	Россия, Санкт-Петербург, Ломоносов, улица Пулемётчиков	0101000020E6100000055262D7F6B63D4031CEDF8442F64D40
81954	3	\N	\N	2	3477	\N	59.964078999999998	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, улица Пудожская, дом 4-Б	Россия, Санкт-Петербург, Пудожская улица, 4б	0101000020E6100000CE50DCF1264B3E4054E1CFF066FB4D40
81943	3	\N	\N	2	13354	\N	59.964004259414203	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ округ Петровский, улица Пудожская, дом 4-Б	Россия, Санкт-Петербург, Пудожская улица, 4б	0101000020E6100000BA2C26361F4B3E404A9BAA7B64FB4D40
82236	3	\N	\N	2	6769	\N	59.936353226532397	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, переулок Прудковский, дом 1/8	Россия, Санкт-Петербург, Прудковский переулок	0101000020E6100000840D4FAF945D3E407841446ADAF74D40
81936	3	\N	\N	2	13350	\N	59.971784999999997	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, улица Профессора Попова, дом 25		0101000020E6100000D40B3ECDC94F3E4026DF6C7363FC4D40
81995	3	\N	\N	2	16113	\N	60.012443606826501	Город Санкт-Петербург, Приморский район, муниципальное образование поселок Лисий Нос, шоссе Приморское (Лисий Нос), дом 48	Россия, Санкт-Петербург, Зеленогорск, Приморское шоссе	0101000020E6100000662FDB4E5B033E400684D6C397014E40
81782	3	\N	\N	2	16113	\N	60.180349659439898	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Смолячково, Приморское шоссе, дом 704	Россия, Санкт-Петербург, Зеленогорск, Приморское шоссе, 703	0101000020E6100000DF347D76C0753D40B3EA73B515174E40
81766	3	\N	\N	2	16113	\N	60.097714928243299	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, Приморское шоссе, дом 308А	Россия, Санкт-Петербург, Зеленогорск, Приморское шоссе, 308	0101000020E61000004F3FA88B14FA3D4011AAD4EC810C4E40
82018	3	\N	\N	2	4237	\N	59.983089999999997	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Черная речка, проспект Приморский, дом 63	Россия, Санкт-Петербург, Приморский проспект, 63	0101000020E6100000C5724BAB21453E402783A3E4D5FD4D40
82014	3	\N	\N	2	4237	\N	59.986722	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, проспект Приморский, дом 157, корп. 3	Россия, Санкт-Петербург, Приморский проспект, 157к3	0101000020E61000004BEA043411323E40321F10E84CFE4D40
82013	3	\N	\N	2	4237	\N	59.985610999999999	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, проспект Приморский, дом 143, корп. 3	Россия, Санкт-Петербург, Приморский проспект, 143к3	0101000020E610000084640113B8353E40F7C9518028FE4D40
82136	3	\N	\N	2	5571	\N	59.870672999999996	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Пражская улица, дом 25		0101000020E6100000478FDFDBF4633E404E417E3672EF4D40
13512	7	66	708	52493	62650	\N	55.146723000000001	Чувашская Республика - Чувашия, Яльчикский район, Яльчикское сельское поселение д.Н.Булаево, Центральная, 25		0101000020E6100000679AB0FD640248401749BBD1C7924B40
82133	3	\N	\N	2	5571	\N	59.872236000000001	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Пражская улица, дом 30	Россия, Санкт-Петербург, Пражская улица, 30к1	0101000020E6100000408A3A730F653E406A32E36DA5EF4D40
82130	3	\N	\N	2	5571	\N	59.869954999999997	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N72, Пражская улица, дом 36		0101000020E6100000FAD4B14AE9653E40EFFE78AF5AEF4D40
82122	3	\N	\N	2	5571	\N	59.876735737256901	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Пражская улица, дом 7, корп. 4	Россия, Санкт-Петербург, Пражская улица, 7к4	0101000020E61000007445292158613E40E99C9FE238F04D40
82217	3	\N	\N	2	13246	\N	59.9236050638725	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Правды, дом 8	Россия, Санкт-Петербург, улица Правды, 8	0101000020E61000001AC40776FC573E4007B64AB038F64D40
81367	3	\N	\N	2	4294	\N	60.043603206008498	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, Поэтический бульвар, дом 3, корп. 2	Россия, Санкт-Петербург, Поэтический бульвар, 3к2	0101000020E61000005D16139B8F573E40F58079C894054E40
81365	3	\N	\N	2	4294	\N	60.042978523613002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Парнас, Поэтический бульвар, дом 5, корп. 3	Россия, Санкт-Петербург, Поэтический бульвар, 5к3	0101000020E6100000C095ECD808583E4018B5FB5580054E40
81357	3	\N	\N	2	4294	\N	60.040469000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ N15, Поэтический бульвар, дом 15	Россия, Санкт-Петербург, Поэтический бульвар, 15	0101000020E61000005A0EF450DB5A3E403CC093162E054E40
81599	3	\N	\N	2	78776	\N	59.813138000000002	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Металлострой, улица Полевая, дом 10	Россия, Санкт-Петербург, посёлок Усть-Ижора, Полевая улица, 10	0101000020E61000006A1327F73B903E404391EEE714E84D40
81596	3	\N	\N	2	78805	\N	59.814433495850402	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Металлострой, улица Плановая, дом 14	Россия, Санкт-Петербург, посёлок Усть-Ижора, Полевая улица, 14	0101000020E610000033FAD170CA903E403FE42D573FE84D40
82071	3	\N	\N	2	16561	\N	60.020493890509997	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N70, улица Поклоногорская, дом 52		0101000020E6100000BA84436FF14C3E40D2E1218C9F024E40
81393	3	\N	\N	2	4080	\N	60.027017000000001	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, Поклонногорская улица, дом 17	Россия, Санкт-Петербург, Поклонногорская улица, 17	0101000020E6100000541A31B3CF4F3E40D0B7054B75034E40
81339	3	\N	\N	2	4080	\N	60.026909631099699	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Поклонногорская улица, дом 17	Россия, Санкт-Петербург, Поклонногорская улица, 17	0101000020E61000002DD2C43BC04F3E40BAF770C971034E40
81865	3	\N	\N	2	13264	\N	59.9143997795777	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Подвойского, дом 18, корп.3	Россия, Санкт-Петербург, улица Подвойского, 18к3	0101000020E6100000B8770DFAD2773E4030BB270F0BF54D40
81714	3	\N	\N	2	13252	\N	59.827619050009901	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Константиновское, улица Пограничника Гарькавого, дом 46, корп. 4	Россия, Санкт-Петербург, улица Пограничника Гарькавого, 46к4	0101000020E6100000F50EB743C3263E402C465D6BEFE94D40
81696	3	\N	\N	2	13252	\N	59.841250973834697	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица Пограничника Гарькавого, дом 11, корп. 2		0101000020E6100000EB353D2828253E40185DDE1CAEEB4D40
81779	3	\N	\N	2	13317	\N	60.082010619712499	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Ушково, Пляжевая улица, дом 10	Россия, Санкт-Петербург, посёлок Парголово, Пляжевая улица, 10	0101000020E61000002DCDAD10564B3E40C57421567F0A4E40
81940	3	\N	\N	2	3302	\N	59.964475999999998	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, улица Плуталова, дом 24	Россия, Санкт-Петербург, Плуталова улица, 24	0101000020E61000006901DA56B34E3E4071E316F373FB4D40
82158	3	\N	\N	2	15309	\N	59.842673745920401	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Пловдивская, дом 14	Россия, Санкт-Петербург, Малая Каштановая аллея	0101000020E6100000A14B38F416633E404298DBBDDCEB4D40
82062	3	\N	\N	2	4845	\N	60.025961000000002	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, улица Планерная, дом 73, корп. 1	Россия, Санкт-Петербург, Планерная улица, 73к1	0101000020E6100000B341261939373E4059FCA6B052034E40
82063	3	\N	\N	2	16616	\N	60.025080908667597	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, улица Планерная, дом 69, корп. 2 литер А	Россия, Санкт-Петербург, Приморский район, район Каменка	0101000020E6100000FAB660A92E383E402060ADDA35034E40
55010	7	63	1391	15800	54650	\N	54.281373000000002	с.Лямбирь, Октябрьская, 78		0101000020E61000003A799109F88F46401C7DCC0704244B40
81608	3	\N	\N	2	4615	\N	59.964669000000001	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Полюстрово, Пискаревский проспект, дом 13	Россия, Санкт-Петербург, Пискарёвский проспект, 13	0101000020E61000003543AA285E693E40863B17467AFB4D40
81607	3	\N	\N	2	4615	\N	59.964669000000001	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Полюстрово, Пискаревский  проспект, дом 13	Россия, Санкт-Петербург, Пискарёвский проспект, 13	0101000020E61000003543AA285E693E40863B17467AFB4D40
81601	3	\N	\N	2	4615	\N	60.003093	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Полюстрово, Пискаревский проспект, дом 144		0101000020E6100000B328ECA2E8713E405BECF65965004E40
81476	3	\N	\N	2	4615	\N	59.991155999999997	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Пискаревский проспект, дом 52	Россия, Санкт-Петербург, Пискарёвский проспект, 52	0101000020E61000003DB83B6BB76D3E40F99D2633DEFE4D40
81382	3	\N	\N	2	4615	\N	60.003021446539499	пр. Пискаревский д.145 Санаторий-профилакторий	Россия, Санкт-Петербург, Пискарёвский проспект, 145	0101000020E61000006CE9D1544F723E40C119FCFD62004E40
81466	3	\N	\N	2	15327	\N	59.966450919822499	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Пискаревский проспект, дом 14		0101000020E6100000DB6FED4449683E40DF1797AAB4FB4D40
81700	3	\N	\N	2	7398	\N	59.850623442762497	Петергофское ш. д. 82 к. 4,  (ООО «Евротракт»), тел.417-24-35	Россия, Санкт-Петербург, Петергофское шоссе, 82к4	0101000020E610000062D7F6764B1A3E40DA1CE736E1EC4D40
81670	3	\N	\N	2	7398	\N	59.848292782912303	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, Петергофское шоссе, дом 5, корп. 4	Россия, Санкт-Петербург, Петергофское шоссе, 5к4	0101000020E6100000F5F411F8C3333E407E3672DD94EC4D40
81669	3	\N	\N	2	7398	\N	59.848357560819402	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, Петергофское шоссе, дом 5, корп. 3	Россия, Санкт-Петербург, Петергофское шоссе, 5к3	0101000020E61000004DD6A88768343E4065A6B4FE96EC4D40
81664	3	\N	\N	2	7398	\N	59.848528108297799	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, Петергофское шоссе, дом 55, корп. 2, лит. А	Россия, Санкт-Петербург, Петергофское шоссе, 65	0101000020E61000008D28ED0DBE203E40C2DEC4909CEC4D40
82074	3	\N	\N	2	77171	\N	59.739463999999998	,Петроградское шоссе д.10 ЛГУ им. Пушкина	Россия, Санкт-Петербург, Петербургское шоссе, 10	0101000020E610000079B130444E633E40E048A0C1A6DE4D40
81618	3	\N	\N	2	7161	\N	59.931621	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Перевозный переулок, дом 19	Россия, Санкт-Петербург, Перевозный переулок, 19к1	0101000020E6100000F1F09E03CB693E4027A25F5B3FF74D40
82088	3	\N	\N	2	16458	\N	59.808542378163501	Поселок Шушары, Первомайская ул., 6, лит. А, (школа № 459) 382-87-58	Россия, Санкт-Петербург, посёлок Шушары, Первомайская улица, 4	0101000020E6100000B439CE6DC2613E40A2B8E34D7EE74D40
82083	3	\N	\N	2	16458	\N	59.8078127448236	Поселок Шушары, Первомайская ул., 6, лит. А,   (школа № 459)	Россия, Санкт-Петербург, посёлок Шушары, Первомайская улица	0101000020E6100000AAF23D2311623E404F24986A66E74D40
81852	3	\N	\N	2	16458	\N	59.808612638306002	Поселок Шушары, Первомайская ул., 6, лит. А, (школа № 459)	Россия, Санкт-Петербург, посёлок Шушары, Первомайская улица, 4	0101000020E6100000C58D5BCCCF613E406B0F7BA180E74D40
81399	3	\N	\N	2	16458	\N	60.101809000000003	Город Санкт-Петербург, Выборгский район, муниципальное образование поселок Левашово, Первомайская улица, дом 37		0101000020E61000001077F52A32323E4020B8CA13080D4E40
81930	3	\N	\N	2	3194	\N	59.958449000000002	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Посадский, переулок Певческий, дом 4	Россия, Санкт-Петербург, Певческий переулок, 4	0101000020E61000006D1FF296AB533E4024F1F274AEFA4D40
81300	3	\N	\N	2	3531	\N	59.986331	Парголовская ул., дом №11 корп.2, Клуб студенческого городка, тел. 295-27-20	Россия, Санкт-Петербург, Парголовская улица, 11к2	0101000020E61000003CA41820D1583E40F7031E1840FE4D40
81574	3	\N	\N	2	13271	\N	59.747835538167102	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Павловская, дом 82	Россия, Санкт-Петербург, Колпино, Павловская улица, 82	0101000020E610000099A0866F61913E40BF620D17B9DF4D40
81654	3	\N	\N	2	7545	\N	59.958471000000003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, Отечественная улица, дом 5		0101000020E6100000C6E1CCAFE67C3E400C957F2DAFFA4D40
81705	3	\N	\N	2	15331	\N	59.835478000000002	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Урицк, улица Отважных, дом 6		0101000020E6100000C1E09A3BFA2B3E4085436FF1F0EA4D40
81272	3	\N	\N	2	3195	\N	59.937362762744101	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Остоумова, дом 19В	Россия, Санкт-Петербург, Остоумова улица	0101000020E61000000E4B033FAA3D3E407FBDC282FBF74D40
81660	3	\N	\N	2	13344	\N	59.948139181462302	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Осипенко, дом 8		0101000020E61000005456D3F5447B3E40F487669E5CF94D40
81734	3	\N	\N	2	15289	\N	59.740707423411202	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Освобождения, дом 29, корп. 3	Россия, Санкт-Петербург, Красное Село, улица Освобождения, 26	0101000020E6100000F818AC38D5163E408A75AA7CCFDE4D40
81331	3	\N	\N	2	13260	\N	60.005225000000003	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, улица Орбели, дом 24		0101000020E610000087C1FC1532573E40910F7A36AB004E40
82121	3	\N	\N	2	74857	\N	59.728352000000001	,ул. Оранжерейная д.73 общежитие № 8		0101000020E6100000F6D03E56F06B3E40F4FC69A33ADD4D40
81269	3	\N	\N	2	13312	\N	59.934846730192497	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Опочинина, дом 35	Россия, Санкт-Петербург, Опочинина улица	0101000020E61000007FC16ED8B63C3E40C1E10511A9F74D40
81268	3	\N	\N	2	13312	\N	59.932102999999998	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Опочинина, дом 10		0101000020E61000001F10E84CDA3C3E4072C0AE264FF74D40
82023	3	\N	\N	2	4376	\N	59.995286999999998	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Омская, дом 16	Россия, Санкт-Петербург, Омская улица, 16	0101000020E61000009DF2E84658503E4025917D9065FF4D40
81844	3	\N	\N	2	1877	\N	59.862470000000002	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, Октябрьская набережная, дом 118	Россия, Санкт-Петербург, Октябрьская набережная, 118к1	0101000020E61000004AD05FE8117F3E40FCE3BD6A65EE4D40
81843	3	\N	\N	2	1877	\N	59.871729999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, Октябрьская набережная, дом 84, корп.1	Россия, Санкт-Петербург, Октябрьская набережная, 84к1	0101000020E61000008E588B4F01783E40967840D994EF4D40
81842	3	\N	\N	2	1877	\N	59.871729999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, Октябрьская набережная, дом 84, корп. 1	Россия, Санкт-Петербург, Октябрьская набережная, 84к1	0101000020E61000008E588B4F01783E40967840D994EF4D40
81841	3	\N	\N	2	1877	\N	59.871729999999999	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, Октябрьская набережная, дом 84, корп 1	Россия, Санкт-Петербург, Октябрьская набережная, 84к1	0101000020E61000008E588B4F01783E40967840D994EF4D40
81839	3	\N	\N	2	1877	\N	59.876888000000001	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, Октябрьская набережная, дом 70, корп.2	Россия, Санкт-Петербург, Октябрьская набережная, 70к2	0101000020E61000003735D07CCE753E409F20B1DD3DF04D40
81625	3	\N	\N	2	7197	\N	59.932906000000003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Новочеркасский проспект, дом 31	Россия, Санкт-Петербург, Новочеркасский проспект, 31	0101000020E6100000FDC0559E40683E40001FBC7669F74D40
81621	3	\N	\N	2	7197	\N	59.9225643058858	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Новочеркасский проспект, дом 50, корп. 3	Россия, Санкт-Петербург, Новочеркасский проспект, 52к3	0101000020E61000000D51853FC36B3E40C53BC09316F64D40
81305	3	\N	\N	2	3599	\N	59.995092999999997	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Новороссийская улица, дом 48	Россия, Санкт-Петербург, Новороссийская улица, 48	0101000020E6100000768C2B2E8E5A3E4040BD19355FFF4D40
81948	3	\N	\N	2	3409	\N	59.962431000000002	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, улица Новоладожская, дом 8		0101000020E6100000B262B83A00463E400BD462F030FB4D40
82070	3	\N	\N	2	4948	\N	60.026837	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N70, проспект Новоколомяжский, дом 4/4	Россия, Санкт-Петербург, Новоколомяжский проспект, 4к4	0101000020E61000005796E82CB34C3E4050A912656F034E40
81757	3	\N	\N	2	15829	\N	60.083685938405303	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, Ново-Гагаринская улица, дом 39, корп. 2	Россия, Санкт-Петербург, Сестрорецк, Ново-Гагаринская улица, 39	0101000020E6100000132A38BC20F63D4008910C39B60A4E40
82064	3	\N	\N	2	4871	\N	60.028753000000002	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, улица Нижне-Каменская, дом 2	Россия, Санкт-Петербург, Нижне-Каменская улица, 2	0101000020E6100000A73D25E7C43A3E40B954A52DAE034E40
82072	3	\N	\N	2	15296	\N	60.028747647341099	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N70, улица Нижне-Каменская, дом 2	Россия, Санкт-Петербург, Нижне-Каменская улица, 2	0101000020E6100000D3BD4EEACB3A3E40A7E9B303AE034E40
81301	3	\N	\N	2	3545	\N	59.967052000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, Нейшлотский переулок, дом 2	Россия, Санкт-Петербург, Нейшлотский переулок, 2	0101000020E61000008159A148F7573E4005C4245CC8FB4D40
82239	3	\N	\N	2	6433	\N	59.924208	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Лиговка-Ямская, проспект Невский, дом 169	Россия, Санкт-Петербург, Невский проспект, 169	0101000020E6100000B0E42A16BF613E40CD599F724CF64D40
82203	3	\N	\N	2	6433	\N	59.932861000000003	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ N78, проспект Невский, дом 39	Россия, Санкт-Петербург, Невский проспект, 39	0101000020E6100000A14B38F416573E40605B3FFD67F74D40
82199	3	\N	\N	2	6433	\N	59.932015680687897	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, проспект Невский, дом 108		0101000020E610000035255987A35B3E40A3ACDF4C4CF74D40
81846	3	\N	\N	2	1959	\N	59.884117000000003	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, улица Народная, дом 44		0101000020E610000050711C78B5783E40386BF0BE2AF14D40
81845	3	\N	\N	2	1959	\N	59.881940999999998	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N53, улица Народная, дом 63	Россия, Санкт-Петербург, Народная улица, 63	0101000020E610000001E0D8B3E77A3E4032005471E3F04D40
81243	3	\N	\N	2	2807	\N	59.904622000000003	Нарвский пр., д.6, ГОУ НОШ № 615	Россия, Санкт-Петербург, Нарвский проспект, 6	0101000020E610000024B891B245463E40FE9E58A7CAF34D40
81288	3	\N	\N	2	3366	\N	59.951763	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, улица Наличная, дом 44, корп. 5	Россия, Санкт-Петербург, Наличная улица, 44к1	0101000020E6100000E25CC30C8D3B3E407C45B75ED3F94D40
81287	3	\N	\N	2	3366	\N	59.952742409301102	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, улица Наличная, дом 44, корп. 4	Россия, Санкт-Петербург, Наличная улица, 44к4	0101000020E6100000C381902C603A3E4048C32973F3F94D40
81286	3	\N	\N	2	3366	\N	59.952970000000001	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, улица Наличная, дом 46, корп. 1	Россия, Санкт-Петербург, Наличная улица, 46	0101000020E6100000C8B5A1629C3B3E40D908C4EBFAF94D40
82184	3	\N	\N	2	79416	\N	59.945608	"Моховая ул., д. 6 Санкт-Петербургский промышленно- экономический колледж, тел.: 273-02-42 "		0101000020E6100000BE326FD575583E40016BD5AE09F94D40
81830	3	\N	\N	2	1052	\N	59.846423000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, Московский проспект, дом 203А	Россия, Санкт-Петербург, Московский проспект, 203а	0101000020E6100000C1C41F459D513E4086CABF9657EC4D40
81828	3	\N	\N	2	1052	\N	59.863427000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, Московский проспект, дом 169	Россия, Санкт-Петербург, Московский проспект, 169	0101000020E61000003ACB2C42B1513E40E0BDA3C684EE4D40
81788	3	\N	\N	2	1052	\N	59.879376000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Московский проспект, дом 164	Россия, Санкт-Петербург, Московский проспект, 164	0101000020E61000000A80F10C1A523E4093718C648FF04D40
81785	3	\N	\N	2	1052	\N	59.919711999999997	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Московский проспект, дом 112	Россия, Санкт-Петербург, Московский проспект, 112	0101000020E61000007C26FBE769503E408FDE701FB9F54D40
81784	3	\N	\N	2	1052	\N	59.900917	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Московский проспект, дом 96	Россия, Санкт-Петербург, Московский проспект, 96	0101000020E61000001956F146E6513E4089B48D3F51F34D40
81783	3	\N	\N	2	1052	\N	59.905078000000003	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Московский проспект, дом 80	Россия, Санкт-Петербург, Московский проспект, 80	0101000020E6100000BE33DAAA24523E40202A8D98D9F34D40
81235	3	\N	\N	2	1052	\N	59.899102999999997	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Измайловское, Московский проспект, дом 79	Россия, Санкт-Петербург, Московский проспект, 79	0101000020E610000097C4591135513E40245E9ECE15F34D40
81203	3	\N	\N	2	1052	\N	59.923851999999997	"Московский пр., д.9-11, ФГБОУ ВПО ""Петербургский государственный университет путей сообщения"""	Россия, Санкт-Петербург, Московский проспект, 9	0101000020E610000005A3923A01513E400E2C47C840F64D40
81285	3	\N	\N	2	3364	\N	59.936692069388698	Морская наб., д.15, корпус 3, Общежитие ФГБОУ ВПО «Санкт-Петербургский государственный горный университет», тел: 355-45-77	Россия, Санкт-Петербург, улица Кораблестроителей, 12к2	0101000020E61000005184D4EDEC373E4061360186E5F74D40
81276	3	\N	\N	2	3364	\N	59.941274518952298	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ округ Морской, Морская набережная, дом 15, корп. 2		0101000020E6100000577A6D3656363E406DC5FEB27BF84D40
81984	3	\N	\N	2	13321	\N	59.910804166654998	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, Михайловская улица, дом 14		0101000020E61000003F355EBA49C43D407288B83995F44D40
81927	3	\N	\N	2	15292	\N	59.959357122619998	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Кронверкское, улица Мира, дом 4		0101000020E61000001500E31934503E402618CE35CCFA4D40
81817	3	\N	\N	2	1564	\N	59.860160999999998	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Кубинская, дом 46		0101000020E6100000C74B3789414C3E40B72572C119EE4D40
81478	3	\N	\N	2	5763	\N	59.995980097020201	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Меншиковский проспект, дом 15, корп. 3	Россия, Санкт-Петербург, Меншиковский проспект, 15к3	0101000020E6100000E95F92CA146F3E402CBCCB457CFF4D40
81495	3	\N	\N	2	5954	\N	59.910080999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Морские ворота, Межевой канал, дом 6	Россия, Санкт-Петербург, Межевой канал, 6	0101000020E6100000D927806264413E4001DBC1887DF44D40
82007	3	\N	\N	2	16548	\N	59.994208691884097	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Мебельная, дом 21, корп. 3	Россия, Санкт-Петербург, Мебельная улица	0101000020E6100000E1B37570B0373E40C631923D42FF4D40
82198	3	\N	\N	2	15312	\N	59.933280000000003	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Маяковского, дом 8		0101000020E6100000A24621C9AC5A3E40650113B875F74D40
82031	3	\N	\N	2	13324	\N	60.011364351739303	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, улица Маршала Новикова, дом 8, корп. 2	Россия, Санкт-Петербург, улица Маршала Новикова, 8к2	0101000020E6100000B01D8CD827443E40062D246074014E40
81665	3	\N	\N	2	15328	\N	59.857956000000001	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, улица Маршала Захарова, дом 16, корп. 4		0101000020E610000056D636C5E32A3E4018B49080D1ED4D40
81492	3	\N	\N	2	13329	\N	59.8908057447141	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, улица Маршала Говорова, дом 34	Россия, Санкт-Петербург, улица Маршала Говорова, 34	0101000020E61000006F0ED76A0F473E40508A56EE05F24D40
81752	3	\N	\N	2	566	\N	59.942981734900897	Манежный пер., д.1, Школа-сад № 662, 435-08-97	Россия, Санкт-Петербург, Манежный переулок, 1	0101000020E6100000541EDD088B5A3E40BC5B59A2B3F84D40
81939	3	\N	\N	2	15731	\N	59.9672365694923	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, проспект Малый, дом 89	Россия, Санкт-Петербург, Петроградский район, Малый проспект П.С., 89	0101000020E6100000797764AC364F3E40963D096CCEFB4D40
81260	3	\N	\N	2	13375	\N	59.944800999999998	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Васильевский, Малый проспект В.О, дом 34	Россия, Санкт-Петербург, Василеостровский район, Малый проспект В.О., 34	0101000020E61000002F14B01D8C443E40321D3A3DEFF84D40
81224	3	\N	\N	2	2492	\N	59.912399999999998	Малодетскосельский пр., д.23, ГОУ СОШ № 307	Россия, Санкт-Петербург, Малодетскосельский проспект, 23	0101000020E6100000FAEFC16B97523E40696FF085C9F44D40
82176	3	\N	\N	2	6028	\N	59.845120999999999	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Малая Бухарестская, дом 36, корп. 3	Россия, Санкт-Петербург, Малая Бухарестская улица	0101000020E6100000CB13083BC56A3E40D714C8EC2CEC4D40
82164	3	\N	\N	2	13258	\N	59.848102581425501	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N75, улица Малая Бухарестская, дом 7, корп. 1	Россия, Санкт-Петербург, Малая Бухарестская улица, 7	0101000020E6100000342BDB87BC693E40DB519CA38EEC4D40
82174	3	\N	\N	2	13249	\N	59.8484162656883	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Малая Бухарестская, дом 44	Россия, Санкт-Петербург, Малая Бухарестская улица	0101000020E610000075E5B33C0F6A3E409AB33EE598EC4D40
82163	3	\N	\N	2	13249	\N	59.848913987708897	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N75, улица Малая Бухарестская, дом 5, корп. 1	Россия, Санкт-Петербург, Малая Бухарестская улица, 5	0101000020E6100000DFA3FE7A85693E40EB8EC536A9EC4D40
82175	3	\N	\N	2	67084	\N	59.826456	Малая Балканская ул., дом 36 корп. 3, школа № 312, тел. 778-41-77		0101000020E6100000ADA23F34F3643E409FCA694FC9E94D40
82168	3	\N	\N	2	15307	\N	59.831023695057901	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ N75, улица Малая Балканская, дом 60, корп. 3		0101000020E6100000210725CCB46D3E40761893FE5EEA4D40
81560	3	\N	\N	2	67086	\N	59.844692000000002	ул. Лени Голикова д.15 корп 2 школа № 221		0101000020E61000009B92ACC3D1393E40AF9811DE1EEC4D40
81771	3	\N	\N	2	16670	\N	60.1668267060085	Город Санкт-Петербург, Курортный район, муниципальное образование поселок Репино, Луговая улица, дом 4	Россия, Санкт-Петербург, посёлок Репино, Луговая улица	0101000020E61000003293A8177CDE3D407E8B4E965A154E40
81194	3	\N	\N	2	79414	\N	59.918652000000002	Лоцманская ул., д.10, ФГБОУ ВПО «Санкт-Петербургский морской технический университет»	Россия, Санкт-Петербург, Лоцманская улица, 10	0101000020E610000032005471E3463E40D733846396F54D40
82195	3	\N	\N	2	15322	\N	59.937520234490201	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, проспект Литейный, дом 46	Россия, Санкт-Петербург, Литейный проспект	0101000020E6100000A4C343183F593E4047ACC5A700F84D40
82243	3	\N	\N	2	5504	\N	59.922047999999997	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Лиговка-Ямская, проспект Лиговский, дом 70	Россия, Санкт-Петербург, Лиговский проспект, 70	0101000020E610000048E17A14AE5B3E40CDAB3AAB05F64D40
82115	3	\N	\N	2	5504	\N	59.912345999999999	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Лиговский проспект, дом 156	Россия, Санкт-Петербург, Лиговский проспект, 156	0101000020E6100000A79196CADB593E407651F4C0C7F44D40
81234	3	\N	\N	2	1867	\N	59.911850000000001	Лермонтовский пр., д.52, ГОУ СОШ № 280	Россия, Санкт-Петербург, Лермонтовский проспект, 52	0101000020E61000003F524486554C3E40C66D3480B7F44D40
81180	3	\N	\N	2	1867	\N	59.919071000000002	Лермонтовский пр., д.21                    ГОУ СОШ № 260	Россия, Санкт-Петербург, Лермонтовский проспект, 21	0101000020E6100000A6F0A0D9754B3E40DCD9571EA4F54D40
81733	3	\N	\N	2	13358	\N	59.732044000000002	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Лермонтова, дом 23		0101000020E61000005393E00D69143E40D49D279EB3DD4D40
81810	3	\N	\N	2	15318	\N	59.835694365352602	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, улица Ленсовета, дом 87, корп. 2		0101000020E61000000491459A78573E4051BB5F05F8EA4D40
81636	3	\N	\N	2	7323	\N	59.941465999999998	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Ленская, дом 2, корп. 2	Россия, Санкт-Петербург, Ленская улица, 2	0101000020E61000003F90BC73287B3E40E12538F581F84D40
81635	3	\N	\N	2	7323	\N	59.939693722185403	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Ленская, дом 1, корп. 2	Россия, Санкт-Петербург, Ленская улица, 1к2	0101000020E610000021E692AAED7A3E40AC1F9BE447F84D40
82246	3	\N	\N	2	74863	\N	59.939788999999998	ул. Ленская д.1 к.2 ДЮСШ №2		0101000020E6100000E71BD13DEB7A3E40FD1186014BF84D40
81682	3	\N	\N	2	6100	\N	\N	Ленинский пр.д.94 к.2 Гимназия № 293		\N
81675	3	\N	\N	2	6100	\N	59.855396680918702	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Юго-Запад, Ленинский проспект, дом 94, корп. 2	Россия, Санкт-Петербург, Ленинский проспект, 96к2	0101000020E610000023F59ECA69373E405B0C1EA67DED4D40
81667	3	\N	\N	2	6100	\N	59.857129	Ленинский пр.д.82 к.4 Детский сад	Россия, Санкт-Петербург, Ленинский проспект, 84а	0101000020E6100000715985CD00333E4002BA2F67B6ED4D40
81666	3	\N	\N	2	6100	\N	59.861623147272603	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, Ленинский проспект, дом 72, корп. 2	Россия, Санкт-Петербург, Ленинский проспект	0101000020E61000006953758F6C2E3E409F3D97A949EE4D40
81518	3	\N	\N	2	6100	\N	59.8498862152301	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, Ленинский проспект, дом 133, корп. 4	Россия, Санкт-Петербург, Ленинский проспект, 133к4	0101000020E6100000F5BEF1B567463E4004AA7F10C9EC4D40
81513	3	\N	\N	2	6100	\N	59.849749496138998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, Ленинский проспект, дом 123, корп. 4	Россия, Санкт-Петербург, Ленинский проспект, 123к4	0101000020E6100000E4F90CA837433E4084674293C4EC4D40
81511	3	\N	\N	2	6100	\N	59.852975865798903	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, Ленинский проспект, дом 124, корп. 2	Россия, Санкт-Петербург, Ленинский проспект, 124к2	0101000020E6100000D13DEB1A2D433E40EE224C512EED4D40
82096	3	\N	\N	2	13345	\N	59.724000397679099	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Ленинградская улица, дом 2	Россия, Санкт-Петербург, Пушкин, Ленинградская улица, 2	0101000020E6100000C9C9C4AD826C3E40E9263108ACDC4D40
82094	3	\N	\N	2	13345	\N	59.7313872857167	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Ленинградская улица, дом 83		0101000020E6100000BB99D18F86673E401ADCD6169EDD4D40
81955	3	\N	\N	2	3493	\N	59.966583	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, Левашовский проспект, дом 5	Россия, Санкт-Петербург, Левашовский проспект, 5	0101000020E6100000804A95287B4B3E404EEFE2FDB8FB4D40
81561	3	\N	\N	2	13352	\N	59.756021176114501	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, шоссе Лагерное, дом 32	Россия, Санкт-Петербург, посёлок Понтонный, Лагерное шоссе, 32	0101000020E6100000221807978E9D3E406B0BCF4BC5E04D40
81361	3	\N	\N	2	13356	\N	60.049267	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ N15, улица Кустодиева, дом 18, корп. 2		0101000020E61000005D3123BC3D5C3E40D2E28C614E064E40
81239	3	\N	\N	2	2731	\N	59.911990000000003	ул. Курляндская, д.43, ГОУ СОШ № 288	Россия, Санкт-Петербург, Курляндская улица, 43	0101000020E6100000B8AD2D3C2F453E40B8239C16BCF44D40
82160	3	\N	\N	2	5970	\N	59.837744864655903	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Купчинская, дом 15, корп. 3	Россия, Санкт-Петербург, Купчинская улица, 15к3	0101000020E6100000D80FB1C1C2613E409AB1683A3BEB4D40
82156	3	\N	\N	2	5970	\N	59.841314921852799	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Купчинская, дом 11, корп. 4	Россия, Санкт-Петербург, Купчинская улица, 11к4	0101000020E6100000A6B73F170D613E402F51BD35B0EB4D40
81814	3	\N	\N	2	15319	\N	59.872444649784001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Кузнецовская, дом 20, корп. 2		0101000020E610000046D26EF4314F3E4084471B47ACEF4D40
81816	3	\N	\N	2	1564	\N	59.862040999999998	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Кубинская, дом 32, корп. 1		0101000020E6100000198F52094F4C3E40D367075C57EE4D40
81853	3	\N	\N	2	13282	\N	59.895958	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, улица Крыленко, дом 25, корп.5		0101000020E6100000E99E758D967B3E40774B72C0AEF24D40
81507	3	\N	\N	2	16551	\N	59.8711732720678	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Кронштадская, дом 7	Россия, Санкт-Петербург, Кронштадтская улица, 7	0101000020E61000005A9E077767413E404014CC9882EF4D40
82112	3	\N	\N	2	16855	\N	59.780137000000003	Пушкинский район,Красносельское шоссе д.9 школа № 409	Россия, Санкт-Петербург, Красносельский район, Красносельское шоссе, 9	0101000020E6100000220038F6EC213E4025B37A87DBE34D40
81922	3	\N	\N	2	16855	\N	59.775824999999998	Пушкинский район, Красносельское шоссе д.14 корп.3 школа №335	Россия, Санкт-Петербург, Красносельский район, Красносельское шоссе, 14	0101000020E61000000C93A98251213E40A835CD3B4EE34D40
82110	3	\N	\N	2	13348	\N	59.706263779696499	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Красносельское шоссе, дом 14, корп. 3		0101000020E6100000D4F19881CA603E40CB2BD7DB66DA4D40
82078	3	\N	\N	2	13348	\N	59.696575000000003	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Красносельское шоссе, дом 9	Россия, Санкт-Петербург, Пушкинский район, МО город Пушкин	0101000020E61000005B5F24B4E5583E40091B9E5E29D94D40
81725	3	\N	\N	2	13348	\N	59.81859	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Горелово, шоссе Красносельское, дом 54, корп. 7		0101000020E6100000EF5696E82C133E40946A9F8EC7E84D40
81818	3	\N	\N	2	1601	\N	59.858381000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Краснопутиловская, дом 60	Россия, Санкт-Петербург, Краснопутиловская улица, 60	0101000020E6100000780B24287E4C3E40FF40B96DDFED4D40
81505	3	\N	\N	2	1601	\N	59.871842999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Краснопутиловская, дом 22		0101000020E6100000B1A547533D453E408E1F2A8D98EF4D40
81503	3	\N	\N	2	1601	\N	59.87612	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Краснопутиловская, дом 2	Россия, Санкт-Петербург, Краснопутиловская улица, 2	0101000020E610000004029D499B423E408EAF3DB324F04D40
81742	3	\N	\N	2	15710	\N	59.7187288288129	Город Санкт-Петербург, Красносельский район, муниципальное образование город Красное Село, улица Красногородская, дом 7, корп. 3	Россия, Санкт-Петербург, Красное Село, Красногородская улица, 7	0101000020E610000097033DD4B6193E40E9D7D64FFFDB4D40
81947	3	\N	\N	2	15297	\N	59.954811483420698	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ округ Петровский, улица Красного Курсанта, дом 6/9		0101000020E61000000518963FDF4A3E40376E313F37FA4D40
81681	3	\N	\N	2	74859	\N	59.857595000000003	улица Котина д.6 к.3 Лицей №590	Россия, Санкт-Петербург, улица Котина, 6к3	0101000020E610000013F241CF66353E40481B47ACC5ED4D40
81355	3	\N	\N	2	4054	\N	60.021186	пр. Костромской д.46 Колледж №4	Россия, Санкт-Петербург, Костромской проспект, 46	0101000020E61000008F56B5A4A3503E4008910C39B6024E40
81337	3	\N	\N	2	4054	\N	60.021186	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Костромской проспект, дом 46	Россия, Санкт-Петербург, Костромской проспект, 46	0101000020E61000008F56B5A4A3503E4008910C39B6024E40
81290	3	\N	\N	2	13266	\N	59.953101917212997	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Остров Декабристов, улица Кораблестроителей, дом 37, корп. 5	Россия, Санкт-Петербург, улица Кораблестроителей, 37к5	0101000020E61000000F5F268A903A3E4048E00F3FFFF94D40
81280	3	\N	\N	2	13266	\N	59.945774421515203	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ округ Морской, улица Кораблестроителей, дом 21, корп. 1		0101000020E610000091F0BDBF41373E401CB4571F0FF94D40
82105	3	\N	\N	2	13276	\N	59.685434210921002	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Павловск, Конюшенная улица, дом 7		0101000020E610000008AD872F13713E4082C8224DBCD74D40
82104	3	\N	\N	2	13276	\N	59.6812307771498	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Павловск, Конюшенная улица, дом 24	Россия, Санкт-Петербург, Павловск, Конюшенная улица, 24	0101000020E6100000C91D3691996F3E40BC02D19332D74D40
82218	3	\N	\N	2	15317	\N	59.918227999999999	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Константина Заслонова, дом 23		0101000020E6100000EBE0606F62583E40C022BF7E88F54D40
81460	3	\N	\N	2	13316	\N	59.968975723594497	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Кондратьевский проспект, дом 40, корп. 7	Россия, Санкт-Петербург, Кондратьевский проспект, 40к7	0101000020E6100000DA3BA3AD4A623E40F04DD36707FC4D40
13474	7	66	939	57903	61856	\N	56.043598585013598	посёлок Совхозный, Заводская, 5	Россия, республика Чувашская, Ядринский район, село Совхозный	0101000020E61000009FE40E9BC8224740B491EBA694054C40
81392	3	\N	\N	2	15302	\N	60.053658038479099	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, проспект Композиторов, дом 11, корп. 2		0101000020E610000015191D9084513E409A95ED43DE064E40
81652	3	\N	\N	2	16615	\N	60.010142289155297	"Коммуны ул., д.42, к.3, ГОУ гимназия № 628 ""Александринская гимназия"", тел. 521-22-87"		0101000020E6100000B0E3BF4010A83E40742843554C014E40
81649	3	\N	\N	2	16615	\N	60.102625232864597	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, улица Коммуны, дом 32, корп. 4	Россия, Санкт-Петербург, посёлок Левашово, улица Коммуны	0101000020E6100000E1270EA0DF333E404260E5D0220D4E40
82247	3	\N	\N	2	74855	\N	60.102539999999998	ул. Коммуны д.32 к.4 школа № 141		0101000020E6100000F01307D0EF333E401344DD07200D4E40
82248	3	\N	\N	2	4745	\N	60.012574999999998	Комендантский пр. д.17 корп.3 школа № 555	Россия, Санкт-Петербург, Комендантский проспект, 17к3	0101000020E6100000FFD0CC936B423E40A4DFBE0E9C014E40
82056	3	\N	\N	2	4745	\N	60.024642295493599	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Комендантский, дом 37, корп. 3	Россия, Санкт-Петербург, Комендантский проспект, 37к3	0101000020E610000023A0C211A43E3E40D40D147827034E40
82055	3	\N	\N	2	4745	\N	60.020334296993099	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Комендантский, дом 29, корп. 2	Россия, Санкт-Петербург, Комендантский проспект, 29к2	0101000020E61000004888F2052D403E40997FF44D9A024E40
82054	3	\N	\N	2	4745	\N	60.019185	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Юнтолово, проспект Комендантский, дом 29, корп.2	Россия, Санкт-Петербург, Комендантский проспект, 29к1	0101000020E6100000A0168387693F3E4071C971A774024E40
82111	3	\N	\N	2	16571	\N	59.7256836086774	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Шушары, Колпинское шоссе (Славянка), дом 20, корп. 3	Россия, Санкт-Петербург, Пушкин, Колпинское шоссе, 22	0101000020E6100000AB23473A03733E40809D9B36E3DC4D40
81875	3	\N	\N	2	13331	\N	59.923240503550197	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Оккервиль, улица Коллонтай, дом 41, корп.2	Россия, Санкт-Петербург, улица Коллонтай, 41к2	0101000020E6100000F513CE6E2D7F3E40C5A9D6C22CF64D40
81867	3	\N	\N	2	13331	\N	59.914976226590298	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Коллонтай, дом 19, копр.5		0101000020E6100000B70A62A06B773E40FD4FFEEE1DF54D40
82229	3	\N	\N	2	6681	\N	59.937449999999998	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, переулок Ковенский, дом 10	Россия, Санкт-Петербург, Ковенский переулок, 10	0101000020E6100000DC65BFEE745B3E404ED1915CFEF74D40
82227	3	\N	\N	2	6621	\N	59.942931000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Кирочная, дом 54		0101000020E6100000F419506F46613E403AB187F6B1F84D40
82223	3	\N	\N	2	6621	\N	59.944088999999998	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Кирочная, дом 28А		0101000020E610000023BE13B35E5C3E40B5C189E8D7F84D40
82190	3	\N	\N	2	13304	\N	59.9441308472964	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Кирочная, дом 8а	Россия, Санкт-Петербург, Кирочная улица	0101000020E61000000C91D3D7F3593E40E411DC48D9F84D40
82076	3	\N	\N	2	13339	\N	59.697707083399401	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Кедринская улица, дом 10А		0101000020E6100000E0DBF4673F6A3E405B9885764ED94D40
82177	3	\N	\N	2	13379	\N	59.934460999999999	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Дворцовый округ, улица Караванная, дом 22	Россия, Санкт-Петербург, Караванная улица, 22	0101000020E6100000E449D23593573E409831056B9CF74D40
81910	3	\N	\N	2	2910	\N	59.838597999999998	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Рыбацкое, улица Караваевская, дом 6	Россия, Санкт-Петербург, Караваевская улица, 6	0101000020E6100000ACE63922DF7D3E40D93EE42D57EB4D40
81496	3	\N	\N	2	13371	\N	59.903511999999999	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Морские ворота, Канонерский остров, дом 32		0101000020E61000001DE6CB0BB0373E4093C5FD47A6F34D40
81192	3	\N	\N	2	2032	\N	59.918913000000003	"Канонерская ул., д.33 ГОУ СОШ № 234"		0101000020E6100000CFDBD8EC48493E40446FF1F09EF54D40
81265	3	\N	\N	2	3093	\N	59.931842000000003	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Канареечная, дом 11		0101000020E61000006D718DCF643F3E400685419946F74D40
81999	3	\N	\N	2	4083	\N	60.005383000000002	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Камышовая, дом 18		0101000020E6100000EC1681B1BE3D3E40297AE063B0004E40
81956	3	\N	\N	2	3227	\N	59.973831994733999	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, Каменноостровский проспект, дом 64, корп. 3	Россия, Санкт-Петербург, Каменноостровский проспект, 64к3	0101000020E61000000306499F564D3E402EE6E786A6FC4D40
6171	7	65	\N	11375	52574	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Сивкова, д.24г		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
81941	3	\N	\N	2	3227	\N	59.967703680961399	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, проспект Каменноостровский, дом 42-Б	Россия, Санкт-Петербург, Левашовский проспект	0101000020E6100000ED815660C84E3E40AC1A84B9DDFB4D40
81937	3	\N	\N	2	3227	\N	59.974279000000003	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, проспект Каменноостровский, дом 69/71	Россия, Санкт-Петербург, Каменноостровский проспект, 69	0101000020E61000000E164ED2FC4D3E40FD169D2CB5FC4D40
81934	3	\N	\N	2	3227	\N	59.964863000000001	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Аптекарский остров, проспект Каменноостровский, дом 36/73		0101000020E61000003B56293DD34F3E406B0F7BA180FB4D40
81245	3	\N	\N	2	15310	\N	59.942501999999998	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, Кадетская линия, дом 3/5		0101000020E6100000E6913F18784A3E401135D1E7A3F84D40
82225	3	\N	\N	2	13322	\N	59.946153000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица Кавалергардская, дом 9		0101000020E6100000402FDCB930623E409301A08A1BF94D40
81643	3	\N	\N	2	7399	\N	59.953178027899398	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, Ириновский проспект, дом 17, корп. 5	Россия, Санкт-Петербург, Ириновский проспект, 17к5	0101000020E6100000FC7266BB42773E4023A298BC01FA4D40
81642	3	\N	\N	2	7399	\N	59.956547999999998	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, Ириновский проспект, дом 23, корп. 2	Россия, Санкт-Петербург, Ириновский проспект, 23к1	0101000020E6100000A2D11DC4CE783E40F086342A70FA4D40
81323	3	\N	\N	2	3856	\N	59.994962999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Институтский переулок, дом 5	Россия, Санкт-Петербург, Институтский переулок, 5	0101000020E6100000522B4CDF6B583E4072DD94F25AFF4D40
81647	3	\N	\N	2	7458	\N	59.938716557837701	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, Индустриальный проспект, дом 10, корп. 2	Россия, Санкт-Петербург, Индустриальный проспект, 10к2	0101000020E610000090BC732843793E408099EFE027F84D40
81897	3	\N	\N	2	2719	\N	59.875574	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Ивановский, улица Ивановская, дом 11	Россия, Санкт-Петербург, Ивановская улица, 11	0101000020E61000003E963E7441713E402C9D0FCF12F04D40
81558	3	\N	\N	2	15299	\N	59.848360765972899	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, улица Зины Портновой, дом 25, корп. 2		0101000020E61000003562669FC7403E40D619DF1797EC4D40
81701	3	\N	\N	2	15330	\N	59.838475000000003	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица Здоровцева, дом 12		0101000020E61000002579AEEFC3293E40BEC1172653EB4D40
81811	3	\N	\N	2	1500	\N	59.833353000000002	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, Звёздная улица, дом 7		0101000020E6100000603FC4060B5B3E400283A44FABEA4D40
81917	3	\N	\N	2	3004	\N	59.951825999999997	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Введенский, улица Зверинская, дом 35		0101000020E6100000BB9866BAD74D3E40C2BD326FD5F94D40
81918	3	\N	\N	2	15326	\N	59.952416595457301	"ул. Зверинская, 21 (отделение в Петроградском районе ГОУ НПО Экономический профессиональный лицей) тел. 232-25-58 "		0101000020E6100000FD4FFEEE1D4D3E40C493DDCCE8F94D40
82219	3	\N	\N	2	16554	\N	59.917403540816203	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Владимирский округ, улица Звенигородская, дом 30-а	Россия, Санкт-Петербург, Звенигородская улица, 30	0101000020E61000007BA35698BE573E401B9C887E6DF54D40
81470	3	\N	\N	2	13337	\N	59.9805084320002	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Замшина улица, дом 31, корп. 2	Россия, Санкт-Петербург, улица Замшина, 31к2	0101000020E6100000A2B437F8C2683E40B2BB404981FD4D40
81464	3	\N	\N	2	13337	\N	59.974055841606202	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Замшина улица, дом 17	Россия, Санкт-Петербург, улица Замшина, 17	0101000020E61000006AC020E9D3663E407D3CF4DDADFC4D40
81458	3	\N	\N	2	13337	\N	59.9806162165128	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Замшина улица, дом 58, корп. 2		0101000020E6100000193C4CFBE6663E4098F738D384FD4D40
81504	3	\N	\N	2	15329	\N	59.873351999999997	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Зайцева, дом 14		0101000020E61000001D1EC2F869443E40B6F292FFC9EF4D40
81219	3	\N	\N	2	2428	\N	59.918470999999997	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Семеновский, Загородный проспект, дом 58	Россия, Санкт-Петербург, Загородный проспект, 58	0101000020E6100000F16778B306533E4086A92D7590F54D40
6821	7	65	1195	12047	52802	\N	56.972914000000003	Удмуртская Республика, Увинский район, с.Ува-Тукля, ул.Добровольского, 16		0101000020E610000059A7CAF78C0E4A4008E92972887C4C40
81981	3	\N	\N	2	13311	\N	59.900964238218002	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, улица Жоры Антоненко, дом 1	Россия, Санкт-Петербург, Ломоносов, улица Жоры Антоненко, 1	0101000020E61000008C868C47A9D03D40CA6FD1C952F34D40
81390	3	\N	\N	2	13360	\N	60.064737229478403	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Жени Егоровой, дом 10, корп. 2		0101000020E610000020D3DA34B64F3E40ABEB504D49084E40
82091	3	\N	\N	2	13353	\N	59.733614687517303	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Железнодорожная улица, дом 54	Россия, Санкт-Петербург, Пушкин, Железнодорожная улица, 54	0101000020E61000003C4CFBE6FE6A3E40726DA818E7DD4D40
82092	3	\N	\N	2	13280	\N	59.734143500061599	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Железнодорожная улица, дом 56		0101000020E61000007F677BF4866B3E40FE463B6EF8DD4D40
81856	3	\N	\N	2	15303	\N	59.897160148057601	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ N54, улица Евдокима Огнева, дом 4, корп.2		0101000020E61000002D431CEBE2763E40C2A38D23D6F24D40
81862	3	\N	\N	2	13293	\N	59.903488491186899	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Дыбенко, дом 12, корп.2	Россия, Санкт-Петербург, улица Дыбенко, 12к2	0101000020E61000006BD8EF8975763E400B2AAA7EA5F34D40
81859	3	\N	\N	2	13293	\N	59.9075516827127	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Дыбенко, дом 24, корп.4		0101000020E6100000DCB930D28B7A3E40AFB5F7A92AF44D40
82169	3	\N	\N	2	5972	\N	59.838348802068403	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, проспект Дунайский, дом 43, корп. 2	Россия, Санкт-Петербург, Дунайский проспект, 43к2	0101000020E6100000E8667FA0DC663E4031D120054FEB4D40
82157	3	\N	\N	2	5972	\N	59.840868970441598	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, проспект Дунайский, дом 48, корп. 2	Россия, Санкт-Петербург, Дунайский проспект, 48к2	0101000020E610000045A165DD3F663E40309C6B98A1EB4D40
81236	3	\N	\N	2	2685	\N	59.910784999999997	ул.Дровяная, д.7а, ГОУ гимназия № 278	Россия, Санкт-Петербург, Дровяная улица, 7а	0101000020E610000058E71890BD4A3E40FB57569A94F44D40
81332	3	\N	\N	2	3977	\N	60.013559999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Дрезденская улица, дом 19	Россия, Санкт-Петербург, Дрезденская улица, 19	0101000020E61000006CB1DB6795553E4052448655BC014E40
81589	3	\N	\N	2	13365	\N	59.777611805831398	Город Санкт-Петербург, Колпинский район, муниципальное образование поселок Саперный, улица Дорожная, дом 11	Россия, Санкт-Петербург, посёлок Сапёрный, Дорожная улица, 11	0101000020E610000094FB1D8A02B13E40137D3ECA88E34D40
81707	3	\N	\N	2	13261	\N	59.826444365604303	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Урицк, улица Добровольцев, дом 60, корп. 2		0101000020E61000002B4D4A41B72B3E40DBFCBFEAC8E94D40
82152	3	\N	\N	2	13363	\N	59.849054337052401	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Димитрова, дом 10, корп. 3	Россия, Санкт-Петербург, улица Димитрова, 10к3	0101000020E6100000B98B3045B9603E40DD442DCDADEC4D40
82089	3	\N	\N	2	16340	\N	59.740119734088701	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Шушары, Центральна улица (Детскосельский), дом 6	Россия, Санкт-Петербург, Пушкин, Детскосельский бульвар	0101000020E6100000E770ADF6B0673E40C98E8D40BCDE4D40
82082	3	\N	\N	2	16340	\N	59.740991659926699	Город Санкт-Петербург, Пушкинский район, муниципальное образование поселок Шушары, Центральная улица (Детскосельский), дом 17	Россия, Санкт-Петербург, Пушкин, Детскосельский бульвар, 17	0101000020E6100000809E060C926A3E407F4C6BD3D8DE4D40
81430	3	\N	\N	2	13301	\N	60.038517611291098	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Северный, улица Демьяна Бедного, дом 12, корп. 2	Россия, Санкт-Петербург, улица Демьяна Бедного, 12к1	0101000020E6100000AED3484BE5613E4057276728EE044E40
82106	3	\N	\N	2	15293	\N	59.679325923322203	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Павловск, улица Декабристов, дом 16	Россия, Санкт-Петербург, Павловск, улица Декабристов, 16	0101000020E61000008C84B69C4B753E4048A98427F4D64D40
82228	3	\N	\N	2	6680	\N	59.939843000000003	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, переулок Дегтярный, дом 24	Россия, Санкт-Петербург, Дегтярный переулок, 24	0101000020E6100000658C0FB397613E40F12F82C64CF84D40
81990	3	\N	\N	2	16539	\N	59.909554129889202	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, улица Дегтярева, дом 1/7	Россия, Санкт-Петербург, Ломоносов, улица Дегтярёва, 1	0101000020E61000004293C49272C33D4016F9F5436CF44D40
81983	3	\N	\N	2	16859	\N	59.939852000000002	"Дворцовый пр., д.12 Районный дом культуры дом 40  администрация муниципального образования город Ломоносов 422-06-21 "	Россия, Санкт-Петербург, Дворцовый проезд	0101000020E61000008448861C5B4F3E40448A01124DF84D40
55009	7	63	1391	15800	54339	\N	54.281373000000002	с.Лямбирь, Ленина, 67		0101000020E61000003A799109F88F46401C7DCC0704244B40
81552	3	\N	\N	2	6236	\N	59.848430941889397	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Дачное, Дачный проспект, дом 3, корп. 2	Россия, Санкт-Петербург, Дачный проспект, 3к2	0101000020E61000006DC9AA08373D3E40CFF4126399EC4D40
81523	3	\N	\N	2	6236	\N	59.838711000000004	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Княжево, Дачный проспект, дом 34, корп. 2	Россия, Санкт-Петербург, Дачный проспект, 34к1	0101000020E61000001F0F7D772B433E40D2E5CDE15AEB4D40
82192	3	\N	\N	2	13370	\N	59.941680346085697	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, переулок Гродненский, дом 8/10	Россия, Санкт-Петербург, Гродненский переулок	0101000020E610000026E0D748125C3E400DA661F888F84D40
82231	3	\N	\N	2	6714	\N	59.936607000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, проспект Греческий, дом 21	Россия, Санкт-Петербург, Греческий проспект, 21	0101000020E6100000B537F8C2645E3E40331AF9BCE2F74D40
81448	3	\N	\N	2	4954	\N	60.007983000000003	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Гражданка, Гражданский проспект, дом 31, корп. 5	Россия, Санкт-Петербург, Гражданский проспект, 31к1	0101000020E6100000F5DA6CACC4643E4045F6419605014E40
81413	3	\N	\N	2	4954	\N	60.020011835177598	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, Гражданский проспект, дом 92, корп. 3	Россия, Санкт-Петербург, Гражданский проспект, 92к3	0101000020E6100000D3BF249529663E4087C3D2C08F024E40
81412	3	\N	\N	2	4954	\N	60.018102927479902	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Академическое, Гражданский проспект, дом 88, корп. 2		0101000020E61000002785798F33653E40D17AF83251024E40
82201	3	\N	\N	2	6408	\N	59.931485000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ N78, улица Гороховая, дом 20	Россия, Санкт-Петербург, Гороховая улица, 20	0101000020E61000006F0D6C9560513E4077DB85E63AF74D40
82108	3	\N	\N	2	15465	\N	59.664775682202396	г. Павловск, Горная ул., (Павловская опытная станция Всероссийского института растениеводства)	Россия, Санкт-Петербург, Павловск, Горная улица	0101000020E610000040BE840A0E673E403695456117D54D40
82241	3	\N	\N	2	6809	\N	59.928812000000001	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Лиговка-Ямская, улица Гончарная, дом 15		0101000020E610000012F758FAD05D3E40F110C64FE3F64D40
81469	3	\N	\N	2	15314	\N	59.982055000000003	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Герасимовская улица, дом 5		0101000020E61000007FA31D37FC663E40C8EF6DFAB3FD4D40
81333	3	\N	\N	2	3999	\N	60.015575252399401	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Гданьская улица, дом 19, корп. 2	Россия, Санкт-Петербург, Гданьская улица, 19к2	0101000020E61000007099D36531553E404ED1915CFE014E40
81793	3	\N	\N	2	67063	\N	59.857807000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, улица Гастелло, дом 19		0101000020E6100000022A1C412A553E40D3A3A99ECCED4D40
81996	3	\N	\N	2	4053	\N	60.003390000000003	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, улица Гаккелевская, дом 24	Россия, Санкт-Петербург, Гаккелевская улица, 24к1	0101000020E6100000C15774EB35413E40159161156F004E40
82182	3	\N	\N	2	16658	\N	59.947429939438301	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Литейный округ, улица Гагаринская, дом 5		0101000020E6100000ECFA05BB61573E40E89FE06245F94D40
81275	3	\N	\N	2	3107	\N	59.940162999999998	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Гаванская, дом 54		0101000020E610000028B517D1763C3E4062F4DC4257F84D40
81266	3	\N	\N	2	3107	\N	59.928212000000002	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Гавань, улица Гаванская, дом 3		0101000020E61000007C613255303E3E409CE09BA6CFF64D40
81957	3	\N	\N	2	3510	\N	59.972104999999999	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, Вяземский переулок, дом 5-7	Россия, Санкт-Петербург, Вяземский переулок, 5	0101000020E6100000FFCD8B135F4D3E4098A3C7EF6DFC4D40
81308	3	\N	\N	2	3645	\N	59.964539000000002	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, Выборгская улица, дом 3		0101000020E6100000BE4F55A181583E40B85B920376FB4D40
82117	3	\N	\N	2	5527	\N	59.909250999999998	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Воронежская улица, дом 79	Россия, Санкт-Петербург, Воронежская улица, 79	0101000020E6100000508BC1C3B4573E407A6D365662F44D40
81960	3	\N	\N	2	16633	\N	59.845580010134903	Город Санкт-Петербург, Петродворцовый район, муниципальное образование поселок Стрельна, Волхонское шоссе, дом 26а	Россия, Санкт-Петербург, посёлок Стрельна, Волхонское шоссе, 26	0101000020E610000061C1FD8007063E406A1327F73BEC4D40
81764	3	\N	\N	2	15298	\N	60.0988615854912	Город Санкт-Петербург, Курортный район, муниципальное образование город Сестрорецк, улица Володарского, дом 12		0101000020E6100000473B6EF8DDF83D4098689082A70C4E40
82119	3	\N	\N	2	5544	\N	59.889263999999997	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Волковский проспект, дом 106	Россия, Санкт-Петербург, Волковский проспект, 106	0101000020E61000003F73D6A71C5B3E404CC11A67D3F14D40
82118	3	\N	\N	2	5544	\N	59.900173000000002	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Волковский проспект, дом 4а		0101000020E6100000543882548A5D3E4001DF6DDE38F34D40
81986	3	\N	\N	2	15136	\N	59.906455774846698	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, Владимирская улица, дом 28		0101000020E6100000EFAEB321FFC43D40A9A10DC006F44D40
81804	3	\N	\N	2	1345	\N	59.838512000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, Витебский проспект, дом 85, корп. 2	Россия, Санкт-Петербург, Витебский проспект, 85	0101000020E61000000E83F92B645E3E40DBA6785C54EB4D40
81803	3	\N	\N	2	1345	\N	59.841251	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, Витебский проспект, дом 73, корп. 2	Россия, Санкт-Петербург, Витебский проспект, 73к1	0101000020E6100000CBDB114E0B5E3E40185DDE1CAEEB4D40
81802	3	\N	\N	2	1345	\N	59.847110000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, Витебский проспект, дом 57, корп. 2	Россия, Санкт-Петербург, Витебский проспект, 57	0101000020E6100000771211FE455C3E40AA0EB9196EEC4D40
81801	3	\N	\N	2	1345	\N	59.849851381856901	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Гагаринское, Витебский проспект, дом 49	Россия, Санкт-Петербург, Витебский проспект, 49к2	0101000020E6100000959A3DD00A5C3E4088BCE5EAC7EC4D40
81199	3	\N	\N	2	67092	\N	59.921109999999999	ул.Витебская, д.7, ГС(К)ОУ VIII вида № 231		0101000020E61000000C23BDA8DD473E406002B7EEE6F54D40
81834	3	\N	\N	2	1804	\N	59.811839999999997	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, улица Взлетная, дом 5, корп. 1	Россия, Санкт-Петербург, Взлётная улица, 5к1	0101000020E61000003C4CFBE6FE4A3E40D5CA845FEAE74D40
81619	3	\N	\N	2	7178	\N	59.936120000000003	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Малая Охта, Весенняя улица, дом 10	Россия, Санкт-Петербург, Весенняя улица, 10	0101000020E6100000E770ADF6B0673E40D690B8C7D2F74D40
81211	3	\N	\N	2	2291	\N	59.916117	Верейская ул., д.20, ГОУ СОШ № 306	Россия, Санкт-Петербург, Верейская улица, 20	0101000020E61000000E863AAC70533E40A227655243F54D40
81441	3	\N	\N	2	16673	\N	59.729751765421298	"Новая Ижора ул. Веревская д.31  УК ооо "" Новая Ижора"""	Россия, Санкт-Петербург, Колпино, Веревская улица	0101000020E6100000D2FE0758AB923E406518778368DD4D40
81921	3	\N	\N	2	3044	\N	59.955593	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Введенский, улица Введенская, дом 16		0101000020E6100000B72407EC6A4E3E40ADA415DF50FA4D40
81920	3	\N	\N	2	3044	\N	59.956971000000003	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Введенский, улица Введенская, дом 3	Россия, Санкт-Петербург, Введенская улица, 3	0101000020E6100000C3BAF1EEC84C3E40371C96067EFA4D40
81827	3	\N	\N	2	1111	\N	59.870632999999998	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, улица Варшавская, дом 40		0101000020E610000049BBD1C77C503E40C0E8F2E670EF4D40
81823	3	\N	\N	2	1111	\N	59.850048000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, улица Варшавская, дом 63	Россия, Санкт-Петербург, Варшавская улица, 63к1	0101000020E6100000C47B0E2C47503E40DE03745FCEEC4D40
81822	3	\N	\N	2	1111	\N	59.850048000000001	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Варшавская, дом 63	Россия, Санкт-Петербург, Варшавская улица, 63к1	0101000020E6100000C47B0E2C47503E40DE03745FCEEC4D40
81820	3	\N	\N	2	1111	\N	59.854585	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Варшавская, дом 51, корп. 2	Россия, Санкт-Петербург, Варшавская улица, 51	0101000020E61000005874EB353D503E407A53910A63ED4D40
81819	3	\N	\N	2	1111	\N	59.861407999999997	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Варшавская, дом 33	Россия, Санкт-Петербург, Варшавская улица, 33	0101000020E610000061FC34EECD4F3E40A2410A9E42EE4D40
81787	3	\N	\N	2	15306	\N	59.873522999999999	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Варшавская улица, дом 30		0101000020E6100000A3E9EC6470503E40E3A6069ACFEF4D40
82120	3	\N	\N	2	5561	\N	59.889611000000002	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Бухарестская улица, дом 5	Россия, Санкт-Петербург, Бухарестская улица, 5	0101000020E6100000C44142942F5C3E40B894F3C5DEF14D40
82142	3	\N	\N	2	13320	\N	59.863462961758202	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Купчино, Бухарестская улица, дом 33, корп. 6	Россия, Санкт-Петербург, Бухарестская улица, 33к6	0101000020E6100000FC1A498270613E402D27A1F485EE4D40
82172	3	\N	\N	2	5606	\N	59.831277	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Балканский, улица Будапештская, дом 93	Россия, Санкт-Петербург, Будапештская улица, 93	0101000020E61000009E5E29CB10673E406075E44867EA4D40
82159	3	\N	\N	2	5606	\N	59.839953999999999	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Будапештская, дом 79, корп. 2	Россия, Санкт-Петербург, Будапештская улица, 79к1	0101000020E610000068EA758BC0643E407B12D89C83EB4D40
82150	3	\N	\N	2	5606	\N	59.857824655344999	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Будапештская, дом 35, корп. 2	Россия, Санкт-Петербург, Будапештская улица, 35к2	0101000020E6100000757286E28E5F3E407958A835CDED4D40
82149	3	\N	\N	2	5606	\N	59.852193999999997	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, улица Будапештская, дом 64, корп. 2	Россия, Санкт-Петербург, Будапештская улица, 64к2	0101000020E6100000378DEDB5A0633E4078EC67B114ED4D40
82143	3	\N	\N	2	5606	\N	59.863564215195503	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Купчино, Будапештская улица, дом 30, корп. 2	Россия, Санкт-Петербург, Будапештская улица, 30к2	0101000020E6100000F9F5436CB0603E406000E14389EE4D40
82124	3	\N	\N	2	5606	\N	59.873367135098803	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Волковское, Будапештская улица, дом 8, корп. 3	Россия, Санкт-Петербург, Будапештская улица, 8к3	0101000020E6100000CB9D9960385F3E40EC33677DCAEF4D40
82144	3	\N	\N	2	13273	\N	59.859555658057701	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Купчино, Будапештская улица, дом 42, корп. 6	Россия, Санкт-Петербург, Будапештская улица, 42к6	0101000020E610000094DA8B683B623E40508A56EE05EE4D40
81475	3	\N	\N	2	5725	\N	59.986834999999999	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Пискаревка, Брюсовская улица, дом 10		0101000020E61000005DC47762D66B3E402AC6F99B50FE4D40
81222	3	\N	\N	2	15320	\N	59.912869000000001	Город Санкт-Петербург, Адмиралтейский район, муниципальное образование муниципальный округ Семеновский, Бронницкая улица, дом 34		0101000020E6100000971C774A07533E40204432E4D8F44D40
81683	3	\N	\N	2	7864	\N	59.849221	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Южно-Приморский, Брестский бульвар, дом 19, корп. 2	Россия, Санкт-Петербург, Брестский бульвар, 19к2	0101000020E6100000CB129D6516313E40C8091346B3EC4D40
81980	3	\N	\N	2	15308	\N	59.874903148912402	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Ботаническая улица, дом 68		0101000020E610000013B70A62A0D33D400E164ED2FCEF4D40
81974	3	\N	\N	2	15308	\N	59.868625228330302	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Петергоф, Ботаническая улица, дом 6		0101000020E610000066136058FEDC3D4077BE9F1A2FEF4D40
81218	3	\N	\N	2	67083	\N	59.924717999999999	ул.Бородинская, д.11, ГОУ Центр образования № 195		0101000020E6100000F52A323A20553E40E202D0285DF64D40
81924	3	\N	\N	2	16664	\N	59.965185671907903	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Кронверкское, Большой проспект, дом 73/36	Россия, Санкт-Петербург, Петроградский район, Большой проспект П.С.	0101000020E610000067B96C74CE4F3E404E4700378BFB4D40
81945	3	\N	\N	2	16854	\N	59.957853999999998	"Большой пр., 29/2, ГОУНПО Профессиональный лицей петербургской моды, отделение в Петроградском районе  тел. 235-74-52 "	Россия, Санкт-Петербург, Петроградский район, Большой проспект П.С., 29	0101000020E61000009015FC36C44C3E40E02BBAF59AFA4D40
81251	3	\N	\N	2	16854	\N	59.958345000000001	Большой пр., д. 31/14, Учреждение Российской академии наук Институт высокомолекулярных соединений РАН (ИВС РАН), 417-21-33	Россия, Санкт-Петербург, Петроградский район, Большой проспект П.С., 31	0101000020E6100000936FB6B9314D3E407FA4880CABFA4D40
81255	3	\N	\N	2	13367	\N	59.929506000000003	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, Большой проспект В.О, дом 88		0101000020E6100000603B18B14F403E40C8B7770DFAF64D40
81314	3	\N	\N	2	3689	\N	59.986033999999997	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, Большой Сампсониесвкий проспект, дом 86	Россия, Санкт-Петербург, Большой Сампсониевский проспект, 86	0101000020E61000009A25016A6A553E403D5FB35C36FE4D40
81311	3	\N	\N	2	3689	\N	59.986033999999997	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Сампсониевское, Большой Сампсониевский проспект, дом 86	Россия, Санкт-Петербург, Большой Сампсониевский проспект, 86	0101000020E61000009A25016A6A553E403D5FB35C36FE4D40
81611	3	\N	\N	2	7064	\N	59.948982448228499	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Большеохтинский проспект, дом 11, корп. 2	Россия, Санкт-Петербург, Большеохтинский проспект, 11к2	0101000020E610000063F19BC24A693E40103FFF3D78F94D40
81630	3	\N	\N	2	7279	\N	59.938198	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Белорусская, дом 10		0101000020E6100000EBFF1CE6CB7F3E4018963FDF16F84D40
81610	3	\N	\N	2	7064	\N	59.956831999999999	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Большая Охта, Большеохтинский проспект, дом 18	Россия, Санкт-Петербург, Большеохтинский проспект, 18	0101000020E61000002AE109BDFE683E4015E2917879FA4D40
81923	3	\N	\N	2	3079	\N	59.959547999999998	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Кронверкское, улица Большая Пушкарская, дом 32		0101000020E610000081423D7D044E3E409A780778D2FA4D40
81929	3	\N	\N	2	3177	\N	59.958250999999997	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Посадский, улица Большая Посадская, дом 5/7	Россия, Санкт-Петербург, Большая Посадская улица, 5	0101000020E6100000FD6662BA10533E40FD2D01F8A7FA4D40
82200	3	\N	\N	2	2312	\N	59.934730999999999	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ N78, улица Большая Морская, дом 18		0101000020E61000005FD1ADD7F4503E4058C7F143A5F74D40
81212	3	\N	\N	2	2312	\N	59.930602	ул.Большая Морская, д.61, УФПС Санкт-Петербурга и Ленинградской области – филиал ФГУП «Почта России»	Россия, Санкт-Петербург, Большая Морская улица, 61	0101000020E6100000BDC3EDD0B04C3E40CDCB61F71DF74D40
81214	3	\N	\N	2	13251	\N	59.933567651821001	ул.Большая Морская, д.33, Санкт-Петербургское государственное учреждение культуры «Центральная городская детская библиотека им.А.С.Пушкина»	Россия, Санкт-Петербург, Большая Морская улица, 33	0101000020E610000021E4BCFF8F4F3E40CB4BFE277FF74D40
81926	3	\N	\N	2	3140	\N	59.960656	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Кронверкское, улица Большая Монетная, дом 2/4		0101000020E6100000522635B401503E40645A9BC6F6FA4D40
81951	3	\N	\N	2	3448	\N	59.964340999999997	Город Санкт-Петербург, Петроградский район, муниципальное образование муниципальный округ Чкаловское, улица Большая Зеленина, дом 30		0101000020E6100000C4B3041901493E409198A0866FFB4D40
81317	3	\N	\N	2	3758	\N	59.998517	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Болотная улица, дом 6		0101000020E6100000D3687231065A3E4001C0B167CFFF4D40
81316	3	\N	\N	2	3758	\N	60.002561999999998	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, Болотная улица, дом 18		0101000020E610000088821953B05A3E402E1B9DF353004E40
82249	3	\N	\N	2	2194	\N	60.001837999999999	Богатырский пр. д.19 школа № 644	Россия, Санкт-Петербург, Богатырский проспект, 19	0101000020E6100000CF85915ED4423E40EDF1423A3C004E40
82042	3	\N	\N	2	2194	\N	60.001772796444101	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, проспект Богатырский, дом 7, корп. 4	Россия, Санкт-Петербург, Богатырский проспект, 7к4	0101000020E61000007DAEB6627F493E40068200193A004E40
82039	3	\N	\N	2	2194	\N	60.001837999999999	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Озеро Долгое, проспект Богатырский, дом 19	Россия, Санкт-Петербург, Богатырский проспект, 19	0101000020E6100000CF85915ED4423E40EDF1423A3C004E40
82005	3	\N	\N	2	2194	\N	60.005364311366698	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, проспект Богатырский, дом 50, корп. 2	Россия, Санкт-Петербург, Богатырский проспект	0101000020E6100000F722DA8EA9373E40B2497EC4AF004E40
82002	3	\N	\N	2	2194	\N	60.007767000000001	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ N65, проспект Богатырский, дом 55, корп. 3	Россия, Санкт-Петербург, Богатырский проспект, 55к3	0101000020E6100000CB4BFE277F373E40787E5182FE004E40
82001	3	\N	\N	2	2194	\N	60.008899999999997	Богатырский, дом 61, корп. 2  Лицей		0101000020E6100000917D9065C1343E409A779CA223014E40
81863	3	\N	\N	2	2194	\N	60.004526177908403	проспект Богатырский, дом 50 корп.2 школа № 655	Россия, Санкт-Петербург, Приморский район, район Северо-Приморская часть	0101000020E6100000B1DEA815A6373E40A8FDD64E94004E40
81790	3	\N	\N	2	1099	\N	59.876409000000002	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Благодатная улица, дом 32	Россия, Санкт-Петербург, Благодатная улица, 32	0101000020E6100000F6B52E3542533E40C5758C2B2EF04D40
81786	3	\N	\N	2	1099	\N	59.876165	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Благодатная улица, дом 20		0101000020E6100000198D7C5EF1503E402E73BA2C26F04D40
81815	3	\N	\N	2	13313	\N	59.873925	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Новоизмайловское, улица Благодатная, дом 11		0101000020E61000008179C8940F4D3E4012143FC6DCEF4D40
81789	3	\N	\N	2	13295	\N	59.876367999999999	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Московская застава, Благодатная улица, дом 36		0101000020E61000002C4487C091543E4066A19DD32CF04D40
82103	3	\N	\N	2	15301	\N	59.6864147862536	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Павловск, Березовая улица, дом 13		0101000020E610000041102043C76E3E40EE3D5C72DCD74D40
81279	3	\N	\N	2	13255	\N	59.946266000000001	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ округ Морской, улица Беринга, дом 38		0101000020E6100000E964A9F57E3B3E408BA8893E1FF94D40
55008	7	63	1391	15800	54339	\N	54.281373000000002	с.Лямбирь, Ленина, 4		0101000020E61000003A799109F88F46401C7DCC0704244B40
81632	3	\N	\N	2	13259	\N	59.943390484722102	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Пороховые, улица Белорусская, дом 26, корп. 2		0101000020E61000002DE8BD3104803E40CDAFE600C1F84D40
82146	3	\N	\N	2	5795	\N	59.862426634858799	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Купчино, Белградская улица, дом 20, корп. 2	Россия, Санкт-Петербург, Белградская улица, 20к2	0101000020E6100000075E2D77665E3E40FC17080264EE4D40
82145	3	\N	\N	2	5795	\N	59.865017999999999	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Купчино, Белградская улица, дом 14, корп. 2	Россия, Санкт-Петербург, Белградская улица, 14к2	0101000020E6100000774D486B0C5E3E40C539EAE8B8EE4D40
82140	3	\N	\N	2	5795	\N	59.869529999999997	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Купчино, Белградская улица, дом 8, корп. 2	Россия, Санкт-Петербург, Белградская улица, 8к1	0101000020E61000006A1327F73B5C3E40087250C24CEF4D40
81486	3	\N	\N	2	13333	\N	59.898643433082199	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Нарвский округ, улица Балтийская, дом 35	Россия, Санкт-Петербург, Балтийская улица, 35	0101000020E610000020D4450A65493E40C1E3DBBB06F34D40
82051	3	\N	\N	2	4714	\N	60.013995999999999	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, улица Байконурская, дом 25	Россия, Санкт-Петербург, Байконурская улица, 25	0101000020E6100000A5F5B704E0473E402D23F59ECA014E40
82040	3	\N	\N	2	4613	\N	59.9979993576138	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, улица Аэродромная, дом 11, корп.2	Россия, Санкт-Петербург, Аэродромная улица, 11к2	0101000020E610000009C6C1A5634A3E406938656EBEFF4D40
82041	3	\N	\N	2	13325	\N	59.998262671903497	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Комендантский аэродром, улица Аэродромная, дом 11, корп. 2		0101000020E6100000255AF2785A4A3E4047E7FC14C7FF4D40
81967	3	\N	\N	2	13325	\N	59.998189000000004	ул. Аэродромная  д.11 корп.2 Гимназия № 66	Россия, Санкт-Петербург, Аэродромная улица, 11к2	0101000020E6100000074147AB5A4A3E400D1D3BA8C4FF4D40
81401	3	\N	\N	2	16576	\N	60.049742999999999	ул. Афанасьева д.6 школа № 457		0101000020E61000000A664CC11A533E403B1A87FA5D064E40
81383	3	\N	\N	2	16576	\N	60.047662849544501	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Асафьева, дом 7, корп. 2		0101000020E61000001B683EE76E533E40581D39D219064E40
82098	3	\N	\N	2	15146	\N	59.7074147616052	Город Санкт-Петербург, Пушкинский район, муниципальное образование город Пушкин, Артиллерийская улица, дом 7/20		0101000020E6100000533F6F2A52693E4094D920938CDA4D40
81457	3	\N	\N	2	5515	\N	59.953316999999998	Арсенальная наб., д.13/1, фойе Концертного зала, тел.542-23-23		0101000020E61000000F289B72855B3E4044DC9C4A06FA4D40
81467	3	\N	\N	2	13326	\N	59.972076626350798	Город Санкт-Петербург, Калининский район, муниципальное образование муниципальный округ Финляндский округ, Антоновская улица, дом 16		0101000020E61000004A97FE25A9683E40CE18E6046DFC4D40
81748	3	\N	\N	2	15294	\N	59.996134266485498	Город Санкт-Петербург, Кронштадтский район, муниципальное образование город Кронштадт, улица Андреевская, дом 5		0101000020E61000003AAFB14B54C33D408237A45181FF4D40
82153	3	\N	\N	2	5901	\N	59.850197000000001	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, переулок Альпийский, дом 5, корп. 2	Россия, Санкт-Петербург, Альпийский переулок, 5к2	0101000020E6100000745C8DEC4A5F3E4023145B41D3EC4D40
82151	3	\N	\N	2	5901	\N	59.8506686491802	Город Санкт-Петербург, Фрунзенский район, муниципальное образование муниципальный округ Георгиевский, переулок Альпийский, дом 19, корп. 2	Россия, Санкт-Петербург, Альпийский переулок, 19к2	0101000020E6100000D313967840613E404B5CC7B8E2EC4D40
81806	3	\N	\N	2	1432	\N	59.848832000000002	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Звездное, Алтайская улица, дом 15		0101000020E6100000F4DE180280533E402EE6E786A6EC4D40
81991	3	\N	\N	2	16546	\N	59.911137125783803	Город Санкт-Петербург, Петродворцовый район, муниципальное образование город Ломоносов, Александровская улица, дом 6/9		0101000020E61000007FFACF9A1FC33D4078962023A0F44D40
81216	3	\N	\N	2	2373	\N	59.938896999999997	Адмиралтейская наб., д.4,   ГОУ СОШ № 225		0101000020E61000000DFCA886FD4E3E4000A8E2C62DF84D40
81510	3	\N	\N	2	6093	\N	59.866526999999998	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Автовская, дом 5	Россия, Санкт-Петербург, Автовская улица, 5	0101000020E61000003C139A2496443E40ED0C535BEAEE4D40
81706	3	\N	\N	2	7239	\N	59.828066	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Урицк, улица Авангардная, дом 43	Россия, Санкт-Петербург, Авангардная улица, 43	0101000020E6100000B0FF3A376D2E3E40FB761211FEE94D40
81703	3	\N	\N	2	7239	\N	59.836097000000002	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Урицк, улица Авангардная, дом 21	Россия, Санкт-Петербург, Авангардная улица, 21	0101000020E6100000029A081B9E2E3E4051A4FB3905EB4D40
12715	7	66	\N	61	61770	\N	56.101759999999999	Чувашская Республика - Чувашия, Ибресинский район, Андреевское сельское поселение, Хузангая, 1а		0101000020E6100000F59F353FFEA247403E05C078060D4C40
82232	3	\N	\N	2	6725	\N	59.936030000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица 9-я Советская, дом 31	Россия, Санкт-Петербург, 9-я Советская улица, 31	0101000020E610000070B1A206D3603E409609BFD4CFF74D40
82234	3	\N	\N	2	6758	\N	59.933731000000002	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица 8-я Советская, дом 58		0101000020E6100000B01EF7ADD6613E407521567F84F74D40
81227	3	\N	\N	2	2540	\N	59.914555999999997	ул.8-я Красноармейская, д.3, ГОУ гимназия № 272		0101000020E6100000419E5DBEF54D3E40272EC72B10F54D40
81248	3	\N	\N	2	15311	\N	59.943082324832098	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Васильевский, 7-я линия В.О, дом 52/31		0101000020E61000009BE5B2D139473E401FB935E9B6F84D40
81258	3	\N	\N	2	15966	\N	59.943194857352097	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, 7-я линия В.О, дом 52/31	Россия, Санкт-Петербург, Василеостровский район, 7-я линия В.О., 52	0101000020E6100000417DCB9C2E473E4018601F9DBAF84D40
81231	3	\N	\N	2	67071	\N	59.911361999999997	7-я Красноармейская ул., д.12-14, ФГБОУ ВПО «Петербургский государственный университет путей сообщения», общежитие		0101000020E6100000F73DEAAF57503E4098689082A7F44D40
82235	3	\N	\N	2	6760	\N	59.935817999999998	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица 6-я Советская, дом 3		0101000020E6100000B537F8C2645E3E400A815CE2C8F74D40
81833	3	\N	\N	2	1776	\N	59.838023	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, 5-й Предпортовый проезд, дом 6 корп. 1	Россия, Санкт-Петербург, 5-й Предпортовый проезд, 6к1	0101000020E6100000BE67244223503E40DD25715644EB4D40
81832	3	\N	\N	2	1776	\N	59.838023	Город Санкт-Петербург, Московский район, муниципальное образование муниципальный округ Пулковский меридиан, 5-й Предпортовый проезд, дом 6, корп. 1	Россия, Санкт-Петербург, 5-й Предпортовый проезд, 6к1	0101000020E6100000BE67244223503E40DD25715644EB4D40
82065	3	\N	\N	2	4873	\N	60.016627	Город Санкт-Петербург, Приморский район, муниципальное образование муниципальный округ Коломяги, 3-я линия 1-й половины, дом 10А	Россия, Санкт-Петербург, 3-я линия 1-й половины, 10а	0101000020E6100000B6F292FFC94B3E40849D62D520024E40
81246	3	\N	\N	2	13307	\N	59.942278185558997	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, 2-я линия В.О, дом 23	Россия, Санкт-Петербург, Василеостровский район, 2-я линия В.О., 23	0101000020E61000004F24986A66493E40C2DEC4909CF84D40
82237	3	\N	\N	2	6781	\N	59.930083000000003	Город Санкт-Петербург, Центральный район, муниципальное образование муниципальный округ Смольнинское, улица 2-я Советская, дом 27/2	Россия, Санкт-Петербург, 2-я Советская улица, 27	0101000020E6100000E2AE5E45465F3E4065C8B1F50CF74D40
81229	3	\N	\N	2	77293	\N	59.915031193924897	2-я Красноармейская ул., д.4, ФГБОУ ВПО «Санкт-Петербургский государственный архитектурно-строительный университет»	Россия, Санкт-Петербург, 2-я Красноармейская улица, 4	0101000020E61000006495D233BD503E40C0E95DBC1FF54D40
81694	3	\N	\N	2	7962	\N	59.838493999999997	Город Санкт-Петербург, Красносельский район, муниципальное образование муниципальный округ Сосновая Поляна, улица 2-ая Комсомольская, дом 23	Россия, Санкт-Петербург, 2-я Комсомольская улица, 23к1	0101000020E6100000B519A721AA243E4034F279C553EB4D40
81907	3	\N	\N	2	2871	\N	59.854917524337203	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Обуховский, 2-й Рабфаковский переулок, дом 1, корп. 4	Россия, Санкт-Петербург, 2-й Рабфаковский переулок, 1к4	0101000020E61000002FBFD364C6773E408061F9F36DED4D40
81325	3	\N	\N	2	3895	\N	59.998432000000001	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Светлановское, 2-й Муринский проспект, дом 43	Россия, Санкт-Петербург, 2-й Муринский проспект, 43	0101000020E61000000874266DAA5A3E40D3A3A99ECCFF4D40
81261	3	\N	\N	2	13309	\N	59.939928999999999	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Васильевский, 17-я линия В.О, дом 34	Россия, Санкт-Петербург, Василеостровский район, 17-я линия В.О., 34	0101000020E6100000CF4E0647C9433E40EFC7ED974FF84D40
81263	3	\N	\N	2	13310	\N	59.941619000000003	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ Васильевский, 16-я линия В.О, дом 55	Россия, Санкт-Петербург, Василеостровский район, 16-я линия В.О., 55	0101000020E6100000A35A441493433E406825ADF886F84D40
81253	3	\N	\N	2	13314	\N	59.9391306596767	Город Санкт-Петербург, Василеостровский район, муниципальное образование муниципальный округ N7, 13-я линия В.О, дом 28	Россия, Санкт-Петербург, Василеостровский район, 13-я линия В.О.	0101000020E6100000F4C0C760C5453E4074D4D17135F84D40
81228	3	\N	\N	2	15912	\N	59.912934794635397	ул.10-я Красноармейская, д.5а, ГОУ СОШ № 286		0101000020E6100000522B4CDF6B4C3E40D72FD80DDBF44D40
81656	3	\N	\N	2	16208	\N	59.9640989857797	Город Санкт-Петербург, Красногвардейский район, муниципальное образование муниципальный округ Ржевка, 1-я Жерновская улица, дом 8	Россия, Санкт-Петербург, 1-я Жерновская улица, 8к1	0101000020E6100000A2B60DA3207C3E409B8D959867FB4D40
55006	7	63	1391	15708	54612	\N	54.335431999999997	с.Кривозерье, Ленина, 8 А		0101000020E6100000BDFBE3BD6AA5464014048F6FEF2A4B40
81575	3	\N	\N	2	13359	\N	59.745279114573499	Город Санкт-Петербург, Колпинский район, муниципальное образование город Колпино, улица Танкистов, дом 26	Россия, Санкт-Петербург, Колпино, улица Танкистов, 26	0101000020E610000041446ADAC5903E40A2B2614D65DF4D40
81502	3	\N	\N	2	13332	\N	59.874259675248602	Город Санкт-Петербург, Кировский район, муниципальное образование муниципальный округ Автово, улица Новостроек, дом 26	Россия, Санкт-Петербург, Кировский район, улица Новостроек, 26	0101000020E61000005116BEBED6453E40B9196EC0E7EF4D40
81866	3	\N	\N	2	13327	\N	59.914970839281601	Город Санкт-Петербург, Невский район, муниципальное образование муниципальный округ Невский округ, улица Коллантай, дом 19, корп.5	Россия, Санкт-Петербург, улица Коллонтай, 19к5	0101000020E6100000E0BA624678773E40EBE40CC51DF54D40
81391	3	\N	\N	2	13361	\N	60.0645817049584	Город Санкт-Петербург, Выборгский район, муниципальное образование муниципальный округ Шувалово-Озерки, улица Жени Егоровой, дом 10,  корп. 2	Россия, Санкт-Петербург, улица Жени Егоровой, 10к2	0101000020E61000004DBB9866BA4F3E4084F4143944084E40
12877	7	66	\N	58046	62936	\N	56.110937	п.имени Кирова, Центральная, 23		0101000020E6100000685BCD3AE39347404B75012F330E4C40
13469	7	66	\N	57863	61613	\N	55.944077	город Ядрин, Чапаева, 20-А		0101000020E6100000B3D2A41474194740F1F3DF83D7F84B40
13470	7	66	\N	57863	61758	\N	55.944077	город Ядрин, Ленина, 39		0101000020E6100000B3D2A41474194740F1F3DF83D7F84B40
13472	7	66	\N	57863	61611	\N	55.944077	город Ядрин, Карла Маркса, 64		0101000020E6100000B3D2A41474194740F1F3DF83D7F84B40
13471	7	66	\N	57863	61610	\N	55.943739779844798	город Ядрин, 50 лет Октября, 71-г	Россия, республика Чувашская, Ядринский район, Ядрин	0101000020E61000003C2EAA4544194740A9F6E978CCF84B40
13461	7	66	\N	2126	61641	\N	55.495787718593597	Чувашская Республика - Чувашия, город Шумерля, Щербакова, 58	Россия, республика Чувашская, Шумерля	0101000020E61000008597E0D407344740E7DF2EFB75BF4B40
13464	7	66	\N	2126	61576	\N	55.494813198812103	Чувашская Республика - Чувашия, город Шумерля, Черняховского, 27	Россия, республика Чувашская, Шумерля	0101000020E6100000FAD346753A3447405D514A0856BF4B40
13214	7	66	\N	2126	61596	\N	55.495300461729997	Чувашская Республика - Чувашия, город Шумерля, Францева, 1	Россия, республика Чувашская, Шумерля	0101000020E61000009624CFF57D344740BADA8AFD65BF4B40
13453	7	66	\N	2126	61606	\N	55.495008104705803	Чувашская Республика - Чувашия, город Шумерля, Сурская, 7	Россия, республика Чувашская, Шумерля	0101000020E6100000354580D3BB34474012A1116C5CBF4B40
13462	7	66	\N	2126	61571	\N	55.494520838155303	Чувашская Республика - Чувашия, город Шумерля, Советская, 18	Россия, республика Чувашская, Шумерля	0101000020E6100000BD38F1D58E344740B517D1764CBF4B40
13467	7	66	\N	2126	61827	\N	55.485846000000002	Чувашская Республика - Чувашия, город Шумерля, Радищева, 32		0101000020E61000000C0742B2803547403B72A43330BE4B40
13457	7	66	\N	2126	61605	\N	55.4952030096307	Чувашская Республика - Чувашия, город Шумерля, Пушкина, 21	Россия, республика Чувашская, Шумерля	0101000020E6100000C3D8429083344740C7F0D8CF62BF4B40
13454	7	66	\N	2126	61607	\N	55.495397913586999	Чувашская Республика - Чувашия, город Шумерля, Некрасова, 62	Россия, республика Чувашская, Шумерля	0101000020E6100000E44C13B69F3447407D40A03369BF4B40
13456	7	66	\N	2126	61595	\N	55.4952030096307	Чувашская Республика - Чувашия, город Шумерля, МОПРа, 2	Россия, республика Чувашская, Шумерля	0101000020E6100000E71C3C139A344740C7F0D8CF62BF4B40
13460	7	66	\N	2126	61608	\N	55.4952030096307	Чувашская Республика - Чувашия, город Шумерля, М.Жукова, 7	Россия, республика Чувашская, Шумерля	0101000020E6100000C3D8429083344740C7F0D8CF62BF4B40
13459	7	66	\N	2126	61575	\N	55.494618291949799	Чувашская Республика - Чувашия, город Шумерля, Ленина, 4Б	Россия, республика Чувашская, Шумерля	0101000020E61000000B613596B0344740A80183A44FBF4B40
13458	7	66	\N	2126	61575	\N	55.494813198812103	Чувашская Республика - Чувашия, город Шумерля, Ленина, 17	Россия, республика Чувашская, Шумерля	0101000020E61000004BCCB392563447405D514A0856BF4B40
13466	7	66	\N	2126	61998	\N	55.485846000000002	Чувашская Республика - Чувашия, город Шумерля, Котовского, 58		0101000020E61000000C0742B2803547403B72A43330BE4B40
13465	7	66	\N	2126	61598	\N	55.485846000000002	Чувашская Республика - Чувашия, город Шумерля, Кирова, 64А		0101000020E61000000C0742B2803547403B72A43330BE4B40
13463	7	66	\N	2126	61598	\N	55.496372418838497	Чувашская Республика - Чувашия, город Шумерля, Кирова, 33	Россия, республика Чувашская, Шумерля	0101000020E6100000C0081A33893447403753211E89BF4B40
13455	7	66	\N	2126	61569	\N	55.4932534409255	Чувашская Республика - Чувашия, город Шумерля, Горького, 5	Россия, республика Чувашская, Шумерля	0101000020E6100000C0081A3389344740B3D30FEA22BF4B40
13468	7	66	\N	2126	61909	\N	55.485846000000002	Чувашская Республика - Чувашия, город Шумерля, Белинского, 1Б		0101000020E61000000C0742B2803547403B72A43330BE4B40
13219	7	66	\N	61	\N	\N	56.167169366271402	"Чувашская Республика - Чувашия, город Чебоксары, Московский район, ОАО ""Санаторий ""Чувашия"""	Россия, республика Чувашская, Чебоксары городской округ, поселок санаторий Чувашская	0101000020E6100000F111312592A84740D8F335CB65154C40
13218	7	66	\N	61	\N	\N	56.291737974191001	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пос.Северный, клуб		0101000020E6100000E15D2EE23B9947400F80B8AB57254C40
13123	7	66	\N	61	\N	\N	56.127150999999998	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, пос.Восточный, д.5	Россия, республика Чувашская, Чебоксары, поселок Восточный, 5	0101000020E610000087A8C29FE1AB4740AC53E57B46104C40
13542	7	66	\N	61	2825	\N	56.111287887962703	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение с.Янтиково, Школьная, 1	Россия, республика Чувашская, Чебоксары, улица Школьная, 2	0101000020E610000030F65E7CD1964740F83768AF3E0E4C40
13158	7	66	\N	61	61775	\N	56.107061999999999	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Хевешская, 17	Россия, республика Чувашская, Чебоксары, улица Хевешская, 17а	0101000020E61000007FF6234564A247407A522635B40D4C40
13173	7	66	\N	61	15761	\N	56.069670000000002	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Совхозная, 9	Россия, республика Чувашская, Чебоксары, поселок Новые Лапсары, улица Совхозная, 9а	0101000020E61000003067B62BF49B474094C151F2EA084C40
13174	7	66	\N	61	61818	\N	56.070680627241302	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Совхозная, 3	Россия, республика Чувашская, Чебоксары, поселок Новые Лапсары, улица Совхозная, 3	0101000020E610000078D32D3BC49B47406BB933130C094C40
13113	7	66	\N	61	61784	\N	56.131475999999999	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Патриса Лумумбы, д.17	Россия, республика Чувашская, Чебоксары, улица Патриса Лумумбы, 17	0101000020E61000003CBEBD6BD0A34740BD1AA034D4104C40
13515	7	66	\N	61	2985	\N	56.139023918110297	Чувашская Республика - Чувашия, Яльчикский район, Большеяльчикское сельское поселение с.Большие Яльчики, ул.Кооперативная, д.13	Россия, республика Чувашская, Чебоксары, улица Кооперативная, 19	0101000020E610000065DEAAEB509F4740F7ADD689CB114C40
12654	7	66	\N	61	2007	\N	56.145108	Чувашская Республика - Чувашия, Ибресинский район, Буинское сельское поселение, Калинина, 28	Россия, республика Чувашская, Чебоксары, улица Калинина, 26	0101000020E61000007DEA58A5F4A04740A93121E692124C40
13221	7	66	\N	61	655	\N	56.125495000000001	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Гражданская, д.50	Россия, республика Чувашская, Чебоксары, улица Гражданская, 50	0101000020E61000009F20B1DD3D9A4740E0675C3810104C40
13132	7	66	\N	61	7702	\N	56.100856	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, пр.Тракторостроителей, д.38	Россия, республика Чувашская, Чебоксары, проспект Тракторостроителей, 38	0101000020E6100000EF38454772A747407DCD72D9E80C4C40
13156	7	66	\N	61	2858	\N	56.110008000000001	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пр.Мира, 88а	Россия, республика Чувашская, Чебоксары, проспект Мира, 88а	0101000020E6100000A94A5B5CE3A147403126FDBD140E4C40
13120	7	66	\N	61	2858	\N	56.121130000000001	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, пр.Мира, д.40	Россия, республика Чувашская, Чебоксары, проспект Мира, 40	0101000020E61000009ACDE33098A3474041481630810F4C40
13119	7	66	\N	61	2858	\N	56.123282000000003	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, пр.Мира, д.1	Россия, республика Чувашская, Чебоксары, проспект Мира, 1	0101000020E61000006CB587BD50A44740BE175FB4C70F4C40
13116	7	66	\N	61	2858	\N	56.128695999999998	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, пр.Мира, д.16	Россия, республика Чувашская, Чебоксары, проспект Мира, 16	0101000020E61000006BD26D895CA4474021904B1C79104C40
13190	7	66	\N	61	59234	\N	56.1480502879282	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пр.М.Горького, д.5	Россия, республика Чувашская, Чебоксары, проспект Максима Горького, 5	0101000020E61000000BD462F0309947401E166A4DF3124C40
13189	7	66	\N	61	59234	\N	56.149656999999998	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пр.М.Горького, д.24	Россия, республика Чувашская, Чебоксары, проспект Максима Горького, 24	0101000020E6100000A6B6D4415E974740094FE8F527134C40
13154	7	66	\N	61	3045	\N	56.116371999999998	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пр.Ленина, 55а	Россия, республика Чувашская, Чебоксары, проспект Ленина, 55а	0101000020E6100000A0F99CBB5DA14740C6151747E50E4C40
13147	7	66	\N	61	3045	\N	56.129322999999999	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пр.Ленина, 9	Россия, республика Чувашская, Чебоксары, проспект Ленина, 9	0101000020E6100000CE548847E29F474070CFF3A78D104C40
13133	7	66	\N	61	3045	\N	56.114409999999999	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пр.Ленина, 61	Россия, республика Чувашская, Чебоксары, проспект Ленина, 61	0101000020E6100000D5AE09698DA14740ED2AA4FCA40E4C40
12734	7	66	\N	61	3045	\N	56.130240999999998	Чувашская Республика - Чувашия, Ибресинский район, Ширтанское сельское поселение, Ленина, 2а	Россия, республика Чувашская, Чебоксары, проспект Ленина, 2а	0101000020E610000058E542E55F9F474096CCB1BCAB104C40
12730	7	66	\N	61	3045	\N	56.128270000000001	Чувашская Республика - Чувашия, Ибресинский район, Хормалинское сельское поселение, Ленина, 13	Россия, республика Чувашская, Чебоксары, проспект Ленина, 13	0101000020E610000040A4DFBE0EA047406A87BF266B104C40
12726	7	66	\N	61	3045	\N	56.129990999999997	Чувашская Республика - Чувашия, Ибресинский район, Новочурашевское сельское поселение, Ленина, 7	Россия, республика Чувашская, Чебоксары, проспект Ленина, 7	0101000020E61000009BA9108FC49F47401DE38A8BA3104C40
12725	7	66	\N	61	3045	\N	56.123703999999996	Чувашская Республика - Чувашия, Ибресинский район, Новочурашевское сельское поселение, Ленина, 30	Россия, республика Чувашская, Чебоксары, проспект Ленина, 30	0101000020E61000007E54C37E4FA0474033315D88D50F4C40
13137	7	66	\N	61	61793	\N	56.085358999999997	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Магницкого, д.7		0101000020E61000008369183E22A44740AAB5300BED0A4C40
13164	7	66	\N	61	8024	\N	56.086951999999997	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пр.И.Яковлева, 20	Россия, республика Чувашская, Чебоксары, проспект Ивана Яковлева, 20	0101000020E6100000C287122D79A2474030293E3E210B4C40
13162	7	66	\N	61	7982	\N	56.094565000000003	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пр.9-ой Пятилетки, 4б	Россия, республика Чувашская, Чебоксары, проспект 9-й Пятилетки, 4б	0101000020E61000001CD3139678A24740522CB7B41A0C4C40
13160	7	66	\N	61	7982	\N	56.097518000000001	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пр.9-ой Пятилетки, 11	Россия, республика Чувашская, Чебоксары, проспект 9-й Пятилетки, 11	0101000020E6100000C76471FF91A34740BB6246787B0C4C40
13155	7	66	\N	61	7939	\N	56.122985999999997	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, проезд Школьный, 3	Россия, республика Чувашская, Чебоксары, проезд Школьный, 3	0101000020E6100000C6C210397DA14740D4EE5701BE0F4C40
13124	7	66	\N	61	7623	\N	56.137214	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, пр.Соляное, д.1	Россия, республика Чувашская, Чебоксары, проезд Соляное, 1	0101000020E61000009FE8BAF083A74740D446753A90114C40
13198	7	66	\N	61	313	\N	56.108611425988499	Чувашская Республика - Чувашия, город Чебоксары, Московский район, площадь Победы, д.3	Россия, республика Чувашская, Чебоксары, улица Коллективная	0101000020E610000005A6D3BA0D964740317E1AF7E60D4C40
13172	7	66	\N	61	8100	\N	56.113380999999997	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, пер. Ягодный, 2	Россия, республика Чувашская, Чебоксары, переулок Ягодный, 2	0101000020E61000004FB2D5E5949C47406F7EC344830E4C40
13200	7	66	\N	61	59223	\N	56.112541999999998	Чувашская Республика - Чувашия, город Чебоксары, Московский район, бульвар А.Миттова, д.23	Россия, республика Чувашская, Чебоксары, бульвар Анатолия Миттова, 23	0101000020E61000004C8A8F4FC898474095B6B8C6670E4C40
13199	7	66	\N	61	59223	\N	56.109080262931997	Чувашская Республика - Чувашия, город Чебоксары, Московский район, бульвар А.Миттова, д.47	Россия, республика Чувашская, Чебоксары, бульвар Анатолия Миттова, 47	0101000020E61000003DF20703CF974740E7525C55F60D4C40
13193	7	66	\N	61	61779	\N	56.117877999999997	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Энтузиастов, д.36/9		0101000020E61000003080F0A1449747407D7555A0160F4C40
13192	7	66	\N	61	61779	\N	56.121918000000001	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Энтузиастов, д.26		0101000020E610000058E36C3A0298474099654F029B0F4C40
13191	7	66	\N	61	61779	\N	56.124561999999997	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Энтузиастов, д.20		0101000020E61000004D840D4FAF9847408429CAA5F10F4C40
13148	7	66	\N	61	61800	\N	56.12697	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Энгельса, 10		0101000020E61000009835B1C057A047405CC98E8D40104C40
13188	7	66	\N	61	61797	\N	56.145434000000002	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Эльгера, д.22		0101000020E610000069C6A2E9EC964740FDDCD0949D124C40
13171	7	66	\N	61	61797	\N	56.145519999999998	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Эльгера, д.24		0101000020E610000058207A5226974740FB743C66A0124C40
13157	7	66	\N	61	7596	\N	56.109988000000001	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, Эгерский бульвар, 5а	Россия, республика Чувашская, Чебоксары, Эгерский бульвар, 5а	0101000020E61000004DBED9E6C6A24740EA793716140E4C40
13122	7	66	\N	61	7596	\N	56.096428000000003	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, Эгерский б-р, д.36	Россия, республика Чувашская, Чебоксары, Эгерский бульвар, 36	0101000020E610000080D250A390A447409835B1C0570C4C40
13159	7	66	\N	61	61792	\N	56.100791000000001	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Шумилова, 8		0101000020E610000018B5FB5580A34740965D30B8E60C4C40
13125	7	66	\N	61	61792	\N	56.104365999999999	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Шумилова, д.33		0101000020E61000000264E8D841A547403C6876DD5B0D4C40
13196	7	66	\N	61	61763	\N	56.113978000000003	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Чернышевского, д.4		0101000020E6100000E560360186974740543BC3D4960E4C40
13194	7	66	\N	61	61763	\N	56.117908	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Чернышевского, д.16		0101000020E6100000F4893C49BA964740E8F7FD9B170F4C40
13149	7	66	\N	61	61789	\N	56.128991999999997	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Чапаева, 41		0101000020E61000009FAF592E1BA147400AB952CF82104C40
13178	7	66	\N	61	61956	\N	56.135402999999997	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Чандровская, д.73		0101000020E61000000395F1EF339E4740E063B0E254114C40
13217	7	66	\N	61	59372	\N	56.175117937495898	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пос.Октябрьский, ул.Центральная, д.6	Россия	0101000020E6100000AF95D05D12A54740707841446A164C40
13167	7	66	\N	61	61770	\N	56.092858	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Хузангая, 23		0101000020E6100000641EF98381A3474003965CC5E20B4C40
13163	7	66	\N	61	61770	\N	56.093305000000001	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Хузангая, 18		0101000020E610000000AB23473AA34740D2C6116BF10B4C40
13161	7	66	\N	61	61770	\N	56.098602	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Хузангая, 8		0101000020E6100000D9D138D4EFA24740FCA886FD9E0C4C40
13206	7	66	\N	61	61781	\N	56.140879866472901	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Урукова, д.11 А	Россия, республика Чувашская, Чебоксары, улица Урукова, 11а	0101000020E610000047E9D2BF249B47408B54185B08124C40
13180	7	66	\N	61	9	\N	56.132429000000002	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Университетская, д.38	Россия, республика Чувашская, Чебоксары, Университетская улица, 38	0101000020E6100000E21E4B1FBA9447406005F86EF3104C40
13203	7	66	\N	61	59251	\N	56.146534109119003	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Т.Кривова, д.8/1	Россия, республика Чувашская, Чебоксары, улица Тимофея Кривова, 8к1	0101000020E61000001C5DA5BBEB98474044E048A0C1124C40
13202	7	66	\N	61	59251	\N	56.145285803999798	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Т.Кривова, д.13 А	Россия, республика Чувашская, Чебоксары, улица Тимофея Кривова, 13а	0101000020E6100000ED0DBE309998474088484DBB98124C40
13201	7	66	\N	61	59251	\N	56.1448064604865	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Т.Кривова, д.15 А	Россия, республика Чувашская, Чебоксары, улица Тимофея Кривова, 15а	0101000020E6100000BF7D1D3867984740DE21C50089124C40
12947	7	66	\N	61	62932	\N	56.112146000000003	Чувашская Республика - Чувашия, город Чебоксары, ул.Строителей, 12		0101000020E6100000444FCAA4869E47404930D5CC5A0E4C40
13208	7	66	\N	61	59296	\N	56.144295572144699	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.С.Михайлова, д.3	Россия, республика Чувашская, Чебоксары, улица Спиридона Михайлова, 1	0101000020E6100000064A0A2C809B4740C878944A78124C40
13197	7	66	\N	61	61798	\N	56.110747327585301	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Социалистическая, д.17 Б	Россия, республика Чувашская, Чебоксары, Социалистическая улица, 17а	0101000020E6100000FEB7921D1B974740A8902BF52C0E4C40
13215	7	66	\N	61	61866	\N	56.135402999999997	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пос.Сосновка, ул.Сосновская, д.57		0101000020E61000000395F1EF339E4740E063B0E254114C40
12733	7	66	\N	61	2957	\N	56.142404999999997	Чувашская Республика - Чувашия, Ибресинский район, Чувашско-Тимяшское сельское поселение, Советская, 53	Россия, республика Чувашская, Чебоксары, Советская набережная	0101000020E6100000A9F57EA31D9F4740B8E4B8533A124C40
13141	7	66	\N	61	61887	\N	56.081770625915603	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, пл.Скворцова, д.3	Россия, республика Чувашская, Чебоксары, площадь Скворцова	0101000020E61000009C31CC09DAA847407061DD78770A4C40
13134	7	66	\N	61	61783	\N	56.077351999999998	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Сапожникова, д.15		0101000020E61000006ADC9BDF30A34740DD239BABE6094C40
13140	7	66	\N	61	61343	\N	56.107925000000002	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Розы Люксембург, д.8	Россия, республика Чувашская, Чебоксары, улица Гастелло, 9	0101000020E61000000CCA349A5CA84740DDB5847CD00D4C40
13216	7	66	\N	61	59414	\N	56.199025511139602	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пос.Первомайский, ул.Родниковая	Россия	0101000020E6100000A79201A08A994740E08618AF79194C40
13136	7	66	\N	61	61411	\N	56.107925000000002	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Рихарда Зорге, д.9	Россия, республика Чувашская, Чебоксары, улица Гастелло, 9	0101000020E61000000CCA349A5CA84740DDB5847CD00D4C40
13115	7	66	\N	61	61399	\N	56.131019630839297	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Патриса Лумумбы, д.8	Россия, республика Чувашская, Чебоксары, улица Патриса Лумумбы, 8	0101000020E61000009485AFAF75A347409B8F6B43C5104C40
13114	7	66	\N	61	61399	\N	56.107925000000002	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Патриса Лумумбы, д.10а	Россия, республика Чувашская, Чебоксары, улица Гастелло, 9	0101000020E61000000CCA349A5CA84740DDB5847CD00D4C40
13151	7	66	\N	61	61796	\N	56.125695999999998	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Ильбекова, 6		0101000020E6100000B954A52DAE9F4740779E78CE16104C40
13212	7	66	\N	61	422	\N	56.145439000000003	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пр.Московский, д.3	Россия, республика Чувашская, Чебоксары, Московский проспект, 3	0101000020E6100000280EA0DFF79D47400F48C2BE9D124C40
13207	7	66	\N	61	422	\N	56.143613999999999	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пр.Московский, д.29	Россия, республика Чувашская, Чебоксары, Московский проспект, 29	0101000020E6100000FED5E3BED59A4740B69F8CF161124C40
13205	7	66	\N	61	422	\N	56.141157	Чувашская Республика - Чувашия, город Чебоксары, Московский район, пр.Московский, д.35	Россия, республика Чувашская, Чебоксары, Московский проспект, 35	0101000020E6100000774D486B0C9A4740FD4CBD6E11124C40
12735	7	66	\N	61	3192	\N	56.154339999999998	Чувашская Республика - Чувашия, Ибресинский район, Ширтанское сельское поселение, Московская, 2	Россия, республика Чувашская, Чебоксары, Московская набережная, 3	0101000020E61000009A266C3F199F4740793BC269C1134C40
13195	7	66	\N	61	59218	\N	56.116224609555097	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.М.Залка, д.4/11	Россия, республика Чувашская, Чебоксары, улица Мате Залка, 4	0101000020E61000000F9BC8CC0598474022FDF675E00E4C40
54870	7	63	866	47964	54903	\N	54.583806000000003	с.Лада, Базарная, 25		0101000020E610000044DD0720B5B74640B39AAE27BA4A4B40
13131	7	66	\N	61	61592	\N	56.109004106591797	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Ленинского Комсомола, д.86	Россия, республика Чувашская, Чебоксары, улица Ленинского Комсомола, 86	0101000020E61000006939D0436DA947400C91D3D7F30D4C40
13130	7	66	\N	61	61592	\N	56.108754653707102	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Ленинского Комсомола, д.74	Россия, республика Чувашская, Чебоксары, улица Ленинского Комсомола, 74	0101000020E61000006C7BBB2539A84740642310AFEB0D4C40
13128	7	66	\N	61	61592	\N	56.107017150127	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Ленинского Комсомола, д.54	Россия, республика Чувашская, Чебоксары, улица Ленинского Комсомола, 54	0101000020E6100000EEB089CC5CA64740DA8EA9BBB20D4C40
13145	7	66	\N	61	61788	\N	56.138553000000002	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Ленинградская, 32		0101000020E6100000C713419C879F4740A0E1CD1ABC114C40
13181	7	66	\N	61	61773	\N	56.146051	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Лебедева, д.13		0101000020E610000013F3ACA415954740284696CCB1124C40
13166	7	66	\N	61	8027	\N	56.089362000000001	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Кукшумская, 19	Россия, республика Чувашская, Чебоксары, Кукшумская улица, 19	0101000020E6100000164B917C25A44740A9C0C936700B4C40
13168	7	66	\N	61	61764	\N	56.089869999999998	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, Кукшумская, 23		0101000020E6100000EA094B3CA0A447401D7233DC800B4C40
13165	7	66	\N	61	61764	\N	56.0880970772225	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Кукшумская, 11а	Россия, республика Чувашская, Чебоксары, Кукшумская улица, 11	0101000020E61000004FB0FF3A37A3474017F032C3460B4C40
13139	7	66	\N	61	61790	\N	56.082225000000001	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Кременского, д.34		0101000020E61000000C1F115322A54740F1F44A59860A4C40
13153	7	66	\N	61	61767	\N	56.118259000000002	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Николаева, 1		0101000020E61000006EBE11DDB3A0474095BA641C230F4C40
13118	7	66	\N	61	61767	\N	56.124094999999997	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Николаева, д.28		0101000020E6100000FEF0F3DF83A347406E4C4F58E20F4C40
13117	7	66	\N	61	61767	\N	56.125345000000003	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Николаева, д.31		0101000020E6100000E8BD310400A34740CBDB114E0B104C40
12721	7	66	\N	61	62937	\N	56.137841000000002	Чувашская Республика - Чувашия, Ибресинский район, Климовское сельское поселение, Кооперативная, 10		0101000020E61000001C78B5DC999F474023861DC6A4114C40
13213	7	66	\N	61	62003	\N	56.153232000000003	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.К.Иванова, д.30		0101000020E6100000C8940F41D59E4740B0592E1B9D134C40
13211	7	66	\N	61	59298	\N	56.149029755042299	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.К.Иванова, д.79/16	Россия, республика Чувашская, Чебоксары, улица Константина Иванова, 79/16	0101000020E610000063B66455849D4740BB0F406A13134C40
13220	7	66	\N	61	59409	\N	56.133669065091297	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Первая Коммунальная слобода, д.25	Россия, республика Чувашская, Чебоксары, улица Коммунальная Слобода, 25	0101000020E61000004CFDBCA9489D474098BED7101C114C40
13169	7	66	\N	61	61771	\N	56.1351775158804	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Коммунальная Слобода, 25	Россия, республика Чувашская, Чебоксары, улица Коммунальная Слобода	0101000020E6100000E10A28D4D39D4740C19140834D114C40
13146	7	66	\N	61	61794	\N	56.138703999999997	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, К.Маркса, 38		0101000020E610000012BD8C62B99F474085E97B0DC1114C40
13144	7	66	\N	61	61794	\N	56.140199000000003	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.К.Маркса, 29		0101000020E610000039B35DA10FA0474049F7730AF2114C40
13126	7	66	\N	61	61765	\N	56.101861	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Кадыкова, д.16а		0101000020E61000009D9CA1B8E3A5474072DEFFC7090D4C40
13110	7	66	\N	61	61632	\N	56.1463680950271	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Зои Яковлевой, д.54а	Россия, республика Чувашская, Чебоксары, улица Зои Яковлевой, 54а	0101000020E61000000283A44FABA247402997C62FBC124C40
13112	7	66	\N	61	61766	\N	56.137610000000002	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Декабристов, д.17		0101000020E61000009E7DE5417AA4474021CD58349D114C40
13222	7	66	\N	61	61791	\N	56.124502	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Гражданская, д.50 А		0101000020E610000027DA5548F9994740AF2479AEEF0F4C40
13111	7	66	\N	61	61782	\N	56.144441	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.Гайдара, д.3		0101000020E6100000EA04341136A24740CC99ED0A7D124C40
13152	7	66	\N	61	61769	\N	56.122314000000003	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Гагарина, 10а		0101000020E610000051A04FE449A04740E6EB32FCA70F4C40
13150	7	66	\N	61	61769	\N	56.125695999999998	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул.Гагарина, 15а		0101000020E61000002BC3B81B44A14740779E78CE16104C40
13170	7	66	\N	61	61772	\N	56.120587999999998	Чувашская Республика - Чувашия, город Чебоксары, Ленинский район, ул. Б. Хмельницкого, 75		0101000020E610000071C79BFC169D47402025766D6F0F4C40
54848	7	63	866	8230	54753	\N	54.713267000000002	с.Кергуды, А. Егорова, 5		0101000020E610000010EA2285B2984640742843554C5B4B40
13187	7	66	\N	61	61778	\N	56.146111679512998	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Ахазова, д.9 А	Россия, республика Чувашская, Чебоксары, улица Ахазова, 9а	0101000020E610000011363CBD52964740CEC64ACCB3124C40
13210	7	66	\N	61	61799	\N	56.148367999999998	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Афанасьева, д.6		0101000020E6100000D4449F8F329C4740EFE2FDB8FD124C40
13209	7	66	\N	61	61799	\N	56.149982999999999	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.Афанасьева, д.11		0101000020E61000006DC7D45DD99B47405DFA97A432134C40
13204	7	66	\N	61	58932	\N	56.120306281320403	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.М.Павлова, д.9	Россия, республика Чувашская, Чебоксары, улица Академика Павлова, 9	0101000020E6100000B343FCC3969C47409CC1DF2F660F4C40
13183	7	66	\N	61	58932	\N	56.121433009860098	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.М.Павлова, д.50/1	Россия, республика Чувашская, Чебоксары, улица Академика Павлова, 50	0101000020E6100000E469F981AB9C4740DDD3D51D8B0F4C40
13179	7	66	\N	61	58932	\N	56.121067426040099	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.М.Павлова, д.78	Россия, республика Чувашская, Чебоксары, улица Академика Павлова	0101000020E610000080812040869C4740FACF9A1F7F0F4C40
13121	7	66	\N	61	61407	\N	56.107925000000002	Чувашская Республика - Чувашия, город Чебоксары, Калининский район, ул.324 стрелковой дивизии, д.10	Россия, республика Чувашская, Чебоксары, улица Гастелло, 9	0101000020E61000000CCA349A5CA84740DDB5847CD00D4C40
13185	7	66	\N	61	61759	\N	56.141933455499199	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.139 стрелковой дивизии, д.12	Россия, республика Чувашская, Чебоксары, улица 139-й Стрелковой Дивизии, 10	0101000020E61000000A12DBDD03964740919C4CDC2A124C40
13186	7	66	\N	61	59104	\N	56.142732355590198	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.139 стрелковой дивизии, д.9	Россия, республика Чувашская, Чебоксары, улица 139-й Стрелковой Дивизии, 9	0101000020E6100000EF0390DAC4954740DD0BCC0A45124C40
13184	7	66	\N	61	59104	\N	56.142441941986803	Чувашская Республика - Чувашия, город Чебоксары, Московский район, ул.139 стрелковой дивизии, д.14	Россия, республика Чувашская, Чебоксары, улица 139-й Стрелковой Дивизии, 14	0101000020E61000006D75392520964740D6C9198A3B124C40
13345	7	66	\N	57859	61644	\N	55.867373999999998	Чувашская Республика - Чувашия, Цивильский район, Цивильское городское поселение, г. Цивильск, улица Рогожкина, д. 59		0101000020E61000008E791D71C8BC47404AB3791C06EF4B40
13346	7	66	\N	57859	61678	\N	55.867373999999998	Чувашская Республика - Чувашия, Цивильский район, Цивильское городское поселение, г. Цивильск, ул. П. Иванова, д. 1А		0101000020E61000008E791D71C8BC47404AB3791C06EF4B40
13344	7	66	\N	57859	61563	\N	55.867373999999998	Чувашская Республика - Чувашия, Цивильский район, Цивильское городское поселение, г. Цивильск, улица М. Горького, д. 1		0101000020E61000008E791D71C8BC47404AB3791C06EF4B40
13095	7	66	\N	21149	61573	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, проезд Ельниковский, д.6А		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13094	7	66	\N	21149	61573	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, проезд Ельниковский, д.6		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13089	7	66	\N	21149	61648	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, бульвар Зеленый, д.26		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13085	7	66	\N	21149	61648	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, бульвар Зеленый, д.3		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13084	7	66	\N	21149	61648	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, бульвар Зеленый, д.10А		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13078	7	66	\N	21149	61392	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Терешковой, д.15	Россия, республика Чувашская, Новочебоксарск	0101000020E61000006C257497C4BF474031B2648EE50B4C40
13098	7	66	\N	21149	61628	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Строителей, д.36		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13088	7	66	\N	21149	61673	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Солнечная, д.14		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13087	7	66	\N	21149	61673	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Солнечная, д.2		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13090	7	66	\N	21149	61591	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Советская, д.27А		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13086	7	66	\N	21149	61591	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Советская, д.3		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13073	7	66	\N	21149	61671	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Силикатная, д.18		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13092	7	66	\N	21149	61586	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Семенова, д.15		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13091	7	66	\N	21149	61586	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Семенова, д.17		0101000020E61000006C257497C4BF474031B2648EE50B4C40
12959	7	66	\N	21149	61586	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Семенова, д.25		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13097	7	66	\N	21149	61394	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Пионерская, д.21	Россия, республика Чувашская, Новочебоксарск	0101000020E61000006C257497C4BF474031B2648EE50B4C40
13108	7	66	\N	21149	61574	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Первомайская, д.10		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13107	7	66	\N	21149	61574	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Первомайская, д.6		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13102	7	66	\N	21149	61574	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Первомайская, д.30		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13101	7	66	\N	21149	61574	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Первомайская, д.45		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13099	7	66	\N	21149	61574	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Первомайская, д.55		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13080	7	66	\N	21149	61590	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Парковая, д.7		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13096	7	66	\N	21149	62762	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Ольдеевская, д.2		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13077	7	66	\N	21149	61672	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Молодежная, д.15		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13082	7	66	\N	21149	9718	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Комсомольская, д.19		0101000020E61000006C257497C4BF474031B2648EE50B4C40
12935	7	66	\N	21149	9718	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Комсомольская, д.18	Россия, республика Чувашская, Новочебоксарск	0101000020E61000006C257497C4BF474031B2648EE50B4C40
13079	7	66	\N	21149	61589	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Коммунистическая, д.37		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13076	7	66	\N	21149	61589	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Коммунистическая, д.2		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13075	7	66	\N	21149	61627	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Жени Крутовой, д.7А		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13074	7	66	\N	21149	61627	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Жени Крутовой, д.2		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13106	7	66	\N	21149	61630	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Винокурова, д.80		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13104	7	66	\N	21149	61630	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Винокурова, д.125		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13081	7	66	\N	21149	61630	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Винокурова, д.12		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13105	7	66	\N	21149	61629	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.В-Интернационалистов, д.9		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13100	7	66	\N	21149	61677	\N	56.092942999999998	Чувашская Республика - Чувашия, город Новочебоксарск, ул.10-й Пятилетки, д.41		0101000020E61000006C257497C4BF474031B2648EE50B4C40
13537	7	66	\N	52521	\N	\N	55.015402999999999	Чувашская Республика - Чувашия, Яльчикский район, Лащ-Таябинское сельское поселение д.Н.Байдеряково, Приозерная, 5	Россия, республика Чувашская, село Новое Байдеряково	0101000020E61000000B7BDAE1AF0D484051A1BAB9F8814B40
12974	7	66	\N	57858	61890	\N	56.105879411694303	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, г. Мариинский  Посад, Фурманова, 27		0101000020E6100000E75086AA98DC4740A62A6D718D0D4C40
12972	7	66	\N	57858	61588	\N	56.114927831060001	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, Николаева, 52	Россия, республика Чувашская, Мариинско-Посадский район, Мариинский Посад	0101000020E6100000CF656A12BCDB474085B2F0F5B50E4C40
12969	7	66	\N	57858	61562	\N	56.113345338453598	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, Ломоносова, 9	Россия, республика Чувашская, Мариинско-Посадский район, Мариинский Посад	0101000020E6100000069FE6E445DC47402315C616820E4C40
12971	7	66	\N	57858	61948	\N	56.114160570078802	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, Ленинская, 2	Россия, республика Чувашская, Мариинско-Посадский район, Мариинский Посад	0101000020E61000007F6DFDF49FDB474045BDE0D39C0E4C40
12970	7	66	\N	57858	61808	\N	56.114736017254899	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, Котовского, 36	Россия, республика Чувашская, Мариинско-Посадский район, Мариинский Посад	0101000020E61000000C01C0B167DB474041D653ABAF0E4C40
12837	7	66	\N	57865	\N	\N	55.829101999999999	Чувашская Республика - Чувашия, Козловский район, г.Козловка, помещение отдела ЗАГС 2 этаж		0101000020E610000074D4D171352048402B86AB0320EA4B40
12836	7	66	\N	57865	\N	\N	55.829101999999999	"Чувашская Республика - Чувашия, Козловский район, г.Козловка, актовый зал МОУ доп. образования детей, ""Центр детского творчества"" 2 эт"		0101000020E610000074D4D171352048402B86AB0320EA4B40
12835	7	66	\N	57865	\N	\N	55.829101999999999	"Чувашская Республика - Чувашия, Козловский район, г.Козловка, помещение МОУ учреждения доп.образования детей, ""Детская художественная школа""1 эт"		0101000020E610000074D4D171352048402B86AB0320EA4B40
12834	7	66	\N	57865	\N	\N	55.829101999999999	"Чувашская Республика - Чувашия, Козловский район, г.Козловка, помещение МОУ, ""КСОШ № 3"" 2 этаж"		0101000020E610000074D4D171352048402B86AB0320EA4B40
12833	7	66	\N	57865	\N	\N	55.829101999999999	"Чувашская Республика - Чувашия, Козловский район, г.Козловка, помещение МОУ, ""КСОШ № 3"" 1 этаж"		0101000020E610000074D4D171352048402B86AB0320EA4B40
12832	7	66	\N	57865	\N	\N	55.829101999999999	"Чувашская Республика - Чувашия, Козловский район, г.Козловка, помещение МОУ, ""КООШ №1"" им.А.Г.Тухланова"		0101000020E610000074D4D171352048402B86AB0320EA4B40
12830	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Автошкола  РОСТО (ул. Толстого – 12)		0101000020E61000009A93179980BF474078094E7D20C14B40
12829	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 4 (ул. Кошевого – 3)		0101000020E61000009A93179980BF474078094E7D20C14B40
12828	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Офис врача общей практики (ул. Репина – 12)		0101000020E61000009A93179980BF474078094E7D20C14B40
12827	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, ПУ № 2 (ул. Ильича – 15)		0101000020E61000009A93179980BF474078094E7D20C14B40
12826	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 11 (пр. Ленина – 60)	Россия, республика Чувашская, Канаш	0101000020E61000009A93179980BF474078094E7D20C14B40
12825	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Офис врача общей практики (ул. Трудовая – 1)	Россия, республика Чувашская, Канаш	0101000020E61000009A93179980BF474078094E7D20C14B40
12824	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 9 (ул. Чкалова – 12)		0101000020E61000009A93179980BF474078094E7D20C14B40
12823	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Городской  Дворец культуры (пр. Ленина – 28)		0101000020E61000009A93179980BF474078094E7D20C14B40
12822	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 10 (пр. Ленина – 29)		0101000020E61000009A93179980BF474078094E7D20C14B40
12821	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 8 (ул. Пушкина – 21)		0101000020E61000009A93179980BF474078094E7D20C14B40
12820	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа-интернат (ул. Московская – 19)		0101000020E61000009A93179980BF474078094E7D20C14B40
12819	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 5 (ул. Московская – 20)		0101000020E61000009A93179980BF474078094E7D20C14B40
12818	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Центр детского и юнош. творчества (ул. 30 лет Победы – 13)		0101000020E61000009A93179980BF474078094E7D20C14B40
12817	7	66	\N	4268	\N	\N	55.508803999999998	"Чувашская Республика - Чувашия, город Канаш, РГУ «КГЦСОН"" (ул. 30 Победы - 32А)"		0101000020E61000009A93179980BF474078094E7D20C14B40
12816	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Канашский педагогический колледж (ул. Комсомольская – 33)		0101000020E61000009A93179980BF474078094E7D20C14B40
12815	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 7 (ул. Машиностроителей – 22)		0101000020E61000009A93179980BF474078094E7D20C14B40
12814	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 1 (ул. Пролетарская – 18)		0101000020E61000009A93179980BF474078094E7D20C14B40
12813	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, ПУ № 22 (Ибресинское шоссе – 1)		0101000020E61000009A93179980BF474078094E7D20C14B40
12812	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Здание восстанов. поезда ОАО РЖД (ул. Железнодорожная, 36 А)		0101000020E61000009A93179980BF474078094E7D20C14B40
12811	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, ООО «Канашский завод технолог. оснастки» (ул. Свободы, 36)		0101000020E61000009A93179980BF474078094E7D20C14B40
12810	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 3 (ул. Кооперативная-10)		0101000020E61000009A93179980BF474078094E7D20C14B40
12702	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 6 (Восточный район – 23)		0101000020E61000009A93179980BF474078094E7D20C14B40
12690	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, ПУ № 16 (Восточный район – 27)		0101000020E61000009A93179980BF474078094E7D20C14B40
12678	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Клуб поселка Элеватор (Элеватор территория)	Россия, республика Чувашская, Канаш	0101000020E61000009A93179980BF474078094E7D20C14B40
12666	7	66	\N	4268	\N	\N	55.508803999999998	Чувашская Республика - Чувашия, город Канаш, Школа № 7 (г. Канаш, ул. Машиностроителей – 22)		0101000020E61000009A93179980BF474078094E7D20C14B40
12594	7	66	\N	4268	\N	\N	55.508901408910702	Чувашская Республика - Чувашия, город Канаш, школа № 6 (Восточный район – 23)	Россия, республика Чувашская, Канаш	0101000020E6100000823CBB7CEBBF47406BF3FFAA23C14B40
13411	7	66	\N	12030	62011	\N	54.768858000000002	Чувашская Республика - Чувашия, Шемуршинский район, Шемуршинское сельское поселение, поселок Канаш, Канашская, 2 А		0101000020E61000003E9468C9E3EB47404DA25EF069624B40
13485	7	66	939	57906	61867	\N	55.860267218383299	село Советское, Советская, 37	Россия, республика Чувашская, Ядринский район, село Советское	0101000020E6100000BABF7ADCB7464740FD69A33A1DEE4B40
12709	7	66	\N	57914	61951	\N	55.303698480079703	Чувашская Республика - Чувашия, Ибресинский район, Ибресинское городское поселение, Школьная, 4	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E61000005FB4C70BE984474028EE7893DFA64B40
12534	7	66	\N	314	\N	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, мкр Стрелка, д.11	Россия, республика Чувашская, Алатырь	0101000020E610000067B796C97048474061360186E56B4B40
12543	7	66	\N	314	61811	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, пер.Больничный, д.2		0101000020E610000067B796C97048474061360186E56B4B40
12531	7	66	\N	314	61579	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, мкр Стрелка, д.7		0101000020E610000067B796C97048474061360186E56B4B40
12532	7	66	\N	314	61651	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул. Южная, д.3		0101000020E610000067B796C97048474061360186E56B4B40
12530	7	66	\N	314	61614	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Юбилейная, д.7		0101000020E610000067B796C97048474061360186E56B4B40
12548	7	66	\N	314	61656	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, Школьный Проезд, д.5		0101000020E610000067B796C97048474061360186E56B4B40
12525	7	66	\N	314	61922	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул. Шаумяна, д. 1		0101000020E610000067B796C97048474061360186E56B4B40
12544	7	66	\N	314	61653	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Почтовая, д.15		0101000020E610000067B796C97048474061360186E56B4B40
12540	7	66	\N	314	61621	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Первомайская, д.48		0101000020E610000067B796C97048474061360186E56B4B40
12539	7	66	\N	314	61621	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Первомайская, д.80		0101000020E610000067B796C97048474061360186E56B4B40
12538	7	66	\N	314	61319	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, Московская, 106	Россия, республика Чувашская, Алатырь	0101000020E610000067B796C97048474061360186E56B4B40
12537	7	66	\N	314	61319	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Московская, д.106		0101000020E610000067B796C97048474061360186E56B4B40
12526	7	66	\N	314	61319	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Московская, д.30		0101000020E610000067B796C97048474061360186E56B4B40
12527	7	66	\N	314	61645	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул. Ленина, д. 13		0101000020E610000067B796C97048474061360186E56B4B40
12529	7	66	\N	314	61619	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Комсомола, д.14		0101000020E610000067B796C97048474061360186E56B4B40
12528	7	66	\N	314	61619	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул. Комсомола, д.21		0101000020E610000067B796C97048474061360186E56B4B40
12541	7	66	\N	314	61923	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Жуковского, д.63		0101000020E610000067B796C97048474061360186E56B4B40
12536	7	66	\N	314	61620	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Димитрова, д.9		0101000020E610000067B796C97048474061360186E56B4B40
12542	7	66	\N	314	61322	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Гончарова, д.115	Россия, республика Чувашская, Алатырь	0101000020E610000067B796C97048474061360186E56B4B40
12549	7	66	\N	314	61580	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Гагарина, д.19		0101000020E610000067B796C97048474061360186E56B4B40
12535	7	66	\N	314	61318	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Володарского, д.14	Россия, республика Чувашская, Алатырь	0101000020E610000067B796C97048474061360186E56B4B40
12547	7	66	\N	314	61618	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Березовая, д.1		0101000020E610000067B796C97048474061360186E56B4B40
12545	7	66	\N	314	61655	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, ул.Артиллерийская, д.34		0101000020E610000067B796C97048474061360186E56B4B40
12546	7	66	\N	314	61622	\N	54.842942000000001	Чувашская Республика - Чувашия, город Алатырь, 40 лет Победы, д.31А		0101000020E610000067B796C97048474061360186E56B4B40
13581	7	66	1567	20441	61916	\N	55.561787000000002	Чувашская Республика - Чувашия, Янтиковский район, Яншихово-Норвашское сельское поселение, с. Яншихово-Норваши, ул. Школьная, д. 16, сельский дом культуры		0101000020E61000004948A46DFCD14740B328ECA2E8C74B40
13575	7	66	1567	20068	61642	\N	55.522190362679702	Чувашская Республика - Чувашия, Янтиковский район, Янтиковское сельское поселение, с. Янтиково, пр. Ленина, д. 3, МУК Янтиковский КДЦ	Россия, республика Чувашская, Янтиковский район, село Янтиково	0101000020E61000009D6340F67AE347402D26361FD7C24B40
13576	7	66	1567	20068	61836	\N	55.519314999999999	Чувашская Республика - Чувашия, Янтиковский район, Янтиковское сельское поселение, с. Янтиково, ул. Ленина, д. 56, детская библиотека		0101000020E610000027BF45274BE347403FA9F6E978C24B40
13573	7	66	1567	19960	61915	\N	55.546754999999997	Чувашская Республика - Чувашия, Янтиковский район, Шимкусское сельское поселениес, Шимкусы, ул. Коммунистическая, д. 4, сельский дом культуры		0101000020E6100000F6D37FD6FCF8474055F65D11FCC54B40
13571	7	66	1567	19847	62908	\N	55.391410999999998	"Чувашская Республика - Чувашия, Янтиковский район, Чутеевское сельское поселение, с. Чутеево, ул. Лесная, д. 39, МДОУ ""Чутеевская СОШ"""		0101000020E6100000D6AD9E93DEE94740B72572C119B24B40
13558	7	66	1567	19179	62902	\N	55.522592000000003	Чувашская Республика - Чувашия, Янтиковский район, Индырчское сельское поселение, д. Уразлино, ул. Николаева, д. 23, сельский клуб		0101000020E61000000AD6389B8EEA47405C936E4BE4C24B40
13487	7	66	939	15616	62125	\N	55.853859999999997	деревня Сехры, Школьная, 15		0101000020E6100000529ACDE3303E474068AED3484BED4B40
13555	7	66	1567	19020	62661	\N	55.570945000000002	Чувашская Республика - Чувашия, Янтиковский район, Алдиаровское сельское поселение, д. Уразкасы, ул. Ильича, д. 29, сельский Дом культуры		0101000020E61000003BFF76D9AFDD47404968CBB914C94B40
13566	7	66	1567	19592	61898	\N	55.439354000000002	Чувашская Республика - Чувашия, Янтиковский район, Тюмеревское сельское поселение, д. Тюмерево, ул. Калинина, д. 4, сельский дом культуры		0101000020E610000082C476F700E34740F3AE7AC03CB84B40
13564	7	66	1567	19488	61838	\N	55.513233999999997	Чувашская Республика - Чувашия, Янтиковский район, Турмышское сельское поселение, с. Турмыши, ул. Советская, д. 12, сельский дом культуры		0101000020E610000021205F4205D54740FE98D6A6B1C14B40
13557	7	66	1567	19121	62095	\N	55.506433999999999	Чувашская Республика - Чувашия, Янтиковский район, Индырчское сельское поселение, д. Тенеево, ул. А. Егоровой, д. 21, сельский Дом культуры		0101000020E6100000AC6F6072A3F647408ECA4DD4D2C04B40
13563	7	66	1567	19442	62660	\N	55.551231999999999	Чувашская Республика - Чувашия, Янтиковский район, Новобуяновское сельское поселение, Старое Буяново, ул. Ленина, д. 21, общественный центр		0101000020E61000004E2A1A6B7FE547401C412AC58EC64B40
13579	7	66	1567	20313	62778	\N	55.505378	Чувашская Республика - Чувашия, Янтиковский район, Янтиковское сельское поселение, д. Салагаево, ул. Родник, д. 24, сельский дом культуры		0101000020E6100000B9162D40DBE84740170FEF39B0C04B40
13578	7	66	1567	20263	62127	\N	55.528595000000003	Чувашская Республика - Чувашия, Янтиковский район, Янтиковское сельское поселение, с. Русские Норваши, ул. Центральная, д. 9, фельдшерско-акушерский пункт		0101000020E610000050FF59F3E3DD474021EA3E00A9C34B40
13554	7	66	1567	18971	62914	\N	55.606811999999998	Чувашская Республика - Чувашия, Янтиковский район, Алдиаровское сельское поселение, д. Нюшкасы, ул. Гагарина, д. 27, сельский клуб		0101000020E610000010C99063EBE147400169FF03ACCD4B40
13582	7	66	1567	20528	62096	\N	55.542822999999999	Чувашская Республика - Чувашия, Янтиковский район, Яншихово-Норвашское сельское поселение, д. Норваш-Кошки, ул. Центральная, д. 10, сельский клуб		0101000020E61000007DCC07043AD9474020425C397BC54B40
13572	7	66	1567	19908	62912	\N	55.371828000000001	Чувашская Республика - Чувашия, Янтиковский район, Чутеевское сельское поселение, д. Новое Ишино, ул. Ленина, д. 17, сельский дом культуры		0101000020E6100000E75608ABB1E4474059DE550F98AF4B40
13562	7	66	1567	19384	62903	\N	55.563980999999998	Чувашская Республика - Чувашия, Янтиковский район, Новобуяновское сельское поселение, д. Новое Буяново, ул. Комсомольская, д. 30, сельский дом культуры		0101000020E6100000E7C589AF76E647405E48878730C84B40
13574	7	66	1567	20021	62910	\N	55.565798999999998	"Чувашская Республика - Чувашия, Янтиковский район, Шимкусское сельское поселение, д. Нижарово, ул. Пролетарская, д. 27, МДОУ ""Шимкусская СОШ"""		0101000020E6100000484F9143C4F14740048E041A6CC84B40
13559	7	66	1567	19239	62776	\N	55.471361999999999	Чувашская Республика - Чувашия, Янтиковский район, Можарское сельское поселение, с. Можарки, ул. Ленина, д. 33, сельский дом культуры		0101000020E61000001D3A3DEFC6E84740E0490B9755BC4B40
13565	7	66	1567	19551	62664	\N	55.505918999999999	Чувашская Республика - Чувашия, Янтиковский район, Турмышское сельское поселение, д. Латышево, ул. Ленина, д. 32, сельский клуб		0101000020E6100000F6B2EDB435DA474067B62BF4C1C04B40
13561	7	66	1567	19329	62905	\N	55.461854000000002	Чувашская Республика - Чувашия, Янтиковский район, Можарское сельское поселение, д. Кичкеево, ул. Первомайская, д. 54, сельский дом культуры		0101000020E610000057CD7344BEF347406EC328081EBB4B40
13570	7	66	1567	19805	62030	\N	55.439450999999998	Чувашская Республика - Чувашия, Янтиковский район, Тюмеревское сельское поселение, д. Кармалы, ул. Советская, д. 3, сельский дом культуры		0101000020E61000002CF52C08E5D94740E5982CEE3FB84B40
13556	7	66	1567	19086	62662	\N	55.517572000000001	Чувашская Республика - Чувашия, Янтиковский район, Индырчское сельское поселение, д. Индырчи, ул. Чапаева, д. 2, сельский Дом культуры		0101000020E6100000A67C08AA46EF4740A4A99ECC3FC24B40
13577	7	66	1567	20184	62907	\N	55.504649000000001	Чувашская Республика - Чувашия, Янтиковский район, Янтиковское сельское поселение, д. Иваново, ул. Школьная, д.1, сельская библиотека		0101000020E6100000BD361B2B31DF4740C47AA35698C04B40
13560	7	66	1567	19283	62607	\N	55.478805999999999	Чувашская Республика - Чувашия, Янтиковский район, Можарское сельское поселение, с. Гришино, ул. Первомайская, д. 24, сельский дом культуры		0101000020E6100000DCBDDC2747F147407590D78349BD4B40
13553	7	66	1567	18910	62904	\N	55.585067000000002	Чувашская Республика - Чувашия, Янтиковский район, Алдиаровское сельское поселение, д. Беляево, ул. Ленина, д. 41, сельский клуб		0101000020E6100000E08618AF79DD4740037CB779E3CA4B40
13568	7	66	1567	19704	62665	\N	55.45675	Чувашская Республика - Чувашия, Янтиковский район, Тюмеревское сельское поселение, д. Бахтиарово, ул. Школьная, д. 1, сельская библиотека		0101000020E610000099B8551003DD47405839B4C876BA4B40
13567	7	66	1567	19640	62780	\N	55.4229967726571	Чувашская Республика - Чувашия, Янтиковский район, Тюмеревское сельское поселение, д. Амалыково, ул. Ленина, д. 2, сельский дом культуры		0101000020E610000065DEAAEB50ED47402FA704C424B64B40
13552	7	66	1567	18876	62128	\N	55.586781999999999	Чувашская Республика - Чувашия, Янтиковский район, Алдиаровское сельское поселение, с. Алдиарово, ул. Воробьева, д. 7, сельский Дом культуры		0101000020E6100000787DE6AC4FE14740D4F02DAC1BCB4B40
13501	7	66	939	16267	62133	\N	55.920445999999998	деревня Сареево, Шоссейная, 4-Б		0101000020E61000008D0C721761244740F4DDAD2CD1F54B40
13514	7	66	708	61568	79402	\N	55.161954065451397	Чувашская Республика - Чувашия, Яльчикский район, Яльчикское сельское поселение д.А.Тимяши, Центральная, 39	Россия, республика Чувашская, Яльчикский район, село Яльчики	0101000020E61000007C462234820148406BBA9EE8BA944B40
13510	7	66	708	16627	62682	\N	55.1596444481088	Чувашская Республика - Чувашия, Яльчикский район, Яльчикское сельское поселение, с.Яльчики, ул.Юбилейная, д.6а	Россия, республика Чувашская, Яльчикский район, село Яльчики	0101000020E61000007ADE8D05850148405680EF366F944B40
13509	7	66	708	16627	61578	\N	55.161557999999999	Чувашская Республика - Чувашия, Яльчикский район, Яльчикское сельское поселение, с.Яльчики, ул.Иванова. д.15		0101000020E610000053AEF02E170148401E34BBEEAD944B40
13508	7	66	708	16627	61578	\N	55.161557999999999	Чувашская Республика - Чувашия, Яльчикский район, Яльчикское сельское поселение, с.Яльчики, ул.Иванова, д.13		0101000020E610000053AEF02E170148401E34BBEEAD944B40
13544	7	66	708	52532	62924	\N	55.030680166340197	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение д.Эшмикеево, Больничная, 12	Россия, республика Чувашская, Яльчикский район, село Эшмикеево	0101000020E6100000F1A1444B1EF1474015527E52ED834B40
13525	7	66	708	52504	62100	\N	55.226005000000001	Чувашская Республика - Чувашия, Яльчикский район, Кильдюшевское сельское поселение, д.Эмметево, Кооперативная, 18		0101000020E6100000CC9BC3B5DADF4740C2DD59BBED9C4B40
13532	7	66	708	52514	62906	\N	54.972194000000002	Чувашская Республика - Чувашия, Яльчикский район, Лащ-Таябинское сельское поселение  д.Шемалакова, Братьев Денисовых, 29		0101000020E610000093A641D13CF4474008AF5DDA707C4B40
13519	7	66	708	21314	61835	\N	55.192594999999997	Чувашская Республика - Чувашия, Яльчикский район, Малотаябинское сельское поселение, д.Ст.Янашево, ул.Анаткасс, д.70		0101000020E6100000CF6740BD19FD4740C22FF5F3A6984B40
13545	7	66	708	52534	\N	\N	55.036886000000003	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение д.Старое Арланово, Клубная, 37	Россия, республика Чувашская, Яльчикский район, село Старое Арланово	0101000020E61000001213D4F02DEC474013D731AEB8844B40
13551	7	66	708	52551	62923	\N	55.153750000000002	Чувашская Республика - Чувашия, Яльчикский район, Сабанчинское сельское поселение с.Сабанчино, Цетральная, 99		0101000020E6100000C0E78711C2F3474048E17A14AE934B40
13524	7	66	708	52502	62874	\N	55.248487691034498	Чувашская Республика - Чувашия, Яльчикский район, Кильдюшевское сельское поселение д.Полевые пинеры, Центральная, 9	Россия, республика Чувашская, Яльчикский район, село Полевые Пинеры	0101000020E61000007099D36531E7474067B96C74CE9F4B40
13548	7	66	708	52167	62901	\N	55.174315999999997	Чувашская Республика - Чувашия, Яльчикский район, Сабанчинское сельское поселение д.Полевые Козыльяры, Мостовая, 1А		0101000020E6100000AAF06778B3EE4740B39597FC4F964B40
13285	7	66	708	52167	62769	\N	55.174315999999997	Чувашская Республика - Чувашия, Урмарский район, Тегешевское сельское поселение, д. Козыльяры, ул. Ленина, д. 11		0101000020E6100000AAF06778B3EE4740B39597FC4F964B40
13528	7	66	708	58055	79399	\N	55.176887703660803	Чувашская Республика - Чувашия, Яльчикский район, Новошимкусское сельское поселение д.П.Буртассы, Центральная, 44		0101000020E6100000B8C9A8328CDF474005871744A4964B40
13550	7	66	708	58055	63032	\N	55.176779196253698	Чувашская Республика - Чувашия, Яльчикский район, Сабанчинское сельское поселение д.Тораево, Полевая, 12A	Россия, республика Чувашская, Яльчикский район, село Полевые Буртасы	0101000020E61000001553E9279CDF47404FCFBBB1A0964B40
13529	7	66	708	32765	\N	\N	55.156548999999998	Чувашская Республика - Чувашия, Яльчикский район, Новошимкусское сельское поселение с.Н Шимкуссы, Центральная, 126	Россия, республика Чувашская, Яльчикский район, село Новые Шимкусы	0101000020E6100000FCFB8C0B07E247405A9C31CC09944B40
13517	7	66	708	58031	62829	\N	55.281475294211297	Чувашская Республика - Чувашия, Яльчикский район, Малотаябинское сельское поселение, д.Н-П-Таяба, ул.Садовая, д.14	Россия, республика Чувашская, Яльчикский район, село Новопоселенная Таяба	0101000020E610000085B53176C2FF474020D26F5F07A44B40
13538	7	66	708	21749	79401	\N	55.110852000000001	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение д.Новое Янашево, ул.Новая, д.45	Россия, республика Чувашская, Яльчикский район, село Новое Янашево	0101000020E61000003EAE0D15E30048401D59F965308E4B40
13530	7	66	708	52508	62879	\N	55.163615	Чувашская Республика - Чувашия, Яльчикский район, Новошимкусское сельское поселение д.Н.Чурино, Центральная, 75		0101000020E61000006B80D250A3E8474049111956F1944B40
13511	7	66	708	52491	\N	\N	55.156255000000002	Чувашская Республика - Чувашия, Яльчикский район, Яльчикское сельское поселение д.Новое Тойдеряково, Магазинная, 19	Россия, республика Чувашская, Яльчикский район, село Новое Тойдеряково	0101000020E6100000172B6A300DFB4740126BF12900944B40
13527	7	66	708	32750	61897	\N	55.199126	Чувашская Республика - Чувашия, Яльчикский район, Кильдюшевское сельское поселение с.Новое Тинчурино, Центральная, 6а		0101000020E61000004D11E0F42EEA474043E4F4F57C994B40
13541	7	66	708	4927	\N	\N	55.092503999999998	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение д.Н.Изамбаево, Федорова, 82	Россия, республика Чувашская, Яльчикский район, село Новое Изамбаево	0101000020E610000028B9C32632F34740E55FCB2BD78B4B40
12606	7	66	708	4927	62039	\N	55.092503999999998	д.Новое Изамбаево, Восточная, 7		0101000020E610000028B9C32632F34740E55FCB2BD78B4B40
13531	7	66	708	52509	62920	\N	55.152811171496197	Чувашская Республика - Чувашия, Яльчикский район, Новошимкусское сельское поселение с. Н.Байбатырево, Центральная, 80	Россия, республика Чувашская, Яльчикский район, село Новое Байбатырево	0101000020E61000008AC745B588EA47400ABC934F8F934B40
13536	7	66	708	52518	77546	\N	55.053302945524699	Чувашская Республика - Чувашия, Яльчикский район, Лащ-Таябинское сельское поселение д.Новое Андиберево, Ленина, 52	Россия, республика Чувашская, Яльчикский район, село Новое Андиберево	0101000020E6100000B0FF3A376DFA4740ACE3F8A1D2864B40
13518	7	66	708	32529	61896	\N	55.220649000000002	Чувашская Республика - Чувашия, Яльчикский район, Малотаябинское сельское поселение, д.М.Таяба, ул.Новая, д.17		0101000020E6100000E6CFB7054BFB47409372F7393E9C4B40
13549	7	66	708	52541	\N	\N	55.186576000000002	Чувашская Республика - Чувашия, Яльчикский район, Сабанчинское сельское поселение д.Малая Ерыкла, Цетральная, 25а	Россия, республика Чувашская, Яльчикский район, село Малая Ерыкла	0101000020E6100000ED9BFBABC7F34740F81BEDB8E1974B40
13534	7	66	708	32814	62601	\N	55.026561000000001	Чувашская Республика - Чувашия, Яльчикский район, Лащ-Таябинское сельское поселение с.Лащ Таяба, Солдатская, 1	Россия, республика Чувашская, Яльчикский район, село Лащ-Таяба	0101000020E610000092CCEA1D6EFF4740AE2CD15966834B40
13523	7	66	708	52501	\N	\N	55.264783999999999	Чувашская Республика - Чувашия, Яльчикский район, Кильдюшевское сельское поселение д.Кушелга, Центральная, 3	Россия, республика Чувашская, Яльчикский район, село Кушелга	0101000020E6100000E84D452A8CE9474085402E71E4A14B40
13543	7	66	708	32873	62775	\N	55.072922253056198	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение д.Кошки-Куликеево, Кирова, 14а	Россия, республика Чувашская, Яльчикский район, село Кошки-Куликеево	0101000020E61000008675E3DD91ED47405794128255894B40
13526	7	66	708	32584	\N	\N	55.220283646328497	Чувашская Республика - Чувашия, Яльчикский район, Кильдюшевское сельское поселение	Россия, республика Чувашская, Яльчикский район, село Кильдюшево	0101000020E6100000E5B33C0FEEE6474081EA1F44329C4B40
13540	7	66	708	52525	62777	\N	55.097614999999998	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение д.Избахтино, Центральная, 55		0101000020E61000008F56B5A4A3F84740AD4CF8A57E8C4B40
13516	7	66	708	32653	61845	\N	55.172469999999997	Чувашская Республика - Чувашия, Яльчикский район, Большеяльчикское сельское поселение с.Большие Яльчики, Кооперативная, 15		0101000020E6100000D3D85E0B7A07484043C5387F13964B40
13533	7	66	708	32692	62931	\N	55.244064999999999	Чувашская Республика - Чувашия, Яльчикский район, Лащ-Таябинское сельское поселение д.Яманчурино, Школьная, 23	Россия, республика Чувашская, Яльчикский район, село Большая Таяба	0101000020E6100000344C6DA983F64740938C9C853D9F4B40
13520	7	66	708	32692	62608	\N	55.244064999999999	Чувашская Республика - Чувашия, Яльчикский район, Большетаябинское сельское поселение с.Большая Таяба, Центральная, 10		0101000020E6100000344C6DA983F64740938C9C853D9F4B40
13522	7	66	708	61200	77533	\N	55.286340638144097	Чувашская Республика - Чувашия, Яльчикский район, Большетаябинское сельское поселение д.Б.Воложка, Цетральная, 2	Россия, республика Чувашская, Яльчикский район, село Белая Воложка	0101000020E6100000D3F4D901D7F14740814067D2A6A44B40
13513	7	66	708	32641	\N	\N	55.144613	Чувашская Республика - Чувашия, Яльчикский район, Яльчикское сельское поселение с.Байдеряково, Восточная, 59	Россия, республика Чувашская, Яльчикский район, село Байдеряково	0101000020E6100000C85EEFFE78054840C9C9C4AD82924B40
13539	7	66	708	52524	\N	\N	55.099825000000003	Чувашская Республика - Чувашия, Яльчикский район, Янтиковское сельское поселение с.Байглычево, Цетральная, 44	Россия, республика Чувашская, Яльчикский район, село Байглычево	0101000020E610000085B2F0F5B5FC47405F29CB10C78C4B40
13521	7	66	708	58073	63176	\N	55.308033999999999	Чувашская Республика - Чувашия, Яльчикский район, Большетаябинское сельское поселение, Хурамакассы, 97а	Россия, республика Чувашская, Яльчикский район, село Аранчеево	0101000020E6100000EA9106B7B5F347402D077AA86DA74B40
13035	7	66	939	25813	62759	\N	55.991596000000001	село Ядрино, Шоссейная, 5		0101000020E6100000BAA29410AC364740166C239EECFE4B40
13349	7	66	939	9071	61900	\N	56.062860999999998	село Юваново, Сюльдикасы, 50		0101000020E61000007F83F6EAE3454740D09849D40B084C40
13103	7	66	939	28913	61972	\N	55.976579000000001	село Чебаково, Ленина, 5		0101000020E61000005DFB027AE12E4740EE7A698A00FD4B40
13491	7	66	939	15773	62688	\N	55.822037999999999	село Хочашево, Березовая, 25		0101000020E6100000AA66D65240364740DD088B8A38E94B40
13493	7	66	939	15902	62018	\N	55.838622000000001	деревня Хорамалы, Калинина, 35-А		0101000020E61000003B1A87FA5D32474062DA37F757EB4B40
13490	7	66	939	15761	62126	\N	55.803980000000003	деревня Хирле-Сиры, Садовая, 13		0101000020E610000079B29B19FD344740AD510FD1E8E64B40
13431	7	66	939	12950	\N	\N	56.092019000000001	село Тяптяево, Ойкасы, 17	Россия, республика Чувашская, Ядринский район, село Тяптяево	0101000020E6100000E388B5F81448474029CE5147C70B4C40
13504	7	66	939	16457	62134	\N	55.823198981561802	деревня Талой, 30 лет Победы, 59	Россия, республика Чувашская, Ядринский район, село Талой	0101000020E610000049D74CBED91A4740CA8CB7955EE94B40
13473	7	66	939	14917	62000	\N	55.965409999999999	деревня Стрелецкая, 40 лет Победы, 63-Б		0101000020E6100000C921E2E6541647409D9D0C8E92FB4B40
13486	7	66	939	15567	61999	\N	55.837429	деревня Старые Тиньгеши, Ленина, 7		0101000020E6100000999B6F44F73E47406ADC9BDF30EB4B40
13489	7	66	939	15693	62016	\N	55.782355000000003	деревня Салугино, Дружбы, 25		0101000020E6100000FCDF1115AA374740596E693524E44B40
12658	7	66	939	7574	62702	\N	55.877474999999997	Чувашская Республика - Чувашия, Вурнарский район, Алгазинское сельское поселение,с.Кукшумы, Ценральная, 13Б		0101000020E610000055320054712B47405F07CE1951F04B40
13478	7	66	939	15171	62797	\N	56.006467000000001	деревня Кудаши, Первомайская, 1		0101000020E6100000499D8026C23047406AC020E9D3004C40
13506	7	66	939	16531	62025	\N	55.839778251444201	деревня Кильдишево, Алины Ивановой, 4	Россия, республика Чувашская, Ядринский район, село Кильдишево	0101000020E610000021E7FD7F9C4A47403DF372D87DEB4B40
13505	7	66	939	16475	62022	\N	55.825713999999998	село Ильина Гора, Мира, 59		0101000020E610000008E9297288104740B7EC10FFB0E94B40
13481	7	66	939	15293	62014	\N	55.966000000000001	деревня Верхние Мочары, Пролетарская, 1-А		0101000020E6100000AF997CB3CD374740CFF753E3A5FB4B40
13396	7	66	939	11292	62032	\N	56.077216999999997	деревня Верхние Ирзеи, Центральная, 47		0101000020E6100000F8A92A3410414740FDD8243FE2094C40
13495	7	66	939	15978	62019	\N	55.809311999999998	деревня Верхние Ачаки, Ленина, 40-А		0101000020E61000009E23F25D4A2D474053211E8997E74B40
13482	7	66	939	15370	62803	\N	55.923850945986501	село Большое Чурашево, пер.Школьный, 1	Россия, республика Чувашская, Ядринский район, село Большое Чурашево	0101000020E6100000DBFB54151A3E47403EB0E3BF40F64B40
13496	7	66	939	16043	62810	\N	55.841372	село Большие Шемердяны, Шоссейная, 7-А		0101000020E6100000BE13B35E0C2B474093E2E313B2EB4B40
13500	7	66	939	16220	62679	\N	55.880302999999998	село Балдаево, Школьная, 18-А		0101000020E61000004D4EED0C532547400CC9C9C4ADF04B40
13494	7	66	939	16004	62811	\N	55.867637000000002	деревня Атликасы, Молодежная, 23-А		0101000020E610000086C77E164B25474058E6ADBA0EEF4B40
13447	7	66	115	13702	\N	\N	55.590108999999998	Чувашская Республика - Чувашия, Шумерлинский район, д. Яндаши	Россия, республика Чувашская, Шумерлинский район, село Яндаши	0101000020E6100000EE4108C897564740A20914B188CB4B40
13451	7	66	115	13869	\N	\N	55.622024000000003	Чувашская Республика - Чувашия, Шумерлинский район, с. Юманаи	Россия, республика Чувашская, Шумерлинский район, село Юманай	0101000020E6100000072461DF4E5A4740DFA9807B9ECF4B40
13432	7	66	115	57910	\N	\N	55.524362828102703	Чувашская Республика - Чувашия, Шумерлинский район, д. Шумерля		0101000020E610000010919A76312F4740C11DA8531EC34B40
13281	7	66	115	5794	\N	\N	55.318013999999998	Чувашская Республика - Чувашия, Шумерлинский район, д. Чувашские Алгаши	Россия, республика Чувашская, Шумерлинский район, село Чувашские Алгаши	0101000020E6100000EACE13CFD9444740C7D5C8AEB4A84B40
13445	7	66	115	13584	\N	\N	55.587260000000001	Чувашская Республика - Чувашия, Шумерлинский район, с. Ходары	Россия, республика Чувашская, Шумерлинский район, село Ходары	0101000020E61000002A90D959F44E4740DE1FEF552BCB4B40
13446	7	66	115	13658	62103	\N	55.598528000000002	Чувашская Республика - Чувашия, Шумерлинский район, д. Тугасы ул. Комсомольская 5		0101000020E610000082E673EE76514740C2DEC4909CCC4B40
13442	7	66	115	13446	\N	\N	55.601233000000001	Чувашская Республика - Чувашия, Шумерлинский район, с. Туваны	Россия, республика Чувашская, Шумерлинский район, село Туваны	0101000020E6100000529CA38E8E4547405323F433F5CC4B40
13438	7	66	115	13300	\N	\N	55.558819	Чувашская Республика - Чувашия, Шумерлинский район, д. Торханы	Россия, республика Чувашская, Шумерлинский район, село Торханы	0101000020E61000006A6798DA5249474014B1886187C74B40
13437	7	66	115	13239	\N	\N	55.597251	Чувашская Республика - Чувашия, Шумерлинский район, пос. Саланчик	Россия, республика Чувашская, Шумерлинский район, село Саланчик	0101000020E6100000276C3F19E32347406C4084B872CC4B40
13449	7	66	115	13783	\N	\N	55.603639000000001	Чувашская Республика - Чувашия, Шумерлинский район, д. Савадеркино	Россия, республика Чувашская, Шумерлинский район, село Савадеркино	0101000020E610000029266F80994947408ACBF10A44CD4B40
13258	7	66	115	4578	\N	\N	55.337685999999998	Чувашская Республика - Чувашия, Шумерлинский район, с. Русские Алгаши	Россия, республика Чувашская, Шумерлинский район, поселок Русские Алгаши	0101000020E6100000CDE67118CC3F474095287B4B39AB4B40
13293	7	66	115	6444	\N	\N	55.340142999999998	Чувашская Республика - Чувашия, Шумерлинский район, пос. Речной	Россия, республика Чувашская, Шумерлинский район, поселок Речной	0101000020E61000009BE8F351464A47404E7B4ACE89AB4B40
13450	7	66	115	13843	\N	\N	55.625816	Чувашская Республика - Чувашия, Шумерлинский район, д. Пояндайкино	Россия, республика Чувашская, Шумерлинский район, село Пояндайкино	0101000020E610000031EA5A7B9F4A474022A81ABD1AD04B40
13093	7	66	115	28435	\N	\N	55.498984	Чувашская Республика - Чувашия, Шумерлинский район, пос. Пинеры	Россия, республика Чувашская, Шумерлинский район, поселок Пинеры	0101000020E610000007600322C4554740179D2CB5DEBF4B40
13433	7	66	115	13023	\N	\N	55.575662999999999	Чувашская Республика - Чувашия, Шумерлинский район, с. Нижняя Кумашка	Россия, республика Чувашская, Шумерлинский район, село Нижняя Кумашка	0101000020E610000046CD57C9C72A474035423F53AFC94B40
13441	7	66	115	10749	\N	\N	55.478383000000001	Чувашская Республика - Чувашия, Шумерлинский район,д. Мыслец	Россия, республика Чувашская, Шумерлинский район, поселок Мыслец	0101000020E6100000588D25AC8D4547402FFB75A73BBD4B40
13384	7	66	115	10749	\N	\N	55.478383000000001	Чувашская Республика - Чувашия, Шумерлинский район, пос. Мыслец	Россия, республика Чувашская, Шумерлинский район, поселок Мыслец	0101000020E6100000588D25AC8D4547402FFB75A73BBD4B40
13440	7	66	115	13374	\N	\N	55.592708000000002	Чувашская Республика - Чувашия, Шумерлинский район, д. Молгачкино	Россия, республика Чувашская, Шумерлинский район, село Молгачкино	0101000020E6100000BCB0355B79454740EE0912DBDDCB4B40
12884	7	66	215	18373	61381	\N	55.230924000000002	с.Токаево, Зеленая, 1	Россия, республика Чувашская, Комсомольский район, село Токаево	0101000020E6100000F722DA8EA9B9474046EEE9EA8E9D4B40
13444	7	66	115	13574	\N	\N	55.598196999999999	Чувашская Республика - Чувашия, Шумерлинский район, д. Малые Туваны	Россия, республика Чувашская, Шумерлинский район, село Малые Туваны	0101000020E61000001C5F7B66494247405CC823B891CC4B40
13443	7	66	115	13504	\N	\N	55.573937999999998	Чувашская Республика - Чувашия, Шумерлинский район, д. Лесные Туваны	Россия, республика Чувашская, Шумерлинский район, село Лесные Туваны	0101000020E610000071E82D1EDE43474040F7E5CC76C94B40
13182	7	66	115	201	\N	\N	55.412615000000002	Чувашская Республика - Чувашия, Шумерлинский район, пос. Красный Октябрь	Россия, республика Чувашская, Шумерлинский район, село Красный Октябрь	0101000020E61000007D91D09673534740666B7D91D0B44B40
13452	7	66	115	13941	\N	\N	55.644424999999998	Чувашская Республика - Чувашия, Шумерлинский район, д. Кадеркино	Россия, республика Чувашская, Шумерлинский район, село Кадеркино	0101000020E61000004DD7135D17524740C6DCB5847CD24B40
13430	7	66	115	12909	\N	\N	55.413739	Чувашская Республика - Чувашия, Шумерлинский район, пос. Кабаново	Россия, республика Чувашская, Шумерлинский район, поселок Кабаново	0101000020E6100000DDEBA4BE2C414740350A4966F5B44B40
13448	7	66	115	13726	\N	\N	55.638040883147703	Чувашская Республика - Чувашия, Шумерлинский район, д. Егоркино	Россия, республика Чувашская, Шумерлинский район, село Егоркино	0101000020E61000004182E2C7982D4740EA40D653ABD14B40
13435	7	66	115	58026	\N	\N	55.557664043491002	Чувашская Республика - Чувашия, Шумерлинский район, пос. Волга	Россия, республика Чувашская, Шумерлинский район, село Волга	0101000020E6100000A9177C9A932347400A14B18861C74B40
13434	7	66	115	13087	\N	\N	55.587316000000001	Чувашская Республика - Чувашия, Шумерлинский район, д. Верхняя Кумашка	Россия, республика Чувашская, Шумерлинский район, село Верхняя Кумашка	0101000020E6100000FC56EBC4E53047407235B22B2DCB4B40
13436	7	66	115	13171	\N	\N	55.629303	Чувашская Республика - Чувашия, Шумерлинский район, д. Верхний Магарин	Россия, республика Чувашская, Шумерлинский район, село Верхний Магарин	0101000020E6100000E8A04B38F42A474029232E008DD04B40
13439	7	66	115	13308	\N	\N	55.562826000000001	Чувашская Республика - Чувашия, Шумерлинский район, д. Бреняши	Россия, республика Чувашская, Шумерлинский район, село Бреняши	0101000020E61000006005F86EF354474054ABAFAE0AC84B40
13429	7	66	115	12889	\N	\N	55.361916999999998	Чувашская Республика - Чувашия, Шумерлинский район, с. Большие Алгаши	Россия, республика Чувашская, Шумерлинский район, село Большие Алгаши	0101000020E6100000A680B4FF013A4740E76ED74B53AE4B40
13428	7	66	1210	57923	62118	\N	54.675932851648398	Чувашская Республика - Чувашия, Шемуршинский район, Чукальское сельское поселение, деревня Яблоновка, Центральная, 29	Россия, республика Чувашская, село Яблоновка	0101000020E61000009067976F7DAA4740C2A4F8F884564B40
13408	7	66	1210	11874	61757	\N	54.887501999999998	Чувашская Республика - Чувашия, Шемуршинский район, Шемуршинское сельское поселение, село Шемурша, Советская, 3		0101000020E6100000E4DA5031CEC147403A9160AA99714B40
13409	7	66	1210	11874	61893	\N	54.887501999999998	Чувашская Республика - Чувашия, Шемуршинский район, Шемуршинское сельское поселение, село Шемурша, Лесхозная, 18		0101000020E6100000E4DA5031CEC147403A9160AA99714B40
13426	7	66	1210	12761	61908	\N	54.897573000000001	Чувашская Республика - Чувашия, Шемуршинский район, Чепкас-Никольское сельское поселение, село Чепкас-Никольское, Чапаева, 24		0101000020E61000001EE21FB6F4E04740E5620CACE3724B40
13425	7	66	1210	12707	62115	\N	54.85248	Чувашская Республика - Чувашия, Шемуршинский район, Малобуяновское сельское поселение, село Трехизб-Шемурша, переулок Центральный, 2		0101000020E6100000DCF63DEAAFCB47403E3F8C101E6D4B40
13424	7	66	1210	12659	61899	\N	54.925370000000001	Чувашская Республика - Чувашия, Шемуршинский район, Трехбалтаевское сельское поселение, село Трехбалтаево, Спортивная, 9		0101000020E61000008A20CEC309D647408A592F8672764B40
13422	7	66	1210	12553	61983	\N	54.713183999999998	Чувашская Республика - Чувашия, Шемуршинский район, Старочукальское сельское поселение, деревня Старые Чукалы, Комсомольская, 79		0101000020E610000086C613419C994740E603029D495B4B40
13423	7	66	1210	12626	62677	\N	54.881048999999997	Чувашская Республика - Чувашия, Шемуршинский район, Большебуяновское сельское поселение, деревня Старая Шемурша, Чкалова, 38		0101000020E61000003677F4BF5CC947403596B036C6704B40
13427	7	66	1210	12771	61826	\N	54.699077000000003	Чувашская Республика - Чувашия, Шемуршинский район, Чукальское сельское поселение, деревня Русские Чукалы, Октябрьская, 15		0101000020E6100000779D0DF9679447406231EA5A7B594B40
13413	7	66	1210	12138	62111	\N	54.877375999999998	Чувашская Республика - Чувашия, Шемуршинский район, Шемуршинское сельское поселение, деревня Новая Шемурша, Кудряшова, 79 Б		0101000020E610000048A98427F4C44740CC2555DB4D704B40
13421	7	66	1210	12525	62795	\N	54.917245999999999	Чувашская Республика - Чувашия, Шемуршинский район, Малобуяновское сельское поселение, деревня Нижнее Буяново, Карла Маркса, 38		0101000020E610000091ED7C3F35D247408331225168754B40
13412	7	66	1210	58065	63116	\N	54.842947000000002	Чувашская Республика - Чувашия, Шемуршинский район, Шемуршинское сельское поселение, деревня Мордовские Тюки, Овражная, 1	Россия, республика Чувашская, Шемуршинский район, село Мордовкие Тюки	0101000020E6100000E753C72AA5B3474073A1F2AFE56B4B40
13420	7	66	1210	12463	61907	\N	54.871865	Чувашская Республика - Чувашия, Шемуршинский район, Малобуяновское сельское поселение, деревня Малое Буяново, Карла Маркса, 32		0101000020E610000004CAA65CE1D1474076C3B645996F4B40
13419	7	66	1210	12412	61568	\N	54.965569000000002	Чувашская Республика - Чувашия, Шемуршинский район, Карабай-Шемуршинское сельское поселение, деревня Карабай-Шемурша, Советская, 13		0101000020E61000007EFD101B2CC247400684D6C3977B4B40
13418	7	66	1210	12367	62789	\N	54.908619000000002	Чувашская Республика - Чувашия, Шемуршинский район, Большебуяновское сельское поселение, деревня Верхнее Буяново, Ленина, 60 А		0101000020E610000060E63BF889CB47401AC39CA04D744B40
13417	7	66	1210	12313	62012	\N	54.897210000000001	Чувашская Республика - Чувашия, Шемуршинский район, Большебуяновское сельское поселение, деревня Большое Буяново, Карла Маркса, 65		0101000020E6100000A0A52BD846CE474074D2FBC6D7724B40
13416	7	66	1210	12286	61910	\N	54.760708999999999	Чувашская Республика - Чувашия, Шемуршинский район, Бичурга-Баишевское сельское поселение, село Бичурга-Баишево, Мичурина, 5		0101000020E6100000B492567C43A74740ED629AE95E614B40
13415	7	66	1210	12215	62113	\N	54.943995000000001	Чувашская Республика - Чувашия, Шемуршинский район, Трехбалтаевское сельское поселение, деревня Байдеряково, Чапаева, 1		0101000020E6100000FAB48AFED0DC4740344B02D4D4784B40
13414	7	66	1210	12167	61997	\N	54.763181000000003	Чувашская Республика - Чувашия, Шемуршинский район, Бичурга-Баишевское сельское поселение, деревня Асаново, Кирова, 25		0101000020E6100000D32EA699EEAB4740DCF63DEAAF614B40
13410	7	66	1210	11961	62675	\N	54.871637	Чувашская Республика - Чувашия, Шемуршинский район, Шемуршинское сельское поселение, деревня Андреевка, Гагарина, 21		0101000020E6100000E0A293A5D6BD4740E57D1CCD916F4B40
13398	7	66	1036	57911	61906	\N	56.066972	Чувашская Республика - Чувашия, Чебоксарский район, Атлашевское сельское поселение, д.Толиково, Школьная, 1		0101000020E6100000DA8D3EE603BA4740B5DFDA8992084C40
13380	7	66	1036	33097	61823	\N	56.090376999999997	Чувашская Республика - Чувашия, Чебоксарский район, Большекатрасьское сельское поселение, д.Яуши, Садовая, 1/1		0101000020E610000083C30B22528D4740C1A73979910B4C40
13359	7	66	1036	33010	61902	\N	55.927835999999999	Чувашская Республика - Чувашия, Чебоксарский район, Янышское сельское поселение, д.Яныши, Центральная, 16		0101000020E6100000E0A0BDFA787A474096067E54C3F64B40
13407	7	66	1036	52349	62674	\N	56.090873999999999	Чувашская Республика - Чувашия, Чебоксарский район, Синьяльское сельское поселение, д.Яндово, Магазинная, 33а		0101000020E610000095641D8EAEB6474042075DC2A10B4C40
13377	7	66	1036	10433	61903	\N	56.013607999999998	Чувашская Республика - Чувашия, Чебоксарский район, Кшаушское сельское поселение, с.Янгильдино, Школьная, 33		0101000020E6100000D2E1218C9F904740637B2DE8BD014C40
13369	7	66	1036	52280	\N	\N	56.059142000000001	Чувашская Республика - Чувашия, Чебоксарский район, Ишлейское сельское поселение, д.Ядринкасы, Садовая, 24	Россия, республика Чувашская, Чебоксарский район, село Ядринкасы	0101000020E610000093A641D13C824740F7E80DF791074C40
13361	7	66	1036	52266	62028	\N	55.890255000000003	Чувашская Республика - Чувашия, Чебоксарский район, Чиршкасинское сельское поселение, д.Эндимиркасы, Октябрьская, 16		0101000020E6100000E92807B309804740DD0C37E0F3F14B40
13393	7	66	1036	32540	61824	\N	55.975465999999997	Чувашская Республика - Чувашия, Чебоксарский район, Акулевское сельское поселение, д.Шорчекасы, Шоссейная, 13		0101000020E6100000085740A19EBC4740122EE411DCFC4B40
13375	7	66	1036	33081	61822	\N	55.987991000000001	Чувашская Республика - Чувашия, Чебоксарский район, Сарабакасинское сельское поселение, д.Шоркино, Ворошилова, 9		0101000020E61000004776A565A498474005DF347D76FE4B40
13363	7	66	1036	52270	62008	\N	55.942953000000003	Чувашская Республика - Чувашия, Чебоксарский район, Чиршкасинское сельское поселение, д.Шоркасы, Солнечная, 30а		0101000020E6100000CD0182397A844740225514AFB2F84B40
13389	7	66	1036	33146	61904	\N	56.024591999999998	Чувашская Республика - Чувашия, Чебоксарский район, Шинерпосинское сельское поселение, д.Шинерпоси, Школьная, 2		0101000020E6100000897B2C7DE8AC474022DFA5D425034C40
13362	7	66	1036	9681	61821	\N	55.998815999999998	Чувашская Республика - Чувашия, Чебоксарский район, Чиршкасинское сельское поселение, д.Чиршкасы, Школьный пер, 8		0101000020E610000020240B98C0A747405B5CE333D9FF4B40
13386	7	66	1036	9681	61892	\N	55.998646423466099	Чувашская Республика - Чувашия, Чебоксарский район, Сирмапосинское сельское поселение, д.Чиршкасы, 11-ой Пятилетки, 1	Россия, республика Чувашская, Чебоксарский район, село Чиршкасы	0101000020E6100000624D6551D8A74740FF23D3A1D3FF4B40
13406	7	66	1036	11799	61905	\N	56.108663	Чувашская Республика - Чувашия, Чебоксарский район, Синьяльское сельское поселение, с.Чемурша, Магазинная, 62а		0101000020E6100000670E492D94B4474083A44FABE80D4C40
13353	7	66	1036	9243	61816	\N	55.992517999999997	Чувашская Республика - Чувашия, Чебоксарский район, Вурман-Сюктерское сельское поселение, с.Хыркасы, Ресторанная, 6		0101000020E6100000A35BAFE941B947407D586FD40AFF4B40
13390	7	66	1036	9243	61995	\N	55.992517999999997	Чувашская Республика - Чувашия, Чебоксарский район, Шинерпосинское сельское поселение, д.Хыркасы, Молодежная, 50		0101000020E6100000A35BAFE941B947407D586FD40AFF4B40
13388	7	66	1036	58003	62594	\N	56.002616000000003	Чувашская Республика - Чувашия, Чебоксарский район, Шинерпосинское сельское поселение, д.Новые Тренькасы, Молодежная, 7	Россия, республика Чувашская, Чебоксарский район, село Тренькасы	0101000020E61000003FAA61BF27B64740223999B855004C40
13402	7	66	1036	33075	61755	\N	55.999991943716203	Чувашская Республика - Чувашия, Чебоксарский район, Лапсарское сельское поселение, д.Сятракасы, Школьная, 9а	Россия, республика Чувашская, Чебоксарский район, село Сятракасы	0101000020E6100000CCB56801DA9647407D21E4BCFFFF4B40
13374	7	66	1036	33075	61889	\N	56.007432999999999	Чувашская Республика - Чувашия, Чебоксарский район, Сарабакасинское сельское поселение, д.Сятракасы, Центральная, 12		0101000020E61000005439ED2939974740A1F48590F3004C40
13352	7	66	1036	9193	61901	\N	56.123874999999998	Чувашская Республика - Чувашия, Чебоксарский район, Вурман-Сюктерское сельское поселение, п.Сюктерка, Главная, 4		0101000020E6100000B2BCAB1E3085474060E5D022DB0F4C40
13405	7	66	1036	11734	61639	\N	56.081499248013102	Чувашская Республика - Чувашия, Чебоксарский район, Синьяльское сельское поселение, с.Синьялы, Центральная, 32	Россия, республика Чувашская, Чебоксарский район, село Синьялы	0101000020E61000005D5320B3B3AE47400FD4298F6E0A4C40
13354	7	66	1036	52256	62669	\N	56.066549999999999	Чувашская Республика - Чувашия, Чебоксарский район, Синьял-Покровское сельское поселение, д.Селиванкино, Школьная, 1/1		0101000020E610000090DC9A745B8C47403FC6DCB584084C40
13350	7	66	1036	57919	62005	\N	56.083511523405903	Чувашская Республика - Чувашия, Чебоксарский район, Вурман-Сюктерское сельское поселение, д.Салабайкасы, Медицинская, 1а	Россия, республика Чувашская, Чебоксарский район, село Салабаикасы	0101000020E6100000B9196EC0E78347406A696E85B00A4C40
13355	7	66	1036	57901	61817	\N	56.042977498572697	Чувашская Республика - Чувашия, Чебоксарский район, Синьял-Покровское сельское поселение, д.Пархикасы, Садовая, 1	Россия, республика Чувашская, Чебоксарский район, село Пархикасы	0101000020E61000000C76C3B64589474077BD344580054C40
13367	7	66	1036	52278	62793	\N	56.023862000000001	Чувашская Республика - Чувашия, Чебоксарский район, Ишлейское сельское поселение, д.Олгаши, Лесная, 3		0101000020E6100000F4A5B73F177D4740FFCEF6E80D034C40
13401	7	66	1036	52333	62112	\N	56.044361722199397	Чувашская Республика - Чувашия, Чебоксарский район, Лапсарское сельское поселение, д.Ойкасы, Октябрьская, 43б	Россия, республика Чувашская, Чебоксарский район, село Ойкасы	0101000020E6100000284701A260A24740B3976DA7AD054C40
13366	7	66	1036	52277	62911	\N	56.014986999999998	Чувашская Республика - Чувашия, Чебоксарский район, Ишлейское сельское поселение, д.Мускаринкасы, Речная, 9		0101000020E610000085436FF1F0824740BD6E1118EB014C40
13379	7	66	1036	52296	62676	\N	56.053381000000002	Чувашская Республика - Чувашия, Чебоксарский район, Большекатрасьское сельское поселение, д.Малые Карачуры, Заречная, 2а		0101000020E61000006E5166834C964740289D4830D5064C40
13348	7	66	1036	32958	61863	\N	56.059463999999998	Чувашская Республика - Чувашия, Чебоксарский район, Вурман-Сюктерское сельское поселение, д.Малый Сундырь, Становая, 1а		0101000020E6100000815A0C1EA67B474009A52F849C074C40
13376	7	66	1036	52291	61440	\N	55.987709000000002	Чувашская Республика - Чувашия, Чебоксарский район, Кшаушское сельское поселение, д.Курмыши, 9-ой Пятилетки, 11	Россия, республика Чувашская, Чебоксарский район, село Курмыши	0101000020E61000008D25AC8DB1874740817B9E3F6DFE4B40
13370	7	66	1036	10047	61612	\N	56.032871	Чувашская Республика - Чувашия, Чебоксарский район, Кугесьское сельское поселение, пгт.Кугеси, Шоссейная, 17		0101000020E61000009F3C2CD49AA6474050FEEE1D35044C40
13371	7	66	1036	10047	61638	\N	56.032871	Чувашская Республика - Чувашия, Чебоксарский район, Кугесьское сельское поселение, пгт.Кугеси, Школьная, 3		0101000020E61000009F3C2CD49AA6474050FEEE1D35044C40
13373	7	66	1036	10047	61617	\N	56.032871	Чувашская Республика - Чувашия, Чебоксарский район, Кугесьское сельское поселение, пгт.Кугеси, Первомайская, 20		0101000020E61000009F3C2CD49AA6474050FEEE1D35044C40
13372	7	66	1036	10047	61617	\N	56.032871	Чувашская Республика - Чувашия, Чебоксарский район, Кугесьское сельское поселение, пгт.Кугеси, Первомайская, 13а		0101000020E61000009F3C2CD49AA6474050FEEE1D35044C40
13368	7	66	1036	52279	\N	\N	55.998775999999999	Чувашская Республика - Чувашия, Чебоксарский район, Ишлейское сельское поселение, д.Корак-Чурачики, Совхозная, 3	Россия, республика Чувашская, Чебоксарский район, село Корак-Чурачики	0101000020E6100000B2632310AF794740CD0358E4D7FF4B40
13383	7	66	1036	33116	61891	\N	55.959519999999998	Чувашская Республика - Чувашия, Чебоксарский район, Абашевское сельское поселение, д.Клычево, Школьная, 15а		0101000020E61000005DF8C1F9D4AB4740D0ED258DD1FA4B40
13365	7	66	1036	9764	61599	\N	56.023319000000001	Чувашская Республика - Чувашия, Чебоксарский район, Ишлейское сельское поселение, с.Ишлеи, Советская, 58		0101000020E6100000B5DFDA89928647400E30F31DFC024C40
13364	7	66	1036	9764	61599	\N	56.023319000000001	Чувашская Республика - Чувашия, Чебоксарский район, Ишлейское сельское поселение, с.Ишлеи, Советская, 52		0101000020E6100000B5DFDA89928647400E30F31DFC024C40
13357	7	66	1036	9415	61819	\N	55.936297000000003	Чувашская Республика - Чувашия, Чебоксарский район, Ишакское сельское поселение, с.Ишаки, Ясельная, 6		0101000020E6100000BC02D19332894740E52B8194D8F74B40
13404	7	66	1036	52340	62010	\N	56.057468	Чувашская Республика - Чувашия, Чебоксарский район, Синьяльское сельское поселение, д.Ильбеши, Школьная, 22		0101000020E6100000213EB0E3BFAC47408448861C5B074C40
13385	7	66	1036	10824	61969	\N	55.974981999999997	Чувашская Республика - Чувашия, Чебоксарский район, Сирмапосинское сельское поселение, с.Икково, Школьная, 2		0101000020E6100000535E2BA1BB9E47402618CE35CCFC4B40
13351	7	66	1036	52252	62785	\N	56.111021999999998	Чувашская Республика - Чувашия, Чебоксарский район, Вурман-Сюктерское сельское поселение, д.Вурманкасы, Приволжская, 12а		0101000020E61000009770E82D1E824740799109F8350E4C40
12892	7	66	215	18794	62101	\N	55.128089000000003	д.Татарские Шуруты, Центральная, 9		0101000020E6100000F33B4D66BCB347401AFD683865904B40
13399	7	66	1036	52252	61825	\N	56.110008177844499	Чувашская Республика - Чувашия, Чебоксарский район, Лапсарское сельское поселение, д.Вурманкасы, 2-ая Садовая, 23а	Россия, республика Чувашская, Чебоксарский район, село Вурманкасы	0101000020E6100000C7629B54348247403126FDBD140E4C40
13360	7	66	1036	52265	62788	\N	55.892127000000002	Чувашская Республика - Чувашия, Чебоксарский район, Чиршкасинское сельское поселение, д.Вурманкас-Туруново, Водопроводная, 63		0101000020E610000042D0D1AA968647407670B03731F24B40
13387	7	66	1036	58048	62939	\N	56.059022497567199	Чувашская Республика - Чувашия, Чебоксарский район, Шинерпосинское сельское поселение, д.Большое Князь-Теняково, Николаева, 37	Россия, республика Чувашская, Чебоксарский район, село Большое Князьтеняково	0101000020E6100000889E94490DB547404CDF6B088E074C40
13358	7	66	1036	52261	62109	\N	55.963827999999999	Чувашская Республика - Чувашия, Чебоксарский район, Янышское сельское поселение, д.Большие Мамыши, Школьная, 1		0101000020E61000005854C4E9247B47400B7C45B75EFB4B40
13378	7	66	1036	57862	61602	\N	56.072389492236297	Чувашская Республика - Чувашия, Чебоксарский район, Большекатрасьское сельское поселение, д.Большие Катраси, Молодежная, 1а	Россия	0101000020E61000005B9A5B21AC9447408ACBF10A44094C40
13400	7	66	1036	32585	61996	\N	56.064193000000003	Чувашская Республика - Чувашия, Чебоксарский район, Лапсарское сельское поселение, д.Большие Карачуры, Школьная, 35		0101000020E610000001A60C1CD0904740EAD0E97937084C40
13391	7	66	1036	52312	62796	\N	56.033695999999999	Чувашская Республика - Чувашия, Чебоксарский район, Шинерпосинское сельское поселение, д.Большой Чигирь, Школьная, 33		0101000020E61000002EC901BB9AB84740C500892650044C40
13382	7	66	1036	52301	62110	\N	55.964393000000001	Чувашская Республика - Чувашия, Чебоксарский район, Абашевское сельское поселение, д.Байсубаково, Родниковая, 32а		0101000020E6100000191D90847DB14740E4BED53A71FB4B40
13394	7	66	1036	58006	62605	\N	56.014916237521298	Чувашская Республика - Чувашия, Чебоксарский район, Атлашевское сельское поселение, п.Новое Атлашево, Парковая, 5	Россия, республика Чувашская, Чебоксарский район, село Атлашево	0101000020E61000007EC85BAE7EC64740F4177AC4E8014C40
13397	7	66	1036	58006	62624	\N	56.011744152022303	Чувашская Республика - Чувашия, Чебоксарский район, Атлашевское сельское поселение, п.Новое Атлашево, Кудряшова, 5	Россия, республика Чувашская, Чебоксарский район, село Атлашево	0101000020E61000008944A165DDC747404DF6CFD380014C40
13395	7	66	1036	58006	62599	\N	56.01229	Чувашская Республика - Чувашия, Чебоксарский район, Атлашевское сельское поселение, п.Новое Атлашево, 70 лет Октября, 1	Россия, республика Чувашская, Чебоксарский район, село Атлашево	0101000020E610000018CDCAF621C74740AF08FEB792014C40
13356	7	66	1036	52258	62108	\N	55.918222	Чувашская Республика - Чувашия, Чебоксарский район, Ишакское сельское поселение, д.Анаткас-Марги, Октябрьская, 41		0101000020E61000006E4F90D8EE8E4740DE3B6A4C88F54B40
13403	7	66	1036	58108	63481	\N	56.070642370298202	Чувашская Республика - Чувашия, Чебоксарский район, Синьяльское сельское поселение, с.Альгешево, Пионерская, 2	Россия	0101000020E6100000420A9E42AEAA4740ADDC0BCC0A094C40
13392	7	66	1036	11116	62673	\N	55.988213000000002	Чувашская Республика - Чувашия, Чебоксарский район, Акулевское сельское поселение, с.Акулево, Аптечная, 3		0101000020E610000029E9616875C24740B43D7AC37DFE4B40
13381	7	66	1036	10632	61959	\N	55.988619999999997	Чувашская Республика - Чувашия, Чебоксарский район, Абашевское сельское поселение, с.Абашево, Верхняя, 35		0101000020E61000004B94BDA59CAD4740F415A4198BFE4B40
13343	7	66	889	8789	61426	\N	55.727927000000001	Чувашская Республика - Чувашия, Цивильский район, Чурачикское сельское поселение, с. Чурачики, улица Ленина, д. 21	Россия, республика Чувашская, Цивильский район, село Чурачики	0101000020E61000005EA10F96B1B747400D7041B62CDD4B40
12885	7	66	889	8789	61426	\N	55.727442402309698	с.Чурачики, Ленина, 144	Россия, республика Чувашская, Цивильский район, село Чурачики	0101000020E6100000F2EEC8586DB8474051DEC7D11CDD4B40
13338	7	66	889	8562	62686	\N	55.803508999999998	Чувашская Республика - Чувашия, Цивильский район, Чиричкасинское сельское поселение, д. Чиричкасы, улица Молодежная, д. 20		0101000020E6100000A724EB7074D1474055850662D9E64B40
13323	7	66	889	7835	62716	\N	55.788808000000003	Чувашская Республика - Чувашия, Цивильский район, Опытное сельское поселение, д. Первое Чемерчеево, улица Молодежная, д. 1А		0101000020E6100000365A0EF450B947405E6919A9F7E44B40
13331	7	66	889	8232	62671	\N	55.824399999999997	Чувашская Республика - Чувашия, Цивильский район, Конарское сельское поселение, д. Хорамалы, улица И. Викторова, д. 29		0101000020E6100000EE409DF2E8E0474044696FF085E94B40
13304	7	66	889	6972	62897	\N	55.862535000000001	Чувашская Республика - Чувашия, Цивильский район, Богатыревское сельское поселение, д. Унгасемы, улица Дружбы, д. 4		0101000020E61000009FE57970779C4740E353008C67EE4B40
13326	7	66	889	7971	62106	\N	55.725422000000002	Чувашская Республика - Чувашия, Цивильский район, Медикасинское сельское поселение, д. Тюрары, улица Животноводов, д. 48В		0101000020E61000001895D40968AE474043E6CAA0DADC4B40
13335	7	66	889	8462	62781	\N	55.881742000000003	Чувашская Республика - Чувашия, Цивильский район, Таушкасинское сельское поселение, д. Тюнзыры, улица Новая, д. 28		0101000020E6100000ACA92C0ABBC447403CC1FEEBDCF04B40
13332	7	66	889	8282	62007	\N	55.910473000000003	Чувашская Республика - Чувашия, Цивильский район, Тувсинское сельское поселение, д. Тувси, улица Октября, д.6		0101000020E61000008F52094FE8BD47400D7217618AF44B40
13337	7	66	889	8537	61858	\N	55.860004000000004	Чувашская Республика - Чувашия, Цивильский район, Таушкасинское сельское поселение, д. Таушкасы, улица Школьная, д. 6		0101000020E61000001DE6CB0BB0C94740F0366F9C14EE4B40
13341	7	66	889	8711	62687	\N	55.700820383378598	Чувашская Республика - Чувашия, Цивильский район, Поваркасинское сельское поселение, д. Таганы, улица Центральная, д. 47	Россия, республика Чувашская, Цивильский район, село Таганы	0101000020E6100000AF43352559BB4740FD304278B4D94B40
13303	7	66	889	6891	62654	\N	55.866838999999999	Чувашская Республика - Чувашия, Цивильский район, Богатыревское сельское поселение, д. Сюлескеры, улица Путёвая, д. 15А		0101000020E610000028999CDA19AC4740DCF29194F4EE4B40
13328	7	66	889	8094	62668	\N	55.770325	Чувашская Республика - Чувашия, Цивильский район, Первостепановское сельское поселение, д. Степное Тугаево, улица Молодежная, д. 12		0101000020E6100000BB0A293FA9BC4740462575029AE24B40
13327	7	66	889	8026	62670	\N	55.748787	Чувашская Республика - Чувашия, Цивильский район, Первостепановское сельское поселение, с. Первое Степаново, улица Николаева, д. 35		0101000020E6100000FFD0CC936BC44740C1559E40D8DF4B40
13329	7	66	889	8129	62009	\N	55.893025999999999	Чувашская Республика - Чувашия, Цивильский район, Конарское сельское поселение, д. Старое Акташево, улица Центральная, д.41А		0101000020E6100000D1CC936B0ADA4740253D0CAD4EF24B40
13333	7	66	889	8328	62782	\N	55.890335	Чувашская Республика - Чувашия, Цивильский район, Тувсинское сельское поселение, д. Синьялы, улица Синьяльская, д. 67		0101000020E6100000A4DE5339ED994740F9BD4D7FF6F14B40
13314	7	66	889	7453	61992	\N	55.853439999999999	Чувашская Республика - Чувашия, Цивильский район, Рындинское сельское поселение, с. Рындино, улица Центральная, д. 61		0101000020E6100000D5E76A2BF6B74740938C9C853DED4B40
13340	7	66	889	8680	61861	\N	55.712431000000002	Чувашская Республика - Чувашия, Цивильский район, Поваркасинское сельское поселение, д. Поваркасы, улица Школьная, д. 5		0101000020E61000007C9DD497A5C147400BD462F030DB4B40
13312	7	66	889	7340	62899	\N	55.902312999999999	Чувашская Республика - Чувашия, Цивильский район, Второвурманкасинское сельское поселение, д. Первомайское, улица Рыбацкая, д. 79Б		0101000020E6100000F25CDF8783AC4740B9E00CFE7EF34B40
13316	7	66	889	7527	62900	\N	55.866146999999998	Чувашская Республика - Чувашия, Цивильский район, Рындинское сельское поселение, д. Первое Семеново, улица Родниковая, д. 15		0101000020E6100000CD3AE3FBE2B04740A643A7E7DDEE4B40
13321	7	66	889	7741	61423	\N	55.853642999999998	Чувашская Республика - Чувашия, Цивильский район, Опытное сельское поселение, п. Опытный, улица Дорожная, д. 7	Россия, республика Чувашская, Цивильский район, село Опытный	0101000020E61000004D4D8237A4BF4740CBBA7F2C44ED4B40
13339	7	66	889	8625	62783	\N	55.814036999999999	Чувашская Республика - Чувашия, Цивильский район, Чиричкасинское сельское поселение, д. Нюрши, улица Советская, д. 79		0101000020E6100000C7F0D8CF62CB4740F25D4A5D32E84B40
13306	7	66	889	7038	62893	\N	55.807485999999997	Чувашская Республика - Чувашия, Цивильский район, Михайловское сельское поселение, д. Нижние Кунаши, улица Центральная, д. 1А		0101000020E6100000E46A64575AAC47402AFD84B35BE74B40
13315	7	66	889	7471	62898	\N	55.846997000000002	Чувашская Республика - Чувашия, Цивильский район, Рындинское сельское поселение, д. Нижние Кибекси, переулок Школьный, д. 4		0101000020E61000002C6684B707AD4740B267CF656AEC4B40
13320	7	66	889	7692	62001	\N	55.774349999999998	Чувашская Республика - Чувашия, Цивильский район, Игорварское сельское поселение, д. Мунсют, улица Молодежная, д. 14		0101000020E61000007C0F971C77CE47402CD49AE61DE34B40
13305	7	66	889	7003	61980	\N	55.825290000000003	Чувашская Республика - Чувашия, Цивильский район, Михайловское сельское поселение, д. Михайловка, улица Чапаева, д. 14		0101000020E61000003B53E8BCC6B04740A1DB4B1AA3E94B40
13324	7	66	889	7885	62656	\N	55.701075000000003	Чувашская Республика - Чувашия, Цивильский район, Медикасинское сельское поселение, д. Медикасы, улица Просвещения, д. 3		0101000020E61000003BAC70CB47AC474088855AD3BCD94B40
13307	7	66	889	7096	62653	\N	55.903978000000002	Чувашская Республика - Чувашия, Цивильский район, Малоянгорчинское сельское поселение, д. Малое Янгорчино, улица Солнечная, д. 7		0101000020E6100000E0F60489EDA64740D926158DB5F34B40
13330	7	66	889	8186	61815	\N	55.864731999999997	Чувашская Республика - Чувашия, Цивильский район, Конарское сельское поселение, пос. Конар, улица Школьная, д. 4		0101000020E6100000064B75012FDB4740FFE6C589AFEE4B40
13342	7	66	889	8759	62822	\N	55.748189000000004	Чувашская Республика - Чувашия, Цивильский район, Чурачикское сельское поселение, д. Камайкасы, улица Шоссейная, д. 11		0101000020E6100000D8F0F44A59B447400D1D3BA8C4DF4B40
13322	7	66	889	7799	62655	\N	55.793939999999999	Чувашская Республика - Чувашия, Цивильский район, Опытное сельское поселение, д. Искеево-Яндуши, переулок Клубный, д. 9		0101000020E610000092955F0663C447403D7E6FD39FE54B40
13336	7	66	889	8467	62107	\N	55.846760000000003	Чувашская Республика - Чувашия, Цивильский район, Таушкасинское сельское поселение, д. Имбюрти, улица Центральная, д. 34		0101000020E61000004C8A8F4FC8D44740CEC7B5A162EC4B40
13319	7	66	889	7668	62092	\N	55.777448999999997	Чувашская Республика - Чувашия, Цивильский район, Игорварское сельское поселение, с. Игорвары, улица Молодежная, д. 11		0101000020E610000061C1FD8007D4474069A7E67283E34B40
13310	7	66	889	7261	62767	\N	55.92718	Чувашская Республика - Чувашия, Цивильский район, Малоянгорчинское сельское поселение, д. Елаши, улица Пушкина, д. 41Б		0101000020E6100000A818E76F429F4740ADC090D5ADF64B40
13317	7	66	889	7580	62771	\N	55.931547000000002	Чувашская Республика - Чувашия, Цивильский район, Булдеевское сельское поселение, д. Вурумсют, Базовый проезд, д. 4		0101000020E61000002332ACE28DCC4740EDD79DEE3CF74B40
13313	7	66	889	57908	61894	\N	55.740317743364699	Цивильский район, д. Вторые Вурманкасы,ул.Центральная,д.7А, здание бывшего сельского клуба	Россия, республика Чувашская, Цивильский район, село Вурманкасы 2-е	0101000020E61000003C86C77E16B34740F0517FBDC2DE4B40
13311	7	66	889	57908	61894	\N	55.737464197140902	Чувашская Республика - Чувашия, Цивильский район, Второвурманкасинское сельское поселение, д. Вторые Вурманкасы, улица Центральная, д. 7А	Россия, республика Чувашская, Цивильский район, село Вурманкасы 2-е	0101000020E610000015C8EC2C7AB347401AFD683865DE4B40
12894	7	66	889	45611	62637	\N	55.692236999999999	д.Вотланы, Мира, 1		0101000020E61000004F401361C3B54740630AD6389BD84B40
13309	7	66	889	7186	62657	\N	55.891571999999996	Чувашская Республика - Чувашия, Цивильский район, Малоянгорчинское сельское поселение, д. Визикасы, улица Советская, д. 46		0101000020E61000002881CD39789E4740C00303081FF24B40
13318	7	66	889	7617	61994	\N	55.906502000000003	Чувашская Республика - Чувашия, Цивильский район, Булдеевское сельское поселение, д. Булдеево, улица Садовая, д. 1Б		0101000020E61000005723BBD232CE47401AE1ED4108F44B40
13325	7	66	889	7950	62787	\N	55.701749	Чувашская Республика - Чувашия, Цивильский район, Медикасинское сельское поселение, д. Борзайкасы, улица Колхозная, д. 26		0101000020E61000003EAF78EA91B24740178046E9D2D94B40
13302	7	66	889	6868	62770	\N	55.814836	Чувашская Республика - Чувашия, Цивильский район, Богатыревское сельское поселение, д. Большие Тиуши, улица Молодежная, д. 32		0101000020E6100000A3E8818FC1A847403ECDC98B4CE84B40
13301	7	66	889	6822	61976	\N	55.851878999999997	Чувашская Республика - Чувашия, Цивильский район, Богатыревское сельское поселение, с. Богатырево, улица Восточная, д. 3		0101000020E6100000DA73999A04A547401893FE5E0AED4B40
13308	7	66	889	7172	62895	\N	55.920436000000002	Чувашская Республика - Чувашия, Цивильский район, Малоянгорчинское сельское поселение, д. Байдуши, улица Гагарина, д. 17		0101000020E610000024D40CA9A2A84740D107CBD8D0F54B40
13334	7	66	889	8383	62024	\N	55.918908000000002	Чувашская Республика - Чувашия, Цивильский район, Таушкасинское сельское поселение, д. Байгеево, улица Средняя, д. 18Б		0101000020E610000021904B1C79C44740320400C79EF54B40
13289	7	66	546	6202	62093	\N	55.712927999999998	Чувашская Республика - Чувашия, Урмарский район, Челкасинское сельское поселение, д. Ямбай, ул. Зеленая, д. 46		0101000020E6100000228E75711BF947408B33863941DB4B40
13298	7	66	546	6626	61847	\N	55.632608858642001	Чувашская Республика - Чувашия, Урмарский район, Шоркистринское сельское поселение, станция Шоркистры, ул. Центральная, д. 56	Россия, республика Чувашская, Урмарский район, село Шоркистры	0101000020E6100000B3CEF8BEB8DE4740E013EB54F9D04B40
13297	7	66	546	6626	61847	\N	55.643572268513601	Чувашская Республика - Чувашия, Урмарский район, Шоркистринское сельское поселение, село Шоркистры, ул. Центральная, д.56	Россия, республика Чувашская, Урмарский район, село Шоркистры	0101000020E6100000A06CCA15DEDF4740874F3A9160D24B40
13294	7	66	546	6458	61977	\N	55.745964999999998	Чувашская Республика - Чувашия, Урмарский район, Шихабыловское сельское поселение, д. Шихабылово, ул. Новая, д. 1		0101000020E6100000BB9A3C6535ED4740F67AF7C77BDF4B40
13292	7	66	546	6350	61919	\N	55.554347999999997	Чувашская Республика - Чувашия, Урмарский район, Шигалинское сельское поселение, с. Шигали, ул. Центральная, д. 7		0101000020E61000003868AF3E1E0448402F4D11E0F4C64B40
13262	7	66	546	4769	62880	\N	55.750943591204198	Чувашская Республика - Чувашия, Урмарский район, Бишевское сельское поселение, д. Шибулаты, ул. Свердлова, д. 47	Россия, республика Чувашская, Урмарский район, село Шибулаты	0101000020E610000089B48D3F51D947404F90D8EE1EE04B40
13290	7	66	546	6246	61958	\N	55.671650999999997	Чувашская Республика - Чувашия, Урмарский район, Чубаевское сельское поселение, д. Чубаево, ул. Школьная, д. 3		0101000020E6100000BB7CEBC37AEF4740B0A9F3A8F8D54B40
13273	7	66	546	5349	62646	\N	55.725062000000001	Чувашская Республика - Чувашия, Урмарский район, Ковалинское сельское поселение, д. Чирш-Сирма, ул. Ленина, д. 55а		0101000020E610000018080264E810484043C9E4D4CEDC4B40
13286	7	66	546	6024	61888	\N	55.702551	Чувашская Республика - Чувашия, Урмарский район, Челкасинское сельское поселение, с. Челкасы, ул. К. Маркса, д. 59		0101000020E610000074417DCB9CF44740D462F030EDD94B40
13300	7	66	546	6759	62768	\N	55.680123000000002	Чувашская Республика - Чувашия, Урмарский район, Шоркистринское сельское поселение, д. Хоруй, ул. Зеленая, д. 27		0101000020E610000017B6662B2FD34740F3203D450ED74B40
13257	7	66	546	4449	61636	\N	55.683233999999999	Чувашская Республика - Чувашия, Урмарский район, Урмарское городское поселение, пгт. Урмары, ул. Мира, д. 6		0101000020E6100000AB24B20FB2F84740F4C1323674D74B40
13256	7	66	546	4449	61634	\N	55.683233999999999	Чувашская Республика - Чувашия, Урмарский район, Урмарское городское поселение, пгт. Урмары, ул. Ленина, д. 16		0101000020E6100000AB24B20FB2F84740F4C1323674D74B40
13283	7	66	546	5897	62122	\N	55.550483	Чувашская Республика - Чувашия, Урмарский район, Тегешевское сельское поселение, д. Тегешево, ул. Школьная, д. 5		0101000020E6100000CD5B751DAA0B48408200193A76C64B40
13279	7	66	546	5662	62089	\N	55.755656999999999	Чувашская Республика - Чувашия, Урмарский район, Кульгешское сельское поселение, д. Тансарино, ул. Ленина, д.7		0101000020E61000005680EF366FFE47402AFF5A5EB9E04B40
13276	7	66	546	58027	62794	\N	55.6453976554753	Чувашская Республика - Чувашия, Урмарский район, Кудеснерское сельское поселение, д. Старые Щелканы, ул. Центральная, д. 33	Россия, республика Чувашская, Урмарский район, село Старые Шелканы	0101000020E6100000B1FA230C03024840B073D3669CD24B40
13282	7	66	546	5825	61597	\N	55.685730999999997	Чувашская Республика - Чувашия, Урмарский район, Староурмарское сельское поселение, д. Старые Урмары, ул. Школьная, д. 6		0101000020E610000057D0B4C4CAFE47403B6D8D08C6D74B40
13288	7	66	546	6169	62090	\N	55.719996999999999	Чувашская Республика - Чувашия, Урмарский район, Челкасинское сельское поселение, д. Старое Шептахово, ул. Гагарина, д. 8		0101000020E6100000CE8AA8893EED4740EB1B98DC28DC4B40
13272	7	66	546	5313	62891	\N	55.669904000000002	Чувашская Республика - Чувашия, Урмарский район, Ковалинское сельское поселение, д. Старое Муратово, ул. Новая, д. 4а		0101000020E6100000E256410C740F4840D4BA0D6ABFD54B40
13278	7	66	546	5634	62649	\N	55.736584000000001	Чувашская Республика - Чувашия, Урмарский район, Кульгешское сельское поселение, д. Ситмиши, ул. Школьная, д. 66		0101000020E610000069A7E67283F74740E1606F6248DE4B40
13271	7	66	546	5257	62885	\N	55.728337000000003	Чувашская Республика - Чувашия, Урмарский район, Ковалинское сельское поселение, д. Систеби, ул. Е. Степановой, д. 16а		0101000020E6100000889D29745E0B4840BFBB95253ADD4B40
13296	7	66	546	6584	62714	\N	55.793692999999998	Чувашская Республика - Чувашия, Урмарский район, Шихабыловское сельское поселение, д. Сине-Кинчеры, ул. Школьная, д. 7		0101000020E610000020EEEA5564F84740350873BB97E54B40
13269	7	66	546	5158	62884	\N	55.724611000000003	Чувашская Республика - Чувашия, Урмарский район, Большеяниковское сельское поселение, д. Саруй, ул. Молодежная, д. 2а		0101000020E610000028806264C9D6474033A9A10DC0DC4B40
13268	7	66	546	5090	62088	\N	55.717472000000001	Чувашская Республика - Чувашия, Урмарский район, Большеяниковское сельское поселение, д. Орнары, ул. Октябрьская, д. 55		0101000020E610000056EF703B34DA4740DAE55B1FD6DB4B40
13265	7	66	546	4935	62882	\N	55.697414910117402	Чувашская Республика - Чувашия, Урмарский район, Большечакинское сельское поселение, д. Новое Шептахово, ул. Новая, д. 2	Россия, республика Чувашская, Урмарский район, село Новое Шептахово	0101000020E610000061C3D32B65ED4740B35E0CE544D94B40
13284	7	66	546	5948	62890	\N	55.607579999999999	Чувашская Республика - Чувашия, Урмарский район, Тегешевское сельское поселение, д. Новое Муратово, ул. Кооперативная, д. 7		0101000020E6100000C2A563CE3308484012DA722EC5CD4B40
13260	7	66	546	4670	62875	\N	55.670538999999998	Чувашская Республика - Чувашия, Урмарский район, Арабосинское сельское поселение, д. Новое Исаково, ул. Ленина, д. 5а		0101000020E61000006747AAEFFCF64740A5D8D138D4D54B40
13280	7	66	546	5752	61975	\N	55.622588	Чувашская Республика - Чувашия, Урмарский район, Мусирминское сельское поселение, с. Мусирмы, ул. Гагарина, д. 35		0101000020E6100000B058C345EEFD4740E770ADF6B0CF4B40
13264	7	66	546	4872	\N	\N	55.694392999999998	Чувашская Республика - Чувашия, Урмарский район, Большечакинское сельское поселение, д. Малое Яниково, ул. Ракета, д. 59	Россия, республика Чувашская, Урмарский район, село Малое Яниково	0101000020E6100000ACAB02B518E2474021C9ACDEE1D84B40
13277	7	66	546	5551	62888	\N	55.759841000000002	Чувашская Республика - Чувашия, Урмарский район, Кульгешское сельское поселение, д. Кульгеши, ул. Школьная, д. 22		0101000020E61000006825ADF886FA474079944A7842E14B40
13274	7	66	546	5407	61886	\N	55.626136000000002	Чувашская Республика - Чувашия, Урмарский район, Кудеснерское сельское поселение, д. Кудеснеры, ул. Виськил, д. 8		0101000020E6100000D192C7D3F2F54740946C753925D04B40
13235	7	66	546	3354	61973	\N	55.677463000000003	Чувашская Республика - Чувашия, Урмарский район, Ковалинское сельское поселение, с. Ковали, ул. Ленина, д. 43		0101000020E6100000F304C24EB106484002A08A1BB7D64B40
13267	7	66	546	5019	\N	\N	55.724657000000001	Чувашская Республика - Чувашия, Урмарский район, Большеяниковское сельское поселение, д. Карак-Сирмы, ул. Гагарина, д. 12а	Россия, республика Чувашская, Урмарский район, село Карак-Сирмы	0101000020E610000062BA10AB3FE04740A3E8818FC1DC4B40
13299	7	66	546	6736	62652	\N	55.676955999999997	Чувашская Республика - Чувашия, Урмарский район, Шоркистринское сельское поселение, д. Ичеснер-Атаево, ул. Центральная, д. 11		0101000020E610000067B4554964DB47405D6A847EA6D64B40
13275	7	66	546	5444	62764	\N	55.652785999999999	Чувашская Республика - Чувашия, Урмарский район, Кудеснерское сельское поселение, д. Избеби, ул. Крупской, д. 1		0101000020E610000008E412471EFE4740B1A4DC7D8ED34B40
13295	7	66	546	6528	62892	\N	55.773378000000001	Чувашская Республика - Чувашия, Урмарский район, Шихабыловское сельское поселение, с. Вознесенское, ул. Центральная, д. 15		0101000020E610000086FF740305F2474013B9E00CFEE24B40
13270	7	66	546	5180	62824	\N	55.703226000000001	Чувашская Республика - Чувашия, Урмарский район, Ковалинское сельское поселение, д. Буинск, ул. И. Метри, д. 7а		0101000020E6100000FCA6B052410B484034D93F4F03DA4B40
13266	7	66	546	5014	62883	\N	55.729847999999997	Чувашская Республика - Чувашия, Урмарский район, Большеяниковское сельское поселение, д. Большое Яниково, ул. К. Маркса, д. 98		0101000020E610000030D5CC5A0AE647408786C5A86BDD4B40
13263	7	66	546	4836	62692	\N	55.699193000000001	Чувашская Республика - Чувашия, Урмарский район, Большечакинское сельское поселение, д. Большие Чаки, ул. Школьная, д. 20		0101000020E6100000DA0242EBE1E74740CB4BFE277FD94B40
12898	7	66	215	19125	62029	\N	55.264045000000003	д.Сюрбей-Токаево, Пожеданова, 2а		0101000020E6100000E3C281902CB447400FD6FF39CCA14B40
13261	7	66	546	4747	61885	\N	55.766495999999997	Чувашская Республика - Чувашия, Урмарский район, Бишевское сельское поселение, д. Бишево, ул. Новая, д. 7		0101000020E6100000D89DEE3CF1E44740E5417A8A1CE24B40
13291	7	66	546	6301	62651	\N	55.670067000000003	Чувашская Республика - Чувашия, Урмарский район, Чубаевское сельское поселение, с. Батеево, ул. Гоголя, д. 9		0101000020E6100000B01BB62DCAE847407E9065C1C4D54B40
13259	7	66	546	4591	61637	\N	55.645226999999998	Чувашская Республика - Чувашия, Урмарский район, Арабосинское сельское поселение, д. Арабоси, ул. Школьная, д. 16		0101000020E6100000C0046EDDCDF3474083BF5FCC96D24B40
13287	7	66	546	6098	62091	\N	55.720089000000002	Чувашская Республика - Чувашия, Урмарский район, Челкасинское сельское поселение, д. Анаткасы, ул. Школьная, д. 23		0101000020E6100000A374E95F92F64740CC9A58E02BDC4B40
13252	7	66	501	4215	62878	\N	55.072122999999998	Чувашская Республика - Чувашия, Порецкий район, Сыресинское сельское поселение, село Сыреси, ул.Октябрьская, д.184		0101000020E6100000F5108DEE203447400B2593533B894B40
13246	7	66	501	3890	62086	\N	55.141928	Чувашская Республика - Чувашия, Порецкий район, Сиявское сельское поселение, село Сиява, ул.Ленина, д.104		0101000020E6100000780E65A88A4147407F315BB22A924B40
13250	7	66	501	4099	62085	\N	55.106313999999998	Чувашская Республика - Чувашия, Порецкий район, Семеновское сельское поселение, село Семеновское, ул.Азина, д.6		0101000020E610000044FCC3961E1B4740B08D78B29B8D4B40
13233	7	66	501	3248	62881	\N	55.234269914322901	Чувашская Республика - Чувашия, Порецкий район, Козловское сельское поселение, село Ряпино, ул.Ульянова, д.31	Россия, республика Чувашская, Порецкий район, село Ряпино	0101000020E6100000B3614D65512447408B37328FFC9D4B40
13255	7	66	501	4390	62685	\N	55.081162999999997	Чувашская Республика - Чувашия, Порецкий район, Рындинское сельское поселение, село Рындино, ул.Кооперативная, д.33		0101000020E6100000410E4A98692747409752978C638A4B40
13254	7	66	501	4323	62765	\N	55.037779	Чувашская Республика - Чувашия, Порецкий район, Сыресинское сельское поселение, село Раздольное, ул.Курмыш, д.48		0101000020E61000006FB9FAB1492C4740E0BC38F1D5844B40
13244	7	66	501	3692	61884	\N	55.193674000000001	Чувашская Республика - Чувашия, Порецкий район, Порецкое сельское поселение, село Порецкое, пер.Школьный, д.4		0101000020E61000004FCC7A3194294740F20A444FCA984B40
13245	7	66	501	3692	61957	\N	55.193674000000001	Чувашская Республика - Чувашия, Порецкий район, Порецкое сельское поселение, село Порецкое, ул.им.Крупской, д.26 А		0101000020E61000004FCC7A3194294740F20A444FCA984B40
13242	7	66	501	3692	61974	\N	55.193674000000001	Чувашская Республика - Чувашия, Порецкий район, Порецкое сельское поселение, село Порецкое, ул.Ленина, д.4		0101000020E61000004FCC7A3194294740F20A444FCA984B40
13243	7	66	501	3692	61846	\N	55.193674000000001	Чувашская Республика - Чувашия, Порецкий район, Порецкое сельское поселение, село Порецкое, ул.Комсомольская, д.11		0101000020E61000004FCC7A3194294740F20A444FCA984B40
13251	7	66	501	4193	62087	\N	55.081591000000003	Чувашская Республика - Чувашия, Порецкий район, Семеновское сельское поселение, село Полибино, ул.Панова, д.30		0101000020E6100000D26EF4311F184740F052EA92718A4B40
13240	7	66	501	3584	62647	\N	55.155493999999997	Чувашская Республика - Чувашия, Порецкий район, Никулинское сельское поселение, село Никулино, ул.Николаева, д.35		0101000020E61000001FD8F15F20084740B35C363AE7934B40
13248	7	66	501	3989	62838	\N	55.182248000000001	Чувашская Республика - Чувашия, Порецкий район, Сиявское сельское поселение, деревня Никольское, ул.Центральная, д.49		0101000020E61000001AF9BCE2A94B474076E107E753974B40
13239	7	66	501	3571	61633	\N	55.125684999999997	Чувашская Республика - Чувашия, Порецкий район, Напольновское сельское поселение, село Напольное, ул.Ленина, д.24 А		0101000020E6100000CD5A0A48FB2D4740834C327216904B40
13237	7	66	501	3471	62667	\N	55.034621000000001	Чувашская Республика - Чувашия, Порецкий район, Мишуковское сельское поселение, село Мишуково, ул.Северная, д.1 А		0101000020E610000081D1E5CDE11247409E60FF756E844B40
13253	7	66	501	4279	62869	\N	55.050488000000001	Чувашская Республика - Чувашия, Порецкий район, Сыресинское сельское поселение, село Любимовка, ул.Мухоморова, д.87		0101000020E61000005A2A6F4738354740946B0A6476864B40
13236	7	66	501	3367	62915	\N	55.230115789349199	Чувашская Республика - Чувашия, Порецкий район, Кудеихинское сельское поселение, село Кудеиха, ул.Советская, д.58	Россия, республика Чувашская, Порецкий район, село Кудеиха	0101000020E6100000DE3B6A4C88354740A724EB70749D4B40
13232	7	66	501	3136	62643	\N	55.262720999999999	Чувашская Республика - Чувашия, Порецкий район, Козловское сельское поселение, село Козловка, ул.Школьная, д.200		0101000020E610000022895E46B1224740787C7BD7A0A14B40
13234	7	66	501	3264	62909	\N	55.217978000000002	Чувашская Республика - Чувашия, Порецкий район, с.Кожевенное, ул.Чапаева, д.24		0101000020E6100000C2137AFD49424740AE9FFEB3E69B4B40
13238	7	66	501	3475	62763	\N	55.021349000000001	Чувашская Республика - Чувашия, Порецкий район, д.Ивановка, ул.Советская, д.10 б		0101000020E6100000E259828C80144740B2666490BB824B40
13247	7	66	501	3956	62712	\N	55.102694	Чувашская Республика - Чувашия, Порецкий район, Сиявское сельское поселение, пос.Долгая Поляна, ул.Почтовая, д.11		0101000020E6100000F12F82C64C4A47406ABFB513258D4B40
13249	7	66	501	4078	62084	\N	55.126668000000002	Чувашская Республика - Чувашия, Порецкий район, Сиявское сельское поселение, село Гарт, ул.Гагарина, д.31 А		0101000020E61000005BB4006DAB55474091B932A836904B40
12864	7	66	215	17368	62064	\N	55.161614999999998	д.Степные Шихазаны, Садовая, 39		0101000020E61000001B4B581B63CB474082C5E1CCAF944B40
12630	7	66	215	6205	62139	\N	55.172911999999997	д.Старые Мураты, Колхозная, 4		0101000020E61000009D64ABCB29B94740008BFCFA21964B40
13230	7	66	501	3022	62081	\N	55.195118000000001	Чувашская Республика - Чувашия, Порецкий район, Анастасовское сельское поселение, деревня Бахмутово, ул.Бахмутово, д.58 А		0101000020E6100000DAAB8F87BE1F4740336E6AA0F9984B40
13241	7	66	501	3680	62644	\N	55.135576999999998	Чувашская Республика - Чувашия, Порецкий район, Октябрьское сельское поселение, село Антипинка, ул.Тракторная, д.5		0101000020E6100000348463963D1F47407E8B4E965A914B40
13231	7	66	501	3125	62083	\N	55.180480000000003	Чувашская Республика - Чувашия, Порецкий район, Анастасовское сельское поселение, село Анастасово, ул.Анастасово-1, д. 26 А		0101000020E6100000F419506F461F474082CAF8F719974B40
13083	7	66	6914	40483	10017	\N	56.107046752421802	Чувашская Республика - Чувашия, город Новочебоксарск, ул.Комсомольская, д.3А	Россия, республика Чувашская, Новочебоксарск городской округ	0101000020E61000000114234BE6C04740451152B7B30D4C40
13045	7	66	1445	26253	\N	\N	55.929999000000002	Чувашская Республика - Чувашия, Моргаушский район, Сятракасинское сельское поселение, д.Ятманкино, ул.Центральная, д.39	Россия, республика Чувашская, Моргаушский район, село Ятманкино	0101000020E61000009D6516A1D86A474007280D350AF74B40
13070	7	66	1445	27391	61882	\N	55.990524000000001	Чувашская Республика - Чувашия, Моргаушский район, Ярославское сельское поселение, д.Ярославка, ул.Центральная, д.5		0101000020E61000009DF3531C074E474099F38C7DC9FE4B40
13067	7	66	1445	57918	62004	\N	56.002839616985597	Чувашская Республика - Чувашия, Моргаушский район, Ярабайкасинское сельское поселение, д.Ярабайкасы, ул.Молодежная, д.16	Россия, республика Чувашская, Моргаушский район, село Ярабаикасы	0101000020E61000001CD0D2156C714740718FA50F5D004C40
13063	7	66	1445	27087	61968	\N	55.851050000000001	Чувашская Республика - Чувашия, Моргаушский район, Юськасинское сельское поселение, с.Юськасы, ул.Центральная, д.58		0101000020E61000008463963D0962474062A1D634EFEC4B40
13062	7	66	1445	27039	62868	\N	56.040298999999997	Чувашская Республика - Чувашия, Моргаушский район, Юнгинское сельское поселение, д.Юнгапоси, ул.Ягодная, д.21		0101000020E6100000DB4FC6F830554740DF87838428054C40
13058	7	66	1445	26857	61967	\N	56.047272999999997	Чувашская Республика - Чувашия, Моргаушский район, Юнгинское сельское поселение, с.Юнга, ул.Центральная, д.5		0101000020E61000008B87F71C58524740ED7DAA0A0D064C40
13024	7	66	1445	25269	62756	\N	56.077140999999997	Чувашская Республика - Чувашия, Моргаушский район, Большесундырское сельское поселение, д.Шупоси, ул.Центральная, д.4		0101000020E6100000B0928FDD055A474022179CC1DF094C40
13033	7	66	1445	25730	62758	\N	56.094450000000002	Чувашская Республика - Чувашия, Моргаушский район, Кадикасинское сельское поселение, д.Шомиково, ул.Шомиково, д.63		0101000020E61000005CC7B8E2E2764740B98D06F0160C4C40
13056	7	66	1445	26771	61955	\N	55.879545484572098	Чувашская Республика - Чувашия, Моргаушский район, Шатьмапосинское сельское поселение, д.Шатьмапоси, ул.Первомайская, д.9	Россия, республика Чувашская, Моргаушский район, село Шатьмапоси	0101000020E61000000ABFD4CF9B7247401F2E39EE94F04B40
13032	7	66	1445	25668	62755	\N	56.107413000000001	Чувашская Республика - Чувашия, Моргаушский район, Кадикасинское сельское поселение, д.Шатракасы, ул.Центральная, д.70		0101000020E610000019C5724BAB6D474027158DB5BF0D4C40
13029	7	66	1445	25532	62632	\N	56.125675999999999	Чувашская Республика - Чувашия, Моргаушский район, Ильинское сельское поселение, д.Чураккасы, ул.Советская, д.150		0101000020E6100000C828CFBC1C6C474030F2B22616104C40
13072	7	66	1445	27478	62102	\N	55.973329999999997	Чувашская Республика - Чувашия, Моргаушский район, Ярославское сельское поселение, с.Чемеево, ул.Центральная, д.3		0101000020E6100000F5F75278D04847409B1BD31396FC4B40
13053	7	66	1445	26616	61953	\N	55.992558000000002	Чувашская Республика - Чувашия, Моргаушский район, Хорнойское сельское поселение, д.Хорной, ул.Школьная, д.17г		0101000020E61000004966F50EB75D47400CB1FA230CFF4B40
13026	7	66	1445	25370	61954	\N	56.163488999999998	Чувашская Республика - Чувашия, Моргаушский район, Ильинское сельское поселение, д.Тренькино, ул.Новая, д.5		0101000020E61000001C40BFEFDF664740BC202235ED144C40
13046	7	66	1445	26275	62866	\N	55.944208000000003	Чувашская Республика - Чувашия, Моргаушский район, Тораевское сельское поселение, с.Тораево, ул.Школьная, д.1		0101000020E610000049D6E1E82A4D4740904FC8CEDBF84B40
13051	7	66	1445	26538	62634	\N	55.928839000000004	Чувашская Республика - Чувашия, Моргаушский район, Тораевское сельское поселение, д.Тойшево, ул.Володарского, д.17		0101000020E61000004165FCFB8C414740EB1F4432E4F64B40
13052	7	66	1445	26589	62862	\N	55.945120000000003	Чувашская Республика - Чувашия, Моргаушский район, Хорнойское сельское поселение, д.Тойгильдино, ул.Западная, д.56		0101000020E610000052D7DAFB54534740D46531B1F9F84B40
13057	7	66	1445	26813	62636	\N	55.857942000000001	Чувашская Республика - Чувашия, Моргаушский район, Шатьмапосинское сельское поселение, д.Тиуши, ул.Чебоксарская, д.31		0101000020E61000007009C03FA5784740B3EE1F0BD1ED4B40
13042	7	66	1445	26120	61979	\N	55.933978000000003	Чувашская Республика - Чувашия, Моргаушский район, Сятракасинское сельское поселение, д.Сятракасы, ул.Школьная, д.17		0101000020E6100000A11342075D6447407D9752978CF74B40
13061	7	66	1445	58013	62658	\N	56.043934999999998	Чувашская Республика - Чувашия, Моргаушский район, Юнгинское сельское поселение, д.Сярьмыскасы, ул.Эхменя, д.13	Россия, республика Чувашская, Моргаушский район, село Сярмыськасы	0101000020E61000005C035B25584C47402B137EA99F054C40
13049	7	66	1445	26439	62638	\N	55.902545000000003	Чувашская Республика - Чувашия, Моргаушский район, Тораевское сельское поселение, д.Сюткюль, ул.Озерная, д.11		0101000020E6100000E294B9F9464E47408C15359886F34B40
13068	7	66	1445	27298	62640	\N	56.027987000000003	Чувашская Республика - Чувашия, Моргаушский район, Ярабайкасинское сельское поселение, д.Сыбайкасы, ул.Школьная, д.2		0101000020E6100000271763601D73474049DBF81395034C40
13065	7	66	1445	27174	62817	\N	55.841549000000001	Чувашская Республика - Чувашия, Моргаушский район, Юськасинское сельское поселение, д.Старые Мадики, ул.Школьная, д.11		0101000020E6100000AC70CB47525C4740A27DACE0B7EB4B40
13036	7	66	1445	25862	62812	\N	56.050756999999997	Чувашская Республика - Чувашия, Моргаушский район, Москакасинское сельское поселение, д.Рыкакасы, ул.Озерная, д.22а		0101000020E6100000BF4692205C6D4740838593347F064C40
13037	7	66	1445	25910	61809	\N	56.058874300472297	Чувашская Республика - Чувашия, Моргаушский район, Москакасинское сельское поселение, д.Полевые Хачики, ул.Молодежная, д.34	Россия, республика Чувашская, Моргаушский район, село Полевые Хачики	0101000020E6100000AE0FEB8D5A614740D84AE82E89074C40
13044	7	66	1445	26196	62857	\N	55.912269000000002	Чувашская Республика - Чувашия, Моргаушский район, Сятракасинское сельское поселение, с.Оточево, ул.Победы, д.15		0101000020E6100000A12FBDFDB9704740CB13083BC5F44B40
13038	7	66	1445	25962	61965	\N	56.013060000000003	Чувашская Республика - Чувашия, Моргаушский район, Орининское сельское поселение, с.Оринино, ул.Центральная, д.61		0101000020E6100000D76D50FBAD674740617138F3AB014C40
13498	7	66	1445	58017	62684	\N	56.102295572545302	деревня Ойкасы, Социалистическая, 49	Россия, республика Чувашская, Моргаушский район, село Ойкасы	0101000020E610000099F1B6D26B5147407D410B09180D4C40
13054	7	66	1445	26686	61881	\N	55.910260999999998	Чувашская Республика - Чувашия, Моргаушский район, Чуманкасинское сельское поселение, д.Одаркино, ул.Школьная, д.45		0101000020E6100000BBED42739D5A474081E9B46E83F44B40
13066	7	66	1445	27212	62773	\N	55.869748000000001	Чувашская Республика - Чувашия, Моргаушский район, Юськасинское сельское поселение, д.Нижние Панклеи, ул.Центральная, д.70		0101000020E61000009FC9FE791A6A474076E107E753EF4B40
13034	7	66	1445	25796	61952	\N	56.049183999999997	Чувашская Республика - Чувашия, Моргаушский район, Москакасинское сельское поселение, д.Москакасы, ул.Московская, д.54		0101000020E6100000DFA815A6EF61474044BE4BA94B064C40
13020	7	66	1445	25012	61626	\N	55.963268999999997	Чувашская Республика - Чувашия, Моргаушский район, Моргаушское сельское поселение, с.Моргауши, ул.Чапаева, д.39в		0101000020E61000004D13B69F8C63474014200A664CFB4B40
13019	7	66	1445	25012	61807	\N	55.963268999999997	Чувашская Республика - Чувашия, Моргаушский район, Моргаушское сельское поселение, с.Моргауши, ул. Красная Площадь, д.5		0101000020E61000004D13B69F8C63474014200A664CFB4B40
13018	7	66	1445	25012	61670	\N	55.963268999999997	Чувашская Республика - Чувашия, Моргаушский район, Моргаушское сельское поселение, с.Моргауши, ул.50 лет Октября, д.15		0101000020E61000004D13B69F8C63474014200A664CFB4B40
13041	7	66	1445	26097	62760	\N	56.014695000000003	Чувашская Республика - Чувашия, Моргаушский район, Орининское сельское поселение, д.Молгачкасы, ул.Центральная, д.48в		0101000020E6100000BDAAB35A606B474016359886E1014C40
13060	7	66	1445	26947	62876	\N	56.07161	Чувашская Республика - Чувашия, Моргаушский район, Юнгинское сельское поселение, д.Кубасы, ул.Победы, д.4		0101000020E61000009DBCC804FC4E4740850838842A094C40
13043	7	66	1445	26160	61966	\N	55.956637999999998	Чувашская Республика - Чувашия, Моргаушский район, Сятракасинское сельское поселение, д.Кашмаши, ул.Советская, д.82		0101000020E61000003065E08096684740300E2E1D73FA4B40
13031	7	66	1445	25627	61950	\N	56.059162000000001	Чувашская Республика - Чувашия, Моргаушский район, Кадикасинское сельское поселение, д.Калайкасы, ул.Молодежная, д.3		0101000020E6100000C8CF46AE9B7047403E95D39E92074C40
13030	7	66	1445	25575	62082	\N	56.080271000000003	Чувашская Республика - Чувашия, Моргаушский район, Кадикасинское сельское поселение, д.Кадикасы, ул.Ягодная, д.24		0101000020E61000007AA86DC3287247409BE8F351460A4C40
13055	7	66	1445	26737	62641	\N	55.868112000000004	Чувашская Республика - Чувашия, Моргаушский район, Чуманкасинское сельское поселение, д.Изедеркино, ул.30 лет Победы, д.58		0101000020E6100000EA23F0879F574740F1A1444B1EEF4B40
13064	7	66	1445	25480	62645	\N	56.003532	Чувашская Республика - Чувашия, Моргаушский район, Юськасинское сельское поселение, д.Вурманкасы, ул.Центральная, д.38		0101000020E610000001FA7DFFE6634740A73E90BC73004C40
13028	7	66	1445	25480	62642	\N	56.002233464901401	Чувашская Республика - Чувашия, Моргаушский район, Ильинское сельское поселение, д.Вурманкасы, ул.Антонова, д.74	Россия, республика Чувашская, Моргаушский район, село Вурманкасы	0101000020E6100000B22B2D23F562474069FCC22B49004C40
13012	7	66	1445	24740	62094	\N	56.105710999999999	Чувашская Республика - Чувашия, Моргаушский район, Большесундырское сельское поселение, д.Вомбакасы, ул.Хырлыхская, д.95		0101000020E6100000C423F1F274584740EAE923F0870D4C40
13021	7	66	1445	25141	61963	\N	55.861230999999997	Чувашская Республика - Чувашия, Моргаушский район, Александровское сельское поселение, д.Васькино, ул.Ленина, д.1в		0101000020E61000006155BDFC4E55474093A641D13CEE4B40
13025	7	66	1445	25331	\N	\N	56.119408999999997	Чувашская Республика - Чувашия, Моргаушский район, Большесундырское сельское поселение, с.Большое Карачкино, ул.Центральная, д.73	Россия, республика Чувашская, Моргаушский район, село Большое Карачкино	0101000020E6100000C5C6BC8E384E47408DEC4ACB480F4C40
12999	7	66	1654	52539	62630	\N	56.042400999999998	Чувашская Республика - Чувашия, Мариинско-Посадский район, Приволжское сельское поселение, д. Астакасы, Мичуринская, 15		0101000020E6100000ABB184B531E84740AA285E656D054C40
13048	7	66	1445	26401	\N	\N	55.926988000000001	Чувашская Республика - Чувашия, Моргаушский район, Тораевское сельское поселение, д.Большие Токшики, ул.Клубная, д.6	Россия, республика Чувашская, Моргаушский район, село Большие Токшики	0101000020E6100000DCBDDC274753474069E4F38AA7F64B40
13023	7	66	1445	25235	62754	\N	56.090688	Чувашская Республика - Чувашия, Моргаушский район, Большесундырское сельское поселение, д.Большие Татаркасы, ул.Пакшандаева, 17а		0101000020E6100000A3CC069964604740E01115AA9B0B4C40
13502	7	66	1445	16323	62681	\N	56.1108781830495	село Большой Сундырь, Советская, 44	Россия, республика Чувашская, Моргаушский район, село Большая Сундырь	0101000020E610000095B54DF1B85E474046EC1340310E4C40
13022	7	66	1445	16323	61572	\N	56.111021999999998	Чувашская Республика - Чувашия, Моргаушский район, Большесундырское сельское поселение, с.Большой Сундырь, ул.Ленина, д.16		0101000020E610000082FE428F185F4740799109F8350E4C40
13040	7	66	1445	26049	62852	\N	56.003115000000001	Чувашская Республика - Чувашия, Моргаушский район, Орининское сельское поселение, д.Басурманы, ул.Главная, д.42		0101000020E6100000D8F50B76C36447404390831266004C40
13027	7	66	1445	25421	62757	\N	56.134922000000003	Чувашская Республика - Чувашия, Моргаушский район, Ильинское сельское поселение, д.Апчары, ул.Центральная, д.35		0101000020E6100000170E84640163474066C1C41F45114C40
13050	7	66	1445	26481	62761	\N	55.942449000000003	Чувашская Республика - Чувашия, Моргаушский район, Тораевское сельское поселение, д.Анаткасы, ул.Колхозная, д.1		0101000020E6100000F3CAF5B699484740EF92382BA2F84B40
13069	7	66	1445	27343	61970	\N	55.965077999999998	Чувашская Республика - Чувашия, Моргаушский район, Ярабайкасинское сельское поселение, с.Акрамово, ул.Центральная, д.40		0101000020E61000005857056A31704740670B08AD87FB4B40
13039	7	66	1445	26010	62863	\N	55.985447999999998	Чувашская Республика - Чувашия, Моргаушский район, Орининское сельское поселение, д.Адабай, ул.Школьная, д.2		0101000020E6100000AA7EA5F3E16947404DF4F92823FE4B40
13008	7	66	1654	52569	62813	\N	56.063806	Чувашская Республика - Чувашия, Мариинско-Посадский район, Сутчевское сельское поселение, д. Ящерино, Кооперативная, 3		0101000020E610000064E597C118D94740F0A485CB2A084C40
13014	7	66	1654	32766	61880	\N	55.966563999999998	Чувашская Республика - Чувашия, Мариинско-Посадский район, Эльбарусовское сельское поселение, д. Эльбарусово, Тогаевская, 1		0101000020E61000001D56B8E523E54740D7BE805EB8FB4B40
12978	7	66	1654	52506	62625	\N	55.907400000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Аксаринское сельское поселение, д. Щамалы, Новая, 1а		0101000020E61000009B73F04C68064840F931E6AE25F44B40
13003	7	66	1654	52552	62753	\N	56.078296999999999	Чувашская Республика - Чувашия, Мариинско-Посадский район, Приволжское сельское поселение, д. Шульгино, Почтовая, 40		0101000020E610000017F19D98F5F04740FD2FD7A2050A4C40
13009	7	66	1654	24612	61878	\N	56.006965000000001	Чувашская Республика - Чувашия, Мариинско-Посадский район, Шоршелское сельское поселение, с. Шоршелы, 30 лет Победы, 13		0101000020E61000007FBE2D58AACB4740BB9BA73AE4004C40
12990	7	66	1654	23672	62921	\N	55.893543392956602	д. Шанары, Малтикас, 49	Россия, республика Чувашская, Мариинско-Посадский район, село Шанары	0101000020E610000015C78157CBFD4740ED48F59D5FF24B40
12995	7	66	1654	23895	61964	\N	55.944878000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Первочурашевское сельское поселение, с. Первое Чурашево, Школьная, 10а		0101000020E6100000FE62B66455D64740DE5A26C3F1F84B40
12989	7	66	1654	58043	62928	\N	55.880685786021203	Чувашская Республика - Чувашия, Мариинско-Посадский район, Кугеевское сельское поселение, д. Вторые Чекуры, Пионерская, 3	Россия, республика Чувашская, Мариинско-Посадский район, село Чекуры 2-е	0101000020E61000008DEC4ACB48EF4740C405A051BAF04B40
13005	7	66	1654	52560	62628	\N	56.097447000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Приволжское сельское поселение, д. Ураково, Смольникова, 43		0101000020E61000005D19541B9CF04740F20BAF24790C4C40
13017	7	66	1654	24975	62080	\N	55.967542000000002	Чувашская Республика - Чувашия, Мариинско-Посадский район, Эльбарусовское сельское поселение, с. Тогаево, Нагорная, 4		0101000020E610000017F4DE1802EC4740D3C08F6AD8FB4B40
13001	7	66	1654	52547	62751	\N	56.068384000000002	Чувашская Республика - Чувашия, Мариинско-Посадский район, Приволжское сельское поселение, д. Тинсарино, Лесная, 1а		0101000020E6100000BE839F3880E44740EBC891CEC0084C40
12977	7	66	1654	52505	62075	\N	55.919549000000004	Чувашская Республика - Чувашия, Мариинско-Посадский район, Аксаринское сельское поселение, д. Сятракасы, Центральная, 41		0101000020E6100000B0CA85CABFFA4740E60819C8B3F54B40
12980	7	66	1654	52507	62629	\N	55.893282999999997	Чувашская Республика - Чувашия, Мариинско-Посадский район, Бичуринское сельское поселение, д. Сюндюково, Кузнечная, 16		0101000020E6100000E869C020E9DF47405089EB1857F24B40
13006	7	66	1654	52565	62846	\N	56.082140000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Сутчевское сельское поселение, д. Сутчево, Новая, 20		0101000020E610000078B81D1A16D94740C3D84290830A4C40
13016	7	66	1654	52581	62752	\N	55.933458999999999	Чувашская Республика - Чувашия, Мариинско-Посадский район, Эльбарусовское сельское поселение, д. Средние Бокаши, Ленина, 23а		0101000020E610000033A7CB6262E347401494A2957BF74B40
12984	7	66	1654	23375	62844	\N	56.021025000000002	Чувашская Республика - Чувашия, Мариинско-Посадский район, Большешигаевское сельское поселение, с. Сотниково, Магазинная, 8		0101000020E6100000618E1EBFB7E34740FFB27BF2B0024C40
12895	7	66	215	18966	62819	\N	55.198996999999999	с.Тугаево, Фрунзе, 1		0101000020E61000000917F2086EAC47404580D3BB78994B40
13015	7	66	1654	58047	62938	\N	55.951291436132202	Чувашская Республика - Чувашия, Мариинско-Посадский район, Эльбарусовское сельское поселение, Первые Синьялы, Школьная, 5а	Россия, республика Чувашская, Мариинско-Посадский район, село Синьялы 1-е	0101000020E6100000DBBFB2D2A4E0474054FD4AE7C3F94B40
12987	7	66	1654	23526	62748	\N	55.939373000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Карабашское сельское поселение, с. Покровское, Церковная, 3		0101000020E61000001343723271F747406ADFDC5F3DF84B40
12994	7	66	1654	52529	62750	\N	55.931789000000002	Чувашская Республика - Чувашия, Мариинско-Посадский район, Октябрьское сельское поселение, д. Передние  Бокаши, Нагорная, 2	Россия, республика Чувашская, Мариинско-Посадский район, село Передние Бокаши	0101000020E6100000AE2990D959E64740E3E2A8DC44F74B40
12992	7	66	1654	23759	61962	\N	55.903816999999997	Чувашская Республика - Чувашия, Мариинско-Посадский район, Октябрьское сельское поселение, с. Октябрьское, Советская, 13		0101000020E61000009AEE75525FE84740CF488446B0F34B40
13002	7	66	1654	52553	62078	\N	56.111899999999999	Чувашская Республика - Чувашия, Мариинско-Посадский район, Приволжское сельское поселение, д. нерядово, Луговая, 17		0101000020E6100000DD28B2D650E4474011363CBD520E4C40
12991	7	66	1654	57922	\N	\N	55.936986446131698	Чувашская Республика - Чувашия, Мариинско-Посадский район, д. Мижули, магазин Октябрьского райпо	Россия, республика Чувашская, Мариинско-Посадский район, село Мижули	0101000020E610000076F9D687F5DC4740A9674128EFF74B40
12975	7	66	1654	22673	61879	\N	56.103673000000001	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, Чкалова, 61б		0101000020E61000005EF58079C8DC4740363D2828450D4C40
12968	7	66	1654	22673	61877	\N	56.103673000000001	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, Новинская, 34		0101000020E61000005EF58079C8DC4740363D2828450D4C40
12973	7	66	1654	22673	61669	\N	56.116174597389097	Чувашская Республика - Чувашия, Мариинско-Посадский район, Мариинско-Посадское городское поселение, г. Мариинский Посад, Лазо, 76	Россия, республика Чувашская, Мариинско-Посадский район, Мариинский Посад	0101000020E610000044A2D0B2EEDB474070CE88D2DE0E4C40
12982	7	66	1654	52511	62745	\N	56.022281999999997	Чувашская Республика - Чувашия, Мариинско-Посадский район, Большешигаевское сельское поселение, д. Малое Шигаево, Лесная, 30		0101000020E610000079B29B19FDD847400DA5F622DA024C40
13011	7	66	1654	52578	62631	\N	56.005409999999998	Чувашская Республика - Чувашия, Мариинско-Посадский район, Шоршелское сельское поселение, д. Малое Камаево, Шоссейная, 2		0101000020E61000009E060C923ED1474022895E46B1004C40
13004	7	66	1654	24339	62826	\N	56.057478000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Приволжское сельское поселение, с. Кушниково, Школьная, 36		0101000020E61000004ED367075CF14740A81E69705B074C40
12988	7	66	1654	52520	62079	\N	55.860176000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Кугеевское сельское поселение, д. Кугеево, Молодежная, 34		0101000020E61000003B014D840DF54740ED66463F1AEE4B40
12998	7	66	1654	52537	62749	\N	55.949375000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Первочурашевское сельское поселение, д. Караньялы, Мокеева, 1а		0101000020E6100000B0726891EDDC4740EC51B81E85F94B40
12986	7	66	1654	52543	\N	\N	55.959923000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Карабашское сельское поселение, д. Карабаши, Центральная, 4	Россия, республика Чувашская, Мариинско-Посадский район, село Карабаши	0101000020E6100000946934B918F54740D0D6C1C1DEFA4B40
12996	7	66	1654	52533	62847	\N	55.92145	Чувашская Республика - Чувашия, Мариинско-Посадский район, Первочурашевское сельское поселение, д. Ибраялы, Северная, 15а		0101000020E6100000C2120F289BD647401973D712F2F54B40
13013	7	66	1654	52579	62850	\N	56.027529000000001	Чувашская Республика - Чувашия, Мариинско-Посадский район, Шоршелское сельское поселение, д. Ельниково, Главная, 12а		0101000020E6100000BF28417FA1CB47408658FD1186034C40
13000	7	66	1654	52545	62633	\N	56.060630000000003	Чувашская Республика - Чувашия, Мариинско-Посадский район, Приволжское сельское поселение, д. Дубовка, Украинская, 13		0101000020E61000009C4EB2D5E5E8474008944DB9C2074C40
12985	7	66	1654	52517	62821	\N	56.000819	Чувашская Республика - Чувашия, Мариинско-Посадский район, Большешигаевское сельское поселение, д. Большое Яндуганово, Полевая, 60		0101000020E61000004BE82E89B3E24740931B45D61A004C40
12981	7	66	1654	52510	62123	\N	55.995815	Чувашская Республика - Чувашия, Мариинско-Посадский район, Большешигаевское сельское поселение, д. Большое Шигаево, Школьная, 1		0101000020E610000024D1CB2896D94740E1EEACDD76FF4B40
13007	7	66	1654	58025	62766	\N	56.089237217834203	Чувашская Республика - Чувашия, Мариинско-Посадский район, Сутчевское сельское поселение, д. Большое Маклашкино, Большая, 62	Россия, республика Чувашская, Мариинско-Посадский район, село Большое Малашкино	0101000020E6100000D15B3CBCE7D44740EC4B361E6C0B4C40
13010	7	66	1654	52576	62705	\N	55.987648999999998	Чувашская Республика - Чувашия, Мариинско-Посадский район, Шоршелское сельское поселение, д. Большое Камаево, Центральная, 9		0101000020E61000007156444DF4CF4740AB764D486BFE4B40
12979	7	66	1654	23165	62814	\N	55.864455	Чувашская Республика - Чувашия, Мариинско-Посадский район, Бичуринское сельское поселение, с. Бичурино, Новая, 35		0101000020E61000001211FE45D0E447408DEE2076A6EE4B40
12983	7	66	1654	52513	62815	\N	56.035742999999997	Чувашская Республика - Чувашия, Мариинско-Посадский район, Большешигаевское сельское поселение, д. Арзаматово, Школьная, 1а		0101000020E610000038BD8BF7E3DA4740CC07043A93044C40
12997	7	66	1654	52535	62816	\N	55.972029999999997	Чувашская Республика - Чувашия, Мариинско-Посадский район, Первочурашевское сельское поселение, д. Алмандаево, Октябрьская, 6		0101000020E6100000923CD7F7E1CE47408D5DA27A6BFC4B40
12993	7	66	1654	52528	62845	\N	55.921227999999999	Чувашская Республика - Чувашия, Мариинско-Посадский район, Октябрьское сельское поселение, д. Акшики, Акшики, 60		0101000020E6100000C158DFC0E4EC47406A1492CCEAF54B40
12976	7	66	1654	52503	62786	\N	55.912001002798199	Чувашская Республика - Чувашия, Мариинско-Посадский район, Аксаринское сельское поселение, д. Аксарино, Центральная усадьба, 11	Россия, республика Чувашская, Мариинско-Посадский район, село Аксарино	0101000020E6100000D02B9E7AA4F54740AB75E272BCF44B40
12948	7	66	1454	52465	62746	\N	55.698197999999998	Чувашская Республика - Чувашия, Красночетайский район, Красночетайское сельское поселение, д.Янгильдино, Центральная, 40		0101000020E6100000D86322A5D9164740F910548D5ED94B40
12928	7	66	1454	52420	62120	\N	55.736776999999996	Чувашская Республика - Чувашия, Красночетайский район, Акчикасинское сельское поселение. д.Ямаши, Молодежная, 24		0101000020E61000006D205D6C5A0F4740F5B86FB54EDE4B40
12958	7	66	1454	52482	62114	\N	55.732711999999999	Чувашская Республика - Чувашия, Красночетайский район, Староатайское сельское поселение, д.Яманы, Вторая, 15а		0101000020E6100000350D8AE6013C474081B1BE81C9DD4B40
12965	7	66	1454	52496	62809	\N	55.714900999999998	Чувашская Республика - Чувашия, Красночетайский район, Хозанкинское сельское поселение, д.Ягункино, Новая, 27		0101000020E6100000FAB31F29222B474058703FE081DB4B40
12966	7	66	1454	22566	61870	\N	55.687624	Чувашская Республика - Чувашия, Красночетайский район, Штанашское сельское поселение, с.Штанаши, Молодежная, 16		0101000020E6100000001C7BF65C3A4740ECF82F1004D84B40
12927	7	66	1454	33148	61946	\N	55.724635999999997	Чувашская Республика - Чувашия, Красночетайский район, Акчикасинское сельское поселение,д.Шоля, Чернореченская, 220 а		0101000020E6100000193DB7D0950847408BC058DFC0DC4B40
12946	7	66	1454	57913	61947	\N	55.711406301052797	Чувашская Республика - Чувашия, Красночетайский район, Красночетайское сельское поселение, д.Черепаново, Центральная, 69	Россия, республика Чувашская, Красночетайский район, село Черепаново	0101000020E61000006616A1D80A104740CE16105A0FDB4B40
12964	7	66	1454	22472	62074	\N	55.725518999999998	Чувашская Республика - Чувашия, Красночетайский район, Хозанкинское сельское поселение, с.Хоршеваши, Центральная, 22		0101000020E610000003232F6B622F474035D07CCEDDDC4B40
12952	7	66	1454	52472	62747	\N	55.756948000000001	Чувашская Республика - Чувашия, Красночетайский район, Пандиковское сельское поселение, д.Хирлукасы, Николаева, 70а		0101000020E610000013807F4A95124740E5620CACE3E04B40
12951	7	66	1454	52470	62741	\N	55.767736999999997	Чувашская Республика - Чувашия, Красночетайский район, Пандиковское сельское поселение, д.Хвадукасы, Запрудная, 14		0101000020E61000008C84B69C4B0B4740EE76BD3445E24B40
12942	7	66	1454	52450	62805	\N	55.766480999999999	Чувашская Республика - Чувашия, Красночетайский район, Испуханское сельское поселение, д.Торханы, Центральная, 53а		0101000020E6100000D07EA4880C1D4740B000A60C1CE24B40
12934	7	66	1454	52431	62099	\N	55.671025999999998	Чувашская Республика - Чувашия, Красночетайский район, Атнарское сельское поселение, д.Тоганаши, Шоссейная, 25а		0101000020E6100000F629C764711F47400262122EE4D54B40
12963	7	66	1454	52492	62077	\N	55.706735999999999	Чувашская Республика - Чувашия, Красночетайский район, Хозанкинское сельское поселение, д.Тиханкино, Ленина, 33		0101000020E61000002FFB75A73B2D4740F373435376DA4B40
12933	7	66	1454	52430	62736	\N	55.663446	Чувашская Республика - Чувашия, Красночетайский район, Атнарское сельское поселение, д.Тарабаи, Центральная, 35а		0101000020E610000077A04E7974174740BD546CCCEBD44B40
12955	7	66	1454	52476	62070	\N	55.714134999999999	Чувашская Республика - Чувашия, Красночетайский район, Староатайское сельское поселение, д.Старые Атаи, Центральная, 165		0101000020E6100000ADFC321823324740E8F692C668DB4B40
12931	7	66	1454	52425	62737	\N	55.677230000000002	Чувашская Республика - Чувашия, Красночетайский район, Атнарское сельское поселение, д.Сосново, Сосновая, 98		0101000020E6100000FD87F4DBD71947405FEFFE78AFD64B40
12932	7	66	1454	52428	62006	\N	55.624124000000002	Чувашская Республика - Чувашия, Красночетайский район, Атнарское сельское поселение, д.Сормово, Центральная, 35		0101000020E6100000F7C77BD5CA1847400953944BE3CF4B40
12960	7	66	1454	52486	62680	\N	55.734273000000002	Чувашская Республика - Чувашия, Красночетайский район, Хозанкинское сельское поселение, д.Санкино, Ленина, 6		0101000020E6100000C2189128B4284740FCAA5CA8FCDD4B40
12953	7	66	1454	33039	61804	\N	55.678702000000001	Чувашская Республика - Чувашия, Красночетайский район, Питеркинское сельское поселение, д.Питеркино, Школьная, 4		0101000020E610000089D00836AE1147406ADD06B5DFD64B40
12954	7	66	1454	33039	62627	\N	55.6800890669737	Чувашская Республика - Чувашия, Красночетайский район, Питеркинское сельское поселение, д.Питеркино, Новая, 1	Россия, республика Чувашская, Красночетайский район, село Питеркино	0101000020E6100000F374AE282512474047AF06280DD74B40
12949	7	66	1454	21795	62742	\N	55.755540000000003	Чувашская Республика - Чувашия, Красночетайский район, Пандиковское сельское поселение, с.Пандиково, Ульянова, 1а		0101000020E61000000E6B2A8BC20E4740F168E388B5E04B40
12957	7	66	1454	52481	62743	\N	55.728265999999998	Чувашская Республика - Чувашия, Красночетайский район, Староатайское сельское поселение, д.Новые Атаи, Школьная, 13		0101000020E610000033FD12F1D6354740F564FED137DD4B40
12938	7	66	1454	52441	62626	\N	55.744622	Чувашская Республика - Чувашия, Красночетайский район, Большеатменское сельское поселение, д.Мочковаши, Лесная, 48б		0101000020E6100000D670917BBA204740E9F010C64FDF4B40
12950	7	66	1454	33027	61960	\N	55.733162999999998	Чувашская Республика - Чувашия, Красночетайский район, Пандиковское сельское поселение, д.Мижеркасы, Ленина, 1		0101000020E61000001F84807C0909474091D10149D8DD4B40
12941	7	66	1454	52447	62734	\N	55.781027999999999	Чувашская Республика - Чувашия, Красночетайский район, Испуханское сельское поселение, д.Кумаркино, Школьная, 2		0101000020E61000008F705AF0A223474051A1BAB9F8E34B40
12956	7	66	1454	52478	62119	\N	55.765471084783002	Чувашская Республика - Чувашия, Красночетайский район, Староатайское сельское поселение, д.Кузнечная, Школьная, 73	Россия, республика Чувашская, Красночетайский район, село Кузнечная	0101000020E6100000817A336ABE344740A98427F4FAE14B40
12944	7	66	1454	21521	61585	\N	55.696067350677502	Чувашская Республика - Чувашия, Красночетайский район, Красночетайское сельское поселение, с.Красные Четаи, пл.Победы, 9	Россия, республика Чувашская, Красночетайский район, село Красные Четаи	0101000020E6100000AFCE31207B134740946934B918D94B40
12943	7	66	1454	21521	61616	\N	55.697857999999997	Чувашская Республика - Чувашия, Красночетайский район, Красночетайское сельское поселение, с.Красные Четаи, Советская, 1		0101000020E6100000B6300BED9C12474040A0336953D94B40
12940	7	66	1454	52448	62621	\N	55.769584999999999	Чувашская Республика - Чувашия, Красночетайский район, Испуханское сельское поселение, д.Карк-Сирмы, Центральная, 15а		0101000020E6100000A1DB4B1AA3154740FF3EE3C281E24B40
13507	7	66	1454	16588	62683	\N	55.769191909896101	деревня Испуханы, Прямая, 50	Россия, республика Чувашская, Красночетайский район, село Испуханы	0101000020E6100000DC9DB5DB2E1C4740232C2AE274E24B40
12939	7	66	1454	16588	62618	\N	55.769337	Чувашская Республика - Чувашия, Красночетайский район, Испуханское сельское поселение, д.Испуханы, Новая, 2		0101000020E61000002C2E8ECA4D1C4740274D83A279E24B40
12945	7	66	1454	52457	62622	\N	55.714084999999997	Чувашская Республика - Чувашия, Красночетайский район, Испуханское сельское поселение, д.Ижекей, Центральная, 2		0101000020E610000025CADE52CE1B474036C8242367DB4B40
12557	7	66	1454	58032	\N	\N	55.710379034005001	Чувашская Республика - Чувашия, Аликовский район, Большевыльское сельское поселение, д.Выла, магазин, фойе	Россия, республика Чувашская, Красночетайский район, село Выла	0101000020E6100000E22021CA17404740F261F6B2EDDA4B40
12962	7	66	1454	52488	62071	\N	55.738976000000001	Чувашская Республика - Чувашия, Красночетайский район, Хозанкинское сельское поселение, д.Вторые Хоршеваши, Школьная, 1		0101000020E6100000DEAAEB504D2D4740B343FCC396DE4B40
12961	7	66	1454	52487	62808	\N	55.757398999999999	Чувашская Республика - Чувашия, Красночетайский район, Хозанкинское сельское поселение, д.Верхнее Аккозино, Ленина, 2		0101000020E61000006F9BA9108F2E4740F5824F73F2E04B40
12936	7	66	1454	32960	61803	\N	55.744109999999999	Чувашская Республика - Чувашия, Красночетайский район, Большеатменское сельское поселение, д.Большие Атмени, Молодежная, 94		0101000020E610000026378AAC35164740335019FF3EDF4B40
12930	7	66	1454	52424	62800	\N	55.601035000000003	Чувашская Республика - Чувашия, Красночетайский район, Атнарское сельское поселение, д.Березовка, Шоссейная, 9 а		0101000020E6100000EB8B84B69C1947402D6002B7EECC4B40
12926	7	66	1454	20681	61961	\N	55.722400999999998	Чувашская Республика - Чувашия, Красночетайский район, Акчикасинское сельское поселение, с.Баймашкино, Колхозная, 100		0101000020E6100000BE30992A1815474081CCCEA277DC4B40
12929	7	66	1454	20811	61860	\N	55.650835999999998	Чувашская Республика - Чувашия, Красночетайский район, Атнарское сельское поселение,с.Атнары, Молодежная, 52 а		0101000020E61000007497C459111B47409C8713984ED34B40
12967	7	66	1454	22632	62072	\N	55.708202	Чувашская Республика - Чувашия, Красночетайский район, Штанашское сельское поселение, Арайкасы, Николаева, 1б		0101000020E6100000FBE6FEEA714147401C7BF65CA6DA4B40
12937	7	66	1454	52440	62069	\N	55.745705999999998	Чувашская Республика - Чувашия, Красночетайский район, Большеатменское сельское поселение, д.Аликово, Солнечная, 164а		0101000020E610000081423D7D041C47402A37514B73DF4B40
12925	7	66	1454	52416	62870	\N	55.723486000000001	Чувашская Республика - Чувашия, Красночетайский район, Акчикасинское сельское поселение, д.Акчикасы, Васюкова, 47а		0101000020E61000001A6CEA3C2A104740938E72309BDC4B40
12917	7	66	1590	57912	61945	\N	55.858381999999999	Чувашская Республика - Чувашия, Красноармейский район, Чадукасинское сельское поселение, д. Чадукасы, ул. 40 лет Победы, д. 4		0101000020E610000025B20FB22C964740CFBC1C76DFED4B40
12906	7	66	1590	19545	61941	\N	55.745468000000002	Чувашская Республика - Чувашия, Красноармейский район, Яншихово-Челлинское сельское поселение, д. Яншихово-Чёллы, ул. Учительская, д. 1		0101000020E61000009C8C2AC3B8A54740761BD47E6BDF4B40
12904	7	66	1590	19440	61990	\N	55.740760000000002	Чувашская Республика - Чувашия, Красноармейский район, Красноармейское сельское поселение, д. Янгасы, ул. Н. Янгаса, д. 3		0101000020E610000076525F9676964740AD174339D1DE4B40
12913	7	66	1590	19912	61918	\N	55.787007000000003	Чувашская Республика - Чувашия, Красноармейский район, Исаковское сельское поселение, д. Яманаки, ул. Центральная, д. 2		0101000020E61000004436902E368D47408E5C37A5BCE44B40
12915	7	66	1590	57921	62076	\N	55.865173446706002	Чувашская Республика - Чувашия, Красноармейский район, Пикшикское сельское поселение, д. Ямайкасы, ул. Каганович, д. 12	Россия, республика Чувашская, Красноармейский район, село Ямаикасы	0101000020E6100000D4F19881CA824740EC3026FDBDEE4B40
12916	7	66	1590	20078	62066	\N	55.837702	Чувашская Республика - Чувашия, Красноармейский район, Пикшикское сельское поселение, д. Шупоси, ул. Магазинная, д. 4		0101000020E61000002F505260018C47409BE5B2D139EB4B40
12921	7	66	1590	20404	62738	\N	55.669986000000002	Чувашская Республика - Чувашия, Красноармейский район, Алманчинское сельское поселение, д. Шивбоси, ул. Центральная, д. 5		0101000020E6100000EA04341136A247409163EB19C2D54B40
13480	7	66	1590	48165	62739	\N	55.734886000000003	село Чиганары, Новая, 1-а		0101000020E6100000022B8716D9984740E62494BE10DE4B40
12923	7	66	1590	20534	61944	\N	55.709890999999999	Чувашская Республика - Чувашия, Красноармейский район, Убеевское сельское поселение, с. Убеево, ул. Сапожникова, д. 6		0101000020E610000033DDEBA4BE924740C45C52B5DDDA4B40
12907	7	66	1590	19594	62617	\N	55.751365999999997	Чувашская Республика - Чувашия, Красноармейский район, Яншихово-Челлинское сельское поселение, д. Санькасы, ул. Клубная, д. 1		0101000020E6100000253E7782FDAD4740C5A9D6C22CE04B40
12912	7	66	1590	19853	62735	\N	55.807389999999998	Чувашская Республика - Чувашия, Красноармейский район, Исаковское сельское поселение, д. Пшонги, ул. Лесная, д. 36		0101000020E6100000CC26C0B0FC9B4740088F368E58E74B40
12914	7	66	1590	19956	62615	\N	55.852293000000003	Чувашская Республика - Чувашия, Красноармейский район, Пикшикское сельское поселение, д. Пикшики, ул. Восточная, д. 2		0101000020E6100000EBAC16D8638447400CCEE0EF17ED4B40
12903	7	66	1590	19381	62097	\N	55.780794999999998	Чувашская Республика - Чувашия, Красноармейский район, Красноармейское сельское поселение, д. Крендейкасы, ул. Северная, д. 1		0101000020E610000001F6D1A92BA14740AEF02E17F1E34B40
12901	7	66	1590	19282	61647	\N	55.773112797865302	Чувашская Республика - Чувашия, Красноармейский район, Красноармейское сельское поселение, с. Красноармейское, ул. Ленина, д. 95	Россия, республика Чувашская, Красноармейский район, село Красноармейское	0101000020E61000005A2F8672A2954740658EE55DF5E24B40
12902	7	66	1590	19282	61583	\N	55.773838494800202	Чувашская Республика - Чувашия, Красноармейский район, Красноармейское сельское поселение, с. Красноармейское, ул. Васильева, д. 2	Россия, республика Чувашская, Красноармейский район, село Красноармейское	0101000020E61000000D6FD6E07D9547407633A31F0DE34B40
12910	7	66	1590	19736	62068	\N	55.790447999999998	Чувашская Республика - Чувашия, Красноармейский район, Большешатьминское сельское поселение, д. Кошки, ул. Школьная, д. 24		0101000020E6100000484E266E1586474024986A662DE54B40
12909	7	66	1590	19703	62616	\N	55.805619	Чувашская Республика - Чувашия, Красноармейский район, Большешатьминское сельское поселение, д. Кожары, ул. Гаражная, д. 1		0101000020E610000064E8D84125824740A304FD851EE74B40
12922	7	66	1590	20449	61802	\N	55.752521000000002	Чувашская Республика - Чувашия, Красноармейский район, Караевское сельское поселение, с. Караево, ул. Центральная, д. 7		0101000020E6100000B4CA4C69FD834740D046AE9B52E04B40
12911	7	66	1590	19802	62732	\N	55.813416695903499	Чувашская Республика - Чувашия, Красноармейский район, Исаковское сельское поселение, с. Исаково, ул. Садовая, д. 21	Россия, республика Чувашская, Красноармейский район, село Исаково	0101000020E6100000838AAA5FE994474056815A0C1EE84B40
12905	7	66	1590	19481	62619	\N	55.787604000000002	Чувашская Республика - Чувашия, Красноармейский район, Яншихово-Челлинское сельское поселение, с. Именево, пер. Центральный, д. 1		0101000020E6100000DA38622D3EA7474072193735D0E44B40
12918	7	66	1590	20192	62823	\N	55.884489000000002	Чувашская Республика - Чувашия, Красноармейский район, Чадукасинское сельское поселение, д. Енешкасы, ул. Школьная, д. 63 А		0101000020E61000000074982F2F944740FC5580EF36F14B40
12924	7	66	1590	20542	61875	\N	55.716628248305902	Чувашская Республика - Чувашия, Красноармейский район, Убеевское сельское поселение, д. Досаево, пер. Зеленый, д. 3	Россия, республика Чувашская, Красноармейский район, село Досаево	0101000020E61000006347E350BF8B4740EEB25F77BADB4B40
12908	7	66	1590	19643	62067	\N	55.822488	Чувашская Республика - Чувашия, Красноармейский район, Большешатьминское сельское поселение, с. Большая Шатьма, ул. Центральная, д. 1		0101000020E61000000DDE57E5428147401DAD6A4947E94B40
12919	7	66	1590	20269	62791	\N	55.696036999999997	Чувашская Республика - Чувашия, Красноармейский район, Алманчинское сельское поселение, с. Алманчино, ул. Школьная, д. 31		0101000020E61000006002B7EEE69B474029E78BBD17D94B40
12920	7	66	1590	20320	62798	\N	55.726213000000001	Чувашская Республика - Чувашия, Красноармейский район, Алманчинское сельское поселение, д. Албахтино, ул. Вокзальная, д. 66		0101000020E610000040BFEFDFBCA247400C772E8CF4DC4B40
12889	7	66	215	18661	62723	\N	55.133164000000001	д.Шурут-Нурусово, Зеленая, 2а		0101000020E610000009C1AA7AF9AB4740958098840B914B40
12888	7	66	215	18593	62144	\N	55.130853000000002	с.Шерауты, Больничная, 19		0101000020E61000001F49490F43AF4740B0CA85CABF904B40
12886	7	66	215	18485	61991	\N	55.206853000000002	д.Чичканы, Молодежная, 196		0101000020E6100000AD31E884D0B747402D0ABB287A9A4B40
12883	7	66	215	12948	61356	\N	55.232823000000003	д.Урмаево, Центральная, 47	Россия, республика Чувашская, Комсомольский район, село Урмаево	0101000020E61000002D211FF46CC04740D960E124CD9D4B40
12900	7	66	215	58039	62922	\N	55.253747578494902	д.Тябердино-Эткерево, Кооперативная, 7	Россия, республика Чувашская, Комсомольский район, село Тябердино-Эткерово	0101000020E61000009D7FBBECD7B9474074B680D07AA04B40
12871	7	66	215	17740	\N	\N	55.231513999999997	д.Новое Бикмурзино, Школьная, 5	Россия, республика Чувашская, Комсомольский район, село Новое Бикмурзино	0101000020E6100000AF230ED940CA474077483140A29D4B40
12876	7	66	215	17986	62065	\N	55.292186999999998	д.Новый Сундырь, Смирнова, 1		0101000020E6100000E202D0285DD447407EA8346266A54B40
12890	7	66	215	18694	62729	\N	55.107056	д.Нижние Бюртли Шигали, Центральная, 2		0101000020E6100000B7B75B9203B04740986BD102B48D4B40
12887	7	66	215	18548	61933	\N	55.1856547163569	д.Нижнее Тимерчеево, школьная, 1	Россия, республика Чувашская, Комсомольский район, село Нижнее Тимерчеево	0101000020E6100000C974E8F4BCB1474060AB048BC3974B40
12870	7	66	215	32522	61940	\N	55.267291999999998	д.Малые Кошелеи, Комсомольская, 38а		0101000020E61000007F6B274A42C04740C03DCF9F36A24B40
12868	7	66	215	49401	61668	\N	55.261710999999998	с.Комсомольское, Шолохова, 40		0101000020E61000000B09185DDEC447407100FDBE7FA14B40
12867	7	66	215	49401	61666	\N	55.261710999999998	с.Комсомольское, Ленина, 8		0101000020E61000000B09185DDEC447407100FDBE7FA14B40
12866	7	66	215	49401	61665	\N	55.261710999999998	с.Комсомольское, Заводская, 50		0101000020E61000000B09185DDEC447407100FDBE7FA14B40
12879	7	66	215	18143	62887	\N	55.233818999999997	д.Кайнлык, Центральный, 1		0101000020E6100000056B9C4D47D047407A17EFC7ED9D4B40
12891	7	66	215	18751	62690	\N	55.114424999999997	д.Ендоба, Центральная, 1		0101000020E61000003BE12538F5B34740226C787AA58E4B40
12869	7	66	215	49447	62917	\N	55.310560000000002	д.Дубовка, Овражная, 13		0101000020E610000068588CBAD6C447400FB9196EC0A74B40
12872	7	66	215	17784	62877	\N	55.213582000000002	д.Байбахтино, Комсомольская, 14		0101000020E6100000E2CB441152C54740D481ACA7569B4B40
12897	7	66	215	33147	61851	\N	55.313249999999996	д.Асаново, Чапаева, 1		0101000020E61000007CEF6FD05EB347406ABC749318A84B40
12873	7	66	215	57907	61876	\N	55.267485697390399	д.Александровка, Комсомольская, 161	Россия, республика Чувашская, Комсомольский район, село Александровка	0101000020E6100000C64D0D349FCB4740A51133FB3CA24B40
12849	7	66	1418	57902	\N	\N	55.881903999999999	Чувашская Республика - Чувашия, Козловский район, с.Карамышево, помещение Карамышевского СДК		0101000020E6100000F5B86FB54E064840151BF33AE2F04B40
12841	7	66	1418	52311	\N	\N	55.822502999999998	Чувашская Республика - Чувашия, Козловский район, д.Янтиково, помещение Янтиковского СДК	Россия, республика Чувашская, Козловский район, село Янтиково	0101000020E6100000A796ADF545F4474052EE3EC747E94B40
12862	7	66	1418	17290	\N	\N	55.725661000000002	Чувашская Республика - Чувашия, Козловский район, с.Янгильдино, помещение Янгильдинского СДК	Россия, республика Чувашская, Козловский район, село Янгильдино	0101000020E61000007AC7293A92174840C87DAB75E2DC4B40
12843	7	66	1418	52313	\N	\N	55.755549999999999	Чувашская Республика - Чувашия, Козловский район, д.Чешлама, помещение Чешламинского СДК	Россия, республика Чувашская, Козловский район, село Чешлама	0101000020E6100000F8889812490C4840143FC6DCB5E04B40
12860	7	66	1418	52351	\N	\N	55.771520000000002	Чувашская Республика - Чувашия, Козловский район, д.Уразметево, помещение Уразметевского фельдшерского акушерс.пункта	Россия, республика Чувашская, Козловский район, село Уразметьево	0101000020E610000038BD8BF7E3164840DF1AD82AC1E24B40
12844	7	66	1418	16382	\N	\N	55.803054000000003	Чувашская Республика - Чувашия, Козловский район, с.Тоганашево, помещение Тоганашевского СДК	Россия, республика Чувашская, Козловский район, село Тогонашево	0101000020E6100000B4E908E06613484004763579CAE64B40
12859	7	66	1418	17122	\N	\N	55.766424999999998	Чувашская Республика - Чувашия, Козловский район, с.Старая Тюрлема, помещение Старотюрлеминского СДК	Россия, республика Чувашская, Козловский район, село Старая Тюрлема	0101000020E6100000362383DC451C48401CEBE2361AE24B40
12858	7	66	1418	17122	\N	\N	55.756704999999997	Чувашская Республика - Чувашия, Козловский район, станция Тюрлема, помещение Тюрлеминского СДК		0101000020E6100000070B2769FE1C48401EDC9DB5DBE04B40
12855	7	66	1418	52344	\N	\N	55.868642000000001	"Чувашская Республика - Чувашия, Козловский район, д.Солдыбаево, помещение МОУ, ""Солдыбаевская СОШ им.А.Г.Журавлев"		0101000020E6100000C366800BB21148404DF73AA92FEF4B40
12865	7	66	1418	52360	\N	\N	55.719531000000003	Чувашская Республика - Чувашия, Козловский район, д.Семенчино, помещение Семенчинской сел.библиотеки	Россия, республика Чувашская, Козловский район, село Семенчино	0101000020E6100000C921E2E654164840A6BA809719DC4B40
12857	7	66	1418	52346	\N	\N	55.868693	Чувашская Республика - Чувашия, Козловский район, д.Пиндиково, помещение Пиндиковского сел.клуба	Россия, республика Чувашская, Козловский район, село Пиндиково	0101000020E61000002D40DB6AD6134840CFA10C5531EF4B40
12854	7	66	1418	52337	\N	\N	55.829653	Чувашская Республика - Чувашия, Козловский район, д.Осинкино, помещение Осинкинского сельского клуба	Россия, республика Чувашская, Козловский район, село Осинкино	0101000020E6100000BD512B4CDF0D48409F03CB1132EA4B40
12851	7	66	1418	52329	\N	\N	55.903615000000002	Чувашская Республика - Чувашия, Козловский район, д.Можары, помещение Можарского СДК	Россия, республика Чувашская, Козловский район, село Можары	0101000020E61000006FF1F09E03094840689604A8A9F34B40
12853	7	66	1418	52336	\N	\N	55.833809000000002	Чувашская Республика - Чувашия, Козловский район, д.Малое Бишево, помещение Малобишевского СДК	Россия, республика Чувашская, Козловский район, село Малое Бишево	0101000020E6100000A1BDFA78E8014840240ED940BAEA4B40
12848	7	66	1418	52323	\N	\N	55.800913999999999	Чувашская Республика - Чувашия, Козловский район, д.Липово, помещение Липовского сельского клуба	Россия, республика Чувашская, Козловский район, село Липово	0101000020E610000096CE8767090848404B74965984E64B40
54847	7	63	866	8180	54754	\N	54.722315999999999	с. Кендя, Кооперативная, 6 Б		0101000020E610000098E0D4079287464053B0C6D9745C4B40
12861	7	66	1418	52352	\N	\N	55.818078	Чувашская Республика - Чувашия, Козловский район, д.Курочкино, помещение Курочкинского СДК	Россия, республика Чувашская, Козловский район, село Курочкино	0101000020E6100000ABE7A4F78D2F4840DEC9A7C7B6E84B40
12840	7	66	1418	52310	\N	\N	55.838723000000002	Чувашская Республика - Чувашия, Козловский район, д.Кудемеры, помещение Кудемерского сел.клуба	Россия, республика Чувашская, Козловский район, село Кудемеры	0101000020E6100000132BA391CFE9474096B377465BEB4B40
12838	7	66	1418	15774	\N	\N	55.829101999999999	Чувашская Республика - Чувашия, Козловский район, г.Козловка, помещение Козловского АТП 2 этаж	Россия, республика Чувашская, Козловский район, Козловка	0101000020E610000074D4D171352048402B86AB0320EA4B40
12850	7	66	1418	52327	\N	\N	55.866712999999997	Чувашская Республика - Чувашия, Козловский район, д.Картлуево, помещение Картлуевского СДК	Россия, республика Чувашская, Козловский район, село Картлуево	0101000020E610000038F3AB39400C48404F029B73F0EE4B40
12852	7	66	1418	52332	\N	\N	55.830604000000001	Чувашская Республика - Чувашия, Козловский район, д.Илебары, помещение Карачевского СДК	Россия, республика Чувашская, Козловский район, село Илебары	0101000020E6100000A6D24F38BB054840A1F65B3B51EA4B40
12846	7	66	1418	52316	\N	\N	55.799607999999999	"Чувашская Республика - Чувашия, Козловский район, д.Еметкино, помещение МОУ, ""Еметкинская СОШ"""		0101000020E61000000FBA84436F0548405BCF108E59E64B40
12856	7	66	1418	52345	\N	\N	55.874056000000003	Чувашская Республика - Чувашия, Козловский район, д.Дятлино, помещение Дятлинского СДК	Россия, республика Чувашская, Козловский район, село Дятлино	0101000020E6100000DB6FED44490E4840B16F2711E1EF4B40
12847	7	66	1418	52318	\N	\N	55.779772999999999	Чувашская Республика - Чувашия, Козловский район, д.Бишево, помещение Бишевского сел.клуба	Россия, республика Чувашская, Козловский район, село Бишево	0101000020E61000006440F67AF7014840E3A6069ACFE34B40
12845	7	66	1418	16458	\N	\N	55.838358999999997	"Чувашская Республика - Чувашия, Козловский район, с.Байгулово, помещение МОУ, ""Байгуловская СОШ"""		0101000020E61000005ABC581822FB474054A703594FEB4B40
12842	7	66	1418	16273	\N	\N	55.777028999999999	Чувашская Республика - Чувашия, Козловский район, с.Аттиково, помещение Аттиковского СДК	Россия, республика Чувашская, Козловский район, село Аттиково	0101000020E6100000D8D47954FC0F48409485AFAF75E34B40
12839	7	66	1418	52309	\N	\N	55.790418000000003	Чувашская Республика - Чувашия, Козловский район, д.Андреево-Базары, помещение Андреево-Базарского СДК	Россия, республика Чувашская, Козловский район, село Андреево-Базары	0101000020E6100000E1D05B3CBCE74740BA15C26A2CE54B40
12863	7	66	1418	52359	\N	\N	55.722983999999997	Чувашская Республика - Чувашия, Козловский район, д.Альменево, помещение Альменевского ФАП	Россия, республика Чувашская, Козловский район, село Альменево	0101000020E610000009151C5E101D484000C45DBD8ADC4B40
12807	7	66	1185	14593	62160	\N	55.439079	Чувашская Республика - Чувашия, Канашский район, Янгличское сельское поселение, с. Янгличи, ул. Ленина, д. 88		0101000020E6100000B5503239B5A5474021AE9CBD33B84B40
12764	7	66	1185	12628	62792	\N	55.596997000000002	Чувашская Республика - Чувашия, Канашский район, Ямашевское сельское поселение, с. Ямашево, ул. Сергеева, д. 11		0101000020E6100000CEC64ACCB39C4740B267CF656ACC4B40
12795	7	66	1185	14030	62666	\N	55.35595	Чувашская Республика - Чувашия, Канашский район, Тобурдановское сельское поселение, дер. Яманово, ул. Ленина, д. 55		0101000020E6100000D2A755F487D247406F8104C58FAD4B40
12793	7	66	1185	13944	62867	\N	55.433011	Чувашская Республика - Чувашия, Канашский район, Караклинское сельское поселение, дер. Юманзары, ул. Михайлова, д. 33		0101000020E6100000A0DD21C500CB474075E789E76CB74B40
12769	7	66	1185	12833	62858	\N	55.665801999999999	Чувашская Республика - Чувашия, Канашский район, Кошноруйское сельское поселение, с. Шоркасы, ул. Октябрьская, д. 15		0101000020E61000001421753BFBAE474042CEFBFF38D54B40
12754	7	66	1185	12128	61581	\N	55.562664729988498	Чувашская Республика - Чувашия, Канашский район, Шихазанское сельское поселение, с. Шихазаны, ул. Генерала Михайлова, д. 15а	Россия, республика Чувашская, Канашский район, село Шихазаны	0101000020E6100000FEEF880AD5B147404BCD1E6805C84B40
12774	7	66	1185	13029	62149	\N	55.680641000000001	Чувашская Республика - Чувашия, Канашский район, Кошноруйское сельское поселение, с. Шигали, ул. Клубная, д. 1		0101000020E610000096B1A19BFDBB47408BA8893E1FD74B40
12758	7	66	1185	12315	62057	\N	55.615806999999997	Чувашская Республика - Чувашия, Канашский район, Шибылгинское сельское поселение, с. Шибылги, ул. Павлова, д. 33		0101000020E61000008B6EBDA607B94740EDD286C3D2CE4B40
12789	7	66	1185	13729	62865	\N	55.45187	Чувашская Республика - Чувашия, Канашский район, Шакуловское сельское поселение, с. Шакулово, ул. Южная, д.40а		0101000020E610000039D4EFC2D6CE474092054CE0D6B94B40
12783	7	66	1185	13451	62060	\N	55.574162000000001	Чувашская Республика - Чувашия, Канашский район, Ухманское сельское поселение, дер. Чиршкасы, ул. Ленина, д. 27а		0101000020E6100000BC74931804BC4740904DF2237EC94B40
12776	7	66	1185	13227	61839	\N	55.619757	Чувашская Республика - Чувашия, Канашский район, Среднекибечское сельское поселение, дер. Челкумаги, ул. Гагарина, д. 4		0101000020E6100000F7AE415F7ACB4740C93B873254CF4B40
12803	7	66	1185	14425	61936	\N	55.471127000000003	Чувашская Республика - Чувашия, Канашский район, Чагасьское сельское поселение, дер. Чагаси, ул. Центральная, д. 12		0101000020E61000007171546EA2AC47409DA1B8E34DBC4B40
12785	7	66	1185	13583	61935	\N	55.519906500314399	Чувашская Республика - Чувашия, Канашский район, Хучельское сельское поселение, дер. Хучель, ул. Школьная, д. 1	Россия, республика Чувашская, Канашский район, село Хучель	0101000020E610000022C2BF081ACD474012FB04508CC24B40
12782	7	66	1185	13429	61993	\N	55.568964999999999	Чувашская Республика - Чувашия, Канашский район, Ухманское сельское поселение, с. Ухманы, ул.Школьная, д. 4		0101000020E61000001CD13DEB1AC14740C9C859D8D3C84B40
12744	7	66	1185	11619	62051	\N	55.523698000000003	Чувашская Республика - Чувашия, Канашский район, Байгильдинское сельское поселение, дер.Туруново, ул. Ленина, д. 1		0101000020E61000009D4B7155D9A74740857D3B8908C34B40
12794	7	66	1185	14001	61840	\N	55.360357	Чувашская Республика - Чувашия, Канашский район, Тобурдановское сельское поселение, с. Тобурданово, ул. Пушкина, д. 57		0101000020E61000001897AAB4C5CB47403DF19C2D20AE4B40
12802	7	66	1185	14357	62727	\N	55.429358999999998	Чувашская Республика - Чувашия, Канашский район, Вутабосинское сельское поселение, дер. Сядорга-Сирмы, ул. Карла Маркса, д. 55		0101000020E610000099107349D5BE4740239F573CF5B64B40
12784	7	66	1185	13507	61663	\N	55.534219999999998	Чувашская Республика - Чувашия, Канашский район, Сугайкасинское сельское поселение, дер. Сугайкасы, ул. Сугай, д. 1		0101000020E6100000E4BB94BA64C047403F6F2A5261C44B40
12796	7	66	1185	14083	62872	\N	55.378723000000001	Чувашская Республика - Чувашия, Канашский район, Шальтямское сельское поселение, дер. Старые Шальтямы, ул. Кооперативная, д. 14а		0101000020E61000009E245D33F9BE47401B9FC9FE79B04B40
12791	7	66	1185	13857	62820	\N	55.472831999999997	Чувашская Республика - Чувашия, Канашский район, Шакуловское сельское поселение, дер. Старое Ахпердино, ул. Канашская, д. 19		0101000020E61000002C6519E258CF47404A404CC285BC4B40
12809	7	66	1185	14718	61873	\N	55.448832000000003	Чувашская Республика - Чувашия, Канашский район, Янгличское сельское поселение, дер. Средние Татмыши, ул. 50 лет Победы, д. 28		0101000020E61000005E9ECE15A59C4740FBB2B45373B94B40
12755	7	66	1185	12165	62055	\N	55.570166	Чувашская Республика - Чувашия, Канашский район, Шихазанское сельское поселение, дер. Сиделево, ул. 50 лет ВЛКСМ, д. 23		0101000020E61000001E8A027D22AD474044A51133FBC84B40
12761	7	66	1185	12459	61988	\N	55.602429000000001	Чувашская Республика - Чувашия, Канашский район, Сеспельское сельское поселение, дер. Сеспель, ул. Школьная, д. 65		0101000020E6100000DF50F86C1DA64740BC94BA641CCD4B40
12741	7	66	1185	11508	62848	\N	55.500763999999997	Чувашская Республика - Чувашия, Канашский район, Асхвинское сельское поселение, дер. Семеновка, ул. Восточная, д. 20		0101000020E610000050A8A78FC0AD4740CF81E50819C04B40
12780	7	66	1185	13310	62151	\N	55.673158999999998	Чувашская Республика - Чувашия, Канашский район, Среднекибечское сельское поселение, дер. Передние Яндоуши, ул. Ленина, д. 1		0101000020E6100000CB2E185C73CF47400801F9122AD64B40
12748	7	66	1185	11825	62053	\N	55.563645000000001	Чувашская Республика - Чувашия, Канашский район, Новочелкасинское сельское поселение, дер. Оженары, ул. Клубная, д. 2а		0101000020E6100000994BAAB69BA64740E7C6F48425C84B40
12797	7	66	1185	14139	62725	\N	55.361482000000002	Чувашская Республика - Чувашия, Канашский район, Шальтямское сельское поселение, дер. Новые Шальтямы, ул. Спортивная, д. 1а		0101000020E610000057E9EE3A1BBE4740DD0BCC0A45AE4B40
12745	7	66	1185	11697	62713	\N	55.530816000000002	Чувашская Республика - Чувашия, Канашский район, Новочелкасинское сельское поселение, дер. Новые Челкасы, ул. Николаева, д. 83		0101000020E61000008527F4FA93A24740C61858C7F1C34B40
12760	7	66	1185	12411	62612	\N	55.614932000000003	Чувашская Республика - Чувашия, Канашский район, Шибылгинское сельское поселение, дер. Новые Пинеры, ул. Новая, д. 5	Россия, республика Чувашская, Канашский район, село Новые Пинеры	0101000020E6100000C0B0FCF9B6BE4740C7A17E17B6CE4B40
12742	7	66	1185	11533	62142	\N	55.521526999999999	Чувашская Республика - Чувашия, Канашский район, Байгильдинское сельское поселение, дер. Новые Мамеи, ул. Гагарина, д. 11		0101000020E6100000CE716E13EEAF4740917D9065C1C24B40
12800	7	66	1185	14283	62726	\N	55.371408000000002	Чувашская Республика - Чувашия, Канашский район, Новоурюмовское сельское поселение, дер. Новые Бюрженеры, ул. Советская, д. 30		0101000020E61000005BCEA5B8AAB6474084BC1E4C8AAF4B40
12752	7	66	1185	12038	62054	\N	55.481735	Чувашская Республика - Чувашия, Канашский район, Ачакасинское сельское поселение, дер. Новые Ачакасы, ул. Молодежная, д. 21		0101000020E61000008EAD6708C79A4740562B137EA9BD4B40
12799	7	66	1185	14226	61872	\N	55.384861000000001	Чувашская Республика - Чувашия, Канашский район, Новоурюмовское сельское поселение, дер. Новое Урюмово, ул. Кооперативная, д. 31а		0101000020E610000090BE49D3A0B44740C040102043B14B40
12808	7	66	1185	14657	62873	\N	55.409435999999999	Чувашская Республика - Чувашия, Канашский район, Янгличское сельское поселение, дер. Новая Яндоба, ул. Гагарина, д. 1а		0101000020E610000069A7E67283AB47400CE71A6668B44B40
12777	7	66	1185	13164	62719	\N	55.623361000000003	Чувашская Республика - Чувашия, Канашский район, Среднекибечское сельское поселение, дер. Нижние Кибечи, ул. Чапаева, д. 49		0101000020E61000002A90D959F4C647400A4D124BCACF4B40
12751	7	66	1185	11956	61978	\N	55.491726999999997	Чувашская Республика - Чувашия, Канашский район, Ачакасинское сельское поселение, дер. Напольные Котяки, ул. Советская, д. 134		0101000020E61000005B41D3122BA14740B4C70BE9F0BE4B40
12805	7	66	1185	14510	62871	\N	55.490048999999999	Чувашская Республика - Чувашия, Канашский район, Чагасьское сельское поселение, дер. Мокры, ул. Спортивная, д. 26		0101000020E61000004B395FECBDAA47400038F6ECB9BE4B40
12798	7	66	1185	14155	62156	\N	55.374493000000001	Чувашская Республика - Чувашия, Канашский район, Шальтямское сельское поселение, дер. Маяк, ул. Шоссейная, д. 17а		0101000020E61000000C2252D32EC647405CCAF962EFAF4B40
12781	7	66	1185	13376	61989	\N	55.624473999999999	Чувашская Республика - Чувашия, Канашский район, Малокибечское сельское поселение, с. Малые Кибечи, ул. Центральная, д. 4		0101000020E61000008AE3C0ABE5D04740E59997C3EECF4B40
12787	7	66	1185	13649	61869	\N	55.480536000000001	Чувашская Республика - Чувашия, Канашский район, Малобикшихское сельское поселение, дер. Малые Бикшихи, ул. Канашская, д. 80		0101000020E61000009775FF5888C047407C46223482BD4B40
12746	7	66	1185	11740	62143	\N	55.543460000000003	Чувашская Республика - Чувашия, Канашский район, Новочелкасинское сельское поселение, дер.Малое Тугаево, ул. Гагарина, д. 7		0101000020E61000001DE736E15EA147409357E71890C54B40
12768	7	66	1185	58022	62722	\N	55.632527206081797	Чувашская Республика - Чувашия, Канашский район, Ямашевское сельское поселение, дер. Малдыпитикасы, ул. Центральная, д. 42	Россия, республика Чувашская, Канашский район, село Малды-Питикасы	0101000020E61000005AD8D30E7FA14740236B0DA5F6D04B40
12759	7	66	1185	12376	62058	\N	55.635182999999998	Чувашская Республика - Чувашия, Канашский район, Шибылгинское сельское поселение, дер. Малая Андреевка, ул. Молодежная, д. 58		0101000020E61000002FDD240681B74740D2FC31AD4DD14B40
12773	7	66	1185	13015	62148	\N	55.675758000000002	Чувашская Республика - Чувашия, Канашский район, Кошноруйское сельское поселение, дер. Кошноруй, ул. Ленина, д. 33		0101000020E6100000CA501553E9B547405401F73C7FD64B40
12740	7	66	1185	11460	61871	\N	55.490315000000002	Чувашская Республика - Чувашия, Канашский район, Асхвинское сельское поселение, дер. Кармамеи, ул. Центральная, д. 50		0101000020E61000007D09151C5EB247407FDE54A4C2BE4B40
12804	7	66	1185	11460	62611	\N	55.490315000000002	Чувашская Республика - Чувашия, Канашский район, Чагасьское сельское поселение, выс. Кармамеи, ул. Лесная, д. 55	Россия, республика Чувашская, Канашский район, село Кармамеи	0101000020E61000007D09151C5EB247407FDE54A4C2BE4B40
12792	7	66	1185	13872	61934	\N	55.435814999999998	Чувашская Республика - Чувашия, Канашский район, Караклинское сельское поселение, дер. Караклы, ул. Молодежная, д. 12		0101000020E6100000CA8AE1EA00C64740990D32C9C8B74B40
12756	7	66	1185	12211	62056	\N	55.610233999999998	Чувашская Республика - Чувашия, Канашский район, Атнашевское сельское поселение, дер. Калиновка, ул. Советская, д. 1		0101000020E6100000FC3559A31EB047402174D0251CCE4B40
12750	7	66	1185	11919	62059	\N	55.516078	Чувашская Республика - Чувашия, Канашский район, Ачакасинское сельское поселение, дер. Ирдеменево-Кошки, ул.Центральная, д. 67а		0101000020E61000000740DCD5AB9C4740B1170AD80EC24B40
12766	7	66	1185	12715	62715	\N	55.584542999999996	Чувашская Республика - Чувашия, Канашский район, Ямашевское сельское поселение, дер. Имелево, ул. Садовая, д. 37		0101000020E61000006AC2F693319E4740880D164ED2CA4B40
12788	7	66	1185	13705	62062	\N	55.481484999999999	Чувашская Республика - Чувашия, Канашский район, Малобикшихское сельское поселение, пос. Зеленый, ул. Центральная, д. 1		0101000020E61000004A404CC285C44740DD41EC4CA1BD4B40
12779	7	66	1185	13298	62721	\N	55.680011	Чувашская Республика - Чувашия, Канашский район, Среднекибечское сельское поселение, дер. Задние Яндоуши, ул. Школьная, д.10		0101000020E61000008CF50D4C6EC84740CBF5B6990AD74B40
12753	7	66	1185	12079	62851	\N	55.456597000000002	Чувашская Республика - Чувашия, Канашский район, Ачакасинское сельское поселение, дер. Елмачи, ул. Мира, д. 2		0101000020E610000052B7B3AF3C9A4740D2393FC571BA4B40
12775	7	66	1185	13088	62860	\N	55.656824	Чувашская Республика - Чувашия, Канашский район, Кошноруйское сельское поселение, дер. Дальние Сормы, ул. Шоссейная, д.19		0101000020E6100000EA5E27F565B747402C9D0FCF12D44B40
12801	7	66	1185	14311	61841	\N	55.430548999999999	Чувашская Республика - Чувашия, Канашский район, Вутабосинское сельское поселение, с. Вутабоси, ул. Восточная, д. 4		0101000020E61000007905A22765B84740AA29C93A1CB74B40
12765	7	66	1185	12664	62147	\N	55.621510999999998	Чувашская Республика - Чувашия, Канашский район, Ямашевское сельское поселение, дер. Вурман-Янишево, ул. Ленина, д. 46		0101000020E61000007FDAA84E079C4740588D25AC8DCF4B40
12747	7	66	1185	11802	62855	\N	55.546805999999997	Чувашская Республика - Чувашия, Канашский район, Новочелкасинское сельское поселение, дер. Вторые Хормалы, ул. Кооперативная, д. 18		0101000020E6100000ADBD4F55A19D4740D7A02FBDFDC54B40
12806	7	66	1185	14560	62864	\N	55.475530999999997	Чувашская Республика - Чувашия, Канашский район, Чагасьское сельское поселение, дер. Верхняя Яндоба, ул. Чапаева, д. 33		0101000020E61000005437177FDBA54740F99D2633DEBC4B40
12778	7	66	1185	13233	62061	\N	55.598497000000002	Чувашская Республика - Чувашия, Канашский район, Среднекибечское сельское поселение, дер. Верхнее Девлизерово, ул. Школьная, д.4		0101000020E61000009FC728CFBCC4474087E0B88C9BCC4B40
12767	7	66	1185	12766	62098	\N	55.623086999999998	Чувашская Республика - Чувашия, Канашский район, Ямашевское сельское поселение, дер. Братьякасы, ул. Центральная, д. 31		0101000020E61000005E66D828EB99474008C89750C1CF4B40
12739	7	66	1185	32994	61868	\N	55.532221999999997	Чувашская Республика - Чувашия, Канашский район, Асхвинское сельское поселение, Большие Бикшихи, ул. Ленина, д. 11		0101000020E61000004EED0C535BBA4740191BBAD91FC44B40
12771	7	66	1185	12898	62718	\N	55.637535	Чувашская Республика - Чувашия, Канашский район, Кошноруйское сельское поселение, дер. Ближние Сормы, ул. Театральная, д. 13		0101000020E610000007D15AD1E6B04740168733BF9AD14B40
12743	7	66	1185	11594	62849	\N	55.530912999999998	Чувашская Республика - Чувашия, Канашский район, Байгильдинское сельское поселение, дер. Байгильдино, ул. Волкова, д.33		0101000020E610000027BC04A73EAC4740B8020AF5F4C34B40
12749	7	66	1185	11876	62818	\N	55.497373000000003	Чувашская Республика - Чувашия, Канашский район, Ачакасинское сельское поселение, с. Ачакасы, ул. Молодежная, д. 23		0101000020E61000001233FB3C46954740EB7420EBA9BF4B40
12762	7	66	1185	12514	62856	\N	55.630426	Чувашская Республика - Чувашия, Канашский район, Сеспельское сельское поселение, дер. Атыково, ул. Чкалова, д. 8		0101000020E610000076DD5B9198A44740284696CCB1D04B40
12757	7	66	1185	12287	61931	\N	55.582940000000001	Чувашская Республика - Чувашия, Канашский район, Атнашевское сельское поселение, дер. Атнашево, ул. Кирова, д. 6		0101000020E610000082C98D226BB94740DFC325C79DCA4B40
12737	7	66	1185	11294	61930	\N	55.522779999999997	Чувашская Республика - Чувашия, Канашский район, Асхвинское сельское поселение, дер. Асхва, ул. Спортивная, д. 19		0101000020E6100000D1CDFE40B9B747405E807D74EAC24B40
12790	7	66	1185	13788	62033	\N	55.453798999999997	Чувашская Республика - Чувашия, Канашский район, Шакуловское сельское поселение, дер. Аниш-Ахпердино, ул. Шакуловская, д. 4		0101000020E61000000E84640113D447408FFAEB1516BA4B40
12763	7	66	1185	12549	62806	\N	55.606516999999997	Чувашская Республика - Чувашия, Канашский район, Сеспельское сельское поселение, дер. Анаткасы, ул. Шелепи, д. 2		0101000020E61000000D37E0F3C3A24740E8BB5B59A2CD4B40
12786	7	66	1185	13593	62154	\N	55.541651999999999	Чувашская Республика - Чувашия, Канашский район, Хучельское сельское поселение, дер. Алешево, ул.Полевая, д. 1		0101000020E610000002F566D47CC9474010E84CDA54C54B40
12770	7	66	1185	12884	62859	\N	55.683483000000003	Чувашская Республика - Чувашия, Канашский район, Кошноруйское сельское поселение, дер. Алаксары, ул. Ленина, д. 42	Россия, республика Чувашская, Канашский район, село Алаксары	0101000020E6100000B54E5C8E57AE47409D2FF65E7CD74B40
12736	7	66	1106	61570	79405	\N	55.277422000000001	Чувашская Республика - Чувашия, Ибресинский район, Ширтанское сельское поселение, Школьная, 1	Россия, республика Чувашская, Ибресинский район, село Ширтаны	0101000020E61000002D98F8A3A88747407098689082A34B40
12731	7	66	1106	58049	62946	\N	55.300213290408301	Чувашская Республика - Чувашия, Ибресинский район, Чувашско-Тимяшское сельское поселение, Школьная, 1	Россия, республика Чувашская, Ибресинский район, село Хормалы	0101000020E61000007172BF4351A04740C26A2C616DA64B40
12729	7	66	1106	58049	79400	\N	55.294469544880201	Чувашская Республика - Чувашия, Ибресинский район, Хормалинское сельское поселение, Центральная, 29	Россия, республика Чувашская, Ибресинский район, село Хормалы	0101000020E61000002C9B3924B5A0474099D36531B1A54B40
12723	7	66	1106	61569	79404	\N	55.257427	Чувашская Республика - Чувашия, Ибресинский район, Малокармалинское сельское поселение, Лесная, 53	Россия, республика Чувашская, Ибресинский район	0101000020E6100000838AAA5FE9864740BF0D315EF3A04B40
12724	7	66	1106	61590	79451	\N	55.154201093857402	Чувашская Республика - Чувашия, Ибресинский район, Малокармалинское сельское поселение, Школьная, 1	Россия, республика Чувашская, Ибресинский район, село Кубня	0101000020E61000008143A852B39B47405801BEDBBC934B40
12713	7	66	1106	32799	61832	\N	55.301619376987802	Чувашская Республика - Чувашия, Ибресинский район, Айбечское сельское поселение, Центральная, 32	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E6100000C4793881E9844740166D8E739BA64B40
12716	7	66	1106	32799	62610	\N	55.2989872514746	Чувашская Республика - Чувашия, Ибресинский район, Березовское сельское поселение, Солнечная, 38	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E61000004BE48233F8854740EE76BD3445A64B40
12712	7	66	1106	32799	61833	\N	55.299194	Чувашская Республика - Чувашия, Ибресинский район, Ибресинское городское поселение, офис ООО "Водстроймонтаж" п. Ибреси, ул.Свердлова, 14		0101000020E61000003B70CE88D284474068942EFD4BA64B40
12732	7	66	1106	32799	62744	\N	55.299194	Чувашская Республика - Чувашия, Ибресинский район, Чувашско-Тимяшское сельское поселение, Октябрьская, 20	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E61000003B70CE88D284474068942EFD4BA64B40
12711	7	66	1106	32799	61567	\N	55.3018273878589	Чувашская Республика - Чувашия, Ибресинский район, Ибресинское городское поселение, Мира, 23	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E6100000A0353FFED284474060066344A2A64B40
12708	7	66	1106	32799	61929	\N	55.299194	Чувашская Республика - Чувашия, Ибресинский район, Ибресинское городское поселение, Маресьева, 20		0101000020E61000003B70CE88D284474068942EFD4BA64B40
12710	7	66	1106	32799	61615	\N	55.299194	Чувашская Республика - Чувашия, Ибресинский район, Ибресинское городское поселение, Центр соцобслуживания населения п. Ибреси, ул.Кооперативная, 27, корпус1		0101000020E61000003B70CE88D284474068942EFD4BA64B40
12728	7	66	1106	32799	61857	\N	55.301423415399697	Чувашская Республика - Чувашия, Ибресинский район, Хормалинское сельское поселение, Комсомольская, 58	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E6100000A0353FFED284474090A1630795A64B40
12720	7	66	1106	32799	61857	\N	55.304459228493201	Чувашская Республика - Чувашия, Ибресинский район, Климовское сельское поселение, Комсомольская, 14	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E61000001572A59E0585474087FC3383F8A64B40
12722	7	66	1106	32799	61874	\N	55.304361302680697	Чувашская Республика - Чувашия, Ибресинский район, Малокармалинское сельское поселение, Евсевьева, 41	Россия, республика Чувашская, Ибресинский район, поселок Ибреси	0101000020E61000007651F4C0C7844740C4961E4DF5A64B40
12719	7	66	1106	58051	62991	\N	55.321396739915897	Чувашская Республика - Чувашия, Ибресинский район, Кировское сельское поселение, Кирова, 8	Россия, республика Чувашская, Ибресинский район, село Бугуян	0101000020E610000062D68BA19C6647402904728923A94B40
12718	7	66	1106	32854	79403	\N	55.381940251886299	Чувашская Республика - Чувашия, Ибресинский район, Большеабакасинское сельское поселение, Советская, 80	Россия, республика Чувашская, Ибресинский район, село Большие Абакасы	0101000020E610000001158E20958447406284F068E3B04B40
12717	7	66	1106	32854	62002	\N	55.384823284382598	Чувашская Республика - Чувашия, Ибресинский район, Большеабакасинское сельское поселение, Мирный, 14	Россия, республика Чувашская, Ибресинский район, село Большие Абакасы	0101000020E61000001364045438844740D2DF4BE141B14B40
12714	7	66	1106	58101	63338	\N	55.319274999999998	Чувашская Республика - Чувашия, Ибресинский район, Андреевское сельское поселение, Молодежная, 2	Россия, республика Чувашская, Ибресинский район, село Андреевка	0101000020E6100000C47AA3569890474017B7D100DEA84B40
12727	7	66	1106	58023	62724	\N	55.341802028878398	Чувашская Республика - Чувашия, Ибресинский район, Хормалинское сельское поселение, Центральная, 32	Россия, республика Чувашская, Ибресинский район, село Айбечи	0101000020E61000002CD7DB662AAC47408CDAFD2AC0AB4B40
12693	7	66	902	9189	62073	\N	55.633190999999997	Чувашская Республика - Чувашия, Вурнарский район, Ойкас-Кибекское сельское поселение,с.Янишево, Центральная, 48		0101000020E610000033A7CB62629747408E8F16670CD14B40
12705	7	66	902	32768	61928	\N	55.539166000000002	Чувашская Республика - Чувашия, Вурнарский район, Янгорчинское сельское поселение,д.Янгорчино, Советская, 2А		0101000020E6100000B45A608F898E4740BD8E386403C54B40
12681	7	66	902	52070	62031	\N	55.616951	Чувашская Республика - Чувашия, Вурнарский район, Калининское сельское поселение,д.Ямбахтино, Центральная, 49В		0101000020E61000006118B0E42A664740041E1840F8CE4B40
12656	7	66	902	51990	62913	\N	55.642055788020699	Чувашская Республика - Чувашия, Вурнарский район, Азимсирминское сельское поселение,д.Эпшики,Заречная,12	Россия, республика Чувашская, Вурнарский район, село Эпшики	0101000020E6100000CB9C2E8B895F4740AC1919E42ED24B40
12703	7	66	902	52102	62843	\N	55.575398	Чувашская Республика - Чувашия, Вурнарский район, Шинерское сельское поселение,д.Шинеры, Клубная, 238		0101000020E6100000BB2A508BC15F4740871744A4A6C94B40
12665	7	66	902	58020	62699	\N	55.582010821569902	Чувашская Республика - Чувашия, Вурнарский район, Большеторханское сельское поселение,д.Ч-Мураты, Новая, 14	Россия, республика Чувашская, Вурнарский район, село Чиршкас-Мураты	0101000020E610000067D5E76A2B844740C57421567FCA4B40
12704	7	66	902	57920	62052	\N	55.576036309181902	Чувашская Республика - Чувашия, Вурнарский район, Шинерское сельское поселение,д.Ч.Шинеры, Парковая, 207	Россия, республика Чувашская, Вурнарский район, село Чириш-Шинеры	0101000020E61000000490DAC4C9634740CAA8328CBBC94B40
12670	7	66	902	8127	62720	\N	55.476157999999998	Чувашская Республика - Чувашия, Вурнарский район, Буртасинское сельское поселение,п.Чаркли, Гагарина, 35А		0101000020E61000005073F222136A474048DDCEBEF2BC4B40
12706	7	66	902	57924	62145	\N	55.543343664582999	Чувашская Республика - Чувашия, Вурнарский район, Янгорчинское сельское поселение,д.Хоронзоры, Молодежная, 12	Россия, республика Чувашская, Вурнарский район, село Хорнзор	0101000020E6100000BB0F406A138B4740293DD34B8CC54B40
12679	7	66	902	52062	62105	\N	55.412619999999997	Чувашская Республика - Чувашия, Вурнарский район, Ершипосинское сельское поселение,д.Хора-Сирма, Парковая, 1		0101000020E6100000CA3505323B87474077D66EBBD0B44B40
12700	7	66	902	52100	62049	\N	55.514288999999998	Чувашская Республика - Чувашия, Вурнарский район, Хирпосинское сельское поселение,д.Хирпоси, Советская, 37		0101000020E610000085EB51B81E914740A5D8D138D4C14B40
12689	7	66	902	58037	62918	\N	55.581724713830504	Чувашская Республика - Чувашия, Вурнарский район, Малояушское сельское поселение,д.Тузи-Сярмусы, Школьная, 28	Россия, республика Чувашская, Вурнарский район, село Тузи-Сярмус	0101000020E61000009B745B2217924740FF21FDF675CA4B40
12691	7	66	902	52088	62711	\N	55.562296000000003	Чувашская Республика - Чувашия, Вурнарский район, Малояушское сельское поселение,д.Троицкое, А.Иванова, 1		0101000020E61000008E3D7B2E53954740F855B950F9C74B40
12694	7	66	902	52089	62141	\N	55.625537000000001	Чувашская Республика - Чувашия, Вурнарский район, Сявалкасинское сельское поселение,д.Сявалкасы, Шоссейнаяё, 1Б		0101000020E61000000470B378B18047400FB8AE9811D04B40
12686	7	66	902	52082	62050	\N	55.468350999999998	Чувашская Республика - Чувашия, Вурнарский район, Кольцовское сельское поселение,д.Сявалкас-Хирпоси, Цивильная, 1В		0101000020E6100000CA6C9049468C47404206F2ECF2BB4B40
12695	7	66	902	52090	62841	\N	55.657316000000002	Чувашская Республика - Чувашия, Вурнарский район, Сявалкасинское сельское поселение,д.Сугут-Торбиково, Школьная, 4		0101000020E6100000A7E7DD58508047409B9141EE22D44B40
12661	7	66	902	52007	62836	\N	55.518239000000001	Чувашская Республика - Чувашия, Вурнарский район, Апнерское сельское поселение,д.Ст.Яхакасы, Новая, 2А		0101000020E6100000A69A594B017B47408141D2A755C24B40
22815	7	61	357	20854	65510	\N	54.443449999999999	с.Балагушево, Молодежная, 1		0101000020E610000060048D9944DF4B40A2B437F8C2384B40
12669	7	66	902	52034	62045	\N	55.669741999999999	Чувашская Республика - Чувашия, Вурнарский район, Большеяушское сельское поселение,д.Синьял-Яуши, Советская, 12А		0101000020E610000010AE80423D874740FA60191BBAD54B40
12675	7	66	902	52050	62046	\N	55.534326999999998	Чувашская Республика - Чувашия, Вурнарский район, Вурманкасинское сельское поселение,д.Сендимиркино, Центральная, 55		0101000020E6100000C24D469561724740552FBFD364C44B40
12701	7	66	902	52101	\N	\N	55.486448000000003	Чувашская Республика - Чувашия, Вурнарский район, Хирпосинское сельское поселение,д.Рунги	Россия, республика Чувашская, Вурнарский район, село Рунги	0101000020E610000024D40CA9A2924740319A95ED43BE4B40
12683	7	66	902	52075	62708	\N	55.652282999999997	Чувашская Республика - Чувашия, Вурнарский район, Калининское сельское поселение,д.Ослаба, Новая, 5		0101000020E610000076DF313CF66F47404E5E64027ED34B40
12699	7	66	902	33103	62842	\N	55.501227999999998	Чувашская Республика - Чувашия, Вурнарский район, Хирпосинское сельское поселение,д.Орауши, Первомайская, 14		0101000020E6100000F030ED9BFB89474074EB353D28C04B40
12668	7	66	902	52033	62703	\N	55.652568000000002	Чувашская Республика - Чувашия, Вурнарский район, Большеяушское сельское поселение,д.Ойкас-Яуши, Зеленая, 8А		0101000020E6100000D28BDAFD2A8A47404435255987D34B40
12663	7	66	902	33119	61986	\N	55.514136000000001	Чувашская Республика - Чувашия, Вурнарский район, Санарпосинское сельское поселение,д.Н.Яхакасы, 40 лет Победы, 1В		0101000020E6100000ADF6B0170A7E47401FD95C35CFC14B40
12707	7	66	902	52109	62710	\N	55.542369999999998	Чувашская Республика - Чувашия, Вурнарский район, Янгорчинское сельское поселение,д.Напольное Тугаево, Дружбы, 22		0101000020E61000007CBABA63B19547406F2A52616CC54B40
12685	7	66	902	52080	62837	\N	55.450859000000001	Чувашская Республика - Чувашия, Вурнарский район, Кольцовское сельское поселение,д.Мамалаево, Административная, 3		0101000020E6100000EC1516DC0F864740BB0D6ABFB5B94B40
12687	7	66	902	52083	62048	\N	55.602713000000001	Чувашская Республика - Чувашия, Вурнарский район, Малояушское сельское поселение,д.Малые Яуши, Центральная, 26		0101000020E610000050C24CDBBF8C4740E1EF17B325CD4B40
12655	7	66	902	51986	62041	\N	55.638587000000001	Чувашская Республика - Чувашия, Вурнарский район, Азимсирминское сельское поселение,д.Малдыкасы, Восточная, 1		0101000020E6100000FE8172DBBE6547404C530438BDD14B40
12677	7	66	902	32574	61829	\N	55.428240000000002	Чувашская Республика - Чувашия, Вурнарский район, Ершипосинское сельское поселение,д.Кюстюмеры, Школьная, 1		0101000020E61000003065E080967E4740666B7D91D0B64B40
12688	7	66	902	52085	62709	\N	55.572426	Чувашская Республика - Чувашия, Вурнарский район, Малояушское сельское поселение,д.Кюмель-Ямаши, Кооперативная, 2	Россия, республика Чувашская, Вурнарский район, село Кюмель-Ямаши	0101000020E610000053CBD6FA22894740A7B0524145C94B40
12682	7	66	902	52069	62047	\N	55.582161999999997	Чувашская Республика - Чувашия, Вурнарский район, Калининское сельское поселение,д.Кюльхири, Победы, 31		0101000020E61000009E25C808A8704740AA7CCF4884CA4B40
12684	7	66	902	52078	62840	\N	55.426231999999999	Чувашская Республика - Чувашия, Вурнарский район, Кольцовское сельское поселение,д.Кольцовка, Центральная, 64А		0101000020E6100000971DE21FB68C47401C412AC58EB64B40
12698	7	66	902	52094	62853	\N	55.693590999999998	Чувашская Республика - Чувашия, Вурнарский район, Ермошкинское сельское поселение,д.Кожар Яндоба, Новая, 1		0101000020E61000009D9D0C8E9283474064E60297C7D84B40
12671	7	66	902	52041	62717	\N	55.507316000000003	Чувашская Республика - Чувашия, Вурнарский район, Буртасинское сельское поселение,д.Киберли, Лесная, 1А		0101000020E6100000A0DFF76F5E604740685E0EBBEFC04B40
12680	7	66	902	8614	61830	\N	55.608713999999999	Чувашская Республика - Чувашия, Вурнарский район, Калининское сельское поселение,с.Калинино, Гагарина, 31		0101000020E6100000D1C952EBFD6C4740054F2157EACD4B40
12676	7	66	902	8457	62839	\N	55.405450000000002	Чувашская Республика - Чувашия, Вурнарский район, Ершипосинское сельское поселение,д.Ершипоси, пер.Юбилейный, 3		0101000020E61000005797530262804740E4141DC9E5B34B40
12696	7	66	902	32697	61864	\N	55.663120999999997	Чувашская Республика - Чувашия, Вурнарский район, Ермошкинское сельское поселение,д.Ермошкино, Школьная, 8		0101000020E61000003735D07CCE75474039252026E1D44B40
12649	7	66	902	7034	61646	\N	55.486392000000002	Чувашская Республика - Чувашия, Вурнарский район, Вурнарское городское поселение,п.Вурнары, Пионерская, 9		0101000020E6100000280F0BB5A67B47409D84D21742BE4B40
12650	7	66	902	7034	61661	\N	55.486392000000002	Чувашская Республика - Чувашия, Вурнарский район, Вурнарское городское поселение,п.Вурнары, Ленина, 160А		0101000020E6100000280F0BB5A67B47409D84D21742BE4B40
12648	7	66	902	7034	61341	\N	55.486392000000002	Чувашская Республика - Чувашия, Вурнарский район, Вурнарское городское поселение,п.Вурнары, К.Маркса, 1	Россия, республика Чувашская, Вурнарский район, поселок Вурнары	0101000020E6100000280F0BB5A67B47409D84D21742BE4B40
12651	7	66	902	7034	61662	\N	55.486392000000002	Чувашская Республика - Чувашия, Вурнарский район, Вурнарское городское поселение,п.Вурнары, ул.К.Маркса, 54		0101000020E6100000280F0BB5A67B47409D84D21742BE4B40
12647	7	66	902	7034	61660	\N	55.486392000000002	Чувашская Республика - Чувашия, Вурнарский район,п.Вурнары, Заводская, 1		0101000020E6100000280F0BB5A67B47409D84D21742BE4B40
12674	7	66	902	52047	62044	\N	55.546554841886604	Чувашская Республика - Чувашия, Вурнарский район, Вурманкасинское сельское поселение,д.Вурманкасы, Советская, 64	Россия, республика Чувашская, Вурнарский район, село Вурманкасы	0101000020E6100000587380608E6C47408E3BA583F5C54B40
12692	7	66	902	58008	62604	\N	55.625774999999997	Чувашская Республика - Чувашия, Вурнарский район, Ойкас-Кибекское сельское поселение,д.Вурман-Кибекий, Молодежная, 8	Россия, республика Чувашская, Вурнарский район, село Вурман-Кибеки	0101000020E610000083A279008B944740C3D32B6519D04B40
12673	7	66	902	57926	62153	\N	55.488412171826504	Чувашская Республика - Чувашия, Вурнарский район, Буртасинское сельское поселение,д.Волонтеры, Коммунаров, 6А	Россия, республика Чувашская, Вурнарский район, село Волонтер	0101000020E610000064EB19C231654740AA7CCF4884BE4B40
12672	7	66	902	8234	61828	\N	55.496093000000002	Чувашская Республика - Чувашия, Вурнарский район, Буртасинское сельское поселение,д.Буртасы, пер.Школьный, 1		0101000020E61000006170CD1DFD6D47402463B5F97FBF4B40
12667	7	66	902	52028	62043	\N	55.637967000000003	Чувашская Республика - Чувашия, Вурнарский район, Большеяушское сельское поселение,д.Большие Яуши, Коммунальная, 9		0101000020E61000008099EFE027884740B07614E7A8D14B40
12653	7	66	902	58029	62807	\N	55.650845530240602	Чувашская Республика - Чувашия, Вурнарский район, Азимсирминское сельское поселение,д.Чирш-Хирлепы, Шоссейная, 54		0101000020E61000009692E52494684740C05DF6EB4ED34B40
12662	7	66	902	52012	62704	\N	55.558920999999998	Чувашская Республика - Чувашия, Вурнарский район, Большеторханское сельское поселение,д.Большие Торханы, Здоровья, 1Б	Россия, республика Чувашская, Вурнарский район, село Большие Торханы	0101000020E610000014E7A8A3E37E474018062CB98AC74B40
12659	7	66	902	52001	62799	\N	55.506825999999997	Чувашская Республика - Чувашия, Вурнарский район, Апнерское сельское поселение,д.Апнеры, Кузнецкая, 32А		0101000020E61000007D3F355EBA7747409961A3ACDFC04B40
12664	7	66	902	52020	62835	\N	55.545523000000003	Чувашская Республика - Чувашия, Вурнарский район, Большеторханское сельское поселение,д.Альмень-Сунары, Центральная, 17		0101000020E6100000EE974F560C834740A01B9AB2D3C54B40
12697	7	66	902	52091	62706	\N	55.646853	Чувашская Республика - Чувашия, Вурнарский район, Ермошкинское сельское поселение,д.Альменево, Садовая, 13		0101000020E61000005B9A5B21AC764740E5284014CCD24B40
12657	7	66	902	51997	62701	\N	55.597316999999997	Чувашская Республика - Чувашия, Вурнарский район, Алгазинское сельское поселение,д.Алгазино, Центральная, 1		0101000020E61000002CB81FF0C0784740232C2AE274CC4B40
12652	7	66	902	51973	62140	\N	55.615099999999998	Чувашская Республика - Чувашия, Вурнарский район, Азимсирминское сельское поселение,д.Азим-Сирма, Советская, 22		0101000020E6100000EA7B0DC1715F474082E2C798BBCE4B40
12660	7	66	902	33102	61820	\N	55.535203000000003	Чувашская Республика - Чувашия, Вурнарский район, Апнерское сельское поселение,д.Абызово, Солнечная, 1А		0101000020E6100000EFE53E390A7647404DDC2A8881C44B40
12638	7	66	619	51938	62138	\N	55.074226000000003	Чувашская Республика - Чувашия, Батыревский район, Бикшикское сельское поселение, д.Яншихово, Центральная, 2		0101000020E61000000D6C956071C04740A741D13C80894B40
12595	7	66	619	4208	61328	\N	55.051766999999998	Чувашская Республика - Чувашия, Батыревский район, Шыгырданское сельское поселение, с.Шыгырдан, Ленина, 58	Россия, республика Чувашская, Батыревский район, село Шыгырдан	0101000020E6100000A33A1DC87AC647408A01124DA0864B40
12592	7	66	619	4208	61328	\N	55.051766999999998	Чувашская Республика - Чувашия, Батыревский район, Шыгырданское сельское поселение, с.Шыгырдан, Ленина, 39		0101000020E6100000A33A1DC87AC647408A01124DA0864B40
12593	7	66	619	4208	61659	\N	55.051766999999998	Чувашская Республика - Чувашия, Батыревский район, Шыгырданское сельское поселение, с.Шыгырдан, Вахитова, 39б		0101000020E6100000A33A1DC87AC647408A01124DA0864B40
12614	7	66	619	32855	61926	\N	55.025421000000001	Чувашская Республика - Чувашия, Батыревский район, Шаймурзинское сельское поселение, д. Шаймурзино, Николаева, 1		0101000020E6100000A9DBD9571EB04740D9D0CDFE40834B40
12601	7	66	619	52912	62035	\N	55.127208000000003	Чувашская Республика - Чувашия, Батыревский район, Долгоостровское сельское поселение, д. Чувашские Ишаки, Куракова, 34		0101000020E6100000C233A14962BF474011E50B5A48904B40
12619	7	66	619	58044	62929	\N	54.948307999999997	Чувашская Республика - Чувашия, Батыревский район, Тарханское сельское поселение, пос. Хурама Твар, Николаева, 1	Россия, республика Чувашская, Батыревский район, село Хумара-Твар	0101000020E61000002C2AE27492AB47408044132862794B40
12626	7	66	619	6017	62779	\N	55.076680000000003	Чувашская Республика - Чувашия, Батыревский район, Бахтигильдинское сельское поселение, пос. Ульяновка, Советская, 44		0101000020E6100000583CF548838D4740EF2076A6D0894B40
12597	7	66	619	4441	61971	\N	55.072690000000001	Чувашская Республика - Чувашия, Батыревский район, Туруновское сельское поселение, с. Туруново, Магистральная, 35		0101000020E6100000F549EEB089C84740855FEAE74D894B40
12605	7	66	619	4871	61981	\N	55.075443	Чувашская Республика - Чувашия, Батыревский район, Тойсинское сельское поселение, с. Тойси, Учительская, 8		0101000020E61000008E06F01648E2474027DBC01DA8894B40
12640	7	66	619	51944	62833	\N	55.061926	Чувашская Республика - Чувашия, Батыревский район, Бикшикское сельское поселение, д. Тигашево, Депутатская, 33б		0101000020E61000000F43AB9333C04740D462F030ED874B40
12602	7	66	619	52915	62697	\N	55.12238	Чувашская Республика - Чувашия, Батыревский район, Новоахпердинское сельское поселение, д.Татмыш-Югелево, Школьная, 1		0101000020E6100000FA47DFA469D247409DD7D825AA8F4B40
12610	7	66	619	52931	62136	\N	55.085095000000003	Чувашская Республика - Чувашия, Батыревский район, Тойсинское сельское поселение, д, Татарские Тимяши, Овражная, 1а		0101000020E6100000F7E978CC40E94740CD069964E48A4B40
12643	7	66	619	33035	61984	\N	54.990864999999999	Чувашская Республика - Чувашия, Батыревский район, Татарско-Сугутское сельское поселение, д. Татарские Сугуты, Школьная, 29		0101000020E61000001668774831DA474022E010AAD47E4B40
12617	7	66	619	5446	61862	\N	55.008479999999999	Чувашская Республика - Чувашия, Батыревский район, Тарханское сельское поселение, с. Тарханы, Кокеля, 12		0101000020E6100000B95164ADA1AA4740C55565DF15814B40
12616	7	66	619	5446	61862	\N	55.008479999999999	Чувашская Республика - Чувашия, Батыревский район, Тарханское сельское поселение, с.Тарханы, Кокеля, 12		0101000020E6100000B95164ADA1AA4740C55565DF15814B40
12641	7	66	619	6762	61330	\N	54.998499000000002	Чувашская Республика - Чувашия, Батыревский район, Сугутское сельское поселение, с. Сугуты, Советская, 1	Россия, республика Чувашская, Батыревский район, село Сугуты	0101000020E6100000384C3448C1D147405B0BB3D0CE7F4B40
12609	7	66	619	32822	61982	\N	55.074303	Чувашская Республика - Чувашия, Батыревский район, Тойсинское сельское поселение, д. Старые Тойси, Кооперативная, 4		0101000020E61000004C6BD3D85EE94740527FBDC282894B40
12604	7	66	619	4834	\N	\N	55.082168000000003	Чувашская Республика - Чувашия, Батыревский район, Новоахпердинское сельское поселение, д. Старое Котяково, ул. Ленина, 60	Россия, республика Чувашская, Батыревский район, село Старое Котяково	0101000020E6100000EA92718C64D147408D63247B848A4B40
12608	7	66	619	52923	62834	\N	55.073489000000002	Чувашская Республика - Чувашия, Батыревский район, Тойсинское сельское поселение, д. Старое Ахпердино, Кооперативная, 4		0101000020E6100000A3737E8AE3DC4740D1CE691668894B40
12631	7	66	619	51922	62696	\N	55.08323	Чувашская Республика - Чувашия, Батыревский район, Первомайское сельское поселение, д. Сидели, Пионерская, 32		0101000020E6100000CD04C3B986A54740E605D847A78A4B40
12624	7	66	619	52958	62037	\N	55.013131000000001	Чувашская Республика - Чувашия, Батыревский район, Сигачинское сельское поселение, д. Сигачи, Победы, 2		0101000020E6100000AEA0698995A347402AC8CF46AE814B40
12623	7	66	619	52958	62037	\N	55.013131000000001	Чувашская Республика - Чувашия, Батыревский район, Сигачинское сельское поселение, д. Сигачи, Победы, 3		0101000020E6100000AEA0698995A347402AC8CF46AE814B40
12636	7	66	619	32995	61814	\N	55.094436000000002	Чувашская Республика - Чувашия, Батыревский район, Бикшикское сельское поселение, д. Полевые Бикшики, Камалетдинова, 2		0101000020E6100000280CCA349ABC474054C8957A168C4B40
12632	7	66	619	51924	62698	\N	55.070735999999997	Чувашская Республика - Чувашия, Батыревский район, Первомайское сельское поселение, д. Полевое Чекурово, Нижняя, 8		0101000020E6100000C74CA25EF0AB47402E5393E00D894B40
12613	7	66	619	32852	61924	\N	55.016027000000001	Чувашская Республика - Чувашия, Батыревский район, Норваш-Шигалинское сельское поселение, д. Подлесные Шигали, Центральная, 1		0101000020E61000005DC47762D6B747402F6D382C0D824B40
12634	7	66	619	6440	61813	\N	55.077323999999997	Чувашская Республика - Чувашия, Батыревский район, Первомайское сельское поселение, с. Первомайское, Кирова, 71		0101000020E61000009599D2FA5BAE47401399B9C0E5894B40
12612	7	66	619	57917	61987	\N	55.033356427613299	Чувашская Республика - Чувашия, Батыревский район, Норваш-Шигалинское сельское поселение, с. Норваш-Шигали, Главной дороги, 8	Россия, республика Чувашская, Батыревский район, село НорвашШигали	0101000020E61000008CD8278062BA47400C90680245844B40
12599	7	66	619	52908	62036	\N	55.100520000000003	Чувашская Республика - Чувашия, Батыревский район, Туруновское сельское поселение, д. Новое Котяково, Напольная, 35		0101000020E610000047C9AB730CCA4740064CE0D6DD8C4B40
12611	7	66	619	52934	62830	\N	55.085121000000001	Чувашская Республика - Чувашия, Батыревский район, Тойсинское сельское поселение, д. Новое Бахтиарово, Кирова, 29		0101000020E61000002DB5DE6FB4DF4740F699B33EE58A4B40
12603	7	66	619	4765	61812	\N	55.087048000000003	Чувашская Республика - Чувашия, Батыревский район, Новоахпердинское сельское поселение, с. Новое Ахпердино, Ленина, 47		0101000020E61000009AD18F8653D8474053978C63248B4B40
12615	7	66	619	32867	61859	\N	55.033645999999997	Чувашская Республика - Чувашия, Батыревский район, Шаймурзинское сельское поселение, д. Нижнее Турмышево, Школьная, 22		0101000020E6100000B4024356B7AC474013D21A834E844B40
12637	7	66	619	51936	62831	\N	55.077993999999997	Чувашская Республика - Чувашия, Батыревский район, Бикшикское сельское поселение, д. Малые Арабузи, Садовая, 19		0101000020E6100000BB5F05F86EB9474061A417B5FB894B40
12598	7	66	619	52903	62034	\N	55.075184999999998	Чувашская Республика - Чувашия, Батыревский район, Туруновское сельское поселение, д. Малое Батырево, Крепкова, 38		0101000020E6100000AFB5F7A92ACC47402B137EA99F894B40
12627	7	66	619	6028	62038	\N	55.042231000000001	Чувашская Республика - Чувашия, Батыревский район, Бахтигильдинское сельское поселение, пос. Люля, Набережная, 9		0101000020E61000008DEDB5A0F78447404EF04DD367854B40
12646	7	66	619	51954	62832	\N	54.987110000000001	Чувашская Республика - Чувашия, Батыревский район, Кзыл-Чишминское сельское поселение, д. Красномайск, Центральная, 58		0101000020E6100000B020CD5834EB4740FCC6D79E597E4B40
12635	7	66	619	51933	62828	\N	55.068004000000002	Чувашская Республика - Чувашия, Батыревский район, Первомайское сельское поселение, д. Кокшаново, Советская, 89		0101000020E610000002F566D47CB34740A4FFE55AB4884B40
12645	7	66	619	40245	9638	\N	54.993897532391898	Чувашская Республика - Чувашия, Батыревский район, Кзыл-Чишминское сельское поселение, д. Кзыл-Чишма, Центральная, 1	Россия, республика Чувашская, Батыревский район, село Кзыл-Чишма	0101000020E6100000F226BF4527E74740A8C7B60C387F4B40
12596	7	66	619	52898	62104	\N	54.997647000000001	Чувашская Республика - Чувашия, Батыревский район, Шыгырданское сельское поселение, д. Кзыл-Камыш, Школьная, 7		0101000020E610000043E21E4B1FCA4740ECF99AE5B27F4B40
12639	7	66	619	51942	62700	\N	55.068654000000002	Чувашская Республика - Чувашия, Батыревский район, Бикшикское сельское поселение, д. Именево, Братьев Шигабетдиновых, 1а		0101000020E6100000A5828AAA5FB94740AB5E7EA7C9884B40
12600	7	66	619	32755	61843	\N	55.117499000000002	Чувашская Республика - Чувашия, Батыревский район, Долгоостровское сельское поселение, д. Долгий Остров, Апанаева, 10		0101000020E6100000E86C01A1F5C4474007280D350A8F4B40
12633	7	66	619	51929	62827	\N	55.100617999999997	Чувашская Республика - Чувашия, Батыревский район, Первомайское сельское поселение, д. Верхние Бюртли-Шигали, Колхозная, 3		0101000020E61000001C06F357C8A84740C8B1F50CE18C4B40
12607	7	66	619	52922	62135	\N	55.075175000000002	Чувашская Республика - Чувашия, Батыревский район, Тойсинское сельское поселение, д. Булаково, Канашская, 2		0101000020E6100000D3DA34B6D7D84740083D9B559F894B40
12621	7	66	619	5749	62137	\N	55.025199000000001	Чувашская Республика - Чувашия, Батыревский район, Большечеменевское сельское поселение, с. Большое Чеменево, Ф. Туптова, 38		0101000020E6100000D10836AE7F9F47402A7288B839834B40
12625	7	66	619	52960	62695	\N	55.089799807345997	Чувашская Республика - Чувашия, Батыревский район, Бахтигильдинское сельское поселение, д. Бахтигильдино, Школьная, 35	Россия, республика Чувашская, Батыревский район, село Бахтигильдино	0101000020E6100000B7989F1B9A9847402497FF907E8B4B40
12588	7	66	619	3993	\N	\N	55.063120878445503	Чувашская Республика - Чувашия, Батыревский район, Батыревское сельское поселение	Россия, республика Чувашская, Батыревский район, село Батырево	0101000020E6100000CFA10C5531CD47406D58535914884B40
12590	7	66	619	3993	61324	\N	55.062961999999999	Чувашская Республика - Чувашия, Батыревский район, Батыревское сельское поселение, с. Батырево, пр-т Ленина, 30	Россия, республика Чувашская, Батыревский район, село Батырево	0101000020E6100000B9196EC0E7CD4740047289230F884B40
12589	7	66	619	3993	61658	\N	55.062961999999999	Чувашская Республика - Чувашия, Батыревский район, Батыревское сельское поселение, с. Батырево, ул. Советская, 10		0101000020E6100000B9196EC0E7CD4740047289230F884B40
12628	7	66	619	51917	62042	\N	55.103406120583202	Чувашская Республика - Чувашия, Батыревский район, Бахтигильдинское сельское поселение, д. Балабаш-Нурусово, Советская, 22	Россия, республика Чувашская, Батыревский район, село Балабаш-Нурусово	0101000020E61000001EF98381E79E4740E71A66683C8D4B40
12629	7	66	619	6170	61865	\N	55.068643999999999	Чувашская Республика - Чувашия, Батыревский район, Балабаш-Баишевское сельское поселение, с. Балабаш-Баишево, Кузнечная, 2		0101000020E6100000EC681CEA77A1474087889B53C9884B40
12622	7	66	619	52957	62694	\N	55.027752999999997	Чувашская Республика - Чувашия, Батыревский район, Большечеменевское сельское поселение, д. Бакашево, Новая, 73		0101000020E61000005F27F565699D4740D5AE09698D834B40
12644	7	66	619	6887	61927	\N	54.984037000000001	Чувашская Республика - Чувашия, Батыревский район, Алманчиковское сельское поселение, с. Алманчиково, Центральная, 3		0101000020E61000008351499D80E24740E886A6ECF47D4B40
12620	7	66	619	52951	62672	\N	54.9644924880281	Чувашская Республика - Чувашия, Батыревский район, Тарханское сельское поселение, д. Абамза, Центральная, 7	Россия, республика Чувашская, Батыревский район, село Абамза	0101000020E6100000CD04C3B9869F474077A04E79747B4B40
12563	7	66	362	52809	\N	\N	55.764814999999999	Чувашская Республика - Чувашия, Аликовский район, Крымзарайкинское сельское поселение, д.Яргунькино, сельская библиотека, читальный зал		0101000020E61000009D83674293584740C03E3A75E5E14B40
12585	7	66	362	3815	\N	\N	55.724738000000002	Чувашская Республика - Чувашия, Аликовский район, Яндобинское сельское поселение, с.Яндоба, КДЦ, зрительный зал	Россия, республика Чувашская, Аликовский район, село Яндоба	0101000020E6100000200A664CC17C47409015FC36C4DC4B40
12575	7	66	362	3265	\N	\N	55.689253191023397	Чувашская Республика - Чувашия, Аликовский район, д.Эренары, бывшее здание ФАП	Россия, республика Чувашская, Аликовский район, село Эренары	0101000020E610000090A1630795624740BFD53A7139D84B40
12567	7	66	362	52821	\N	\N	55.6693512802131	Чувашская Республика - Чувашия, Аликовский район, Раскильдинское сельское поселение, д.Шундряши, сельский клуб	Россия, республика Чувашская, Аликовский район, село Шундряши	0101000020E6100000B9A81611C5484740BF45274BADD54B40
12580	7	66	362	3574	\N	\N	55.785851999999998	Чувашская Республика - Чувашия, Аликовский район, Шумшевашское сельское поселение, с.Шумшеваши, СДК, 1 этаж, фойе	Россия, республика Чувашская, Аликовский район, село Шумшеваши	0101000020E6100000F8E28BF67847474083BF5FCC96E44B40
12571	7	66	362	52828	\N	\N	55.729525428277903	Чувашская Республика - Чувашия, Аликовский район, Таутовское сельское поселение, д.Шерашево, сельский клуб, зрительный зал		0101000020E610000043AED4B3204C4740A54E401361DD4B40
12576	7	66	362	3352	\N	\N	55.823312000000001	Чувашская Республика - Чувашия, Аликовский район, Чувашско-Сорминское сельское поселение, с.Чувашская Сорма, КДЦ, фойе		0101000020E6100000C3F5285C8F6A4740C233A14962E94B40
12586	7	66	362	52875	\N	\N	55.740628999999998	"Чувашская Республика - Чувашия, Аликовский район, Яндобинское сельское поселение, д.Челкасы, адмздание СХПК ""Звезда"", зал заседаний"		0101000020E6100000D218ADA3AA7947400EBC5AEECCDE4B40
12573	7	66	362	52839	\N	\N	55.733902999999998	Чувашская Республика - Чувашия, Аликовский район, Таутовское сельское поселение, д.Хирлеппоси, сельский клуб-библиотека, зрительный зал		0101000020E610000043E1B37570544740D8B79388F0DD4B40
12565	7	66	362	2702	\N	\N	55.804201999999997	Чувашская Республика - Чувашия, Аликовский район, Питишевское сельское поселение, с.Устье, Устьинский ФАП		0101000020E6100000FE481119565F47405BB05417F0E64B40
12772	7	66	362	57897	61786	\N	55.723126000000001	д.Урмаево, Баумана, 3	Россия, республика Чувашская, Аликовский район, село Урмаево	0101000020E6100000D9E90775915E474093718C648FDC4B40
12569	7	66	362	52826	\N	\N	55.674702000000003	Чувашская Республика - Чувашия, Аликовский район, Раскильдинское сельское поселение, д.Тури-Выла, сельская библиотека-клуб, зрительный зал		0101000020E6100000957EC2D9AD434740DD4598A25CD64B40
12574	7	66	362	3249	\N	\N	55.685766999999998	Чувашская Республика - Чувашия, Аликовский район, Тенеевское сельское поселение, с.Тенеево, СДК, фойе		0101000020E6100000D15790662C60474088D68A36C7D74B40
12570	7	66	362	57900	\N	\N	55.707355470863803	Чувашская Республика - Чувашия, Аликовский район, Таутовское сельское поселение, д.Таутово, КДЦ, фойе	Россия, республика Чувашская, Аликовский район, село Таутово	0101000020E6100000A69C2FF65E504740BFD4CF9B8ADA4B40
12556	7	66	362	52794	\N	\N	55.742503999999997	Чувашская Республика - Чувашия, Аликовский район, Большевыльское сельское поселение, д.Сириккасы, дом фольклора, фойе		0101000020E6100000069CA564394147401893FE5E0ADF4B40
12587	7	66	362	3888	\N	\N	55.766627999999997	Чувашская Республика - Чувашия, Аликовский район, Яндобинское сельское поселение, с.Русская Сорма, сельская библиотека, читальный зал		0101000020E610000047C66AF3FF7247405419C6DD20E24B40
12566	7	66	362	2744	\N	\N	55.684016	Чувашская Республика - Чувашия, Аликовский район, Раскильдинское сельское поселение, с.Раскильдино, КДЦ, зрительный зал		0101000020E6100000C0B167CF654A47406AF816D68DD74B40
12581	7	66	362	52859	\N	\N	55.793905000000002	Чувашская Республика - Чувашия, Аликовский район, Шумшевашское сельское поселение, д.Прошкино, здание ФАП	Россия, республика Чувашская, Аликовский район, село Прошкино	0101000020E6100000297B4B395F4C4740C190D5AD9EE54B40
12564	7	66	362	52811	\N	\N	55.795904	Чувашская Республика - Чувашия, Аликовский район, Питишевское сельское поселение, д.Питишево, СДК, зрительный зал		0101000020E61000000E83F92B64584740B760A92EE0E54B40
12578	7	66	362	52848	\N	\N	55.786980999999997	Чувашская Республика - Чувашия, Аликовский район, Чувашско-Сорминское сельское поселение, д.Нижние Елыши, сельский клуб-библиотека, фойе		0101000020E61000001615713AC96C474064C91CCBBBE44B40
12579	7	66	362	52852	\N	\N	55.821703999999997	Чувашская Республика - Чувашия, Аликовский район, Чувашско-Сорминское сельское поселение, д.Мартынкино, сельский клуб-библиотека, фойе		0101000020E6100000FB07910C39764740067FBF982DE94B40
12572	7	66	362	32558	\N	\N	55.685087000000003	Чувашская Республика - Чувашия, Аликовский район, Таутовское сельское поселение, д.Малые Туваны, сельский клуб, второй этаж, фойе		0101000020E610000050C422861D58474017F549EEB0D74B40
12562	7	66	362	2562	\N	\N	55.780866000000003	Чувашская Республика - Чувашия, Аликовский район, Крымзарайкинское сельское поселение, с.Крымзарайкино, информационно-культурный центр		0101000020E6100000F0DC7BB8E45447407847C66AF3E34B40
12583	7	66	362	52869	\N	\N	55.777706999999999	Чувашская Республика - Чувашия, Аликовский район, Шумшевашское сельское поселение, д.Кивой, сельский клуб, зрительный зал		0101000020E6100000B9AB5791D1414740656F29E78BE34B40
12582	7	66	362	52863	\N	\N	55.761740000000003	Чувашская Республика - Чувашия, Аликовский район, Шумшевашское сельское поселение, д.Ишпарайкино, СДК, зал заседаний		0101000020E610000052B7B3AF3C4E47400C0742B280E14B40
12561	7	66	362	57905	\N	\N	55.772404568828598	"Чувашская Республика - Чувашия, Аликовский район, Илгышевское сельское поселение, д.Илгышево, МБОУ ""Илгышевская СОШ"", 1 этаж, фойе"		0101000020E610000074232C2AE26047402922C32ADEE24B40
12558	7	66	362	57899	\N	\N	55.715690073738998	Чувашская Республика - Чувашия, Аликовский район, Ефремкасинское сельское поселение, д.Ефремкасы, КДЦ, фойе	Россия, республика Чувашская, Аликовский район, село Ефремкасы	0101000020E61000002B69C537146A47408109DCBA9BDB4B40
12560	7	66	362	18911	\N	\N	55.735162821969404	Чувашская Республика - Чувашия, Аликовский район, Ефремкасинское сельское поселение, д.Вотланы, СДК, фойе		0101000020E6100000A4367172BF6F4740581D39D219DE4B40
12559	7	66	362	33115	\N	\N	55.682920000000003	Чувашская Республика - Чувашия, Аликовский район, Ефремкасинское сельское поселение, д.Верхние Карачуры, СДК, 1 этаж		0101000020E610000024D5777E5170474065E42CEC69D74B40
12584	7	66	362	58019	\N	\N	55.761263999999997	"Чувашская Республика - Чувашия, Аликовский район, Шумшевашское сельское поселение, с.Большое Ямашево, МБОУ ""Большеямашевская СОШ"", 1 этаж, фойе"	Россия, республика Чувашская, Аликовский район, село Большое Ямашаево	0101000020E6100000F72004E44B3A4740A2CF471971E14B40
12577	7	66	362	52845	\N	\N	55.840609000000001	Чувашская Республика - Чувашия, Аликовский район, Чувашско-Сорминское сельское поселение, д.Большие Шиуши, здание конторы производственного участка	Россия, республика Чувашская, Аликовский район, село Большие Шиуши	0101000020E61000003BE2900DA46B474094DC611399EB4B40
54079	7	62	\N	1218	62299	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Сомбатхей, д. 22		0101000020E6100000628731E9EFEF4740ACE122F774514C40
12568	7	66	362	52822	\N	\N	55.671219000000001	Чувашская Республика - Чувашия, Аликовский район, Раскильдинское сельское поселение, д.Большие Токташи, прокатный пункт, зрительный зал		0101000020E610000084B872F6CE4E474017BA1281EAD54B40
12555	7	66	362	2125	\N	\N	55.725782000000002	"Чувашская Республика - Чувашия, Аликовский район, Большевыльское сельское поселение, с.Большая Выла, МБОУ ""Большевыльская СОШ"", спортзал"		0101000020E6100000CB65A3737E4647404303B16CE6DC4B40
12554	7	66	362	1859	61810	\N	55.737856000000001	Чувашская Республика - Чувашия, Аликовский район, Аликовское сельское поселение, с.Аликово, ул.Советская, д.15		0101000020E610000001F9122A386047402594BE1072DE4B40
12552	7	66	362	1859	61810	\N	55.737856000000001	Чувашская Республика - Чувашия, Аликовский район, Аликовское сельское поселение, с.Аликово, ул.Советская, д.13, 1 этаж		0101000020E610000001F9122A386047402594BE1072DE4B40
12551	7	66	362	1859	61810	\N	55.737856000000001	Чувашская Республика - Чувашия, Аликовский район, Аликовское сельское поселение, с.Аликово, ул.Советская, д.13		0101000020E610000001F9122A386047402594BE1072DE4B40
12522	7	66	107	151	62017	\N	54.867119000000002	деревня Ялушево, Озерная, 1		0101000020E610000083A10E2BDC444740C05E61C1FD6E4B40
12338	7	66	107	23998	62774	\N	54.914409999999997	село Явлеи, Первомайская, 5		0101000020E61000009CFC169D2C49474053910A630B754B40
12521	7	66	107	32935	61853	\N	54.863275000000002	село Чуварлеи, Ворошилова, 144		0101000020E610000031D3F6AFAC4047402A3A92CB7F6E4B40
12463	7	66	107	29765	62023	\N	55.024450000000002	село Сурский Майдан, Чебоксарская, 72		0101000020E6100000AC1E300F994447409031772D21834B40
12520	7	66	107	32497	61649	\N	54.786107210074498	село Стемасы, Ленина, 124	Россия, республика Чувашская, Алатырский район, село Стемасы	0101000020E61000000C01C0B1674F47400E1478279F644B40
12519	7	66	107	32410	61837	\N	54.950024999999997	село Старые Айбеси, Школьная, 5		0101000020E6100000FA6184F068854740F2B0506B9A794B40
12512	7	66	107	47246	62691	\N	54.679279999999999	поселок Соловьевский, Верхнее-Иветская, 5		0101000020E6100000516A2FA2ED684740D769A4A5F2564B40
12518	7	66	107	32404	61854	\N	54.786881999999999	село Сойгино, К.Маркса, 38		0101000020E6100000A968ACFD9D894740D1E7A38CB8644B40
12517	7	66	107	54713	38894	\N	54.914147085237097	поселок Первомайский, Ленина, 50	Россия, республика Чувашская, Алатырский район, село Первомайский	0101000020E610000081D1E5CDE17A4740465ED6C402754B40
12444	7	66	107	28905	61920	\N	54.807496999999998	село Новые Айбеси, Ленина, 18		0101000020E61000000A2B1554548547401E4FCB0F5C674B40
12499	7	66	107	31541	61914	\N	54.899425999999998	село Миренки, Советская-2, 42		0101000020E6100000F06AB933133247400796236420734B40
12416	7	66	107	27627	62121	\N	54.975942797569402	село Междуречье, 50 лет ЧАССР, 14	Россия, республика Чувашская, Алатырский район, село Междуречье	0101000020E6100000EF5696E82C4347404CE141B3EB7C4B40
12513	7	66	107	47259	62131	\N	54.978819000000001	село Кувакино, Пролетарская, 1		0101000020E61000001F115322893447400ADAE4F0497D4B40
12523	7	66	107	205	61855	\N	55.081457	поселок Киря, Сидорина, 8		0101000020E6100000EF8D2100386E4740E083D72E6D8A4B40
12524	7	66	107	205	61925	\N	55.0814079416743	поселок Киря, Лермонтова, 5	Россия, республика Чувашская, Алатырский район, поселок Киря	0101000020E6100000DAC87553CA6D4740FFD0CC936B8A4B40
12514	7	66	107	32230	62784	\N	54.97777	село Ичиксы, Новая линия, 6а		0101000020E610000083DC4598A23C474045813E91277D4B40
12511	7	66	107	32073	61852	\N	54.726376999999999	село Иваньково-Ленино, Пушкина, 1а		0101000020E6100000AC00DF6DDE56474086C8E9EBF95C4B40
12510	7	66	107	54269	35834	\N	54.802858000000001	поселок Восход, Садовая, 9	Россия, республика Чувашская, Алатырский район, село Восход	0101000020E6100000E4A3C519C34A47407EAA0A0DC4664B40
12515	7	66	107	32271	62132	\N	54.965072999999997	село Березовый Майдан, Кооперативная, 22		0101000020E61000005AA148F7732E474055A01683877B4B40
12509	7	66	107	32002	38909	\N	54.853541999999997	село Ахматово, Ленина, 53	Россия, республика Чувашская, Алатырский район, село Ахматово	0101000020E610000066D993C0E634474097E13FDD406D4B40
12508	7	66	107	31915	62689	\N	55.008996000000003	поселок Атрать, Комсомольская, 7		0101000020E61000009964E42CEC554740BDE5EAC726814B40
12507	7	66	107	31915	62027	\N	55.008996000000003	село Атрать, Кирова, 2а		0101000020E61000009964E42CEC554740BDE5EAC726814B40
12506	7	66	107	47119	62026	\N	54.828771000000003	поселок Анютино, Молодежная, 10		0101000020E6100000CCB6D3D6885A4740C66F0A2B156A4B40
12505	7	66	107	32821	61917	\N	54.899770995609998	село Алтышево, ул. Октябрьская, 2б	Россия, республика Чувашская, Алатырский район, село Алтышево	0101000020E610000013B875374F5B4740D27135B22B734B40
12516	7	66	107	32821	61921	\N	54.900117237579302	поселок Алтышево, Заводская, 6	Россия, республика Чувашская, Алатырский район, село Алтышево	0101000020E6100000D784B4C6A05B47406DC9AA0837734B40
6451	7	65	\N	56388	52895	\N	56.783462864656002	Удмуртская Республика, Завьяловский район, д. Шудья, Досуговый центр, ул. Центральная, д. 13	Россия, республика Удмуртская, деревня Шудья	0101000020E6100000611BF16437894A402250FD8348644C40
6182	7	65	\N	11375	\N	\N	56.456108176907101	427960, Адрес УИК и помещения для голосования: Удмуртская Республика, город Сарапул, ул.Пугачева (здание лингвистической гимназии №20), д.130	Россия, республика Удмуртская, Сарапул	0101000020E610000060E63BF889E54A40D4B837BF613A4C40
6176	7	65	\N	11375	\N	\N	56.474353584898402	427960, Адрес УИК и помещения для голосования: Удмуртская Республика, город Сарапул, ул.Труда (здание политехнического института), д.8	Россия, республика Удмуртская, Сарапул	0101000020E6100000261B0FB6D8E54A40075DC2A1B73C4C40
6199	7	65	\N	11375	52481	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Электрозаводская, д.3		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6208	7	65	\N	11375	52655	\N	56.465643999999998	Удмуртская Республика, город Сарапул, поселок Дубровка, ул.Школьная, д.22		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6202	7	65	\N	11375	52618	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Чистякова, д.42		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6197	7	65	\N	11375	52410	\N	56.453475894136901	Удмуртская Республика, город Сарапул, ул.Фурманова, д.1а	Россия, республика Удмуртская, Сарапул	0101000020E61000009B374E0AF3E04A40ADC266800B3A4C40
6200	7	65	\N	11375	52576	\N	56.466021430607199	Удмуртская Республика, город Сарапул, ул.Фрунзе, д.18	Россия, республика Удмуртская, Сарапул	0101000020E6100000DD41EC4CA1E34A40E61F7D93A63B4C40
6191	7	65	\N	11375	52408	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Фабричная, д.1а		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6186	7	65	\N	11375	52476	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Труда, д.62		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6184	7	65	\N	11375	52573	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Степана Разина, д.59		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6172	7	65	\N	11375	52404	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Советская, д.69		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6170	7	65	\N	11375	52572	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Соболева, д.15		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6187	7	65	\N	11375	52475	\N	56.4658907693807	Удмуртская Республика, город Сарапул, ул.Пугачева, д.63	Россия, республика Удмуртская, Сарапул	0101000020E6100000B8C9A8328CE34A401840F850A23B4C40
6185	7	65	\N	11375	52475	\N	56.465926404305399	Удмуртская Республика, город Сарапул, ул.Пугачева, д.60	Россия, республика Удмуртская, Сарапул	0101000020E610000041F163CC5DE34A40952D9276A33B4C40
6183	7	65	\N	11375	52475	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Пугачева, д.76		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6180	7	65	\N	11375	52475	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Пугачева, д.130		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6175	7	65	\N	11375	52387	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Первомайская, д.22а		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6193	7	65	\N	11375	52616	\N	56.466140213148599	Удмуртская Республика, город Сарапул, ул.Озерная, д.108	Россия, республика Удмуртская, Сарапул	0101000020E6100000DCD9571EA4E34A40C1ADBB79AA3B4C40
6201	7	65	\N	11375	52778	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Молодежная, д.5		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6206	7	65	\N	11375	52479	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Мельникова, д.8		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6195	7	65	\N	11375	52409	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Ленина, д.78а		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6192	7	65	\N	11375	52480	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Крылова, д.15		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6177	7	65	\N	11375	52615	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Красноармейская, д.93		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6168	7	65	\N	11375	52402	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Костычева, д.28		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6194	7	65	\N	11375	52619	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Комсомольская, д.37		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6204	7	65	\N	11375	52477	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Калинина, д.5		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6198	7	65	\N	11375	52617	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Жуковского, д.14		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6178	7	65	\N	11375	52391	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Горького, д.102		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6148	7	65	\N	11375	52391	\N	56.476146024163697	Удмуртская Республика, город Сарапул, ул.Горького, д.61б	Россия, республика Удмуртская, Сарапул	0101000020E610000037C5E3A25AE64A40840F255AF23C4C40
6210	7	65	\N	11375	52478	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Гончарова, д.1а		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6207	7	65	\N	11375	52478	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Гончарова, д.40		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6205	7	65	\N	11375	52478	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Гончарова, д.53		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6189	7	65	\N	11375	52405	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Гоголя, д.99		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6174	7	65	\N	11375	52405	\N	56.464786070059198	Удмуртская Республика, город Сарапул, ул.Гоголя, д.23	Россия, республика Удмуртская, Сарапул	0101000020E6100000C860C5A9D6E44A40BFD18E1B7E3B4C40
6173	7	65	\N	11375	52405	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Гоголя, д.30а		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6181	7	65	\N	11375	52407	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Гагарина, д.52		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6179	7	65	\N	11375	52407	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Гагарина, д.85		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6196	7	65	\N	11375	52577	\N	56.451123142800398	Удмуртская Республика, город Сарапул, ул.Вокзальная, д.13	Россия, республика Удмуртская, Сарапул	0101000020E6100000F2CD3637A6E34A4099BC0166BE394C40
6190	7	65	\N	11375	52406	\N	56.465736350985601	Удмуртская Республика, город Сарапул, ул.Азина, д.140	Россия, республика Удмуртская, Сарапул	0101000020E6100000B9FDF2C98AE34A40F148BC3C9D3B4C40
6188	7	65	\N	11375	52406	\N	56.465643999999998	Удмуртская Республика, город Сарапул, ул.Азина, д.75		0101000020E61000001ADD41EC4CE34A4010CAFB389A3B4C40
6169	7	65	\N	11375	52777	\N	56.466211482494401	Удмуртская Республика, город Сарапул, ул.Tрактовая, д.21	Россия, республика Удмуртская, Сарапул	0101000020E6100000B62DCA6C90E34A408A0453CDAC3B4C40
6209	7	65	\N	11375	52581	\N	56.482742340770102	Удмуртская Республика, город Сарапул, ул.5-й Зеленый проезд, д.5	Россия, республика Удмуртская, Сарапул	0101000020E610000033A9A10DC0E64A40EC33677DCA3D4C40
22756	7	61	317	49404	66094	\N	55.094988000000001	деревня Ленино, Кашаевых, 28		0101000020E61000001B118C834B394B4098C11891288C4B40
6448	7	65	\N	56379	\N	\N	56.855666007815898	Удмуртская Республика, Завьяловский район, д. Позимь, эдание Позимского клуба, д. 25		0101000020E61000000ABFD4CF9BB44A404A26A776866D4C40
6922	7	65	\N	52432	28883	\N	56.779772000000001	Удмуртская Республика, Якшур-Бодьинский район, село Маяк, улица Центральная, 6	Россия, республика Удмуртская, деревня Пирогово, Центральная улица	0101000020E610000026512FF834934A40132BA391CF634C40
6447	7	65	\N	56360	52442	\N	56.854415482924097	"Удмуртская Республика, Завьяловский район, с. Первомайский, МБУ ""КК ""Первомайский"", ул. Сабурова, д. 1-б"		0101000020E6100000309C6B98A1AD4A401E1B81785D6D4C40
6360	7	65	\N	56361	\N	\N	56.840405652718196	"Удмуртская Республика, Завьяловский район, с. Октябрьский, МОУ ""Октябрьская СОШ"", здание"	Россия, республика Удмуртская, село Октябрьский	0101000020E610000009FB761211AA4A405CAE7E6C926B4C40
6146	7	65	\N	11277	\N	\N	56.449364000000003	Удмуртская Республика, город Можга, Компрессорный микрорайон, 19	Россия, республика Удмуртская, Можга	0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6151	7	65	\N	11277	52567	\N	56.449364000000003	Удмуртская Республика, город Можга, Школьный переулок, 1		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6166	7	65	\N	11277	52398	\N	56.449364000000003	Удмуртская Республика, город Можга, Фалалеева, 14		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6163	7	65	\N	11277	52398	\N	56.449364000000003	Удмуртская Республика, город Можга, Фалалеева, 2		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6156	7	65	\N	11277	52569	\N	56.449364000000003	Удмуртская Республика, город Можга, Спортивная, 10		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6155	7	65	\N	11277	52568	\N	56.449364000000003	Удмуртская Республика, город Можга, Советская, 21		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6149	7	65	\N	11277	52395	\N	56.449364000000003	Удмуртская Республика, город Можга, Свердловский бульвар, 71		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6150	7	65	\N	11277	52396	\N	56.449364000000003	Удмуртская Республика, город Можга, Октябрьская, 44		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6165	7	65	\N	11277	52474	\N	56.449364000000003	Удмуртская Республика, город Можга, Наговицына, 199		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6159	7	65	\N	11277	52474	\N	56.449364000000003	Удмуртская Республика, город Можга, Наговицына, 107		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6158	7	65	\N	11277	52397	\N	56.449364000000003	Удмуртская Республика, город Можга, Короленко, 50		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6161	7	65	\N	11277	52471	\N	56.449364000000003	Удмуртская Республика, город Можга, Кирова, 67		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6160	7	65	\N	11277	52471	\N	56.449364000000003	Удмуртская Республика, город Можга, Кирова, 55		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6147	7	65	\N	11277	52472	\N	56.449364000000003	Удмуртская Республика, город Можга, Дзержинского, 1		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6153	7	65	\N	11277	52403	\N	56.449364000000003	Удмуртская Республика, город Можга, Горбунова, 3		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6152	7	65	\N	11277	52403	\N	56.452691474283398	Удмуртская Республика, город Можга, Горбунова, 32	Россия, республика Удмуртская, Можга городской округ	0101000020E61000004D4C1762F51D4A40C61858C7F1394C40
6162	7	65	\N	11277	52494	\N	56.449364000000003	Удмуртская Республика, город Можга, Гагарина, 6		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6157	7	65	\N	11277	52614	\N	56.449364000000003	Удмуртская Республика, город Можга, Вокзальная, 11		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6154	7	65	\N	11277	52613	\N	56.449364000000003	Удмуртская Республика, город Можга, Водокачный переулок, 4		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6164	7	65	\N	11277	52401	\N	56.449364000000003	Удмуртская Республика, город Можга, Вешняковский микрорайон, 13		0101000020E61000008E3BA583F51B4A40F8FF71C284394C40
6519	7	65	\N	28834	\N	\N	56.269320999999998	"Удмуртская Республика, Камбарский район, г.Камбарка, территория ОАО ""136 ЦБПР"", столовая"		0101000020E6100000488787307E1A4B4021904B1C79224C40
6511	7	65	\N	28834	\N	\N	56.269320999999998	Удмуртская Республика, Камбарский район, г.Камбарка, ул.Суворова, д.1(актовый зал МП Камбарская ПМК)	Россия, республика Удмуртская, Камбарка	0101000020E6100000488787307E1A4B4021904B1C79224C40
6512	7	65	\N	28834	52635	\N	56.2656910661334	Удмуртская Республика, Камбарский район, г.Камбарка, пер.Уральский, д.5 (школа №3)	Россия, республика Удмуртская, Камбарка городской округ	0101000020E61000008EAED2DD75184B40B7EBA52902224C40
6524	7	65	\N	28834	52556	\N	56.269320999999998	"Удмуртская Республика, Камбарский район, г.Камбарка, ул.Советская, д.89 (РДЦ ""Овация"")"		0101000020E6100000488787307E1A4B4021904B1C79224C40
6513	7	65	\N	28834	52556	\N	56.269320999999998	Удмуртская Республика, Камбарский район, г.Камбарка, ул.Советская, д.26 (актовый зал колледжа)		0101000020E6100000488787307E1A4B4021904B1C79224C40
6518	7	65	\N	28834	52498	\N	56.269320999999998	Удмуртская Республика, Камбарский район, г.Камбарка, ул. Первомайская, д.237 (школа №2)		0101000020E6100000488787307E1A4B4021904B1C79224C40
6516	7	65	\N	28834	52498	\N	56.269320999999998	Удмуртская Республика, Камбарский район, г.Камбарка, ул.Первомайская, д.237 (актовый зал школы №2)		0101000020E6100000488787307E1A4B4021904B1C79224C40
6517	7	65	\N	28834	52752	\N	56.269320999999998	"Удмуртская Республика, Камбарский район, г.Камбарка, ул.Маяковского, д.2а (КДЦ ""Молодежный"")"		0101000020E6100000488787307E1A4B4021904B1C79224C40
6514	7	65	\N	28834	52496	\N	56.269320999999998	Удмуртская Республика, Камбарский район, г.Камбарка, ул.К.Маркса, д.73 (лицей №1)		0101000020E6100000488787307E1A4B4021904B1C79224C40
6515	7	65	\N	28834	52571	\N	56.269320999999998	Удмуртская Республика, Камбарский район, г.Камбарка, ул.Азина, д.14 (зал д\\с №3)		0101000020E6100000488787307E1A4B4021904B1C79224C40
6034	7	65	\N	70	52447	\N	56.834976991212798	Удмуртская Республика, город Ижевск, Первомайский район, ул.Восточная, д.1		0101000020E610000068EBE0606F9E4A40C3F4BD86E06A4C40
6840	7	65	\N	70	\N	\N	56.924974942000397	427260, Адрес УИК и помещения для голосования: Удмуртская Республика, Увинский район, п.Ува, ул.Школьная (средняя школа №1), д.15	Россия, республика Удмуртская, Ижевск, Октябрьский район	0101000020E61000001CB62DCA6C944A400E4FAF9465764C40
6104	7	65	\N	70	\N	\N	56.919443352897602	427432, Адрес УИК и помещения для голосования: Удмуртская Республика, город Воткинск, ул.Энтузиастов (здание школы №5), д.25	Россия, республика Удмуртская, Ижевск, Октябрьский район	0101000020E6100000CBDB114E0B964A40A0C4E74EB0754C40
6045	7	65	\N	70	\N	\N	56.856701999999999	"Удмуртская Республика, город Ижевск, Первомайский район, микрорайон ""Медведево"", Детско-подростковый клуб ""Колосок"""		0101000020E61000008E06F01648964A407A354069A86D4C40
6010	7	65	\N	70	\N	\N	56.959422717528597	Удмуртская Республика, город Ижевск, Октябрьский район, мкр. Нагорный, Административное здание ПНИ	Россия, республика Удмуртская, Ижевск, Октябрьский район, микрорайон Нагорный	0101000020E610000032E9EFA5F0944A40DE03745FCE7A4C40
5981	7	65	\N	70	\N	\N	56.856701999999999	"426069, Адрес УИК и помещения для голосования: Удмуртская Республика, город Ижевск, Октябрьский район, ул. Студенческая ( здание ФГБОУ ВПО ""ИжГТУ"" ДК ""Интеграл""), д.7"		0101000020E61000008E06F01648964A407A354069A86D4C40
5964	7	65	\N	70	\N	\N	56.835669481035197	Удмуртская Республика, город Ижевск, Ленинский район, Городок Машиностроителей, 61	Россия, республика Удмуртская, Ижевск, Ленинский район, микрорайон Городок Машиностроителей, 61	0101000020E61000008386FE092E8E4A40F9A3A833F76A4C40
6064	7	65	\N	70	52605	\N	56.873896898486997	Удмуртская Республика, город Ижевск, Устиновский район, Петрова, 19	Россия, республика Удмуртская, Ижевск, улица имени Петрова, 19	0101000020E6100000056EDDCD53A54A4048895DDBDB6F4C40
6037	7	65	\N	70	52381	\N	56.823482410537501	Удмуртская Республика, город Ижевск, Первомайский район, ул.Щедрина, д.1	Россия, республика Удмуртская, Ижевск, улица Щедрина, 1	0101000020E610000015E29178799C4A401E6CB1DB67694C40
5977	7	65	\N	70	52536	\N	56.878848311863798	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Школьная, д.54	Россия, республика Удмуртская, Ижевск, Школьная улица, 54	0101000020E6100000685BCD3AE3974A40D7135D177E704C40
5922	7	65	\N	70	52352	\N	56.863505813109001	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Шишкина, 3	Россия, республика Удмуртская, Ижевск, улица Шишкина, 3	0101000020E61000005CE7DF2EFB9D4A402CF3565D876E4C40
5998	7	65	\N	70	52454	\N	56.857724010774497	Удмуртская Республика, город Ижевск, Октябрьский район, пер.Широкий, д.71А	Россия, республика Удмуртская, Ижевск, Широкий переулок, 71а	0101000020E610000045F5D6C0569B4A40457F68E6C96D4C40
5997	7	65	\N	70	52454	\N	56.8580432302888	Удмуртская Республика, город Ижевск, Октябрьский район, пер.Широкий, д.73	Россия, республика Удмуртская, Ижевск, Широкий переулок, 73	0101000020E610000046EEE9EA8E9B4A40E7C75F5AD46D4C40
5966	7	65	\N	70	52588	\N	56.840512690872998	Удмуртская Республика, город Ижевск, Ленинский район, Шевченко, 25		0101000020E6100000909F8D5C378F4A40726E13EE956B4C40
6325	7	65	\N	70	52849	\N	56.841625000000001	427413, Удмуртская Республика, Воткинский район, муниципальное образование «Нововолковское», п.Новый,  ул.Чайковского (здание дома культуры), д.15, адрес УИК: ул.Центральная (здание администрации), д.9		0101000020E6100000D6E07D552E8E4A407D3F355EBA6B4C40
6012	7	65	\N	70	52346	\N	56.878216999999999	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Холмогорова, д.37В	Россия, республика Удмуртская, Ижевск, улица Холмогорова, 37в	0101000020E61000003D433866D99B4A4047E5266A69704C40
6007	7	65	\N	70	52346	\N	56.8788588669794	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Холмогорова, д.37	Россия, республика Удмуртская, Ижевск, улица Холмогорова, 37	0101000020E610000079CC4065FC9B4A40CB65A3737E704C40
6006	7	65	\N	70	52346	\N	56.8744087485316	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Холмогорова, д.34	Россия, республика Удмуртская, Ижевск, улица Холмогорова, 34	0101000020E6100000A3CD716E139C4A40FE2955A2EC6F4C40
6004	7	65	\N	70	52346	\N	56.873993283986401	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Холмогорова, д.22	Россия, республика Удмуртская, Ижевск, улица Холмогорова, 22	0101000020E61000002A5437177F9B4A406AF7AB00DF6F4C40
5938	7	65	\N	70	52341	\N	56.846641376005103	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Халтурина, 2а	Россия, республика Удмуртская, Ижевск, улица Халтурина, 2	0101000020E6100000EB01F39029A14A40F33977BB5E6C4C40
5923	7	65	\N	70	52341	\N	56.865461000000003	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Халтурина, 150	Россия, республика Удмуртская, Ижевск, улица Халтурина, 150	0101000020E610000011A96917D3A04A40537B116DC76E4C40
5912	7	65	\N	70	52517	\N	56.851103079081703	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Университетская, 1	Россия, республика Удмуртская, Ижевск, Университетская улица, 1	0101000020E6100000BED9E6C6F49C4A4085436FF1F06C4C40
5913	7	65	\N	70	52579	\N	56.854506591912802	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Удмуртская, 230	Россия, республика Удмуртская, Ижевск, Удмуртская улица, 230	0101000020E6100000A9D903ADC09C4A40FE99417C606D4C40
5914	7	65	\N	70	52532	\N	56.867052614894597	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Удмуртская, 284		0101000020E6100000E8BE9CD9AE9C4A400873BB97FB6E4C40
6067	7	65	\N	70	52369	\N	56.859597687383399	Удмуртская Республика, город Ижевск, Устиновский район, Труда, 18	Россия, республика Удмуртская, Ижевск, улица Труда, 18	0101000020E6100000C47AA35698A44A407FDAA84E076E4C40
5921	7	65	\N	70	52523	\N	56.867473941009102	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Тимирязева, 23а	Россия, республика Удмуртская, Ижевск, улица Тимирязева, 23а	0101000020E6100000C7F319506F9E4A40AE105663096F4C40
5936	7	65	\N	70	52348	\N	56.851085167934599	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Тельмана, 14	Россия, республика Удмуртская, Ижевск, улица Тельмана, 14	0101000020E6100000F1D7648D7A9E4A40DE8E705AF06C4C40
5969	7	65	\N	70	52534	\N	56.851038415207498	Удмуртская Республика, город Ижевск, Ленинский район, Тверская, 58	Россия, республика Удмуртская, Ижевск, Тверская улица, 58	0101000020E6100000BBED42739D8E4A409ED32CD0EE6C4C40
5968	7	65	\N	70	52534	\N	56.850466539186201	Удмуртская Республика, город Ижевск, Ленинский район, Тверская, 56		0101000020E6100000B80721205F8E4A40E3A9471ADC6C4C40
6065	7	65	\N	70	52599	\N	56.863163	Удмуртская Республика, город Ижевск, Устиновский район, Барамзиной, 36	Россия, республика Удмуртская, Ижевск, улица Татьяны Барамзиной, 36	0101000020E6100000DCF4673F52A44A40020F0C207C6E4C40
5983	7	65	\N	70	52361	\N	56.870755000000003	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Студенческая, д.7	Россия, республика Удмуртская, Ижевск, Студенческая улица, 7	0101000020E6100000AAF1D24D62964A400CEA5BE6746F4C40
5980	7	65	\N	70	52361	\N	56.856701999999999	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Студенческая, д.42		0101000020E61000008E06F01648964A407A354069A86D4C40
5947	7	65	\N	70	52583	\N	56.802129704262697	Удмуртская Республика, город Ижевск, Ленинский район, Степная, 81	Россия, республика Удмуртская, Ижевск, Степная улица, 81	0101000020E610000028D192C7D3964A40FB912232AC664C40
6036	7	65	\N	70	52594	\N	56.817704999999997	Удмуртская Республика, город Ижевск, Первомайский район, ул.С.Разина, д.56	Россия, республика Удмуртская, Ижевск, улица Степана Разина, 56	0101000020E610000054A703594F9B4A404963B48EAA684C40
6062	7	65	\N	70	53163	\N	56.874819628982998	Удмуртская Республика, город Ижевск, Устиновский район, Старосмирновская, 28	Россия, республика Удмуртская, Ижевск, улица Архитектора Берша	0101000020E6100000B16A10E676A74A4080F10C1AFA6F4C40
6059	7	65	\N	70	52461	\N	56.884665654281498	Удмуртская Республика, город Ижевск, Устиновский район, Спортивная, 20	Россия, республика Удмуртская, Ижевск, Спортивная улица	0101000020E61000003DF19C2D20AC4A400BF148BC3C714C40
6077	7	65	\N	70	52462	\N	56.849302552405497	Удмуртская Республика, город Ижевск, Устиновский район, Союзная, 59	Россия, республика Удмуртская, Ижевск, Союзная улица, 59	0101000020E61000007D08AA46AFA64A4085B2F0F5B56C4C40
6075	7	65	\N	70	52462	\N	56.854580525958703	Удмуртская Республика, город Ижевск, Устиновский район, Союзная, 149	Россия, республика Удмуртская, Ижевск, Союзная улица, 149	0101000020E6100000BC96900F7AA64A40396403E9626D4C40
5919	7	65	\N	70	52580	\N	56.8657554624303	Удмуртская Республика, город Ижевск, Индустриальный район, ул.С.Ковалевской, 16	Россия, республика Удмуртская, Ижевск, улица Софьи Ковалевской	0101000020E6100000D61D8B6D529D4A409BAC510FD16E4C40
6029	7	65	\N	70	52595	\N	56.8462253261116	Удмуртская Республика, город Ижевск, Первомайский район, ул.Советская, д.30	Россия, республика Удмуртская, Ижевск, Советская улица	0101000020E61000005932C7F2AE9C4A405F07CE19516C4C40
5991	7	65	\N	70	52522	\N	56.845832421562498	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Советская, д.17	Россия, республика Удмуртская, Ижевск, Советская улица, 17	0101000020E6100000435376FA419B4A4084F41439446C4C40
5911	7	65	\N	70	52522	\N	56.846601999999997	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Советская, 23	Россия, республика Удмуртская, Ижевск, Советская улица, 23	0101000020E6100000DE567A6D369C4A40355D4F745D6C4C40
6015	7	65	\N	70	52834	\N	56.918418000000003	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Славянское шоссе, д.0/13		0101000020E6100000813E9127499B4A40640795B88E754C40
95026	7	65	\N	70	52465	\N	56.921040445645801	"426030 г. Ижевск, Индустриальный район ул.Сельская (здание ОАО ""Удмуртское"") д.1Б"	Россия, республика Удмуртская, Ижевск, Сельская улица, 1	0101000020E610000081D07AF832A14A40672783A3E4754C40
6003	7	65	\N	70	52542	\N	56.867878001956001	Удмуртская Республика, город Ижевск, Октябрьский район, пер.Северный, д.53	Россия, республика Удмуртская, Ижевск, Северный переулок, 53	0101000020E6100000530438BD8B9B4A407D7555A0166F4C40
5952	7	65	\N	70	52529	\N	56.824672388842799	Удмуртская Республика, город Ижевск, Ленинский район, Саратовская, 38		0101000020E6100000B9AB5791D1954A40A5F622DA8E694C40
6063	7	65	\N	70	52370	\N	56.878189299592997	Удмуртская Республика, город Ижевск, Устиновский район, Сабурова, 23	Россия, республика Удмуртская, Ижевск, улица Сабурова, 23	0101000020E6100000BEDBBC7152A64A407D5A457F68704C40
6061	7	65	\N	70	52370	\N	56.874926282725298	Удмуртская Республика, город Ижевск, Устиновский район, Сабурова, 49а	Россия, республика Удмуртская, Ижевск, улица Сабурова, 49а	0101000020E6100000030B60CAC0A54A40C6353E93FD6F4C40
6050	7	65	\N	70	52368	\N	56.831028561144002	Удмуртская Республика, город Ижевск, Первомайский район, ул.Ракетная, д.17	Россия, республика Удмуртская, Ижевск, Ракетная улица, 17	0101000020E6100000632AFD84B3A34A40888384285F6A4C40
6906	7	65	1401	16013	52429	\N	57.183002000000002	Удмуртская Республика, Якшур-Бодьинский район, село Якшур-Бодья, улица Пушиной, 95		0101000020E61000003CDD79E239954A40228D0A9C6C974C40
6040	7	65	\N	70	52368	\N	56.8305424910385	Удмуртская Республика, город Ижевск, Первомайский район, ул.Ракетная, д.11	Россия, республика Удмуртская, Ижевск, Ракетная улица	0101000020E6100000D00EB8AE98A34A402BFA43334F6A4C40
6001	7	65	\N	70	52453	\N	56.867854406606597	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Пушкинская, д.285	Россия, республика Удмуртская, Ижевск, Пушкинская улица, 285	0101000020E6100000518369183E9A4A40F5D901D7156F4C40
6026	7	65	\N	70	52460	\N	56.841464995348403	Удмуртская Республика, город Ижевск, Первомайский район, ул.Пушкинская, д.177	Россия, республика Удмуртская, Ижевск, Пушкинская улица, 177	0101000020E61000003AE97DE36B9B4A4044DD0720B56B4C40
6005	7	65	\N	70	52460	\N	56.873861098094999	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Пушкинская, д.371	Россия, республика Удмуртская, Ижевск, Пушкинская улица, 371	0101000020E6100000F390291F829A4A40FB1F60ADDA6F4C40
5996	7	65	\N	70	52460	\N	56.857249000000003	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Пушкинская, д.245	Россия, республика Удмуртская, Ижевск, Пушкинская улица, 245	0101000020E6100000B2834A5CC79A4A40ADC3D155BA6D4C40
6042	7	65	\N	70	52656	\N	56.844707	Удмуртская Республика, город Ижевск, Первомайский район, пр.Прасовский, д.5	Россия, республика Удмуртская, Ижевск, Прасовский переулок, 5	0101000020E61000006C3F19E3C39E4A40E4D9E55B1F6C4C40
6420	7	65	\N	70	28922	\N	56.821035000000002	Адрес УИК и помещения для голосования, Удмуртская Республика, Завьяловский район, д. Ожмес-Пурга, ул. Полевая (здание школы), д. 1-А	Россия, республика Удмуртская, Ижевск, Полевая улица, 1а	0101000020E6100000ED0F94DBF6954A4089EFC4AC17694C40
6014	7	65	\N	70	52774	\N	56.868659302556601	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Песочная, д.32А	Россия, республика Удмуртская, Ижевск, Песочная улица, 32а	0101000020E610000002F390291F964A402330D637306F4C40
5945	7	65	\N	70	52353	\N	56.795785810024398	Удмуртская Республика, город Ижевск, Ленинский район, Пермская, 20	Россия, республика Удмуртская, Ижевск, Пермская улица, 20	0101000020E610000094C0E61C3C934A40AD4ECE50DC654C40
5924	7	65	\N	70	52440	\N	56.854115795233497	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Парковая, 9а	Россия, республика Удмуртская, Ижевск, Парковая улица, 9а	0101000020E6100000EECF4543C69F4A40C37E4FAC536D4C40
5958	7	65	\N	70	52539	\N	56.826784033513597	Удмуртская Республика, город Ижевск, Ленинский район, Драгунова, 74	Россия, республика Удмуртская, Ижевск, улица Оружейника Драгунова, 74	0101000020E6100000FE99417C60914A40946DE00ED4694C40
5967	7	65	\N	70	52587	\N	56.839227999999999	Удмуртская Республика, город Ижевск, Ленинский район, Орсовская, 17	Россия, республика Удмуртская, Ижевск, Орсовская улица, 17	0101000020E6100000F9DB9E20B18F4A4099F1B6D26B6B4C40
6043	7	65	\N	70	52366	\N	56.839624862100798	Удмуртская Республика, город Ижевск, Первомайский район, ул.Орджоникидзе, д.33А	Россия, республика Удмуртская, Ижевск, улица Орджоникидзе, 33а	0101000020E6100000999A046F489F4A40B6F3FDD4786B4C40
6039	7	65	\N	70	52366	\N	56.836020866918801	Удмуртская Республика, город Ижевск, Первомайский район, ул.Орджоникидзе, д.17	Россия, республика Удмуртская, Ижевск, улица Орджоникидзе, 17	0101000020E610000006668522DD9F4A4076E272BC026B4C40
5940	7	65	\N	70	52770	\N	56.931963471883101	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Оранжерейная, 24	Россия, республика Удмуртская, Ижевск, Оранжерейная улица, 24	0101000020E6100000C860C5A9D69E4A40810A47904A774C40
5961	7	65	\N	70	52533	\N	56.831511959806903	Удмуртская Республика, город Ижевск, Ленинский район, Новостроительная, 28	Россия, республика Удмуртская, Ижевск, Новостроительная улица	0101000020E61000002140868E1D924A40A31D37FC6E6A4C40
5959	7	65	\N	70	52533	\N	56.827109216539803	Удмуртская Республика, город Ижевск, Ленинский район, Новостроительная, 34	Россия, республика Удмуртская, Ижевск, Новостроительная улица, 34	0101000020E6100000D047197101924A40179D2CB5DE694C40
6074	7	65	\N	70	52467	\N	56.850429981442197	Удмуртская Республика, город Ижевск, Устиновский район, Молодежная, 97	Россия, республика Удмуртская, Ижевск, Молодежная улица, 97	0101000020E6100000F627F1B913A64A40C6C4E6E3DA6C4C40
6073	7	65	\N	70	52467	\N	56.848542000000002	Удмуртская Республика, город Ижевск, Устиновский район, Молодежная, 64	Россия, республика Удмуртская, Ижевск, Молодежная улица, 64	0101000020E610000026732CEFAAA54A4027A435069D6C4C40
6072	7	65	\N	70	52467	\N	56.849793430051001	Удмуртская Республика, город Ижевск, Устиновский район, Молодежная, 26	Россия, республика Удмуртская, Ижевск, Молодежная улица, 26	0101000020E6100000CFC0C8CB9AA44A4053AF5B04C66C4C40
6071	7	65	\N	70	52467	\N	56.854380030553003	Удмуртская Республика, город Ижевск, Устиновский район, Молодежная, 61		0101000020E6100000446B459BE3A44A40A12DE7525C6D4C40
5984	7	65	\N	70	52431	\N	56.871400794350301	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Металлистов, д.32	Россия, республика Удмуртская, Ижевск, улица Металлистов, 32	0101000020E61000004CA8E0F082984A40D15966118A6F4C40
5979	7	65	\N	70	52431	\N	56.874380292203703	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Металлистов, д.46	Россия, республика Удмуртская, Ижевск, улица Металлистов, 46	0101000020E6100000289EB30584984A40642310AFEB6F4C40
6011	7	65	\N	70	52543	\N	56.869794775786097	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Майская, д.13А	Россия, республика Удмуртская, Ижевск, Майская улица, 13	0101000020E6100000B96C74CE4F9B4A40B79C4B71556F4C40
6008	7	65	\N	70	52543	\N	56.869878227296098	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Майская, д.14А	Россия, республика Удмуртская, Ижевск, Майская улица, 14а	0101000020E61000001EE0490B979B4A4044C18C29586F4C40
5975	7	65	\N	70	52358	\N	56.786795999538903	Удмуртская Республика, город Ижевск, Ленинский район, Локомотивная, 29	Россия, республика Удмуртская, Ижевск, Локомотивная улица, 29	0101000020E6100000894336902E964A40D34F38BBB5644C40
6048	7	65	\N	70	52364	\N	56.842017899608102	Удмуртская Республика, город Ижевск, Первомайский район, ул.Ленина, д.168	Россия, республика Удмуртская, Ижевск, улица Ленина, 168	0101000020E61000008884EFFD0DA64A405952EE3EC76B4C40
6046	7	65	\N	70	52364	\N	56.848153000000003	Удмуртская Республика, город Ижевск, Первомайский район, ул.Ленина, д.114	Россия, республика Удмуртская, Ижевск, улица Ленина, 114	0101000020E61000002E1D739EB1A14A408D800A47906C4C40
6031	7	65	\N	70	52364	\N	56.845418751156899	Удмуртская Республика, город Ижевск, Первомайский район, ул.Ленина, д.82	Россия, республика Удмуртская, Ижевск, улица Ленина, 82	0101000020E6100000A29A92ACC39D4A40613596B0366C4C40
6028	7	65	\N	70	52364	\N	56.844808939509697	Удмуртская Республика, город Ижевск, Первомайский район, ул.Ленина, д.68	Россия, республика Удмуртская, Ижевск, улица Ленина, 68	0101000020E610000044317903CC9C4A40E82E89B3226C4C40
5944	7	65	\N	70	52350	\N	56.791615999999998	Удмуртская Республика, город Ижевск, Ленинский район, Леваневского, 102	Россия, республика Удмуртская, Ижевск, улица Леваневского, 102	0101000020E610000073BB97FBE4964A40C37E4FAC53654C40
5943	7	65	\N	70	52350	\N	56.807293999999999	Удмуртская Республика, город Ижевск, Ленинский район, Леваневского, 2А	Россия, республика Удмуртская, Ижевск, улица Леваневского, 2а	0101000020E61000000F0BB5A679974A40E620E86855674C40
6055	7	65	\N	70	52948	\N	56.841403989790003	Удмуртская Республика, город Ижевск, Первомайский район, ул.Курортная, д.2	Россия, республика Удмуртская, Ижевск, Курортная улица, 2	0101000020E61000007429AE2AFBA24A409E5C5320B36B4C40
5990	7	65	\N	70	52820	\N	56.847806364491497	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Красногеройская, д.12	Россия, республика Удмуртская, Ижевск, Красногеройская улица, 12	0101000020E6100000E868554B3A9A4A4021AD31E8846C4C40
6016	7	65	\N	70	52776	\N	56.847955728778103	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Красногеройская, д.28А	Россия, республика Удмуртская, Ижевск, Красногеройская улица, 28а	0101000020E6100000D7506A2FA29B4A4037397CD2896C4C40
95202	7	65	\N	70	52455	\N	56.839173000000002	Удмуртская Республика, г. Ижевск, Первомайский район, ул. Красноармейская, д.132А (здание Цирка)		0101000020E6100000C37FBA81029B4A40D65757056A6B4C40
6025	7	65	\N	70	52455	\N	56.839094433353999	Удмуртская Республика, город Ижевск, Первомайский район, ул.Красноармейская, д.130	Россия, республика Удмуртская, Ижевск, Красноармейская улица, 130	0101000020E6100000E3DD91B1DA9A4A408A22A46E676B4C40
6023	7	65	\N	70	52455	\N	56.834383273869697	Удмуртская Республика, город Ижевск, Первомайский район, ул.Красноармейская, д.78	Россия, республика Удмуртская, Ижевск, Красноармейская улица, 78	0101000020E6100000DD7C23BA679B4A4050ABE80FCD6A4C40
6066	7	65	\N	70	52463	\N	56.868390026538897	Удмуртская Республика, город Ижевск, Устиновский район, Короткова, 17а	Россия, республика Удмуртская, Ижевск, улица Короткова, 17а	0101000020E6100000EF8D210038A44A4033164D67276F4C40
6032	7	65	\N	70	52452	\N	56.837524000000002	Удмуртская Республика, город Ижевск, Первомайский район, ул.Коммунаров, д.144	Россия, республика Удмуртская, Ижевск, улица Коммунаров, 144	0101000020E6100000D998D711879C4A40BCCE86FC336B4C40
6027	7	65	\N	70	52452	\N	56.841295000000002	Удмуртская Республика, город Ижевск, Первомайский район, ул.Коммунаров, д.200	Россия, республика Удмуртская, Ижевск, улица Коммунаров, 200	0101000020E6100000062AE3DF679C4A40E8A4F78DAF6B4C40
6002	7	65	\N	70	52452	\N	56.862608431307898	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Коммунаров, д.353А	Россия, республика Удмуртская, Ижевск, улица Коммунаров, 353а	0101000020E6100000EB573A1F9E9B4A404DA25EF0696E4C40
5993	7	65	\N	70	52452	\N	56.850383000000001	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Коммунаров, д.281	Россия, республика Удмуртская, Ижевск, улица Коммунаров, 281	0101000020E6100000E4DA5031CE9B4A408509A359D96C4C40
5974	7	65	\N	70	52342	\N	56.831840999999997	Удмуртская Республика, город Ижевск, Ленинский район, Клубная, 50А	Россия, республика Удмуртская, Ижевск, Клубная улица, 50а	0101000020E61000007C6308008E914A40683C11C4796A4C40
5955	7	65	\N	70	52342	\N	56.831523263540902	Удмуртская Республика, город Ижевск, Ленинский район, Клубная, 58	Россия, республика Удмуртская, Ижевск, Клубная улица, 58	0101000020E6100000F295404AEC904A40976F7D586F6A4C40
5954	7	65	\N	70	52342	\N	56.828355000000002	Удмуртская Республика, город Ижевск, Ленинский район, Клубная, 82А	Россия, республика Удмуртская, Ижевск, Клубная улица, 82а	0101000020E6100000E6400FB56D924A40323D6189076A4C40
5916	7	65	\N	70	52342	\N	56.829896685317998	Удмуртская Республика, город Ижевск, Ленинский район, Клубная, 33	Россия, республика Удмуртская, Ижевск, Клубная улица, 33	0101000020E61000003562669FC7924A4036069D103A6A4C40
6013	7	65	\N	70	52363	\N	56.862180346954901	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Кирова, д.56		0101000020E6100000F58590F3FE974A40F5A10BEA5B6E4C40
6908	7	65	1401	16013	52719	\N	57.183002000000002	Удмуртская Республика, Якшур-Бодьинский район, село Якшур-Бодья, улица Ленина, 33а		0101000020E61000003CDD79E239954A40228D0A9C6C974C40
6009	7	65	\N	70	52363	\N	56.862316999999997	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Кирова, д.22	Россия, республика Удмуртская, Ижевск, улица Кирова, 22	0101000020E61000002D93E1783E974A4075E44867606E4C40
5999	7	65	\N	70	52363	\N	56.856701999999999	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Кирова, д.110		0101000020E61000008E06F01648964A407A354069A86D4C40
5994	7	65	\N	70	52363	\N	56.856701999999999	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Кирова, д.108		0101000020E61000008E06F01648964A407A354069A86D4C40
5987	7	65	\N	70	52363	\N	56.861556392804403	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Кирова, д.16	Россия, республика Удмуртская, Ижевск, улица Кирова, 16	0101000020E6100000DC4944F817974A4017D68D77476E4C40
6024	7	65	\N	70	52362	\N	56.833264457181997	Удмуртская Республика, город Ижевск, Первомайский район, ул.К.Маркса, д.75	Россия, республика Удмуртская, Ижевск, улица Карла Маркса, 75	0101000020E6100000D34A21904B9A4A4092770E65A86A4C40
6022	7	65	\N	70	52362	\N	56.838824000000002	Удмуртская Республика, город Ижевск, Первомайский район, ул.К.Маркса, д.164	Россия, республика Удмуртская, Ижевск, улица Карла Маркса, 164	0101000020E610000051DA1B7C619A4A40CA8CB7955E6B4C40
6000	7	65	\N	70	52362	\N	56.866101	Удмуртская Республика, город Ижевск, Октябрьский район, ул. К.Маркса, д.427	Россия, республика Удмуртская, Ижевск, улица Карла Маркса, 427	0101000020E6100000CC0BB08F4E994A403604C765DC6E4C40
5995	7	65	\N	70	52362	\N	56.857102186083601	Удмуртская Республика, город Ижевск, Октябрьский район, ул. К.Маркса, д.288А	Россия, республика Удмуртская, Ижевск, улица Карла Маркса, 288а	0101000020E610000006DA1D520C9A4A4008ABB184B56D4C40
5992	7	65	\N	70	52362	\N	56.857008144642101	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Маркса, д.288А	Россия, республика Удмуртская, Ижевск, улица Карла Маркса, 288а	0101000020E6100000352A70B20D9A4A4087342A70B26D4C40
6053	7	65	\N	70	52435	\N	56.836613363650997	Удмуртская Республика, город Ижевск, Первомайский район, ул.К. Либкнехта, д.24	Россия, республика Удмуртская, Ижевск, улица Карла Либкнехта, 24	0101000020E61000006C97361C969C4A4048348122166B4C40
6049	7	65	\N	70	52435	\N	56.836727028588697	Удмуртская Республика, город Ижевск, Первомайский район, ул.К.Либкнехта, д.24	Россия, республика Удмуртская, Ижевск, улица Карла Либкнехта, 24	0101000020E610000060E97C78969C4A401157CEDE196B4C40
6033	7	65	\N	70	52435	\N	56.838828999999997	Удмуртская Республика, город Ижевск, Первомайский район, ул.К.Либкнехта, д.53	Россия, республика Удмуртская, Ижевск, улица Карла Либкнехта, 53	0101000020E6100000B7CF2A33A59D4A40DBF7A8BF5E6B4C40
6041	7	65	\N	70	52602	\N	56.821851345086401	Удмуртская Республика, город Ижевск, Первомайский район, ул.Камская, д.6А		0101000020E6100000F5F6E7A2219F4A40AB97DF6932694C40
5957	7	65	\N	70	52354	\N	56.832040474635498	Удмуртская Республика, город Ижевск, Ленинский район, З.Космодемьянской, 109	Россия, республика Удмуртская, Ижевск, улица Зои Космодемьянской, 109	0101000020E6100000C217265305934A405F7B6649806A4C40
5960	7	65	\N	70	52355	\N	56.836361406668701	Удмуртская Республика, город Ижевск, Ленинский район, Заречное шоссе, 37	Россия, республика Удмуртская, Ижевск, Заречное шоссе, 37	0101000020E61000000953944BE3914A402E5393E00D6B4C40
5956	7	65	\N	70	52355	\N	56.8359141834271	Удмуртская Республика, город Ижевск, Ленинский район, Заречное шоссе, 39	Россия, республика Удмуртская, Ижевск, Заречное шоссе, 39	0101000020E6100000C49448A297914A406022DE3AFF6A4C40
5927	7	65	\N	70	52351	\N	56.8858237646416	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Дзержинского, 71	Россия, республика Удмуртская, Ижевск, улица Дзержинского, 71	0101000020E61000009355116E32A04A4086014BAE62714C40
5925	7	65	\N	70	52351	\N	56.881126036447	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Дзержинского, 9	Россия, республика Удмуртская, Ижевск, улица Дзержинского, 9	0101000020E6100000399A232BBF9E4A40E1D39CBCC8704C40
6044	7	65	\N	70	52550	\N	56.796126717110198	Удмуртская Республика, город Ижевск, Первомайский район, ул.Демократическая, д.37	Россия, республика Удмуртская, Ижевск, Демократическая улица, 37	0101000020E6100000FEF0F3DF839F4A40363B527DE7654C40
6052	7	65	\N	70	52945	\N	56.784834653499502	Удмуртская Республика, город Ижевск, Первомайский район, д.Люлли, ул.Гороховая, д.10	Россия, республика Удмуртская, Ижевск, Первомайский район, микрорайон Люлли	0101000020E6100000D255BABBCEA64A40CAE0287975644C40
5973	7	65	\N	70	53062	\N	56.8356540435041	Удмуртская Республика, город Ижевск, Ленинский район, Городок Машиностроителей, 76	Россия, республика Удмуртская, Ижевск, Ленинский район, микрорайон Городок Машиностроителей, 76	0101000020E61000008DD5E6FF558D4A40C362D4B5F66A4C40
5942	7	65	\N	70	52349	\N	56.800108642003998	Удмуртская Республика, город Ижевск, Ленинский район, Гагарина, 29	Россия, республика Удмуртская, Ижевск, улица Гагарина	0101000020E610000002F4FBFECD974A401D1EC2F869664C40
5934	7	65	\N	70	9855	\N	56.891665524148003	Удмуртская Республика, город Ижевск, Индустриальный район, Воткинское шоссе, 166б	Россия, республика Удмуртская, Ижевск, Воткинское шоссе, 166б	0101000020E610000096404AECDAA24A40427A8A1C22724C40
6038	7	65	\N	70	52447	\N	56.837117088735603	Удмуртская Республика, город Ижевск, Первомайский район, ул.Восточная, д.12	Россия, республика Удмуртская, Ижевск, Восточная улица, 12	0101000020E6100000B32616F88A9E4A407BF65CA6266B4C40
6058	7	65	\N	70	52365	\N	56.880205583392502	Удмуртская Республика, город Ижевск, Устиновский район, Ворошилова, 17	Россия, республика Удмуртская, Ижевск, улица Ворошилова, 17	0101000020E6100000D74FFF59F3A14A401ADF1797AA704C40
6057	7	65	\N	70	52365	\N	56.875438000000003	Удмуртская Республика, город Ижевск, Устиновский район, Ворошилова, 66	Россия, республика Удмуртская, Ижевск, улица Ворошилова, 66	0101000020E6100000F0DFBC38F1A14A407CD6355A0E704C40
6056	7	65	\N	70	52365	\N	56.880029915521099	Удмуртская Республика, город Ижевск, Устиновский район, Ворошилова, 57	Россия, республика Удмуртская, Ижевск, улица Ворошилова, 57	0101000020E61000008D7F9F71E1A24A40DBBFB2D2A4704C40
6035	7	65	\N	70	52375	\N	56.829188740001598	Удмуртская Республика, город Ижевск, Первомайский район, ул.Володарского, д.52	Россия, республика Удмуртская, Ижевск, улица Володарского, 52	0101000020E610000059349D9D0C9E4A40FA997ADD226A4C40
6030	7	65	\N	70	52544	\N	56.841384236462702	Удмуртская Республика, город Ижевск, Первомайский район, ул.В.Краева, д.50	Россия, республика Удмуртская, Ижевск, улица Владимира Краева	0101000020E6100000D5CDC5DFF69C4A4057B08D78B26B4C40
5929	7	65	\N	70	52441	\N	56.8753377897931	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Буммашевская, 50	Россия, республика Удмуртская, Ижевск, Буммашевская улица, 50	0101000020E61000005C1D0071579F4A40187959130B704C40
5928	7	65	\N	70	52441	\N	56.879027999999998	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Буммашевская, 66а	Россия, республика Удмуртская, Ижевск, Буммашевская улица, 66а	0101000020E610000016A4198BA69F4A40572250FD83704C40
5988	7	65	\N	70	52450	\N	56.858226991490397	Удмуртская Республика, город Ижевск, Октябрьский район, ул. Береговая, д.11	Россия, республика Удмуртская, Ижевск, Береговая улица, 11	0101000020E610000065AA605452974A40A8C5E061DA6D4C40
6060	7	65	\N	70	52367	\N	56.870032000000002	Удмуртская Республика, город Ижевск, Устиновский район, Барышникова, 51	Россия, республика Удмуртская, Ижевск, улица Барышникова, 51	0101000020E6100000E25AED612FA64A409B3C65355D6F4C40
5948	7	65	\N	70	52585	\N	56.798220999999998	Удмуртская Республика, город Ижевск, Ленинский район, Азина, 325	Россия, республика Удмуртская, Ижевск, улица Азина, 325	0101000020E6100000622D3E05C0944A407EFD101B2C664C40
5946	7	65	\N	70	52585	\N	56.820306712583402	Удмуртская Республика, город Ижевск, Ленинский район, Азина, 84	Россия, республика Удмуртская, Ижевск, улица Азина, 84	0101000020E6100000639B5434D6964A4006D7DCD1FF684C40
5951	7	65	\N	70	52457	\N	56.815224132614098	Удмуртская Республика, город Ижевск, Ленинский район, Автономная, 23	Россия, республика Удмуртская, Ижевск, Автономная улица, 23	0101000020E61000007C7E18213C964A400875914259684C40
5953	7	65	\N	70	52444	\N	56.814141242643203	Удмуртская Республика, город Ижевск, Ленинский район, Автономная, 81		0101000020E6100000DC10E335AF924A4097AAB4C535684C40
5950	7	65	\N	70	52444	\N	56.816977395230502	Удмуртская Республика, город Ижевск, Ленинский район, Автономная, 60	Россия, республика Удмуртская, Ижевск, Автономная улица, 60	0101000020E6100000E509849D62954A40C74ACCB392684C40
5920	7	65	\N	70	52345	\N	56.860900839430897	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Авангардная, 15	Россия, республика Удмуртская, Ижевск, Авангардная улица, 15	0101000020E6100000B22FD978B09D4A40FE0B0401326E4C40
5932	7	65	\N	70	52343	\N	56.874754000000003	Удмуртская Республика, город Ижевск, Индустриальный район, ул.9 Января, 193а	Россия, республика Удмуртская, Ижевск, улица 9 Января, 193а	0101000020E61000006667D13B15A04A40C90567F0F76F4C40
5931	7	65	\N	70	52343	\N	56.880223021641697	Удмуртская Республика, город Ижевск, Индустриальный район, ул.9 Января, 247а	Россия, республика Удмуртская, Ижевск, улица 9 Января, 247а	0101000020E61000004F90D8EE1EA04A40F017B325AB704C40
5930	7	65	\N	70	52343	\N	56.856701999999999	Удмуртская Республика, город Ижевск, Индустриальный район, ул.9 Января, 249		0101000020E61000008E06F01648964A407A354069A86D4C40
5985	7	65	\N	70	52449	\N	56.867799870994602	Удмуртская Республика, город Ижевск, Октябрьский район, ул. 5-я Подлесная, д.44		0101000020E6100000738577B988974A4002BC0512146F4C40
6070	7	65	\N	70	52459	\N	56.850901463364799	Удмуртская Республика, город Ижевск, Устиновский район, 40 лет Победы, 62	Россия, республика Удмуртская, Ижевск, улица 40 лет Победы, 62	0101000020E61000007DEC2E5052A44A401D91EF52EA6C4C40
6047	7	65	\N	70	52459	\N	56.843914690290198	Удмуртская Республика, город Ижевск, Первомайский район, ул.40 лет Победы, д.128	Россия, республика Удмуртская, Ижевск, улица 40 лет Победы, 128	0101000020E61000009DB81CAF40A44A404BCD1E68056C4C40
5986	7	65	\N	70	52359	\N	56.868021501755599	Удмуртская Республика, город Ижевск, Октябрьский район, ул. 30 лет Победы, д. 29	Россия, республика Удмуртская, Ижевск, улица 30 лет Победы, 29	0101000020E6100000179AEB34D2964A40B11A4B581B6F4C40
5982	7	65	\N	70	52359	\N	56.8677610349798	Удмуртская Республика, город Ижевск, Октябрьский район, ул. 30 лет Победы, д.29	Россия, республика Удмуртская, Ижевск, улица 30 лет Победы, 29	0101000020E61000000C207C28D1964A4044DFDDCA126F4C40
5976	7	65	\N	70	52359	\N	56.876750999999999	Удмуртская Республика, город Ижевск, Октябрьский район, ул. 30 лет Победы, д.55	Россия, республика Удмуртская, Ижевск, улица 30 лет Победы, 55а	0101000020E6100000B64C86E3F9964A401EDE736039704C40
5962	7	65	\N	70	52356	\N	56.8382083166033	Удмуртская Республика, город Ижевск, Ленинский район, Пятнадцатая, 51	Россия, республика Удмуртская, Ижевск, 15-я улица, 51	0101000020E61000009BCAA2B08B924A406F9F55664A6B4C40
5918	7	65	\N	70	52344	\N	56.8723182520935	Удмуртская Республика, город Ижевск, Индустриальный район, ул.10 лет Октября, 55Б	Россия, республика Удмуртская, Ижевск, улица 10 лет Октября, 55б	0101000020E61000002159C0046E9D4A4027DBC01DA86F4C40
5949	7	65	\N	70	52445	\N	56.856701999999999	Удмуртская Республика, город Ижевск, Ленинский район, Депутатская, 40А		0101000020E61000008E06F01648964A407A354069A86D4C40
5926	7	65	\N	70	52443	\N	56.856701999999999	Удмуртская Республика, город Ижевск, Индустриальный район, Воткинское шоссе, 110		0101000020E61000008E06F01648964A407A354069A86D4C40
6426	7	65	\N	56364	52489	\N	56.788623000000001	"Удмуртская Республика, Завьяловский район, с. Завьялово, МБОУ ""Завьяловская СОШ"" ул. Чкалово, д. 34"	Россия, республика Удмуртская, село Завьялово	0101000020E6100000280D350A49B04A40CCEF3499F1644C40
6139	7	65	\N	9492	52565	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Циолковского, д.2		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6140	7	65	7409	\N	52385	\N	58.144049083183504	Удмуртская Республика, город Глазов, ул.Толстого, д.42	Россия, республика Удмуртская, Глазов городской округ	0101000020E61000007995B54DF1524A40C102983270124D40
6137	7	65	\N	9492	52385	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Толстого, д.45		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6122	7	65	\N	9492	52394	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Тани Барамзиной, д.4		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6117	7	65	\N	9492	52470	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Советская, д.29		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6131	7	65	\N	9492	52386	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Сибирская, д.19		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6126	7	65	\N	9492	52448	\N	58.1349368268977	Удмуртская Республика, город Глазов, ул.Революции, д.8	Россия, республика Удмуртская, Глазов	0101000020E61000009146054EB6514A409B02999D45114D40
6143	7	65	\N	9492	52611	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Пионерская, д.19		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6138	7	65	\N	9492	52389	\N	58.1385683926094	Удмуртская Республика, город Глазов, ул.Пехтина, д.12А	Россия, республика Удмуртская, Глазов	0101000020E6100000E23E726BD2514A40D522A298BC114D40
6134	7	65	\N	9492	52389	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Пехтина, д.2А		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6132	7	65	\N	9492	52389	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Пехтина, д.22А		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6128	7	65	\N	9492	52610	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Первомайская, д.25		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6120	7	65	\N	9492	52555	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Парковая, д.45		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6115	7	65	\N	9492	52555	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Парковая, д.10А		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6114	7	65	\N	9492	52606	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Мира, д.34		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6127	7	65	\N	9492	52562	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Луначарского, д.20		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6124	7	65	\N	9492	52557	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Короленко, д.5		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6133	7	65	\N	9492	52564	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Колхозная, д.12		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6125	7	65	\N	9492	52379	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Кирова, д.13		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6121	7	65	\N	9492	52379	\N	58.138023681449297	Удмуртская Республика, город Глазов, ул.Кирова, д.37	Россия, республика Удмуртская, Глазов	0101000020E61000002D978DCEF9514A4014083BC5AA114D40
6113	7	65	\N	9492	52379	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Кирова, д.75А		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6112	7	65	\N	9492	52379	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Кирова, д.75		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6136	7	65	\N	9492	52497	\N	58.138477607996798	Удмуртская Республика, город Глазов, ул.Калинина, д.4А	Россия, республика Удмуртская, Глазов	0101000020E6100000DC9E20B1DD514A40959BA8A5B9114D40
6135	7	65	\N	9492	52497	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Калинина, д.9А		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6130	7	65	\N	9492	52383	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.К.Маркса, д.17		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6129	7	65	\N	9492	52383	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.К.Маркса, д.8А		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6142	7	65	\N	9492	52390	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Драгунова, д.69		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6141	7	65	\N	9492	52390	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Драгунова, д.74		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6111	7	65	\N	9492	52378	\N	58.139839352792301	Удмуртская Республика, город Глазов, ул.Гайдара, д.12	Россия, республика Удмуртская, Глазов городской округ	0101000020E61000002843554CA5534A4049DA8D3EE6114D40
6116	7	65	\N	9492	52608	\N	58.135663169777501	Удмуртская Республика, город Глазов, ул.Белинского, д.7	Россия, республика Удмуртская, Глазов городской округ	0101000020E6100000069E7B0F97564A407D23BA675D114D40
6110	7	65	\N	9492	52377	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.70 лет Победы, д.1		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
6118	7	65	\N	9492	52380	\N	58.137661000000001	Удмуртская Республика, город Глазов, ул.Пряженникова, д.37А		0101000020E6100000840D4FAF94514A40A3772AE09E114D40
95060	7	65	61	49997	53005	\N	56.364331	427720 Кизнерский район, д. Саркуз ул. Молодежная (Здание администрации) д. 10		0101000020E61000004B94BDA59CD94940A1F5F065A22E4C40
6879	7	65	\N	8096	\N	\N	57.036637455098699	"427070, Адрес УИК и помещения для голосования: Удмуртская Республика, Шарканский район, село Шаркан, ул. Советская (здание администрации МО ""Шарканское""), дом 44 г"	Россия, республика Удмуртская, Воткинск	0101000020E610000007B29E5A7DFB4A406A696E85B0844C40
6858	7	65	\N	8096	\N	\N	57.040100040378498	427072, Адрес УИК и помещения для голосования: Удмуртская Республика, Шарканский район, село Мишкино, ул. Центральная (здание Мишкинской СОШ), дом 12	Россия, республика Удмуртская, Воткинск	0101000020E61000004223D8B8FEFB4A40E9482EFF21854C40
6102	7	65	\N	8096	\N	\N	57.035867358707002	Удмуртская Республика, город Воткинск, д.Вогулка		0101000020E6100000A5F622DA8EFB4A40B900344A97844C40
6079	7	65	\N	8096	\N	\N	57.036425999999999	427435, Адрес УИК и помещения для голосования: Удмуртская Республика, город Воткинск, ул.Кунгурцева (здание школы №22), 2	Россия, республика Удмуртская, Воткинск	0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
95028	7	65	\N	8096	52384	\N	57.036425999999999	427432 г. Воткинск ул.Энтузиастов (здание школы №5) д.25		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6097	7	65	\N	8096	52371	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Школьная, д.3		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6109	7	65	\N	8096	52725	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Тихая, д.12		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6081	7	65	\N	8096	52598	\N	57.040172235050498	Удмуртская Республика, город Воткинск, ул.Серова, д.14	Россия, республика Удмуртская, Воткинск городской округ	0101000020E6100000AA0B789961FF4A40821B295B24854C40
6080	7	65	\N	8096	52598	\N	57.036686259623202	Удмуртская Республика, город Воткинск, ул.Серова, 25	Россия, республика Удмуртская, Воткинск	0101000020E6100000CC0A45BA9FFB4A404C1C7920B2844C40
6088	7	65	\N	8096	52601	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Свободы, д.56		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6084	7	65	\N	8096	52551	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Расковой, д.1А		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6083	7	65	\N	8096	52552	\N	57.036428892716302	Удмуртская Республика, город Воткинск, ул.Пугачева, д.21	Россия, республика Удмуртская, Воткинск	0101000020E610000081B2295778FB4A4020D099B4A9844C40
6093	7	65	\N	8096	52592	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Песчаная, д.4		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6086	7	65	\N	8096	52464	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Орджоникидзе, д.15		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6087	7	65	\N	8096	52373	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Мира, д.27А		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6082	7	65	\N	8096	52373	\N	57.045038014019703	Удмуртская Республика, город Воткинск, ул.Мира, д.19	Россия, республика Удмуртская, Воткинск городской округ	0101000020E6100000780AB952CFFE4A40E38920CEC3854C40
6085	7	65	\N	8096	52372	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Луначарского, д.6		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6100	7	65	\N	8096	52604	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Ленинградская, д.13		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6089	7	65	\N	8096	52612	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Ленина, д.40		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6108	7	65	\N	8096	52376	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Красноармейская, д.283А		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6096	7	65	\N	8096	52339	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Королева, д.15		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6095	7	65	\N	8096	52339	\N	57.036425999999999	Удмуртская Республика, город Воткинск, улКоролева, д.15		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6094	7	65	\N	8096	52339	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Королева, д.20А		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6090	7	65	\N	8096	52466	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Кирова, д.9		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6106	7	65	\N	8096	52374	\N	57.049526010781598	Удмуртская Республика, город Воткинск, ул.Гагарина, д.26	Россия, республика Удмуртская, Воткинск городской округ	0101000020E6100000BA9F53909FFD4A409E2633DE56864C40
6105	7	65	\N	8096	52374	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Гагарина, д.23		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6099	7	65	\N	8096	52469	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Волгоградская, д.10		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6098	7	65	\N	8096	52469	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.Волгоградская, д.1		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6092	7	65	\N	8096	52578	\N	57.036616068826099	Удмуртская Республика, город Воткинск, ул.1905 года, д.17	Россия, республика Удмуртская, Воткинск	0101000020E6100000F6EE8FF7AAFB4A40534145D5AF844C40
6091	7	65	\N	8096	52603	\N	57.036425999999999	Удмуртская Республика, город Воткинск, ул.1 Мая, д.19Б		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6103	7	65	\N	8096	53155	\N	57.036425999999999	Удмуртская Республика, город Воткинск, 2-ой км.Чайковского тракта		0101000020E6100000392A37514BFB4A40AF5C6F9BA9844C40
6952	7	65	1498	56365	52511	\N	58.241863321783299	"Удмуртская Республика, Ярский район, посёлок Яр, ГОУ СПО ""Ярский политехникум"", ул.Ф.Васильева, д.31"	Россия, республика Удмуртская, Ярский район, поселок Яр	0101000020E6100000B2BAD573D20D4A40658EE55DF51E4D40
6953	7	65	1498	56365	52653	\N	58.244578818165103	"Удмуртская Республика, Ярский район, посёлок Яр, культурно-досуговый центр ""Юбилейный"", ул.Советская, д.52"	Россия, республика Удмуртская, Ярский район, поселок Яр	0101000020E6100000DC9E20B1DD0D4A40EA245B5D4E1F4D40
6954	7	65	1498	56365	52853	\N	58.246751065012901	"Удмуртская Республика, Ярский район, посёлок Яр, Ярский участок НГЧ-4 ОАО ""РЖД"", ул.Горького, д.47"	Россия, республика Удмуртская, Ярский район, поселок Яр	0101000020E6100000649291B3B00D4A40AEA06989951F4D40
6947	7	65	1498	56406	53153	\N	58.1430586606904	"Удмуртская Республика, Ярский район, деревня Юр, административное здание КФХ ""Касаткин Г.Н."", ул.Жуйкова, д.44"	Россия, республика Удмуртская, Ярский район, село Юр	0101000020E6100000850A0E2F88F249400133DFC14F124D40
6935	7	65	1498	17515	52938	\N	58.247455000000002	"Удмуртская Республика, Ярский район, деревня Юдчино, административное здание СПК ""Прогресс"", ул.Логовая, д.20"		0101000020E61000001F10E84CDAFA4940A81DFE9AAC1F4D40
6943	7	65	1498	17917	53027	\N	58.315497000000001	Удмуртская Республика, Ярский район, деревня Усть-Лекма, Усть-Лекомский сельский клуб, ул.Совхозная, д.1		0101000020E61000000FB9196EC0074A40397EA83462284D40
6949	7	65	1498	18205	52724	\N	58.163761999999998	Удмуртская Республика, Ярский район, село Укан, Уканский сельский Дом культуры, ул.Школьная, д.24		0101000020E6100000DA73999A04074A40ED293927F6144D40
6945	7	65	1498	18017	\N	\N	58.310559748208	427515, Адрес УИК и помещения для голосования: Удмуртская Республика, Ярский район, деревня Тум, ул.Школьная (Тумская основная общеобразоват. школа), д.15	Россия, республика Удмуртская, Ярский район, село Тум	0101000020E610000020459DB987284A400FB9196EC0274D40
6950	7	65	1498	18210	52723	\N	58.305280000000003	"Удмуртская Республика, Ярский район, село Пудем, Дом культуры ""Металлург"", ул.Кирова, д.8"		0101000020E61000006DAD2F12DA144A40BB0F406A13274D40
6951	7	65	1498	18210	52657	\N	58.305280000000003	Удмуртская Республика, Ярский район, село Пудем, МОУ Пудемская средняя общеобразовательная школа, ул.Гагарина, д.1		0101000020E61000006DAD2F12DA144A40BB0F406A13274D40
6946	7	65	1498	18020	75049	\N	58.247998791433702	427515, Адрес УИК и помещения для голосования: Удмуртская Республика, Ярский район, деревня Озерки, ул.Школьная (Озеркинская основная общеобразоват. школа), д.8		0101000020E610000002F4FBFECD194A406938656EBE1F4D40
6948	7	65	1498	18130	\N	\N	58.0621465670284	427505, Адрес УИК и помещения для голосования: Удмуртская Республика, Ярский район, село Никольское, ул.Центральная (Никольская средняя общеобразоват. школа), д.3	Россия, республика Удмуртская, Ярский район, село Никольское	0101000020E610000082035ABA82F14940B345D26EF4074D40
6939	7	65	1498	17722	53026	\N	58.190432999999999	Удмуртская Республика, Ярский район, деревня Мосеево, Мосеевский сельский Дом культуры, ул.Сибирская, д.31		0101000020E610000008E3A7716F204A40228AC91B60184D40
6942	7	65	1498	17841	\N	\N	57.016136058805301	427513, Адрес УИК и помещения для голосования: Удмуртская Республика, Ярский район, деревня Кузьмино, ул.Молодежная (Кузьминский сельский клуб), д.10, кв.1		0101000020E610000089D349B6BAC84940E62494BE10824C40
6944	7	65	1498	17932	53141	\N	58.193643999999999	Удмуртская Республика, Ярский район, деревня Зюино, МОУ Зюинская средняя общеобразовательная школа, ул.Школьная, д.77а		0101000020E6100000431F2C6343E5494087889B53C9184D40
6941	7	65	1498	17814	\N	\N	58.345363999999996	427512, Адрес УИК и помещения для голосования: Удмуртская Республика, Ярский район, село Елово, ул.Школьная (Еловская основная общеобразоват. школа), д.11	Россия, республика Удмуртская, Ярский район, село Елово	0101000020E61000002D42B11534FB49409D9B36E3342C4D40
6940	7	65	1498	17729	52510	\N	58.216571000000002	Удмуртская Республика, Ярский район, село Дизьмино, Дизьминский Центральный сельский Дом культуры, ул.Чепецкая, д.26		0101000020E610000001309E4143134A408A213999B81B4D40
6937	7	65	1498	17615	\N	\N	58.102518753357501	427506, Адрес УИК и помещения для голосования: Удмуртская Республика, Ярский район, деревня Ворца, ул.Чапаевская (Ворцинская средняя общеобразоват. школа), д.6а	Россия, республика Удмуртская, Ярский район, село Ворца	0101000020E6100000B3EA73B515134A40FC1BB4571F0D4D40
6938	7	65	1498	17629	53241	\N	58.069333	Удмуртская Республика, Ярский район, деревня Васепиево, Васепиевский сельский клуб, ул.Первомайская, д.2		0101000020E61000003FE1ECD632074A404CC45BE7DF084D40
6936	7	65	1498	17543	52937	\N	58.275785999999997	Удмуртская Республика, Ярский район, деревня Бачумово, Бачумовский сельский Дом культуры, ул.Школьная, д.27		0101000020E61000006EC328081EF54940EA58A5F44C234D40
6934	7	65	1498	17414	52809	\N	58.259113999999997	Удмуртская Республика, Ярский район, деревня Бармашур, Бармашурский сельский Дом культуры, ул.Советская, д.33		0101000020E6100000D1E638B7090B4A40C6F7C5A52A214D40
6933	7	65	1401	16013	\N	\N	57.180575415556902	427100, Адрес УИК и помещения для голосования: Удмуртская Республика, Якшур-Бодьинский район, село Якшур-Бодья, ул.Боровая (здание лесничества), 2а	Россия, республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья	0101000020E6100000D05E7D3CF4954A40D3BCE3141D974C40
6907	7	65	1401	16013	\N	\N	57.186587839338401	427100, Адрес УИК и помещения для голосования: Удмуртская Республика, Якшур-Бодьинский район, село Якшур-Бодья, ул. Пушиной (здание средней школы), 61	Россия, республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья	0101000020E61000003E40F7E5CC944A40BCE9961DE2974C40
6927	7	65	1401	16013	52935	\N	57.183002000000002	Удмуртская Республика, Якшур-Бодьинский район, село Якшур-Бодья, проезд Гребенщикова, 10		0101000020E61000003CDD79E239954A40228D0A9C6C974C40
6926	7	65	1401	16013	52429	\N	57.183002000000002	Удмуртская Республика, Якшур-Бодьинский район, село Якшур-Бодья, улица Пушиной, 135		0101000020E61000003CDD79E239954A40228D0A9C6C974C40
6471	7	65	1401	16203	52634	\N	57.211194143208097	"Удмуртская Республика, Завьяловский район, д. Якшур, МБУ ""КК ""Якшурский"", ул. Юбилейная, д. 7"	Россия, республика Удмуртская, Якшур-Бодьинский район, село Якшур	0101000020E6100000529E7939EC944A40438EAD67089B4C40
6909	7	65	1401	16203	52722	\N	57.211410999999998	Удмуртская Республика, Якшур-Бодьинский район, деревня Якшур, улица Комсомольская, 7		0101000020E6100000684128EFE3944A40E08101840F9B4C40
6932	7	65	1401	15919	52702	\N	57.110759999999999	Удмуртская Республика, Якшур-Бодьинский район, село Чур, улица Коммунаров, 5а		0101000020E61000009BAE27BA2E7C4A403CDA38622D8E4C40
6904	7	65	1401	15919	52702	\N	57.110853417697399	Удмуртская Республика, Якшур-Бодьинский район, село Чур, улица Коммунаров, 20а	Россия, республика Удмуртская, Якшур-Бодьинский район, село Чур	0101000020E6100000E73A8DB4547C4A40EDD45C6E308E4C40
6913	7	65	1401	16410	52934	\N	57.204625	Удмуртская Республика, Якшур-Бодьинский район, деревня Сюровай, улица Пушкина, 13		0101000020E61000004F5C8E5720764A40D578E926319A4C40
6914	7	65	1401	16415	52519	\N	57.348067	Удмуртская Республика, Якшур-Бодьинский район, село Старые Зятцы, улица площадь Свободы, 6		0101000020E6100000EF3A1BF2CF524A408EE89E758DAC4C40
6931	7	65	1401	16415	53023	\N	57.348067	Удмуртская Республика, Якшур-Бодьинский район, село Старые Зятцы, улица Октябрьская, 10		0101000020E6100000EF3A1BF2CF524A408EE89E758DAC4C40
6920	7	65	1401	16741	52518	\N	57.071109	Удмуртская Республика, Якшур-Бодьинский район, село Селычка, улица Школьная, 16		0101000020E61000005342B0AA5E984A40C3B986191A894C40
6921	7	65	1401	16816	53024	\N	57.207394999999998	Удмуртская Республика, Якшур-Бодьинский район, деревня Пушкари, улица Молодежная, 10		0101000020E61000004D86E3F90CA04A404D2D5BEB8B9A4C40
6912	7	65	1401	16324	53137	\N	57.220042999999997	Удмуртская Республика, Якшур-Бодьинский район, деревня Порва, улица Молодежная, 6		0101000020E61000007A51BB5F05844A405B5B785E2A9C4C40
6911	7	65	1401	16302	53025	\N	57.204528000000003	Удмуртская Республика, Якшур-Бодьинский район, деревня Нижний Пислеглуд, улица Молодежная, 24		0101000020E6100000738577B9888B4A40E38E37F92D9A4C40
6924	7	65	1401	16929	52810	\N	57.240909000000002	Удмуртская Республика, Якшур-Бодьинский район, деревня Мукши, улица Советская, 9		0101000020E6100000B91CAF40F4B24A40F2272A1BD69E4C40
6917	7	65	1401	16611	53240	\N	57.143068	Удмуртская Республика, Якшур-Бодьинский район, деревня Малая Итча, улица Молодежная, 1		0101000020E6100000639B5434D66C4A40548D5E0D50924C40
6919	7	65	1401	16725	52701	\N	57.014404999999996	Удмуртская Республика, Якшур-Бодьинский район, село Люкшудья, улица Совхозная, 4		0101000020E61000000DDFC2BAF1844A400EF3E505D8814C40
6910	7	65	1401	16206	52649	\N	57.295043	Удмуртская Республика, Якшур-Бодьинский район, село Лынга, улица Советская, 15		0101000020E61000004B3D0B4279834A40F5F411F8C3A54C40
6925	7	65	1401	17011	53165	\N	57.287601000000002	Удмуртская Республика, Якшур-Бодьинский район, деревня Кыква, улица Советская, 5		0101000020E61000004B22FB20CBB64A4001A60C1CD0A44C40
6929	7	65	1401	17210	53244	\N	57.211449999999999	Удмуртская Республика, Якшур-Бодьинский район, село Кекоран, улица Советская, 28а		0101000020E6100000153B1A87FA7D4A409E5E29CB109B4C40
6930	7	65	1401	17219	52936	\N	57.139459000000002	Удмуртская Республика, Якшур-Бодьинский район, деревня Иж-Забегалово, улица Пушиной, 18б		0101000020E610000013B69F8CF1AB4A400211E2CAD9914C40
6916	7	65	1401	16534	53022	\N	57.314739000000003	Удмуртская Республика, Якшур-Бодьинский район, деревня Зеглуд, улица Центральная, 13		0101000020E61000006B2A8BC22E4A4A404CE3175E49A84C40
6928	7	65	1401	17140	53242	\N	57.168038000000003	Удмуртская Республика, Якшур-Бодьинский район, деревня Выжоил, улица Ключевая, 29		0101000020E6100000D74D29AF95884A401D3EE94482954C40
6893	7	65	1401	15435	53019	\N	57.278621000000001	Удмуртская Республика, Якшур-Бодьинский район, деревня Варавай, улица Советская, 42		0101000020E61000006D8E739B70494A404A7D59DAA9A34C40
6923	7	65	1401	16917	53135	\N	57.200924999999998	Удмуртская Республика, Якшур-Бодьинский район, деревня Большие Ошворцы, улица Центральная, 13		0101000020E61000000150C58D5BA64A4072F90FE9B7994C40
6915	7	65	1401	16513	52931	\N	57.273496999999999	Удмуртская Республика, Якшур-Бодьинский район, деревня Алгазы, улица Центральная, 19		0101000020E6100000F60CE19865614A40ED461FF301A34C40
6884	7	65	1368	14783	\N	\N	57.8971827859299	"427680, Адрес УИК и помещения для голосования: Удмуртская Республика, Юкаменский район, муниципальное образование ""Юкаменское"", с.Юкаменское, ул.Молодежная (здание ООО ""Монолит""), д.1"	Россия, республика Удмуртская, Юкаменский район, село Юкаменское	0101000020E6100000994528B6821E4A407AC37DE4D6F24C40
6887	7	65	1368	14783	52698	\N	57.893318999999998	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Юкаменское"", с.Юкаменское, ул.Первомайская, д.78 (контора ООО ""ЖКК"")"		0101000020E6100000485167EE211F4A409DF2E84658F24C40
6885	7	65	1368	14783	52698	\N	57.893318999999998	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Юкаменское"", с.Юкаменское, ул. Первомайская, д.56 (ЦРБ)"		0101000020E6100000485167EE211F4A409DF2E84658F24C40
6880	7	65	1368	14783	52698	\N	57.893318999999998	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Юкаменское"", с.Юкаменское, ул.Первомайская, д.4 (РДК)"		0101000020E6100000485167EE211F4A409DF2E84658F24C40
6886	7	65	1368	14783	52721	\N	57.893318999999998	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Юкаменское"", с.Юкаменское, ул.Майская, 12а (Спецдом)"		0101000020E6100000485167EE211F4A409DF2E84658F24C40
6874	7	65	1271	14486	53131	\N	57.398842999999999	Удмуртская Республика, Шарканский район, село Сюрсовай, Сюрсовайская СОШ, улица Школьная, дом 10		0101000020E610000013BBB6B75BD44A40889E94490DB34C40
6881	7	65	1368	14783	53235	\N	57.893318999999998	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Юкаменское"", с.Юкаменское, ул.Вежеевская, д.37 (школа)"		0101000020E6100000485167EE211F4A409DF2E84658F24C40
6894	7	65	1368	15456	53020	\N	57.839832000000001	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Верх-Унинское"", д.Шафеево, ул.Центральная, д.5 (детсад)"		0101000020E6100000ADDF4C4C17124A4030116F9D7FEB4C40
6895	7	65	1368	15537	52862	\N	58.017268000000001	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Шамардановское"", д.Шамардан, ул.Центральная, д.5 (школа)"		0101000020E6100000E86B96CB46134A4038A27BD635024D40
6899	7	65	1368	56392	52939	\N	57.981704129983498	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Ежевское"", д.Тат-Ключи, ул.Новая, д.1 (ФАП)"	Россия, республика Удмуртская, Юкаменский район, село Татарские Ключи	0101000020E61000001AFA27B858214A401B2D077AA8FD4C40
6889	7	65	1368	15238	52699	\N	57.898891999999996	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Пышкетское"", с.Пышкет, ул.Советская, д.12а (администрация МО)"		0101000020E6100000310C587215FB494069519FE40EF34C40
6898	7	65	1368	15642	53237	\N	57.956617000000001	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Ежевское"", д.Починки, ул.Средняя, д.6 (школа)"		0101000020E61000003BA759A0DD214A4019E6046D72FA4C40
6900	7	65	1368	15730	52720	\N	57.954340000000002	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Палагайское"", д.Палагай, ул.Центральная, д.75 (администрация МО)"		0101000020E61000002FBE688F172E4A40E0A128D027FA4C40
6896	7	65	1368	56414	53248	\N	57.979020911401904	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Шамардановское"", д.Ново-Елово, ул.Центральная, д.1 (школа)"	Россия, республика Удмуртская, Юкаменский район, село Новоелово	0101000020E610000007600322C4054A40728C648F50FD4C40
6903	7	65	1368	15920	52959	\N	57.878822	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Засековское"", д.Малый Вениж, ул.Молодежная, д.16 (школа)"		0101000020E61000000E68E90AB63F4A40AE80423D7DF04C40
6888	7	65	1368	15174	52930	\N	57.965192999999999	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Пышкетское"", д.Кельдыки, ул.Центральная, д.23 (СДК)"		0101000020E61000001DE90C8CBC004A4000AAB8718BFB4C40
6883	7	65	1368	14958	53021	\N	57.813549999999999	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Юкаменское"", д.Камки, ул.Молодежная, д.3 (СДК)"		0101000020E61000001B9C887E6D1B4A4095D4096822E84C40
6891	7	65	1368	15340	53018	\N	57.834508999999997	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Ертемское"", д.Зянкино, ул.Лесная, д.6 (СДК)"		0101000020E6100000AC014A438DF84940DC9BDF30D1EA4C40
6901	7	65	1368	15807	53238	\N	57.855370000000001	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Засековское"", д.Засеково, ул.Школьная, д.9 (школа)"		0101000020E6100000494DBB9866364A4061FD9FC37CED4C40
6902	7	65	1368	15837	53132	\N	57.821823999999999	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Засековское"", д.Жувам, ул. Центральная, д.42 (школа)"		0101000020E6100000C7D5C8AEB42A4A40B188618731E94C40
6890	7	65	1368	15259	53143	\N	57.888277000000002	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Ертемское"", д.Ертем, ул.Советская, д.23 (администрация МО)"		0101000020E610000002BA2F67B6074A40FE648C0FB3F14C40
6897	7	65	1368	15634	52717	\N	58.028773000000001	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Ежевское"", с.Ежево, ул.Школьная, д.2 (администрация МО)"		0101000020E6100000FE0FB056ED1C4A4000016BD5AE034D40
6892	7	65	1368	15346	53236	\N	57.811042999999998	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Верх-Унинское"", с.Верх-Уни, ул.Молодежная, д.36 (СДК)"		0101000020E6100000984C158C4A0C4A402A53CC41D0E74C40
6905	7	65	1368	16001	53239	\N	57.889907999999998	"Удмуртская Республика, Юкаменский район, муниципальное образование ""Засековское"", д.Бадеро, ул.Луговая, д.1а (СДК)"		0101000020E6100000F4E159828C324A4071395E81E8F14C40
6869	7	65	1271	14120	\N	\N	57.302681547342097	"427070, Адрес УИК и помещения для голосования: Удмуртская Республика, Шарканский район, деревня Кипун, ул. Казакова (здание детского сада ""Аленушка""), дом 13 а"	Россия, республика Удмуртская, Шарканский район, село Шаркан	0101000020E6100000B4E4F1B4FCEE4A403F8BA548BEA64C40
6868	7	65	1271	14120	52430	\N	57.299925000000002	Удмуртская Республика, Шарканский район, с.Шаркан, Управление Образования, улица Советская, дом 38		0101000020E610000097900F7A36EF4A405C2041F163A64C40
6867	7	65	1271	14120	52648	\N	57.299925000000002	"Удмуртская Республика, Шарканский район, село Шаркан, администрация МО ""Шарканский район"", улица Ленина, дом 14"		0101000020E610000097900F7A36EF4A405C2041F163A64C40
6866	7	65	1271	14120	52509	\N	57.302297095454001	Удмуртская Республика, Шарканский район, село Шаркан, Районный дом культуры, улица Коммунальная, дом 1	Россия, республика Удмуртская, Шарканский район, село Шаркан	0101000020E6100000056B9C4D47F04A40E75608ABB1A64C40
6857	7	65	1271	13718	53126	\N	57.225301000000002	Удмуртская Республика, Шарканский район, деревня Чужегово, Чужеговская НОШ, улица Центральная, дом 15		0101000020E61000002618CE35CC044B40C860C5A9D69C4C40
6878	7	65	1271	14692	53136	\N	57.300663999999998	Удмуртская Республика, Шарканский район, деревня Титово, Сельский дом культуры, улица Азина, дом 2		0101000020E6100000DC2E34D769FA4A40D28A6F287CA64C40
6873	7	65	1271	14479	53140	\N	57.326197999999998	Удмуртская Республика, Шарканский район, деревня Суроново, Сельский клуб, улица Молодежная, дом 1а		0101000020E6100000952A51F696C24A40A30227DBC0A94C40
6847	7	65	1271	13255	52715	\N	57.217703	Удмуртская Республика, Шарканский район, деревня Старые Быги, Быгинская СОШ, улица Школьная, дом 6		0101000020E610000039F06AB933E14A40DC9E20B1DD9B4C40
6871	7	65	1271	56412	53246	\N	57.348208046142297	"Удмуртская Республика, Шарканский район, деревня Старое Ягино, ООО ""Труженик"", улица Колхозная, дом 42"	Россия, республика Удмуртская, Шарканский район, село СтароеЯгино	0101000020E61000002B4B749659E24A40501A6A1492AC4C40
6865	7	65	1271	14098	52716	\N	57.258043999999998	"Удмуртская Республика, Шарканский район, село Сосновка, администрация МО ""Сосновское"", улица Центральная, дом 11"		0101000020E6100000A12FBDFDB9C24A40EA76F69507A14C40
6860	7	65	1271	13814	75052	\N	57.235579549776503	427073, Адрес УИК и помещения для голосования: Удмуртская Республика, Шарканский район, деревня Собино, ул. Тамбырь (административное здание КФК Собина Н.И.), дом 5б	Россия, республика Удмуртская, Шарканский район, село Собино	0101000020E610000046787B1002F64A40BCCB457C279E4C40
6848	7	65	1271	13261	52828	\N	57.274655000000003	"Удмуртская Республика, Шарканский район, деревня Порозово, кафе ""Чингыли"", улица Центральная, дом 60"		0101000020E6100000812381069BFA4A40695721E527A34C40
6864	7	65	1271	14036	53017	\N	57.226509	Удмуртская Республика, Шарканский район, деревня Пашур-Вишур, Пашур-Вишурская НОШ, улица Школьная, дом 7		0101000020E6100000B07092E68FD54A40F59F353FFE9C4C40
6855	7	65	1271	13626	53139	\N	57.323171000000002	Удмуртская Республика, Шарканский район, деревня Нижние Кивары, Ниж-Киварская СОШ, улица Садовая, дом 4		0101000020E6100000F9BF232A540B4B400002D6AA5DA94C40
6849	7	65	1271	58780	\N	\N	57.201078869349999	427079, Адрес УИК и помещения для голосования: Удмуртская Республика, Шарканский район, деревня Нижний Казес, ул. Школьная (здание сельского дома культуры), дом 4	Россия, республика Удмуртская, Шарканский район, село Нижние Быги	0101000020E6100000CDC8207711DE4A40C974E8F4BC994C40
6872	7	65	1271	14409	52806	\N	57.294600000000003	Удмуртская Республика, Шарканский район, деревня Мувыр, Мувырская СОШ, улица Молодежная, дом 14		0101000020E6100000DD9A745B22CB4A4068B3EA73B5A54C40
6859	7	65	1271	13817	52932	\N	57.211596	Удмуртская Республика, Шарканский район, деревня Малый Казес, Сельский клуб, улица Камышево, дом 28		0101000020E6100000C689AF7614ED4A4072FBE593159B4C40
6870	7	65	1271	14319	52845	\N	57.363303000000002	Удмуртская Республика, Шарканский район, деревня Кыква, Кыквинская СОШ, улица Центральная, дом 7		0101000020E61000007EFCA5457DEA4A40F4C473B680AE4C40
6876	7	65	1271	14587	53234	\N	57.349227999999997	Удмуртская Республика, Шарканский район, деревня Кулак- Кучес, Кусогуртская НОШ, улица Центральная, дом 8		0101000020E61000005AF10D85CFCC4A407A6CCB80B3AC4C40
6861	7	65	1271	13911	53230	\N	57.307734000000004	Удмуртская Республика, Шарканский район, деревня Козино, Сельский дом культуры, улица Родниковая, дом 4		0101000020E610000009FA0B3D62044B4003EFE4D363A74C40
6851	7	65	1271	13442	53014	\N	57.415531000000001	Удмуртская Республика, Шарканский район, деревня Кельдыш, Кельдышевская ООШ, Школьный переулок, дом 1		0101000020E61000001F69705B5B064B40B2BCAB1E30B54C40
6856	7	65	1271	13654	53228	\N	57.273336	Удмуртская Республика, Шарканский район, деревня Карсашур, Карсашурская ООШ, улица Пушкинская, дом 3		0101000020E6100000A73B4F3C67074B40E4688EACFCA24C40
6854	7	65	1271	13443	\N	\N	57.472782394316397	427083, Адрес УИК и помещения для голосования: Удмуртская Республика, Шарканский район, село Зюзино, ул. Мира (здание Зюзинской СОШ), дом 30		0101000020E610000071917BBABA034B409911DE1E84BC4C40
6852	7	65	1271	13443	52696	\N	57.474383000000003	Удмуртская Республика, Шарканский район, село Зюзино, Зюзинская СОШ, улица Мира, дом 30		0101000020E6100000AD4ECE50DC034B40A2630795B8BC4C40
6862	7	65	1271	13936	52697	\N	57.195487999999997	Удмуртская Республика, Шарканский район, деревня Заречный Вишур, здание сельской администрации, улица Поселковская, дом 17		0101000020E6100000FE63213A04CA4A40566133C005994C40
6875	7	65	1271	14705	52807	\N	57.305841999999998	"Удмуртская Республика, Шарканский район, деревня Вортчино, администрация МО ""Вортчинское"", улица Мира, дом 1"		0101000020E6100000795DBF6037DC4A4022DFA5D425A74C40
6850	7	65	1271	13372	52994	\N	57.438518999999999	Удмуртская Республика, Шарканский район, деревня Бородули, Бородулинская ООШ, Школьный переулок, дом 1		0101000020E6100000F2CF0CE203154B405AD6FD6321B84C40
6877	7	65	1271	14666	53130	\N	57.361705999999998	Удмуртская Республика, Шарканский район, деревня Большой Билиб, Билибская НОШ, улица Степанова, дом 2		0101000020E6100000FBE8D495CFFC4A402C62D8614CAE4C40
6853	7	65	1271	13530	53015	\N	57.496115000000003	Удмуртская Республика, Шарканский район, деревня Байкей, Фельдшерский акушерский пункт, улица Труда, дом 28		0101000020E6100000C2A6CEA3E20B4B400C0742B280BF4C40
6076	7	65	7411	56367	52530	\N	56.846708895256199	Удмуртская Республика, город Ижевск, Устиновский район, Союзная, 25		0101000020E610000056815A0C1EA64A404B1DE4F5606C4C40
6819	7	65	1195	11941	53223	\N	56.861396999999997	Удмуртская Республика, Увинский район, д.Чистостем, ул.Центральная, 9		0101000020E6100000362383DC451C4A40AEEFC341426E4C40
6830	7	65	1195	12460	53124	\N	57.113765000000001	Удмуртская Республика, Увинский район, с.Чекан, ул.Нагорная, 18		0101000020E610000049F59D5F94544A40F836FDD98F8E4C40
6836	7	65	1195	12754	52714	\N	57.054141000000001	Удмуртская Республика, Увинский район, д.Узей-Тукля, ул.Пислегина, 4		0101000020E61000005B25581CCE124A40B62FA017EE864C40
6843	7	65	1195	12832	\N	\N	56.986159263018003	427260, Адрес УИК и помещения для голосования: Удмуртская Республика, Увинский район, п.Ува, ул.Максима Горького (профессиональный колледж), д.95	Россия, республика Удмуртская, Увинский район, поселок Ува	0101000020E61000002B6C06B820174A40FAD346753A7E4C40
6835	7	65	1195	12832	\N	\N	56.981660652028602	427260, Адрес УИК и помещения для голосования: Удмуртская Республика, Увинский район, с.Подмой, ул.Станционная (Подмойская школа-сад), д.19	Россия, республика Удмуртская, Увинский район, поселок Ува	0101000020E6100000DB19A6B6D4174A401C615111A77D4C40
6828	7	65	1195	12832	\N	\N	56.996279142535798	"427260, Адрес УИК и помещения для голосования: Удмуртская Республика, Увинский район, с.У,дугучин, ул.Свободы (средняя школа), д.13"	Россия, республика Удмуртская, Увинский район, поселок Ува	0101000020E61000009F02603C83164A408658FD11867F4C40
6846	7	65	1195	12832	52647	\N	56.988002000000002	Удмуртская Республика, Увинский район, п.Ува, ул.Энгельса, 3		0101000020E610000042EBE1CB44174A40F9307BD9767E4C40
6838	7	65	1195	12832	52439	\N	56.984255986641102	Удмуртская Республика, Увинский район, п.Ува, ул.Селтинская, 1	Россия, республика Удмуртская, Увинский район, поселок Ува	0101000020E61000003B6D8D08C6174A402672C119FC7D4C40
6845	7	65	1195	12832	52805	\N	56.988002000000002	Удмуртская Республика, Увинский район, п.Ува, ул.Курчатова, 16		0101000020E610000042EBE1CB44174A40F9307BD9767E4C40
6841	7	65	1195	12832	52924	\N	56.988002000000002	Удмуртская Республика, Увинский район, п.Ува, ул.Курортная, 13		0101000020E610000042EBE1CB44174A40F9307BD9767E4C40
6844	7	65	1195	12832	52506	\N	56.988002000000002	Удмуртская Республика, Увинский район, п.Ува, ул.Калинина, 13		0101000020E610000042EBE1CB44174A40F9307BD9767E4C40
6842	7	65	1195	12832	52506	\N	56.988002000000002	Удмуртская Республика, Увинский район, п.Ува, ул.Калинина, 21		0101000020E610000042EBE1CB44174A40F9307BD9767E4C40
6839	7	65	1195	12832	52515	\N	56.988002000000002	Удмуртская Республика, Увинский район, п.Ува, ул.Заводская, 1		0101000020E610000042EBE1CB44174A40F9307BD9767E4C40
6823	7	65	1195	12122	52923	\N	57.047620000000002	Удмуртская Республика, Увинский район, д.Сюровай, ул.Удмуртская, 24		0101000020E6100000C3499A3FA6014A405951836918864C40
6822	7	65	1195	12089	52695	\N	56.917180000000002	Удмуртская Республика, Увинский район, с.Рябово, ул.Советская, 4		0101000020E6100000B936548CF3094A40CC457C2766754C40
95078	7	65	1195	12627	53233	\N	57.118192999999998	427260 Увинский район, д.Пужмесь-Тукля ул.Школьная (медпункт) д.19		0101000020E61000006F9EEA909B394A40DDCEBEF2208F4C40
6824	7	65	1195	12182	52712	\N	57.094499999999996	Удмуртская Республика, Увинский район, д.Поршур-Тукля, ул.Пислегина, 22		0101000020E61000005DF8C1F9D4134A406ABC7493188C4C40
6812	7	65	1195	11593	53158	\N	56.696579999999997	Удмуртская Республика, Увинский район, д.Петропавлово, ул.Садовая, 14а		0101000020E610000088BEBB9525404A401A868F8829594C40
6827	7	65	1195	12341	52978	\N	57.138579999999997	Удмуртская Республика, Увинский район, д.Пачегурт, ул.Труда, 2б		0101000020E61000004DF6CFD3801D4A4099F04BFDBC914C40
95079	7	65	1195	12661	52928	\N	56.983980000000003	427260 Увинский район, с.Областная ул.Линейная (сельский дом культуры) д.22Б		0101000020E6100000F279C5538F4A4A4084F57F0EF37D4C40
6815	7	65	1195	11758	52822	\N	56.761668999999998	Удмуртская Республика, Увинский район, с,Нылга, ул. Садовая, 14		0101000020E6100000CC7D7214202E4A4042B0AA5E7E614C40
6816	7	65	1195	11758	52645	\N	56.761668999999998	Удмуртская Республика, Увинский район, с.Нылга, пер.Школьный, 2		0101000020E6100000CC7D7214202E4A4042B0AA5E7E614C40
6826	7	65	1195	12258	52826	\N	57.151476000000002	Удмуртская Республика, Увинский район, с.Новый Мултан, ул.Советская, 1а		0101000020E610000052B648DA8D244A408010C99063934C40
6832	7	65	1195	12546	53229	\N	57.060901000000001	Удмуртская Республика, Увинский район, с.Мушковай, ул.Школьная, 35		0101000020E6100000512D228AC9434A4098A59D9ACB874C40
95077	7	65	1195	56411	53227	\N	57.102371193088601	427260 Увинский район, с.Сям-Можга ул.Школьная (сельский дом культуры) д.12		0101000020E61000004374081C09FC49408787307E1A8D4C40
6829	7	65	1195	12441	52925	\N	57.201666000000003	Удмуртская Республика, Увинский район, д.Малые Сюрзи, ул.Центральная, 2		0101000020E6100000E20511A969314A408A5B0531D0994C40
6813	7	65	1195	11645	53161	\N	56.722839999999998	Удмуртская Республика, Увинский район, д,Лоллез Жикья, ул.Зеленая, 5а		0101000020E6100000C6FCDCD094394A40CD1E6805865C4C40
6817	7	65	1195	11844	52668	\N	56.867041	Удмуртская Республика, Увинский район, с.Кыйлуд, ул.Школьная, 5		0101000020E6100000BC57AD4CF8394A4044A51133FB6E4C40
6811	7	65	1195	11565	52988	\N	56.807481000000003	Удмуртская Республика, Увинский район, д.Кулябино, ул.Школьная, 1		0101000020E610000075ADBD4F55274A40199293895B674C40
95076	7	65	1195	11669	52713	\N	56.737811000000001	427260  Увинский район, с.Красное ул.Советская (сельский дом культуры) д.2		0101000020E6100000B8567BD80B4B4A4085D04197705E4C40
6820	7	65	1195	11964	52922	\N	56.879865000000002	Удмуртская Республика, Увинский район, с.Киби-Жикья, ул.Школьная, 7		0101000020E6100000D4EE5701BE134A4091F2936A9F704C40
6831	7	65	1195	12523	52711	\N	56.984392	Удмуртская Республика, Увинский район, с.Каркалай, ул.Азина, 4		0101000020E6100000B9E2E2A8DC304A40D6389B8E007E4C40
95080	7	65	1195	12807	53232	\N	57.090415999999998	427260 Увинский район, д.Возеншур ул.Клубная (сельский клуб) д.2		0101000020E61000009ED32CD0EE0C4A407F8461C0928B4C40
6818	7	65	1195	11868	53199	\N	56.909008	Удмуртская Республика, Увинский район, с.Вишур, ул.Советская, 38		0101000020E610000008C89750C13D4A40B4E6C75F5A744C40
6445	7	65	1195	25825	52626	\N	56.681047	Удмуртская Республика, Увинский район, с.Булай, ул.Ленина, 11		0101000020E61000004C4F58E201294A40FB04508C2C574C40
6810	7	65	1195	11501	52801	\N	56.715381000000001	Удмуртская Республика, Увинский район, д.Большой Жужгес, ул.Клубная, 25		0101000020E61000005F0CE544BB224A400397C79A915B4C40
95074	7	65	1128	56391	52929	\N	56.947398053635403	427386 Сюмсинский район, ст. Сюрек ул. Первомайская, (ФАП) д. 4	Россия, республика Удмуртская, Сюмсинский район, поселок Сюрек	0101000020E610000046B41D5377B94940DD25715644794C40
6791	7	65	1128	10389	\N	\N	57.112646125336703	427370, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, д. Акилово, ул. Вишневая, (спец. дом), д. 5	Россия, республика Удмуртская, Сюмсинский район, село Сюмси	0101000020E610000058E6ADBA0ECF49403A03232F6B8E4C40
6790	7	65	1128	10389	\N	\N	57.113790110949701	427370, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, с. Сюмси, ул. Лесная, (учебный корпус ПУ-34), д. 23	Россия, республика Удмуртская, Сюмсинский район, село Сюмси	0101000020E6100000C311A452ECCE4940514EB4AB908E4C40
6788	7	65	1128	10389	52804	\N	57.111175000000003	Удмуртская Республика, Сюмсинский район, с. Сюмси, ул. Советская, д. 56		0101000020E610000083A6255646CF494000917EFB3A8E4C40
6787	7	65	1128	10389	52512	\N	57.111175000000003	Удмуртская Республика, Сюмсинский район, с. Сюмси, ул. Партизанская, д. 4		0101000020E610000083A6255646CF494000917EFB3A8E4C40
6786	7	65	1128	10389	52512	\N	57.111175000000003	Удмуртская Республика, Сюмсинский район, с. Сюмси, ул. Партизанская, д. 54		0101000020E610000083A6255646CF494000917EFB3A8E4C40
6789	7	65	1128	10389	52819	\N	57.111175000000003	Удмуртская Республика, Сюмсинский район, с. Сюмси, ул. Лесная, д. 23		0101000020E610000083A6255646CF494000917EFB3A8E4C40
6795	7	65	1128	20586	\N	\N	57.078798103023701	427374, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, д. Правые Гайны, ул. Школьная, (школа-детский сад), д. 4	Россия, республика Удмуртская, Сюмсинский район, село Правые Гайны	0101000020E6100000B2D6506A2FE04940BF7E880D168A4C40
6799	7	65	1128	22042	\N	\N	56.902095166709799	427385, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, ст. Пижил, ул. Школьная, (школа), д.34	Россия, республика Удмуртская, Сюмсинский район, поселок Пижил	0101000020E6100000A8C30AB77CCA49404C7155D977734C40
6802	7	65	1128	11120	52694	\N	57.115338999999999	Удмуртская Республика, Сюмсинский район, с. Орловское, пер. Торфяной, д. 2а		0101000020E6100000280F0BB5A6B74940077AA86DC38E4C40
6801	7	65	1128	11097	53152	\N	56.953560000000003	Удмуртская Республика, Сюмсинский район, с. Муки-Какси, ул. Колхозная, д. 2а		0101000020E610000003EB387EA8B449400B630B410E7A4C40
6792	7	65	1128	10654	52951	\N	57.167701000000001	Удмуртская Республика, Сюмсинский район, д. Маркелово, ул. Маркеловская, д. 1		0101000020E61000006F826F9A3EE14940D540F33977954C40
6796	7	65	1128	58389	\N	\N	57.053011690222	427374, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, д. Дмитрошур, ул. Клубная, (школа), д. 2	Россия, республика Удмуртская, Сюмсинский район, село Лялино	0101000020E6100000994869368FDD4940D525E318C9864C40
95075	7	65	1128	11284	53046	\N	57.343259000000003	427383 Сюмсинский район, д. Ключевка ул. Первомайская, (сельский клуб) д. 11		0101000020E6100000E8F7FD9B17C34940628731E9EFAB4C40
6793	7	65	1128	10739	53037	\N	57.143771533344399	Удмуртская Республика, Сюмсинский район, д. Лекшур, ул. Лекшурская, д. 24	Россия, республика Удмуртская, Сюмсинский район, село Лекшур	0101000020E6100000575D876A4AEC49404E0AF31E67924C40
6808	7	65	1128	11385	52428	\N	57.009475000000002	Удмуртская Республика, Сюмсинский район, с. Кильмезь, ул. Пушкинская, д. 7		0101000020E6100000D1E80E6267AA494097900F7A36814C40
6803	7	65	1128	11181	52927	\N	57.180787000000002	Удмуртская Республика, Сюмсинский район, с. Зон, ул. Школьная, д. 31а		0101000020E610000049F7730AF2AD49405F45460724974C40
6794	7	65	1128	58386	\N	\N	57.119650121079502	427376, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, д. Гуртлуд, ул. Молодежная, (школа), д. 1	Россия, республика Удмуртская, Сюмсинский район, село Гуртруд	0101000020E61000003E4162BB7BDA4940B37BF2B0508F4C40
6805	7	65	1128	21908	\N	\N	57.286696851349802	427383, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, с. Гура, ул. Школьная, (школа), д. 10	Россия, республика Удмуртская, Сюмсинский район, село Гура	0101000020E6100000DC0DA2B5A2B349403F6EBF7CB2A44C40
6804	7	65	1128	21908	\N	\N	57.282978480857899	427383, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, с.Гура, ул. Школьная, (школа), д. 10	Россия, республика Удмуртская, Сюмсинский район, село Гура	0101000020E6100000650113B875B3494066BE839F38A44C40
6797	7	65	1128	21996	\N	\N	57.034110499201503	427372, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, д. Васькино, ул. Школьная, (школа), д. 7	Россия, республика Удмуртская, Сюмсинский район, село Васькино	0101000020E61000003881E9B46EC94940B83B6BB75D844C40
6798	7	65	1128	10932	53043	\N	56.974159999999998	Удмуртская Республика, Сюмсинский район, д. Блаж-Юс, ул. Центральная, д.22		0101000020E610000096AFCBF09FCA494022895E46B17C4C40
6809	7	65	1128	11456	53156	\N	57.029716000000001	Удмуртская Республика, Сюмсинский район, д. Балма, ул. Балминская, д. 57		0101000020E6100000C00644882BAF49407F15E0BBCD834C40
6783	7	65	176	10212	52926	\N	57.241760999999997	"Удмуртская Республика, Селтинский район, муниципальное образование ""Сюромошурское"", д.Юмга-Омга, ул. Родниковая, 1"		0101000020E61000003BC43F6CE91B4A4060394206F29E4C40
6774	7	65	176	9784	53056	\N	57.271774000000001	"Удмуртская Республика, Селтинский район, муниципальное образование ""Кильмезское"", д.Югдон, ул. Молодежная, 3 А"		0101000020E6100000E57D1CCD911F4A4099F38C7DC9A24C40
6772	7	65	176	9679	52690	\N	57.207331000000003	"Удмуртская Республика, Селтинский район, муниципальное образование ""Халдинское"", с. Халды, ул. Советская, 6"		0101000020E6100000FAB9A1293BF5494037397CD2899A4C40
6760	7	65	131	9136	53031	\N	56.330271000000003	Удмуртская Республика, Сарапульский район, д.Оленье-Болото, ул.Сиреневая, д.2а		0101000020E610000053927538BAE44A409BE8F351462A4C40
6775	7	65	176	56418	53260	\N	57.359831660036797	"Удмуртская Республика, Селтинский район, муниципальное образование ""Копкинское"", с.Уть-Сюмси, ул. Школьная, 13"	Россия, республика Удмуртская, Селтинский район	0101000020E61000002BDEC83CF2FF4940F20698F90EAE4C40
6782	7	65	176	10173	52921	\N	57.35622	"Удмуртская Республика, Селтинский район, муниципальное образование ""Узинское"", с.Узи, ул.Советская, 29"		0101000020E6100000868DB27E33374A402F17F19D98AD4C40
95072	7	65	176	9991	52949	\N	57.230342999999998	Селтинский район, д. Сюромошур ул.Пушкинская, д.2 (здание школы)		0101000020E6100000D5CDC5DFF60A4A4067EE21E17B9D4C40
6597	7	65	176	555	52818	\N	57.367308000000001	Удмуртская Республика, Кизнерский район, д. Старые Копки, Здание школы, ул. Молодежная, 6		0101000020E6100000C9C9C4AD82E2494093C7D3F203AF4C40
6779	7	65	176	10015	52425	\N	57.311117000000003	"Удмуртская Республика, Селтинский район, муниципальное образование ""Селтинское"", с.Селты, Юбилейная, 1"		0101000020E6100000D95BCAF9620F4A40651D8EAED2A74C40
6780	7	65	176	10015	52643	\N	57.311117000000003	"Удмуртская Республика, Селтинский район, муниципальное образование ""Селтинское"", с.Селты, ул. Ленина, 30"		0101000020E6100000D95BCAF9620F4A40651D8EAED2A74C40
6784	7	65	176	58835	\N	\N	57.296688103395901	"427277, Адрес УИК и помещения для голосования: Удмуртская Республика, Селтинский район, муниципальное образование ""Колесурское"", д Пожгурт, ул. Пожгуртская (здание СДК), д. 47"	Россия, республика Удмуртская, Селтинский район, село Рожки	0101000020E610000083A7902BF52C4A40CE8E54DFF9A54C40
6776	7	65	176	9882	52691	\N	57.193624999999997	"Удмуртская Республика, Селтинский район, муниципальное образование ""Новомоньинское"", д. Новая Монья, пер.Субботина, 6"		0101000020E6100000A0DFF76F5E144A40105839B4C8984C40
95073	7	65	176	10310	53175	\N	57.2801201810911	"427270 Селтинский район, д. Мадьярово Молодежная, (здание СПК ""Нива"") д. 2"	Россия, республика Удмуртская, Селтинский район, село Мадьярово	0101000020E61000002AA8A8FA95124A404E7ADFF8DAA34C40
6773	7	65	176	9703	52800	\N	57.380813000000003	"Удмуртская Республика, Селтинский район, муниципальное образование ""Копкинское"", с.Копки, ул.Школьная, 7"		0101000020E6100000EC6D3315E2DF49402272FA7ABEB04C40
6771	7	65	176	9604	52710	\N	57.317883000000002	"Удмуртская Республика, Селтинский район, муниципальное образование ""Колесурское"", д.Колесур, ул. Карачева, 1"		0101000020E6100000A69C2FF65E204A40297AE063B0A84C40
6777	7	65	176	9900	52946	\N	57.156157999999998	"Удмуртская Республика, Селтинский район, муниципальное образование ""Новомоньинское"",д.Гобгурт, ул. 70 лет Октября, 26"		0101000020E61000002A37514B73074A401F813FFCFC934C40
6770	7	65	176	9557	53036	\N	57.455798999999999	"Удмуртская Республика, Селтинский район, муниципальное образование ""Валамазское"",с.Валамаз, пер. Молодежный, 1"		0101000020E61000006F4BE48233084A405646239F57BA4C40
6807	7	65	176	10096	\N	\N	57.264194947896698	427390, адрес УИК и помещения для голосования: Удмуртская Республика, Сюмсинский район, с. Кильмезь, ул. Ломоносова, (школа), д. 35	Россия, республика Удмуртская, Селтинский район, село Большой Кильмезь-Бия	0101000020E6100000FEF15EB532054A4024624A24D1A14C40
6781	7	65	176	10096	52920	\N	57.265082999999997	"Удмуртская Республика, Селтинский район, муниципальное образование ""Кильмезское"", д.Большая Кильмезь-Бия, ул. Азина, 27"		0101000020E610000079EBFCDB65054A40DFDC5F3DEEA14C40
6743	7	65	131	8321	52917	\N	56.618512000000003	Удмуртская Республика, Сарапульский район, деревня Юриха, ул.Комсомольская, д.4		0101000020E610000062A3ACDF4CDC4A407F17B6662B4F4C40
6756	7	65	131	8945	53149	\N	56.372129000000001	Удмуртская Республика, Сарапульский район, д.Юрино, ул.Советская, д.1		0101000020E61000007349D57613B04A4054724EECA12F4C40
6750	7	65	131	8688	52705	\N	56.462257000000001	Удмуртская Республика, Сарапульский район, с.Шевырялово, ул.Первомайская, д.54		0101000020E6100000C097C28366D34A406DACC43C2B3B4C40
6758	7	65	131	9038	52692	\N	56.280526000000002	Удмуртская Республика, Сарапульский район, д.Шадрино, ул.Школьная, д.9		0101000020E6100000696E85B01ACB4A40BFD6A546E8234C40
6765	7	65	131	9320	52817	\N	56.392387999999997	Удмуртская Республика, Сарапульский район, д.Усть-Сарапулка, ул.Вечтомова, д.60		0101000020E6100000F0164850FCEC4A40E2AB1DC539324C40
6593	7	65	131	284	52548	\N	56.488670999999997	Удмуртская Республика, Сарапульский район, с.Уральский, ул. Соскова, д.2		0101000020E61000002D431CEBE2C24A4076C075C58C3E4C40
6495	7	65	131	284	52548	\N	56.488908202117102	Удмуртская Республика, Сарапульский район, с.Уральское, ул.Соскова, д.2	Россия, республика Удмуртская, Сарапульский район, село Уральский	0101000020E610000050A912656FC34A405B608F89943E4C40
6762	7	65	131	9215	52795	\N	56.254171999999997	Удмуртская Республика, Сарапульский район, с.Тарасово, ул.Школьная, д.2		0101000020E610000095F1EF332E0E4B408AC745B588204C40
6764	7	65	131	9294	52709	\N	56.271979999999999	Удмуртская Республика, Сарапульский район, д.Соколовка, ул.Школьная, д.12		0101000020E61000004835ECF7C4024B4042959A3DD0224C40
95071	7	65	131	9384	52338	\N	56.422266	"Сарапульский район, МО ""Сигаевское"", с.Сигаево ул.Советская (здание Сарапульского дорожного предприятия) д.109"		0101000020E610000017838769DFE24A403B1BF2CF0C364C40
6767	7	65	131	9384	52338	\N	56.422266	Удмуртская Республика, Сарапульский район, с.Сигаево, ул.Советская, д.58		0101000020E610000017838769DFE24A403B1BF2CF0C364C40
6766	7	65	131	9384	52641	\N	56.422266	Удмуртская Республика, Сарапульский район, с.Сигаево, ул.Лермонтова, д.32		0101000020E610000017838769DFE24A403B1BF2CF0C364C40
6757	7	65	131	8978	52916	\N	56.279442000000003	Удмуртская Республика, Сарапульский район, д.Пентеги, ул.Молодежная, д.2		0101000020E610000048F8DEDFA0C14A407E9065C1C4234C40
6742	7	65	131	8314	52796	\N	56.646726867088198	Удмуртская Республика, Сарапульский район, село Нечкино, ул.Юбилейная, д.1	Россия, республика Удмуртская, Сарапульский район, село Нечкино	0101000020E6100000139B8F6B43E14A40583849F3C7524C40
6759	7	65	131	9063	52815	\N	56.278747000000003	Удмуртская Республика, Сарапульский район, с.Мостовое, ул.Платова, д.1б		0101000020E6100000124A5F0839DB4A40D76D50FBAD234C40
6761	7	65	131	9143	52708	\N	56.319229999999997	Удмуртская Республика, Сарапульский район, с. Мазунино, ул.Ленина, д.45		0101000020E61000000002D6AA5DFF4A4077F35487DC284C40
6744	7	65	131	8412	53030	\N	56.618333999999997	Удмуртская Республика, Сарапульский район, деревня Лагуново, ул. Школьная, д.1		0101000020E6100000F4DC425722CE4A409F008A91254F4C40
6768	7	65	131	9475	52919	\N	56.386045000000003	Удмуртская Республика, Сарапульский район, д.Костино, ул.Полевая, д.1а		0101000020E61000002250FD8348E04A4065E42CEC69314C40
6754	7	65	131	8796	52639	\N	56.363239	"Удмуртская Республика, Сарапульский район, муниципальное образование ""Кигбаевское"", с.Кигбаево, адрес помещения для голования: ул.Совхозная (здание школы), д.1а, адрес УИК: ул Совхозная (здание администрации), д.1"		0101000020E61000007D410B0918D14A40DDD0949D7E2E4C40
6753	7	65	131	8796	52639	\N	56.363239	Удмуртская Республика, Сарапульский район, с.Кигбаево, ул.Совхозная, д.1а		0101000020E61000007D410B0918D14A40DDD0949D7E2E4C40
6745	7	65	131	8438	52687	\N	56.549939000000002	Удмуртская Республика, Сарапульский район, деревня Дулесово, ул.Школьная, д.18		0101000020E6100000861E317A6EE34A40C1E5B16664464C40
6747	7	65	131	8518	53151	\N	56.542380999999999	Удмуртская Республика, Сарапульский район, д.Девятово, пер.Школьный, д.1		0101000020E610000067D311C0CDD24A40637C98BD6C454C40
6755	7	65	131	56401	53038	\N	56.366907018174999	Удмуртская Республика, Сарапульский район, д.Выезд, ул.Центральная, д.25	Россия, республика Удмуртская, Сарапульский район, село Выезд	0101000020E610000083F8C08EFFBA4A4034D6FECEF62E4C40
6746	7	65	1005	56400	53035	\N	56.511910324018899	Удмуртская Республика, Сарапульский район, с.Яромаска, ул.Мира, д.1б	Россия, республика Удмуртская, Сарапул городской округ, поселок Яромаска	0101000020E610000057CF49EF1BE94A40683F524486414C40
6752	7	65	1005	8709	52399	\N	56.463501000000001	Удмуртская Республика, Сарапульский район, с. Северный, ул.Октябрьская, д.6а		0101000020E6100000844A5CC7B8DE4A40E7543200543B4C40
6751	7	65	1005	8709	52399	\N	56.464539679846602	Удмуртская Республика, Сарапульский район, с.Северный, ул.Октябрьская, д.6а	Россия, республика Удмуртская, Сарапул городской округ, село Северный	0101000020E610000061C5A9D6C2DE4A4088D7F50B763B4C40
5989	7	65	7412	56369	52547	\N	56.857783428422898	Удмуртская Республика, город Ижевск, Октябрьский район, ул. М.Горького, д.160		0101000020E6100000302E55698B994A404A0856D5CB6D4C40
6732	7	65	847	56398	53032	\N	56.452361827430302	"Удмуртская Республика, Можгинский район, д.Залесный, Контора ООО ""Зверохозяйство Можгинское"", з-д Полевой, 2"	Россия, республика Удмуртская, Можгинский район	0101000020E61000002DEC6987BF244A4001FA7DFFE6394C40
6714	7	65	847	6971	52516	\N	56.444488	Удмуртская Республика, Можгинский район, с.Черемушки, Черемушкинский центральный дом культуры, ул.Заводская, 1		0101000020E6100000C4263273812D4A4073BB97FBE4384C40
6722	7	65	847	7348	53034	\N	56.323532999999998	Удмуртская Республика, Можгинский район, д.Трактор, Тракторский сельский дом культуры, ул.Удмуртская, 13		0101000020E6100000CB68E4F38A2B4A40A016838769294C40
6719	7	65	847	7188	52915	\N	56.332047000000003	Удмуртская Республика, Можгинский район, д.Старый Березняк, Ст-Березнякский сельский дом культуры, ул.Молодежная, 1б		0101000020E6100000A5846055BD384A4012DE1E84802A4C40
6723	7	65	847	7406	53029	\N	56.292127999999998	Удмуртская Республика, Можгинский район, д.Старые Юбери, Ст-Юберинская школа, ул.Юберинская, 1		0101000020E610000034492C2977274A40791F477364254C40
6725	7	65	847	7478	52707	\N	56.265017	Удмуртская Республика, Можгинский район, д.Старые Какси, Ст-Каксинский центральный дом культуры, ул.Даниила Яшина, 1а		0101000020E61000000F4757E9EE204A4028F1B913EC214C40
6734	7	65	847	7898	53145	\N	56.413254000000002	Удмуртская Республика, Можгинский район, ст.Сардан, Сарданский сельский клуб, з-д Больничный, 2		0101000020E61000005AA148F773084A407978CF81E5344C40
6708	7	65	847	6685	53013	\N	56.654066	Удмуртская Республика, Можгинский район, с.Русский Пычас, Русскопычасский сельский дом культуры, ул.Центральная, 4		0101000020E6100000B8E52329E9414A4078B6476FB8534C40
6710	7	65	847	6720	52426	\N	56.503349	Удмуртская Республика, Можгинский район, с.Пычас, Пычасский центральный сельский дом культуры, ул.Садовая, 14		0101000020E6100000B13385CE6B384A40B6BC72BD6D404C40
6709	7	65	847	6720	52566	\N	56.503349	"Удмуртская Республика, Можгинский район, с.Пычас, Контора торфопредприятия ""Можгинское"", ул.Переездная, 3"		0101000020E6100000B13385CE6B384A40B6BC72BD6D404C40
6728	7	65	847	7620	52861	\N	56.317681999999998	Удмуртская Республика, Можгинский район, с.Поршур, Поршурский сельский дом культуры, ул.Почтовая, 25		0101000020E6100000E08096AE60034A409143C4CDA9284C40
6739	7	65	847	8116	52703	\N	56.623479000000003	Удмуртская Республика, Можгинский район, д.Пазял, Пазяльский центральный сельский дом культуры, ул.Парковая, 27а		0101000020E6100000A3586E6935164A40145FED28CE4F4C40
6727	7	65	847	7562	52683	\N	56.349524000000002	Удмуртская Республика, Можгинский район, д.Ныша, Нышинский центральный сельский дом культуры, ул.Молодежная, 21		0101000020E610000038143E5B070B4A406495D233BD2C4C40
6726	7	65	847	7537	52814	\N	56.222344999999997	Удмуртская Республика, Можгинский район, с.Нынек, Нынекская школа, Центральная площадь, 6		0101000020E6100000AED4B32094F94940EDB60BCD751C4C40
6733	7	65	847	7822	52812	\N	56.421813	Адрес УИК и помещения для голосования: Удмуртская Республика, Можгинский район, д.Новый Русский Сюгаил, (МОУ Русско-Сюгаильская средняя школа,) ул.Ленина, 37		0101000020E6100000791F4773640F4A408A03E8F7FD354C40
6731	7	65	847	7822	52812	\N	56.421813	Удмуртская Республика, Можгинский район, д.Новый Русский Сюгаил, Русско-Сюгаильская средняя школа, ул.Ленина, 37		0101000020E6100000791F4773640F4A408A03E8F7FD354C40
6711	7	65	847	6812	53173	\N	56.500661000000001	"Удмуртская Республика, Можгинский район, д.Новая Бия, Административное здание ООО ""Новобиинское"", ул.Советская, 12"		0101000020E610000059350873BB3D4A40FBB0DEA815404C40
6720	7	65	847	7275	53142	\N	56.404105000000001	Удмуртская Республика, Можгинский район, д.Нижний Вишур, Вишурская школа, ул.Школьная, 4		0101000020E61000009CA73AE466264A4036936FB6B9334C40
6721	7	65	847	7282	52682	\N	56.375298999999998	Удмуртская Республика, Можгинский район, с.Можга, Можгинская средняя школа, Микрорайон, 7		0101000020E610000065DEAAEB50214A405A9C31CC09304C40
6707	7	65	847	6616	53225	\N	56.584381999999998	Удмуртская Республика, Можгинский район, д.Мельниково, Мельниковский сельский дом культуры, ул.Нагорная, 10		0101000020E61000007AE1CE8591424A407F2F8507CD4A4C40
6737	7	65	847	8023	52684	\N	56.508758999999998	Удмуртская Республика, Можгинский район, д.Малая Сюга, М-Сюгинский центральный сельский дом культуры, ул.Дубовская, 4		0101000020E6100000228C9FC6BD174A40D845D1031F414C40
6738	7	65	847	8103	52813	\N	56.620007999999999	Удмуртская Республика, Можгинский район, с.Малая Воложикья, М-Воложикьинский сельский дом культуры, Центральная площадь, 5		0101000020E61000001FDAC70A7E254A4012A1116C5C4F4C40
6730	7	65	847	56381	52816	\N	56.4322640992362	Удмуртская Республика, Можгинский район, ст.Люга, Люгинский сельский дом культуры, ул.Заводская, 22	Россия, республика Удмуртская, Можгинский район, поселок Люга	0101000020E61000007EA99F3715F949407C9E3F6D54374C40
6741	7	65	847	8220	53144	\N	56.679766999999998	Удмуртская Республика, Можгинский район, д.Ломеслуд, Ломеслудский сельский дом культуры, ул.Клубная, 1		0101000020E61000004E8061F9F3114A4034F3E49A02574C40
6729	7	65	847	7653	52913	\N	56.325069999999997	Удмуртская Республика, Можгинский район, д.Комяк, Комякский клуб, ул.Советская, 64а		0101000020E6100000950B957F2DFD49409274CDE49B294C40
6715	7	65	847	56415	53250	\N	56.463859523165297	Удмуртская Республика, Можгинский район, ст.Керамик, Здание детского сада, ул.Кирпичная, 18	Россия, республика Удмуртская, Можгинский район, село Керамик	0101000020E6100000992B836A83274A4016F6B4C35F3B4C40
6718	7	65	847	7150	52680	\N	56.399751000000002	Удмуртская Республика, Можгинский район, д.Кватчи, Кватчинский центральный дом культуры, Центральная площадь, 2		0101000020E6100000C37DE4D6A4314A408BC56F0A2B334C40
6701	7	65	847	6294	52846	\N	56.451563	Удмуртская Республика, Можгинский район, с.Горняк, Горнякский сельский дом культуры, ул.Коммунальная, 7		0101000020E6100000C0B0FCF9B6364A40B58AFED0CC394C40
6717	7	65	847	7113	52797	\N	56.428030999999997	Удмуртская Республика, Можгинский район, д.Верхние Юри, В-Юринский центральный сельский дом культуры, ул.Юбилейная, 11		0101000020E6100000AF230ED940484A404B5645B8C9364C40
6724	7	65	847	7460	52850	\N	56.333914	Удмуртская Республика, Можгинский район, д.Большие Сибы, Б-Сибинский центральный дом культуры, ул.Центральная, 3		0101000020E6100000CAE2FE23D31F4A4099D6A6B1BD2A4C40
6740	7	65	847	8195	52400	\N	56.609220000000001	Удмуртская Республика, Можгинский район, с.Большая Уча, Б-Учинский центральный сельский дом культуры, ул.Садовая, 22		0101000020E610000050E27327D8094A40D908C4EBFA4D4C40
6735	7	65	847	7930	52954	\N	56.487349000000002	Удмуртская Республика, Можгинский район, с.Большая Пудга, Б-Пудгинский сельский дом культуры, ул.Центральная, 50		0101000020E61000005260014C190E4A40815EB873613E4C40
6716	7	65	847	7073	52433	\N	56.36992	Удмуртская Республика, Можгинский район, с.Большая Кибья, Б-Кибьинский центральный сельский дом культуры, ул.Советская, 52		0101000020E6100000C4D0EAE40C4D4A407311DF89592F4C40
6713	7	65	847	6899	52943	\N	56.497462317297099	Удмуртская Республика, Можгинский район, д.Бальзяшур, Здание ФАП, ул.Труда, 21	Россия, республика Удмуртская, Можгинский район, село Бальзяшур	0101000020E6100000FBE59315C3494A405A80B6D5AC3F4C40
6680	7	65	634	5212	52422	\N	56.583033999999998	Удмуртская Республика, Малопургинский район, с. Яган-Докья, здание Яган-Докьинской средней школы, Садовая, 1		0101000020E61000001A16A3AEB59D4A40603AADDBA04A4C40
6672	7	65	634	4794	52526	\N	56.560232999999997	Удмуртская Республика, Малопургинский район, с. Яган, здание центрального сельского Дома культуры, Первомайская, 4		0101000020E6100000C66D3480B78E4A40EA9106B7B5474C40
6687	7	65	634	5552	52852	\N	56.565223000000003	Удмуртская Республика, Малопургинский район, с. Уром, здание Уромской средней школы, Молодежная, 1а		0101000020E610000014B18861875D4A4038F92D3A59484C40
6700	7	65	634	6260	52918	\N	56.487861000000002	Удмуртская Республика, Малопургинский район, д. Сырьезшур, здание Сырьезшурской начальной школы-детского сада, Школьная, 10		0101000020E6100000D767CEFA94514A4037FFAF3A723E4C40
6677	7	65	634	5061	53008	\N	56.522351	Удмуртская Республика, Малопургинский район, д. Сундуково, здание Сундуковской начальной школы, Колхозная, 6		0101000020E6100000842D76FBACA84A403604C765DC424C40
6705	7	65	634	6517	52507	\N	56.440075	427827, Удмуртская Республика, Малопургинский район, д. Старая Монья, ул. Октябрьская (здание Старомоньинской сельской библиотеки), д. 21а, адрес УИК: ул. Октябрьская (зубной кабинет), д. 21б-2		0101000020E610000007431D56B8714A40C364AA6054384C40
6673	7	65	634	4857	52760	\N	56.528055999999999	Удмуртская Республика, Малопургинский район, д. Среднее Кечево, здание Среднекечевской средней школы, Советская, 55		0101000020E6100000EA42ACFE089B4A40713AC95697434C40
6693	7	65	634	5871	53122	\N	56.641252999999999	Удмуртская Республика, Малопургинский район, д. Сизяшур, здание Сизяшурской начальной школы - детского сад, Трактовая, 7		0101000020E6100000BC3C9D2B4A574A401FBB0B9414524C40
6682	7	65	634	5318	52908	\N	56.551631	Удмуртская Республика, Малопургинский район, д. Пуро-Можга, здание Пуро-Можгинской начальной школы, Мельничная, 30		0101000020E6100000D253E41071B34A40DA3A38D89B464C40
95069	7	65	634	4695	52505	\N	56.607401000000003	427801 Малопургинский район, с. Пугачево, ул. Ленина (здание Пугачевской средней школы), д. 50		0101000020E6100000874D64E602894A406347E350BF4D4C40
6694	7	65	634	5957	52679	\N	56.670504000000001	Удмуртская Республика, Малопургинский район, с. Норья, здание Норьинской средней школы, Школьная, 1		0101000020E610000006F7031E185A4A4029EB3713D3554C40
6704	7	65	634	6488	53010	\N	56.423918999999998	Удмуртская Республика, Малопургинский район, д. Новая Монья, здание Новомоньинской основной школы, Школьная, 1		0101000020E6100000A5BDC11726654A40969350FA42364C40
6702	7	65	634	6411	\N	\N	56.404745759144902	427826, Адрес УИК и помещения для голосования: Удмуртская Республика, Малопургинский район, д. Средние Юри, ул. Центральная (здание Среднеюринской начальной школы), д. 43	Россия, республика Удмуртская, Малопургинский район, село Нижние Юри	0101000020E61000002BDEC83CF25B4A40EA9788B7CE334C40
6703	7	65	634	6411	52762	\N	56.409438999999999	427826, Удмуртская Республика, Малопургинский район, д. Нижние Юри, ул. Кировская (здание Нижнеюринской средней школы), д. 15, адрес УИК: ул. Кировская (здание администрации), д. 13		0101000020E61000002C29779FE35B4A407D5A457F68344C40
95068	7	65	634	4581	52676	\N	56.574956999999998	427801 Малопургинский район, д. Миндерево, ул. Полевая (здание Миндеревской начальной школы), д.  2		0101000020E6100000C93CF20703814A409ACDE33098494C40
95067	7	65	634	4581	52676	\N	56.574956999999998	427801Малопургинский район, д. Миндерево, ул. Полевая (здание Миндеревской начальной школы), д. 2		0101000020E6100000C93CF20703814A409ACDE33098494C40
6662	7	65	634	4188	\N	\N	56.557107424838101	427820, Адрес УИК и помещения для голосования: Удмуртская Республика, Малопургинский район, с. Малая Пурга, пл. Победы (здание районного Дома культуры), д. 3	Россия, республика Удмуртская, Малопургинский район, село Малая Пурга	0101000020E610000088484DBB98804A40B4AF3C484F474C40
6661	7	65	634	4188	\N	\N	56.556349039730598	427820, Адрес УИК и помещения для голосования: Удмуртская Республика, Малопургинский район, с. Малая Пурга, пл. Победы (здание Центральной районной библиотеки), д. 4		0101000020E6100000A8C30AB77C7E4A40C614AC7136474C40
6663	7	65	634	4188	52421	\N	56.553669999999997	Удмуртская Республика, Малопургинский район, с. Малая Пурга, здание Малопургинской гимназии, Школьная, 1		0101000020E6100000655419C6DD7E4A405E6397A8DE464C40
6664	7	65	634	4188	52636	\N	56.553669999999997	Удмуртская Республика, Малопургинский район, с. Малая Пурга, здание Малопургинской средней школы №1, Советская, 62		0101000020E6100000655419C6DD7E4A405E6397A8DE464C40
6666	7	65	634	4457	53116	\N	56.565649000000001	Удмуртская Республика, Малопургинский район, д. Малая Бодья, здание Малободьинской начальной школы, Школьная, 8		0101000020E61000004089CF9D60874A40EF01BA2F67484C40
6660	7	65	634	4142	53221	\N	56.603012	Удмуртская Республика, Малопургинский район, д. Курчум-Норья, здание Курчум-Норьинской основной школы, Нарядная, 19		0101000020E6100000111E6D1CB17C4A403B8C497F2F4D4C40
6684	7	65	634	5397	53009	\N	56.538277000000001	Удмуртская Республика, Малопургинский район, д. Курегово, здание Куреговской начальной школы, Школьная, 5		0101000020E6100000EA060ABC93734A403198BF42E6444C40
6695	7	65	634	5989	53041	\N	56.650854000000002	Удмуртская Республика, Малопургинский район, д. Кулаево, здание Кулаевской начальной школы, Школьная, 8		0101000020E61000003B8F8AFF3B604A40433C122F4F534C40
6665	7	65	634	4409	53117	\N	56.608268000000002	Удмуртская Республика, Малопургинский район, д. Кечур, здание Кечурской начальной школы, Школьная, 9		0101000020E61000004260E5D022714A40079ACFB9DB4D4C40
6675	7	65	634	4950	53115	\N	56.510517	Удмуртская Республика, Малопургинский район, с. Кечево, здание Дома культуры, Клубная, 3		0101000020E610000069AD68739C9B4A40A986FD9E58414C40
6688	7	65	634	5629	52909	\N	56.511941999999998	Удмуртская Республика, Малопургинский район, д. Карашур, здание Карашурской начальной школы, Центральная, 31		0101000020E6100000E23C9CC0745C4A4073B9C15087414C40
6696	7	65	634	6073	53123	\N	56.702672999999997	Удмуртская Республика, Малопургинский район, д. Капустино, здание Капустинской начальной школы, Садовая, 11		0101000020E61000002A70B20DDC5F4A401F645930F1594C40
6706	7	65	634	6607	53120	\N	56.420766999999998	Удмуртская Республика, Малопургинский район, д. Итешево, здание Итешевской начальной школы, Центральная, 9а		0101000020E6100000D0251C7A8B734A40361E6CB1DB354C40
6691	7	65	634	5799	52424	\N	56.483665999999999	Удмуртская Республика, Малопургинский район, с. Ильинское, здание центрального сельского Дома культуры, Советская, 33		0101000020E61000000E2C47C840644A40F4177AC4E83D4C40
6697	7	65	634	6104	53127	\N	56.696638999999998	Удмуртская Республика, Малопургинский район, д. Иваново-Самарское, здание Иваново-Самарской основной школы, Центральная, 7		0101000020E6100000AA9ECC3FFA644A401F0F7D772B594C40
22770	7	61	317	18458	64665	\N	54.950071000000001	село Караталово, Родниковая, 2		0101000020E61000003D9AEAC9FC2D4B4063F030ED9B794B40
6698	7	65	634	6175	52956	\N	56.469771000000001	427825, Удмуртская Республика, Малопургинский район, д. Гужношур, ул. Центральная (здание Гужношурской начальной школы), д. 21, адрес УИК: ул. Центральная (здание магазина), д. 23		0101000020E6100000F9F6AE415F5C4A40FBCDC474213C4C40
6685	7	65	634	5475	52811	\N	56.541662000000002	Удмуртская Республика, Малопургинский район, д. Гожня, здание Гожнинской средней школы, Молодежная, 1а		0101000020E610000046239F573C6D4A4034BE2F2E55454C40
6676	7	65	634	4966	53118	\N	56.496566999999999	Удмуртская Республика, Малопургинский район, д. Верхнее Кечево, здание Верхнекечевской начальной школы, Пионерская, 40		0101000020E610000021CB82893F9C4A40ECA2E8818F3F4C40
6674	7	65	634	4882	53114	\N	56.509335	Удмуртская Республика, Малопургинский район, д. Валион, здание Валионской начальной школы, Школьная, 11		0101000020E610000004CAA65CE1954A40A5DAA7E331414C40
6681	7	65	634	5235	52678	\N	56.588312999999999	Удмуртская Республика, Малопургинский район, с. Бураново, здание Бурановской средней школы, Школьная, 3а		0101000020E6100000292499D53BAA4A40E46723D74D4B4C40
6699	7	65	634	6191	52799	\N	56.486165999999997	Удмуртская Республика, Малопургинский район, д. Бобья-Уча, здание Бобья-Учинской средней школы, Азина, 27		0101000020E610000090A1630795584A40AC36FFAF3A3E4C40
6679	7	65	634	5141	53119	\N	56.468021	Удмуртская Республика, Малопургинский район, д. Байситово, здание сельского Дома культуры, Советская, 9		0101000020E61000002DEC6987BFA84A40AD6BB41CE83B4C40
6689	7	65	634	5720	53121	\N	56.522599999999997	Удмуртская Республика, Малопургинский район, д. Бажаново, здание Бажановской начальной школы, Школьная, 8		0101000020E6100000764F1E166A654A40DE718A8EE4424C40
6686	7	65	634	5518	53219	\N	56.568382	Удмуртская Республика, Малопургинский район, д. Алганча-Игра, здание сельского клуба, Заречная, 27а		0101000020E61000000F46EC1340694A404AD1CABDC0484C40
6678	7	65	634	5106	52761	\N	56.442672000000002	Удмуртская Республика, Малопургинский район, д. Аксакшур, здание центрального сельского Дома культуры, Колхозная, 20		0101000020E61000000038F6ECB9984A406E6DE179A9384C40
6683	7	65	634	56373	52689	\N	56.513720445432298	Удмуртская Республика, Малопургинский район, д. Баграш-Бигра, здание Баграш-Бигринской средней школы, Трактовая, 23	Россия, республика Удмуртская, Малопургинский район, село Агрыз-Бигра	0101000020E6100000774A07EBFF784A408BA6B393C1414C40
95070	7	65	634	5869	53012	\N	56.490614000000001	427824 Малопургинский район, д. Абдэс-Урдэс ул. Октябрьская (здание сельского клуба) д. 8		0101000020E61000009581035ABA6A4A40D97A8670CC3E4C40
5965	7	65	6899	40326	52607	\N	56.833948999999997	Удмуртская Республика, город Ижевск, Ленинский район, Городок Машиностроителей, 109		0101000020E6100000E94999D4D08E4A4015C440D7BE6A4C40
5972	7	65	6899	40326	9826	\N	56.851642430207697	Удмуртская Республика, город Ижевск, Ленинский район, Баранова, 76		0101000020E61000000821205F429D4A4034F3E49A026D4C40
6655	7	65	510	3861	53216	\N	57.737062999999999	Удмуртская Республика, Красногорский район, деревня Мухино, улица Черниговская, дом 7		0101000020E61000009FE6E445261E4A40BB0B941458DE4C40
6654	7	65	510	3812	53113	\N	57.657865000000001	Удмуртская Республика, Красногорский район, деревня Малягурт, улица Центральная, дом 2		0101000020E6100000AD1402B9C4454A406E179AEB34D44C40
6653	7	65	510	3761	52758	\N	57.711714999999998	Удмуртская Республика, Красногорский район, село Курья, улица Советская, дом 54		0101000020E61000006A50340F60094A404C89247A19DB4C40
6652	7	65	510	3123	52504	\N	57.706060000000001	Удмуртская Республика, Красногорский район, село Красногорское, улица Ленина, дом 68		0101000020E6100000C79FA86C583F4A40C381902C60DA4C40
6650	7	65	510	3123	52504	\N	57.706060000000001	Удмуртская Республика, Красногорский район, село Красногорское, улица Ленина, дом 50		0101000020E6100000C79FA86C583F4A40C381902C60DA4C40
6641	7	65	510	3123	52504	\N	57.706060000000001	Удмуртская Республика, Красногорский район, село Красногорское, улица Ленина, дом 57		0101000020E6100000C79FA86C583F4A40C381902C60DA4C40
6659	7	65	510	3123	52637	\N	57.706060000000001	427650, Удмуртская Республика, Красногорский район, село Красногорское, ул. Глазовская, дом 1а, адрес УИК: ул. Первомайская,, дом 1 ()		0101000020E6100000C79FA86C583F4A40C381902C60DA4C40
6658	7	65	510	3123	52637	\N	57.706060000000001	Удмуртская Республика, Красногорский район, село Красногорское, улица Глазовская, дом 1а		0101000020E6100000C79FA86C583F4A40C381902C60DA4C40
95066	7	65	510	3667	53226	\N	57.574165000000001	427654 Красногорский район, с. Кокман, ул. Центральная, дом 2		0101000020E6100000DB4FC6F8302F4A4001C11C3D7EC94C40
6649	7	65	510	3575	52686	\N	57.828141000000002	Удмуртская Республика, Красногорский район, село Дёбы, улица Школьная, дом 30		0101000020E6100000323B8BDEA93E4A4006BD378600EA4C40
6648	7	65	510	3509	52914	\N	57.722228000000001	Удмуртская Республика, Красногорский район, село Васильевское, улица Школьная, дом 3		0101000020E6100000ABED26F8A6254A40B42094F771DC4C40
6647	7	65	510	3458	52756	\N	57.543038000000003	Удмуртская Республика, Красногорский район, село Валамаз, улица Карла Маркса, дом 8		0101000020E61000004BB0389CF90B4A401D3EE94482C54C40
6657	7	65	510	3970	53053	\N	57.660007999999998	Удмуртская Республика, Красногорский район, село Большой Селег, улица Советская, дом 6		0101000020E6100000AC3C81B053F64940978C63247BD44C40
6646	7	65	510	3406	53111	\N	57.786265	Удмуртская Республика, Красногорский район, деревня Бараны, улица Советская, дом 6а		0101000020E610000063997E89785F4A40A67EDE54A4E44C40
95065	7	65	510	3339	52866	\N	57.766579	427650 Красногорский район, д. Багыр,  ул. Мира, д. 1		0101000020E6100000A35BAFE941474A407366BB421FE24C40
6644	7	65	510	3281	53112	\N	57.787219999999998	Удмуртская Республика, Красногорский район, село Архангельское, улица Новая, дом 4		0101000020E61000008F554ACFF4564A40E960FD9FC3E44C40
6643	7	65	510	3233	52910	\N	57.729571999999997	Удмуртская Республика, Красногорский район, деревня Артык, улица Ключевая, дом 34		0101000020E61000001096B1A19B2D4A40E509849D62DD4C40
6626	7	65	369	2248	52955	\N	56.393484000000001	Удмуртская Республика, Киясовский район, с.Яжбахтино, Яжбахтинский сельский Дом культуры, ул.Клубная, д.1а		0101000020E610000029AF95D05DA24A40E8BF07AF5D324C40
6631	7	65	369	2552	53222	\N	56.242324000000004	Удмуртская Республика, Киясовский район, д. Чувашайка, Чувашаевский сельский Дом культуры, ул.Советская, д.35		0101000020E6100000321F10E84C9A4A4099840B79041F4C40
6635	7	65	369	2750	53105	\N	56.215282999999999	Удмуртская Республика, Киясовский район, д.Тавзямал, ул.Нагорная, д.32а		0101000020E6100000508E0244C1884A404031B2648E1B4C40
6637	7	65	369	2887	52765	\N	56.175832	Удмуртская Республика, Киясовский район, д.Старая Салья, Старосальинская средняя школа, ул.Чистопольская, д.45		0101000020E6100000DE3CD52137974A408ECBB8A981164C40
6622	7	65	369	1893	52755	\N	56.384141	Удмуртская Республика, Киясовский район, с. Подгорное, Подгорновская средняя общеобразовательная школа, ул.Школьная, д.6в		0101000020E6100000556B6116DA834A40C00644882B314C40
6624	7	65	369	2140	52824	\N	56.374327000000001	Удмуртская Республика, Киясовский район, с.Первомайский, Первомайская средняя школа, ул.Октябрьская, д.5		0101000020E610000021904B1C799E4A40418177F2E92F4C40
6639	7	65	369	3001	53055	\N	56.181469	Удмуртская Республика, Киясовский район, д.Нижняя Малая Салья, Нижнемалосальинский сельский Дом культуры, ул.Советская, д.13		0101000020E61000005303CDE7DCA14A40711E4E603A174C40
6634	7	65	369	2706	53220	\N	56.237347	Удмуртская Республика, Киясовский район, с. Мушак, Мушаковская средняя общеобразовательная школа, ул.Школьная, д.9		0101000020E6100000B6A2CD716E874A40E066F162611E4C40
6627	7	65	369	2318	53004	\N	56.302208	Удмуртская Республика, Киясовский район, д. Лутоха, Лутохинский центральный сельский Дом культуры, ул.Советская, д.28		0101000020E610000071AFCC5B75A54A40774B72C0AE264C40
95064	7	65	369	1949	52420	\N	56.344366000000001	427840 Киясовский район, c. Киясово, ул. Советская (здание школы), д.3		0101000020E6100000DA53724EEC8F4A405BED612F142C4C40
6621	7	65	369	1949	52420	\N	56.344366000000001	Удмуртская Республика, Киясовский район, c.Киясово, Межпоселенческий дом культуры, ул.Советская, д.1		0101000020E6100000DA53724EEC8F4A405BED612F142C4C40
6632	7	65	369	2604	52794	\N	56.305973000000002	Удмуртская Республика, Киясовский район, д. Карамас-Пельга, Карамас-Пельгинская средняя школа, ул.Гагарина, д.17а		0101000020E610000034F3E49A02894A40C13A8E1F2A274C40
6628	7	65	369	2367	53007	\N	56.296748999999998	Удмуртская Республика, Киясовский район, д.Калашур, Лутохинская средняя общеобразовательная школа, ул.Советская, д.1		0101000020E6100000E814E46723AD4A40730F09DFFB254C40
6640	7	65	369	3068	52907	\N	56.118319999999997	Удмуртская Республика, Киясовский район, д.Кады Салья, Кады-Сальинский сельский Дом культуры, ул.Восточная, д.35		0101000020E6100000A7E67283A1A84A403A3B191C250F4C40
6630	7	65	369	2472	52972	\N	56.264422000000003	Удмуртская Республика, Киясовский район, с. Ильдибаево, Ильдибаевская средняя общеобразовательная школа, ул.Суворова, д.28		0101000020E6100000790778D2C29F4A40E52B8194D8214C40
6636	7	65	369	2808	52906	\N	56.141722999999999	Удмуртская Республика, Киясовский район, с.Ермолаево, Ермолаевская средняя общеобразовательная школа, ул.Школьная, д.6		0101000020E610000096218E7571A14A40A60BB1FA23124C40
6629	7	65	369	2429	53006	\N	56.267037000000002	Удмуртская Республика, Киясовский район, д. Дубровский, Дубровский сельский Дом культуры, ул.Центральная, д.12		0101000020E61000002639605793AB4A4036E9B6442E224C40
6638	7	65	369	2950	53109	\N	56.163960000000003	Удмуртская Республика, Киясовский район, д. Верхняя Малая Салья, Верхнемалосальинский сельский Дом культуры, ул.Новая, д.1		0101000020E61000002FA4C34318A14A4014ED2AA4FC144C40
6633	7	65	369	2664	53110	\N	56.281536000000003	Удмуртская Республика, Киясовский район, д. Байсары, Байсарский сельский Дом культуры, ул.Советская, д.24а		0101000020E6100000D34D621058874A40C652245F09244C40
6623	7	65	369	2079	53003	\N	56.435217999999999	Удмуртская Республика, Киясовский район, д. Атабаево, Атабаевская средняя общеобразовательная школа, ул.Советская, д.51		0101000020E6100000C5538F34B88F4A40B5503239B5374C40
6625	7	65	369	2207	53011	\N	56.395552000000002	Удмуртская Республика, Киясовский район, д.Аксарино, Аксаринский сельский Дом культуры, ул.Юбилейная, д.32		0101000020E61000005F42058717964A4007EFAB72A1324C40
95062	7	65	61	1232	52677	\N	56.347534000000003	427709 Кизнерский район, д. Ягул ул. Центральная (Здание школы) д.11		0101000020E6100000F1D7648D7ACA4940C11F7EFE7B2C4C40
6592	7	65	61	233	52952	\N	56.029718000000003	Удмуртская Республика, Кизнерский район, д. Удмуртский Сарамак, Здание детского сада, ул. Нагорная, 3		0101000020E6100000290989B48DC74940200DA7CCCD034C40
6587	7	65	61	32398	52848	\N	56.179124999999999	Удмуртская Республика, Кизнерский район, д. Старый Кармыж, Здание школы, ул. Школьная, 8		0101000020E6100000EB1A2D077AEA4940B0726891ED164C40
6596	7	65	61	497	53042	\N	56.168812000000003	Удмуртская Республика, Кизнерский район, д.Старый Аргабаш, Здание ФАП, ул. Центральная, 12		0101000020E6100000CB10C7BAB8D149401096B1A19B154C40
6603	7	65	61	910	52754	\N	56.357973000000001	Удмуртская Республика, Кизнерский район, д. Старая Бодья, Здание школы, ул. Аллейная, 9		0101000020E6100000221B48179BAC4940EEEC2B0FD22D4C40
6611	7	65	61	1363	53107	\N	56.333829000000001	Удмуртская Республика, Кизнерский район, д. Синяр Бодья, Здание СДК, ул. Нижняя, 32		0101000020E610000075AE282504B349406BBA9EE8BA2A4C40
21018	7	61	317	47158	65699	\N	55.127147000000001	с. Каран микрорайон ПУ-94, Новая, 7		0101000020E61000002F87DD770C2F4B406B64575A46904B40
6599	7	65	61	672	52996	\N	56.551025000000003	Удмуртская Республика, Кизнерский район, д. Русская Коса, Здание школы, ул.Школьная, 1		0101000020E610000046425BCEA5C04940A323B9FC87464C40
6600	7	65	61	719	52997	\N	56.590083	Удмуртская Республика, Кизнерский район, д. Муркозь Омга, Здание школы, ул. Верхняя, 30		0101000020E61000003C6A4C88B9AA49407976F9D6874B4C40
95059	7	65	61	353	53102	\N	55.998443000000002	427707 Кизнерский район, д. Крымская Слудка ул. Школьная (Здание школы) д.1		0101000020E610000003CDE7DCEDB64940C7F5EFFACCFF4B40
95061	7	65	61	852	52904	\N	56.421405	427722 Кизнерский район, с. Короленко ул. Им. Короленко (Здание Администрации) д.3		0101000020E6100000EF8CB62A89E2494079AF5A99F0354C40
6610	7	65	61	1252	53138	\N	56.314141999999997	Удмуртская Республика, Кизнерский район, с. Кизнер, Здание СДК, ул. Шумиловка, 1б		0101000020E61000003E76172829C24940672618CE35284C40
6609	7	65	61	1252	52501	\N	56.314141999999997	Удмуртская Республика, Кизнерский район, с. Кизнер, Здание детского сада №7, ул. Механизаторов, 6		0101000020E61000003E76172829C24940672618CE35284C40
6616	7	65	61	1448	52417	\N	56.284044000000002	Удмуртская Республика, Кизнерский район, п. Кизнер, Здание школы №1, ул. Школьная, 1		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
6613	7	65	61	1448	52417	\N	56.284044000000002	Удмуртская Республика, Кизнерский район, п. Кизнер, Здание школы, ул. Школьная, 1		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
6618	7	65	61	1448	52502	\N	56.284044000000002	Удмуртская Республика, Кизнерский район, п. Кизнер, Здание школы №2, ул. Савина, 3		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
6619	7	65	61	1448	52521	\N	56.284044000000002	"Удмуртская Республика, Кизнерский район, п. Кизнер, Здание МУСО ""КЦСОН"", ул. Первомайская, 117"		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
6615	7	65	61	1448	52563	\N	56.284044000000002	427710, Удмуртская Республика, Кизнерский район, п. Кизнер, ул. Карла маркса, 25 ()		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
6612	7	65	61	1448	52563	\N	56.284044000000002	Удмуртская Республика, Кизнерский район, п. Кизнер, Здание РДК, ул. Карла Маркса, 22а		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
6614	7	65	61	1448	52757	\N	56.284044000000002	"Удмуртская Республика, Кизнерский район, п. Кизнер, Здание МУП ""Коммунальный комплекс"", ул. Гоголя, 4"		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
95063	7	65	61	1448	52726	\N	56.284044000000002	427710 Кизнерский район, п. Кизнер ул. Вокзальная (Здание семенной инспекции) д. 4		0101000020E6100000EF6FD05E7DC249400150C58D5B244C40
6605	7	65	61	990	53002	\N	56.414682999999997	Удмуртская Республика, Кизнерский район, с. Кибья, Здание школы, ул. Школьная, 9		0101000020E610000009A9DBD957B44940849A215514354C40
6598	7	65	61	597	52905	\N	56.559662000000003	Удмуртская Республика, Кизнерский район, д. Гыбдан, Здание школы, ул.Центральная, 33		0101000020E61000007156444DF4CF494030682101A3474C40
6604	7	65	61	983	52903	\N	56.388387000000002	Удмуртская Республика, Кизнерский район, д. Вичурка, Здание школы, ул. Школьная, 1		0101000020E6100000ECA17DACE0A7494085984BAAB6314C40
6589	7	65	61	32493	53104	\N	56.302528000000002	Удмуртская Республика, Кизнерский район, д. Верхняя Тыжма, Здание школы, ул. Шанхайская, 14		0101000020E6100000F9872D3D9AE24940E90FCD3CB9264C40
6588	7	65	61	32424	53217	\N	56.227870000000003	Удмуртская Республика, Кизнерский район, д. Верхний Бемыж, Здание школы, ул. Молодежная, 3		0101000020E6100000274A42226DDB4940A9DE1AD82A1D4C40
6591	7	65	61	160	52792	\N	56.147585999999997	Удмуртская Республика, Кизнерский район, с. Бемыж, Здание школы, ул. Коммунальная, 4		0101000020E6100000AA2B9FE579DC494079AC1919E4124C40
6606	7	65	61	1103	53101	\N	56.459784999999997	Удмуртская Республика, Кизнерский район, д. Безменшур, Здание школы, ул.Полевая, 5		0101000020E61000004546072461A349407E18213CDA3A4C40
6595	7	65	61	433	53214	\N	56.204823372481201	Удмуртская Республика, Кизнерский район, с. Балдейка, Здание школы, ул. Центральная, 23	Россия, республика Удмуртская, Кизнерский район, село Балдейка	0101000020E61000007138F3AB39C44940FB3BDBA3371A4C40
6590	7	65	61	74	53040	\N	56.206941999999998	Удмуртская Республика, Кизнерский район, д. Айдуан Чабья, Здание школы, ул. Молодежная, 9		0101000020E61000005985CD0017D649409C1551137D1A4C40
6557	7	65	1658	31005	52987	\N	57.932366000000002	"Удмуртская Республика, Кезский район, муниципальное образование ""Юскинское"", с.Юски, ул.Школьная, д.20"		0101000020E6100000E527D53E1DE34A4080F3E2C457F74C40
6574	7	65	1658	31829	\N	\N	57.809153000000002	"Удмуртская Республика, Кезский район, муниципальное образование ""Чепецкое"", д.Юрук, сельский клуб"		0101000020E6100000CC9A58E02BB64A40EB3A545392E74C40
6555	7	65	1658	30919	52999	\N	57.982250999999998	"Удмуртская Республика, Кезский район, муниципальное образование ""Юскинское"", д.Ю-Чабья, ул.Ю-Чабьинская, д.26"		0101000020E6100000B0FF3A376DE24A404DBB9866BAFD4C40
6554	7	65	1658	30852	52898	\N	58.031770999999999	"Удмуртская Республика, Кезский район, муниципальное образование ""Новоунтемское"", д.Ю-Тольен, ул.Центральная, д.2"		0101000020E610000034F6251B0FE64A4009FB761211044D40
6346	7	65	1658	31722	\N	\N	57.8880939764122	"Удмуртская Республика, Глазовский район, п. Дом отдыха Чепца, ООО ""Санаторий-профилакторий ""Чепца"""	Россия, республика Удмуртская, Кезский район, село Чепца	0101000020E6100000664CC11A67B34A400DE36E10ADF14C40
6572	7	65	1658	31722	52753	\N	57.887866000000002	"Удмуртская Республика, Кезский район, муниципальное образование ""Чепецкое"", с.Чепца, ул.Школьная, д.6а"		0101000020E6100000D734EF3845B34A407C9DD497A5F14C40
6573	7	65	1658	31722	52675	\N	57.887866000000002	"Удмуртская Республика, Кезский район, муниципальное образование ""Чепецкое"", с.Чепца, ул.Пионерская, д.35"		0101000020E6100000D734EF3845B34A407C9DD497A5F14C40
6556	7	65	1658	30963	53108	\N	57.978637999999997	"Удмуртская Республика, Кезский район, муниципальное образование ""Юскинское"", д.Филинцы, ул.Рабочая, д.18, кв.1"		0101000020E610000090D78349F1F74A40B94F8E0244FD4C40
6563	7	65	1658	31276	52992	\N	57.862112000000003	"Удмуртская Республика, Кезский район, муниципальное образование ""Сюрзинское"", д.Удмурт-Зязьгор, ул.Школьная, д.25"		0101000020E610000061DF4E22C2ED4A409DBE9EAF59EE4C40
6562	7	65	1658	31239	52912	\N	57.813488	"Удмуртская Республика, Кезский район, муниципальное образование ""Сюрзинское"", д.Тортым, пер.Церковный, д.1, кв.3"		0101000020E610000064963D096CF84A401FD8F15F20E84C40
6550	7	65	1658	30665	52933	\N	58.254398000000002	"Удмуртская Республика, Кезский район, муниципальное образование ""Степаненское"", д.Тимены, ул.Советская, д.2а"		0101000020E61000000EF3E505D8BF4A407B15191D90204D40
95056	7	65	1658	31519	52901	\N	57.86992	Кезский район,  д.Сыга - 2, ул.Новая (здание сельского клуба), д.1		0101000020E61000009F8F32E202C84A407311DF8959EF4C40
6549	7	65	1658	30603	52860	\N	58.219192	"Удмуртская Республика, Кезский район, муниципальное образование ""Степаненское"", д.Степаненки, ул.Советская, д.17"		0101000020E6100000226DE34F54E04A40BDC5C37B0E1C4D40
6566	7	65	1658	31461	53098	\N	57.845709999999997	"Удмуртская Республика, Кезский район, муниципальное образование ""Сосновоборское"", д.Стеньгурт, ул.Садовая, д.1"		0101000020E610000086376BF0BECE4A4038F3AB3940EC4C40
95057	7	65	1658	31555	53103	\N	58.123413999999997	"Кезский район, д.Старая Гыя, ул.Центральная (здание МКОУ ""Гыинская СОШ""), д.37"		0101000020E6100000A5F8F884ECC44A402CEFAA07CC0F4D40
6579	7	65	1658	32064	52995	\N	57.924954	"Удмуртская Республика, Кезский район, муниципальное образование ""Ключевское"", д.Пужмезь, ул.Комсомольская, д.1а"		0101000020E610000069A8514832C54A40F62686E464F64C40
6577	7	65	1658	31970	52899	\N	57.773102000000002	"Удмуртская Республика, Кезский район, муниципальное образование ""Поломское"", с.Поломское, ул.Школьная, д.19"		0101000020E610000055336B2920AD4A40713C9F01F5E24C40
6576	7	65	1658	31923	53213	\N	57.773443	"Удмуртская Республика, Кезский район, муниципальное образование ""Поломское"", с.Полом, ул.Центральная, д.57"		0101000020E6100000A391CF2B9EBA4A40FA28232E00E34C40
6578	7	65	1658	56397	53001	\N	57.981361915291799	"Удмуртская Республика, Кезский район, муниципальное образование ""Ключевское"", поч.Пажман, ул.Трактовая, д.8"	Россия, республика Удмуртская, Кезский район, село Пажман	0101000020E6100000CA51802898D14A40C1C41F459DFD4C40
6552	7	65	1658	30764	52990	\N	58.135793	"Удмуртская Республика, Кезский район, муниципальное образование ""Мысовское"", д.Мысы, ул.Центральная, д.20"		0101000020E6100000F6B704E09FEC4A404B033FAA61114D40
6564	7	65	1658	31346	53168	\N	57.798824000000003	"Удмуртская Республика, Кезский район, муниципальное образование ""Сосновоборское"", д.Липовка, ул.Центральная, д.25, кв.2"		0101000020E6100000508A56EE05DC4A4045A165DD3FE64C40
95054	7	65	1658	30689	52663	\N	58.184041999999998	Кезский район, с.Кулига, ул.Советская (здание сельского дома культуры), д.45		0101000020E6100000AD32535A7FE14A40938B31B08E174D40
95053	7	65	1658	30689	52663	\N	58.184041999999998	Кезский район,  с.Кулига, ул.Советская (здание сельского дома культуры), д.45		0101000020E6100000AD32535A7FE14A40938B31B08E174D40
6558	7	65	1658	31060	52789	\N	57.944629999999997	"Удмуртская Республика, Кезский район, муниципальное образование ""Кузьминское"", с.Кузьма, ул.Кооперативная, д.23"		0101000020E61000009B5434D6FE044B400569C6A2E9F84C40
6553	7	65	1658	30810	53209	\N	58.068477000000001	"Удмуртская Республика, Кезский район, муниципальное образование ""Новоунтемское"", с.Ключи, ул.Набережная, д.23а"		0101000020E61000006EDC627E6EE04A409CC3B5DAC3084D40
6583	7	65	1658	31399	52559	\N	57.897528999999999	"Удмуртская Республика, Кезский район, муниципальное образование ""Кезское"", п.Кез, ул.Тургенева, д.2а"		0101000020E6100000D576137CD3DA4A40151BF33AE2F24C40
6581	7	65	1658	31399	52561	\N	57.897574720874601	"Удмуртская Республика, Кезский район, муниципальное образование ""Кезское"", п.Кез, ул.Некрасова, д.12"	Россия, республика Удмуртская, Кезский район, поселок Кез	0101000020E61000002237C30DF8DA4A40865AD3BCE3F24C40
6586	7	65	1658	31399	52633	\N	57.897528999999999	"Удмуртская Республика, Кезский район, муниципальное образование ""Кезское"", п.Кез, ул.Мира, д.31"		0101000020E6100000D576137CD3DA4A40151BF33AE2F24C40
95058	7	65	1658	31399	52416	\N	57.897528999999999	"Кезский район,  п.Кез, ул.Малокезская (здание ПК ""Кезское МСО""), д.13"		0101000020E6100000D576137CD3DA4A40151BF33AE2F24C40
6580	7	65	1658	31399	52632	\N	57.897528999999999	"Удмуртская Республика, Кезский район, муниципальное образование ""Кезское"", п.Кез, ул.Ленина, д.44"		0101000020E6100000D576137CD3DA4A40151BF33AE2F24C40
6582	7	65	1658	31399	52503	\N	57.896980256262196	"Удмуртская Республика, Кезский район, муниципальное образование ""Кезское"", п.Кез, ул.Клубничная, д.2"	Россия, республика Удмуртская, Кезский район, поселок Кез	0101000020E6100000D07CCEDDAEDB4A4042959A3DD0F24C40
6565	7	65	1658	31399	53100	\N	57.897528999999999	"Удмуртская Республика, Кезский район, муниципальное образование ""Кезское"", п.Кез,, ул.Ангарская (здание учебного корпуса ПУ 50)"		0101000020E6100000D576137CD3DA4A40151BF33AE2F24C40
6584	7	65	1658	31399	52500	\N	57.897528999999999	"Удмуртская Республика, Кезский район, муниципальное образование ""Кезское"", п.Кез, ул.1-я Лесная, д.5"		0101000020E6100000D576137CD3DA4A40151BF33AE2F24C40
6561	7	65	1658	21224	53211	\N	57.923074999999997	"Удмуртская Республика, Кезский район, муниципальное образование ""Кабалудское"", с.Кабалуд, ул.Комсомольская (здание МОУ ""Кабалудской СОШ""), д.2,, адрес УИК: ул.Центральная (здание Админ. МО ""Кабалудское""),, д.4"		0101000020E610000022718FA50FEF4A40AA60545227F64C40
95055	7	65	1658	21194	53215	\N	57.963253999999999	"Кезский район, д.Желтопи, ул.Цветочная (здание МБОУ ""Кузьминская средняя общеобразовательная школа""), д.1"		0101000020E61000007D224F92AE054B40DFDE35E84BFB4C40
6570	7	65	1658	31618	53054	\N	58.053297999999998	"Удмуртская Республика, Кезский район, муниципальное образование ""Большеолыпское"", д.Дырпа, ул.Родниковая (здание почты), д.36,, адрес УИК: д.Большой Олып, пер.Клубный, (здание сельского клуба), д.2"		0101000020E61000007D21E4BCFFB54A409A780778D2064D40
6575	7	65	1658	31859	53016	\N	57.947138000000002	"Удмуртская Республика, Кезский район, муниципальное образование ""Чепецкое"", д.Вортча, ул.Новая, д.1"		0101000020E61000005D8C81751CBB4A40416667D13BF94C40
6569	7	65	1658	31612	52847	\N	58.049211999999997	"Удмуртская Республика, Кезский район, муниципальное образование ""Большеолыпское"", д.Большой Олып, пер.Клубный, д.2"		0101000020E6100000FE2AC0779BC34A400E492D944C064D40
6571	7	65	1658	31691	53218	\N	58.030970000000003	"Удмуртская Республика, Кезский район, муниципальное образование ""Большеолыпское"", с.Александрово, ул.Школьная, д.24"		0101000020E6100000253FE257ACC74A401D9430D3F6034D40
6545	7	65	1629	30393	52842	\N	55.954259	Удмуртская Республика, Каракулинский район, село Чеганда, улица Моргунова, 18		0101000020E610000065FCFB8C0BC34A40F374AE2825FA4B40
6544	7	65	1629	30346	52894	\N	56.075367999999997	Удмуртская Республика, Каракулинский район, деревня Усть-Сакла, улица В.Исенекова, 8		0101000020E61000005FB532E197BC4A401C959BA8A5094C40
6532	7	65	1629	29774	53203	\N	56.200198	Удмуртская Республика, Каракулинский район, деревня Пинязь, улица Центральная, 85		0101000020E610000072C0AE264FD54A40C05C8B16A0194C40
6548	7	65	1629	30553	52844	\N	55.903821999999998	Удмуртская Республика, Каракулинский район, деревня Ныргында, улица Князева, 1		0101000020E6100000143DF03158AB4A40E1B37570B0F34B40
6535	7	65	1629	56413	53247	\N	56.184638766135997	Удмуртская Республика, Каракулинский район, деревня М-Калмаши, улица Садовая, 10	Россия, республика Удмуртская, Каракулинский район, село Малые Калмаши	0101000020E61000004A60730E9EF34A4077483140A2174C40
6543	7	65	1629	30269	53205	\N	56.056367000000002	Удмуртская Республика, Каракулинский район, село Кулюшево, улица Школьная, 9-а		0101000020E6100000E27668588CC84A406DC9AA0837074C40
6533	7	65	1629	29805	53204	\N	56.191527999999998	Удмуртская Республика, Каракулинский район, деревня Котово, улица Мира, 38		0101000020E6100000639AE95E27DB4A40572250FD83184C40
6546	7	65	1629	30457	53207	\N	55.982430999999998	Удмуртская Республика, Каракулинский район, село Колесниково, улица Комсомольская, 4		0101000020E6100000FB90B75CFDC84A40CDC98B4CC0FD4B40
6542	7	65	1629	20470	52751	\N	56.013416999999997	Удмуртская Республика, Каракулинский район, село Каракулино, улица Раскольникова, 12		0101000020E610000056629E95B4DA4A40EF1AF4A5B7014C40
6541	7	65	1629	20470	52843	\N	56.013416999999997	Удмуртская Республика, Каракулинский район, село Каракулино, улица улица Кирьянова, 12		0101000020E610000056629E95B4DA4A40EF1AF4A5B7014C40
6540	7	65	1629	20470	52790	\N	56.013416999999997	Удмуртская Республика, Каракулинский район, село Каракулино, улица Каманина, 12		0101000020E610000056629E95B4DA4A40EF1AF4A5B7014C40
6539	7	65	1629	20470	52840	\N	56.013416999999997	Удмуртская Республика, Каракулинский район, село Каракулино, улица Девятьярова, 1		0101000020E610000056629E95B4DA4A40EF1AF4A5B7014C40
6536	7	65	1629	29968	52893	\N	56.154589999999999	Удмуртская Республика, Каракулинский район, село Галаново, улица Камская, 4		0101000020E610000052BAF42F490D4B40F224E99AC9134C40
6537	7	65	1629	30009	53206	\N	56.062066999999999	Удмуртская Республика, Каракулинский район, село Вятское, улица Школьная, 7		0101000020E6100000BE30992A18EF4A409694BBCFF1074C40
6547	7	65	1629	30514	53097	\N	55.904134999999997	Удмуртская Республика, Каракулинский район, деревня Быргында, улица 8-е Марта, 8		0101000020E610000060E63BF889B54A40A01518B2BAF34B40
6538	7	65	1629	30056	52791	\N	56.057341999999998	Удмуртская Республика, Каракулинский район, деревня Боярка, улица Новая, 5		0101000020E610000034DB15FA60034B40F7578FFB56074C40
6531	7	65	1629	29713	52808	\N	56.144502000000003	Удмуртская Республика, Каракулинский район, село Арзамасцево, улица Ленина, 2		0101000020E6100000A2B2614D65D94A40721AA20A7F124C40
6527	7	65	1608	29528	52560	\N	56.352502000000001	Удмуртская Республика, Камбарский район, с.Шолья, ул.Рейда, д.6 (Шольинская школа)		0101000020E6100000F9DB9E20B1074B4026E318C91E2D4C40
6528	7	65	1608	29592	52787	\N	56.445627999999999	Удмуртская Республика, Камбарский район, д.Н.Армязь, ул.Школьная, д.2а (Армязьская школа)		0101000020E61000004AB20E4757FD4A4048179B560A394C40
6522	7	65	1608	29305	53202	\N	56.413249	Удмуртская Республика, Камбарский район, с.Михайловка, ул.Юбилейная, д.2а (Михайловский СДК)		0101000020E6100000AFCF9CF529234B40670DDE57E5344C40
6526	7	65	1608	29443	52558	\N	56.300843999999998	"Удмуртская Республика, Камбарский район, с.Кама, ул.Гагарина, д.55 (д\\с ""Кораблик"" )"		0101000020E610000039252026E10E4B405299620E82264C40
6525	7	65	1608	29443	52558	\N	56.300843999999998	Удмуртская Республика, Камбарский район, с.Кама, ул.Гагарина, д.2 (Камская школа)		0101000020E610000039252026E10E4B405299620E82264C40
6529	7	65	1608	22241	53095	\N	56.455120000000001	Удмуртская Республика, Камбарский район, с.Ершовка, ул.Советская, д.36 (Ершовский СДК)		0101000020E610000078D1579066F04A40B5E0455F413A4C40
6530	7	65	1608	29673	52786	\N	56.432569999999998	Удмуртская Республика, Камбарский район, п.Борок, ул.Ленина, д.19 (Борковская школа)		0101000020E610000082AE7D01BDF24A40889D29745E374C40
6521	7	65	1608	29279	53000	\N	56.329507	Удмуртская Республика, Камбарский район, с.Балаки, пер.Клубный, д.7а (Балакинская школа)		0101000020E6100000560C570740264B40CB660E492D2A4C40
5915	7	65	6901	40334	52456	\N	56.875583516917501	Удмуртская Республика, город Ижевск, Индустриальный район, ул.Холмогорова, 76		0101000020E6100000F2ED5D83BE9C4A405073F22213704C40
6497	7	65	1321	28157	52782	\N	57.389982000000003	Удмуртская Республика, Игринский район, село Чутырь, ул.Совхозная, 79, (Чутырский ЦСДК)	Россия, республика Удмуртская, Игринский район, село Чутырь	0101000020E610000090A4A487A19F4A40AC0320EEEAB14C40
6499	7	65	1321	28252	52891	\N	57.414493999999998	Удмуртская Республика, Игринский район, дер.Чемошур, ул.Труда, 21, (Чемошурская школа-сад)		0101000020E61000000C3F389F3A8A4A40B131AF230EB54C40
6483	7	65	1321	27514	52492	\N	57.633132000000003	Удмуртская Республика, Игринский район, село Факел, ул.Кирова, 32а, (Факельский СДК)		0101000020E610000005BF0D315E834A408A0629780AD14C40
6482	7	65	1321	27514	52492	\N	57.633132000000003	Удмуртская Республика, Игринский район, село Факел, ул.Кирова, 43, (Факельская СОШ)		0101000020E610000005BF0D315E834A408A0629780AD14C40
6498	7	65	1321	28237	53169	\N	57.445790000000002	Удмуртская Республика, Игринский район, дер.Удмурт-Лоза, ул.Трактовая, 15, (Удмуртлозинская библиотека)		0101000020E6100000425E0F26C58F4A4022718FA50FB94C40
6501	7	65	1321	28350	52783	\N	57.525190000000002	Удмуртская Республика, Игринский район, дер.Сундур, ул.Сельская, 3, (Сундурский ЦСДК)		0101000020E6100000333674B33F8E4A40D717096D39C34C40
6486	7	65	1321	27710	53200	\N	57.602339000000001	Удмуртская Республика, Игринский район, дер.Среднее Шадбегово, ул.Молодежная, 3, (Среднешадбеговский СДК)		0101000020E6100000A648BE12489F4A407C0DC17119CD4C40
6491	7	65	1321	27939	52749	\N	57.525823000000003	Удмуртская Республика, Игринский район, дер.Сеп, ул.Труда, 25, (Сепский ЦСДК)		0101000020E6100000CE1951DA1BA84A40083E062B4EC34C40
6489	7	65	1321	27836	52983	\N	57.576680000000003	Удмуртская Республика, Игринский район, дер.Оник-Ирым, ул.Молодежная, 7, (Оник-Ирымский СДК)		0101000020E6100000B8CD548847BC4A40EF2076A6D0C94C40
6508	7	65	1321	28684	52838	\N	57.459159	"Удмуртская Республика, Игринский район, село Новые Зятцы, ул.Центральная, 40, (Админ-ция МО ""Новозятцинское"")"		0101000020E61000009DD9AED007494A400055DCB8C5BA4C40
95050	7	65	1321	28052	52863	\N	57.395690999999999	Игринский район, д. Мужбер ул.Вепревых (здание Мужберской сельской библиотеки) д.2		0101000020E6100000D027F224E9B64A402829B000A6B24C40
95049	7	65	1321	27624	52554	\N	57.6370879655096	Игринский район, село Менил ул.Ленина (здание Менильской СОШ) д.16	Россия, республика Удмуртская, Игринский район, село Менил	0101000020E61000008A7269FCC28B4A4047567E198CD14C40
6509	7	65	1321	28743	53167	\N	57.533168000000003	Удмуртская Республика, Игринский район, село Малягурт, ул.Железнодорожная, 4, (Малягуртская бибилиотека)		0101000020E61000006DAAEE91CD454A400AA359D93EC44C40
6510	7	65	1321	28786	52890	\N	57.364983000000002	Удмуртская Республика, Игринский район, село Магистральный, ул.Клубная, 2, (Магистральный клуб-библиотека)		0101000020E6100000BE4BA94BC6334A40494C50C3B7AE4C40
6863	7	65	1321	14006	53133	\N	57.407755000000002	Удмуртская Республика, Шарканский район, деревня Ляльшур, Ляльшурская СОШ, улица Центральная, дом 2		0101000020E6100000CD21A985929F4A40E7E3DA5031B44C40
95051	7	65	1321	28508	52798	\N	57.473173000000003	Игринский район, д. Лонки-Ворцы ул.Северная (здание Лонки-Ворцинской ООШ) д.11		0101000020E610000004029D499B984A40D42CD0EE90BC4C40
6487	7	65	1321	27722	52671	\N	57.679979000000003	Удмуртская Республика, Игринский район, дер.Лозолюк, ул.Молодежная, 1, (Лозолюкский СДК)		0101000020E6100000992CEE3F32A54A40C07B478D09D74C40
6500	7	65	1321	28325	52784	\N	57.379061	Удмуртская Республика, Игринский район, село Лоза, ул.Советская, 64, (Лозинская СОШ)		0101000020E6100000A5F622DA8E814A403318231285B04C40
6503	7	65	1321	28448	53048	\N	57.483522999999998	Удмуртская Республика, Игринский район, дер.Левая Кушья, ул.Труда, 46,(Левокушьинский клуб-библиотека)		0101000020E61000006B9BE271518F4A4091EEE714E4BD4C40
6505	7	65	1321	28518	53201	\N	57.454844999999999	Удмуртская Республика, Игринский район, село Кушья, ул.Советская, 2, (Кушьинский СДК)		0101000020E610000084BD8921398D4A40E3DF675C38BA4C40
6502	7	65	1321	28427	52985	\N	57.51634	Удмуртская Республика, Игринский район, дер.Кузьмовыр, ул.Мира, 25, (Кузьмовырский СДК)		0101000020E61000007BF65CA626974A40EECEDA6D17C24C40
95052	7	65	1321	28597	52734	\N	57.527993000000002	"Игринский район, дер.Комсомолец ул.Парковая (здание админ. МО ""Комсомольское"") д.2"		0101000020E6100000FB928D075B844A402BC24D4695C34C40
6485	7	65	1321	27640	52837	\N	57.583812000000002	Удмуртская Республика, Игринский район, дер.Кабачигурт, ул.Молодежная, 14, (Кабачигуртский БКСК)		0101000020E610000093C49272F7954A409581035ABACA4C40
6479	7	65	1321	21547	52491	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, мрн.Нефтяников, 31, (Игринская районная библиотека)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6478	7	65	1321	21547	52491	\N	57.550775000000002	"Удмуртская Республика, Игринский район, пос.Игра, мрн.Нефтяников, 34, (ДК и С ""Нефтяник"")"		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6481	7	65	1321	21547	52674	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, ул.Трактовая, 14, (Центр детского творчества)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6472	7	65	1321	21547	52414	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, ул.Пугачева, 38, (Игринская СОШ №3)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6476	7	65	1321	21547	52495	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, ул.Пионерская, 24а, (Игринская СОШ №5)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6480	7	65	1321	21547	52490	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, мрн.Нефтяников, 49, (Игринская СОШ №4)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6473	7	65	1321	21547	52788	\N	57.550800604616597	Удмуртская Республика, Игринский район, пос.Игра, ул.Мира, 26, (Игринская СОШ №2)		0101000020E61000007786A92D75884A4053CDACA580C64C40
6474	7	65	1321	21547	52418	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, ул.Ломоносова, 58, (Дом Дружбы народов)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6475	7	65	1321	21547	52493	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, ул.Лесная, 54, (Проф. училище №36)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6477	7	65	1321	21547	52419	\N	57.550775000000002	Удмуртская Республика, Игринский район, пос.Игра, ул.Коммунальная, 28, (Игринская СОШ №1)		0101000020E61000009BCAA2B08B884A402A3A92CB7FC64C40
6488	7	65	1321	27790	52553	\N	57.604754999999997	Удмуртская Республика, Игринский район, село Зура, ул.Льнозаводская, 9, (Зуринская СОШ)		0101000020E6100000F0A2AF20CDB24A40D68BA19C68CD4C40
6490	7	65	1321	27790	52640	\N	57.604640243197601	Удмуртская Республика, Игринский район, село Зура, ул,Ленина, 36, (Зуринский ЦСДК)	Россия, республика Удмуртская, Игринский район, село Зура	0101000020E610000076C24B70EAB34A403EEDF0D764CD4C40
6496	7	65	1321	28152	52986	\N	57.362580000000001	Удмуртская Республика, Игринский район, дер.Верх-Нязь, ул.Центральная, 41, (Верх-Нязьский СДК)		0101000020E6100000787C7BD7A0A14A4083177D0569AE4C40
6493	7	65	1321	28012	53208	\N	57.528073248890898	Удмуртская Республика, Игринский район, село Большая Пурга, ул.Солнечная, 1, (Больше-Пургинская СОШ)	Россия, республика Удмуртская, Игринский район, село Большая Пурга	0101000020E61000001F49490F43BF4A40477364E597C34C40
6492	7	65	1321	27973	53166	\N	57.523899999999998	"Удмуртская Республика, Игринский район, дер.Беляевское, ул.Центральная, 3а, (Администрация МО ""Беляевское"")"		0101000020E61000008D0A9C6C03BB4A40EC2FBB270FC34C40
6507	7	65	1321	28621	52902	\N	57.506459	Удмуртская Республика, Игринский район, дер.Бачкеево, ул.Сибирская, 16а, (Бачкеевская СОШ)		0101000020E610000092EA3BBF287B4A40E7E104A6D3C04C40
6467	7	65	1575	26811	52499	\N	56.948435000000003	"Удмуртская Республика, Завьяловский район, с. Ягул, МБОУ ""Ягульская СОШ"", ул. Холмогорова, д. 1"		0101000020E61000006B4606B98BA84A40DEB06D5166794C40
95045	7	65	1575	26338	52659	\N	56.660809	Завьяловский район, с. Юськи ул. Школьная (здание клуба) д. 10		0101000020E6100000F9484A7A188A4A4084F3A96395544C40
6465	7	65	1575	26732	52779	\N	56.916767	"Удмуртская Республика, Завьяловский район, д. Шабердино, МБУ ""КК ""Шабердинский"", ул. Советская, д. 28"		0101000020E610000081CEA44DD57F4A40A986FD9E58754C40
6419	7	65	1575	24618	52979	\N	56.671740999999997	Удмуртская Республика, Завьяловский район, д. Чепаниха, Чепанихинская начальная школа, ул. Верхняя, д. 11		0101000020E61000006AA510C825D04A40F030ED9BFB554C40
6464	7	65	1575	26672	52651	\N	56.911828999999997	"Удмуртская Республика, Завьяловский район, д. Хохряки, МБОУ ""Хохряковская СОШ"", ул. Тепличная, д. 20"		0101000020E6100000BFD364C6DBA84A40AE450BD0B6744C40
6436	7	65	1575	25392	53039	\N	56.795791993721799	Удмуртская Республика, Завьяловский район, д. Старые Кены, Кенский детский сад, ул. Лесная, д. 4-А	Россия, республика Удмуртская, Завьяловский район, село Старые Тукмачи	0101000020E6100000D0B8702024C14A408F352383DC654C40
6469	7	65	1575	26926	52961	\N	56.964612000000002	Удмуртская Республика, Завьяловский район, д. Старое Михайловское, Старо-Михайловский ФАП, ул. Совхозная, д. 9-2		0101000020E610000018B325AB22A24A4022AAF067787B4C40
6430	7	65	1575	25120	52485	\N	56.827562	"Удмуртская Республика, Завьяловский район, д. Старое Мартьяново, МАУ ""КСК""Завьяловский"", ул. Центральная, д. 30"		0101000020E610000028D714C8ECB44A40C8B4368DED694C40
6461	7	65	1575	26546	52780	\N	56.759740000000001	"Удмуртская Республика, Завьяловский район, д. Средний Постол, МБУ ""КК ""Среднепостольский"", ул. Центральная, д. 8"		0101000020E6100000DCF3FC69A3644A4045BB0A293F614C40
95048	7	65	1575	26960	52984	\N	57.046357607360903	"Завьяловский район, д. Сокол ул.Кооперативная (здание торфопредприятия ""Сокол"") д. 8"	Россия, республика Удмуртская, Завьяловский район, село Сокол	0101000020E6100000A2629CBF09AF4A4038F4160FEF854C40
6456	7	65	1575	26316	52773	\N	56.687573999999998	"Удмуртская Республика, Завьяловский район, с. Совхозный, МБУ ""КК ""Совхозный"", ул. Восточная, д. 37-А"		0101000020E6100000787B1002F28D4A403ACAC16C02584C40
6439	7	65	1575	25553	53231	\N	56.723353000000003	Удмуртская Республика, Завьяловский район, д. Сизево, Сизевский сельский клуб, ул. Клубная, д. 14-А		0101000020E6100000FAB660A92EAE4A40543BC3D4965C4C40
6454	7	65	1575	26216	52897	\N	56.770051000000002	Удмуртская Республика, Завьяловский район, д. Сепыч, Сепыченская начальная школа, ул. Центральная, д. 59		0101000020E610000061E28FA2CE804A4045A0FA0791624C40
95040	7	65	1575	24565	53028	\N	56.679371000000003	Завьяловский район, д. Сапарово ул. Шорболяк (здание сельского клуба) д. 7		0101000020E6100000BCE82B4833C04A40E86C01A1F5564C40
95047	7	65	1575	26880	53094	\N	56.963906000000001	Завьяловский район, д. Русский Вожой ул. Молодежная (здание ФАПа) д. 9		0101000020E61000006A6B44300EB04A4087359545617B4C40
6429	7	65	1575	25056	52747	\N	56.769666000000001	Удмуртская Республика, Завьяловский район, д. Пычанки, Пычановский клуб, ул. Центральная, 36-А		0101000020E6100000AB764D486BB44A40EC6B5D6A84624C40
6463	7	65	1575	26635	52631	\N	56.782603697138001	"Удмуртская Республика, Завьяловский район, с. Постол, ГУЗ ""РПБ"", ул. Станционная, д. 5-А"	Россия, республика Удмуртская, Завьяловский район, село Постол	0101000020E6100000FD6662BA10634A4001DC2C5E2C644C40
6446	7	65	1575	26131	\N	\N	56.729956000000001	"Удмуртская Республика, Завьяловский район, с. Октябрьский, МБУ ""Культурный комплекс"" ""Октябрьский"", д. 37"		0101000020E6100000BC77D498107B4A406EC2BD326F5D4C40
6452	7	65	1575	26131	52629	\N	56.729956000000001	"Удмуртская Республика, Завьяловский район, д. Подшивалово, МАУ ""КК ""Подшиваловский"", ул. Зайцева, д. 8-А"		0101000020E6100000BC77D498107B4A406EC2BD326F5D4C40
6449	7	65	1575	26002	\N	\N	56.780186	"Удмуртская Республика, Завьяловский район, д. Пирогово, МБОУ ""Юбилейная СОШ"", ул. Западная, д. 1-А"	Россия, республика Удмуртская, Завьяловский район, село Пирогово	0101000020E6100000A8E2C62DE6934A4006668522DD634C40
6417	7	65	1575	24538	53089	\N	56.597318000000001	"Удмуртская Республика, Завьяловский район, д. Пальники, МБОУ ""Пальниковская ООШ"", ул. Комсомольская, д. 1"		0101000020E6100000EC6AF294D5BE4A40F4A78DEA744C4C40
6444	7	65	1575	25759	53090	\N	56.934514999999998	Удмуртская Республика, Завьяловский район, д. Новый Сентег, Ново-Сентегский клуб, ул. Клубная, д. 19		0101000020E61000006D8C9DF0126E4A408B4F01309E774C40
95042	7	65	1575	25247	52981	\N	56.963160000000002	Завьяловский район, д. Новокварсинское ул. Береговая (здание клуба) д.1		0101000020E6100000058A58C4B0C74A405E68AED3487B4C40
6434	7	65	1575	25273	52642	\N	56.830876000000004	"Удмуртская Республика, Завьяловский район, д. Новая Казмаска, МБУ ""КК ""Казмаский"", ул. Сосунова, д. 41"		0101000020E6100000A67F492A53C44A4002840F255A6A4C40
6460	7	65	1575	26515	53096	\N	56.706719999999997	Удмуртская Республика, Завьяловский район, д. Непременная Лудзя, Непременнолудзинский клуб, ул. Центральная, д. 35		0101000020E610000057EA5910CA8B4A40EDB60BCD755A4C40
6438	7	65	1575	25486	52980	\N	56.742066999999999	Удмуртская Республика, Завьяловский район, д. Мещеряки, Мещеряковский ФАП, ул. Удмуртская, д. 20-А		0101000020E6100000138255F5F2A74A406D382C0DFC5E4C40
6305	7	65	1575	24772	53187	\N	56.714660000000002	Удмуртская Республика, Вавожский район,д. Макарово, детский сад, ул. Центральная, д.65		0101000020E61000006BF46A80D2DC4A4033E197FA795B4C40
6422	7	65	1575	24772	53092	\N	56.714660000000002	Удмуртская Республика, Завьяловский район, д. Макарово, Макаровский ФАП, ул. Свердлова, д. 57		0101000020E61000006BF46A80D2DC4A4033E197FA795B4C40
6466	7	65	1575	26785	52781	\N	56.966294978747001	"Удмуртская Республика, Завьяловский район, с. Люкшудья, МБОУ ""Люкшудьинская ООШ"", ул Вокзальная, д. 13"		0101000020E6100000BD35B05582814A40E8A4F78DAF7B4C40
6443	7	65	1575	25743	52672	\N	56.912021000000003	"Удмуртская Республика, Завьяловский район, с. Люк, МБОУ ""Люкская СОШ"", ул. Советская, д. 58"		0101000020E610000030BDFDB968664A40F321A81ABD744C40
6450	7	65	1575	26073	52771	\N	56.755136	"Удмуртская Республика, Завьяловский район, д. Лудорвай, МБОУ ""Лудорвайская ООШ"", ул. Школьная, д. 10"		0101000020E610000016A3AEB5F78B4A402104E44BA8604C40
6453	7	65	1575	26154	52976	\N	56.816330999999998	Удмуртская Республика, Завьяловский район, д. Ленино, Дом пенсионеров, ул. Свободы, д. 9		0101000020E610000007F01648507C4A4001DBC1887D684C40
6440	7	65	1575	25602	52748	\N	56.968935000000002	"Удмуртская Республика, Завьяловский район, д. Кияик, МБУ ""КК ""Кияикский"", ул. Школьная, д. 19"		0101000020E610000055F99E9108674A409279E40F067C4C40
6435	7	65	1575	25351	52487	\N	56.731091999999997	"Удмуртская Республика, Завьяловский район, д. Каменное, МБУ ""КК ""Каменский"", ул. Молодежная, д. 2-А"		0101000020E61000005B5F24B4E5A44A40012F336C945D4C40
95041	7	65	1575	58398	\N	\N	56.915414376997703	Завьяловский район, с. Италмас (здание школы) д. 19	Россия	0101000020E6100000F1B8A81611BD4A40782634492C754C40
6432	7	65	1575	58398	\N	\N	56.914627455357397	Адрес УИК и помещения для голосования, Удмуртская Республика, Завьяловский район, с. Италмас, (здание школы), д.19	Россия	0101000020E6100000D670917BBABC4A40F1845E7F12754C40
6425	7	65	1575	18952	52841	\N	56.791201000000001	Адрес УИК и помещения для голосования, Удмуртская Республика, Завьяловский район, с. Завьялово, ул. Чкалово (здание культурного комплекса), д.38		0101000020E6100000AAD5575705B04A4000C8091346654C40
6427	7	65	1575	18952	52769	\N	56.791201000000001	"Удмуртская Республика, Завьяловский район,с. Завьялово, МДОУ ""Центр развития ребенка-детский сад № 2"", ул. Прудовая, д. 22"		0101000020E6100000AAD5575705B04A4000C8091346654C40
6428	7	65	1575	18952	52537	\N	56.791201000000001	"Удмуртская Республика, Завьяловский район, с. Завьялово, МБУЗ ""Завьяловская районная больница"", ул. Гольянская, д. 1"		0101000020E6100000AAD5575705B04A4000C8091346654C40
6423	7	65	1575	24801	52950	\N	56.785162	Удмуртская Республика, Завьяловский район, д. Забегалово, Забегаловский ФАП, ул. Заречная, д. 11-2		0101000020E61000008D0B0742B2D44A40EE073C3080644C40
6421	7	65	1575	24717	53197	\N	56.813557000000003	Удмуртская Республика, Завьяловский район, д. Докша, Докшинский клуб, ул. Пихтовая, д. 27		0101000020E610000093A9825149DF4A404837C2A222684C40
95043	7	65	1575	25442	53099	\N	56.685253236525099	Завьяловский район, д. Динтем-Бодья ул. Шоссейная (здание клуба) д. 15	Россия, республика Удмуртская, Завьяловский район, село Динтем-Бодья	0101000020E6100000BB0CFFE906A44A40323ECC5EB6574C40
6408	7	65	1575	24070	52750	\N	56.758048000000002	"Удмуртская Республика, Завьяловский район, с. Гольяны, МОУ ""Гольянская СОШ"", ул. М. Горького, д. 15"		0101000020E6100000003620425CDD4A402C6684B707614C40
6455	7	65	1575	56410	53210	\N	56.699873285806099	Удмуртская Республика, Завьяловский район, д. Верхняя Лудзя, Верхнелудзинская начальная школа, ул. Школьная, д. 6	Россия, республика Удмуртская, Завьяловский район, село Верхняя Лудзя	0101000020E61000006954E0641B764A403C2D3F7095594C40
6462	7	65	1575	56395	52982	\N	56.722774459540197	Удмуртская Республика, Завьяловский район, д. Верхний Женвай, Верхнеженвайская начальная школа, ул. Школьная, д. 21	Россия, республика Удмуртская, Завьяловский район, село Верхний Женвай	0101000020E6100000E1D1C6116B574A401633C2DB835C4C40
6424	7	65	1575	24865	\N	\N	56.864319999999999	"Удмуртская Республика, Завьяловский район, с. Вараксино, МБУ ""КК ""Вараксинский"", д. 23"	Россия, республика Удмуртская, село Вараксино, 23	0101000020E61000009E62D520CC8B4A40ADA3AA09A26E4C40
95044	7	65	1575	25700	53093	\N	57.020667000000003	Завьяловский район, д. Большой Кияик ул. Советская (здание досугового центра) д. 5		0101000020E6100000363E93FDF3604A40A08D5C37A5824C40
95046	7	65	1575	33022	52704	\N	56.733240000000002	Завьяловский район, д. Большая Венья ул. Садовая (здание клуба) д. 36а		0101000020E610000001DC2C5E2C924A403D0FEECEDA5D4C40
6416	7	65	1575	24458	52627	\N	56.653655000000001	"Удмуртская Республика, Завьяловский район, с. Бабино, Администрация МО ""Бабинское, ул. Центральная, д.1"		0101000020E610000033E202D028BB4A40F6EE8FF7AA534C40
6441	7	65	1575	25648	52835	\N	56.970828597062102	Удмуртская Республика, Завьяловский район, с.Азино, Азинский клуб, ул. Штабная, д. 2	Россия, республика Удмуртская, Завьяловский район, село Азино	0101000020E6100000685E0EBBEF5A4A401381EA1F447C4C40
6415	7	65	1721	24416	53091	\N	57.538134999999997	Удмуртская Республика, Дебесский район, Уйвай деревня, (Здание школы), ул.Школьная, д.1		0101000020E6100000D42CD0EE90F64A409EEA909BE1C44C40
6399	7	65	1721	23634	52974	\N	57.657874999999997	Удмуртская Республика, Дебесский район, Удмуртский Лем деревня, (Здание дома культуры), ул.Удлемская, д.89		0101000020E6100000A7751BD47E014B4091ED7C3F35D44C40
6414	7	65	1721	24345	52746	\N	57.495457000000002	Удмуртская Республика, Дебесский район, Тыловай село, (Здание дома культуры), ул.Кирова, д.14		0101000020E6100000868DB27E33E54A4082C98D226BBF4C40
6410	7	65	1721	24172	53196	\N	57.711888000000002	Удмуртская Республика, Дебесский район, Турнес деревня, (Здание клуба), ул.Турнесская, д.2		0101000020E6100000919DB7B1D9E74A401A355F251FDB4C40
6413	7	65	1721	24318	53086	\N	57.711345000000001	Удмуртская Республика, Дебесский район, Тольен деревня, (Здание дома культуры), ул.Октябрьская, д.48		0101000020E6100000B6D9588979D84A4029965B5A0DDB4C40
6407	7	65	1721	24019	53087	\N	57.572823999999997	Удмуртская Республика, Дебесский район, Такагурт деревня, (Здание библиотеки), ул.Майская, д.1		0101000020E610000009F9A067B3DA4A40942EFD4B52C94C40
6409	7	65	1721	24104	52766	\N	57.621383000000002	Удмуртская Республика, Дебесский район, Сюрногурт деревня, (Здание творческо-досугового центра), ул.Сибирская, д.73		0101000020E610000013D38558FDD14A402BA5677A89CF4C40
6406	7	65	1721	23973	53194	\N	57.534632000000002	Удмуртская Республика, Дебесский район, Старый Кыч деревня, (Здание правления СПК им.Чапаева), ул.Центральная, д.7		0101000020E61000006F4562821ADC4A4092B245D26EC44C40
6403	7	65	1721	23804	53164	\N	57.690967999999998	Удмуртская Республика, Дебесский район, Нижняя Пыхта деревня, (Здание дома культуры), ул. Молодежная, д.1		0101000020E61000001502B9C491FF4A40904AB1A371D84C40
6393	7	65	1721	23339	52886	\N	57.634740999999998	Удмуртская Республика, Дебесский район, Малая Чепца деревня, (Здание клуба), ул.Сибирская, д.22		0101000020E61000008ECD8E54DFE14A4015376E313FD14C40
6412	7	65	1721	24267	52975	\N	57.662796	Удмуртская Республика, Дебесский район, Лесагурт деревня, (Здание дома культуры), ул.Восточная, д.52		0101000020E6100000999EB0C403D84A40B6F5D37FD6D44C40
6402	7	65	1721	23764	53081	\N	57.678019999999997	"Удмуртская Республика, Дебесский район, Котегурт деревня, (Здание администрации МО""Котегуртское), ул.Молодежная, д.1"		0101000020E61000000B5D8940F5C34A405704FF5BC9D64C40
6401	7	65	1721	23731	52743	\N	57.622236000000001	Удмуртская Республика, Дебесский район, Заречная Медла деревня, (Здание дома культуры), ул.Советская, д.42		0101000020E610000003780B2428F64A406A32E36DA5CF4C40
6397	7	65	1721	23383	52484	\N	57.65108	Удмуртская Республика, Дебесский район, Дебесы село, (Здание Центра детского технического творчества), ул.Труда, д.12		0101000020E6100000CD74AF93FAE64A40338AE59656D34C40
6396	7	65	1721	23383	52742	\N	57.651399972730196	"Удмуртская Республика, Дебесский район, Дебесы село, (Здание Дебесского РДК""Чупчигур""), ул.Советская, д.90"	Россия, республика Удмуртская, Дебесский район, село Дебесы	0101000020E61000003FADA23F34E74A40A54E401361D34C40
6394	7	65	1721	23383	52742	\N	57.65108	Удмуртская Республика, Дебесский район, Дебесы село, (Здание Дебесского лесничества),ул.Советская, д.136		0101000020E6100000CD74AF93FAE64A40338AE59656D34C40
6398	7	65	1721	23383	52667	\N	57.65108	"Удмуртская Республика, Дебесский район, Дебесы село, (Здание ООО ""Атолл""), ул.Радищева, д.6"		0101000020E6100000CD74AF93FAE64A40338AE59656D34C40
6395	7	65	1721	23383	52741	\N	57.65108	Удмуртская Республика, Дебесский район, Дебесы село, (Здание Дебесского политехникума), ул.Андронова, д.32		0101000020E6100000CD74AF93FAE64A40338AE59656D34C40
6405	7	65	1721	23896	52887	\N	57.491689000000001	Удмуртская Республика, Дебесский район, Верхний Четкер деревня, (Здание дома культуры), ул.Удмуртская, д.7		0101000020E61000009B73F04C68D04A40C76647AAEFBE4C40
6411	7	65	1721	24189	52896	\N	57.681899000000001	Удмуртская Республика, Дебесский район, Варни деревня, (Здание школы-детского сада), ул.Варнинская, д.21		0101000020E61000009ACDE33098DF4A406A16687748D74C40
6392	7	65	1721	23301	52884	\N	57.597617999999997	Удмуртская Республика, Дебесский район, Большой Зетым деревня, (Здание дома культуры), ул.Центральная, д.13		0101000020E610000016F6B4C35FE34A401EC022BF7ECC4C40
6400	7	65	1721	23696	53162	\N	57.615921	Удмуртская Республика, Дебесский район, Большая Кизня деревня, (Здание школы), ул.Большекизнинская, д.43		0101000020E61000005F96766A2E074B40B6F5D37FD6CE4C40
6404	7	65	1721	23874	52885	\N	57.665742000000002	Удмуртская Республика, Дебесский район, Ариково деревня, (Здание школы), ул.Центральная, д.92		0101000020E610000002284696CCF54A406DC9AA0837D54C40
6372	7	65	1562	22409	52882	\N	56.092069000000002	Удмуртская Республика, Граховский район, д. Яги Какси, (Здание сельского клуба), ул. Осиновская, д. 4		0101000020E6100000C9E88024ECF94940DBFCBFEAC80B4C40
6381	7	65	1562	56390	52911	\N	56.069750999999997	Удмуртская Республика, Граховский район, д. Старые Ятчи, (Здание СОШ), ул. Староятчинская, д.32		0101000020E61000007959130B7CF3494080EECB99ED084C40
6389	7	65	1562	23143	53079	\N	55.931970999999997	Удмуртская Республика, Граховский район, д. Старая Игра, (Здание сельского клуба), ул. Удмуртская, д. 59		0101000020E61000003352EFA99C124A4003E962D34AF74B40
6383	7	65	1562	22893	52881	\N	56.051304999999999	Удмуртская Республика, Граховский район, д. Селянур, (Здание сельского клуба), ул.Молодежная, д.4		0101000020E61000000B9B012EC8DC4940868F882991064C40
6375	7	65	1562	22554	53085	\N	56.006759000000002	Удмуртская Республика, Граховский район, д. Порым, (Здание сельского дома культуры), ул. Центральная, д.13		0101000020E61000001570CFF3A7FD494012FA997ADD004C40
6382	7	65	1562	22841	53088	\N	56.026724999999999	Удмуртская Республика, Граховский район, д. Поршур, (Здание сельского клуба), ул. Тимофеева, д.16		0101000020E6100000F86C1D1CECD94940287E8CB96B034C40
6384	7	65	1562	22927	52973	\N	56.083581000000002	Удмуртская Республика, Граховский район, с. Новогорское, (Здание СОШ), ул. Школьная, д.1		0101000020E6100000CD8FBFB4A8154A4093C83EC8B20A4C40
6379	7	65	1562	22717	52970	\N	55.967103000000002	Удмуртская Республика, Граховский район, д. Нижние Юраши, (Здание сельского дома культуры), ул. Кирова, д.42 Г		0101000020E6100000DB32E02C25E34940876EF607CAFB4B40
6391	7	65	1562	23257	53082	\N	55.925324000000003	Удмуртская Республика, Граховский район, д. Мишкино, (Здание сельского клуба), ул. Колхозная, д.13		0101000020E61000002B155454FD0A4A401A1A4F0471F64B40
6387	7	65	1562	23080	53192	\N	56.013291000000002	Удмуртская Республика, Граховский район, д. Мари-Возжай, (Здание сельского клуба), ул. Советская, д.38 А		0101000020E610000016C09481030E4A40632AFD84B3014C40
6380	7	65	1562	22765	52958	\N	55.973394999999996	Удмуртская Республика, Граховский район, д. Мамаево, (Здание сельского клуба), ул. Мичурина, д.14		0101000020E6100000BE6BD097DEEC4940828B153598FC4B40
6371	7	65	1562	18944	52965	\N	56.162511000000002	Удмуртская Республика, Граховский район, д. Макарово, (Здание сельского клуба), ул. Школьная, д. 1 А		0101000020E6100000FDDD3B6A4C0A4A40C11E1329CD144C40
6378	7	65	1562	22666	52833	\N	55.998116000000003	Удмуртская Республика, Граховский район, д. Лолошур-Возжи, (Здание сельского дома культуры), ул. Советская, д.2 Е		0101000020E61000000874266DAAE24940A3CEDC43C2FF4B40
6370	7	65	1562	22319	53076	\N	56.116864	Удмуртская Республика, Граховский район, д.Котловка, (Здание сельского клуба), ул. Пионерская, д. 11		0101000020E6100000CE1B278579014A40350A4966F50E4C40
6385	7	65	1562	22973	53077	\N	56.110314000000002	Удмуртская Республика, Граховский район, д. Кокшан, (Здание сельского клуба), ул. Грузлевская, д. 17		0101000020E610000040D9942BBC0F4A403E25E7C41E0E4C40
6336	7	65	1562	20687	52888	\N	56.039203000000001	Удмуртская Республика, Граховский район, д. Каменное, (Здание школы), ул. Советская, д.2		0101000020E6100000DA1CE736E1024A40DA73999A04054C40
6374	7	65	1562	20217	52855	\N	56.035330999999999	Удмуртская Республика, Граховский район, д.Иж-Бобья, адрес помещения для голосования:(Иж-Бобьинская начальная школа), ул. Кооперативная, д.1, адрес УИК: ул. Заречная (Иж-Бобьинский детсад), д.2		0101000020E6100000A52DAEF199084A407AC4E8B985044C40
6376	7	65	1562	18831	52968	\N	56.037553000000003	Адрес УИК и помещения для голосования: Удмуртская Республика, Граховский район, с. Заречный, ул. Школьная, (здание средней школы), д.3		0101000020E6100000B43A394371F14940F06E6589CE044C40
6369	7	65	1562	18728	52531	\N	56.048118000000002	Удмуртская Республика, с. Грахово, (Здание районного дома культуры (спортзал), ул. Колпакова, д.5		0101000020E610000014B1886187FB4940AA2C0ABB28064C40
6388	7	65	1562	23121	53193	\N	55.948135000000001	Удмуртская Республика, Граховский район, д. Верхняя Игра, (Здание сельского дома культуры), ул. 10 Пятилетки, д.1		0101000020E6100000A647533D990D4A40B398D87C5CF94B40
6386	7	65	1562	23029	53083	\N	56.024582000000002	Удмуртская Республика, Граховский район, д. Большая Ерыкса, (Здание сельского клуба), ул. Гагарина, д.1		0101000020E610000049810530651A4A40FF08C38025034C40
6377	7	65	1562	22624	52969	\N	55.998916000000001	Удмуртская Республика, Граховский район, д. Благодатное, (Здание детского сада), ул. Благодатновская, д. 53 Б		0101000020E6100000F81C588E90EF4940BFB9BF7ADCFF4B40
6390	7	65	1562	23211	52967	\N	55.954188000000002	Удмуртская Республика, Граховский район, д. Байтуганово, (Здание сельского клуба), ул. Центральная, д.38 А		0101000020E610000060730E9E091D4A402A1E17D522FA4B40
6368	7	65	1000	22240	52625	\N	58.111288000000002	"Удмуртская Республика, Глазовский район, д. Штанигурт, МУК ""КДЦ ""Искра"", ул. Глазовская, д. 3"		0101000020E6100000074147AB5A544A40F83768AF3E0E4D40
6356	7	65	1000	21647	53074	\N	58.102857	Удмуртская Республика, Глазовский район, д. Чура, Чуринский СДК, ул. Центральная, д. 12а		0101000020E6100000AE4A22FB20414A4014950D6B2A0D4D40
6347	7	65	1000	18929	52957	\N	58.331054999999999	Адрес УИК и помещения для голосования: Удмуртская Республика, Глазовский район, д. Чажайский лесоучасток, ул. Школьная (здание клуба), д.8		0101000020E6100000813D26529A5B4A40B1169F02602A4D40
6351	7	65	1000	21420	53191	\N	58.041409000000002	"Удмуртская Республика, Глазовский район, д. Удмуртские Ключи, МУК ""Ключевской ДК"", ул. Школьная, д. 4"		0101000020E6100000444DF4F9283B4A404A61DEE34C054D40
6359	7	65	1000	21815	53084	\N	58.006326000000001	"Удмуртская Республика, Глазовский район, д. Трубашур, МУСО ""КЦСОН"", ул. Школьная, д. 1"		0101000020E61000006A4FC939B1674A40A88E554ACF004D40
6364	7	65	1000	22049	52880	\N	58.463507	Удмуртская Республика, Глазовский район, п. Сева, Севинский сельский клуб, ул. Горьковская, д. 1		0101000020E6100000C8CD70033E7F4A40C93B8732543B4D40
22741	7	61	106	49208	65507	\N	52.307580999999999	д. Исянгильдино, Акмуллы, 4		0101000020E6100000C520B072683D4D407CEF6FD05E274A40
6366	7	65	1000	22141	53190	\N	57.947864000000003	Удмуртская Республика, Глазовский район, д. Пусошур, Пусошурский ЦСДК, ул. Школьная, д. 1		0101000020E6100000D09CF529C75C4A402387889B53F94C40
6362	7	65	1000	21944	52650	\N	58.248975999999999	"Удмуртская Республика, Глазовский район, с. Понино, МУК ""Понинский КСК"", ул. Коммунальная, д. 7"		0101000020E61000005682C5E1CC674A4094BE1072DE1F4D40
6361	7	65	1000	21919	52669	\N	57.941127999999999	"Удмуртская Республика, Глазовский район, с. Парзи, МУК ""Парзинский КДЦ"", ул. Прудовая, д. 7"		0101000020E61000003BDF4F8D974A4A40C9ACDEE176F84C40
6365	7	65	1000	22102	52966	\N	57.885224999999998	Удмуртская Республика, Глазовский район, д. Отогурт, Отогуртский СДК, ул. Кирова, д. 38		0101000020E6100000E38BF67821534A40014D840D4FF14C40
6358	7	65	1000	8580	52486	\N	58.084705	"Удмуртская Республика, Глазовский район, с. Октябрьский, МУК ""Октябрьский ЦСДК"", ул. Центральная, д. 23"		0101000020E6100000A9D898D7116F4A4062670A9DD70A4D40
6748	7	65	1000	8580	53157	\N	58.084705	Удмуртская Республика, Сарапульский район, с.Октябрьский, ул.Пастухова, д.1		0101000020E6100000A9D898D7116F4A4062670A9DD70A4D40
6350	7	65	1000	21378	52665	\N	58.253833999999998	Удмуртская Республика, Глазовский район, с. Люм, Люмский ЦСДК, ул. Люмская, д. 41		0101000020E6100000C34483143C3B4A40724EECA17D204D40
6357	7	65	1000	21701	52624	\N	58.198700000000002	"Удмуртская Республика, Глазовский район, д. Курегово, МУК ""Куреговская ЦКС"" , пер. Школьный, д. 2"		0101000020E6100000033FAA61BF874A408CDB68006F194D40
6367	7	65	1000	56383	52857	\N	58.046948066497798	"Удмуртская Республика, Глазовский район, д. Кочишево, МУК ""Кочишевская ЦКС"", ул. Ленина, д. 35"	Россия, республика Удмуртская, Глазовский район, село Кочищево	0101000020E6100000F949B54FC75F4A406A4E5E6402064D40
6354	7	65	1000	21557	52831	\N	58.140425	"Удмуртская Республика, Глазовский район, д.Кожиль, МУК ""ЦКС ""Дружба"", ул. Кировская, д. 35"		0101000020E610000095D5743DD1374A4039454772F9114D40
6353	7	65	1000	21522	52413	\N	58.103969999999997	Удмуртская Республика, Глазовский район, д. Качкашур, Качкашурский ДК, ул. Центральная, 3а		0101000020E6100000E161DA37F7634A40EFE192E34E0D4D40
6363	7	65	1000	22003	52767	\N	58.313699999999997	"Удмуртская Республика, Глазовский район, д. Золотарево, МОУ ""Золотаревская начальная школа-детский сад"", ул.Школьная, д. 1а"		0101000020E6100000323B8BDEA96A4A40AA60545227284D40
6348	7	65	1000	21287	53075	\N	58.253791999999997	"Удмуртская Республика, Глазовский район, д. Дондыкар, МОУ ""Дондыкарская СОШ"", ул. Мира, д. 5"		0101000020E6100000E3E13D0796594A4043FE99417C204D40
6355	7	65	1000	21608	52744	\N	58.182023980035297	Удмуртская Республика, Глазовский район, с. Дзякино, Дзякинский СДК, ул. Советская, д. 5	Россия, республика Удмуртская, Глазовский район, село Дзякино	0101000020E6100000E5D022DBF92A4A40268BFB8F4C174D40
6352	7	65	1000	18655	52836	\N	57.996758999999997	"Удмуртская Республика, Глазовский район, д. Гулеково, ул. Центральная (здание СПК ""Луч""), д.13а, адрес УИК: ул. Центральная (здание Администрации), д.15"		0101000020E6100000DE9387855A394A40307F85CC95FF4C40
6349	7	65	1000	21334	52832	\N	58.214855	"Удмуртская Республика, Глазовский район, д. Слудка, Слудский ЦСДК"", ул. Садовая, д. 7"		0101000020E6100000BF654E97C5484A40E8305F5E801B4D40
6345	7	65	1000	21158	52666	\N	58.140098000000002	"Удмуртская Республика, Глазовский район, д. Адам, МОУ ДОД ""Детско-юношеская спортивная школа"", ул. Советская, д. 16а"		0101000020E6100000BA2D910BCE6A4A40151E34BBEE114D40
6123	7	65	7409	56358	52382	\N	58.129307165410097	Удмуртская Республика, город Глазов, ул.Кирова, д.34	Россия, республика Удмуртская, Глазов городской округ	0101000020E6100000DCB930D28B564A406A12BC218D104D40
6327	7	65	1557	20158	53070	\N	57.160249	"Удмуртская Республика, Воткинский район, муниципальное образование ""Верхнеталицкое"", дер.Черновский лесоучасток, ул.Школьная, д.5"		0101000020E6100000890B40A374D34A40BD1B0B0A83944C40
6344	7	65	1557	21088	53159	\N	57.058948000000001	"Удмуртская Республика, Воткинский район, муниципальное образование ""Светлянское"", дер.Черная, ул.Колхозная, д.8а"		0101000020E610000084F23E8EE6C04A401215AA9B8B874C40
6339	7	65	1557	20814	53068	\N	57.117215999999999	"Удмуртская Республика, Воткинский район, муниципальное образование ""Первомайское"", дер.Черепановка, ул.Кокорина, д.41"		0101000020E6100000132BA391CF154B40B24813EF008F4C40
6342	7	65	1557	21013	52839	\N	57.060754000000003	"Удмуртская Республика, Воткинский район, муниципальное образование ""Светлянское"", с.Светлое, пер.Октябрьский, д.1"		0101000020E6100000CFD8976C3CD04A40F48C7DC9C6874C40
6322	7	65	1557	18614	52878	\N	57.150817000000004	427425, Удмуртская Республика, Воткинский район, муниципальное образование «Большекиварское», с.Пихтовка, ул.Центральная (здание школы), д. 7, адрес УИК: ул.Центральная (здание дома культуры), д. 10		0101000020E6100000E65B1FD61B134B402657B1F84D934C40
6340	7	65	1557	20907	52528	\N	56.881442999999997	"Удмуртская Республика, Воткинский район, муниципальное образование ""Перевозинское"", с.Перевозиное, ул.Советская, д.38а"		0101000020E610000021CD58349DF54A40E124CD1FD3704C40
6338	7	65	1557	20801	52622	\N	57.065956	"Удмуртская Республика, Воткинский район, муниципальное образование ""Первомайское"", с.Первомайский, пр-д Молодежный, д.2"		0101000020E610000037A79201A0104B40CC7C073F71884C40
6341	7	65	1557	20936	53073	\N	56.895310000000002	"Удмуртская Республика, Воткинский район, муниципальное образование ""Перевозинское"", дер.Ольхово, ул.Молодежная, д.25/3"		0101000020E61000008AE76C01A1E54A4011E4A08499724C40
6316	7	65	1535	19530	53060	\N	56.754765999999996	Удмуртская Республика, Вавожский район, д. Монья, столовая, ул. Центральная, д.6		0101000020E61000006E15C440D7C04940FD101B2C9C604C40
22584	7	61	659	46243	66189	\N	54.214919999999999	Кудашево, Салавата, 49		0101000020E61000007F30F0DC7BA24D40CFA0A17F821B4B40
6324	7	65	1557	56362	52483	\N	56.810216997337903	"Удмуртская Республика, Воткинский район, муниципальное образование ""Нововолковское"", пос.Новый, ул.Центральная, д.9"	Россия, республика Удмуртская, Воткинский район, поселок Новый	0101000020E6100000EDF5EE8FF7044B40E5D4CE30B5674C40
6323	7	65	1557	56362	52483	\N	56.811865857708398	"Удмуртская Республика, Воткинский район, муниципальное образование ""Нововолковское"", пос.Новый, ул.Центральная, д.15"	Россия, республика Удмуртская, Воткинский район, поселок Новый	0101000020E610000024253D0CAD044B40FF5D9F39EB674C40
6332	7	65	1557	20363	53071	\N	56.872664	427415, Удмуртская Республика, Воткинский район, муниципальное образование «Июльское», дер.Молчаны,  ул.Широкая (здание дома культуры), д.38б, адрес УИК: ул.Центральная (здание ДКиС «Современник»), д.29		0101000020E6100000CD3D247CEFD14A40C2323674B36F4C40
6337	7	65	1557	20720	52764	\N	57.001626999999999	"Удмуртская Республика, Воткинский район, муниципальное образование ""Кукуевское"", дер.Кукуи, ул.Школьная, д.8"		0101000020E61000004B5CC7B8E2E64A4032E5435035804C40
6343	7	65	1557	21063	53186	\N	57.012577	"Удмуртская Республика, Воткинский район, муниципальное образование ""Светлянское"", дер.Кудрино, ул.Гагарина, д.45а"		0101000020E61000008E95986725C94A4045D7851F9C814C40
6321	7	65	1557	19815	53188	\N	57.237313999999998	"Удмуртская Республика, Балезинский район, муниципальное образование ""Большеварыжское"", с.Кельчино, ул.Школьная, д.1"		0101000020E61000003753211E89174B4004711E4E609E4C40
6334	7	65	1557	20584	52514	\N	56.960357999999999	"Удмуртская Республика, Воткинский район, муниципальное образование ""Кварсинское"", дер.Кварса, ул.Советская, д.12"		0101000020E61000000C01C0B167F94A40DA39CD02ED7A4C40
6333	7	65	1557	20496	52830	\N	57.032606000000001	"Удмуртская Республика, Воткинский район, муниципальное образование ""Камское"", с.Камское, ул.Комсомольская, д.3а"		0101000020E61000008E959867251B4B40A2D3F36E2C844C40
6523	7	65	1557	20496	52673	\N	57.032606000000001	"Удмуртская Республика, Камбарский район, с.Камское, ул.Советская, д.26 (ДК ""Нефтяник"")"		0101000020E61000008E959867251B4B40A2D3F36E2C844C40
6331	7	65	1557	20388	52621	\N	56.921729999999997	"Удмуртская Республика, Воткинский район, муниципальное образование ""Июльское"", с.Июльское, ул.Центральная, д.29"		0101000020E61000007D40A03369CD4A40FCDEA63FFB754C40
95039	7	65	1557	20388	52879	\N	56.921729999999997	427415 Воткинский район,  с.Июльское,  ул.Молодежная (здание школы), д.1		0101000020E61000007D40A03369CD4A40FCDEA63FFB754C40
6335	7	65	1557	20599	53072	\N	57.009548000000002	"Удмуртская Республика, Воткинский район, муниципальное образование ""Кварсинское"", дер.Двигатель, ул.Коммунаров, д.2"		0101000020E6100000643BDF4F8DF54A4001DF6DDE38814C40
6328	7	65	1557	20227	52660	\N	57.0336916995523	"Удмуртская Республика, Воткинский район, муниципальное образование ""Гавриловское"", дер.Гавриловска, ул.Набережная, д.4"	Россия, республика Удмуртская, Воткинский район, село Гавриловка	0101000020E61000008F352383DC094B408411FB0450844C40
6326	7	65	1557	20079	52763	\N	57.071432000000001	"Удмуртская Республика, Воткинский район, муниципальное образование ""Верхнеталицкое"", дер.Верхняя Талица, ул.Центральная, д.36"		0101000020E610000040A54A94BDDF4A40A6F10BAF24894C40
6319	7	65	1557	56384	52859	\N	56.966616838682	"Удмуртская Республика, Воткинский район, муниципальное образование ""Болгуринское"", дер.Верхне-Позимь, ул.Школьная, д.30"	Россия, республика Удмуртская, Воткинский район, село Верхнепозимь	0101000020E6100000C3BB5CC477D44A40FA60191BBA7B4C40
6320	7	65	1557	19748	52825	\N	57.18291	"Удмуртская Республика, Воткинский район, муниципальное образование ""Большекиварское"", дер.Большая Кивара, ул.Новая, д.2"		0101000020E6100000D3DB9F8B86184B40410E4A9869974C40
95038	7	65	1557	19663	52727	\N	56.9618112665433	427400 Воткинский район,  д.Болгуры,  ул.Школьная (здание школы), д. 1г	Россия, республика Удмуртская, Воткинский район, село Болгуры	0101000020E6100000F3C98AE1EAE24A406EF7729F1C7B4C40
6329	7	65	1557	20229	52964	\N	56.933802999999997	"Удмуртская Республика, Воткинский район, муниципальное образование ""Гавриловское"", дер.Беркуты, ул.Юбилейная, д.1"		0101000020E61000007CD11E2FA4074B400EF450DB86774C40
6107	7	65	7410	56363	52488	\N	57.048894507998099	Удмуртская Республика, город Воткинск, ул.Освобождения, д.5	Россия, республика Удмуртская, Воткинск городской округ	0101000020E61000006FD8B628B3F94A400EF8FC3042864C40
6303	7	65	1535	18858	53063	\N	56.736443999999999	Удмуртская Республика, Вавожский район,д.Яголуд, СК, ул. Центральная, д.14		0101000020E6100000D2C43BC0930E4A40EFAA07CC435E4C40
6301	7	65	1535	56403	53078	\N	56.746912033925199	Удмуртская Республика, Вавожский район, д. Уё-Докья, школа, ул. Садовая, д.27	Россия, республика Удмуртская, Вавожский район, село Уе-Докья	0101000020E6100000901150E108024A40B77EFACF9A5F4C40
6310	7	65	1535	19235	53045	\N	56.564523000000001	"Удмуртская Республика, Вавожский район,с. Тыловыл-Пельга, Администрация МО ""Тыловыл-Пельгинское"", ул. Центральная, д.61"		0101000020E6100000994A3FE1ECDE49407F6B274A42484C40
6309	7	65	1535	19197	53065	\N	56.607134000000002	Удмуртская Республика, Вавожский район,д.Ожги, школа-сад, ул. Евдокимова, д.17		0101000020E610000087FBC8AD49E3494014252191B64D4C40
6298	7	65	1535	18611	52662	\N	56.805352999999997	Удмуртская Республика, Вавожский район, с.Нюрдор-Котья, СДК, ул.Советская, д.1б		0101000020E6100000A9A3E36A64EF4940245E9ECE15674C40
6312	7	65	1535	19320	\N	\N	56.803224	Удмуртская Республика, Вавожский район, д. Новая Бия, СДК, ул. Школьная, д.33 а	Россия, республика Удмуртская, Вавожский район, село Новая Бия	0101000020E6100000419FC893A4D9494060AE450BD0664C40
6296	7	65	1535	18520	53059	\N	56.838622000000001	"Удмуртская Республика, Вавожский район, д.Лыстем, контора ООО""Лыстемское"", ул.Новая, д.2"		0101000020E61000002C2AE27492E7494062DA37F7576B4C40
6302	7	65	1535	18833	52872	\N	56.820666000000003	Удмуртская Республика, Вавожский район, д.Каменный Ключ, СК, ул.Садовая, д.23		0101000020E610000082531F48DE154A4036785F950B694C40
6317	7	65	1535	18532	52740	\N	56.852376	Удмуртская Республика, Вавожский район,с.Какмож, СДК,ул. Поточная, 1		0101000020E610000065A9F57EA3ED494099F221A81A6D4C40
6297	7	65	1535	18532	52740	\N	56.852376	Удмуртская Республика, Вавожский район, с.Какмож, СДК,ул.Поточная, д.1		0101000020E610000065A9F57EA3ED494099F221A81A6D4C40
6314	7	65	1535	19446	52883	\N	56.759428999999997	Удмуртская Республика, Вавожский район,д. Зямбайгурт, СДК, ул. Центральная, д.13 а		0101000020E61000001EA67D737FCF494026512FF834614C40
6308	7	65	1535	19143	53064	\N	56.722301000000002	Удмуртская Республика, Вавожский район,д. Зядлуд, СК, ул. Центральная, д.11		0101000020E6100000965984622BE049401E6FF25B745C4C40
6300	7	65	1535	54702	53185	\N	56.808560999999997	Удмуртская Республика, Вавожский район,д.Зяглуд-Какся, школа,ул.Новая, д.11		0101000020E61000002366F6798C124A4018E945ED7E674C40
6294	7	65	1535	18386	53069	\N	56.826797999999997	Удмуртская Республика, Вавожский район, д. Жуё-Можга, СК,ул.Лермонтова, 16		0101000020E6100000088F368E58FB4940F8325184D4694C40
6311	7	65	1535	19299	53067	\N	56.552866000000002	"Удмуртская Республика, Вавожский район, д. Дубровка, контора ООО ""Восход"", ул. Новая, д.2"		0101000020E6100000FA0AD28C45E3494001892650C4464C40
6307	7	65	1535	19066	52738	\N	56.680695999999998	Удмуртская Республика, Вавожский район,с.Волипельга, СДК, ул. Советская, д.8		0101000020E6100000AB3DEC8502E449404E42E90B21574C40
6313	7	65	1535	19402	52664	\N	56.815098999999996	Удмуртская Республика, Вавожский район,с.Водзимонье, школа, ул. Коммунальная, д.32		0101000020E6100000ADA6EB89AECF49404B00FE2955684C40
6293	7	65	1535	18216	52524	\N	56.772927000000003	"Удмуртская Республика, Вавожский район,с.Вавож, ГУ УР ""Вавожское лесничество"",ул.Северная, д.3"		0101000020E61000000A0F9A5DF7F6494003999D45EF624C40
6292	7	65	1535	18216	52638	\N	56.7733274765109	Удмуртская Республика, Вавожский район,с.Вавож, РДК,ул.Интернациональная, д.44 б	Россия, республика Удмуртская, Вавожский район, село Вавож	0101000020E6100000807F4A9528F74940910E0F61FC624C40
6291	7	65	1535	18216	52638	\N	56.772927000000003	Удмуртская Республика, Вавожский район,с.Вавож, РДК, ул.Интернациональная, д.44 б		0101000020E61000000A0F9A5DF7F6494003999D45EF624C40
6315	7	65	1535	19498	52963	\N	56.715829999999997	Удмуртская Республика, Вавожский район,с.Брызгалово, СК, ул. Молодежная, д.4		0101000020E61000002D98F8A3A8BF494072BF4351A05B4C40
6304	7	65	1535	18932	52870	\N	56.700701000000002	Удмуртская Республика, Вавожский район,д. Большое Волково, центр досуга, ул. Центральная, д.44		0101000020E61000007E5704FF5BFD494023A30392B0594C40
6295	7	65	1535	18410	53066	\N	56.863975000000003	Удмуртская Республика, Вавожский район, д.Большая Можга, СК,ул. Центральная, д.13		0101000020E610000063D34A2190F74940E3C798BB966E4C40
6299	7	65	1535	18631	52876	\N	56.772146999999997	Удмуртская Республика, Вавожский район,д. Большая Гурезь-Пудга, СДК, ул. Первомайская, д.23		0101000020E6100000B45549641F0A4A402D5A80B6D5624C40
6306	7	65	1535	19047	52875	\N	56.670484999999999	Удмуртская Республика, Вавожский район,д. Березек, школа-сад, ул. Вишневая, д.17		0101000020E610000073BC02D193024A40B2BAD573D2554C40
6261	7	65	1392	16727	\N	\N	57.912927000000003	Удмуртская Республика, Балезинский район, д.Ягошур, ФАП		0101000020E6100000524832AB77724A405551BCCADAF44C40
6258	7	65	1392	16613	53177	\N	57.882233999999997	Удмуртская Республика, Балезинский район, с.Юнда, ул.Центральная, 42		0101000020E610000053CF8250DE714A40AAB5300BEDF04C40
95033	7	65	1392	17232	52874	\N	58.060698000000002	Балезинский район, д.Эркешево ул.Центральная (здание школы) д.13		0101000020E6100000390B7BDAE1974A406077BAF3C4074D40
6284	7	65	1392	17903	52892	\N	58.340107000000003	Удмуртская Республика, Балезинский район, д.Шарпа, ул.Школьная, 2		0101000020E61000002191B6F127B84A4002124DA0882B4D40
6264	7	65	1392	16919	53179	\N	57.784044000000002	Удмуртская Республика, Балезинский район, д.Ушур, ул.Центральная, 9		0101000020E6100000B4AD669DF1794A400150C58D5BE44C40
95032	7	65	1392	17112	53184	\N	58.003469000000003	Балезинский район, с.Турецкое, ул.Труда (здание школы), 14		0101000020E6100000EF0390DAC49F4A4061C614AC71004D40
6249	7	65	1392	16119	\N	\N	57.953552000000002	Удмуртская Республика, Балезинский район, д.Такапи, бригадный дом		0101000020E61000002C47C8409E854A408884EFFD0DFA4C40
6283	7	65	1392	17821	53061	\N	58.407229000000001	Удмуртская Республика, Балезинский район, с.Сергино, ул.ул.Советская, 2		0101000020E610000009707A17EFC34A40CC7D721420344D40
6256	7	65	1392	16503	52864	\N	57.885894	Удмуртская Республика, Балезинский район, д.Пышкец, ул.Луговая, 25, СДК		0101000020E6100000B5334C6DA99B4A407FDC7EF964F14C40
6250	7	65	1392	16191	52737	\N	57.989030999999997	Удмуртская Республика, Балезинский район, д.Пыбья, ул.Клубная, 2		0101000020E61000008CF7E3F6CB734A4076DD5B9198FE4C40
95030	7	65	1392	16228	53180	\N	58.086551	Балезинский район, д.Подборново ул.Центральная (здание школы) д.19		0101000020E610000030630AD6387D4A40D237691A140B4D40
6288	7	65	1392	18097	\N	\N	57.865904	Удмуртская Республика, Балезинский район, д.Пибаньшур, здание ЭЧК-31	Россия, республика Удмуртская, Балезинский район, село Пибаньшур	0101000020E6100000E353008C67A24A40E0BC38F1D5EE4C40
6260	7	65	1392	16721	53189	\N	57.914662	Удмуртская Республика, Балезинский район, д.Падера, ул.Центральная, 41		0101000020E61000006E1805C1E3794A406D72F8A413F54C40
95034	7	65	1392	17303	53051	\N	58.077696000000003	Балезинский район, д.Оросово ул.им.А.Русских (здание школы) д.2		0101000020E6100000DDD1FF722D8E4A40D88349F1F1094D40
6266	7	65	1392	17017	52960	\N	57.832329000000001	Удмуртская Республика, Балезинский район, с.Нововолково, ул.Волкова, 27		0101000020E610000083F8C08EFF8A4A409641B5C189EA4C40
6267	7	65	1392	17019	53058	\N	57.726154999999999	Удмуртская Республика, Балезинский район, д.Люк, ул.Школьная, 14		0101000020E610000071CB4752D28B4A40D769A4A5F2DC4C40
6273	7	65	1392	17019	53195	\N	57.726154999999999	Удмуртская Республика, Балезинский район, с.Люк, ул.Школьная, 9, СДК		0101000020E610000071CB4752D28B4A40D769A4A5F2DC4C40
95036	7	65	1392	56394	52977	\N	58.0259458557614	Балезинский район, д.Котомка Полевая (здание ФАП) д.9	Россия, республика Удмуртская, Балезинский район, село Котомка	0101000020E6100000B857E6ADBA724A4023BBD23252034D40
6262	7	65	1392	16818	53033	\N	57.910479000000002	Удмуртская Республика, Балезинский район, д.Котегово, ул.Сепычевская, 3		0101000020E6100000E9633E20D0674A40EF586C938AF44C40
6274	7	65	1392	56385	52869	\N	58.134877775419199	д.Коршуново, ул.Шкоьная, 2-3	Россия, республика Удмуртская, Балезинский район, село Коршуново	0101000020E6100000467A51BB5FAD4A409679ABAE43114D40
6248	7	65	1392	16109	52732	\N	58.006774	Удмуртская Республика, Балезинский район, д.Кожило, ул.Советская, 1		0101000020E61000009C3237DF88804A40473B6EF8DD004D40
6277	7	65	1392	17517	53183	\N	58.217173000000003	Удмуртская Республика, Балезинский район, д.Киршонки, ул.Новая, 7		0101000020E6100000232F6B6281B14A4080492A53CC1B4D40
6289	7	65	1392	18121	52962	\N	58.418259999999997	Удмуртская Республика, Балезинский район, д.Кипрята, ул.Полевая, 2		0101000020E6100000022D5DC136BC4A40CB9C2E8B89354D40
6252	7	65	1392	16307	52823	\N	58.029463999999997	Удмуртская Республика, Балезинский район, д.Кестым, ул.Школьная, 8		0101000020E6100000ACAA97DF697C4A406534F279C5034D40
6279	7	65	1392	17624	52735	\N	58.223463000000002	Удмуртская Республика, Балезинский район, с.Карсовай, ул..Первомайская, 17		0101000020E6100000DBFB54151A984A40DB6E826F9A1C4D40
6278	7	65	1392	17624	52735	\N	58.224864188182103	Удмуртская Республика, Балезинский район, с.Карсовай, ул.Первомайская, 21, ЦСДК	Россия, республика Удмуртская, Балезинский район, село Карсовай	0101000020E61000001B834E081D984A401C06F357C81C4D40
6280	7	65	1392	17624	52868	\N	58.223463000000002	Удмуртская Республика, Балезинский район, с.Карсовай, ул.Механизаторов, 3		0101000020E6100000DBFB54151A984A40DB6E826F9A1C4D40
6269	7	65	1392	17119	53182	\N	57.937258999999997	Удмуртская Республика, Балезинский район, с.Каменное Заделье, ул.Школьная, 5 б, СДК		0101000020E6100000C5AC1743399B4A40DA70581AF8F74C40
95031	7	65	1392	16827	52739	\N	57.843319999999999	Балезинский район, д.Исаково ул.Школьная (здание школы) д.1		0101000020E6100000ECF82F1004764A400708E6E8F1EB4C40
6255	7	65	1392	16424	52856	\N	57.878309999999999	Удмуртская Республика, Балезинский район, с.Заречный, ул.Больничная, 1		0101000020E6100000DEE68D93C2904A40F8DF4A766CF04C40
6253	7	65	1392	16315	53176	\N	58.069423999999998	Удмуртская Республика, Балезинский район, д.Гордино, ул.Колхозная, 1-2		0101000020E6100000EA059FE6E47F4A405CC7B8E2E2084D40
6254	7	65	1392	16399	52733	\N	57.884574000000001	Удмуртская Республика, Балезинский район, д.Воегурт, ул.Полевая, 2 а		0101000020E61000008A20CEC3098A4A402A7288B839F14C40
95035	7	65	1392	17507	52858	\N	58.168703999999998	Балезинский район, д.Верх-Люкино ул.Центральная (здание школы) д.24		0101000020E61000009D47C5FF1DA94A40295AB91798154D40
6257	7	65	1392	16522	52941	\N	57.909747000000003	Удмуртская Республика, Балезинский район, д.Быдыпи, ул.Советская, 13а, СДК		0101000020E61000005EB9DE36537F4A402B51F69672F44C40
6270	7	65	1392	17206	52942	\N	57.980600000000003	Удмуртская Республика, Балезинский район, д.Бурино, ул.Центральная, 32-1		0101000020E61000009352D0ED25894A40933A014D84FD4C40
6275	7	65	1392	17431	52865	\N	58.116028	Удмуртская Республика, Балезинский район, д.Большой Варыж, ул.Центральная, 26		0101000020E6100000A2F14410E7934A40CCB56801DA0E4D40
6287	7	65	1392	18036	\N	\N	58.097259000000001	Удмуртская Республика, Балезинский район, д.Большое Сазаново, ФАП		0101000020E61000001B9C887E6DA94A40EF1EA0FB720C4D40
95029	7	65	1392	16027	53172	\N	58.023440000000001	Балезинский район с.Балезино ул.Школьная (Здание школы № 4) д.2		0101000020E6100000FDD8243FE2854A4089B5F81400034D40
6246	7	65	1392	15239	52482	\N	57.978698530458402	Удмуртская Республика, Балезинский район, п.Балезино, ул.Школьная, 12	Россия, республика Удмуртская, Балезинский район, поселок Балезино	0101000020E61000007C60C77F81804A405FD0420246FD4C40
6240	7	65	1392	15239	52520	\N	57.978605000000002	Удмуртская Республика, Балезинский район, п.Балезино, ул.Советская, 9		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6239	7	65	1392	15239	52411	\N	57.978605000000002	Удмуртская Республика, Балезинский район, п. Балезино, ул.Сибирская, 1 а		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6243	7	65	1392	15239	52620	\N	57.978605000000002	Удмуртская Республика, Балезинский район. п.Балезино, ул.Свердлова, 1		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6230	7	65	1392	15239	52415	\N	57.978605000000002	Удмуртская Республика, Балезинский район, п.Балезино, ул.Московская, д.41 а ()		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6241	7	65	1392	15239	52412	\N	57.978605000000002	Удмуртская Республика, Балезинский район, п.Балезино, ул. к.Маркса, 30		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6242	7	65	1392	15239	52434	\N	57.978605000000002	Удмуртская Республика, Балезинский район, п.Балезино, ул.Калинина, д.50		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6245	7	65	1392	15239	52768	\N	57.978605000000002	Удмуртская Республика, Балезинский район, п.Балезино, ул.Заводская, 1		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6244	7	65	1392	15239	52436	\N	57.978605000000002	Удмуртская Республика, Балезинский район. п.Балезино, ул.Железнодорожная, 10		0101000020E6100000698D412784804A40DE59BBED42FD4C40
6282	7	65	1392	17810	53057	\N	58.287719000000003	Удмуртская Республика, Балезинский район, д.Базаны, ул.Солнечная, 22, детский сад		0101000020E6100000AD6EF59CF4904A400BB8E7F9D3244D40
6259	7	65	1392	16619	\N	\N	57.821921619162303	Удмуртская Республика, Балезинский район, д. Ахмади, ФАП	Россия, республика Удмуртская, Балезинский район, село Ахмади	0101000020E6100000FFE89B340D6A4A4074EE76BD34E94C40
6265	7	65	1392	16939	52827	\N	57.784010000000002	Удмуртская Республика, Балезинский район, с.Андрейшур, ул.Советская, 10		0101000020E610000015CAC2D7D79A4A4055DE8E705AE44C40
6281	7	65	1392	17731	52947	\N	58.2752205477545	Удмуртская Республика, Балезинский район, д.Андреевцы, ул.Школьная, 2	Россия, республика Удмуртская, Балезинский район, село Андреевцы	0101000020E6100000D42B6519E2A04A40121615713A234D40
6234	7	65	1333	56408	\N	\N	56.118128394932199	427882, адрес УИК и помещения для голосования: Удмуртская Республика, Алнашский район, д.Варали., ул. Центральная (здание Дома марийской культуры), 55	Россия, республика Удмуртская, Алнашский район, село Удмуртское Гондырево	0101000020E6100000B935E9B644204A40F65E7CD11E0F4C40
6233	7	65	1333	56408	\N	\N	56.121310000000001	"Удмуртская Республика, Алнашский район, д.Удм.Гондырево, МОУ ""Удмурт-Гондыревская СОШ"""		0101000020E61000005419C6DD20204A40C1560916870F4C40
6235	7	65	1333	15452	52854	\N	56.259672999999999	"Удмуртская Республика, Алнашский район, д.Удмуртский Тоймобаш, МОУ ""Удмурттоймобашская СОШ"", Малая, 3"		0101000020E6100000A46C91B41B3B4A40BD5301F73C214C40
6238	7	65	1333	58441	\N	\N	56.219646186146697	427891, адрес УИК и помещения для голосования: Удмуртская Республика, Алнашский район, д.Чем.Куюк, ул. Школьная (здание школы), 1	Россия, республика Удмуртская, Алнашский район, село Татарский Тоймобаш	0101000020E6100000CC0A45BA9F3D4A403E59315C1D1C4C40
6236	7	65	1333	15539	\N	\N	56.254652	Удмуртская Республика, Алнашский район, д.Сям-Какси, Сям-Каксинский СДД		0101000020E6100000787DE6AC4F2D4A4035EECD6F98204C40
6232	7	65	1333	15334	52730	\N	56.163137999999996	"Удмуртская Республика, Алнашский район, д.Старый Утчан, МОУ ""Староутчанская СОШ"", Молодежная, 2"		0101000020E610000023D74D29AF2B4A400F5EBBB4E1144C40
6215	7	65	1333	14495	\N	\N	56.187646000000001	Удмуртская Республика, Алнашский район, д.Старая Шудья, Старо-Шудьинский СДД		0101000020E61000004D4BAC8C46464A40D49CBCC804184C40
6214	7	65	1333	14487	52940	\N	56.166837000000001	Удмуртская Республика, Алнашский район, д.Новый Утчан, Ново-Утчанский СДД, Поперечная, 4		0101000020E610000086376BF0BE304A40A26131EA5A154C40
6237	7	65	1333	15553	52829	\N	56.299954999999997	"427892, Удмуртская Республика, Алнашский район, д.Нижний Сырьез, проезд Молодежный (здание школы), д.3, адрес УИК: пр-д Молодежный (здание ад-и МО ""Писеевское"")"		0101000020E6100000EECEDA6D17464A40C6A2E9EC64264C40
6227	7	65	1333	15076	53171	\N	56.107067000000001	"Удмуртская Республика, Алнашский район, д.Нижнее Котнырево, МОУ ""Котныревская СОШ"", Новая, 1"		0101000020E610000068CA4E3FA8334A408CBD175FB40D4C40
6228	7	65	1333	15142	52729	\N	56.085822	"Удмуртская Республика, Алнашский район, с.Нижнее Асаново, 427880, МОУ ""Асановская СОШ"", М.Крылова"		0101000020E610000047AAEFFCA2404A407FA31D37FC0A4C40
6225	7	65	1333	14975	52728	\N	56.044528	"Удмуртская Республика, Алнашский район, д.Муважи, МОУ ""Муважинская СОШ"", Фестивальная, 13"		0101000020E6100000D505BCCCB0594A40CEE0EF17B3054C40
6222	7	65	1333	14861	\N	\N	56.152163999999999	Удмуртская Республика, Алнашский район, д.Ляли, Лялинский СДД		0101000020E6100000390EBC5AEE664A4074D0251C7A134C40
6219	7	65	1333	14679	\N	\N	56.187761992372003	"Удмуртская Республика, Алнашский район, д.Кузюмово, МОУ ""Кузюмовская НОШ"""	Россия, республика Удмуртская, Алнашский район, село Кузюмово	0101000020E610000006836BEEE85D4A403DB7D09508184C40
6223	7	65	1333	14888	52658	\N	56.072820999999998	"Удмуртская Республика, Алнашский район, д.Кузебаево, МОУ ""Кузебаевская СОШ"", Центральная, 50"		0101000020E6100000F91400E3195A4A4023BBD23252094C40
6224	7	65	1333	14967	\N	\N	56.137369999999997	"Удмуртская Республика, Алнашский район, д.Варзибаш, МОУ ""Варзибашская школа-детский сад"","		0101000020E61000009085E81038524A40CBB9145795114C40
6221	7	65	1333	14775	\N	\N	56.126959999999997	"Удмуртская Республика, Алнашский район, с.Варзи-Ятчи, Клуб ООО ""Санатоий Варзи-Ятчи"""	Россия, республика Удмуртская, Алнашский район, село Варзи-Ятчи	0101000020E6100000F7ADD689CB654A4038F3AB3940104C40
6220	7	65	1333	14775	\N	\N	56.126959999999997	Удмуртская Республика, Алнашский район, с.Варзи-Ятчи, Варзи-Ятчинский СКЦ		0101000020E6100000F7ADD689CB654A4038F3AB3940104C40
6226	7	65	1333	15039	\N	\N	56.078227844942099	Удмуртская Республика, Алнашский район, д.Байтеряково, Байтеряковский СКЦ	Россия, республика Удмуртская, Алнашский район, село Байтеряково	0101000020E6100000B891B245D2364A40D5D00660030A4C40
6229	7	65	1333	56386	52873	\N	56.073269070944697	"427885, Удмуртская Республика, Алнашский район, пос.Асановский совхоз-техникум, ул.Школьная (здание средней школы), д.21, адрес УИК: ул.Центральная (здание адм-и МО ""Техникумовское""), 3"	Россия, республика Удмуртская, Алнашский район, село Асановский	0101000020E6100000A114ADDC0B4A4A40C367EBE060094C40
6216	7	65	1333	14302	\N	\N	56.186730324810298	427880, адрес УИК и помещения для голосования: Удмуртская Республика, Алнашский район, д.Казаково., ул.Лесная (здание детского сада), 20	Россия, республика Удмуртская, Алнашский район, село Алнаши	0101000020E610000054FEB5BC723D4A404E97C5C4E6174C40
6213	7	65	1333	14302	52392	\N	56.178854000000001	Удмуртская Республика, Алнашский район, с.Алнаши, Алнашский ДДТ, Комсомольская, 4		0101000020E6100000DB31755776414A40206118B0E4164C40
6212	7	65	1333	14302	52392	\N	56.178854000000001	Удмуртская Республика, Алнашский район, с.Алнаши, ЦКиИ, Комсомольская, 3		0101000020E6100000DB31755776414A40206118B0E4164C40
6211	7	65	1333	14302	52392	\N	56.178854000000001	Удмуртская Республика, Алнашский район, с.Алнаши, РДК, Комсомольская, 6		0101000020E6100000DB31755776414A40206118B0E4164C40
22593	7	61	659	9917	66172	\N	53.931567000000001	Кубагушево, Куяшевская, 36		0101000020E6100000234BE658DE5B4D40348463963DF74A40
6231	7	65	1333	14302	52851	\N	56.178854000000001	427885, Удмуртская Республика, Алнашский район, ст.Алнаши, ул.Лесная (здание основной школы), д.6, адрес УИК: ул.Мира (здание сельского дома досуга), 2		0101000020E6100000DB31755776414A40206118B0E4164C40
6218	7	65	1333	14662	\N	\N	56.190907000000003	Удмуртская Республика, Алнашский район, д.Азаматово, Азаматовский СКЦ		0101000020E610000091D0967329504A40EBC9FCA36F184C40
94253	7	64	\N	61544	79367	\N	55.945274519101702	Республика Татарстан (Татарстан), Высокогорский муниципальный район, пос.Озерный, ул.Садовая, д.3	Россия	0101000020E610000005FC1A4982844840FB5C6DC5FEF84B40
94170	7	64	\N	61375	79072	\N	55.750469247824597	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, пос.им.Кирова, ул.Центральная, д.19	Россия, республика Татарстан, поселок им. Кирова	0101000020E61000002EE3A6069A774840B7D4415E0FE04B40
94044	7	64	\N	61430	79167	\N	54.542476999999998	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.ж/д ст. Акбаш, ул.Школьная, д.7	Россия, республика Татарстан, Бугульма городской округ	0101000020E610000081221631EC684A4085EAE6E26F454B40
1305	7	64	\N	61272	78051	\N	55.6409711293553	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Шильнебаш, ул.60 лет Октября, д.2		0101000020E61000007C60C77F813E4A409B5775560BD24B40
1405	7	64	\N	3607	11620	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, Энгельса улица, д.78		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1402	7	64	\N	3607	11620	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Энгельса, д.14А		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1393	7	64	\N	3607	11607	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Чернышевского, д.167А		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1407	7	64	\N	3607	11626	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Полющенкова, д.15		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1401	7	64	\N	3607	11619	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Зеленая, д.2		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1399	7	64	\N	3607	11616	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Заводская, д.13		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1380	7	64	\N	3607	11590	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Вотякова, д.23		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1400	7	64	\N	3607	11618	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Виктора Ногина, д.97		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1395	7	64	\N	3607	11610	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.40 лет Победы, д.34		0101000020E6100000003B376DC651494003EB387EA8AE4B40
417	7	64	\N	40967	12177	\N	55.679397000000002	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Усады, ул.Дорожная, д.4	Россия, республика Татарстан, село Усады	0101000020E610000097715303CD9B484011001C7BF6D64B40
94171	7	64	\N	29378	78430	\N	55.776440999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Печищи, ул.Кирова, д.62		0101000020E6100000698B6B7C2679484003232F6B62E34B40
896	7	64	\N	12275	11127	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Линейная, д.12		0101000020E610000053CC41D0D1664940DD4598A25C364B40
895	7	64	\N	12275	11126	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Заводская, д.1		0101000020E610000053CC41D0D1664940DD4598A25C364B40
149	7	64	\N	8108	10148	\N	55.895983999999999	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, п.Новониколаевский, ул.Центральная, д.13	Россия, республика Татарстан, поселок Новониколаевский	0101000020E610000021CEC3094C7B4840A0DE8C9AAFF24B40
150	7	64	\N	8191	12253	\N	55.867971043740503	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Новая Тура, ул.Центральная, д.10а	Россия, республика Татарстан, село Новая Тура	0101000020E61000001B683EE76E6B48402E7079AC19EF4B40
94209	7	64	\N	31212	79114	\N	55.694561	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Нижний Услон, ул.Дзержинского, д.6		0101000020E6100000F513CE6E2D7B4840DD09F65FE7D84B40
1267	7	64	\N	61520	79286	\N	55.614170000000001	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Нефтебаза, ул.Центральная, д.21	Россия	0101000020E61000003694DA8B683B4A409817601F9DCE4B40
706	7	64	\N	1104	11286	\N	55.829248999999997	Республика Татарстан (Татарстан), город Набережные Челны, ул.Шамиля Усманова, д.5	Россия, республика Татарстан, Казань, улица Шамиля Усманова, 5	0101000020E6100000419E5DBEF5894840CF9ECBD424EA4B40
743	7	64	\N	1104	11035	\N	55.742062188537297	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Шамиля Усманова, д.139	Россия, республика Татарстан, Набережные Челны, улица Ш. Усманова	0101000020E610000000AAB8718B314A405BCD3AE3FBDE4B40
707	7	64	\N	1104	11035	\N	55.769693524425001	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, ул.Шамиля Усманова, д.19	Россия, республика Татарстан, Набережные Челны, улица Ш. Усманова	0101000020E61000005264ADA1D4364A40B6F63E5585E24B40
704	7	64	\N	1104	11035	\N	55.755181507606999	Республика Татарстан (Татарстан), город Набережные Челны, ул.Шамиля Усманова, д.10	Россия, республика Татарстан, Набережные Челны, улица Ш. Усманова	0101000020E6100000C49448A297334A409143C4CDA9E04B40
768	7	64	\N	1104	11054	\N	55.741233005237703	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Шамиля Усманова, д.110		0101000020E6100000CA17B49080314A40A5DB12B9E0DE4B40
750	7	64	\N	1104	11054	\N	55.736178841239798	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Шамиля Усманова, д.128а		0101000020E610000011C5E40D30314A4041800C1D3BDE4B40
749	7	64	\N	1104	11054	\N	55.7464620111488	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул. Шамиля Усманова, д.128а		0101000020E6100000BA30D28BDA314A4077DA1A118CDF4B40
692	7	64	\N	1104	532	\N	55.693536000000002	Республика Татарстан (Татарстан), город Набережные Челны, ул.Хади Такташа, д.35	Россия, республика Татарстан, Набережные Челны, улица Хади Такташа	0101000020E6100000145E82531F2C4A40A14CA3C9C5D84B40
751	7	64	\N	1104	77570	\N	55.768433522193398	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Татарстан, д.14	Россия, республика Татарстан, Набережные Челны, 48-й квартал, 14	0101000020E6100000B760A92EE0354A403691990B5CE24B40
741	7	64	\N	1104	932	\N	55.741707177689399	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Беляева Раиса, д.60	Россия, республика Татарстан, Набережные Челны, улица Раиса Беляева	0101000020E61000002FBFD364C62F4A406D1B4641F0DE4B40
709	7	64	\N	1104	11876	\N	55.736197001089401	423832, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), г.Набережные Челны, Центральный район, ул.Касимова (здание школы №53), д.2	Россия, республика Татарстан, Набережные Челны, улица Касымова	0101000020E61000005A63D009A12F4A40E7340BB43BDE4B40
725	7	64	\N	1104	1044	\N	55.737729999999999	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, ул.40 Лет Победы, д.29		0101000020E610000056D5CBEF34374A4098A3C7EF6DDE4B40
716	7	64	\N	1104	79290	\N	55.741678	423812, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), г.Набережные Челны, Центральный район, пр-т Мира (здание школы №31), д.29		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
681	7	64	\N	1104	11005	\N	55.741678	Республика Татарстан (Татарстан), город Набережные Челны, пер.Энергетиков, д.1		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
641	7	64	\N	1104	11851	\N	55.741678	Республика Татарстан (Татарстан), город Набережные Челны, пер.Юности, д.1	Россия, республика Татарстан, Набережные Челны, Мира проспект	0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
729	7	64	\N	1104	11023	\N	55.741678	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, б-р Энтузиастов, д.2		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
764	7	64	\N	1104	11030	\N	55.741678	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Автомобилестроителей, д.5		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
691	7	64	\N	1104	11887	\N	55.694164516922903	Республика Татарстан (Татарстан), город Набережные Челны, б-р Тинчурина, д.2		0101000020E6100000B7F1272A1B284A4090831266DAD84B40
688	7	64	\N	1104	11010	\N	55.740748802427397	Республика Татарстан (Татарстан), город Набережные Челны, б-р Корчагина, д.2		0101000020E6100000EC4CA1F31A374A40B9C5FCDCD0DE4B40
763	7	64	\N	1104	11325	\N	55.741678	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Автомобилестроителей, д.9	Россия, республика Татарстан, Набережные Челны, Мира проспект	0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
720	7	64	\N	1104	11878	\N	55.741678	423812, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), г.Набережные Челны, Центральный район, б-р 60 Лет Октября (здание школы №35), д.10		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
689	7	64	\N	1104	499	\N	55.690196999999998	Республика Татарстан (Татарстан), город Набережные Челны, б-р Ямашева, д.4/14А		0101000020E6100000BB6246787B264A400E66136058D84B40
759	7	64	\N	1104	77579	\N	55.7550164468365	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Юных Ленинцев, д.7	Россия, республика Татарстан, Набережные Челны, 27-й квартал, 7	0101000020E6100000033E3F8C10384A4076FA415DA4E04B40
762	7	64	\N	1104	77578	\N	55.757414296833097	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Юных Ленинцев, д.3	Россия, республика Татарстан, Набережные Челны, 26-й квартал, 3	0101000020E610000001F9122A38384A402AC423F1F2E04B40
732	7	64	\N	1104	1148	\N	55.746578	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, б-р Школьный, д.2		0101000020E6100000F12900C633344A40E0F42EDE8FDF4B40
757	7	64	\N	1104	1349	\N	55.7508310805419	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Шишкинсикй, д.26	Россия, республика Татарстан, Набережные Челны, Шишкинский бульвар	0101000020E6100000A0C03BF9F4364A4057E9EE3A1BE04B40
756	7	64	\N	1104	1349	\N	55.748821999999997	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Шишкинский, д.26		0101000020E6100000E6AC4F3926374A403D433866D9DF4B40
745	7	64	\N	1104	1349	\N	55.748821999999997	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Шишкинский, д.11		0101000020E6100000E6AC4F3926374A403D433866D9DF4B40
758	7	64	\N	1104	77561	\N	55.749221386014199	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Шишкинский, д.9	Россия, республика Татарстан, Набережные Челны, 29-й квартал, 9	0101000020E610000095B9F94674374A40FB3C4679E6DF4B40
765	7	64	\N	1104	11032	\N	55.755671580812702	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Шамиля Усманова, д.96		0101000020E6100000E770ADF6B0334A405F402FDCB9E04B40
746	7	64	\N	1104	11013	\N	55.741136165158302	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Шамиля Усманова, д.82	Россия, республика Татарстан, Набережные Челны, улица Ш. Усманова	0101000020E6100000C9AF1F6283314A40B2F1608BDDDE4B40
771	7	64	\N	1104	835	\N	55.751490917836399	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Чулман, д.112	Россия, республика Татарстан, Набережные Челны, Чулман проспект	0101000020E6100000E7FBA9F1D2314A40821E6ADB30E04B40
767	7	64	\N	1104	835	\N	55.751030952199599	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, пр-т Чулман, д.112	Россия, республика Татарстан, Набережные Челны, Чулман проспект	0101000020E6100000C0E78711C2314A401EA4A7C821E04B40
747	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, пр-т Чулман, д.136		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
739	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Чулман, д.56		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
738	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Чулман, д.62		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
737	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Чулман, д.72		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
736	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Чулман, д.78		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
735	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Чулман, д.88		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
713	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Чулман, д.38		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
712	7	64	\N	1104	835	\N	55.751503	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Чулман, д.34		0101000020E6100000A9BF5E61C1314A4046EC134031E04B40
702	7	64	\N	1104	75464	\N	55.698568999999999	Республика Татарстан (Татарстан), город Набережные Челны, пос.Орловка, ул.Центральная, д.7		0101000020E6100000174A26A776284A40ED7F80B56AD94B40
766	7	64	\N	1104	1410	\N	55.755575999999998	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Цветочный, д.21		0101000020E61000000E84640113364A403DD2E0B6B6E04B40
748	7	64	\N	1104	1410	\N	55.7555985050885	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, б-р Цветочный, д.15	Россия, республика Татарстан, Набережные Челны, Цветочный бульвар	0101000020E61000007FDAA84E07364A40F5F1D077B7E04B40
693	7	64	\N	1104	77294	\N	55.693796854139499	Республика Татарстан (Татарстан), город Набережные Челны, ул.Хади Такташа, д.27	Россия, республика Татарстан, Набережные Челны, улица Хади Такташа	0101000020E6100000DD5CFC6D4F2C4A400E881057CED84B40
769	7	64	\N	1104	77554	\N	55.767156089746898	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, ул.Татарстан, д.27	Россия, республика Татарстан, Набережные Челны, улица Татарстан	0101000020E6100000C68A1A4CC3364A401077F52A32E24B40
744	7	64	\N	1104	1343	\N	55.753438000000003	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, пр-т Сююмбике, д.103		0101000020E6100000ED82C13577344A4026C808A870E04B40
727	7	64	\N	1104	77332	\N	55.734521813835599	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, б-р Строителей, д.1	Россия, республика Татарстан, Набережные Челны, 4-й квартал, 1	0101000020E610000058E1968FA4344A40A41820D104DE4B40
728	7	64	\N	1104	77555	\N	55.733583503391998	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, б-р Строителей, д.9	Россия, республика Татарстан, Набережные Челны, 5-й квартал, 9	0101000020E610000008B0C8AF1F344A40376F9C14E6DD4B40
699	7	64	\N	1104	77552	\N	55.710464000000002	Республика Татарстан (Татарстан), город Набережные Челны, пос.Элеваторная Гора, ул.Спартаковская, д.6		0101000020E6100000651C23D9232A4A40207EFE7BF0DA4B40
733	7	64	\N	1104	1166	\N	55.744804000000002	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, б-р Солнечный, д.2		0101000020E6100000B85A272EC7334A400AF7CABC55DF4B40
703	7	64	\N	1104	11012	\N	55.6636837823485	Республика Татарстан (Татарстан), город Набережные Челны, ул.Сармановский тракт, д.36		0101000020E610000016BD5301F72C4A407270E998F3D44B40
677	7	64	\N	1104	75460	\N	55.693485000000003	Республика Татарстан (Татарстан), город Набережные Челны, ул.Сайдашева, д.10		0101000020E6100000CE8B135FED2C4A401FA2D11DC4D84B40
698	7	64	\N	1104	618	\N	55.699609000000002	Республика Татарстан (Татарстан), город Набережные Челны, пер.Садовый, д.4		0101000020E6100000F321A81ABD2C4A405F7EA7C98CD94B40
93098	7	64	\N	134	2684	\N	55.851930000000003	Республика Татарстан (Татарстан), город Казань, Кировский район, пер.Осиновский, д.8		0101000020E610000045662E70797248409B3DD00A0CED4B40
708	7	64	\N	1104	77331	\N	55.734166999999999	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, ул.Раскольникова, д.33А		0101000020E6100000BD546CCCEB2E4A40B6662B2FF9DD4B40
734	7	64	\N	1104	11901	\N	55.735854000000003	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, ул. Беляева Раиса, д.26		0101000020E6100000855FEAE74D334A40BE50C07630DE4B40
726	7	64	\N	1104	11901	\N	55.733420526396301	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, ул.Беляева Раиса, д.3	Россия, республика Татарстан, Набережные Челны, улица Раиса Беляева	0101000020E610000038A4518193334A408D9944BDE0DD4B40
697	7	64	\N	1104	75365	\N	55.700206999999999	Республика Татарстан (Татарстан), город Набережные Челны, ул.Низаметдинова, д.28		0101000020E610000011902FA1822D4A4013B70A62A0D94B40
705	7	64	\N	1104	11014	\N	55.726180650531099	Республика Татарстан (Татарстан), город Набережные Челны, ул.Нариманова, д.44	Россия, республика Татарстан, Набережные Челны	0101000020E6100000A4C16D6DE13D4A4000FDBE7FF3DC4B40
679	7	64	\N	1104	352	\N	55.677371999999998	Республика Татарстан (Татарстан), город Набережные Челны, пр.Мусы Джалиля, д.14		0101000020E6100000BCCADAA678244A40F19C2D20B4D64B40
722	7	64	\N	1104	993	\N	55.736229999999999	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Московский, д.95		0101000020E61000000C01C0B167354A40C32ADEC83CDE4B40
760	7	64	\N	1104	859	\N	55.744008999999998	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, пр-т Мира, д.94		0101000020E6100000FD4B529962344A40FF76D9AF3BDF4B40
730	7	64	\N	1104	859	\N	55.744008999999998	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Мира, д.54		0101000020E6100000FD4B529962344A40FF76D9AF3BDF4B40
714	7	64	\N	1104	859	\N	55.744008999999998	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Мира, корп.V	Россия, республика Татарстан, Набережные Челны, Мира проспект	0101000020E6100000FD4B529962344A40FF76D9AF3BDF4B40
715	7	64	\N	1104	77540	\N	55.7437840491584	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Мира, д.29	Россия, республика Татарстан, Набережные Челны, Мира проспект	0101000020E61000000D6C956071344A40DFA4695034DF4B40
695	7	64	\N	1104	79366	\N	55.698603370917503	"423806, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), г.Набережные Челны, Комсомольский район, ул.Маршала Жукова (здание лицея ""КАЛКАН""), д.36"	Россия, республика Татарстан, Набережные Челны, 16-й Гидростроителей квартал, 36	0101000020E6100000834C3272162C4A4099F1B6D26BD94B40
177	7	64	\N	1104	75459	\N	55.697015999999998	Республика Татарстан (Татарстан), город Набережные Челны, ул.Комарова, д.23		0101000020E610000043FF04172B2C4A40F564FED137D94B40
723	7	64	\N	1104	11900	\N	55.717596870403	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, б-р Кол Гали, д.22	Россия, республика Татарстан, Набережные Челны, Колгали бульвар	0101000020E6100000732F302B14334A40965AEF37DADB4B40
711	7	64	\N	1104	11865	\N	55.738206638685902	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, ул.Касимова, д.6	Россия, республика Татарстан, Набережные Челны, Мира проспект	0101000020E61000008995D1C8E7334A40D25625917DDE4B40
628	7	64	\N	1104	328	\N	55.672772999999999	Республика Татарстан (Татарстан), город Набережные Челны, пр.Казанский, д.17		0101000020E6100000FF0758AB76254A40DF50F86C1DD64B40
694	7	64	\N	1104	75461	\N	55.694012999999998	Республика Татарстан (Татарстан), город Набережные Челны, ул.Железнодорожников, д.65		0101000020E610000085CC9541B52D4A40DAFF006BD5D84B40
724	7	64	\N	1104	1029	\N	55.72851	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Дружбы Народов, д.9А		0101000020E6100000C0EC9E3C2C324A408C67D0D03FDD4B40
675	7	64	\N	1104	11003	\N	55.741678	Республика Татарстан (Татарстан), город Набережные Челны, ул.Грина, д.9		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
731	7	64	\N	1104	1130	\N	55.748488000000002	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, б-р Главмосстроевцев, д.2		0101000020E6100000251FBB0B94344A4067B96C74CEDF4B40
685	7	64	\N	1104	75469	\N	55.686264000000001	Республика Татарстан (Татарстан), город Набережные Челны, ул.Гидростроителей, д.5		0101000020E610000038BBB54C86254A400936AE7FD7D74B40
676	7	64	\N	1104	75465	\N	55.670529000000002	Республика Татарстан (Татарстан), город Набережные Челны, ул.Гвардейская, д.3		0101000020E610000006802A6EDC244A408202EFE4D3D54B40
687	7	64	\N	1104	387	\N	55.684767000000001	Республика Татарстан (Татарстан), город Набережные Челны, ул.Набережная Тукая, д.53А	Россия, республика Татарстан, Набережные Челны, Габдуллы Тукая набережная	0101000020E6100000DA20938C9C274A40A530EF71A6D74B40
684	7	64	\N	1104	387	\N	55.684767000000001	Республика Татарстан (Татарстан), город Набережные Челны, ул.Набережная Тукая, д.43		0101000020E6100000DA20938C9C274A40A530EF71A6D74B40
683	7	64	\N	1104	387	\N	55.684767000000001	Республика Татарстан (Татарстан), город Набережные Челны, ул.Набережная Тукая, д.33		0101000020E6100000DA20938C9C274A40A530EF71A6D74B40
682	7	64	\N	1104	387	\N	55.684767000000001	Республика Татарстан (Татарстан), город Набережные Челны, ул.Набережная Тукая, д.31		0101000020E6100000DA20938C9C274A40A530EF71A6D74B40
753	7	64	\N	1104	77814	\N	55.738987463815597	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, пр-т Вахитова, д.23	Россия, республика Татарстан, Набережные Челны, 54-й квартал, 23	0101000020E61000002828452BF7364A40A795422097DE4B40
755	7	64	\N	1104	77572	\N	55.7486042478454	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, пр-т Вахитова, д.2	Россия, республика Татарстан, Набережные Челны, 30-й квартал, 2	0101000020E61000004E29AF95D0354A40D0D38041D2DF4B40
700	7	64	\N	1104	77559	\N	55.703716188160897	Республика Татарстан (Татарстан), город Набережные Челны, б-р Бумажников, д.3	Россия, республика Татарстан, Набережные Челны, 17а Гидростроителей квартал, 3	0101000020E6100000D80C7041B62A4A4002D6AA5D13DA4B40
742	7	64	\N	1104	12018	\N	55.737453131344402	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, пр-т Беляев Раиса, д.60		0101000020E61000004B72C0AE26334A4026AB22DC64DE4B40
690	7	64	\N	1104	11006	\N	55.742298230182797	Республика Татарстан (Татарстан), город Набережные Челны, ул.Батенчука, д.9/10	Россия, республика Татарстан, Набережные Челны, 53-й квартал, 1	0101000020E6100000645930F147374A406FF1F09E03DF4B40
686	7	64	\N	1104	11006	\N	55.741678	Республика Татарстан (Татарстан), город Набережные Челны, ул.Батенчука, д.21		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
752	7	64	\N	1104	1477	\N	55.752530999999998	Республика Татарстан (Татарстан), г.Набережные Челны, Автозаводский район, пр-т Автозаводский, д.39		0101000020E610000065E42CEC69374A40F31C91EF52E04B40
718	7	64	\N	1104	11872	\N	55.741678	Республика Татарстан (Татарстан), город Набережные Челны, Центральный район, ул.60 Лет Октября, д.10		0101000020E6100000DE567A6D36344A40D314014EEFDE4B40
449	7	64	\N	21814	10696	\N	54.592335292242097	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Степана Разина, 1	Россия, республика Татарстан, Лениногорск	0101000020E610000072A774B0FE394A4059A31EA2D14B4B40
94208	7	64	\N	61420	79155	\N	55.670513785720601	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Ключищи, ул.Центральная, д.8		0101000020E61000007F677BF4867B48404CC11A67D3D54B40
94073	7	64	\N	61523	79297	\N	55.434598999999999	423230, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.г.т.Карабаш, ул.Вахитова (здание Дома Культуры), д.17		0101000020E610000039EE940ED6354940E9EFA5F0A0B74B40
93133	7	64	\N	134	\N	\N	55.815916654257499	Республика Татарстан (Татарстан), город Казань, Кировский район, станция Юдино, технический кабинет грузового депо	Россия, республика Татарстан, Казань, Кировский район	0101000020E6100000D449B6BA9C7248400EA0DFF76FE84B40
93101	7	64	\N	134	\N	\N	55.832089756922102	Республика Татарстан (Татарстан), город Казань, Кировский район, озеро Лебяжье, д.7		0101000020E61000009E5DBEF56179484011AAD4EC81EA4B40
562	7	64	\N	134	15339	\N	55.780921999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, д.Абалачи, ул.Центральная, д.35	Россия, республика Татарстан, Казань, Вахитовский район, улица Центральная, 35а	0101000020E6100000CF8250DEC79348400B5D8940F5E34B40
94241	7	64	\N	134	78520	\N	55.777187769384398	Республика Татарстан (Татарстан), Высокогорский муниципальный район, пос.Дачное, ул.Центральная, д.2	Россия, республика Татарстан, Казань, Вахитовский район, улица Центральная	0101000020E61000005FCFD72C97934840FD6B79E57AE34B40
93198	7	64	\N	134	3897	\N	55.839379999999998	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Фатыха Амирхана, д.111	Россия, республика Татарстан, Казань, улица Фатыха Амирхана, 111	0101000020E6100000738236397C9048404F75C8CD70EB4B40
93169	7	64	\N	134	3631	\N	55.840026999999999	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Рахимова, д.29	Россия, республика Татарстан, Казань, улица Рахимова, 29	0101000020E6100000056B9C4D47844840E560360186EB4B40
93286	7	64	\N	134	4974	\N	55.859872000000003	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Парковая, д.16	Россия, республика Татарстан, Казань, улица Парковая, 16	0101000020E6100000E066F162619C4840815F234910EE4B40
93105	7	64	\N	134	2782	\N	55.827418999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Окольная, д.25	Россия, республика Татарстан, Казань, улица Окольная, 25	0101000020E61000003FFD67CD8F854840658BA4DDE8E94B40
93104	7	64	\N	134	2782	\N	55.824354	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Окольная, д.9	Россия, республика Татарстан, Казань, улица Окольная, 9	0101000020E610000016DA39CD02854840D4298F6E84E94B40
93117	7	64	\N	134	78413	\N	55.811187505087197	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Односторонка Гривки, д.48	Россия, республика Татарстан, Казань, улица Односторонняя Гривка, 40	0101000020E61000007E8AE3C0AB8B48402E742502D5E74B40
93278	7	64	\N	134	4997	\N	55.870137	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Начальная, д.6	Россия, республика Татарстан, Казань, улица Начальная, 6	0101000020E610000079E57ADB4C9D4840100533A660EF4B40
93036	7	64	\N	134	1785	\N	55.853344062205402	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Лядова, д.16	Россия, республика Татарстан, Казань, улица Лядова, 16	0101000020E6100000B7CF2A33A5894840711E4E603AED4B40
93056	7	64	\N	134	2053	\N	55.793024000000003	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Кремлевская, д.25/22	Россия, республика Татарстан, Казань, улица Кремлевская, 25/22	0101000020E6100000C7BDF90D138F4840B87878CF81E54B40
55304	7	63	\N	1332	54501	\N	54.212255999999996	Республика Мордовия, город Саранск, Пролетарский район, Миронова, 8		0101000020E610000072C3EFA65B8E46409C3061342B1B4B40
93209	7	64	\N	134	4168	\N	55.772046000000003	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Красного Пожарника, д.1а	Россия, республика Татарстан, Казань, улица Красного Пожарника, 1а	0101000020E61000001C5F7B66498E4840FA804067D2E24B40
93142	7	64	\N	134	3273	\N	55.822806999999997	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Короленко, д.26	Россия, республика Татарстан, Казань, улица Короленко, 26	0101000020E6100000AB402D060F8D4840BEF561BD51E94B40
93066	7	64	\N	134	59005	\N	55.793655263136202	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Горького, д.29/19	Россия, республика Татарстан, Казань, улица Горького, 29	0101000020E6100000D2FBC6D79E91484048A7AE7C96E54B40
93183	7	64	\N	134	3347	\N	55.836620000000003	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Восстания, д.8А	Россия, республика Татарстан, Казань, улица Восстания, 8а	0101000020E61000006B63EC84978C4840FB96395D16EB4B40
93042	7	64	\N	134	1865	\N	55.866388999999998	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Беломорская, д.104	Россия, республика Татарстан, Казань, улица Беломорская, 104	0101000020E61000009A94826E2F8748409C4EB2D5E5EE4B40
93163	7	64	\N	134	3543	\N	55.828631999999999	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Бакалейная, д.41	Россия, республика Татарстан, Казань, улица Бакалейная, 41	0101000020E6100000541C075E2D874840A435069D10EA4B40
93219	7	64	\N	134	4295	\N	55.746583000000001	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Актайская, д.5	Россия, республика Татарстан, Казань, улица Актайская, 5	0101000020E61000003F19E3C3EC914840F25F200890DF4B40
93160	7	64	\N	134	3518	\N	55.838313999999997	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Академика Королева, д.47	Россия, республика Татарстан, Казань, улица Академика Королева, 47	0101000020E610000071033E3F8C884840B4E386DF4DEB4B40
93255	7	64	\N	134	75232	\N	55.7794953474734	Республика Татарстан (Татарстан), город Казань, Советский район, проспект Альберта Камалеева, д.22	Россия, республика Татарстан, Казань, улица Толбухина	0101000020E6100000B83D4162BB954840A032FE7DC6E34B40
93148	7	64	\N	134	77607	\N	55.750111004586202	Республика Татарстан (Татарстан), город Казань, Приволжский район, пр.Победы, д.71А	Россия, республика Татарстан, Казань, Приволжский район, улица Рихарда Зорге, 71а	0101000020E6100000B6F81400E39B484057AF22A303E04B40
93192	7	64	\N	134	3316	\N	55.829355	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, пр.Ямашева, д.100А	Россия, республика Татарстан, Казань, Ямашева проспект, 100а	0101000020E610000010E7E104A693484015E3FC4D28EA4B40
93144	7	64	\N	134	3316	\N	55.826543999999998	Республика Татарстан (Татарстан), город Казань, Московский район, пр.Ямашева, д.8	Россия, республика Татарстан, Казань, Ямашева проспект, 8	0101000020E6100000CB863595458B48403E5A9C31CCE94B40
93217	7	64	\N	134	4249	\N	55.727916999999998	Республика Татарстан (Татарстан), город Казань, Приволжский район, пер.Якты Юл, д.4	Россия, республика Татарстан, Казань, Якты Юл переулок, 4	0101000020E61000004DF73AA92F934840E9995E622CDD4B40
93240	7	64	\N	134	77882	\N	55.745711	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Ю.Фучика, д.40		0101000020E61000008C2FDAE3859C48403CA2427573DF4B40
93239	7	64	\N	134	77882	\N	55.741433999999998	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Ю.Фучика, д.26		0101000020E6100000126C5CFFAE9B48403C122F4FE7DE4B40
93236	7	64	\N	134	77882	\N	55.755083999999997	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Ю.Фучика, д.105а		0101000020E6100000F816D68D779D4840CEDDAE97A6E04B40
93212	7	64	\N	134	75407	\N	55.731526000000002	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Южно-Промышленная, д.3		0101000020E61000009D853DEDF08B48403C16DBA4A2DD4B40
93076	7	64	\N	134	77763	\N	55.773049	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Эсперанто, д.48		0101000020E6100000CBB91457959148404E9A0645F3E24B40
93152	7	64	\N	134	77942	\N	55.826898	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Энергетиков, д.10		0101000020E6100000841266DAFE8948405C902DCBD7E94B40
93111	7	64	\N	134	78576	\N	55.807886000000003	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Энгельса, д.12		0101000020E610000079944A7842894840B972F6CE68E74B40
93109	7	64	\N	134	77857	\N	55.817329999999998	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Шульгина, д.19		0101000020E61000004C6BD3D85E8748401405FA449EE84B40
93115	7	64	\N	134	77913	\N	55.807693	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Шоссейная, д.24		0101000020E6100000AD3594DA8B8A4840A41AF67B62E74B40
93804	7	64	\N	134	78566	\N	55.743161999999998	Республика Татарстан (Татарстан), Апастовский район, пжд.ст.Каратун, ул.Школьная, д.2а		0101000020E6100000B2BE81C98D924840A2D0B2EE1FDF4B40
93979	7	64	\N	134	79191	\N	55.743161999999998	Республика Татарстан (Татарстан), Балтасинский муниципальный район, д.Алан, ул.Школьная, д.12		0101000020E6100000B2BE81C98D924840A2D0B2EE1FDF4B40
93215	7	64	\N	134	69441	\N	55.743144412567297	Республика Татарстан (Татарстан), город Казань, Приволжский район, Петровский, ул.Школьная, д.2	Россия, республика Татарстан, Казань, Приволжский район, улица Школьная, 2	0101000020E6100000BFD4CF9B8A924840FC1BB4571FDF4B40
93060	7	64	\N	134	77732	\N	55.777434	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Шигабутдина Марджани, д.26		0101000020E61000003D0AD7A3708F4840346612F582E34B40
93155	7	64	\N	134	68514	\N	55.830984630879698	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Ш.Усманова, д.14	Россия, республика Татарстан, Казань, улица Шамиля Усманова, 14	0101000020E610000077F700DD97894840B83B6BB75DEA4B40
93156	7	64	\N	134	71062	\N	55.831205696351503	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Ш.Усманова, д.30		0101000020E610000012DDB3AED1884840971E4DF564EA4B40
93154	7	64	\N	134	71062	\N	55.8302968950156	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Ш.Усманова, д.25Б	Россия, республика Татарстан, Казань, улица Шамиля Усманова, 25	0101000020E610000054A9D903AD884840C47B0E2C47EA4B40
93153	7	64	\N	134	71062	\N	55.829086793689697	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Ш.Усманова, д.11	Россия, республика Татарстан, Казань, улица Шамиля Усманова	0101000020E61000007EA7C98CB7894840F644D7851FEA4B40
93308	7	64	\N	134	78017	\N	55.763528000000001	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Чишмяле, д.3		0101000020E6100000950D6B2A8B9C484047CA1649BBE14B40
93306	7	64	\N	134	78017	\N	55.762464999999999	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Чишмяле, д.5		0101000020E6100000E867EA758B9C48401DACFF7398E14B40
93207	7	64	\N	134	77576	\N	55.820808999999997	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Чистопольская, д.67		0101000020E610000029232E008D90484098A1F14410E94B40
93200	7	64	\N	134	77576	\N	55.823034	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Чистопольская, д.83		0101000020E6100000C91EA166489348407FBF982D59E94B40
93201	7	64	\N	134	77839	\N	55.824162000000001	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Четаева, д.29		0101000020E61000004391EEE714904840904DF2237EE94B40
584	7	64	\N	134	79101	\N	55.779848999999999	Республика Татарстан (Татарстан), Мензелинский муниципальный район,  с.Аю, ул.Центральная, д.53		0101000020E6100000D26F5F07CE934840BE688F17D2E34B40
94204	7	64	\N	134	79263	\N	55.764928491758603	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, д.им.М.Вахитова, ул.Центральная, д.24	Россия, республика Татарстан, Казань, улица Шарифа Камала	0101000020E6100000747D1F0E128E4840B8E52329E9E14B40
93052	7	64	\N	134	78730	\N	55.912563570422101	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, санаторий Крутушка	Россия, республика Татарстан, Казань, Авиастроительный район, улица Центральная, 5	0101000020E6100000B169A510C8934840E4C0ABE5CEF44B40
502	7	64	\N	134	77623	\N	55.781306999999998	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Камский леспромхоз, ул.Центральная, д.54А		0101000020E6100000CE88D2DEE0934840649126DE01E44B40
93231	7	64	\N	134	75189	\N	55.754033441533899	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Х.Мавлютова, д.15	Россия, республика Татарстан, Казань, Приволжский район, улица Хусаина Мавлютова, 15	0101000020E61000002881CD3978984840698D412784E04B40
93230	7	64	\N	134	75189	\N	55.7504162064767	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Х.Мавлютова, д.34	Россия, республика Татарстан, Казань, Приволжский район, улица Хусаина Мавлютова, 34	0101000020E6100000AE47E17A149848409432A9A10DE04B40
93168	7	64	\N	134	77729	\N	55.842944000000003	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Хлебозаводская, д.3		0101000020E6100000427A8A1C22864840022EC896E5EB4B40
93172	7	64	\N	134	77740	\N	55.876773	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Химиков, д.55		0101000020E6100000630B410E4A824840068200193AF04B40
93170	7	64	\N	134	77740	\N	55.863869000000001	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Химиков, д.11		0101000020E6100000511553E9278248409D83674293EE4B40
93271	7	64	\N	134	77953	\N	55.818463000000001	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Халитова, д.5		0101000020E6100000FA7FD5912399484037FE4465C3E84B40
93279	7	64	\N	134	77992	\N	55.870812999999998	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Советская, д.18	Россия, республика Татарстан, Казань, улица Халезова	0101000020E6100000AD6EF59CF49C484040F7E5CC76EF4B40
93284	7	64	\N	134	77964	\N	55.860832000000002	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Халезова, д.26		0101000020E61000001807978E399B4840D6AC33BE2FEE4B40
93280	7	64	\N	134	77964	\N	55.867106999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Халезова, д.11		0101000020E6100000D998D711879C4840FB90B75CFDEE4B40
93315	7	64	\N	134	78025	\N	55.786313	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Хайдара Бигичева, д.26		0101000020E6100000BF2A172AFF9C4840B7B585E7A5E44B40
93075	7	64	\N	134	77780	\N	55.773380683665302	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Хади Такташа, д.81		0101000020E61000006090F46915914840842C0B26FEE24B40
93216	7	64	\N	134	75413	\N	55.725782000000002	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Ферма-2, Учебный корпус КГАУ		0101000020E61000009A05DA1D529648404303B16CE6DC4B40
93197	7	64	\N	134	77795	\N	55.839652999999998	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Фатыха Амирхана, д.28А		0101000020E6100000A10F96B1A1914840807EDFBF79EB4B40
93190	7	64	\N	134	77795	\N	55.830655	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Фатыха Амирхана, д.14А		0101000020E61000000A647616BD91484023A12DE752EA4B40
54151	7	62	\N	1218	62246	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Соловьева, д. 39		0101000020E6100000628731E9EFEF4740ACE122F774514C40
93188	7	64	\N	134	77795	\N	55.832180999999999	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Фатыха Амирхана, д.55А		0101000020E6100000D3BEB9BF7A90484021AD31E884EA4B40
93082	7	64	\N	134	77778	\N	55.784587000000002	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Товарищеская, д.40б		0101000020E610000098FC4FFEEE934840F2EEC8586DE44B40
93081	7	64	\N	134	77778	\N	55.785663458088699	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Товарищеская, д.32	Россия, республика Татарстан, Казань, улица Товарищеская, 32	0101000020E610000097033DD4B6934840B056ED9A90E44B40
93151	7	64	\N	134	77934	\N	55.825831000000001	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Тверская, д.2А		0101000020E610000079909E22878A4840F18288D4B4E94B40
93059	7	64	\N	134	75390	\N	55.779063999999998	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Татарстан, д.40		0101000020E61000006CAF05BD378E4840D7BE805EB8E34B40
93037	7	64	\N	134	77670	\N	55.856487000000001	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Социалистическая, д.5		0101000020E610000048C2BE9D448A48407E39B35DA1ED4B40
93254	7	64	\N	134	77501	\N	55.808718962065399	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Советская, д.77А	Россия, республика Татарстан, Казань, Советский район, Константиновка микрорайон	0101000020E61000005DC0CB0C1BA14840B153AC1A84E74B40
93053	7	64	\N	134	77574	\N	55.8665913120455	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Симонова, д.17		0101000020E610000019028063CF8A484004013274ECEE4B40
93031	7	64	\N	134	77574	\N	55.865318000000002	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Симонова, д.5		0101000020E610000058C7F143A58B4840F0517FBDC2EE4B40
93272	7	64	\N	134	8208	\N	55.819154797400202	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Сибирский Тракт, д.35	Россия, республика Татарстан, Казань, Сибирский тракт, 35	0101000020E6100000C0EAC891CE9648406DAD2F12DAE84B40
93165	7	64	\N	134	77762	\N	55.825214000000003	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Серова, д.12А		0101000020E6100000350D8AE601884840C619C39CA0E94B40
93241	7	64	\N	134	77894	\N	55.746101000000003	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Сафиуллина, д.56а		0101000020E6100000D2FD9C82FC9C4840A741D13C80DF4B40
93224	7	64	\N	134	77865	\N	55.764550999999997	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Роторная, д.7		0101000020E61000001E19ABCDFF934840E28FA2CEDCE14B40
93235	7	64	\N	134	75199	\N	55.750065432103099	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Р.Зорге, д.71	Россия, республика Татарстан, Казань, Приволжский район, улица Рихарда Зорге, 71	0101000020E6100000EDB94C4D829B4840E76F422102E04B40
93051	7	64	\N	134	75140	\N	55.897815376141097	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, н.п.Кадышево, ул.Зорге, д.2/5	Россия, республика Татарстан, Казань, Авиастроительный район, улица Рихарда Зорге	0101000020E6100000AC74779D0D914840DB6D179AEBF24B40
93130	7	64	\N	134	77691	\N	55.818337358851501	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Революционная, д.41		0101000020E6100000B3EBDE8AC4724840AA0D4E44BFE84B40
93314	7	64	\N	134	78027	\N	55.784759000000001	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Рашида Вагапова, д.11		0101000020E610000030630AD6389D4840EF1EA0FB72E44B40
93065	7	64	\N	134	79355	\N	55.793672000000001	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Пушкина, д.31		0101000020E61000009DB98784EF8F48401EE0490B97E54B40
93128	7	64	\N	134	77688	\N	55.810105999999998	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Приволжская, д.97		0101000020E61000000667F0F78B7548408D25AC8DB1E74B40
93134	7	64	\N	134	78504	\N	55.814644000000001	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Привокзальная, д.1		0101000020E6100000DE3829CC7B724840FAF02C4146E84B40
93211	7	64	\N	134	78573	\N	55.738925999999999	Республика Татарстан (Татарстан), город Казань, Приволжский район, Кукушкино, ул.Поперечно-Кукушкинская, д.26		0101000020E61000000F5EBBB4E18C484001158E2095DE4B40
93067	7	64	\N	134	79357	\N	55.8038246477633	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Подлужная, д.55	Россия, республика Татарстан, Казань, Вахитовский район	0101000020E610000034D769A4A5924840865AD3BCE3E64B40
93305	7	64	\N	134	15884	\N	55.769407999999999	Республика Татарстан (Татарстан), город Казань, Советский район, проспект Победы, д.108	Россия, республика Татарстан, Казань, Приволжский район, Победы проспект, 108	0101000020E61000009BFEEC478A9C4840F0A31AF67BE24B40
93237	7	64	\N	134	15884	\N	55.746111999999997	Республика Татарстан (Татарстан), город Казань, Приволжский район, пр.Победы, д.48	Россия, республика Татарстан, Казань, Приволжский район, Победы проспект, 48	0101000020E610000069E4F38AA79A48409A93179980DF4B40
93263	7	64	\N	134	77928	\N	55.805574	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Пионерская, д.10		0101000020E6100000BC067DE9ED9748400341800C1DE74B40
93283	7	64	\N	134	77969	\N	55.861353000000001	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Парковая, д.12		0101000020E6100000349E08E23C9C4840DFA7AAD040EE4B40
93276	7	64	\N	134	77969	\N	55.858165	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Парковая, д.27А		0101000020E6100000BC033C69E19C484032C9C859D8ED4B40
93292	7	64	\N	134	77978	\N	55.768360000000001	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Отрадная, д.42		0101000020E6100000DA38622D3E974840FCC6D79E59E24B40
93226	7	64	\N	134	69510	\N	55.748953995347001	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Оренбургский Тракт, д.48	Россия, республика Татарстан, Казань, Приволжский район, Первомайский микрорайон	0101000020E6100000726A6798DA944840AC1A84B9DDDF4B40
93227	7	64	\N	134	75162	\N	55.730433565796197	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Оренбургский Тракт, д.138	Россия, республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 138	0101000020E6100000FE463B6EF897484078F17EDC7EDD4B40
93223	7	64	\N	134	75162	\N	55.762207851351	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Оренбургский Тракт, д.4	Россия, республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 4	0101000020E6100000BF9EAF592E934840F25F200890E14B40
93222	7	64	\N	134	75162	\N	55.761691678463201	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Оренбургский Тракт, д.3	Россия, республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 3	0101000020E610000097FDBAD39D934840FACF9A1F7FE14B40
93307	7	64	\N	134	78009	\N	55.770851	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Ноксинский Спуск, д.17		0101000020E610000057CC086F0F9E4840618BDD3EABE24B40
93132	7	64	\N	134	77694	\N	55.826143999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Новороссийская, д.76		0101000020E6100000E7C589AF766E4840B0E42A16BFE94B40
93214	7	64	\N	134	75118	\N	55.699495379073397	Республика Татарстан (Татарстан), город Казань, Приволжский район, Мирный, ул.Ново-Давликеевская, д.90		0101000020E6100000E4A1EF6E65914840965B5A0D89D94B40
93258	7	64	\N	134	77683	\N	55.800393	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Николая Ершова, д.57А		0101000020E6100000A2293BFDA096484042791F4773E64B40
93256	7	64	\N	134	77683	\N	55.795327	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Николая Ершова, д.58		0101000020E6100000C1ABE5CE4C9648401A506F46CDE54B40
93080	7	64	\N	134	77683	\N	55.792786999999997	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Николая Ершова, д.30		0101000020E6100000E0641BB803954840D3D85E0B7AE54B40
93118	7	64	\N	134	75404	\N	55.802973000000001	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Несмелова, д.7		0101000020E6100000B14D2A1A6B8948401749BBD1C7E64B40
93282	7	64	\N	134	77971	\N	55.868156999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Начальная, д.15		0101000020E6100000187C9A93179D48409065C1C41FEF4B40
93288	7	64	\N	134	78564	\N	55.885848000000003	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Научный городок, д.2	Россия	0101000020E6100000F0DDE68D93A248400F9D9E7763F14B40
93072	7	64	\N	134	77774	\N	55.788879004089701	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Муштари, д.6	Россия, республика Татарстан, Казань, улица Муштари, 6	0101000020E61000008109DCBA9B91484027C0B0FCF9E44B40
93203	7	64	\N	134	77643	\N	55.825789999999998	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Мусина, д.17		0101000020E6100000DEC7D11C598F484092AE997CB3E94B40
93189	7	64	\N	134	77643	\N	55.830987999999998	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Мусина, д.32		0101000020E610000096EB6D331590484029AF95D05DEA4B40
93187	7	64	\N	134	77643	\N	55.829987000000003	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Мусина, д.30		0101000020E6100000F5D72B2CB88F4840768D96033DEA4B40
93108	7	64	\N	134	77687	\N	55.818171433992397	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Музыкальная, д.5		0101000020E6100000008FA850DD8648408FC4CBD3B9E84B40
93085	7	64	\N	134	77790	\N	55.768208000000001	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Моторная, д.31а		0101000020E610000098BF42E6CA9448404643C6A354E24B40
93103	7	64	\N	134	77610	\N	55.821410999999998	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Можайского, д.14		0101000020E6100000790778D2C28348408EC9E2FE23E94B40
93277	7	64	\N	134	77653	\N	55.862515000000002	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Мира, д.35А		0101000020E6100000032670EB6E9C48409CA73AE466EE4B40
93247	7	64	\N	134	69533	\N	55.740683926358102	Республика Татарстан (Татарстан), город Казань, Приволжский район, Салмачи, ул.Мира, д.2а	Россия, республика Татарстан, Казань, Приволжский район, улица Мира	0101000020E610000001A60C1CD0A24840D255BABBCEDE4B40
93213	7	64	\N	134	77584	\N	55.674484	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Матюшинская, д.57		0101000020E610000089096AF8169048406FD6E07D55D64B40
93194	7	64	\N	134	77806	\N	55.838905686287099	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Маршала Чуйкова, д.89А		0101000020E6100000774EB340BB9348408735954561EB4B40
93120	7	64	\N	134	75429	\N	55.799902000000003	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Мало-Московская, д.15		0101000020E61000003694DA8B68874840A400513063E64B40
93119	7	64	\N	134	75429	\N	55.800691	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Мало-Московская, д.12		0101000020E6100000A30227DBC0874840CC99ED0A7DE64B40
93041	7	64	\N	134	77599	\N	55.865079555244201	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Малая Армавирская, д.31А	Россия, республика Татарстан, Казань, улица Малая Армавирская	0101000020E610000012876C205D8848403B3602F1BAEE4B40
93028	7	64	\N	134	77668	\N	55.864096000000004	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Максимова, д.76		0101000020E61000006090F469158948405E4D9EB29AEE4B40
93063	7	64	\N	134	77744	\N	55.769691999999999	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Мазита Гафури, д.34а		0101000020E6100000274BADF71B8D484015FF774485E24B40
93039	7	64	\N	134	77676	\N	55.852283	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Лядова, д.7		0101000020E6100000ACE5CE4C308A4840E8F7FD9B17ED4B40
93049	7	64	\N	134	79299	\N	55.853011568673502	420036, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Лядова (здание школы №112), д.16	Россия, республика Татарстан, Казань, улица Лядова	0101000020E6100000BC3B32569B8948403B8C497F2FED4B40
93043	7	64	\N	134	77741	\N	55.875399999999999	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Луначарского, д.9		0101000020E6100000386744696F8848408E75711B0DF04B40
93310	7	64	\N	134	77606	\N	55.76641	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Ломжинская, д.6А		0101000020E610000031EA5A7B9F9C4840E7A90EB919E24B40
93285	7	64	\N	134	77979	\N	55.862267000000003	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Липатова, д.25		0101000020E610000055849B8C2A9B4840C4B5DAC35EEE4B40
93287	7	64	\N	134	79724	\N	55.884630999999999	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Лесная, д.16	Россия, республика Татарстан, Казань, Советский район, Большие Дербышки микрорайон	0101000020E6100000EECF4543C69948408E03AF963BF14B40
93027	7	64	\N	134	77585	\N	55.865029999999997	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Ленинградская, д.28		0101000020E61000009BE5B2D1398B48408907944DB9EE4B40
93026	7	64	\N	134	77585	\N	55.865029999999997	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Ленинградская, д.30		0101000020E61000009BE5B2D1398B48408907944DB9EE4B40
93131	7	64	\N	134	77692	\N	55.819862999999998	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Лейтенанта Красикова, д.16		0101000020E61000009A93179980734840A8195245F1E84B40
93057	7	64	\N	134	77722	\N	55.793657000000003	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Лево-Булачная, д.14а		0101000020E61000005F27F565698D4840E99E758D96E54B40
93297	7	64	\N	134	77996	\N	55.761724999999998	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Латышских Стрелков, д.15		0101000020E6100000B29C84D217964840D6C56D3480E14B40
93162	7	64	\N	134	77716	\N	55.828394000000003	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Кулахметова, д.21		0101000020E6100000B9895A9A5B874840F01989D008EA4B40
93106	7	64	\N	134	77831	\N	55.822128999999997	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Краснококшайская, д.178		0101000020E6100000CD069964E4864840ED0BE8853BE94B40
93303	7	64	\N	134	77995	\N	55.780385000000003	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Красной Позиции, д.37		0101000020E61000008D60E3FA77954840FDA4DAA7E3E34B40
93300	7	64	\N	134	77995	\N	55.787593999999999	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Красной Позиции, д.8А		0101000020E610000024D3A1D3F39448404E4354E1CFE44B40
93299	7	64	\N	134	77995	\N	55.788438999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Красной Позиции, д.6А		0101000020E61000008315A75A0B9548400AF2B391EBE44B40
93045	7	64	\N	134	77701	\N	55.867273124533902	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Котовского, д.2	Россия, республика Татарстан, Казань, улица Котовского, 2	0101000020E610000043E21E4B1F84484016DA39CD02EF4B40
93143	7	64	\N	134	77704	\N	55.824722999999999	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Короленко, д.24		0101000020E6100000B131AF230E8D484027A1F48590E94B40
93038	7	64	\N	134	77672	\N	55.856214000000001	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Копылова, д.11		0101000020E61000004E098849B88A48404D309C6B98ED4B40
93035	7	64	\N	134	77672	\N	55.849656000000003	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Копылова, д.2		0101000020E6100000CB863595458B4840D36C1E87C1EC4B40
93033	7	64	\N	134	77673	\N	55.857568999999998	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Копылова, д.13		0101000020E6100000889FFF1EBC8A48401E882CD2C4ED4B40
93244	7	64	\N	134	77899	\N	55.747449000000003	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Комиссара Габишева, д.15		0101000020E6100000BBEF181EFB9D4840C636A968ACDF4B40
93243	7	64	\N	134	77899	\N	55.752657999999997	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Комиссара Габишева, д.27а		0101000020E61000003927F6D03E9E48405089EB1857E04B40
93298	7	64	\N	134	78000	\N	55.756908000000003	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Комарова, д.12		0101000020E61000003929CC7B9C954840570A815CE2E04B40
93121	7	64	\N	134	77611	\N	55.798636999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Клары Цеткин, д.11		0101000020E6100000B7CF2A33A58748401230BABC39E64B40
93281	7	64	\N	134	77967	\N	55.864773	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Каштановая, д.5		0101000020E61000009CC1DF2F669D48405EBBB4E1B0EE4B40
93221	7	64	\N	134	77855	\N	55.772902000000002	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Качалова, д.107		0101000020E61000002A38BC2022934840AA81E673EEE24B40
93073	7	64	\N	134	69766	\N	55.7849107766652	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Катановский переулок, д.1	Россия, республика Татарстан, Казань, Катановский переулок, 1	0101000020E610000016325706D5904840A5A2B1F677E44B40
93071	7	64	\N	134	77682	\N	55.794714999999997	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Карла Маркса, д.68		0101000020E6100000689604A8A991484000529B38B9E54B40
93054	7	64	\N	134	77682	\N	55.796520999999998	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Карла Маркса, д.10		0101000020E61000000CE6AF90B98E4840E2C96E66F4E54B40
93061	7	64	\N	134	77736	\N	55.778421000000002	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Карима Тинчурина, д.3		0101000020E6100000F10EF0A4858D484083C2A04CA3E34B40
93077	7	64	\N	134	77768	\N	55.783802000000001	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Зеленая, д.1		0101000020E6100000871403249A9248400B45BA9F53E44B40
93127	7	64	\N	134	77685	\N	55.809373000000001	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Звездная, д.15		0101000020E61000008EAED2DD75784840F9A1D28899E74B40
93124	7	64	\N	134	78569	\N	55.802188999999998	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Затонская, д.12		0101000020E610000027F56569A77C4840001B1021AEE64B40
93100	7	64	\N	134	77630	\N	55.848165000000002	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Залесная, д.2		0101000020E6100000ADDBA0F65B754840514EB4AB90EC4B40
93311	7	64	\N	134	78019	\N	55.777408000000001	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Закиева, д.31		0101000020E6100000C2172653059D48400BD3F71A82E34B40
93055	7	64	\N	134	77713	\N	55.797694999999997	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Жуковского, д.18		0101000020E6100000CD1DFD2FD79048406397A8DE1AE64B40
93029	7	64	\N	134	69422	\N	55.863095809167298	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Дунайсквя, д.16	Россия, республика Татарстан, Казань, улица Дунайская	0101000020E6100000F530B43A398948407AA702EE79EE4B40
93245	7	64	\N	134	77903	\N	55.739609999999999	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Дубравная, д.45		0101000020E610000022C66B5ED5994840B4E55C8AABDE4B40
93238	7	64	\N	134	77903	\N	55.740465999999998	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Дубравная, д.51а		0101000020E610000032ACE28DCC99484064E60297C7DE4B40
93261	7	64	\N	134	77921	\N	55.806924000000002	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Дружбы, д.1		0101000020E61000009293895B05974840C32D1F4949E74B40
93079	7	64	\N	134	77626	\N	55.7890340032598	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Достоевского, д.51		0101000020E61000009A779CA2239348404EB7EC10FFE44B40
93078	7	64	\N	134	77626	\N	55.789027958209303	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Достоевского, д.51а		0101000020E6100000C72B103D299348406CD097DEFEE44B40
93068	7	64	\N	134	77626	\N	55.787781000000003	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Достоевского, д.79		0101000020E6100000E3A59BC42094484081B4FF01D6E44B40
93275	7	64	\N	134	77959	\N	55.847330999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Дорожная, д.32А		0101000020E6100000C6353E93FD9B484088F19A5775EC4B40
93316	7	64	\N	134	78024	\N	55.793135999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Джаудата Файзи, д.8		0101000020E61000001749BBD1C79C4840DFA3FE7A85E54B40
93208	7	64	\N	134	79326	\N	55.723160999999998	420138, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Деревня Универсиады (здание общежития), д.2		0101000020E6100000CD91955F069548400F5F268A90DC4B40
93034	7	64	\N	134	77656	\N	55.857866999999999	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Дементьева, д.18		0101000020E6100000E012807F4A8D4840A8A8FA95CEED4B40
93032	7	64	\N	134	77656	\N	55.861503999999996	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Дементьева, д.70А		0101000020E61000001004C8D0B18D4840C4AF58C345EE4B40
93024	7	64	\N	134	77656	\N	55.862343000000003	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Дементьева, д.39		0101000020E6100000CC6262F3718D48409F77634161EE4B40
93150	7	64	\N	134	77634	\N	55.820309000000002	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Декабристов, д.89		0101000020E6100000DA722EC5558B4840A7CEA3E2FFE84B40
93149	7	64	\N	134	77634	\N	55.820290461889698	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Декабристов, д.89А		0101000020E6100000B7D09508548B4840309E4143FFE84B40
93145	7	64	\N	134	77634	\N	55.832090000000001	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Декабристов, д.156А		0101000020E61000001E3526C45C8A484011AAD4EC81EA4B40
93140	7	64	\N	134	77634	\N	55.815094000000002	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Декабристов, д.2		0101000020E610000064EB19C2318D48403A950C0055E84B40
93295	7	64	\N	134	78054	\N	55.764505451072402	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Даурская, д.32	Россия, республика Татарстан, Казань, Приволжский район, улица Даурская, 32	0101000020E61000007250C24CDB9548407250C24CDBE14B40
93296	7	64	\N	134	77998	\N	55.763568999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Даурская, д.26		0101000020E610000057CEDE196D954840A59E05A1BCE14B40
93294	7	64	\N	134	77994	\N	55.764308	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Даурская, д.30		0101000020E6100000F2B0506B9A9548401C0934D8D4E14B40
93317	7	64	\N	134	77618	\N	55.769546669599102	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Грачиная, д.33	Россия, республика Татарстан, Казань, улица Грачиная	0101000020E6100000971C774A07A1484012DE1E8480E24B40
55297	7	63	\N	1332	54515	\N	54.216667999999999	Республика Мордовия, город Саранск, Пролетарский район, Металлургов, 2		0101000020E61000001CCEFC6A0E9046407C0BEBC6BB1B4B40
93022	7	64	\N	134	75388	\N	55.877015999999998	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Граничная, д.2		0101000020E6100000FE62B664558A4840CC086F0F42F04B40
93070	7	64	\N	134	77647	\N	55.793190508055602	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Горького, д.16/7		0101000020E610000074D2FBC6D7904840A33D5E4887E54B40
93102	7	64	\N	134	68510	\N	55.826233541190398	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Горьковское Шоссе, д.24	Россия, республика Татарстан, Казань, Горьковское шоссе, 24	0101000020E61000005376FA415D844840F06B2409C2E94B40
93114	7	64	\N	134	77908	\N	55.817233999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Горсоветская, д.2		0101000020E610000032AEB8382A8B4840F296AB1F9BE84B40
93158	7	64	\N	134	77958	\N	55.835315999999999	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Городская, д.2		0101000020E6100000B1E07EC003894840ABE97AA2EBEA4B40
93186	7	64	\N	134	77752	\N	55.837741999999999	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Голубятникова, д.18		0101000020E610000008AF5DDA708E4840293E3E213BEB4B40
93182	7	64	\N	134	77752	\N	55.838464999999999	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Голубятникова, д.31		0101000020E6100000CC086F0F428E48409AEB34D252EB4B40
93232	7	64	\N	134	77874	\N	55.753259725691102	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Гарифьянова, д.7	Россия, республика Татарстан, Казань, улица Гарифьянова, 7	0101000020E6100000B003E78C2899484046B1DCD26AE04B40
93167	7	64	\N	134	75129	\N	55.824913753535398	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Г.Баруди, д.25А	Россия, республика Татарстан, Казань, улица Галимджана Баруди, 25а	0101000020E610000034F44F70B18848409B012EC896E94B40
93260	7	64	\N	134	77930	\N	55.801631999999998	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Галеева, д.3А		0101000020E61000008B5242B0AA964840AAB69BE09BE64B40
93157	7	64	\N	134	77943	\N	55.836216	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Гагарина, д.101А		0101000020E6100000D158FB3BDB8948402B323A2009EB4B40
93147	7	64	\N	134	77707	\N	55.837736999999997	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Гагарина, д.26А		0101000020E6100000FAD170CADC8A484017D34CF73AEB4B40
93181	7	64	\N	134	77655	\N	55.839182999999998	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Гагарина, д.18А		0101000020E610000038F581E49D8B4840F92D3A596AEB4B40
93180	7	64	\N	134	77655	\N	55.839556999999999	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Гагарина, д.8		0101000020E61000003FA9F6E9788C48405E10919A76EB4B40
93058	7	64	\N	134	77725	\N	55.782744000000001	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Габдуллы Тукая, д.26		0101000020E6100000749A05DA1D8E4840F39194F430E44B40
93266	7	64	\N	134	77940	\N	55.811695	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Восьмого Марта, д.10		0101000020E610000022DE3AFF76974840D2A92B9FE5E74B40
93159	7	64	\N	134	77715	\N	55.837817999999999	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Восход, д.29		0101000020E6100000BF0CC688448948400400C79E3DEB4B40
93161	7	64	\N	134	77639	\N	55.833947067532399	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Восстания, д.80		0101000020E6100000E33785950A88484075CC79C6BEEA4B40
93146	7	64	\N	134	77639	\N	55.833950999999999	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Восстания, д.36		0101000020E610000094A46B26DF8A4840B6BB07E8BEEA4B40
93178	7	64	\N	134	79359	\N	55.841634999999997	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Воровского, д.13		0101000020E6100000B9E00CFE7E8B4840A01518B2BAEB4B40
93074	7	64	\N	134	77821	\N	55.782100999999997	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Волкова, д.3		0101000020E610000078EC67B1149148409E95B4E21BE44B40
93185	7	64	\N	134	77644	\N	55.830446999999999	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Волгоградская, д.39		0101000020E610000009FA0B3D628C4840D90759164CEA4B40
93184	7	64	\N	134	77644	\N	55.832030000000003	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Волгоградская, д.26		0101000020E6100000702711E15F8C48403CA583F57FEA4B40
93218	7	64	\N	134	77847	\N	55.743420999999998	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.В.Кулагина, д.2		0101000020E610000099BA2BBB609248406E14596B28DF4B40
93229	7	64	\N	134	77590	\N	55.755707000000001	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Братьев Касимовых, д.12		0101000020E61000009FE8BAF083974840DC2DC901BBE04B40
93225	7	64	\N	134	77590	\N	55.755688880737701	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Братьев Касимовых, д.14	Россия, республика Татарстан, Казань, улица Братьев Касимовых, 12	0101000020E610000087C09140839748403579CA6ABAE04B40
93086	7	64	\N	134	77654	\N	55.767862999999998	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Братская, д.1		0101000020E6100000FDBFEAC8919448407B67B45549E24B40
93084	7	64	\N	134	77786	\N	55.778745000000001	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Бойничная, д.8		0101000020E6100000923CD7F7E1924840367689EAADE34B40
93123	7	64	\N	134	77613	\N	55.801439999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Боевая, д.161		0101000020E6100000DE0033DFC17F484066DAFE9595E64B40
93122	7	64	\N	134	77613	\N	55.799228999999997	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Боевая, д.13		0101000020E6100000F19D98F562844840E481C8224DE64B40
93129	7	64	\N	134	77689	\N	55.820329817404598	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Бирюзовая, д.24	Россия, республика Татарстан, Казань, улица Бирюзовая, 24	0101000020E610000084F23E8EE6704840BEF6CC9200E94B40
93044	7	64	\N	134	77695	\N	55.866733000000004	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Беломорская, д.144		0101000020E6100000A724EB707485484097AE601BF1EE4B40
93040	7	64	\N	134	77684	\N	55.852693000000002	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Белинского, д.39		0101000020E61000008449F1F1098948409A43520B25ED4B40
93164	7	64	\N	134	77728	\N	55.825319999999998	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Батыршина, д.15		0101000020E61000007157AF22A38748400B5EF415A4E94B40
93062	7	64	\N	134	77738	\N	55.774897000000003	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Ахтямова, д.26		0101000020E610000097A949F0868E48405F622CD32FE34B40
93083	7	64	\N	134	77782	\N	55.783300321881399	Республика Татарстан (Татарстан), г.Казань, Вахитовский район, ул.Амирхана Еники, д.23		0101000020E6100000902FA182C3934840787AA52C43E44B40
93099	7	64	\N	134	77798	\N	55.844636999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Алтынова, д.2		0101000020E6100000F9A23D5E48734840EBFEB1101DEC4B40
93267	7	64	\N	134	77925	\N	55.810955999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Александра Попова, д.21		0101000020E6100000AA436E861B9848405B3FFD67CDE74B40
93265	7	64	\N	134	77925	\N	55.809727000000002	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Александра Попова, д.16		0101000020E61000001B66683C1198484017D86322A5E74B40
93262	7	64	\N	134	77925	\N	55.809463999999998	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Александра Попова, д.3		0101000020E6100000AC5791D10197484009A52F849CE74B40
93313	7	64	\N	134	78013	\N	55.778633999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Академика Сахарова, д.8		0101000020E61000006F8099EFE09D4840DEC66647AAE34B40
93312	7	64	\N	134	78013	\N	55.778877000000001	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Академика Сахарова, д.9		0101000020E6100000323A2009FB9C4840A54DD53DB2E34B40
93193	7	64	\N	134	77809	\N	55.830869521598402	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Академика Лаврентьева, д.18А	Россия, республика Татарстан, Казань, улица Академика Лаврентьева, 18а	0101000020E61000001348895DDB9348401F9DBAF259EA4B40
93269	7	64	\N	134	77949	\N	55.809964999999998	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Академика Губкина, д.39/1		0101000020E610000087C0914083994840CBF3E0EEACE74B40
93268	7	64	\N	134	77949	\N	55.805259999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Академика Губкина, д.11		0101000020E610000066F84F375098484073637AC212E74B40
93025	7	64	\N	134	77651	\N	55.868602000000003	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Айдарова, д.10		0101000020E610000082FE428F188B4840BF9EAF592EEF4B40
93023	7	64	\N	134	77651	\N	55.867728	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Айдарова, д.2		0101000020E6100000FAB7CB7EDD8B484068E90AB611EF4B40
93289	7	64	\N	134	77596	\N	55.873963260890697	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Азина, д.65А		0101000020E6100000A2B8E34D7E9F484000750305DEEF4B40
93196	7	64	\N	134	77803	\N	55.839128000000002	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Адоратского, д.41А		0101000020E61000002E73BA2C269248403694DA8B68EB4B40
93195	7	64	\N	134	77803	\N	55.839815000000002	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Адоратского, д.36А		0101000020E61000003C2EAA45449348405AD8D30E7FEB4B40
93191	7	64	\N	134	77803	\N	55.829487	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Адоратского, д.25А		0101000020E6100000EAE74D452A92484084BA48A12CEA4B40
93290	7	64	\N	134	77985	\N	55.783164999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Аделя Кутуя, д.84		0101000020E610000031ED9BFBAB974840982F2FC03EE44B40
93202	7	64	\N	134	75127	\N	55.826534000000002	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Абдуллы Бичурина, д.22/26		0101000020E6100000BB0A293FA99048401B84B9DDCBE94B40
93112	7	64	\N	134	77901	\N	55.821289999999998	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.2-ая Юго-Западная, д.27а		0101000020E610000066BD18CA898A48401344DD0720E94B40
93270	7	64	\N	134	77968	\N	55.802396000000002	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Азинская 2-я, д.7А		0101000020E61000008A93FB1D8A9A48407A3881E9B4E64B40
93304	7	64	\N	134	78008	\N	55.770187999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Юлиуса Фучика, д.147		0101000020E6100000473A03232F9D4840C5E2378595E24B40
93116	7	64	\N	134	77919	\N	55.807662999999998	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Шоссейная, д.20		0101000020E6100000B1169F02608A484039984D8061E74B40
93107	7	64	\N	134	77852	\N	55.820652000000003	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Чкалова, д.8		0101000020E6100000DFA815A6EF874840D1B2EE1F0BE94B40
93204	7	64	\N	134	77832	\N	55.824936000000001	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Четаева, д.37		0101000020E610000002BA2F67B68F484083A5BA8097E94B40
93199	7	64	\N	134	77832	\N	55.824334	Республика Татарстан (Татарстан), город Казань, Ново-Савиновский район, ул.Четаева, д.1		0101000020E6100000B75F3E59319248408D7DC9C683E94B40
54070	7	62	\N	1218	62228	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Советская, д. 20А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
93171	7	64	\N	134	77749	\N	55.871217999999999	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Химиков, д.41А		0101000020E610000070ED444948824840E0D7481284EF4B40
93210	7	64	\N	134	77842	\N	55.754998000000001	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Учительская, д.2		0101000020E6100000CEC29E76F88D4840D04543C6A3E04B40
93293	7	64	\N	134	77980	\N	55.763720999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Рихарда Зорге, д.1А		0101000020E6100000CD565EF23F9748405B22179CC1E14B40
93030	7	64	\N	134	77660	\N	55.859437999999997	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Побежимова, д.47А		0101000020E6100000DAA9B9DC608A484046787B1002EE4B40
93257	7	64	\N	134	77910	\N	55.798222000000003	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Николая Ершова, д.55		0101000020E6100000085740A19E9648404F7974232CE64B40
93125	7	64	\N	134	77628	\N	55.805781000000003	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Минусинская, д.1		0101000020E61000003CFA5FAE457948407D5EF1D423E74B40
93110	7	64	\N	134	77863	\N	55.813338999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Лукницкого, д.1		0101000020E61000006808C72C7B884840DAC70A7E1BE84B40
93264	7	64	\N	134	77931	\N	55.800924000000002	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Космонавтов, д.19		0101000020E610000056293DD34B9848406F4A79AD84E64B40
93141	7	64	\N	134	77698	\N	55.823240127163601	Республика Татарстан (Татарстан), город Казань, Московский район, ул.Короленко, д.26А	Россия, республика Татарстан, Казань, улица Короленко, 26а	0101000020E61000007B9FAA42038D48402861A6ED5FE94B40
93242	7	64	\N	134	77897	\N	55.755023000000001	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Комиссара Габишева, д.33а		0101000020E6100000234A7B832F9E4840295DFA97A4E04B40
93228	7	64	\N	134	77869	\N	55.752718000000002	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Карбышева, д.64		0101000020E610000097749483D9964840268E3C1059E04B40
93113	7	64	\N	134	77904	\N	55.816884999999999	Республика Татарстан (Татарстан), город Казань, Кировский район, ул.Дежнева, д.1		0101000020E61000001363997E898A4840E6CB0BB08FE84B40
93046	7	64	\N	134	77709	\N	55.870173403387398	Республика Татарстан (Татарстан), город Казань, Авиастроительный район, ул.Гудованцева, д.26		0101000020E6100000E8323509DE8248405D6E30D461EF4B40
93234	7	64	\N	134	77878	\N	55.754877	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Братьев Касимовых, д.68		0101000020E610000008CBD8D0CD9A484055C03DCF9FE04B40
93233	7	64	\N	134	77878	\N	55.754779999999997	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Братьев Касимовых, д.52		0101000020E610000051DA1B7C619A484062D68BA19CE04B40
93220	7	64	\N	134	77849	\N	55.767736999999997	Республика Татарстан (Татарстан), город Казань, Приволжский район, ул.Ботаническая, д.7		0101000020E61000006D8D08C6C1914840EE76BD3445E24B40
93301	7	64	\N	134	77973	\N	55.784587000000002	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Аделя Кутуя, д.4А		0101000020E6100000E8887C9752954840F2EEC8586DE44B40
93291	7	64	\N	134	77973	\N	55.779179999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Аделя Кутуя, д.114		0101000020E610000009C6C1A56398484040D9942BBCE34B40
93273	7	64	\N	134	77589	\N	55.835158999999997	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Агрызская, д.61		0101000020E61000005A7F4B00FE994840E3FA777DE6EA4B40
93274	7	64	\N	134	78581	\N	55.854982	Республика Татарстан (Татарстан), город Казань, Советский район, ул.Станционная 4-я, д.5		0101000020E6100000F92F1004C89848409755D80C70ED4B40
132	7	64	\N	6600	10193	\N	55.850131410141103	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Юности, д.3	Россия, республика Татарстан, Зеленодольск	0101000020E6100000B7EEE6A90E4348406B28B517D1EC4B40
135	7	64	\N	6600	10231	\N	55.848344853496897	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Чапаева, д.1	Россия, республика Татарстан, Зеленодольск	0101000020E6100000CB67791EDC414840D15CA79196EC4B40
137	7	64	\N	6600	10128	\N	55.849745134611403	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Чайковского, д.56	Россия, республика Татарстан, Зеленодольск	0101000020E61000006A882AFC194248404278B471C4EC4B40
142	7	64	\N	6600	10136	\N	55.848779428919698	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Хазиева, д.2	Россия, республика Татарстан, Зеленодольск	0101000020E6100000658EE55DF54248400B444FCAA4EC4B40
119	7	64	\N	6600	10325	\N	55.843371031729397	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Украинская, д.4		0101000020E6100000919C4CDC2A42484089B2B794F3EB4B40
120	7	64	\N	6600	10130	\N	55.845833877731202	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Тургенева, д.19	Россия, республика Татарстан, Зеленодольск	0101000020E6100000533F6F2A5243484025ECDB4944EC4B40
140	7	64	\N	6600	10161	\N	55.847765000000003	422550, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Столичная (здание филиала КНИТУ-КАИ), д.27А	Россия, республика Татарстан, Зеленодольск	0101000020E610000080B56AD784424840C3D8429083EC4B40
93709	7	64	\N	4205	68372	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Ленина, д.1б		0101000020E6100000294014CC98284A40DD9733DB15724B40
148	7	64	\N	6600	10255	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Сайдашева, д.4	Россия, республика Татарстан, Зеленодольск	0101000020E610000080B56AD784424840C3D8429083EC4B40
124	7	64	\N	6600	10111	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Рогачева, д.4		0101000020E610000080B56AD784424840C3D8429083EC4B40
145	7	64	\N	6600	12139	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.М.Жукова, д.3	Россия, республика Татарстан, Зеленодольск	0101000020E610000080B56AD784424840C3D8429083EC4B40
129	7	64	\N	6600	9942	\N	55.846413348135499	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Ленина, д.46	Россия, республика Татарстан, Зеленодольск	0101000020E610000003098A1F6342484062F4DC4257EC4B40
118	7	64	\N	6600	9942	\N	55.8484414262347	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Ленина, д.13	Россия, республика Татарстан, Зеленодольск	0101000020E6100000DFC4909C4C424840F3CAF5B699EC4B40
127	7	64	\N	6600	10175	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Космонавтов, д.13	Россия, республика Татарстан, Зеленодольск	0101000020E610000080B56AD784424840C3D8429083EC4B40
144	7	64	\N	6600	10244	\N	55.848972571985698	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Королева, д.2	Россия, республика Татарстан, Зеленодольск	0101000020E61000008F72309B00434840F017B325ABEC4B40
147	7	64	\N	6600	10247	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Комарова, д.22А		0101000020E610000080B56AD784424840C3D8429083EC4B40
143	7	64	\N	6600	10247	\N	55.845061237030698	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Комарова, д.15А	Россия, республика Татарстан, Зеленодольск	0101000020E6100000CEDDAE97A6424840021077F52AEC4B40
117	7	64	\N	6600	10104	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Кирпичная, д.40	Россия, республика Татарстан, Зеленодольск	0101000020E610000080B56AD784424840C3D8429083EC4B40
136	7	64	\N	6600	11330	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, у.К.Насыри, д.13А		0101000020E610000080B56AD784424840C3D8429083EC4B40
134	7	64	\N	6600	11330	\N	55.849262284777602	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.К.Насыри, д.13А		0101000020E6100000658EE55DF542484027DE019EB4EC4B40
125	7	64	\N	6600	11473	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.К.Маркса, д.20		0101000020E610000080B56AD784424840C3D8429083EC4B40
122	7	64	\N	6600	11473	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.К.Маркса, д.7		0101000020E610000080B56AD784424840C3D8429083EC4B40
146	7	64	\N	6600	10266	\N	55.849310570032102	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Жукова, д.9	Россия, республика Татарстан, Зеленодольск	0101000020E6100000B8567BD80B43484008910C39B6EC4B40
139	7	64	\N	6600	10141	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Дальняя, д.1А	Россия, республика Татарстан, Зеленодольск	0101000020E610000080B56AD784424840C3D8429083EC4B40
130	7	64	\N	6600	10133	\N	55.846654791577002	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Гоголя, д.60	Россия, республика Татарстан, Зеленодольск	0101000020E6100000E294B9F94642484058FFE7305FEC4B40
126	7	64	\N	6600	10133	\N	55.845544139275802	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Гоголя, д.40А	Россия, республика Татарстан, Зеленодольск	0101000020E61000007BBB2539604348401DAA29C93AEC4B40
121	7	64	\N	6600	10133	\N	55.847765000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Гоголя, д.5		0101000020E610000080B56AD784424840C3D8429083EC4B40
131	7	64	\N	6600	10190	\N	55.849889988386899	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Гастелло, д.4	Россия, республика Татарстан, Зеленодольск	0101000020E610000054A703594F43484046990D32C9EC4B40
138	7	64	\N	6600	10227	\N	55.848731143002503	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, город Зеленодольск, ул.Гаринская, д.38Б	Россия, республика Татарстан, Зеленодольск	0101000020E61000008D0A9C6C03434840FA0CA837A3EC4B40
65	7	64	\N	3350	67377	\N	55.288662779550997	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, пр.Победы, д.1/18	Россия, республика Татарстан, Заинск	0101000020E6100000471FF30181FE49405A48C0E8F2A44B40
94308	7	64	\N	141	\N	\N	55.754882000000002	"Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, Административное здание ООО""Стахеевская"""		0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
1034	7	64	923	32544	12229	\N	54.598971032078197	п.г.т.Уруссу, ул.Пушкина, д.89	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E6100000185C7347FFB94A404F20EC14AB4C4B40
27	7	64	\N	141	\N	\N	55.754882000000002	"Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, Административное здание АО ""Елабужская Керамика"""		0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
20	7	64	\N	141	67250	\N	55.756600188292801	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, пр.Мира, д.59	Россия, республика Татарстан, Елабуга	0101000020E61000001327F73B14014A40A913D044D8E04B40
15	7	64	\N	141	9578	\N	55.7562371803769	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, пр.Нефтяников, д.24		0101000020E6100000732B84D558064A403883BF5FCCE04B40
10	7	64	\N	141	9578	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, пр.Нефтяников, д.82	Россия, республика Татарстан, Елабуга	0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
9	7	64	\N	141	9594	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, пр.Нефтяников, д.109		0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
17	7	64	\N	141	12166	\N	55.748722154424399	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, пр.Мира, д.15а	Россия, республика Татарстан, Елабуга	0101000020E610000024F25D4A5D024A40DAE55B1FD6DF4B40
24	7	64	\N	141	11943	\N	55.754494695148601	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, пр.Мира, д.26		0101000020E610000036902E36AD064A406DFFCA4A93E04B40
19	7	64	\N	141	11943	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, пр.Мира, д.39		0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
3	7	64	\N	141	9593	\N	55.764827457661603	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Тугарова, д.28	Россия, республика Татарстан, Елабуга	0101000020E6100000BADA8AFD65094A40840CE4D9E5E14B40
5	7	64	\N	141	8271	\N	55.754881920844298	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Тугарова, д.6	Россия, республика Татарстан, Елабуга	0101000020E6100000124C35B396064A40672B2FF99FE04B40
25	7	64	\N	141	10073	\N	55.754397888121503	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Строителей, д.16		0101000020E6100000C7F319506F064A407B15191D90E04B40
14	7	64	\N	141	10073	\N	55.755027129484901	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Строителей, д.6	Россия, республика Татарстан, Елабуга	0101000020E61000005F0CE544BB064A406A4C88B9A4E04B40
13	7	64	\N	141	10073	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Строителей, д.5	Россия, республика Татарстан, Елабуга	0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
12	7	64	\N	141	9572	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Разведчиков, д.41	Россия, республика Татарстан, Елабуга	0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
23	7	64	\N	141	9577	\N	55.757398793764402	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Пролетарская, д.48	Россия, республика Татарстан, Елабуга	0101000020E61000008C82E0F1ED054A40F5824F73F2E04B40
22	7	64	\N	141	9577	\N	55.756721190177501	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Пролетарская, д.36	Россия, республика Татарстан, Елабуга	0101000020E61000003E5A9C31CC054A402499D53BDCE04B40
18	7	64	\N	141	9577	\N	55.755849968193402	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Пролетарская, д.1а		0101000020E61000009D0FCF1264064A403F575BB1BFE04B40
11	7	64	\N	141	9640	\N	55.756019373998697	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Набережная, д.7	Россия, республика Татарстан, Елабуга	0101000020E610000085ECBC8DCD064A40CB13083BC5E04B40
16	7	64	\N	141	9579	\N	55.7579795874288	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Молодежная, д.4	Россия, республика Татарстан, Елабуга	0101000020E6100000D7DAFB5415064A40D482177D05E14B40
28	7	64	\N	141	9647	\N	55.754688308479103	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Марджани, д.26		0101000020E61000007BF5F1D077054A408257CB9D99E04B40
26	7	64	\N	141	9647	\N	55.751687193395597	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Марджани, д.54	Россия, республика Татарстан, Елабуга	0101000020E6100000484E266E15044A4007EA944737E04B40
6	7	64	\N	141	8273	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Казанская, д.15		0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
1	7	64	\N	141	8273	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Казанская, д.91		0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
4	7	64	\N	141	8244	\N	55.761591203067397	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Горького, д.84	Россия, республика Татарстан, Елабуга	0101000020E610000009FEB7921D094A40C7F65AD07BE14B40
7	7	64	\N	141	9627	\N	55.754882000000002	423600, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Говорова (здание школы №2), д.3	Россия, республика Татарстан, Елабуга	0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
2	7	64	\N	141	9575	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, город Елабуга, ул.Азина, д.177	Россия, республика Татарстан, Елабуга	0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
94228	7	64	\N	31939	75342	\N	55.908242000000001	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Высокая Гора, ул.Полковая, д.16		0101000020E610000000750305DEA74840446D1B4641F44B40
94224	7	64	\N	31939	75341	\N	55.908242000000001	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Высокая Гора, ул.Большая Красная, д.113А		0101000020E610000000750305DEA74840446D1B4641F44B40
94167	7	64	\N	28941	78425	\N	55.765430000000002	422570, Адрес УИК и помещение для голосования: Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Верхний Услон, ул.Чехова (здание Палаты имущественных и земельных отнош-ий), д.37	Россия, республика Татарстан, село Верхний Услон	0101000020E6100000B70BCD751A7D48404BB0389CF9E14B40
94165	7	64	\N	28941	78425	\N	55.767994999999999	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Верхний Услон, ул.Чехова, д.76		0101000020E61000001C23D923D47C4840EA3E00A94DE24B40
94164	7	64	\N	28941	78425	\N	55.767994999999999	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Верхний Услон, ул.Чехова, д.34		0101000020E61000001C23D923D47C4840EA3E00A94DE24B40
94090	7	64	\N	25001	69254	\N	54.985510913149	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Строительная, д.2	Россия, республика Татарстан, Буинск	0101000020E6100000A724EB7074274840946C7539257E4B40
94088	7	64	\N	25001	69254	\N	54.9748359257582	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Строительная, д.4	Россия, республика Татарстан, Буинск	0101000020E6100000C6F99B5088244840537B116DC77C4B40
94075	7	64	\N	25001	75332	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Советская, д.9Б		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94081	7	64	\N	25001	69205	\N	54.972071071215801	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Р.Люксембург, д.117	Россия, республика Татарстан, Буинск	0101000020E6100000787C7BD7A0254840EC3191D26C7C4B40
94078	7	64	\N	25001	69205	\N	54.9648124183162	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Р.Люксембург, д.65	Россия, республика Татарстан, Буинск	0101000020E6100000B1A6B228EC244840E964A9F57E7B4B40
94085	7	64	\N	25001	75337	\N	54.974404411980302	422430, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Р.Люксембург (здание Центра занятости населения), д.157/1	Россия, республика Татарстан, Буинск	0101000020E6100000A6ED5F5969244840B98B3045B97C4B40
94083	7	64	\N	25001	75337	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Р.Люксембург, д.157		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94080	7	64	\N	25001	75334	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Космовского, д.43/39		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94089	7	64	\N	25001	75338	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Комсомольская, д.7		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94087	7	64	\N	25001	75338	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Комсомольская, д.32		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94079	7	64	\N	25001	71721	\N	54.965367974026101	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.К.Маркса, д.72	Россия, республика Татарстан, Буинск	0101000020E610000053927538BA2448406E4DBA2D917B4B40
94076	7	64	\N	25001	75333	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Железнодорожная, д.43		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94086	7	64	\N	25001	75336	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Ефремова, д.148		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94082	7	64	\N	25001	75336	\N	54.974308000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Ефремова, д.133		0101000020E61000007A39ECBE63244840971DE21FB67C4B40
94077	7	64	\N	25001	71698	\N	54.970096058051503	Республика Татарстан (Татарстан), Буинский муниципальный район, г.Буинск, ул.Г.Исхаки, д.29	Россия, республика Татарстан, Буинский район	0101000020E61000007D59DAA9B92248407EFD101B2C7C4B40
94023	7	64	\N	22026	68985	\N	54.539718593395897	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Гашека, д.3	Россия, республика Татарстан, Бугульма городской округ	0101000020E6100000103D29931A664A40D1031F8315454B40
94031	7	64	\N	22026	71641	\N	54.531246060039301	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Чайковского, д.2В	Россия, республика Татарстан, Бугульма городской округ	0101000020E610000063416150A6694A40BF1072DEFF434B40
94037	7	64	\N	22026	75326	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Тухачевского, д.12		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94036	7	64	\N	22026	78307	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Тупиковая, д.6		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
1374	7	64	923	32544	11440	\N	54.598970999999999	п.г.т.Уруссу, ул.Уруссинская, д.38		0101000020E6100000793BC269C1B94A404F20EC14AB4C4B40
94035	7	64	\N	22026	69098	\N	54.526466222838501	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Оршанской Дивизии, д.61	Россия, республика Татарстан, Бугульма городской округ	0101000020E6100000F623456458674A405C3AE63C63434B40
94034	7	64	\N	22026	69098	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Оршанской Дивизии, д.1А		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94039	7	64	\N	22026	75330	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Орджоникидзе, д.2А		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94020	7	64	\N	22026	75319	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Матросова, д.13		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94038	7	64	\N	22026	69132	\N	54.531957371565902	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Локомотивная, д.28	Россия, республика Татарстан, Бугульма	0101000020E6100000EC3191D26C664A406BF0BE2A17444B40
94033	7	64	\N	22026	67691	\N	54.535576132132803	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Ленина, д.98	Россия, республика Татарстан, Бугульма городской округ	0101000020E6100000A8A624EB70684A40E1421EC18D444B40
94032	7	64	\N	22026	67691	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Ленина, д.137		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94021	7	64	\N	22026	67691	\N	54.529324208740199	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Ленина, д.33	Россия, республика Татарстан, Бугульма городской округ	0101000020E61000008A213999B8694A40747E8AE3C0434B40
94018	7	64	\N	22026	67691	\N	54.532431572333202	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Ленина, д.9	Россия, республика Татарстан, Бугульма городской округ	0101000020E61000007B30293E3E694A4004AC55BB26444B40
94012	7	64	\N	22026	79277	\N	54.529236849703501	423231, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Красноармейская (здание школы №9), д.37А	Россия, республика Татарстан, Бугульма городской округ	0101000020E6100000E371512D22684A40A56ABB09BE434B40
94011	7	64	\N	22026	68895	\N	54.537385391563298	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Красноармейская, д.37А	Россия, республика Татарстан, Бугульма городской округ	0101000020E610000059C2DA183B634A40342E1C08C9444B40
94014	7	64	\N	22026	68936	\N	54.536287367864297	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Комсомольская, д.5	Россия, республика Татарстан, Бугульма городской округ	0101000020E610000042226DE34F684A408E226B0DA5444B40
94029	7	64	\N	22026	71601	\N	54.541802141660902	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Калинина, д.114	Россия, республика Татарстан, Бугульма городской округ	0101000020E6100000C1A7397991654A40257497C459454B40
94019	7	64	\N	22026	75318	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Казанская, д.12А		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94026	7	64	\N	22026	75321	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Джалиля, д.31		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94025	7	64	\N	22026	75321	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Джалиля, д.37		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94022	7	64	\N	22026	75321	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Джалиля, д.2		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94030	7	64	\N	22026	69062	\N	54.536362234059197	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Гоголя, д.128	Россия, республика Татарстан, Бугульма городской округ	0101000020E61000005A66118AAD664A4098689082A7444B40
94027	7	64	\N	22026	69062	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Гоголя, д.64		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94016	7	64	\N	22026	9862	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Гафиатуллина, д.23		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94015	7	64	\N	22026	9862	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Гафиатуллина, д.30		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94024	7	64	\N	22026	69040	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Вахитова, д.6		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94028	7	64	\N	22026	75322	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.14 Павших, д.56		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
93948	7	64	\N	59436	71360	\N	54.392342544464498	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, площадь Победы, 5	Россия, республика Татарстан, поселок Бавлы	0101000020E61000000A65E1EB6BA14A4042E8A04B38324B40
93952	7	64	\N	59436	71460	\N	54.393394368703397	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Чапаева, 2	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000E1B4E0455FA14A40A8380EBC5A324B40
93950	7	64	\N	59436	71442	\N	54.393244109756203	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, С.Сайдашева, 25	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000E08096AE60A14A4093ACC3D155324B40
93949	7	64	\N	59436	71398	\N	54.392943590203501	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Куйбышева, 36	Россия, республика Татарстан, поселок Бавлы	0101000020E61000007F6DFDF49FA14A4068942EFD4B324B40
93946	7	64	\N	59436	71334	\N	54.395297600855201	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Горюнова, 9	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000F59F353FFEA04A404C16F71F99324B40
93951	7	64	\N	59436	71455	\N	54.393294196133397	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Вахитова, 8	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000BF0CC68844A14A4044DB317557324B40
93943	7	64	\N	60571	75313	\N	54.396192840570599	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Татарстан, 1	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000BB6246787BA24A40BAF3C473B6324B40
93942	7	64	\N	60571	75311	\N	54.389844451170802	Республика Татарстан (Татарстан), Бавлинский муниципальный район, г.Бавлы, ул.Пионерская, д.18	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000CE5147C7D5A24A405A457F68E6314B40
93945	7	64	\N	60571	75314	\N	54.395848519925501	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Ленина, 13	Россия, республика Татарстан, поселок Бавлы	0101000020E61000007D772B4B74A24A40C093162EAB324B40
93944	7	64	\N	60571	75314	\N	54.3960926748641	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Ленина, 17	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000E54691B586A24A405796E82CB3324B40
93836	7	64	\N	59161	71121	\N	56.090476666405699	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, пл.Советская, д.17	Россия, республика Татарстан, Арский район, поселок Арск	0101000020E6100000B8239C16BCF04840250516C0940B4C40
93846	7	64	\N	59161	79315	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Молодежная, д.1б		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93845	7	64	\N	59161	71253	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Луговая, д.1		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93834	7	64	\N	59161	68629	\N	56.096210316889298	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Вагизовых, д.14	Россия, республика Татарстан, Арский район, поселок Арск	0101000020E6100000C34659BF99EE48402AC6F99B500C4C40
93833	7	64	\N	59161	68629	\N	56.086589771502098	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Вагизовых, д.11	Россия, республика Татарстан, Арский район, поселок Арск	0101000020E6100000F2EEC8586DF0484090149161150B4C40
93835	7	64	\N	59161	68690	\N	56.101739238932197	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Большая, д.77	Россия, республика Татарстан, Арский район	0101000020E610000063D2DF4BE1F1484027DD96C8050D4C40
93670	7	64	\N	4205	\N	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Шевченко, д.2а	Россия, республика Татарстан, Альметьевск	0101000020E6100000294014CC98284A40DD9733DB15724B40
93704	7	64	\N	4205	70568	\N	54.892600390368997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, пр.Сроителей, д.59	Россия, республика Татарстан, Альметьевск	0101000020E6100000EE4108C897224A406E3480B740724B40
93698	7	64	\N	4205	70568	\N	54.904929440142801	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, пр.Строителей, д.14	Россия, республика Татарстан, Альметьевский район	0101000020E61000004EED0C535B224A40DB19A6B6D4734B40
93666	7	64	\N	4205	68303	\N	54.9082058316394	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, пр.Тукая, д.11а	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000B3CF639467284A40F7031E1840744B40
93696	7	64	\N	4205	77510	\N	54.891784090780902	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, пр.Строителей, д.2	Россия, республика Татарстан, Альметьевск	0101000020E610000098DC28B2D6284A404C8C65FA25724B40
93706	7	64	\N	4205	67754	\N	54.891190407916298	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Шевченко, д.136	Россия, республика Татарстан, Альметьевск	0101000020E6100000D5777E5182284A40D942908312724B40
93700	7	64	\N	4205	67754	\N	54.897757535440903	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Шевченко, д.132	Россия, республика Татарстан, Альметьевский район	0101000020E61000002E3BC43F6C214A4077DCF0BBE9724B40
93687	7	64	\N	4205	67754	\N	54.896038560782799	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Шевченко, д.98	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000C79FA86C58234A406478EC67B1724B40
93683	7	64	\N	4205	67754	\N	54.895444940904099	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Шевченко, д.82	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000116F9D7FBB244A40F12E17F19D724B40
93677	7	64	\N	4205	68404	\N	54.911395419637898	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Чернышевского, д.44а	Россия, республика Татарстан, Альметьевск городской округ	0101000020E610000047E6913F18264A40745E6397A8744B40
93676	7	64	\N	4205	78067	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Чапаева, д.4		0101000020E6100000294014CC98284A40DD9733DB15724B40
93675	7	64	\N	4205	78067	\N	54.888023950867101	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Чапаева, д.4а		0101000020E6100000D61D8B6D52294A4014083BC5AA714B40
93710	7	64	\N	4205	75278	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Фахретдина, д.67		0101000020E6100000294014CC98284A40DD9733DB15724B40
93659	7	64	\N	4205	75278	\N	54.891487250447298	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Фахретдина, д.5	Россия, республика Татарстан, Альметьевск	0101000020E610000071C806D2C5284A4092E7FA3E1C724B40
93668	7	64	\N	4205	68341	\N	54.901492032138101	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Тимирязева, д.39	Россия, республика Татарстан, Альметьевск городской округ	0101000020E610000072DEFFC709274A4085CD001764734B40
93662	7	64	\N	4205	70053	\N	54.907884386210199	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Тельмана, д.57	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000713AC95697294A40E547FC8A35744B40
93661	7	64	\N	4205	70053	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Тельмана, д.86		0101000020E6100000294014CC98284A40DD9733DB15724B40
93658	7	64	\N	4205	70053	\N	54.891091459917703	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Тельмана, д.48	Россия, республика Татарстан, Альметьевск	0101000020E610000023A0C211A4284A40466117450F724B40
93657	7	64	\N	4205	75275	\N	54.891685144247198	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Тагирова, д.33	Россия, республика Татарстан, Альметьевск	0101000020E6100000B13385CE6B284A40B9AAECBB22724B40
93665	7	64	\N	4205	75281	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Сулеймановой, д.20		0101000020E6100000294014CC98284A40DD9733DB15724B40
93694	7	64	\N	4205	75252	\N	54.892278819787599	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, пр.Строителей, д.9а	Россия, республика Татарстан, Альметьевск	0101000020E610000025CADE52CE274A402CF4C13236724B40
93655	7	64	\N	4205	70027	\N	54.911512860861798	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Советская, д.45а	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000006859F78F852C4A407E703E75AC744B40
93654	7	64	\N	4205	68261	\N	54.901130345272101	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Полевая, д.1а	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000009C31CC09DA284A40E5B8533A58734B40
93693	7	64	\N	4205	70260	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Нефтяников, д.41		0101000020E6100000294014CC98284A40DD9733DB15724B40
93691	7	64	\N	4205	70260	\N	54.889904064891802	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Нефтяников, д.14	Россия, республика Татарстан, Альметьевск	0101000020E6100000630B410E4A284A40304AD05FE8714B40
93689	7	64	\N	4205	70260	\N	54.901674420003701	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Нефтяников, д.12	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000973C9E961F244A40A6D3BA0D6A734B40
93684	7	64	\N	4205	67882	\N	54.896527053882799	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Джалиля, д.9	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000002FBE688F17264A40917D9065C1724B40
93690	7	64	\N	4205	69660	\N	54.9007995689567	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Мира, д.10	Россия, республика Татарстан, Альметьевск городской округ	0101000020E610000026E318C91E234A404F1E166A4D734B40
93667	7	64	\N	4205	75284	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Маяковского, д.40		0101000020E6100000294014CC98284A40DD9733DB15724B40
93672	7	64	\N	4205	67662	\N	54.896582704617899	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Лермонтова, д.14	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000008EB1135E82274A402593533BC3724B40
1310	7	64	36	32161	11529	\N	55.914099999999998	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Ачи, ул.Ленина, д.31		0101000020E61000006170CD1DFD21494005A3923A01F54B40
93701	7	64	\N	4205	68372	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Ленина, д.157		0101000020E6100000294014CC98284A40DD9733DB15724B40
93697	7	64	\N	4205	68372	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Ленина, д.124		0101000020E6100000294014CC98284A40DD9733DB15724B40
93688	7	64	\N	4205	68372	\N	54.899328044980997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Ленина, д.98	Россия, республика Татарстан, Альметьевск городской округ	0101000020E610000038A4518193234A4044300E2E1D734B40
93685	7	64	\N	4205	68372	\N	54.892080928917402	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Ленина, д.37	Россия, республика Татарстан, Альметьевск	0101000020E6100000E6046D72F8284A400531D0B52F724B40
93680	7	64	\N	4205	68372	\N	54.903767184089297	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Ленина, д.21	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000005610035DFB264A401E1A16A3AE734B40
93669	7	64	\N	4205	68372	\N	54.9046203327798	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Ленина, д.2	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000008DB62A89EC274A405DA79196CA734B40
93650	7	64	\N	4205	75268	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Кошевого, д.12		0101000020E6100000294014CC98284A40DD9733DB15724B40
93686	7	64	\N	4205	67935	\N	54.904929440142801	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.К.Цеткин, д.54	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000A662635E47264A40DB19A6B6D4734B40
93652	7	64	\N	4205	69983	\N	54.899204385043802	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Интернациональная, д.20	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000F0DFBC38F12B4A405837DE1D19734B40
93681	7	64	\N	4205	75248	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Джалиля, д.41		0101000020E6100000294014CC98284A40DD9733DB15724B40
93702	7	64	\N	4205	75291	\N	54.8921798744746	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Грузинская, д.3	Россия, республика Татарстан, Альметьевск	0101000020E61000004AB4E4F1B4284A40991249F432724B40
93664	7	64	\N	4205	70117	\N	54.9048799831249	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Герцена, д.86	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000001DE4F560522A4A40F9669B1BD3734B40
93653	7	64	\N	4205	70117	\N	54.891292	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Герцена, д.86а		0101000020E6100000294014CC98284A40DD9733DB15724B40
93699	7	64	\N	4205	70894	\N	54.906561487498799	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Гафиатуллина, д.29а	Россия, республика Татарстан, Альметьевский район	0101000020E6100000DE21C50089224A401F6ADB300A744B40
93692	7	64	\N	4205	70894	\N	54.890695665481999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Гафиатуллина, д.28	Россия, республика Татарстан, Альметьевск	0101000020E61000008DEF8B4B55284A40C956975302724B40
93651	7	64	\N	4205	75269	\N	54.890599325278501	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Волгоградская, д.24	Россия, республика Татарстан, Альметьевск	0101000020E6100000B13385CE6B284A40D76CE525FF714B40
93682	7	64	\N	4205	67567	\N	54.904224671876896	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Белоглазова, д.131а	Россия, республика Татарстан, Альметьевск городской округ	0101000020E610000058C85C1954254A40E09C11A5BD734B40
93678	7	64	\N	4205	67567	\N	54.905782564095801	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Белоглазова, д.60	Россия, республика Татарстан, Альметьевск городской округ	0101000020E610000048E17A14AE254A40EA2285B2F0734B40
93674	7	64	\N	4205	67567	\N	54.908947618943898	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Белоглазова, д.20	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000001975ADBD4F274A40DFE1766858744B40
93707	7	64	\N	4205	68017	\N	54.911519041969299	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Аминова, д.2а	Россия, республика Татарстан, Альметьевский район	0101000020E6100000514B732B84214A40605793A7AC744B40
93663	7	64	\N	4205	70075	\N	54.906165845757201	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.8 Марта, д.30	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000C36169E047294A40A25F5B3FFD734B40
93703	7	64	\N	4205	70984	\N	54.891687753192102	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.70 лет Октября, д.1	Россия, республика Татарстан, Альметьевск	0101000020E61000008DEF8B4B55284A402A1E17D522724B40
1263	7	64	\N	61508	79267	\N	55.614170000000001	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Азьмушкино, ул.Центральная, д.35А	Россия	0101000020E61000003694DA8B683B4A409817601F9DCE4B40
93388	7	64	\N	23555	79333	\N	54.864140690999697	423330, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Азнакаевский муниципальный район, г.Азнакаево, ул.Школьная (здание школы №2), д.2	Россия, республика Татарстан, Азнакаево	0101000020E6100000E222F77475894A40FD101B2C9C6E4B40
93400	7	64	\N	23555	75244	\N	54.860771999999997	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Хасаншиной, д.21		0101000020E6100000A2B77878CF894A4000A8E2C62D6E4B40
93401	7	64	\N	23555	68108	\N	54.853594250280899	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Хасанова, д.24	Россия, республика Татарстан, Азнакаево	0101000020E61000002B85402E718A4A40EA077591426D4B40
93396	7	64	\N	23555	68108	\N	54.852653353382699	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Хасанова, д.5	Россия, республика Татарстан, Азнакаево	0101000020E6100000A5BBEB6CC8894A400BEBC6BB236D4B40
93395	7	64	\N	23555	68108	\N	54.860771999999997	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Хасанова, д.19		0101000020E6100000A2B77878CF894A4000A8E2C62D6E4B40
93402	7	64	\N	23555	67709	\N	54.857270964920303	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Султангалиева, д.27	Россия, республика Татарстан, Азнакаево	0101000020E610000061C3D32B658B4A4094675E0EBB6D4B40
93394	7	64	\N	23555	67709	\N	54.857072901330497	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Султангалиева, д.23а	Россия, республика Татарстан, Азнакаево	0101000020E61000004F3BFC35598B4A406EA46C91B46D4B40
93393	7	64	\N	23555	67709	\N	54.860771999999997	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Султангалиева, д.21а		0101000020E6100000A2B77878CF894A4000A8E2C62D6E4B40
93390	7	64	\N	23555	75235	\N	54.860771999999997	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Пушкина, д.1		0101000020E6100000A2B77878CF894A4000A8E2C62D6E4B40
93386	7	64	\N	23555	69687	\N	54.8584964616579	423330, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Азнакаевский муниципальный район, г.Азнакаево, ул.Лениногорский тракт (здание школы №9), д.2а	Россия, республика Татарстан, Азнакаево	0101000020E61000007E737FF5B8894A4098DF6932E36D4B40
93385	7	64	\N	23555	69687	\N	54.867086267477099	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Лениногорский тракт, д.2	Россия, республика Татарстан, Азнакаево	0101000020E61000005D6BEF5355864A40E4688EACFC6E4B40
93397	7	64	\N	23555	67628	\N	54.851947666242303	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Ленина, д.36	Россия, республика Татарстан, Азнакаево	0101000020E6100000EFAB72A1F2894A4041F2CEA10C6D4B40
93391	7	64	\N	23555	67628	\N	54.858505745581297	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Ленина, д.18	Россия, республика Татарстан, Азнакаево	0101000020E6100000DCF4673F528A4A40BBB54C86E36D4B40
93389	7	64	\N	23555	67628	\N	54.862135595137303	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Ленина, д.1	Россия, республика Татарстан, Азнакаево	0101000020E61000003FA9F6E9788A4A40255AF2785A6E4B40
93399	7	64	\N	23555	69864	\N	54.850845779068599	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Гагарина, д.9	Россия, республика Татарстан, Азнакаево	0101000020E6100000D061BEBC00894A4059F78F85E86C4B40
93398	7	64	\N	23555	69864	\N	54.851638150426602	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Гагарина, 9	Россия, республика Татарстан, Азнакаево	0101000020E61000002B85402E718A4A40F3035779026D4B40
93392	7	64	\N	23555	69618	\N	54.856986248202702	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, город Азнакаево, ул.Булгар, д.18	Россия, республика Татарстан, Азнакаево	0101000020E6100000C23577F4BF8A4A409F909DB7B16D4B40
93338	7	64	\N	61539	79362	\N	56.518889999999999	422230, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Агрызский муниципальный район, г.Агрыз, ул.Гоголя (здание детской поликлиники), д.6а		0101000020E610000014234BE658804A40581CCEFC6A424C40
94238	7	64	7510	60611	75448	\N	55.932917165577003	Республика Татарстан (Татарстан), Высокогорский муниципальный район, поселок ж.д.ст.Высокая Гора, ул.Пролетарская, д.1	Россия, республика Татарстан, поселок ж д ст Высокая Гора	0101000020E6100000A48AE255D6A64840F47002D369F74B40
1045	7	64	923	41030	12189	\N	54.5948844535774	п.г.т.Уруссу, ул.Пушкина, д.70	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E6100000B282DF8618BB4A40F374AE28254C4B40
1453	7	64	923	7466	11691	\N	54.581249	д.Яссы-Тугай, ул.Тукая, д.21	Россия, республика Татарстан, Ютазинский район, село Яссы-Тугай	0101000020E6100000ECF65965A6AA4A4096EA025E664A4B40
1464	7	64	923	7925	11702	\N	54.590004	с.Ютаза, ул.Загот-Зерно, д.68		0101000020E6100000946DE00ED4A14A402D414640854B4B40
1463	7	64	923	40942	11705	\N	54.590004	с.Ютаза, ул.Дмитрова, д.9		0101000020E6100000946DE00ED4A14A402D414640854B4B40
54058	7	62	\N	1218	62228	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Советская, д. 158		0101000020E6100000628731E9EFEF4740ACE122F774514C40
1349	7	64	923	32544	11440	\N	54.5936883038909	п.г.т.Уруссу, ул.Уруссинская, д.1 Б	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E6100000FDDAFAE93FBB4A408A03E8F7FD4B4B40
1300	7	64	923	32544	11440	\N	54.598970999999999	п.г.т.Уруссу, ул.Уруссинская, д.1А		0101000020E6100000793BC269C1B94A404F20EC14AB4C4B40
1215	7	64	923	32544	11440	\N	54.598970999999999	п.г.т.Уруссу, ул.Уруссинская, д.44		0101000020E6100000793BC269C1B94A404F20EC14AB4C4B40
1251	7	64	923	32544	11273	\N	54.598818707739802	п.г.т.Уруссу, ул.Пушкина, д.22	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E61000005C59A2B3CCBA4A40999CDA19A64C4B40
1079	7	64	923	32544	11273	\N	54.594734936796499	п.г.т.Уруссу, ул.Пушкина, 70	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E6100000D82E6D382CBB4A40AE64C746204C4B40
1409	7	64	923	32544	11632	\N	54.598970999999999	п.г.т.Уруссу, ул.Поэта Сирина, д.44	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E6100000793BC269C1B94A404F20EC14AB4C4B40
1447	7	64	923	32544	11680	\N	54.595295427200703	п.г.т.Уруссу, ул.Мияссарова, д.69	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E6100000FA27B85851BB4A40753C66A0324C4B40
1466	7	64	923	32544	11707	\N	54.596004059760197	п.г.т.Уруссу, ул.Луговая, д.64	Россия, республика Татарстан, Ютазинский район, поселок Уруссу	0101000020E6100000A77686A92DBB4A408124ECDB494C4B40
1458	7	64	923	40943	11710	\N	54.688253000000003	д.Урал, ул.Уральская, д.10 А	Россия, республика Татарстан, Ютазинский район, село Урал	0101000020E6100000DDB3AED172904A40DC2F9FAC18584B40
1459	7	64	923	7726	11701	\N	54.758375999999998	с.Старый Каразерик, ул.Советская, д.15	Россия, республика Татарстан, Ютазинский район, село Старый Каразерик	0101000020E6100000B22C98F8A3CC4A402009FB7612614B40
1460	7	64	923	61310	78517	\N	54.602804999999996	с.Старые Уруссу, ул.Советская, д.45 А	Россия, республика Татарстан, Ютазинский район, село Старые Уруссы	0101000020E6100000946A9F8EC7B24A40C16ED8B6284D4B40
985	7	64	923	16532	11228	\N	54.644797077922803	Республика Татарстан (Татарстан), Пестречинский муниципальный район, д.Салкын-Чишма, ул.Нариманова, д.50		0101000020E610000001892650C4A04A408AC745B588524B40
1462	7	64	923	61317	78538	\N	54.638267999999997	д.Малые Уруссу, ул.Советская, д.18 Б	Россия, республика Татарстан, Ютазинский район, село Малые Уруссы	0101000020E610000099D9E731CAAF4A40AA0A0DC4B2514B40
1457	7	64	923	32614	11706	\N	54.680483000000002	с.Каракашлы, ул.Мирфатиха Закиева, д.19	Россия, республика Татарстан, Ютазинский район, село Каракашлы	0101000020E6100000E2CB4411529F4A40F33D23111A574B40
1451	7	64	923	7393	11699	\N	54.525880999999998	с.Дым-Тамак, ул.Ленина, д.1 В		0101000020E610000053CF8250DEAD4A403C4B901150434B40
1454	7	64	923	7545	11693	\N	54.707726488958301	с.Байряка, ул.Октября, д.1 А		0101000020E610000099840B7904AF4A40B343FCC3965A4B40
1455	7	64	923	7545	79268	\N	54.711652600005401	с.Байряки-Тамак, ул.Новая, д.36	Россия, республика Татарстан, Ютазинский район, село Байряка	0101000020E6100000BADC60A8C3B04A40D68C0C72175B4B40
1461	7	64	923	7817	11700	\N	54.604723	с.Байларово, ул.Тукая, д.41		0101000020E61000007D7901F6D1BD4A40CB113290674D4B40
1465	7	64	923	61494	79252	\N	54.644094159648198	д.Алма-Ата, ул.Зеленая, д.1 А	Россия, республика Татарстан, Ютазинский район, село Алма-Ата	0101000020E6100000759483D904924A4061C614AC71524B40
1452	7	64	923	40935	11689	\N	54.507458	д.Алабакуль, ул.Центральная, д.8 А		0101000020E6100000149337C0CCAB4A40FA0B3D62F4404B40
1449	7	64	923	32567	11683	\N	54.566437999999998	с.Абсалямово, ул.Советская, д.50 А		0101000020E61000002E910BCEE0B54A40179B560A81484B40
1411	7	64	763	5360	11634	\N	55.370292999999997	Республика Татарстан (Татарстан), Чистопольский муниципальный район, п.Юлдуз, ул.Полевая, д.10		0101000020E6100000B0E2546B615A49400778D2C265AF4B40
1446	7	64	763	7153	11677	\N	55.349255999999997	Республика Татарстан (Татарстан), Чистопольский муниципальный район, п.Луч, ул.Победы, д.16	Россия, республика Татарстан, Чистопольский район, село совхоз Луч	0101000020E610000081768714034C494044F7AC6BB4AC4B40
1434	7	64	763	6596	11666	\N	55.145138000000003	Республика Татарстан (Татарстан), Чистопольский муниципальный район, д.Чулпан, ул.Театральная, д.2а		0101000020E6100000A1F48590F352494014B4C9E193924B40
1429	7	64	763	6296	11659	\N	55.080075999999998	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Чувашский Елтан, ул.Школьная, д.15в		0101000020E610000088BA0F406A574940E5982CEE3F8A4B40
1448	7	64	763	7273	11696	\N	55.332308498095799	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Чистопольские Выселки, ул.Чапаева, д.64а	Россия, республика Татарстан, Чистопольский район, село Чистопольские Выселки	0101000020E6100000505436ACA95449407E198C1189AA4B40
1410	7	64	763	40924	11635	\N	55.378712999999998	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Дорожная, д.7		0101000020E6100000C6C03A8E1F484940F7C8E6AA79B04B40
1413	7	64	763	5468	11637	\N	55.429445000000001	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Четырчи, ул.Зеленая, д.12		0101000020E6100000137D3ECA887949402237C30DF8B64B40
1437	7	64	763	6710	11668	\N	55.219945000000003	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Четыре Двора, ул.Школьная, д.9		0101000020E6100000664B5645B841494099F56228279C4B40
1438	7	64	763	6782	11669	\N	55.185538000000001	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Татарское Адельшино, ул.Сатдарова, д.32		0101000020E61000005EDA70581A3C494027158DB5BF974B40
1423	7	64	763	5973	11652	\N	55.227525	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Татарский Толкиш, ул.Советская, д.4		0101000020E61000009F91088D60574940DE02098A1F9D4B40
1198	7	64	1778	26958	11425	\N	55.139091999999998	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Измери, ул.Школьная, д.8		0101000020E61000004AB3791C06C548404F9143C4CD914B40
1421	7	64	763	5868	11649	\N	55.249519999999997	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Татарский Сарсаз, ул.Центральная, д.13		0101000020E6100000081EDFDE356A494055D97745F09F4B40
1427	7	64	763	6182	11656	\N	55.120063000000002	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Татарский Елтан, ул.Кооперативная, д.9		0101000020E61000005E0EBBEF18664940D63A71395E8F4B40
1433	7	64	763	6512	11664	\N	55.14555	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Татарская Багана, ул.Центральная, д.35а		0101000020E6100000A56ABB09BE49494066F7E461A1924B40
1418	7	64	763	5712	11645	\N	55.261094999999997	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Старое Ромашкино, ул.Центральная, д.29		0101000020E61000001D5BCF108E6F494016139B8F6BA14B40
1441	7	64	763	6892	11674	\N	55.312978000000001	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Старое Иванаево, ул.Овражная, д.1		0101000020E6100000AD6A4947393649400A2FC1A90FA84B40
1431	7	64	763	6397	11662	\N	55.064798000000003	Республика Татарстан (Татарстан), Чистопольский муниципальный район, д.Нижняя Кондрата, ул.Комсомольская, д.31		0101000020E6100000BC57AD4CF8494940516C054D4B884B40
1439	7	64	763	6818	11670	\N	55.255671999999997	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Нарат-Елга, ул.Центральная, д.1	Россия, республика Татарстан, Чистопольский район, село Нарат Елга	0101000020E6100000942EFD4B524949405F402FDCB9A04B40
1435	7	64	763	6608	11665	\N	55.199444	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Муслюмкино, ул.Пионерская, д.10		0101000020E61000002F35423F534D494014B1886187994B40
1416	7	64	763	5635	11643	\N	55.343978	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Малый Толкиш, ул.Центральная, д17		0101000020E610000091B8C7D28778494091459A7807AC4B40
1440	7	64	763	6866	11671	\N	55.235790000000001	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Кутлушкино, ул.Клубная, д.18		0101000020E610000092AF045262314940A75CE15D2E9E4B40
1443	7	64	763	6993	11688	\N	55.38841	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Кубассы, ул.Центральная, д.3	Россия, республика Татарстан, Чистопольский район, село Кубассы	0101000020E61000002A1E17D5223249403DB83B6BB7B14B40
1415	7	64	763	5549	11642	\N	55.386732000000002	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Красный Яр, ул.Пришкольная, д.1а		0101000020E61000009CC58B85219C49408928266F80B14B40
1424	7	64	763	6056	11655	\N	55.259765999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Кзыл-Ялан, ул.Гиниятуллина, д.22		0101000020E6100000E0BA6246785949406E4E250340A14B40
1425	7	64	763	6084	11653	\N	55.246876999999998	Республика Татарстан (Татарстан), Чистопольский муниципальный район, д.Кзыл Болгар, ул.Зеленая, д.16а		0101000020E610000041D7BE805E5449403A9160AA999F4B40
1420	7	64	763	5846	11648	\N	55.216909999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Каргали, ул.Чапаева, д.2а		0101000020E61000005A626534F27349407216F6B4C39B4B40
1430	7	64	763	6382	11660	\N	55.062421000000001	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Ишалькино, ул.Красноармейская, д.6		0101000020E6100000651A4D2EC65E4940B4CA4C69FD874B40
1419	7	64	763	5791	11647	\N	55.290342000000003	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Исляйкино, ул.8 Марта, д.20б		0101000020E610000045A0FA07917C4940DF5339ED29A54B40
1426	7	64	763	6177	11654	\N	55.170388000000003	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Изгары, ул.Школьная, д.13		0101000020E61000006F0ED76A0F654940C0D02346CF954B40
1444	7	64	763	7054	11675	\N	55.365800999999998	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Данауровка, ул.Центральная, д.30а		0101000020E610000032005471E34649400BEC3191D2AE4B40
1432	7	64	763	6478	11663	\N	55.086976	Республика Татарстан (Татарстан), Чистопольский муниципальный район, д.Верхняя Кондрата, ул.Ивана Чалмаева, д.4		0101000020E6100000AC5791D1014B4940B9C49107228B4B40
1412	7	64	763	5394	11636	\N	55.418430000000001	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Булдырь, ул.Центральная, д.23		0101000020E61000004415FE0C6F6E494028D53E1D8FB54B40
1414	7	64	763	5519	11640	\N	55.351317999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Большой Толкиш, ул.Набережная, д.39		0101000020E6100000075E2D77668A4940813FFCFCF7AC4B40
1445	7	64	763	7102	11676	\N	55.290458999999998	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Белая Гора, ул.Центральная, д.26		0101000020E6100000581D39D21940494018EAB0C22DA54B40
1436	7	64	763	6684	11667	\N	55.191006999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Бахта, ул.Широкая, д.48		0101000020E610000096422097384849404E27D9EA72984B40
1442	7	64	763	6964	11673	\N	55.358043000000002	Республика Татарстан (Татарстан), Чистопольский муниципальный район, д.Байтеряково, ул.Речная, д.19		0101000020E610000073F56393FC2E4940E7C75F5AD4AD4B40
1417	7	64	763	5702	11644	\N	55.344361999999997	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Александровка, ул.Школьная, д.7		0101000020E6100000F7949C137B64494019FED30D14AC4B40
1428	7	64	763	6265	11657	\N	55.119286000000002	Республика Татарстан (Татарстан), Чистопольский муниципальный район, с.Акбулатово, ул.Октябрская, д.26		0101000020E6100000B16CE690D44E4940726F7EC3448F4B40
55220	7	63	\N	1332	54470	\N	54.172535000000003	Республика Мордовия, город Саранск, Ленинский район, М.Расковой, 17а		0101000020E6100000CA6C9049469246402B357BA015164B40
1404	7	64	6928	40920	11623	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Энгельса, д.78		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1392	7	64	6928	40920	11608	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Чернышевского, д.167	Россия, республика Татарстан, Чистополь	0101000020E6100000003B376DC651494003EB387EA8AE4B40
1386	7	64	6928	40920	11602	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Урицкого, д.45		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1396	7	64	6928	40920	11613	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Тукая, д.54Б	Россия, республика Татарстан, Чистополь	0101000020E6100000003B376DC651494003EB387EA8AE4B40
1390	7	64	6928	40920	11606	\N	55.346817852716399	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Студенческая, д.1	Россия, республика Татарстан, Чистополь городской округ	0101000020E6100000724D81CCCE52494002D53F8864AC4B40
1378	7	64	6928	40920	11591	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Мира, д.42		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1382	7	64	6928	40920	11601	\N	55.3629525678394	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Льва Толстого, д.144	Россия, республика Татарстан, Чистополь	0101000020E6100000C5C9FD0E45514940177E703E75AE4B40
1397	7	64	6928	40920	11615	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Крупской, д.32	Россия, республика Татарстан, Чистополь	0101000020E6100000003B376DC651494003EB387EA8AE4B40
1391	7	64	6928	40920	11598	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Карла Маркса, д.164	Россия, республика Татарстан, Чистополь	0101000020E6100000003B376DC651494003EB387EA8AE4B40
1389	7	64	6928	40920	11598	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Карла Маркса, д.168	Россия, республика Татарстан, Чистополь	0101000020E6100000003B376DC651494003EB387EA8AE4B40
1388	7	64	6928	40920	11598	\N	55.376055377912103	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Карла Маркса, д.142	Россия, республика Татарстан, Чистополь городской округ	0101000020E61000005872158BDF544940A73FFB9122B04B40
1384	7	64	6928	40920	11598	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Карла Маркса, д.78		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1403	7	64	6928	40920	11622	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Гуськова, д.18Б		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1381	7	64	6928	40920	11594	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Бутлерова, д.7А		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1383	7	64	6928	40920	11597	\N	55.347698228635103	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Бебеля, д.121	Россия, республика Татарстан, Чистополь городской округ	0101000020E6100000C075C58CF05249403B71395E81AC4B40
1406	7	64	6928	40920	11625	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Академика Королева, д.5		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1398	7	64	6928	40920	11617	\N	55.364516999999999	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Айвазовского, д.81		0101000020E6100000003B376DC651494003EB387EA8AE4B40
1376	7	64	319	61511	79271	\N	54.738934189678801	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Шешминка, ул.Комарова, д.14	Россия, республика Татарстан, Черемшанский район, село Шешминская Крепость	0101000020E6100000F86D88F19ADF494084F3A963955E4B40
1377	7	64	319	3555	11587	\N	54.798752999999998	Республика Татарстан (Татарстан), Черемшанский муниципальный район, п.Чумачка, ул.Ленина, д.33		0101000020E6100000CCB392567CDD49407B4ACE893D664B40
1375	7	64	319	3454	11586	\N	54.824347000000003	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Черный Ключ, ул.Советская, д.77		0101000020E6100000BEA4315A47C7494022C7D63384694B40
1370	7	64	319	3109	11581	\N	54.652166999999999	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Черемшан, ул.Шешминская, д.2		0101000020E61000001AA20A7F86BF4940E54350357A534B40
1371	7	64	319	3109	11585	\N	54.652166999999999	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Черемшан, ул.Техническая, д.36		0101000020E61000001AA20A7F86BF4940E54350357A534B40
1369	7	64	319	3109	11579	\N	54.652166999999999	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Черемшан, ул.Советская, д.34		0101000020E61000001AA20A7F86BF4940E54350357A534B40
1373	7	64	319	3109	11584	\N	54.652166999999999	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Черемшан, ул.Молодежная, д.60	Россия, республика Татарстан, Черемшанский район, село Черемшан	0101000020E61000001AA20A7F86BF4940E54350357A534B40
1372	7	64	319	3109	11629	\N	54.652166999999999	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Черемшан, ул.Гагарина, д.42		0101000020E61000001AA20A7F86BF4940E54350357A534B40
1361	7	64	319	61412	79146	\N	54.750538591274299	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Утыз Имян, ул.Советская, д.51	Россия, республика Татарстан, Черемшанский район, село Новое Кадеево	0101000020E6100000A032FE7DC69D4940B0AF75A911604B40
1368	7	64	319	3048	11577	\N	54.725020000000001	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Ульяновка, ул.Центральная, д.46		0101000020E6100000FCA886FD9EA0494014799274CD5C4B40
1367	7	64	319	2990	11630	\N	54.790115999999998	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Туйметкино, ул.Школьная, д.1		0101000020E610000003D19332A9C54940EE05668522654B40
1366	7	64	319	2931	11576	\N	54.607790000000001	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Старый Утямыш, ул.Мусы Джалиля, д.54		0101000020E6100000DC9C4A0680D24940FD6A0E10CC4D4B40
1365	7	64	319	2875	11575	\N	54.695315000000001	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Старые Кутуши, ул.Свежухина, д.34		0101000020E6100000376DC669888E494089B5F81400594B40
1364	7	64	319	2815	11574	\N	54.744408999999997	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Старое Кадеево, ул.Тукая, д.12		0101000020E6100000D2C43BC0939649408DEC4ACB485F4B40
1363	7	64	319	2751	11573	\N	54.752021999999997	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Старое Ильмово, ул.Луговая, д.22		0101000020E61000005AF624B039A94940AEEFC34142604B40
1362	7	64	319	2692	11572	\N	54.609890999999998	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Подлесный Утямыш, ул.Советская, д.12а		0101000020E610000033E197FA79DD4940F78F85E8104E4B40
1360	7	64	319	2584	11571	\N	54.739415000000001	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Новое Ильмово, ул.Ключевая, д.15		0101000020E61000002DEA93DC61B14940FF959526A55E4B40
1359	7	64	319	61423	79159	\N	54.637060610246699	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Нижний Чегодай, ул.Советская, д.36а	Россия, республика Татарстан, Черемшанский район, село Нижняя Чегодайка	0101000020E610000074ECA012D7C749404E4700378B514B40
1358	7	64	319	2473	11570	\N	54.787640000000003	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Нижняя Кармалка, ул.Ленина, д.9		0101000020E6100000BEA59C2FF6D04940BF823463D1644B40
1357	7	64	319	2427	11569	\N	54.858041	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Нижняя Каменка, ул.Центральная, д.60	Россия, республика Татарстан, Черемшанский район, село Нижняя Каменка	0101000020E610000047551344DDBB494046D09849D46D4B40
1356	7	64	319	2362	11568	\N	54.691319	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Мордовское-Афонькино, ул.Цаплина, д.17		0101000020E6100000BA2F67B62BDA49403D0D18247D584B40
1355	7	64	319	2306	11566	\N	54.737850000000002	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Лашманка, ул.Советская, д.55		0101000020E6100000A7785C548BBA494043AD69DE715E4B40
1354	7	64	319	2241	11567	\N	54.664988999999998	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Лагерка, ул.Школьная, д.22		0101000020E61000001118EB1B98DE494091990B5C1E554B40
1353	7	64	319	2196	11565	\N	54.845098999999998	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Кутема, ул.Клубная, д.1а		0101000020E6100000D9E9077591B04940EF703B342C6C4B40
1352	7	64	319	2127	11564	\N	54.901775999999998	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Карамышево, ул. Бари Габдрахманова, д.44а		0101000020E6100000952BBCCB45B64940AA285E656D734B40
1351	7	64	319	2017	11563	\N	54.668191999999998	423100, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Черемшанский муниципальный район, д.Казанка, ул.Школьная (здание начальной школы), д.36		0101000020E6100000C68844A165AD494073B9C15087554B40
1348	7	64	319	1877	11562	\N	54.882866999999997	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Ивашкино, ул.Центральная, д.36		0101000020E61000004AB6BA9C12AA4940DBDB2DC901714B40
1347	7	64	319	61398	79129	\N	54.651852417674398	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Верхний Чегодай, ул.Советская, д.25а	Россия, республика Татарстан, Черемшанский район, село Верхняя Чегодайка	0101000020E61000003E3C4B9011CE494085EAE6E26F534B40
1346	7	64	319	1766	11561	\N	54.747526999999998	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Верхняя Кармалка, ул.Советская, д.13		0101000020E61000002E724F5777CA494041F0F8F6AE5F4B40
1345	7	64	319	1721	11560	\N	54.807290000000002	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Верхняя Каменка, ул.Дружбы, д.6		0101000020E610000030A182C30BBC4940A5315A4755674B40
1344	7	64	319	1679	11558	\N	54.813957000000002	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Беркет-Ключ, ул.Ленина, д.75		0101000020E61000006000E14389D04940D6AC33BE2F684B40
1343	7	64	319	1577	11559	\N	54.719954999999999	Республика Татарстан (Татарстан), Черемшанский муниципальный район, д.Андреевка, ул. Высоцкого, д.35/1		0101000020E6100000215C01857AE64940BCCB457C275C4B40
1342	7	64	319	1568	11557	\N	54.746747999999997	Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Амирово, ул.Школьная, д.30		0101000020E6100000921FF12BD6BE49403C2D3F70955F4B40
1315	7	64	36	32402	11533	\N	55.834814999999999	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Баландыш, ул.Ленина, д.2		0101000020E610000018CC5F21733B4940E99AC937DBEA4B40
22605	7	61	659	46686	65038	\N	54.617643999999999	Комсосмольск, Беркут Тау, 43		0101000020E6100000D61BB5C2F4DD4D400A4966F50E4F4B40
1341	7	64	319	1447	11555	\N	54.905990819404799	423113, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Черемшанский муниципальный район, с.Аккиреево, ул.Школьная (здание Сельского Дома культуры), д.30	Россия, республика Татарстан, Черемшанский район, село Аккиреево	0101000020E6100000292504ABEAB3494034BC5983F7734B40
1322	7	64	36	41034	12262	\N	55.823236999999999	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Большие Нырсы, ул.Школьная, д.5	Россия, республика Татарстан, Тюлячинский район, село Пановая Гора	0101000020E6100000F2ED5D83BE224940B7ED7BD45FE94B40
1320	7	64	36	219	11539	\N	55.820607569937998	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, с.Шармаши, ул.Школьная, д.43	Россия, республика Татарстан, Тюлячинский район, село Шармаши	0101000020E6100000F2D1E28C61204940016BD5AE09E94B40
1323	7	64	36	419	11542	\N	55.720930000000003	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Шадки, ул.Ленина, д.2		0101000020E61000003A22DFA5D4194940475A2A6F47DC4B40
1335	7	64	36	61452	79197	\N	55.895211720160503	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Урумширма, ул.Верхняя, д.21А	Россия, республика Татарстан, Тюлячинский район, село Уруширма	0101000020E61000007C26FBE7692649404E7E8B4E96F24B40
1317	7	64	36	44	11536	\N	55.864899000000001	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, пос.Узяк, ул.Татарстан, д.4		0101000020E610000044C18C2958234940EBABAB02B5EE4B40
1318	7	64	36	44	11537	\N	55.864899000000001	422092, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Тюлячинский муниципальный район, пос.Узяк, ул.Каримовой  (здание школы), д.1	Россия, республика Татарстан, Тюлячинский район, село Узяк	0101000020E610000044C18C2958234940EBABAB02B5EE4B40
1308	7	64	36	32058	11526	\N	55.889785000000003	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, с.Тюлячи, ул.Школьная, д.3	Россия, республика Татарстан, Тюлячинский район, село Тюлячи	0101000020E61000004DBF44BC751E494056BC9179E4F14B40
1309	7	64	36	32058	11525	\N	55.889785000000003	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, с.Тюлячи, ул.Ленина, д.82		0101000020E61000004DBF44BC751E494056BC9179E4F14B40
1307	7	64	36	32058	11525	\N	55.889785000000003	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, с.Тюлячи, ул.Ленина, д.40		0101000020E61000004DBF44BC751E494056BC9179E4F14B40
1333	7	64	36	993	11550	\N	55.934961000000001	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Трюк-Тямти, ул.Центральная, д.7		0101000020E6100000492EFF21FD0E49408A0453CDACF74B40
1314	7	64	36	32309	11532	\N	55.753371999999999	422095, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Субаш, ул.Ленина (здание школы), д.25		0101000020E610000087890629783849406EDC627E6EE04B40
1336	7	64	36	1228	11552	\N	55.728484000000002	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Старый Карабаян, ул.Пушкина, д.10		0101000020E6100000191F662FDB30494063D4B5F63EDD4B40
1316	7	64	36	32413	11535	\N	55.870491000000001	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Ст.Зюри, ул.Школьная, д.1А		0101000020E610000083A5BA80972D49402E3BC43F6CEF4B40
1321	7	64	36	291	11540	\N	55.797938000000002	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Сауш, ул.Сиразетдинова, д.47	Россия, республика Татарстан, Тюлячинский район, село Сауш	0101000020E61000004277499C151949402A1E17D522E64B40
1328	7	64	36	41035	12263	\N	55.823236999999999	422082, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Ямбулат, ул.Нагуманова (здание сельского ДК), д.18	Россия, республика Татарстан, Тюлячинский район, село Пановая Гора	0101000020E6100000F2ED5D83BE224940B7ED7BD45FE94B40
1331	7	64	36	61516	79280	\N	55.943800177137803	422080, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Малые Кибякози, ул.Малая (здание школы), д.10	Россия, республика Татарстан, Тюлячинский район, село Малые Кибя Кози	0101000020E61000004FAE2990D91949407FFB3A70CEF84B40
1334	7	64	36	1100	11551	\N	56.001997000000003	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Максабаш, ул.Татарстан, д.27		0101000020E610000006D49B51F30D494056D80C7041004C40
1329	7	64	36	783	11549	\N	55.933422999999998	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, пос.Лесной, ул.Татарстан, д.8		0101000020E6100000BA8102EFE4014940C72AA5677AF74B40
1325	7	64	36	538	11543	\N	55.864096000000004	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Кукча, ул.Шоссейная, д.67		0101000020E610000094BDA59C2F1449405E4D9EB29AEE4B40
1332	7	64	36	61406	79138	\N	55.976582879190097	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Верхние Кибякози, ул.Ленина, д.1А	Россия, республика Татарстан, Тюлячинский район, село Верхние Кибя-Кози	0101000020E61000001D058882191349402F6AF7AB00FD4B40
1326	7	64	36	604	11544	\N	55.886457999999998	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Большие Метески, ул. Фатиха Хусни, д.56А		0101000020E6100000A305685BCD0A494087A3AB7477F14B40
1311	7	64	36	32231	11530	\N	55.820318999999998	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Большая Меша, ул.Школьная, д.2		0101000020E61000000CE8853B17444940CAA4863600E94B40
1324	7	64	36	61460	79206	\N	55.877155557666299	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Алан, ул.Октябрьская, д.211	Россия, республика Татарстан, Тюлячинский район, село Алан-Зире	0101000020E61000005C0531D0B5314940BEBED6A546F04B40
1312	7	64	36	32278	11531	\N	55.764074999999998	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Айдарово, ул.Ленина, д.34		0101000020E610000062F71DC3633149407958A835CDE14B40
1279	7	64	1883	30663	11495	\N	55.628124	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Татарстан, ул.Школьная, д.18		0101000020E61000008DEE2076A64C4A4096EA025E66D04B40
1278	7	64	1883	30663	11494	\N	55.629628761428798	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Татарстан, ул.Советская, д.2	Россия, республика Татарстан, Тукаевский район, село п. Совхоза Татарстан	0101000020E61000004CFF9254A64C4A407DCEDDAE97D04B40
1280	7	64	1883	30663	11496	\N	55.628124	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Татарстан, ул.Нагорная, д.5		0101000020E61000008DEE2076A64C4A4096EA025E66D04B40
1306	7	64	1883	61507	79266	\N	55.440404994810301	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Яна-Буляк, ул.Тукая, д.38	Россия, республика Татарстан, Тукаевский район, село Янга-Буляк	0101000020E6100000CCB8A981E63B4A4058FFE7305FB84B40
1303	7	64	1883	31846	11522	\N	55.472448999999997	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Тлянче-Тамак, ул.Татарстан, д.6		0101000020E61000004F3FA88B14504A409203763579BC4B40
1302	7	64	1883	31832	11520	\N	55.490488570291298	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Старый Дрюш, ул.Тукая, д.21	Россия, республика Татарстан, Тукаевский район, село Старый Дрюш	0101000020E6100000BF9CD9AED0414A401C06F357C8BE4B40
1290	7	64	1883	31229	11508	\N	55.622314000000003	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Старые Ерыклы, ул.Центральная, д.16А	Россия, республика Татарстан, Тукаевский район, село Старые Ерыклы	0101000020E610000007978E39CF1E4A40E6EB32FCA7CF4B40
1299	7	64	1883	31706	11517	\N	55.541769000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Старое абдулово, ул.Центральная, д.16		0101000020E6100000946DE00ED4554A404A7EC4AF58C54B40
1297	7	64	1883	31600	11515	\N	55.605581999999998	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Семекеево, ул.Биктимирова, д.42		0101000020E610000078EDD286C35E4A40EC8502B683CD4B40
1298	7	64	1883	31632	11516	\N	55.584650000000003	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Саитово, ул.Торговая, д.28		0101000020E61000004A5F0839EF594A409FCDAACFD5CA4B40
1262	7	64	1883	61217	77632	\N	55.701900631799901	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Новый, ул.Центральная, д.1		0101000020E610000049F4328AE5544A40CD0358E4D7D94B40
1292	7	64	1883	40917	11528	\N	55.6202855450478	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Новотроицкое, ул.Ленина, д.11		0101000020E6100000596ABDDF68334A4055151A8865CF4B40
1294	7	64	1883	31455	11512	\N	55.613422	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Нижний Суык-Су, ул.Центральная, д.1А		0101000020E6100000EC2E505260254A40CE52B29C84CE4B40
1291	7	64	1883	31281	11509	\N	55.512689000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Мусабай-Завод, ул.Ленина, д.33А		0101000020E6100000CADDE7F868334A406D020CCB9FC14B40
1289	7	64	1883	31192	11507	\N	55.596778	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Мелкес, ул.Центральная, д.27А	Россия, республика Татарстан, Тукаевский район, село Мелекес	0101000020E61000006B6281AFE8164A40747CB43863CC4B40
1277	7	64	1883	30544	11493	\N	55.798181	423884, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Малтабарово, ул.Октябрьская (здание начальной школы), д.25	Россия, республика Татарстан, Тукаевский район, село Малтабарово	0101000020E6100000EB5223F433654A40F0A485CB2AE64B40
1285	7	64	1883	31014	11502	\N	55.803094000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Малая Шильна, ул.Центральная, д.1		0101000020E6100000B77D8FFAEB434A4092CEC0C8CBE64B40
1293	7	64	1883	31402	11511	\N	55.572167	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Куперле, ул.Большая, д.35		0101000020E6100000DB6FED4449344A40DB6CACC43CC94B40
1283	7	64	1883	30910	11500	\N	55.772182999999998	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Кузкеево, ул.М.Джалиля, д.37		0101000020E61000005D3123BC3D664A407AC37DE4D6E24B40
1296	7	64	1883	31542	11514	\N	55.580736999999999	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Кувады, ул.Центральная, д.35А		0101000020E6100000EDD45C6E30264A40E0490B9755CA4B40
1282	7	64	1883	30857	11499	\N	55.653984999999999	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Круглое Поле, ул.Гагарина, д.11А		0101000020E6100000E108522976164A408B89CDC7B5D34B40
1281	7	64	1883	30819	11498	\N	55.584440999999998	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Комсомолец, ул.Школьная, д.1		0101000020E61000006EA46C91B43F4A4084B872F6CECA4B40
1275	7	64	1883	30504	11491	\N	55.809635999999998	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Калмия, ул.Молодежная, д.23		0101000020E6100000A77686A92D614A4006D50627A2E74B40
1274	7	64	1883	30436	11490	\N	55.732418000000003	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Калмаш, ул.Центральная, д.32		0101000020E6100000E8305F5E80514A4039807EDFBFDD4B40
1304	7	64	1883	31914	11523	\N	55.456296000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Казаклар, ул.Шарипова, д.40		0101000020E6100000C1525DC0CB4E4A40D7A546E867BA4B40
1273	7	64	1883	32781	11497	\N	55.531799690344599	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Иштиряково, ул.Центральная, д.116А	Россия, республика Татарстан, Тукаевский район, село Иштеряково	0101000020E6100000C7116BF129FA4940A301BC0512C44B40
1287	7	64	1883	31107	11504	\N	55.785645000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Ильбухтино, ул.Центральная, д.1А		0101000020E61000008A0629780A494A400AA2EE0390E44B40
1295	7	64	1883	31507	11513	\N	55.594433000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Верхний Суык-Су, ул.Центральная, д.32Б		0101000020E61000002D0B26FE28224A40E3546B6116CC4B40
1284	7	64	1883	30952	11501	\N	55.719622000000001	Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Верхний Байлар, ул.Советская, д.29		0101000020E610000087890629785E4A40B6BDDD921CDC4B40
1271	7	64	1883	30275	11489	\N	55.515487	423896, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Тукаевский муниципальный район, д.Бурдыбаш, ул.Центральная (здание сельского ДК), д.83		0101000020E61000004436902E362B4A40AF415F7AFBC14B40
1270	7	64	1883	30254	11487	\N	55.517398	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Бурды, ул.Центральная, д.64		0101000020E6100000F52F49658A254A40068200193AC24B40
1286	7	64	1883	31046	11503	\N	55.793404000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Большая Шильна, ул.Кирова, д.55		0101000020E61000001C45D61A4A3D4A40FF4124438EE54B40
1269	7	64	1883	30188	11488	\N	55.836266000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Биюрган, ул.Тойгузино, д.1А		0101000020E61000003CA41820D1684A40DD60A8C30AEB4B40
1268	7	64	1883	30140	11485	\N	55.621927999999997	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Биклянь, ул.Чкалова, д.30А		0101000020E6100000554E7B4ACE114A40BC3B32569BCF4B40
1265	7	64	1883	29963	11486	\N	55.674123000000002	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Бетьки, ул.Гагарина, д.1	Россия, республика Татарстан, Тукаевский район, село Бетьки	0101000020E6100000BF29AC5450114A409F3D97A949D64B40
1264	7	64	1883	29963	11486	\N	55.674705054873499	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Бетьки, ул.Гагарина, д.2	Россия, республика Татарстан, Тукаевский район, село Бетьки	0101000020E610000043C9E4D4CE124A404EB9C2BB5CD64B40
1288	7	64	1883	31145	11505	\N	55.857250000000001	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Белоус, ул.Центральная		0101000020E6100000A92F4B3B353D4A407D3F355EBAED4B40
1301	7	64	6936	41032	12260	\N	55.724687000000003	Республика Татарстан (Татарстан), Тукаевский муниципальный район, с.Мрясево, ул.Сайдашева, д.24	Россия, республика Татарстан, Актанышский район, село Мрясево	0101000020E6100000FF959526A5F24A400E6B2A8BC2DC4B40
1261	7	64	1815	29817	11481	\N	54.792991999999998	Республика Татарстан (Татарстан), Тетюшский муниципальный район, д.Чувашское Черепаново, ул.Ленина, д.12		0101000020E6100000E867EA758B3A4840ACFE08C380654B40
1258	7	64	1815	61505	79264	\N	54.783291435077203	Республика Татарстан (Татарстан), Тетюшский муниципальный район, д.Татарский Чикилдым, ул.Чапаева, д.24	Россия, республика Татарстан, Тетюшский район, село Чувашский Чикилдым	0101000020E6100000C0E78711C2334840252026E142644B40
1259	7	64	1815	29724	11479	\N	54.978988999999999	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Чинчурино, ул.Школьная, д.12	Россия, республика Татарстан, Тетюшский район, село Чинчурино	0101000020E610000064AF777FBC5548406612F5824F7D4B40
1257	7	64	1815	29619	11478	\N	54.928747999999999	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Федоровка, ул.Школьная, д.1		0101000020E6100000155454FD4A534840DA1CE736E1764B40
1256	7	64	1815	29583	11477	\N	54.772291000000003	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Урюм, ул.Чапаева, д.2		0101000020E610000006802A6EDC60484061FF756EDA624B40
1255	7	64	1815	29538	11476	\N	54.946140999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Тоншерма, ул.Ленина, д.57		0101000020E610000036902E36AD3C4840CE33F6251B794B40
1206	7	64	1815	27321	11432	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.Фрунзе, д.23		0101000020E61000009AB51490F6694840925852EE3E774B40
1214	7	64	1815	27321	11433	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.Свердлова, д.69		0101000020E61000009AB51490F6694840925852EE3E774B40
1208	7	64	1815	27321	11433	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.Свердлова, д.32		0101000020E61000009AB51490F6694840925852EE3E774B40
1207	7	64	1815	27321	11433	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.Свердлова, д.128		0101000020E61000009AB51490F6694840925852EE3E774B40
1216	7	64	1815	27321	11439	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.Малкина, д.44		0101000020E61000009AB51490F6694840925852EE3E774B40
1212	7	64	1815	27321	11437	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.М.Горького, д.41		0101000020E61000009AB51490F6694840925852EE3E774B40
81	7	64	6913	41006	12059	\N	55.50909	Республика Татарстан, Заинский муниципальный район, с.Керекес, ул.Центральная, д.34А		0101000020E61000008257CB9D99FE49403E5C72DC29C14B40
1210	7	64	1815	27321	11437	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.М.Горького, д.82		0101000020E61000009AB51490F6694840925852EE3E774B40
1211	7	64	1815	27321	11436	\N	54.938129235965398	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.Ленина, д.89	Россия, республика Татарстан, Тетюшский район, Тетюши	0101000020E6100000D1B01875AD6B4840F0366F9C14784B40
1213	7	64	1815	27321	11438	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.Зеленая, д.24		0101000020E61000009AB51490F6694840925852EE3E774B40
1209	7	64	1815	27321	11434	\N	54.931607999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, город Тетюши, ул.200 лет Тетюшам, д.25		0101000020E61000009AB51490F6694840925852EE3E774B40
1223	7	64	1815	28082	11447	\N	54.723049000000003	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с. Татарская Беденьга, ул.Вахитова, д.41		0101000020E61000007E02284696364840E833A0DE8C5C4B40
1254	7	64	1815	29488	9900	\N	54.708919000000002	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Сюндюково, ул.Тукая, д.14		0101000020E6100000B2F336363B224840AB4198DBBD5A4B40
1252	7	64	1815	29402	11474	\N	54.805374999999998	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Пролей-Каша, ул.Октябрьская, д.21		0101000020E6100000BEDBBC71526448400C022B8716674B40
1250	7	64	1815	61486	79237	\N	54.778015698820603	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Починок-Ново-Льяшево, ул.Центральная, д.3	Россия, республика Татарстан, Тетюшский район, село Починок-Новольяшево	0101000020E6100000C422861DC6424840E3E13D0796634B40
1249	7	64	1815	29263	11472	\N	54.951470783985897	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Нармонка, ул.Школьная, д.1	Россия, республика Татарстан, Тетюшский район, село Нармонка	0101000020E61000001F8315A75A5F4840D40B3ECDC9794B40
1248	7	64	1815	29214	11471	\N	55.042513999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Монастырское, ул.Комсомольская, д.33		0101000020E6100000C1745AB7416B4840A2CF471971854B40
1245	7	64	1815	29083	11468	\N	55.121890999999998	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Малые Атряси, ул.Зиганшина, д.61		0101000020E6100000F52B9D0FCF6248409F56D11F9A8F4B40
1247	7	64	1815	29191	11470	\N	55.063772	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Малое Шемякино, ул.Центральная, д.19		0101000020E61000008D7E349C3247484044334FAE29884B40
1244	7	64	1815	29060	11467	\N	55.026437000000001	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Льяшево, ул.Пролетарская, д.22а		0101000020E61000005CAB3DEC855A4840C233A14962834B40
1243	7	64	1815	28988	11466	\N	55.118538999999998	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Лаптевка, ул.Гагарина, д.2		0101000020E6100000CA89761552704840782634492C8F4B40
1241	7	64	1815	28899	11464	\N	54.980859000000002	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Кушкуй, ул.Ленина, д.26		0101000020E6100000BB6246787B4C48405F7EA7C98C7D4B40
1240	7	64	1815	28888	11463	\N	54.816555999999999	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Кошки-Новотимбаево, ул.Яковлева, д.4		0101000020E6100000CE55F31C9141484021AD31E884684B40
1239	7	64	1815	28820	11462	\N	54.980632	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Кляшево, ул.Гагарина, д.15		0101000020E6100000C878944A784048409EB47059857D4B40
1238	7	64	1815	28766	11461	\N	54.740521999999999	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Киртели, ул.Гагарина, д.21Б		0101000020E61000009A7B48F8DE4F4840F8FBC56CC95E4B40
1237	7	64	1815	28728	11460	\N	54.758682999999998	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Кильдюшево, ул.Молодежная, д.22		0101000020E6100000D8648D7A88564840FD8348861C614B40
1234	7	64	1815	28590	11457	\N	54.857030000000002	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Кашка, ул.Центральная, д.19		0101000020E61000006E6AA0F99C6B48406FD8B628B36D4B40
1236	7	64	1815	28686	11459	\N	54.810777000000002	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Иоково, ул.Первомайская, д.1		0101000020E61000001842CEFBFF564840ACAC6D8AC7674B40
1233	7	64	1815	28521	11456	\N	54.799411999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, д.Жуково, ул.Верхняя, д.7		0101000020E6100000E7E099D024514840D503E62153664B40
1232	7	64	1815	28504	11455	\N	54.732283000000002	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Вожжи, ул.Центральная, д.28	Россия, республика Татарстан, Тетюшский район, село Вожжи	0101000020E61000008750A5660F2C484059350873BB5D4B40
1231	7	64	1815	28158	11449	\N	54.685084000000003	422386, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Верхние Тарханы, ул.Ленина (здание СДК), д.21/1		0101000020E6100000E9D7D64FFF3F4840A6811FD5B0574B40
1230	7	64	1815	28407	11454	\N	55.038361999999999	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Большое Шемякино, ул.Кутузова, д.1	Россия, республика Татарстан, Тетюшский район, село Большое Шемякино	0101000020E61000003718EAB0C24F48405FB4C70BE9844B40
1227	7	64	1815	28247	11451	\N	55.012414	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.  Большое Бисярино, ул.Школьная, д.25		0101000020E6100000DC82A5BA805548409B012EC896814B40
1220	7	64	1815	27967	11444	\N	54.705464999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Большие Тарханы, ул.Горького, д.7		0101000020E610000050FC1873D74448407FBC57AD4C5A4B40
1226	7	64	1815	28228	11450	\N	55.102488000000001	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Большие Атряси, ул.Молодежная, д.8		0101000020E6100000A4A833F790624840C11DA8531E8D4B40
1228	7	64	1815	28317	11452	\N	55.056156000000001	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Большая Турма, ул.Мусина, д.57а		0101000020E6100000390F27309D544840B2BCAB1E30874B40
1224	7	64	1815	28148	11448	\N	54.809691999999998	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Богдашкино, ул.Гагарина, д.4		0101000020E6100000B9347EE1955E48409AEAC9FCA3674B40
1222	7	64	1815	28044	11446	\N	54.674418000000003	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Бессоново, ул.Стахановская, д.12		0101000020E6100000AC3AAB05F63A4840B8EA3A5453564B40
1221	7	64	1815	28004	11445	\N	54.752156999999997	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Бакрчи, ул.Гагарина, д.25		0101000020E61000005C21ACC6123A48408E3A3AAE46604B40
1219	7	64	1815	27926	11443	\N	55.112391000000002	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Байрашево, ул.М.Джалиля, д.72		0101000020E6100000C4211B4817514840B0AE0AD4628E4B40
1218	7	64	1815	27871	11442	\N	54.874864000000002	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Алекина Поляна, ул.Молодежная, д.1		0101000020E6100000CFA3E2FF8E5048405039268BFB6F4B40
1217	7	64	1815	27837	11441	\N	55.091958404966398	Республика Татарстан (Татарстан), Тетюшский муниципальный район, с.Алабердино, ул.Ленина, д.71	Россия, республика Татарстан, Тетюшский район, село Алабердино	0101000020E6100000D40FEA22855A4840834D9D47C58B4B40
1200	7	64	1778	27060	11428	\N	55.006559000000003	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Ямбухтино, ул.Центральная, д.17		0101000020E610000028EE7893DFD448404B3FE1ECD6804B40
1202	7	64	1778	61509	79269	\N	54.661367147823903	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Чэчэкле, ул.Центральная, д.9		0101000020E6100000273108AC1CCA4840AAD381ACA7544B40
1178	7	64	1778	26056	11406	\N	54.9095442261927	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Урняк, ул.Вахитова, д.26 А	Россия, республика Татарстан, Спасский район, село Урняк	0101000020E6100000C861307F857A4840F22213F06B744B40
1191	7	64	1778	26629	12255	\N	54.994083000000003	Республика Татарстан (Татарстан), Спасский муниципальный район, д.Тукай, ул.Г.Тукая, д.33 В		0101000020E610000069705B5B78C248403A419B1C3E7F4B40
1177	7	64	1778	25991	11405	\N	54.907658271759999	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Три Озера, ул.Школьная, д.58	Россия, республика Татарстан, Спасский район, село Три Озера	0101000020E6100000B01BB62DCA864840F4F928232E744B40
1195	7	64	1778	26795	11422	\N	54.918622999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Татарская Тахтала, ул.Центральная, д.57 А		0101000020E6100000BA675DA3E5C648403C2D3F7095754B40
1181	7	64	1778	26151	11409	\N	54.820815000000003	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Танкеевка, ул.70 лет Октября, д.28		0101000020E6100000E2AE5E45468F48407B88467710694B40
1203	7	64	1778	27184	11430	\N	54.789473000000001	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Средний Юрткуль, ул.Центральная, д.32		0101000020E6100000DDB1D82615BF48409A0986730D654B40
1184	7	64	1778	26310	11411	\N	54.986252999999998	Республика Татарстан (Татарстан), Спасский муниципальный район, п.Приволжский, ул.Школьная, д.1		0101000020E61000004DD6A887688A48407B4ACE893D7E4B40
1179	7	64	1778	26083	11407	\N	54.827620000000003	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Полянки, ул.Центральная, д.26		0101000020E6100000A391CF2B9E7E4840FDC1C073EF694B40
1186	7	64	1778	26382	11413	\N	54.854593999999999	Республика Татарстан (Татарстан), Спасский муниципальный район, д.Отрада, ул.Клубная, д.28		0101000020E6100000274EEE7728AE4840CDAD1056636D4B40
1185	7	64	1778	26320	11412	\N	54.918669000000001	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Никольское, ул.Буденного, д.20		0101000020E6100000AD174339D1B24840AD6C1FF296754B40
1188	7	64	1778	26493	11414	\N	55.048039000000003	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Куралово, ул.60 лет Октября, д.15 А		0101000020E6100000C3B81B446BB748405EF7562426864B40
1201	7	64	1778	27068	11429	\N	54.718966999999999	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Кузнечиха, ул.Советская, д.18		0101000020E61000000EF7915B93CE48409DF3531C075C4B40
1183	7	64	1778	26237	11410	\N	54.931514999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, д.Красный Вал, ул.Новая, д.2		0101000020E610000033FD12F1D6974840E15D2EE23B774B40
1182	7	64	1778	61488	79242	\N	54.960005671162598	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Красная Слобода, ул.Школьная, д.2 А	Россия, республика Татарстан, Спасский район, село Красная Слобода	0101000020E6100000F0DAA50D87A148405DFB027AE17A4B40
1190	7	64	1778	26587	78557	\N	54.9919755494683	Республика Татарстан (Татарстан), Спасский муниципальный район, п.Ким, ул.Клубная, д.4	Россия, республика Татарстан, Спасский район, село Ким	0101000020E6100000CB4BFE277FB348405D35CF11F97E4B40
1197	7	64	1778	26919	11424	\N	55.135032000000002	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Каюки, ул.Советская, д.23		0101000020E6100000D734EF3845D94840EDF483BA48914B40
1205	7	64	1778	61335	78590	\N	54.5956941318791	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Иске-Рязап, ул.Ленина, д.56	Россия, республика Татарстан, Спасский район, село Иске-Рязяп	0101000020E6100000C0232A5437D74840333674B33F4C4B40
54057	7	62	\N	1218	63030	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Пушкина, д. 27		0101000020E6100000628731E9EFEF4740ACE122F774514C40
1204	7	64	1778	27218	11431	\N	54.829248	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Иж-Борискино, ул.Центральная, д.97		0101000020E610000066DCD440F3C74840FF2268CC246A4B40
1189	7	64	1778	26522	11415	\N	55.036921999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Екатериновка, ул.Центральная, д.14 А		0101000020E6100000B4CBB73EACC348405F402FDCB9844B40
1193	7	64	1778	26726	11420	\N	54.878822	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Гусиха, ул.Школьная, д.26		0101000020E61000007444BE4BA9C34840AE80423D7D704B40
1199	7	64	1778	26990	11427	\N	55.103822000000001	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Вожи, ул.Бугровская, д.85		0101000020E610000051FA42C879CB48407B4D0F0A4A8D4B40
1196	7	64	1778	26876	11423	\N	55.126286999999998	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Бураково, ул.Молодежная, д.41		0101000020E61000006211C30E63D448407974232C2A904B40
1187	7	64	1778	26426	9787	\N	54.911822204806697	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Бугровка, ул.Спирькова, д.50	Россия, республика Татарстан, Спасский район, село Бугровка	0101000020E61000003BC8EBC1A4A84840FCE25295B6744B40
1171	7	64	1778	25642	11400	\N	54.975707999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, город Болгар, ул.Советская, д.46		0101000020E61000002CBB6070CD8348400839EFFFE37C4B40
1175	7	64	1778	25642	11404	\N	54.967166146918601	Республика Татарстан (Татарстан), Спасский муниципальный район, город Болгар, ул.Рабочая, д.10	Россия, республика Татарстан, Спасский район, Болгар	0101000020E610000080457EFD10834840CDE67118CC7B4B40
1170	7	64	1778	25642	11399	\N	54.975707999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, город Болгар, ул.Пионерская, д.44		0101000020E61000002CBB6070CD8348400839EFFFE37C4B40
1169	7	64	1778	25642	11399	\N	54.975707999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, город Болгар, ул.Пионерская, д.40 А		0101000020E61000002CBB6070CD8348400839EFFFE37C4B40
1174	7	64	1778	25642	11403	\N	54.975707999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, город Болгар, ул.Октябрьская, д.59		0101000020E61000002CBB6070CD8348400839EFFFE37C4B40
1173	7	64	1778	25642	11402	\N	54.975707999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, город Болгар, ул.Ленина, д.108		0101000020E61000002CBB6070CD8348400839EFFFE37C4B40
1172	7	64	1778	25642	11401	\N	54.975707999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, город Болгар, ул.Гордеева, д.1		0101000020E61000002CBB6070CD8348400839EFFFE37C4B40
1180	7	64	1778	26127	11408	\N	54.855314999999997	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Балымеры, ул.Садовая, д.27		0101000020E6100000B14F00C5C87A48409D6340F67A6D4B40
1192	7	64	1778	26684	11419	\N	54.9135905285018	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Антоновка, ул.Советская, д.57	Россия, республика Татарстан, Спасский район, село Антоновка	0101000020E61000006877483140BE4840C075C58CF0744B40
1194	7	64	1778	26787	11421	\N	54.943773	Республика Татарстан (Татарстан), Спасский муниципальный район, с.Аграмаковка, ул.Куйбышева, д.1 В		0101000020E61000004B1FBAA0BED1484085ECBC8DCD784B40
1114	7	64	1265	61515	79278	\N	55.150388218643997	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Яхши-Каран, ул.Родниковая, д.1	Россия, республика Татарстан, Сармановский район, село Яхшы-Каран	0101000020E61000001D91EF52EA6E4A40FDDAFAE93F934B40
1153	7	64	1265	24870	11385	\N	55.313572000000001	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Янурусово, ул.Ленина, д.43А		0101000020E6100000437573F1B74D4A407D78962023A84B40
1111	7	64	1265	22882	79240	\N	55.361801528114299	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Юлтимерово, ул.Набережная, д.5	Россия, республика Татарстан, Сармановский район, село Юлтимирово	0101000020E6100000A7AD11C1384E4A404ED026874FAE4B40
1112	7	64	1265	22912	11343	\N	55.408583	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Шигаево, ул.Шоссейная, д.18А		0101000020E61000008EAF3DB324464A40CD599F724CB44B40
1136	7	64	1265	24053	11369	\N	55.409165000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Шарлиарема, ул.Школьная, д.57		0101000020E610000059A2B3CC225E4A407CD5CA845FB44B40
1121	7	64	1265	23329	11350	\N	55.458424000000001	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Чурашево, ул.М.Джалиля, д.81А		0101000020E6100000DE72F56393664A40CBD93BA3ADBA4B40
1151	7	64	1265	24788	11383	\N	55.284246000000003	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Чукмарлы, ул.Советская, д.41		0101000020E610000048C0E8F2E6364A406902452C62A44B40
1146	7	64	1265	61426	79162	\N	55.368324883248199	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Сарысаз-Такерман, ул.К.Маркса, д.1В	Россия, республика Татарстан, Сармановский район, село Сырысаз-Такерман	0101000020E6100000317BD976DA5E4A404CA60A4625AF4B40
1135	7	64	1265	24003	11368	\N	55.436126999999999	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Сулюково, ул.Школьная, д.56		0101000020E610000037E0F3C308634A4088F37002D3B74B40
1144	7	64	1265	24446	11378	\N	55.406722000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Сулы-Саклово, ул.М.Джалиля, д.21А		0101000020E6100000950F41D5E86D4A4028486C770FB44B40
1150	7	64	1265	24771	11382	\N	55.076278000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Старый Мензелябаш, ул.50 лет Октября, д.75		0101000020E6100000859675FF58584A40C0B33D7AC3894B40
1148	7	64	1265	24657	11380	\N	55.153343999999997	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Старый Кашир, ул.Комсомольская, д4А		0101000020E6100000EC14AB0661464A40D784B4C6A0934B40
1145	7	64	1265	24519	11377	\N	55.361733000000001	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Старый Имян, ул.М.Вахитова, д.36В		0101000020E6100000D68BA19C68654A40267156444DAE4B40
1147	7	64	1265	24611	11379	\N	55.156954972051103	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Средний Кашир, ул.Х.Такташа, д.38А	Россия, республика Татарстан, Сармановский район, село Средний Кашир	0101000020E6100000999CDA19A6404A40CBF8F71917944B40
1156	7	64	1265	24945	11389	\N	55.252315274537096	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Сарманово, ул.Энергетиков, д.1	Россия, республика Татарстан, Сармановский район, село Сарманово	0101000020E6100000A6BA8097194C4A4027A5A0DB4BA04B40
1158	7	64	1265	24945	11392	\N	55.252563000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Сарманово, ул.Терешковой, д.8		0101000020E61000002F1686C8E94B4A40FF9600FC53A04B40
1154	7	64	1265	24945	11386	\N	55.252563000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Сарманово, ул.Сельхозтехники, д.25		0101000020E61000002F1686C8E94B4A40FF9600FC53A04B40
1159	7	64	1265	24945	11393	\N	55.252563000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Сарманово, ул.М.Джалиля, д.63		0101000020E61000002F1686C8E94B4A40FF9600FC53A04B40
1155	7	64	1265	24945	11388	\N	55.252563000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Сарманово, ул.Ленина, д.1Б		0101000020E61000002F1686C8E94B4A40FF9600FC53A04B40
1157	7	64	1265	24945	11391	\N	55.252563000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Сарманово, ул.Куйбышева, д.31		0101000020E61000002F1686C8E94B4A40FF9600FC53A04B40
1125	7	64	1265	23523	11356	\N	55.147443304905899	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Сарайлы, ул.М.Джалиля, д.37А	Россия, республика Татарстан, Сармановский район, село Сарайлы	0101000020E610000024D6E25300524A4017838769DF924B40
1142	7	64	1265	24338	11374	\N	55.381807000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Саклов-Баш, ул.Ленина, д.93А		0101000020E610000071AB2006BA704A402331410DDFB04B40
1141	7	64	1265	24304	11373	\N	55.204120000000003	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Рантамак, ул.Вахитова, д.51		0101000020E610000073D87DC7F0704A40D23AAA9A209A4B40
1140	7	64	1265	24258	11375	\N	55.218369000000003	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Рангазар, ул.Советская, д.48		0101000020E6100000206118B0E4604A40E9BAF083F39B4B40
1137	7	64	1265	24094	11370	\N	55.318834000000003	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Петровский Завод, ул.Поперечная, д.2А		0101000020E6100000782634492C3F4A402B6D718DCFA84B40
1133	7	64	1265	23887	11366	\N	55.119166999999997	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Новый Имян, ул.М.Джалиля, д.25А		0101000020E6100000D36BB3B112394A4097E13FDD408F4B40
1160	7	64	1265	13155	11394	\N	55.274472000000003	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Новое Ахметово, ул.Ленина, д.9		0101000020E6100000EE073C30804C4A4078D503E621A34B40
1124	7	64	1265	23466	11354	\N	55.098274000000004	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Нижний Лешев, ул.40 лет Победы, д.38А		0101000020E610000009DE9046054A4A400806103E948C4B40
1138	7	64	1265	24165	11371	\N	55.329051999999997	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Мустафино, ул.Октябрьская, д.14А		0101000020E61000007C6308008E2F4A4079573D601EAA4B40
1128	7	64	1265	23687	11360	\N	55.215107000000003	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Муртыш-Тамак, ул.Советская, д.47		0101000020E61000005AD93EE42D4D4A4002124DA0889B4B40
1118	7	64	1265	23199	11347	\N	55.219355	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Муртыш Баш, ул.Школьная, д.18		0101000020E6100000F1F109D979474A40679B1BD3139C4B40
1127	7	64	1265	23609	11358	\N	55.345554999999997	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Ляки, ул.Школьная, д.5		0101000020E610000033A9A10DC03C4A4011FC6F253BAC4B40
1123	7	64	1265	23386	11353	\N	55.117807999999997	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Лешев Тамак, ул.Советская, д.1Б		0101000020E6100000711B0DE02D504A40849A2155148F4B40
1122	7	64	1265	23386	11351	\N	55.117807999999997	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Лешев Тамак, ул.Молодежная, д.1А		0101000020E6100000711B0DE02D504A40849A2155148F4B40
1132	7	64	1265	23861	11365	\N	55.129241999999998	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Кутемели, ул.Гагарина, д.39		0101000020E6100000DEE522BE13414A4083A279008B904B40
1129	7	64	1265	23724	11362	\N	55.184699999999999	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Кульметьево, ул.Хисамова, д.9	Россия, республика Татарстан, Сармановский район, село Кульметьево	0101000020E610000038BC2022354F4A401DC9E53FA4974B40
1149	7	64	1265	24706	11381	\N	55.085872999999999	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Кузяково, ул.Советская, д.64		0101000020E6100000D525E318C94E4A40014EEFE2FD8A4B40
1152	7	64	1265	24864	11384	\N	55.297066999999998	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Каташ-Каран, ул.Ленина, д.45А		0101000020E61000007A8F334DD8504A4044DC9C4A06A64B40
1120	7	64	1265	23292	11349	\N	55.473275999999998	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Карашай-Саклово, ул.Ленина, д.100		0101000020E61000003C69E1B20A6B4A40A8FDD64E94BC4B40
1119	7	64	1265	23245	11348	\N	55.277734000000002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Кавзияково, ул.Советская, д.14А		0101000020E61000007FA5F3E159684A405F7EA7C98CA34B40
1116	7	64	1265	23108	11345	\N	55.242525000000001	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Иляксаз, ул.Комсомольская, д.2		0101000020E61000005CAB3DEC85444A4030BB270F0B9F4B40
1139	7	64	1265	24176	11372	\N	55.288741036554299	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Димитарлау, ул.Советская, д.7/1	Россия, республика Татарстан, Сармановский район, село Димитарлау	0101000020E6100000E162450DA6454A40D6011077F5A44B40
1168	7	64	1265	25227	11398	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.Лесная, д.25		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1167	7	64	1265	25227	11398	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.Лесная, д.10		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1163	7	64	1265	25227	11396	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.Ленина, д.21		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1166	7	64	1265	25227	11397	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.Ахмадиева, д.20		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1165	7	64	1265	25227	11397	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.Ахмадиева, д.39А		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1164	7	64	1265	25227	11397	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.Ахмадиева, д.23		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1162	7	64	1265	25227	11395	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.30 лет Победы, д.6		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1161	7	64	1265	25227	11395	\N	55.024414	Республика Татарстан (Татарстан), Сармановский муниципальный район, пгт Джалиль, ул.30 лет Победы, д.1		0101000020E6100000F9D85DA0A45E4A4043C879FF1F834B40
1126	7	64	1265	23602	11357	\N	55.383996000000003	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Верхние Чершилы, ул.Ленина, д.40А		0101000020E61000000762D9CC213D4A40BDE5EAC726B14B40
1131	7	64	1265	23806	11364	\N	55.084941000000001	Республика Татарстан (Татарстан), Сармановский муниципальный район, д.Буралы-Чишма, ул.Советская, д.12А		0101000020E61000009B1C3EE9443E4A40768BC058DF8A4B40
1134	7	64	1265	23963	11367	\N	55.378073999999998	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Большое Нуркеево, ул.Школьная, д.34		0101000020E6100000456458C51B554A40E4BB94BA64B04B40
1115	7	64	1265	23065	11344	\N	55.252896	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Альметьево, ул.Ленина, д.56А		0101000020E610000001A260C6145C4A4005A568E55EA04B40
1113	7	64	1265	22960	11342	\N	55.142344000000001	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Александровка, ул.Школьная, д.7		0101000020E610000048A98427F4624A401364045438924B40
1110	7	64	1265	22830	11340	\N	55.337581796095002	Республика Татарстан (Татарстан), Сармановский муниципальный район, с.Азалаково, ул.Советская, д.22А	Россия, республика Татарстан, Сармановский район, село Азалаково	0101000020E6100000BB46CB811E524A40F0DB10E335AB4B40
1108	7	64	1640	22752	11352	\N	55.952025999999996	422070, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Юлбат, ул.Г.Тукая, д.57		0101000020E61000001021AE9CBD3B49408978EBFCDBF94B40
1101	7	64	1640	22431	11328	\N	56.104661999999998	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Шикши, ул.Школьная, д.1		0101000020E610000076172829B03C494025917D90650D4C40
1105	7	64	1640	22481	11336	\N	56.188152000000002	Республика Татарстан (Татарстан), Сабинский муниципальный район, п.Шемордан, ул.Х.Такташа, д.3		0101000020E61000008A56EE0566334940A8565F5D15184C40
1106	7	64	1640	22481	11334	\N	56.188152000000002	Республика Татарстан (Татарстан), Сабинский муниципальный район, п. Шемордан, ул.Фрунзе, д.5 а	Россия, республика Татарстан, Сабинский район, поселок Шемордан	0101000020E61000008A56EE0566334940A8565F5D15184C40
1102	7	64	1640	22481	11329	\N	56.188152000000002	Республика Татарстан (Татарстан), Сабинский муниципальный район, п.Шемордан, ул.Первомайская, д.41		0101000020E61000008A56EE0566334940A8565F5D15184C40
1103	7	64	1640	22481	11331	\N	56.188152000000002	Республика Татарстан (Татарстан), Сабинский муниципальный район, п.Шемордан, ул.Лермонтова, д.2		0101000020E61000008A56EE0566334940A8565F5D15184C40
1069	7	64	1640	20921	11303	\N	55.949713000000003	422084, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Уют, ул.Ленина, д.39		0101000020E6100000D1ADD7F4A024494004CB113290F94B40
1078	7	64	1640	21357	11309	\N	55.992441999999997	Республика Татарстан (Татарстан), Сабинский муниципальный район, д.Туктар, ул.Советская, д.39 а		0101000020E6100000C3D8429083444940A296E65608FF4B40
1098	7	64	1640	22316	11327	\N	56.045668999999997	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Тимершик, ул.Пионерская, д.3		0101000020E6100000D50968226C2C494073B8567BD8054C40
55269	7	63	\N	1332	54492	\N	54.200201	Республика Мордовия, город Саранск, Октябрьский район, Лихачева, 40		0101000020E61000008F352383DC9D464031D0B52FA0194B40
1097	7	64	1640	32987	11359	\N	55.868493909318502	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Ст.Икшурма, ул.Пушкина, д.2	Россия, республика Татарстан, Сабинский район, село Старая Икшурма	0101000020E610000064E94317D44F4940D862B7CF2AEF4B40
1085	7	64	1640	61484	79234	\N	56.016083999999999	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Ст.Мичан, ул.Школьная, д.12	Россия, республика Татарстан, Сабинский район	0101000020E610000056293DD34B36494093FE5E0A0F024C40
1095	7	64	1640	22180	11323	\N	55.930821000000002	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Сатышево, ул.Советская, д.24		0101000020E61000006C06B8205B3649400BB77C2425F74B40
1084	7	64	1640	21641	11313	\N	56.032936999999997	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Сабабаш, ул.Школьная, д.1		0101000020E61000009D8026C2864D494007EA944737044C40
1075	7	64	1640	21223	11307	\N	56.138593999999998	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Олуяз, ул.Ленина, д.18		0101000020E61000002EC6C03A8E354940FEB5BC72BD114C40
1082	7	64	1640	21550	11311	\N	56.119593999999999	Республика Татарстан (Татарстан), Сабинский муниципальный район, д.Н.Отар, ул.М.Джалиля, д.62		0101000020E610000004E5B67D8F2649401F662FDB4E0F4C40
1087	7	64	1640	21808	11316	\N	55.885145000000001	422067, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Н.Шитцы, ул.Тукая, д.1 а		0101000020E610000040C39B35783F4940E59B6D6E4CF14B40
1107	7	64	1640	22712	11337	\N	56.160891999999997	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Мичанбаш, ул.Советская, д.31		0101000020E61000004D2D5BEB8B2C49401118EB1B98144C40
1100	7	64	1640	61482	79232	\N	56.0233115779222	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Мингерь, ул.Татарстан, д.23	Россия, республика Татарстан, Сабинский район, село Мингер	0101000020E6100000DBA7E331032949405BCD3AE3FB024C40
1096	7	64	1640	22227	11324	\N	55.863095999999999	Республика Татарстан (Татарстан), Сабинский муниципальный район, д.Мамалаево, ул.Чапаева, д.6		0101000020E61000008EB1135E823749407AA702EE79EE4B40
1083	7	64	1640	40912	11315	\N	56.044071000000002	Республика Татарстан (Татарстан), Сабинский муниципальный район, п.Лесхоз, ул.Детсадовская, д.26		0101000020E6100000FFE6C589AF584940DCD9571EA4054C40
1099	7	64	1640	22363	79142	\N	56.0738228173309	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Кзыл-Меша, ул.Ленина, д.32	Россия, республика Татарстан, Сабинский район, село Кызыл-Меша	0101000020E610000011C64FE3DE2E4940A758350873094C40
1086	7	64	1640	21745	11314	\N	56.092511000000002	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Кренни, ул.Школьная, д.16		0101000020E6100000C843DFDDCA22494098C28366D70B4C40
1080	7	64	1640	21453	11310	\N	56.148327999999999	422051, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Корсабаш, ул.Советская, д.18		0101000020E6100000CBA2B08BA2254940618A7269FC124C40
93876	7	64	1640	61425	79161	\N	56.110936444966299	Республика Татарстан(Татарстан), Арский муниципальный район, пос.ж.д.разъезд Корса, ул.Школьная, д.48	Россия, республика Татарстан, Сабинский район, поселок Корса	0101000020E6100000D8F50B76C31649407BF99D26330E4C40
1077	7	64	1640	21321	11308	\N	56.022025999999997	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Кильдебяк, ул.Кооперативная, д.20 а		0101000020E6100000F8DEDFA0BD484940B2D47ABFD1024C40
1074	7	64	1640	61394	79122	\N	56.099368593864	Республика Татарстан (Татарстан), Сабинский муниципальный район, д,Илеберь, ул.8 Марта, д.50	Россия, республика Татарстан, Сабинский район, село Илебер	0101000020E6100000A85489B2B73449403D9E961FB80C4C40
1073	7	64	1640	61479	79228	\N	56.107318980048298	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Изма, ул.Школьная, д.5	Россия, республика Татарстан, Сабинский район, село Измя	0101000020E610000052BAF42F49334940A59E05A1BC0D4C40
1072	7	64	1640	21082	11306	\N	56.113010000000003	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Евлаштау, ул.Ш.Бариева, д.11		0101000020E6100000C651B9895A4649407C0F971C770E4C40
1065	7	64	1640	20686	11299	\N	55.942680000000003	422069, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Сабинский муниципальный район, д.Два поля Арташ, ул.Школьная, д.12		0101000020E6100000D13B1570CF534940F14BFDBCA9F84B40
1071	7	64	1640	21048	11304	\N	56.055095999999999	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.В.Симет, ул.Советская, д.32		0101000020E6100000E8120EBDC5174940F911BF620D074C40
1089	7	64	1640	21903	11317	\N	55.905427000000003	Республика Татарстан (Татарстан), Сабинский муниципальный район, д.В.Шитцы, ул.Ленина, д.31		0101000020E61000005FD38382524249402CF52C08E5F34B40
1068	7	64	1640	20903	11302	\N	55.988030999999999	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Б.Шинар, ул.Кооперативная, д.37		0101000020E61000002C2E8ECA4D2249409337C0CC77FE4B40
1067	7	64	1640	20809	11301	\N	55.966141	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Б.Нырты, ул.М.Джалиля, д.13 а		0101000020E610000013F241CF665B494091291F82AAFB4B40
1066	7	64	1640	20792	11300	\N	55.827530000000003	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Б.Кибячи, ул.Ф.Энгельса, д.75		0101000020E61000008313D1AFAD514940BD3AC780ECE94B40
1092	7	64	1640	21946	11320	\N	56.012414012640299	Республика Татарстан (Татарстан), Сабинский муниципальный район, поселок городского типа Богатые Сабы, ул.Школьная, д.50	Россия, республика Татарстан, Сабинский район, село Богатые Сабы	0101000020E6100000618A7269FC3849409B012EC896014C40
1094	7	64	1640	21946	11322	\N	56.005682	Республика Татарстан (Татарстан), Сабинский муниципальный район, поселок городского типа Богатые Сабы, ул.М.Джалиля, д.2		0101000020E61000005D52B5DD0439494083161230BA004C40
1093	7	64	1640	21946	11321	\N	56.005682	Республика Татарстан (Татарстан), Сабинский муниципальный район, поселок городского типа Богатые Сабы, ул.Кол Гали, д.40		0101000020E61000005D52B5DD0439494083161230BA004C40
1091	7	64	1640	21946	11319	\N	55.9966881344576	Республика Татарстан (Татарстан), Сабинский муниципальный район, поселок городского типа Богатые Сабы, ул.З.Юсупова, д.22	Россия, республика Татарстан, Сабинский район, село Богатые Сабы	0101000020E6100000FE9C82FC6C3849406728EE7893FF4B40
1090	7	64	1640	21946	11318	\N	56.005682	Республика Татарстан (Татарстан), Сабинский муниципальный район, поселок городского типа Богатые Сабы, ул.Г.Закирова, д.27		0101000020E61000005D52B5DD0439494083161230BA004C40
997	7	64	1476	17139	11237	\N	55.561399999999999	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Янчиково, ул.40 лет Победы, д.23		0101000020E6100000B0C8AF1F62194940B9FC87F4DBC74B40
1061	7	64	1476	20489	11294	\N	55.633606999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Ямашево, ул.Татарстан, д.1а		0101000020E61000004F7633A31F39494022C2BF081AD14B40
1060	7	64	1476	20454	11292	\N	55.601827999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Юлсубино, ул.Татарстан, д.44а		0101000020E6100000F3583332C83B494096E82CB308CD4B40
1053	7	64	1476	40909	11650	\N	55.6053393569333	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Шетнево-Тулуши, ул.М.Джалиля, д.18		0101000020E610000039D384ED27E5484026FF93BF7BCD4B40
1058	7	64	1476	20343	11291	\N	55.583016000000001	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Шумково, ул.Центральная, д.6а		0101000020E61000002D978DCEF9074940BA85AE44A0CA4B40
1055	7	64	1476	20131	11289	\N	55.564959000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Шумбут, ул.Советская, д.18		0101000020E61000000D8D2782385749405A4A969350C84B40
1016	7	64	1476	18101	11257	\N	55.593409999999999	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Шетнево-Черемышево, ул.Советская, д.20		0101000020E6100000FE2C9622F9F04840478FDFDBF4CB4B40
1047	7	64	1476	19696	11281	\N	55.730705	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Шеморбаш, ул.Советская, д.47		0101000020E6100000CBD58F4DF24B49400803CFBD87DD4B40
1042	7	64	1476	19423	11278	\N	55.496051999999999	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Урахча, ул.Советская, д.20Б		0101000020E610000073BC02D193384940C58EC6A17EBF4B40
1041	7	64	1476	19394	11276	\N	55.456490000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Троицкий Урай, ул.Прикамская, д.1		0101000020E6100000BDC458A65F1E4940BC79AA436EBA4B40
1021	7	64	1476	61524	79303	\N	55.646244335253897	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Тябердино Челны, ул.Гагарина, д.34	Россия, республика Татарстан, Рыбно-Слободский район, село Тебердино-Челны	0101000020E6100000EF71A609DB5349403D9E961FB8D24B40
1050	7	64	1476	19850	11284	\N	55.695493999999997	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Тавларово, ул.Ленина, д.50а		0101000020E61000008524B37A874B4940384888F205D94B40
995	7	64	1476	17043	11235	\N	55.605632	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Старый Арыш, ул.Центральная, д.25		0101000020E61000009B3A8F8AFF1549409EB4705985CD4B40
1057	7	64	1476	40911	11295	\N	55.543765999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Шестая Речка, ул.Лесная, д.6		0101000020E610000069739CDB845549409F56D11F9AC54B40
1035	7	64	1476	40906	77573	\N	55.461330216088598	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, п.г.т.Рыбная Слобода, ул.Ленина, д.46а	Россия, республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода	0101000020E61000009B1BD31396124940F35487DC0CBB4B40
1040	7	64	1476	40906	78548	\N	55.460669363468099	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, п.г.т.Рыбная Слобода, ул.Заводская, д.6а	Россия, республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода	0101000020E6100000DE3D40F7E5124940F9A3A833F7BA4B40
1036	7	64	1476	40906	12183	\N	55.459994497447298	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, п.г.т.Рыбная Слобода, ул.З.Шаймарданова, д.58		0101000020E610000098A59D9ACB114940992D5915E1BA4B40
1037	7	64	1476	40906	78041	\N	55.466858253568802	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, п.г.т.Рыбная Слобода, ул.Больничный переулок, д.6	Россия, республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода	0101000020E6100000BE30992A1813494020F0C000C2BB4B40
1039	7	64	1476	40906	11277	\N	55.458631204129802	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, п.г.т.Рыбная Слобода, ул.60 лет Октября, д.9	Россия, республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода	0101000020E610000094F771344712494044F7AC6BB4BA4B40
1038	7	64	1476	40906	11277	\N	55.459019088376301	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, п.г.т.Рыбная Слобода, ул.60 лет Октября, д.1	Россия, республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода	0101000020E61000004A7D59DAA91149400E9F7422C1BA4B40
93562	7	64	1476	18939	79058	\N	55.4670201560644	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Ошняк, ул.Хай Вахита, д.11	Россия, республика Татарстан, Рыбно-Слободский район, село Русский Ошняк	0101000020E610000078D4981073034940F949B54FC7BB4B40
1033	7	64	1476	18939	11272	\N	55.471311	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Русский Ошняк, ул.Профсоюзная, д.7а		0101000020E6100000DC9F8B868C0349405E9F39EB53BC4B40
1063	7	64	1476	20597	11297	\N	55.468459000000003	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Полянка, ул.Механизаторов, д.3б		0101000020E610000061FC34EECD0D49402942EA76F6BB4B40
1001	7	64	1476	17336	11241	\N	55.571748999999997	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Околоток-Янгасала, ул.Калинина, д.102		0101000020E610000080EF366F9C524940A6423C122FC94B40
1030	7	64	1476	18826	11270	\N	55.654142	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Новый Арыш, ул.Центральная, д.49		0101000020E6100000EFE4D3635B2649405378D0ECBAD34B40
1054	7	64	1476	61393	79120	\N	55.595134106806	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Новая Ырга, ул.Школьная, д.48	Россия, республика Татарстан, Рыбно-Слободский район, село Новая Ирга	0101000020E6100000E1D39CBCC8E848406C5ED5592DCC4B40
1028	7	64	1476	18725	11269	\N	55.576349999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Нижний Тимерлек, ул.Школьная, д.47а		0101000020E610000004745FCE6C334940598638D6C5C94B40
1044	7	64	1476	19533	11279	\N	55.507452999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Мельничный Починок, ул.Кирова, д.23		0101000020E61000007BA4C16D6D3D4940E8A04B38F4C04B40
1023	7	64	1476	18414	11265	\N	55.435335000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Масловка, ул.Центральная, д.13		0101000020E61000006C76A4FACEFF4840EFE6A90EB9B74B40
1022	7	64	1476	18392	11263	\N	55.648752999999999	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Мамли-Козяково Челны, ул.Центральная, д.27		0101000020E61000000856D5CBEF56494048179B560AD34B40
1009	7	64	1476	17745	11250	\N	55.519401000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Малый Ошняк, ул.Красноармейская, д.32а		0101000020E61000000CAEB9A3FFFD48403E4162BB7BC24B40
998	7	64	1476	17211	11238	\N	55.557590405595001	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Малый Атмас, ул.Гагарина, д.11а	Россия, республика Татарстан, Рыбно-Слободский район, село Малый Атмас	0101000020E6100000CBBF9657AE134940CF49EF1B5FC74B40
1019	7	64	1476	18209	11260	\N	55.633673000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Кутлу-Букаш, ул.Советская, д.28		0101000020E6100000A2629CBF09514940DAAD65321CD14B40
1062	7	64	1476	20587	11296	\N	55.660023000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Кукеево, ул.Н.Гиззатуллина, д.36а	Россия, республика Татарстан, Рыбно-Слободский район, село Кукеево	0101000020E610000052F2EA1C03364940CDCD37A27BD44B40
1017	7	64	1476	18116	11258	\N	55.548966	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Кугарчино, ул.Советская, д.43а		0101000020E61000009EEE3CF19C3B4940D74E948444C64B40
1015	7	64	1476	18022	11256	\N	55.551048999999999	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Корноухово, ул.Совхозная, д.8		0101000020E61000002713B70A62F248402BBF0CC688C64B40
1012	7	64	1476	17915	11253	\N	55.645952914907902	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Козяково-Челны, ул.Иванова, д.26	Россия, республика Татарстан, Рыбно-Слободский район, село Козяково-Челны	0101000020E6100000D61F6118B044494065E08096AED24B40
1018	7	64	1476	40907	11280	\N	55.572866207654798	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Зангар-Куль, ул.Г.Тукая, д.3а	Россия, республика Татарстан, Рыбно-Слободский район, село Зянгаркуль	0101000020E61000006022DE3AFF424940C37E4FAC53C94B40
1004	7	64	1476	17513	11244	\N	55.483387999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Дон-Урай, ул.Садовый переулок, д.2		0101000020E6100000DCD8EC48F51F4940B1A371A8DFBD4B40
1027	7	64	1476	18615	11268	\N	55.594101999999999	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Верхний Тимерлек, ул.Советская, д.72а		0101000020E610000018B5FB55803149407D3ECA880BCC4B40
1010	7	64	1476	17818	11262	\N	55.616590000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Большой Салтан, ул.Шарафеева, д.12а		0101000020E6100000D89C836742F748403485CE6BECCE4B40
1007	7	64	1476	17725	11249	\N	55.521470999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Большой Ошняк, ул.Г.Тукая, д.28а		0101000020E6100000F8C43A55BEF74840FD67CD8FBFC24B40
1005	7	64	1476	17536	11246	\N	55.687071000000003	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Большой Машляк, ул.Ленина, д.15а		0101000020E61000002F88484DBB584940D88349F1F1D74B40
1003	7	64	1476	17432	11243	\N	55.514906000000003	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Большая Кульга, ул.Школьная, д.11		0101000020E61000006D3B6D8D082E4940D1419770E8C14B40
1002	7	64	1476	17402	11242	\N	55.426349999999999	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Большая Елга, ул.Октябрьская, д.25		0101000020E6100000DBFAE93F6BF04840265305A392B64B40
1006	7	64	1476	17625	11247	\N	55.664299	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Бикчураево, ул.Горького, д.11		0101000020E6100000826F9A3E3B584940FCE1E7BF07D54B40
1000	7	64	1476	17310	11240	\N	55.607809000000003	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Биектау, ул.Сафиуллина, д.1		0101000020E61000003F8C101E6D564940749B70AFCCCD4B40
996	7	64	1476	17115	11236	\N	55.515960999999997	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Бетьки, ул.Мира, д.2		0101000020E610000022E010AAD4164940778192020BC24B40
1014	7	64	1476	18010	11255	\N	55.656914999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, д.Бердибяково, ул.Школьная, д.5		0101000020E61000002F6CCD565E4C49403CA06CCA15D44B40
994	7	64	1476	17018	11234	\N	55.591818881755501	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Балыклы-Чукаево, ул.Центральная, д.8	Россия, республика Татарстан, Рыбно-Слободский район, село Балыклы-Чукаево	0101000020E61000007C7E18213C0E4940621399B9C0CB4B40
993	7	64	1476	16948	11233	\N	55.479841999999998	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Анатыш, ул.Клубная, д.17		0101000020E610000032E9EFA5F0104940A59F70766BBD4B40
1049	7	64	1476	19813	11283	\N	55.693536000000002	Республика Татарстан (Татарстан), Рыбно-Слободский муниципальный район, с.Алан-Полян, ул.Якова Емельянова, д.6		0101000020E610000036CEA62380454940A14CA3C9C5D84B40
992	7	64	1398	16920	11232	\N	55.764474999999997	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Янцевары, ул.Центральная, д.1		0101000020E61000007C7BD7A02F11494007CE1951DAE14B40
989	7	64	1398	16724	11230	\N	55.681559	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Шали, ул.Хайруллина, д.35		0101000020E610000085D0419770D44840B1A547533DD74B40
988	7	64	1398	16724	11230	\N	55.681559	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Шали, ул.Хайруллина, д.32		0101000020E610000085D0419770D44840B1A547533DD74B40
987	7	64	1398	16639	9720	\N	55.728058646786103	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Чита, ул.Кооперативная, д.84	Россия, республика Татарстан, Пестречинский район, село Чита	0101000020E61000000EF3E505D8F348407C478D0931DD4B40
986	7	64	1398	16617	11229	\N	55.828646999999997	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Татарское Ходяшево, ул.Советская, д.15а		0101000020E6100000EFC517EDF1E84840D976DA1A11EA4B40
990	7	64	1398	16826	11231	\N	55.827554999999997	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Старое Шигалеево, ул.Центральная, д.14		0101000020E610000044C18C2958C1484015527E52EDE94B40
984	7	64	1398	16514	11226	\N	55.774897000000003	Республика Татарстан (Татарстан), Пестречинский муниципальный район, д.Пимери, ул.Советская, д.25а		0101000020E6100000BA675DA3E5EC48405F622CD32FE34B40
983	7	64	1398	16225	11225	\N	55.754263999999999	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Пестрецы, ул.Советская, д.7		0101000020E610000090A2CEDC43D448406B4606B98BE04B40
982	7	64	1398	16225	11225	\N	55.754263999999999	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Пестрецы, ул.Советская, д.9		0101000020E610000090A2CEDC43D448406B4606B98BE04B40
981	7	64	1398	16225	11224	\N	55.754263999999999	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Пестрецы, ул.Молодежная, д.1		0101000020E610000090A2CEDC43D448406B4606B98BE04B40
980	7	64	1398	16225	11223	\N	55.754263999999999	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Пестрецы, ул.Казанская, д.7		0101000020E610000090A2CEDC43D448406B4606B98BE04B40
979	7	64	1398	16225	11223	\N	55.754263999999999	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Пестрецы, ул.Казанская, д.7а		0101000020E610000090A2CEDC43D448406B4606B98BE04B40
978	7	64	1398	16204	11222	\N	55.825952000000001	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Пановка, ул.Центральная, д.7а		0101000020E610000017105A0F5FF848406C088ECBB8E94B40
977	7	64	1398	16132	11221	\N	55.686523000000001	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Отар-Дубровка, ул.Центральная, д.6		0101000020E6100000BEFA78E8BB034940D57954FCDFD74B40
976	7	64	1398	16110	11220	\N	55.856048000000001	Республика Татарстан (Татарстан), Пестречинский муниципальный район, д.Надеждино, ул.Школьная, д.1		0101000020E61000004EB4AB90F2DF484032E719FB92ED4B40
974	7	64	1398	16010	11218	\N	55.827454000000003	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Ленино-Кокушкино, ул.Центральная, д.17		0101000020E61000009694BBCFF1D74840E2783E03EAE94B40
975	7	64	1398	16010	11219	\N	55.823878727725003	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Ленино-Кокушкино, ул.Техническая, д.10	Россия, республика Татарстан, Пестречинский район, село Ленино-Кокушкино	0101000020E6100000ABB35A608FD748403B6EF8DD74E94B40
973	7	64	1398	15938	11217	\N	55.712426000000001	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Кулаево, ул.Молодежная, д.22а		0101000020E6100000D40D147827C94840F96871C630DB4B40
972	7	64	1398	15916	11216	\N	55.702992000000002	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Кряш-Серда, ул.Татарстан, д.6а		0101000020E6100000B610E4A084F74840C1AC50A4FBD94B40
971	7	64	1398	15834	11215	\N	55.812626000000002	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Кощаково, ул.Центральная, д.19		0101000020E61000008236397CD2B348408DF0F62004E84B40
970	7	64	1398	15809	11214	\N	55.717837000000003	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Конь, ул.Советская, д.61а		0101000020E6100000D8497D59DADB4840EC6D3315E2DB4B40
969	7	64	1398	15746	11213	\N	55.806353000000001	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Ковали, ул.Школьная, д.1		0101000020E6100000C4CDA9640006494008043A9336E74B40
968	7	64	1398	15722	11212	\N	55.915441999999999	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Кобяково, ул.Тукая, д.28		0101000020E6100000E28FA2CEDCE9484042B115342DF54B40
967	7	64	1398	15651	11211	\N	55.754998000000001	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Кибячи, ул.Пионерская, д.9		0101000020E6100000C9C6832D76FD4840D04543C6A3E04B40
965	7	64	1398	15565	11209	\N	55.657169000000003	Республика Татарстан (Татарстан), Пестречинский муниципальный район, п.Карповка, ул.Советская, д.37		0101000020E610000076711B0DE0C34840F778211D1ED44B40
964	7	64	1398	15543	11208	\N	55.809989999999999	Республика Татарстан (Татарстан), Пестречинский муниципальный район, д.Званка, ул.Приозерная, д.19		0101000020E6100000ACAC6D8AC7AF4840240B98C0ADE74B40
963	7	64	1398	15466	11206	\N	55.655380999999998	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Екатериновка, ул.Школьная, д.2		0101000020E61000002E39EE940EEA4840BBB54C86E3D34B40
962	7	64	1398	15444	11205	\N	55.741039000000001	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Богородское, ул.Центральная, д.46		0101000020E6100000A0C6BDF90DB14840C007AF5DDADE4B40
961	7	64	1398	15369	11204	\N	55.892142999999997	Республика Татарстан (Татарстан), Пестречинский муниципальный район, с.Белкино, ул.Школьная, д.87		0101000020E6100000FE0DDAAB8FEF48407B2DE8BD31F24B40
915	7	64	1254	13177	11158	\N	54.487808999999999	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Якушкино, ул.Школьная, д.2		0101000020E6100000F59F353FFE504940E4D87A86703E4B40
928	7	64	1254	13813	11168	\N	54.488095999999999	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Чулпаново, ул.Центральная, д.2А		0101000020E6100000751F80D4263449407AA702EE793E4B40
959	7	64	1254	15265	11201	\N	54.630837	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Чувашский Тимерлек, ул.Центральная, д.3		0101000020E61000008ACA863595214940AA0D4E44BF504B40
912	7	64	1254	13065	11156	\N	54.454587389966598	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Чувашская Менча, ул.Шоссейная, д.25	Россия, республика Татарстан, Нурлатский район, село Чувашская Менча	0101000020E610000081CB63CDC85E4940E71725E82F3A4B40
910	7	64	1254	12970	11154	\N	54.414375594211101	Республика Татарстан (Татарстан), Нурлатский муниципальный район, п.Чишма, ул.Кооперативная, д.65	Россия, республика Татарстан, Нурлатский район, село Чишма	0101000020E61000004679E6E5B05D4940A71FD4450A354B40
926	7	64	1254	13645	11166	\N	54.409759999999999	423040, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Фомкино, ул.Школьная (здание школы), д.18		0101000020E61000007522C154333F4940BF9A030473344B40
946	7	64	1254	14672	11188	\N	54.593438225493202	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Тюрнясево, ул.Школьная, д.22	Россия, республика Татарстан, Нурлатский район, село Тюрнясево	0101000020E61000003447567E194C4940111AC1C6F54B4B40
958	7	64	1254	15244	11200	\N	54.503898	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Турнояс, ул.Лесная, д.26	Россия, республика Татарстан, Нурлатский район, село Турнояс	0101000020E61000005B25581CCE2249408942CBBA7F404B40
919	7	64	1254	61318	78539	\N	54.481629661280898	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Степное Озеро, ул.Школьная, д.21	Россия, республика Татарстан, Нурлатский район, село Степное Озеро	0101000020E61000004A7B832F4C484940E162450DA63D4B40
944	7	64	1254	14574	11185	\N	54.548743999999999	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Старые Челны, ул.Ленина, д.6		0101000020E610000093C7D3F2037B494028F04E3E3D464B40
954	7	64	1254	15051	11196	\N	54.781758000000004	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Старое Альметьево, ул.Октябрьская, д.19		0101000020E6100000EA5910CAFB2C494075B169A510644B40
952	7	64	1254	14965	11194	\N	54.824669	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Старая Татарская Амзя, ул.Карла Маркса, д.5		0101000020E6100000386BF0BE2A3549403483F8C08E694B40
938	7	64	1254	14304	11181	\N	54.498522999999999	423040, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Средняя Камышла, ул.Школьная (здание школы), д.31		0101000020E610000082902C6002674940E3A6069ACF3F4B40
948	7	64	1254	14772	11190	\N	54.689601000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Селенгуши, ул.Гагарина, д.32		0101000020E610000005DCF3FC69414940FB2477D844584B40
918	7	64	1254	13350	11161	\N	54.535384000000001	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Салдакаево, ул.Центральная, д.14		0101000020E61000005B61FA5E434A49409D66817687444B40
935	7	64	1254	14107	11176	\N	54.604472999999999	423040, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Русское Богдашкино, ул.Школьная (здание школы), д.14А		0101000020E61000004DDA54DD2373494052280B5F5F4D4B40
957	7	64	1254	15170	11202	\N	54.535969000000001	Республика Татарстан (Татарстан), Нурлатский муниципальный район, п.Октябрина, ул.Садовая, д.3		0101000020E61000001288D7F50B304940BD55D7A19A444B40
903	7	64	1254	40898	11417	\N	54.425750353103197	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Нурлатская, д.8	Россия, республика Татарстан, Нурлат	0101000020E6100000DC65BFEE74674940D122DBF97E364B40
897	7	64	1254	40898	11132	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Куйбышева, д.47		0101000020E610000053CC41D0D1664940DD4598A25C364B40
909	7	64	1254	12908	11426	\N	54.409576999999999	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Новое  Иглайкино, ул.Пушкина, д.5		0101000020E610000017F4DE1802744940CE18E6046D344B40
960	7	64	1254	15341	11203	\N	54.575687000000002	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Новая Тумба, ул.Шоссейная, д.1		0101000020E61000004C1B0E4B030F4940BEDD921CB0494B40
951	7	64	1254	14893	11193	\N	54.824337	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Новая Амзя, ул.Ленина, д.12		0101000020E61000000C5872158B394940FEF0F3DF83694B40
945	7	64	1254	14596	11187	\N	54.498659000000004	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Нижние Челны, ул.Ленина, д.1		0101000020E6100000E9279CDD5A7C4940946DE00ED43F4B40
947	7	64	1254	14693	11189	\N	54.636260999999998	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Мамыково, ул.Тельмана, д.51		0101000020E6100000CD751A69A94C4940315C1D0071514B40
943	7	64	1254	14501	11184	\N	54.554473000000002	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Курманаево, ул.Клубная, д.3		0101000020E6100000FC8D76DCF0714940ECC1A4F8F8464B40
955	7	64	1254	15074	11197	\N	54.834968000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Кульбаево-Мараса, ул.Ленина, д.30	Россия, республика Татарстан, Нурлатский район, село Кульбаево-Мараса	0101000020E610000063D1747632264940709A3E3BE06A4B40
920	7	64	1254	61470	79219	\N	54.525947391822498	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Кривое Озеро, ул.Центральная, д.76		0101000020E61000006C5CFFAECF464940F436363B52434B40
950	7	64	1254	14796	11191	\N	54.736581999999999	423040, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Кичкальня, ул.Школьная (здание школы), д.17		0101000020E610000041F163CC5D2D49404069A851485E4B40
953	7	64	1254	14986	11195	\N	54.846699999999998	Республика Татарстан (Татарстан), Нурлатский муниципальный район, п.Кзыл Юл, ул.Октябрьская, д.8		0101000020E610000083A279008B484940F8C264AA606C4B40
937	7	64	1254	14220	11179	\N	54.532359	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Караульная Гора, ул.Школьная, д.27		0101000020E610000001A5A146215749409A5DF75624444B40
921	7	64	1254	13456	11162	\N	54.414921	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Илюткино, ул.Клубная, д.10		0101000020E61000009274CDE49B49494039B69E211C354B40
930	7	64	1254	13913	11171	\N	54.501927000000002	Республика Татарстан (Татарстан), Нурлатский муниципальный район, п.Заречный, ул.Центральная, д.4		0101000020E6100000E97DE36BCF3049405DFDD8243F404B40
927	7	64	1254	13739	11167	\N	54.457290999999998	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Ерыкла, ул.Школьная, д.34Г		0101000020E61000007B67B455493E4940A8E0F082883A4B40
911	7	64	1254	12996	11152	\N	54.440612000000002	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Ерепкино, ул.Кирова, д.9		0101000020E6100000CEFFAB8E1C574940D21C59F965384B40
956	7	64	1254	15143	11198	\N	54.568739999999998	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Елаур, ул.Центральная, д.25		0101000020E610000065506D70222E4940A9F6E978CC484B40
936	7	64	1254	14199	11178	\N	54.497363	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Егоркино, ул.Центральная, д.33		0101000020E6100000997E8978EB5A4940C79E3D97A93F4B40
923	7	64	1254	13556	11164	\N	54.510447999999997	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Гайтанкино, ул.Центральная, д.13		0101000020E61000002046088F3642494080272D5C56414B40
940	7	64	1254	14388	11182	\N	54.542743999999999	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Вишневая Поляна, ул.Школьная, д.5		0101000020E6100000A54929E8F6604940D40CA9A278454B40
931	7	64	1254	13934	11172	\N	54.636381	Республика Татарстан (Татарстан), Нурлатский муниципальный район, п.Бутаиха, ул.Лесозаводская, д.12		0101000020E61000005AB741EDB73A4940DC65BFEE74514B40
942	7	64	1254	14483	11183	\N	54.5685	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Бурметьево, ул.Центральная, д.1А		0101000020E6100000C91EA166486D494054E3A59BC4484B40
922	7	64	1254	13537	11163	\N	54.502105	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Биляр-Озеро, ул.Зеленая, д.48А		0101000020E61000008C81751C3F3C49403C1405FA44404B40
924	7	64	1254	13627	11165	\N	54.363926999999997	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Бикулово, ул.Школьная, д.23А		0101000020E6100000914259F8FA464940D190F128952E4B40
914	7	64	1254	40901	11177	\N	54.391244028348098	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Ахметово, ул.Центральная, д.48	Россия, республика Татарстан, Нурлатский район, село Ахметьево	0101000020E610000089B5F81400514940CC608C4814324B40
933	7	64	1254	14010	11175	\N	54.636735999999999	423040, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Андреевка, ул.Советская (здание школы), д.39А		0101000020E61000005B28999CDA7F4940CA17B49080514B40
55264	7	63	\N	1332	54512	\N	54.178412000000002	Республика Мордовия, город Саранск, Октябрьский район, Ленинградская, 34		0101000020E6100000E622BE13B39E4640639B5434D6164B40
913	7	64	1254	13084	11155	\N	54.456291	Республика Татарстан (Татарстан), Нурлатский муниципальный район, с.Аксумла, ул.Центральная, д.51		0101000020E6100000910DA48B4D4F4940C53A55BE673A4B40
917	7	64	1254	13279	11160	\N	54.506027503961498	Республика Татарстан (Татарстан), Нурлатский муниципальный район, д.Абрыскино, ул.Гагарина, д.59А	Россия, республика Татарстан, Нурлатский район, село Абрыскино	0101000020E6100000F48B12F4174C49401E6E8786C5404B40
902	7	64	6927	40899	11138	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Школьная, д.9		0101000020E610000053CC41D0D1664940DD4598A25C364B40
904	7	64	6927	40899	11141	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Самаренкина, д.4		0101000020E610000053CC41D0D1664940DD4598A25C364B40
906	7	64	6927	40899	11148	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Нижненурлатская, д.19	Россия, республика Татарстан, Нурлат	0101000020E610000053CC41D0D1664940DD4598A25C364B40
898	7	64	6927	40899	11134	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Мугинова, д.10	Россия, республика Татарстан, Нурлат	0101000020E610000053CC41D0D1664940DD4598A25C364B40
900	7	64	6927	40899	11139	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Мира, д.9		0101000020E610000053CC41D0D1664940DD4598A25C364B40
908	7	64	6927	40899	11150	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Клубная, д.1		0101000020E610000053CC41D0D1664940DD4598A25C364B40
899	7	64	6927	40899	12025	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Дружба, д.68		0101000020E610000053CC41D0D1664940DD4598A25C364B40
901	7	64	6927	40899	11136	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Гиматдинова, д.83		0101000020E610000053CC41D0D1664940DD4598A25C364B40
907	7	64	6927	40899	11147	\N	54.424702000000003	Республика Татарстан (Татарстан), Нурлатский муниципальный район, г.Нурлат, ул.Верхненурлатская, д.32		0101000020E610000053CC41D0D1664940DD4598A25C364B40
874	7	64	1157	61313	78532	\N	55.0150088712452	Республика Татарстан (Татарстан), Новошешминский муниципальный район, п.с-за Красный Октябрь, ул.Центральная, д.13	Россия, республика Татарстан, Новошешминский район, село совхоз Красный Октябрь	0101000020E6100000B9C3263273A34940A5129ED0EB814B40
892	7	64	1157	12129	11123	\N	55.150942000000001	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Шахмайкино, ул.Центральная, д.45		0101000020E6100000D7C0560916894940E2CB441152934B40
889	7	64	1157	11952	11122	\N	55.078324000000002	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Чувашская Чебоксарка, ул.Чапаева, д.3б		0101000020E6100000FE9DEDD11B724940F73E5585068A4B40
894	7	64	1157	12249	11125	\N	55.159295	Республика Татарстан (Татарстан), Новошешминский муниципальный район, д.Чертушкино, ул.Центральная, д.32а	Россия, республика Татарстан, Новошешминский район, село Чертушкино	0101000020E6100000AF97A608708249404AB54FC763944B40
887	7	64	1157	11865	11120	\N	55.210962000000002	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Татарское Утяшкино, ул.Центральная, д.10		0101000020E6100000D3156C239EAA4940715985CD009B4B40
890	7	64	1157	61307	78494	\N	54.955904051067897	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Слобода Черемуховая, ул.Пролетарская, д.47	Россия, республика Татарстан, Новошешминский район, село Слобода Черемуховая	0101000020E6100000A13193A817924940CB0EF10F5B7A4B40
884	7	64	1157	61316	78535	\N	55.0605644842665	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Слобода Петропавловская, ул.Ленина, д.33	Россия, республика Татарстан, Новошешминский район, село Слобода Петропавловская	0101000020E61000007C478D0931AF494050A8A78FC0874B40
871	7	64	1157	61388	79115	\N	55.014764095400203	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Слобода Екатерининская, ул.Центральная, д.49	Россия, республика Татарстан, Новошешминский район, село Слобода Екатерининская	0101000020E61000009B1BD313968849403E9468C9E3814B40
870	7	64	1157	61461	79207	\N	55.062741000000003	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Слобода Волчья, ул.Центральная, д.29	Россия, республика Татарстан, Новошешминский район	0101000020E6100000A5BBEB6CC8994940268FA7E507884B40
869	7	64	1157	61499	79257	\N	55.158759590279203	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Слобода Архангельская, ул.Горького, д.21а	Россия, республика Татарстан, Новошешминский район, село Слобода Архангельская	0101000020E61000005A0D897B2CA14940DCF4673F52944B40
888	7	64	1157	11937	11121	\N	55.057707999999998	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Русская Чебоксарка, ул.Речная, д.6	Россия, республика Татарстан, Новошешминский район, село Русская Чебоксарка	0101000020E6100000CE39782634774940D95BCAF962874B40
893	7	64	1157	12185	11124	\N	55.132773	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Простые Челны, ул.Центральная, д.58		0101000020E61000006EF8DD74CB8449405A65A6B4FE904B40
80	7	64	6913	41005	12058	\N	55.467489	Республика Татарстан, Заинский муниципальный район, с.Карманово, ул.Центральная, д.43Б		0101000020E6100000DE770C8FFD064A40B01EF7ADD6BB4B40
879	7	64	1157	11494	11115	\N	55.065669	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Новошешминск, ул.Школьная, д.5		0101000020E610000092088D60E39E494036AE7FD767884B40
880	7	64	1157	11494	11116	\N	55.065669	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Новошешминск, ул.Набережная, д.2		0101000020E610000092088D60E39E494036AE7FD767884B40
886	7	64	1157	11494	81105	\N	55.070867764988002	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Тубылгы Тау, ул.Молодежная, д.94	Россия, республика Татарстан, Новошешминский район, село Новошешминск	0101000020E61000008D4127840EA049409D2ADF3312894B40
883	7	64	1157	11494	11118	\N	55.065669	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Новошешминск, ул.Ленина, д.92а		0101000020E610000092088D60E39E494036AE7FD767884B40
882	7	64	1157	11494	11117	\N	55.065669	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Новошешминск, ул.Заливная, д.4		0101000020E610000092088D60E39E494036AE7FD767884B40
881	7	64	1157	11494	11117	\N	55.065669	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Новошешминск, ул.Заливная, д.5		0101000020E610000092088D60E39E494036AE7FD767884B40
875	7	64	1157	11298	11111	\N	54.970556000000002	Республика Татарстан (Татарстан), Новошешминский муниципальный район, д.Новопоселенная Лебедка, ул.Центральная, д.36		0101000020E6100000711B0DE02DB24940E277D32D3B7C4B40
872	7	64	1157	11180	11109	\N	55.002634999999998	Республика Татарстан (Татарстан), Новошешминский муниципальный район, д.Новое Иванаево, ул.Молодежная, д.1		0101000020E610000032772D211F8C49409869FB5756804B40
877	7	64	1157	11396	11113	\N	55.197249999999997	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Ленино, ул.Центральная, д.89		0101000020E61000006A4E5E6402A049406891ED7C3F994B40
873	7	64	1157	11196	11110	\N	55.176665999999997	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Ерыклы, ул.Ленина, д.53		0101000020E6100000414AECDADEB649405628D2FD9C964B40
876	7	64	1157	11379	11112	\N	54.982098999999998	Республика Татарстан (Татарстан), Новошешминский муниципальный район, д.Екатериновка, ул.Центральная, д.19		0101000020E61000005793A7ACA6BD49409737876BB57D4B40
878	7	64	1157	11469	11114	\N	55.227970999999997	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Горшково, ул.Луговая, д.54		0101000020E61000008C4D2B85409A4940DCB75A272E9D4B40
885	7	64	1157	11782	11119	\N	55.033113999999998	Республика Татарстан (Татарстан), Новошешминский муниципальный район, д.Андреевка, ул.Центральная, д.12	Россия, республика Татарстан, Новошешминский район, село Андреевка	0101000020E6100000144031B264B6494016855D143D844B40
868	7	64	1157	61455	79200	\N	54.905185321278303	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Акбуре, ул.Комсомольская, д.30	Россия, республика Татарстан, Новошешминский район, село Татарская Волчья	0101000020E61000001A6D5512D99F494036EA211ADD734B40
867	7	64	1157	10936	11108	\N	55.205615000000002	Республика Татарстан (Татарстан), Новошешминский муниципальный район, с.Азеево, ул.Советская, д.20		0101000020E6100000B2D5E594808C49409548A297519A4B40
836	7	64	856	9402	11074	\N	55.515456	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Шингальчи, ул.Школьная, д.34		0101000020E6100000075DC2A1B7E8494074435376FAC14B40
852	7	64	856	10182	11090	\N	55.381822999999997	423560, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Шереметьевка, ул.Октябрькая площадь (здание дома культуры), д.18а		0101000020E610000081D1E5CDE1C6494028EE7893DFB04B40
841	7	64	856	9672	11078	\N	55.470525000000002	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Туба, ул.Чапаева, д.18		0101000020E6100000A59F70766BDF4940A779C7293ABC4B40
850	7	64	856	10095	11088	\N	55.403568999999997	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, п.Трудовой, ул.Школьная, д.11		0101000020E61000006B48DC63E9D54940F7562426A8B34B40
838	7	64	856	9464	11075	\N	55.500309999999999	423554, Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Ташлык, адрес помещения для голосования: ул.Центральная (здание библиотеки), д.28а, адрес УИК: ул.Центральная (здание дома культуры), д.28	Россия, республика Татарстан, Нижнекамский район, село Ташлык	0101000020E6100000697407B133E749404EEE77280AC04B40
843	7	64	856	9786	11080	\N	55.447724000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Сухарево, ул.Пролетарская, д.12		0101000020E6100000556AF6402BD2494031D120054FB94B40
863	7	64	856	10772	11104	\N	55.379879000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Старошешминск, ул.Нижнекамская, д.24		0101000020E61000007BC1A739799F4940F6B704E09FB04B40
832	7	64	856	9240	11072	\N	55.656595000000003	423553, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Прости, ул.Школьная (здание школы), д.8		0101000020E61000003B70CE88D2FC4940CBDB114E0BD44B40
855	7	64	856	10390	11095	\N	55.346865000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Нижняя Уратьма, ул.Гагарина, д.45а		0101000020E6100000CA6ABA9EE8D049404390831266AC4B40
776	7	64	856	6398	11038	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Тукая, д.15А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
22535	7	61	659	7183	65627	\N	54.551721000000001	Кирябинское, Никольская, 10		0101000020E6100000AD4ECE50DCA14D401AC231CB9E464B40
848	7	64	856	10017	11087	\N	55.3976699111873	423005, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Нижние Челны, ул.Красноармейская (здание библиотеки), д.51	Россия, республика Татарстан, Нижнекамский район, село Нижние Челны	0101000020E61000002600FF942AEB4940D74CBED9E6B24B40
829	7	64	856	6398	11068	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Химиков, д.13		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
828	7	64	856	6398	11068	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Химиков, д.13А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
825	7	64	856	6398	11068	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Химиков, д.41		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
823	7	64	856	6398	11339	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Строителей, д.47		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
819	7	64	856	6398	11059	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Мира, д.60		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
817	7	64	856	6398	11059	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Мира, д.45		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
815	7	64	856	6398	11059	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Мира, д.16		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
814	7	64	856	6398	11059	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Мира, д.21		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
796	7	64	856	6398	11333	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Вахитова, д.2А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
795	7	64	856	6398	11333	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Вахитова, д.13		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
827	7	64	856	6398	11066	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Химиков, д.29	Россия, республика Татарстан, Нижнекамский район, Нижнекамск	0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
824	7	64	856	6398	11066	\N	55.647317281830802	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Химиков, д.45		0101000020E610000020B75F3E59ED49408A929048DBD24B40
782	7	64	856	6398	11066	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Химиков, д.35		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
772	7	64	6926	\N	11066	\N	55.640424427199797	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Химиков, д.8Б	Россия, республика Татарстан, Нижнекамск городской округ	0101000020E6100000F163CC5D4BEA494069C9E369F9D14B40
821	7	64	856	6398	11910	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Мира, д.79		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
803	7	64	856	6398	11053	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Шинников, д.60		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
802	7	64	856	6398	11053	\N	55.645532000000003	423570, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Шинников (здание гимназии №25), д.60		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
785	7	64	856	6398	11036	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Юности, д.4		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
783	7	64	856	6398	11036	\N	55.645532000000003	423570, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Юности (здание школы №8), д.14В		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
775	7	64	856	6398	11036	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Юности, д.23		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
773	7	64	856	6398	11036	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Юности, д.34		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
786	7	64	856	6398	11043	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Школьный бульвар, д.2		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
820	7	64	856	6398	11062	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Чулман, д.18		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
781	7	64	6926	\N	11041	\N	55.644404956668602	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Центральная, д.1	Россия, республика Татарстан, Нижнекамск городской округ	0101000020E6100000EB353D2828E949407F30F0DC7BD24B40
777	7	64	856	6398	11038	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Тукая, д.15		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
54148	7	62	\N	1218	62176	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Прохорова, д. 30		0101000020E6100000628731E9EFEF4740ACE122F774514C40
818	7	64	856	6398	11060	\N	55.646200916225297	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Сююмбике, д.38	Россия, республика Татарстан, Нижнекамский район, Нижнекамск	0101000020E6100000C1E5B16664EE49403DD2E0B6B6D24B40
778	7	64	856	6398	11039	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Строителей, д.9		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
793	7	64	856	6398	11045	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Спортивная, д.21А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
789	7	64	856	6398	11045	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Спортивная, д.13Б		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
788	7	64	856	6398	11044	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Сквер Лемаева, д.14		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
787	7	64	856	6398	11044	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Сквер Лемаева, д.12		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
810	7	64	856	6398	11057	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Мурадьяна, д.18А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
808	7	64	856	6398	11057	\N	55.645532000000003	423570, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Мурадьяна (здание школы №21), д.18А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
813	7	64	856	6398	11048	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Менделеева, д.37А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
797	7	64	856	6398	11048	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Менделеева, д.15А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
774	7	64	856	6398	11037	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Корабельная, д.13		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
800	7	64	856	6398	11049	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Кайманова, д.7		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
799	7	64	856	6398	11049	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Кайманова, д.4		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
798	7	64	856	6398	11046	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Гагарина, д.42		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
792	7	64	856	6398	11046	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Гагарина, д.5В		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
790	7	64	856	6398	11046	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Гагарина, д.1В		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
794	7	64	856	6398	11047	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, пр.Вахитова, д.19		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
811	7	64	856	6398	11055	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Бызова, д.1Б		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
806	7	64	856	6398	11055	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Бызова, д.9А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
805	7	64	856	6398	11055	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Бызова, д.10Б		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
804	7	64	856	6398	11055	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Бызова, д.18Б		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
822	7	64	856	6398	11063	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Баки Урманче, д.13		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
779	7	64	856	6398	11040	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.Ахтубинская, д.2		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
826	7	64	856	6398	11067	\N	55.645532000000003	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, г.Нижнекамск, ул.30 лет Победы, д.7А		0101000020E610000047718E3A3AEE4940C042E6CAA0D24B40
853	7	64	856	10278	11093	\N	55.388026000000004	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, д.Нариман, ул.Центральная, д.56б		0101000020E6100000FBE769C020BD4940B5FF01D6AAB14B40
860	7	64	856	10631	11100	\N	55.267707000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Кулмакса, ул.Центральная, д.26		0101000020E6100000A359D93EE4A1494084F4143944A24B40
835	7	64	856	9386	11073	\N	55.682265000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, п.Красный Ключ, ул.Советская, д.17а	Россия, республика Татарстан, Нижнекамский район, село Красный Ключ	0101000020E610000037A8FDD64EE849404C1AA37554D74B40
95025	7	63	\N	1332	54460	\N	54.201355	Республика Мордовия, г. Саранск, Октябрьский район, ул.Косарева, д.112-б		0101000020E6100000043752B648A046406BF12900C6194B40
847	7	64	856	9983	11085	\N	55.415455999999999	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Красная Кадка, ул.Ленина, д.60		0101000020E61000001DC9E53FA4E54940A77686A92DB54B40
861	7	64	856	10643	11101	\N	55.304246999999997	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Кармалы, ул.Пионерская, д.3		0101000020E610000052B648DA8D964940FB73D190F1A64B40
854	7	64	856	10309	11094	\N	55.348968999999997	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, п.Камский, ул.Московская, д.1		0101000020E610000007B29E5A7DBF4940AE282504ABAC4B40
865	7	64	856	10820	11106	\N	55.426963000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, пгт.Камские Поляны, ул.4, д.1	Россия, республика Татарстан, Нижнекамский район, поселок Камские Поляны	0101000020E61000009C525E2BA1B1494010CD3CB9A6B64B40
866	7	64	856	10820	11107	\N	55.426963000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, пгт.Камские Поляны, ул.2, д.20	Россия, республика Татарстан, Нижнекамский район, поселок Камские Поляны	0101000020E61000009C525E2BA1B1494010CD3CB9A6B64B40
864	7	64	856	10820	11105	\N	55.426963000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, пгт.Камские Поляны, ул.1, д.29	Россия, республика Татарстан, Нижнекамский район, поселок Камские Поляны	0101000020E61000009C525E2BA1B1494010CD3CB9A6B64B40
840	7	64	856	9599	11077	\N	55.489339999999999	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Каенлы, ул.Ленина, д.44		0101000020E6100000473B6EF8DDDC4940F44F70B1A2BE4B40
859	7	64	856	10582	11099	\N	55.291919999999998	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Елантово, ул.Нагорная, д.1г		0101000020E610000026FDBD141E9A49402F8672A25DA54B40
862	7	64	856	10722	11102	\N	55.292679	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Городище, ул.Колхозная, д.5а		0101000020E61000009B00C3F2E7934940ED9C668176A54B40
857	7	64	856	10468	11097	\N	55.256267000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Верхняя Уратьма, ул.Молодежная, д.2		0101000020E61000004E0AF31E67E04940A305685BCDA04B40
845	7	64	856	9874	11082	\N	55.371209	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Верхние Челны, ул.Молодежная, д.11		0101000020E6100000FC8D76DCF0E349408D7DC9C683AF4B40
842	7	64	856	9698	11939	\N	55.546917999999998	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Борок, ул.М.Горького, д.8		0101000020E6100000CB4DD4D2DCD64940FFCBB56801C64B40
831	7	64	856	9154	11069	\N	55.604371	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Большое Афанасово, ул.Молодежная, д.5	Россия, республика Татарстан, Нижнекамский район, село Большое Афанасово	0101000020E6100000CD920035B5E449404ED367075CCD4B40
830	7	64	856	9154	11069	\N	55.604371	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Большое Афанасово, ул.Молодежная, д.3	Россия, республика Татарстан, Нижнекамский район, село Большое Афанасово	0101000020E6100000CD920035B5E449404ED367075CCD4B40
846	7	64	856	40897	11103	\N	55.398845000000001	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Большие Аты, ул.Красноармейская, д.1		0101000020E6100000C11DA8531EDF494029965B5A0DB34B40
844	7	64	856	9804	11081	\N	55.414726000000002	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Болгар, ул.Ленина, д.56а		0101000020E6100000B9196EC0E7CD49408466D7BD15B54B40
858	7	64	856	10540	11098	\N	55.137672000000002	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, д.Благодатная, ул.Мира, д.1а		0101000020E610000078EE3D5C72C4494097C9703C9F914B40
839	7	64	856	9571	11076	\N	55.545024421082204	Республика Татарстан (Татарстан), Нижнекамский муниципальный район, с.Балчиклы, ул.Терешковой, д.52а	Россия, республика Татарстан, Нижнекамский район, село Балчиклы	0101000020E6100000F29881CAF8E749407EC4AF58C3C54B40
645	7	64	32	40860	10967	\N	55.176929437199902	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Шуганка, ул.Ленина, д.8	Россия, республика Татарстан, Муслюмовский район, село Шуганга	0101000020E6100000D238D4EFC28C4A40645B069CA5964B40
672	7	64	32	904	10998	\N	55.395583000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Уразметьево, ул.Школьная, д.45А		0101000020E6100000DF4F8D976ECE4A4042EDB776A2B24B40
670	7	64	32	790	10996	\N	55.276662000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Тойгильдино, ул.Центральная, д.2		0101000020E610000000AB23473A834A40E20511A969A34B40
663	7	64	32	345	10984	\N	55.392868	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, д.Тогашево, ул.Вахитова, д.10А		0101000020E6100000BC0512143F844A408DD2A57F49B24B40
671	7	64	32	847	10997	\N	55.258786000000001	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Ташлияр, ул.Урожайная, д.78Б		0101000020E6100000E0D5726726784A40D2544FE61FA14B40
655	7	64	32	32349	10975	\N	55.406697000000001	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, д.Таш-Елга, ул.Лесная, д.35А	Россия, республика Татарстан, Муслюмовский район, село Таш-Елга	0101000020E610000076FEEDB25FA34A40CF30B5A50EB44B40
651	7	64	32	32158	10971	\N	55.442422999999998	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Татарское Булярово, ул.Дружбы, д.5А		0101000020E610000096B377465BC94A40C5FF1D51A1B84B40
22415	7	61	102	662	65928	\N	56.160105000000001	с.Савкияз, Центральная, 24		0101000020E61000004582A966D6F64B408A7615527E144C40
674	7	64	32	995	11002	\N	55.180768	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, д.Татарская Смыловка, ул.Ленинская, д.5		0101000020E61000002E3D9AEAC9AC4A40E814E46723974B40
650	7	64	32	40861	10968	\N	55.326557999999999	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Старый Варяш, ул.Чишма, д.10А		0101000020E61000005B441493379C4A40A31F0DA7CCA94B40
669	7	64	32	723	10995	\N	55.317138	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Старые Карамалы, ул.Кооперативная, д.113А		0101000020E6100000CFF4126399C64A40D0285DFA97A84B40
666	7	64	32	540	10993	\N	55.407922999999997	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Семяково, ул.Школьная, д.8А		0101000020E610000003D19332A9B54A40A22424D236B44B40
659	7	64	32	38	10981	\N	55.273400000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Салауз Мухан, ул.Кооперативная, д.62		0101000020E6100000E84EB0FF3AA14A40FB5C6DC5FEA24B40
673	7	64	32	980	11001	\N	55.196762	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Русский Шуган, ул.Ленина, д.16А		0101000020E6100000F2CEA10C55994A403B8C497F2F994B40
665	7	64	32	481	10990	\N	55.328668	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Октябрь, ул.Центральная, д.33А		0101000020E6100000056F48A302CF4A40F19E03CB11AA4B40
664	7	64	32	420	10985	\N	55.270498000000003	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Новые Усы, ул.Советская, д.30		0101000020E6100000B51B7DCC07AE4A4014D1AFAD9FA24B40
652	7	64	32	40864	10973	\N	55.402916917438603	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, д.Ново Саитово, ул.Мирная, д.50А	Россия, республика Татарстан, Муслюмовский район, село Новое Саитово	0101000020E610000026FF93BF7BC34A405000C5C892B34B40
662	7	64	32	287	10983	\N	55.368333999999997	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Нижний Табын, ул.Школьная, д.40А		0101000020E610000067D47C957C844A409F008A9125AF4B40
638	7	64	32	31500	10954	\N	55.299255000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Муслюмово, ул.Пушкина, д.32		0101000020E61000003410CB660E994A400E15E3FC4DA64B40
636	7	64	32	31500	10954	\N	55.299255000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Муслюмово, ул.Пушкина, д.35		0101000020E61000003410CB660E994A400E15E3FC4DA64B40
639	7	64	32	31500	10955	\N	55.299255000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Муслюмово, ул.Октябрьская, д.39		0101000020E61000003410CB660E994A400E15E3FC4DA64B40
640	7	64	32	31500	10957	\N	55.299255000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Муслюмово, ул.Молодежная, д.15		0101000020E61000003410CB660E994A400E15E3FC4DA64B40
642	7	64	32	31500	10951	\N	55.299255000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Муслюмово, ул.Кооперативная, д.170А		0101000020E61000003410CB660E994A400E15E3FC4DA64B40
637	7	64	32	31500	10951	\N	55.299255000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Муслюмово, ул.Кооперативная, д.150		0101000020E61000003410CB660E994A400E15E3FC4DA64B40
660	7	64	32	147	10994	\N	55.240209383520501	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Михайловко, ул.Гагарина, д.24	Россия, республика Татарстан, Муслюмовский район, село Михайловка	0101000020E6100000FF756EDA8C774A40399A232BBF9E4B40
658	7	64	32	32498	10979	\N	55.301068999999998	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Митряево, ул.Кооперативная, д.65		0101000020E61000007044F7AC6BA24A40726BD26D89A64B40
657	7	64	32	61338	78608	\N	55.312977175500798	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Мелля-Тамак, ул.Кооперативная, д.32А	Россия, республика Татарстан, Муслюмовский район, село Меллятамак	0101000020E6100000DF88EE59D78C4A4039B35DA10FA84B40
653	7	64	32	32276	10978	\N	55.415421000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Мари Буляр, ул.60 лет Октября, д.31		0101000020E610000035D4282499BD4A402B89EC832CB54B40
656	7	64	32	32403	10976	\N	55.433185000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Кряш-Шуран, ул.Центральная, д.6А		0101000020E610000065C8B1F50C934A40130F289B72B74B40
668	7	64	32	671	11004	\N	55.423048999999999	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, д.Елгабаш, ул.Колхозная, д.42А		0101000020E610000017F3734353B24A4081CD397826B64B40
661	7	64	32	214	10982	\N	55.361006000000003	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Верхний Табын, ул.Тукая, д.21А		0101000020E610000071FF91E9D07F4A4074D4D17135AE4B40
649	7	64	32	32078	10969	\N	55.361215999999999	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Варяш-Баш, ул.Кооперативная, д.45А		0101000020E6100000C02500FF94A04A405E656D533CAE4B40
648	7	64	32	61495	79253	\N	55.226520145865898	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Большой Чекмак, ул.Центральная, д.1	Россия, республика Татарстан, Муслюмовский район, село Большой Чекман	0101000020E6100000FC6F253B36944A40E9F17B9BFE9C4B40
646	7	64	32	61405	79137	\N	55.219854785625998	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Баюково, ул.Советская, д.2	Россия, республика Татарстан, Муслюмовский район, село Баюкова	0101000020E610000003B00111E2CA4A40596E6935249C4B40
54147	7	62	\N	1218	62176	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Прохорова, д. 31		0101000020E6100000628731E9EFEF4740ACE122F774514C40
644	7	64	32	31844	10964	\N	55.192214	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Баланны, ул.Советская, д.85		0101000020E6100000B6BA9C1210854A40ABEAE5779A984B40
643	7	64	32	31831	10963	\N	55.366219999999998	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, с.Амикеево, ул.Фаррахова, д.32	Россия, республика Татарстан, Муслюмовский район, село Амикеево	0101000020E6100000F16778B306DB4A401092054CE0AE4B40
595	7	64	1856	29484	10899	\N	55.542946000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д.Ямаково, ул.Галиева, д.14А		0101000020E6100000570740DCD5754A403CBF28417FC54B40
618	7	64	1856	61490	79245	\N	55.666629999999998	Республика Татарстан (Татарстан), Мензелинский муниципальный район, пос.Юртово, ул.Лесная, д.2	Россия, республика Татарстан, Мензелинский район	0101000020E6100000BBB6B75B92874A402844C02154D54B40
611	7	64	1856	30252	10924	\N	55.679015999999997	Республика Татарстан (Татарстан), Мензелинский муниципальный район, пос.Холодный ключ, ул.Тукая, д.11А		0101000020E6100000B22AC24D46894A40F9BA0CFFE9D64B40
599	7	64	1856	29663	10901	\N	55.630262999999999	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Усаево, ул.Школьная, д.19	Россия, республика Татарстан, Мензелинский район, село Усаево	0101000020E6100000F0FCA204FD6F4A407E703E75ACD04B40
616	7	64	1856	30500	10929	\N	55.775058999999999	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д.Урусово, ул.Дружбы, д.42А		0101000020E6100000126A8654516E4A4038BC202235E34B40
614	7	64	1856	30396	10928	\N	55.759070999999999	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д.Тулубаево, ул.Социалистическая, д.36		0101000020E610000085CE6BEC126B4A40C72B103D29E14B40
597	7	64	1856	29580	10912	\N	55.626674999999999	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Топасево, ул.Школьная, д.2		0101000020E61000004963B48EAA784A40431CEBE236D04B40
583	7	64	1856	40836	10881	\N	55.4535170036065	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Татарская Мушуга, ул.Алая заря, д.2	Россия, республика Татарстан, Мензелинский район, село Татарская Мишуга	0101000020E61000001B81785DBFB44A400B9755D80CBA4B40
592	7	64	1856	29464	10891	\N	55.497453999999998	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Старый Иркеняш, ул. Имянле, д.21		0101000020E6100000335019FF3EA34A40D7A19A92ACBF4B40
610	7	64	1856	30186	10922	\N	55.646030000000003	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Старое Мазино, ул.Ленина, д.31		0101000020E610000031D0B52FA0874A40111E6D1CB1D24B40
612	7	64	1856	30272	10926	\N	55.537453999999997	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Старая Матвеевка, ул.Горького, д.5		0101000020E61000001EDC9DB5DBA44A405C8DEC4ACBC44B40
613	7	64	1856	30351	10927	\N	55.579500000000003	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Старая Александровка, ул.Новая, д.45А		0101000020E6100000075C57CC08AF4A401904560E2DCA4B40
604	7	64	1856	29887	10905	\N	55.528956000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Русский Каран, ул.Октября, д.43		0101000020E6100000CFD72C978D904A40F18288D4B4C34B40
590	7	64	1856	40842	10892	\N	55.668378614479998	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Подгорный Такермен, ул.Марса, д.54А		0101000020E6100000A5C00298325C4A40A62A6D718DD54B40
608	7	64	1856	30097	10917	\N	55.759334000000003	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Подгорный Байлар, ул.Центральная, д.20А	Россия, республика Татарстан, Мензелинский район, село Подгорный Байлар	0101000020E61000006CAF05BD377E4A40D55E44DB31E14B40
606	7	64	1856	30010	10909	\N	55.696798000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Новый Мелькен, ул.Школьная, д.9		0101000020E6100000EB3BBF2841A74A4088F546AD30D94B40
605	7	64	1856	29961	10906	\N	55.462161000000002	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Новое Мазино, ул.Центральная, д.19		0101000020E6100000213A048E048E4A404B3E761728BB4B40
600	7	64	1856	29719	10902	\N	55.666041	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д.Новая Александровка, ул.Первомайская, д.15	Россия, республика Татарстан, Мензелинский район, село Новая Александровка	0101000020E61000008E739B70AF6A4A40C765DCD440D54B40
603	7	64	1856	29875	11885	\N	55.529282000000002	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Николаевка, ул.Мираня, д.45		0101000020E6100000E2C96E66F4974A40452E3883BFC34B40
601	7	64	1856	29753	10925	\N	55.564857275223801	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Наратлы-Кичу, ул.К.Маркса, д.6	Россия, республика Татарстан, Мензелинский район, село Наратлы-Кичу	0101000020E6100000016E162F166C4A4056F5F23B4DC84B40
631	7	64	1856	30688	10945	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Шамова, д.48		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
626	7	64	1856	30688	10939	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Чернышевского, д.16		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
629	7	64	1856	30688	10942	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Челнинский Тракт, д.1		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
54943	7	63	\N	12510	54387	\N	54.045367935164798	г. Ковылкино, фролова, 3 А	Россия, республика Мордовия, Ковылкино	0101000020E6100000E6AC4F3926F7454079245E9ECE054B40
634	7	64	1856	30688	10947	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Татарстан, д.2А		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
620	7	64	1856	30688	10933	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Стрителей, д.39		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
627	7	64	1856	30688	10941	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.М.Джалиля, д.18		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
635	7	64	1856	30688	10948	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Ленина, д.69		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
625	7	64	1856	30688	10940	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.К.Маркса, д.77	Россия, республика Татарстан, Мензелинский район, Мензелинск	0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
633	7	64	1856	30688	10935	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Изыскателей, д.3/15Б		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
623	7	64	1856	30688	10935	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Изыскателей, д.2/7		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
622	7	64	1856	30688	10935	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Изыскателей, д.1/22	Россия, республика Татарстан, Мензелинский район, Мензелинск	0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
621	7	64	1856	30688	10935	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Изыскателей, д.2/15		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
632	7	64	1856	30688	10937	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Гурьянова, д.98	Россия, республика Татарстан, Мензелинский район, Мензелинск	0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
624	7	64	1856	30688	10937	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Гурьянова, д.84		0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
630	7	64	1856	30688	10943	\N	55.725169000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, г.Мензелинск, ул.Головина, д.137	Россия, республика Татарстан, Мензелинский район, Мензелинск	0101000020E6100000245E9ECE158D4A4059897956D2DC4B40
587	7	64	1856	29139	10883	\N	55.627071999999998	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д.Куяново, ул.Советская, д.24	Россия, республика Татарстан, Мензелинский район, село Куяново	0101000020E6100000E0D91EBDE1AC4A40601E32E543D04B40
598	7	64	1856	29618	10900	\N	55.631458000000002	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Кузембетьево, ул.Советская, д.33А		0101000020E6100000A699EE7552614A401766A19DD3D04B40
596	7	64	1856	29533	10898	\N	55.692739000000003	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Коноваловка, ул.Центральная, д.6		0101000020E61000002827DA5548794A40F6D4EAABABD84B40
593	7	64	1856	40852	10915	\N	55.480837000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д.Кзыл-Тюбяк, ул.Гагарина, д.13		0101000020E6100000DB32E02C25A74A4077DA1A118CBD4B40
582	7	64	1856	61510	79270	\N	55.438574789422297	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Калтаково, ул.Школьная, д.2	Россия, республика Татарстан, Мензелинский район, село Калтаново	0101000020E61000004BCADDE7F8AA4A40EEEBC03923B84B40
594	7	64	1856	29452	10896	\N	55.532069999999997	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Кадряково, ул.Кирова, д.29	Россия, республика Татарстан, Мензелинский район, село Кадряково	0101000020E6100000CEC133A1497A4A406397A8DE1AC44B40
591	7	64	1856	61467	79216	\N	55.706137555459101	Республика Татарстан (Татарстан), Мензелинский муниципальный район, пос.совхоза им.Воровского, ул.Центральная, д.26	Россия, республика Татарстан, Мензелинский район, село Имени Воровского	0101000020E6100000A41AF67B62954A403F3BE0BA62DA4B40
607	7	64	1856	30041	10911	\N	55.697468000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Дусай Кичу, ул.М.Джалиля, д.48	Россия, республика Татарстан, Мензелинский район, село Дусай-Кичу	0101000020E61000007EE36BCF2CAD4A40D600A5A146D94B40
585	7	64	1856	29058	10944	\N	55.657763000000003	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д.Дружба, ул.Школьная, д.2	Россия, республика Татарстан, Мензелинский район, село Дружба	0101000020E61000006C97361C96964A406AC2F69331D44B40
609	7	64	1856	30139	10920	\N	55.765954000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Деуково, ул.Советская, д.25		0101000020E6100000A7E8482EFF734A40C51EDAC70AE24B40
617	7	64	1856	30542	10931	\N	55.798647000000003	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Гулюково, ул.Строительная, д.1	Россия, республика Татарстан, Мензелинский район, село Гулюково	0101000020E610000082751C3F54744A4036069D103AE64B40
588	7	64	1856	40838	10886	\N	55.653482976505899	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Верхний Такермен, ул.М.Джалиля, д.1Б		0101000020E6100000C495B37746594A40F9BEB854A5D34B40
22083	7	61	237	17051	65197	\N	55.988166999999997	с. Малоустьикинское, Трактовая, 2а		0101000020E6100000DA756F45622A4D4043FE99417CFE4B40
619	7	64	1856	30658	10932	\N	55.555351999999999	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Верхние Юшады, ул.Новая, д.4	Россия, республика Татарстан, Мензелинский район, село Верхние Юшады	0101000020E61000006A4C88B9A4824A4054E23AC615C74B40
586	7	64	1856	29077	10882	\N	55.650165000000001	Республика Татарстан (Татарстан), Мензелинский муниципальный район, с.Бикбулово, ул.Ленина, д.50		0101000020E6100000B4722F302BB84A407E00529B38D34B40
581	7	64	1856	28884	10878	\N	55.464105000000004	Республика Татарстан (Татарстан), Мензелинский муниципальный район, д. Атрякле, ул.Центральная, д.24	Россия, республика Татарстан, Мензелинский район, село Атрякле	0101000020E6100000FE7E315BB2AC4A407E74EACA67BB4B40
580	7	64	1814	28814	10877	\N	55.951929999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Тураево, ул.Центральная, д.9а		0101000020E6100000452E3883BF494A40670A9DD7D8F94B40
569	7	64	1814	28312	10864	\N	56.012979000000001	Республика Татарстан (Татарстан), Менделеевский муниципальный район, д.Тойма, ул.Вахитова, д.40а		0101000020E61000002D5BEB8B84324A407444BE4BA9014C40
579	7	64	1814	28762	10876	\N	56.058608999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Тойгузино, ул.Центральная, д.48		0101000020E6100000D8B79388F03B4A402920ED7F80074C40
578	7	64	1814	28725	10875	\N	55.803559999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Тихоново, ул.Коммунистическая, д.27в	Россия, республика Татарстан, Менделеевский район, село Тихоново	0101000020E61000003B56293DD31D4A40D72FD80DDBE64B40
577	7	64	1814	28677	10874	\N	55.859589999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Татарские Челны, ул.Школьная, д.16	Россия, республика Татарстан, Менделеевский район, село Татарские Челны	0101000020E61000002250FD83481C4A40FCFB8C0B07EE4B40
564	7	64	1814	28079	10860	\N	55.940331	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Старое Гришкино, ул.Молодежная, д.1		0101000020E61000005B069CA564214A401E3526C45CF84B40
565	7	64	1814	28146	10861	\N	55.944232999999997	423648, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Сетяково, ул.Дружбы (здание клуба), д.10		0101000020E610000094FB1D8A02334A40E8667FA0DCF84B40
576	7	64	1814	28608	10873	\N	55.969853999999998	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Псеево, ул.Тукая, д.1а		0101000020E6100000904B1C7920424A4088F2052D24FC4B40
575	7	64	1814	28585	10872	\N	55.891990999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, д.Мунайка, ул.Ленина, д.54		0101000020E6100000EAB0C22D1F214A40C5A9D6C22CF24B40
572	7	64	1814	28428	10868	\N	56.042723000000002	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Монашево, ул.Школьная, д.21		0101000020E6100000A4DFBE0E9C254A40BDE47FF277054C40
557	7	64	1814	27253	10855	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, б-р Интернационалистов, д.2	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
558	7	64	1814	27253	11853	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, б-р Интернационалистов, д.3	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
556	7	64	1814	27253	10854	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Юбилейная, д.8	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
555	7	64	1814	27253	10854	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Юбилейная, д.10	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
552	7	64	1814	27253	10852	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Фомина, д.10	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
560	7	64	1814	27253	10857	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Тукая, д.7		0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
561	7	64	1814	27253	10858	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Татарстана, д.1б		0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
548	7	64	1814	27253	10851	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Профсоюзная, д.2	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
559	7	64	1814	27253	10856	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Набережная, д.83	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
546	7	64	1814	27253	10850	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.М.Горького, д.3а	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
550	7	64	1814	27253	10849	\N	55.896220999999997	423650, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Менделеевский муниципальный район, г.Менделеевск, ул.Зеленая (здание МБДОУ №8), д.11		0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
547	7	64	1814	27253	10849	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Зеленая, д.23	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
553	7	64	1814	27253	10853	\N	55.896220999999997	"423650, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Менделеевский муниципальный район, г.Менделеевск, ул.Бурмистрова (здание РДК ""Юность""), д.3"	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
551	7	64	1814	27253	10853	\N	55.896220999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, город Менделеевск, ул.Бурмистрова, д.17	Россия, республика Татарстан, Менделеевский район, Менделеевск	0101000020E6100000D943FB58C1274A40847EA65EB7F24B40
571	7	64	1814	28405	10869	\N	56.007423000000003	Республика Татарстан (Татарстан), Менделеевский муниципальный район, д.Камаево, ул.Д.Сирая, д.14а		0101000020E610000062855B3E922A4A407E1EA33CF3004C40
573	7	64	1814	28499	10870	\N	56.018394440947098	423644, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Ильнеть, ул.Школьная (здание средней школы), д.9	Россия, республика Татарстан, Менделеевский район, село Ильнеть	0101000020E61000006D904946CE1E4A40A8380EBC5A024C40
570	7	64	1814	28336	10866	\N	55.965077999999998	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Ижевка, ул.Советская, д.23		0101000020E6100000EA944737C2504A40670B08AD87FB4B40
568	7	64	1814	28244	10863	\N	55.980038999999998	Республика Татарстан (Татарстан), Менделеевский муниципальный район, д.Енабердино, ул.Клубная, д.7		0101000020E6100000FA0D130D522A4A40FBE6FEEA71FD4B40
567	7	64	1814	40834	10862	\N	55.925787999999997	Республика Татарстан (Татарстан), Менделеевский муниципальный район, д.Брюшли, ул.Заречная, д.14		0101000020E6100000581F0F7D77FB4940BE839F3880F64B40
563	7	64	1814	28039	10859	\N	55.926034999999999	Республика Татарстан (Татарстан), Менделеевский муниципальный район, с.Бизяки, ул.Новая, д.1	Россия, республика Татарстан, Менделеевский район, село Бизяки	0101000020E6100000E31A9FC9FE394A40C6F99B5088F64B40
500	7	64	1755	61529	79334	\N	55.627133000000001	"Республика Татарстан (Татарстан), Мамадышский муниципальный район, п.Ферма №2 с/за ""Мамадышский"", ул.Гагарина, д.14"	Россия, республика Татарстан, Мамадышский район, село ферма 2 Совхоза Мамадышский	0101000020E6100000601DC70F95A44940069FE6E445D04B40
532	7	64	1755	61391	79118	\N	55.660519369278298	"Республика Татарстан (Татарстан), Мамадышский муниципальный район, п.с/за ""Пятилетка"", ул.Садовая, д.20"	Россия, республика Татарстан, Мамадышский район, село совхоз Пятилетка	0101000020E6100000B7EEE6A90EB549407DB1F7E28BD44B40
535	7	64	1755	61226	77665	\N	55.708827671169097	"Республика Татарстан (Татарстан), Мамадышский муниципальный район, п.с/за ""Мамадышский"", ул.Мира, д.11"	Россия, республика Татарстан, Мамадышский район, село совхоз Мамадышский	0101000020E61000001041D5E8D5AE49409A3E3BE0BADA4B40
545	7	64	1755	27217	10846	\N	55.910815999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, д.Шемяк, ул.Г.Тукая, д.4	Россия, республика Татарстан, Мамадышский район, село Шемяк	0101000020E6100000CB65A3737E8249403656629E95F44B40
544	7	64	1755	27180	10845	\N	55.924264999999998	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Шадчи, ул.Молодёжная, д.18	Россия, республика Татарстан, Мамадышский район, село Шадчи	0101000020E610000082734694F6A2494031EBC5504EF64B40
543	7	64	1755	27136	10844	\N	55.812798000000001	Республика Татарстан (Татарстан), Мамадышский муниципальный район, д.Хасаншино, ул.Ленина, д.35	Россия, республика Татарстан, Мамадышский район, село Хасаншино	0101000020E6100000EC3026FDBD8E49408A20CEC309E84B40
542	7	64	1755	27067	10843	\N	55.6935	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Усали, ул.Центральная, д.38А	Россия, республика Татарстан, Мамадышский район, село Усали	0101000020E61000004E4700378B6D494054E3A59BC4D84B40
541	7	64	1755	27059	10842	\N	55.590367999999998	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Уразбахтино, ул.Центральная, д.28	Россия, республика Татарстан, Мамадышский район, село Уразбахтино	0101000020E6100000C0046EDDCD9149406E4DBA2D91CB4B40
540	7	64	1755	26986	10840	\N	55.910614000000002	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Тулбай, ул.Пионерская, д.7	Россия, республика Татарстан, Мамадышский район, село Тулбай	0101000020E61000006CE9D1544F884940CFA3E2FF8EF44B40
539	7	64	1755	26948	10838	\N	55.863939000000002	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Тавели, ул.Нагорная, д.70	Россия, республика Татарстан, Мамадышский район, село Тавели	0101000020E61000003FC4060B277F4940965E9B8D95EE4B40
538	7	64	1755	26912	10837	\N	55.832636000000001	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Старый Кумазан, ул.Школьная, д.7	Россия, республика Татарстан, Мамадышский район, село Старый Кумазан	0101000020E610000055698B6B7CA2494073BC02D193EA4B40
537	7	64	1755	26870	10841	\N	55.678189000000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Средние Кирмени, ул.Ленина, д.16А	Россия, республика Татарстан, Мамадышский район, село Средние Кирмени	0101000020E6100000BE688F17D28F4940E4C0ABE5CED64B40
536	7	64	1755	26791	10836	\N	55.547345999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Соколка, ул.Школьная, д.38		0101000020E61000007506465ED6C0494057CC086F0FC64B40
534	7	64	1755	26719	10833	\N	55.553227999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Секинесь, ул.Школьная, д.3	Россия, республика Татарстан, Мамадышский район, село Секинесь	0101000020E6100000978DCEF929A84940A19DD32CD0C64B40
533	7	64	1755	26668	10834	\N	55.536354000000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Рагозино, ул.Новая, д.12	Россия, республика Татарстан, Мамадышский район, село Рагозино	0101000020E6100000B2D6506A2FA04940168A743FA7C44B40
531	7	64	1755	26586	10829	\N	55.982613000000001	Республика Татарстан (Татарстан), Мамадышский муниципальный район, д.Пойкино, ул.Октябрьская, д.16	Россия, республика Татарстан, Мамадышский район, село Пойкино	0101000020E610000040F67AF7C7A74940EECF4543C6FD4B40
530	7	64	1755	26521	10831	\N	55.624245999999999	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Отарка, ул.Октябрьская, д.17	Россия, республика Татарстан, Мамадышский район, село Отарка	0101000020E61000005EBEF561BDB749405454FD4AE7CF4B40
529	7	64	1755	26490	10827	\N	55.543674000000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Омары, ул.Школьная, д.18	Россия, республика Татарстан, Мамадышский район, село Омары	0101000020E6100000083D9B559F974940BFD7101C97C54B40
528	7	64	1755	26423	10824	\N	55.910421999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Олуяз, ул.Ш.Маннура, д.2	Россия, республика Татарстан, Мамадышский район, село Олуяз	0101000020E6100000064CE0D6DD9249408AC745B588F44B40
487	7	64	1755	61311	78530	\N	55.510102564238899	Республика Татарстан (Татарстан), Мамадышский муниципальный район, п.Новый, ул.Березовая, д.16А	Россия, республика Татарстан, Мамадышский район, село Новый	0101000020E6100000596B28B5176D4940B64B1B0E4BC14B40
525	7	64	1755	26309	10818	\N	55.845734	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Никифорово, ул.К.Маркса, д.2	Россия, республика Татарстан, Мамадышский район, село Никифорово	0101000020E6100000B22E6EA301724940C18EFF0241EC4B40
523	7	64	1755	26209	10815	\N	55.976841	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Нижняя Уча, ул.Первомайская, д.1	Россия, республика Татарстан, Мамадышский район, село Нижняя Уча	0101000020E61000002043C70E2A8349402B323A2009FD4B40
521	7	64	1755	26126	10808	\N	55.65305	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Нижняя Сунь, ул.К.Маркса, д.18А	Россия, республика Татарстан, Мамадышский район, село Нижняя Сунь	0101000020E61000000B7BDAE1AF7549408F53742497D34B40
520	7	64	1755	26079	11058	\N	55.728909999999999	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Нижняя Ошма, ул.Советская, д.39А	Россия, республика Татарстан, Мамадышский район, село Нижняя Ошма	0101000020E61000001BBE8575E3A549401ADD41EC4CDD4B40
506	7	64	1755	25411	10795	\N	55.903947337198503	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Нижняя Кузгунча, ул.Татарстан, д.30	Россия, республика Татарстан, Мамадышский район, село Нижняя Кузгунча	0101000020E6100000C1E270E6579749409E280989B4F34B40
522	7	64	1755	26145	10810	\N	55.936357999999998	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Нижний Таканыш, ул.Советская, д.2	Россия, республика Татарстан, Мамадышский район, село Нижний Таканыш	0101000020E6100000ADDEE176688649408AAC3594DAF74B40
524	7	64	1755	61402	79133	\N	55.633920112761203	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Нижние Яки, ул.Ленина, д.50	Россия, республика Татарстан, Мамадышский район, село Нижние Янки	0101000020E6100000E23D079623884940E223624A24D14B40
512	7	64	1755	25669	11845	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, пер.Текстильный, д.5	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
515	7	64	1755	25669	10804	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, ул.Советская, д.42	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
511	7	64	1755	25669	10798	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, ул.Ленина, д.107	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
519	7	64	1755	25669	10807	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, ул.Давыдова, д.159В	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
518	7	64	1755	25669	10807	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, ул.Давыдова, д.170	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
517	7	64	1755	25669	10807	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, ул.Давыдова, д.97А	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
516	7	64	1755	25669	10805	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, ул.Горького, д.25	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
513	7	64	1755	25669	10801	\N	55.707054999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, г.Мамадыш, ул.Азина, д.10	Россия, республика Татарстан, Мамадышский район, Мамадыш	0101000020E6100000CF49EF1B5FB3494094BC3AC780DA4B40
509	7	64	1755	25568	10800	\N	55.738661999999998	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Малые Кирмени, ул.Нигматуллина, д.31	Россия, республика Татарстан, Мамадышский район, село Малые Кирмени	0101000020E61000001F680586AC8A49402366F6798CDE4B40
508	7	64	1755	25531	10791	\N	55.813364	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Малмыжка, ул.Советская, д.28	Россия, республика Татарстан, Мамадышский район, село Малмыжка	0101000020E6100000CD5CE0F258AD494033DFC14F1CE84B40
510	7	64	1755	25633	10797	\N	55.707735	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Малая Сунь, ул.Советская, д.17А	Россия, республика Татарстан, Мамадышский район, село Малая Сунь	0101000020E6100000E02F664B56774940069E7B0F97DA4B40
526	7	64	1755	26319	10823	\N	55.851363999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Куюк-Ерыкса, ул.Гагарина, д.29	Россия, республика Татарстан, Мамадышский район, село Куюк-Ерыкса	0101000020E6100000F04C689258AC4940F17EDC7EF9EC4B40
507	7	64	1755	25467	11844	\N	55.617702999999999	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Кулущи, ул.А.Гайдара, д.2А		0101000020E610000025E82FF4887149400FD253E410CF4B40
505	7	64	1755	25395	10785	\N	55.696604751575698	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Красная Горка, ул.Ямашева, д.1	Россия, республика Татарстан, Мамадышский район, село Красная Горка	0101000020E6100000ADDF4C4C17B04940739D465A2AD94B40
504	7	64	1755	25352	10784	\N	55.959071999999999	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Кемеш-Куль, ул.Центральная, д.19	Россия, республика Татарстан, Мамадышский район, село Кемеш-Куль	0101000020E6100000EC18575C1C91494031410DDFC2FA4B40
503	7	64	1755	25292	10783	\N	55.637911000000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Катмыш, ул.Ленина, д.85	Россия, республика Татарстан, Мамадышский район, село Катмыш	0101000020E6100000A51309A69A6B49401C615111A7D14B40
489	7	64	1755	24672	10769	\N	55.829289000000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Ишкеево, ул.Школьная, д.18	Россия, республика Татарстан, Мамадышский район, село Ишкеево	0101000020E6100000B7B3AF3C487B49405EF7562426EA4B40
501	7	64	1755	25195	10782	\N	55.947147000000001	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Зюри, ул.Советская, д.1	Россия, республика Татарстан, Мамадышский район, село Зюри	0101000020E6100000342E1C08C9AC494094C0E61C3CF94B40
499	7	64	1755	61296	78409	\N	55.5428434062623	Республика Татарстан (Татарстан), Мамадышский муниципальный район, п.Зверосовхоз, ул.Ленина, д.4	Россия, республика Татарстан, Рыбно-Слободский район, село пос. Зверосовхоза	0101000020E610000069A7E672836B494067EE21E17BC54B40
498	7	64	1755	25061	11026	\N	55.864044999999997	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Дюсьметьево, ул.Молодежная, д.1	Россия, республика Татарстан, Мамадышский район, село Дюсьметьево	0101000020E6100000F69A1E1494A04940DBA2CC0699EE4B40
647	7	64	1755	32003	10966	\N	55.916603000000002	Республика Татарстан (Татарстан), Муслюмовский муниципальный район, д.Дусаево, ул.Центральная, д.6А	Россия, республика Татарстан, Мамадышский район, село Дусаево	0101000020E6100000A759A0DD218D49402F35423F53F54B40
497	7	64	1755	40831	10835	\N	55.757632000000001	Республика Татарстан (Татарстан), Мамадышский муниципальный район, п.Дружба, ул.Центральная, д.20	Россия, республика Татарстан, Мамадышский район	0101000020E6100000A703594FAD8C49409833DB15FAE04B40
496	7	64	1755	24972	10774	\N	55.586089999999999	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Дигитли, ул.Центральная, д.13	Россия, республика Татарстан, Мамадышский район, село Дигитли	0101000020E6100000069E7B0F978449409E4143FF04CB4B40
495	7	64	1755	24951	10814	\N	55.885862000000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, д.Гришкино, ул.Красное Знамя, д.51	Россия, республика Татарстан, Мамадышский район, село Гришкино	0101000020E6100000F836FDD98FB8494074620FED63F14B40
490	7	64	1755	24720	10765	\N	55.733086999999998	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Владимирово, ул.Школьная, д.3	Россия, республика Татарстан, Мамадышский район, село Владимирово	0101000020E6100000257497C4596D4940B60F79CBD5DD4B40
493	7	64	1755	24868	10813	\N	55.744916000000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Верхняя Сунь, ул.Советская, д.20А	Россия, республика Татарстан, Мамадышский район, село Верхняя Сунь	0101000020E6100000B55373B9C17A49403222516859DF4B40
492	7	64	1755	24803	10811	\N	55.760565	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Верхняя Ошма, ул.Советская, д.52А	Россия, республика Татарстан, Мамадышский район, село Верхняя Ошма	0101000020E61000008BC058DFC09A4940BABDA4315AE14B40
491	7	64	1755	24778	10767	\N	55.723019000000001	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Верхний Берсут, ул.Советская, д.44	Россия, республика Татарстан, Мамадышский район, село Верхний Берсут	0101000020E6100000EED11BEE236749407DB1F7E28BDC4B40
494	7	64	1755	61496	79254	\N	55.689148600000003	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Верхние Яки, ул.Центральная, д.1		0101000020E61000009702D2FE078449401A89D00836D84B40
488	7	64	1755	24629	10763	\N	55.893056000000001	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Большая Шия, ул.Давыдова, д.43А	Россия, республика Татарстан, Мамадышский район, село Большая Шия	0101000020E610000096CFF23CB8A9494090BFB4A84FF24B40
486	7	64	1755	24529	10762	\N	55.768127	Республика Татарстан (Татарстан), Мамадышский муниципальный район, с.Албай, ул.Центральная, д.42	Россия, республика Татарстан, Мамадышский район, село Албай	0101000020E61000002D0B26FE285E494059164CFC51E24B40
463	7	64	970	23397	10718	\N	54.557715000000002	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Мичуринское сельское поселение, п.им.Мичурина, ул.Советская, д.28	Россия, республика Татарстан, Лениногорский район, село имени Мичурина	0101000020E61000002A1BD65416EB49408CBE823463474B40
477	7	64	970	24068	10742	\N	54.492922999999998	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Сугушлинское сельское поселение, д.Юлтимирово, ул.Советская, д.75	Россия, республика Татарстан, Лениногорский район, село Юлтимирово	0101000020E6100000546F0D6C95204A401D39D219183F4B40
485	7	64	970	24466	10760	\N	54.510771117401099	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Шугуровское сельское поселение, с.Шугурово, ул.Ленина, д.35	Россия, республика Татарстан, Лениногорский район, поселок Шугурово	0101000020E610000046990D32C9104A40635FB2F160414B40
483	7	64	970	24364	10754	\N	54.675266999999998	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Федотовское сельское поселение, с.Федотовка, ул.Советская, д.8	Россия, республика Татарстан, Лениногорский район, село Федотовка	0101000020E6100000478E740646FE4940B58828266F564B40
451	7	64	970	61517	79281	\N	54.588532999999998	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Глазовское сельское поселение, д.Урняк-Кумяк, ул.Школьная, д.3А	Россия, республика Татарстан, Лениногорский район	0101000020E6100000E605D847A71C4A40F2CEA10C554B4B40
482	7	64	970	24272	10780	\N	54.755768000000003	423294, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лениногорский муниципальный район, с.Урмышла, ул.Центральная (здание Совета сельского поселения), д.2	Россия, республика Татарстан, Лениногорский район, село Урмышла	0101000020E61000000B0A83328DF4494082AE7D01BD604B40
480	7	64	970	24206	10750	\N	54.415408999999997	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Туктарово-Урдалинское сельское поселение, с.Туктарово-Урдала, ул.Советская, д.103	Россия, республика Татарстан, Лениногорский район, село Туктарово-Урдала	0101000020E61000001C430070EC0F4A4066BB421F2C354B40
478	7	64	970	24111	10746	\N	54.56861	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Тимяшевское сельское поселение, с.Тимяшево, ул.Кирова, д.26	Россия, республика Татарстан, Лениногорский район, село Тимяшево	0101000020E6100000AC915D69192F4A40DB166536C8484B40
476	7	64	970	24028	10740	\N	54.526032000000001	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Сугушлинское сельское поселение, с.Сугушла, ул.Центральная, д.27	Россия, республика Татарстан, Лениногорский район, село Сугушла	0101000020E610000037C5E3A25A244A4022533E0455434B40
474	7	64	970	23907	10738	\N	54.620792999999999	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Старокувакское сельское поселение, с.Старый Кувак, ул.Заварыкина, д.36	Россия, республика Татарстан, Лениногорский район, село Старый Кувак	0101000020E610000017299485AFF94940F94A2025764F4B40
472	7	64	970	23819	10737	\N	54.5456793662281	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Староиштерякское сельское поселение, с.Старый Иштеряк, ул.Школьная, д.15	Россия, республика Татарстан, Лениногорский район, село Старый Иштеряк	0101000020E6100000A7B393C151024A40978E39CFD8454B40
475	7	64	970	23977	10989	\N	54.522866	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Старошугуровское сельское поселение, с.Старое Шугурово, ул.С.Садриева, д.7	Россия, республика Татарстан, Лениногорский район, село Старое Шугурово	0101000020E6100000DEB06D51660D4A405D18E945ED424B40
470	7	64	970	23741	10987	\N	54.553882000000002	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Письмянское сельское поселение, с.Старая Письмянка, ул.Центральная, д.50	Россия, республика Татарстан, Лениногорский район, село Старая Письмянка	0101000020E61000007A1C06F357504A40EAEBF99AE5464B40
454	7	64	970	22981	10707	\N	54.461153000000003	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Зеленорощинское сельское поселение, с. Спиридоновка, ул.Советская, д.32	Россия, республика Татарстан, Лениногорский район, село Спиридоновка	0101000020E6100000E1F08288D4084A40E5B9BE0F073B4B40
471	7	64	970	23781	10732	\N	54.661078000000003	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Сарабикуловское сельское поселение, с.Сарабикулово, ул.Кирова, д.4А	Россия, республика Татарстан, Лениногорский район, село Сарабикулово	0101000020E6100000F0DC7BB8E4F24940740D33349E544B40
469	7	64	970	40868	10986	\N	54.590145	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Письмянское сельское поселение, п.Подлесный, ул.Гагарина, д.5		0101000020E6100000035FD1ADD7404A40EF7211DF894B4B40
467	7	64	970	23608	10729	\N	54.498612000000001	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Новоиштерякское сельское поселение, с.Новый Иштеряк, ул.Центральная, д.7	Россия, республика Татарстан, Лениногорский район, село Новый Иштеряк	0101000020E6100000CFF4126399024A4053B29C84D23F4B40
468	7	64	970	23637	10727	\N	54.641764000000002	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Новочершилинское сельское поселение, п.Новочершилинский, ул.Центральная, д.12А	Россия, республика Татарстан, Лениногорский район, село Новочершилинский	0101000020E610000014CE6E2D93314A4005E09F5225524B40
464	7	64	970	23444	10720	\N	54.565989000000002	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Мичуринское сельское поселение, с.Новое Сережкино, ул.Центральная, д.9	Россия, республика Татарстан, Лениногорский район, село Новое Сережкино	0101000020E6100000212235ED62DC4940A872DA5372484B40
93727	7	64	970	8104	78181	\N	54.786129000000003	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Елховское сельское поселение, с.Елхово, ул.Советская, д.61		0101000020E6100000B4942C27A1F04940F6B704E09F644B40
94051	7	64	970	23834	78339	\N	54.468975999999998	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.Вязовка, ул.Центральная, д.32		0101000020E610000080B9162D40314A40F04DD367073C4B40
466	7	64	970	23545	10724	\N	54.663530999999999	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Нижнечершилинское сельское поселение, с.Нижние Чершилы, ул.Центральная, д.56	Россия, республика Татарстан, Лениногорский район, село Нижние Чершилы	0101000020E6100000C2887D02280E4A40EB707495EE544B40
465	7	64	970	23492	10725	\N	54.584181999999998	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Мукмин-Каратайское сельское поселение, с.Мукмин-Каратай, ул.Механизаторов, д.31Б	Россия, республика Татарстан, Лениногорский район, село Мукмин-Каратай	0101000020E6100000C1E61C3C13064A40B874CC79C64A4B40
460	7	64	970	23265	10710	\N	54.620145999999998	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Кармалкинское сельское поселение, с.Мордовская Кармалка, ул.Нагорная, д.33	Россия, республика Татарстан, Лениногорский район, село Мордовская Кармалка	0101000020E6100000F4C5DE8B2FEA4940635FB2F1604F4B40
456	7	64	970	23088	10708	\N	54.436354999999999	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Ивановское сельское поселение, с.Михайловка, ул.Центральная, д.12	Россия, республика Татарстан, Лениногорский район, село Михайловка	0101000020E61000000261A75835484A4019390B7BDA374B40
429	7	64	970	40765	10674	\N	54.592933391454899	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Губкина, 59	Россия, республика Татарстан, Лениногорск городской округ	0101000020E610000052EE3EC7473B4A400EDC813AE54B4B40
484	7	64	970	24426	10755	\N	54.663713000000001	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Федотовское сельское поселение, с.Кузьминовка, ул.Кооперативная, д.10	Россия, республика Татарстан, Лениногорский район, село Кузьминовка	0101000020E61000002E54FEB5BC024A400C772E8CF4544B40
462	7	64	970	23349	12264	\N	54.656603210380297	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Куакбашское сельское поселение, с.Куакбаш, ул.К.Маркса, д.15		0101000020E6100000ACE4637781184A404DBA2D910B544B40
461	7	64	970	23307	10712	\N	54.700752000000001	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Керлигачское сельское поселение, с.Керлигач, ул.Советская, д.33А	Россия, республика Татарстан, Лениногорский район, село Керлигач	0101000020E610000046787B1002F24940A54DD53DB2594B40
457	7	64	970	23125	10706	\N	54.503928999999999	423272, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лениногорский муниципальный район, с.Каркали, ул.Советская (здание ДК), д.93	Россия, республика Татарстан, Лениногорский район, село Каркали	0101000020E61000002FFA0AD28C194A40C440D7BE80404B40
455	7	64	970	23033	10703	\N	54.5057133766067	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Ивановское сельское поселение, с.Ивановка, ул.Юности, д.5	Россия, республика Татарстан, Лениногорский район, село Ивановка	0101000020E61000000CB08F4E5D394A40BE141E34BB404B40
19916	7	61	482	6159	63464	\N	55.885584999999999	город Агидель, Первых строителей, 8, А		0101000020E6100000889CBE9EAFF74A40016A6AD95AF14B40
453	7	64	970	61271	78039	\N	54.483336294858198	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Зеленорощинское сельское поселение, с.Зеленая Роща, ул.Строительная, д.1	Россия, республика Татарстан, Лениногорский район, поселок Зеленая Роща	0101000020E6100000EC8497E0D4054A405F7D3CF4DD3D4B40
452	7	64	970	22903	10700	\N	54.7044005272747	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Зай-Каратайское сельское поселение, с.Зай-Каратай, ул.Советская, д.56	Россия, республика Татарстан, Лениногорский район, село Зай-Каратай	0101000020E61000008925E5EE73304A408522DDCF295A4B40
93755	7	64	970	9395	78960	\N	54.753129000000001	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Старомихайловское сельское поселение, с.Булгар, ул.Ирня, д.11А		0101000020E6100000603B18B14FEE4940A855F48766604B40
473	7	64	970	23873	10735	\N	54.540367000000003	Республика Татарстан (Татарстан), Лениногорский муниципальный район, Староиштерякское сельское поселение, с.Бакирово, ул.Нагорная, д.37	Россия, республика Татарстан, Лениногорский район, село Бакирово	0101000020E61000009CA4F9635A054A40386BF0BE2A454B40
431	7	64	6920	40766	10682	\N	54.5918368694918	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Школьная, 8	Россия, республика Татарстан, Лениногорск	0101000020E6100000E84B6F7F2E3A4A4008C89750C14B4B40
430	7	64	6920	40766	10681	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Широкая, 15		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
444	7	64	6920	40766	11787	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Шашина, 55		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
447	7	64	6920	40766	11050	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Степная, 2а	Россия, республика Татарстан, Лениногорск	0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
445	7	64	6920	40766	11009	\N	54.590939693101497	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Садриева, 24	Россия, республика Татарстан, Лениногорск	0101000020E61000005FB2F1608B394A40FAF202ECA34B4B40
436	7	64	6920	40766	10684	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Морякова, 4		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
435	7	64	6920	40766	10684	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Морякова, 10		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
440	7	64	6920	40766	10688	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Ленинградская, 40		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
439	7	64	6920	40766	10688	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Ленинградская, 28а		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
442	7	64	6920	40766	10953	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Кутузова, 14		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
441	7	64	6920	40766	10953	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Кутузова, 2		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
443	7	64	6920	40766	11786	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Крупской, 6		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
448	7	64	6920	40766	10697	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Кошевого, 32		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
446	7	64	6920	40766	10697	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Кошевого, 28	Россия, республика Татарстан, Лениногорск	0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
438	7	64	6920	40766	10686	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Гагарина, 51		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
437	7	64	6920	40766	10686	\N	54.592135923877201	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Гагарина, 29	Россия, республика Татарстан, Лениногорск	0101000020E6100000703FE081013A4A406364C91CCB4B4B40
433	7	64	6920	40766	10686	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Гагарина, 12		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
428	7	64	6920	40766	11781	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Асфальтная, 1		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
432	7	64	6920	40766	11782	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, Агадуллмна, 1		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
434	7	64	6920	40766	11000	\N	54.592039	Республика Татарстан (Татарстан), Лениногорский муниципальный район, город Лениногорск, 50 лет Победы, 26		0101000020E6100000AC8E1CE90C3A4A40707A17EFC74B4B40
393	7	64	971	48581	75151	\N	55.489412000000002	Республика Татарстан (Татарстан), Лаишевский муниципальный район, п.совхоза им.25 Октября, ул.Центральная, д.6		0101000020E6100000096EA46C91CC48408E226B0DA5BE4B40
399	7	64	971	20355	10600	\N	55.371014000000002	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Шуран, ул.Кооперативная, д.32	Россия, республика Татарстан, Лаишевский район, село Шуран	0101000020E61000002A8F6E8445E94840D82D02637DAF4B40
396	7	64	971	20155	10593	\N	55.444889895611503	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Чирпы, ул.Заводская, д.22	Россия, республика Татарстан, Лаишевский район, село Чирпы	0101000020E61000001366DAFE95DB4840A228D027F2B84B40
427	7	64	971	21760	10666	\N	55.434052999999999	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Тетеево, ул.Центральная, д.12а	Россия, республика Татарстан, Лаишевский район, село Тетеево	0101000020E6100000CEA78E554A9B484087DD770C8FB74B40
383	7	64	971	19443	10568	\N	55.320574999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Ташкирмень, ул.Верхняя, д.34	Россия, республика Татарстан, Лаишевский район, село Ташкирмень	0101000020E61000001F85EB51B8B048402575029A08A94B40
401	7	64	971	20475	10606	\N	55.553116000000003	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Татарский Янтык, ул.Магазинная, д.31а	Россия, республика Татарстан, Лаишевский район, село Татарский Янтык	0101000020E610000090DD054A0AE248407A724D81CCC64B40
426	7	64	971	21705	10663	\N	55.489987999999997	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Татарский Кабан, ул.Солнечная, д.16а	Россия, республика Татарстан, Лаишевский район, село Татарский Кабан	0101000020E61000009A999999999F48405AB741EDB7BE4B40
382	7	64	971	19408	10566	\N	55.342492999999997	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Татарские Саралы, ул.Татарстан, д.17	Россия, республика Татарстан, Лаишевский район, село Татарские Саралы	0101000020E6100000F549EEB089A24840F10D85CFD6AB4B40
380	7	64	971	19309	10563	\N	55.409543999999997	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Тангачи, ул.Октябрьская, д.3	Россия, республика Татарстан, Лаишевский район, село Тангачи	0101000020E6100000B9A6406667A74840F22213F06BB44B40
1470	7	64	971	40754	11720	\N	55.6398582799333	422624, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Столбище, ул.Заозерная (помещение СДК), д.21		0101000020E6100000F0A65B76889B4840BF0AF0DDE6D14B40
415	7	64	971	8302	10641	\N	55.640586466497503	422624, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Столбище, ул.Школьная (помещение средней школы), д.10		0101000020E6100000EB6E9EEA909B48404223D8B8FED14B40
413	7	64	971	8302	10642	\N	55.640101000000001	"422624, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Столбище, ул.Совхозная (административное здание ООО ""Мир овощей""), д.7а"		0101000020E61000001553E9279C9B484086915ED4EED14B40
416	7	64	971	8302	10645	\N	55.640101000000001	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Столбище, ул.Северная, д.14	Россия, республика Татарстан, Лаишевский район, село Столбище	0101000020E61000001553E9279C9B484086915ED4EED14B40
400	7	64	971	20389	10602	\N	55.499693929397502	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Среднее Девятово, ул.Сергеева, д.6	Россия, республика Татарстан, Лаишевский район, село Среднее Девятово	0101000020E6100000FB5C6DC5FED44840F30016F9F5BF4B40
407	7	64	971	20804	10636	\N	55.618639000000002	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Сокуры, ул.Школьная, д.1	Россия, республика Татарстан, Лаишевский район, село Сокуры	0101000020E610000039B4C876BEB34840DC8310902FCF4B40
381	7	64	971	19337	10571	\N	55.389192000000001	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Сингели, ул.Школьная, д.52	Россия, республика Татарстан, Лаишевский район, село Сингели	0101000020E6100000BE141E34BBA64840B3EE1F0BD1B14B40
422	7	64	971	21526	10657	\N	55.561292999999999	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Пиголи, ул.Закарьевская, д.2а	Россия, республика Татарстан, Лаишевский район, село Пиголи	0101000020E610000086E28E37F9954840A33CF372D8C74B40
419	7	64	971	21369	10649	\N	55.626624	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Песчаные Ковали, ул.Октябрьская, д.9а	Россия, республика Татарстан, Лаишевский район, село Песчаные Ковали	0101000020E6100000BB46CB811E924840C171193735D04B40
403	7	64	971	20592	10607	\N	55.568629000000001	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Пелево, ул.Советская, д.1а	Россия, республика Татарстан, Лаишевский район, село Пелево	0101000020E610000090D78349F1CB48405247C7D5C8C84B40
421	7	64	971	40758	10655	\N	55.564923	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Орел, ул.Олимпийская, д.1а	Россия, республика Татарстан, Лаишевский район, село Орел	0101000020E61000009F573CF5488948400DE198654FC84B40
423	7	64	971	21568	10659	\N	55.534005999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Никольское, ул.Центральная, д.43		0101000020E6100000917F66101F98484013EF004F5AC44B40
425	7	64	971	8423	10665	\N	55.489815	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Нармонка, ул.Центральная, д.28	Россия, республика Татарстан, Лаишевский район, село Нармонка	0101000020E61000003D601E32E5A548408D0B0742B2BE4B40
1473	7	64	971	40761	11722	\N	55.489815	422630, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Нармонка, ул.Молодежная (здание Исполнительного комитета), д.12а		0101000020E61000003D601E32E5A548408D0B0742B2BE4B40
411	7	64	971	21003	10637	\N	55.617190281001797	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Малые Кабаны, ул.Южная, д.1	Россия, республика Татарстан, Лаишевский район, село Малые Кабаны	0101000020E610000089B7CEBF5DA4484089B5F81400CF4B40
397	7	64	971	20223	10624	\N	55.415210999999999	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Малая Елга, ул.Советская, д.56	Россия, республика Татарстан, Лаишевский район, село Малая Елга	0101000020E61000004E2A1A6B7FEB484040F850A225B54B40
1468	7	64	971	8112	11721	\N	55.402504999999998	422610, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Чернышевского (помещение районной библиотеки), д.26	Россия, республика Татарстан, Лаишевский район, поселок Лаишево	0101000020E610000070E998F38CC54840FDBCA94885B34B40
1467	7	64	971	8112	11852	\N	55.402504999999998	422610, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Производственная (помещение Спорткомплекса), д.1а	Россия, республика Татарстан, Лаишевский район, поселок Лаишево	0101000020E610000070E998F38CC54840FDBCA94885B34B40
390	7	64	971	8112	10616	\N	55.402504999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Маяковского, д.5	Россия, республика Татарстан, Лаишевский район, поселок Лаишево	0101000020E610000070E998F38CC54840FDBCA94885B34B40
388	7	64	971	8112	10613	\N	55.402504999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Ленина, д.16	Россия, республика Татарстан, Лаишевский район, поселок Лаишево	0101000020E610000070E998F38CC54840FDBCA94885B34B40
389	7	64	971	8112	10614	\N	55.402504999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Лебедевой, д.32	Россия, республика Татарстан, Лаишевский район, поселок Лаишево	0101000020E610000070E998F38CC54840FDBCA94885B34B40
391	7	64	971	8112	10584	\N	55.402504999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Александра Матросова, д.24	Россия, республика Татарстан, Лаишевский район, поселок Лаишево	0101000020E610000070E998F38CC54840FDBCA94885B34B40
387	7	64	971	40732	10587	\N	55.402504999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, пер.Школьный, д.3а		0101000020E610000070E998F38CC54840FDBCA94885B34B40
1469	7	64	971	40732	10585	\N	55.402504999999998	422610, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Горького (помещение УЭООС), д.80		0101000020E610000070E998F38CC54840FDBCA94885B34B40
392	7	64	971	40732	10585	\N	55.402700567743203	Республика Татарстан (Татарстан), Лаишевский муниципальный район, г.Лаишево, ул.Горького, д.2		0101000020E6100000115663096BC548408388D4B48BB34B40
424	7	64	971	61491	79246	\N	55.514308791183502	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Кунтечи, ул.Центральная, д.15а	Россия, республика Татарстан, Лаишевский район, село Кутенчи	0101000020E61000004031B2648E9B4840EC8497E0D4C14B40
386	7	64	971	19613	10572	\N	55.441963999999999	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Курманаково, ул.Центральная, д.26а	Россия, республика Татарстан, Лаишевский район, село Курманаково	0101000020E6100000C5C6BC8E38B048403201BF4692B84B40
408	7	64	971	20826	10623	\N	55.563594999999999	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Кирби, ул.Юности, д.10а	Россия, республика Татарстан, Лаишевский район, село Кирби	0101000020E610000037A79201A0A84840359886E123C84B40
409	7	64	971	20914	10638	\N	55.512830999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Карадули, ул.Овражная, д.128	Россия, республика Татарстан, Лаишевский район, село Карадули	0101000020E61000004E2844C021A84840FFAF3A72A4C14B40
404	7	64	971	20611	10609	\N	55.577460000000002	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Каипы, ул.Центральная, д.50	Россия, республика Татарстан, Лаишевский район, село Каипы	0101000020E61000008C65FA25E2BD4840C45F9335EAC94B40
395	7	64	971	20096	10589	\N	55.425389000000003	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Именьково, ул.Школьная, д.2а	Россия, республика Татарстан, Лаишевский район, село Именьково	0101000020E6100000FBAE08FEB7DC4840018A912573B64B40
379	7	64	971	19230	10561	\N	55.442163000000001	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Дятлово, ул.Юности, д.2	Россия, республика Татарстан, Лаишевский район, село Дятлово	0101000020E6100000A1A17F828BA94840294014CC98B84B40
402	7	64	971	20498	10603	\N	55.552999	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Державино, ул.Заббарова, д.39а	Россия, республика Татарстан, Лаишевский район, село Державино	0101000020E610000069E04735ECC7484040DCD5ABC8C64B40
1339	7	64	289	1351	11554	\N	55.867677	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Тактамыш, ул.Кирова, д.23		0101000020E6100000020CCB9F6F5B4940E63E390A10EF4B40
418	7	64	971	19494	10575	\N	55.611780000000003	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Габишево, ул.Советская, д.5	Россия, республика Татарстан, Лаишевский район, село Габишево	0101000020E6100000EB3713D385924840672C9ACE4ECE4B40
384	7	64	971	19494	10575	\N	55.611780000000003	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Габишево, ул.Советская, д.3	Россия, республика Татарстан, Лаишевский район, село Габишево	0101000020E6100000EB3713D385924840672C9ACE4ECE4B40
420	7	64	971	21431	10652	\N	55.612878000000002	Республика Татарстан (Татарстан), Лаишевский муниципальный район, д.Матюшино, ул.Березовая, д.25	Россия, республика Татарстан, Лаишевский район, село Боровое Матюшино	0101000020E610000001F8A754898248400D384BC972CE4B40
410	7	64	971	20945	10630	\N	55.646137000000003	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Большие Кабаны, ул.Победы, д.6	Россия, республика Татарстан, Лаишевский район, село Большие Кабаны	0101000020E61000009CFBABC77DA7484027DE019EB4D24B40
405	7	64	971	20701	10611	\N	55.617708	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Бима, ул.Центральная, д.56	Россия, республика Татарстан, Лаишевский район, село Бима	0101000020E6100000EB025E66D8C04840213D450E11CF4B40
406	7	64	971	20713	10619	\N	55.549174999999998	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Березовка, ул.Центральная, д.28	Россия, республика Татарстан, Лаишевский район, село Березовка	0101000020E61000000FB56D1805B74840F163CC5D4BC64B40
412	7	64	971	21056	10635	\N	55.283636000000001	Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Атабаево, ул.Молодежная, д.1	Россия, республика Татарстан, Лаишевский район, село Атабаево	0101000020E61000004834812216AD4840F0FB372F4EA44B40
394	7	64	971	61527	79311	\N	55.465308050988597	Республика Татарстан (Татарстан), Лаишевский муниципальный район, п.Александровский, ул.Молодежная, д.6		0101000020E6100000944C4EED0CC74840994869368FBB4B40
1472	7	64	6931	40968	11855	\N	55.679397000000002	422624, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Лаишевский муниципальный район, с.Усады, ул.Медицинская (помещение Усадского ФАП), д.11	Россия, республика Татарстан, село Усады	0101000020E610000097715303CD9B484011001C7BF6D64B40
296	7	64	289	15055	10408	\N	55.991617163765	Республика Татарстан (Татарстан), Кукморский район, с.Ятмас Дусай, ул.Центральная, д.73А	Россия, республика Татарстан, Кукморский район, село Ятмас-Дусай	0101000020E610000008E8BE9CD96649402D944C4EEDFE4B40
294	7	64	289	14957	10414	\N	56.255437000000001	422122, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Яныль, ул.Центральная (здание средней школы), д.1А		0101000020E6100000A56ABB09BE4949401C98DC28B2204C40
308	7	64	289	15638	10433	\N	56.226699000000004	Республика Татарстан (Татарстан), Кукморский район, с.Янцобино, ул.Пионерская, д.15	Россия, республика Татарстан, Кукморский район, село Янцобино	0101000020E61000003735D07CCE65494099840B79041D4C40
377	7	64	289	19147	10559	\N	56.230851999999999	Республика Татарстан (Татарстан), Кукморский район, с.Ядыгерь, ул.Ленина, д.21А	Россия, республика Татарстан, Кукморский район, село Ядыгерь	0101000020E6100000A59F70766B414940AC1BEF8E8C1D4C40
314	7	64	289	15910	10449	\N	56.299307007519701	422113, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Чишма-Баш, ул.Победы (здание начальная школа), д.50	Россия, республика Татарстан, Кукморский район, село Чишма-Баш	0101000020E6100000BC74931804524940603B18B14F264C40
372	7	64	289	18864	10545	\N	56.282766033620902	Республика Татарстан (Татарстан), Кукморский район, д.Челны, ул.Школьная, д.1	Россия, республика Татарстан, Кукморский район, село Челны	0101000020E61000008E78B29B19734940DB3521AD31244C40
375	7	64	289	41033	12261	\N	56.123671760085202	422119, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Чарли, ул.Молодежная (здание средняя школа), д.4	Россия, республика Татарстан, Кукморский район	0101000020E610000091B41B7DCC7D494028B7ED7BD40F4C40
351	7	64	289	17815	10508	\N	56.043833999999997	Республика Татарстан (Татарстан), Кукморский район, с.Урясьбаш, ул.Пионерская, д.21	Россия, республика Татарстан, Кукморский район, село Урясьбаш	0101000020E61000009BA9108FC4794940F7393E5A9C054C40
353	7	64	289	17913	10513	\N	55.952396136586302	Республика Татарстан (Татарстан), Кукморский район, с.Туркаш, ул.Центральная, д.44	Россия, республика Татарстан, Кукморский район, село Туркаш	0101000020E61000003F1F65C405724940AD6BB41CE8F94B40
371	7	64	289	18828	10543	\N	56.267842000000002	Республика Татарстан (Татарстан), Кукморский район, с.Туембаш, ул.Заречная, 3	Россия, республика Татарстан, Кукморский район, село Туембаш	0101000020E61000000E661360586E4940643F8BA548224C40
365	7	64	289	18512	10553	\N	56.357300000000002	Республика Татарстан (Татарстан), Кукморский район, д.Трыш, ул.Набережная, д.3	Россия, республика Татарстан, Кукморский район, село Трыш	0101000020E61000007FF5B86FB54249402F6EA301BC2D4C40
376	7	64	289	19070	10555	\N	56.071348999999998	Республика Татарстан (Татарстан), Кукморский район, д.Татарская Тулба, ул.Зеленая, д.41	Россия, республика Татарстан, Кукморский район, село Татарская Тулба	0101000020E6100000FA7C941117A4494018CDCAF621094C40
325	7	64	289	16506	10460	\N	56.061056999999998	Республика Татарстан (Татарстан), Кукморский район, д.Старый Каенсар, ул.Зеленая, д.25	Россия, республика Татарстан, Кукморский район, село Старый Каенсар	0101000020E610000004013274EC7E49408F183DB7D0074C40
358	7	64	289	18141	10522	\N	56.150855	422102, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Старая Юмья, ул.Школьная (здание начальная школа), д.20	Россия, республика Татарстан, Кукморский район, село Старая Юмья	0101000020E610000087A757CA325C494013B875374F134C40
369	7	64	289	18646	10539	\N	56.152298999999999	422101, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Средний Кумор, ул.Майская (здание средняя школа), д.12		0101000020E6100000A053909F8D644940541B9C887E134C40
367	7	64	289	18618	10628	\N	56.265427000000003	Республика Татарстан (Татарстан), Кукморский район, с.Село-Чура, ул.Школьная, д.34	Россия, республика Татарстан, Кукморский район, село Село-Чура	0101000020E6100000EFAD484C503D4940DA3C0E83F9214C40
363	7	64	289	18398	10617	\N	56.320627000000002	Республика Татарстан (Татарстан), Кукморский район, с.Сардек-Баш, ул.Центральная, д.45	Россия, республика Татарстан, Кукморский район, село Сардек-Баш	0101000020E6100000923D42CD904A4940789B374E0A294C40
322	7	64	289	16314	10455	\N	56.207794	Республика Татарстан (Татарстан), Кукморский район, Саз-Тамак, ул.Ленина, 36А	Россия, республика Татарстан, Кукморский район, село Саз-Тамак	0101000020E61000007958A835CD6149400B2769FE981A4C40
378	7	64	289	19195	12259	\N	56.218536	Республика Татарстан (Татарстан), Кукморский район, д.Починок Шемордан, ул.М.Джалиля, д.6А		0101000020E6100000FE43FAEDEB3C4940D47FD6FCF81B4C40
347	7	64	289	17612	10500	\N	56.078453000000003	Республика Татарстан (Татарстан), Кукморский район, с.Починок Кучук, ул.Школьная, д.47	Россия, республика Татарстан, Кукморский район, село Починок-Кучук	0101000020E6100000FE28EACC3D704940F5A276BF0A0A4C40
323	7	64	289	16402	10458	\N	56.0687	Республика Татарстан (Татарстан), Кукморский район, д.Починок Сутер, ул.Ленина, 1	Россия, республика Татарстан, Кукморский район, село Починок Сутер	0101000020E6100000910BCEE0EF8349401B9E5E29CB084C40
366	7	64	289	18537	10532	\N	56.296159000000003	Республика Татарстан (Татарстан), Кукморский район, д.Поршур, ул.Новая, д.5	Россия, республика Татарстан, Кукморский район, село Поршур	0101000020E6100000CE716E13EE3D494042B5C189E8254C40
334	7	64	289	16932	10476	\N	56.127974000000002	Республика Татарстан (Татарстан), Кукморский район, с.Ошторма Юмья, ул.Школьная, 42А	Россия, республика Татарстан, Кукморский район, село Ошторма-Юмья	0101000020E610000005F86EF3C65D4940815EB87361104C40
355	7	64	289	18014	10515	\N	56.264372000000002	Республика Татарстан (Татарстан), Кукморский район, с.Олуяз, ул.Новая, д.11	Россия, республика Татарстан, Кукморский район, село Олуяз	0101000020E6100000268C6665FB54494033FD12F1D6214C40
354	7	64	289	17929	10512	\N	56.199960498988801	Республика Татарстан (Татарстан), Кукморский район, с.Нырья, ул.Комсомольская, д.69	Россия, республика Татарстан, Кукморский район, село Нырья	0101000020E61000001AFD6838654A49400B410E4A98194C40
352	7	64	289	61384	79106	\N	55.938236455732202	Республика Татарстан, Кукморский район, п.Ныртинского совхоза, ул.Садовая, 25	Россия, республика Татарстан, Кукморский район, село Ныртинский	0101000020E6100000C879FF1F276A494006F7031E18F84B40
364	7	64	289	18426	10551	\N	56.377512000000003	Республика Татарстан (Татарстан), Кукморский район, с.Новый Сардек, ул.Новая, д.2А	Россия, республика Татарстан, Кукморский район, село Новый Сардек	0101000020E6100000C98E8D40BC4C49407DEC2E5052304C40
349	7	64	289	17723	10504	\N	56.011191388492897	422132, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Нижняя Русь, ул.Г.Ахметова (здание средняя школа), д.1А		0101000020E6100000E4A08499B67D49403881E9B46E014C40
370	7	64	289	18755	10541	\N	56.142124000000003	Республика Татарстан (Татарстан), Кукморский район, д.Нижний Кумор, ул.Нагорная, д.6В	Россия, республика Татарстан, Кукморский район, село Нижний Кумор	0101000020E61000002F6EA301BC69494005FD851E31124C40
357	7	64	289	18104	12258	\N	56.270916	Республика Татарстан (Татарстан), Кукморский район, д.Нижний Казаклар, ул.М.Джалиля, д.20		0101000020E6100000153B1A87FA51494048FB1F60AD224C40
344	7	64	289	17419	10494	\N	56.012214	Республика Татарстан (Татарстан), Кукморский район, с.Нижний Искубаш, ул.Советская, д.66А	Россия, республика Татарстан, Кукморский район, село Нижний Искубаш	0101000020E610000061C3D32B658F4940D446753A90014C40
332	7	64	289	16836	10480	\N	56.340145999999997	422115, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Маскара, ул.Центральная (здание спец. коррек. школа-интернат), д.39		0101000020E61000006D91B41B7D6A4940BFEE74E7892B4C40
340	7	64	289	15535	10426	\N	56.176774999999999	Республика Татарстан (Татарстан), Кукморский район, с.Манзарас, ул.Молодежная, д.18А	Россия, республика Татарстан, Кукморский район, село Манзарас	0101000020E6100000E998F38C7D7549400DE02D90A0164C40
305	7	64	289	15535	10426	\N	56.176774999999999	Республика Татарстан (Татарстан), Кукморский район, с.Манзарас, ул.Молодежная, д.34	Россия, республика Татарстан, Кукморский район, село Манзарас	0101000020E6100000E998F38C7D7549400DE02D90A0164C40
339	7	64	289	17198	10586	\N	56.368315000000003	Республика Татарстан (Татарстан), Кукморский район, с.Мамашир, ул.Школьная, д.14	Россия, республика Татарстан, Кукморский район, село Мамашир	0101000020E6100000191F662FDB6C494029D027F2242F4C40
341	7	64	289	17301	10486	\N	56.143599000000002	Республика Татарстан (Татарстан), Кукморский район, с.Люга, ул.Центральная, 19	Россия, республика Татарстан, Кукморский район, село Люга	0101000020E610000074081C0934764940815EB87361124C40
338	7	64	289	17103	10482	\N	56.039076999999999	Республика Татарстан (Татарстан), Кукморский район, с.Лубяны, ул.Школьная, д.18	Россия, республика Татарстан, Кукморский район, поселок Лубяны	0101000020E6100000B9162D40DBB249404D83A27900054C40
337	7	64	289	17103	10479	\N	56.039076999999999	Республика Татарстан (Татарстан), Кукморский район, с.Лубяны, ул.Техникумская, д.10	Россия, республика Татарстан, Кукморский район, поселок Лубяны	0101000020E6100000B9162D40DBB249404D83A27900054C40
335	7	64	289	17004	10477	\N	56.316614000000001	422126, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Лельвиж, ул.Школьная (здание средняя школа), д.5		0101000020E610000077D7D9907F42494056BABBCE86284C40
304	7	64	289	14579	10423	\N	56.184806000000002	"422110, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, пгт.Кукмор, ул.Нур Баяна (МБДОУ ""Дет. сад №2 ""Чулпан""""), д.44"		0101000020E61000006EDFA3FE7A734940630D17B9A7174C40
286	7	64	289	14579	12257	\N	56.184806000000002	Республика Татарстан (Татарстан), Кукморский район, пгт.Кукмор, ул.М.Джалиля, д.35		0101000020E61000006EDFA3FE7A734940630D17B9A7174C40
301	7	64	289	14579	10421	\N	56.184806000000002	Республика Татарстан (Татарстан), Кукморский район, пгт.Кукмор, ул.Мичурина, д.25	Россия, республика Татарстан, Кукморский район, поселок Кукмор	0101000020E61000006EDFA3FE7A734940630D17B9A7174C40
298	7	64	289	14579	10415	\N	56.184806000000002	Республика Татарстан (Татарстан), Кукморский район, пгт.Кукмор, ул.Майская, д.4	Россия, республика Татарстан, Кукморский район, поселок Кукмор	0101000020E61000006EDFA3FE7A734940630D17B9A7174C40
300	7	64	289	14579	10419	\N	56.184999536157498	Республика Татарстан (Татарстан), Кукморский район, пгт.Кукмор, ул.Ленина, д.38	Россия, республика Татарстан, Кукморский район, поселок Кукмор	0101000020E6100000BFD7101C9773494048E17A14AE174C40
303	7	64	289	14579	10816	\N	56.184997479432099	"422110, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, пгт.Кукмор, ул.Железнодорожная (здание МБДОУ ""Дет.сад №10 ""Ромашка""""), д.17"	Россия, республика Татарстан, Кукморский район, поселок Кукмор	0101000020E610000092239D8191734940D76D50FBAD174C40
297	7	64	289	14579	10411	\N	56.184806000000002	Республика Татарстан (Татарстан), Кукморский район, пгт.Кукмор, ул.Ворошилова, д.44	Россия, республика Татарстан, Кукморский район, поселок Кукмор	0101000020E61000006EDFA3FE7A734940630D17B9A7174C40
331	7	64	289	16817	10468	\N	56.330705000000002	Республика Татарстан (Татарстан), Кукморский район, с.Кошкино, ул.Театральная, д.40	Россия, республика Татарстан, Кукморский район, село Кошкино	0101000020E610000005DCF3FC69674940D5CF9B8A542A4C40
316	7	64	289	16016	10444	\N	56.266039782718302	422113, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Копки, ул.Пролетарская (здание дом культуры), д.1А	Россия, республика Татарстан, Кукморский район, село Копки	0101000020E61000007B87DBA1615B4940C3B645990D224C40
361	7	64	289	18303	10524	\N	56.092109000000001	Республика Татарстан (Татарстан), Кукморский район, д.Княгор, ул.Майская, д.12	Россия, республика Татарстан, Кукморский район, село Княгор	0101000020E6100000FA7ABE66B976494069554B3ACA0B4C40
360	7	64	289	18221	10550	\N	56.055014999999997	Республика Татарстан (Татарстан), Кукморский район, с.Кня-Баш, ул.Средняя, д.50А	Россия, республика Татарстан, Кукморский район, село Кня-Баш	0101000020E6100000A0C4E74EB06D49400CE544BB0A074C40
342	7	64	289	17316	10879	\N	56.188986383714301	422110, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, д.Качимир, ул.Зеленая (здание детский сад), д.2А		0101000020E6100000BD19355F257B494070B378B130184C40
327	7	64	289	16610	10463	\N	56.106043	422116, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Каркаусь, ул.Ленина (здание дом культуры), д.102		0101000020E61000002788BA0F40924940207C28D1920D4C40
93561	7	64	289	31794	78606	\N	56.124656999999999	Республика Татарстан (Татарстан), Кукморский район, д.Камышлы, ул.Ленина, 14		0101000020E610000069A7E672836F4940D61BB5C2F40F4C40
326	7	64	289	16517	10462	\N	56.177242650956899	Республика Татарстан (Татарстан), Кукморский район, с.Каенсар, ул.Х.Такташа, д.23	Россия, республика Татарстан, Кукморский район, село Каенсар	0101000020E6100000684128EFE3504940F3380CE6AF164C40
1076	7	64	289	61492	79249	\N	56.165118547842603	Республика Татарстан (Татарстан), Сабинский муниципальный район, п.ж.д.р. Иштуган, ул.Центральная, д.9	Россия, республика Татарстан, Кукморский район, поселок Иштуган	0101000020E6100000207F69519F4449405F79909E22154C40
309	7	64	289	15720	10438	\N	56.230017245426602	422120, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, д.Иске Юрт, ул.Центральная (здание начальная школа), д.36		0101000020E610000031276893C361494013437232711D4C40
324	7	64	289	16419	10459	\N	56.093786999999999	Республика Татарстан (Татарстан), Кукморский район, с.Верхняя Шунь, ул.Октябрьская, д.23	Россия, республика Татарстан, Кукморский район, село Верхняя Шунь	0101000020E6100000D311C0CDE28549401DE56036010C4C40
345	7	64	289	17502	10501	\N	56.056567999999999	Республика Татарстан (Татарстан), Кукморский район, с.Верхний Искубаш, ул.С.Ахтямова, д.38А	Россия, республика Татарстан, Кукморский район, село Верхний Искубаш	0101000020E610000029779FE3A38F49400400C79E3D074C40
373	7	64	289	18941	10547	\N	55.981043329331598	Республика Татарстан (Татарстан), Кукморский район, д.Верхний Арбаш, ул.Зеленая, д.104А	Россия, республика Татарстан, Кукморский район, село Верхний Арбаш	0101000020E6100000452BF702B3744940207C28D192FD4B40
295	7	64	289	15041	10406	\N	56.273634999999999	Республика Татарстан (Татарстан), Кукморский район, с.Вахитово, ул.Клубная, д.5	Россия, республика Татарстан, Кукморский район, село Вахитово	0101000020E6100000EA78CC40654449403E05C07806234C40
312	7	64	289	15816	10440	\N	56.296020827356898	Республика Татарстан (Татарстан), Кукморский район, с.Большой Сардек, ул.Центральная, 114	Россия, республика Татарстан, Кукморский район, село Большой Сардек	0101000020E61000002D5F97E13F594940F1F62004E4254C40
307	7	64	289	15547	10441	\N	56.1987372069215	422120, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Большой Кукмор, ул.Ленина (здание средняя школа), д.39	Россия, республика Татарстан, Кукморский район, село Большой Кукмор	0101000020E610000003250516C06C4940A9C0C93670194C40
348	7	64	289	17520	10497	\N	56.033303243541901	422107, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, д.Битлянгур, ул.Гагарина (здание начальная школа, д.47А		0101000020E610000065E3C116BB8F4940E9EDCF4543044C40
94260	7	64	289	1467	79067	\N	56.109515999999999	Республика Татарстан (Татарстан), Кукморский район, с.Березняк, ул.Ленина, д.17		0101000020E6100000651C23D923664940C231CB9E040E4C40
356	7	64	289	18037	10518	\N	56.246670999999999	Республика Татарстан (Татарстан), Кукморский район, д.Балыклы, ул.Центральная, д.23	Россия, республика Татарстан, Кукморский район, село Балыклы	0101000020E61000005FF0694E5E52494091EF52EA921F4C40
321	7	64	289	16303	10453	\N	56.207368000000002	Республика Татарстан (Татарстан), Кукморский район, с.Байлянгар, ул.Советская, 6	Россия, республика Татарстан, Кукморский район, село Байлянгар	0101000020E6100000BA4C4D82375C4940541EDD088B1A4C40
318	7	64	289	16105	10451	\N	56.286942000000003	422113, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, д.Аш-Бузи, ул.Молодежная (здание начальная школа), д.45		0101000020E6100000145D177E705E4940A7ECF483BA244C40
362	7	64	289	18326	10526	\N	56.1198476019173	Республика Татарстан (Татарстан), Кукморский район, д.Асан-Елга, ул.Молодежная, д.1	Россия, республика Татарстан, Кукморский район, село Асан-Елга	0101000020E61000002E8ECA4DD4784940D93EE42D570F4C40
320	7	64	289	16196	10457	\N	56.310306259103399	422113, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Адаево, ул.Татарстан (здание начальная школа), д.12		0101000020E61000002E73BA2C2660494054E0641BB8274C40
1337	7	64	289	1238	11553	\N	55.875531000000002	Республика Татарстан (Татарстан), Тюлячинский муниципальный район, д.Абди, ул.Ленина, д.17		0101000020E6100000149337C0CC5F49402DD1596611F04B40
329	7	64	6935	41027	12162	\N	56.111449	422116, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кукморский муниципальный район, с.Ташлы-Елга, ул.Татарстан (здание начальная школа), 59		0101000020E610000097CADB114E9749400116F9F5430E4C40
289	7	64	1238	14764	10393	\N	55.471323279662897	Республика Татарстан, Камско-Устьинский муниципальный район, п.Осинники, ул.Лесная, д.3	Россия, республика Татарстан, Камско-Устьинский район, село совхоз Осинники	0101000020E6100000629D2ADF33724840226DE34F54BC4B40
263	7	64	1238	40976	11914	\N	55.259643245141298	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Тенишево, ул.Ленина, д.12	Россия, республика Татарстан, Камско-Устьинский район	0101000020E610000031B5A50EF296484052D158FB3BA14B40
272	7	64	1238	13923	10363	\N	55.228473850941	Республика Татарстан, Камско-Устьинский муниципальный район, д.Челны, ул.Ленина, д.43	Россия, республика Татарстан, Камско-Устьинский район, село Челны	0101000020E61000006E6AA0F99C7348403FFED2A23E9D4B40
285	7	64	1238	14566	10384	\N	55.181651471578697	Республика Татарстан, Камско-Устьинский муниципальный район, с.Уразлино, ул.Мира, д.7	Россия, республика Татарстан, Камско-Устьинский район, село Уразлино	0101000020E6100000B05417F0329748409224085740974B40
288	7	64	1238	14665	10396	\N	55.434482000000003	Республика Татарстан, Камско-Устьинский муниципальный район, с.Теньки, ул.Октябрьская, д.50	Россия, республика Татарстан, Камско-Устьинский район, село Теньки	0101000020E6100000D600A5A1467D4840B0592E1B9DB74B40
287	7	64	1238	14665	10391	\N	55.434482000000003	Республика Татарстан, Камско-Устьинский муниципальный район, с.Теньки, ул.Вторая Октябрьская, д.60	Россия, республика Татарстан, Камско-Устьинский район, село Теньки	0101000020E6100000D600A5A1467D4840B0592E1B9DB74B40
168	7	64	6906	60582	75359	\N	55.833688562705497	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, п.Октябрьский, ул.Школьная, д.1	Россия	0101000020E6100000A2B8E34D7E67484079043752B6EA4B40
269	7	64	1238	13806	10349	\N	55.107925999999999	Республика Татарстан, Камско-Устьинский муниципальный район, с.Сюкеево, ул.Колхозная, д.16А	Россия, республика Татарстан, Камско-Устьинский район, село Сюкеево	0101000020E61000000F7EE200FA814840AD31E884D08D4B40
256	7	64	1238	13157	10621	\N	55.308818000000002	Республика Татарстан, Камско-Устьинский муниципальный район, с.Старое Казеево, ул.Хади Такташа, д.4	Россия, республика Татарстан, Камско-Устьинский район, село Старое Казеево	0101000020E6100000CBB91457956B48404435255987A74B40
252	7	64	1238	12982	10327	\N	55.308725000000003	422835, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Камско-Устьинский муниципальный район, с.Старое Барышево, ул.Центральная (здание сельского дома культуры), д.15		0101000020E6100000DAC69FA86C5E4840933A014D84A74B40
245	7	64	1238	12721	10596	\N	55.175555000000003	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Салтыганово, ул.Центральная, д.48а	Россия, республика Татарстан, Камско-Устьинский район, село Салтыганово	0101000020E6100000A9DDAF027C9148401CD3139678964B40
258	7	64	1238	13258	10634	\N	55.11251	Республика Татарстан, Камско-Устьинский муниципальный район, д.Мордовский Каратай, ул.Центральная, д.1	Россия, республика Татарстан, Камско-Устьинский район, село Мордовский Каратай	0101000020E6100000C503CAA65C8948408A3C49BA668E4B40
278	7	64	1238	14200	10378	\N	55.284036	Республика Татарстан, Камско-Устьинский муниципальный район, с.Малые Салтыки, ул.Баки Урманче, д.9	Россия, республика Татарстан, Камско-Устьинский район, село Малые Салтыки	0101000020E610000098A432C51C8C48407E71A94A5BA44B40
284	7	64	1238	14489	10389	\N	55.196300000000001	Республика Татарстан, Камско-Устьинский муниципальный район, д.Малые Кармалы, ул.Малая, д.1А	Россия, республика Татарстан, Камско-Устьинский район, село Малые Кармалы	0101000020E610000043AB933314954840371AC05B20994B40
291	7	64	1238	14863	10398	\N	55.266193999999999	Республика Татарстан, Камско-Устьинский муниципальный район, д.Буртасы, ул.Центральная, д.3	Россия, республика Татарстан, Камско-Устьинский район, село Малые Буртасы	0101000020E6100000022CF2EB877648401A321EA512A24B40
279	7	64	1238	14293	10373	\N	55.250827999999998	Республика Татарстан, Камско-Устьинский муниципальный район, д.Малое Мереткозино, ул.Вахитова, д.9		0101000020E61000007C7E18213C944840E675C4211BA04B40
265	7	64	1238	40648	11661	\N	55.155879994533699	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Куйбышевский Затон, ул.Ульяновское Шоссе, д.8		0101000020E6100000B2F336363B964840DD0C37E0F3934B40
264	7	64	1238	40648	78514	\N	55.156307339736998	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Куйбышевский Затон, ул.Ленина, д.12	Россия, республика Татарстан, Камско-Устьинский район, поселок Куйбышевский Затон	0101000020E610000036CEA62380954840649126DE01944B40
266	7	64	1238	40648	78567	\N	55.156445563616302	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Куйбышевский Затон, ул.Гагарина, д.12	Россия, республика Татарстан, Камско-Устьинский район, поселок Куйбышевский Затон	0101000020E6100000B8C9A8328C95484086CB2A6C06944B40
290	7	64	1238	14779	10399	\N	55.360674000000003	Республика Татарстан, Камско-Устьинский муниципальный район, с.Красновидово, ул.Мира, д.1	Россия, республика Татарстан, Камско-Устьинский район, село Красновидово	0101000020E610000091EEE714E48948403E42CD902AAE4B40
273	7	64	1238	14002	10364	\N	55.217336000000003	Республика Татарстан, Камско-Устьинский муниципальный район, с.Клянчеево, ул.Габдуллы Тукая, д.35	Россия, республика Татарстан, Камско-Устьинский район, село Клянчеево	0101000020E610000015C5ABAC6D6C48402A1F82AAD19B4B40
267	7	64	1238	13706	10360	\N	55.134985999999998	Республика Татарстан, Камско-Устьинский муниципальный район, с.Кирельское, ул.Площадь Совхозная, д.13	Россия, республика Татарстан, Камско-Устьинский район, село Кирельское	0101000020E61000001C7DCC07049248407CB5A33847914B40
254	7	64	1238	13071	10557	\N	55.288474999999998	Республика Татарстан, Камско-Устьинский муниципальный район, д.Картапа, ул.Школьная, д.10	Россия, республика Татарстан, Камско-Устьинский район, село Картапа	0101000020E6100000221B48179B604840575BB1BFECA44B40
255	7	64	1238	13146	10332	\N	55.284815000000002	Республика Татарстан, Камско-Устьинский муниципальный район, д.Караталга, ул.Мостовая, д.5		0101000020E610000095BA641C236B4840833463D174A44B40
262	7	64	1238	13338	10340	\N	55.199320999999998	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Камское Устье, ул.Комарова, д.16	Россия, республика Татарстан, Камско-Устьинский район, поселок Камское Устье	0101000020E6100000F2D24D6210A24840F833BC5983994B40
261	7	64	1238	13338	10337	\N	55.199320999999998	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Камское Устье, ул.Карла Маркса, д.4	Россия, республика Татарстан, Камско-Устьинский район, поселок Камское Устье	0101000020E6100000F2D24D6210A24840F833BC5983994B40
259	7	64	1238	13338	10337	\N	55.199320999999998	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Камское Устье, ул.Карла Маркса, д.105		0101000020E6100000F2D24D6210A24840F833BC5983994B40
213	7	64	1168	11169	10261	\N	55.453778999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Федоровское, ул.Тутаева, д.41	Россия, республика Татарстан, Кайбицкий район, село Федоровское	0101000020E610000092EC116A86304840484E266E15BA4B40
260	7	64	1238	13338	10660	\N	55.199320999999998	Республика Татарстан, Камско-Устьинский муниципальный район, п.г.т.Камское Устье, ул.Гагарина, д.80	Россия, республика Татарстан, Камско-Устьинский район, поселок Камское Устье	0101000020E6100000F2D24D6210A24840F833BC5983994B40
268	7	64	1238	13715	10366	\N	55.151347999999999	Республика Татарстан, Камско-Устьинский муниципальный район, д.Ишимово, ул.Центральная, д.10	Россия, республика Татарстан, Камско-Устьинский район, село Ишимово	0101000020E610000044A33B889D87484052280B5F5F934B40
281	7	64	1238	14387	10379	\N	55.2297253596766	Республика Татарстан, Камско-Устьинский муниципальный район, д.Данышево, ул.Кооперативная, д.71	Россия, республика Татарстан, Камско-Устьинский район, село Данышево	0101000020E6100000B3EE1F0BD18348406C09F9A0679D4B40
292	7	64	1238	14874	10403	\N	55.365217999999999	Республика Татарстан, Камско-Устьинский муниципальный район, с.Варварино, ул.Школьная, д.6А	Россия, республика Татарстан, Камско-Устьинский район, село Варварино	0101000020E6100000DE9387855A6F48408CF4A276BFAE4B40
280	7	64	1238	14303	10386	\N	55.260300000000001	Республика Татарстан, Камско-Устьинский муниципальный район, с.Большие Салтыки, ул.Свердлова, д.126		0101000020E610000004E5B67D8F8848400C93A98251A14B40
271	7	64	1238	13902	10358	\N	55.224330999999999	Республика Татарстан, Камско-Устьинский муниципальный район, с.Большие Кляри, ул.Пионерская, д.5	Россия, республика Татарстан, Камско-Устьинский район, село Большие Кляри	0101000020E61000007555A016837B48404F3DD2E0B69C4B40
282	7	64	1238	14397	10381	\N	55.212651723853703	Республика Татарстан, Камско-Устьинский муниципальный район, с.Большие Кармалы, ул.Школьная, д.6	Россия, республика Татарстан, Камско-Устьинский район, село Большие Кармалы	0101000020E6100000B1170AD80E904840E9B6442E389B4B40
275	7	64	1238	14096	10372	\N	55.274959000000003	Республика Татарстан, Камско-Устьинский муниципальный район, с.Большие Буртасы, ул.Ленинградская, д.27	Россия, республика Татарстан, Камско-Устьинский район, село Большие Буртасы	0101000020E610000053EA92718C744840D55E44DB31A34B40
277	7	64	1238	14191	10376	\N	55.279831000000001	Республика Татарстан, Камско-Устьинский муниципальный район, с.Большая Янгасала, ул.Центральная, д.1	Россия, республика Татарстан, Камско-Устьинский район, село Большая Янгасала	0101000020E610000021567F84617E484018B49080D1A34B40
283	7	64	1238	14475	10383	\N	55.217598000000002	Республика Татарстан, Камско-Устьинский муниципальный район, д.Баргузино, ул.Школьная, д.16	Россия, республика Татарстан, Камско-Устьинский район, село Баргузино	0101000020E6100000D50792770E87484067D65240DA9B4B40
276	7	64	1238	14111	10375	\N	55.306932000000003	Республика Татарстан, Камско-Устьинский муниципальный район, д.Балчиклы, ул.Ленина, д.70	Россия, республика Татарстан, Камско-Устьинский район, село Балчиклы	0101000020E61000002E71E481C8744840460C3B8C49A74B40
257	7	64	1238	13242	10334	\N	55.270347049469898	Республика Татарстан, Камско-Устьинский муниципальный район, д.Атабаево, ул.Центральная, д.14	Россия, республика Татарстан, Камско-Устьинский район, село Атабаево	0101000020E610000095D6DF12806D48402EC901BB9AA24B40
251	7	64	1238	12971	10330	\N	55.326726999999998	Республика Татарстан, Камско-Устьинский муниципальный район, д.Азимово-Курлебаш, ул.Центральная, д.2А	Россия, республика Татарстан, Камско-Устьинский район, село Азимово-Курлебаш	0101000020E6100000570740DCD56F48402FDCB930D2A94B40
216	7	64	1168	40592	10272	\N	55.460496999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, ст.Куланга, ул.Светлая, д.21а	Россия, республика Татарстан, Кайбицкий район	0101000020E6100000A91611C5E4354840FB73D190F1BA4B40
221	7	64	1168	40835	10865	\N	55.377997000000001	422327, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Имянле Буртас, ул.Гагарина (Буртасский дом культуры), д.7а	Россия, республика Татарстан, Кайбицкий район	0101000020E6100000B3CF6394670E4840397EA83462B04B40
226	7	64	1168	11841	10285	\N	55.321653970535401	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Янсурино, ул.Кирова, д.14	Россия, республика Татарстан, Кайбицкий район, село Янсуринское	0101000020E6100000FF3C0D1824E14740555051F52BA94B40
237	7	64	1168	12343	11547	\N	55.350572496232999	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Эбалаково, ул.Светлая, д.5	Россия, республика Татарстан, Кайбицкий район, село Эбалаково	0101000020E61000009EB64604E31848405872158BDFAC4B40
218	7	64	1168	11390	10269	\N	55.492031592010299	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Шушерма, ул.Ямашева, д.1	Россия, республика Татарстан, Кайбицкий район, село Шушерма	0101000020E61000009BE3DC26DC2D4840F14A92E7FABE4B40
230	7	64	1168	11954	10288	\N	55.284215000000003	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Чутеево, ул.Кооперативная, д.37	Россия, республика Татарстан, Кайбицкий район, село Чутеево	0101000020E61000009E42AED4B3E247402E04392861A44B40
228	7	64	1168	11866	11519	\N	55.366190000000003	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Хозесаново, ул.Центральная, д.16	Россия, республика Татарстан, Кайбицкий район, село Хозесаново	0101000020E6100000C45DBD8A8CEA4740A60F5D50DFAE4B40
55195	7	63	1108	49497	54345	\N	54.436413000000002	рабочий поселок Комсомольский, микрорайон-2, 13		0101000020E6100000CB2F833122E946404E469561DC374B40
249	7	64	1168	12891	10328	\N	55.415784000000002	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Ульянково, ул.Школьная, д.39	Россия, республика Татарстан, Кайбицкий район, село Ульянково	0101000020E61000002829B000A60848409C19FD6838B54B40
229	7	64	1168	11939	11521	\N	55.348334000000001	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Турминское, ул.Центральная, д.6	Россия, республика Татарстан, Кайбицкий район, село Турминское	0101000020E6100000D47C957CECF04740DD0A613596AC4B40
232	7	64	1168	12084	11534	\N	55.402751000000002	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Старые Чечкабы, ул.Клубная, д.4	Россия, республика Татарстан, Кайбицкий район, село Старые Чечкабы	0101000020E6100000029D499BAA0D484035B742588DB34B40
225	7	64	1168	11763	11506	\N	55.340691	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Старое Тябердино, ул.Советская, д.27	Россия, республика Татарстан, Кайбицкий район, село Старое Тябердино	0101000020E61000002D27A1F485DC474051853FC39BAB4B40
224	7	64	1168	61383	79108	\N	55.308450646266799	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Полевая Буа, ул.Центральная, д.51		0101000020E610000055F65D11FCEB474091B586527BA74B40
211	7	64	1168	11096	10253	\N	55.497080632948197	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Надеждино, ул.Центральная, д.17	Россия, республика Татарстан, Кайбицкий район, село Надеждино	0101000020E610000051A5660FB4024840433BA759A0BF4B40
212	7	64	1168	11103	10315	\N	55.429675000000003	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Мурали, ул.Центральная, д.45	Россия, республика Татарстан, Кайбицкий район, село Мурали	0101000020E61000003FA9F6E9782A484054742497FFB64B40
223	7	64	1168	11654	10276	\N	55.323197999999998	422336, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Молькеево, ул.Почтовая (Молькеевский дом культуры), д.18	Россия, республика Татарстан, Кайбицкий район, село Молькеево	0101000020E6100000C21550A8A7E74740F910548D5EA94B40
219	7	64	1168	11464	9956	\N	55.448279999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Малые Меми, ул.Центральная, д.27	Россия, республика Татарстан, Кайбицкий район, село Малые Меми	0101000020E61000004696CCB1BC414840B6B9313D61B94B40
235	7	64	1168	12252	10297	\N	55.41375	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Кушманы, ул.Школьная, д.31		0101000020E6100000C9570229B1214840295C8FC2F5B44B40
236	7	64	1168	12276	11545	\N	55.372058000000003	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Малые Кайбицы, ул.Центральная, д.52	Россия, республика Татарстан, Кайбицкий район, село Малые Кайбицы	0101000020E6100000EE940ED6FF1548408B1BB7989FAF4B40
242	7	64	1168	12560	10308	\N	55.351682505410402	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Малое Русаково, ул.Усманова, д.46	Россия, республика Татарстан, Кайбицкий район, село Малое Русаково	0101000020E61000004703780B242C484093C7D3F203AD4B40
248	7	64	1168	12834	10321	\N	55.422047999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Малое Подберезье, ул.Большая Красная, д.32б	Россия, республика Татарстан, Кайбицкий район, село Малое Подберезье	0101000020E6100000A4AB74779DF54740CDAB3AAB05B64B40
250	7	64	1168	12910	10323	\N	55.383966000000001	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Корноухово, ул.Бутанина, д.58	Россия, республика Татарстан, Кайбицкий район, село Корноухово	0101000020E61000001EE1B4E045034840526342CC25B14B40
247	7	64	1168	40653	10368	\N	55.284697000000001	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Каргала, ул.Красный Герой, д.16	Россия, республика Татарстан, Кайбицкий район, село Каргалы	0101000020E6100000A9BD88B663044840792288F370A44B40
217	7	64	1168	11376	10271	\N	55.501686999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Бурундуки, ул.Октябрьская, д.22	Россия, республика Татарстан, Кайбицкий район, село Бурундуки	0101000020E610000044DB31755738484007EA944737C04B40
231	7	64	1168	12045	11527	\N	55.274805999999998	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Большое Тябердино, ул.Центральная, д.21	Россия, республика Татарстан, Кайбицкий район, село Большое Тябердино	0101000020E6100000D5EB1681B1DC47404E5FCFD72CA34B40
241	7	64	1168	12531	10317	\N	55.362490000000001	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Большое Русаково, ул.Зиганшина, д.38	Россия, республика Татарстан, Кайбицкий район, село Большое Русаково	0101000020E6100000DC8310902F3348404390831266AE4B40
246	7	64	1168	12749	10319	\N	55.357546999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Большое Подберезье, ул.Площадь Свободы, д.31	Россия, республика Татарстан, Кайбицкий район, село Большое Подберезье	0101000020E6100000693A3B191CFD474036E49F19C4AD4B40
233	7	64	1168	12136	10299	\N	55.403402745995599	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Большие Кайбицы, ул.Шамиля Галеева, д.11	Россия, республика Татарстан, Кайбицкий район, село Большие Кайбицы	0101000020E6100000D34B8C65FA174840DC0DA2B5A2B34B40
151	7	64	6906	40640	10344	\N	55.879525999999998	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Осиново, ул.40 лет Победы, д.1		0101000020E6100000A5D93C0E83714840A8FDD64E94F04B40
240	7	64	1168	12458	10305	\N	55.355238999999997	422339, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Кайбицкий муниципальный район, с.Берлибаш, ул.Школьная (Берлибашская школа), д.1	Россия, республика Татарстан, Кайбицкий район, село Берлибаш	0101000020E6100000DD94F25A09114840C2A1B77878AD4B40
215	7	64	1168	11269	10265	\N	55.468269999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Беляево, ул.Школьная, д.1	Россия, республика Татарстан, Кайбицкий район, село Беляево	0101000020E61000003E062B4EB534484055D97745F0BB4B40
243	7	64	1168	12633	10318	\N	55.487544999999997	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Багаево, ул.Центральная, д.28	Россия, республика Татарстан, Кайбицкий район, село Багаево	0101000020E610000007D15AD1E6124840062AE3DF67BE4B40
234	7	64	1168	12189	10293	\N	55.430053000000001	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Афанасьевка, ул.Конторская, д.9	Россия, республика Татарстан, Кайбицкий район, село Афанасьевка	0101000020E61000001B4CC3F0111B4840FA4509FA0BB74B40
244	7	64	1168	12676	10662	\N	55.487264513556298	Республика Татарстан (Татарстан), Кайбицкий муниципальный район, д.Арасланово, ул.Чапаева, д.18	Россия, республика Татарстан, Кайбицкий район, село Арасланово	0101000020E610000055DCB8C5FC18484023BE13B35EBE4B40
198	7	64	947	10480	10222	\N	55.569566571136697	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Утяшки, ул.Центральная, д.40а	Россия, республика Татарстан, Зеленодольский район, село Утяшки	0101000020E6100000C2DB8310902D4840BFF04A92E7C84B40
199	7	64	947	10548	10228	\N	55.564098999999999	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, д.Утяково, ул.Мира, д.25а	Россия, республика Татарстан, Зеленодольский район, село Утяково	0101000020E61000005DA8FC6B79394840685A626534C84B40
163	7	64	947	8783	10166	\N	56.033501190105902	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Уразла, ул.Дружбы, д.3	Россия, республика Татарстан, Зеленодольский район, село Уразла	0101000020E610000080EF366F9C5C484010B1C1C249044C40
206	7	64	947	61415	79149	\N	55.648717149275001	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Тавлино, ул.Центральная, д.14	Россия, республика Татарстан, Зеленодольский район, село Товлино	0101000020E6100000D272A087DA224840FBAD9D2809D34B40
204	7	64	947	10770	10505	\N	55.514957000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Татарское Танаево, ул.Центральная, д.1а	Россия, республика Татарстан, Зеленодольский район, село Татарское Танаево	0101000020E610000043E1B3757018484053EC681CEAC14B40
209	7	64	947	11005	10257	\N	55.668990000000001	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Сунчелеево, ул.Чишма, д.6	Россия, республика Татарстан, Зеленодольский район, село Сунчелеево	0101000020E610000027A1F485900B4840EFACDD76A1D54B40
183	7	64	947	9685	10442	\N	55.771625999999998	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Свияжск, ул.Рождественская, д.1	Россия, республика Татарстан, Зеленодольский район, село Свияжск	0101000020E6100000DAA9B9DC60544840245F09A4C4E24B40
200	7	64	947	10578	10234	\N	55.510808818015001	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Русское Азелеево, ул.Центральная, д.1/3	Россия, республика Татарстан, Зеленодольский район, село Русское Азелеево	0101000020E6100000D47D00529B26484051C0763062C14B40
160	7	64	947	32928	10506	\N	55.903908160835798	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, п.Местечко Раифа, ул.Клубный переулок, д.15	Россия, республика Татарстан, Зеленодольский район, село Раифа	0101000020E6100000EFAA07CC435E4840E04BE141B3F34B40
187	7	64	947	9902	10220	\N	55.773595999999998	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, д.Протопоповка, ул.Кооперативная, д.7	Россия, республика Татарстан, Зеленодольский район, село Протопоповка	0101000020E61000001F0F7D772B4348408028983105E34B40
152	7	64	947	40643	10347	\N	55.8742425137373	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Осиново, ул.Гагарина, д.11а	Россия, республика Татарстан, село Осиново	0101000020E6100000789CA223B9724840E3E0D231E7EF4B40
194	7	64	947	10273	10484	\N	55.611964100190399	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Нурлаты, ул.Школьная, д.1	Россия, республика Татарстан, Зеленодольский район, село Нурлаты	0101000020E61000002235ED629A254840282A1BD654CE4B40
195	7	64	947	10273	10215	\N	55.611332542921801	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Нурлаты, ул.Гагарина, д.46	Россия, республика Татарстан, Зеленодольский район, село Нурлаты	0101000020E6100000CE6C57E88325484098FBE42840CE4B40
154	7	64	947	8404	10880	\N	55.873663000000001	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, п.Новопольский, ул.Свободы, д.39	Россия, республика Татарстан, Зеленодольский район, село Новопольский	0101000020E6100000486DE2E47E614840D55C6E30D4EF4B40
192	7	64	947	10181	10216	\N	55.699061	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Нижние Ураспуги, ул.Центральная, д.63а		0101000020E6100000226DE34F542648405C74B2D47AD94B40
184	7	64	947	9781	10199	\N	55.797635	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Нижние Вязовые, ул.Школьная, д.2	Россия, республика Татарстан, Зеленодольский район, поселок Нижние Вязовые	0101000020E610000078B471C45A4248408E9257E718E64B40
186	7	64	947	9781	10201	\N	55.797635	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Нижние Вязовые, ул.Советская, д.108	Россия, республика Татарстан, Зеленодольский район, поселок Нижние Вязовые	0101000020E610000078B471C45A4248408E9257E718E64B40
185	7	64	947	9781	10200	\N	55.797635	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Нижние Вязовые, ул.Первомайская, д.70	Россия, республика Татарстан, Зеленодольский район, поселок Нижние Вязовые	0101000020E610000078B471C45A4248408E9257E718E64B40
197	7	64	947	10409	10219	\N	55.611530999999999	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Молвино, ул.Центральная, д.17а	Россия, республика Татарстан, Зеленодольский район, село Молвино	0101000020E6100000B3976DA7AD314840BEBED6A546CE4B40
203	7	64	947	10731	10237	\N	55.534469000000001	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Мамадыш-Акилово, ул.Ленина, д.19а	Россия, республика Татарстан, Зеленодольский район, село Мамадыш-Акилово	0101000020E61000004F5DF92CCF114840E8DCED7A69C44B40
189	7	64	947	10000	10209	\N	55.753214999999997	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Малые Ширданы, ул.Каюма Насыри, д.31		0101000020E6100000A9143B1A872E4840A6ED5F5969E04B40
207	7	64	947	10912	10240	\N	55.656930000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Кугушево, ул.Советская, д.17	Россия, республика Татарстан, Зеленодольский район, село Кугушево	0101000020E6100000A08B868C4715484072E1404816D44B40
205	7	64	947	10814	10260	\N	55.613778000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Кугеево, ул.Центральная, д.32	Россия, республика Татарстан, Зеленодольский район, село Кугеево	0101000020E610000024473A03231B48408D800A4790CE4B40
155	7	64	947	8419	10402	\N	55.852566000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, д.Красный Яр, ул.Школьная, д.1	Россия, республика Татарстан, Зеленодольский район, село Красный Яр	0101000020E6100000E36C3A02B85148403DD7F7E120ED4B40
196	7	64	947	10386	10487	\N	55.666168376774699	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Косяково, ул.Светлая, д.6	Россия, республика Татарстан, Зеленодольский район, село Косяково	0101000020E61000002E3D9AEAC928484024D236FE44D54B40
202	7	64	947	10653	10235	\N	55.548527999999997	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Карашам, ул.Новая, д.27		0101000020E61000000D897B2C7D2248405B785E2A36C64B40
164	7	64	947	8853	10431	\N	56.018700000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, д.Каратмень, ул.Клубная, д.23	Россия, республика Татарстан, Зеленодольский район, село Каратмень	0101000020E610000040C23060C9614840B537F8C264024C40
191	7	64	947	40686	10481	\N	55.707101000000002	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, д.Васюково, ул.Ибрагимова, д.54а		0101000020E610000059164CFC5120484005FC1A4982DA4B40
175	7	64	947	9064	10225	\N	55.8384070418441	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Школьная, д.58	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E610000006B98B304559484065DEAAEB50EB4B40
174	7	64	947	9064	10184	\N	55.83802	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Территория Санатория, Центр досуга	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E61000009C69C2F6935948406CB2463D44EB4B40
169	7	64	947	9064	10173	\N	55.83802	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Спортивная, д.24	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E61000009C69C2F6935948406CB2463D44EB4B40
179	7	64	947	9064	10187	\N	55.838696833720803	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Свободы, д.1	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E6100000B8904770235948406D205D6C5AEB4B40
178	7	64	947	9064	10185	\N	55.83802	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Праздничная, д.9	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E61000009C69C2F6935948406CB2463D44EB4B40
180	7	64	947	9064	10189	\N	55.838986623428603	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Первомайская, д.26	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E6100000917C25901259484074620FED63EB4B40
77	7	64	6913	41002	12055	\N	55.323838000000002	Республика Татарстан, Заинский муниципальный район, с.Сарсаз-Багряж, ул.Школьная, д.3		0101000020E6100000919BE1067C1C4A40DD99098673A94B40
176	7	64	947	9064	10489	\N	55.83802	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Набережная, д.17	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E61000009C69C2F6935948406CB2463D44EB4B40
173	7	64	947	9064	10174	\N	55.83802	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Ленина, д.6	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E61000009C69C2F6935948406CB2463D44EB4B40
172	7	64	947	9064	10174	\N	55.838793430531098	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Ленина, д.40	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E610000006B98B30455948408F8EAB915DEB4B40
171	7	64	947	9064	10174	\N	55.839388099335402	422532, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Ленина (здание детской художественной школы), д.59а	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E610000013D4F02DAC594840D253E41071EB4B40
182	7	64	947	9064	10197	\N	55.83802	"Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Лагерная, к/концертный зал ЛОК ""Сосновый бор"""	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E61000009C69C2F6935948406CB2463D44EB4B40
181	7	64	947	9064	10194	\N	55.838986623428603	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, поселок городского типа Васильево, ул.Залесная, д.14а	Россия, республика Татарстан, Зеленодольский район, поселок Васильево	0101000020E6100000917C25901259484074620FED63EB4B40
167	7	64	947	8966	10461	\N	56.029220000000002	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Большой Кульбаш, ул.Подгорная, д.26	Россия, республика Татарстан, Зеленодольский район, село Большой Кульбаш	0101000020E61000000266BE839F704840CF31207BBD034C40
190	7	64	947	10087	10207	\N	55.733812	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Большое Ходяшево, ул.Светлая, д.2	Россия, республика Татарстан, Зеленодольский район, село Большое Ходяшево	0101000020E61000009886E123623C4840C8B4368DEDDD4B40
165	7	64	947	8862	10168	\N	56.021566071912702	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Большие Яки, ул.Школьная, д.5	Россия, республика Татарстан, Зеленодольский район, село Большие Яки	0101000020E6100000912BF52C086548404F5AB8ACC2024C40
188	7	64	947	9978	10470	\N	55.759110999999997	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Большие Ширданы, ул.Кирова, д.6	Россия, республика Татарстан, Зеленодольский район, село Большие Ширданы	0101000020E61000006B44300E2E39484055849B8C2AE14B40
166	7	64	947	8935	10171	\N	56.011218	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Большие Кургузи, ул.Школьная, д.30	Россия, республика Татарстан, Зеленодольский район, село Большие Кургузи	0101000020E6100000999B6F44F76A4840329067976F014C40
161	7	64	947	8700	10420	\N	55.982452000000002	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Большие Ключи, ул.Волостнова, д.21а	Россия, республика Татарстан, Зеленодольский район, село Большие Ключи	0101000020E61000002E73BA2C26664840E5F1B4FCC0FD4B40
193	7	64	947	10215	10213	\N	55.708652999999998	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Большие Ачасыры, ул.Кооперативная, д.26		0101000020E6100000664B5645B82B48402C9B3924B5DA4B40
162	7	64	947	8762	10164	\N	55.996948000000003	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Бишня, ул.Школьная, д.10	Россия, республика Татарстан, Зеленодольский район, село Бишня	0101000020E610000081CCCEA27778484004E8F7FD9BFF4B40
158	7	64	947	8583	10394	\N	55.929369121603898	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Бело-Безводное, ул.Юбилейная, д.13	Россия, республика Татарстан, Зеленодольский район, село Бело-Безводное	0101000020E610000079758E01D961484047753A90F5F64B40
208	7	64	947	10938	10245	\N	55.639277999999997	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Акзигитово, ул.Центральная, д.7	Россия, республика Татарстан, Зеленодольский район, село Акзигитово	0101000020E6100000200BD12170084840B1868BDCD3D14B40
156	7	64	947	8487	10353	\N	55.870874474910799	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Айша, ул.Светлая, д.1	Россия, республика Татарстан, Зеленодольский район, село Айша	0101000020E6100000118E59F624504840E6779ACC78EF4B40
157	7	64	947	8487	10390	\N	55.870585489452601	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Айша, ул.Молодежная, д.60	Россия, республика Татарстан, Зеленодольский район, село Айша	0101000020E610000001A777F17E504840AFB14B546FEF4B40
153	7	64	6906	40640	10344	\N	55.879525999999998	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Осиново, ул.40 лет Победы, д.5	Россия, республика Татарстан, село Осиново	0101000020E6100000A5D93C0E83714840A8FDD64E94F04B40
102	7	64	639	5853	10071	\N	55.469535	Республика Татарстан, Заинский муниципальный район, с.Шикмамаево, ул.Центральная, д.65А	Россия, республика Татарстан, Заинский район, село Шикмамаево	0101000020E610000054AC1A84B91F4A40E7A90EB919BC4B40
114	7	64	639	40524	10087	\N	55.198273	Республика Татарстан, Заинский муниципальный район, с.Чубуклы, ул.Молодежная, д.229А		0101000020E6100000FD82DDB06DF749400457790261994B40
113	7	64	639	6404	10088	\N	55.094380000000001	Республика Татарстан, Заинский муниципальный район, с.Урсаево, ул.Центральная, д.5	Россия, республика Татарстан, Заинский район, село Урсаево	0101000020E6100000F0DC7BB8E41E4A40C0B2D2A4148C4B40
94003	7	64	639	21628	78906	\N	55.133857999999996	Республика Татарстан, Заинский муниципальный район, с.Тюгеевка, ул.Школьная, д.89		0101000020E61000006D00362042E449406B274A4222914B40
97	7	64	639	5558	10758	\N	55.413764999999998	Республика Татарстан, Заинский муниципальный район, д.Тонгузино, ул.Центральная, д.8А	Россия, республика Татарстан, Заинский район, село Тонгузино	0101000020E6100000E8DD5850180A4A405E9D6340F6B44B40
115	7	64	639	6523	10105	\N	55.174906999999997	Республика Татарстан, Заинский муниципальный район, д.Суык-Чишма, ул.Центральная, д.30А		0101000020E6100000FDD98F1491EB4940B56B425A63964B40
110	7	64	639	6273	10082	\N	55.069029999999998	Республика Татарстан, Заинский муниципальный район, с.Старое Маврино, ул.Центральная, д.4		0101000020E610000094895B0531004A40B0389CF9D5884B40
100	7	64	639	40833	10847	\N	55.285311999999998	Республика Татарстан, Заинский муниципальный район, с.Пусташит, ул.Г.Тукая, д.56		0101000020E6100000745FCE6C57084A400394861A85A44B40
108	7	64	639	61385	79107	\N	55.184058512412399	Республика Татарстан, Заинский муниципальный район, с.Светлое Озеро, ул.Ленина, д.81	Россия, республика Татарстан, Заинский район, село Светлое Озеро	0101000020E6100000DBE044F46B014A4069C4CC3E8F974B40
107	7	64	639	6097	10098	\N	55.221491	Республика Татарстан, Заинский муниципальный район, с.Сармаш-Баш, ул.Центральная, д.144	Россия, республика Татарстан, Заинский район, село Сармаш-Баш	0101000020E6100000A25EF0694E2C4A40DEAD2CD1599C4B40
106	7	64	639	6067	10077	\N	55.225400961929097	Республика Татарстан, Заинский муниципальный район, с.Сарапала, ул.Центральная, д.28	Россия, республика Татарстан, Заинский район, село Сарапала	0101000020E6100000329067976FF549402BBEA1F0D99C4B40
109	7	64	639	6192	10080	\N	55.100212511721097	Республика Татарстан, Заинский муниципальный район, с.Савалеево, ул.Центральная, д.11	Россия, республика Татарстан, Заинский район, село Савалеево	0101000020E61000007AFEB4519D024A4028D192C7D38C4B40
105	7	64	639	61504	79262	\N	55.250418095781399	Республика Татарстан, Заинский муниципальный район, с.Поручиково, ул.Чапаева, д.25	Россия, республика Татарстан, Заинский район, село Поруиково	0101000020E610000028637C98BDFC4940352A70B20DA04B40
104	7	64	639	5965	10078	\N	55.376196	Республика Татарстан, Заинский муниципальный район, с.Поповка, ул.Центральная, д.4	Россия, республика Татарстан, Заинский район, село Поповка	0101000020E61000008C118942CB104A406971C63027B04B40
103	7	64	639	5878	10092	\N	55.142693999999999	Республика Татарстан, Заинский муниципальный район, с.Новоспасск, ул.Молодежная, д.14	Россия, республика Татарстан, Заинский район, село Новоспасск	0101000020E6100000A913D044D81A4A40EFAA07CC43924B40
83	7	64	639	61473	79222	\N	55.448259500077299	Республика Татарстан, Заинский муниципальный район, с.Нижние Лузи, ул.Центральная, д.38А	Россия, республика Татарстан, Заинский район, село Нижние Лузы	0101000020E61000009981CAF8F7014A406F0D6C9560B94B40
98	7	64	639	5643	10540	\N	55.441958999999997	Республика Татарстан, Заинский муниципальный район, с.Нижнее Бишево, ул.Центральная, д.47		0101000020E6100000B83CD68C0C204A402096CD1C92B84B40
99	7	64	639	5709	10778	\N	55.442663000000003	Республика Татарстан, Заинский муниципальный район, с.Куш-Елга, ул.З.Салимова, д.9	Россия, республика Татарстан, Заинский район, село Куш-Елга	0101000020E61000007A8CF2CCCB194A401B13622EA9B84B40
91	7	64	639	40500	10054	\N	55.083173000000002	Республика Татарстан, Заинский муниципальный район, с.Гулькино, ул.Центральная, д.27		0101000020E610000092205C0185E849408274B169A58A4B40
82	7	64	639	61458	79204	\N	55.451901964867702	Республика Татарстан, Заинский муниципальный район, с.Верхние Лузи, ул.Центральная, д.38А	Россия, республика Татарстан, Заинский район, село Верхние Лузы	0101000020E610000018062CB98AFB49409D7FBBECD7B94B40
112	7	64	639	6389	10103	\N	55.153359000000002	Республика Татарстан, Заинский муниципальный район, с.Алексеевка, ул.Центральная, д.22	Россия, республика Татарстан, Заинский район, село Алексеевка	0101000020E6100000C102983270D649400DC68844A1934B40
74	7	64	639	61457	79202	\N	55.235309718649297	Республика Татарстан, Заинский муниципальный район, с.Александровская Слобода, ул.Центральная, д.72Б	Россия, республика Татарстан, Заинский район, село Александровская Слобода	0101000020E610000022AAF067780F4A40FC3559A31E9E4B40
72	7	64	6913	40999	12052	\N	55.393763	Республика Татарстан, Заинский муниципальный район, с.Старый Токмак, ул.Советская, д.5А		0101000020E6100000613596B036FE4940FBAF73D366B24B40
76	7	64	6913	41004	12057	\N	55.351630999999998	Республика Татарстан, Заинский муниципальный район, с.Средний Багряж, ул.Центральная, д.47А		0101000020E6100000E4310395F11D4A4040A19E3E02AD4B40
111	7	64	6913	40527	10108	\N	55.081369000000002	Республика Татарстан, Заинский муниципальный район, с.Новое Маврино, ул.Дорожная, ФАП		0101000020E6100000D5E76A2BF6094A4041F4A44C6A8A4B40
95	7	64	6913	40691	11042	\N	55.451058000000003	Республика Татарстан, Заинский муниципальный район, с.Кадырово, ул.Молодежная, д.1		0101000020E61000002C9D0FCF120E4A40B24CBF44BCB94B40
90	7	64	6913	41015	12100	\N	55.348191	Республика Татарстан, Заинский муниципальный район, с.Имянлебаш, ул.Центральная, д.63		0101000020E61000000ADAE4F049E949407AE1CE8591AC4B40
94	7	64	6913	41017	12102	\N	55.456837	Республика Татарстан, Заинский муниципальный район, с.Зычебаш, ул.Центральная, д.102		0101000020E61000006FBDA607052B4A40274D83A279BA4B40
66	7	64	6913	40480	10023	\N	55.295990000000003	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, пр.Победы, д.5		0101000020E61000005FB87361A4034A40B6F81400E3A54B40
64	7	64	6913	40480	10023	\N	55.295990000000003	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, пр.Победы, д.1/12		0101000020E61000005FB87361A4034A40B6F81400E3A54B40
62	7	64	6913	40480	10021	\N	55.295990000000003	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, пр.Нефтяников, д.33	Россия, республика Татарстан, Заинск	0101000020E61000005FB87361A4034A40B6F81400E3A54B40
60	7	64	6913	40480	10015	\N	55.295005494780298	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Энергетиков, д.8	Россия, республика Татарстан, Заинск	0101000020E61000001C2785798F034A4008944DB9C2A54B40
70	7	64	6913	40480	10034	\N	55.296180866856098	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Ульянова, д.63	Россия, республика Татарстан, Заинск	0101000020E610000072193735D0024A4029594E42E9A54B40
69	7	64	6913	40480	10031	\N	55.295984973938502	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Толстого, д.39	Россия, республика Татарстан, Заинск	0101000020E6100000D1CE691668034A40A48D23D6E2A54B40
68	7	64	6913	40480	12049	\N	55.295990000000003	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Пионерская, д.16	Россия, республика Татарстан, Заинск	0101000020E61000005FB87361A4034A40B6F81400E3A54B40
61	7	64	6913	40480	10013	\N	55.295495237394803	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Лобачевского, д.5	Россия, республика Татарстан, Заинск	0101000020E6100000CEFE40B96D034A40D690B8C7D2A54B40
58	7	64	6913	40480	10010	\N	55.295299341077502	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Ленина, д.17		0101000020E610000072193735D0024A4050C58D5BCCA54B40
56	7	64	6913	40480	10010	\N	55.295201392554603	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Ленина, д.26 А	Россия, республика Татарстан, Заинск	0101000020E6100000CEFE40B96D034A408D5F7825C9A54B40
55	7	64	6913	40480	10010	\N	55.294667741014301	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Ленина, д.29 А	Россия, республика Татарстан, Заинск	0101000020E6100000168A743FA7024A40C09657AEB7A54B40
59	7	64	6913	40480	10014	\N	55.2931444174787	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Комсомольская, д.50 А		0101000020E61000006A34B91803FF494062821ABE85A54B40
57	7	64	6913	40480	10014	\N	55.296180866856098	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Комсомольская, д.50	Россия, республика Татарстан, Заинск	0101000020E6100000F51263997E034A4029594E42E9A54B40
63	7	64	6913	40480	10039	\N	55.2960829205187	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Казанская, д.5	Россия, республика Татарстан, Заинск	0101000020E6100000A7EA1ED95C034A4067F3380CE6A54B40
67	7	64	6913	40480	10029	\N	55.296670594900803	Республика Татарстан (Татарстан), Заинский муниципальный район, г.Заинск, ул.Заводская, д.1	Россия, республика Татарстан, Заинск	0101000020E6100000AD8A709351034A40F855B950F9A54B40
93	7	64	6913	41016	12101	\N	55.434522999999999	Республика Татарстан, Заинский муниципальный район, с.Дурт-Мунча, ул.Молодежная, д.147		0101000020E61000008EEA7420EB274A400E2E1D739EB74B40
73	7	64	6913	41000	12053	\N	55.334730999999998	Республика Татарстан, Заинский муниципальный район, с.Вторая Бугульда, ул.Пушкина, бригадный дом КФХ Шакирзянова		0101000020E6100000F31B261AA4004A408BFA2477D8AA4B40
85	7	64	6913	41009	12085	\N	55.262070000000001	Республика Татарстан, Заинский муниципальный район, с.Верхний Налим, ул.Молодежная, д.7		0101000020E61000006BD3D85E0B204A40A1A17F828BA14B40
75	7	64	6913	41001	12054	\N	55.341802000000001	Республика Татарстан, Заинский муниципальный район, с.Верхний Багряж, ул.Советская, д.4А		0101000020E6100000BAD91F28B7254A408CDAFD2AC0AB4B40
89	7	64	6913	41014	12099	\N	55.329687	Республика Татарстан, Заинский муниципальный район, с.Верхние Шипки, ул.Молодежная, д.2		0101000020E61000005890662C9AEE49404B75012F33AA4B40
88	7	64	6913	41013	12098	\N	55.504337999999997	Республика Татарстан, Заинский муниципальный район, с.Верхние Пинячи, ул.Речная, д.26А		0101000020E61000004E7FF623450E4A40A510C8258EC04B40
84	7	64	6913	41008	12079	\N	55.143852000000003	Республика Татарстан, Заинский муниципальный район, с.Бухарай, ул.Школьная, д.12		0101000020E610000064ADA1D45E284A406BBB09BE69924B40
87	7	64	6913	41010	12089	\N	55.489147000000003	Республика Татарстан, Заинский муниципальный район, с.Бура-Кирта, ул.Центральная, д.20А		0101000020E61000001C5F7B66491C4A40E0F76F5E9CBE4B40
78	7	64	6913	41003	12056	\N	55.487540000000003	Республика Татарстан, Заинский муниципальный район, с.Бегишево, ул.Клубная, д.117		0101000020E6100000F31C91EF52044A40F5BEF1B567BE4B40
96	7	64	6913	41018	12103	\N	55.461894999999998	Республика Татарстан, Заинский муниципальный район, д.Ахметьево, ул.Центральная, д.62		0101000020E6100000C4EE3B86C7144A40CC9717601FBB4B40
71	7	64	6913	40998	12051	\N	55.340813940600803	Республика Татарстан, Заинский муниципальный район, с.Аксарино, ул.Вахитова, д.2		0101000020E6100000DD09F65FE7F449406D020CCB9FAB4B40
36	7	64	173	2234	8260	\N	55.825066999999997	Республика Татарстан (Татарстан), Елабужский муниципальный район, п.Малоречинский, ул.Центральная, д.17	Россия, республика Татарстан, Елабужский район, село Малоречинский	0101000020E61000008D62B9A5D5EE49402101A3CB9BE94B40
40	7	64	173	2467	8264	\N	55.783752064594999	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Лекарево, ул.Московская, д.13	Россия, республика Татарстан, Елабужский район, село Лекарево	0101000020E610000050E09D7C7AE8494059164CFC51E44B40
37	7	64	173	2299	8261	\N	55.884715999999997	Республика Татарстан (Татарстан),  Елабужский муниципальный район, с.Большой Шурняк, ул.Ленина, д.8	Россия, республика Татарстан, Елабужский район, село Большой Шурняк	0101000020E61000005E81E84999C84940BC1FB75F3EF14B40
35	7	64	173	2191	8259	\N	55.818711583811996	Республика Татарстан (Татарстан), Елабужский муниципальный район, Большекачкинское сельское поселение, с.Большая Качка, ул.Школьная, д.12	Россия, республика Татарстан, Елабужский район, село Большая Качка	0101000020E6100000E8DA17D00BFB4940DF6B088ECBE84B40
54	7	64	1949	40995	12006	\N	55.740679	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Яковлево, ул.Мира, д.1		0101000020E610000026A94C3107C74940C0EAC891CEDE4B40
52	7	64	1949	40903	11227	\N	55.802649000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, д.Хлыстово, ул.Набережная, д.31		0101000020E61000002310AFEB17FC49406495D233BDE64B40
53	7	64	1949	40994	12005	\N	55.849423000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Тат.Дюм-Дюм, ул. Школьная, д.3		0101000020E610000054909F8D5CC7494030BC92E4B9EC4B40
50	7	64	1949	40992	12003	\N	55.740371460507397	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Танайка, ул.Ермазова, д.9		0101000020E61000000DAB7823F3F4494013F4177AC4DE4B40
49	7	64	1949	40991	12002	\N	55.907530999999999	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Старый Юраш, ул.Школьная, д.33		0101000020E6100000319A95ED43DE4940978DCEF929F44B40
48	7	64	1949	40990	12001	\N	55.909039999999997	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Старый Куклюк, ул. Садовая, д.1а		0101000020E6100000E0A0BDFA78CC4940BF60376C5BF44B40
44	7	64	1949	40985	11992	\N	55.734434999999998	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Мурзиха, ул.Центральная, д.3		0101000020E61000003EB0E3BF40D24940D50451F701DE4B40
46	7	64	1949	40987	11995	\N	55.775706999999997	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Поспелово, ул.Лесная, д.7		0101000020E61000000932022A1C1D4A409E23F25D4AE34B40
45	7	64	1949	40986	11994	\N	55.708160999999997	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Покровское, ул.Прикамская, д.19		0101000020E61000001BB80375CADB4940BDA60705A5DA4B40
42	7	64	1949	40268	9685	\N	55.810347336385199	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Морты, ул.Казанская, д.60а		0101000020E610000011514CDE00DD4940B3B45373B9E74B40
47	7	64	1949	40989	11998	\N	55.7458440726719	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Мальцево, ул.Есенина, д.41		0101000020E61000009B20EA3E00174A407BF5F1D077DF4B40
39	7	64	1949	40996	12007	\N	55.637368784254697	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Котловка, ул.Нефтяников, д.2		0101000020E61000005567B5C01ED54940FB3DB14E95D14B40
38	7	64	1949	40982	11988	\N	55.697851273437102	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Костенеево, ул.Молодежная, д.30		0101000020E6100000603FC4060BCD49408E3D7B2E53D94B40
51	7	64	1949	40993	12004	\N	55.774369999999998	Республика Татарстан (Татарстан), Елабужский муниципальный район, д.Колосовка, ул.Центральная, д.20		0101000020E6100000850B790437F849407380608E1EE34B40
33	7	64	1949	40980	11970	\N	55.8705899194482	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Гари, ул.Центральная, д.7		0101000020E6100000BDC458A65F024A40C11C3D7E6FEF4B40
34	7	64	1949	40902	11186	\N	55.7910762318606	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Большое Елово, ул.40 лет Победы, д.2		0101000020E610000082E49D4319C84940435376FA41E54B40
41	7	64	1949	40236	9628	\N	55.773915000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Большие Армалы, ул.Центральная, д.9		0101000020E6100000C823B891B2E1494022718FA50FE34B40
32	7	64	1949	40239	9632	\N	55.832498474795102	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Бехтерево, ул.Гусева, д.8		0101000020E6100000ABED26F8A60F4A4022FE614B8FEA4B40
31	7	64	1949	40979	11964	\N	55.886518503483401	Республика Татарстан (Татарстан), Елабужский муниципальный район, с.Альметьево, ул.Сайдашева, д.4		0101000020E6100000381268B0A9DD49402D24607479F14B40
94284	7	64	376	2857	78493	\N	54.814911000000002	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Шланга, ул.Ленина, д.26		0101000020E6100000DF6C73637AB247404913EF004F684B40
94291	7	64	376	3258	78477	\N	54.708903999999997	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Чувашское Дрожжаное, ул.Октябрьская, д.21а		0101000020E6100000239EEC6646C347407500C45DBD5A4B40
94276	7	64	376	2404	79070	\N	54.677995000000003	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Чувашская Бездна, ул.Горького, д.8	Россия, республика Татарстан, Дрожжановский район, село Чувашская Бездна	0101000020E6100000E6965643E2B84740FFEC478AC8564B40
94305	7	64	376	3976	79105	\N	54.892758000000001	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Чепкас-Ильметьево, ул.Школьная, д.22		0101000020E61000001FBAA0BE65DE4740069FE6E445724B40
94303	7	64	376	3875	79087	\N	54.817708000000003	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Хорновар-Шигали, ул.Горького, д.2		0101000020E6100000D78A36C7B9D94740BBD6DEA7AA684B40
94292	7	64	376	3324	79080	\N	54.724083999999998	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, д.Хайбулдино, ул.Клубная, д.1		0101000020E61000001572A59E05C3474047C7D5C8AE5C4B40
94300	7	64	376	3748	79103	\N	54.787199000000001	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Убей, ул.Красная площадь, д.48		0101000020E6100000C66F0A2B15E24740D238D4EFC2644B40
94271	7	64	376	2101	79077	\N	54.550086	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Татарские Шатрашаны, ул.Комарова, д.26		0101000020E61000002B306475ABB1474065FED13769464B40
94287	7	64	376	3017	79081	\N	54.867212000000002	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, д.Татарские Тюки, ул.Советская, д.1		0101000020E61000009AD2FA5B02B64740715985CD006F4B40
94281	7	64	376	2680	79073	\N	54.701948999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Татарская Бездна, ул.Гагарина, д.32		0101000020E6100000096EA46C91B64740DE3AFF76D9594B40
94277	7	64	376	2451	78469	\N	54.651057999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старые Чукалы, ул.Коминтерна, д.18		0101000020E6100000EE5D83BEF4C447404BE658DE55534B40
94286	7	64	376	2981	78468	\N	54.832214	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старые Какерли, ул.Советская, д.38		0101000020E6100000FC34EECD6FC24740FDA204FD856A4B40
94289	7	64	376	3140	79076	\N	54.807876	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старые Ишли, ул.Центральная, д.16		0101000020E6100000E0A293A5D6BD4740959C137B68674B40
94269	7	64	376	1990	69280	\N	54.753207000000003	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старое Шаймурзино, ул.Ленина, д.61		0101000020E6100000D862B7CF2AFD4740240F441669604B40
94293	7	64	376	3373	79102	\N	54.689653	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старое Ильмово, ул.Центральная, д.23		0101000020E61000002D05A4FD0FCA47404D4BAC8C46584B40
94297	7	64	376	3587	79104	\N	54.783622000000001	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, д.Старое Дуваново, ул.Крепкова, д.1		0101000020E6100000F1660DDE57D747408B36C7B94D644B40
94295	7	64	376	3446	69321	\N	54.726309000000001	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старое Дрожжаное, ул.Центральная, д.9		0101000020E6100000CF4A5AF10DC747402EE57CB1F75C4B40
94294	7	64	376	3446	69321	\N	54.724275146000899	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старое Дрожжаное, ул.Центральная, д.15	Россия, республика Татарстан, Дрожжановский район, село Старое Дрожжаное	0101000020E6100000C0CE4D9B71C84740BB270F0BB55C4B40
94299	7	64	376	3687	79093	\N	54.707160999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Старая Задоровка, ул.Ленина, д.1		0101000020E61000009C525E2BA1D14740DA006C40845A4B40
94301	7	64	376	3791	79089	\N	54.771205999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Новый Убей, ул.Центральная, д.61		0101000020E6100000E065868DB2E447404F3DD2E0B6624B40
94279	7	64	376	2558	79074	\N	54.63993	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Новые Чукалы, ул.Советская, д.20а		0101000020E6100000B4CA4C69FDCF474059DDEA39E9514B40
94290	7	64	376	3223	79078	\N	54.818792000000002	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Новые Какерли, ул.Ленина, д.31		0101000020E6100000C5591135D1CB4740FC1C1F2DCE684B40
94288	7	64	376	3091	78974	\N	54.795374000000002	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Новые Ишли, ул.Кооперативная, д.9		0101000020E6100000FDDB65BFEEC647405B0BB3D0CE654B40
94274	7	64	376	2289	79075	\N	54.564272000000003	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Новое Чекурское, ул.Центральная, д.22б		0101000020E61000003A75E5B33CBD474036069D103A484B40
94278	7	64	376	2523	78470	\N	54.670867999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Новое Ильмово, ул.Советская, д.34		0101000020E6100000ACE28DCC23D147406AF7AB00DF554B40
94296	7	64	376	3538	78484	\N	54.738557	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Новое Дрожжаное, ул.Молодежная, д.17		0101000020E6100000658C0FB397C74740AE9D2809895E4B40
94280	7	64	376	2632	78464	\N	54.728138999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Нижний Каракитан, ул.Ленина, д.30		0101000020E610000085CFD6C1C1AA474098F8A3A8335D4B40
94272	7	64	376	2174	78458	\N	54.594656999999998	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Нижнее Чекурское, ул.Дорожная, д.12		0101000020E6100000B2A03028D3B4474032AB77B81D4C4B40
94283	7	64	376	2783	79082	\N	54.770375000000001	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Мочалей, ул.Замалетдинова, д.10		0101000020E61000000796236420B34740F853E3A59B624B40
94282	7	64	376	2740	78466	\N	54.780194999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Матаки, ул.Уганина, д.22а		0101000020E6100000FB40F2CEA1B8474059C0046EDD634B40
94302	7	64	376	3844	79084	\N	54.782158000000003	Республика Татарстан, Дрожжановский район, с.Малый Убей, ул.Центральная, д.19		0101000020E6100000548EC9E2FEE547400327DBC01D644B40
94306	7	64	376	4050	75346	\N	54.768338999999997	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Малая Цильна, ул.Крупская, д.2		0101000020E6100000F92CCF83BBEF4740E49EAEEE58624B40
94304	7	64	376	3941	79090	\N	54.855666999999997	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, д.Коршанга-Шигали, ул.Комсомольская, д.5		0101000020E61000008411FB0450D247401AA20A7F866D4B40
94273	7	64	376	2215	78462	\N	54.581029999999998	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Городище, ул.Клубная, д.6а		0101000020E61000007C0C569C6AC3474058FFE7305F4A4B40
94270	7	64	376	61381	79097	\N	54.7721949986448	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, поселок железнодорожная станция Бурундуки, ул.Вокзальная, д.27	Россия, республика Татарстан, село Бурундуки	0101000020E61000002367614F3B1E48403F912749D7624B40
94268	7	64	376	1932	78455	\N	54.689720999999999	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Большая Цильна, ул.Родина, д.1		0101000020E610000044A4A65D4CED4740A52E19C748584B40
94275	7	64	376	2329	78463	\N	54.626745	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Большая Акса, ул.Октябрьская, д.47		0101000020E610000048DFA46950C047403CF71E2E39504B40
94298	7	64	376	3657	78482	\N	54.752037000000001	Республика Татарстан (Татарстан), Дрожжановский муниципальный район, с.Алешкин-Саплык, ул.Школьная, д.3а		0101000020E61000001152B7B3AFD24740E43098BF42604B40
94223	7	64	13	61191	77516	\N	55.977313038803999	Республика Татарстан (Татарстан), Высокогорский муниципальный район, пос.Бирюлинского зверосовхоза, ул.Кольцевая, д.33	Россия, республика Татарстан, Высокогорский район, село совхоз Бирюлинский	0101000020E610000028B9C32632B14840537AA69718FD4B40
94210	7	64	13	31311	79046	\N	56.114530000000002	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Янга-Аул, ул.Кирова, д.29		0101000020E6100000BA11161571744840983446EBA80E4C40
94246	7	64	13	649	78451	\N	55.975369999999998	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Ямашурма, ул.Нариманова, д.15		0101000020E6100000F10F5B7A34CD4840F0BF95ECD8FC4B40
94225	7	64	13	31980	79055	\N	56.046388	Республика Татарстан (Татарстан), Высокогорский муниципальный район, пос.Юртыш, ул.Кооперативная, д.34		0101000020E61000000E85CFD6C1754840A376BF0AF0054C40
94267	7	64	13	61395	79124	\N	56.110640263691302	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Шуман, ул.Северная, д.20	Россия, республика Татарстан, Высокогорский район, село Шуманы	0101000020E6100000C2DCEEE53EAB484091D09673290E4C40
94245	7	64	13	577	78443	\N	55.953215	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Шапши, ул.Ленина, д.2		0101000020E6100000AD8905BEA2BF48404087F9F202FA4B40
94220	7	64	13	31746	79341	\N	56.065016999999997	422727, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Чувашли, ул.Клубная (здание сельского клуба), д.23		0101000020E61000008BC56F0A2B8148408E57207A52084C40
94215	7	64	13	61376	79079	\N	56.0874051973219	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Чирша, ул.Центральня, д.34	Россия, республика Татарстан, Высокогорский район, село Чирши	0101000020E61000003929CC7B9C9B4840E1404816300B4C40
94262	7	64	13	1591	78454	\N	55.966583999999997	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Чернышевка, ул.Клубная, д.1		0101000020E6100000992CEE3F32A548401E6B4606B9FB4B40
94263	7	64	13	1639	75305	\N	56.001317999999998	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Чепчуги, ул.Школьная, д.1		0101000020E61000008FE3874A23C24840B4722F302B004C40
94261	7	64	13	1524	69273	\N	55.994194	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Усады, ул.Советская, д.41		0101000020E61000002E8D5F7825A7484091F0BDBF41FF4B40
94259	7	64	13	1399	78975	\N	56.067107999999998	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Ташлы-Ковали, ул.Школьная, д.94		0101000020E6100000BBED42739DBC484065A6B4FE96084C40
94265	7	64	13	1752	79069	\N	56.040123000000001	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.татарская Айша, ул.Школьная, д.20		0101000020E6100000A794D74AE8D64840A1681EC022054C40
94256	7	64	13	1175	79323	\N	56.097422000000002	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Суксу, ул.Комсомольская, д.18А		0101000020E6100000D68C0C72178F484099F4F752780C4C40
94254	7	64	13	1136	79066	\N	56.173516999999997	Республика Татарстан (Татарстан), Высокогорский муниципальный район, д.Средний Алат, ул.Центральная, д.27		0101000020E6100000997FF44D9A9A4840672618CE35164C40
94258	7	64	13	1362	79068	\N	56.016314999999999	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Сосновка, ул.Центральная, д.68А		0101000020E61000004A60730E9EB9484095B7239C16024C40
94252	7	64	13	999	79071	\N	55.949657000000002	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Семиозерка, ул.Верхняя, д.99А		0101000020E6100000ADFA5C6DC58C484070B54E5C8EF94B40
94212	7	64	13	31368	79048	\N	56.052844	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Сая, ул.Светлая, д.13		0101000020E61000007BD976DA1A97484019E59997C3064C40
94251	7	64	13	935	78448	\N	55.88147	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Пановка, ул.Крупской, д.33		0101000020E6100000AEF4DA6CACB24840DB334B02D4F04B40
55194	7	63	1108	49497	54391	\N	54.436413000000002	рабочий поселок Комсомольский, микрорайон-1, 48		0101000020E6100000CB2F833122E946404E469561DC374B40
94237	7	64	13	61534	79351	\N	56.3183117888277	"422721, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Высокогорский муниципальный район, д.Наратлык, ул.Аринская (здание ГБУ ""Ислейтарлес""), д.25"	Россия, республика Татарстан, Высокогорский район, село Ислейтарский Лесхоз	0101000020E61000000A2C80290389484051F69672BE284C40
94250	7	64	13	822	79320	\N	56.051777999999999	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Мульма, ул.Центральная, д.28А		0101000020E6100000BABE0F0709CB48407E5358A9A0064C40
94247	7	64	13	697	79060	\N	56.058090999999997	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Мемдель, ул.Кооперативная, д.30А		0101000020E610000012312592E87748409198A0866F074C40
94233	7	64	13	32362	79422	\N	56.1262835012026	422720, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Высокогорский муниципальный район, д.Малый Сулабаш, ул.Школьная (здание дома культуры), д.5		0101000020E6100000EC89AE0B3FA048400801F9122A104C40
94257	7	64	13	1302	79061	\N	56.112779000000003	Республика Татарстан (Татарстан), Высокогорский муниципальный район,д.Малый Рясь, ул.Г.Камала, д.18		0101000020E610000055C03DCF9F8648407A56D28A6F0E4C40
94264	7	64	13	1702	78453	\N	56.000563	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Куркачи, ул.Клубная, д.4		0101000020E6100000FB04508C2CCD4840384BC97212004C40
94266	7	64	13	60614	75454	\N	56.009730931377902	Республика Татарстан (Татарстан), Высокогорский муниципальный район, пос.ж.д.разъезд Куркачи, ул.гагарина, д.7	Россия, республика Татарстан, Высокогорский район, поселок Куркачи	0101000020E610000068942EFD4BC84840F2608BDD3E014C40
94231	7	64	13	32240	78445	\N	55.947212	Республика Татарстан (Татарстан), Высокогорский муниципальный район, д.Калинино, ул.Центральная, д.32		0101000020E61000005358A9A0A2AE48407B30293E3EF94B40
94235	7	64	13	32452	79056	\N	56.246071000000001	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Казаклар, ул.Советская, д.11		0101000020E610000020628385939A48403CBF28417F1F4C40
94217	7	64	13	31662	79053	\N	56.05585	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Инся, ул.Колхозная, д.7А		0101000020E6100000E55FCB2BD7A94840A5BDC11726074C40
94232	7	64	13	32288	75343	\N	56.120513000000003	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Дубъязы, ул.Ленина, д.35		0101000020E610000079944A784299484016DF50F86C0F4C40
94214	7	64	13	31522	79051	\N	56.244720000000001	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Гарь, ул.Школьная, д.1		0101000020E6100000C311A452EC864840AC5626FC521F4C40
94229	7	64	13	61535	79353	\N	55.908299809643502	422701, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Высокая Гора, ул.Центральная (здание спортивного комплекса), д.11А	Россия, республика Татарстан, село Высокая Гора	0101000020E61000004298DBBDDCA74840787AA52C43F44B40
94226	7	64	13	61535	79360	\N	55.913687000000003	422701, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Высокая Гора, ул.Татарстан (здание школы № 3), д.25	Россия, республика Татарстан, село Высокая Гора	0101000020E6100000FE28EACC3DA84840E3E313B2F3F44B40
94244	7	64	13	524	79063	\N	56.149301000000001	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Большой Куюк, ул.Школьная, д.6		0101000020E61000003E5B07077B7D48404B21904B1C134C40
94221	7	64	13	31798	78437	\N	56.175311000000001	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Большой Битаман, ул.Московская, д.2В		0101000020E61000003C855CA96787484085D0419770164C40
94218	7	64	13	31669	79064	\N	56.030583	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Большие Ковали, ул.Клубная, д.8		0101000020E610000072FDBB3E738848402368CC24EA034C40
94222	7	64	13	31879	78976	\N	56.183458000000002	Республика Татарстан (Татарстан), Высокогорский муниципальный район, д.Бикнарат, ул.Центральная, д.19		0101000020E6100000CAE2FE23D381484044183F8D7B174C40
94239	7	64	13	61537	79356	\N	55.902070217388598	422700, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Высокогорский муниципальный район, пос.Березовка, ул.Центральная (здание ТСЖ), д.65	Россия, республика Татарстан, поселок Березовка	0101000020E6100000A41820D104A04840F3599E0777F34B40
94216	7	64	13	31611	78496	\N	56.065776	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Березка, ул.Центральная, д.12		0101000020E61000004A5E9D6340A248404C6E14596B084C40
94211	7	64	13	31323	79050	\N	56.020743000000003	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Альдермыш, ул.Ленина, д.26		0101000020E6100000CD3FFA264D9D48407B4FE5B4A7024C40
94213	7	64	13	31430	79052	\N	56.179459999999999	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Алан-Бексерь, ул.Центральная, д.17		0101000020E61000007521567F848D48405778978BF8164C40
94243	7	64	13	444	79059	\N	56.100239000000002	Республика Татарстан (Татарстан), Высокогорский муниципальный район, с.Айбаш, ул.Центральная, д.31		0101000020E610000034BF9A03047F48405264ADA1D40C4C40
94203	7	64	1872	30931	79047	\N	55.561216999999999	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, д.Янга-Юл, ул.Центральная, д.18а		0101000020E610000039D6C56D34744840C87A6AF5D5C74B40
94191	7	64	1872	30314	78879	\N	55.504944999999999	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Егидерево, ул.Центральная, д.30		0101000020E61000008A8EE4F21F5C4840ADA3AA09A2C04B40
94197	7	64	1872	30610	10120	\N	55.490003722287902	422570, Адрес УИК и помещение для голосования: Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Ямбулатово, ул.Школьная (здание МОУ общеобразовательной школы), д.5	Россия, республика Татарстан, Верхнеуслонский район, село Ямбулатово	0101000020E6100000887FD8D2A363484060747973B8BE4B40
94200	7	64	1872	30728	79054	\N	55.527912000000001	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Шеланга, ул.Строителей, д.47	Россия, республика Татарстан, Верхнеуслонский район, село Шеланга	0101000020E6100000A81ABD1AA08048403E95D39E92C34B40
94199	7	64	1872	30728	78433	\N	55.527912000000001	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Шеланга, ул.Советская, д.7		0101000020E6100000A81ABD1AA08048403E95D39E92C34B40
94189	7	64	1872	30167	79345	\N	55.546455000000002	422570, Адрес УИК и помещение для голосования: Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Чулпаниха, ул.Центральная (здание фельдшерско-акушерского пункта), д.81	Россия, республика Татарстан, Верхнеуслонский район, село Чулпаниха	0101000020E6100000D7DAFB54153C48402BDEC83CF2C54B40
94185	7	64	1872	30028	79029	\N	55.554898000000001	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, д.Уланово, ул.Заозерная, д.15		0101000020E61000008388D4B48B594840D34ECDE506C74B40
94175	7	64	1872	29565	79030	\N	55.702368	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Татарское Бурнашево, ул.Советская, д.62		0101000020E6100000CA17B49080534840E3E0D231E7D94B40
94198	7	64	1872	30717	79042	\N	55.563074999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Старое Русское Маматкозино, ул.Дорожная, д.1		0101000020E610000043AA285E65654840FC1873D712C84B40
94187	7	64	1872	30129	79038	\N	55.611784999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Соболевское, ул.Береговая, д.30		0101000020E6100000C3F4BD86E03A484078978BF84ECE4B40
94180	7	64	1872	29834	79027	\N	55.614072999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Сеитово, ул.Центральная, д.29		0101000020E610000061FF756EDA644840A52DAEF199CE4B40
94181	7	64	1872	29844	78762	\N	55.592474000000003	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Русское Макулово, ул.Центральная, д.125		0101000020E6100000469737876B5B48407BDD2230D6CB4B40
94182	7	64	1872	29844	78439	\N	55.592474000000003	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Русское Макулово, ул.Садовая, д.5		0101000020E6100000469737876B5B48407BDD2230D6CB4B40
94176	7	64	1872	29604	79026	\N	55.669787999999997	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Русское Бурнашево, ул.Большая, д.4		0101000020E610000033897AC1A75D48406AA0F99CBBD54B40
94192	7	64	1872	30408	79037	\N	55.463788999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Патрикеево, ул.Береговая, д.10		0101000020E6100000179D2CB5DE4948404D9F1D705DBB4B40
94207	7	64	1872	61536	79354	\N	55.660676965838498	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, пос.Октябрьский, ул.Центральная, д.7		0101000020E61000006F8104C58F714840151C5E1091D44B40
94194	7	64	1872	61440	79185	\N	55.372222000000001	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Нижнее Озеро, ул.Центральная, д.7		0101000020E610000026C5C727645B4840056D72F8A4AF4B40
94201	7	64	1872	30927	79301	\N	55.555289999999999	422570, Адрес УИК и помещение для голосования: Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, д.Нариман, ул.Центральная (здание сельского клуба), д.12А	Россия, республика Татарстан, Верхнеуслонский район, село Нариман	0101000020E6100000AC36FFAF3A7E4840DEE522BE13C74B40
94172	7	64	1872	61301	78461	\N	55.770896999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Набережные Моркваши, ул.Красавина, д.40		0101000020E61000003C32569BFF6B4840D1CABDC0ACE24B40
94206	7	64	1872	31081	79045	\N	55.649605999999999	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, д.Матюшино, ул.Волжская, д.1		0101000020E610000090D78349F179484087A4164A26D34B40
94195	7	64	1872	30527	79049	\N	55.452058000000001	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Майдан, ул.Советская, д.35		0101000020E6100000A94A5B5CE365484095F25A09DDB94B40
94177	7	64	1872	29656	78432	\N	55.645364999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Куралово, ул.Центральная, д.25		0101000020E61000003E9468C9E35D4840D47D00529BD24B40
94178	7	64	1872	29656	79034	\N	55.645364999999998	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Куралово, ул.Пионерская, д.19		0101000020E61000003E9468C9E35D4840D47D00529BD24B40
94190	7	64	1872	30310	79032	\N	55.498913000000002	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Коргуза, ул.Центральная Площадь, д.1		0101000020E610000001FA7DFFE65348404E469561DCBF4B40
94183	7	64	1872	30024	79337	\N	55.601278999999998	422570, Адрес УИК и помещение для голосования: Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, д.Клянчино, ул.Центральная (здание сельского клуба), д.26	Россия, республика Татарстан, Верхнеуслонский район, село Клянчино	0101000020E6100000058BC3995F4D4840C362D4B5F6CC4B40
94186	7	64	1872	30120	79043	\N	55.539059000000002	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Кильдеево, ул.Центральная, д.16		0101000020E6100000D00EB8AE98534840A7CEA3E2FFC44B40
94162	7	64	1872	61372	79062	\N	55.767994999999999	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Верхний Услон, ул.Чехова, д.54		0101000020E61000001C23D923D47C4840EA3E00A94DE24B40
94163	7	64	1872	61372	79036	\N	55.7705572539207	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Верхний Услон, ул.Советская, д.22	Россия, республика Татарстан, село Верхний Услон	0101000020E6100000C8B4368DED7D4840185A9D9CA1E24B40
94169	7	64	1872	61372	79044	\N	55.767994999999999	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Верхний Услон, ул.Печищинский тракт, д.1		0101000020E61000001C23D923D47C4840EA3E00A94DE24B40
94161	7	64	1872	61372	79091	\N	55.768023088875097	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Верхний Услон, ул.Колхозная, д.32	Россия, республика Татарстан, село Верхний Услон	0101000020E610000055850662D97C4840B4C9E1934EE24B40
94173	7	64	1872	61533	79343	\N	55.7591769742967	422570, Адрес УИК и помещение для голосования: Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Введенская Слобода, ул.Центральная (здание МОУ общеобразовательной школы), д.53А	Россия, республика Татарстан, Верхнеуслонский район, село Введенская Слобода	0101000020E6100000CAC0012D5D5948400D7041B62CE14B40
94193	7	64	1872	30418	79039	\N	55.401268000000002	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, с.Большие Меми, ул.Молодежная, д.19		0101000020E610000077D844662E5648403677F4BF5CB34B40
94205	7	64	1872	61444	79184	\N	55.641366312683601	Республика Татарстан (Татарстан), Верхнеуслонский муниципальный район, пос.Бакча-Сарай, ул.Центральная, д.1	Россия, республика Татарстан, Верхнеуслонский район, село Бахчи-Сарай	0101000020E6100000554FE61F7D7948401762F54718D24B40
94160	7	64	1742	61380	79096	\N	54.890987293694501	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Яшевска, ул.Нагорная, д.9		0101000020E610000056444DF4F93E4840A114ADDC0B724B40
94095	7	64	1742	25943	78970	\N	54.764786000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Яскуль, ул.Ленина, д.71		0101000020E6100000EED0B018752748402638F581E4614B40
94158	7	64	1742	28798	78987	\N	54.908271999999997	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Энтуганы, ул.Центральная, д.12		0101000020E6100000AA44D95BCAED4740AEEFC34142744B40
94145	7	64	1742	28198	79011	\N	54.802765000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Шаймурзино, ул.Кооперативная, д.5		0101000020E610000039ED2939270C4840CDAFE600C1664B40
94139	7	64	1742	27950	79330	\N	54.984786	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Чураково, ул.Центральная, д.53А		0101000020E61000006C054D4BAC1C484082C7B7770D7E4B40
94155	7	64	1742	28653	79041	\N	54.777687	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Чувашские Кищаки, ул.Ленина, д.39		0101000020E610000034A0DE8C9A1548401EC3633F8B634B40
94109	7	64	1742	26567	78998	\N	55.054217000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Беловолжка Чувашская, ул.Школьная, д.1А		0101000020E61000004DA1F31ABB0A484091F12895F0864B40
94152	7	64	1742	28511	78421	\N	55.104166999999997	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Черки-Кильдуразы, пр-т.Иванова, д.5		0101000020E61000008FA7E507AE22484045292158558D4B40
94104	7	64	1742	26366	78992	\N	55.080224999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Черки-Дюртиле, ул.Советская, д.5		0101000020E610000006A1BC8FA32D48402AA913D0448A4B40
94150	7	64	1742	28469	78427	\N	55.049452000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Черки-Гришино, ул.Озерная, д.1		0101000020E610000043A9BD88B6254840645C717154864B40
94110	7	64	1742	26653	78990	\N	55.050246000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Тойгильды, ул.Октябрьская, д.2А		0101000020E610000088F6B182DF0648409E60FF756E864B40
94098	7	64	1742	26075	78978	\N	54.938229	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Тингаш, ул.Комсомольская, д.2		0101000020E6100000D21DC4CE141A484053944BE317784B40
94149	7	64	1742	28378	79013	\N	54.937924000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Тимбаево, ул.Мира, д.14		0101000020E61000005C3D27BD6FF447401711C5E40D784B40
94122	7	64	1742	27151	79031	\N	54.808490471847897	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Татарское Пимурзино, ул.Вахитова, д.15А	Россия, республика Татарстан, Буинский район, село Татарское Пимурзино	0101000020E610000038F3AB39401E48404F92AE997C674B40
94108	7	64	1742	26564	78986	\N	55.031782999999997	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Беловолжка Татарская, ул.Мира, д.19		0101000020E61000003B394371C70D4840CDC8207711844B40
94156	7	64	1742	28745	79022	\N	54.742142999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Таковары, ул.Школьная, д.12		0101000020E6100000A6B6D4415E0F484048FAB48AFE5E4B40
94115	7	64	1742	26840	78999	\N	55.036833999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Степные Енали, ул.Школьная, д.1		0101000020E610000034A0DE8C9A1B4840C0B0FCF9B6844B40
94103	7	64	1742	26279	78981	\N	55.005066999999997	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Степановка, ул.Колхозная, д.11		0101000020E6100000DE054A0A2C304840F8A41309A6804B40
94143	7	64	1742	28104	69263	\N	54.8817274976102	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Старый Студенец, ул.Школьная, д.4	Россия, республика Татарстан, Буинский район, село Старый Студенец	0101000020E6100000D236FE446521484006802A6EDC704B40
94144	7	64	1742	28191	79010	\N	54.839582	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Старые Тинчали, ул.Советская, д.15		0101000020E610000074081C0934144840B727486C776B4B40
94124	7	64	1742	27278	79006	\N	54.773133000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Старые Мертли, ул.Школьная, д.6		0101000020E61000003CDC0E0D8B294840AC3AAB05F6624B40
94106	7	64	1742	26413	78985	\N	54.805016999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Старые Бурундуки, ул.Колхозная, д.53		0101000020E6100000365CE49EAE324840ADDC0BCC0A674B40
94146	7	64	1742	28245	79019	\N	54.849691	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Старостуденецкие Выселки, ул.Школьная, д.17		0101000020E6100000A0168387690D48404F5AB8ACC26C4B40
94142	7	64	1742	28031	78969	\N	54.947718000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Сорок-Сайдак, ул.Центральная, д.2		0101000020E61000004D486B0C3AE947404FEACBD24E794B40
94141	7	64	1742	28031	78969	\N	54.947718000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Сорок-Сайдак, ул.Центральная, д.10		0101000020E61000004D486B0C3AE947404FEACBD24E794B40
94147	7	64	1742	28289	79015	\N	54.842967999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Сарсаз, ул.Клубная, д.6		0101000020E6100000D7506A2FA20548408AC91B60E66B4B40
94119	7	64	1742	27026	79001	\N	54.842334999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Русские Кищаки, ул.Садовая, д.2		0101000020E6100000CA1649BBD139484059A31EA2D16B4B40
94138	7	64	1742	27936	78426	\N	54.954484042775	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Рунга, ул.Советская, д.6	Россия, республика Татарстан, Буинский район, село Рунга	0101000020E6100000F9669B1BD313484013471E882C7A4B40
94096	7	64	1742	26027	78982	\N	54.744253	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Раково, ул.Клубная, д.6		0101000020E610000047054EB6811D48409679ABAE435F4B40
94056	7	64	1742	24120	78917	\N	54.977573	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.Плодопитомник, ул.Верхняя, д.4		0101000020E61000005DA5BBEB6C2E4840EF39B01C217D4B40
94137	7	64	1742	27852	79008	\N	55.034104999999997	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Нурлаты, ул.Центральная, д.14		0101000020E6100000711DE38A8B154840A6D0798D5D844B40
94134	7	64	1742	27714	79014	\N	55.070751999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Новые Чечкабы, ул.Свободы, д.32А		0101000020E61000004AD05FE8111148403410CB660E894B40
94131	7	64	1742	27581	78416	\N	54.817250999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Новые Тинчали, ул.Ленина, д.30		0101000020E6100000882B67EF8CFE4740C8CF46AE9B684B40
94121	7	64	1742	27116	79003	\N	54.816955	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Новые Мертли, ул.Победы, д.13Б		0101000020E61000001BD7BFEB33194840DFA63FFB91684B40
94157	7	64	1742	28755	79020	\N	54.738422	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Новоселки, ул.Шоссейная, д.2		0101000020E6100000FD86890629164840CE52B29C845E4B40
94133	7	64	1742	27677	79007	\N	54.818869999999997	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Новая Цильна, ул.О.Кошевого, д.18А		0101000020E6100000FD2D01F8A7F4474077D66EBBD0684B40
94129	7	64	1742	27482	78410	\N	55.013306999999998	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Нижний Наратбаш, ул.Советская, д.2А		0101000020E6100000D177B7B24429484068E7340BB4814B40
93622	7	64	1742	26142	78753	\N	54.933836954753801	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Мулланур-Вахитово, ул.М.Вахитова, д.35		0101000020E61000001938A0A52B104840BA6587F887774B40
94099	7	64	1742	26142	78968	\N	54.933590000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Мулланур Вахитов, ул.Колхозная, д.1		0101000020E6100000CEDF844204104840B3EF8AE07F774B40
94127	7	64	1742	27389	78406	\N	54.936584000000003	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Мокрая Савалеевка, ул.Молодежная, д.49		0101000020E6100000E695EB6D330148407BFA08FCE1774B40
94126	7	64	1742	27374	78230	\N	54.938921999999998	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Мещеряково, ул.М.Джалиля, д.109		0101000020E61000008F705AF0A223484059BF99982E784B40
94125	7	64	1742	27284	78404	\N	54.955365	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Малая Буинка, ул.Молодежная, д.33А		0101000020E6100000056A3178981E48401C5F7B66497A4B40
94151	7	64	1742	61453	79198	\N	55.054427853233904	Республика Татарстан (Татарстан), Буинский муниципальный район, пос. ж/д разъезда Лащи, ул.Центральная, д.3	Россия, республика Татарстан, Буинский район, село Лащи	0101000020E6100000E97DE36BCF1E48404CFE277FF7864B40
93782	7	64	1742	61454	79361	\N	55.105443999999999	Республика Татарстан (Татарстан), Апастовский район, с.Тявгельдино, ул.Школьная, д.1А	Россия, республика Татарстан, Буинский район, село Кыр-Тавгельдино	0101000020E610000066BD18CA891248409BC761307F8D4B40
94135	7	64	1742	61454	79199	\N	55.103940430291601	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Кыр-Тавгильдино, ул.Клубная, д.6А	Россия, республика Татарстан, Буинский район, село Кыр-Тавгельдино	0101000020E6100000E014562AA8124840855FEAE74D8D4B40
94154	7	64	1742	61407	79139	\N	55.065217809385203	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Черки-Кощаково, ул.Мирная, д.2	Россия, республика Татарстан, Буинский район, село КощаковоЧерки	0101000020E61000005E9ECE15A5244840268E3C1059884B40
21778	7	61	64	1955	64065	\N	54.362189999999998	село Шаймуратово, Партизанская, 36		0101000020E61000005E6743FE99054C401878EE3D5C2E4B40
94123	7	64	1742	27208	79004	\N	54.795862	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Кошки-Шемякино, ул.Революционная, д.1		0101000020E61000001D75745C8D224840881057CEDE654B40
94120	7	64	1742	27106	79002	\N	54.834200000000003	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Кошки-Теняково, ул.Школьная, д.2А		0101000020E6100000840F255AF21C48405F29CB10C76A4B40
94118	7	64	1742	27021	79000	\N	54.866782000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Козловка, ул.Широкая, д.22		0101000020E61000005DC0CB0C1B31484078616BB6F26E4B40
94117	7	64	1742	26946	78394	\N	54.882607999999998	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Кият, ул.Молодежная, д.9		0101000020E6100000A0A696ADF53348400F98874CF9704B40
94148	7	64	1742	26192	79018	\N	54.924728000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Каменный Брод, ул.Центральная, д.21		0101000020E610000065E1EB6B5DF0474006D9B27C5D764B40
94101	7	64	1742	26192	78984	\N	54.924728000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Каменный Брод, ул.Ленина, д.17		0101000020E610000065E1EB6B5DF0474006D9B27C5D764B40
94114	7	64	1742	26830	78995	\N	55.008676000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Кайбицы, ул.Мирная, д.12		0101000020E6100000C0EB33677D1848404B21904B1C814B40
94153	7	64	1742	28568	79017	\N	55.076174000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Черки-Ишмяково, ул.Московская, д.31		0101000020E61000008847E2E5E92048401B67D311C0894B40
94111	7	64	1742	26664	78993	\N	55.085332000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Исаково, ул.Зеленая, д.31		0101000020E61000006AA164726AF74740B1A6B228EC8A4B40
94128	7	64	1742	27429	79012	\N	54.937545999999998	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Ембулатово, ул.Пролетарская, д.10		0101000020E61000000589EDEE01FA4740703FE08101784B40
94159	7	64	1742	28859	79023	\N	54.878236000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Вольный Стан, ул.Калинина, д.73		0101000020E610000013807F4A95E64740BE1589096A704B40
94116	7	64	1742	26893	79005	\N	55.020207999999997	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Верхний Наратбаш, ул.Центральная, д.45		0101000020E6100000E129E44A3D1F48400C8FFD2C96824B40
94107	7	64	1742	26500	78996	\N	55.031917	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Верхние Лащи, ул.Центральная, д.1		0101000020E610000085ECBC8DCD064840DD9733DB15844B40
94105	7	64	1742	26368	78386	\N	54.810175000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Бюрганы, ул.Ленина, д.43		0101000020E61000005CCCCF0D4D274840B6847CD0B3674B40
94102	7	64	1742	26229	78983	\N	55.051608000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Большое Фролово, ул.Гагарина, д.7		0101000020E6100000853E58C686344840221B48179B864B40
94130	7	64	1742	27574	79016	\N	54.986966000000002	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Большая Карланга, ул.Овражная, д.13А		0101000020E610000097749483D9344840C921E2E6547E4B40
94100	7	64	1742	26147	78979	\N	55.131011999999998	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Бик-Утеево, ул.Центральная, д.25		0101000020E61000003483F8C08E0B484018B14F00C5904B40
94136	7	64	1742	27845	79009	\N	55.081724999999999	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Ахмаметьево, ул.Центральная, д.16А		0101000020E61000001A18795913174840FF21FDF6758A4B40
94112	7	64	1742	26754	78994	\N	55.090119000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Атабай-Анкебе, ул.Центральная, д.17		0101000020E6100000EACF7EA488FC4740C6DFF604898B4B40
94097	7	64	1742	26030	78399	\N	54.933796000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Альшихово, ул.Правды, д.48А		0101000020E6100000E5266A696E1548405C9198A086774B40
94094	7	64	1742	25936	78377	\N	54.752598999999996	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Альшеево, ул.Центральная, д.18А		0101000020E6100000D461855B3E2448404B00FE2955604B40
94113	7	64	1742	26755	78997	\N	55.097414000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Алькеево, ул.Дружбы, д.14		0101000020E61000007EE19524CF0148401616DC0F788C4B40
94092	7	64	1742	25798	78977	\N	55.181657000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, д.Аксу, ул.Центральная, д.116А		0101000020E6100000174850FC180B4840740B5D8940974B40
94091	7	64	1742	25758	78367	\N	54.945754000000001	Республика Татарстан (Татарстан), Буинский муниципальный район, с.Адав-Тулумбаево, ул.Советская, д.19		0101000020E61000002504ABEAE52B4840D50792770E794B40
94071	7	64	1683	24834	78351	\N	54.343620000000001	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Татарская-Дымская, ул. Ворошилова, д.1А		0101000020E61000008A22A46E677B4A4032207BBDFB2B4B40
94047	7	64	1683	23610	79340	\N	54.567247094841697	423231, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Бугульминский муниципальный район, д.Таллы-Буляк, ул.Новая (здание Дома Культуры), д.18	Россия, республика Татарстан, Бугульминский район, село Таллы-Буляк	0101000020E61000004DF73AA92F5D4A4087E0B88C9B484B40
94065	7	64	1683	24547	78928	\N	54.708185999999998	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Старое Сумароково, ул.Молодежная, д.6		0101000020E6100000EC33677DCA734A4016BEBED6A55A4B40
94069	7	64	1683	24739	78946	\N	54.457458000000003	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Старое Исаково, ул.Советская, д.46		0101000020E6100000268E3C1059824A4094A5D6FB8D3A4B40
55193	7	63	1108	49497	54391	\N	54.436413000000002	рабочий поселок Комсомольский, микрорайон-1, 18		0101000020E6100000CB2F833122E946404E469561DC374B40
94066	7	64	1683	24631	78940	\N	54.424911000000002	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Спасское, ул.Спасская, д.16		0101000020E610000044F9821612784A40F75AD07B63364B40
94063	7	64	1683	24437	78972	\N	54.656084	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Соколка, ул.Полевая, д.4А		0101000020E6100000FD885FB1866F4A40E5B67D8FFA534B40
94060	7	64	1683	24324	78922	\N	54.699269000000001	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Ростовка, ул.Центральная, д.3		0101000020E6100000522976340E874A40A60D87A581594B40
94048	7	64	1683	23740	78318	\N	54.564042000000001	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.Прогресс, ул.Ягофарова, д.10		0101000020E61000003526C45C52634A4004C93B8732484B40
1456	7	64	1683	24422	11709	\N	54.636496000000001	п.Подгорный, ул.Центральная, д.22 А	Россия, республика Татарстан, Бугульминский район, село Подгорный	0101000020E610000076340EF5BB724A40750470B378514B40
94062	7	64	1683	24422	78358	\N	54.634173348934901	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.Подгорный, ул.Луговая, д.5	Россия, республика Татарстан, Бугульминский район, село Подгорный	0101000020E6100000A510C8258E724A40CB80B3942C514B40
94053	7	64	1683	23935	78907	\N	54.673518000000001	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.Победа, ул.Пушкина, д.23		0101000020E6100000645930F147554A4038A27BD635564B40
94061	7	64	1683	24325	78231	\N	54.3921733031017	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Петровка, ул.Центральная, д.8	Россия, республика Татарстан, Бугульминский район, село Петровка	0101000020E6100000F778211D1E644A40E6AF90B932324B40
94059	7	64	1683	24241	78916	\N	54.649442999999998	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Новое Сумароково, ул.Советская, д.13		0101000020E610000078F17EDC7E834A40DDCEBEF220534B40
94057	7	64	1683	24132	78971	\N	54.571067999999997	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Новая Александровка, ул.Центральная, д.2В		0101000020E6100000ADA23F34F3744A4064E597C118494B40
94058	7	64	1683	24174	78333	\N	54.411123000000003	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Наратлы, ул.Советская, д.28А		0101000020E6100000C520B07268894A4014D1AFAD9F344B40
94055	7	64	1683	24033	69159	\N	54.510970999999998	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Малая Бугульма, ул.Совхозная, д.7Б		0101000020E610000099D4D00660714A402A1A6B7F67414B40
94054	7	64	1683	24025	78328	\N	54.743062999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Кудашево, ул.Советская, д.66А		0101000020E6100000FACF9A1F7F4D4A400FEF39B01C5F4B40
94052	7	64	1683	23872	78325	\N	54.557203000000001	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Ключи, ул.Озерная, д.1А		0101000020E610000036E7E099D0824A40D61D8B6D52474B40
94072	7	64	1683	23446	75331	\N	54.700454999999998	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.г.т.Карабаш, ул. Школьная, д.4		0101000020E6100000E2016553AE484A40EBA86A82A8594B40
94042	7	64	1683	23446	69150	\N	54.691997251035701	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.г.т.Карабаш, ул.Вахитова, д.23	Россия, республика Татарстан, Бугульминский район, поселок Карабаш	0101000020E6100000384888F2054B4A400EF7915B93584B40
94049	7	64	1683	23743	78315	\N	54.443475999999997	Республика Татарстан (Татарстан), Бугульминский муниципальный район, д.Зеленая Роща, ул.Шоссейная, д.9А		0101000020E6100000AE484C50C35F4A40CB4752D2C3384B40
94050	7	64	1683	23820	78909	\N	54.501592000000002	Республика Татарстан (Татарстан), Бугульминский муниципальный район, д.Забугоровка, ул.Ленина, д.33А		0101000020E6100000AD2F12DA72644A40B6F7A92A34404B40
94067	7	64	1683	24638	78937	\N	54.472011000000002	Республика Татарстан (Татарстан), Бугульминский муниципальный район, д.Ефановка, ул.Советская, д.16		0101000020E6100000302DEA93DC6B4A40172D40DB6A3C4B40
94070	7	64	1683	24781	78340	\N	54.501137999999997	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.Восточный, ул.Гафиатуллина, д.8Б		0101000020E61000007A6D3656627A4A4034643C4A25404B40
94045	7	64	1683	23560	71676	\N	54.574716000000002	Республика Татарстан (Татарстан), Бугульминский муниципальный район, п.Березовка, ул.Центральная, д.5		0101000020E61000000377A04E79644A40753E3C4B90494B40
94064	7	64	1683	24491	78923	\N	54.608378999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, д.Батыр, ул.Школьная, д.1А		0101000020E610000090F7AA95096F4A405E49F25CDF4D4B40
94043	7	64	1683	23451	78647	\N	54.372041000000003	Республика Татарстан (Татарстан), Бугульминский муниципальный район, с.Андреевка, ул.Ключевская, д.24		0101000020E61000006211C30E634C4A40B5E21B0A9F2F4B40
1450	7	64	1683	40934	11687	\N	54.415820478669303	с.Акбаш, ул.Школьная, д.17	Россия, республика Татарстан, Бугульминский район, село Акбаш	0101000020E6100000FE5F75E4484B4A40E882FA9639354B40
94017	7	64	6902	40336	9866	\N	54.531632999999999	Республика Татарстан (Татарстан), Бугульминский муниципальный район, город Бугульма, ул.Гафиатуллина, д.20А		0101000020E610000026E5EE737C664A40B83CD68C0C444B40
94000	7	64	1620	21527	78899	\N	56.380797000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, д.Ярак Чурма, ул.М.Горького, д.28		0101000020E6100000185DDE1CAE1349401CB5C2F4BD304C40
94004	7	64	1620	21672	78301	\N	56.410693999999999	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Янгулово, ул.Дружбы, д.1		0101000020E61000008EE733A0DE324940EB54F99E91344C40
93998	7	64	1620	21390	78299	\N	56.465877999999996	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Шишинер, ул.Г.Тукая, д.60		0101000020E6100000994528B6823E494083F6EAE3A13B4C40
93989	7	64	1620	20976	78891	\N	56.512304999999998	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Чутай, ул.В.Булатова, д.50		0101000020E6100000477364E597414940E449D23593414C40
94001	7	64	1620	21531	71499	\N	56.526150000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Ципья, ул.Ленина, д.12		0101000020E6100000AF5DDA70582649402C6519E258434C40
93997	7	64	1620	21349	78895	\N	56.470930000000003	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Тюнтер, ул.Колхозная, д.7		0101000020E610000034A14962491F4940475A2A6F473C4C40
94005	7	64	1620	21738	78910	\N	56.424207000000003	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Старый Кушкет, ул.Дружбы, д.18а		0101000020E61000001FDB32E02C294940FDDD3B6A4C364C40
93992	7	64	1620	21122	75317	\N	56.365716999999997	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Старая Салаусь, ул.Советская, д.12		0101000020E6100000C91CCBBBEA294940AD4B8DD0CF2E4C40
93996	7	64	1620	21342	78896	\N	56.446727000000003	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Средний Кушкет, ул.Центральная, д.6		0101000020E6100000BFEE74E789234940BF9EAF592E394C40
93994	7	64	1620	21254	78295	\N	56.476616999999997	Республика Татарстан (Татарстан), Балтасинский муниципальный район, д.Смаиль, ул.Баумана, д.50		0101000020E6100000404D2D5BEB394940DBDB2DC9013D4C40
93990	7	64	1620	21061	78290	\N	56.593324000000003	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Пижмар, ул.С.Муликова, д.19		0101000020E6100000A2F0D93A382E494049F7730AF24B4C40
93988	7	64	1620	20968	78286	\N	56.527748000000003	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Нуринер, ул.Ленина, д.97		0101000020E61000007D3F355EBA3B4940C443183F8D434C40
94010	7	64	1620	20806	71513	\N	56.335937615498402	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Норма, ул.Казанская, д.11	Россия, республика Татарстан, Балтасинский район, село Норма	0101000020E6100000EE3D5C72DC234940E8BD3104002B4C40
93986	7	64	1620	20806	71513	\N	56.335366	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Норма, ул.Казанская, д.1		0101000020E61000008FC6A17E172449405D18E945ED2A4C40
93993	7	64	1620	21177	78289	\N	56.373624	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Нижняя Сосна, ул.Героя Сарвара, д.2		0101000020E6100000454B1E4FCB1D4940178046E9D22F4C40
93983	7	64	1620	20648	78277	\N	56.333793999999997	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Нижняя Кня, ул.Школьная, д.5а		0101000020E61000000E68E90AB6034940EECC04C3B92A4C40
94006	7	64	1620	21826	78302	\N	56.347360000000002	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Малые Лызи, ул.Центральная, д.1		0101000020E6100000F9BB77D49812494023F8DF4A762C4C40
93981	7	64	1620	20550	78893	\N	56.445428999999997	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Кушкетбаш, ул.Центральная, д.15		0101000020E61000005C035B255816494051D845D103394C40
93984	7	64	1620	20752	78276	\N	56.610210000000002	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Кугунур, ул.Кирова, д.103б		0101000020E6100000A583F57F0E1F494099D87C5C1B4E4C40
93987	7	64	1620	20869	78221	\N	56.305844	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Килеево, ул.Г.Тукая, д.33/3		0101000020E6100000857AFA08FC254940C3D66CE525274C40
93982	7	64	1620	20642	78279	\N	56.343333999999999	Республика Татарстан (Татарстан), Балтасинский муниципальный район, д.Карадуван, ул.Сибирский Тракт, д.30		0101000020E610000004E44BA8E00C49406CCD565EF22B4C40
93985	7	64	1620	20762	78281	\N	56.593592000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, д.Дурга, ул.Парковая, д.2а		0101000020E6100000A5A2B1F677264940689599D2FA4B4C40
93999	7	64	1620	21444	78967	\N	56.372084000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, д.Верхний Шубан, ул.Центральная, д.31		0101000020E610000085EB51B81E094940B4AED172A02F4C40
93980	7	64	1620	20484	78280	\N	56.488447000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Верхний Субаш, ул.К.Маркса, д.5		0101000020E6100000D734EF38450F4940276A696E853E4C40
93995	7	64	1620	21257	78312	\N	56.431251000000003	Республика Татарстан (Татарстан), Балтасинский муниципальный район, д.Бурнак, ул.Татарстана, д.4		0101000020E6100000C8B4368DED31494004AF963B33374C40
93978	7	64	1620	20422	78271	\N	56.299695999999997	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Бурбаш, ул.Ф.Шакирова, д.18		0101000020E61000007B6649809A344940FA5E43705C264C40
94008	7	64	1620	59178	68839	\N	56.345379000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, пгт.Балтаси, ул.Наримана, д.108		0101000020E6100000F59F353FFE1A4940D3DC0A61352C4C40
94009	7	64	1620	20291	68872	\N	56.345379000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, пгт.Балтаси, ул.Ленина, д.45		0101000020E6100000F59F353FFE1A4940D3DC0A61352C4C40
93977	7	64	1620	20291	68872	\N	56.345379000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, пгт.Балтаси, ул.Ленина, д.154		0101000020E6100000F59F353FFE1A4940D3DC0A61352C4C40
94007	7	64	1620	20291	68717	\N	56.345379000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, пгт.Балтаси, ул.К.Маркса, д.7		0101000020E6100000F59F353FFE1A4940D3DC0A61352C4C40
93991	7	64	1620	21067	78973	\N	56.634985999999998	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Атня, ул.Комсомола, д.22		0101000020E61000009A05DA1D522E49407CB5A33847514C40
94002	7	64	1620	21616	78912	\N	56.546520000000001	Республика Татарстан (Татарстан), Балтасинский муниципальный район, с.Арбор, ул.Татарстана, д.53		0101000020E6100000D84AE82E891B4940124E0B5EF4454C40
93965	7	64	1546	61366	78884	\N	54.214657636066498	Республика Татарстан (Татарстан), Бавлинский муниципальный район, п.Новозареченск, ул.Вахитова, д.15	Россия, республика Татарстан, Бавлинский район	0101000020E610000042226DE34FB04A4092E9D0E9791B4B40
93966	7	64	1546	19724	78877	\N	54.097597	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Шалты, ул.Советская, д.56а		0101000020E6100000641EF98381B94A400798F90E7E0C4B40
93967	7	64	1546	19730	78873	\N	54.042521000000001	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Хансверкино, ул.Советская, д.31		0101000020E6100000BE89213999AE4A405532005471054B40
93975	7	64	1546	20179	78885	\N	54.300711999999997	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Удмуртские Ташлы, ул.Ленина, д.61а		0101000020E6100000880E812381924A40E3C116BB7D264B40
93954	7	64	1546	19056	78966	\N	54.493676000000001	Республика Татарстан (Татарстан), Бавлинский муниципальный район, д.Уба, ул.Центральная, д.25		0101000020E6100000878A71FE26B44A40F96871C6303F4B40
93956	7	64	1546	61421	79156	\N	54.4881107600362	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Татарские Ташлы, ул.Подгорная, д.9а	Россия, республика Татарстан, Бавлинский район, село Ташлы	0101000020E610000044DD0720B59D4A40B0E8D66B7A3E4B40
93971	7	64	1546	19932	79318	\N	54.129238000000001	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Татарский Кандыз, ул.Советская, д.68		0101000020E6100000F4E0EEACDD904A4042B3EBDE8A104B40
93962	7	64	1546	19512	78066	\N	54.317568999999999	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Татарская Тумбарла, ул.Ленина, д.51		0101000020E61000007D09151C5EA24A40999CDA19A6284B40
93969	7	64	1546	19840	78902	\N	54.101270790225101	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Салихово, ул.Калинина, д.21	Россия, республика Татарстан, Бавлинский район, село Салихово	0101000020E6100000562AA8A8FAA54A404084B872F60C4B40
93976	7	64	1546	20286	78268	\N	54.361035999999999	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Потапово-Тумбарла, ул.Советская, д.35		0101000020E6100000EBFF1CE6CB954A40DE567A6D362E4B40
93973	7	64	1546	20056	78274	\N	54.189751000000001	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Поповка, ул.Центральная, д.14		0101000020E6100000F8359204E19E4A4010B1C1C249184B40
93963	7	64	1546	19523	78269	\N	54.256813000000001	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Покровский Урустамак, ул.Советская, д.65б		0101000020E6100000A27A6B60ABB04A400518963FDF204B40
93968	7	64	1546	19780	78878	\N	54.070227000000003	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Новые Чути, ул.Школьная, д.11	Россия, республика Татарстан, Бавлинский район, село Новые Чути	0101000020E6100000CE5147C7D5AA4A40EA25C632FD084B40
93964	7	64	1546	19617	78883	\N	54.198146999999999	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Николашкино, ул.Советская, д.38а		0101000020E6100000942F682101AF4A40776682E15C194B40
93960	7	64	1546	19410	78988	\N	54.475453000000002	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Муртаза, ул.Школьная, д.13		0101000020E61000000F7C0C569C904A407EE4D6A4DB3C4B40
93959	7	64	1546	19351	78874	\N	54.539171000000003	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Крым-Сарай, ул.Советская, д.59б		0101000020E610000072E0D572678E4A40CFF9298E03454B40
93953	7	64	1546	19011	75315	\N	54.415596999999998	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Кзыл-Яр, ул.Советская, д.15а		0101000020E6100000B3B6291E17B14A4069A8514832354B40
93961	7	64	1546	19415	78222	\N	54.329918999999997	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Исергапово, ул.Советская, д.108		0101000020E610000020D5B0DF13B14A401DAA29C93A2A4B40
93972	7	64	1546	20044	78886	\N	54.179744999999997	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Верхняя Фоминовка, ул.Советская, д.91а		0101000020E61000008E3EE60302894A404C4F58E201174B40
93958	7	64	1546	19266	79321	\N	54.400657000000002	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Васькино-Туйралы, ул.Школьная, д.25б		0101000020E6100000F01989D008964A40EDF483BA48334B40
93947	7	64	1546	60491	75074	\N	54.389694179164103	Республика Татарстан (Татарстан), Бавлинский муниципальный район, город Бавлы, Горюнова, 2 Б	Россия, республика Татарстан, поселок Бавлы	0101000020E6100000C8B1F50CE1A24A4045B9347EE1314B40
93974	7	64	1546	20113	78888	\N	54.242882999999999	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Алексеевка, ул.Советская, д.51г		0101000020E61000009AB67F65A5994A408FE046CA161F4B40
93955	7	64	1546	19116	78266	\N	54.466700000000003	Республика Татарстан (Татарстан), Бавлинский муниципальный район, с.Александровка, ул.Школьная, д.2		0101000020E61000006C5F402FDCA34A4088855AD3BC3B4B40
93928	7	64	1481	61532	79342	\N	56.333627846793	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Таш-Чишма, ул.М.Горького, д.29	Россия, республика Татарстан, Атнинский район, село Татарская Чишма	0101000020E6100000C05DF6EB4ECB4840D3838252B42A4C40
93940	7	64	1481	18349	78867	\N	56.368015999999997	Республика Татарстан (Татарстан), Атнинский муниципальный район, д.Старый Югуп, ул.Зелень, д.42		0101000020E61000003691990B5CB84840CE33F6251B2F4C40
93938	7	64	1481	32507	78849	\N	56.343234000000002	Республика Татарстан (Татарстан), Атнинский муниципальный район, д.Старый Узюм, ул.Татарстан, д.18		0101000020E610000091D6187442C8484009707A17EF2B4C40
93939	7	64	1481	18257	78852	\N	56.363947000000003	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Новые Шаши, ул.Молодежная, д.15		0101000020E61000001DE8A1B60DBB4840193DB7D0952E4C40
93931	7	64	1481	17872	78991	\N	56.288446	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Нижний Куюк, ул.Татарстан, д.71А		0101000020E6100000E882FA9639A54840BD546CCCEB244C40
93916	7	64	1481	17164	78260	\N	56.235911000000002	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Нижняя Береске, ул.Чишмяле, д.10А		0101000020E610000081E84999D4AA484022E2E654321E4C40
93915	7	64	1481	17072	78788	\N	56.229336000000004	Республика Татарстан (Татарстан), Атнинский муниципальный район, д.Малая Атня, ул.Советская, д.31Б		0101000020E6100000FD885FB186BB4840D2E5CDE15A1D4C40
93930	7	64	1481	61468	79217	\N	56.373807043467998	Республика Татарстан (Татарстан), Атнинский муниципальный район, д.Кзыл Утар, ул.Ленина, д.4	Россия, республика Татарстан, Атнинский район, село Кызыл-Утар	0101000020E6100000E7FC14C781C74840080264E8D82F4C40
93929	7	64	1481	17781	78823	\N	56.345489000000001	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Кшклово, ул.Татарстан, д.7		0101000020E61000008D614ED026BF48405A10CAFB382C4C40
93924	7	64	1481	17518	78275	\N	56.317832000000003	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Кунгер, ул.Советская, д.33		0101000020E6100000BC2363B5F9BD4840A7CF0EB8AE284C40
93926	7	64	1481	17673	78822	\N	56.332161999999997	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Кулле-Кими, ул.Кирова, д.1А		0101000020E610000021C9ACDEE1A44840AA7CCF48842A4C40
93925	7	64	1481	17583	78259	\N	56.29533	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Кубян, ул.Школьная, д.2		0101000020E61000001F317A6EA1B148408BC3995FCD254C40
93937	7	64	1481	18119	79344	\N	56.287391999999997	422753, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Кошар, ул.Татарстан (здание школы), д.49		0101000020E6100000E9EE3A1BF2C14840E690D442C9244C40
93923	7	64	1481	17465	78814	\N	56.154260000000001	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Коморгузя, ул.Комсомольская, д.11		0101000020E610000082E2C798BBBA48405D8AABCABE134C40
93941	7	64	1481	18362	78868	\N	56.422978000000001	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Ключи Сап, ул.Тукая, д.70		0101000020E6100000BC04A73E90B64840B876A22424364C40
93921	7	64	1481	17362	79307	\N	56.308365000000002	422740, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Каенсар, ул.Мира (здание библиотеки), д.39		0101000020E610000036069D103AAA4840931D1B8178274C40
93927	7	64	1481	17676	78819	\N	56.325778999999997	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Ислейтар, ул.Колхозная, д.7		0101000020E6100000DCBA9BA73A9448409E5C5320B3294C40
93919	7	64	1481	17214	79316	\N	56.299036000000001	Республика Татарстан (Татарстан), Атнинский муниципальный район, д.Дусюм, ул.Ш.Камала, д.46		0101000020E6100000DB8B683BA6B84840D029C8CF46264C40
93922	7	64	1481	17451	78962	\N	56.128681	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Верхняя Серда, ул.Узяк, д.22		0101000020E6100000D671FC5069C84840EC4E779E78104C40
93933	7	64	1481	17974	78649	\N	56.311576000000002	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Верхний Куюк, ул.Тукая, д.59А		0101000020E6100000B4CC22145BA14840F81BEDB8E1274C40
93934	7	64	1481	18062	78265	\N	56.239933000000001	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Большой Менгер, ул.Советская, д.11		0101000020E6100000185FB4C70BC94840971DE21FB61E4C40
93917	7	64	1481	17174	78800	\N	56.221443999999998	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Большие Берези, ул.Большая, д.37А		0101000020E6100000EA04341136A248409DF2E846581C4C40
93913	7	64	1481	16979	75309	\N	56.254652	Республика Татарстан (Татарстан), Атнинский муниципальный район, с.Большая Атня, ул.Советская, д.2		0101000020E6100000357D76C075B9484035EECD6F98204C40
93935	7	64	1481	18073	78824	\N	56.209496000000001	Республика Татарстан (Татарстан), Атнинский муниципальный район, д.Бахтияр, ул.Ирек, д.2		0101000020E6100000643C4A253CCD48404852D2C3D01A4C40
93912	7	64	1263	16926	78767	\N	55.9864077612146	Республика Татарстан(Татарстан), Арский муниципальный район, с.Янга-Сала, ул.Центральная, д.18	Россия, республика Татарстан, Арский район, село Янга-Сала	0101000020E6100000A1F831E6AEFD4840A2410A9E42FE4B40
93908	7	64	1263	16779	78258	\N	56.390813000000001	Республика Татарстан(Татарстан), Арский муниципальный район, с.Шушмабаш, ул.Школьная, д.1в		0101000020E6100000361D01DC2CF0484003ED0E2906324C40
93862	7	64	1263	14527	78711	\N	56.477418	Республика Татарстан(Татарстан), Арский муниципальный район, с.Шурабаш, ул.Гагарина, д.17а		0101000020E6100000C89A9141EEDA4840C84274081C3D4C40
93864	7	64	1263	14575	78713	\N	56.489843999999998	Республика Татарстан(Татарстан), Арский муниципальный район, с.Шура, ул.Х.Такташа, д.35		0101000020E61000006CCB80B394D6484027124C35B33E4C40
93889	7	64	1263	15782	78741	\N	55.960859999999997	Республика Татарстан(Татарстан), Арский муниципальный район, с.Штырь, ул.Советская, д.32		0101000020E61000002C616D8C9DE648406C04E275FDFA4B40
93911	7	64	1263	16880	78764	\N	56.401510000000002	Республика Татарстан(Татарстан), Арский муниципальный район, с.Шека, ул.Свердлова, д.19		0101000020E610000086032159C0EA48402C82FFAD64334C40
93853	7	64	1263	14076	79352	\N	56.359045999999999	422006, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Хасаншаих, ул.Комсомольская (здание Хасаншаихской школы), д.64		0101000020E61000009354A698830249403BE12538F52D4C40
93870	7	64	1263	14870	78717	\N	56.180005999999999	Республика Татарстан(Татарстан), Арский муниципальный район, с.Учили, ул.Тукая, д.77		0101000020E61000002FDE8FDB2FE74840B98AC56F0A174C40
93905	7	64	1263	16576	78758	\N	56.152861000000001	Республика Татарстан(Татарстан), Арский муниципальный район, с.Утар-Аты, ул.Кооперативная, д.22		0101000020E61000000CCA349A5CD44840BCEA01F390134C40
93899	7	64	1263	16259	79346	\N	56.233197826124801	422019, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, пос.Урняк, ул.Садовая (здание Лесхозской школы), д.10	Россия, республика Татарстан, Арский район, село Урняк	0101000020E6100000A12B11A8FEFF48400EBF9B6ED91D4C40
1024	7	64	1263	18510	11266	\N	56.081035	Республика Татарстан (Татарстан), Сабинский муниципальный район, с.Тюбяк, ул.Ленина, д.28		0101000020E61000002EABB019E0F648406A6AD95A5F0A4C40
93891	7	64	1263	61526	79310	\N	56.199407359017002	422039, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Ташкичу, ул.Ленина (здание Ташкичинской школы), д.36	Россия, республика Татарстан, Арский район, село Ташкич	0101000020E6100000F775E09C111D4940F7CB272B86194C40
93860	7	64	1263	14435	78707	\N	56.395437000000001	Республика Татарстан(Татарстан), Арский муниципальный район, с.Сюрда, ул.Советская, д.37		0101000020E61000009B38B9DFA1D248406E50FBAD9D324C40
93882	7	64	1263	15450	78726	\N	56.227589999999999	Республика Татарстан(Татарстан), Арский муниципальный район, д.Старый Яваш, ул.М.Джалиля, д.35а		0101000020E6100000A0C552245FE94840C5724BAB211D4C40
93880	7	64	1263	15396	79308	\N	56.196291000000002	422021, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Старый Кырлай, ул.Молодежная (здание Старокырлайской школы), д.1а	Россия, республика Татарстан, Арский район, село Старый Кырлай	0101000020E610000024B5503239F34840E4BF401020194C40
93867	7	64	1263	14723	78721	\N	56.250782000000001	Республика Татарстан(Татарстан), Арский муниципальный район, с.Старый Кишит, ул.Г.Сафиуллина, д.26а		0101000020E61000009D7FBBECD7D148407636E49F19204C40
93897	7	64	1263	16160	79317	\N	56.347973000000003	422030, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Старый Ашит, ул.Школьная (здание Староашитской школы), д.7	Россия, республика Татарстан, Арский район, село Старый Ашит	0101000020E610000097395D1613D548400D7217618A2C4C40
93904	7	64	1263	16555	78754	\N	56.198650000000001	Республика Татарстан(Татарстан), Арский муниципальный район, с.Старые Турнали, ул.Школьная, д.46		0101000020E6100000611A868F88FB4840DAACFA5C6D194C40
93888	7	64	1263	15678	79309	\N	56.030215088828598	422014, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Старое Чурилино, ул.Школьная (здание Старочурилинской школы), д.49	Россия, республика Татарстан, Арский район, село Старое Чурилино	0101000020E6100000CB2C42B115DE4840A06CCA15DE034C40
93878	7	64	1263	15286	78734	\N	56.106780000000001	Республика Татарстан(Татарстан), Арский муниципальный район, с.Средняя Серда, ул.Центральная, д.18а		0101000020E6100000EEEA556474CA4840F6EE8FF7AA0D4C40
93879	7	64	1263	15289	78254	\N	56.099992999999998	Республика Татарстан(Татарстан), Арский муниципальный район, д.Средняя Корса, ул.Молодежная, д.13		0101000020E61000008B87F71C580649401A6A1492CC0C4C40
93902	7	64	1263	16367	79292	\N	56.2498781090083	422019, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Средний Пшалым, ул.Вахитова (здание Среднепшалымской школы), д.22	Россия, республика Татарстан, Арский район, село Средний Пшалым	0101000020E61000006745D4449FF94840B5FE9600FC1F4C40
93875	7	64	1263	15096	78252	\N	56.106901000000001	Республика Татарстан(Татарстан), Арский муниципальный район, с.Смак-Корса, ул.Школьная, д.2		0101000020E610000036ACA92C0A0D4940717495EEAE0D4C40
93874	7	64	1263	15094	78724	\N	56.164306000000003	Республика Татарстан(Татарстан), Арский муниципальный район, с.Сикертан, ул.Школьная, д.77		0101000020E6100000E6AC4F3926114940AF44A0FA07154C40
93873	7	64	1263	15010	79306	\N	56.179285	422027, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Сиза, ул.Школьная (здание Сизинской школы), д.21		0101000020E61000003AAFB14B54194940E9D495CFF2164C40
93852	7	64	1263	13967	79282	\N	56.414268999999997	422006, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Пшенгер, ул.Чапаева (здание Пшенгерской школы), д.54		0101000020E6100000E57ADB4C85FE4840915F3FC406354C40
93909	7	64	1263	16788	79298	\N	56.427706999999998	422005, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Нуса, ул.Татарстана (здание Нусинской школы), д.31		0101000020E6100000EE0A7DB08CF5484098A25C1ABF364C40
93869	7	64	1263	14827	78248	\N	56.271191000000002	Республика Татарстан(Татарстан), Арский муниципальный район, с.Новый Кырлай, ул.Центральная, д.3		0101000020E61000009D9D0C8E92E548401AFCFD62B6224C40
93865	7	64	1263	14643	79329	\N	56.261111182706401	422034, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Новый Кишит, ул.Новая (здание Новокишитской школы), д.1	Россия, республика Татарстан, Арский район, село Новый Кишит	0101000020E6100000726E13EE95D548401CD0D2156C214C40
93859	7	64	1263	13862	78246	\N	56.401254328985502	422031, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Новый Кинер, ул.Советская (здание Новокинерского лицея), д.8	Россия, республика Татарстан, Арский район, село Новый Кинер	0101000020E6100000AEF4DA6CACDC4840D1B1834A5C334C40
93858	7	64	1263	13862	78246	\N	56.398395999999998	Республика Татарстан(Татарстан), Арский муниципальный район, с.Новый Кинер, ул.Советская, д.12		0101000020E6100000F06DFAB31FDB4840B96DDFA3FE324C40
93914	7	64	1263	17065	78782	\N	56.486116000000003	Республика Татарстан (Татарстан), Атнинский муниципальный район, д.Новая Атня, ул.Советская, д.7А		0101000020E6100000B62E35423FCF4840FB07910C393E4C40
93861	7	64	1263	14437	78699	\N	56.401907999999999	Республика Татарстан(Татарстан), Арский муниципальный район, с.Нижняя Ура, ул.Кирова, д.12		0101000020E61000001155F833BCCD48401900AAB871334C40
93883	7	64	1263	15505	78747	\N	56.139741074187697	Республика Татарстан(Татарстан), Арский муниципальный район, с.Нижние Метески, ул.Центральная, д.22	Россия, республика Татарстан, Арский район, село Нижние Метески	0101000020E6100000A3E6ABE463F5484086747808E3114C40
93877	7	64	1263	15210	78253	\N	56.11985	Республика Татарстан(Татарстан), Арский муниципальный район, д.Нижние Аты, ул.Центральная, д.37а		0101000020E6100000D97BF1457BD848407A36AB3E570F4C40
93856	7	64	1263	14243	79319	\N	56.113818000000002	422018, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Наласа, ул.Молодежная (здание Наласинской школы), д.91		0101000020E61000000FF10F5B7ADE48401BD99596910E4C40
93885	7	64	1263	15590	79285	\N	56.171332	422022, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Мендюш, ул.Татарстан (здание Мендюшской школы), д.48		0101000020E6100000838769DFDCF348400F61FC34EE154C40
93868	7	64	1263	14823	9893	\N	56.278218000000003	Республика Татарстан(Татарстан), Арский муниципальный район, с.Кшкар, ул.Мостовая, д.124		0101000020E6100000A7CF0EB8AED448404B94BDA59C234C40
93907	7	64	1263	15586	79295	\N	56.159619537029798	422017, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, д.Кошлауч, ул.Тукая (здание Кошлаучской школы), д.60	Россия, республика Татарстан, Арский район, село Кошлауч	0101000020E6100000B9196EC0E7C74840CDE49B6D6E144C40
93855	7	64	1263	14151	78245	\N	56.061373000000003	Республика Татарстан(Татарстан), Арский муниципальный район, с.Качелино, ул.Центральная, д.200		0101000020E6100000ED9C668176E74840C0ED0912DB074C40
93903	7	64	1263	16469	78256	\N	56.15448	Республика Татарстан(Татарстан), Арский муниципальный район, с.Казанбаш, ул.Кирова, д.50		0101000020E6100000B39943520BFD48406BF12900C6134C40
93871	7	64	1263	14929	78725	\N	56.157527999999999	Республика Татарстан(Татарстан), Арский муниципальный район, д.Верхние Верези, ул.Мостовая, д.2		0101000020E6100000666A12BC21E74840261AA4E029144C40
93906	7	64	1263	16621	78761	\N	56.148156999999998	Республика Татарстан(Татарстан), Арский муниципальный район, с.Верхние Аты, ул.Кооперативная, д.22		0101000020E6100000BA490C022BD9484034D6FECEF6124C40
93890	7	64	1263	15865	78965	\N	55.961016999999998	Республика Татарстан(Татарстан), Арский муниципальный район, с.Венета, ул.Школьная, д.3		0101000020E610000086915ED4EEF3484034F3E49A02FB4B40
93863	7	64	1263	61450	79195	\N	56.508264144204901	Республика Татарстан(Татарстан), Арский муниципальный район, с.Байкал, ул.Тукая, д.35	Россия, республика Татарстан, Арский район, село Байкал	0101000020E61000004278B471C4DE4840F8DD74CB0E414C40
93893	7	64	1263	15971	79336	\N	56.325854	422039, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Ашитбаш, ул.Пионерская (здание Ашитбашской школы), д.34		0101000020E610000015AC71361DE34840A9A27895B5294C40
93837	7	64	1263	13111	75238	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Школьная, д.2		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93844	7	64	1263	13111	78243	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Цветочная, д.22а		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93843	7	64	1263	13111	75308	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Трудовая, д.1		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93842	7	64	1263	13111	75306	\N	56.079594767944201	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Мостовая, д.15	Россия, республика Татарстан, Арский район, поселок Арск	0101000020E610000065FCFB8C0BF148406AF6402B300A4C40
93841	7	64	1263	13111	75306	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Мостовая, д.36		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93840	7	64	1263	13111	78239	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Комсомольская, д.47		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93839	7	64	1263	13111	75239	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Галактионова, д.28		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93838	7	64	1263	13111	75239	\N	56.086745999999998	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Галактионова, д.26		0101000020E6100000543BC3D496F048408787307E1A0B4C40
93832	7	64	1263	13111	68546	\N	56.101667284112999	Республика Татарстан(Татарстан), Арский муниципальный район, г.Арск, ул.Банковская, д.32	Россия, республика Татарстан, Арский район, поселок Арск	0101000020E61000005DA626C11BF048408D0A9C6C030D4C40
93849	7	64	1263	13864	79300	\N	56.388412000000002	422006, Адрес УИК и помещения для голосования: Республика Татарстан(Татарстан), Арский муниципальный район, с.Апазово, ул.Советская (здание Апазовской школы), д.28		0101000020E61000008C497F2F85FD4840DEAF027CB7314C40
55192	7	63	1108	49497	54344	\N	54.436413000000002	рабочий поселок Комсомольский, Театральная, 3		0101000020E6100000CB2F833122E946404E469561DC374B40
93895	7	64	1263	61361	78789	\N	56.335399203491399	Республика Татарстан(Татарстан), Арский муниципальный район, д.Ак-Чишма, ул.Школьная, д.5	Россия, республика Татарстан, Арский район, село Акчишма	0101000020E61000005DFC6D4F90EE4840390EBC5AEE2A4C40
93789	7	64	950	11098	78634	\N	55.311492000000001	Республика Татарстан (Татарстан), Апастовский район, с.Ясашно-Барышево, ул.Подгорная, д.12		0101000020E6100000399CF9D51C5A48409A7B48F8DEA74B40
93830	7	64	950	13021	78697	\N	55.260064	Республика Татарстан (Татарстан), Апастовский район, д.Эбалаково, ул.Х.Такташа, д.28		0101000020E610000020F12BD6702F4840F86EF3C649A14B40
93791	7	64	950	11143	79332	\N	55.275508000000002	422354, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Апастовский муниципальный район, с.Шонгуты, ул.Завражная (здание сельского ДК), д.5		0101000020E610000062F88898124B4840A8E49CD843A34B40
93812	7	64	950	12146	78644	\N	55.366388999999998	Республика Татарстан (Татарстан), Апастовский район, д.Шигаево, ул.Клубная, д.2		0101000020E61000002E55698B6B4248409C4EB2D5E5AE4B40
93816	7	64	950	12345	78687	\N	55.209313999999999	Республика Татарстан (Татарстан), Апастовский  район, д.Шемяково, ул.Центральная, д.44		0101000020E6100000D6011077F51E4840274C18CDCA9A4B40
93828	7	64	950	12896	78695	\N	55.295138999999999	Республика Татарстан (Татарстан), Апастовский район, с.Шамбулыхчи, ул.Г.Тукая, д.15		0101000020E6100000F793313ECC3448401763601DC7A54B40
93826	7	64	950	61428	79164	\N	55.268749	Республика Татарстан (Татарстан), Апастовский район, с.Чури Барышево, ул.Гагарина, д.3	Россия, республика Татарстан, Апастовский район	0101000020E6100000C2C073EFE136484096EA025E66A24B40
93825	7	64	950	61436	79175	\N	55.258360225404999	Республика Татарстан (Татарстан), Апастовский район, с.Черемшаны, ул.Вахитова, д.38	Россия, республика Татарстан, Апастовский район, село Черемшан	0101000020E61000008509A359D90E48401B4CC3F011A14B40
93445	7	64	950	61362	78804	\N	55.170203000000001	Республика Татарстан (Татарстан), Апастовский район, д.Чатбаш, ул.Татарстан, д.51		0101000020E6100000D40FEA22851C48402E573F36C9954B40
93798	7	64	950	11515	78662	\N	55.320011999999998	Республика Татарстан (Татарстан), Апастовский район, д.Утямишево, ул.Ленина, д.58		0101000020E6100000C7B94DB857444840ED293927F6A84B40
93820	7	64	950	12588	78870	\N	55.121046	Республика Татарстан (Татарстан), Апастовский район, д.Тюбяк Черки, ул.Ленина, д.86		0101000020E61000004548DDCEBE384840E3A7716F7E8F4B40
93822	7	64	950	12648	78692	\N	55.182603	Республика Татарстан (Татарстан), Апастовский район, с.Тутаево, ул.С.Ахтямова, д.10		0101000020E6100000D97A8670CC1048406493FC885F974B40
93827	7	64	950	12855	78694	\N	55.197816000000003	Республика Татарстан (Татарстан), Апастовский район, д.Танай Тураево, ул.Советская, д.37		0101000020E610000066118AADA04D48401250E10852994B40
93819	7	64	950	12533	78689	\N	55.157756999999997	Республика Татарстан (Татарстан), Апастовский район, д.Табар Черки, ул.Молодежная, д.70		0101000020E61000007E5704FF5B39484087DBA16131944B40
93817	7	64	950	61404	79135	\N	55.135236780423298	Республика Татарстан (Татарстан), Апастовский район, с.Старый Юмралы, ул.Вахитова, д.29	Россия, республика Татарстан, Апастовский район, село Старые Юмралы	0101000020E6100000FDF7E0B54B4B4840C51A2E724F914B40
93778	7	64	950	10552	78627	\N	55.185903000000003	Республика Татарстан (Татарстан), Апастовский район, д.Старые Енали, ул.Советская, д43		0101000020E61000009B92ACC3D1434840399D64ABCB974B40
93810	7	64	950	12102	78672	\N	55.180681	Республика Татарстан (Татарстан), Апастовский район, д.Ст.Бурнашево, ул.Амира Сабирова, д.17		0101000020E61000002367614F3B2648401901158E20974B40
93831	7	64	950	13028	78700	\N	55.2934612353489	Республика Татарстан (Татарстан), Апастовский район, с.Средний Биябаш, ул.Островского, д.20	Россия, республика Татарстан, Апастовский район, село Средний Биябаш	0101000020E61000007BDD2230D625484063D34A2190A54B40
93814	7	64	950	12264	78677	\N	55.226703000000001	Республика Татарстан (Татарстан), Апастовский район, с.Среднее Балтаево, ул.50 лет Победы, д.91		0101000020E6100000EBC5504EB4234840DA73999A049D4B40
93806	7	64	950	11848	78663	\N	55.232002000000001	Республика Татарстан (Татарстан), Апастовский район, п.Свияжский, ул.Заводская, д.14		0101000020E6100000FF58880E81394840A54DD53DB29D4B40
93811	7	64	950	12143	78964	\N	55.379489999999997	Республика Татарстан (Татарстан), Апастовский район, с.Сатламышево, ул.Центральная, д.42		0101000020E6100000029F1F46083B48405B94D92093B04B40
93829	7	64	950	12939	78698	\N	55.286501999999999	Республика Татарстан (Татарстан), Апастовский район, с.Нижний Биябаш, ул.Г.Тукая, д.17		0101000020E61000002B137EA99F2948408A1EF818ACA44B40
93805	7	64	950	11847	78696	\N	55.243561999999997	Республика Татарстан (Татарстан), Апастовский район, с.Мурзино, ул.Татарстана, д.18		0101000020E610000024287E8CB92F48403046240A2D9F4B40
93788	7	64	950	11053	78632	\N	55.322970016832301	Республика Татарстан (Татарстан), Апастовский район, д.Малые Кокузы, ул.Пушкина, д.41	Россия, республика Татарстан, Апастовский район, село Малые Кокузы	0101000020E6100000710168942E51484068CBB91457A94B40
93786	7	64	950	10967	78630	\N	55.204504999999997	Республика Татарстан (Татарстан), Апастовский район, с.Малые Болгояры, ул.Школьная, д.5		0101000020E61000007BDB4C85786248402A6F47382D9A4B40
93802	7	64	950	11680	78669	\N	55.172778999999998	Республика Татарстан (Татарстан), Апастовский район, д.Мазиково, ул.Сунгатуллина, д.20		0101000020E6100000037AE1CE85494840C1374D9F1D964B40
93808	7	64	950	11986	78670	\N	55.148910000000001	Республика Татарстан (Татарстан), Апастовский район, с.Куштово, ул.Х.Такташа, д.22		0101000020E6100000B6BC72BD6D24484010069E7B0F934B40
93794	7	64	950	11325	78640	\N	55.282435999999997	Республика Татарстан (Татарстан), Апастовский район, д.Курмашево, ул.Молодежная, д.43		0101000020E6100000E9D7D64FFF3F4840459BE3DC26A44B40
93800	7	64	950	11612	78660	\N	55.149146000000002	Республика Татарстан (Татарстан), Апастовский район, д.Кулганы, ул.Просвещения, д.8		0101000020E6100000EFFE78AF5A2B4840242A543717934B40
93803	7	64	950	61291	78247	\N	55.2334481296188	Республика Татарстан (Татарстан), Апастовский район, пжд.ст.Каратун, ул.Х.Такташа, д.1а	Россия, республика Татарстан, Апастовский район, село Коратун	0101000020E610000059FCA6B05233484087A8C29FE19D4B40
93809	7	64	950	61349	78675	\N	55.168138713380799	Республика Татарстан (Татарстан), Апастовский район, п.жд.ст. Кильдуразы, ул.Пионерская, д.24	Россия, республика Татарстан, Апастовский район, село Кильдуразы	0101000020E610000047E867EA752748405017299485954B40
93807	7	64	950	11901	78668	\N	55.188858000000003	Республика Татарстан (Татарстан), Апастовский район, с.Кзыл-Тау, ул.Вахитова, д.116		0101000020E610000013F06B240918484043CBBA7F2C984B40
93796	7	64	950	11382	78656	\N	55.405259999999998	Республика Татарстан (Татарстан), Апастовский район, с.Карамасары, ул.Гали Хужи, д.2		0101000020E6100000651C23D9233A48404030478FDFB34B40
93818	7	64	950	12478	78621	\N	55.136786999999998	Республика Татарстан (Татарстан), Апастовский район, д.Карабаево, ул.Тукая, д.6		0101000020E610000041446ADAC54E48404CC2853C82914B40
93813	7	64	950	12253	78679	\N	55.339610999999998	Республика Татарстан (Татарстан), Апастовский район, с.Кабы Копры, ул.Школьная, д.19		0101000020E61000002CBB6070CD474840512E8D5F78AB4B40
93801	7	64	950	61472	79221	\N	55.155751559699198	Республика Татарстан (Татарстан), Апастовский район, с.Идряс-Теникеево, ул.Вахитова, д.1	Россия, республика Татарстан, Апастовский район, село Идрясь-Теникеево	0101000020E610000059FD1186014B4840AF2479AEEF934B40
93799	7	64	950	11570	78661	\N	55.175206000000003	Республика Татарстан (Татарстан), Апастовский район, с.Деушево, ул.Ленина, д.75		0101000020E6100000A6811FD5B02D4840100874266D964B40
93784	7	64	950	10866	78951	\N	55.214471000000003	Республика Татарстан (Татарстан), Апастовский район, с.Давликеево, ул.Молодежная, д.12		0101000020E61000005F28603B182F4840607825C9739B4B40
93797	7	64	950	11468	78655	\N	55.302903999999998	Республика Татарстан (Татарстан), Апастовский район, с.Верхний Индырчи, ул.Тукая, д.21		0101000020E61000005708ABB1843D4840EEE9EA8EC5A64B40
93815	7	64	950	12339	78684	\N	55.239131999999998	Республика Татарстан (Татарстан), Апастовский район, д.Верхнее Балтаево, ул.Советская, д.27		0101000020E6100000D4601A868F204840AAB69BE09B9E4B40
93719	7	64	950	7757	78846	\N	55.240147999999998	Республика Татарстан (Татарстан), Апастовский район, с.Бурнашево, ул.Советская, д.31		0101000020E610000004E5B67D8F62484093196F2BBD9E4B40
93792	7	64	950	11225	78638	\N	55.257826999999999	Республика Татарстан (Татарстан), Апастовский район, с.Булым-Булыхчи, ул.Мечеть, д.13 А		0101000020E6100000F31DFCC4013E48404D83A27900A14B40
93787	7	64	950	11006	78643	\N	55.309032999999999	Республика Татарстан (Татарстан), Апастовский район, с.Большие Кокузы, ул.Ленина, д.50		0101000020E6100000809BC58B855348404031B2648EA74B40
93785	7	64	950	10921	78666	\N	55.224192000000002	Республика Татарстан (Татарстан), Апастовский район, с.Большие Болгояры, ул.Советская, д.8		0101000020E6100000BA826DC4936748402E03CE52B29C4B40
93783	7	64	950	10793	78641	\N	55.229157000000001	Республика Татарстан (Татарстан), Апастовский район, с.Бишево, ул.Ленина, 53		0101000020E6100000BF29AC545037484022533E04559D4B40
93759	7	64	950	9630	78955	\N	55.249243	Республика Татарстан (Татарстан), Апастовский район, с.Бакрче, ул.Центральная, д.36		0101000020E6100000006F8104C5194840E3E0D231E79F4B40
210	7	64	950	9630	10248	\N	55.249243	Республика Татарстан (Татарстан), Зеленодольский муниципальный район, с.Бакрче, ул.Советская, д.26	Россия, республика Татарстан, Апастовский район, село Бакрче	0101000020E6100000006F8104C5194840E3E0D231E79F4B40
93824	7	64	950	61462	79209	\N	55.2742289838204	Республика Татарстан (Татарстан), Апастовский район, с.Багишево, ул.Зеленая, д.19	Россия, республика Татарстан, Апастовский район, село Багищево	0101000020E61000002E73BA2C260C4840B14E95EF19A34B40
93823	7	64	950	61451	79196	\N	55.249927890299901	Республика Татарстан (Татарстан), Апастовский район, д.Аюкудерган, ул.Центральная, д.37	Россия, республика Татарстан, Апастовский район, село Аю-Кудерган	0101000020E61000004014CC9882074840662D05A4FD9F4B40
93777	7	64	950	10343	78233	\N	55.201797999999997	Республика Татарстан (Татарстан), Апастовский район, пгт.Апастово, ул.Советская, д.3		0101000020E61000000796236420414840F8325184D4994B40
93776	7	64	950	10343	68526	\N	55.201797999999997	Республика Татарстан (Татарстан), Апастовский  район, пгт.Апастово, ул.Красноармейская, д.65		0101000020E61000000796236420414840F8325184D4994B40
93773	7	64	950	10343	79288	\N	55.201797999999997	Республика Татарстан, Апастовский  район, пгт.  Апастово, ул.Заводская, д.11Б		0101000020E61000000796236420414840F8325184D4994B40
93775	7	64	950	10343	78224	\N	55.201797999999997	Республика Татарстан (Татарстан), Апастовский  район, пгт.Апастово, ул.Гагарина, д.7		0101000020E61000000796236420414840F8325184D4994B40
93779	7	64	950	10608	79312	\N	55.256456999999997	Республика Татарстан (Татарстан), Апастовский район, с.Альмендерово, ул.Победа, д.1		0101000020E61000009DD497A59D5C484046EA3D95D3A04B40
93432	7	64	950	25756	78784	\N	55.273000000000003	Республика Татарстан (Татарстан), Апастовский район, д.Азимово, ул.Ленина, д.6		0101000020E61000001152B7B3AF5A48406DE7FBA9F1A24B40
93795	7	64	950	11370	78651	\N	55.416401999999998	Республика Татарстан (Татарстан), Апастовский район, д.Азбаба, ул.Октябрьская, д.116		0101000020E61000000B28D4D34744484097FE25A94CB54B40
93764	7	64	151	9889	78216	\N	55.114842000000003	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Ямашинское сельское поселение, с.Ямаши, ул.Советская, д.4		0101000020E61000000B410E4A98CD4940871A8524B38E4B40
93767	7	64	151	10004	78959	\N	55.034219	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Ямашское сельское поселение, с.Ямаш, ул.Советская, д.109А		0101000020E6100000AED689CBF1164A406FF3C64961844B40
93738	7	64	151	8647	78185	\N	54.795177000000002	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Маметьевское сельское поселение, с.Чупаево, ул.Кирова, д.12А		0101000020E610000070B6B9313D114A4005C4245CC8654B40
93752	7	64	151	9310	78950	\N	54.929757000000002	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Сиренькинское сельское поселение, с.Чувашское Сиренькино, ул.Центральная, д.34А		0101000020E61000008908FF2268D84940111D024702774B40
93761	7	64	151	61355	78691	\N	55.000786456382201	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Сулеевское сельское поселение, с.Урсалбаш, ул.Ахмадуллина, д.113А	Россия, республика Татарстан, Альметьевский район, село Урсалабаш	0101000020E61000004F3BFC3559534A40B72572C119804B40
93763	7	64	151	9793	78211	\N	54.799028	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Тайсугановское сельское поселение, с.Тайсуганово, ул.Ленина, д.12		0101000020E6100000B4C876BE9F404A404D4BAC8C46664B40
93758	7	64	151	9583	79314	\N	54.992249999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Сулеевское сельское поселение, с.Сулеево, ул.Заречная, д.29А		0101000020E61000008BF9B9A1294F4A405EBA490C027F4B40
93756	7	64	151	9483	78203	\N	54.744295346391098	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Старосуркинское сельское поселение, с.Старое Суркино, ул.Ленина, сельский Дом культуры	Россия, республика Татарстан, Альметьевский район, село Старое Суркино	0101000020E6100000215B96AFCB1A4A40C5C9FD0E455F4B40
93754	7	64	151	9311	79328	\N	55.054015999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Старомихайловское сельское поселение, с.Старая Михайловка, ул.Ленина, д.1А		0101000020E6100000446ADAC534454A40F9BA0CFFE9864B40
92	7	64	151	5315	10095	\N	55.046646000000003	Республика Татарстан, Заинский муниципальный район, д.Старая Елань, ул.Долгобуль, д.3	Россия, республика Татарстан, Альметьевский район, село Старая Елань	0101000020E61000004A9A3FA6B5EF49409F3E027FF8854B40
93750	7	64	151	9151	71037	\N	55.038128999999998	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Русско-Акташское сельское поселение, с.Русский Акташ, ул.Школьная, 2		0101000020E610000039984D80610F4A40BC033C69E1844B40
93749	7	64	151	9151	75301	\N	55.038128999999998	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Русско-Акташское сельское поселение, с.Русский Акташ, ул.Комсомольская, д.12		0101000020E610000039984D80610F4A40BC033C69E1844B40
93748	7	64	151	9100	78202	\N	55.019283999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Новотроицкое сельское поселение, с.Новотроицкое, ул.Советская, д.2		0101000020E6100000744694F606BB494004ABEAE577824B40
93747	7	64	151	9099	78199	\N	55.052045999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Новоникольское сельское поселение, с.новоникольск, ул.Центральная, д.100		0101000020E61000001822A7AFE72B4A409DF17D71A9864B40
93757	7	64	151	9536	78954	\N	54.719403999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Старосуркинское сельское поселение, с.Новое Суркино, ул.Лесная, д.32		0101000020E61000000CB1FA230C1F4A40484E266E155C4B40
93746	7	64	151	9059	75240	\N	54.895051000000002	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Новонадыровское сельское поселение, с.новое надырово, ул.Советская, д.95		0101000020E6100000B21188D7F53B4A4045A0FA0791724B40
93743	7	64	151	32598	78215	\N	54.962043999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Новокашировское сельское поселение, с.Новокаширово, ул.Школьная, Сельская школа		0101000020E61000002A8D98D9E7434A4011A8FE41247B4B40
93744	7	64	151	32598	78117	\N	54.962043999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Новокашировское сельское поселение, с.Новокаширово, ул.Тавабилова, сельский Дом культуры	Россия, республика Татарстан, Альметьевский район, село Новое Каширово	0101000020E61000002A8D98D9E7434A4011A8FE41247B4B40
93762	7	64	151	9789	78953	\N	55.012594	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Сулеевское сельское поселение, с.Новая Михайловка, ул.Заречная, д.29а		0101000020E610000097CADB114E4B4A401B1021AE9C814B40
93712	7	64	151	7382	75294	\N	54.861165999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, пгт Нижняя Мактама, с.Тихоновка, ул.Терешковой, д.72		0101000020E61000008B6B7C26FB354A40AC36FFAF3A6E4B40
93772	7	64	151	7382	79331	\N	54.861165999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, поселок городского типа Нижняя Мактама, ул.Промышленная, д.1А		0101000020E61000008B6B7C26FB354A40AC36FFAF3A6E4B40
93769	7	64	151	7382	75131	\N	54.8696832891155	423440, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Альметьевский муниципальный район, п.г.т. Нижняя Мактама, ул.Некрасова (здание школы №2), д.1	Россия, республика Татарстан, Альметьевский район, поселок Нижняя Мактама	0101000020E6100000FA298E03AF364A408F71C5C5516F4B40
21634	7	61	300	27271	66692	\N	53.483426000000001	с.Новоаптиково,ул.Школьная,8		0101000020E6100000BC067DE9ED254C409F0436E7E0BD4A40
93768	7	64	151	7382	75131	\N	54.861165999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, поселок городского типа Нижняя Мактама, ул.Некрасова, д.10		0101000020E61000008B6B7C26FB354A40AC36FFAF3A6E4B40
93711	7	64	151	7382	75131	\N	54.861165999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, поселок городского типа Нижняя Мактама, ул.Некрасова, д.1		0101000020E61000008B6B7C26FB354A40AC36FFAF3A6E4B40
93742	7	64	151	8821	78206	\N	54.883778	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Нижнеабдулловское сельское поселение, с.Нижнее Абдулово, ул.Ленина, Сельский Дом культуры		0101000020E61000007CB94F8E02CE49404F7633A31F714B40
93732	7	64	151	8384	78905	\N	54.877181909346902	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Кичуйское сельское поселение, с.Нагорное, ул.Центральная, д.32		0101000020E610000094F947DFA4054A40E751F17F47704B40
93741	7	64	151	8768	78213	\N	54.833511000000001	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Миннибаевское сельское поселение. ст.миннибаево, ул.Шоссейная, д.20А		0101000020E6100000A915A6EF35224A409AED0A7DB06A4B40
93740	7	64	151	8768	78197	\N	54.820135000000001	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Миннибаевское сельское поселение, с.Миннибаево, ул.Бикчурина, д.50		0101000020E6100000494BE5ED081F4A4009A7052FFA684B40
93739	7	64	151	8706	78189	\N	54.815227999999998	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Маметьевское сельское поселение, с.Маметьево, ул.Советская, д.3		0101000020E6100000EBAA402D060B4A4049641F6459684B40
93736	7	64	151	8591	75300	\N	54.887377000000001	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Кульшариповское сельское поселение, с.Кульшарипово, ул.Тукая, д.50Б		0101000020E6100000D07B630800184A407E1CCD9195714B40
93735	7	64	151	8510	78864	\N	55.020403999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Кузайкинское сельское поселение, с.Кузайкино, ул.Советская, д.38	Россия, республика Татарстан, Альметьевский район, село Кузайкино	0101000020E610000084471B47ACE34940925A28999C824B40
93734	7	64	151	8503	78863	\N	54.876340999999996	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Клементейкинское сельское поселение, с.Клементейкино, ул.Центральная, д.38А		0101000020E6100000D50792770ED949406C921FF12B704B40
93733	7	64	151	8414	78103	\N	54.842677999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Кичучатовское сельское поселение, с.Кичучатово, ул.Юлдаш, д.2А		0101000020E61000008200193A760A4A40838769DFDC6B4B40
93731	7	64	151	8320	78853	\N	54.893906999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Кичуйское сельское поселение, с.Кичуй, ул.Центральная, д.59	Россия, республика Татарстан, Альметьевский район, село Кичуй	0101000020E61000003161342BDBFD49402E55698B6B724B40
93751	7	64	151	61435	79174	\N	54.973422086040202	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Сиренькинское сельское поселение, с.Кителга, ул.Советская, д.7А	Россия, республика Татарстан, Альметьевский район, село Кительга	0101000020E61000006F48A30227DB49407C9A9317997C4B40
93730	7	64	151	8304	78188	\N	54.892964999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Кама-Исмагиловское сельское поселение, с.Кама-Исмагилово, ул.Школьгая, д.15		0101000020E6100000B728B34126474A407FBC57AD4C724B40
1266	7	64	151	30044	11484	\N	54.82734	Республика Татарстан (Татарстан), Тукаевский муниципальный район, п.Кама, ул.Ключевая, д.7		0101000020E6100000E162450DA6514A401956F146E6694B40
93729	7	64	151	8223	75299	\N	54.925063999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Калейкинское сельское поселение, с.Калейкино, ул.Токарликова, д.104А		0101000020E610000060C77F8120164A407D5A457F68764B40
93737	7	64	151	8223	68502	\N	54.918726626870203	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Лесно-Калейкинское сельское поселение, ст.Калейкино, ул.Железнодорожная, д.38Б	Россия, республика Татарстан, Альметьевский район, село Калейкино	0101000020E6100000FE9E58A7CA114A40E179A9D898754B40
93716	7	64	151	7629	78786	\N	54.955758000000003	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Аппаковское сельское поселение, с.Ильтень-Бута, ул.Советская, д.52		0101000020E61000001C2785798FF34940F8713447567A4B40
93765	7	64	151	9891	79338	\N	55.067143000000002	423430, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Альметьевский муниципальный район, с.Зай-Чишма, ул.Верхняя (здание сельского клуба), д.18б		0101000020E6100000AA29C93A1C114A40E2934E2498884B40
93728	7	64	151	8208	78855	\N	54.929648	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Ерсубайкинское сельское поселение, с.Ерсубайкино, ул.Советская, д.11		0101000020E6100000EE77280AF4DF49405A65A6B4FE764B40
93714	7	64	151	7547	78072	\N	54.947265716219398	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Альметьевское сельское поселение, с.Дербедень, ул.Школьная, д.3	Россия, республика Татарстан, Альметьевский район, село Дербедень	0101000020E61000008335CEA623024A406E4E250340794B40
93631	7	64	310	3224	78944	\N	54.979210999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Старые Челны, ул.Центральная, д.20		0101000020E6100000F35487DC0C07494015713AC9567D4B40
93717	7	64	151	7638	78876	\N	54.937897999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Багряж-Никольское сельское поселение, с.Дальняя Ивановка, ул.Молодёжная, д.26		0101000020E61000000458E4D70FC54940ED7DAA0A0D784B40
93726	7	64	151	8102	78176	\N	54.827148000000001	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Верхнемактаминское сельское поселение, с.Верхняя Мактама, ул.Октября, д.57		0101000020E610000099F56228272E4A40D57954FCDF694B40
93725	7	64	151	8046	78175	\N	54.960828999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Верхнеакташское сельское поселение, с.Верхний Акташ, ул.Советская, д.18		0101000020E6100000B5C6A01342134A403106D671FC7A4B40
93724	7	64	151	7964	78857	\N	54.768137000000003	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Васильевское сельское поселение,с.Васильевка, ул.Центральная, д.26		0101000020E6100000889E94490D254A407DEC2E5052624B40
93723	7	64	151	7911	78751	\N	55.01708	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Бутинское сельское поселение, с.Бута, ул.Большая, д.1		0101000020E6100000D0B4C4CA68F8494035B56CAD2F824B40
93721	7	64	151	7809	78749	\N	55.032851000000001	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Борискинское сельское поселение, с.Борискино, ул.Центральная, д.61		0101000020E610000035B56CAD2FD249400952297634844B40
93718	7	64	151	7716	79327	\N	54.858258999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Бишмунчинское сельское поселение, с.Бишмунча, ул.Советская, д.57Б		0101000020E6100000344DD87E324C4A40B33F506EDB6D4B40
93745	7	64	151	9017	78949	\N	55.016444999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Новокашировское сельское поселение, с.Бикасаз, ул.Школьная, сельский клуб		0101000020E61000002B6B9BE271374A406397A8DE1A824B40
93722	7	64	151	7900	78750	\N	55.023133999999999	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Борискинское сельское поселение, с.Берёзовка, ул.Центральная, д.16		0101000020E610000085CC9541B5DB49407CB60E0EF6824B40
93715	7	64	151	7557	78585	\N	54.931742999999997	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Аппаковское сельское поселение, с.Аппаково, ул.Школьная, д.2		0101000020E6100000B98C9B1A68F4494072A3C85A43774B40
93713	7	64	151	60590	75380	\N	54.776631536892502	Республика Татарстан (Татарстан), Альметьевский муниципальный район, Абдрахмановское сельское поселение, ул.Советская, д.49	Россия, республика Татарстан, Альметьевский район, село Абдрахманово	0101000020E6100000EDEF6C8FDE3E4A40778368AD68634B40
93656	7	64	7477	59389	75273	\N	54.894886481888499	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Советская, Дом культуры	Россия, республика Татарстан, Альметьевск городской округ	0101000020E6100000B24813EF00274A40FAD2DB9F8B724B40
93679	7	64	7477	59389	70189	\N	54.906864398067498	Республика Татарстан (Татарстан), Альметьевский муниципальный район, город Альметьевск, ул.Белоглазова, д.105	Россия, республика Татарстан, Альметьевск городской округ	0101000020E61000007138F3AB39264A40BAF59A1E14744B40
93645	7	64	310	3937	78113	\N	54.624279999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Юхмачи, ул.Луговая, д.1а		0101000020E6100000EC2FBB270FFD484000C63368E84F4B40
93642	7	64	310	3789	78956	\N	54.818199999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Чувашское Шапкино, ул.Центральная, д.39		0101000020E61000001B48179B56E6484029CB10C7BA684B40
93641	7	64	310	3747	78744	\N	54.717104999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Чувашское Бурнаево, ул.Центральная, 25а		0101000020E6100000E884D04197E848402766BD18CA5B4B40
93640	7	64	310	3684	78114	\N	54.740443999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Чувашский Брод, ул.Молодежная, д.2а		0101000020E61000002CF2EB87D80A49407C4276DEC65E4B40
93639	7	64	310	3653	78746	\N	55.020833000000003	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Хлебодаровка, ул.Зеленая, д.2		0101000020E6100000674815C5ABEA4840BBD6DEA7AA824B40
93635	7	64	310	3447	79024	\N	54.858238	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Тяжбердино, ул.Центральная, д.34	Россия, республика Татарстан, Алькеевский район, село Тяжбердино	0101000020E610000060AC6F6072F748409C1727BEDA6D4B40
93634	7	64	310	3372	78942	\N	54.802739000000003	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Татарское Тюгульбаево, ул.Шавалеева, д.8б		0101000020E610000003EE79FEB4D54840A41CCC26C0664B40
93633	7	64	310	3328	78938	\N	54.898964999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Татарское Муллино, ул.Школьная, д.46		0101000020E61000002AFD84B35B134940D39FFD4811734B40
93632	7	64	310	3257	78957	\N	54.73404	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Татарское Бурнаево, ул.Центральная, д.32		0101000020E61000009A081B9E5EED484059FAD005F55D4B40
93649	7	64	310	4167	78948	\N	54.699181000000003	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Ахметьево, ул.Центральная, д.10б		0101000020E6100000323CF6B358064940077E54C37E594B40
93643	7	64	310	3848	78952	\N	54.659261000000001	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Шибаши, ул.Мира, д.20		0101000020E6100000A708707A17F148409E4319AA62544B40
93636	7	64	310	3473	78947	\N	54.892856000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Ургагары, ул.Г.Тукая, д.4		0101000020E6100000C345EEE9EA024940C904FC1A49724B40
93628	7	64	310	2785	78936	\N	54.931350000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Старые Салманы, ул.Клубная, д.1		0101000020E61000004B1E4FCB0FDE484097900F7A36774B40
93627	7	64	310	2979	78943	\N	54.868834	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Старые Матаки, ул.Центральная, д.7		0101000020E6100000931B45D61AEC484091D3D7F3356F4B40
93646	7	64	310	3979	78745	\N	54.762827999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Старое Ямкино, ул.Мира, д.39		0101000020E610000012FA997ADD1649408E3C1059A4614B40
93626	7	64	310	2912	78935	\N	54.837296000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Старое Камкино, ул.Нижняя, д.66		0101000020E61000009DBB5D2F4D0F49402B89EC832C6B4B40
93625	7	64	310	2861	78963	\N	54.877428000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Старое Алпарово, ул.Северная, д.29		0101000020E6100000749A05DA1D1649401F4C8A8F4F704B40
93638	7	64	310	3591	78945	\N	54.777977999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Старая Хурада, ул.Школьная, д.1		0101000020E6100000FB1EF5D72BF84840F58079C894634B40
93629	7	64	310	3088	78941	\N	54.890225000000001	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Старая Тахтала, ул.Ежевичная, д.88а		0101000020E61000008B8A389D64D54840728A8EE4F2714B40
93623	7	64	310	2739	78939	\N	54.821437000000003	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Среднее Алькеево, ул.Центральная, д.47		0101000020E6100000F817416326034940B85CFDD824694B40
93637	7	64	310	61476	79225	\N	54.769414499534101	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Сиктерме-Хузангаево, ул.Майская, д.1а	Россия, республика Татарстан, Алькеевский район, село Хузангаево	0101000020E61000007847C66AF3ED4840D28A6F287C624B40
93620	7	64	310	2555	78739	\N	54.950702	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Новые Челны, ул.Советская, д.35		0101000020E6100000676325E659034940F31E679AB0794B40
93624	7	64	310	61371	79025	\N	54.957123000000003	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Салманы, ул.Школьная, д.16	Россия, республика Татарстан, Алькеевский район, село Новые Салманы	0101000020E6100000F6F065A208E34840ED9FA701837A4B40
93647	7	64	310	4053	79186	\N	54.760473131930901	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Нижнее Колчуурино, ул.Центральная, д.27	Россия, республика Татарстан, Алькеевский район, село Нижнее Колчурино	0101000020E6100000FF959526A5E84840D93EE42D57614B40
93621	7	64	310	2065	78932	\N	54.675964	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Нижнее Качеево, ул.Центральная, д.106		0101000020E6100000501C40BFEFFD4840FDA204FD85564B40
93619	7	64	310	2520	78931	\N	54.885415000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Нижнее Биктимирово, ул.Мира, д.17		0101000020E6100000242A543717FB4840A5315A4755714B40
93618	7	64	310	2452	78926	\N	54.606422999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Нижнее Альмурзино, ул.Советская, д.9		0101000020E610000077BCC96FD1FD48406745D4449F4D4B40
93617	7	64	310	2407	78168	\N	54.779375000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Нижнее Алькеево, ул.Советская, д.56		0101000020E6100000CC7C073F71044940F6285C8FC2634B40
93616	7	64	310	2328	78930	\N	54.828381999999998	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Кошки, ул.М.Джалиля, д.21		0101000020E6100000D74CBED9E6D048402B4CDF6B086A4B40
93614	7	64	310	2219	78919	\N	54.999093000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Каргополь, ул.Мостовая, д.12		0101000020E6100000B3B45373B9F54840CE548847E27F4B40
93613	7	64	310	2173	78918	\N	54.814849000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Карамалы, ул.Г.Тукая, д.20		0101000020E6100000E4DC26DC2B1B4940D316D7F84C684B40
93615	7	64	310	2290	78920	\N	54.563530999999998	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Каракули, ул.Школьная, д.26		0101000020E610000069705B5B78FE48401EA4A7C821484B40
93610	7	64	310	1985	78915	\N	54.863802999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Верхние Матаки, ул.Клубная, д.1		0101000020E6100000B13385CE6BE64840E597C118916E4B40
93609	7	64	310	1931	78921	\N	54.752103614797001	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Верхнее Колчурино, ул.8 Марта, д.21	Россия, республика Татарстан, Алькеевский район, село Верхнее Колчурино	0101000020E61000002DEDD45C6EE448406C98A1F144604B40
93612	7	64	310	2106	79348	\N	55.434598999999999	422889, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Верхнее Качеево, ул.Центральная (здание сельского Дома культуры), д.45		0101000020E610000039EE940ED6354940E9EFA5F0A0B74B40
93608	7	64	310	1853	78925	\N	54.614609999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Верхнее Альмурзино, ул.Пионерская, д.24		0101000020E6100000D0B9DBF5D2F44840B4E55C8AAB4E4B40
93607	7	64	310	1817	78913	\N	54.782892155165101	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Верхнее Алькеево, ул.Мира, д.70	Россия, республика Татарстан, Алькеевский район, село Верхнее Алькеево	0101000020E61000000D51853FC3FD4840672618CE35644B40
93606	7	64	310	1753	78908	\N	54.788876000000002	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Борискино, ул.Дружбы, д.8		0101000020E61000008C4CC0AF910E4940B64C86E3F9644B40
93605	7	64	310	1710	78911	\N	55.005412999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Бибаево-Челны, ул.Мира, д.22		0101000020E6100000BCE7C0728408494093FC885FB1804B40
93602	7	64	310	1397	78159	\N	54.906393999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Базарные Матаки, ул.Школьная, д.6/2		0101000020E6100000C34659BF99F6484033A5F5B704744B40
93601	7	64	310	1397	78159	\N	54.906393999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Базарные Матаки, ул.Школьная, д.6/1		0101000020E6100000C34659BF99F6484033A5F5B704744B40
93603	7	64	310	1397	78187	\N	54.906393999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Базарные Матаки, ул.Центральная Усадьба, д.1		0101000020E6100000C34659BF99F6484033A5F5B704744B40
93644	7	64	310	1397	78112	\N	54.906393999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Базарные Матаки, ул.Крайнова, д.185		0101000020E6100000C34659BF99F6484033A5F5B704744B40
93600	7	64	310	1397	78112	\N	54.906393999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Базарные Матаки, ул.Крайнова, д.55		0101000020E6100000C34659BF99F6484033A5F5B704744B40
93604	7	64	310	1397	78163	\N	54.906393999999999	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Базарные Матаки, ул.40 лет Победы, д.1		0101000020E6100000C34659BF99F6484033A5F5B704744B40
93648	7	64	310	4092	78961	\N	54.532910739568102	Республика Татарстан (Татарстан), Алькеевский муниципальный район, с.Аппаково, ул.Мира, д.1	Россия, республика Татарстан, Алькеевский район, село Аппаково	0101000020E6100000EF90628044FB4840DE567A6D36444B40
93630	7	64	6904	40355	9917	\N	54.554378999999997	Республика Татарстан (Татарстан), Алькеевский муниципальный район, д.Старая Тумба, ул.Центральная, д.21		0101000020E610000056647440120849406A4B1DE4F5464B40
93598	7	64	20	1299	78740	\N	55.082585999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Ялкын, ул.Гагарина, д.42		0101000020E6100000444FCAA486F04840C18D942D928A4B40
93556	7	64	20	31528	78860	\N	54.981009	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Шама, ул.Заречная, д.17		0101000020E6100000BD8BF7E3F63D4940740AF2B3917D4B40
93584	7	64	20	446	78903	\N	55.052778000000004	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Чувашская Майна, ул.Школьная, д.10		0101000020E6100000637D03931B43494062F9F36DC1864B40
93588	7	64	20	700	78727	\N	55.154609000000001	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Тиган Буляк, ул.Кирова, д.2		0101000020E6100000B58828266F20494069554B3ACA934B40
93573	7	64	20	32290	78722	\N	55.148409999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Сухие Курнали, ул.Заки Кутлина, д.24		0101000020E61000000FEF39B01C0349401E335019FF924B40
93595	7	64	20	1134	78653	\N	55.285020000000003	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Степная Шентала, ул.Вахитова, д.34		0101000020E6100000368FC360FE2249405C5A0D897BA44B40
93569	7	64	20	32111	78671	\N	54.933129000000001	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Старое Муллино, ул.Гагарина, д.33		0101000020E61000009E7B0F971C1549407FF964C570774B40
93593	7	64	20	1006	78106	\N	55.165770000000002	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Средние Тиганы, ул.Зеленая, д.12		0101000020E610000007B47405DB18494037548CF337954B40
93591	7	64	20	893	78735	\N	55.311225999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Сахаровка, ул.Мирная, д.101		0101000020E6100000302AA913D02449401BD5E940D6A74B40
93579	7	64	20	132	78927	\N	55.372104	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Саконы, ул.Центральная, д.39		0101000020E610000073F1B73D411A4940FB5A971AA1AF4B40
93553	7	64	20	31369	78858	\N	55.243437999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Сабакайка, ул.Центральная, д.13		0101000020E6100000A69A594B01034940444DF4F9289F4B40
93590	7	64	20	821	78731	\N	55.061039000000001	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Ромодан, ул.Советская, д.1		0101000020E61000005DFDD8243F004940E9633E20D0874B40
93587	7	64	20	651	78659	\N	55.138216999999997	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Родники, ул.Советская, д.3		0101000020E610000035971B0C7520494028603B18B1914B40
93592	7	64	20	933	78737	\N	55.364859000000003	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Речное, ул.Комсомольская, д.4		0101000020E6100000C76647AAEF2249405D5320B3B3AE4B40
93570	7	64	20	32514	78890	\N	54.949362999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Приозерная, ул.Бутлерова, д.15		0101000020E6100000DC662AC42323494027840EBA84794B40
93585	7	64	20	523	78904	\N	55.112231999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Подлесная Шентала, ул.Тукая, д.42		0101000020E6100000DA3A38D89B2C494047C8409E5D8E4B40
93576	7	64	20	61363	78826	\N	55.146155880638503	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Новоспасск, ул.Некрасова, д.18А	Россия, республика Татарстан, Заинский район, село Новоспасск	0101000020E61000000F98874CF91A4A409D0E643DB5924B40
93594	7	64	20	1056	78736	\N	55.188915000000001	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Нижние Тиганы, ул.Центральная, д.45		0101000020E61000007D3D5FB35C1E4940A75CE15D2E984B40
93563	7	64	20	31883	78158	\N	55.289003999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Мокрые Курнали, ул.Школьная, д.9		0101000020E61000000BEE073C30FE4840E3344415FEA44B40
93589	7	64	20	767	78729	\N	55.106191000000003	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Масловка, ул.Школьная, д.6		0101000020E6100000048F6FEF1A0049409510ACAA978D4B40
93571	7	64	20	32200	78720	\N	54.878480000000003	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Мараса, ул.Школьная, д.31		0101000020E610000037FC6EBA651D494055185B0872704B40
93596	7	64	20	1178	78733	\N	55.236293000000003	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Малый Красный Яр, ул.Молодежная, д.7		0101000020E6100000A723809BC51F49400AA359D93E9E4B40
93581	7	64	20	182	79287	\N	55.139513999999998	422907, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Левашево, ул.Советская (здание сельского Дома культуры), д.14		0101000020E6100000BFD364C6DBF44840C5AA4198DB914B40
93578	7	64	20	25	78152	\N	55.323101000000001	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Лебяжье, ул.Центральная, д.29А		0101000020E610000072A8DF85AD1349400727A25F5BA94B40
93575	7	64	20	32360	78723	\N	55.225650999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Лебедино, ул.Кооперативная, д.3		0101000020E6100000E9EDCF4543EA4840A4A7C821E29C4B40
93572	7	64	20	32239	78719	\N	55.194943000000002	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Куркуль, ул.Центральная, д.36		0101000020E610000017105A0F5F0E4940C5CA68E4F3984B40
93558	7	64	20	31665	78865	\N	55.022137999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Красный Баран, ул.Центральная, д.48Б		0101000020E610000031276893C3194940DAFF006BD5824B40
93597	7	64	20	1247	78742	\N	55.094320892480901	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Караваево, ул.Школьная, д.3	Россия, республика Татарстан, Алексеевский район, село Караваево	0101000020E61000004A7A185A9DEC4840BB29E5B5128C4B40
93568	7	64	20	32109	78900	\N	54.953488999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Ерыкла, ул.Правонабережная, д.35	Россия, республика Татарстан, Алексеевский район, село Ерыкла	0101000020E61000005E4C33DDEB1C4940410C74ED0B7A4B40
93582	7	64	20	317	78897	\N	55.023288999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Горка, ул.Ленина, д.2А		0101000020E610000046072461DF344940A3AD4A22FB824B40
93566	7	64	20	31981	78889	\N	55.106557000000002	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Войкино, ул.Викторова, д.12		0101000020E610000025CADE52CEE548407714E7A8A38D4B40
93583	7	64	20	398	78898	\N	55.073163999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Верхняя Татарская Майна, ул.Горская, д.15		0101000020E6100000BEDEFDF15E3949404D9F1D705D894B40
93564	7	64	20	31931	78613	\N	55.253475999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Бутлеровка, ул.Центральная, д.38		0101000020E6100000D61A4AED45FA48401329CDE671A04B40
93560	7	64	20	31745	78881	\N	55.132212000000003	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Большие Тиганы, ул.Баттала, д.17		0101000020E61000005E85949F54134940C311A452EC904B40
93557	7	64	20	31615	78861	\N	55.050499000000002	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Большие Полянки, ул.Центральная, д.18		0101000020E610000019ABCDFFAB1C494088BD50C076864B40
93555	7	64	20	31431	75243	\N	54.984181	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Билярск, ул.Ленина, д.2		0101000020E61000002DEC6987BF3049401B2C9CA4F97D4B40
93554	7	64	20	31431	78063	\N	54.984181	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Билярск, ул.Калинина, д.1		0101000020E61000002DEC6987BF3049401B2C9CA4F97D4B40
93577	7	64	20	32490	\N	\N	55.202137	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Березовая Грива, ул.Пушкина, д.2Б	Россия, республика Татарстан, Алексеевский район, село Березовая Грива	0101000020E61000004640852348DF4840E1270EA0DF994B40
93565	7	64	20	31938	78880	\N	55.306024999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Балахчино, ул.Комсомольская, д.11		0101000020E61000000FB6D8EDB3F648401361C3D32BA74B40
93567	7	64	20	32039	78628	\N	55.136426999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, с.Базяково, ул.Федина, д.20		0101000020E6100000ABAE433525DD48404CA59F7076914B40
93586	7	64	20	578	78901	\N	55.014983999999998	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Арбузов Баран, ул.Чернышевского, д.14		0101000020E61000003A07CF84262749404CFBE6FEEA814B40
93546	7	64	20	31084	75195	\N	55.307490999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, пгт.Алексеевское, ул.Советская, д.1А		0101000020E6100000D505BCCCB00D49403C6876DD5BA74B40
93547	7	64	20	31084	67732	\N	55.307490999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, пгт.Алексеевское, ул.Некрасова, д.38		0101000020E6100000D505BCCCB00D49403C6876DD5BA74B40
93549	7	64	20	31084	67739	\N	55.307490999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, пгт.Алексеевское, ул.Ленина, д.73		0101000020E6100000D505BCCCB00D49403C6876DD5BA74B40
93548	7	64	20	31084	67739	\N	55.307490999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, пгт.Алексеевское, ул.Ленина, д.33		0101000020E6100000D505BCCCB00D49403C6876DD5BA74B40
93552	7	64	20	31084	68200	\N	55.307490999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, пгт.Алексеевское, ул.Есенина, д.19		0101000020E6100000D505BCCCB00D49403C6876DD5BA74B40
93551	7	64	20	31084	78042	\N	55.307490999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, пгт.Алексеевское, ул.Дорожников, д.1		0101000020E6100000D505BCCCB00D49403C6876DD5BA74B40
93550	7	64	20	31084	68182	\N	55.307490999999999	Республика Татарстан (Татарстан), Алексеевский муниципальный район, пгт.Алексеевское, ул.Гагарина, д.20		0101000020E6100000D505BCCCB00D49403C6876DD5BA74B40
93559	7	64	20	31667	78882	\N	55.034286000000002	Республика Татарстан (Татарстан), Алексеевский муниципальный район, д.Александровка, ул.Мирная, д.9		0101000020E61000005D16139B8F114940F75AD07B63844B40
93545	7	64	1851	31026	78716	\N	55.703164999999998	Республика Татарстан (Татарстан), Актанышский муниципальный район, Уразаевское сельское поселение, д.Шарипово, ул.Центральная, д.5		0101000020E61000009A0986730DF74A408E588B4F01DA4B40
93544	7	64	1851	30930	78718	\N	55.409154999999998	Республика Татарстан (Татарстан), Актанышский муниципальный район, Чуракаевское сельское поселение, с.Чуракаево, ул.Кирова, д.55		0101000020E610000053CC41D0D1EE4A4058FFE7305FB44B40
93543	7	64	1851	30925	78715	\N	55.578808000000002	Республика Татарстан (Татарстан), Актанышский муниципальный район, Чишминское сельское поселение, с.Чишма, ул.Центральная, д.50		0101000020E610000044C2F7FE06014B40E3546B6116CA4B40
93542	7	64	1851	30845	78714	\N	55.664461000000003	Республика Татарстан (Татарстан), Актанышский муниципальный район, Атясевское сельское поселение, д.Чатово, ул.Центральная, д.43		0101000020E610000053E8BCC62ED54A40D63BDC0E0DD54B40
93541	7	64	1851	30778	78709	\N	55.772987999999998	Республика Татарстан (Татарстан), Актанышский муниципальный район, Чалманаратское сельское поселение, с.Чалманарат, ул.Центральная, д.2		0101000020E610000091D3D7F335E34A40A8195245F1E24B40
93540	7	64	1851	30733	78705	\N	55.565845000000003	Республика Татарстан (Татарстан), Актанышский муниципальный район, Усинское сельское поселение, с.Усы, ул.Молодежная, д.5а		0101000020E610000019E25817B7CF4A4075CDE49B6DC84B40
93539	7	64	1851	30719	78862	\N	55.755419000000003	Республика Татарстан (Татарстан), Актанышский муниципальный район, Уразаевское сельское поселение, с.Уразаево, ул.Центральная, д.4		0101000020E61000002579AEEFC3F74A4076E3DD91B1E04B40
93538	7	64	1851	30612	78702	\N	55.480438999999997	Республика Татарстан (Татарстан), Актанышский муниципальный район, Кировское сельское поселение, с.Улиманово, ул.1 Мая, д.33		0101000020E610000089EDEE01BAD54A40895C70067FBD4B40
93537	7	64	1851	30614	78109	\N	55.602336999999999	Республика Татарстан (Татарстан), Актанышский муниципальный район, Тюковское сельское поселение, с.Тюково, ул.Ленина, д.61/2		0101000020E6100000892650C422C64A40DB15FA6019CD4B40
93534	7	64	1851	30422	78148	\N	55.827793	Республика Татарстан (Татарстан), Актанышский муниципальный район, Татарско-Ямалинское сельское поселение, д.Татарские Ямалы, ул.Ленина, д.14		0101000020E6100000842C0B26FEE04A40CA6DFB1EF5E94B40
93533	7	64	1851	30417	78095	\N	55.754176999999999	Республика Татарстан (Татарстан), Актанышский муниципальный район, Татарско-Суксинское сельское поселение, с.Татарские Суксы, ул.Гагарина, д.1б		0101000020E61000008884EFFD0DD44A409C3237DF88E04B40
93532	7	64	1851	30313	78098	\N	55.768141999999997	Республика Татарстан (Татарстан), Актанышский муниципальный район, Такталачукское сельское поселение, с.Такталачук, ул.Г.Авзал, д.50		0101000020E6100000FDDAFAE93FEF4A408E57207A52E24B40
93531	7	64	1851	61429	79165	\N	55.430494048549001	Республика Татарстан (Татарстан), Актанышский муниципальный район, Верхнеяхшеевское сельское поселение, д.Табанлыкуль, ул.Гагарина, д.23	Россия, республика Татарстан, Актанышский район, село Табанлы-Куль	0101000020E61000004F75C8CD70DF4A40E78F696D1AB74B40
93511	7	64	1851	61464	79213	\N	55.6966626003139	Республика Татарстан (Татарстан), Актанышский муниципальный район, Кузякинское сельское поселение, д.Верхнеурьяды, ул.Советская, д.23	Россия, республика Татарстан, Актанышский район, село Старые Урьяды	0101000020E6100000D218ADA3AACD4A40A8AAD0402CD94B40
93528	7	64	1851	32547	78046	\N	55.613737999999998	Республика Татарстан (Татарстан), Актанышский муниципальный район, Старобугадинское сельское поселение, с.Старобугады, ул.Центральная, д.58		0101000020E61000005950189469F44A40FE277FF78ECE4B40
93535	7	64	1851	30470	78701	\N	55.705517999999998	Республика Татарстан (Татарстан), Актанышский муниципальный район, Тлякеевское сельское пселение, д.Тлякеево, ул.Центральная, д.85		0101000020E6100000DB5207793DEE4A40A25EF0694EDA4B40
93530	7	64	1851	32563	78105	\N	55.548996000000002	Республика Татарстан (Татарстан), Актанышский муниципальный район, Старосафаровское сельское поселение, д.Старосафарово, ул.М.Вахитова, д.16		0101000020E6100000D8BAD408FDE44A4042D13C8045C64B40
93529	7	64	1851	32555	78052	\N	55.668126999999998	Республика Татарстан (Татарстан), Актанышский муниципальный район, Старокурмашевское сельское поселение, с.Старокурмашево, ул.Центральная, д.26		0101000020E6100000C4094CA775E14A408C497F2F85D54B40
93510	7	64	1851	61417	79151	\N	55.633091373418701	Республика Татарстан (Татарстан), Актанышский муниципальный район, Атясевское сельское поселение, д.Бикчантаево, ул.Г.Тукая, д.3	Россия, республика Татарстан, Актанышский район, село Старое Бикчентаево	0101000020E610000058923CD7F7D74A402B323A2009D14B40
21621	7	61	300	26670	66854	\N	53.667783999999997	д.Нижнеарметово, ул.Гизатуллина, 84б		0101000020E61000003F36C98FF83F4C40626534F279D54A40
93527	7	64	1851	32543	78089	\N	55.480454000000002	Республика Татарстан (Татарстан), Актанышский муниципальный район, Старобайсаровское сельское поселение, с.Старобайсарово, ул.Советская, д.25		0101000020E61000004580D3BB78EF4A40BF9D44847FBD4B40
93526	7	64	1851	61448	79190	\N	55.626302426087101	Республика Татарстан (Татарстан), Актанышский муниципальный район, Новоалимовское сельское поселение, д.Староалимово, ул.Центральная, д.27а	Россия, республика Татарстан, Актанышский район, село Старое Алимово	0101000020E610000065A88AA9F4054B40AFB5F7A92AD04B40
93525	7	64	1851	61368	78924	\N	55.510490605840097	Республика Татарстан (Татарстан), Актанышский муниципальный район, Староаймановское сельское поселение, д.Староайманово, ул.Новая, д.5а	Россия, республика Татарстан, Актанышский район, село Старое Айманово	0101000020E61000000A4D124BCAC34A4080F3E2C457C14B40
93524	7	64	1851	61501	79259	\N	55.392326692354601	Республика Татарстан (Татарстан), Актанышский муниципальный район, Чуракаевское сельское поселение, д.Староагъбязово, ул.Ленина, д.53	Россия, республика Татарстан, Актанышский район, село Старое Агбязово	0101000020E6100000F9BCE2A947EA4A403D2B69C537B24B40
93523	7	64	1851	29883	75266	\N	55.536861292916001	Республика Татарстан (Татарстан), Актанышский муниципальный район, Поисевское сельское поселение, с.Поисево, ул.Советская, д.21	Россия, республика Татарстан, Актанышский район, село Поисево	0101000020E6100000F3E505D847BF4A40BABF7ADCB7C44B40
93522	7	64	1851	61445	79187	\N	55.714186524678396	Республика Татарстан (Татарстан), Актанышский муниципальный район, Ново-Курмашевское сельское поселение, с.Новокурмашево, ул.Центральная, д.41а		0101000020E6100000F086342A70DC4A403B1DC87A6ADB4B40
93521	7	64	1851	33137	78086	\N	55.677230000000002	Республика Татарстан (Татарстан), Актанышский муниципальный район, Новоалимовское сельское поселение, с.Ново-Алимово, ул.Г.Тукая, д.53		0101000020E6100000CC6262F371054B405FEFFE78AFD64B40
93520	7	64	1851	61364	78869	\N	55.7854199339953	Республика Татарстан (Татарстан), Актанышский муниципальный район, Чалманаратское сельское поселение, д.Нижне-Гареево, ул.Красноармейская, д.17	Россия, республика Татарстан, Актанышский район, село Нижнее Гареево	0101000020E610000090A2CEDC43E84A40EACF7EA488E44B40
93519	7	64	1851	29737	78856	\N	55.745595000000002	Республика Татарстан (Татарстан), Актанышский муниципальный район, Татарско-Суксинское сельское поселение, с.Мари-Суксы, ул.И.Миннибаева, д.29		0101000020E6100000F19C2D20B4D24A40D3872EA86FDF4B40
93518	7	64	1851	29660	78611	\N	55.735525000000003	Республика Татарстан (Татарстан), Актанышский муниципальный район, Уразаевское сельское поселение, д.Куяново, ул.Центральная, д.55		0101000020E6100000747ADE8D05014B40F931E6AE25DE4B40
93516	7	64	1851	61424	79160	\N	55.649817138516099	Республика Татарстан (Татарстан), Актанышский муниципальный район, Кузякинское сельское поселение, с.Кузякно, ул.Советская, д.46	Россия, республика Татарстан, Актанышский район, село Кузякино	0101000020E610000028D192C7D3CA4A4042B115342DD34B40
93514	7	64	1851	29471	78850	\N	55.546754999999997	Республика Татарстан (Татарстан), Актанышский муниципальный район, Усинское сельское посление, д.Качкиново, ул.Центральная, д.37в		0101000020E61000001A868F8829C94A4055F65D11FCC54B40
93513	7	64	1851	29465	78847	\N	55.664161999999997	Республика Татарстан (Татарстан), Актанышский муниципальный район, Казкеевское сельское поселение, д.Казкеево, ул.Первомайская, д.1а		0101000020E6100000CDEA1D6E87184B407B9FAA4203D54B40
93536	7	64	1851	29465	78710	\N	55.698492999999999	Республика Татарстан (Татарстан), Актанышский муниципальный район, Казкеевское сельское поселение, д.Тыннамасово, ул.Октябрьская, д.72б		0101000020E610000006465ED6C41A4B4012BEF73768D94B40
93515	7	64	1851	29335	78507	\N	55.549864307693603	Республика Татарстан (Татарстан), Актанышский муниципальный район, Кировское сельское поселение, поселок совхоза имени Кирова, ул.Кирова, д.39	Россия, республика Татарстан, Актанышский район, село Имени Кирова	0101000020E610000073B8567BD8D94A40B69F8CF161C64B40
93512	7	64	1851	61413	79152	\N	55.472137168925698	Республика Татарстан (Татарстан), Актанышский муниципальный район, Верхнеяхшеевское сельское поселение, д.Верхнеяхшеево, ул.Победы, ул.59	Россия, республика Татарстан, Актанышский район, село Верхнее Яхшеево	0101000020E61000008E5A61FA5EDD4A40A31D37FC6EBC4B40
93509	7	64	1851	29292	78851	\N	55.814179000000003	Республика Татарстан (Татарстан), Актанышский муниципальный район, Масадинское сельское поселение, д.Барсуково, ул.Куйбышева, д.4		0101000020E61000006403E962D3EC4A40850B790437E84B40
93508	7	64	1851	29201	78848	\N	55.616193000000003	Республика Татарстан (Татарстан), Актанышский муниципальный район, Атясевское сельское поселение, с.Атясево, ул.Центральная, д.76		0101000020E6100000E4BED53A71D14A4017838769DFCE4B40
93498	7	64	1851	28752	69627	\N	55.721517669772197	Республика Татарстан (Татарстан), Актанышский муниципальный район, Актанышское сельское поселение, с.Актаныш, пр.Ленина, д.42	Россия, республика Татарстан, Актанышский район, село Актаныш	0101000020E61000008386FE092E084B40D8BCAAB35ADC4B40
93503	7	64	1851	28752	67720	\N	55.717207999999999	Республика Татарстан (Татарстан), Актанышский муниципальный район, Актанышское сельское поселение, с.Актаныш, ул.Юбилейная, д.111		0101000020E6100000AF78EA9106094B40FC36C478CDDB4B40
55196	7	63	1108	49497	54390	\N	54.436413000000002	рабочий поселок Комсомольский, Комсомольская, 5		0101000020E6100000CB2F833122E946404E469561DC374B40
93500	7	64	1851	28752	67720	\N	55.719095367181602	Республика Татарстан (Татарстан), Актанышский муниципальный район, Актанышское сельское поселение, с.Актаныш, ул.Юбилейная, д.66	Россия, республика Татарстан, Актанышский район, село Актаныш	0101000020E61000004F779E78CE064B40CBDB114E0BDC4B40
93499	7	64	1851	28752	67720	\N	55.719507169266599	Республика Татарстан (Татарстан), Актанышский муниципальный район, Актанышское сельское поселение, с.Актаныш, ул.Юбилейная, д.4	Россия, республика Татарстан, Актанышский район, село Актаныш	0101000020E6100000ECFB709010074B401D1F2DCE18DC4B40
93501	7	64	1851	28752	78184	\N	55.714650049461397	Республика Татарстан (Татарстан), Актанышский муниципальный район, Актанышское сельское поселение, с.Актаныш, Центральная, 36б	Россия, республика Татарстан, Актанышский район, село Актаныш	0101000020E6100000BAD7497D590A4B400F0BB5A679DB4B40
93502	7	64	1851	28752	75264	\N	55.717207999999999	Республика Татарстан (Татарстан), Актанышский муниципальный район, Актанышское сельское поселение, с.Актаныш, Механизаторов, 9		0101000020E6100000AF78EA9106094B40FC36C478CDDB4B40
93507	7	64	1851	29199	78841	\N	55.521664000000001	Республика Татарстан (Татарстан), Актанышский муниципальный район, Аккузовское сельское поселение, с.Аккузово, ул.Центральная, д.1		0101000020E6100000FF3C0D1824F74A4012C0CDE2C5C24B40
93505	7	64	1851	29073	78854	\N	55.629033	Республика Татарстан (Татарстан), Актанышский муниципальный район, Аишевское сельское поселение, с.Аишево, Ленина, 30	Россия, республика Татарстан, Актанышский район, село Аишево	0101000020E6100000B3B112F3AC104B40698D412784D04B40
93504	7	64	1851	29032	78843	\N	55.711508000000002	Республика Татарстан (Татарстан), Актанышский муниципальный район, Кузякинское сельское поселение, д.Адаево, Горького, 2		0101000020E610000040A4DFBE0EC64A40D36BB3B112DB4B40
93488	7	64	1802	28287	78732	\N	54.826199000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Щербень, ул.Лермонтова, д.6		0101000020E6100000A8DF85ADD94C4940747E8AE3C0694B40
93460	7	64	1802	27025	78809	\N	54.909410999999999	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Чувашское Енорускино, ул.Школьная, д.18		0101000020E6100000C23577F4BF7A4940B3CF639467744B40
93491	7	64	1802	61487	79248	\N	54.940526999061703	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Старый Чувашский Адам, ул.Чапаева, д.20		0101000020E6100000A9A27895B5454940A400513063784B40
93456	7	64	1802	26842	78136	\N	55.006120000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Урмандеево, ул.Фрунзе, д.2А		0101000020E61000009869FB5756684940FFEC478AC8804B40
93480	7	64	1802	27951	9833	\N	54.7536265939111	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Трудолюбово, ул.Романова, д.6	Россия, республика Татарстан, Аксубаевский район, село Трудолюбово	0101000020E6100000E36BCF2C094A4940F9307BD976604B40
93495	7	64	1802	28651	78834	\N	54.978596000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Тахтала, ул.Школьная, д.3		0101000020E6100000B63176C24B5249408BFF3BA2427D4B40
93476	7	64	1802	27769	78821	\N	54.717511000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Татарское Сунчелеево, ул.Тукая, д.12		0101000020E61000002C4833164D5D494098C28366D75B4B40
93459	7	64	1802	27024	78808	\N	54.951441000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Тарханка, ул.Западная, д.16		0101000020E61000009CDD5A26C36D49406A8995D1C8794B40
93477	7	64	1802	27843	78832	\N	54.697187999999997	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Сунчелеево, ул.Ленина, д.79		0101000020E6100000B037312427574940F294D5743D594B40
93493	7	64	1802	28513	78835	\N	55.014209999999999	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Старый Татарский Адам, ул.Центральная, д.17		0101000020E6100000A8DF85ADD94C494059A31EA2D1814B40
93455	7	64	1802	26835	78801	\N	54.998685000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Старые Савруши, ул.Комсомольская, д.20		0101000020E61000007E52EDD3F15C4940BD00FBE8D47F4B40
93496	7	64	1802	28655	78144	\N	54.737554000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Старые Киязлы, ул.Центральная, д.54		0101000020E61000003C17467A518949405A84622B685E4B40
93471	7	64	1802	27572	78817	\N	54.698582000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Старое Узеево, ул.Ленина, д.2А		0101000020E61000002C7FBE2D5872494082C98D226B594B40
93466	7	64	1802	27281	78137	\N	54.735177999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Старое Тимошкино, ул.Ленина, д.27		0101000020E610000018247D5A457F49408D5E0D501A5E4B40
93474	7	64	1802	27672	78825	\N	54.709527999999999	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Старое Мокшино, ул.Зеленая, д.1		0101000020E6100000EC17EC866D67494053CC41D0D15A4B40
93458	7	64	1802	26944	78807	\N	54.892353999999997	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Старое Ильдеряково, ул.Советская, д.13		0101000020E610000099654F029B6F4940363AE7A738724B40
93461	7	64	1802	27105	75263	\N	54.860740999999997	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Старое Ибрайкино, ул.Кооперативная, д.2		0101000020E61000001938A0A52B844940C5A9D6C22C6E4B40
93453	7	64	1802	26750	78803	\N	54.913519999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Старая Киреметь, ул.Ленина, д.37		0101000020E61000009BC6F65AD0634940F71E2E39EE744B40
21435	7	61	831	32595	64046	\N	52.781967000000002	д.Кананикольск, ул.Ленина, 24		0101000020E61000007E737FF5B8BD4C408FC6A17E17644A40
93492	7	64	1802	61441	79181	\N	54.916573902879598	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Сосновка, ул.Садовая, д.12	Россия, республика Татарстан, Аксубаевский район, село Сосновка	0101000020E610000028B85851834B4940942EFD4B52754B40
93457	7	64	1802	26891	78139	\N	54.998587000000001	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Савгачево, ул.Советская, д.2А		0101000020E6100000C784984BAA624940FA9AE5B2D17F4B40
93487	7	64	1802	28243	78836	\N	54.888227000000001	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Русская Киреметь, ул.Новостройки, д.29		0101000020E6100000548D5E0D505A49404C361E6CB1714B40
93475	7	64	1802	27715	78833	\N	54.667811	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, п.Пионер, ул.Центральная, д.1		0101000020E6100000CB65A3737E5C49405C74B2D47A554B40
93481	7	64	1802	27988	78796	\N	54.712460999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Октябрь, ул.Садовая, д.4		0101000020E6100000E57B4622344E494075560BEC315B4B40
93489	7	64	1802	28373	78704	\N	54.983685000000001	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Новый Чувашский Адам, ул.Советская, д.4		0101000020E61000009561DC0DA24949406B48DC63E97D4B40
93468	7	64	1802	27386	78812	\N	54.709423999999999	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Новое Узеево, ул.Школьная, д.7		0101000020E6100000C3482F6AF7754940AE7FD767CE5A4B40
93467	7	64	1802	27372	78813	\N	54.778793	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Новое Тимошкино, ул.Центральная, д.8		0101000020E61000008F37F92D3A7F494047AD307DAF634B40
93472	7	64	1802	27579	78818	\N	54.736114000000001	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Новое Мокшино, ул.Ленина, д.20		0101000020E6100000840F255AF26E49405A10CAFB385E4B40
93452	7	64	1802	26662	78797	\N	54.90014	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Новое Ильдеряково, ул.Центральная, д.7		0101000020E6100000D40CA9A27873494025E99AC937734B40
93462	7	64	1802	27115	75152	\N	54.867513000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Новое Ибрайкино, ул.Советская, д.25		0101000020E6100000DB19A6B6D49549406CED7DAA0A6F4B40
93485	7	64	1802	28189	78859	\N	54.810521999999999	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Новое Демкино, ул.Калинина, д.13А		0101000020E6100000F8C43A55BE5949402158552FBF674B40
93463	7	64	1802	27153	78690	\N	54.837336999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Новое Аксубаево, ул.Центральная, д.27		0101000020E61000002AC58EC6A1724940895DDBDB2D6B4B40
93486	7	64	1802	28201	78831	\N	54.848657681220999	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Новая Киреметь, ул.Мусы Джалиля, д.15А	Россия, республика Татарстан, Аксубаевский район, село Новая Киреметь	0101000020E61000007FA4880CAB5A494090BE49D3A06C4B40
93494	7	64	1802	28569	78840	\N	55.036613000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Нижняя Татарская Майна, ул.Центральная, д.2		0101000020E610000074D3669C86424940E2CD1ABCAF844B40
93484	7	64	1802	28108	78828	\N	54.788522999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Нижняя Баланда, ул.Зеленая, д.18		0101000020E6100000BAA3FFE55A60494068925852EE644B40
93454	7	64	1802	26756	78802	\N	55.039893999999997	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Нижние Савруши, ул.Центральная, д.22		0101000020E6100000E5B9BE0F075749403FA7203F1B854B40
93473	7	64	1802	27656	78820	\N	54.710031999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, п.МЮД, ул.Центральная, д.27		0101000020E6100000B1868BDCD3634940868E1D54E25A4B40
93478	7	64	1802	27851	78827	\N	54.656016000000001	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Малое Сунчелеево, ул.Гагарина, д.8		0101000020E610000044C2F7FE065349408DD31055F8534B40
93464	7	64	1802	27206	78693	\N	54.811638000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Малое Аксубаево, ул.Лесная, д.29		0101000020E61000004ED026874F7449406E1805C1E3674B40
93483	7	64	1802	28102	78829	\N	54.767907999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Кривоозерки, ул.Школьная, д.1		0101000020E6100000249D8191975D49401B2B31CF4A624B40
93465	7	64	1802	27280	78810	\N	54.855609999999999	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Кисы, ул.Ленина, д.12		0101000020E61000003C6A4C88B96E4940B610E4A0846D4B40
93497	7	64	1802	28742	78839	\N	54.763154999999998	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Кзыл-Тау, ул.Гафиятуллина, д.23		0101000020E6100000A321E3512A894940B2632310AF614B40
93479	7	64	1802	27938	78844	\N	54.738604000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Караса, ул.Кирова, д.20		0101000020E610000051F52B9D0F574940EF586C938A5E4B40
93490	7	64	1802	28377	78706	\N	54.971383000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, с.Емелькино, ул.Центральная, д.10		0101000020E610000027840EBA84474940F8713447567C4B40
93469	7	64	1802	27430	78816	\N	54.711993	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, д.Беловка, ул.Полевая, д.1		0101000020E610000008AEF204C27A49408FFD2C96225B4B40
93470	7	64	1802	27484	78815	\N	54.673205000000003	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, п.Алексеевка, ул.Зеленая, д.21		0101000020E61000003FFF3D78ED7C49407940D9942B564B40
93410	7	64	1309	24734	78121	\N	54.885812999999999	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Мальбагуш, ул.Нефтяников, д.30		0101000020E6100000BD72BD6DA6684A4092AF045262714B40
93451	7	64	1802	26496	75256	\N	54.850090000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, поселок городского типа Аксубаево, ул.Школьная, д.4А		0101000020E6100000E2E5E95C516849400D54C6BFCF6C4B40
93448	7	64	1802	26496	75255	\N	54.850090000000002	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, поселок городского типа Аксубаево, ул.Романова, д.2		0101000020E6100000E2E5E95C516849400D54C6BFCF6C4B40
93450	7	64	1802	26496	68159	\N	54.836619899408497	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, поселок городского типа Аксубаево, ул.Мазилина, д.39	Россия, республика Татарстан, Аксубаевский район, поселок Аксубаево	0101000020E61000002975C93846664940FB96395D166B4B40
93449	7	64	1802	26496	68159	\N	54.835926316082997	Республика Татарстан (Татарстан), Аксубаевский муниципальный район, поселок городского типа Аксубаево, ул.Мазилина, д.2	Россия, республика Татарстан, Аксубаевский район, поселок Аксубаево	0101000020E61000002975C9384666494024F0879FFF6A4B40
93446	7	64	1309	26367	78838	\N	55.088743000000001	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Чубар-Абдуллово, ул.Советская, д.85		0101000020E6100000F9A23D5E48734A40DD5F3DEE5B8B4B40
93409	7	64	1309	24724	78777	\N	54.765326999999999	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Чемодурово, ул.Нагорная, д.3а		0101000020E610000042B5C189E86D4A4076DF313CF6614B40
93430	7	64	1309	61403	79134	\N	54.921762999999999	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Чекан, ул.Базарная, д.2	Россия, республика Татарстан, Азнакаевский район	0101000020E6100000F3AACE6A81954A40D8D47954FC754B40
93441	7	64	1309	26149	78085	\N	55.086976	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Чалпы, ул.Центральная, д.24		0101000020E61000001494A2957B894A40B9C49107228B4B40
93435	7	64	1309	25934	78790	\N	54.911558999999997	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Учалле, ул.Советская, д.51		0101000020E61000002C7DE882FAA64A40EEAF1EF7AD744B40
93438	7	64	1309	26029	78131	\N	55.082585999999999	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Урсаево, ул.Советская, д.14		0101000020E610000005F9D9C8759D4A40C18D942D928A4B40
93427	7	64	1309	25551	78794	\N	54.836019999999998	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Урманаево, ул.Татарстана, д.27а		0101000020E610000093E34EE960AD4A40A5660FB4026B4B40
93419	7	64	1309	25161	9776	\N	54.870600004103203	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Уразаево, ул.Энгельса, д.63	Россия, республика Татарстан, Азнакаевский район, село Уразаево	0101000020E61000005A12A0A696954A40E5F21FD26F6F4B40
93437	7	64	1309	26026	69945	\N	55.018515000000001	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Тумутук, ул.Тельмана, д.62		0101000020E6100000E9B81AD995A64A4023BE13B35E824B40
93443	7	64	1309	26227	78791	\N	55.146425000000001	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Татарский Шуган, ул.Советская, д.41в		0101000020E610000063601DC70F854A408D28ED0DBE924B40
93426	7	64	1309	25457	78642	\N	54.743630000000003	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Таллы-Буляк, ул.Центральная, д.10		0101000020E6100000A180ED60C4A04A40892991442F5F4B40
93420	7	64	1309	61500	79258	\N	54.808491052815597	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Тойкино, ул.Джалиля, д.19	Россия, республика Татарстан, Азнакаевский район, село Тайкино	0101000020E6100000A9A0A2EA578A4A401F0E12A27C674B40
93433	7	64	1309	25799	78125	\N	54.958860000000001	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Сарлы, ул.Центральная, д.74		0101000020E6100000B4AA251DE5BA4A40A6B8AAECBB7A4B40
93421	7	64	1309	25252	78081	\N	54.903976	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Сапеево, ул.Школьная, д.46а		0101000020E6100000E3FA777DE6904A40382F4E7CB5734B40
93429	7	64	1309	25606	78079	\N	54.866129999999998	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, п.Победа, ул.Центральная, д.29		0101000020E610000086C77E164BB34A40D00A0C59DD6E4B40
93428	7	64	1309	52144	78645	\N	54.760724000000003	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, п.Первое Мая, ул.Средняя, д.14		0101000020E61000006C5F402FDCA94A4023A46E675F614B40
93417	7	64	1309	61411	79145	\N	54.877582573560701	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Маняуз, ул.Советская, д.1а	Россия, республика Татарстан, Азнакаевский район, село Мяняус	0101000020E6100000F6EFFACC59834A404643C6A354704B40
93444	7	64	1309	26277	78795	\N	55.125318999999998	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Мяндей, ул.Новая, 2а		0101000020E61000006939D0436D714A40A148F7730A904B40
93439	7	64	1309	26074	78648	\N	55.040115999999998	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Муслюмово, ул.Гафури, д.31		0101000020E61000003C873254C5944A40EE05668522854B40
93424	7	64	1309	25365	78624	\N	54.820326999999999	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Митряево, ул.Тукая, д.15а		0101000020E6100000DF6DDE3829A64A404D83A27900694B40
93403	7	64	1309	24421	78119	\N	54.725825999999998	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Микулино, ул.Советская, д.74		0101000020E6100000BCB1A030285F4A40124BCADDE75C4B40
93412	7	64	1309	24838	78783	\N	54.998091000000002	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Масягутово, ул.Багманова, д.16		0101000020E61000007C65DEAAEB724A404AB72572C17F4B40
93436	7	64	1309	25938	78787	\N	55.003718999999997	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Кук-Тяка, ул.Ленина, д.40		0101000020E610000042EA76F695B14A40D9AF3BDD79804B40
93425	7	64	1309	25454	78080	\N	54.785682999999999	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Карамалы, ул.Молодежная, д.3		0101000020E6100000758E01D9EB974A40F702B34291644B40
93414	7	64	1309	24917	78132	\N	54.945763999999997	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Какре-Елга, ул.Советская, д.22		0101000020E6100000F2B6D26BB3754A40F8DD74CB0E794B40
93440	7	64	1309	26143	78665	\N	55.022402	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Ирекле, ул.Гагарина, д.43		0101000020E61000006E8786C5A8814A40B8AE9811DE824B40
93413	7	64	1309	24911	78781	\N	55.033698000000001	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Ильбяково, ул.Валеева, д.53		0101000020E610000048A643A7E76D4A4066F84F3750844B40
93431	7	64	1309	25750	78082	\N	54.903536000000003	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Верхнее Стярле, ул.Советская, д.32г		0101000020E61000008A73D4D171BB4A401C615111A7734B40
93447	7	64	1309	26422	78798	\N	55.077195000000003	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Буралы, ул.Октябрьская, д.34		0101000020E6100000430070ECD96B4A4016359886E1894B40
93434	7	64	1309	25882	78785	\N	54.981918	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Буляк, ул.Центральная, д.26а		0101000020E6100000C2C2499A3FB64A4047AD307DAF7D4B40
93422	7	64	1309	25264	78077	\N	54.991588999999998	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Большой Сухояш, ул.Советская, д.34		0101000020E61000007E3672DD94924A4063096B63EC7E4B40
93408	7	64	1309	24635	78771	\N	54.693384000000002	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Бирючевка, ул.Центральная, д.27		0101000020E61000001FD7868A71664A40EBC891CEC0584B40
270	7	64	1309	13816	10361	\N	54.787563317597602	Республика Татарстан, Камско-Устьинский муниципальный район, с.Балтачево, ул.Центральная, д.1	Россия, республика Татарстан, Азнакаевский район, село Балтачево	0101000020E610000022A5D93C0E854A40134548DDCE644B40
93418	7	64	1309	13816	78780	\N	54.787733000000003	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Балтачево, ул.Молодежная, д.1а		0101000020E6100000A7CEA3E2FF844A40707D586FD4644B40
93442	7	64	1309	26188	78792	\N	55.089032000000003	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, д.Балан-Буляк, ул.Октябрьская, д.39		0101000020E61000005EA0A4C0027E4A4014268C66658B4B40
93423	7	64	1309	25310	78616	\N	54.836019999999998	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Асеево, ул.Центральная, д.38г		0101000020E610000051A4FB39059F4A40A5660FB4026B4B40
93411	7	64	1309	24786	78772	\N	54.933683000000002	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Алькеево, ул.Советская, д.34		0101000020E610000087DF4DB7EC644A4064EAAEEC82774B40
93406	7	64	1309	24436	68148	\N	54.814227000000002	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, пгт.Актюбинский, ул.Лесная, д.17а		0101000020E61000007D03931B45664A409642209738684B40
93407	7	64	1309	24436	75247	\N	54.814227000000002	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, пгт.Актюбинский, ул.Комарова, д.5		0101000020E61000007D03931B45664A409642209738684B40
93405	7	64	1309	24436	69936	\N	54.811252588065898	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, пгт.Актюбинский, ул.Губкина, д.16	Россия, республика Татарстан, Азнакаевский район, поселок Актюбинский	0101000020E610000064062AE3DF674A4015E46723D7674B40
93404	7	64	1309	24436	78145	\N	54.814227000000002	Республика Татарстан (Татарстан), Азнакаевский муниципальный район, пгт.Актюбинский, ул.Булатова, д.16		0101000020E61000007D03931B45664A409642209738684B40
93416	7	64	1309	24993	79350	\N	54.830353000000002	423303, Адрес УИК и помещения для голосования: Республика Татарстан (Татарстан), Азнакаевский муниципальный район, с.Агерзе, ул.Хакима (здание школы с.Агерзе), д.10		0101000020E6100000B0E2546B61804A405891D101496A4B40
93356	7	64	1646	22214	79291	\N	56.213991	422211, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Агрызский муниципальный район, с.Янга-Аул, ул.Молодежная (здание сельского ДК), д.10а		0101000020E6100000AC72A1F2AF694A40B5519D0E641B4C40
93369	7	64	1646	22780	78759	\N	56.005420000000001	Республика Татарстан (Татарстан), Агрызский муниципальный район, Салаушское сельское поселение, село Ямурзино, ул. Советская, д. 63		0101000020E61000007A6F0C01C0814A40465F419AB1004C40
93366	7	64	1646	22659	78756	\N	56.099545999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Шаршадинское сельское поселение, село Шаршада, ул. Лесоводов, д. 20		0101000020E6100000AAD381ACA7824A404B395FECBD0C4C40
93382	7	64	1646	23379	78770	\N	56.159041999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, Старосляковское сельское поселение, село Утяганово, ул. Центральная, д. 35		0101000020E610000093C6681D55C34A406058FE7C5B144C40
93370	7	64	1646	22831	78757	\N	56.005716999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Салаушское сельское поселение, деревня Уразаево, ул. Ленина, д. 32		0101000020E6100000DF1797AAB4794A40FF03AC55BB004C40
93350	7	64	1646	21918	78088	\N	56.333321003143297	Республика Татарстан (Татарстан), Агрызский муниципальный район, Терсинское сельское поселение, село Терси, ул. Школьная, д. 3	Россия, республика Татарстан, Агрызский район, село Терси	0101000020E6100000A1BB24CE8A724A40F6083543AA2A4C40
93349	7	64	1646	21918	78057	\N	56.330888999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, Терсинское сельское поселение, село Терси, ул. Центральная, д. 163		0101000020E610000015527E52ED714A4096CD1C925A2A4C40
93354	7	64	1646	22119	78604	\N	56.282966516794602	Республика Татарстан (Татарстан), Агрызский муниципальный район, Табарлинское сельское поселение, село Табарле, ул. Ленина, д. 8а	Россия, республика Татарстан, Агрызский район, село Табарле	0101000020E61000002C64AE0CAA574A40726C3D4338244C40
93355	7	64	1646	22201	78609	\N	56.248570999999998	Республика Татарстан (Татарстан), Агрызский муниципальный район, Табарлинское сельское поселение, село Сукман, ул. Карла Маркса, д. 6а		0101000020E610000097C62FBC924C4A40F4DDAD2CD11F4C40
93381	7	64	1646	23320	78775	\N	56.178412999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, Старосляковское сельское поселение, село Старое Сляково, ул. Клубная, д. 1		0101000020E6100000745C8DEC4AC14A403317B83CD6164C40
93368	7	64	1646	22741	78765	\N	56.076357999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, Старочекалдинское сельское поселение, село Старая Чекалда, ул. Зеленая, д. 11		0101000020E6100000CC5F217365924A40DC645419C6094C40
93383	7	64	1646	23450	78779	\N	56.222479999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Девятернинское сельское поселение, село Сосново, ул. Центральная, д. 22		0101000020E6100000906802452CBA4A40CD0182397A1C4C40
93351	7	64	1646	21968	79325	\N	56.311062	422206, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Агрызский муниципальный район, с.Сарсак-Омга, пл.Кирова (здание лицея), д.13		0101000020E6100000789ACC785B694A40A1832EE1D0274C40
93371	7	64	1646	61387	79112	\N	55.991876680494002	Республика Татарстан (Татарстан), Агрызский муниципальный район, Салаушское сельское поселение, село Салауши, ул. Ленина, д. 73а	Россия, республика Татарстан, Агрызский район, село Салауш	0101000020E610000040F850A225714A40CA5356D3F5FE4B40
93376	7	64	1646	23106	78763	\N	56.026130999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, Бимское сельское поселение, село Пелемеш, ул. Ленина, д. 49а		0101000020E61000004AECDADE6EA54A40B534B74258034C40
93353	7	64	1646	22117	78603	\N	56.267246999999998	Республика Татарстан (Татарстан), Агрызский муниципальный район, Табарлинское сельское поселение, село Новое Аккузино, ул. Ленина, д. 34б		0101000020E610000014ED2AA4FC5E4A40207A522635224C40
93358	7	64	1646	22309	79275	\N	56.205260000000003	422210, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Агрызский муниципальный район, с.Кучуково, ул.Ленина (здание сельского ДК), д.12		0101000020E6100000965D30B8E6764A40A796ADF5451A4C40
93374	7	64	1646	61459	79205	\N	55.975415328214602	Республика Татарстан (Татарстан), Агрызский муниципальный район, Кулегашское сельское поселение, село Кулегаш, ул. Советская, д. 38		0101000020E6100000C57421567FA24A4090831266DAFC4B40
93348	7	64	1646	21824	79349	\N	56.368603999999998	422205, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Агрызский муниципальный район, с.Кудашево, ул.Тукая (здание селького ДК), д.8		0101000020E61000005E13D21A83684A405F96766A2E2F4C40
93362	7	64	1646	22473	78116	\N	56.141692999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Крындинское сельское поселение, село Крынды, ул. Советская, д. 33		0101000020E6100000ABE80FCD3C754A403B8908FF22124C40
93375	7	64	1646	23041	69541	\N	55.891424699150299	Республика Татарстан (Татарстан), Агрызский муниципальный район, Красноборское сельское поселение, село Красный Бор, ул. Маркина, д. 34	Россия, республика Татарстан, Агрызский район, село Красный Бор	0101000020E6100000C9C6832D768B4A401CEBE2361AF24B40
93364	7	64	1646	61369	78989	\N	56.0731128653889	Республика Татарстан (Татарстан), Агрызский муниципальный район, Кичкетанское сельское поселение, село Кичкетан, ул. М. Джалиля, д. 2	Россия, республика Татарстан, Агрызский район, село Кичке-Тан	0101000020E6100000D7BE805EB86B4A40CBF44BC45B094C40
93373	7	64	1646	22994	78619	\N	55.981757000000002	Республика Татарстан (Татарстан), Агрызский муниципальный район, Азевское сельское поселение, деревня Каменный Ключ, ул. Шкетана, д. 6		0101000020E610000046072461DF9C4A403ECF9F36AAFD4B40
93380	7	64	1646	23274	78806	\N	56.158665999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Кадыбашское сельское поселение, село Кадыбаш, ул. Клубная, д. 49а		0101000020E610000077137CD3F4B54A405A7EE02A4F144C40
93367	7	64	1646	22737	78774	\N	56.142696000000001	Республика Татарстан (Татарстан), Агрызский муниципальный район, Кадряковское сельское поселение, село Кадряково, ул. Ленина, д. 55		0101000020E610000006836BEEE8914A4090A2CEDC43124C40
93379	7	64	1646	23266	78122	\N	56.048499999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Исенбаевское сельское поселение, село Исенбаево, ул. Советская, д. 79		0101000020E6100000978FA4A487B54A4091ED7C3F35064C40
93344	7	64	1646	21637	78598	\N	56.468387824022599	Республика Татарстан (Татарстан), Агрызский муниципальный район, Иж-Бобьинское сельское поселение, село Иж-Бобья, ул.Центральная, д. 20	Россия, республика Татарстан, Агрызский район, село Иж-Бобья	0101000020E61000000CAF2479AE7F4A405FEB5223F43B4C40
55278	7	63	\N	1332	\N	\N	54.1949957002454	Республика Мордовия, город Саранск, Октябрьский район, п.Пушкино, Пушкинская начальная общеобразовательная школа		0101000020E610000010B3976DA79D4640E86C01A1F5184B40
93345	7	64	1646	21674	78597	\N	56.404335943382101	Республика Татарстан (Татарстан), Агрызский муниципальный район, Иж-Бобьинское сельское поселение, деревня Иж-Байки, ул. Центральная, д. 20	Россия, республика Татарстан, Агрызский район, село Иж-Байки	0101000020E610000041481630817B4A40384C3448C1334C40
93384	7	64	1646	23459	78773	\N	56.20196	Республика Татарстан (Татарстан), Агрызский муниципальный район, Девятернинское сельское поселение, село Девятерня, ул. Советская, д. 48		0101000020E61000009430D3F6AFB24A40D28C45D3D9194C40
93361	7	64	1646	61519	79284	\N	56.210436000000001	"422210, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Агрызский муниципальный район, с.Варклед Бодья, ул.Ленина (здание ООО ""Агрофирма ""Ак Барс-Агрыз""), д.6"	Россия, республика Татарстан, Агрызский район, село Варкледбодья	0101000020E61000000394861A85704A4056F31C91EF1A4C40
93363	7	64	1646	61483	79233	\N	56.0648596012038	Республика Татарстан (Татарстан), Агрызский муниципальный район, Кичкетанское сельское поселение, село Варзи-Пельга, ул. Клубная, д. 2	Россия, республика Татарстан, Агрызский район, село Варзипельга	0101000020E6100000C85F5AD427734A40C7681D554D084C40
93365	7	64	1646	22654	78755	\N	56.056688999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, Кичкетанское сельское поселение, село Варзи-Омга, ул. Клубная, д. 1		0101000020E610000091D10149D8634A407F85CC9541074C40
93378	7	64	1646	23182	78768	\N	56.006929999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Бимское сельское поселение, село Бима, ул. Ленина, д. 1		0101000020E61000003EB0E3BF40AC4A403EAE0D15E3004C40
93346	7	64	1646	21737	78605	\N	56.384295000000002	Республика Татарстан (Татарстан), Агрызский муниципальный район, Кудашевское сельское поселение, село Биктово, ул. Сайдашева, д. 2		0101000020E6100000C493DDCCE8734A4017821C9430314C40
93372	7	64	1646	22905	78760	\N	56.000884999999997	Республика Татарстан (Татарстан), Агрызский муниципальный район, Азевское сельское поселение, село Азево, ул. Советская, д. 22		0101000020E61000007AFF1F274C924A404A07EBFF1C004C40
93334	7	64	1646	20870	67588	\N	56.528072107780801	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Энергетиков, д. 8	Россия, республика Татарстан, Агрызский район, Агрыз	0101000020E6100000D06053E7517D4A4077F700DD97434C40
93328	7	64	1646	20870	78045	\N	56.519004984282802	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Чапаева, д. 3	Россия, республика Татарстан, Агрызский район, Агрыз	0101000020E610000035F0A31AF67D4A40F1BA7EC16E424C40
93335	7	64	1646	20870	78060	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Саетова, д. 11		0101000020E610000014234BE658804A40581CCEFC6A424C40
93331	7	64	1646	20870	75234	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Пушкина, д. 4		0101000020E610000014234BE658804A40581CCEFC6A424C40
93336	7	64	1646	20870	78068	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Октябрьская, д. 25а		0101000020E610000014234BE658804A40581CCEFC6A424C40
93330	7	64	1646	20870	78036	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Карла Маркса, д. 7		0101000020E610000014234BE658804A40581CCEFC6A424C40
93341	7	64	1646	20870	67637	\N	56.511009401750101	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Карла Маркса, д. 87	Россия, республика Татарстан, Агрызский район, Агрыз	0101000020E6100000F2B391EBA67E4A40187B2FBE68414C40
93340	7	64	1646	20870	67637	\N	56.518832990317897	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Карла Маркса, д. 108	Россия, республика Татарстан, Агрызский район, Агрыз	0101000020E6100000B4E908E0667F4A40F48AA71E69424C40
93332	7	64	1646	20870	67637	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Карла Маркса, д. 9		0101000020E610000014234BE658804A40581CCEFC6A424C40
93329	7	64	1646	20870	67637	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Карла Маркса, д. 4а		0101000020E610000014234BE658804A40581CCEFC6A424C40
93342	7	64	1646	20870	79289	\N	56.518889999999999	422230, Адрес УИК и помещения для голосования:Республика Татарстан (Татарстан), Агрызский муниципальный район, г.Агрыз, ул.Заводская (здание завода АЗСМ), д.59		0101000020E610000014234BE658804A40581CCEFC6A424C40
93333	7	64	1646	20870	78047	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Гагарина, д. 56		0101000020E610000014234BE658804A40581CCEFC6A424C40
93339	7	64	1646	20870	75236	\N	56.518889999999999	Республика Татарстан (Татарстан), Агрызский муниципальный район, город Агрыз, ул. Вокзальная, д. 1		0101000020E610000014234BE658804A40581CCEFC6A424C40
1379	7	64	6930	40921	11599	\N	55.363052735543498	Республика Татарстан (Татарстан), Чистопольский муниципальный район, город Чистополь, ул.Мира, д.40		0101000020E6100000D4D2DC0A615349407BDB4C8578AE4B40
94307	7	64	6923	61389	79116	\N	55.754882000000002	Республика Татарстан (Татарстан), Елабужский муниципальный район, г.Елабуга, ул.Радищева, д.5		0101000020E61000006614CB2DAD064A40672B2FF99FE04B40
55125	7	63	\N	56537	54445	\N	54.631102751890403	Республика Мордовия, Темниковский муниципальный район, городское поселение Темников, Советская, 45		0101000020E6100000E5F04927129C454029B4ACFBC7504B40
21434	7	61	831	17541	65557	\N	51.991152999999997	д.Кадырша, ул.Акмуллы, 25		0101000020E6100000F0FACC599FD04C40882AFC19DEFE4940
54931	7	63	\N	1332	501	\N	54.182675000000003	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Новое Мамангино, Школьная, 1	Россия, республика Мордовия, Саранск, улица Школьная, 1	0101000020E61000004E7ADFF8DA934640FE65F7E461174B40
55173	7	63	\N	1332	4905	\N	54.183807999999999	рп Торбеево, Ленина, 7	Россия, республика Мордовия, Саранск, проспект Ленина, 7	0101000020E6100000EEB1F4A10B984640205F420587174B40
55235	7	63	\N	1332	54385	\N	54.185329289451097	Республика Мордовия, город Саранск, Ленинский район, пр. им. В.И. Ленина, 11	Россия, республика Мордовия, Саранск, проспект Ленина, 11	0101000020E6100000FEBAD39D279846400D0055DCB8174B40
55233	7	63	\N	1332	54385	\N	54.186973698096899	Республика Мордовия, город Саранск, Ленинский район, пр. им.В.И. Ленина, 15	Россия, республика Мордовия, Саранск, проспект Ленина, 15	0101000020E6100000DC2F9FAC18984640E59997C3EE174B40
55232	7	63	\N	1332	54385	\N	54.190257402746099	Республика Мордовия, город Саранск, Ленинский район, пр. им. В.И. Ленина, 24	Россия, республика Мордовия, Саранск, проспект Ленина, 24	0101000020E610000066F9BA0CFF974640E46A64575A184B40
55272	7	63	\N	1332	7244	\N	54.192748000000002	Республика Мордовия, городской округ Саранск, Октябрьский район, 70 лет Октября, 160	Россия, республика Мордовия, Саранск, проспект 70 лет Октября, 160	0101000020E61000001EDC9DB5DB9E4640492F6AF7AB184B40
55270	7	63	\N	1332	7244	\N	54.192748000000002	Республика Мордовия, город Саранск, Октябрьский район, 70 лет Октября, 160	Россия, республика Мордовия, Саранск, проспект 70 лет Октября, 160	0101000020E61000001EDC9DB5DB9E4640492F6AF7AB184B40
55267	7	63	\N	1332	7244	\N	54.193137999999998	Республика Мордовия, город Саранск, Октябрьский район, 70 лет Октября, 70	Россия, республика Мордовия, Саранск, проспект 70 лет Октября, 70	0101000020E610000033A48AE2559C4640B3CEF8BEB8184B40
55266	7	63	\N	1332	7244	\N	54.194285999999998	Республика Мордовия, город Саранск, Октябрьский район, 70 лет Октября, 102	Россия, республика Мордовия, Саранск, проспект 70 лет Октября, 102	0101000020E6100000F435CB65A39D46400B09185DDE184B40
55298	7	63	\N	1332	7548	\N	54.222048000000001	Республика Мордовия, город Саранск, Пролетарский район, пр-т 60 лет Октября, 101	Россия, республика Мордовия, Саранск, проспект 60 лет Октября, 103	0101000020E6100000E2B034F0A39046403412A1116C1C4B40
55296	7	63	\N	1332	7548	\N	54.218923823571899	Республика Мордовия, город Саранск, Пролетарский район, 60  лет Октября, 12а	Россия, республика Мордовия, Саранск, проспект 60 лет Октября, 12а	0101000020E61000008978EBFCDB8F46409E279EB3051C4B40
55294	7	63	\N	1332	7548	\N	54.222087293514399	Республика Мордовия, город Саранск, Пролетарский район, 60 лет Октября, 101	Россия, республика Мордовия, Саранск, проспект 60 лет Октября, 103	0101000020E6100000D6027B4CA4904640F2EEC8586D1C4B40
55274	7	63	\N	1332	7311	\N	54.1975789238777	Республика Мордовия, город Саранск, Октябрьский район, Ст.Эрьзи, 28а	Россия, республика Мордовия, Саранск, улица Тани Бибиной, 28а	0101000020E6100000118E59F624A046402DB0C7444A194B40
55252	7	63	\N	1332	54504	\N	54.215156999999998	Республика Мордовия, город Саранск, Октябрьский район, Энергетическая, 10а		0101000020E61000007E52EDD3F1984640B340BB438A1B4B40
55219	7	63	\N	1332	54472	\N	54.175370999999998	Республика Мордовия, город Саранск, Ленинский район, Щорса, 29		0101000020E610000030293E3E219346405AD5928E72164B40
55277	7	63	\N	1332	54395	\N	54.148472392582804	Республика Мордовия, город Саранск, Октябрьский район, р.п.Николаевка, Школьная, 16	Россия, республика Мордовия, Саранск, Школьная площадь, 16	0101000020E61000006682E15CC3924640942F682101134B40
95136	7	63	\N	1332	54662	\N	54.182501000000002	"""п. """"Совхоз """"Коммунар"""", Школьная, 3 А"""		0101000020E61000005B5CE333D9934640603E59315C174B40
55146	7	63	\N	1332	54662	\N	54.182222972181599	Республика Мордовия, Темниковский муниципальный район, сельское поселение Баево, Школьная, 5		0101000020E610000061191BBAD99346401DCA501553174B40
55221	7	63	\N	1332	54509	\N	54.176394000000002	Республика Мордовия, город Саранск, Ленинский район, Фурманова, 34а		0101000020E61000006C06B8205B924640F69A1E1494164B40
55225	7	63	\N	1332	54453	\N	54.1814421279716	Республика Мордовия, город Саранск, Ленинский район, Ульянова, 26	Россия, республика Мордовия, Саранск, улица Ульянова, 17	0101000020E610000021C8410933934640770FD07D39174B40
55262	7	63	\N	1332	54480	\N	54.159863999999999	Республика Мордовия, город Саранск, Октябрьский район, Транспортная, 17		0101000020E61000002E1F49490F93464064E76D6C76144B40
55261	7	63	\N	1332	54480	\N	54.159516000000004	Республика Мордовия, город Саранск, Октябрьский район, Транспортная, 11		0101000020E6100000B247A81952934640299831056B144B40
55260	7	63	\N	1332	54480	\N	54.159516000000004	Республика Мордовия, город Саранск, Октябрьский район, Транспортная, 9		0101000020E6100000C460FE0A99934640299831056B144B40
55273	7	63	\N	1332	54491	\N	54.199089999999998	Республика Мордовия, город Саранск, Октябрьский район, Сущинского, 5		0101000020E610000089EAAD81AD9E4640F67AF7C77B194B40
55256	7	63	\N	1332	54491	\N	54.201318000000001	Республика Мордовия, город Саранск, Октябрьский район, Сущинского, 24а		0101000020E61000007AFEB4519D9E46404E0CC9C9C4194B40
55258	7	63	\N	1332	54503	\N	54.160829	Республика Мордовия, город Саранск, Октябрьский район, Студенческая, 13		0101000020E6100000B2BAD573D2934640CB9F6F0B96144B40
55257	7	63	\N	1332	54503	\N	54.160496999999999	Республика Мордовия, город Саранск, Октябрьский район, Студенческая, 11а		0101000020E6100000DBC01DA853944640950D6B2A8B144B40
55241	7	63	\N	1332	54477	\N	54.187964999999998	Республика Мордовия, город Саранск, Ленинский район, Ст.Разина, 21		0101000020E6100000C8D3F2035795464075E5B33C0F184B40
54146	7	62	\N	1218	62176	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Прохорова, д. 28		0101000020E6100000628731E9EFEF4740ACE122F774514C40
55249	7	63	\N	1332	1853	\N	54.180109000000002	Республика Мордовия, город Саранск, Ленинский район, Советская, 24	Россия, республика Мордовия, Саранск, Советская улица, 24	0101000020E6100000B471C45A7C9846408E5BCCCF0D174B40
55280	7	63	\N	1332	54471	\N	54.1825680099425	Республика Мордовия, город Саранск, Октябрьский район, с.Зыково, Советская, 124а		0101000020E610000086CABF9657944640E8A562635E174B40
55248	7	63	\N	1332	54471	\N	54.181105000000002	Республика Мордовия, город Саранск, Ленинский район, Советская, 60		0101000020E610000040C05AB56B9646403012DA722E174B40
55247	7	63	\N	1332	54471	\N	54.182032	Республика Мордовия, город Саранск, Ленинский район, Советская, 77		0101000020E6100000782975C938964640A96917D34C174B40
55222	7	63	\N	1332	6816	\N	54.171719000000003	Республика Мордовия, город Саранск, Ленинский район, Серадзская, 26а	Россия, республика Мордовия, Саранск, Серадзская улица, 26а	0101000020E61000006D8D08C6C1914640098D60E3FA154B40
55223	7	63	\N	1332	54494	\N	54.173051999999998	Республика Мордовия, город Саранск, Ленинский район, Серадзская, 21		0101000020E61000009EB5DB2E34914640F240649126164B40
55268	7	63	\N	1332	7235	\N	54.196334999999998	Республика Мордовия, город Саранск, Октябрьский район, Севастопольская, 74	Россия, республика Мордовия, Саранск, Севастопольская улица, 74	0101000020E6100000FEB7921D1B9D4640B3075A8121194B40
55265	7	63	\N	1332	54466	\N	54.190084572369599	Республика Мордовия, город Саранск, Октябрьский район, Севастопольская, 46	Россия, республика Мордовия, Саранск, Севастопольская улица, 46а	0101000020E6100000EE7BD45FAF9C4640E73A8DB454184B40
55216	7	63	\N	1332	6761	\N	54.178269999999998	Республика Мордовия, город Саранск, Ленинский район, Саранская, 52	Россия, республика Мордовия, Саранск, Саранская улица, 52	0101000020E610000035423F53AF954640D0ED258DD1164B40
55224	7	63	\N	1332	54347	\N	54.170369999999998	Республика Мордовия, город Саранск, Ленинский район, Р.Люксембург, 28	Россия, республика Мордовия, Саранск, улица Розы Люксембург, 28	0101000020E61000000EBF9B6ED98F4640191C25AFCE154B40
55284	7	63	\N	1332	54400	\N	54.169445492431997	Республика Мордовия, город Саранск, Октябрьский район, р.п.Луховка, Рабочая, 15	Россия, республика Мордовия, Саранск, рабочий поселок Луховка, улица Рабочая, 15	0101000020E61000001F9DBAF2599C464041BCAE5FB0154B40
55282	7	63	\N	1332	54906	\N	54.194809422712801	Республика Мордовия, город Саранск, Октябрьский район, д.Полянки, Рабочая, 4а	Россия, республика Мордовия, Саранск, Октябрьский район	0101000020E61000002D996379579D4640B5FB5580EF184B40
55312	7	63	\N	1332	54353	\N	54.229502621724897	Республика Мордовия, город Саранск, Пролетарский район, Пушкино, 22	Россия, республика Мордовия, Саранск, улица Пушкина, 22	0101000020E6100000EB8CEF8B4B914640BDAAB35A601D4B40
55238	7	63	\N	1332	54486	\N	54.191752999999999	Республика Мордовия, город Саранск, Ленинский район, Пролетарская, 101а		0101000020E6100000C0249529E696464077F4BF5C8B184B40
55242	7	63	\N	1332	54488	\N	54.191299000000001	Республика Мордовия, город Саранск, Ленинский район, Полежаева, 177		0101000020E610000078978BF84E944640F660527C7C184B40
55236	7	63	\N	1332	54488	\N	54.189003	Республика Мордовия, город Саранск, Ленинский район, Полежаева, 44		0101000020E61000001B800D881097464046EC134031184B40
55306	7	63	\N	1332	54481	\N	54.209437999999999	Республика Мордовия, город Саранск, Пролетарский район, Победы, 23а		0101000020E6100000B75ED383828E4640134548DDCE1A4B40
55305	7	63	\N	1332	54481	\N	54.207264000000002	Республика Мордовия, город Саранск, Пролетарский район, Победы, 4		0101000020E61000009755D80C708F4640AFD172A0871A4B40
55259	7	63	\N	1332	54411	\N	54.1648836822866	Республика Мордовия, город Саранск, Октябрьский район, П.Морозова, 11	Россия, республика Мордовия, Саранск, улица Павлика Морозова, 11	0101000020E610000032AA0CE36E9446401CD13DEB1A154B40
55285	7	63	\N	1332	54377	\N	54.195816196044902	Республика Мордовия, город Саранск, Октябрьский район, р.п.Луховка, Октябрьская, 29	Россия, республика Мордовия, Саранск, Ленинский район, Октябрьская улица, 29	0101000020E6100000E7AA798EC89346404B04AA7F10194B40
55286	7	63	\N	1332	54476	\N	54.167566669055198	Республика Мордовия, город Саранск, Октябрьский район, р.п.Луховка, Октябрьская, 27	Россия, республика Мордовия, Саранск, рабочий поселок Луховка, улица Мичурина, 27	0101000020E61000002524D236FE9A4640C571E0D572154B40
55314	7	63	\N	1332	54396	\N	54.2156880930944	Республика Мордовия, город Саранск, Пролетарский район, Н.Эркая, 16	Россия, республика Мордовия, Саранск, улица Никула Эркая, 16	0101000020E610000094145800538E4640E01115AA9B1B4B40
55255	7	63	\N	1332	54456	\N	54.163322000000001	Республика Мордовия, город Саранск, Октябрьский район, Московская, 115		0101000020E6100000C80BE9F010984640D15B3CBCE7144B40
55251	7	63	\N	1332	54456	\N	54.170802000000002	Республика Мордовия, город Саранск, Ленинский район, Московская, 78		0101000020E61000007EACE0B721984640B30B06D7DC154B40
55250	7	63	\N	1332	54456	\N	54.171835000000002	Республика Мордовия, город Саранск, Ленинский район, Московская, 68		0101000020E6100000A06B5F402F98464072A774B0FE154B40
55288	7	63	\N	1332	54898	\N	54.1662998097448	Республика Мордовия, город Саранск, Октябрьский район, с.Напольная Тавла, Московская, 83б		0101000020E610000019FED30D1498464093A9825149154B40
55254	7	63	\N	1332	54510	\N	54.161355999999998	Республика Мордовия, город Саранск, Октябрьский район, Мокшанская, 16		0101000020E61000008B1BB7989F974640B6813B50A7144B40
55279	7	63	\N	1332	54374	\N	54.127358054921999	Республика Мордовия, город Саранск, Октябрьский район, р.п.Ялга, Мичурина, 34а	Россия, республика Мордовия, Саранск, рабочий поселок Ялга, Пионерская улица, 34	0101000020E61000009354A69883904640267156444D104B40
54120	7	62	\N	1218	62225	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Пролетарская, д. 68		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54717	7	63	\N	1332	54555	\N	54.215127213811101	Республика Мордовия, Дубенский муниципальный район, Ардатовское сельское поселение, Кооперативная, д.3	Россия, республика Мордовия, Саранск, Октябрьский район, улица Кооперативная, 3	0101000020E6100000D4D2DC0A6199464049BE1248891B4B40
55245	7	63	\N	1332	54499	\N	54.185378	Республика Мордовия, город Саранск, Ленинский район, Коммунистическая, 89		0101000020E610000053CA6B2574954640EEB25F77BA174B40
55246	7	63	\N	1332	54508	\N	54.185625000000002	Республика Мордовия, город Саранск, Ленинский район, Коммунистическая, 103		0101000020E610000034A2B437F8944640F6285C8FC2174B40
55218	7	63	\N	1332	54495	\N	54.168424999999999	Республика Мордовия, город Саранск, Ленинский район, Комарова, 7		0101000020E610000011346612F5924640166A4DF38E154B40
55303	7	63	\N	1332	54402	\N	54.212366000000003	Республика Мордовия, город Саранск, Пролетарский район, Коваленко	Россия, республика Мордовия, Саранск, улица Коваленко, 38а	0101000020E61000002783A3E4D58F4640246420CF2E1B4B40
55308	7	63	\N	1332	54507	\N	54.219273999999999	Республика Мордовия, город Саранск, Пролетарский район, Коваленко, 21		0101000020E61000000114234BE68E46407A6EA12B111C4B40
55307	7	63	\N	1332	54507	\N	54.219858000000002	Республика Мордовия, город Саранск, Пролетарский район, Коваленко, 13		0101000020E610000007280D350A8F4640CAE1934E241C4B40
55005	7	63	\N	1332	55018	\N	54.144290132287402	д.Николаевка, Зеленый Дол, 50 А	Россия, республика Мордовия, Саранск, рабочий поселок Николаевка, Первомайская улица	0101000020E6100000C85C19541B924640E6913F1878124B40
55299	7	63	\N	1332	54482	\N	54.224316999999999	Республика Мордовия, город Саранск, Пролетарский район, Есенина, 14а		0101000020E610000061A6ED5F598F4640EA77616BB61C4B40
55217	7	63	\N	1332	54485	\N	54.172156000000001	Республика Мордовия, город Саранск, Ленинский район, Гагарина, 108		0101000020E610000083F6EAE3A1934640B4E7323509164B40
55243	7	63	\N	1332	54489	\N	54.192157999999999	Республика Мордовия, город Саранск, Ленинский район, Гагарина, 7А		0101000020E610000017618A726994464017D522A298184B40
55244	7	63	\N	1332	54487	\N	54.188813000000003	Республика Мордовия, город Саранск, Ленинский район, Гагарина, 13		0101000020E6100000B9FB1C1F2D944640A3073E062B184B40
55234	7	63	\N	1332	54497	\N	54.182248000000001	Республика Мордовия, город Саранск, Ленинский район, Володарского, 5		0101000020E61000005C2041F16398464076E107E753174B40
55263	7	63	\N	1332	7216	\N	54.186131000000003	Республика Мордовия, город Саранск, Октябрьский район, Волгоградская, 88	Россия, республика Мордовия, Саранск, Волгоградская улица, 88	0101000020E61000007171546EA29C4640CAE2FE23D3174B40
95158	7	63	\N	1332	54448	\N	54.226623513572299	Республика Мордовия, г. Саранск, Пролетарский район, ул.Веселовского, д.39	Россия, республика Мордовия, Саранск, улица Веселовского, 39	0101000020E6100000352A70B20D9046408E3EE603021D4B40
55311	7	63	\N	1332	54448	\N	54.221909324928902	Республика Мордовия, город Саранск, Пролетарский район, Веселовского, 3	Россия, республика Мордовия, Саранск, улица Веселовского, 4а	0101000020E6100000070B2769FE92464012D89C83671C4B40
55300	7	63	\N	1332	54448	\N	54.226711999999999	Республика Мордовия, город Саранск, Пролетарский район, Веселовского, 39		0101000020E6100000369204E10A9046402DCE18E6041D4B40
55293	7	63	\N	1332	54448	\N	54.223236999999997	Республика Мордовия, город Саранск, Пролетарский район, Веселовского, 16а		0101000020E61000006C06B8205B924640EA20AF07931C4B40
55292	7	63	\N	1332	54448	\N	54.223236999999997	Республика Мордовия, город Саранск, Пролетарский район, ул. Веселовского, 16а		0101000020E61000006C06B8205B924640EA20AF07931C4B40
55253	7	63	\N	1332	54502	\N	54.217061999999999	Республика Мордовия, город Саранск, Октябрьский район, Вакеева, 3		0101000020E61000003620425C39994640289A07B0C81B4B40
55239	7	63	\N	1332	6962	\N	54.191299000000001	Республика Мордовия, город Саранск, Ленинский район, Ботевградская, 102	Россия, республика Мордовия, Саранск, Ботевградская улица, 102	0101000020E610000007B7B585E7954640F660527C7C184B40
55240	7	63	\N	1332	54473	\N	54.187474999999999	Республика Мордовия, город Саранск, Ленинский район, Б.Хмельницкого, 57		0101000020E610000048C153C895964640A7E8482EFF174B40
55237	7	63	\N	1332	54473	\N	54.187106	Республика Мордовия, город Саранск, Ленинский район, Б.Хмельницкого, 39		0101000020E610000073BB97FBE49646405471E316F3174B40
55310	7	63	\N	1332	54483	\N	54.227490000000003	Республика Мордовия, город Саранск, Пролетарский район, А. Лусс, 7		0101000020E61000007E737FF5B891464062156F641E1D4B40
55309	7	63	\N	1332	54483	\N	54.227490000000003	Республика Мордовия, город Саранск, Пролетарский район, А.Лусс, 7		0101000020E61000007E737FF5B891464062156F641E1D4B40
55215	7	63	\N	1332	54506	\N	54.170411999999999	Республика Мордовия, город Саранск, Ленинский район, А.Невского, 57		0101000020E61000000420EEEA55964640486C770FD0154B40
55283	7	63	\N	1332	54423	\N	54.1850377954067	Республика Мордовия, город Саранск, Октябрьский район, р.п.Луховка, Рабочая, 33а		0101000020E6100000331823128598464035423F53AF174B40
55313	7	63	\N	1332	54484	\N	54.229680000000002	Республика Мордовия, город Саранск, Пролетарский район, Пушкина, 22		0101000020E6100000D464C6DB4A914640CC457C27661D4B40
55231	7	63	\N	1332	54475	\N	54.195103000000003	Республика Мордовия, город Саранск, Ленинский район, Васенко, 3		0101000020E61000008A3E1F65C4974640FE2C9622F9184B40
55055	7	63	\N	32650	54548	\N	54.049329999999998	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, б-р Школьный, д.1		0101000020E610000055185B0872784640185B087250064B40
55079	7	63	\N	32650	54382	\N	54.057581279603497	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, б-р Горшкова, д.3А	Россия, республика Мордовия, Рузаевка	0101000020E61000003A1F9E25C87846407CEF6FD05E074B40
95144	7	63	1600	48738	54896	\N	54.659292000000001	Республика Мордовия, Темниковский р-н, д. Нижние Борки, Центральная, 48		0101000020E6100000CFA10C5531BB4540D94125AE63544B40
55056	7	63	\N	32650	54342	\N	54.050432542979799	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, Юрасова, 15	Россия, республика Мордовия, Рузаевка	0101000020E61000008B170B43E4784640D0D1AA9674064B40
55070	7	63	\N	32650	55076	\N	54.0570042071515	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Энергетическая, д.2Г		0101000020E6100000A794D74AE8784640DFDE35E84B074B40
55072	7	63	\N	32650	54341	\N	54.050309045442802	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Тухачевского, д.10	Россия, республика Мордовия, Рузаевка	0101000020E610000040BFEFDFBC784640E4D87A8670064B40
55071	7	63	\N	32650	54431	\N	54.063135596935702	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Титова, д.б/н	Россия, республика Мордовия, Рузаевка	0101000020E6100000B00111E2CA794640A29927D714084B40
55062	7	63	\N	32650	54431	\N	54.044961512544099	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Титова, д.2	Россия, республика Мордовия, Рузаевка	0101000020E6100000EDF2AD0FEB79464008C89750C1054B40
55049	7	63	\N	32650	54434	\N	54.057985255115803	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Терешковой, д.91/93	Россия, республика Мордовия, Рузаевка	0101000020E61000003A1F9E25C87846404C546F0D6C074B40
55058	7	63	\N	32650	54331	\N	54.049563482372101	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Станиславского, д.4	Россия, республика Мордовия, Рузаевка	0101000020E61000002F88484DBB784640BB0B941458064B40
55047	7	63	\N	32650	54527	\N	54.049329999999998	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Революции 1905 года, д.6		0101000020E610000055185B0872784640185B087250064B40
55057	7	63	\N	32650	54458	\N	54.062962528886203	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Полежаева, д.33	Россия, республика Мордовия, Рузаевка	0101000020E6100000DF35E84B6F794640D5EDEC2B0F084B40
55075	7	63	\N	32650	54625	\N	54.049329999999998	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Мира, д.21		0101000020E610000055185B0872784640185B087250064B40
55077	7	63	\N	32650	54437	\N	54.0568743129596	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, Маяковского, 90А	Россия, республика Мордовия, Рузаевка	0101000020E6100000054EB6813B78464011FFB0A547074B40
55054	7	63	\N	32650	54437	\N	54.049329999999998	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Маяковского, д.102		0101000020E610000055185B0872784640185B087250064B40
55073	7	63	\N	32650	54588	\N	54.049329999999998	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Луговая, д.6А		0101000020E610000055185B0872784640185B087250064B40
55052	7	63	\N	32650	54451	\N	54.046880946681803	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Ленина, д.59	Россия, республика Мордовия, Рузаевка	0101000020E61000003D450E1137794640E2E6543200064B40
55048	7	63	\N	32650	54451	\N	54.049664496202901	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, Ленина, 93	Россия, республика Мордовия, Рузаевка	0101000020E61000002CB81FF0C0784640EFE4D3635B064B40
55046	7	63	\N	32650	54451	\N	54.047082987199502	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Ленина, д.16	Россия, республика Мордовия, Рузаевка	0101000020E61000006AF981AB3C7946404A99D4D006064B40
55076	7	63	\N	32650	54474	\N	54.050006007932801	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Красноармейская, д.35	Россия, республика Мордовия, Рузаевка	0101000020E610000040BFEFDFBC784640494DBB9866064B40
55050	7	63	\N	32650	54635	\N	54.049329999999998	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Карла Маркса, д.15		0101000020E610000055185B0872784640185B087250064B40
55074	7	63	\N	32650	54375	\N	54.054248331025903	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.З.Космодемьянской, д.80	Россия, республика Мордовия, Рузаевка	0101000020E61000009F7422C154794640CCEF3499F1064B40
55098	7	63	\N	32650	54352	\N	54.079743602072298	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, 40 лет Победы, 18А	Россия, республика Мордовия, Рузаевка	0101000020E6100000B493C151F2784640AF06280D350A4B40
55053	7	63	\N	32650	54340	\N	54.0504389602578	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, ул.Байкузова, д.137	Россия, республика Мордовия, Рузаевка	0101000020E6100000A4C4AEEDED784640B2B8FFC874064B40
54969	7	63	\N	56533	54959	\N	54.425393	Республика Мордовия, Краснослободский район, г. Краснослободск, пл. Советская, д. 9		0101000020E6100000F64201DBC1E4454042791F4773364B40
54967	7	63	\N	56533	54349	\N	54.428695954691101	Республика Мордовия, Краснослободский район, г. Краснослободск, ул. Коммунистическая, д. 49	Россия, республика Мордовия, Краснослободский район, Краснослободск	0101000020E61000002F8A1EF818E6454088F6B182DF364B40
54944	7	63	\N	12510	81074	\N	54.044778999999998	Республика Мордовия, Ковылкинский муниципальный район, городское поселение Ковылкино, Щорса, 4		0101000020E6100000FF1F274C18F7454017467A51BB054B40
54938	7	63	\N	12510	54540	\N	54.044778999999998	г. ковылкино, Школьная, 1		0101000020E6100000FF1F274C18F7454017467A51BB054B40
54935	7	63	\N	12510	54365	\N	54.046278030866802	Республика Мордовия, Ковылкинский муниципальный район, городское поселение Ковылкино, Урицкого, 7А	Россия, республика Мордовия, Ковылкино	0101000020E61000003B6F63B323F745401C430070EC054B40
54947	7	63	\N	12510	54789	\N	54.041150847762502	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Сосновый бор	Россия, республика Мордовия, Ковылкино	0101000020E61000000DAA0D4E44F345404E999B6F44054B40
54945	7	63	\N	12510	54658	\N	54.045721814322597	Республика Мордовия, Ковылкинский муниципальный район, городское поселение Ковылкино, Пионерская, 44	Россия, республика Мордовия, Ковылкино	0101000020E610000002F04FA912F74540965AEF37DA054B40
95132	7	63	\N	12510	54439	\N	54.044778999999998	Республика Мордовия, Ковылкинский р-н, г. Ковылкино, ул.Ленина, 4		0101000020E6100000FF1F274C18F7454017467A51BB054B40
54946	7	63	\N	12510	54682	\N	54.042337986095397	Республика Мордовия, Ковылкинский муниципальный район, городское поселение Ковылкино, Кутузова, 20	Россия, республика Мордовия, Ковылкино	0101000020E6100000726A6798DAF6454064B0E2546B054B40
54942	7	63	\N	12510	54386	\N	54.044778999999998	г. Ковылкино, королева, 5		0101000020E6100000FF1F274C18F7454017467A51BB054B40
54941	7	63	\N	12510	54958	\N	54.0420508738137	г.Ковылкино, Желябова, 26	Россия, республика Мордовия, Ковылкино	0101000020E6100000B745990D32F74540CEE15AED61054B40
54940	7	63	\N	12510	54758	\N	54.044778999999998	г. Ковылкино, Есенина, 10		0101000020E6100000FF1F274C18F7454017467A51BB054B40
54937	7	63	\N	12510	54609	\N	54.042353969607198	Республика Мордовия, Ковылкинский муниципальный район, городское поселение Ковылкино, Гагарина, 14А	Россия, республика Мордовия, Ковылкино	0101000020E610000020B6F468AAF745406A6D1ADB6B054B40
95131	7	63	\N	12510	54542	\N	54.041141573110103	Республика Мордовия, Ковылкинский район, г. Ковылкино, ул. 40 лет Октября, 10	Россия, республика Мордовия, Ковылкино	0101000020E6100000D55DD90583F74540FB3E1C2444054B40
54821	7	63	\N	56539	79757	\N	53.863056727428898	Республика Мордовия, Инсарский муниципальный район, городское поселение Инсар, Московская, 118	Россия, республика Мордовия, Инсарский район, Инсар	0101000020E6100000E4DC26DC2B2F4640BCCADAA678EE4A40
54823	7	63	\N	56539	54544	\N	53.865568000000003	Республика Мордовия, Инсарский муниципальный район, городское поселение Инсар, Восточный переулок, 12а		0101000020E6100000344DD87E32304640693BA6EECAEE4A40
54825	7	63	\N	56539	54652	\N	53.865568000000003	Республика Мордовия, Инсарский муниципальный район, городское поселение Инсар, Больничный переулок, 9		0101000020E6100000344DD87E32304640693BA6EECAEE4A40
54997	7	63	\N	62088	81125	\N	54.232142528151599	с.Берсеневка, Пролетарская, 15		0101000020E6100000C554FA0967854640677FA0DCB61D4B40
54596	7	63	\N	56536	54441	\N	54.8476381209788	Республика Мордовия, Ардатовский муниципальный район, городское поселение Ардатов, Садовая, 47	Россия, республика Мордовия, Ардатовский район, Ардатов	0101000020E61000000E4B033FAA1F4740666CE8667F6C4B40
55190	7	63	1108	24809	54415	\N	54.407315476634899	рабочий поселок Чамзинка, микрорайон-6, 24	Россия, республика Мордовия, Чамзинский район, поселок Чамзинка	0101000020E6100000EE0912DBDDE34640CA15DEE522344B40
55189	7	63	1108	24809	54334	\N	54.4078203700467	рабочий поселок Чамзинка, Титова, 12	Россия, республика Мордовия, Чамзинский район, поселок Чамзинка	0101000020E61000001407D0EFFBE34640CE531D7233344B40
55187	7	63	1108	24809	54363	\N	54.4074198198294	рабочий поселок Чамзинка, Терешковой, 7А	Россия, республика Мордовия, Чамзинский район, поселок Чамзинка	0101000020E6100000EA2285B2F0E3464040DEAB5626344B40
55188	7	63	1108	24809	9732	\N	54.407302999999999	рабочий поселок Чамзинка, Ленина, 18		0101000020E6100000D9B11188D7E346400648348122344B40
55186	7	63	1108	24809	9732	\N	54.408279	рабочий поселок Чамзинка, Ленина, 10	Россия, республика Мордовия, Чамзинский район, поселок Чамзинка	0101000020E61000008A213999B8E3464061527C7C42344B40
95157	7	63	1108	25950	54874	\N	54.476086000000002	Республика Мордовия, Чамзинский р-н, с. Сабур-Мачкасы, ул.Советская, 52		0101000020E6100000D6E6FF5547F04640AF0AD462F03C4B40
55191	7	63	1108	56540	54523	\N	54.398301838991202	село Репьевка, Советская, 46А	Россия, республика Мордовия, Чамзинский район, село Репьевка	0101000020E6100000698CD651D5DE464038F7578FFB324B40
95156	7	63	1108	25800	54696	\N	54.281615000000002	Республика Мордовия, Чамзинский р-н, с. Пянгелей, Подлесная, 14		0101000020E610000003780B2428DA46401288D7F50B244B40
55213	7	63	1108	56557	54683	\N	54.322078675404001	село Пичеуры, Луначарского, 17	Россия, республика Мордовия, Чамзинский район, село Печеуры	0101000020E610000098FA795391EA46403CDD79E239294B40
55212	7	63	1108	45559	54875	\N	54.432107999999999	село Отрадное, Молодежная, 13		0101000020E61000004CFDBCA948D54640842BA0504F374B40
95154	7	63	1108	45487	55033	\N	54.533869000000003	Республика Мордовия, Чамзинский р-н, с. Новоселки, ул.Центральная, 1-а		0101000020E610000036902E36ADDA464093ACC3D155444B40
95151	7	63	1108	25240	54891	\N	54.488985	Республика Мордовия, Чамзинский р-н, с. Наченалы, Большая, 58		0101000020E6100000034015376ED74640069E7B0F973E4B40
95155	7	63	1108	25784	54883	\N	54.254866999999997	Республика Мордовия, Чамзинский р-н, с. Мокшалей, ул.Ленинская, 53		0101000020E6100000F374AE2825D0464031EA5A7B9F204B40
55207	7	63	1108	45483	55031	\N	54.550494	село Мичурино, Советская, 4		0101000020E6100000F92CCF83BBDF464076525F9676464B40
55205	7	63	1108	25505	54633	\N	54.439611999999997	село Медаево, Гагарина, 1А		0101000020E61000004609FA0B3D004740EE76BD3445384B40
55206	7	63	1108	25599	54703	\N	54.386519999999997	село Мачказерово, Ленина, 1		0101000020E6100000D50968226C064740FD9FC37C79314B40
55204	7	63	1108	25497	54873	\N	54.313378	село Малое Маресево, Ленина, 1		0101000020E610000010CF126404CC464098A432C51C284B40
95153	7	63	1108	25406	54897	\N	54.431511	Республика Мордовия, Чамзинский р-н, с. Кульмино, ул. Площадь, д.19		0101000020E61000002E1A321EA5CC4640A06EA0C03B374B40
55202	7	63	1108	45403	54909	\N	54.590916999999997	село Красный Поселок, Центральная, 21		0101000020E61000009335EA211AD5464041D3122BA34B4B40
54669	7	63	1108	25132	54639	\N	54.426617361058902	с. Киржеманы, ул. Советская, д.8	Россия, республика Мордовия, Чамзинский район, село Киржеманы	0101000020E610000074D4D17135EC46407575C7629B364B40
55197	7	63	1108	25132	54651	\N	54.425849957321503	село Киржеманы, Карла Маркса, 1	Россия, республика Мордовия, Чамзинский район, село Киржеманы	0101000020E610000047205ED72FEC46403480B74082364B40
53556	7	63	1108	25132	54917	\N	54.426400464179103	с. Киржеманы, Советская, 33	Россия, республика Мордовия, Чамзинский район, село Киржеманы	0101000020E61000006E3480B740EC4640D881734694364B40
95152	7	63	1108	25304	54562	\N	54.349540118100201	Республика Мордовия, Чамзинский р-н, с. Большое Маресево, ул.Видяйкина, д.1	Россия, республика Мордовия, Чамзинский район, село Большое Маресево	0101000020E61000006DA818E76FD6464069520ABABD2C4B40
55201	7	63	1108	25318	54700	\N	54.368825999999999	село Большие Ремезенки, Молодежная, 1В		0101000020E61000009677D503E6C746400EF5BBB0352F4B40
95150	7	63	1108	25188	54560	\N	54.500494000000003	Республика Мордовия, Чамзинский р-н, с. Апраксино, ул.Центральная, 11		0101000020E610000081B1BE81C9E1464010ECF82F10404B40
55179	7	63	838	56574	54900	\N	54.101329	поселок Центральный, Школьная, 5		0101000020E6100000FA7ABE66B986454075914259F80C4B40
55183	7	63	838	24487	54872	\N	54.169283999999998	село Хилково, Советская 1-я, 90		0101000020E6100000EC67B114C99D454037DE1D19AB154B40
55174	7	63	838	49253	54356	\N	54.076408000000001	рп Торбеево, мкр 3-й, 4		0101000020E6100000444FCAA4869E45408E93C2BCC7094B40
55172	7	63	838	49253	54440	\N	54.076929402966897	рп Торбеево, Студенческая, 45	Россия, республика Мордовия, Торбеевский район, поселок Торбеево	0101000020E6100000598AE42B819E4540978E39CFD8094B40
55171	7	63	838	49253	54443	\N	54.0767275082586	Республика Мордовия, Торбеевский муниципальный район, рп Торбеево, Садовая, 42	Россия, республика Мордовия, Торбеевский район, поселок Торбеево	0101000020E6100000572250FD839E454000581D39D2094B40
55176	7	63	838	24159	54892	\N	54.185130000000001	село Татарские Юнки, Молодежная, 4		0101000020E610000074B2D47ABFAB454016C1FF56B2174B40
95104	7	63	838	19739	55034	\N	54.038207	"""село Сургодь, Школьная, 1 """"а"""""""		0101000020E6100000EA08E066F18A454038BD8BF7E3044B40
52424	7	63	838	18409	54822	\N	54.005288999999998	село Старые Пичуры, Ленина, 2		0101000020E6100000C7F2AE7AC0BC4540A703594FAD004B40
95103	7	63	838	9608	54800	\N	54.031613	Республика Мордовия, Торбеевский р-н, с. Слаим, Советская, 23		0101000020E610000032E36DA5D7924540719010E50B044B40
52412	7	63	838	17812	55045	\N	54.038713999999999	село Семивражки, Восточная, 3		0101000020E6100000EDD79DEE3CB34540DCF29194F4044B40
95105	7	63	838	27981	54636	\N	54.124859000000001	"""село Салазгорь, Эрькина, 5 """"а"""""""		0101000020E610000060200890A19345403ECE3461FB0F4B40
55051	7	63	838	17942	54859	\N	54.076946999999997	село Савва, Школьная, 1		0101000020E61000002FE1D05B3C8A45403D433866D9094B40
55184	7	63	838	24567	54518	\N	54.229959000000001	село Носакино, Центральная, 9		0101000020E61000003F8F519E79974540DF35E84B6F1D4B40
55028	7	63	838	56604	55089	\N	54.053077999999999	село Никольчское, Центральная, 3	Россия, республика Мордовия, Торбеевский район, село Никольское	0101000020E6100000DCA16131EA9245408C118942CB064B40
95148	7	63	838	24193	54890	\N	54.144941000000003	"""село Мордовские Юнки, Школьная, 9 """"а"""""""		0101000020E6100000F0C000C287BA4540BE6C3B6D8D124B40
95149	7	63	838	49353	54697	\N	54.167138999999999	Республика Мордовия, Торбеевский р-н, с. Мальцево, ул.Садовая, д.2		0101000020E61000002D78D157908E45406D718DCF64154B40
51441	7	63	838	48369	54821	\N	54.005490000000002	с.Лопатино, Центральная, 7		0101000020E61000007CF1457BBC8E45403F3A75E5B3004B40
52382	7	63	838	48734	55052	\N	54.062241999999998	село Краснополье, Школьная, 3		0101000020E6100000D9CF622992AB45400438BD8BF7074B40
55178	7	63	838	56546	54629	\N	54.0748622029204	поселок Красноармейский, Школьная, 1	Россия, республика Мордовия, Торбеевский район, село Красноармеец	0101000020E610000017F549EEB0B9454049DBF81395094B40
52464	7	63	838	20579	54913	\N	54.032580000000003	село Красаевка, Советская, 36		0101000020E61000005C2041F163BE45407940D9942B044B40
95102	7	63	838	6189	55036	\N	54.009734000000002	Республика Мордовия, Торбеевский р-н, с.Кажлодка, ул.Школьная, д.49		0101000020E61000009C525E2BA195454063D4B5F63E014B40
95147	7	63	838	32998	54595	\N	54.101055000000002	"""село Жуково, Почтовая, 21 """"в"""""""		0101000020E6100000062E8F3523A54540740CC85EEF0C4B40
52290	7	63	838	47003	54360	\N	54.047438	село Дракино, Школьная, 2А		0101000020E610000088D860E124A14540384BC97212064B40
55185	7	63	838	24583	54815	\N	54.253324999999997	село Виндрей, Советская, 14		0101000020E610000082E2C798BB7E45402D211FF46C204B40
55180	7	63	838	24360	54887	\N	54.184745999999997	село Варжеляй, Советская 2-я, 43		0101000020E61000002EABB019E08E45408D08C6C1A5174B40
53003	7	63	838	47476	54911	\N	53.995730999999999	деревня Аксеновка, Школьная, 20		0101000020E6100000126A8654518E4540834E081D74FF4A40
55170	7	63	1711	49186	55030	\N	54.772790000000001	с. Шокша, Верхняя, 19А		0101000020E610000078978BF84E424540825660C8EA624B40
55158	7	63	1711	23279	54871	\N	54.709564	Республика Мордовия, Теньгушевский муниципальный район, с. Широмасово, Советская, 27		0101000020E6100000E92807B309444540A0353FFED25A4B40
55168	7	63	1711	23774	55032	\N	54.632973	с. Хлебино, Школьная, 1Б		0101000020E6100000914770236569454021205F4205514B40
55149	7	63	1711	56538	54455	\N	54.764177173027903	Республика Мордовия, Теньгушевский муниципальный район, Теньгушевское сельское поселение, Ленина, 74	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E61000002FBE688F175C45407DAD4B8DD0614B40
55154	7	63	1711	56538	55087	\N	54.768395545727799	Республика Мордовия, Теньгушевский муниципальный район, Дачное сельское поселение, Школьная, 2	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E61000006EC1525DC05B45404930D5CC5A624B40
55163	7	63	1711	56538	55053	\N	54.768891117368199	Республика Мордовия, Теньгушевский муниципальный район, Старокачеевское сельское поселение, Центральная, 61	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E61000001975ADBD4F5B4540299831056B624B40
54867	7	63	1600	30141	54532	\N	54.5636429428857	с.Оброчное, Юбилейная, 25	Россия, республика Мордовия, Темниковский район, село Оброчное	0101000020E610000084D558C2DA8C454046CF2D7425484B40
55155	7	63	1711	56538	55053	\N	54.769039999999997	Республика Мордовия, Теньгушевский муниципальный район, Красноярское сельское поселение, Центральная, 39	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E61000004089CF9D605B45406DA818E76F624B40
55153	7	63	1711	56538	54478	\N	54.764723104964602	Республика Мордовия, Теньгушевский муниципальный район, Барашевское сельское поселение, Московская, 2	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E61000002B86AB03205C4540DFBF7971E2614B40
55159	7	63	1711	56538	54452	\N	54.767799359053399	Республика Мордовия, Теньгушевский муниципальный район, Кураевское сельское поселение, Ленина, 7	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E6100000B2F50CE1985B45406473D53C47624B40
55157	7	63	1711	56538	54452	\N	54.766658622225201	Республика Мордовия, Теньгушевский муниципальный район, Куликовское сельское поселение, Ленина, 94	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E610000054E6E61BD15B45408F17D2E121624B40
55148	7	63	1711	56538	54452	\N	54.7657653181207	Республика Мордовия, Теньгушевский муниципальный район, Теньгушевское сельское поселение, улица Ленина, дом 72	Россия, республика Мордовия, Теньгушевский район, село Теньгушево	0101000020E610000081785DBF605B4540F2B5679604624B40
55156	7	63	1711	23205	54868	\N	54.742308999999999	Республика Мордовия, Теньгушевский муниципальный район, д. Телимерки, Центральная, 26/2		0101000020E610000083A5BA8097634540634337FB035F4B40
55166	7	63	1711	23671	55026	\N	54.721499999999999	с. Такушево, Новая, 3		0101000020E6100000096EA46C917A45403108AC1C5A5C4B40
55162	7	63	1711	23483	54885	\N	54.64217	с.Стандрово, Школьная, 16А		0101000020E61000006556EF703B544540753C66A032524B40
55169	7	63	1711	23817	55029	\N	54.758802000000003	с. Сакаево, Советская, 2		0101000020E61000004E27D9EA724C4540D811876C20614B40
55165	7	63	1711	49116	54869	\N	54.707302677538699	п. Садовый, Центральная, 8	Россия, республика Мордовия, Теньгушевский район, село Садовый	0101000020E61000004EED0C535B7245406DAE9AE7885A4B40
55161	7	63	1711	23416	54870	\N	54.727417000000003	с. Нароватово, Садовая, 2		0101000020E61000008C6A11514C584540F8C610001C5D4B40
55164	7	63	1711	49104	54889	\N	54.724634999999999	д. Нагорная, Центральная, 50		0101000020E61000006B9F8EC70C784540BB44F5D6C05C4B40
55160	7	63	1711	61830	79748	\N	54.755856000000001	Республика Мордовия, Теньгушевский муниципальный район, Мельсетьевское сельское поселение, Гагарина, 2А		0101000020E61000002769FE98D6364540213EB0E3BF604B40
55181	7	63	1711	56566	54740	\N	54.735037311584897	село Куликово, Куликово, 124	Россия, республика Мордовия, Теньгушевский район, село Куликово	0101000020E61000005B79C9FFE4474540CB2C42B1155E4B40
55150	7	63	1711	22931	55028	\N	54.79907	Республика Мордовия, Теньгушевский муниципальный район, д. Дудниково, Центральная, 18/1		0101000020E6100000745C8DEC4A5945407C9BFEEC47664B40
55152	7	63	1711	23037	54867	\N	54.781391598531897	Республика Мордовия, Теньгушевский муниципальный район, д. Вечкидеево, Центральная, 48/1	Россия, республика Мордовия, Теньгушевский район, село Вичкидеево	0101000020E6100000CC46E7FC1461454092AD2EA704644B40
55167	7	63	1711	49151	55027	\N	54.729902000000003	д.Веденяпино, Поповка, 5		0101000020E6100000D3156C239E7E45407BA4C16D6D5D4B40
55151	7	63	1711	22984	54694	\N	54.770598	Республика Мордовия, Теньгушевский муниципальный район, с. Башкирцы, Центральная, 2А		0101000020E610000059F8FA5A975E4540772E8CF4A2624B40
55137	7	63	1600	56592	55060	\N	54.673481000000002	д.Чуматрово, Школьная, 103	Россия, республика Мордовия, Темниковский район, село Чумартово	0101000020E610000089B2B794F3AB45401BBD1AA034564B40
54998	7	63	1600	56581	\N	\N	54.597583999999998	п.Чекаевский, 153	Россия, республика Мордовия, Темниковский район, село Чекаевка	0101000020E6100000185FB4C70BC94540724EECA17D4C4B40
54680	7	63	1600	56562	54731	\N	54.636365531432801	с. Ушаковка, ул. Фрунзе, д.27	Россия, республика Мордовия, Темниковский район, село Ушаковка	0101000020E610000070B1A206D3924540A724EB7074514B40
55144	7	63	1600	22667	54884	\N	54.600102999999997	с. Урей-3, Советская, 8		0101000020E610000065506D7022C64540A19DD32CD04C4B40
55129	7	63	1600	56553	54669	\N	54.661605534047901	с. Русское Тювеево, Молодежная, 15	Россия, республика Мордовия, Темниковский район, село Тювеево	0101000020E610000015CAC2D7D7A045402F6B6281AF544B40
55083	7	63	1600	19573	54355	\N	54.634974	город Темников, Школьная, 1А		0101000020E61000004A6249B9FB9A4540B8E7F9D346514B40
55123	7	63	1600	19573	54412	\N	54.634974	город Темников, Коммунистическая, 17		0101000020E61000004A6249B9FB9A4540B8E7F9D346514B40
55126	7	63	1600	19573	54517	\N	54.634974	город Темников, Восточная, 2		0101000020E61000004A6249B9FB9A4540B8E7F9D346514B40
95143	7	63	1600	19573	54397	\N	54.635370248809103	Республика Мордовия, Темниковский район, город Темников, ул.Белинского, д.18-а	Россия, республика Мордовия, Темниковский район, Темников	0101000020E61000008787307E1A9B4540056EDDCD53514B40
55143	7	63	1600	48755	55024	\N	54.538151999999997	с. Тарханы, Малая, 4		0101000020E61000008BFA2477D8B4454074232C2AE2444B40
55141	7	63	1600	22515	54902	\N	54.629736999999999	с. Старый Ковыляй, Центральная, 27		0101000020E6100000747ADE8D05BF4540630AD6389B504B40
55115	7	63	1600	56593	55062	\N	54.678322999999999	с. Старый Город, Центральная, 50А	Россия, республика Мордовия, Темниковский район, село Старый Город	0101000020E61000005C1D0071578D4540F38FBE49D3564B40
55139	7	63	1600	22448	54975	\N	54.686478999999999	д. Русское Караево, Центральная, 107		0101000020E610000043554CA59F9E454005323B8BDE574B40
55140	7	63	1600	22511	55025	\N	54.713231	п. Пушта, Лесная, 9		0101000020E61000009C4EB2D5E59C454027BF45274B5B4B40
95099	7	63	1600	22407	54688	\N	54.663583000000003	Республика Мордовия, Темниковский р-н, с. Пурдошки, ул.Крупской, д.18		0101000020E61000000C789961A3C645403E97A949F0544B40
55133	7	63	1600	22189	54777	\N	54.587629999999997	с. Подгорное Канаково, Центральная, 2		0101000020E610000086E28E37F9A545400113B875374B4B40
55136	7	63	1600	22333	54526	\N	54.651921999999999	с. Митрялы, Центральная, 27		0101000020E61000009C35785F95B145407EC51A2E72534B40
55127	7	63	1600	21906	55022	\N	54.558117000000003	Республика Мордовия, Темниковский район, с. Лесное Цибаево, ул. Центральная, дом 6, МБУК КДЦ «Лесно-Цибаевский»		0101000020E610000015ADDC0BCC944540BB2BBB6070474B40
55128	7	63	1600	21947	55064	\N	54.582612411789498	с. Лесное Ардашево, Лесная, 101	Россия, республика Мордовия, Темниковский район, село Лесное Ардашево	0101000020E61000002E3C2F151B914540EA20AF07934A4B40
52155	7	63	1600	48789	54916	\N	54.494194	с. Лаврентьево, Бугорская, 7		0101000020E6100000349E08E23C86454091F0BDBF413F4B40
55130	7	63	1600	22062	54689	\N	54.503965999999998	с. Кушки, Школьная, 13		0101000020E6100000B0045262D7A24540E12538F581404B40
95096	7	63	1600	22152	54810	\N	54.609124999999999	Республика Мордовия, Темниковский р-н, с. Кондровка, Центральная, 24		0101000020E6100000F629C76471A745408716D9CEF74D4B40
95097	7	63	1600	22269	54813	\N	54.554561	Республика Мордовия, Темниковский р-н, с. Ишейки, Молодежная, 12		0101000020E61000000611A96917AB45408B51D7DAFB464B40
55134	7	63	1600	48597	54708	\N	54.713777	с. Жегалово, Молодежная, 10		0101000020E61000006687F8872DB5454089D1730B5D5B4B40
95145	7	63	1600	22705	54566	\N	54.555458999999999	Республика Мордовия, Темниковский р-н, с. Булаево, ул.Гагарина, д.13		0101000020E61000008B321B6492C745406AA2CF4719474B40
95146	7	63	1600	40323	54559	\N	54.636507601533999	Республика Мордовия, Темниковский район, с. Андреевка,  ул.Молодежная, д.10	Россия, республика Мордовия, Темниковский район, село Андреевка	0101000020E61000006688635DDCAA454039D2191879514B40
55104	7	63	1600	48040	55035	\N	54.631968000000001	д. Алексеевка, Поселковая, 2		0101000020E6100000446ADAC5349145402C0FD253E4504B40
55131	7	63	1600	22068	55042	\N	54.596358000000002	с. Аксел, Центральная, 13		0101000020E61000005DBF60376CB545409F5A7D75554C4B40
55122	7	63	1631	21654	54866	\N	54.187715700621901	Республика Мордовия, Старошайговский муниципальный район, Шуварское сельское поселение, село Шувары, Центральная, 1 а	Россия, республика Мордовия, Старошайговский район, село Шувары	0101000020E6100000F2608BDD3E3B4640CD77F01307184B40
55121	7	63	1631	21613	54865	\N	54.426347	Республика Мордовия, Старошайговский муниципальный район, Шигоньское сельское поселение, село Шигонь, Московская, 35		0101000020E610000031EBC5504E644640B5DFDA8992364B40
55120	7	63	1631	21499	54357	\N	54.301457999999997	Республика Мордовия, Старошайговский муниципальный район, Старошайговское сельское поселение, село Старое Шайгово, адрес помещения для голосования: ул.Комсомольский переулок, д.13, адрес УИК: ул.Комарова, 47		0101000020E61000005F7D3CF4DD3B46400C8FFD2C96264B40
55119	7	63	1631	21499	54343	\N	54.301457999999997	Республика Мордовия, Старошайговский муниципальный район, Старошайговское сельское поселение, село Старое Шайгово,  адрес помещения для голосования: ул.Кирова, д.14, адрес УИК: ул.Комарова, 47		0101000020E61000005F7D3CF4DD3B46400C8FFD2C96264B40
55118	7	63	1631	21482	54886	\N	54.489753999999998	Республика Мордовия, Старошайговский муниципальный район, Старофедоровское сельское поселение, село Старая Федоровка, Молодежная, 31		0101000020E610000058AD4CF8A5604640E78A5242B03E4B40
55117	7	63	1631	21382	54519	\N	54.260120999999998	Республика Мордовия, Старошайговский муниципальный район, сельское поселение Старая Теризморга, Центральная, 76		0101000020E6100000C442AD69DE4346405C001AA54B214B40
55100	7	63	1631	20563	55019	\N	54.163449	Республика Мордовия, Старошайговский муниципальный район, Восходское сельское поселение, село Восход, Центральная, 40		0101000020E6100000DD0BCC0A454646402EC896E5EB144B40
55113	7	63	1631	21294	55086	\N	54.212447195038301	Республика Мордовия, Старошайговский муниципальный район, сельское поселение Рязановка, Ленина, 8	Россия, республика Мордовия, Старошайговский район, село Рязановка	0101000020E61000004F965AEF374A464010919A76311B4B40
55109	7	63	1631	56605	55091	\N	54.371001353938901	Республика Мордовия, Старошайговский муниципальный район, Новотроицкое сельское поселение, село Новотроицк, адрес помещения для голосования: ул.Советская, д.5, адрес УИК: ул. Советская, 35	Россия, республика Мордовия, Старошайговский район, село Новотроицкое	0101000020E610000012876C205D64464043E4F4F57C2F4B40
55107	7	63	1631	20929	54593	\N	54.301746999999999	Республика Мордовия, Старошайговский муниципальный район, Новоакшинское сельское поселение, село Новое Акшино, Центральная, 13		0101000020E61000005C72DC291D64464043554CA59F264B40
55110	7	63	1631	21102	\N	\N	54.455348999999998	Республика Мордовия, Старошайговский муниципальный район, Новофедоровское сельское поселение, село Новая Федоровка, Московская, 20	Россия, республика Мордовия, Старошайговский район, село Новая Федоровка	0101000020E6100000DB6B41EF8D4B464016A243E0483A4B40
55108	7	63	1631	40458	54880	\N	54.507244	Республика Мордовия, Старошайговский муниципальный район, Новоалександровское сельское поселение, село Новая Александровка, Новая, 13 а		0101000020E6100000404E98309A374640CE8B135FED404B40
55106	7	63	1631	20915	54594	\N	54.454217999999997	Республика Мордовия, Старошайговский муниципальный район, Мельцанское сельское поселение, село Мельцаны, адрес помещения для голосования: ул.Ремесленная-1, д. 1, адрес УИК: ул. Ремесленная-1, 3		0101000020E61000002F35423F535D464094A0BFD0233A4B40
55105	7	63	1631	20836	55041	\N	54.311923	Республика Мордовия, Старошайговский муниципальный район, Леткинское сельское поселение, село Летки, Центральная, 35		0101000020E61000009ED0EB4FE247464063EFC517ED274B40
55103	7	63	1631	20748	54863	\N	54.343819000000003	Республика Мордовия, Старошайговский муниципальный район, Лемдяйское сельское поселение, село Лемдяй, Советская, 32		0101000020E6100000ABED26F8A65B4640295FD042022C4B40
55112	7	63	1631	56595	55069	\N	54.419105743162497	Республика Мордовия, Старошайговский муниципальный район, сельское поселение Кулдым, Чапаева, 43	Россия, республика Мордовия, Старошайговский район, село Кулдым	0101000020E6100000AE9AE7887C4D464058C7F143A5354B40
55102	7	63	1631	56607	55094	\N	54.351759999999999	Республика Мордовия, Старошайговский муниципальный район, Конопатское сельское поселение, село Конопать, Молодежная, 1	Россия, республика Мордовия, Старошайговский район, село Конолать	0101000020E6100000043BFE0B047346403E05C078062D4B40
55101	7	63	1631	20641	54882	\N	54.393351000000003	Республика Мордовия, Старошайговский муниципальный район, Ингенер-Пятинское сельское поселение, село Ингенер-Пятина, Советская, 52		0101000020E61000004B0169FF036C4640A96C585359324B40
55111	7	63	1631	21131	54864	\N	54.484057999999997	Республика Мордовия, Старошайговский муниципальный район, Новофедоровское сельское поселение, село Вертелим, Базарная, 1а		0101000020E610000014E7A8A3E3424640FFAECF9CF53D4B40
55099	7	63	1631	20521	54516	\N	54.305498	Республика Мордовия, Старошайговский муниципальный район, Богдановское сельское поселение, село Богдановка, Переулок Чапаева, 4		0101000020E61000009CA73AE466304640287FF78E1A274B40
55276	7	63	7414	56541	54565	\N	54.232645460999997	Республика Мордовия, город Саранск, Октябрьский район, п.Озерный, Тепличная, 16	Россия, республика Мордовия, Саранск городской округ, село Озерный	0101000020E6100000A391CF2B9EA44640F949B54FC71D4B40
55281	7	63	7414	56559	54701	\N	54.086695965527902	Республика Мордовия, город Саранск, Октябрьский район, с.Монастырское, Школьная, 19		0101000020E61000006C21C84109914640D658C2DA180B4B40
95141	7	63	1514	19725	54351	\N	54.021129999999999	"""Республика Мордовия, Рузаевский муниципальный район, Красносельцовское сельское поселение, пос. """"Совхоз """"Красное сельцо"""", адрес помещения для голосования: ул.Садовая, д.1, адрес УИК: ул.Ленина, д.6"""		0101000020E6100000F29881CAF8714640747B4963B4024B40
55080	7	63	1514	19456	54525	\N	54.189118000000001	Республика Мордовия, Рузаевский муниципальный район, Шишкеевское сельское поселение, с.Шишкеево, ул.Базарная, д.12А		0101000020E6100000E4F38AA71E614640DF8AC40435184B40
55096	7	63	1514	20339	54879	\N	54.072475364711103	Республика Мордовия, Рузаевский муниципальный район, Хованщинское сельское поселение, с.Хованщина, ул.Железнодорожная, д.21А	Россия, республика Мордовия, Рузаевский район, село Хованщина	0101000020E61000000CC9C9C4AD4C464088635DDC46094B40
55094	7	63	1514	20215	54590	\N	54.028793999999998	Республика Мордовия, Рузаевский муниципальный район, Трускляйское сельское поселение, с.Трускляй, ул.Ленина, д.18А		0101000020E6100000BF60376C5B6C464017299485AF034B40
55091	7	63	1514	20046	54381	\N	54.061925000000002	Республика Мордовия, Рузаевский муниципальный район, Татарско-Пишлинское сельское поселение, с.Татарская Пишля, ул.Южная, д.23		0101000020E61000002C67EF8CB674464004E78C28ED074B40
55092	7	63	1514	20046	54407	\N	54.061925000000002	Республика Мордовия, Рузаевский муниципальный район, Татарско-Пишлинское сельское поселение, с.Татарская Пишля, пер.Школьный, д.15		0101000020E61000002C67EF8CB674464004E78C28ED074B40
55065	7	63	1514	18676	54624	\N	54.120035999999999	Республика Мордовия, Рузаевский муниципальный район, Сузгарьевское сельское поселение, с.Сузгарье, адрес помещения для голосования: ул.Коммунистическая, д.30А, адрес УИК: ул.Центральная, д.1А		0101000020E6100000E8F4BC1B0B764640DC2BF3565D0F4B40
55097	7	63	1514	56600	55079	\N	54.198223623234199	Республика Мордовия, Рузаевский муниципальный район, Стрелецко-Слободское сельское поселение, с.Стрелецкая Слобода, ул.Пролетарская, д.8	Россия, республика Мордовия, Рузаевский район, село Стрелецкая Слобода	0101000020E6100000DF32A7CB625A464023A46E675F194B40
55089	7	63	1514	19899	54876	\N	54.039555	Республика Мордовия, Рузаевский муниципальный район, Русско-Баймаковское сельское поселение, дер.Русское Баймаково, ул.Школьная, д.4		0101000020E6100000D40FEA228558464057B2632310054B40
55067	7	63	1514	18772	54623	\N	54.018776000000003	Республика Мордовия, Рузаевский муниципальный район, Плодопитомническое сельское поселение, пос.Плодопитомнический, ул.Солнечная, д.8		0101000020E61000005298F738D382464090F9804067024B40
55066	7	63	1514	18717	54619	\N	54.187500999999997	Республика Мордовия, Рузаевский муниципальный район, Перхляйское сельское поселение, с.Перхляй, ул.Шишкеевская, д.3А		0101000020E6100000C102983270744640D07B630800184B40
55088	7	63	1514	19885	54684	\N	53.941203999999999	Республика Мордовия, Рузаевский муниципальный район, Палаевское сельское поселение, с.Палаевка, ул.Садовая, д.21		0101000020E61000006F7F2E1A325E4640A46E675F79F84A40
95142	7	63	1514	56567	54768	\N	54.080803460913799	Республика Мордовия, Рузаевский район, Пайгармское сельское поселение, пос. совхоза №3 ДорУРСа, адрес помещения для голосования: ул.Центральная, д.1А, адрес УИК: ул.Центральная, д.1-а	Россия, республика Мордовия, Рузаевский район, село Пайгарма	0101000020E610000072158BDF146C46409835B1C0570A4B40
55090	7	63	1514	19984	54862	\N	54.054214000000002	Республика Мордовия, Рузаевский муниципальный район, Русско-Баймаковское сельское поселение, с.Новый Усад, ул.Центральная, д.13А		0101000020E61000006E895C70065D4640207EFE7BF0064B40
55082	7	63	1514	19572	54861	\N	53.998435999999998	Республика Мордовия, Рузаевский муниципальный район, Болдовское сельское поселение, с.Новая Муравьевка, ул.Молодежная, д.4		0101000020E610000059518369185A4640149337C0CCFF4A40
55086	7	63	1514	19774	54905	\N	54.107464	Республика Мордовия, Рузаевский муниципальный район, Мордовско-Пишлинское сельское поселение, с.Мордовская Пишля, адрес помещения для голосования: ул.Байкузова, д.33А, адрес УИК: ул.Молодежная, д.1А		0101000020E6100000581D39D219664640A9BF5E61C10D4B40
55068	7	63	1514	18835	54591	\N	54.107574	Республика Мордовия, Рузаевский муниципальный район, Приреченское сельское поселение, пос.Левженский, ул.Центральная, д.29		0101000020E6100000C3EFA65B768A464030F31DFCC40D4B40
55064	7	63	1514	18605	54585	\N	54.084415999999997	Республика Мордовия, Рузаевский муниципальный район, Левженское сельское поселение, с.Левжа, ул.Ленина, д.68А		0101000020E61000006729594E428146402BA1BB24CE0A4B40
55063	7	63	1514	18561	54584	\N	54.048515999999999	Республика Мордовия, Рузаевский муниципальный район, Красноклинское сельское поселение, с.Красный Клин, адрес помещения для голосования: пер.Школьный, д.104А, адрес УИК: пер.Школьный, д.100		0101000020E6100000E469F981AB7C464097AAB4C535064B40
55061	7	63	1514	18460	54860	\N	54.142426	Республика Мордовия, Рузаевский муниципальный район, Ключаревское сельское поселение, с.Ключарево, ул.Центральная, д.28		0101000020E6100000E62494BE10804640D00CE2033B124B40
55095	7	63	1514	20266	54878	\N	54.010713000000003	Республика Мордовия, Рузаевский муниципальный район, Трускляйское сельское поселение, с.Инсар-Акшино, ул.Московская, д.5		0101000020E6100000E4310395F16346402F52280B5F014B40
55084	7	63	1514	19670	54676	\N	53.931854000000001	Республика Мордовия, Рузаевский муниципальный район, Верхнеурледимское сельское поселение, с.Верхний Урледим, ул.Урледимская, д.8А		0101000020E610000039471D1D57574640CA52EBFD46F74A40
55081	7	63	1514	19466	54568	\N	53.988690782937802	Республика Мордовия, Рузаевский муниципальный район, Болдовское сельское поселение, с.Болдово, ул.Никольская, д.1А	Россия, республика Мордовия, Рузаевский район, село Болдово	0101000020E61000002E20B41EBE504640BE6C3B6D8DFE4A40
55060	7	63	1514	32937	54617	\N	54.043441000000001	Республика Мордовия, Рузаевский муниципальный район, Архангельско-Голицынское сельское поселение, с.Арх-Голицыно, ул.Советская, д.42		0101000020E6100000B37BF2B0508746401C2785798F054B40
55059	7	63	1514	18330	54776	\N	53.983704000000003	Республика Мордовия, Рузаевский муниципальный район, Аргамаковское сельское поселение, с.Аргамаково, адрес помещения для голосования: ул.Школьная, д.17, адрес УИК: ул.Строительная, д.50		0101000020E61000006DC7D45DD98B4640E2783E03EAFD4A40
55069	7	63	6907	40362	9946	\N	54.049329999999998	Республика Мордовия, Рузаевский муниципальный район, городское поселение Рузаевка, адрес помещения для голосования: ул.Переходная, д.6, адрес УИК: ул.Переходная, д.21		0101000020E610000055185B0872784640185B087250064B40
55045	7	63	1380	17664	55017	\N	54.503080757440699	Республика Мордовия, Ромодановский муниципальный район, Уришкинское сельское поселение,с.Уришка, Клубная, 3	Россия, республика Мордовия, Ромодановский район, село Уришка	0101000020E61000005ED72FD80DA14640971E4DF564404B40
55044	7	63	1380	17620	54653	\N	54.515439000000001	Республика Мордовия, Ромодановский муниципальный район, Трофимовщинское сельское поселение,с.Трофимовщина, Школьная, 1		0101000020E610000084F068E3889D46409E0AB8E7F9414B40
55027	7	63	1380	16751	55047	\N	54.355269999999997	Республика Мордовия, Ромодановский муниципальный район, Анненковское сельское поселение, с.Старая Михайловка, Центральная, 7		0101000020E6100000FF428F183D954640FD9FC37C792D4B40
95138	7	63	1380	17101	55023	\N	54.423256000000002	"""Республика Мордовия, Ромодановский муниципальный район, Кочуновское сельское поселение,п.Совхоз """"Садвинтрест"""", Садовая, 18"""		0101000020E6100000197442E8A0B54640FBEAAA402D364B40
95139	7	63	1380	56583	54997	\N	54.429966	Республика Мордовия, Ромодановский район, ул. Набережное сельское поселение, п.Ромодановский Махоркосовхоз, пер.Школьный, 7		0101000020E610000060200890A1A946402B323A2009374B40
95140	7	63	1380	16286	54498	\N	54.4325702854429	Республика Мордовия, Ромодановский район, Пятинское сельское поселение,п.Садовский, Центральная, 97	Россия, республика Мордовия, Ромодановский район, поселок Ромоданово	0101000020E610000032C687D9CBAA4640889D29745E374B40
55017	7	63	1380	16286	54498	\N	54.420965936348999	Республика Мордовия, Ромодановский муниципальный район, городское поселение Ромоданово, Центральная, 9	Россия, республика Мордовия, Ромодановский район, поселок Ромоданово	0101000020E61000005C38109205AC46402D5DC136E2354B40
55021	7	63	1380	16286	54413	\N	54.4210576338198	Республика Мордовия, Ромодановский муниципальный район, городское поселение Ромоданово, Транспортный проезд,5	Россия, республика Мордовия, Ромодановский район, поселок Ромоданово	0101000020E6100000DFC5FB71FBAB46400EDC813AE5354B40
95137	7	63	1380	16286	54556	\N	54.420559356274502	Республика Мордовия, Ромодановский район, городское поселение Ромоданово, Пятинское шоссе, 4	Россия, республика Мордовия, Ромодановский район, поселок Ромоданово	0101000020E6100000FA08FCE1E7AB4640EC8497E0D4354B40
55020	7	63	1380	16286	54614	\N	54.420657213498401	Республика Мордовия, Ромодановский муниципальный район, Ромодановское городское поселение, п.Ромоданово, Промышленное шоссе, 18	Россия, республика Мордовия, Ромодановский район, поселок Ромоданово	0101000020E610000092054CE0D6AB4640AFEAAC16D8354B40
55002	7	63	1391	45962	55010	\N	54.301779000000003	с.Масловка, Заречная, 8		0101000020E6100000DB4C8578247046404FCFBBB1A0264B40
55018	7	63	1380	16286	54399	\N	54.420448	Республика Мордовия, Ромодановский муниципальный район, Ромодановское городское поселение, п.Ромоданово, Крылова, 2		0101000020E6100000FAD4B14AE9AB464095D5743DD1354B40
55023	7	63	1380	16286	54430	\N	54.420448	Республика Мордовия, Ромодановский муниципальный район, Ромодановское городское поселение, п.Ромоданово, Железнодорожная, 7		0101000020E6100000FAD4B14AE9AB464095D5743DD1354B40
55022	7	63	1380	16286	54373	\N	54.420448	Республика Мордовия, Ромодановский муниципальный район, Ромодановское городское поселение, п.Ромоданово, Есенина, 7		0101000020E6100000FAD4B14AE9AB464095D5743DD1354B40
55019	7	63	1380	16286	54372	\N	54.420448	Республика Мордовия, Ромодановский муниципальный район, Ромодановское городское поселение, п.Ромоданово, Дорожная, 30		0101000020E6100000FAD4B14AE9AB464095D5743DD1354B40
55042	7	63	1380	17488	55015	\N	54.513489999999997	Республика Мордовия, Ромодановский муниципальный район, Пушкинское сельское поселение, с.Пушкино, Школьная, 1		0101000020E61000008195438B6CAF46405969520ABA414B40
55040	7	63	1380	17404	54771	\N	54.379981000000001	Республика Мордовия, Ромодановский муниципальный район, Малоберезниковское сельское поселение,с.Малые Березники, Дорожная, 34		0101000020E6100000537AA69718BB4640FA0CA837A3304B40
55039	7	63	1380	17325	54968	\N	54.428362999999997	Республика Мордовия, Ромодановский муниципальный район, Липкинское сельское поселение,п.Липки, Школьная, 9		0101000020E610000086AFAF75A98F464081E84999D4364B40
55037	7	63	1380	17244	54858	\N	54.554257999999997	Республика Мордовия, Ромодановский муниципальный район, Курмачкасское сельское поселение,с.Курмачкасы, Кирова, 26А		0101000020E610000044C2F7FE06C54640EFC517EDF1464B40
55035	7	63	1380	17135	54856	\N	54.459845000000001	Республика Мордовия, Ромодановский муниципальный район, Куриловское сельское поселение, с.Курилово, Центральная, 29		0101000020E6100000D4D4B2B5BEBC4640541D7233DC3A4B40
55038	7	63	1380	17296	54966	\N	54.435046	Республика Мордовия, Ромодановский муниципальный район, Салминское сельское поселение,п.Красный Узел, Школьная, 8		0101000020E610000093E52494BE9E4640B8205B96AF374B40
55033	7	63	1380	17038	54855	\N	54.421030000000002	Республика Мордовия, Ромодановский муниципальный район, Кочуновское сельское поселение,с.Кочуново, Молодежная, 26		0101000020E6100000A5D8D138D4B946404451A04FE4354B40
55031	7	63	1380	16950	54772	\N	54.468584	Республика Мордовия, Ромодановский муниципальный район, Константиновское сельское поселение, с.Константиновка, Центральная, 3		0101000020E6100000A54E401361AF4640E5B67D8FFA3B4B40
54993	7	63	1380	15069	\N	\N	54.311214	с.Инят, Центральная, 87	Россия, республика Мордовия, Ромодановский район, село Инят	0101000020E6100000F6D03E56F0B14640570740DCD5274B40
55032	7	63	1380	16992	55013	\N	54.448942000000002	Республика Мордовия, Ромодановский муниципальный район, Константиновское сельское поселение,д.Ивановка, Центральная, 22		0101000020E6100000ADBD4F55A1B3464082E673EE76394B40
55030	7	63	1380	16905	54967	\N	54.451872999999999	Республика Мордовия, Ромодановский муниципальный район, Вырыпаевское сельское поселение, с.Вырыпаево, Школьная, 7		0101000020E61000001A5245F12A934640037976F9D6394B40
55036	7	63	1380	17194	54857	\N	54.488593000000002	Республика Мордовия, Ромодановский муниципальный район, Куриловское сельское поселение,с.Болтино, Химмашевская, 22		0101000020E610000040F9BB77D4C24640FB0626378A3E4B40
55029	7	63	1380	16845	54348	\N	54.340753999999997	Республика Мордовия, Ромодановский муниципальный район, Белозерьевское сельское поселение,с.Белозерье, Центральная, 2		0101000020E610000019AE0E80B8AF464097FDBAD39D2B4B40
55026	7	63	1380	16704	54582	\N	54.382299000000003	Республика Мордовия, Ромодановский муниципальный район, Анненковское сельское поселение, с.Анненково, Новая, 18		0101000020E610000027D9EA724AA646409225732CEF304B40
55025	7	63	1380	16637	55011	\N	54.373856000000004	Республика Мордовия, Ромодановский муниципальный район, Алтарское сельское поселение, с.Алтары, Молодежная, 18		0101000020E6100000E738B709F7AA4640EAB46E83DA2F4B40
55011	7	63	1391	15941	54769	\N	54.260626000000002	с.Черемишево, Молодежная, 35		0101000020E6100000C6A354C2138A4640603E59315C214B40
51968	7	63	1391	28176	54642	\N	54.227148	с.Татарская Тавла, Школьная, 34		0101000020E61000000C94145800AD464008AD872F131D4B40
55000	7	63	1391	33141	54598	\N	54.217821000000001	Республика Мордовия, Лямбирский муниципальный район, сельское поселение  Татарская Свербеевка, Центральная, 38А		0101000020E6100000CE8E54DFF9834640E6B0FB8EE11B4B40
55007	7	63	1391	56598	55072	\N	54.340430078396999	д.Суркино, Молодежная, 2 А	Россия, республика Мордовия, Лямбирский район, село Суркино	0101000020E6100000BF27D6A9F2A14640E449D235932B4B40
51171	7	63	1391	29365	54818	\N	54.364812999999998	с.Смольково, Школьная, 9		0101000020E61000001D5A643BDF7B4640EC134031B22E4B40
54630	7	63	1391	29365	54787	\N	54.364812999999998	Республика Мордовия, Ардатовский муниципальный район, Турдаковское сельское поселение, с.Смольково, Центральная, 21		0101000020E61000001D5A643BDF7B4640EC134031B22E4B40
51500	7	63	1391	49324	55043	\N	54.192284999999998	с.Скрябино, Советская, 35		0101000020E6100000A2EBC20FCEC9464074417DCB9C184B40
55015	7	63	1391	16127	55001	\N	54.264360000000003	с.Протасово, Комсомольская, 12	Россия, республика Мордовия, Лямбирский район, село Протасово	0101000020E61000004BEA043411C446406F2F698CD6214B40
55013	7	63	1391	32594	54549	\N	54.430736000000003	с.Первомайск, Жигули, 15		0101000020E610000088F37002D3834640DD9A745B22374B40
95135	7	63	1391	16088	54638	\N	54.235937	Республика Мордовия, Лямбирский р-н, с.Пензятка, ул.Юбилейная, д.5-а		0101000020E6100000583849F3C77E46404B75012F331E4B40
55012	7	63	1391	61828	79746	\N	54.322253000000003	с.Михайловка, Нижняя, 8	Россия, республика Мордовия, Лямбирский район, село Новая Михайловка	0101000020E61000007940D9942B8A4640DA0418963F294B40
95134	7	63	1391	15560	54393	\N	54.273761	Республика Мордовия, Лямбирский р-н, с.Большая Елховка, Фабричная, 21		0101000020E610000006F2ECF2ADA94640CBF5B6990A234B40
55004	7	63	1391	15560	54393	\N	54.273761	Республика Мордовия, Лямбирский муниципальный район, сельское поселение Елховка, Фабричная, 18	Россия, республика Мордовия, Лямбирский район, поселок Большая Елховка	0101000020E610000006F2ECF2ADA94640CBF5B6990A234B40
55001	7	63	1391	45943	54964	\N	54.275680000000001	с.Болотниково, Садовая, 24 А		0101000020E610000027C286A757764640A514747B49234B40
54999	7	63	1391	15365	\N	\N	54.239105000000002	д.Блохино, 1-Б/3		0101000020E610000091442FA3588A4640B1A71DFE9A1E4B40
54995	7	63	1391	15225	54432	\N	54.180304	Республика Мордовия, Лямбирский муниципальный район, сельское поселение  Атемар, Центральная, 71	Россия, республика Мордовия, Лямбирский район, село Атемар	0101000020E6100000D3307C444CB3464043AB933314174B40
54994	7	63	1391	61824	79740	\N	54.266644999999997	с.Александровка, Долганова, 1	Россия, республика Мордовия, Лямбирский район, село Александровка	0101000020E6100000CF87670932A246402A52616C21224B40
54992	7	63	1391	45763	54394	\N	54.248460000000001	с.Аксеново, Молодежная, 29		0101000020E610000016F9F5436CAC46409D2E8B89CD1F4B40
54990	7	63	287	14950	54770	\N	54.324758000000003	Республика Мордовия, Краснослободский район, с. Шаверки, ул. Ленина, д. 25		0101000020E6100000DCD9571EA4E14540A48E8EAB91294B40
54991	7	63	287	1219	42040	\N	54.523304000000003	Республика Мордовия, Краснослободский район, с. Чукалы, ул. Садовая, д. 13 а		0101000020E6100000A320787C7BD14540D9EE1EA0FB424B40
54983	7	63	287	14600	54427	\N	54.447339999999997	Республика Мордовия, Краснослободский район, с. Старые Горяши, ул. Садовая, д. 2 Г		0101000020E6100000A515DF50F8E44540A818E76F42394B40
54989	7	63	287	14896	54428	\N	54.415021000000003	Республика Мордовия, Краснослободский район, с. Старое Синдрово, ул. Советская, д. 2 А		0101000020E61000003F53AF5B040E46409D137B681F354B40
54986	7	63	287	14753	54854	\N	54.399897000000003	Республика Мордовия, Краснослободский район, д. Старое Зубарево, ул. Нижняя, д. 45		0101000020E610000090A339B2F2E745405F622CD32F334B40
54988	7	63	287	14849	54586	\N	54.337299999999999	Республика Мордовия, Краснослободский район, с. Старая Рябка, ул. Молодежная, д. 32		0101000020E6100000191BBAD91FF645406C787AA52C2B4B40
54982	7	63	287	14552	54962	\N	54.397078	Республика Мордовия, Краснослободский район, с. Слободские Дубровки, ул. Коммунистическая, д. 37		0101000020E6100000A304FD851EC5454005FBAF73D3324B40
95133	7	63	287	14500	54814	\N	54.351948	Республика Мордовия, Краснослободский район, с. Сивинь, ул. Садовая, д. 10-а		0101000020E61000002E8F35238320464041F2CEA10C2D4B40
54980	7	63	287	14472	54547	\N	54.468516000000001	Республика Мордовия, Краснослободский район, с. Селищи, ул. Ленина, д. 1 а		0101000020E61000005567B5C01EC145408DD31055F83B4B40
54976	7	63	287	14285	54773	\N	54.511149778826301	Республика Мордовия, Краснослободский район, с. Русское Маскино, ул. Подгора, д. 14		0101000020E6100000784485EAE6E64540DAACFA5C6D414B40
54985	7	63	287	14687	54580	\N	54.412453999999997	Республика Мордовия, Краснослободский район, с. Пригородное, ул. Центральная, д. 29		0101000020E610000034BBEEAD48E245405C8DEC4ACB344B40
54987	7	63	287	56551	54661	\N	54.380948883394602	Республика Мордовия, Краснослободский район, п. Преображенский, ул. Лесная, д. 18	Россия, республика Мордовия, Краснослободский район	0101000020E61000009888B7CEBFE94540D238D4EFC2304B40
54971	7	63	287	14027	54853	\N	54.375585999999998	Республика Мордовия, Краснослободский район, с. Плужное, ул. Большая, д. 114а		0101000020E6100000378DEDB5A0DF4540F06AB93313304B40
54979	7	63	287	14408	54583	\N	54.413428000000003	Республика Мордовия, Краснослободский  район, с. Новая Карьга, пл. Центральная, д. 1		0101000020E6100000A60D87A581FD454017A06D35EB344B40
54978	7	63	287	14379	54961	\N	54.416592999999999	Республика Мордовия, Краснослободский район, с. Мордовские Парки, ул. Ленина, д. 68		0101000020E6100000AD2F12DA72C045400B5F5FEB52354B40
54977	7	63	287	14308	55007	\N	54.410274000000001	Республика Мордовия, Краснослободский район, с. Куликово, ул. Центральная, д. 23		0101000020E610000003E962D34AD345401633C2DB83344B40
54964	7	63	287	13614	54429	\N	54.425393	Республика Мордовия, Краснослободский район, г. Краснослободск, ул. Микрорайон-3, д. 11		0101000020E6100000F64201DBC1E4454042791F4773364B40
54965	7	63	287	13614	54367	\N	54.425393	Республика Мордовия, Краснослободский район, г. Краснослободск, ул. Микрорайон-3, д. 17		0101000020E6100000F64201DBC1E4454042791F4773364B40
54962	7	63	287	13614	54338	\N	54.425393	Республика Мордовия, Краснослободский район, г. Краснослободск, ул. Микрорайон-1, д. 38		0101000020E6100000F64201DBC1E4454042791F4773364B40
54963	7	63	287	13614	54369	\N	54.425393	Республика Мордовия, Краснослободский район, г. Краснослободск, ул. Кирова, 95		0101000020E6100000F64201DBC1E4454042791F4773364B40
54968	7	63	287	13614	54329	\N	54.425393	Республика Мордовия, Краснослободский район, г. Краснослободск, ул. Интернациональная, д. 25 а		0101000020E6100000F64201DBC1E4454042791F4773364B40
54966	7	63	287	13614	54329	\N	54.425393	Республика Мордовия, Краснослободский район, г. Краснослободск, ул. Интернациональная, д. 67		0101000020E6100000F64201DBC1E4454042791F4773364B40
54975	7	63	287	14221	54613	\N	54.485852000000001	Республика Мордовия, Краснослободский район, д. Красная Подгора, ул. Зеленая, д. 36		0101000020E61000005471E316F3E545401D59F965303E4B40
54973	7	63	287	14128	54577	\N	54.358953	Республика Мордовия, Краснослободский район, с. Колопино, ул. Пролетарская, д. 62 а		0101000020E610000095F430B43A1346408AE6012CF22D4B40
54984	7	63	287	14658	54578	\N	54.414644000000003	Республика Мордовия, Краснослободский район, с. Заречное, ул. Кооперативная, д. 29 А		0101000020E6100000E607AEF204E84540C7BDF90D13354B40
54974	7	63	287	14184	54765	\N	54.474815	Республика Мордовия, Краснослободский район, д. Желтоногово, ул. Центральная, д. 153		0101000020E610000091BA9D7DE5E145403B53E8BCC63C4B40
54972	7	63	287	14093	54543	\N	54.304546999999999	Республика Мордовия, Краснослободский район, с. Ефаево, ул. Центральная, д. 62 б		0101000020E6100000B2F2CB608CE24540268C6665FB264B40
54970	7	63	287	13993	54576	\N	54.387971999999998	Республика Мордовия, Краснослободский район, с. Гумны, ул. Победы, д. 33		0101000020E6100000CA198A3BDEDC4540C1E10511A9314B40
54952	7	63	1256	13148	54760	\N	53.949778000000002	Республика Мордовия, Кочкуровский муниципальный район, Качелайское сельское поселение, село Татарский Умыс, Московская, 167А		0101000020E61000005B069CA564CF4640EB3A545392F94A40
54961	7	63	1256	13552	54774	\N	53.915087999999997	Республика Мордовия, Кочкуровский муниципальный район, Старотурдаковское сельское поселение, село Старые Турдаки, Московская, 3		0101000020E6100000F660527C7CBC4640247B849A21F54A40
54959	7	63	1256	13466	54610	\N	53.9407	Республика Мордовия, Кочкуровский муниципальный район, Семилейское сельское поселение, село Семилей, Центральная, 62А		0101000020E610000060066344A2AA464071AC8BDB68F84A40
54958	7	63	1256	30639	54553	\N	53.9887205191894	с.Сабаево, ул. Ленина, 68, Сабаевская средняя общеобразовательная школа	Россия, республика Мордовия, Кочкуровский район, село Сабаево	0101000020E61000002CB98AC56FDC464028EFE3688EFE4A40
54957	7	63	1256	13379	54955	\N	54.095821999999998	Республика Мордовия, Кочкуровский муниципальный район, Подлесно-Тавлинское сельское поселение, село Подлесная Тавла, Школьная, 3А		0101000020E610000059F78F85E8BC4640601E32E5430C4B40
54960	7	63	1256	13526	54775	\N	53.900767000000002	Республика Мордовия, Кочкуровский муниципальный район, Семилейское сельское поселение, село Новые Турдаки, Карла Маркса, 18		0101000020E61000000890A16307AD4640742843554CF34A40
54956	7	63	1256	13337	54763	\N	54.010950999999999	Республика Мордовия, Кочкуровский муниципальный район, Новопырменское сельское поселение, село Новая Пырма, Школьная, 13		0101000020E6100000209C4F1DABBA4640E36DA5D766014B40
54955	7	63	1256	13286	54960	\N	54.041542999999997	Республика Мордовия, Кочкуровский муниципальный район, Мураньское сельское поселение, село Мурань, Центральная, 52		0101000020E61000005646239F57C846405930F14751054B40
54954	7	63	1256	13236	54764	\N	53.971820999999998	Республика Мордовия, Кочкуровский муниципальный район, Мордовско-Давыдовское сельское поселение, село Мордовское Давыдово, Центральная, 9А		0101000020E610000090DC9A745BDE464073486AA164FC4A40
54953	7	63	1256	13173	54762	\N	53.958897	Республика Мордовия, Кочкуровский муниципальный район, Красномайское сельское поселение, поселок Красномайский, Центральная, 16А		0101000020E610000038BF61A241B64640C39D0B23BDFA4A40
54948	7	63	1256	12952	54370	\N	54.037503999999998	Республика Мордовия, Кочкуровский муниципальный район, Кочкуровское сельское поселение, село Кочкурово, Ленинская, 8		0101000020E6100000ADA580B4FFB546400EBC5AEECC044B40
54729	7	63	1256	12952	54546	\N	54.037506242621902	с.Кочкурово, Ленина, д.37	Россия, республика Мордовия, Кочкуровский район, село Кочкурово	0101000020E6100000F52D73BA2CB64640AFB321FFCC044B40
54951	7	63	1256	13091	54761	\N	53.938988000000002	Республика Мордовия, Кочкуровский муниципальный район, Качелайское сельское поселение, село Качелай, Нагорная, 1А		0101000020E6100000DE57E542E5D5464011AB3FC230F84A40
55287	7	63	1256	56549	54646	\N	54.107632230622997	Республика Мордовия, город Саранск, Октябрьский район, с.Горяйновка, Орлова, 5г	Россия, республика Мордовия, Кочкуровский район, село Горяйновка	0101000020E6100000A795422097AA46406500A8E2C60D4B40
54950	7	63	1256	13054	54808	\N	53.969242000000001	Республика Мордовия, Кочкуровский муниципальный район, Воеводское сельское поселение, село Воеводское, Советская, 17		0101000020E6100000FF5A5EB9DEA246406FF4311F10FC4A40
54949	7	63	1256	12999	54575	\N	54.055300262755203	Республика Мордовия, Кочкуровский муниципальный район, Булгаковское сельское поселение, село Булгаково, Корнишина, 19	Россия, республика Мордовия, Кочкуровский район, село Булгаково	0101000020E61000000A849D62D59E464002BC051214074B40
95120	7	63	698	50006	54358	\N	53.814425999999997	Республика Мордовия, Ковылкинский р-н, с. Янгужинский Майдан, ул.Советская, д.20		0101000020E6100000FE7C5BB0540146408C81751C3FE84A40
54903	7	63	698	33151	55077	\N	53.903058867208202	с. Морд. Шадым, Центральная, 64	Россия, республика Мордовия, Ковылкинский район, село Шадым	0101000020E610000071CB4752D2054640E2ADF36F97F34A40
50532	7	63	698	22700	54908	\N	53.977677999999997	с. Чепурновка, Центральная, 31		0101000020E610000050A6D1E462DC454064027E8D24FD4A40
54912	7	63	698	11262	54848	\N	54.100659	с. Унуевский Майдан, Верхняя, 22		0101000020E6100000DCDAC2F3522146402786E464E20C4B40
95127	7	63	698	50007	55006	\N	54.090921999999999	Республика Мордовия, Ковылкинский район, с. Троицк, ул.Молодежная, 11		0101000020E6100000C4EE3B86C7E84540533E0455A30B4B40
95124	7	63	698	11201	54895	\N	54.050742	Республика Мордовия, Ковылкинский р-н, с. Токмово, Новая, 14		0101000020E61000009B560A815C0C46404E44BFB67E064B40
54913	7	63	698	56606	55092	\N	54.107299174090997	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Старое  Пшенево,Школьная, 18	Россия, республика Мордовия, Ковылкинский район, село Старое Пшеново	0101000020E61000003F00A94D9C1A46405EF23FF9BB0D4B40
95121	7	63	698	31057	54805	\N	53.893970000000003	Республика Мордовия, Ковылкинский район, Стародракинское сельское поселение, с. Старое Дракино,  ул Школьная, д11		0101000020E610000049111956F1F8454075CDE49B6DF24A40
95129	7	63	698	11747	54956	\N	54.216825999999998	Республика Мордовия, Ковылкинский р-н, с. Старое Аллагулово, Центральная, 16		0101000020E61000003CBD529621C04540147651F4C01B4B40
54923	7	63	698	11779	54538	\N	54.219552999999998	с. Старая Самаевка, Сире веле, 36		0101000020E61000004968CBB914D745408D5E0D501A1C4B40
95101	7	63	698	45818	54802	\N	54.109268999999998	Республика Мордовия, Ковылкинский р-н, пос. Силикатный, ул.Горького, 15		0101000020E610000007B64AB038F44540BABBCE86FC0D4B40
54928	7	63	698	12021	54425	\N	54.313237263001902	с. Самозлейка, Центральная, 5	Россия, республика Мордовия, Ковылкинский район, село Самозлейка	0101000020E6100000A9674128EFF14540D672672618284B40
50303	7	63	698	11454	54904	\N	54.002780999999999	пос. Самаевка, Советская, 2		0101000020E6100000AB5D13D21AD345406C06B8205B004B40
54925	7	63	698	11923	55075	\N	54.260656980842001	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Рыбкино, Советская, 5	Россия, республика Мордовия, Ковылкинский район, село Рыбкино	0101000020E610000085950A2AAAE245409B3C65355D214B40
54924	7	63	698	11923	54422	\N	54.262113999999997	с. Рыбкино, Мокшанская, 3		0101000020E61000000951BEA085E2454070E998F38C214B40
95130	7	63	698	50008	54707	\N	54.018745612977902	Республика Мордовия, Ковылкинский район, с. Русская Лашма, ул.Школьная, 18	Россия, республика Мордовия, Ковылкинский район, село Русская Лашма	0101000020E6100000643DB5FAEAEC45402577D84466024B40
54916	7	63	698	56543	54607	\N	54.035420000000002	п. Примокшанский, Песчаная, 7		0101000020E61000007842AF3F89F34540EACF7EA488044B40
95100	7	63	698	16897	54521	\N	54.201085999999997	Республика Мордовия, Ковылкинский р-н, с. Польцо, ул.Молодежная, 24		0101000020E61000009B012EC896E345407BD7A02FBD194B40
50587	7	63	698	49415	54709	\N	54.066485999999998	с. Покровск, Советская, 56		0101000020E610000048C0E8F2E6CE454028D2FD9C82084B40
54915	7	63	698	56572	54852	\N	54.127200025023598	пос. Первомайский, Приовражная, 21	Россия, республика Мордовия, Ковылкинский район, село Первомайский	0101000020E6100000522AE109BD0646408E06F01648104B40
54888	7	63	698	10094	54947	\N	53.990246999999997	с. Парапино, Совесткая, 22		0101000020E61000004F3C670B08F3454026FBE769C0FE4A40
54899	7	63	698	10657	54846	\N	53.953344000000001	с. Паньжа, Центральная, 104А		0101000020E61000000F0C207C28E745403EEB1A2D07FA4A40
54872	7	63	698	48000	54943	\N	53.752538000000001	поселок Октябрьский, Школьная, 1		0101000020E610000023F609A018074640A67F492A53E04A40
54909	7	63	698	11160	55066	\N	54.0415547864541	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Новое Пшенево, Советская, 1А	Россия, республика Мордовия, Ковылкинский район, село Новое Пшенево	0101000020E6100000745FCE6C571446401EFE9AAC51054B40
54929	7	63	698	56590	55057	\N	54.234884999999998	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Новая Самаевка, Центральная, 59	Россия, республика Мордовия, Ковылкинский район, село Новая Самаевка	0101000020E61000009EB470598505464015A930B6101E4B40
54898	7	63	698	56594	55067	\N	53.964774153577402	с. Морд Вечкенино, Советская, 2А	Россия, республика Мордовия, Ковылкинский район, село Мордовское Вечкино	0101000020E6100000944E24986AEE4540FB03E5B67DFB4A40
95122	7	63	698	11024	55090	\N	53.962129277202699	Республика Мордовия, Ковылкинский р-н, с.Мордовское Коломасово, ул.Молодежная, 8-а	Россия, республика Мордовия, Ковылкинский район, село Мордов Коломасово	0101000020E610000025ADF886C21146403FC4060B27FB4A40
95128	7	63	698	48900	54851	\N	54.138843999999999	Республика Мордовия, Ковылкинский р-н, с. Михайловское, Школьная, 42		0101000020E6100000CB14731074CA4540779FE3A3C5114B40
54927	7	63	698	11955	54611	\N	54.297002999999997	с. Мамолаево, Советская, 2		0101000020E610000049BC3C9D2BFC45402DE8BD3104264B40
54934	7	63	698	30738	54608	\N	54.053279000000003	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Курнино, Гагарина, 2А		0101000020E61000004CA60A4625F145402448A5D8D1064B40
54902	7	63	698	10796	54953	\N	53.847225000000002	с. Красный Шадым, Советская, 30		0101000020E6100000069E7B0F970C464043AD69DE71EC4A40
95125	7	63	698	32609	54541	\N	54.100495000000002	Республика Мордовия, Ковылкинский р-н, пос. Красная Пресня, ул.Победы, 12		0101000020E6100000211E8997A7034640AD342905DD0C4B40
95123	7	63	698	11071	54847	\N	54.0184	Республика Мордовия, Ковылкинский р-н, с. Кочелаево, ул.Ленина, 2А		0101000020E6100000EB0088BB7A0546408A1F63EE5A024B40
95098	7	63	698	46371	54801	\N	53.972546999999999	Республика Мордовия, Ковылкинский р-н, с. Клиновка, ул.Центральная, д.40		0101000020E6100000D8497D59DAD5454055698B6B7CFC4A40
54905	7	63	698	56603	55085	\N	53.929966	с. Казеный Майдан, Центральная, 7	Россия, республика Мордовия, Ковылкинский район, село Казенный Майдан	0101000020E61000009EEBFB70900446402B323A2009F74A40
95126	7	63	698	4870	54695	\N	54.118431000000001	Республика Мордовия, Ковылкинский район, с. Изосимовка, ул. Центральная, д.3		0101000020E6100000FE0A992B83DE454092EA3BBF280F4B40
54918	7	63	698	56585	55008	\N	54.087835574304101	Республика Мордовия, Ковылкинский муниципальный район, сельское поселение Ежовка, Старая, 70	Россия, республика Мордовия, Ковылкинский район, село Ежовка	0101000020E6100000B874CC79C6DA4540ABB4C5353E0B4B40
51138	7	63	698	20090	54912	\N	54.021230000000003	с. Гумны, Школная, 16	Россия, республика Мордовия, Ковылкинский район, село Гумны	0101000020E6100000F7730AF2B3DD4540D8D825AAB7024B40
54930	7	63	698	12135	54384	\N	54.158509000000002	с. Волгапино, Советская, 1		0101000020E610000059FD118601E34540938FDD054A144B40
54889	7	63	698	56589	55046	\N	53.928938000000002	с. Васильевка, Школьная, 1	Россия, республика Мордовия, Ковылкинский район, село Васильевка	0101000020E6100000912C6002B7EE45407E01BD70E7F64A40
54920	7	63	698	11632	54850	\N	54.172936	с. Большой Азясь, Молодежная, 35		0101000020E6100000374F75C8CDD64540892650C422164B40
95119	7	63	698	32381	54806	\N	53.813453000000003	Республика Мордовия, Ковылкинский район, с.Алькино, ул. Школьная, 51		0101000020E610000001DBC1887DFA4540A3EA573A1FE84A40
95117	7	63	963	8019	54693	\N	53.960003999999998	Республика Мордовия, Инсарский район, Ямщинское сельское поселение, с.Ямщина, ул.Молодежная, д.8-а		0101000020E6100000FBB0DEA815204640BC033C69E1FA4A40
54849	7	63	866	6530	54534	\N	54.690271893267202	село Кемля, Советская, 207	Россия, республика Мордовия, Ичалковский район, Кемля	0101000020E610000048C32973F3A1464019AC38D55A584B40
54900	7	63	963	10715	55003	\N	54.079757000000001	Республика Мордовия, Кадошкинский муниципальный район, Пушкинское сельское поселение, адрес помещения для голосования: село Сиалеевский Майдан, улица Нижняя, дом 9, адрес УИК: село Пушкино, улица Московская, 2		0101000020E61000001A506F46CD1946404450357A350A4B40
54896	7	63	963	10522	54759	\N	54.094048000000001	Республика Мордовия, Кадошкинский муниципальный район, Пушкинское сельское поселение, село Пушкино, Московская, 2		0101000020E610000062D8614CFA2F46408A20CEC3090C4B40
54894	7	63	963	10407	54845	\N	54.019421000000001	Республика Мордовия, Кадошкинский муниципальный район, Паевское сельское поселение, село Паево, адрес помещения для голосования: улица Школьная, дом 22, адрес УИК: Школьная, 20		0101000020E610000073D9E89C9F1C464085ED27637C024B40
54895	7	63	963	10473	54949	\N	54.137867999999997	Республика Мордовия, Кадошкинский муниципальный район, Пушкинское сельское поселение, адрес помещения для голосования: село Нагаево, улица Школьная, дом 67, адрес УИК: село Пушкино, улица Московская, 2		0101000020E61000008D98D9E7313646401C959BA8A5114B40
54890	7	63	963	56597	55071	\N	53.954456999999998	Республика Мордовия, Кадошкинский муниципальный район, Латышовское сельское поселение, село Латышовка, адрес помещения для голосования: улица Молодежная, дом 12 А, адрес УИК: Молодежная, 12	Россия, республика Мордовия, Кадошкинский район, село Латышевка	0101000020E6100000D71533C2DB3346401938A0A52BFA4A40
54887	7	63	963	9956	54336	\N	54.030396000000003	Республика Мордовия, Кадошкинский муниципальный район, Кадошкинское городское поселение, рабочий поселок Кадошкино, Светотехническая, 6 А		0101000020E6100000F8A75489B2334640F1F62004E4034B40
54886	7	63	963	9956	54383	\N	54.030396000000003	Республика Мордовия, Кадошкинский муниципальный район, Кадошкинское городское поселение, рабочий поселок Кадошкино, Крупской, 14 А		0101000020E6100000F8A75489B2334640F1F62004E4034B40
54885	7	63	963	9956	54656	\N	54.030716634929703	Республика Мордовия, Кадошкинский муниципальный район, Кадошкинское городское поселение, рабочий поселок Кадошкино, Заводская, 35	Россия, республика Мордовия, Кадошкинский район, поселок Кадошкино	0101000020E610000059A31EA2D13346403337DF88EE034B40
54897	7	63	963	52959	54950	\N	54.066490999999999	Республика Мордовия, Кадошкинский муниципальный район, Пушкинское сельское поселение,  адрес помещения для голосования: поселок Инсар, улица Советская, дом 31 А, адрес УИК: село Пушкино, улица Московская, 2		0101000020E6100000B29E5A7D752546403A3DEFC682084B40
54893	7	63	963	10385	55002	\N	54.025356000000002	Республика Мордовия, Кадошкинский муниципальный район, Глушковское сельское поселение, село Глушково, А. Корнеева, 2		0101000020E6100000D593F947DF204640F2608BDD3E034B40
54892	7	63	963	10315	54599	\N	54.003261999999999	Республика Мордовия, Кадошкинский муниципальный район, Большеполянское сельское поселение, село Большая Поляна, адрес помещения для голосования: улица Школьная, дом 1 А, адрес УИК: Ленина, 9		0101000020E610000048C2BE9D44284640E7A8A3E36A004B40
54891	7	63	963	10248	54679	\N	53.9504355710433	Республика Мордовия, Кадошкинский муниципальный район, Адашевское сельское поселение, село Адашево, адрес помещения для голосования: улица Пролетарская, дом 1, адрес УИК: Ленина, 5	Россия, республика Мордовия, Кадошкинский район, село Адашево	0101000020E6100000FE98D6A6B1294640757808E3A7F94A40
54869	7	63	866	9194	55021	\N	54.654505999999998	с.Ульянка, Гагарина, 1		0101000020E6100000213A048E04AE4640948444DAC6534B40
54866	7	63	866	47890	55016	\N	54.697645999999999	пос. Троицкий, Колхозная, 1		0101000020E61000007BD80B056CB94640B517D1764C594B40
54882	7	63	866	9794	\N	\N	54.760449000000001	с.Тарханово, Ленинская, 17	Россия, республика Мордовия, Ичалковский район, село Тарханово	0101000020E61000001BBCAFCA85D4464051A3906456614B40
54855	7	63	866	32577	54573	\N	54.725431	пос. Смольный, Школьная, 1		0101000020E6100000FD82DDB06DA5464096404AECDA5C4B40
54856	7	63	866	32577	54648	\N	54.725431	Республика Мордовия, Ичалковский муниципальный район, сельское поселение Смольный, Мира, 2		0101000020E6100000FD82DDB06DA5464096404AECDA5C4B40
54857	7	63	866	32577	54755	\N	54.725431	пос. Смольный, Алатырская, 6		0101000020E6100000FD82DDB06DA5464096404AECDA5C4B40
95118	7	63	866	9783	54893	\N	54.739009000000003	Республика Мордовия, Ичалковский р-н, с. Селищи, ул.Центральная, д.36-б		0101000020E61000004CDF6B088ED146408F39CFD8975E4B40
54862	7	63	866	47816	54570	\N	54.689059999999998	с. Рождествено, Первомайская, 6	Россия, республика Мордовия, Ичалковский район, село Рождествено	0101000020E61000009605137F14A54640AA7D3A1E33584B40
54863	7	63	866	47816	54778	\N	54.689059999999998	с.Рождествено, Кулакова, 44		0101000020E61000009605137F14A54640AA7D3A1E33584B40
54876	7	63	866	9514	54952	\N	54.625411	село Резоватово, Советская, 18		0101000020E6100000E2934E2498BC464082C7B7770D504B40
54860	7	63	866	47763	54901	\N	54.591287999999999	с.Пермеево, Садовая, 13		0101000020E6100000999D45EF5498464035423F53AF4B4B40
54874	7	63	866	9424	54843	\N	54.664915999999998	село Парадеево, Колхозная, 2		0101000020E61000004E44BFB67ED44640274BADF71B554B40
54880	7	63	866	9707	54844	\N	54.740547999999997	село Папулево, Красная, 1 А		0101000020E6100000BDC804FC1ACB4640218FE046CA5E4B40
54864	7	63	866	33005	54637	\N	54.6637300539752	пос.ст.Оброчное, Мира, 28	Россия, республика Мордовия, Ичалковский район, село Оброчное	0101000020E6100000217365506DAA4640E2AFC91AF5544B40
54868	7	63	866	33005	81095	\N	54.663125999999998	с.Оброчиное, Ленина, 106		0101000020E610000096ECD808C4A946404B901150E1544B40
54865	7	63	866	9019	55014	\N	54.725892999999999	село Новые Ичалки, Нагорная, 8		0101000020E61000001C5F7B6649B446409AB2D30FEA5C4B40
54859	7	63	866	8756	54925	\N	54.621799000000003	с.Лобаски, Молодежная, 15		0101000020E61000009DBAF2599E934640BFD7101C974F4B40
54812	7	63	866	6530	54534	\N	54.691365751645101	село Кемля, Советская, 68	Россия, республика Мордовия, Ичалковский район, Кемля	0101000020E6100000048F6FEF1AA046407EC85BAE7E584B40
54851	7	63	866	6530	54704	\N	54.690818999999998	село Кемля, Кооперативный пер, 2		0101000020E6100000488C9E5BE89E46404B3ACAC16C584B40
54850	7	63	866	6530	54558	\N	54.690818999999998	село Кемля, Советская, 143		0101000020E6100000488C9E5BE89E46404B3ACAC16C584B40
54836	7	63	866	6530	54558	\N	54.6910840354467	село Кемля, Советская, 66	Россия, республика Мордовия, Ичалковский район, Кемля	0101000020E61000006798DA52079F4640F964C57075584B40
54837	7	63	866	6530	54572	\N	54.690818999999998	село Кемля, Больничный пер, 10		0101000020E6100000488C9E5BE89E46404B3ACAC16C584B40
54877	7	63	866	48085	54757	\N	54.603748000000003	село Камаево, Шлукина, 6		0101000020E6100000F8DF4A766CC4464041834D9D474D4B40
54854	7	63	866	8439	54705	\N	54.678592999999999	село Ичалки, им. В.И.Чинченкова, 3		0101000020E61000002E01F8A754A54640B325AB22DC564B40
54852	7	63	866	8439	54615	\N	54.678592999999999	село Ичалки, Школьная, 2 А		0101000020E61000002E01F8A754A54640B325AB22DC564B40
54853	7	63	866	8439	54574	\N	54.678592999999999	село Ичалки, Махова, 16	Россия, республика Мордовия, Ичалковский район, село Ичалки	0101000020E61000002E01F8A754A54640B325AB22DC564B40
54873	7	63	866	56579	54957	\N	54.584307000000003	деревня Инсаровска, Хилковская, 1А	Россия, республика Мордовия, Ичалковский район, село Инсаровка	0101000020E6100000CFF9298E03B3464075E95F92CA4A4B40
54884	7	63	866	56571	54849	\N	54.730316884251003	поселок Инелей, Ленинская, 37	Россия, республика Мордовия, Ичалковский район, село Инелей	0101000020E6100000965CC5E237DD46403E5B07077B5D4B40
54871	7	63	866	47979	54826	\N	54.652521	с.Дубровское, Советская, 62		0101000020E610000066DD3F16A2B54640037AE1CE85534B40
54725	7	63	866	56542	54592	\N	54.672491280277399	Республика Мордовия, Дубенский муниципальный район, Кабаевское сельское поселение, Московская, д.98	Россия, республика Мордовия, Ичалковский район, село Дубенки	0101000020E6100000022A1C412AD346405BED612F14564B40
54846	7	63	866	47528	54840	\N	54.733857999999998	с.Гуляево, Советская, 44		0101000020E6100000B77D8FFAEB8F464038F4160FEF5D4B40
54875	7	63	866	9440	54941	\N	54.684818999999997	село Вечкусы, Ленинская, 3		0101000020E61000007C46223482CD4640F7562426A8574B40
54883	7	63	866	9864	\N	\N	54.764536999999997	село Ведянцы, Романова, 2	Россия, республика Мордовия, Ичалковский район, село Ведянцы	0101000020E6100000D32D3BC43FDE46407DCA3159DC614B40
54861	7	63	866	8831	55054	\N	54.5643375163759	с.Большая Пестровка, Смоленская, 45	Россия, республика Мордовия, Ичалковский район, село Большая Пестровка	0101000020E6100000FF5A5EB9DEA04640EDF1423A3C484B40
54878	7	63	866	9609	54999	\N	54.711376654863102	село Болдасево, Советская, 28	Россия, республика Мордовия, Ичалковский район, село Болдасево	0101000020E610000058ACE122F7C646403410CB660E5B4B40
54879	7	63	866	9631	55000	\N	54.735469000000002	село Береговые Сыреси, Советская, 7 Б		0101000020E61000008237A45181CD4640651C23D9235E4B40
14685	7	63	866	58366	64828	\N	54.678753021590097	с.Баево, 1 Мая, 19 А	Россия, республика Мордовия, Ичалковский район, село Баево	0101000020E6100000A26131EA5AA94640EC87D860E1564B40
54845	7	63	903	8084	54842	\N	53.897896000000003	Республика Мордовия, Инсарский муниципальный район, Яндовищенское сельское поселение, село Яндовище, Колхозная, 14		0101000020E6100000E02EFB75A7474640C89A9141EEF24A40
54843	7	63	903	7970	54752	\N	53.781001000000003	Республика Мордовия, Инсарский муниципальный район, Языково-Пятинское сельское поселение, село Языкова Пятина, Гагарина, 25		0101000020E61000006AF816D68D47464058923CD7F7E34A40
54842	7	63	903	56577	54948	\N	53.715303153154501	Республика Мордовия, Инсарский муниципальный район, Шадымо-Рыскинское сельское поселение, село Шадымо-Рыскино, Бибишева, 28	Россия, республика Мордовия, Инсарский район, село Шадым-Рыскино	0101000020E61000002843554CA553464087DD770C8FDB4A40
54841	7	63	903	7887	54899	\N	53.89293	Республика Мордовия, Инсарский муниципальный район, Челмодеевско-Майданское сельское поселение, село Челмодеевский Майдан, Центральная, 41		0101000020E6100000A374E95F921C464003CFBD874BF24A40
54839	7	63	903	7793	54837	\N	53.867628000000003	Республика Мордовия, Инсарский муниципальный район, Староверхисское сельское поселение, село Старые Верхиссы, Центральная, 10		0101000020E6100000F450DB8651444640058C2E6F0EEF4A40
54838	7	63	903	7739	54756	\N	53.814357000000001	Республика Мордовия, Инсарский муниципальный район, Сиалеевско-Пятинское сельское поселение, село Сиалеевская Пятина, Советская, 50		0101000020E6100000E9B985AE444246406422A5D93CE84A40
54834	7	63	903	7572	54841	\N	53.902915	Республика Мордовия, Инсарский муниципальный район, Русско-Паевское сельское поселение, село Русская Паевка, Садовая, 16		0101000020E6100000D8497D59DA274640AF08FEB792F34A40
54840	7	63	903	56587	55012	\N	53.851612000000003	Республика Мордовия, Инсарский муниципальный район, Староверхисское сельское поселение, село Новые Верхиссы, Большая, 28	Россия, республика Мордовия, Инсарский район, село Новые Верхисы	0101000020E610000024438EAD67484640CA703C9F01ED4A40
54833	7	63	903	7538	54750	\N	53.926870000000001	Республика Мордовия, Инсарский муниципальный район, Новлейское сельское поселение, село Новлей, Московская, 62		0101000020E6100000F0517FBDC24646405FD218ADA3F64A40
54831	7	63	903	56596	55070	\N	53.827437205644898	Республика Мордовия, Инсарский муниципальный район, Нижневязерское сельское поселение, село Нижняя Вязера, Центральная, 178	Россия, республика Мордовия, Инсарский район, село Нижняя Вязерка	0101000020E610000068B114C9573C46400C40A374E9E94A40
54830	7	63	903	7434	54998	\N	53.742426000000002	Республика Мордовия, Инсарский муниципальный район, Мордовско-Паевское сельское поселение, село Мордовская Паевка, Центральная, 53		0101000020E6100000FBAC32535A2146409DD9AED007DF4A40
54829	7	63	903	56582	54996	\N	53.728798938644601	Республика Мордовия, Инсарский муниципальный район, Лухменско-Майданское сельское поселение, село Лухменский Майдан, Фролова, 2	Россия, республика Мордовия, Инсарский район, село Лухманский Майдан	0101000020E6100000C7B94DB857144640C32D1F4949DD4A40
54835	7	63	903	7613	54944	\N	53.876196999999998	Республика Мордовия, Инсарский муниципальный район, Русско-Паевское сельское поселение, село Кульмеж, Антроповых, 79		0101000020E61000006077BAF3C425464039ED293927F04A40
54827	7	63	903	7258	54993	\N	53.796252000000003	Республика Мордовия, Инсарский муниципальный район, Кочетовское сельское поселение, село Кочетовка, Ленина, 56		0101000020E61000000839EFFFE3204640F3AFE595EBE54A40
54832	7	63	903	7482	54838	\N	53.814377999999998	Республика Мордовия, Инсарский муниципальный район, Казеевское сельское поселение, село Казеевка, Новая Казеевка, 64		0101000020E610000085251E50363346407B4ACE893DE84A40
54820	7	63	903	32694	54467	\N	53.865841381786801	Республика Мордовия, Инсарский муниципальный район, городское поселение Инсар, Советская, 55	Россия, республика Мордовия, Инсарский район, Инсар	0101000020E61000007FA5F3E1593046409A44BDE0D3EE4A40
54819	7	63	903	32694	54467	\N	53.863642944205203	Республика Мордовия, Инсарский муниципальный район, городское поселение Инсар, Советская, 22а	Россия, республика Мордовия, Инсарский район, Инсар	0101000020E6100000AA0D4E44BF2E4640AD3594DA8BEE4A40
54822	7	63	903	32694	54461	\N	53.865790650682399	Республика Мордовия, Инсарский муниципальный район, городское поселение Инсар, Гагарина, 28а	Россия, республика Мордовия, Инсарский район, Инсар	0101000020E610000055C1A8A44E304640E8154F3DD2EE4A40
53433	7	63	903	46839	54921	\N	53.826386824758302	с. Горки, Энгельса, 15		0101000020E6100000EBE1CB4411264640766B990CC7E94A40
54826	7	63	903	7198	54749	\N	53.780197999999999	Республика Мордовия, Инсарский муниципальный район, Верхнелухменское сельское поселение, село Верхняя Лухма, Московская, 42		0101000020E6100000B900344A97184640CA332F87DDE34A40
54828	7	63	903	7300	54945	\N	53.831876000000001	Республика Мордовия, Инсарский муниципальный район, Кочетовское сельское поселение, село Арбузовка, Ленина, 67а		0101000020E610000041F0F8F6AE294640E529ABE97AEA4A40
54771	7	63	475	4326	54834	\N	54.124383999999999	Республика Мордовия, Зубово-Полянский район, поселок Ясная Поляна, Школьная, 8		0101000020E6100000056A3178986A4540A5129ED0EB0F4B40
54813	7	63	475	6469	54539	\N	54.417661000000003	Республика Мордовия, Зубово-Полянский район,  рабочий поселок Явас, Чернореченская, 1		0101000020E6100000F7C95180286C454047E867EA75354B40
54815	7	63	475	6469	54424	\N	54.417661000000003	Республика Мордовия, Зубово-Полянский район,  рабочий поселок Явас, Косарева, 30		0101000020E6100000F7C95180286C454047E867EA75354B40
54811	7	63	475	6469	54424	\N	54.417661000000003	Республика Мордовия, Зубово-Полянский район,  рабочий поселок Явас, Косарева, 28		0101000020E6100000F7C95180286C454047E867EA75354B40
54814	7	63	475	6469	54380	\N	54.417661000000003	Республика Мордовия, Зубово-Полянский район,  рабочий поселок Явас, Дзержинского, 39		0101000020E6100000F7C95180286C454047E867EA75354B40
54772	7	63	475	56588	55020	\N	54.082228194828197	Республика Мордовия, Зубово-Полянский район, Школа Тракторных бригадиров, Садовая, 2	Россия, республика Мордовия, Зубово-Полянский район, село Школа Тракторных Бригадиров	0101000020E610000076FEEDB25F6F454062687572860A4B40
54810	7	63	475	6414	54337	\N	53.849201000000001	Республика Мордовия, Зубово-Полянский район,  село Ширингуши, Новая, 19		0101000020E61000004F779E78CE624540815D4D9EB2EC4A40
54807	7	63	475	6250	54839	\N	54.116360584515697	Республика Мордовия, Зубово-Полянский район,  рабочий поселок Умет, адрес помещения для голосования: ул. Школьная, д. 20, адрес УИК: ул.Почтовая, 9	Россия, республика Мордовия, Зубово-Полянский район, Умет	0101000020E61000008E20956247594540D2C3D0EAE40E4B40
54809	7	63	475	6250	54368	\N	54.110151887117901	Республика Мордовия, Зубово Полянский муниципальный район, городское поселение Умет, Озерная, 7А	Россия, республика Мордовия, Зубово-Полянский район, Умет	0101000020E61000004FB16A10E658454064CBF275190E4B40
54789	7	63	475	5300	54524	\N	54.342775000000003	Республика Мордовия, Зубово-Полянский район,  поселок Ударный, Молодежная, 2		0101000020E6100000BE4C1421756D454076711B0DE02B4B40
54806	7	63	475	6190	54836	\N	54.017235999999997	Республика Мордовия, Зубово-Полянский район,  село Уголок, адрес помещения для голосования: ул. Школьная, д. 2, адрес УИК: Центральная, 19		0101000020E6100000BB9866BAD76D45402C280CCA34024B40
54805	7	63	475	6171	54530	\N	53.930883000000001	Республика Мордовия, Зубово-Полянский район,  село Тарханская Потьма, Ленина, 128		0101000020E6100000EF91CD55F37C454081B3942C27F74A40
54804	7	63	475	6100	54954	\N	54.162410000000001	Республика Мордовия, Зубово-Полянский район,  село Студенец, Центральная, 34		0101000020E6100000280F0BB5A62945408D45D3D9C9144B40
54803	7	63	475	6044	54746	\N	53.838681999999999	Республика Мордовия, Зубово-Полянский район,  село Старое Бадиково, адрес помещения для голосования: ул. Центральная, д. 2, адрес УИК: ул.Центральная, 1		0101000020E6100000514D49D6E158454037DF88EE59EB4A40
54801	7	63	475	56556	54678	\N	54.267529900727801	Республика Мордовия, Зубово-Полянский район,  п. Сосновка, Почтовая, 5	Россия, республика Мордовия, Зубово-Полянский район, село Сосновка	0101000020E610000040FCFCF7E071454075594C6C3E224B40
54790	7	63	475	5351	54942	\N	54.006549	Республика Мордовия, Зубово-Полянский район,  село Свеженькая, Школьная, 6		0101000020E6100000B35DA10F963745402769FE98D6004B40
53760	7	63	226	19361	54698	\N	54.892007	с. Новое Баево, Советская, 34		0101000020E6100000DAC87553CADD4640CB660E492D724B40
54779	7	63	475	4793	54739	\N	53.838676999999997	Республика Мордовия, Зубово-Полянский район, село Русский Лундан, Садовая, 2 А		0101000020E6100000C53A55BE67724540257497C459EB4A40
54800	7	63	475	5831	54378	\N	54.118842999999998	Республика Мордовия, Зубово-Полянский район,  рабочий поселок Потьма, адрес помещения для голосования: ул. Школьная, д. 19 А, адрес УИК: Школьная, 24		0101000020E61000009F03CB1132744540E42D573F360F4B40
54799	7	63	475	5831	54655	\N	54.119111925773097	Республика Мордовия, Зубово-Полянский район,  рабочий поселок Потьма, адрес помещения для голосования: ул. Пионерская, д. 20, адрес УИК: Школьная, 24	Россия, республика Мордовия, Зубово-Полянский район, Потьма	0101000020E6100000C2DF2F664B744540D447E00F3F0F4B40
54784	7	63	475	5039	54992	\N	54.000737999999998	Республика Мордовия, Зубово-Полянский район,  село Покровские Селищи, Монастырская, 164		0101000020E6100000AED85F764F804540A6EECA2E18004B40
54798	7	63	475	5771	54835	\N	54.304327000000001	Республика Мордовия, Зубово-Полянский район,  село Подлясово, Центральная, 37/1		0101000020E610000073F1B73D415645401825E82FF4264B40
54797	7	63	475	5734	54833	\N	53.870665000000002	Республика Мордовия, Зубово-Полянский район,  село Пичпанда, Советская, 33		0101000020E6100000F513CE6E2D7B4540CC6262F371EF4A40
54818	7	63	475	6831	54641	\N	54.360951999999997	Республика Мордовия, Зубово-Полянский район,  поселок Парца, Школьная, 2 А		0101000020E6100000B58828266F6C454080B6D5AC332E4B40
54817	7	63	475	6771	54618	\N	54.409655000000001	Республика Мордовия, Зубово-Полянский район,  поселок Озерный, Центральная, 14 Б		0101000020E6100000BE88B663EA5845404AD235936F344B40
54794	7	63	475	5572	54537	\N	53.994281000000001	Республика Мордовия, Зубово-Полянский район,  село Новые Выселки, адрес помещения для голосования: ул. Школьная, д. 137 А, адрес УИК: Центральная, 226 А		0101000020E6100000525F96766A7C454060048D9944FF4A40
54793	7	63	475	5505	54745	\N	53.794311	Республика Мордовия, Зубово-Полянский район,  село Новое Бадиково, Советская, 1		0101000020E61000008F34B8AD2D5E454031ED9BFBABE54A40
54796	7	63	475	5699	54643	\N	54.045360000000002	Республика Мордовия, Зубово-Полянский район,  село Новая Потьма, адрес помещения для голосования: ул.Советская, д. 43, адрес УИК: Советская, 43 А		0101000020E61000008DF161F6B27D4540F645425BCE054B40
54791	7	63	475	5409	54743	\N	53.854044999999999	Республика Мордовия, Зубово-Полянский район,  село Мордовский Пимбур, адрес помещения для голосования: ул. Центральная, д. 10, адрес УИК: Центральная, 4		0101000020E610000093567C43E1914540FA27B85851ED4A40
54792	7	63	475	5457	54664	\N	53.958928	Республика Мордовия, Зубово-Полянский район,  село Мордовская Поляна, адрес помещения для голосования: ул. Степная, д. 44ё, адрес УИК: Международная, 111 Б		0101000020E61000006A6AD95A5F6A4540FE9B1727BEFA4A40
54802	7	63	475	5991	54747	\N	54.237284000000002	Республика Мордовия, Зубово-Полянский район,  поселок Молочница, Новая, 1 А		0101000020E6100000F9C08EFF027145409AEE75525F1E4B40
54816	7	63	475	6726	54748	\N	54.463172999999998	Республика Мордовия, Зубово-Полянский район,  поселок Лесной, Лесная, 11		0101000020E6100000505260014C5B4540F2B1BB40493B4B40
54788	7	63	475	5234	54597	\N	54.309648000000003	Республика Мордовия, Зубово-Полянский район,  поселок Леплей, адрес помещения для голосования: ул. Садовая, д. 28, адрес УИК: Советская, 5		0101000020E6100000DE019EB4706D4540CBA2B08BA2274B40
54787	7	63	475	5190	54831	\N	54.202219963696798	Республика Мордовия, Зубово-Полянский район,  село Каргашино, Сураевой, 8	Россия, республика Мордовия, Зубово-Полянский район, село Каргашино	0101000020E6100000DD408177F24D45406E4C4F58E2194B40
54785	7	63	475	5080	54940	\N	53.978467000000002	Республика Мордовия, Зубово-Полянский район,  село Каргал, Школьная, 27		0101000020E6100000ABECBB22F87D45408D9B1A683EFD4A40
54786	7	63	475	5142	54946	\N	53.936788999999997	Республика Мордовия, Зубово-Полянский район,  село Известь, Свердлова, 18		0101000020E6100000FAD170CADC3845405320B3B3E8F74A40
54767	7	63	475	4046	54409	\N	54.078885	Республика Мордовия, Зубово-Полянский район, рабочий поселок Зубова Поляна, Советская, 50 В		0101000020E6100000D788601C5C6A45408E9257E7180A4B40
54768	7	63	475	4046	54418	\N	54.078885	Республика Мордовия, Зубово-Полянский район, рабочий поселок Зубова Поляна, Олега Кошевого, 24		0101000020E6100000D788601C5C6A45408E9257E7180A4B40
54766	7	63	475	4046	54361	\N	54.078885	Республика Мордовия, Зубово-Полянский район, рабочий поселок Зубова Поляна, Новикова-Прибоя, 23		0101000020E6100000D788601C5C6A45408E9257E7180A4B40
54769	7	63	475	4046	54416	\N	54.078885	Республика Мордовия, Зубово-Полянский район, рабочий поселок Зубова Поляна, Ленинская, 7 А		0101000020E6100000D788601C5C6A45408E9257E7180A4B40
54770	7	63	475	4046	54622	\N	54.076159871268601	Республика Мордовия, Зубово-Полянский район, рабочий поселок Зубова Поляна, Новикова-Прибоя, 19	Россия, республика Мордовия, Зубово-Полянский район, поселок Зубова Поляна	0101000020E61000000DC2DCEEE56A4540B6A1629CBF094B40
54783	7	63	475	4977	54742	\N	53.972472000000003	Республика Мордовия, Зубово-Полянский район,  село Зарубкино, Балашова, 6		0101000020E6100000DA756F45628045404B2366F679FC4A40
54782	7	63	475	4942	54640	\N	54.125264999999999	Республика Мордовия, Зубово-Полянский район,  село Журавкино, адрес помещения для голосования: ул. Заречная, д. 82, адрес УИК: Заречная, 23		0101000020E610000072A8DF85AD494540AE2AFBAE08104B40
54781	7	63	475	4876	54994	\N	53.872819999999997	Республика Мордовия, Зубово-Полянский район,  село Жуковка, адрес помещения для голосования: ул. Школьная, д. 22, адрес УИК: Школьная, 34		0101000020E6100000F5BBB0355B5D4540B9A5D590B8EF4A40
54138	7	62	\N	1218	62258	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Димитрова, д. 57		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54780	7	63	475	4835	54632	\N	54.161883000000003	Республика Мордовия, Зубово-Полянский район, село Дубитель, адрес помещения для голосования: ул. Пионерская, д. 23, адрес УИК: Центральная, 11		0101000020E61000006803B001114A4540A2630795B8144B40
54743	7	63	475	2835	54928	\N	53.861814000000003	Республика Мордовия, Зубово-Полянский район, село Горенка, Школьная, 11		0101000020E6100000EE5D83BEF4724540139ED0EB4FEE4A40
95116	7	63	475	4631	54832	\N	53.848064000000001	Республика Мордовия, Зубово-Полянский район, с. Выша, ул.Школьная, д.1		0101000020E61000005BED612F143045401D75745C8DEC4A40
54777	7	63	475	4662	54995	\N	54.280994999999997	Республика Мордовия, Зубово-Полянский район, село Вадовские Селищи, Молодежная, 6		0101000020E610000076374F75C851454075ABE7A4F7234B40
54775	7	63	475	4568	54741	\N	53.899559128477598	Республика Мордовия, Зубово-Полянский район, село Булдыгино, Центральная, 59		0101000020E6100000A3B1F677B66F454047E9D2BF24F34A40
54774	7	63	475	4504	54557	\N	53.910659000000003	Республика Мордовия, Зубово-Полянский район, село Ачадово, адрес помещения для голосования, ул. Молодежная, д. 36, адрес УИК: ул.Молодежная, 1		0101000020E6100000C6A2E9EC648045406F675F7990F44A40
95115	7	63	475	4440	\N	\N	54.236274000000002	Республика Мордовия, Зубово-Полянский район, с. Анаево, ул.Советская, д.32	Россия, республика Мордовия, Зубово-Полянский район, село Анаево	0101000020E61000004FADBEBA2A4845409372F7393E1E4B40
54795	7	63	475	5614	54991	\N	54.047511999999998	Республика Мордовия, Зубово-Полянский район,  село Аким-Сергеевка, адрес помещения для голосования: ул. Алтухова, д. 93, адрес УИК:Центральная, 226 А		0101000020E610000016359886E171454072158BDF14064B40
54742	7	63	466	2741	55040	\N	54.577314999999999	Республика Мордовия, Ельниковский муниципальный район, Ельниковское сельское поселение, с.Старые Пичингуши, Безбородова, 8		0101000020E6100000B090B932A8EA4540C03E3A75E5494B40
54765	7	63	466	52621	54744	\N	54.555453999999997	Республика Мордовия, Ельниковский муниципальный район, Старотештелимское сельское поселение, с.Старотештелимскме Выселки, Школьная, 1		0101000020E610000064062AE3DF0746405837DE1D19474B40
54756	7	63	466	3558	54606	\N	54.586461999999997	Республика Мордовия, Ельниковский муниципальный район, Стародевиченское сельское поселение, с.Стародевичье, Ленинская, 8		0101000020E6100000D34B8C65FAE14540622CD32F114B4B40
54758	7	63	466	3660	54935	\N	54.692655999999999	Республика Мордовия, Ельниковский муниципальный район, Новоникольское сельское поселение, с.Софьино, Советская, 47		0101000020E6100000658F5033A4F8454068B0A9F3A8584B40
54735	7	63	466	56564	54735	\N	54.579642099966399	с.Петровка, Школьная, 3а		0101000020E610000087E0B88C9BFC4540ABB184B5314A4B40
54751	7	63	466	3299	54736	\N	54.794451000000002	Республика Мордовия, Ельниковский муниципальный район, Новоямское сельское поселение, с.Новый Ковыляй, Колхозная, 3		0101000020E610000066F84F3750D4454023A30392B0654B40
54755	7	63	466	3521	54830	\N	54.568556999999998	Республика Мордовия, Ельниковский муниципальный район, Стародевиченское сельское поселение, д.Новые Пичингуши, Колхозная, 78		0101000020E6100000E012807F4AD94540B874CC79C6484B40
54750	7	63	466	56591	55068	\N	54.736885014568799	Республика Мордовия, Ельниковский муниципальный район, Новоямское сельское поселение, с.Новоямская Слобода, Центральная, 168		0101000020E610000049F6083543DC4540DCF4673F525E4B40
54763	7	63	466	3920	54989	\N	54.492604	Республика Мордовия, Ельниковский муниципальный район, Новоусадское сельское поселение, с.Новоусадские Выселки, Луговая, 11		0101000020E6100000FB912232AC0846407CF0DAA50D3F4B40
54757	7	63	466	3628	55050	\N	54.682746999999999	Республика Мордовия, Ельниковский муниципальный район, Новоникольское сельское поселение, с.Новоникольское, Пролетарская, 7		0101000020E61000004F22C2BF080446409738F24064574B40
54764	7	63	466	3951	54939	\N	54.570306000000002	Республика Мордовия, Ельниковский муниципальный район, Новодевиченское сельское поселение, с.Новодевичье, Центральная, 98		0101000020E6100000AB251DE560FC4540365B79C9FF484B40
54759	7	63	466	3723	54987	\N	54.635621	Республика Мордовия, Ельниковский муниципальный район, Надеждинское сельское поселение, с.Надеждино, М.Ларина, 48		0101000020E6100000EE5BAD13970946404ED367075C514B40
54752	7	63	466	3340	54933	\N	54.682622000000002	Республика Мордовия, Ельниковский муниципальный район, Мордовско-Коринское сельское поселение, с.Мордовское Корино, Центральная, 38		0101000020E61000003B35971B0CD34540DBC35E2860574B40
54762	7	63	466	3852	54988	\N	54.510840000000002	Республика Мордовия, Ельниковский муниципальный район, Мордовско-Маскинское сельское поселение, с.Мордовско-Маскинские Выселки, Маскинская, 81		0101000020E6100000D3C08F6AD8F945408CBE823463414B40
54761	7	63	466	3824	54937	\N	54.534585	Республика Мордовия, Ельниковский муниципальный район, Каньгушанское сельское поселение, с.Каньгуши, Ленина, 10А		0101000020E6100000D9976C3CD8E4454051F701486D444B40
54746	7	63	466	2864	54379	\N	54.622132000000001	Республика Мордовия, Ельниковский муниципальный район, Ельниковское сельское поселение, с.Ельники, пл. 1Мая, д.6		0101000020E61000009D9B36E334EE4540C5E57805A24F4B40
54747	7	63	466	2864	54332	\N	54.622132000000001	Республика Мордовия, Ельниковский муниципальный район, Ельниковское сельское поселение, с.Ельники, Садовая, д.43		0101000020E61000009D9B36E334EE4540C5E57805A24F4B40
54744	7	63	466	2864	54332	\N	54.622132000000001	Республика Мордовия, Ельниковский муниципальный район, Ельниковское сельское поселение, с.Ельники, Садовая, 2		0101000020E61000009D9B36E334EE4540C5E57805A24F4B40
54075	7	62	\N	1218	62246	\N	56.636381999999998	Республике Марий Эл»,Республика Марий Эл,  г.Йошкар-Ола, ул.Соловьева, 3		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54745	7	63	466	2864	54531	\N	54.622132000000001	Республика Мордовия, Ельниковский муниципальный район, Ельниковское сельское поселение, с.Ельники, Ленина, 23		0101000020E61000009D9B36E334EE4540C5E57805A24F4B40
54754	7	63	466	3449	54934	\N	54.632249000000002	Республика Мордовия, Ельниковский муниципальный район, Большемордовско-Пошатское сельское поселение, д.Вачеевка, Мира, 3		0101000020E61000006C5F402FDCD94540E0F60489ED504B40
54749	7	63	466	3189	54828	\N	54.684942999999997	Республика Мордовия, Ельниковский муниципальный район, Большеуркатское сельское поселение, с.Большой Уркат, Советская, 2		0101000020E61000002786E464E2EC4540E34F5436AC574B40
54753	7	63	466	3414	54738	\N	54.659751	Республика Мордовия, Ельниковский муниципальный район, Большемордовско-Пошатское сельское поселение, с.Большие Мордовские Пошаты, Школьная, 1		0101000020E6100000A2B8E34D7ED945406C4084B872544B40
54760	7	63	466	3750	54936	\N	54.622616999999998	Республика Мордовия, Ельниковский муниципальный район, Надеждинское сельское поселение, д.Алексеевка, Центральная, 24		0101000020E6100000E8F86871C61246408177F2E9B14F4B40
54748	7	63	466	3103	54985	\N	54.637022000000002	Республика Мордовия, Ельниковский муниципальный район, Акчеевское сельское поселение, с.Акчеево, Молодежная, 4		0101000020E610000066D828EB37DF4540906AD8EF89514B40
54741	7	63	321	2705	54986	\N	54.463723000000002	с.Чиндяново, Советская, д.18		0101000020E6100000CD1E68058632474096B377465B3B4B40
54740	7	63	321	2633	54983	\N	54.365081000000004	с.Чеберчино, Большая, 23Б		0101000020E6100000959F54FB743C47400CB265F9BA2E4B40
54739	7	63	321	2597	54630	\N	54.3740240171539	с.Пуркаево, Жадейкина, д.1	Россия, республика Мордовия, Дубенский район, село Пуркаево	0101000020E6100000126745D444514740A5F5B704E02F4B40
54737	7	63	321	2406	54930	\N	54.467573999999999	с.Поводимово, Школьная, д.1		0101000020E61000008DB7955E9B274740DE3AFF76D93B4B40
54736	7	63	321	2406	54605	\N	54.467573999999999	с.Поводимово, Школьная, д.2		0101000020E61000008DB7955E9B274740DE3AFF76D93B4B40
54732	7	63	321	49483	54827	\N	54.353008000000003	с.Неклюдово, Богдановка, д.11		0101000020E61000007C48F8DEDF104740FA9CBB5D2F2D4B40
54733	7	63	321	2251	54981	\N	54.402717000000003	с.Морга, Московская, д.30		0101000020E610000033315D88D539474089450C3B8C334B40
54731	7	63	321	2148	54733	\N	54.366695999999997	с. Ломаты, Семипалаты, д.1		0101000020E610000069520ABABD10474079C9FFE4EF2E4B40
54730	7	63	321	49459	54927	\N	54.364671000000001	с. Красино, Молодежная, д.1		0101000020E6100000840CE4D9E53747405A66118AAD2E4B40
54728	7	63	321	1940	54820	\N	54.338655000000003	с.Кайбичево, Ленина, д.85а		0101000020E61000001C9947FE602047403ED00A0C592B4B40
54722	7	63	321	32695	54563	\N	54.438836999999999	Республика Мордовия, Дубенский муниципальный район, Дубенское сельское поселение, Центральная, д.11		0101000020E6100000C767B27F9E2647402BA391CF2B384B40
54719	7	63	321	32695	54563	\N	54.438836999999999	Республика Мордовия, Дубенский муниципальный район, Березовское сельское поселение, Центральная, д.18	Россия, республика Мордовия, Дубенский район, село Дубенки	0101000020E6100000C767B27F9E2647402BA391CF2B384B40
54723	7	63	321	32695	54645	\N	54.442491979963201	Республика Мордовия, Дубенский муниципальный район, Дубенское сельское поселение, Луговая, д.5	Россия, республика Мордовия, Дубенский район, село Дубенки	0101000020E6100000A06F0B96EA264740EE5EEE93A3384B40
54724	7	63	321	32695	55088	\N	54.437889328414897	Республика Мордовия, Дубенский муниципальный район, Енгалычевское сельское поселение, Лесная, д.2	Россия, республика Мордовия, Дубенский район, село Дубенки	0101000020E610000060E811A3E72647409A232BBF0C384B40
54726	7	63	321	32695	55083	\N	54.437789265002401	Республика Мордовия, Дубенский муниципальный район, Кабаевское сельское поселение, Куйбышева, д.62	Россия, республика Мордовия, Дубенский район, село Дубенки	0101000020E610000016F88A6EBD26474037C64E7809384B40
54721	7	63	321	32695	54581	\N	54.440835616807099	Республика Мордовия, Дубенский муниципальный район, Дубенское сельское поселение, Денисова, д.7	Россия, республика Мордовия, Дубенский район, село Дубенки	0101000020E61000003E40F7E5CC264740217365506D384B40
54720	7	63	321	32695	54528	\N	54.438836999999999	Республика Мордовия, Дубенский муниципальный район, Дубенское сельское поселение, Бровцева, д.139		0101000020E6100000C767B27F9E2647402BA391CF2B384B40
54727	7	63	321	32695	55082	\N	54.4383896417947	Республика Мордовия, Дубенский муниципальный район, Кабаевское сельское поселение, Школьная, д.1	Россия, республика Мордовия, Дубенский район, село Дубенки	0101000020E6100000EE7BD45FAF2647405C72DC291D384B40
54718	7	63	321	62111	81157	\N	54.3875710388252	Республика Мордовия, Дубенский муниципальный район, Березовское сельское поселение, Центральная, д.27	Россия, республика Мордовия, Дубенский район, село Петровка	0101000020E61000001C5C3AE63C2F474063F030ED9B314B40
54738	7	63	321	49581	54829	\N	54.510626000000002	дер.Антоновка, Лесная, д.1		0101000020E61000008D2AC3B81B224740603E59315C414B40
95114	7	63	226	50005	54926	\N	55.036225999999999	Республика Мордовия, Большеигнатовский р-н, с. Чукалы, Кооперативная, 34		0101000020E6100000F03504C765C24640E8A1B60DA3844B40
53503	7	63	226	6949	54919	\N	54.962617999999999	с. Хухорево, Центральная, 4		0101000020E610000095D5743DD1EB46403D450E11377B4B40
54716	7	63	226	1261	54980	\N	55.036772999999997	с. Старые Селищи, Садовая, 14		0101000020E6100000AF06280D35BA46401A3048FAB4844B40
54712	7	63	226	1008	54729	\N	55.063282000000001	с. Старое Чамзино, Западная, 4а		0101000020E61000004833164D67CF46407636E49F19884B40
95113	7	63	226	50004	54982	\N	55.124490999999999	Республика Мордовия, Большеигнатовский р-н, с. Спасское, ул.Новая, д.1		0101000020E610000044A852B307D64640BBD23252EF8F4B40
53824	7	63	226	22597	55055	\N	54.961857999999999	с. Протасово, Ленина, 19	Россия, республика Мордовия, Большеигнатовский район, село Протасово	0101000020E610000050340F6091BF4640AFB2B6291E7B4B40
53686	7	63	226	15620	54823	\N	54.923366999999999	с. Новое Качаево, Гагарина, 27		0101000020E6100000AF5B04C6FACC4640529ACDE330764B40
54711	7	63	226	56580	54977	\N	54.890872999999999	с. Новая Александровка, Гагарина, 32	Россия, республика Мордовия, Большеигнатовский район, село Новая Александровка	0101000020E61000004CE3175E49BA4640D8F15F2008724B40
53615	7	63	226	12278	54710	\N	55.029353	с. Кучкаево, Ленина, 18		0101000020E6100000B859BC5818D846400E85CFD6C1834B40
95107	7	63	226	49603	54690	\N	54.985250999999998	Республика Мордовия, Большеигнатовский р-н, с. Красная Нива, Школьная, 2-а		0101000020E6100000A180ED60C4D64640F7AC6BB41C7E4B40
54666	7	63	226	58364	64826	\N	54.873096259241201	с. Козловка, ул. Советская, д.67	Россия, республика Мордовия, Большеигнатовский район, село Козловка	0101000020E6100000CCEB884336E646405B22179CC16F4B40
54858	7	63	226	47731	54766	\N	54.897494999999999	поселок Калыша, Школьная, 4		0101000020E61000002C67EF8CB6C0464069A9BC1DE1724B40
95106	7	63	226	2414	55049	\N	54.971578999999998	Республика Мордовия, Большеигнатовский р-н,  с. Вармазейка, Советская, 44		0101000020E6100000DAE55B1FD6C746407D3D5FB35C7C4B40
53405	7	63	226	1673	54401	\N	55.020347000000001	с. Большое Игнатово, Советская, 28		0101000020E61000004E0E9F7422C946402EC901BB9A824B40
54714	7	63	226	1132	54730	\N	55.109017999999999	с. Аржадеево, Центральная, 7		0101000020E6100000016BD5AE09CF46407156444DF48D4B40
54708	7	63	67	780	54604	\N	54.268239999999999	Республика Мордовия, Большеберезниковский муниципальный район, Шугуровское сельское поселение, с.Шугурово, Карла Маркса, 53		0101000020E6100000EBC9FCA36F0C474051BD35B055224B40
54707	7	63	67	739	54819	\N	54.278834000000003	Республика Мордовия, Большеберезниковский муниципальный район, Чернопромзинское сельское поселение, с.Черная Промза, Центральная, 51		0101000020E6100000147B681F2B204740A6811FD5B0234B40
95112	7	63	67	658	54924	\N	54.310882999999997	Республика Мордовия, Большеберезниковский район, Тазинское сельское поселение, с. Тазино, Ленина, д.10-а		0101000020E610000081936DE00E0A4740F1F09E03CB274B40
54700	7	63	67	280	54811	\N	54.154296000000002	Республика Мордовия, Большеберезниковский муниципальный район, Судосевское сельское поселение, с. Судосево, Школьная, 4		0101000020E6100000529D0E643DE74640AAF3A8F8BF134B40
95111	7	63	67	623	54732	\N	54.264507000000002	Республика Мордовия, Большеберезниковский район, Старонайманское сельское поселение, с.Старые Найманы, ул. О.Николаева, 68		0101000020E61000004EB6813B50F746401348895DDB214B40
54704	7	63	67	526	54817	\N	54.254035999999999	Республика Мордовия, Большеберезниковский муниципальный район, Симкинское сельское поселение, с. Симкино, Ленина, 13		0101000020E61000006DA983BC1E164740DA006C4084204B40
95110	7	63	67	507	54596	\N	54.231833000000002	Республика Мордовия, Большеберезниковский район, Русско-Найманское сельское поселение, с.Русские Найманы, ул.Центральная, 34		0101000020E61000002446CF2D74074740199128B4AC1D4B40
54689	7	63	67	56578	54951	\N	54.200285999999998	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, п. Присурский, Новосельская, 21-а		0101000020E6100000B3EE1F0BD1F946405FECBDF8A2194B40
54699	7	63	67	232	54727	\N	54.205067999999997	Республика Мордовия, Большеберезниковский муниципальный район, Починковское сельское поселение, с. Починки, Октябрьская, 1		0101000020E6100000564ACFF412ED464062BA10AB3F1A4B40
54698	7	63	67	144	54809	\N	54.093952999999999	Республика Мордовия, Большеберезниковский муниципальный район, Пермисское сельское поселение, с. Пермиси, Верхняя, 2		0101000020E610000093533BC3D4E84640382EE3A6060C4B40
54701	7	63	67	363	54922	\N	54.300187000000001	Республика Мордовия, Большеберезниковский муниципальный район, Паракинское сельское поселение, с. Паракино, Московская, 26		0101000020E6100000DD96C8056718474099D711876C264B40
54691	7	63	67	32255	54804	\N	54.146101999999999	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, с. Николаевка, Центральная, 72		0101000020E61000005C1E6B4606034740AAF06778B3124B40
54734	7	63	67	32255	81085	\N	54.144813528548397	с.Николаевка, Школьная, д.5	Россия, республика Мордовия, Большеберезниковский район, село Николаевка	0101000020E61000001689096AF80247406000E14389124B40
54697	7	63	67	82	54554	\N	54.134549999999997	Республика Мордовия, Большеберезниковский муниципальный район, Марьяновское сельское поселение, с.Марьяновка, Гагарина, 1		0101000020E6100000AF601BF164F54640A1D634EF38114B40
54690	7	63	67	32212	54725	\N	54.205126	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, д. Мариуполь, Советская, 152		0101000020E610000077F86BB246F9464097C79A91411A4B40
54696	7	63	67	32469	54979	\N	54.214804000000001	Республика Мордовия, Большеберезниковский муниципальный район, Косогорское сельское поселение, с. Косогоры, Ленина, 82		0101000020E6100000CAE2FE23D3E3464066868DB27E1B4B40
54695	7	63	67	56602	55081	\N	54.237219696819103	Республика Мордовия, Большеберезниковский муниципальный район, Елизаветинское сельское поселение с.Елизаветинка, Садовая, 2	Россия, республика Мордовия, Большеберезниковский район, село Елизаветинка	0101000020E6100000CB10C7BAB8F1464083FA96395D1E4B40
54694	7	63	67	32386	54807	\N	54.157138000000003	Республика Мордовия, Большеберезниковский муниципальный район, Гузынское сельское поселение, с. Дегилёвка, Советская, 1		0101000020E61000004968CBB914D74640BC7A15191D144B40
54693	7	63	67	32355	54726	\N	54.187865000000002	Республика Мордовия, Большеберезниковский муниципальный район, Гузынское сельское поселение, с.Гузынцы, Советская, 15		0101000020E61000002EA9DA6E82D946401288D7F50B184B40
54055	7	63	270	1137	54668	\N	54.586308930969402	пос. Атяшево, ул. Большевистская, д. 105	Россия, республика Мордовия, Атяшевский район, поселок Атяшево	0101000020E61000002A6F47382D0C4740DC2C5E2C0C4B4B40
54692	7	63	67	32316	55039	\N	54.14472	Республика Мордовия, Большеберезниковский муниципальный район, Судосевское сельское поселение, с. Гарт, Школьная, 9		0101000020E610000004013274ECD04640DF89592F86124B40
54702	7	63	67	408	54816	\N	54.328296999999999	Республика Мордовия, Большеберезниковский муниципальный район, Паракинское сельское поселение, с. Бузаево, Карла Маркса, 36		0101000020E6100000A52C431CEB144740FD2FD7A2052A4B40
54686	7	63	67	31954	54376	\N	54.174981000000002	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, с. Большие Березники, Ленина, 72		0101000020E610000083DF8618AFFB4640F03504C765164B40
54685	7	63	67	31954	54376	\N	54.174981000000002	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, с. Большие Березники, Ленина, 56		0101000020E610000083DF8618AFFB4640F03504C765164B40
54684	7	63	67	31954	54403	\N	54.174981000000002	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, с. Большие Березники, Карла Маркса, 19		0101000020E610000083DF8618AFFB4640F03504C765164B40
54687	7	63	67	31954	54601	\N	54.174981000000002	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, с. Большие Березники, Казанская, 21		0101000020E610000083DF8618AFFB4640F03504C765164B40
54688	7	63	67	31954	54803	\N	54.174981000000002	Республика Мордовия, Большеберезниковский муниципальный район, Большеберезниковское сельское поселение, с. Большие Березники, Дубенское шоссе, 1		0101000020E610000083DF8618AFFB4640F03504C765164B40
95109	7	63	270	31863	55138	\N	54.490737000000003	Республика Мордовия, Атяшевский р-н  п. Птицесовхоз «Сараст», ул. Лесная, д. 19	Россия, республика Мордовия, Атяшевский район, село Шейн-Майдан	0101000020E61000008F39CFD8970E4740F5F75278D03E4B40
54682	7	63	270	31863	54798	\N	54.490737000000003	с. Шейн Майдан, ул. Комсомольская, д.4а		0101000020E61000008F39CFD8970E4740F5F75278D03E4B40
54662	7	63	270	30894	54984	\N	54.720695626541897	с. Чукалы-на-Вежне, ул. Красная Слобода, д. 1	Россия, республика Мордовия, Атяшевский район, село Чукалы-на-Вежне	0101000020E61000002F3196E997E64640D32D3BC43F5C4B40
54670	7	63	270	48528	54797	\N	54.60125	с. Челпаново, ул. Центральная, д.5		0101000020E61000008A0629780AE74640295C8FC2F54C4B40
54659	7	63	270	48330	54792	\N	54.573745000000002	с. Тетюши, ул. Ленина, д.98		0101000020E61000001BF67B629D0447402C9FE57970494B40
54679	7	63	270	48676	54724	\N	54.581020000000002	с. Тарасово, ул. Красная, д.75		0101000020E61000000CB1FA230C1F4740352905DD5E4A4B40
54144	7	63	270	6041	54711	\N	54.625321999999997	с. Тазнеево, ул. Ленина, д.1а		0101000020E6100000ED461FF301E1464012BC218D0A504B40
54681	7	63	270	31808	54923	\N	54.685541999999998	с. Сосуновка, ул. Ленина, д.2а		0101000020E61000003B3AAE467611474068041BD7BF574B40
54677	7	63	270	31621	54751	\N	54.649844000000002	с. Селищи, ул. Ленинская, д.71		0101000020E6100000950C0055DC2047403CC093162E534B40
54675	7	63	270	31559	54920	\N	54.582344999999997	с. Сабанчеево, ул. Советская, д.10		0101000020E61000003B8F8AFF3B2447409BFEEC478A4A4B40
54674	7	63	270	31478	55038	\N	54.519438000000001	с. Русские Дубровки, ул. Советская, д.4		0101000020E6100000DD787764ACF446405B26C3F17C424B40
54673	7	63	270	48578	54796	\N	54.769461	с. Покровское, ул. Центральная, д.4		0101000020E6100000C153C8957AEA46401346B3B27D624B40
54667	7	63	270	31157	54722	\N	54.711264999999997	с. Пилесево, ул. М.Горького, д.77		0101000020E6100000E1D39CBCC8F846400CE544BB0A5B4B40
54663	7	63	270	56570	54812	\N	54.706802562692999	с. Низовка, ул. Первомайская, д.28	Россия, республика Мордовия, Атяшевский район, село Низовка	0101000020E6100000520ABABDA4DF46407BDB4C85785A4B40
54672	7	63	270	31396	54799	\N	54.674835000000002	с. Наборные Сыреси, ул. Центральная, д.1		0101000020E61000008063CF9ECBEE46401C9947FE60564B40
54396	7	63	270	18136	54712	\N	54.569575	с. Мордовские Сыреси, ул. Октябрьская, д.105		0101000020E610000003B34291EE39474042CF66D5E7484B40
54676	7	63	270	31601	54723	\N	54.585695000000001	д. Мордовские Дубровки, ул. Новая, д. 2а		0101000020E6100000A1815836732647402237C30DF84A4B40
54097	7	63	270	3548	54644	\N	54.64414	с. Лобаски, ул. Пушкина, д. 1а		0101000020E610000035EB8CEF8BDD4640D105F52D73524B40
54063	7	63	270	1587	54824	\N	54.551031000000002	с. Капасово, ул. Центральная, д.72		0101000020E6100000170E846401174740850A0E2F88464B40
55209	7	63	270	56573	54894	\N	54.783027703436503	село Знаменское, Центральная, 15	Россия, республика Мордовия, Атяшевский район, село Знаменское	0101000020E6100000FEBAD39D27EC464018EDF1423A644B40
54665	7	63	270	30989	54793	\N	54.649099	с. Дюрки, ул. Комсомольская, д.14А		0101000020E610000094145800532E4740E36E10AD15534B40
54664	7	63	270	30989	54793	\N	54.649099	с. Дюрки, ул. Комсомольская, д.50		0101000020E610000094145800532E4740E36E10AD15534B40
54660	7	63	270	30792	54791	\N	54.609448	с. Вечерлей, ул. Куйбышева, д.9		0101000020E61000002AFEEF880AFB46406A4E5E64024E4B40
54658	7	63	270	30709	54550	\N	54.564011000000001	с. Большие Манадыши, ул. Молодежная, д.1		0101000020E610000082902C6002FF4640C9CA2F8331484B40
54655	7	63	270	30559	54600	\N	54.574919999999999	с. Батушево, ул. Ленина, д.76		0101000020E6100000EED0B018751147407DE882FA96494B40
54661	7	63	270	30865	54974	\N	54.594276999999998	с. Ахматово, ул. Ленина, д.95		0101000020E6100000E4DC26DC2BEF4640EBE1CB44114C4B40
54709	7	63	270	1137	54420	\N	54.588039602075803	с. Атяшево, Центральная, 12	Россия, республика Мордовия, Атяшевский район, поселок Атяшево	0101000020E6100000D00A0C59DD0C4740B35E0CE5444B4B40
53247	7	63	270	1137	54420	\N	54.577753000000001	пос. Атяшево, ул. Центральная, д. 34		0101000020E61000003C4D66BCAD0C47403C1570CFF3494B40
54653	7	63	270	1137	54435	\N	54.5871065131481	Республика Мордовия, Атяшевский муниципальный район, городское поселение Атяшево, Советский переулок, 4	Россия, республика Мордовия, Атяшевский район, поселок Атяшево	0101000020E610000028452BF7020D474058207A52264B4B40
53305	7	63	270	1137	54417	\N	54.577753000000001	пос. Атяшево, Микрорайон-2, 6а		0101000020E61000003C4D66BCAD0C47403C1570CFF3494B40
54145	7	62	\N	1218	62227	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Строителей, д.25		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54657	7	63	270	56569	54794	\N	54.655470018579997	с. Андреевка, ул. Ленина, д.53	Россия, республика Мордовия, Атяшевский район, село Андреевка	0101000020E6100000726F7EC344FF46402BC1E270E6534B40
54656	7	63	270	30604	54628	\N	54.632176000000001	с. Алово, ул. Школьная, д.6		0101000020E6100000D4484BE5ED38474076A8A624EB504B40
54678	7	63	270	56601	55080	\N	54.6371078689493	с. Алашеевка, ул. Новая, д.4	Россия, республика Мордовия, Атяшевский район, село Алашевка	0101000020E6100000473A03232F1D47408E0244C18C514B40
54640	7	63	1801	56599	55074	\N	54.237201039127498	с.Большой Шуструй, Центральная, 30	Россия, республика Мордовия, Атюрьевский район, село Шуструй	0101000020E6100000AB949EE925B045400CCA349A5C1E4B40
54639	7	63	1801	47948	54717	\N	54.308791999999997	д.Чудинка, Центральная, 18а		0101000020E6100000C5E74EB0FF9245401AA20A7F86274B40
54641	7	63	1801	56584	55004	\N	54.227032999999999	с.Усть-Рахмановка, Центральная, 62	Россия, республика Мордовия, Атюрьевский район, село Усть-Рахмановка	0101000020E6100000D93D7958A8B945406F0ED76A0F1D4B40
54552	7	63	1801	46193	54781	\N	54.393741546930201	с.Стрельниково, Школьная, 1	Россия, республика Мордовия, Атюрьевский район, село Стрельниково	0101000020E61000006E693524EE9F4540E4874A2366324B40
54637	7	63	1801	29674	54976	\N	54.343310000000002	д.Русская Велязьма, Мелиораторов, 8		0101000020E61000006B44300E2EAB4540E4310395F12B4B40
54567	7	63	1801	26468	54675	\N	54.415711999999999	д.Пичеполонга, Школьная, 18		0101000020E6100000B69F8CF1619C45400247020D36354B40
54647	7	63	1801	48089	54825	\N	54.309505999999999	с.Оброчное, Заречная, 1		0101000020E6100000C806D2C5A6BB454038F581E49D274B40
54650	7	63	1801	30276	54907	\N	54.399436000000001	с.Новочадово, Школьная, 82а		0101000020E6100000ED832C0B26AA45402B6C06B820334B40
54651	7	63	1801	62027	80936	\N	54.407432	д.Новая Нярьга, Новая, 6	Россия, республика Мордовия, Атюрьевский район, село Новая Карьга	0101000020E61000002FF834272FB0454004AC55BB26344B40
54648	7	63	1801	30187	54687	\N	54.459812999999997	с.Мордовская Козловка, Центральная, 45		0101000020E610000086747808E3A7454048A30227DB3A4B40
54646	7	63	1801	30117	54702	\N	54.325656000000002	с.Курташки, Центральная, 60а		0101000020E61000005B608F8994B8454083DF8618AF294B40
54632	7	63	1801	29422	55056	\N	54.432395542393401	д.Клопинка, Лесная, 54		0101000020E61000005DC30C8D27A44540EA758BC058374B40
54645	7	63	1801	30068	54918	\N	54.377223000000001	с.Кишалы, Нижняя, 93а		0101000020E610000030682101A39945404626E0D748304B40
54668	7	63	1801	61822	79737	\N	54.286382615256898	с. Каменка, ул. Молодежная, д.1	Россия, республика Мордовия, Атюрьевский район, село Каменка	0101000020E61000008A7615527EA84540B090B932A8244B40
54652	7	63	1801	30369	55065	\N	54.344921999999997	д.Духонькино, Школьная, 94	Россия, республика Мордовия, Атюрьевский район, село Духонькино	0101000020E610000004E621533EB24540E0D57267262C4B40
54643	7	63	1801	29971	54790	\N	54.228732999999998	с.Дмитриев Усад, Центральная, 107		0101000020E6100000B37DC85BAEA445400B42791F471D4B40
54642	7	63	1801	29909	54721	\N	54.255535000000002	с.Вольно-Никольское, Центральная, 23		0101000020E6100000DE3EABCC94BE4540DFFDF15EB5204B40
54649	7	63	1801	61823	79738	\N	54.486753	д.Барашево, Школьная, 17	Россия, республика Мордовия, Атюрьевский район, село Барашево	0101000020E6100000B24AE9995EA245406D1D1CEC4D3E4B40
54644	7	63	1801	61823	79741	\N	54.486753	с.Каменка, Молодежная, 3	Россия, республика Мордовия, Атюрьевский район, село Барашево	0101000020E6100000B24AE9995EA245406D1D1CEC4D3E4B40
54636	7	63	1801	29552	54333	\N	54.324219818697102	с.Атюрьево, Школьная, 1	Россия, республика Мордовия, Атюрьевский район, село Атюрьево	0101000020E6100000963FDF162CAB4540C45A7C0A80294B40
54635	7	63	1801	29552	54335	\N	54.323901999999997	с.Атюрьево, Центральная, 8		0101000020E61000005D52B5DD04AB4540F38DE89E75294B40
54634	7	63	1801	29552	54405	\N	54.323901999999997	с.Атюрьево, Ленина, 1		0101000020E61000005D52B5DD04AB4540F38DE89E75294B40
54638	7	63	1801	47931	54719	\N	54.337867000000003	с.Арга, Школьная, 1		0101000020E61000007C293C6876914540E6B2D1393F2B4B40
54633	7	63	1824	29513	54564	\N	54.715634000000001	Республика Мордовия, Ардатовский муниципальный район, Чукальское сельское поселение, с.Чукалы, Полевая, 1-А		0101000020E6100000CF49EF1B5F254740EDF318E5995B4B40
54631	7	63	1824	29418	54603	\N	55.029786000000001	Республика Мордовия, Ардатовский муниципальный район, Урусовское сельское поселение, с.Урусово, Ленина, 93		0101000020E6100000457F68E6C921474078F01307D0834B40
54629	7	63	1824	29320	54971	\N	54.809458999999997	Республика Мордовия, Ардатовский муниципальный район, Турдаковское сельское поселение, с.Турдаково, Центральная, 14		0101000020E610000009C4EBFA05194740F7393E5A9C674B40
54598	7	63	1824	56535	54602	\N	54.837731368816598	Республика Мордовия, Ардатовский муниципальный район, Тургеневское городское поселение, Ленинская, 8-А	Россия, республика Мордовия, Ардатовский район, поселок Тургенево	0101000020E610000003EE79FEB427474035ECF7C43A6B4B40
54597	7	63	1824	56535	54602	\N	54.840109212132802	Республика Мордовия, Ардатовский муниципальный район, Тургеневское городское поселение, Ленинская, 72	Россия, республика Мордовия, Ардатовский район, поселок Тургенево	0101000020E6100000D7DF12807F284740A20914B1886B4B40
54600	7	63	1824	56535	54454	\N	54.8413971518411	Республика Мордовия, Ардатовский муниципальный район, Тургеневское городское поселение, Заводская, 38	Россия, республика Мордовия, Ардатовский район, поселок Тургенево	0101000020E6100000ADA1D45E44294740ECF99AE5B26B4B40
54599	7	63	1824	56535	54433	\N	54.841557947905102	Республика Мордовия, Ардатовский муниципальный район, Тургеневское городское поселение, Заводская, 34	Россия, республика Мордовия, Ардатовский район, поселок Тургенево	0101000020E61000004A61DEE34C294740F5D72B2CB86B4B40
54628	7	63	1824	29266	54972	\N	54.995652999999997	Республика Мордовия, Ардатовский муниципальный район, Староардатовское сельское поселение, с.Старое Ардатово, Советская, 58		0101000020E61000008CD82780621A47400795B88E717F4B40
54142	7	62	\N	1218	62227	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Строителей, д. 13А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54618	7	63	1824	28827	54713	\N	54.799475000000001	Республика Мордовия, Ардатовский муниципальный район, Луньгинско-Майданское сельское поселение, с.Спасские Мурзы, Набережная, 50		0101000020E610000013656F29E7F346401C7C613255664B40
54627	7	63	1824	29208	54718	\N	54.975997	Республика Мордовия, Ардатовский муниципальный район, Солдатское сельское поселение, с.Солдатское, Центральная, 50		0101000020E61000005E11FC6F25F946403FFF3D78ED7C4B40
54626	7	63	1824	29178	54970	\N	54.984527	Республика Мордовия, Ардатовский муниципальный район, Силинское сельское поселение, с.Силино, Садовая, 28		0101000020E61000008177F2E9B1034740B68311FB047E4B40
54624	7	63	1824	29111	54551	\N	54.812966000000003	Республика Мордовия, Ардатовский муниципальный район, Редкодубское сельское поселение, с.Редкодубье, Гагарина, 66		0101000020E6100000F27B9BFEEC154740466117450F684B40
54610	7	63	1824	28467	54915	\N	54.763773	Республика Мордовия, Ардатовский муниципальный район, Кечушевское сельское поселение, с.Полое, Церковная, 1-А		0101000020E610000070D1C952EB134740AE484C50C3614B40
54623	7	63	1824	29042	54715	\N	54.654516000000001	Республика Мордовия, Ардатовский муниципальный район, Пиксясинское сельское поселение, с.Пиксяси, Молодежная, 28		0101000020E61000002B4EB51666274740B85A272EC7534B40
54622	7	63	1824	29019	54626	\N	54.904408109875902	Республика Мордовия, Ардатовский муниципальный район, Октябрьское сельское поселение, п.Октябрьский, Юбилейная, 13	Россия, республика Мордовия, Ардатовский район, село Октябрьский	0101000020E6100000473CD9CD8C1C4740D11E2FA4C3734B40
54621	7	63	1824	28982	54627	\N	54.758127000000002	Республика Мордовия, Ардатовский муниципальный район, Низовское сельское поселение, с.Низовка, Центральная, 1		0101000020E61000001E4FCB0F5C274740789B374E0A614B40
54620	7	63	1824	28915	54714	\N	54.770493999999999	Республика Мордовия, Ардатовский муниципальный район, Манадышское 2 сельское поселение,с.Манадыши-2, Центральная, 39		0101000020E61000001A6D5512D9FD4640D2E1218C9F624B40
54619	7	63	1824	28882	54786	\N	54.946348	Республика Мордовия, Ардатовский муниципальный район, Манадышское 1 сельское поселение, с.Манадыши-1, Центральная, 58-А		0101000020E6100000A2B8E34D7EFF4640485167EE21794B40
54613	7	63	1824	28573	54783	\N	55.011732000000002	Республика Мордовия, Ардатовский муниципальный район, Куракинское сельское поселение, с.Малое Кузьмино, Речная, 4		0101000020E61000000BB3D0CE691047408928266F80814B40
54617	7	63	1824	56561	54720	\N	54.815529925885301	Республика Мордовия, Ардатовский муниципальный район, Луньгинско-Майданское сельское поселение, с.Лунньгинский Майдан, Карла Маркса, 22	Россия, республика Мордовия, Ардатовский район, село Луньгинский Майдан	0101000020E6100000D540F33977E7464015747B4963684B40
54616	7	63	1824	28724	54784	\N	54.789945000000003	Республика Мордовия, Ардатовский муниципальный район, Луньгинское сельское поселение, с.Луньга, Центральная, 53		0101000020E6100000441669E21DFA4640C251F2EA1C654B40
54615	7	63	1824	28665	54788	\N	54.822733999999997	Республика Мордовия, Ардатовский муниципальный район, Лесозаводское сельское поселение, п.Лесозавод, Заводская, 15		0101000020E61000008AAF7614E702474054A703594F694B40
95108	7	63	1824	28633	54520	\N	54.731482	Республика Мордовия, Ардатовский район, Кученяевское сельское поселение, с.Кученяево, ул.Полевая, д.5		0101000020E61000008A93FB1D8A3247406CCEC133A15D4B40
54611	7	63	1824	28487	54780	\N	54.958300999999999	Республика Мордовия, Ардатовский муниципальный район, Куракинское сельское поселение, с.Куракино, Центральная, 73-А		0101000020E610000043588D25AC114740AF5C6F9BA97A4B40
54608	7	63	1824	28362	54969	\N	54.740028000000002	Республика Мордовия, Ардатовский муниципальный район, Кечушевское сельское поселение, с.Кечушево, Ларина, 1-А		0101000020E6100000FC34EECD6F0E4740E90FCD3CB95E4B40
54606	7	63	1824	28274	54877	\N	54.699696000000003	Республика Мордовия, Ардатовский муниципальный район, Кельвядинское сельское поселение, с.Кельвядни, Одыре, 45		0101000020E6100000344A97FE252B47402E9276A38F594B40
54605	7	63	1824	28234	55037	\N	54.781519000000003	Республика Мордовия, Ардатовский муниципальный район, Каласевское сельское поселение, с.Каласево, Овражная, 18		0101000020E610000032AA0CE36E044740F01989D008644B40
54604	7	63	1824	28170	54699	\N	54.719507999999998	Республика Мордовия, Ардатовский муниципальный район, Жаренское сельское поселение, с.Жаренки, Колхозная, 16-А		0101000020E610000021E4BCFF8F1F4740ED9A90D6185C4B40
54603	7	63	1824	28147	54681	\N	55.032680999999997	Республика Мордовия, Ардатовский муниципальный район, Жабинское сельское поселение, с.Жабино, Верхняя, 197		0101000020E61000004FE78A52421C4740AC1919E42E844B40
54612	7	63	1824	28547	54782	\N	54.951514000000003	Республика Мордовия, Ардатовский муниципальный район, Куракинское сельское поселение, с.Большое Кузьмино, Газовиков, 42		0101000020E610000093C5FD47A60B4740D4D7F335CB794B40
54625	7	63	1824	29137	54785	\N	54.845995000000002	Республика Мордовия, Ардатовский муниципальный район, Редкодубское сельское поселение, с.Большие Поляны, Ленинская, 47		0101000020E61000005089EB18570E47402ECA6C90496C4B40
54609	7	63	1824	28400	54914	\N	54.751995999999998	Республика Мордовия, Ардатовский муниципальный район, Кечушевское сельское поселение, с.Безводное, Центральная, 27		0101000020E61000005EA10F96B1094740855CA96741604B40
54602	7	63	1824	28087	54404	\N	54.836407000000001	Республика Мордовия, Ардатовский муниципальный район, Баевское сельское поселение, с.Баево, Советская, 7-б	Россия, республика Мордовия, Ардатовский район, село Баево	0101000020E6100000A5660FB4022F47409F9273620F6B4B40
54601	7	63	1824	56555	54677	\N	54.761367522787303	Республика Мордовия, Ардатовский муниципальный район, Ардатовское сельское поселение,п. Станция Ардатов, Центральная, 9	Россия, республика Мордовия, Ардатовский район, село Ардатов	0101000020E6100000A14D0E9F74224740471CB28174614B40
54593	7	63	1824	32696	54450	\N	54.844567289077297	Республика Мордовия, Ардатовский муниципальный район, городское поселение Ардатов, Полевая, 49	Россия, республика Мордовия, Ардатовский район, Ардатов	0101000020E610000012DDB3AED11E4740F2237EC51A6C4B40
54594	7	63	1824	32696	54511	\N	54.841694362833799	Республика Мордовия, Ардатовский муниципальный район, городское поселение Ардатов, Луначарского, 10	Россия, республика Мордовия, Ардатовский район, Ардатов	0101000020E610000029266F80991D4740A59E05A1BC6B4B40
54595	7	63	1824	32696	81155	\N	54.847364073476101	Республика Мордовия, Ардатовский муниципальный район, городское поселение Ардатов, Л.Толстого, 2/2	Россия, республика Мордовия, Ардатовский район, Ардатов	0101000020E6100000522635B4011E474064E76D6C766C4B40
54592	7	63	1824	32696	38834	\N	54.850213476402899	Республика Мордовия, Ардатовский муниципальный район, городское поселение Ардатов, Карла Маркса, 138	Россия, республика Мордовия, Ардатовский район, Ардатов	0101000020E6100000D333BDC4581E474028D192C7D36C4B40
54440	7	63	1824	28303	54529	\N	54.698759589532003	с. Андреевка, Первомайская, 89	Россия, республика Мордовия, Ардатовский район, село Андреевка	0101000020E6100000C4060B276932474061E0B9F770594B40
54607	7	63	1824	28303	54965	\N	54.698842999999997	Республика Мордовия, Ардатовский муниципальный район, Кельвядинское сельское поселение, с.Андреевка, Колхозная, 1		0101000020E610000072A609DB4F324740EE04FBAF73594B40
54186	7	62	\N	7823	62235	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, бульвар Космонавтов, д. 7		0101000020E61000003D61890794474740F52C08E57D2A4C40
54185	7	62	\N	7823	62235	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, бульвар Космонавтов, д. 2		0101000020E61000003D61890794474740F52C08E57D2A4C40
54187	7	62	\N	7823	63189	\N	56.336258219370599	Республика Марий Эл, город Козьмодемьянск, ул. Юбилейная, д. 11-А	Россия, республика Марий Эл, Козьмодемьянск	0101000020E610000098689082A74847405A828C800A2B4C40
54189	7	62	\N	7823	62949	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Чернышевского, д. 37		0101000020E61000003D61890794474740F52C08E57D2A4C40
54192	7	62	\N	7823	62183	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Советская, д. 35		0101000020E61000003D61890794474740F52C08E57D2A4C40
54194	7	62	\N	7823	62266	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Свободы, д. 1-А		0101000020E61000003D61890794474740F52C08E57D2A4C40
54190	7	62	\N	7823	63091	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Свердлова, д. 15		0101000020E61000003D61890794474740F52C08E57D2A4C40
54193	7	62	\N	7823	62268	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Промышленная, д. 52		0101000020E61000003D61890794474740F52C08E57D2A4C40
54188	7	62	\N	7823	62981	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Комсомольская, д. 25		0101000020E61000003D61890794474740F52C08E57D2A4C40
54184	7	62	\N	7823	62234	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Квартал маслозавода, д. 2		0101000020E61000003D61890794474740F52C08E57D2A4C40
54195	7	62	\N	7823	63034	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. Гагарина, д. 56-В		0101000020E61000003D61890794474740F52C08E57D2A4C40
54191	7	62	\N	7823	62305	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. 8 Марта, д. 15		0101000020E61000003D61890794474740F52C08E57D2A4C40
54181	7	62	\N	7823	62265	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. 3-ий микрорайон, д. 1		0101000020E61000003D61890794474740F52C08E57D2A4C40
54183	7	62	\N	7823	62155	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. 2-ой микрорайон, д. 5		0101000020E61000003D61890794474740F52C08E57D2A4C40
54182	7	62	\N	7823	62155	\N	56.331966999999999	Республика Марий Эл, город Козьмодемьянск, ул. 2-ой микрорайон, д. 28		0101000020E61000003D61890794474740F52C08E57D2A4C40
54126	7	62	\N	1218	\N	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Осипенко, д. 46	Россия, республика Марий Эл, Йошкар-Ола	0101000020E6100000628731E9EFEF4740ACE122F774514C40
54072	7	62	\N	1218	62162	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, пр. Гагарина, д. 8		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54056	7	62	\N	1218	62159	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, пл. Ленина, д. 3		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54077	7	62	\N	1218	62250	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, пер. Голикова, д. 4А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54076	7	62	\N	1218	62298	\N	56.636381999999998	г.Йошкар-Олы», 1 блок,Республика Марий Эл, г.Йошкар-Ола, пер.Голикова, 4А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54078	7	62	\N	1218	62249	\N	56.636381999999998	Республика Марий Эл, г.Йошкар-Ола, бул. Эшкинина, 18		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54087	7	62	\N	1218	62166	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, бул. Чавайна, д. 11		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54118	7	62	\N	1218	62224	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Я.Эшпая, д. 103		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54112	7	62	\N	1218	62224	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Я.Эшпая, д. 156		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54136	7	62	\N	1218	62175	\N	56.636381999999998	Республика Марий Эл, г.Йошкар-Ола, ул. Школьная, 19		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54071	7	62	\N	1218	62297	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Успенская, д. 15А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54150	7	62	\N	1218	62227	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Строителей, д. 62		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54133	7	62	\N	1218	62301	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Подольских курсантов, д. 8Б		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54084	7	62	\N	1218	62164	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Петрова, д. 16		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54080	7	62	\N	1218	62164	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Петрова, д. 15		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54114	7	62	\N	1218	62169	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Первомайская, д. 109		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54064	7	62	\N	1218	62169	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Первомайская, д. 89		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54074	7	62	\N	1218	62163	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Панфилова, 17		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54073	7	62	\N	1218	62163	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Панфилова, д. 17		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54115	7	62	\N	1218	62170	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Осипенко, д. 60		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54068	7	62	\N	1218	62161	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Орая, д. 51А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54093	7	62	\N	1218	62222	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Мичурина, д. 38		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54095	7	62	\N	1218	62168	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Мира, д. 25		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54094	7	62	\N	1218	62168	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Мира, д. 61		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54092	7	62	\N	1218	62168	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Мира, д. 91А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54089	7	62	\N	1218	62167	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Медицинская, д. 5		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54149	7	62	\N	1218	62174	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Машиностроителей, д. 44А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54132	7	62	\N	1218	62174	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Машиностроителей, д. 6Б		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54129	7	62	\N	1218	62174	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Машиностроителей, д. 22А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54110	7	62	\N	1218	62256	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Лобачевского, д. 1		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54109	7	62	\N	1218	62256	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Лобачевского, д. 12		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54111	7	62	\N	1218	62165	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, Ленинский проспект, д. 54		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54086	7	62	\N	1218	62165	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, Ленинский пр, д. 10А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54152	7	62	\N	1218	63018	\N	56.620462492727199	Республика Марий Эл, г. Йошкар-Ола, ул. Крылова, д. 47	Россия, республика Марий Эл, Йошкар-Ола	0101000020E6100000139ED0EB4FEC474094347F4C6B4F4C40
54117	7	62	\N	1218	62172	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Кремлевская, д. 44		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54116	7	62	\N	1218	62172	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Кремлевская, д. 32		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54062	7	62	\N	1218	62172	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Кремлевская, д. 22		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54060	7	62	\N	1218	62172	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Кремлевская, д. 4		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54143	7	62	\N	1218	62260	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Краснофлотская, д. 15		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54128	7	62	\N	1218	62226	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Красноармейская, д. 71		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54127	7	62	\N	1218	62226	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Красноармейская, д. 78		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54065	7	62	\N	1218	62226	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Красноармейская, д. 41		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54059	7	62	\N	1218	62217	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Комсомольская, д. 157		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54099	7	62	\N	1218	62252	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Кирпичная, д. 58		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54098	7	62	\N	1218	62252	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Кирпичная, д. 2А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54088	7	62	\N	1218	62259	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. К.Либкнехта, д. 54		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54140	7	62	\N	1218	62254	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Йывана Кырли, д. 19Б		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54101	7	62	\N	1218	62171	\N	56.646502515261602	Республика Марий Эл, г. Йошкар-Ола, с. Семеновка, ул. Интернатская, д. 7	Россия, республика Марий Эл, Йошкар-Ола городской округ, село Семеновка	0101000020E61000006F0F4240BEFC474009E23C9CC0524C40
54139	7	62	\N	1218	62291	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Зеленая, д. 1		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54100	7	62	\N	1218	62253	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Звездная, д. 12А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54108	7	62	\N	1218	62255	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Зарубина, д. 22		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54137	7	62	\N	1218	62257	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Дружбы, д. 2		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54135	7	62	\N	1218	62257	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Дружбы, д. 93		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54096	7	62	\N	1218	62150	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Героев Сталинградской Битвы, д. 35		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54066	7	62	\N	1218	62247	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Волкова, д. 110		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54085	7	62	\N	1218	62221	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Воинов-Интернационалистов, д. 25. (Адрес помещения для голосования: ул. Петрова, д. 16)		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54083	7	62	\N	1218	62221	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Воинов-Интернационалистов, д. 22. (Адрес помещения для голосования: ул. Воинов-Интернационалистов, д. 21)		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54082	7	62	\N	1218	62221	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Воинов-Интернационалистов, д. 22		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54081	7	62	\N	1218	62221	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Воинов-Интернационалистов, д. 28		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54119	7	62	\N	1218	62218	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Водопроводная, д. 85		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54069	7	62	\N	1218	62218	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Водопроводная, д. 41		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54141	7	62	\N	1218	62302	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Баумана, д. 20		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54134	7	62	\N	1218	62173	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Анциферова, д. 2А		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54131	7	62	\N	1218	62173	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Анциферова, д. 9		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54130	7	62	\N	1218	62173	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. Анциферова, д. 29		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54091	7	62	\N	1218	62251	\N	56.636381999999998	Республика Марий Эл, г. Йошкар-Ола, ул. 8 Марта, д. 19		0101000020E6100000628731E9EFEF4740ACE122F774514C40
54264	7	62	\N	57932	62307	\N	55.972195144322697	Республика Марий Эл, г.Звенигово, ул.Школьная, д.109	Россия, республика Марий Эл, Звениговский район, Звенигово	0101000020E610000045B75ED383024840D82AC1E270FC4B40
54262	7	62	\N	57932	62277	\N	55.973350290290398	Республика Марий Эл, г.Звенигово, ул.Чехова, д.38	Россия, республика Марий Эл, Звениговский район, Звенигово	0101000020E61000001EA33CF372024840E3C798BB96FC4B40
54265	7	62	\N	57932	62958	\N	55.958457000000003	Республика Марий Эл, г.Звенигово, ул.Пушкина, д.41		0101000020E6100000C5E2378595084840A7CF0EB8AEFA4B40
54261	7	62	\N	57932	62988	\N	55.960449194053197	Республика Марий Эл, г.Звенигово, ул.Ленина, д.1	Россия, республика Марий Эл, Звениговский район, Звенигово	0101000020E6100000FCFD62B664054840EA3C2AFEEFFA4B40
54176	7	62	\N	6770	62306	\N	55.867846806747998	Республика Марий Эл, г. Волжск, ул. Юбилейная, д. 10	Россия, республика Марий Эл, Волжск	0101000020E61000003A3FC571E02D48404277499C15EF4B40
54156	7	62	\N	6770	62303	\N	55.867702020189498	Республика Марий Эл, г. Волжск, ул. Щорса, д. 16	Россия, республика Марий Эл, Волжск	0101000020E610000089CF9D60FF2D48403F56F0DB10EF4B40
54170	7	62	\N	6770	62181	\N	55.867702020189498	Республика Марий Эл, г. Волжск, ул. Щербакова, д. 4	Россия, республика Марий Эл, Волжск	0101000020E6100000B3B3E89D0A2E48403F56F0DB10EF4B40
54172	7	62	\N	6770	62237	\N	55.868715514716399	Республика Марий Эл, г. Волжск, ул. Шестакова, д. 44	Россия, республика Марий Эл, Волжск	0101000020E6100000C66AF3FFAA2D484087C1FC1532EF4B40
54169	7	62	\N	6770	62237	\N	55.868377686158503	Республика Марий Эл, г. Волжск, ул. Шестакова, д. 8	Россия, республика Марий Эл, Волжск	0101000020E610000016FBCBEEC92D48406F48A30227EF4B40
54166	7	62	\N	6770	62272	\N	55.867798544622097	Республика Марий Эл, г. Волжск, ул. Учительская, д. 4	Россия, республика Марий Эл, Волжск	0101000020E61000005FEB5223F42D48403140A20914EF4B40
54157	7	62	\N	6770	62179	\N	55.867943330819202	Республика Марий Эл, г. Волжск, ул. Советская, д. 29 а	Россия, республика Марий Эл, Волжск	0101000020E6100000DAC70A7E1B2E484064E597C118EF4B40
54173	7	62	\N	6770	62240	\N	55.868184639943301	Республика Марий Эл, г. Волжск, ул. Прохорова, д. 120 а	Россия, республика Марий Эл, Волжск	0101000020E6100000F04E3E3DB62D48405AF0A2AF20EF4B40
54177	7	62	\N	6770	62945	\N	55.868602000000003	Республика Марий Эл, г. Волжск, ул. Помарское шоссе, д. 1		0101000020E610000081CEA44DD52D4840BF9EAF592EEF4B40
54171	7	62	\N	6770	62304	\N	55.867846806747998	Республика Марий Эл, г. Волжск, ул. Маяковского, д. 9	Россия, республика Марий Эл, Волжск	0101000020E610000038D73043E32D48404277499C15EF4B40
54174	7	62	\N	6770	62182	\N	55.868329424694998	Республика Марий Эл, г. Волжск, ул. Либкнехта, д. 128	Россия, республика Марий Эл, Волжск	0101000020E6100000642310AFEB2D48408E95986725EF4B40
54164	7	62	\N	6770	62229	\N	55.868602000000003	Республика Марий Эл, г. Волжск, ул. Ленина, д. 64		0101000020E610000081CEA44DD52D4840BF9EAF592EEF4B40
54162	7	62	\N	6770	62229	\N	55.8616989337186	Республика Марий Эл, г. Волжск, ул. Ленина, д. 39	Россия, республика Марий Эл, Волжск	0101000020E610000015E5D2F8852F48407AFF1F274CEE4B40
54160	7	62	\N	6770	62229	\N	55.868602000000003	Республика Марий Эл, г. Волжск, ул. Ленина, д. 33		0101000020E610000081CEA44DD52D4840BF9EAF592EEF4B40
54159	7	62	\N	6770	62229	\N	55.868602000000003	Республика Марий Эл, г. Волжск, ул. Ленина, д. 34		0101000020E610000081CEA44DD52D4840BF9EAF592EEF4B40
54158	7	62	\N	6770	62229	\N	55.868602000000003	Республика Марий Эл, г. Волжск, ул. Ленина, д. 37		0101000020E610000081CEA44DD52D4840BF9EAF592EEF4B40
54154	7	62	\N	6770	62177	\N	55.867895068813702	Республика Марий Эл, г. Волжск, ул. Кошкина, д. 10	Россия, республика Марий Эл, Волжск	0101000020E610000073486AA1642E484053AEF02E17EF4B40
54155	7	62	\N	6770	62178	\N	55.867636319339397	Республика Марий Эл, г. Волжск, ул. Коммунистическая, д. 1 а	Россия, республика Марий Эл, Волжск	0101000020E610000068774831402E4840876A4AB20EEF4B40
54167	7	62	\N	6770	62239	\N	55.868118939913003	Республика Марий Эл, г. Волжск, ул. Комарова, д. 24	Россия, республика Марий Эл, Волжск	0101000020E6100000DC0DA2B5A22D4840A304FD851EEF4B40
54163	7	62	\N	6770	62261	\N	55.868215463304999	Республика Марий Эл, г. Волжск, ул. Кирова, д. 5	Россия, республика Марий Эл, Волжск	0101000020E6100000CC26C0B0FC2D4840C5724BAB21EF4B40
54168	7	62	\N	6770	62152	\N	55.8672502185442	Республика Марий Эл, г. Волжск, ул. Дружбы, д. 2 б	Россия, республика Марий Эл, Волжск	0101000020E61000006B47718E3A2E48405EBA490C02EF4B40
54165	7	62	\N	6770	62152	\N	55.852545999999997	Республика Марий Эл, г. Волжск, ул. Дружбы, д. 16 а		0101000020E61000008EB0A888D3334840F52A323A20ED4B40
54161	7	62	\N	6770	62180	\N	55.868602000000003	Республика Марий Эл, г. Волжск, ул. Гагарина, д. 40		0101000020E610000081CEA44DD52D4840BF9EAF592EEF4B40
54175	7	62	\N	6770	62264	\N	55.868184639943301	Республика Марий Эл, г. Волжск, ул. Гаврилова, д. 7	Россия, республика Марий Эл, Волжск	0101000020E6100000376F9C14E62D48405AF0A2AF20EF4B40
54178	7	62	\N	6770	62233	\N	55.868602000000003	Республика Марий Эл, г. Волжск, ул. 107 бригады, д. 5		0101000020E610000081CEA44DD52D4840BF9EAF592EEF4B40
54571	7	62	1792	26701	63137	\N	56.514406000000001	Республика Марий Эл, Юринский район, пос. Юркино, ул.Юркинская, д.14		0101000020E61000009546CCECF31A4740DF6E490ED8414C40
54572	7	62	1792	26701	63138	\N	56.514406000000001	Республика Марий Эл, Юринский район, пос. Юркино, ул.Новая Стройка, д.30		0101000020E61000009546CCECF31A4740DF6E490ED8414C40
54561	7	62	1792	26130	62209	\N	56.294440999999999	"Республика Марий Эл, Юринский район, пос. Юрино, пер.Володарского, д.24""а"""		0101000020E610000050C24CDBBF244740FFCC203EB0254C40
54560	7	62	1792	26130	62216	\N	56.294440999999999	"Республика Марий Эл, Юринский район, пос. Юрино, ул.Центральный проспект, д.5""а"""		0101000020E610000050C24CDBBF244740FFCC203EB0254C40
54559	7	62	1792	26130	63025	\N	56.294440999999999	Республика Марий Эл, Юринский район, пос. Юрино, ул.Советская, д.30		0101000020E610000050C24CDBBF244740FFCC203EB0254C40
54563	7	62	1792	26300	63212	\N	56.333244999999998	Республика Марий Эл, Юринский район, дер. Суходол, ул.Лесная, д.23		0101000020E61000005B441493372447401B47ACC5A72A4C40
54566	7	62	1792	26463	63187	\N	56.278018000000003	Республика Марий Эл, Юринский район, дер. Починок, ул.Починок, д.76		0101000020E6100000868E1D54E20E474084D9041896234C40
54569	7	62	1792	26601	63059	\N	56.564107	Республика Марий Эл, Юринский район, село  Марьино, ул.Школьная, д.12		0101000020E61000002750C42286014740EB387EA834484C40
54570	7	62	1792	26610	63094	\N	56.523893325516099	Республика Марий Эл, Юринский район, дер. Красная Люнда, ул.Школьная, д.6	Россия, республика Марий Эл, Юринский район, село Красная Люнда	0101000020E61000007D91D096730547403ACD02ED0E434C40
54568	7	62	1792	26553	63215	\N	56.695829027562198	Республика Марий Эл, Юринский район, пос. Козиково, ул.Железнодорожная, д.3	Россия, республика Марий Эл, Юринский район, село Козиково	0101000020E61000000CAD4ECE50F84640E04DB7EC10594C40
54565	7	62	1792	58060	63084	\N	56.279266999999997	Республика Марий Эл, Юринский район, дер. Горный Шумец, ул.Горный Шумец, д.110	Россия, республика Марий Эл, Юринский район, село Горный Шимец	0101000020E610000037E15E99B71447400FED6305BF234C40
54564	7	62	1792	26329	63134	\N	56.518676999999997	Республика Марий Эл, Юринский район, село  Васильевское, ул.Школьная, д.259		0101000020E6100000963E74417DE74640FC17080264424C40
54562	7	62	1792	26246	63060	\N	56.301993000000003	Республика Марий Эл, Юринский район, дер. Быковка, ул.Центральная, д.157		0101000020E61000009DD5027B4C2447407B4FE5B4A7264C40
54558	7	62	1765	58086	63434	\N	56.603194344912502	Республика Марий Эл, Советский район, пос. Голубой, ул. Мира, д. 8	Россия, республика Марий Эл, Советский район	0101000020E61000009E40D829563B48405C920376354D4C40
54551	7	62	1765	25778	63004	\N	56.787858999999997	Республика Марий Эл, Советский район, дер. Шуарсола, ул. Речная, д. 120		0101000020E61000001092054CE0184840FC6D4F90D8644C40
54555	7	62	1765	25953	63099	\N	56.700844672861102	Республика Марий Эл, Советский район, с. Чкарино, ул. Центральная, д. 5	Россия, республика Марий Эл, Советский район, село Чкарино	0101000020E6100000C26A2C616D3848405648F949B5594C40
54541	7	62	1765	25303	62999	\N	56.747669000000002	Республика Марий Эл, Советский район, пос. Ургакш, ул. Новая, д. 2	Россия, республика Марий Эл, Советский район, село Ургакш	0101000020E6100000969350FA42364840D49D279EB35F4C40
54549	7	62	1765	25699	63002	\N	56.930694000000003	Республика Марий Эл, Советский район, дер. Средний Кадам, ул. Молодёжная, д. 38		0101000020E6100000B537F8C264324840AE4A22FB20774C40
54557	7	62	1765	26033	62205	\N	56.541359	Республика Марий Эл, Советский район, пос. Солнечный, ул. Солнечная, д. 1		0101000020E61000004DD9E90775334840983270404B454C40
54538	7	62	1765	25112	62290	\N	56.758057999999998	Республика Марий Эл, Советский район, пос. Советский, ул. Свободы, д. 15		0101000020E6100000DE770C8FFD3C48404F3C670B08614C40
54540	7	62	1765	25112	62944	\N	56.758670248985098	Республика Марий Эл, Советский район, пос. Советский, ул. Пушкина, д. 32 А	Россия, республика Марий Эл, Советский район, поселок Советский	0101000020E61000007782FDD7B93D4840693A3B191C614C40
54539	7	62	1765	25112	62214	\N	56.758057999999998	Республика Марий Эл, Советский район, пос. Советский, ул. Победы, д. 18 Б		0101000020E6100000DE770C8FFD3C48404F3C670B08614C40
54537	7	62	1765	25112	62213	\N	56.758057999999998	Республика Марий Эл, Советский район, пос. Советский, ул. Ломоносова, д. 8		0101000020E6100000DE770C8FFD3C48404F3C670B08614C40
54104	7	62	1765	57930	62223	\N	56.674335493015299	"Республика Марий Эл,  г.Йошкар-Ола,  с.Семеновка,  ул. Советская, 9"	Россия, республика Марий Эл, Советский район, село Семеновка	0101000020E6100000EBFEB1101D2A48402AC6F99B50564C40
54103	7	62	1765	57930	62223	\N	56.673446018187697	Республика Марий Эл, г. Йошкар-Ола, с. Семеновка, ул. Советская, д. 9	Россия, республика Марий Эл, Советский район, село Семеновка	0101000020E6100000C79C67EC4B2A48409ECF807A33564C40
54554	7	62	1765	25928	62204	\N	56.705198000000003	Республика Марий Эл, Советский район, с. Ронга, ул. Центральная, д. 2		0101000020E6100000B1DD3D40F7414840319A95ED435A4C40
54546	7	62	1765	25511	63024	\N	56.909348000000001	Республика Марий Эл, Советский район, с. Орша, ул. Советская, д. 28		0101000020E610000049BA66F2CD4048406D57E88365744C40
54553	7	62	1765	25879	62203	\N	56.657747000000001	Республика Марий Эл, Советский район, дер. Михайловка, ул. Зеленая, д. 4		0101000020E61000008F1B7E37DD2048406405BF0D31544C40
54544	7	62	1765	25410	63001	\N	56.875211999999998	Республика Марий Эл, Советский район, дер. Кукмарь, ул. Нижняя, д. 5		0101000020E6100000D1967329AE5648408B8862F206704C40
54548	7	62	1765	25639	63058	\N	56.848911000000001	Республика Марий Эл, Советский район, с. Кужмара, ул. Центральная, д. 3		0101000020E610000029965B5A0D2948407A1B9B1DA96C4C40
54547	7	62	1765	25597	63147	\N	56.822640999999997	Республика Марий Эл, Советский район, дер. Колянур, м-н Светлый, д. 10 А		0101000020E6100000A01518B2BA454840A3ACDF4C4C694C40
54550	7	62	1765	25705	63003	\N	56.816799000000003	Республика Марий Эл, Советский район, дер. Кельмаксола, ул. Ермакова, д. 22		0101000020E6100000774D486B0C224840E833A0DE8C684C40
54545	7	62	1765	25496	62295	\N	56.782223000000002	Республика Марий Эл, Советский район, с. Вятское, ул. Дружбы, д. 3		0101000020E61000008ACDC7B5A1424840EA961DE21F644C40
54543	7	62	1765	25401	63039	\N	56.775472000000001	Республика Марий Эл, Советский район, с. Верх-Ушнур, ул. Центральная, д. 10		0101000020E6100000CC5EB69DB65248405B7B9FAA42634C40
54556	7	62	1765	26013	\N	\N	56.673743999999999	Республика Марий Эл, Советский район, дер. Великополье, ул. Великополье, д. 43 А		0101000020E6100000C5E57805A23F484028F04E3E3D564C40
54542	7	62	1765	25311	62215	\N	56.747551000000001	Республика Марий Эл, Советский район, пос. Алексеевский, ул. Октябрьская, д. 1		0101000020E6100000A54BFF92542C4840CA8B4CC0AF5F4C40
54522	7	62	1730	24418	63089	\N	57.301389	Республика Марий Эл, Сернурский район, деревня Эшполдино, ул. Эшполдино, д.4		0101000020E61000001D007157AF924840E42F2DEA93A64C40
54520	7	62	1730	24279	63218	\N	57.253369999999997	Республика Марий Эл, Сернурский район, деревня Читово, ул. Читово, д. 87а		0101000020E6100000CC441152B7894840CDE49B6D6EA04C40
54532	7	62	1730	24889	62973	\N	56.904246000000001	Республика Марий Эл, Сернурский район, деревня Чендемерово, ул. Колхозная, д. 86		0101000020E6100000D23AAA9A208C4840F8C43A55BE734C40
54525	7	62	1730	24569	\N	\N	56.966918999999997	Республика Марий Эл, Сернурский район, деревня Чашкаял, ул. Чашкаял, д. 91		0101000020E6100000095053CBD6A24840C5707500C47B4C40
54513	7	62	1730	23975	63131	\N	56.872087999999998	Республика Марий Эл, Сернурский район, деревня Тамшинер, ул. Мира, д. 26а		0101000020E610000008E3A7716FA84840F59D5F94A06F4C40
54507	7	62	1730	23578	62210	\N	56.937747000000002	Республика Марий Эл, Сернурский район, пос. Сернур, ул. Микрорайон, д. 16		0101000020E610000003965CC5E29148400876FC1708784C40
54506	7	62	1730	23578	62201	\N	56.937747000000002	Республика Марий Эл, Сернурский район, пос. Сернур, ул. Комсомольская, д. 24		0101000020E610000003965CC5E29148400876FC1708784C40
54505	7	62	1730	23578	62201	\N	56.937747000000002	Республика Марий Эл, Сернурский район, пос. Сернур, ул. Комсомольская, д. 2		0101000020E610000003965CC5E29148400876FC1708784C40
54508	7	62	1730	23578	62202	\N	56.937747000000002	Республика Марий Эл, Сернурский район, пос. Сернур, ул. Коммунистическая, д. 78		0101000020E610000003965CC5E29148400876FC1708784C40
54509	7	62	1730	23578	62212	\N	56.937747000000002	Республика Марий Эл, Сернурский район, пос. Сернур, ул. Казанская, д. 11		0101000020E610000003965CC5E29148400876FC1708784C40
54523	7	62	1730	24475	63136	\N	57.220227999999999	Республика Марий Эл, Сернурский район, деревня Нижний Рушенер, ул. Нижний Рушенер, д. 5		0101000020E610000004AF963B338D4840EDD45C6E309C4C40
54510	7	62	1730	23814	63035	\N	56.889679999999998	Республика Марий Эл, Сернурский район,  деревня Нижний Кугенер, ул. Советская, д. 16		0101000020E6100000F8FD9B17279C4840E0F3C308E1714C40
54534	7	62	1730	24978	63184	\N	56.936655999999999	Республика Марий Эл, Сернурский район, деревня Мустаево, ул. Центральная, д. 15		0101000020E61000009CA73AE46682484014CD0358E4774C40
54528	7	62	1730	24726	62970	\N	57.039794999999998	Республика Марий Эл, Сернурский район, село Марисола, ул. Центральная, д. 21		0101000020E610000089450C3B8C8B4840ACC5A70018854C40
54530	7	62	1730	24810	63211	\N	57.033501999999999	Республика Марий Эл, Сернурский район, деревня Мари Кугунур, ул. Набережная, д.18		0101000020E61000005C74B2D47A814840E02C25CB49844C40
54535	7	62	1730	25041	\N	\N	56.959390999999997	Республика Марий Эл, Сернурский район, деревня Малый Шокшем, ул. Малый Шокшем, д. 41		0101000020E6100000707D586FD47C4840D2890453CD7A4C40
54515	7	62	1730	24067	63224	\N	57.020882999999998	Республика Марий Эл, Сернурский район,  деревня Лоскутово, ул. Лоскутово, д. 48		0101000020E61000003E3F8C101E9D48406C054D4BAC824C40
54526	7	62	1730	24588	63093	\N	56.990350999999997	Республика Марий Эл, Сернурский район, деревня Летник, ул. Летник, д. 4		0101000020E61000004E7D2079E7A44840CB4752D2C37E4C40
54512	7	62	1730	58053	63009	\N	56.875672371152703	Республика Марий Эл, Сернурский район, деревня Лажъял, ул. Молодежная, д. 14	Россия, республика Марий Эл, Сернурский район, село Лажьял	0101000020E61000002995F0845EA34840EF02250516704C40
54521	7	62	1730	24367	63182	\N	57.255133000000001	Республика Марий Эл, Сернурский район, деревня Купсола, ул. Купсола, д. 32		0101000020E6100000FDFA213658924840B090B932A8A04C40
54533	7	62	1730	24925	63183	\N	56.899890999999997	Республика Марий Эл, Сернурский район, деревня Куприяново, ул. Центральная, д. 2		0101000020E610000016359886E18748407C7BD7A02F734C40
54519	7	62	1730	58066	63123	\N	57.231560999999999	Республика Марий Эл, Сернурский район, село Кукнур, ул. Кооперативная, д. 5	Россия, республика Марий Эл, Сернурский район, село Кункур	0101000020E6100000B4588AE42B874840B80375CAA39D4C40
54527	7	62	1730	24676	63200	\N	56.936475000000002	Республика Марий Эл, Сернурский район, деревня Кочанур, ул. Кочанур, д. 58а		0101000020E6100000392BA226FA9C4840C442AD69DE774C40
54517	7	62	1730	24157	63023	\N	56.980890000000002	Республика Марий Эл, Сернурский район, деревня Калеево, ул. Новая, д. 5		0101000020E61000006CCB80B394C048409A7CB3CD8D7D4C40
54518	7	62	1730	24199	62293	\N	57.150373000000002	Республика Марий Эл, Сернурский район, село Казанское, ул. Коммунальная, д. 5а		0101000020E610000019E76F4221904840C899266C3F934C40
54529	7	62	1730	24752	63086	\N	57.054782000000003	Республика Марий Эл, Сернурский район, деревня Йошкар Памаш, ул. Йошкар Памаш, д. 22		0101000020E610000033E202D0288F48406A34B91803874C40
54516	7	62	1730	24079	63133	\N	56.966183000000001	Республика Марий Эл, Сернурский район, село Зашижемье, ул. Больничная, д.10		0101000020E61000003849F3C7B4B04840C07971E2AB7B4C40
54514	7	62	1730	23979	63033	\N	56.972380000000001	Республика Марий Эл, Сернурский район, деревня Дубники, ул. Дубники, д. 53		0101000020E6100000AD32535A7F8F48406AA4A5F2767C4C40
54536	7	62	1730	25046	63214	\N	56.861992000000001	Республика Марий Эл, Сернурский район, пос. Горняк, ул. Полевая, д. 4		0101000020E610000099D4D00660874840F2B4FCC0556E4C40
54524	7	62	1730	24484	62969	\N	56.937781000000001	Республика Марий Эл, Сернурский район, деревня Большой Сердеж, ул. Большой Сердеж, д. 44		0101000020E6100000020F0C207CA24840B4E7323509784C40
54531	7	62	1730	24840	63213	\N	57.009695000000001	Республика Марий Эл, Сернурский район, деревня Большие Ключи, ул. Шабалина, д. 10		0101000020E610000098A59D9ACB7F4840A5F78DAF3D814C40
54511	7	62	1730	23849	63186	\N	56.897938631932902	Республика Марий Эл, Сернурский район, деревня Большая Мушка, ул. Центральная, д. 23	Россия, республика Марий Эл, Сернурский район, село Большая Мушка	0101000020E6100000056A317898924840C76647AAEF724C40
54504	7	62	1707	23544	63132	\N	56.723061999999999	Республика Марий Эл, Параньгинский район, дер.Усола, ул.Коммунистическая, д.52		0101000020E6100000CA332F87DDBB48407C7DAD4B8D5C4C40
54502	7	62	1707	23413	63010	\N	56.885160999999997	Республика Марий Эл, Параньгинский район, дер.Русская Ляжмарь, ул.Молодежная, д.4		0101000020E61000008ACA863595BF4840EA58A5F44C714C40
54501	7	62	1707	23394	62983	\N	56.683539000000003	Республика Марий Эл, Параньгинский район, дер.Портянур, ул.Колхозная, д.27		0101000020E61000002AFF5A5EB9A248403145B9347E574C40
54495	7	62	1707	23128	63216	\N	56.878025000000001	Республика Марий Эл, Параньгинский район, дер.Помосъял, ул.Мира, д.29		0101000020E61000005BEA20AF07B3484003098A1F63704C40
54490	7	62	1707	22842	62200	\N	56.704189999999997	Республика Марий Эл, Параньгинский район, пос.Параньга, ул.Тукаевская, д.146		0101000020E6100000D2A92B9FE5B34840CA15DEE5225A4C40
54491	7	62	1707	22842	62288	\N	56.704189999999997	Республика Марий Эл, Параньгинский район, пос.Параньга, ул.Колхозная, д.21		0101000020E6100000D2A92B9FE5B34840CA15DEE5225A4C40
54489	7	62	1707	22842	62294	\N	56.704189999999997	Республика Марий Эл, Параньгинский район, пос.Параньга, ул.Гагарина, д.20		0101000020E6100000D2A92B9FE5B34840CA15DEE5225A4C40
54503	7	62	1707	23479	62984	\N	56.743637	Республика Марий Эл, Параньгинский район, дер.Олоры, ул.Гагарина, д.5		0101000020E610000043C70E2A71C748403B8C497F2F5F4C40
54499	7	62	1707	23285	63110	\N	56.742792999999999	Республика Марий Эл, Параньгинский район, дер.Мурзанаево, ул.Центральная, д.58		0101000020E61000007EFE7BF0DA9F48404F594DD7135F4C40
54493	7	62	1707	23036	63180	\N	56.771664211518498	Республика Марий Эл, Параньгинский район, дер.Куянково, ул.Советская, д.42	Россия, республика Марий Эл, Параньгинский район, село Куянково	0101000020E6100000172829B000BC484012C0CDE2C5624C40
54498	7	62	1707	23237	62967	\N	56.729985999999997	Республика Марий Эл, Параньгинский район, с.Куракино, ул.Новая, д.21		0101000020E610000001BEDBBC71A44840D844662E705D4C40
54500	7	62	1707	23337	63209	\N	56.691392753881203	Республика Марий Эл, Параньгинский район, дер.Ирнур, ул.Кооперативная, д.6	Россия, республика Марий Эл, Параньгинский район, село Ирнур	0101000020E610000062D8614CFAA5484077D7D9907F584C40
54497	7	62	1707	23197	62962	\N	56.792093999999999	Республика Марий Эл, Параньгинский район, дер.Ильпанур, ул.Мира, д.32		0101000020E610000062DBA2CC06B34840CDAD105663654C40
54496	7	62	1707	23173	63081	\N	56.574793999999997	Республика Марий Эл, Параньгинский район, с.Илеть, ул.Заречная, д.28		0101000020E61000006684B70721C04840F0F78BD992494C40
54494	7	62	1707	23050	62968	\N	56.855561000000002	Республика Марий Эл, Параньгинский район, с.Елеево, ул.Рабочая, д.4		0101000020E6100000C1FF56B263B54840D55DD905836D4C40
54492	7	62	1707	22976	63031	\N	56.775165999999999	Республика Марий Эл, Параньгинский район, дер.Алашайка, ул.Ленина, д.76		0101000020E6100000E3FC4D2844BE48404E7CB5A338634C40
54488	7	62	1677	22789	62971	\N	56.941468999999998	Республика Марий Эл, Оршанский район, село Шулка, ул. Микрорайон, д. 8	Россия, республика Марий Эл, Оршанский район, село Шулка	0101000020E6100000F2086EA46C1548405299620E82784C40
54486	7	62	1677	22710	63205	\N	56.902816000000001	Республика Марий Эл, Оршанский район, деревня Чирки, ул. Новая, д. 15б		0101000020E6100000A8C4758C2B1E48401C2785798F734C40
54485	7	62	1677	22670	63129	\N	56.870125000000002	Республика Марий Эл, Оршанский район, село Упша, ул. Первомайская, д. 2а		0101000020E6100000508C2C9963DD47404C378941606F4C40
54484	7	62	1677	22645	63178	\N	56.964598000000002	Республика Марий Эл, Оршанский район, село Табашино, ул. Школьная, д. 4а		0101000020E61000001F9F909DB7DB4740BDE47FF2777B4C40
54483	7	62	1677	22596	62979	\N	56.801862999999997	Республика Марий Эл, Оршанский район, деревня Старое Крещено, ул. Волкова, д. 13		0101000020E610000097FDBAD39DFF4740AC6F6072A3664C40
54487	7	62	1677	22756	63207	\N	56.974567999999998	Республика Марий Эл, Оршанский район, деревня Отары, ул. Школьная, д. 95		0101000020E6100000618A7269FC26484033DDEBA4BE7C4C40
54476	7	62	1677	22149	63141	\N	56.920639000000001	Республика Марий Эл, Оршанский район, посёлок Оршанка, ул. Юбилейная, д. 1		0101000020E6100000249C16BCE8F147400936AE7FD7754C40
54475	7	62	1677	22149	62211	\N	56.920639000000001	Республика Марий Эл, Оршанский район, посёлок Оршанка, ул. Советская, д. 85		0101000020E6100000249C16BCE8F147400936AE7FD7754C40
21073	7	61	58	31849	65661	\N	55.939594999999997	д. Бустанаево, Школьная, 28		0101000020E6100000E36BCF2C09A04B40183E22A644F84B40
54474	7	62	1677	22149	63075	\N	56.920639000000001	Республика Марий Эл, Оршанский район, посёлок Оршанка, ул. Пролетарская, д. 9		0101000020E6100000249C16BCE8F147400936AE7FD7754C40
54473	7	62	1677	22149	62199	\N	56.920639000000001	Республика Марий Эл, Оршанский район, посёлок Оршанка, ул. Гагарина, д. 4		0101000020E6100000249C16BCE8F147400936AE7FD7754C40
54468	7	62	1677	21902	62964	\N	56.862572999999998	Республика Марий Эл, Оршанский район, деревня Марково, ул. Восточная, д. 9		0101000020E6100000280B5F5FEBF44740D0B4C4CA686E4C40
54479	7	62	1677	22408	63197	\N	56.853591999999999	Республика Марий Эл, Оршанский район, деревня Малый Пуял, ул. Новая, д. 33		0101000020E6100000CEE33098BF0E48404910AE80426D4C40
54481	7	62	1677	22510	63130	\N	57.074989000000002	Республика Марий Эл, Оршанский район, деревня Малый Кугланур, ул. Центральная, д. 31а		0101000020E61000004A6249B9FB284840A647533D99894C40
54480	7	62	1677	22446	63202	\N	56.935119	Республика Марий Эл, Оршанский район, деревня Малая Каракша, ул. Школьная, д. 5б		0101000020E6100000180B43E4F4F54740226FB9FAB1774C40
54482	7	62	1677	22519	63077	\N	57.011577000000003	Республика Марий Эл, Оршанский район, деревня Лужбеляк, ул. Центральная, д. 53		0101000020E6100000B96E4A79AD1C48406231EA5A7B814C40
54478	7	62	1677	22353	63179	\N	56.815286	Республика Марий Эл, Оршанский район, село Великополье, ул. Шкетана, д. 24		0101000020E610000013B534B7420A48407E71A94A5B684C40
54477	7	62	1677	22336	63156	\N	56.919745173846401	Республика Марий Эл, Оршанский район, деревня Большая Орша, д. 155а	Россия, республика Марий Эл, Оршанский район, село Большая Орша	0101000020E61000006D6FB72407EA47406BD44334BA754C40
54464	7	62	1661	21694	63195	\N	57.121505999999997	Республика Марий Эл, Новоторъяльский район, д. Шура, ул. Микрорайон, д. 6		0101000020E61000009E7C7A6CCB284840462234828D8F4C40
54471	7	62	1661	22063	63143	\N	57.006681	Республика Марий Эл, Новоторъяльский район, д. Чуксола, ул. им.В.Иванова, д. 8	Россия, республика Марий Эл, Новоторъяльский район, село Чуксола	0101000020E6100000BFF38B12F461484096404AECDA804C40
54466	7	62	1661	21778	63022	\N	56.921553000000003	Республика Марий Эл, Новоторъяльский район, д. Токтарсола, ул. Центральная, д. 41		0101000020E6100000EBA7FFACF95B4840EE43DE72F5754C40
54465	7	62	1661	21772	63037	\N	56.962339999999998	Республика Марий Эл, Новоторъяльский район, с. Старый Торъял, ул. Центральная, д. 57а		0101000020E6100000166D8E739B644840FAD005F52D7B4C40
54470	7	62	1661	61561	79389	\N	56.999565733789197	Республика Марий Эл, Новоторъяльский район, д. Старокрещено, ул. Молодежная, д. 1	Россия, республика Марий Эл, Новоторъяльский район, село Кукмарь	0101000020E61000002140868E1D724840C61858C7F17F4C40
54463	7	62	1661	21638	63021	\N	57.032380000000003	Республика Марий Эл, Новоторъяльский район, с. Пектубаево, ул. Советская, д. 54		0101000020E6100000CE55F31C91314840B285200725844C40
54456	7	62	1661	21241	62287	\N	57.008544000000001	Республика Марий Эл, Новоторъяльский район, пос. Новый Торъял, ул. Советская, д. 53		0101000020E6100000C72AA5677A5D4840DC4944F817814C40
54455	7	62	1661	21241	62286	\N	57.008544000000001	Республика Марий Эл, Новоторъяльский район, пос. Новый Торъял, ул. Первомайская, д. 23		0101000020E6100000C72AA5677A5D4840DC4944F817814C40
54457	7	62	1661	21241	62198	\N	57.008544000000001	Республика Марий Эл, Новоторъяльский район, пос. Новый Торъял, ул. Культуры, д. 20		0101000020E6100000C72AA5677A5D4840DC4944F817814C40
54454	7	62	1661	21241	62292	\N	57.008544000000001	Республика Марий Эл, Новоторъяльский район, пос. Новый Торъял, ул. Коммунистическая, д. 27		0101000020E6100000C72AA5677A5D4840DC4944F817814C40
54469	7	62	1661	21936	62965	\N	57.069020000000002	Республика Марий Эл, Новоторъяльский район, д. Немда-Обалыш, ул. Центральная, д. 13		0101000020E61000007BF5F1D0776748408D62B9A5D5884C40
54460	7	62	1661	21484	63191	\N	57.121135000000002	Республика Марий Эл, Новоторъяльский район, с. Масканур, ул. Советская, д. 11		0101000020E6100000F73B1405FA52484053B3075A818F4C40
54467	7	62	1661	21861	63074	\N	56.940786000000003	Республика Марий Эл, Новоторъяльский район, д. Кузнецы, ул Центральная, д. 2		0101000020E61000003411363CBD7048407044F7AC6B784C40
54459	7	62	1661	58075	63188	\N	57.081593028140603	Республика Марий Эл, Новоторъяльский район,д. Куанпамаш, ул. Полевая, д. 1а	Россия, республика Марий Эл, Новоторъяльский район, село Куан-Памаш	0101000020E61000000BF148BC3C494840904AB1A3718A4C40
54462	7	62	1661	21611	63065	\N	57.076931000000002	Республика Марий Эл, Новоторъяльский район, д. Кремленки, ул. Микрорайон, д. 12		0101000020E6100000A7CCCD37A23B4840388600E0D8894C40
54461	7	62	1661	21566	62978	\N	56.971271000000002	Республика Марий Эл, Новоторъяльский район, д. Елембаево, ул. Центральная, д. 16		0101000020E610000048E00F3FFF4B4840D046AE9B527C4C40
54472	7	62	1661	22078	63041	\N	56.971727000000001	Республика Марий Эл, Новоторъяльский район, д. Шуйбеляк, ул. Центральная, д. 27		0101000020E61000004C512E8D5F5C4840F2D1E28C617C4C40
54458	7	62	1661	58072	63175	\N	57.115124000000002	Республика Марий Эл, Новоторъяльский район, д. Большая Лумарь, пер. Садовый, д. 9	Россия, республика Марий Эл, Новоторъяльский район, село Большой Ломарь	0101000020E61000003B38D89B185C48400B7E1B62BC8E4C40
54439	7	62	1583	20473	63140	\N	56.434123	Республика Марий Эл, Моркинский район, д. Ямбатор, ул. Ямбаторская, д. 28		0101000020E6100000C139234A7BBF484080B8AB5791374C40
54441	7	62	1583	20561	62208	\N	56.462411000000003	Республика Марий Эл, Моркинский район, д. Шоруньжа, ул. Спортивная, д. 11		0101000020E6100000912A8A5759C14840C4279D48303B4C40
54433	7	62	1583	20072	62975	\N	56.571168999999998	Республика Марий Эл, Моркинский район, д. Шордур, ул. Центральная, д. 37		0101000020E6100000E5805D4D9E8C484098BED7101C494C40
54437	7	62	1583	20338	63011	\N	56.425691	Республика Марий Эл, Моркинский район, с. Шиньша, ул. Петрова, д. 1б		0101000020E61000002AA8A8FA95AE4840CC99ED0A7D364C40
54423	7	62	1583	19560	63173	\N	56.344889999999999	Республика Марий Эл, Моркинский район, д. Адымаш, ул. Русская, д. 8		0101000020E61000001BA034D4287C4840D55B035B252C4C40
54450	7	62	1583	21039	63109	\N	56.337594986382904	Республика Марий Эл, Моркинский район, д. Шереганово, ул. Школьная, д. 17а	Россия, республика Марий Эл, Моркинский район, село Шереганово	0101000020E61000001B2D077AA85B484085251E50362B4C40
54442	7	62	1583	58070	63157	\N	56.516142053800898	Республика Марий Эл, Моркинский район, пос. Уньжинский, ул. Набережная, д. 20	Россия, республика Марий Эл, Моркинский район, село Уньжа	0101000020E61000006EF7729F1CC14840C80BE9F010424C40
54425	7	62	1583	19669	63177	\N	56.437556999999998	Республика Марий Эл, Моркинский район, д. Тыгыде Морко, ул. Молодежная, д. 9		0101000020E6100000E5B512BA4B6E4840649126DE01384C40
54436	7	62	1583	20252	63217	\N	56.388137999999998	Республика Марий Эл, Моркинский район, д. Токпердино, ул. Центральная, д. 2		0101000020E6100000624ED02687AD4840DC2A8881AE314C40
54449	7	62	1583	20378	62966	\N	56.408377999999999	Республика Марий Эл, Моркинский район, д. Чодраял, ул. Школьная, д. 2		0101000020E6100000CFF753E3A5AB4840F433F5BA45344C40
54438	7	62	1583	20378	63206	\N	56.408377999999999	Республика Марий Эл, Моркинский район, д. Тат-Чодраял, ул. Солнечная, д. 1		0101000020E6100000CFF753E3A5AB4840F433F5BA45344C40
54420	7	62	1583	19367	63145	\N	56.398330999999999	Республика Марий Эл, Моркинский район, д. Старое Мазиково, ул. Центральная, д. 8		0101000020E61000008BFED0CC938D4840D2FD9C82FC324C40
54430	7	62	1583	19889	63226	\N	56.517260999999998	Республика Марий Эл, Моркинский район, д. Семисола, ул. Советская, д. 17		0101000020E61000001C5E10919A8A4840853FC39B35424C40
54426	7	62	1583	19720	63104	\N	56.481698000000002	Республика Марий Эл, Моркинский район, д. Себеусад, ул. Школьная, д. 3		0101000020E61000000DA661F8886848403946B247A83D4C40
54432	7	62	1583	20023	63127	\N	56.555218000000004	Республика Марий Эл, Моркинский район, с. Петровское, ул. Пушкина, д. 19		0101000020E61000000A3197546DA148404513286211474C40
54445	7	62	1583	20779	63020	\N	56.418298	Республика Марий Эл, Моркинский район, д. Осипсола, ул. Клубная, д. 4		0101000020E610000061FD9FC37C5D4840B9FDF2C98A354C40
54452	7	62	1583	21139	63027	\N	56.312519999999999	Республика Марий Эл, Моркинский район, пос. Октябрьский, ул. Центральная, д. 6а		0101000020E61000007380608E1E4D484047ACC5A700284C40
54434	7	62	1583	20139	63125	\N	56.404175000000002	Республика Марий Эл, Моркинский район, д. Нуж-Ключ, ул. Школьная, д. 1		0101000020E610000032056B9C4DA548402F6EA301BC334C40
54419	7	62	1583	19100	\N	\N	56.434246999999999	Республика Марий Эл, Моркинский район, пос. Морки, ул. РТС, д. 5		0101000020E610000015376E313F7F48406CB1DB6795374C40
54417	7	62	1583	19100	62195	\N	56.434246999999999	Республика Марий Эл, Моркинский район, пос. Морки, бул. Калинина, д. 10		0101000020E610000015376E313F7F48406CB1DB6795374C40
54414	7	62	1583	19100	62194	\N	56.434246999999999	Республика Марий Эл, Моркинский район, пос. Морки, ул. Советская, д. 7		0101000020E610000015376E313F7F48406CB1DB6795374C40
54415	7	62	1583	19100	62245	\N	56.434246999999999	Республика Марий Эл, Моркинский район, пос. Морки, ул. Льва Толстого, д. 13		0101000020E610000015376E313F7F48406CB1DB6795374C40
54418	7	62	1583	19100	62196	\N	56.434246999999999	Республика Марий Эл, Моркинский район, пос. Морки, ул. Компрессорная, д. 7		0101000020E610000015376E313F7F48406CB1DB6795374C40
54416	7	62	1583	19100	62219	\N	56.434246999999999	Республика Марий Эл, Моркинский район, пос. Морки, ул. Заозерная, д. 1а		0101000020E610000015376E313F7F48406CB1DB6795374C40
54421	7	62	1583	19452	63128	\N	56.358471999999999	Республика Марий Эл, Моркинский район, д. Мари-Кужеры, ул. Центральная, д. 37б		0101000020E6100000682096CD1C8648400F441669E22D4C40
54422	7	62	1583	19464	63100	\N	56.377521999999999	Республика Марий Эл, Моркинский район, д. Кучко-Памаш, ул. Центральная, д. 2		0101000020E6100000CFA0A17F827B4840A0C211A452304C40
54451	7	62	1583	21108	63103	\N	56.358676000000003	Республика Марий Эл, Моркинский район, д. Кутюк-Кинер, ул. М. Казакова, д. 67		0101000020E6100000BEF6CC920057484018EE5C18E92D4C40
54448	7	62	1583	20925	63068	\N	56.288091000000001	Республика Марий Эл, Моркинский район, д. Кульбаш, ул. Центральная, д. 54а		0101000020E6100000E2033BFE0B664840CFA2772AE0244C40
54453	7	62	1583	21197	62976	\N	56.222796000000002	Республика Марий Эл, Моркинский район, пос. Красный Стекловар, ул. Советская, д. 2		0101000020E61000007B13437232654840FED64E94841C4C40
54447	7	62	1583	20911	63029	\N	56.347673999999998	Республика Марий Эл, Моркинский район, д. Коркатово, ул. Юбилейная, д. 4		0101000020E6100000096D3997E2604840B2D5E594802C4C40
54428	7	62	1583	19797	63064	\N	56.609408000000002	Республика Марий Эл, Моркинский район, д. Изи Кугунур, ул. Центральная, д. 14		0101000020E61000007C26FBE769604840DCF5D214014E4C40
54446	7	62	1583	20830	63124	\N	56.469557000000002	Республика Марий Эл, Моркинский район, д. Изи Шурга, ул. Центральная, д. 50		0101000020E6100000FF5BC98E8D5A4840CF4D9B711A3C4C40
54429	7	62	1583	19881	62972	\N	56.521034999999998	Республика Марий Эл, Моркинский район, пос. Зеленогорск, ул. Кооперативная, д. 10		0101000020E61000007BBDFBE3BD64484022895E46B1424C40
54435	7	62	1583	20206	63126	\N	56.357374999999998	Республика Марий Эл, Моркинский район, д. Досметкино, ул. Мира, д. 36		0101000020E610000080D250A390A4484039B4C876BE2D4C40
54427	7	62	1583	19746	63111	\N	56.552746999999997	Республика Марий Эл, Моркинский район, д. Весьшурга, ул. Заозерная, д. 2		0101000020E6100000BC033C69E166484026FBE769C0464C40
54424	7	62	1583	58063	63112	\N	56.4461945531976	Республика Марий Эл, Моркинский район, д. Большой Кожлаял, ул. Центральная, д. 9	Россия, республика Марий Эл, Моркинский район, село Большой Кожлоял	0101000020E6100000E8F9D34675744840C251F2EA1C394C40
54443	7	62	1583	20697	63026	\N	56.419428000000003	Республика Марий Эл, Моркинский район, д. Большие Шали, ул. Молодежная, д. 2		0101000020E61000009F9273620F6B48406B8313D1AF354C40
54431	7	62	1583	19972	63067	\N	56.492204000000001	Республика Марий Эл, Моркинский район, д. Алмаметьево, ул. Титова, д. 27		0101000020E6100000F59ECA694F894840EE7A698A003F4C40
54444	7	62	1583	20751	63105	\N	56.403504307710797	Республика Марий Эл, Моркинский район, д. Азъял, ул. Школьная, д. 14	Россия, республика Марий Эл, Моркинский район, село Азъял	0101000020E610000082A8FB00A474484010E7E104A6334C40
54413	7	62	1452	58054	63028	\N	56.753473278244897	Республика Марий Эл, Медведевский район, пос.Юбилейный, ул.Культуры, д.2	Россия, республика Марий Эл, Медведевский район	0101000020E6100000C1CAA145B61B4840A2B5A2CD71604C40
54393	7	62	1452	18012	62974	\N	56.788908999999997	Республика Марий Эл, Медведевский район, д.Яныкайсола, ул.Центральная, д.31		0101000020E6100000C32ADEC83CD44740914259F8FA644C40
54107	7	62	1452	58061	\N	\N	56.6816667199218	"Республика Марий Эл, г. Йошкар-Ола, д. Якимово, д. 42Б. (Адрес помещения для голосования: ООО ""Крестьянское подворье - АГРО"", административное здание)"	Россия, республика Марий Эл, Медведевский район, село Якимово	0101000020E6100000CE8AA8893EFF474097E13FDD40574C40
54409	7	62	1452	18805	62193	\N	56.723412000000003	Республика Марий Эл, Медведевский район, с.Шойбулак, ул.Мира, д.18		0101000020E610000075914259F8F4474059C4B0C3985C4C40
54379	7	62	1452	17293	63171	\N	56.653531000000001	Республика Марий Эл, Медведевский район, д.Шеклянур, ул.Советская, д.2		0101000020E6100000DCBA9BA73AD047400AF65FE7A6534C40
54412	7	62	1452	18951	62998	\N	56.733638999999997	Республика Марий Эл, Медведевский район, с.Цибикнур, ул.Пионерская, д.5		0101000020E61000007958A835CDE94740FA08FCE1E75D4C40
54382	7	62	1452	17452	63097	\N	56.770268000000002	Республика Марий Эл, Медведевский район, д.Томшарово, ул.Школьная, д.50		0101000020E610000075CB0EF10F0F4840E2934E2498624C40
54389	7	62	1452	17807	62283	\N	56.446483999999998	Республика Марий Эл, Медведевский район, пос.Сурок, ул.Коммунистическая, д.1		0101000020E6100000F816D68D770F4840F817416326394C40
54408	7	62	1452	18780	63102	\N	56.880130000000001	Республика Марий Эл, Медведевский район, д.Средняя Турша, ул.Школьная, д.6		0101000020E6100000BE4F55A181CA47403F1D8F19A8704C40
54380	7	62	1452	58079	63203	\N	56.675498109476401	Республика Марий Эл, Медведевский район, д.Средние Шапы, ул.Центральная, д.10	Россия, республика Марий Эл, Медведевский район, село Шапы	0101000020E610000034F8FBC56CC74740B741EDB776564C40
54378	7	62	1452	17235	63014	\N	56.621096999999999	Республика Марий Эл, Медведевский район, д.Среднее Азяково, ул.Зеленая, д.2а		0101000020E61000008484285FD0D247406552431B804F4C40
54388	7	62	1452	17756	62192	\N	56.378788307597603	Республика Марий Эл, Медведевский район, пос.Силикатный, ул.Мира, д.34	Россия, республика Марий Эл, Медведевский район, поселок Силикатный	0101000020E6100000F4DE180280194840020F0C207C304C40
54403	7	62	1452	18487	62942	\N	56.677373000000003	Республика Марий Эл, Медведевский район, д.Сенькино, ул.Школьная, д.18а		0101000020E6100000637E6E68CAF44740C2189128B4564C40
54401	7	62	1452	18406	62284	\N	56.629159000000001	Республика Марий Эл, Медведевский район, пос.Руэм, ул.Шумелева, д.14		0101000020E6100000D3A57F492AE14740F67D384888504C40
54402	7	62	1452	18406	62943	\N	56.629159000000001	Республика Марий Эл, Медведевский район, пос.Руэм, ул.Победы, д.1		0101000020E6100000D3A57F492AE14740F67D384888504C40
54400	7	62	1452	18319	62313	\N	56.673358	Республика Марий Эл, Медведевский район, д.Русский Кукмор, ул.Пионерская, д.3		0101000020E610000097A8DE1AD8124840FF3F4E9830564C40
54399	7	62	1452	18288	62977	\N	56.827689999999997	Республика Марий Эл, Медведевский район, д.Пижма, ул.Центральная, д.30а		0101000020E61000008CF337A110B14740F59CF4BEF1694C40
54391	7	62	1452	17884	63016	\N	56.514555000000001	Республика Марий Эл, Медведевский район, пос.Пемба, ул.Зеленая, д.49		0101000020E6100000F7C8E6AA79064840247F30F0DC414C40
54397	7	62	1452	18191	63017	\N	56.676419000000003	Республика Марий Эл, Медведевский район, д.Пекшиксола, ул.Транспортная, д.10		0101000020E6100000AEB8382A37DD47404FB2D5E594564C40
54411	7	62	1452	18935	63174	\N	56.728810000000003	Республика Марий Эл, Медведевский район, д.Орешкино, ул.Орешкино, д.33		0101000020E6100000EC12D55B03ED4740B77F65A5495D4C40
54394	7	62	1452	18025	63055	\N	56.709995999999997	Республика Марий Эл, Медведевский район, с.Нурма, ул.Кедровой, д.48		0101000020E610000033F9669B1BDB474039252026E15A4C40
54398	7	62	1452	18233	62947	\N	56.677106000000002	Республика Марий Эл, Медведевский район, пос.Новый, ул.Школьная, д.1	Россия, республика Марий Эл, Медведевский район, село Новый	0101000020E6100000363E93FDF3E8474073F6CE68AB564C40
54386	7	62	1452	17670	62950	\N	56.720449000000002	Республика Марий Эл, Медведевский район, д.Новое Комино, ул.Школьная, д.8		0101000020E610000088122D793C034840CCB73EAC375C4C40
54365	7	62	1452	16500	62187	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Шумелева, д.8		0101000020E61000009161156F64E64740527FBDC282514C40
54374	7	62	1452	16500	63098	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Чехова, д.6		0101000020E61000009161156F64E64740527FBDC282514C40
54364	7	62	1452	16500	62279	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Терешковой, д.13		0101000020E61000009161156F64E64740527FBDC282514C40
54368	7	62	1452	16500	62312	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Советская, д.23		0101000020E61000009161156F64E64740527FBDC282514C40
54369	7	62	1452	16500	62281	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Полевая, д.20		0101000020E61000009161156F64E64740527FBDC282514C40
54367	7	62	1452	16500	62281	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Полевая, д.3		0101000020E61000009161156F64E64740527FBDC282514C40
54363	7	62	1452	16500	62280	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Мира, д.9		0101000020E61000009161156F64E64740527FBDC282514C40
54366	7	62	1452	16500	62311	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Лермонтова, д.13		0101000020E61000009161156F64E64740527FBDC282514C40
54372	7	62	1452	16500	62282	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Ленина, д.14		0101000020E61000009161156F64E64740527FBDC282514C40
54371	7	62	1452	16500	62282	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Ленина, 14		0101000020E61000009161156F64E64740527FBDC282514C40
54370	7	62	1452	16500	63096	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Коммунистическая, 18		0101000020E61000009161156F64E64740527FBDC282514C40
54373	7	62	1452	16500	63054	\N	56.636803	Республика Марий Эл, Медведевский район, пос.Медведево, ул.Гагарина, д.2а		0101000020E61000009161156F64E64740527FBDC282514C40
54392	7	62	1452	17945	62996	\N	56.825502999999998	Республика Марий Эл, Медведевский район, д.Люльпаны, ул.Лесная, д.18		0101000020E61000005B272EC72BC84740FCDF1115AA694C40
54385	7	62	1452	17619	62296	\N	56.692377999999998	Республика Марий Эл, Медведевский район, с.Кузнецово, ул.Пионерская, д.1а		0101000020E6100000B94F8E0244054840253CA1D79F584C40
54376	7	62	1452	17097	62285	\N	56.675353315026101	Республика Марий Эл, Медведевский район, пос.Краснооктябрьский, ул.Фабричная, д.3	Россия, республика Марий Эл, Медведевский район, поселок Краснооктябрьский	0101000020E6100000D751D50451D54740B42094F771564C40
54375	7	62	1452	17097	62189	\N	56.675495064092203	Республика Марий Эл, Медведевский район, пос.Краснооктябрьский, ул.Горького, д.21	Россия, республика Марий Эл, Медведевский район, поселок Краснооктябрьский	0101000020E6100000BEBC00FBE8D4474046CEC29E76564C40
54387	7	62	1452	17702	63230	\N	56.729343999999998	Республика Марий Эл, Медведевский район, д.Ким, ул.Центральная, д.1а		0101000020E6100000E8154F3DD20C484054C4E9245B5D4C40
54384	7	62	1452	17480	62191	\N	56.637569999999997	Республика Марий Эл, Медведевский район,  пос.Знаменский, ул.Победы, д.5		0101000020E61000001899805F23FF47409274CDE49B514C40
54383	7	62	1452	17480	62191	\N	56.637569999999997	Республика Марий Эл, Медведевский район, пос.Знаменский, ул.Победы, д.5		0101000020E61000001899805F23FF47409274CDE49B514C40
54381	7	62	1452	17400	9894	\N	56.715366000000003	Республика Марий Эл, Медведевский район, с.Ежово, ул.Комсомольская, д.20		0101000020E6100000B1C1C2499A0F4840CE55F31C915B4C40
54404	7	62	1452	58064	\N	\N	56.693260028334201	Республика Марий Эл, Медведевский район, пос.Аэропорт, ул.Аэропорт, д.11	Россия, республика Марий Эл, Медведевский район	0101000020E610000056815A0C1EF44740FFCF61BEBC584C40
54395	7	62	1452	18106	63232	\N	56.716996000000002	Республика Марий Эл, Медведевский район, д.Арбаны, ул.Полевая, д.13		0101000020E610000050560C5707E2474071AE6186C65B4C40
54410	7	62	1452	58103	63380	\N	56.766673328074098	Республика Марий Эл, Медведевский район, д.Аксаркино, ул.Аксаркино, д.5	Россия, республика Марий Эл, Медведевский район, село Аксарка	0101000020E6100000B4739A05DAFB4740F4DC425722624C40
54377	7	62	1452	17197	62190	\N	56.716320000000003	Республика Марий Эл, Медведевский район, с.Азаново, ул.Фабричная, д.4		0101000020E61000002310AFEB171C484041BCAE5FB05B4C40
54362	7	62	1390	16427	63015	\N	56.648513999999999	Республика Марий Эл, Мари-Турекский район, с. Хлебниково, ул. Свободы, д.2		0101000020E6100000CD069964E4F84840C37FBA8102534C40
54345	7	62	1390	15619	63057	\N	56.803938000000002	Республика Марий Эл, Мари-Турекский район, д. Тат-Китня, ул.Победы, д.1 (помещение для голосования: ул.Победы, д. 1а)		0101000020E61000005C59A2B3CCDA48407E01BD70E7664C40
54350	7	62	1390	15832	\N	\N	57.003793999999999	Республика Марий Эл, Мари-Турекский район, д. Сысоево, ул. Центральная усадьба, д. 13 (помещение для голосования - ул. Центральная усадьба, д. 10)		0101000020E6100000CF143AAFB1D14840E4F560527C804C40
54357	7	62	1390	58067	63135	\N	56.478013429105197	Республика Марий Эл, Мари-Турекский район, п. Новопавловский, ул. Клубная, д. 9	Россия, республика Марий Эл, Мари-Турекский район, село Совхоз Павловский	0101000020E6100000AB9509BFD4E748400B08AD872F3D4C40
54353	7	62	1390	15993	63108	\N	56.790106999999999	Республика Марий Эл, Мари-Турекский район, д.Сенда, ул. Русская Сенда, д. 18		0101000020E61000008FAB915D69F548409BABE63922654C40
54348	7	62	1390	15738	63166	\N	56.448045999999998	Республика Марий Эл, Мари-Турекский район, д.Сардаял, ул. Советская, д. 7 (зал для голосования - ул.Школьная, д.1)		0101000020E61000008CA37213B5FC4840438D429259394C40
54356	7	62	1390	16121	62186	\N	56.516064999999998	Республика Марий Эл, Мари-Турекский район, п.Мариец, ул.Клубная, д.2. (помещение для голосования: ул.Центральная усадьба, д. 6)		0101000020E6100000378AAC3594EA48401CCEFC6A0E424C40
54344	7	62	1390	15262	63012	\N	56.788268000000002	Республика Марий Эл, Мари-Турекский район, п. Мари-Турек, ул. Советская, д. 16		0101000020E61000009082A7902BCF4840DE3D40F7E5644C40
54338	7	62	1390	15262	62310	\N	56.788268000000002	Республика Марий Эл, Мари-Турекский район, п. Мари-Турек, ул. Парковая, д.5 (помещение для голосования: ул. Лесная, д. 3)		0101000020E61000009082A7902BCF4840DE3D40F7E5644C40
54343	7	62	1390	15262	62997	\N	56.788268000000002	Республика Марий Эл, Мари-Турекский район, п. Мари-Турек, ул.Мичурина, д. 30		0101000020E61000009082A7902BCF4840DE3D40F7E5644C40
54342	7	62	1390	15262	62997	\N	56.788268000000002	Республика Марий Эл, Мари-Турекский район, п. Мари-Турек, ул. Мичурина, д. 30		0101000020E61000009082A7902BCF4840DE3D40F7E5644C40
54339	7	62	1390	15262	62276	\N	56.788268000000002	Республика Марий Эл, Мари-Турекский район, п. Мари-Турек, ул. Комсомольская, д. 36		0101000020E61000009082A7902BCF4840DE3D40F7E5644C40
54341	7	62	1390	15431	62995	\N	56.85087	Республика Марий Эл, Мари-Турекский район, д. Мари-Купта, ул. Молодежная, д. 13		0101000020E6100000A9BC1DE1B4DA4840E292E34EE96C4C40
54340	7	62	1390	15371	63225	\N	56.822758999999998	Республика Марий Эл, Мари-Турекский район, д. Мари-Китня, ул. Школьная, д. 2		0101000020E6100000B77F65A549D34840ADBEBA2A50694C40
54351	7	62	1390	15904	63053	\N	56.841886000000002	Республика Марий Эл, Мари-Турекский район, с.Мари-Билямор, ул.Колхозная, д.3. (помещение для голосования: ул.Комсомольская, д. 16)		0101000020E61000008331225168F34840EA7AA2EBC26B4C40
54347	7	62	1390	15715	63049	\N	56.558382999999999	Республика Марий Эл, Мари-Турекский район, д. Лопово, ул.Лопово, д.47 (Адрес для голосования - Лопово, д.45)		0101000020E61000002DCC423BA715494039D2191879474C40
54359	7	62	1390	16294	63172	\N	56.610981809594101	Республика Марий Эл, Мари-Турекский район, д.Лом, ул. Лом, д. 43	Россия, республика Марий Эл, Мари-Турекский район, село Лом	0101000020E61000007D06D49B51FD4840EB387EA8344E4C40
54358	7	62	1390	16227	\N	\N	56.712663999999997	Республика Марий Эл, Мари-Турекский район, д. Крупино, ул. Крупино, д. 49		0101000020E61000009DF4BEF1B5FF4840AD84EE92385B4C40
54349	7	62	1390	15796	62158	\N	56.927363999999997	Республика Марий Эл, Мари-Турекский район, с.Косолапово, ул. Совхозная, д.33 (помещение для голосования - ул. Советская д.29)		0101000020E61000002D6002B7EECC48406EBE11DDB3764C40
54360	7	62	1390	16331	\N	\N	56.670211999999999	Республика Марий Эл, Мари-Турекский район, д.Ивская Вершина, ул.Ивская Вершина, д.1а		0101000020E610000044A852B307FC484081B1BE81C9554C40
54352	7	62	1390	15943	63056	\N	56.810659999999999	Республика Марий Эл, Мари-Турекский район, д. Елымбаево, ул.Школьная д.9		0101000020E6100000ED116A8654E948407216F6B4C3674C40
54355	7	62	1390	16087	\N	\N	56.539110999999998	Республика Марий Эл, Мари-Турекский район, д. Дружино, ул. Дружино д. 52		0101000020E61000001092054CE0F84840F9F4D89601454C40
54346	7	62	1390	15653	62243	\N	56.565584999999999	Республика Марий Эл, Мари-Турекский район, д. Большой Карлыган, ул. Мира, д. 26 (помещение для голосования: ул. Багаева, д.3)		0101000020E610000026C3F17C06084940D80DDB1665484C40
54361	7	62	1390	16390	63013	\N	56.656631458430503	Республика Марий Эл, Мари-Турекский район, д.Большое Опарино ул. Советская,  47 (помещение для голосования - ул. Молодежная д.1а)	Россия, республика Марий Эл, Мари-Турекский район, село Большое Опарино	0101000020E6100000B2D47ABFD1EC484017450F7C0C544C40
54337	7	62	1390	15224	63087	\N	56.720058999999999	Республика Марий Эл, Мари-Турекский район, с.Алексеевское, ул. Заречная, д. 9		0101000020E61000003D0FEECEDADD48406118B0E42A5C4C40
54336	7	62	1334	15168	62994	\N	56.808753000000003	Республика Марий Эл, Куженерский район, с. Юледур, ул. Коммунистическая, д. 22а (зал для голосования - с. Юледур, ул.Строителей д.2а)		0101000020E610000025CFF57D389648405DC5E23785674C40
54330	7	62	1334	14887	63019	\N	56.823720000000002	Республика Марий Эл, Куженерский район, дер. Шорсола, ул. Центральная, д. 5 (зал для голосования - ул.Школьная, 2)		0101000020E610000026E0D748128A4840D3872EA86F694C40
54331	7	62	1334	14949	62961	\N	56.763598000000002	Республика Марий Эл, Куженерский район, дер. Шой-Шудумарь, ул. Рыбакова, д. 11 (адрес помещения для голосования - ул. Победы, д. 5)		0101000020E610000009FEB7921D8B484040A54A94BD614C40
54328	7	62	1334	14792	63167	\N	56.832014000000001	Республика Марий Эл, Куженерский район, дер. Большой Тумьюмучаш, ул. Тумьюмучаш, д. 40 (адрес помещения для голосования - ул. Новостройка, д. 28)		0101000020E61000003CF4DDAD2C63484036E84B6F7F6A4C40
54326	7	62	1334	14694	63052	\N	56.869962999999998	Республика Марий Эл, Куженерский район, с. Токтайбеляк, ул. Молодежная, д. 3 (адрес помещения для голосования - ул. Молодежная, д. 27)		0101000020E61000000249D8B79376484072DD94F25A6F4C40
54325	7	62	1334	14652	63169	\N	56.708340999999997	Республика Марий Эл, Куженерский район, с. Салтакъял, ул. Рабочая, д. 18, кв. 10 (адрес помещения для голосования - ул.Заречная, 50)		0101000020E610000029CC7B9C697648403DB5FAEAAA5A4C40
54323	7	62	1334	14550	63051	\N	56.669466	Республика Марий Эл, Куженерский район, с. Русские Шои, ул. Школьная, д. 4 (адрес помещения для голосования - ул. Школьная, д. 2)		0101000020E6100000BA13ECBFCE91484058E4D70FB1554C40
54324	7	62	1334	14599	63168	\N	56.686432000000003	Республика Марий Эл, Куженерский район, дер. Мари Шои, ул. Починок, д. 3		0101000020E6100000A3CC0699648C4840C576F700DD574C40
54321	7	62	1334	14314	62185	\N	56.810614999999999	Республика Марий Эл, Куженерский район, пос Куженер, ул. Степана Лебедева, д. 20 а (адрес помещения для голосования - ул. Заречная, д. 4а)		0101000020E6100000492F6AF7AB744840D252793BC2674C40
54320	7	62	1334	14314	62185	\N	56.810614999999999	Республика Марий Эл, Куженерский район, пос. Куженер, ул. Степана Лебедева, д. 20а (адрес помещения для голосования - ул. Школьная, д. 5а)		0101000020E6100000492F6AF7AB744840D252793BC2674C40
54319	7	62	1334	14314	62185	\N	56.810614999999999	Республика Марий Эл, Куженерский район, пос Куженер, ул.. Степана Лебедева, д. 20а (адрес помещения для голосования - ул. Степана Лебедева, 14)		0101000020E6100000492F6AF7AB744840D252793BC2674C40
54318	7	62	1334	14314	62185	\N	56.810614999999999	Республика Марий Эл, Куженерский район, пос. Куженер, ул.Степана Лебедева,  20 а (Республика Марий Эл, Килемарский район, пос. Куженер, ул. Кирова, 2 а - зал для голосования)		0101000020E6100000492F6AF7AB744840D252793BC2674C40
54333	7	62	1334	58084	63229	\N	56.755145364217903	Республика Марий Эл, Куженерский район, с. Русский Кугунур, ул. Зеленая, д. 16	Россия, республика Марий Эл, Куженерский район, село Кугунур	0101000020E610000044A2D0B2EE934840745E6397A8604C40
54329	7	62	1334	14853	63170	\N	56.860334000000002	Республика Марий Эл, Куженерский район, дер. Конганур, ул. Конганур, д. 75		0101000020E6100000F486FBC8AD65484085D1AC6C1F6E4C40
54322	7	62	1334	14503	62992	\N	56.792887238193799	Республика Марий Эл, Куженерский район, дер. Иштымбал , ул. Набережная, д. 2(адрес помещения для голосования - ул.Набережная, д. 4)	Россия, республика Марий Эл, Куженерский район, село Иштымбал	0101000020E610000081ED60C43E69484037363B527D654C40
54335	7	62	1334	15121	63227	\N	56.850977999999998	Республика Марий Эл, Куженерский район, дер. Ивансола, ул. Ивансола, д. 37а (зал для голосования - д. Купсола,  ул.Купсола, д.47а)		0101000020E6100000221ADD41EC924840C8CEDBD8EC6C4C40
54327	7	62	1334	14763	63223	\N	56.801090000000002	Республика Марий Эл, Куженерский район, дер. Верх-Ушут, ул. Школьная, д. 64		0101000020E6100000234E27D9EA6048408A93FB1D8A664C40
54334	7	62	1334	15066	62948	\N	56.830393999999998	Республика Марий Эл, Куженерский район, дер. Большой Ляждур, ул. Центральная, д. 29б (зал для голосования - ул. Школьная, 2а)		0101000020E610000063B323D577A04840B665C0594A6A4C40
54317	7	62	1284	14277	63219	\N	56.317098000000001	Республика Марий Эл, Килемарский район, с.Юксары, ул.Школьная, д. 5		0101000020E61000004E4354E1CF84474042D0D1AA96284C40
54315	7	62	1284	14188	63222	\N	56.739840999999998	Республика Марий Эл, Килемарский район, д.Широкундыш, ул. Механизаторов, д. 11		0101000020E61000002C0DFCA886754740B69E211CB35E4C40
54310	7	62	1284	13928	63088	\N	56.577848000000003	Республика Марий Эл, Килемарский район, пос.Озерный, ул. Зеленая, д. 1		0101000020E610000051FA42C8798F47408E075BECF6494C40
54313	7	62	1284	14091	63164	\N	56.932236000000003	Республика Марий Эл, Килемарский район, с.Нежнур, ул. Коммунистическая, д. 18		0101000020E610000080D250A390524740B2135E8253774C40
54305	7	62	1284	13700	63162	\N	56.419351416936301	Республика Марий Эл, Килемарский район, пос. Механизаторов, ул. Ветеранов, д. 3	Россия, республика Марий Эл, Килемарский район, поселок Механизаторов	0101000020E61000004AD1CABDC0604740BF45274BAD354C40
54312	7	62	1284	14032	63163	\N	56.713079	Республика Марий Эл, Килемарский район, пос. Майский, ул. Железнодорожная, д. 12		0101000020E61000003659A31EA23D4740713B342C465B4C40
54311	7	62	1284	13989	63122	\N	56.684967999999998	Республика Марий Эл, Килемарский район, с. Кумья, ул. Советская, д. 6		0101000020E6100000BD72BD6DA65247403C670B08AD574C40
54309	7	62	1284	13898	63085	\N	56.559722000000001	Республика Марий Эл, Килемарский район, пос.Красный Мост, ул. Центральная, д. 8		0101000020E6100000852348A5D8934740056D72F8A4474C40
54300	7	62	1284	13450	62273	\N	56.785778000000001	Республика Марий Эл, Килемарский район, пос.Килемары, ул. Садовая, д. 56		0101000020E610000049D576137C6F474049F59D5F94644C40
54301	7	62	1284	13450	62309	\N	56.785778000000001	Республика Марий Эл, Килемарский район, пос.Килемары, ул. Мира, д. 31		0101000020E610000049D576137C6F474049F59D5F94644C40
54304	7	62	1284	13647	63092	\N	56.395985000000003	Республика Марий Эл, Килемарский район, д.Ершово, ул. Школьная, д. 12		0101000020E61000002060ADDA356D4740715AF0A2AF324C40
54308	7	62	1284	57931	62275	\N	56.437216048687702	Республика Марий Эл, Килемарский район, пос.Визимьяры, ул. Советская, д. 18 а	Россия, республика Марий Эл, Килемарский район, поселок Визимъяры	0101000020E6100000A839799109784740DBA4A2B1F6374C40
54306	7	62	1284	13733	63117	\N	56.911543999999999	Республика Марий Эл, Килемарский район, д. Большое Кибеево, ул. Большекибеевская, д. 69		0101000020E6100000828FC18A53894740B96E4A79AD744C40
54303	7	62	1284	13619	63050	\N	56.405011000000002	Республика Марий Эл, Килемарский район, с.Арда, ул. Школьная, д. 5		0101000020E61000007A17EFC7ED63474098C28366D7334C40
54302	7	62	1284	13558	63221	\N	56.425939999999997	Республика Марий Эл, Килемарский район, д. Алешкино, ул. Лесная, д. 12		0101000020E6100000E94317D4B75C47407407B13385364C40
54316	7	62	1284	14218	63090	\N	56.267882	Республика Марий Эл, Килемарский район, д. Алатайкино, ул. Алатайкинская, д. 45		0101000020E61000004981053065764740F29716F549224C40
54314	7	62	1284	14127	63118	\N	56.670465	Республика Марий Эл, Килемарский район, с.Актаюж, ул. Лесная, д. 1		0101000020E6100000DA5548F9498147406B0E10CCD1554C40
54102	7	62	1520	57933	62300	\N	56.646549801337102	Республика Марий Эл, г. Йошкар-Ола, с.Семеновка, ул. Молодежная, д. 11	Россия, республика Марий Эл, Йошкар-Ола городской округ, село Семеновка	0101000020E6100000A489778027FD4740499D8026C2524C40
54406	7	62	1520	18667	63000	\N	56.552002999999999	Республика Марий Эл, Медведевский район, пос.Светлый, ул.Садовая, д.1		0101000020E6100000179E978A8DEB47409E25C808A8464C40
54105	7	62	1520	57927	62188	\N	56.657565926496503	Республика Марий Эл, г. Йошкар-Ола, д. Савино, ул. Школьная, д. 9	Россия, республика Марий Эл, Йошкар-Ола городской округ, село Савино	0101000020E6100000AA285E656D014840147B681F2B544C40
54153	7	62	1520	58081	\N	\N	56.589784999999999	Республика Марий Эл, г. Йошкар-Ола, пос. Нолька, д. 43	Россия, республика Марий Эл, Йошкар-Ола городской округ, село Нолька	0101000020E6100000E6779ACC78F34740EF552B137E4B4C40
54405	7	62	1520	58081	63210	\N	56.588911319596903	Республика Марий Эл, г.Йошкар-Ола, пос.Нолька, д.4	Россия, республика Марий Эл, Йошкар-Ола городской округ, село Нолька	0101000020E6100000554D10751FF4474099A0866F614B4C40
54390	7	62	1520	17855	62244	\N	56.550092999999997	Республика Марий Эл, Медведевский район, пос.Куяр, ул.Лесная, д.21		0101000020E6100000C32B499EEBFD474017618A7269464C40
54407	7	62	1520	18709	63101	\N	56.573732999999997	Республика Марий Эл, Медведевский район, пос.Зеленый, ул.Зеленая, д.1а		0101000020E6100000FC389A232BE7474067D13B1570494C40
54293	7	62	1199	13143	63119	\N	56.189455000000002	Республика Марий Эл, Звениговский район, д.Шимшурга, ул.Шимшургинская, д.44		0101000020E61000004B5B5CE333F347402788BA0F40184C40
54298	7	62	1199	13371	62184	\N	56.221865000000001	Республика Марий Эл, Звениговский район, пос.Шелангер, ул.Школьная, д.36		0101000020E61000005706D5062720484043908312661C4C40
54297	7	62	1199	58082	\N	\N	56.358122999999999	Республика Марий Эл, Звениговский район, п.Черное Озеро, д.52	Россия, республика Марий Эл, Звениговский район, село Черное Озеро	0101000020E610000039B4C876BEB34740037976F9D62D4C40
54299	7	62	1199	13425	63161	\N	56.284649000000002	Республика Марий Эл, Звениговский район, д.Филиппсола, ул.Валерия Волкова, д.2а		0101000020E6100000E0826C59BE40484068EBE0606F244C40
54275	7	62	1199	12314	\N	\N	56.130938999999998	Республика Марий Эл, Звениговский район, пос.Трубный, здание Красногорского ПНИ	Россия, республика Марий Эл, Звениговский район, село Трубный	0101000020E6100000136058FE7C2D4840AE62F19BC2104C40
54273	7	62	1199	12226	\N	\N	56.154885999999998	Республика Марий Эл, Звениговский район, д.Ташнур, д.51		0101000020E61000003D9CC0745A1F4840DB4DF04DD3134C40
54291	7	62	1199	13058	63160	\N	56.268805999999998	Республика Марий Эл, Звениговский район, пос.Таир, ул.Школьная, д.16б		0101000020E61000004B22FB20CBEC4740FA7B293C68224C40
54278	7	62	1199	12428	62956	\N	56.311526000000001	Республика Марий Эл, Звениговский район, пос. Суслонгер, ул. Железнодорожная,  60		0101000020E61000007407B1338520484046ED7E15E0274C40
54277	7	62	1199	12428	62242	\N	56.311526000000001	Республика Марий Эл, Звениговский район, пос.Суслонгер, ул.Гвардейская, д.8		0101000020E61000007407B1338520484046ED7E15E0274C40
54282	7	62	1199	52796	63155	\N	56.027217999999998	Республика Марий Эл, Звениговский район, д.Сосновка, ул.Мюшультурская, д.57		0101000020E610000015AB06616E05484067EE21E17B034C40
54295	7	62	1199	13238	62960	\N	56.164987000000004	Республика Марий Эл, Звениговский район, с.Сидельниково, ул.Школьная, д.12		0101000020E6100000828E56B5A4D14740F1A1444B1E154C40
54292	7	62	1199	13076	63080	\N	56.141272000000001	Республика Марий Эл, Звениговский район, д.Семеновка, ул.Селиванова, д.57		0101000020E61000009FE5797077EE474096EB6D3315124C40
54289	7	62	1199	12954	62990	\N	56.163758999999999	Республика Марий Эл, Звениговский район, д.Поянсола, ул.Школьная, д.14		0101000020E6100000EC4CA1F31A0D48407CB60E0EF6144C40
54286	7	62	1199	12829	\N	\N	56.120859000000003	Республика Марий Эл, Звениговский район, д.Нуктуж, ул.Нуктуж, д.255		0101000020E610000026E4839ECD104840B136C64E780F4C40
54296	7	62	1199	13277	63158	\N	56.254412000000002	Республика Марий Эл, Звениговский район, д.Липша, ул.Новая, д.11	Россия, республика Марий Эл, Звениговский район, село Новая Липша	0101000020E610000007B5DFDA89BA4740E0DA899290204C40
54288	7	62	1199	58057	63044	\N	56.106517654793997	Республика Марий Эл, Звениговский район, д.Нижние Памъялы, ул.Центральная, д.55а	Россия, республика Марий Эл, Звениговский район, село Нижние Помьялы	0101000020E6100000207D93A641054840B937BF61A20D4C40
54276	7	62	1199	12360	62278	\N	56.330314999999999	Республика Марий Эл, Звениговский район, пос.Мочалище, ул.Школьная, д.17		0101000020E610000044FB58C16F2D48406A300DC3472A4C40
54287	7	62	1199	12872	63204	\N	56.160431000000003	Республика Марий Эл, Звениговский район, д.Малая Кужмара, ул.Малокужмарская, д.16а		0101000020E6100000BA8102EFE4174840DE21C50089144C40
54280	7	62	1199	12568	\N	\N	55.948407000000003	Республика Марий Эл, Звениговский район, д.Кукшенеры, д.65а		0101000020E6100000ECFA05BB611B484014268C6665F94B40
54285	7	62	1199	12780	63007	\N	56.144637000000003	Республика Марий Эл, Звениговский район, с.Кужмара, ул.Центральная, д.5		0101000020E610000054AA44D95B0848405265187783124C40
54283	7	62	1199	12612	62989	\N	56.034933000000002	Республика Марий Эл, Звениговский район, с.Красный Яр, ул.Центральная, д.17		0101000020E6100000E013EB54F90248408D463EAF78044C40
54281	7	62	1199	12612	62989	\N	56.034933000000002	Республика Марий Эл, Звениговский район, с.Красный Яр, ул.Центральная, д.15		0101000020E6100000E013EB54F90248408D463EAF78044C40
54272	7	62	1199	12022	62270	\N	56.153632999999999	Республика Марий Эл, Звениговский район, пос.Красногорский, ул.Центральная, д.73		0101000020E6100000C2DB8310902948400E4B033FAA134C40
54269	7	62	1199	12022	62270	\N	56.153632999999999	Республика Марий Эл, Звениговский район, пос.Красногорский, ул.Центральная, д.1а		0101000020E6100000C2DB8310902948400E4B033FAA134C40
54274	7	62	1199	12022	63106	\N	56.153632999999999	Республика Марий Эл, Звениговский район, пос.Красногорский, ул.Первомайская, д.84		0101000020E6100000C2DB8310902948400E4B033FAA134C40
54271	7	62	1199	12022	62308	\N	56.153632999999999	Республика Марий Эл, Звениговский район, пос.Красногорский, ул.Машиностроителей, д.6		0101000020E6100000C2DB8310902948400E4B033FAA134C40
54270	7	62	1199	12022	62271	\N	56.153632999999999	Республика Марий Эл, Звениговский район, пос.Красногорский, ул.Ленина, д.12		0101000020E6100000C2DB8310902948400E4B033FAA134C40
54294	7	62	1199	13178	62993	\N	56.161534000000003	Республика Марий Эл, Звениговский район, д.Кокшамары, ул.Молодежная, д.29а		0101000020E6100000EE4108C897DE474096986725AD144C40
54290	7	62	1199	12993	63046	\N	56.142606000000001	Республика Марий Эл, Звениговский район, с.Кокшайск, ул.Заводская, д.1а		0101000020E61000007B6649809AE84740501BD5E940124C40
54279	7	62	1199	12499	62957	\N	55.976393000000002	Республика Марий Эл, Звениговский район, с.Исменцы, ул.Молодежная, д.4		0101000020E6100000D2191879591B48408C852172FAFC4B40
54284	7	62	1199	12758	63121	\N	56.063720000000004	Республика Марий Эл, Звениговский район, д.Иркино, ул.Малое Иркино, д.65		0101000020E61000008BA4DDE863004840F20C1AFA27084C40
54268	7	62	1199	11963	63159	\N	56.114736000000001	Республика Марий Эл, Звениговский район, пос.Илеть, ул.Куйбышева, д.13	Россия, республика Марий Эл, Звениговский район, поселок Илеть	0101000020E6100000EA5910CAFB2C484041D653ABAF0E4C40
54263	7	62	1199	11587	63005	\N	55.971244529473402	Республика Марий Эл, г.Звенигово, ул.Советская, д.41	Россия, республика Марий Эл, Звениговский район, Звенигово	0101000020E6100000B0C8AF1F62014840A7B393C151FC4B40
54260	7	62	1199	11587	63008	\N	55.958457000000003	Республика Марий Эл, г.Звенигово, ул.Набережная, д.16		0101000020E6100000C5E2378595084840A7CF0EB8AEFA4B40
54266	7	62	1199	58087	63248	\N	55.945887024257402	Республика Марий Эл, Звениговский район, д.Чуваш-Отары, ул.Чуваш-Отарская, д.72а	Россия, республика Марий Эл, Звениговский район, Звенигово	0101000020E61000006BF0BE2A170A4840145B41D312F94B40
54253	7	62	1095	11266	63078	\N	56.071438999999998	Республика Марий Эл, Горномарийский район, д. Яштуга, ул. Яштугинская, д. 9а		0101000020E610000039ED2939271C47405854C4E924094C40
54230	7	62	1095	10170	63201	\N	56.131946999999997	Республика Марий Эл, Горномарийский район, д. Юнго-Кушерга, ул. Юнго-Кушерга, д. 93в		0101000020E6100000E9EE3A1BF239474014E7A8A3E3104C40
54241	7	62	1095	10713	63198	\N	56.205596	Республика Марий Эл, Горномарийский район, с. Юлъялы, ул. Вознесенская, д. 25г		0101000020E610000087C09140835D47401E1840F8501A4C40
54236	7	62	1095	10474	63070	\N	56.262787000000003	Республика Марий Эл, Горномарийский район, д. Четнаево, ул. Архипкинская, д. 54		0101000020E61000003659A31EA24D474030682101A3214C40
54257	7	62	1095	11449	62954	\N	56.246850999999999	Республика Марий Эл, Горномарийский район, д. Чекеево, ул. Центральная, д. 8		0101000020E6100000483657CD733C474011FE45D0981F4C40
54259	7	62	1095	11543	62959	\N	56.236660999999998	Республика Марий Эл, Горномарийский район, с. Усола, ул. Центральная, д. 26		0101000020E610000062BD512B4C4D47408C9E5BE84A1E4C40
54224	7	62	1095	9867	63082	\N	56.194167999999998	Республика Марий Эл, Горномарийский район, д. Тушналы, ул. Тушналы, д. 49		0101000020E6100000DB8AFD65F74C474001F73C7FDA184C40
54256	7	62	1095	11399	63120	\N	56.292743000000002	Республика Марий Эл, Горномарийский район, с. Троицкий Посад, ул. Карла Маркса, д. 45а		0101000020E610000016A58460553B47400491459A78254C40
54248	7	62	1095	11028	63072	\N	56.526600999999999	Республика Марий Эл, Горномарийский район, пос. Три Рутки, ул. Больничная, д. 8		0101000020E610000024B891B2455047403C855CA967434C40
54239	7	62	1095	10612	63115	\N	56.191558000000001	Республика Марий Эл, Горномарийский район, д. Токари, ул. Лесная, д. 8а		0101000020E610000082AE7D01BD644740C2A4F8F884184C40
54225	7	62	1095	58135	63821	\N	56.206582604339197	Республика Марий Эл, Горномарийский район, д. Пичужкино, ул. Пичужкино, д. 7	Россия, республика Марий Эл, Горномарийский район	0101000020E61000006ADE718A8E5847406D74CE4F711A4C40
54229	7	62	1095	10093	63149	\N	56.156354999999998	Республика Марий Эл, Горномарийский район, д. Пертюково, ул. Пертюково, д. 8а		0101000020E6100000E1D39CBCC82E474075C8CD7003144C40
54233	7	62	1095	10319	63150	\N	56.227989999999998	Республика Марий Эл, Горномарийский район, с. Пертнуры, ул. Пертнуры, д. 41		0101000020E6100000897AC1A73937474053E8BCC62E1D4C40
54223	7	62	1095	9799	63153	\N	56.136566999999999	Республика Марий Эл, Горномарийский район, с. Паратмары, ул. Паратмары, 76		0101000020E6100000FEEDB25F774647403E5B07077B114C40
54251	7	62	1095	11163	62955	\N	56.178904000000003	Республика Марий Эл, Горномарийский район, с. Пайгусово, ул. Новая, д. 105г		0101000020E6100000F03499F1B6264740D28F8653E6164C40
54235	7	62	1095	10404	63069	\N	56.289594999999998	Республика Марий Эл, Горномарийский район, пос. Октябрьский, ул. Красная, д. 11а		0101000020E6100000AC55BB26A4434740E50AEF7211254C40
54247	7	62	1095	10939	62987	\N	56.401375000000002	Республика Марий Эл, Горномарийский район, д. Озерки, ул. Советская, д. 12		0101000020E610000098512CB7B44447404C37894160334C40
54246	7	62	1095	10939	62982	\N	56.401375000000002	Республика Марий Эл, Горномарийский район, д. Озерки, ул. Заволжская, д. 37		0101000020E610000098512CB7B44447404C37894160334C40
54258	7	62	1095	11498	\N	\N	56.233378999999999	Республика Марий Эл, Горномарийский район, д.Носелы, ул. Носелы, д. 113		0101000020E6100000454B1E4FCB5347405E49F25CDF1D4C40
54252	7	62	1095	11200	63142	\N	56.098562000000001	Республика Марий Эл, Горномарийский район, д. Новая Слобода, ул. Школьная, д. 48а		0101000020E6100000AF601BF1640B47406E50FBAD9D0C4C40
54237	7	62	1095	10531	63165	\N	56.273400000000002	Республика Марий Эл, Горномарийский район, д. Нижние Шелаболки, ул. Нижнешелаболкинская, д. 2		0101000020E6100000766B990CC74B4740FB5C6DC5FE224C40
54255	7	62	1095	11364	63199	\N	56.309533999999999	Республика Марий Эл, Горномарийский район, д. Мумариха, ул. Набережная, д. 4		0101000020E61000008578245E9E3E4740028063CF9E274C40
54244	7	62	1095	10844	63006	\N	56.205561000000003	Республика Марий Эл, Горномарийский район, с. Микряково, ул. Центральная, д. 29		0101000020E6100000B760A92EE01D4740A22AA6D24F1A4C40
54254	7	62	1095	11293	63083	\N	56.262476999999997	Республика Марий Эл, Горномарийский район, д. Малая Юнга, ул. Центральная, д. 12		0101000020E6100000058C2E6F0E414740E179A9D898214C40
54250	7	62	1095	11117	62952	\N	56.160229999999999	Республика Марий Эл, Горномарийский район, д. Макаркино, ул. Центральная, д. 72в		0101000020E61000003C11C4793821474046EBA86A82144C40
54234	7	62	1095	10380	63045	\N	56.249986999999997	Республика Марий Эл, Горномарийский район, с. Кулаково, ул. Механизаторов, д. 2		0101000020E610000005FC1A49824647406BB6F292FF1F4C40
54238	7	62	1095	10583	63071	\N	56.161439000000001	Республика Марий Эл, Горномарийский район, с. Кузнецово, ул. Центральная, д. 22в		0101000020E6100000A3ACDF4C4C5B474044A67C08AA144C40
54240	7	62	1095	10583	63151	\N	56.161439000000001	Республика Марий Эл, Горномарийский район, с. Кузнецово, ул. Верхняя, д. 99		0101000020E6100000A3ACDF4C4C5B474044A67C08AA144C40
54222	7	62	1095	9782	63066	\N	56.123980000000003	Республика Марий Эл, Горномарийский район, с. Кожважи, ул. Кожважи, д. 11		0101000020E61000009C4F1DAB94544740D6AD9E93DE0F4C40
54228	7	62	1095	10083	63193	\N	56.201770000000003	Республика Марий Эл, Горномарийский район, с. Картуково, ул. Центральная, д. 41		0101000020E61000002D5BEB8B844247402FA86F99D3194C40
54245	7	62	1095	10895	63062	\N	56.398505999999998	Республика Марий Эл, Горномарийский район, д. Еникеево, ул. Центральная, д. 29		0101000020E6100000B153AC1A8437474040A19E3E02334C40
54232	7	62	1095	10242	63043	\N	56.226928999999998	Республика Марий Эл, Горномарийский район, с. Емешево, ул. Проезжая, д. 80		0101000020E6100000DDB419A7212C4740CAC16C020C1D4C40
54231	7	62	1095	10242	63043	\N	56.226928999999998	Республика Марий Эл, Горномарийский район, с. Емешево, ул. Проезжая, д. 77		0101000020E6100000DDB419A7212C4740CAC16C020C1D4C40
54227	7	62	1095	10021	\N	\N	56.140820994915003	Республика Марий Эл, Горномарийский район, с. Емелево, ул. Емелево, д. 29а	Россия, республика Марий Эл, Горномарийский район, село Емелево	0101000020E610000009A52F849C31474086CB2A6C06124C40
54243	7	62	1095	10795	63048	\N	56.233378999999999	Республика Марий Эл, Горномарийский район, с.Емангаши, ул.Приволжская,  99		0101000020E6100000BE6A65C22F1F47405E49F25CDF1D4C40
54226	7	62	1095	9961	62953	\N	56.168892	Республика Марий Эл, Горномарийский район, с. Еласы, ул. Октябрьская, д. 15		0101000020E610000083E0F1ED5D3B47402C47C8409E154C40
54221	7	62	1095	9716	63042	\N	56.173116999999998	Республика Марий Эл, Горномарийский район, с. Виловатово, ул. Советская, д. 3		0101000020E6100000388600E0D84D4740D9B0A6B228164C40
54249	7	62	1095	11074	63194	\N	56.212454000000001	Республика Марий Эл, Горномарийский район, д. Верхнее Акчерино, ул. Центральная, д. 8б		0101000020E6100000AC8F87BEBB274740C3F352B1311B4C40
54242	7	62	1095	10773	63073	\N	56.154364999999999	Республика Марий Эл, Горномарийский район, д. Березово, ул. Центральная, д. 38		0101000020E61000001155F833BC194740D252793BC2134C40
54206	7	62	878	9011	63146	\N	56.125836	Республика Марий Эл, Волжский район, д. Ярамор, ул. Красноармейская, д. 122А		0101000020E6100000C6F7C5A52A5D48406954E0641B104C40
54220	7	62	878	9635	62269	\N	55.989699391780398	Республика Марий Эл, Волжский район, с. Эмеково, ул. Советская, д. 8	Россия, республика Марий Эл, Волжский район, село Эмеково	0101000020E61000005D328E91EC35484024F1F274AEFE4B40
54218	7	62	878	9532	63114	\N	56.161669000000003	Республика Марий Эл, Волжский район, д. Шарибоксад, ул. Клубная, д. 3		0101000020E61000006C7C26FBE761484076E3DD91B1144C40
54201	7	62	878	8813	63040	\N	56.167473000000001	Республика Марий Эл, Волжский район, д. Чодыраял, ул. Школьная, д. 2		0101000020E6100000C15774EB3571484044FB58C16F154C40
54212	7	62	878	9300	62238	\N	55.921983453563598	Республика Марий Эл, Волжский район, д. Часовенная, ул. Школьная, д. 18А	Россия, республика Марий Эл, Волжский район, село Часовенная	0101000020E610000092E7FA3E1C2C4840E63BF88903F64B40
54209	7	62	878	9171	62951	\N	56.066946999999999	Республика Марий Эл, Волжский район, д. Учейкино, ул. Советская, д. 60		0101000020E6100000EF535568206448405CC823B891084C40
54217	7	62	878	9517	63038	\N	56.140836	Республика Марий Эл, Волжский район, с. Сотнур, ул. Центральная, д. 26		0101000020E6100000139A249694634840BB0CFFE906124C40
54214	7	62	878	9308	62267	\N	55.964075000000001	Республика Марий Эл, Волжский район, пос. Приволжский, ул. Молодежная, д. 3А		0101000020E61000006C938AC6DA35484013F241CF66FB4B40
54213	7	62	878	9308	62241	\N	55.964075000000001	Республика Марий Эл, Волжский район, пос. Приволжский, ул. Заводская, д. 3		0101000020E61000006C938AC6DA35484013F241CF66FB4B40
54211	7	62	878	9250	62941	\N	55.969062999999998	Республика Марий Эл, Волжский район, с. Помары, ул. Станционная, д. 3		0101000020E6100000AF963B33C12C4840BF61A2410AFC4B40
54204	7	62	878	8913	62236	\N	56.024607000000003	Республика Марий Эл, Волжский район, д. Полевая, ул. Новая, д. 6		0101000020E6100000809F71E1402C484058207A5226034C40
54205	7	62	878	8986	62157	\N	56.097667999999999	Республика Марий Эл, Волжский район, д. Петъялы, ул. Школьная, д. 2		0101000020E61000001EC539EAE8584840D0EE9062800C4C40
54215	7	62	878	58068	63152	\N	56.117829366035402	Республика Марий Эл, Волжский район, д. Памашенер, ул. Центральная, д. 16	Россия, республика Марий Эл, Волжский район, село Помашенер	0101000020E6100000459F8F32E26648409CC24A05150F4C40
54199	7	62	878	8697	63063	\N	56.009250000000002	Республика Марий Эл, Волжский район, д. Отымбал, ул. Учительская, д. 7		0101000020E61000009B3BFA5FAE55484077BE9F1A2F014C40
54216	7	62	878	9438	63148	\N	56.166370999999998	Республика Марий Эл, Волжский район, д. Нуршари, ул. Центральная, д. 2		0101000020E6100000861DC6A4BF6748405C001AA54B154C40
54200	7	62	878	8755	63144	\N	56.178794000000003	Республика Марий Эл, Волжский район, д. Новый Карамас, ул. Центральная, д. 27		0101000020E610000088687407B17B48404B5CC7B8E2164C40
54219	7	62	878	9607	63220	\N	55.951481999999999	Республика Марий Эл, Волжский район, с. Моркиялы, ул. Зеленая, д. 52		0101000020E61000009F3BC1FEEB404840C85D8429CAF94B40
54203	7	62	878	8891	63139	\N	56.135202999999997	Республика Марий Эл, Волжский район, пос. Кленовая Гора, ул. Пугачева, д. 1		0101000020E61000004E61A5828A36484019A9F7544E114C40
54202	7	62	878	8842	63061	\N	56.074680000000001	Республика Марий Эл, Волжский район, пос. Кичиер, ул. Лесная, д. 9		0101000020E61000005872158BDF2C484028D53E1D8F094C40
54208	7	62	878	9138	63113	\N	56.044150999999999	Республика Марий Эл, Волжский район, д. Карай, ул. Пионерская, д. 32		0101000020E61000005281936DE0524840F88A6EBDA6054C40
54207	7	62	878	9086	63190	\N	56.065092	Республика Марий Эл, Волжский район, д. Инерымбал, ул. Школьная, д. 1А		0101000020E610000073B8567BD84F4840999D45EF54084C40
54179	7	62	878	6592	62289	\N	55.852545999999997	Республика Марий Эл, г. Волжск, ул. Кабанова, д. 10 а		0101000020E61000008EB0A888D3334840F52A323A20ED4B40
54198	7	62	878	57928	62197	\N	55.982080918989901	Республика Марий Эл, Волжский район, с. Новые Параты, ул. Финская, д. 23	Россия, республика Марий Эл, Волжский район, село Большие Параты	0101000020E61000006DAE9AE788544840F18288D4B4FD4B40
54197	7	62	878	58085	63231	\N	55.960421923577698	Республика Марий Эл, Волжский район, д. Бизюргуб, ул. Заречная, д. 25	Россия, республика Марий Эл, Волжский район, село Бизергуб	0101000020E61000002AFEEF880A514840F12DAC1BEFFA4B40
54210	7	62	878	58069	63154	\N	55.960177334760303	Республика Марий Эл, Волжский район, д. Березники, ул. Лесная, д. 2	Россия, республика Марий Эл, Волжский район, село Березняки	0101000020E61000002121CA17B42648408AAF7614E7FA4B40
20475	7	61	\N	58326	64714	\N	52.608274000000002	Республика Башкортостан, Баймакский район, д.Ярмухаметово, улица Буранбая, дом 14		0101000020E61000007D5C1B2AC6E94C40E98024ECDB4D4A40
21453	7	61	\N	58690	66028	\N	52.247900999999999	Япарсаз, ул.Школьная, 19/1		0101000020E61000000E32C9C859F84C40A6D24F38BB1F4A40
22905	7	61	\N	58088	63502	\N	56.266463779723999	г. Янаул, Социалистическая, 19	Россия, республика Башкортостан, Янаульский район, Янаул	0101000020E6100000289CDD5A26774B40DAC70A7E1B224C40
22903	7	61	\N	58088	63444	\N	56.268756000000003	г. Янаул, Советская, 18		0101000020E6100000CB10C7BAB8754B40494DBB9866224C40
22898	7	61	\N	58088	63687	\N	56.272194972638097	г. Янаул, Ломоносова, 17	Россия, республика Башкортостан, Янаульский район, Янаул	0101000020E6100000CCB6D3D688764B403F912749D7224C40
22906	7	61	\N	58088	63332	\N	56.268756360349499	г. Янаул, Куйбышева, 68		0101000020E6100000170FEF39B0764B40494DBB9866224C40
22904	7	61	\N	58088	63250	\N	56.268756000000003	г. Янаул, Кирова, 66		0101000020E6100000CB10C7BAB8754B40494DBB9866224C40
22899	7	61	\N	58088	63249	\N	56.267323513624603	г. Янаул, Азина, 20	Россия, республика Башкортостан, Янаульский район, Янаул	0101000020E61000009415C3D501764B40CCB73EAC37224C40
20636	7	61	\N	58467	65088	\N	55.952317999999998	д.Ялангачево, Центральная, 17		0101000020E6100000F4A62215C6244C4031B2648EE5F94B40
21563	7	61	\N	58648	65867	\N	55.662903	Республика Башкортостан, Илишевский район, Ябалаковский сельсовет, с. Ябалаково, Т. Назмиева, 30		0101000020E6100000F01989D0081E4B40CCB56801DAD44B40
21042	7	61	58	10311	64209	\N	55.840871	с. Бураево, Энергетиков, 6		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
21805	7	61	\N	58303	64934	\N	55.625298000000001	Республика Башкортостан, Кигинский район, Кандаковский сельсовет, деревня Юсупово, Школьная, 51		0101000020E6100000F4A5B73F17374D408A20CEC309D04B40
21791	7	61	\N	58601	65689	\N	55.360981000000002	Республика Башкортостан, Кигинский район, Верхнекигинский сельсовет, деревня Юнусово, Салавата Юлаева, 61		0101000020E6100000E5B512BA4B4E4D401BBD1AA034AE4B40
21060	7	61	\N	58452	65056	\N	55.919927000000001	д. Юмакаево, Школьная, 13		0101000020E61000008C2C996379CD4B408CDAFD2AC0F54B40
21361	7	61	\N	58670	65954	\N	51.858038000000001	Республика Башкортостан, Зианчуринский район, Абзановский сельсовет, Юлдыбаево, Центральная, 15		0101000020E6100000B51B7DCC07524C40D55C6E30D4ED4940
22588	7	61	\N	58230	64433	\N	52.8549157182279	Юлдашево, Школьная, 1	Россия, республика Башкортостан, село Юлдашево	0101000020E61000001D9430D3F6974B40E06932E36D6D4A40
21309	7	61	\N	58474	65127	\N	55.395696000000001	Республика Башкортостан, Дюртюлинский район, Суккуловский сельсовет, с.Юкаликулево, Ленина, 6		0101000020E6100000E068C70DBF7D4B403A94A12AA6B24B40
22556	7	61	\N	8159	2231	\N	54.655729999999998	Республика Башкортостан, Уфимский район, д. Шмидтово, Мира, 2	Россия, республика Башкортостан, деревня Шмидтово, улица Мира, 2	0101000020E61000004B22FB20CB184C40C780ECF5EE534B40
22338	7	61	\N	8159	2231	\N	54.655729999999998	453154, РБ Стерлитамакский район, с. Бельское, ул. Мира д.2	Россия, республика Башкортостан, деревня Шмидтово, улица Мира, 2	0101000020E61000004B22FB20CB184C40C780ECF5EE534B40
20295	7	61	\N	8159	66375	\N	54.653390999999999	Республика Башкортостан, Альшеевский район, Аксеновский сельсовет, с. Ким, Мира, 14б		0101000020E610000020B8CA1308194C401840F850A2534B40
20943	7	61	\N	58313	64645	\N	54.902993000000002	д.Шарлык, Школьная, 7		0101000020E61000001EDD088B8A924B402BC24D4695734B40
21961	7	61	\N	58207	64318	\N	54.958481999999997	Республика Башкортостан, Кушнаренковский район, с.Шарипово, Султанова, 13		0101000020E610000055DAE21A9FC74B40FFE6C589AF7A4B40
20330	7	61	\N	58604	65707	\N	54.004553999999999	Республика Башкортостан, Альшеевский район, Шафрановский сельсовет, с. Чуракаево, Салавата Юлаева, 26б		0101000020E6100000E7E3DA5031624B407288B83995004B40
22202	7	61	\N	58571	65581	\N	53.701571999999999	деревня Чураево, улица Демская, дом 26		0101000020E6100000008DD2A57F494B4008E57D1CCDD94A40
22523	7	61	\N	58455	65061	\N	54.402816999999999	с.Чукадыбашево, Советская, 58		0101000020E610000051853FC39B154B40ECA2E8818F334B40
21482	7	61	\N	58482	65158	\N	54.650869999999998	Республика Башкортостан, Иглинский район, Кальтовский сельсовет, д. Чкаловское, Цветочная, 30		0101000020E6100000F71E2E39EE484C4048F949B54F534B40
21282	7	61	\N	58450	65054	\N	55.542228000000001	Республика Башкортостан, Дюртюлинский район, Исмаиловский сельсовет, с.Чишма, Молодежная, 3		0101000020E6100000A4A5F27684474B40DD7C23BA67C54B40
20480	7	61	\N	58365	64827	\N	52.653278999999998	Республика Башкортостан, Баймакский район, д.Чингизово, улица Х.Ахметова, дом 20		0101000020E61000008E3EE60302014D40F01472A59E534A40
22245	7	61	\N	8386	6538	\N	54.602403000000002	д.Нур, Дружная,Здание школы	Россия, республика Башкортостан, деревня Чесноковка, улица Нур, 1	0101000020E6100000D0D38041D2F94B409301A08A1B4D4B40
20434	7	61	\N	8386	66940	\N	54.603628	Республика Башкортостан, Аургазинский район, д.Турсугали, ул.Гафури, 14		0101000020E61000002C465D6BEFF94B409679ABAE434D4B40
22747	7	61	\N	58176	64276	\N	55.143317000000003	село Чекмагуш, Октябрьская, 1		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22749	7	61	\N	58176	64153	\N	55.143317000000003	село Чекмагуш, Мира, 28		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22753	7	61	\N	58176	64400	\N	55.143317000000003	село Чекмагуш, 70-лет Октября, 99		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22248	7	61	\N	58472	65104	\N	55.299593000000002	д.Чандар, Симская, 49		0101000020E610000046B41D53775B4C40268E3C1059A64B40
21861	7	61	\N	58653	65880	\N	52.797226000000002	Республика Башкортостан, Кугарчинский район, Ялчинский сельсовет, д. Худайбердино, Псянчина, 7		0101000020E6100000C78157CB9D054C40ADC266800B664A40
22064	7	61	\N	58435	65006	\N	53.063611999999999	Республика Башкортостан, Мелеузовский район, Александровский сельсовет, с. Хлебодаровка, Центральная, 38, А		0101000020E6100000E8BB5B59A2294C400BD1217024884A40
20275	7	61	\N	58576	65603	\N	53.504145999999999	с.Хамитово, ул.Сагадатова, 22		0101000020E610000099D87C5C1BFE4C4061342BDB87C04A40
22654	7	61	\N	16756	66408	\N	54.570486847019701	Республика Башкортостан, Федоровский район, Каралачикский сельсовет с.Балыклыбашево, переулок Овражный, 7		0101000020E61000001250E10852FB4B4086E5CFB705494B40
20974	7	61	\N	16756	66377	\N	54.5715608630899	дер. Федоровка, Центральная, 16		0101000020E6100000D481ACA756FB4B40A4552DE928494B40
22736	7	61	\N	16756	65644	\N	54.570644999999999	с. Федоровка, Мусы Гареева, 22		0101000020E6100000DAE731CA33FB4B401E5036E50A494B40
22183	7	61	\N	58712	66135	\N	53.554101000000003	село Уязыбашево, улица Центральная, дом 5		0101000020E61000005D34643C4A874B4028D714C8ECC64A40
22629	7	61	\N	58097	63876	\N	54.305798307962199	г.Учалы - СОШ №2, пер.Школьный, 6		0101000020E6100000D57ABFD18EB54D4053978C6324274B40
22632	7	61	\N	58097	63860	\N	54.301384073803902	г.Учалы - УГЭС, Энергетиков, 1		0101000020E6100000B5A50EF27AB84D40D2C43BC093264B40
22631	7	61	\N	58097	63860	\N	54.306701782529501	г.Учалы - БГУ, Энергетиков, 29		0101000020E61000009885764EB3B64D4014CFD90242274B40
22625	7	61	\N	58097	64530	\N	54.3011802379364	с. Учалы - БГ, Чкалова, 25	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E6100000D026874F3AB74D40CA1AF5108D264B40
22628	7	61	\N	58097	63988	\N	54.313272058861202	г.Учалы - Башкиргеология, Фабричный переулок, 3	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E61000009F20B1DD3DB44D405260014C19284B40
22637	7	61	\N	58097	63442	\N	54.305199000000002	г.Учалы - СОШ №1, Муртазина, 20		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22645	7	61	\N	58097	63978	\N	54.305199000000002	г.Учалы - Комбинатский дом, М.Горького, 2/1	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E6100000392A37514BB54D40CEE2C5C210274B40
21047	7	61	58	10311	63436	\N	55.840871	с. Бураево, Чкалова, 10		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
22647	7	61	\N	58097	63806	\N	54.286117698179197	г.Учалы - Ровесник, М.Горького, 6	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E6100000C632FD12F1B84D400266BE839F244B40
22642	7	61	\N	58097	63806	\N	54.312322954451702	"г.Учалы - ""Дом Детского Творчества"", М.Горького, 1а"		0101000020E6100000392A37514BB54D40F1643733FA274B40
22636	7	61	\N	58097	63556	\N	54.305199000000002	г.Учалы - гл.корпус УУИиК, Ленинского Комсомола, 6		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22648	7	61	\N	58097	63304	\N	54.305199000000002	г.Учалы - СОШ №3, Ленина, 44а		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22638	7	61	\N	58097	63825	\N	54.302430787858199	г.Учалы - СОШ № 10, Кирова, 6		0101000020E610000066F4A3E194B74D40F6251B0FB6264B40
22640	7	61	\N	58097	63619	\N	54.305199000000002	г.Учалы - СОШ №5, Башкортостана, 15		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22624	7	61	\N	58097	64378	\N	54.305199000000002	с. Учалы - ДШИ, Багаутдинова, 79		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22649	7	61	\N	58097	63690	\N	54.305199000000002	г.Учалы - Реабилитационный центр, Ахметгалина, 28		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
19656	7	61	\N	59	\N	\N	54.7895437524312	Республика Башкортостан, город Уфа, Калининский район, УМЗ Б	Россия, республика Башкортостан, Уфа, Калининский район	0101000020E610000082380F2730134C4063601DC70F654B40
19783	7	61	\N	59	179	\N	54.761980999999999	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 26/1	Россия, республика Башкортостан, Уфа, улица Юрия Гагарина, 26/1	0101000020E6100000BAA46ABB09084C403196E99788614B40
19780	7	61	\N	59	179	\N	54.766474000000002	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 15/1	Россия, республика Башкортостан, Уфа, улица Юрия Гагарина, 15/1	0101000020E6100000193BE12538074C40FE9DEDD11B624B40
19604	7	61	\N	59	6406	\N	54.709902	Республика Башкортостан, город Уфа, Демский район, Ухтомского, 29	Россия, республика Башкортостан, Уфа, улица Ухтомского, 29	0101000020E6100000E78D93C2BCE94B40B8AE9811DE5A4B40
19602	7	61	\N	59	6406	\N	54.712575999999999	Республика Башкортостан, город Уфа, Демский район, Ухтомского, 28	Россия, республика Башкортостан, Уфа, улица Ухтомского, 28	0101000020E610000065C5707500EA4B400EF5BBB0355B4B40
21970	7	61	\N	59	4284	\N	54.818449000000001	Куюргазинский район, с.Айсуак, ул. Совхозная, 3	Россия, республика Башкортостан, Уфа, улица Совхозная, 3	0101000020E6100000809D9B36E3144C40D238D4EFC2684B40
19719	7	61	\N	59	7673	\N	54.602412999999999	Республика Башкортоста, город Уфа, Кировский район, Светлая, 39	Россия, республика Башкортостан, Уфа, улица Светлая, 39	0101000020E6100000AC55BB26A4F74B40B6D782DE1B4D4B40
19663	7	61	\N	59	7046	\N	54.727001000000001	Республика Башкортостан, город Уфа, Кировский район, Свердлова, 55	Россия, республика Башкортостан, Уфа, улица Свердлова, 55	0101000020E6100000D7DCD1FF72F74B406494675E0E5D4B40
19831	7	61	\N	59	952	\N	54.820701	Республика Башкортостан, город Уфа, Орджоникидзевский район, Репина, 6	Россия, республика Башкортостан, Уфа, улица Репина, 6	0101000020E6100000EE27637C980B4C40B265F9BA0C694B40
19676	7	61	\N	59	1892	\N	54.719700000000003	Республика Башкортостан, город Уфа, Кировский район, Пушкина, 103 А	Россия, республика Башкортостан, Уфа, улица Пушкина, 103а	0101000020E6100000F1F5B52E35FA4B4032772D211F5C4B40
19664	7	61	\N	59	1892	\N	54.723944000000003	Республика Башкортостан, город Уфа, Кировский район, Пушкина, 67	Россия, республика Башкортостан, Уфа, улица Пушкина, 67	0101000020E610000012A0A696ADF74B4056116E32AA5C4B40
19860	7	61	\N	59	1429	\N	54.745719000000001	Республика Башкортостан, город Уфа, Советский район, Пархоменко, 155/2	Россия, республика Башкортостан, Уфа, улица Пархоменко, 155/2	0101000020E610000029B16B7BBBFB4B40BF805EB8735F4B40
19781	7	61	\N	59	15358	\N	54.761310999999999	Республика Башкортостан, город Уфа, Октябрьский район, Н.Ковшовой, 10/1	Россия, республика Башкортостан, Уфа, улица Натальи Ковшовой, 10/1	0101000020E6100000E17B7F83F6064C40E38A8BA372614B40
19603	7	61	\N	59	15709	\N	54.712460999999998	Республика Башкортостан, город Уфа, Демский район, Мусы Джалиля, 74/1	Россия, республика Башкортостан, Уфа, Демский район, улица Мусы Джалиля, 74/1	0101000020E61000000DDE57E542E94B4075560BEC315B4B40
19894	7	61	\N	59	61	\N	54.723117000000002	Республика Башкортостан, город Уфа, Советский район, Менделеева, 193	Россия, республика Башкортостан, Уфа, улица Менделеева, 193	0101000020E61000009AB67F65A5014C4040170D198F5C4B40
19893	7	61	\N	59	61	\N	54.723564000000003	Республика Башкортостан, город Уфа, Советский район, Менделеева, 177/3 корпус 1	Россия, республика Башкортостан, Уфа, улица Менделеева, 177/3	0101000020E6100000ACE3F8A1D2004C400F48C2BE9D5C4B40
19691	7	61	\N	59	61	\N	54.720058999999999	Республика Башкортостан, город Уфа, Кировский район, Менделеева, 146/1	Россия, республика Башкортостан, Уфа, улица Менделеева, 146/1	0101000020E6100000F7E80DF791014C406118B0E42A5C4B40
19738	7	61	\N	59	2256	\N	54.743796000000003	Республика Башкортостан, город Уфа, Ленинский район, Лесозаводская, 1/1	Россия, республика Башкортостан, Уфа, улица Лесозаводская, 1/1	0101000020E6100000A1D634EF38F34B40A47213B5345F4B40
19895	7	61	\N	59	1894	\N	54.718811000000002	Республика Башкортостан, город Уфа, Советский район, Красноводская, 13	Россия, республика Башкортостан, Уфа, улица Красноводская, 13	0101000020E6100000E7C6F48425004C40A680B4FF015C4B40
19876	7	61	\N	59	130	\N	54.746372999999998	Республика Башкортостан, город Уфа, Советский район, Комсомольская, 29	Россия, республика Башкортостан, Уфа, улица Комсомольская, 29	0101000020E610000059A31EA2D1FF4B4007CF8426895F4B40
19627	7	61	\N	59	63908	\N	54.826261000000002	Республика Башкортостан, город Уфа, Калининский район, Чехова, 1		0101000020E61000009A99999999174C40EA7AA2EBC2694B40
21330	7	61	\N	59	15937	\N	54.730978	Республика Башкортостан, Ермекеевский район, Елань-Чишминский сельсовет, с. Елань-Чишмы, Кирова, 12	Россия, республика Башкортостан, Уфа, Кировский район, улица Кирова, 8	0101000020E6100000E7374C3448F94B40390CE6AF905D4B40
19677	7	61	\N	59	15937	\N	54.728332000000002	Республика Башкортостан, город Уфа, Кировский район, Кирова, 65	Россия, республика Башкортостан, Уфа, Кировский район, улица Кирова, 65	0101000020E610000034D93F4F03FC4B40AD50A4FB395D4B40
19643	7	61	\N	59	6875	\N	54.802557	Республика Башкортостан, город Уфа, Калининский район, Хакимова, 7	Россия, республика Башкортостан, Уфа, улица Карима Хакимова, 7	0101000020E610000073D87DC7F00E4C4083161230BA664B40
19649	7	61	\N	59	1825	\N	54.806998999999998	Республика Башкортостан, город Уфа, Калининский район, Интернациональная, 123	Россия, республика Башкортостан, Уфа, улица Интернациональная, 123	0101000020E61000009E23F25D4A0D4C40CD7344BE4B674B40
19601	7	61	\N	59	6446	\N	54.712694999999997	Республика Башкортостан, город Уфа, Демский район, Дагестанская, 31/1	Россия, республика Башкортостан, Уфа, улица Дагестанская, 31/1	0101000020E610000014984EEB36EA4B40E882FA96395B4B40
19619	7	61	\N	59	6635	\N	54.776133999999999	Республика Башкортостан, город Уфа, Калининский район, Георгия Мушникова, 5/2	Россия, республика Башкортостан, Уфа, улица Георгия Мушникова, 5/2	0101000020E61000001CB1169F020E4C4026A8E15B58634B40
19692	7	61	\N	59	7358	\N	54.716138000000001	Республика Башкортостан, город Уфа, Кировский район, Ген. Горбатова, 11	Россия, республика Башкортостан, Уфа, улица Генерала Горбатова, 11	0101000020E6100000780DFAD2DB014C4020B6F468AA5B4B40
21449	7	61	\N	59	15743	\N	54.729937999999997	Шанск, ул.Гаражная, 17	Россия, республика Башкортостан, Уфа, улица Гаражная, 15	0101000020E61000008750A5660FF64B40C70DBF9B6E5D4B40
19900	7	61	\N	59	1971	\N	54.719949999999997	Республика Башкортостан, город Уфа, Советский район, Бакалинская, 66/1	Россия, республика Башкортостан, Уфа, улица Бакалинская, 66/1	0101000020E61000008A027D224FFE4B40AA605452275C4B40
19897	7	61	\N	59	1922	\N	54.715805000000003	Республика Башкортостан, город Уфа, Советский район, Акназарова, 24 (учебный корпус)	Россия, республика Башкортостан, Уфа, улица Акназарова, 24	0101000020E6100000A01B9AB2D3FF4B401AA88C7F9F5B4B40
19903	7	61	\N	59	1486	\N	54.735137000000002	Республика Башкортостан, город Уфа, Советский район, 50-летия Октября, 16/1	Россия, республика Башкортостан, Уфа, улица 50-летия Октября, 16/1	0101000020E610000028D4D347E0FB4B402F8A1EF8185E4B40
19774	7	61	\N	59	8	\N	54.748598000000001	Республика Башкортостан, город Уфа, Октябрьский район, 50 лет СССР, 36	Россия, республика Башкортостан, Уфа, улица 50 Лет СССР, 36	0101000020E6100000B70DA32078024C40EEEC2B0FD25F4B40
19875	7	61	\N	59	63889	\N	54.751778000000002	Республика Башкортостан, город Уфа, Советский район, проспект Октября, 33		0101000020E6100000E84D452A8CFF4B4018EDF1423A604B40
19771	7	61	\N	59	63974	\N	54.742927999999999	Республика Башкортостан, город Уфа, Октябрьский район, им. города Галле, 9		0101000020E6100000118E59F624004C402FA4C343185F4B40
19794	7	61	\N	59	63813	\N	54.779364000000001	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 74/1		0101000020E610000005508C2C99094C4002D71533C2634B40
19789	7	61	\N	59	63813	\N	54.769756999999998	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 48/1		0101000020E6100000FF91E9D0E9094C40FC6EBA6587624B40
19788	7	61	\N	59	63813	\N	54.770052999999997	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 37/1		0101000020E61000007D40A03369094C40E597C11891624B40
19786	7	61	\N	59	63813	\N	54.763824999999997	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 36/2		0101000020E610000040506EDBF7084C40006F8104C5614B40
19785	7	61	\N	59	63813	\N	54.766458999999998	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 25/1		0101000020E610000065C39ACAA2084C40C85C19541B624B40
19782	7	61	\N	59	63813	\N	54.762006999999997	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 24/1		0101000020E610000083C2A04CA3074C405A29047289614B40
19779	7	61	\N	59	63813	\N	54.765332000000001	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 15		0101000020E610000051F4C0C760074C40884A2366F6614B40
19830	7	61	\N	59	63769	\N	54.900075599822102	Республика Башкортостан, город Уфа, Орджоникидзевский район, посёлок Новые Черкассы, Юрия Гагарина, 11	Россия, республика Башкортостан, Уфа, поселок Новые Черкассы, улица Юрия Гагарина, 11/1	0101000020E610000020B8CA1308134C400EF5BBB035734B40
19687	7	61	\N	59	66934	\N	54.665354000000001	Республика Башкортостан, город Уфа, Кировский район, Элеваторная, 7/2		0101000020E61000002B508BC1C3F84B40A321E3512A554B40
19809	7	61	\N	59	66949	\N	54.790469000000002	Республика Башкортостан, город Уфа, Орджоникидзевский район, Ш. Руставели, 18а		0101000020E6100000C28A53AD85054C403CC093162E654B40
19947	7	61	\N	59	2665	\N	54.702379999999998	"Республика Башкортостан, ЗАТО ""город Межгорье"", Периулок Школьный, 1"	Россия, республика Башкортостан, Уфа, Школьный переулок, 3	0101000020E61000001F6ADB300AFA4B40A7AE7C96E7594B40
19777	7	61	\N	59	63861	\N	54.758915999999999	Республика Башкортостан, город Уфа, Октябрьский район, Шафиева, 31/2		0101000020E61000003F3A75E5B3024C40A034D42824614B40
19750	7	61	\N	59	63861	\N	54.766162999999999	Республика Башкортостан, город Уфа, Октябрьский район, Шафиева, 1		0101000020E6100000F0880AD5CDFF4B40DF3312A111624B40
19744	7	61	\N	59	63905	\N	54.792681000000002	Республика Башкортостан, город Уфа, Ленинский район, Чкалова, 110		0101000020E6100000871744A4A6EF4B408E942D9276654B40
20978	7	61	\N	59	65423	\N	54.929198	д. Аркаул, Чишминская, 32		0101000020E610000086E81038120E4C401AC1C6F5EF764B40
19729	7	61	\N	59	63837	\N	54.732506000000001	Республика Башкортостан, город Уфа, Ленинский район, Чернышевского, 25а		0101000020E610000024D3A1D3F3F64B40D80FB1C1C25D4B40
19675	7	61	\N	59	63837	\N	54.725847000000002	Республика Башкортостан, город Уфа, Кировский район, Чернышевского, 141		0101000020E6100000D88349F1F1FB4B402A73F38DE85C4B40
19674	7	61	\N	59	63837	\N	54.725695999999999	Республика Башкортостан, город Уфа, Кировский район, Чернышевского, 145		0101000020E6100000292499D53BFC4B40446B459BE35C4B40
19641	7	61	\N	59	63827	\N	54.806075999999997	Республика Башкортостан, город Уфа, Калининский район, Черниковская, 46/А		0101000020E610000059C0046EDD0F4C40950B957F2D674B40
19638	7	61	\N	59	63827	\N	54.808337999999999	Республика Башкортостан, город Уфа, Калининский район, Черниковская, 89		0101000020E6100000419C871398104C40990E9D9E77674B40
19865	7	61	\N	59	63957	\N	54.739336999999999	Республика Башкортостан, город Уфа, Советский район, Цюрупы, 126		0101000020E61000000B60CAC001FB4B4083DC4598A25E4B40
19686	7	61	\N	59	64457	\N	54.619290999999997	Республика Башкортостан, город Уфа, Кировский район, Цветы Башкирии, 2/3		0101000020E6100000EFC682C2A0024C4083DA6FED444F4B40
19672	7	61	\N	59	63909	\N	54.728737000000002	Республика Башкортостан, город Уфа, Кировский район, Худайбердина, 15		0101000020E61000008BFB8F4C87FA4B404D310741475D4B40
19911	7	61	\N	59	63870	\N	54.733347999999999	Республика Башкортостан, город Уфа, Советский район, Харьковская, 121		0101000020E610000075AC527AA6FD4B40234BE658DE5D4B40
19890	7	61	\N	59	1622	\N	54.732630999999998	Республика Башкортостан, город Уфа, Советский район, бульвар Хадии Давлетшиной, 34	Россия, республика Башкортостан, Уфа, Хадии Давлетшиной бульвар, 34	0101000020E610000032CA332F87FF4B40948444DAC65D4B40
19874	7	61	\N	59	1622	\N	54.733936	Республика Башкортостан, город Уфа, Советский район, бульвар Хадии Давлетшиной, 28	Россия, республика Башкортостан, Уфа, Хадии Давлетшиной бульвар, 28	0101000020E6100000F1F274AE28FF4B40B4AD669DF15D4B40
19626	7	61	\N	59	63934	\N	54.799008000000001	Республика Башкортостан, город Уфа, Калининский район, Фурманова, 39		0101000020E6100000FC389A232B134C40069FE6E445664B40
19615	7	61	\N	59	63916	\N	54.782350000000001	Республика Башкортостан, город Уфа, Калининский район, Ферина, 14/1		0101000020E61000000EDAAB8F87104C404703780B24644B40
19614	7	61	\N	59	63916	\N	54.781523999999997	Республика Башкортостан, город Уфа, Калининский район, Ферина, 19/1		0101000020E61000005BB6D61709114C4001857AFA08644B40
19595	7	61	\N	59	63958	\N	54.704107	Республика Башкортостан, город Уфа, Демский район, Ухтомского, 12		0101000020E6100000DD0BCC0A45EA4B403DF19C2D205A4B40
19768	7	61	\N	59	63879	\N	54.783658000000003	Республика Башкортостан, город Уфа, Октябрьский район, Уфимское шоссе, 20		0101000020E61000008D7BF31B26064C40D89FC4E74E644B40
19829	7	61	\N	59	63927	\N	54.822926000000002	Республика Башкортостан, город Уфа, Орджоникидзевский район, Ульяновых, 50		0101000020E610000007F01648500A4C409983A0A355694B40
19827	7	61	\N	59	63927	\N	54.819071999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Ульяновых, 38		0101000020E610000090696D1ADB094C40DF88EE59D7684B40
19815	7	61	\N	59	63927	\N	54.813827000000003	Республика Башкортостан, город Уфа, Орджоникидзевский район, Ульяновых, 13/1		0101000020E6100000A777F17EDC084C4008CDAE7B2B684B40
19616	7	61	\N	59	6587	\N	54.781689999999998	Республика Башкортостан, город Уфа, Калининский район, Тухвата Янаби, 59/2	Россия, республика Башкортостан, Уфа, Тухвата Янаби бульвар, 59/2	0101000020E6100000BF60376C5B104C401CCEFC6A0E644B40
19613	7	61	\N	59	6587	\N	54.776891999999997	Республика Башкортостан, город Уфа, Калининский район, Тухвата Янаби, 49/4	Россия, республика Башкортостан, Уфа, Тухвата Янаби бульвар, 49/4	0101000020E61000005325CADE52104C401343723271634B40
19667	7	61	\N	59	63891	\N	54.715608000000003	Республика Башкортостан, город Уфа, Кировский район, Тукаева, 39		0101000020E6100000965AEF37DAF94B40C460FE0A995B4B40
19621	7	61	\N	59	63873	\N	54.782089999999997	Республика Башкортостан, город Уфа, Калининский район, Транспортная, 50/4		0101000020E61000003274ECA0120F4C40AA436E861B644B40
19618	7	61	\N	59	63873	\N	54.777115999999999	Республика Башкортостан, город Уфа, Калининский район, Транспортная, 34/1		0101000020E61000006806F1811D0F4C4063997E8978634B40
19617	7	61	\N	59	63873	\N	54.779072999999997	Республика Башкортостан, город Уфа, Калининский район, Транспортная, 40/1		0101000020E610000017D9CEF7530F4C402A1900AAB8634B40
19655	7	61	\N	59	66461	\N	54.797860999999997	Республика Башкортостан, город Уфа, Калининский район, Трамвайная, 10		0101000020E61000003E5B07077B0B4C407EE02A4F20664B40
19848	7	61	\N	59	63954	\N	54.836559999999999	Республика Башкортостан, город Уфа, Орджоникидзевский район, Таманская, 47		0101000020E6100000DB89929048134C402592E865146B4B40
19598	7	61	\N	59	63900	\N	54.706620000000001	Республика Башкортостан, город Уфа, Демский район, Таллинская, 25		0101000020E610000072C0AE264FEB4B408A592F86725A4B40
19596	7	61	\N	59	63900	\N	54.705080000000002	Республика Башкортостан, город Уфа, Демский район, Таллинская, 17		0101000020E6100000F17EDC7EF9EA4B402788BA0F405A4B40
19592	7	61	\N	59	63900	\N	54.701511000000004	Республика Башкортостан, город Уфа, Демский район, Таллинская, 3		0101000020E610000056D5CBEF34EB4B406364C91CCB594B40
19839	7	61	\N	59	63855	\N	54.814428999999997	Республика Башкортостан, город Уфа, Орджоникидзевский район, Суворова, 35		0101000020E6100000605B3FFD670F4C40FDF49F353F684B40
19640	7	61	\N	59	63855	\N	54.802759999999999	Республика Башкортостан, город Уфа, Калининский район, Суворова, 10		0101000020E6100000A5BF97C283104C40BB44F5D6C0664B40
19696	7	61	\N	59	63892	\N	54.700246999999997	Республика Башкортостан, город Уфа, Кировский район, Степана Кувыкина, 5/2		0101000020E610000069C6A2E9ECFE4B40A10F96B1A1594B40
19690	7	61	\N	59	63892	\N	54.707234	Республика Башкортостан, город Уфа, Кировский район, Степана Кувыкина, 29/1		0101000020E61000009FE8BAF083FF4B40444FCAA4865A4B40
19901	7	61	\N	59	63816	\N	54.718654999999998	Республика Башкортостан, город Уфа, Советский район, Степана Злобина, 1		0101000020E6100000535C55F65DFF4B40AE0D15E3FC5B4B40
19896	7	61	\N	59	63816	\N	54.719164999999997	Республика Башкортостан, город Уфа, Советский район, Степана Злобина, 22/2		0101000020E6100000F98381E7DEFF4B40C3B645990D5C4B40
19769	7	61	\N	59	63828	\N	54.777831999999997	Республика Башкортостан, город Уфа, Октябрьский район, Станиславского, 43/1		0101000020E6100000637D03931B074C4021E4BCFF8F634B40
19631	7	61	\N	59	63887	\N	54.767477	Республика Башкортостан, город Уфа, Калининский район, Стадионная, 11		0101000020E610000059A5F44C2F1D4C4052B7B3AF3C624B40
19630	7	61	\N	59	63887	\N	54.767467000000003	Республика Башкортостан, город Уфа, Калининский район, Стадионная, 9		0101000020E6100000CD91955F061D4C402FE1D05B3C624B40
19654	7	61	\N	59	63950	\N	54.815092999999997	Республика Башкортостан, город Уфа, Калининский район, Спартака, 13		0101000020E61000007F50172994094C406919A9F754684B40
19688	7	61	\N	59	63977	\N	54.708472	Республика Башкортостан, город Уфа, Кировский район, Сочинская, 15		0101000020E610000033FCA71B28FC4B40DC10E335AF5A4B40
19709	7	61	\N	59	63933	\N	54.696745999999997	Республика Башкортостан, город Уфа, Кировский район, С. Перовской, 21/4		0101000020E610000053CF8250DEFF4B4035CF11F92E594B40
19702	7	61	\N	59	63933	\N	54.698597999999997	Республика Башкортостан, город Уфа, Кировский район, С.Перовской, 75		0101000020E61000005C57CC086FFF4B408786C5A86B594B40
19628	7	61	\N	59	63910	\N	54.825436000000003	Республика Башкортостан, город Уфа, Калининский район, Сосновская, 1/3		0101000020E61000008D9AAF928F174C40757808E3A7694B40
19796	7	61	\N	59	63780	\N	54.617440999999999	Республика Башкортостан, город Уфа, Октябрьский район, с.Нагаево, Советская, 13/1		0101000020E610000072BF4351A00D4C40D21A834E084F4B40
19823	7	61	\N	59	64217	\N	54.7251841181427	Республика Башкортостан, город Уфа, Орджоникидзевский район, Советская, 54		0101000020E61000008E7747C66AF94B408ECA4DD4D25C4B40
19633	7	61	\N	59	63888	\N	54.786524	Республика Башкортостан, город Уфа, Калининский район, Советов, 27		0101000020E61000009772BED87B1D4C4072C284D1AC644B40
19803	7	61	\N	59	531	\N	54.790551999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Бульвар Славы, 6	Россия, республика Башкортостан, Уфа, Славы бульвар, 6	0101000020E61000009180D1E5CD034C40C9E4D4CE30654B40
19778	7	61	\N	59	63878	\N	54.770121000000003	Республика Башкортостан, город Уфа, Октябрьский район, Сипайловская, 14		0101000020E610000058FFE7305F064C403E7B2E5393624B40
19733	7	61	\N	59	63858	\N	54.747760999999997	Республика Башкортостан, город Уфа, Ленинский район, Силикатная, 3		0101000020E6100000AAB9DC60A8F54B40B41CE8A1B65F4B40
19624	7	61	\N	59	63871	\N	54.787671000000003	Республика Башкортостан, город Уфа, Калининский район, Сельская Богородская, 37		0101000020E61000007784D38217114C40FA804067D2644B40
19623	7	61	\N	59	63871	\N	54.786814999999997	Республика Башкортостан, город Уфа, Калининский район, Сельская Богородская, 45/1		0101000020E6100000AE47E17A14104C4049809A5AB6644B40
19814	7	61	\N	59	63982	\N	54.812545999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Северодвинская, 22		0101000020E61000000B45BA9F53084C40703FE08101684B40
19843	7	61	\N	59	63884	\N	54.819164999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Свободы, 44		0101000020E610000057410C74ED0D4C4090831266DA684B40
19647	7	61	\N	59	63884	\N	54.813557000000003	Республика Башкортостан, город Уфа, Калининский район, Свободы, 24/1		0101000020E6100000C8D3F203570D4C404837C2A222684B40
19662	7	61	\N	59	63936	\N	54.727260999999999	Республика Башкортостан, город Уфа, Кировский район, Свердлова, 51		0101000020E61000007C6473D53CF74B40005471E3165D4B40
20521	7	61	\N	59	717	\N	54.717937999999997	Республика Башкортостан, Баймакский район, с.Семеновское, улица С.Юлаева, дом 25	Россия, республика Башкортостан, Уфа, Салавата Юлаева проспект, 27а	0101000020E6100000410FB56D18FB4B401F477364E55B4B40
19883	7	61	\N	59	63932	\N	54.725045999999999	Республика Башкортостан, город Уфа, Советский район, Сагита Агиша, 16		0101000020E6100000105D50DF32014C403D0CAD4ECE5C4B40
19882	7	61	\N	59	63932	\N	54.724603999999999	Республика Башкортостан, город Уфа, Советский район, Сагита Агиша, 16/1		0101000020E6100000D7C0560916014C408046E9D2BF5C4B40
19811	7	61	\N	59	63862	\N	54.782563000000003	Республика Башкортостан, город Уфа, Орджоникидзевский район, ул. Российская, 31		0101000020E610000082902C6002054C40A3073E062B644B40
19806	7	61	\N	59	63862	\N	54.785500999999996	Республика Башкортостан, город Уфа, Орджоникидзевский район, Российская, 54		0101000020E6100000DFC2BAF1EE044C40D6FCF84B8B644B40
19767	7	61	\N	59	63862	\N	54.780391999999999	Республика Башкортостан, город Уфа, Октябрьский район, Российская, 37		0101000020E61000000D54C6BFCF044C40AF0793E2E3634B40
19766	7	61	\N	59	63862	\N	54.779198000000001	Республика Башкортостан, город Уфа, Октябрьский район, Российская, 41/3		0101000020E61000000C772E8CF4044C40E78D93C2BC634B40
19765	7	61	\N	59	63862	\N	54.7790084403821	Республика Башкортостан, город Уфа, Октябрьский район, Российская, 80	Россия, республика Башкортостан, Уфа, улица Российская, 80	0101000020E6100000EE073C3080044C4043A9BD88B6634B40
19764	7	61	\N	59	63862	\N	54.774036000000002	Республика Башкортостан, город Уфа, Октябрьский район, Российская, 90		0101000020E61000008AE5965643044C409DF6949C13634B40
19762	7	61	\N	59	63862	\N	54.769767000000002	Республика Башкортостан, город Уфа, Октябрьский район, Российская, 163/1		0101000020E61000005C548B8862044C4020459DB987624B40
19761	7	61	\N	59	63862	\N	54.766724000000004	Республика Башкортостан, город Уфа, Октябрьский район, Российская, 171/1		0101000020E610000088B839950C044C407787140324624B40
19760	7	61	\N	59	63862	\N	54.769902000000002	Республика Башкортостан, город Уфа, Октябрьский район, Российская, 100/3		0101000020E6100000FC71FBE593034C40009013268C624B40
19867	7	61	\N	59	63859	\N	54.748598000000001	Республика Башкортостан, город Уфа, Советский район, Рихарда Зорге, 10/1		0101000020E610000021E868554BFE4B40EEEC2B0FD25F4B40
19751	7	61	\N	59	63859	\N	54.761566000000002	Республика Башкортостан, город Уфа, Октябрьский район, Рихарда Зорге, 50		0101000020E61000008099EFE027004C406EDFA3FE7A614B40
19748	7	61	\N	59	63859	\N	54.755637999999998	Республика Башкортостан, город Уфа, Октябрьский район, Рихарда Зорге, 27		0101000020E6100000431A1538D9FE4B40B3CEF8BEB8604B40
19747	7	61	\N	59	63859	\N	54.752899999999997	Республика Башкортостан, город Уфа, Октябрьский район, Рихарда Зорге, 17/1		0101000020E6100000B5A679C729FE4B404694F6065F604B40
19914	7	61	\N	59	63824	\N	54.729957438218001	Республика Башкортостан, город Уфа, Советский район, Революционная, 156/1	Россия, республика Башкортостан, Уфа, улица Революционная, 156	0101000020E61000009414580053FE4B403E3E213B6F5D4B40
19910	7	61	\N	59	63824	\N	54.732469999999999	Республика Башкортостан, город Уфа, Советский район, Революционная, 169		0101000020E61000008ECA4DD4D2FC4B408BA6B393C15D4B40
19908	7	61	\N	59	63824	\N	54.732531999999999	Республика Башкортостан, город Уфа, Советский район, Революционная, 171		0101000020E6100000FD15325706FD4B4001A3CB9BC35D4B40
19887	7	61	\N	59	63824	\N	54.730936	Республика Башкортостан, город Уфа, Советский район, Революционная, 88		0101000020E6100000F697DD9387FD4B400ABC934F8F5D4B40
19886	7	61	\N	59	63824	\N	54.728602000000002	Республика Башкортостан, город Уфа, Советский район, Революционная, 96/2		0101000020E6100000247F30F0DCFD4B406DE690D4425D4B40
19703	7	61	\N	59	63841	\N	54.702001000000003	Республика Башкортостан, город Уфа, Кировский район, Рабкоров, 16/1		0101000020E61000000B7A6F0C01004C403161342BDB594B40
19697	7	61	\N	59	63841	\N	54.703024999999997	Республика Башкортостан, город Уфа, Кировский район, Рабкоров, 8/1		0101000020E610000071E481C822FF4B409CA223B9FC594B40
19695	7	61	\N	59	63841	\N	54.703904999999999	Республика Башкортостан, город Уфа, Кировский район, Рабкоров, 13		0101000020E6100000A9D903ADC0004C40D53E1D8F195A4B40
19730	7	61	\N	59	64574	\N	54.727006000000003	Республика Башкортостан, город Уфа, Ленинский район, Пушкина, 35/2		0101000020E6100000F99FFCDD3BF64B4076FF58880E5D4B40
19668	7	61	\N	59	64574	\N	54.72072	Республика Башкортостан, город Уфа, Кировский район, Пушкина, 108		0101000020E6100000FC372F4E7CF94B405CC98E8D405C4B40
19915	7	61	\N	59	16106	\N	54.748108611856601	Республика Башкортостан, город Уфа, Советский район, Привокзальная площадь, 3	Россия, республика Башкортостан, Уфа, улица Привокзальная Площадь	0101000020E6100000EBA9D55757F94B40F06B2409C25F4B40
19597	7	61	\N	59	63897	\N	54.703482999999999	Республика Башкортостан, город Уфа, Демский район, Правды, 18		0101000020E6100000062FFA0AD2EA4B405F251FBB0B5A4B40
19594	7	61	\N	59	63897	\N	54.701517000000003	Республика Башкортостан, город Уфа, Демский район, Правды, 25		0101000020E61000001348895DDBE94B40454B1E4FCB594B40
19680	7	61	\N	59	63925	\N	54.713236000000002	Республика Башкортостан, город Уфа, Кировский район, Посадская, 26		0101000020E61000002CBB6070CDFB4B40392A37514B5B4B40
19854	7	61	\N	59	63864	\N	54.739803999999999	Республика Башкортостан, город Уфа, Советский район, Подвойского, 7		0101000020E610000088821953B0F84B4099B9C0E5B15E4B40
19828	7	61	\N	59	63928	\N	54.819980000000001	Республика Башкортостан, город Уфа, Орджоникидзевский район, Победы, 24		0101000020E610000049D74CBED90A4C40E2AFC91AF5684B40
19635	7	61	\N	59	6794	\N	54.810122999999997	Республика Башкортостан, город Уфа, Калининский район, Бульвар Плеханова, 7/1	Россия, республика Башкортостан, Уфа, Плеханова бульвар, 7/1	0101000020E610000064B14D2A1A114C40635E471CB2674B40
19634	7	61	\N	59	6794	\N	54.809085000000003	Республика Башкортостан, город Уфа, Калининский район, Бульвар Плеханова, 5/1	Россия, республика Башкортостан, Уфа, Плеханова бульвар, 5/1	0101000020E6100000D2AC6C1FF2104C409357E71890674B40
19625	7	61	\N	59	63838	\N	54.794845000000002	Республика Башкортостан, город Уфа, Калининский район, Петрозаводская, 10/В		0101000020E6100000B80721205F124C40CF31207BBD654B40
19832	7	61	\N	59	63863	\N	54.815643000000001	Республика Башкортостан, город Уфа, Орджоникидзевский район, Первомайская, 47		0101000020E610000021B07268910B4C400D1B65FD66684B40
19817	7	61	\N	59	63863	\N	54.819372999999999	Республика Башкортостан, город Уфа, Орджоникидзевский район, Первомайская, 14		0101000020E61000004B051555BF084C40DA1CE736E1684B40
19648	7	61	\N	59	63863	\N	54.809604	Республика Башкортостан, город Уфа, Калининский район, Первомайская, 83А		0101000020E610000026A60BB1FA0D4C40FB5A971AA1674B40
19749	7	61	\N	59	63924	\N	54.762579000000002	Республика Башкортостан, город Уфа, Октябрьский район, Парковая, 12/1		0101000020E61000006D1ADB6B41FF4B40E6CE4C309C614B40
19607	7	61	\N	59	63902	\N	54.704638000000003	Республика Башкортостан, город Уфа, Демский район, Островского, 16		0101000020E6100000B9FC87F4DBE94B406AC2F693315A4B40
19644	7	61	\N	59	63946	\N	54.804544999999997	Республика Башкортостан, город Уфа, Калининский район, Орджоникидзе, 4		0101000020E610000048FB1F60AD0E4C4085949F54FB664B40
19707	7	61	\N	59	63911	\N	54.708901314441903	Республика Башкортостан, город Уфа, Кировский район, Онежская, 1		0101000020E61000004BADF71BEDFE4B40048D9944BD5A4B40
19632	7	61	\N	59	63935	\N	54.775677000000002	Республика Башкортостан, город Уфа, Калининский район, Олимпийская, 8		0101000020E610000078D15790661C4C4034A1496249634B40
19879	7	61	\N	59	482	\N	54.753295000000001	Республика Башкортостан, город Уфа, Советский район, проспект Октября, 50/2	Россия, республика Башкортостан, Уфа, Октября проспект, 50/2	0101000020E6100000B1A71DFE9A004C40C39E76F86B604B40
19870	7	61	\N	59	482	\N	54.748472999999997	Республика Башкортостан, город Уфа, Советский район, проспект Октября, 23/4	Россия, республика Башкортостан, Уфа, Октября проспект, 23/4	0101000020E61000008B6F287CB6FE4B40317898F6CD5F4B40
19808	7	61	\N	59	482	\N	54.792852000000003	Республика Башкортостан, город Уфа, Орджоникидзевский район, Проспект Октября, 174	Россия, республика Башкортостан, Уфа, Октября проспект, 174	0101000020E6100000EFA83121E6044C40BB48A12C7C654B40
19805	7	61	\N	59	482	\N	54.796314000000002	Республика Башкортостан, город Уфа, Орджоникидзевский район, Проспект Октября, 137	Россия, республика Башкортостан, Уфа, Октября проспект, 137	0101000020E6100000F085C954C1044C4069ACFD9DED654B40
19801	7	61	\N	59	482	\N	54.778528000000001	Республика Башкортостан, город Уфа, Орджоникидзевский район, Проспект Октября, 93/5	Россия, республика Башкортостан, Уфа, Октября проспект, 93/5	0101000020E61000008E20956247034C40998235CEA6634B40
19800	7	61	\N	59	482	\N	54.777214000000001	Республика Башкортостан, город Уфа, Орджоникидзевский район, Проспект Октября, 91	Россия, республика Башкортостан, Уфа, Октября проспект, 91	0101000020E61000007495EEAEB3034C4026FF93BF7B634B40
19756	7	61	\N	59	482	\N	54.761467000000003	Республика Башкортостан, город Уфа, Октябрьский район, проспект Октября, 74/2	Россия, республика Башкортостан, Уфа, Октября проспект, 74/2	0101000020E6100000931B45D61A024C40DBFD2AC077614B40
19753	7	61	\N	59	482	\N	54.766193999999999	Республика Башкортостан, город Уфа, Октябрьский район, проспект Октября, 71	Россия, республика Башкортостан, Уфа, Октября проспект, 71	0101000020E6100000F357C85C19024C401A321EA512624B40
19752	7	61	\N	59	482	\N	54.763519000000002	Республика Башкортостан, город Уфа, Октябрьский район, проспект Октября, 67	Россия, республика Башкортостан, Уфа, Октября проспект, 67	0101000020E610000093A8177C9A014C40F46F97FDBA614B40
19681	7	61	\N	59	63984	\N	54.718004999999998	Республика Башкортостан, город Уфа, Кировский район, Октябрьской Революции, 55		0101000020E61000005BB05417F0FA4B40A7AE7C96E75B4B40
19821	7	61	\N	59	64580	\N	54.827427999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Новочеркасская, 11		0101000020E6100000BF64E3C116094C40B8E52329E9694B40
19701	7	61	\N	59	66536	\N	54.625140000000002	Республика Башкортостан, город Уфа, Кировский район, Новая, 3		0101000020E6100000C5C9FD0E450D4C40F2B5679604504B40
19889	7	61	\N	59	63895	\N	54.735188999999998	Республика Башкортостан, город Уфа, Советский район, Николая Дмитриева, 13/1		0101000020E6100000B4CBB73EACFF4B4081B053AC1A5E4B40
19885	7	61	\N	59	63895	\N	54.737017999999999	Республика Башкортостан, город Уфа, Советский район, Николая Дмитриева, 19/1		0101000020E61000000135B56CADFF4B401B48179B565E4B40
19735	7	61	\N	59	63922	\N	54.732776999999999	Республика Башкортостан, город Уфа, Ленинский район, Нехаева, 94		0101000020E61000006FF085C954F54B40682101A3CB5D4B40
19824	7	61	\N	59	63923	\N	54.815913000000002	Республика Башкортостан, город Уфа, Орджоникидзевский район, Нежинская, 13		0101000020E61000005036E50AEF084C40CDB051D66F684B40
19816	7	61	\N	59	63923	\N	54.816161999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Нежинская, 4		0101000020E6100000745FCE6C57084C40751E15FF77684B40
19652	7	61	\N	59	63923	\N	54.812036999999997	Республика Башкортостан, город Уфа, Калининский район, Нежинская, 51		0101000020E61000008D45D3D9C90A4C402B1213D4F0674B40
19791	7	61	\N	59	63896	\N	54.775714000000001	Республика Башкортостан, город Уфа, Октябрьский район, Набережная р.Уфы, 51/1		0101000020E6100000B69F8CF1610A4C405186AA984A634B40
19723	7	61	\N	59	63963	\N	54.735292999999999	Республика Башкортостан, город Уфа, Ленинский район, Мустая Карима, 53/55		0101000020E61000002DB0C7444AF94B4026FDBD141E5E4B40
19600	7	61	\N	59	63931	\N	54.707900000000002	Республика Башкортостан, город Уфа, Демский район, Мусоргского, 2а		0101000020E6100000CB65A3737EEA4B40516B9A779C5A4B40
19706	7	61	\N	59	63844	\N	54.697864000000003	Республика Башкортостан, город Уфа, Кировский район, Мубарякова, 14		0101000020E6100000629E95B4E2FF4B402387889B53594B40
19704	7	61	\N	59	63844	\N	54.699216999999997	Республика Башкортостан, город Уфа, Кировский район, Мубарякова, 20/1		0101000020E610000090A2CEDC43004C4053E751F17F594B40
22680	7	61	\N	59	66502	\N	54.704503000000003	Республика Башкортостан, Федоровский район, Верхнеяушевский сельсовет с.Верхнеяушево, Молодежная, 3		0101000020E6100000A0353FFED2EE4B408A7780272D5A4B40
22667	7	61	\N	59	66562	\N	54.704711000000003	Республика Башкортостан, Федоровский район, Денискинский сельсовет с.Новоселка, Молодежная, 1		0101000020E61000008080B56AD7EE4B40D41055F8335A4B40
22675	7	61	\N	59	66545	\N	54.704481999999999	Республика Башкортостан, Федоровский район, Покровский сельсовет д.Покровка, Молодежная, 5		0101000020E61000004AEEB089CCEE4B40724F57772C5A4B40
19899	7	61	\N	59	63872	\N	54.723486000000001	Республика Башкортостан, город Уфа, Советский район, Минигали Губайдуллина, 27		0101000020E610000010751F80D4FE4B40938E72309B5C4B40
19909	7	61	\N	59	63940	\N	54.735007000000003	Республика Башкортостан, город Уфа, Советский район, Мингажева, 160		0101000020E61000001E520C9068FC4B4061AA99B5145E4B40
19906	7	61	\N	59	63940	\N	54.731534000000003	Республика Башкортостан, город Уфа, Советский район, Мингажева, 138А (общежитие №3)		0101000020E610000040DEAB5626FC4B40BFF4F6E7A25D4B40
19679	7	61	\N	59	63940	\N	54.727125999999998	Республика Башкортостан, город Уфа, Кировский район, Мингажева, 107/1		0101000020E6100000740AF2B391FB4B402009FB76125D4B40
19678	7	61	\N	59	63940	\N	54.729694000000002	Республика Башкортостан, город Уфа, Кировский район, Мингажева, 126		0101000020E6100000BAD8B45208FC4B40310BED9C665D4B40
19863	7	61	\N	59	63886	\N	54.746029999999998	Республика Башкортостан, город Уфа, Советский район, Миасская, 22		0101000020E610000016BF29AC54FA4B40DDEA39E97D5F4B40
19892	7	61	\N	59	63840	\N	54.723564000000003	Республика Башкортостан, город Уфа, Советский район, Менделеева, 177/3		0101000020E6100000ACE3F8A1D2004C400F48C2BE9D5C4B40
20628	7	61	\N	58311	64641	\N	55.964075000000001	д.Старые Каргалы, Школьная, 45		0101000020E6100000001FBC7669D34B4013F241CF66FB4B40
19891	7	61	\N	59	63840	\N	54.721187999999998	Республика Башкортостан, город Уфа, Советский район, Менделеева, 148		0101000020E61000000FD07D39B3014C4042226DE34F5C4B40
19775	7	61	\N	59	63840	\N	54.749507000000001	Республика Башкортостан, город Уфа, Октябрьский район, Менделеева, 215/3		0101000020E61000005F950B957F034C40C18F6AD8EF5F4B40
19773	7	61	\N	59	63840	\N	54.740839000000001	Республика Башкортостан, город Уфа, Октябрьский район, Менделеева, 203		0101000020E61000002BBD361B2B034C40F94CF6CFD35E4B40
19772	7	61	\N	59	63840	\N	54.738089000000002	Республика Башкортостан, город Уфа, Октябрьский район, Менделеева, 197/1		0101000020E61000002BBD361B2B034C40C8444AB3795E4B40
19689	7	61	\N	59	63840	\N	54.711218000000002	Республика Башкортостан, город Уфа, Кировский район, Менделеева, 41		0101000020E6100000D9791B9B1DFD4B40CC290131095B4B40
19682	7	61	\N	59	63840	\N	54.712663999999997	Республика Башкортостан, город Уфа, Кировский район, Менделеева, 7/2		0101000020E610000092B1DAFCBFFC4B40AD84EE92385B4B40
19653	7	61	\N	59	63980	\N	54.812840999999999	Республика Башкортостан, город Уфа, Калининский район, Маяковского, 3		0101000020E6100000DEAF027CB7094C4089EC832C0B684B40
19645	7	61	\N	59	63975	\N	54.805894000000002	Республика Башкортостан, город Уфа, Калининский район, Машиностроителей, 10		0101000020E61000000E881057CE0E4C407505DB8827674B40
19819	7	61	\N	59	63986	\N	54.819201999999997	Республика Башкортостан, город Уфа, Орджоникидзевский район, Матвея Пинского, 12		0101000020E61000002BA4FCA4DA074C40AD68739CDB684B40
19732	7	61	\N	59	64548	\N	54.743389999999998	Республика Башкортостан, город Уфа, Ленинский район, Малая Трактовая, 199		0101000020E6100000B5FAEAAA40F74B4033164D67275F4B40
19610	7	61	\N	59	63913	\N	54.688102999999998	Республика Башкортостан, город Уфа, Демский район, Майкопская, 58		0101000020E61000008B1A4CC3F0E54B40C6A354C213584B40
19728	7	61	\N	59	63760	\N	54.603471203685103	Республика Башкортостан, город Уфа, Ленинский район, Мажита Гафури, 7	Россия, республика Башкортостан, деревня Чесноковка, улица Мажита Гафури, 7	0101000020E610000099F04BFDBCF94B40CE8AA8893E4D4B40
19605	7	61	\N	59	63903	\N	54.707686000000002	Республика Башкортостан, город Уфа, Демский район, Магистральная, 27/3		0101000020E61000008EACFC3218E94B4025EB7074955A4B40
19807	7	61	\N	59	63990	\N	54.788137999999996	Республика Башкортостан, город Уфа, Орджоникидзевский район, Львовская, 4		0101000020E61000005FD1ADD7F4044C400F5EBBB4E1644B40
19745	7	61	\N	59	63856	\N	54.795831	Республика Башкортостан, город Уфа, Ленинский район, Летчиков, 8/2		0101000020E6100000795C548B88EE4B404D124BCADD654B40
19861	7	61	\N	59	63831	\N	54.736300999999997	Республика Башкортостан, город Уфа, Советский район, Ленина, 61		0101000020E6100000E3A6069ACFF94B408C81751C3F5E4B40
19857	7	61	\N	59	63831	\N	54.748068000000004	Республика Башкортостан, город Уфа, Советский район, Ленина, 127		0101000020E61000008046E9D2BFFA4B40929735B1C05F4B40
19722	7	61	\N	59	63831	\N	54.730556999999997	Республика Башкортостан, город Уфа, Ленинский район, Ленина, 25/29		0101000020E6100000734BAB2171F94B40936E4BE4825D4B40
19670	7	61	\N	59	63831	\N	54.729979999999998	Республика Башкортостан, город Уфа, Кировский район, Ленина, 50		0101000020E61000001E37FC6EBAF94B40F65D11FC6F5D4B40
19669	7	61	\N	59	63831	\N	54.725383999999998	Республика Башкортостан, город Уфа, Кировский район, Ленина, 26		0101000020E6100000A1BFD02346F94B4055850662D95C4B40
19666	7	61	\N	59	63831	\N	54.721130000000002	Республика Башкортостан, город Уфа, Кировский район, Ленина, 3		0101000020E610000017838769DFF84B400E15E3FC4D5C4B40
19609	7	61	\N	59	63942	\N	54.694847000000003	Республика Башкортостан, город Уфа, Демский район, Левитана, 36		0101000020E61000009697FC4FFEE84B40A35C1ABFF0584B40
19608	7	61	\N	59	63942	\N	54.696818999999998	Республика Башкортостан, город Уфа, Демский район, Левитана, 24		0101000020E61000006D205D6C5AE94B409F1D705D31594B40
19593	7	61	\N	59	63942	\N	54.699362999999998	Республика Башкортостан, город Уфа, Демский район, Левитана, 12		0101000020E61000001A89D00836EA4B4027840EBA84594B40
19673	7	61	\N	59	63890	\N	54.730167000000002	Республика Башкортостан, город Уфа, Кировский район, Кустарная, 17		0101000020E6100000A4880CAB78FB4B4029CFBC1C765D4B40
19834	7	61	\N	59	63869	\N	54.819772	Республика Башкортостан, город Уфа, Орджоникидзевский район, Кулибина, 38		0101000020E6100000E4A1EF6E650D4C409816F549EE684B40
19725	7	61	\N	59	63877	\N	54.733004999999999	Республика Башкортостан, город Уфа, Ленинский район, Красина, 33		0101000020E61000009414580053F84B40F9669B1BD35D4B40
19818	7	61	\N	59	63983	\N	54.816307000000002	Республика Башкортостан, город Уфа, Орджоникидзевский район, Космонавтов, 8/2		0101000020E6100000DB300A82C7074C40793F6EBF7C684B40
19820	7	61	\N	59	63937	\N	54.824092999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Конституции, 2а		0101000020E610000099F5622827084C4067EE21E17B694B40
19884	7	61	\N	59	63901	\N	54.741556000000003	Республика Башкортостан, город Уфа, Советский район, Комсомольская, 14		0101000020E61000005C57CC086FFF4B408813984EEB5E4B40
19877	7	61	\N	59	63901	\N	54.747895999999997	Республика Башкортостан, город Уфа, Советский район, Комсомольская, 33		0101000020E6100000124E0B5EF4FF4B4094675E0EBB5F4B40
19873	7	61	\N	59	63901	\N	54.744570000000003	Республика Башкортостан, город Уфа, Советский район, Комсомольская, 23/3		0101000020E6100000F31FD26F5FFF4B4097CADB114E5F4B40
19776	7	61	\N	59	63901	\N	54.759363	Республика Башкортостан, город Уфа, Октябрьский район, Комсомольская, 138		0101000020E610000026FDBD141E024C406F6589CE32614B40
19759	7	61	\N	59	63901	\N	54.766745	Республика Башкортостан, город Уфа, Октябрьский район, Комсомольская, 165/2		0101000020E6100000D28E1B7E37034C408EAF3DB324624B40
19758	7	61	\N	59	63901	\N	54.765881999999998	Республика Башкортостан, город Уфа, Октябрьский район, Комсомольская, 165/1		0101000020E6100000F243A51133034C402B4CDF6B08624B40
19757	7	61	\N	59	63901	\N	54.764069999999997	Республика Башкортостан, город Уфа, Октябрьский район, Комсомольская, 161/2		0101000020E61000003A765089EB024C4067EDB60BCD614B40
19755	7	61	\N	59	63901	\N	54.759903000000001	Республика Башкортостан, город Уфа, Октябрьский район, Комсомольская, 137		0101000020E6100000D175E107E7014C40EF90628044614B40
19754	7	61	\N	59	63901	\N	54.757523999999997	Республика Башкортостан, город Уфа, Октябрьский район, Комсомольская, 113		0101000020E6100000255D33F966014C40B1F7E28BF6604B40
22686	7	61	\N	59	63852	\N	54.726149247937698	Республика Башкортостан, Федоровский район, Федоровский сельсовет с.Федоровка, Коммунистическая, 59	Россия, республика Башкортостан, Уфа, улица Коммунистическая, 59	0101000020E610000001C11C3D7EF94B40F5824F73F25C4B40
19727	7	61	\N	59	63852	\N	54.729018000000003	Республика Башкортостан, город Уфа, Ленинский район, Коммунистическая, 16		0101000020E6100000E141B3EBDEF64B4001193A76505D4B40
19847	7	61	\N	59	63907	\N	54.818351	Республика Башкортостан, город Уфа, Орджоникидзевский район, Коммунаров, 69/3		0101000020E6100000DD28B2D650104C400FD3BEB9BF684B40
19646	7	61	\N	59	63907	\N	54.810574000000003	Республика Башкортостан, город Уфа, Калининский район, Коммунаров, 12А		0101000020E610000052D32EA6990E4C40747E8AE3C0674B40
19835	7	61	\N	59	63830	\N	54.814630999999999	Республика Башкортостан, город Уфа, Орджоникидзевский район, Кольцевая, 143		0101000020E6100000A647533D990D4C4065A71FD445684B40
19833	7	61	\N	59	63830	\N	54.821545999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Кольцевая, 105		0101000020E6100000EBE6E26F7B0C4C406E14596B28694B40
19826	7	61	\N	59	63830	\N	54.823289000000003	Республика Башкортостан, город Уфа, Орджоникидзевский район, Кольцевая, 49		0101000020E6100000728BF9B9A1094C400A14B18861694B40
19825	7	61	\N	59	63830	\N	54.823324999999997	Республика Башкортостан, город Уфа, Орджоникидзевский район, Кольцевая, 37		0101000020E61000009487855AD3084C40567DAEB662694B40
19636	7	61	\N	59	63830	\N	54.813233987276497	Республика Башкортостан, город Уфа, Калининский район, Кольцевая, 200/1	Россия, республика Башкортостан, Уфа, улица Кольцевая, 200	0101000020E610000049BA66F2CD104C4065FF3C0D18684B40
19671	7	61	\N	59	63917	\N	54.731471999999997	Республика Башкортостан, город Уфа, Кировский район, Кирова, 15		0101000020E6100000A723809BC5F94B4048F8DEDFA05D4B40
19721	7	61	\N	59	63948	\N	54.731960000000001	Республика Башкортостан, город Уфа, Ленинский район, Кирова, 1		0101000020E6100000E1F08288D4F84B4076FD82DDB05D4B40
22641	7	61	\N	59	63815	\N	54.731836000000001	"г.Учалы - ""Стиль"", Кирова, 7а"		0101000020E61000000DFB3DB14EF94B408A0453CDAC5D4B40
19736	7	61	\N	59	63919	\N	54.739477000000001	Республика Башкортостан, город Уфа, Ленинский район, Кирзаводская, 1/3		0101000020E6100000191D90847DF34B407592AD2EA75E4B40
19629	7	61	\N	59	63972	\N	54.756115999999999	Республика Башкортостан, город Уфа, Калининский район, Касимовская, 10/2		0101000020E61000003DB9A640661F4C40BDFDB968C8604B40
19862	7	61	\N	59	63845	\N	54.742476000000003	Республика Башкортостан, город Уфа, Советский район, Карла Маркса, 50		0101000020E6100000A4198BA6B3F94B404F081D74095F4B40
19855	7	61	\N	59	63845	\N	54.740349999999999	Республика Башкортостан, город Уфа, Советский район, Карла Маркса, 69		0101000020E61000002E8D5F7825F94B40FBCBEEC9C35E4B40
19724	7	61	\N	59	63845	\N	54.728346999999999	Республика Башкортостан, город Уфа, Ленинский район, Карла Маркса, 35		0101000020E61000001A1A4F0471F84B40E29178793A5D4B40
19881	7	61	\N	59	63868	\N	54.7399306102526	Республика Башкортостан, город Уфа, Советский район, Казанская, 10а		0101000020E61000002C634337FBFF4B40F6251B0FB65E4B40
19700	7	61	\N	59	64403	\N	54.519798000000002	Республика Башкортостан, город Уфа, Кировский район, Искинская, 59/2	Россия, республика Башкортостан, Уфа, деревня Искино, улица Искинская, 59/2	0101000020E6100000F1457BBC90F44B405B43A9BD88424B40
19642	7	61	\N	59	63943	\N	54.801622999999999	Республика Башкортостан, город Уфа, Калининский район, Интернациональная, 157		0101000020E6100000656F29E78B0F4C40575C1C959B664B40
19639	7	61	\N	59	63943	\N	54.802376000000002	Республика Башкортостан, город Уфа, Калининский район, Интернациональная, 183		0101000020E61000007AABAE4335114C40338CBB41B4664B40
19859	7	61	\N	59	1402	\N	54.742345999999998	Республика Башкортостан, город Уфа, Советский район, бульвар Ибрагимова, 41	Россия, республика Башкортостан, Уфа, Ибрагимова бульвар, 41	0101000020E6100000B1F7E28BF6FA4B4080289831055F4B40
19683	7	61	\N	59	63874	\N	54.703009999999999	Республика Башкортостан, город Уфа, Кировский район, З. Космодемьянской, 38		0101000020E6100000B24B546F0DFA4B4067614F3BFC594B40
19726	7	61	\N	59	63951	\N	54.730583000000003	Республика Башкортостан, город Уфа, Ленинский район, Зенцова, 51		0101000020E6100000C5E6E3DA50F74B40BD0166BE835D4B40
19740	7	61	\N	59	63894	\N	54.790101	Республика Башкортостан, город Уфа, Ленинский район, Защитников Отечества, 17		0101000020E61000001BBAD91F28F94B40B9C4910722654B40
19856	7	61	\N	59	63882	\N	54.742944000000001	Республика Башкортостан, город Уфа, Советский район, Запотоцкого, 48		0101000020E610000017D34CF73AF94B403561FBC9185F4B40
19665	7	61	\N	59	63979	\N	54.720095999999998	Республика Башкортостан, город Уфа, Кировский район, Заки Валиди, 32		0101000020E610000048BF7D1D38F74B407EFD101B2C5C4B40
19698	7	61	\N	59	63945	\N	54.693952000000003	Республика Башкортостан, город Уфа, Кировский район, З. Исмагилова, 1		0101000020E6100000ED48F59D5FFE4B40357F4C6BD3584B40
19872	7	61	\N	59	63930	\N	54.742781999999998	Республика Башкортостан, город Уфа, Советский район, Железняцкая, 35		0101000020E61000005E11FC6F25FF4B405B07077B135F4B40
19708	7	61	\N	59	7542	\N	54.707358999999997	Республика Башкортостан, город Уфа, Кировский район, Дуванский бульвар, 22/2	Россия, республика Башкортостан, Уфа, Дуванский бульвар, 22/2	0101000020E61000007715527E52FF4B4000C45DBD8A5A4B40
19905	7	61	\N	59	63832	\N	54.732937999999997	Республика Башкортостан, город Уфа, Советский район, Достоевского, 99 корпус А		0101000020E610000045D95BCAF9FA4B4071FF91E9D05D4B40
14693	7	61	58	10311	63694	\N	55.840871	с. Бураево, Победы, 13		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
19720	7	61	\N	59	63832	\N	54.733801	Республика Башкортостан, город Уфа, Ленинский район, Достоевского, 67		0101000020E6100000A933F790F0F94B40D462F030ED5D4B40
19842	7	61	\N	59	63956	\N	54.821981999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Дмитрия Донского, 87		0101000020E6100000C138B874CC0D4C4049F3C7B436694B40
19685	7	61	\N	59	64415	\N	54.709248038192399	Республика Башкортостан, город Уфа, Кировский район, Демская, 2	Россия, республика Башкортостан, Уфа, улица Демская, 2	0101000020E6100000F1D58EE21CF94B40706072A3C85A4B40
19810	7	61	\N	59	63880	\N	54.789099	Республика Башкортостан, город Уфа, Орджоникидзевский район, Даута Юлтыя, 6		0101000020E61000000BF0DDE68D054C4035272F3201654B40
19599	7	61	\N	59	63961	\N	54.708128000000002	Республика Башкортостан, город Уфа, Демский район, Дагестанская, 15/1		0101000020E610000075CAA31B61EB4B40E2B034F0A35A4B40
19651	7	61	\N	59	63921	\N	54.814304	Республика Башкортостан, город Уфа, Калининский район, Гончарова, 19		0101000020E610000021567F84610C4C4041800C1D3B684B40
19650	7	61	\N	59	63921	\N	54.810848999999997	Республика Башкортостан, город Уфа, Калининский район, Гончарова, 5		0101000020E6100000FB3C4679E60B4C40457F68E6C9674B40
19591	7	61	\N	59	64572	\N	54.692135999999998	Республика Башкортостан, город Уфа, Демский район, Глазовская, 38А		0101000020E61000009FCA694FC9EB4B402F3196E997584B40
19620	7	61	\N	59	63926	\N	54.782874	Республика Башкортостан, город Уфа, Калининский район, Георгия Мушникова, 17/1		0101000020E6100000B3EC4960730E4C40C171193735644B40
19731	7	61	\N	59	63342	\N	54.736076412423301	Республика Башкортостан, город Уфа, Ленинский район, Мажита Гафури, 103		0101000020E6100000533F6F2A52F74B406CAF05BD375E4B40
19657	7	61	\N	59	64558	\N	54.689456	Республика Башкортостан, город Уфа, Калининский район, деревня Федоровка, Галечная, 7		0101000020E61000007193516518114C40F7031E1840584B40
19734	7	61	\N	59	63949	\N	54.741799999999998	Республика Башкортостан, город Уфа, Ленинский район, Выгонная, 10		0101000020E61000007995B54DF1F44B401E166A4DF35E4B40
19845	7	61	\N	59	63836	\N	54.819071999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Вологодская, 64/1		0101000020E610000093E34EE9600F4C40DF88EE59D7684B40
19844	7	61	\N	59	63836	\N	54.820870344170103	Республика Башкортостан, город Уфа, Орджоникидзевский район, Вологодская, 76/2	Россия, республика Башкортостан, Уфа, улица Вологодская, 76/1	0101000020E6100000A99F3715A90E4C403E22A64412694B40
19841	7	61	\N	59	63836	\N	54.815648000000003	Республика Башкортостан, город Уфа, Орджоникидзевский район, Вологодская, 29		0101000020E610000093C9A99D61104C401F86562767684B40
19840	7	61	\N	59	63836	\N	54.815595999999999	Республика Башкортостан, город Уфа, Орджоникидзевский район, Вологодская, 58		0101000020E610000028486C770F104C40CC5F217365684B40
20781	7	61	\N	59	63875	\N	54.743364	Республика Башкортостан, Белорецкий район, Железнодорожный сельсовет, Вокзальная, 7		0101000020E6100000E71890BDDEF74B400A83328D265F4B40
19912	7	61	\N	59	63981	\N	54.731222000000002	Республика Башкортостан, город Уфа, Советский район, Владивостокская, 5		0101000020E610000027D9EA724AFE4B40D00EB8AE985D4B40
19846	7	61	\N	59	63866	\N	54.816845999999998	Республика Башкортостан, город Уфа, Орджоникидзевский район, Борисоглебская, 12		0101000020E610000045A165DD3F0E4C4028EFE3688E684B40
19838	7	61	\N	59	63866	\N	54.816550999999997	Республика Башкортостан, город Уфа, Орджоникидзевский район, Борисоглебская, 17		0101000020E610000003931B45D60E4C400F4240BE84684B40
19837	7	61	\N	59	63866	\N	54.812966000000003	Республика Башкортостан, город Уфа, Орджоникидзевский район, Борисоглебская, 32		0101000020E6100000DE3CD521370F4C40466117450F684B40
19836	7	61	\N	59	63866	\N	54.815944000000002	Республика Башкортостан, город Уфа, Орджоникидзевский район, Борисоглебская, 16		0101000020E6100000F9872D3D9A0E4C4008AF5DDA70684B40
19804	7	61	\N	59	63853	\N	54.793449000000003	Республика Башкортостан, город Уфа, Орджоникидзевский район, Блюхера, 25		0101000020E61000004C35B39602044C409F05A1BC8F654B40
19802	7	61	\N	59	63853	\N	54.788241999999997	Республика Башкортостан, город Уфа, Орджоникидзевский район, Блюхера, 9		0101000020E6100000E8C1DD59BB034C40B4AA251DE5644B40
19822	7	61	\N	59	66508	\N	54.895221999999997	Республика Башкортостан, город Уфа, Орджоникидзевский район, Биологическая, 35		0101000020E6100000B612BA4BE2044C4071546EA296724B40
19858	7	61	\N	59	63834	\N	54.745204000000001	Республика Башкортостан, город Уфа, Советский район, Белякова, 25/1		0101000020E6100000C66E9F5566FA4B40986C3CD8625F4B40
19795	7	61	\N	59	66542	\N	54.754432999999999	Республика Башкортостан, город Уфа, Октябрьский район, Белоозерская, 57		0101000020E6100000889E94490D054C40F702B34291604B40
19784	7	61	\N	59	63395	\N	54.766296882975603	Республика Башкортостан, город Уфа, Октябрьский район, Б.Бикбая, 31/1	Россия, республика Башкортостан, Уфа, улица Баязита Бикбая, 31/1	0101000020E6100000338D261763084C40EF02250516624B40
19694	7	61	\N	59	63839	\N	54.705553999999999	Республика Башкортостан, город Уфа, Кировский район, Батырская, 8/3		0101000020E6100000268E3C1059004C40EFC7ED974F5A4B40
19693	7	61	\N	59	63839	\N	54.707000000000001	Республика Башкортостан, город Уфа, Кировский район, Батырская, 4/2		0101000020E61000007AC5538F34004C40D122DBF97E5A4B40
19869	7	61	\N	59	63906	\N	54.7437288680877	Республика Башкортостан, город Уфа, Советский район, Бабушкина, 23	Россия, республика Башкортостан, Уфа, улица Бабушкина	0101000020E6100000253E7782FDFD4B401C0B0A83325F4B40
19868	7	61	\N	59	63906	\N	54.743999000000002	Республика Башкортостан, город Уфа, Советский район, Бабушкина, 21		0101000020E6100000BA6A9E23F2FD4B40DCA0F65B3B5F4B40
19743	7	61	\N	59	63829	\N	54.788184999999999	Республика Башкортостан, город Уфа, Ленинский район, Ахметова, 320		0101000020E6100000B003E78C28F14B405019FF3EE3644B40
19742	7	61	\N	59	63829	\N	54.783969999999997	Республика Башкортостан, город Уфа, Ленинский район, Ахметова, 275		0101000020E61000002844C02154F14B40C685032159644B40
19741	7	61	\N	59	63829	\N	54.784343	Республика Башкортостан, город Уфа, Ленинский район, Ахметова, 306		0101000020E610000049490F43ABF14B405BECF65965644B40
19739	7	61	\N	59	63829	\N	54.778767000000002	Республика Башкортостан, город Уфа, Ленинский район, Ахметова, 207		0101000020E6100000514A0856D5F14B401E1A16A3AE634B40
19898	7	61	\N	59	63955	\N	54.715805000000003	Республика Башкортостан, город Уфа, Советский район, Акназарова, 24 (жилой дом)		0101000020E6100000A01B9AB2D3FF4B401AA88C7F9F5B4B40
19792	7	61	\N	59	63898	\N	54.773251999999999	Республика Башкортостан, город Уфа, Октябрьский район, Академика Королева, 25		0101000020E610000059FAD005F5094C4086C8E9EBF9624B40
19787	7	61	\N	59	63898	\N	54.771273999999998	Республика Башкортостан, город Уфа, Октябрьский район, Академика Королева, 13/1		0101000020E6100000575A46EA3D094C40A7203F1BB9624B40
19813	7	61	\N	59	63941	\N	54.794517999999997	Республика Башкортостан, город Уфа, Орджоникидзевский район, Адмирала Макарова, 20		0101000020E6100000CE8B135FED064C40AA0A0DC4B2654B40
19705	7	61	\N	59	63959	\N	54.700856000000002	Республика Башкортостан, город Уфа, Кировский район, Авроры, 17/1		0101000020E6100000D74D29AF95004C404A9A3FA6B5594B40
19712	7	61	\N	59	65686	\N	54.710057275181597	Республика Башкортостан, город Уфа, Кировский район, Зеленая роща	Россия, республика Башкортостан, Уфа, улица Авроры, 18/2	0101000020E6100000B56CAD2F12024C40DFA5D425E35A4B40
19907	7	61	\N	59	63883	\N	54.736373999999998	Республика Башкортостан, город Уфа, Советский район, 8 марта, 3		0101000020E6100000CC7A319413FD4B40F6CFD380415E4B40
19904	7	61	\N	59	63929	\N	54.735515999999997	Республика Башкортостан, город Уфа, Советский район, 50-летия Октября, 14/1		0101000020E6100000EC33677DCAFB4B40A5D76663255E4B40
19871	7	61	\N	59	63929	\N	54.737102	Республика Башкортостан, город Уфа, Советский район, 50-летия Октября, 24		0101000020E6100000BDAB1E300FFD4B4079E8BB5B595E4B40
19864	7	61	\N	59	63929	\N	54.737642000000001	Республика Башкортостан, город Уфа, Советский район, 50-летия Октября, 7А		0101000020E6100000BA15C26A2CFB4B40F913950D6B5E4B40
19880	7	61	\N	59	63867	\N	54.756250999999999	Республика Башкортостан, город Уфа, Советский район, 50 лет СССР, 10		0101000020E610000058C6866EF6FF4B409D4830D5CC604B40
19770	7	61	\N	59	63867	\N	54.750390000000003	Республика Башкортостан, город Уфа, Октябрьский район, 50 лет СССР, 30/5		0101000020E6100000113AE8120E014C406B9F8EC70C604B40
19793	7	61	\N	59	63843	\N	54.7765736847876	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 59		0101000020E6100000F3E505D847094C404276DEC666634B40
19812	7	61	\N	59	66948	\N	54.791558999999999	Республика Башкортостан, город Уфа, Орджоникидзевский район, Шота Руставели 24		0101000020E6100000BBEF181EFB054C405FED28CE51654B40
19637	7	61	\N	59	63947	\N	54.809261602285197	Республика Башкортостан, город Уфа, Калининский район, Черниковская, 59/1	Россия, республика Башкортостан, Уфа, улица Черниковская, 59/1	0101000020E610000016F6B4C35F0F4C40A1F2AFE595674B40
19699	7	61	\N	59	66943	\N	54.689267999999998	Республика Башкортостан, город Уфа, Кировский район, Пугачева, 112/1		0101000020E61000005B61FA5E43FE4B40F4160FEF39584B40
22672	7	61	\N	59	66539	\N	54.704138999999998	Республика Башкортостан, Федоровский район, Дедовский сельсовет с.Ижбуляк, Молодежная, 2		0101000020E6100000E867EA758BEE4B40486B0C3A215A4B40
19737	7	61	\N	59	63962	\N	54.743234999999999	Республика Башкортостан, город Уфа, Ленинский район, Лесозаводская, 1а		0101000020E61000008A22A46E67F34B400C1F1153225F4B40
19888	7	61	\N	59	63939	\N	54.727967999999997	Республика Башкортостан, город Уфа, Советский район, Кирова, 97/2		0101000020E6100000A724EB7074FD4B406B44300E2E5D4B40
19612	7	61	\N	59	63971	\N	54.712144000000002	Республика Башкортостан, город Уфа, Демский район, Дагестанская, 10/2		0101000020E61000004E2A1A6B7FEB4B407505DB88275B4B40
19606	7	61	\N	59	66938	\N	54.708044999999998	Республика Башкортостан, город Уфа, Демский район,Грозненская, 69/3		0101000020E6100000C1ABE5CE4CE84B40548CF337A15A4B40
19790	7	61	\N	59	63966	\N	54.769959999999998	Республика Башкортостан, город Уфа, Октябрьский район, Ю.Гагарина, 50/3		0101000020E610000073F1B73D410A4C40349D9D0C8E624B40
20224	7	61	\N	58354	65095	\N	53.394148999999999	д.Утяганово, ул.Центральная, 5		0101000020E61000008ECA4DD4D2284D402460747973B24A40
20794	7	61	\N	58333	64736	\N	54.227142999999998	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Усмангали, ленина, 31		0101000020E61000002429E96168C14C40F6419605131D4B40
19948	7	61	\N	9468	63814	\N	54.570368999999999	"Республика Башкортостан, ЗАТО ""город Межгорье"", Строителей, 20"		0101000020E61000001232906797F34B407CD3F4D901494B40
20395	7	61	\N	58578	65609	\N	56.087232999999998	Республика Башкортостан, Аскинский район, Урмиязовский сельсовет, с.Урмиязы, Ленина, 21		0101000020E6100000B56FEEAF1E714C40E41071732A0B4C40
21557	7	61	\N	58401	64932	\N	55.322445000000002	Республика Башкортостан, Илишевский район, Урметовский сельсовет, с. Урметово, Р.Хайри, 64а		0101000020E610000018231285961F4B401EE1B4E045A94B40
21721	7	61	\N	58158	64056	\N	55.736289999999997	с.Ургуш, Корочкина, 25		0101000020E610000028B9C32632554C40982F2FC03EDE4B40
20555	7	61	\N	58367	64829	\N	55.310513999999998	село Умирово, улица Октябрьская, дом 2		0101000020E6100000FA7E6ABC74E74A409E7939ECBEA74B40
22831	7	61	\N	58612	65727	\N	54.491259999999997	д.Удряк, Школьная, 5		0101000020E6100000CBD8D0CDFE984B409EEA909BE13E4B40
22323	7	61	\N	58561	65532	\N	53.491087	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, с.Тятербаш, Школьная, 9А		0101000020E6100000EB5223F4339B4B40D13E56F0DBBE4A40
22519	7	61	\N	58188	64200	\N	54.683820206693298	с.Тюменяк, Клубная, 2	Россия, республика Башкортостан, Туймазинский район, село Тюменяк	0101000020E6100000FDA02E5228E54A40E42CEC6987574B40
21975	7	61	\N	58461	65075	\N	52.715559980535701	Республика Башкортостан, Куюргазинский район, д.Тюканово 2-е, Интернациональная, 32		0101000020E61000009D66817687BA4B40B3295778975B4A40
20633	7	61	\N	58462	65076	\N	56.077860000000001	д.Тыканово, Октябрьская, 21		0101000020E6100000965CC5E237DB4B4052D50451F7094C40
22459	7	61	\N	58096	63544	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, проспект Ленина, 3		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22455	7	61	\N	58096	63544	\N	54.606943852372503	Республика Башкортостан, Туймазинский район, город Туймазы, проспект Ленина, 2, В		0101000020E610000078B471C45ADA4A4070404B57B04D4B40
22463	7	61	\N	58096	63774	\N	54.5977752949657	Республика Башкортостан, Туймазинский район, город Туймазы, площадь Октября, 3	Россия, республика Башкортостан, Туймазинский район, Туймазы	0101000020E61000002446CF2D74DB4A40E6AE25E4834C4B40
22449	7	61	\N	58096	63425	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, мкр. Молодежный, 14		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22448	7	61	\N	58096	63425	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, мкр.Молодежный, 4		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22445	7	61	\N	58096	63548	\N	54.609933182677999	Республика Башкортостан, Туймазинский район, город Туймазы, Южная, 34,А	Россия, республика Башкортостан, Туймазинский район, Туймазы	0101000020E610000000E65AB400DB4A4026E0D748124E4B40
22446	7	61	\N	58096	63428	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Чехова, 2,А		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22464	7	61	\N	58096	63707	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Чапаева, 14		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22466	7	61	\N	58096	63313	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Советская, 40		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22451	7	61	\N	58096	63313	\N	54.609634356877002	Республика Башкортостан, Туймазинский район, город Туймазы, Советская, 14	Россия, республика Башкортостан, Туймазинский район, Туймазы	0101000020E610000088F546AD30DB4A40CC43A67C084E4B40
22447	7	61	\N	58096	63765	\N	54.597476282175101	Республика Башкортостан, Туймазинский район, город Туймазы, С.Юлаева, 83		0101000020E6100000355EBA490CD84A408C12F4177A4C4B40
22453	7	61	\N	58096	63679	\N	54.608588108638699	Республика Башкортостан, Туймазинский район, город Туймазы, Островского, 9,В		0101000020E6100000438D429259D94A40785E2A36E64D4B40
22452	7	61	\N	58096	63682	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Ленина, 34		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22460	7	61	\N	58096	63290	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Комарова, 25		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22456	7	61	\N	58096	63290	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Комарова, 8,Б		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22468	7	61	\N	58096	63535	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Зеленая, 4		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22465	7	61	\N	58096	63670	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Губкина, 1		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22467	7	61	\N	58096	63770	\N	54.598971324073197	Республика Башкортостан, Туймазинский район, город Туймазы, Гафурова, 31,А	Россия, республика Башкортостан, Туймазинский район, Туймазы	0101000020E6100000195932C7F2DA4A404F20EC14AB4C4B40
21093	7	61	\N	58593	65669	\N	55.768906999999999	д.Тугаряково, Садовая, 25		0101000020E61000009A780778D2804B402E55698B6BE24B40
20989	7	61	\N	27931	64402	\N	54.931261999999997	поселок Тугай, Луговая, 16/2	Россия, республика Башкортостан, поселок Тугай	0101000020E610000054ABAFAE0AFC4B40F700DD9733774B40
20625	7	61	\N	58570	65577	\N	56.104185000000001	д.Тошкурово, Центральная, 6		0101000020E6100000702711E15F0A4C40ECDD1FEF550D4C40
20810	7	61	\N	58179	64164	\N	54.207521999999997	Республика Башкортостан, Белорецкий район, Тирлянский сельсовет, с.Тирлянский, Полуэктова, 8		0101000020E6100000CF876709324A4D40AA99B514901A4B40
21974	7	61	\N	58425	64982	\N	52.668207000000002	Республика Башкортостан, Куюргазинский район, д.Тимербаево, Центральная, 106		0101000020E61000001FA2D11DC4AA4B40A9FA95CE87554A40
21089	7	61	\N	58468	65093	\N	56.045352999999999	с.Тепляки, Мелиораторов, 1		0101000020E6100000BB7EC16ED8C04B4043E38920CE054C40
22888	7	61	\N	58615	65738	\N	54.925570999999998	д.Темяково, Рабочая, 2А		0101000020E6100000645930F147034B4021904B1C79764B40
20269	7	61	\N	58456	65064	\N	53.471876999999999	д.Таштимерово, ул.Коммунистическая, 25/1		0101000020E6100000E3FF8EA850574D40075E2D7766BC4A40
19954	7	61	\N	58131	63783	\N	56.047027	село Ташкиново, Чеверева, 7а		0101000020E6100000942EFD4B52234B40B68311FB04064C40
22197	7	61	\N	58449	65052	\N	53.461671000000003	село Таукай-Гайна, улица Школьная, дом 7		0101000020E610000082AE7D01BD7A4B407D410B0918BB4A40
21321	7	61	\N	58335	64747	\N	55.55471	Республика Башкортостан, Дюртюлинский район, Учпилинский сельсовет, д.Таубаш-Бадраково, Октябрьской Революции, 11А		0101000020E61000004913EF004F944B40D061BEBC00C74B40
22273	7	61	\N	58489	65186	\N	55.207751999999999	с.Татарский Малояз, Школьная, 5		0101000020E6100000A8514832AB134D40DCD6169E979A4B40
22793	7	61	\N	58714	66139	\N	55.215502999999998	село Таскаклы, Ф. Алтайского, 32		0101000020E6100000D447E00F3F714B404E98309A959B4B40
22557	7	61	\N	8259	64397	\N	54.605980000000002	Республика Башкортостан, Уфимский район, с. Таптыково, Центральная, 22		0101000020E6100000056F48A302E54B40DA03ADC0904D4B40
22180	7	61	\N	58357	64810	\N	53.594329000000002	село Тамьян-Таймас, улица Советская, дом 1 А		0101000020E6100000680586AC6E474B403E0801F912CC4A40
20584	7	61	\N	58521	65320	\N	54.982745000000001	село Таллы-Сыза, улица Родниковая, дом 1А		0101000020E610000096067E54C3BE4A405DA79196CA7D4B40
22315	7	61	\N	58371	64840	\N	53.294750000000001	Республика Башкортостан, Стерлибашевский район, Кундрякский сельсовет, д.Табулда, Комсомольская, 14		0101000020E61000001F4AB4E4F1B84B407D3F355EBAA54A40
20585	7	61	\N	58731	66225	\N	54.947520748059901	село Суюндюково, улица Нагорная, дом 1А		0101000020E6100000A374E95F92C04A40F9A23D5E48794B40
21762	7	61	\N	1043	64805	\N	54.461970000000001	село Суук-Чишма, Пушкина, 22а		0101000020E61000000589EDEE01FA4B40D7DD3CD5213B4B40
21349	7	61	\N	58304	64626	\N	54.109020999999998	Республика Башкортостан, Ермекеевский район, Кызыл-Ярский сельсовет, с. Суерметово, Комсомольская, 36		0101000020E610000007B64AB038BE4A40E2C96E66F40D4B40
20450	7	61	\N	58362	64824	\N	54.221632	Республика Башкортостан, Аургазинский район, Уршакский сельсовет, д.Субхангулово, Ленина, 31а		0101000020E6100000EB538EC9E2CA4B40A0DFF76F5E1C4B40
22530	7	61	\N	33034	64562	\N	54.519432000000002	Республика Башкортостан, Уфимский район, д. Стуколино, Школьная, 16		0101000020E61000005F402FDCB9F04B40793F6EBF7C424B40
20187	7	61	\N	15983	63259	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Октября, 5А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20184	7	61	\N	15983	63259	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Октября, 35		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20183	7	61	\N	15983	63259	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Октября, 41		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20181	7	61	\N	15983	63259	\N	53.6514180686275	Республика Башкортостан, город Стерлитамак, проспект Октября, 69	Россия, республика Башкортостан, Стерлитамак	0101000020E6100000DC2BF3565DFB4B404B033FAA61D34A40
20176	7	61	\N	15983	63259	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Октября, 16А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20163	7	61	\N	15983	63446	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 30В		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20157	7	61	\N	15983	63446	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 61		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20156	7	61	\N	15983	63446	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 47		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20153	7	61	\N	15983	63446	\N	53.625506350141301	Республика Башкортостан, город Стерлитамак, просект Ленина, 37		0101000020E6100000A391CF2B9EF64B40D4B9A29410D04A40
20152	7	61	\N	15983	63446	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 18		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20147	7	61	\N	15983	63446	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 2А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20117	7	61	\N	15983	63497	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Южная, 20		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20110	7	61	\N	15983	63497	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Южная, 148		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20155	7	61	\N	15983	63457	\N	53.650602388328203	Республика Башкортостан, город Стерлитамак, Элеваторная, 80	Россия, республика Башкортостан, Стерлитамак	0101000020E610000042CD902A8AFB4B40295B24ED46D34A40
20114	7	61	\N	15983	63587	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Шафиева, 9		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20113	7	61	\N	15983	63587	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Шафиева, 23		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20168	7	61	\N	15983	63451	\N	53.658352603033798	Республика Башкортостан, город Стерлитамак, Шаймуратова, 9	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000319A95ED43FA4B409B1C3EE944D44A40
20167	7	61	\N	15983	63451	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Шаймуратова, 5А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20133	7	61	\N	15983	63575	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Чехова, 8		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20085	7	61	\N	15983	63575	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Чехова, 12		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20212	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 216		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20171	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 149		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20170	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 196		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20169	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 194		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20164	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 101А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20123	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 50		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20122	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 18		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20116	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 58		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20115	7	61	\N	15983	63381	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Худайбердина, 74	Россия, республика Башкортостан, Стерлитамак	0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20120	7	61	\N	15983	63499	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Фучика, 1		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20140	7	61	\N	15983	63353	\N	53.673441018556801	Республика Башкортостан, город Стерлитамак, Тукаева, 2Д	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E61000008ECBB8A981FC4B408C648F5033D64A40
20139	7	61	\N	15983	63353	\N	53.648562620213703	Республика Башкортостан, город Стерлитамак, Тукаева, 2Г		0101000020E61000008D0A9C6C03F74B40A532C51C04D34A40
20137	7	61	\N	15983	63353	\N	53.651010330054298	Республика Башкортостан, город Стерлитамак, Тукаева, 9	Россия, республика Башкортостан, Стерлитамак	0101000020E6100000A67C08AA46FB4B403AAFB14B54D34A40
20208	7	61	\N	15983	63635	\N	53.598608382666001	Республика Башкортостан, город Стерлитамак, Суханова, 4	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000BE141E34BBF84B40DE8FDB2F9FCC4A40
20207	7	61	\N	15983	63453	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Стерлибашевский тракт, 39		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20106	7	61	\N	15983	63453	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Стерлибашевский тракт, 29		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20141	7	61	\N	15983	63256	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Социалистическая, 35		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20138	7	61	\N	15983	63256	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Социалистическая, 21		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20136	7	61	\N	15983	63256	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Социалистическая, 5		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20126	7	61	\N	15983	63627	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Сакко и Ванцетти, 68		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20112	7	61	\N	15983	63785	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Сазонова, 16А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20151	7	61	\N	15983	63784	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Революционная, 9А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20159	7	61	\N	15983	63597	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 69		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20158	7	61	\N	15983	63597	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 81Б		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20109	7	61	\N	15983	63625	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Полевая, 29		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20130	7	61	\N	15983	63260	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Паровозная, 3А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20189	7	61	\N	15983	63631	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Островского, 2		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20111	7	61	\N	15983	63995	\N	53.6813908373082	Республика Башкортостан, город Стерлитамак, Оренбургский тракт, 24	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000960A2AAA7EFF4B40F564FED137D74A40
20179	7	61	\N	15983	63356	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Октября, 2		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20146	7	61	\N	15983	63257	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Одесская, 4		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20166	7	61	\N	15983	63532	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Николаева, 2А	Россия, республика Башкортостан, Стерлитамак	0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20149	7	61	\N	15983	63532	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Николаева, 7	Россия, республика Башкортостан, Стерлитамак	0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20148	7	61	\N	15983	63532	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Николаева, 124		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20121	7	61	\N	15983	63715	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Мира, 47	Россия, республика Башкортостан, Стерлитамак	0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20143	7	61	\N	15983	63534	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Макаренко, 1		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20135	7	61	\N	15983	63718	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Лесная, 20		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20161	7	61	\N	15983	63504	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, проспект Ленина, 28Б		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20186	7	61	\N	15983	63455	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Л. Толстого, 9		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20190	7	61	\N	15983	63508	\N	53.606521336748699	Республика Башкортостан, город Стерлитамак, Курчатова, 36	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E61000002DD1596611F84B402AABE97AA2CD4A40
20178	7	61	\N	15983	63508	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Курчатова, 3		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20177	7	61	\N	15983	63508	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Курчатова, 14		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20204	7	61	\N	15983	63354	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Коммунистическая, 82		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20203	7	61	\N	15983	63354	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Коммунистическая, 84		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20198	7	61	\N	15983	63354	\N	53.650398415978003	Республика Башкортостан, город Стерлитамак, Коммунистическая, 104	Россия, республика Башкортостан, Стерлитамак	0101000020E6100000F4A44C6A68FB4B4021B1DD3D40D34A40
20196	7	61	\N	15983	63354	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Коммунистическая, 40		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20175	7	61	\N	15983	63354	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Коммунистическая, 23		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20174	7	61	\N	15983	63354	\N	53.629383953591898	Республика Башкортостан, город Стерлитамак, Коммунистическая, 43	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000ED65DB696BF84B401650A8A78FD04A40
20173	7	61	\N	15983	63354	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Коммунистическая, 10	Россия, республика Башкортостан, Стерлитамак	0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20150	7	61	\N	15983	63354	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Коммунистическая, 8		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20185	7	61	\N	15983	63362	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Комарова, 2		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20134	7	61	\N	15983	63355	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, К. Маркса, 150		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20124	7	61	\N	15983	63355	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, К. Маркса, 125		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20119	7	61	\N	15983	63355	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, К. Маркса, 54		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20209	7	61	\N	15983	64094	\N	53.614611430237296	Республика Башкортостан, город Стерлитамак, Ивлева, 9		0101000020E6100000F2EF332E1CFA4B408461C092ABCE4A40
20194	7	61	\N	15983	63258	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Ибрагимова, 1		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20193	7	61	\N	15983	63258	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Ибрагимова, 14		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20165	7	61	\N	15983	63589	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Дружбы, 37		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20162	7	61	\N	15983	63358	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Голикова, 24А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20199	7	61	\N	15983	63489	\N	53.595098127799098	Республика Башкортостан, город Стерлитамак, Гоголя, 122	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000CB845FEAE7F74B401FF5D72B2CCC4A40
20108	7	61	\N	15983	63489	\N	53.599386781873697	Республика Башкортостан, город Стерлитамак, Гоголя, 118	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000CBDAA6785CF84B40E35295B6B8CC4A40
20107	7	61	\N	15983	63489	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Гоголя, 147		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20160	7	61	\N	15983	63588	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Волочаевская, 15А	Россия, республика Башкортостан, Стерлитамак	0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20154	7	61	\N	15983	63588	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Волочаевская, 2		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20131	7	61	\N	15983	62314	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Вокзальная, 26А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20129	7	61	\N	15983	62314	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Вокзальная, 2Г		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20128	7	61	\N	15983	62314	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Вокзальная, 2Д		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20125	7	61	\N	15983	62314	\N	53.665489692289498	Республика Башкортостан, город Стерлитамак, Вокзальная, 2	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000E6E786A6ECFA4B4053E8BCC62ED54A40
20144	7	61	\N	15983	63628	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Воинов-интернационалистов, 19		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20145	7	61	\N	15983	63439	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Бородина, 3		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20192	7	61	\N	15983	63393	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Блюхера, 15		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20191	7	61	\N	15983	63393	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Блюхера, 13		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20182	7	61	\N	15983	63393	\N	53.625315011756001	Республика Башкортостан, город Стерлитамак, Блюхера, 10	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E61000005CC64D0D34F54B40605969520AD04A40
20211	7	61	\N	15983	63363	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Артема, 146А		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20206	7	61	\N	15983	63363	\N	53.6314246537261	Республика Башкортостан, город Стерлитамак, Артема, 98		0101000020E6100000BC033C69E1FA4B403B70CE88D2D04A40
20200	7	61	\N	15983	63363	\N	53.618190225480298	Республика Башкортостан, город Стерлитамак, Артема, 115	Россия, республика Башкортостан, Стерлитамакский район	0101000020E610000050C6F8307BF34B406C5B94D920CF4A40
20197	7	61	\N	15983	63363	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Артема, 71		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20180	7	61	\N	15983	63363	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Артема, 27		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20172	7	61	\N	15983	63363	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Артема, 13	Россия, республика Башкортостан, Стерлитамак	0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20188	7	61	\N	15983	63591	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, А. Невского, 27		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20118	7	61	\N	15983	63712	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, 23 Мая, 18		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
20195	7	61	\N	15983	63262	\N	53.651622000000003	Республика Башкортостан, город Стерлитамак, Гоголя, 115		0101000020E61000006ABFB51325FB4B4054AD855968D34A40
22424	7	61	\N	58368	64830	\N	56.251806999999999	с.Старый Курдым, Центральная, 23		0101000020E6100000E90AB6114FBE4B40B2F336363B204C40
22327	7	61	\N	58538	65393	\N	53.483935000000002	Республика Башкортостан, Стерлибашевский район, Старокалкашевский сельсовет, д.Старый Калкаш, Молодежная, 1/А		0101000020E610000094DA8B683BB24B40E4310395F1BD4A40
21718	7	61	\N	58498	65219	\N	55.893309000000002	д.Старый Акбуляк, Салавата, 44		0101000020E6100000CEC47421565F4C407A1C06F357F24B40
21740	7	61	\N	32224	64269	\N	54.567774	деревня Старые Киешки, Октября, 34/1		0101000020E6100000CEE15AED61074C4072C284D1AC484B40
20544	7	61	\N	58352	64797	\N	55.123924000000002	село Старые Балыклы, улица Миасара Басырова, дом 47А		0101000020E6100000C231CB9E04DE4A404298DBBDDC8F4B40
21315	7	61	\N	58319	64684	\N	55.445717000000002	Республика Башкортостан, Дюртюлинский район, Такарликовский сельсовет, с.Старосултанбеково, Матросова, 15		0101000020E6100000D63730B9516C4B40B82231410DB94B40
22004	7	61	\N	58433	64998	\N	52.432808999999999	Республика Башкортостан, Куюргазинский район, Мурапталовский сельсовет, д.Старомурапталово, Школьная, 1 а		0101000020E6100000971FB8CA13E64B400D350A4966374A40
21197	7	61	\N	58534	65382	\N	54.273466999999997	Республика Башкортостан, Давлекановский район, Имай-Кармалинский сельсовет, с.Старомрясево, Центральная, 1		0101000020E6100000946A9F8EC7C24B4082C476F700234B40
20397	7	61	\N	58325	64708	\N	56.091828	Республика Башкортостан, Аскинский район, Урмиязовский сельсовет, д.Старокочкильдино, Комсомольская, 23		0101000020E6100000D15966118A6D4C40B56D1805C10B4C40
21288	7	61	\N	58668	65940	\N	55.58961	Республика Башкортостан, Дюртюлинский район, Маядыковский сельсовет, с.Старокангышево, Ленина, 13		0101000020E61000005A12A0A696794B4081B2295778CB4B40
22779	7	61	\N	58608	65719	\N	55.074596999999997	село Староихсаново, Днепр, 2		0101000020E610000059F78F85E8864B409AB0FD648C894B40
20573	7	61	\N	58625	65764	\N	55.075679999999998	село Старогусево, улица Центральная, дом 51		0101000020E61000009DD66D50FB174B400B7BDAE1AF894B40
22241	7	61	\N	58522	65325	\N	55.199947999999999	д.Старобедеево, Центральная, 70		0101000020E61000005E4D9EB29A4C4C40477364E597994B40
21938	7	61	\N	58422	64975	\N	55.148997000000001	Республика Башкортостан, Кушнаренковский район, д.Старобаскаково, Школьная, 7		0101000020E610000046EBA86A82A64B40DF196D5512934B40
21774	7	61	\N	58245	64494	\N	54.189008000000001	деревня Старобабичево, Садовая, 3		0101000020E610000089EDEE01BA114C405857056A31184B40
20304	7	61	\N	58594	65676	\N	54.126187999999999	Республика Башкортостан, Альшеевский район, Казанский сельсовет, д. Староаккулаево, Энгельса, 27		0101000020E61000001D3C139A247E4B40E692AAED26104B40
20448	7	61	\N	58599	65685	\N	54.120373000000001	Республика Башкортостан, Аургазинский район, Уршакский сельсовет, с.Староабсалямово, Ленина, 56в		0101000020E6100000D9CEF753E3D34B402429E961680F4B40
22000	7	61	\N	58432	64996	\N	52.584466999999997	Республика Башкортостан, Куюргазинский район, Отрадинский сельсовет, с.Старая Отрада, Дружбы, 61		0101000020E61000008198840B79EC4B40AD4B8DD0CF4A4A40
21840	7	61	\N	58404	64936	\N	55.801206999999998	с.Старая Мушта, Молодежная, 2		0101000020E6100000A9DDAF027C1F4B40C32973F38DE64B40
21705	7	61	\N	58736	66276	\N	54.232548000000001	д.Сосновый Бор, Школьная, 1		0101000020E61000000490DAC4C9294B4007600322C41D4B40
20094	7	61	\N	15877	63702	\N	52.710205000000002	Республика Башкортостан, город Сибай, проспект Горняков, дом 4		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20097	7	61	\N	15877	63346	\N	52.710205188872997	Республика Башкортостан, город Сибай, улица Чайковского, дом 30	Россия, республика Башкортостан, Сибай	0101000020E6100000E9818FC18A554D40543A58FFE75A4A40
20084	7	61	7458	\N	63346	\N	52.727091659289698	Республика Башкортостан, город Сибай, улица Чайковского, дом 1	Россия, республика Башкортостан, Сибай городской округ	0101000020E6100000FA9CBB5D2F554D407497C459115D4A40
20086	7	61	\N	15877	63492	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Цеткин, дом 10		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20103	7	61	\N	15877	63681	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Старательская, дом 12а		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20105	7	61	\N	15877	63352	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Сибаева, дом 45		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20090	7	61	\N	15877	63255	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Маяковского, дом 18		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20089	7	61	\N	15877	63747	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Ленина, дом 3		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20083	7	61	\N	15877	63747	\N	52.722088945549203	Республика Башкортостан, город Сибай, улица Ленина, дом 40	Россия, республика Башкортостан, Сибай городской округ	0101000020E610000015527E52ED534D4092E68F696D5C4A40
20096	7	61	\N	15877	63708	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Кусимова, дом 7		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20099	7	61	\N	15877	63261	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Заки Валиди, дом 55		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20092	7	61	\N	15877	63261	\N	52.722017287907697	Республика Башкортостан, город Сибай, улица Заки Валиди, дом 53	Россия, республика Башкортостан, Сибай городской округ	0101000020E6100000E2E6543200564D40F913950D6B5C4A40
20100	7	61	\N	15877	64227	\N	52.705956477725898	Республика Башкортостан, город Сибай, улица Достоевского, дом 4	Россия, республика Башкортостан, Сибай городской округ	0101000020E610000088F2052D24544D401E3526C45C5A4A40
20088	7	61	\N	15877	63487	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Горького, дом 27		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20087	7	61	\N	15877	63487	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Горького, дом 29		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20091	7	61	\N	15877	63608	\N	52.721593853974902	Республика Башкортостан, город Сибай, проспект Горняков, дом 2		0101000020E61000007AA52C431C574D40B37E33315D5C4A40
20102	7	61	\N	15877	63294	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Горная, дом 55		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20101	7	61	\N	15877	63294	\N	52.688409851038799	Республика Башкортостан, город Сибай, улица Горная, дом 40	Россия, республика Башкортостан, Сибай городской округ	0101000020E61000006346787B10544D40A31EA2D11D584A40
20064	7	61	\N	7789	63584	\N	53.375647000000001	Республика Башкортостан, город Салават, ул. Губкина, 7		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20104	7	61	\N	15877	64338	\N	52.718440769853203	Республика Башкортостан, город Сибай, улица Гаражная, дом 1	Россия, республика Башкортостан, Сибай городской округ	0101000020E6100000228B34F10E564D40828DEBDFF55B4A40
20098	7	61	\N	15877	63253	\N	52.710205000000002	Республика Башкортостан, город Сибай, улица Белова, дом 21		0101000020E6100000D5AE09698D554D40543A58FFE75A4A40
20095	7	61	\N	15877	63253	\N	52.710413703870699	Республика Башкортостан, город Сибай, улица Белова, дом 36	Россия, республика Башкортостан, Сибай	0101000020E610000011FE45D098554D406E4F90D8EE5A4A40
22908	7	61	\N	58372	64843	\N	56.191293000000002	с. Сибады, Байман, 29		0101000020E610000035D07CCEDD9E4B40147AFD497C184C40
20243	7	61	\N	58674	65971	\N	53.390008999999999	д.Селивановский, ул.Центральная, 33		0101000020E6100000978C63247B584D40A5129ED0EBB14A40
22428	7	61	\N	58491	65193	\N	56.254272	д.Сараштыбаш, Центральная, 62		0101000020E6100000B91CAF40F4B24B40EE2422FC8B204C40
22312	7	61	\N	58529	65355	\N	53.351337999999998	Республика Башкортостан, Стерлибашевский район, Сарайсинский сельсовет, д.Сарайсино, Школьная, 1А		0101000020E61000001EA5129ED0CB4B40C8EBC1A4F8AC4A40
20966	7	61	\N	58471	65100	\N	55.281216000000001	с. Саннинское, Школьная, 56		0101000020E6100000E692AAED26124C40548EC9E2FEA34B40
22803	7	61	\N	58370	64838	\N	54.620677999999998	д.Санжаровка, Школьная, 2/1		0101000020E6100000030B60CAC0BF4B4060AC6F60724F4B40
21972	7	61	\N	58481	65156	\N	52.662723999999997	Республика Башкортостан, Куюргазинский район, Ермолаевский сельсовет, д.Сандин 2-й, Центральная, 2 А		0101000020E61000004F5AB8ACC2D04B401C23D923D4544A40
20913	7	61	\N	58531	65362	\N	54.627110000000002	с.Самарино, Центральная, 1		0101000020E61000003F90BC73287B4B404E7FF62345504B40
21889	7	61	\N	58702	66072	\N	52.566510999999998	Республика Башкортостан, Кугарчинский район, Исимовский сельсовет, д. Салихово, Советская, 9Б		0101000020E6100000D0EFFB372F424C4081E9B46E83484A40
21442	7	61	\N	58689	66026	\N	56.013558000000003	Салимово, ул.М.Гафури, 14		0101000020E610000003B00111E2BC4B40B24CBF44BC014C40
20268	7	61	\N	58446	65047	\N	53.468538000000002	д.Салаватово, ул.Школьная, 93		0101000020E61000005133A48AE2494D4075779D0DF9BB4A40
20055	7	61	\N	7789	63373	\N	53.351041840057803	Республика Башкортостан, город Салават, Б. Космонавтов, 6	Россия, республика Башкортостан, Салават	0101000020E6100000FB592C45F2F54B40DFC2BAF1EEAC4A40
20047	7	61	\N	7789	63485	\N	53.375647000000001	Республика Башкортостан, город Салават, Школьный переулок, 7		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20046	7	61	\N	7789	63420	\N	53.375647000000001	Республика Башкортостан, город Салават, Фурманова, 4		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20081	7	61	\N	7789	63252	\N	53.375647000000001	Республика Башкортостан, город Салават, Уфимская, 120а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20065	7	61	\N	7789	63252	\N	53.375647000000001	Республика Башкортостан, город Салават, Уфимская, 106		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20056	7	61	\N	7789	63252	\N	53.375647000000001	Республика Башкортостан, город Салават, Уфимская, 90	Россия, республика Башкортостан, Салават	0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20050	7	61	\N	7789	63252	\N	53.375647000000001	Республика Башкортостан, город Салават, Уфимская, 72		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20048	7	61	\N	7789	63252	\N	53.375647000000001	Республика Башкортостан, город Салават, Уфимская, 58		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20031	7	61	\N	7789	64246	\N	53.375647000000001	Республика Башкортостан, город Салават, Строителей, 7		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20034	7	61	\N	7789	63994	\N	53.375647000000001	Республика Башкортостан, город Салават, Пугачева, 7		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20038	7	61	\N	7789	63344	\N	53.369692906843298	Республика Башкортостан, город Салават, Первомаяская, 23		0101000020E61000000C1EA67D73F34B40B247A81952AF4A40
20071	7	61	\N	7789	63461	\N	53.375647000000001	Республика Башкортостан, город Салават, Островского, 70		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20060	7	61	\N	7789	63461	\N	53.375647000000001	Республика Башкортостан, город Салават, Островского, 32		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20053	7	61	\N	7789	66752	\N	53.356549443366603	Республика Башкортостан, город Салават, Октябрьская, 43	Россия, республика Башкортостан, Салават	0101000020E61000000664AF777FF84B40F435CB65A3AD4A40
20030	7	61	\N	7789	63247	\N	53.375647000000001	Республика Башкортостан, город Салават, Монтажников, 34а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20041	7	61	\N	7789	63408	\N	53.375647000000001	Республика Башкортостан, город Салават, Матросова, 18		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20036	7	61	\N	7789	63408	\N	53.356344044425498	Республика Башкортостан, город Салават, Матросова, 27	Россия, республика Башкортостан, Салават	0101000020E61000006E1805C1E3F74B401B1021AE9CAD4A40
20044	7	61	\N	7789	63421	\N	53.375647000000001	Республика Башкортостан, город Салават, Ленина, 14		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20043	7	61	\N	7789	63421	\N	53.375647000000001	Республика Башкортостан, город Салават, Ленина, 3		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20029	7	61	\N	7789	63623	\N	53.375647000000001	Республика Башкортостан, город Салават, Комсомольская, 20		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20072	7	61	\N	7789	63573	\N	53.375647000000001	Республика Башкортостан, город Салават, Калинина, 78		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20059	7	61	\N	7789	63573	\N	53.375647000000001	Республика Башкортостан, город Салават, Калинина, 47		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20040	7	61	\N	7789	63779	\N	53.375647000000001	Республика Башкортостан, город Салават, К. Маркса, 13		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20075	7	61	\N	7789	63584	\N	53.375647000000001	Республика Башкортостан, город Салават, ул.Губкина, 22б		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20074	7	61	\N	7789	63584	\N	53.362505579998903	Республика Башкортостан, город Салават, ул. Губкина, 14/82	Россия, республика Башкортостан, Салават	0101000020E6100000EEEE01BA2FF74B40494DBB9866AE4A40
20073	7	61	\N	7789	63584	\N	53.375647000000001	Республика Башкортостан, город Салават, Губкина, 14		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20063	7	61	\N	7789	63584	\N	53.375647000000001	Республика Башкортостан, город Салават, Губкина, 12а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20082	7	61	\N	7789	63401	\N	53.375647000000001	Республика Башкортостан, город Салават, Губайдуллина, 4а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20039	7	61	\N	7789	63405	\N	53.375647000000001	Республика Башкортостан, город Салават, Горького, 3		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20035	7	61	\N	7789	63405	\N	53.375647000000001	Республика Башкортостан, город Салават, Горького, 23		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20045	7	61	\N	7789	63348	\N	53.375647000000001	Республика Башкортостан, город Салават, Гагарина, 21/2		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20027	7	61	\N	7789	63348	\N	53.375647000000001	Республика Башкортостан, город Салават, Гагарина, 8		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20080	7	61	\N	7789	63705	\N	53.3670234705192	Республика Башкортостан, город Салават, Бочкарева, 5	Россия, республика Башкортостан, Салават	0101000020E61000003602F1BA7EF34B409EF0129CFAAE4A40
20032	7	61	\N	7789	63683	\N	53.369436237577098	Республика Башкортостан, город Салават, Б.Хмельницкого, 29	Россия, республика Башкортостан, Салават	0101000020E6100000EAB12D03CEF64B4087FBC8AD49AF4A40
20078	7	61	\N	7789	9723	\N	53.375647000000001	Республика Башкортостан, город Салават, б.С.Юлаева, 20а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20076	7	61	\N	7789	9723	\N	53.367742181447902	Республика Башкортостан, город Салават, Б.С. Юлаева, 36	Россия, республика Башкортостан, Салават	0101000020E61000003B71395E81F64B40CDAE7B2B12AF4A40
20079	7	61	\N	7789	9702	\N	53.375647000000001	Республика Башкортостан, город Салават, Б.С. Юлаева, 10		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20077	7	61	\N	7789	9702	\N	53.375647000000001	Республика Башкортостан, город Салават, Б.С. Юлаева, 32а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20070	7	61	\N	7789	9702	\N	53.362094838809497	Республика Башкортостан, город Салават, Б.С. Юлаева, 61	Россия, республика Башкортостан, Салават	0101000020E610000006A051BAF4F54B40C685032159AE4A40
20069	7	61	\N	7789	9702	\N	53.375647000000001	Республика Башкортостан, город Салават, Б.С. Юлаева, 3		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20068	7	61	\N	7789	9702	\N	53.375647000000001	Республика Башкортостан, город Салават, Б.С. Юлаева, 37		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20067	7	61	\N	7789	9702	\N	53.375647000000001	Республика Башкортостан, город Салават, Б.С. Юлаева, 21		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20033	7	61	\N	7789	63788	\N	53.369673656702197	Республика Башкортостан, город Салават, Б. Хмельницкого, 45	Россия, республика Башкортостан, Салават	0101000020E6100000D09849D40BF84B403C17467A51AF4A40
20058	7	61	\N	7789	63347	\N	53.375647000000001	Республика Башкортостан, город Салават, Б. Космонавтов, 22а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20057	7	61	\N	7789	63347	\N	53.375647000000001	Республика Башкортостан, город Салават, Б. Космонавтов, 20		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20054	7	61	\N	7789	63347	\N	53.375647000000001	Республика Башкортостан, город Салават, Б. Космонавтов, 41а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20052	7	61	\N	7789	63347	\N	53.375647000000001	Республика Башкортостан, город Салават, Б. Космонавтов, 23		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20051	7	61	\N	7789	63347	\N	53.375647000000001	Республика Башкортостан, город Салават, Б. Космонавтов, 21		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20062	7	61	\N	7789	63431	\N	53.375647000000001	Республика Башкортостан, город Салават, 30 лет Победы, 5		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20061	7	61	\N	7789	63431	\N	53.375647000000001	Республика Башкортостан, город Салават, 30 лет Победы, 16		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20049	7	61	\N	7789	66664	\N	53.375647000000001	Республика Башкортостан, город Салават, 21-го съезда, 124		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
20066	7	61	\N	7789	63787	\N	53.375647000000001	Республика Башкортостан, город Салават, Б.С. Юлаева, 21а		0101000020E61000005AA0DD21C5F44B4096EB6D3315B04A40
21676	7	61	\N	58159	64060	\N	55.951203999999997	деревня Сазово, Центральная, 21		0101000020E610000060066344A2844B4085E97B0DC1F94B40
21829	7	61	\N	58181	64170	\N	55.814597999999997	д.Редькино, Ленина, 57		0101000020E610000025CD1FD3DA424B4089B14CBF44E84B40
20249	7	61	\N	3847	66741	\N	54.785345	д.Покровка, ул. Школьная, 1 а	Россия, республика Башкортостан, деревня Покровка, улица Нижняя Покровская	0101000020E6100000A56ABB09BEE74B40DF89592F86644B40
22521	7	61	\N	3847	65506	\N	54.785345	д.Покровка, Центральная, 15		0101000020E6100000A56ABB09BEE74B40DF89592F86644B40
22822	7	61	\N	58315	64655	\N	54.343094999999998	с.Петряево, Сергея Алексеева, 7		0101000020E6100000300E2E1D73CC4B40E7357689EA2B4B40
20391	7	61	\N	58314	64652	\N	56.095996	Республика Башкортостан, Аскинский район, Петропавловский сельсовет, д.Петропавловка, Космонавтов, 2		0101000020E6100000C85F5AD427354C40FE45D098490C4C40
20681	7	61	\N	58248	64505	\N	54.046888000000003	Республика Башкортостан, Белебеевский район, Донской сельсовет, д.Пахарь, Центральная, 27		0101000020E61000004580D3BB78254B4095490D6D00064B40
21993	7	61	\N	58711	66118	\N	52.667966999999997	Республика Башкортостан, Куюргазинский район, Кривле-Илюшкинский сельсовет, д.Павловка, Центральная, 58		0101000020E6100000386A85E97B0B4C4053E751F17F554A40
19991	7	61	\N	7989	64123	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Школьная, 1		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20024	7	61	\N	7989	63564	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Шашина, 2		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20010	7	61	\N	7989	63400	\N	54.4890580319883	Республика Башкортостан, город Октябрьский, Трипольского, 67	Россия, республика Башкортостан, Октябрьский	0101000020E61000008D45D3D9C9C24A4070ECD973993E4B40
20006	7	61	\N	7989	63613	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Свердлова, 76		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20957	7	61	\N	57935	63603	\N	55.034714000000001	г. Благовещенск, Братьев Першиных, 5/1		0101000020E6100000895C70067FFD4B404F5B238271844B40
20018	7	61	\N	7989	63402	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Садовое кольцо, 155		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20009	7	61	\N	7989	63402	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Садовое кольцо, 55		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
19998	7	61	\N	7989	63402	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Садовое кольцо, 174		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
19992	7	61	\N	7989	63392	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Партизанская, 9		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20007	7	61	\N	7989	63482	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Островского, 59		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
19999	7	61	\N	7989	66658	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Матросова,121		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20000	7	61	\N	7989	64337	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Ломоносова, 1а		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20005	7	61	\N	7989	63614	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Лермонтова, 3		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20008	7	61	\N	7989	63624	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Ленина, 37		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20002	7	61	\N	7989	63624	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Ленина, 4		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20011	7	61	\N	7989	63483	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Кувыкина, 15		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20001	7	61	\N	7989	63610	\N	54.492255912337598	Республика Башкортостан, город Октябрьский, Крупской, 1	Россия, республика Башкортостан, Октябрьский	0101000020E61000006D5512D907C14A4040A19E3E023F4B40
20016	7	61	\N	7989	63617	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Космонавтов, 41/1		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20012	7	61	\N	7989	63772	\N	54.484860432690702	Республика Башкортостан, город Октябрьский, Королева, 1	Россия, республика Башкортостан, Октябрьский	0101000020E610000079E8BB5B59C24A40BC9179E40F3E4B40
20017	7	61	\N	7989	63561	\N	54.487658880320197	Республика Башкортостан, город Октябрьский, Кооперативная, 105	Россия, республика Башкортостан, Октябрьский	0101000020E6100000B8921D1B81BC4A40CF4C309C6B3E4B40
20003	7	61	\N	7989	63699	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Комсомольская, 3		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
19995	7	61	\N	7989	63699	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Комсомольская, 33		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
19993	7	61	\N	7989	63699	\N	54.485716228391702	Республика Башкортостан, город Октябрьский, Комсомольская, 22	Россия, республика Башкортостан, Октябрьский	0101000020E610000017BA1281EABD4A406C921FF12B3E4B40
19997	7	61	\N	7989	63295	\N	54.485260222702699	Республика Башкортостан, город Октябрьский, Девонская, 54а	Россия, республика Башкортостан, Октябрьский	0101000020E61000006616A1D80ABE4A404A07EBFF1C3E4B40
19994	7	61	\N	7989	63295	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Девонская, 8а		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
19996	7	61	\N	7989	63768	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Герцена, 18		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20004	7	61	\N	7989	63696	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, Геофизиков, 3		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20028	7	61	\N	7989	63626	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 35 микрорайон, школа № 12		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20026	7	61	\N	7989	63626	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 35 микрорайон, гимназия № 3		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20025	7	61	\N	7989	63626	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 35 микрорайон, 15а		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20023	7	61	\N	7989	63243	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 34 микрорайон, школа №20		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20022	7	61	\N	7989	63243	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 34 микрорайон, школа № 20		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20021	7	61	\N	7989	63243	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 34 микрорайон, 6		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20020	7	61	\N	7989	63404	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 29 микрорайон, школа № 22		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20019	7	61	\N	7989	63404	\N	54.485460000000003	Республика Башкортостан, город Октябрьский, 29  микрорайон, школа № 22		0101000020E6100000A165DD3F16BE4A4012C2A38D233E4B40
20015	7	61	\N	7989	63341	\N	54.483860940482302	Республика Башкортостан, город Октябрьский, 25 микрорайон, школа № 8		0101000020E61000007EC7F0D8CFBC4A40A9674128EF3D4B40
20014	7	61	\N	7989	63341	\N	54.486472062186699	Республика Башкортостан, город Октябрьский, 25 микрорайон, ПТУ № 68	Россия, республика Башкортостан, Октябрьский	0101000020E610000056D3F544D7C14A40B935E9B6443E4B40
21842	7	61	\N	58405	64938	\N	55.865642000000001	д.Новый Янзигит, Дорожная, 20		0101000020E61000005854C4E924194B40A305685BCDEE4B40
20865	7	61	\N	58631	65795	\N	53.768241000000003	с.Новый Биктяш, Абдулинская, 33		0101000020E61000009755D80C70F74A40223999B855E24A40
21834	7	61	\N	58253	64520	\N	55.917006000000001	с.Новый Актанышбаш, Школьная, 35		0101000020E6100000556B6116DA274B402E1EDE7360F54B40
22434	7	61	\N	58692	66037	\N	56.224572000000002	с.Новые Татышлы, Школьная, 25		0101000020E6100000E5F1B4FCC0F74B4075CC79C6BE1C4C40
22474	7	61	\N	58583	65623	\N	54.463020999999998	с.Новые Бишинды, Центральная, 47		0101000020E610000013B70A62A0D54A403C2EAA45443B4B40
21087	7	61	\N	58458	65067	\N	55.757212000000003	д.Новошиликово, Озерная, 25		0101000020E610000083C0CAA145724B40C311A452ECE04B40
20347	7	61	\N	58361	64820	\N	54.528258000000001	д. Новошареево, Нижняя, 16		0101000020E6100000D5B32094F7574C40D9EC48F59D434B40
21303	7	61	\N	58295	64603	\N	55.405152999999999	Республика Башкортостан, Дюртюлинский район, Старобаишевский сельсовет, д.Новоуртаево, Агидель, 6		0101000020E6100000A359D93EE4A14B402A70B20DDCB34B40
20564	7	61	\N	58703	66074	\N	55.136828000000001	село Новоурсаево, улица Ленина, дом 37		0101000020E6100000BA2F67B62BB44A40AB96749483914B40
21856	7	61	\N	58698	66055	\N	52.678206000000003	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, с. Новониколаевское, Молодежная, 43		0101000020E610000064963D096C444C40BAF94674CF564A40
22089	7	61	\N	58234	64453	\N	55.942180999999998	с. Новомуслюмово, Луговая, 85		0101000020E610000035D42824993B4D40CFF4126399F84B40
20571	7	61	\N	58369	64835	\N	55.075819000000003	село Новокуручево, улица Центральная, дом 38		0101000020E6100000AD6D8AC745054B402DB5DE6FB4894B40
21320	7	61	\N	58229	64431	\N	55.553334999999997	Республика Башкортостан, Дюртюлинский район, Учпилинский сельсовет, с.Новокангышево, Молодежная, 40		0101000020E61000001E882CD2C4854B40B75D68AED3C64B40
22359	7	61	\N	58373	64845	\N	56.350785999999999	с.Новокайпаново, Новая, 2		0101000020E610000055A69883A0E34B4084F23E8EE62C4C40
21843	7	61	\N	58191	64210	\N	55.920454565130903	с.Новокабаново, Центральная, 28	Россия, республика Башкортостан, Краснокамский район, село Новокабаново	0101000020E6100000B32781CD39F64A4047382D78D1F54B40
21998	7	61	\N	58430	64991	\N	52.683802	Республика Башкортостан, Куюргазинский район, Отрадинский сельсовет, д.Новая Уралка, Уральская, 25 а		0101000020E6100000B7CF2A33A5E94B403E78EDD286574A40
21837	7	61	\N	58403	64935	\N	55.901142	с.Нижняя Татья, Ленина, 26		0101000020E610000007B29E5A7D374B40A986FD9E58F34B40
22932	7	61	\N	58770	66424	\N	56.087379047728597	д. Нижний Чат, Ш.Худайбердина, 38	Россия, республика Башкортостан, Янаульский район, село Нижный Чат	0101000020E61000005376FA415DB44B40B8AD2D3C2F0B4C40
21744	7	61	\N	58353	64798	\N	54.200470000000003	деревня Нижний Тюкунь, Шоссейная, 19		0101000020E610000069554B3ACA314C4021EA3E00A9194B40
21167	7	61	\N	58533	65373	\N	53.741681	Республика Башкортостан, Гафурийский район, с. Нижний Ташбукан, Гафури, 37		0101000020E6100000B1A6B228EC484C4044882B67EFDE4A40
21391	7	61	\N	58638	65822	\N	51.986376999999997	Республика Башкортостан, Зианчуринский район, Муйнакский сельсовет, Нижний Муйнак, Юнай, 12		0101000020E6100000D28BDAFD2A5A4C406743FE9941FE4940
20708	7	61	\N	58247	64503	\N	55.819515000000003	Республика Башкортостан, Белокатайский район, Нижнеискушинский сельсовет, Нижний Искуш, Бунакова, 24		0101000020E6100000C6A69542205F4D406DCA15DEE5E84B40
21809	7	61	\N	58650	65871	\N	55.541508999999998	Республика Башкортостан, Кигинский район, Нижнекигинский сельсовет, село Нижние Киги, 8-марта, 1		0101000020E6100000B8CCE9B298404D40ADBEBA2A50C54B40
22430	7	61	\N	58227	64418	\N	56.208860000000001	с.Нижнебалтачево, Центарльная, 28		0101000020E61000004D6551D8450F4C40A6B8AAECBB1A4C40
21153	7	61	\N	2298	588	\N	54.616397999999997	х.Надеждинский, ул.Школьная, 20	Россия, республика Башкортостан, село Нижегородка, улица Школьная, 20	0101000020E6100000AE7FD767CEEC4B40EFA83121E64E4B40
22681	7	61	\N	2298	63807	\N	54.615094999999997	Республика Башкортостан, Федоровский район, Федоровский сельсовет с.Кузьминовка, Школьная, 6		0101000020E6100000E7C589AF76EC4B407077D66EBB4E4B40
22674	7	61	\N	2298	63807	\N	54.615094999999997	Республика Башкортостан, Федоровский район, Гончаровский сельсовет с.Алешкино, Школьная, 6		0101000020E6100000E7C589AF76EC4B407077D66EBB4E4B40
22668	7	61	\N	2298	63807	\N	54.614657000000001	Республика Башкортостан, Федоровский район, Денискинский сельсовет с.Кирюшкино, Школьная, 3		0101000020E6100000F357C85C19EC4B40F5A0A014AD4E4B40
22666	7	61	\N	2298	63807	\N	54.615439000000002	Республика Башкортостан, Федоровский район, Разинский сельсовет д.Саитово, Школьная, 15		0101000020E61000007A8A1C226EEC4B406BD784B4C64E4B40
22663	7	61	\N	2298	63807	\N	54.616252000000003	Республика Башкортостан, Федоровский район, Михайловский сельсовет с.Юлдашево, Школьная, 25		0101000020E6100000D6027B4CA4EC4B401C0C7558E14E4B40
22657	7	61	\N	2298	63807	\N	54.614829	Республика Башкортостан, Федоровский район, Бала-Четырманский сельсовет д.Златоустовка, Школьная, 2		0101000020E610000051DA1B7C61EC4B40F2D077B7B24E4B40
22656	7	61	1261	\N	63807	\N	53.126694993750903	Республика Башкортостан, Федоровский район, Бала-Четырманский сельсовет с.Старый Четырман, Школьная, 23	Россия, республика Башкортостан, Федоровский район	0101000020E61000008995D1C8E7A34B408AC8B08A37904A40
21953	7	61	\N	2298	63807	\N	54.615203999999999	Республика Башкортостан, Кушнаренковский район, д.Сюльтюп, Школьная, 13		0101000020E610000068B114C957EC4B40272F3201BF4E4B40
20725	7	61	\N	2298	63807	\N	54.614525999999998	Республика Башкортостан, Белокатайский район, Атаршинский сельсовет, Атарша, Школьная, 1		0101000020E6100000774D486B0CEC4B405645B8C9A84E4B40
20466	7	61	\N	2298	63807	\N	54.615214999999999	Республика Башкортостан, Баймакский район, д.Сайгафар, улица Школьная, дом 8		0101000020E61000006AC18BBE82EC4B401B81785DBF4E4B40
20250	7	61	\N	2298	63807	\N	54.615808999999999	д.Самарского отделения совхоза, ул. Школьная, 16		0101000020E6100000E9F2E670ADEC4B408ECA4DD4D24E4B40
22807	7	61	\N	2298	66474	\N	54.607946840088097	д.Новая, Центральная, 29а	Россия, республика Башкортостан, село Нижегородка, улица Центральная	0101000020E610000087342A70B2ED4B40C5591135D14D4B40
22665	7	61	\N	2298	66481	\N	54.616607000000002	Республика Башкортостан, Федоровский район, Разинский сельсовет д.Ключевка, Школьная, 22		0101000020E6100000D72FD80DDBEC4B400ABE69FAEC4E4B40
22659	7	61	1261	\N	66481	\N	54.615214999999999	Республика Башкортостан, Федоровский район, Бала-Четырманский сельсовет с.Новояушево, Школьная, 8		0101000020E61000006AC18BBE82EC4B401B81785DBF4E4B40
20843	7	61	\N	2298	66481	\N	54.615527	д.Тулубаево, ул.Школьная,12а		0101000020E6100000E6E8F17B9BEC4B400A67B796C94E4B40
20945	7	61	\N	57935	63998	\N	55.034714000000001	г. Благовещенск, Братьев Кадомцевых, 9/2		0101000020E6100000895C70067FFD4B404F5B238271844B40
20313	7	61	\N	2298	66481	\N	54.615214999999999	Республика Башкортостан, Альшеевский район, Кызыльский сельсовет, д. Ярташлы, Школьная, 8		0101000020E61000006AC18BBE82EC4B401B81785DBF4E4B40
19973	7	61	\N	8531	63606	\N	56.096463	город Нефтекамск, Юбилейный проспект, 17		0101000020E6100000596B28B517234B4014234BE6580C4C40
19953	7	61	\N	8531	63469	\N	56.096463	город Нефтекамск, Трактовая, 41		0101000020E6100000596B28B517234B4014234BE6580C4C40
19950	7	61	\N	8531	63469	\N	56.096463	город Нефтекамск, Трактовая, 35		0101000020E6100000596B28B517234B4014234BE6580C4C40
19949	7	61	\N	8531	63469	\N	56.103085743527899	город Нефтекамск, Трактовая, 1	Россия, республика Башкортостан, Нефтекамск	0101000020E6100000E736E15E99214B4075560BEC310D4C40
19986	7	61	\N	8531	63246	\N	56.096463	город Нефтекамск, Строителей, 65а		0101000020E6100000596B28B517234B4014234BE6580C4C40
19982	7	61	\N	8531	63246	\N	56.096463	город Нефтекамск, Строителей, 89а	Россия, республика Башкортостан, Нефтекамск	0101000020E6100000596B28B517234B4014234BE6580C4C40
19987	7	61	\N	8531	63335	\N	56.096463	город Нефтекамск, Социалистическая, 54а		0101000020E6100000596B28B517234B4014234BE6580C4C40
19984	7	61	\N	8531	63335	\N	56.096463	город Нефтекамск, Социалистическая, 62в		0101000020E6100000596B28B517234B4014234BE6580C4C40
19980	7	61	\N	8531	63335	\N	56.096463	город Нефтекамск, Социалистическая, 74		0101000020E6100000596B28B517234B4014234BE6580C4C40
19972	7	61	\N	8531	63335	\N	56.104045094516103	город Нефтекамск, Социалистическая, 65	Россия, республика Башкортостан, Нефтекамск	0101000020E610000095BA641C23234B40FA27B858510D4C40
19970	7	61	\N	8531	63335	\N	56.096463	город Нефтекамск, Социалистическая, 42		0101000020E6100000596B28B517234B4014234BE6580C4C40
19965	7	61	\N	8531	63335	\N	56.096463	город Нефтекамск, Социалистическая, 45в		0101000020E6100000596B28B517234B4014234BE6580C4C40
19952	7	61	\N	8531	64413	\N	56.096463	город Нефтекамск, Сиреневая, 5		0101000020E6100000596B28B517234B4014234BE6580C4C40
19985	7	61	\N	8531	63245	\N	56.096463	город Нефтекамск, Победы, 5		0101000020E6100000596B28B517234B4014234BE6580C4C40
19976	7	61	\N	8531	63245	\N	56.096463	город Нефтекамск, Победы, 11		0101000020E6100000596B28B517234B4014234BE6580C4C40
19975	7	61	\N	8531	63245	\N	56.096463	город Нефтекамск, Победы, 10		0101000020E6100000596B28B517234B4014234BE6580C4C40
19958	7	61	\N	8531	63315	\N	56.096463	город Нефтекамск, Парковая, 18		0101000020E6100000596B28B517234B4014234BE6580C4C40
19968	7	61	\N	8531	63379	\N	56.096463	город Нефтекамск, Нефтяников, 2		0101000020E6100000596B28B517234B4014234BE6580C4C40
19967	7	61	\N	8531	63379	\N	56.096463	город Нефтекамск, Нефтяников, 11в		0101000020E6100000596B28B517234B4014234BE6580C4C40
19966	7	61	\N	8531	63379	\N	56.090394568820301	город Нефтекамск, Нефтяников, 24	Россия, республика Башкортостан, Нефтекамск	0101000020E61000000B43E4F4F5204B40685C3810920B4C40
19983	7	61	\N	8531	63241	\N	56.096463	город Нефтекамск, Ленина, 84а		0101000020E6100000596B28B517234B4014234BE6580C4C40
19981	7	61	\N	8531	63241	\N	56.096463	город Нефтекамск, Ленина, 39б		0101000020E6100000596B28B517234B4014234BE6580C4C40
19978	7	61	\N	8531	63241	\N	56.096463	город Нефтекамск, Ленина, 66		0101000020E6100000596B28B517234B4014234BE6580C4C40
19977	7	61	\N	8531	63241	\N	56.089166457936003	город Нефтекамск, Ленина, 23	Россия, республика Башкортостан, Нефтекамск	0101000020E6100000DFFC8689061F4B4023F59ECA690B4C40
19974	7	61	\N	8531	63241	\N	56.096463	город Нефтекамск, Ленина, 56		0101000020E6100000596B28B517234B4014234BE6580C4C40
19964	7	61	\N	8531	63241	\N	56.096463	город Нефтекамск, Ленина, 9		0101000020E6100000596B28B517234B4014234BE6580C4C40
19963	7	61	\N	8531	63241	\N	56.094354546206603	город Нефтекамск, Ленина, 5б	Россия, республика Башкортостан, Нефтекамск	0101000020E61000003A596ABDDF204B40679B1BD3130C4C40
19956	7	61	\N	8531	63387	\N	56.096463	город Нефтекамск, Кувыкина переулок, 10		0101000020E6100000596B28B517234B4014234BE6580C4C40
19971	7	61	\N	8531	63284	\N	56.096933334720099	город Нефтекамск, Комсомольский проспект, 17б	Россия, республика Башкортостан, Нефтекамск	0101000020E6100000D3F6AFAC34234B409B73F04C680C4C40
19969	7	61	\N	8531	63284	\N	56.095853862957	город Нефтекамск, Комсомольский проспект, 7	Россия, республика Башкортостан, Нефтекамск	0101000020E6100000D0F23CB83B234B406C98A1F1440C4C40
19959	7	61	\N	8531	63284	\N	56.097521034348397	город Нефтекамск, Комсомольский проспект, 44в	Россия, республика Башкортостан, Нефтекамск	0101000020E61000006397A8DE1A204B402CD670917B0C4C40
19957	7	61	\N	8531	63251	\N	56.096463	город Нефтекамск, Карла Маркса, 18	Россия, республика Башкортостан, Нефтекамск	0101000020E6100000596B28B517234B4014234BE6580C4C40
19955	7	61	\N	8531	63251	\N	56.096463	город Нефтекамск, Карла Маркса, 10б		0101000020E6100000596B28B517234B4014234BE6580C4C40
19962	7	61	\N	8531	63472	\N	56.095503496622698	город Нефтекамск, Дорожная, 49	Россия, республика Башкортостан, Нефтекамск	0101000020E61000000E130D52F0224B40BFD53A71390C4C40
19951	7	61	\N	8531	63472	\N	56.096463	город Нефтекамск, Дорожная, 2		0101000020E6100000596B28B517234B4014234BE6580C4C40
19979	7	61	\N	8531	63336	\N	56.096463	город Нефтекамск, Дзержинского, 18		0101000020E6100000596B28B517234B4014234BE6580C4C40
20844	7	61	\N	58684	66011	\N	54.501565999999997	д.Набережный, Школьная, 4		0101000020E61000009485AFAF752D4C408C648F5033404B40
20512	7	61	\N	58607	65716	\N	52.791562999999996	Республика Башкортостан, Баймакский район, д.Мукасово 1-е, улица 1 Мая, дом 5		0101000020E61000005039268BFB4F4D40A0DCB6EF51654A40
22869	7	61	\N	58394	64907	\N	54.934252000000001	с.Мичуринск, Миргая Фархутдинова, 3		0101000020E610000013807F4A95124B407E1CCD9195774B40
22872	7	61	\N	7265	66420	\N	54.799812000000003	д.Михайловка, Школьная, 2		0101000020E6100000B130444E5FF14B406479573D60664B40
20559	7	61	\N	7265	65413	\N	54.808587000000003	село Михайловка, улица Центральная, дом 4		0101000020E610000086032159C0F04B40427C60C77F674B40
20266	7	61	\N	7265	64132	\N	54.820899577201402	с.Михайловка, ул.Парковая, 32	Россия, республика Башкортостан, Уфа, улица Парковая	0101000020E6100000821E6ADB30F44B40A9A44E4013694B40
22684	7	61	\N	7265	63846	\N	54.802940999999997	Республика Башкортостан, Федоровский район, Федоровский сельсовет с.Федоровка, Ленина, 43		0101000020E6100000724F57772CF24B400BCF4BC5C6664B40
22682	7	61	1261	\N	63846	\N	54.801424799694303	Республика Башкортостан, Федоровский район, Федоровский сельсовет с.Акбулатово, Ленина, 33	Россия, республика Башкортостан, село Михайловка, улица Ленина, 30	0101000020E6100000A088450C3BF24B4031992A1895664B40
22550	7	61	\N	7265	63846	\N	54.806828000000003	Республика Башкортостан, Уфимский район, с. Михайловка, Ленина, 56		0101000020E6100000F99E91088DF24B40A1BFD02346674B40
20217	7	61	\N	7265	63846	\N	54.799391999999997	д.станции Альмухаметово, ул.Ленина, 15		0101000020E6100000CD77F01307F24B408E57207A52664B40
21004	7	61	\N	7265	66203	\N	54.808587000000003	с. Михайловка, Красногвардейская, 8б		0101000020E610000086032159C0F04B40427C60C77F674B40
20925	7	61	\N	58165	64102	\N	54.704865627004601	с.Мирный, Школьная, 4	Россия, республика Башкортостан, Благоварский район, село Мирный	0101000020E6100000ECC1A4F8F8704B40FB07910C395A4B40
22591	7	61	\N	58196	64252	\N	54.031551753003598	Миндяк (квартал Кильмяк), Хисматуллина, 12	Россия, республика Башкортостан, Учалинский район, поселок Миндяк	0101000020E6100000E1270EA0DF654D40CB0F5CE509044B40
21241	7	61	\N	6151	1671	\N	54.775095999999998	Республика Башкортостан, Дуванский район, Сикиязский сельсовет, с. Озеро, Советская, 3	Россия, республика Башкортостан, село Миловка, улица Советская, 3	0101000020E6100000EB8D5A61FAEA4B4055A1815836634B40
20601	7	61	\N	6151	16088	\N	54.779747999999998	д. Зилязекулево, Приозерная, 4	Россия, республика Башкортостан, село Миловка, улица Приозерная, 13	0101000020E6100000540262122EEA4B408A8F4FC8CE634B40
22548	7	61	\N	6151	2131	\N	54.778128000000002	Республика Башкортостан, Уфимский район, с. Миловка, Михайлова, 1	Россия, республика Башкортостан, село Миловка, улица Михайлова, 3	0101000020E61000001F662FDB4EEB4B400B0DC4B299634B40
22655	7	61	\N	6151	63849	\N	54.775967999999999	Республика Башкортостан, Федоровский район, Бала-Четырманский сельсовет с.Бала-Четырман, Советская, 16		0101000020E6100000FCE3BD6A65EA4B400B5F5FEB52634B40
21024	7	61	\N	6151	63849	\N	54.775427999999998	с.Ахун, Советская, 17		0101000020E6100000C18D942D92EA4B408B33863941634B40
20852	7	61	\N	6151	63849	\N	54.775438000000001	с.Усак-Кичу, Советская, 35		0101000020E6100000BE33DAAA24EA4B40AF09698D41634B40
19946	7	61	\N	6151	63849	\N	54.775979	"Республика Башкортостан, ЗАТО ""город Межгорье"", Советская, 20"		0101000020E610000076DEC66647EA4B40FFB0A54753634B40
21208	7	61	\N	58250	64512	\N	54.225859	Республика Башкортостан, Давлекановский район, Микяшевский сельсовет, Микяшево, Центральная, 46		0101000020E61000003CFA5FAE45534B40EE409DF2E81C4B40
22276	7	61	\N	58673	65967	\N	55.363016999999999	с.Мечетлино, Центральная, 73		0101000020E6100000C39D0B23BD004D402E724F5777AE4B40
22020	7	61	\N	58094	63529	\N	52.968404984135098	Республика Башкортостан, Мелеузовский район, город Мелеуз, Шлычкова, 29	Россия, республика Башкортостан, Мелеузовский район, Мелеуз	0101000020E6100000618907944DF74B403524EEB1F47B4A40
22028	7	61	\N	58094	63527	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Свердлова, 19		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22019	7	61	\N	58094	63528	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Правды, 31		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22018	7	61	\N	58094	63761	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Площадь Лесокомбината, 5		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22032	7	61	\N	58094	63282	\N	52.952338295975601	Республика Башкортостан, Мелеузовский район, город Мелеуз, Октябрьская, 1	Россия, республика Башкортостан, Мелеузовский район, Мелеуз	0101000020E61000008D976E1283F64B40785E2A36E6794A40
22031	7	61	\N	58094	63282	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Октябрьская, 5, А		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22033	7	61	\N	58094	63430	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Московская, 2		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22026	7	61	\N	58094	63738	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Ленина, 200		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22021	7	61	\N	58094	63738	\N	52.952811312415903	Республика Башкортостан, Мелеузовский район, город Мелеуз, Ленина, 73	Россия, республика Башкортостан, Мелеузовский район, Мелеуз	0101000020E61000007BDB4C8578F64B407022FAB5F5794A40
22015	7	61	\N	58094	63738	\N	52.9494352867126	Республика Башкортостан, Мелеузовский район, город Мелеуз, Ленина, 3	Россия, республика Башкортостан, Мелеузовский район, Мелеуз	0101000020E61000001407D0EFFBF74B40C156091687794A40
22024	7	61	\N	58094	63744	\N	52.948605819532098	Республика Башкортостан, Мелеузовский район, город Мелеуз, Колхозная, 12		0101000020E6100000744012F6EDF64B400A65E1EB6B794A40
22022	7	61	\N	58094	63411	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Бурангулова, 11		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22027	7	61	\N	58094	63312	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, 31 микрорайон, 11		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
21781	7	61	\N	58345	64777	\N	55.589635999999999	Республика Башкортостан, Кигинский район, Абзаевский сельсовет, деревня Масяково, Безымянная, 65		0101000020E6100000C4B0C398F44D4D40AA45443179CB4B40
20793	7	61	\N	58338	64757	\N	54.266872999999997	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Манышта, Новая, 3		0101000020E6100000E544BB0A29CD4C40BB97FBE428224B40
21638	7	61	\N	58339	64764	\N	53.418948999999998	Маломаксютово деревня, Каран-Елга, 16		0101000020E6100000F7B182DF86284C4090D8EE1EA0B54A40
20236	7	61	\N	58587	65636	\N	53.532938999999999	д.Майгашта, ул.Лесорубов, 20		0101000020E610000063450DA6611A4D40A8E15B5837C44A40
20709	7	61	\N	58331	64729	\N	55.714312999999997	Республика Башкортостан, Белокатайский район, Тардавский сельсовет, Левали, Мира, 35		0101000020E6100000F20698F90E504D40C70DBF9B6EDB4B40
21511	7	61	\N	58669	65946	\N	55.643169999999998	Республика Башкортостан, Илишевский район, Базитамакский сельсовет, д. Кызыл-Юлдуз, Ленина, 21а		0101000020E6100000D25625917D4C4B4058E2016553D24B40
21447	7	61	\N	58642	65842	\N	52.914053000000003	д.Кызлар-Бирган, ул.Заречная, 4		0101000020E6100000FE7BF0DAA5A14C40C5E74EB0FF744A40
22612	7	61	\N	58589	65639	\N	54.176183000000002	Кутуево, Школьная, 16		0101000020E610000077BAF3C473844D403B8E1F2A8D164B40
22275	7	61	\N	58337	64751	\N	55.352925999999997	д.Кусепеево, Школьная, 1		0101000020E6100000180B43E4F4FB4C403CF4DDAD2CAD4B40
22787	7	61	\N	58709	66112	\N	54.986784999999998	село Кусекеево, Ахтямова, 71		0101000020E610000076E3DD91B15E4B4078978BF84E7E4B40
20505	7	61	\N	58605	65712	\N	52.983758000000002	Республика Башкортостан, Баймакский район, с.Кусеево, улица Б.Валида, дом 6		0101000020E6100000A8A624EB70364D40D5963AC8EB7D4A40
20346	7	61	\N	58360	64816	\N	54.503213000000002	с. Кумурлы, Школьная, 1		0101000020E6100000D7BFEB3367494C4006F6984869404B40
19940	7	61	\N	8146	63238	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Чапаева, 7		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19924	7	61	\N	8146	63376	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Пушкина, 18		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19939	7	61	\N	8146	64325	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Палатникова, 8		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19927	7	61	\N	8146	63339	\N	52.771436702429	Республика Башкортостан, город Кумертау, Некрасова, 28	Россия, республика Башкортостан, Кумертау	0101000020E6100000D788601C5CE84B4051F69672BE624A40
19936	7	61	\N	8146	63465	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Мира, 3а		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19938	7	61	\N	8146	63388	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Машиностроителей, 7б		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19937	7	61	\N	8146	63388	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Машиностроителей, 6а		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19933	7	61	\N	8146	63239	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Ломоносова, 31а		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19932	7	61	\N	8146	63239	\N	52.758219140208297	Республика Башкортостан, город Кумертау, Ломоносова, 23а	Россия, республика Башкортостан, Кумертау	0101000020E6100000D63BDC0E0DE74B40581AF8510D614A40
19930	7	61	\N	8146	63235	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Комсомольская, 2		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19921	7	61	\N	8146	63235	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Комсомольская, 21		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19919	7	61	\N	8146	63235	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Комсомольская, 12	Россия, республика Башкортостан, Кумертау	0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19931	7	61	\N	8146	63382	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Калинина, 11		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19929	7	61	\N	8146	63759	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Заслонова, 1		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19942	7	61	\N	8146	63466	\N	52.764668981235801	Республика Башкортостан, город Кумертау, село Маячный, Горького, 14	Россия, республика Башкортостан, Кумертау	0101000020E61000006CB587BD50EA4B40ECA17DACE0614A40
19935	7	61	\N	8146	63466	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Горького, 20		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19934	7	61	\N	8146	63466	\N	52.758481122686	Республика Башкортостан, город Кумертау, Горького, 11	Россия, республика Башкортостан, Кумертау	0101000020E6100000D0D556EC2FE54B4096D1C8E715614A40
19920	7	61	\N	8146	63466	\N	52.771436999999999	Республика Башкортостан, город Кумертау, Горького, 22а		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19928	7	61	\N	8146	66917	\N	52.768033451695999	Республика Башкортостан, город Кумертау, Вокзальная, 5	Россия, республика Башкортостан, Кумертау	0101000020E6100000F20703CFBDE34B40D89FC4E74E624A40
19926	7	61	\N	8146	64412	\N	52.771409048027103	Республика Башкортостан, город Кумертау, Антошкина, 6	Россия, республика Башкортостан, Кумертау	0101000020E610000069FD2D01F8E74B40876BB587BD624A40
19941	7	61	\N	8146	63471	\N	52.771436999999999	Республика Башкортостан, город Кумертау, село Ира, 70 лет Октября, 33		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19925	7	61	\N	8146	63609	\N	52.771436999999999	Республика Башкортостан, город Кумертау, 60 лет БАССР, 14а		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19923	7	61	\N	8146	63693	\N	52.771436999999999	Республика Башкортостан, город Кумертау, 40 лет Победы, 44		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
19922	7	61	\N	8146	63695	\N	52.771436999999999	Республика Башкортостан, город Кумертау, 2-й переулок Салавата, 9		0101000020E6100000ED0F94DBF6E74B4051F69672BE624A40
21766	7	61	\N	1267	65798	\N	54.501587000000001	деревня Кулушево, Школьная, 25		0101000020E61000005C1C959BA8174C40A48CB80034404B40
22611	7	61	\N	1267	66185	\N	54.501587000000001	Кулушево, Шагар, 24		0101000020E61000005C1C959BA8174C40A48CB80034404B40
21844	7	61	\N	58652	65877	\N	55.889361000000001	д.Кузгово, Центральная, 51		0101000020E61000007E37DDB243084B403FABCC94D6F14B40
21928	7	61	\N	58704	66080	\N	55.061580999999997	Республика Башкортостан, Кушнаренковский район, с.Кувыково, Горная, 18		0101000020E6100000E1ECD63219D44B400987DEE2E1874B40
20381	7	61	\N	58494	65214	\N	56.103793000000003	Республика Башкортостан, Аскинский район, Кубиязовский сельсовет, с.Кубиязы, Совхозная, 2		0101000020E6100000D07EA4880C5F4C40E146CA16490D4C40
21555	7	61	\N	58647	65865	\N	55.530377999999999	Республика Башкортостан, Илишевский район, Старокуктовский сельсовет, д. Красный Октябрь, Дружбы, 37		0101000020E6100000A46FD23428204B404A42226DE3C34B40
20301	7	61	\N	58681	65997	\N	53.891444	Республика Башкортостан, Альшеевский район, Зеленоклиновский сельсовет, д. Красный Клин, Краснобашкирская, 2		0101000020E61000002A52616C219E4B40931B45D61AF24A40
22740	7	61	\N	58695	66047	\N	54.617643999999999	д. Комсомольск, Зайнаб Биишевой, 4		0101000020E6100000D61BB5C2F4DD4D400A4966F50E4F4B40
20526	7	61	\N	58707	66107	\N	55.274912999999998	Республика Башкортостан, Баймакский район, д.Комсомол, улица Школьная, дом 1		0101000020E6100000FACF9A1F7F114D40641F645930A34B40
21659	7	61	\N	58501	65226	\N	56.040137999999999	деревня Козлоялово, Труда, 2		0101000020E610000066F7E461A1484B40D6A9F23D23054C40
20862	7	61	\N	58527	65350	\N	53.874147000000001	с.Кожай-Икские Вершины, Центральная, 43		0101000020E6100000D40E7F4DD6084B40C172840CE4EF4A40
20863	7	61	\N	58528	65354	\N	53.834304000000003	с.Кистенли-Ивановка, Центральная, 32/1		0101000020E610000025404D2D5B174B4004763579CAEA4A40
22544	7	61	\N	7621	63327	\N	54.802925999999999	Республика Башкортостан, Уфимский район, д. Кириллово, Центральная, 64		0101000020E6100000FA7FD59123274C40D68D7747C6664B40
22860	7	61	\N	58267	64554	\N	54.763900908486903	с.Кир-Тлявли, Дорожная, 8	Россия, республика Башкортостан, Шаранский район, село Кир-Тлявли	0101000020E6100000895DDBDB2D134B40DB300A82C7614B40
21994	7	61	\N	58710	66115	\N	52.667028000000002	Республика Башкортостан, Куюргазинский район, Кривле-Илюшкинский сельсовет, д.Кинзябаево, Центральная, 11		0101000020E610000029AE2AFBAE164C4016C26A2C61554A40
22786	7	61	\N	58611	65725	\N	55.070216000000002	село Киндеркулево, Буденного, 26		0101000020E6100000B519A721AA704B40F6D37FD6FC884B40
22439	7	61	\N	58282	64583	\N	56.106143000000003	д.Кашкаково, Центральная, 49		0101000020E6100000A7EB89AE0BBB4B4084D90418960D4C40
20305	7	61	\N	58682	66001	\N	54.023764	Республика Башкортостан, Альшеевский район, Кармышевский сельсовет, с. Кармышево, Центральная, 18/1		0101000020E61000007CEF6FD05E7D4B403C69E1B20A034B40
22542	7	61	\N	58348	64784	\N	54.907625000000003	Республика Башкортостан, Уфимский район, с. Кармасан, Центральная, 1		0101000020E610000004E275FD82BF4B401904560E2D744B40
20332	7	61	\N	58356	64808	\N	54.049599999999998	Республика Башкортостан, Альшеевский район, Шафрановский сельсовет, д. Каран, Родниковая, 28		0101000020E61000007616BD53015F4B40D8F0F44A59064B40
21299	7	61	\N	58292	64600	\N	55.407944000000001	Республика Башкортостан, Дюртюлинский район, Семилетовский сельсовет, с.Каралачук, Советская, 47А		0101000020E61000000745F30016534B40BA4C4D8237B44B40
22529	7	61	\N	6894	64565	\N	54.517321000000003	Республика Башкортостан, Уфимский район, д. Камышлы, Саитова, 15		0101000020E61000008FC360FE0AF94B405B44149337424B40
22286	7	61	\N	58355	64804	\N	55.166238	д.Калмакларово, Центральная, 8		0101000020E6100000388600E0D8174D401DAD6A4947954B40
20567	7	61	\N	58621	65754	\N	55.216015149456403	село Казанчи, улица Колхозная, дом 13	Россия, республика Башкортостан, Бакалинский район, село Казанчи	0101000020E610000075AF93FAB2C04A4004392861A69B4B40
21739	7	61	\N	32179	63803	\N	54.536773215817497	Адрес помещения для голосования: деревня Кабаково, улица Победы, дом 49, Адрес УИК: улица Строителей, дом 17	Россия, республика Башкортостан, деревня Кабаково, улица Победы	0101000020E61000006B49473998134C401A3048FAB4444B40
20590	7	61	\N	58626	65768	\N	55.875607000000002	д. Иштиряково, Советская, 24		0101000020E6100000B7EC10FFB0F94B400893E2E313F04B40
20519	7	61	\N	58177	64159	\N	52.447499999999998	Республика Башкортостан, Баймакский район, с.Ишмурзино, улица Игишева, дом 25		0101000020E610000078F2E9B12D154D40E17A14AE47394A40
21577	7	61	\N	57936	\N	\N	53.44802	город Ишимбай, Передвижной вагончик		0101000020E61000003E5E488787064C401AFA27B858B94A40
21600	7	61	\N	57936	63326	\N	53.441460952048601	город Ишимбай, Ленина проспект, 23	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E61000004E452A8C2D064C40CFBA46CB81B84A40
21191	7	61	\N	57936	63326	\N	53.455500233046699	город Ишимбай, Ленина проспект, 49	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E6100000E3FC4D2844044C40FCA9F1D24DBA4A40
21587	7	61	\N	57936	63285	\N	53.44802	город Ишимбай, Стахановская, 58		0101000020E61000003E5E488787064C401AFA27B858B94A40
21584	7	61	\N	57936	63285	\N	53.448737365828002	город Ишимбай, Стахановская, 18Б	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E6100000DE02098A1F054C40A9C0C93670B94A40
21573	7	61	\N	57936	63285	\N	53.44802	город Ишимбай, Стахановская, 6А		0101000020E61000003E5E488787064C401AFA27B858B94A40
21598	7	61	\N	57936	63678	\N	53.44802	город Ишимбай, Революционная, 12А		0101000020E61000003E5E488787064C401AFA27B858B94A40
21580	7	61	\N	57936	63612	\N	53.4394110319611	город Ишимбай, Радужная, 2	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E6100000B7EEE6A90E054C405740A19E3EB84A40
21609	7	61	\N	57936	63475	\N	53.44802	город Ишимбай, Промысловая, 13А		0101000020E61000003E5E488787064C401AFA27B858B94A40
21599	7	61	\N	57936	63577	\N	53.44802	город Ишимбай, Пролетарская, 27		0101000020E61000003E5E488787064C401AFA27B858B94A40
21586	7	61	\N	57936	63641	\N	53.445867943743899	город Ишимбай, Мичурина, 9	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E61000003FE257ACE1044C409D2ADF3312B94A40
21585	7	61	\N	57936	63641	\N	53.441428922811497	город Ишимбай, Мичурина, 4		0101000020E6100000A0A52BD846064C40C440D7BE80B84A40
21583	7	61	\N	57936	63733	\N	53.451299185261	город Ишимбай, Машиностроителей, 28	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E61000006A6CAF05BD054C40D7DB662AC4B94A40
21602	7	61	\N	57936	63440	\N	53.44802	город Ишимбай, Ленина проспект, 22		0101000020E61000003E5E488787064C401AFA27B858B94A40
21604	7	61	\N	57936	63458	\N	53.44802	город Ишимбай, Космонавтов, 6А		0101000020E61000003E5E488787064C401AFA27B858B94A40
21605	7	61	\N	57936	62320	\N	53.44802	город Ишимбай, Есенина, 2		0101000020E61000003E5E488787064C401AFA27B858B94A40
21578	7	61	\N	57936	63756	\N	53.4410509759809	город Ишимбай, Докучаева, 10А		0101000020E61000003E5E488787064C401E6FF25B74B84A40
21597	7	61	\N	57936	63653	\N	53.440640995938303	город Ишимбай, Губкина, 41	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E6100000F52F49658A054C406C239EEC66B84A40
21594	7	61	\N	57936	63653	\N	53.44802	город Ишимбай, Губкина, 28		0101000020E61000003E5E488787064C401AFA27B858B94A40
21608	7	61	\N	57936	62321	\N	53.44802	город Ишимбай, Горького, 34		0101000020E61000003E5E488787064C401AFA27B858B94A40
21607	7	61	\N	57936	62321	\N	53.44802	город Ишимбай, Горького, 55		0101000020E61000003E5E488787064C401AFA27B858B94A40
21603	7	61	\N	57936	62319	\N	53.446735836369498	город Ишимбай, Геологическая, 16	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E6100000F31C91EF52044C4012F92EA52EB94A40
21595	7	61	\N	57936	62319	\N	53.44802	город Ишимбай, Геологическая, 60		0101000020E61000003E5E488787064C401AFA27B858B94A40
21579	7	61	\N	57936	63308	\N	53.44802	город Ишимбай, Гайфуллина, 15		0101000020E61000003E5E488787064C401AFA27B858B94A40
21591	7	61	\N	57936	63378	\N	53.44802	город Ишимбай, Бульварная, 47		0101000020E61000003E5E488787064C401AFA27B858B94A40
21589	7	61	\N	57936	63378	\N	53.44802	город Ишимбай, Бульварная, 55		0101000020E61000003E5E488787064C401AFA27B858B94A40
21360	7	61	\N	58477	65139	\N	51.874805000000002	Республика Башкортостан, Зианчуринский район, Абзановский сельсовет, Иткулово, Камышла, 3а		0101000020E61000003BFF76D9AF6B4C404BB0389CF9EF4940
21278	7	61	\N	58236	64463	\N	55.559877999999998	Республика Башкортостан, Дюртюлинский район, Исмаиловский сельсовет, с.Исмаилово, Ханифв Валиева, 49		0101000020E6100000A5F3E15982504B40FCDF1115AAC74B40
20252	7	61	\N	58715	66142	\N	52.3537949766515	д.Искужино, ул.Центральная, 16		0101000020E610000016FA60191BE24C40813E9127492D4A40
21194	7	61	\N	58637	65815	\N	54.175477000000001	Республика Башкортостан, Давлекановский район, Бик-Кармалинский сельсовет, с.Искандарово, Верхняя, 25		0101000020E6100000AF21382EE3B24B40A019C40776164B40
19622	7	61	\N	58672	65962	\N	54.428421	с. Ирныкши, Советская, 44		0101000020E6100000CB64389ECF484C40B6F5D37FD6364B40
20789	7	61	\N	58206	65337	\N	54.216335999999998	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Инзер, Пушкина, 1		0101000020E6100000A1496249B9C74C404679E6E5B01B4B40
20786	7	61	\N	58206	64312	\N	54.2152665992053	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Инзер, Дорожников, 3	Россия, республика Башкортостан, Белорецкий район, поселок Инзер	0101000020E61000003FE257ACE1C84C403A747ADE8D1B4B40
21515	7	61	\N	58644	65855	\N	55.296256999999997	Республика Башкортостан, Илишевский район, Бишкураевский сельсовет, д. Илякшиде, Санникова, 2		0101000020E6100000CB9C2E8B894B4B40041BD7BFEBA54B40
21775	7	61	\N	58602	65691	\N	54.334297999999997	село Ильтуганово, Мостовая, 2		0101000020E6100000540262122E004C40218FE046CA2A4B40
22551	7	61	\N	58322	64689	\N	54.339216	Ильтебаново, Клубная, 22/1		0101000020E6100000ACC77DAB75A24D40D5230D6E6B2B4B40
22677	7	61	\N	58447	\N	\N	53.402949	Республика Башкортостан, Федоровский район, Теняевский сельсовет д.Орловка, Ильинка, 8		0101000020E61000003DBA111615D14B405B7A34D593B34A40
21884	7	61	\N	58700	66065	\N	52.751289999999997	Республика Башкортостан, Кугарчинский район, Ибраевский сельсовет, д. Игубаево, Школьная, 12		0101000020E6100000B9A981E673404C40EAE74D452A604A40
21521	7	61	\N	58643	65854	\N	55.397879000000003	Республика Башкортостан, Илишевский район, Игметовский сельсовет, с. Игметово, Ленина, 11		0101000020E610000082C476F700454B40F261F6B2EDB24B40
21433	7	61	\N	58492	65209	\N	52.631628999999997	д.Ивано-Кувалат, ул.Школьная, 4		0101000020E610000011E2CAD93BBD4C40431A1538D9504A40
21768	7	61	\N	1370	65109	\N	54.503996999999998	деревня Ибрагимово, Школьная, 3А		0101000020E6100000043DD4B6611E4C401C2444F982404B40
22540	7	61	\N	1776	63818	\N	54.614854999999999	Республика Башкортостан, Уфимский район, с. Зубово, Центральная, 77/5		0101000020E61000002DCDAD1056F34B401B649291B34E4B40
22403	7	61	\N	58663	65919	\N	56.320706999999999	д. Зиримзи, Центральная, 47		0101000020E6100000BCB20B06D7CA4B40944C4EED0C294C40
22816	7	61	\N	58465	65082	\N	54.610298	с.Еремеево, Центральная, 20		0101000020E6100000D482177D05AB4B403868AF3E1E4E4B40
22814	7	61	\N	20835	64650	\N	54.508242000000003	с.Енгалышево, Манаева, 22		0101000020E61000004337FB03E5E24B40113AE8120E414B40
21270	7	61	\N	58104	63398	\N	55.492282474827697	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Советская, 96	Россия, республика Башкортостан, Дюртюлинский район, поселок Дюртюли	0101000020E61000009DBCC804FC6C4B406A34B91803BF4B40
21262	7	61	\N	58104	63762	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Первомайская, 24/А		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21260	7	61	\N	58104	66738	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Ленина, 23		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
22050	7	61	\N	58434	65003	\N	55.676732000000001	с. Дуван-Мечетлино, Вагапова, 1		0101000020E61000004AED45B41D274D400E1478279FD64B40
21247	7	61	\N	58163	64088	\N	55.689886999999999	Республика Башкортостан, Дуванский район, Дуванский сельсовет, с. Дуван, С.А. Михляева, 13		0101000020E610000062307F85CCF14C40C0779B374ED84B40
22532	7	61	\N	5667	63819	\N	54.813074999999998	Республика Башкортостан, Уфимский район, с. Дмитриевка, Школьная, 23/1		0101000020E61000000588821953E64B40FC1873D712684B40
21432	7	61	\N	5667	65825	\N	54.811242999999997	д.Дмитриевка, ул.Чучкалова, 17		0101000020E6100000F67EA31D37E64B40F10D85CFD6674B40
94453	7	61	\N	5667	66967	\N	54.811242999999997	д. Дмитриевка, ул. Центральная, 11		0101000020E6100000F67EA31D37E64B40F10D85CFD6674B40
20917	7	61	\N	5667	65576	\N	54.811242999999997	д.Дмитриевка, Комиссарова, 14		0101000020E6100000F67EA31D37E64B40F10D85CFD6674B40
20226	7	61	\N	58584	65625	\N	53.364272999999997	д.Даутово, ул.Школьная, 5		0101000020E61000008F352383DC414D406CE8667FA0AE4A40
21184	7	61	\N	58100	63811	\N	54.208469999999998	Республика Башкортостан, Давлекановский район, город Давлеканово, Российская, 4		0101000020E61000007633A31F0D854B403B191C25AF1A4B40
21181	7	61	\N	58100	63322	\N	54.215083655757503	Республика Башкортостан, Давлекановский район, город Давлеканово, Комсомольская, 26а	Россия, республика Башкортостан, Давлекановский район, Давлеканово	0101000020E610000022C2BF081A854B4049F25CDF871B4B40
21177	7	61	\N	58100	64186	\N	54.2094491491588	Республика Башкортостан, Давлекановский район, город Давлеканово, Коммунистическая, 18	Россия, республика Башкортостан, Давлекановский район, Давлеканово	0101000020E6100000BCE82B4833864B4007978E39CF1A4B40
20947	7	61	\N	57935	63560	\N	55.034714000000001	г. Благовещенск, Социалистический, 16 А		0101000020E6100000895C70067FFD4B404F5B238271844B40
21182	7	61	\N	58100	63416	\N	54.218202425598001	Республика Башкортостан, Давлекановский район, город Давлеканово, Карла Маркса, 119	Россия, республика Башкортостан, Давлекановский район, Давлеканово	0101000020E61000004436902E36854B40FDF50A0BEE1B4B40
21176	7	61	\N	58100	63586	\N	54.211991768700102	Республика Башкортостан, Давлекановский район, город Давлеканово, Гагарина, 144		0101000020E6100000042159C004844B40BF81C98D221B4B40
21183	7	61	\N	58100	63377	\N	54.208469999999998	Республика Башкортостан, Давлекановский район, город Давлеканово, Высоковольтная, 20/2		0101000020E61000007633A31F0D854B403B191C25AF1A4B40
21179	7	61	\N	58100	63407	\N	54.2098516395235	Республика Башкортостан, Давлекановский район, город Давлеканово, Ворошилова, 17	Россия, республика Башкортостан, Давлекановский район, Давлеканово	0101000020E61000008F34B8AD2D864B4006802A6EDC1A4B40
21188	7	61	\N	58100	63798	\N	54.208469999999998	Республика Башкортостан, Давлекановский район, город Давлеканово, Беляева, 14		0101000020E61000007633A31F0D854B403B191C25AF1A4B40
22272	7	61	\N	58675	65974	\N	55.239666	с.Гусевка, Центральная, 8		0101000020E6100000E4F560527C0C4D4048FB1F60AD9E4B40
22913	7	61	\N	58374	64847	\N	56.211512999999997	д. Гудбурово, Центральная, 8		0101000020E6100000100874266D664B40E4D6A4DB121B4C40
22561	7	61	\N	58258	64537	\N	54.577252000000001	Республика Башкортостан, Уфимский район, д. Геофизиков, Геологов	Россия, республика Башкортостан, поселок Геофизик, улица Геологов	0101000020E61000005709168733F54B407AC6BE64E3494B40
21402	7	61	\N	58269	64555	\N	54.877211000000003	Республика Башкортостан, Зианчуринский район, Сакмарский сельсовет, Арсеново, Клубная, 21		0101000020E6100000E71C3C139A1C4C408258367348704B40
21061	7	61	\N	58729	66214	\N	55.610992000000003	с. Вострецово, Школьная, 3		0101000020E61000003C6BB75D68984B400F0F61FC34CE4B40
21655	7	61	\N	58344	64773	\N	55.979979	деревня Верхний Тыхтем, Красноармейская, 9		0101000020E61000002B306475AB4F4B4026E2ADF36FFD4B40
21105	7	61	\N	58616	65740	\N	53.213293999999998	Республика Башкортостан, Бурзянский район, Галиакберовский сельсовет, д. Верхний Нугуш, ул.  Нугуш, 9/1		0101000020E6100000AC58FCA6B07A4C406D37C1374D9B4A40
20426	7	61	\N	58506	65241	\N	53.824744000000003	Республика Башкортостан, Аургазинский район, Семенкинский сельсовет, д.Верхний Бегеняш, Центральная, 11а		0101000020E6100000ABB4C5353ECD4B403FC91D3691E94A40
20214	7	61	\N	58581	65616	\N	52.952399999999997	д.Верхнее Абдряшево, ул.Школьная, 5		0101000020E6100000C7BB2363B5614D40EE5A423EE8794A40
21931	7	61	\N	58705	66083	\N	54.971863999999997	Республика Башкортостан, Кушнаренковский район, д.Верхнесаитово, Мира, 64		0101000020E6100000199128B4AC7F4B407214200A667C4B40
20728	7	61	\N	58332	64732	\N	55.641551103129999	Республика Башкортостан, Белокатайский район, Майгазинский сельсовет, Васелга, Животноводов, 11	Россия, республика Башкортостан, Белокатайский район, село Васелга	0101000020E61000003A05F9D9C85D4D40A9DBD9571ED24B40
19244	7	61	\N	13289	66403	\N	54.8171036548502	д. Михайловка, Заречная, 30	Россия, республика Башкортостан, деревня Вавилово, улица Заречная, 30	0101000020E6100000E7A90EB919EC4B4024B726DD96684B40
22664	7	61	\N	13289	66550	\N	54.806064999999997	Республика Башкортостан, Федоровский район, Пугачевский сельсовет с.Юрматы, Первомайская, 6		0101000020E6100000836BEEE87FED4B40A1B94E232D674B40
22426	7	61	\N	58590	65643	\N	56.277907999999996	д.Бургынбаш, Центральная, 16		0101000020E61000008FC70C54C6B54B40FCA5457D92234C40
22106	7	61	\N	58439	65019	\N	55.956043000000001	д. Бургаджино, Советская, 2		0101000020E61000009A27D714C8F44C40ED48F59D5FFA4B40
21044	7	61	\N	58171	64120	\N	55.840871	с. Бураево, Ленина, 70		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
22528	7	61	\N	2245	63938	\N	54.499752000000001	Республика Башкортостан, Уфимский район, с. Булгаково, Цюрупы, 148		0101000020E6100000802BD9B111F24B40280EA0DFF73F4B40
22266	7	61	\N	2245	66477	\N	54.495683999999997	д.Яхья, Лесная, 8		0101000020E6100000ABCC94D6DFF04B404293C492723F4B40
20545	7	61	\N	58603	65697	\N	55.096049000000001	село Бузюрово, улица Школьная, дом 63		0101000020E6100000739EB12FD9C84A4021E868554B8C4B40
21363	7	61	\N	58392	64901	\N	51.781283999999999	Республика Башкортостан, Зианчуринский район, Абуляисовский сельсовет, Бужан, Лесная, 15		0101000020E61000001CD13DEB1A654C40AC71361D01E44940
22040	7	61	\N	58463	65079	\N	52.992182	Республика Башкортостан, Мелеузовский район, Денисовский сельсовет, д. Богородское, Центральная, 6		0101000020E6100000B5FB5580EFD44B4006D7DCD1FF7E4A40
20520	7	61	\N	58327	64716	\N	52.391961000000002	Республика Башкортостан, Баймакский район, д.Богачево, улица Молодежная, дом 12		0101000020E61000004CFC51D499234D405B272EC72B324A40
20949	7	61	\N	57935	63323	\N	55.034714000000001	г. Благовещенск, Чапаева, 57		0101000020E6100000895C70067FFD4B404F5B238271844B40
20946	7	61	\N	57935	64053	\N	55.0298822795137	г. Благовещенск, Социалистическая, 16 А	Россия, республика Башкортостан, Благовещенский район, Благовещенск	0101000020E6100000F4FE3F4E98FE4B409A5E622CD3834B40
20952	7	61	\N	57935	63562	\N	55.034714000000001	г. Благовещенск, Советская, 11		0101000020E6100000895C70067FFD4B404F5B238271844B40
20955	7	61	\N	57935	63778	\N	55.027318456945501	г. Благовещенск, Седова, 98	Россия, республика Башкортостан, Благовещенский район, Благовещенск	0101000020E61000007F68E6C935FF4B40CB4BFE277F834B40
20953	7	61	\N	57935	63778	\N	55.031755737979303	г. Благовещенск, Седова, 2	Россия, республика Башкортостан, Благовещенский район, Благовещенск	0101000020E61000002E7079AC19FF4B40D4B9A29410844B40
20954	7	61	\N	57935	63734	\N	55.034714000000001	г. Благовещенск, Расковой, 23		0101000020E6100000895C70067FFD4B404F5B238271844B40
20959	7	61	\N	57935	62316	\N	55.034714000000001	г. Благовещенск, Комарова, 19		0101000020E6100000895C70067FFD4B404F5B238271844B40
20951	7	61	\N	57935	63630	\N	55.0284031712143	г. Благовещенск, Кирова, 14		0101000020E6100000DC813AE5D1FF4B40DC0DA2B5A2834B40
20948	7	61	\N	57935	63630	\N	55.034714000000001	г. Благовещенск, Кирова, 58		0101000020E6100000895C70067FFD4B404F5B238271844B40
20960	7	61	\N	57935	63757	\N	55.034714000000001	г. Благовещенск, Демьяна Бедного, 68/3		0101000020E6100000895C70067FFD4B404F5B238271844B40
20868	7	61	\N	58102	63523	\N	55.426825000000001	Республика Башкортостан, Бирский район, город Бирск, Ленина, 17		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20878	7	61	\N	58102	63801	\N	55.426825000000001	город Бирск, Курбатова, 59		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20875	7	61	\N	58102	63370	\N	55.421458187120599	г. Бирск, Красноармейская, 81		0101000020E6100000ED10FFB0A5C54B409C51F355F2B54B40
20881	7	61	\N	58102	63374	\N	55.426825000000001	г. Бирск, Коммунистическая, 97		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20876	7	61	\N	58102	63374	\N	55.426825000000001	г. Бирск, Коммунистическая, 54		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20879	7	61	\N	58102	63654	\N	55.426825000000001	г. Бирск, Кирова, 20		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20873	7	61	\N	58102	63746	\N	55.426825000000001	город Бирск, Калинина, 20		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20877	7	61	\N	58102	63367	\N	55.426825000000001	г. Бирск, Интернациональная, 1		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20874	7	61	\N	58102	63367	\N	55.426825000000001	г. Бирск, Интернациональная, 74-в		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20872	7	61	\N	58102	63795	\N	55.426825000000001	Республика Башкортостан, Бирский район, город Бирск, Гагарина, 89		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20882	7	61	\N	58102	63390	\N	55.426825000000001	г. Бирск, Бурновская, 2		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
21375	7	61	\N	58743	66320	\N	52.206887000000002	Республика Башкортостан, Зианчуринский район, Бикбауский сельсовет, Бикбау, Школьная, 34		0101000020E6100000E27492AD2E5F4C40D97BF1457B1A4A40
20831	7	61	\N	58132	64081	\N	53.697418999999996	с.Бижбуляк, Строительная, 22		0101000020E6100000096F0F4240224B40F44D9A0645D94A40
20830	7	61	\N	58132	63794	\N	53.697418999999996	с.Бижбуляк, Советская, 25		0101000020E6100000096F0F4240224B40F44D9A0645D94A40
22431	7	61	\N	58688	66023	\N	56.214016000000001	д.Бигинеево, Центарльная, 2		0101000020E610000055BDFC4E93034C400E6954E0641B4C40
20619	7	61	\N	58306	64630	\N	55.904114999999997	д.Бигильдино, Октябрьская, 12		0101000020E610000090F46915FD174C405969520ABAF34B40
20751	7	61	\N	58093	63274	\N	53.9661800528268	Республика Башкортостан, Белорецкий район, город Белорецк, Спортивная, 51А	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E6100000FCC22B499E314D404F0647C9ABFB4A40
20759	7	61	\N	58093	65789	\N	53.9615870547443	Республика Башкортостан, Белорецкий район, город Белорецк, Совхозная, 81	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E6100000AED9CA4BFE2B4D401FA1664815FB4A40
20764	7	61	\N	58093	63655	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Свободы, 45		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20750	7	61	\N	58093	63272	\N	53.973669471371998	Республика Башкортостан, Белорецкий район, город Белорецк, Садовая, 15	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E610000074CFBA46CB314D408410902FA1FC4A40
20762	7	61	\N	58093	63658	\N	53.971439767248903	Республика Башкортостан, Белорецкий район, город Белорецк, Молодежная, 61	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E6100000E63BF88903324D405C035B2558FC4A40
20756	7	61	\N	58093	65343	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Маршала Жукова, 1		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20748	7	61	\N	58093	63514	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Маркса, 48		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20739	7	61	\N	58093	63514	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Маркса, 49		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20733	7	61	\N	58093	63514	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Маркса, 84		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20749	7	61	\N	58093	63743	\N	53.967394644992801	Республика Башкортостан, Белорецкий район, город Белорецк, Луначарского, 93		0101000020E610000074CFBA46CB314D402FA86F99D3FB4A40
20741	7	61	\N	58093	63790	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Ленина, 18		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20755	7	61	\N	58093	63669	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Крупской, 160		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20761	7	61	\N	58093	63383	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, БЛЮХЕРА, 82		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20758	7	61	\N	58093	63383	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Блюхера, 137		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20763	7	61	\N	58093	63800	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Артамонова, 23		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20743	7	61	\N	58093	63725	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Алексеева, 29		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20754	7	61	\N	58093	63710	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, 50 лет Октября, 178		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20737	7	61	\N	58093	63710	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, 50 лет Октября, 13		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20735	7	61	\N	58093	63710	\N	53.968552270052299	Республика Башкортостан, Белорецкий район, город Белорецк, 50 лет Октября, 51		0101000020E6100000904946CEC2324D40DA3C0E83F9FB4A40
20644	7	61	\N	57937	63318	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Советская, 137		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20655	7	61	\N	57937	63607	\N	54.110374599266997	Республика Башкортостан, Белебеевский район, город Белебей, Революционеров, 8	Россия, республика Башкортостан, Белебеевский район, Белебей	0101000020E61000009C887E6DFD104B40E3A59BC4200E4B40
22891	7	61	1348	24450	64504	\N	54.819066999999997	с.Шаран, Пролетарская, 2		0101000020E61000007BD976DA1AFF4A40CD1DFD2FD7684B40
20651	7	61	\N	57937	63607	\N	54.110273733763201	Республика Башкортостан, Белебеевский район, город Белебей, Революционеров, 24/1	Россия, республика Башкортостан, Белебеевский район, Белебей	0101000020E610000003081F4AB4104B40AFCC5B751D0E4B40
20659	7	61	\N	57937	63305	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Пионерская, 49		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20663	7	61	\N	57937	63644	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Красноармейская, 265а		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20662	7	61	\N	57937	63644	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Красноармейская, 156		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20649	7	61	\N	57937	63361	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Красная, 138		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20646	7	61	\N	57937	63361	\N	54.104221352384201	Республика Башкортостан, Белебеевский район, город Белебей, Красная, 103	Россия, республика Башкортостан, Белебеевский район, Белебей	0101000020E61000001250E108520D4B4039471D1D570D4B40
20645	7	61	\N	57937	63361	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Красная, 101		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20660	7	61	\N	57937	63637	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Карла Маркса, 26		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20661	7	61	\N	57937	63417	\N	54.111837121367898	Республика Башкортостан, Белебеевский район, город Белебей, Горохова, 28		0101000020E6100000E4A08499B60D4B40CBBDC0AC500E4B40
20642	7	61	\N	57937	63622	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Восточная, 72		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20648	7	61	\N	57937	62327	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Волгоградская, 5/1		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20654	7	61	\N	57937	63572	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Амирова, 13		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
22281	7	61	\N	58320	64686	\N	55.071241999999998	д.Баш.Ильчикеево, С.Юлаева, 39		0101000020E61000005BE9B5D9583D4D40020D36751E894B40
22072	7	61	\N	58437	65011	\N	52.987400999999998	Республика Башкортостан, Мелеузовский район, Абитовский сельсовет, д. Басурмановка, Береговая, 2		0101000020E6100000D7F6764B72224C40D384ED27637E4A40
22496	7	61	\N	58691	66033	\N	54.445124999999997	с.Балтаево, Школьная, 57		0101000020E610000016889E94490B4B40E5D022DBF9384B40
21943	7	61	\N	58658	65895	\N	55.050699999999999	Республика Башкортостан, Кушнаренковский район, с.Байталлы, Шоссейная, 11		0101000020E6100000897C975297904B401FF46C567D864B40
20452	7	61	\N	58090	63539	\N	52.582686081468701	Республика Башкортостан, Баймакский район, город Баймак, пр.С.Юлаева, дом 27	Россия, республика Башкортостан, Баймакский район, Баймак	0101000020E6100000E4A1EF6E65274D4025EB7074954A4A40
20453	7	61	\N	58090	64147	\N	52.588433999999999	Республика Башкортостан, Баймакский район, город Баймак, ул.Юбилейная, дом 21		0101000020E61000006A6B44300E284D405FED28CE514B4A40
20455	7	61	\N	58090	63264	\N	52.588433999999999	Республика Башкортостан, Баймакский район, город Баймак, улица Чекмарева, дом 13		0101000020E61000006A6B44300E284D405FED28CE514B4A40
20457	7	61	\N	58090	63651	\N	52.588433999999999	Республика Башкортостан, Баймакский район, город Баймак, улица Стахановская, дом 19		0101000020E61000006A6B44300E284D405FED28CE514B4A40
20456	7	61	\N	58090	63266	\N	52.585718323569203	Республика Башкортостан, Баймакский район, город Баймак, улица Нигмати, дом 1	Россия, республика Башкортостан, Баймакский район, Баймак	0101000020E6100000AAD6C22CB4274D40DA56B3CEF84A4A40
20458	7	61	\N	58090	63675	\N	52.584881864045897	Республика Башкортостан, Баймакский район, город Баймак, улица М.Горького, дом 10	Россия, республика Башкортостан, Баймакский район, Баймак	0101000020E6100000BB63B14D2A284D407102D369DD4A4A40
20459	7	61	\N	58090	64190	\N	52.588433999999999	Республика Башкортостан, Баймакский район, город Баймак, улица Ленина, дом 62		0101000020E61000006A6B44300E284D405FED28CE514B4A40
20934	7	61	\N	58299	64609	\N	54.208125403672497	д.Ахуново, Центральная, 4	Россия, республика Башкортостан, Учалинский район, село Ахуново	0101000020E61000007AC37DE4D6CE4D40713D0AD7A31A4B40
21951	7	61	\N	58423	64978	\N	55.035131999999997	Республика Башкортостан, Кушнаренковский район, д.Ахта, Лесная, 2а		0101000020E61000008A7269FCC2A14B40838593347F844B40
22416	7	61	\N	58665	65930	\N	56.188262000000002	д.Асавды, Центральная, 31		0101000020E61000008CBD175FB4F14B402F8A1EF818184C40
21680	7	61	\N	58388	64893	\N	55.851858999999997	с.Артакуль, Центральная, 7		0101000020E610000045DAC69FA83A4C40D1E638B709ED4B40
21899	7	61	\N	58417	64965	\N	52.365743999999999	Республика Башкортостан, Кугарчинский район, Максютовский сельсовет, д. Ардатово, Старый Хутор, 13		0101000020E6100000234BE658DE454C40A75A0BB3D02E4A40
21238	7	61	\N	58537	65390	\N	55.440626000000002	Республика Башкортостан, Дуванский район, Рухтинский сельсовет, д. Анзяк, Центральная, 57		0101000020E6100000B188618731254D4037E2C96E66B84B40
20495	7	61	\N	58445	65046	\N	52.970100000000002	Республика Башкортостан, Баймакский район, д.Аминево, улица Школьная, дом 5		0101000020E610000074EB353D280A4D40C0EC9E3C2C7C4A40
20221	7	61	\N	58679	65988	\N	53.351638999999999	с.Амангильдино, ул.Центральная, 37		0101000020E61000009E4319AA62284D40C37FBA8102AD4A40
22676	7	61	\N	6002	1636	\N	54.825643999999997	Республика Башкортостан, Федоровский район, Покровский сельсовет д.Татарский Сухой Изяк, Центральная, 39	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 39	0101000020E61000007EC6850321FF4B40BE11DDB3AE694B40
22828	7	61	357	21507	64895	\N	54.480705999999998	с.Барсуанбашево, Центральная, 35		0101000020E610000042D13C8045CC4B40D87E32C6873D4B40
22651	7	61	\N	6002	1636	\N	54.822873999999999	Республика Башкортостан, Федоровский район, Балыклинский сельсовет д.Атяшево, Центральная, 18	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 20	0101000020E610000019709692E5FE4B40465D6BEF53694B40
21422	7	61	\N	6002	1636	\N	54.822640999999997	Республика Башкортостан, Зианчуринский район, Яныбаевский сельсовет, Нижняя Мамбетша, Центральная, 21а	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 19/1	0101000020E610000041F33977BBFE4B40A3ACDF4C4C694B40
21412	7	61	\N	6002	1636	\N	54.827655999999998	Республика Башкортостан, Зианчуринский район, Тазларовский сельсовет, Нижний Сарабиль, Центральная, 48	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 46	0101000020E6100000A2D5C9198AFF4B40492BBEA1F0694B40
20825	7	61	\N	6002	1636	\N	54.832920000000001	с.Алексеевка, Центральная, 74	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 66	0101000020E61000001A6CEA3C2A004C409817601F9D6A4B40
22524	7	61	\N	6002	66382	\N	54.833402299376701	с.Алексеевка, Школьная, 26		0101000020E61000004F401361C3FF4B40E335AFEAAC6A4B40
22671	7	61	\N	6002	63316	\N	54.827655999999998	Республика Башкортостан, Федоровский район, Дедовский сельсовет с.Дедово, Центральная, 48		0101000020E6100000A2D5C9198AFF4B40492BBEA1F0694B40
22662	7	61	\N	6002	63316	\N	54.827655999999998	Республика Башкортостан, Федоровский район, Михайловский сельсовет с.Михайловка, Центральная, 50		0101000020E6100000A2D5C9198AFF4B40492BBEA1F0694B40
21902	7	61	\N	6002	63316	\N	54.827655999999998	Республика Башкортостан, Кугарчинский район, Кугарчинский сельсовет, х. Семиречье, Центральная, 50		0101000020E6100000A2D5C9198AFF4B40492BBEA1F0694B40
21883	7	61	\N	6002	63316	\N	54.825161000000001	Республика Башкортостан, Кугарчинский район, Ибраевский сельсовет, д. Газиз, Центральная, 34		0101000020E6100000BA66F2CD36FF4B40A3772AE09E694B40
21562	7	61	\N	6002	63316	\N	54.821556999999999	Республика Башкортостан, Илишевский район, Юнновский сельсовет, д. Каенлык, Центральная, 13		0101000020E6100000FB57569A94FE4B4062669FC728694B40
21404	7	61	\N	6002	63316	\N	54.823127999999997	Республика Башкортостан, Зианчуринский район, Сакмарский сельсовет, Тирякле, Центральная, 22		0101000020E6100000098A1F63EEFE4B40003620425C694B40
21193	7	61	\N	6002	63316	\N	54.823900999999999	Республика Башкортостан, Давлекановский район, Бик-Кармалинский сельсовет, с.Бик-Карамалы, Центральная, 27		0101000020E6100000B933130CE7FE4B402312859675694B40
20835	7	61	\N	6002	63316	\N	54.825902999999997	д.Алексеевка, Центральная, 41А		0101000020E6100000F1F274AE28FF4B408A558330B7694B40
20608	7	61	\N	6002	63316	\N	54.821266000000001	д.Имяново, Центральная, 10		0101000020E61000006B9DB81CAFFE4B408BA8893E1F694B40
22658	7	61	1261	\N	66429	\N	54.825006000000002	Республика Башкортостан, Федоровский район, Бала-Четырманский сельсовет с.Гавриловка, Центральная, 31		0101000020E6100000AC74779D0DFF4B407C80EECB99694B40
21737	7	61	\N	58301	64612	\N	54.225949006001201	деревня Алайгирово, Школьная, 2	Россия, республика Башкортостан, Кармаскалинский район, село Алайгирово	0101000020E6100000AC72A1F2AF194C402EC896E5EB1C4B40
21468	7	61	\N	19288	64521	\N	54.593040000000002	Республика Башкортостан, Иглинский район, Акбердинский сельсовет, с. Акбердино, Центральная, 12		0101000020E6100000E6B2D1393F174C40249C16BCE84B4B40
22300	7	61	\N	58645	65862	\N	53.289910999999996	Республика Башкортостан, Стерлибашевский район, Яшергановский сельсовет, с.Айтуган, Тятер, 21		0101000020E6100000EE4108C8976C4B4015E0BBCD1BA54A40
21368	7	61	\N	58577	65606	\N	51.905603999999997	Республика Башкортостан, Зианчуринский район, Баишевский сельсовет, Агурда, Центральная, 11		0101000020E6100000B7442E38838F4C403A90F5D4EAF34940
19918	7	61	\N	57934	63334	\N	55.878457827470299	город Агидель, Цветочный бульвар, 3	Россия, республика Башкортостан, Краснокамский район, поселок Агидель	0101000020E61000007CF2B0506BF84A406D74CE4F71F04B40
19878	7	61	\N	57934	62315	\N	55.881497385759097	город Агидель, Мира, 2	Россия, республика Башкортостан, Краснокамский район, поселок Агидель	0101000020E6100000E109BDFE24F84A40D542C9E4D4F04B40
18009	7	61	\N	57934	62315	\N	55.878554325057301	город Агидель, Мира, 3	Россия, республика Башкортостан, Краснокамский район, поселок Агидель	0101000020E6100000CB82893F8AF84A408FE21C7574F04B40
20765	7	61	\N	58233	64448	\N	53.830361292548098	Республика Башкортостан, Белорецкий район, Абзаковский сельсовет, с.Абзаково, Ленина, 82	Россия, республика Башкортостан, Белорецкий район, село Абзаково	0101000020E610000072F90FE9B74B4D40DB6FED4449EA4A40
22009	7	61	\N	58661	65906	\N	52.623758000000002	Республика Башкортостан, Куюргазинский район,с.Абдулово, Молодежная, 1		0101000020E61000001CD3139678BE4B40274F594DD74F4A40
21234	7	61	\N	58748	66350	\N	55.603394999999999	"Республика Башкортостан, Дуванский район, Месягутовский сельсовет, д. Абдрашитово, Айская, 45 ""А"""		0101000020E610000047E9D2BF24274D40F3C81F0C3CCD4B40
22902	7	61	1613	24735	63240	\N	56.268756000000003	г. Янаул, Победы, 77		0101000020E6100000CB10C7BAB8754B40494DBB9866224C40
22901	7	61	1613	24735	63579	\N	56.268756000000003	г. Янаул, Ленина, 20	Россия, республика Башкортостан, Янаульский район, Янаул	0101000020E6100000CB10C7BAB8754B40494DBB9866224C40
22900	7	61	1613	24735	66665	\N	56.265651791005098	452800, РБ г.Янаул ,ул.Азина,9/а	Россия, республика Башкортостан, Янаульский район, Янаул	0101000020E6100000D61A4AED45784B40FA0E7EE200224C40
22897	7	61	1613	24735	63233	\N	56.268756000000003	г. Янаул, Азина, 32		0101000020E6100000CB10C7BAB8754B40494DBB9866224C40
22949	7	61	1613	27135	64475	\N	56.140779999999999	с. Ямады, Центральная, 24		0101000020E6100000CAC4AD8218AA4B4027F73B1405124C40
22909	7	61	1613	25262	65205	\N	56.195165000000003	с. Юссуково, Центральная, 46		0101000020E61000002B323A2009934B407429AE2AFB184C40
22951	7	61	1613	27215	66088	\N	56.173361999999997	с. Югамаш, Ф.Халикова, 5		0101000020E610000005172B6A30B14B40402FDCB930164C40
19990	7	61	1613	58157	64050	\N	56.250414278937399	село Энергетик, Высоковольтная, 15	Россия, республика Башкортостан, Янаульский район	0101000020E61000003F027FF8F94B4B40F33AE2900D204C40
22948	7	61	1613	27099	64480	\N	56.248556000000001	с. Шудек, Центральная, 53		0101000020E610000083A10E2BDC704B40BF9CD9AED01F4C40
22586	7	61	1613	58523	65327	\N	56.213089590798802	Урал, Центральная, 20	Россия, республика Башкортостан, Янаульский район, село Урал	0101000020E610000020EC14AB06B74B40658D7A88461B4C40
22936	7	61	1613	26528	64844	\N	56.318556000000001	д. Татарская Урада, Верхняя, 6/а		0101000020E610000030BB270F0B754B40E8F86871C6284C40
22939	7	61	1613	26674	64316	\N	56.186146236808298	с. Сусады-Эбалак, Комсомольская, 1		0101000020E610000041F163CC5D754B40FF23D3A1D3174C40
22940	7	61	1613	58840	66565	\N	56.137590876101399	д. Старый Сусадыбаш, Центральная, 25	Россия, республика Башкортостан, Янаульский район, село Староый Сусадыбаш	0101000020E6100000429946938B6B4B40AA9CF6949C114C40
22922	7	61	1613	58569	65575	\N	56.293823015645401	с. Старый Куюк, Ф.Асхадуллина, 20/а	Россия, республика Башкортостан, Янаульский район, село Староый Куюк	0101000020E6100000FAF19716F5854B4004E8F7FD9B254C40
22945	7	61	1613	26942	64011	\N	56.085751000000002	с. Старый Варяш, Парковая, 25		0101000020E610000068EBE0606FA44B40B64C86E3F90A4C40
22914	7	61	1613	58781	66456	\N	56.250218384131699	с. Старый Артаул, Чапаева, 2/б	Россия, республика Башкортостан, Янаульский район, село Староый Артаул	0101000020E6100000E353008C67684B406D6FB72407204C40
22946	7	61	1613	27012	64813	\N	56.128861999999998	с. Старокудашево, Центральная, 2		0101000020E6100000D3F544D785594B403CD9CD8C7E104C40
22911	7	61	1613	58786	66460	\N	56.157874	с. Старая Орья, Центральная, 13	Россия, республика Башкортостан, Янаульский район, село Староая Орья	0101000020E610000004E44BA8E05E4B40C171193735144C40
22942	7	61	1613	33033	64068	\N	56.256653	с. Сандугач, Комсомольская, 6		0101000020E61000005298F738D3984B40CCB56801DA204C40
22950	7	61	1613	20092	65239	\N	56.189549999999997	с. Салихово, Победы, 32	Россия, республика Башкортостан, Янаульский район, село Салихово	0101000020E6100000BCAE5FB01BB64B40787AA52C43184C40
22944	7	61	1613	26930	66310	\N	56.3159732783989	с. Рабак, Мира, 38	Россия, республика Башкортостан, Янаульский район, село Рабак	0101000020E61000003D2B69C5379E4B40A2B5A2CD71284C40
22928	7	61	1613	26161	66807	\N	56.244644999999998	452820, РБ Янаульский район, с. Прогресс, ул.Центральная, 1		0101000020E610000009DD2571565C4B40A1100187501F4C40
22933	7	61	1613	26390	66867	\N	56.288350999999999	452815, РБ Янаульский район, д. Тау, ул.Чишминская,1		0101000020E6100000F67EA31D375E4B406B6281AFE8244C40
22934	7	61	1613	26445	64410	\N	56.317722000000003	с. Новый Артаул, Центральная, 61		0101000020E6100000B39AAE27BA684B40209C4F1DAB284C40
22931	7	61	1613	26270	65596	\N	56.087733705928997	с. Месягутово, Центральная, 17	Россия, республика Башкортостан, Янаульский район, село Месягутово	0101000020E6100000A374E95F92AC4B40A65F22DE3A0B4C40
22929	7	61	1613	26189	65280	\N	56.239452999999997	с. Максимово, Молодежная, 8		0101000020E61000006F2D93E178A84B40ECF65965A61E4C40
22926	7	61	1613	26095	65604	\N	56.209611000000002	с. Кумово, Школьная, 20		0101000020E6100000A67EDE54A4324B40E1F08288D41A4C40
22947	7	61	1613	27030	65275	\N	56.171824000000001	д. Кумалак, Мира, 21		0101000020E6100000376E313F37564B407E552E54FE154C40
22927	7	61	1613	26115	64218	\N	56.227969999999999	с. Кисак-Каин, Победы, 4/а		0101000020E61000001F80D4264E524B400C3CF71E2E1D4C40
22925	7	61	1613	26034	66806	\N	56.231158000000001	452810, РБ Янаульский район, с. Карманово, ул.Магистральная,1		0101000020E6100000103CBEBD6B444B40B91AD995961D4C40
22924	7	61	1613	26005	66302	\N	56.183954	с. Каймашабаш, Полевая, 6		0101000020E6100000AEF36F97FD884B40F4FBFECD8B174C40
22923	7	61	1613	25944	64499	\N	56.2185769899151	с. Иткинеево, Куйбышева, 9	Россия, республика Башкортостан, Янаульский район, село Иткинеево	0101000020E6100000166A4DF38E7B4B403354C554FA1B4C40
22920	7	61	1613	25816	64146	\N	56.279797000000002	с. Истяк, Центральная, 44/а		0101000020E610000043C9E4D4CE824B406C425A63D0234C40
22917	7	61	1613	25657	64799	\N	56.039233000000003	с. Ижболдино, Школьная, 35	Россия, республика Башкортостан, Янаульский район, село Ижболдино	0101000020E6100000E84CDA54DD894B4045F6419605054C40
22941	7	61	1613	48714	64690	\N	56.097060999999997	с. Зайцево, Молодежная, 2		0101000020E6100000E485747808794B40C85BAE7E6C0C4C40
22915	7	61	1613	25559	65544	\N	56.371704999999999	с. Вояды, Новая, 17		0101000020E6100000CC441152B7534B403D618907942F4C40
22930	7	61	1613	26254	65289	\N	56.293866000000001	д. Верхняя Барабановка, Г.Файзуллина, 28		0101000020E6100000876A4AB20EA94B4003B4AD669D254C40
22935	7	61	1613	26467	65611	\N	56.350223	д. Варяш, Механизаторов, 30		0101000020E6100000D5AE09698D6B4B404CA7751BD42C4C40
22943	7	61	1613	26854	65607	\N	56.272239999999996	с. Барабановка, Школьная, 18		0101000020E6100000ED0BE8853B9D4B40DE54A4C2D8224C40
22921	7	61	1613	25850	65170	\N	56.250207000000003	д. Ахтиял, Молодежная, 20		0101000020E61000001A6B7F677B844B407A1D71C806204C40
22919	7	61	1613	25771	66766	\N	56.065876000000003	452822, РБ Янаульский район, с. Атлегач, ул.Центральная, 12		0101000020E6100000128942CBBA854B40B0CBF09F6E084C40
22907	7	61	1613	25172	65742	\N	56.178728999999997	с. Асавдыбаш, Центральная, 33		0101000020E6100000D591239D81974B4063EC8497E0164C40
22916	7	61	1613	25631	65188	\N	56.331392999999998	д. Акылбай, Центральная, 28		0101000020E6100000810871E5EC534B40C98FF8156B2A4C40
22912	7	61	1613	25433	65208	\N	56.207563	с. Айбуляк, Центральная, 19		0101000020E6100000DCA16131EA5C4B40096EA46C911A4C40
22856	7	61	1348	22806	66835	\N	54.897489999999998	452634, Республика Башкортостан, Шаранский район, с.Янгаулово, ул.Центральная, д.78 А		0101000020E61000009F008A91251D4B40573ECBF3E0724B40
20244	7	61	1348	22806	66835	\N	54.896945881736599	д.Янаулово, ул.Центральная, 46	Россия, республика Башкортостан, Шаранский район, село Янгаулово	0101000020E6100000147B681F2B1E4B4096236420CF724B40
22890	7	61	1348	24408	64905	\N	54.735396999999999	с.Юмадыбаш, Шаранская, 14		0101000020E6100000B4B0A71DFEFC4A40CB49287D215E4B40
22870	7	61	1348	23424	65266	\N	54.965558999999999	с.Шаранбаш-Князево, Центральная, 33А		0101000020E6100000B6114F7633114B40E2ADF36F977B4B40
22894	7	61	1348	24450	\N	\N	54.819066999999997	452630 Республика Башкортостан Шаранский район с. Шаран ул. Цветочная, 7А		0101000020E61000007BD976DA1AFF4A40CD1DFD2FD7684B40
22892	7	61	1348	24450	63432	\N	54.8208977380378	с.Шаран, Школьная, 2А	Россия, республика Башкортостан, Шаранский район, село Шаран	0101000020E61000001500E31934004B4008AD872F13694B40
22893	7	61	1348	24450	66815	\N	54.819066999999997	452630, Республика Башкортостан, Шаранский район, с.Шаран, ул.Первомайская, д.60		0101000020E61000007BD976DA1AFF4A40CD1DFD2FD7684B40
14659	7	61	1348	48682	65057	\N	54.804197000000002	с.Чупаево, Школьная, 11		0101000020E6100000E9279CDD5A0A4B404A4563EDEF664B40
22877	7	61	1348	23746	66758	\N	54.847602000000002	452643, Республика Башкортостан, Шаранский район, с.Чекан-Тамак, ул.Клубная, д.1А		0101000020E61000001AA721AAF0D14A401903EB387E6C4B40
22889	7	61	1348	24334	64271	\N	54.765720999999999	с.Чалмалы, Школьная, 3		0101000020E6100000FDA4DAA7E3F34A40226E4E2503624B40
22858	7	61	1348	47151	66161	\N	54.845559999999999	д.Урсаево, Шоссейная, 1		0101000020E610000004392861A60F4B402367614F3B6C4B40
22873	7	61	1348	23590	64668	\N	54.978988999999999	д.Три Ключа, Возрождения, 55		0101000020E61000004CA7751BD4264B406612F5824F7D4B40
22896	7	61	1348	47872	64906	\N	54.762484999999998	д.Тархан, Школьная, 45		0101000020E6100000E449D23593054B406458C51B99614B40
22875	7	61	1348	23676	66219	\N	55.025182999999998	с.Старочикеево, Центральная, 31		0101000020E6100000331B649291234B4024B5503239834B40
22887	7	61	1348	24234	65735	\N	54.876480000000001	д.Старотумбагушево, Центральная, 14		0101000020E6100000DA58897956044B408ECC237F30704B40
22874	7	61	1348	47489	66387	\N	54.998153000000002	д.Соколовка, Школьная, 25А	Россия, республика Башкортостан, Шаранский район, село Соколовка	0101000020E6100000745E6397A81A4B40C0B33D7AC37F4B40
22886	7	61	1348	24213	65730	\N	54.995209000000003	с.Сакты, Центральная, 7		0101000020E610000074081C0934044B40AAD72D02637F4B40
20981	7	61	1348	46401	65426	\N	54.919958000000001	с. Покровка, 30 лет Победы, 26		0101000020E6100000F60CE198652B4B40C7D8092FC1754B40
22884	7	61	1348	58827	66533	\N	54.971441257055503	д.Писарево, Школьная, 11	Россия, республика Башкортостан, Шаранский район, село Писарево	0101000020E61000007218CC5F21F94A402C7FBE2D587C4B40
22881	7	61	1348	23953	65538	\N	54.786996000000002	с.Нуреево, Центральная, 18		0101000020E6100000F986C267EB1A4B409A0AF148BC644B40
22871	7	61	1348	23464	65273	\N	54.954419000000001	с.Новоюмашево, Центральная, 20		0101000020E61000005130630AD6184B402CD7DB662A7A4B40
22880	7	61	1348	23900	66870	\N	54.967657000000003	452645, Республика Башкортостан, Шаранский район, с.Новоюзеево, ул.Центральная, д.28Б		0101000020E6100000494A7A185ADF4A406C5F402FDC7B4B40
22855	7	61	1348	22755	66158	\N	54.885278802918201	д.Новотавларово, Центральная, 33	Россия, республика Башкортостан, Шаранский район, село Новотавларово	0101000020E61000008A3F8A3A73174B40F46A80D250714B40
21037	7	61	1348	22755	65747	\N	54.884985	д.Новотавларово, Октябрьская, 62/1		0101000020E61000003C17467A51174B40AC39403047714B40
20914	7	61	1348	24460	65626	\N	54.9747668838667	с.Новоалександровка, Школьная, 4	Россия, республика Башкортостан, Шаранский район, село Новоалександровка	0101000020E61000006EA7AD11C1084B402A1C412AC57C4B40
22879	7	61	1348	23832	64058	\N	54.928800000000003	с.Нижние Ташлы, Победы, 18		0101000020E6100000E9B985AE44E04A402D431CEBE2764B40
22876	7	61	1348	23729	64154	\N	54.835704	с.Нижнезаитово, Центральная, 30А		0101000020E6100000B62E35423FD54A4075914259F86A4B40
22895	7	61	1348	24648	66718	\N	54.794984999999997	452630, Республика Башкортостан, Шаранский район, с.Наратасты ул.Школьная, д.1		0101000020E6100000B9DE365321FC4A40C0E78711C2654B40
22857	7	61	1348	22818	66653	\N	54.825633000000003	452630, Республика Башкортостан, Шаранский район, д.Мещерево, ул.Центральная, д.6		0101000020E61000003F558506620B4B40CBBF9657AE694B40
20624	7	61	1348	22818	66590	\N	54.823800027098301	д.Мищерово, Кооперативная, 24	Россия, республика Башкортостан, Шаранский район, село Мещерево	0101000020E61000005B7C0A80F10A4B40EF38454772694B40
22867	7	61	1348	23280	65729	\N	54.890324	д.Куртутель, Школьная, 12		0101000020E6100000F18288D4B4E34A40056C0723F6714B40
22878	7	61	1348	23811	66224	\N	54.887490999999997	д.Кугарчи-Буляк, Центральная, 35		0101000020E6100000D6389B8E00D84A40463F1A4E99714B40
22862	7	61	1348	58783	66453	\N	54.896961243505501	д.Источник, Цветочная, 1А	Россия, республика Башкортостан, Шаранский район, село Источник	0101000020E6100000FDA36FD234EC4A40CB64389ECF724B40
22866	7	61	1348	21410	64323	\N	54.849322999999998	с.Зириклы, Дружбы, 2		0101000020E61000009EEC66463FE24A40CC5EB69DB66C4B40
22863	7	61	1348	23097	66166	\N	54.76247	с.Еремкино, Салиха Сабитова, 57		0101000020E61000005F402FDCB9E04A402F17F19D98614B40
22883	7	61	1348	24052	64669	\N	54.821603000000003	с.Енахметово, Шадт Булата, 11		0101000020E61000004DA088450C1D4B40D3A57F492A694B40
22882	7	61	1348	23990	66223	\N	54.750670999999997	с.Емметово, Мухаметьянова, 2		0101000020E610000013D38558FD1D4B401E87C1FC15604B40
22861	7	61	1348	23012	65203	\N	54.847540000000002	д.Дмитриева Поляна, Полевая, 2А		0101000020E6100000D7F6764B72F64A40A306D3307C6C4B40
20712	7	61	1348	14451	65653	\N	54.853596184668	с.Биккулово, Центральная, 26	Россия, республика Башкортостан, Шаранский район, село Биккулово	0101000020E6100000ACE122F774114B408BFF3BA2426D4B40
20259	7	61	1348	14451	65653	\N	54.853497143932103	д.Биккулово, ул.Центральная, 17	Россия, республика Башкортостан, Шаранский район, село Биккулово	0101000020E610000085CD001764114B40F71DC3633F6D4B40
22859	7	61	1348	22936	65262	\N	54.724853000000003	с.Базгиево, Школьная, 4		0101000020E61000006A1327F73B0A4B4029B4ACFBC75C4B40
22885	7	61	1348	24134	66288	\N	54.978974000000001	д.Анисимова Поляна, Центральная, 1		0101000020E6100000B22FD978B0ED4A4031D120054F7D4B40
22868	7	61	1348	23347	66157	\N	54.840421999999997	д.Алпаево, Речная, 25		0101000020E6100000D8614CFA7BE94A40616BB6F2926B4B40
22854	7	61	1348	22703	65258	\N	54.861876000000002	с.Акбарисово, Центральная, 4		0101000020E61000003D0D18247D184B40899AE8F3516E4B40
22799	7	61	357	58758	66373	\N	54.637413000000002	"с.санатория ""Алкино"", Нагорная, 1"	Россия, республика Башкортостан, Чишминский район, село санаторий Алкинский	0101000020E6100000CEA8F92AF9CA4B40CB85CABF96514B40
22840	7	61	357	22095	65260	\N	54.397528000000001	с.Ябалаклы, Западная, 8/1		0101000020E6100000B7990AF148A24B40459F8F32E2324B40
22841	7	61	357	22131	64437	\N	54.386037000000002	с.Шингак-Куль, Школьная, 3		0101000020E6100000FEF2C98AE19A4B40E20511A969314B40
22842	7	61	357	22131	63578	\N	54.386037000000002	с.Шингак-Куль, Малокольцевая, 2		0101000020E6100000FEF2C98AE19A4B40E20511A969314B40
22836	7	61	357	5640	66621	\N	54.369917000000001	452166, РБ Чишминский район, с.Чувалкипово, ул.Центральная, 56		0101000020E61000001D3BA8C475B64B40029EB470592F4B40
22849	7	61	357	21689	63477	\N	54.573210060865001	р.п.Чишмы, Революционная, 12	Россия, республика Башкортостан, Чишминский район, село Чишмы	0101000020E6100000377172BF43AD4B40BEDEFDF15E494B40
22851	7	61	357	21689	63501	\N	54.573060464161898	р.п.Чишмы, Парковая, 18	Россия, республика Башкортостан, Чишминский район, село Чишмы	0101000020E61000003509DE9046AD4B40A852B3075A494B40
22845	7	61	357	21689	63688	\N	54.572857999999997	р.п.Чишмы, Ленина, 101а		0101000020E610000034A1496249AD4B4040A0336953494B40
22852	7	61	357	21689	63234	\N	54.572857999999997	р.п.Чишмы, Кирова, 5		0101000020E610000034A1496249AD4B4040A0336953494B40
22850	7	61	357	21689	63234	\N	54.5794427665721	р.п.Чишмы, Кирова, 13	Россия, республика Башкортостан, Чишминский район, село Чишмы	0101000020E6100000DA006C4084B04B40B4722F302B4A4B40
22844	7	61	357	46624	64545	\N	54.589310394941002	р.п.Чишмы, Элеваторная, 1	Россия, республика Башкортостан, Чишминский район, поселок Чишмы	0101000020E61000001572A59E05B14B40569A94826E4B4B40
22848	7	61	357	46624	63462	\N	54.589011319716199	р.п.Чишмы, Садовая, 7	Россия, республика Башкортостан, Чишминский район, поселок Чишмы	0101000020E61000007F1475E61EB24B40FCFD62B6644B4B40
22846	7	61	357	46624	64291	\N	54.592786106448699	р.п.Чишмы, Промышленная, 2		0101000020E610000016889E9449B34B4069C36169E04B4B40
22847	7	61	357	46624	64571	\N	54.589396748607598	р.п.Чишмы, Нагорная, 2	Россия, республика Башкортостан, Чишминский район, поселок Чишмы	0101000020E6100000F73DEAAF57B24B4025AE635C714B4B40
22853	7	61	357	46624	63350	\N	54.5893134129415	р.п.Чишмы, Мира, 21	Россия, республика Башкортостан, Чишминский район, поселок Чишмы	0101000020E6100000EE5D83BEF4B04B40C70DBF9B6E4B4B40
22832	7	61	357	46624	63340	\N	54.591240993159197	с.Чишмы, Колхозная, 24	Россия, республика Башкортостан, Чишминский район, поселок Чишмы	0101000020E610000018B2BAD573B24B40F486FBC8AD4B4B40
22802	7	61	357	20134	65202	\N	54.684085000000003	с.Уразбахты, Школьная, 21	Россия, республика Башкортостан, Чишминский район, село Уразбахты	0101000020E6100000E9F17B9BFEBC4B409357E71890574B40
22800	7	61	357	58330	64726	\N	54.643208834695201	с.Узытамак, Центральная, 81	Россия	0101000020E6100000F435CB65A3CB4B4016BF29AC54524B40
22837	7	61	357	21934	65250	\N	54.324432000000002	с.Теперишево, Школьная, 2	Россия, республика Башкортостан, Чишминский район, село Теперишево	0101000020E6100000EDBB22F8DFB24B4050E3DEFC86294B40
22834	7	61	357	1831	66831	\N	54.387815000000003	452166, РБ Чишминский район, с.Старомусино, ул.Центральная, 39		0101000020E6100000FD885FB186C14B40FAF202ECA3314B40
22830	7	61	357	10303	63802	\N	54.556780000000003	с.Сафарово, Центральная, 21	Россия, республика Башкортостан, Чишминский район, село Сафарово	0101000020E6100000BC749318049C4B409088299144474B40
22601	7	61	357	10303	63802	\N	54.556780000000003	Сафарово, Центральная, 93		0101000020E6100000BC749318049C4B409088299144474B40
22801	7	61	357	58696	66048	\N	54.6939174224309	с.Салихово, Мира, 29/1	Россия, республика Башкортостан, Чишминский район, село Салихово	0101000020E6100000B187F6B182C54B40B891B245D2584B40
22829	7	61	357	58560	65531	\N	54.5003275686976	с.Сайраново, пер.Школьный, 9	Россия, республика Башкортостан, Чишминский район, село Сайраново	0101000020E6100000BE4EEACBD2D04B40F5A276BF0A404B40
22838	7	61	357	21986	65574	\N	54.450428000000002	д.Новоусманово, Шоссейная, 19	Россия, республика Башкортостан, Чишминский район, село Новоусманово	0101000020E6100000D95C35CF11A14B40F299EC9FA7394B40
22827	7	61	357	46652	66451	\N	54.475234	с.Новотроицкое, Центральная, 16	Россия, республика Башкортостан, Чишминский район, село Новотроицкое	0101000020E61000002194F77134C34B4040F9BB77D43C4B40
22819	7	61	357	58793	66475	\N	54.594168208679598	д.Нижние Термы, Центральная, 38	Россия, республика Башкортостан, Чишминский район, село Нижнии Термы	0101000020E61000000ABDFE243EA14B40352A70B20D4C4B40
22805	7	61	357	20324	65053	\N	54.556446000000001	с.Кляшево, Мустая Карима, 13	Россия, республика Башкортостан, Чишминский район, село Кляшево	0101000020E61000009450FA42C8D34B40B9FE5D9F39474B40
21469	7	61	357	19338	66777	\N	54.557237694300397	д. Карамалы, ул. Школьная, 4	Россия, республика Башкортостан, Чишминский район, село Карамалы	0101000020E61000003198BF42E6924B40520B259353474B40
22824	7	61	357	21320	64439	\N	54.559536999999999	с.Кара-Якупово, Центральная, 29		0101000020E61000004C6F7F2E1ABC4B4073F38DE89E474B40
22817	7	61	357	20990	64424	\N	54.655855000000003	с.Калмашево, Школьная, 1		0101000020E6100000F6436CB0709C4B4084F57F0EF3534B40
22833	7	61	357	58237	64468	\N	54.524616000000002	д.Игнатовка, Центральная, 25	Россия, республика Башкортостан, Чишминский район, село Игнатовка	0101000020E6100000B037312427A94B40AB7AF99D26434B40
22821	7	61	357	21143	65508	\N	54.398390457383499	с.Ибрагимово, Молодежная, 10	Россия, республика Башкортостан, Чишминский район, село Ибрагимово	0101000020E6100000512E8D5F78CD4B40D7868A71FE324B40
22811	7	61	357	46167	64899	\N	54.424371999999998	с.Дурасово, Центральная, 58	Россия, республика Башкортостан, Чишминский район, село Дурасово	0101000020E6100000DA907F6610A54B4047AB5AD251364B40
22810	7	61	357	22029	64763	\N	54.765445999999997	д.Дмитриевка, Старая Деревня, 18	Россия, республика Башкортостан, Чишминский район, село Дмитриевка	0101000020E6100000E0BA624678AB4B40506D7022FA614B40
22839	7	61	357	22029	66735	\N	54.765445999999997	452140, РБ Чишминский район, д.Дмитриевка, ул.Мира, 38		0101000020E6100000E0BA624678AB4B40506D7022FA614B40
22825	7	61	357	58497	65218	\N	54.54372	с.Горный, Молодежная, 21	Россия, республика Башкортостан, Чишминский район, село Горный	0101000020E610000031276893C3B74B402F17F19D98454B40
20858	7	61	357	58747	66349	\N	54.4128869518713	д.Вишневка, Центральная, 1А	Россия, республика Башкортостан, Чишминский район, село Вишневка	0101000020E6100000292158552FD94B40C6F8307BD9344B40
22843	7	61	357	58829	66537	\N	54.437881901841997	х.Верхний, Школьная, 1	Россия, республика Башкортостан, Чишминский район, село Верхний	0101000020E61000007009C03FA5844B40E8C072840C384B40
22818	7	61	357	21045	64786	\N	54.605198000000001	с.Верхние Термы, Центральная, 75		0101000020E6100000D89B189293974B4064CDC820774D4B40
22812	7	61	357	20735	65051	\N	54.381858000000001	д.Булякбашево, Шоссейная, 2а	Россия, республика Башкортостан, Чишминский район, село Булякбашево	0101000020E6100000658EE55DF5AE4B40A5DB12B9E0304B40
22809	7	61	357	20546	65074	\N	54.779769000000002	с.Бишкази, Новая, 9		0101000020E610000015A930B610A24B40A2B77878CF634B40
22806	7	61	357	20406	64679	\N	54.678890000000003	с.Арсланово, Центральная, 40	Россия, республика Башкортостан, Чишминский район, село Арсланово	0101000020E6100000BCB20B06D7B44B406DCA15DEE5564B40
22804	7	61	357	20244	64139	\N	54.568359000000001	д.Арово, Центральная, 23		0101000020E61000001631EC3026CB4B4092B1DAFCBF484B40
22813	7	61	357	20764	65509	\N	54.338144999999997	д.Альбеево, Демская, 54		0101000020E6100000CA54C1A8A4A44B402827DA55482B4B40
22826	7	61	357	58156	64045	\N	54.658537989838997	с.Алкино-2, пер.Школьный, 18	Россия, республика Башкортостан, Чишминский район, село Алкино	0101000020E6100000C2340C1F11CB4B402D9622F94A544B40
22835	7	61	357	21841	66104	\N	54.395420999999999	д.Абраево, Центральная, 44г		0101000020E61000009545611745BB4B406893C3279D324B40
22768	7	61	317	18345	66680	\N	54.999603999999998	Чекмагушевский район, с.Юмашево, ул.Советская, 16		0101000020E610000039984D8061354B40B3791C06F37F4B40
22744	7	61	317	17073	64004	\N	55.143317000000003	село Чекмагуш, Тракторная, 23		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22750	7	61	317	17073	64145	\N	55.143317000000003	село Чекмагуш, Мира, 25		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22752	7	61	317	17073	63786	\N	55.140690415849498	село Чекмагуш, Ленина, 7	Россия, республика Башкортостан, Чекмагушевский район, село Чекмагуш	0101000020E61000006518778368534B40E76F422102924B40
22748	7	61	317	17073	63786	\N	55.143317000000003	село Чекмагуш, Ленина, 68		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22746	7	61	317	17073	63786	\N	55.143317000000003	село Чекмагуш, Ленина, 72		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22743	7	61	317	17073	63786	\N	55.143317000000003	село Чекмагуш, Ленина, 81	Россия, республика Башкортостан, Чекмагушевский район, село Чекмагуш	0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22745	7	61	317	17073	64008	\N	55.143317000000003	село Чекмагуш, Кооперативная, 61		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22751	7	61	317	17073	64272	\N	55.143317000000003	село Чекмагуш, Западная, 2А		0101000020E6100000F9F884ECBC534B40FDFA213658924B40
22785	7	61	317	19245	66887	\N	55.033197362917797	Чекмагушевский район, с. Урняк,  ул. Советская, 18		0101000020E6100000096EA46C91624B40A4A99ECC3F844B40
22769	7	61	317	18361	64662	\N	54.966298000000002	село Уйбулатово, Кутуева, 5		0101000020E6100000C2DD59BBED364B40591822A7AF7B4B40
22760	7	61	317	58864	66632	\N	55.174825340578998	село Тайняшево, Центральная, 32	Россия, республика Башкортостан, Чекмагушевский район, село Тяйняшево	0101000020E61000005F0D501A6A344B40F8C264AA60964B40
22757	7	61	317	58613	65731	\N	55.145302999999998	деревня Тукаево, Салавата, 22	Россия, республика Башкортостан, Чекмагушевский район, село Тукаево	0101000020E6100000E0BDA3C6843E4B405E81E84999924B40
22791	7	61	317	19537	65540	\N	55.206780999999999	село Тузлукушево, Центральная, 69	Россия, республика Башкортостан, Чекмагушевский район, село Тузлукушево	0101000020E6100000BC3B32569B694B409337C0CC779A4B40
22782	7	61	317	19082	65714	\N	55.124583000000001	село Ташкалмашево, Молодежная, 4		0101000020E6100000F226BF45277B4B409C51F355F28F4B40
22798	7	61	317	19918	65728	\N	55.238680000000002	село Тамьяново, Центральная, 1		0101000020E6100000C214E5D2F8454B40CA1AF5108D9E4B40
22792	7	61	317	19604	64138	\N	55.212699000000001	село Сыйрышбашево, Хузиных, 75А		0101000020E6100000C9ACDEE176604B402A7288B8399B4B40
22780	7	61	317	19604	64138	\N	55.212699000000001	Чекмагушевский район, с. Старобаширово, ул. Хузиных, 89		0101000020E6100000C9ACDEE176604B402A7288B8399B4B40
22765	7	61	317	18178	66620	\N	55.060976882181002	Чекмагушевский район, с.Старосурметово, ул.Гагарина, 45	Россия, республика Башкортостан, Чекмагушевский район, село Старосурметово	0101000020E610000032569BFF57234B4073672618CE874B40
22767	7	61	317	18275	65092	\N	54.992156999999999	село Старопучкаково, Ш.Салихова, 53/1		0101000020E61000007E8FFAEB153C4B40ADBF2500FF7E4B40
22777	7	61	317	1997	66756	\N	55.124217999999999	Чекмагушевский район, с.Старокалмашево, ул.Нефтяников, 1А		0101000020E6100000FCC22B499E694B408AC91B60E68F4B40
22776	7	61	317	1997	64052	\N	55.124217999999999	село Старокалмашево, Мира, 1А		0101000020E6100000FCC22B499E694B408AC91B60E68F4B40
22775	7	61	317	18708	65708	\N	55.025235000000002	село Старобиккино, Мира, 76		0101000020E61000001C2444F9824A4B4077DB85E63A834B40
22761	7	61	317	18002	65703	\N	55.169020000000003	село Старобалаково, В.Галимова, 56		0101000020E6100000A85489B2B72E4B405A2F8672A2954B40
22763	7	61	317	18089	64320	\N	55.097486000000004	село Резяпово, Центральная, 46		0101000020E6100000A5D93C0E83254B40B0E8D66B7A8C4B40
22772	7	61	317	1440	66916	\N	55.065348999999998	Чекмагушевский район, с.Рапатово, ул. Ленина, 2		0101000020E61000007F15E0BBCD4D4B40C4E9245B5D884B40
22759	7	61	317	17831	66659	\N	55.046933996992003	село Нижние Карьявды, Школьная, 15	Россия, республика Башкортостан, Чекмагушевский район, село Новые Карьявды	0101000020E6100000390F27309D2E4B400589EDEE01864B40
22758	7	61	317	17831	66794	\N	55.044707000000002	Чекмагушевский район, с. Новые Карьявды, ул.Центральная, 46		0101000020E610000021AF0793E22D4B407E737FF5B8854B40
22771	7	61	317	58350	64791	\N	54.979500000000002	село Новосеменкино, Свободы, 44	Россия, республика Башкортостан, Чекмагушевский район, село Новосеменкино	0101000020E6100000DA8D3EE603384B404C378941607D4B40
22797	7	61	317	2303	66797	\N	55.210104999999999	Чекмагушевский район, с.Новокутово,  ул. Центральная, 25		0101000020E6100000153944DC9C4A4B40F0DC7BB8E49A4B40
22781	7	61	317	19000	64860	\N	55.123538000000003	село Новокалмашево, С. Муратова, 25		0101000020E6100000C7F2AE7AC0864B4019E8DA17D08F4B40
22784	7	61	317	19173	66109	\N	55.075077	село Новоихсаново, 55 лет Победы, 26		0101000020E61000000AD6389B8E784B4045D7851F9C894B40
22773	7	61	317	18600	66097	\N	55.065679000000003	село Новобиккино, Дуслык, 25		0101000020E61000007E3672DD94564B405A84622B68884B40
22755	7	61	317	17703	66666	\N	55.115023000000001	Чекмагушевский район, с.Новобалтачево, ул. Ленина, 83		0101000020E61000003293A8177C364B40D7A4DB12B98E4B40
22764	7	61	317	18138	65723	\N	55.134214	село Новобалаково, М. Дашкина, 25		0101000020E6100000A8E2C62DE6214B402A55A2EC2D914B40
22778	7	61	317	18878	65711	\N	55.182926999999999	село Новая Муртаза, Еникеева Рифката, 5		0101000020E6100000D34D621058774B401747E5266A974B40
22754	7	61	317	49378	66092	\N	55.172198000000002	деревня Нариманово, Фабричная, 14		0101000020E610000049D6E1E82A534B40E33785950A964B40
22766	7	61	317	18223	66843	\N	55.024956000000003	Чекмагушевский район, с.Митро-Аюповское,ул.Молодежная, 2/1		0101000020E6100000E38920CEC33B4B4064EB19C231834B40
22794	7	61	317	19687	66842	\N	55.290342000000003	Чекмагушевский район, с.Каразириково, ул.Школьная, 16		0101000020E61000001268B0A9F3664B40DF5339ED29A54B40
22774	7	61	317	18643	64304	\N	55.008066999999997	село Калмашбашево, Центральная, 126		0101000020E61000008FA7E507AE4E4B40A296E65608814B40
20836	7	61	317	58878	66850	\N	55.114068370188797	д.Калиновка, ул.Центральная,16	Россия, республика Башкортостан, Чекмагушевский район, село Калиновка	0101000020E6100000F3AACE6A81454B4094C2BCC7998E4B40
22795	7	61	317	19755	66675	\N	55.283923000000001	Чекмагушевский район, с. Имянликулево,  ул. Школьная, 3		0101000020E6100000537765170C544B4086CABF9657A44B40
22796	7	61	317	19784	66633	\N	55.327536000000002	Чекмагушевский район, с. Верхний Аташ,  ул. Кр. Партизан, 2		0101000020E6100000FB592C45F2574B409F211CB3ECA94B40
22790	7	61	317	19492	65216	\N	54.939087999999998	село Бардаслы, Первомайская, 39		0101000020E6100000118AADA069634B4074081C0934784B40
22762	7	61	317	18031	66100	\N	55.225316999999997	село Ахметово, Нур Гайсина, 33	Россия, республика Башкортостан, Чекмагушевский район, село Ахметово	0101000020E6100000EF92382BA2344B40CD1DFD2FD79C4B40
22788	7	61	317	4462	66929	\N	54.980249999999998	Чекмагушевский район, с. Аблаево, ул.Советская, 6		0101000020E6100000C5E74EB0FF6C4B40B6F3FDD4787D4B40
22789	7	61	317	4462	65847	\N	54.980249999999998	село Аблаево, Профессора Кудоярова, 71/2	Россия, республика Башкортостан, Чекмагушевский район, село Аблаево	0101000020E6100000C5E74EB0FF6C4B40B6F3FDD4787D4B40
22703	7	61	106	15126	66196	\N	51.887453000000001	д. Янтышево, Школьная, 14		0101000020E61000001EFE9AAC51DD4C4059DE550F98F14940
22728	7	61	106	58504	65233	\N	51.999215	д. Яковлевка, Ахметшина, 3	Россия, республика Башкортостан, Хайбуллинский район, село Яковлевка	0101000020E61000009BC937DBDCFC4C401956F146E6FF4940
22719	7	61	106	15879	65461	\N	52.064635000000003	д. Юлбарсово, Вахитова, 16		0101000020E61000006B662D05A4FF4C40A796ADF545084A40
22738	7	61	106	33038	64467	\N	52.235393999999999	с. Целинное, Заки Валиди, 2		0101000020E610000075ADBD4F55534D405AD6FD63211E4A40
22718	7	61	106	15856	66194	\N	52.101615543206002	д. Хворостянское, Матросова, 49	Россия, республика Башкортостан, Хайбуллинский район, село Хворостянское	0101000020E6100000CB49287D21124D400B60CAC0010D4A40
22730	7	61	106	16366	64183	\N	52.212229000000001	с. Уфимский, Целинная, 17		0101000020E6100000446ADAC534254D40A321E3512A1B4A40
22729	7	61	106	16366	66705	\N	52.212229000000001	453803, РБ, Хайбуллинский  район, с. Уфимский, ул. Арсланова, д.1		0101000020E6100000446ADAC534254D40A321E3512A1B4A40
22691	7	61	106	14531	66832	\N	51.836367000000003	453814, РБ, Хайбуллинский  район,д. Урняк, ул.Салавата Юлаева, д.17		0101000020E6100000446E861BF0D14C40113AE8120EEB4940
22695	7	61	106	14749	66197	\N	51.967309999999998	д. Уразбаево, Заки Валиди, 8	Россия, республика Башкортостан, Хайбуллинский район, село Уразбаево	0101000020E610000065A54929E8B84C40008C67D0D0FB4940
22723	7	61	106	58794	66476	\N	51.968243016773499	д. Таштугай, Бабича, 25	Россия, республика Башкортостан, Хайбуллинский район, село Султангузино	0101000020E61000008D2958E36C4C4D405CCAF962EFFB4940
22727	7	61	106	16253	64174	\N	51.967283000000002	с. Татыр-Узяк, Победы, 7		0101000020E61000007B849A2155124D40077DE9EDCFFB4940
22702	7	61	106	32819	\N	\N	51.819012000000001	с. Степной, Мира, 15	Россия, республика Башкортостан, Хайбуллинский район, село Степной	0101000020E6100000DE3994A12A144D400A849D62D5E84940
22716	7	61	106	15765	\N	\N	52.033141999999998	с. Самарское, Заки Валиди, 62	Россия, республика Башкортостан, Хайбуллинский район, село Самарское	0101000020E6100000A110018750134D40E00F3FFF3D044A40
22690	7	61	106	33160	66401	\N	51.835990878136698	д. Сакмар-Назаргулово, Мира, 14	Россия, республика Башкортостан, Хайбуллинский район, село Сакмар-Назаргулово	0101000020E6100000B1A371A8DFC14C400B60CAC001EB4940
22701	7	61	106	47255	65515	\N	51.903270817842099	с. Садовый, Новая, 15	Россия, республика Башкортостан, Хайбуллинский район, село Садовый	0101000020E6100000D0D2156C231A4D406D3656629EF34940
22173	7	61	106	47255	66306	\N	51.903647999999997	село Садовый, улица Фестивальная, дом 2/2		0101000020E6100000643F8BA5481A4D40438CD7BCAAF34940
22713	7	61	106	58580	65614	\N	51.807291380483001	д. Сагитово, Школьная, 19	Россия, республика Башкортостан, Хайбуллинский район, село Сагитово	0101000020E61000002AFEEF880A3D4D4075ADBD4F55E74940
22725	7	61	106	16158	65588	\N	52.077903999999997	с. Савельевка, Муртазина, 9		0101000020E6100000249BABE639464D40211D1EC2F8094A40
22708	7	61	106	48661	65045	\N	51.943038999999999	д. Пугачево, Яковлева, 7		0101000020E6100000EB6E9EEA90E94C4020ED7F80B5F84940
22720	7	61	106	8757	66880	\N	52.042588000000002	453805, РБ, Хайбуллинский  район, с. Подольск, ул.Гагарина, д.5		0101000020E61000005798BED710384D40DD99098673054A40
22735	7	61	106	33026	64047	\N	52.171380999999997	д. Петропавловский, Кипчак, 1/1		0101000020E6100000083BC5AA41084D40F01307D0EF154A40
22714	7	61	106	3500	66681	\N	51.7987325155392	453808, РБ, Хайбуллинский  район, с. Новый Зирган, ул.Баракатова, д. 43(СДК)		0101000020E6100000118FC4CBD3254D40349E08E23CE64940
22724	7	61	106	16136	65465	\N	52.088197999999998	д. Новоукраинка, Полтавская, 5		0101000020E61000001D3D7E6FD34B4D404BC972124A0B4A40
22734	7	61	106	58719	66160	\N	52.314751481174397	1-е Мурзино, Победы, 2	Россия, республика Башкортостан, Хайбуллинский район, село Мурзино 1-е	0101000020E61000005CC64D0D341B4D4010B1C1C249284A40
22707	7	61	106	58302	64613	\N	52.040045638229898	с. Михайловка, Худайбердина, 20	Россия, республика Башкортостан, Хайбуллинский район, село Михайловка	0101000020E610000038A1100187EE4C40F52A323A20054A40
22711	7	61	106	2239	65649	\N	51.857965	село Мамбетово, Салавата Юлаева, 13		0101000020E6100000D7A6B1BD16384D406B0E10CCD1ED4940
20465	7	61	106	2239	65700	\N	51.857965	Республика Башкортостан, Баймакский район, д.Мамбетово, улица Набережная, дом 8		0101000020E6100000D7A6B1BD16384D406B0E10CCD1ED4940
22688	7	61	106	14417	66187	\N	51.794433811764897	д. Малоарслангулово, Молодежная, 31	Россия, республика Башкортостан, Хайбуллинский район, село Малоарслангулово	0101000020E6100000EF39B01C21BF4C404D6A6803B0E54940
22712	7	61	106	15573	64382	\N	51.962735183828698	село Макан, Целинная, 58	Россия, республика Башкортостан, Хайбуллинский район, село Макан	0101000020E610000028D53E1D8F2B4D4077DB85E63AFB4940
22715	7	61	106	15674	66878	\N	51.764614999999999	453808, РБ, Хайбуллинский  район, д. Илячево, ул.Мира, 3(СДК)		0101000020E6100000BEBD6BD0971A4D40F98381E7DEE14940
22706	7	61	106	33150	64369	\N	51.980325999999998	с. Ивановка, Заки Валиди, 27	Россия, республика Башкортостан, Хайбуллинский район, село Ивановка	0101000020E6100000EF2076A6D0F14C4091B586527BFD4940
22722	7	61	106	40337	9867	\N	51.899246589181402	д. Адель, Акмуллы, 4	Россия, республика Башкортостан, Хайбуллинский район	0101000020E6100000812381069B3E4D40580394861AF34940
22692	7	61	106	149	66764	\N	51.949967000000001	453813, РБ, Хайбуллинский  район,с. Галиахметово, ул. Гагарина, д.19 (СДК)		0101000020E610000072C0AE264FC54C40BEA3C68498F94940
22710	7	61	106	58609	65720	\N	52.119408	д. Воздвиженка, Первоцелинников, 20	Россия, республика Башкортостан, Хайбуллинский район, село Воздвиженка	0101000020E61000005D4F745DF82D4D40BD70E7C2480F4A40
22646	7	61	106	12476	63448	\N	51.959862999999999	село Бурибай, Тасимова, 51	Россия, республика Башкортостан, Хайбуллинский район, поселок Бурибай	0101000020E610000064AC36FFAF144D40FAD170CADCFA4940
22685	7	61	106	12476	63536	\N	51.959862999999999	с. Бурибай, Заки Валиди, 40		0101000020E610000064AC36FFAF144D40FAD170CADCFA4940
22705	7	61	106	12476	63297	\N	51.959862999999999	с. Бурибай, Гагарина, 12а		0101000020E610000064AC36FFAF144D40FAD170CADCFA4940
22717	7	61	106	15778	65642	\N	52.092784999999999	д. Бузавлык, Юбилейная, 11		0101000020E6100000E674594C6C0E4D409947FE60E00B4A40
22689	7	61	106	14441	66190	\N	51.809936	с. Большеарслангулово, Дружбы, 12		0101000020E6100000E60297C79AC54C4031ED9BFBABE74940
22687	7	61	106	14344	66790	\N	51.774441000000003	453814, РБ, Хайбуллинский  район,с. Большеабишево, ул.Ахметшина, д. 19 (ФАП)		0101000020E610000071732A1900C04C403DD7F7E120E34940
22721	7	61	106	58843	66569	\N	51.999103241940702	д. Бакаловка, Победы, 16	Россия, республика Башкортостан, Хайбуллинский район, село Бакаловская	0101000020E6100000ADA3AA09A2424D40F12A6B9BE2FF4940
22726	7	61	106	16233	64119	\N	51.923736965274301	село Байгускарово, Гагарина, 13		0101000020E610000027A089B0E1FD4C40768D96033DF64940
22704	7	61	106	15183	65043	\N	51.886707999999999	с. Антинган, К.Ахметшина, 2		0101000020E61000006326512FF8F24C40008DD2A57FF14940
22731	7	61	106	16477	65463	\N	52.236314999999998	с. Алибаевское, Дружбы, 10		0101000020E610000094331477BC254D40F146E6913F1E4A40
22698	7	61	106	14789	\N	\N	51.861091000000002	с. Акъяр, Салавата Юлаева, 43	Россия, республика Башкортостан, Хайбуллинский район, село Акъяр	0101000020E610000055F99E91081B4D40A2F0D93A38EE4940
22696	7	61	106	14789	64395	\N	51.861091000000002	с. Акъяр, Энергетиков, 1	Россия, республика Башкортостан, Хайбуллинский район, село Акъяр	0101000020E610000055F99E91081B4D40A2F0D93A38EE4940
22697	7	61	106	14789	64394	\N	51.861091000000002	с. Акъяр, Подгорная, 69	Россия, республика Башкортостан, Хайбуллинский район, село Акъяр	0101000020E610000055F99E91081B4D40A2F0D93A38EE4940
22700	7	61	106	14789	64253	\N	51.861091000000002	с. Акъяр, Акмуллы, 9/1	Россия, республика Башкортостан, Хайбуллинский район, село Акъяр	0101000020E610000055F99E91081B4D40A2F0D93A38EE4940
22699	7	61	106	14789	64253	\N	51.861091000000002	село Акъяр, Акмуллы, 7		0101000020E610000055F99E91081B4D40A2F0D93A38EE4940
22694	7	61	106	14683	66195	\N	51.894980963399099	д. Акъюлово, Горная, 20	Россия, республика Башкортостан, Хайбуллинский район, село Акъюлово	0101000020E6100000E961687572C04C404CC5C6BC8EF24940
22709	7	61	106	15419	65621	\N	51.944009999999999	д. Акташево, М.Муртазина, 17/2	Россия, республика Башкортостан, Хайбуллинский район, село Акташево	0101000020E610000099D36531B1E54C40698CD651D5F84940
22693	7	61	106	58806	66563	\N	51.917177054344997	д. Акназарово, Акназар, 18	Россия, республика Башкортостан, Хайбуллинский район, село Акназарово	0101000020E6100000FC17080264D24C405BD2510E66F54940
22737	7	61	106	16797	65647	\N	51.868093000000002	с. Абубакирово, Заки Валиди, 1		0101000020E6100000A0C4E74EB0FB4C407A71E2AB1DEF4940
22742	7	61	106	17062	64597	\N	52.267679999999999	д. Абдулнасырово, Абдулнасыровская, 6А		0101000020E6100000AED85F764F344D408AE5965643224A40
22678	7	61	1261	33601	66418	\N	53.175558270952202	Республика Башкортостан, Федоровский район, Теняевский сельсовет с.Теняево, Центральная, 18		0101000020E610000067614F3BFC974B408D463EAF78964A40
22670	7	61	1261	33601	66418	\N	53.182622567060903	Республика Башкортостан, Федоровский район, Денискинский сельсовет д.Веселовка, Центральная, 10	Россия, республика Башкортостан, Федоровский район, село Федоровка	0101000020E6100000556CCCEB88974B40AB3FC23060974A40
22660	7	61	1261	33601	66193	\N	53.177345705541498	Республика Башкортостан, Федоровский район, Бала-Четырманский сельсовет д.Новософиевка, Первая, 27	Россия, республика Башкортостан, Федоровский район, село Федоровка	0101000020E6100000BB63B14D2A964B40C8091346B3964A40
22683	7	61	1261	33601	64151	\N	53.177160000000001	Республика Башкортостан, Федоровский район, Федоровский сельсовет с.Федоровка, Коммунистическая, 94		0101000020E6100000FBB0DEA815984B406614CB2DAD964A40
22679	7	61	1261	33601	66415	\N	53.177002163743701	Республика Башкортостан, Федоровский район, Булякаевский сельсовет с.Верхний-Алыштан, Дружбы, 91	Россия, республика Башкортостан, Федоровский район, село Федоровка	0101000020E61000007A56D28A6F984B40CEA96400A8964A40
22097	7	61	1261	45679	65480	\N	53.034678999999997	д. Новояушево, Ленина, 37а		0101000020E61000003E9468C9E3AF4B40D26D895C70844A40
22653	7	61	1261	58842	66567	\N	53.104827	Республика Башкортостан, Федоровский район, Каралачикский сельсовет с.Каралачик, Центральная, 57а	Россия, республика Башкортостан, Федоровский район, село Каралачик	0101000020E6100000CA332F87DD9B4B40705E9CF86A8D4A40
22669	7	61	1261	32580	\N	\N	53.012542000000003	Республика Башкортостан, Федоровский район, Денискинский сельсовет с.Денискино, Центральная, 12	Россия, республика Башкортостан, Федоровский район, село Денискино	0101000020E610000085B4C6A013924B40C9E9EBF99A814A40
22739	7	61	659	46686	66602	\N	54.617643999999999	453806, РБ, Хайбуллинский  район, д.Комсомольск, ул.З.Биишевой, д.3		0101000020E6100000D61BB5C2F4DD4D400A4966F50E4F4B40
22673	7	61	1261	32601	64255	\N	53.172443000000001	Республика Башкортостан, Федоровский район, Гончаровский сельсовет с.Гончаровка, Салавата Юлаева, 10		0101000020E6100000AA7CCF48848E4B404AB6BA9C12964A40
22652	7	61	1261	33108	64095	\N	53.094332000000001	Республика Башкортостан, Федоровский район, Балыклинский сельсовет с.Балыклы, Ленина, 8		0101000020E61000002A73F38DE8A64B40AF7B2B12138C4A40
22626	7	61	659	11421	65039	\N	54.305199000000002	с.Учалы - ПУ №98, Школьная, 2		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22622	7	61	659	11421	66457	\N	54.292645478269201	"с.Учалы - ""Рябинушка"", Тагирова, 1а"	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E6100000BA9F53909FB74D40412B306475254B40
22633	7	61	659	11421	63805	\N	54.305199000000002	г.Учалы - 2-й уч. корпус УУИиК, Строительная, 8		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22634	7	61	659	11421	63808	\N	54.298067766759303	г.Учалы - техникум, Пионерская, 6	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E61000006CD102B4ADB64D40F8FD9B1727264B40
22623	7	61	659	11421	64533	\N	54.305199000000002	с. Учалы - лесхоз, Партизанская, 16		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22635	7	61	659	11421	63968	\N	54.301354170096502	г.Учалы - Ледовая арена, Мира, 3	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E610000003780B2428B64D40684293C492264B40
22639	7	61	659	11421	63989	\N	54.3092113295803	г.Учалы - Филармония, Ленина, 27	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E61000005E143DF031B64D401F48DE3994274B40
22644	7	61	659	11421	63558	\N	54.305199000000002	"г.Учалы - помещение ТОУ ""Роспотребнадзор"", Ахметгалина, 12"		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22643	7	61	659	11421	63558	\N	54.305199000000002	г.Учалы - Ветстанция, Ахметгалина, 6		0101000020E6100000392A37514BB54D40CEE2C5C210274B40
22630	7	61	659	11421	66528	\N	54.305798307962199	г.Учалы - Торговый центр, Чехова, 17	Россия, республика Башкортостан, Учалинский район, Учалы	0101000020E610000023A30392B0B54D4053978C6324274B40
22621	7	61	659	58183	64192	\N	54.3613781011599	с. Учалы - элеватор, Элеваторный переулок, 1	Россия, республика Башкортостан, Учалинский район, село Учалы	0101000020E61000002C0C91D3D7B74D4038BF61A2412E4B40
22620	7	61	659	58183	64178	\N	54.361779103012303	с.Учалы - детский сад, С.Юлаева, 4	Россия, республика Башкортостан, Учалинский район, село Учалы	0101000020E6100000C85C19541BB84D4096B036C64E2E4B40
22617	7	61	659	46927	63551	\N	54.123021999999999	Уральск, Гагарина, 12		0101000020E61000005BEF37DA718F4D402158552FBF0F4B40
22613	7	61	659	10890	64263	\N	54.266562999999998	Уразово, Центральная, 16		0101000020E61000005AB8ACC266904D406DA983BC1E224B40
22604	7	61	659	10488	66708	\N	54.602403000000002	"Учалинский район, д.Тунгатарово, ул.Ирандыкская, 41а  "		0101000020E6100000F52A323A20DD4D409301A08A1B4D4B40
22570	7	61	659	8822	65630	\N	54.022303999999998	Сураманово, Школьная, 14		0101000020E610000082919735B1804D40F54883DBDA024B40
21724	7	61	659	31502	65964	\N	54.773173999999997	д.Сулейманово, Турновская, 19		0101000020E61000004EEE77280AF04D400A0F9A5DF7624B40
22603	7	61	659	10419	64688	\N	54.569809999999997	Старомуйнаково, Школьная, 6		0101000020E6100000757632384ADC4D408577B988EF484B40
22607	7	61	659	10622	65044	\N	54.661766	Старобалбуково, Клубная, 8/2		0101000020E61000009C89E942ACD64D4068CD8FBFB4544B40
22608	7	61	659	10670	65457	\N	54.729813	Старобайрамгулово, Центральная, 47		0101000020E6100000FEEDB25F77DA4D400B992B836A5D4B40
22627	7	61	659	11523	66183	\N	54.337977000000002	Сайтаково, М.Шагеева, 31		0101000020E61000003B1C5DA5BBC74D406DE690D4422B4B40
22582	7	61	659	9371	65210	\N	54.470875999999997	Рысаево, Центральная, 1		0101000020E6100000B9C4910722B14D40533C2EAA453C4B40
22585	7	61	659	9500	65640	\N	54.213056000000002	Расулево, Школьная, 33		0101000020E6100000B43EE5982C9E4D40B91B446B451B4B40
22599	7	61	659	58592	65650	\N	54.630654	Поляковка, Советская, 94	Россия, республика Башкортостан, Учалинский район, село Поляковка	0101000020E6100000DE7536E49FD94D40B98B3045B9504B40
22602	7	61	659	10376	66174	\N	54.428944999999999	Первый Май, Заречная, 7		0101000020E6100000ED0BE8853BD94D40306475ABE7364B40
22616	7	61	659	45770	65269	\N	54.097426930516001	Октябрьск, Школьная, 25	Россия, республика Башкортостан, Учалинский район, село Октябрьск	0101000020E6100000800BB265F99C4D40AB5FE97C780C4B40
22102	7	61	659	45770	65391	\N	54.098637677045801	д. Октябрьск, Центральная, 17	Россия, республика Башкортостан, Учалинский район, село Октябрьск	0101000020E6100000A7954220979C4D404912842BA00C4B40
22594	7	61	659	9975	66871	\N	53.951998000000003	Учалинский район, с. Озерный, ул.Школьная, д.31		0101000020E61000001F4AB4E4F16C4D40C0ED0912DBF94A40
22598	7	61	659	10143	64531	\N	54.100183999999999	Новобайрамгулово, Шоссейная, 43		0101000020E6100000DEE7F86871844D408ECA4DD4D20C4B40
22597	7	61	659	46529	65037	\N	54.046047999999999	Наурузово, Школьный, 7		0101000020E61000002DB1321AF98A4D40EA059FE6E4054B40
22619	7	61	659	9158	66722	\N	54.397895815619798	Ургуново, Школьная, 10	Россия, республика Башкортостан, Учалинский район, село Мулдашево	0101000020E6100000BCCB457C27B24D40C89A9141EE324B40
22577	7	61	659	9158	65456	\N	54.397759000000001	Мулдашево, Иремельская, 49		0101000020E61000001D9430D3F6B14D40475854C4E9324B40
22596	7	61	659	58496	65217	\N	53.980182999999997	Москово, Школьная, 24	Россия, республика Башкортостан, Учалинский район, село Москово	0101000020E610000078D503E6218D4D402E8CF4A276FD4A40
22592	7	61	659	9838	63292	\N	54.033782270570001	Миндяк, Уфимская, 3	Россия, республика Башкортостан, Учалинский район, поселок Миндяк	0101000020E61000008658FD1186654D40C498F4F752044B40
22589	7	61	659	32736	64518	\N	54.485543999999997	Мансурово, Мира, 7б	Россия, республика Башкортостан, Учалинский район, село Мансурово	0101000020E61000005D514A0856C34D406F62484E263E4B40
22571	7	61	659	8900	65032	\N	54.055050000000001	Малоказаккулово, Советская, 30		0101000020E6100000DC847B65DE784D4089D2DEE00B074B40
22578	7	61	659	46100	65624	\N	54.836886	Кучуково, Хандугас, 1		0101000020E610000037E15E99B7F44D40793D98141F6B4B40
22606	7	61	659	10576	66686	\N	54.637141999999997	"Учалинский район, д.Курамино, ул.Соловьиная, 9  "		0101000020E610000090DD054A0AE84D403A747ADE8D514B40
22587	7	61	659	9615	64354	\N	54.340291999999998	Кунакбаево, Шоссейная, 23	Россия, республика Башкортостан, Учалинский район, село Кунакбаево	0101000020E610000061C26856B6A74D40938B31B08E2B4B40
22576	7	61	659	9124	65523	\N	54.6950816773155	Каримово, Центральная, 21	Россия, республика Башкортостан, Учалинский район, село Каримово	0101000020E610000023DA8EA9BBE84D40E6046D72F8584B40
22618	7	61	659	11134	66177	\N	54.410257999999999	Калканово, Школьная, 2		0101000020E610000054C37E4FACA74D4010768A5583344B40
22609	7	61	659	10704	65041	\N	54.689444999999999	Кажаево, Центральная, 7		0101000020E610000045D7851F9CCD4D4003B2D7BB3F584B40
22610	7	61	659	10769	65641	\N	54.203684634340497	Ишмекеево, Сорагул, 3	Россия, республика Башкортостан, Учалинский район, село Ишмекеево	0101000020E6100000EF1AF4A5B78F4D40C7D79E59121A4B40
22615	7	61	659	10980	65469	\N	54.167571000000002	Ишкиново, Школьная, 22		0101000020E610000041649126DE954D4007616EF772154B40
22614	7	61	659	10956	66186	\N	54.139941	Истамгулово, Центральная, 29		0101000020E610000015376E313F954D404D2F3196E9114B40
22583	7	61	659	58289	64594	\N	54.273590296420799	Имангулово, Центральная, 49	Россия, республика Башкортостан, Учалинский район, село Имангулово	0101000020E61000002BC0779B37A84D409E4143FF04234B40
22581	7	61	659	9347	63997	\N	54.420338000000001	Ильчино, Кучербай, 2		0101000020E6100000B665C0594AC44D400EA2B5A2CD354B40
22575	7	61	659	32626	64567	\N	54.756958582714297	Ильчигулово, Агышбай, 60	Россия, республика Башкортостан, Учалинский район, село Ильчигулово	0101000020E6100000B41EBE4C14E74D40D9B45208E4604B40
22600	7	61	659	46605	65462	\N	54.645358999999999	Вознесенка, Зеленая, 24		0101000020E61000001344DD0720CB4D40F296AB1F9B524B40
22574	7	61	659	9150	64034	\N	54.252763000000002	Буйда, Центральная, 35		0101000020E61000007974232C2AC04D40C651B9895A204B40
22595	7	61	659	4468	66604	\N	53.884279999999997	Учалинский район, д.Батталово, ул.Школьная, д. 2		0101000020E61000004147AB5AD26F4D40E140481630F14A40
22573	7	61	659	8920	63721	\N	54.210239000000001	Ахуново, Партизанская, 121		0101000020E610000070B4E386DFCD4D4000AC8E1CE91A4B40
22572	7	61	659	8920	63721	\N	54.210239000000001	Ахуново, Партизанская, 67		0101000020E610000070B4E386DFCD4D4000AC8E1CE91A4B40
20132	7	61	659	47810	\N	\N	53.918608999999996	д.Аслаево, ул.Комсомольская, 5	Россия, республика Башкортостан, Учалинский район, село Аслаево	0101000020E610000011A8FE4124774D40D767CEFA94F54A40
22590	7	61	659	9745	64130	\N	54.584204395370897	Абзаково, Шоссейная, 1а	Россия, республика Башкортостан, Учалинский район, село Абзаково	0101000020E6100000F67CCD72D9C64D40A0185932C74A4B40
22567	7	61	284	58260	64540	\N	54.6164260423594	Республика Башкортостан, Уфимский район, с. санатория Юматово имени 15-летия БАССР, Кольцевая, 27	Россия, республика Башкортостан, Уфимский район, село санаторий Юматово	0101000020E6100000CB4C69FD2DD14B40B933130CE74E4B40
22569	7	61	284	45892	63547	\N	54.623643999999999	Республика Башкортостан, Уфимский район, д. Юматово, Центральная, 46		0101000020E6100000BF61A2410AD84B405E2C0C91D34F4B40
22568	7	61	284	45892	64535	\N	54.6232459659605	Республика Башкортостан, Уфимский район, с. станции Юматово, Северная, 51	Россия, республика Башкортостан, Уфимский район, поселок Юматово	0101000020E61000009B1DA9BEF3D74B4071AE6186C64F4B40
22566	7	61	284	8641	65453	\N	54.789748000000003	Республика Башкортостан, Уфимский район, с. Шемяк, Молодежная, 6		0101000020E6100000AF601BF164BF4B406C0A647616654B40
22559	7	61	284	58546	65455	\N	54.949927693831803	Республика Башкортостан, Уфимский район, с. Чуварез, Заречная, 1	Россия, республика Башкортостан, деревня Чуварез	0101000020E61000009D499BAA7B1E4C4000C79E3D97794B40
22560	7	61	284	58137	63833	\N	54.608139000000001	Республика Башкортостан, Уфимский район, с. Чесноковка, Школьная, 47		0101000020E6100000E6913F1878F84B400936AE7FD74D4B40
22547	7	61	284	7731	64532	\N	54.858668000000002	Республика Башкортостан, Уфимский район, с. Чернолесовский, Школьная, 12		0101000020E6100000153944DC9CE84B40950F41D5E86D4B40
22558	7	61	284	58636	65811	\N	54.905587154721204	Республика Башкортостан, Уфимский район, с. Черкассы, Трактовая, 11	Россия, республика Башкортостан, село Черкасы	0101000020E6100000611A868F88194C4064575A46EA734B40
22539	7	61	284	7377	65449	\N	54.703780000000002	Республика Башкортостан, Уфимский район, д. Сергеевка, Центральная, 5а		0101000020E6100000A59F70766BDF4B4019CA8976155A4B40
22555	7	61	284	58168	64110	\N	54.707295999999999	Республика Башкортостан, Уфимский район, с. Русский Юрмаш, Центральная, 19		0101000020E6100000F56915FDA11F4C40BA4BE2AC885A4B40
22534	7	61	284	7167	63422	\N	54.867378000000002	Республика Башкортостан, Уфимский район, д. Подымалово, Южная, 22		0101000020E6100000EF586C938ADE4B408CA2073E066F4B40
22565	7	61	284	8627	65628	\N	54.77778	Республика Башкортостан, Уфимский район, д. Первомайский, Школьная, 24		0101000020E61000008E03AF963BB74B40CFBD874B8E634B40
22554	7	61	284	58195	64237	\N	54.551003428975598	Республика Башкортостан, Уфимский район, с. Ольховое, Буденова, 6	Россия, республика Башкортостан, поселок Конный Завод 119	0101000020E6100000BC74931804044C40BB7F2C4487464B40
22562	7	61	284	8479	63447	\N	54.761783999999999	Республика Башкортостан, Уфимский район, с. Октябрьский, Центральная, 14а		0101000020E6100000CAE2FE23D3BD4B40DB4E5B2382614B40
22553	7	61	284	8001	63549	\N	54.814132999999998	Республика Башкортостан, Уфимский район, с. Нурлино, Школьная, 22		0101000020E6100000C3F4BD86E0C84B4014CC988235684B40
22564	7	61	284	8559	66165	\N	54.724863999999997	Республика Башкортостан, Уфимский район, д. Новотроевка, Школьная, 14а		0101000020E6100000577BD80B05B64B401C06F357C85C4B40
22552	7	61	284	7993	63533	\N	54.819451000000001	Республика Башкортостан, Уфимский район, д. Николаевка, Советская, 22		0101000020E610000084674293C4D84B4056D636C5E3684B40
22541	7	61	284	58134	63817	\N	54.609302	Республика Башкортостан, Уфимский район, с. Нижегородка, Мира, 26/1		0101000020E610000065A71FD445EC4B4096B1A19BFD4D4B40
22549	7	61	284	58152	63987	\N	54.803964000000001	Республика Башкортостан, Уфимский район, с. Михайловка, Ленина, 48		0101000020E6100000D1CB28965BF24B40A794D74AE8664B40
22538	7	61	284	58321	64687	\N	54.735562999999999	Республика Башкортостан, Уфимский район, д. Мармылёво, Школьная, 3/2		0101000020E61000008369183E22E64B40E692AAED265E4B40
22546	7	61	284	1203	66781	\N	54.947594000000002	Уфимский район, с.Кумлекуль, ул.Центральная, д.15		0101000020E61000001CD0D2156CEF4B4063F19BC24A794B40
22545	7	61	284	7650	63673	\N	54.891401444628897	Республика Башкортостан, Уфимский район, с. Красный Яр, Советская, 82	Россия, республика Башкортостан, Уфимский район, село Красный Яр	0101000020E610000094BF7B478DF54B40944F8F6D19724B40
22537	7	61	284	58123	63716	\N	54.652588999999999	Республика Башкортостан, Уфимский район, с. Жуково, Ильина, 1а		0101000020E610000014967840D9E24B405B5D4E0988534B40
22531	7	61	284	58139	63851	\N	54.807259000000002	Республика Башкортостан, Уфимский район, с. Дмитриевка, Советская, 23		0101000020E61000003AB01C2103E74B406A334E4354674B40
22536	7	61	284	7267	64390	\N	54.895533	Республика Башкортостан, Уфимский район, д. Волково, Мкр.Солнечный, 1		0101000020E6100000BB0F406A13CF4B4090BE49D3A0724B40
22563	7	61	284	8543	64882	\N	54.722552428486402	Республика Башкортостан, Уфимский район, с. Бейгулово, Бейгуловская, 13/1	Россия, республика Башкортостан, Уфимский район, село Бейгулово	0101000020E6100000882D3D9AEABF4B4067D47C957C5C4B40
22543	7	61	284	7567	66171	\N	54.894894501337703	Республика Башкортостан, Уфимский район, с. Асаново, Восточная, 1	Россия, республика Башкортостан, Уфимский район, село Асаново	0101000020E61000008D0A9C6C03BF4B404D2D5BEB8B724B40
22527	7	61	284	58098	63810	\N	54.832607923184398	Республика Башкортостан, Уфимский район, д. Алексеевка, Школьная, 4	Россия, республика Башкортостан, деревня Алексеевка, улица Школьная, 3	0101000020E6100000994869368FFF4B40A93121E6926A4B40
22526	7	61	284	58098	63409	\N	54.830972478735497	Республика Башкортостан, Уфимский район, д. Алексеевка, Центральная, 52		0101000020E6100000F10D85CFD6FF4B4024F25D4A5D6A4B40
22525	7	61	284	6717	63574	\N	54.669440999999999	Республика Башкортостан, Уфимский район, с. Авдон, 60-летия СССР, 2		0101000020E61000002D7B12D89CDB4B40FFCC203EB0554B40
22661	7	61	308	13131	\N	\N	54.538946000000003	Республика Башкортостан, Федоровский район, Михайловский сельсовет с.Батырово, 1 мая, 35		0101000020E610000086713788D6FE4A40AF27BA2EFC444B40
22480	7	61	308	4343	64388	\N	54.603544999999997	с.Япрыково, Уфимская, 8		0101000020E610000011FE45D098C34A4008556AF6404D4B40
22492	7	61	308	5010	\N	\N	54.354393999999999	с.Чукадытамак, Школьная, 2	Россия, республика Башкортостан, Туймазинский район, село Чукадытамак	0101000020E610000030BB270F0B0D4B4006F357C85C2D4B40
22514	7	61	308	6156	66052	\N	54.634833999999998	д.Чуваш-Улканово, Пушкина, 2	Россия, республика Башкортостан, Туймазинский район, село Чуваш-Улканово	0101000020E6100000121615713AED4A40C631923D42514B40
22477	7	61	308	58556	65493	\N	54.338894660306003	д.Фрунзе, Центральная, 1	Россия, республика Башкортостан, Туймазинский район, село Фрунзе	0101000020E6100000240B98C0ADDD4A4093E34EE9602B4B40
22498	7	61	308	5309	66031	\N	54.371023999999998	с.Уязытамак, Школьная, 69		0101000020E61000009F909DB7B1B54A40FB03E5B67D2F4B40
22505	7	61	308	5663	65198	\N	54.544702000000001	с.Урмекеево, Социалистическая, 49		0101000020E6100000BAF59A1E141C4B406C088ECBB8454B40
22471	7	61	308	3858	64063	\N	54.646250000000002	с.Туктагулово, Центральная, 32,А	Россия, республика Башкортостан, Туймазинский район, село Туктагулово	0101000020E61000002DB4739A05084B401F85EB51B8524B40
22450	7	61	308	2300	63314	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Советская, 2,Б		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22457	7	61	308	2300	66618	\N	54.608040000000003	452750,г.Туймазы,ул. Пугачева, д.5-а		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22454	7	61	308	2300	63543	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Островского, 11		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22443	7	61	308	2300	63717	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Луначарского, 24		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22444	7	61	308	2300	66717	\N	54.600917034631898	452750, г.Туймазы,ул. Лесовода Морозова, 5	Россия, республика Башкортостан, Туймазинский район, Туймазы	0101000020E6100000A33EC91D36D94A40234E27D9EA4C4B40
22462	7	61	308	2300	63302	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Комарова, 26,А	Россия, республика Башкортостан, Туймазинский район, Туймазы	0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22458	7	61	308	2300	63325	\N	54.608040000000003	Республика Башкортостан, Туймазинский район, город Туймазы, Гагарина, 32		0101000020E6100000EA20AF0793DA4A4076543541D44D4B40
22518	7	61	308	6364	65503	\N	54.690330000000003	д.Тирян-Елга, Лесная, 1,1		0101000020E610000098BF42E6CAF64A404EB9C2BB5C584B40
22513	7	61	308	6091	65199	\N	54.624124000000002	с.Татар-Улканово, Ленина, 15		0101000020E6100000C3EFA65B76F24A400953944BE34F4B40
22511	7	61	308	49199	63480	\N	54.556393999999997	с.Субханкулово, Школьная, 1		0101000020E6100000697407B133E74A4066D828EB37474B40
22510	7	61	308	49199	63506	\N	54.556254497671098	с.Субханкулово, Черняева, 3	Россия, республика Башкортостан, Туймазинский район, поселок Субханкулово	0101000020E6100000E6CFB7054BE74A407522C15433474B40
22509	7	61	308	5887	63454	\N	54.546723	с.Старые Туймазы, Гаражная, 2,А		0101000020E6100000F69672BED8CD4A404A7CEE04FB454B40
22487	7	61	308	4711	65612	\N	54.54383	с.Старые Кандры, Центральная, 30,А		0101000020E6100000EDF0D7648D064B40B64AB0389C454B40
22507	7	61	308	5758	63491	\N	54.424225	с.Серафимовский, площадь Советская, 5		0101000020E61000000B7F86376BE64A40A3923A014D364B40
22508	7	61	308	5758	63494	\N	54.424225	с.Серафимовский, Ленина, 9		0101000020E61000000B7F86376BE64A40A3923A014D364B40
22506	7	61	308	5758	63476	\N	54.424225	с.Серафимовский, 21-ый квартал, 1		0101000020E61000000B7F86376BE64A40A3923A014D364B40
22504	7	61	308	5636	64386	\N	54.478747724507002	с.Сайраново, Советская, 2	Россия, республика Башкортостан, Туймазинский район, село Сайраново	0101000020E610000022FE614B8F184B4041834D9D473D4B40
22522	7	61	308	6587	64264	\N	54.633651	с.Райманово, Гагарина, 35	Россия, республика Башкортостан, Туймазинский район, село Райманово	0101000020E61000001AC231CB9EDA4A40F209D9791B514B40
22512	7	61	308	6061	63495	\N	54.572842000000001	д.Нуркеево, Первомайская, 24		0101000020E6100000459C4EB2D5E54A403BE3FBE252494B40
22461	7	61	308	58720	66168	\N	54.5200254626562	д.Никитинка, Центральная, 47	Россия, республика Башкортостан, Туймазинский район, село Никитинка	0101000020E61000009C86A8C29FEF4A401B0DE02D90424B40
22516	7	61	308	58775	66433	\N	54.614162241266001	д.Нижний Сардык, Центральная, 41,А	Россия, республика Башкортостан, Туймазинский район, село Нижный Сардык	0101000020E610000030A182C30BFC4A40153944DC9C4E4B40
22475	7	61	308	58278	64573	\N	54.488149115901997	с.Нижние Бишинды, Зеленая, 53,А	Россия, республика Башкортостан, Туймазинский район, село Нижнии Бишинды	0101000020E6100000B325AB22DCDE4A409D499BAA7B3E4B40
22500	7	61	308	5342	63671	\N	54.340795999999997	с.Нижнетроицкий, Ленина, 59,А		0101000020E6100000FDC1C073EFD74A40C64D0D349F2B4B40
22499	7	61	308	5342	63330	\N	54.340795999999997	с.Нижнетроицкий, Гагарина, 6		0101000020E6100000FDC1C073EFD74A40C64D0D349F2B4B40
22493	7	61	308	5022	65102	\N	54.308782000000001	с.Метевтамак, Чапаева, 35		0101000020E610000014252191B60F4B40F7CB272B86274B40
21039	7	61	308	30197	66208	\N	54.637033000000002	с. Киска-Елга, Коммунистическая, 22		0101000020E610000077DA1A118CEB4A4084BC1E4C8A514B40
22503	7	61	308	5571	66039	\N	54.477321000000003	с.Кендектамак, Клубная, 2		0101000020E61000007E552E54FEF54A40D658C2DA183D4B40
22497	7	61	308	5229	65645	\N	54.340491999999998	с.Каратово, Школьная, 41		0101000020E610000063B9A5D590B64A405A46EA3D952B4B40
22491	7	61	308	4921	64106	\N	54.351013999999999	с.Карамалы-Губеево, Ленина, 65		0101000020E61000003B1DC87A6A074B401538D906EE2C4B40
22502	7	61	308	5507	66044	\N	54.493901000000001	с.Кандрыкуль, Озерная, 91		0101000020E61000001D3BA8C475024B40193BE125383F4B40
22488	7	61	308	4790	64173	\N	54.513103000000001	с.Кандры-Кутуй, Молодежная, 28		0101000020E6100000F05014E8130D4B40603DEE5BAD414B40
22485	7	61	308	4490	63686	\N	54.550618999999998	с.Кандры, Мира, 10		0101000020E610000096CE8767090E4B4032C7F2AE7A464B40
22483	7	61	308	4490	63692	\N	54.550618999999998	с.Кандры, Матросова, 14		0101000020E610000096CE8767090E4B4032C7F2AE7A464B40
22484	7	61	308	4490	63568	\N	54.550618999999998	с.Кандры, Крупской, 5		0101000020E610000096CE8767090E4B4032C7F2AE7A464B40
22486	7	61	308	4490	63550	\N	54.550618999999998	с.Кандры, Вострецова, 2		0101000020E610000096CE8767090E4B4032C7F2AE7A464B40
22494	7	61	308	5097	65696	\N	54.313088999999998	с.Кальшали, Центральная, 22		0101000020E610000041F0F8F6AE094B4061DEE34C13284B40
22481	7	61	308	4372	64103	\N	54.698524999999997	с.Какрыбашево, Школьная, 10		0101000020E6100000D751D50451D34A401D38674469594B40
22479	7	61	308	4264	64524	\N	54.638882000000002	с.Ильчимбетово, Советская, 1		0101000020E6100000B5A84F7287C94A406500A8E2C6514B40
22489	7	61	308	4825	64222	\N	54.585669062442399	с.Ермухаметово, Даутова, 1,Б	Россия, республика Башкортостан, Туймазинский район, село Ермухаметово	0101000020E610000069C878944A164B40F9A3A833F74A4B40
22472	7	61	308	3902	64636	\N	54.646286000000003	с.Ермунчино, Центральная, 19,А		0101000020E610000058E71890BD1E4B406CEEE87FB9524B40
22427	7	61	308	1381	62326	\N	54.549272000000002	с.Дуслык, Клубная, 1,А		0101000020E6100000E27327D87FE34A40E44D7E8B4E464B40
22478	7	61	308	4222	63324	\N	54.524945000000002	с.Гафурово, Школьная, 4,1		0101000020E6100000E4F38AA71ED94A407099D36531434B40
22517	7	61	308	6298	65201	\N	54.642221999999997	с.Верхний Сардык, Центральная, 22,А		0101000020E6100000E40F069E7BFB4A40C7629B5434524B40
22473	7	61	308	3947	64129	\N	54.477949000000002	с.Верхние Бишинды, Победы, 48,А		0101000020E61000008DEE2076A6DA4A40F513CE6E2D3D4B40
22476	7	61	308	4119	64267	\N	54.345751	с.Верхнетроицкое, Базарная, 28		0101000020E6100000E413B2F336E44A4097C79A91412C4B40
22470	7	61	308	58555	65488	\N	54.668657942957601	с.Бишкураево, Гагарина, 12, А	Россия, республика Башкортостан, Туймазинский район, село Бишкураево	0101000020E610000055F7C8E6AA174B40B91AD99596554B40
22515	7	61	308	6206	65200	\N	54.588313999999997	с.Аднагулово, Центральная, 31,А		0101000020E6100000BAF42F4965F24A40B4E386DF4D4B4B40
22520	7	61	308	6471	64199	\N	54.625255000000003	с.Агиртамак, Комарова, 47,В		0101000020E6100000E481C8224DE24A408B54185B08504B40
22482	7	61	308	2194	66181	\N	54.767133999999999	с.Аблаево, Центральная, 38,2		0101000020E61000001E51A1BAB9D24A4028D3687231624B40
22440	7	61	102	2130	65087	\N	56.13897	с.Ялгыз-Нарат, Центральная, 3а		0101000020E61000005018946934DF4B400490DAC4C9114C40
22407	7	61	102	142	65195	\N	56.357000999999997	д.Юда, Центральная, 35		0101000020E6100000FE62B66455F24B40D4D17135B22D4C40
22437	7	61	102	1944	64332	\N	56.153387000000002	с.Шулганово, Центральная, 58	Россия, республика Башкортостан, Татышлинский район, село Шулганово	0101000020E61000002106BAF605C04B40D7506A2FA2134C40
22399	7	61	102	32227	65452	\N	56.139055554879398	д.Чургулды, Ленина, 36А	Россия, республика Башкортостан, Татышлинский район, село Чургулды	0101000020E6100000A3E716BA12D34B4002284696CC114C40
22436	7	61	102	1887	65192	\N	56.254657000000002	с.Уразгильды, Центральная, 32		0101000020E61000001822A7AFE7EF4B404759BF9998204C40
22419	7	61	102	58792	66473	\N	56.328700727874399	д.Старый Шардак, Центральная, 33а	Россия, республика Башкортостан, Татышлинский район, село Староый Шардак	0101000020E6100000C5E2378595F64B40CD94D6DF122A4C40
22442	7	61	102	58762	66383	\N	56.163455064948799	д.Старый Сикияз, Дружбы, 63	Россия, республика Башкортостан, Татышлинский район, село Староый Сикияз	0101000020E61000006CEC12D55BE94B4010AFEB17EC144C40
22425	7	61	102	1205	66019	\N	56.251806999999999	с.Старый Курдым, Центральная, 25		0101000020E6100000E90AB6114FBE4B40B2F336363B204C40
22432	7	61	102	58803	66493	\N	56.242534668750203	д.Старый Кызыл-Яр, Центральная, 22а	Россия, республика Башкортостан, Татышлинский район, село Староый Кызыл-Яр	0101000020E6100000DFE2E13D07144C4053910A630B1F4C40
22408	7	61	102	215	66889	\N	56.332697716443001	Татышлинский район, д.Старочукурово, ул.М.Джалиля, д.1	Россия, республика Башкортостан, Татышлинский район, село Старочукурово	0101000020E6100000FB777DE6ACD54B40E9B81AD9952A4C40
22317	7	61	102	58752	66359	\N	56.427393806062298	д.Старосолдово, Лесная, 39	Россия, республика Башкортостан, Татышлинский район, село Старосолодово	0101000020E6100000AA471ADCD6E24B40D940BAD8B4364C40
22414	7	61	102	605	64257	\N	56.168962000000001	с.Старокальмиярово, Советская, 6		0101000020E61000008E3F51D9B0044C402522FC8BA0154C40
22389	7	61	102	31766	65446	\N	56.372816999999998	с.Старокайпаново, Центральная, 66		0101000020E6100000179F02603CDF4B404832AB77B82F4C40
22397	7	61	102	19032	66199	\N	56.124033573589102	с.Староакбулатово, Центральная, 36б	Россия, республика Башкортостан, Татышлинский район, село Староакбулатово	0101000020E6100000800D881057CC4B40C9CB9A58E00F4C40
22398	7	61	102	1319	65304	\N	56.103507	д.Савалеево, Центральная, 24	Россия, республика Башкортостан, Татышлинский район, село Савалеево	0101000020E6100000BABDA4315ACD4B401BF4A5B73F0D4C40
22121	7	61	102	46175	65898	\N	56.103337000000003	д. Новоакбулатово, Ленина, 24		0101000020E6100000E4688EACFCCA4B40BFBB95253A0D4C40
22374	7	61	102	31031	64848	\N	56.343234000000002	д.Маматаево, Центарльная, 13		0101000020E610000018080264E8DA4B4009707A17EF2B4C40
22435	7	61	102	58429	64989	\N	56.218592588607798	д.Малая Бальзюга, М.Гарипова, 30	Россия, республика Башкортостан, Татышлинский район, село Малая Бальзюга	0101000020E61000000B0BEE073C004C403811FDDAFA1B4C40
22433	7	61	102	1720	66029	\N	56.289909999999999	д.Кыткы-Елга, Парковая, 2		0101000020E610000045DAC69FA8144C40456458C51B254C40
22423	7	61	102	1142	65900	\N	56.268135999999998	д.Кардагушево, Фрунзе, 33		0101000020E610000027A5A0DB4BCE4B40AC70CB4752224C40
22417	7	61	102	791	65945	\N	56.277493	с.Кальятево, ул.Арманшина, 67		0101000020E6100000C097C28366F94B4039EFFFE384234C40
22404	7	61	102	58801	66489	\N	56.356411629568001	с. Ильметьево, Центральная, 42	Россия, республика Башкортостан, Татышлинский район, село Ильметово	0101000020E6100000E04BE141B3D14B4073F38DE89E2D4C40
22438	7	61	102	2000	65187	\N	56.169888999999998	д.Гарибашево, Октябрьская, 8		0101000020E61000009FCBD42478C94B409E7939ECBE154C40
22413	7	61	102	282	64042	\N	56.291992999999998	с.Верхние Татышлы, ул.Строителей, д.21		0101000020E6100000E3344415FEEC4B4099D4D00660254C40
22412	7	61	102	282	62325	\N	56.291992999999998	с.Верхние Татышлы, Советская, 2		0101000020E6100000E3344415FEEC4B4099D4D00660254C40
22411	7	61	102	282	63329	\N	56.291992999999998	с.Верхние Татышлы, Ленина, 57		0101000020E6100000E3344415FEEC4B4099D4D00660254C40
22410	7	61	102	282	63329	\N	56.291992999999998	с.Верхние Татышлы, Ленина, 67		0101000020E6100000E3344415FEEC4B4099D4D00660254C40
22409	7	61	102	282	64201	\N	56.291992999999998	с.Верхние Татышлы, Комсомольская, 36		0101000020E6100000E3344415FEEC4B4099D4D00660254C40
22421	7	61	102	940	65955	\N	56.285603000000002	с.Верхнекудашево, Хайдарова, 1		0101000020E6100000F1D58EE21CD94B40DB519CA38E244C40
22420	7	61	102	940	65955	\N	56.285603000000002	Татышлинский район, с.Верхнекудашево, ул.Хайдарова, д.23		0101000020E6100000F1D58EE21CD94B40DB519CA38E244C40
22330	7	61	102	28945	64336	\N	56.328194000000003	с.Буль-Кайпаново, Ленина, 47		0101000020E610000037514B732BE44B40295FD042022A4C40
22406	7	61	102	47331	65196	\N	56.419412999999999	с.Беляшево, ул.Школьная, 30		0101000020E6100000FE0C6FD6E0F14B4035423F53AF354C40
22441	7	61	102	2198	64817	\N	56.116954	с.Башкибаш, Центральаня, 47а		0101000020E6100000C0249529E6D84B4075914259F80E4C40
22405	7	61	102	32455	65985	\N	56.378011000000001	д.Бадряшево, ул.Матросова, 6		0101000020E61000006440F67AF7F14B409E4319AA62304C40
22401	7	61	102	32315	65944	\N	56.348612000000003	д. Артаулово, Центральная, 32		0101000020E6100000BA6A9E23F2C14B40207F69519F2C4C40
22422	7	61	102	27367	66853	\N	56.247841000000001	Татышлинский район, д.Арибаш,  ул.Школьная, д.2		0101000020E61000003813D38558E14B40D1CDFE40B91F4C40
22400	7	61	102	32242	64248	\N	56.363219000000001	с. Аксаитово, Центральная, 42		0101000020E6100000897C975297CC4B409624CFF57D2E4C40
22429	7	61	102	1483	65693	\N	56.263292	д. 2-Зиримзибаш, Центральная, 33		0101000020E6100000A872DA5372BA4B4033A6608DB3214C40
22321	7	61	130	58215	64364	\N	53.848424999999999	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, с.Первомайский, Молодежная, 6/2	Россия, республика Башкортостан, Стерлитамакский район, село совхоза Первомайский	0101000020E6100000EBE5779ACCB64B40ED0DBE3099EC4A40
22377	7	61	130	58215	66697	\N	53.849049380507303	453164, РБ Стерлитамакский район, с. Первомайское, ул. Дружбы, д.13	Россия, республика Башкортостан, Стерлитамакский район, село совхоза Первомайский	0101000020E6100000D10836AE7FB74B40CBD93BA3ADEC4A40
22394	7	61	130	58874	66763	\N	53.637183	453162, РБ Стерлитамакский район,с. Нижние Услы, ул. Имая Насыри, 46а		0101000020E6100000732B84D558DE4B40994869368FD14A40
22383	7	61	130	58911	67008	\N	53.624123213097498	453152, РБ Стерлитамакский район, с. Большое Аксаково, ул. Южная, 24	Россия, республика Башкортостан, Стерлитамакский район	0101000020E6100000E4F8A1D288DB4B4038D73043E3CF4A40
22368	7	61	130	30724	66770	\N	53.710532000000001	453147, РБ Стерлитамакский район, д. Южный, ул. Степная, д.1а		0101000020E610000075CC79C6BEB64B4078616BB6F2DA4A40
22378	7	61	130	58889	66942	\N	53.899135587741902	453164, РБ Стерлитамакский район, д. Красноармейская, ул. Мира, д. 17	Россия, республика Башкортостан, Стерлитамакский район, село отделение Красноармейское	0101000020E6100000B613252191B04B40005471E316F34A40
22380	7	61	130	31324	66730	\N	53.788623387380099	453164, РБ Стерлитамакский район, д. Бегеняш, ул. Ленина, д. 23а	Россия, республика Башкортостан, Стерлитамакский район, село отделение Бегеняш Совхоза Первомайский	0101000020E6100000DD7BB8E4B8BF4B40CCEF3499F1E44A40
21000	7	61	130	58821	66525	\N	53.636223595025299	деревня хозяйства заготскота, Набережная, 2	Россия, республика Башкортостан, Стерлитамакский район, село база Заготовки Скота	0101000020E6100000B9FC87F4DBED4B401477BCC96FD14A40
22337	7	61	130	29282	66759	\N	53.742593872100699	453154, РБ Стерлитамакский район,д. Юрактау, ул. Шоссейная, д.10а		0101000020E61000008D7BF31B26104C40581AF8510DDF4A40
22395	7	61	130	32041	66922	\N	53.733553000000001	453162, РБ Стерлитамакский район,д. Чуртан, ул. Молодежная, д. 5 е		0101000020E610000081B1BE81C9C14B40FC709010E5DD4A40
22351	7	61	130	58888	66941	\N	53.770780360368299	453153, РБ Стерлитамакский район, д. Чувашский Куганак, ул. Центральная, д. 1а	Россия, республика Башкортостан, Стерлитамакский район, село Чувашский Чуганак	0101000020E61000003CA1D79FC4034C40983446EBA8E24A40
22396	7	61	130	32099	66619	\N	53.762109000000002	453162, РБ Стерлитамакский район,с. Услыбаш, ул. Мира, д.12 в		0101000020E610000094DA8B683BC84B405F7EA7C98CE14A40
22392	7	61	130	31918	66798	\N	53.460642	453162, РБ Стерлитамакский район, с. Тюрюшля, ул. Центральная, д.43г		0101000020E6100000AC8C463EAFD04B40FF942A51F6BA4A40
22344	7	61	130	29563	66864	\N	53.7557067227903	453161, РБ Стерлитамакский район, с. Талачево, ул. Октябрьская, д. 32	Россия, республика Башкортостан, Стерлитамакский район, село Талачево	0101000020E610000042B0AA5E7EE54B40DC2DC901BBE04A40
22386	7	61	130	31626	66684	\N	53.814112999999999	453152, РБ Стерлитамакский район, с. Талалаевка, ул. Мира, д. 22		0101000020E61000001286014BAE024C40CD1FD3DA34E84A40
20210	7	61	130	58117	63665	\N	53.611472556780498	Республика Башкортостан, город Стерлитамак, Водолаженко, 2А	Россия, республика Башкортостан, Стерлитамакский район	0101000020E6100000DCDAC2F352F34B4089B14CBF44CE4A40
22367	7	61	130	30687	66761	\N	53.616989353570801	453147, РБ Стерлитамакский район, д. Северная, ул. Московская, д. 1а	Россия, республика Башкортостан, Стерлитамакский район, поселок Северное Отделение	0101000020E6100000C991CEC0C8D14B40F17EDC7EF9CE4A40
22345	7	61	130	29622	66657	\N	53.776611000000003	453161, РБ Стерлитамакский район, д. Садовка, ул. Первомайская, д. 31 а		0101000020E6100000BA9F53909FDF4B40605B3FFD67E34A40
22388	7	61	130	31737	66818	\N	53.668183999999997	453162, РБ Стерлитамакский район, д. Рязановка, ул. Центральная, д.77		0101000020E6100000D4450A65E1E14B40F0DAA50D87D54A40
22387	7	61	130	31677	66845	\N	53.747655000000002	453137, РБ Стерлитамакский район, с. Рощинский, ул. Лесная, д. 13		0101000020E6100000F982161230F64B406FD8B628B3DF4A40
22365	7	61	130	30581	66672	\N	53.567053999999999	453145, РБ Стерлитамакский район, д. Преображеновка, ул. Молодежная, д. 4		0101000020E61000006C770FD07DDD4B407288B83995C84A40
22334	7	61	130	29138	66900	\N	53.510995999999999	453142, РБ Стерлитамакский район,с. Помряскино, ул. Центральная, д. 73		0101000020E610000049D9226937EC4B408331225168C14A40
22361	7	61	130	29995	66710	\N	53.851309943005901	453167, РБ Стерлитамакский район, д. Покровка, ул. Центральная, д.37		0101000020E6100000ED48F59D5F124C40FE60E0B9F7EC4A40
22353	7	61	130	29995	66772	\N	53.851182277919101	453149, РБ Стерлитамакский район, с. Покровка, ул.Мира, д.9		0101000020E61000004D8237A451114C40D1782288F3EC4A40
22384	7	61	130	31526	66673	\N	53.813413416676703	453152, РБ Стерлитамакский район, д. Подлесное, ул. Центральная, д. 32а		0101000020E6100000A4FE7A8505F74B401492CCEA1DE84A40
22366	7	61	130	58869	66709	\N	53.864877381146798	453147, РБ Стерлитамакский район, с. Октябрьское, ул. Мира, д. 8	Россия, республика Башкортостан, Стерлитамакский район, село отделение Октябрьское	0101000020E6100000E84B6F7F2EBA4B4003081F4AB4EE4A40
22339	7	61	130	29357	66930	\N	53.421537585576999	453142, РБ Стерлитамакский район, с. Новофедоровское, ул. Центральная, д. 20 б	Россия, республика Башкортостан, Стерлитамакский район, село Новофедоровское	0101000020E61000002D3E05C078DE4B40B8020AF5F4B54A40
22346	7	61	130	29652	66837	\N	53.703256000000003	453151, РБ Стерлитамакский район, с. Новое Барятино, ул.Дружбы, д. 25		0101000020E6100000FE277FF78EF44B409F5BE84A04DA4A40
22371	7	61	130	30909	66791	\N	53.593522	453140, РБ Стерлитамакский район,с. Новая Отрадовка, ул. Школьная, д.		0101000020E6100000C72C7B12D8F24B406FBA6587F8CB4A40
22341	7	61	130	29451	66778	\N	53.467986000000003	453142, РБ Стерлитамакский район, д. Новая Васильевка, ул. Цетральная, д.27		0101000020E610000038DA71C3EFEA4B40317E1AF7E6BB4A40
20961	7	61	130	30524	65655	\N	53.527957238012497	с. Николаевка, Нижняя, 91	Россия, республика Башкортостан, Стерлитамакский район, село Николаевка	0101000020E6100000454772F90FC94B40DE58501894C34A40
22358	7	61	130	30201	66612	\N	53.5234553138826	453167, РБ Стерлитамакский район,с. Наумовка, ул. Студенческая, д.3		0101000020E61000002AFD84B35BF54B40BEF6CC9200C34A40
22357	7	61	130	30201	66890	\N	53.519005260638799	453167, РБ Стерлитамакский район, с. Наумовка, ул. Ленина, д. 16	Россия, республика Башкортостан, Стерлитамакский район, село Наумовка	0101000020E6100000E1CE85915EF44B40F1BA7EC16EC24A40
22342	7	61	130	29475	66614	\N	53.394202999999997	453142, РБ Стерлитамакский район, с. Мурдашево, ул. Сухайлинская, д. 22 а		0101000020E6100000734C16F71FE74B40177E703E75B24A40
22381	7	61	130	31401	66747	\N	53.865594999999999	453164, РБ Стерлитамакский район, д. Матвеевка, ул. Полевая, д.3а	Россия, республика Башкортостан, Стерлитамакский район, село Матвеевка	0101000020E61000005BD07B6308C44B40624A24D1CBEE4A40
22373	7	61	130	31000	66836	\N	53.653019999999998	453140, РБ Стерлитамакский район,с. Мариинский, ул. Молодежная, 2 а		0101000020E61000007670B03731EC4B4024D1CB2896D34A40
22375	7	61	130	31000	66746	\N	53.653019999999998	453140, РБ Стерлитамакский район, с. Мариинский, ул. Лазурная,9		0101000020E61000007670B03731EC4B4024D1CB2896D34A40
22355	7	61	130	30096	66903	\N	53.603953977709502	453148, РБ Стерлитамакский район,д. Максимовка, ул. Молодежная, д.4,	Россия, республика Башкортостан, Стерлитамакский район, село Максимовка	0101000020E61000002EAA454431BD4B40EA245B5D4ECD4A40
22390	7	61	130	31816	66816	\N	53.680526999999998	453162, РБ Стерлитамакский район, д. Кучербаево, ул. Мира, д.87		0101000020E61000006D6FB72407D64B40C2853C821BD74A40
22379	7	61	130	58885	66921	\N	53.796392255218201	453164, РБ Стерлитамакский район, д. Кузьминовка, ул. Степная, д.12	Россия, республика Башкортостан, Аургазинский район, село Кузьминовка	0101000020E6100000DF1797AAB4C94B40E4654D2CF0E54A40
22349	7	61	130	29815	66866	\N	53.702030000000001	453153, РБ Стерлитамакский район, с. Косяковка, ул. Ленина, д. 91а		0101000020E610000085D0419770004C40CB67791EDCD94A40
22348	7	61	130	29761	66849	\N	53.764760000000003	453165, РБ Стерлитамакский район, д. Константиноградовка, ул. Мира, д. 41ж		0101000020E6100000CC24EA059FB04B40FDA4DAA7E3E14A40
22369	7	61	130	30807	66737	\N	53.558765845091102	453147, РБ Стерлитамакский район, д. Кононовский, ул. Трудовая, д.2		0101000020E6100000586FD40AD3D34B40F10EF0A485C74A40
22347	7	61	130	283	66724	\N	53.741341104519897	453151, РБ Стерлитамакский район, с. Кармаскалы, ул. Трудовая, д.2	Россия, республика Башкортостан, Стерлитамакский район, село Кармаскалы	0101000020E6100000C1745AB741EF4B408B170B43E4DE4A40
22363	7	61	130	30483	66819	\N	53.446475	453167, РБ Стерлитамакский район, д. Кантюковка. ул. Школьная, д. 1а		0101000020E6100000DD408177F2F74B40A5BDC11726B94A40
22385	7	61	130	31598	66674	\N	53.806834000000002	453152, РБ Стерлитамакский район, с. Ишпарсово, ул. Школьная, д. 17б		0101000020E6100000E76F422102FC4B4083A6255646E74A40
21043	7	61	58	10311	64048	\N	55.840871	с. Бураево, Пионерская, 5		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
22391	7	61	130	31850	9972	\N	53.420731000000004	453162, РБ Стерлитамакский район, д.Золотоношка, ул. Центральная, д.1з		0101000020E6100000A0C1A6CEA3C44B40EAB46E83DAB54A40
22360	7	61	130	58900	66968	\N	53.637183	453167, РБ Стерлитамакский район,  с. Заливной, ул. Клубная, д.6	Россия, республика Башкортостан, Стерлитамакский район	0101000020E6100000732B84D558DE4B40994869368FD14A40
22372	7	61	130	58884	66919	\N	53.600746602533903	453140, РБ Стерлитамакский район,с. Загородный, ул. Фестивальная, д.7 е	Россия, республика Башкортостан, Стерлитамакский район	0101000020E6100000F19D98F562F04B40C6151747E5CC4A40
22335	7	61	130	29165	66897	\N	53.717208999999997	453154, РБ Стерлитамакский район,с. Забельское, ул. Советская, д. 2 б		0101000020E6100000ED10FFB0A5114C40CCB22781CDDB4A40
22376	7	61	130	31129	66661	\N	53.841805999999998	453164, РБ Стерлитамакский район, с. Дергачевка, ул. Дружбы, д.5		0101000020E6100000C9C9C4AD82C24B40CDC98B4CC0EB4A40
22071	7	61	130	58824	66529	\N	53.723937509208	Республика Башкортостан, Мелеузовский район, Абитовский сельсовет, д. Восточный, Парковая, 13	Россия, республика Башкортостан, Стерлитамакский район, село Восточный	0101000020E6100000102219726CF74B40732A1900AADC4A40
22370	7	61	130	30840	66760	\N	53.557534128997403	453147, РБ Стерлитамакский район, ,д. Веселый, ул. Луговая, д. 20 а	Россия, республика Башкортостан, Стерлитамакский район, село Веселый	0101000020E6100000DF89592F86E44B403B342C465DC74A40
22393	7	61	130	31957	66787	\N	53.723640000000003	453162, РБ Стерлитамакский район,с.Верхние Услы, ул. 40 лет Победы 13/		0101000020E6100000A4FACE2F4ACC4B40EA094B3CA0DC4A40
22343	7	61	130	29535	66745	\N	53.717618999999999	453161, РБ Стерлитамакский район, с. Буриказганово, ул. Советская, д.64		0101000020E610000065A54929E8E44B407EFE7BF0DADB4A40
22354	7	61	130	30048	66650	\N	53.658239000000002	453148, РБ Стерлитамакский район,д. Бугуруслановка, ул. Садовая, д. 36а		0101000020E6100000CA349A5C8CC54B40D3F9F02C41D44A40
22352	7	61	130	29933	66859	\N	53.805025999999998	453149, РБ Стерлитамакский район, с. Большой Куганак, ул. Ленина, д.2		0101000020E6100000198C1189420B4C4000378B170BE74A40
22340	7	61	130	29376	66789	\N	53.435222000000003	453142, РБ Стерлитамакский район, с. Аючево, ул. Янаульская, д.47а		0101000020E6100000632827DA55E44B40F73FC05AB5B74A40
22356	7	61	130	30133	66792	\N	53.636820373008099	453148, РБ Стерлитамакский район,д. Алга, ул. Дружбы, д. 34	Россия, республика Башкортостан, Стерлитамакский район, село Алга	0101000020E61000001399B9C0E5B14B4028B8585183D14A40
22333	7	61	130	29097	66624	\N	53.485135	453142, РБ Стерлитамакский район,с. Айгулево, ул. Центральная, д. 31 а		0101000020E6100000D4B5F63E55E74B408E9257E718BE4A40
20127	7	61	7457	58092	64062	\N	53.648154654693897	Республика Башкортостан, город Стерлитамак, Садовая, 20	Россия, республика Башкортостан, Стерлитамак городской округ	0101000020E6100000312592E865F64B4094DE37BEF6D24A40
22302	7	61	368	27667	64385	\N	53.330252000000002	Республика Башкортостан, Стерлибашевский район, Яшергановский сельсовет, с.Яшерганово, Р.Кашапова, 92		0101000020E6100000EA043411366C4B4024B891B245AA4A40
22331	7	61	368	29015	65602	\N	53.56476	Республика Башкортостан, Стерлибашевский район, Янгурчинский сельсовет, с.Янгурча, Советская, 19А		0101000020E6100000705B5B785E964B40630B410E4AC84A40
22326	7	61	368	1884	66615	\N	53.549393000000002	Стерлибашевский район, 453172. РБ, д.Юмагузино,ул. Лесная, 2		0101000020E61000008081204086A64B405FD3838252C64A40
22306	7	61	368	27855	65587	\N	53.375540000000001	Республика Башкортостан, Стерлибашевский район, Халикеевский сельсовет, с.Халикеево, Центральная, 4		0101000020E6100000C18F6AD8EF9F4B40802BD9B111B04A40
22305	7	61	368	27838	66150	\N	53.315713000000002	Республика Башкортостан, Стерлибашевский район, Бузатовский сельсовет, д.Учуган-Асаново, Школьная, 7		0101000020E6100000A5BBEB6CC84D4B4006F6984869A84A40
22299	7	61	368	27540	64408	\N	53.339193999999999	Республика Башкортостан, Стерлибашевский район, Тятер-Араслановский сельсовет, с.Тятер-Арасланово, К.Маркса, 102Б		0101000020E6100000007157AF22794B40ED7F80B56AAB4A40
22329	7	61	368	28932	65593	\N	53.522129757832801	Республика Башкортостан, Стерлибашевский район, Янгурчинский сельсовет, с.Турмаево, Школьная, 4	Россия, республика Башкортостан, Стерлибашевский район, село Турмаево	0101000020E610000027DE019EB49A4B405721E527D5C24A40
22320	7	61	368	27759	63703	\N	53.438682	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, с.Стерлибашево, Школьная, 1А		0101000020E610000051A3906456A14B4004AC55BB26B84A40
22304	7	61	368	27759	63309	\N	53.438682	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, с.Стерлибашево, Комсомольская, 13		0101000020E610000051A3906456A14B4004AC55BB26B84A40
22318	7	61	368	27759	63310	\N	53.438682	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, с.Стерлибашево, К.Маркса, 70		0101000020E610000051A3906456A14B4004AC55BB26B84A40
22319	7	61	368	27759	63713	\N	53.438682	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, с.Стерлибашево, К.Маркса, 107		0101000020E610000051A3906456A14B4004AC55BB26B84A40
22162	7	61	368	58741	66297	\N	53.255743035658	д. Раевка, Ворошилова, 12	Россия, республика Башкортостан, Стерлибашевский район, село Раевка	0101000020E6100000CFF57D3848B64B402997C62FBCA04A40
22247	7	61	368	48648	65375	\N	53.459268999999999	д.Первомайск, Центральная,Здание дома культуры		0101000020E610000001FA7DFFE6A54B4087889B53C9BA4A40
22328	7	61	368	28878	66159	\N	53.481808000000001	Республика Башкортостан, Стерлибашевский район, Старокалкашевский сельсовет, д.Новый Калкаш, Центральная, 1		0101000020E6100000B0045262D7B84B40C07971E2ABBD4A40
22285	7	61	787	16791	66038	\N	55.097914000000003	с.Первомайский, Советская, 11	Россия, республика Башкортостан, Салаватский район, поселок Первомайский	0101000020E610000072E14048165C4D4008E92972888C4B40
22310	7	61	368	58280	64575	\N	53.220379351153198	Республика Башкортостан, Стерлибашевский район, Аллагуватский сельсовет, д.Нижний Аллагуват, Молодежная, 2	Россия, республика Башкортостан, Стерлибашевский район, село Нижный Аллагуват	0101000020E6100000068200193AC44B40D3DC0A61359C4A40
22301	7	61	368	27655	9740	\N	53.297375126326699	Республика Башкортостан, Стерлибашевский район, Яшергановский сельсовет, д.Нижнеибраево, Центральная, 28А	Россия, республика Башкортостан, Стерлибашевский район, село Нижнеибраево	0101000020E61000001DE4F560526A4B40F2D24D6210A64A40
22324	7	61	368	28659	66162	\N	53.502710999999998	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, д.Муртаза, Школьная, 2		0101000020E610000049D74CBED9A24B40732B84D558C04A40
22314	7	61	368	28202	65595	\N	53.269285000000004	Республика Башкортостан, Стерлибашевский район, Кундрякский сельсовет, с.Кундряк, Советская, 10		0101000020E61000001669E21DE0B74B40D5264EEE77A24A40
22325	7	61	368	28731	64057	\N	53.583623000000003	Республика Башкортостан, Стерлибашевский район, Куганакбашевский сельсовет, с.Куганакбаш, Школьная, 5		0101000020E6100000EAB0C22D1FAF4B40C2189128B4CA4A40
22308	7	61	368	27975	64207	\N	53.295498000000002	Республика Башкортостан, Стерлибашевский район, Карагушский сельсовет, с.Карагуш, Саубанова, 1		0101000020E6100000D594641D8EA24B404704E3E0D2A54A40
22309	7	61	368	27995	64118	\N	53.267480755578902	Республика Башкортостан, Стерлибашевский район, Кабакушский сельсовет, с.Кабакуш, Центральная, 34/5	Россия, республика Башкортостан, Стерлибашевский район, село Кабакуш	0101000020E6100000E97FB9162DAC4B4093A641D13CA24A40
22322	7	61	368	28565	66270	\N	53.470033000000001	Республика Башкортостан, Стерлибашевский район, Стерлибашевский сельсовет, д.Ибракаево, Ленина, 28		0101000020E61000004834812216AD4B403885950A2ABC4A40
22311	7	61	368	24885	65346	\N	53.354337000000001	Республика Башкортостан, Стерлибашевский район, Сарайсинский сельсовет, с.Елимбетово, Парковая, 3		0101000020E6100000211FF46C56D14B40A26131EA5AAD4A40
20264	7	61	368	24885	65672	\N	53.354337000000001	д.Елимбетово, ул.Коммунистическая, 27		0101000020E6100000211FF46C56D14B40A26131EA5AAD4A40
22332	7	61	368	29026	66169	\N	53.548878999999999	Республика Башкортостан, Стерлибашевский район, Янгурчинский сельсовет, д.Верхний Гулюм, Центральная, 13А		0101000020E6100000AB3FC230608F4B40083BC5AA41C64A40
22313	7	61	368	28180	66151	\N	53.290939000000002	Республика Башкортостан, Стерлибашевский район, Сарайсинский сельсовет, д.Верхнешакарово, Заки Валиди, 4		0101000020E61000006D01A1F5F0C14B40C310397D3DA54A40
22362	7	61	368	46426	66652	\N	53.454974999999997	453167, РБ Стерлитамакский район, с. Васильевка, ул. Оренбургский тракт, д. 60 а		0101000020E6100000CB9E0436E78E4B40B1BFEC9E3CBA4A40
22303	7	61	368	27753	64098	\N	53.305663000000003	Республика Башкортостан, Стерлибашевский район, Бузатовский сельсовет, с.Бузат, Ленина, 102А		0101000020E610000032923D42CD584B40734C16F71FA74A40
22316	7	61	368	28313	64035	\N	53.3547389297728	Республика Башкортостан, Стерлибашевский район, Бакеевский сельсовет, с.Бакеево, Советская, 1	Россия, республика Башкортостан, Стерлибашевский район, село Бакеево	0101000020E61000004EB4AB90F2AD4B40D1CE691668AD4A40
21019	7	61	368	27921	65419	\N	53.341882683018198	с. Амирово, Российская, 1а	Россия, республика Башкортостан, Стерлибашевский район, село Амирово	0101000020E610000073F38DE89E994B40790778D2C2AB4A40
22307	7	61	368	27921	66584	\N	53.34178	Стерлибашевский район, 453187. РБ, с. Амирово, ул. Акчишма, 40		0101000020E61000003E3E213B6F994B40A4367172BFAB4A40
22298	7	61	368	27505	64302	\N	53.381771000000001	Республика Башкортостан, Стерлибашевский район, Айдаралинский сельсовет, с.Айдарали, Молодежная, 45		0101000020E6100000D13C80457E834B40D6C743DFDDB04A40
20093	7	61	7458	58130	63782	\N	52.719170429524702	Республика Башкортостан, город Сибай, проспект Горняков, дом 8	Россия, республика Башкортостан, Сибай городской округ	0101000020E6100000D0ECBAB722554D40D52137C30D5C4A40
22297	7	61	787	58375	64852	\N	55.301337054274001	с.Янгантау, Школьная, 1	Россия, республика Башкортостан, Салаватский район	0101000020E6100000BEF90D130D104D409109F83592A64B40
22269	7	61	787	26170	65183	\N	55.272995000000002	д.Язги-Юрт, Школьная, 10		0101000020E6100000DA1CE736E12E4D405B7C0A80F1A24B40
22259	7	61	787	58755	66366	\N	55.129335266949703	д.Юлаево, Школьная, 2	Россия, республика Башкортостан, Салаватский район, село Юлаево	0101000020E610000047718E3A3A004D40349D9D0C8E904B40
22280	7	61	787	58622	65758	\N	55.4499061303598	с.Шарипово, Парт Мурзы, 51	Россия, республика Башкортостан, Салаватский район, село Шарипово	0101000020E61000004DBD6E1118174D401823128596B94B40
22296	7	61	787	58683	66008	\N	55.2931284425973	д.Чулпан, Коммунаров, 12	Россия, республика Башкортостан, Салаватский район, село Чулпан	0101000020E6100000AAF3A8F8BF0D4D405DC5E23785A54B40
22268	7	61	787	49014	65177	\N	55.212051000000002	д.Чебаркуль, Центральная, 40А		0101000020E610000012D89C8367364D40C40AB77C249B4B40
22271	7	61	787	26252	65757	\N	55.144855	д.Урманчино, Школьная, 2А		0101000020E6100000FDF9B660A9424D40BFD4CF9B8A924B40
22291	7	61	787	27168	64127	\N	55.471958999999998	с.Урмантау, Центральная, 27		0101000020E6100000D576137CD3DA4C40C4060B2769BC4B40
22294	7	61	787	27288	64258	\N	55.333477000000002	с.Турналы, Центральная, 35		0101000020E6100000C504357C0B214D40EE7BD45FAFAA4B40
22292	7	61	787	27214	64514	\N	55.077348786623801	с.Терменево, Школьная, 1	Россия, республика Башкортостан, Салаватский район, село Терменево	0101000020E6100000C0B2D2A414524D406CB07092E6894B40
22290	7	61	787	27132	66682	\N	55.470162999999999	Салаватский район, с.Таймеево, Молодежная,4		0101000020E6100000D542C9E4D4EC4C4006651A4D2EBC4B40
22279	7	61	787	26618	65981	\N	55.406564000000003	д.Саргамыш, Центральная, 28		0101000020E6100000B03C484F910D4D4090DD054A0AB44B40
22258	7	61	787	25658	65171	\N	55.136653000000003	д.Новые Каратавлы, Переулок Пришкольный, 1		0101000020E610000024ED461FF3114D403DF372D87D914B40
22284	7	61	787	26859	64274	\N	55.168697966490697	с.Насибаш, Центральная, 28	Россия, республика Башкортостан, Салаватский район, село Насибаш	0101000020E610000062C092AB582A4D40477364E597954B40
22283	7	61	787	26799	62324	\N	55.038314999999997	с.Мурсалимкино, Пепеляева, 3		0101000020E61000004FE78A5242484D401EF98381E7844B40
22265	7	61	787	26003	65178	\N	54.940918000000003	д.Миндишево, Школьная, 1		0101000020E610000062D9CC21A9FD4C40DF1B430070784B40
22278	7	61	787	26576	65578	\N	55.422660999999998	с.Мещегарово, Ленина, 10		0101000020E61000005072874D641A4D40B72572C119B64B40
22288	7	61	787	27009	63443	\N	55.184309059580102	с.Малояз, Коммунистическая, 47	Россия, республика Башкортостан, Салаватский район, село Малояз	0101000020E61000000DFCA886FD144D40E2ADF36F97974B40
22287	7	61	787	27009	63443	\N	55.181018439615798	с.Малояз, Коммунистическая, 63	Россия, республика Башкортостан, Салаватский район, село Малояз	0101000020E6100000390A100533144D4061FE0A992B974B40
22270	7	61	787	26191	64509	\N	55.194876000000001	с.Лаклы, Советская, 6		0101000020E61000007C0F971C77464D403D635FB2F1984B40
22267	7	61	787	26094	64387	\N	55.262633999999998	с.Лагерево, Айская, 69		0101000020E61000004A79AD84EE384D40A968ACFD9DA14B40
22263	7	61	787	25906	65561	\N	55.397157999999997	д.Куселярово, Центральная, 16		0101000020E61000009AB33EE598F04C4021ACC612D6B24B40
21002	7	61	787	5566	65530	\N	55.274912999999998	с.Комсомол, Школьная, 1а		0101000020E6100000FACF9A1F7F114D40641F645930A34B40
22282	7	61	787	26783	64792	\N	55.033248999999998	д.Карагулово, Центральная, 51	Россия, республика Башкортостан, Салаватский район, село Карагулово	0101000020E6100000535DC0CB0C3F4D40F6CFD38041844B40
22264	7	61	787	25945	64674	\N	54.935762312617797	с.Ишимбаево, Молодежная, 6	Россия, республика Башкортостан, Салаватский район, село Ишимбаево	0101000020E61000001766A19DD3024D40766B990CC7774B40
22295	7	61	787	27360	64614	\N	55.266978999999999	д.Ильтаево, Школьная, 36	Россия, республика Башкортостан, Салаватский район, село Ильтаево	0101000020E6100000DBDD03745F124D4001DC2C5E2CA24B40
20490	7	61	787	58836	66557	\N	55.055095334152497	Республика Башкортостан, Баймакский район, д.В.Идрисово, улица Молодежная, дом 12/1	Россия, республика Башкортостан, Салаватский район, село Идрисово	0101000020E6100000DD611399B9104D4029965B5A0D874B40
22289	7	61	787	58810	66507	\N	55.4126773628726	д.2-еИдельбаево, Центральная, 1	Россия, республика Башкортостан, Салаватский район, село Идельбаево 2-е	0101000020E61000006A87BF266BEA4C40DC679599D2B44B40
22277	7	61	787	6362	65991	\N	55.387417999999997	с.Еланыш, Центральная, 54	Россия, республика Башкортостан, Салаватский район, село Еланыш	0101000020E6100000207C28D1921D4D40DCF0BBE996B14B40
21712	7	61	787	30905	65792	\N	55.374885533465402	д.Бияз, Школьная, 10	Россия, республика Башкортостан, Салаватский район, село Бияз	0101000020E6100000ADA415DF50CC4C4037DDB243FCAF4B40
22262	7	61	787	25848	64673	\N	55.380028000000003	д.Бешевлярово, Школьная, 9		0101000020E6100000EDF1423A3CFA4C403BC8EBC1A4B04B40
22274	7	61	787	58550	65476	\N	55.323162000000004	д.Ахуново, Центральная, 15	Россия, республика Башкортостан, Салаватский район, село Ахуново	0101000020E6100000B79A75C6F7074D40ADA7565F5DA94B40
22261	7	61	787	25815	63668	\N	55.399616999999999	с.Аркаулово, Салавата Юлаева, 7		0101000020E61000004F04711E4EF64C407BF65CA626B34B40
22256	7	61	787	48807	64741	\N	55.087955000000001	с.Алькино, Кольцевая, 6		0101000020E61000002F6D382C0D0A4D408542041C428B4B40
22293	7	61	787	58753	66362	\N	55.388562093645703	д.Айская, Школьная, 2	Россия, республика Башкортостан, Салаватский район, село Айская	0101000020E6100000A94A5B5CE32F4D40F33B4D66BCB14B40
22251	7	61	944	25335	65584	\N	55.412837295283097	д.Яман Порт, Садовая,Здание дома культуры	Россия, республика Башкортостан, Нуримановский район, село Яман-Порт	0101000020E61000005FD04202464F4C4015CAC2D7D7B44B40
22225	7	61	944	24118	66598	\N	55.031314000000002	Нуримановский район, д. Укарлино, ул.Центральная,32		0101000020E61000003A90F5D4EA3D4C4017F4DE1802844B40
22231	7	61	944	24413	65499	\N	55.126524000000003	с.Старокулево, Колхозная, 12		0101000020E6100000D316D7F84C524C405E143DF031904B40
22232	7	61	944	24465	66622	\N	55.104557999999997	Нуримановский район, д. Староисаево, ул.Центральная,62		0101000020E6100000AE0E80B8AB554C4080441328628D4B40
22242	7	61	944	24936	65555	\N	55.252958	д.Старобирючево, Береговая, 34		0101000020E6100000C6DE8B2FDA4B4C407BA180ED60A04B40
22230	7	61	944	24335	65548	\N	55.028573999999999	д.Сатлык, Центральная, 24		0101000020E61000002BBF0CC6885C4C4009C21550A8834B40
22246	7	61	944	25095	64582	\N	55.237032999999997	д.Сарва, Школьная, 4\\1		0101000020E61000007B336ABE4A864C405089EB18579E4B40
22255	7	61	944	32552	64735	\N	55.419555000000003	с.Павловка, Строителей, 1	Россия, республика Башкортостан, Нуримановский район, поселок Павловка	0101000020E6100000DC9BDF30D1464C40C8EF6DFAB3B54B40
22253	7	61	944	32552	64074	\N	55.419555000000003	с.Павловка, Карла Маркса, 31		0101000020E6100000DC9BDF30D1464C40C8EF6DFAB3B54B40
22244	7	61	944	25017	65551	\N	55.144345999999999	с.Новый Субай, Лесная, 1		0101000020E6100000B0FF3A376D804C407AA702EE79924B40
22229	7	61	944	24311	63767	\N	55.082265999999997	с.Новокулево, Советская, 76		0101000020E61000008C101E6D1C4F4C404FC939B1878A4B40
22240	7	61	944	24825	66706	\N	55.241169999999997	Нуримановский район, д. Новобирючево, ул. Центральная,10		0101000020E610000054C6BFCFB8504C405E6397A8DE9E4B40
22227	7	61	944	24205	66882	\N	55.060941954571597	Нуримановский район, с. Нимислярово, ул.Насретдинова,55	Россия, республика Башкортостан, Нуримановский район, село Нимислярово	0101000020E610000011AAD4EC81484C40F6798CF2CC874B40
22243	7	61	944	24961	66736	\N	55.187291000000002	Нуримановский район, с. Никольское, ул.Центральная,87		0101000020E6100000D3DA34B6D7664C40E6EAC726F9974B40
22228	7	61	944	24232	65319	\N	55.007007999999999	д.Кызыл Баржау, Родниковая, 3а		0101000020E6100000616F62484E4A4C40BA675DA3E5804B40
22223	7	61	944	23987	66847	\N	54.978476999999998	Нуримановский район, д. Кушкулево,ул. Парковая,19		0101000020E6100000016BD5AE094D4C40B071FDBB3E7D4B40
22249	7	61	944	32533	64490	\N	55.384186	с.Красный Ключ, Матросова, 35		0101000020E6100000D4997B48F8524C4060CAC0012DB14B40
22238	7	61	944	24654	64406	\N	55.197127000000002	с.Красная Горка, Тукаева, 1	Россия, республика Башкортостан, Нуримановский район, село Красная Горка	0101000020E6100000E1B37570B0554C404D1421753B994B40
22237	7	61	944	24654	64615	\N	55.197127000000002	с.Красная Горка, Советская, 87	Россия, республика Башкортостан, Нуримановский район, село Красная Горка	0101000020E6100000E1B37570B0554C404D1421753B994B40
22236	7	61	944	24654	64615	\N	55.197127000000002	Нуримановский район, с. Красная Горка,ул. Советская,56		0101000020E6100000E1B37570B0554C404D1421753B994B40
22239	7	61	944	24654	64242	\N	55.197127000000002	с.Красная Горка, Альмухаметова, 1		0101000020E6100000E1B37570B0554C404D1421753B994B40
22155	7	61	944	46898	66227	\N	55.004322999999999	д. Каргино, Интернациональная, 40		0101000020E6100000A1F7C61000384C4070CFF3A78D804B40
22233	7	61	944	24486	66800	\N	55.075885999999997	Нуримановский район, д. Ишмуратово, ул. Центральная,32		0101000020E61000005A492BBEA1684C40B41CE8A1B6894B40
22226	7	61	944	24126	66779	\N	55.050437747178997	Нуримановский район, д. Истриково, ул. Мубарякова,15	Россия, республика Башкортостан, Нуримановский район, село Истриково	0101000020E61000008274B169A53E4C40E23C9CC074864B40
22235	7	61	944	24592	65547	\N	55.158651999999996	д.Большие Шиды, Школьная, Здание школы		0101000020E610000006DA1D520C604C40F5B86FB54E944B40
22224	7	61	944	24062	66704	\N	55.005417999999999	Нуримановский район, д. Большетенькашево,ул. Свободы,3		0101000020E6100000844A5CC7B8404C40A5677A89B1804B40
22222	7	61	944	23949	66944	\N	54.988804000000002	Нуримановский район, д. Бикмурзино,ул. Школьная,20		0101000020E61000001FA2D11DC4384C40B6132521917E4B40
22234	7	61	944	24560	65514	\N	55.145251000000002	д.Баш-Шиды, Советская, 1		0101000020E6100000FB230C03965C4C400C5BB39597924B40
22221	7	61	944	23901	66148	\N	54.980575000000002	Республика Башкортостан, Нуримановский район, Байгильдинский сельсовет,с.Байгильдино, Садовая, 20/2		0101000020E61000007444BE4BA9414C403A234A7B837D4B40
21708	7	61	944	30681	66273	\N	55.574772000000003	с.Атняш, ул.Коммунистическая, 1		0101000020E6100000CE8DE9094B9C4C400954FF2092C94B40
22188	7	61	271	22391	66138	\N	53.440635	село Шатмантамак, улица Шоссейная, дом 26		0101000020E61000008192020B60484B408A3C49BA66B84A40
22174	7	61	271	21741	64809	\N	53.810859000000001	деревня Чятай-Бурзян, улица Центральная, дом 28/2		0101000020E6100000AD4B8DD0CF6A4B4069554B3ACAE74A40
22219	7	61	271	23805	64215	\N	53.628261000000002	село Уршакбашкарамалы, улица Ленина, дом 58		0101000020E610000022C495B377924B40172D40DB6AD04A40
22220	7	61	271	23828	65444	\N	53.640338	село Уршак, улица Ленина, дом 35		0101000020E6100000E7A7380EBC9C4B406A317898F6D14A40
22194	7	61	271	22684	65035	\N	53.728593060109397	деревня Софиевка, улица Полевая, дом 9	Россия, республика Башкортостан, Миякинский район, село Софиевка	0101000020E61000009357E718908F4B40198C118942DD4A40
22185	7	61	271	47503	65494	\N	53.561385999999999	деревня Сафарово, улица Первомайская, дом 16		0101000020E6100000B2F2CB608C3A4B405437177FDBC74A40
22216	7	61	271	23673	65099	\N	53.504505000000002	село Сатыево, улица Центральная, дом 19		0101000020E6100000C1C93670075E4B4091D5AD9E93C04A40
22215	7	61	271	58802	66491	\N	53.679719919931102	деревня Суккул-Михайловка, улица Садовая, дом 11 а	Россия, республика Башкортостан, Миякинский район, село Саккул-Михайловка	0101000020E6100000C5707500C45F4B40F437A11001D74A40
22204	7	61	271	58340	64765	\N	53.595286811450499	село Родниковка, улица Молодежная, дом 14		0101000020E61000004DA3C9C518684B40F25D4A5D32CC4A40
22213	7	61	271	48008	65549	\N	53.691490999999999	деревня Новый Мир, улица Молодежная, дом 7	Россия, республика Башкортостан, Миякинский район, село Новый Мир	0101000020E610000004C6FA0626874B403A3DEFC682D84A40
22217	7	61	271	23728	66255	\N	53.547044	деревня Новые Омельники, улица Шевченко, дом 7		0101000020E6100000BE874B8E3B5B4B408CBCAC8905C64A40
22214	7	61	271	58565	65560	\N	53.655912999999998	село Новые Карамалы, улица Центральная, дом 57 а		0101000020E6100000335184D4ED5A4B40B8020AF5F4D34A40
22196	7	61	271	22751	66136	\N	53.489502000000002	село Новые Ишлы, улица Центральная, дом 12		0101000020E6100000DD4598A25C6C4B40CEA96400A8BE4A40
22190	7	61	271	22478	65025	\N	53.848537	село Нарыстау, улица Мира, дом 52		0101000020E6100000EA3C2AFEEF844B40153944DC9CEC4A40
22200	7	61	271	22925	64256	\N	53.783028000000002	село Миякитамак, улица Коммунистическая, дом 66		0101000020E61000002BDA1CE7365F4B4018EDF1423AE44A40
22201	7	61	271	22958	64036	\N	53.704577999999998	село Менеузтамак, улица Шоссейная, дом 7/1		0101000020E6100000BDC804FC1A434B4094BDA59C2FDA4A40
22182	7	61	271	22134	65030	\N	53.513517473777199	село Малые Каркалы, улица Первомайская, дом 1	Россия, республика Башкортостан, Миякинский район, село Малые Каркалы	0101000020E61000008527F4FA937A4B405378D0ECBAC14A40
22205	7	61	271	23170	66147	\N	53.552864999999997	село Курманайбаш, улица Королева, дом 4		0101000020E6100000884B8E3BA56B4B40300DC347C4C64A40
22192	7	61	271	22560	66141	\N	53.797969999999999	село Куль-Кункас, улица Демская, дом 47		0101000020E610000077483140A2774B40359886E123E64A40
22179	7	61	271	21990	66294	\N	53.556561000000002	деревня Култай-Каран, улица Матросова, дом 43 Б		0101000020E6100000764F1E166A3F4B40529D0E643DC74A40
22195	7	61	271	58281	64578	\N	53.466689348866097	село Качеганово, улица Шоссейная, дом 18	Россия, республика Башкортостан, Миякинский район, село Кочеганово	0101000020E61000004014CC98826F4B4094331477BCBB4A40
22193	7	61	271	58562	65534	\N	53.743619000000002	деревня Комсомольский, улица Центральная, дом 1	Россия, республика Башкортостан, Миякинский район, село Комсомольский	0101000020E61000009CE1067C7E824B4095D74AE82EDF4A40
22198	7	61	271	22822	64465	\N	53.739539999999998	село Кожай-Семеновка, улица Советская, дом 62		0101000020E6100000B05582C5E15A4B40BB0A293FA9DE4A40
22208	7	61	271	23213	64113	\N	53.634278999999999	село Киргиз-Мияки, улица Шоссейная, дом 2		0101000020E6100000B5C2F4BD86664B4011C5E40D30D14A40
22210	7	61	271	23213	64037	\N	53.634278999999999	село Киргиз-Мияки, улица Советская, дом 12		0101000020E6100000B5C2F4BD86664B4011C5E40D30D14A40
22207	7	61	271	23213	63418	\N	53.634278999999999	село Киргиз-Мияки, улица Ленина, дом 28		0101000020E6100000B5C2F4BD86664B4011C5E40D30D14A40
22211	7	61	271	23213	64033	\N	53.634278999999999	село Киргиз-Мияки, улица Калинина, дом 29		0101000020E6100000B5C2F4BD86664B4011C5E40D30D14A40
22206	7	61	271	23213	63822	\N	53.634278999999999	село Киргиз-Мияки, улица Губайдуллина, дом 130		0101000020E6100000B5C2F4BD86664B4011C5E40D30D14A40
22209	7	61	271	23213	64243	\N	53.634278999999999	село Киргиз-Мияки, улица Абдуллина, дом 2		0101000020E6100000B5C2F4BD86664B4011C5E40D30D14A40
22199	7	61	271	22888	65472	\N	53.715710999999999	село Кекен-Васильевка, улица Советская, дом 40		0101000020E610000049145AD6FD5B4B409831056B9CDB4A40
22191	7	61	271	22545	65442	\N	53.768160999999999	село Каран-Кункас, улица Школьная, дом 2		0101000020E6100000E0BC38F1D5764B400588821953E24A40
22178	7	61	271	21939	65166	\N	53.663483999999997	село Канбеково, улица Советская, дом 49/1		0101000020E6100000051A6CEA3C4A4B40AAB5300BEDD44A40
22187	7	61	271	22345	65948	\N	53.440527590112403	деревня Исламгулово, улица Ш.Бабича, дом 9	Россия, республика Башкортостан, Миякинский район, село Исламгулово	0101000020E6100000B477465B953C4B40747CB43863B84A40
22189	7	61	271	22423	65929	\N	53.823079999999997	село Ильчигулово, улица Советская, дом 15		0101000020E6100000D595CFF23C804B40EFFE78AF5AE94A40
22186	7	61	271	22311	64523	\N	53.428972999999999	село Зильдярово, улица Дружбы, дом 14		0101000020E61000002AA913D044504B40FAEE5696E8B64A40
22203	7	61	271	1139	66863	\N	53.613681	452080, РБ, Миякинский район  с. Ерлыково, ул. Центральная 28		0101000020E610000070EB6E9EEA6A4B409A9658198DCE4A40
22184	7	61	271	22221	65101	\N	53.623652999999997	село Енебей-Урсаево, улица Центральная, дом 4 А		0101000020E610000022FAB5F5D3414B40B1868BDCD3CF4A40
21431	7	61	271	46164	65293	\N	53.552415000000003	д.Воскресенка, ул.Молодежная, 28		0101000020E610000099840B7904774B40F168E388B5C64A40
22181	7	61	271	22092	65925	\N	53.500332999999998	село Большие Каркалы, улица Советская, дом 12		0101000020E610000037FB03E5B6814B40060E68E90AC04A40
22177	7	61	271	47711	65062	\N	53.622008000000001	село Богданово, улица Ленина, дом 39	Россия, республика Башкортостан, Миякинский район, село Богданово	0101000020E61000009F1EDB32E0464B40D9EC48F59DCF4A40
22175	7	61	271	45714	65307	\N	53.743723179207898	село Биккулово, улица Школьная, дом 1	Россия, республика Башкортостан, Миякинский район, село Биккулово	0101000020E6100000257497C459714B403A24B55032DF4A40
22218	7	61	271	58620	65749	\N	53.454556974870499	село Баязитово, улица Мира, дом 28	Россия, республика Башкортостан, Миякинский район, село Баязитово	0101000020E6100000DA5548F949614B407D957CEC2EBA4A40
22212	7	61	271	58284	64586	\N	53.604949334002399	село Анясево, улица Центральная, дом 14	Россия, республика Башкортостан, Миякинский район, село Миякибашево	0101000020E610000098689082A77C4B40BB5F05F86ECD4A40
22120	7	61	798	18898	65437	\N	55.412007000000003	д. Яндыганово, Ленина, 45		0101000020E6100000A67EDE54A4FC4B408E5C37A5BCB44B40
22119	7	61	798	18877	65028	\N	55.372385000000001	с. Янагушево, Клубная, 20	Россия, республика Башкортостан, Мишкинский район, село Янагушево	0101000020E6100000B0C7444AB3054C40AF42CA4FAAAF4B40
22164	7	61	798	58359	64814	\N	55.626730999999999	с. Чураево, Яныша Ялкайна, 35	Россия, республика Башкортостан, Мишкинский район, село Чураево	0101000020E6100000EFC7ED974FCA4B40D731AEB838D04B40
22163	7	61	798	58359	64821	\N	55.626730999999999	с. Чураево, Ленина, 28	Россия, республика Башкортостан, Мишкинский район, село Чураево	0101000020E6100000EFC7ED974FCA4B40D731AEB838D04B40
22117	7	61	798	18746	65024	\N	55.4238495142205	д.Урьяды, Фатхинурова, 22	Россия, республика Башкортостан, Мишкинский район, село Урьяды	0101000020E610000084807C0915084C406E3480B740B64B40
22144	7	61	798	20210	65923	\N	55.681468000000002	д. Укозяш, Лесная, 23		0101000020E6100000C233A14962114C40A1A2EA573AD74B40
22159	7	61	798	21040	66284	\N	55.601050000000001	д. Тынбаево, Школьная, 6		0101000020E61000002D78D15790BA4B4062A1D634EFCC4B40
22167	7	61	798	21416	64692	\N	55.679813000000003	д. Тигирменево, Шоссейная, 3		0101000020E6100000575C1C959BD44B40A532C51C04D74B40
22148	7	61	798	20447	65418	\N	55.711067	д. Терекеево, Чапаева, 19		0101000020E61000009B1DA9BEF3F54B40E621533E04DB4B40
22145	7	61	798	20240	66132	\N	55.633769999999998	с. Татарбаево, Саита Хамата, 20		0101000020E6100000A56ABB09BEFD4B40CC9717601FD14B40
22158	7	61	798	20984	65837	\N	55.618444088415998	д. Старокульчубаево, Чапаева, 16	Россия, республика Башкортостан, Мишкинский район, село Старокульчубаево	0101000020E6100000656EBE11DDC14B402634492C29CF4B40
22123	7	61	798	19060	65009	\N	55.513300000000001	д. Староваськино, Трактовая, 24-а		0101000020E6100000BC5B59A2B3FC4B40B6847CD0B3C14B40
22147	7	61	798	20373	65922	\N	55.694747999999997	д. Староатнагулово, Советская, 15		0101000020E6100000A9BF5E61C1FB4B400F7BA180EDD84B40
22140	7	61	798	19961	65031	\N	55.621923000000002	д. Староарзаматово, Яныша Ялкайна, 2		0101000020E610000005888219530C4C40ABD0402C9BCF4B40
22122	7	61	798	46186	65479	\N	55.482056	д. Староакбулатово, Трактовая, 41-а		0101000020E6100000745C8DEC4AFD4B40986BD102B4BD4B40
22156	7	61	798	46909	64664	\N	55.554695000000002	д. Сосновка, Школьная, 12		0101000020E61000005B7C0A80F1CA4B409B20EA3E00C74B40
22118	7	61	798	18804	65085	\N	55.410704000000003	д.Сабаево, Мичуринская, 1	Россия, республика Башкортостан, Мишкинский район, село Сабаево	0101000020E6100000CD8FBFB4A8054C400F2BDCF291B44B40
22165	7	61	798	5641	65943	\N	55.608328	д. Октябрь, Яныша Ялкайна, 44	Россия, республика Башкортостан, Мишкинский район, село Октябрь	0101000020E61000001497E31588D04B40DC9E20B1DDCD4B40
22134	7	61	798	19628	65937	\N	55.584823	д. Новоключево, Советская, 28-а		0101000020E6100000153C855CA9E34B406C79E57ADBCA4B40
22172	7	61	798	58865	66639	\N	55.650101989340897	д. Новокильметево, Тракторная, 10	Россия, республика Башкортостан, Мишкинский район, село Новокильметово	0101000020E61000006669A7E672C94B403788D68A36D34B40
22146	7	61	798	58825	66530	\N	55.6665413223187	д. Новокарачево, Школьная, 4		0101000020E6100000603DEE5BAD014C40B9382A3751D54B40
22124	7	61	798	19131	65023	\N	55.524121000000001	д. Нововаськино, Интернациональная, 42		0101000020E6100000F54883DBDA004C40CB129D6516C34B40
22136	7	61	798	19761	65601	\N	55.600414077730399	д. Нижнесорокино, Интернациональная, 12	Россия, республика Башкортостан, Мишкинский район, село Нижнесорокино	0101000020E6100000FD9FC37C79F94B40C007AF5DDACC4B40
22130	7	61	798	33060	\N	\N	55.534036	с. Мишкино, Северная, 30	Россия, республика Башкортостан, Мишкинский район, село Мишкино	0101000020E610000079B130444EFB4B407E71A94A5BC44B40
20637	7	61	798	33060	65366	\N	55.533941009000202	д. Мишкино, Центральная, 23	Россия, республика Башкортостан, Мишкинский район, село Мишкино	0101000020E6100000848252B472FB4B402C7FBE2D58C44B40
22131	7	61	798	33060	64454	\N	55.534036	с. Мишкино, Тракторная, 16		0101000020E610000079B130444EFB4B407E71A94A5BC44B40
22126	7	61	798	33060	64522	\N	55.534036	с. Мишкино, Мира, 46	Россия, республика Башкортостан, Мишкинский район, село Мишкино	0101000020E610000079B130444EFB4B407E71A94A5BC44B40
22128	7	61	798	33060	64009	\N	55.534036	с. Мишкино, Ленина, 73	Россия, республика Башкортостан, Мишкинский район, село Мишкино	0101000020E610000079B130444EFB4B407E71A94A5BC44B40
22127	7	61	798	33060	64009	\N	55.534036	с. Мишкино, Ленина, 106		0101000020E610000079B130444EFB4B407E71A94A5BC44B40
22125	7	61	798	33060	64009	\N	55.534036	с. Мишкино, Ленина, 143		0101000020E610000079B130444EFB4B407E71A94A5BC44B40
22129	7	61	798	33060	64136	\N	55.534036	с.Мишкино, Дружбы, 26		0101000020E610000079B130444EFB4B407E71A94A5BC44B40
22151	7	61	798	20619	64661	\N	55.605877	д. Малые Шады, Малошадинская, 38		0101000020E610000060066344A2E64B400533A6608DCD4B40
22141	7	61	798	58851	66583	\N	55.650058953775698	д. Малонакаряково, Школьная, 2	Россия, республика Башкортостан, Мишкинский район, село Малонакоряково	0101000020E6100000F4DC425722104C4038BC202235D34B40
22168	7	61	798	21448	66834	\N	55.705204000000002	452353, РБ Мишкинский район, д. Лепешкино, ул.Молодежная, 2	Россия, республика Башкортостан, Мишкинский район, село Лепешкино	0101000020E6100000282A1BD654D64B401381EA1F44DA4B40
22250	7	61	798	58170	64117	\N	55.4375957984984	с.Красный Ключ, Советская, 122	Россия, республика Башкортостан, Мишкинский район, село Красный Ключ	0101000020E6100000003620425C1B4C40226E4E2503B84B40
22132	7	61	798	19548	65438	\N	55.479734999999998	д. Кигазытамаково, Социалистическая, 1		0101000020E6100000731074B4AAEB4B408FDFDBF467BD4B40
21957	7	61	798	11033	64985	\N	55.469100448485499	с.Камеево, Орсаева, 18	Россия, республика Башкортостан, Мишкинский район, село Камеево	0101000020E6100000BF7FF3E2C40B4C40DC4603780BBC4B40
22115	7	61	798	11033	66124	\N	55.469197999999999	с. Камеево, Больничная, 13		0101000020E61000002497FF907E0B4C409FAC18AE0EBC4B40
22154	7	61	798	20774	65167	\N	55.552565999999999	д. Кайраково, Центральная, 31		0101000020E610000081B2295778DB4B40D670917BBAC64B40
22149	7	61	798	20510	65428	\N	55.650418999999999	д. Иштыбаево, Кирова, 2		0101000020E6100000882CD2C43BF24B4038D906EE40D34B40
22169	7	61	798	47180	64663	\N	55.747024000000003	д. Ишимово, Ишкинина, 32		0101000020E6100000D4B5F63E55D14B40DFA9807B9EDF4B40
22137	7	61	798	19792	66129	\N	55.567092000000002	д. Ирсаево, Социалистическая, 4		0101000020E61000000FD4298F6EFA4B4060E97C7896C84B40
22160	7	61	798	21075	65840	\N	55.601452000000002	д. Изимарино, Мичурина, 12		0101000020E6100000217711A628B34B40910E0F61FCCC4B40
22138	7	61	798	46546	66126	\N	55.602789999999999	д. Елышево, Трактовая, 24		0101000020E61000001BD5E940D6014C408C2D043928CD4B40
22135	7	61	798	19707	65917	\N	55.594957000000001	д. Верхнесорокино, Матросова, 1		0101000020E61000000F45813E91F34B405DC30C8D27CC4B40
22166	7	61	798	21354	66289	\N	55.646344999999997	д. Букленды, Советская, 16		0101000020E61000005CAFE94141D14B407077D66EBBD24B40
22150	7	61	798	20556	65160	\N	55.656174	д. Большие Шады, Больничная, 30		0101000020E6100000E7012CF2EBE74B40253E7782FDD34B40
22157	7	61	798	20944	64347	\N	55.569853907701003	д. Большесухоязово, Центральная, 30	Россия, республика Башкортостан, Мишкинский район, село Большесухоязово	0101000020E61000007FBC57AD4CC64B4055BFD2F9F0C84B40
22142	7	61	798	6889	66740	\N	55.691389000000001	452348, РБ Мишкинский район, д.Бирюбаш д.Мира, 24		0101000020E61000009E5E29CB101B4C4036E84B6F7FD84B40
22153	7	61	798	20731	64780	\N	55.518825999999997	д. Бикшиково, Трактовая, 3		0101000020E6100000ABB184B531D84B404128EFE368C24B40
22116	7	61	798	18710	65018	\N	55.405546999999999	д.Байтурово, Школьная, 7		0101000020E6100000245E9ECE151B4C40D6FECEF6E8B34B40
22114	7	61	798	46005	65492	\N	55.500264000000001	с. Бабаево, Школьная, 11	Россия, республика Башкортостан, Мишкинский район, село Бабаево	0101000020E6100000C57421567F104C40DEAE97A608C04B40
22260	7	61	237	58542	65597	\N	55.824304801600299	д.Юнусово, Юлаева, 1	Россия, республика Башкортостан, Мечетлинский район, село Юнусово	0101000020E61000002EC55565DF314D40F37684D382E94B40
22092	7	61	237	58542	65431	\N	55.824208168645001	д. Юнусово, Хаерзаманова, 1	Россия, республика Башкортостан, Мечетлинский район, село Юнусово	0101000020E610000006499F56D1314D40008DD2A57FE94B40
22086	7	61	237	17193	66131	\N	56.066986999999997	д. Такино, Мира, 57		0101000020E6100000A4E2FF8EA84C4D40EA20AF0793084C40
22093	7	61	237	17531	66155	\N	55.760261	д. Таишево, Горная, 4		0101000020E6100000DC291DACFF394D404EB6813B50E14B40
22579	7	61	237	45704	65516	\N	55.7994610683837	Сулейманово, Миасс, 15	Россия, республика Башкортостан, Мечетлинский район, село Сулейманово	0101000020E610000083312251682B4D40B7B6F0BC54E64B40
22099	7	61	237	45704	65490	\N	55.799557999999998	д. Сулейманово, Механизаторов, 2		0101000020E61000004A44F817412B4D40A9A0A2EA57E64B40
22112	7	61	237	58788	66468	\N	56.032114322555202	д. Степной, Советская, 5	Россия, республика Башкортостан, Мечетлинский район, село Степной	0101000020E61000003BA759A0DD0F4D4033DFC14F1C044C40
22098	7	61	237	17798	65420	\N	55.736198999999999	д. Старомещерово, Коммунистическая, 24а		0101000020E6100000FC6EBA6587344D40882CD2C43BDE4B40
22111	7	61	237	58860	66607	\N	56.089206195961097	д. Средняя Ока, Советская, 27	Россия, республика Башкортостан, Мечетлинский район	0101000020E6100000B1A206D3301E4D40B14D2A1A6B0B4C40
20528	7	61	237	58724	66513	\N	55.976365746150897	Республика Башкортостан, Баймакский район, д.Сосновка, улица Школьная, дом 17а	Россия, республика Башкортостан, Мечетлинский район, село Сосновка	0101000020E610000092205C01850C4D409276A38FF9FC4B40
22079	7	61	237	58544	65448	\N	55.917409033206901	д. Сальзигутово, Айская, 27	Россия, республика Башкортостан, Мечетлинский район, село Сальзигутово	0101000020E6100000276A696E851C4D402D077AA86DF54B40
22101	7	61	237	17920	65432	\N	55.877232999999997	д. Сабанаково, Молодежная, 4		0101000020E6100000E6965643E2204D4069FCC22B49F04B40
22095	7	61	237	17632	64236	\N	55.701227000000003	д. Новомещерово, Школьная, 40		0101000020E6100000FF59F3E32F334D403E096CCEC1D94B40
22076	7	61	237	16678	65021	\N	55.684237918193197	д. Тукбаево, Октябрьская, 26	Россия, республика Башкортостан, Мечетлинский район, село Нижние Тукбаево	0101000020E6100000A65EB7088C194D4019575C1C95D74B40
22084	7	61	237	17071	65433	\N	55.992114999999998	с. Нижнее Бобино, Солнечная, 2		0101000020E6100000EB71DF6A9D304D407E6FD39FFDFE4B40
22105	7	61	237	18135	65016	\N	55.927725000000002	д. Мелекасово, Революционная, 25		0101000020E6100000F46A80D250FD4C403F575BB1BFF64B40
22100	7	61	237	29945	66669	\N	55.829013195664203	Мечетлинский район, д. Лемез-Тамаково, ул. К. Маркса, 3	Россия, республика Башкортостан, Мечетлинский район, село Лемез-Тамак	0101000020E610000071E7C2482F224D40BC7A15191DEA4B40
22085	7	61	237	17149	65012	\N	56.141652999999998	д. Кургатово, Ленина, 115		0101000020E61000009EEA909BE1424D40AD307DAF21124C40
22109	7	61	237	58800	66488	\N	56.074972664089103	д. Ключевой, Первомайская, 14	Россия, республика Башкортостан, Мечетлинский район, село Ключевой	0101000020E610000071AC8BDB68084D40A08A1BB798094C40
22063	7	61	237	58444	65042	\N	55.639744999999998	д. Каранаево, Набережная, 26	Россия, республика Башкортостан, Мечетлинский район, село Каранаево	0101000020E610000039EE940ED6254D40C763062AE3D14B40
22088	7	61	237	5576	66884	\N	56.004548999999997	Мечетлинский район, д. Ишалино, ул. Пролетарская, 36		0101000020E610000010786000E1454D40601DC70F95004C40
22096	7	61	237	26539	66707	\N	55.695875000000001	Мечетлинский район, д. Еланышево, ул. Школьная, 2		0101000020E61000008693347F4C274D40508D976E12D94B40
21628	7	61	237	47236	66667	\N	55.657405308717699	с.Гумерово,ул.Центральная,32	Россия, республика Башкортостан, Мечетлинский район, село Гумерово	0101000020E6100000397B67B455294D400A9DD7D825D44B40
22103	7	61	237	18035	66490	\N	55.902119661057903	д. Буртаковка, Мостовая, 1	Россия, республика Башкортостан, Мечетлинский район, село Буртаковка	0101000020E6100000DAE55B1FD60D4D40A4880CAB78F34B40
21900	7	61	237	8327	64971	\N	55.675080476453999	д. Буранчино, Школьная, 5	Россия, республика Башкортостан, Мечетлинский район, село Буранчино	0101000020E6100000E6948098841F4D4083177D0569D64B40
22082	7	61	237	58146	63960	\N	55.934187068075097	с. Большеустьикинское, Ленина, 19	Россия, республика Башкортостан, Мечетлинский район	0101000020E610000064C91CCBBB244D4097AC8A7093F74B40
22107	7	61	237	18247	65435	\N	55.966090999999999	д. Большекызылбаево, Революционная, 22		0101000020E610000065A9F57EA3094D40DFFAB0DEA8FB4B40
22110	7	61	237	18390	64319	\N	56.075668999999998	с. Большая Ока, Мира, 45		0101000020E61000004BAE62F19B1A4D4017299485AF094C40
22080	7	61	237	58145	63976	\N	55.947674907942499	с. Большеустьикинское, Молодежная, 15	Россия, республика Башкортостан, Мечетлинский район, село Болшеустьикинское	0101000020E6100000DFC4909C4C224D404F1E166A4DF94B40
22081	7	61	237	58145	63953	\N	55.944616472082103	с. Большеустьикинское, Ленина, 15	Россия, республика Башкортостан, Мечетлинский район, село Болшеустьикинское	0101000020E610000071E7C2482F224D40A1A3552DE9F84B40
22090	7	61	237	17384	65020	\N	55.860044000000002	д. Аюпово, Школьная, 5а		0101000020E61000002FFCE07CEA264D407E8FFAEB15EE4B40
22104	7	61	237	18099	64298	\N	55.936982999999998	с. Алегазово, Октябрьская, 14		0101000020E610000020F12BD6700F4D4038F4160FEFF74B40
22113	7	61	237	931	66715	\N	56.028700999999998	Мечетлинский район, д. Азикеево, ул. Школьная, 3		0101000020E6100000F2CEA10C55214D40662E7079AC034C40
22094	7	61	237	17599	65430	\N	55.746368871854401	д. Азангулово, Гагарина, 24	Россия, республика Башкортостан, Мечетлинский район, село Азангулово	0101000020E610000099F38C7DC9384D40C6DFF60489DF4B40
22108	7	61	237	5479	66485	\N	56.069004318506202	д. Абдуллино, Ленина, 96	Россия, республика Башкортостан, Мечетлинский район, село Абдуллино	0101000020E6100000887FD8D2A3FB4C4087A5811FD5084C40
22091	7	61	237	17428	65014	\N	55.826386999999997	д. Абдрахимово, Октябрьская, 26а		0101000020E6100000492F6AF7AB284D40766B990CC7E94B40
22078	7	61	179	58376	64855	\N	52.917474973725298	Республика Башкортостан, Мелеузовский район, Первомайский сельсовет, д. Первомайский, Ленина, 31		0101000020E61000006DA983BC1EFE4B40E5F21FD26F754A40
22055	7	61	179	15671	65007	\N	53.173273999999999	Республика Башкортостан, Мелеузовский район, Зирганский сельсовет, д. Юмаково, Салавата Юлаева, 38		0101000020E6100000A8380EBC5AFC4B40A19FA9D72D964A40
22077	7	61	179	16747	65421	\N	52.976394999999997	Республика Башкортостан, Мелеузовский район, Первомайский сельсовет, д. Узя, Потешкина, 3		0101000020E61000007BF486FBC8074C402C7DE882FA7C4A40
22044	7	61	179	15124	65912	\N	53.015365000000003	Республика Башкортостан, Мелеузовский район, Партизанский сельсовет, с. Троицкое, Победы, 6		0101000020E610000003B68311FBE84B406440F67AF7814A40
22052	7	61	179	15509	66122	\N	53.273921000000001	Республика Башкортостан, Мелеузовский район, Корнеевский сельсовет, д. Сухаревка, Сухаревская, 75		0101000020E6100000ACE122F774E34B400458E4D70FA34A40
22059	7	61	179	15853	64099	\N	53.035361000000002	Республика Башкортостан, Мелеузовский район, Араслановский сельсовет, д. Смаково, Правонабережная, 6		0101000020E61000007EC7F0D8CF084C40E54691B586844A40
22066	7	61	179	16161	65422	\N	53.068232999999999	Республика Башкортостан, Мелеузовский район, Нугушевский сельсовет, д. Сергеевка, Мира, 25		0101000020E6100000AC02B5183C3E4C4005C1E3DBBB884A40
22068	7	61	179	16263	64116	\N	52.907100999999997	Республика Башкортостан, Мелеузовский район, Сарышевский сельсовет, с. Сарышево, Мира, 6		0101000020E6100000E1D05B3CBC294C409E95B4E21B744A40
22073	7	61	179	16558	65918	\N	52.945292000000002	Республика Башкортостан, Мелеузовский район, Первомайский сельсовет, д. Самаро - Ивановка, Советская, 2, Б		0101000020E6100000BA313D6189074C40D1950854FF784A40
22042	7	61	179	15030	65913	\N	53.03678	Республика Башкортостан, Мелеузовский район, Денисовский сельсовет, д. Саитовский, Юрматинская, 6		0101000020E610000084A0A3552DCF4B40CD920035B5844A40
22053	7	61	179	15580	65000	\N	53.253368000000002	Республика Башкортостан, Мелеузовский район, Зирганский сельсовет, д. Сабашево, Колхозная, 20, А		0101000020E61000005265187783FA4B402DEDD45C6EA04A40
22176	7	61	179	46848	65363	\N	52.9257586130094	деревня Рассвет, улица Центральная, дом 1	Россия, республика Башкортостан, Мелеузовский район, село Рассвет	0101000020E6100000DBDB2DC901F14B40247D5A457F764A40
22041	7	61	179	14974	65911	\N	53.111525	Республика Башкортостан, Мелеузовский район, Денисовский сельсовет, д. Петропавловка, Центральная, 25		0101000020E61000005D177E703ED94B40DCD78173468E4A40
22139	7	61	179	58742	66319	\N	52.919503198681198	д. Озерки, Озерная, 14	Россия, республика Башкортостан, Мелеузовский район, село Озерки	0101000020E61000006BF3FFAA23E54B4075C93846B2754A40
22065	7	61	179	16144	64393	\N	53.0420640554117	Республика Башкортостан, Мелеузовский район, Нугушевский сельсовет, с. Нугуш, Молодежная, 10	Россия, республика Башкортостан, Мелеузовский район, поселок Нугуш	0101000020E610000069C878944A384C40632B685A62854A40
22046	7	61	179	15209	64446	\N	53.241470999999997	Республика Башкортостан, Мелеузовский район, Нордовский сельсовет, с. Нордовка, Гагарина, 1		0101000020E61000000A68226C78CC4B4059F78F85E89E4A40
22350	7	61	179	46136	66631	\N	53.339694000000001	453153, РБ Стерлитамакский район, с. Новый Краснояр, ул. Молодежная, д. 1в		0101000020E61000006A882AFC19D64B40DF52CE177BAB4A40
22016	7	61	179	13759	63602	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Южная, 5		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22035	7	61	179	13759	63289	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Смоленская, 192		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22023	7	61	179	13759	63286	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Площадь Элеватора, 1		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22030	7	61	179	13759	63552	\N	52.9664487969359	Республика Башкортостан, Мелеузовский район, город Мелеуз, Первомайская, 8	Россия, республика Башкортостан, Мелеузовский район, Мелеуз	0101000020E61000005169C4CC3EF74B403E20D099B47B4A40
22034	7	61	179	13759	63598	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Костромская, 35		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22017	7	61	179	13759	64238	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, Береговая, 2, В		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22036	7	61	179	13759	63283	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, 50 лет ВЛКСМ, 55		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22029	7	61	179	13759	63283	\N	52.957000999999998	Республика Башкортостан, Мелеузовский район, город Мелеуз, 50 лет ВЛКСМ, 19		0101000020E6100000D3F544D785F74B40A19E3E027F7A4A40
22025	7	61	179	13759	63698	\N	52.964793741278903	Республика Башкортостан, Мелеузовский район, город Мелеуз, 32 микрорайон, 4	Россия, республика Башкортостан, Мелеузовский район, Мелеуз	0101000020E61000002EE7525C55F64B4042B0AA5E7E7B4A40
22038	7	61	179	14852	64097	\N	53.009286000000003	Республика Башкортостан, Мелеузовский район, Мелеузовский сельсовет, д. Кутушево, Школьная, 5		0101000020E61000001E335019FFFA4B40C4279D4830814A40
22049	7	61	179	15363	64527	\N	53.328386471191799	Республика Башкортостан, Мелеузовский район, Корнеевский сельсовет, д. Корнеевка, Ямилева, 2	Россия, республика Башкортостан, Мелеузовский район, село Корнеевка	0101000020E610000066118AADA0E54B406D3B6D8D08AA4A40
21753	7	61	179	58118	63685	\N	53.3346828157364	Адрес помещения для голосования: село Константиновка, улица Ленина, дом 67в, Адрес УИК: улица Кооперативная, дом 2а	Россия, республика Башкортостан, Мелеузовский район, село Константиновка	0101000020E6100000CA181F662FEF4B407AC37DE4D6AA4A40
22074	7	61	179	559	66857	\N	52.966721	453885 Республика Башкортостан, Мелеузовский район, Первомайский сельсовет, д. Кизрай, Школьная, д.1		0101000020E61000008E075BECF6114C409FAD8383BD7B4A40
22037	7	61	179	14785	63415	\N	52.924255000000002	Республика Башкортостан, Мелеузовский район, Мелеузовский сельсовет, д.Каран, Берёзовая, 6		0101000020E610000038876BB587F54B400E15E3FC4D764A40
22067	7	61	179	5950	66902	\N	52.963624000000003	453871 Республика Башкортостан, Мелеузовский район, Иштугановский сельсовет, д. Иштуганово, Центральная 39, А		0101000020E6100000A8380EBC5A384C4003D2FE07587B4A40
22057	7	61	179	15677	63288	\N	53.226379000000001	Республика Башкортостан, Мелеузовский район, Зирганский сельсовет, с. Зирган, Советская, 213		0101000020E6100000D5963AC8EBF54B4027C0B0FCF99C4A40
22056	7	61	179	15677	63288	\N	53.226379000000001	Республика Башкортостан, Мелеузовский район, Зирганский сельсовет, с. Зирган, Советская, 122		0101000020E6100000D5963AC8EBF54B4027C0B0FCF99C4A40
22047	7	61	179	15277	66120	\N	53.222572999999997	Республика Башкортостан, Мелеузовский район, Нордовский сельсовет, д. Дмитриевка, Механизаторов, 1		0101000020E61000009D685721E5DD4B407EFCA5457D9C4A40
22043	7	61	179	15058	64317	\N	53.046309000000001	Республика Башкортостан, Мелеузовский район, Партизанский сельсовет, с. Дарьино, Советская, 1		0101000020E6100000B69E211CB3F04B4057410C74ED854A40
22051	7	61	179	15488	65915	\N	53.327255999999998	Республика Башкортостан, Мелеузовский район, Корнеевский сельсовет, д. Даниловка, Школьная, 7		0101000020E610000049F7730AF2D34B40BBB54C86E3A94A40
20999	7	61	179	46777	65690	\N	52.959642000000002	с. Восточное, Школьная, 7		0101000020E6100000069D103AE8244C401CEF8E8CD57A4A40
22060	7	61	179	58213	64352	\N	53.123517999999997	Республика Башкортостан, Мелеузовский район, Воскресенский сельсовет, с. Воскресенское, Ленина, 34		0101000020E6100000E97FB9162D124C40D13B1570CF8F4A40
22061	7	61	179	15872	64107	\N	53.123517999999997	Республика Башкортостан, Мелеузовский район, Воскресенский сельсовет, с. Воскресенское, Рихарда Зорге, 42		0101000020E6100000E97FB9162D124C40D13B1570CF8F4A40
22054	7	61	179	15594	66121	\N	53.310429999999997	Республика Башкортостан, Мелеузовский район, Зирганский сельсовет, д. Верхнеюлдашево, Школьная, 1, А		0101000020E610000094DE37BEF6FC4B4040D9942BBCA74A40
22045	7	61	179	15181	65103	\N	53.094121999999999	Республика Башкортостан, Мелеузовский район, Партизанский сельсовет, с. Васильевка, Школьная, 2		0101000020E6100000A438471D1DFB4B40C4EA8F300C8C4A40
21046	7	61	58	10311	63565	\N	55.840871	с. Бураево, Магдана, 38/1		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
21627	7	61	179	15181	66739	\N	53.093705937378701	д.Васильевка,ул.Центральная, 33	Россия, республика Башкортостан, Мелеузовский район, село Васильевка	0101000020E610000016A5846055FB4B4030B8E68EFE8B4A40
22048	7	61	179	15309	66721	\N	53.188583999999999	453881 Республика Башкортостан, Мелеузовский район, Нордовский сельсовет, д. Варварино, Социалстическая, 36, А		0101000020E6100000614F3BFC35DD4B404146408523984A40
22058	7	61	179	5876	66805	\N	53.116211	453875 Республика Башкортостан, Мелеузовский район, Араслановский сельсовет, д. Береговка, Заречная, 64, А		0101000020E6100000444C89247AFB4B40BD378600E08E4A40
22069	7	61	179	16356	64450	\N	52.888952000000003	Республика Башкортостан, Мелеузовский район, Аптраковский сельсовет, д. Аптраково, Салима Масагутова, 1		0101000020E61000003944DC9C4A164C405EDBDB2DC9714A40
22039	7	61	179	14894	65005	\N	52.905827829885297	Республика Башкортостан, Мелеузовский район, Шевченковский сельсовет, д. Антоновка, Заречная, 8/1	Россия, республика Башкортостан, Мелеузовский район, село Антоновка	0101000020E6100000DEC83CF207DF4B408AE6012CF2734A40
22062	7	61	179	15962	65004	\N	53.035080000000001	Республика Башкортостан, Мелеузовский район, Александровский сельсовет, с. Александровка, Центральная, 51		0101000020E6100000232E008DD21F4C40315F5E807D844A40
22070	7	61	179	16365	64029	\N	53.005065000000002	Республика Башкортостан, Мелеузовский район, Абитовский сельсовет, д. Абитово, Центральная, 4		0101000020E61000006281AFE8D62B4C4058AD4CF8A5804A40
21995	7	61	531	12820	65907	\N	52.582514000000003	Республика Башкортостан, Куюргазинский район, Бахмутский сельсовет, с.Ямансарово, Школьная, 1		0101000020E6100000492A53CC41004C4028BB99D18F4A4A40
22001	7	61	531	13075	64997	\N	52.541964999999998	Республика Башкортостан, Куюргазинский район, Отрадинский сельсовет, д.Ямангулово, Школьная, 2		0101000020E61000007FA1478C9EF74B40CF49EF1B5F454A40
21978	7	61	531	12041	65416	\N	52.798352999999999	Республика Башкортостан, Куюргазинский район, д.Ялчикаево, Искужина, 34		0101000020E61000001F2BF86D88C74B40EDD45C6E30664A40
22014	7	61	531	13697	64399	\N	52.561207000000003	Республика Башкортостан, Куюргазинский район, Якшимбетовский сельсовет, с.Якшимбетово, Талгата Азнабаева, 1 в		0101000020E610000096B377465BC94B40A5A487A1D5474A40
22006	7	61	531	58875	66804	\N	52.430408603240402	Куюргазинский район, с.Якутово, ул. Баяна, 6	Россия, республика Башкортостан, Куюргазинский район	0101000020E6100000A93121E692E04B40B87361A417374A40
22013	7	61	531	13636	65080	\N	52.62753	Республика Башкортостан, Куюргазинский район, с.Якупово, Центральная, 44		0101000020E6100000520DFB3DB1C64B4023A12DE752504A40
22012	7	61	531	13605	64999	\N	52.517601999999997	Республика Башкортостан, Куюргазинский район, Якшимбетовский сельсовет, д.Язлав, Биктеевская, 33		0101000020E61000009CC58B8521D84B400E2C47C840424A40
22003	7	61	531	13192	66123	\N	52.493741	Республика Башкортостан, Куюргазинский район, Мурапталовский сельсовет, д.Юшатырка, Кооперативная, 3		0101000020E6100000AF963B33C1E64B40E0D8B3E7323F4A40
21984	7	61	531	12325	65159	\N	52.901719	Республика Башкортостан, Куюргазинский район, д.Юмагузино, Дружбы, 3		0101000020E610000052616C21C8EB4B40469737876B734A40
21987	7	61	531	3948	66812	\N	52.727862000000002	Куюргазинский район, д.Шабагиш, ул. Мира, 2		0101000020E6100000524832AB77DA4B402600FF942A5D4A40
21986	7	61	531	12408	64987	\N	52.737738	Республика Башкортостан, Куюргазинский район, Шабагишский сельсовет, д.Холодный Ключ, Дружбы, 8	Россия, республика Башкортостан, Куюргазинский район, село Холодный Ключ	0101000020E6100000BABE0F0709D14B401B82E3326E5E4A40
21976	7	61	531	11921	66101	\N	52.753993999999999	Республика Башкортостан, Куюргазинский район, с.Свобода, Гагарина, 1		0101000020E61000008BC22E8A1EB84B40ABB019E082604A40
22254	7	61	531	12760	63570	\N	52.667966999999997	с.Павловка, Карла Маркса, 39		0101000020E6100000386A85E97B0B4C4053E751F17F554A40
21977	7	61	531	11947	9805	\N	52.787240744506398	Республика Башкортостан, Куюргазинский район, с.Новотаймасово, Ленина, 8	Россия, республика Башкортостан, Куюргазинский район, село Новотаймасово	0101000020E61000000EA14ACD1EBC4B4001892650C4644A40
21982	7	61	531	12236	64988	\N	52.837451000000001	Республика Башкортостан, Куюргазинский район, с.Новомусино, Школьная, 2	Россия, республика Башкортостан, Куюргазинский район, село Новомусино	0101000020E61000001EDFDE35E8D54B4052802898316B4A40
22005	7	61	531	13290	64381	\N	52.424688000000003	Республика Башкортостан, Куюргазинский район, Мурапталовский сельсовет, с.Новомурапталово, Парковая, 1б		0101000020E6100000A182C30B22E44B407880272D5C364A40
22008	7	61	531	13435	64992	\N	52.404527999999999	Республика Башкортостан, Куюргазинский район, Мурапталовский сельсовет, д.Новокалтаево, Баязита Бикбая, 15 а	Россия, республика Башкортостан, Куюргазинский район, село Новокалтаево	0101000020E6100000D95F764F1ED24B407C28D192C7334A40
21999	7	61	531	13001	64995	\N	52.640210000000003	Республика Башкортостан, Куюргазинский район, Отрадинский сельсовет, д.Новая Отрада, Новоотрадинская, 56 а		0101000020E6100000897AC1A739EB4B403D49BA66F2514A40
22010	7	61	531	13502	65910	\N	52.401012000000001	Республика Башкортостан, Куюргазинский район, Якшимбетовский сельсовет, с.Нижнее Бабаларово, Молодежная, 4-1		0101000020E6100000779E78CE16C44B40DBA6785C54334A40
21971	7	61	531	11709	65899	\N	52.621609999999997	Республика Башкортостан, Куюргазинский район, с.Молоканово, Школьная, 3 а		0101000020E6100000D53F8864C8DB4B40EB6E9EEA904F4A40
21981	7	61	531	12161	66106	\N	52.951641000000002	Республика Башкортостан, Куюргазинский район, д.Михайловка, Центральная, 25		0101000020E6100000FD6B79E57A9B4B4031444E5FCF794A40
21980	7	61	531	12137	65897	\N	52.890701999999997	Республика Башкортостан, Куюргазинский район, д.Марьевка, Школьная, 5		0101000020E61000000F971C774AA94B40AB3DEC8502724A40
21989	7	61	531	12574	65081	\N	52.877383000000002	Республика Башкортостан, Куюргазинский район, Ленинский сельсовет, д.Мамбеткулово, Заки Валиди, 1		0101000020E610000064744012F6FB4B407F880D164E704A40
21913	7	61	531	4235	66644	\N	52.496569999999998	Куюргазинский район, д.Куюргазы, ул. Школьная, 1		0101000020E610000008C72C7B12C84B405D16139B8F3F4A40
22011	7	61	531	13564	65415	\N	52.524112000000002	Республика Башкортостан, Куюргазинский район, Якшимбетовский сельсовет, с.Кутлуюлово, Школьная, 12 а		0101000020E610000045662E7079C44B4078B81D1A16434A40
21992	7	61	531	12693	66103	\N	52.686624000000002	Республика Башкортостан, Куюргазинский район, Кривле-Илюшкинский сельсовет, с.Кривле-Илюшкино, Школьная, 23		0101000020E6100000D099B4A9BA054C400953944BE3574A40
22007	7	61	531	29476	66939	\N	52.419903848282701	Куюргазинский район, д.Красный Маяк, ул. Горная, 18 А	Россия, республика Башкортостан, Куюргазинский район, село Красный Маяк	0101000020E6100000C07971E2ABD94B40D4BA0D6ABF354A40
21985	7	61	531	12395	65001	\N	52.788966000000002	Республика Башкортостан, Куюргазинский район, Шабагишский сельсовет,.Канчура, Центральная, 17		0101000020E61000004981053065DE4B40F6D37FD6FC644A40
21983	7	61	531	3239	66886	\N	52.864452	Куюргазинский район, д.Илькинеево, ул. Набережная, 1 А		0101000020E6100000513239B533E44B401C7BF65CA66E4A40
21979	7	61	531	12057	64104	\N	52.870218999999999	Республика Башкортостан, Куюргазинский район, с.Зяк-Ишметово, Школьная, 8		0101000020E6100000A2B77878CFB54B40CDAD1056636F4A40
21969	7	61	531	3292	63419	\N	52.702205999999997	Республика Башкортостан, Куюргазинский район, Ермолаевский сельсовет, с.Ермолаево, проспект Мира, 8		0101000020E610000077103B53E8E64B400987DEE2E1594A40
21965	7	61	531	3292	66821	\N	52.702205999999997	Куюргазинский район, с.Ермолаево, ул.Чапаева, 123		0101000020E610000077103B53E8E64B400987DEE2E1594A40
21968	7	61	531	3292	63600	\N	52.708256624832302	Республика Башкортостан, Куюргазинский район, Ермолаевский сельсовет, с.Ермолаево, Советская, 160 А	Россия, республика Башкортостан, Куюргазинский район, поселок Ермолаево	0101000020E6100000BF982D5915E74B40E014562AA85A4A40
21966	7	61	531	3292	64295	\N	52.702205999999997	Республика Башкортостан, Куюргазинский район, Ермолаевский сельсовет, с.Ермолаево, Калинина, 17 А		0101000020E610000077103B53E8E64B400987DEE2E1594A40
21967	7	61	531	3292	63739	\N	52.702205999999997	Республика Башкортостан, Куюргазинский район, Ермолаевский сельсовет, с.Ермолаево, Ватутина, 2		0101000020E610000077103B53E8E64B400987DEE2E1594A40
21996	7	61	531	12882	64993	\N	52.610076537535399	Республика Башкортостан, Куюргазинский район, Бахмутский сельсовет, д.Горный Ключ, Баянская, 1-1	Россия, республика Башкортостан, Куюргазинский район, село Горный Ключ	0101000020E6100000564ACFF412F34B405985CD00174E4A40
21988	7	61	531	12505	66809	\N	52.835825	Куюргазинский район, с.Бугульчан, ул. Школьная, 8		0101000020E610000008AC1C5A64FB4B40F0164850FC6A4A40
21997	7	61	531	12923	66872	\N	52.654563000000003	Куюргазинский район, с.Бахмут, ул. Советская, 39		0101000020E61000002E73BA2C26F44B40F9156BB8C8534A40
21990	7	61	531	4115	66811	\N	52.755361999999998	Куюргазинский район, д.Бальза, ул. Рабочая, 9 Б		0101000020E61000008C648F5033F64B401152B7B3AF604A40
22002	7	61	531	13134	66119	\N	52.483173000000001	Республика Башкортостан, Куюргазинский район, Мурапталовский сельсовет, д.Аксарово, Молодежная, 10		0101000020E6100000E2AC889AE8E94B40B5A7E49CD83D4A40
21973	7	61	531	58740	66287	\N	52.663618646304201	Республика Башкортостан, Куюргазинский район, д.Кинья-Абыз, 40 лет Победы, 4	Россия, республика Башкортостан, Куюргазинский район	0101000020E6100000C80C54C6BFB54B408A00A777F1544A40
21940	7	61	1041	10218	65412	\N	55.116171000000001	Республика Башкортостан, Кушнаренковский район, д.Якупово, Молодежная, 3		0101000020E61000005307793D989A4B402FDFFAB0DE8E4B40
21936	7	61	1041	10014	66082	\N	55.162216999999998	Республика Башкортостан, Кушнаренковский район, с.Чирша-Тартыш, Речная, 46		0101000020E61000008D28ED0DBE924B4078EDD286C3944B40
21960	7	61	1041	11155	64981	\N	54.936790999999999	Республика Башкортостан, Кушнаренковский район, д.Угузево, Мира, 56		0101000020E61000008CBE823463A94B40F4177AC4E8774B40
21937	7	61	1041	10071	64683	\N	55.187475999999997	Республика Башкортостан, Кушнаренковский район, д.Толбазы, Победы, 40а		0101000020E6100000768D96033D844B407764AC36FF974B40
21924	7	61	1041	9418	63317	\N	55.082565000000002	Республика Башкортостан, Кушнаренковский район, с.Тарабердино, Кирова, 43		0101000020E61000006F8445459CB24B40AA656B7D918A4B40
21946	7	61	1041	10523	65406	\N	54.848923999999997	Республика Башкортостан, Кушнаренковский район, с.Султанаево, Школьная, 1		0101000020E61000009ACDE33098B94B400E65A88AA96C4B40
21955	7	61	1041	10960	64314	\N	54.937549655268398	Республика Башкортостан, Кушнаренковский район, с.Старые Тукмаклы, Центральная, 7	Россия, республика Башкортостан, Кушнаренковский район, село Старые Тукмаклы	0101000020E610000009FA0B3D62A24B40B22E6EA301784B40
21948	7	61	1041	10629	64370	\N	54.950180000000003	Республика Башкортостан, Кушнаренковский район, с.Старые Камышлы, Школьная, 29		0101000020E61000002FC4EA8F30E24B401AA88C7F9F794B40
21950	7	61	1041	10703	64172	\N	55.086986000000003	Республика Башкортостан, Кушнаренковский район, с.Старокурмашево, Парковая, 11		0101000020E61000009A40118B18A44B40DD9A745B228B4B40
21944	7	61	1041	10415	64367	\N	54.829138999999998	Республика Башкортостан, Кушнаренковский район, с.Старогумерово, Валиева, 12		0101000020E6100000CD7344BE4BA74B40486B0C3A216A4B40
21934	7	61	1041	9924	66784	\N	55.270580000000002	452246, РБ, Кушнаренковский район, д.Саитово, ул.Коммунаров, 40		0101000020E61000000892770E65844B40D1798D5DA2A24B40
21941	7	61	1041	10288	65586	\N	55.078122999999998	Республика Башкортостан, Кушнаренковский район, д.Расмекеево, Пролетарская, 48		0101000020E6100000D234289A078C4B405F0839EFFF894B40
94459	7	61	518	30092	66771	\N	55.717796999999997	РБ,Караидельский район,д.Абдуллино, ул.С.Юлаева 10а		0101000020E6100000916456EF70854C405D15A8C5E0DB4B40
21947	7	61	1041	10569	66087	\N	55.010905999999999	Республика Башкортостан, Кушнаренковский район, с.Первушино, Парковая, 20		0101000020E6100000E7E44526E0DD4B4043AA285E65814B40
21958	7	61	1041	11061	65411	\N	55.005097999999997	Республика Башкортостан, Кушнаренковский район, с.Новые Тукмаклы, Центральная, 38		0101000020E610000070D234289AA54B4033A31F0DA7804B40
21952	7	61	1041	10800	65893	\N	55.019485000000003	Республика Башкортостан, Кушнаренковский район, с.Новокурмашево, Центральная, 34		0101000020E610000083FB010F0C964B409CE1067C7E824B40
21945	7	61	1041	10478	66085	\N	54.885486999999998	Республика Башкортостан, Кушнаренковский район, д.Новогумерово, Новая, 32/1		0101000020E6100000BBB4E1B034A64B403E0455A357714B40
21929	7	61	1041	9663	65405	\N	55.052948000000001	Республика Башкортостан, Кушнаренковский район, с.Медведёрово, Трактовая, 34		0101000020E6100000DA53724EECCB4B40BE310400C7864B40
21962	7	61	1041	11249	66098	\N	55.000585000000001	Республика Башкортостан, Кушнаренковский район, д.Мамяково, Центральная, 62		0101000020E6100000A8E507AEF2CA4B4020EF552B13804B40
21921	7	61	1041	9117	63735	\N	55.107087	Республика Башкортостан, Кушнаренковский район, с.Кушнаренково, Терешковой, 15	Россия, республика Башкортостан, Кушнаренковский район, поселок Кушнаренково	0101000020E61000002BFC19DEACAD4B40D369DD06B58D4B40
21920	7	61	1041	9117	63596	\N	55.107087	Республика Башкортостан, Кушнаренковский район, с.Кушнаренково, Советская, 22		0101000020E61000002BFC19DEACAD4B40D369DD06B58D4B40
21922	7	61	1041	9117	63599	\N	55.107087	Республика Башкортостан, Кушнаренковский район, с.Кушнаренково, Октябрьская, 49		0101000020E61000002BFC19DEACAD4B40D369DD06B58D4B40
21919	7	61	1041	9117	63599	\N	55.107087	Республика Башкортостан, Кушнаренковский район, с.Кушнаренково, Октябрьская, 60		0101000020E61000002BFC19DEACAD4B40D369DD06B58D4B40
21918	7	61	1041	9117	63599	\N	55.107087	Республика Башкортостан, Кушнаренковский район, с.Кушнаренково, Октябрьская, 84		0101000020E61000002BFC19DEACAD4B40D369DD06B58D4B40
21917	7	61	1041	9117	66782	\N	55.107087	452230, РБ, Кушнаренковский район, с.Кушнаренково, ул.Мичурина, 1		0101000020E61000002BFC19DEACAD4B40D369DD06B58D4B40
21923	7	61	1041	9117	63661	\N	55.107087	Республика Башкортостан, Кушнаренковский район, с.Кушнаренково, Большевистская, 57	Россия, республика Башкортостан, Кушнаренковский район, поселок Кушнаренково	0101000020E61000002BFC19DEACAD4B40D369DD06B58D4B40
21935	7	61	1041	9970	64162	\N	55.20299	Республика Башкортостан, Кушнаренковский район, с.Карача-Елга, Ленина, 15		0101000020E61000006A317898F68F4B4020B58993FB994B40
21956	7	61	1041	10976	66093	\N	54.966768000000002	Республика Башкортостан, Кушнаренковский район, с.Каратяки, Школьная, 12		0101000020E6100000DB4C8578249C4B40E068C70DBF7B4B40
21926	7	61	1041	9497	64976	\N	55.114857999999998	Республика Башкортостан, Кушнаренковский район, с.Канлы, Центральная, 32		0101000020E6100000C26C020CCBC54B408CD7BCAAB38E4B40
21963	7	61	1041	11308	64528	\N	55.003006999999997	Республика Башкортостан, Кушнаренковский район, с.Калтаево, Дорожная, 8		0101000020E6100000B0AD9FFEB3B44B405C548B8862804B40
21959	7	61	1041	11133	65414	\N	54.943742	Республика Башкортостан, Кушнаренковский район, с.Казарма, Школьная, 13		0101000020E6100000BE4C142175AF4B404AEEB089CC784B40
21949	7	61	1041	10668	65410	\N	54.963259000000001	Республика Башкортостан, Кушнаренковский район, д.Ильмурзино, Школьная, 50а		0101000020E610000002BB9A3C65E54B40F14927124C7B4B40
22170	7	61	1041	9835	9932	\N	55.215632823501799	д. Иликово, Школьная, 5	Россия, республика Башкортостан, Кушнаренковский район, село Иликово	0101000020E61000000F7C0C569C7A4B401C78B5DC999B4B40
21932	7	61	1041	9835	64233	\N	55.216222000000002	Республика Башкортостан, Кушнаренковский район, с.Иликово, Коминтерна, 20		0101000020E61000004F0306499F7A4B407E569929AD9B4B40
22820	7	61	1041	58591	65648	\N	55.027344072874499	с.Ибрагимово, Центральная, 19	Россия, республика Башкортостан, Кушнаренковский район, село Ибрагимово	0101000020E610000078B471C45A984B40F4DE180280834B40
21964	7	61	1041	11346	65905	\N	55.000435206092803	Республика Башкортостан, Кушнаренковский район, д.Гургуреево, Парковая, 4	Россия, республика Башкортостан, Кушнаренковский район, село Гургуреево	0101000020E6100000CA87A06AF4AC4B400B630B410E804B40
21933	7	61	1041	9849	65890	\N	55.214537	Республика Башкортостан, Кушнаренковский район, д.Гумерово, 13 лет Октября, 32		0101000020E6100000FC010F0C20864B401764CBF2759B4B40
20336	7	61	1041	47332	65755	\N	55.150782	д. Горный, Садовая, 13/2		0101000020E6100000249C16BCE8BB4B40A96917D34C934B40
21954	7	61	1041	10883	66095	\N	54.965445000000003	Республика Башкортостан, Кушнаренковский район, д.Бейкеево, Центральная, 14		0101000020E6100000FB5C6DC5FE884B401A8BA6B3937B4B40
21939	7	61	1041	10139	65891	\N	55.174326000000001	Республика Башкортостан, Кушнаренковский район, с.Бардовка, Свободы, 33		0101000020E6100000739F1C0588A04B40D76B7A5050964B40
21930	7	61	1041	9706	66081	\N	55.030287000000001	Республика Башкортостан, Кушнаренковский район, с.Бакаево, Центральная, 26		0101000020E6100000F5BEF1B567844B403A3FC571E0834B40
21925	7	61	1041	9465	64447	\N	55.098491000000003	Республика Башкортостан, Кушнаренковский район, с.Ахметово, Центральная, 34		0101000020E610000022E3512AE1BF4B40A5F9635A9B8C4B40
21927	7	61	1041	9570	65886	\N	55.161985000000001	Республика Башкортостан, Кушнаренковский район, с.Ахлыстино, Центральная, 5		0101000020E6100000E9D32AFA43D54B40A6B8AAECBB944B40
21890	7	61	258	7832	65397	\N	52.582069825188803	Республика Башкортостан, Кугарчинский район, Исимовский сельсовет, с. Янаул, М. Гафури, 1А	Россия, республика Башкортостан, Кугарчинский район, село Янаул	0101000020E6100000793A5794123A4C40CAFD0E45814A4A40
21860	7	61	258	6426	65896	\N	52.869007000000003	Республика Башкортостан, Кугарчинский район, Ялчинский сельсовет, д. Ялчино, Центральная, 13		0101000020E61000009C525E2BA1394C405F7F129F3B6F4A40
21872	7	61	258	6426	66058	\N	52.869007000000003	Республика Башкортостан, Кугарчинский район, Иртюбякский сельсовет, д. Ялчино, Мира, 21		0101000020E61000009C525E2BA1394C405F7F129F3B6F4A40
21877	7	61	258	7170	64380	\N	52.897481999999997	Республика Башкортостан, Кугарчинский район, Юмагузинский сельсовет, с. Юмагузино, Школьная, 64А		0101000020E61000000ED76A0F7B314C40D45FAFB0E0724A40
21876	7	61	258	7170	63410	\N	52.897481999999997	Республика Башкортостан, Кугарчинский район, Юмагузинский сельсовет, с. Юмагузино, Строителей, 20		0101000020E61000000ED76A0F7B314C40D45FAFB0E0724A40
21875	7	61	258	7170	64954	\N	52.897897195347802	Республика Башкортостан, Кугарчинский район, Юмагузинский сельсовет, с. Юмагузино, Равенства, 17А	Россия, республика Башкортостан, Кугарчинский район, село Юмагузино	0101000020E6100000D673D2FBC6314C409816F549EE724A40
21878	7	61	258	7170	66802	\N	52.897481999999997	с. Юмагузино, улица Комсомольская, 5		0101000020E61000000ED76A0F7B314C40D45FAFB0E0724A40
21908	7	61	258	58717	66152	\N	52.640025947144998	Республика Башкортостан, Кугарчинский район, Юлдыбаевский сельсовет, д. Юлдыбай, З. Биишевой, 37	Россия, республика Башкортостан, Кугарчинский район, село Юлдыбаево 1-е	0101000020E6100000C87E164B91624C407B4B395FEC514A40
21879	7	61	258	58760	66378	\N	52.880643999999997	Республика Башкортостан, Кугарчинский район, Юмагузинский сельсовет, х. Хлебодаровка, Речная, 66	Россия, республика Башкортостан, Кугарчинский район, село Хлебодаровка	0101000020E6100000C8CEDBD8EC204C4095B54DF1B8704A40
21873	7	61	258	7046	64952	\N	52.862256270110599	Республика Башкортостан, Кугарчинский район, Иртюбякский сельсовет, д. Тюлебаево, Школьная, 5	Россия, республика Башкортостан, Кугарчинский район, село Тюлебаево	0101000020E6100000FD2D01F8A7464C40D06394675E6E4A40
21909	7	61	258	58426	64983	\N	52.663880792553897	Республика Башкортостан, Кугарчинский район, Юлдыбаевский сельсовет, д. 1-е Тупчаново, З. Валиди, 20	Россия, республика Башкортостан, Кугарчинский район, село Тупчаново 1-е	0101000020E610000039D0436D1B5E4C40C8B7770DFA544A40
21916	7	61	258	58541	65409	\N	52.520023999999999	Республика Башкортостан, Кугарчинский район, Нукаевский сельсовет, д. 1-е Тукатово, Мира, 24А	Россия, республика Башкортостан, Кугарчинский район, село Тукатово 1-е	0101000020E610000032CA332F87614C404B917C2590424A40
21897	7	61	258	8175	66070	\N	52.34328	Республика Башкортостан, Кугарчинский район, Максютовский сельсовет, д. Туембетово, Школьная, 1		0101000020E6100000D593F947DF3C4C4079AF5A99F02B4A40
21864	7	61	258	6630	65381	\N	52.666023000000003	Республика Башкортостан, Кугарчинский район, Тляумбетовский сельсовет, д. Тляумбетово, Молодежная, 1		0101000020E6100000C8D0B1834A284C4021B1DD3D40554A40
21866	7	61	258	6716	66057	\N	52.601179999999999	Республика Башкортостан, Кугарчинский район, Тляумбетовский сельсовет, д. Таваканово, Сэнкем, 6		0101000020E6100000785E2A36E62B4C4030815B77F34C4A40
21855	7	61	258	6149	64940	\N	52.765247000000002	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, д. Султангулово, Х. Давлетшиной, 4		0101000020E61000005FEE93A300514C405A2E1B9DF3614A40
21871	7	61	258	6978	64947	\N	52.865288999999997	Республика Башкортостан, Кугарчинский район, Иртюбякский сельсовет, с. Семено-Петровское, Колхозная, 6А		0101000020E61000003D601E32E5334C40554B3ACAC16E4A40
21911	7	61	258	8823	64579	\N	52.598756999999999	Республика Башкортостан, Кугарчинский район, Юлдыбаевский сельсовет, д. Сатлыки, Пушкина, 1		0101000020E6100000D21BEE23B7644C4023A0C211A44C4A40
21904	7	61	258	8542	64979	\N	52.5225815477257	Республика Башкортостан, Кугарчинский район, Ижбердинский сельсовет, д. Сапыково, Молодежная, 12	Россия, республика Башкортостан, Кугарчинский район, село Сапыково	0101000020E6100000F77475C762454C4038BD8BF7E3424A40
21888	7	61	258	7724	65392	\N	52.599397000000003	Республика Башкортостан, Кугарчинский район, Новопетровский сельсовет, с. Саиткулово, Верхняя, 20		0101000020E61000009A22C0E95D444C400729780AB94C4A40
21764	7	61	258	1085	63582	\N	52.972192999999997	село Прибельский, Пугачева, 1		0101000020E61000003F6EBF7CB2424C403733FAD1707C4A40
21763	7	61	258	1085	63237	\N	52.972192999999997	Адрес помещения для голосования: село Прибельский, улица Ленина, дом 6, Адрес УИК: улица Пугачева, дом 1		0101000020E61000003F6EBF7CB2424C403733FAD1707C4A40
21868	7	61	258	6809	64943	\N	52.719094288156697	Республика Башкортостан, Кугарчинский район, Чапаевский сельсовет, с. Подгорное, Советская, 37	Россия, республика Башкортостан, Кугарчинский район, село Подгорное	0101000020E61000004337FB03E52E4C40FA5FAE450B5C4A40
21859	7	61	258	27601	66848	\N	52.716905166704699	с.Побоище, ул.Советская, д. № 54 а	Россия, республика Башкортостан, Кугарчинский район, село Побоище	0101000020E610000041834D9D47914C4060AB048BC35B4A40
21915	7	61	258	9024	65887	\N	52.556486999999997	Республика Башкортостан, Кугарчинский район, Нукаевский сельсовет, с. Нукаево, Салавата Юлаева, 2А		0101000020E61000009F0436E7E0574C4017D34CF73A474A40
21907	7	61	258	58539	65402	\N	52.627243487567597	Республика Башкортостан, Кугарчинский район, Юлдыбаевский сельсовет, х. Новохвалынский, Оло Ик, 14	Россия, республика Башкортостан, Кугарчинский район, село Новохвалынский	0101000020E6100000B398D87C5C5F4C408DD2A57F49504A40
21857	7	61	258	6262	65878	\N	52.650553000000002	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, с. Новопокровское, Заозерная, 1		0101000020E610000045BA9F5390454C4048A8195245534A40
21898	7	61	258	8257	65882	\N	52.390850999999998	Республика Башкортостан, Кугарчинский район, Максютовский сельсовет, д. Верхнее Сазово, Русская, 11		0101000020E6100000B85B9203764D4C40F04DD36707324A40
21887	7	61	258	7709	64961	\N	52.616073638290501	Республика Башкортостан, Кугарчинский район, Новопетровский сельсовет, с. Новопетровское, Центральная, 34А	Россия, республика Башкортостан, Кугарчинский район, село Новопетровское	0101000020E6100000A019C40776404C403CF54883DB4E4A40
22733	7	61	258	7709	66198	\N	52.615606	с. Новопетровское, Гафури, 2		0101000020E610000001F9122A38404C40569C6A2DCC4E4A40
21880	7	61	258	7374	65879	\N	52.957982999999999	Республика Башкортостан, Кугарчинский район, Нижнебиккузинский сельсовет, д. Нижнебиккузино, Победы, 36		0101000020E61000004C8BFA2477404C40DE8FDB2F9F7A4A40
21896	7	61	258	8157	65885	\N	52.301049999999996	Республика Башкортостан, Кугарчинский район, Максютовский сельсовет, с. Назаркино, Центральная, 5		0101000020E610000028806264C93E4C40FB3A70CE88264A40
21912	7	61	258	58291	66595	\N	52.585117119908297	Республика Башкортостан, Кугарчинский район, Юлдыбаевский сельсовет, д. Мурадым, Молодежная, 8	Россия, республика Башкортостан, Кугарчинский район	0101000020E610000028603B18B16B4C40B4AA251DE54A4A40
21892	7	61	258	7912	64963	\N	52.4748736360119	Республика Башкортостан, Кугарчинский район, Исимовский сельсовет, д. Мукачево, с. Юлаева, 39	Россия, республика Башкортостан, Кугарчинский район, село Мукачево	0101000020E6100000B517D1764C3F4C4040DCD5ABC83C4A40
21850	7	61	258	5881	64002	\N	52.713859999999997	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, с. Мраково, Учительская, 1		0101000020E6100000D461855B3E504C4016F6B4C35F5B4A40
21854	7	61	258	5881	64031	\N	52.713859999999997	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, с. Мраково, Октябрьская, 33		0101000020E6100000D461855B3E504C4016F6B4C35F5B4A40
21852	7	61	258	5881	63657	\N	52.713859999999997	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, с. Мраково, Ленина, 51		0101000020E6100000D461855B3E504C4016F6B4C35F5B4A40
21853	7	61	258	5881	64310	\N	52.713859999999997	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, с. Мраково, Иванова, 42		0101000020E6100000D461855B3E504C4016F6B4C35F5B4A40
21851	7	61	258	5881	63646	\N	52.713859999999997	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, с. Мраково, З.Биишевой, 117		0101000020E6100000D461855B3E504C4016F6B4C35F5B4A40
21894	7	61	258	8008	64235	\N	52.321894999999998	Республика Башкортостан, Кугарчинский район, Максютовский сельсовет, с. Максютово, Центральная, 70А		0101000020E610000006BEA25BAF434C407ADFF8DA33294A40
21858	7	61	258	6304	65884	\N	52.691628999999999	Республика Башкортостан, Кугарчинский район, Мраковский сельсовет, д. Кузьминовка, Центральная, 6		0101000020E6100000A5828AAA5F574C408BFB8F4C87584A40
21901	7	61	258	8390	64330	\N	52.438782000000003	Республика Башкортостан, Кугарчинский район, Кугарчинский сельсовет, с. Кугарчи, Советская, 25		0101000020E610000026FC523F6F4A4C40680932022A384A40
21863	7	61	258	6575	64313	\N	52.776747999999998	Республика Башкортостан, Кугарчинский район, Волостновский сельсовет, д. Калдарово, Молодежная, 28		0101000020E6100000261E5036E5204C40E09D7C7A6C634A40
21891	7	61	258	7884	64526	\N	52.538114	Республика Башкортостан, Кугарчинский район, Исимовский сельсовет, с. Исимово, 40 лет Победы, 26А		0101000020E6100000BC7669C361414C4087C267EBE0444A40
21885	7	61	258	7614	66064	\N	52.708005946278298	Республика Башкортостан, Кугарчинский район, Ибраевский сельсовет, д. Иртюбяк, Шевченко, 31	Россия, республика Башкортостан, Кугарчинский район, село Иртюбяк	0101000020E6100000A35A4414933F4C4096AFCBF09F5A4A40
21905	7	61	258	8558	64682	\N	52.514696999999998	Республика Башкортостан, Кугарчинский район, Ижбердинский сельсовет, с. Ижбердино, Школьная, 20		0101000020E610000077A38FF9804E4C40B62C5F97E1414A40
21910	7	61	258	8801	65403	\N	52.676105020599998	Республика Башкортостан, Кугарчинский район, Юлдыбаевский сельсовет, д. Ибрагимово, Школьная, 1	Россия, республика Башкортостан, Кугарчинский район, село Ибрагимово	0101000020E6100000D844662E70574C40BFD4CF9B8A564A40
21895	7	61	258	8086	66066	\N	52.292926000000001	Республика Башкортостан, Кугарчинский район, Максютовский сельсовет, д. Зирекля, Сулеймана, 25		0101000020E6100000DFA63FFB914A4C40F51263997E254A40
21865	7	61	258	6688	9968	\N	52.612741	Республика Башкортостан, Кугарчинский район, Тляумбетовский сельсовет, д. Даут-Каюпово, Луговая, 25		0101000020E61000001C45D61A4A1D4C408CF50D4C6E4E4A40
21869	7	61	258	6862	64785	\N	52.793773999999999	Республика Башкортостан, Кугарчинский район, Зареченский сельсовет, д. Воскресенское, 70 лет Октября, 34		0101000020E610000005A4FD0FB02E4C402235ED629A654A40
21862	7	61	258	6518	65378	\N	52.813727	Республика Башкортостан, Кугарчинский район, Волостновский сельсовет, с. Волостновка, Центральная, 17		0101000020E6100000454B1E4FCB1D4C40A46FD23428684A40
21903	7	61	258	8478	65398	\N	52.442636	Республика Башкортостан, Кугарчинский район, Кугарчинский сельсовет, д. Верхнесюрюбаево, Центральная, 28		0101000020E610000065355D4F74414C402104E44BA8384A40
21893	7	61	258	7992	64967	\N	52.481651736293898	Республика Башкортостан, Кугарчинский район, Санзяповский сельсовет, с. Верхнесанзяпово, Центральная, 47	Россия, республика Башкортостан, Кугарчинский район, село Верхнесанзяпово	0101000020E61000003CDBA337DC314C40C806D2C5A63D4A40
21886	7	61	258	7649	64959	\N	52.419133806458802	Республика Башкортостан, Кугарчинский район, Кугарчинский сельсовет, д. Верхнемурсаляево, Центральная, 41	Россия, республика Башкортостан, Кугарчинский район, село Верхнемурсаляево	0101000020E610000065C746205E3F4C402252D32EA6354A40
19917	7	61	482	6159	63464	\N	55.885584999999999	город Агидель, Первых строителей, 7, А		0101000020E6100000889CBE9EAFF74A40016A6AD95AF14B40
21881	7	61	258	7457	64771	\N	52.996166000000002	Республика Башкортостан, Кугарчинский район, Нижнебиккузинский сельсовет, д. Верхнебиккузино, Набережная, 18		0101000020E61000000D8CBCAC89434C408EB1135E827F4A40
21906	7	61	258	8622	65399	\N	52.727649	Республика Башкортостан, Кугарчинский район, Уральский сельсовет, д. Бикбулатово, Набережная, 15		0101000020E61000002F4D11E0F4604C40CAFB389A235D4A40
21867	7	61	258	6787	65881	\N	52.658174000000002	Республика Башкортостан, Кугарчинский район, Тляумбетовский сельсовет, д. Бекечево, Буранбая, 67		0101000020E6100000882CD2C43B2E4C40EC89AE0B3F544A40
21914	7	61	258	8988	64977	\N	52.613846000000002	Республика Башкортостан, Кугарчинский район, Юлдыбаевский сельсовет, д. Багдашкино, Худайбердина, 45		0101000020E6100000B03C484F916F4C40E5637781924E4A40
21870	7	61	258	58847	66577	\N	52.621118000000003	Республика Башкортостан, Кугарчинский район, Зареченский сельсовет, д. Аралбай, Революционная, 39		0101000020E6100000ED65DB696B4A4C407D7A6CCB804F4A40
21882	7	61	258	7468	65396	\N	52.816077999999997	Республика Башкортостан, Кугарчинский район, Ибраевский сельсовет, д. Альмясово, Центральная, 35		0101000020E61000003D7FDAA84E4B4C40177E703E75684A40
21874	7	61	258	7081	64964	\N	52.885441999999998	Республика Башкортостан, Кугарчинский район, Юмагузинский сельсовет, с. Александровка, Молодежная, 25А		0101000020E61000001AA37554352B4C409E40D82956714A40
21828	7	61	482	4721	65872	\N	55.756984000000003	д.Янгузнарат, Береговая, 25А		0101000020E610000069368FC360304B4032CC09DAE4E04B40
21835	7	61	482	5096	65874	\N	55.894525878822897	с.Шушнур, Советская, 1	Россия, республика Башкортостан, Краснокамский район, село Шушнур	0101000020E6100000494C50C3B72E4B40FAB5F5D37FF24B40
21839	7	61	482	5298	65374	\N	55.807678000000003	с.Староянзигитово, Победы, 50		0101000020E61000006556EF703B0E4B406FD921FE61E74B40
21823	7	61	482	58841	66566	\N	55.718227843373597	д.Старый Буртюк, Центральная, 53	Россия, республика Башкортостан, Краснокамский район, село СтарБуртюк	0101000020E610000015E3FC4D28484B40278925E5EEDB4B40
21845	7	61	482	5625	65875	\N	55.983533999999999	д.Саузбаш, Дорожная, 4		0101000020E61000006555849B8CF44A4085402E71E4FD4B40
21846	7	61	482	5660	66073	\N	55.997255761991802	с.Саклово, Дорожная, 45	Россия, республика Башкортостан, Краснокамский район, село Саклово	0101000020E6100000FE45D09849024B40B1DEA815A6FF4B40
21722	7	61	482	33072	65836	\N	56.139391000000003	с.Раздолье, Центральная, 15		0101000020E61000002619390B7B344B40AA2D7590D7114C40
21818	7	61	482	33072	64455	\N	56.139391000000003	д.Раздолье, Молодежная, 3Б	Россия, республика Башкортостан, Краснокамский район, село Раздолье	0101000020E61000002619390B7B344B40AA2D7590D7114C40
21826	7	61	482	4598	65174	\N	55.797624999999996	с.Новый Каинлык, Школьная, 15		0101000020E61000009ED0EB4FE23D4B406ABC749318E64B40
21830	7	61	482	4814	65299	\N	55.844875000000002	д.Новохазино, Озерная, 22		0101000020E6100000446CB07092524B40A01A2FDD24EC4B40
21812	7	61	482	49085	65401	\N	56.014383000000002	д.Новоуразаево, Ленина, 45		0101000020E6100000CAC2D7D7BA1A4B40274F594DD7014C40
21838	7	61	482	5246	64100	\N	55.922181999999999	с.Новонагаево, Колхозная, 36А		0101000020E6100000770FD07D391F4B40DD7A4D0F0AF64B40
21836	7	61	482	5128	66051	\N	55.865647000000003	д.Новая Мушта, Большая, 5		0101000020E6100000AF5A99F04B314B40B5705985CDEE4B40
21822	7	61	482	4369	64093	\N	55.771773000000003	д.Новая Бура, Колхозная, 8А		0101000020E6100000F8DD74CB0E4B4B40C9772975C9E24B40
21824	7	61	482	58856	66596	\N	55.7354678575417	д.Новый Буртюк, Школьная, 8	Россия, республика Башкортостан, Краснокамский район, село НовБуртюк	0101000020E610000012842BA0504D4B4094A0BFD023DE4B40
21819	7	61	482	7722	65821	\N	56.178567999999999	с.Никольское, Дорожная, 1	Россия, республика Башкортостан, Краснокамский район, село Никольское	0101000020E61000000BED9C6681464B405A0EF450DB164C40
21847	7	61	482	5757	63521	\N	56.130938999999998	с.Николо-Берёзовка, Макаренко, 2		0101000020E6100000CBBC55D7A1144B40AE62F19BC2104C40
21849	7	61	482	5757	63320	\N	56.130938999999998	с.Николо-Берёзовка, Карла Маркса, 1		0101000020E6100000CBBC55D7A1144B40AE62F19BC2104C40
21848	7	61	482	5757	63320	\N	56.1313219270614	с.Николо-Берёзовка, Карла Маркса, 5	Россия, республика Башкортостан, Краснокамский район, поселок Николо-Березовка	0101000020E610000001DA56B3CE144B40669FC728CF104C40
21756	7	61	482	58558	65498	\N	56.156702830336997	деревня Мурзино, Речная, 7	Россия, республика Башкортостан, Краснокамский район, село Мурзино	0101000020E6100000BFB5132521314B40B1170AD80E144C40
21816	7	61	482	4068	64445	\N	56.172770999999997	с.Музяк, Школьная, 2		0101000020E6100000215A2BDA1C314B403E59315C1D164C40
21825	7	61	482	4556	66768	\N	55.747889999999998	д.Маняк, ул.Чапаева, 27А		0101000020E6100000C59107228B564B40B28009DCBADF4B40
21814	7	61	482	33049	66713	\N	56.063334407409002	Краснокамский район, д. Кулинка, ул. Солнечная, д. 1А		0101000020E6100000A7954220972C4B40C85C19541B084C40
21827	7	61	482	4676	64760	\N	55.853163000000002	д.Купербаш, Речная, 65		0101000020E6100000FD6CE4BA293D4B402194F77134ED4B40
21820	7	61	482	49195	66050	\N	56.172198999999999	д.Кувакино, Центральная, 57		0101000020E61000008D45D3D9C9404B40B3B3E89D0A164C40
21813	7	61	482	3906	64092	\N	56.018377999999998	с.Кариево, Школьная, 5		0101000020E6100000F50F221972364B40A27BD6355A024C40
21815	7	61	482	4008	65873	\N	55.991365000000002	д.Енактаево, Можарская, 9А		0101000020E6100000B45549641F304B4014B35E0CE5FE4B40
21817	7	61	482	49156	65813	\N	56.134450000000001	д.Воробьево, Школьная, 19		0101000020E6100000C03C64CA87224B403E7958A835114C40
21821	7	61	482	4340	66079	\N	56.160611000000003	д.Ведресево, Зеленая, 2		0101000020E610000054A86E2EFE4C4B405E30B8E68E144C40
21794	7	61	482	2874	64929	\N	55.793055000000003	д.Бурнюш, Школьная, 13		0101000020E6100000F0F96184F02E4B40F37684D382E54B40
21831	7	61	482	4890	65168	\N	55.838850000000001	д.Барьязибаш, Центральная, 40		0101000020E6100000DD28B2D650464B40F31FD26F5FEB4B40
21841	7	61	482	58861	66610	\N	55.838214999999998	д.Бачкитау, Новая, 1А	Россия, республика Башкортостан, Краснокамский район, село Бакчитау	0101000020E61000003D81B053AC084B4021020EA14AEB4B40
21811	7	61	482	3811	64308	\N	55.972513999999997	с.Арлан, Ленина, 28		0101000020E6100000F48C7DC9C61F4B407973B8567BFC4B40
19763	7	61	482	6159	63674	\N	55.885540713386398	город Агидель, Цветочный бульвар, 4	Россия, республика Башкортостан, Краснокамский район, поселок Агидель	0101000020E61000009DF4BEF1B5F74A403222516859F14B40
19684	7	61	6677	58221	\N	\N	54.563977274834798	Республика Башкортостан, город Уфа, Кировский район, Аэропорт	Россия, республика Башкортостан, поселок Уршак	0101000020E61000009A25016A6AF14B401D59F96530484B40
21802	7	61	207	3342	65870	\N	55.265594	Республика Башкортостан, Кигинский район, Ибраевский сельсовет, деревня Ягуново, М.Халила, 17		0101000020E6100000A54E401361434D40C501F4FBFEA14B40
21801	7	61	207	58660	65903	\N	55.329416000000002	Республика Башкортостан, Кигинский район, Ибраевский сельсовет, деревня Юкаликулево, Ленина, 33		0101000020E610000052D66F26A62F4D40BB63B14D2AAA4B40
94461	7	61	207	2934	65395	\N	55.480688999999998	Республика Башкортостан, Кигинский район, Душанбековский сельсовет, леревня Тукаево, Центральная, 31		0101000020E6100000462234828D434D400246973787BD4B40
22495	7	61	207	2934	65395	\N	55.4805404671582	с.Тукаево, Центральная, 39	Россия, республика Башкортостан, Кигинский район, село Тукаево	0101000020E6100000C09657AEB7434D40BD35B05582BD4B40
21787	7	61	207	2481	64806	\N	55.318131999999999	Республика Башкортостан, Кигинский район, Арслановский сельсовет, деревня Тугузлы, Советская, 43		0101000020E61000005A2A6F4738614D40D1E7A38CB8A84B40
21786	7	61	207	2424	65958	\N	55.424847999999997	Республика Башкортостан, Кигинский район, Арслановский сельсовет, деревня Сюрбаево, Нагорная, 4		0101000020E610000030D5CC5A0A8A4D40B0E2546B61B64B40
21804	7	61	207	1051	66808	\N	55.578422595997303	РБ, Кигинский район, д. Султановка, ул. Солдатская, д.№82	Россия, республика Башкортостан, Кигинский район, село Султановка	0101000020E61000006022DE3AFF3C4D408A20CEC309CA4B40
21800	7	61	207	3234	66732	\N	55.276471999999998	РБ, Кигинский район, д. Старомухаметово, ул. Советская, д.№18		0101000020E61000005708ABB1843D4D403E213B6F63A34B40
21793	7	61	207	2824	9857	\N	55.452232000000002	Республика Башкортостан, Кигинский район, Душанбековский сельсовет, деревня Сагирово, Новая, 5		0101000020E61000008A929048DB4A4D40331AF9BCE2B94B40
21810	7	61	207	1077	66810	\N	55.541508999999998	РБ, Кигинский район, с. Нижние Киги, ул. 8-Марта, д.№1		0101000020E6100000B8CCE9B298404D40ADBEBA2A50C54B40
94462	7	61	207	3612	66691	\N	55.441606	РБ, Кигинский район, с. Леуза, ул. Ракшина, д.№9		0101000020E6100000AB5D13D21A674D40D3DB9F8B86B84B40
21807	7	61	207	3612	64026	\N	55.441606	Республика Башкортостан, Кигинский район, Леузинский сельсовет, село Леуза, Гагарина, 35		0101000020E6100000AB5D13D21A674D40D3DB9F8B86B84B40
21806	7	61	207	3557	65288	\N	55.368634999999998	Республика Башкортостан, Кигинский район, Леузинский сельсовет, деревня Кургашево, Салавата Юлаева, 15		0101000020E6100000A27F828B15614D409A94826E2FAF4B40
21798	7	61	207	3102	66689	\N	55.174511000000003	РБ, Кигинский район, д. Кульметово, ул. Школьная, д.№10		0101000020E610000024D236FE445B4D4069E55E6056964B40
21785	7	61	207	2344	66702	\N	55.342723999999997	РБ, Кигинский район, д. Кулбаково, ул. Заречная, д.№1		0101000020E610000032C7F2AE7A924D40F3C64961DEAB4B40
21803	7	61	207	3397	65869	\N	55.601436999999997	Республика Башкортостан, Кигинский район, Кандаковский сельсовет, село Кандаковка, Мира, 2		0101000020E61000007DCB9C2E8B3D4D405BCD3AE3FBCC4B40
22257	7	61	207	855	65308	\N	55.372981156678598	д.Идрисово, Школьная, 8	Россия, республика Башкортостан, Кигинский район, село Идрисово	0101000020E6100000725298F7386F4D40C38366D7BDAF4B40
21784	7	61	207	855	66820	\N	55.372984000000002	РБ, Кигинский район, д. Идрисово ул. Молодежная, д.№7		0101000020E61000004CA60A46256F4D4034F790F0BDAF4B40
20491	7	61	207	855	66372	\N	55.372687888410802	Республика Башкортостан, Баймакский район, д.Н.Идрисово, улица С.Юлаева, дом 8/1	Россия, республика Башкортостан, Кигинский район, село Идрисово	0101000020E6100000FA4509FA0B6F4D404ACE893DB4AF4B40
21799	7	61	207	3169	66049	\N	55.319761	Республика Башкортостан, Кигинский район, Ибраевский сельсовет, село Ибраево, Советская, 25		0101000020E6100000700B96EA023A4D40A4C4AEEDEDA84B40
21796	7	61	207	939	66765	\N	55.227294000000001	РБ, Кигинский район, с. Еланлино, ул. Бурхана Шарафутдинова, д.№27		0101000020E61000009F7422C1544D4D40DC4944F8179D4B40
21792	7	61	207	2753	65294	\N	55.441229	Республика Башкортостан, Кигинский район, Душанбековский сельсовет, село Душанбеково, Советская, 44		0101000020E610000078EFA83121404D40FD851E317AB84B40
21788	7	61	207	2537	62323	\N	55.405332000000001	Республика Башкортостан, Кигинский район, Верхнекигинский сельсовет, село Верхние Киги, Советская, 8		0101000020E61000002C6519E2584D4D40DA0242EBE1B34B40
21789	7	61	207	2537	62328	\N	55.405332000000001	"Республика Башкортостан, Кигинский район, Верхнекигинский сельсовет, село Верхние Киги, Салавата, 7""а"""		0101000020E61000002C6519E2584D4D40DA0242EBE1B34B40
21790	7	61	207	2537	63236	\N	55.405332000000001	Республика Башкортостан, Кигинский район, Верхнекигинский сельсовет, село Верхние Киги, Ибрагимова, 19		0101000020E61000002C6519E2584D4D40DA0242EBE1B34B40
21797	7	61	207	3054	66860	\N	55.277180000000001	РБ, Кигинский район, д. Вакиярово, ул. Школьная, д.№47		0101000020E61000001B12F758FA524D407A8D5DA27AA34B40
21783	7	61	207	2242	64766	\N	55.313147000000001	Республика Башкортостан, Кигинский район, Арслановский сельсовет, деревня Асылгужино, Центральная, 18		0101000020E61000005875560BEC894D4096EB6D3315A84B40
21782	7	61	207	2187	65119	\N	55.358013	Республика Башкортостан, Кигинский район, Арслановский сельсовет, село Арсланово, Кирова, 16		0101000020E6100000DC4AAFCDC67E4D407C45B75ED3AD4B40
21780	7	61	207	2070	65116	\N	55.590322	Республика Башкортостан, Кигинский район, Абзаевский сельсовет, деревня Алагузово, Гагарина, 77		0101000020E6100000D0F23CB83B634D40FE0DDAAB8FCB4B40
21779	7	61	207	782	65778	\N	55.597194221345497	РБ, Кигинский район, с. Абзаево, ул. Школьная, д.№4	Россия, республика Башкортостан, Кигинский район, село Абзаево	0101000020E6100000FEB5BC72BD574D4008AF5DDA70CC4B40
21748	7	61	64	154	66091	\N	54.363208	деревня Шарипкулово, Школьная, 17/1		0101000020E6100000DCF29194F4244C40A2D288997D2E4B40
21759	7	61	64	851	64837	\N	54.320042000000001	деревня Утяганово, Идель, 30	Россия, республика Башкортостан, Кармаскалинский район, село Утяганово	0101000020E61000008257CB9D993A4C4058ACE122F7284B40
21747	7	61	64	79	66649	\N	54.397790000000001	Република Башкортостан, Кармаскалинский район, деревня Урал, Центральная, 21		0101000020E6100000E6779ACC781F4C40825660C8EA324B40
21745	7	61	64	32439	63777	\N	54.430736000000003	Адрес помещения для голосования: деревня Улукулево, улица К. Маркса, дом 101, Адрес УИК: улица К. Маркса, дом 64		0101000020E61000003FADA23F34294C40DD9A745B22374B40
21746	7	61	64	32439	63429	\N	54.430736000000003	Адрес помещения для голосования: деревня Улукулево, улица 60 лет Октября, дом 82А, Адрес УИК: улица К. Маркса, дом 64		0101000020E61000003FADA23F34294C40DD9A745B22374B40
21772	7	61	64	1601	65585	\N	54.441910999999998	деревня Старошареево, Новая, 31		0101000020E610000039252026E13A4C400F5F268A90384B40
21776	7	61	64	32827	64539	\N	54.349429999999998	деревня Старомусино, Молодежная, 3	Россия, республика Башкортостан, Кармаскалинский район, село Старомусино	0101000020E6100000DCF0BBE996F74B40E21E4B1FBA2C4B40
21771	7	61	64	1545	65960	\N	54.456003000000003	деревня Староакташево, Школьная, 4		0101000020E61000007A51BB5F05384C405FF0694E5E3A4B40
21741	7	61	64	58877	66827	\N	54.505330000000001	Република Башкортостан, Кармаскалинский район, село Сихонкино, Школьная, 8		0101000020E61000005167EE21E1014C4006D847A7AE404B40
21770	7	61	64	1481	64328	\N	54.430799	Адрес помещения для голосования: деревня Сахаево, улица Шоссейная, дом 3, Адрес УИК: улица Шоссейная, дом 1		0101000020E6100000D6E1E82ADD2F4C402313F06B24374B40
21758	7	61	64	793	64001	\N	54.362631	село Сарт-Чишма, Школьная, 45а		0101000020E610000066101FD8F1394C4005C24EB16A2E4B40
22865	7	61	64	58572	65583	\N	54.430046895792003	д.Сарсаз, Центральная, 8	Россия, республика Башкортостан, Кармаскалинский район, село Сарсаз	0101000020E61000002D5BEB8B84FA4B40185FB4C70B374B40
21767	7	61	64	32746	64211	\N	54.470064999999998	село Савалеево, Мира, 4		0101000020E6100000E7E104A6D31E4C4043FF04172B3C4B40
21757	7	61	64	717	64254	\N	54.337741000000001	село Новые Киешки, Б.Батыровой, 11		0101000020E6100000DDCEBEF220374C4059C2DA183B2B4B40
21754	7	61	64	45944	64516	\N	54.463948000000002	деревня Николаевка, 50 лет Октября, 9а	Россия, республика Башкортостан, Кармаскалинский район, село Николаевка	0101000020E61000004034F3E49A124C40B685E7A5623B4B40
21735	7	61	64	47689	65687	\N	54.247959999999999	деревня Никитино, Центральная, 16		0101000020E61000009E7C7A6CCBCC4B40AB5B3D27BD1F4B40
21755	7	61	64	603	66279	\N	54.307079999999999	деревня Мукаево, Центральная, 31		0101000020E6100000AF2479AEEF254C40BAA0BE654E274B40
21743	7	61	64	32354	65077	\N	54.260598999999999	деревня Малаево, Центральная, 12		0101000020E6100000952D9276A3354C40662FDB4E5B214B40
21733	7	61	64	31912	66077	\N	54.380358999999999	деревня Кустугулово, Центральная, 70		0101000020E610000015580053062C4C40A0DE8C9AAF304B40
21749	7	61	64	206	63676	\N	54.368521999999999	село Кармаскалы, Советская, 33		0101000020E6100000768A558330174C40A2ED98BA2B2F4B40
21750	7	61	64	206	63677	\N	54.368371279899897	Адрес помещения для голосования: село Кармаскалы, улица Садовая, дом 25, Адрес УИК: улица Худайбердина, дом 10	Россия, республика Башкортостан, Кармаскалинский район, село Кармаскалы	0101000020E6100000ED4ACB48BD174C40BDE5EAC7262F4B40
21751	7	61	64	206	63667	\N	54.368521999999999	село Кармаскалы, Парковая, 7		0101000020E6100000768A558330174C40A2ED98BA2B2F4B40
21773	7	61	64	1651	64658	\N	54.246834	деревня Карламанбаш, Центральная, 31		0101000020E61000001B84B9DDCB0D4C403BC5AA41981F4B40
21752	7	61	64	439	65678	\N	54.314391000000001	деревня Карламан, Ш. Биккула, 30		0101000020E61000006C5CFFAECF104C401094DBF63D284B40
21742	7	61	64	32293	65073	\N	54.243124999999999	Адрес помещения для голосования: село Камышлинка, улица Школьная, дом 46, Адрес УИК: улица Шоссейная, дом 17		0101000020E610000057B3CEF8BE2A4C4085EB51B81E1F4B40
21777	7	61	64	1890	66726	\N	54.417625000000001	Република Башкортостан, Кармаскалинский район, село Ильтеряково, Школьная, 1		0101000020E6100000028063CF9E034C40FA7E6ABC74354B40
21738	7	61	64	32119	66636	\N	54.266762999999997	Република Башкортостан, Кармаскалинский район, село Ефремкино, Ленина, 19		0101000020E61000003A419B1C3E214C4034643C4A25224B40
21613	7	61	64	49514	66268	\N	54.299078000000002	Восток деревня, Восточная, 52		0101000020E6100000EC1516DC0FFE4B40FF791A3048264B40
21736	7	61	64	32032	63427	\N	54.292856999999998	село Бузовьязы, Советская, 1		0101000020E6100000054D4BAC8CE84B40CCB392567C254B40
21765	7	61	64	1204	64137	\N	54.452747000000002	деревня Бишаул-Унгарово, Школьная, 17		0101000020E6100000D61F6118B0224C405A2E1B9DF3394B40
21734	7	61	64	31966	64069	\N	54.322327000000001	Адрес помещения для голосования: село Адзитарово, улица Коммунистическая, дом 32в, Адрес УИК: улица Коммунистическая, дом 31в		0101000020E610000002BB9A3C65D54B4014CFD90242294B40
21700	7	61	518	30299	65148	\N	55.563864000000002	д.Янбак, Школьная, 12		0101000020E61000009E5E29CB106D4C4025B20FB22CC84B40
21719	7	61	518	58600	65688	\N	55.872155749718097	д.Якупово, Дружбы, 1	Россия, республика Башкортостан, Караидельский район, село Якупово	0101000020E61000009D6516A1D85E4C404D81CCCEA2EF4B40
21732	7	61	518	31841	65481	\N	55.780242999999999	д.Явгильдино, Центральная, 15		0101000020E610000033349E08E23A4C406AF7AB00DFE34B40
94460	7	61	518	5517	66597	\N	55.600593000000003	РБ,Караидельский район, д. Шамратово, ул. Садовая, 2		0101000020E6100000F1F5B52E35924C40709A3E3BE0CC4B40
21726	7	61	518	47526	65732	\N	55.686309999999999	д.Чебыково, Школьная, 24		0101000020E6100000B4AED172A0674C4079758E01D9D74B40
22152	7	61	518	47526	65860	\N	55.686408870612297	д. Чебыково, Ленина, 40	Россия, республика Башкортостан, Караидельский район, село Чебыково	0101000020E6100000006F8104C5674C400C570740DCD74B40
21693	7	61	518	29944	66235	\N	55.939014999999998	д.Чапаш, ул.Центральная, 20		0101000020E61000000ED76A0F7B7D4C400ABABDA431F84B40
21717	7	61	518	58735	66275	\N	55.900571999999997	д.Халилово, Школьная, 1	Россия, республика Башкортостан, Караидельский район, село Халилово	0101000020E61000009818CBF44B5A4C40BED87BF145F34B40
21651	7	61	706	28041	64745	\N	55.796466000000002	деревня Чумара, Центральная, 18		0101000020E6100000BE8575E3DD634B401F300F99F2E54B40
21727	7	61	518	58766	66409	\N	55.626976991989302	д.Урюш-Битуллино, Трактовая, 1	Россия, республика Башкортостан, Караидельский район, село Урюш-Битуллино	0101000020E6100000EE96E4805D434C400E2C47C840D04B40
21716	7	61	518	58518	65478	\N	55.6113678405627	д.Уразаево, Центральная, 4	Россия, республика Башкортостан, Караидельский район, село Уразаево	0101000020E6100000730F09DFFB234C4014E97E4E41CE4B40
20620	7	61	518	58518	65312	\N	55.611124931420498	д.Уразаево, Центральная, 5	Россия, республика Башкортостан, Караидельский район, село Уразаево	0101000020E61000009C8BBFED09244C404E62105839CE4B40
21720	7	61	518	31290	65223	\N	55.902670999999998	д.Тегерменево, Центральная, 16		0101000020E61000005A68E7340B544C4018062CB98AF34B40
21731	7	61	518	31817	65115	\N	55.799553000000003	д.Тайкаш, Хамзи Исламова, 40		0101000020E61000003B8C497F2F2F4C409835B1C057E64B40
22580	7	61	518	8483	66042	\N	55.729716000000003	Суюндюково, Таулы, 7		0101000020E6100000778368AD68394C4019AF795567DD4B40
21703	7	61	518	8483	66267	\N	55.729815845395798	д.Суюндюково, Суюндюковская, 30	Россия, республика Башкортостан, Караидельский район, село Суюндюково	0101000020E61000002DAF5C6F9B394C407C0C569C6ADD4B40
21694	7	61	518	30006	65107	\N	55.885156000000002	д.Старые Багазы, Центральная, 14		0101000020E61000004D6551D845714C40D9EDB3CA4CF14B40
21682	7	61	518	29442	66244	\N	55.883000000000003	д.Старооткустино, Центральная, 23		0101000020E6100000247D5A457F424C401B2FDD2406F14B40
21728	7	61	518	46743	66063	\N	55.583974966357196	д.Седяш-Нагаево, Хайруллина, 2	Россия, республика Башкортостан, Караидельский район, село Седяш	0101000020E6100000B5DE6FB4E3404C403F575BB1BFCA4B40
21688	7	61	518	46743	65175	\N	55.436881999999997	д.Седяш, Речная, 30		0101000020E610000021CA17B490364C40041BD7BFEBB74B40
21760	7	61	518	30993	63758	\N	55.682392	Адрес помещения для голосования: село Подлубово, улица Советская, дом 42, Адрес УИК: улица Школьная, дом 35		0101000020E6100000EA7AA2EBC2254C40A986FD9E58D74B40
21714	7	61	518	30993	66892	\N	55.682392	РБ,Караидельский район, д. Подлубово, ул.Дружбы,15		0101000020E6100000EA7AA2EBC2254C40A986FD9E58D74B40
21710	7	61	518	46570	66360	\N	56.035487000000003	д.Озерки, Набережная, 19	Россия, республика Башкортостан, Караидельский район, село Озерки	0101000020E610000082C7B7770DB84C40723788D68A044C40
21706	7	61	518	30584	66274	\N	55.624966999999998	д.Новый Бердяш, ул.Центральная, 24		0101000020E610000032FFE89B348F4C40240A2DEBFECF4B40
21687	7	61	518	29646	65084	\N	55.709809	д.Новоянсаитово, Центральная, 15		0101000020E6100000AB967494836D4C4007B47405DBDA4B40
21709	7	61	518	30730	65094	\N	55.950121000000003	с.Новомуллакаево, Центральная, 6		0101000020E6100000E6CAA0DAE08C4C40151F9F909DF94B40
21692	7	61	518	29899	65090	\N	55.885781999999999	д.Нижние Балмазы, Школьная, 37		0101000020E6100000C7B94DB857804C4057B1F84D61F14B40
21715	7	61	518	31030	64666	\N	55.605110360782298	д,Нагретдиново, Центральная, 18	Россия, республика Башкортостан, Караидельский район, село Нагретдиново	0101000020E6100000E2B034F0A3284C40C53D963E74CD4B40
21730	7	61	518	31760	65512	\N	55.669680999999997	д.Мрясимово, Центральная, 3		0101000020E610000052D158FB3B3D4C4054E0641BB8D54B40
21704	7	61	518	30492	62322	\N	55.761284000000003	с.Магинск, Октябрьская, 22		0101000020E61000004E999B6F447B4C40EA7B0DC171E14B40
21701	7	61	518	30319	65089	\N	55.715955999999998	д.Куртлыкуль, Мира, 47		0101000020E6100000E57B4622342E4C40FFAF3A72A4DB4B40
21711	7	61	518	30835	65097	\N	55.995272	с.Круш, Центральная, 29	Россия, республика Башкортостан, Караидельский район, село Круш	0101000020E6100000376C5B94D9B64C40F04FA91265FF4B40
21729	7	61	518	31736	66282	\N	55.634912999999997	с.Красный Урюш, Школьная, 19		0101000020E6100000DF3312A1113A4C40126745D444D14B40
21697	7	61	518	47644	65436	\N	55.702829999999999	с.Комсомольский, Почтовая, 3	Россия, республика Башкортостан, Караидельский район, село Комсомольский	0101000020E6100000A7406667D1914C40E7525C55F6D94B40
21698	7	61	518	29166	9836	\N	55.613523999999998	РБ, Караидельский район, с. Кирзя, ул. Центральная, 29		0101000020E6100000726C3D4338644C40D2A755F487CE4B40
21695	7	61	518	32979	64018	\N	55.700623	с.Караяр, Советская, 16		0101000020E6100000DBC4C9FD0E834C40A7E9B303AED94B40
21690	7	61	518	29756	63449	\N	55.839871000000002	с.Караидель (мкр.Молодежный), Мира, 13/1		0101000020E610000009168733BF724C40EEED96E480EB4B40
21689	7	61	518	29756	63493	\N	55.839871000000002	с.Караидель, Ленина, 9		0101000020E610000009168733BF724C40EEED96E480EB4B40
21645	7	61	518	3167	63505	\N	55.558829000000003	с.Калтасы, ул.Карла Маркса, 64	Россия, республика Башкортостан, Караидельский район, село Калтасы	0101000020E6100000406CE9D1543B4C4038876BB587C74B40
21644	7	61	518	3167	63505	\N	55.558829000000003	село Калтасы, Карла Маркса, 74		0101000020E6100000406CE9D1543B4C4038876BB587C74B40
21723	7	61	518	47471	64913	\N	55.743841000000003	д.Зуевка, Центральная, 3		0101000020E61000003C33C170AE5F4C404436902E36DF4B40
21725	7	61	518	58573	65589	\N	55.645232	д.Дубровка, пер.Школьный, 3	Россия, республика Башкортостан, Караидельский район, село Дубровка	0101000020E6100000DA39CD02ED4E4C40952A51F696D24B40
21702	7	61	518	47028	65162	\N	55.727702467373497	д.Деушево, Лесная, 12	Россия, республика Башкортостан, Караидельский район, село Деушево	0101000020E61000000A698D41272A4C40ED9DD15625DD4B40
21686	7	61	518	17180	66586	\N	55.791839371734802	д.Бердяш, Центральная, 1	Россия, республика Башкортостан, Караидельский район, село Бердяш	0101000020E6100000F3380CE6AF784C404359F8FA5AE54B40
21713	7	61	518	47252	66281	\N	55.807778667228497	д.Бартым, Лесная, 6/2	Россия, республика Башкортостан, Караидельский район, село Бартым	0101000020E6100000F7393E5A9CBF4C40A2B2614D65E74B40
21683	7	61	518	29473	63445	\N	55.807248000000001	с.Байкибашево, ул.Корочкина, 84		0101000020E610000010C99063EB494C4076E107E753E74B40
94458	7	61	518	5011	66879	\N	55.880076000000003	РБ,Караидельский район, д.Байки-Юнусово ул. Центральная , 12		0101000020E61000007ADE8D05854D4C404CFF9254A6F04B40
21685	7	61	518	29568	66731	\N	55.840113000000002	РБ,Караидельский район, с.Байки, ул. Ленина, 52		0101000020E6100000C5AD8218E8684C40E4F8A1D288EB4B40
21699	7	61	518	46968	66140	\N	55.574751999999997	с.Атамановка, Школьная, 11/3		0101000020E610000078F01307D0594C40C1A7397991C94B40
21691	7	61	518	29851	64373	\N	55.82132	с.Абызово, Лежнина, 19		0101000020E6100000234E27D9EA764C407EC6850321E94B40
21681	7	61	518	29375	65227	\N	55.828789	д.Абуталипово, Ленина, 10		0101000020E6100000E88711C2A3354C406C2409C215EA4B40
21657	7	61	706	28301	64800	\N	56.092525999999999	деревня Чилибеево, Пеледыш, 32	Россия, республика Башкортостан, Калтасинский район, село Чилибеево	0101000020E610000062F88898123B4B40CD0358E4D70B4C40
21663	7	61	706	28561	65670	\N	56.048454999999997	деревня Тюльди, Центральная, 69		0101000020E61000001CB5C2F4BD6E4B40F12900C633064C40
21665	7	61	706	28546	66775	\N	56.089488000000003	д.Старый Орьебаш, ул.Комсомольская, 18		0101000020E610000039D4EFC2D65C4B4036B1C057740B4C40
21646	7	61	706	58826	66532	\N	55.9707883914731	деревня Старые Калтасы, Центральная, 8		0101000020E61000001D0247020D6A4B40B4ACFBC742FC4B40
21669	7	61	706	28872	65673	\N	56.035637000000001	деревня Старояшево, Садовая, 10		0101000020E6100000BA1457957DAB4B4087C3D2C08F044C40
20607	7	61	706	58525	65347	\N	56.095610509092197	д.Норкино, Ленина, 7	Россия, республика Башкортостан, Калтасинский район, село Норкино	0101000020E6100000D6AC33BE2F384B40A51133FB3C0C4C40
21666	7	61	706	28727	66262	\N	55.981389	деревня Новокильбахтино, Ленина, 18		0101000020E61000004E97C5C4E6934B40BBD39D279EFD4B40
21660	7	61	706	28455	65470	\N	55.980758999999999	деревня Нижний Качмаш, Гагарина, 39 А		0101000020E6100000D40AD3F71A5C4B40FB20CB8289FD4B40
21650	7	61	706	58393	64902	\N	55.853040999999997	село Надеждино, Центральная, 4	Россия, республика Башкортостан, Калтасинский район, село Надеждино	0101000020E61000003A1F9E25C8704B40D5928E7230ED4B40
21833	7	61	706	58099	63306	\N	55.961629611005201	с.Куяново, Танып, 57	Россия, республика Башкортостан, Калтасинский район, село Куяново	0101000020E610000087DC0C37E08B4B401E6D1CB116FB4B40
21832	7	61	706	58099	63306	\N	55.959896351919397	с.Куяново, Танып, 44	Россия, республика Башкортостан, Калтасинский район, село Куяново	0101000020E610000012A0A696AD8B4B40D6C743DFDDFA4B40
21668	7	61	706	28809	65671	\N	55.998106	село Кучаш, Школьная, 9		0101000020E61000006F4A79AD84A24B407FF8F9EFC1FF4B40
21654	7	61	706	28179	64479	\N	55.994844000000001	село Кутерем, Нефтяников, 6		0101000020E6100000A7EB89AE0B434B40984F560C57FF4B40
21673	7	61	706	29030	66239	\N	55.872228605984503	деревня Кугарчино, Нагорная, 7	Россия, республика Башкортостан, Калтасинский район, село Кугарчино	0101000020E6100000494C50C3B78A4B40B7CF2A33A5EF4B40
21679	7	61	706	4918	63486	\N	55.986606000000002	село Краснохолмский, Юбилейная, 2		0101000020E610000030849CF7FF854B40C904FC1A49FE4B40
21677	7	61	706	4918	63490	\N	55.986606000000002	село Краснохолмский, Тимиряя, 1 А		0101000020E610000030849CF7FF854B40C904FC1A49FE4B40
21678	7	61	706	4918	63441	\N	55.986606000000002	село Краснохолмский, Стадионная, 7		0101000020E610000030849CF7FF854B40C904FC1A49FE4B40
21674	7	61	706	4918	66861	\N	55.986606000000002	с.Краснохолмский, ул.Парковая, 1		0101000020E610000030849CF7FF854B40C904FC1A49FE4B40
21661	7	61	706	28475	64646	\N	55.986001999999999	деревня Кокуш, Пушкина, 16		0101000020E61000002387889B53574B4032E5435035FE4B40
21672	7	61	706	29013	65224	\N	55.960155	деревня Качкинтурай, В.Абдуллина, 16		0101000020E610000045D4449F8F964B40A20BEA5BE6FA4B40
20854	7	61	706	48421	66322	\N	56.012681999999998	с.Каменка, Школьная, 13		0101000020E610000047CB811E6A4F4B40BA9F53909F014C40
21648	7	61	706	27922	65117	\N	55.894706999999997	деревня Калмиябаш, Молодежная, 16		0101000020E6100000363AE7A738784B404A404CC285F24B40
21656	7	61	706	28265	65225	\N	56.093806999999998	деревня Калегино, Советская, 18 А		0101000020E6100000726A6798DA464B40649126DE010C4C40
21653	7	61	706	28112	65125	\N	55.926625567881203	деревня Графское, Мира, 40 А	Россия, республика Башкортостан, Калтасинский район, село Графское	0101000020E610000010B056ED9A3A4B40C8CF46AE9BF64B40
21662	7	61	706	28544	65668	\N	56.014271999999998	деревня Верхний Качмаш, Кирова, 29		0101000020E6100000C3D84290835A4B40CF9F36AAD3014C40
21652	7	61	706	28095	64442	\N	55.965975	деревня Большой Кельтей, Советская, 21А		0101000020E61000008597E0D407464B4076E09C11A5FB4B40
21664	7	61	706	28642	64788	\N	56.033324	деревня Большетуганеево, Кооперативная, 1 А		0101000020E6100000F0E0270EA0694B400116F9F543044C40
21675	7	61	706	29140	65746	\N	56.017729000000003	деревня Большекуразово, Центральная, 2		0101000020E61000002C9ACE4E067B4B406C98A1F144024C40
21671	7	61	706	28951	64411	\N	55.920375999999997	деревня Большекачаково, Советская, 65 А		0101000020E61000001310937021954B40FB027AE1CEF54B40
22864	7	61	706	47282	65904	\N	55.928561999999999	с.Барсуково, Школьная, 10А		0101000020E6100000297B4B395F624B4078279F1EDBF64B40
21649	7	61	706	58296	64604	\N	55.896191055241502	деревня Бабаево, Центральная, 1	Россия, республика Башкортостан, Калтасинский район, село Бабаево	0101000020E61000000B42791F47854B401AFCFD62B6F24B40
21658	7	61	706	28338	66258	\N	56.062669999999997	деревня Амзибаш, Дружбы, 3		0101000020E6100000D13E56F0DB4E4B405C38109205084C40
21670	7	61	706	28925	66234	\N	55.9946087348848	село Актуганово, Дорожная, 1	Россия, республика Башкортостан, Калтасинский район, село Актуганово	0101000020E610000029266F8099A74B4054A703594FFF4B40
21610	7	61	300	26166	65105	\N	53.502834	Яр-Бишкадак деревня, Береговая, 29		0101000020E610000074B2D47ABF034C408FA850DD5CC04A40
21620	7	61	300	32638	66851	\N	53.686888699478303	с.Янурусово, ул.Пролетарская,14а	Россия, республика Башкортостан, Ишимбайский район, село Янурусово	0101000020E61000000CCEE0EF172D4C40B77D8FFAEBD74A40
22336	7	61	300	58917	67019	\N	53.566216060928397	д. Шиханы, ул. Центральная 2а	Россия, республика Башкортостан, Ишимбайский район, село Шихан	0101000020E6100000BB7F2C44870A4C40683C11C479C84A40
20142	7	61	300	58129	63781	\N	53.651766000000002	Республика Башкортостан, город Стерлитамак, пос. Шахтау, ул. Российская, 9	Россия, республика Башкортостан, Ишимбайский район, Шахтау	0101000020E610000094A46B26DF084C4087527B116DD34A40
21611	7	61	300	26187	64187	\N	53.527196000000004	Урман-Бишкадак село, Центральная, 20Г		0101000020E6100000D06394675E0A4C40804A95287BC34A40
21637	7	61	300	27383	66685	\N	53.332434999999997	д.Уразбаево,ул. Октября, 17		0101000020E6100000A6EF3504C72B4C40DB85E63A8DAA4A40
21618	7	61	300	26534	65843	\N	53.537964000000002	Тимашевка деревня, Партизанская, 49		0101000020E610000047C7D5C8AE2A4C4072361D01DCC44A40
21641	7	61	300	27597	66247	\N	53.303403000000003	Скворчиха село, Школьная, 6		0101000020E610000037DE1D19AB0F4C401041D5E8D5A64A40
21632	7	61	300	21549	66828	\N	53.446942	с.Сайраново,ул.Надыршина,18		0101000020E6100000F94B8BFA24334C40BB9A3C6535B94A40
22252	7	61	300	58559	65504	\N	53.573532452830896	с.Павловка, Электрофикации, 40	Россия, республика Башкортостан, Ишимбайский район, село Павловка	0101000020E6100000D23AAA9A20364C40D09A1F7F69C94A40
21625	7	61	300	58136	63826	\N	53.57799201393	Кулгуна село, Школьная, 19	Россия, республика Башкортостан, Ишимбайский район, село Кулгунино	0101000020E61000002BF9D85DA0784C40C1AC50A4FBC94A40
21630	7	61	300	27096	66881	\N	53.563375000000001	с.Кузяново, ул.Советская,46		0101000020E61000001B8524B37A3D4C40273108AC1CC84A40
21642	7	61	300	27649	66914	\N	53.294125000000001	д.Кинзекеево, ул.Первомайская, 11		0101000020E6100000C3633F8BA5064C40CFF753E3A5A54A40
21639	7	61	300	27509	66678	\N	53.403968999999996	с.Кинзебулатово,ул.1 Мая,20		0101000020E61000007522C15433194C4085CC9541B5B34A40
21612	7	61	300	26249	66589	\N	53.594906000000002	д.Карайганово, ул.Кутушева, 30		0101000020E610000020F0C000C2054C40DB183BE125CC4A40
21615	7	61	300	26385	66855	\N	53.559514	д.Канакаево, ул.Хасанова,55		0101000020E61000005917B7D1001A4C40BBD39D279EC74A40
21596	7	61	300	1315	9703	\N	53.44802	город Ишимбай, Чкалова, 21		0101000020E61000003E5E488787064C401AFA27B858B94A40
21588	7	61	300	1315	9703	\N	53.441665938591903	город Ишимбай, Чкалова, 4	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E61000008C868C47A9064C40A8E0F08288B84A40
21575	7	61	300	1315	63281	\N	53.44802	город Ишимбай, ул.Стахановская, 16		0101000020E61000003E5E488787064C401AFA27B858B94A40
21593	7	61	300	1315	63662	\N	53.44802	город Ишимбай, Советская, 72		0101000020E61000003E5E488787064C401AFA27B858B94A40
21606	7	61	300	1315	63755	\N	53.44802	город Ишимбай, Революционная, 85		0101000020E61000003E5E488787064C401AFA27B858B94A40
21582	7	61	300	1315	63620	\N	53.44802	город Ишимбай, Мичурина, 13		0101000020E61000003E5E488787064C401AFA27B858B94A40
21601	7	61	300	1315	64179	\N	53.44802	город Ишимбай, Ленина проспект, 18А		0101000020E61000003E5E488787064C401AFA27B858B94A40
21581	7	61	300	1315	63524	\N	53.44802	город Ишимбай, Крылова, 31		0101000020E61000003E5E488787064C401AFA27B858B94A40
21548	7	61	300	1315	63731	\N	53.44802	город Ишимбай, Ишимбайская, 32Б		0101000020E61000003E5E488787064C401AFA27B858B94A40
21574	7	61	300	1315	63615	\N	53.44802	город Ишимбай, Заки Валиди бульвар, 5		0101000020E61000003E5E488787064C401AFA27B858B94A40
21576	7	61	300	1315	66783	\N	53.414637682017698	город Ишимбай, пос.Перегонный, ул.Жуковского, 14	Россия, республика Башкортостан, Ишимбайский район, Ишимбай	0101000020E610000032AD4D637B034C40E4D6A4DB12B54A40
21592	7	61	300	1315	63467	\N	53.44802	город Ишимбай, Губкина, 27		0101000020E61000003E5E488787064C401AFA27B858B94A40
21590	7	61	300	1315	63467	\N	53.44802	город Ишимбай, Губкина, 15		0101000020E61000003E5E488787064C401AFA27B858B94A40
21616	7	61	300	32671	66936	\N	53.618462000000001	с.Ишеево,ул.Уразбаевых, 66		0101000020E61000001842CEFBFF104C40CDE847C329CF4A40
21643	7	61	300	27671	64135	\N	53.189408999999998	Верхотор село, Ленина, 43		0101000020E6100000B456B439CE234C40B648DA8D3E984A40
21635	7	61	300	27289	66874	\N	53.377913999999997	с.Верхнеиткулово,ул.Молодежная,2		0101000020E6100000451152B7B3294C40AB59677C5FB04A40
21622	7	61	300	33109	66925	\N	53.694738000000001	д.Вехнеарметово, ул.Слветская,87		0101000020E61000003D635FB2F13E4C40ECA4BE2CEDD84A40
21631	7	61	300	27129	66858	\N	53.465777000000003	д.Биксяново,ул.Селеукская,45		0101000020E61000000053060E68294C40501DAB949EBB4A40
21617	7	61	300	26465	66013	\N	53.574384999999999	Бердышла деревня, Центральная, 11		0101000020E6100000AE62F19BC22E4C400F289B7285C94A40
22910	7	61	300	48168	66059	\N	53.428313000000003	с. Байгузино, Школьная, 22		0101000020E6100000F8A75489B2134C40D0B9DBF5D2B64A40
21640	7	61	300	48168	66357	\N	53.427689146004397	Байгужа деревня, Пионерских лагерей улица, 1А	Россия, республика Башкортостан, Ишимбайский район, село Байгузино	0101000020E61000004AB72572C1134C40F2ED5D83BEB64A40
21614	7	61	300	32623	66901	\N	53.591608999999998	с.Ахмерово, ул.Горная,6		0101000020E61000009817601F9D1A4C407782FDD7B9CB4A40
21626	7	61	300	26923	66593	\N	53.642958999999998	д.Арметрахимово, ул.Центральная,40		0101000020E610000027BC04A73E3A4C409DD5027B4CD24A40
21633	7	61	300	27209	66895	\N	53.495790999999997	д.Аптиково,ул.Салавата Юлаева,47		0101000020E61000009274CDE49B234C405853591476BF4A40
21636	7	61	300	21079	66626	\N	53.406728000000001	д.Азнаево,ул.Гиниятуллина,28		0101000020E610000099620E828E2E4C400A2FC1A90FB44A40
21553	7	61	293	23465	66630	\N	55.307229	Илишевский район, 452269, д.Янтуганово, ул.Центральная, 21		0101000020E6100000A33B889D29324B40FFB0A54753A74B40
21503	7	61	293	6810	66716	\N	55.589005	Илишевский район, Аккузевский сельсовет, д. Шамметово, ул. Центральная, д. 22		0101000020E6100000EAE74D452A104B401A170E8464CB4B40
21509	7	61	293	6991	66899	\N	55.661608000000001	Илишевский район, Базитамакский сельсовет, д.Чуй-Атасево, ул. Чапаева, 9		0101000020E6100000BB270F0BB5444B40D0622992AFD44B40
21549	7	61	293	23290	64937	\N	55.699573000000001	Республика Башкортостан, Илишевский район, Новомедведевский сельсовет, д. Уяндыково, Лесная, 44		0101000020E61000003B6D8D08C62D4B401215AA9B8BD94B40
21519	7	61	293	21938	66725	\N	55.245080999999999	Илишевский район, 452264, д.Урняково, ул.Урняк, 28а		0101000020E610000087DD770C8F214B407CEF6FD05E9F4B40
21530	7	61	293	32541	66841	\N	55.513146999999996	Илишевский район, 452276, д.Улу-Яланово, ул.Лесная, 17а		0101000020E6100000B4E908E066134B402F8507CDAEC14B40
21525	7	61	293	22226	66796	\N	55.5024140963489	Илишевский район, 452277, д.Турачи, ул. Центральная, 52/1	Россия, республика Башкортостан, Илишевский район, село Турачи	0101000020E61000000D198F5209034B40BA86191A4FC04B40
21558	7	61	293	23734	65191	\N	55.269635999999998	Республика Башкортостан, Илишевский район, Урметовский сельсовет, с. Тупеево, Центральная, 8/1		0101000020E6100000EC4D0CC9C9164B4081E9B46E83A24B40
21526	7	61	293	7271	66634	\N	55.415298	Илишевский район, 452277, д.Тукай-Тамаково, ул.Сюнь, 11		0101000020E6100000BF4692205CF54A400F0C207C28B54B40
21532	7	61	293	58849	66580	\N	55.535387060193599	Республика Башкортостан, Илишевский район, Итеевский сельсовет, д.Телпаново, Центральная, 27	Россия, республика Башкортостан, Илишевский район, село Телепаново	0101000020E61000005CC98E8D403E4B400EDAAB8F87C44B40
21529	7	61	293	22398	65850	\N	55.614865999999999	Республика Башкортостан, Илишевский район, Исанбаевский сельсовет, д.Телекеево, Центральная, 24а		0101000020E6100000DFA7AAD040284B400FB6D8EDB3CE4B40
21510	7	61	293	21508	66587	\N	55.603481000000002	Илишевский район, Базитамакский сельсовет, д.Ташкичи, ул. Ленина, 37а		0101000020E6100000EE073C30803C4B40F2608BDD3ECD4B40
21045	7	61	58	10311	64283	\N	55.840871	с. Бураево, М.Гафури, 41		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
21512	7	61	293	7042	66822	\N	55.623620000000003	Илишевский район, 452272, д.Тат.Менеуз, ул.Ворошилова, 18а		0101000020E610000088307E1AF73C4B40D690B8C7D2CF4B40
21543	7	61	293	23006	65580	\N	55.610809000000003	Республика Башкортостан, Илишевский район, Кужбахтинский сельсовет, с. Тазеево, Мостовая, 10		0101000020E6100000261E5036E5464B401E8D43FD2ECE4B40
21552	7	61	293	23436	65858	\N	55.296441000000002	Республика Башкортостан, Илишевский район, Сюльтинский сельсовет, с. Сюльтино, Центральная, 5		0101000020E610000072512D228A354B40C61858C7F1A54B40
21538	7	61	293	22801	66906	\N	55.364266000000001	Илишевский район, 452267, д.Сынгряново, ул. Мухамадиева, 4		0101000020E61000008A558330B7F34A40BA85AE44A0AE4B40
21566	7	61	293	24113	65194	\N	55.742477999999998	Республика Башкортостан, Илишевский район, Ябалаковский сельсовет, с. Старотатышево, Советская, 57		0101000020E6100000AC545051F5194B40EFFFE38409DF4B40
21554	7	61	293	23532	65185	\N	55.463975229740598	Республика Башкортостан, Илишевский район, Старокуктовский сельсовет, с. Старокуктово, Советская, 57	Россия, республика Башкортостан, Илишевский район, село Старокуктово	0101000020E61000008B321B64921D4B40AF94658863BB4B40
21546	7	61	293	23175	65856	\N	55.686010000000003	Республика Башкортостан, Илишевский район, Новомедведевский сельсовет,с. Старокиргизово, Новая, 13		0101000020E61000007B116DC7D4274B404F5DF92CCFD74B40
21536	7	61	293	22702	66043	\N	55.487310000000001	Республика Башкортостан, Илишевский район, Ишкаровский сельсовет, д.Саиткулово, Центральная, 42		0101000020E6100000CCD24ECDE5464B40C381902C60BE4B40
21551	7	61	293	23374	64329	\N	55.356237	Республика Башкортостан, Илишевский район, Рсаевский сельсовет, с. Рсаево, Советская, 4а		0101000020E610000019AA622AFD2E4B4005508C2C99AD4B40
21508	7	61	293	21412	65851	\N	55.623356000000001	Республика Башкортостан, Илишевский район, Базитамакский сельсовет, д.Новонадырово, Титова, 9а		0101000020E61000003D81B053AC424B40F8E12021CACF4B40
21545	7	61	293	23093	65179	\N	55.698984526553801	Республика Башкортостан, Илишевский район, Новомедведевский сельсовет, с.Новомедведево, Школьная, 10	Россия, республика Башкортостан, Илишевский район, село Новомедведево	0101000020E6100000A52DAEF199264B4081B2295778D94B40
21540	7	61	293	22891	66905	\N	55.410586000000002	Илишевский район, 452266, д.Новокуктово ул.Куйбышева, 42		0101000020E6100000749A05DA1D1C4B40051901158EB44B40
21520	7	61	293	21989	66873	\N	55.462293000000003	Илишевский район, 452260, с.Нижнеяркеево, ул.К.Маркса, 6/1		0101000020E6100000BEDA519CA32A4B40BA15C26A2CBB4B40
21559	7	61	293	23745	66046	\N	55.495088000000003	Республика Башкортостан, Илишевский район, Черекулевский сельсовет, с. Нижнечерекулево, Советская, 26		0101000020E6100000F2D3B837BF334B402F52280B5FBF4B40
21506	7	61	293	21325	64761	\N	55.685630000000003	Республика Башкортостан, Илишевский район, Андреевский сельсовет, д. Марино, Чапаева, 21		0101000020E610000000FF942A51404B4008944DB9C2D74B40
21513	7	61	293	21645	66826	\N	55.647624999999998	Илишевский район, 452272, д.Мари-Менеуз, ул. Ленина, 18		0101000020E6100000E8A4F78DAF3F4B4037894160E5D24B40
21516	7	61	293	21811	65848	\N	55.316538999999999	Республика Башкортостан, Илишевский район, Бишкураевский сельсовет, д. Мало-Бишкураево, Х.Гильданова, 28		0101000020E6100000A8380EBC5A484B404B74965984A84B40
21535	7	61	293	22680	66041	\N	55.471024999999997	Республика Башкортостан, Илишевский район, Ишкаровский сельсовет, д. Лаяшты, Кооперативная, 40		0101000020E610000081B22957784D4B40984C158C4ABC4B40
21542	7	61	293	22957	64926	\N	55.592551	Республика Башкортостан, Илишевский район, Кужбахтинский сельсовет, с. Кужбахты, Шоссейная, 10		0101000020E6100000F6B52E3542474B40261B0FB6D8CB4B40
21550	7	61	293	23346	65859	\N	55.656036999999998	Республика Башкортостан, Илишевский район, Новомедведевский сельсовет, д. Красноярово, Молодежная, 28		0101000020E6100000E8F86871C6284B40A4FB3905F9D34B40
21502	7	61	293	58913	67012	\N	55.5657674508277	Илишевский район, д.Кипчаково, ул. Центральная, 12	Россия, республика Башкортостан, Илишевский район	0101000020E61000007442E8A04B0C4B40F913950D6BC84B40
21539	7	61	293	22815	65189	\N	55.394309326613197	Республика Башкортостан, Илишевский район, Карабашевский сельсовет, с. Карабашево, Мира, 47	Россия, республика Башкортостан, Илишевский район, село Карабашево	0101000020E6100000B7973446EB164B405DC2A1B778B24B40
21537	7	61	293	22748	66695	\N	55.361973999999996	Илишевский район, 452267, с.Кадырово, ул.Центральная, 34	Россия, республика Башкортостан, Илишевский район, село Кадырово	0101000020E61000000C5872158B034B404B00FE2955AE4B40
21541	7	61	293	22934	65852	\N	55.378732999999997	Республика Башкортостан, Илишевский район, Карабашевский сельсовет, д. Иштеряково, Пионерская, 5		0101000020E610000016C3D50110194B403E75AC527AB04B40
21534	7	61	293	22642	64155	\N	55.476939000000002	Республика Башкортостан, Илишевский район, Ишкаровский сельсовет, с. Ишкарово, Ленина, 42		0101000020E61000008869DFDC5F434B40EE974F560CBD4B40
21531	7	61	293	22479	64930	\N	55.519990861219803	Республика Башкортостан, Илишевский район, Итеевский сельсовет, с. Итеево, Советская, 54	Россия, республика Башкортостан, Илишевский район, село Итеево	0101000020E6100000723788D68A3A4B406F9BA9108FC24B40
21528	7	61	293	22347	65070	\N	55.557662999999998	Республика Башкортостан, Илишевский район, Исанбаевский сельсовет, с. Исанбаево, Школьная, 33а		0101000020E61000004B1DE4F5601C4B4039984D8061C74B40
22918	7	61	293	22347	65245	\N	55.5579549830871	с. Исанбаево, Центральная, 28	Россия, республика Башкортостан, Илишевский район, село Исанбаево	0101000020E6100000ED0DBE30991C4B40E1D1C6116BC74B40
21524	7	61	293	7192	66769	\N	55.462834000000001	Илишевский район, 452277, с.Исаметово, ул. Шоссейная, 10/1		0101000020E610000080B8AB5791074B400ABDFE243EBB4B40
20980	7	61	58	10311	62317	\N	55.840871	с. Бураево, Ленина, 16		0101000020E610000039B709F7CAB44B40D19332A9A1EB4B40
21564	7	61	293	23993	65579	\N	55.629862000000003	Республика Башкортостан, Илишевский район, Ябалаковский сельсовет, с. Илишево, Советская, 32		0101000020E61000004835ECF7C4184B40207F69519FD04B40
21556	7	61	293	58862	66617	\N	55.5233508835151	Республика Башкортостан, Илишевский район, Старокуктовский сельсовет, д. Ибрагим, Победы, 1	Россия, республика Башкортостан, Илишевский район, село 5-й Участок	0101000020E6100000D5777E5182224B4019AA622AFDC24B40
21527	7	61	293	7297	66923	\N	55.480683999999997	Илишевский район, 452277, д.Зяйлово, ул.Береговая, 31/1		0101000020E61000007C7C4276DE044B40F0DAA50D87BD4B40
21517	7	61	293	7085	66933	\N	55.253045604740699	Илишевский район, 452264, с.Стародюмеево, ул. Советская, 3а	Россия, республика Башкортостан, Илишевский район, село Дюмеево	0101000020E610000032207BBDFB2B4B401A31B3CF63A04B40
21547	7	61	293	23219	66660	\N	55.699359999999999	Илишевский район, 452274, д.Груздевка, ул.Новая, 1		0101000020E6100000A4349BC761284B40B610E4A084D94B40
21544	7	61	293	23077	66045	\N	55.624017000000002	Республика Башкортостан, Илишевский район, Кужбахтинский сельсовет, д. Гремучий Ключ, Родниковая, 4		0101000020E61000001C075E2D77504B40F392FFC9DFCF4B40
21565	7	61	293	58649	65868	\N	55.687188463302597	Республика Башкортостан, Илишевский район, Ябалаковский сельсовет, д. Верхнее Юлдашево, Чеверева, 1	Россия, республика Башкортостан, Илишевский район, село Верхние Юлдашево	0101000020E6100000C685032159224B40111AC1C6F5D74B40
21572	7	61	293	1272	63752	\N	55.446421999999998	Республика Башкортостан, Илишевский район, Яркеевский сельсовет, с. Верхнеяркеево, Советская, 42		0101000020E610000065FD6662BA284B40821B295B24B94B40
21568	7	61	293	1272	63752	\N	55.446421999999998	Республика Башкортостан, Илишевский район, Яркеевский сельсовет, с. Верхнеяркеево, Советская, 31		0101000020E610000065FD6662BA284B40821B295B24B94B40
21570	7	61	293	1272	66638	\N	55.446421999999998	Илишевский район, 452260, с.Верхнеяркеево, ул.Молодежная, 18		0101000020E610000065FD6662BA284B40821B295B24B94B40
21571	7	61	293	1272	66744	\N	55.451446460872297	Илишевский район, 452260, с.Верхнеяркеево, ул.Матросова 38/1	Россия, республика Башкортостан, Илишевский район, село Верхнеяркеево	0101000020E610000027FA7C9411294B407BF486FBC8B94B40
21567	7	61	293	1272	63463	\N	55.446421999999998	Республика Башкортостан, Илишевский район, Яркеевский сельсовет, с. Верхнеяркеево, Коммунистическая, 15		0101000020E610000065FD6662BA284B40821B295B24B94B40
21569	7	61	293	1272	63406	\N	55.446421999999998	Республика Башкортостан, Илишевский район, Яркеевский сельсовет, с Верхнеяркеево, 50-лет Октября, 20		0101000020E610000065FD6662BA284B40821B295B24B94B40
21561	7	61	293	58297	64605	\N	55.4055423997969	Республика Башкортостан, Илишевский район, Юнновский сельсовет, с. Юнны, Дорожная, 3	Россия, республика Башкортостан, Илишевский район, село Верхнеюнново	0101000020E6100000605B3FFD67294B40C493DDCCE8B34B40
21560	7	61	293	23807	65866	\N	55.490456999999999	Республика Башкортостан, Илишевский район, Черекулевский сельсовет, д. Верхнечерекулево, Гафури, 24		0101000020E61000002AC76471FF2D4B40118C834BC7BE4B40
21523	7	61	293	22138	65849	\N	55.365008000000003	Республика Башкортостан, Илишевский район, Игметовский сельсовет, с. Верхнеманчарово, Ленина, 6		0101000020E61000004BE7C3B304474B40A2630795B8AE4B40
21533	7	61	293	32505	66036	\N	55.537035740590902	Республика Башкортостан, Илишевский район, Итеевский сельсовет, д.Буралы, Центральная, 33	Россия, республика Башкортостан, Илишевский район, село Буралы	0101000020E610000017BA1281EA314B4028637C98BDC44B40
21514	7	61	293	3813	66030	\N	55.310073000000003	Республика Башкортостан, Илишевский район, Бишкураевский сельсовет, с. Бишкураево, Ленина, 69		0101000020E6100000361E6CB1DB454B40B22FD978B0A74B40
21507	7	61	293	21362	66690	\N	55.646816999999999	Илишевский район, Базитамакский сельсовет, с. Базитамак, ул. Пушкина, д. 16а		0101000020E6100000D3BEB9BF7A444B4098BF42E6CAD24B40
21518	7	61	293	7173	66651	\N	55.276888	Илишевский район, 452264, д.База-Куяново, ул.Чишминская, 38а		0101000020E61000000394861A85284B40D253E41071A34B40
21504	7	61	293	21228	64444	\N	55.696959999999997	Республика Башкортостан, Илишевский район, Андреевский сельсовет, с. Андреевка, Советская, 41		0101000020E6100000EA23F0879F314B40614F3BFC35D94B40
21505	7	61	293	21269	64922	\N	55.708033999999998	Республика Башкортостан, Илишевский район, Андреевский сельсовет, д. Аначево, Свердлова, 37/1		0101000020E61000006005F86EF3344B40603AADDBA0DA4B40
21501	7	61	293	21076	66582	\N	55.556961000000001	Илишевский район, Аккузевский сельсовет, с. Аккузево, ул. Школьная, д. 1		0101000020E61000003AB187F6B1104B40E012807F4AC74B40
21522	7	61	293	27752	66928	\N	55.406666000000001	Илишевский район, 452282, д.Абдулла,ул. Дружбы, 32		0101000020E6100000D2510E66134A4B409432A9A10DB44B40
22533	7	61	877	58808	66505	\N	54.761155608430599	Республика Башкортостан, Уфимский район, д. Ягодная Поляна, Центральная, 1		0101000020E6100000164F3DD2E0364C40BC934F8F6D614B40
21498	7	61	877	20949	63605	\N	54.884576000000003	Республика Башкортостан, Иглинский район, Чуваш-Кубовский сельсовет, с. Чуваш-Кубово, Площадь Октября, 32		0101000020E61000008BA6B393C1494C40CB694FC939714B40
21470	7	61	877	19369	65145	\N	54.562434000000003	Республика Башкортостан, Иглинский район, Акбердинский сельсовет, д. Урунда, Центральная, 7		0101000020E6100000CC99ED0A7D2A4C4049145AD6FD474B40
21467	7	61	877	19223	65149	\N	54.877067557403201	Республика Башкортостан, Иглинский район, Урманский сельсовет, с. Урман, Ленина, 2 а	Россия, республика Башкортостан, Иглинский район, поселок Урман	0101000020E61000008A5759DB146F4C401F2FA4C343704B40
21466	7	61	877	19223	64059	\N	54.873207000000001	Республика Башкортостан, Иглинский район, Урманский сельсовет, с. Урман, Калинина, 12		0101000020E610000060730E9E096F4C40B3D1393FC56F4B40
21464	7	61	877	19059	64374	\N	54.912858	Республика Башкортостан, Иглинский район, Улу-Телякский сельсовет, с. Улу-Теляк, Ленина, 23		0101000020E610000083E0F1ED5D7D4C402CF2EB87D8744B40
21465	7	61	877	19059	64025	\N	54.912858	Республика Башкортостан, Иглинский район, Улу-Телякский сельсовет, с. Улу-Теляк, Коммунистическая, 12		0101000020E610000083E0F1ED5D7D4C402CF2EB87D8744B40
21485	7	61	877	6589	65157	\N	54.803232000000001	Республика Башкортостан, Иглинский район, Лемезинский сельсовет, д. Улу-Карамалы, Пчеловодов, 45		0101000020E6100000F4177AC4E87F4C40E38C614ED0664B40
21494	7	61	877	20734	65846	\N	54.953457999999998	Республика Башкортостан, Иглинский район, Уктеевский сельсовет, с. Уктеево, Центральная, 24		0101000020E6100000718FA50F5D3E4C40060E68E90A7A4B40
21493	7	61	877	20664	64361	\N	54.652921999999997	Республика Башкортостан, Иглинский район, Турбаслинский сельсовет, с. Турбаслы, Центральная, 40/1		0101000020E6100000739D465A2A274C40616BB6F292534B40
21489	7	61	877	20439	65164	\N	54.822760000000002	Республика Башкортостан, Иглинский район, Надеждинский сельсовет,  д. Тикеево, Главная, 20		0101000020E61000006A87BF266B704C407E3A1E3350694B40
20606	7	61	877	48075	65784	\N	54.792546000000002	д.Ташлы-Елга, Центральная, 25		0101000020E610000086C8E9EBF9804C40AE49B72572654B40
21484	7	61	877	7459	66628	\N	54.717385999999998	Иглинский район, Лемезенский сельсовет, д. Тау, ул. Родниковая, д. 45		0101000020E61000007D3ECA880B8A4C40DB4DF04DD35B4B40
21491	7	61	877	20562	63750	\N	54.884255000000003	Республика Башкортостан, Иглинский район, Тавтимановский сельсовет, Тавтиманово, Крупской, 36		0101000020E61000000BB3D0CE69524C40892991442F714B40
21499	7	61	877	7474	66780	\N	54.848686410390002	Иглинский район, Чуваш-Кубовский сельсовет, с. Старокубово, ул. Школьная, д. 10	Россия, республика Башкортостан, Иглинский район, село Старокубово	0101000020E61000002592E86514414C405A492BBEA16C4B40
21496	7	61	877	58817	66520	\N	54.8927948968038	Республика Башкортостан, Иглинский район, Уктеевский сельсовет, с. Сарт-Лобово, Центральная, 44	Россия, республика Башкортостан, Иглинский район, село Саратовская Лобово	0101000020E610000038F581E49D3F4C402384471B47724B40
21487	7	61	877	20306	64915	\N	54.892668999999998	Республика Башкортостан, Иглинский район, Майский сельсовет, д. Расмикеево, Центральная, 18		0101000020E610000068791EDC9D874C40969350FA42724B40
21488	7	61	877	19472	64917	\N	54.746778999999997	Республика Башкортостан, Иглинский район, Надеждинский сельсовет, с. Пятилетка, Центральная, 4		0101000020E610000075CB0EF10F674C40772B4B74965F4B40
21472	7	61	877	19472	65558	\N	54.745555031386502	Республика Башкортостан, Иглинский район, Ауструмский сельсовет, д. Пятилетка, ул. Романовская, 19	Россия, республика Башкортостан, Иглинский район, село Пятилетка	0101000020E610000087C0914083674C40452FA3586E5F4B40
21480	7	61	877	7371	66915	\N	54.699274000000003	Иглинский район, Калтымановский сельсовет, с. Пушкинское, ул. Горького, 20		0101000020E6100000A8C821E2E6424C40B87878CF81594B40
21492	7	61	877	20627	66024	\N	54.938130999999998	Республика Башкортостан, Иглинский район, Тавтимановский сельсовет, д. Покровка, Школьная, 32		0101000020E6100000DEE4B7E864534C40902E36AD14784B40
21623	7	61	877	58105	63399	\N	54.619290999999997	Петровское село, Ленина, 21		0101000020E6100000EFC682C2A0024C4083DA6FED444F4B40
22490	7	61	877	46731	64240	\N	54.7260016710255	с.Первомайское, Садовая, 22	Россия, республика Башкортостан, Иглинский район, село Первомайское	0101000020E61000007E1AF7E6374E4C40516A2FA2ED5C4B40
22732	7	61	877	46731	65646	\N	54.726152999999996	с. Первомайское, Бабича, 13		0101000020E610000043C5387F134E4C403672DD94F25C4B40
22823	7	61	877	28550	65471	\N	55.079447757859903	д.Первомайский, Конторная, 1	Россия, республика Башкортостан, Иглинский район, село Первомайский	0101000020E6100000F25B74B2D4904C40C6DD205A2B8A4B40
21490	7	61	877	20511	64089	\N	54.497995000000003	Республика Башкортостан, Иглинский район, Охлебининский сельсовет, с. Охлебинино, Анискина, 2		0101000020E6100000C959D8D30E2F4C402849D74CBE3F4B40
21500	7	61	877	21036	64920	\N	54.841982999999999	Республика Башкортостан, Иглинский район, Чуваш-Кубовский сельсовет, с. Новокубово, Хисматуллина, 15/1		0101000020E6100000715AF0A2AF464C40DC645419C66B4B40
21483	7	61	877	20055	65841	\N	54.754463999999999	Республика Башкортостан, Иглинский район, Лемезинский сельсовет, с. Нижние Лемезы, Центральная, 39		0101000020E61000002009FB76127F4C403201BF4692604B40
21477	7	61	877	19753	\N	\N	55.070546	Республика Башкортостан, Иглинский район, Красновосходский сельсовет, д. Михайловка	Россия, республика Башкортостан, Иглинский район, село Михайловка	0101000020E610000083A10E2BDC864C408B6EBDA607894B40
21495	7	61	877	20769	64918	\N	54.915765999999998	Республика Башкортостан, Иглинский район, Уктеевский сельсовет, с. Минзитарово, Центральная, 50		0101000020E61000008E75711B0D3C4C40F564FED137754B40
21486	7	61	877	20243	65857	\N	54.861865000000002	Республика Башкортостан, Иглинский район, Майский сельсовет, с. Майский, Центральная, 15		0101000020E6100000529CA38E8E874C409548A297516E4B40
22133	7	61	877	46439	65916	\N	54.657964	с. Ленинское, Новостройка, 5		0101000020E6100000289CDD5A26454C4001F9122A38544B40
21463	7	61	877	18973	64436	\N	54.876769158192701	Республика Башкортостан, Иглинский район, Кудеевский сельсовет, с. Кудеевский, Чапаева, 1	Россия, республика Башкортостан, Иглинский район, поселок Кудеевский	0101000020E6100000EC14AB0661624C40C59272F739704B40
21462	7	61	877	18973	64496	\N	54.877858000000003	Республика Башкортостан, Иглинский район, Кудеевский сельсовет, с. Кудеевский, Пушкина, 2		0101000020E6100000B30B06D7DC614C401844A4A65D704B40
21475	7	61	877	19637	65838	\N	54.973858	Республика Башкортостан, Иглинский район, Красновосходский сельсовет, с. Красный Восход, Молодежная, 41		0101000020E61000002310AFEB17844C4057790261A77C4B40
21497	7	61	877	20880	65184	\N	54.912039999999998	Республика Башкортостан, Иглинский район, Уктеевский сельсовет, с. Кляшево, Школьная, 1		0101000020E610000069C878944A324C4069520ABABD744B40
21481	7	61	877	19954	64027	\N	54.676921113814998	Республика Башкортостан, Иглинский район, Кальтовский сельсовет, с. Кальтовка, Парковая, 20	Россия, республика Башкортостан, Иглинский район, село Кальтовка	0101000020E6100000E9D66B7A50504C40E17CEA58A5564B40
21478	7	61	877	19786	64294	\N	54.717298	Республика Башкортостан, Иглинский район, Калтымановский сельсовет, с. Калтыманово, Школьная, 2		0101000020E6100000F9D7F2CAF5344C403CBEBD6BD05B4B40
21476	7	61	877	19712	65151	\N	54.983989959468097	Республика Башкортостан, Иглинский район, Красновосходский сельсовет, с. Казаяк, Советская	Россия, республика Башкортостан, Иглинский район, село Казаяк	0101000020E610000057CEDE196D8F4C40A7CB6262F37D4B40
21457	7	61	877	18563	63522	\N	54.827620000000003	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Якутова, 23/1		0101000020E6100000570A815CE2344C40FDC1C073EF694B40
21460	7	61	877	18563	63601	\N	54.827620000000003	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Целинная, 2/3		0101000020E6100000570A815CE2344C40FDC1C073EF694B40
21454	7	61	877	18563	64000	\N	54.836538040169202	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Свердлова, 15	Россия, республика Башкортостан, Иглинский район, поселок Иглино	0101000020E61000002DCC423BA7354C403DEE5BAD136B4B40
21455	7	61	877	18563	64309	\N	54.827620000000003	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Революционная, 26		0101000020E6100000570A815CE2344C40FDC1C073EF694B40
21461	7	61	877	18563	63311	\N	54.827620000000003	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Октябрьская, 7		0101000020E6100000570A815CE2344C40FDC1C073EF694B40
21456	7	61	877	18563	63277	\N	54.827620000000003	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Ленина, 149		0101000020E6100000570A815CE2344C40FDC1C073EF694B40
21459	7	61	877	18563	63594	\N	54.837132531845398	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Гражданская, 2	Россия, республика Башкортостан, Иглинский район, поселок Иглино	0101000020E6100000B665C0594A364C4081B3942C276B4B40
21458	7	61	877	18563	63519	\N	54.827620000000003	Республика Башкортостан, Иглинский район, Иглинский сельсовет, с. Иглино, Горького, 45		0101000020E6100000570A815CE2344C40FDC1C073EF694B40
21474	7	61	877	19614	65147	\N	54.605911999999996	Республика Башкортостан, Иглинский район, Ивано-Казанский сельсовет, с. Ивано-Казанка, Центральная, 12		0101000020E6100000D200DE0209364C40812040868E4D4B40
21473	7	61	877	19553	64028	\N	54.772036999999997	Республика Башкортостан, Иглинский район, Балтийский сельсовет, с. Балтика, Центральная, 45		0101000020E61000009641B5C189444C40A626C11BD2624B40
21471	7	61	877	19437	65835	\N	54.810507000000001	Республика Башкортостан, Иглинский район, Ауструмский сельсовет, с. Ауструм, Школьная, 2		0101000020E6100000E38DCC237F604C40EC1681B1BE674B40
21479	7	61	877	19842	64371	\N	54.776913	Республика Башкортостан, Иглинский район, Калтымановский сельсовет, с. Алаторка, Интернациональная, 17		0101000020E61000002EAA4544312F4C402B6B9BE271634B40
21452	7	61	831	18424	64357	\N	52.302861	с.Ямансаз, ул.Центральная, 1		0101000020E6100000A515DF50F8004D40EF1D3526C4264A40
21451	7	61	831	18387	64890	\N	52.212874999999997	д.Юмагужино, ул.Ш.Бабича, 13		0101000020E6100000D926158DB5E14C406891ED7C3F1B4A40
21448	7	61	831	18245	65827	\N	52.446984	Чуюнчи-Чупаново, ул.Акман, 31		0101000020E61000003F1F65C405884C40EAEA8EC536394A40
21446	7	61	831	18131	65154	\N	52.305389098401903	д.Султантимирово, ул.С.Юлаева, 28	Россия, республика Башкортостан, Зилаирский район, село Султантимирово	0101000020E610000034BDC458A6114D4071C79BFC16274A40
21445	7	61	831	58413	64957	\N	52.231494350406201	Старо-Якупово, ул.Дильмухаметова, 7	Россия, республика Башкортостан, Зилаирский район, село Староякупово	0101000020E61000008E91EC116AEC4C40309C6B98A11D4A40
21444	7	61	831	58410	64950	\N	52.170414000000001	д.Сидоровка, ул.Молодёжная, 6	Россия, республика Башкортостан, Зилаирский район, село Сидоровка	0101000020E6100000747973B856FD4C40E9633E20D0154A40
21443	7	61	831	17978	66015	\N	52.197940000000003	д.Саляхово, ул.Муртаева, 25		0101000020E610000005F9D9C875D94C40FE48111956194A40
21441	7	61	831	17890	65830	\N	52.063975999999997	с.Сабырово, ул.Школьная, 1		0101000020E61000004FCDE50643E14C404CDD955D30084A40
21440	7	61	831	58734	66245	\N	52.352913000000001	д.Петровка, ул.Павлова, 9	Россия, республика Башкортостан, Зилаирский район, село Петровка	0101000020E61000001D90847D3BB94C40A8AAD0402C2D4A40
21437	7	61	831	58893	66953	\N	52.170026597448299	х.Новопреображенский, ул.Центральная, 10	Россия, республика Башкортостан, Зилаирский район, село Новопреображенский	0101000020E6100000BF9A030473CE4C40EF37DA71C3154A40
21438	7	61	831	58892	66950	\N	52.471460134649099	х.Новопокровский, ул. Школьная, 7	Россия, республика Башкортостан, Зилаирский район, село Новопокровский	0101000020E61000009ED0EB4FE2954C40A3AF20CD583C4A40
21418	7	61	831	16742	64168	\N	52.249583000000001	Матраево, ул.Салавата Юлаева, 41		0101000020E61000002EC72B103D034D409C51F355F21F4A40
21393	7	61	831	58816	66519	\N	52.331968329703201	д.Мало-Юлдыбаево, ул.Шахизады Бабича, 16	Россия, республика Башкортостан, Зилаирский район, село Малоюлдыбаево	0101000020E61000007636E49F19EC4C40C6A86BED7D2A4A40
21380	7	61	831	58406	64939	\N	52.271014000000001	д. Максютово, ул.Салавата Юлаева, 4	Россия, республика Башкортостан, Зилаирский район, село Максютово	0101000020E61000007555A01683E34C400B613596B0224A40
21229	7	61	831	46775	64883	\N	52.340237999999999	д.Кашкарово, ул.Школьная, 1		0101000020E6100000F0366F9C14E24C40A06D35EB8C2B4A40
21216	7	61	831	7168	65819	\N	52.399231999999998	д.Картлазма, ул.Центральня, 14		0101000020E610000005F9D9C8758D4C4022C2BF081A334A40
21367	7	61	831	6000	64497	\N	52.217564764575798	с.Зилаир, ул.Шестакова, 16	Россия, республика Башкортостан, Зилаирский район, село Зилаир	0101000020E6100000E605D847A7B84C408BE07F2BD91B4A40
21439	7	61	831	6000	63526	\N	52.231588000000002	с.Зилаир, ул.Ленина, 51		0101000020E61000006CB3B112F3B84C40B212F3ACA41D4A40
21293	7	61	831	6000	63526	\N	52.231588000000002	с.Зилаир, ул.Ленина, 87		0101000020E61000006CB3B112F3B84C40B212F3ACA41D4A40
21430	7	61	831	17332	64634	\N	52.139730999999998	д.Верхнегалеево, ул.Сакмара, 11а		0101000020E6100000B3CF639467EE4C40629E95B4E2114A40
21429	7	61	831	58739	66286	\N	52.100121999999999	д.Васильевка, ул.Клубная, 1	Россия, республика Башкортостан, Зилаирский район, село Васильевка	0101000020E6100000A67B9DD497CB4C4018CE35CCD00C4A40
21427	7	61	831	46067	64914	\N	52.1786306891428	д. Бердяш, ул.Школьная, 5	Россия, республика Башкортостан, Зилаирский район, село Бердяш	0101000020E6100000572250FD839A4C40A1866F61DD164A40
21426	7	61	831	17136	64908	\N	52.232294000000003	д.Балапан, ул.Ш.Бабича, 8		0101000020E61000002B86AB0320044D404D874ECFBB1D4A40
21425	7	61	831	17079	66012	\N	52.0764540007156	д.Байгужино, ул.Молодежная, 9	Россия, республика Башкортостан, Зилаирский район, село Байгужино	0101000020E6100000AA7CCF4884F04C40FED2A23EC9094A40
21424	7	61	831	17046	65529	\N	52.013368999999997	д.Ашкадарово, ул.Школьная, 5		0101000020E6100000ED293927F6D64C40DEE34C13B6014A40
21423	7	61	831	58520	65316	\N	52.123224	д.Анновка, ул. Школьная, 7	Россия, республика Башкортостан, Зилаирский район, село Анновка	0101000020E61000002541B8020ABF4C40890AD5CDC50F4A40
21403	7	61	184	58899	66965	\N	51.681314683699298	Республика Башкортостан, Зианчуринский район, Сакмарский сельсовет, Деревня фермы №3 Сакмарского совхоза,  ул.Речная д.45	Россия, республика Башкортостан, Зианчуринский район, село ферма 3	0101000020E61000001EDE736039704C401AA3755435D74940
21417	7	61	184	16712	65824	\N	51.6896750498776	Республика Башкортостан, Зианчуринский район, Яныбаевский сельсовет, Яныбаево, Школьная, 24	Россия, республика Башкортостан, Зианчуринский район, село Яныбаево	0101000020E61000003370404B57A24C4035EF384547D84940
21414	7	61	184	16549	64903	\N	51.730707000000002	Республика Башкортостан, Зианчуринский район, Утягуловский сельсовет, Юнаево, Центральная, 38		0101000020E61000006B7F677BF4884C40A9FA95CE87DD4940
21450	7	61	184	13996	63593	\N	51.858038000000001	с.Юлдыбаево, ул.Советская, 55		0101000020E6100000B51B7DCC07524C40D55C6E30D4ED4940
21408	7	61	184	16247	65546	\N	52.156005999999998	Республика Башкортостан, Зианчуринский район, Суренский сельсовет, Худабандино, Центральная, 14		0101000020E61000005D35CF11F97A4C4069FD2D01F8134A40
21413	7	61	184	16492	65141	\N	51.702399999999997	Республика Башкортостан, Зианчуринский район, Утягуловский сельсовет, Утягулово, С.Абдуллина, 51		0101000020E610000042B115342D854C40EE5A423EE8D94940
21392	7	61	184	15457	66009	\N	52.063659999999999	Республика Башкортостан, Зианчуринский район, Муйнакский сельсовет, Умбетово, Гафарова, 1		0101000020E610000083E0F1ED5D674C401C08C90226084A40
21376	7	61	184	14695	64696	\N	52.236750999999998	Республика Башкортостан, Зианчуринский район, Бикбауский сельсовет, Трушино, Дружбы, 12а		0101000020E6100000D1E7A38CB8604C40CC2555DB4D1E4A40
21410	7	61	184	16339	64368	\N	52.149033000000003	Республика Башкортостан, Зианчуринский район, Тазларовский сельсовет, Тазларово, Советская, 24		0101000020E610000077DB85E63A574C402C836A8313134A40
21372	7	61	184	14511	65522	\N	52.250895690923798	Республика Башкортостан, Зианчуринский район, Байдавлетовский сельсовет, Серегулово, Школьная, 21	Россия, республика Башкортостан, Зианчуринский район, село Серегулово	0101000020E61000009487855AD3724C403E59315C1D204A40
21365	7	61	184	14177	65228	\N	51.814430000000002	Республика Башкортостан, Зианчуринский район, Баишевский сельсовет, Сагитово, Салавата Юлаева, 36		0101000020E6100000C2DA183BE18D4C40CE70033E3FE84940
21400	7	61	184	15859	\N	\N	52.199948999999997	Республика Башкортостан, Зианчуринский район, Новочебенкинский сельсовет, Новые Чебенки, Центральная, 35	Россия, республика Башкортостан, Зианчуринский район, село Новые Чебенки	0101000020E6100000AA454431792D4C4017EFC7ED97194A40
21396	7	61	184	15643	66250	\N	52.223556000000002	Республика Башкортостан, Зианчуринский район, Новопетровский сельсовет, Новопетпровское, Стеклянка, 2		0101000020E6100000BEDC274701484C408C69A67B9D1C4A40
21384	7	61	184	15071	64815	\N	52.173589999999997	Республика Башкортостан, Зианчуринский район, Исянгуловский сельсовет, Новопавловка, Мира, 18/1	Россия, республика Башкортостан, Зианчуринский район, село Новопавловка	0101000020E6100000884677103B494C40D174763238164A40
21401	7	61	184	15882	64774	\N	52.266506	Республика Башкортостан, Зианчуринский район, Новочебенкинский сельсовет, Новониколаевка, Центральная, 63		0101000020E610000034F790F0BD354C4009185DDE1C224A40
22161	7	61	184	15882	66300	\N	52.266032355544802	д. Новониколаевка, Лесная, 25	Россия, республика Башкортостан, Зианчуринский район, село Новониколаевка	0101000020E6100000821FD5B0DF354C4041D829560D224A40
21377	7	61	184	14748	65998	\N	52.258161000000001	Республика Башкортостан, Зианчуринский район, Бикбауский сельсовет, Нижняя Бикберда, Центральная, 55		0101000020E6100000B2F336363B644C40240D6E6B0B214A40
21390	7	61	184	15358	65543	\N	51.998638999999997	Республика Башкортостан, Зианчуринский район, Муйнакский сельсовет, Нижняя Акберда, Хутор, 8		0101000020E610000073840CE4D9614C404CC11A67D3FF4940
21358	7	61	184	13847	65142	\N	51.972332000000002	Республика Башкортостан, Зианчуринский район, Абзановский сельсовет, Мухамедьяново, Советская, 24		0101000020E6100000BCB20B06D7784C40596DFE5F75FC4940
21406	7	61	184	660	66888	\N	52.125425	Республика Башкортостан, Зианчуринский район, Суренский сельсовет, Малый Муйнак, Центральная, 25		0101000020E6100000F629C76471614C40E78C28ED0D104A40
21362	7	61	184	14044	65957	\N	51.778452999999999	Республика Башкортостан, Зианчуринский район, Абуляисовский сельсовет, Малиновка, Школьная, 1/1		0101000020E610000072158BDF14704C408E3C1059A4E34940
21394	7	61	184	15563	65278	\N	52.061047000000002	Республика Башкортостан, Зианчуринский район, Муйнакский сельсовет, Мазитово, Большой Ускалык, 53/а		0101000020E6100000C00644882B734C406C425A63D0074A40
21416	7	61	184	58756	66368	\N	51.868715999999999	Республика Башкортостан, Зианчуринский район, Утягуловский сельсовет, Лукьяновка, Центральная, 12	Россия, республика Башкортостан, Зианчуринский район, село Лукьяновский	0101000020E6100000381268B0A97B4C4087C1FC1532EF4940
21399	7	61	184	15787	66246	\N	52.217339000000003	Республика Башкортостан, Зианчуринский район, Новочебенкинский сельсовет, Кузебеково, Советская, 8		0101000020E61000001406651A4D344C409B92ACC3D11B4A40
21420	7	61	184	16846	65829	\N	51.599398189142597	Республика Башкортостан, Зианчуринский район, Яныбаевский сельсовет, Кужанак, Школьная, 22а	Россия, республика Башкортостан, Зианчуринский район, село Кужанак	0101000020E61000006A85E97B0D974C40D7A4DB12B9CC4940
21405	7	61	184	16091	64202	\N	52.148446999999997	Республика Башкортостан, Зианчуринский район, Суренский сельсовет, Кугарчи, Комсомольская, 50б		0101000020E61000009D2CB5DE6F6A4C403B18B14F00134A40
21407	7	61	184	16171	66251	\N	52.158410000000003	Республика Башкортостан, Зианчуринский район, Суренский сельсовет, Кинзябулатово, Центральная, 30		0101000020E61000000AF4893C49664C4000AE64C746144A40
21409	7	61	184	58811	66511	\N	52.121886000000003	Республика Башкортостан, Зианчуринский район, Суренский сельсовет, Каргала, Центральная, 55	Россия, республика Башкортостан, Зианчуринский район, село Карагала	0101000020E6100000CD76853E588C4C408EEBDFF5990F4A40
21388	7	61	184	15260	64629	\N	51.810791342566098	Республика Башкортостан, Зианчуринский район, Казанбулакский сельсовет, Казанка, Утарбарская, 37	Россия, республика Башкортостан, Зианчуринский район, село Казанка	0101000020E61000000F9A5DF756944C401172DEFFC7E74940
21398	7	61	184	58329	64725	\N	52.188191233542497	Республика Башкортостан, Зианчуринский район, Новочебенкинский сельсовет, Ишемгул, Чекмарева, 42а	Россия, республика Башкортостан, Зианчуринский район, село Иняк	0101000020E6100000C79E3D97A9274C40663387A416184A40
21379	7	61	184	5239	63273	\N	52.192540999999999	Республика Башкортостан, Зианчуринский район, Исянгуловский сельсовет, Исянгулово, Советская, 1		0101000020E61000002BDD5D67434A4C40CF11F92EA5184A40
94456	7	61	184	5239	66754	\N	52.192540999999999	Республика Башкортостан, Зианчуринский район, Исянгуловский сельсовет, Исянгулово, ул. Магистральная, д. 1		0101000020E61000002BDD5D67434A4C40CF11F92EA5184A40
21385	7	61	184	5239	64819	\N	52.192540999999999	Республика Башкортостан, Зианчуринский район, Исянгуловский сельсовет, Исянгулово, Лесная, 1		0101000020E61000002BDD5D67434A4C40CF11F92EA5184A40
21381	7	61	184	5239	63301	\N	52.192540999999999	Республика Башкортостан, Зианчуринский район, Исянгуловский сельсовет, Исянгулово, Комсомольская, 11	Россия, республика Башкортостан, Зианчуринский район, село Исянгулово	0101000020E61000002BDD5D67434A4C40CF11F92EA5184A40
21382	7	61	184	5239	64030	\N	52.192540999999999	Республика Башкортостан, Зианчуринский район, Исянгуловский сельсовет, Исянгулово, 40 лет Победы, 2в		0101000020E61000002BDD5D67434A4C40CF11F92EA5184A40
21370	7	61	184	14416	64693	\N	51.875278000000002	Республика Башкортостан, Зианчуринский район, Баишевский сельсовет, Ильмаля, Кунсбаева, 1/4		0101000020E61000000ABDFE243E8D4C404374081C09F04940
21415	7	61	184	16569	64904	\N	51.740082999999998	Республика Башкортостан, Зианчуринский район, Утягуловский сельсовет, Идяш, Школьная, 1		0101000020E6100000EBC891CEC0804C40ACA92C0ABBDE4940
21387	7	61	184	15213	63542	\N	51.774965000000002	Республика Башкортостан, Зианчуринский район, Казанбулакский сельсовет, Идельбаково, Советская, 6		0101000020E6100000003620425C914C40B745990D32E34940
21373	7	61	184	14539	65533	\N	52.257119000000003	Республика Башкортостан, Зианчуринский район, Байдавлетовский сельсовет, Ибраево, Школьная, 49а		0101000020E6100000611C5C3AE67A4C4012178046E9204A40
21395	7	61	184	15611	66243	\N	52.109890999999998	Республика Башкортостан, Зианчуринский район, Муйнакский сельсовет, Габбасово, Малый Ускалык, 41/2		0101000020E6100000CFF6E80DF7714C40F78F85E8100E4A40
21378	7	61	184	14784	66003	\N	52.277180999999999	Республика Башкортостан, Зианчуринский район, Бикбауский сельсовет, Верхняя Бикберда, Центральная, 7		0101000020E6100000A648BE1248634C404A09C1AA7A234A40
21389	7	61	184	15298	65542	\N	52.033358	Республика Башкортостан, Зианчуринский район, Муйнакский сельсовет, Верхний Муйнак, Центральная, 3		0101000020E61000006F8445459C604C40AD872F1345044A40
21419	7	61	184	58848	66579	\N	51.722433205218501	Республика Башкортостан, Зианчуринский район, Яныбаевский сельсовет, Верхняя Мамбетша, Центральная, 31	Россия, республика Башкортостан, Зианчуринский район, село Верхние Мамбетшино	0101000020E6100000651D8EAED2A54C408D463EAF78DC4940
21371	7	61	184	14442	65519	\N	51.944826999999997	Республика Башкортостан, Зианчуринский район, Баишевский сельсовет, Биштиряк, Ялна Ер, 1		0101000020E6100000EE4108C897984C405BB05417F0F84940
21411	7	61	184	16400	65844	\N	52.101554999999998	Республика Башкортостан, Зианчуринский район, Тазларовский сельсовет, Биккужа, Центральная, 8а		0101000020E6100000CBBC55D7A1504C4065DF15C1FF0C4A40
21421	7	61	184	16893	65140	\N	51.667389	Республика Башкортостан, Зианчуринский район, Яныбаевский сельсовет, Башкирский Бармак, Центральная, 6а		0101000020E6100000800F5EBBB4994C40E65AB4006DD54940
21359	7	61	184	13901	65972	\N	51.942993999999999	Республика Башкортостан, Зианчуринский район, Абзановский сельсовет, Башкирская Чумаза, Кооперативная, 30		0101000020E6100000ED9925016A644C4080290307B4F84940
21397	7	61	184	15697	64327	\N	52.264648999999999	Республика Башкортостан, Зианчуринский район, Новопетровский сельсовет, Башкирская Ургинка, Молодежная, 6		0101000020E6100000EA95B20C71544C40A5F5B704E0214A40
21374	7	61	184	14611	64900	\N	52.208928999999998	Республика Башкортостан, Зианчуринский район, Байдавлетовский сельсовет, Байдавлетово, Бишай, 33		0101000020E6100000605B3FFD67714C40CE177B2FBE1A4A40
21366	7	61	184	14219	65231	\N	51.839087999999997	Республика Башкортостан, Зианчуринский район, Баишевский сельсовет, Баишево, Школьная, 5		0101000020E610000034F8FBC56C8B4C40A73B4F3C67EB4940
21386	7	61	184	15158	65608	\N	52.165127925727603	Республика Башкортостан, Зианчуринский район, Исянгуловский сельсовет, Аютово, Набережная, 17	Россия, республика Башкортостан, Зианчуринский район, село Аютово	0101000020E6100000E1B54B1B0E414C40B3D30FEA22154A40
21357	7	61	184	13778	65949	\N	51.934555000000003	Республика Башкортостан, Зианчуринский район, Абзановский сельсовет, Алибаево, Ассель, 38		0101000020E610000058AD4CF8A5764C401AA88C7F9FF74940
21369	7	61	184	14350	64691	\N	51.884562000000003	Республика Башкортостан, Зианчуринский район, Баишевский сельсовет, Акдавлетово, Центральная, 8		0101000020E6100000C51EDAC70A824C4066A4DE5339F14940
21364	7	61	184	14133	65144	\N	51.753321	Республика Башкортостан, Зианчуринский район, Абуляисовский сельсовет, Абуляисово, Ишапай, 11		0101000020E610000065C5707500724C40EC3191D26CE04940
21356	7	61	184	13760	64434	\N	51.851557	Республика Башкортостан, Зианчуринский район, Абзановский сельсовет, Абзаново, Магадеева, 42		0101000020E6100000962023A0C2614C4006D7DCD1FFEC4940
20689	7	61	144	58845	66573	\N	53.840157497241201	Республика Башкортостан, Белебеевский район, Максим-Горьковский сельсовет, с.Санатория Глуховского, Школьная, 1	Россия, республика Башкортостан, Ермекеевский район, село участок Санатория Имени Глуховского	0101000020E6100000CB13083BC5F64A40B340BB438AEB4A40
21329	7	61	144	12503	64039	\N	53.896729000000001	Республика Башкортостан, Ермекеевский район, Восьмомартовский сельсовет, пос.8 Марта, Школьная, 9		0101000020E61000002904728923E14A40F92F1004C8F24A40
21355	7	61	144	4902	66875	\N	54.268917475380199	Республика Башкортостан, Ермекеевский район, Усман-Ташлинский сельсовет, с. Усман-Ташлы, Центральная, 27	Россия, республика Башкортостан, Ермекеевский район, село Усман-Ташлы	0101000020E61000005303CDE7DCC74A40522B4CDF6B224B40
21354	7	61	144	13637	64466	\N	53.836477000000002	Республика Башкортостан, Ермекеевский район, Тарказинский сельсовет, с. Тарказы, Молодежная, 26		0101000020E6100000BAA1293BFDD04A40986DA7AD11EB4A40
21353	7	61	144	13608	64443	\N	54.230247120157998	Республика Башкортостан, Ермекеевский район, Суккуловский сельсовет, с. Суккулово, Школьная, 5	Россия, республика Башкортостан, Ермекеевский район, село Суккулово	0101000020E6100000F0315871AADD4A404580D3BB781D4B40
21350	7	61	144	13480	65521	\N	54.189982000000001	Республика Башкортостан, Ермекеевский район, Старосуллинский сельсовет, с. Старые Сулли, Школьная, 155		0101000020E6100000C6C1A563CEC94A40126A865451184B40
21352	7	61	144	13576	65748	\N	54.297053789795001	Республика Башкортостан, Ермекеевский район, Усман-Ташлинский сельсовет, с. Старошахово, Центральная, 12	Россия, республика Башкортостан, Ермекеевский район, село Старошахово	0101000020E6100000C58F31772DCD4A40B0928FDD05264B40
21351	7	61	144	448	66727	\N	54.276057999999999	Республика Башкортостан, Ермекеевский район, Старотураевский сельсовет, с. Старотураево, Ленина, 20		0101000020E610000070067FBF98BF4A404BE658DE55234B40
94457	7	61	144	448	66824	\N	54.276057999999999	деревня Старотураево, ул. Кирова, 2/1		0101000020E610000070067FBF98BF4A404BE658DE55234B40
21348	7	61	144	445	66927	\N	53.981076999999999	Республика Башкортостан, Ермекеевский район, Среднекарамалинский сельсовет, с. Средние-Карамалы, Чапаева, 2		0101000020E610000043041C4295CC4A40CCED5EEE93FD4A40
21347	7	61	144	13328	64144	\N	53.978065474905598	Республика Башкортостан, Ермекеевский район, Спартакский сельсовет, пос. Спартак, Клубная, 4	Россия, республика Башкортостан, Ермекеевский район, село Спартак	0101000020E6100000699082A790E54A405E2EE23B31FD4A40
21346	7	61	144	13292	64623	\N	54.102290000000004	Республика Башкортостан, Ермекеевский район, Ермекеевский сельсовет, с. Семено-Макарово, Лесная, 7		0101000020E61000008446B071FDE54A409B5AB6D6170D4B40
21345	7	61	144	13218	64043	\N	54.083691999999999	Республика Башкортостан, Ермекеевский район, с. Рятамак, Коммунистическая, 28		0101000020E6100000D0B69A75C6C34A40EA77616BB60A4B40
20673	7	61	144	12213	63581	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Школьная, 3		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
20672	7	61	144	12213	63640	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Свердлова, 6		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
20669	7	61	144	12213	63640	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Свердлова, 10		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
20667	7	61	144	12213	63640	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Свердлова, 9а		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
21323	7	61	133	12212	64622	\N	55.708562000000001	Республика Башкортостан, Дюртюлинский район, Черлаковский сельсовет, с.Юсупово, Центральная, 14		0101000020E610000075CC79C6BE544B401C98DC28B2DA4B40
20666	7	61	144	12213	63640	\N	53.901400559790602	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Свердлова, 5	Россия, республика Башкортостан, Ермекеевский район, поселок Приютово	0101000020E6100000AABA473657F74A4075CAA31B61F34A40
20671	7	61	144	12213	64547	\N	53.891693120812299	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Первомайская, 8а	Россия, республика Башкортостан, Ермекеевский район, поселок Приютово	0101000020E6100000E5284014CCF84A403B8908FF22F24A40
20674	7	61	144	12213	63645	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Комсомольская, 3в		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
20670	7	61	144	12213	63384	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Бульвар Мира, 3		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
20665	7	61	144	12213	63384	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, Бульвар Мира, 9а		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
20668	7	61	144	12213	63647	\N	53.893445	Республика Башкортостан, Белебеевский район, Приютовский поссовет, р.п.Приютово, 50 лет ВЛКСМ, 5а		0101000020E610000008ABB184B5F74A402AE3DF675CF24A40
21343	7	61	144	13138	64621	\N	53.980865999999999	Республика Башкортостан, Ермекеевский район, Спартакский сельсовет, с. Пионерский, Пионерская, 28		0101000020E6100000828C800A47E04A4011E15F048DFD4A40
21344	7	61	144	13202	66719	\N	53.881785999999998	Республика Башкортостан, Ермекеевский район, Бекетовский сельсовет, пос. Новый, ул. Молодежная,д.8/1		0101000020E610000001344A97FEFB4A400B09185DDEF04A40
21340	7	61	144	343	66788	\N	54.164076000000001	Республика Башкортостан, Ермекеевский район, Старосуллинский сельсовет, с.Новые Сулли, Центральная,д.40		0101000020E6100000A25F5B3FFDCD4A407D073F7100154B40
21341	7	61	144	13045	64620	\N	53.810726000000003	Республика Башкортостан, Ермекеевский район, Восьмомартовский сельсовет, с. Новошахово, Нагорная, 15		0101000020E6100000D847A7AE7CEA4A402A029CDEC5E74A40
21342	7	61	144	13085	65137	\N	53.831259000000003	Республика Башкортостан, Ермекеевский район, Восьмомартовский сельсовет, с. Новотураево, Салавата Юлаева, 43		0101000020E6100000EA060ABC93EB4A40BAC0E5B166EA4A40
21338	7	61	144	58846	66575	\N	53.950497273814399	Республика Башкортостан, Ермекеевский район, Среднекарамалинский сельсовет, с.Нижние Карамалы, Молодежная, 2	Россия, республика Башкортостан, Ермекеевский район, село Нижнии Карамалы	0101000020E6100000A795422097C84A401AF9BCE2A9F94A40
21339	7	61	144	12943	64911	\N	54.062432999999999	Республика Башкортостан, Ермекеевский район, Нижнеулу-Елгинский сельсовет, с.Нижнеулу-Елга, Молодежная, 10	Россия, республика Башкортостан, Ермекеевский район, село Нижнеулу-Елга	0101000020E6100000D2E0B6B6F0DE4A407898F6CDFD074B40
21337	7	61	144	12886	65517	\N	54.16328	Республика Башкортостан, Ермекеевский район, Суккуловский сельсовет, с. Купченеево, Школьная, 59		0101000020E61000003944DC9C4ADA4A40A20BEA5BE6144B40
21336	7	61	144	4673	66640	\N	54.162173000000003	Республика Башкортостан, Ермекеевский район, Кулбаевский сельсовет, с.Кулбаево, Клубная, 4а		0101000020E6100000D13B1570CFBB4A40A9A5B915C2144B40
21335	7	61	144	10285	66688	\N	53.758068999999999	Республика Башкортостан, Ермекеевский район, Тарказинский сельсовет, с.Исламбахты, Садовая,1а		0101000020E6100000F1BC546CCCDD4A40438EAD6708E14A40
21333	7	61	144	12607	63537	\N	54.077939999999998	Республика Башкортостан, Ермекеевский район, Ермекеевский сельсовет, с.Ермекеево, Школьная, 11		0101000020E61000008639419B1CD64A406E861BF0F9094B40
21332	7	61	144	12607	63426	\N	54.077939999999998	Республика Башкортостан, Ермекеевский район, Ермекеевский сельсовет, с. Ермекеево, Ленина, 3		0101000020E61000008639419B1CD64A406E861BF0F9094B40
21331	7	61	144	12607	64430	\N	54.077939999999998	Республика Башкортостан, Ермекеевский район, Ермекеевский сельсовет, с. Ермекеево, Коммунистическая, 3		0101000020E61000008639419B1CD64A406E861BF0F9094B40
21328	7	61	144	12470	65518	\N	54.027603999999997	Республика Башкортостан, Ермекеевский район, Нижнеулу-Елгинский сельсовет, с Верхнеулу-Елга, Центральная, 35		0101000020E61000007F130A1170DE4A40909E228788034B40
21334	7	61	144	58850	66581	\N	54.042179334606701	Республика Башкортостан, Ермекеевский район, Нижнеулу-Елгинский сельсовет,с. Большезингереево, Набережная, 16	Россия, республика Башкортостан, Ермекеевский район, село Больщеезингереево	0101000020E6100000CDCEA2772AEA4A40FBC9181F66054B40
21327	7	61	144	12406	65947	\N	53.916817000000002	Республика Башкортостан, Ермекеевский район, с. Бекетово, Школьная, 2		0101000020E6100000996379573DF04A405BB56B425AF54A40
21761	7	61	144	12406	65501	\N	53.917118311688903	Адрес помещения для голосования: село Бекетово, улица Октябрьская, дом 21а, Адрес УИК: улица Октябрьская, дом 15	Россия, республика Башкортостан, Ермекеевский район, село Бекетово	0101000020E6100000200BD12170F04A405649641F64F54A40
21326	7	61	144	12382	65952	\N	53.872635000000002	Республика Башкортостан, Ермекеевский район, с. Атамкуль, Мира, 26/1		0101000020E610000056D3F544D7CD4A40282CF180B2EF4A40
21325	7	61	144	12318	65134	\N	54.236694999999997	Республика Башкортостан, Ермекеевский район, с. Абдулово, Горная, 14		0101000020E61000006682E15CC3B84A40381092054C1E4B40
21324	7	61	144	12268	65122	\N	54.080824	Республика Башкортостан, Ермекеевский район, с. Абдулкаримово, Тукая, 13		0101000020E61000007C46223482CD4A40AF5DDA70580A4B40
22402	7	61	133	12212	64622	\N	55.708804292828802	д. Юсупово, Центральная, 23	Россия, республика Башкортостан, Дюртюлинский район, село Юсупово	0101000020E61000001825E82FF4544B4012A3E716BADA4B40
21322	7	61	133	12154	64617	\N	55.738460000000003	Республика Башкортостан, Дюртюлинский район, Черлаковский сельсовет, с.Черлак, Центральная, 63		0101000020E61000008351499D80604B40BCB376DB85DE4B40
21318	7	61	133	11959	64611	\N	55.447867000000002	Республика Башкортостан, Дюртюлинский район, Учпилинский сельсовет, с.Учпили, Советская, 48		0101000020E61000002D793C2D3F824B4094FAB2B453B94B40
21286	7	61	133	10487	64671	\N	55.267189000000002	Республика Башкортостан, Дюртюлинский район, Куккуяновский сельсовет, д.Урман-Асты, Механизаторская, 15		0101000020E610000090662C9ACE764B40EC6CC83F33A24B40
21290	7	61	133	58866	66683	\N	55.6523145600598	Республика Башкортостан, Дюртюлинский район, Маядыковский сельсовет, с.Ярмино, Давлетгареевых,  45А	Россия, республика Башкортостан, Дюртюлинский район, село ТатЯрмино	0101000020E610000077137CD3F4834B405AD8D30E7FD34B40
21314	7	61	133	11807	65511	\N	55.461843999999999	Республика Башкортостан, Дюртюлинский район, Такарликовский сельсовет, с.Такарликово, Механизаторская, 5		0101000020E6100000F99E91088D644B404AED45B41DBB4B40
21310	7	61	133	11597	64307	\N	55.373275999999997	Республика Башкортостан, Дюртюлинский район, Таймурзинский сельсовет, с.Таймурзино, Озерная, 2		0101000020E6100000F436363B526B4B40DB300A82C7AF4B40
21311	7	61	133	11627	65941	\N	55.409201000000003	Республика Башкортостан, Дюртюлинский район, Таймурзинский сельсовет, д.Султанбеково, Ахуновых, 30		0101000020E6100000676325E6596B4B40C93EC8B260B44B40
21308	7	61	133	11511	64128	\N	55.413096000000003	Республика Башкортостан, Дюртюлинский район, Суккуловский сельсовет, с.Суккулово, Центральная, 9		0101000020E6100000A9C1340C1F754B40E10D6954E0B44B40
21304	7	61	133	11309	64021	\N	55.465785299331799	Республика Башкортостан, Дюртюлинский район, Староянтузовский сельсовет, с.Староянтузово, Молодежная, 2	Россия, республика Башкортостан, Дюртюлинский район, село Староянтузово	0101000020E6100000C974E8F4BC894B40D2FBC6D79EBB4B40
21302	7	61	133	11215	64896	\N	55.399718999999997	Республика Башкортостан, Дюртюлинский район, Старобаишевский сельсовет, с.Староуртаево, Кооперативная, 3		0101000020E610000089450C3B8C914B407F4B00FE29B34B40
20610	7	61	133	9612	\N	\N	55.531035000000003	с.Старобалтачево, Юбилейная, 2	Россия, республика Башкортостан, Дюртюлинский район, село Старобалтачево	0101000020E61000009B1E1494A25B4B40040473F4F8C34B40
21281	7	61	133	9612	65484	\N	55.531035000000003	Республика Башкортостан, Дюртюлинский район, Исмаиловский сельсовет, д.Старобалтачево, Дормидонтова, 9		0101000020E61000009B1E1494A25B4B40040473F4F8C34B40
21301	7	61	133	11165	65497	\N	55.418011	Республика Башкортостан, Дюртюлинский район, Старобаишевский сельсовет, с.Старобаишево, Молодежная, 7		0101000020E610000093E52494BE8E4B40232F6B6281B54B40
21283	7	61	133	10300	65272	\N	55.531371925997099	Республика Башкортостан, Дюртюлинский район, Исмаиловский сельсовет, д.Сикаликуль, Советская, 1/1	Россия, республика Башкортостан, Дюртюлинский район, село Сикаликуль	0101000020E61000000A85083884424B404B0169FF03C44B40
21296	7	61	133	10887	63293	\N	55.360208	Республика Башкортостан, Дюртюлинский район, Семилетовский сельсовет, с.Семилетка, Мира, 19А		0101000020E610000098A25C1ABF4E4B40F8E0B54B1BAE4B40
21295	7	61	133	10887	63293	\N	55.360208	Республика Башкортостан, Дюртюлинский район, Семилетовский сельсовет, с.Семилетка, Мира, 19		0101000020E610000098A25C1ABF4E4B40F8E0B54B1BAE4B40
21297	7	61	133	10887	64311	\N	55.360208	Республика Башкортостан, Дюртюлинский район, Семилетовский сельсовет, с.Семилетка, Ленина, 10		0101000020E610000098A25C1ABF4E4B40F8E0B54B1BAE4B40
21306	7	61	133	11429	64607	\N	55.471387999999997	Республика Башкортостан, Дюртюлинский район, Староянтузовский сельсовет, д.Сабанаево, Фазыловых, 9		0101000020E6100000D064FF3C0D964B4009DD257156BC4B40
21317	7	61	133	11931	65942	\N	55.561762000000002	Республика Башкортостан, Дюртюлинский район, Такарликовский сельсовет, с.Новобиктово, Механизаторская, 18		0101000020E6100000293C6876DD6B4B405A1135D1E7C74B40
21300	7	61	133	11131	65114	\N	55.391181000000003	Республика Башкортостан, Дюртюлинский район, Семилетовский сельсовет, с.Нижнеманчарово, Коммунистическая, 51Б		0101000020E61000007C9DD497A54F4B4086E8103812B24B40
21298	7	61	133	11035	65486	\N	55.370395000000002	Республика Башкортостан, Дюртюлинский район, Семилетовский сельсовет, с.Нижнеаташево, Гумерова, 47/2		0101000020E6100000307F85CC955D4B400CCD751A69AF4B40
21280	7	61	133	10153	64889	\N	55.520469251644698	Республика Башкортостан, Дюртюлинский район, Исмаиловский сельсовет, д.Нижнеалькашево, Школьная, 17	Россия, республика Башкортостан, Дюртюлинский район, село Нижнеалькашево	0101000020E6100000FD6B79E57A534B4079CA6ABA9EC24B40
21292	7	61	133	10696	64249	\N	55.319130999999999	Республика Башкортостан, Дюртюлинский район, Московский сельсовет, с.Москово, Калинина, 47		0101000020E6100000F701486DE28A4B40E411DC48D9A84B40
21291	7	61	133	10696	64249	\N	55.319130999999999	Республика Башкортостан, Дюртюлинский район, Московский сельсовет, с.Москово, Калинина, 47А		0101000020E6100000F701486DE28A4B40E411DC48D9A84B40
21289	7	61	133	10617	65931	\N	55.619385999999999	Республика Башкортостан, Дюртюлинский район, Маядыковский сельсовет, с.Миништы, Советская, 10		0101000020E6100000D1C952EBFD824B40D5CC5A0A48CF4B40
21287	7	61	133	10527	64247	\N	55.617291000000002	Республика Башкортостан, Дюртюлинский район, Маядыковский сельсовет, с.Маядык, Горшкова, 14		0101000020E610000052F01472A57A4B40BD8E386403CF4B40
21316	7	61	133	11883	64755	\N	55.509548000000002	Республика Башкортостан, Дюртюлинский район, Такарликовский сельсовет, с.Кушулево, Советская, 3		0101000020E6100000B894F3C5DE634B4001DF6DDE38C14B40
21284	7	61	133	10392	64894	\N	55.317152999999998	Республика Башкортостан, Дюртюлинский район, Куккуяновский сельсовет, с.Куккуяново, Школьная, 47		0101000020E6100000A034D42824794B40056A317898A84B40
21279	7	61	133	10070	64462	\N	55.559877999999998	Республика Башкортостан, Дюртюлинский район, Исмаиловский сельсовет, с.Исмаилово, Школьная, 14		0101000020E6100000A5F3E15982504B40FCDF1115AAC74B40
21294	7	61	133	10858	65936	\N	55.337229999999998	Республика Башкортостан, Дюртюлинский район, Московский сельсовет, с.Имай-Утарово, Школьная, 1А		0101000020E6100000C9AA0837197F4B40739D465A2AAB4B40
21285	7	61	133	10417	65108	\N	55.290044000000002	Республика Башкортостан, Дюртюлинский район, Куккуяновский сельсовет, с.Ивачево, Школьная, 8		0101000020E6100000111956F146804B4055336B2920A54B40
21312	7	61	133	11716	63276	\N	55.492196999999997	Республика Башкортостан, Дюртюлинский район, Такарликовский сельсовет, с.Иванаево, Комсомольская, 7		0101000020E61000003946B247A8694B403B18B14F00BF4B40
21319	7	61	133	12048	65123	\N	55.457107000000001	Республика Башкортостан, Дюртюлинский район, Учпилинский сельсовет, д.Зейлево, Социалистическая, 2		0101000020E610000084F23E8EE6844B40E7E26F7B82BA4B40
21269	7	61	133	295	63751	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, переулок Марии Якутовой, 4	Россия, республика Башкортостан, Дюртюлинский район, поселок Дюртюли	0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21274	7	61	133	295	64384	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Седова, 4/3		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21271	7	61	133	295	63569	\N	55.482581011560796	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Разиля Мусина, 80	Россия, республика Башкортостан, Дюртюлинский район, поселок Дюртюли	0101000020E61000006939D0436D6F4B40E355D636C5BD4B40
21263	7	61	133	295	63636	\N	55.492568760998601	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Первомайская, 3	Россия, республика Башкортостан, Дюртюлинский район, поселок Дюртюли	0101000020E6100000DB5207793D6C4B40000341800CBF4B40
21261	7	61	133	295	63636	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Первомайская, 54		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21203	7	61	133	295	63279	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Назара Наджми, 36		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21267	7	61	133	295	63700	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Матросова, 3		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21264	7	61	133	295	63700	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Матросова, 10		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21273	7	61	133	295	64022	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, д.Аргамак, Марии Якутовой, 1		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21272	7	61	133	295	63516	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Ленина, 7		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21266	7	61	133	295	63516	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Ленина, 42А		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21265	7	61	133	295	63516	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Ленина, 19		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21268	7	61	133	295	63730	\N	55.488871000000003	Республика Башкортостан, Дюртюлинский район, город Дюртюли, Василия Горшкова, 12		0101000020E610000086730D33346E4B403E7B2E5393BE4B40
21313	7	61	133	11725	65124	\N	55.484183000000002	Республика Башкортостан, Дюртюлинский район, Такарликовский сельсовет, Гублюкучуково, Школьная, 7		0101000020E6100000603B18B14F664B40BC2363B5F9BD4B40
21307	7	61	133	11439	65489	\N	55.525888999999999	Республика Башкортостан, Дюртюлинский район, Староянтузовский сельсовет, с. Байгильды, Интернациональная, 25		0101000020E6100000075F984C15944B40BF29AC5450C34B40
21277	7	61	133	10018	64232	\N	55.444405000000003	Республика Башкортостан, Дюртюлинский район, Асяновский сельсовет, с.Асяново, Ш.Бабича, 12		0101000020E61000001288D7F50B5C4B40E6965643E2B84B40
21275	7	61	133	9931	\N	\N	55.637509999999999	Республика Башкортостан, Дюртюлинский район, Ангасяковский сельсовет, с. Ангасяк, Чиглинцева, 1	Россия, республика Башкортостан, Дюртюлинский район, село Ангасяк	0101000020E6100000A9DA6E826F664B40BD6F7CED99D14B40
21276	7	61	133	9931	64038	\N	55.637509999999999	Республика Башкортостан, Дюртюлинский район, Ангасяковский сельсовет, Чиглинцева, 3		0101000020E6100000A9DA6E826F664B40BD6F7CED99D14B40
21305	7	61	133	11347	65939	\N	55.438149000000003	Республика Башкортостан, Дюртюлинский район, Староянтузовский сельсовет, с.Аканеево, Интернациональная, 2		0101000020E6100000C89A9141EE8E4B4037E3344415B84B40
21256	7	61	119	8919	64245	\N	55.850838000000003	"Республика Башкортостан, Дуванский район, Ярославский сельсовет, с. Ярославка, Советская, 179 ""А"""		0101000020E610000007EC6AF294FB4C40D7187442E8EC4B40
21255	7	61	119	8919	64245	\N	55.850838000000003	Республика Башкортостан, Дуванский район, Ярославский сельсовет, с. Ярославка, Советская, 110		0101000020E610000007EC6AF294FB4C40D7187442E8EC4B40
21254	7	61	119	8919	64245	\N	55.850838000000003	Республика Башкортостан, Дуванский район, Ярославский сельсовет, с. Ярославка, Советская, 12/1		0101000020E610000007EC6AF294FB4C40D7187442E8EC4B40
21248	7	61	119	8658	66351	\N	55.729152999999997	"Республика Башкортостан, Дуванский район, Дуванский сельсовет, д. Чертан, Сушзаводская, 2 ""А"""		0101000020E61000004F95EF1989F44C40E063B0E254DD4B40
21059	7	61	58	31188	65279	\N	55.945467999999998	д. Большешукшаново, Школьная, 39		0101000020E6100000ABCFD556ECC54B400FB56D1805F94B40
21244	7	61	119	8476	63396	\N	55.660809999999998	Республика Башкортостан, Дуванский район, Улькундинский сельсовет, с. Улькунды, 60 лет Октября, 37		0101000020E6100000DE5A26C3F1FC4C40546F0D6C95D44B40
21252	7	61	119	8816	64090	\N	55.762171000000002	Республика Башкортостан, Дуванский район, Вознесенский сельсовет, с. Тастуба, Площадь Ившина, 10		0101000020E61000006F9F55664AF14C40D57ABFD18EE14B40
21233	7	61	119	7923	64888	\N	55.578650000000003	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, д. Старохалилово, Центральная, 18		0101000020E6100000145E82531F2C4D404BEA043411CA4B40
21240	7	61	119	8301	\N	\N	55.485719000000003	"Республика Башкортостан, Дуванский район, Сикиязский сельсовет, с. Сикияз, ДМ. Араловец, 2 ""В"""		0101000020E610000078B6476FB8134D40DE054A0A2CBE4B40
21257	7	61	119	9078	64322	\N	55.896936772538801	Республика Башкортостан, Дуванский район, Сальевский сельсовет, с. Сальевка, Октябрьская, 6	Россия, республика Башкортостан, Дуванский район, село Сальевка	0101000020E61000007808E3A771F94C4043C9E4D4CEF24B40
21237	7	61	119	8158	66743	\N	55.457229473593202	Республика Башкортостан, Дуванский район, Рухтинский сельсовет, с. Рухтино, ул. Мира, 47	Россия, республика Башкортостан, Дуванский район, село Рухтино	0101000020E61000000A2E56D460304D4032E4D87A86BA4B40
21249	7	61	119	8730	65384	\N	55.617108000000002	Республика Башкортостан, Дуванский район, Дуванский сельсовет, д. Октябрьский, Лесная, 5		0101000020E61000008DF161F6B2BF4C40CC0C1B65FDCE4B40
21242	7	61	119	8388	64365	\N	55.578971000000003	"Республика Башкортостан, Дуванский район, Михайловский сельсовет, с. Михайловка, Михайловская, 22 ""Б"""		0101000020E61000002B31CF4A5AF74C408D2AC3B81BCA4B40
21243	7	61	119	8437	65820	\N	55.630360000000003	Республика Башкортостан, Дуванский район, Михайловский сельсовет, д. Митрофановка, Береговая, 1		0101000020E61000006891ED7C3FF74C40715AF0A2AFD04B40
21258	7	61	119	9120	64458	\N	56.013502000000003	Республика Башкортостан, Дуванский район, Метелинский сельсовет, с. Метели, Советская, 38		0101000020E610000097AAB4C535FA4C401E37FC6EBA014C40
21226	7	61	119	7454	63616	\N	55.530757416602498	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Электрическая, 31	Россия, республика Башкортостан, Дуванский район, село Месягутово	0101000020E61000007497C45911214D40C18F6AD8EFC34B40
21224	7	61	119	7454	63616	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Электрическая, 29		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21223	7	61	119	7454	63660	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с Месягутово, Революционная, 12		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21232	7	61	119	7454	65818	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Промышленная, 20		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21225	7	61	119	7454	64019	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Партизанская, 24		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21230	7	61	119	7454	64303	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Новая, 28		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21228	7	61	119	7454	64515	\N	55.528955763627799	"Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Набережная, 14 ""В"""	Россия, республика Башкортостан, Дуванский район, село Месягутово	0101000020E61000000B43E4F4F5204D40F18288D4B4C34B40
21231	7	61	119	7454	66356	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Магистральная, 12		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21222	7	61	119	7454	65380	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Крупская, 1		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21227	7	61	119	7454	64087	\N	55.527738999999997	Республика Башкортостан, Дуванский район, Месягутовский сельсовет, с. Месягутово, Коммунистическая, 71		0101000020E6100000E9D32AFA43214D4070E998F38CC34B40
21251	7	61	119	8804	65385	\N	55.744368000000001	Республика Башкортостан, Дуванский район, Лемазинский сельсовет, с. Лемазы, Молодежная, 27		0101000020E61000000937195586094D402F185C7347DF4B40
21236	7	61	119	8081	66347	\N	55.567644733925398	Республика Башкортостан, Дуванский район, Ариевский сельсовет, д. Каракулево, Речная, 4	Россия, республика Башкортостан, Дуванский район, село Каракулево	0101000020E610000072FDBB3E73164D40745E6397A8C84B40
21647	7	61	119	8738	65969	\N	55.625261999999999	деревня Калмаш, Центральная, 22	Россия, республика Башкортостан, Дуванский район, село Калмаш	0101000020E61000003AE63C635FBC4C403DB7D09508D04B40
21250	7	61	119	8738	65969	\N	55.625261999999999	Республика Башкортостан, Дуванский район, Дуванский сельсовет, с. Калмаш, Центральная, 3		0101000020E61000003AE63C635FBC4C403DB7D09508D04B40
21239	7	61	119	216	66883	\N	55.383924999999998	Республика Башкортостан, Дуванский район, Рухтинский сельсовет, д. Кадырово, ул. Первомайская, 38		0101000020E610000024F25D4A5D244D40F38E537424B14B40
21259	7	61	119	9162	65932	\N	56.089855	Республика Башкортостан, Дуванский район, Заимкинский сельсовет, Заимка, Советская, 18		0101000020E6100000FE0DDAAB8FC94C40E8305F5E800B4C40
21245	7	61	119	8530	66668	\N	55.689886999999999	Республика Башкортостан, Дуванский район, Дуванский сельсовет, с. Дуван, Ленина, 39		0101000020E610000062307F85CCF14C40C0779B374ED84B40
21174	7	61	57	5006	64427	\N	53.785704000000003	Республика Башкортостан, Гафурийский район, Мраковский сельсовет, с.Мраково, Партизанская, 6		0101000020E6100000212235ED62184C400F2BDCF291E44A40
21246	7	61	119	8530	64485	\N	55.698034186699502	Республика Башкортостан, Дуванский район, Дуванский сельсовет, с. Дуван, Гагарина, 51	Россия, республика Башкортостан, Дуванский район, село Дуван	0101000020E610000075E789E76CF14C407FBF982D59D94B40
21253	7	61	119	8903	64096	\N	55.799522000000003	Республика Башкортостан, Дуванский район, Вознесенский сельсовет, с. Вознесенка, Центральная, 101		0101000020E6100000C99063EB19F84C405D37A5BC56E64B40
21235	7	61	119	8005	64358	\N	55.613326000000001	Республика Башкортостан, Дуванский район, Ариевский сельсовет, с. Ариево, Салавата Юлаева, 4		0101000020E6100000973AC8EBC11A4D40ACE4637781CE4B40
21219	7	61	732	58778	66439	\N	54.094999000000001	Республика Башкортостан, Давлекановский район, Чуюнчинский сельсовет, с.Чуюнчи-Николаевка, Центральная, 2а	Россия, республика Башкортостан, Давлекановский район, село ЧуюнчиНиколаевка	0101000020E61000008F8AFF3BA2B64B408C135FED280C4B40
21218	7	61	732	7260	66344	\N	54.1004891007384	Республика Башкортостан, Давлекановский район, Чуюнчинский сельсовет, с.Чуюнчи, Центральная, 19/2	Россия, республика Башкортостан, Давлекановский район, село Чуюнчи	0101000020E610000036E50AEF72AF4B40CB4DD4D2DC0C4B40
21200	7	61	732	6374	65383	\N	54.114731999999997	Республика Башкортостан, Давлекановский район, Кадыргуловский сельсовет, с.Хусаиново, Озерная, 6/2		0101000020E6100000A9674128EFC74B40FFE6C589AF0E4B40
21198	7	61	732	6269	65812	\N	54.226374999999997	Республика Башкортостан, Давлекановский район, Имай-Кармалинский сельсовет, с.Ташлы-Шарипово, Озерная, 7/1		0101000020E61000001B834E081DA84B40E5D022DBF91C4B40
21217	7	61	732	7187	65814	\N	54.200349000000003	Республика Башкортостан, Давлекановский район, Соколовский сельсовет, д.Соколовка, Школьная, 14		0101000020E61000001D1CEC4D0C8F4B40A6643909A5194B40
21215	7	61	732	7087	64284	\N	54.213076999999998	Республика Башкортостан, Давлекановский район, Сергиопольский сельсовет, д.Сергиополь, Центральная, 1		0101000020E6100000DECB7D7214784B40D0436D1B461B4B40
21192	7	61	732	5954	66833	\N	54.315998	Республика Башкортостан, Давлекановский район, Алгинский сельсовет, д.Романовка,  Молодежная, 13		0101000020E610000091459A7807684B40FBCC599F72284B40
21003	7	61	732	6981	65659	\N	54.289625626505497	с. Рассвет, Школьная, 5а	Россия, республика Башкортостан, Давлекановский район, село Рассвет	0101000020E610000034A2B437F87A4B402009FB7612254B40
21212	7	61	732	6981	66679	\N	54.289524999999998	Республика Башкортостан, Давлекановский район, Рассветовский сельсовет, Рассвет, Клубная, 1		0101000020E6100000E411DC48D97A4B40EC2FBB270F254B40
21211	7	61	732	6886	64877	\N	54.124409999999997	Республика Башкортостан, Давлекановский район, Раевский сельсовет, д.Раево, Каримова, 5		0101000020E61000008F006E162F964B40CEA5B8AAEC0F4B40
21210	7	61	732	6865	64885	\N	54.324675274921098	Республика Башкортостан, Давлекановский район, Поляковский сельсовет, с.Поляковка, Поляковская, 3	Россия, республика Башкортостан, Давлекановский район, село Поляковка	0101000020E610000022C7D63384854B40166A4DF38E294B40
21202	7	61	732	6467	65810	\N	54.32282	Республика Башкортостан, Давлекановский район, Казангуловский сельсовет, с.Новояппарово, Школьная, 18		0101000020E6100000363D282845994B40533F6F2A52294B40
21199	7	61	732	6302	64024	\N	54.193964999999999	Республика Башкортостан, Давлекановский район, Кадыргуловский сельсовет, д.Новоянбеково, Мира, 57а		0101000020E6100000A453573ECBC74B40C9C859D8D3184B40
21207	7	61	732	6727	64875	\N	54.135147000000003	Республика Башкортостан, Давлекановский район, Курманкеевский сельсовет, с.Новоаккулаево, Салавата, 34		0101000020E6100000B58CD47B2A814B408693347F4C114B40
21214	7	61	732	7049	64880	\N	54.357090973317398	Республика Башкортостан, Давлекановский район, Рассветовский сельсовет, с.Ленинский, Полевая, 4	Россия, республика Башкортостан, Давлекановский район, село Ленинский	0101000020E610000005C4245CC85B4B4014596B28B52D4B40
21189	7	61	732	5765	65739	\N	54.249654144979601	Республика Башкортостан, Давлекановский район, Алгинский сельсовет, с.Курьятмасово, Салавата Юлаева, 45а	Россия, республика Башкортостан, Давлекановский район, село Курятмасово	0101000020E61000005FEFFE78AF484B4065A88AA9F41F4B40
21213	7	61	732	33123	64299	\N	54.238720999999998	Республика Башкортостан, Давлекановский район, Рассветовский сельсовет, с.Комсомол, Школьная, 4а		0101000020E61000007B8505F703784B4028EFE3688E1E4B40
21204	7	61	732	6577	64300	\N	54.320216000000002	Республика Башкортостан, Давлекановский район, Кидрячевский сельсовет, с.Кидрячево, Школьная, 1/1		0101000020E61000006E3480B7403A4B40F6D37FD6FC284B40
21201	7	61	732	6423	65823	\N	54.280563999999998	Республика Башкортостан, Давлекановский район, Казангуловский сельсовет, с.Казангулово, Демская, 27		0101000020E6100000E7012CF2EB9B4B40AC376A85E9234B40
21196	7	61	732	58857	66599	\N	54.225307786267201	Республика Башкортостан, Давлекановский район, Имай-Кармалинский сельсовет, с.Имай-Карамалы, Советская, 1	Россия, республика Башкортостан, Давлекановский район, село Имай-Кармалы	0101000020E610000079B29B19FDB24B407AC37DE4D61C4B40
21195	7	61	732	6088	64085	\N	54.390158	Республика Башкортостан, Давлекановский район, Ивановский сельсовет, с.Ивановка, Механизаторская, 26		0101000020E6100000ACE4637781504B40EA2285B2F0314B40
21220	7	61	732	7342	64084	\N	54.415052000000003	Республика Башкортостан, Давлекановский район, Шестаевский сельсовет, д.Ивангород, Крестьянская, 31/4		0101000020E6100000B0E76B96CB6C4B40D811876C20354B40
21170	7	61	57	4785	65376	\N	53.921546999999997	Республика Башкортостан, Гафурийский район, Ташлинский сельсовет, д.Мендим, Центральная, 39		0101000020E6100000BEF8A23D5E644C400B5D8940F5F54A40
21206	7	61	732	6693	66346	\N	54.141169399144701	Республика Башкортостан, Давлекановский район, Курманкеевский сельсовет, с.Дюртюли, Ярыштау, 1/1	Россия, республика Башкортостан, Давлекановский район, село Дюртюли	0101000020E6100000C40AB77C24894B40C11A67D311124B40
22783	7	61	732	6693	65526	\N	54.143185000000003	с.Дюртюли, Школьная, 27		0101000020E61000009DDA19A6B6884B408E23D6E253124B40
21185	7	61	732	5107	66654	\N	54.208469999999998	Республика Башкортостан, Давлекановский район, город Давлеканово, Первомайская, 9		0101000020E61000007633A31F0D854B403B191C25AF1A4B40
21187	7	61	732	5107	63397	\N	54.208744781540602	Республика Башкортостан, Давлекановский район, город Давлеканово, Мира, 24а	Россия, республика Башкортостан, Давлекановский район, Давлеканово	0101000020E61000004436902E36854B400D1AFA27B81A4B40
21186	7	61	732	5107	63397	\N	54.208469999999998	Республика Башкортостан, Давлекановский район, город Давлеканово, Мира, 14		0101000020E61000007633A31F0D854B403B191C25AF1A4B40
21178	7	61	732	5107	63729	\N	54.208469999999998	Республика Башкортостан, Давлекановский район, город Давлеканово, Красная Площадь, 11		0101000020E61000007633A31F0D854B403B191C25AF1A4B40
21180	7	61	732	5107	63745	\N	54.2099793822238	Республика Башкортостан, Давлекановский район, город Давлеканово, Заводская, 1а	Россия, республика Башкортостан, Давлекановский район, Давлеканово	0101000020E61000005743E21E4B834B4063EC8497E01A4B40
22418	7	61	732	58685	66014	\N	54.144348200270997	с.Вязовка, Центарльная, 48	Россия, республика Башкортостан, Давлекановский район, село Вязовка	0101000020E6100000E27327D87FA34B401B9FC9FE79124B40
21209	7	61	732	6799	63590	\N	54.297297	Республика Башкортостан, Давлекановский район, Поляковский сельсовет, с.Вперед, Школьная, 13		0101000020E61000003C4A253CA18F4B407619FED30D264B40
21205	7	61	732	6636	9682	\N	54.295986738500403	Республика Башкортостан, Давлекановский район, Кидрячевский сельсовет, с.Бурангулово, Школьная, 41	Россия, республика Башкортостан, Давлекановский район, село Бурангулово	0101000020E6100000789ACC785B414B404485EAE6E2254B40
21190	7	61	732	5843	64873	\N	54.280746999999998	Республика Башкортостан, Давлекановский район, Алгинский сельсовет, д.Алга, Центральная, 31а		0101000020E61000008ACBF10A44514B409DB98784EF234B40
21173	7	61	57	69	64872	\N	53.777403999999997	Республика Башкортостан, Гафурийский район, Янгискаинский сельсовет, с.Янгискаин, Асфандиярова, 2		0101000020E610000005DF347D76264C40C9E369F981E34A40
20257	7	61	57	58723	66180	\N	54.3017955662106	д.Якты-Куль, ул.Молодежная, 6	Россия, республика Башкортостан, Гафурийский район, село Якты-Куль	0101000020E6100000EC4D0CC9C9444C4025085740A1264B40
21154	7	61	57	3911	66335	\N	54.146107000000001	Республика Башкортостан, Гафурийский район, Бурлинский сельсовет, д.Явгильды, Школьная, 21		0101000020E610000056F5F23B4D424C40BC5B59A2B3124B40
21163	7	61	57	4371	64017	\N	54.228338000000001	Республика Башкортостан, Гафурийский район, Ковардинский сельсовет, д.Юлуково, Центральная, 77		0101000020E6100000CCD1E3F736534C408F37F92D3A1D4B40
21161	7	61	57	4253	65817	\N	54.151116999999999	Республика Башкортостан, Гафурийский район, Саитбабинский сельсовет, д.Юзимяново, 30 лет Победы, 25		0101000020E61000002975C938464C4C40506F46CD57134B40
21171	7	61	57	4822	65377	\N	53.727310000000003	Республика Башкортостан, Гафурийский район, Утяковский сельсовет, с.Утяково, Чапаева, 2		0101000020E610000030293E3E21374C40E2067C7E18DD4A40
21156	7	61	57	4011	64229	\N	54.187938000000003	Республика Башкортостан, Гафурийский район, Зилим-Карановский сельсовет, д.Узбяково, Школьная, 10		0101000020E610000093399677D53B4C407CD6355A0E184B40
21172	7	61	57	4892	64871	\N	53.7415896535705	Республика Башкортостан, Гафурийский район, Утяковский сельсовет, д.Тугаево, Центральная, 2б	Россия, республика Башкортостан, Гафурийский район, село Тугаево	0101000020E6100000EAE8B81AD92B4C403485CE6BECDE4A40
21027	7	61	57	4892	64871	\N	53.744439	с.Тугаево, Центральная, 36		0101000020E61000000B5D8940F52B4C40F86EF3C649DF4A40
21076	7	61	57	4892	66291	\N	53.744540725260102	д. Тугаево, Победы, 31	Россия, республика Башкортостан, Гафурийский район, село Тугаево	0101000020E610000085D1AC6C1F2C4C40FCC3961E4DDF4A40
21168	7	61	57	4669	64868	\N	54.025573000000001	Республика Башкортостан, Гафурийский район, д.Толпарово, Центральная, 11		0101000020E6100000D63A71395E8D4C408F54DFF945034B40
21169	7	61	57	4727	64870	\N	53.898553999999997	Республика Башкортостан, Гафурийский район, Ташлинский сельсовет, д.Ташла, переулок Школьный, 4		0101000020E61000005FB7088CF5514C4051D845D103F34A40
21148	7	61	57	3614	66240	\N	53.941352000000002	Республика Башкортостан, Гафурийский район, Белоозерский сельсовет, д.Татарский Саскуль, Школьная, 2		0101000020E61000007C478D0931234C401903EB387EF84A40
21124	7	61	57	2240	64015	\N	53.981459000000001	с.Табынское, Школьная, 6		0101000020E61000002F36AD1402314C40B4AED172A0FD4A40
21140	7	61	57	2240	64362	\N	53.981459000000001	с.Табынское, Центральная, 55		0101000020E61000002F36AD1402314C40B4AED172A0FD4A40
21159	7	61	57	4124	64191	\N	54.086449000000002	Республика Башкортостан, Гафурийский район, Саитбабинский сельсовет, с.Саитбаба, Партизанская, 50		0101000020E6100000E204A6D3BA594C40CEE2C5C2100B4B40
21158	7	61	57	4124	64016	\N	54.086449000000002	Республика Башкортостан, Гафурийский район, Саитбабинский сельсовет, с.Саитбаба, Вахитова, 31		0101000020E6100000E204A6D3BA594C40CEE2C5C2100B4B40
21149	7	61	57	3663	65172	\N	53.906215418292	Республика Башкортостан, Гафурийский район, Белоозерский сельсовет, д.Русский Саскуль, Чапаева, 17	Россия, республика Башкортостан, Гафурийский район, село Русский Саскуль	0101000020E6100000137CD3F4D91D4C40841266DAFEF34A40
21084	7	61	57	33014	64340	\N	53.944128999999997	с.Родина, Центральная, 4		0101000020E6100000209C4F1DAB324C40431A1538D9F84A40
21144	7	61	57	3393	64864	\N	53.838585999999999	Республика Башкортостан, Гафурийский район, Бельский сельсовет, д.Кутлугуза, Кооперативная, 26а		0101000020E6100000373811FDDA244C4015713AC956EB4A40
21138	7	61	57	58138	63850	\N	53.924914000000001	с.Курорта, Ключевая, 10	Россия, республика Башкортостан, Гафурийский район, село Курорт	0101000020E61000005FB35C363A434C4068CEFA9463F64A40
21152	7	61	57	3816	65368	\N	54.134175999999997	Республика Башкортостан, Гафурийский район, Бурлинский сельсовет, д.Курмантау, Школьная, 38		0101000020E61000003F1EFAEE56324C403CF4DDAD2C114B40
21166	7	61	57	4565	65369	\N	53.814315000000001	Республика Башкортостан, Гафурийский район, д.Кургашла, Лесная, 3		0101000020E6100000CDCAF6216F4F4C4035D252793BE84A40
21135	7	61	57	2641	64432	\N	53.895175000000002	с.Красноусольский, Чкалова, 20		0101000020E6100000855D143DF03B4C4031992A1895F24A40
21133	7	61	57	2641	63385	\N	53.895175000000002	с.Красноусольский, Фрунзе, 40		0101000020E6100000855D143DF03B4C4031992A1895F24A40
21139	7	61	57	2641	66823	\N	53.894667653379301	Республика Башкортостан, Гафурийский район, Красноусольский сельсовет, с.Красноусольский, Садовая, 25	Россия, республика Башкортостан, Гафурийский район, поселок Красноусольский	0101000020E6100000F4F928232E3C4C408D63247B84F24A40
21134	7	61	57	2641	63666	\N	53.895175000000002	с.Красноусольский, Ленина, 33		0101000020E6100000855D143DF03B4C4031992A1895F24A40
21137	7	61	57	2641	63389	\N	53.895175000000002	с.Красноусольский, Коммунистическая, 45		0101000020E6100000855D143DF03B4C4031992A1895F24A40
21131	7	61	57	2641	64511	\N	53.892640162183397	с.Красноусольский, Комарова, 13	Россия, республика Башкортостан, Гафурийский район, поселок Красноусольский	0101000020E610000099BA2BBB603C4C40FC8C0B0742F24A40
21132	7	61	57	2641	64301	\N	53.895175000000002	с.Красноусольский, Калмыкова, 16/1		0101000020E6100000855D143DF03B4C4031992A1895F24A40
21136	7	61	57	2641	64169	\N	53.895175000000002	с.Красноусольский, К.Маркса, 72		0101000020E6100000855D143DF03B4C4031992A1895F24A40
21162	7	61	57	4350	64351	\N	54.210923000000001	Республика Башкортостан, Гафурийский район, Ковардинский сельсовет, с.Коварды, Заки Валиди, 32		0101000020E6100000D0B69A75C6614C40B37C5D86FF1A4B40
21165	7	61	57	4484	64082	\N	54.140759000000003	Республика Башкортостан, Гафурийский район, Имендяшевский сельсовет, с.Карагаево, Центральная, 52		0101000020E6100000C619C39CA0594C4010CF126404124B40
21143	7	61	57	3334	65367	\N	53.8749225415796	Республика Башкортостан, Гафурийский район, Бельский сельсовет, с.Инзелга, Школьная, 24а	Россия, республика Башкортостан, Гафурийский район, село Инзелга	0101000020E610000016A5846055274C4055C2137AFDEF4A40
21164	7	61	57	4469	64867	\N	54.137531000000003	Республика Башкортостан, Гафурийский район, Имендяшевский сельсовет, с.Имендяшево, Колхозная, 47		0101000020E6100000CA6FD1C952614C40D597A59D9A114B40
21157	7	61	57	4071	66339	\N	54.241898999999997	Республика Башкортостан, Гафурийский район, Зилим-Карановский сельсовет, д.Ибрагимово, Бикташева, 2		0101000020E610000021CA17B4904C4C40B1F7E28BF61E4B40
21155	7	61	57	3959	66340	\N	54.233753	Республика Башкортостан, Гафурийский район, Зилим-Карановский сельсовет, с.Зилим-Караново, М.Гафури, 17		0101000020E61000002D793C2D3F464C40C32B499EEB1D4B40
21175	7	61	57	5018	66342	\N	53.720582	Республика Башкортостан, Гафурийский район, Буруновский сельсовет, с.Буруновка, Молодежная, 10		0101000020E6100000A1D79FC4E71C4C400B0BEE073CDC4A40
21150	7	61	57	3712	64866	\N	54.130656999999999	Республика Башкортостан, Гафурийский район, Бурлинский сельсовет, с.Бурлы, Казанская, 21		0101000020E6100000297B4B395F3C4C402AFF5A5EB9104B40
21142	7	61	57	3285	65808	\N	54.080774480760098	Республика Башкортостан, Гафурийский район, Табынский сельсовет, д.Березовка, Школьная, 20	Россия, республика Башкортостан, Гафурийский район, село Березовка	0101000020E6100000986C3CD8623D4C40FD2E6CCD560A4B40
20889	7	61	57	3285	66358	\N	54.078248792142503	с. Березовка, Советская, 6	Россия, республика Башкортостан, Гафурийский район, село Березовка	0101000020E6100000ACE5CE4C303E4C40ECF82F10040A4B40
21428	7	61	57	3285	65496	\N	54.078955393288901	д.Березовка, ул.Школьная, 12	Россия, республика Башкортостан, Гафурийский район, село Березовка	0101000020E6100000AD31E884D03D4C40876D8B321B0A4B40
21145	7	61	57	58194	66954	\N	53.994899664382203	Республика Башкортостан, Гафурийский район, Белоозерский сельсовет, с.Белое Озеро, Элеваторная, 1/5	Россия, республика Башкортостан, Гафурийский район, село Белое Озеро	0101000020E61000004BE5ED08A71D4C402C6519E258FF4A40
21146	7	61	57	58194	64234	\N	53.989318894975597	с.Белое Озеро, Школьная, 6	Россия, республика Башкортостан, Гафурийский район, село Белое Озеро	0101000020E61000009604A8A9651D4C40DD274701A2FE4A40
21151	7	61	57	3754	66333	\N	54.169437000000002	Республика Башкортостан, Гафурийский район, Бурлинский сельсовет, д.Баимбетово, Центральная, 9		0101000020E61000004DBC033C69394C40BEDD921CB0154B40
21141	7	61	57	3232	66238	\N	54.070104999999998	Республика Башкортостан, Гафурийский район, Табынский сельсовет, с.Архангельское, Центральная, 31		0101000020E61000001AC40776FC334C409E245D33F9084B40
20334	7	61	57	3232	63280	\N	54.070104999999998	с. Архангельское, Н.Крупской, 3		0101000020E61000001AC40776FC334C409E245D33F9084B40
21147	7	61	57	3562	64315	\N	53.993741	Республика Башкортостан, Гафурийский район, Белоозерский сельсовет, с.Антоновка, Школьная, 5		0101000020E61000009B75C6F7C5234C40E0D8B3E732FF4A40
21104	7	61	158	1090	66753	\N	53.327235000000002	Республика Башкортостан, Бурзянский район, Байназаровский сельсовет, д. Яумбаево, ул. Школьная, 1		0101000020E6100000E4688EACFCD04C40A48D23D6E2A94A40
21130	7	61	158	9346	66662	\N	53.180447000000001	Республика Башкортостан, Бурзянский район, Тимеровский сельсовет, д. Тимерово, ул. Агидели, 9		0101000020E610000082397AFCDEC44C40A6D425E318974A40
21123	7	61	158	2007	66337	\N	53.103223164048003	Республика Башкортостан, Бурзянский район, Старосубхангуловский сельсовет, с. Старосубхангулово, ул.  Школьная, 1	Россия, республика Башкортостан, Бурзянский район, село Старосубхангулово	0101000020E610000095D39E9273B84C40F6984869368D4A40
21122	7	61	158	2007	64225	\N	53.104897102119601	Республика Башкортостан, Бурзянский район, Старосубхангуловский сельсовет, с. Старосубхангулово, ул.  М.Гареева, 16	Россия, республика Башкортостан, Бурзянский район, село Старосубхангулово	0101000020E6100000848252B472B74C406939D0436D8D4A40
21129	7	61	158	2007	63518	\N	53.105341000000003	Республика Башкортостан, Бурзянский район, Старосубхангуловский сельсовет, с. Старосубхангулово, ул.  Ленина, 74		0101000020E610000010CCD1E3F7B64C40C7F65AD07B8D4A40
21125	7	61	158	2007	64296	\N	53.104173943076603	Республика Башкортостан, Бурзянский район, Старосубхангуловский сельсовет, с. Старосубхангулово, ул.  Кызыл-Таш, 16	Россия, республика Башкортостан, Бурзянский район, село Старосубхангулово	0101000020E61000000AF2B391EBB84C40F88BD992558D4A40
21128	7	61	158	2479	66330	\N	53.159588999999997	Республика Башкортостан, Бурзянский район, Старосубхангуловский сельсовет, д. Старомусятово, ул. Сакмагош, 28		0101000020E61000003A4030478FB54C4092E68F696D944A40
21121	7	61	158	2077	65800	\N	53.227958999999998	Республика Башкортостан, Бурзянский район, Старомунасиповский сельсовет, д. Старомунасипово, ул.  С.Юлаева, 5		0101000020E61000007958A835CDC94C4018EAB0C22D9D4A40
21117	7	61	158	1827	66694	\N	53.345064999999998	Республика Башкортостан, Бурзянский район, Кулганинский сельсовет, д. Саргая, ул.  Центральная, 7		0101000020E61000008B18761893E44C4043FF04172BAC4A40
21099	7	61	158	784	66733	\N	53.066789	Республика Башкортостан, Бурзянский район, Байгазинский сельсовет, д. Новоусманово, ул.  г. Шаймуратова, 1		0101000020E6100000649291B3B0D34C40C45DBD8A8C884A40
21127	7	61	158	2432	66839	\N	53.144694999999999	Республика Башкортостан, Бурзянский район, Старосубхангуловский сельсовет, д. Новосубхангулово, ул. Школьная, 2		0101000020E610000047C7D5C8AEB84C408672A25D85924A40
21126	7	61	158	2363	64863	\N	53.202010999999999	Республика Башкортостан, Бурзянский район, Старосубхангуловский сельсовет, д. Новомусятово, ул.  З. Валиди, 15		0101000020E6100000D656EC2FBBAF4C405437177FDB994A40
21119	7	61	158	1957	66776	\N	53.237797088927202	Республика Башкортостан, Бурзянский район, Старомунасиповский сельсовет, д. Новомунасипово, ул.  М.Сагитова, 30	Россия, республика Башкортостан, Бурзянский район, село Новомунасипово	0101000020E6100000E998F38C7DC54C40200BD121709E4A40
21118	7	61	158	716	66829	\N	53.261035029770802	Республика Башкортостан, Бурзянский район, Старомунасиповский сельсовет, д. Набиево, ул.  А.Сатвалова, 15	Россия, республика Башкортостан, Бурзянский район, село Набиево	0101000020E6100000A185048C2EC54C40410E4A9869A14A40
21103	7	61	158	1049	66909	\N	53.341264000000002	Республика Башкортостан, Бурзянский район, Байназаровский сельсовет, д. Мурадымово, ул. Школьная, 5		0101000020E610000053060E68E9C24C40ADA6EB89AEAB4A40
20866	7	61	158	1049	65806	\N	53.341081966594103	д.Мурадымово, Мусы Гареева, 28		0101000020E6100000FBAD9D2809C34C408CA03193A8AB4A40
21112	7	61	158	1561	66728	\N	53.053702999999999	Республика Башкортостан, Бурзянский район, Киекбаевский сельсовет, д. Миндигулово, ул. Агидели, 27		0101000020E61000007B6AF5D555AB4C403A596ABDDF864A40
21115	7	61	158	1712	66844	\N	53.28519	Республика Башкортостан, Бурзянский район, Кипчакский сельсовет, д. Малый Кипчак,  ул.Молодежная, 5		0101000020E6100000912C6002B7E44C40B8921D1B81A44A40
21109	7	61	158	1377	66332	\N	53.004599032662	Республика Башкортостан, Бурзянский район, Иргизлинский сельсовет, д. Максютово, ул.  Школьная, 23	Россия, республика Башкортостан, Бурзянский район, село Максютово	0101000020E6100000E61E12BEF7794C40124C35B396804A40
21102	7	61	158	942	66793	\N	53.386271000000001	Республика Башкортостан, Бурзянский район, Байназаровский сельсовет, д. Магадеево, ул. З.Валиди, 37		0101000020E6100000A96917D34CCF4C405532005471B14A40
21108	7	61	158	1324	66663	\N	52.984073000000002	Республика Башкортостан, Бурзянский район, Иргизлинский сельсовет, д. Кутаново, ул. Туйбага, 4		0101000020E6100000D3DC0A6135844C4035F0A31AF67D4A40
21101	7	61	158	925	66907	\N	53.277566	Республика Башкортостан, Бурзянский район, Байназаровский сельсовет, д. Кургашлы, ул. Школьная, 1		0101000020E6100000E4654D2CF0C54C40A33D5E4887A34A40
21116	7	61	158	1775	66813	\N	53.363376000000002	Республика Башкортостан, Бурзянский район, Кулганинский сельсовет, д. Кулганино, ул.Ш.Шакмана, 6		0101000020E61000007C9C69C2F6F94C405E13D21A83AE4A40
21114	7	61	158	1657	66711	\N	53.279547999999998	Республика Башкортостан, Бурзянский район, Кипчакский сельсовет, д. Кильдигулово, ул.  Молодежная, 21		0101000020E610000095B7239C16EE4C40C3D4963AC8A34A40
21111	7	61	158	1496	66676	\N	53.046698999999997	Республика Башкортостан, Бурзянский район, Киекбаевский сельсовет, д. Киекбаево, ул. Школьная, 11		0101000020E610000026A94C3107A14C40C1E09A3BFA854A40
21096	7	61	158	614	66701	\N	53.414209999999997	Республика Башкортостан, Бурзянский район, Аскаровский сельсовет, д. Исламбаево, ул. Сыбайялан,  4		0101000020E6100000317C444C89A44C408CD651D504B54A40
21107	7	61	158	33107	66952	\N	52.9595202559032	Республика Башкортостан, Бурзянский район, Иргизлинский сельсовет, д. Иргизла, ул. Заповедная, 6а	Россия, республика Башкортостан, Бурзянский район, село Иргизлы	0101000020E6100000CA703C9F01834C40D0ED258DD17A4A40
21057	7	61	58	31101	65049	\N	55.939605	д. Ваныш-Алпаутово, Молодежная, 7		0101000020E6100000D3DB9F8B86B64B403C1405FA44F84B40
21106	7	61	158	1201	66625	\N	53.268282999999997	Республика Башкортостан, Бурзянский район, Галиакберовский сельсовет, д. Галиакберово, ул.  Центральная, 88		0101000020E6100000C4CE143AAF874C405089EB1857A24A40
21110	7	61	158	1441	66773	\N	53.078313000000001	Республика Башкортостан, Бурзянский район, Киекбаевский сельсовет, д. Гадельгареево, ул.  Шульган, 23а		0101000020E6100000CBD93BA3AD864C4003ED0E29068A4A40
21095	7	61	158	563	66647	\N	53.538969999999999	Республика Башкортостан, Бурзянский район, Аскаровский сельсовет, д. Бретяк, ул. Школьная, 3		0101000020E6100000A60BB1FA239A4C4037C30DF8FCC44A40
21100	7	61	158	845	66869	\N	53.29419	Республика Башкортостан, Бурзянский район, Байназаровский сельсовет, д. Байназарово, ул. Октября, 31		0101000020E610000006D50627A2C54C40B6679604A8A54A40
21098	7	61	158	715	66840	\N	53.162838999999998	Республика Башкортостан, Бурзянский район, д.Байгазино, ул.Горная, 2		0101000020E61000002E71E481C8DC4C40B5C189E8D7944A40
21097	7	61	158	667	66893	\N	53.010440000000003	Республика Башкортостан, Бурзянский район, Атиковский сельсовет, д. Атиково, ул.  Дружбы, 1		0101000020E6100000A7ECF483BAAE4C40FE48111956814A40
20229	7	61	158	459	\N	\N	53.460979999999999	с.Аскарово, ул.Ленина, 8	Россия, республика Башкортостан, Бурзянский район, село Аскарово	0101000020E61000003E5A9C31CCAB4C40170E846401BB4A40
21094	7	61	158	459	66601	\N	53.460979999999999	Республика Башкортостан, Бурзянский район, Аскаровский сельсовет, д. Аскарово, ул. Школьная, 5		0101000020E61000003E5A9C31CCAB4C40170E846401BB4A40
20227	7	61	158	459	63632	\N	53.460979999999999	с.Аскарово, ул.Р.Давлетова, 24		0101000020E61000003E5A9C31CCAB4C40170E846401BB4A40
20225	7	61	158	459	63804	\N	53.460979999999999	с.Аскарово, ул.Ленина, 43		0101000020E61000003E5A9C31CCAB4C40170E846401BB4A40
21113	7	61	158	1610	66698	\N	53.279580000000003	Республика Башкортостан, Бурзянский район, Кипчакский сельсовет, д. Абдулмамбетово, ул.  С.Мухаметкулова, 21		0101000020E6100000E71BD13DEBDC4C40CF4E0647C9A34A40
21048	7	61	58	58771	66425	\N	55.801126751599199	д. Шабаево, Султанова, 40	Россия, республика Башкортостан, Бураевский район, село Шабаево	0101000020E6100000C991CEC0C8AF4B40A7785C548BE64B40
21085	7	61	58	32511	65662	\N	55.860245999999997	д. Чишма-Бураево, Ключевая, 30		0101000020E61000001689096AF8C24B40E5417A8A1CEE4B40
21092	7	61	58	347	64343	\N	55.699289	с.Челкаково, Пинегина, 6		0101000020E61000007D3D5FB35C864B40EDB94C4D82D94B40
21086	7	61	58	32433	64793	\N	55.789746368080401	д.Тангатарово, Школьная, 22	Россия, республика Башкортостан, Бураевский район, село Тангатарово	0101000020E6100000024BAE62F1794B40CB129D6516E54B40
21082	7	61	58	32252	64678	\N	55.867641999999996	д.Старотазларово, Лебединая, 25		0101000020E610000024D3A1D3F3D04B4069519FE40EEF4B40
21080	7	61	58	32192	66228	\N	55.910598999999998	д. Старокизганово, Пушкина, 6		0101000020E610000083C13577F4D74B4099620E828EF44B40
21070	7	61	58	31719	65657	\N	55.742503999999997	д. Старокарагушево, Мира, 10		0101000020E610000056D80C7041E64B401893FE5E0ADF4B40
21056	7	61	58	31029	66209	\N	55.740796000000003	д. Старобикметово, Школьная, 3		0101000020E6100000E99D0AB8E7AD4B40FA804067D2DE4B40
21055	7	61	58	58863	66623	\N	55.694980501907501	д. Силосово, Школьная, 1	Россия, республика Башкортостан, Бураевский район, село Силасово	0101000020E610000025CE8AA889A84B40B22B2D23F5D84B40
21088	7	61	58	71	65091	\N	55.824950999999999	д.Саит-Курзя, Школьная, 2		0101000020E6100000535BEA20AF834B40B8E68EFE97E94B40
21081	7	61	58	32221	66229	\N	55.844712999999999	д.Новотазларово, Школьная, 1		0101000020E6100000134548DDCEC84B40C6C03A8E1FEC4B40
21051	7	61	58	30800	66263	\N	55.696430447410997	д. Новомустафино, Мира, 28	Россия, республика Башкортостан, Бураевский район, село Новомустафино	0101000020E6100000C24CDBBFB2C64B4005FA449E24D94B40
21079	7	61	58	32116	66231	\N	55.887861999999998	д. Новокизганово, г.Тукая, 27		0101000020E6100000E0BC38F1D5D84B403AAE4676A5F14B40
21062	7	61	58	31319	65058	\N	55.562840999999999	с. Новоельдяково, Школьная, 55		0101000020E610000067D13B15709F4B4089EC832C0BC84B40
21063	7	61	58	31400	64660	\N	55.664979000000002	д. Новобикметово, Школьная, 14		0101000020E610000025AFCE3120914B406EC328081ED54B40
22501	7	61	58	46467	65264	\N	56.008194813642	с.Николаевка, Школьная, 2	Россия, республика Башкортостан, Бураевский район, село Николаевка	0101000020E610000000E2AE5E45C84B40D07EA4880C014C40
22364	7	61	58	46467	66868	\N	56.008338999999999	453145, РБ Стерлитамакский район, с. Николаевка, ул. Ушакова, д. 7		0101000020E6100000FD1186014BC84B4003249A4011014C40
21052	7	61	58	29569	66852	\N	55.752706562357403	д.Муллино, ул.Горная,1	Россия, республика Башкортостан, Бураевский район, село Муллино	0101000020E61000005FD0420246B94B40323CF6B358E04B40
21058	7	61	58	31128	66534	\N	55.991370893737901	д. Минлино, Полевая, 13	Россия, республика Башкортостан, Бураевский район, село Минлино	0101000020E6100000E4C0ABE5CEB84B40F699B33EE5FE4B40
21050	7	61	58	30727	64656	\N	55.778759999999998	д. Мамады, Школьная, 8		0101000020E6100000D6355A0EF4CC4B406BB75D68AEE34B40
21074	7	61	58	31909	65594	\N	55.810035999999997	д. Кушманаково, Роберта Ахметгалиева, 57		0101000020E61000000F7C0C569CA04B40944A7842AFE74B40
21066	7	61	58	31529	65654	\N	55.778046000000003	д. Кулаево, Школьная, 22		0101000020E61000003B8F8AFF3B9C4B404E64E60297E34B40
21071	7	61	58	31782	65658	\N	55.907940000000004	д. Кузбаево, Школьная, 9		0101000020E6100000DE550F9887A84B40795DBF6037F44B40
21075	7	61	58	58718	66156	\N	55.855561492799801	д. Кудашево, Малика Вахитова, 7	Россия, республика Башкортостан, Бураевский район, село Кудашево	0101000020E6100000751E15FF77A44B40D55DD90583ED4B40
21067	7	61	58	31595	66216	\N	55.784972000000003	д. Кашкалево, Ахмета Закирова, 24		0101000020E6100000CCB8A981E6DF4B404B2366F679E44B40
21083	7	61	58	58823	66527	\N	55.893780397586298	д.Касиярово, Школьная, 3	Россия, республика Башкортостан, Бураевский район, село Касиярово	0101000020E6100000629D2ADF33CE4B40D1E80E6267F24B40
21078	7	61	58	32097	65660	\N	55.823918999999997	д. Каратамак, Солнечная, 32		0101000020E61000005DA626C11B9A4B40C9C6832D76E94B40
21065	7	61	58	48051	65069	\N	55.736904000000003	д. Карабаево, Набережная, 8		0101000020E610000043C70E2A71914B405325CADE52DE4B40
21064	7	61	58	31427	66212	\N	55.769449000000002	д. Каинлыково, Молодежная, 12		0101000020E6100000F486FBC8AD914B404F78094E7DE24B40
21068	7	61	58	31624	66213	\N	55.768481000000001	д. Даутларово, Свободы, 18		0101000020E61000007E52EDD3F1DA4B40774CDD955DE24B40
21053	7	61	58	30903	64259	\N	55.692506000000002	д. Большебадраково, Ленина, 9		0101000020E610000031D120054FA14B4053245F09A4D84B40
21054	7	61	58	30932	64787	\N	55.731479999999998	д. Берлячево, Мира, 4		0101000020E61000006002B7EEE69B4B40CBD6FA22A1DD4B40
20538	7	61	58	5884	63278	\N	55.821086999999999	село Бакалы, улица Шакирьянова, дом 2		0101000020E6100000B01C210379DC4B40DB15FA6019E94B40
20532	7	61	58	5884	63652	\N	55.821086999999999	село Бакалы, улица Октябрьская, дом 94		0101000020E6100000B01C210379DC4B40DB15FA6019E94B40
21069	7	61	58	5884	66345	\N	55.822969282605499	д. Бакалы, Луговая, 4	Россия, республика Башкортостан, Бураевский район, село Бакалы	0101000020E61000001286014BAEDC4B40984F560C57E94B40
21091	7	61	58	278	65663	\N	56.075569000000002	д. Байшады, Гагарина, 1		0101000020E61000004B1E4FCB0FCE4B40B4CBB73EAC094C40
21090	7	61	58	210	66233	\N	56.010292	д. Арняшево, Мира, 24		0101000020E6100000C5538F34B8CB4B4089B48D3F51014C40
21072	7	61	58	31830	66217	\N	55.933982999999998	д. Алтаево, Мира, 35		0101000020E610000089D4B48B69AE4B408E0244C18CF74B40
21049	7	61	58	30683	65665	\N	55.766176999999999	д. Азяково, Школьная, 31		0101000020E6100000AB5B3D27BDC14B4044F9821612E24B40
21077	7	61	58	48301	65775	\N	55.807127000000001	д. Абзаево, Школьная, 14	Россия, республика Башкортостан, Бураевский район, село Абзаево	0101000020E6100000FEB968C878944B40FB5B02F04FE74B40
21041	7	61	1021	58779	66442	\N	54.460564456747903	с.Сарайгир, Мира, 4а	Россия, республика Башкортостан, Буздякский район, село отделение Сарайгирское Совхоза Уртакульский	0101000020E610000006BEA25BAF394B4083DBDAC2F33A4B40
21021	7	61	1021	47227	65135	\N	54.813837999999997	с. Якупово, Центральная, 46/1		0101000020E6100000EEAF1EF7AD444B40FB1EF5D72B684B40
20993	7	61	1021	28088	64772	\N	54.607971999999997	д. Юлдузлы, Центральная, 19/1		0101000020E61000005917B7D1002A4B401D71C806D24D4B40
20992	7	61	1021	58772	66427	\N	54.595379431954797	д. Шланлыкуль, Центральная, 61/1	Россия, республика Башкортостан, Буздякский район, село Шланлыкулево	0101000020E6100000CCD24ECDE5364B40D3DC0A61354C4B40
21022	7	61	1021	29374	64651	\N	54.751694999999998	д.Шарбаш, Центральная, 25/2		0101000020E61000000D36751E15434B408AC8B08A37604B40
21025	7	61	1021	58630	65794	\N	54.907128999999998	д.Чишма, Салавата, 35	Россия, республика Башкортостан, Буздякский район, село Чишма	0101000020E610000044A4A65D4C554B40682096CD1C744B40
21040	7	61	1021	58834	66546	\N	54.516700148797	с.Уртакуль, Школьная, 20		0101000020E6100000EEED96E4803B4B40EEEBC03923424B40
20994	7	61	1021	28106	64195	\N	54.698566999999997	с. Урзайбаш, Мостовая, 32/1		0101000020E61000002D23F59ECA2F4B404C88B9A46A594B40
21017	7	61	1021	29161	64250	\N	54.706161999999999	с.Ураново, 60 лет СССР, 6		0101000020E610000094F8DC09F63D4B40C7D63384635A4B40
21030	7	61	1021	29752	64049	\N	54.907755000000002	с.Тюрюшево, Революционная, 40а		0101000020E6100000EECD6F9868484B40E7E3DA5031744B40
21005	7	61	1021	58551	65477	\N	54.507750999999999	с. Ташлыкуль, Молодежная, 10а		0101000020E6100000245F09A4C4444B4072C119FCFD404B40
21008	7	61	1021	28772	65474	\N	54.409886	д.Таллыкулево, Центральная, 15		0101000020E6100000BCB376DB85304B404C8BFA2477344B40
21028	7	61	1021	58807	66497	\N	54.853074477108599	с.Старый Шигай, Центральная, 39	Россия, республика Башкортостан, Буздякский район, село Староый Шигай	0101000020E6100000C539EAE8B83E4B40B1886187316D4B40
21038	7	61	1021	30137	64790	\N	54.613290999999997	с.Старый Буздяк, Школьная, 2а		0101000020E6100000FE8172DBBE454B402FF7C951804E4B40
20991	7	61	1021	58773	66428	\N	54.6316198507485	с.Старые Богады, Казанская, 4/1	Россия, республика Башкортостан, Буздякский район, село Староый Богады	0101000020E6100000B1E1E995B23A4B40F0BF95ECD8504B40
21035	7	61	1021	29997	64331	\N	54.816437000000001	с. Старотавларово, Центральная, 21		0101000020E6100000B4739A05DA334B40471FF30181684B40
21016	7	61	1021	29133	64778	\N	54.719290000000001	с.Староактау, Коммунистическая, 13а		0101000020E6100000D8BB3FDEAB3A4B40802BD9B1115C4B40
20998	7	61	1021	58596	65679	\N	54.582988164496001	с.Сергеевка, Центральная, 44	Россия, республика Башкортостан, Буздякский район, село Сергеевка	0101000020E610000051F9D7F2CA514B40F0FACC599F4A4B40
21033	7	61	1021	29896	66207	\N	54.959589000000001	с.Севадыбашево, Советская, 19а		0101000020E6100000503A9160AA534B40F94CF6CFD37A4B40
21015	7	61	1021	47109	65274	\N	54.743442000000002	с.Сабанаево, Школьная, 33	Россия, республика Башкортостан, Буздякский район, село Сабанаево	0101000020E6100000902FA182C33B4B40863C821B295F4B40
21026	7	61	1021	29566	64216	\N	54.873818	с.Сабаево, Мира, 41		0101000020E61000000EF450DB863B4B40FC53AA44D96F4B40
21014	7	61	1021	29027	64776	\N	54.757015000000003	с.Новоактау, Идяш, 22		0101000020E610000011C7BAB88D2C4B406DCA15DEE5604B40
21006	7	61	1021	58548	65473	\N	54.456315473158803	с. Никольское, Школьная, 11	Россия, республика Башкортостан, Буздякский район, село Никольское	0101000020E6100000535E2BA1BB484B404DD6A887683A4B40
21034	7	61	1021	58777	66437	\N	54.948889188543603	д.Нижняя Чатра, Школьная, 21а	Россия, республика Башкортостан, Буздякский район, село Нижная Чатра	0101000020E6100000CD237F30F0584B405F44DB3175794B40
21031	7	61	1021	58454	65060	\N	54.904803999999999	д.Кызыл-Яр, Мажита Гафури, 80	Россия, республика Башкортостан, Буздякский район, село Кызыл-Яр	0101000020E610000056BC9179E43B4B401EA5129ED0734B40
21009	7	61	1021	58552	65482	\N	54.407854303197503	д.Кузьминка, Центральная, 10	Россия, республика Башкортостан, Буздякский район, село Кузьминка	0101000020E6100000B5DD04DF343F4B407AC5538F34344B40
21023	7	61	1021	10805	66210	\N	54.880873000000001	с. Кузеево, Ленина, 37		0101000020E6100000C4060B27694E4B40F7764B72C0704B40
21012	7	61	1021	28940	64176	\N	54.523947573181701	с.Копей-Кубово, Ленина, 88	Россия, республика Башкортостан, Буздякский район, село Копей-Кубово	0101000020E61000005245F12A6B2F4B40FD6662BA10434B40
21020	7	61	1021	29294	64500	\N	54.768329000000001	с. Килимово, Буденного, 51/1		0101000020E61000001CD13DEB1A4F4B40C1C8CB9A58624B40
21036	7	61	1021	30052	64783	\N	54.814377	с.Картамак, Центральная, 55	Россия, республика Башкортостан, Буздякский район, село Картамак	0101000020E61000003A94A12AA63C4B40ABCE6A813D684B40
21032	7	61	1021	29847	65651	\N	54.937758000000002	д.Каразирек, Матросова, 32а		0101000020E61000007521567F843B4B40FCC7427408784B40
21007	7	61	1021	28732	64335	\N	54.376835	с.Канлы-Туркеево, Школьная, 2		0101000020E6100000B9A7AB3B16394B407C7E18213C304B40
21011	7	61	1021	8898	66757	\N	54.458546283856997	с.Казаклар-Кубово,ул.Горная,д.1	Россия, республика Башкортостан, Буздякский район, село Казаклар-Кубово	0101000020E61000005A12A0A696294B4016DBA4A2B13A4B40
21010	7	61	1021	8898	66757	\N	54.458088997149801	с.Казаклар-Кубово,ул.Горная,д.3	Россия, республика Башкортостан, Буздякский район, село Казаклар-Кубово	0101000020E610000040BE840A0E294B4024D40CA9A23A4B40
21029	7	61	1021	29707	66204	\N	54.868352000000002	д.Идяшбаш, Лесная, 3		0101000020E6100000103FFF3D78294B4046B58828266F4B40
21001	7	61	1021	28454	66178	\N	54.547898000000004	с.Гафури, Школьная, 5в		0101000020E6100000454AB3791C564B409CC58B8521464B40
20995	7	61	1021	28173	63433	\N	54.571171999999997	с. Буздяк, Рабочая, 31		0101000020E6100000C47C7901F6434B400932022A1C494B40
20996	7	61	1021	28173	62318	\N	54.571171999999997	с. Буздяк, Красная площадь, 28		0101000020E6100000C47C7901F6434B400932022A1C494B40
20997	7	61	1021	28173	63337	\N	54.571171999999997	с.Буздяк, Кирова, 25а		0101000020E6100000C47C7901F6434B400932022A1C494B40
21013	7	61	1021	29010	66202	\N	54.569831000000001	с. Большая Устюба, Колхозная, 2/2		0101000020E6100000C287122D79304B409D9FE238F0484B40
20990	7	61	1021	58543	65439	\N	54.6507884015871	с. Арсланово, Центральная, 78/4	Россия, республика Башкортостан, Буздякский район, село Арасланово	0101000020E6100000336ABE4A3E344B408B506C054D534B40
20972	7	61	497	27130	65220	\N	55.293427000000001	дер. Эманино, Речная, 40		0101000020E61000000282397AFC564C40B76114048FA54B40
94454	7	61	497	32887	9626	\N	55.172993531503998	с. Удельные Дуванеи, ул. Зырянова, 21	Россия, республика Башкортостан, Благовещенский район, село Удельно-Дуваней	0101000020E61000007EA8346266EB4B40BE33DAAA24964B40
20985	7	61	497	27749	65487	\N	55.031100384172298	дер. Турушла, Школьная, 4/1	Россия, республика Башкортостан, Благовещенский район, село Турушла	0101000020E61000004A287D21E41C4C40EB73B515FB834B40
20984	7	61	497	46460	64775	\N	55.127223460225899	дер. Трошкино, Горная, 1	Россия, республика Башкортостан, Благовещенский район, село Трошкино	0101000020E61000000B60CAC0010F4C404626E0D748904B40
20976	7	61	497	27292	66182	\N	55.215066	с. Старонадеждино, Молодежная, 5 А		0101000020E6100000EC2E5052603B4C40A33D5E48879B4B40
20968	7	61	497	58502	65230	\N	55.344453999999999	с. Староиликово, Советская, 73	Россия, республика Башкортостан, Благовещенский район, село Староиликово	0101000020E6100000B309302C7F1E4C40FA7C941117AC4B40
22938	7	61	497	46376	65267	\N	55.202675265873303	д. Петровка, Первомайская, 31	Россия, республика Башкортостан, Благовещенский район, село Петровка	0101000020E6100000376C5B94D9044C40C05B2041F1994B40
20970	7	61	497	58391	64898	\N	55.463804000000003	с. Осиповка, Лесная, 1	Россия, республика Башкортостан, Благовещенский район, село Осиповка	0101000020E610000024F0879FFF2C4C4083E0F1ED5DBB4B40
20964	7	61	497	58725	66191	\N	55.194259260317601	с. Орловка, Школьная, 2	Россия, республика Башкортостан, Благовещенский район, село Орловка	0101000020E6100000C119FCFD62004C4012FA997ADD984B40
20983	7	61	497	33023	64241	\N	55.177225999999997	село Новонадеждино, Советская, 6		0101000020E6100000F39194F4300C4C401D007157AF964B40
20988	7	61	497	58844	66571	\N	54.9764422732027	д. Нижний Изяк, Школьная, 2	Россия, республика Башкортостан, Благовещенский район, село Нижный Изяк	0101000020E6100000AB75E272BC244C406D382C0DFC7C4B40
20971	7	61	497	27093	66751	\N	55.506061000000003	д. Карагайкуль, ул. Нижняя, 23		0101000020E6100000AEBB79AA433A4C40FA635A9BC6C04B40
20986	7	61	497	58142	63899	\N	55.042485697402199	с. Ильина Поляна, Советская, 9 А	Россия, республика Башкортостан, Благовещенский район, село Ильино-Поляна	0101000020E6100000E529ABE97A164C40D844662E70854B40
94455	7	61	497	32952	66817	\N	55.410525	д. Ежовка, ул. Петропавловка, 12		0101000020E6100000D3D9C9E028274C405F984C158CB44B40
21942	7	61	497	58706	66086	\N	55.351856917573102	д. Гумерово, Садовая, 13	Россия, республика Башкортостан, Благовещенский район, село Гумерово	0101000020E6100000A777F17EDC244C4031EF71A609AD4B40
20979	7	61	497	58595	65677	\N	55.176581656366103	с. Волково, Молодежная, 1 Б	Россия, республика Башкортостан, Благовещенский район, село Волково	0101000020E6100000B07092E68F2D4C40F9872D3D9A964B40
20987	7	61	497	27841	64112	\N	54.987274999999997	село Верхний Изяк, Школьная, 16		0101000020E61000003E7958A8351F4C404694F6065F7E4B40
20965	7	61	497	46035	66173	\N	55.243997999999998	с. Богородское, Осиновка, 15		0101000020E610000071E2AB1DC5F74B400B2593533B9F4B40
20958	7	61	497	39011	66838	\N	55.033629493614001	г. Благовещенск, ул. Комарова, 2	Россия, республика Башкортостан, Благовещенский район, Благовещенск	0101000020E6100000B340BB438AFD4B403D997FF44D844B40
20944	7	61	497	39011	63629	\N	55.034714000000001	г. Благовещенск, Кирова, 81		0101000020E6100000895C70067FFD4B404F5B238271844B40
20956	7	61	497	39011	66629	\N	55.034714000000001	г. Благовещенск, ул. Братьев Першиных, 4		0101000020E6100000895C70067FFD4B404F5B238271844B40
20950	7	61	497	39011	63479	\N	55.034714000000001	г. Благовещенск, Баранова, 5		0101000020E6100000895C70067FFD4B404F5B238271844B40
20967	7	61	497	26927	65524	\N	55.377879	д. Биштиново, Партизанская, 1		0101000020E6100000E3C798BB96184C402F6CCD565EB04B40
20973	7	61	497	27162	63437	\N	55.325037000000002	с. Бедеева Поляна, Чернышевского, 18		0101000020E6100000FE277FF78E304C40B77EFACF9AA94B40
20977	7	61	497	58473	65120	\N	55.133025000000004	с. Ахлыстино, Шоссейная, 15	Россия, республика Башкортостан, Благовещенский район, село Ахлыстино	0101000020E610000027874F3A91424C40744694F606914B40
20975	7	61	497	58628	65772	\N	55.284687445187899	дер. Александровка, Интернациональная, 13	Россия, республика Башкортостан, Благовещенский район, село Александровка	0101000020E6100000309E4143FF344C40554CA59F70A44B40
20942	7	61	642	25775	66164	\N	54.923718999999998	с.Янышево, Базарная, 20б		0101000020E6100000E998F38C7D8B4B40CFD8976C3C764B40
20941	7	61	642	25731	64653	\N	54.619922000000003	с.Ямакай, Цветочная, 29		0101000020E61000000BD5CDC5DF8A4B401409A69A594F4B40
20982	7	61	642	45494	63468	\N	54.691536999999997	дер. Языково, Пушкина, 74	Россия, республика Башкортостан, Благоварский район, село Языково	0101000020E6100000384BC97212824B40AA7CCF4884584B40
20939	7	61	642	45494	63468	\N	54.691536999999997	с.Языково, Пушкина, 25		0101000020E6100000384BC97212824B40AA7CCF4884584B40
20938	7	61	642	45494	63468	\N	54.691536999999997	с.Языково, Пушкина, 22		0101000020E6100000384BC97212824B40AA7CCF4884584B40
20940	7	61	642	45494	63541	\N	54.691536999999997	с.Языково, Ленина, 16	Россия, республика Башкортостан, Благоварский район, село Языково	0101000020E6100000384BC97212824B40AA7CCF4884584B40
20937	7	61	642	45494	63541	\N	54.694370893502402	с.Языково, Ленина, 18	Россия, республика Башкортостан, Благоварский район, село Языково	0101000020E610000034B91803EB824B4039252026E1584B40
21160	7	61	642	4228	66312	\N	54.850794999999998	Республика Башкортостан, Гафурийский район, Саитбабинский сельсовет, д.Усманово, Центральная, 12		0101000020E610000060066344A2744B40D74CBED9E66C4B40
20935	7	61	642	25426	64239	\N	54.527259999999998	с.Удрякбаш, Центральная, 24		0101000020E6100000EB1C03B2D7794B40963E74417D434B40
20933	7	61	642	45411	64676	\N	54.797809000000001	с.Троицкий, Центральная, 54		0101000020E6100000AA9ECC3FFA644B402CBAF59A1E664B40
20930	7	61	642	25162	64534	\N	54.819617000000001	с.Тан, Коммуны, 3	Россия, республика Башкортостан, Благоварский район, село Тан	0101000020E61000001B1021AE9C814B40711FB935E9684B40
20931	7	61	642	25243	66317	\N	54.834423000000001	с.Такчура, Такчуринская, 76/а		0101000020E61000003E5C72DC29714B40DE03745FCE6A4B40
20929	7	61	642	25149	65360	\N	54.909379999999999	с.Сынташтамак, Школьная, 2		0101000020E61000001D740987DE804B4078D1579066744B40
20928	7	61	642	25091	65803	\N	54.670253000000002	с.Старые Санны, Совхозная, 1		0101000020E6100000252026E1425E4B40E085ADD9CA554B40
20920	7	61	642	24732	64513	\N	54.907558000000002	с.Старокучербаево, Центральная, 1		0101000020E61000007E8CB96B096D4B40919C4CDC2A744B40
20922	7	61	642	24828	65799	\N	54.904209000000002	с.Староабзаново, Киндеркульская, 39		0101000020E610000073B8567BD8654B40DBDFD91EBD734B40
20911	7	61	642	24303	64349	\N	54.543480000000002	д.Сарайлы, А.Галиева, 6		0101000020E61000001F4C8A8F4F844B40DA03ADC090454B40
20910	7	61	642	24229	63672	\N	54.841101999999999	с.Пришиб, Ленина, 38		0101000020E61000000DC347C494944B40D34CF73AA96B4B40
20927	7	61	642	58161	64064	\N	54.673721	с.Первомайский, Ленина, 7	Россия, республика Башкортостан, Благоварский район, село Первомайский	0101000020E6100000B51666A19D654B4070D05E7D3C564B40
21436	7	61	642	49372	66510	\N	54.6516061003421	д.Ново-Александровка, ул.Клубная, 19	Россия, республика Башкортостан, Благоварский район, село Новоалександровка	0101000020E6100000AA108FC4CB6F4B404EF04DD367534B40
20918	7	61	642	58764	66398	\N	54.558107459043001	д.Нижние Каргалы, Центральная, 21	Россия, республика Башкортостан, Благоварский район, село Нижнии Каргалы	0101000020E610000088F37002D3614B409755D80C70474B40
20923	7	61	642	49505	64861	\N	54.861933000000001	д.Ломово, Центральная, 39		0101000020E6100000944E24986A644B40ED2B0FD2536E4B40
20936	7	61	642	25459	65520	\N	54.481955999999997	д.Куллекул, Центральная, 3		0101000020E61000003DBB7CEBC3724B40340EF5BBB03D4B40
20924	7	61	642	24933	64423	\N	54.719715999999998	с.Коб-Покровка, Центральная, 42	Россия, республика Башкортостан, Благоварский район, село Коб-Покровка	0101000020E6100000BD00FBE8D4814B40373465A71F5C4B40
20919	7	61	642	24714	64859	\N	54.731493	с.Кашкалаши, Советская, 54		0101000020E610000071AB2006BA964B4060200890A15D4B40
20915	7	61	642	58812	66514	\N	54.784706999999997	д.Западный, Школьная, 5	Россия, республика Башкортостан, Благоварский район, село Западное Отделение Совхоза Благоварский	0101000020E6100000392861A6ED914B409CF86A4771644B40
20912	7	61	642	24332	63275	\N	54.579720999999999	с.Благовар, Совхозная, 1		0101000020E61000004D486B0C3A774B40F7E6374C344A4B40
20921	7	61	642	58708	66364	\N	54.909873095259599	д.Ахметово, Центральная, 29	Россия, республика Башкортостан, Благоварский район, село Ахметово	0101000020E610000083FB010F0C744B40B741EDB776744B40
20916	7	61	642	58530	65359	\N	54.747759797569799	д.6-е Алкино, Речная, 29	Россия, республика Башкортостан, Благоварский район, село Алкино 6-е	0101000020E61000009529E620E8544B40E4A08499B65F4B40
20932	7	61	642	25256	64823	\N	54.851287999999997	с.Агарды, Школьная, 1		0101000020E6100000DEACC1FBAA864B4016BD5301F76C4B40
20898	7	61	1594	23693	65635	\N	55.276175000000002	с. Шелканово, Радужная, 14		0101000020E61000000E2DB29DEF934B40857CD0B359A34B40
20907	7	61	1594	58763	66391	\N	55.274734000000002	с. Угузево, Коммунистическая, 18-б		0101000020E6100000D55B035B25D84B40B58CD47B2AA34B40
20905	7	61	1594	33124	64429	\N	55.427743999999997	с. Суслово, Антипина, 2-а		0101000020E6100000B2BB404981D94B40B587BD50C0B64B40
20891	7	61	1594	23343	64167	\N	55.440105000000003	с. Старобурново, Школьная, 6-а		0101000020E61000000D8D278238CF4B402EE7525C55B84B40
20902	7	61	1594	23868	64067	\N	55.302387000000003	с. Старобазаново, Комарова, 3		0101000020E61000002191B6F127A84B4027DE019EB4A64B40
20901	7	61	1594	23815	64356	\N	55.324585999999996	с. Силантьево, Восточная, 19		0101000020E61000006FD40AD3F7C24B40A65EB7088CA94B40
20883	7	61	1594	48932	63726	\N	55.396630999999999	Пономаревка, Гагарина, 11		0101000020E6100000488B338639C74B4036CAFACDC4B24B40
20903	7	61	1594	23891	64080	\N	55.239009000000003	с. Питяково, Мира, 31-а		0101000020E6100000BF0B5BB395C14B408F39CFD8979E4B40
20890	7	61	1594	49053	64856	\N	55.218487000000003	с. Печенкино, Советская, 12		0101000020E6100000A260C614ACAB4B40F3CCCB61F79B4B40
20899	7	61	1594	33100	64517	\N	55.362045000000002	с. Осиновка, Овчинникова, 8		0101000020E6100000EC12D55B03DD4B401557957D57AE4B40
20888	7	61	1594	23212	64854	\N	55.512250000000002	д. Новоянтузово, Ленина, 14		0101000020E610000071AE6186C6A14B4021B0726891C14B40
20886	7	61	1594	23092	66280	\N	55.506025999999999	д. Новокульчубаево, Красноармейская, 19		0101000020E6100000F3599E0777B74B407D76C075C5C04B40
20892	7	61	1594	49082	65652	\N	55.392143489962898	д. Николаевка, Октябрьская, 33	Россия, республика Башкортостан, Бирский район, село Николаевка	0101000020E610000042226DE34FCE4B407B2DE8BD31B24B40
20897	7	61	1594	23622	64857	\N	55.246805000000002	с. Маядыково, Свердлова, 10		0101000020E6100000ADDEE176689C4B40A1BE654E979F4B40
20906	7	61	1594	24045	65365	\N	55.399571000000002	д. Малосухоязово, Школьная, 8		0101000020E61000004B9352D0EDEB4B400BB77C2425B34B40
20895	7	61	1594	19342	64956	\N	55.402693999999997	с. Кусекеево, Новосктройки, 8	Россия, республика Башкортостан, Бирский район, село Кусекеево	0101000020E6100000658A39083AB04B40D0251C7A8BB34B40
20909	7	61	1594	58797	66482	\N	55.358959784689702	д. Кузово, Ленина, 46	Россия, республика Башкортостан, Бирский район, село Кузово	0101000020E61000003A7AFCDEA6974B403D49BA66F2AD4B40
20894	7	61	1594	58814	66517	\N	55.397407070254403	д. Кондаковка, Школьная, 7	Россия, республика Башкортостан, Бирский район, село Кандаковка	0101000020E6100000AED9CA4BFEB94B40CA198A3BDEB24B40
20893	7	61	1594	23418	63659	\N	55.243155999999999	с. Калинники, Калинина, 23-а		0101000020E61000006D3656629EDF4B40C0E95DBC1F9F4B40
20900	7	61	1594	23772	66329	\N	55.363657000000003	с. Емашево, Антипина, 28		0101000020E6100000E1B37570B0F34B4012FB04508CAE4B40
20887	7	61	1594	23167	64853	\N	55.471300999999997	д. Верхнелачентау, Тукая, 15		0101000020E610000076A73B4F3CAF4B403AC9569753BC4B40
20869	7	61	1594	22315	63403	\N	55.426825000000001	Республика Башкортостан, Бирский район, город Бирск, Чеверева, 143		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20871	7	61	1594	22315	63773	\N	55.417454932062299	Республика Башкортостан, Бирский район, город Бирск, Пролетарская, 140	Россия, республика Башкортостан, Бирский район, Бирск	0101000020E6100000ED10FFB0A5C54B409D465A2A6FB54B40
20870	7	61	1594	22315	63796	\N	55.426825000000001	Республика Башкортостан, Бирский район, город Бирск, Овчинникова, 48		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20880	7	61	1594	22315	63580	\N	55.426825000000001	город Бирск, Мира, 124 а		0101000020E6100000A1DAE044F4C54B40BF0E9C33A2B64B40
20904	7	61	1594	23962	66326	\N	55.225316999999997	д. Бекмурзино, Молодежная, 2		0101000020E610000030D63730B9C94B40CD1DFD2FD79C4B40
20885	7	61	1594	23074	64508	\N	55.537469999999999	с. Бахтыбаево, Памфилова, 19		0101000020E6100000DB368C82E0BB4B40624A24D1CBC44B40
20884	7	61	1594	33043	64020	\N	55.491554000000001	с. Баженово, Мира, 30		0101000020E610000033F9669B1BCB4B40E71BD13DEBBE4B40
22952	7	61	1594	58754	66363	\N	55.378805019899701	с. Андреевка, Школьная, 18	Россия, республика Башкортостан, Бирский район, село Андреевка	0101000020E6100000B9C4910722A14B40D847A7AE7CB04B40
20896	7	61	1594	23582	65796	\N	55.345973999999998	д. Акудибашево, Школьная, 5		0101000020E61000008BE1EA0088A34B4016A243E048AC4B40
20845	7	61	1414	48261	65138	\N	53.409584000000002	д.Хомутовка, Центральная, 11		0101000020E61000005589B2B794254B40817B9E3F6DB44A40
20864	7	61	1414	58193	64231	\N	53.735849000000002	с.Сухоречка, Центральная, 33	Россия, республика Башкортостан, Бижбулякский район, село Сухоречка	0101000020E61000008EACFC3218FF4A40ACE5CE4C30DE4A40
20838	7	61	1414	20871	66729	\N	53.706949999999999	д.Седякбаш, ул.Центральная, 51		0101000020E6100000F0DE516342104B401FF46C567DDA4A40
20840	7	61	1414	58633	65801	\N	53.582687825840601	д.Ольховка, Молодежная, 1	Россия, республика Башкортостан, Бижбулякский район, село Ольховка	0101000020E6100000AAD6C22CB4014B40C5E2378595CA4A40
20860	7	61	1414	32902	66926	\N	53.905636000000001	с.Михайловка, ул.Девонская, 9		0101000020E6100000AD8905BEA2114B40460A65E1EBF34A40
20859	7	61	1414	21889	64851	\N	53.875946999999996	с.Менеуз-Москва, Центральная, 27А		0101000020E6100000179AEB34D2284B40C00303081FF04A40
20850	7	61	1414	21445	65351	\N	53.658282	с.Малый Седяк, переулок Школьный, 8		0101000020E6100000317DAF21380A4B40D2C5A69542D44A40
20861	7	61	1414	21991	66324	\N	53.977772999999999	с.Малый Менеуз, Шоссейная, 1А		0101000020E6100000F2B391EBA6184B40B6F468AA27FD4A40
20851	7	61	1414	21503	65345	\N	53.654584	д.Лысогорка, Центральная, 31		0101000020E6100000BB7F2C4487004B40103E9468C9D34A40
20856	7	61	1414	21734	64221	\N	53.717395000000003	с.Кунакулово, Центральная, 91А		0101000020E610000051F701486D384B402FA86F99D3DB4A40
20857	7	61	1414	21792	64083	\N	53.913677	с.Кош-Елга, МТМ, 8		0101000020E6100000CC0A45BA9F1D4B40BF0D315EF3F44A40
20829	7	61	1414	20369	65341	\N	53.809018999999999	с.Кистенли-Богданово, Школьная, 25		0101000020E61000001D75745C8D224B40DB6B41EF8DE74A40
20855	7	61	1414	21686	63571	\N	53.675764000000001	с.Кенгер-Менеуз, Центральная, 62		0101000020E610000014B01D8CD8334B4036E84B6F7FD64A40
20848	7	61	1414	21358	66325	\N	53.520375999999999	д.Качкиново, Салавата Юлаева, 7А		0101000020E61000004339D1AE42264B40C8CF46AE9BC24A40
20826	7	61	1414	46048	65790	\N	53.555999	д.Каримово, Подлесная, 5		0101000020E610000071C79BFC16154B40EACDA8F92AC74A40
20768	7	61	1414	17178	66308	\N	53.417994	с.Каныкаево, Коммунистическая, 6		0101000020E6100000481B47ACC5134B404DF6CFD380B54A40
21629	7	61	1414	27037	66774	\N	53.718625876337903	д.Исякаево, ул.Речная,40а	Россия, республика Башкортостан, Бижбулякский район, село Исякаево	0101000020E61000009869FB5756EA4A401407D0EFFBDB4A40
20867	7	61	1414	27037	64849	\N	53.720097000000003	с.Исякаево, Мусы Джалиля, 41	Россия, республика Башкортостан, Бижбулякский район, село Исякаево	0101000020E610000014984EEB36EA4A404F7974232CDC4A40
20849	7	61	1414	58646	65863	\N	53.641596682325599	с.Зириклы, Центральная, 55	Россия, республика Башкортостан, Бижбулякский район, село Зириклы	0101000020E61000005A48C0E8F2104B40191BBAD91FD24A40
20847	7	61	1414	21318	64180	\N	53.535283	с.Елбулактамак, Центральная, 2Б		0101000020E6100000DBC4C9FD0E214B40698D412784C44A40
20837	7	61	1414	20825	66696	\N	53.649343000000002	с.Елбулак-Матвеевка, ул.Чкалова,28		0101000020E610000092E68F696D1A4B407A71E2AB1DD34A40
20828	7	61	1414	47927	64746	\N	53.737062999999999	д.Егоровка, Центральная, 28		0101000020E61000009F909DB7B12D4B40BB0B941458DE4A40
20738	7	61	1414	15694	64659	\N	53.482841999999998	с.Дюсяново, Центральная, 11		0101000020E61000009D6340F67A174B404F9143C4CDBD4A40
20841	7	61	1414	21034	64404	\N	53.538034000000003	с.Демский, Центральная, 15		0101000020E61000004E621058393A4B406B11514CDEC44A40
20839	7	61	1414	20942	66305	\N	53.628374000000001	с.Верхняя Курмаза, Центральная, 32		0101000020E61000002F52280B5F274B400FD4298F6ED04A40
20846	7	61	1414	48269	65769	\N	53.498913999999999	д.Боголюбовка, Садовая, 33		0101000020E6100000C901BB9A3C274B401EC2F869DCBF4A40
20834	7	61	1414	20446	66687	\N	53.696502303649297	с.Бижбуляк, ул.Трудовая, 13	Россия, республика Башкортостан, Бижбулякский район, село Бижбуляк	0101000020E6100000A88FC01F7E224B409FCC3FFA26D94A40
20833	7	61	1414	20446	64224	\N	53.697418999999996	с.Бижбуляк, Спортивная, 2		0101000020E6100000096F0F4240224B40F44D9A0645D94A40
20832	7	61	1414	20446	64078	\N	53.697418999999996	с.Бижбуляк, Пушкина, 20		0101000020E6100000096F0F4240224B40F44D9A0645D94A40
20827	7	61	1414	20239	64076	\N	53.746355999999999	с.Базлык, Центральная, 168А		0101000020E61000009DF2E84658244B403196E99788DF4A40
20824	7	61	1414	20053	64372	\N	53.527088999999997	с.Аитово, Фатиха Карима, 43	Россия, республика Башкортостан, Бижбулякский район, село Аитово	0101000020E6100000880E8123811A4B40698A00A777C34A40
20842	7	61	1414	27363	66056	\N	53.493336999999997	с.Азнаево, Центральная, 39		0101000020E6100000ABAFAE0AD4324B401074B4AA25BF4A40
20819	7	61	1403	19787	66318	\N	53.803474000000001	Республика Башкортостан, Белорецкий район, Шигаевский сельсовет, с.Шигаево, Школьная, 18		0101000020E610000090A339B2F2194D40D9976C3CD8E64A40
20822	7	61	1403	19955	64970	\N	53.726463000000003	Республика Башкортостан, Белорецкий район, Шигаевский сельсовет, д.Хусаиново, Молодежная, 16		0101000020E6100000D9226937FA1E4D40856055BDFCDC4A40
20821	7	61	1403	19893	66321	\N	53.773445000000002	Республика Башкортостан, Белорецкий район, Шигаевский сельсовет, с.Уткалево, Школьная, 15		0101000020E6100000897C9752971E4D409B20EA3E00E34A40
20820	7	61	1403	19841	64850	\N	53.679817999999997	Республика Башкортостан, Белорецкий район, Шигаевский сельсовет, с.Узянбаш, Янгиреева, 29		0101000020E610000014234BE6581E4D40B69DB64604D74A40
20816	7	61	1403	19714	64951	\N	53.695568999999999	Республика Башкортостан, Белорецкий район, Узянский сельсовет. с.Узян, Портнова, 2	Россия, республика Башкортостан, Белорецкий район, село Узян	0101000020E61000007F30F0DC7BEE4C40438EAD6708D94A40
20817	7	61	1403	19714	64226	\N	53.693679572806303	Республика Башкортостан, Белорецкий район, Узянский сельсовет, с.Узян, Победы, 2	Россия, республика Башкортостан, Белорецкий район, село Узян	0101000020E61000002BBF0CC688EE4C40D4F19881CAD84A40
20814	7	61	1403	19550	64426	\N	53.841996999999999	Республика Башкортостан, Белорецкий район, Туканский сельсовет, с.Тукан, Матросова, 14		0101000020E6100000744694F606BB4C40412AC58EC6EB4A40
20815	7	61	1403	19550	64292	\N	53.841996999999999	Республика Башкортостан, Белорецкий район, Туканский сельсовет, с.Тукан, Горького, 17		0101000020E6100000744694F606BB4C40412AC58EC6EB4A40
20812	7	61	1403	19277	64003	\N	54.207018400952201	Республика Башкортостан, Белорецкий район, Тирлянский сельсовет, с.Тирлянский, проезд Дзержинского, 7	Россия, республика Башкортостан, Белорецкий район, поселок Тирлянский	0101000020E61000007DCD72D9E84A4D4077D7D9907F1A4B40
20811	7	61	1403	19277	64012	\N	54.207521999999997	Республика Башкортостан, Белорецкий район, Тирлянский сельсовет, с.Тирлянский, Советская, 181		0101000020E6100000CF876709324A4D40AA99B514901A4B40
20809	7	61	1403	19277	64230	\N	54.207521999999997	Республика Башкортостан, Белорецкий район, Тирлянский сельсовет, с.Тирлянский, Первомайская, 73		0101000020E6100000CF876709324A4D40AA99B514901A4B40
20813	7	61	1403	19277	64223	\N	54.207521999999997	Республика Башкортостан, Белорецкий район, Тирлянский сельсовет, с.Тирлянский, Коммунистическая, 115		0101000020E6100000CF876709324A4D40AA99B514901A4B40
20807	7	61	1403	19201	64213	\N	53.855919	Республика Башкортостан, Белорецкий район, Сосновский сельсовет, с.Сосновка, Центральная, 3		0101000020E6100000B1DEA815A6254D403483F8C08EED4A40
20806	7	61	1403	19137	63267	\N	53.880087000000003	Республика Башкортостан, Белорецкий район, Серменевский сельсовет, с.Серменево, Ленина, 25А		0101000020E6100000E09C11A5BD0F4D404051D9B0A6F04A40
20808	7	61	1403	19233	66313	\N	53.798943000000001	Республика Башкортостан, Белорецкий район, Сосновский сельсовет, с.Рысакаево, Школьная, 10		0101000020E61000005ED905836B224D401F2FA4C343E64A40
20804	7	61	1403	19030	65788	\N	54.060847000000003	Республика Башкортостан, Белорецкий район, Нурский сельсовет, с.Отнурок, Школьная, 26		0101000020E6100000429605137F204D40A587A1D5C9074B40
20795	7	61	1403	18560	65786	\N	54.175282000000003	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Нукатово, Горная, 20		0101000020E610000088D9CBB6D3B04C40EBC9FCA36F164B40
20823	7	61	1403	20039	66242	\N	53.855139000000001	Республика Башкортостан, Белорецкий район, Шигаевский сельсовет, д.Новобельское, Бельская, 2		0101000020E6100000DCBB067DE9154D405F44DB3175ED4A40
20767	7	61	1403	17143	66301	\N	53.809933999999998	Республика Башкортостан, Белорецкий район, Абзаковский сельсовет, с.Новоабзаково, Вокзальная, 9/1		0101000020E61000002E8F352383524D4090F5D4EAABE74A40
20801	7	61	1403	18879	65787	\N	54.371774000000002	Республика Башкортостан, Белорецкий район, Николаевский сельсовет, с.Николаевка, Центральная, 8		0101000020E6100000C269C18BBE5E4D4066C0594A962F4B40
20766	7	61	1403	17076	65776	\N	53.697073000000003	Республика Башкортостан, Белорецкий район, Абзаковский сельсовет, д.Мухаметово, Школьная, 11		0101000020E6100000D61A4AED453C4D405AF624B039D94A40
20776	7	61	1403	17592	64841	\N	54.587457999999998	Республика Башкортостан, Белорецкий район, Ассинский сельсовет, с.Мулдакаево, Центральная, 57		0101000020E610000086747808E3D34C4004E3E0D2314B4B40
19945	7	61	1403	58121	64157	\N	54.238156007459203	"Республика Башкортостан, ЗАТО ""город Межгорье"", Советская, 25"		0101000020E6100000BEBED6A546FA4C404FAC53E57B1E4B40
19944	7	61	1403	58121	63709	\N	54.221573327260899	"Республика Башкортостан, ЗАТО ""город Межгорье"", 40 лет Победы, 3"	Россия, республика Башкортостан, Белорецкий район	0101000020E61000007192E68F69FF4C409B560A815C1C4B40
20800	7	61	1403	18803	66643	\N	54.329614999999997	Республика Башкортостан, Белорецкий район, Николаевский сельсовет, д.Махмутово, Иремель, 6		0101000020E610000014E97E4E41664D40B1A206D3302A4B40
20799	7	61	1403	18750	63366	\N	53.920948000000003	Республика Башкортостан, Белорецкий район, Ломовский сельсовет, с.Ломовка, Ленина, 34		0101000020E61000005854C4E9242F4D4087A8C29FE1F54A40
20771	7	61	1403	17341	65780	\N	53.990773256904099	Республика Башкортостан, Белорецкий район, Азикеевский сельсовет, д.Кузгун-Ахмерово, Центральная, 16/2	Россия, республика Башкортостан, Белорецкий район, село Кузгун-Ахмерово	0101000020E6100000CB82893F8A204D40416150A6D1FE4A40
20818	7	61	1403	19763	65364	\N	53.638336000000002	Республика Башкортостан, Белорецкий район, Узянский сельсовет, д.Кагарманово, Юлаева, 20А		0101000020E6100000DDEBA4BE2CE54C4003EE79FEB4D14A40
20798	7	61	1403	18721	66641	\N	53.524529999999999	Республика Башкортостан, Белорецкий район, Кагинский сельсовет, с.Кага, Ленина, 45		0101000020E61000009624CFF57DD84C40ACE28DCC23C34A40
20796	7	61	1403	18588	64846	\N	53.898696999999999	Республика Башкортостан, Белорецкий район, Ишлинский сельсовет, с.Ишля, Советская, 23		0101000020E61000003A0664AF77E74C40B401D88008F34A40
20780	7	61	1403	17795	66311	\N	53.696337	Республика Башкортостан, Белорецкий район, Верхнеавзянский сельсовет, с.Исмакаево, Советская, 35		0101000020E6100000D1E80E6267C64C4054FF209221D94A40
20777	7	61	1403	17651	66309	\N	54.538440000000001	Республика Башкортостан, Белорецкий район, Ассинский сельсовет, с.Искушта, Клубная, 27А		0101000020E6100000471CB28174CB4C40DB6D179AEB444B40
20788	7	61	1403	18102	9670	\N	54.215631304659098	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Инзер, Энергетиков, 31А	Россия, республика Башкортостан, Белорецкий район, поселок Инзер	0101000020E61000003ACAC16C02C84C407C80EECB991B4B40
20787	7	61	1403	18102	9670	\N	54.216335999999998	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Инзер, Энергетиков,  16А		0101000020E6100000A1496249B9C74C404679E6E5B01B4B40
20790	7	61	1403	18102	65785	\N	54.216335999999998	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Инзер, Школьная, 6		0101000020E6100000A1496249B9C74C404679E6E5B01B4B40
20791	7	61	1403	18102	64420	\N	54.216335999999998	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, с.Инзер, Октябрьская, 4А		0101000020E6100000A1496249B9C74C404679E6E5B01B4B40
20784	7	61	1403	17982	64214	\N	54.404997000000002	Республика Башкортостан, Белорецкий район, Зуяковский сельсовет, с.Зуяково, Мубарякова, 37		0101000020E6100000F56569A7E6AE4C4033FD12F1D6334B40
20783	7	61	1403	17888	65781	\N	53.837592999999998	Республика Башкортостан, Белорецкий район, Зигазинский сельсовет, с.Зигаза, Школьная, 6		0101000020E6100000F778211D1EAA4C40E42D573F36EB4A40
20782	7	61	1403	17888	65335	\N	53.837592999999998	Республика Башкортостан, Белорецкий район, Зигазинский сельсовет, с.Зигаза, Октябрьская, 29		0101000020E6100000F778211D1EAA4C40E42D573F36EB4A40
20785	7	61	1403	18045	65783	\N	54.452317999999998	Республика Башкортостан, Белорецкий район, Зуяковский сельсовет, с.Габдюково, Школьная, 2А		0101000020E61000002C2CB81FF0A24C4031B2648EE5394B40
20779	7	61	1403	17694	66814	\N	53.525933000000002	Республика Башкортостан, Белорецкий район, Верхнеавзянский сельсовет, с.Верхний Авзян,  Загорская, 2		0101000020E6100000A9F8BF232AC64C408F71C5C551C34A40
20778	7	61	1403	17694	66918	\N	53.525933000000002	Республика Башкортостан, Белорецкий район, Верхнеавзянский сельсовет, с.Верхний Авзян, Блюхера, 70		0101000020E6100000A9F8BF232AC64C408F71C5C551C34A40
20803	7	61	1403	58809	66503	\N	54.227441021159599	Республика Башкортостан, Белорецкий район, Николаевский сельсовет, с.Верхнебельский, Школьная, 1	Россия, республика Башкортостан, Белорецкий район, село совхоза 3	0101000020E6100000A393A5D6FB554D40806264C91C1D4B40
20802	7	61	1403	18899	66314	\N	54.365012	Республика Башкортостан, Белорецкий район, Николаевский сельсовет, с.Верхнеаршинский, переулок Школьный, 5		0101000020E610000020D26F5F07444D40E35295B6B82E4B40
20772	7	61	1403	17378	\N	\N	53.906081999999998	Республика Башкортостан, Белорецкий район, Азикеевский сельсовет, с.Буганак, Центральная, 1	Россия, республика Башкортостан, Белорецкий район, село Буганак	0101000020E61000003E7782FDD71D4D4044BFB67EFAF34A40
20774	7	61	1403	17475	66303	\N	54.379567000000002	Республика Башкортостан, Белорецкий район, Ассинский сельсовет, с.Бриштамак, Горная, 10		0101000020E6100000C74B378941BE4C4007D2C5A695304B40
20775	7	61	1403	17542	64734	\N	54.406872999999997	Республика Башкортостан, Белорецкий район, Ассинский сельсовет, с.Бриш, Центральная, 28/1		0101000020E61000006EBF7CB262C04C400D501A6A14344B40
20792	7	61	1403	18382	65026	\N	54.159505000000003	Республика Башкортостан, Белорецкий район, Инзерский сельсовет, д.Бердагулово, Школьная, 24		0101000020E61000000AD7A3703DE44C403546EBA86A144B40
22075	7	61	1403	48339	66154	\N	53.517277421672802	Республика Башкортостан, Мелеузовский район, Первомайский сельсовет, д. Бельский, Школьная, 8	Россия, республика Башкортостан, Белорецкий район, село Бельский	0101000020E6100000F969DC9BDFD24C408BFCFA2136C24A40
21769	7	61	1403	48339	65831	\N	53.516559000000001	деревня Бельский, Центральная, 24		0101000020E6100000AB4198DBBDD24C402CBAF59A1EC24A40
20747	7	61	1403	15455	\N	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Кирова, 40	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20760	7	61	1403	15455	66947	\N	53.970430969834197	Республика Башкортостан, Белорецкий район, город Белорецк, Тюленина, 40	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E61000000A80F10C1A324D402503401537FC4A40
20744	7	61	1403	15455	63557	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Точисского, 16		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20746	7	61	1403	15455	66894	\N	53.966920199160299	Республика Башкортостан, Белорецкий район, город Белорецк, Пушкина, 67А	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E6100000A699EE7552354D4096ECD808C4FB4A40
20757	7	61	1403	15455	63728	\N	53.974074266285299	Республика Башкортостан, Белорецкий район, город Белорецк, Металлургическая, 24	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E6100000E90B21E7FD314D4024F1F274AEFC4A40
20752	7	61	1403	15455	63793	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Маркса, 85		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20753	7	61	1403	15455	63727	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Ленина, 131	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20742	7	61	1403	15455	63503	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, Косоротова, 10А	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20745	7	61	1403	15455	63375	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, 50 лет Октября, 68		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20736	7	61	1403	15455	63375	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, 50 лет Октября, 48		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20734	7	61	1403	15455	63375	\N	53.975082999999998	Республика Башкортостан, Белорецкий район, город Белорецк, 50 лет Октября, 74		0101000020E61000009813B4C9E1314D405AF10D85CFFC4A40
20740	7	61	1403	15455	64869	\N	53.975427770585497	Республика Башкортостан, Белорецкий район, город Белорецк, 50 лет Октября, 62	Россия, республика Башкортостан, Белорецкий район, Белорецк	0101000020E61000000FB8AE9811324D4025CD1FD3DAFC4A40
20773	7	61	1403	17437	63996	\N	54.371375	Республика Башкортостан, Белорецкий район, Ассинский сельсовет, с.Ассы, Мубарякова, 25/1		0101000020E610000014950D6B2AC94C40A8C64B37892F4B40
20770	7	61	1403	17288	65336	\N	53.926519999999996	Республика Башкортостан, Белорецкий район, Азикеевский сельсовет, с.Азналкино, Победы, 13/1		0101000020E610000022FC8BA031134D40828B153598F64A40
20805	7	61	1403	19065	66799	\N	53.834442000000003	Республика Башкортостан, Белорецкий район, Серменевский сельсовет, д.Азнагулово, Агидель, 28 А		0101000020E610000068976F7D58FD4C405534D6FECEEA4A40
20769	7	61	1403	17242	65777	\N	53.932172000000001	Республика Башкортостан, Белорецкий район, Азикеевский сельсовет, с.Азикеево, Советская, 4		0101000020E6100000D2E1218C9F1E4D409B1F7F6951F74A40
20710	7	61	1325	14374	64070	\N	55.763593478382198	Республика Башкортостан, Белокатайский район, Яныбаевский сельсовет, Яныбаево, Центральная, 10	Россия, республика Башкортостан, Белокатайский район, село Яныбаево	0101000020E6100000C36169E0475B4D402E3A596ABDE14B40
20718	7	61	1325	14745	66298	\N	55.763517999999998	Республика Башкортостан, Белокатайский район, Старобелокатайский сельсовет, Шакарла, Советская, 15		0101000020E6100000E486DF4DB7924D4023F433F5BAE14B40
20522	7	61	1325	14922	63576	\N	55.548072182397597	Республика Башкортостан, Баймакский район, с.Ургаза, улица Х.Давлетшиной, дом 9	Россия, республика Башкортостан, Белокатайский район, село Ургала	0101000020E6100000C2887D0228C04D4039ED293927C64B40
20722	7	61	1325	14922	63386	\N	55.548074999999997	Республика Башкортостан, Белокатайский район, Ургалинский сельсовет, Ургала, Ленина, 93		0101000020E610000099F04BFDBCBF4D40AA60545227C64B40
20724	7	61	1325	58799	66484	\N	55.665294000000003	Республика Башкортостан, Белокатайский район, Атаршинский сельсовет, Ураково, Мира, 26	Россия, республика Башкортостан, Белокатайский район, село Ураковская Ферма Совхоза	0101000020E61000005B441493378C4D40CE1C925A28D54B40
20717	7	61	1325	14684	64405	\N	55.782693999999999	Республика Башкортостан, Белокатайский район, Старобелокатайский сельсовет, Старобелокатай, Советская, 71		0101000020E61000002864E76D6C7E4D40416326512FE44B40
20713	7	61	1325	14492	65326	\N	55.738078999999999	Республика Башкортостан, Белокатайский район, Новобелокатайский сельсовет, Соколки, Клубная, 14		0101000020E6100000AA0A0DC4B2714D40A46E675F79DE4B40
20705	7	61	1325	14119	64353	\N	55.979128000000003	Республика Башкортостан, Белокатайский район, Ногушинский сельсовет,Ногуши, Крупской, 19		0101000020E610000016A4198BA6534D40884CF91054FD4B40
20714	7	61	1325	14553	63611	\N	55.707394999999998	Республика Башкортостан, Белокатайский район, Новобелокатайский сельсовет, Новобелокатай, Школьный переулок, 7		0101000020E610000036E9B6442E7A4D404D2D5BEB8BDA4B40
20715	7	61	1325	14553	63649	\N	55.707394999999998	Республика Башкортостан, Белокатайский район, Новобелокатайский сельсовет, Новобелокатай, Советская, 124		0101000020E610000036E9B6442E7A4D404D2D5BEB8BDA4B40
20716	7	61	1325	14553	63531	\N	55.707394999999998	Республика Башкортостан, Белокатайский район, Новобелокатайский сельсовет, Новобелокатай, Молодежная, 10		0101000020E610000036E9B6442E7A4D404D2D5BEB8BDA4B40
20719	7	61	1325	14787	66304	\N	55.655844000000002	Республика Башкортостан, Белокатайский район, Утяшевский сельсовет, Нижнеутяшево, Победы, 10		0101000020E61000008C9FC6BDF97B4D4090A339B2F2D34B40
20729	7	61	1325	58815	66518	\N	55.754274000000002	Республика Башкортостан, Белокатайский район, Майгазинский сельсовет, Медятово, Совхозная, 13	Россия, республика Башкортостан, Белокатайский район, село Медятовская Ферма	0101000020E6100000614F3BFC35554D408F1CE90C8CE04B40
20727	7	61	1325	15169	64072	\N	55.607411999999997	Республика Башкортостан, Белокатайский район, Майгазинский сельсовет, Майгаза, Мира, 12		0101000020E6100000CB2DAD86C46F4D40569929ADBFCD4B40
20732	7	61	1325	15414	64733	\N	56.067343999999999	Республика Башкортостан, Белокатайский район, Белянковский сельсовет, Кирикеево, Мусы Гареева, 2		0101000020E61000003B1BF2CF0C9E4D4079CA6ABA9E084C40
20706	7	61	1325	14167	63791	\N	55.947293000000002	Республика Башкортостан, Белокатайский район, Карлыхановский сельсовет,Карлыханово, Советская, 100		0101000020E610000082C8224DBC594D40685DA3E540F94B40
20721	7	61	1325	14909	65330	\N	55.604488000000003	Республика Башкортостан, Белокатайский район, Ургалинский сельсовет, Карантрав, Школьный переулок, 3		0101000020E610000059147651F4964D408869DFDC5FCD4B40
20726	7	61	1325	15113	65333	\N	55.522759999999998	Республика Башкортостан, Белокатайский район, Атаршинский сельсовет, Кадырово, Мира, 18		0101000020E6100000A60EF27A30954D4017D4B7CCE9C24B40
20704	7	61	1325	14084	64493	\N	55.939841999999999	Республика Башкортостан, Белокатайский район, Емашинский сельсовет,Емаши, Кирова, 2		0101000020E61000004298DBBDDC4D4D4020B41EBE4CF84B40
20731	7	61	1325	15361	64165	\N	56.043210999999999	Республика Башкортостан, Белокатайский район, Белянковский сельсовет, Белянка, Гагарина, 1А		0101000020E61000007EACE0B7219E4D40EAE923F087054C40
20730	7	61	1325	15319	65342	\N	55.922863	Республика Башкортостан, Белокатайский район, Белянковский сельсовет, Ашаево, Школьный переулок, 1		0101000020E61000007C4276DEC6984D401FD8F15F20F64B40
20720	7	61	1325	14847	65328	\N	55.697401999999997	Республика Башкортостан, Белокатайский район, Утяшевский сельсовет, Апутово, Салавата Юлаева, 40		0101000020E61000007460394206844D401E15FF7744D94B40
20707	7	61	1325	14240	65324	\N	55.903867948518297	Республика Башкортостан, Белокатайский район, Карлыхановский сельсовет, Айдакаево, Салавата Юлаева, 42	Россия, республика Башкортостан, Белокатайский район, село Айдакаево	0101000020E610000001892650C45C4D4052F355F2B1F34B40
20711	7	61	1325	14402	66295	\N	55.717964000000002	Республика Башкортостан, Белокатайский район, Яныбаевский сельсовет, Айгырьял, Мечетлинская, 33		0101000020E6100000486DE2E47E674D4049DA8D3EE6DB4B40
20723	7	61	1325	14997	64836	\N	55.524456999999998	Республика Башкортостан, Белокатайский район, Ургалинский сельсовет, Абсалямово, Шаймуратова, 31		0101000020E6100000A741D13C80C14D4042942F6821C34B40
20688	7	61	1158	58144	63952	\N	54.0041857146444	Республика Башкортостан, Белебеевский район, Максим-Горьковский сельсовет, с.ЦУП им.Максима Горького, Садовая, 3	Россия, республика Башкортостан, Белебеевский район, село совхоза Имени М. Горького	0101000020E610000018EE5C18E9254B40EF8CB62A89004B40
20702	7	61	1158	13968	65323	\N	54.022108000000003	Республика Башкортостан, Белебеевский район, Шаровский сельсовет, д.Шаровка, Школьная, 1		0101000020E61000003F55850662314B40707D586FD4024B40
20700	7	61	1158	13884	64344	\N	54.187933000000001	Республика Башкортостан, Белебеевский район, Усень-Ивановский сельсовет, с.Усень-Ивановское, Комсомольская, 72		0101000020E6100000FB20CB82892B4B406A6B44300E184B40
20699	7	61	1158	13820	66767	\N	54.258305999999997	Республика Башкортостан, Белебеевский район, Тузлукушевский сельсовет, с.Тузлукуш, Чапаева, 58		0101000020E610000082ACA7565F114B40272EC72B10214B40
20696	7	61	1158	13678	64839	\N	54.344124000000001	Республика Башкортостан, Белебеевский район, Семенкинский сельсовет, с.Старосеменкино, Дружбы, 14		0101000020E6100000629E95B4E2254B4065E256410C2C4B40
20698	7	61	1158	13796	64290	\N	53.973812000000002	Республика Башкортостан, Белебеевский район, Слакбашевский сельсовет, с.Слакбаш, К.Иванова, 58		0101000020E61000007BD976DA1A354B40E73922DFA5FC4A40
20695	7	61	1158	13663	66264	\N	54.043832000000002	Республика Башкортостан, Белебеевский район, Рассветовский сельсовет, д.Рассвет, Лесная, 19		0101000020E610000081B1BE81C9FD4A40574277499C054B40
20697	7	61	1158	13742	66266	\N	54.384312000000001	Республика Башкортостан, Белебеевский район, Семенкинский сельсовет, с.Новосеменкино, Пушкина, 14		0101000020E6100000028063CF9E294B40EDBAB72231314B40
20687	7	61	1158	13262	65773	\N	54.073253999999999	Республика Башкортостан, Белебеевский район, Знаменский сельсовет, д.Новосараево, Овражная, 8	Россия, республика Башкортостан, Белебеевский район, село Новосараево	0101000020E6100000FAB5F5D37F384B408D26176360094B40
20675	7	61	1158	12751	65313	\N	54.035404	Республика Башкортостан, Белебеевский район, Аксаковский сельсовет, с.Надеждино, Интернациональная, 2		0101000020E610000051F9D7F2CA134B40E412471E88044B40
20693	7	61	1158	13545	64542	\N	54.293815386710001	Республика Башкортостан, Белебеевский район, Метевбашевский сельсовет, с.Метевбаш, Школьная, 62а	Россия, республика Башкортостан, Белебеевский район, село Метевбаш	0101000020E61000000CCA349A5C1E4B408109DCBA9B254B40
19943	7	61	1158	58089	63254	\N	54.113602	"Республика Башкортостан, ЗАТО ""город Межгорье"", 40 лет Победы, 58"	Россия, республика Башкортостан, Белебеевский район, село Междугорное	0101000020E6100000AE64C74620204B404E61A5828A0E4B40
20685	7	61	1158	13185	66236	\N	54.247286000000003	Республика Башкортостан, Белебеевский район, Ермолкинский сельсовет, с.Малоалександровка, Центральная, 20		0101000020E610000037C478CDABF44A401C615111A71F4B40
20691	7	61	1158	13461	64075	\N	54.000965999999998	Республика Башкортостан, Белебеевский район, Малиновский сельсовет7018, д.Малиновка, Школьная, 4		0101000020E61000007AFF1F274C0A4B40373465A71F004B40
20679	7	61	1158	12912	66259	\N	54.183613000000001	Республика Башкортостан, Белебеевский район, Анновский сельсовет, д.Илькино, Центральная, 9		0101000020E61000002F505260010A4B406B0F7BA180174B40
21991	7	61	1158	13237	65920	\N	54.102406000000002	Республика Башкортостан, Куюргазинский район, Кривле-Илюшкинский сельсовет, д.Знаменка, Зеленая, 16		0101000020E61000002FBFD364C6314B400475CAA31B0D4B40
20686	7	61	1158	13237	63723	\N	54.102406000000002	Республика Башкортостан, Белебеевский район, Знаменский сельсовет, с.Знаменка, Заводская, 20		0101000020E61000002FBFD364C6314B400475CAA31B0D4B40
20853	7	61	1158	13112	65832	\N	54.193216999999997	с.Ермолкино, Центральная, 2А		0101000020E610000037E15E99B7F44A40FF03AC55BB184B40
20684	7	61	1158	13112	65767	\N	54.193216999999997	Республика Башкортостан, Белебеевский район, Ермолкинский сельсовет, с.Ермолкино, Ленина, 1		0101000020E610000037E15E99B7F44A40FF03AC55BB184B40
20701	7	61	1158	13949	66296	\N	54.165863000000002	Республика Башкортостан, Белебеевский район, Усень-Ивановский сельсовет, с.Веровка, Веровка, 31/1		0101000020E61000003A950C0055404B40E84EB0FF3A154B40
20643	7	61	1158	10973	63321	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Чапаева, 73		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20658	7	61	1158	10973	63792	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Тукаева, 77		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20639	7	61	1158	10973	64044	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Советская, 11		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20641	7	61	1158	10973	63621	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Пролетарская, 41а		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20657	7	61	1158	10973	9951	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Ленина, 1		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20241	7	61	571	32901	64456	\N	53.349150000000002	с.Давлетово, ул.Школьная, 16		0101000020E6100000EBFEB1101D564D40FFB27BF2B0AC4A40
20656	7	61	1158	10973	9951	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Ленина, 9		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20638	7	61	1158	10973	63639	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Красноармейская, 77		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20647	7	61	1158	10973	63328	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Красная, 111		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20640	7	61	1158	10973	63592	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Коммунистическая, 13в		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20650	7	61	1158	10973	63595	\N	54.096932098593498	Республика Башкортостан, Белебеевский район, город Белебей, Волгоградская, 10	Россия, республика Башкортостан, Белебеевский район, Белебей	0101000020E61000004D83A279000D4B40CBF78C44680C4B40
20653	7	61	1158	10973	63473	\N	54.103313418626797	Республика Башкортостан, Белебеевский район, город Белебей, Амирова, 10а	Россия, республика Башкортостан, Белебеевский район, Белебей	0101000020E6100000075C57CC080F4B403620425C390D4B40
20652	7	61	1158	10973	63473	\N	54.103515000000002	Республика Башкортостан, Белебеевский район, город Белебей, Амирова, 6		0101000020E610000044F7AC6BB40E4B409ED2C1FA3F0D4B40
20683	7	61	1158	13103	65314	\N	54.160127000000003	Республика Башкортостан, Белебеевский район, Ермолкинский сельсовет, д.Баймурзино, Мира, 33		0101000020E610000058FE7C5BB0F24A40721AA20A7F144B40
20680	7	61	1158	12962	63545	\N	53.974871	Республика Башкортостан, Белебеевский район, Баженовский сельсовет, с.Баженово, Административная, 5		0101000020E6100000FD31AD4D63F34A40CF68AB92C8FC4A40
20678	7	61	1158	12874	66257	\N	54.245266000000001	Республика Башкортостан, Белебеевский район, Анновский сельсовет, с.Анновка, Советская, 15		0101000020E6100000D00EB8AE98074B400E6954E0641F4B40
20694	7	61	1158	13592	65318	\N	54.101514000000002	Республика Башкортостан, Белебеевский район, Рассветовский сельсовет, д.Алексеевка, Школьная, 15		0101000020E6100000EB5223F433034B40070B2769FE0C4B40
20676	7	61	1158	12767	63364	\N	54.0137162182955	Республика Башкортостан, Белебеевский район, Аксаковский сельсовет, с.Аксаково, Первомайская, 2	Россия, республика Башкортостан, Белебеевский район, поселок Аксаково	0101000020E61000007B2FBE688F134B404AB72572C1014B40
20682	7	61	1158	13042	64727	\N	54.180520000000001	Республика Башкортостан, Белебеевский район, Ермолкинский сельсовет, с.Аделькино, Центральная, 54		0101000020E6100000A75B76887FFC4A40102384471B174B40
20596	7	61	607	8991	66249	\N	55.973379999999999	д.Янтимирово, Центральная, 43		0101000020E6100000406B7EFCA5114C404D4A41B797FC4B40
20635	7	61	607	10862	64244	\N	56.078713999999998	д.Штанды, Центральная, 8	Россия, республика Башкортостан, Балтачевский район, село Штанды	0101000020E61000002AA73D25E7124C4061DEE34C130A4C40
20631	7	61	607	58782	66452	\N	56.078700147141198	Адрес помещения для голосования: д.Шавъяды, улица Центральная, 49\\1, Адрес УИК: д.Шавъяды, улица Центральная, 61		0101000020E61000004644317903EA4B40FC1873D7120A4C40
20599	7	61	607	9128	66252	\N	55.792107999999999	Адрес помещения для голосования: д.Чуртанлыкуль, улица Центральная 8, Адрес УИК: д.Чуртанлыкуль, улица Победы, 15		0101000020E6100000CEFBFF3861FC4B40327381CB63E54B40
20621	7	61	607	48372	65572	\N	55.887518	д.Чукалы, Центральная, 9		0101000020E61000006C770FD07D194C40404E98309AF14B40
20908	7	61	607	58632	65797	\N	55.866376575857203	с. Чишма, Советская, 4	Россия, республика Башкортостан, Балтачевский район, село Чишма	0101000020E6100000E8D9ACFA5CFB4B40D8800871E5EE4B40
20609	7	61	607	58795	66478	\N	55.920403356392399	д.Усманово, Центральная, 16\\1	Россия, республика Башкортостан, Балтачевский район, село Усманово	0101000020E61000004C89247A19E54B40F511F8C3CFF54B40
20629	7	61	607	10572	64633	\N	55.987085	с.Тучубаево, Школьная, 13		0101000020E610000080492A53CCD94B40A3AF20CD58FE4B40
20604	7	61	607	58785	66463	\N	56.085035540630699	Адрес помещения для голосования: д.Тутагачево, улица Центральная, 31, АдресУИК: д.Тутагачево, улица Центральная, 29		0101000020E6100000725298F738FB4B40C87DAB75E20A4C40
20616	7	61	607	9922	66261	\N	56.032156999999998	д. Туктаево, Центральная, 2		0101000020E61000005E2BA1BB24044C4032AB77B81D044C40
20595	7	61	607	4263	66795	\N	55.987774999999999	д.Тузлубино, ул.Мира, 17		0101000020E6100000CE8C7E349CFA4B40386744696FFE4B40
20632	7	61	607	58789	66469	\N	56.079366999999998	д.Тибелево, Центральная, 35	Россия, республика Башкортостан, Балтачевский район, село Тибелеево	0101000020E6100000B344679945F04B40D9B0A6B2280A4C40
20618	7	61	607	10011	64833	\N	55.913978999999998	д.Староянбаево, Ленина, 42		0101000020E6100000382F4E7CB5134C408A1D8D43FDF44B40
20623	7	61	607	10289	64627	\N	55.940975999999999	д.Староямурзино, Центральная, 30\\1		0101000020E61000007A3881E9B4EA4B401329CDE671F84B40
20614	7	61	607	9839	64730	\N	56.008671	д. Староякшеево, Центральная, 20		0101000020E6100000C45DBD8A8CF04B4039B69E211C014C40
20586	7	61	607	8535	66608	\N	55.8569905536324	Адрес избирательного участка: д.Старотимкино, ул.. Центральная 13, Адрес УИК: д.Старотимкино, ул. Жукова, 1	Россия, республика Башкортостан, Балтачевский район, село Старотимкино	0101000020E61000009AB67F65A50B4C40B1FB8EE1B1ED4B40
20612	7	61	607	9747	63724	\N	56.003281755370502	с.Старобалтачево, Юбилейная 2	Россия, республика Башкортостан, Балтачевский район, село Старобалтачево	0101000020E6100000E75086AA98F64B402E55698B6B004C40
20613	7	61	607	9747	63291	\N	56.003140000000002	с.Старобалтачево, Советская, 92		0101000020E61000006EDC627E6EF64B409CA73AE466004C40
20611	7	61	607	9747	63511	\N	56.003140000000002	с.Старобалтачево, Комсомольская, 65		0101000020E61000006EDC627E6EF64B409CA73AE466004C40
20622	7	61	607	10222	64196	\N	55.971747999999998	с.Сейтяково, Советская, 1		0101000020E6100000789B374E0AE54B4009FA0B3D62FC4B40
20589	7	61	607	8645	64723	\N	55.916648000000002	д. Новоямурзино, К.Маркса, 16		0101000020E6100000936E4BE482F74B40CFF8BEB854F54B40
20627	7	61	607	6508	64973	\N	56.051355999999998	д.Новобалтачево, Первомайская, 39	Россия, республика Башкортостан, Балтачевский район, село Новобалтачево	0101000020E6100000D42B6519E2024C40083A5AD592064C40
20603	7	61	607	4342	66896	\N	56.122416903698301	с. Нижнесикиязово, ул. Центральная ,19	Россия, республика Башкортостан, Балтачевский район, село Нижнесикиязово	0101000020E6100000A9A27895B5F34B40BABC395CAB0F4C40
20597	7	61	607	9031	64739	\N	55.834713999999998	с.Нижнекарышево, Центральная, 35		0101000020E61000008DEDB5A0F7FC4B40B5C189E8D7EA4B40
20593	7	61	607	8818	66248	\N	55.956229	д.Нижнеиванаево, Центральная, 54		0101000020E61000008DD5E6FF55FF4B404F3E3DB665FA4B40
20602	7	61	607	58839	66564	\N	55.814422456515203	Адрес помещения для голосования: д. Начарово, улица Озерная, 12, Адрес УИК: д. Начарово, улица Озерная, 10	Россия, республика Башкортостан, Балтачевский район, село Начарово	0101000020E6100000FE2AC0779BF34B404B92E7FA3EE84B40
14692	7	61	607	10265	65441	\N	56.069353999999997	д.Мата, Ленина, 18	Россия, республика Башкортостан, Балтачевский район, село Мата	0101000020E61000003E95D39E921B4C4063EC8497E0084C40
20605	7	61	607	58798	66483	\N	56.126170488306499	д.Мангашлы-Алмантаево, Центральная, 38	Россия, республика Башкортостан, Балтачевский район, село Магашлы-Алмантаево	0101000020E6100000386A85E97BFF4B4040DEAB5626104C40
20592	7	61	607	8805	65771	\N	55.908524999999997	Адрес помещения для голосования: д.Курачево, улица Первомайская, 5, Адрес УИК: улица Ленина, 4		0101000020E61000000DA7CCCD37264C40984C158C4AF44B40
20594	7	61	607	8905	65765	\N	55.964815999999999	д.Кунтугушево, К.Маркса, 20		0101000020E6100000DCD6169E97084C402A5437177FFB4B40
20591	7	61	607	8744	64832	\N	55.849701000000003	Адрес избирательного участка: д.Кундашлы, улица Такаева 49, Адрес УИК: д.Кундашлы, улица Центральная 48		0101000020E61000000490DAC4C9194C4073309B00C3EC4B40
20615	7	61	607	9848	66256	\N	56.006376000000003	д.Кумьязы, Советская, 49\\4		0101000020E610000078616BB6F2004C405ABDC3EDD0004C40
20634	7	61	607	29446	65443	\N	56.036220999999998	д.Кузеево, Центральная, 28	Россия, республика Башкортостан, Балтачевский район, село Кузеево	0101000020E6100000244223D8B8E84B40D636C5E3A2044C40
20600	7	61	607	9159	66253	\N	55.756020999999997	Адрес помещения для голосования: д. Кизганбашево, улица Центральная 15, Адрес УИК: д. Кизганбашево, улица Покровская, 9		0101000020E610000022C66B5ED5EB4B406B0BCF4BC5E04B40
20617	7	61	607	58805	66495	\N	56.028550999866397	д.Староиликеево, Кооперативная, 2\\2	Россия, республика Башкортостан, Балтачевский район, село Иликеево	0101000020E610000091F3FE3F4EFA4B4051A2258FA7034C40
20588	7	61	607	8620	66226	\N	55.954515999999998	д. Верхнеянактаево, Социалистическая, 10		0101000020E6100000FA0E7EE200F84B401EC18D942DFA4B40
20598	7	61	607	58796	66480	\N	55.809456360059698	Адрес помещения для голосования: д.Верхнекарышево, улица Центральная, 15, Адрес УИК: д.Верхнекарышево, улица Центральная, 35	Россия, республика Башкортостан, Балтачевский район, село Верхнекарышево	0101000020E61000004DBA2D910BFE4B4086C613419CE74B40
20630	7	61	607	10619	65150	\N	56.011454000000001	д.Верхнекансиярово, Школьная, 5		0101000020E61000007B8670CCB2DD4B4046B41D5377014C40
20587	7	61	607	47349	66292	\N	55.845627999999998	с. Богданово, Варламова, 5	Россия, республика Башкортостан, Балтачевский район, село Богданово	0101000020E61000003B8C497F2F094C407B4ACE893DEC4B40
20626	7	61	607	10408	66163	\N	56.138146999999996	д.Асавка, Минниахметова, 53		0101000020E6100000EBE2361AC00D4C402F8507CDAE114C40
20547	7	61	846	6683	66108	\N	55.137172999999997	деревня Юльтимировка, улица Центральная, дом 41		0101000020E6100000B188618731D34A40757286E28E914B40
20577	7	61	846	58820	66524	\N	55.224043000000002	село Старые Шарашли, улица Центральная, дом 59	Россия, республика Башкортостан, Бакалинский район, село Шарашли	0101000020E6100000E3FA777DE6E24A40E9F2E670AD9C4B40
20561	7	61	846	7347	64591	\N	55.004092972302502	село Утарово, улица Мира, дом 63А	Россия, республика Башкортостан, Бакалинский район, село Утарово	0101000020E6100000603AADDBA0E24A403E92921E86804B40
20550	7	61	846	6808	65163	\N	54.996344999999998	деревня Устюмово, улица Т. Нуркаева, дом 48А		0101000020E61000000F7C0C569CDC4A403D44A33B887F4B40
20581	7	61	846	47608	65311	\N	54.926720000000003	село Урманаево, улица Центральная, дом 1А		0101000020E61000001D03B2D7BBC34A404A46CEC29E764B40
20542	7	61	846	6417	64715	\N	55.137548000000002	село Токбердино, улица Школьная, дом 46		0101000020E6100000AC1C5A643BF14A40ABD0402C9B914B40
20579	7	61	846	8170	65774	\N	55.223730000000003	село Тактагулово, улица Молодежная, дом 9	Россия, республика Башкортостан, Бакалинский район, село Тактагулово	0101000020E6100000C05E61C1FD184B402A91442FA39C4B40
20575	7	61	846	7984	64286	\N	55.234112000000003	село Старые Маты, улица Победы, дом 7		0101000020E610000044F7AC6BB4F84A40F3CCCB61F79D4B40
20541	7	61	846	6359	65753	\N	55.113252164491698	село Старокуяново, улица Центральная, дом 95	Россия, республика Башкортостан, Бакалинский район, село Старокуяново	0101000020E6100000F9484A7A18EC4A40721AA20A7F8E4B40
20569	7	61	846	7640	64014	\N	55.137295999999999	село Старокуручево, улица Центральная, дом 41		0101000020E6100000C095ECD808084B4091EF52EA92914B40
20568	7	61	846	7640	64014	\N	55.137295999999999	село Старокуручево, улица Центральная, дом 23		0101000020E6100000C095ECD808084B4091EF52EA92914B40
20566	7	61	846	58776	66434	\N	55.203749999999999	село Старокостеево, улица Центральная, дом 69А	Россия, республика Башкортостан, Бакалинский район, село Старокостеевко	0101000020E6100000C40B2252D3D24A40AE47E17A149A4B40
20563	7	61	846	7455	64502	\N	55.177431003749099	село Старокатаево, улица Школьная, дом 20	Россия, республика Башкортостан, Бакалинский район, село Старокатаево	0101000020E6100000363FFED2A2F64A40F6251B0FB6964B40
20554	7	61	846	6987	65545	\N	55.325564	село Староиликово, улица Центральная, дом 42А		0101000020E61000006876DD5B91EE4A40A260C614ACA94B40
20548	7	61	846	6712	66105	\N	55.157912000000003	село Старое Азмеево, улица Центральная, дом 31А		0101000020E61000002CD670917BC84A40AFD2DD7536944B40
20539	7	61	846	58804	66494	\N	55.163188864753501	деревня Сосновка, улица Сосновая, дом 4	Россия, республика Башкортостан, Бакалинский район	0101000020E610000033FB3C4679EC4A4092088D60E3944B40
20558	7	61	846	7178	65667	\N	55.038294	село Новый Тумутук, улица Центральная, дом 62		0101000020E610000028EE7893DFAE4A4007D15AD1E6844B40
20576	7	61	846	8006	66116	\N	55.253326999999999	село Новые Маты, улица Ленина, дом 16		0101000020E6100000BA9F53909F054B40CE18E6046DA04B40
20540	7	61	846	6293	65302	\N	55.133266999999996	деревня Новые Балыклы, улица Центральная, дом 73		0101000020E6100000A0E238F06AE34A4069519FE40E914B40
20557	7	61	846	7169	64706	\N	55.000518	деревня Новосасыкуль, улица Нагорная, дом 1		0101000020E6100000B7EF517FBDB84A4098874CF910804B40
20553	7	61	846	58377	64865	\N	55.343814000000002	село Новоиликово, улица Магистральная, дом 24	Россия, республика Башкортостан, Бакалинский район, село Новоиликово	0101000020E61000004FCDE50643F14A4017F4DE1802AC4B40
20552	7	61	846	6888	66117	\N	55.287430000000001	деревня Новоальметьево, улица Мира, дом 55		0101000020E6100000DA3BA3AD4ADE4A40D4F19881CAA44B40
20578	7	61	846	8154	65762	\N	55.271518	деревня Новоагбязово, улица Школьная, дом 13		0101000020E6100000B05758703FDA4A403E23111AC1A24B40
20565	7	61	846	7532	64767	\N	55.155834303265003	село Нагайбаково, улица Речная, дом 75	Россия, республика Башкортостан, Бакалинский район, село Нагайбаково	0101000020E610000052B9895A9AA14A406CCD565EF2934B40
20562	7	61	846	7379	64193	\N	55.019067	село Мустафино, улица Ленина, дом 103	Россия, республика Башкортостан, Бакалинский район, село Мустафино	0101000020E61000001669E21DE0CD4A4067B796C970824B40
20582	7	61	846	8330	66179	\N	54.958244999999998	деревня Мирзаитово, улица Центральная, дом 5		0101000020E6100000BDE2A9471AD04A401B47ACC5A77A4B40
20556	7	61	846	7077	65305	\N	55.018830000000001	село Куштиряково, улица Школьная, дом 2		0101000020E6100000693524EEB1B44A4083177D0569824B40
20420	7	61	846	32117	64756	\N	55.069431999999999	село Курчеево, улица Ленина, дом 29А		0101000020E610000075E789E76CBF4A40DFA5D425E3884B40
20572	7	61	846	7836	64719	\N	55.150618000000001	село Килькабызово, улица Советская, дом 10		0101000020E61000001E17D522A2FE4A402F185C7347934B40
20551	7	61	846	47020	65760	\N	55.283292000000003	село Килеево, улица Центральная, дом 2А	Россия, республика Башкортостан, Бакалинский район, село Килеево	0101000020E61000004F948444DAEA4A40F69B89E942A44B40
20549	7	61	846	6784	64345	\N	55.032707000000002	село Камышлытамак, улица Клубная, дом 14		0101000020E6100000D0D1AA9674DC4A40D6AC33BE2F844B40
20583	7	61	846	7718	64720	\N	55.186807999999999	село Камаево, улица Центральная, дом 6		0101000020E61000002618CE35CC1A4B40CA501553E9974B40
20570	7	61	846	7718	64720	\N	55.186807999999999	село Камаево, улица Центральная, дом 70а		0101000020E61000002618CE35CC1A4B40CA501553E9974B40
20546	7	61	846	6624	65306	\N	55.081333000000001	село Дияшево, улица Школьная, дом 54		0101000020E61000005D1ABFF04AD44A40F48AA71E698A4B40
20580	7	61	846	58761	66381	\N	55.210084608601001	деревня Гурдебашево, улица Лесная, дом 33	Россия, республика Башкортостан, Бакалинский район, село Гурдыбашево	0101000020E6100000C005D9B27C0B4B40A930B610E49A4B40
20560	7	61	846	7284	66071	\N	55.056398000000002	село Бугабашево, улица Утина, дом 19 А		0101000020E6100000E48233F8FBF54A40A8C7B60C38874B40
20574	7	61	846	47484	64728	\N	55.075760923719599	деревня Балчиклы, улица Центральная, дом 29	Россия, республика Башкортостан, Бакалинский район, село Балчиклы	0101000020E6100000E620E868550B4B40F8A75489B2894B40
20536	7	61	846	32794	63722	\N	55.177925000000002	село Бакалы, улица Школьная, дом 19		0101000020E6100000274D83A279E64A400612143FC6964B40
20535	7	61	846	32794	63722	\N	55.177925000000002	село Бакалы, улица Школьная, дом 1		0101000020E6100000274D83A279E64A400612143FC6964B40
20537	7	61	846	32794	63296	\N	55.177925000000002	село Бакалы, улица Ленина, дом 166		0101000020E6100000274D83A279E64A400612143FC6964B40
20534	7	61	846	32794	63296	\N	55.177925000000002	село Бакалы, улица Ленина, дом 116		0101000020E6100000274D83A279E64A400612143FC6964B40
20533	7	61	846	32794	63488	\N	55.177945899156903	село Бакалы, улица Красных партизан, дом 31/2	Россия, республика Башкортостан, Бакалинский район, село Бакалы	0101000020E61000005AF44E05DCE54A401D3A3DEFC6964B40
20543	7	61	846	46850	65701	\N	55.142158999999999	село Ахманово, улица Центральная, дом 82		0101000020E610000075594C6C3EDC4A4081EA1F4432924B40
20473	7	61	322	2687	65704	\N	52.566161000000001	Республика Башкортостан, Баймакский район, с.Яратово, улица Сакмара, дом 10		0101000020E6100000F2EB87D860FB4C40A5A2B1F677484A40
20518	7	61	322	5127	65295	\N	52.619615122707501	Республика Башкортостан, Баймакский район, д.Янзигитово, улица Мельничная, дом 13	Россия, республика Башкортостан, Баймакский район, село Янзигитово	0101000020E61000001C261AA4E04B4D40378E588B4F4F4A40
20530	7	61	322	5766	65310	\N	52.355201000000001	Республика Башкортостан, Баймакский район, д.Янгазино, улица Янгазинская, дом 19		0101000020E61000007C613255303E4D40D540F339772D4A40
20467	7	61	322	2347	64007	\N	52.506996999999998	Республика Башкортостан, Баймакский район, с.Юмашево, улица Школьная, дом 2А		0101000020E6100000F373435376F84C40C6151747E5404A40
20468	7	61	322	2413	65705	\N	52.519098	Республика Башкортостан, Баймакский район, д.Юлук, улица Чанышева, дом 2		0101000020E61000000F0A4AD1CAE54C40A2B5A2CD71424A40
20478	7	61	322	2996	65247	\N	52.690308000000002	Республика Башкортостан, Баймакский район, д.Шулька, улица Акназарова, дом 20		0101000020E6100000BE2F2E5569DB4C40661536035C584A40
20524	7	61	322	58651	65876	\N	52.275258000000001	Республика Башкортостан, Баймакский район, д.Урал, улица Школьная, дом 34	Россия, республика Башкортостан, Баймакский район, село Уральское	0101000020E610000039F1D58EE2724D402FFB75A73B234A40
20502	7	61	322	4255	66125	\N	53.129714999999997	Республика Башкортостан, Баймакский район, д.Уметбаево, улица Башкир, дом 49		0101000020E6100000DEE4B7E864174D407B6649809A904A40
20509	7	61	322	58510	65255	\N	52.854484999999997	Республика Башкортостан, Баймакский район, д.2-е Туркменево, улица Мурадым, дом 20	Россия, республика Башкортостан, Баймакский район, село Туркменево 2-е	0101000020E61000004D49D6E1E83E4D4016F6B4C35F6D4A40
20508	7	61	322	4589	64182	\N	52.873170999999999	Республика Башкортостан, Баймакский район, с.1-е Туркменево, улица Школьная, дом 2		0101000020E61000003944DC9C4A424D4066683C11C46F4A40
20503	7	61	322	4348	64205	\N	52.893070999999999	Республика Башкортостан, Баймакский район, с.Тубинский, улица С.Юлаева, дом 28		0101000020E6100000FE261422E01C4D40C500892650724A40
20493	7	61	322	3809	66913	\N	52.989879000000002	Республика Башкортостан, Баймакский район, с.Темясово, улица Советская, дом 8		0101000020E61000002CBAF59A1E0E4D40A4FFE55AB47E4A40
20494	7	61	322	3809	63265	\N	52.989879000000002	Республика Башкортостан, Баймакский район, с.Темясово, улица С.Юлаева, дом 18		0101000020E61000002CBAF59A1E0E4D40A4FFE55AB47E4A40
20515	7	61	322	5001	65717	\N	52.575744999999998	Республика Башкортостан, Баймакский район, с.Татлыбаево, улица Татлыбаева, дом 48а		0101000020E6100000357A3540694C4D40F2EA1C03B2494A40
20513	7	61	322	4883	63749	\N	52.707450000000001	Республика Башкортостан, Баймакский район, с.Старый Сибай, улица Ленина, дом 14		0101000020E61000009FE74F1BD5474D4011C7BAB88D5A4A40
20496	7	61	322	3954	65710	\N	52.823816999999998	Республика Башкортостан, Баймакский район, д.Сакмар, улица Школьная, дом 1		0101000020E6100000D09849D40B124D40C571E0D572694A40
20523	7	61	322	58540	65407	\N	54.7852098805946	Республика Башкортостан, Баймакский район, д.Покровка, улица Молодежная, дом 23а	Россия, республика Башкортостан, деревня Покровка, улица Нижняя Покровская	0101000020E610000094F8DC09F6E74B40FF3EE3C281644B40
20476	7	61	322	2872	64487	\N	52.631072000000003	Республика Башкортостан, Баймакский район, с.1-е Иткулово, улица Ленина, дом 101		0101000020E6100000EA5A7B9FAAFA4C40EEB5A0F7C6504A40
20527	7	61	322	58746	66343	\N	52.396432565678801	Республика Башкортостан, Баймакский район, д.Октябрь, улица Школьная, дом 1	Россия, республика Башкортостан, Баймакский район, село поселок Октябрьского Отделения	0101000020E6100000B01F628385654D4010070951BE324A40
20497	7	61	322	4012	66034	\N	53.037094000000003	Республика Башкортостан, Баймакский район, д.Нижнетагирово, улица Школьная, дом 53		0101000020E61000006EDA8CD310154D405D70067FBF844A40
20479	7	61	322	61546	79368	\N	52.695838456825697	Республика Башкортостан, Баймакский район, с.Тавлыкаево, улица З.Валиди, дом  19	Россия, республика Башкортостан, Баймакский район, село Нижнетавлыкаево	0101000020E610000056647440120A4D4033A8363811594A40
20486	7	61	322	3450	64492	\N	52.789434	Республика Башкортостан, Баймакский район, с.Нигаматово, улица К.Диярова, дом 3		0101000020E6100000E6CC76853E064D40DC2C5E2C0C654A40
20492	7	61	322	58598	65683	\N	52.898736999999997	Республика Башкортостан, Баймакский район, Кульчуровский сельсовет, улица Тансыккужина, дом 28	Россия, республика Башкортостан, Баймакский район, село Муллакаево	0101000020E610000050AA7D3A1E0D4D40425A63D009734A40
20339	7	61	322	58598	66856	\N	52.8989414314714	д. Муллакаево, ул. Сулейманова, 11	Россия, республика Башкортостан, Баймакский район, село Муллакаево	0101000020E61000001BF5108DEE0C4D404B04AA7F10734A40
20504	7	61	322	4376	64152	\N	52.681863	Республика Башкортостан, Баймакский район, с.Мерясово, улица Р.Уметбаева, дом 2		0101000020E6100000CF2EDFFAB0284D401DAD6A4947574A40
20483	7	61	322	3288	64495	\N	52.665739000000002	Республика Башкортостан, Баймакский район, с.Куянтаево, улица Аселинская, дом 2		0101000020E610000098C0ADBB79164D40FC5580EF36554A40
20489	7	61	322	3617	66027	\N	52.927500999999999	Республика Башкортостан, Баймакский район, с.Кульчурово, улица Самарбаева, дом 8		0101000020E6100000A3E6ABE463094D40EF004F5AB8764A40
20525	7	61	322	58852	66585	\N	52.631406261595998	Республика Башкортостан, Баймакский район, д.Культабан, улица Школьная, дом 1	Россия, республика Башкортостан, Баймакский район, село Культубанское	0101000020E6100000AF601BF164594D40C43F6CE9D1504A40
20501	7	61	322	58716	66143	\N	52.739618999999998	Республика Башкортостан, Баймакский район, д.Кугидель, улица Ирандык, дом 14		0101000020E6100000F54A5986381E4D400740DCD5AB5E4A40
20471	7	61	322	2596	66801	\N	52.418987000000001	Республика Башкортостан, Баймакский район, д.Крепостной Зилаир, улица Почтовая, дом 13		0101000020E6100000A9DE1AD82AD74C407E39B35DA1354A40
20516	7	61	322	5016	66102	\N	52.527481000000002	Республика Башкортостан, Баймакский район, д.Карышкино, улица Ямаш, дом 7а		0101000020E610000049BC3C9D2B4E4D407521567F84434A40
20464	7	61	322	2189	65246	\N	52.625179000000003	Республика Башкортостан, Баймакский район, д.Каратал, улица С.Юлаева, дом 23		0101000020E61000003FE3C281900E4D40B0928FDD05504A40
20514	7	61	322	4914	65290	\N	52.713151795692298	Республика Башкортостан, Баймакский район, д.Калинино, улица Школьная, дом 1	Россия, республика Башкортостан, Баймакский район, село Калинино	0101000020E61000007CF1457BBC604D40DB899290485B4A40
20511	7	61	322	4777	66099	\N	52.786520000000003	Республика Башкортостан, Баймакский район, д.Казанка, улица Школьная, дом 2		0101000020E610000046239F573C5D4D4031D3F6AFAC644A40
20529	7	61	322	5754	64722	\N	52.388086999999999	Республика Башкортостан, Баймакский район, с.Ишмухаметово, улица Даута, дом 1		0101000020E6100000707A17EFC73B4D405A80B6D5AC314A40
20499	7	61	322	4118	65251	\N	52.959614999999999	Республика Башкортостан, Баймакский район, д.Ишей, улица Куктакинская, дом 5а		0101000020E610000061E3FA777DEC4C4022E010AAD47A4A40
20469	7	61	322	2474	64710	\N	52.482844	Республика Башкортостан, Баймакский район, с.Ишберда, улица С.Юлаева, дом 33		0101000020E6100000486AA16472D44C40F0880AD5CD3D4A40
20488	7	61	322	3560	65249	\N	52.819436000000003	Республика Башкортостан, Баймакский район, д.Исяново, улица Аминева, дом 46		0101000020E61000004D8237A4511F4D4021956247E3684A40
20507	7	61	322	4561	66096	\N	52.924970999999999	Республика Башкортостан, Баймакский район, д.Исянбетово, улица Исрафилова, дом 28		0101000020E61000004390831266304D40CC5F217365764A40
20472	7	61	322	58791	66471	\N	52.592334999999999	Республика Башкортостан, Баймакский район, д.Зелимво, улица Школьная, дом 9	Россия, республика Башкортостан, Баймакский район, село Зелимово	0101000020E6100000A77A32FFE8D74C4059A31EA2D14B4A40
20474	7	61	322	2747	65718	\N	52.585879037953802	Республика Башкортостан, Баймакский район, д.Гумерово, улица Исмагилова, дом 21	Россия, республика Башкортостан, Баймакский район, село Гумерово	0101000020E61000004546072461FB4C40E3344415FE4A4A40
20477	7	61	322	2938	66020	\N	52.613835000000002	Республика Башкортостан, Баймакский район, д.Гадельбаево, улица Школьная, дом 1		0101000020E6100000E38BF67821F74C40F1113125924E4A40
20484	7	61	322	58192	64219	\N	52.825268999999999	Республика Башкортостан, Баймакский район, с.2-е Иткулово, улица Ленина, дом 1	Россия, республика Башкортостан, Баймакский район, село Второе Иткулово	0101000020E61000003E97A949F0FC4C4089B3226AA2694A40
20487	7	61	322	58853	66588	\N	52.739618999999998	Республика Башкортостан, Баймакский район, д.В.Яикбаево, улица Школьная, дом 2	Россия, республика Башкортостан, Баймакский район	0101000020E6100000F54A5986381E4D400740DCD5AB5E4A40
20470	7	61	322	2527	66035	\N	52.405231999999998	Республика Башкортостан, Баймакский район, д.Бурзян-Елга, улица Баракал, дом 15		0101000020E61000002312859675C74C4076A565A4DE334A40
20481	7	61	322	3163	64834	\N	52.638635999999998	Республика Башкортостан, Баймакский район, д.Буранбаево, улица Сакмар, дом 9		0101000020E610000000529B38B9FF4C402D060FD3BE514A40
20506	7	61	322	58666	65934	\N	52.901974000000003	Республика Башкортостан, Баймакский район, д.Басаево, улица К.Диярова, дом 2	Россия, республика Башкортостан, Баймакский район, село Большебасаево	0101000020E610000096236420CF364D40D1EB4FE273734A40
20500	7	61	322	4172	66670	\N	53.078242000000003	Республика Башкортостан, Баймакский район, с.Билялово, улица З.Биишевой, дом  10		0101000020E61000008A7780272D1C4D403A9677D5038A4A40
20498	7	61	322	58879	66862	\N	53.062380276953299	Республика Башкортостан, Баймакский район, д.Бетеря, улица Школьная, дом 1	Россия, республика Башкортостан, Баймакский район, село Лесозавод 2	0101000020E6100000BE326FD575F84C4055F65D11FC874A40
20482	7	61	322	3226	64288	\N	52.739530999999999	Республика Башкортостан, Баймакский район, с.Бекешево, улица Колхозная, дом 2		0101000020E61000007AA52C431C0B4D4068B0A9F3A85E4A40
22171	7	61	322	47212	66299	\N	52.435702999999997	д. Баймурзино, Мичурина, 12		0101000020E6100000386A85E97B374D4071E2AB1DC5374A40
20454	7	61	322	1475	63538	\N	52.588433999999999	Республика Башкортостан, Баймакский район, город Баймак, проспект С.Юлаева, дом 19		0101000020E61000006A6B44300E284D405FED28CE514B4A40
20531	7	61	322	5837	65300	\N	52.471907000000002	Республика Башкортостан, Баймакский район, д.Баишево, улица Ургаза, дом 28а		0101000020E6100000D272A087DA424D4072E0D572673C4A40
20485	7	61	322	3392	64712	\N	52.865668999999997	Республика Башкортостан, Баймакский район, д.Баимово, улица Садовая, дом 38		0101000020E6100000348463963DFF4C409C14E63DCE6E4A40
20510	7	61	322	4712	64717	\N	52.833984060895098	Республика Башкортостан, Баймакский район, д.Ахмерово, улица Школьная, дом 1	Россия, республика Башкортостан, Баймакский район, село Ахмерово	0101000020E6100000CAA31B6151434D4092B1DAFCBF6A4A40
22808	7	61	322	3900	66221	\N	52.970100000000002	с.Аминево, Школьная, 20а		0101000020E610000074EB353D280A4D40C0EC9E3C2C7C4A40
20461	7	61	322	2003	66830	\N	52.454272000000003	Республика Башкортостан, Баймакский район, д.Алгазино, улица Янтура, дом 7		0101000020E61000008BA6B393C1E74C4088BEBB95253A4A40
20463	7	61	322	2141	66016	\N	52.572547999999998	Республика Башкортостан, Баймакский район, д.Актау, улица Х.Давлетшиной, дом 7		0101000020E61000004B94BDA59C154D40F2B1BB4049494A40
20462	7	61	322	2067	66693	\N	52.536898000000001	Республика Башкортостан, Баймакский район, с.Акмурун, улица Ленина, дом 40		0101000020E6100000FDDD3B6A4C104D40D7A4DB12B9444A40
20460	7	61	322	1946	65692	\N	52.422353999999999	Республика Башкортостан, Баймакский район, с.Абдулкаримово, улица Молодежная, дом 18		0101000020E6100000158F8B6A11EF4C40DAAA24B20F364A40
22382	7	61	322	5094	66865	\N	52.556415999999999	453164, РБ Стерлитамакский район, д. Абдрахманово, ул. Центральная 7		0101000020E6100000278925E5EE4F4D404E7CB5A338474A40
20517	7	61	322	5094	65292	\N	52.556415999999999	Республика Башкортостан, Баймакский район, д.Абдрахманово, улица С.Юлаева, дом 17а		0101000020E6100000278925E5EE4F4D404E7CB5A338474A40
20240	7	61	55	45365	64803	\N	53.912757022419903	д.Юлдашево, ул.Школьная, 1	Россия, республика Башкортостан, Аургазинский район, село Юлдашево	0101000020E6100000E6B2D1393FD34B40F818AC38D5F44A40
20440	7	61	55	786	64709	\N	54.032845000000002	Республика Башкортостан, Аургазинский район, Толбазинский сельсовет, д.Юламаново, Ленина, 22		0101000020E6100000E1CFF0660DEA4B40276BD44334044B40
20428	7	61	55	32463	64197	\N	53.870292999999997	Республика Башкортостан, Аургазинский район, Семенкинский сельсовет, с.Шланлы, Центральная, 42а		0101000020E6100000B07092E68FD54B400778D2C265EF4A40
20429	7	61	55	67	66146	\N	53.892060000000001	Республика Башкортостан, Аургазинский район, Семенкинский сельсовет, д.Шеверли, Центральная, 1б		0101000020E6100000D02A33A5F5D74B40EE08A7052FF24A40
20451	7	61	55	1427	64149	\N	53.955029000000003	Республика Башкортостан, Аургазинский район, Чуваш-Карамалинский сельсовет, с.Чуваш-Карамалы, Центральная, 10		0101000020E6100000171230BABC154C40A5DDE8633EFA4A40
20419	7	61	55	32096	64140	\N	54.126584000000001	Республика Башкортостан, Аургазинский район, Нагадакский сельсовет, д.Утеймуллино, Молодежная, 29		0101000020E610000000C974E8F41E4C4033198EE733104B40
20447	7	61	55	1213	64711	\N	54.068694000000001	Республика Башкортостан, Аургазинский район, Турумбетовский сельсовет, д.Усманово, Центральная, 10		0101000020E61000000FD6FF39CCC54B4039B709F7CA084B40
20446	7	61	55	1153	65992	\N	54.010713000000003	Республика Башкортостан, Аургазинский район, Турумбетовский сельсовет, с.Турумбет, Центральная, 8		0101000020E61000001C7A8B87F7C24B402F52280B5F014B40
20443	7	61	55	936	64491	\N	54.217663000000002	Республика Башкортостан, Аургазинский район, Тукаевский сельсовет, с.Тукаево, Чанышева, 32		0101000020E61000005E2EE23B31E94B404E469561DC1B4B40
20441	7	61	55	844	64484	\N	54.086981999999999	Республика Башкортостан, Аургазинский район, Тряпинский сельсовет, с.Тряпино, Первомайская, 1		0101000020E6100000317C444C89164C409BABE639220B4B40
20439	7	61	55	461	63566	\N	54.005951000000003	Республика Башкортостан, Аургазинский район, Толбазинский сельсовет, с.Толбазы, Школьная, 2	Россия, республика Башкортостан, Аургазинский район, село Толбазы	0101000020E61000001D3BA8C475F24B4073309B00C3004B40
20438	7	61	55	461	63633	\N	54.005951000000003	Республика Башкортостан, Аургазинский район, Толбазинский сельсовет, с.Толбазы, Химиков, 4		0101000020E61000001D3BA8C475F24B4073309B00C3004B40
20437	7	61	55	461	63512	\N	54.005951000000003	Республика Башкортостан, Аургазинский район, Толбазинский сельсовет, с.Толбазы, Ленина, 125		0101000020E61000001D3BA8C475F24B4073309B00C3004B40
20436	7	61	55	461	63512	\N	54.005951000000003	Республика Башкортостан, Аургазинский район, Толбазинский сельсовет, с.Толбазы, Ленина, 113	Россия, республика Башкортостан, Аургазинский район, село Толбазы	0101000020E61000001D3BA8C475F24B4073309B00C3004B40
20435	7	61	55	461	63510	\N	54.005951000000003	Республика Башкортостан, Аургазинский район, Толбазинский сельсовет, с.Толбазы, Ибрагимова, 23		0101000020E61000001D3BA8C475F24B4073309B00C3004B40
20433	7	61	55	342	64142	\N	53.961233	Республика Башкортостан, Аургазинский район, Таштамакский сельсовет, д.Таштамак, Фрунзе, 6		0101000020E610000091D26C1E87DF4B40016BD5AE09FB4A40
20418	7	61	55	32031	64486	\N	54.095193999999999	Республика Башкортостан, Аургазинский район, Нагадакский сельсовет, д.Татарский Нагадак, Центральная, 121		0101000020E61000002F4D11E0F4244C40416326512F0C4B40
20432	7	61	55	274	64392	\N	54.100600999999997	Республика Башкортостан, Аургазинский район, Султанмуратовский сельсовет, с.Султанмуратово, Центральная, 44		0101000020E6100000804A95287BDD4B40F2785A7EE00C4B40
20430	7	61	55	153	64324	\N	54.002490000000002	Республика Башкортостан, Аургазинский район, Степановский сельсовет, с.Степановка, Молодежная, 1г		0101000020E6100000C11BD2A8C0D74B409548A29751004B40
20415	7	61	55	31920	65987	\N	53.895458581831697	Республика Башкортостан, Аургазинский район, Меселинский сельсовет, д.Старомакарово, Выездная, 2	Россия, республика Башкортостан, Аургазинский район, село Старомакарово	0101000020E610000079573D601EF24B4056F487669EF24A40
20411	7	61	55	31735	65234	\N	54.254531756151501	Республика Башкортостан, Аургазинский район, Ишлинский сельсовет, д.Старокузяково, Советская, 16	Россия, республика Башкортостан, Аургазинский район, село Старокузяково	0101000020E61000006A6AD95A5FF64B408AE42B8194204B40
20424	7	61	55	32297	64341	\N	53.813076000000002	Республика Башкортостан, Аургазинский район, Семенкинский сельсовет, с.Семенкино, Советская, 2в		0101000020E61000004243FF0417D94B40CD94D6DF12E84A40
21619	7	61	55	45948	66748	\N	54.034280720830203	д.Салихово,ул.Советская,2	Россия, республика Башкортостан, Аургазинский район, село Салихово	0101000020E6100000335019FF3EC34B40E5EFDE5163044B40
20421	7	61	55	3910	65445	\N	54.050953	Республика Башкортостан, Аургазинский район, Новокальчировский сельсовет, д.Новые Карамалы, Центральная, 15		0101000020E61000003A234A7B83F74B400951BEA085064B40
20407	7	61	55	31535	64441	\N	54.114711	Республика Башкортостан, Аургазинский район, Ибраевский сельсовет, д.Новофедоровка, Первомайская, 26а		0101000020E61000001AA6B6D4410A4C40E8BE9CD9AE0E4B40
20409	7	61	55	31635	65229	\N	54.203451000000001	Республика Башкортостан, Аургазинский район, Исмагиловский сельсовет, д.Новотимошкино, К.Маркса, 19		0101000020E610000025CFF57D38FE4B4054ABAFAE0A1A4B40
20403	7	61	55	31316	64707	\N	54.027852000000003	Республика Башкортостан, Аургазинский район, Батыровский сельсовет, д.Новоитикеево, Школьная, 14		0101000020E6100000008E3D7B2EFB4B40699082A790034B40
20425	7	61	55	58774	66436	\N	53.788468926412897	Республика Башкортостан, Аургазинский район, Семенкинский сельсовет, д.Нижний Бегеняш, Центральная, 1в		0101000020E610000049490F43ABC74B4075745C8DECE44A40
20401	7	61	55	31215	64321	\N	53.894250999999997	Республика Башкортостан, Аургазинский район, Балыклыкульский сельсовет, д.Наумкино, Центральная, 31а		0101000020E6100000A51309A69AE34B4028B517D176F24A40
20404	7	61	55	31412	65620	\N	54.067093	Республика Башкортостан, Аургазинский район, Батыровский сельсовет, д.Мустафино, 7 Ноября, 11		0101000020E61000008C834BC79C0D4C403065E08096084B40
20417	7	61	55	58380	64878	\N	53.948178412724303	Республика Башкортостан, Аургазинский район, Михайловский сельсовет, д.Мурадым, Школьная, 35	Россия, республика Башкортостан, Аургазинский район	0101000020E6100000C4B3041901C34B40B2648EE55DF94A40
20416	7	61	55	31962	66010	\N	53.954118000000001	Республика Башкортостан, Аургазинский район, Михайловский сельсовет, д.Михайловка, Ленина, 69		0101000020E610000011E335AFEAD04B403143E38920FA4A40
20413	7	61	55	31821	64077	\N	53.841056999999999	Республика Башкортостан, Аургазинский район, Меселинский сельсовет, с.Месели, Центральная, 80		0101000020E610000083A10E2BDCE84B4033897AC1A7EB4A40
20414	7	61	55	31851	65619	\N	53.852494	Республика Башкортостан, Аургазинский район, Меселинский сельсовет, с.Манеево, Циолковского, 3а		0101000020E61000009AEB34D252E34B40A304FD851EED4A40
80052	7	72	393	15878	48411	\N	53.702558000000003	село Северный Ключ, Мира, 8-В		0101000020E61000005857056A31D8494087C5A86BEDD94A40
20442	7	61	55	932	65240	\N	54.060704999999999	Республика Башкортостан, Аургазинский район, Тряпинский сельсовет, д.Малый Нагадак, Восточная, 27		0101000020E61000002AE109BDFE1C4C4012DA722EC5074B40
20406	7	61	55	31518	65617	\N	54.136153999999998	Республика Башкортостан, Аургазинский район, Ибраевский сельсовет, с.Малое Ибраево, Ленина, 1а		0101000020E6100000C8D0B1834A024C401B9C887E6D114B40
21624	7	61	55	58876	66825	\N	54.226172075042697	с.Макарово, ул.Центральная,28	Россия, республика Башкортостан, Аургазинский район, село Макарово	0101000020E61000001B834E081DE04B40ADA23F34F31C4B40
20423	7	61	55	32248	64280	\N	54.099518000000003	Республика Башкортостан, Аургазинский район, Новокальчировский сельсовет, д.Кшанны, Ленина, 49		0101000020E610000006D49B51F3E74B4082AE7D01BD0C4B40
20449	7	61	55	1326	65242	\N	54.137225000000001	Республика Башкортостан, Аургазинский район, Уршакский сельсовет, д.Курманаево, Школьная, 4а		0101000020E610000022FC8BA031D14B40C898BB9690114B40
20402	7	61	55	31284	64469	\N	54.018326000000002	Республика Башкортостан, Аургазинский район, Батыровский сельсовет, с.Куезбашево, Садовая, 40а		0101000020E61000001572A59E05054C405055A18158024B40
20412	7	61	55	31761	64279	\N	53.941564	Республика Башкортостан, Аургазинский район, Кебячевский сельсовет, д.Кебячево, Мира, 2а		0101000020E6100000DB19A6B6D4F74B40A48B4D2B85F84A40
20422	7	61	55	58787	66464	\N	54.082763319842002	Республика Башкортостан, Аургазинский район, Новокальчировский сельсовет, д.Кальчирбуран, Центральная, 47б		0101000020E61000009D0E643DB5EE4B40D0285DFA970A4B40
20410	7	61	55	31682	64273	\N	54.197772999999998	Республика Башкортостан, Аургазинский район, Ишлинский сельсовет, с.Ишлы, Ленина, 21		0101000020E61000002041F163CCF34B4012842BA050194B40
20408	7	61	55	31599	64391	\N	54.168998999999999	Республика Башкортостан, Аургазинский район, Исмагиловский сельсовет, с.Исмагилово, Центральная, 5		0101000020E6100000EAB46E83DAF94B4042075DC2A1154B40
20444	7	61	55	1047	65664	\N	54.170901999999998	Республика Башкортостан, Аургазинский район, Тукаевский сельсовет, с.Болотино, Центральная, 37		0101000020E6100000501BD5E940EA4B401669E21DE0154B40
20405	7	61	55	31429	64326	\N	53.981501000000002	Республика Башкортостан, Аургазинский район, Бишкаинский сельсовет, с.Бишкаин, Центральная, 63а		0101000020E6100000ACC43C2B690F4C40E3FE23D3A1FD4A40
20400	7	61	55	28776	66594	\N	53.951594658097797	Республика Башкортостан, Аургазинский район, Балыклыкульский сельсовет, д.Балыклыкуль, Центральная, 39	Россия, республика Башкортостан, Аургазинский район, село Балыклыкуль	0101000020E61000003B1A87FA5DE84B40C0046EDDCDF94A40
20427	7	61	55	32425	65633	\N	53.835053000000002	Республика Башкортостан, Аургазинский район, Семенкинский сельсовет, д.Асавбашево, Центральная, 67б		0101000020E6100000F60CE19865D94B409EB64604E3EA4A40
20445	7	61	55	1089	65243	\N	54.235894999999999	Республика Башкортостан, Аургазинский район, Тукаевский сельсовет, с.Андреевка, Школьная, 8		0101000020E610000078EE3D5C72DA4B401C25AFCE311E4B40
19989	7	61	55	11407	63546	\N	53.865664000000002	село Амзя, Школьная, 25		0101000020E6100000B4588AE42BDF4B408BA9F413CEEE4A40
19988	7	61	55	11407	63563	\N	53.865664000000002	село Амзя, Лесохимическая, 10		0101000020E6100000B4588AE42BDF4B408BA9F413CEEE4A40
20431	7	61	55	224	66648	\N	54.045814999999997	Республика Башкортостан, Аургазинский район, д.Александровка, ул.Ленина, 51		0101000020E6100000E7FEEA71DFDC4B4047551344DD054B40
20394	7	61	998	30899	64699	\N	56.077939999999998	Республика Башкортостан, Аскинский район, Султанбековский сельсовет, д.Чурашево, Центральная, 8		0101000020E61000009160AA99B5964C406E861BF0F9094C40
20367	7	61	998	29560	65535	\N	55.912076999999996	Республика Башкортостан, Аскинский район, Аскинский сельсовет, д.Чишма-Уракаево, Центральная, 34/2		0101000020E61000008D9B1A683E314C4086376BF0BEF44B40
20383	7	61	998	30325	64754	\N	56.090864000000003	Республика Башкортостан, Аскинский район, Кубиязовский сельсовет, д.Утяшино, Крупской, 2		0101000020E610000020D1048A58664C401F317A6EA10B4C40
20399	7	61	998	31127	65221	\N	56.131419999999999	Республика Башкортостан, Аскинский район, Усть-Табасский сельсовет, д.Усть-Табаска, Гагарина, 29		0101000020E61000006EA5D76663BB4C402905DD5ED2104C40
20398	7	61	998	31110	64703	\N	56.149751999999999	Республика Башкортостан, Аскинский район, Урмиязовский сельсовет, д.Уршады, Набережная, 3		0101000020E61000004BE9995E628A4C405B41D3122B134C40
20370	7	61	998	29709	64742	\N	55.928339999999999	Республика Башкортостан, Аскинский район, Евбулякский сельсовет, д.Упканкуль, Центральная, 1		0101000020E6100000EE08A7052F404C40C9C859D8D3F64B40
20797	7	61	998	47344	64672	\N	56.347389	Республика Башкортостан, Белорецкий район, Ишлинский сельсовет, с.Улуелга, Лесная, 8		0101000020E6100000CA6DFB1EF52D4C40BDFE243E772C4C40
20363	7	61	998	29372	64657	\N	56.262022999999999	Республика Башкортостан, Аскинский район, Аскинский сельсовет, д.Тюйск, Цветочная, 16		0101000020E61000004B5CC7B8E24E4C4060E63BF889214C40
20360	7	61	998	29275	65235	\N	56.233578999999999	Республика Башкортостан, Аскинский район, Аскинский сельсовет, д.Тульгузбаш, Юбилейная, 2		0101000020E6100000CE716E13EE3D4C402504ABEAE51D4C40
20393	7	61	998	30841	65568	\N	56.030214999999998	Республика Башкортостан, Аскинский район, Султанбековский сельсовет, д.Султанбеково, Центральная, 33		0101000020E6100000D3F4D901D7914C40A06CCA15DE034C40
20369	7	61	998	29642	65539	\N	56.028661	Республика Башкортостан, Аскинский район, Евбулякский сельсовет, д.Султанай, Механизаторов, 22		0101000020E610000006D50627A23D4C40D8D5E429AB034C40
20389	7	61	998	30625	64753	\N	56.221443999999998	Республика Башкортостан, Аскинский район, Мутабашевский сельсовет, с.Старый Мутабаш, Центральная, 29		0101000020E61000006092CA1473244C409DF2E846581C4C40
79849	7	72	\N	55868	\N	\N	53.0498724898059	поселок Рощинский, Комбинат бытового обслуживания	Россия	0101000020E6100000C13BF9F4D83E4940397EA83462864A40
20371	7	61	998	29751	64261	\N	56.204549	Республика Башкортостан, Аскинский район, Казанчинский сельсовет, с.Старые Казанчи, Школьная, 11А		0101000020E6100000684128EFE31C4C40FAB660A92E1A4C40
20372	7	61	998	29751	64700	\N	56.204549	Республика Башкортостан, Аскинский район, Казанчинский сельсовет, с.Старые Казанчи, Центральная, 21		0101000020E6100000684128EFE31C4C40FAB660A92E1A4C40
20387	7	61	998	8554	65562	\N	56.282600000000002	Республика Башкортостан, Аскинский район, Кшлау-Елгинский сельсовет, д.Новые Казанчи, Гумерова, 4		0101000020E61000003D433866D9234C40C0EC9E3C2C244C40
20365	7	61	998	58822	66526	\N	55.999688047946798	Республика Башкортостан, Аскинский район, Аскинский сельсовет, д.Новые Багазы, Советская, 10	Россия, республика Башкортостан, Аскинский район, село Новобогазы	0101000020E61000009355116E325A4C40111AC1C6F5FF4B40
20396	7	61	998	31001	64704	\N	56.086399	Республика Башкортостан, Аскинский район, Урмиязовский сельсовет, д.Новокочкильдино, Трактовая, 6		0101000020E6100000B0AA5E7EA76D4C401CB4571F0F0B4C40
20373	7	61	998	29856	65968	\N	56.131023999999996	Республика Башкортостан, Аскинский район, Казанчинский сельсовет, д.Новая Кара, Школьная, 2А		0101000020E610000060915F3FC4204C40DC7EF964C5104C40
20362	7	61	998	29349	65956	\N	56.159213000000001	Республика Башкортостан, Аскинский район, Аскинский сельсовет, с.Новая Бурма, Школьная, 1		0101000020E61000007A724D81CC564C408D0C721761144C40
20390	7	61	998	30706	64909	\N	56.209890999999999	Республика Башкортостан, Аскинский район, Мутабашевский сельсовет, д.Мута-Елга, Центральная, 51		0101000020E6100000906802452C2C4C40C45C52B5DD1A4C40
20384	7	61	998	30387	64701	\N	56.050189000000003	Республика Башкортостан, Аскинский район, Кубиязовский сельсовет, д.Матала, Ленина, 10		0101000020E6100000DF1B430070624C403ACFD8976C064C40
20386	7	61	998	30498	65975	\N	56.286163000000002	Республика Башкортостан, Аскинский район, Кшлау-Елгинский сельсовет, д.Кшлау-Елга, Школьная, 7		0101000020E610000096CCB1BCAB2C4C40A2293BFDA0244C40
20364	7	61	998	29445	64695	\N	56.015259	Республика Башкортостан, Аскинский район, Аскинский сельсовет, с.Куяштыр, Крестьянская, 6		0101000020E6100000166A4DF38E494C401EFCC401F4014C40
20385	7	61	998	30416	65973	\N	56.214427044216102	Республика Башкортостан, Аскинский район, Кунгаковский сельсовет, д.Кунгак, Молодежная, 4	Россия, республика Башкортостан, Аскинский район, село Кунгак	0101000020E61000006F2BBD361BA74C4090300C58721B4C40
20382	7	61	998	30217	65559	\N	56.103793000000003	Республика Башкортостан, Аскинский район, Кубиязовский сельсовет, с.Кубиязы, Ленина, 2		0101000020E6100000D07EA4880C5F4C40E146CA16490D4C40
20380	7	61	998	30205	65556	\N	55.984532000000002	Республика Башкортостан, Аскинский район, Ключевский сельсовет, с.Ключи, Центральная, 10		0101000020E6100000FA0D130D52304C40C8EE022505FE4B40
20392	7	61	998	30798	65980	\N	56.053069999999998	Республика Башкортостан, Аскинский район, Петропавловский сельсовет, с.Кигазы, Центральная, 6		0101000020E6100000BF2A172AFF2A4C4009336DFFCA064C40
20375	7	61	998	29902	65550	\N	56.022131999999999	Республика Башкортостан, Аскинский район, Кашкинский сельсовет, с.Кашкино, Мира, 10		0101000020E61000009B594B01697F4C40F818AC38D5024C40
20374	7	61	998	29902	65550	\N	56.022131999999999	Республика Башкортостан, Аскинский район, Кашкинский сельсовет, с.Кашкино, Мира, 17		0101000020E61000009B594B01697F4C40F818AC38D5024C40
20379	7	61	998	30138	65215	\N	55.943582999999997	Республика Башкортостан, Аскинский район, Карткисяковский сельсовет, д.Карткисяк, Центральная, 8		0101000020E6100000626534F2794B4C40E107E753C7F84B40
20368	7	61	998	29623	64740	\N	55.995004999999999	Республика Башкортостан, Аскинский район, Евбулякский сельсовет, д.Евбуляк, Центральная, 11		0101000020E610000038A4518193414C40A12DE7525CFF4B40
20378	7	61	998	30110	64702	\N	55.996519999999997	Республика Башкортостан, Аскинский район, Кашкинский сельсовет, д.Гумбино, Первомайская, 16		0101000020E6100000184339D1AE864C40ABE7A4F78DFF4B40
20377	7	61	998	30043	65978	\N	56.003326000000001	Республика Башкортостан, Аскинский район, Кашкинский сельсовет, д.Бильгиш, Первомайская, 12		0101000020E610000092E86514CB734C40FE9C82FC6C004C40
20361	7	61	998	29291	65938	\N	56.143377999999998	Республика Башкортостан, Аскинский район, Аскинский сельсовет, д.Барахаевка, Лесная, 4		0101000020E61000004C6E14596B464C40A27BD6355A124C40
20388	7	61	998	28737	66786	\N	56.351435339891502	Республика Башкортостан, Аскинский район, Кшлау-Елгинский сельсовет, д.Базанчатово, Центральная, 3	Россия, республика Башкортостан, Аскинский район, село Базанчатово	0101000020E61000004C1C7920B2344C40BBD573D2FB2C4C40
20355	7	61	998	29025	63372	\N	56.093007999999998	Республика Башкортостан,  Аскинский район, Аскинский сельсовет, с.Аскино, Пионерская, 7		0101000020E6100000AC55BB26A4494C401822A7AFE70B4C40
20358	7	61	998	29025	63634	\N	56.093007999999998	Республика Башкортостан, Аскинский район, Аскинский сельсовет, с.Аскино, Октябрьская, 6		0101000020E6100000AC55BB26A4494C401822A7AFE70B4C40
20359	7	61	998	29025	63459	\N	56.093007999999998	Республика Башкортостан, Аскинский район, Аскинский сельсовет, с.Аскино, Мичурина, 59		0101000020E6100000AC55BB26A4494C401822A7AFE70B4C40
20356	7	61	998	29025	66637	\N	56.093007999999998	Республика Башкортостан, Аскинский район, Аскинский сельсовет, с.Аскино,  Мира, 8		0101000020E6100000AC55BB26A4494C401822A7AFE70B4C40
20357	7	61	998	29025	64483	\N	56.093007999999998	Республика Башкортостан, Аскинский район, Аскинский сельсовет, с.Аскино, Ленина, 100		0101000020E6100000AC55BB26A4494C401822A7AFE70B4C40
20366	7	61	998	29534	65536	\N	55.95194	Республика Башкортостан, Аскинский район, Арбашевский сельсовет, с.Арбашево, Центральная, 9/2		0101000020E6100000BE310400C72E4C408BE07F2BD9F94B40
79834	7	72	\N	62070	81084	\N	53.233868534718603	село Рождествено, Шоссейная, 1б	Россия	0101000020E61000004225AE635C0749402C465D6BEF9D4A40
20376	7	61	998	29280	64748	\N	56.036969999999997	Республика Башкортостан, Аскинский район, Кашкинский сельсовет, д.Амирово, Центральная, 47		0101000020E610000004594FADBE7C4C407077D66EBB044C40
20354	7	61	931	29007	65211	\N	54.518821000000003	с. Узунларово, Центральная, 35		0101000020E61000003ECBF3E0EE784C4030BDFDB968424B40
20042	7	61	931	13952	65598	\N	54.228954000000002	д. Убалары, Центральная, 84		0101000020E610000062D68BA19C6A4C40EA245B5D4E1D4B40
20344	7	61	931	58553	65483	\N	54.627828999999998	д. Троицкое, Заречная, 1 А	Россия, республика Башкортостан, Архангельский район, село Троицкое	0101000020E610000004E275FD82574C407D3D5FB35C504B40
18587	7	61	931	7491	64409	\N	54.431176000000001	д. Тереклы, Школьная, 40		0101000020E61000006DAE9AE7887A4C40F96871C630374B40
20351	7	61	931	28870	66005	\N	54.468421999999997	д. Тавакачево, Школьная, 12		0101000020E610000063D520CCED604C400B5D8940F53B4B40
20343	7	61	931	47461	65126	\N	54.591821975123899	д. Сагитово, Школьная, 48	Россия, республика Башкортостан, Архангельский район, село Сагитово	0101000020E6100000062D246074654C40D386C3D2C04B4B40
20350	7	61	931	28803	66004	\N	54.447251000000001	д. Приуралье, Вокзальная, 3 А		0101000020E6100000AB05F698485F4C40390D51853F394B40
22937	7	61	931	58623	66352	\N	54.330454758551397	с. Орловка, Центральная, 48	Россия, республика Башкортостан, Архангельский район, село Орловка	0101000020E61000000953944BE3494C405CE674594C2A4B40
20349	7	61	931	58623	65759	\N	54.330254104553497	д. Орловка, Казаковская, 35	Россия, республика Башкортостан, Архангельский район, село Орловка	0101000020E61000003067B62BF4494C40C4AF58C3452A4B40
20337	7	61	931	32842	64150	\N	54.299585792720698	д. Максим Горький, Ленина, 42	Россия, республика Башкортостан, Архангельский район, село Максим Горький	0101000020E6100000E9B6442E38654C40732B84D558264B40
20342	7	61	931	28453	65782	\N	54.333089999999999	д. Кысынды, Центральная, 25		0101000020E6100000C45E28603B564C40F44F70B1A22A4B40
20341	7	61	931	28406	65737	\N	54.320614999999997	с. Красный Зилим, Центральная, 2		0101000020E61000005DFC6D4F904E4C40B3CD8DE909294B40
18351	7	61	931	27830	66646	\N	54.408948000000002	д. Кизги, ул. Центральная, 25		0101000020E6100000CAC16C020C8F4C40DFE1766858344B40
20348	7	61	931	28723	66516	\N	54.374155555625499	д. Карташевка, Нефтяников, 4	Россия, республика Башкортостан, Архангельский район, село Карташевка	0101000020E610000003EB387EA8404C4014CD0358E42F4B40
18795	7	61	931	58448	65050	\N	54.513814000000004	с. Казанка, Озерная, 9	Россия, республика Башкортостан, Архангельский район, село Казанка	0101000020E610000040C39B35786B4C400D1D3BA8C4414B40
20338	7	61	931	47372	66188	\N	54.277510247806397	д.Заря, Школьная, 6	Россия, республика Башкортостан, Архангельский район, село Заря	0101000020E61000006058FE7C5B684C400F289B7285234B40
20340	7	61	931	28334	64858	\N	54.312558000000003	д.Заитово, Нижняя, 2 А	Россия, республика Башкортостан, Архангельский район, село Заитово	0101000020E6100000376F9C14E6594C40350D8AE601284B40
18620	7	61	931	33045	64268	\N	54.541655938073902	с. Валентиновка, Советская, 57	Россия, республика Башкортостан, Архангельский район, село Валентиновка	0101000020E6100000F73B1405FA704C4052D7DAFB54454B40
20345	7	61	931	58184	64185	\N	54.507153757408602	с. Благовещенка, Центральная, 2	Россия, республика Башкортостан, Архангельский район, село Благовещенка	0101000020E610000065A54929E8524C408E041A6CEA404B40
20324	7	61	931	27732	64266	\N	54.432144999999998	с. Бакалдинское, Матросова, 8	Россия, республика Башкортостан, Архангельский район, село Бакалдинское	0101000020E6100000ED2DE57CB1734C40A110018750374B40
20335	7	61	931	47303	63604	\N	54.403860000000002	с. Архангельское, Чернышевского, 22 А		0101000020E6100000486C770FD0634C40CF143AAFB1334B40
20353	7	61	931	28944	66002	\N	54.484785000000002	д. Айтмембетово, Школьная, 16		0101000020E61000009F758D9603874C40B24B546F0D3E4B40
20352	7	61	931	47632	65143	\N	54.454039999999999	д. Азово, Советская, 29		0101000020E6100000E607AEF2048C4C40B58993FB1D3A4B40
20333	7	61	931	28043	64481	\N	54.457531000000003	с. Абзаново, ул. А.Абдрахманова, 70		0101000020E610000060E5D022DB554C40FEF33460903A4B40
20308	7	61	672	58838	66561	\N	53.969208263014302	Республика Башкортостан, Альшеевский район, Кармышевский сельсовет, с. Дим, Салавата Юлаева, 28	Россия, республика Башкортостан, Альшеевский район	0101000020E6100000CAA48636007D4B40C382FB010FFC4A40
20329	7	61	672	27863	63456	\N	53.982014999999997	Республика Башкортостан, Альшеевский район, Шафрановский сельсовет, с. Шафраново, Кирова, 4		0101000020E610000049F3C7B436634B403997E2AAB2FD4A40
20307	7	61	672	26861	65698	\N	53.999885999999996	Республика Башкортостан, Альшеевский район, Кармышевский сельсовет, д. Чураево, Школьная, 40/1		0101000020E6100000ED82C13577804B4037DDB243FCFF4A40
20328	7	61	672	27840	64287	\N	53.865195999999997	Республика Башкортостан, Альшеевский район, Чебенлинский сельсовет, с. Чебенли, Центральная, 6		0101000020E610000058E1968FA4804B40A45016BEBEEE4A40
20296	7	61	672	26336	65129	\N	53.948293999999997	Республика Башкортостан, Альшеевский район, Аксеновский сельсовет, д. Ханжарово, Школьная, 7		0101000020E6100000B4E4F1B4FC4C4B401B7FA2B261F94A40
20312	7	61	672	27094	65702	\N	53.820109000000002	Республика Башкортостан, Альшеевский район, Кызыльский сельсовет, с. Уразметово, Молодежная, 12		0101000020E6100000D3669C86A8B44B40E013EB54F9E84A40
20306	7	61	672	26804	65118	\N	53.988331000000002	Республика Башкортостан, Альшеевский район, Кармышевский сельсовет, д. Уваровка, Рабочая, 12а		0101000020E6100000F77475C7626F4B40BE4F55A181FE4A40
20326	7	61	672	27750	64472	\N	54.097042000000002	Республика Башкортостан, Альшеевский район, Трунтаишевский сельсовет, с. Трунтаишево, Центральная, 68а		0101000020E6100000B2D991EA3B5F4B40522B4CDF6B0C4B40
20325	7	61	672	27663	64293	\N	54.175244999999997	Республика Башкортостан, Альшеевский район, Ташлинский сельсовет, с. Ташлы, Центральная, 37		0101000020E6100000588CBAD6DE574B40CDE49B6D6E164B40
20311	7	61	672	27034	64278	\N	53.789219089139799	Республика Башкортостан, Альшеевский район, Кызыльский сельсовет, с. Тавричанка, Гагарина, 15	Россия, республика Башкортостан, Альшеевский район, село Тавричанка	0101000020E6100000B3976DA7AD9F4B40E030D12005E54A40
20323	7	61	672	27595	64010	\N	53.963605999999999	Республика Башкортостан, Альшеевский район, Слаковский сельсовет, с. Слак, Центральная, 1		0101000020E6100000A0E238F06A5B4B405C1D007157FB4A40
20327	7	61	672	27761	65999	\N	54.072699167459398	Республика Башкортостан, Альшеевский район, Трунтаишевский сельсовет, с. Сараево, Школьная, 5	Россия, республика Башкортостан, Альшеевский район, село Сараево	0101000020E6100000C1C58A1A4C4F4B40D8B969334E094B40
20291	7	61	672	4593	63736	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Школьная, 1		0101000020E610000001857AFA08784B40C6F99B5088084B40
20283	7	61	672	4593	63991	\N	54.078371225851697	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Советская площадь, 3	Россия, республика Башкортостан, Альшеевский район, поселок Раевский	0101000020E6100000B35C363AE7774B4037FA980F080A4B40
20284	7	61	672	4593	63638	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Свободы, 108		0101000020E610000001857AFA08784B40C6F99B5088084B40
20285	7	61	672	4593	63643	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Полевая, 63		0101000020E610000001857AFA08784B40C6F99B5088084B40
20286	7	61	672	4593	63357	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Победы, 2А		0101000020E610000001857AFA08784B40C6F99B5088084B40
20282	7	61	672	4593	64281	\N	54.0693925803605	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Кускова, 36		0101000020E6100000DA20938C9C794B4021C9ACDEE1084B40
20288	7	61	672	4593	64421	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Коммунистическая, 41		0101000020E610000001857AFA08784B40C6F99B5088084B40
20287	7	61	672	4593	64421	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Коммунистическая, 17		0101000020E610000001857AFA08784B40C6F99B5088084B40
20289	7	61	672	4593	63359	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Кирова, 88А		0101000020E610000001857AFA08784B40C6F99B5088084B40
20290	7	61	672	4593	63515	\N	54.066659999999999	Республика Башкортостан, Альшеевский район, Раевский сельсовет, с. Раевский, Гагаринаё, 20		0101000020E610000001857AFA08784B40C6F99B5088084B40
20310	7	61	672	27011	65726	\N	53.970618999999999	Республика Башкортостан, Альшеевский район, Кипчак-Аскаровский сельсовет, с. Отрада, Центральная, 52	Россия, республика Башкортостан, Альшеевский район, село Отрада	0101000020E61000002DB4739A05904B4028F04E3E3DFC4A40
22143	7	61	672	58554	65485	\N	54.145491237111898	с. Новотроицкое, Школьная, 34	Россия, республика Башкортостан, Альшеевский район, село Новотроицкое	0101000020E6100000927538BA4A534B40616EF7729F124B40
20302	7	61	672	26614	64134	\N	54.079836	Республика Башкортостан, Альшеевский район, Ибраевский сельсовет, с. Новосепяшево, Центральная, 38/3		0101000020E61000008E7406465E844B409085E810380A4B40
20926	7	61	672	25015	65802	\N	53.79815	с.Новоконстантиновка, Дружбы, 27/1		0101000020E610000030664B5645984B40B5A679C729E64A40
20319	7	61	672	27388	64188	\N	53.82687	Республика Башкортостан, Альшеевский район, Никифаровский сельсовет, с. Никифарово, Дружбы, 51а		0101000020E6100000F1A0D9756F594B4092054CE0D6E94A40
20321	7	61	672	27513	64006	\N	53.917850999999999	Республика Башкортостан, Альшеевский район, Нижнеаврюзовский сельсовет, с. Нижнее Аврюзово, Ленина, 54		0101000020E61000007C4276DEC6724B40EACC3D247CF54A40
20322	7	61	672	58858	66605	\N	54.615527	Республика Башкортостан, Альшеевский район, Нижнеаврюзовский сельсовет, с. Мечниково, Школьная, 12		0101000020E6100000E6E8F17B9BEC4B400A67B796C94E4B40
20315	7	61	672	27211	66877	\N	54.011893000000001	Республика Башкортостан, Альшеевский район, Нигматуллинский сельсовет, с. Нигматуллино, ул.Центральная, 35В		0101000020E61000000266BE839FAC4B409206B7B585014B40
20318	7	61	672	27357	65553	\N	53.970337999999998	Республика Башкортостан, Альшеевский район, Нигматуллинский сельсовет, с. Нефорощанка, Дружбы, 29		0101000020E61000004563EDEF6CB94B4074081C0934FC4A40
20314	7	61	672	27164	64435	\N	53.915008	Республика Башкортостан, Альшеевский район, Мендяновский сельсовет, с. Мендяново, Центральная, 68		0101000020E6100000FD169D2CB5624B4008CA6DFB1EF54A40
20293	7	61	672	26185	63999	\N	54.071235999999999	Республика Башкортостан, Альшеевский район, Абдрашитовский сельсовет, с. Крымский, Больничная, 2а		0101000020E61000004F3BFC3559A34B402026E1421E094B40
20309	7	61	672	26939	64131	\N	53.935192999999998	Республика Башкортостан, Альшеевский район, Кипчак-Аскаровский сельсовет, с. Кипчак-Аскарово, Салавата Юлаева, 109		0101000020E610000046D09849D4874B405C397B67B4F74A40
20297	7	61	672	26379	65111	\N	53.931567000000001	Республика Башкортостан, Альшеевский район, Аксеновский сельсовет, с. Кайраклы, Центральная, 8		0101000020E6100000DA54DD239B414B40348463963DF74A40
20303	7	61	672	26660	64648	\N	54.136571000000004	Республика Башкортостан, Альшеевский район, Казанский сельсовет, с. Казанка, Центральная, 60		0101000020E6100000CDE506431D684B40804A95287B114B40
20331	7	61	672	27964	65133	\N	54.019298999999997	Республика Башкортостан, Альшеевский район, Шафрановский сельсовет, д. Идрисово, Школьная, 1а		0101000020E6100000C0EC9E3C2C6E4B4039ECBE6378024B40
20300	7	61	672	26544	64642	\N	53.828873000000002	Республика Башкортостан, Альшеевский район, Зеленоклиновский сельсовет, д. Зеленый Клин, Школьная, 2		0101000020E6100000894160E5D0924B40CAC4AD8218EA4A40
20299	7	61	672	26472	64476	\N	53.798209	Республика Башкортостан, Альшеевский район, Гайниямакский сельсовет, с. Гайниямак, Центральная, 45		0101000020E6100000B020CD58344D4B40BA2F67B62BE64A40
20298	7	61	672	26431	64125	\N	53.875878	Республика Башкортостан, Альшеевский район, Воздвиженский сельсовет, с. Воздвиженка, Центральная, 10		0101000020E610000088BD50C076424B4098A432C51CF04A40
20320	7	61	672	27467	65130	\N	53.834994999999999	Республика Башкортостан, Альшеевский район, Никифаровский сельсовет,  д. Балгазы, Школьная, 10а		0101000020E6100000CBD6FA22A16B4B4069A9BC1DE1EA4A40
20317	7	61	672	27285	64737	\N	53.947076000000003	Республика Башкортостан, Альшеевский район, Нигматуллинский сельсовет, с. Байдаковка, Центральная, 3		0101000020E61000008AE8D7D64FAD4B40CB694FC939F94A40
20294	7	61	672	26247	64459	\N	53.916674	Республика Башкортостан, Альшеевский район, Аксеновский сельсовет, с. Аксеново, Советская, 14		0101000020E6100000ECC039234A4D4B40F88BD99255F54A40
20292	7	61	672	26168	64184	\N	54.016210000000001	Республика Башкортостан, Альшеевский район, Абдрашитовский сельсовет, с. Абдрашитово, Озерная, 1а		0101000020E61000005875560BEC994B4020EF552B13024B40
20248	7	61	571	32926	66932	\N	53.454915999999997	д.Озерное, ул. Школьная, 32		0101000020E610000074EE76BD34674D40AC36FFAF3ABA4A40
20281	7	61	571	61565	79396	\N	53.258198999999998	с.Янгельское, ул. Стадионная, 14		0101000020E610000004E5B67D8F644D40116E32AA0CA14A40
20276	7	61	571	4489	66885	\N	53.586013000000001	д.Шарипово, ул. Горная, 7		0101000020E610000093567C43E10F4D40F303577902CB4A40
20219	7	61	571	8076	66931	\N	53.020825000000002	с.Целинный, ул. Ленина, 5		0101000020E61000004F745DF8C15D4D4038F8C264AA824A40
20274	7	61	571	25334	64262	\N	53.050141000000004	с.Халилово, ул.Советская, 2 Г		0101000020E6100000274BADF71B474D40299831056B864A40
20270	7	61	571	25151	64752	\N	53.439498	д.Тупаково, ул.Хисматуллина, 53		0101000020E61000007FF8F9EFC1534D402654707841B84A40
20255	7	61	571	24457	65567	\N	53.1409369642315	д.Тепяново, ул.Центральная, 2	Россия, республика Башкортостан, Абзелиловский район, село Тепяново	0101000020E6100000AD342905DD464D40EFE53E390A924A40
22087	7	61	571	17231	66254	\N	53.661963999999998	д. Теляшево, Советская, 100		0101000020E6100000D449B6BA9C524D408E90813CBBD44A40
20280	7	61	571	58902	66979	\N	53.344930303699599	д.Таштуй, ул. Мира, 12/3	Россия, республика Башкортостан, Абзелиловский район	0101000020E61000005358A9A0A2624D4063B48EAA26AC4A40
20262	7	61	571	24808	64005	\N	53.622522368694597	с.Ташбулатово, ул.Центральная, 16	Россия, республика Башкортостан, Абзелиловский район, село Ташбулатово	0101000020E6100000D192C7D3F2594D402F8507CDAECF4A40
20239	7	61	571	23667	65656	\N	53.245759999999997	д.Тал-Кускарово, ул.Клубная, 8		0101000020E61000002DEDD45C6E3A4D401D554D10759F4A40
20238	7	61	571	3772	66645	\N	53.237526000000003	д.Таксырово, ул. Целинная, 1 а		0101000020E61000000327DBC01D544D4090F98040679E4A40
20233	7	61	571	23363	65541	\N	53.693111999999999	д.Старобалапаново, ул.Центральная, 2		0101000020E6100000C97553CA6B674D408A3BDEE4B7D84A40
20218	7	61	571	46521	65065	\N	53.130530999999998	д.Северный, ул.Клубная, 2		0101000020E61000009067976F7D644D409D0E643DB5904A40
20267	7	61	571	58784	66455	\N	53.521265911215004	д.Новое Самарское, ул.Центральная, 37/1	Россия, республика Башкортостан, Абзелиловский район, село Самарское	0101000020E610000052EE3EC7475D4D40244223D8B8C24A40
20223	7	61	571	22926	64595	\N	53.315244963663602	д.Рыскужино, ул.40 лет Победы, 23	Россия, республика Башкортостан, Абзелиловский район, село Рыскужино	0101000020E6100000C4EA8F300C2C4D401F9DBAF259A84A40
20232	7	61	571	3665	66912	\N	53.824249000000002	д.Рахметово, ул. Школьная, 14		0101000020E61000002FC03E3A75714D405F61C1FD80E94A40
20254	7	61	571	24412	65525	\N	53.207399000000002	д.Равилово, ул.Центральная, 23		0101000020E61000001895D40968424D408F1CE90C8C9A4A40
20279	7	61	571	58582	65618	\N	53.238264000000001	д.Первомайский, ул.Ф.Гумеровой, 14	Россия, республика Башкортостан, Абзелиловский район, село Первомайский	0101000020E6100000069CA564396D4D4036E84B6F7F9E4A40
20231	7	61	571	23281	65977	\N	53.744695149935197	д.Новобалапаново, ул.Салавата Юлаева, 9	Россия, республика Башкортостан, Абзелиловский район, село Новобалапаново	0101000020E610000036CCD07822604D40533F6F2A52DF4A40
20261	7	61	571	24731	64637	\N	53.704008895062003	д.Ниязгулово, ул.Школьная, 14	Россия, республика Башкортостан, Абзелиловский район, село Ниязгулово	0101000020E6100000F3C98AE1EA5C4D407A8B87F71CDA4A40
20230	7	61	571	23233	64590	\N	53.762604000000003	д.Муракаево, ул.Центральная, 7		0101000020E61000006B9BE27151594D403FE603029DE14A40
20273	7	61	571	58656	65889	\N	53.120112690398201	д.Махмутово, ул.Дружбы, 16 А	Россия, республика Башкортостан, Абзелиловский район, село Махмутово	0101000020E610000028D714C8EC444D408869DFDC5F8F4A40
20242	7	61	571	23803	65113	\N	53.347290000000001	д.Кушеево, ул.Сулейманова, 30		0101000020E6100000CEA78E554A4F4D402A1DACFF73AC4A40
20256	7	61	571	58275	64563	\N	53.606118346532099	с.Кусимовского рудника, ул.Школьная, 1	Россия, республика Башкортостан, Абзелиловский район, село Кусимовский Рудник	0101000020E61000009A99999999534D402BC24D4695CD4A40
20260	7	61	571	24716	66742	\N	53.624267000000003	д.Кусимово, ул. Школьная, 11		0101000020E61000002E71E481C84E4D406C7C26FBE7CF4A40
20265	7	61	571	24939	65527	\N	53.449311999999999	д.Кужаново, ул.Худайбердина, 33/1		0101000020E61000004B92E7FA3E4A4D40A5D93C0E83B94A40
20247	7	61	571	58122	63711	\N	53.391024000000002	с.Красная Башкирия, ул.Центральная, 11	Россия, республика Башкортостан, Абзелиловский район, село Красная Башкирия	0101000020E61000002E73BA2C266C4D40BEF90D130DB24A40
20246	7	61	571	23992	66128	\N	53.224412000000001	с.Кирдасово, ул.Советская, 50		0101000020E610000007EC6AF294214D403C6A4C88B99C4A40
20222	7	61	571	22884	65068	\N	53.312759999999997	д.Казмашево, ул.Ишбулатова, 24		0101000020E610000069E4F38AA7284D409CBF098508A84A40
20253	7	61	571	24331	63993	\N	53.164884999999998	с.Ишкулово, ул.Матросова, 35		0101000020E61000008DD2A57F49464D40EC4CA1F31A954A40
20235	7	61	571	23457	65110	\N	53.428688000000001	д.Ишкильдино, ул.Салавата Юлаева, 11		0101000020E6100000CFBA46CB81244D400518963FDFB64A40
20272	7	61	571	25239	66069	\N	53.075180000000003	д.Ишбулдино, ул.Новая, 2		0101000020E61000000C74ED0BE84B4D401AA88C7F9F894A40
20013	7	61	571	12631	64584	\N	53.766297999999999	д.Еникеево, ул.Шаймуратова, 19		0101000020E61000001557957D57644D40BF7E880D16E24A40
20251	7	61	571	24230	64762	\N	53.194535000000002	д.Давлетшино, ул.Центральная, 22		0101000020E610000040C05AB56B504D40B476DB85E6984A40
20237	7	61	571	23580	64251	\N	53.2673518104287	с.Гусево, ул.Соколова, 93	Россия, республика Башкортостан, Абзелиловский район, село Гусево	0101000020E6100000ACE46377815E4D409642209738A24A40
20234	7	61	571	23417	\N	\N	53.472622000000001	с.Бурангулово, ул.Советская, 39/2	Россия, республика Башкортостан, Абзелиловский район, село Бурангулово	0101000020E610000006F52D73BA2C4D4060AFB0E07EBC4A40
20216	7	61	571	58453	65059	\N	53.053324000000003	д.Булатово, ул.Молодежная, 21	Россия, республика Башкортостан, Абзелиловский район, село Булатово	0101000020E61000006E4E250340554D40C40B2252D3864A40
18132	7	61	571	58110	63509	\N	53.731059360689599	с.Баимово, ул.Школьная, 16	Россия, республика Башкортостан, Абзелиловский район, село Баимово	0101000020E61000004BC8073D9B6B4D402639605793DD4A40
20258	7	61	571	24584	65213	\N	53.586478	д.Аюсазово, ул.Школьная, 5		0101000020E61000003788D68A365B4D4068E90AB611CB4A40
20245	7	61	571	58385	64887	\N	53.229273999999997	д.Ахметово, ул.Сакмарская, 5	Россия, республика Башкортостан, Абзелиловский район, село Ахметово	0101000020E610000049D6E1E82A174D405BE9B5D9589D4A40
20278	7	61	571	58831	66540	\N	53.1802533624071	д.Атавды, ул.Школьная, 1	Россия, республика Башкортостан, Абзелиловский район, село отделение 4 Совхоза Янгильский	0101000020E6100000B936548CF3594D40C100C28712974A40
20228	7	61	571	49432	63513	\N	53.337414000000003	с.Аскарово, ул.Пионерская, 1		0101000020E6100000B88FDC9A74414D40359BC76130AB4A40
20215	7	61	571	22558	65990	\N	53.018127	д.Альмухаметово, ул.Молодежная, 10		0101000020E6100000431EC18D94594D4059164CFC51824A40
20277	7	61	571	58855	66592	\N	53.277178964079802	д.Авняш, ул.Центральная, 26	Россия, республика Башкортостан, Абзелиловский район, село отделение 2 Совхоза Янгильский	0101000020E610000082902C6002614D40A911FA997AA34A40
20263	7	61	571	24832	66021	\N	53.467782	д.Абзелилово, ул.Клочкова, 1		0101000020E6100000354580D3BB544D4028D4D347E0BB4A40
20271	7	61	571	25163	64924	\N	53.106572999999997	д.Абдулмамбетово, ул.Салавата Кадырова, 2		0101000020E6100000E8A4F78DAF454D407CD11E2FA48D4A40
20220	7	61	571	22799	65986	\N	53.341554000000002	д.Абдулгазино, ул.Ленина, 54		0101000020E6100000FDA4DAA7E31F4D40B4E89D0AB8AB4A40
7616	7	74	\N	6621	1788	\N	54.427168999999999	Ульяновская область, Ульяновский район, р.п. Ишеевка, ул. Школьная, д. 3	Россия, Ульяновская область, рабочий поселок Ишеевка, Школьная улица, 3	0101000020E6100000772E8CF4A2204840B96E4A79AD364B40
7614	7	74	\N	6621	47142	\N	54.421008999999998	Ульяновская область, Ульяновский район, р.п. Ишеевка, ул. Новокомбинатовская, д. 7		0101000020E6100000B1DF13EB542348402C29779FE3354B40
7613	7	74	\N	6621	47149	\N	54.420563364417099	Ульяновская область, Ульяновский район, р.п. Ишеевка, ул. Дачная, д. 5	Россия, Ульяновская область, рабочий поселок Ишеевка, Дачная улица, 1	0101000020E61000004E42E90B212348402E742502D5354B40
94445	7	74	\N	72	\N	\N	54.363039999999998	Ульяновская область,  город Ульяновск, Ленинский район, Муниципальное автономное дошкольное образовательное учреждение детский сад № 258 (ул. Репина, 41), спортивный зал		0101000020E6100000B2D5E59480244840E6913F18782E4B40
94444	7	74	\N	72	\N	\N	54.363039999999998	Ульяновская область,  город Ульяновск, Ленинский район, Муниципальное автономное дошкольное образовательное учреждение детский сад № 258 (ул. Репина, 41), музыкальный зал		0101000020E6100000B2D5E59480244840E6913F18782E4B40
94442	7	74	\N	72	\N	\N	54.248564999999999	Ульяновская область, город Ульяновск,  Железнодорожный район, адрес помещения для голосования: Муниципальное бюджетное дошкольное образовательное учреждение детский сад деревня Кувшиновка (ул. Кооперативная, 12), адрес УИК: ул. Свободы, д. 9		0101000020E6100000EB3A54539225484012F758FAD01F4B40
7837	7	74	\N	72	7440	\N	54.305546	Ульяновская область, город Ульяновск, Засвияжский район, ул. Терешковой, д. 6	Россия, Ульяновская область, Ульяновск, улица Терешковой, 6	0101000020E61000003D2828452B2B484039B69E211C274B40
7805	7	74	\N	72	7077	\N	54.348705000000002	Ульяновская область, город Ульяновск, Заволжский район, ул. Тельмана, д. 7	Россия, Ульяновская область, Ульяновск, улица Тельмана, 7	0101000020E6100000E6E786A6EC444840D1798D5DA22C4B40
7803	7	74	\N	72	7077	\N	54.345069000000002	Ульяновская область, город Ульяновск, Заволжский район, ул. Тельмана, д. 38	Россия, Ульяновская область, Ульяновск, улица Тельмана, 38	0101000020E61000007AA69718CB44484085EE92382B2C4B40
7880	7	74	\N	72	7908	\N	54.352010999999997	Ульяновская область,  город Ульяновск, Ленинский район, ул. Северный Венец, д. 32	Россия, Ульяновская область, Ульяновск, улица Северный Венец, 32	0101000020E610000020B6F468AA314840876A4AB20E2D4B40
7855	7	74	\N	72	7597	\N	54.281036999999998	Ульяновская область, город Ульяновск, Засвияжский район, ул. Рябикова, д. 25 А	Россия, Ульяновская область, Ульяновск, улица Рябикова, 25а	0101000020E6100000C170AE6186264840A4FB3905F9234B40
7854	7	74	\N	72	7597	\N	54.284101	Ульяновская область, город Ульяновск, Засвияжский район, ул. Рябикова, д. 30	Россия, Ульяновская область, Ульяновск, улица Рябикова, 30	0101000020E610000082531F48DE25484065E1EB6B5D244B40
7850	7	74	\N	72	7597	\N	54.291300999999997	Ульяновская область, город Ульяновск, Засвияжский район, ул. Рябикова, д. 6	Россия, Ульяновская область, Ульяновск, улица Рябикова, 6	0101000020E610000093A8177C9A2748406325E65949254B40
7876	7	74	\N	72	7878	\N	54.355778999999998	Ульяновская область,  город Ульяновск, Ленинский район, ул. Розы Люксембург, д. 48	Россия, Ульяновская область, Ульяновск, улица Розы Люксембург, 48	0101000020E61000008CD827806230484042CD902A8A2D4B40
7891	7	74	\N	72	47236	\N	54.347546000000001	Ульяновская область,  город Ульяновск, Ленинский район, ул. Радищева, д. 168		0101000020E610000050C422861D32484085ED27637C2C4B40
7894	7	74	\N	72	8012	\N	54.327199	Ульяновская область,  город Ульяновск, Ленинский район, ул. Радищева, д. 39	Россия, Ульяновская область, Ульяновск, улица Радищева, 39	0101000020E6100000B7ED7BD45F334840572426A8E1294B40
7841	7	74	\N	72	7431	\N	54.304647000000003	Ульяновская область, город Ульяновск, Засвияжский район, ул. Полбина, д. 21	Россия, Ульяновская область, Ульяновск, улица Полбина, 21	0101000020E610000070D1C952EB2948408AE942ACFE264B40
7836	7	74	\N	72	7431	\N	54.305083000000003	Ульяновская область, город Ульяновск, Засвияжский район, ул. Полбина, д. 57 А	Россия, Ульяновская область, Ульяновск, улица Полбина, 57а	0101000020E6100000861DC6A4BF2B484065C8B1F50C274B40
7865	7	74	\N	72	7630	\N	54.269770000000001	Ульяновская область, город Ульяновск, Засвияжский район, ул. Ефремова, д. 145 А	Россия, Ульяновская область, Ульяновск, улица Ефремова, 145а	0101000020E610000048A819524523484091B8C7D287224B40
7853	7	74	\N	72	7630	\N	54.286098000000003	Ульяновская область, город Ульяновск, Засвияжский район, ул. Ефремова, д. 55	Россия, Ульяновская область, Ульяновск, улица Ефремова, 55	0101000020E610000089EE59D768254840BBB9F8DB9E244B40
7778	7	74	\N	72	6854	\N	54.256529	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Варейкиса, д. 17	Россия, Ульяновская область, Ульяновск, улица Варейкиса, 17	0101000020E61000006118B0E42A2A4840E0BC38F1D5204B40
7831	7	74	\N	72	7364	\N	54.318215000000002	Ульяновская область, город Ульяновск, Засвияжский район, ул. Артема, д. 21	Россия, Ульяновская область, Ульяновск, улица Артема, 21	0101000020E6100000FB912232AC2E48405F0CE544BB284B40
7798	7	74	\N	72	7032	\N	54.334271000000001	Ульяновская область, город Ульяновск, Заволжский район, ул. Академика Сахарова, д. 11	Россия, Ульяновская область, Ульяновск, улица Академика Сахарова, 11	0101000020E61000004FCDE506433D484028806264C92A4B40
7863	7	74	\N	72	7743	\N	54.269418000000002	Ульяновская область, город Ульяновск, Засвияжский район, просп. Хо Ши Мина, д. 30	Россия, Ульяновская область, Ульяновск, проспект Хо Ши Мина, 30	0101000020E61000009E44847F11264840147AFD497C224B40
7813	7	74	\N	72	7192	\N	54.364724000000002	Ульяновская область, город Ульяновск, Заволжский район, просп. Туполева, д. 1	Россия, Ульяновская область, Ульяновск, проспект Туполева, 1	0101000020E61000002BA391CF2B4A48407D08AA46AF2E4B40
7817	7	74	\N	72	7233	\N	54.370184000000002	Ульяновская область, город Ульяновск, Заволжский район, просп. Созидателей, д. 62	Россия, Ульяновская область, Ульяновск, проспект Созидателей, 62	0101000020E61000007825C9737D4B484051C07630622F4B40
7888	7	74	\N	72	7927	\N	54.338144999999997	Ульяновская область,  город Ульяновск, Ленинский район, просп. Нариманова, д. 13	Россия, Ульяновская область, Ульяновск, проспект Нариманова, 13	0101000020E61000001405FA449E3048402827DA55482B4B40
7883	7	74	\N	72	7927	\N	54.350504999999998	Ульяновская область,  город Ульяновск, Ленинский район, просп. Нариманова, д. 106	Россия, Ульяновская область, Ульяновск, проспект Нариманова, 106	0101000020E61000008D96033DD42E4840D00A0C59DD2C4B40
7882	7	74	\N	72	7927	\N	54.356969999999997	Ульяновская область,  город Ульяновск, Ленинский район, пр-т Нариманова, 83/1	Россия, Ульяновская область, Ульяновск, проспект Нариманова, 83	0101000020E61000002600FF942A2D484099D36531B12D4B40
7774	7	74	\N	72	6799	\N	54.265790000000003	Ульяновская область, город Ульяновск, Железнодорожный район, просп. Гая, д. 21	Россия, Ульяновская область, Ульяновск, проспект Гая, 21	0101000020E6100000551344DD072A48404BCD1E6805224B40
7773	7	74	\N	72	6799	\N	54.268219000000002	Ульяновская область, город Ульяновск, Железнодорожный район, просп.  Гая, д. 15	Россия, Ульяновская область, Ульяновск, проспект Гая, 15	0101000020E610000020B41EBE4C2A48403A950C0055224B40
7772	7	74	\N	72	6799	\N	54.268219000000002	Ульяновская область, город Ульяновск, Железнодорожный район, просп. Гая, д. 15	Россия, Ульяновская область, Ульяновск, проспект Гая, 15	0101000020E610000020B41EBE4C2A48403A950C0055224B40
7825	7	74	\N	72	7304	\N	54.384506000000002	Ульяновская область, город Ульяновск, Заволжский район, просп. Врача Сурова, д. 11	Россия, Ульяновская область, Ульяновск, проспект Врача Сурова, 11	0101000020E6100000A01B9AB2D34B4840D28E1B7E37314B40
7844	7	74	\N	72	7517	\N	54.299030999999999	Ульяновская область, город Ульяновск, Засвияжский район, просп. 50-летия ВЛКСМ, д. 25	Россия, Ульяновская область, Ульяновск, проспект 50-летия ВЛКСМ, 25	0101000020E6100000D80E46EC132A4840BEBED6A546264B40
7769	7	74	\N	72	16287	\N	54.290433999999998	Ульяновская область,  город Ульяновск, Железнодорожный район, ул. Южная, д. 134	Россия, Ульяновская область, Ульяновск, Железнодорожный район, микрорайон Туть, Южная улица, 132	0101000020E6100000C32CB4739A2D4840BFD2F9F02C254B40
7799	7	74	\N	72	47235	\N	54.331001000000001	Ульяновская область, город Ульяновск, Заволжский район, ул. Шоферов, д. 16		0101000020E610000056D7A19A923E4840BEF8A23D5E2A4B40
7909	7	74	\N	72	47130	\N	54.379244614554104	Ульяновская область,  город Ульяновск, Ленинский район, с. Лаишевка, ул. Школьная, д. 1	Россия, Ульяновская область, Ульяновск, Ленинский район, село Лаишевка, Школьная улица	0101000020E6100000105CE50984234840F415A4198B304B40
7788	7	74	\N	72	47448	\N	54.217804732727302	Ульяновская область, город Ульяновск, Железнодорожный район, с. Луговое, ул. Школьная, д. 27	Россия, Ульяновская область, Ульяновск, Железнодорожный район, село Луговое	0101000020E610000025CB49287D1F4840E0F3C308E11B4B40
7790	7	74	\N	72	47631	\N	54.225291971744802	Ульяновская область, город Ульяновск, Железнодорожный район, с. Анненково, ул. Школьная, д. 3	Россия, Ульяновская область, Ульяновск, Железнодорожный район, село Анненково	0101000020E61000009B8E006E161948407506465ED61C4B40
7791	7	74	\N	72	47248	\N	54.243124430434499	Ульяновская область, город Ульяновск,  Железнодорожный район, пос. Пригородный, ул. Школьная, д. 8	Россия, Ульяновская область, Ульяновск, Железнодорожный район, поселок Пригородный, Школьная улица, 8	0101000020E6100000FA0B3D62F4204840B56FEEAF1E1F4B40
7787	7	74	\N	72	47383	\N	54.202070999999997	Ульяновская область, город Ульяновск, Железнодорожный район, пос. Плодовый, ул. Центральная, д. 5		0101000020E6100000F3CAF5B699224840293C6876DD194B40
7779	7	74	\N	72	47145	\N	54.255277	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Хрустальная, д. 56		0101000020E6100000FB40F2CEA12A4840E335AFEAAC204B40
7866	7	74	\N	72	47207	\N	54.263739000000001	Ульяновская область, город Ульяновск, Засвияжский район, ул. Хваткова, д. 2 А		0101000020E6100000C0CB0C1B6523484002D71533C2214B40
7856	7	74	\N	72	47230	\N	54.278565999999998	Ульяновская область, город Ульяновск, Засвияжский район, ул. Фруктовая, д. 3		0101000020E610000029779FE3A327484086E3F90CA8234B40
7816	7	74	\N	72	7210	\N	54.377620999999998	Ульяновская область, город Ульяновск, Заволжский район, бульв. Фестивальный, д. 24	Россия, Ульяновская область, Ульяновск, Фестивальный бульвар, 24	0101000020E6100000884CF9105449484033A48AE255304B40
7815	7	74	\N	72	7210	\N	54.375492000000001	Ульяновская область, город Ульяновск, Заволжский район, бульв. Фестивальный, д. 18	Россия, Ульяновская область, Ульяновск, Фестивальный бульвар, 18	0101000020E61000000B7BDAE1AF4948406FF4311F10304B40
7814	7	74	\N	72	7210	\N	54.370997000000003	Ульяновская область, город Ульяновск, Заволжский район, бульв. Фестивальный, д. 4	Россия, Ульяновская область, Ульяновск, Фестивальный бульвар, 4	0101000020E61000008925E5EE734A484002F566D47C2F4B40
7875	7	74	\N	72	47161	\N	54.356209	Ульяновская область,  город Ульяновск, Ленинский район, ул. Ульяны Громовой, д. 5/58		0101000020E61000009833DB15FA3048403BC5AA41982D4B40
7770	7	74	\N	72	6780	\N	54.286661000000002	Ульяновская область,  город Ульяновск, Железнодорожный район, ул. Трудовая, д.3	Россия, Ульяновская область, Ульяновск, Трудовая улица, 5	0101000020E6100000DFC325C79D2E4840F304C24EB1244B40
7887	7	74	\N	72	47194	\N	54.337578999999998	Ульяновская область,  город Ульяновск, Ленинский район, ул. Толбухина, д. 21		0101000020E61000005473B9C1502F48407F68E6C9352B4B40
7885	7	74	\N	72	47194	\N	54.343153000000001	Ульяновская область,  город Ульяновск, Ленинский район, ул. Толбухина, д. 57		0101000020E6100000AAF1D24D622E48401C430070EC2B4B40
7890	7	74	\N	72	47201	\N	54.345771999999997	Ульяновская область,  город Ульяновск, Ленинский район, ул. Тимирязева, д. 51		0101000020E61000006C425A63D0314840AEEFC341422C4B40
7806	7	74	\N	72	47228	\N	54.348605999999997	Ульяновская область, город Ульяновск, Заволжский район, ул. Тельмана, д. 9		0101000020E610000075E8F4BC1B4548403D98141F9F2C4B40
7906	7	74	\N	72	47252	\N	54.337567999999997	Ульяновская область,  город Ульяновск, Ленинский район, ул. Старосельдинская, д. 62		0101000020E6100000B153AC1A842748408B16A06D352B4B40
7852	7	74	\N	72	47237	\N	54.289335999999999	Ульяновская область, город Ульяновск, Засвияжский район, ул. Станкостроителей, д. 15		0101000020E6100000355D4F745D26484019C748F608254B40
7895	7	74	\N	72	47046	\N	54.363039999999998	Ульяновская область,  город Ульяновск, Ленинский район, ул. Спасская, д. 15		0101000020E6100000B2D5E59480244840E6913F18782E4B40
7812	7	74	\N	72	47218	\N	54.3598890928305	Ульяновская область, город Ульяновск, Заволжский район, ул. Солнечная, д. 8	Россия, Ульяновская область, Ульяновск, Солнечная улица, 8	0101000020E6100000D8497D59DA4548405798BED7102E4B40
7485	7	74	\N	72	28898	\N	54.266826000000002	Ульяновская область, Сенгилеевский район, с. Новая Слобода, адрес помещения для голосования: пер. Совхозный, д. 13, адрес УИК: ул. Первомайская, д. 71	Россия, Ульяновская область, Ульяновск, Совхозный переулок, 13	0101000020E6100000204432E4D82448407BDCB75A27224B40
7868	7	74	\N	72	47233	\N	54.314033999999999	Ульяновская область, город Ульяновск, Засвияжский район, ул. Сельдинская, д. 49		0101000020E61000008257CB9D9924484081EA1F4432284B40
7847	7	74	\N	72	47119	\N	54.287807312104903	Ульяновская область, город Ульяновск, Засвияжский район, ул. Севастпольская, д. 14	Россия, Ульяновская область, Ульяновск, Севастопольская улица, 14	0101000020E61000007993DFA293274840AA471ADCD6244B40
7848	7	74	\N	72	47243	\N	54.287801000000002	Ульяновская область, город Ульяновск, Засвияжский район, ул. Севастопольская, д. 14		0101000020E61000006DE525FF93274840C860C5A9D6244B40
7859	7	74	\N	72	47191	\N	54.275244000000001	Ульяновская область, город Ульяновск, Засвияжский район, ул. Самарская, д. 11 А		0101000020E610000059F9653046264840CA3505323B234B40
7858	7	74	\N	72	47191	\N	54.275244000000001	Ульяновская область,  город Ульяновск, Засвияжский район, ул. Самарская, д. 11 А		0101000020E610000059F9653046264840CA3505323B234B40
7905	7	74	\N	72	47251	\N	54.337127000000002	Ульяновская область,  город Ульяновск, Ленинский район, ул. Российская, д. 138а		0101000020E61000006BB933130C2B48409FCC3FFA262B4B40
7893	7	74	\N	72	47236	\N	54.332061000000003	Ульяновская область,  город Ульяновск, Ленинский район, ул. Радищева, д. 102		0101000020E6100000747973B85633484077A38FF9802A4B40
7892	7	74	\N	72	47236	\N	54.340716999999998	Ульяновская область,  город Ульяновск, Ленинский район, ул. Радищева, д. 159		0101000020E6100000D61F6118B03248407A185A9D9C2B4B40
7767	7	74	\N	72	47210	\N	54.299120000000002	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Пушкинская, д. 2		0101000020E6100000838769DFDC2F48402ECA6C9049264B40
7833	7	74	\N	72	47278	\N	54.316901999999999	Ульяновская область, город Ульяновск, Засвияжский район, ул. Пушкарева, д. 60 А	Россия, Ульяновская область, Ульяновск, улица Пушкарева, 60а	0101000020E61000001AC40776FC2D4840BC04A73E90284B40
94443	7	74	\N	72	9250	\N	54.371096785152297	Ульяновская область,  город Ульяновск, Ленинский район, Поливенское шоссе, 5	Россия, Ульяновская область, Ульяновск, Поливенское шоссе	0101000020E6100000D099B4A9BA2F48406552431B802F4B40
7874	7	74	\N	72	47371	\N	54.395184999999998	Ульяновская область,  город Ульяновск, Ленинский район, ул. Поливенская, д. 19		0101000020E6100000876EF607CA2F4840546F0D6C95324B40
7829	7	74	\N	72	7344	\N	54.384422000000001	Ульяновская область, город Ульяновск, Заволжский район, бульв. Пензенский, д. 10	Россия, Ульяновская область, Ульяновск, Пензенский бульвар, 10	0101000020E6100000EDBC8DCD8E4E484074EE76BD34314B40
7884	7	74	\N	72	47158	\N	54.349629	Ульяновская область,  город Ульяновск, Ленинский район, ул. Пархоменко, д. 98		0101000020E6100000B5C35F93352E4840D95DA0A4C02C4B40
7864	7	74	\N	72	47231	\N	54.267955999999998	Ульяновская область, город Ульяновск, Засвияжский район, ул. Отрадная, д. 14		0101000020E6100000723447567E2548402C62D8614C224B40
7902	7	74	\N	72	47202	\N	54.325088999999998	Ульяновская область,  город Ульяновск, Ленинский район, ул. Островского, д. 6		0101000020E6100000D40FEA228532484009A52F849C294B40
7809	7	74	\N	72	7136	\N	54.355910000000002	Ульяновская область, город Ульяновск, Заволжский район, ул. Оренбургская, д. 38	Россия, Ульяновская область, Ульяновск, Оренбургская улица, 38	0101000020E610000085285FD042444840E12879758E2D4B40
7808	7	74	\N	72	47240	\N	54.355559	Ульяновская область, город Ульяновск, Заволжский район, ул. Оренбургская, д. 34А		0101000020E61000002C2D23F59E444840346612F5822D4B40
7838	7	74	\N	72	7447	\N	54.297071000000003	Ульяновская область, город Ульяновск, Засвияжский район, ул. Октябрьская, д. 26	Россия, Ульяновская область, Ульяновск, Октябрьская улица, 26	0101000020E610000060048D99442B484086CB2A6C06264B40
95174	7	74	\N	72	6823	\N	54.2680791076207	Ульяновская область, город Ульяновск, Железнодорожный район, пер. Озерный, д. 9	Россия, Ульяновская область, Ульяновск, Озерный переулок	0101000020E610000015747B49632C484048DFA46950224B40
7823	7	74	\N	72	7252	\N	54.375880000000002	Ульяновская область, город Ульяновск, Заволжский район, бульв. Новосондецкий, д. 4	Россия, Ульяновская область, Ульяновск, Новосондецкий бульвар, 4	0101000020E61000005776C1E09A4B4840399CF9D51C304B40
7821	7	74	\N	72	7252	\N	54.380085999999999	Ульяновская область, город Ульяновск, Заволжский район, бульв. Новосондецкий, д. 14	Россия, Ульяновская область, Ульяновск, Новосондецкий бульвар, 14	0101000020E6100000BC202235ED4A48406FD575A8A6304B40
7820	7	74	\N	72	7252	\N	54.382418999999999	Ульяновская область, город Ульяновск, Заволжский район, бульв. Новосондецкий, д. 20	Россия, Ульяновская область, Ульяновск, Новосондецкий бульвар, 20	0101000020E6100000B2F2CB608C4A48403C2F151BF3304B40
7819	7	74	\N	72	7252	\N	54.378602000000001	Ульяновская область, город Ульяновск, Заволжский район, бульв. Новосондецкий, д. 13	Россия, Ульяновская область, Ульяновск, Новосондецкий бульвар, 13	0101000020E61000009624CFF57D4A4840A019C40776304B40
7818	7	74	\N	72	7252	\N	54.374737000000003	Ульяновская область, город Ульяновск, Заволжский район, бульв. Новосондецкий, д. 3	Россия, Ульяновская область, Ульяновск, Новосондецкий бульвар, 3	0101000020E6100000AD84EE92384B4840F3CCCB61F72F4B40
7768	7	74	\N	72	47148	\N	54.318201598262903	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Набережная реки Свияги, д. 106	Россия, Ульяновская область, Ульяновск, улица Набережная реки Свияги	0101000020E6100000BC581822A72F4840CAC2D7D7BA284B40
7867	7	74	\N	72	7787	\N	54.290424000000002	Ульяновская область, город Ульяновск, Засвияжский район, пос. Аэропорт, ш. Московское, адм. здание ОАО ДЭП-148		0101000020E610000007B29E5A7D2148409CFC169D2C254B40
7807	7	74	\N	72	47217	\N	54.351202999999998	Ульяновская область, город Ульяновск, Заволжский район, ул. Московская, д. 5А		0101000020E61000009E7E501729464840E8A04B38F42C4B40
7897	7	74	\N	72	47222	\N	54.307290000000002	Ульяновская область,  город Ульяновск, Ленинский район, ул. Минаева, д. 50		0101000020E6100000117008556A324840A5315A4755274B40
7804	7	74	\N	72	7094	\N	54.340077000000001	Ульяновская область, город Ульяновск, Заволжский район, ул. Мелекесская, д. 4	Россия, Ульяновская область, Ульяновск, Мелекесская улица, 4	0101000020E61000000E164ED2FC474840978FA4A4872B4B40
7879	7	74	\N	72	47245	\N	54.354562000000001	Ульяновская область,  город Ульяновск, Ленинский район, ул. Любови Шевцовой, д. 55		0101000020E61000007C65DEAAEB304840C233A149622D4B40
7878	7	74	\N	72	47245	\N	54.355148999999997	Ульяновская область,  город Ульяновск, Ленинский район, ул. Любови Шевцовой, д. 57		0101000020E610000067B5C01E13314840821ABE85752D4B40
7830	7	74	\N	72	7317	\N	54.382219999999997	Ульяновская область, город Ульяновск, Заволжский район, бульв. Львовский, д. 10	Россия, Ульяновская область, Ульяновск, Львовский бульвар, 10	0101000020E6100000E57B4622344E484045F0BF95EC304B40
7826	7	74	\N	72	7317	\N	54.383290000000002	Ульяновская область, город Ульяновск, Заволжский район, бульв. Львовский, д. 10а	Россия, Ульяновская область, Ульяновск, Львовский бульвар, 10а	0101000020E6100000F04DD367074E484022718FA50F314B40
7900	7	74	\N	72	47204	\N	54.309932000000003	Ульяновская область,  город Ульяновск, Ленинский район, ул. Льва Толстого, д. 10		0101000020E61000009D9B36E334304840F0FD0DDAAB274B40
7899	7	74	\N	72	47204	\N	54.310783000000001	Ульяновская область,  город Ульяновск, Ленинский район, ул. Льва Толстого, д. 37/110		0101000020E6100000780B24287E3048408E93C2BCC7274B40
7896	7	74	\N	72	47204	\N	54.312584000000001	Ульяновская область,  город Ульяновск, Ленинский район, ул. Льва Толстого, д. 97		0101000020E6100000EDD3F198813248405EA0A4C002284B40
7771	7	74	\N	72	6786	\N	54.271821000000003	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Локомотивная, д. 87	Россия, Ульяновская область, Ульяновск, Локомотивная улица, 87	0101000020E610000091D61874422A4840DAAED007CB224B40
7904	7	74	\N	72	47250	\N	54.330680000000001	Ульяновская область,  город Ульяновск, Ленинский район, ул. Лесная, д. 12		0101000020E6100000E388B5F8143248407CB8E4B8532A4B40
7765	7	74	\N	72	47166	\N	54.303927999999999	Ульяновская область,  город Ульяновск, Железнодорожный район, ул. Куйбышева, д. 3		0101000020E610000080D3BB783F3048405A2BDA1CE7264B40
7764	7	74	\N	72	47166	\N	54.304601193082398	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Куйбышева, д. 4	Россия, Ульяновская область, Ульяновск, улица Куйбышева, 4	0101000020E6100000D367075C5730484019AA622AFD264B40
7901	7	74	\N	72	47249	\N	54.320993000000001	Ульяновская область,  город Ульяновск, Ленинский район, ул. Крымова, д. 69		0101000020E61000001B9C887E6D3148405A9F724C16294B40
7626	7	74	\N	72	5228	\N	54.332774999999998	Ульяновская область, Ульяновский район, п. Красноармейский, ул. Центральная, д. 1	Россия, Ульяновская область, Ульяновск, Красноармейский переулок, 1	0101000020E610000083BF5FCC9632484094F6065F982A4B40
7857	7	74	\N	72	47206	\N	54.273618999999997	Ульяновская область, город Ульяновск, Засвияжский район, ул. Корунковой, д. 6		0101000020E6100000DCB75A272E274840384888F205234B40
7783	7	74	\N	72	6881	\N	54.259905000000003	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Кольцевая, д. 12	Россия, Ульяновская область, Ульяновск, Кольцевая улица, 12	0101000020E61000005F27F565692B48409088299144214B40
7782	7	74	\N	72	6881	\N	54.258195999999998	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Кольцевая, д. 32	Россия, Ульяновская область, Ульяновск, Кольцевая улица, 32	0101000020E6100000B972F6CE682B4840A0FA07910C214B40
7828	7	74	\N	72	47147	\N	54.390377999999998	Ульяновская область, город Ульяновск, Заволжский район, ул. Карбышева, д. 38		0101000020E610000049BBD1C77C4A4840F88903E8F7314B40
7827	7	74	\N	72	47147	\N	54.386037000000002	Ульяновская область, город Ульяновск, Заволжский район, ул. Карбышева, д. 26		0101000020E61000001502B9C4914B4840E20511A969314B40
7824	7	74	\N	72	47147	\N	54.378528000000003	Ульяновская область, город Ульяновск, Заволжский район, ул. Карбышева, д. 2		0101000020E610000033A31F0DA74C4840664F029B73304B40
7860	7	74	\N	72	7710	\N	54.27957	Ульяновская область, город Ульяновск, Засвияжский район, ул. Камышинская, д. 51	Россия, Ульяновская область, Ульяновск, Камышинская улица, 51	0101000020E610000027C286A757244840AB7823F3C8234B40
7862	7	74	\N	72	47220	\N	54.274965000000002	Ульяновская область, город Ульяновск, Засвияжский район, ул. Камышинская, д. 28		0101000020E61000001AFD683865244840B745990D32234B40
7861	7	74	\N	72	47220	\N	54.275337999999998	Ульяновская область, город Ульяновск, Засвияжский район, ул. Камышинская, д. 32		0101000020E6100000A88AA9F4132448404BAC8C463E234B40
7797	7	74	\N	72	47213	\N	54.334339982421199	Ульяновская область, город Ульяновск, Заволжский район, ул. Калнина, д. 1	Россия, Ульяновская область, Ульяновск, улица Калнина, 1	0101000020E61000004F20EC14AB3C484050DF32A7CB2A4B40
7907	7	74	\N	72	47164	\N	54.364975999999999	Ульяновская область,  город Ульяновск, Ленинский район, ул. Ипподромная, д. 13а		0101000020E61000009031772D212D484096E99788B72E4B40
7793	7	74	\N	72	47212	\N	54.325299000000001	Ульяновская область, город Ульяновск, Заволжский район, ул. Заречная, д. 24		0101000020E6100000E8F9D346753C4840F435CB65A3294B40
7845	7	74	\N	72	7494	\N	54.299346	Ульяновская область, город Ульяновск, Засвияжский район, бульв. Западный, д. 20 А	Россия, Ульяновская область, Ульяновск, Западный бульвар, 20а	0101000020E6100000465ED6C4022948401E1840F850264B40
7842	7	74	\N	72	7494	\N	54.303801	Ульяновская область, город Ульяновск, Засвияжский район, бульв. Западный, д. 12	Россия, Ульяновская область, Ульяновск, Западный бульвар, 12	0101000020E6100000B8AD2D3C2F294840FDBE7FF3E2264B40
7794	7	74	\N	72	6987	\N	54.325229999999998	Ульяновская область, город Ульяновск, Заволжский район, пр-д Заводской, д. 27А	Россия, Ульяновская область, Ульяновск, Заводской проезд, 27а	0101000020E6100000A9DBD9571E3E4840CBD6FA22A1294B40
7908	7	74	\N	72	47065	\N	54.341641000000003	Ульяновская область,  город Ульяновск, Ленинский район, с. Карлинское, адрес помещения для голосования: ул. Дорожная, д. 4, Адрес УИК: ул. Дорожная, д. 10		0101000020E61000003BC5AA41981F484083FC6CE4BA2B4B40
7846	7	74	\N	72	47244	\N	54.290911999999999	Ульяновская область, город Ульяновск, Засвияжский район, ул. Доватора, д. 15		0101000020E61000008445459C4E284840C901BB9A3C254B40
7802	7	74	\N	72	47215	\N	54.339998000000001	Ульяновская область, город Ульяновск, Заволжский район, ул. Димитрова, д. 7		0101000020E6100000EB7420EBA94548404B5AF10D852B4B40
7801	7	74	\N	72	47176	\N	54.339551999999998	Ульяновская область, город Ульяновск, Заволжский район, ул. Гоголя, д. 40		0101000020E61000005F28603B184548404CA59F70762B4B40
7777	7	74	\N	72	47211	\N	54.260899000000002	Ульяновская область, город Ульяновск,  Железнодорожный район, ул. Героев Свири, д. 12		0101000020E61000002F6D382C0D2A48409147702365214B40
7776	7	74	\N	72	47211	\N	54.260899000000002	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Героев Свири, д. 12		0101000020E61000002F6D382C0D2A48409147702365214B40
7869	7	74	\N	72	47128	\N	54.292084000000003	Ульяновская область, город Ульяновск, Засвияжский район, с. Баратаевка, ул. Герасимова, д. 6 А		0101000020E6100000ECDD1FEF551B4840AAD72D0263254B40
7792	7	74	\N	72	47238	\N	54.252200000000002	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Вольная, д. 6		0101000020E6100000E86C01A1F52648408E06F01648204B40
7903	7	74	\N	72	47234	\N	54.326155	Ульяновская область,  город Ульяновск, Ленинский район, ул. Верхнеполевая, д. 3		0101000020E61000000BD3F71A82314840A4367172BF294B40
7886	7	74	\N	72	47645	\N	54.347225999999999	Ульяновская область,  город Ульяновск, Ленинский район, ул. Архитектора Шодэ, д.6		0101000020E6100000F5BEF1B5672C48401329CDE6712C4B40
7832	7	74	\N	72	47172	\N	54.316502999999997	Ульяновская область, город Ульяновск, Засвияжский район, ул. Артема, д. 8		0101000020E610000064963D096C2E4840FE0A992B83284B40
7784	7	74	\N	72	47167	\N	54.26193	Ульяновская область, город Ульяновск, Железнодорожный район, ул. Амурская, д. 10		0101000020E6100000A794D74AE8284840AFEB17EC86214B40
7849	7	74	\N	72	47227	\N	54.284080000000003	Ульяновская область, город Ульяновск, Засвияжский район, ул. Александра Невского, д. 2 А		0101000020E6100000A4C16D6DE12748404EB9C2BB5C244B40
7898	7	74	\N	72	47208	\N	54.311171999999999	Ульяновская область,  город Ульяновск, Ленинский район, ул. Александра Матросова, д. 11		0101000020E61000005FB69DB64632484028B7ED7BD4274B40
7800	7	74	\N	72	47241	\N	54.333199999999998	Ульяновская область, город Ульяновск, Заволжский район, ул. Академика Павлова, д. 20		0101000020E6100000C0CE4D9B714448407B832F4CA62A4B40
7835	7	74	\N	72	47183	\N	54.308875999999998	Ульяновская область, город Ульяновск, Засвияжский район, ул. Аблукова, д. 23		0101000020E610000069C4CC3E8F2D48407842AF3F89274B40
7834	7	74	\N	72	47183	\N	54.310572999999998	Ульяновская область, город Ульяновск, Засвияжский район, ул. Аблукова, д. 31		0101000020E6100000F3C7B4368D2D4840A30227DBC0274B40
7766	7	74	\N	72	47209	\N	54.300781000000001	Ульяновская область, город Ульяновск, Железнодорожный район, ул. 12 Сентября, д. 81		0101000020E610000059501894693048400C21E7FD7F264B40
7796	7	74	\N	72	7012	\N	54.327781999999999	Ульяновская область, город Ульяновск, Заволжский район, ул. 1 Линия, д. 5	Россия, Ульяновская область, Ульяновск, 1-я Линия, 5	0101000020E61000004930D5CC5A3C4840D61BB5C2F4294B40
7840	7	74	\N	72	47189	\N	54.3000466214108	Ульяновская область, город Ульяновск, Засвияжский район, ул. Терешковой, д. 22	Россия, Ульяновская область, Ульяновск, улица Терешковой, 22	0101000020E6100000240D6E6B0B2B4840A721AAF067264B40
7851	7	74	\N	72	47186	\N	54.291995	Ульяновская область, город Ульяновск, Засвияжский район, ул. Стасова, д. 16		0101000020E61000000D535BEA202748403ACC971760254B40
7822	7	74	\N	72	47181	\N	54.374091743860298	Ульяновская область, город Ульяновск, Заволжский район, ул. 40-летия Победы, д. 3	Россия, Ульяновская область, Ульяновск, улица 40-летия Победы, 3	0101000020E61000001EA4A7C8214C4840FDD8243FE22F4B40
7632	7	74	\N	55840	47643	\N	54.4066122532669	Ульяновская область, Ульяновский район, п. Станция Лаишевка, ул. Центральная, д. 12	Россия, Ульяновская область, поселок Лаишевка	0101000020E61000000DA5F622DA1A4840A114ADDC0B344B40
7697	7	74	\N	22727	46905	\N	54.321203763215799	Ульяновская область, Чердаклинский район, пос. Колхозный, адрес помещения для голосования: ул. Центральная, д. 5, адрес УИК: ул. Центральная, д. 7	Россия, Ульяновская область, поселок Колхозный, Центральная улица	0101000020E6100000ACE3F8A1D248484015AC71361D294B40
7615	7	74	\N	55765	47043	\N	54.424746282081898	Ульяновская область, Ульяновский район, р.п. Ишеевка, адрес помещения для голосования: ул Ленина, д. 35, адрес УИК: ул. Ленина, д. 32	Россия, Ульяновская область, рабочий поселок Ишеевка, улица Ленина	0101000020E61000003604C765DC204840AC8DB1135E364B40
7744	7	74	\N	12983	\N	\N	54.217657000000003	Ульяновская область, город Димитровград, д. Рабочая, д. 2	Россия, Ульяновская область, Димитровград	0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7681	7	74	\N	12983	\N	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Славского, д. 11	Россия, Ульяновская область, Димитровград	0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7714	7	74	\N	12983	47108	\N	54.217657000000003	Ульяновская область, город Димитровград, пр. Ленина, д. 17		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7712	7	74	\N	12983	9849	\N	54.214239275717503	Ульяновская область, город Димитровград, пр. Димитрова, д. 4	Россия, Ульяновская область, Димитровград	0101000020E61000000264E8D841CD48408D43FD2E6C1B4B40
7718	7	74	\N	12983	46903	\N	54.217657000000003	Ульяновская область, город Димитровград, пр. Димитрова, д. 14		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7717	7	74	\N	12983	47109	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Терешковой, д. 2		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7724	7	74	\N	12983	47113	\N	54.217657000000003	Ульяновская область, город Димитровград, ул .Строителей, д. 15		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7745	7	74	\N	12983	46996	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Рабочая, д.2		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7742	7	74	\N	12983	46982	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Победы, д. 18а		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7736	7	74	\N	12983	46990	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Московская, д. 73		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7732	7	74	\N	12983	46929	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Мелекесская, д. 37а		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7604	7	74	\N	12983	46964	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. М.Тореза, д. 4а		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7501	7	74	\N	12983	46964	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. М.Тореза, д. 4		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7728	7	74	\N	12983	46925	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Луговая, д. 40		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7738	7	74	\N	12983	47365	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Ленинградская, д. 54а		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7719	7	74	\N	12983	47112	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Ленина, д. 45		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7715	7	74	\N	12983	46985	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Курчатова, д. 8		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
95171	7	74	\N	12983	46906	\N	54.217657000000003	"Ульяновская область, город Димитровград, МБУК «Центр искусств» Кабинет I этаж ул.Куйбышева, 241 "		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7746	7	74	\N	12983	46906	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Куйбышева, д. 144		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7729	7	74	\N	12983	46906	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Куйбышева, д. 294		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7726	7	74	\N	12983	46906	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Куйбышева, д. 258		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7737	7	74	\N	12983	46991	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Крымская, д. 96		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7716	7	74	\N	12983	46901	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Королева, д. 1		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7741	7	74	\N	12983	46978	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Западная, д. 9		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7713	7	74	\N	12983	47106	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Гончарова, д. 8		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7725	7	74	\N	12983	46902	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Гвардейская, д. 15		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7723	7	74	\N	12983	46902	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Гвардейская, д. 43		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7721	7	74	\N	12983	46902	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Гвардейская, д. 47		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7720	7	74	\N	12983	46902	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Гвардейская, д. 30		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7749	7	74	\N	12983	46999	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Гагарина, д. 19		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7750	7	74	\N	12983	46911	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Восточная, д. 32		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
95170	7	74	\N	12983	47044	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Вокзальная, д. 28		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7722	7	74	\N	12983	46987	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Братская, д. 50		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
95173	7	74	\N	12983	9744	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Баданова, д. 77		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7743	7	74	\N	12983	46910	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Автостроителей, д. 22		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7740	7	74	\N	12983	46910	\N	54.217657000000003	Ульяновская область, город Димитровград, пр. Автостроителей, д. 47		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7739	7	74	\N	12983	46910	\N	54.217657000000003	Ульяновская область, город Димитровград, пр. Автостроителей, д. 32		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7735	7	74	\N	12983	46910	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Автостроителей, д. 65		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
95172	7	74	\N	12983	47005	\N	54.217657000000003	"Ульяновская область, город Димитровград, МУК «Димитровградский драматический театр им.А.Н.Островского Фойе, I этаж, ул.III Интернационала, 74 "		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7733	7	74	\N	12983	46907	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. 9-ая Линия, д. 15		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7730	7	74	\N	12983	46927	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. 3-го Интернационала, д. 146		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7711	7	74	\N	12983	46984	\N	54.217657000000003	Ульяновская область, город Димитровград, пр. Димитрова, д. 5		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7734	7	74	\N	12983	46909	\N	54.217657000000003	Ульяновская область, город Димитровград, ул. Октябрьская, д. 74		0101000020E61000003A05F9D9C8CD48406C5F402FDC1B4B40
7062	7	74	\N	23336	46932	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, пл. Фабричная, д. 14		0101000020E610000055A016838791474051137D3ECAD24A40
7057	7	74	\N	23336	46932	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Фабричная, д. 57		0101000020E610000055A016838791474051137D3ECAD24A40
7055	7	74	\N	23336	47343	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Строителей, д. 9А		0101000020E610000055A016838791474051137D3ECAD24A40
7060	7	74	\N	23336	47264	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Степана Разина, д. 25		0101000020E610000055A016838791474051137D3ECAD24A40
7059	7	74	\N	23336	47345	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Льва Толстого, д. 47	Россия, Ульяновская область, Барыш	0101000020E610000055A016838791474051137D3ECAD24A40
7063	7	74	\N	23336	46931	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Луначарского, д. 4		0101000020E610000055A016838791474051137D3ECAD24A40
7061	7	74	\N	23336	41952	\N	53.646337984694	Ульяновская область, Барышский район, г. Барыш, ул. Ленина, д. 70	Россия, Ульяновская область, Барыш	0101000020E6100000C974E8F4BC914740BE141E34BBD24A40
7053	7	74	\N	23336	46924	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Красноармейская, д. 45		0101000020E610000055A016838791474051137D3ECAD24A40
7052	7	74	\N	23336	46924	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Красноармейская, д. 34А		0101000020E610000055A016838791474051137D3ECAD24A40
7064	7	74	\N	23336	46853	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Калинина, д. 1А		0101000020E610000055A016838791474051137D3ECAD24A40
7058	7	74	\N	23336	47312	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, ул. Бебеля, д. 17		0101000020E610000055A016838791474051137D3ECAD24A40
7054	7	74	\N	23336	47070	\N	53.646796999999999	Ульяновская область, Барышский район, г. Барыш, адрес помешения для голосования: ул. 45 Стрелковой Дивизии, д. 26, адрес УИК: ул. Пушкина, д. 29		0101000020E610000055A016838791474051137D3ECAD24A40
7695	7	74	1666	22638	47254	\N	54.196762	Ульяновская область, Чердаклинский район, с. Чувашский Калмаюр, ул. Советская, д. 37А		0101000020E610000067B5C01E137D48403B8C497F2F194B40
7680	7	74	1666	21430	46894	\N	54.359361999999997	Ульяновская область, Чердаклинский район, р.п. Чердаклы, ул. Советская, д. 2		0101000020E6100000473D44A33B6C48406BB6F292FF2D4B40
7682	7	74	1666	21430	46896	\N	54.359361999999997	Ульяновская область, Чердаклинский район, р.п. Чердаклы, ул. Неверова, д. 1		0101000020E6100000473D44A33B6C48406BB6F292FF2D4B40
7669	7	74	1666	21430	47041	\N	54.359361999999997	Ульяновская область, Чердаклинский район, р.п. Чердаклы, ул. 50 лет ВЛКСМ, д. 12		0101000020E6100000473D44A33B6C48406BB6F292FF2D4B40
7696	7	74	1666	22682	47362	\N	54.150916000000002	Ульяновская область, Чердаклинский район, с. Уразгильдино, адрес помещения для голосования: ул. Школьная, д. 27, адрес УИК: ул. Новая, д. 17		0101000020E6100000F25CDF8783704840B9382A3751134B40
7685	7	74	1666	22185	47300	\N	54.025455999999998	Ульяновская область, Чердаклинский район, с. Суходол, адрес помещения для голосования: ул. Школьная, Здание Суходольской СОШ, адрес УИК: ул. Мира, д. 27		0101000020E610000031EE06D15A85484055BE672442034B40
7684	7	74	1666	22140	47333	\N	53.98077	Ульяновская область, Чердаклинский район, с. Старый Белый Яр, адрес помещения для голосования: ул. Школьная, д. 24, адрес УИК: ул. Набережная, д. 1		0101000020E6100000DBFD2AC077734840EF7211DF89FD4A40
7705	7	74	1666	47687	47617	\N	54.337646999999997	Ульяновская область, Чердаклинский район, с. Старый Уренбаш, ул. Центральная, д. 54		0101000020E6100000567DAEB6627B4840D74B5304382B4B40
7688	7	74	1666	22330	47616	\N	54.353822000000001	Ульяновская область, Чердаклинский район, с. Старое Матюшкино, ул. Центральная, д. 3		0101000020E610000042CD902A8A9148407B4D0F0A4A2D4B40
7692	7	74	1666	22497	47615	\N	54.317700000000002	Ульяновская область, Чердаклинский район, с. Старое Еремкино, ул. Центральная, д. 8А		0101000020E6100000CA181F662FA3484038F8C264AA284B40
7691	7	74	1666	22406	47545	\N	54.341598916592503	Ульяновская область, Чердаклинский район, с. Станция Бряндино, ул. Школьная, д. 37А	Россия, Ульяновская область, Чердаклинский район, село Станция Бряндино	0101000020E6100000B9A5D590B8AD484054AC1A84B92B4B40
7690	7	74	1666	22406	47545	\N	54.341037999999998	Ульяновская область, Чердаклинский район, с. Бряндино, адрес помещения для голосования: ул. Школьная, д. 20, адрес УИК: ул. Школьная, д. 6		0101000020E6100000761BD47E6BAD4840BC581822A72B4B40
7709	7	74	1666	23256	47256	\N	54.228937999999999	Ульяновская область, Чердаклинский район, пос. Пятисотенный, пер. Садовый, д. 9		0101000020E61000004CA60A4625694840E46723D74D1D4B40
7694	7	74	1666	22589	47303	\N	54.239457999999999	Ульяновская область, Чердаклинский район, с. Поповка, адрес помещения для голосования: ул. Центральная, д. 74, адрес УИК: ул. Колхозная, д. 38		0101000020E61000008FC2F5285C774840FE614B8FA61E4B40
7687	7	74	1666	22272	47382	\N	54.382666	Ульяновская область, Чердаклинский район, с. Петровское, адрес помещения для голосования: ул. Центральная, д. 72, адрес УИК: ул. Центральная, д. 40		0101000020E6100000D333BDC45882484044A51133FB304B40
7708	7	74	1666	23198	47253	\N	54.282528999999997	Ульяновская область, Чердаклинский район, пос. Первомайский, ул. Первомайская, д. 1		0101000020E61000001BD99596915C4840F69507E929244B40
7707	7	74	1666	23119	46921	\N	54.338371000000002	Ульяновская область, Чердаклинский район, пос. Октябрьский, ул. Студенческая, д. 3		0101000020E6100000BF28417FA15948401975ADBD4F2B4B40
7706	7	74	1666	23119	46919	\N	54.338371000000002	Ульяновская область, Чердаклинский район, пос. Октябрьский, ул. Ленина, д. 21		0101000020E6100000BF28417FA15948401975ADBD4F2B4B40
7703	7	74	1666	22971	47104	\N	54.285651999999999	Ульяновская область, Чердаклинский район, с. Озерки, адрес помещения для голосования: ул. Центральная, д. 3, адрес УИК: ул. Кооперативная, д. 16		0101000020E61000001D3BA8C4758A4840BC04A73E90244B40
7683	7	74	1666	22104	47329	\N	53.972208000000002	Ульяновская область, Чердаклинский район, с. Новый Белый Яр, адрес помещения для голосования: ул. Пролетарская, д. 26, адрес УИК: ул. Кооперативная, д. 15	Россия, Ульяновская область, Чердаклинский район, село Новый Белый Яр	0101000020E610000005508C2C997B48406D74CE4F71FC4A40
7701	7	74	1666	22883	46917	\N	54.365777999999999	Ульяновская область, Чердаклинский район, пос. Мирный, ул. Молодежная, д. 2А		0101000020E610000060200890A15D484053CC41D0D12E4B40
7702	7	74	1666	22924	47620	\N	54.321396999999997	Ульяновская область, Чердаклинский район, с. Малаевка, ул. Центральная, д. 37		0101000020E610000028F224E99A8148402904728923294B40
79833	7	72	\N	55926	77221	\N	53.235083749862298	село Рождествено, Пацаева, 1	Россия	0101000020E6100000EE96E4805D0749400CE8853B179E4A40
7699	7	74	1666	22788	46918	\N	54.184871999999999	Ульяновская область, Чердаклинский район, с. Крестово-Городище, ул. Ленина, д. 56А		0101000020E6100000E99AC937DB5048401AF9BCE2A9174B40
7698	7	74	1666	22754	47305	\N	54.241945999999999	Ульяновская область, Чердаклинский район, с. Красный Яр, ул. Пионерская, д. 31		0101000020E6100000A0FB7266BB464840F2B22616F81E4B40
7678	7	74	1666	21842	47322	\N	54.426031999999999	Ульяновская область, Чердаклинский район, с. Енганаево, адрес помещения для голосования: ул. Первая, д. 2А, адрес УИК: ул. Первая, д. 2		0101000020E6100000417FA1478C7248405586713788364B40
7686	7	74	1666	22230	47449	\N	54.387720000000002	Ульяновская область, Чердаклинский район, с. Богдашкино, ул. Лидии Бернт, д. 5		0101000020E610000005A4FD0FB08A4840A80018CFA0314B40
7700	7	74	1666	22837	46897	\N	54.430017999999997	Ульяновская область, Чердаклинский район, с. Архангельское, адрес помещения для голосования: ул. 50 лет Победы, д. 36, адрес УИК: ул. Западная, д. 17		0101000020E6100000E4874A23665448407D586FD40A374B40
7693	7	74	1666	22539	47334	\N	54.147046000000003	Ульяновская область, Чердаклинский район, с. Андреевка, адрес помещения для голосования: ул. Дружбы, д. 47, адрес УИК: ул. Дружбы, д. 23		0101000020E6100000EC18575C1C6B4840FA804067D2124B40
7689	7	74	1666	55836	47638	\N	54.423895558878598	Ульяновская область, Чердаклинский район, с. Абдуллово, адрес помещения для голосования: ул. Школьная, д. 1, адрес УИК: ул. Новая, д. 3	Россия, Ульяновская область, Чердаклинский район, село Абдулово	0101000020E61000004224438EADBB4840DE73603942364B40
7674	7	74	1610	21660	47612	\N	54.487577999999999	Ульяновская область, Цильнинский район, с. Чириково, ул. Плетневская, д. 6		0101000020E610000064CDC82077DB4740E21FB6F4683E4B40
7644	7	74	1610	20019	47286	\N	54.592962	Ульяновская область, Цильнинский район, р.п. Цильна, ул. Станционная, д. 1		0101000020E61000006AC18BBE82124840A8E2C62DE64B4B40
7643	7	74	1610	20019	46970	\N	54.592962	Ульяновская область, Цильнинский район, р.п. Цильна, ул. О.Кошевого, д. 4		0101000020E61000006AC18BBE82124840A8E2C62DE64B4B40
7673	7	74	1610	21612	47446	\N	54.441706000000003	Ульяновская область, Цильнинский район, с. Устеренка, ул. Зеленая, д. 3		0101000020E6100000681F2BF86DE4474037397CD289384B40
7672	7	74	1610	21555	47619	\N	54.414690999999998	Ульяновская область, Цильнинский район, д. Тимофеевка, ул. Тимофеевская, д. 6 А		0101000020E6100000707D586FD4C8474007793D9814354B40
7642	7	74	1610	19949	47501	\N	54.595367000000003	Ульяновская область, Цильнинский район, с. Телешовка, пер. Школьный, д. 7		0101000020E6100000DA8CD310551848400F0F61FC344C4B40
7668	7	74	1610	21377	47500	\N	54.639100999999997	Ульяновская область, Цильнинский район, с. Сухая Бугурна, ул. Пролетарская, д. 16	Россия, Ульяновская область, Цильнинский район, село Сухая Бугурна	0101000020E6100000711E4E603A094840A2EBC20FCE514B40
7650	7	74	1610	20458	47332	\N	54.387652000000003	Ульяновская область, Цильнинский район, с. Степное Анненково, ул. Пионерская, д. 3		0101000020E61000008F53742497ED4740501DAB949E314B40
7648	7	74	1610	20353	46891	\N	54.661078000000003	Ульяновская область, Цильнинский район, с.Старые Алгаши, адрес помещения для голосования: ул. Советская, д. 7, адрес УИК: ул. Советская, д. 30		0101000020E610000060915F3FC4DE4740740D33349E544B40
7647	7	74	1610	55827	47621	\N	54.696933734742103	Ульяновская область, Цильнинский район, д. Средние Алгаши, ул. Школьная, д. 22	Россия, Ульяновская область, Цильнинский район, село Средний Алгаши	0101000020E6100000C9C6832D76E3474038BC202235594B40
7677	7	74	1610	21812	47301	\N	54.551119999999997	Ульяновская область, Цильнинский район, с. Средние Тимерсяны, адрес помещения для голосования: ул. Школьная, д. 1 А, адрес УИК: ул. Клубная, д. 1	Россия, Ульяновская область, Цильнинский район, село Средние Тимерсяны	0101000020E6100000A1BDFA78E8DB4740F415A4198B464B40
7660	7	74	1610	21006	\N	\N	54.448841999999999	Ульяновская область, Цильнинский район, пос.Солнце, начальная школа		0101000020E6100000B55208E412FF47401E8997A773394B40
7659	7	74	1610	55814	\N	\N	54.545065366238099	Ульяновская область, Цильнинский район, д. Садки, начальная школа	Россия, Ульяновская область, Цильнинский район, село Садки	0101000020E6100000E62494BE10FE4740DD989EB0C4454B40
7667	7	74	1610	21341	47445	\N	54.706026999999999	Ульяновская область, Цильнинский район, с. Русская Цильна, ул. Советская, д. 10		0101000020E6100000B742588D25FA4740E78BBD175F5A4B40
7666	7	74	1610	21285	47542	\N	54.593186000000003	Ульяновская область, Цильнинский район, с. Покровское, адрес помещения для голосования: ул. Советская, д. 14, адрес УИК: ул. Мира, д. 17		0101000020E61000004AD40B3ECD094840F838D384ED4B4B40
7649	7	74	1610	20384	47497	\N	54.440067999999997	Ульяновская область, Цильнинский район, с. Пилюгино, адрес помещения для голосования: ул. Красная горка, д. 22, адрес УИК: ул. Центральная, д. 8	Россия, Ульяновская область, Цильнинский район, село Пилюгино	0101000020E6100000BA4A77D7D9F247401002F22554384B40
7658	7	74	1610	20916	47541	\N	54.60951	Ульяновская область, Цильнинский район, пос. Орловка, ул. Молодёжная, д. 5		0101000020E6100000E1CFF0660DEA4740E04A766C044E4B40
7656	7	74	1610	20798	47287	\N	54.516416999999997	Ульяновская область, Цильнинский район, с. Норовка, ул. Молодёжная, д. 16 А		0101000020E6100000C0EC9E3C2CF64740990CC7F319424B40
7657	7	74	1610	20805	47499	\N	54.540795000000003	Ульяновская область, Цильнинский район, с. Новые Тимерсяны, ул. Кооперативная, д. 14		0101000020E61000008B53AD8559EC4740906B43C538454B40
7646	7	74	1610	20222	47285	\N	54.716304999999998	Ульяновская область, Цильнинский район, с. Новые Алгаши, адрес помещения для голосования: ул. Школьная, д. 42, адрес УИК: ул. Школьная, д. 46		0101000020E610000024B4E55C8ADF47400B7BDAE1AF5B4B40
80597	7	72	\N	55921	\N	\N	54.210591999999998	п.Привольный, Центральная, 1		0101000020E6100000B682A625564649404D66BCADF41A4B40
7671	7	74	1610	21513	47288	\N	54.441004999999997	Ульяновская область, Цильнинский район, с. Новое Никулино, адрес помещения для голосования: ул. Школьная, д. 5, адрес УИК: ул. Центральная, д. 2 А		0101000020E61000002385B2F0F5D74740AD2F12DA72384B40
7655	7	74	1610	20711	\N	\N	54.596947	Ульяновская область, Цильнинский район, пос. Новая Воля, начальная школа		0101000020E610000051A1BAB9F8F54740003961C2684C4B40
7676	7	74	1610	21757	47341	\N	54.549208999999998	Ульяновская область, Цильнинский район, с. Нижние Тимерсяны, адрес помещения для голосования: ул. Центральная, д. 12, адрес УИК: ул. Центральная, д. 38	Россия, Ульяновская область, Цильнинский район, село Нижние Тимерсяны	0101000020E6100000A2D3F36E2CE247409DD5027B4C464B40
7665	7	74	1610	21221	47401	\N	54.676558	Ульяновская область, Цильнинский район, с. Мокрая Бугурна, адрес помещения для голосования: ул. Суркова, д. 5, адрес УИК: ул. Суркова, д. 2		0101000020E610000034130CE71A06484070ECD97399564B40
7654	7	74	1610	20699	47444	\N	54.628742000000003	Ульяновская область, Цильнинский район, с.Малое Нагаткино, адрес помещения для голосования: ул. Ликино, д. 3, адрес УИК: ул. Ликино, д. 5		0101000020E61000004B051555BFF2474092CF2B9E7A504B40
7663	7	74	1610	55828	47628	\N	54.724926701018198	Ульяновская область, Цильнинский район, с. Кундюковка, ул. Школьная, д. 18		0101000020E61000001D007157AF104840637E6E68CA5C4B40
7653	7	74	1610	20601	47465	\N	54.508597999999999	Ульяновская область, Цильнинский район, с. Крестниково, ул. Церковная, д. 7	Россия, Ульяновская область, Цильнинский район, село Крестниково	0101000020E610000030A182C30B084840CF6740BD19414B40
7670	7	74	1610	21456	47611	\N	54.428547000000002	Ульяновская область, Цильнинский район, с. Карабаевка, адрес помещения для голосования: ул. Школьная, д. 1, адрес УИК: ул. Новая, д. 1		0101000020E610000012F6ED2422DC474043E6CAA0DA364B40
7662	7	74	1610	21090	47498	\N	54.708616999999997	Ульяновская область, Цильнинский район, с. Кайсарово, ул. Центральная, д. 42		0101000020E6100000BD732843551A4840DF313CF6B35A4B40
7661	7	74	1610	55792	47373	\N	54.687753999999998	Ульяновская область, Цильнинский район, с. Елховое Озеро, адрес помещения для голосования: ул. Колхозная, д. 115, адрес УИК: ул. Советская, д. 32	Россия, Ульяновская область, Цильнинский район, село Елховое Озеро	0101000020E61000004354E1CFF0184840BAD8B45208584B40
7675	7	74	1610	21691	47361	\N	54.543261000000001	Ульяновская область, Цильнинский район, с. Верхние Тимерсяны, адрес помещения для голосования: ул. Пролетарская, д. 16, адрес УИК: ул. Пролетарская, д. 30		0101000020E6100000C9CB9A58E0D347409C18929389454B40
7651	7	74	1610	20481	47102	\N	54.517038999999997	Ульяновская область, Цильнинский район, с. Большое Нагаткино, пл. Революции, д. 1		0101000020E61000007CEE04FBAFFB4740D6E07D552E424B40
7652	7	74	1610	20481	47036	\N	54.517038999999997	Ульяновская область, Цильнинский район, с. Большое Нагаткино, ул. Садовая, д. 7		0101000020E61000007CEE04FBAFFB4740D6E07D552E424B40
7664	7	74	1610	21185	47610	\N	54.563144000000001	Ульяновская область, Цильнинский район, с. Богородская Репьевка, ул. Труда, д. 20		0101000020E6100000EBE3A1EF6E0B48402578431A15484B40
7645	7	74	1610	20144	47339	\N	54.614167000000002	Ульяновская область, Цильнинский район, с. Богдашкино, адрес помещения для голосования: ул. Ленина, д. 3, адрес УИК: ул. Ленина, д. 26		0101000020E6100000FE62B66455D6474027A435069D4E4B40
7641	7	74	1610	19921	47462	\N	54.555526999999998	Ульяновская область, Цильнинский район, с. Арбузовка, адрес помещения для голосования: ул. Свияжская, д. 31, адрес УИК: ул. Свияжская, д. 31		0101000020E61000002F51BD35B01D4840C2853C821B474B40
7618	7	74	505	18733	46893	\N	54.117269999999998	Ульяновская область, Ульяновский район, с. Большие Ключищи, ул. Каштанкина, д. 17		0101000020E610000048F8DEDFA0234840A5660FB4020F4B40
7619	7	74	505	18733	47094	\N	54.117269999999998	Ульяновская область, Ульяновский район, с. Большие Ключищи, ул. Димитрова, д. 48		0101000020E610000048F8DEDFA0234840A5660FB4020F4B40
7630	7	74	505	55778	47229	\N	54.342979999999997	Ульяновская область, Ульяновский район, п. Тимирязевский, ул. капитана Каравашкина, СДК		0101000020E6100000A8363811FD1A48404E97C5C4E62B4B40
7634	7	74	505	19544	47299	\N	54.513804	Ульяновская область, Ульяновский район, с. Шумовка, ул. Победы, д. 3а		0101000020E6100000A0E1CD1ABC1B4840E9465854C4414B40
7637	7	74	505	19599	\N	\N	54.607267999999998	Ульяновская область, Ульяновский район, с. Ундоры, санаторий имени В.И.Ленина, лечебный корпус		0101000020E61000000DA661F88832484023F433F5BA4D4B40
7636	7	74	505	19599	\N	\N	54.607267999999998	Ульяновская область, Ульяновский район, с. Ундоры, санаторий Дубки, библиотека	Россия, Ульяновская область, Ульяновский район, село Ундоры	0101000020E61000000DA661F88832484023F433F5BA4D4B40
7635	7	74	505	19599	47096	\N	54.607267999999998	Ульяновская область, Ульяновский район, с. Ундоры, ул. Мира, д. 21а		0101000020E61000000DA661F88832484023F433F5BA4D4B40
7299	7	74	505	3044	47077	\N	54.465324000000003	Ульяновская область, Ульяновский район, д. Салмановка, ул. Победы, д. 22а		0101000020E6100000DFA7AAD0402248409F05A1BC8F3B4B40
7639	7	74	505	19807	\N	\N	54.676682999999997	"Ульяновская область, Ульяновский район, с. Русская Беденьга, контора ООО ""Хлебороб"""		0101000020E61000006A32E36DA52B48402C616D8C9D564B40
7620	7	74	505	18834	47443	\N	54.075209000000001	Ульяновская область, Ульяновский район, с. Поникий Ключ, ул. Лесная, д. 1		0101000020E6100000535BEA20AF1B4840B4AED172A0094B40
7760	7	74	505	55815	47502	\N	54.114386561150098	Ульяновская область, город Новоульяновск, с. Панская Слобода, ул. Ленина, д. 28	Россия, Ульяновская область, Ульяновский район, село Панская Слобода	0101000020E6100000FC5580EF363F4840350BB43BA40E4B40
7625	7	74	505	55788	47310	\N	54.2104452466628	Ульяновская область, Ульяновский район, п. Станция Охотничья, пер. Школьный, д. 10	Россия, Ульяновская область, Ульяновский район, село Охотничья	0101000020E61000002C4A09C1AA0A4840A94D9CDCEF1A4B40
7631	7	74	505	19405	47330	\N	54.420940999999999	Ульяновская область, Ульяновский район, с. Новый Урень, ул. Школьная, д. 23		0101000020E610000047C66AF3FF104840D4450A65E1354B40
7617	7	74	505	18656	47364	\N	54.496547	Ульяновская область, Ульяновский район,  с. Новая Беденьга, ул. Центральная, д. 24		0101000020E6100000ADA580B4FF2D4840A5F622DA8E3F4B40
7762	7	74	505	55791	47369	\N	54.1193864884725	Ульяновская область, город Новоульяновск, п. Меловой, ул. Школьная, д. 18	Россия, Ульяновская область, Ульяновский район, поселок Меловой	0101000020E61000005A9E077767294840D5CC5A0A480F4B40
7621	7	74	505	18844	\N	\N	54.082720000000002	"Ульяновская область, Ульяновский район, с. Ломы, Красный уголок ПСК ""Красная Звезда"""		0101000020E6100000E2033BFE0B2A4840D15CA791960A4B40
7759	7	74	505	55779	47261	\N	54.109401788487297	Ульяновская область, город Новоульяновск, п. Липки, ул. Ленина, д. 17	Россия, Ульяновская область, Ульяновский район, село Липки	0101000020E6100000F88C446804334840FA0E7EE2000E4B40
7638	7	74	505	19750	\N	\N	54.643003999999998	"Ульяновская область, Ульяновский район, п. Крутояр, МУ ""Межпоселенческая библиотека пос.Крутояр"""		0101000020E610000033C51C041D3348403D997FF44D524B40
7761	7	74	505	55762	47020	\N	54.103803248217098	Ульяновская область, город Новоульяновск, с. Криуши, ул. Полевая, д. 5	Россия, Ульяновская область, Ульяновский район, поселок Криуши	0101000020E61000000725CCB4FD434840041DAD6A490D4B40
7624	7	74	505	19048	47496	\N	54.189650999999998	Ульяновская область, Ульяновский район, с. Ивановка, ул. Школьная, д. 20		0101000020E610000015CAC2D7D70C4840AC53E57B46184B40
7623	7	74	505	55780	47263	\N	54.160986999999999	Ульяновская область, Ульяновский район, п. Зеленая Роща, ул. Лесная, д. 8	Россия, Ульяновская область, Ульяновский район, село Зеленая Роща	0101000020E61000006CD102B4AD024840630AD6389B144B40
7629	7	74	505	19310	47598	\N	54.398009999999999	Ульяновская область, Ульяновский район, с. Загудаевка, ул. Школьная, д. 6		0101000020E61000008EB1135E82FB474090BDDEFDF1324B40
7622	7	74	505	18937	47298	\N	54.082841999999999	Ульяновская область, Ульяновский район, с. Елшанка, ул. Набережная, д. 23		0101000020E6100000EA758BC0580D48401C5E10919A0A4B40
7495	7	74	505	12756	\N	\N	54.063589999999998	Ульяновская область, Сенгилеевский район, с. Екатериновка, ул. Новая Линия, д. 20		0101000020E6100000BF0F070951424840232D95B723084B40
7640	7	74	505	19869	47360	\N	54.553125000000001	Ульяновская область, Ульяновский район, с. Вышки, ул. Колхозная, д. 1		0101000020E61000000E130D52F02C4840CDCCCCCCCC464B40
7628	7	74	505	19224	\N	\N	54.238709999999998	"Ульяновская область, Ульяновский район, с. Волостниковка, здание конторы ЗАО ""Тетюшское"""	Россия, Ульяновская область, Ульяновский район, село Волостниковка	0101000020E6100000A3AD4A22FBFC4740349D9D0C8E1E4B40
7633	7	74	505	55804	47415	\N	54.410628218424897	Ульяновская область, Ульяновский район, п. Новая Бирючевка, ул. Школьная, д. 4	Россия, Ульяновская область, Ульяновский район, село Бирючевка	0101000020E61000007BDCB75A270E4840346953758F344B40
7871	7	74	505	55841	47648	\N	54.3047905024968	Ульяновская область, город Ульяновск, Засвияжский район, с. Арское, ул. Школьная, д. 2 А	Россия, Ульяновская область, Ульяновск городской округ, село Арское	0101000020E6100000E22021CA170E4840BD8E386403274B40
7872	7	74	1773	55795	47379	\N	54.272403327657202	Ульяновская область, город Ульяновск, Засвияжский район, с. Отрада, ул. Мира, средняя школа	Россия, Ульяновская область, Ульяновск городской округ, село Отрада	0101000020E6100000E38A8BA3720F4840882AFC19DE224B40
7754	7	74	1773	25285	46972	\N	54.142927	Ульяновская область, город Новоульяновск, ул. Ульяновская, д. 5		0101000020E6100000223317B83C324840925B936E4B124B40
7753	7	74	1773	25285	46912	\N	54.142927	Ульяновская область, город Новоульяновск, ул. Мира, д. 10		0101000020E6100000223317B83C324840925B936E4B124B40
7758	7	74	1773	25285	47260	\N	54.142927	Ульяновская область, город Новоульяновск, ул. Кременская, д. 12		0101000020E6100000223317B83C324840925B936E4B124B40
7755	7	74	1773	25285	46914	\N	54.142927	Ульяновская область, город Новоульяновск, ул. Комсомольская, д. 31		0101000020E6100000223317B83C324840925B936E4B124B40
7752	7	74	1773	25285	46914	\N	54.142927	Ульяновская область, город Новоульяновск, ул. Комсомольская, д. 2А		0101000020E6100000223317B83C324840925B936E4B124B40
7756	7	74	1773	25285	46915	\N	54.142927	Ульяновская область, город Новоульяновск, ул. Заводская, д. 13		0101000020E6100000223317B83C324840925B936E4B124B40
7870	7	74	1773	55775	47219	\N	54.299798362853899	Ульяновская область, город Ульяновск, Засвияжский район, с. Кротовка, ул. Центральная, д. 6 А		0101000020E6100000A2EE0390DA124840FFB3E6C75F264B40
7611	7	74	1471	18298	47331	\N	53.914298000000002	Ульяновская область, Тереньгульский район, с. Ясашная Ташла, ул. Центральная, д. 12		0101000020E6100000A3AD4A22FB2248402C6684B707F54A40
7610	7	74	1471	18298	47297	\N	53.914298000000002	Ульяновская область, Тереньгульский район, с. Ясашная Ташла, ул. Ленина, д. 86а		0101000020E6100000A3AD4A22FB2248402C6684B707F54A40
7590	7	74	1471	17306	\N	\N	53.784581000000003	Ульяновская область, Тереньгульский район, с. Федькино, здание школы	Россия, Ульяновская область, Тереньгульский район, село Федькино	0101000020E61000009FC893A46B2A4840100874266DE44A40
7589	7	74	1471	17230	\N	\N	53.747436999999998	Ульяновская область, Тереньгульский район, с. Тумкино, адрес помещения для голосования:  здание общеобразовательной школы, Адрес УИК: здание администрации городского поселения		0101000020E61000004E9A0645F32648400169FF03ACDF4A40
7586	7	74	1471	17105	46974	\N	53.716900000000003	Ульяновская область, Тереньгульский район. р.п. Тереньга, пл. Ленина, д. 1		0101000020E6100000336E6AA0F92E48404F401361C3DB4A40
7587	7	74	1471	17105	47089	\N	53.716900000000003	Ульяновская область, Тереньгульский район, р.п. Тереньга, ул. Евстифеева, д. 5		0101000020E6100000336E6AA0F92E48404F401361C3DB4A40
7588	7	74	1471	17105	47056	\N	53.716900000000003	"Ульяновская область, Тереньгульский район, р.п. Тереньга, адрес помещения для голосования: ул. Булыгина, д. 10, средняя школа, адрес УИК: ул. Ульяновская, д. 26"		0101000020E6100000336E6AA0F92E48404F401361C3DB4A40
7608	7	74	1471	18204	47433	\N	53.903821999999998	Ульяновская область, Тереньгульский район, с. Суровка, ул. Ряская, д. 3		0101000020E6100000C1ADBB79AA0F4840E1B37570B0F34A40
7597	7	74	1471	17639	\N	\N	53.611165	Ульяновская область, Тереньгульский район, с. Сосновка, здание общеобразовательной школы	Россия, Ульяновская область, Тереньгульский район, село Сосновка	0101000020E6100000041DAD6A49134840DCBA9BA73ACE4A40
7609	7	74	1471	18225	\N	\N	54.012157000000002	Ульяновская область, Тереньгульский район, с. Солдатская Ташла, здание культурно-досугового центра	Россия, Ульяновская область, Тереньгульский район, село Солдатская Ташла	0101000020E6100000452DCDAD101A484070B54E5C8E014B40
7607	7	74	1471	18137	\N	\N	53.973267	Ульяновская область, Тереньгульский район, с. Скугареевка, Здание центрального корпуса  ПУ-23, библиотека		0101000020E61000003201BF46921E484055A3570394FC4A40
7606	7	74	1471	18103	\N	\N	53.953502999999998	"Ульяновская область, Тереньгульский район, с. Подкуровка, адрес помещения для голосования: здание общеобразовательной школы, Адрес УИК: здание администрации сельского поселения"		0101000020E610000001892650C41E4840A6D1E4620CFA4A40
7591	7	74	1471	17322	\N	\N	53.785539	Ульяновская область, Тереньгульский район, с. Назайкино, здание культурно-досугового центра	Россия, Ульяновская область, Тереньгульский район, село Назайкино	0101000020E610000057AF22A3031C4840C45DBD8A8CE44A40
7595	7	74	1471	17527	\N	\N	53.778091000000003	Ульяновская область, Тереньгульский район, ст.Молвино, Контора Молвинского лесничества		0101000020E6100000BD8A8C0E483A4840EE27637C98E34A40
7602	7	74	1471	17909	\N	\N	53.53942	"Ульяновская область, Тереньгульский район, с. Михайловка, адрес помещения для голосования: здание средней школы, Адрес УИК: здание администрации сельского поселения"		0101000020E610000019AA622AFD2848407767EDB60BC54A40
7600	7	74	1471	17816	\N	\N	53.755806999999997	"Ульяновская область, Тереньгульский район, с. Красноборск, адрес помещения для голосования: здание средней школы, Адрес УИК: здание администрации сельского поселения"		0101000020E61000004B5AF10D850548403F8BA548BEE04A40
7605	7	74	1471	18023	\N	\N	53.548552999999998	Ульяновская область, Тереньгульский район, с. Калиновка, здание культурно-досугового центра	Россия, Ульяновская область, Тереньгульский район, село Калиновка	0101000020E6100000A8C30AB77C304840B48F15FC36C64A40
7601	7	74	1471	17836	\N	\N	53.834006000000002	"Ульяновская область, Тереньгульский район, с. Зеленец, адрес помещения для голосования: здание средней школы, Адрес УИК: здание администрации сельского поселения"		0101000020E61000003691990B5C0448407A5567B5C0EA4A40
7603	7	74	1471	17933	\N	\N	53.530284000000002	Ульяновская область, Тереньгульский район, с. Елшанка, здание культурно-досугового центра	Россия, Ульяновская область, Тереньгульский район, село Елшанка	0101000020E61000000B47904AB11F4840C9CB9A58E0C34A40
7592	7	74	1471	17394	\N	\N	53.667251	Ульяновская область, Тереньгульский район, с. Гладчиха, здание общеобразовательной школы	Россия, Ульяновская область, Тереньгульский район, село Гладчиха	0101000020E61000000403081F4A244840959C137B68D54A40
7581	7	74	1471	16844	\N	\N	53.554282000000001	Ульяновская область, Тереньгульский район, с.Гавриловка, здание культурно-досугового центра	Россия, Ульяновская область, Тереньгульский район, село Гавриловка	0101000020E6100000A33F34F3E42A484078616BB6F2C64A40
7598	7	74	1471	17716	\N	\N	53.525001000000003	"Ульяновская область, Тереньгульский район, с. Большая Борла, адрес помещения для голосования: здание средней школы, Адрес УИК: здание администрации сельского поселения"	Россия, Ульяновская область, Тереньгульский район, село Большая Борла	0101000020E610000093E1783E0308484004AF963B33C34A40
7596	7	74	1471	17614	\N	\N	53.582928000000003	Ульяновская область, Тереньгульский район, с. Белогорское, здание администрации сельского поселения	Россия, Ульяновская область, Тереньгульский район, село Белогорское	0101000020E6100000C07630629F1648401BF67B629DCA4A40
7594	7	74	1471	17498	\N	\N	53.755248000000002	Ульяновская область, Тереньгульский район, с. Байдулино, адрес помещения для голосования: здание общеобразовательной школы, Адрес УИК: здание  администрации городского поселения		0101000020E6100000603DEE5BAD314840492F6AF7ABE04A40
7599	7	74	1471	17744	\N	\N	53.489736999999998	Ульяновская область, Тереньгульский район, с. Алешкино, здание сельского дома культуры	Россия, Ульяновская область, Тереньгульский район, село Алешкино	0101000020E6100000A08A1BB7981148401152B7B3AFBE4A40
7582	7	74	1361	16909	47402	\N	54.554378999999997	Ульяновская область, Сурский район, с. Шатрашаны, адрес помещения для голосования: с. Атяшкино. пер. Школьный, д. 4, адрес УИК: ул. Первомайская, д. 2		0101000020E610000073672618CEAD47406A4B1DE4F5464B40
7583	7	74	1361	16909	47495	\N	54.554378999999997	Ульяновская область, Сурский район, с. Шатрашаны, ул. Первомайская, д. 2		0101000020E610000073672618CEAD47406A4B1DE4F5464B40
7579	7	74	1361	16735	47603	\N	54.647452999999999	Ульяновская область, Сурский район, с. Чирково, ул. Гора, д. 14		0101000020E6100000ECA529029C4447403A596ABDDF524B40
7585	7	74	1361	17025	47539	\N	54.532511	Ульяновская область, Сурский район, с. Чеботаевка, адрес помещения для голосования: ул. Центральная. д. 1а, адрес УИК: ул. Полыновка, д. 2		0101000020E6100000645DDC46039A474050E1085229444B40
7578	7	74	1361	16634	47494	\N	54.603237	Ульяновская область, Сурский район, с. Хмелевка, адрес помещения для голосования: с. Шеевщино, ул. Школьная, д. 16, адрес УИК: ул. Школьная, д. 3	Россия, Ульяновская область, Сурский район, село Хмелевка	0101000020E610000050FD8348864847405B5EB9DE364D4B40
7577	7	74	1361	16634	47494	\N	54.603237	Ульяновская область, Сурский район, с. Хмелевка, адрес помещения для голосования: ул. Школьная, д. 1а, адрес УИК: ул. Школьная, д. 3		0101000020E610000050FD8348864847405B5EB9DE364D4B40
7568	7	74	1361	16005	47490	\N	54.479717000000001	Ульяновская область, Сурский район, р.п. Сурское, адрес помещения для голосования: с. Чернёново, ул. Юбилейная, д. 3, адрес УИК: ул. Ленина, д. 37		0101000020E61000005743E21E4B5B4740E92ADD5D673D4B40
7567	7	74	1361	16005	46867	\N	54.479717000000001	Ульяновская область, Сурский район, р.п. Сурское, адрес помещения для голосования: ул. Энгельса, д. 63, адрес УИК: ул. Ленина, д. 37		0101000020E61000005743E21E4B5B4740E92ADD5D673D4B40
7573	7	74	1361	16005	47535	\N	54.479717000000001	Ульяновская область, Сурский район, р.п. Сурское, адрес помещения для голосования: с. Студенец, ул. Центральная, д. 52, адрес УИК: ул. Ленина, д. 37		0101000020E61000005743E21E4B5B4740E92ADD5D673D4B40
7564	7	74	1361	16005	46889	\N	54.479717000000001	Ульяновская область, Сурский район, р.п. Сурское, адрес помещения для голосования: ул. Хазова, д. 21, адрес УИК: ул. Ленина, д. 37		0101000020E61000005743E21E4B5B4740E92ADD5D673D4B40
7565	7	74	1361	16005	47034	\N	54.479717000000001	Ульяновская область, Сурский район, р.п. Сурское, адрес помещения для голосования: ул. Советская, д. 27, адрес УИК: ул. Ленина, д. 37		0101000020E61000005743E21E4B5B4740E92ADD5D673D4B40
7566	7	74	1361	16005	47328	\N	54.479717000000001	Ульяновская область, Сурский район, р.п. Сурское, адрес помещения для голосования: ул. Промышленная, д. 8, адрес УИК: ул. Ленина, д. 37		0101000020E61000005743E21E4B5B4740E92ADD5D673D4B40
7574	7	74	1361	16005	47602	\N	54.479717000000001	Ульяновская область, Сурский район, р.п. Сурское, адрес помещения для голосования: с. Полянки, ул. Ленина, д. 21, кв. 3, адрес УИК: ул. Ленина, д. 37		0101000020E61000005743E21E4B5B4740E92ADD5D673D4B40
7569	7	74	1361	16005	47409	\N	54.489275864332797	"Ульяновская область, Сурский район, пос. Центральная Усадьба совхоза ""Сурский"", ул. Зелёная, д. 5"	Россия, Ульяновская область, Сурский район, поселок Сурское	0101000020E6100000774B72C0AE5C4740DD5B9198A03E4B40
7562	7	74	1361	15823	47492	\N	54.645866793052299	Ульяновская область, Сурский район, с. Сара, адрес помещения для голосования: с. Засарье, ул. Советская, д. 1, адрес УИК: ул. Комсомольская, д. 14	Россия, Ульяновская область, Сурский район, село Сара	0101000020E6100000DFFE5C3464604740674815C5AB524B40
7561	7	74	1361	15823	47353	\N	54.644920999999997	Ульяновская область, Сурский район, с. Сара, ул. Комсомольская, д. 14		0101000020E6100000E066F1626160474076C075C58C524B40
7555	7	74	1361	15566	47606	\N	54.428657000000001	Ульяновская область, Сурский район, с. Кезьмино, адрес помещения для голосования: с. Ружеевщино, ул. Мира, 7, адрес УИК: ул. Новая, д. 1		0101000020E6100000C0AF912408A54740CA198A3BDE364B40
7550	7	74	1361	15336	47534	\N	54.622148000000003	Ульяновская область, Сурский район, с. Паркино, пер. Центральный, д. 3		0101000020E6100000715985CD009F4740CBA2B08BA24F4B40
7557	7	74	1361	15650	47397	\N	54.462612999999997	Ульяновская область, Сурский район, с. Никитино, адрес помещения для голосования: ул. Линёвка, д. 37, адрес УИК: ул. Линёвка, д. 32		0101000020E6100000B3075A81218947402BDA1CE7363B4B40
7552	7	74	1361	15438	47282	\N	54.478361999999997	Ульяновская область, Сурский район, с. Лава, адрес помещения для голосования: ул. Садовая, д. 3, адрес УИК: ул. Садовая, д. 5		0101000020E6100000022B8716D972474017D34CF73A3D4B40
7554	7	74	1361	15541	47597	\N	54.482453	Ульяновская область, Сурский район, с. Кезьмино, адрес помещения для голосования: д. Красная Якла, ул. Мира, д. 44, адрес УИК: ул. Новая, д. 1		0101000020E61000005B5D4E09889D4740B56D1805C13D4B40
7575	7	74	1361	16528	47493	\N	54.561025000000001	Ульяновская область, Сурский район, с. Княжуха, адрес помещения для голосования: ул. Большая дорога, д. 8, адрес УИК: ул. Большая дорога, д. 13, кв. 1		0101000020E61000008F34B8AD2D484740849ECDAACF474B40
7571	7	74	1361	52682	47447	\N	54.402858999999999	"Ульяновская область, Сурский район, пос. Центральная Усадьба совхоза ""Сурский"", адрес помещения для голосования: с. Кирзять, ул. Центральная, д. 50, адрес УИК: ул. Зелёная, д. 5"		0101000020E610000082CAF8F7195B47401BF33AE290334B40
7580	7	74	1361	16305	47540	\N	54.695596000000002	Ульяновская область, Сурский район, с. Ждамирово, адрес помещения для голосования: с. Зимницы, ул. Ленина, д. 32, адрес УИК: ул. Красная площадь, д. 4		0101000020E61000006C97361C964447403D9D2B4A09594B40
7570	7	74	1361	16305	47600	\N	54.695596000000002	Ульяновская область, Сурский район, с. Ждамирово, адрес помещения для голосования: ул. Красная площадь, д. 21, адрес УИК: ул. Красная площадь, д. 4		0101000020E61000006C97361C964447403D9D2B4A09594B40
80596	7	72	\N	55920	48487	\N	53.087931426226199	с.Преображенка, Тополиная, 15		0101000020E61000004BE5ED08A70F4940FCA6B052418B4A40
7560	7	74	1361	15810	47430	\N	54.675604999999997	Ульяновская область, Сурский район, с. Елховка, адрес помещения для голосования: ул. Центральная, д. 14, адрес УИК: ул. Центральная, д. 37		0101000020E6100000FE2C9622F9524740CD0182397A564B40
7572	7	74	1361	16412	47537	\N	54.431939999999997	Ульяновская область, Сурский район, с. Гулюшево, адрес помещения для голосования: ул. Ягодная, д. 19, адрес УИК: ул. Ягодная, д. 17		0101000020E6100000BB9D7DE5414A4740C8EA56CF49374B40
7558	7	74	1361	15712	47392	\N	54.490591000000002	Ульяновская область, Сурский район, с. Выползово, адрес помещения для голосования: с. Кивать, ул. Проулок, д. 99, адрес УИК: ул. Центральная, д. 33	Россия, Ульяновская область, Сурский район, село Выползово	0101000020E6100000B3EDB43522844740215B96AFCB3E4B40
7559	7	74	1361	15712	47599	\N	54.490591000000002	Ульяновская область, Сурский район, с. Выползово, адрес помещения для голосования: ул. Московская, д. 25, адрес УИК: ул. Центральная, д. 33		0101000020E6100000B3EDB43522844740215B96AFCB3E4B40
7549	7	74	1361	14682	47538	\N	54.619281000000001	Ульяновская область, Сурский район, с. Большой Кувай, адрес помещения для голосования: с. Малый Кувай, ул. Московская, д. 16, адрес УИК: ул. Хазова, д. 18		0101000020E61000000C91D3D7F38B474060048D99444F4B40
7537	7	74	1361	14682	47487	\N	54.619281000000001	Ульяновская область, Сурский район, с. Большой Кувай, адрес помещения для голосования: ул. Волкова, д. 30, адрес УИК: ул. Хазова, д. 18		0101000020E61000000C91D3D7F38B474060048D99444F4B40
7553	7	74	1361	15462	47489	\N	54.440218999999999	Ульяновская область, Сурский район, с. Белый Ключ, ул. Садовая, д. 4		0101000020E610000026A60BB1FA694740F609A01859384B40
7563	7	74	1361	55835	47637	\N	54.586457000000003	Ульяновская область, Сурский район, с. Барышская Слобода, адрес помещения для голосования: ул. Кирова, д. 9, адрес УИК: ул. Кирова, д. 14	Россия, Ульяновская область, Сурский район, село Барышская Слобода	0101000020E610000066A032FE7D64474051C1E105114B4B40
7548	7	74	1361	15139	47429	\N	54.546734000000001	Ульяновская область, Сурский район, с. Астрадамовка, адрес помещения для голосования: с. Аркаево, ул. Центральная, д. 21, адрес УИК: ул. Больничная, д. 5		0101000020E6100000014C1938A09147403ECE3461FB454B40
7547	7	74	1361	15139	47491	\N	54.546734000000001	Ульяновская область, Сурский район, с. Астрадамовка, адрес помещения для голосования: д. Лебедевка, ул. Линия, д. 18, адрес УИК: ул. Больничная, д. 5		0101000020E6100000014C1938A09147403ECE3461FB454B40
7546	7	74	1361	15139	47296	\N	54.546734000000001	Ульяновская область, Сурский район, с. Астрадамовка, адрес помещения для голосования: ул. Красная площадь, д. 26, адрес УИК: ул. Больничная, д. 5		0101000020E6100000014C1938A09147403ECE3461FB454B40
7584	7	74	1361	17015	47389	\N	54.530191000000002	Ульяновская область, Сурский район, с. Архангельское, адрес помещения для голосования: ул. Центральная, д. 1, адрес УИК: ул. Центральная, д. 43		0101000020E61000007AE2395B40A8474018D1764CDD434B40
7576	7	74	1361	16612	47431	\N	54.580837000000002	Ульяновская область, Сурский район, с. Араповка, пер. Школьный, д. 2		0101000020E6100000991249F4324E474044A7E7DD584A4B40
7551	7	74	1361	55807	47426	\N	54.572872103987102	Ульяновская область, Сурский район, с. Астрадамовка, адрес помещения для голосования: д. Алейкино, ул. Садовая, д. 3, адрес УИК: ул. Больничная, д. 5	Россия, Ульяновская область, Сурский район, село Алейкино	0101000020E6100000A5F622DA8E994740A565A4DE53494B40
7545	7	74	1316	55824	47601	\N	54.454770438197102	Ульяновская область, Старомайнский район, с. Ясашное Помряскино, ул. Пушкина, д. 1	Россия, Ульяновская область, Старомайнский район, село Ясащное Помряскино	0101000020E6100000210725CCB4974840D99942E7353A4B40
7533	7	74	1316	14496	47393	\N	54.787827	Ульяновская область, Старомайнский район, с. Шмелевка, адрес помещения для голосования: пер. Школьный, д. 7, адрес УИК: ул. Культурная, д. 18		0101000020E61000001079CBD58F954840F1F3DF83D7644B40
7544	7	74	1316	15047	47420	\N	54.423141000000001	Ульяновская область, Старомайнский район, с. Татарское Урайкино, адрес помещения для голосования: ул. Кооперативная, д. 104, адрес УИК: ул. Кооперативная, д. 68		0101000020E6100000016DAB5967A04840624CFA7B29364B40
7543	7	74	1316	14973	47594	\N	54.582141999999997	Ульяновская область, Старомайнский район, с. Старое Рождествено, ул. Советская, д. 48		0101000020E61000002F302B14E9C2484063D009A1834A4B40
7521	7	74	1316	13908	46854	\N	54.605562999999997	Ульяновская область, Старомайнский район, р.п. Старая Майна, пл. Ленина, д. 2		0101000020E610000097E4805D4D7648407555A016834D4B40
95169	7	74	1316	13908	47002	\N	54.605562999999997	Ульяновская область, Старомайнский район, р.п. Старая Майна, ул. Льва Толстого, д. 97		0101000020E610000097E4805D4D7648407555A016834D4B40
7520	7	74	1316	13908	46979	\N	54.605562999999997	Ульяновская область, Старомайнский район, р.п. Старая Майна, ул. Комсомольская, д. 37		0101000020E610000097E4805D4D7648407555A016834D4B40
7536	7	74	1316	14668	47396	\N	54.745854000000001	Ульяновская область, Старомайнский район, с. Русский Юрткуль, адрес помещения для голосования: ул. Школьная, д. 10, адрес УИК: ул. Молодежная, д. 14		0101000020E6100000B14D2A1A6BAF48409FCBD424785F4B40
7528	7	74	1316	14295	47338	\N	54.536481000000002	Ульяновская область, Старомайнский район, с. Прибрежное, адрес помещения для голосования: ул. Советская, д. 2, адрес УИК: ул. Советская, д. 10		0101000020E6100000A65EB7088C79484073F6CE68AB444B40
7527	7	74	1316	14210	47544	\N	54.492258999999997	Ульяновская область, Старомайнский район, с. Новиковка, адрес помещения для голосования: ул. Придорожная, д. 1, адрес УИК: ул. Садовая, д. 25		0101000020E61000001343723271954840B114C957023F4B40
7532	7	74	1316	14476	47484	\N	54.779774000000003	Ульяновская область, Старомайнский район, с. Матвеевка, ул. Матвеевская, д. 12	Россия, Ульяновская область, Старомайнский район, село Матвеевка	0101000020E6100000CB11329067994840B4226AA2CF634B40
7540	7	74	1316	14862	47531	\N	54.490957000000002	Ульяновская область, Старомайнский район, с. Малая Кандала, адрес помещения для голосования: ул. Кооперативная, д. 5, адрес УИК: ул. Советская, д. 11		0101000020E61000009E0C8E9257B14840035FD1ADD73E4B40
7542	7	74	1316	14964	47548	\N	54.596817000000001	Ульяновская область, Старомайнский район, с. Лесное Никольское, адрес помещения для голосования: ул. Магистральная, д. 1, адрес УИК: ул. Магистральная, д. 2		0101000020E61000006E693524EEB948403259DC7F644C4B40
7539	7	74	1316	14790	47547	\N	54.572378	Ульяновская область, Старомайнский район, п. Лесная Поляна, ул. Парковая, д. 10		0101000020E61000004700378B17A348409679ABAE43494B40
94441	7	74	1316	14383	47403	\N	54.508707000000001	Ульяновская область, Старомайнский район, с. Кремёнки, ул. Дачная, д. 4, здание АУ ДК		0101000020E610000027C0B0FCF96E4840861F9C4F1D414B40
7526	7	74	1316	55793	47377	\N	54.579179551507799	Ульяновская область, Старомайнский район, с. Красная Река, адрес помещения для голосования: ул. Советская, д. 30, адрес УИК: ул. Советская, д. 13	Россия, Ульяновская область, Старомайнский район, село Красная Река	0101000020E6100000EB0088BB7A8F4840A73FFB91224A4B40
7525	7	74	1316	14121	47543	\N	54.726944000000003	Ульяновская область, Старомайнский район, с. Жедяевка, адрес помещения для голосования: ул. Казанская, д. 1А, адрес УИК: ул. Казанская, д. 22		0101000020E6100000209C4F1DAB944840000341800C5D4B40
7541	7	74	1316	14884	47425	\N	54.458458	Ульяновская область, Старомайнский район, с. Ертуганово, ул. Школьная, д. 39		0101000020E6100000C8B3CBB73EB64840774B72C0AE3A4B40
7531	7	74	1316	14393	47258	\N	54.434961999999999	Ульяновская область, Старомайнский район, с. Дмитриево Помряскино, адрес помещения для голосования: ул. Школьная, д. 3, адрес УИК: ул. Молодежная, д. 5		0101000020E61000002BF9D85DA07648405A80B6D5AC374B40
7534	7	74	1316	14568	47394	\N	54.806396999999997	Ульяновская область, Старомайнский район, с. Грибовка, ул. Центральная, д. 77А		0101000020E6100000EF3B86C77EA24840D74B530438674B40
7529	7	74	1316	14318	47486	\N	54.523989	Ульяновская область, Старомайнский район, п. Восход, ул. Снежная, д.1		0101000020E6100000AC3C81B0537E48405C3B511212434B40
7524	7	74	1316	14100	47483	\N	54.723486000000001	Ульяновская область, Старомайнский район, с. Волостниковка, адрес помещения для голосования: ул. Центральная, д. 46, адрес УИК: ул. Центральная, д. 14		0101000020E61000000AF31E679A824840938E72309B5C4B40
7538	7	74	1316	14769	47336	\N	54.551178	Ульяновская область, Старомайнский район, с. Большая Кандала, адрес помещения для голосования: ул. Московская, д. 13, адрес УИК: ул. Парк Победы, д. 5		0101000020E61000006F2EFEB627AC484029232E008D464B40
7535	7	74	1316	14585	47395	\N	54.783600999999997	Ульяновская область, Старомайнский район, с. Базарно-Мордовский Юрткуль, адрес помещения для голосования: ул. Школьная, д. 59, адрес УИК: ул. Школьная, д.38		0101000020E61000000A83328D26B94840730E9E094D644B40
7523	7	74	1316	14031	47618	\N	54.674512	Ульяновская область, Старомайнский район, д. Арчиловка, ул. Озаренная, д. 11		0101000020E610000007077B13438648403961C26856564B40
7506	7	74	1253	13251	47536	\N	52.612254999999998	Ульяновская область, Старокулаткинский район, с. Усть-Кулатка, ул. Октябрьская, д. 58		0101000020E61000008CD7BCAAB3E04740FFE7305F5E4E4A40
7511	7	74	1253	55790	47357	\N	52.700332975605697	Ульяновская область, Старокулаткинский район, с. Старый Мостяк, ул. Юбилейная, д. 16		0101000020E6100000FCDEA63FFBB34740A0A70183A4594A40
7513	7	74	1253	13548	47325	\N	52.785758000000001	Ульяновская область, Старокулаткинский район, с. Старый Атлаш, ул. Ленина, д. 64		0101000020E61000007BD976DA1AA747400249D8B793644A40
7507	7	74	1253	13260	47340	\N	52.781128000000002	Ульяновская область, Старокулаткинский район, с. Старое Зеленое, ул. Советская, д. 68	Россия, Ульяновская область, Старокулаткинский район, село Старое Зеленое	0101000020E6100000574277499CF54740B5FE9600FC634A40
7505	7	74	1253	13163	47391	\N	52.809497	Ульяновская область, Старокулаткинский район, с Старая Яндовка, ул. Молодежная, д. 18		0101000020E6100000D2FC31AD4DBF4740E59A02999D674A40
7499	7	74	1253	12888	46963	\N	52.728172999999998	Ульяновская область, Старокулаткинский район, р.п. Старая Кулатка, ул. Куйбышева, д. 51		0101000020E610000064B14D2A1ACF4740446ADAC5345D4A40
7498	7	74	1253	12888	46963	\N	52.728172999999998	Ульяновская область, Старокулаткинский район, р.п. Старая Кулатка, ул. Куйбышева, д. 20		0101000020E610000064B14D2A1ACF4740446ADAC5345D4A40
7516	7	74	1253	13711	47354	\N	52.890684999999998	Ульяновская область, Старокулаткинский район, с. Средняя Терешка, ул. М. Асадуллина, д. 250		0101000020E6100000331B649291C14740D50451F701724A40
7512	7	74	1253	13536	47423	\N	52.723503999999998	Ульяновская область, Старокулаткинский район, с. Новый Мостяк, ул. Просвещения, д. 11		0101000020E610000072E1404816B84740394371C79B5C4A40
7502	7	74	1253	13062	47259	\N	52.672564999999999	Ульяновская область, Старокулаткинский район, с. Новые Зимницы, ул. Кузахметова, д. 5	Россия, Ульяновская область, Старокулаткинский район, село Новые Зимницы	0101000020E6100000062D246074C7474095B7239C16564A40
7510	7	74	1253	13433	47593	\N	52.785921000000002	Ульяновская область, Старокулаткинский район, с. Новое Зеленое, ул. Советская, д. 51		0101000020E6100000BF620D17B9014840AC1E300F99644A40
7504	7	74	1253	13154	47485	\N	52.757798000000001	Ульяновская область, Старокулаткинский район, с. Новая Яндовка, ул. Т. Рашитовой, д. 30		0101000020E610000002D8800871C94740B37C5D86FF604A40
7519	7	74	1253	13825	47546	\N	52.897764000000002	Ульяновская область, Старокулаткинский район, с. Новая Терешка, ул. 4-х братьев Аксяновых, д. 46		0101000020E61000009D2CB5DE6FC6474059C345EEE9724A40
7503	7	74	1253	13086	47388	\N	52.653601999999999	Ульяновская область, Старокулаткинский район, с. Новая Кулатка, ул. Советская, д. 63		0101000020E6100000252191B6F1D34740D34CF73AA9534A40
7515	7	74	1253	13635	47482	\N	52.731330999999997	Ульяновская область, Старокулаткинский район, с. Мосеевка, ул. Советская, д. 51а		0101000020E610000002D8800871A3474086C613419C5D4A40
7518	7	74	1253	13810	47422	\N	52.906813999999997	Ульяновская область, Старокулаткинский район, с. Кирюшкино, ул. Советская, д. 54		0101000020E61000005470784144D2474008C72C7B12744A40
7514	7	74	1253	13620	47595	\N	52.834730999999998	Ульяновская область, Старокулаткинский район, с. Кармалей, ул. Советская, д. 34		0101000020E61000008E075BECF6AF47408BFA2477D86A4A40
7509	7	74	1253	13360	47591	\N	52.694068999999999	Ульяновская область, Старокулаткинский район, с. Зарыклей, ул. Г. Тукая, д. 1		0101000020E6100000A774B0FECFF747406E15C440D7584A40
7508	7	74	1253	13344	47589	\N	52.678975000000001	Ульяновская область, Старокулаткинский район, с. Вязовый Гай, ул. Советская, д. 36		0101000020E61000004AEF1B5F7B0248409BE61DA7E8564A40
7517	7	74	1253	13730	47592	\N	52.897177999999997	Ульяновская область, Старокулаткинский район, с. Верхняя Терешка, ул. Советская, д. 38		0101000020E6100000956247E350AF474068588CBAD6724A40
7500	7	74	1253	12972	47302	\N	52.699798999999999	Ульяновская область, Старокулаткинский район, с. Бахтеевка, ул. Школьная, д. 1		0101000020E6100000D2FF722D5AE0474002637D0393594A40
7497	7	74	1184	12824	47326	\N	54.052370000000003	Ульяновская область, Сенгилеевский район, с. Шиловка, адрес помещения для голосования: ул. Володарского, д. 17, адрес УИК: пл. Революции, д. 30		0101000020E610000043723271AB52484051A5660FB4064B40
7496	7	74	1184	12803	47351	\N	54.028565999999998	Ульяновская область, Сенгилеевский район, с.Тушна, адрес помещения для голосования: ул. Центральная, д. 10, адрес УИК: ул. Школьная, д. 2	Россия, Ульяновская область, Сенгилеевский район, село Тушна	0101000020E6100000EE77280AF441484086E3F90CA8034B40
7480	7	74	1184	11949	46960	\N	53.989246999999999	Ульяновская область, Сенгилеевский район, пгт. Силикатный, адрес помещения для голосования: ул. Садовая, д. 3, адрес УИК: ул. Энгельса, д. 5		0101000020E6100000E0D6DD3CD529484043554CA59FFE4A40
7479	7	74	1184	11949	46888	\N	53.989246999999999	Ульяновская область, Сенгилеевский район, пгт. Силикатный, адрес помещения для голосования: ул. Заводская, д. 3, адрес УИК: ул. Энгельса, д. 5		0101000020E6100000E0D6DD3CD529484043554CA59FFE4A40
7477	7	74	1184	11291	46868	\N	53.960692000000002	Ульяновская область, Сенгилеевский район, г. Сенгилей, адрес помещения для голосования: ул. Чапаева, д. 29, адрес УИК: ул. Волжская, д. 141		0101000020E610000012DC48D922654840B1C398F4F7FA4A40
7474	7	74	1184	11291	47289	\N	53.960692000000002	Ульяновская область, Сенгилеевский район, г. Сенгилей, ул. Октябрьская, д. 12	Россия, Ульяновская область, Сенгилеевский район, Сенгилей	0101000020E610000012DC48D922654840B1C398F4F7FA4A40
7476	7	74	1184	11291	47084	\N	53.960692000000002	Ульяновская область, Сенгилеевский район, г. Сенгилей, ул. Новая Линия, д. 36		0101000020E610000012DC48D922654840B1C398F4F7FA4A40
7465	7	74	1184	11291	46887	\N	53.960692000000002	Ульяновская область, Сенгилеевский район, г. Сенгилей, ул. Красноармейская, д. 86		0101000020E610000012DC48D922654840B1C398F4F7FA4A40
7475	7	74	1184	11291	46955	\N	53.960692000000002	Ульяновская область, Сенгилеевский район, г. Сенгилей, ул. Колхозная, д. 1		0101000020E610000012DC48D922654840B1C398F4F7FA4A40
7478	7	74	1184	55789	47356	\N	54.002130000000001	Ульяновская область, Сенгилеевский район, р.п. Цемзавод, ул. Цементников, д. 4	Россия, Ульяновская область, Сенгилеевский район, поселок Сенгилеевский Цементный Завод 1 километр	0101000020E610000028B7ED7BD45D4840952BBCCB45004B40
7492	7	74	1184	12632	47590	\N	53.768315000000001	Ульяновская область, Сенгилеевский район, с. Русская Бектяшка, адрес помещения для голосования: ул. Полевая, д. 66, адрес УИК: пер. Широкий, д. 2		0101000020E610000022C495B3776C48405C035B2558E24A40
7493	7	74	1184	12674	47417	\N	53.803192000000003	Ульяновская область, Сенгилеевский район, с. Мордово, адрес помещения для голосования: ул. Ленина, д. 34, адрес УИК: ул. Ленина, д. 45А		0101000020E61000002194F771347148405534D6FECEE64A40
7491	7	74	1184	12542	47587	\N	53.773530999999998	Ульяновская область, Сенгилеевский район, с. Кротково, адрес помещения для голосования: ул.Школьная, д. 11, адрес УИК: ул.Школьная, д. 5		0101000020E6100000B1A71DFE9A46484099B8551003E34A40
7482	7	74	1184	12088	46966	\N	54.027900000000002	Ульяновская область, Сенгилеевский район, пгт. Красный Гуляй, адрес помещения для голосования: пер. Пионерский, д. 6, адрес УИК: ул. Пчеловская, д. 1		0101000020E610000090F98040672A48407AC7293A92034B40
7481	7	74	1184	12088	47088	\N	54.027900000000002	Ульяновская область, Сенгилеевский район, пгт.Красный Гуляй, адрес помещения для голосования: ул. Мира, д. 11, адрес УИК: ул. Пчеловская, д. 1		0101000020E610000090F98040672A48407AC7293A92034B40
7486	7	74	1184	12334	47481	\N	53.951616999999999	Ульяновская область, Сенгилеевский район, с. Каранино, пер. Речной, д. 6		0101000020E6100000978C63247B584840A8A8FA95CEF94A40
7488	7	74	1184	12438	47283	\N	53.838369	Ульяновская область, Сенгилеевский район, с. Елаур, ул. Крупской, д. 1		0101000020E6100000D7A4DB12B9664840787DE6AC4FEB4A40
7484	7	74	1184	12251	47588	\N	53.838709000000001	Ульяновская область, Сенгилеевский район, с. Вырыстайкино, ул. Кооперативная, 21Б		0101000020E61000006C98A1F1446E484031EE06D15AEB4A40
7490	7	74	1184	12519	47418	\N	53.755887000000001	Ульяновская область, Сенгилеевский район, с. Бекетовка, ул. Ленина, д. 65А		0101000020E61000003BC61517475F48405C3CBCE7C0E04A40
7494	7	74	1184	12711	47327	\N	53.961767999999999	Ульяновская область, Сенгилеевский район, с. Артюшкино, адрес помещения для голосования: ул. Советская, д. 33, адрес УИК: ул. Советская, д. 4		0101000020E6100000EB39E97DE33748406F2BBD361BFB4A40
7483	7	74	1184	12174	47421	\N	53.873021999999999	Ульяновская область, Сенгилеевский район, с. Алешкино, адрес помещения для голосования: ул. Молодежная, д. 1, адрес УИК: ул. Ленина, д. 53Б		0101000020E6100000AC730CC85E6748402158552FBFEF4A40
7472	7	74	1130	11656	\N	\N	52.903674000000002	Ульяновская область, Радищевский район, п. Шевченко, кабинет сельского клуба		0101000020E61000006B494739981548406D1FF296AB734A40
7452	7	74	1130	10723	\N	\N	52.779794000000003	"Ульяновская область, Радищевский район, с. Чауши, зал филиала МУ КДЦМ ""Спутник"""		0101000020E6100000BC96900F7ADE4740FBCE2F4AD0634A40
7471	7	74	1130	11590	\N	\N	52.957793000000002	Ульяновская область, Радищевский район, с. Средниково, адрес помещения для голосования: сельский клуб, адрес УИК: кабинет ФАПа		0101000020E610000069C537143E0B48403BAB05F6987A4A40
7470	7	74	1130	11555	\N	\N	52.937336999999999	Ульяновская область, Радищевский район, с. Софьино, фойе начальной общеобразовательной школы		0101000020E6100000E19524CFF5054840562AA8A8FA774A40
7455	7	74	1130	10842	\N	\N	52.947479000000001	Ульяновская область, Радищевский район, с. Соловчиха, зал сельского Дома культуры		0101000020E6100000957F2DAF5CE54740CA52EBFD46794A40
7461	7	74	1130	11111	\N	\N	52.913666999999997	"Ульяновская область, Радищевский район, ст. Рябина, помещение ООО ""Хлебоприемное предприятие Рябина"""	Россия, Ульяновская область, Радищевский район, село Рябина	0101000020E61000006AA4A5F2762848409B374E0AF3744A40
7446	7	74	1130	10428	46863	\N	52.854948	"Ульяновская область, Радищевский район, р.п. Радищево, адрес помещения для голосования: пл. 50 лет ВЛКСМ, д. 17, МУК ""Радищевский Дом культуры"", танцевальный зал, адрес УИК: пл. 50 лет ВЛКСМ, д. 11, кабинет № 21а"		0101000020E6100000AF21382EE3EE4740EBE3A1EF6E6D4A40
7448	7	74	1130	10428	47324	\N	52.854948	Ульяновская область, Радищевский район, р.п. Радищево, адрес помещения для голосования: ул. Свердлова, д. 15, МУО ДОД  Детская школа искусств, танцевальный зал, адрес УИК: пл. 50 лет ВЛКСМ, д. 11, кабинет № 18		0101000020E6100000AF21382EE3EE4740EBE3A1EF6E6D4A40
7449	7	74	1130	10428	47281	\N	52.854948	Ульяновская область, Радищевский район, р.п. Радищево, МОУ Радищевская СОШ № 2, ул. Кооперативная, д. 29		0101000020E6100000AF21382EE3EE4740EBE3A1EF6E6D4A40
7447	7	74	1130	10428	47295	\N	52.854948	"Ульяновская область, Радищевский район, р.п. Радищево, адрес помещения для голосования: р.п. Радищево, ул. Заводская, д. 6, ОАО ""Гидравлик"", кабинет специалистов, адрес УИК: ул. Заводская, д. 8, кабинет специалистов ОГУ"		0101000020E6100000AF21382EE3EE4740EBE3A1EF6E6D4A40
7460	7	74	1130	11080	\N	\N	52.925080000000001	Ульяновская область, Радищевский район, с. Паньшино, зал сельского клуба		0101000020E6100000124F7633A339484083177D0569764A40
7466	7	74	1130	11378	\N	\N	52.941228000000002	Ульяновская область, Радищевский район, с. Ореховка, адрес помещения для голосования: зал администрации МО Ореховское сельское поселение, адрес УИК: читальный зал сельской библиотеки	Россия, Ульяновская область, Радищевский район, село Ореховка	0101000020E61000002FBFD364C61B48402D0ABB287A784A40
7462	7	74	1130	11173	\N	\N	53.020603000000001	"Ульяновская область, Радищевский район, п. Октябрьский, адрес помещения для голосования: зал МУК ""Центральный поселенческий Дом культуры"", адрес УИК: кабинет администрации МО Октябрьское СП"		0101000020E6100000D2E28C614EF6474089997D1EA3824A40
7451	7	74	1130	10648	\N	\N	52.820844999999998	"Ульяновская область, Радищевский район, с. Новая Дмитриевка, адрес помещения для голосования: филиал МУ КДЦМ ""Спутник"", адрес УИК: кабинет администратора сёл"		0101000020E6100000A81B28F04EFC4740E50AEF7211694A40
7464	7	74	1130	11275	\N	\N	52.925204999999998	Ульяновская область, Радищевский район, с. Нижняя Маза, кабинет начальной общеобразовательной школы		0101000020E6100000ABECBB22F8F547403F8C101E6D764A40
7469	7	74	1130	55818	\N	\N	52.825717006737399	Ульяновская область, Радищевский район, с. Мордовская Карагужа, адрес помещения для голосования: фойе основной общеобразовательной школы, адрес УИК: кабинет администратора сёл		0101000020E610000059A31EA2D115484028603B18B1694A40
7459	7	74	1130	11021	\N	\N	52.977724000000002	Ульяновская область, Радищевский район, п. Кубра, зал сельского Дома культуры		0101000020E6100000B0C56E9F55244840D5415E0F267D4A40
7456	7	74	1130	10905	\N	\N	52.958682000000003	Ульяновская область, Радищевский район, с. Калиновка, зал администрации МО Калиновское сельское поселение	Россия, Ульяновская область, Радищевский район, село Калиновка	0101000020E6100000D6355A0EF4284840C7A17E17B67A4A40
7453	7	74	1130	10767	\N	\N	52.950609999999998	"Ульяновская область, Радищевский район, с. Дмитриевка, адрес помещения для голосования: МУК ""Центральный поселенческий Дом культуры"", зал, адрес УИК: кабинет администрации МО Дмитриевское СП"		0101000020E6100000D0B8702024DB474012A0A696AD794A40
7454	7	74	1130	10811	\N	\N	52.993938999999997	Ульяновская область, Радищевский район,  п. Гремячий, зал сельского клуба		0101000020E61000000EA48B4D2BD94740069CA564397F4A40
7458	7	74	1130	11007	\N	\N	52.860678999999998	Ульяновская область, Радищевский район, с. Вязовка, зал сельского Дома культуры		0101000020E61000006E8786C5A82F48404FADBEBA2A6E4A40
80051	7	72	393	15863	47900	\N	53.606752	село Савруха, Центральная Усадьба, 33		0101000020E6100000E7A7380EBCD849402C64AE0CAACD4A40
7468	7	74	1130	11455	\N	\N	53.013235000000002	Ульяновская область, Радищевский район, с. Волчанка, кабинет начальной общеобразовательной школы		0101000020E6100000E5EE737CB4124840CF143AAFB1814A40
7467	7	74	1130	11389	\N	\N	52.857764000000003	Ульяновская область, Радищевский район, п. Володарский, зал сельского клуба		0101000020E6100000512D228AC91D4840D4D7F335CB6D4A40
7457	7	74	1130	10935	\N	\N	53.013809999999999	Ульяновская область, Радищевский район, п. Вишневый, кабинет ФАПа		0101000020E6100000CF488446B0214840CB2DAD86C4814A40
7463	7	74	1130	11198	\N	\N	52.964215000000003	Ульяновская область, Радищевский район, с. Верхняя Маза, адрес помещения для голосования: зал сельского Дома культуры, адрес УИК: кабинет администратора сёл		0101000020E6100000DA1F28B7EDF7474005A8A9656B7B4A40
7450	7	74	1130	10634	\N	\N	52.890282999999997	Ульяновская область, Радищевский район, с.  Адоевщина, адрес помещения для голосования: начальная общеобразовательная школа, фойе, адрес УИК: кабинет администратора села		0101000020E61000007E737FF5B8DD4740A69718CBF4714A40
7442	7	74	1044	10224	47609	\N	52.604554999999998	Ульяновская область, Павловский район, с. Шиковка, адрес помещения для голосования: ул. Молодежная, д. 22, Адрес УИК: ул. Центральная, д. 162		0101000020E610000004A9143B1AB347400FD1E80E624D4A40
7439	7	74	1044	10085	47280	\N	52.625753000000003	Ульяновская область, Павловский район, с. Шаховское, ул. Советская, д. 103		0101000020E61000001CCD91955FA24740DC2F9FAC18504A40
7426	7	74	1044	9400	47323	\N	52.624059000000003	Ульяновская область, Павловский район, с. Шалкино, ул. Центральная, д. 15		0101000020E610000027DBC01DA887474022E3512AE14F4A40
7435	7	74	1044	9881	47349	\N	52.847943000000001	Ульяновская область, Павловский район, с. Холстовка, ул. Центральная, д. 14/6		0101000020E6100000D3BD4EEACB9C4740A2EF6E65896C4A40
94440	7	74	1044	10275	47368	\N	52.730420000000002	Ульяновская область, Павловский район, с. Татарский Шмалак, ул. Центральная, 5 Муниципальное учреждение культуры «Татарско-Шмалакский центральный сельский Дом культуры», фойе		0101000020E6100000AE65321CCF7F4740132C0E677E5D4A40
7431	7	74	1044	9668	47529	\N	52.870061999999997	Ульяновская область, Павловский район, с. Старый Пичеур, ул. Школьная, д.1		0101000020E6100000AD307DAF2188474005BF0D315E6F4A40
7434	7	74	1044	9801	47530	\N	52.896357000000002	Ульяновская область, Павловский район, с. Старое Чирково, адрес помещения для голосования: ул. Заречная, д. 1, Адрес УИК: ул. Первомайская, д. 35		0101000020E6100000D427B9C3267C4740354580D3BB724A40
7429	7	74	1044	9560	47472	\N	52.658282999999997	Ульяновская область, Павловский район, д. Плетьма, ул. Молодежная, д. 1		0101000020E610000009151C5E106F4740A2410A9E42544A40
7421	7	74	1044	9157	46958	\N	52.687125999999999	Ульяновская область, Павловский район, р.п. Павловка, адрес помещения для голосования:  пл. Советская, д. 1, Адрес УИК: ул. Ленина, д. 83		0101000020E61000005038BBB54C9247409B1DA9BEF3574A40
7420	7	74	1044	9157	46890	\N	52.687125999999999	Ульяновская область, Павловский район, р.п. Павловка, ул. Школьная, д. 2		0101000020E61000005038BBB54C9247409B1DA9BEF3574A40
7419	7	74	1044	9157	46952	\N	52.687125999999999	Ульяновская область, Павловский район, р.п. Павловка, ул. Калинина, д.33		0101000020E61000005038BBB54C9247409B1DA9BEF3574A40
7438	7	74	1044	10003	47350	\N	52.743855000000003	Ульяновская область, Павловский район, с. Октябрьское, ул. Центральная, д. 9		0101000020E6100000207EFE7BF0904740A9FB00A4365F4A40
7437	7	74	1044	9985	47532	\N	52.801734000000003	Ульяновская область, Павловский район, д. Новая Камаевка, ул. Новая, д. 2		0101000020E6100000AC014A438D964740AF0B3F389F664A40
7441	7	74	1044	10184	47480	\N	52.645181999999998	Ульяновская область, Павловский район, д. Новая Андреевка, ул. Садовая, д. 66		0101000020E6100000374F75C8CDB04740E3FBE25295524A40
7433	7	74	1044	9788	47412	\N	52.833371	Ульяновская область, Павловский район, с. Новая Алексеевка, ул. Новая, д. 34		0101000020E61000005E6397A8DE8E4740A837A3E6AB6A4A40
7428	7	74	1044	9505	47348	\N	52.686078000000002	Ульяновская область, Павловский район, с. Муратовка, ул. Колхозная, д. 20		0101000020E6100000501BD5E940724740A7406667D1574A40
7445	7	74	1044	10382	47478	\N	52.792085999999998	Ульяновская область, Павловский район, с. Мордовский Шмалак, ул. Школьная, д. 63		0101000020E6100000300F99F2217E47404ACFF41263654A40
7432	7	74	1044	9690	47416	\N	52.853349000000001	Ульяновская область, Павловский район, д. Лапаевка, ул. Верхняя, д. 6		0101000020E610000017D522A29882474083893F8A3A6D4A40
7425	7	74	1044	9380	47527	\N	52.666252	Ульяновская область, Павловский район, с. Кадышевка, ул. А.Новикова, д. 1		0101000020E610000052F355F2B19B47408272DBBE47554A40
7424	7	74	1044	9315	47607	\N	52.596623999999998	Ульяновская область, Павловский район, с. Илюшкино, адрес помещения для голосования: ул. Саратовская, д. 20, Адрес УИК: ул. Центральная, д. 53		0101000020E6100000321D3A3DEF8C47401D01DC2C5E4C4A40
7436	7	74	1044	9898	47533	\N	52.823658999999999	Ульяновская область, Павловский район, д. Ивановка, ул. Вторая, д. 26		0101000020E6100000573ECBF3E09A47402D077AA86D694A40
7423	7	74	1044	9298	47586	\N	52.737051000000001	Ульяновская область, Павловский район, с. Евлейка, ул. Центральная, д.46		0101000020E6100000E5D022DBF99C4740F73DEAAF575E4A40
7440	7	74	1044	10106	47475	\N	52.62706	Ульяновская область, Павловский район, п. Гремучий, ул. Луговая, д.5		0101000020E610000011FE45D098AD47409C50888043504A40
7427	7	74	1044	9470	47528	\N	52.676648999999998	Ульяновская область, Павловский район, с. Баклуши, ул. Рабочая, д. 2		0101000020E61000004DF910548D74474080EF366F9C564A40
7418	7	74	660	9070	47476	\N	53.242258	Ульяновская область, Новоспасский район, п. Фабричные Выселки, ул. Запрудная, д. 4		0101000020E610000077BE9F1A2FEF4740E198654F029F4A40
7414	7	74	660	8870	\N	\N	53.284478999999997	Ульяновская область, Новоспасский район, с. Троицкий Сунгур, Троицкосунгурский КДЦ		0101000020E6100000AA46AF0628CF47400BB3D0CE69A44A40
7403	7	74	660	8409	\N	\N	53.089136000000003	Ульяновская область, Новоспасский район, с. Суруловка, Сельский дом культуры		0101000020E6100000C100C28712DF4740B972F6CE688B4A40
7406	7	74	660	8520	47605	\N	53.188287000000003	Ульяновская область, Новоспасский район, с. Старое Томышево, ул. Школьная, д. 43		0101000020E6100000E814E46723F3474088A1D5C919984A40
7412	7	74	660	8800	47526	\N	53.14537	Ульяновская область, Новоспасский район, с. Свирино, ул. Почтовая, д. 16		0101000020E61000001764CBF275CB4740E6E8F17B9B924A40
7416	7	74	660	8972	47524	\N	53.278934	Ульяновская область, Новоспасский район, с. Самайкино, ул. Молодежная, д. 1	Россия, Ульяновская область, Новоспасский район, село Самайкино	0101000020E610000006802A6EDCE8474009DFFB1BB4A34A40
7411	7	74	660	55794	47378	\N	53.129820358343103	Ульяновская область, Новоспасский район, с. Садовое, ул. Школьная, д. 28	Россия, Ульяновская область, Новоспасский район, село Садовое	0101000020E61000007D24253D0CD34740F12E17F19D904A40
7326	7	74	660	4485	\N	\N	53.224966999999999	Ульяновская область, Новоспасский район, д. Рокотушка, Клуб		0101000020E6100000DFDFA0BDFAD84740F1D6F9B7CB9C4A40
7409	7	74	660	8691	47294	\N	53.162255999999999	Ульяновская область, Новоспасский район, с. Репьевка, ул. Школьная, д. 67		0101000020E6100000F451465C000C484036CAFACDC4944A40
7417	7	74	660	9042	47473	\N	53.249122	Ульяновская область, Новоспасский район, п. Плодопитомник, ул. Центральная, д. 21		0101000020E61000007959130B7CED4740685BCD3AE39F4A40
7399	7	74	660	7937	47086	\N	53.148006000000002	Ульяновская область, Новоспасский район, р.п. Новоспасское, пл. Макаренко, д. 1		0101000020E61000006C921FF12BE047404FCE50DCF1924A40
7395	7	74	660	7937	47284	\N	53.148006000000002	Ульяновская область, Новоспасский район, р.п. Новоспасское, пос. Сельхозтехника, д. 5		0101000020E61000006C921FF12BE047404FCE50DCF1924A40
7397	7	74	660	7937	46886	\N	53.148006000000002	Ульяновская область, Новоспасский район, р.п. Новоспасское, ул. Мира, д. 23		0101000020E61000006C921FF12BE047404FCE50DCF1924A40
7394	7	74	660	7937	46953	\N	53.148006000000002	Ульяновская область, Новоспасский район, р.п.  Новоспасское, ул. Кузнецкая, д. 104а		0101000020E61000006C921FF12BE047404FCE50DCF1924A40
7398	7	74	660	7937	47032	\N	53.148006000000002	Ульяновская область, Новоспасский район, р.п. Новоспасское, ул. Горького, д. 11а		0101000020E61000006C921FF12BE047404FCE50DCF1924A40
7396	7	74	660	7937	47471	\N	53.148006000000002	Ульяновская область, Новоспасский район, р.п. Новоспасское, ул. Горшенина, д. 15		0101000020E61000006C921FF12BE047404FCE50DCF1924A40
7401	7	74	660	7937	47522	\N	53.148006000000002	Ульяновская область, Новоспасский район, р.п. Новоспасское, ул. Гагарина, д. 64		0101000020E61000006C921FF12BE047404FCE50DCF1924A40
7389	7	74	660	7703	\N	\N	53.151699999999998	Ульяновская область, Новоспасский район, с. Новое Томышево, Сельский дом культуры		0101000020E6100000062D246074F34740CF66D5E76A934A40
7413	7	74	660	8858	47477	\N	53.052619999999997	Ульяновская область, Новоспасский район, с. Новая Лава, ул. Молодежная, д. 31		0101000020E6100000AEEFC34142C64740C98E8D40BC864A40
7402	7	74	660	8326	\N	\N	53.144755000000004	Ульяновская область, Новоспасский район, д. Малая Андреевка, Сельский клуб		0101000020E61000008925E5EE73E847405C77F35487924A40
7408	7	74	660	8611	47523	\N	53.151958999999998	Ульяновская область, Новоспасский район, п. Крупозавод, ул. Центральная, д. 23		0101000020E610000003250516C01048409BAA7B6473934A40
7410	7	74	660	8696	47584	\N	53.144154999999998	Ульяновская область, Новоспасский район, п. Красный, ул. Урожайная, д. 2		0101000020E610000027F6D03E560848400647C9AB73924A40
7407	7	74	660	8588	47082	\N	53.173824000000003	Ульяновская область, Новоспасский район, п. Красносельск, ул. Школьная, д. 13		0101000020E61000008884EFFD0D10484045A165DD3F964A40
7405	7	74	660	8484	47304	\N	53.181693000000003	Ульяновская область, Новоспасский район, с. Коптевка, ул. Ленина, д. 45а		0101000020E6100000518369183EF84740C1745AB741974A40
7415	7	74	660	8949	\N	\N	53.282131999999997	Ульяновская область, Новоспасский район, с. Комаровка, Филиал МУК Троицкосунгурский КДЦ		0101000020E61000008368AD6873DC4740D993C0E61CA44A40
7404	7	74	660	8430	47470	\N	53.289200000000001	Ульяновская область, Новоспасский район, с. Алакаевка, ул. Советская, д. 64		0101000020E610000054A86E2EFEFA474069006F8104A54A40
7381	7	74	892	7349	47585	\N	54.174765000000001	Ульяновская область, Новомалыклинский район, с. Эчкаюн, ул. Молодежная, д. 16		0101000020E61000008A8F4FC8CE13494023BE13B35E164B40
7388	7	74	892	7646	47525	\N	54.328654	Ульяновская область, Новомалыклинский район, с. Старый Сантимир, ул. Центральная, д. 36		0101000020E6100000C4D2C08F6A0849408CD99255112A4B40
7385	7	74	892	7543	47320	\N	54.307397314970601	Ульяновская область, Новомалыклинский район, с. Старая Тюгальбуга, адрес помещения для голосования: ул. Кооперативная, д. 37, адрес УИК: ул. Кооперативная, д. 31	Россия, Ульяновская область, Новомалыклинский район, село Старая Тюгальбуга	0101000020E6100000B267CF656A144940BBF1EEC858274B40
7393	7	74	892	7894	47613	\N	54.227111999999998	Ульяновская область, Новомалыклинский район, с. Старая Малыкла, ул. Центральная, д. 40		0101000020E6100000596C938AC6EA4840BB438A01121D4B40
7379	7	74	892	7264	47411	\N	54.224547999999999	Ульяновская область, Новомалыклинский район, с. Старая Куликовка, ул. Совхозная, д. 21		0101000020E61000007689EAAD81FD4840EC3026FDBD1C4B40
7387	7	74	892	7626	47520	\N	54.296514000000002	Ульяновская область, Новомалыклинский район, с. Старая Бесовка, ул. Колхозная, д. 45		0101000020E6100000D8B628B341FC48403067B62BF4254B40
95167	7	74	892	55839	47642	\N	54.195885298993304	"Ульяновская область, Новомалыклинский район, с. Станция Якушка, ул. Кооперативная, д.8 Дом культуры (ДК) - фойе "	Россия, Ульяновская область, Новомалыклинский район, село Станция Якушка	0101000020E6100000CFA10C55310B494073637AC212194B40
7392	7	74	892	7818	47319	\N	54.167023	Ульяновская область, Новомалыклинский район, с. Средняя Якушка, ул. Октябрьская, д. 15А		0101000020E6100000570740DCD5E748400457790261154B40
7386	7	74	892	7564	47293	\N	54.27384	Ульяновская область, Новомалыклинский район, с. Средний Сантимир, ул. Школьная, д. 1		0101000020E6100000CD5B751DAA0B4940172B6A300D234B40
7383	7	74	892	7439	46948	\N	54.363675000000001	Ульяновская область, Новомалыклинский район, с. Новочеремшанск, адрес помещения для голосования: ул. Заводская, д. 51, адрес УИК: ул. Заводская, д. 4		0101000020E610000057EA5910CA134940B8AF03E78C2E4B40
7384	7	74	892	7439	46950	\N	54.363675000000001	Ульяновская область, Новомалыклинский район, с. Новочеремшанск, адрес помещения для голосования: ул. Дорожная, д. 5, адрес УИК: ул. Заводская, д. 4		0101000020E610000057EA5910CA134940B8AF03E78C2E4B40
7378	7	74	892	7156	46947	\N	54.199905999999999	Ульяновская область, Новомалыклинский район, с. Новая Малыкла, адрес помещения для голосования: ул. Советская, д. 70, адрес УИК: ул. Советская, д. 24		0101000020E6100000265646239FF748401823128596194B40
7377	7	74	892	7156	46973	\N	54.199905999999999	Ульяновская область, Новомалыклинский район, с. Новая Малыкла, адрес помещения для голосования: ул. Кооперативная, д. 51, адрес УИК: ул. Советская, д. 24		0101000020E6100000265646239FF748401823128596194B40
7375	7	74	892	7063	47387	\N	54.126494000000001	Ульяновская область, Новомалыклинский район, с. Новая Куликовка, ул. Советская, д. 16		0101000020E61000006A183E22A6064940F39194F430104B40
7374	7	74	892	6994	47517	\N	54.125529	Ульяновская область, Новомалыклинский район, с. Новая Бесовка, ул. Колхозная, д. 5	Россия, Ульяновская область, Новомалыклинский район, село Новая Бесовка	0101000020E6100000B83A00E2AE1249408CD9925511104B40
7391	7	74	892	7807	47582	\N	54.209749000000002	Ульяновская область, Новомалыклинский район, с. Нижняя Якушка, адрес помещения для голосования:  ул. Молодежная, д. 2А, адрес УИК: ул. Советская, д. 11А		0101000020E61000009A6038D730E5484032AF230ED91A4B40
7373	7	74	892	6969	47479	\N	54.069623999999997	Ульяновская область, Новомалыклинский район, с. Елховый Куст, адрес помещения для голосования: ул. Центральная, д. 29, адрес УИК: ул. Центральная, д.25	Россия, Ульяновская область, Новомалыклинский район, село Елховый Куст	0101000020E6100000CAC0012D5DFD484023827170E9084B40
7372	7	74	892	6893	47516	\N	54.076338999999997	Ульяновская область, Новомалыклинский район, с. Высокий Колок, адрес помещения для голосования: ул. Братьев Кипкаевых, д.57, адрес УИК: ул. Братьев Кипкаевых, д. 68		0101000020E6100000BA4BE2AC880C49406534F279C5094B40
7382	7	74	892	7389	47413	\N	54.304268999999998	Ульяновская область, Новомалыклинский район, с. Вороний Куст, ул. Центральная, д. 24		0101000020E61000005186AA984A194940E3175E49F2264B40
95168	7	74	892	7715	47488	\N	54.129443999999999	Ульяновская область, Новомалыклинский район, с. Верхняя Якушка, адрес помещения для голосования: ул. Советская, д. 25, адрес УИК: ул. Советская, д. 41		0101000020E6100000F949B54FC7EF4840EB54F99E91104B40
7371	7	74	892	55843	47649	\N	54.020205161382997	Ульяновская область, Новомалыклинский район, с. Абдреево, ул. 50 Лет Победы, д. 63	Россия, Ульяновская область, Новомалыклинский район, село Андреево	0101000020E6100000BAA3FFE55A0449409B1BD31396024B40
7376	7	74	892	7100	47583	\N	54.215046000000001	Ульяновская область, Новомалыклинский район, с. Александровка, ул. Центральная, д. 6		0101000020E6100000BE4F55A1810649405C9198A0861B4B40
7365	7	74	154	6602	47467	\N	53.304388000000003	Ульяновская область, Николаевский район, с. Эзекеево, ул. Центральная, д. 73		0101000020E6100000266F8099EF804740BEA59C2FF6A64A40
7366	7	74	154	55829	47626	\N	53.299744654631802	Ульяновская область, Николаевский район, с. Чувашский Сайман, адрес помещения для голосования ул. Школьная, д. 19, адрес УИК: ул. Молодежная, д. 5	Россия, Ульяновская область, Николаевский район, село ЧувашскийСайман	0101000020E61000003718EAB0C28D4740DC114E0B5EA64A40
7351	7	74	154	5856	47577	\N	53.281846999999999	Ульяновская область, Николаевский район, с. Топорнино, ул. Советская, д. 100		0101000020E6100000D8F4A0A0149D4740E4BCFF8F13A44A40
7347	7	74	154	5647	47579	\N	53.231301000000002	Ульяновская область, Николаевский район, с. Тепловка, пер. Школьный, д. 1		0101000020E6100000D2E1218C9FB647401C446B459B9D4A40
7346	7	74	154	5570	47408	\N	53.016382999999998	Ульяновская область, Николаевский район, с. Телятниково, адрес помещения для голосования: ул. Центральная, д. 12, адрес УИК: ул. Центральная, д. 14		0101000020E61000005663096B63A24740ED9A90D618824A40
7363	7	74	154	6482	46883	\N	53.292484000000002	Ульяновская область, Николаевский район, с. Татарский Сайман, адрес помещения для голосования: ул. Советская, д. 112, адрес УИК: ул. Советская, д. 93		0101000020E6100000A4AA09A2EE8F4740384D9F1D70A54A40
7369	7	74	154	6785	47407	\N	52.980077000000001	Ульяновская область, Николаевский район, с. Сухая Терешка, ул. Николаевская, д. 3		0101000020E6100000A06B5F402FBE4740E947C329737D4A40
7367	7	74	154	6692	46884	\N	52.958427	Ульяновская область, Николаевский район, с. Славкино, адрес помещения для голосования: ул. Узкоколейная, д. 63, адрес УИК: ул. Больничная, д. 37		0101000020E6100000BFD4CF9B8A9647403C4D66BCAD7A4A40
7360	7	74	154	6292	47518	\N	53.190499000000003	Ульяновская область, Николаевский район, с. Рызлей, ул. Афанасьева, д. 23		0101000020E6100000FF04172B6A7C4740DA756F4562984A40
7364	7	74	154	6515	47410	\N	53.306885000000001	Ульяновская область, Николаевский район, с. Поспеловка, ул. Школьная, д. 11		0101000020E6100000FD84B35BCB8647400551F70148A74A40
80049	7	72	393	15771	48220	\N	53.750999	село Рысайкино, Ижедерова, 59		0101000020E610000057CEDE196D1D4A40132A38BC20E04A40
7341	7	74	154	5320	47466	\N	53.189641000000002	Ульяновская область, Николаевский район, с. Поника, ул. Молодежная, д. 10		0101000020E610000057EC2FBB27934740897D022846984A40
7362	7	74	154	55837	47640	\N	53.153142766016501	Ульяновская область, Николаевский район, п. Станция Никулино, ул. Железнодорожная, д. 10	Россия, Ульяновская область, Николаевский район, поселок Никулино	0101000020E61000004BC8073D9B874740404E98309A934A40
7359	7	74	154	6259	47519	\N	53.1678	Ульяновская область, Николаевский район, с. Никулино, ул. Путиловка, д. 3		0101000020E610000013D55B035B87474068226C787A954A40
7336	7	74	154	55764	47163	\N	53.131467142828001	Ульяновская область, Николаевский район, р.п. Николаевка, пл. Ленина, д. 7		0101000020E6100000CB863595459B47406AC020E9D3904A40
7913	7	74	154	55764	47644	\N	53.130176580554398	Ульяновская область, Николаевский район, р.п. Николаевка, ул. Узкоколейная, 29	Россия, Ульяновская область, Николаевский район, поселок Николаевка	0101000020E6100000D89DEE3CF19A474080D8D2A3A9904A40
7335	7	74	154	55764	47133	\N	53.130627576000997	Ульяновская область, Николаевский район, р.п. Николаевка, ул. Советская, д. 56	Россия, Ульяновская область, Николаевский район, поселок Николаевка	0101000020E61000009CC3B5DAC39A474090F8156BB8904A40
7338	7	74	154	55764	47029	\N	53.127543712745499	Ульяновская область, Николаевский район, р.п. Николаевка, ул. Комсомольская, д. 17	Россия, Ульяновская область, Николаевский район, поселок Николаевка	0101000020E6100000055262D7F69A474088669E5C53904A40
7337	7	74	154	55764	47321	\N	53.124859053188402	Ульяновская область, Николаевский район, р.п. Николаевка, ул. Коммунальная, д. 67	Россия, Ульяновская область, Николаевский район, поселок Николаевка	0101000020E610000088F19A57759C47403ECE3461FB8F4A40
7912	7	74	154	55764	47647	\N	53.128576229243997	Ульяновская область, Николаевский район, р.п. Николаевка, ул. Гагарина,11	Россия, Ульяновская область, Николаевский район, поселок Николаевка	0101000020E6100000EA76F695079D47407786A92D75904A40
7370	7	74	154	6819	47521	\N	53.082639999999998	Ульяновская область, Николаевский район, с. Куроедово, ул. Старая, д. 52		0101000020E61000009FC893A46BB84740B4AB90F2938A4A40
7358	7	74	154	6181	47468	\N	53.130201999999997	Ульяновская область, Николаевский район, с. Курмаевка, ул. Школьная, д. 22		0101000020E61000008C82E0F1ED7B4740D8EF8975AA904A40
7356	7	74	154	6101	47317	\N	53.143344999999997	Ульяновская область, Николаевский район, п. Крутец, адрес помещения для голосования: ул. Центральная, д. 23а, адрес УИК: ул. Молодежная, д. 12	Россия, Ульяновская область, Николаевский район, село Крутец	0101000020E610000080828B1535B44740C685032159924A40
7349	7	74	154	5713	47509	\N	53.292382000000003	Ульяновская область, Николаевский район, с. Кравково, ул. Центральная, д. 28		0101000020E6100000581AF8510DA7474034F8FBC56CA54A40
7556	7	74	154	15626	47424	\N	53.285884000000003	Ульяновская область, Сурский район, с. Кезьмино, адрес помещения для голосования: ул. Советская, д. 1, адрес УИК: ул. Новая, д. 1		0101000020E61000001825E82FF49847408F39CFD897A44A40
7350	7	74	154	5789	47510	\N	53.331187	Ульяновская область, Николаевский район, с. Канасаево, ул. Центральная, д. 33		0101000020E61000008D60E3FA77BB474020EEEA5564AA4A40
7353	7	74	154	6052	47639	\N	53.164907549748001	Ульяновская область, Николаевский район, с. Мордовский Канадей, ул. Центральная, д. 39	Россия, Ульяновская область, Николаевский район, поселок Канадей	0101000020E61000006150A6D1E4C24740A46C91B41B954A40
7355	7	74	154	6052	46881	\N	53.165463000000003	Ульяновская область, Николаевский район, с. Канадей, ул. Лесная, д. 16		0101000020E61000007E5358A9A0C247405AD93EE42D954A40
7352	7	74	154	5864	47512	\N	53.088503000000003	Ульяновская область, Николаевский район, с. Дубровка, ул. Нижняя, д. 29		0101000020E610000068E89FE062834740884CF910548B4A40
7343	7	74	154	5390	47337	\N	53.068201000000002	Ульяновская область, Николаевский район, с. Давыдовка, адрес помещения для голосования: ул. Новая, д. 4, адрес УИК: ул. Новая, д. 6		0101000020E6100000F2ED5D83BE944740FA4674CFBA884A40
7345	7	74	154	5532	47581	\N	53.064369999999997	Ульяновская область, Николаевский район, с. Губашево, ул. Школьная, д. 4а		0101000020E61000002A3BFDA02E8E4740F86BB2463D884A40
7348	7	74	154	5707	47511	\N	53.280586999999997	Ульяновская область, Николаевский район, с. Головино, адрес помещения для голосования: ул. Почтовая, д. 34, адрес УИК: ул. Советская, д. 12		0101000020E6100000E8A38CB800AE474064575A46EAA34A40
7357	7	74	154	6180	46885	\N	53.147973999999998	Ульяновская область, Николаевский район, с. Большой Чирклей, ул. Советская, д. 140		0101000020E6100000A75CE15D2E8247404354E1CFF0924A40
7344	7	74	154	5466	47614	\N	53.022862000000003	Ульяновская область, Николаевский район, с. Болдасьево, ул. Центральная, д. 39		0101000020E6100000C904FC1A498E47401C295B24ED824A40
7354	7	74	154	55805	47419	\N	53.022484188425501	Ульяновская область, Николаевский район, п. Белое Озеро, ул. Приозерная, д. 19	Россия, Ульяновская область, Николаевский район, село Белое Озеро	0101000020E6100000E8D84125AE7D4740755776C1E0824A40
7342	7	74	154	5362	47335	\N	53.019671000000002	Ульяновская область, Николаевский район, с. Барановка, ул. Советская, д. 54	Россия, Ульяновская область, Николаевский район, село Барановка	0101000020E610000025B03907CF944740FED64E9484824A40
7340	7	74	154	5226	47030	\N	53.093904999999999	Ульяновская область, Николаевский район, с. Баевка, адрес помещения для голосования: ул. Юдина, д. 17, адрес УИК: ул. Советская, д. 1		0101000020E610000065E08096AEA0474027F73B14058C4A40
7361	7	74	154	6387	47347	\N	53.235737	Ульяновская область, Николаевский район, с. Ахметлей, ул. Средняя, д. 35а		0101000020E6100000FB5B02F04F7F474084BA48A12C9E4A40
7368	7	74	154	6708	47580	\N	52.965777000000003	Ульяновская область, Николаевский район, с. Андреевка, ул. Центральная, д. 17		0101000020E61000007636E49F198A4740501DAB949E7B4A40
7293	7	74	411	2697	47573	\N	54.103012999999997	Ульяновская область, Мелекесский район, п. Щербаковка, ул. Школьная, д. 9		0101000020E6100000EE5D83BEF4F048400B08AD872F0D4B40
7320	7	74	411	4192	47405	\N	53.879939	Ульяновская область, Мелекесский район, с. Чувашский Сускан, ул. Дзержинского, д. 24/1		0101000020E6100000EC8502B6839B4840CBBC55D7A1F04A40
7292	7	74	411	55834	47636	\N	54.177100360084196	Ульяновская область, Мелекесский район, п. Чёрная Речка, ул. Лесная, д. 23	Россия, Ульяновская область, Мелекесский район, село Черная Речка	0101000020E6100000F374AE2825E04840910F7A36AB164B40
7312	7	74	411	3770	47275	\N	54.001426000000002	Ульяновская область, Мелекесский район, с. Филипповка, ул. Куйбышева, д. 1		0101000020E61000002F6EA301BCE148409BAE27BA2E004B40
7309	7	74	411	3609	47469	\N	53.907423999999999	Ульяновская область, Мелекесский район, п. Уткин, ул. Труда, д. 2		0101000020E61000003B8908FF22D2484081CD397826F44A40
7334	7	74	411	4955	47508	\N	54.499071999999998	Ульяновская область, Мелекесский район, с. Тинарка, ул. Набережная, д. 63		0101000020E61000003E23111AC1CC4840B62C5F97E13F4B40
95166	7	74	411	4622	41930	\N	54.3886679144562	Ульяновская область, Мелекесский район, с. Тиинск, адрес помещения для голосования: ул. Площадь Советов, д. 1, МУК ЦКД, фойе, 1 этаж, адрес УИК: ул. Площадь Советов, д. 1	Россия, Ульяновская область, Мелекесский район, село Тиинск	0101000020E6100000446D1B4641D2484039807EDFBF314B40
7333	7	74	411	4862	47515	\N	54.385874999999999	Ульяновская область, Мелекесский район, с. Терентьевка, ул. Центральная, д. 20		0101000020E6100000676490BB08E1484008AC1C5A64314B40
7300	7	74	411	3116	47398	\N	54.054997	Ульяновская область, Мелекесский район, с. Степная Васильевка, ул. Набережная, д. 2		0101000020E610000052F355F2B1C14840663046240A074B40
7327	7	74	411	49157	47506	\N	54.375124999999997	Ульяновская область, Мелекесский район, с. Старый Письмирь, ул. Новая, д. 1		0101000020E61000007A8CF2CCCBF34840BC74931804304B40
7321	7	74	411	4233	47291	\N	54.421354999999998	Ульяновская область, Мелекесский район, с. Старая Сахча, ул. Комсомольская, д. 60	Россия, Ульяновская область, Мелекесский район, село Старая Сахча	0101000020E6100000F6D37FD6FCF84840C780ECF5EE354B40
7332	7	74	411	55833	47635	\N	54.353858979964201	Ульяновская область, Мелекесский район, с. Слобода-Выходцево, ул. Центральная, д. 43	Россия, Ульяновская область, Мелекесский район, село Слобода Выходцева	0101000020E61000009EEE3CF19CD34840983270404B2D4B40
7298	7	74	411	2944	47316	\N	54.143901999999997	Ульяновская область, Мелекесский район, с. Сабакаево, ул. Мелиоративная, д. 1		0101000020E6100000ED2AA4FCA4D448401CEA77616B124B40
7297	7	74	411	2944	46946	\N	54.143901999999997	Ульяновская область, Мелекесский район, с. Сабакаево, адрес помещения для голосования: ул. Победы, д. 13, адрес УИК: ул. Ленина, д. 6		0101000020E6100000ED2AA4FCA4D448401CEA77616B124B40
7314	7	74	411	3871	46879	\N	53.981828999999998	Ульяновская область, Мелекесский район, с. Рязаново, адрес помещения для голосования: ул. Октябрьская, д. 10, адрес УИК ул. Октябрьская, д. 5		0101000020E61000001955867137B44840D7A19A92ACFD4A40
7331	7	74	411	4782	47344	\N	54.307499999999997	Ульяновская область, Мелекесский район, с. Русский Мелекесс, адрес помещения для голосования: ул. Школьная, д.5, адрес УИК: ул. Строителей, д. 7		0101000020E61000003ECBF3E0EEC448408FC2F5285C274B40
7308	7	74	411	3559	47463	\N	53.868445999999999	Ульяновская область, Мелекесский район, п. Просторы, ул. Майская, д. 11		0101000020E6100000B6F5D37FD6F44840C72B103D29EF4A40
7296	7	74	411	2886	47404	\N	54.055968999999997	Ульяновская область, Мелекесский район, с. Приморское, ул. Мира, д. 45		0101000020E61000003733FAD170BA48407F4B00FE29074B40
7305	7	74	411	3403	46878	\N	53.90213	Ульяновская область, Мелекесский район, п. Новосёлки, ул. Крупской, д. 11		0101000020E61000001079CBD58FE14840C85EEFFE78F34A40
7313	7	74	411	3807	47578	\N	54.4604	Ульяновская область, Мелекесский район, с. Новая Сахча, ул. Черемшанская, д. 24		0101000020E6100000F030ED9BFB014940098A1F63EE3A4B40
7288	7	74	411	2422	46944	\N	54.149107999999998	Ульяновская область, Мелекесский район, р.п. Новая Майна, адрес помещения для голосования: ул. Шутова, д. 1, адрес УИК: ул. Советская, д. 6		0101000020E61000006C921FF12BE0484036C98FF815134B40
7290	7	74	411	2422	46993	\N	54.149107999999998	Ульяновская область, Мелекесский район, р.п. Новая Майна, адрес помещения для голосования: ул. Новая, д. 2а, адрес УИК: ул. Микрорайон, д. 11		0101000020E61000006C921FF12BE0484036C98FF815134B40
7289	7	74	411	2422	46993	\N	54.149107999999998	Ульяновская область, Мелекесский район, р.п. Новая Майна, адрес помещения для голосования: ул. Новая, д. 2а, адрес УИК: ул. Микрорайон, д. 8		0101000020E61000006C921FF12BE0484036C98FF815134B40
7302	7	74	411	3241	46877	\N	54.053998	Ульяновская область, Мелекесский район, с. Никольское-на-Черемшане, адрес помещения для голосования: ул. Ленина, д. 59, адрес УИК: ул. Мира, д. 4		0101000020E6100000BA66F2CD3697484053060E68E9064B40
7285	7	74	411	2193	46942	\N	54.205241999999998	Ульяновская область, Мелекесский район, р.п. Мулловка, адрес помещения для голосования: ул. Советская, д. 65, адрес УИК: ул. Советская, д. 63		0101000020E61000008ECC237F30B2484000E2AE5E451A4B40
7284	7	74	411	2193	46941	\N	54.205241999999998	Ульяновская область, Мелекесский район, р.п. Мулловка, ул. Победы, д. 9		0101000020E61000008ECC237F30B2484000E2AE5E451A4B40
7286	7	74	411	2193	47049	\N	54.205241999999998	Ульяновская область, Мелекесский район, р.п. Мулловка, адрес помещения для голосования: ул. Красноармейская, д. 2, адрес УИК: ул. Маркова, д. 7		0101000020E61000008ECC237F30B2484000E2AE5E451A4B40
7311	7	74	411	3714	47608	\N	53.978180999999999	Ульяновская область, Мелекесский район, с. Мордово-Озеро, ул. Клубная, д. 2		0101000020E6100000B4CBB73EACD94840C748F60835FD4A40
7310	7	74	411	3672	47604	\N	54.046723999999998	Ульяновская область, Мелекесский район, с. Моисеевка, ул. Школьная, д. 34		0101000020E61000009E7DE5417AE048401AF8510DFB054B40
7287	7	74	411	2373	9681	\N	54.258379623300002	Ульяновская область, Мелекесский район, п. Лесной, ул. Дорожная, д. 5	Россия, Ульяновская область, Мелекесский район, село Лесной	0101000020E6100000BFF2203D4596484062F8889812214B40
7330	7	74	411	4752	47292	\N	54.52749	Ульяновская область, Мелекесский район, с. Лесная Хмелевка, адрес помещения для голосования: ул. Мираксовой, д. 6, адрес УИК:ул. Мираксовой, д. 4		0101000020E6100000DE019EB470D54840C87BD5CA84434B40
7329	7	74	411	4691	47575	\N	54.465412999999998	Ульяновская область, Мелекесский район, с. Лесная Васильевка, ул. Набережная, д. 16		0101000020E61000009DF7FF71C2D448400E1137A7923B4B40
7294	7	74	411	2759	47290	\N	54.122948000000001	Ульяновская область, Мелекесский район, с. Лебяжье, ул. Березовая, д. 3		0101000020E61000006CCD565EF2CD4840E78D93C2BC0F4B40
7301	7	74	411	3181	47574	\N	54.029829999999997	Ульяновская область, Мелекесский район, д. Куликовка, ул. Центральная, д. 2		0101000020E61000005437177FDBBB484047382D78D1034B40
7307	7	74	411	3501	47451	\N	53.988458000000001	Ульяновская область, Мелекесский район, п. Ковыльный, ул. Центральная, д. 7		0101000020E610000006D847A7AEF648401BBCAFCA85FE4A40
7304	7	74	411	3353	47504	\N	54.152329000000002	Ульяновская область, Мелекесский район, п. Кипрей, ул. Гагарина, д. 13		0101000020E610000058E2016553944840BF9D44847F134B40
7303	7	74	411	3295	47400	\N	54.116542000000003	Ульяновская область, Мелекесский район, с. Ерыклинск, ул. Молодежная, д. 2		0101000020E6100000770FD07D39A74840234E27D9EA0E4B40
7319	7	74	411	4140	47464	\N	53.865796000000003	Ульяновская область, Мелекесский район, с. Дубравка, ул. Школьная, д. 36		0101000020E61000001C295B24EDB84840FA804067D2EE4A40
7315	7	74	411	3912	47276	\N	53.941363000000003	Ульяновская область, Мелекесский район, п. Дивный, адрес помещения для голосования: ул.  Советская, д. 31, адрес УИК: ул. Советская, д. 33		0101000020E6100000B4AB90F293BE48400D5531957EF84A40
7318	7	74	411	4041	47505	\N	53.911715000000001	Ульяновская область, Мелекесский район, с. Вишенка, ул. Центральная, д. 35		0101000020E610000074999A046FC64840E622BE13B3F44A40
7306	7	74	411	3461	47399	\N	53.952565	Ульяновская область, Мелекесский район, п. Видный, ул. Центральная, д. 12		0101000020E61000008E59F624B0ED4840392861A6EDF94A40
7291	7	74	411	2590	47503	\N	54.105753	Ульяновская область, Мелекесский район, с. Верхний Мелекесс, ул. Луговая, д. 22		0101000020E61000006D567DAEB6E44840193A7650890D4B40
7324	7	74	411	4385	47576	\N	54.305199000000002	Ульяновская область, Мелекесский район, с. Бригадировка, адрес помещения для голосования: ул. Советская, д. 26, адрес УИК: ул. Советская, д. 5		0101000020E61000001B9DF3531CE34840CEE2C5C210274B40
7323	7	74	411	4356	47406	\N	54.492113000000003	Ульяновская область, Мелекесский район, с. Боровка, ул. Советская, д. 53		0101000020E6100000D61EF64201F94840DE770C8FFD3E4B40
7317	7	74	411	4029	47513	\N	53.919812999999998	Ульяновская область, Мелекесский район, с. Бирля, ул. Гагарина, д. 27	Россия, Ульяновская область, Мелекесский район, село Бирля	0101000020E61000001344DD07209F4840C3B7B06EBCF54A40
7322	7	74	411	4303	47507	\N	54.526083999999997	Ульяновская область, Мелекесский район, с. Аппаково, ул. Комсомольская, д. 3		0101000020E61000000A83328D26F54840747973B856434B40
7295	7	74	411	2828	47453	\N	54.049626000000004	Ульяновская область, Мелекесский район, с. Аллагуллово, ул. Школьная, д. 1	Россия, Ульяновская область, Мелекесский район, село Аллагулово	0101000020E6100000849A215514C9484002840F255A064B40
7316	7	74	411	3952	47342	\N	53.923566999999998	Ульяновская область, Мелекесский район, с. Александровка, адрес помещения для голосования: ул. Советская, д. 25, адрес УИК: ул. Ленина, д. 48		0101000020E6100000889E94490DB348401955867137F64A40
7263	7	74	50	55819	\N	\N	54.167833999999999	Ульяновская область, Майнский район, п. Новоанненковский, здание школы		0101000020E6100000AAF3A8F8BFD347401494A2957B154B40
7278	7	74	50	1838	\N	\N	54.452542999999999	Ульяновская область, Майнский район, с. Чуфарово, здание библиотеки	Россия, Ульяновская область, Майнский район, село Чуфарово	0101000020E610000046B247A819C047405184D4EDEC394B40
7277	7	74	50	1769	\N	\N	54.523294	Ульяновская область, Майнский район, с. Чирикеево, здание школы	Россия, Ульяновская область, Майнский район, село Чирикеево	0101000020E6100000BD8A8C0E48C24740B5183C4CFB424B40
7282	7	74	50	2071	\N	\N	54.289909000000002	Ульяновская область, Майнский район, с. Уржумское, здание школы	Россия, Ульяновская область, Майнский район, село Уржумское	0101000020E61000000DE02D90A0EA474075E8F4BC1B254B40
7279	7	74	50	1878	\N	\N	54.301667999999999	Ульяновская область, Майнский район, с. Тагай, здание Центра культуры и досуга	Россия, Ульяновская область, Майнский район, село Тагай	0101000020E610000028D4D347E0CF4740F71F990E9D264B40
7264	7	74	50	1000	\N	\N	54.158102999999997	Ульяновская область, Майнский район, с. Сущевка, здание школы	Россия, Ульяновская область, Майнский район, село Сущевка	0101000020E6100000AC36FFAF3AB44740223317B83C144B40
7272	7	74	50	1461	\N	\N	53.965026000000002	Ульяновская область, Майнский район, д. Сухаревка, здание ФАП	Россия, Ульяновская область, Майнский район, село Сухаревка	0101000020E6100000DC65BFEE74E3474015E5D2F885FB4A40
7274	7	74	50	1581	\N	\N	53.964691999999999	Ульяновская область, Майнский район, с. Степное Матюнино, здание школы	Россия, Ульяновская область, Майнский район, село Степное Матюнино	0101000020E6100000AF5DDA7058EA47403E5B07077BFB4A40
7275	7	74	50	1681	\N	\N	54.457462999999997	Ульяновская область, Майнский район, с. Старые Маклауши, здание школы	Россия, Ульяновская область, Майнский район, село Старые Маклауши	0101000020E61000003F1EFAEE56BA4740A510C8258E3A4B40
7254	7	74	50	413	\N	\N	53.989919	Ульяновская область, Майнский район, с. Сосновка, здание школы	Россия, Ульяновская область, Майнский район, село Сосновка	0101000020E6100000B933130CE7D24740325871AAB5FE4A40
7283	7	74	50	2136	\N	\N	54.336081999999998	Ульяновская область, Майнский район, с. Сиуч, здание администрации	Россия, Ульяновская область, Майнский район, село Сиуч	0101000020E61000009DBB5D2F4DE347401B6327BC042B4B40
7253	7	74	50	55802	\N	\N	53.879561479789302	Ульяновская область, Майнский район, п. Родниковые Пруды, здание школы	Россия, Ульяновская область, Майнский район, село Родниковые Пруды	0101000020E610000081423D7D04C4474025EB707495F04A40
7273	7	74	50	1569	\N	\N	54.074981000000001	Ульяновская область, Майнский район, с. Репьевка-Космынка, здание администрации	Россия, Ульяновская область, Майнский район, село Репьевка-Космынка	0101000020E6100000F487669E5CF14740236937FA98094B40
7261	7	74	50	853	\N	\N	54.051645999999998	Ульяновская область, Майнский район, с. Репьевка Колхозная, здание детского сада	Россия, Ульяновская область, Майнский район, село Репьевка Колхозная	0101000020E6100000E9465854C4B947400F7C0C569C064B40
7252	7	74	50	297	\N	\N	53.931859000000003	Ульяновская область, Майнский район, с. Поповка, здание школы	Россия, Ульяновская область, Майнский район, село Поповка	0101000020E6100000E964A9F57ECD4740DCBDDC2747F74A40
7269	7	74	50	1336	\N	\N	54.129649000000001	Ульяновская область, Майнский район, с. Полбино, здание школы	Россия, Ульяновская область, Майнский район, село Полбино	0101000020E6100000C6BE64E3C1F44740C47AA35698104B40
7281	7	74	50	2029	\N	\N	54.315793999999997	Ульяновская область, Майнский район, с. Подлесное, адрес помещения для голосования: здание школы, адрес УИК: здание администрации		0101000020E6100000200BD12170CC4740F22213F06B284B40
7276	7	74	50	1722	\N	\N	54.503808999999997	Ульяновская областть, Майнский район, с. Новые Маклауши, здание библиотеки	Россия, Ульяновская область, Майнский район, село Новые Маклауши	0101000020E610000090662C9ACEBC4740193735D07C404B40
7256	7	74	50	479	47075	\N	54.113539000000003	Ульяновская область, Майнский район, р.п. Майна, ул. Советская, д. 11		0101000020E6100000D32D3BC43FCE474008E92972880E4B40
94402	7	74	50	479	46859	\N	54.113539000000003	"Ульяновская область, Майнский район, р.п. Майна, ул. Первомайская, д.43, МУК ""Майнский историко-краеведческий музей"""		0101000020E6100000D32D3BC43FCE474008E92972880E4B40
7258	7	74	50	479	47315	\N	54.114345884028197	Ульяновская область, Майнский район, р.п. Майна, ул. Павлика Морозова, д. 7	Россия, Ульяновская область, Майнский район, поселок Майна	0101000020E6100000AA49F08634CE4740D636C5E3A20E4B40
7257	7	74	50	479	46976	\N	54.113539000000003	Ульяновская область, Майнский район, р.п. Майна, ул. 1-я Комсомольская, д. 39		0101000020E6100000D32D3BC43FCE474008E92972880E4B40
7280	7	74	50	1968	\N	\N	54.282656000000003	Ульяновская область, Майнский район, с. Копышовка, адрес помещения для голосоания: здание школы, адрес УИК: здание администрации	Россия, Ульяновская область, Майнский район, село Копышовка	0101000020E6100000BAD91F28B7D34740540262122E244B40
7271	7	74	50	1445	\N	\N	53.997028	Ульяновская область, Майнский район, с. Карлинское, здание школы	Россия, Ульяновская область, Майнский район, село Карлинское	0101000020E6100000CAFCA36FD2E2474020990E9D9EFF4A40
7249	7	74	50	58	46876	\N	53.949921000000003	Ульяновская обасть, Майнский район, р.п. Игнатовка, ул. 2 Советская, д. 11А		0101000020E6100000C3D4963AC8D347404E64E60297F94A40
7248	7	74	50	58	46876	\N	53.949921000000003	Ульяновская область, Майнский район, р.п. Игнатовка, адрес помещения для голосования: ул. 2 Советская,  д. 17, адрес УИК: ул. 2 Советская,  д. 11А		0101000020E6100000C3D4963AC8D347404E64E60297F94A40
7251	7	74	50	221	\N	\N	53.877549999999999	Ульяновская область, Майнский район, с. Загоскино, здание школы	Россия, Ульяновская область, Майнский район, село Загоскино	0101000020E61000004C6BD3D85ED347406A4DF38E53F04A40
7270	7	74	50	55817	\N	\N	54.015254136826201	Ульяновская область, Майнский район, п. Гимово, здание администрации	Россия, Ульяновская область, Майнский район, село Гимова	0101000020E6100000543A58FFE7F647400C91D3D7F3014B40
7260	7	74	50	787	\N	\N	54.049990999999999	Ульяновская область, Майнский район, с. Вязовка, здание школы	Россия, Ульяновская область, Майнский район, село Вязовка	0101000020E6100000490ED8D5E4DD4740130CE71A66064B40
7266	7	74	50	1111	\N	\N	54.182310999999999	Ульяновская область, Майнский район, с. Выры, здание школы	Россия, Ульяновская область, Майнский район, село Выры	0101000020E61000008DEDB5A0F7E64740BC5983F755174B40
7265	7	74	50	1111	\N	\N	54.173658048801599	Ульяновская область, Майнский район, п. Станция Выры, здание СДК	Россия, Ульяновская область, Майнский район, село Выры	0101000020E6100000E0A128D027F047402A58E36C3A164B40
7259	7	74	50	732	\N	\N	54.164982999999999	Ульяновская область, Майнский район, с. Большое Жеребятниково, здание СДК	Россия, Ульяновская область, Майнский район, село Большое Жеребятниково	0101000020E61000000D17B9A7ABC34740AFB2B6291E154B40
7205	7	74	50	30451	\N	\N	54.051555999999998	Ульяновская область, Майнский район. с. Березовка, здание СДК	Россия, Ульяновская область, Майнский район, село Березовка	0101000020E6100000D88349F1F1CF4740CFF4126399064B40
7250	7	74	50	55803	\N	\N	53.854309860812798	Ульяновская область, Майнский район, с. Белое Озеро, адрес помещения для голосования: здание школы, адрес УИК: здание администрации	Россия, Ульяновская область, Майнский район, село Белое Озеро	0101000020E6100000C09657AEB7C94740A852B3075AED4A40
7268	7	74	50	55813	\N	\N	54.201460335064098	Ульяновская область, Майнский район, п. Безречный, здание школы	Россия, Ульяновская область, Майнский район, село Выровский	0101000020E61000006C76A4FACEF14740E0B9F770C9194B40
7267	7	74	50	55823	\N	\N	54.167833999999999	Ульяновская область, Майнский район, п. Безлесный, здание школы		0101000020E6100000AAF3A8F8BFD347401494A2957B154B40
7262	7	74	50	55784	\N	\N	54.1069491712367	Ульяновская область,  Майнский район, с. Анненково-Лесное, здание школы	Россия, Ульяновская область, Майнский район, село Анненково	0101000020E6100000073F7100FDB4474082AB3C81B00D4B40
7121	7	74	50	26593	\N	\N	54.200223000000001	Ульяновская область,  Майнский район, с. Абрамовка, здание СДК	Россия, Ульяновская область, Майнский район, село Абрамовка	0101000020E61000009DD5027B4CD84740197442E8A0194B40
7224	7	74	1910	31414	\N	\N	53.750914000000002	"Ульяновская область, Кузоватовский район, с. Чириково, адрес помещения для голосования: здание СПК ""Свияга"", Адрес УИК: здание администрации"		0101000020E6100000800C1D3BA8EA4740E50D30F31DE04A40
7223	7	74	1910	31349	\N	\N	53.82443	Ульяновская область, Кузоватовский район, с. Чертановка, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание администрации		0101000020E610000040C23060C9E94740AFEB17EC86E94A40
7222	7	74	1910	31302	\N	\N	53.791905999999997	Ульяновская область, Кузоватовский район, с. Хвостиха, адрес помещения для голосования: административное здание, помещение клуба, Адрес УИК: здание администрации	Россия, Ульяновская область, Кузоватовский район, село Хвостиха	0101000020E610000024B5503239F34740CAC0012D5DE54A40
7228	7	74	1910	31610	\N	\N	53.665126999999998	Ульяновская область, Кузоватовский район, с. Уваровка, адрес помещения для голосования: здание сельского клуба, Адрес УИК: здание школы		0101000020E6100000CAFCA36FD2E24740E257ACE122D54A40
7243	7	74	1910	32279	\N	\N	53.478656999999998	Ульяновская область, Кузоватовский район, с.Томылово, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание администрации		0101000020E61000009BC761307FEF47403080F0A144BD4A40
7244	7	74	1910	32314	\N	\N	53.409697000000001	Ульяновская область, Кузоватовский район, с. Студенец, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание администрации		0101000020E6100000705CC64D0DFC4740792288F370B44A40
7218	7	74	1910	31104	\N	\N	53.972562000000003	Ульяновская область, Кузоватовский район, с. Стоговка, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание МОУ СОШ, библиотека		0101000020E6100000ECF99AE5B20148408BAA5FE97CFC4A40
7219	7	74	1910	31136	\N	\N	53.885787000000001	Ульяновская область, Кузоватовский район, с. Спешневка, адрес помещения для голосования: здание МОУ ООШ, Адрес УИК: здание администрации		0101000020E610000048C0E8F2E6FA4740691CEA7761F14A40
7225	7	74	1910	31458	\N	\N	53.753965000000001	"Ульяновская область, Кузоватовский район, с. Смышляевка, адрес помещения для голосования: здание МОУ ООШ, Адрес УИК: здание ООО ""Смышляевский"""		0101000020E6100000E5F0492712DE474011AAD4EC81E04A40
7239	7	74	1910	32089	\N	\N	53.57461	"Ульяновская область, Кузоватовский район, пос. Приволье, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание СПК ""Кузоватовский"""		0101000020E610000044A4A65D4CED47402FFA0AD28CC94A40
7221	7	74	1910	31243	\N	\N	53.817774999999997	Ульяновская область, Кузоватовский район, с. Порецкое, адрес помещения для голосования: здание начальной школы, Адрес УИК: здание начальной школы		0101000020E61000004A9BAA7B64F34740423EE8D9ACE84A40
7220	7	74	1910	31195	\N	\N	53.892972999999998	Ульяновская область, Кузоватовский район, пос. Первомайский, адрес помещения для голосования: здание МОУ ООШ, Адрес УИК: здание ФАП		0101000020E6100000AC1DC539EAEE4740029B73F04CF24A40
7234	7	74	1910	31840	\N	\N	53.366239772954401	Ульяновская область, Кузоватовский район, с. Никольское, адрес помещения для голосования: здание СДК, Адрес УИК: здание администрации	Россия, Ульяновская область, Кузоватовский район, село Никольское	0101000020E61000009E961FB8CAE54740573ECBF3E0AE4A40
7231	7	74	1910	55785	\N	\N	53.558942614355097	Ульяновская область, Кузоватовский район, пос. станция Налейка, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание МОУ СОШ	Россия, Ульяновская область, Кузоватовский район, село Налейка	0101000020E61000005DFB027AE1BE474000AAB8718BC74A40
7240	7	74	1910	32144	\N	\N	53.533591999999999	Ульяновская область, Кузоватовский район, с. Малая Борла, адрес помещения для голосования: здание начальной школы, Адрес УИК: здание начальной школы		0101000020E6100000F180B2295702484020B41EBE4CC44A40
7232	7	74	1910	31778	\N	\N	53.449815999999998	Ульяновская область, Кузоватовский район, с. Лесное Матюнино, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание администрации		0101000020E61000007769C36169B64740D89B189293B94A40
7229	7	74	1910	31623	\N	\N	53.554577000000002	Ульяновская область, Кузоватовский район, с. Кузоватово, адрес помещения для голосования: МОУ СОШ № 2, Адрес УИК: здание ФАП		0101000020E61000007FA2B2614DCF4740910E0F61FCC64A40
7247	7	74	1910	32357	\N	\N	53.545231000000001	Ульяновская область, Кузоватовский район, р.п. Кузоватово, адрес помещения для голосования: здание МОУ СОШ № 1, Адрес УИК: здание администрации р.п. Кузоватово		0101000020E61000008FFD2C9622D74740F8E12021CAC54A40
7246	7	74	1910	32357	\N	\N	53.545231000000001	"Ульяновская область, Кузоватовский район, р.п. Кузоватово, адрес помещения для голосования: здание МУК ""Кузоватовский РДК"", Адрес УИК: здание администрации р.п. Кузоватово"		0101000020E61000008FFD2C9622D74740F8E12021CAC54A40
7245	7	74	1910	32357	\N	\N	53.545231000000001	Ульяновская область, Кузоватовский район, р.п. Кузоватово, адрес помещения для голосования: МОУ СОШ № 3, Адрес УИК: здание администрации р.п. Кузоватово		0101000020E61000008FFD2C9622D74740F8E12021CAC54A40
7233	7	74	1910	31838	\N	\N	53.422688999999998	Ульяновская область, Кузоватовский район, с. Красная Балтия, адрес помещения для голосования: здание СДК, Адрес УИК: здание библиотеки		0101000020E61000000E4B033FAAC7474081B053AC1AB64A40
7227	7	74	1910	31554	\N	\N	53.606623999999996	Ульяновская область, Кузоватовский район, с. Коромысловска, адрес помещения для голосования: здание МОУ 0ОШ, Адрес УИК: здание администрации		0101000020E6100000BEF90D130DDA4740FE7BF0DAA5CD4A40
7237	7	74	1910	32008	\N	\N	53.465091000000001	"Ульяновская область, Кузоватовский район, с. Кивать, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание СПК ""Киватский"""		0101000020E6100000FB21365838D74740FC54151A88BB4A40
7236	7	74	1910	31964	\N	\N	53.406857000000002	Ульяновская область, Кузоватовский район, с. Еделево, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание администрации поселения		0101000020E6100000776A2E3718E047400893E2E313B44A40
7238	7	74	1910	32065	\N	\N	53.564428999999997	"Ульяновская область, Кузоватовский район, с. Волынщина, адрес помещения для голосования: здание  МОУ ООШ, Адрес УИК: здание МУК ""Волынщинский СДК"""	Россия, Ульяновская область, Кузоватовский район, село Волынщина	0101000020E61000002D944C4EEDE64740FDF49F353FC84A40
7226	7	74	1910	31510	\N	\N	53.723303999999999	"Ульяновская область, Кузоватовский район, с. Бестужевка, адрес помещения для голосования: здание ООО ""Дружба"", Адрес УИК: здание ООО ""Дружба"""		0101000020E61000006555849B8CDE47407288B83995DC4A40
7242	7	74	1910	32513	\N	\N	53.4948560554488	Ульяновская область, Кузоватовский район, ст. Безводовка, адрес помещения для голосования: здание начальной школы, Адрес УИК: здание начальной школы	Россия, Ульяновская область, Кузоватовский район, село Безводовка	0101000020E610000053978C6324F747405C1D007157BF4A40
7241	7	74	1910	32513	\N	\N	53.524706999999999	"Ульяновская область, Кузоватовский район, с. Безводовка, адрес помещения для голосования: здание МОУ СОШ, Адрес УИК: здание МУК ""Безводовский СДК"""		0101000020E61000002DCF83BBB3FA4740BB7D569929C34A40
7230	7	74	1910	31693	\N	\N	53.596905	Ульяновская область, Кузоватовский район, с. Баевка, адрес помещения для голосования: здание МОУ ООШ, Адрес УИК: здание ФАП		0101000020E610000088A1D5C919CE4740D1E80E6267CC4A40
7189	7	74	1869	55798	47386	\N	54.226033000000001	"Ульяновская область, Карсунский район, пос. Чулочно-носочной фабрики, адрес помещения для голосования: ул.Фабричная, здание сельского Дома культуры, Адрес УИК: р.п.Карсун, ул.Куйбышева, д. 14"		0101000020E610000071E7C2482F7C47408C683BA6EE1C4B40
7195	7	74	1869	29881	47366	\N	54.294122999999999	"Ульяновская область, Карсунский район,  р.п.Языково, адрес помещения для голосования: ул. Октябрьская, д. 1, Адрес УИК: ул. Цветкова, д. 15"		0101000020E6100000381268B0A9B147402E008DD2A5254B40
7193	7	74	1869	29881	46875	\N	54.294122999999999	"Ульяновская область, Карсунский район,  р.п.Языково, адрес помещения для голосования: ул. Клубная, д. 1, Адрес УИК: ул. Цветкова, д. 15"		0101000020E6100000381268B0A9B147402E008DD2A5254B40
7202	7	74	1869	30281	\N	\N	54.372985	"Ульяновская область, Карсунский район, с.Усть-Урень, адрес помещения для голосования: помещение сельской библиотеки, Адрес УИК: здание администрации поселения"		0101000020E61000003813D385588947400473F4F8BD2F4B40
7214	7	74	1869	30921	\N	\N	54.294135757322003	"Ульяновская область, Карсунский район, с.Урено-Карлинское, адрес помещения для голосования: МОУ Урено-Карлинская средняя общеобразовательная школа, Адрес УИК: здание администрации поселения"	Россия, Ульяновская область, Карсунский район, село Урено-Карлинское	0101000020E6100000BFB67EFACF9E4740C3499A3FA6254B40
7213	7	74	1869	30867	\N	\N	54.124530999999998	"Ульяновская область, Карсунский район, с.Уразовка, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: с. Сосновка, здание администрации поселения"		0101000020E6100000825660C8EA564740492BBEA1F00F4B40
7217	7	74	1869	31062	\N	\N	54.348097000000003	"Ульяновская область, Карсунский район, с.Теньковка, адрес помещения для голосования: МОУ Теньковская средняя общеобразовательная школа, Адрес УИК: здание администрации поселения"		0101000020E610000048A7AE7C96A74740F96A47718E2C4B40
7203	7	74	1869	55800	\N	\N	54.254678500551798	"Ульяновская область, Карсунский район, с.Татарские Горенки, адрес помещения для голосования: МОУ Татарскогоренская  основная общеобразовательная школа, Адрес УИК: здание администрации поселения"		0101000020E61000001EDFDE35E85947402FFD4B5299204B40
80047	7	72	393	15632	47669	\N	53.603952999999997	село Подбельск, Куйбышевская, 123		0101000020E6100000CC9717601FE7494019A9F7544ECD4A40
7208	7	74	1869	30575	\N	\N	54.277251999999997	Ульяновская область, Карсунский район, д.Татарская Голышевка, Адрес УИК: сельский Дом культуры, помещение для голосования	Россия, Ульяновская область, Карсунский район, село Татарская Голышевка	0101000020E610000035289A07B0544740136058FE7C234B40
7190	7	74	1869	29722	\N	\N	54.168246000000003	"Ульяновская область, Карсунский район, с.Таволжанка, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения"		0101000020E610000053E8BCC62E83474067D7BD1589154B40
7211	7	74	1869	30761	\N	\N	54.182965000000003	"Ульяновская область, Карсунский район, с.Сухой Карсун, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения"		0101000020E6100000FD4AE7C3B350474005A8A9656B174B40
7212	7	74	1869	30816	\N	\N	54.109031000000002	"Ульяновская область, Карсунский район, с.Сосновка, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения"		0101000020E61000000E4A9869FB51474006A051BAF40D4B40
7196	7	74	1869	30020	\N	\N	54.269145000000002	"Ульяновская область, Карсунский район,  с.Прислониха, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения"	Россия, Ульяновская область, Карсунский район, село Прислониха	0101000020E61000007C7E18213CBA4740E370E65773224B40
7200	7	74	1869	30200	\N	\N	54.328586000000001	"Ульяновская область, Карсунский район, с. Потьма, адрес помещения для голосования: здание бывшей школы, Адрес УИК: здание администрации села"		0101000020E61000002AE109BDFE78474034F6251B0F2A4B40
7188	7	74	1869	55809	47450	\N	54.226033000000001	"Ульяновская область, Карсунский район, д.Пески, адрес помещения для голосования: ул. Комарова, д.16а, Адрес УИК: р.п.Карсун, ул. Куйбышева, д. 14"		0101000020E610000071E7C2482F7C47408C683BA6EE1C4B40
7209	7	74	1869	55816	\N	\N	54.147909284461903	Ульяновская область, Карсунский район, с.Новое Погорелово: адрес помещения для голосования: МОУ Новопогореловская средняя общеобразовательная школа, Адрес УИК: здание администрации поселения	Россия, Ульяновская область, Карсунский район, село Новое Погорелово	0101000020E610000065C6DB4AAF6547405CE49EAEEE124B40
7210	7	74	1869	30686	\N	\N	54.182380000000002	"Ульяновская область, Карсунский район, с.Нагаево, адрес помещения для голосования: МОУ Нагаевская средняя общеобразовательная школа, Адрес УИК: здание администрации поселения"	Россия, Ульяновская область, Карсунский район, село Нагаево	0101000020E6100000E0BBCD1B275D4740E5B8533A58174B40
7192	7	74	1869	29825	\N	\N	54.305602999999998	"Ульяновская область, Карсунский район, с.Малое Станичное, адрес помещения для голосования: МОУ Малостаниченская начальная общеобразовательная школа, Адрес УИК: здание администрации поселения"		0101000020E6100000FB3DB14E958147409D47C5FF1D274B40
7191	7	74	1869	55811	\N	\N	54.164835775484001	Ульяновская область, Карсунский район, с.Красноплка: адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения	Россия, Ульяновская область, Карсунский район, село Краснополка	0101000020E61000009A0AF148BC7647400B9A965819154B40
7204	7	74	1869	30506	\N	\N	54.294533000000001	"Ульяновская область, Карсунский район, с.Котяково, адрес помещения для голосования: здание администрации Горенского сельского поселения, Адрес УИК: с. Татарские Горенки, здание администрации"	Россия, Ульяновская область, Карсунский район, село Котяково	0101000020E610000066101FD8F1594740E04BE141B3254B40
7198	7	74	1869	30116	\N	\N	54.279896000000001	"Ульяновская область, Карсунский район,  с.Комаровка, адрес помещения для голосования: здание фельдшерско-акушерского пункта, Адрес УИК: с. Большие Поселки, здание администрации поселения"		0101000020E6100000787FBC57AD704740FF23D3A1D3234B40
7186	7	74	1869	29479	47022	\N	54.191941999999997	"Ульяновская область, Карсунский район, р.п.Карсун, адрес помещения для голосования: ул. Ульянова, д. 2, Адрес УИК: ул. Куйбышева, д. 14"		0101000020E6100000B66AD784B47E47404A5D328E91184B40
94439	7	74	1869	29479	47000	\N	54.191941999999997	Ульяновская область, Карсунский район, р.п. Карсун, ул. Советская, д. 14, Карсунская детская школа искусств им. А.Пластова, фойе		0101000020E6100000B66AD784B47E47404A5D328E91184B40
7187	7	74	1869	29479	47027	\N	54.191941999999997	"Ульяновская область, Карсунский район, р.п.Карсун, адрес помещения для голосования: ул. Мира, д. 16, Адрес УИК: ул. Куйбышева, д. 14"		0101000020E6100000B66AD784B47E47404A5D328E91184B40
7206	7	74	1869	30515	\N	\N	54.330506999999997	Ульяновская область, Карсунский район, с.Кадышево, Адрес УИК: здание бывшей школы, помещение для голосования	Россия, Ульяновская область, Карсунский район, село Кадышево	0101000020E6100000ABE97AA2EB5C4740AE0CAA0D4E2A4B40
7199	7	74	1869	30151	\N	\N	54.352200000000003	"Ульяновская область, Карсунский район, с.Вальдиватское, адрес помещения для голосования: МОУ Вальдиватская средняя общеобразовательная школа, Адрес УИК: здание администрации поселения"		0101000020E6100000CADDE7F8687F47405BD3BCE3142D4B40
7201	7	74	1869	30255	\N	\N	54.401161000000002	"Ульяновская область, Карсунский район, с.Большая Кандарать, адрес помещения для голосования: МОУ Большекандаратская средняя общеобразовательная  школа, Адрес УИК: здание администрации поселения"		0101000020E61000001EDD088B8A7C474020B75F3E59334B40
7197	7	74	1869	55825	\N	\N	54.284733647809098	"Ульяновская область, Карсунский район,  с.Большие Поселки, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения"	Россия, Ульяновская область, Карсунский район, село Большии Поселки	0101000020E6100000952BBCCB457C47409607E92972244B40
7215	7	74	1869	30958	\N	\N	54.329557000000001	"Ульяновская область, Карсунский район, с.Белозерье, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения"		0101000020E6100000A1100187509547407D957CEC2E2A4B40
7207	7	74	1869	30534	\N	\N	54.258685	"Ульяновская область, Карсунский район, с.Беловодье, адрес помещения для голосования: сельский Дом культуры, Адрес УИК: здание администрации поселения"	Россия, Ульяновская область, Карсунский район, село Беловодье	0101000020E6100000764F1E166A4F47409E7B0F971C214B40
7216	7	74	1869	31021	\N	\N	54.306837999999999	Ульяновская область, Карсунский район, с.Базарный Урень, Адрес УИК: здание администрации поселения, помещение для голосования	Россия, Ульяновская область, Карсунский район, село Базарный Урень	0101000020E6100000B1FA230C03A44740C495B37746274B40
7176	7	74	186	55821	47566	\N	53.905375999999997	Ульяновская область, Инзенский район, разъезд Дубенки, ул. Лесная, д. 16 (ФАП)		0101000020E61000004AD1CABDC03A4740A94A5B5CE3F34A40
7158	7	74	186	55844	47650	\N	53.946697734854602	Ульяновская область, Инзенский район, с. Палатово, ул. Центральная, д. 97	Россия, Ульяновская область, Инзенский район	0101000020E6100000ED9FA7018330474024986A662DF94A40
7178	7	74	186	29194	\N	\N	53.967319000000003	Ульяновская область, Инзенский район, с. Юлово, адрес помещения для голосования: здание основной общеобразовательной школы, адрес УИК: ул. Верхняя, д. 3		0101000020E6100000499F56D11F3E474054E6E61BD1FB4A40
7167	7	74	186	28687	\N	\N	54.162272999999999	Ульяновская область, Инзенский район, с. Чумакино, сельская библиотека	Россия, Ульяновская область, Инзенский район, село Чумакино	0101000020E610000077F52A323A2A47400C03965CC5144B40
7184	7	74	186	29456	47571	\N	53.74633	Ульяновская область, Инзенский район, с. Черемушки, ул. Шоссейная, д. 33 (здание администрации)		0101000020E6100000F0C000C2873847400803CFBD87DF4A40
7166	7	74	186	28616	\N	\N	54.071294000000002	Ульяновская область, Инзенский район, с. Чамзинка, административное здание		0101000020E6100000BDE47FF27739474055336B2920094B40
7177	7	74	186	29146	47367	\N	53.907716000000001	Ульяновская область, Инзенский район, с. Труслейка, пер. Советский, д. 4 (здание администрации)		0101000020E610000002840F255A3247402907B30930F44A40
7149	7	74	186	27881	\N	\N	53.845922999999999	Ульяновская область, Инзенский район, с. Троицкое, здание филиала городского Дома культуры	Россия, Ульяновская область, Инзенский район, село Троицкое	0101000020E61000008EB27E333135474094F7713447EC4A40
7161	7	74	186	28420	47438	\N	54.141855999999997	Ульяновская область, Инзенский район, с. Тияпино, ул. Центральная, д. 54а		0101000020E6100000EFCB99ED0A0F4740E55E605628124B40
7173	7	74	186	28970	\N	\N	53.821888999999999	"Ульяновская область, Инзенский район, с. Сюксюм, здание Администрации МО ""Сюксюмское сельское поселение"""	Россия, Ульяновская область, Инзенский район, село Сюксюм	0101000020E61000004C8BFA24773A474098F8A3A833E94A40
7172	7	74	186	28901	\N	\N	53.858260999999999	Ульяновская область, Инзенский район, пос. Свет, сельский дом культуры (зрительный зал)		0101000020E61000006CEC12D55B1B47405437177FDBED4A40
7183	7	74	186	29387	47570	\N	53.785778000000001	Ульяновская область, Инзенский район, с. Репьевка, ул. Советская, д. 2		0101000020E6100000AAD381ACA730474049F59D5F94E44A40
7160	7	74	186	28329	47567	\N	54.109707	Ульяновская область, Инзенский район, с. Пятино, пер. Школьный, д. 9		0101000020E61000003C670B08AD114740369204E10A0E4B40
7165	7	74	186	28583	\N	\N	54.100453000000002	Ульяновская область, Инзенский район, с. Проломиха, Сельский дом культуры (кабинет директора)	Россия, Ульяновская область, Инзенский район, село Проломиха	0101000020E6100000A1116C5CFF3647407EE4D6A4DB0C4B40
7182	7	74	186	29362	47572	\N	53.727831999999999	Ульяновская область, Инзенский район, с. Поддубное, пер. Школьный, д. 13 (школа-лицей)		0101000020E6100000984EEB36A8394740BB7D569929DD4A40
7159	7	74	186	28320	47555	\N	54.017845000000001	Ульяновская область, Инзенский район, с. Первомайское, ул. Советская, д. 3		0101000020E6100000DDCEBEF220F54640D5B2B5BE48024B40
7171	7	74	186	28889	\N	\N	53.804940999999999	Ульяновская область, Инзенский район, с. Панциревка, здание средней школы (фойе)	Россия, Ульяновская область, Инзенский район, село Панциревка	0101000020E610000055C2137AFD254740D21A834E08E74A40
7170	7	74	186	28824	\N	\N	53.832593000000003	"Ульяновская область, Инзенский район, с. Оськино, здание Администрации МО ""Оськинское сельское поселение"""	Россия, Ульяновская область, Инзенский район, село Оськино	0101000020E61000009F58A7CAF724474074F04C6892EA4A40
7164	7	74	186	28519	\N	\N	54.228527	Ульяновская область, Инзенский район, с. Новосурск, административное здание		0101000020E61000004D9F1D705D39474062A06B5F401D4B40
7153	7	74	186	28033	\N	\N	53.893752999999997	Ульяновская область, Инзенский район, пос. Неклюдовский, здание средней общеобразовательной школы	Россия, Ульяновская область, Инзенский район, село Неклюдовский	0101000020E6100000DE91B1DAFC574740D7D9907F66F24A40
7154	7	74	186	28091	\N	\N	53.863720000000001	Ульяновская область, Инзенский район, с. Неклюдово, помещение ФАП	Россия, Ульяновская область, Инзенский район, село Неклюдово	0101000020E6100000A1832EE1D0594740587380608EEE4A40
7163	7	74	186	28505	\N	\N	54.181842000000003	"Ульяновская область, Инзенский район, с. Коржевка, здание Администрации МО ""Коржевское сельское поселение"""	Россия, Ульяновская область, Инзенский район, село Коржевка	0101000020E61000009C1A683EE73047400685419946174B40
7148	7	74	186	27225	47363	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, пер. Рузаевский, д. 2		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7137	7	74	186	27225	46869	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Энгельса, д. 51		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7141	7	74	186	27225	46870	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Школьная, д. 66		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7145	7	74	186	27225	47358	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Фрунзе, д. 2А		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7135	7	74	186	27225	46934	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Терешковой, д. 1		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7147	7	74	186	27225	46873	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Революции, д. 56		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7146	7	74	186	27225	46873	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Революции, д. 53		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7142	7	74	186	27225	47271	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Пугачева, д. 23	Россия, Ульяновская область, Инзенский район, Инза	0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7138	7	74	186	27225	47074	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Парковая, д. 8		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7144	7	74	186	27225	46871	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Мира, д. 17А		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7143	7	74	186	27225	46871	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Мира, д. 17		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7139	7	74	186	27225	46935	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Ломоносова, д. 9		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7136	7	74	186	27225	47309	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Дорожная, д. 1		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7140	7	74	186	27225	46938	\N	53.853608999999999	Ульяновская область, Инзенский район, г. Инза, ул. Алашеева, д. 1		0101000020E6100000CBF6216FB92E47401F49490F43ED4A40
7169	7	74	186	28773	\N	\N	53.877730999999997	Ульяновская область, Инзенский район, с. Забалуйка, административное здание (кабинет специалиста)		0101000020E6100000B37E33315D204740BAD7497D59F04A40
7162	7	74	186	28432	\N	\N	54.189692999999998	Ульяновская область, Инзенский район, с. Дракино, здание сельского клуба (зрительный зал)	Россия, Ульяновская область, Инзенский район, село Дракино	0101000020E6100000FC170802643A4740DBA337DC47184B40
7175	7	74	186	29055	\N	\N	53.998525999999998	Ульяновская область, Инзенский район, с. Городищи, помещение ФАП	Россия, Ульяновская область, Инзенский район, село Городищи	0101000020E6100000060DFD135C144740541A31B3CFFF4A40
7152	7	74	186	27934	\N	\N	53.955351999999998	"Ульяновская область, Инзенский район, р.п. Глотовка, здание РЭУ-13 филиала Пензенский ОАО ""Славянка"""	Россия, Ульяновская область, Инзенский район, поселок Глотовка	0101000020E61000006E6B0BCF4B59474087156EF948FA4A40
7151	7	74	186	27934	47273	\N	53.955351999999998	Ульяновская область, Инзенский район, р.п. Глотовка, ул. Советская, д. 31	Россия, Ульяновская область, Инзенский район, поселок Глотовка	0101000020E61000006E6B0BCF4B59474087156EF948FA4A40
7150	7	74	186	27934	47272	\N	53.955351999999998	Ульяновская область, Инзенский район, р.п. Глотовка, ул. Садовая, д. 28		0101000020E61000006E6B0BCF4B59474087156EF948FA4A40
7157	7	74	186	28231	47556	\N	54.061470999999997	Ульяновская область, Инзенский район, с. Валгуссы, ул. Большая, д. 61		0101000020E61000005C3D27BD6F1A474082531F48DE074B40
7181	7	74	186	29323	47569	\N	53.764622000000003	Ульяновская область, Инзенский район, с. Бояркино, ул. Центральная, д. 12 (СДК)		0101000020E610000061C5A9D6C2344740ACE63922DFE14A40
7156	7	74	186	28166	47558	\N	54.152430000000003	Ульяновская область, Инзенский район, с. Большое Шуватово, ул. Центральная, д. 15а		0101000020E61000004CFC51D4991D4740F37684D382134B40
7180	7	74	186	29260	47442	\N	53.671700000000001	Ульяновская область, Инзенский район, с. Большая Борисовка, ул. Ленина, д. 21 (административное здание)		0101000020E610000026E1421EC13B4740925CFE43FAD54A40
7179	7	74	186	29226	47557	\N	53.628132999999998	Ульяновская область, Инзенский район, с. Аристовка, ул. Молодежная, д. 14 (СДК)		0101000020E61000002E02637D03474740E94482A966D04A40
7174	7	74	186	28998	\N	\N	53.963267000000002	Ульяновская область, Инзенский район, с. Аргаш, Актовый зал административного здания		0101000020E6100000E78D93C2BC1F4740742843554CFB4A40
7168	7	74	186	52000	\N	\N	53.773966999999999	Ульяновская область, Инзенский район, д. Андрияновка, помещение ФАП	Россия, Ульяновская область, Инзенский район, село Андрияновка	0101000020E6100000DC63E943172847407497C45911E34A40
7155	7	74	186	28150	47565	\N	54.061661000000001	Ульяновская область, Инзенский район, с. Аксаур, ул. Центральная, д. 60		0101000020E61000004548DDCEBE0C47402638F581E4074B40
7128	7	74	1787	26878	47311	\N	53.964420867319397	Ульяновская область, Вешкаймский район, п. Шарлово, ул. Заводская, д. 5	Россия, Ульяновская область, Вешкаймский район, поселок Шарлово	0101000020E61000003FE3C281906C4740AE49B72572FB4A40
7127	7	74	1787	26878	47564	\N	53.965232	Ульяновская область, Вешкаймский район, п. Шарлово, адрес помещения для голосования: ул. Школьная, д. 5, адрес УИК: ул. Школьная, д. 9		0101000020E61000007AC5538F346C4740BE86E0B88CFB4A40
7119	7	74	1787	26432	46933	\N	54.095025	Ульяновская область, Вешкаймский район, р.п. Чуфарово, адрес помещения для голосования: ул. Заводская, д. 11а, адрес УИК: ул. Мира, д. 44		0101000020E61000008656276728AA4740B5A679C7290C4B40
7118	7	74	1787	26432	46933	\N	54.095025	Ульяновская область, Вешкаймский район, р.п. Чуфарово, ул. Заводская, д. 1а		0101000020E61000008656276728AA4740B5A679C7290C4B40
7117	7	74	1787	26373	47434	\N	54.111485999999999	Ульяновская область, Вешкаймский район, с. Ховрино, адрес помещения для голосования: ул. Ленина, д. 15, адрес УИК: ул. Ленина, д. 19		0101000020E6100000D2510E66139647401EFB592C450E4B40
7133	7	74	1787	55797	47385	\N	53.953267673276102	Ульяновская область, Вешкаймский район, с. Стемасс, адрес помещения для голосования: ул. Центральный Массив, д. 4, адрес УИК: ул. Центральный Массив, д. 6	Россия, Ульяновская область, Вешкаймский район, село Стемас	0101000020E6100000FA298E03AFB24740632992AF04FA4A40
7123	7	74	1787	26666	47440	\N	54.125824000000001	Ульяновская область, Вешкаймский район, с. Старое Погорелово, ул. Центральная, д. 79	Россия, Ульяновская область, Вешкаймский район, село Старое Погорелово	0101000020E6100000FA980F08746E4740A58636001B104B40
7131	7	74	1787	27063	47441	\N	53.895513999999999	Ульяновская область, Вешкаймский район, с. Нижняя Туарма, ул. Клубная, д. 22		0101000020E6100000618DB3E908944740198EE733A0F24A40
7126	7	74	1787	55822	47568	\N	53.931802776346203	Ульяновская область, Вешкаймский район, с. Мордовский Белый Ключ, ул. Верхняя, д. 2	Россия, Ульяновская область, Вешкаймский район, село Мордово-Белый Ключ	0101000020E6100000827170E99879474048A8195245F74A40
7116	7	74	1787	55783	47277	\N	54.0020434736686	Ульяновская область, Вешкаймский район, с. Красный Бор, адрес помещения для голосования: ул. Репинского, д. 100а, адрес УИК: ул. Репинского, д. 95	Россия, Ульяновская область, Вешкаймский район, село Красный Бор	0101000020E6100000B1A371A8DF9F4740C617EDF142004B40
7130	7	74	1787	26985	47554	\N	53.874254000000001	Ульяновская область, Вешкаймский район, с. Коченяевка, ул. Центральная, д. 72		0101000020E6100000BEA59C2FF67E4740D732198EE7EF4A40
7129	7	74	1787	26951	47314	\N	53.922676000000003	Ульяновская область, Вешкаймский район, с. Каргино, адрес помещения для голосования: ул. Егоровка, д. 8, адрес УИК: ул. Советская, д. 4		0101000020E610000039EFFFE3848B4740ED66463F1AF64A40
7125	7	74	1787	26788	47553	\N	54.045713999999997	Ульяновская область, Вешкаймский район, с. Зимненки, ул. Советская, д. 41		0101000020E6100000E292E34EE96C4740137CD3F4D9054B40
7115	7	74	1787	55831	47634	\N	54.019434178747701	Ульяновская область, Вешкаймский район, п. Залесный, ул. Советская, д. 14	Россия, Ульяновская область, Вешкаймский район	0101000020E6100000D175E107E7854740193735D07C024B40
7124	7	74	1787	26718	47355	\N	54.006951000000001	Ульяновская область, Вешкаймский район, с. Ермоловка, адрес помещения для голосования: ул. Центральная, д. 101, адрес УИК: ул. Центральная, д. 124		0101000020E61000009738F240646F474056D636C5E3004B40
7114	7	74	1787	26223	47307	\N	54.062649	Ульяновская область, Вешкаймский район, с. Вешкайма, адрес помещения для голосования: ул. Школьная, д. 7, адрес УИК: ул. Мира, д. 5		0101000020E6100000221ADD41EC8247404510E7E104084B40
7109	7	74	1787	26046	47069	\N	54.049954	Ульяновская область, Вешкаймский район, р.п. Вешкайма, ул. Труда, д. 6А		0101000020E6100000D218ADA3AA8F4740F62686E464064B40
7112	7	74	1787	26046	47071	\N	54.049954	Ульяновская область, Вешкаймский район, р.п. Вешкайма, ул. Лесхозная, д. 19		0101000020E6100000D218ADA3AA8F4740F62686E464064B40
7111	7	74	1787	26046	47018	\N	54.049954	Ульяновская область, Вешкаймский район, р.п. Вешкайма, ул. Комсомольская, д. 14а		0101000020E6100000D218ADA3AA8F4740F62686E464064B40
7110	7	74	1787	26046	46872	\N	54.049954	Ульяновская область, Вешкаймский район, р.п. Вешкайма, ул. Комсомольская, д. 3		0101000020E6100000D218ADA3AA8F4740F62686E464064B40
7120	7	74	1787	26537	47458	\N	54.049298999999998	Ульяновская область, Вешкаймский район, с. Березовка, ул. Калинина, д. 3		0101000020E6100000F86F5E9CF8A84740DD5CFC6D4F064B40
7113	7	74	1787	26215	47437	\N	54.151327999999999	Ульяновская область, Вешкаймский район, с. Белый Ключ, ул. Волынцева, д. 37		0101000020E61000004487C091409147400B7C45B75E134B40
7134	7	74	1787	27190	47460	\N	53.859392	Ульяновская область, Вешкаймский район, с. Беклемишево, ул. Школьная, д. 22	Россия, Ульяновская область, Вешкаймский район, село Беклемишево	0101000020E610000061FA5E4370B44740D6389B8E00EE4A40
7122	7	74	1787	26630	47313	\N	54.087532000000003	Ульяновская область, Вешкаймский район, с. Бекетовка, адрес помещения для голосования: ул. Центральная, д. 49, адрес УИК: ул. Цветочная, д. 2		0101000020E6100000B3295778976F47403FADA23F340B4B40
7132	7	74	1787	27069	47439	\N	53.938495000000003	Ульяновская область, Вешкаймский район, с. Ахматово-Белый Ключ, ул. Клубная, д. 6		0101000020E6100000B2D47ABFD1824740D23AAA9A20F84A40
7075	7	74	162	24410	47267	\N	53.564996000000001	Ульяновская область, Барышский район, р.п. им. В.И. Ленина, адрес помещения для голосования: ул. Молодежная, д. 3А, адрес УИК: ул. Ленина, д. 52		0101000020E610000098C3EE3B867D4740772FF7C951C84A40
7074	7	74	162	24410	47014	\N	53.564996000000001	Ульяновская область, Барышский район, р.п. им. В.И. Ленина, адрес помещения для голосования: ул. Ленина, д. 51, адрес УИК: ул. Ленина, д. 33		0101000020E610000098C3EE3B867D4740772FF7C951C84A40
7104	7	74	162	25811	47270	\N	53.693095999999997	Ульяновская область, Барышский район, с. Чувашская Решетка, адрес помещения для голосования: ул. Шоссейная, д. 11, адрес УИК: ул. Советская, д. 45		0101000020E61000008202EFE4D3834740847EA65EB7D84A40
79748	7	72	\N	55034	48034	\N	53.090951538487303	г. Новокуйбышевск, ул. Чернышевского,  6	Россия	0101000020E6100000DB8827BB99F54840BEC0AC50A48B4A40
7082	7	74	162	24791	47559	\N	53.387855999999999	Ульяновская область, Барышский район, с. Сурские Вершины, ул. Старая, д. 20		0101000020E6100000BDFF8F132678474058C7F143A5B14A40
7083	7	74	162	24859	47021	\N	53.720933000000002	Ульяновская область, Барышский район, р.п. Старотимошкино, ул. Советская, д. 62		0101000020E6100000AB764D486BC44740B8CD548847DC4A40
7084	7	74	162	24859	46937	\N	53.720933000000002	Ульяновская область, Барышский район, р.п. Старотимошкино, ул. Пролетарская, д. 1		0101000020E6100000AB764D486BC44740B8CD548847DC4A40
7103	7	74	162	25774	47474	\N	53.755386000000001	Ульяновская область, Барышский район, д. Старая Савадерка, ул. Центральная, д. 25		0101000020E61000005C3CBCE7C07E47409AED0A7DB0E04A40
7087	7	74	162	25028	47454	\N	53.718071999999999	Ульяновская область, Барышский район, с. Смольково, ул. Нижняя, д. 24		0101000020E6100000C05C8B16A0D547402F1686C8E9DB4A40
7069	7	74	162	62068	81080	\N	53.574416200000002	Ульяновская область, Барышский район, пос. Самородки, адрес помещения для голосования: ул. Школьная. д. 7А, адрес УИК: ул. Нагорная, д. 2	Россия, Ульяновская область, Барышский район, село Учхоз	0101000020E6100000B8CEBF5DF67347404A26A77686C94A40
7081	7	74	162	24776	47435	\N	53.394482000000004	Ульяновская область, Барышский район, с. Русская Бекшанка, ул. Центральная, 7	Россия, Ульяновская область, Барышский район, село Русская Бекшанка	0101000020E610000014AFB2B6298C47402B6EDC627EB24A40
7080	7	74	162	24710	47262	\N	53.528775000000003	Ульяновская область, Барышский район, с. Румянцево, ул. Чкалова, д. 152А		0101000020E6100000A7785C548B7E4740A1F831E6AEC34A40
7105	7	74	162	25856	47318	\N	53.613050999999999	Ульяновская область, Барышский район, пос. Поливаново, адрес помещения для голосования: ул. Школьная, д. 1, адрес УИК: пер. Березки, д. 4	Россия, Ульяновская область, Барышский район, село Поливаново	0101000020E6100000C971A774B0AE4740DAE3857478CE4A40
7068	7	74	162	24101	47550	\N	53.594324	Ульяновская область, Барышский район, с. Павловка, ул. Молодежная, д. 28		0101000020E61000008386FE092E6247402C9D0FCF12CC4A40
7093	7	74	162	25282	47552	\N	53.485348999999999	Ульяновская область, Барышский район, с. Осока, ул. Молодежная, д. 2		0101000020E610000061A6ED5F59A54740BA1281EA1FBE4A40
7102	7	74	162	25740	47514	\N	53.809635999999998	Ульяновская область, Барышский район, с. Новый Дол, адрес помещения для голосования: ул. Молодежная, д. 2А, адрес УИК: ул. Центральная, д. 4		0101000020E61000004AD3A0681E94474006D50627A2E74A40
7073	7	74	162	24347	47452	\N	53.665196999999999	Ульяновская область, Барышский район, с. Новая Ханинеевка, ул. Центральная, д. 15		0101000020E61000000B5EF415A49B4740DB32E02C25D54A40
7067	7	74	162	55838	47641	\N	53.560677029819701	Ульяновская область, Барышский район, с. Новая Деревня, ул. Центральная, д. 55	Россия, Ульяновская область, Барышский район, село Новая Деревня	0101000020E61000007F8978EBFC6D4740484F9143C4C74A40
7079	7	74	162	24662	47436	\N	53.388204999999999	Ульяновская область, Барышский район, с. Новая Бекшанка, адрес помещения для голосования: ул. Центральная, д. 27, адрес УИК: ул. Центральная, д. 29		0101000020E61000006552431B80874740649291B3B0B14A40
7099	7	74	162	25578	47269	\N	53.756706000000001	Ульяновская область, Барышский район, с. Малая Хомутерь, ул. Новоселов, д. 7		0101000020E6100000478FDFDBF4894740EF5701BEDBE04A40
7072	7	74	162	24306	47384	\N	53.814968999999998	Ульяновская область, Барышский район, с. Ляховка, пер. Центральный, д. 8		0101000020E610000030D978B0C5A847407D2079E750E84A40
7098	7	74	162	25530	\N	\N	53.612741	Ульяновская область, Барышский район, пос. Лесная Дача, здание фельдшерско-акушерского пункта	Россия, Ульяновская область, Барышский район, село Лесная Дача	0101000020E61000004B9352D0ED8347408CF50D4C6ECE4A40
7092	7	74	162	25216	47461	\N	53.491602	Ульяновская область, Барышский район, с. Кудажлейка, ул. Молодежная, д. 11	Россия, Ульяновская область, Барышский район, село Кудажлейка	0101000020E61000003F355EBA499E4740F85278D0ECBE4A40
7078	7	74	162	24622	47562	\N	53.430931000000001	Ульяновская область, Барышский район, с. Красная Поляна, ул. Центральная, д. 48		0101000020E6100000965E9B8D9564474092EA3BBF28B74A40
7097	7	74	162	25485	47563	\N	53.605047999999996	Ульяновская область, Барышский район, с. Красная Зорька, ул. Школьная, д. 1		0101000020E6100000F46F97FDBA8147404E417E3672CD4A40
7096	7	74	162	25441	47560	\N	53.565193000000001	Ульяновская область, Барышский район, с. Конновка, ул. Седова, д. 23		0101000020E61000000EBBEF181E974740CD76853E58C84A40
7091	7	74	162	25177	47561	\N	53.446978999999999	Ульяновская область, Барышский район, с. Киселевка, ул. Новая, д. 34		0101000020E610000060764F1E169A4740D87F9D9B36B94A40
7090	7	74	162	25148	47455	\N	53.516511000000001	Ульяновская область, Барышский район, с. Кармалейка, ул. Центральная, д. 15		0101000020E6100000F27C06D49B8B47401B834E081DC24A40
7086	7	74	162	24959	46865	\N	53.783825999999998	Ульяновская область, Барышский район, с. Калда, ул. Советская, д. 58		0101000020E61000001407D0EFFBBF474093E00D6954E44A40
7071	7	74	162	24182	46855	\N	53.721294999999998	Ульяновская область, Барышский район, р.п. Измайлово, ул. Школьная, д. 2		0101000020E6100000F44E05DCF39E474058E2016553DC4A40
7070	7	74	162	24182	46856	\N	53.721294999999998	Ульяновская область, Барышский район, р.п. Измайлово, ул. Советская, д. 14		0101000020E6100000F44E05DCF39E474058E2016553DC4A40
7095	7	74	162	25373	47457	\N	53.643498000000001	Ульяновская область, Барышский район, пос. Земляничный, ул. Плодопитомническая, д. 10/1		0101000020E6100000605969520A8A47404D8578245ED24A40
7085	7	74	162	24946	47266	\N	53.725014000000002	Ульяновская область, Барышский район, с. Заречное, ул. Зеленая, д. 7А		0101000020E6100000115663096BCB474032923D42CDDC4A40
7089	7	74	162	25114	47456	\N	53.418771999999997	Ульяновская область, Барышский район, с. Загарино, ул. Парковая, д. 16		0101000020E610000030B8E68EFE9F4740813D26529AB54A40
7088	7	74	162	25050	47255	\N	53.481330999999997	Ульяновская область, Барышский район, с. Живайкино, адрес помещения для голосования: ул. Школьная, д. 7, адрес УИК: ул. Советская, д. 41		0101000020E6100000BB0A293FA990474086C613419CBD4A40
7066	7	74	162	23957	47279	\N	53.574257000000003	Ульяновская область, Барышский район, р.п. Жадовка, ул. Гая, д. 3		0101000020E61000008D9AAF928F794740E23FDD4081C94A40
7065	7	74	162	23957	47265	\N	53.574257000000003	Ульяновская область, Барышский район, р.п. Жадовка, ул. Гагарина, д. 3А		0101000020E61000008D9AAF928F794740E23FDD4081C94A40
7077	7	74	162	24546	47432	\N	53.477311999999998	Ульяновская область, Барышский район, с. Головцево, ул. Молодежная, д. 28		0101000020E61000008D7A8846776E474082FE428F18BD4A40
7076	7	74	162	24512	47551	\N	53.515706999999999	Ульяновская область, Барышский район, с. Воецкое, ул. Советская, д. 25		0101000020E6100000C0B33D7AC3774740BDA8DDAF02C24A40
7107	7	74	162	25980	47596	\N	53.634669000000002	Ульяновская область, Барышский район, с. Водорацк, адрес помещения для голосования: ул. Школьная, д. 1, адрес УИК: ул. Солнечная, д. 2А		0101000020E610000095BA641C23A747407C6473D53CD14A40
7101	7	74	162	25674	47549	\N	53.844695999999999	Ульяновская область, Барышский район, с. Барышская Дурасовка, ул. Горная, д. 1А		0101000020E610000020CF2EDFFA944740F0879FFF1EEC4A40
7100	7	74	162	25637	47459	\N	53.715181435947201	Ульяновская область, Барышский район, с. Алинкино, адрес помещения для голосования: пер. Больничный, д. 1, адрес УИК: ул. Клубная, д. 28	Россия, Ульяновская область, Барышский район, село Алинкино	0101000020E6100000593673486A8147403CDC0E0D8BDB4A40
7106	7	74	162	25915	47346	\N	53.673572	Ульяновская область, Барышский район, с. Акшуат, адрес помещения для голосования: ул. Колхозная, д. 1 А, адрес УИК: ул. Ленина, д. 1А		0101000020E61000005169C4CC3EB747402BC0779B37D64A40
7043	7	74	1691	55808	\N	\N	53.681735681522298	Ульяновская область, Базарносызганский район, п. Сосновый Бор, здание школы	Россия, Ульяновская область, Базарносызганский район	0101000020E6100000EB556474405C4740C040102043D74A40
7041	7	74	1691	22840	\N	\N	53.724125000000001	Ульяновская область, Базарносызганский район, с. Ясачный Сызган, здание фельдшерско - акушерского пункта	Россия, Ульяновская область, Базарносызганский район, село Ясачный Сызган	0101000020E6100000056A3178986A4740A69BC420B0DC4A40
7048	7	74	1691	23139	\N	\N	53.646844999999999	Ульяновская область, Базарносызганский район, с. Юрловка, задание школы	Россия, Ульяновская область, Базарносызганский район, село Юрловка	0101000020E610000002637D0393654740624A24D1CBD24A40
7036	7	74	1691	22633	\N	\N	53.691021999999997	Ульяновская область, Базарносызганский район, п. Черный Ключ, здание фельдшерско - акушерского пункта	Россия, Ульяновская область, Базарносызганский район, село Черный Ключ	0101000020E6100000DF6DDE38295447408368AD6873D84A40
7042	7	74	1691	22886	\N	\N	53.788789000000001	Ульяновская область, Базарносызганский район, д. Русская Хомутерь, здание фельдшерско - акушерского пункта	Россия, Ульяновская область, Базарносызганский район, село Русская Хомутерь	0101000020E610000036AD1402B9724740E738B709F7E44A40
7037	7	74	1691	55832	\N	\N	53.726857615901999	Ульяновская область, Базарносызганский район, п. Раздолье, здание библиотеки	Россия, Ульяновская область, Базарносызганский район	0101000020E61000006DFDF49F35554740016BD5AE09DD4A40
7049	7	74	1691	23192	\N	\N	53.674340000000001	Ульяновская область, Базарносызганский район, с. Патрикеево, задание школы		0101000020E610000029064834816A47403C31EBC550D64A40
7046	7	74	1691	23068	\N	\N	53.579245	Ульяновская область, Базарносызганский район, с. Папузы, здание школы	Россия, Ульяновская область, Базарносызганский район, село Папузы	0101000020E6100000FEEF880AD55347408EAF3DB324CA4A40
7047	7	74	1691	23111	\N	\N	53.593859000000002	Ульяновская область, Базарносызганский район, д. Папуз-Гора, здание фельдшерско - акушерского пункта	Россия, Ульяновская область, Базарносызганский район, село Папуз-Гора	0101000020E61000004D49D6E1E84E4740B7B75B9203CC4A40
7040	7	74	1691	55820	\N	\N	53.745686475197203	Ульяновская область, Базарносызганский район, с. Лапшаур, адрес помещения для голосования: здание фельдшерско - акушерского пункта, адрес УИК: здание администрации	Россия, Ульяновская область, Базарносызганский район, село Папшаур	0101000020E6100000BEF90D130D684740E38A8BA372DF4A40
7039	7	74	1691	22750	\N	\N	53.865291999999997	Ульяновская область, Базарносызганский район, с. Красная Сосна, здание школы	Россия, Ульяновская область, Базарносызганский район, село Красная Сосна	0101000020E6100000FDFA213658664740C6BE64E3C1EE4A40
7050	7	74	1691	23248	\N	\N	53.633904999999999	"Ульяновская область, Базарносызганский район, д. Иевлевка, здание конторы ОАО ""МАСЛОДЕЛ"""	Россия, Ульяновская область, Базарносызганский район, село Иевлевка	0101000020E6100000D061BEBC005F4740ACE28DCC23D14A40
7038	7	74	1691	55842	\N	\N	53.685200486882302	Ульяновская область, Базарносызганский район, п. Дубки, здание фельдшерско - акушерского пункта		0101000020E61000002AFF5A5EB95C47400F9C33A2B4D74A40
7035	7	74	1691	22576	\N	\N	53.731721	Ульяновская область, Базарносызганский район, с. Должниково, адрес помещения для голосования: здание школы, адрес УИК: здание сельского Дома культуры		0101000020E610000006F52D73BA524740F165A208A9DD4A40
83851	7	73	\N	1193	30608	\N	51.467862916337303	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 5, ул. Менделеева, д. 3а		0101000020E6100000514A0856D511474015014EEFE2BB4940
7044	7	74	1691	22972	\N	\N	53.513672999999997	Ульяновская область, Базарносызганский район, с. Годяйкино, здание фельдшерско - акушерского пункта	Россия, Ульяновская область, Базарносызганский район, село Годяйкино	0101000020E610000023F8DF4A764A47404AEB6F09C0C14A40
7045	7	74	1691	23026	\N	\N	53.511997000000001	Ульяновская область, Базарносызганский район, с. Вороновка, здание фельдшерско - акушерского пункта	Россия, Ульяновская область, Базарносызганский район, село Вороновка	0101000020E61000005BCF108E595847403753211E89C14A40
7031	7	74	1691	22393	47067	\N	53.753970000000002	Ульяновская область, Базарносызганский район, р.п. Базарный Сызган, ул. Советская, д. 82		0101000020E61000006C7C26FBE76147402315C61682E04A40
7033	7	74	1691	22393	46857	\N	53.753970000000002	Ульяновская область, Базарносызганский район, р.п. Базарный Сызган, ул. Рабочая, д. 34		0101000020E61000006C7C26FBE76147402315C61682E04A40
7034	7	74	1691	22393	47427	\N	53.753970000000002	Ульяновская область, Базарносызганский район, р.п. Базарный Сызган, ул. Дорожная, д. 1		0101000020E61000006C7C26FBE76147402315C61682E04A40
7032	7	74	1691	22393	47008	\N	53.753970000000002	Ульяновская область, Базарносызганский район, р.п. Базарный Сызган, ул. Авдеева, д. 113		0101000020E61000006C7C26FBE76147402315C61682E04A40
83884	7	73	\N	1193	\N	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, МОУ ООШ № 26, ул. Маяковского, д. 167		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83865	7	73	\N	1193	\N	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, Музыкально-эстетический лицей, ул. Тельмана, д. 3	Россия, Саратовская область, Энгельс	0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83852	7	73	\N	1193	31079	\N	51.446000620804803	Саратовская область, Энгельсский район, г. Энгельс, ОАО Завод металлоконструкций, просп. Строителей, д. 68		0101000020E610000094A0BFD023124740DD7D8E8F16B94940
83846	7	73	\N	1193	30763	\N	51.596253860053402	Саратовская область, Энгельсский район, г. Энгельс, ДК Дружба, ул. Ломоносова, д. 21а	Россия, Саратовская область, Саратов, проспект Ломоносова, 21	0101000020E610000006F2ECF2ADFB4640FA0D130D52CC4940
83862	7	73	\N	1193	31291	\N	51.4959649966274	Саратовская область, Энгельсский район, г. Энгельс, Технологический институт СГТУ, площадь Свободы, д. 17		0101000020E6100000A75D4C33DD0F4740F67AF7C77BBF4940
81474	7	73	\N	1193	30730	\N	51.330997000000004	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 23, г. Энгельс-1		0101000020E6100000BEBED6A5462E47407D09151C5EAA4940
83895	7	73	\N	1193	30463	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, ЖКУ поселка Зеленый, г.Энгельс - 10, ул. Щорса, д. 22		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83866	7	73	\N	1193	31526	\N	51.499927293577301	Саратовская область, Энгельсский район, г. Энгельс, учебный корпус, ул. Халтурина, д. 25		0101000020E6100000F032C346590F474096B1A19BFDBF4940
83871	7	73	\N	1193	31499	\N	51.501250423575598	Саратовская область, Энгельсский район, г. Энгельс, Спортивно-оздоровительный комплекс Олимпия, ул. Тургенева, д. 14		0101000020E61000002C29779FE30947405C8FC2F528C04940
83874	7	73	\N	1193	30961	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 24, ул. Транспортная, д. 30		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83868	7	73	\N	1193	30605	\N	51.495437508304001	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 33, ул. Тельмана, д. 2		0101000020E6100000AAD4EC81560E47400B992B836ABF4940
83857	7	73	\N	1193	30605	\N	51.4836994367611	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 1, ул. Тельмана, д. 139		0101000020E61000001B81785DBF104740D00D4DD9E9BD4940
83864	7	73	\N	1193	30966	\N	51.500017999999997	Саратовская область, Энгельсский район, г. Энгельс, Театр оперетты, ул. Театральная, д. 2		0101000020E6100000556CCCEB880F4740A6B4FE9600C04940
83834	7	73	\N	1193	31125	\N	51.498860160999698	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 19, ул. Студенческая, д. 26а		0101000020E6100000C9E6AA798E1447402BA4FCA4DABF4940
83830	7	73	\N	1193	31125	\N	51.508921117204103	Саратовская область, Энгельсский район, г. Энгельс, ул. Студенческая, д. 195 здание Энгельсского государственного профессионально-педагогического колледжа		0101000020E61000001E6FF25B74184740B29FC55224C14940
83856	7	73	\N	1193	31248	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 18, ул. Строительная, д. 32		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83855	7	73	\N	1193	2427	\N	51.460602000000002	Саратовская область, Энгельсский район, г. Энгельс, ДК Строитель, проспект Строителей, д. 7		0101000020E61000005E49F25CDF114740713C9F01F5BA4940
83835	7	73	\N	1193	30404	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, Дом - интернат для престарелых и инвалидов, ул. Санаторная, д. 3		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83861	7	73	\N	1193	31491	\N	51.500551000000002	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 12, ул. Пушкина, д. 1а		0101000020E61000002A8BC22E8A104740747D1F0E12C04940
83848	7	73	\N	1193	30190	\N	51.476666000000002	Саратовская область, Энгельсский район, г. Энгельс, Институт бизнеса и делового администрирования, ул.Полтавская, д. 27а		0101000020E61000004AB8904770134740BD8E386403BD4940
83858	7	73	\N	1193	31372	\N	51.486730919516397	Саратовская область, Энгельсский район, г. Энгельс, общежитие Поволжского кооп. техникума,ул. Полиграфическая, д. 57		0101000020E6100000B2648EE55D11474085798F334DBE4940
83831	7	73	\N	1193	30794	\N	51.501975586224802	Саратовская область, Энгельсский район, г. Энгельс, медицинский колледж, ул. Новая, д. 21		0101000020E61000009755D80C701347403EB0E3BF40C04940
79738	7	72	\N	55034	48034	\N	53.524417999999997	город Новокуйбышевск, Чернышевского, 16		0101000020E6100000A77686A92DB3484084B7072120C34A40
83850	7	73	\N	1193	30608	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 3, ул. Менделеева, д. 7		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83832	7	73	\N	1193	30347	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, подростковый клуб Юность, ул. Маршала Василевского, д. 50		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83843	7	73	\N	1193	31653	\N	51.479723998045401	Саратовская область, Энгельсский район, г. Энгельс, диспетчерская ООО Транс - Лайн, ул. М. Расковой, д. 4		0101000020E61000009B5434D6FE1247409B8D959867BD4940
83870	7	73	\N	1193	30464	\N	51.498503363349897	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 14, ул. Лесозаводская, д. 2в		0101000020E6100000D36A48DC630B47409CFA40F2CEBF4940
83888	7	73	\N	1193	30870	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, админ.здание Анисовской дистанции пути (ПЧ-18), ул.Курчатова, д. 12		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83885	7	73	\N	1193	30349	\N	51.4565251104192	Саратовская область, Энгельсский район, г. Энгельс, ДК Искра ул. Крупской, д. 24		0101000020E6100000881057CEDE0D4740386744696FBA4940
83900	7	73	\N	1193	31335	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, село Квасниковка, здание администрации, ул. Колхозная, д. 129а		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83839	7	73	\N	1193	31110	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 30, ул. Колотилова, д. 82		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83837	7	73	\N	1193	31110	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, ДК Мелиоратор, ул. Колотилова, д. 6а		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83836	7	73	\N	1193	31110	\N	51.488965999999998	Саратовская область, Энгельсский район, г. Энгельс, подростково - молодежный клуб Мечта, ул. Колотилова, д. 54		0101000020E61000007A724D81CC1447408F6D197096BE4940
83876	7	73	\N	1193	31303	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, 1-й корпус профессионального лицея № 34, ул. Железнодорожная, д. 13		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83898	7	73	\N	1193	30673	\N	51.330997000000004	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ  № 31, г.Энгельс-23, ул. Гагарина, д. 65а		0101000020E6100000BEBED6A5462E47407D09151C5EAA4940
83897	7	73	\N	1193	30673	\N	51.479852017205701	Саратовская область, Энгельсский район, г. Энгельс, здание ВолжНИИГиМ, ул. Гагарина, д. 1		0101000020E610000019E76F42210E4740C97553CA6BBD4940
83886	7	73	\N	1193	31161	\N	51.449052000000002	Саратовская область, Энгельсский район, г. Энгельс, Энгельсская районная концертная организация, ул. Воронежская, д. 84		0101000020E61000008ECEF9298E0B4740091A33897AB94940
83867	7	73	\N	1193	30621	\N	51.492010999999998	Саратовская область, Энгельсский район, г. Энгельс, МОУ Кадетская школа Патриот, ул. Волоха, д. 16		0101000020E61000002448A5D8D10E4740D9226937FABE4940
83899	7	73	\N	1193	31439	\N	51.374256926556299	Саратовская область, Энгельсский район, г. Энгельс, с. Квасниковка, здание ДК Волга, пер Большевистский		0101000020E610000043572250FD03474048A643A7E7AF4940
83890	7	73	\N	1193	30758	\N	51.484438277305799	Саратовская область, Энгельсский район, г. Энгельс, ДК Покровский, г.Энгельс-2		0101000020E61000000AF4893C491A474046787B1002BE4940
83840	7	73	\N	1193	30919	\N	51.483020454821698	Саратовская область, Энгельсский район, г. Энгельс, Запсибгазпром, ул. 2-я Ленинградская, д. 51		0101000020E6100000992D5915E11247402FA86F99D3BD4940
83882	7	73	\N	1193	30791	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, ПУ № 9, 4-й корпус ГОУ СПО Энгельсский политехникум 1-й Микрорайон, д. 13б		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83909	7	73	\N	11330	30860	\N	51.562120999999998	Саратовская область, Энгельсский район, с. Шумейка, здание  МОУ СОШ, ул. Советская, д. 92		0101000020E6100000B30B06D7DC1F474089B2B794F3C74940
83826	7	73	\N	1659	30308	\N	52.492902000000001	Саратовская область, Хвалынский район, город Хвалынск, ул. Советская, д.55  (Санаторная школа-интернат)		0101000020E61000008B1A4CC3F00B48400611A969173F4A40
83825	7	73	\N	1659	30308	\N	52.492875157843798	Саратовская область, Хвалынский район, город Хвалынск, ул. Советская, д. 130 (ГОУ Школа-интернат)	Россия, Саратовская область, Хвалынск	0101000020E6100000774CDD955D0C48400C022B87163F4A40
83827	7	73	7272	\N	31117	\N	52.4898503815268	Саратовская область, Хвалынский район, город Хвалынск, ул. Росреспублики, д. 116 д.118  (ГОУ НПО ПУ-71)	Россия, Саратовская область, Хвалынск городской округ	0101000020E6100000786000E1430D484009F9A067B33E4A40
83828	7	73	\N	1659	30388	\N	52.492902000000001	Саратовская область, Хвалынский район, город Хвалынск, ул. Верхняя Слободка, д. 49 ул.Октябрьская, д.2Б здание информационного центра  (ФГБУНациональный парк)		0101000020E61000008B1A4CC3F00B48400611A969173F4A40
83713	7	73	\N	53189	\N	\N	51.569002198462996	Саратовская область, Саратовский район, р.п.Соколовый, (МОУ СОШ р.п. Соколовый)	Россия, Саратовская область, поселок городского типа Соколовый	0101000020E6100000691D554D10EB4640E6ADBA0ED5C84940
82503	7	73	\N	29	\N	\N	51.613222999999998	Саратовская область, город Саратов, Ленинский район, посёлок Латухино, начальная школа-детский сад №88		0101000020E6100000852348A5D8F54640D7135D177ECE4940
82338	7	73	\N	29	\N	\N	51.562721734054897	Саратовская область, город Саратов, Волжский район, совхоз Комбайн (МОУ СОШ №66 им. Н.И.Вавилова)	Россия, Саратовская область, Саратов, Волжский район	0101000020E610000056B60F79CB0B4740AF5E454607C84940
82453	7	73	\N	29	1233	\N	51.568201000000002	Саратовская область, город Саратов, Ленинский район, ул. Шехурдина, д. 2 (Общежитие ГОУ ВПО СГСЭУ)		0101000020E61000008944A165DDFF4640FA4674CFBAC84940
82334	7	73	\N	29	1001	\N	51.528531000000001	Саратовская область, город Саратов, Волжский район, ул. Челюскинцев, д. 12	Россия, Саратовская область, Саратов, улица Челюскинцев, 12	0101000020E61000002219726C3D0747400AF65FE7A6C34940
82420	7	73	\N	29	710	\N	51.564180999999998	Саратовская область, город Саратов, Кировский район, ул. Техническая, д. 14 (клуб Островок)		0101000020E6100000DB3521AD31FE46402503401537C84940
83859	7	73	\N	29	31366	\N	51.563017738790897	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 10, ул. Телеграфная, д. 88	Россия, Саратовская область, Саратов, улица Телеграфная	0101000020E6100000E5620CACE3FC464098874CF910C84940
82433	7	73	\N	29	724	\N	51.586385999999997	Саратовская область, город Саратов, Кировский район, ул. Танкистов, д. 126 (МОУ СОШ №71)	Россия, Саратовская область, Саратов, улица Танкистов, 126	0101000020E6100000E2E6543200044740876A4AB20ECB4940
82480	7	73	\N	29	30947	\N	51.589061495251102	Саратовская область, город Саратов, Ленинский район, ул. Строителей, МОУ СОШ №105	Россия, Саратовская область, Саратов, улица Строителей	0101000020E6100000884CF91054ED4640AE2CD15966CB4940
82575	7	73	\N	29	30707	\N	51.536570595865797	Саратовская область, город Саратов, Фрунзенский район, ул. им. Разина С.Т, д. 32 (МОУ СОШ №1)	Россия, Саратовская область, Саратов, улица Степана Разина, 36	0101000020E61000002ECA6C9049004740B37DC85BAEC44940
82404	7	73	\N	29	30375	\N	51.547234736063999	Саратовская область, город Саратов, Кировский район, ул.  Разина, д. 89 (МДОУ Детский сад №136)	Россия, Саратовская область, Саратов, улица Степана Разина, 89	0101000020E61000003FC571E0D5004740001DE6CB0BC64940
94380	7	73	\N	29	1281	\N	51.530749999999998	Саратовская область, Петровский район, ул. Советская, д. 79 (МОУ СОШ №3)	Россия, Саратовская область, Саратов, улица Советская, 77	0101000020E610000069E1B20A9B0147400E2DB29DEFC34940
82574	7	73	\N	29	30980	\N	51.536644195686002	Саратовская область, город Саратов, Фрунзенский район, ул. им. Слонова И.А, д. 37/41 (Детский сад Бэмби)	Россия, Саратовская область, Саратов, улица Слонова, 37/41	0101000020E6100000037976F9D6FF46401DCC26C0B0C44940
82397	7	73	\N	29	377	\N	51.511218999999997	Саратовская область, город Саратов, Заводской район, ул. Ростовская, д.29, (МОУ ООШ № 22)		0101000020E6100000077AA86DC3F84640020CCB9F6FC14940
82348	7	73	\N	29	7914	\N	51.537231317240398	Саратовская область, город Саратов, Волжский район, ул. Рогожина, д. 24/32 (МОУ СОШ №10)	Россия, Саратовская область, Саратов, улица Рогожина	0101000020E610000028F1B913EC074740DDB243FCC3C44940
94358	7	73	\N	29	2861	\N	51.534899931406997	Саратовская область, город Саратов, МОУ «Средняя общеобразовательная школа № 18, ул. им. Рахова В.Г., дом № 124, тел. 51-66-62	Россия, Саратовская область, Саратов, улица Рахова, 124	0101000020E610000018B325AB22024740B1506B9A77C44940
82505	7	73	\N	29	1923	\N	51.605096930129598	Саратовская область, город Саратов, Ленинский район, ул. Перспективная, д. 9А (МОУ Гимназия №87)	Россия, Саратовская область, Саратов, улица Перспективная, 9	0101000020E610000022A81ABD1AFE464030F488D173CD4940
82513	7	73	\N	29	31280	\N	51.587790010175098	Саратовская область, город Саратов, Ленинский район, ул. Ипподромная, МОУ СОШ №46	Россия, Саратовская область, Саратов, улица Овражная	0101000020E6100000F4F928232EFE46403A75E5B33CCB4940
82407	7	73	\N	29	517	\N	51.542485999999997	Саратовская область, город Саратов, Кировский район, ул. Московская, д. 185 (Участковый пункт полиции 9)		0101000020E61000006612F5824FFF4640D844662E70C54940
81745	7	73	\N	29	31100	\N	51.5865792675026	Саратовская область, город Саратов, Волжский район, ул. Молодежная, д. 31 (МУК Клуб Парус)	Россия, Саратовская область, Саратов, улица Молодежная	0101000020E6100000ACE5CE4C300E47409CC24A0515CB4940
82525	7	73	\N	29	2215	\N	51.525919999999999	Саратовская область, город Саратов, Октябрьский район, ул.Мичурина, д.88 (МОУ Гимназия №1)		0101000020E6100000B4CC22145B034740FA27B85851C34940
83887	7	73	\N	29	1398	\N	51.5818062612014	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 20, ул. Мира, д. 20	Россия, Саратовская область, Саратов, улица Мира, 20	0101000020E6100000E411DC48D9FA4640EC4E779E78CA4940
82386	7	73	\N	29	173	\N	51.480625567651202	Саратовская область, город Саратов, Заводской район, УЛ. им.Маркина Н.Г., Д.17/39, (МОУ СОШ № 39)	Россия, Саратовская область, Саратов, улица Маркина	0101000020E6100000874ECFBBB1F04640BCCD1B2785BD4940
82384	7	73	\N	29	173	\N	51.480679160914796	Саратовская область, город Саратов, Заводской район, ул. им.Маркина Н.Г., д.17/39, (МОУ СОШ № 59)	Россия, Саратовская область, Саратов, улица Маркина	0101000020E6100000718E3A3AAEF04640DF6FB4E386BD4940
82476	7	73	\N	29	1567	\N	51.589576000000001	Саратовская область, город Саратов, Ленинский район, ул. Крылова, д. 1Б (детский сад №177)		0101000020E61000004419AA622AF54640D540F33977CB4940
82549	7	73	\N	29	2612	\N	51.529477999999997	Саратовская область, город Саратов, Октябрьский район, ул.Клочкова, д.74 (Городская поликлиника №10)		0101000020E6100000A08A1BB798FB4640CAF962EFC5C34940
82352	7	73	\N	29	7959	\N	51.568218000000002	Саратовская область, город Саратов, Волжский район, Ново-Соколовогорский поселок, ул. Казанская, д. 29 (МОУ СОШ №66 им.Н.И.Вавилова)		0101000020E6100000211FF46C56074740D07F0F5EBBC84940
83412	7	73	\N	29	606	\N	51.547784197839597	Саратовская область, Озинский район, с.Светлое Озеро, ул. Зеленая, д.7 (МОУ Основная школа)	Россия, Саратовская область, Саратов, улица Зеленая	0101000020E61000001AA4E029E4044740D3A23EC91DC64940
79749	7	72	\N	55034	77214	\N	53.096157944047199	г. Новокуйбышевск, ул. Успенского, 2а		0101000020E610000039268BFB8FF84840D89FC4E74E8C4A40
82449	7	73	\N	29	1168	\N	51.537680000000002	Саратовская область, город Саратов, Кировский район, ул. Большая Казачья, д. 110 (МУППСаратовгорэлектротранс)	Россия, Саратовская область, Саратов, улица Большая Казачья, 110	0101000020E6100000AE49B725720147404DDBBFB2D2C44940
82523	7	73	\N	29	2196	\N	51.603082000000001	Саратовская область, город Саратов, Ленинский район, ул. Бардина, д. 3 (МОУ СОШ №61)		0101000020E61000009A94826E2FFF464034677DCA31CD4940
82447	7	73	\N	29	1126	\N	51.5428	Саратовская область, город Саратов, Кировский район, ул. Астраханская, д. 138 (Детская поликлиника №2)	Россия, Саратовская область, Саратов, улица Астраханская, 138	0101000020E610000087DC0C37E001474068226C787AC54940
82377	7	73	\N	29	31631	\N	51.497725000000003	Саратовская область, город Саратов, Заводской район, проспект Энтузиастов, д.48, (МОУ СОШ № 34)		0101000020E61000003929CC7B9CF7464068B3EA73B5BF4940
82508	7	73	\N	29	30918	\N	51.58717	Саратовская область, город Саратов, Ленинский район, проспект Строителей, д. 6/1 (центр детского творчества)		0101000020E6100000D462F030EDFB46409E98F56228CB4940
82496	7	73	\N	29	30588	\N	51.5950841685002	Саратовская область, город Саратов, Ленинский район, ул. Ломоносова, д. 20 (центр народного творчества)		0101000020E61000005CAE7E6C92FB4640BA2F67B62BCC4940
82493	7	73	\N	29	30582	\N	51.597543795410203	Саратовская область, город Саратов, Ленинский район, ул. Ломоносова, д. 14 (МУК ЦДТТ Романтик)	Россия, Саратовская область, Саратов, проспект Ломоносова	0101000020E6100000014D840D4FFB4640E4F560527CCC4940
83853	7	73	\N	29	30810	\N	51.599230313370299	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 9, ул. Ломоносова, д. 7а	Россия, Саратовская область, Саратов, проспект Ломоносова	0101000020E610000067D2A6EA1EFB46401B649291B3CC4940
82467	7	73	\N	29	31310	\N	51.565915515544098	Саратовская область, город Саратов, Ленинский район, проспект им. 50 лет Октября, д. 107 (МОУ Гимназия №108) т.63-10-69	Россия, Саратовская область, Саратов, проспект 50 лет Октября, 63	0101000020E6100000FD2E6CCD56FE46403E247CEF6FC84940
82535	7	73	\N	29	71745	\N	51.522499646730303	Саратовская область, город Саратов, Октябрьский район, Весенний проезд, дом 4, т.20-22-43	Россия, Саратовская область, Саратов, проезд Весенний	0101000020E6100000DA8CD310550047407B14AE47E1C24940
82358	7	73	\N	29	30926	\N	51.489869469218199	Саратовская область, город Саратов, Заводской район, поселок Юриш, Адм.здание Речпорт	Россия, Саратовская область, Саратов, Заводской район	0101000020E610000083FC6CE4BAFB464080290307B4BE4940
82462	7	73	\N	29	30762	\N	51.580500210018997	Саратовская область, город Саратов, Ленинский район, площадь им. Ленина В.И, ОГУК ДК Россия	Россия, Саратовская область, Саратов, улица 50 лет Октября	0101000020E610000056BB26A435FC4640FCA9F1D24DCA4940
83863	7	73	\N	29	30593	\N	51.532784852883601	Саратовская область, Энгельсский район, г. Энгельс, Театр оперетты, ул. Театральная, д 2	Россия, Саратовская область, Саратов, площадь Театральная, 1	0101000020E610000041295AB9170447405166834C32C44940
82562	7	73	\N	29	31511	\N	51.532936351411799	Саратовская область, город Саратов, Фрунзенский район, Театральная площадь, д. 13 (Дворец творчества Д и М)	Россия, Саратовская область, Саратов, площадь Театральная	0101000020E6100000C2F693313E044740376E313F37C44940
83845	7	73	\N	29	31084	\N	51.526099070533697	Саратовская область, Энгельсский район, г. Энгельс, подростковый клуб Орлёнок, ул. Космонавтов, д. 19	Россия, Саратовская область, Саратов, набережная Космонавтов	0101000020E6100000EF74E789E7064740AABA473657C34940
82375	7	73	\N	29	30244	\N	51.467430999999998	Саратовская область, город Саратов, Заводской район, ул. им.Пономарева П.Т., д. 10/15, (МОУ ДОД Центр внешкольной работы)		0101000020E61000000806103E94F446407B116DC7D4BB4940
82372	7	73	\N	29	30679	\N	51.492116838357902	Саратовская область, город Саратов, Заводской район, ул. им.Пономарева П.Т., д.49, (МОУ СОШ № 43)	Россия, Саратовская область, Саратов, улица Пономарева	0101000020E6100000053411363CF746401F679AB0FDBE4940
82506	7	73	\N	29	31640	\N	51.601784000000002	Саратовская область, город Саратов, Ленинский район, ул. Академика Антонова, д. 10 (геологический колледж)		0101000020E6100000A48AE255D6FC4640C7A0134207CD4940
82497	7	73	\N	29	31640	\N	51.603143000000003	Саратовская область, город Саратов, Ленинский район, ул. Академика Антонова, д. 5 (Городская поликлиника №17)		0101000020E61000004AEF1B5F7BFC4640DAE731CA33CD4940
82361	7	73	\N	29	31596	\N	51.469805000000001	Саратовская область, город Саратов, Заводской район, ул. Южно-Зеленая, д. 11-А, (МОУ СОШ № 84)		0101000020E61000006A882AFC19F64640A73FFB9122BC4940
82391	7	73	\N	29	31528	\N	51.502355999999999	Саратовская область, город Саратов, Заводской район, ул. Южная, д.46, (МОУ СОШ № 38)		0101000020E6100000766EDA8CD3F4464085798F334DC04940
82371	7	73	\N	29	51	\N	51.505456000000002	Саратовская область, город Саратов, Заводской район, проспект Энтузиастов, д.14, (МОУ Лицей № 15)	Россия, Саратовская область, Саратов, Энтузиастов проспект, 14	0101000020E6100000857AFA08FCF9464093C83EC8B2C04940
83729	7	73	\N	29	31537	\N	51.568649000000001	Саратовская область, Советский район, станция Наливная, ул. Школьная, д. 14 (Здание библиотеки)		0101000020E6100000E02A4F20ECFC464099F38C7DC9C84940
82478	7	73	\N	29	31508	\N	51.572148737070499	Саратовская область, город Саратов, Ленинский район, ул. Широкая, д. 34 (МОУ СОШ №52)		0101000020E6100000658D7A8846F1464035B8AD2D3CC94940
82490	7	73	\N	29	31605	\N	51.593246000000001	Саратовская область, город Саратов, Ленинский район, ул. Шехурдина, д. 56А (МОУ СОШ №102)		0101000020E610000060014C1938FA4640CD3D247CEFCB4940
82583	7	73	\N	29	31500	\N	51.539614747657502	Саратовская область, город Саратов, Фрунзенский район, ул. Шелковичная, д. 181 (ООО Нова Терра)		0101000020E6100000E1F08288D4FC46402CB7B41A12C54940
82582	7	73	\N	29	31500	\N	51.541499999999999	Саратовская область, город Саратов, Фрунзенский район, ул. Шелковичная, д. 186 (бизнес-центр ТЕСАР)		0101000020E6100000793A579412FC46405A643BDF4FC54940
82581	7	73	\N	29	31500	\N	51.541940350493299	Саратовская область, город Саратов, Фрунзенский район, ул. Шелковичная, д. 224 (Детский сад №221 Росинка)	Россия, Саратовская область, Саратов, улица Шелковичная	0101000020E61000009B92ACC3D1FB46407632384A5EC54940
82580	7	73	\N	29	31500	\N	51.540649000000002	Саратовская область, город Саратов, Фрунзенский район, ул. Шелковичная, д. 178 (здание МОУДОД ДЮЦ района)		0101000020E6100000A25D85949FFC4640BCCE86FC33C54940
82567	7	73	\N	29	31500	\N	51.536867999999998	Саратовская область, город Саратов, Фрунзенский район, ул. Шелковичная, д. 141 (МОУ СОШ №77)		0101000020E6100000AD4ECE50DCFD46406C223317B8C44940
82519	7	73	\N	29	31611	\N	51.603825999999998	Саратовская область, город Саратов, Ленинский район, ул. Чехова, д. 4А (кадетская школа-интернат №2)		0101000020E6100000C23060C955004740BC3C9D2B4ACD4940
82517	7	73	\N	29	31611	\N	51.602769000000002	Саратовская область, город Саратов, Ленинский район, ул. Чехова, д. 1А (МОУ СОШ №55)		0101000020E6100000946C7539250047407505DB8827CD4940
82329	7	73	\N	29	31623	\N	51.524619999999999	Саратовская область, город Саратов, Волжский район, ул. Чернышевского, д. 138 (МОУ Гимназия №2)		0101000020E61000000492B06F27054740EC6987BF26C34940
82326	7	73	\N	29	31623	\N	51.522815000000001	Саратовская область, город Саратов, Волжский район, ул. Чернышевского, д. 151		0101000020E61000008F8CD5E6FF034740DB6D179AEBC24940
82500	7	73	\N	29	31648	\N	51.607607000000002	Саратовская область, город Саратов, Ленинский район, ул. Чемодурова, д. 8А (станция юных туристов)		0101000020E6100000452BF702B3FC46400CE9F010C6CD4940
82439	7	73	\N	29	31576	\N	51.535866164262501	Саратовская область, город Саратов, Кировский район, ул. Челюскинцев, д. 114 (Мин-во строительства и ЖКХ)	Россия, Саратовская область, Саратов, улица Челюскинцев, 114	0101000020E610000019ADA3AA09044740E884D04197C44940
82528	7	73	\N	29	31610	\N	51.524512999999999	Саратовская область, город Саратов, Октябрьский район, ул.Чапаева, д.14/26 (Детская поликлиника №1)		0101000020E6100000892650C422024740D6A9F23D23C34940
82511	7	73	\N	29	30613	\N	51.587131488814698	Саратовская область, город Саратов, Ленинский район, ул. Центральная, д. 28 (детская музык. школа №5)	Россия, Саратовская область, Саратов, улица Центральная	0101000020E6100000239F573CF5FC4640E0BBCD1B27CB4940
82537	7	73	\N	29	31649	\N	51.525072999999999	Саратовская область, город Саратов, Октябрьский район, ул.Хользунова, д.19 (Городская поликлиника №8)		0101000020E6100000AE635C71710047409D81919735C34940
82336	7	73	\N	29	31115	\N	51.575720503440301	Саратовская область, город Саратов, Волжский район, ул. Федоровская, д. 3 (МОУ Гимназия №7)	Россия, Саратовская область, Саратов, Федоровская улица, 3	0101000020E610000096CB46E7FC0847406A4FC939B1C94940
82522	7	73	\N	29	31637	\N	51.611835999999997	Саратовская область, город Саратов, Ленинский район, ул. Уфимцева, д. 4А (МОУ СОШ №63)		0101000020E61000000CEA5BE674FF4640FA415DA450CE4940
82405	7	73	\N	29	31592	\N	51.541011461742897	Саратовская область, город Саратов, Кировский район, ул. Университетская, д. 59 (Художественное училище)	Россия, Саратовская область, Саратов, Университетская улица, 59	0101000020E61000002DCF83BBB30047405CE333D93FC54940
82411	7	73	\N	29	31645	\N	51.555529999999997	Саратовская область, город Саратов, Кировский район, ул. Украинская, д. 6 (МУЗ Поликлиника №2 филиал)		0101000020E61000002FDCB930D2FF464033F9669B1BC74940
82380	7	73	\N	29	31644	\N	51.476883999999998	Саратовская область, город Саратов, Заводской район, ул. Тульская, д.17, (Библиотека № 22)		0101000020E6100000904C874ECFF346402AFEEF880ABD4940
82379	7	73	\N	29	31644	\N	51.476883999999998	Саратовская область, город Саратов, Заводской район, ул. Тульская, д.17, (МУК ЦБС г.Саратова Библиотека № 22)		0101000020E6100000904C874ECFF346402AFEEF880ABD4940
82452	7	73	\N	29	31622	\N	51.572141999999999	Саратовская область, город Саратов, Ленинский район, ул. Тулайкова, д. 7 (НИИ Юго-Востока)		0101000020E61000001021AE9CBDFF46408255F5F23BC94940
82410	7	73	\N	29	31615	\N	51.553351999999997	Саратовская область, город Саратов, Кировский район, ул. Тракторная, д. 33 (МОУ СОШ №54)		0101000020E610000091459A78070047408D96033DD4C64940
83872	7	73	\N	29	30717	\N	51.497192395616999	Саратовская область, Энгельсский район, г. Энгельс, МОУ ООШ № 7, ул. Телефонная, д. 1		0101000020E6100000E2E7BF07AF0747409AEAC9FCA3BF4940
82458	7	73	\N	29	31618	\N	51.571033999999997	Саратовская область, город Саратов, Ленинский район, ул. Тверская, д. 45 (МОУ СОШ №41)		0101000020E61000004912842BA0FC4640B87361A417C94940
82526	7	73	\N	29	30186	\N	51.5286121186437	Саратовская область, город Саратов, Октябрьский район, ул.Т.Шевченко, д.26 (Центр. детск. музыкал. школа)		0101000020E6100000C30C8D2782024740F722DA8EA9C34940
82432	7	73	\N	29	31527	\N	51.577736646356698	Саратовская область, город Саратов, Кировский район, ул. Танкистов, д. 103 (клуб Дружба)	Россия, Саратовская область, Саратов, улица Танкистов, 103	0101000020E6100000CEFE40B96D03474036583849F3C94940
82425	7	73	\N	29	31527	\N	51.558711000000002	Саратовская область, город Саратов, Кировский район, ул. Танкистов, д. 55 А (ЗАО Завод Медтехника)		0101000020E61000007FA4880CAB0247402E7590D783C74940
82441	7	73	\N	29	31570	\N	51.542845	Саратовская область, город Саратов, Кировский район, ул. Посадского, д. 193 (МОУ СОШ №21)		0101000020E6100000FDDB65BFEE02474008E6E8F17BC54940
82421	7	73	\N	29	31527	\N	51.568570838176399	Саратовская область, город Саратов, Кировский район, ул. Танкистов, д. 93  (ГОУ Школа-интернат №2)	Россия, Саратовская область, Саратов, улица Танкистов	0101000020E610000025CD1FD3DA0247401D3A3DEFC6C84940
82510	7	73	\N	29	1933	\N	51.58717	Саратовская область, город Саратов, Ленинский район, проспект Строителей, д. 6 (стоматологическая полик-ка)		0101000020E6100000D462F030EDFB46409E98F56228CB4940
82509	7	73	\N	29	1933	\N	51.588898999999998	Саратовская область, город Саратов, Ленинский район, проспект Строителей, д. 12 (МДОУ Детский сад №161)		0101000020E61000006153E751F1FB4640D4D2DC0A61CB4940
82479	7	73	\N	29	30238	\N	51.589495897197203	Саратовская область, город Саратов, Ленинский район, п. Жасминный,  ул. Строителей, МОУ СОШ №105		0101000020E61000002ECA6C9049EC4640B88FDC9A74CB4940
82332	7	73	\N	29	31647	\N	51.529254000000002	Саратовская область, город Саратов, Волжский район, ул. Соляная, д. 17 (МОУ СОШ №9)		0101000020E6100000382D78D1570647407BA35698BEC34940
82350	7	73	\N	29	31584	\N	51.553242916447402	Саратовская область, город Саратов, Волжский район, ул. Соколовогорская, д. 8 (ГОУ НПО ПУ №22)	Россия, Саратовская область, Саратов, Соколовогорская улица, 8	0101000020E6100000297AE063B0064740D7DEA7AAD0C64940
82335	7	73	\N	29	71757	\N	51.5308750288007	"Саратовская область, город Саратов, Волжский район, подростковый клуб ""Дружба"", ул.Соколовая, д.18/40, т.28-87-05 "		0101000020E6100000B9C1508715084740CBA145B6F3C34940
82518	7	73	\N	29	31651	\N	51.529791000000003	Саратовская область, город Саратов, Октябрьский район, ул.Советская, д.46 (Лицей №3 им.А.С.Пушкина)		0101000020E6100000098B8A389D0247408A5B0531D0C34940
82330	7	73	\N	29	31577	\N	51.533019000000003	Саратовская область, город Саратов, Волжский район, ул. Соборная, д. 33 (МОУ СОШ №8)		0101000020E61000004EF1B8A816054740C59272F739C44940
82327	7	73	\N	29	31577	\N	51.530638000000003	Саратовская область, город Саратов, Волжский район, ул. Соборная, д. 23/25 (ПАГС им.Столыпина)		0101000020E61000005FB4C70BE9044740E7012CF2EBC34940
82531	7	73	\N	29	31561	\N	51.522776	Саратовская область, город Саратов, Октябрьский район, ул.Симбирцева, д.34 (МОУ СОШ №6)		0101000020E61000009D6340F67A0147401D91EF52EAC24940
82597	7	73	\N	29	31567	\N	51.532671000000001	Саратовская область, Александрово-Гайский  район, хутор Морозов, ул. Северная, д. 11(сельский клуб)		0101000020E61000005D19541B9C064740894336902EC44940
82576	7	73	\N	29	31601	\N	51.537551000000001	Саратовская область, город Саратов, Фрунзенский район, ул. Свинцовая, д. 10а (Детский сад №25 Маячок)		0101000020E610000016A3AEB5F7FD46404F779E78CEC44940
82414	7	73	\N	29	31627	\N	51.559052000000001	Саратовская область, город Саратов, Кировский район, ул. Рябиновская, д. 21 (МДОУ Детский сад №65)		0101000020E6100000B4588AE42BFF4640B76114048FC74940
82398	7	73	\N	29	31513	\N	51.511218999999997	Саратовская область, город Саратов, Заводской район, ул. Ростовская, д.29, (МОУ ООШ № 29)		0101000020E6100000077AA86DC3F84640020CCB9F6FC14940
83689	7	73	\N	29	31545	\N	51.670514549018797	Саратовская область, Саратовский район, поселок Дубки, ул. Рахова, д. 22 А (МУК Дом культуры п. Дубки)		0101000020E610000077BCC96FD10947401D3D7E6FD3D54940
82565	7	73	\N	29	31545	\N	51.534767000000002	Саратовская область, город Саратов, Фрунзенский район, ул. им. Рахова В.Г, д. 124 (МОУ СОШ №18)		0101000020E6100000A3EA573A1F02474072FDBB3E73C44940
82340	7	73	\N	29	31612	\N	51.534117000000002	Саратовская область, город Саратов, Волжский район, ул. Радищева, д. 32 МОУ Национальная татарская гимназия		0101000020E61000009C31CC09DA0447406B9E23F25DC44940
82339	7	73	\N	29	31612	\N	51.539315999999999	Саратовская область, город Саратов, Волжский район, ул. Радищева, д. 89 (ФГОУ ВПО СГСЭУ)		0101000020E610000004AF963B33054740D21A834E08C54940
82328	7	73	\N	29	31612	\N	51.526088000000001	Саратовская область, город Саратов, Волжский район, ул. Радищева, д. 18 (МОУ СОШ №8)		0101000020E6100000EA04341136044740B66801DA56C34940
94356	7	73	\N	29	31549	\N	51.526172000000003	"Саратовская область, город Саратов, ул. Рабочая, 32 МДОУ ""Детский сад"" №15"		0101000020E61000001A14CD03580247401409A69A59C34940
82569	7	73	\N	29	31549	\N	51.534083000000003	Саратовская область, город Саратов, Фрунзенский район, ул. Рабочая, д. 106а (СК Юность)		0101000020E6100000401878EE3D004740BF2CEDD45CC44940
82566	7	73	\N	29	30254	\N	51.538304968911	Саратовская область, город Саратов, Фрунзенский район, ул. им. Пугачева Е.И, д. 119 (Дет/сад №219 Колокольчик)	Россия, Саратовская область, Саратов, Пугачевская улица	0101000020E61000008AAC3594DA014740FB22A12DE7C44940
82448	7	73	\N	29	31228	\N	51.537917537271298	Саратовская область, город Саратов, Кировский район, ул. Пугачева, д. 123 (МОУ СОШ №67)	Россия, Саратовская область, Саратов, Пугачевская улица	0101000020E61000003F8EE6C8CA01474001F73C7FDAC44940
82507	7	73	\N	29	31656	\N	51.597822999999998	Саратовская область, город Саратов, Ленинский район, ул. Производственная, д. 5 (МОУ СОШ №103)		0101000020E61000003EEAAF5758FC4640F7E5CC7685CC4940
94357	7	73	\N	29	31617	\N	51.522787000000001	"Саратовская область, город Саратов, ул. Провиантская, 7 МДОУ ""Детский сад комбинированного вида №56"		0101000020E61000008F368E588B03474011E335AFEAC24940
82406	7	73	\N	29	15777	\N	51.541988000000003	Саратовская область, город Саратов, Кировский район, Привокзальная площадь, д. 1 (ж/д вокзал Саратов-1)		0101000020E6100000BCE9961DE2FF46408869DFDC5FC54940
82446	7	73	\N	29	31570	\N	51.5434667139561	Саратовская область, город Саратов, Кировский район, ул. Посадского, д. 248 (Лицей математики и инф-ки)	Россия, Саратовская область, Саратов, улица Посадского	0101000020E6100000ADFBC7427402474045BA9F5390C54940
80042	7	72	393	45409	48616	\N	53.530819000000001	поселок Передовка, Юбилейная, 2-А		0101000020E6100000DFF8DA334BDA4940378C82E0F1C34A40
82373	7	73	\N	29	30819	\N	51.494472087279703	Саратовская область, город Саратов, Заводской район, ул им.Пономарева П.Т.,.д. 49, (МОУ СОШ № 43)	Россия, Саратовская область, Саратов, улица Пономарева	0101000020E6100000707A17EFC7F74640D464C6DB4ABF4940
82544	7	73	\N	29	31589	\N	51.521599000000002	Саратовская область, город Саратов, Октябрьский район, ул.Политехническая, д.62/70 (подростковый клуб Атлет)		0101000020E6100000DEC66647AAFD46402B508BC1C3C24940
82504	7	73	\N	29	31580	\N	51.605124000000004	Саратовская область, город Саратов, Ленинский район, ул. Перспективная, д. 9/10 (МОУ ООШ №44)		0101000020E61000000FB8AE9811FE46402A0307B474CD4940
82502	7	73	\N	29	31580	\N	51.613357000000001	Саратовская область, город Саратов, Ленинский район, ул. Перспективная, д. 29 (МОУ ООШ №57)		0101000020E610000087DBA16131FE4640E7E26F7B82CE4940
82491	7	73	\N	29	31609	\N	51.589799999999997	Саратовская область, город Саратов, Ленинский район, ул. Осенняя, д. 5 (МОУ СОШ №75)		0101000020E6100000EFCA2E185CFB46402497FF907ECB4940
82460	7	73	\N	29	31597	\N	51.577615999999999	Саратовская область, город Саратов, Ленинский район, ул. Одесская, д. 7 (МАОУ Лицей №36)		0101000020E6100000D8F335CB65FB4640BBD23252EFC94940
82401	7	73	\N	29	31591	\N	51.516235999999999	Саратовская область, город Саратов, Заводской район, ул. Огородная, д.33, (МОУ СОШ № 106)		0101000020E61000008ACA863595FB46404982700514C24940
82396	7	73	\N	29	31591	\N	51.506414999999997	Саратовская область, город Саратов, Заводской район, ул. Огородная, д.173, (МОУ СОШ № 173)		0101000020E610000047753A90F5F64640179AEB34D2C04940
82395	7	73	\N	29	31591	\N	51.506414999999997	Саратовская область, город Саратов, Заводской район, ул. Огородная, д.173, (МОУ СОШ № 78)		0101000020E610000047753A90F5F64640179AEB34D2C04940
82394	7	73	\N	29	31591	\N	51.500652000000002	Саратовская область, город Саратов, Заводской район, ул. Огородная, д. 196, (МОУ СОШ № 5)		0101000020E6100000556B6116DAF54640A8565F5D15C04940
82392	7	73	\N	29	31591	\N	51.500652000000002	Саратовская область, город Саратов, Заводской район, ул. Огородная, д.196, (МОУ СОШ № 5)		0101000020E6100000556B6116DAF54640A8565F5D15C04940
82577	7	73	\N	29	31548	\N	51.535041	Саратовская область, город Саратов, Фрунзенский район, ул. Новоузенская, д. 162 (Детский сад №186 Белочка)		0101000020E61000004B8FA67A32FD4640738236397CC44940
82368	7	73	\N	29	30445	\N	51.467430999999998	Саратовская область, город Саратов, Заводской район, ул. Ново-Крекингская, д.47, (МОУ ООШ № 26)		0101000020E61000000806103E94F446407B116DC7D4BB4940
82362	7	73	\N	29	30445	\N	51.468190219383501	Саратовская область, город Саратов, Заводской район, ул. Ново-Крекингская, д. 47 (МОУ ООШ № 26)	Россия, Саратовская область, Саратов, улица Южно-Зеленая, 47	0101000020E6100000FF08C38025F54640392861A6EDBB4940
82402	7	73	\N	29	30355	\N	51.510579559708503	Саратовская область, город Саратов, Заводской район, Ново-Астраханское шоссе, д.47, (Библиотека № 31)	Россия, Саратовская область, Саратов, Ново-Астраханское шоссе, 47	0101000020E6100000732F302B14FB4640EFFE78AF5AC14940
82387	7	73	\N	29	30360	\N	51.495077999999999	Саратовская область, город Саратов, Заводской район, Ново-Астраханское шоссе, д..56, (МУК Центр культуры и досуга)		0101000020E6100000AF06280D35F646400B7C45B75EBF4940
82417	7	73	\N	29	31573	\N	51.561498999999998	Саратовская область, город Саратов, Кировский район, ул. Наумовская, д. 39 А (Детская поликлиника №4)		0101000020E6100000D671FC5069FE46404CDE0033DFC74940
82415	7	73	\N	29	31573	\N	51.559427999999997	Саратовская область, город Саратов, Кировский район, ул. Наумовская, д. 11 (МОУ СОШ №17)		0101000020E61000009C4EB2D5E5FE4640BC3B32569BC74940
82489	7	73	\N	29	30365	\N	51.606426999999996	Саратовская область, город Саратов, Ленинский район, ул. Московское шоссе, д. 4 (ОАО Трансаммиак)	Россия, Саратовская область, Саратов, Московское шоссе, 4	0101000020E6100000F4A5B73F17F54640A83462669FCD4940
82488	7	73	\N	29	30365	\N	51.596435999999997	Саратовская область, город Саратов, Ленинский район, ул. Московское шоссе, д. 17 (ЗАО АКБ Экспресс-Волга)	Россия, Саратовская область, Саратов, Московское шоссе, 17	0101000020E61000004ACFF41263F746401A14CD0358CC4940
82440	7	73	\N	29	31585	\N	51.5377572738347	Саратовская область, город Саратов, Кировский район, ул. Московская, д. 137/149 (Поликлиника №1)	Россия, Саратовская область, Саратов, Московская улица, 137	0101000020E6100000C4EA8F300C024740F818AC38D5C44940
82408	7	73	\N	29	31585	\N	51.542653999999999	Саратовская область, город Саратов, Кировский район, ул. Московская, д. 170 (ОАО СарАвтовокзал)		0101000020E6100000AAD6C22CB4FF46409485AFAF75C54940
82323	7	73	\N	29	31585	\N	51.533383000000001	Саратовская область, город Саратов, Волжский район, ул. Московская, д. 64 (МОУ Лицей №4)		0101000020E6100000836DC493DD044740069FE6E445C44940
82573	7	73	\N	29	30400	\N	51.530033116466001	Саратовская область, город Саратов, Фрунзенский район, ул. им. Мичурина И.В, д. 2/12 (Дет/сад №236 Лукоморье)	Россия, Саратовская область, Саратов, улица Мичурина, 2	0101000020E6100000459E245D330147408066101FD8C34940
82570	7	73	\N	29	30400	\N	51.529798900614701	Саратовская область, город Саратов, Фрунзенский район, ул. им. Мичурина И.В, д. 16 (МОУ СОШ №2)		0101000020E61000007FA2B2614D0147400C3A2174D0C34940
82524	7	73	\N	29	31638	\N	51.525959	Саратовская область, город Саратов, Октябрьский район, ул.Мичурина, д.85 (общежитие СГППК им.Гагарина)		0101000020E6100000F486FBC8AD034740B804E09F52C34940
82341	7	73	\N	29	31638	\N	51.531354999999998	Саратовская область, город Саратов, Волжский район, ул. Мичурина, д. 202 ГОУ СПО Саратовский государственный колледж книжнего бизнеса и информационных технологий		0101000020E6100000BB9BA73AE406474075C8CD7003C44940
82333	7	73	\N	29	31638	\N	51.531354999999998	Саратовская область, город Саратов, Волжский район, ул. Мичурина, д. 202		0101000020E6100000BB9BA73AE406474075C8CD7003C44940
82564	7	73	\N	29	2050	\N	51.531298999999997	Саратовская область, город Саратов, Фрунзенский район, Мирный переулок, д. 3 (МАОУ Лицей №37)	Россия, Саратовская область, Саратов, Мирный переулок, 3	0101000020E61000004087F9F202024740E1B20A9B01C44940
82464	7	73	\N	29	31574	\N	51.580419999999997	Саратовская область, город Саратов, Ленинский район, ул. Мира, д. 15  (спортцентр Сокол)		0101000020E6100000B9C5FCDCD0FA4640DFF8DA334BCA4940
82463	7	73	\N	29	31574	\N	51.579726000000001	"""Саратовская область, город Саратов, Ленинский район, ул. Мира, д. 9В МДОУ ""Детский сад №132"""		0101000020E61000009148DBF813FB46400952297634CA4940
82481	7	73	\N	29	30786	\N	51.584073196560702	Саратовская область, город Саратов, Ленинский район, ул. Мелиораторов, МОУ СОШ №69	Россия, Саратовская область, Саратов, Ленинский район	0101000020E6100000B55208E412EB464001BD70E7C2CA4940
82469	7	73	\N	29	31619	\N	51.584119999999999	Саратовская область, город Саратов, Ленинский район, ул. Международная, д. 24 (торгово-экономический ун-т)		0101000020E610000088DA368C82FA46404278B471C4CA4940
83683	7	73	\N	29	31492	\N	51.4831270076157	Саратовская область, Саратовский район, поселок Тепличный, ул. Маркина, д.66 (Здание администрации)	Россия, Саратовская область, Саратов, улица Маркина	0101000020E61000000EDDEC0F94F146404568041BD7BD4940
82385	7	73	\N	29	31492	\N	51.482045767746598	Саратовская область, город Саратов, Заводской район, ул. им.Маркина Н.Г., д.17/39, (МОУ СОШ № 39)	Россия, Саратовская область, Саратов, улица Маркина	0101000020E6100000C7F2AE7AC0F046407495EEAEB3BD4940
83844	7	73	\N	29	30749	\N	51.492172301706198	Саратовская область, Энгельсский район, г. Энгельс, диспетчерская ООО Транс-Лайн, ул. М. Расковой, д. 4	Россия, Саратовская область, Саратов, улица Марины Расковой, 4	0101000020E61000004A0856D5CBF54640E200FA7DFFBE4940
83842	7	73	\N	29	30749	\N	51.492172301706198	Саратовская область, Энгельсский район, г. Энгельс, СОК (спортивно - оздоровительный комплекс), ул. М.Расковой, д. 4	Россия, Саратовская область, Саратов, улица Марины Расковой, 4	0101000020E61000004AD40B3ECDF54640E200FA7DFFBE4940
82388	7	73	\N	29	30749	\N	51.491122567847	Саратовская область, город Саратов, Заводской район, ул. им.Расковой М.М., д.12, (МОУ Гимназия № 58)	Россия, Саратовская область, Саратов, улица Марины Расковой, 12	0101000020E6100000B1F9B83654F646401EA8531EDDBE4940
82520	7	73	\N	29	31565	\N	51.606890889359001	Саратовская область, город Саратов, Ленинский район, ул. Мамонтовой, д. 1 (Городская поликлиника №19)	Россия, Саратовская область, Саратов, улица Мамонтовой	0101000020E61000002331410DDF0047404D9EB29AAECD4940
82486	7	73	\N	29	30370	\N	51.537652000000001	Саратовская область, город Саратов, Ленинский район, ул. Мало-Елшанская, д. 5 (МОУ СОШ №89)	Россия, Саратовская область, Саратов, Университетская улица	0101000020E6100000601DC70F950047408350DEC7D1C44940
82438	7	73	\N	29	31566	\N	51.540346	Саратовская область, город Саратов, Кировский район, ул. Горького, д. 91 (МОУ ДОД Школа искусств №10)		0101000020E6100000850A0E2F880447402043C70E2AC54940
82359	7	73	\N	29	30209	\N	51.472794932491901	Саратовская область, город Саратов, Заводской район, ул. Лесопильная, д.17, (МОУ ООШ № 104)	Россия, Саратовская область, Саратов, Заводской район	0101000020E610000011548D5E0DFA46402D5BEB8B84BC4940
82418	7	73	\N	29	31594	\N	51.563238617872102	Саратовская область, город Саратов, Кировский район, ул. Лесная, д. 1/9 (МОУ СОШ №31)	Россия, Саратовская область, Саратов, улица Придорожная	0101000020E6100000C214E5D2F8FF4640776A2E3718C84940
82501	7	73	\N	29	30587	\N	51.6059955888094	Саратовская область, город Саратов, Ленинский район, ул. Лебедева-Кумача, МОУ СОШ №101		0101000020E61000000E30F31DFCFC4640DFC0E44691CD4940
82512	7	73	\N	29	31628	\N	51.586851000000003	Саратовская область, город Саратов, Ленинский район, ул. Куприянова, д. 16 (стоматологическая полик-ка)		0101000020E61000001DCBBBEA01FD4640FD4FFEEE1DCB4940
82390	7	73	\N	29	31626	\N	51.489874	Саратовская область, город Саратов, Заводской район, ул. Крымская, д.2, (МОУ СОШ № 83)		0101000020E6100000514D49D6E1F646409294F430B4BE4940
82475	7	73	\N	29	31655	\N	51.589671000000003	Саратовская область, город Саратов, Ленинский район, ул. Крылова, д. 1 (клуб Современник)		0101000020E610000085B01A4B58F546402733DE567ACB4940
82409	7	73	\N	29	31636	\N	51.545752	Саратовская область, город Саратов, Кировский район, ул. Краевая, д. 85 (ГУП Бизнес-инкубатор)		0101000020E61000005BEA20AF07FF464001DD9733DBC54940
82342	7	73	\N	29	30402	\N	51.531294097064702	Саратовская область, город Саратов, Волжский район, ул. Комсомольская, д. 41 ГУК Саратовский областной Дом работников искусства	Россия, Саратовская область, Саратов, Комсомольская улица	0101000020E61000004D4D8237A4054740D047197101C44940
82331	7	73	\N	29	31564	\N	51.531187000000003	Саратовская область, город Саратов, Волжский район, ул. Комсомольская, д. 39 (МОУ Лицей прикладных наук)		0101000020E61000002DAF5C6F9B054740BA8784EFFDC34940
82884	7	73	\N	29	29034	\N	51.547426000000002	Саратовская область, Балтайский район, село Столыпино, ул. Колхозная, д. 1 (Столыпинский сельский ДК)		0101000020E61000007940D9942B024740747D1F0E12C64940
82550	7	73	\N	29	31671	\N	51.528693991913897	Саратовская область, город Саратов, Октябрьский район, ул.Клочкова, д.77 (МОУ СОШ №97)	Россия, Саратовская область, Саратов, улица Клочкова, 77	0101000020E61000008FFCC1C073FB4640B4CBB73EACC34940
82547	7	73	\N	29	31531	\N	51.536369000000001	Саратовская область, город Саратов, Октябрьский район, ул.Клиническая, д.7 (спорткомплекс Салют)		0101000020E6100000882AFC19DEFA46404BCB48BDA7C44940
82561	7	73	\N	29	2803	\N	51.530844999999999	Саратовская область, город Саратов, Фрунзенский район, проспект им. Кирова С.М, д. 2 (университет им. Н.И.Вавилова)	Россия, Саратовская область, Саратов, Кирова проспект, 2	0101000020E61000007C2C7DE882044740601F9DBAF2C34940
82376	7	73	\N	29	31536	\N	51.498885999999999	Саратовская область, город Саратов, Заводской район, ул. Кавказская, д.17, (МОУ СОШ № 40)		0101000020E610000053CA6B2574F746405437177FDBBF4940
82374	7	73	\N	29	31536	\N	51.494568000000001	Саратовская область, город Саратов, Заводской район, ул. Кавказская, д, 2-А, (МОУ Детский сад № 44)		0101000020E6100000F566D47C95F84640F6D214014EBF4940
82532	7	73	\N	29	15733	\N	51.521116999999997	Саратовская область, город Саратов, Октябрьский район, Ильинская площадь, д.1 (МОУ Лицей № 62)		0101000020E6100000060E68E90A024740DF313CF6B3C24940
82530	7	73	\N	29	15733	\N	51.519788596112498	Саратовская область, город Саратов, Октябрьский район, Ильинская площадь, д.4 (Колледж производ. технологий)	Россия, Саратовская область, Саратов, Ильинская площадь, 4	0101000020E6100000E886A6ECF401474008E9297288C24940
82529	7	73	\N	29	15733	\N	51.521116999999997	Саратовская область, город Саратов, Октябрьский район, Ильинская площадь, д.1 (МОУ Лицей №62)		0101000020E6100000060E68E90A024740DF313CF6B3C24940
82422	7	73	\N	29	31661	\N	51.563648999999998	Саратовская область, город Саратов, Кировский район, ул. Зенитная, д. 14 (Центр социальной помощи)		0101000020E6100000001DE6CB0B02474028B682A625C84940
82436	7	73	\N	29	31509	\N	51.548859999999998	Саратовская область, город Саратов, Кировский район, ул. Зеленая, д. 28 (ГОУ НПО ПУ №39)		0101000020E6100000AA9A20EA3E044740910A630B41C64940
82445	7	73	\N	29	31568	\N	51.542520000000003	Саратовская область, город Саратов, Кировский район, ул. Зарубина, д. 158/162 (Цент. библиотеч. сист.)		0101000020E6100000B0A9F3A8F801474085B69C4B71C54940
82367	7	73	\N	29	31547	\N	51.473720999999998	Саратовская область, город Саратов, Заводской район, ул. Заречная, д.1, (МОУ ООШ № 90)		0101000020E6100000D4D347E00FF54640D636C5E3A2BC4940
82495	7	73	\N	29	31660	\N	51.599082000000003	Саратовская область, город Саратов, Ленинский район, ул. Загороднева, д.2  (МОУ СОШ №48)		0101000020E61000006BD5AE0969FB4640A7CF0EB8AECC4940
82494	7	73	\N	29	31660	\N	51.599082000000003	Саратовская область, город Саратов, Ленинский район, ул. Загороднева, д2 (МОУ СОШ №48)		0101000020E61000006BD5AE0969FB4640A7CF0EB8AECC4940
82492	7	73	\N	29	31660	\N	51.595506999999998	Саратовская область, город Саратов, Ленинский район, ул. Загороднева, д. 16 (МОУ СОШ №50)		0101000020E610000091D5AD9E93FA464000C5C89239CC4940
82434	7	73	\N	29	31616	\N	51.558256999999998	Саратовская область, город Саратов, Кировский район, ул. Жуковского, д. 25 (ОАО Саратовские авиалинии)	Россия, Саратовская область, Саратов, улица Жуковского, 25	0101000020E610000075C8CD7003044740ACE122F774C74940
82430	7	73	\N	29	31616	\N	51.562680999999998	Саратовская область, город Саратов, Кировский район, ул. Жуковского, д. 24 (МОУ СОШ №24)		0101000020E61000003D0FEECEDA034740508A56EE05C84940
82429	7	73	\N	29	31616	\N	51.565178000000003	Саратовская область, город Саратов, Кировский район, ул. Жуковского, д. 1 (МОУ СОШ 93)		0101000020E6100000555051F52B0347409835B1C057C84940
82428	7	73	\N	29	31616	\N	51.565178000000003	Саратовская область, город Саратов, Кировский район, ул. Жуковского, д. 1 (МОУ СОШ №93)		0101000020E6100000555051F52B0347409835B1C057C84940
82403	7	73	\N	29	31581	\N	51.545848875414698	Саратовская область, город Саратов, Кировский район, ул. Железнодорожная, д. 61/69 (Городская поликлиника №2)		0101000020E61000006C43C5387F014740F3C64961DEC54940
82459	7	73	\N	29	75040	\N	51.574112496607697	Саратовская область, город Саратов, Ленинский район, ул. Им. Б.А.Дубовикова, д.5 т.55-53-24 МДОУ Детский сад компенсирующего вида № 199 (было:Тверская, д. 45 (МОУ СОШ №41)		0101000020E6100000CA880B40A3FC4640DE1E84807CC94940
82337	7	73	\N	29	31517	\N	51.573807058680003	Саратовская область, город Саратов, Волжский район, ул. Державинская, д. 1 (МОУ СОШ №66 им. Н.И.Вавилова)	Россия, Саратовская область, Саратов, Державинская улица, 1	0101000020E61000006A183E22A6084740A29BFD8172C94940
81759	7	73	\N	29	31493	\N	51.573287997496998	Саратовская область, город Саратов, Волжский район, ул. Державинская, д. 10 (МОУ Лицей №107)		0101000020E610000036E84B6F7F08474039984D8061C94940
82454	7	73	\N	29	1235	\N	51.565821999999997	Саратовская область, город Саратов, Ленинский район, Деловой проезд, д.5 МДОУ Детский сад 3 195 т.66-61-76 (было:ул. Шехурдина, д. 2 (Общежитие ГОУ ВПО СГСЭУ)	Россия, Саратовская область, Саратов, Деловой проезд, 3	0101000020E6100000357BA01518FE4640BCADF4DA6CC84940
82540	7	73	\N	29	31562	\N	51.516599999999997	Саратовская область, город Саратов, Октябрьский район, ул.Дегтярная, д.12 (МОУ СОШ №45)		0101000020E6100000FBAD9D2809FF46408A8EE4F21FC24940
82533	7	73	\N	29	31562	\N	51.516376000000001	Саратовская область, город Саратов, Октябрьский район, ул.Дегтярная, д.7 (МОУ СОШ №27)		0101000020E61000001C5DA5BBEBFE46403B38D89B18C24940
82427	7	73	\N	29	31643	\N	51.559777358415602	Саратовская область, город Саратов, Кировский район, ул. Высокая, д. 17 А (МДОУ Детский сад №131)		0101000020E6100000D7BE805EB8034740C806D2C5A6C74940
82343	7	73	\N	29	31497	\N	51.531895612173898	Саратовская область, город Саратов, Волжский район, ул. Вознесенская, д. 5 (МОУ Гимназия №4)	Россия, Саратовская область, Саратов, Вознесенская улица, 5	0101000020E61000001094DBF63D064740C66F0A2B15C44940
82456	7	73	\N	29	31532	\N	51.565244999999997	Саратовская область, город Саратов, Ленинский район, ул. Вишневая, д. 16 (МОУ СОШ №76)		0101000020E6100000E694809884FD46401F9DBAF259C84940
82455	7	73	\N	29	31532	\N	51.565244999999997	Саратовская область, город Саратов, Ленинский район, ул.Вишневая, д. 16 (МОУ СОШ №76)		0101000020E6100000E694809884FD46401F9DBAF259C84940
82378	7	73	\N	29	31659	\N	51.477590999999997	Саратовская область, город Саратов, Заводской район, ул. Васильковская, д.17, (МОУ ООШ № 81)		0101000020E6100000056B9C4D47F6464095EEAEB321BD4940
83829	7	73	\N	29	30208	\N	51.570356662870999	Саратовская область, Энгельсский район, пос. Прибрежный, здание Дома досуга Прибрежновский, ул. Вавилова, д. 2	Россия, Саратовская область, Саратов, лесопарк Кумысная Поляна	0101000020E61000002B4B749659F64640B8054B7501C94940
82360	7	73	\N	29	31613	\N	51.462718000000002	Саратовская область, город Саратов, Заводской район, ул. Брянская, д. 3, (МОУ Кадетская школа № 16)		0101000020E61000006F48A30227F74640A1A2EA573ABB4940
82444	7	73	\N	29	31603	\N	51.550372000000003	Саратовская область, город Саратов, Кировский район, ул. Большая Садовая, д. 240 (МОУ СОШ №70)		0101000020E6100000117349D5760147402B51F69672C64940
82412	7	73	\N	29	31603	\N	51.54853	Саратовская область, город Саратов, Кировский район, ул. Большая Садовая, д. 239 (МДОУ Детский сад №18)		0101000020E610000033A9A10DC0004740FC6F253B36C64940
82572	7	73	\N	29	31546	\N	51.539203999999998	Саратовская область, город Саратов, Фрунзенский район, ул. Большая Казачья, д. 125 (ОАО Газаппарат)		0101000020E6100000047289230F004740AAEFFCA204C54940
82571	7	73	\N	29	31546	\N	51.538416514318897	Саратовская область, город Саратов, Фрунзенский район, ул. Большая Казачья, д. 121 (МАОУ Гимназия №3)		0101000020E610000088BD50C076004740234E27D9EAC44940
82563	7	73	\N	29	31546	\N	51.534050000000001	Саратовская область, город Саратов, Фрунзенский район, ул. Большая Казачья, д. 43/45 (Дет/сад №180 Солнышко)		0101000020E6100000691D554D10034740E3361AC05BC44940
82450	7	73	\N	29	31546	\N	51.538446999999998	Саратовская область, город Саратов, Кировский район, ул. Большая Казачья, д. 112 а (СГУ им.Черныш. корпус №8)		0101000020E61000007C0E2C47C80047408DD0CFD4EBC44940
82347	7	73	\N	29	30969	\N	51.538748012686099	Саратовская область, город Саратов, Волжский район, ул. Большая Горная, д. 141МОУ Гуманитарно-экономический лицей	Россия, Саратовская область, Саратов, Большая Горная улица	0101000020E6100000A4198BA6B30547408864C8B1F5C44940
82443	7	73	\N	29	31494	\N	51.542503779240299	Саратовская область, город Саратов, Кировский район, ул. Большая Горная, д. 236 (Музыкальная школа №7)	Россия, Саратовская область, Саратов, Большая Горная улица, 231а	0101000020E6100000FB5A971AA10347407FF964C570C54940
82442	7	73	\N	29	31595	\N	51.544099000000003	Саратовская область, город Саратов, Кировский район, ул. Большая Горная, д. 277/279 (Центр детского твор-ва)		0101000020E61000009D82FC6CE4024740A6643909A5C54940
82346	7	73	\N	29	31595	\N	51.538347000000002	Саратовская область, город Саратов, Волжский район, ул. Большая Горная, д. 141 МОУ Гуманитарно-экономический лицей		0101000020E6100000A0E1CD1ABC0547402A73F38DE8C44940
82344	7	73	\N	29	31595	\N	51.529040999999999	Саратовская область, город Саратов, Волжский район, ул. Большая Горная, д. 1, ГОУ ДПО Саратовский институт повышения квалификации и переподготовки работников образования		0101000020E6100000219221C7D60747401F9F909DB7C34940
82515	7	73	\N	29	31505	\N	51.600612868697198	Саратовская область, город Саратов, Ленинский район, ул. Блинова, д. 19А (детский сад №156)		0101000020E61000006EDFA3FE7AFF4640B74604E3E0CC4940
82514	7	73	\N	29	31505	\N	51.600458047154497	Саратовская область, город Саратов, Ленинский район, ул. Блинова, д. 23А (детский сад №167)		0101000020E61000008E01D9EBDDFF4640904FC8CEDBCC4940
82431	7	73	\N	29	31558	\N	51.569308999999997	Саратовская область, город Саратов, Кировский район, ул. Бирюзова, д. 16 ( ГОУ СПО Техникум ПТ и АС)		0101000020E6100000B24B546F0D044740C328081EDFC84940
94355	7	73	\N	29	31620	\N	51.588853999999998	Саратовская область, город Саратов, ул. Бережная, 1 МОУ СОШ №72		0101000020E610000001A3CB9BC3F74640340F60915FCB4940
82471	7	73	\N	29	31620	\N	51.588853999999998	Саратовская область, город Саратов, Ленинский район, ул. Бережная, д. 1 (МОУ СОШ №72)		0101000020E610000001A3CB9BC3F74640340F60915FCB4940
82470	7	73	\N	29	67052	\N	51.588720445028201	"""Саратовская область, город Саратов, Ленинский район, МОУ ""СОШ №72"", ул. Бережная, д.1 т. 63-76-20."	Россия, Саратовская область, Саратов, улица Бережная, 1	0101000020E6100000D4BA0D6ABFF7464025404D2D5BCB4940
82424	7	73	\N	29	31633	\N	51.561354000000001	Саратовская область, город Саратов, Кировский район, ул. Безымянная, д. 6 (Городская поликлиника №11)		0101000020E61000007B4ACE893D02474049BDA772DAC74940
82521	7	73	\N	29	31604	\N	51.611172888269998	Саратовская область, город Саратов, Ленинский район, ул. Батавина, д. 6А (МОУ СОШ №60)	Россия, Саратовская область, Саратов, улица Батавина, 6а	0101000020E6100000ECDFF599B30047405F99B7EA3ACE4940
83896	7	73	\N	29	31556	\N	51.531118999999997	Саратовская область, Энгельсский район, г. Энгельс, МОУ Начальная школа-детский сад № 1 , ул. Аткарская, д. 22		0101000020E6100000CADFBDA3C6FE464061A417B5FBC34940
82542	7	73	\N	29	31583	\N	51.531754043023497	Саратовская область, город Саратов, Октябрьский район, ул.Аткарская, д.1В (МОУ СОШ №7)	Россия, Саратовская область, Саратов, Аткарская улица	0101000020E6100000EDD3F19881FE464033C2DB8310C44940
94354	7	73	\N	29	31630	\N	51.568095	Саратовская область, город Саратов, Кировский район, ул. Артиллерийская, д. 23 (МОУ СОШ №51)		0101000020E610000030F5F3A622014740B4024356B7C84940
82416	7	73	\N	29	31516	\N	51.560378999999998	Саратовская область, город Саратов, Кировский район, ул. Аптечная, д. 33/47 (МАОУ Кристаллик)		0101000020E6100000EC4E779E78FE4640BE2EC37FBAC74940
82383	7	73	\N	29	30843	\N	51.467430999999998	Саратовская область, город Саратов, Заводской район, ул. Азовская, д.15, (МОУ ООШ № 39)		0101000020E61000000806103E94F446407B116DC7D4BB4940
82369	7	73	\N	29	30616	\N	51.471121915984803	Саратовская область, город Саратов, Заводской район, ул. им. Азина В.М., д.34, (МУК ДК Химиков)	Россия, Саратовская область, Саратов, улица Азина	0101000020E6100000F295404AECF446408B36C7B94DBC4940
82468	7	73	\N	29	597	\N	51.584892000000004	Саратовская область, город Саратов, Ленинский район, проспект им. 50 лет Октября, д. 107 (МОУ Гимназия №108)		0101000020E6100000D4B6611404FB464095D8B5BDDDCA4940
82466	7	73	\N	29	597	\N	51.584892000000004	"""Саратовская область, город Саратов, Ленинский район, проспект им. 50 лет Октября, д. 107 (МОУ """"Гимназия №108"""")"""	Россия, Саратовская область, Саратов, 50 Лет Октября проспект, 107	0101000020E6100000D4B6611404FB464095D8B5BDDDCA4940
82457	7	73	\N	29	597	\N	51.569566999999999	Саратовская область, город Саратов, Ленинский район, проспект им. 50 лет Октября, д. 75 (МОУ СОШ №94)		0101000020E6100000A83AE466B8FD4640BFF04A92E7C84940
82413	7	73	\N	29	597	\N	51.558878999999997	Саратовская область, город Саратов, Кировский район, просп. 50 лет Октября, д. 34/56 (ГАУ КЦ соц.обслуживания)	Россия, Саратовская область, Саратов, 50 Лет Октября проспект, 34	0101000020E6100000861DC6A4BFFF4640E9B5D95889C74940
82400	7	73	\N	29	396	\N	51.510402671829098	Саратовская область, город Саратов, Заводской район, 5-й Нагорный проезд, д.3, (МОУ СОШ № 23)	Россия, Саратовская область, Саратов, 5-й Нагорный проезд	0101000020E6100000D12346CF2DFA4640E063B0E254C14940
82399	7	73	\N	29	396	\N	51.518689999999999	Саратовская область, город Саратов, Заводской район, 5-й Нагорный проезд, д. 3, (МОУ СОШ № 23)		0101000020E6100000338AE59656F946409161156F64C24940
82356	7	73	\N	29	31642	\N	51.507858903843797	Саратовская область, город Саратов, Заводской район, 4-й проезд им.Чернышевского Н.Г., д. 2, (МОУ СОШ № 53)	Россия, Саратовская область, Саратов, 4-й проезд Чернышевского	0101000020E61000002A53CC41D0FD464059FD118601C14940
82355	7	73	\N	29	31642	\N	51.5064127305317	Саратовская область, город Саратов, Заводской район, 4-й проезд им. Чернышевского Н.Г., д. 2, (МОУ СОШ № 53)	Россия, Саратовская область, Саратов, 4-й проезд Чернышевского	0101000020E61000002A53CC41D0FD464077A22424D2C04940
82484	7	73	\N	29	31621	\N	51.601885000000003	Саратовская область, город Саратов, Ленинский район, ул. 3-я Степная, д. 6 (МОУ Лицей №47)		0101000020E6100000C44142942FF44640FB7953910ACD4940
82499	7	73	\N	29	1879	\N	51.605040000000002	Саратовская область, город Саратов, Ленинский район, 3-й проезд Строителей, д. 3 (МОУ СОШ №56)	Россия, Саратовская область, Саратов, 3-й Строителей проезд, 3	0101000020E6100000265305A392FC4640CC6262F371CD4940
82485	7	73	\N	29	31543	\N	51.604314020900098	Саратовская область, город Саратов, Ленинский район, ул. Стахановская, д. 8 (МОУ ООШ №64)	Россия, Саратовская область, Саратов, 2-я Степная улица, 8	0101000020E61000002AC6F99B50F44640EA4141295ACD4940
82545	7	73	\N	29	31588	\N	51.531886999999998	Саратовская область, город Саратов, Октябрьский район, ул.2-я Садовая, д.106А (МОУ СОШ №82)		0101000020E6100000882F134548FD464072158BDF14C44940
82539	7	73	\N	29	31588	\N	51.523493000000002	Саратовская область, город Саратов, Октябрьский район, ул.2-я Садовая, д.39/53 (женск.консультация пол.№8)		0101000020E610000047904AB1A3FF4640AC5791D101C34940
82538	7	73	\N	29	31588	\N	51.520439000000003	Саратовская область, город Саратов, Октябрьский район, ул.2-я Садовая, д.23А (МДОУ Детский сад №21)		0101000020E61000001381EA1F440047400F48C2BE9DC24940
82536	7	73	\N	29	31588	\N	51.518858999999999	Саратовская область, город Саратов, Октябрьский район, ул.2-я Садовая, д.19 (Детский сад №31 Колосок)		0101000020E61000001B9FC9FE790047401D1EC2F869C24940
82534	7	73	\N	29	31588	\N	51.521044000000003	Саратовская область, город Саратов, Октябрьский район, ул.2-я Садовая, д.23 (МОУ СОШ №95)		0101000020E61000009E44847F1100474076E3DD91B1C24940
82487	7	73	\N	29	1726	\N	51.597996999999999	Саратовская область, город Саратов, Ленинский район, 2-й Московский проезд, д. 5 (МОУ СОШ №86)		0101000020E61000003CF71E2E39F64640950D6B2A8BCC4940
82426	7	73	\N	29	797	\N	51.559344000000003	Саратовская область, город Саратов, Кировский район, 2-й Магнитный проезд, д. 44 (МОУ СОШ №73)		0101000020E6100000556D37C1370347405F9B8D9598C74940
82546	7	73	\N	29	30441	\N	51.5238840260822	Саратовская область, город Саратов, Октябрьский район, 1-я Линия Октябрьсого поселка, д.3 (МОУ Лицей №2)	Россия, Саратовская область, Саратов, Октябрьский район, 1-я линия, 3	0101000020E6100000F88C446804FD4640E77283A10EC34940
82543	7	73	\N	29	30441	\N	51.523950953759602	Саратовская область, город Саратов, Октябрьский район, 1-я Линия Октябрьского поселка, д.3 (МОУ Лицей №2)	Россия, Саратовская область, Саратов, Октябрьский район, 1-я линия, 3	0101000020E6100000F9C08EFF02FD46406EDA8CD310C34940
82437	7	73	\N	29	31502	\N	51.546267177971202	Саратовская область, город Саратов, Кировский район, ул. 1-я Садовая, д. 35 (МОУ СОШ №14)	Россия, Саратовская область, Саратов, 1-я Садовая улица, 35	0101000020E6100000DA3A38D89B04474028F1B913ECC54940
82349	7	73	\N	29	31658	\N	51.544609000000001	Саратовская область, город Саратов, Волжский район, ул. 1-я Садовая, д. 2, МОУ Восточно-Европейский лицей		0101000020E61000003196E99788054740BB0D6ABFB5C54940
83593	7	73	\N	23458	30527	\N	52.260900999999997	Саратовская область, город Ртищево, ул. 22 Партсъезда, д. 3 (Техникум)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83880	7	73	\N	29	31308	\N	51.576412093833802	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 16, ул. Одесская, д. 34	Россия, Саратовская область, Саратов, 1-я Одесская улица	0101000020E610000011C7BAB88DFA4640CF8250DEC7C94940
82477	7	73	\N	29	31544	\N	51.581322	Саратовская область, город Саратов, Ленинский район, ул. 1-я Елшанская, д. 60		0101000020E610000063EC8497E0F24640003961C268CA4940
82548	7	73	\N	29	31506	\N	51.52899	Саратовская область, город Саратов, Октябрьский район, ул.1-я Детская, д.36/40 (МОУ СОШ №82)		0101000020E6100000A25D85949FFC46409DF4BEF1B5C34940
82473	7	73	\N	29	77483	\N	51.590454490564703	Саратовская область, город Саратов, Ленинский район, 31й Панфиловский проезд, д.1 т.63-73-08, МДОУ Детский сад комбинированногг вида №172	Россия, Саратовская область, Саратов, 1-й проезд Панфилова, 1	0101000020E61000004015376E31F746406DE525FF93CB4940
82382	7	73	\N	29	134	\N	51.4758497675504	Саратовская область, город Саратов, Заводской район, 1-й Тульский проезд, д. 6-А, (МОУ Гимназия № 5)	Россия, Саратовская область, Саратов, 1-й Тульский проезд, 6а	0101000020E6100000815B77F354F346409BE61DA7E8BC4940
82381	7	73	\N	29	134	\N	51.473322000000003	Саратовская область, город Саратов, Заводской район, 1-й Тульский проезд, д.6-А, (МОУ Гимназия № 5)		0101000020E6100000785F950B95F34640193DB7D095BC4940
82435	7	73	\N	29	30986	\N	51.610896925345799	Саратовская область, город Саратов, Кировский район, 1-й Топольчанский проезд, д. 5 А (МДОУ Детский сад №112)	Россия, Саратовская область, Саратов, 1-й Топольчанский проезд, 5а	0101000020E6100000B4E89D0AB8014740BD1C76DF31CE4940
82351	7	73	\N	29	7941	\N	51.551071999999998	Саратовская область, город Саратов, Волжский район, 1-й Соколовогорский проезд, д. 1 (МОУ СОШ №11)		0101000020E6100000AE9CBD33DA064740E3DEFC8689C64940
82474	7	73	\N	29	1545	\N	51.591098000000002	Саратовская область, город Саратов, Ленинский район, 1-й проезд Панфилова, д. 3 (МОУ СОШ №100)		0101000020E61000009605137F14F74640925D6919A9CB4940
82366	7	73	\N	29	30788	\N	51.467430999999998	Саратовская область, город Саратов, Заводской район, 1-й Нефтяной проезд, д.1, (Филиал МОУ СОШ № 83)		0101000020E61000000806103E94F446407B116DC7D4BB4940
82516	7	73	\N	29	31652	\N	51.604653999999996	Саратовская область, город Саратов, Ленинский район, ул. Перспективная, д. 10А (МОУ СОШ №49)		0101000020E6100000CFA3E2FF8EFE4640A2B2614D65CD4940
82568	7	73	\N	29	67166	\N	51.535775000000001	"""Саратовская область, город Саратов, Фрунзенский район, ул. Астраханская, д. 77 ФГБОУ ВПО ""СГУ им. Чернышевского"" Колледж радиоэлектроники им. Яблочкова, т.51-40-74, 51-26-73"""		0101000020E610000040DB6AD619014740D881734694C44940
83595	7	73	\N	23458	30523	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Яблочкова, д. 13 (СШ №5)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83606	7	73	\N	23458	31481	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Чкалова, д. 6 (СШ №4)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83605	7	73	\N	23458	30829	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Советская, д. 30 (СШ №2 1 этаж)	Россия, Саратовская область, Ртищево	0101000020E6100000800C1D3BA8E44540313F373465214A40
83604	7	73	\N	23458	30829	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Советская, д. 30 (СШ №2 Актовый зал)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83594	7	73	\N	23458	30902	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Сердобский тупик, д. 19 (здание Дистанции пути)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83597	7	73	\N	23458	31355	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Пугачевская, д. 82 (СШ №1)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83603	7	73	\N	23458	30731	\N	52.260900999999997	Саратовская область, город Ртищево, пер. Ветеринарный, д. 1 (Ветлечебница)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83592	7	73	\N	23458	30305	\N	52.260900999999997	Саратовская область, город Ртищево, ул. М. Горького, д. 38а  (Библиотека)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83609	7	73	\N	23458	31522	\N	52.257002910588298	Саратовская область, горрод Ртищево, ул. Котовского, д.1  (Клуб в\\ч 06807)	Россия, Саратовская область, Ртищево	0101000020E61000002C6684B707E54540A8FC6B79E5204A40
83596	7	73	\N	23458	30897	\N	52.260900999999997	Саратовская область, город Ртищево, ул. К. Маркса, д. 13 (ПУ №12)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83591	7	73	\N	23458	31471	\N	52.256278672784902	Саратовская область, город Ртищево, ул. Ильича, д. 78  (СШ №7)	Россия, Саратовская область, Ртищево	0101000020E61000003F56F0DB10E5454067D311C0CD204A40
83607	7	73	\N	23458	31053	\N	52.249141002726901	Саратовская область, город Ртищево, ул. Зои Космодемьянской, д. 19 (ФОК Юность)		0101000020E6100000043C69E1B2E04540DF8B2FDAE31F4A40
83602	7	73	\N	23458	30732	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Железнодорожная, д. 66 (СШ №9)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83600	7	73	\N	23458	30732	\N	52.257476950714597	Саратовская область, город Ртищево, ул. Железнодорожная, д. 21 (СШ № 7)	Россия, Саратовская область, Ртищево	0101000020E610000019AF795567E54540713C9F01F5204A40
83599	7	73	\N	23458	30732	\N	52.260900999999997	Саратовская область, город Ртищево, ул. Железнодорожная, д. 12 (Дом кино)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83590	7	73	\N	23458	31345	\N	52.267272639944601	Саратовская область, город Ртищево, ул. Горная, д. 1 (ДК Спутник)	Россия, Саратовская область, Ртищево	0101000020E6100000C76647AAEFE645404A0D6D0036224A40
83598	7	73	\N	23458	30312	\N	52.260900999999997	Саратовская область, город Ртищево, ул. им. Алексея Громова, д. 12 (Библиотека им. А. Пушкина)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83601	7	73	\N	23458	30536	\N	52.260900999999997	Саратовская область, город Ртищево, ул. 60 лет Октября, д.14 (Автошкола РОСТО)		0101000020E6100000800C1D3BA8E44540313F373465214A40
83703	7	73	\N	53214	\N	\N	51.622141999999997	Саратовская область, Саратовский район, поселок Расково, (МОУ СОШ п. Расково)	Россия, Саратовская область, поселок Расково	0101000020E610000008C89750C1014740E8BB5B59A2CF4940
83515	7	73	\N	2278	30668	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Урицкого, д.3 (СОШ №3)		0101000020E6100000868F8829916448405D8AABCABE014A40
83514	7	73	\N	2278	16806	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Топорковская, д.40/1 (СОШ № 1)		0101000020E6100000868F8829916448405D8AABCABE014A40
83504	7	73	\N	2278	16806	\N	52.013635000000001	Саратовская область, Пугачвевский район, город Пугачев, ул.Топорковская, д.99 (ФОК Олимп)	Россия, Саратовская область, Пугачев	0101000020E6100000868F8829916448405D8AABCABE014A40
83509	7	73	\N	2278	30642	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Рев.Проспект,д.272 Магазин Легенда  д.307 (Гостиница Вольской КЭЧ)		0101000020E6100000868F8829916448405D8AABCABE014A40
83510	7	73	\N	2278	30452	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Пушкинская, д.316 (Филиал СОШ № 3 )		0101000020E6100000868F8829916448405D8AABCABE014A40
83505	7	73	\N	2278	30701	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.М.Горького, д.155 (СОШ № 13) ул.М.Горького,134 МАУ ФОК Олимп		0101000020E6100000868F8829916448405D8AABCABE014A40
83501	7	73	\N	2278	30787	\N	52.013635000000001	Саратовская область, Пугачевский район,город Пугачев, ул.Кутякова, д.70 (СОШ № 14)		0101000020E6100000868F8829916448405D8AABCABE014A40
83500	7	73	\N	2278	30787	\N	52.013635000000001	Саратовская оюласть, Пугачевский район,город Пугачев, ул.Кутякова, д.70 (СОШ № 14)		0101000020E6100000868F8829916448405D8AABCABE014A40
83516	7	73	\N	2278	30904	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Коммунистическая, д.12 (СОШ №2)		0101000020E6100000868F8829916448405D8AABCABE014A40
83476	7	73	\N	2278	30651	\N	52.012572902460803	Саратовская область, Пугачевский район, город Пугачев, ул. Карьер МВД-4, Филиал Пугачевские СЭС	Россия, Саратовская область, Пугачев	0101000020E6100000DA571EA4A764484004E8F7FD9B014A40
83503	7	73	\N	2278	31033	\N	52.013635000000001	Саратаовская область, Пугачевский район, город Пугачев, ул. Интернациональная, д.122 (Филиал Городские ЭС)		0101000020E6100000868F8829916448405D8AABCABE014A40
83507	7	73	\N	2278	30410	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Железнодорожная, д.10 (МУП Дорожник)		0101000020E6100000868F8829916448405D8AABCABE014A40
94381	7	73	\N	2278	30669	\N	52.008627007958097	Саратовская область, Пугачевский район, город Пугачев, ул.Горького, д.56 (Кафе № 1)	Россия, Саратовская область, Пугачев городской округ	0101000020E6100000CB694FC939674840696E85B01A014A40
83444	7	73	\N	19941	31490	\N	52.305520999999999	Саратовская область, Петровский район, г. Петровск, ул. Шамаева, д. 99 (МОУ СОШ №2)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83449	7	73	\N	19941	30938	\N	52.305520999999999	Саратовская область, Петровский район, г. Петровск, ул. Чернышевского, д. 205 (МОУ СОШ №1)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83452	7	73	\N	19941	31096	\N	52.305520999999999	Саратовская область, Петровский район, г. Петровск, ул. Спартака, д. 5 (МОУ СОШ №8)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83450	7	73	\N	19941	31321	\N	52.300170071325098	Саратовская область, Петровский район, г. Петровск, ул. Советская, д. 2 (Дом физкультуры)	Россия, Саратовская область, Петровск	0101000020E6100000003CA24275B14640C39E76F86B264A40
83443	7	73	\N	19941	31441	\N	52.305520999999999	Саратовская область, Петровский  район, г. Петровск, ул. Радищева, д. 21 (МОУ СОШ №5)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83448	7	73	\N	19941	30597	\N	52.305520999999999	Саратовская область, Петровский район, г. Петровск, ул. Московская, д. 8 (здание картинной галереи)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83446	7	73	\N	19941	30597	\N	52.305520999999999	Саратовская область, Петровский район, г. Петровск, ул. Московская, д. 86 (районный Дом культуры)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83453	7	73	\N	19941	30759	\N	52.305520999999999	Саратовская область, Петровский район, г. Петровск, ул. Железнодорожная, д. 16 (КДЦ Современник)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83451	7	73	\N	19941	31444	\N	52.300334508114297	Саратовская область, Петровский район, г. Петровск, ул. Гоголя, д. 51 (МОУ СОШ №8)	Россия, Саратовская область, Петровск	0101000020E610000082AAD1AB01B046400D6C956071264A40
83445	7	73	\N	19941	31432	\N	52.305520999999999	Саратовская область, Петровский район, г. Петровск, ул. 25 лет Октября, д. 164-А (МОУ СОШ №7)		0101000020E61000000BEBC6BB23B14640E09EE74F1B274A40
83361	7	73	\N	53190	\N	\N	50.452638	"Саратовская область, Новоузенский район, город Новоузенск, дом кино ""Юность"""		0101000020E610000068942EFD4B124840A376BF0AF0394940
83331	7	73	\N	2574	30690	\N	51.708795116343801	Саратовская область, Марксовский район, город Маркс, пр. Строителей, д. 1 (Центральный дом культуры)	Россия, Саратовская область, Маркс городской округ	0101000020E610000092CB7F48BF614740BF4868CBB9DA4940
83330	7	73	\N	2574	31320	\N	51.707672187459202	Саратовская область, Марксовский район, город Маркс, пр. Ленина, д. 107 (ГОУ НПО Профес.лицей №46)	Россия, Саратовская область, Маркс	0101000020E61000008463963D09604740C02500FF94DA4940
83322	7	73	\N	2574	31298	\N	51.708711999999998	Саратовская область, Марксовский район, город Маркс, пр. Строителей, д. 22 (МОУ-средняя общеоб.школа №3)		0101000020E6100000AF7B2B121360474031242713B7DA4940
82904	7	73	\N	3738	30873	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, площадь Равенства, д. 96 (МОУ Гимназия)		0101000020E6100000B05758703FAE4740295E656D53044A40
83327	7	73	\N	2574	31389	\N	51.708711999999998	Саратовская область, Марксовский район, город Маркс, ул. Рабочая, д. 195 (МОУ-сред. общеоб.школа №5)		0101000020E6100000AF7B2B121360474031242713B7DA4940
83314	7	73	\N	2574	31043	\N	51.708711999999998	Саратовская область, Марксовский район, город Маркс, ул. Победы, д. 10 (МОУДОД Центр внешкол.работы)		0101000020E6100000AF7B2B121360474031242713B7DA4940
83326	7	73	\N	2574	30368	\N	51.708711999999998	Саратовская область, Марксовский район, город Маркс, пр. Ленина. д. 60 (ФГОУ СПО Марксовский с/х техникум, в помещении спорт. зала №1), пр. Ленина, д. 68 (помещение общежития №1)		0101000020E6100000AF7B2B121360474031242713B7DA4940
83328	7	73	\N	2574	30922	\N	51.708711999999998	Саратовская область, Марксовский район, город Маркс, Интернациональная площадь, д. 10 (МОУ-средняя общеоб.школа №4)		0101000020E6100000AF7B2B121360474031242713B7DA4940
83324	7	73	\N	2574	67110	\N	51.708711999999998	"Саратовская область, Марксовский район, г.Маркс, ОАО ""Пивзавод - Марксовский"", ул. Загородная роща, 27"	Россия, Саратовская область, Маркс	0101000020E6100000AF7B2B121360474031242713B7DA4940
83329	7	73	\N	2574	31162	\N	51.708711999999998	Саратовская область, Марксовский район, город Маркс, ул. 6-я линия, д. 35 (филиал СГСЭУ 2 корпус)		0101000020E6100000AF7B2B121360474031242713B7DA4940
83332	7	73	\N	2574	31434	\N	51.708711999999998	Саратовская область, Марксовский район, город Маркс, ул. 10-я линия, д. 47 (Админист.здание ОАОАлтаец)		0101000020E6100000AF7B2B121360474031242713B7DA4940
83174	7	73	\N	23	67059	\N	51.025837000000003	"Саратовская область, Красноармейский район, город Красноармейск, МОУ ""СОШ № 1"", ул.Танцорова,1 "		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83172	7	73	\N	23	31106	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. Почтовая, д. 42 (МОУ СОШ № 2)		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83162	7	73	\N	23	30778	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. Луначарского, д. 33 (МОУ СОШ № 8)		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83167	7	73	\N	23	30236	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. Коммунистическая, д. 3 (МОУ СОШ № 5) СОШ №3		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83166	7	73	\N	23	30236	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. Коммунистическая, д. 3 (МОУ СОШ № 5)  СОШ № 3		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83173	7	73	\N	23	30399	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. Кирова, д. 9 (ДЮСШ № 1)		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83161	7	73	\N	23	30555	\N	51.033377961291002	Саратовская область, Красноармейский район, город Красноармейск, ул. Захарова, д. 57 (МОУ СОШ № 4)	Россия, Саратовская область, Красноармейск	0101000020E61000003F912749D7DA4640F433F5BA45844940
83164	7	73	\N	23	30851	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. Богдана Хмельницкого, д. 111 (филиал МАК) Колледж		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83170	7	73	\N	23	30525	\N	51.008536957311598	Саратовская область, Красноармейский район, город Красноармейск, ул. 5 микрорайон, Здание МОУ СОШ № 3 Микрорайон 5, д.43	Россия, Саратовская область, Красноармейск	0101000020E6100000BB5E9A22C0D9464029E78BBD17814940
83168	7	73	\N	23	30525	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. 5 микрорайон, Здание филиала РДК, Микрорайон 5		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83171	7	73	\N	23	31120	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. 3-й Фабричный переулок, д. 18 (ДЮСШ № 2) Степной переулок,12		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83169	7	73	\N	23	30415	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. 1 микрорайон, Здание начальной школы МОУ СОШ №5 СОШ №3 Микрорайон 5, д.43		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83163	7	73	\N	23	31388	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул. 1 Мая, д. 61 (Районный Дворец культуры)		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83681	7	73	\N	32022	31143	\N	51.472144	Саратовская область, Саратовский  район, деревня Кокурино, ул. Центральная, д.3 (Фельдшерско-акушерский пункт)		0101000020E61000003E213B6F63EB46405680EF366FBC4940
83126	7	73	\N	53162	30662	\N	51.501162000000001	Саратовская область, Калининский район, г.Калининск, ул. Советская (МОУ СОШ №2), д. 9		0101000020E610000054C8957A163C4640BDFF8F1326C04940
94393	7	73	\N	53183	30960	\N	51.619022000000001	Саратовская область, ЗАТО Михайловский, ул.60 лет Победы, д.7 Дом культуры		0101000020E61000001C23D923D42A474094C0E61C3CCF4940
82893	7	73	\N	3738	30955	\N	52.057399876124698	Саратовская область, Вольский район, город Вольск, ул. Чернышевского, д. 72 (МОУ СКОШ № 14)	Россия, Саратовская область, Вольск	0101000020E61000007C2C7DE882AE47402C6519E258074A40
82901	7	73	\N	3738	31272	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, поселок завода Красный Октябрь, д. 35 (МОУ СОШ № 17)		0101000020E6100000B05758703FAE4740295E656D53044A40
82905	7	73	\N	3738	30385	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, площадь Юности, д. 1 (МОУ СОШ № 6)		0101000020E6100000B05758703FAE4740295E656D53044A40
82912	7	73	\N	3738	30622	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, площадь Свободы, д. 1 (МОУ СПО музучилище)		0101000020E6100000B05758703FAE4740295E656D53044A40
82920	7	73	\N	3738	31119	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Школьная, д. 7-А (МОУ СОШ № 11)		0101000020E6100000B05758703FAE4740295E656D53044A40
82900	7	73	\N	3738	31399	\N	52.029296140080397	Саратовская область, Вольский район, город Вольск, ул. Чехова, д. 16 (библиотека № 7)	Россия, Саратовская область, Вольск	0101000020E61000001D93C5FD47AC4740AAF3A8F8BF034A40
82892	7	73	\N	3738	31278	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Цементников, д. 97 (МОУ ООШ № 10)		0101000020E6100000B05758703FAE4740295E656D53044A40
82891	7	73	\N	3738	31278	\N	52.042787885370402	Саратовская область, Вольский район, город Вольск, ул. Цементников, д. 184 (библиотека № 2)		0101000020E61000005AD427B9C3B24740A454C2137A054A40
82913	7	73	\N	3738	31416	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Струина, д. 2 (ЦДО Радуга)		0101000020E6100000B05758703FAE4740295E656D53044A40
82889	7	73	\N	3738	30774	\N	52.040425967522403	Саратовская область, Вольский район, город Вольск, ул. Свердлова, д. 9-А (ГОУ НПО ПУ № 5)	Россия, Саратовская область, Вольск	0101000020E61000001B4B581B63B147403CF4DDAD2C054A40
82906	7	73	\N	3738	31275	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Саратовская, д. 44 (ФГОУ СПО стройколледж)		0101000020E6100000B05758703FAE4740295E656D53044A40
82909	7	73	\N	3738	30617	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Революционная, д. 46 (управление образования)		0101000020E6100000B05758703FAE4740295E656D53044A40
82902	7	73	\N	3738	30181	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Пятницкого, д. 5 (магазин ООО Дельфин)		0101000020E6100000B05758703FAE4740295E656D53044A40
82910	7	73	\N	3738	31396	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Пугачева, д. 56 (МОУ Лицей)		0101000020E6100000B05758703FAE4740295E656D53044A40
82914	7	73	\N	3738	31282	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Одесская, д. 2 (ФГУП СО Облводоресурс)		0101000020E6100000B05758703FAE4740295E656D53044A40
82899	7	73	\N	3738	30957	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Некрасова, д. 28 (МОУ СОШ № 17)		0101000020E6100000B05758703FAE4740295E656D53044A40
82898	7	73	\N	3738	31109	\N	52.044421967996399	Саратовская область, Вольский район, город Вольск, ул. Л. Толстого, д. 253 (ГОУ СПО Медколледж)	Россия, Саратовская область, Вольск	0101000020E610000090C01F7EFEB14740889CBE9EAF054A40
82896	7	73	\N	3738	30606	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Краснооктябрьская, д. 1-А (УК Трансстройсервис)		0101000020E6100000B05758703FAE4740295E656D53044A40
82911	7	73	\N	3738	30790	\N	52.0454275274585	Саратовская область, Вольский район, город Вольск, ул. Красногвардейская, д. 7-А (МОУ СОШ № 16)	Россия, Саратовская область, Вольск	0101000020E6100000FB05BB61DBB047404E29AF95D0054A40
82908	7	73	\N	3738	30790	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Красногвардейская, д. 56 (МОУ СОШ № 19)		0101000020E6100000B05758703FAE4740295E656D53044A40
82919	7	73	\N	3738	31139	\N	52.059555879144199	Саратовская область, Вольский район, город Вольск, ул. Комсомольская, д. 251 (здание ОТШ РОСТО)	Россия, Саратовская область, Вольск	0101000020E6100000A0F99CBB5DAD4740EA23F0879F074A40
82918	7	73	\N	3738	31139	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Комсомольская, д. 202 (ГОУ СПО Педколледж)		0101000020E6100000B05758703FAE4740295E656D53044A40
82916	7	73	\N	3738	31139	\N	52.049026185522898	Саратовская область, Вольский район, город Вольск, ул. Комсомольская, д. 161 (ГОУ НПО ТУ № 25)	Россия, Саратовская область, Вольск	0101000020E6100000C18F6AD8EFAF4740AC53E57B46064A40
82888	7	73	\N	3738	30747	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Коммунарная, д. 30-А (МОУ СОШ № 5)		0101000020E6100000B05758703FAE4740295E656D53044A40
82897	7	73	\N	3738	31271	\N	52.035000359101197	Саратовская область, Вольский район, город Вольск, ул. Володарского, д. 200 (библиотека № 3)	Россия, Саратовская область, Вольск	0101000020E6100000D00EB8AE98AF474014AE47E17A044A40
82903	7	73	\N	3738	30601	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Волжская, д. 25 (клуб пос. Рыбное)		0101000020E6100000B05758703FAE4740295E656D53044A40
82915	7	73	\N	3738	30626	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Волгоградская, д. 52-А (МОУ СОШ № 3)		0101000020E6100000B05758703FAE4740295E656D53044A40
83680	7	73	\N	53204	\N	\N	51.418984000000002	Саратовская область, Саратовский район, поселок Водник, (Фельдшерско-акушерский пункт)	Россия, Саратовская область, поселок Водник	0101000020E61000005E10919A76F546400DC68844A1B54940
82826	7	73	\N	4360	\N	\N	51.550744821804798	"Саратовская область, Балашовский район, город Балашов-3. МОУ ДОД ""Станция юных техников"""	Россия, Саратовская область, Балашов	0101000020E6100000E4BCFF8F13984540BFB7E9CF7EC64940
94368	7	73	\N	4360	30498	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, пер. Вокзальный, д. 6 (Уч.центр траспортной отрасли)		0101000020E610000016C0948103964540BDC799266CC54940
82818	7	73	\N	4360	30711	\N	51.5394759206416	Саратовская область, Балашовский район, город Балашов, пер. Школьный, д. 14 (Станция юных натуралистов)	Россия, Саратовская область, Балашов	0101000020E61000005B423EE8D99445400B7DB08C0DC54940
82839	7	73	\N	4360	31219	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Юбилейная, д. 13 (СШ № 3)		0101000020E610000016C0948103964540BDC799266CC54940
83647	7	73	826	30312	\N	\N	51.259481999999998	Саратовская область, Самойловский район, поселок Алексеевский, д. 47 (ФАП)		0101000020E6100000DE205A2BDAD6454049F3C7B436A14940
82835	7	73	\N	4360	31223	\N	51.542363000000002	"Саратовская область, Балашовский район, город Балашов, ул. Шоссейная, 9АП здание МУЗ ""Балашовская ЦРБ"" поликлиника №2"		0101000020E610000016C0948103964540BDC799266CC54940
82825	7	73	\N	4360	31223	\N	51.535969979225598	Саратовская область, Балашовский район, город Балашов, ул. Шоссейная, д. 9 (здание Автошколы РОСТО)	Россия, Саратовская область, Балашов	0101000020E61000006AC020E9D39A45408DD13AAA9AC44940
82827	7	73	\N	4360	31135	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Фестивальная, д. 2 (ПУ-15)		0101000020E610000016C0948103964540BDC799266CC54940
82832	7	73	\N	4360	30411	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Титова, д. 2 (СШ № 4)		0101000020E610000016C0948103964540BDC799266CC54940
82824	7	73	\N	4360	30411	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Титова, д. 13  (СОШ № 12)	Россия, Саратовская область, Балашов	0101000020E610000016C0948103964540BDC799266CC54940
82838	7	73	\N	4360	30891	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Строителей, д.9 А (СШ № 15)		0101000020E610000016C0948103964540BDC799266CC54940
82837	7	73	\N	4360	30891	\N	51.556530266990201	Саратовская область, Балашовский район, город Балашов, ул. Строителей, д. 9 А (СШ № 15)	Россия, Саратовская область, Балашов	0101000020E61000007C2B1213D49A4540179F02603CC74940
82821	7	73	\N	4360	30703	\N	51.535648810713901	Саратовская область, Балашовский район, город Балашов, ул. Софинского, д. 13 (МОУ СОШ № 16)	Россия, Саратовская область, Балашов	0101000020E610000099D36531B19345404B917C2590C44940
81487	7	73	\N	4360	30703	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Софинского, д. 13 (СШ № 16)		0101000020E610000016C0948103964540BDC799266CC54940
82811	7	73	\N	4360	30217	\N	51.550888421826897	Саратовская область, Балашовский район, город Балашов, ул. Пушкина, д. 51 (МОУ СОШ № 7)	Россия, Саратовская область, Балашов	0101000020E6100000228E75711B93454022E17B7F83C64940
82810	7	73	\N	4360	30798	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Пугачевская, д. 287 (МОУ СОШ № 5)		0101000020E610000016C0948103964540BDC799266CC54940
82808	7	73	\N	4360	30798	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Пугачевская, д. 328 (Балашовское мед. училище)		0101000020E610000016C0948103964540BDC799266CC54940
94365	7	73	\N	4360	30179	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Нефтяная, д. 44б (бывшая СШ № 14)		0101000020E610000016C0948103964540BDC799266CC54940
82798	7	73	\N	4360	30179	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Нефтяная, д. 54 (Клуб Балашовского Дома-интерната для престарелых и инвалидов)		0101000020E610000016C0948103964540BDC799266CC54940
82822	7	73	\N	4360	31405	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Нарадноя, д. 38 (здание филиала СГСЭУ)		0101000020E610000016C0948103964540BDC799266CC54940
94369	7	73	\N	4360	30424	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Менделеева, д. 7 (Детский сад Черемушки)		0101000020E610000016C0948103964540BDC799266CC54940
94367	7	73	\N	4360	30213	\N	51.551971991581901	Саратовская область, Балашовский район, город Балашов, ул. Ленина, д. 22 (Гимназия им. Ю.А. Гарнаева)	Россия, Саратовская область, Балашов	0101000020E6100000EAB303AE2B9245406327BC04A7C64940
82805	7	73	\N	4360	30213	\N	51.5339626386546	Саратовская область, Балашовский район, город Балашов, ул. Ленина, д. 5 (Кинотеатр Победа)	Россия, Саратовская область, Балашов	0101000020E61000006495D233BD92454014234BE658C44940
82802	7	73	\N	4360	30213	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Ленина, д. 31 (Кооперативный техникум)		0101000020E610000016C0948103964540BDC799266CC54940
82823	7	73	\N	4360	30886	\N	51.540907658338703	Саратовская область, Балашовский район, город Балашов, ул. Красина, д. 97 (МУЗ Балашовская ЦРП)	Россия, Саратовская область, Балашов	0101000020E6100000BD1C76DF3194454088122D793CC54940
94366	7	73	\N	4360	30797	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Коммунистическая, д.188 (МУП Балашов-благоустройство и озеленение)		0101000020E610000016C0948103964540BDC799266CC54940
82815	7	73	\N	4360	30296	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. К. Маркса, д. 96 (Центр культуры)		0101000020E610000016C0948103964540BDC799266CC54940
82809	7	73	\N	4360	30296	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. К. Маркса, д. 25 (Балашовское муз. училище)		0101000020E610000016C0948103964540BDC799266CC54940
82813	7	73	\N	4360	30287	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Депутатская, д. 29 (Лицей-интернат)		0101000020E610000016C0948103964540BDC799266CC54940
82806	7	73	\N	4360	31167	\N	51.542363000000002	"""Саратовская область, Балашовский район, город Балашов, ул.Володарского, 35, учебный корпус Балашовского института СГУ им.Чернышевского"		0101000020E610000016C0948103964540BDC799266CC54940
82812	7	73	\N	4360	67041	\N	51.542363000000002	"""Саратовская область, Балашовский район, город Балашов, переулок Вокзальный, д.8  (Детский сад """"Лучик"""")"""		0101000020E610000016C0948103964540BDC799266CC54940
82833	7	73	\N	4360	31377	\N	51.543058734021301	Саратовская область, Балашовский район, город Балашов, Балашов-3, Гарнизонный Дом офицеров	Россия, Саратовская область, Балашов	0101000020E6100000D0D6C1C1DE984540346612F582C54940
79740	7	72	\N	55034	81127	\N	53.095394980272197	город Новокуйбышевск, Бочарикова, 6-б	Россия	0101000020E6100000BF9EAF592EFD4840D99942E7358C4A40
82836	7	73	\N	4360	31218	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. 50 лет ВЛКСМ, д. 2 (Гимназия № 1)		0101000020E610000016C0948103964540BDC799266CC54940
82829	7	73	\N	4360	30299	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. 50  лет ВЛКСМ, д. 2 (Гимназия № 1)		0101000020E610000016C0948103964540BDC799266CC54940
82727	7	73	\N	6127	\N	\N	51.999767540257899	Саратовская область, Балаковский район, город Балаково, МУДОД ДЮСШ №2		0101000020E6100000327216F6B4E547402ECBD765F8FF4940
82742	7	73	\N	6127	9895	\N	52.005353979823703	Саратовская область, Балаковский район, город Балаково, ул. Шевченко, д. 1А (МОУ СОШ №19)	Россия, Саратовская область, Балаково	0101000020E61000003733FAD170E847408E739B70AF004A40
82724	7	73	\N	6127	30903	\N	52.024783573146699	Саратовская область, Балаковский район, город Балаково, ул. Чапаева, д. 140 (ФГБОУ ВПО БИТТиУ)	Россия, Саратовская область, Балаково	0101000020E61000007F87A2409FE2474066BB421F2C034A40
82719	7	73	\N	6127	30284	\N	52.009902655092702	Саратовская область, Балаковский район, город Балаково, ул. Факел Социализма, д. 27 (ФГОУ СПО Бал. техникум)	Россия, Саратовская область, Балаково	0101000020E6100000BA13ECBFCEE74740EF90628044014A40
82754	7	73	\N	6127	30656	\N	52.026152861242302	Саратовская область, Балаковский район, город Балаково, ул. Трнавская, д. 38 (МОУ СОШ №28)	Россия, Саратовская область, Балаково	0101000020E610000016BD5301F7EA47409DD843FB58034A40
82749	7	73	\N	6127	30656	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Трнавская, д. 49А (МОУ СОШ №22)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82726	7	73	\N	6127	30840	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Титова, д. 25А (МУДОД Доп. обр. детей)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82762	7	73	\N	6127	30242	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Степная, д. 70  (МАУ УСК Форум)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82758	7	73	\N	6127	30242	\N	52.004372448660703	"Центр: Балаковский институт экономики и бизнеса ФГБОУ ВПО ""СГСЭУ"", ул Степная, 18"		0101000020E6100000AF601BF164E747405182FE428F004A40
82757	7	73	\N	6127	30242	\N	51.987842000000001	Саратовская область, Балаковский  район, город Балаково, ул. Степная, д. 30 (МОУ СОШ №27)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82756	7	73	\N	6127	30242	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Степная, д. 30 (МОУ СОШ №27)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82755	7	73	\N	6127	30242	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Степная, д. 70 (МАУ УСК Форум)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82718	7	73	\N	6127	30396	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Свердлова, д. 4 (МБУК ГКВЦ  кт. Октябрь)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82759	7	73	\N	6127	30407	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Саратовское Шоссе, д. 83/6 (ЦТП-74)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82743	7	73	\N	6127	30407	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Саратовское Шоссе, д. 33 (ГОУ СПО Бал. АЭМ техникум)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82717	7	73	\N	6127	31004	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Редкова, д. 50 (МОУ СОШ №2)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82761	7	73	\N	6127	30378	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Привокзальная, д. 2 Б (ПТП ст. Балаково)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82720	7	73	\N	6127	30618	\N	52.0287942148613	Саратовская область, Балаковский район, город Балаково, ул. Пионерская, д. 1 (МОУ Гимназия №1)	Россия, Саратовская область, Балаково	0101000020E6100000A1A17F828BE3474017299485AF034A40
82735	7	73	\N	6127	30434	\N	52.013001049877303	Саратовская область, Балаковский район, город Балаково, ул. Набережная Леонова, д. 1А (МУК РДК)	Россия, Саратовская область, Балаково	0101000020E61000009679ABAE43E547405CE84A04AA014A40
82739	7	73	\N	6127	30221	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Минская, д. 59А (МОУ СОШ №13)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82732	7	73	\N	6127	30814	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Менделеева, д. 1А (МОУ СОШ №5)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82725	7	73	\N	6127	30454	\N	51.987842000000001	Саратовская область, Балаковский  район, город Балаково, ул. Красноармейская, д. 13 (ФГБОУ ВПО БИТТиУ)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82728	7	73	\N	6127	30351	\N	52.026504354794497	Саратовская область, Балаковский район, город Балаково, ул. Комсомольская, д. 34 (ГОУ СПО Бал. п.т.техникум)	Россия, Саратовская область, Балаково	0101000020E61000005DA45016BEE447404A9BAA7B64034A40
82723	7	73	\N	6127	30351	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Комсомольская, д. 47Б (МОУ СОШ №20)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82722	7	73	\N	6127	30351	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Комсомольская, д. 31 (МОУ СОШ № 7)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82721	7	73	\N	6127	30351	\N	52.027272066677099	Саратовская область, Балаковский район, город Балаково, ул. Комсомольская, д. 31 (МОУ СОШ №7)	Россия, Саратовская область, Балаково	0101000020E610000015AA9B8BBFE347405B0C1EA67D034A40
82851	7	73	595	24023	\N	\N	51.724325	Саратовская область, Балашовский район, с. Пады, МОУ СОШ с. Пады		0101000020E6100000C1559E40D89F45406D567DAEB6DC4940
82713	7	73	\N	6127	30602	\N	52.041009222380197	Саратовская область, Балаковский район, город Балаково, ул. Коммунистическая, д. 124А (МУК КО ГЦИ)	Россия, Саратовская область, Балаково	0101000020E61000008463963D09E64740BCEB6CC83F054A40
82734	7	73	\N	6127	30653	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Комарова, д. 115 (МОУ СОШ №6)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82744	7	73	\N	6127	30827	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Заречная, д. 45 (МОУ СОШ №26)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82737	7	73	\N	6127	30836	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Волжская, д. 1А (МОУ СОШ №10)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82736	7	73	\N	6127	30836	\N	52.015980072277102	Саратовская область, Балаковский район, город Балаково, ул. Волжская, д. 39 (МОУ СОШ №3)	Россия, Саратовская область, Балаково	0101000020E6100000B7989F1B9AE64740EEB1F4A10B024A40
82740	7	73	\N	6127	30983	\N	51.991201781620198	Саратовская область, Балаковский район, город Балаково, ул. Вокзальная, д. 16А (МОУ СОШ №18)	Россия, Саратовская область, Балаково	0101000020E61000007FA2B2614DE747406ADD06B5DFFE4940
82751	7	73	\N	6127	30992	\N	51.987842000000001	Саратовская область, Балаковский  район, город Балаково, ул. Бульвар Роз, д. 5А (МОУ Гимназия №2)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82750	7	73	\N	6127	30992	\N	52.029005987873397	Саратовская область, Балаковский район, город Балаково, ул. Бульвар Роз, д. 5А (МОУ Гимназия №2)	Россия, Саратовская область, Балаково	0101000020E6100000BC79AA436EEA4740A3B1F677B6034A40
82716	7	73	\N	6127	30611	\N	52.037317282385096	Саратовская область, Балаковский район, город Балаково, ул. Братьев Захаровых, д. 8А (МОУ СОШ №25)	Россия, Саратовская область, Балаково	0101000020E6100000193C4CFBE6E24740DC4AAFCDC6044A40
82753	7	73	\N	6127	30195	\N	52.017198104011797	Саратовская область, Балаковский район, город Балаково, ул. 30 лет Победы, д. 24 (МОУ СОШ №21)	Россия, Саратовская область, Балаково	0101000020E6100000C03FA54A94E947403FC7478B33024A40
82747	7	73	\N	6127	30195	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. 30 лет Победы, д. 41А (МОУ Лицей №1)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82746	7	73	\N	6127	30195	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. 30 лет Победы, д. 9Б (МОУ ДОД школа искусств №2)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82763	7	73	\N	6127	30781	\N	52.010610342948901	Саратовская область, Балаковский район, город Балаково, ул. 30 Лет Победы, д. 71 (ГУ Дом инвал. и престар.)	Россия, Саратовская область, Балаково	0101000020E61000005B9544F641EA47405A8121AB5B014A40
82653	7	73	\N	6079	30314	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Школьная, д. 41 (детский сад № 7 Яблочко)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82649	7	73	\N	6079	30896	\N	51.876531309340201	Саратовская область, Аткарский район, город Аткарск, ул. Чапаева, д. 54 (Районный культурный центр)	Россия, Саратовская область, Аткарск	0101000020E610000048A643A7E77F46401077F52A32F04940
82650	7	73	\N	6079	30310	\N	51.874567099341697	Саратовская область, Аткарский район, город Аткарск, ул. Советская, д. 92 (МОУ СОШ № 3)	Россия, Саратовская область, Аткарск	0101000020E610000059C16F438C7F46409694BBCFF1EF4940
82646	7	73	\N	6079	31049	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Локомотивная, д. 20 (МОУ СОШ № 10)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82647	7	73	\N	6079	30521	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Ленина, д. 116 (МОУ СОШ № 1)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82655	7	73	\N	6079	30900	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. К. Маркса, д. 40 (ГДК Россия)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82654	7	73	\N	6079	30900	\N	51.873370296877702	Саратовская область, Аткарский район, город Аткарск, ул. К. Маркса, д. 38 (МОУ СОШ № 6)	Россия, Саратовская область, Аткарск	0101000020E610000029081EDFDE7F46405DA79196CAEF4940
82643	7	73	\N	6079	31215	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Грибоедова, д. 2 (начальная школа-д/с № 7)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82645	7	73	\N	6079	31216	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Гоголя, д. 17 (ОАО Аткарский МЭЗ)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82652	7	73	\N	6079	30526	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Гагарина, д. 60 (администрация МО г. Аткарск)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82642	7	73	\N	6079	71742	\N	51.872042073742598	"Саратовская область, Аткарский район, город Аткарск, Здание ГАУ СЛ ""Аткарский дом-интернат для престарелых и инвалидов"" второй этаж, фойе, ул. Верхне-Красавская, д.1 "	Россия, Саратовская область, Аткарск	0101000020E6100000DB6CACC43C7F4640855E7F129FEF4940
82644	7	73	\N	6079	30515	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. 30 лет Победы, д. 5 (МОУ СОШ № 2)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82609	7	73	\N	53168	30694	\N	51.929656999999999	Саратовская область, Аркадакский район, город Аркадак (районный Дом культуры), ул.Ленина, д.6		0101000020E61000008FE046CA16C14540ADBF2500FFF64940
83678	7	73	\N	53211	31417	\N	51.444927	Саратовская область, Саратовский район, село Александровка, ул. Привокзальная, (МОУ СОШ с. Александровка)	Россия, Саратовская область, село Александровка	0101000020E61000000281CEA44DEB4640BF0D315EF3B84940
83889	7	73	7271	53188	31027	\N	51.427734509245099	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 42, г. Энгельс - 8, ст. Анисовка, 3-й квартал		0101000020E610000023DC645419064740622D3E05C0B64940
94390	7	73	288	53202	31277	\N	51.411067361890801	Саратовская область, Энгельсский район, пос. Анисовский, МОУ ООШ, ул. Молодежная, д. 1а		0101000020E61000001F85EB51B80C474080BBECD79DB44940
83893	7	73	288	53136	30448	\N	51.479562586618798	Саратовская область, Энгельсский район, г. Энгельс, ДК Восход, г.Энгельс-19, 1-й квартал		0101000020E6100000DDED7A698A14474092AF045262BD4940
81421	7	73	288	53136	30228	\N	51.330997000000004	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 15, г. Энгельс-1		0101000020E6100000BEBED6A5462E47407D09151C5EAA4940
83875	7	73	288	53136	30229	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ №1, ул. Тельмана, д. 139		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83877	7	73	288	53136	30231	\N	51.488455999999999	Саратовская область, Энгельсский район, г. Энгельс, горком ОСТО, ул. Степная, д. 137		0101000020E610000041498105300F47407AC4E8B985BE4940
83869	7	73	288	53136	30514	\N	51.494349550797899	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ  № 2, ул. Свердлова, д. 122		0101000020E61000001442075DC20D474088635DDC46BF4940
83841	7	73	288	53136	30376	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, здание детской спортивной школы, ул. Садовая, д. 17		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83860	7	73	288	53136	30352	\N	51.4820284970071	Саратовская область, Энгельсский район, г. Энгельс, ГОУ С(К)ОШ № 17, ул. Рабочая, д. 109а		0101000020E61000004B3E761728114740CEE0EF17B3BD4940
83854	7	73	288	53136	30183	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, 2 корпус ПУ № 9, ул. Полтавская, д. 17 ГОУ СПО Энгельсский политехникум		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83847	7	73	288	53136	30183	\N	51.476537	Саратовская область, Энгельсский район, г. Энгельс, 2 корп ГОУ НПО Профессиональный лицей № 34, ул. Полтавская, д. 19		0101000020E6100000E333D93F4F0F4740BF2A172AFFBC4940
83879	7	73	288	53136	30446	\N	51.330997000000004	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 32, ул. Минская, д. 29	Россия, Саратовская область, Саратов, Минская улица	0101000020E6100000BEBED6A5462E47407D09151C5EAA4940
83838	7	73	288	53136	31255	\N	51.490828	Саратовская область, Энгельсский район, г. Энгельс, детская школа искусств № 6, ул. Колотилова, д. 58а		0101000020E610000069FF03AC5515474005FBAF73D3BE4940
83891	7	73	288	53136	31103	\N	51.482564410221997	Саратовская область, Энгельсский район, г. Энгельс, МОУ СОШ № 21, г.Энгельс-2, ул. Гагарина		0101000020E610000027309DD66D1A47400D1D3BA8C4BD4940
83883	7	73	288	53136	31443	\N	51.454096461264001	Саратовская область, Энгельсский район, г. Энгельс, красный уголок ЗАОЭнгельсский кирпичный завод,2-Микрорайон, д. 43		0101000020E61000007A1A3048FA0C4740499F56D11FBA4940
83881	7	73	288	53136	30738	\N	51.467138045815503	Саратовская область, Энгельсский район, г. Энгельс, стадион Торпедо, 1-й Микрорайон		0101000020E6100000310C5872150F4740035C902DCBBB4940
83892	7	73	288	53192	31145	\N	51.330997000000004	Саратовская область, Энгельсский район, г. Энгельс, спортивный зал поселка Приволжский, г.Энгельс-19, 1-й кварта		0101000020E6100000BEBED6A5462E47407D09151C5EAA4940
94392	7	73	288	12723	31068	\N	51.280692000000002	Саратовская область, Энгельсский район, с. Широкополье, здание МОУ СОШ, ул. Рабочая,22		0101000020E61000007D957CEC2E524740DA1F28B7EDA34940
83933	7	73	288	12486	31440	\N	51.127766000000001	Саратовская область, Энгельсский район, пос. Шевченко, здание Дом досуга, ул. Школьная, д. 3		0101000020E6100000ED2C7AA7023E474037C5E3A25A904940
83914	7	73	288	11564	\N	\N	51.660518000000003	Саратовская область, Энгельсский район, с. Усть-Караман, здание филиала  МОУ ООШ с. Ленинское		0101000020E6100000E960FD9FC3464740AD3594DA8BD44940
83904	7	73	288	11056	30995	\N	51.251871999999999	Саратовская область, Энгельсский район, с. Узморье, здание МОУ СОШ, ул. Революционная, д. 3		0101000020E610000007CF842689F54640996379573DA04940
83939	7	73	288	12727	30700	\N	51.299365000000002	Саратовская область, Энгельсский район, с. Титоренко, здание МОУ ООШ, ул. Школьная, д. 1		0101000020E6100000ED80EB8A194D47409548A29751A64940
83901	7	73	288	10965	30280	\N	51.303407999999997	Саратовская область, Энгельсский район, с. Терновка, здание администрации, ул. Центральная, д. 26в		0101000020E6100000FAF202ECA3FB464021ACC612D6A64940
83907	7	73	288	11230	30459	\N	51.120331999999998	Саратовская область, Энгельсский район, с. Степное, здание МОУ ООШ, Первомайская, д. 14		0101000020E6100000D784B4C6A0F94640C554FA09678F4940
83915	7	73	288	11607	30470	\N	51.561762000000002	Саратовская область, Энгельсский район, с. Старицкое, здание МОУ ООШ, ул. Центральная, д. 11		0101000020E6100000431D56B8E53F47405A1135D1E7C74940
83924	7	73	288	12009	31012	\N	51.373156999999999	Саратовская область, Энгельсский район, пос. им. Карла Маркса, здание Дома культуры, ул.Советская, д. 31		0101000020E610000015CAC2D7D71C474001A3CB9BC3AF4940
83903	7	73	288	11050	30331	\N	51.282781999999997	Саратовская область, Энгельсский район, с. Смеловка, здание Дома досуга, ул. Центральная, д. 10		0101000020E610000004E3E0D231F94640E0F2583332A44940
83902	7	73	288	53220	31507	\N	51.303829274507898	Саратовская область, Энгельсский район, с. Новая Терновка, здание МОУ СОШ, ул. Ленина, д. 2	Россия, Саратовская область, Энгельсский район, село Терновка	0101000020E6100000D3A3A99ECCFB4640C74961DEE3A64940
83918	7	73	288	11722	\N	\N	51.429678000000003	Саратовская область, Энгельсский район, пос. Пробуждение, здание МОУ СОШ		0101000020E61000004CC2853C82134740C5E74EB0FFB64940
83932	7	73	288	12407	31438	\N	51.239355000000003	Саратовская область, Энгельсский район, пос. Прилужный, здание Дома досуга, ул. Овражная, д. 15		0101000020E610000016A4198BA63D47402A91442FA39E4940
83921	7	73	288	11850	31319	\N	51.390656	Саратовская область, Энгельсский район, пос. Придорожный, здание МОУ СОШ, ул. Школьная, д. 2а		0101000020E6100000D6E07D552E2647403BFE0B0401B24940
83912	7	73	288	11463	30264	\N	51.663567999999998	Саратовская область, Энгельсский район, с. Подстепное, здание МОУ ООШ, ул. Кирова		0101000020E6100000753A90F5D43C47400856D5CBEFD44940
83929	7	73	288	12257	30863	\N	51.344614	Саратовская область, Энгельсский район, с. Первомайское, здание Дома досуга, ул. Трактовая, д. 8		0101000020E61000006AA510C82542474033DFC14F1CAC4940
83917	7	73	288	11670	\N	\N	51.539506000000003	Саратовская область, Энгельсский район, с. Осиновка, магазин, здание Дома досуга		0101000020E6100000D73384639647474076FF58880EC54940
83923	7	73	288	12001	30850	\N	51.390188999999999	Саратовская область, Энгельсский район, пос. Новопушкинское, здание ДК, 1-й квартал, д. 49		0101000020E61000001AC231CB9E104740252191B6F1B14940
83935	7	73	288	12578	31183	\N	51.269208999999996	Саратовская область, Энгельсский район, пос. Межевой, здание фельдшерско-акушерского пункта, ул. Колхозная, д. 3а		0101000020E610000055F833BC59374740F964C57075A24940
83925	7	73	288	12095	31326	\N	51.361421	/Саратовская область, Энгельсский район, пос. Лощинный, здание Дома культуры, ул. Ленина, д. 13		0101000020E6100000D5B14AE999244740378B170B43AE4940
83916	7	73	288	11663	30847	\N	51.527028999999999	Саратовская область, Энгельсский район, с. Липовка, здание Дома культуры, ул. Советская, д. 11		0101000020E6100000098B8A389D4E47409485AFAF75C34940
83913	7	73	288	11477	31001	\N	51.612181999999997	Саратовская область, Энгельсский район, с. Ленинское, здание Дома досуга, ул. Ленина, д. 11		0101000020E6100000A8AAD0402C3F47409599D2FA5BCE4940
83911	7	73	288	11387	30999	\N	51.628919000000003	Саратовская область, Энгельсский район, с. Красный Яр, здание Дома культуры, ул. Мира, д. 98		0101000020E61000002A52616C21364740A16AF46A80D04940
83930	7	73	288	12333	31089	\N	51.320810000000002	Саратовская область, Энгельсский район, с. Красный Партизан, здание МОУ НШ, ул. Южная, д. 12		0101000020E6100000F86C1D1CEC3B4740691D554D10A94940
83905	7	73	288	11144	30461	\N	51.202970000000001	Саратовская область, Энгельсский район, с. Красноармейское, здание ДК, ул. Ленина, д. 14		0101000020E61000008997A77345F54640D908C4EBFA994940
83919	7	73	288	11774	31431	\N	51.429588000000003	Саратовская область, Энгельсский район, пос. Коминтерн, здание МОУ СОШ, ул. Школьная, д. 13		0101000020E61000005000C5C892174740856055BDFCB64940
83936	7	73	288	12598	30695	\N	51.027740999999999	Саратовская область, Энгельсский район, с. Кирово, здание Дома досуга, ул. Советская, д. 66		0101000020E6100000BFD364C6DB30474011E15F048D834940
83934	7	73	288	12488	31020	\N	51.086466000000001	Саратовская область, Энгельсский район, пос. Калинино, здание МОУ СОШ, ул. Дорожная, д. 39		0101000020E6100000232D95B723424740A41B6151118B4940
83931	7	73	288	12349	31019	\N	51.251471000000002	Саратовская область, Энгельсский район, с. Зеленый Дол, здание МОУ СОШ, ул. Советская, д. 13		0101000020E6100000DFA3FE7A853947403B72A43330A04940
83319	7	73	288	2511	31095	\N	51.625205999999999	Саратовская область, Марксовский район, село Звонаревка, ул. Ленина, д. 2 а (МОУ-средняя общеобразовательная школа), ул. Ленина, д. 1 (здание администрации)		0101000020E61000007A37161406434740A9A10DC006D04940
83920	7	73	288	11855	31133	\N	51.4499	Саратовская область, Энгельсский район, пос. Голубьевка, здание фельдшерско-акушерского пункта, ул. Центральная, д. 2/1		0101000020E6100000ED9FA70183284740363CBD5296B94940
83910	7	73	288	11331	30839	\N	51.592804000000001	Саратовская область, Энгельсский район, с. Генеральское, здание Дома культуры, ул. Московская, д. 67		0101000020E6100000F418E599972B474010786000E1CB4940
83937	7	73	288	12642	30281	\N	50.992762999999997	Саратовская область, Энгельсский район, с. Воскресенка, здание Дома культуры, ул. Центральная, д. 81		0101000020E6100000EC4E779E783A4740E4D6A4DB127F4940
83908	7	73	288	53232	31571	\N	51.449151834198801	Саратовская область, Энгельсский район, пос. Взлетный, здание Дома Досуга, ул. Производственная, д. 21	Россия, Саратовская область, Энгельсский район, село Голубьевка	0101000020E6100000B39597FC4F2847406C770FD07DB94940
83940	7	73	288	12806	30862	\N	51.280157000000003	Саратовская область, Энгельсский район, пос. Бурный, здание МОУ СОШ, ул. Школьная, д. 1		0101000020E610000031B77BB94F3447406C5F402FDCA34940
83906	7	73	288	11183	30672	\N	51.178849	Саратовская область, Энгельсский район, с. Березовка, здание МОУ СОШ, ул. Центральная, д. 33		0101000020E6100000D8D30E7F4DF646400EF62686E4964940
83926	7	73	288	12109	30854	\N	51.332155999999998	Саратовская область, Энгельсский район, с. Безымянное, здание МОУ ООШ, ул. Чкалова, д. 7		0101000020E6100000A20DC00644384740C8957A1684AA4940
83811	7	73	626	53243	31614	\N	52.712637258557798	Саратовская область, Хвалынский район, станция Возрождения, ул. Железнодорожная, д. 25А (административное здание)	Россия, Саратовская область, Хвалынский район, поселок Возрождение	0101000020E61000001D76DF313C144840B47570B0375B4A40
83823	7	73	626	53150	30311	\N	52.492902000000001	Саратовская область,  Хвалынский район, город Хвалынск, ул. Советская, д. 293 (ЗАО Элеватор-Холдинг)		0101000020E61000008B1A4CC3F00B48400611A969173F4A40
83824	7	73	626	53150	30381	\N	52.492902000000001	Саратовская область, Хвалынский район, город Хвалынск, ул. Революционная, д. 260 (МОУ СОШ №2)		0101000020E61000008B1A4CC3F00B48400611A969173F4A40
83820	7	73	626	7084	30592	\N	52.436898999999997	Саратовская область, Хвалынский район, село Ульянино, ул. имени Ульянина, д. 62Б (административное здание)		0101000020E6100000C0B4A84F72F34740DA53724EEC374A40
83818	7	73	626	7017	30171	\N	52.685101000000003	Саратовская область, Хвалынский район, село Старая Лебежайка, ул. Первомайская, д. 1 (МОУ ООШ)		0101000020E61000003A3B191C25EF47407CBABA63B1574A40
83819	7	73	626	7030	30931	\N	52.493549000000002	Саратовская область, Хвалынский район, село Сосновая Маза, ул. Ленина, д. 51 (Дом культуры)		0101000020E610000092CCEA1D6EEF47409CFC169D2C3F4A40
83808	7	73	626	6548	30578	\N	52.351619999999997	Саратовская область, Хвалынский район, село Селитьба, ул. Центральная, д. 41В (МОУ ООШ)		0101000020E6100000B20FB22C98F247404C4F58E2012D4A40
83814	7	73	626	6796	31385	\N	52.722239000000002	Саратовская область, Хвалынский район, поселок Северный, ул. Мира, д. 24 (Дом культуры)		0101000020E6100000362383DC451C4840A872DA53725C4A40
83817	7	73	626	6935	31263	\N	52.601349999999996	Саратовская область, Хвалынский район, село Поповка, ул. Космонавтов, д. 19 А (Дом досуга)		0101000020E61000003526C45C52EB47408CB96B09F94C4A40
83762	7	73	626	4043	\N	\N	52.419553000000001	Саратовская область,  Хвалынский район, село Ивановка, ул. Молодежная, д. 25/3 (МОУ ООШ)	Россия, Саратовская область, Хвалынский район, село Ивановка	0101000020E61000007FC00303080F484027F8A6E9B3354A40
83816	7	73	626	6931	30167	\N	52.582476	Саратовская область, Хвалынский район, село Елшанка, ул. Николаева, д. 38А (Дом досуга)		0101000020E610000053D0ED258DFD47403A5AD5928E4A4A40
83821	7	73	626	7132	31172	\N	52.529223000000002	Саратовская область, Хвалынский район, село Елховка, ул. Молодежная, д. 6 (МОУ ООШ)		0101000020E61000006116DA39CDE6474040A54A94BD434A40
83815	7	73	626	6878	31260	\N	52.566237000000001	Саратовская область, Хвалынский район, село Горюши, ул. Советская, д. 76 (Дом культуры)		0101000020E6100000390B7BDAE1CD474080643A747A484A40
83812	7	73	626	6705	30158	\N	52.700771000000003	Саратовская область, Хвалынский район, поселок Возрождение, ул. Степная, д. 1А (Дом культуры)		0101000020E610000064CDC820771748401C7E37DDB2594A40
83809	7	73	626	6552	31380	\N	52.694375000000001	Саратовская область, Хвалынский район, село Благодатное, ул. Центральная, д. 133 (Дом культуры)		0101000020E61000000AF83592040D48407B14AE47E1584A40
83813	7	73	626	6795	30945	\N	52.311230999999999	Саратовская область, Хвалынский район, село Апалиха, ул. 60 лет Октября, д. 46 (дом досуга)		0101000020E6100000D53F8864C8DB47402D40DB6AD6274A40
83807	7	73	626	6497	30940	\N	52.308681999999997	Саратовская область, Хвалынский район, поселок Алексеевка, ул. Чапаева, д. 64 (администрация)		0101000020E610000066868DB27E034840936E4BE482274A40
83822	7	73	626	7221	30599	\N	52.453789	Саратовская область, Хвалынский район, село Акатная Маза, ул. Молодежная, д. 2 (МОУ ООШ)		0101000020E610000009168733BFD447406C2409C2153A4A40
83801	7	73	218	1454	31373	\N	51.359188000000003	"Саратовская область, Федоровский район, Федоровское муниципальное образование, село Федоровка, Администрация округа - ул. Молодежная,15, ул. Им. Гаввы, 86 Дом культуры  "		0101000020E61000006D1B4641F0C04740CE8E54DFF9AD4940
83804	7	73	218	1580	30835	\N	51.364019711898798	Саратовская область, Федоровский район, Калужское муниципальное образование, село Тамбовка, ул. Победы 55, МОУ ООШ	Россия, Саратовская область, Федоровский район, село Тамбовка	0101000020E610000047E7FC14C7914740828B153598AE4940
83796	7	73	218	5870	30293	\N	51.376727000000002	Саратовская область, Федоровский , Спартакское муниципальное образование, село Спартак, ул.Советская, д. 11б,(адм.МО), ул. Кооперативная,2 МОУ СОШ		0101000020E6100000E1421EC18DE447409642209738B04940
83793	7	73	218	53159	30554	\N	51.1750177943428	Саратовская область, Федоровский район, Никольское муниципальное образование, поселок Солнечный, ул. Набережная, д. 4 Дом культуры	Россия, Саратовская область, Федоровский район, село Солнечный	0101000020E610000084BBB376DBF747400D1B65FD66964940
83787	7	73	218	5430	30557	\N	51.182575	Саратовская область, Федоровский , Семеновское муниципальное образование, село Семеновка, ул. Центральная, д.59а Дом культуры		0101000020E6100000A2EC2DE57CCD47409A081B9E5E974940
83802	7	73	218	6195	30765	\N	51.383771000000003	"Саратовская область, Федоровский муниципальный район, Романовское муниципальное образование, село Романовка, д. 11, Администрация округа-ул.Советская,51, ул.Советская,49 Дом культуры"		0101000020E61000007A17EFC7EDAF47409D137B681FB14940
94389	7	73	218	5865	30544	\N	51.292729999999999	Саратовская область, Федоровский , Морцевское муниципальное образование, село Плес, ул. Рабочая, 3, МДОУ д/с Петушок		0101000020E6100000EB6E9EEA90E347406F47382D78A54940
83798	7	73	218	5977	31367	\N	51.462364000000001	Саратовская область, Федоровский муниципальный район, Первомайское муниципальное образование, село Первомайское, Администрация округа, ул.Октябрьская, 19 МОУ СОШ		0101000020E61000009032E202D0CE4740836C59BE2EBB4940
83789	7	73	218	5489	30979	\N	51.190004999999999	Саратовская область, Федоровский район, Николаевское муниципальное образование, село Николаевка, ул. Центральная, д.44 Дом культуры		0101000020E6100000FE7F9C3061D64740CA89761552984940
83797	7	73	218	5928	\N	\N	51.313391000000003	Саратовская область, Федоровский  район, Мунинское муниципальное образование, село Мунино, здание Школы	Россия, Саратовская область, Федоровский район, село Мунино	0101000020E61000008597E0D407F447402DEE3F321DA84940
83792	7	73	218	5666	30328	\N	51.288460999999998	Саратовская область, Федоровский район, Морцевское муниципальное образование, село Морцы, ул .Степная, д. 5 Дом культуры		0101000020E61000009BC6F65AD0EB4740F295404AECA44940
83782	7	73	218	829	30532	\N	51.238340000000001	Саратовская область, Федоровский  р.п. Мокроус, ул. Энгельса, 14а Дом Культуры		0101000020E6100000A3AD4A22FBC0474011AAD4EC819E4940
83781	7	73	218	829	31212	\N	51.238340000000001	Сартовская область, Федоровский район, п. Мокроус, ул. Советская, д. 3		0101000020E6100000A3AD4A22FBC0474011AAD4EC819E4940
83784	7	73	218	829	31234	\N	51.238340000000001	Саратовская область, Федоровский район р.п. Мокроус, ул. Сельхозтеника, д. 1а д.14, здание налоговой инспекции		0101000020E6100000A3AD4A22FBC0474011AAD4EC819E4940
83783	7	73	218	829	30243	\N	51.238340000000001	Саратовская область, Федоровский муниципальный район, Мокроусское муниципальное образование, р.п. Мокроус, р.п. Победы, д.21 (адм.МО)		0101000020E6100000A3AD4A22FBC0474011AAD4EC819E4940
83785	7	73	218	829	31226	\N	51.238340000000001	Саратовская область, Федоровский , р.п. Мокроус, ул.Восточная, д.40 МОУ СОШ №2		0101000020E6100000A3AD4A22FBC0474011AAD4EC819E4940
94387	7	73	218	1352	31238	\N	51.158980999999997	Саратовская область, Федоровский муниципальный район, село Митрофановка, ул. Новая,5а филиал МОУ СОШ №1		0101000020E6100000AC3B16DBA4C64740BAD7497D59944940
83803	7	73	218	6282	30834	\N	51.370964000000001	Саратовская область, Федоровский район, Калужское муниципальное образование, село Калуга, Администрация округа, ул.Школьная,2 Дом культуры		0101000020E6100000986BD102B495474026FF93BF7BAF4940
83791	7	73	218	5598	31067	\N	51.223923999999997	Саратовская область, Федоровский район, село Калдино, ул. Победы, д.48 Дом культуры		0101000020E6100000234BE658DEDD47400E65A88AA99C4940
83786	7	73	218	887	30324	\N	51.163052999999998	Саратовская область, Федоровский , село Ивановка, ул. Центральная, д.60, Дом Культуры		0101000020E61000003A765089EBC04740E141B3EBDE944940
83805	7	73	218	6338	30576	\N	51.231668999999997	Саратовская область, Федоровский муниципальный район, Ерусланское муниципальное образование, село Еруслан, ул. Мирная, 10А, МОУ СОШ		0101000020E610000092921E8656A947409E3F6D54A79D4940
83806	7	73	218	6399	31314	\N	51.140917999999999	Саратовская область, Федоровский , Долинское муниципальное образование, село Долина, ул. Иванова А.А., д.7, МОУ СОШ		0101000020E6100000E0F42EDE8FB5474078B5DC9909924940
83800	7	73	218	6124	\N	\N	51.391713000000003	Саратовская область, Федоровский район, Федоровское муниципальное образование, село Воскресенка, Дом культуры, ул.Набережная, 24, адм. МО	Россия, Саратовская область, Федоровский район, село Воскресенка	0101000020E61000009B3924B550C047408335CEA623B24940
94388	7	73	218	1417	30335	\N	51.017747	Саратовская область, Федоровский муниципальный район, Борисоглебовское муниципальное образование, село Борисоглебовка, ул.Победы, д. 33, МОУ СОШ		0101000020E6100000DF87838428E14740124DA08845824940
83780	7	73	201	758	67133	\N	51.921607030457501	Саратовская область, Турковский район, село Шепелевка, МОУ ООШ ул.Школьная, 1	Россия, Саратовская область, Турковский район, село Шепелевка	0101000020E61000003A3E5A9C319C4540E161DA37F7F54940
83779	7	73	201	4962	67132	\N	51.953274999999998	Саратовская область, Турковский район, село Чернавка, МОУ ООШ, ул. 40 лет Победы, 19		0101000020E6100000842BA0504F854540158C4AEA04FA4940
83767	7	73	201	4153	31048	\N	51.983837000000001	Саратовская область, Турковский район, рабочий поселок Турки, ул. Ульяны Громовой, д. 1 (школа)	Россия, Саратовская область, Турковский район, поселок Турки	0101000020E61000001024EF1CCAA2454021CCED5EEEFD4940
83764	7	73	201	4153	30666	\N	51.983837000000001	Саратовская область, Турковский район, рабочий поселок Турки, ул. Свердлова, д. 5 (средняя школа)		0101000020E61000001024EF1CCAA2454021CCED5EEEFD4940
83766	7	73	201	4153	30301	\N	51.983837000000001	Саратовская область, Турковский район, рабочий поселок Турки, ул. Ленина, д. 124/1 (Дом досуга)		0101000020E61000001024EF1CCAA2454021CCED5EEEFD4940
83765	7	73	201	4153	30301	\N	51.983837000000001	Саратовская область, Турковский район, рабочий поселок Турки, ул. Ленина, д. 1А (Дом культуры)		0101000020E61000001024EF1CCAA2454021CCED5EEEFD4940
83768	7	73	201	4362	9759	\N	52.037101516892697	Саратовская область, Турковский район, село Трубетчино, ул. Центральная, д. 39А (школа)	Россия, Саратовская область, Турковский район, село Трубетчино	0101000020E610000063D2DF4BE1A34540DF4E22C2BF044A40
83778	7	73	201	4958	31137	\N	52.109371000000003	Саратовская область, Турковский район, село Студенка, ул. Мира, д. 24/3 (администрация МО)		0101000020E6100000DA3BA3AD4A8C4540BF1072DEFF0D4A40
83777	7	73	201	4911	30978	\N	52.117279000000003	Саратовская область, Турковский район, село Рязанка, ул. Центральная, д. 135 (ДК)		0101000020E6100000B4E6C75F5A7A4540F9C08EFF020F4A40
83776	7	73	201	4852	31350	\N	52.231202000000003	Саратовская область, Турковский район, село Перевесино-Михайловка, ул. Советская, д. 57А (школа)		0101000020E61000006FD39FFD487D45408962F206981D4A40
83774	7	73	201	4710	31467	\N	52.211914	Саратовская область, Турковский район, село Перевесинка, ул. Центральная, д. 28 (ДК)		0101000020E610000079C9FFE4EFA0454043C879FF1F1B4A40
83773	7	73	201	4702	30728	\N	52.119193000000003	Саратовская область, Турковский район, село Марьино, ул. Молодежная, д. 7В (ДК)		0101000020E6100000BF45274BAD634540C1745AB7410F4A40
83772	7	73	201	4594	31456	\N	52.038648999999999	Саратовская область, Турковский район, село Лунино, ул. Горная, д.32 т.2-47-25 МОУ ООШ		0101000020E6100000DC662AC4236F4540F5824F73F2044A40
83771	7	73	201	4587	9856	\N	52.013933999999999	Саратовская область, Турковский район, село Каменка, ул. Ленина, д. 37 (школа)		0101000020E610000073486AA164964540B726DD96C8014A40
94386	7	73	201	4522	9920	\N	52.229568999999998	Саратовская область, Турковский район, село Дмитриевка, ул. Советская, д. 11А (МОУ НОШ)		0101000020E6100000B28174B16987454074965984621D4A40
83769	7	73	201	4435	31466	\N	52.147374999999997	Саратовская область, Турковский район, село Бороно-Михайловка, ул. Школьная, д. 41 (школа)		0101000020E6100000BE4D7FF623974540BE9F1A2FDD124A40
83761	7	73	219	3983	31451	\N	51.971632999999997	Саратовская область, Татищевский район, село Ягодная Поляна, ул. Советская, д.51 (здание сельского клуба)		0101000020E610000027A25F5B3FCD4640705B5B785EFC4940
83759	7	73	219	3892	31195	\N	51.705357999999997	Саратовская область, Татищевский район, село Широкое, Адрес помещения для голосования: ул.Московская, д.7 (МОУ СОШ с.Широкое), Адрес УИК: ул.Ленина, д.59А (здание администрации)		0101000020E6100000DF6FB4E386E3464069FCC22B49DA4940
83758	7	73	219	3794	30332	\N	51.678024000000001	Саратовская область, Татищевский район, р.п.Татищево, ул.Школьная, д.8 (МОУ СОШ №1 р.п. Татищево)		0101000020E6100000EB6E9EEA90CD464099F38C7DC9D64940
83757	7	73	219	3794	31338	\N	51.678024000000001	Саратовская область, Татищевский район, р.п.Татищево, ул.Советская, д.5 (здание ЦДК)		0101000020E6100000EB6E9EEA90CD464099F38C7DC9D64940
83753	7	73	219	53184	31600	\N	51.648889931029998	Саратовская область, Татищевский район, село Сторожевка, ул.Школьная, д.1 (МОУ СОШ с.Сторожевка)		0101000020E6100000C7F484251EE84640C959D8D30ED34940
83752	7	73	219	53184	30963	\N	51.651132436191297	Саратовская область, Татищевский район, село Сторожевка, Адрес помещения для голосования: ул.Свободный переулок, д.4А (сельский дом культуры  МУК Межпоселенческая ЦКС), Адрес УИК: ул.Газовиков, д.2 (здание администрации)		0101000020E6100000B16D516683E8464085B01A4B58D34940
83747	7	73	219	3275	30893	\N	52.003196000000003	Саратовская область, Татищевский район, село Сокур, ул.Юбилейная, д.22 (МОУ СОШ с.Сокур)		0101000020E6100000F17EDC7EF9E4464030BDFDB968004A40
83741	7	73	219	2922	31136	\N	51.746797000000001	Саратовская область, Татищевский район, село Слепцовка, Адрес помещения для голосования: ул. Школьная, д.3Б (сельский клуб МУК Межпоселенческая ЦКС), Адрес УИК: ул. Советская, д.86 (здание администрации)		0101000020E61000003F56F0DB10BD46401EE0490B97DF4940
83750	7	73	219	3439	30865	\N	51.760869	Саратовская область, Татищевский район, поселок Садовый, ул. Центральная, д.4 ( здание сельского клуба)		0101000020E610000044334FAE29A8464026C5C72764E14940
83751	7	73	219	3497	30421	\N	51.782983000000002	Саратовская область, Татищевский район, деревня Полянское, Адрес помещения для голосования: ул.Центральная, д.23 (сельский клуб МУК Межпоселенческая ЦКС), Адрес УИК: ул.Центральная, д.41 (ОАО Кологривовское)		0101000020E61000001B834E081DA84640782975C938E44940
83736	7	73	219	2616	30366	\N	51.860596000000001	Саратовская область, Татищевский район, село Полчаниновка, Адрес помещения для голосования: ул. Центральная, д.67 (сельский клуб МУК Межпоселенческая ЦКС), Адрес УИК: ул. Центральная, д.72/1 (здание администрации)		0101000020E610000031242713B7CC4640C2887D0228EE4940
83748	7	73	219	3315	30384	\N	51.637689999999999	Саратовская область, Татищевский район, село Октябрьский Городок, Адрес помещения для голосования: ул.Уханова, д.115 (МОУ СОШ с.Октябрьский городок), Адре УИК: ул.Уханова, д.60 (здание администрации)		0101000020E61000000074982F2FBA46403D7E6FD39FD14940
83738	7	73	219	2731	30691	\N	51.789591000000001	Саратовская область, Татищевский район, село Нееловка, ул.Дорожная, д. 22А (здание сельского клуба)		0101000020E610000036E50AEF72ED4640A41B615111E54940
83745	7	73	219	3150	30696	\N	51.8505607887246	Саратовская область, Татищевский район, село Мизино-Лапшиновка, ул.Октябрьская, д.44 (здание администрации)	Россия, Саратовская область, Татищевский район, село Мизино-Лапшиновка	0101000020E61000009B374E0AF3E646406420CF2EDFEC4940
83705	7	73	219	832	30430	\N	51.712021999999997	Саратовская область, Саратовский район, хутор Малая Скатовка, ул. Дорожная, д. 14 (МОУ ООШ х. Малая Скатовка)		0101000020E61000002F3201BF46F046402904728923DB4940
83740	7	73	219	2851	31435	\N	51.791646	Саратовская область, Татищевский район, деревня Македоновка, ул.Центральная, д.41 (здание школы)		0101000020E6100000325871AAB5C046402E01F8A754E54940
83756	7	73	219	3706	31378	\N	51.616466000000003	Саратовская область, Татищевский район, станция Курдюм, Адрес помещения для голосования: ул.Школьная, д.10 (МОУ СОШ ст.Курдюм), Адрес УИК: ул.Школьная, д.49 (здание администрации)		0101000020E61000000EA0DFF76FDA4640488C9E5BE8CE4940
83755	7	73	219	3706	30500	\N	51.612334335527201	Саратовская область, Татищевский район, село Курдюм, Адрес помещения для голосования: ул.Пономарева, д.22 (сельский клуб МУК Межпоселенческая ЦКС), Адре УИК: ул.Пономарева, д.12 (здание администрации)	Россия, Саратовская область, Татищевский район, село Курдюм	0101000020E6100000242713B70ADA46404B1DE4F560CE4940
83744	7	73	219	3074	30692	\N	51.584198000000001	Саратовская область, Татищевский район, село Куликовка, ул. Мира, д.14 (здание сельского клуба)		0101000020E610000024D3A1D3F3A44640BE310400C7CA4940
83749	7	73	219	3381	31235	\N	51.631405999999998	Саратовская область, Татищевский район, село Кувыка, Адрес помещения для голосования: ул.Шигаева, д.92 (МОУ ООШ  с. Кувыка), ул.Шигаева, д.85 (здание администрации)		0101000020E61000009D66817687C04640C43F6CE9D1D04940
83746	7	73	219	3214	31101	\N	51.875812000000003	Саратовская область, Татищевский район, село Корсаковка, ул.Центральная, д.55 (здание бывшей школы)		0101000020E6100000E90FCD3CB9E04640E1B88C9B1AF04940
83743	7	73	219	3041	31279	\N	51.692525000000003	Саратовская область, Татищевский район, село Карякино, ул.Школьная, д.1 (здание сельского клуба)		0101000020E6100000F20A444FCAA44640CA54C1A8A4D84940
83742	7	73	219	2970	30735	\N	51.646026883272199	Саратовская область, Татищевский район, село Карамышка, Адрес помещения для голосования: ул.Юбилейная, д.25 (сельский клуб МУК Межпоселенческая ЦКС), Адре УИК: ул.Юбилейная, д.21 (здание администрации)	Россия, Саратовская область, Татищевский район, село Карамышка	0101000020E6100000E4D9E55B1FAE46409FAA4203B1D24940
83754	7	73	219	3648	31107	\N	51.658031999999999	Саратовская область, Татищевский район, деревня Ильиновка, ул.Центральная, д.24/1 (здание сельского клуба)		0101000020E61000008F6CAE9AE7D8464059DC7F643AD44940
83739	7	73	219	2802	9940	\N	51.712122000000001	Саратовская область, Татищевский район, село Идолга, Адрес помещения для голосования: ул.Центральная, д.49 (сельский дом культуры МУК Межпоселенческая ЦКС), Адрес УИК: ул.Центральная, д.8 (здание администрации)		0101000020E6100000890CAB7823D146408D614ED026DB4940
83268	7	73	219	53171	30771	\N	51.677950831718903	Саратовская область, ЗАТО Светлый, ул. Кузнецова, д.10 (СОШ №2 актовый зал)	Россия, Саратовская область, Татищевский район, поселок Татищево	0101000020E610000064E8D84125D046402FA52E19C7D64940
83737	7	73	219	2696	30417	\N	51.803064999999997	Саратовская область, Татищевский район, село Вязовка, ул.Ленина, д.135 (здание администрации)		0101000020E6100000481ADCD616E44640F7C77BD5CAE64940
83763	7	73	219	4102	30203	\N	51.844757999999999	Саратовская область, Татищевский район, село Большая Федоровка, ул.Верхняя, д.48 (здание сельского клуба)		0101000020E6100000041BD7BFEBBF46406684B70721EC4940
83760	7	73	219	3928	30497	\N	51.760061	Саратовская область, Татищевский район, село Большая Каменка, ул.Рабочая, д.8 (здание школы)		0101000020E6100000B8054B7501DF464087FBC8AD49E14940
83735	7	73	219	2575	67117	\N	51.811	Саратовская область, Татищевский район, село Большая Ивановка, Адрес помещения для голосования: ул. Административный проезд 1, д.6 (сельский дом культуры МУК Межпоселенческая ЦКС), Адрес УИК: ул. Административный проезд 1, д.10 (здание администрации)		0101000020E61000001074B4AA25CF46402B8716D9CEE74940
83719	7	73	327	1523	30250	\N	51.380544	Саратовская область, Советский район, рабочий поселок Степное, ул. Школьная, д. 4  (МОУ-СОШ №1)		0101000020E6100000FF976BD1026C4740325871AAB5B04940
83154	7	73	327	1523	31159	\N	51.380544	Саратовская область, Калининский район, п. Степное, ул. Советская (Школа), д. 39		0101000020E6100000FF976BD1026C4740325871AAB5B04940
83721	7	73	327	1523	31081	\N	51.380544	Саратовская область, Советский район, рабочий поселок Степное, ул. К.Маркса, д. 10 (Дом культуры)		0101000020E6100000FF976BD1026C4740325871AAB5B04940
83722	7	73	327	1523	30563	\N	51.380544	Саратовская область, Советский район, рабочий поселок Степное, ул. Димитрова, д. 20 (МОУ-СОШ №2)		0101000020E6100000FF976BD1026C4740325871AAB5B04940
83717	7	73	327	1523	30563	\N	51.380544	Саратовская область, Советский район, рабочий поселок Степное, ул. Димитрова, д. 1Б (здание Пенсионного фонда)		0101000020E6100000FF976BD1026C4740325871AAB5B04940
83720	7	73	327	1523	30998	\N	51.380544	Саратовская область, Советский район, рабочий поселок Степное, ул. 50 лет Победы, д. 5  (Школа искусств)		0101000020E6100000FF976BD1026C4740325871AAB5B04940
83718	7	73	327	1523	30998	\N	51.380544	Саратовская область, Советский район, рабочий поселок Степное, ул. 50 лет Победы, д. 14 (РДДиЮ)		0101000020E6100000FF976BD1026C4740325871AAB5B04940
83723	7	73	327	1869	30468	\N	51.442962000000001	Саратовская область, Советский район, рабочий поселок Советское, ул. 50 лет Пионерии, д. 13 (МОУ-СОШ)		0101000020E6100000AFE94141295E474075AF93FAB2B84940
83728	7	73	327	2158	30205	\N	51.226384000000003	Саратовская область, Советский район, село Розовое, ул. Кооперативная, д. 20 (Дом культуры)		0101000020E610000070D234289A634740392BA226FA9C4940
83724	7	73	327	1913	30471	\N	51.231758999999997	Саратовская область, Советский район, рабочий поселок Пушкино, ул. Кооперативная, д. 27 (Дом культуры)		0101000020E61000004B749659847C4740DEC66647AA9D4940
83730	7	73	327	2280	30265	\N	51.294808000000003	Саратовская область, Советский район, село Пионерское, ул. Клубная, д. 17 (МОУ-ООШ)		0101000020E6100000EB5223F4336F4740B24CBF44BCA54940
83734	7	73	327	2517	30933	\N	51.352072999999997	Саратовская область, Советский район, село Новолиповка, ул. Клубная, д. 14 (МОУ-ООШ)		0101000020E61000004A9BAA7B647B4740FD6662BA10AD4940
83733	7	73	327	2459	30206	\N	51.284258000000001	Саратовская область, Советский район, село Новокривовка, ул. Школьная, д. 14А (Дом культуры)		0101000020E610000026A77686A98347402DD0EE9062A44940
83725	7	73	327	1998	30965	\N	51.262334000000003	Саратовская область, Советский район, село Новоантоновка, ул. Школьная, д. 11 (Клуб)		0101000020E6100000DFA46950347947407F50172994A14940
83731	7	73	327	2356	30883	\N	51.436146000000001	Саратовская область, Советский район, село Мечетное, ул. Школьная, д. 12А (Дом культуры)		0101000020E6100000C5ABAC6D8A814740FF23D3A1D3B74940
83732	7	73	327	2394	31194	\N	51.438543000000003	Саратовская область, Советский район, село Любимово, ул. Школьная, д. 20А (МОУ-ООШ)		0101000020E61000005F0839EFFF8B4740E371512D22B84940
83726	7	73	327	2052	30412	\N	51.280185000000003	Саратовская область, Советский район, село Золотая Степь, ул. Вокзальная, д. 1А (Клуб)		0101000020E610000081B4FF01D664474036EA211ADDA34940
83727	7	73	327	2121	30289	\N	51.265399000000002	Саратовская область, Советский район, село Александровка, ул. Юбилейная, д. 3 (Дом культуры)		0101000020E6100000713D0AD7A36C474010B22C98F8A14940
83706	7	73	7270	53186	\N	\N	51.641065213423197	Саратовская область, Саратовский район, поселок Зоринский, (Административное здание ООО Горизонт)		0101000020E61000007F4E417E360247401CCEFC6A0ED24940
83693	7	73	25	53194	31158	\N	51.495767999999998	Саратовская область, Саратовский район, с. Свинцовка, ул.Школьная, (Дом Досуга с. Свинцовка)		0101000020E610000088F71C588EE44640A033695375BF4940
83701	7	73	25	583	31221	\N	51.443449999999999	Саратовская область, Саратовский район, деревня Юрловка, ул. Молодежная, (МОУ СОШ д. Юрловка)		0101000020E6100000DAAB8F87BEB74640A2B437F8C2B84940
80740	7	72	1496	17356	47689	\N	52.905157000000003	Утевка, Льва Толстого, 26 (школа)		0101000020E61000009F71E140487849406C5F402FDC734A40
83686	7	73	25	32195	67112	\N	51.806896000000002	"Саратовская область, Саратовский район,с.Шевыревка, ул. Центральная, д.58 УИК адм. Вольновского МО, в день голосования- ул. Центральная,37 филиал ""Дом досуга"""		0101000020E61000003A77BB5E9A164740F9A23D5E48E74940
83715	7	73	25	1420	31311	\N	51.650824	Саратовская область, Саратовский  район, село Усть-Курдюм, ул. Большая Советская, д. 66 (МОУ СОШ с. Усть-Курдюм)		0101000020E6100000AAD72D0263194740D8B969334ED34940
83700	7	73	25	516	30453	\N	51.449221000000001	Саратовская область, Саратовский район, село Сосновка, ул. Школьная, д. 17 (МОУ СОШ с. Сосновка)		0101000020E61000002A8BC22E8AC4464095D6DF1280B94940
83685	7	73	25	32191	30225	\N	51.383377000000003	Саратовская область, Саратовский район, поселок Хмелевский, ул. Центральная, д.39 (Дом досуга п. Хмелевский)		0101000020E6100000EFA83121E6E84640F1845E7F12B14940
83708	7	73	25	53237	31586	\N	51.307645522731697	Саратовская область, Саратовский район, п. Центральная усадьба совхоза 15 лет Октября, ул. Центральная, д. 1Б (Здание Дома досуга)		0101000020E61000001A355F251FB14640635FB2F160A74940
83711	7	73	25	1195	31178	\N	51.23715	Саратовская область, Саратовский район, село Синенькие, ул. Советская, д. 89 (Дом культуры с. Синенькие)		0101000020E61000008CF678211DE246408A1F63EE5A9E4940
83712	7	73	25	1236	31077	\N	51.290370000000003	Саратовская область, Саратовский район, поселок Сергиевский, ул. Октябрьская, д. 22 (Детская школа искусств № 4)		0101000020E6100000535C55F65DD34640A9DE1AD82AA54940
83688	7	73	25	32287	30826	\N	51.691358000000001	Саратовская область, Саратовский район, село Сабуровка, ул. Школьная, д.1 (Здание школы)		0101000020E610000037A5BC5642194740FBE93F6B7ED84940
83707	7	73	25	955	31315	\N	51.281571	Саратовская область, Саратовский район, село Рыбушка, ул.Школьная, д.42 А (МОУ СОШ с. Рыбушка)		0101000020E6100000D00F238447B946404240BE840AA44940
83716	7	73	25	53167	30681	\N	51.602448867670397	Саратовская область, Саратовский район, село Пристанное, ул. Советская, д. 3 (МОУ СОШ с. Усть-Курдюм)	Россия, Саратовская область, село Пристанное	0101000020E61000002578431A151A47400341800C1DCD4940
83710	7	73	25	1125	31323	\N	51.420147	Саратовская область, Саратовский район, село Поповка, ул. Школьная, д. 28 (Дом культуры с. Поповка)		0101000020E6100000C423F1F274CA46409A417C60C7B54940
82365	7	73	25	53210	\N	\N	51.434933000000001	Саратовская область, город Саратов, Заводской район, поселок Новый Увек, (МОУ ООШ № 91)	Россия, Саратовская область, Саратов, Заводской район	0101000020E61000006F62484E26FC4640C07971E2ABB74940
83691	7	73	25	32454	30230	\N	51.722405999999999	Саратовская область, Саратовский район, деревня Новая Липовка, ул. Широкая, д.5 (Дом досуга д. Новая Липовка)		0101000020E6100000404CC2853C0A47409337C0CC77DC4940
83697	7	73	25	324	31292	\N	51.493552999999999	Саратовская область, Саратовский район,село Михайловка, ул. Центральная, д.9 (МОУ СОШ с. Михайловка)		0101000020E61000005DDC460378DB4640DDEBA4BE2CBF4940
83695	7	73	25	199	30988	\N	51.354317999999999	Саратовская область, Саратовский район, р.п. Красный Текстильщик, ул. Калинина, д.4 А (МОУ СОШ р.п.Кр.Текстильщик)		0101000020E6100000AA99B51490EA46402B31CF4A5AAD4940
83696	7	73	25	199	30449	\N	51.354317999999999	Саратовская область, Саратовский район, р.п. Красный Текстильщик, ул.Базарная, д.8, (Дом культуры р.п. Красный Текстильщик)		0101000020E6100000AA99B51490EA46402B31CF4A5AAD4940
83694	7	73	25	117	30235	\N	51.541365999999996	Саратовская область, Саратовский район, р.п. Красный Октябрь, ул. Нефтяников,  д.21, (Дом культуры р.п. Красный Октябрь)		0101000020E61000009D2B4A09C1D846404A95287B4BC54940
83698	7	73	25	385	30670	\N	51.438868999999997	Саратовская область, Саратовский район, село Константиновка, ул. Коммунарная, д.2 Б (МОУ ООШ с. Константиновка)		0101000020E61000008733BF9A03D04640361D01DC2CB84940
83699	7	73	25	466	31131	\N	51.383012000000001	Саратовская область, Саратовский район, село Колотов Буерак, ул. Садовая, д.27(Фельдшерско-акушерский пункт)		0101000020E6100000E6E61BD13DDF4640DFFC868906B14940
83692	7	73	25	32458	31422	\N	51.729201000000003	Саратовская область, Саратовский район, село Клещевка, ул. Советская, д.29 (Дом досуга с. Клещевка)		0101000020E610000015AB06616E054740F29A577556DD4940
83702	7	73	25	646	30832	\N	51.387974999999997	Саратовская область, Саратовский район, поселок Ивановский, ул. Центральная, д. 31 (МОУ ООШ п. Ивановский)		0101000020E610000092B3B0A71DD846403255302AA9B14940
83690	7	73	25	53205	31309	\N	51.663776246715997	Саратовская область, Саратовский район, поселок Дубки, ул.Октябрьская, (МОУ СОШ п. Дубки)		0101000020E61000009A5E622CD307474052EFA99CF6D44940
83704	7	73	25	53165	\N	\N	51.674578934381202	Саратовская область, Саратовский район, хутор Бартоломеевский, (МДОУ Детский сад Теремок)		0101000020E6100000649291B3B0FD4640C1C8CB9A58D64940
83684	7	73	25	32118	30224	\N	51.416007	Саратовская область, Саратовский район, село Багаевка, ул.Советская, д.25 (МУК Дом культуры с. Багаевка)		0101000020E61000005C3AE63C63E946401BF4A5B73FB54940
83682	7	73	7267	53193	31147	\N	51.499867000000002	Саратовская область, Саратовский район, поселок Рейник, ул. Овражная, д.12/3(Фельдшерско-акушерский пунк)		0101000020E610000048C32973F3EF4640C1AC50A4FBBF4940
83679	7	73	7267	53172	30800	\N	51.464036999999998	Саратовская область, Саратовский  район, село Березина-Речка, ул. Школьная, (МОУ СОШ с. Березина Речка)		0101000020E6100000029B73F04CF0464025917D9065BB4940
83663	7	73	826	22459	30612	\N	51.233252999999998	Саратовская область, Самойловский район, поселок Южный, ул. Совхозная, д. 6 А (филиал МОУ СОШ)		0101000020E6100000AD510FD1E8BC4540D158FB3BDB9D4940
82847	7	73	595	23785	\N	\N	51.623663000000001	Саратовская область, Балашовский район, п. Александровский, здание школы		0101000020E6100000FAD170CADCC64540D55C6E30D4CF4940
83675	7	73	826	6928	31078	\N	51.194429999999997	Саратовская область, Самойловский район, село Хрущевка,  ул.Школьная,д.2 здание филиала МОУ СОШ п.Садовый в с.Хрущевка   ул. Почтовая, д. 2 (Хрущевский СК)		0101000020E610000080D6FCF84BFF45403EAE0D15E3984940
83655	7	73	826	30735	30954	\N	51.134141999999997	Саратовская область, Самойловский район, село Тюменевка, ул. Рабочая, д. 70 (филиал МОУ СОШ)		0101000020E6100000E3DD91B1DA9045409082A7902B914940
83670	7	73	826	31523	31123	\N	51.309764999999999	Саратовская область, Самойловский район, поселок Тульский, ул. Мира, д. 12 (филиал МОУ СОШ)		0101000020E6100000FC71FBE593B1454004392861A6A74940
83668	7	73	826	31418	31397	\N	51.329759000000003	Саратовская область, Самойловский район, село Святославка, ул. Ленина, д. 45 (Святославский СДК)		0101000020E61000002FDD240681B74540E547FC8A35AA4940
83674	7	73	826	24576	30197	\N	51.413114999999998	Саратовская область, Самойловский район, поселок Самородовка, ул. Центральная, д. 2 А (филиал МОУ СОШ)		0101000020E61000006BD26D895CCA4540573ECBF3E0B44940
83642	7	73	826	23131	30769	\N	51.180419000000001	Саратовская область, Самойловский район, р.п. Самойловка, ул. Ревякина, д. 8 Б  (МОУ СОШ № 2)		0101000020E61000003509DE9046DB4540DC4944F817974940
83643	7	73	826	23131	30941	\N	51.180419000000001	Саратовская область, Самойловский район, р.п. Самойловка, ул. Красная площадь, д. 18 (Районный дом культуры)		0101000020E61000003509DE9046DB4540DC4944F817974940
83644	7	73	826	23131	30580	\N	51.180419000000001	Саратовская область, Самойловский район, р.п. Самойловка, ул. Коневка, д. 100 (МОУ ДОД ДЮСШ)		0101000020E61000003509DE9046DB4540DC4944F817974940
83676	7	73	826	31757	31130	\N	51.180802999999997	Саратовская область, Самойловский район, поселок Садовый, ул. Центральная, д. 16 (Садовый СДК)		0101000020E6100000836C59BE2E11464064027E8D24974940
83654	7	73	826	30670	30953	\N	51.13794	Саратовская область, Самойловский район, село Полтавка, ул. Ленина, д. 34 (филиал МОУ СОШ)		0101000020E6100000DC0E0D8B51A34540B6679604A8914940
83658	7	73	826	22387	30290	\N	51.068221999999999	Саратовская область, Самойловский район, село Полоцкое, ул. Победы, д. 52 А (филиал МОУ СОШ)		0101000020E610000007D15AD1E6AA4540116F9D7FBB884940
83667	7	73	826	31325	30398	\N	51.304326000000003	Саратовская область, Самойловский район, село Песчанка, ул. Ленина, д. 20 (филиал МОУ СОШ)		0101000020E61000005517F032C3D6454048A98427F4A64940
83673	7	73	826	11846	30964	\N	51.412244000000001	Саратовская область, Самойловский район, поселок Передовой, ул. Школьная, д. 2 (филиал МОУ СОШ)		0101000020E61000008A3F8A3A73B1454072FC5069C4B44940
83651	7	73	826	30519	30950	\N	51.161805000000001	Саратовская область, Самойловский район, село Ольшанка, ул. Ленина, д. 5 (Ольшанский СДК)		0101000020E6100000463F1A4E99D5454026AAB706B6944940
83672	7	73	826	6400	31166	\N	51.360194999999997	Саратовская область, Самойловский район, село Новомихайловка, ул. Грейдерная, д. 7 А (филиал МОУ СОШ)		0101000020E610000092205C0185BC45406397A8DE1AAE4940
83660	7	73	826	30974	31392	\N	51.321863	Саратовская область, Самойловский район, село Новоалександровка, ул. Заречная, д. 36 (филиал МОУ СОШ)		0101000020E6100000B3CF639467BC45406F6589CE32A94940
83664	7	73	826	31210	30187	\N	51.261921999999998	Саратовская область, Самойловский район, село Николаевка, ул. Гагарина, д. 7 (филиал МОУ СОШ)		0101000020E61000009581035ABAA045402C0DFCA886A14940
83656	7	73	826	30830	30600	\N	51.136192999999999	Саратовская область, Самойловский район, село Низовка, ул. Новая, д. 5 (филиал МОУ СОШ)		0101000020E61000001475E61E12BE4540D978B0C56E914940
94385	7	73	826	31262	31233	\N	51.311554999999998	Саратовская область, Самойловский район, село Криуша, ул. Почтовая,3 (СДК)		0101000020E610000023BF7E880DDC4540E0F3C308E1A74940
83669	7	73	826	31420	31398	\N	51.410035999999998	Саратовская область, Самойловский район, село Крийнички, ул. Новая, д. 5 (филиал МОУ СОШ)		0101000020E6100000AAEFFCA204D545406117450F7CB44940
83671	7	73	826	22555	31284	\N	51.450662999999999	Саратовская область, Самойловский район, поселок Красный, ул. Ковалевская, д. 3 А (филиал МОУ СОШ)		0101000020E610000049BA66F2CDC8454035423F53AFB94940
83659	7	73	826	9477	30604	\N	51.351560999999997	Саратовская область, Самойловский район, поселок Краснознаменский, ул. Центральная, д. 2 В (Краснознаменский СДК)		0101000020E6100000EF0390DAC4AF454047C66AF3FFAC4940
83653	7	73	826	30616	30956	\N	51.166272999999997	Саратовская область, Самойловский район, село Красавка, ул. Ленина, д. 25 (филиал МОУ СОШ)		0101000020E6100000B66455849BB44540999A046F48954940
83665	7	73	826	31211	30792	\N	51.338391000000001	Саратовская область, Самойловский район, село Каменка, ул. Центральная, д. 6 (Каменский СДК)		0101000020E61000009274CDE49BE145406021736550AB4940
83646	7	73	826	5927	30777	\N	51.202517999999998	Саратовская область, Самойловский район, село Залесянка, ул. Школьная, д. 29 Б (филиал МОУ СОШ)		0101000020E610000001A4367172D54540F86C1D1CEC994940
83652	7	73	826	30611	31387	\N	51.112907999999997	Саратовская область, Самойловский район, село Еловатка, ул. Ленина, д. 34 (филиал МОУ СОШ)		0101000020E61000004243FF0417D3454077BAF3C4738E4940
83649	7	73	826	30421	30779	\N	51.353918	Саратовская область, Самойловский район, деревня Елизаветино, ул. Елизаветинская, д. 30 (ФАП)		0101000020E6100000CEC5DFF604FB45409DBB5D2F4DAD4940
83657	7	73	826	30832	31273	\N	51.067796999999999	Саратовская область, Самойловский район, село Воронино, ул. Заречная, д. 1 (филиал МОУ СОШ)		0101000020E6100000897AC1A739BF45402AE27492AD884940
83662	7	73	826	22457	30185	\N	51.249927	Саратовская область, Самойловский район, село Воздвиженка, ул. Заречная, д. 43 А (филиал МОУ СОШ)		0101000020E6100000F4E159828CB4454096B1A19BFD9F4940
83648	7	73	826	30364	30583	\N	51.323534000000002	Саратовская область, Самойловский район, село Благовещенка, ул. Центральная, д. 8 (Благовещенский СДК)		0101000020E6100000D28C45D3D90546407192E68F69A94940
83650	7	73	826	30518	31105	\N	51.289152999999999	Саратовская область, Самойловский район, село Александровка, ул. Александровская, д. 10 (филиал МОУ СОШ)		0101000020E6100000ADA6EB89AE05464028452BF702A54940
83635	7	73	1712	29736	30341	\N	52.222000999999999	Саратовская область, Ртищевский район, село Шило-Голицыно, ул. Советская, д. 43 (Социально-культурный центр)		0101000020E61000008A1EF818ACDE4540F3565D876A1C4A40
83640	7	73	1712	30026	30577	\N	52.385987	Саратовская область, Ртищевский район, село Урусово, ул. Школьная, д. 24 (Средняя школа)		0101000020E6100000373465A71FE4454030D7A20568314A40
83623	7	73	1712	29200	31071	\N	52.264864000000003	Саратовская область, Ртищевский  район, поселок Темп, ул. Мира, д. 2 (Средняя школа)		0101000020E6100000DCF0BBE996F14540A2F14410E7214A40
83638	7	73	1712	53231	31569	\N	52.291541828870798	Саратовская область, Ртищевский район, поселок Стройиндустрия, ул. Школьная, д. 2 (Средняя щкола)	Россия, Саратовская область, Ртищевский район, село Стройидустрия	0101000020E61000009A0986730DE3454089B48D3F51254A40
83637	7	73	1712	53175	30818	\N	52.258098503424797	Саратовская область, Ртищевский район, поселок Центральная усадьба совхоза Выдвиженец, ул. Юбилейная, д. 22 (Дом культуры)	Россия, Саратовская область, Ртищевский район, село Совхоза Выдвиженец	0101000020E61000002D6002B7EEDE4540AE10566309214A40
83616	7	73	1712	28933	31359	\N	52.181773999999997	Саратовская область, Ртищевский  район, село Сланцы, ул. Куйбышева, д. 58 (Общеобразовательная школа)		0101000020E6100000488C9E5BE8CA4540ADA1D45E44174A40
83621	7	73	1712	29120	30745	\N	52.344766	Саратовская область, Ртищевский район, село Северка, ул. Школьная, д. 13 (Общеобразовательная школа)		0101000020E61000004A0C022B87844540E962D34A212C4A40
83625	7	73	1712	29299	31076	\N	52.329006	Саратовская область, Ртищевский район, село Сапожок, ул. Зеленая, д. 15 (Средняя школа)		0101000020E6100000342BDB87BCFD454009185DDE1C2A4A40
83629	7	73	1712	29469	31252	\N	52.115465999999998	Саратовская область, Ртищевский  район, село Салтыковка, ул. Кирова, д. 35 (Средняя школа)		0101000020E6100000F25F20089009464064E60297C70E4A40
83639	7	73	1712	29932	31094	\N	52.330622644132298	Саратовская область, Ртищевский район, поселок Ртищевсвкий, ул. Школьная, д. 1 (Средняя школа)	Россия, Саратовская область, Ртищевский район, село Ртищевский	0101000020E61000008BA8893E1FF145401827BEDA512A4A40
83620	7	73	1712	29116	31480	\N	52.403830999999997	Саратовская область, Ртищевский район, село Репьевка, ул. Свердлова, д. 3 (Общеобразовательная школа)		0101000020E6100000651D8EAED29F4540340EF5BBB0334A40
83626	7	73	1712	29370	30559	\N	52.314825999999996	Саратовская область, Ртищевский район, поселок Правда, ул. Школьная, д. 2а (Средняя школа)		0101000020E6100000D236FE44650546401AF7E6374C284A40
83618	7	73	1712	28987	30911	\N	52.272232000000002	Саратовская область, Ртищевский  район, село Потьма, ул. Молодежная, д. 1 (Общеобразовательная школа)		0101000020E610000062821ABE85B145405C76887FD8224A40
83611	7	73	1712	28657	30329	\N	52.379483999999998	Саратовская область, Ртищевский район, село Подгоренка, ул. Горная, д. 1а (сельский Клуб)		0101000020E61000005C1E6B4606C7454079AD84EE92304A40
83627	7	73	1712	29373	31243	\N	52.232244999999999	Саратовская область, Ртищевский  район, поселок Первомайский, ул. Садовая, д. 12 (Средняя школа)		0101000020E6100000B682A625561A46406BD44334BA1D4A40
83615	7	73	1712	28848	31239	\N	52.200650000000003	Саратовская область, Ртищевский район, хутор Ободной, ул. Песчаная, д. 3 (Сельский клуб)		0101000020E6100000849CF7FF71A44540A1F831E6AE194A40
83632	7	73	1712	29641	30929	\N	52.100360000000002	Саратовская область, Ртищевский район, село Малиновка, ул. Крупской, д. 54 (Средняя школа)		0101000020E6100000B03907CF84FC4540CDE9B298D80C4A40
83619	7	73	1712	29035	31066	\N	52.274121999999998	Саратовская область, Ртищевский район, село Макарово, ул. Советская, д. 23 (Общеобразовательная школа)		0101000020E6100000637AC2120FAA45409B8E006E16234A40
83624	7	73	1712	29244	31362	\N	52.231186000000001	Саратовская область, Ртищевский  район, поселок Луч, ул. Ленина, д. 15 (Средняя школа)		0101000020E61000007D073F7100FD454083A5BA80971D4A40
83617	7	73	1712	28950	31358	\N	52.145412999999998	Саратовская область, Ртищевский район, село Лопатино, ул. Молодежная, д. 37 (Общеобразовательная школа)		0101000020E61000008352B4722FC04540E5B4A7E49C124A40
83641	7	73	1712	30030	30764	\N	52.214232000000003	Саратовская область, Ртищевский  район, село Курган, ул. Молодежная, д. 1а (Социально-культурный центр)		0101000020E6100000C39E76F86BFE4540DBE044F46B1B4A40
83630	7	73	1712	29515	30569	\N	52.071399999999997	Саратовская область, Ртищевский  район, село Крутец, ул. Пушкина, д. 61 (Средняя школа)		0101000020E6100000E8D84125AE0746409A779CA223094A40
83634	7	73	1712	29728	31253	\N	52.177771	Саратовская область, Ртищевский район, поселок Красные Гривки, ул. Школьная, д. 4 (Дом культуры)		0101000020E6100000384D9F1D70E54540AF963B33C1164A40
83614	7	73	1712	28845	31237	\N	52.196432999999999	Саратовская область, Ртищевский  район, село Красная Звезда, ул. Барменкова, д. 7 (Средняя школа)		0101000020E6100000299831056BB84540766D6FB724194A40
94384	7	73	1712	28761	30704	\N	52.227621999999997	Саратовская область, Ртищевский район, село Ключи, ул. Первомайская, д. 5 (Амбулатория)		0101000020E6100000FD2D01F8A7B84540D0ECBAB7221D4A40
83631	7	73	1712	29571	30570	\N	52.039689289784903	Саратовская область, Ртищевский район, село Каменка, ул. Школьная, д. 1 (Средняя школа)	Россия, Саратовская область, Ртищевский район, село Каменка	0101000020E6100000EBFEB1101DFA45406781768714054A40
83633	7	73	1712	29649	31374	\N	52.137244000000003	Саратовская область, Ртищевский район, село Ерышевка, ул. Советская, д. 17 (Дом культуры)		0101000020E6100000340F60915FF145403FC91D3691114A40
80760	7	72	1496	18307	48381	\N	52.824241000000001	Трофимовка, Центральная, 2 (Клуб)		0101000020E6100000170FEF39B06C4940DC82A5BA80694A40
83628	7	73	1712	29466	30750	\N	52.210281000000002	Саратовская область, Ртищевский  район, село Елань, ул. Школьная, д. 26 (Дом культуры)		0101000020E6100000C9E6AA798E1846402FFCE07CEA1A4A40
83677	7	73	1712	24646	30742	\N	52.210551000000002	Саратовская область, Самойловский район, село Голицыно, ул. Советская, д. 9 адм.здание ИП  КФХ Нестеров  В.В. (По согласованию)		0101000020E61000009F3D97A949BA4540EF91CD55F31A4A40
94383	7	73	1712	28696	31061	\N	52.331868	Саратовская область, Ртищевский район, село Владыкино, ул. Садовая, д. 66 (Средняя Школа)		0101000020E61000007E52EDD3F1BE4540624B8FA67A2A4A40
83622	7	73	1712	29198	31363	\N	52.305582000000001	Саратовская область, Ртищевский район, село Васильевка, ул. Ленина, д. 72 (Общеобразовательная школа)		0101000020E6100000A8C64B3789874540861F9C4F1D274A40
83610	7	73	1712	28649	30330	\N	52.276364999999998	Саратовская область, Ртищевский район, село Александровка, ул. 60 лет Октября, д. 65 (Дом культуры)		0101000020E610000083FC6CE4BACF45402861A6ED5F234A40
83577	7	73	622	22999	31205	\N	51.871107520614103	Саратовская область, Романовский район, село Усть-Щербедино, сельский Дом культуры, ул. Ленина,д.29А	Россия, Саратовская область, Романовский район, село Усть-Щербедино	0101000020E610000025B37A87DB6F454059A4897780EF4940
83587	7	73	622	23367	31214	\N	51.685194000000003	Саратовская область, Романовский район, поселок Таволжанский, сельский Дом культуры, ул.Садовая,д.2		0101000020E6100000E7C75F5AD47545402DB5DE6FB4D74940
83574	7	73	622	4298	30403	\N	51.761932617849098	Саратовская область, Романовский район, рабочий поселок Романовка, ул. Федоровка (клуб Маяк)	Россия, Саратовская область, Романовский район, поселок Романовка	0101000020E610000008E9297288604540205F420587E14940
83571	7	73	622	4298	30291	\N	51.750773000000002	Саратовская область, Романовский район, рабочий поселок Романовка, ул. Советская, д. 281 (детский сад Сказка)		0101000020E6100000878BDCD3D55F454023DC645419E04940
83570	7	73	622	4298	30233	\N	51.750773000000002	Саратовская область, Романовский район, рабочий поселок Романовка, ул. Народная, д. 27 А (районный Дом культуры)		0101000020E6100000878BDCD3D55F454023DC645419E04940
83569	7	73	622	4298	30233	\N	51.750773000000002	Саратовская область, Романовский район, рабочий поселок Романовка, ул. Народная, д. 39 (средняя школа)	Россия, Саратовская область, Романовский район, поселок Романовка	0101000020E6100000878BDCD3D55F454023DC645419E04940
83573	7	73	622	4298	31294	\N	51.750773000000002	Саратовская область, Романовский район, рабочий поселок Романовка, ул. 2-ая Заводская, д. 5 (детский сад Колокольчик)		0101000020E6100000878BDCD3D55F454023DC645419E04940
83588	7	73	622	4586	31224	\N	51.667462	Саратовская область, Романовский район, село Подгорное, средняя школа, ул.Чиркина, д.63		0101000020E6100000AB9674948367454050A912656FD54940
83581	7	73	622	9734	31460	\N	51.864907000000002	Саратовская область, Романовский район, поселок Памятка, средняя школа, ул.Центральная, д.24		0101000020E61000001135D1E7A39645406E8AC745B5EE4940
83576	7	73	622	22995	31458	\N	51.882010999999999	Саратовская область, Романовский район, село Осиновка, сельский Дом культуры, ул.Центральная, д.73а		0101000020E6100000B08C0DDDEC6345402BDB87BCE5F04940
83585	7	73	622	20753	31047	\N	51.812587000000001	Саратовская область, Романовский район, село Мордовский Карай, сельский Дом культуры Мир ул. Ленина, д.52А		0101000020E61000002AFD84B35B6F4540CF13CFD902E84940
83584	7	73	622	20753	31463	\N	51.812587000000001	Саратовская область, Романовский район, село Мордовский Карай, средняя школа, ул.Комсомольская,д.78		0101000020E61000002AFD84B35B6F4540CF13CFD902E84940
83578	7	73	622	3982	31203	\N	51.995589000000002	Саратовская область, Романовский район, село Малое Щербедино, сельский Дом культуры, ул.Народная, д.145		0101000020E610000041BAD8B4526A4540F1A0D9756FFF4940
83586	7	73	622	23356	30513	\N	51.746284000000003	Саратовская область, Романовский район, поселок Красноармейский, средняя школа, ул.Радость, д.58		0101000020E6100000BD361B2B3167454098C3EE3B86DF4940
83589	7	73	622	23406	\N	\N	51.607075999999999	Саратовская область, Романовский район, село Инясево, средняя школа,	Россия, Саратовская область, Романовский район, село Инясево	0101000020E61000009F1EDB32E0664540DF1797AAB4CD4940
83583	7	73	622	22807	30723	\N	51.870379	Саратовская область, Романовский район, село Бык, сельский Дом культуры, ул. Горная,д.1		0101000020E6100000290472892379454006103E9468EF4940
83579	7	73	622	17685	31213	\N	51.600436000000002	Саратовская область, Романовский район, село Большой Карай, сельский Дом культуры, пл.Стоякина, д.1А		0101000020E6100000C9552C7E53564540A8AB3B16DBCC4940
83580	7	73	622	17685	30715	\N	51.600436000000002	Саратовская область, Романовский район, село Большой Карай, средняя школа, ул.Ленина д.20А		0101000020E6100000C9552C7E53564540A8AB3B16DBCC4940
83575	7	73	622	22906	30882	\N	51.827506999999997	Саратовская область, Романовский район, село Бобылевка, средняя школа ул Ярославская, д.210		0101000020E6100000C79BFC169D664540041BD7BFEBE94940
83582	7	73	622	23190	30720	\N	51.884273	Саратовская область, Романовский район, поселок Алексеевский, сельский Дом культуры, ул.Набережная, д.27А		0101000020E61000007AFD497CEE8445402FDE8FDB2FF14940
94382	7	73	1698	26365	31184	\N	51.056050999999997	Саратовская область, Ровенский  район, с.Яблоновка, ул. Почтовая, д. 24 (здание СДК)		0101000020E6100000D7C22CB4730247403CF4DDAD2C874940
83560	7	73	1698	26359	31025	\N	51.030313	Саратовская область, Ровенский район, с. Чкаловское, ул. Школьная, д. 12 (здание СДК)		0101000020E61000005A7EE02A4F08474063D2DF4BE1834940
83567	7	73	1698	26657	30880	\N	50.651902	Саратовская область, Ровенский  район,  с. Циково, ул. Садовая, д. 18 (здание СДК)		0101000020E6100000C440D7BE801647403719558671534940
83559	7	73	1698	26273	30278	\N	51.022647999999997	Саратовская область, Ровенский район,  с. Тарлыковка, ул. Рабочая, д. 29 (здание СДК)		0101000020E61000005001309E410B4740EFA83121E6824940
83558	7	73	1698	26267	30276	\N	50.977930000000001	Саратовская область, Ровенский район,  с. Скатовка, ул. Кооперативная, д. 21 (здание СДК)		0101000020E61000004DD9E907750D47407EE36BCF2C7D4940
83556	7	73	1698	26144	\N	\N	50.896290999999998	Саратовская область,  Ровенский район, пос.Серебряный Бор, здание селького клуба	Россия, Саратовская область, Ровенский район, село Серебряный Бор	0101000020E6100000F2ED5D83BE0C47407D59DAA9B9724940
83551	7	73	1698	22603	30858	\N	50.772295	Саратовская область, Ровенский район,  р.п. Ровное, ул. Свердлова, д. 1 (Школа)		0101000020E6100000ECBFCE4D9B074740A2EE0390DA624940
83549	7	73	1698	22603	30858	\N	50.772295	Саратовская область, Ровенский  район, р.п. Ровное, ул. Свердлова, д. 1 (Школа)		0101000020E6100000ECBFCE4D9B074740A2EE0390DA624940
83550	7	73	1698	22603	67129	\N	50.774363089001397	"""Саратовская область, Ровенский  район, р.п. Ровное, ул.Калинина,63, здание РДК"	Россия, Саратовская область, Ровенский район, поселок Ровное	0101000020E610000004711E4E60064740C11DA8531E634940
83557	7	73	1698	26194	30699	\N	50.929774999999999	Саратовская область,  Ровенский район, с. Привольное, ул. Советская, д. 16 (здание СДК)		0101000020E610000025B1A4DC7D0A4740B7D100DE02774940
83562	7	73	1698	26457	30285	\N	51.090131999999997	Саратовская область, Ровенский й район,  с. Приволжское, ул. Советская, д. 62 (здание СДК)		0101000020E6100000A01518B2BAF946405A290472898B4940
83568	7	73	1698	26749	30286	\N	50.574745	Саратовская область, Ровенский  район, с. Первомайское, ул. Центральная, д. 14 (здание СДК)		0101000020E61000007497C459111B47400F45813E91494940
83554	7	73	1698	26070	31093	\N	50.794584	Саратовская область, Ровенский  район,  с. Новопривольное, ул. Волжская, д. 17 (здание СДК)		0101000020E610000021205F42050B474062F6B2EDB4654940
83563	7	73	1698	26508	31026	\N	50.823225999999998	Саратовская область,  Ровенский район, с. Новокаменка, ул. Советская, д. 12 (здание СДК)		0101000020E6100000946A9F8EC7344740C39B35785F694940
83565	7	73	1698	26570	30489	\N	50.637576000000003	Саратовская область,  Луговское муниципальное образование, с. Луговское, ул. Ленина, д. 24 (здание СДК)		0101000020E6100000A0FA07910C3D4740755B22179C514940
83553	7	73	1698	26028	31329	\N	50.697538999999999	Саратовская область, Ровенский район, п. Лиманный, ул. Центральная, д. 25 (Школа)		0101000020E6100000287FF78E1A0947409F573CF548594940
83564	7	73	1698	26561	31333	\N	50.865518000000002	Саратовская область, Ровенский район, с. Кривояр, ул. Советская, д. 7 (здание Администрации МО )		0101000020E6100000AB5E7EA7C93E4740B70C384BC96E4940
83555	7	73	1698	26141	31179	\N	50.849080000000001	Саратовская область, Ровенский район, с. Кочетное, ул. Центральная, д. 25 (здание СДК)		0101000020E6100000C784984BAA10474006D847A7AE6C4940
83566	7	73	1698	26658	30705	\N	50.651279000000002	Саратовская область, Ровенский район, п. Владимирский, ул. Волгоградская, д. 12 (здание СДК)		0101000020E61000001AF8510DFB2147402AC93A1C5D534940
83552	7	73	1698	53244	31632	\N	50.764891671608297	Саратовская область, Ровенский район,  с. Береговое, ул. Волжская, д. 1 (здание СДК)		0101000020E6100000B875374F750847406C7C26FBE7614940
83540	7	73	1233	25451	30260	\N	51.841313999999997	Саратовская область, Пугачевский район, поселок Чапаевский, ул.Школьная, д.10-б (Дом культуры)		0101000020E61000005646239F579248405ED5592DB0EB4940
83530	7	73	1233	24953	31426	\N	52.056793999999996	Саратовская область, Пугачевский район,село Успенка, ул. Набережная, д.1 (здание Администрации)		0101000020E6100000F0BF95ECD8704840F44D9A0645074A40
83529	7	73	1233	24920	31313	\N	52.044294000000001	Саратовская область, Пугачевский район, поселок Тургеневский, ул.Молодежная, д.33 (Школа)		0101000020E6100000469737876B5B48405BB4006DAB054A40
83538	7	73	1233	25353	31010	\N	52.056229000000002	Саратовская область, Пугачевский район,село Старая Порубежка, ул.Лободина, д. 21-а ( СОШ )		0101000020E6100000A7CAF78C449648401C0B0A8332074A40
83527	7	73	1233	24826	30975	\N	52.078341999999999	Саратовская область, Пугачевский район,поселок Солянский, ул.Школьная, д.1(СОШ)		0101000020E6100000DB34B6D7823648409DF3531C070A4A40
83524	7	73	1233	24686	31445	\N	52.232438000000002	Саратовская область, Пугачевский район, село Селезниха, ул.Чапаева, д.17 (Дом культуры)		0101000020E6100000C39B35785F554840802C4487C01D4A40
83541	7	73	1233	25460	31176	\N	51.95852	Саратовская область, Пугачевский район, село Рахмановка, ул. Молодежная, д. 1/2 (Школа)		0101000020E61000002BD9B11188BD4840ED478AC8B0FA4940
83511	7	73	1233	24039	30451	\N	52.034022999999998	Саратовская область, Пугачевский район,поселок Пугачевский, ул.Комарова, д.14-а (дом культуры)		0101000020E6100000003CA242756B4840E9279CDD5A044A40
83519	7	73	1233	53132	30564	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Садовая, д.72 (СОШ № 5)		0101000020E6100000868F8829916448405D8AABCABE014A40
83520	7	73	1233	53132	30474	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.Набережная, д.21 (ИП Притугин)		0101000020E6100000868F8829916448405D8AABCABE014A40
83506	7	73	1233	53132	30168	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул.М.Горького, д.134, МАУ ФОК Олимп (столовая Виктория)		0101000020E6100000868F8829916448405D8AABCABE014A40
83522	7	73	1233	53132	30273	\N	52.013635000000001	Саратовская область, Пугачевский район, город Пугачев, ул. Камышинский переулок, д.9 (ФБУ ИК-17 )		0101000020E6100000868F8829916448405D8AABCABE014A40
83496	7	73	1233	53132	31305	\N	52.028141207259502	Саратовская область, Пугачевский район, город Пугачев, ул. Ермощенко, д.179/2 (ТСЖ Сокол)	Россия, Саратовская область, Пугачев городской округ	0101000020E6100000B62FA017EE6248409F56D11F9A034A40
80672	7	72	123	48748	48370	\N	52.228113	с.Благодатовка, ул.Набережная, д.20		0101000020E6100000C4B29943523949406F6589CE321D4A40
83531	7	73	1233	25006	30923	\N	52.059103	Саратовская область, Пугачевский район, село Преображенка, ул.Советская, д. 99 (Дом культуры)		0101000020E61000008CDB68006F774840390CE6AF90074A40
83543	7	73	1233	25565	30477	\N	52.219259000000001	Саратовская область, пугачевский район, поселок Новопавловка, ул. Комплексная, д. 22 ( Школа)		0101000020E61000001D03B2D7BB4B4840452DCDAD101C4A40
83544	7	73	1233	25650	30480	\N	51.756855000000002	Саратовская область, Пугачевский район, село Новая Порубежка, ул. Советская, д.17 (Школа)		0101000020E6100000E675C4211BD648403468E89FE0E04940
83525	7	73	1233	24741	30994	\N	52.214810999999997	Саратовская область, Пугачевский район, село Надеждинка, ул.Ленина, д.13 (Дом культуры)		0101000020E610000097AAB4C53556484018E945ED7E1B4A40
83532	7	73	1233	25078	30997	\N	52.057879999999997	Саратовская область, Пугачевский район, село Малая Таволожка, ул.Кооперативная, д.19/1 (Клуб)		0101000020E610000047E867EA757F4840D68BA19C68074A40
83523	7	73	1233	24641	31330	\N	52.345551999999998	Саратовская область, Пугачевский район, село Мавринка, ул.Фрунзе, д.43 (школа)		0101000020E6100000511553E9275C4840A088450C3B2C4A40
83545	7	73	1233	25655	31433	\N	51.750973999999999	Саратовская область, Пугачевский район, село Любицкое, ул. Советская, д. 49-а (Школа)		0101000020E6100000D50627A25FA94840BA1281EA1FE04940
83528	7	73	1233	24909	31293	\N	52.116207000000003	Саратовская область, Пугачевский район, село Красная Речка, ул.Кутякова, д.74/2 (Дом культуры)		0101000020E61000007C2B1213D44C48407C48F8DEDF0E4A40
84138	7	73	1233	22567	30710	\N	51.673226	Саратовская область, Пугачевский район, село Клинцовка, ул.Красноармейская, д.27 (Дом культуры)		0101000020E6100000A9893E1F65984840906802452CD64940
83542	7	73	1233	25508	31132	\N	51.801633000000002	Саратовская область, Пугачевский район, село Карловка, ул. Советская, д. 10-б (Дом культуры)		0101000020E610000014E97E4E41C248407B32FFE89BE64940
83535	7	73	1233	25170	31428	\N	51.941501000000002	Саратовская область, Пугачевский район, село Каменка, ул.Советская, д. 6 ( Школа)		0101000020E61000006B0F7BA1805748405E13D21A83F84940
83539	7	73	1233	25358	31429	\N	52.096014136396597	Саратовская область, Пугачевский район, село Камелик, ул. Школьная, д.1 (Школа)		0101000020E61000003CD9CD8C7EB44840A4FACE2F4A0C4A40
83537	7	73	1233	25268	30846	\N	52.046498999999997	Саратовская область, Пугачевский район, поселок Заречный, ул. Заречная, д.1 Клуб ГАУ Центр реабилитации Пугачевский		0101000020E61000006D718DCF64754840FA25E2ADF3054A40
83534	7	73	1233	25158	30481	\N	51.923276000000001	Саратовская область, Пугачевский район, поселок Заволжский, ул.Мира, д. 37 (здание Администрации)		0101000020E6100000C47762D68B414840429770E82DF64940
83548	7	73	1233	25836	30686	\N	51.602516999999999	Саратовская область, Пугачевский район, село Жестянка, ул.Советская, д.45 (Дом культуры)		0101000020E6100000BC033C69E1B248405B24ED461FCD4940
83536	7	73	1233	25208	30842	\N	51.977601999999997	Саратовская область, Пугачевский район, село Давыдовка, ул.Чапаевская, д.85 (Дом культуры)		0101000020E6100000B9A7AB3B166F48408940F50F22FD4940
83533	7	73	1233	25082	30565	\N	52.101134000000002	Саратовская область, Пугачевский район, село Большая Таволожка, ул. Пугачевская, д.24 (Дом культуры)		0101000020E610000011A8FE4124874840C0417BF5F10C4A40
83278	7	73	1233	12646	30639	\N	51.925964	Саратовская область, Пугачевский район, село Березово, ул.Советская, д.72 (Школа)		0101000020E61000003E95D39E923B4840FDA204FD85F64940
83526	7	73	1233	20765	30336	\N	52.084750999999997	Саратовская область, Пугачевский район,поселок Бажановский, ул. Гагарина, д.2 (школа) филиал МОУ СОШ п.Солянский		0101000020E6100000AD6D8AC7452B4840D2A6EA1ED90A4A40
83518	7	73	7265	53207	31328	\N	52.0077133113804	Саратовская область, Пугачевский район, город Пугачев, ул.Горького, д.21 (ФГОУ СПО Пугачевский ГМТ)		0101000020E6100000672783A3E4674840856055BDFC004A40
83512	7	73	7265	53164	30675	\N	52.020318020523298	Саратовская область, Пугачевский район, город Пугачев, ул.Ермощенко, д.4 (ООШ № 4)		0101000020E61000005A0EF450DB6A484094C2BCC799024A40
83494	7	73	387	53224	31521	\N	50.542283422422102	Саратовская область, Питерский  район,  пос. Ясновидовка, ул. Степная, д. 2 (СДК пос. Ясновидовка)	Россия, Саратовская область, Питерский район, село Ясновидка	0101000020E6100000DA8F1491618D4740A016838769454940
83488	7	73	387	52032	30652	\N	50.778593999999998	Саратовская область, Питерский район, пос. Трудовик пос. Верный, адрес помещения для голосования: пос. Трудовик (СОШ пос. Трудовик), ул Ленина,36 Здание администрации МО		0101000020E6100000D272A087DADA4740506EDBF7A8634940
83492	7	73	387	2218	30383	\N	50.444251999999999	Саратовская область, Питерский район, пос. Руновский, Здание МОУ Начальная образовательная школа п. Руновский ул.Московская, 3/2		0101000020E610000029232E008DA647405F97E13FDD384940
83495	7	73	387	53160	30641	\N	50.567637239335802	Саратовская область, Питерский  район,  с. Агафоновка, х. Решетников, адрес помещения для голосования: ул. Колхозная, д. 2 д.35  ( СОШ с. Агафоновка), ул.Советская, д.71 (Администрация МО)	Россия, Саратовская область, Питерский район, село Решетников	0101000020E6100000A1F831E6AEB94740F17F4754A8484940
83491	7	73	387	21917	30442	\N	50.471245000000003	Саратовская область, Питерский район,  пос. Приозерный, Здание МОУ Начальная образовательная школа ул.Колхозная		0101000020E61000001B67D311C0C14740A7B393C1513C4940
83485	7	73	387	22821	30629	\N	50.822240999999998	Саратовская область, Питерский  район, пос. Привольный, ул. Советская, д. 12 (ФАП)		0101000020E61000009545611745C5474015376E313F694940
83499	7	73	387	1992	30971	\N	50.615713999999997	Саратовская область, Питерский район, пос. станция Питерка, Здание МДОУ Детский сад Сказка ст. Питерка ул. Школьная, 21		0101000020E610000044317903CCB647403CD862B7CF4E4940
80580	7	72	664	46995	48476	\N	52.752211000000003	пос.Дальний, ул.Школьная 15, Здание СДК		0101000020E61000005F0CE544BBC049408258367348604A40
83478	7	73	387	1992	31251	\N	50.615713999999997	Саратовская область, Питерский район,  с.Питерка, ул. Молодежная, д.12 (Здание  ДЮСШ с. Питерка)		0101000020E610000044317903CCB647403CD862B7CF4E4940
83477	7	73	387	49416	31129	\N	50.674425999999997	Саратовская область, Питерский район, с. Питерка, адрес помещения для голосования: С. Питерка, ул.Ленина, д. 102, Районный Дом культуры, пер.Садовый, д.15 (Администрация Питерского МО)		0101000020E6100000C1AA7AF99DB847403AC9569753564940
83497	7	73	387	23370	31256	\N	50.568703999999997	Саратовская область, Питерский район,  пос. Первопитерский, адрес помещения для голосования : СДК пос. Первопитерский), ул.Центральная, д21, кв.2а (НОШ п. Первопитерский)		0101000020E61000008C0FB3976DA747405C8DEC4ACB484940
83487	7	73	387	22914	30990	\N	50.951734000000002	Саратовская область, Питерский район,  пос. Опытная станция, Здание МОУ Начальная школа-детский сад п. Опытная станция ул.Крекера,1		0101000020E61000001407D0EFFBD54740E23E726BD2794940
83484	7	73	387	21834	30627	\N	50.837591000000003	Саратовская область, Питерский  район,  с. Новотулка, ул.Советская, д.50 (МОУ СОШ с. Новотулка)		0101000020E610000016DC0F7860C847404436902E366B4940
83482	7	73	387	2049	30802	\N	50.774174000000002	Саратовская область, Питерский район, пос. Новореченский, адрес помещения для голосования: ул. Ленина, д. 31 Набережная, 25 (здание СДК), ул.Ленина, д. 26 (Администрация МО)		0101000020E6100000C7BC8E3864B14740EEB4352218634940
83490	7	73	387	23086	30437	\N	50.426459999999999	Саратовская область, Питерский  район, пос. Нива, адрес помещения для голосования: Нивский СДК, ул.Комсомольская, д.2 (Администрация МО)		0101000020E6100000AC8BDB6800B14740AD86C43D96364940
83498	7	73	387	23405	31421	\N	50.614400000000003	Саратовская область, Питерский район,  пос. Нариманово, ул. Центральная, д. 1  д.2 (СОШ пос. Нариманово)		0101000020E6100000D0F1D1E28CBB4740CA54C1A8A44E4940
83480	7	73	387	22608	30962	\N	50.740555000000001	Саратовская область, Питерский район, с. Моршанка, адрес помещения для голосования: ул. Революционная, д.8 (здание СДК), ул. Революционная, д.7 (Администрация МО)		0101000020E610000086376BF0BEB84740D4F19881CA5E4940
83479	7	73	387	21716	30693	\N	50.751976999999997	Саратовская область, Питерский район, с. Мироновка, адрес помещения для голосования: ул. Садовая, д. 6, (детский сад Колосок), ул.Советская, д.36 (Администрация МО)		0101000020E610000045F295404ABA47400E2C47C840604940
83489	7	73	387	2161	30219	\N	50.484090999999999	Саратовская область, Питерский  район, с. Малый Узень, адрес помещения для голосования: ул. Гагарина, д. 3 ул.Ленина, 1 (Малоузенский СДК), ул.Ленина, д.5 (Администрация МО)		0101000020E6100000D105F52D73D04740DBA4A2B1F63D4940
83483	7	73	387	21775	31331	\N	50.862920000000003	Саратовская область, Питерский район,  с. Козловка, адрес помещения для голосования: ул. Молодежная, д. 31 (Здание МОУ СОШ с. Козловка), ул.Советская, д.30 (Администрация МО)		0101000020E6100000B95510035DC947403C889D29746E4940
83481	7	73	387	21729	30632	\N	50.784357999999997	Саратовская область, Питерский район,  пос. Зеленый Луг, ул. Комсомольская, д.9 (Детский сад Вишенка)		0101000020E61000007A6CCB80B3B24740902DCBD765644940
83493	7	73	387	23188	30981	\N	50.546495	Саратовская область, Питерский  район,  с. Запрудное, адрес помещения для голосования: ул. Советская, д. 6 (СОШ с. Запрудное), ул. Кооперативная, д. 10/2 (Администрация МО)		0101000020E61000002FDE8FDB2F954740B936548CF3454940
83486	7	73	387	22859	31297	\N	50.956681000000003	Саратовская область, Питерский район,  с. Алексашкино, адрес помещения для голосования: пер. Школьный, д. 5 (СОШ с. Алексашкино), ул. Ленина, д. 23А (Администрация МО)		0101000020E61000001D7233DC80DB474030DAE385747A4940
83393	7	73	387	18167	31211	\N	50.411228000000001	Саратовская область, Новоузенский район, село Августовка, ул.Центральная, д.19 (начальная школа)		0101000020E610000010B3976DA7D5474089997D1EA3344940
83458	7	73	366	21619	30163	\N	52.194378999999998	Саратовская область, Петровский район, п. Тракторный, ул. Центральная, д. 5/2 (административное здание), ул. Центральная, д. 36 (МОУ ООШ)		0101000020E6100000CDCEA2772A7E4640BC033C69E1184A40
83473	7	73	366	22304	31390	\N	52.432577999999999	Саратовская область, Петровский район, с. Татарская Пакаевка, ул. Школьная, д. 2 (МОУ ООШ)		0101000020E61000009737876BB5DD46400B7C45B75E374A40
83468	7	73	366	22064	30782	\N	52.192905000000003	Саратовская область, Петровский район, с. Таволожка, ул. Молодежная, д. 10 (МОУ СОШ)		0101000020E610000002D6AA5D13D84640111E6D1CB1184A40
83456	7	73	366	21483	30944	\N	52.098855	Саратовская область, Петровский  район, п. Студеный, пер. Школьный, д. 2 (МОУ ООШ)		0101000020E6100000A1866F61DD8A4640E605D847A70C4A40
83462	7	73	366	21781	31266	\N	52.266716000000002	Саратовская область, Петровский район, с. Сосновоборское, ул. Садовая, д. 4а (административное здание), ул. Школьная, д. 8 (МОУ ООШ)		0101000020E6100000A0DE8C9AAF984640F4A8F8BF23224A40
83470	7	73	366	22200	30783	\N	52.324657999999999	Саратовская область, Петровский  район, с. Синенькие, ул. Центральная, д. 31 (МОУ ООШ)		0101000020E6100000A03715A930CA46404031B2648E294A40
83475	7	73	366	22390	30977	\N	52.440967000000001	Саратовская область, Петровский район, с. Савкино, ул. Мира, д. 20 а (МОУ ООШ)		0101000020E6100000ACFE08C380D74640C0CE4D9B71384A40
83465	7	73	366	21923	30594	\N	52.279693000000002	Саратовская область, Петровский район, пос. Пригородный, ул. Светличная, д. 3 (МОУ СОШ)		0101000020E61000000F4240BE84B64640C7F5EFFACC234A40
83464	7	73	366	21921	31268	\N	52.048914000000003	Саратовская область, Петровский район, с. Оркино, ул. Кооперативная, д. 36 (МОУ ООШ)		0101000020E6100000793BC269C1C9464085285FD042064A40
72820	7	71	\N	16298	51650	\N	56.759227000000003	г. Чайковский, ул. К.Мракса, 30		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
83440	7	73	366	20750	31156	\N	52.011141000000002	Саратовская область, Петровский район, с. Озерки, ул. Политотдельская, д. 72 а (МОУ СОШ)		0101000020E610000024D40CA9A2BE464087527B116D014A40
83472	7	73	366	22294	31116	\N	52.379154	Саратовская область, Петровский район, с. Ножкино, ул. Советская, д. 36, ул. Советская, д. 2 (МОУ начальная школа-детсад)		0101000020E6100000696FF085C9CE4640E412471E88304A40
83463	7	73	366	21837	30586	\N	52.177444999999999	Саратовская область, Петровский район, с. Новозахаркино, ул. 70 лет Октября, д. 70 (МОУ СОШ)		0101000020E61000004B3D0B4279A946405BEB8B84B6164A40
83474	7	73	366	22341	30392	\N	52.398648999999999	Саратовская область, Петровский район, с. Новодубровка, ул. Молодежная д. 26 (административное здание), ул. Молодежная, д. 23 (МОУ ООШ)		0101000020E6100000BC1FB75F3EBF4640A3CA30EE06334A40
83455	7	73	366	3835	30637	\N	52.132728	Саратовская область, Петровский район, с. Новая Усть-уза, ул. Центральная, д.38 (МОУ начальная школа-детсад)		0101000020E6100000315D88D51F974640BAA1293BFD104A40
83467	7	73	366	22023	31113	\N	52.218750999999997	Саратовская область, Петровский район, п. Мирный, ул. Школьная, д. 2 (МОУ ООШ)		0101000020E6100000705F07CE19B54640D07B6308001C4A40
83469	7	73	366	1873	30560	\N	52.147275999999998	Саратовская область, Петровский район, с. Колки, ул. Центральная, д. 2, сельский клуб,  (административное здание)		0101000020E61000001C7BF65CA6C046402BBEA1F0D9124A40
83457	7	73	366	21538	31262	\N	52.185716999999997	Саратовская область, Петровский  район, с. Кожевино, ул. Рабочая, д. 23 (административное здание), ул. Демина, д. 69 (МОУ СОШ)		0101000020E6100000C93D5DDDB1944640D6A71C93C5174A40
83459	7	73	366	21622	30164	\N	52.354723	Саратовская область, Петровский  район, с. Грачевка, ул. Мира, д. 18 а (административное здание), ул. Новоселов, д. 1 а (МОУ СОШ)		0101000020E610000082E15CC30CA14640CB113290672D4A40
83471	7	73	366	22204	30184	\N	52.280856	Саратовская область, Петровский район, с. Вязьмино, ул. Центральная, д. 45 (административное здание), ул. Центральная, д. 105 (МОУ ООШ)		0101000020E6100000E789E76C01D546405471E316F3234A40
83466	7	73	366	22012	31112	\N	52.276828000000002	Саратовская область, Петровский район, с. 1-я Березовка, ул. Центральная, д. 26 (административное здание), ул. Центральная, д. 27 (МОУ СОШ)		0101000020E61000009415C3D501AA4640FD4E93196F234A40
83454	7	73	366	21437	30770	\N	52.092762999999998	Саратовская область, Петровский район, с. Березовка, ул. Советская, д. 175 (административное здание), ул. Советская, д. 90 (МОУ ООШ)		0101000020E6100000512D228AC98F4640B1A371A8DF0B4A40
83461	7	73	366	21732	31209	\N	52.336556000000002	Саратовская область, Петровский район, с. Асметовка, ул. Ленинская, д. 81 (МОУ ООШ)		0101000020E610000054FF209221774640E4A25A44142B4A40
83460	7	73	366	21714	30949	\N	52.300510000000003	Саратовская область, Петровский район, д. Абодим, ул. Молодежная, д. 12 (МОУ ООШ)		0101000020E6100000A33A1DC87A9A46407C0F971C77264A40
83429	7	73	678	20050	31496	\N	51.673572999999998	Саратовская область, Перелюбский  район, поселок Целинный, пер.Школьный, д.11 (здание школы)		0101000020E61000001B9FC9FE79164940FB3BDBA337D64940
83428	7	73	678	20045	31357	\N	51.661724999999997	Саратовская область, Перелюбский  район, село Холманка, ул.Школьная, д.5 (здание школы)		0101000020E61000002FFCE07CEA36494009F9A067B3D44940
83431	7	73	678	20175	31479	\N	51.672662000000003	Саратовская область, Перелюбский  район, село Харитоновка, ул.Степная, д.21 (здание школы)		0101000020E6100000450F7C0C561C494088A1D5C919D64940
83442	7	73	678	20850	30757	\N	52.106521999999998	Саратовская область, Перелюбский  район, поселок Тепловский, ул.Школьная, д.8а (здание школы)		0101000020E610000019FED30D14EC4840FA264D83A20D4A40
83426	7	73	678	53221	31510	\N	51.731868965406299	Саратовская область, Перелюбский  район, хуторТараховка, ул.Степная, д.4 (здание школы)	Россия, Саратовская область, Перелюбский район, село Тараховка	0101000020E6100000931E8656275F494066FA25E2ADDD4940
83435	7	73	678	19886	30751	\N	51.979477000000003	Саратовская область, Перелюбский  район, село Смородинка, ул.Советская, д.44 ул.Центральная,1 (здание школы) т.3-56-45		0101000020E6100000E1B4E0455FF74840941799805FFD4940
83437	7	73	678	20547	31075	\N	52.064667999999998	Саратовская область, Перелюбский  район, поселок Пригорки, ул.Школьная, д.6а (здание школы)		0101000020E610000019C5724BAB0B4940828C800A47084A40
83423	7	73	678	19726	30541	\N	51.862214999999999	Саратовская область, Перелюбский  район, село Перелюб, ул.Чкаловская, д.59 (здание школы)		0101000020E610000096AFCBF09F2C4940718FA50F5DEE4940
83422	7	73	678	19726	31352	\N	51.862214999999999	Саратовская область, Перелюбский  район, село Перелюб, ул.Ленина, д.108 (Районный дом культуры)		0101000020E610000096AFCBF09F2C4940718FA50F5DEE4940
83434	7	73	678	20426	30746	\N	51.893734000000002	Саратовская область, Перелюбский район, поселок Октябрьский, ул.Советская, д.36 (здание школы)		0101000020E61000001EC4CE143A09494061A92EE065F24940
83436	7	73	678	4706	30426	\N	51.974761999999998	Саратовская область, Перелюбский  район, станция Новый Перелюб, ул.Вокзальная, д.10 (здание пост ЭЦ) Ново-Перелюбский изб.участок, с.Смородинка, ул.Центральная, 1 здание школы, т.3-56-45		0101000020E610000058569A9482FA484018B14F00C5FC4940
83430	7	73	678	20163	31064	\N	51.665914999999998	Саратовская область, Перелюбский  район, село Нижняя Покровка, ул.Школьная, д.7 (здание школы)		0101000020E6100000B16B7BBB250F49403A75E5B33CD54940
83425	7	73	678	19835	31065	\N	51.776218999999998	Саратовская область, Перелюбский  район, село Натальин Яр, ул.Западная, д.2 (здание школы)		0101000020E6100000E6B166649049494054C4E9245BE34940
83439	7	73	678	20659	31150	\N	51.947823999999997	Саратовская область, Перелюбский  район, поселок Молодежный, ул.Ленина, д.17 (Дом культуры)		0101000020E61000002827DA5548C54840942EFD4B52F94940
83427	7	73	678	19945	30913	\N	51.694747	Саратовская область, Перелюбский  район, село Кучумбетово, ул.Интернациональная, д.55 (сельский Дом культуры)		0101000020E610000013D6C6D8092949403FFF3D78EDD84940
83433	7	73	678	20304	30917	\N	51.681401999999999	Саратовская область, Перелюбский  район, деревня Кузябаево, ул.Озерная, д.17 (сельский клуб)		0101000020E61000006666666666F84840E9B6442E38D74940
83432	7	73	678	20235	30550	\N	51.709024999999997	Саратовская область, Перелюбский  район, село Калинин, ул.Рабочая, д.3а (здание школы)		0101000020E6100000E6B1666490E74840F085C954C1DA4940
83424	7	73	678	19828	31060	\N	51.916609999999999	Саратовская область, Перелюбский  район, село Иваниха, ул.Советская, д.3 (Дом культуры)		0101000020E61000002C9B3924B5424940E197FA7953F54940
83438	7	73	678	20594	30531	\N	51.996581999999997	Саратовская область, Перелюбский  район, село Грачев -Куст, ул.Перетрухина, д.67б (здание администрации)		0101000020E61000002FA3586E69E9484021E4BCFF8FFF4940
83441	7	73	678	20756	30845	\N	51.983604	Саратовская область, Перелюбский  район, село Большая Тарасовка, ул.Школьная, д.8 (здание школы)		0101000020E61000005C751DAA29C148407E1B62BCE6FD4940
83408	7	73	432	18997	31055	\N	51.175969000000002	Саратовская область, Озинский район, с.Старые Озинки, ул. Набережная, д.51 (администрация МО)		0101000020E6100000000341800CD748400F0EF62686964940
83420	7	73	432	19574	30478	\N	51.491186999999996	Саратовская область, Озинский район, с.Солянка, Адрес помещения для голосования: ул. Терешковой, д.37 (МОУ Основная школа), Адрес УИК: ул. Гагарина, д.35 (административное здание)		0101000020E6100000831953B0C60B4940349C3237DFBE4940
83399	7	73	432	18477	\N	\N	51.167368000000003	Саратовская область, Озинский район, п.Сланцевый Рудник, д.8 (сельский Дом культуры), Адрес УИК:, д.9 (администрация МО)		0101000020E6100000197442E8A0D14840CF328B506C954940
83414	7	73	432	2456	30934	\N	51.320388000000001	Саратовская область, Озинский район, п.Синегорский, ул. Рабочая, д.12 (МОУ Средняя школа)		0101000020E6100000DAE1AFC91AF54840F303577902A94940
83413	7	73	432	19217	31059	\N	51.423315000000002	Саратовская область, Озинский район, с.Пигари, ул. Октябрьская, д.5 (сельский Дом культуры)		0101000020E61000000536E7E099D848400074982F2FB64940
83416	7	73	432	19407	30323	\N	51.629657000000002	Саратовская область, Озинский район, п.Первоцелинный, Адрес помещения для голосования: ул. Чапаевская, д.6 (сельский Дом культуры), Адрес УИК: ул. Набережная, д.16 (администрация МО)		0101000020E6100000A3E9EC6470E848404759BF9998D04940
83404	7	73	432	4104	31052	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, ул. Советская, д.49		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83396	7	73	432	4104	30300	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. Молодежная, д.4 (МОУ ДОД ДЮСШ), Адрес УИК: ул. Ленина, д.14 (администрация района)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83398	7	73	432	4104	30519	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. Ленина, д.22 (Дом культуры), Адрес УИК: ул. Ленина, д.14 (администрация района)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83397	7	73	432	4104	31046	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. Комарова, д.23 (Начальная школа №3), Адрес УИК: ул. Ленина, д.14 (администрация района)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83401	7	73	432	4104	30522	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. Кирова, д.4 (ГУ Центр занятости населения), Адрес УИК: ул. Ленина, д.14 (администрация района)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83405	7	73	432	4104	30307	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. Вольская, д.2 (МОУ  Начальная школа - детский сад), Адрес УИК: ул. Ленина, д.14 (администрация района)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83400	7	73	432	4104	30516	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. Ветеранов, д.2 (ГУ Комплексный центр социального обслуживания населения), Адрес УИК: ул. Ленина, д.14 (администрация района)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83406	7	73	432	4104	31087	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. Александрова, д.17 (клуб Прогресс), Адрес УИК: ул. Ленина, д.20 (Управление культуры и кино)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83403	7	73	432	4104	30192	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. 8 Марта, д.9 (МОУ Основная общеобразовательная школа), Адрес УИК: ул. Советская, д.49 (администрация МО)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83402	7	73	432	4104	30192	\N	51.199849	Саратовская область, Озинский район, р.п.Озинки, Адрес помещения для голосования: ул. 8 Марта, д.9 (МОУ Основная общеобразовательная школа), Адрес УИК: ул. Ленина, д.14 (администрация района)		0101000020E6100000F7EAE3A1EFDC4840B491EBA694994940
83417	7	73	432	19411	30325	\N	51.607422999999997	Саратовская область, Озинский район, с.Новочерниговка, Адрес помещения для голосования: площадь Революции, д.6 (сельский Дом культуры), Адрес УИК: ул. Советская, д.38а (административное здание)		0101000020E61000001DACFF7398FB48404AEB6F09C0CD4940
79765	7	72	\N	55034	77339	\N	53.084337189884401	город Новокуйбышевск, проспект Победы, 38	Россия	0101000020E61000005395B6B8C6F54840DF6B088ECB8A4A40
83421	7	73	432	4703	30935	\N	51.526060000000001	Саратовская область, Озинский район, п.Новозаволжский, Адрес помещения для голосования: ул. Школьная, д.9 (МОУ Средняя школа), Адрес УИК: ул. Школьная, д.10 (администрация МО)		0101000020E6100000637B2DE8BD254940ECDD1FEF55C34940
83407	7	73	432	9306	30529	\N	51.270488	Саратовская область, Озинский район, п.Непряхин, Адрес помещения для голосования: ул. Советская, д.30 (МОУ Основная общеобразовательная школа), Адрес УИК: ул. Советская, д.29 (администрация МО)		0101000020E61000005CE674594CE04840F0FACC599FA24940
83410	7	73	432	2353	30899	\N	51.167949999999998	Саратовская область, Озинский район, п.Модин, ул. Пионерская, д.9 (МОУ Средняя школа)		0101000020E61000008463963D09B448407DAEB6627F954940
83411	7	73	432	19111	30848	\N	51.382528000000001	Саратовская область, Озинский район, п.Липовский, Адрес помещения для голосования: ул. Школьная, д.1а (МОУ Средняя общеобразовательная школа), Адрес УИК: ул. Ленина, д.26 (администрация МО)		0101000020E6100000A35C1ABFF0C24840F3E670ADF6B04940
83409	7	73	432	18999	30729	\N	51.157015000000001	Саратовская область, Озинский район, п.Горный, ул. Школьная, д.8 (административное здание)		0101000020E61000004BB1A371A8E34840A0FD481119944940
83419	7	73	432	19517	30540	\N	51.421574	Саратовская область, Озинский район, п.Белоглинный, Адрес помещения для голосования: ул. Набережная, д.20/1 (сельский Дом культуры), Адрес УИК: ул. Комсомольская, д.3 (администрация МО)		0101000020E6100000A9DDAF027C094940056C0723F6B54940
83415	7	73	432	19319	31227	\N	51.409771999999997	Саратовская область, Озинский район, с.Балаши, Адрес помещения для голосования: ул. Советская, д.19 (сельский Дом культуры), Адрес УИК: ул. Советская, д.42 (администрация МО)		0101000020E61000007023658BA4F548408368AD6873B44940
83373	7	73	615	17168	30283	\N	50.675933000000001	Саратовская область, Новоузенский район, хутор Шукеев, ул.Зеленая, д.14 (начальная школа)		0101000020E6100000957D5704FF7B4840C2A4F8F884564940
83378	7	73	615	17455	31452	\N	50.613571	Саратовская область, Новоузенский район, хутор Чилижный, ул.Центральная, д.24 (начальная школа)		0101000020E6100000AED85F764F5A48401363997E894E4940
83394	7	73	615	18211	30831	\N	50.589564000000003	Саратовская область, Новоузенский район, поселок Чертанла, ул.Центральная, д.6 (школа) МОУ СОШ		0101000020E61000005FECBDF8A21D4840117349D5764B4940
83368	7	73	615	16969	30428	\N	50.168291000000004	Саратовская область, Новоузенский район, хутор Труба, ул.Клубная, д.7 (клуб)		0101000020E61000007311DF89590F4840079B3A8F8A154940
83370	7	73	615	17024	31410	\N	50.782025230014803	Саратовская область, Новоузенский район, село Таловка, ул.Радищева, д.26 (клуб)	Россия, Саратовская область, Новоузенский район, село Таловка	0101000020E610000000016BD5AE174840C3D32B6519644940
83392	7	73	615	18162	30722	\N	50.705314999999999	Саратовская область, Новоузенский район, поселок Степной, ул.Центральная, д.18 (начальная школ)		0101000020E61000003F8C101E6D5648406A300DC3475A4940
83379	7	73	615	18162	30288	\N	50.702259437582399	Саратовская область, Новоузенский район, хутор Степной, ул.Новостепная, д.24  д.26 (начальная школа)	Россия, Саратовская область, Новоузенский район, село Степной	0101000020E6100000B3EA73B5155748402C29779FE3594940
83359	7	73	615	53177	30864	\N	50.461621130477603	Саратовская область, Новоузенский район, город Новоузенск, поселок Солянка, ул.Дружбы, д.1 (начальная школа)	Россия, Саратовская область, Новоузенский район, село Солянка	0101000020E61000000C5A48C0E81E4840CB129D65163B4940
83389	7	73	615	17988	31341	\N	50.465826999999997	Саратовская область, Новоузенский район, поселок Радищево, ул.Радищева, д.19 (ДК)		0101000020E610000081971936CA084840014C1938A03B4940
83388	7	73	615	17921	31340	\N	50.526049999999998	Саратовская область, Новоузенский район, село Пограничное, ул.Копылова, д.38б (школа)		0101000020E6100000AD6D8AC745514840C8073D9B55434940
83386	7	73	615	17860	31201	\N	50.256453999999998	Саратовская область, Новоузенский район, село Петропавловка, пл.Революции, д.9 (ДК)		0101000020E610000018B5FB5580F54740D576137CD3204940
83372	7	73	615	17162	30282	\N	50.755173999999997	Саратовская область, Новоузенский район, хутор Песчанный Мар, ул.Школьная, д.4 (начальная школа)		0101000020E61000003FC4060B275948400E65A88AA9604940
83365	7	73	615	16800	31016	\N	50.383986999999998	Саратовская область, Новоузенский район, поселок Первомайский, ул.Советская, д.1 (начальная школа)		0101000020E610000027F911BF62294840698B6B7C26314940
83380	7	73	615	16800	31534	\N	50.382430932587198	Саратовская область, Новоузенский район, хутор Первомайский, ул.Молодежная, д.12 (детский сад)	Россия, Саратовская область, Новоузенский район, село Первомайский	0101000020E6100000E44D7E8B4E2A484000FDBE7FF3304940
83371	7	73	615	17081	30486	\N	50.682143000000003	Саратовская область, Новоузенский район, поселок Основной, ул.Советская, д.23 (ДК)		0101000020E61000006CD097DEFE60484001193A7650574940
83384	7	73	615	17770	31198	\N	50.720520999999998	Саратовская область, Новоузенский район, село Олоновка, ул.Первомайская, д.9 (ДК)		0101000020E6100000EECF4543C6334840658A39083A5C4940
83362	7	73	615	9228	31041	\N	50.452638	Саратовская область, Новоузенский район, город Новоузенск, пл.Льва Толстого, д.3 (автовокзал)		0101000020E610000068942EFD4B124840A376BF0AF0394940
83354	7	73	615	9228	31182	\N	50.452638	Саратовская область, Новоузенский район, город Новоузенск, ул.Хайкина, д.2а (клуб пристанционного поселка)		0101000020E610000068942EFD4B124840A376BF0AF0394940
83357	7	73	615	9228	30509	\N	50.452638	Саратовская область, Новоузенский район, город Новоузенск, ул.Трутнева, д.48 (ФГОУ НСХТ)		0101000020E610000068942EFD4B124840A376BF0AF0394940
83363	7	73	615	9228	31023	\N	50.427310953852	Саратовская область, Новоузенский район, город Новоузенск, поселок Узенский, ул.Степная, д.19 (начальная школа) ул.Молодежная,	Россия, Саратовская область, Новоузенский район, Новоузенск	0101000020E61000007651F4C0C71248404C1C7920B2364940
83360	7	73	615	9228	30482	\N	50.452638	Саратовская область, Новоузенский район, город Новоузенск, ул.Советская, д.7б (центральная библиотека)		0101000020E610000068942EFD4B124840A376BF0AF0394940
83356	7	73	615	9228	30483	\N	50.452638	Саратовская область, Новоузенский район, город Новоузенск, Микрорайон-2, д.4 (школа №1) МОУ СОШ №1		0101000020E610000068942EFD4B124840A376BF0AF0394940
83355	7	73	615	9228	30646	\N	50.452638	Саратовская область, Новоузенский район, город Новоузенск, ул.Зеленый Клин, д.1  ул.ГОУ ПУ-65 (ПЛ-65)		0101000020E610000068942EFD4B124840A376BF0AF0394940
83358	7	73	615	9228	31086	\N	50.452638	Саратовская область, Новоузенский район, город Новоузенск, ул.Елецкая, д.43 (школа №4) МОУ СОШ №4		0101000020E610000068942EFD4B124840A376BF0AF0394940
83367	7	73	615	16876	30813	\N	50.349426000000001	Саратовская область, Новоузенский район, поселок Мирный, ул.Трудовая, д.3 (начальная школа)		0101000020E61000003D62F4DC420F4840A12FBDFDB92C4940
83387	7	73	615	53242	31608	\N	50.177477278152303	Саратовская область, Новоузенский район, село Лохмотовка, ул.Московская, д.17/2 (ФАП) клуб	Россия, Саратовская область, Новоузенский район, село Лохматовка	0101000020E61000009AB2D30FEAFE47406765FB90B7164940
83366	7	73	615	16870	30271	\N	50.252825999999999	Саратовская область, Новоузенский район, поселок Ленинский, ул.Центральная, д.16 (начальная школа)		0101000020E6100000670E492D941648400CCA349A5C204940
83382	7	73	615	3891	31196	\N	50.721153999999999	Саратовская область, Новоузенский район, село Куриловка, пл.Революции, д.1а  (ДК), д.15 МУК СДК		0101000020E61000003B55BE672404484096B036C64E5C4940
83383	7	73	615	3891	30292	\N	50.721153999999999	Саратовская область, Новоузенский район, село Куриловка, ул.Молодежная, д.1 (филиал школы искусств)		0101000020E61000003B55BE672404484096B036C64E5C4940
83376	7	73	615	17314	31186	\N	50.587569000000002	Саратовская область, Новоузенский район, поселок Кубанка, ул.Молодежная, д.7 (начальная школа)		0101000020E61000001EA5129ED00148405C920376354B4940
83381	7	73	615	17577	31038	\N	50.696660000000001	Саратовская область, Новоузенский район, село Крепость Узень, пл.Космонавтов, д.17, (начальная школа)		0101000020E6100000D1950854FF0048403737A6272C594940
83385	7	73	615	3927	30716	\N	50.780757999999999	Саратовская область, Новоузенский район, село Киевка, ул.Центральная, д.37  д.9 (клуб)		0101000020E6100000F0DFBC38F1394840910BCEE0EF634940
83303	7	73	615	13773	30958	\N	50.530372999999997	Саратовская область, Новоузенский район, поселок Карев, ул.Рабочая, д.15 д.19 (начальаяй школа)		0101000020E6100000BAD7497D59DC474038D73043E3434940
83377	7	73	615	17379	30709	\N	50.656309999999998	Саратовская область, Новоузенский район, поселок Дюрский, ул.Почтовая, д.2 (ДК)		0101000020E6100000446B459BE3484840D50451F701544940
83374	7	73	615	17258	31334	\N	50.639439000000003	Саратовская область, Новоузенский район, село Дмитриевка, ул.Советская, д.25 (ДК)		0101000020E6100000CDE49B6D6EFC4740BB641C23D9514940
83390	7	73	615	18068	31207	\N	50.448008999999999	Саратовская область, Новоузенский район, хутор Дейков, ул.Рабочая, д.3 (начальная школа)		0101000020E61000006CB2463D44FB474026A8E15B58394940
83395	7	73	615	4040	30295	\N	50.525827	Саратовская область, Новоузенский район, поселок Ближний, ул.Новоузенская, д.69, кв.1 (начальная школа) Клуб		0101000020E61000007E8B4E965A174840492D944C4E434940
83369	7	73	615	16974	31442	\N	50.778292	Саратовская область, Новоузенский район, село Бессоновка, ул.Октябрьская, д.38 (школа)		0101000020E61000008E57207A52224840855E7F129F634940
83375	7	73	615	17265	30868	\N	50.600262999999998	Саратовская область, Новоузенский район, поселок Алексеевка, ул.Целинная, д.16а (начальная школа)		0101000020E610000096B377465BFF4740DAFF006BD54C4940
83364	7	73	615	16730	31015	\N	50.406714999999998	Саратовская область, Новоузенский район, поселок Алгайский, ул.Центральная, д.11 (ДК)		0101000020E6100000F38E53742411484075E5B33C0F344940
83336	7	73	462	2684	31257	\N	51.964779999999998	Саратовская область, Новобурасский район, село Чернышевка, Адрес помещения для голосования: ул.Чернышевского, д.103 (здание администрации с.Чернышевка), Адрус УИК: ул.Чернышевского, д.36Б (здание школы с.Чернышевка)		0101000020E6100000BABF7ADCB70A4740DDEA39E97DFB4940
83339	7	73	462	15504	30457	\N	52.068759999999997	Саратовская область, Новобурасский район, село Тепловка, ул.Советская, д.1 (здание школы с.Тепловка)		0101000020E6100000B0AD9FFEB3104740F0A2AF20CD084A40
83687	7	73	462	53143	\N	\N	51.820836018451899	Саратовская область, Саратовский район, ст. Тарханы, (МОУ Средняя обшеобразовательная школа ст. Тарханы)		0101000020E6100000E75432005419474092B06F2711E94940
83333	7	73	462	15200	31013	\N	51.870145000000001	Саратовская область, Новобурасский район, село Радищево, ул.Первомайская, д.18 (здание клуба с.Радищево)		0101000020E61000000B630B410E16474093E34EE960EF4940
94379	7	73	462	15299	31354	\N	52.129874999999998	Саратовская область, Новобурасский район, р.п.Новые Бурасы, ул. Советская, д.4 (здание школы №1)		0101000020E61000003D7FDAA84E094740B4C876BE9F104A40
83346	7	73	462	15299	30841	\N	52.129874999999998	Саратовская область, Новобурасский район, р.п.Новые Бурасы, ул. Гагарина, д. 52 (здание школы №2)		0101000020E61000003D7FDAA84E094740B4C876BE9F104A40
83344	7	73	462	15299	30255	\N	52.129874999999998	Саратовская область, Новобурасский район, р.п.Новые Бурасы, ул. Баумана, д. 29 (здание ДК р.п.Новые Бурасы)		0101000020E61000003D7FDAA84E094740B4C876BE9F104A40
83335	7	73	462	15299	30255	\N	52.129874999999998	Саратовская область, Новобурасский район, р.п. Новые Бурасы, ул. Баумана, д. 35 (здание библиотеки)		0101000020E61000003D7FDAA84E094740B4C876BE9F104A40
83337	7	73	462	15395	30796	\N	51.961433999999997	Саратовская область, Новобурасский район, село Новоалексеевка, ул.Центральная, д.85 д.84(здание школы с.Новоалексеевка)		0101000020E61000000CE6AF90B92C474098A1F14410FB4940
83341	7	73	462	15603	30215	\N	52.026741999999999	Саратовская область, Новобурасский район, село Марьино-Лашмино, Адрес помещения для голосования: ул.Колхозная, д.1 (здание администрации с.Марьино-Лашмино), Адрес УИК: ул. Колхозная, д.4(здание школы с.Марьино-Лашмино)		0101000020E6100000109370218FF64640FEB627486C034A40
83351	7	73	462	16071	30476	\N	52.288722999999997	Саратовская область, Новобурасский район, село Малые-Озерки, Адрес помещения для голосования: ул.Шарковых, д.49 (здание администрации с.Малые Озерки), Адрес УИК: ул.Шарковых, д.46 (здание школы с.Малые Озерки)		0101000020E6100000F8FE06EDD5EB46402F4D11E0F4244A40
83342	7	73	462	2807	30465	\N	52.132539999999999	Саратовская область, Новобурасский район, село Лох, Адрес помещения для голосования: ул.Молодежная, д.8 (здание администрации с.Лох), Адрес УИК: ул.Загороднева, д.42А,кор.1(здание школы с.Лох)		0101000020E610000035EB8CEF8BED4640B7B41A12F7104A40
83352	7	73	462	16114	30648	\N	52.394016999999998	Саратовская область, Новобурасский район, с.Леляевка, Адрес помещения для голосования: ул.Юбилейная, д.41 (здание администрации с.Леляевка), Адрес УИК: ул.Юбилейная, д.81 (здание школы с.Леляевка)		0101000020E6100000021077F52AF24640B58828266F324A40
83350	7	73	462	16058	30685	\N	52.279131	Саратовская область, Новобурасский район, село Кутьино, Адрес помещения для голосования: ул.Новая, д.1 (здание администрации с.Кутьино), Адрес УИК: ул.Бабушкина, д.5 (здание школы с.Кутьино)		0101000020E61000009DD66D50FBDB46405F268A90BA234A40
83338	7	73	462	2732	30460	\N	52.001339000000002	Саратовская область, Новобурасский район, село Ириновка, Адрес помещения для голосования: ул.Первомайская, д.12А (здание администрации с.Ириновка), Адрес УИК: ул.Советская, д.25,кор.1(здание школы с.Ириновка)		0101000020E61000001F115322891E4740CC9A58E02B004A40
83340	7	73	462	15550	30458	\N	52.063969999999998	Саратовская область, Новобурасский район, село Елшанка, Адрес помещения для голосования: ул.Кооперативная, д.1 (здание администрации с.Тепловка), Адрес УИК: ул. Школьная, д.1 (здание школы с.Тепловка)		0101000020E610000003CDE7DCED0247406AF6402B30084A40
83353	7	73	462	53241	31625	\N	52.365023959137801	Саратовская область, Новобурасский район, поселок Динамовский, Адрес помещения для голосования: ул. Мирная, д.9А (здание администрации п.Динамовский), Адрес УИК: ул.Молодежная, д.1 (здание школы п.Динамовский)		0101000020E61000005512D907590C4740A7203F1BB92E4A40
83343	7	73	462	15676	31124	\N	52.091766999999997	Саратовская область, Новобурасский район, село Гремячка, Адрес помещения для голосования: ул.Колхозная, д.10А (здание администрации с.Гремячка), Адрес УИК: ул.Северная, д.2А (здание школы с.Гремячка)		0101000020E610000072C45A7C0ADE46400FED6305BF0B4A40
83349	7	73	462	15964	31002	\N	52.262768999999999	Саратовская область, Новобурасский район, поселок Вихляйка, ул. Элеваторная, д. 1 (здание клуба п.Вихляйка)		0101000020E6100000F793313ECCE8464089B3226AA2214A40
83347	7	73	462	15889	30259	\N	52.209746000000003	Саратовская область, Новобурасский район, поселок Бурасы, Адрес помещения для голосования: ул.Соеветская, д. 31 (здание администрации п.Бурасы), Адрес УИК: ул.Первомайская, д. 6 (здание школы п.Бурасы)		0101000020E6100000C9CB9A58E00F4740C13BF9F4D81A4A40
83348	7	73	462	15957	31318	\N	52.241515999999997	Саратовская область, Новобурасский район, поселок Белоярский, Адрес помещения для голосования: ул.Октябрьская, д.2 (здание администрации п.Белоярский), Адрес УИК: ул. Коммунарная, д.3 (здание клуба п.Белоярский)		0101000020E61000000473F4F8BDED4640F9BA0CFFE91E4A40
83334	7	73	462	15251	30490	\N	51.922775999999999	Саратовская область, Новобурасский район, село Аряш, Адрес помещения для голосования: ул.Советская, д.78 (здание администрации с.Аряш), Адрес УИК: ул.Новая, д.1А (здание школы с.Аряш)		0101000020E6100000BCB376DB8514474050C422861DF64940
83285	7	73	1239	12934	30304	\N	51.855322999999999	Саратовская область, Марксовский район, село Ястребовка, ул. Первомайская, д. 14 а (МОУ-основ. общеоб.школа)		0101000020E61000000C3A2174D087474020425C397BED4940
83304	7	73	1239	13818	30438	\N	51.57161	Саратовская область, Марксовский район, село Яблоня, ул. Центральная, д. 15 (МОУ-основная общеоб. школа)		0101000020E61000004983DBDAC2DF4740850838842AC94940
83298	7	73	1239	13544	31276	\N	51.554147	Саратовская область, Марксовский район, село Чкаловка, ул. Центральная, д. 19		0101000020E6100000D8F15F2008A847409816F549EEC64940
83305	7	73	1239	13879	31144	\N	51.660468000000002	Саратовская область, Марксовский район, село Фурманово, ул. Целинная, д. 9 а (МОУ-средняя общеоб.школа)		0101000020E6100000B58993FB1DAC4740FB0626378AD44940
83321	7	73	1239	14634	31423	\N	51.537277000000003	Саратовская область, Марксовский район, село Фурмановка, ул. Заречная, д. 6А (Дом культуры)		0101000020E6100000672B2FF99F4C47404EF2237EC5C44940
83288	7	73	1239	13110	30805	\N	51.607635000000002	Саратовская область, Марксовский район, село Степное, ул. Душанбинская, д. 18/1 (Центр немецкой культуры)		0101000020E6100000D234289A079C4740D673D2FBC6CD4940
83299	7	73	1239	13596	31141	\N	51.485157999999998	Саратовская область, Марксовский район, поселок Солнечный, ул. Рабочая, д. 12		0101000020E610000044334FAE29BE474046B247A819BE4940
83286	7	73	1239	12976	31393	\N	51.767055999999997	Саратовская область, Марксовский район, село Семеновка, ул. Школьная, д. 1 (МОУ-основная .общеобр. школа)		0101000020E6100000EB1B98DC28AC4740AC1919E42EE24940
83320	7	73	1239	14620	30830	\N	51.508203000000002	Саратовская область, Марксовский район, село Раскатово, ул. Мелиораторов, д. 12 (МОУ-средняя общеобразовательная школа), ул. Мелиораторов, д. 11 (здание администрации)		0101000020E6100000789B374E0A514740535DC0CB0CC14940
83287	7	73	1239	13039	30422	\N	51.634625999999997	Саратовская область, Марксовский район, село Пугачевка, ул. Центральная, д. 14/2 (Здание бригадного дома)		0101000020E61000009CFA40F2CEA347407C98BD6C3BD14940
83315	7	73	1239	14346	30665	\N	51.690989999999999	Саратовская область, Марксовский район, село Приволжское, ул. К. Маркса, д. 6 а (МОУ -средняя общеобразовательная школа), ул. Дорожная, д. 1А (здание администрации)		0101000020E6100000AA436E861B5C474078EE3D5C72D84940
83289	7	73	1239	53235	31579	\N	51.674764352666003	Саратовская область, Марксовский район, село Полековское, ул. Мира, д. 35 (МОУ-средняя общеоб. школа)	Россия, Саратовская область, Марксовский район, село Полековская	0101000020E6100000882F1345489D47405342B0AA5ED64940
83292	7	73	1239	13210	30343	\N	51.820141999999997	Саратовская область, Марксовский район, село Подлесное, ул. Ленина, д. 34 (Дом культуры)		0101000020E61000009EB12FD978824740BB09BE69FAE84940
83291	7	73	1239	13210	30644	\N	51.820141999999997	Саратовская область, Марксовский район, село Подлесное, ул. Комсомольская, д. 85 (МОУ-средняя общеоб. школа)		0101000020E61000009EB12FD978824740BB09BE69FAE84940
83313	7	73	1239	14247	31304	\N	51.678671999999999	Саратовская область, Марксовский район, село Павловка, ул. Революции, д. 13 (МОУ-средняя общеобразовательная школа), ул. Ленина, д. 24 (здание администрации)		0101000020E6100000FA0B3D62F4584740FF5A5EB9DED64940
83318	7	73	1239	14528	30635	\N	51.576335	Саратовская область, Марксовский район, поселок Осиновский, ул. Школьная, д. 8 (МОУ-средняя общеоб. школа)		0101000020E6100000105A0F5F2668474024456458C5C94940
83325	7	73	1239	14826	30456	\N	51.760618000000001	Саратовская область, Марксовский район, село Орловское, ул. Ленина, д. 52 а (Дом культуры)		0101000020E610000014CB2DAD86724740DD5F3DEE5BE14940
83284	7	73	1239	12932	30996	\N	51.830869	Саратовская область, Марксовский район, село Михайловка, ул. Советская, д. 22 е (Дом досуга)		0101000020E6100000E4486760E48347404F2157EA59EA4940
83296	7	73	1239	13487	30418	\N	51.545791000000001	Саратовская область, Марксовский район, село Липовка, ул. Молодежная, д. 1Б (Дом досуга)		0101000020E61000009ACDE33098B34740BFB9BF7ADCC54940
83317	7	73	1239	14454	31249	\N	51.681609000000002	Саратовская область, Марксовский район, село Красная Поляна, ул. Школьная, д. 4		0101000020E6100000327216F6B44D474063D4B5F63ED74940
83302	7	73	1239	13766	30821	\N	51.667786	Саратовская область, Марксовский район, село Красная Звезда, ул. Овражная, д. 6		0101000020E6100000244223D8B8CC4740035DFB027AD54940
83283	7	73	1239	12854	31290	\N	51.765529000000001	Саратовская область, Марксовский район, поселок Колос, ул. Ленина, д. 38 (МОУ-средняя общеобр.школа)		0101000020E61000006E313F3734A14740DE91B1DAFCE14940
83306	7	73	1239	13962	30444	\N	51.562882000000002	Саратовская область, Марксовский район, село Кировское, ул.Кировская, д. 1 (МОУ-средняя общеоб. школа)		0101000020E6100000151C5E10919C4740E8C072840CC84940
83295	7	73	1239	13400	30645	\N	51.703772999999998	Саратовская область, Марксовский район, село Караман, ул. Заречная, д. 25 а (Дом досуга)		0101000020E6100000C4060B27698447406667D13B15DA4940
83312	7	73	1239	14244	31009	\N	51.576374000000001	Саратовская область, Марксовский район, село Каменка, ул. Ленина, д. 1 (МОУ-средняя общеоб. школа)		0101000020E610000066F84F3750724740E2218C9FC6C94940
83308	7	73	1239	14059	30982	\N	51.510092	Саратовская область, Марксовский район, село Калининское, ул. Центральная, д. 40 (МОУ-средняя общеобр. школа)		0101000020E6100000B4226AA2CF8B4740C2F9D4B14AC14940
83300	7	73	1239	13673	30815	\N	51.524194000000001	Саратовская область, Марксовский район, поселок им. Тельмана, ул. Школьная, д. 11 (МОУ-средняя общеоб. школа)		0101000020E6100000395FECBDF8CC47403561FBC918C34940
83279	7	73	1239	12729	30803	\N	51.897990999999998	Саратовская область, Марксовский район, село Зоркино, ул. Ленина, д. 27 (МОУ-средняя общеобраз.школа)		0101000020E610000057D0B4C4CA964740198D7C5EF1F24940
83301	7	73	1239	13676	30817	\N	51.590432	Саратовская область, Марксовский район, село Заря, ул. Почтовая, д. 7 кв. 2		0101000020E6100000C3633F8BA5CA47408541994693CB4940
83281	7	73	1239	12805	30419	\N	51.933267000000001	Саратовская область, Марксовский район, село Георгиевка, ул. Комсомольская, д. 13 (МОУ-Средняя общеобраз.школа)		0101000020E6100000B037312427A34740D0B7054B75F74940
83282	7	73	1239	12852	30643	\N	51.921554	Саратовская область, Марксовский район, село Воротаевка, ул Интернациональная, д. 38 (Дом досуга)		0101000020E6100000D027F224E9A04740BEBF417BF5F54940
83307	7	73	1239	13966	31146	\N	51.500028999999998	Саратовская область, Марксовский район, село Вознесенка, ул. Калинина, д. 4 б (МОУ-основ. общеоб. школа)		0101000020E61000009F3C2CD49AA647409A0645F300C04940
83309	7	73	1239	14071	30659	\N	51.589022	Саратовская область, Марксовский район, поселок Водопьяновка, ул. Комсомольская, д. 6 (МОУ-основная общеоб. школа)		0101000020E61000003677F4BF5C8D4740F04FA91265CB4940
83280	7	73	1239	12730	31408	\N	51.906233122094598	Саратовская область, Марксовский район, село Васильевка, ул. Центральная, д. 38 (Дом досуга)	Россия, Саратовская область, Марксовский район, село Васильевка	0101000020E610000023A298BC019A47402AC76471FFF34940
83311	7	73	1239	14163	30807	\N	51.676276000000001	Саратовская область, Марксовский район, село Бородаевка, ул. Почтовая, д. 24 (МОУ-основная общеоб. школа)		0101000020E610000025E99AC9376F4740EC88433690D64940
83316	7	73	1239	14395	30623	\N	51.647866999999998	Саратовская область, Марксовский район, село Бобровка, ул. Центральная, д. 30 (Дом культуры)		0101000020E610000055DCB8C5FC5047402D944C4EEDD24940
83297	7	73	1239	13503	31379	\N	51.576177999999999	Саратовская область, Марксовский район, село Бобово, ул. Фрунзе, д. 21 (Дом досуга)		0101000020E61000001B7FA2B261BF47405C566133C0C94940
83310	7	73	1239	14114	30985	\N	51.659691000000002	Саратовская область, Марксовский район, село Березовка, ул. З. Космодемьянской, д. 10А (МОУ-основная общеобр.школа)		0101000020E610000001A60C1CD06A4740973B33C170D44940
83293	7	73	1239	13321	30191	\N	51.796554	Саратовская область, Марксовский район, село Баскатовка, ул. Чапаева, д. 18 а (Дом культуры)		0101000020E610000052F17F47547E4740BEBF417BF5E54940
83294	7	73	1239	13394	30196	\N	51.763038000000002	Саратовская область, Марксовский район, село Александровка, ул. Колхозная, д. 2 (Дом домуга)		0101000020E6100000C82764E76D78474079CDAB3AABE14940
83323	7	73	1239	14743	31299	\N	51.671165000000002	Саратовская область, Марксовский район, село Андреевка, ул. Центральная, д. 11Б/1 (Дом культуры)		0101000020E610000048F949B54F634740249C16BCE8D54940
83260	7	73	503	3075	30630	\N	51.633184	Саратовская область, Лысогорский район, п.Яблочный, Адрес помещения для голосования: ул.Садовая, д.47 (МОУ СОШ п.Яблочный), Адрес УИК: ул.Садовая, д.46 (здание сельского ДК)		0101000020E61000005BB56B425A534640DC2C5E2C0CD14940
83264	7	73	503	11997	30204	\N	51.556610999999997	Саратовская область, Лысогорский район, с.Юнгеровка, ул.Центральная, д.52 (здание школы с.Юнгеровка)		0101000020E61000000892770E658E464003CC7C073FC74940
83873	7	73	503	53155	30447	\N	51.486690497337797	Саратовская область, Энгельсский район, г. Энгельс, Детская школа искусств № 5, ул. Транспортная, д. 30а	Россия, Саратовская область, Лысогорский район	0101000020E61000002C802903070C474027A5A0DB4BBE4940
83270	7	73	503	12263	31028	\N	51.339590000000001	Саратовская область, Лысогорский район, с.Широкоий Карамыш, Адрес помещения для голосования: ул.Садовая, д.37 (33) (здание МОУ СОШ с.Широкий Карамыш), Адрес УИК: ул.Советская, д.78 (здание местной администрации)		0101000020E610000041B8020AF58846403A0664AF77AB4940
83261	7	73	503	11849	30631	\N	51.626379999999997	Саратовская область, Лысогорский район, с.Шереметьевка, ул.Песчаная, д.61А (здание школы с.Шереметьевка)		0101000020E6100000936E4BE4826946402A6F47382DD04940
83258	7	73	503	11673	30362	\N	51.381971999999998	Саратовская область, Лысогорский район, с.Чадаевка, ул.Набережная, д.1(здание сельского ДК)		0101000020E6100000E620E868556146406DFE5F75E4B04940
83267	7	73	503	9221	30773	\N	51.434125000000002	Саратовская область, Лысогорский район, с.Урицкое, Адрес помещения для голосования: ул.Заречная, д.23А (здание МОУ СОШ с.Урицкое), Адрес УИК: ул.Набережная, д.28 (здание местной администрации)		0101000020E6100000BD361B2B3177464021B0726891B74940
83276	7	73	503	12577	30590	\N	51.241143000000001	Саратовская область, Лысогорский район, п.Раздольное, Адрес помещения для голосования: ул.Школьная, д.22 (здание МОУ СОШ п.Раздольное), Адрес УИК: ул.Центральная, д.10 (здание местной администрации)		0101000020E61000003DD7F7E1209F4640655419C6DD9E4940
83263	7	73	503	11905	30369	\N	51.550125999999999	Саратовская область, Лысогорский район, п.Октябрьский, ул.Почтовая, д.3 (здание местной администрации)		0101000020E61000004ED53DB2B9864640F3565D876AC64940
83262	7	73	503	11856	30178	\N	51.553727000000002	Саратовская область, Лысогорский район, с.Новая Красавка, Адрес помещения для голосования: ул.Садовая, д.1А (здание сельского ДК), Адрес УИК: ул.Садовая, д.2А (здание местной администрации)		0101000020E61000004759BF9998784640C3F4BD86E0C64940
94378	7	73	503	12410	30533	\N	51.220742999999999	Саратовская область, Лысогорский район, с.Невежкино, ул. Центральная,42 (здание сельского ДК)		0101000020E6100000FD4FFEEE1D79464014E97E4E419C4940
83255	7	73	503	3039	\N	\N	51.550938000000002	Саратовская область, Лысогорский район, р.п.Лысые Горы, ул. Мира, д.71  (здание городского ДК)	Россия, Саратовская область, Лысогорский район, поселок Лысые Горы	0101000020E6100000755B22179C6B4640D40FEA2285C64940
94377	7	73	503	3039	31134	\N	51.550938000000002	Саратовская область, Лысогорский район, р.п.Лысые Горы, пл.50 лет Октября, д.1 (здание районного ДК)		0101000020E6100000755B22179C6B4640D40FEA2285C64940
83256	7	73	503	3039	30951	\N	51.550938000000002	Саратовская область, Лысогорский район, р.п.Лысые Горы, Адрес помещения для голосования: ул.Пионерская, д.33 (здание МОУ СОШ №2 р.п.Лысые Горы), Адрес УИК: ул.Мира, д.35 (здание к/т Мир)		0101000020E6100000755B22179C6B4640D40FEA2285C64940
83266	7	73	503	3151	67043	\N	51.433737000000001	"""Саратовская область, Лысогорский район, с.Ключи, Адрес помещения для голосования: ул.Набережная, 19, здание сельского Дома Культуры т.3-46-85 "		0101000020E6100000EACA67791E9846405708ABB184B74940
83275	7	73	503	12492	30849	\N	51.387402000000002	Саратовская область, Лысогорский район, с.Двоенка, Адрес помещения для голосования: ул.Советская, д.16 (здание МОУ СОШ с.Двоенка), Адрес УИК: ул.Советская, д.14 (здание местной администрации)	Россия, Саратовская область, Лысогорский район, село Двоенка	0101000020E61000007D9752978CA54640D733846396B14940
83236	7	73	193	707	30510	\N	51.770651000000001	Саратовская область, Краснопартизанский район,  р.п.Горный, ул. Новая, д.32 (филиал ФГУ Сармелиоводхоз)		0101000020E6100000C6F7C5A52A4748409AD024B1A4E24940
83265	7	73	503	12002	30984	\N	51.476064999999998	Саратовская область, Лысогорский район, п.Гремячий, Адрес помещения для голосования: ул.Мира, д.5 (здание МОУ СОШ п.Гремячий), Адрес УИК: ул.Мира, д.6 (здание сельского ДК)		0101000020E610000050A912656F9B464097E2AAB2EFBC4940
83257	7	73	503	11659	31090	\N	51.522748	Саратовская область, Лысогорский район, с. Бутырки, Адрес помещения для голосования ул.Молодежная, д.11 (здание сельского ДК), Адрес УИК: ул. Молодежная, д.11 (здание местной администрации)		0101000020E6100000F33B4D66BC67464053060E68E9C24940
83272	7	73	503	12350	31220	\N	51.191760357877101	Саратовская область, Лысогорский район, с.Большие Копены, ул.Советская, д.12,здание сельского Дома Культуры	Россия, Саратовская область, Лысогорский район, село Большие Копены	0101000020E61000001EC3633F8B7F46402A5778978B984940
83259	7	73	503	11726	30811	\N	51.600597999999998	Саратовская область, Лысогорский район, с.Большая Рельня, Адрес помещения для голосования: ул.Ленинская, д.115 (здание сельского ДК), Адрес УИК: ул.Ленинская, д.131(здание местной администрации)		0101000020E6100000D6355A0EF45E464081053065E0CC4940
83277	7	73	503	12601	30598	\N	51.323337000000002	Саратовская область, Лысогорский район, с.Большая Каменка, ул.Дорожная, д.2А (здание школы)		0101000020E61000002EC6C03A8E9746401B4B581B63A94940
83274	7	73	503	12484	30240	\N	51.348168999999999	Саратовская область, Лысогорский район, с.Большая Дмитриевка, Адрес помещения для голосования: ул.Школьная, д.12 (здание МОУ СОШ с.Большая Дмитриевка), Адрес УИК: ул.Советская, д.45 (здание местной администрации)		0101000020E61000009487855AD3A04640923D42CD90AC4940
83271	7	73	503	12331	31264	\N	51.312748999999997	Саратовская область, Лысогорский район, п.Барсучий, ул.Центральная, д.4 (здание лесхоза)		0101000020E6100000FFCEF6E80D814640A86DC32808A84940
83269	7	73	503	3212	30972	\N	51.292178	Саратовская область, Лысогорский район, с.Атаевка Адрес помещения для голосования: ул.Школьная, д.27А (здание сельского ДК), Адрес УИК: ул.Школьная, д.28 (здание МДОУ Золотая Рыбка)		0101000020E6100000938D075BEC6A46402B4EB51666A54940
83247	7	73	193	11182	31364	\N	51.737378	Саратовская область, Краснопартизанский район,  п.Чистопольский, ул.Радищева, д.20 (МОУ НОШ)		0101000020E6100000EB6F09C03F6F48401B65FD6662DE4940
83243	7	73	193	10969	30927	\N	51.914940856630999	Саратовская область, Краснопартизанский район, с.Толстовка, ул.Центральная, д.36 а  (МОУ СОШ)	Россия, Саратовская область, Краснопартизанский район, село Толстовка	0101000020E61000004B0169FF03604840806264C91CF54940
83240	7	73	193	10873	30333	\N	51.848191	Саратовская область, Краснопартизанский район, с.Сулак, ул.М.Горького, д.15 (МОУ СОШ)		0101000020E610000070D234289A2D48407AE1CE8591EC4940
83943	7	73	193	53178	31654	\N	51.729128937158301	Саратовская область, ЗАТО Светлый, ул. Лопатина, 11 здание ДЮСШ, 1 этаж вестибюль	Россия, Саратовская область, Краснопартизанский район, село Светлый	0101000020E6100000863AAC70CB7B484058C85C1954DD4940
83944	7	73	193	53178	30867	\N	51.730266	Саратовская область, ЗАТО Светлый, ул.Кузнецова, д.10 (СОШ №2 спортивный зал)	Россия, Саратовская область, Краснопартизанский район, село Светлый	0101000020E61000008A7269FCC27B4840BCB0355B79DD4940
83942	7	73	193	53178	30867	\N	51.730266	Саратовская область, ЗАТО Светлый, ул.Кузнецова, д.12 (СОШ №3 спортивный зал)	Россия, Саратовская область, Краснопартизанский район, село Светлый	0101000020E61000008A7269FCC27B4840BCB0355B79DD4940
83239	7	73	193	10799	30910	\N	51.701250000000002	Саратовская область, Краснопартизанский район, с.Савельевка, ул.Ленинская, д.34 (МОУ ООШ)		0101000020E6100000392861A6ED3F4840F6285C8FC2D94940
83252	7	73	193	11391	31006	\N	51.577057000000003	Саратовская область, Краснопартизанский район,  п.Римско-Корсаковка, ул.Советская, д.33 (МОУ СОШ)		0101000020E6100000570A815CE2444840C576F700DDC94940
83245	7	73	193	11054	30744	\N	51.815922	Саратовская область, Краснопартизанский район, с.Раздольное, ул.Советская, д.1 (МОУ ООШ)		0101000020E610000051F4C0C760734840200BD12170E84940
83251	7	73	193	11334	30752	\N	51.535713999999999	Саратовская область, Краснопартизанский район, с.Подшибаловка, ул.Центральная, д.13-а (МОУ НОШ)		0101000020E6100000E292E34EE94648403201BF4692C44940
83242	7	73	193	10966	30549	\N	51.819229	Саратовская область, Краснопартизанский район, п.Петровский, ул.Центральная, д.40 (МОУ СОШ)		0101000020E6100000FAD4B14AE95F4840A777F17EDCE84940
83248	7	73	193	11228	30898	\N	51.634202000000002	Саратовская область, Краснопартизанский район, п.Октябрьский, ул.Школьная, д.1 (МОУ ООШ)		0101000020E6100000B7D100DE028F48406687F8872DD14940
83249	7	73	193	11279	30353	\N	51.619559000000002	Саратовская область, Краснопартизанский район, с.Милорадовка, ул.Степная, д.5 (МОУ СОШ)		0101000020E61000000D36751E15634840A37895B54DCF4940
83244	7	73	193	11052	30339	\N	51.756644000000001	Саратовская область, Краснопартизанский район, с.Корнеевка, ул.Школьная, д.4 (МОУ СОШ)		0101000020E6100000AE9E93DE37604840795BE9B5D9E04940
83253	7	73	193	2974	30775	\N	51.611409999999999	Саратовская область, Краснопартизанский район, п.Емельяновка, ул.Молодежная, д.2 а т.2-76-18  д.2 (СДК)		0101000020E6100000BC9179E40F4448404339D1AE42CE4940
83246	7	73	193	11141	31072	\N	51.674092000000002	Саратовская область, Краснопартизанский район, п.Дальний, ул.Чапаевская, д.4 (администрация)		0101000020E6100000FD4E93196F654840643F8BA548D64940
83238	7	73	193	707	31267	\N	51.770651000000001	"Саратовская область, Краснопартизанский район, р.п.Горный, ул.Стадионная площадь, д.29 ""б"" МУ ""ФОК ""Степняк"" т.2-11-69, "		0101000020E6100000C6F7C5A52A4748409AD024B1A4E24940
83237	7	73	193	707	31474	\N	51.770651000000001	"Саратовская область, Краснопартизанский район, р.п.Горный, ул.Горная, д.30 ""а"" административное здание Дома культуры т.2-13-38 "		0101000020E6100000C6F7C5A52A4748409AD024B1A4E24940
83250	7	73	193	11326	30566	\N	51.528592000000003	Саратовская область, Краснопартизанский район, с.Головинщено, ул.Кутузова, д.2 (МОУ ООШ)		0101000020E610000097395D16135D4840B07614E7A8C34940
83241	7	73	193	10878	31477	\N	51.880243	Саратовская область, Краснопартизанский район, с.Большая Сакма, ул.Советская, д.31-а (МОУ ООШ)		0101000020E6100000E2C803914542484037C478CDABF04940
83223	7	73	166	9993	30317	\N	50.972003999999998	Краснокутский район, с. Ямское, ул. Школьная, д. 10 (МОУ СОШ с. Ямское)		0101000020E6100000533F6F2A529D474064CA87A06A7C4940
83226	7	73	166	10190	31351	\N	50.726782	Саратовская область, Краснокутский район, село Чкалово, ул. Центральная, д. 24 (Дом культуры)		0101000020E6100000802A6EDC6286474026A94C31075D4940
83225	7	73	166	10097	30318	\N	50.781789000000003	Саратовская область, Краснокутский район, село Усатово, пер. Клубный, д. 1 (Дом культуры)		0101000020E6100000D993C0E61C744740B0AF75A911644940
83214	7	73	166	53169	\N	\N	50.9247733071672	Саратовская область, Краснокутский район, Студгородок, Студгородок, Учебный корпус Зооветтехникума	Россия, Саратовская область, Краснокутский район	0101000020E610000019E6046D727E4740A69C2FF65E764940
83215	7	73	166	9592	30895	\N	50.915353000000003	Саратовская область, Краснокутский район, поселок Семенной, ул. Зеленая, д.1 (Дом культуры)		0101000020E61000005726FC523F874740D3A57F492A754940
83219	7	73	166	9797	\N	\N	51.097022000000003	Саратовская область, Краснокутский район, село Репное, клуб		0101000020E61000000801F9122AA647400B7F86376B8C4940
83234	7	73	166	10556	31063	\N	50.965566000000003	Саратовская область, Краснокутский район, село Рекорд, ул. Школьная, д. 12 (МОУ СОШ с. Рекорд)		0101000020E6100000C64FE3DEFC5447409510ACAA977B4940
83232	7	73	166	10496	30740	\N	50.953137382042698	Саратовская область, Краснокутский район, село Первомайское, ул. Зеленая, д. 10Б (Дом культуры)	Россия, Саратовская область, Краснокутский район	0101000020E6100000BF2B82FFAD644740C4CDA964007A4940
83235	7	73	166	10606	30495	\N	50.932850999999999	Саратовская область, Краснокутский район, село Норки, ул. Центральная, д.22 (клуб)		0101000020E610000056D3F544D77B47403C855CA967774940
83216	7	73	166	9634	31347	\N	50.997048999999997	Саратовская область, Краснокутский район, село Логиновка, ул. Новая, д. 3 (МОУ СОШ с. Логиновка)		0101000020E6100000F3583332C887474037C1374D9F7F4940
83228	7	73	166	10253	30543	\N	50.645659000000002	Саратовская область, Краснокутский район, село Лепехинка, ул. Центральная, д. 4 (Дом культуры)		0101000020E6100000F06C8FDE707547401DAF40F4A4524940
83217	7	73	166	9729	31054	\N	51.076813000000001	Саратовская область, Краснокутский район, село Лебедевка, ул. Центральная, д. 42 (Дом культуры)		0101000020E61000001288D7F50B9247402E742502D5894940
83231	7	73	166	10400	31230	\N	50.953606000000001	Саратовская область, Краснокутский район, село Лавровка, ул. Советская, д. 41 МДОУ Ручеек		0101000020E61000007DB3CD8DE97547407BA2EBC20F7A4940
83212	7	73	166	512	31217	\N	50.954712999999998	Саратовская область, город Красный Кут, пер.Спортивный, д. 2Б (стадион)		0101000020E610000049145AD6FD7B474074081C09347A4940
83207	7	73	166	512	30889	\N	50.954712999999998	Саратовская область, город Красный Кут, пер. Инкубаторный, д. 60 (МОУ СОШ №1)		0101000020E610000049145AD6FD7B474074081C09347A4940
83209	7	73	166	512	30303	\N	50.954712999999998	Саратовская область, город Красный Кут, ул. Московская, д.50 (МОУ СОШ №3)		0101000020E610000049145AD6FD7B474074081C09347A4940
83208	7	73	166	512	30303	\N	50.954712999999998	Саратовская область, город Красный Кут, ул. Московская, д. 73В (районный Дом культуры)		0101000020E610000049145AD6FD7B474074081C09347A4940
83175	7	73	166	512	30401	\N	50.954712999999998	Саратовская область, город Красный Кут, ул. Куховаренко, д.196 (общежитие ГОУ НПО ПУ-64)		0101000020E610000049145AD6FD7B474074081C09347A4940
83210	7	73	166	512	31346	\N	50.954726295287799	Саратовская область, город Красный Кут, ул. Комсомольская, д. 102 (МОУ СОШ №2)	Россия, Саратовская область, Краснокутский район, Красный Кут	0101000020E610000092E86514CB7B474009522976347A4940
83211	7	73	166	512	30930	\N	50.954712999999998	Саратовская область, город Красный Кут, ул. Астраханская, д. 1/13 (ООО Первая зерновая комп)		0101000020E610000049145AD6FD7B474074081C09347A4940
83197	7	73	166	512	30322	\N	50.954712999999998	Саратовская область, город Красный Кут, ул. Авиационная, д. 25 (лицей-интернат №5 ОАО РЖД)		0101000020E610000049145AD6FD7B474074081C09347A4940
83224	7	73	166	10062	31229	\N	50.784996	Саратовская область, Краснокутский район, село Комсомольское, ул. Советская, д.34 (МОУ СОШ с. Комсомльское)		0101000020E610000008944DB9C2854740D3BEB9BF7A644940
83229	7	73	166	10334	30537	\N	50.805680000000002	Саратовская область, Краснокутский район, село Кирово, ул. Центральная, д. 5 (МОУ СОШ с. Кирово)		0101000020E6100000E8DEC325C75947404985B18520674940
83220	7	73	166	9885	31057	\N	51.101553000000003	Саратовская область, Краснокутский район, село Карпенка, ул. Центральная, д.53 (Дом культуры)		0101000020E61000001F317A6EA1A14740C5E74EB0FF8C4940
83233	7	73	166	10506	30908	\N	51.088332999999999	Саратовская область, Краснокутский район, село Интернациональное, ул. Школьная, д. 7 (МОУ СОШ с. Интернациональное)		0101000020E610000086014BAE625B47402B14E97E4E8B4940
83213	7	73	166	9527	31050	\N	50.970993999999997	Саратовская область, Краснокутский район, поселок Загородный, ул. Центральная, д. 3 (Дом культуры)		0101000020E6100000F5A10BEA5B7E47405D4E0988497C4940
83222	7	73	166	9992	31470	\N	50.888075000000001	Саратовская область, Краснокутский район, село Журавлевка, ул. Центральная, д. 1 (Дом культуры)		0101000020E6100000494BE5ED0891474096B20C71AC714940
83218	7	73	166	9736	31468	\N	51.062935000000003	Саратовская область, Краснокутский район, село Ждановка, ул. Центральная, д.1 (дом культуры)		0101000020E61000000F9D9E77639347400B630B410E884940
83227	7	73	166	10192	30319	\N	50.718775999999998	Саратовская область, Краснокутский район, село Дьяковка, ул. Энгельса, д. 1 (Дом культуры)		0101000020E61000002DB4739A0564474029931ADA005C4940
83221	7	73	166	9941	31469	\N	50.952432000000002	Саратовская область, Краснокутский район, село Верхний Еруслан, ул. Советская, д. 31А (Дом культуры)		0101000020E6100000B9A6406667814740FAD4B14AE9794940
83230	7	73	166	10397	30907	\N	50.934089	Саратовская область, Краснокутский район, село Ахмат, пер. Солнечный, д. 11 (Дом культуры)		0101000020E61000004D81CCCEA2774740D446753A90774940
83198	7	73	116	8830	31342	\N	50.975140000000003	Саратовская область, Красноармейский район, село Усть-Золиха, Здание СДК с. Усть-Золиха, ул.Центральная,40		0101000020E6100000711C78B5DCC54640BF823463D17C4940
83201	7	73	116	9016	\N	\N	50.973942999999998	Саратовская область, Красноармейский район, село Старая Топовка, Здание МОУ ООШ с. Ст.Топовка		0101000020E61000001E1A16A3AEA7464085950A2AAA7C4940
83203	7	73	116	470	31462	\N	51.066360000000003	Саратовская область, Красноармейский район, село Сплавнуха, Здание МОУ СОШ с. Сплавнуха ул.Ленина,30		0101000020E610000058AEB7CD54B046409CE1067C7E884940
83177	7	73	116	7819	30869	\N	51.189830000000001	Саратовская область, Красноармейский район, село Сосновка, Здание МОУ ООШ с. Сосновкаул.Красноармейская,12		0101000020E6100000DF6FB4E386E346405CE674594C984940
83179	7	73	116	7920	\N	\N	51.038769000000002	Саратовская область, Красноармейский район, село Садовое, Адрес помещения для голосования: Здание МОУ СОШ с. Садовое, Адрес УИК: Здание администрации Садовского МО ул. Первомайская,12		0101000020E61000004FCC7A3194ED4640A08CF161F6844940
83185	7	73	116	8274	31029	\N	50.896602999999999	Саратовская область, Красноармейский район, село Рогаткино, Здание МОУ ООШ с. Рогаткино ул.Центральная,64		0101000020E6100000527DE71725DC46406C3F19E3C3724940
83181	7	73	116	8054	30390	\N	50.928128000000001	Саратовская область, Красноармейский район, село Ревино, Здание МОУ ООШ с. Ревино ул.Советская,12в		0101000020E6100000B262B83A00EE46403E40F7E5CC764940
83192	7	73	116	8597	30881	\N	50.784193000000002	Саратовская область, Красноармейский район, село Первомайское, Здание МОУ СОШ с. Первомайское ул.Школьная,16		0101000020E61000005FD4EE5701BE46404660AC6F60644940
83205	7	73	116	53191	31088	\N	51.186015621937202	Саратовская область, Красноармейский район, станция Паницкая, Здание МОУ СОШ ст. Паницкая ул.Пионерская,14	Россия, Саратовская область, Красноармейский район, село Паницкая	0101000020E61000000C74ED0BE8BF464031444E5FCF974940
83188	7	73	116	8382	31031	\N	50.730589999999999	Саратовская область, Красноармейский район, село Нижняя Банновка, Здание МОУ СОШ с. Н. Банновка ул. Кооперативная,48		0101000020E61000002E5393E00DD346406F641EF9835D4940
83204	7	73	116	9102	31461	\N	51.162770999999999	Саратовская область, Красноармейский район, село Некрасово, Здание МОУ СОШ с. Некрасово ул.Кирова,32а		0101000020E6100000F9BA0CFFE9A646405DDE1CAED5944940
83178	7	73	116	203	\N	\N	51.121282000000001	Саратовская область, Красноармейский район, село Мордово, Адрес помещения для голосования: Здание МОУ ООШ с. Мордово, Адрес УИК: Здание администрации Мордовинского МО ул.Садовая,2		0101000020E61000004F93196F2BE74640F7CB272B868F4940
83187	7	73	116	8319	30708	\N	50.787461	Саратовская область, Красноармейский район, село Меловое, Здание МОУ ООШ с. Меловое ул.Вишневая,58		0101000020E61000004BE9995E62D046400FF0A485CB644940
83176	7	73	116	7287	31175	\N	51.169611000000003	Саратовская область, Красноармейский район, село Луганское, Здание МОУ СОШ с. Луганское, ул. Волжская,45		0101000020E6100000242A543717D546405C0531D0B5954940
83165	7	73	116	7287	31175	\N	51.169611000000003	Саратовская область, Красноармейский район, село Луганское, Здание МОУ СОШ с. Луганское ул. Волжская,45		0101000020E6100000242A543717D546405C0531D0B5954940
83160	7	73	116	53158	30556	\N	51.025837000000003	Саратовская область, Красноармейский район, город Красноармейск, ул.Захарова, д. 57 (МОУ СОШ № 4)		0101000020E6100000B9C2BB5CC4D946406D0377A04E834940
83182	7	73	116	251	30697	\N	50.971085000000002	Саратовская область, Красноармейский район, село Ключи, Здание администрации Ключевского МО ул.Ульяновская,16		0101000020E6100000618BDD3EABD846406E5166834C7C4940
83195	7	73	116	8705	\N	\N	50.921734999999998	Саратовская область, Красноармейский район, село Карамышевка, Здание МОУ СОШ с. Карамышевка ул.Центральная,14		0101000020E610000073F4F8BD4DB346400E4A9869FB754940
83199	7	73	116	326	31473	\N	50.970733407034302	Саратовская область, Красноармейский район, село Карамыш, Здание МОУ ООШ с. Карамыш ул.Школьная,3	Россия, Саратовская область, Красноармейский район, село Карамыш	0101000020E61000001B118C834BC34640F1129CFA407C4940
83196	7	73	116	326	31454	\N	50.966831309276699	Саратовская область, Красноармейский район, станция Карамыш, Здание СДК ст. Карамыш ул.Почтовая,21б	Россия, Саратовская область, Красноармейский район, село Карамыш	0101000020E6100000B7EF517FBDC2464026E1421EC17B4940
83194	7	73	116	8644	31339	\N	50.889018999999998	Саратовская область, Красноармейский район, поселок Каменский, Здание СДК п. Каменский ул.Первомайская,59		0101000020E61000003B8E1F2A8DBE4640E542E55FCB714940
83193	7	73	116	8644	31339	\N	50.889018999999998	Саратовская область, Красноармейский район, поселок Каменский, Здание СДК п. Каменский, ул.Первомайская,59		0101000020E61000003B8E1F2A8DBE4640E542E55FCB714940
72814	7	71	\N	16298	51762	\N	56.759227000000003	г.Чайковский, ул.Камская, д.3		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
83190	7	73	116	8502	30501	\N	50.695684999999997	Саратовская область, Красноармейский район, село Каменка, Здание МОУ СОШ № 6 с. Каменка ул.Советская,27б		0101000020E6100000FD6838656EB64640ACA8C1340C594940
83184	7	73	116	8203	31332	\N	50.830030000000001	Саратовская область, Красноармейский район, село Золотое, Здание СДК с. Золотое пер.Больничный, 6б		0101000020E610000057B439CE6DF2464075594C6C3E6A4940
83191	7	73	116	8557	30615	\N	50.735715999999996	Саратовская область, Красноармейский район, село Елшанка, Здание МОУ ООШ с. Елшанка ул.55 лет Победы,2		0101000020E610000076DD5B9198BA46406C921FF12B5E4940
83183	7	73	116	8115	31185	\N	50.85322	Саратовская область, Красноармейский район, село Дубовка, Здание МОУ ООШ с. Дубовка ул.Советская,26		0101000020E6100000A20DC0064402474085251E50366D4940
83186	7	73	116	8312	31085	\N	50.849836000000003	Саратовская область, Красноармейский район, село Гусево, Здание МОУ ООШ с. Гусево ул.Школьная,19		0101000020E610000048A98427F4DA4640537B116DC76C4940
83189	7	73	116	8415	30718	\N	50.643253999999999	Саратовская область, Красноармейский район, село Гвардейское, Здание МОУ СОШ с. Гвардейское ул.Заречная,23		0101000020E6100000376E313F37B24640B682A62556524940
83200	7	73	116	388	\N	\N	51.004168999999997	Саратовская область, Красноармейский район, село Высокое, Здание СДК с. Высокое,		0101000020E61000001C2444F982BC464019541B9C88804940
83180	7	73	116	7958	31032	\N	50.957265999999997	Саратовская область, Красноармейский район, село Ваулино, Здание МОУ ООШ с. Ваулино ул.Школьная,19		0101000020E610000059FCA6B052E546404FC939B1877A4940
83202	7	73	116	9015	31206	\N	51.083292	Саратовская область, Красноармейский район, село Бобровка, Здание МОУ СОШ с. Бобровка ул.Школьная,11		0101000020E61000007B9FAA4203C346405C02F04FA98A4940
83147	7	73	727	6402	30872	\N	51.362203000000001	Саратовская область, Калининский район, с. Шклово, ул. Центральная (Школа), д. 81А		0101000020E6100000AC1919E42E424640ADC1FBAA5CAE4940
83132	7	73	727	5594	30647	\N	51.667226999999997	Саратовская область, Калининский район, с. Широкий Уступ, ул. Рабочая (Школа), д. 27		0101000020E61000002D26361FD73446400C01C0B167D54940
83139	7	73	727	5975	31424	\N	51.427464999999998	Саратовская область, Калининский район, д. Федоровка, ул. Центральная (СДК), д. 57		0101000020E6100000F964C570752E4640A297512CB7B64940
83143	7	73	727	6197	31488	\N	51.309522999999999	Саратовская область, Калининский район, с. Таловка, Школьный переулок (Школа), д. 7		0101000020E6100000088ECBB8A91D46400E2E1D739EA74940
83159	7	73	727	7020	30875	\N	51.709415999999997	Саратовская область, Калининский район, с. Славновка, ул. Кирова (Школа), д. 40		0101000020E6100000739EB12FD92446402BA1BB24CEDA4940
83141	7	73	727	6128	30263	\N	51.366599999999998	Саратовская область, Калининский район, с. Симоновка, ул. Советская (Школа), д. 22		0101000020E610000098C1189128604640575BB1BFECAE4940
83155	7	73	727	6797	30874	\N	51.607807999999999	Саратовская область, Калининский район, с. Сергиевка, ул. Школьная (Школа), д. 7		0101000020E61000005801BEDBBC074640A31F0DA7CCCD4940
83146	7	73	727	6336	31030	\N	51.257593	Саратовская область, Калининский район, с. Свердлово, ул. Верхняя (Администрация МО), д. 52		0101000020E61000005070B1A206494640DA56B3CEF8A04940
83136	7	73	727	5857	\N	\N	51.432074999999998	Саратовская область, Калининский район, с. Салтыково, ул. Центральная (СДК), д. 39	Россия, Саратовская область, Калининский район, село Салтыково	0101000020E610000035EF3845474E4640A835CD3B4EB74940
83152	7	73	727	6699	30491	\N	51.503701999999997	Саратовская область, Калининский район, п. Песчаный, ул. Школьная (СДК), д. 9		0101000020E610000034A14962490946400377A04E79C04940
83137	7	73	727	5863	30359	\N	51.488646000000003	Саратовская область, Калининский район, с. Первомайское, ул. Октябрьская (СДК), д. 1Б		0101000020E6100000207BBDFBE34946401EA9BEF38BBE4940
94376	7	73	727	6285	30321	\N	51.272770000000001	Саратовская область, Калининский район, с. Орловка, ул. Мира (Администрация МО), д. 42		0101000020E610000040868E1D542446403BAA9A20EAA24940
83150	7	73	727	6549	31035	\N	51.433221000000003	Саратовская область, Калининский район, с. Озерки, ул. Придорожная (Школа), д. 13		0101000020E6100000683F5244860F4640607825C973B74940
83156	7	73	727	6874	31190	\N	51.55198	Саратовская область, Калининский район, с. Новые Выселки, ул. Кооперативная (Школа), д. 2		0101000020E6100000FAB836548C174640E605D847A7C64940
83134	7	73	727	5718	30833	\N	51.462229999999998	Саратовская область, Калининский район, с. Новая Ивановка, ул. Советская (Школа), д. 1		0101000020E6100000AAEE91CD55494640739D465A2ABB4940
83151	7	73	727	6620	31189	\N	51.376086000000001	Саратовская область, Калининский район, с. Нижегороды, ул. Петрозавадовка (Школа), д. 42		0101000020E61000008E03AF963B134640E23D079623B04940
83142	7	73	727	6134	31007	\N	51.414130999999998	Саратовская область, Калининский район, с. Монастырское, ул. Школьная (Школа), д. 2		0101000020E6100000AB5AD2510E56464040A19E3E02B54940
83144	7	73	727	6278	31021	\N	51.331487000000003	Саратовская область, Калининский район, с. Михайловка, ул. Центральная (Школа), д. 72		0101000020E6100000B115342DB13446404B06802A6EAA4940
83138	7	73	727	5924	30538	\N	51.410176999999997	Саратовская область, Калининский район, с. Малая Екатериновка, Школьный тупик (Школа), д. 63		0101000020E6100000C408E1D1C6234640234910AE80B44940
83148	7	73	727	6494	31034	\N	51.213787000000004	Саратовская область, Калининский район, с. Красноармейское, ул. Центральная (Школа), д. 9		0101000020E6100000D8F2CAF5B6334640ADA7565F5D9B4940
83149	7	73	727	6547	30706	\N	51.198788	Саратовская область, Калининский район, с. Колокольцовка, ул. Ленина (Школа), д. 57Б		0101000020E610000079AEEFC3414C46402B6B9BE271994940
83128	7	73	727	5060	30237	\N	51.501162000000001	Саратовская область, Калининский район, г.Калининск, ул. Чехова (Центр социального обслуживания), д. 58		0101000020E610000054C8957A163C4640BDFF8F1326C04940
83124	7	73	727	5060	30232	\N	51.501162000000001	Саратовская область, Калининский район, г.Калининск, ул. Советская (Районный Дом Культуры), д. 30		0101000020E610000054C8957A163C4640BDFF8F1326C04940
83121	7	73	727	5060	30660	\N	51.501162000000001	Саратовская область, Калининский район, г.Калининск, ул. Первомайская (ПУ-54), д. 19		0101000020E610000054C8957A163C4640BDFF8F1326C04940
83122	7	73	727	5060	31485	\N	51.500094387167898	Саратовская область, Калининский район, г.Калининск, ул. Ленина (городская библиотека), д. 355/1	Россия, Саратовская область, Калининский район, Калининск	0101000020E610000020990E9D9E3B46408176871403C04940
83125	7	73	727	5060	31486	\N	51.4988584985309	Саратовская область, Калининский район, г.Калининск, ул. Коллективная (районная библиотека), д. 96	Россия, Саратовская область, Калининский район, Калининск	0101000020E61000004A46CEC29E3E46408AAC3594DABF4940
83123	7	73	727	5060	31163	\N	51.499243950762597	Саратовская область, Калининский район, г.Калининск, ул. Богдана Хмельницкого (МОУ СОШ №1), д. 32		0101000020E61000002D211FF46C3C4640B35C363AE7BF4940
83130	7	73	727	5060	67124	\N	51.497519173226003	Саратовская область, Калининский район, г.Калининск,  ул. 50 лет Октября,28 (здание д/с №7)	Россия, Саратовская область, Калининский район, Калининск	0101000020E610000028BA2EFCE03C4640BE11DDB3AEBF4940
83129	7	73	727	5060	30968	\N	51.501162000000001	Саратовская область, Калининский район, г.Калининск, ул. 30 лет ВЛКСМ (администроция МО г.Калининск), д. 47		0101000020E610000054C8957A163C4640BDFF8F1326C04940
83153	7	73	727	6703	31427	\N	51.471465000000002	Саратовская область, Калининский район, с.Казачка, ул. Молодежная (Администрация МО), д. 2/1		0101000020E61000002716F88A6EF74540B51A12F758BC4940
83135	7	73	727	5806	30989	\N	51.550378000000002	Саратовская область, Калининский район, п. Дубравный, ул. Школьная (СДК), д. 5		0101000020E6100000DFA815A6EF4B46400D384BC972C64940
83140	7	73	727	6076	30256	\N	51.512642999999997	Саратовская область, Калининский район, с. Большая Ольшанка, ул. Центральная (Школа), д. 4		0101000020E6100000EC4E779E78244640FCC22B499EC14940
83158	7	73	727	6933	30492	\N	51.612999000000002	Саратовская область, Калининский район, с. Ахтуба, ул. Центральная (Школа), д. 158		0101000020E6100000494DBB986630464088BD50C076CE4940
83133	7	73	727	5661	31151	\N	51.710219000000002	Саратовская область, Калининский район, с. Анастасьино, ул. Центральная (Школа), д. 2		0101000020E6100000AA7D3A1E33404640B9FFC874E8DA4940
83157	7	73	727	6927	30338	\N	51.679341999999998	Саратовская область, Калининский район, с. 3-я Александровка, ул. Пушкина (Школа), д. 8А		0101000020E61000007B134372321346404D66BCADF4D64940
83118	7	73	633	4909	30823	\N	52.205226000000003	Саратовская область, Ивантеевский район, село Яблоновый Гай, ул. Чапаева, д. 39 (сельский Дом Культуры)		0101000020E6100000C5FF1D51A1CC4840FB2477D8441A4A40
83116	7	73	633	4768	30822	\N	52.315745999999997	Саратовская область, Ивантеевский район, село Чернава, ул. Центральная, д. 37 (сельский Дом Культуры)		0101000020E610000094DA8B683BB24840E1EB6B5D6A284A40
83108	7	73	633	4359	30654	\N	52.288652419829198	Саратовская область, Ивантеевский район, село Раевка, ул. Центральная, д. 66 (сельский Дом Культуры)		0101000020E610000062DC0DA2B578484066F6798CF2244A40
83105	7	73	633	4156	31283	\N	52.452674999999999	Саратовская область, Ивантеевский район, село Николаевка, ул. Кооперативная, д. 94 (сельский Дом Культуры)		0101000020E6100000FBB1497EC49B4840C05B2041F1394A40
83109	7	73	633	4365	31270	\N	52.217376999999999	Саратовская область, Ивантеевский район, поселок Мирный, ул. Рабочая, д. 12 (здание школы)		0101000020E610000035D428249971484088F37002D31B4A40
83120	7	73	633	4964	30658	\N	52.108806999999999	Саратовская область, Ивантеевский район, село Клевенка, ул. Советская, д. 93 А (сельский Дом Культуры)		0101000020E610000099B7EA3A54C34840B6494563ED0D4A40
83119	7	73	633	4956	30226	\N	52.189515999999998	Саратовская область, Ивантеевский район, село Канаёвка, ул. Школьная, д.1(МОУ ООШ с. Канаёвка)		0101000020E6100000302AA913D0D24840CC086F0F42184A40
83112	7	73	633	4430	30189	\N	52.270606999999998	Саратовская область, Ивантеевский район, село Ивантеевка, ул. Советская, д. 24 (МУ ЦДК)		0101000020E61000007E1CCD91958D4840CA880B40A3224A40
83111	7	73	633	4430	30189	\N	52.270606999999998	Саратовская область, Ивантеевский район, село Ивантеевка, ул. Советская, д. 23 (МОУ СОШ с.Ивантеевка)		0101000020E61000007E1CCD91958D4840CA880B40A3224A40
83113	7	73	633	4430	30784	\N	52.270606999999998	Саратовская область, Ивантеевский район, село Ивантеевка, ул. Московская, д.1 (Ивантеевская ЦРБ Поликлиника)		0101000020E61000007E1CCD91958D4840CA880B40A3224A40
83110	7	73	633	4430	30435	\N	52.270606999999998	Саратовская область, Ивантеевский район, село Ивантеевка, ул. Кооперативная, д. 11 А (Дом кино Колос)		0101000020E61000007E1CCD91958D4840CA880B40A3224A40
83114	7	73	633	4430	31418	\N	52.270606999999998	Саратовская область, Ивантеевский район, село Ивантеевка, ул. Строителей, д.16 (МОУ Гимназия с. Ивантеевка)		0101000020E61000007E1CCD91958D4840CA880B40A3224A40
83115	7	73	633	4707	31142	\N	52.201787000000003	Саратовская область, Ивантеевский район, село Ивановка, ул. Кооперативная, д. 49 (сельский Дом Культуры)		0101000020E6100000081EDFDE35A6484005E10A28D4194A40
83106	7	73	633	4211	31402	\N	52.321283999999999	Саратовская область, Ивантеевский район, поселок Знаменский, ул. Центральная, д. 20 А (сельский Дом Культуры)		0101000020E61000006747AAEFFC944840315D88D51F294A40
83117	7	73	633	4855	30440	\N	52.338433000000002	Саратовская область, Ивантеевский район, поселок Восточный, ул. Зеленая, д. 44 (сельский клуб)		0101000020E6100000FF21FDF675C848408F71C5C5512B4A40
83104	7	73	633	4108	30624	\N	52.429344	Саратовская область, Ивантеевский район, село Бартеневка, ул. Победы, д. 42 (сельский Дом Культуры)		0101000020E6100000E7DF2EFB75894840EE5D83BEF4364A40
83107	7	73	633	4306	30760	\N	52.301496	Саратовская область, Ивантеевский район, село Арбузовка, ул. Арбузовская, д. 15 А (МОУ ООШ с.Арбузовка)		0101000020E61000009757AEB7CD864840FAEFC16B97264A40
83070	7	73	267	2222	30937	\N	51.490177000000003	Саратовская область, Ершовский район, поселок Южный, Здание МОУ СОШ, ул. Центральная,4		0101000020E6100000E95F92CA143348402E20B41EBEBE4940
94375	7	73	267	3033	30901	\N	51.411749999999998	Саратовская область, Ершовский район, село Чугунка, ул. Юбилейная, 2А Здание МОУ ООШ		0101000020E610000087DBA16131EE474062105839B4B44940
83086	7	73	267	3144	30173	\N	51.499867000000002	Саратовская область, Ершовский район, село Чкалово, ул.60 лет СССР, Здание МОУ СОШ		0101000020E610000058E6ADBA0EEF4740C1AC50A4FBBF4940
83075	7	73	267	2513	31098	\N	51.024783999999997	Саратовская область, Ершовский район, село Черная Падина, Здание МОУ ООШ, ул.Советская,34		0101000020E610000061FA5E4370F0474066BB421F2C834940
83101	7	73	267	3314	31281	\N	51.638114999999999	Саратовская область, Ершовский район, село Чапаевка, ул.Школьная, 111А Здание МОУ СОШ		0101000020E6100000C03C64CA87064840240B98C0ADD14940
83072	7	73	267	2349	30761	\N	51.345252840609902	Саратовская область, Ершовский район, поселок Целинный, Здание администрации МО, ул.Ленина,4	Россия, Саратовская область, Ершовский район, село Целинный	0101000020E610000049861C5BCF42484046EC134031AC4940
83065	7	73	267	1915	31254	\N	51.338649975340701	Саратовская область, Ершовский район, поселок Учебный, ул. Центральная, 24, здание администрации	Россия, Саратовская область, Ершовский район, село Учебный	0101000020E61000001E34BBEEAD1C48402C6519E258AB4940
83067	7	73	267	2053	\N	\N	51.373747000000002	Саратовская область, Ершовский район, поселок Тулайково, здание конторы ОСОЗ Ершовское		0101000020E610000006F7031E181E484033FD12F1D6AF4940
83097	7	73	267	53138	30193	\N	50.9325560963049	Саратовская область, Ершовский район, поселок Трудовой, ул.Центральная,28 . СДК  (Здание Дом кульутры)	Россия, Саратовская область, Ершовский район, село Трудовое	0101000020E6100000D236FE44651F484023D8B8FE5D774940
83089	7	73	267	3317	31111	\N	51.317984000000003	Саратовская область, Ершовский район, село Сокорная Балка, ул Центральная,43  Здание МОУ ООШ		0101000020E610000092921E86560B48405D5320B3B3A84940
83071	7	73	267	2285	30363	\N	51.482897999999999	Саратовская область, Ершовский район, село Семено-Полтавка, Здание МОУ СОШ, ул.Семеново-Полтавская,57		0101000020E610000033DE567A6D444840E3A6069ACFBD4940
83078	7	73	267	2682	30776	\N	51.660215999999998	Саратовская область, Ершовский район, поселок Садовый, МОУ НОШ, ул.Рабочая,7,  Здание детского сада		0101000020E610000098A432C51C2A4840E12538F581D44940
83100	7	73	267	3889	31121	\N	51.319662000000001	Саратовская область, Ершовский район, село Рефлектор, ул.Ленина,13 СДК (Здание МОУ СОШ)		0101000020E610000057CD7344BE3F484011E335AFEAA84940
83068	7	73	267	2118	\N	\N	51.433619	Саратовская область, Ершовский район, поселок Полуденный, здание МОУ СОШ (школы)		0101000020E610000010406A13272748404DF6CFD380B74940
83098	7	73	267	3796	30397	\N	51.202489999999997	Саратовская область, Ершовский район, село Перекопное, ул.Пылайкина,65 Здание МОУ СОШ		0101000020E6100000B4006DAB590748402EE23B31EB994940
83092	7	73	267	3493	30182	\N	51.105811000000003	Саратовская область, Ершовский район, село Осинов-Гай, ул.Школьная,9 Здание МОУ СОШ		0101000020E61000009BABE639224548404E4700378B8D4940
83095	7	73	267	3651	30609	\N	50.919792999999999	Саратовская область, Ершовский район, село Орлов-Гай, ул.Саловая,46 Здание детского сада МДОУ Калинка		0101000020E6100000AA0A0DC4B21948407C0BEBC6BB754940
83096	7	73	267	3651	30785	\N	50.919792999999999	Саратовская область, Ершовский район, село Орлов-Гай, ул.Кривошеева, 45А Здание МОУ СОШ		0101000020E6100000AA0A0DC4B21948407C0BEBC6BB754940
83073	7	73	267	29790	31664	\N	51.326878000000001	Саратовская область, Ершовский район, поселок Новый, Здание начальной школы, ул.Рабочая,15	Россия, Саратовская область, Ершовский район, село Новый	0101000020E61000006D382C0DFC48484015E46723D7A94940
83093	7	73	267	3531	30386	\N	51.663401	Саратовская область, Ершовский район, поселок Новоселький,  ул.Заводская,30 Здание МОУ СОШ		0101000020E610000024253D0CAD0E48401D91EF52EAD44940
83091	7	73	267	3434	30603	\N	51.073740000000001	Саратовская область, Ершовский район, село Новорепное, ул. Советская,44 Здание МОУ СОШ		0101000020E61000007A1B9B1DA93648401A34F44F70894940
83088	7	73	267	3278	31288	\N	51.319166000000003	Саратовская область, Ершовский район, село Новая Краснянка, ул Братиславская, 28А контора к-за 18 п/с (Здание Дома культуры)		0101000020E61000009E29745E631D484061FF756EDAA84940
83085	7	73	267	3081	9829	\N	51.446418274158802	Саратовская область, Ершовский район, село Нестерово, ул.Новая,1А Здание Дома культуры	Россия, Саратовская область, Ершовский район, село Нестерово	0101000020E6100000649126DE01FA4740412C9B3924B94940
83087	7	73	267	3211	30596	\N	51.243425999999999	Саратовская область, Ершовский район, село Моховое, ул.25 партсъезда, Здание МОУ СОШ		0101000020E61000001D39D21918214840807F4A95289F4940
83079	7	73	267	2733	30581	\N	51.668255000000002	Саратовская область, Ершовский район, поселок Михайло-Вербовка, МОУ НОШ, ул. Почтовая, 2А, здание начальной школы		0101000020E61000008A5B0531D01F4840BA313D6189D54940
83083	7	73	267	2971	30584	\N	51.444173999999997	Саратовская область, Ершовский район, село Миусс, ул. Комсомольская,20 Здание МОУ СОШ		0101000020E6100000D0285DFA97F64740E3DD91B1DAB84940
83081	7	73	267	2848	30165	\N	51.470674000000002	Саратовская область, Ершовский район, село Марьевка, Здание МОУ ООШ, ул. Молодежная,2А		0101000020E610000078280AF4891A4840EC89AE0B3FBC4940
82852	7	73	595	24037	\N	\N	51.438892000000003	Саратовская область, Балашовский район, п. Первомайский, Дом культуры		0101000020E610000073F22213F0954540EF3CF19C2DB84940
83094	7	73	267	26181	30894	\N	51.575192999999999	Саратовская область, Ершовский район, село Лобки - 2е, ул.Прудовая, 112 , Здание МОУ СОШ		0101000020E6100000677DCA3159184840AEF199EC9FC94940
83090	7	73	267	3377	31114	\N	51.347994999999997	Саратовская область, Ершовский район, поселок Лесной,  ул Молодежная,121 Здание сельского клуба (начальной школы)		0101000020E6100000F50F2219720A4840F415A4198BAC4940
83077	7	73	267	2617	31104	\N	51.631390000000003	Саратовская область, Ершовский район, поселок Кушумский, Здание МОУ СОШ, ул.Советская,1		0101000020E6100000F435CB65A32B4840BF823463D1D04940
83074	7	73	267	2453	30579	\N	51.052711000000002	Саратовская область, Ершовский район, село Краснянка, Здание МОУ СОШ, пер.Больничный,23		0101000020E6100000EBC9FCA36FF64740DA91EA3BBF864940
83082	7	73	267	2913	31261	\N	51.392116999999999	Саратовская область, Ершовский район, поселок Красный боец,ул. Центральная, СДК. З(дание МОУ СОШ)		0101000020E6100000290989B48D134840529ACDE330B24940
83055	7	73	267	1120	31069	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Юбилейная, д. 2А, здание центра Досуга и кино  (ГДК)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83062	7	73	267	1120	31475	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, здание Вагонного ремонтного депо, ул Урожайная, 1В		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83064	7	73	267	1120	31152	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Ремонтная, д. 1 (контора ООО МТС Ершовская)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83058	7	73	267	1120	30340	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Некрасова (здание МОУ СОШ №3 )		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83061	7	73	267	1120	30921	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Мелиоративная, д. 41 (здание УГАДН)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83060	7	73	267	1120	30921	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Мелиоративная, д. 19 (поликлиника)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83057	7	73	267	1120	31407	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Локомотивная, д. 96 (ДДТ)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83059	7	73	267	1120	31483	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Крупской (здание РОСТО ДОСААФ)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83053	7	73	267	1120	31070	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Краснопартизанская, д. 4 (РДК)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83063	7	73	267	1120	30754	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, здание МОУ СОШ №5 Дорожный проезд,2		0101000020E610000068D0D03FC1234840967A1684F2AC4940
94371	7	73	267	1120	30530	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул.М. Горького, 2а (МОУ СОШ №2)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83054	7	73	267	1120	31082	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. Гагарина (здание Дом кино Юность)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
83056	7	73	267	1120	31080	\N	51.350415886271698	Саратовская область, Ершовский район, город Ершов, ул. Вокзальная, д. 69 (МОУ СОШ № 4)	Россия, Саратовская область, Ершовский район, Ершов	0101000020E6100000ABCE6A813D24484061FF756EDAAC4940
94370	7	73	267	1120	30914	\N	51.351151000000002	Саратовская область, Ершовский район, город Ершов, ул. 22 Партсъезда,д.23 (МОУ СОШ № 1)		0101000020E610000068D0D03FC1234840967A1684F2AC4940
94373	7	73	267	2578	31349	\N	51.058988999999997	Саратовская область, Ершовский район, село Еремеевка, Здание МОУ ООШ, ул. Ленина,10а		0101000020E61000004F04711E4E06484070E998F38C874940
83102	7	73	267	3981	30628	\N	51.606001999999997	Саратовская область, Ершовский район, село Дмитриевка, ул.Молодежная 10А,  Здание МОУ СОШ		0101000020E6100000E7E44526E0FD4740C1A7397991CD4940
94374	7	73	267	2806	30946	\N	51.535736	Саратовская область, Ершовский район, село Верхний Кушум, Здание МОУ СОШ, ул.Молодежная,3а		0101000020E61000002C0C91D3D72548401AA54BFF92C44940
83099	7	73	267	3838	31395	\N	51.110284999999998	Саратовская область, Ершовский район, село Васильевка, ул. Школьная,6 Здание МОУ СОШ		0101000020E61000001079CBD58F074840A31EA2D11D8E4940
94372	7	73	267	2164	30316	\N	51.378126999999999	Саратовская область, Ершовский район, село Антоновка, Здание МОУ СОШ, ул.Парковая,6		0101000020E610000058C9C7EE02314840075E2D7766B04940
83037	7	73	28	253	30799	\N	51.846026999999999	Саратовская область, Екатериновский район, посёлок Юбилейный, Адрес помещения для голосования: ул. Юбилейная, д. 1 (здание МОУ СОШ п.Юбилейный), Адрес УИК: ул. Новосельская, д. 8 (бывшая администрация округа)		0101000020E6100000DE54A4C2D82646403944DC9C4AEC4940
83036	7	73	28	209	30414	\N	51.781005	Саратовская область, Екатериновский район, село Упоровка, Адрес помещения для голосования: ул. Ленинская, д. 71а (здание Упоровского ФАП), Адрес УИК: ул. Ленинская, д. 71а (здание Упоровского ФАП)		0101000020E6100000A4703D0AD72346409981CAF8F7E34940
83050	7	73	28	1064	30420	\N	51.950994000000001	Саратовская область, Екатериновский район, село Сластуха, Адрес помещения для голосования: ул. Молодёжная, д. 7 (здание МОУ СОШ с.Сластуха), Адрес УИК: ул. Советская, д. 79 (библиотека с.Сластуха)		0101000020E61000005B7A34D5934546409B58E02BBAF94940
83048	7	73	28	959	30801	\N	51.994301999999998	Саратовская область, Екатериновский район, посёлок Прудовой, Адрес помещения для голосования: ул. Молодёжная, д. 4 (здание МОУ СОШ п.Прудовой), Адрес УИК: ул. Пионерская, д. 14 (здание администрации МО)		0101000020E61000001D56B8E523314640772CB64945FF4940
83049	7	73	28	992	30416	\N	52.012382000000002	Саратовская область, Екатериновский район, село Переезд, Адрес помещения для голосования: ул. Центральная, д. 38а (здание Переездинской ООШ), Адрес УИК: ул. Центральная, д. 38а (здание Переездинской ООШ)		0101000020E6100000863AAC70CB3546409087BEBB95014A40
83046	7	73	28	830	30433	\N	51.951754000000001	Саратовская область, Екатериновский район, село Новоселовка, Адрес помещения для голосования: ул. Центральная, д. 57а (здание Новосёловского СДК), Адрес УИК: ул. Центральная, д. 18 (здание администрации МО)		0101000020E61000003E0796236422464029EB3713D3F94940
83039	7	73	28	393	30734	\N	52.367519999999999	Саратовская область, Екатериновский район, деревня Михайловка, Адрес помещения для голосования: ул. Кипецкая, 2а (здание МОУ СОШ с.Кипцы), Адрес УИК: ул. Советская, д. 66а (здание администрации МО)		0101000020E610000050189469345146401E5036E50A2F4A40
83047	7	73	28	885	31289	\N	52.036915	Саратовская область, Екатериновский район, деревня Малая Екатериновка, Адрес помещения для голосования: ул. Майская, д. 57 (здание библиотеки д.Малая Екатериновка), Адрес УИК: ул. Майская, д. 57 (библиотека д.М.Екатериновка)		0101000020E61000004D2CF015DD284640ADDD76A1B9044A40
83044	7	73	28	714	30636	\N	52.290568	Саратовская область, Екатериновский район, село Кручи, Адрес помещения для голосования: ул. Школьная, д. 9 (здание МОУ СОШ с.Кручи), Адрес УИК: ул. Школьная, д. 9 (МОУ СОШ с.Кручи)		0101000020E610000070EA03C93B614640CFA10C5531254A40
83045	7	73	28	755	30772	\N	52.127349000000002	Саратовская область, Екатериновский район, село Крутояр, Адрес помещения для голосования: ул. Школьная, 22б (здание МОУ СОШ с.Крутояр), Адрес УИК: ул. Школьная, д. 22а (здание администрации МО)		0101000020E61000001633C2DB83544640D316D7F84C104A40
83043	7	73	28	644	30327	\N	52.364457000000002	Саратовская область, Екатериновский район, село Комаровка, Адрес помещения для голосования: ул. Угловая, д. 31а (здание МОУ СОШ с.Комаровка), Адрес УИК: ул. Угловая, д. 30 (здание Комаровского ФАП)		0101000020E610000031410DDFC26446402EE6E786A62E4A40
83040	7	73	28	467	31286	\N	51.868988999999999	Саратовская область, Екатериновский район, село Колено, Адрес помещения для голосования: ул. Новая, д. 19 (здание Коленовского СДК), Адрес УИК: ул. Советская, д. 22 (здание администрации МО)		0101000020E610000025085740A10E4640B8CA13083BEF4940
83042	7	73	28	586	\N	\N	51.849504000000003	Саратовская область, Екатериновский район, село Киселевка, Адрес помещения для голосования: ул. Рабочая, д. 30а (здание Киселевской начальной школы), Адрес УИК: ул. Рабочая, д. 30а (Киселевская школа)	Россия, Саратовская область, Екатериновский район, село Киселевка	0101000020E6100000922232ACE21546401DE90C8CBCEC4940
83038	7	73	28	330	30877	\N	52.131411999999997	Саратовская область, Екатериновский район, поселок Индустриальный, Адрес помещения для голосования: ул. Советская, д. 11б (здание МОУ СОШ п.Индустриальный), Адрес УИК: ул. Кооперативная, д. 10 (здание администрации МО)		0101000020E6100000EA961DE21F2C4640A626C11BD2104A40
83033	7	73	28	32461	30413	\N	52.459941000000001	Саратовская область, Екатериновский район, село Ивановка, Адрес помещения для голосования: ул. Советская, д. 44 (здание МОУ СОШ с.Ивановка), Адрес УИК: ул. Заречная, д. 39 (бывшая администрация округа)		0101000020E6100000640795B88E474640768BC058DF3A4A40
83026	7	73	28	30924	30650	\N	52.052695999999997	Саратовская область, Екатериновский район, р.п.Екатериновка, Адрес помещения для голосования: ул.Первомайская, д. 43 (здание управления образования администрации района), Адрес УИК: ул. Молодёжная, д. 43 (здание администрации МО)		0101000020E610000060730E9E092D4640A45016BEBE064A40
83025	7	73	28	30924	9654	\N	52.052695999999997	Саратовская область, Екатериновский район, р.п.Екатериновка, Адрес помещения для голосования: ул. Молодёжная, д. 21 (здание отдела ЗАГС), Адрес УИК: ул. Молодёжная, д. 21 (здание администации р.п.Екатериновка, помещение отдела ЗАГС)		0101000020E610000060730E9E092D4640A45016BEBE064A40
83027	7	73	28	30924	31348	\N	52.052695999999997	Саратовская область, Екатериновский район, р.п.Екатериновка, Адрес помещения для голосования: ул. Мичуринская, д. 68 (здание МОУ СОШ №2 р.п.Екатериновка), Адрес УИК: ул.Молодежная, д. 21 (администрация МО)		0101000020E610000060730E9E092D4640A45016BEBE064A40
83041	7	73	28	510	30973	\N	51.93526	Саратовская область, Екатериновский район, село Гривки, Адрес помещения для голосования: ул. Октябрьская, д. 20А (здание Гривского сельского клуба), Адрес УИК: ул. Октябрьская, д. 20А (здание Гривского клуба)		0101000020E6100000D61BB5C2F40D4640E4A08499B6F74940
83035	7	73	28	122	30634	\N	51.853465	Саратовская область, Екатериновский район, село Галахово, Адрес помещения для голосования: ул. Петра Орешина, д. 42 (здание МОУ СОШ с.Галахово), Адрес УИК: ул. Петра Орешина, д. 40 (здание администрации МО)		0101000020E610000074B33F506E374640ECA353573EED4940
83034	7	73	28	34	30633	\N	52.017842000000002	Саратовская область, Екатериновский район, село Вязовка, Адрес помещения для голосования: ул. Центральная, д. 34 (здание Вязовского СДК), Адрес УИК: ул. Молодежная, д. 30 (здание детсада Малыш)		0101000020E6100000C020E9D32A4C4640643F8BA548024A40
79754	7	72	\N	55034	77339	\N	53.0821549251486	город Новокуйбышевск, пропект Победы, 7	Россия	0101000020E610000024809BC58BF34840F819170E848A4A40
83031	7	73	28	32367	31126	\N	52.293922999999999	Саратовская область, Екатериновский район, село Воронцовка, Адрес помещения для голосования: ул. Верхняя. д.7 (здание МОУ СОШ с.Воронцовка), Адрес УИК: ул. Верхняя, д. 44 (бывшая администрация округа)		0101000020E61000003A3C84F1D32E46406745D4449F254A40
83030	7	73	28	32323	30409	\N	52.350520000000003	Саратовская область, Екатериновский район, село Бутурлинка, Адрес помещения для голосования: ул.Центральная, д. 63А (здание МОУ СОШ с.Бутурлинка), Адрес УИК: ул. Центральная, д. 49 (бывшая администрация округа)		0101000020E6100000C11DA8531E414640064CE0D6DD2C4A40
83032	7	73	28	32453	31400	\N	52.363022000000001	Саратовская область, Екатериновский район, село Бакуры, Адрес помещения для голосования: ул. Тургенева, д. 5 (здание МОУ СОШ с.Бакуры), Адрес УИК: ул. Тургенева, д. 8 (администрация Бакурского МО)		0101000020E6100000B493C151F258464040DD4081772E4A40
83029	7	73	28	32286	31412	\N	52.284056999999997	Саратовская область, Екатериновский район, село Андреевка, Адрес помещения для голосования: ул.Рабочая, д. 22 (здание МОУ СОШ с.Андреевка), Адрес УИК: ул. Рабочая, д. 18а (администрация МО)		0101000020E610000001A3CB9BC34946409599D2FA5B244A40
83028	7	73	28	16562	30726	\N	52.201875000000001	Саратовская область, Екатериновский район, село Альшанка, Адрес помещения для голосования: ул. Революционная, д. 33А (здание МОУ СОШ с.Альшанка), Адрес УИК: ул. Революционная, д. 52 (здание СХПК Альшанский)		0101000020E610000013B69F8CF1434640A4703D0AD7194A40
83010	7	73	239	31419	31202	\N	52.515793000000002	Саратовская область, Духовницкий район, с. Теликовка, ул. Ленина, д. 19 (здание Дома культуры)		0101000020E61000004356B77A4E304840BC40498105424A40
83022	7	73	239	32021	30725	\N	52.259484	Саратовская область, Духовницкий район, с. Софьинка, ул. Комсомольская, д. 1 (здание школы)		0101000020E6100000024BAE62F1154840EAEA8EC536214A40
83020	7	73	239	31932	30724	\N	52.319605000000003	Саратовская область, Духовницкий район, д. Росляково, ул. Гагарина, д. 13 (здание Дома культуры)		0101000020E6100000D847A7AE7C204840AD510FD1E8284A40
83023	7	73	239	32027	30890	\N	52.254263999999999	Саратовская область, Духовницкий район, п. Полеводинский, ул. Заовражная, д. 4 (здание школы)		0101000020E6100000DF4E22C2BF3C48406B4606B98B204A40
83018	7	73	239	31799	30512	\N	52.348478999999998	Саратовская область, Духовницкий район, с. Озерки, ул. Гагарина, д. 27 (здание Дома культуры)		0101000020E61000003BE0BA6246284840E02BBAF59A2C4A40
83024	7	73	239	32066	\N	\N	52.171706	Саратовская область, Духовницкий район, с. Новозахаркино, ул. Молодёжная, д. 1 (здание Дома культуры)	Россия, Саратовская область, Духовницкий район, село Новозахаркино	0101000020E61000009A0986730D3D484074435376FA154A40
83014	7	73	239	17626	30393	\N	52.499513999999998	Саратовская область, Духовницкий район, с. Никольское, ул. Советская, д. 57 А (здание Дома культуры)		0101000020E61000005376FA415D50484073F22213F03F4A40
83017	7	73	239	952	30539	\N	52.408302999999997	Саратовская область, Духовницкий район, с. Липовка, ул. Советская, д. 7 В (здание Дома культуры)		0101000020E61000000E2F88484D334840E9EDCF4543344A40
83016	7	73	239	31743	31045	\N	52.345387000000002	Саратовская область, Духовницкий район, с. Левенка, ул. Ленина, д. 44 (здание школы)		0101000020E61000003C873254C542484056BB26A4352C4A40
83006	7	73	239	29514	31040	\N	52.487170999999996	Саратовская область, Духовницкий район, р.п. Духовницкое, пл. 60 лет Советской Армии, д. 7 (здание школы)		0101000020E61000003A419B1C3E1B4840A1478C9E5B3E4A40
83007	7	73	239	29514	30504	\N	52.487170999999996	Саратовская область, Духовницкий район, р.п. Духовницкое, ул. Чернышевского, д. 32 (Дом Детского Творчества)		0101000020E61000003A419B1C3E1B4840A1478C9E5B3E4A40
83009	7	73	239	29514	30257	\N	52.487170999999996	Саратовская область, Духовницкий район, р.п. Духовницкое, ул. Ленина, д. 10 Б (здание РДК)		0101000020E61000003A419B1C3E1B4840A1478C9E5B3E4A40
83008	7	73	239	29514	31208	\N	52.487170999999996	Саратовская область, Духовницкий район, р.п. Духовницкое, ул. Красноармейская, д. 85 (управление образования)		0101000020E61000003A419B1C3E1B4840A1478C9E5B3E4A40
82983	7	73	239	29514	31017	\N	52.487170999999996	Саратовская область, Духовницкий район, р.п. Духовницкое, ул. Заводская, д. 1 (здание ветстанции)		0101000020E61000003A419B1C3E1B4840A1478C9E5B3E4A40
83019	7	73	239	987	31360	\N	52.419212000000002	Саратовская область, Духовницкий район, с. Дмитриевка, ул. Ленина, д. 23 Б (здание Дома культуры)		0101000020E61000009163EB19C21948409E0B23BDA8354A40
83012	7	73	239	31531	30987	\N	52.599578000000001	Саратовская область, Духовницкий район, с. Григорьевка, ул. Пушкина, д. 30 (здание школы)		0101000020E6100000CADFBDA3C64A484057B3CEF8BE4C4A40
83021	7	73	239	53233	31572	\N	52.285393332235003	Саратовская область, Духовницкий район, с. Горяйновка, ул. Советская, д. 81 (здание школы)	Россия, Саратовская область, Духовницкий район, село Горяиновка	0101000020E6100000710514EAE91D4840F0C000C287244A40
83013	7	73	239	31572	31459	\N	52.543717000000001	Саратовская область, Духовницкий район, с. Брыковка, ул. Грибанова, д. 56 (здание Дома культуры)		0101000020E6100000C7F2AE7AC04A4840BEA3C68498454A40
83015	7	73	239	31668	31118	\N	52.451962000000002	Саратовская область, Духовницкий район, с. Богородское, ул. Мира, д. 2 (здание школы)		0101000020E61000008C9FC6BDF965484073840CE4D9394A40
83011	7	73	239	31520	30885	\N	52.614747999999999	Саратовская область, Духовницкий район, с. Березовая Лука, ул. Кирова, д. 42 (здание Дома культуры)		0101000020E61000007653CA6B2538484005A4FD0FB04E4A40
82993	7	73	844	30609	31464	\N	51.173513	Саратовская область, Дергачевский район, поселок Тимонин, ул.Центральная, д.70 (здание МОУ СОШ)		0101000020E610000032AD4D637B9D484026378AAC35964940
83005	7	73	844	6284	30678	\N	51.201096	Саратовская область, Дергачевский район, поселок Советский, ул.Целинная, д.1А (здание СДК)		0101000020E6100000E481C8224D6448409FAD8383BD994940
83004	7	73	844	31125	30712	\N	50.915346999999997	Саратовская область, Дергачевский район, село Сафаровка, ул.Комсомольская, д.56 (здание МОУ СОШ)		0101000020E610000031074147AB704840F0BE2A172A754940
83003	7	73	844	6280	31153	\N	51.250129999999999	Саратовская область, Дергачевский район, село Петропавловка, ул.Советская, д.51А (здание МОУ СОШ)		0101000020E61000004FCC7A3194654840CEDF844204A04940
82998	7	73	844	30836	30702	\N	51.357804999999999	Саратовская область, Дергачевский район, поселок Первомайский, пер. Школьный, д.5 (здание МОУ СОШ)		0101000020E6100000725303CDE772484032ACE28DCCAD4940
83002	7	73	844	31037	31199	\N	51.036673999999998	Саратовская область, Дергачевский район, поселок Орошаемый, пер. Школьный, д.1 (здание МОУ СОШ)		0101000020E61000003259DC7F64624840874ECFBBB1844940
83001	7	73	844	30973	31036	\N	50.950507999999999	Саратовская область, Дергачевский район, поселок Октябрьский, ул.Школьная, д.37 (здание МОУ СОШ)		0101000020E6100000EC18575C1C9148400E4B033FAA794940
82994	7	73	844	30615	30487	\N	51.241075000000002	Саратовская область, Дергачевский район, село Новоросляевка, ул.Данукалова, д.46 (здание МОУ СОШ)		0101000020E6100000605B3FFD678148400D71AC8BDB9E4940
82999	7	73	844	29462	30871	\N	50.904397000000003	Саратовская область, Дергачевский район, поселок Мирный, ул.Советская, д.21А (здание МОУ СОШ)		0101000020E6100000BC783F6EBF424840DECCE847C3734940
83000	7	73	844	30929	31192	\N	50.899779000000002	Саратовская область, Дергачевский район, поселок Красноозерный, ул.Школьная, д.19 (здание МОУ СОШ)		0101000020E6100000FC372F4E7C914840555051F52B734940
82997	7	73	844	30831	31448	\N	51.464126	Саратовская область, Дергачевский муниципальный район, село Камышево, ул.Школьная, д.10 (здание МОУ СОШ)		0101000020E610000023A30392B0734840959C137B68BB4940
82996	7	73	844	30731	31191	\N	50.945684999999997	Саратовская область, Дергачевский район, поселок Зерновой, ул.Школьная, д.2 (здание МОУ СОШ)		0101000020E610000031EF71A609274840ACA8C1340C794940
82995	7	73	844	30667	31188	\N	51.425758000000002	Саратовская область, Дергачевский район, село Жадовка, ул.Ленинская, д.7 (здание МОУ СОШ)		0101000020E6100000D63A71395E9D48405401F73C7FB64940
82980	7	73	844	29202	30269	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, ул.Советская, д.86 (здание МОУ СОШ №1)		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82978	7	73	844	29202	30269	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, ул.Советская, д.76 (здание ДДТ)		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82981	7	73	844	29202	31155	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, ул.Сиреневая, д.14, Молодежный центр		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82984	7	73	844	29202	31014	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, ул.Садовая, д.39 (здание Заволжские ЭС)		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82979	7	73	844	29202	30852	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, ул.Олимпийская, д.6 (здание МДОУ Тополек)		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82985	7	73	844	29202	30427	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, ул.Набережная, д.2 (здание МОУ СОШ №2)		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82986	7	73	844	29202	67143	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, ул.Комсомольская, 80, адм.здание межрайонной инспекции федеральной налоговой службы России №49 по Саратовской области		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82982	7	73	844	29202	31384	\N	51.234810000000003	Саратовская область, Дергачевский район, р.п. Дергачи, пер.Веселый, д.6 (детский сад Дружба)		0101000020E6100000CD8FBFB4A86148400B630B410E9E4940
82992	7	73	844	30522	31022	\N	51.201818000000003	Саратовская область, Дергачевский район, село Демьяс, ул.Комсомольская, д.58 (здание МОУ СОШ)		0101000020E61000002D978DCEF98F484040DF162CD5994940
82991	7	73	844	30517	30861	\N	51.021566	Саратовская область, Дергачевский район,  поселок Восточный, ул.Школьная, д.6 (здание МОУ СОШ)		0101000020E610000044DC9C4A06A448404F5AB8ACC2824940
82990	7	73	844	30420	30649	\N	50.913137999999996	Саратовская область, Дергачевский район,  село Верхазовка, ул.Комсомольская, д.68 (здание МОУ СОШ)		0101000020E6100000E7C6F484256248400F5EBBB4E1744940
82987	7	73	844	30311	31018	\N	51.289079999999998	Саратовская область, Дергачевский район, село Васильевка, ул.Центральная, д.44 (здание детского сада)		0101000020E61000002655DB4DF0554840BEF6CC9200A54940
82989	7	73	844	29468	31316	\N	51.319910472866397	Саратовская область, Дергачевский район, село Антоновка, ул.Набережная, д.2Б (здание СДК)	Россия, Саратовская область, Дергачевский район, село Антоновка	0101000020E6100000F2B391EBA6664840E9D495CFF2A84940
82988	7	73	844	30315	31180	\N	51.100200999999998	Саратовская область, Дергачевский район, село Алтата, ул.Школьная, д.1 (здание МОУ СОШ)		0101000020E61000008D0B0742B25C48406403E962D38C4940
82961	7	73	742	25840	30838	\N	51.789679999999997	Саратовская область, Воскресенский район, с.Чардым, административное здание Елшанского МО, ул. Советская,30		0101000020E6100000548CF337A12A47401327F73B14E54940
82964	7	73	742	25933	30466	\N	51.801099000000001	Саратовская область, Воскресенский район, с.Усовка, здание СК, ул. Набережная,36		0101000020E610000024287E8CB93F4740DDED7A698AE64940
82966	7	73	742	5225	30467	\N	51.916981999999997	Саратовская область, Воскресенский район, с.Студеновка, здание МОУ СОШ, ул. Тростянка,25а		0101000020E6100000679DF17D71494740A5828AAA5FF54940
72824	7	71	\N	16298	51718	\N	56.759227000000003	г.Чайковский, ул.Кабалевского, д.32		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
82960	7	73	742	25760	31154	\N	51.841631	Саратовская область, Воскресенский район, с.Славянка, дом культуры ул.Центральная,21		0101000020E610000006668522DD1F47405F268A90BAEB4940
82967	7	73	742	26024	30469	\N	51.988684999999997	Саратовская область, Воскресенский район, с.Синодское, Синодский СДК, ул. Клочкова,30		0101000020E6100000F5F6E7A221554740DB85E63A8DFE4940
82973	7	73	742	53149	30309	\N	51.957477519529199	Саратовская область, Воскресенский район, с.Ново-Алексеевка, СК, ул.70 лет Октября,35	Россия, Саратовская область, Воскресенский район, село Новая Алексеевка	0101000020E6100000EB8CEF8B4B674740DB519CA38EFA4940
82968	7	73	742	26071	30258	\N	51.969839999999998	Саратовская область, Воскресенский район, с.Медяниково, Медяниковский СК, ул. Центральная, 29		0101000020E610000087DD770C8F574740232D95B723FC4940
82970	7	73	742	5323	9747	\N	51.827973158083701	Саратовская область, Воскресенский район, с.Кошели, МОУ НОШ, ул.Вишневая,10	Россия, Саратовская область, Воскресенский район, село Кошели	0101000020E6100000D7169E978A4B47404A7CEE04FBE94940
82962	7	73	742	25845	31005	\N	51.867604	Саратовская область, Воскресенский район, с.Коммуна, сельский клуб, ул. Запрудная,9		0101000020E610000017B6662B2F2F47407CF0DAA50DEF4940
82975	7	73	742	53225	31524	\N	51.924800184422203	Саратовская область, Воскресенский район, с.Кадомка, СК, ул.Луговая,17		0101000020E6100000780AB952CF6E47409FABADD85FF64940
82963	7	73	742	5210	30676	\N	51.815353999999999	Саратовская область, Воскресенский район, с.Елшанка, здание СДК, ул. Школьная,39б		0101000020E6100000CEFBFF3861324740D65416855DE84940
82977	7	73	742	29733	30479	\N	51.825130000000001	Саратовская область, Воскресенский район, с.Воскресенское, здание детской школы искусств, ул.Шеина,25		0101000020E6100000BD361B2B3177474068791EDC9DE94940
82976	7	73	742	29733	67121	\N	51.825130000000001	"Саратовская область, Воскресенский район, с.Воскресенское, адм.здание ГБУ ""УСЗН"", ул. Партизанская,10"		0101000020E6100000BD361B2B3177474068791EDC9DE94940
82972	7	73	742	29570	31236	\N	51.993364999999997	Саратовская область, Воскресенский район, с.Булгаковка, СК, ул. Новая,43		0101000020E61000001EC539EAE86E4740DAFE959526FF4940
82969	7	73	742	26072	30924	\N	51.861603000000002	Саратовская область, Воскресенский район, с.Букатовка, МОУ СОШ, ул.Школьная,13		0101000020E610000015C78157CB4D47405891D10149EE4940
82974	7	73	742	29643	31008	\N	51.936703999999999	Саратовская область, Воскресенский район, с.Биктимировка, СК, ул.Мусы Джалиля,29		0101000020E61000001D3D7E6FD36B47402504ABEAE5F74940
82971	7	73	742	26137	30684	\N	51.745413999999997	Саратовская область, Воскресенский район, с.Березняки, Березняковский СК, ул.Набережная, 3а		0101000020E6100000BED87BF14559474082FDD7B969DF4940
82965	7	73	742	25942	31160	\N	51.904768170632998	Саратовская область, Воскресенский район, с.Андреевка, здание СК, ул. Луговая,20	Россия, Саратовская область, Воскресенский район, село Андреевка	0101000020E6100000336C94F59B3F4740D13B1570CFF34940
82929	7	73	663	27625	30824	\N	52.345585	Саратовская область, Вольский район, село Юловая Маза, ул. Центральная, д. 40 (Детский сад)		0101000020E61000001C7A8B87F7BC47407C7E18213C2C4A40
83945	7	73	663	53217	31519	\N	52.119467702297001	Саратовская область, ЗАТО Шиханы, ул. Ленина, д. 22 (СОШ №12)	Россия, Саратовская область, Вольский район, поселок Шиханы	0101000020E6100000E62494BE109A4740927538BA4A0F4A40
83946	7	73	663	53217	31525	\N	52.114472410303598	Саратовская область, ЗАТО Шиханы, ул. Ленина, д. 8 (ДК Корунд)	Россия, Саратовская область, Вольский район, поселок Шиханы	0101000020E610000084D382177D9947406327BC04A70E4A40
82953	7	73	663	28694	30268	\N	52.117091000000002	Саратовская область, Вольский район, село Широкий Буерак, ул. Коммунистическая, д. 2-А (Школа)		0101000020E61000003DD34B8C65E24740F6D37FD6FC0E4A40
82933	7	73	663	27848	31420	\N	52.191023000000001	Саратовская область, Вольский район, село Шировка, ул. Ленина, д. 2-А (здание ФАП)		0101000020E6100000DA03ADC09063474054E4107173184A40
82950	7	73	663	28556	30246	\N	52.425142999999998	Саратовская область, Вольский район, р.п. Черкасское, ул. Московская, д. 5 (Дом культуры)		0101000020E61000004167D2A6EA9A4740C98FF8156B364A40
82958	7	73	663	28954	30741	\N	52.317430000000002	Саратовская область, Вольский район, село Труевая Маза, ул. Народная, д. 20-А (ФАП)		0101000020E61000000C5A48C0E8B247407862D68BA1284A40
82949	7	73	663	25706	31092	\N	52.058500000000002	Саратовская область, Вольский район, поселок Тополевый, ул. Санаторная, д. 5 (санаторий Светлана)		0101000020E61000009A249694BBCD4740736891ED7C074A40
82945	7	73	663	26656	30222	\N	52.084916999999997	Саратовская область, Вольский район, село Терса, ул. Талалихина, д. 1 (Библиотека сельхозтехникума)		0101000020E61000008690F3FE3FC44740EDEF6C8FDE0A4A40
82907	7	73	663	26656	31391	\N	52.084916999999997	Саратовская область, Вольский район, село Терса, ул. Советская, д. 26 (Школа)		0101000020E61000008690F3FE3FC44740EDEF6C8FDE0A4A40
82946	7	73	663	26656	31419	\N	52.084916999999997	Саратовская область, Вольский район, село Терса, ул. Красный Октябрь, д. 29 (Детский сад № 2)		0101000020E61000008690F3FE3FC44740EDEF6C8FDE0A4A40
82947	7	73	663	28429	30991	\N	52.153061000000001	Саратовская область, Вольский район, село Тепловка, ул. Талалихина, д. 154 (Детский сад)		0101000020E6100000F7B182DF86C0474083A5BA8097134A40
82943	7	73	663	28279	30812	\N	52.108851000000001	Саратовская область, Вольский район, село Талалихино, ул. Школьная, д. 2 (Школа)		0101000020E6100000BF47FDF50AD3474086915ED4EE0D4A40
82951	7	73	663	4521	31003	\N	52.500779999999999	Саратовская область, Вольский район, село Спасское, ул. Народная, д.28 (Молодежная), Клуб с. Спасское		0101000020E61000000F7C0C569C8A4740D53E1D8F19404A40
82939	7	73	663	28027	30239	\N	52.157663999999997	Саратовская область, Вольский район, поселок Сенной, пер Школьный, д. 8 (Школа № 2)		0101000020E6100000A8AAD0402C7B4740D6E07D552E144A40
82938	7	73	663	28027	30619	\N	52.157663999999997	Саратовская область, Вольский район, поселок Сенной, пер. Школьный, д. 3 (Школа № 47)		0101000020E6100000A8AAD0402C7B4740D6E07D552E144A40
82940	7	73	663	28027	30202	\N	52.157661361923701	Саратовская область, Вольский район, поселок Сенной, ул. Солопова, д. 17-А (Детский сад № 51)	Россия, Саратовская область, Вольский район, поселок Сенной	0101000020E6100000A912656F297B4740656D533C2E144A40
82941	7	73	663	28027	31287	\N	52.157663999999997	Саратовская область, Вольский район, поселок Сенной, ул. Привокзальная, д. 36 (ЖД Вокзал)		0101000020E6100000A8AAD0402C7B4740D6E07D552E144A40
82886	7	73	663	5117	31097	\N	52.521777	Саратовская область, Вольский район, село Покурлей, ул. Октябрьская, д.191 А (Школа)		0101000020E610000026C79DD2C1AE47400A67B796C9424A40
82956	7	73	663	28852	30277	\N	52.340297999999997	Саратовская область, Вольский район, село Покровка, ул. Центральная, д. 1-Г (Школа)		0101000020E61000008A9125732CA34740757286E28E2B4A40
82921	7	73	663	53163	\N	\N	52.098544277860398	Саратовская область, Вольский район, город Вольск, поселок Откормсовхоз, д. 11, кв. 8	Россия, Саратовская область, Вольский район	0101000020E61000009546CCECF3A64740C79BFC169D0C4A40
82957	7	73	663	28938	31446	\N	52.394038999999999	Саратовская область, Вольский район, село Осиновка, ул. Центральная, д. 79/1 (Школа - сад)		0101000020E6100000B69E211CB3AE47409D2CB5DE6F324A40
82937	7	73	663	28020	30394	\N	52.336672	Саратовская область, Вольский район, село Николаевка, ул. Молодежная, д. 19 (Школа)		0101000020E6100000742497FF908247404DBD6E11182B4A40
82935	7	73	663	27893	31302	\N	52.281433999999997	Саратовская область, Вольский район, село Нижняя Чернавка, ул. Пролетарская, д. 32 (здание администрации)		0101000020E6100000CF9F36AAD39D4740C1FD800706244A40
82959	7	73	663	28985	30671	\N	52.509802999999998	Саратовская область, Вольский район, село Междуречье, ул. Луговая, д. 23 (Школа)		0101000020E61000006553AEF02EC147408B33863941414A40
82934	7	73	663	27757	\N	\N	52.172478925238899	Саратовская область, Вольский район, станция Куриловка, ФАП ст. Куриловка	Россия, Саратовская область, Вольский район, село Куриловка	0101000020E6100000AB2006BAF66B4740971FB8CA13164A40
82931	7	73	663	27757	30674	\N	52.159773999999999	Саратовская область, Вольский район, село Куриловка, ул. Садовая, д. 20-А (Школа)		0101000020E610000086CB2A6C067047402460747973144A40
82807	7	73	663	22013	31285	\N	52.241951	Саратовская область, Вольский район, село Куликовка, ул. Рабочая, д. 1-А (Школа)		0101000020E61000008DF0F62004CC4740041E1840F81E4A40
82936	7	73	663	27954	31149	\N	52.269421999999999	Саратовская область, Вольский район, село Кряжим, пер. Школьный, д. 4 (Школа)		0101000020E6100000018750A5668F474055698B6B7C224A40
82578	7	73	663	10740	30484	\N	52.565055000000001	Саратовская область, Вольский район, село Колояр, ул. Ленина, д. 21 (Школа)		0101000020E61000001AC231CB9E7847407CB8E4B853484A40
82942	7	73	663	28207	\N	\N	52.167828999999998	Саратовская область, Вольский район, село Ключи, ул. Ленина, д. 49-Б (Школа)	Россия, Саратовская область, Вольский район, село Ключи	0101000020E61000008907944DB98847400229B16B7B154A40
82887	7	73	663	53200	31265	\N	52.089807999999998	Саратовская область, Вольский район, город Вольск, п. Клены пл. Радужная, д.2 (1) (ДК Факел)		0101000020E61000003F70952710BC4740A7751BD47E0B4A40
82952	7	73	663	28656	31164	\N	52.559300999999998	Саратовская область, Вольский район, село Калмантай, ул. Ленина, д. 29-А (Школа)		0101000020E6100000B56D1805C18F47405FCFD72C97474A40
94391	7	73	663	12166	30855	\N	52.200766000000002	Саратовская область, Энгельсский район, с. Заветное, здание МОУ СОШ, ул. Центральная, д. 16		0101000020E61000000AA0185932DF47400A1346B3B2194A40
82695	7	73	663	16252	30153	\N	52.527892000000001	Саратовская область, Вольский район, село Ерыкла, ул. Народная, д. 33 (Клуб)		0101000020E61000006EDFA3FE7A834740F7E80DF791434A40
82932	7	73	663	27762	30920	\N	52.207036000000002	Саратовская область, Вольский район, село Елховка, ул. Советская, д. 9-А (АКЦ с. Елховка)		0101000020E610000021AF0793E27947401E8CD827801A4A40
82948	7	73	663	28478	30573	\N	52.066350999999997	Саратовская область, Вольский район, село Девичьи Горки, ул. Колхозная, д. 16 (Библиотека)		0101000020E61000007CB60E0EF6D24740488787307E084A40
82890	7	73	663	53133	30395	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, поселок Большевик, д. 63 (МОУ СОШ № 4)		0101000020E6100000B05758703FAE4740295E656D53044A40
82895	7	73	663	53133	30170	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Здравоохранения, д. 50 (поликлиника № 1 МУЗ Вольская ЦРБ)		0101000020E6100000B05758703FAE4740295E656D53044A40
82461	7	73	663	53133	30575	\N	52.061738229668698	Саратовская область, Вольский район, город Вольск, ул. Дзержинского, д. 20 (ГОУ СО Волжанка)	Россия, Саратовская область, Вольск	0101000020E61000002025766D6FAB4740D175E107E7074A40
82917	7	73	663	53133	30346	\N	52.033796000000002	Саратовская область, Вольский район, город Вольск, ул. Водопьянова, д. 140 (Спортивная школа)		0101000020E6100000B05758703FAE4740295E656D53044A40
82930	7	73	663	27676	31414	\N	52.173181	Саратовская область, Вольский район, село Верхняя Чернавка, ул. Революционная, д. 35 (Школа)		0101000020E61000000919C8B3CBA34740F0A485CB2A164A40
82955	7	73	663	28847	31327	\N	52.190415000000002	Саратовская область, Вольский район, село Богородское, ул. Октябрьская, д. 2-А (ФАП)		0101000020E6100000D78A36C7B9E947407CD5CA845F184A40
82954	7	73	663	28757	31171	\N	52.220737	Саратовская область, Вольский район, село Богатое, ул. Коммунистическая, д. 43 (Школа)		0101000020E61000000C1EA67D73DD474032022A1C411C4A40
82928	7	73	663	27580	30439	\N	52.395862999999999	Саратовская область, Вольский район, село Белогорное, ул. 65 лет Октября, д. 10 (Дом культуры)		0101000020E6100000679B1BD313CA4740255987A3AB324A40
79769	7	72	\N	55034	77334	\N	53.0983914597482	город Новокуйбышевск, Миронова, 32	Россия	0101000020E61000005019FF3EE3F64840419C8713988C4A40
82927	7	73	663	27577	31413	\N	52.118690000000001	Саратовская область, Вольский район, село Барановка, ул. Ленина, д. 58 (Школа)		0101000020E6100000336DFFCA4A7747405E2EE23B310F4A40
82885	7	73	1497	25651	30766	\N	52.445002000000002	Саратовская область, Балтайский район, село Царевщина, ул. Ленина, д. 30 (администрация МО)		0101000020E6100000F629C764715B4740CA5356D3F5384A40
82882	7	73	1497	25458	30364	\N	52.365699999999997	Саратовская область, Балтайский район, село Старое Сарайкино, ул. Центральная, д. 6 (Старосарайкинский клуб)		0101000020E61000009C31CC09DA504740D712F241CF2E4A40
82883	7	73	1497	25504	30939	\N	52.371265000000001	Саратовская область, Балтайский район, село Сосновка, ул. Советская, д. 2 (Сосновский сельский ДК)		0101000020E6100000C2C1DEC49076474021938C9C852F4A40
82881	7	73	1497	25452	30768	\N	52.485334000000002	Саратовская область, Балтайский район, село Садовка, ул. Победы, д. 105 (Садовский сельский ДК)		0101000020E6100000E085ADD9CA4B474085D1AC6C1F3E4A40
82880	7	73	1497	25360	30936	\N	52.622260998077998	Саратовская область, Балтайский район, село Пилюгино, ул. Центральная, д. 57 (Пилюгинский сельский ДК)	Россия, Саратовская область, Балтайский район, село Пилюгино	0101000020E61000001D71C806D2314740C3499A3FA64F4A40
82879	7	73	1497	25354	31383	\N	52.431584999999998	Саратовская область, Балтайский район, село Осановка, ул. Вишневая, д. 22 (Осановский сельский клуб)		0101000020E610000092770E65A84E4740DA38622D3E374A40
82878	7	73	1497	25267	31250	\N	52.416905	Саратовская область, Балтайский район, село Новая Лопастейка, ул. Почтовая, д. 62(Новолопастейский сельский ДК)		0101000020E6100000B94F8E0244774740FA449E245D354A40
82877	7	73	1497	25221	30571	\N	52.530642	Саратовская область, Балтайский район, село Малая Караваевка, ул. Зеленая, д. 30 (Малокараваевский клуб)		0101000020E6100000117349D57653474028F1B913EC434A40
82876	7	73	1497	25168	31148	\N	52.662444999999998	Саратовская область, Балтайский район, село Журавлиха, ул. Колхозная, д. 87 (Журавлихинский сельский ДК)		0101000020E6100000941117804649474009336DFFCA544A40
82875	7	73	1497	25159	30756	\N	52.506098000000001	Саратовская область, Балтайский район, село Донгуз, ул. Победы, д. 26а (Донгузский сельский ДК)		0101000020E610000085B4C6A0136647401749BBD1C7404A40
82874	7	73	1497	25083	30568	\N	52.497058000000003	Саратовская область, Балтайский район, село Всеволодчино, ул. Новая, д. 49 (Всеволодчинский клуб)		0101000020E61000001D7233DC803D47408B1BB7989F3F4A40
82873	7	73	1497	25079	31487	\N	52.602269	Саратовская область, Балтайский район, село Большие Озерки, ул. Пионерская, д. 4 (Большеозерский сельский ДК)		0101000020E6100000BD8DCD8E5445474083328D26174D4A40
82872	7	73	1497	25004	31083	\N	52.332248	Саратовская область, Балтайский район, село Барнуковка, ул. Новая, д. 36а (Барнуковский сельский ДК)		0101000020E61000001BDA006C40604740A9143B1A872A4A40
82871	7	73	1497	17376	30380	\N	52.465657999999998	Саратовская область, Балтайский район, село Балтай, ул. Ленина, д. 1 (районный Дом культуры, 3 этаж)		0101000020E61000001B4641F0F8504740758F6CAE9A3B4A40
82870	7	73	1497	17376	30380	\N	52.465657999999998	Саратовская область, Балтайский район, село Балтай, ул. Ленина, д. 1 (районный Дом культуры, 2 этаж)		0101000020E61000001B4641F0F8504740758F6CAE9A3B4A40
82197	7	73	595	17166	\N	\N	51.570625	Саратовская область, Балашовский район, с. Хоперское, Здание ФГУ САС Балашовская		0101000020E610000002452C62D89D4540D7A3703D0AC94940
82141	7	73	595	17166	\N	\N	51.570625	Саратовская область, Балашовский район, с. Хоперское, МОУ СОШ с. Хоперское		0101000020E610000002452C62D89D4540D7A3703D0AC94940
82841	7	73	595	23508	\N	\N	51.452308000000002	Саратовская область, Балашовский район, с. Устиновка, Клуб		0101000020E61000000C59DDEA39AF45400EDC813AE5B94940
81713	7	73	595	32369	\N	\N	51.5059800412389	Саратовская область, Балашовский район, с. Тростянка, МОУ СОШ с. Тростянка	Россия, Саратовская область, Балашовский район, село Тростянка	0101000020E6100000B3EDB435228C45400D37E0F3C3C04940
82866	7	73	595	24743	\N	\N	51.326258000000003	Саратовская область, Балашовский район, с. Терновка, Дом культуры		0101000020E6100000821DFF0582764540790778D2C2A94940
82867	7	73	595	24824	\N	\N	51.253411	Саратовская область, Балашовский район, с. Сухая Елань, МОУ СОШ с. Сухая Елань		0101000020E61000005E4BC8073D7B45402CB98AC56FA04940
82865	7	73	595	24685	\N	\N	51.499917000000003	Саратовская область, Балашовский район, с. Старый Хопер, Дом культуры		0101000020E6100000100533A6607B454073DBBE47FDBF4940
82863	7	73	595	5976	\N	\N	51.657842000000002	Саратовская область, Балашовский район, п. Соцземледельский,  Дом культуры		0101000020E6100000BDE47FF277D74540B6F7A92A34D44940
82850	7	73	595	23924	\N	\N	51.742353000000001	Саратовская область, Балашовский район. п. Садовый, фельдшерско-акушерский пункт		0101000020E610000054FCDF1115924540338B506C05DF4940
82860	7	73	595	24441	\N	\N	51.422123999999997	Саратовская область, Балашовский район, с. Родничок, Дом культуры		0101000020E6100000AFE9414129744540A86DC32808B64940
82859	7	73	595	6875	\N	\N	51.595618999999999	Саратовская область, Балашовский район, с. Репное,  СОШ		0101000020E61000000249D8B79396454028F04E3E3DCC4940
82857	7	73	595	6875	\N	\N	51.595618999999999	Саратовская область, Балашовский район, с. Репное, клуб ООО Дорожник-Репное		0101000020E61000000249D8B79396454028F04E3E3DCC4940
82849	7	73	595	23920	\N	\N	51.713216000000003	Саратовская область, Балашовский район, с. Репная Вершина, фельдшерско-акушерский пункт		0101000020E610000063B6645584954540F27D71A94ADB4940
81689	7	73	595	31259	\N	\N	51.566701000000002	Саратовская область, Балашовский район, с. Рассказань, Дом культуры		0101000020E6100000B5C35F933554454025CE8AA889C84940
82854	7	73	595	24136	\N	\N	51.563839999999999	Саратовская область, Балашовский район, р.п. Пинеровка, Дом культуры		0101000020E61000007F6C921FF18745409C16BCE82BC84940
82848	7	73	595	23837	\N	\N	51.746333999999997	Саратовская область, Балашовский район, п. Октябрьский, МОУ СОШ п. Октябрьский		0101000020E61000007920B2481395454049F25CDF87DF4940
82846	7	73	595	23749	\N	\N	51.577016999999998	Саратовская область, Балашовский район, с.Новопокровское, Дом культуры		0101000020E6100000348463963DCD4540361E6CB1DBC94940
81493	7	73	595	53197	\N	\N	51.521173894955801	Саратовская область, Балашовский район, п. Новая Глебовка, клуб	Россия, Саратовская область, Балашовский район, село Нижная Глебовка	0101000020E6100000B6F5D37FD6B6454044C362D4B5C24940
82861	7	73	595	24530	\N	\N	51.367139999999999	Саратовская область, Балашовский район, с. Михайловка, здание школы		0101000020E61000001A8BA6B393734540D7868A71FEAE4940
81550	7	73	595	24827	\N	\N	51.651913	Саратовская область, Балашовский район, с. Малый Мелик, Дом культуры		0101000020E6100000E2CCAFE600B345402B6B9BE271D34940
82843	7	73	595	23652	\N	\N	51.499878000000002	Саратовская область, Балашовский район, с. Малая Семеновка, Дом культуры		0101000020E6100000F1A1444B1ECF4540B5FE9600FCBF4940
82864	7	73	595	24640	\N	\N	51.709643999999997	Саратовская область, Балашовский район, с. Львовка, здание школы	Россия, Саратовская область, Балашовский район, село Львовка	0101000020E6100000DBA7E33103CF4540BCE6559DD5DA4940
82856	7	73	595	53215	31482	\N	51.586412075112897	Саратовская область, Балашовский район, р.п. Пинеровка, ул. Почтовая, д. 1Б (здание администрации МО)	Россия, Саратовская область, Балашовский район, село Лопатино	0101000020E6100000630D17B9A78B4540B1FD648C0FCB4940
81671	7	73	595	30365	\N	\N	51.575975999999997	Саратовская область, Балашовский район, с. Лесное, Дом культуры		0101000020E6100000422619390B614540F4A3E194B9C94940
82131	7	73	595	21168	\N	\N	51.406429000000003	Саратовская область, Балашовский район, п. Красная Кудрявка, Дом культуры		0101000020E61000000FD1E80E62874540B0928FDD05B44940
81522	7	73	595	23452	\N	\N	51.707881	Саратовская область, Балашовский район, с. Котоврас, МОУ СОШ с. Котоврас		0101000020E61000007CF2B0506BA84540DA3A38D89BDA4940
82842	7	73	595	23568	\N	\N	51.478797	Саратовская область, Балашовский район, п. Конный, фельдшерско-акушерский пункт		0101000020E6100000DD2230D6376645402236583849BD4940
81903	7	73	595	9940	\N	\N	51.403412000000003	Саратовская область, Балашовский район, с. Кардаил, Дом культуры		0101000020E61000008D25AC8DB171454030682101A3B34940
82858	7	73	595	24329	\N	\N	51.666220874128904	Саратовская область, Балашовский район, с. Заречное, здание администрации муниципального образования		0101000020E610000064B0E2546B8F45404774CFBA46D54940
82862	7	73	595	24533	\N	\N	51.436808999999997	Саратовская область, Балашовский район, с. Дуплятка, здание школы	Россия, Саратовская область, Балашовский район, село Дуплятка	0101000020E6100000B2BAD573D26745409ACC785BE9B74940
82868	7	73	595	24837	\N	\N	51.266131999999999	Саратовская область, Балашовский район, с. Данилкино, МОУ СОШ с. Данилкино		0101000020E6100000EC3191D26C8C4540A435069D10A24940
82844	7	73	595	23655	\N	\N	51.515832000000003	Саратовская область, Балашовский район, с. Гусевка, здание школы		0101000020E6100000D3A57F492ADB45407A1D71C806C24940
82853	7	73	595	24080	\N	\N	51.480092999999997	Саратовская область, Балашовский район, п. Ветельный, МОУ СОШ п. Ветельный		0101000020E6100000BC404981059C4540EE04FBAF73BD4940
81516	7	73	595	23181	\N	\N	51.623378000000002	Саратовская область, Балашовский район, с. Большой Мелик, Дом культуры		0101000020E610000071E2AB1DC5A54540E085ADD9CACF4940
82845	7	73	595	23736	\N	\N	51.529130000000002	Саратовская область, Балашовский район, с. Березовка, здание ФАПа		0101000020E610000069FD2D01F8C145408FAA2688BAC34940
82840	7	73	595	23453	\N	\N	51.488309999999998	Саратовская область, Балашовский район, с. Барки, Дом культуры		0101000020E61000004E5FCFD72CB74540A6272CF180BE4940
82830	7	73	595	53127	67126	\N	51.542363000000002	"Саратовская область, Балашовский район, город Балашов, ул. Юбилейная, д. 2 здание ГОУ ""Профессиональное училище №47"""		0101000020E610000016C0948103964540BDC799266CC54940
82803	7	73	595	53127	30218	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Пушкина, д. 88 ( Детская Школа искусств № 1)		0101000020E610000016C0948103964540BDC799266CC54940
82819	7	73	595	53127	30150	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Макаренко, д. 46 (МОУ СОШ № 9)		0101000020E610000016C0948103964540BDC799266CC54940
82816	7	73	595	53127	31343	\N	51.594037235992502	Саратовская область, Балашовский район, город Балашов, ул. Луначарского, д. 100 (Учебный корпус БТМ с/х)	Россия, Саратовская область, Балашовский район	0101000020E6100000732EC555659D454096CE876709CC4940
82799	7	73	595	53127	30214	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Ленина, д. 67 (МОУ СОШ № 6)		0101000020E610000016C0948103964540BDC799266CC54940
82820	7	73	595	53127	30505	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. К. Маркса, д.69 (Детская художественная школа)		0101000020E610000016C0948103964540BDC799266CC54940
82801	7	73	595	53127	30436	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Горохова, д. 11 (Драматический театр)		0101000020E610000016C0948103964540BDC799266CC54940
82817	7	73	595	53127	30503	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Астраханская, д. 87 (Детская библиотека)		0101000020E610000016C0948103964540BDC799266CC54940
82834	7	73	595	53127	30520	\N	51.542363000000002	Саратовская область, Балашовский район, город Балашов, ул. Юбилейная, д. 13 (МОУ СОШ № 3)		0101000020E610000016C0948103964540BDC799266CC54940
82855	7	73	595	24226	\N	\N	51.559607	Саратовская область, Балашовский район, с. Алмазово, МОУ СОШ с. Алмазово		0101000020E6100000F6402B30647545406CCEC133A1C74940
82795	7	73	7273	53195	31193	\N	51.527043322912597	Саратовская область, Балашовский район, город Балашов, ул. Ленина, д. 182 (МОУ СОШ № 17)	Россия, Саратовская область, Балашов городской округ, поселок Ветлянка	0101000020E610000049D6E1E82A934540F94A202576C34940
82794	7	73	588	21355	9941	\N	52.140500000000003	Саратовская область, Балаковский район, село Хлебновка, ул. Советская, д. 124 (МОУ ООШ)		0101000020E610000065A6B4FE962E4840448B6CE7FB114A40
82784	7	73	588	20861	31168	\N	51.883662000000001	Саратовская область, Балаковский район, село Сухой-Отрог, ул. Краснознаменцев, д. 67 (МОУ ООШ)		0101000020E61000005DA5BBEB6C184840E65B1FD61BF14940
82774	7	73	588	20299	30462	\N	51.827584999999999	Саратовская область, Балаковский район, село Пылковка, ул. Молодежная, д. 29 (МОУ ООШ)		0101000020E6100000B1169F0260EC474080D4264EEEE94940
82782	7	73	588	20767	30472	\N	52.004721000000004	Саратовская область, Балаковский район, село Подсосенки, ул. Школьная, д. 10 (МОУ ООШ)		0101000020E610000097C4591135F347405E4D9EB29A004A40
82766	7	73	588	19833	30688	\N	51.968846999999997	Саратовская область, Балаковский район, село Плеханы, ул. Ленина, д. 171  (МОУ СОШ)		0101000020E61000001F4DF564FEAD4740F2E9B12D03FC4940
82785	7	73	588	20967	30261	\N	51.858338000000003	Саратовская область, Балаковский район, село Перекопная Лука, ул. Садовая, д. 73А (МУК СДК)		0101000020E6100000F16778B30627484000750305DEED4940
82773	7	73	588	20289	31312	\N	51.731771999999999	Саратовская область, Балаковский район, село Новая Елюзань, ул. Советская, д. 22 (МУК СДК)		0101000020E61000009B70AFCC5BE54740731074B4AADD4940
82769	7	73	588	19992	31425	\N	51.75515	Саратовская область, Балаковский район, село Новополеводино, ул. Центральная, д. 30 (МУК СКЦ)		0101000020E6100000AFCE31207BBD474086C954C1A8E04940
82789	7	73	588	21164	30267	\N	52.049700000000001	Саратовская область, Балаковский район, поселок Новониколаевский, ул. Советская, д. 28 (МОУ СОШ)		0101000020E6100000F2CD3637A61748403C4ED1915C064A40
82771	7	73	588	20167	30993	\N	51.729368000000001	Саратовская область, Балаковский район, село Никольское Казаково, ул. Ворошилова, д. 42А (МУК СДК)		0101000020E61000009BE5B2D139D74740DD5F3DEE5BDD4940
82793	7	73	588	21302	30857	\N	52.124794000000001	Саратовская область, Балаковский район, поселок Николевский, ул. Школьная, д. 3А (МОУ СОШ)		0101000020E61000009677D503E6194840575EF23FF90F4A40
82792	7	73	588	21264	30687	\N	52.170569	Саратовская область, Балаковский район, село Николевка, ул. Центральная, д. 13 (МОУ ООШ)		0101000020E61000002E3D9AEAC9084840105B7A34D5154A40
82777	7	73	588	20532	30262	\N	51.832928000000003	Саратовская область, Балаковский район, село Наумовка, ул. Победы, д. 19 (МОУ СОШ)		0101000020E61000002AADBF2500FD47401BF67B629DEA4940
82790	7	73	588	21169	31324	\N	52.063814999999998	Саратовская область, Балаковский район, село Натальино, ул. Карла Маркса, д. 19 (МОУ СОШ)		0101000020E6100000C2A6CEA3E2F5474043FF04172B084A40
82768	7	73	588	19935	30655	\N	51.899329999999999	Саратовская область, Балаковский район, село Маянга, ул. Мельникова, д. 60А (МУК Маянгский СКЦ)		0101000020E6100000B7F1272A1BD04740E527D53E1DF34940
82791	7	73	588	3705	30664	\N	52.150680000000001	Саратовская область, Балаковский район, село Матвеевка, ул. Кирова, д. 32А (МУК Матвеевский СКЦ)		0101000020E6100000E9995E622C014840A514747B49134A40
82775	7	73	588	20367	30252	\N	51.847918999999997	Саратовская область, Балаковский район, село Малый Кушум, ул. Заиргизная, (МУК, филиал СКЦ)		0101000020E610000072193735D0F0474019541B9C88EC4940
82786	7	73	588	20979	30266	\N	51.908420999999997	Саратовская область, Балаковский район, село Малоперекопное, ул. Чапаева, д. 41 (МУК СДК)		0101000020E61000001D041DAD6A294840F3FFAA2347F44940
82770	7	73	588	20063	30247	\N	51.893250000000002	Саратовская область, Балаковский район, село Малая Быковка, ул. Советская, д. 19 (Здание администрации)		0101000020E610000020D3DA34B6DF47407593180456F24940
82780	7	73	588	20656	30680	\N	51.854894999999999	Саратовская область, Балаковский район, село КриволучьеСура, ул. Коммунистическая, д. 18 (МУК ФКЦ орг. досуг насел.)		0101000020E6100000FC6F253B360C4840C84109336DED4940
94364	7	73	588	19827	30892	\N	51.962338000000003	Саратовская область, Балаковский район, село Красный Яр, ул. Героев, д. 36  (МОУ ООШ)		0101000020E6100000CA37DBDC98D047405AD93EE42DFB4940
82779	7	73	588	20643	30682	\N	51.897962999999997	Саратовская область, Балаковский район, село Кормежка, ул. Гагарина, д. 35 (МОУ СОШ)		0101000020E61000007286E28E370148404F029B73F0F24940
82776	7	73	588	53157	30518	\N	51.9340736393507	Саратовская область, Балаковский район, село Комсомольское, ул. Степная, (МУК СДК)	Россия, Саратовская область, Балаковский район	0101000020E6100000AB5AD2510EF047409F05A1BC8FF74940
82764	7	73	588	19742	30475	\N	51.982733000000003	Саратовская область, Балаковский район, село Ивановка, ул. Сельхозтехникум, д. 1 (МОУ ООШ)		0101000020E610000004AE2B6684DB474099D9E731CAFD4940
82783	7	73	588	20855	\N	\N	52.055737000000001	Саратовская область, Балаковский район, поселок Затонский, Административное здание ООО Волжский терминал		0101000020E610000037E15E99B7EE4740AD16D86322074A40
82767	7	73	588	19929	31024	\N	51.934916000000001	Саратовская область, Балаковский район, село Еланка, ул. Пролетарская, д. 15А  (МОУ ООШ)		0101000020E6100000D7DEA7AAD0BC4740EA40D653ABF74940
82788	7	73	588	21077	31173	\N	51.994757	Саратовская область, Балаковский район, поселок Грачи, ул. 1-й Микрорайон, д. 3 (МУК филиал СДК)		0101000020E61000009E29745E630D4840C93B873254FF4940
82787	7	73	588	21020	31169	\N	51.967305000000003	Саратовская область, Балаковский район, поселок Головановский, ул. Новая, д. 12 (Здание администрации)		0101000020E6100000206118B0E40E4840EF2076A6D0FB4940
82772	7	73	588	20172	30249	\N	51.931462000000003	Саратовская область, Балаковский район, село Быков Отрог, ул. Набережная, д. 1Б (МУК СКЦ)		0101000020E61000002252D32EA6E74740BFBB95253AF74940
82778	7	73	588	20543	30677	\N	51.768979000000002	Саратовская область, Балаковский район, село Большой Кушум, ул. Молодежная, д. 5А (МУК филиал СДК)		0101000020E610000029D027F2240D4840C82764E76DE24940
82781	7	73	588	20708	31165	\N	51.819496000000001	Саратовская область, Балаковский район, поселок Береговой, ул. Мира, д. 8 (МУК ФКЦ орг. досуг насел.)		0101000020E61000007BD976DA1A0F4840F699B33EE5E84940
82741	7	73	588	40350	9902	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Шевченко, д. 90 (МОУ СОШ №8)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82748	7	73	588	40350	30234	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Трнавская, д. 16А (МОУ СОШ №16)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82729	7	73	588	40350	31296	\N	52.018508774842701	Саратовская область, Балаковский район, город Балаково, ул. Титова, д. 2А (МУК Бал. драмтеатр)	Россия, Саратовская область, Балаковский район	0101000020E61000004D4BAC8C46E4474041D7BE805E024A40
82733	7	73	588	40350	30595	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Набережная Леонова, д. 9 (ГОУ СПО Поволжский колледж)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82715	7	73	588	40350	30561	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Московская, д. 40 (ГАУ СПО Бал. мед. колледж)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82738	7	73	588	40350	30223	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Минская, д. 59 (МОУ СОШ №11)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82714	7	73	588	40350	30610	\N	52.044323043322201	Саратовская область, Балаковский район, город Балаково, ул. Коммунистическая, д. 124А  (МУК КО ГЦИ)		0101000020E6100000F0C4AC1743E34740F5BA4560AC054A40
82752	7	73	7264	53156	30455	\N	51.987842000000001	Саратовская область, Балаковский  район, город Балаково, ул. 30 лет Победы, д. 24 (МОУ СОШ №21)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82712	7	73	7255	53135	30180	\N	51.987842000000001	Саратовская область, Балаковский район, город Балаково, ул. Коммунистическая, д. 137 А (МОУ ДОД ДЮСШ №2)		0101000020E6100000BB99D18F86E94740C0CE4D9B71FE4940
82709	7	73	793	53228	31540	\N	51.524945000000002	Саратовская область, Базарно-Карабулакский район, с.Большой Содом, ул.Комсомольская, д.1а (СДК)		0101000020E6100000D82D02637D0547407099D36531C34940
82703	7	73	793	16665	30625	\N	52.511572999999999	Саратовская область, Базарно-Карабулакский район, с.Яковлевка, пер.Почтовый, д.1б (СОШ)		0101000020E61000002864E76D6C16474020425C397B414A40
82704	7	73	793	16672	31386	\N	52.57349	Саратовская область, Базарно-Карабулакский район, с.Шняево, ул.Победы, д.9 (СОШ)		0101000020E6100000520E661360164740A14ACD1E68494A40
82697	7	73	793	16357	31074	\N	52.351377999999997	Саратовская область, Базарно-Карабулакский район, с.Хватовка, ул.Школьная, д.28 (СОШ)		0101000020E6100000CCD424784348474056444DF4F92C4A40
82708	7	73	793	16873	30174	\N	52.411028000000002	Саратовская область, Базарно-Карабулакский район, с.Первая Ханеневка, ул.Школьная, д.1а (СДК)		0101000020E6100000CA6FD1C952094740C2DEC4909C344A40
82700	7	73	793	16489	30733	\N	52.346493000000002	Саратовская область, Базарно-Карабулакский район, с.Тепляковка, ул.Ленина, д.44в (СДК)		0101000020E610000018D1764CDD2747407FA5F3E1592C4A40
82689	7	73	793	15961	31489	\N	52.010982131678603	Саратовская область, Базарно-Карабулакский район, с.Сухой Карабулак, ул.Молодежная, д.7Б (СОШ)		0101000020E6100000618C48145A3647401E6CB1DB67014A40
82693	7	73	793	16111	31091	\N	52.220506	Саратовская область, Базарно-Карабулакский район, с.Стригай, ул.Ленина, д.2 (СОШ)		0101000020E6100000EEB25F77BA4F47403049658A391C4A40
82707	7	73	793	16872	31246	\N	52.258018	Саратовская область, Базарно-Карабулакский район, с.Старые Бурасы, ул.Ленина, д.15 (СОШ)		0101000020E61000002CF015DD7A134740C1E3DBBB06214A40
82694	7	73	793	5804	30342	\N	52.201219000000002	Саратовская область, Базарно-Карабулакский район, с.Старая Жуковка, ул.Революции, д.3а (СДК)		0101000020E6100000E659492BBE414740BB2A508BC1194A40
82699	7	73	793	16421	31403	\N	52.329430000000002	Саратовская область, Базарно-Карабулакский район, п.Свободный, ул.Советская, д.49 (СОШ)		0101000020E61000006155BDFC4E2F4740202922C32A2A4A40
82706	7	73	793	16802	30372	\N	52.536383000000001	Саратовская область, Базарно-Карабулакский район, с.Репьевка, ул.Новая, д.37 (СОШ)		0101000020E610000065C6DB4AAF0D4740B090B932A8444A40
82681	7	73	793	15545	30431	\N	52.311081999999999	Саратовская область, Базарно-Карабулакский район, с.Марьино, ул.Московская, д.30а (СДК)		0101000020E6100000FDC1C073EFFD4640E82FF488D1274A40
82691	7	73	793	16057	30574	\N	52.057996000000003	Саратовская область, Базарно-Карабулакский район, с.Максимовка, ул.Советская, д.43а (СДК)		0101000020E61000007901F6D1A947474040A6B5696C074A40
82702	7	73	793	27196	31122	\N	52.437575000000002	Саратовская область, Базарно-Карабулакский район, с.Липовка, ул.Октябрьская, д.1б (СДК)		0101000020E6100000C5724BAB211947400B46257502384A40
82698	7	73	793	16363	31102	\N	52.314078000000002	Саратовская область, Базарно-Карабулакский район, с.Лесная Нееловка, ул.Советская, д.10/2  (СДК)		0101000020E6100000A77A32FFE8334740513239B533284A40
82690	7	73	793	5664	30361	\N	51.983255	Саратовская область, Базарно-Карабулакский район, с.Ключи, ул.Кооперативная, д.147а (СОШ)		0101000020E6100000317903CC7C4147407250C24CDBFD4940
82696	7	73	793	16257	30207	\N	52.281588999999997	Саратовская область, Базарно-Карабулакский район, с.Казанла, ул.Коммунистическая, д.1а (СОШ)		0101000020E6100000DE04DF347D524740E8F4BC1B0B244A40
82688	7	73	793	15890	31371	\N	52.149745365733502	Саратовская область, Базарно-Карабулакский район, с.Ивановка, ул.Победы, д.1 (СОШ)	Россия, Саратовская область, Базарно-Карабулакский район, село Ивановка	0101000020E6100000CC99ED0A7D204740A9DE1AD82A134A40
82692	7	73	793	16062	30152	\N	52.164034000000001	Саратовская область, Базарно-Карабулакский район, с.Вязовка, ул.Советская, д.28 (СОШ)		0101000020E610000082E3326E6A5C47404EB7EC10FF144A40
82711	7	73	793	17022	31247	\N	52.366782999999998	Саратовская область, Базарно-Карабулакский район, с.Большая Чечуйка, ул.Молодежная, д.31 (СОШ)		0101000020E610000057D11F9A7902474048DDCEBEF22E4A40
82710	7	73	793	16972	30177	\N	52.510291000000002	Саратовская область, Базарно-Карабулакский район, с.Большая Гусиха, ул.Школьная, д.9 (СОШ)		0101000020E6100000B685E7A562254740B9382A3751414A40
82701	7	73	793	5855	30212	\N	52.386240000000001	Саратовская область, Базарно-Карабулакский район, с.Березовка, ул.Жукова, д.13а (СОШ)		0101000020E61000002A58E36C3A2647401A34F44F70314A40
82705	7	73	793	16728	31245	\N	52.586568	Саратовская область, Базарно-Карабулакский район, с.Белая Гора, ул.Коммунистическая, д.103 (СДК)		0101000020E6100000E469F981AB1A4740A87004A9144B4A40
82684	7	73	793	5595	30354	\N	52.275725999999999	Саратовская область, Базарно-Карабулакский район, р.п.Базарный Карабулак, ул.Топольчанская, д.1 (СОШ №2)		0101000020E6100000DA1B7C6132354740155454FD4A234A40
82685	7	73	793	5595	31368	\N	52.275725999999999	Саратовская область, Базарно-Карабулакский район, р.п.Базарный Карабулак, ул.Социальная, д.15 (Техникум агробизнеса)		0101000020E6100000DA1B7C6132354740155454FD4A234A40
82686	7	73	793	5595	31375	\N	52.275725999999999	Саратовская область, Базарно-Карабулакский район, р.п.Базарный Карабулак, ул.Некрасова, д.35 (АТП)		0101000020E6100000DA1B7C6132354740155454FD4A234A40
82683	7	73	793	5595	30689	\N	52.275725999999999	Саратовская область, Базарно-Карабулакский район, р.п.Базарный Карабулак, ул.Ленина, д.201 (ЦСОН)		0101000020E6100000DA1B7C6132354740155454FD4A234A40
82682	7	73	793	5595	30689	\N	52.275725999999999	Саратовская область, Базарно-Карабулакский район, р.п.Базарный Карабулак, ул.Ленина, д.92а (СОШ №1)		0101000020E6100000DA1B7C6132354740155454FD4A234A40
82687	7	73	793	15817	30928	\N	52.227904000000002	Саратовская область, Базарно-Карабулакский район,  с.Алексеевка, ул.Советская, д.12 (СОШ)		0101000020E6100000780E65A88A2B4740555051F52B1D4A40
82657	7	73	819	14394	31225	\N	52.174446000000003	Саратовская область, Аткарский район, село Умет, ул. Рабочая, д. 8 (администрация МО в с. Умет)		0101000020E6100000A75CE15D2E72464082751C3F54164A40
82661	7	73	819	14623	30326	\N	51.909042999999997	Саратовская область, Аткарский район, поселок Тургенево, ул. Школьная, д. 21А (СДК п. Тургенево)		0101000020E61000009013268C667B464030D461855BF44940
82669	7	73	819	14970	30542	\N	51.986426999999999	Саратовская область, Аткарский район, поселок Сазоново, ул. Школьная, д. 2 (здание МОУ СОШ п. Сазоново)		0101000020E6100000D7DB662AC48B464019726C3D43FE4940
82660	7	73	819	14530	31472	\N	52.058782000000001	Саратовская область, Аткарский район, село Прокудино, ул. Центральная, д. 43 (СДК с. Прокудино)		0101000020E6100000FB1F60ADDA834640F7CB272B86074A40
82676	7	73	819	15301	30916	\N	51.743763999999999	Саратовская область, Аткарский район, село Приречное, ул. Рабочая, д. 10 (СДК с. Приречное)		0101000020E6100000BEF90D130D78464098F8A3A833DF4940
94362	7	73	819	14928	30545	\N	51.990271	Саратовская область, Аткарский район, село Петрово, ул. Советская, д. 43А (СДК с. Петрово)		0101000020E61000006D205D6C5A974640AF963B33C1FE4940
82667	7	73	819	14915	30737	\N	51.941361999999998	Саратовская область, Аткарский район, село Песчанка, ул. Школьная, д. 4 (администрация МО)		0101000020E610000033897AC1A7B946403CD9CD8C7EF84940
94363	7	73	819	15398	30553	\N	51.666043000000002	Саратовская область, Аткарский район, село Озерное, ул. Школьная, д. 30 (МОУ СОШ с. Озерное)		0101000020E61000003C9F01F566764640685DA3E540D54940
82666	7	73	819	14825	30909	\N	51.85134	Саратовская область, Аткарский район, село Марфино, ул. Школьная, д. 28 (МОУ СОШ с. Марфино)		0101000020E6100000FEB8FDF2C9A0464069E388B5F8EC4940
82663	7	73	819	14674	30905	\N	51.949373000000001	Саратовская область, Аткарский район, село Малые Копены, ул. Революционная, д. 29 (администрация МО)		0101000020E61000000D36751E156346404B5AF10D85F94940
82677	7	73	819	15397	30551	\N	51.756208999999998	Саратовская область, Аткарский район, село Малая Осиновка, ул. Солнечная, д. 4 (МОУ ООШ с. Малая Осиновка)		0101000020E6100000651D8EAED28946406EF8DD74CBE04940
82664	7	73	819	14738	30736	\N	51.984786	Саратовская область, Аткарский район, поселок Лопуховка, ул. Советская, д. 17 (администрация МО)		0101000020E6100000E3E313B2F35A464082C7B7770DFE4940
82674	7	73	819	15203	30548	\N	51.736921000000002	Саратовская область, Аткарский район, село Кочетовка, ул. Молодежная, д. 16 (СДК с. Кочетовка)		0101000020E61000007A56D28A6F5A4640295E656D53DE4940
82679	7	73	819	15489	31244	\N	51.654958999999998	Саратовская область, Аткарский район, село Иваново-Языковка, ул. Чапаева, д. 1 (администрация МО)		0101000020E6100000E84EB0FF3A9B4640459C4EB2D5D34940
82662	7	73	819	14632	30753	\N	51.909077000000003	Саратовская область, Аткарский район, село Земляные Хутора, ул. Советская, д. 17 (здание МОУ СОШ)		0101000020E61000003BC43F6CE9574640DD4598A25CF44940
82665	7	73	819	14819	30739	\N	51.832521999999997	Саратовская область, Аткарский район, деревня Ершовка, ул. Центральная, д. 12 (МОУ СОШ д. Ершовка)		0101000020E6100000ECF82F10049C4640AA99B51490EA4940
82672	7	73	819	15095	67035	\N	51.830818000000001	Саратовская область, Аткарский район, село Елизаветино, ул.Кооперативная, 4. Здание администрации, кабинет специалистов		0101000020E6100000485167EE216B4640CD76853E58EA4940
82659	7	73	819	14526	30320	\N	51.971732000000003	Саратовская область, Аткарский район, село Даниловка, ул. Центральная, д. 91 (СДК с. Даниловка)		0101000020E6100000CBD58F4DF2714640043DD4B661FC4940
82673	7	73	819	15192	31241	\N	51.778069000000002	Саратовская область, Аткарский район, село Вяжля, ул. Молодежная, д. 3 (администрация МО)		0101000020E610000006F7031E184446400684D6C397E34940
82680	7	73	819	9537	31465	\N	51.768723000000001	Саратовская область, Аткарский район, село Большая Осиновка, ул. Перспективная, д.27. Здание МОУ СОШ, кабинет начальных классов		0101000020E6100000FD169D2CB59846406D57E88365E24940
82656	7	73	819	5862	30241	\N	52.125318999999998	Саратовская область, Аткарский район, с. Б.Екатериновка, ул. Школьная, д.32/1. Здание Большеекатериновского МО, кабинет специалистов		0101000020E6100000E54691B5866C4640A148F7730A104A40
82675	7	73	819	15247	31242	\N	51.676470999999999	Саратовская область, Аткарский район, село Белгаза, ул. Центральная, д. 53 (СДК с. Белгаза)		0101000020E610000097A949F086624640A1D80A9A96D64940
82670	7	73	819	15025	31062	\N	51.901975999999998	Саратовская область, Аткарский район, село Барановка, ул. Советская, д. 18 (МОУ СОШ с. Барановка)		0101000020E6100000F452B131AF87464071E316F373F34940
82651	7	73	819	53151	30315	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Советская, д. 66 (Центр детского творчества)		0101000020E61000004DD9E907757F464090F46915FDEF4940
82648	7	73	819	53151	30524	\N	51.874910999999997	Саратовская область, Аткарский район, город Аткарск, ул. Ленина, д. 76 (Центр досуга и кино)		0101000020E61000004DD9E907757F464090F46915FDEF4940
94361	7	73	568	12978	30879	\N	51.759208000000001	Саратовская область, Аркадакский район, поселок Шебалов (МОУ-ООШ), ул.Школьная, д.28		0101000020E61000000B98C0ADBBE14540486E4DBA2DE14940
82621	7	73	568	12733	30507	\N	51.792386999999998	Саратовская область, Аркадакский район, село Чиганак (МОУ-СОШ), ул.Буднюка, д.49-Б		0101000020E61000000E12A27C41AB45404563EDEF6CE54940
82629	7	73	568	13107	31039	\N	51.680107	Саратовская область, Аркадакский район, село Софьино (МОУ-ООШ), ул.Школьная, д.16		0101000020E610000035D4282499F34540ED6305BF0DD74940
94359	7	73	568	12644	30517	\N	51.882178000000003	Саратовская область, Аркадакский район, село Семеновка (Администрация Семеновского МО), ул.Дружбы Народов, д.6		0101000020E610000022C154336BAD454017A06D35EBF04940
82625	7	73	568	12933	30496	\N	51.859990000000003	Саратовская область, Аркадакский район, село Росташи (сельский Дом культуры), пер.Школьный, д.21-А		0101000020E6100000B35F77BAF3CC45408B71FE2614EE4940
82640	7	73	568	13601	30511	\N	51.980896999999999	Саратовская область, Аркадакский район, село Подгорное (МОУ-СОШ), ул.Школьная, д.1-А		0101000020E6100000D09849D40BC045404CDF6B088EFD4940
82620	7	73	568	12728	30348	\N	51.835008999999999	Саратовская область, Аркадакский район, село Памятка (филиал МОУ-СОШ села Семеновка в селе Памятка), ул.Трудовая,д.190		0101000020E610000044C4CDA964A04540CE6E2D93E1EA4940
82624	7	73	568	12857	31450	\N	51.860190000000003	Саратовская область, Аркадакский район, село Ольшанка (МОУ-СОШ), ул.Молодежная, д.1		0101000020E61000006C938AC6DABD4540522CB7B41AEE4940
82641	7	73	568	13674	31344	\N	51.966222999999999	Саратовская область, Аркадакский район, поселок Октябрьский (библиотека), ул.Садовая, д.19		0101000020E610000021787C7BD7C645404ED2FC31ADFB4940
82628	7	73	568	13034	31037	\N	51.727437999999999	Саратовская область, Аркадакский район, село Новосельское (сельский Дом культуры), ул.Мира, д.20		0101000020E61000002A8BC22E8ADA45400FEF39B01CDD4940
82637	7	73	568	13483	30721	\N	51.984884999999998	Саратовская область, Аркадакский район, село Мещеряковка (филиал МОУ-СОШ город Аркадак), ул.Новая, д.30		0101000020E61000008E05854199DE454015A930B610FE4940
82623	7	73	568	12853	30878	\N	51.776302000000001	Саратовская область, Аркадакский район, село Малиновка (сельский Дом культуры), ул.Крупской, д.15		0101000020E61000005E6919A9F7B44540E2E82ADD5DE34940
82632	7	73	568	13211	31042	\N	51.912165999999999	Саратовская область, Аркадакский район, село Львовка (центр досуга), ул.Школьная, д.10		0101000020E61000001EFF058200DB4540F64201DBC1F44940
82618	7	73	568	3650	30866	\N	51.873030999999997	Саратовская область, Аркадакский район, поселок Летяжевский санаторий (административное здание), ул.Кумысная (Санаторская), д.6		0101000020E6100000A93121E692B0454074B2D47ABFEF4940
82633	7	73	568	13263	30713	\N	51.910971000000004	Саратовская область, Аркадакский район, село Крутец (медпункт), ул.Радищева, д.10		0101000020E6100000B91AD99596D145405E4D9EB29AF44940
82617	7	73	568	53161	30661	\N	51.9153677653822	Саратовская область, Аркадакский район, село Красный Полуостров (сельский Дом культуры), ул.Прихоперская, д.3	Россия, Саратовская область, Аркадакский район, село Красный Полуостров	0101000020E610000095EF1989D0B4454008E753C72AF54940
82634	7	73	568	13319	30425	\N	52.054684000000002	Саратовская область, Аркадакский район, село Красное Знамя (сельский Дом культуры), ул.Ленина, д.21-Б		0101000020E610000066A4DE5339C54540A7CEA3E2FF064A40
82636	7	73	568	13397	31210	\N	52.105376999999997	Саратовская область, Аркадакский район, село Кистендей (административное здание), ул.Советская, д.20		0101000020E610000005FA449E24D74540136058FE7C0D4A40
82631	7	73	568	13205	30884	\N	51.884140000000002	Саратовская область, Аркадакский район, село Ивановка (сельский Дом культуры), ул.Инициативная, д.1-А		0101000020E610000034BC5983F7E54540F08AE07F2BF14940
94360	7	73	568	12936	30502	\N	51.823993999999999	Саратовская область, Аркадакский район, село Грачевка (сельский Дом культуры), ул.Школьная, д.8		0101000020E61000008CD9925511D24540D40CA9A278E94940
82639	7	73	568	13539	30297	\N	52.061734000000001	Саратовская область, Аркадакский район, село Большая Журавка (МОУ-СОШ), ул.Советская, д.33		0101000020E61000006D1B4641F0AA4540908653E6E6074A40
82635	7	73	568	13396	30714	\N	52.065376999999998	Саратовская область, Аркадакский район, село Беловка (сельский Дом культуры), ул.Первомайская, д.1-А		0101000020E6100000B1C05774EBCF45408E7406465E084A40
82638	7	73	568	13500	30294	\N	52.109824000000003	Саратовская область, Аркадакский район, село Баклуши (МОУ-СОШ), ул.Кооперативная, д.16		0101000020E6100000BBD573D2FBAE454070287CB60E0E4A40
82615	7	73	568	3529	\N	\N	51.929656999999999	Саратовская область, Аркадакский район, город Аркадак (административное здание ООО Прихоперский элеватор), территория элеватора, д.10		0101000020E61000008FE046CA16C14540ADBF2500FFF64940
82613	7	73	568	3529	30201	\N	51.929656999999999	Саратовская область, Аркадакский район, город Аркадак (МОУ-СОШ № 3), ул.Ленина, д.117		0101000020E61000008FE046CA16C14540ADBF2500FFF64940
82612	7	73	568	3529	30201	\N	51.929656999999999	Саратовская область, Аркадакский район, город Аркадак (кинотеатр Космос), ул.Ленина, д.92		0101000020E61000008FE046CA16C14540ADBF2500FFF64940
82611	7	73	568	3529	30201	\N	51.938053265938599	Саратовская область, Аркадакский район, город Аркадак (Дом творчества юных), ул.Ленина, д.47	Россия, Саратовская область, Аркадакский район, Аркадак	0101000020E61000001C9AB2D30FC045401475E61E12F84940
82616	7	73	568	3529	30698	\N	51.929656999999999	Саратовская область, Аркадакский район, город Аркадак (МОУ-СОШ № 1), ул.Л.Толстого, д.35		0101000020E61000008FE046CA16C14540ADBF2500FFF64940
82610	7	73	568	3529	30816	\N	51.929656999999999	Саратовская область, Аркадакский район, город Аркадак (школа искусств), ул.Калинина, д.6		0101000020E61000008FE046CA16C14540ADBF2500FFF64940
82614	7	73	568	3529	31382	\N	51.929656999999999	Саратовская область, Аркадакский район, город Аркадак (клуб Надежда), ул.Заводская, д.2		0101000020E61000008FE046CA16C14540ADBF2500FFF64940
82630	7	73	568	13115	30912	\N	51.839216	Саратовская область, Аркадакский район, село Алексеевка (сельский Дом культуры), ул.Алексеевская, д.105		0101000020E6100000747973B856F74540D5230D6E6BEB4940
82608	7	73	556	12115	31436	\N	50.090021	Саратовская область, Александрово-Гайский район, хутор Сысоев, ул. Алгайская, д.7(сельский клуб)		0101000020E61000007E6E68CA4E2D4840037AE1CE850B4940
82601	7	73	556	11776	31322	\N	50.094985000000001	Саратовская область, Александрово-Гайский район, поселок Приузенский, ул. Первомайская, д.6(сельский дом культуры)		0101000020E6100000AA4885B1855E4840274EEE77280C4940
82596	7	73	556	53240	31602	\N	50.3605004220098	Саратовская область, Александрово-Гайский  район, хутор Новостепной, ул. Центральная, д.4(сельский клуб)	Россия, Саратовская область, Александрово-Гайский район, село Луков Кордон	0101000020E61000001ADD41EC4C2D4840A01A2FDD242E4940
82604	7	73	556	3437	30374	\N	50.129443000000002	Саратовская область, Александрово-Гайский  район, село Новоалександровка, ул. Прудовая, д.12 а(сельская средняя школа)		0101000020E6100000EA3E00A94D4A48401BD9959691104940
82600	7	73	556	11727	31174	\N	50.275675	Саратовская область, Александрово-Гайский район, хутор Монахов, ул. Школьная, д.5 (начальная школа)		0101000020E610000017D34CF73A45484093A9825149234940
82595	7	73	556	11478	31409	\N	50.362110000000001	Саратовская область, Александрово-Гайский район. поселок Луков Кордон, ул. Школьная, д.2(средняя школа с. Луков Кордон)		0101000020E61000001A187959132D4840FCC6D79E592E4940
82598	7	73	556	11664	30974	\N	50.388081999999997	Саратовская область, Александрово-Гайский  район, село Канавка, ул. Коммунарная, д.3(сельский дом культуры)		0101000020E6100000A4E2FF8EA84648404815C5ABAC314940
82594	7	73	556	11474	30210	\N	50.263820000000003	Саратовская область, Александрово-Гайский  район, село Камышки, ул. Новостройка, д. 23(социальный центр)		0101000020E610000088F546AD302F4840EF0390DAC4214940
82607	7	73	556	3498	30408	\N	49.940683999999997	Саратовская область, Александрово-Гайский  район, хутор Ветелки, ул. Полевая, д.2 а(сельский клуб)		0101000020E610000097E4805D4D2448406BEF535568F84840
82593	7	73	556	53227	31535	\N	50.160879857717802	Саратовская область, Александрово-Гайский  район, поселок Васильки, ул. Новая, д.2 (интернат присредней школе №2)	Россия, Саратовская область, Александрово-Гайский район	0101000020E6100000BA4E232D953B48404D4A41B797144940
82606	7	73	556	12006	30220	\N	50.011333	Саратовская область, Александрово-Гайский  район, село Варфоломеевка, ул. Пионерская, д. 1 а(сельская средняя школа)		0101000020E61000000327DBC01D184840CB2E185C73014940
82605	7	73	556	12000	30176	\N	49.990135000000002	Саратовская область, Александрово-Гайский район, хутор Байгужа, ул. Лиманная, д.17а(сельский клуб)		0101000020E6100000FB9463B2B8394840FFCF61BEBCFE4840
82588	7	73	556	11185	31404	\N	50.403001000000003	Саратовская область, Александрово-Гайский  район, хутор Бабошкин, ул Центральная, д.3(сельский клуб)		0101000020E610000056D7A19A92544840AEA0698995334940
82603	7	73	556	11859	30853	\N	50.180210000000002	Саратовская область, Александрово-Гайский  район, хутор Ахматов, ул. Комсомольская, д. 13(сельский клуб)		0101000020E6100000A110018750594840C2340C1F11174940
82586	7	73	556	10970	30253	\N	50.143490999999997	Саратовская область, Александрово-Гайский район, село Александров-Гай, площадь 35-летия победы, д.1 (Районный дом культуры)		0101000020E6100000B2BAD573D24748409A22C0E95D124940
82584	7	73	556	10970	31127	\N	50.143490999999997	Саратовская область, Александрово-Гайский  район, село  Александров-Гай, площадь 35-летия Победы, д.1 (Центр детского творчества)		0101000020E6100000B2BAD573D24748409A22C0E95D124940
82590	7	73	556	10970	31336	\N	50.143490999999997	Саратовская область, Александрово-Гайский  район, село  Александров-Гай, ул. Советская, д. 16( средняя школа №1)		0101000020E6100000B2BAD573D24748409A22C0E95D124940
82592	7	73	556	10970	31128	\N	50.143490999999997	Саратовская область, Александрово-Гайский  район, село Александров-Гай, ул.Привокзальная, д.4 (сельский клуб)		0101000020E6100000B2BAD573D24748409A22C0E95D124940
79815	7	72	\N	4596	47836	\N	52.972144581855098	Самарская область, городской округ Чапаевск, ул.Жуковского, 35	Россия, Самарская область, Чапаевск	0101000020E6100000304B3B3597DD484026FC523F6F7C4A40
82591	7	73	556	10970	30976	\N	50.142170126876103	Саратовская область, Александрово-Гайский  район, село Александров-Гай, ул.Почтовая, д.69 (средняя школа №2)	Россия, Саратовская область, Александрово-Гайский район, поселок Александров Гай	0101000020E6100000BCAE5FB01B464840753C66A032124940
82585	7	73	556	10970	31455	\N	50.143349154138001	Саратовская область, Александрово-Гайский  район, село Александров-Гай, ул. Красного бойца, д.67 (средняя школа №3)	Россия, Саратовская область, Александрово-Гайский район, поселок Александров Гай	0101000020E6100000DAAA24B20F4C48400875914259124940
82589	7	73	556	10970	31140	\N	50.143490999999997	Саратовская область, Александрово-Гайский  район, село Александров-Гай, ул. Коммунистическая, д. 19 (Дом кино Маяк)		0101000020E6100000B2BAD573D24748409A22C0E95D124940
82587	7	73	556	10970	31140	\N	50.142997517486201	Саратовская область, Александрово-Гайский  район, с. Александров-Гай, ул. Коммунистическая, д.82(Музей краеведения)	Россия, Саратовская область, Александрово-Гайский район, поселок Александров Гай	0101000020E6100000CCD3B9A2944648405BB22AC24D124940
82602	7	73	7258	53141	30211	\N	50.096037695754902	Саратовская область, Александрово-Гайский  район, поселок Передовой, ул. Пограничная, д.25(сельский клуб)	Россия, Саратовская область, село Передовой	0101000020E61000004FAF9465886748402D9622F94A0C4940
83714	7	73	7275	53216	\N	\N	51.567094111059397	Саратовская область, Саратовский район, р.п. Соколовый, (МОУ СОШ р.п. Соколовый)	Россия, Саратовская область, поселок городского типа Соколовый	0101000020E61000008FE21C7574EA464000E1438996C84940
83513	7	73	7268	53173	30804	\N	52.015935905588499	Саратовская область, Пугачевский район, город Пугачев, ул. Вокзальная, Дом культуры		0101000020E6100000AA7EA5F3E16548401F6ADB300A024A40
95094	7	72	\N	50003	48441	\N	53.412429000000003	"Самарская область, городской округ Жигулевск, село Ширяево, ул. Рабочая, д.15 МУК СДК ""Родник"""		0101000020E61000003909A52F8402494004763579CAB44A40
79808	7	72	\N	4596	47947	\N	52.963788854992998	Самарская область, городской округ Чапаевск, ул.Ярославская, 7а	Россия, Самарская область, Чапаевск	0101000020E610000096B1A19BFDDB48404D9F1D705D7B4A40
79824	7	72	\N	4596	48100	\N	52.971799154569801	Самарская область, городской округ Чапаевск, ул.Чкалова, 1	Россия, Самарская область, Чапаевск	0101000020E6100000BEDEFDF15EDD48408BA4DDE8637C4A40
79811	7	72	\N	4596	48035	\N	52.963374261708402	Самарская область, городской округ Чапаевск, ул.Херсонская, 17	Россия, Самарская область, Чапаевск	0101000020E61000005CE674594CDC48408AE8D7D64F7B4A40
79819	7	72	\N	4596	48129	\N	52.973326	Самарская область, городской округ Чапаевск, ул.Силикатная, 8		0101000020E610000055A0168387DD48405A2C45F2957C4A40
79828	7	72	\N	4596	47969	\N	52.971937325974899	Самарская область, городской округ Чапаевск, ул.Сергея Лазо, 34а		0101000020E6100000304B3B3597DD4840DC627E6E687C4A40
79829	7	72	\N	4596	47944	\N	52.966069046643497	Самарская область, городской округ Чапаевск, ул.Радищева, 28		0101000020E61000006AA33A1DC8DC4840F7562426A87B4A40
79821	7	72	\N	4596	48328	\N	52.977882649599401	Самарская область, городской округ Чапаевск, ул.Озерная, 5	Россия, Самарская область, Чапаевск	0101000020E610000098DBBDDC27DB48403D2828452B7D4A40
79813	7	72	\N	4596	47961	\N	52.972351811436901	Самарская область, городской округ Чапаевск, ул.Мирная, 38		0101000020E61000007286E28E37DD4840A019C407767C4A40
79809	7	72	\N	4596	48004	\N	52.971458110130399	Самарская область, городской округ Чапаевск, ул.Макаренко, 16	Россия, Самарская область, Чапаевск	0101000020E6100000C9586DFE5FDD484002B859BC587C4A40
79814	7	72	\N	4596	47920	\N	52.9714882678782	Самарская область, городской округ Чапаевск, ул.Ленина, 133Б	Россия, Самарская область, Чапаевск	0101000020E6100000575F5D15A8DD48406D3A02B8597C4A40
79805	7	72	\N	4596	47920	\N	52.966690896118799	Самарская область, городской округ Чапаевск, ул.Ленина, 51		0101000020E61000008CBD175FB4DD4840342BDB87BC7B4A40
79802	7	72	\N	4596	47920	\N	52.967239257875299	Самарская область, городской округ Чапаевск, ул.Ленина, 20	Россия, Самарская область, Чапаевск	0101000020E6100000FDA36FD234DC48403735D07CCE7B4A40
79804	7	72	\N	4596	47951	\N	52.966276330800703	Самарская область, городской округ Чапаевск, ул.Куйбышева, 13А	Россия, Самарская область, Чапаевск	0101000020E61000006EF7729F1CDB4840717495EEAE7B4A40
79803	7	72	\N	4596	47951	\N	53.010405096331098	Самарская область, городской округ Чапаевск, ул.Куйбышева, 12А	Россия, Самарская область, Чапаевск	0101000020E6100000925D6919A9DD4840815B77F354814A40
79827	7	72	\N	4596	47835	\N	52.973326	Самарская область, городской округ Чапаевск, ул.Крымская, 1		0101000020E610000055A0168387DD48405A2C45F2957C4A40
79823	7	72	\N	4596	48205	\N	52.968556390610701	Самарская область, городской округ Чапаевск, ул.Крестьянская, 6	Россия, Самарская область, Чапаевск	0101000020E610000006F4C29D0BDD48401B2C9CA4F97B4A40
79830	7	72	\N	4596	47859	\N	52.973326	Самарская область, городской округ Чапаевск, ул.Котовского, 10		0101000020E610000055A0168387DD48405A2C45F2957C4A40
79817	7	72	\N	4596	47821	\N	52.977882649599401	Самарская область, городской округ Чапаевск, ул.Короленко, 72	Россия, Самарская область, Чапаевск	0101000020E6100000AC38D55A98DB48403D2828452B7D4A40
79801	7	72	\N	4596	47995	\N	52.971665368319798	Самарская область, городской округ Чапаевск, ул.К.Маркса, 12	Россия, Самарская область, Чапаевск	0101000020E61000001781B1BE81DD48407CD5CA845F7C4A40
79812	7	72	\N	4596	47997	\N	52.967727291935397	Самарская область, городской округ Чапаевск, ул.Запорожская, 6	Россия, Самарская область, Чапаевск	0101000020E6100000BAF59A1E14DC4840643A747ADE7B4A40
79818	7	72	\N	4596	47836	\N	52.971799154569801	г.Чапаевск,ул. Жуковского, 35	Россия, Самарская область, Чапаевск	0101000020E61000000ED76A0F7BDD48408BA4DDE8637C4A40
80953	7	72	\N	463	48052	\N	53.529812999999997	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Луначарского, 19		0101000020E610000096B4E21B0AA7484071FF91E9D0C34A40
81024	7	72	\N	463	47935	\N	53.506214	Самарская область, городской округ Тольятти, Центральный район, бульвар Ленина, 1	Россия, Самарская область, Тольятти, Ленина, 5	0101000020E61000008522DDCF29B648408063CF9ECBC04A40
80934	7	72	\N	463	48108	\N	53.513612298406102	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Королёва, 3	Россия, Самарская область, Тольятти, Королева, 3	0101000020E61000009D0FCF1264A24840A56ABB09BEC14A40
80932	7	72	\N	463	48108	\N	53.512939000000003	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Королёва, 12		0101000020E6100000F96706F181A14840E6EB32FCA7C14A40
80948	7	72	\N	463	47708	\N	53.511310999999999	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Будённого, 9		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
80947	7	72	\N	463	47708	\N	53.511310999999999	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Будённого, 1		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
80946	7	72	\N	463	47708	\N	53.510450296655499	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Будённого, 12		0101000020E6100000BB80971936A44840211FF46C56C14A40
80949	7	72	\N	463	7043	\N	53.502786	Самарская область, городской округ Тольятти, Автозаводский район, улица Юбилейная, 81	Россия, Самарская область, Тольятти, Юбилейная, 81	0101000020E61000002F3201BF46A448407E71A94A5BC04A40
81002	7	72	\N	463	7638	\N	53.472037999999998	Самарская область, городской округ Тольятти, Комсомольский район, Энергетиков, 17	Россия, Самарская область, Тольятти, Энергетиков, 17	0101000020E61000008B355CE49EC24840103CBEBD6BBC4A40
79751	7	72	\N	463	16251	\N	53.515101999999999	город Новокуйбышевск, пер.Школьный, 7	Россия, Самарская область, Тольятти, Школьный, 7	0101000020E6100000A41CCC26C0B24840560DC2DCEEC14A40
79750	7	72	\N	463	16251	\N	53.515101999999999	город Новокуйбышевск, пер. Школьный, 7	Россия, Самарская область, Тольятти, Школьный, 7	0101000020E6100000A41CCC26C0B24840560DC2DCEEC14A40
80376	7	72	\N	463	7961	\N	53.534078999999998	Самарская область, городской округ Самара, Ленинский район, Чкалова, 90	Россия, Самарская область, Тольятти, Чкалова, 90	0101000020E6100000A11342075DB648407D3D5FB35CC44A40
79759	7	72	\N	463	15646	\N	53.524417999999997	город Новокуйбышевск, Чернышевского, 24	Россия, Самарская область, Тольятти, Чернышевского	0101000020E6100000A77686A92DB3484084B7072120C34A40
80988	7	72	\N	463	47891	\N	53.483209937875401	Самарская область, городской округ Тольятти, Комсомольский район, Лизы Чайкиной, 57	Россия, Самарская область, Тольятти, Чайкиной, 57	0101000020E6100000AAB8718BF9BB4840D28C45D3D9BD4A40
80972	7	72	\N	463	7280	\N	53.537702000000003	Самарская область, городской округ Тольятти, Автозаводский район, Цветной бульвар, 13	Россия, Самарская область, Тольятти, Цветной, 13	0101000020E6100000897956D28AAB4840357F4C6BD3C44A40
80971	7	72	\N	463	7280	\N	53.538066000000001	Самарская область, городской округ Тольятти, Автозаводский район, Цветной бульвар, 18	Россия, Самарская область, Тольятти, Цветной, 18	0101000020E610000015CAC2D7D7AA4840768BC058DFC44A40
80958	7	72	\N	463	7132	\N	53.515520000000002	Самарская область, городской округ Тольятти, Автозаводский район, улица Фрунзе, 2	Россия, Самарская область, Тольятти, Фрунзе, 2	0101000020E6100000ADFBC74274A648408B37328FFCC14A40
80957	7	72	\N	463	7132	\N	53.515199000000003	Самарская область, городской округ Тольятти, Автозаводский район, улица Фрунзе, 12	Россия, Самарская область, Тольятти, Фрунзе, 12	0101000020E61000004A969350FAA4484049F7730AF2C14A40
80249	7	72	\N	463	6657	\N	53.482354000000001	Самарская область, городской округ Самара, Промышленный район, Фадеева, 61	Россия, Самарская область, Тольятти, Фадеева, 61	0101000020E61000006094A0BFD0C34840228C9FC6BDBD4A40
80991	7	72	\N	463	7490	\N	53.483629000000001	Самарская область, городской округ Тольятти, Комсомольский район, Громовой, 42а	Россия, Самарская область, Тольятти, Ульяны Громовой, 42а	0101000020E6100000616BB6F292BD4840D732198EE7BD4A40
80990	7	72	\N	463	7490	\N	53.484679999999997	Самарская область, городской округ Тольятти, Комсомольский район, Громовой, 38	Россия, Самарская область, Тольятти, Ульяны Громовой, 38	0101000020E6100000A3ACDF4C4CBD48403C8386FE09BE4A40
80954	7	72	\N	463	7110	\N	53.521633999999999	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Туполева, 12	Россия, Самарская область, Тольятти, Туполева, 12	0101000020E6100000B8CD548847A64840A73D25E7C4C24A40
80979	7	72	\N	463	7349	\N	53.545209	Самарская область, городской округ Тольятти, Автозаводский район, улица Тополиная, 5	Россия, Самарская область, Тольятти, Тополиная, 5	0101000020E6100000F6B6990AF1AC4840103E9468C9C54A40
80978	7	72	\N	463	7349	\N	53.544401000000001	Самарская область, городской округ Тольятти, Автозаводский район, улица Тополиная, 18	Россия, Самарская область, Тольятти, Тополиная, 18	0101000020E6100000572426A8E1AB4840717495EEAEC54A40
80998	7	72	\N	463	7592	\N	53.487653000000002	Самарская область, городской округ Тольятти, Комсомольский район, Телеграфная, 4		0101000020E610000011A8FE4124C34840ED65DB696BBE4A40
80977	7	72	\N	463	7329	\N	53.54522	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Татищева, 19	Россия, Самарская область, Тольятти, Татищева, 19	0101000020E6100000297AE063B0AA48400490DAC4C9C54A40
80960	7	72	\N	463	7062	\N	53.509630000000001	Самарская область, городской округ Тольятти, Автозаводский район, проспект Степана Разина, 73	Россия, Самарская область, Тольятти, Степана Разина, 73	0101000020E610000026A60BB1FAA54840BE874B8E3BC14A40
80959	7	72	\N	463	7062	\N	53.511729000000003	Самарская область, городской округ Тольятти, Автозаводский район, проспект Степана Разина, 65	Россия, Самарская область, Тольятти, Степана Разина, 65	0101000020E610000009DE904605A6484018B5FB5580C14A40
80950	7	72	\N	463	7062	\N	53.502448999999999	Самарская область, городской округ Тольятти, Автозаводский район, проспект Степана Разина, 78	Россия, Самарская область, Тольятти, Степана Разина, 78	0101000020E610000025CD1FD3DAA448403674B33F50C04A40
81028	7	72	\N	463	7906	\N	53.508901999999999	Самарская область, городской округ Тольятти, Центральный район, Ставропольская, 19	Россия, Самарская область, Тольятти, Ставропольская, 19	0101000020E6100000BD5301F73CB348403B6F63B323C14A40
79835	7	72	\N	463	15531	\N	53.475264000000003	поселок Верхняя Подстепновка, Специалистов, 4	Россия, Самарская область, Тольятти, Специалистов, 4	0101000020E6100000B6679604A8AF4840AB7B6473D5BC4A40
80561	7	72	\N	463	1308	\N	53.513823000000002	Алексевка,  ул. Советская, 23	Россия, Самарская область, Тольятти, Советская, 23	0101000020E6100000580394861AB348406077BAF3C4C14A40
79822	7	72	\N	463	1308	\N	53.510593999999998	Самарская область, городской округ Чапаевск, ул.Советская, 56	Россия, Самарская область, Тольятти, Советская, 56	0101000020E61000002504ABEAE5B3484054C4E9245BC14A40
81013	7	72	\N	463	47701	\N	53.511310999999999	Самарская область, городской округ Тольятти, Комсомольский район, Сиреневая, 24		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
81005	7	72	\N	463	7658	\N	53.467289000000001	Самарская область, городской округ Тольятти, Комсомольский район, Севастопольская, 1	Россия, Самарская область, Тольятти, Севастопольская, 1	0101000020E61000000AA359D93EC44840E9633E20D0BB4A40
80942	7	72	\N	463	6981	\N	53.525835999999998	Самарская область, городской округ Тольятти, Автозаводский район, улица Свердлова, 23	Россия, Самарская область, Тольятти, Свердлова, 23	0101000020E6100000EA094B3CA0A448409C8713984EC34A40
79744	7	72	\N	463	6981	\N	53.527180000000001	город Новокуйбышевск, Свердлова, 12	Россия, Самарская область, Тольятти, Свердлова, 12	0101000020E61000009A97C3EE3BA848407A8D5DA27AC34A40
79736	7	72	\N	463	6981	\N	53.525835999999998	город Новокуйбышевск, Свердлова, 23	Россия, Самарская область, Тольятти, Свердлова, 23	0101000020E6100000EA094B3CA0A448409C8713984EC34A40
95088	7	72	\N	463	19395	\N	53.513790999999998	Самарская область, городской округ Жигулевск, Репина, д.39, здание Школы №13		0101000020E610000082902C6002B3484054FD4AE7C3C14A40
80937	7	72	\N	463	6912	\N	53.527088999999997	Самарская область, городской округ Тольятти, Автозаводский район, улица Революционная, 11/33	Россия, Самарская область, Тольятти, Революционная, 11/33	0101000020E61000009ACDE33098A34840698A00A777C34A40
80936	7	72	\N	463	6912	\N	53.531450999999997	Самарская область, городской округ Тольятти, Автозаводский район, улица Революционная, 7	Россия, Самарская область, Тольятти, Революционная, 7	0101000020E6100000B3B45373B9A3484097361C9606C44A40
80935	7	72	\N	463	6912	\N	53.535524000000002	Самарская область, городской округ Тольятти, Автозаводский район, улица Революционная, 3/56	Россия, Самарская область, Тольятти, Революционная, 3/56	0101000020E61000006C5F402FDCA348408F1CE90C8CC44A40
80983	7	72	\N	463	48344	\N	53.547833954256397	Самарская область, городской округ Тольятти, Автозаводский район, улица Полякова, 26 (офисное помещение)	Россия, Самарская область, Тольятти	0101000020E6100000F16261889CA8484085D1AC6C1FC64A40
81039	7	72	\N	463	1860	\N	53.518529000000001	Самарская область, городской округ Тольятти, Центральный район, Победы, 36	Россия, Самарская область, Тольятти, Победы, 36/80	0101000020E61000008F5033A48AB64840888384285FC24A40
81035	7	72	\N	463	1860	\N	53.515354000000002	Самарская область, городской округ Тольятти, Центральный район, Победы, 42	Россия, Самарская область, Тольятти, Победы, 42	0101000020E61000005CC823B891B6484070EEAF1EF7C14A40
95018	7	72	\N	463	4756	\N	53.522646000000002	Самарская область, городской округ Жигулевск, Первомайская, д.21, здание школы №7, корпус 3		0101000020E6100000944F8F6D19B448404FB16A10E6C24A40
79946	7	72	\N	463	4756	\N	53.522072999999999	село Первомайск, Первомайская, 89	Россия, Самарская область, Тольятти, Первомайская, 89	0101000020E6100000BDFF8F1326B44840F38FBE49D3C24A40
95001	7	72	\N	463	7310	\N	53.548584839473897	Самарская область, г.Тольятти, ул.Офицерская,6а- офисное помещение	Россия, Самарская область, Тольятти, Офицерская, 4	0101000020E61000004A7F2F8507A94840C009850838C64A40
80976	7	72	\N	463	7310	\N	53.549297000000003	Самарская область, городской округ Тольятти, Автозаводский район, улица Офицерская, 2А (офисное помещение)		0101000020E61000004F745DF8C1A948403D65355D4FC64A40
79762	7	72	\N	463	16045	\N	53.479781956484899	г. Новокуйбышевск,  ул. Островского, 12	Россия, Самарская область, Тольятти, Островского	0101000020E6100000B988EFC4ACBB4840D09A1F7F69BD4A40
80944	7	72	\N	463	6983	\N	53.523764999999997	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Орджоникидзе, 3	Россия, Самарская область, Тольятти, Орджоникидзе, 3	0101000020E6100000F27D71A94AA548400CE544BB0AC34A40
80943	7	72	\N	463	6983	\N	53.522790000000001	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Орджоникидзе, 14	Россия, Самарская область, Тольятти, Орджоникидзе, 14	0101000020E61000009B73F04C68A44840825660C8EAC24A40
79826	7	72	\N	463	6983	\N	53.521692999999999	Самарская область, городской округ Чапаевск, ул.Орджоникидзе, 17	Россия, Самарская область, Тольятти, Орджоникидзе, 17	0101000020E6100000E15E99B7EAA44840ACC612D6C6C24A40
79825	7	72	\N	463	6983	\N	53.521265	Самарская область, городской округ Чапаевск, ул.Орджоникидзе, 18	Россия, Самарская область, Тольятти, Орджоникидзе, 18	0101000020E6100000D8F0F44A59A4484054C6BFCFB8C24A40
81007	7	72	\N	463	277	\N	53.462454000000001	Самарская область, городской округ Тольятти, Комсомольский район, Носова, 21	Россия, Самарская область, Тольятти, Носова, 21	0101000020E6100000D449B6BA9CC44840C3F352B131BB4A40
81006	7	72	\N	463	277	\N	53.463194000000001	Самарская область, городской округ Тольятти, Комсомольский район, Носова, 18	Россия, Самарская область, Тольятти, Носова, 17	0101000020E61000006E162F1686C448400ADAE4F049BB4A40
80997	7	72	\N	463	7419	\N	53.477344000000002	Самарская область, городской округ Тольятти, Комсомольский район, Мурысева, 61	Россия, Самарская область, Тольятти, Мурысева, 61	0101000020E6100000F2237EC51ABC48408E78B29B19BD4A40
80995	7	72	\N	463	7419	\N	53.475687999999998	Самарская область, городской округ Тольятти, Комсомольский район, Мурысева, 84	Россия, Самарская область, Тольятти, Мурысева, 84	0101000020E610000022AB5B3D27BD4840C18C2958E3BC4A40
80994	7	72	\N	463	7419	\N	53.476894000000001	Самарская область, городской округ Тольятти, Комсомольский район, Мурысева, 89а	Россия, Самарская область, Тольятти, Мурысева, 89а	0101000020E6100000F646AD307DBD48404ED4D2DC0ABD4A40
80985	7	72	\N	463	7419	\N	53.478479999999998	Самарская область, городской округ Тольятти, Комсомольский район, Мурысева, 49	Россия, Самарская область, Тольятти, Мурысева, 49	0101000020E61000001901158E20BB484021E527D53EBD4A40
80931	7	72	\N	463	6877	\N	53.518625	Самарская область, городской округ Тольятти, Автозаводский район, Московский проспект, 37	Россия, Самарская область, Тольятти, Московский, 37	0101000020E61000000C1EA67D73A14840AAF1D24D62C24A40
81034	7	72	\N	463	7960	\N	53.516863999999998	Самарская область, городской округ Тольятти, Центральный район, Молодежный бульвар, 28	Россия, Самарская область, Тольятти, Молодежный, 28	0101000020E610000026732CEFAAB54840683D7C9928C24A40
81037	7	72	\N	463	1239	\N	53.512216000000002	Самарская область, городской округ Тольятти, Центральный район, Мира, 158	Россия, Самарская область, Тольятти, Мира, 158	0101000020E610000071AAB5300BB94840753E3C4B90C14A40
81036	7	72	\N	463	1239	\N	53.513024999999999	Самарская область, городской округ Тольятти, Центральный район, Мира, 116	Россия, Самарская область, Тольятти, Мира, 116	0101000020E6100000340EF5BBB0B74840E4839ECDAAC14A40
81027	7	72	\N	463	1239	\N	53.509480000000003	Самарская область, городской округ Тольятти, Центральный район, Мира, 121	Россия, Самарская область, Тольятти, Мира, 121	0101000020E610000091D26C1E87B94840A9FB00A436C14A40
79820	7	72	\N	463	1239	\N	53.504896000000002	Самарская область, городской округ Чапаевск, ул.Мира, 7	Россия, Самарская область, Тольятти, Мира, 7	0101000020E6100000519FE40E9BB24840CCF09F6EA0C04A40
80996	7	72	\N	463	7472	\N	53.475388000000002	Самарская область, городской округ Тольятти, Комсомольский район, Матросова, 5	Россия, Самарская область, Тольятти, Матросова, 5	0101000020E6100000153944DC9CBC484097749483D9BC4A40
80989	7	72	\N	463	7472	\N	53.485520999999999	Самарская область, городской округ Тольятти, Комсомольский район, Матросова, 37	Россия, Самарская область, Тольятти, Матросова, 37	0101000020E6100000923D42CD90BC4840B742588D25BE4A40
81041	7	72	\N	463	326	\N	53.521538	Самарская область, городской округ Тольятти, Центральный район, Горького, 47	Россия, Самарская область, Тольятти, Максима Горького, 47	0101000020E61000004A7CEE04FBB5484085CFD6C1C1C24A40
81040	7	72	\N	463	326	\N	53.522255000000001	Самарская область, городской округ Тольятти, Центральный район, Горького, 88	Россия, Самарская область, Тольятти, Максима Горького, 88	0101000020E6100000844BC79C67B6484014967840D9C24A40
81030	7	72	\N	463	326	\N	53.521265	Самарская область, городской округ Тольятти, Центральный район, Горького, 39	Россия, Самарская область, Тольятти, Максима Горького, 39	0101000020E6100000F52B9D0FCFB4484054C6BFCFB8C24A40
81029	7	72	\N	463	326	\N	53.517688	Самарская область, городской округ Тольятти, Центральный район, Горького, 34	Россия, Самарская область, Тольятти, Максима Горького, 34	0101000020E61000006E13EE9579B348400DC4B29943C24A40
80866	7	72	\N	463	326	\N	53.514733	Самарская область, п.г.т. Междуреченск, Горького, 7	Россия, Самарская область, Тольятти, Максима Горького, 7	0101000020E6100000838AAA5FE9B2484003965CC5E2C14A40
80856	7	72	\N	463	326	\N	53.515017	Самарская область,  п.г.т. Балашейка, Горького, 10	Россия, Самарская область, Тольятти, Максима Горького, 10	0101000020E61000006AA33A1DC8B2484028F1B913ECC14A40
80999	7	72	\N	463	47941	\N	53.484116999999998	Самарская область, городской округ Тольятти, Комсомольский район, Майский проезд, 7		0101000020E61000005A677C5F5CC248400438BD8BF7BD4A40
81047	7	72	\N	463	47979	\N	53.540281	Самарская область, городской округ Тольятти, Центральный район, Толстого, 26а		0101000020E6100000AAD6C22CB4B3484039D384ED27C54A40
80952	7	72	\N	463	7074	\N	53.530026035957903	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Луначарского, 11	Россия, Самарская область, Тольятти, Луначарского, 12	0101000020E610000039F2406491A64840CD0358E4D7C34A40
80992	7	72	\N	463	47795	\N	53.511310999999999	Самарская область, городской округ Тольятти, Комсомольский район, Лизы Чайкиной, 69а		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
81049	7	72	\N	463	48460	\N	53.511310999999999	Самарская область, городской округ Тольятти, Центральный район, Лесопарковое шоссе, 2		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
79768	7	72	\N	463	16334	\N	53.508462999999999	город Новокуйбышевск, Лесная, 15	Россия, Самарская область, Тольятти, Лесная, 15	0101000020E61000003D7C992842B24840EF1CCA5015C14A40
80945	7	72	\N	463	6862	\N	53.521538	Самарская область, городской округ Тольятти, Автозаводский район, Ленинский проспект, 20	Россия, Самарская область, Тольятти, Ленинский, 20	0101000020E61000006F826F9A3EA5484085CFD6C1C1C24A40
80928	7	72	\N	463	6862	\N	53.522672999999998	Самарская область, городской округ Тольятти, Автозаводский район, Ленинский проспект, 42	Россия, Самарская область, Тольятти, Ленинский, 42	0101000020E6100000D4D7F335CBA1484048C0E8F2E6C24A40
81019	7	72	\N	463	1053	\N	53.505125999999997	Самарская область, городской округ Тольятти, Центральный район, Ленинградская, 28	Россия, Самарская область, Тольятти, Ленинградская, 28	0101000020E61000006C26DF6C73B34840FD2D01F8A7C04A40
81018	7	72	\N	463	1053	\N	53.502935999999998	Самарская область, городской округ Тольятти, Центральный район, Ленинградская, 33А		0101000020E61000007731CD74AFB3484093FDF33460C04A40
80484	7	72	\N	463	1053	\N	53.504382	Самарская область, городской округ Сызрань, Ленинградская, 10	Россия, Самарская область, Тольятти, Ленинградская, 10	0101000020E6100000C8B260E28FB248407558E1968FC04A40
80465	7	72	\N	463	1053	\N	53.506014999999998	Самарская область, городской округ Октябрьск, улица Ленинградская, 48	Россия, Самарская область, Тольятти, Ленинградская, 48	0101000020E61000001C5F7B6649B4484089247A19C5C04A40
79737	7	72	\N	463	1053	\N	53.503053999999999	город Новокуйбышевск, Ленинградская, 5	Россия, Самарская область, Тольятти, Ленинградская, 5	0101000020E6100000EB1B98DC28B248409D0FCF1264C04A40
95015	7	72	\N	463	1037	\N	53.541356999999998	Самарская область, городской округ Жигулевск, Ленина, д.1, здание школы №16	Россия, Самарская область, Тольятти, Ленина, 3	0101000020E6100000CC086F0F42B44840F73AA92F4BC54A40
81045	7	72	\N	463	1037	\N	53.534891999999999	Самарская область, городской округ Тольятти, Центральный район, Ленина, 58	Россия, Самарская область, Тольятти, Ленина, 58/63	0101000020E61000003F8BA548BEB448402E724F5777C44A40
81043	7	72	\N	463	1037	\N	53.529882999999998	Самарская область, городской округ Тольятти, Центральный район, Ленина, 59	Россия, Самарская область, Тольятти, Ленина, 59	0101000020E61000008CD7BCAAB3B448406ADAC534D3C34A40
81032	7	72	\N	463	1037	\N	53.513908000000001	Самарская область, городской округ Тольятти, Центральный район, Ленина, 108	Россия, Самарская область, Тольятти, Ленина, 108	0101000020E610000089B3226AA2B548408E93C2BCC7C14A40
80471	7	72	\N	463	1037	\N	53.530943000000001	Самарская область, городской округ Октябрьск, улица Ленина, 57	Россия, Самарская область, Тольятти, Ленина, 57/20	0101000020E610000016BEBED6A5B448402385B2F0F5C34A40
79807	7	72	\N	463	1037	\N	53.529342	Самарская область, городской округ Чапаевск, ул.Ленина, 70а	Россия, Самарская область, Тольятти, Ленина, 70	0101000020E61000006E4F90D8EEB448401A33897AC1C34A40
79806	7	72	\N	463	1037	\N	53.531146	Самарская область, городской округ Чапаевск, ул.Ленина, 66	Россия, Самарская область, Тольятти, Ленина, 66/22	0101000020E61000005281936DE0B448405BB39597FCC34A40
81044	7	72	\N	463	8050	\N	53.533602999999999	Самарская область, городской округ Тольятти, Центральный район, Ларина, 66	Россия, Самарская область, Тольятти, Ларина, 66	0101000020E6100000774A07EBFFB448401406651A4DC44A40
80941	7	72	\N	463	6945	\N	53.530188000000003	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Курчатова, 15	Россия, Самарская область, Тольятти, Курчатова, 15	0101000020E610000057EBC4E578A54840A75D4C33DDC34A40
80939	7	72	\N	463	6945	\N	53.530636999999999	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Курчатова, 16	Россия, Самарская область, Тольятти, Курчатова, 16	0101000020E6100000349C3237DFA448401686C8E9EBC34A40
80938	7	72	\N	463	6945	\N	53.535052999999998	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Курчатова, 2	Россия, Самарская область, Тольятти, Курчатова, 2	0101000020E61000008A1D8D43FDA448403750E09D7CC44A40
80927	7	72	\N	463	6828	\N	53.532800000000002	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Кулибина, 17	Россия, Самарская область, Тольятти, Кулибина, 17	0101000020E610000027F56569A7A2484087A757CA32C44A40
80926	7	72	\N	463	6828	\N	53.532687000000003	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Кулибина, 13	Россия, Самарская область, Тольятти, Кулибина, 13	0101000020E6100000D1031F8315A348408F006E162FC44A40
80925	7	72	\N	463	6828	\N	53.534683999999999	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Кулибина, 8	Россия, Самарская область, Тольятти, Кулибина, 8	0101000020E6100000454AB3791CA24840E4D87A8670C44A40
80924	7	72	\N	463	6828	\N	53.535041999999997	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Кулибина, 4	Россия, Самарская область, Тольятти, Кулибина, 4	0101000020E6100000C59107228BA2484043FE99417CC44A40
81000	7	72	\N	463	7606	\N	53.477279000000003	Самарская область, городской округ Тольятти, Комсомольский район, Куйбышева, 24	Россия, Самарская область, Тольятти, Куйбышева, 24	0101000020E610000074CFBA46CBC14840A708707A17BD4A40
80510	7	72	\N	5112	47878	\N	53.1728143774994	Самарская область, городской округ Сызрань, Образцовская, 27	Россия, Самарская область, Сызрань	0101000020E6100000236B0DA5F63E48403E25E7C41E964A40
80970	7	72	\N	463	7268	\N	53.536524999999997	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Космонавтов, 17	Россия, Самарская область, Тольятти, Космонавтов, 17	0101000020E6100000868DB27E33A94840423EE8D9ACC44A40
80933	7	72	\N	463	6896	\N	53.514513000000001	Самарская область, городской округ Тольятти, Автозаводский район, бульвар Королёва, 6	Россия, Самарская область, Тольятти, Королева, 6	0101000020E6100000B62C5F97E1A14840F52EDE8FDBC14A40
81048	7	72	\N	463	8090	\N	53.477252999999997	Самарская область, городской округ Тольятти, Центральный район, Комсомольское шоссе, 1	Россия, Самарская область, Тольятти, Комсомольское, 5	0101000020E6100000F9A23D5E48AF48407D7555A016BD4A40
80519	7	72	647	\N	1829	\N	53.141466167924897	Самарская область, городской округ Сызрань, Комсомольская, 4	Россия, Самарская область, Сызранский район	0101000020E6100000E2033BFE0B3C48407BBFD18E1B924A40
80488	7	72	\N	463	1435	\N	53.476582999999998	Самарская область, городской округ Сызрань, Коммунистическая, 21-а	Россия, Самарская область, Тольятти, Коммунистическая, 21	0101000020E61000007D24253D0CBB48402F6AF7AB00BD4A40
80380	7	72	\N	463	1435	\N	53.476582999999998	Самарская область, городской округ Самара, Ленинский район, Коммунистическая, 25	Россия, Самарская область, Тольятти, Коммунистическая, 21	0101000020E61000007D24253D0CBB48402F6AF7AB00BD4A40
80379	7	72	\N	463	1435	\N	53.473801000000002	Самарская область, городской округ Самара, Ленинский район, Коммунистическая, 16	Россия, Самарская область, Тольятти, Коммунистическая, 18	0101000020E61000005A2E1B9DF3BB4840F3E7DB82A5BC4A40
79758	7	72	\N	463	16279	\N	53.533704	город Новокуйбышевск, Кирова, 21	Россия, Самарская область, Тольятти, Кирова, 19	0101000020E6100000FDBD141E34B3484048DFA46950C44A40
79757	7	72	\N	463	16279	\N	53.537044000000002	город Новокуйбышевск, Кирова, 4	Россия, Самарская область, Тольятти, Кирова, 14/59	0101000020E61000009818CBF44BB64840AB4198DBBDC44A40
81031	7	72	\N	463	960	\N	53.509523000000002	Самарская область, городской округ Тольятти, Центральный район, Карла Маркса, 59	Россия, Самарская область, Тольятти, Карла Маркса, 59	0101000020E61000008A1D8D43FDB44840A8C7B60C38C14A40
81010	7	72	\N	463	47798	\N	53.511310999999999	Самарская область, городской округ Тольятти, Комсомольский район, Ингельберга, 52		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
81008	7	72	\N	463	47798	\N	53.511310999999999	Самарская область, городской округ Тольятти, Комсомольский район, Ингельберга, 1в		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
81020	7	72	\N	463	7839	\N	53.506588000000001	Самарская область, городской округ Тольятти, Центральный район, Жилина, 32	Россия, Самарская область, Тольятти, Жилина, 30	0101000020E6100000B5A4A31CCCB44840E54526E0D7C04A40
80987	7	72	\N	463	7444	\N	53.481513	Самарская область, городской округ Тольятти, Комсомольский район, Есенина, 18	Россия, Самарская область, Тольятти, Есенина, 16	0101000020E6100000FF9600FC53BA4840A7CCCD37A2BD4A40
80951	7	72	\N	463	6953	\N	53.533008000000002	Самарская область, городской округ Тольятти, Автозаводский район, улица Дзержинского, 39	Россия, Самарская область, Тольятти, Дзержинского, 39	0101000020E6100000925A28999CA64840D1402C9B39C44A40
80940	7	72	\N	463	6953	\N	53.534602999999997	Самарская область, городской округ Тольятти, Автозаводский район, улица Дзержинского, 51	Россия, Самарская область, Тольятти, Дзержинского, 51	0101000020E61000007496598462A54840F7AB00DF6DC44A40
80333	7	72	\N	463	6953	\N	53.53349	Самарская область, городской округ Самара, Железнодорожный район, Дзержинского, 32	Россия, Самарская область, Тольятти, Дзержинского, 32	0101000020E61000004A29E8F692AA48401C5F7B6649C44A40
79755	7	72	\N	463	6953	\N	53.533420999999997	город Новокуйбышевск, Дзержинского, 2	Россия, Самарская область, Тольятти, Дзержинского, 12	0101000020E6100000B075A911FAAB4840F3FFAA2347C44A40
79753	7	72	\N	463	6953	\N	53.534180999999997	город Новокуйбышевск, Дзержинского, 41-а	Россия, Самарская область, Тольятти, Дзержинского, 41	0101000020E610000033FB3C4679A648408192020B60C44A40
81033	7	72	\N	463	7897	\N	53.511504000000002	Самарская область, городской округ Тольятти, Центральный район, Голосова, 83	Россия, Самарская область, Тольятти, Голосова, 83	0101000020E610000045F12A6B9BB64840F8E28BF678C14A40
81025	7	72	\N	463	7897	\N	53.507477000000002	Самарская область, городской округ Тольятти, Центральный район, Голосова, 34	Россия, Самарская область, Тольятти, Голосова, 34	0101000020E6100000A10F96B1A1B74840713C9F01F5C04A40
81004	7	72	\N	463	7640	\N	53.472257999999997	Самарская область, городской округ Тольятти, Комсомольский район, Гидротехническая, 37	Россия, Самарская область, Тольятти, Гидротехническая, 37	0101000020E6100000228AC91B60C448401EA33CF372BC4A40
81003	7	72	\N	463	7640	\N	53.473196000000002	Самарская область, городской округ Тольятти, Комсомольский район, Гидротехническая, 31	Россия, Самарская область, Тольятти, Гидротехническая, 29	0101000020E61000004B94BDA59CC348408C4CC0AF91BC4A40
95000	7	72	\N	463	7111	\N	53.541035999999998	Самарская область, г.Тольятти, ул.Ворошилова,3	Россия, Самарская область, Тольятти, Ворошилова, 3	0101000020E610000034BA83D899A84840B5FAEAAA40C54A40
80969	7	72	\N	463	7111	\N	53.541035999999998	Самарская область, городской округ Тольятти, Автозаводский район, улица Ворошилова, 3	Россия, Самарская область, Тольятти, Ворошилова, 3	0101000020E610000034BA83D899A84840B5FAEAAA40C54A40
80547	7	72	\N	5112	47868	\N	53.156308216668499	Самарская область, городской округ Сызрань, Новостроящаяся, 10	Россия, Самарская область, Сызрань	0101000020E6100000F5BD86E0B83C4840350D8AE601944A40
80968	7	72	\N	463	7111	\N	53.535742999999997	Самарская область, городской округ Тольятти, Автозаводский район, улица Ворошилова, 21	Россия, Самарская область, Тольятти, Ворошилова, 21	0101000020E610000025B1A4DC7DA84840CC07043A93C44A40
80961	7	72	\N	463	7111	\N	53.529353	Самарская область, городской округ Тольятти, Автозаводский район, улица Ворошилова, 37	Россия, Самарская область, Тольятти, Ворошилова, 37	0101000020E610000066321CCF67A848400E85CFD6C1C34A40
80956	7	72	\N	463	7111	\N	53.520665000000001	Самарская область, городской округ Тольятти, Автозаводский район, улица Ворошилова, 32	Россия, Самарская область, Тольятти, Ворошилова, 32	0101000020E61000006138D73043A74840FF959526A5C24A40
80955	7	72	\N	463	7111	\N	53.522699000000003	Самарская область, городской округ Тольятти, Автозаводский район, улица Ворошилова, 28	Россия, Самарская область, Тольятти, Ворошилова, 28	0101000020E6100000B79C4B7155A74840725303CDE7C24A40
79974	7	72	\N	463	7111	\N	53.533521999999998	Клявлино ж/д станция, Ворошилова, 25б(интернат)	Россия, Самарская область, Тольятти, Ворошилова, 23	0101000020E61000001E705D3123A8484027D9EA724AC44A40
79743	7	72	\N	463	7111	\N	53.532226999999999	город Новокуйбышевск, Ворошилова, 6	Россия, Самарская область, Тольятти, Ворошилова, 6	0101000020E610000032E719FB92A748402B86AB0320C44A40
79742	7	72	\N	463	7111	\N	53.531236999999997	город Новокуйбышевск, Ворошилова, 12	Россия, Самарская область, Тольятти, Ворошилова, 12	0101000020E6100000083D9B559FA748406BB6F292FFC34A40
95017	7	72	\N	463	7418	\N	53.564203999999997	Самарская область, городской округ Жигулевск, Вокзальная, д.16, здание КДЦ	Россия, Самарская область, Тольятти, Вокзальная, 21	0101000020E61000000FF27A3029A64840DD2230D637C84A40
80984	7	72	\N	463	7418	\N	53.564203999999997	Самарская область, городской округ Тольятти, Автозаводский район, улица Вокзальная, 30А	Россия, Самарская область, Тольятти, Вокзальная, 21	0101000020E61000000FF27A3029A64840DD2230D637C84A40
81016	7	72	\N	463	7770	\N	53.500557999999998	Самарская область, городской округ Тольятти, Центральный район, Белорусская, 14	Россия, Самарская область, Тольятти, Белорусская, 14	0101000020E6100000AC3AAB05F6B2484026E0D74812C04A40
81015	7	72	\N	463	7770	\N	53.499706000000003	Самарская область, городской округ Тольятти, Центральный район, Белорусская, 33	Россия, Самарская область, Тольятти, Белорусская, 33	0101000020E6100000319A95ED43B24840B8CEBF5DF6BF4A40
80930	7	72	\N	463	6864	\N	53.525536000000002	Самарская область, городской округ Тольятти, Автозаводский район, Баумана Бульвар, 3	Россия, Самарская область, Тольятти, Баумана, 3	0101000020E6100000FC17080264A24840726F7EC344C34A40
80929	7	72	\N	463	6864	\N	53.525536000000002	Самарская область, городской округ Тольятти, Автозаводский район, Баумана бульвар, 3	Россия, Самарская область, Тольятти, Баумана, 3	0101000020E6100000FC17080264A24840726F7EC344C34A40
81026	7	72	\N	463	7794	\N	53.507440000000003	Самарская область, городской округ Тольятти, Центральный район, Баныкина, 44	Россия, Самарская область, Тольятти, Баныкина, 44	0101000020E6100000D714C8EC2CB8484054573ECBF3C04A40
81023	7	72	\N	463	7794	\N	53.504252999999999	Самарская область, городской округ Тольятти, Центральный район, Баныкина, 22	Россия, Самарская область, Тольятти, Баныкина, 22	0101000020E61000006AA4A5F276B6484077F4BF5C8BC04A40
81021	7	72	\N	463	7794	\N	53.501908	Самарская область, городской округ Тольятти, Центральный район, Баныкина, 12	Россия, Самарская область, Тольятти, Баныкина, 12	0101000020E6100000A73B4F3C67B54840E6CC76853EC04A40
81017	7	72	\N	463	7794	\N	53.500295000000001	Самарская область, городской округ Тольятти, Центральный район, Баныкина, 4	Россия, Самарская область, Тольятти, Баныкина, 4	0101000020E610000033E02C25CBB3484019ADA3AA09C04A40
80963	7	72	\N	463	7198	\N	53.528137999999998	Самарская область, городской округ Тольятти, Автозаводский район, улица Автостроителей, 92		0101000020E6100000B85B920376A948402EE3A6069AC34A40
80962	7	72	\N	463	7198	\N	53.530054	Самарская область, городской округ Тольятти, Автозаводский район, улица Автостроителей, 84	Россия, Самарская область, Тольятти, Автостроителей, 84	0101000020E61000004148163081A94840978E39CFD8C34A40
79977	7	72	\N	463	3490	\N	53.541142999999998	"Клявлино ж/д станция, 70 лет Октября, 37(ДО ""Прометей"")"	Россия, Самарская область, Тольятти, 70 Лет Октября, 37	0101000020E61000000DFCA886FDAA4840CBBA7F2C44C54A40
81012	7	72	\N	463	47800	\N	53.511310999999999	Самарская область, городской округ Тольятти, Комсомольский район, 60 лет СССР, 17		0101000020E61000008D7DC9C683B54840E38A8BA372C14A40
81011	7	72	\N	463	47800	\N	53.5178171416675	Самарская область, городской округ Тольятти, Комсомольский район, 60 лет СССР, 19	Россия, Самарская область, Тольятти	0101000020E61000007138F3AB39BA48400B28D4D347C24A40
81042	7	72	\N	463	979	\N	53.530959000000003	Самарская область, городской округ Тольятти, Центральный район, бульвар 50 Лет Октября, 61	Россия, Самарская область, Тольятти, 50 Лет Октября, 61	0101000020E6100000DE3AFF76D9B548402942EA76F6C34A40
81038	7	72	\N	463	979	\N	53.526372000000002	Самарская область, городской округ Тольятти, Центральный район, бульвар 50 Лет Октября, 23	Россия, Самарская область, Тольятти, 50 Лет Октября, 23	0101000020E6100000C9586DFE5FB34840DBC35E2860C34A40
80982	7	72	\N	463	7211	\N	53.521076999999998	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 7 (офисное помещение)	Россия, Самарская область, Тольятти, 40 Лет Победы, 13	0101000020E610000070067FBF98A9484051D9B0A6B2C24A40
80980	7	72	\N	463	7211	\N	53.543722000000002	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 10	Россия, Самарская область, Тольятти, 40 Лет Победы, 6	0101000020E61000007C98BD6C3BAF4840D00EB8AE98C54A40
80974	7	72	\N	463	7211	\N	53.536343000000002	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 42	Россия, Самарская область, Тольятти, 40 Лет Победы, 40	0101000020E6100000EB01F39029AD484022382EE3A6C44A40
80973	7	72	\N	463	7211	\N	53.536797	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 44	Россия, Самарская область, Тольятти, 40 Лет Победы, 44	0101000020E6100000B4024356B7AC4840A3CB9BC3B5C44A40
80967	7	72	\N	463	7211	\N	53.530017000000001	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 74	Россия, Самарская область, Тольятти, 40 Лет Победы, 74	0101000020E6100000B69DB64604AB48407AA9D898D7C34A40
80966	7	72	\N	463	7211	\N	53.527929	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 86	Россия, Самарская область, Тольятти, 40 Лет Победы, 86	0101000020E610000015747B4963AA484014CE6E2D93C34A40
80965	7	72	\N	463	7211	\N	53.520364999999998	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 120	Россия, Самарская область, Тольятти, 40 Лет Победы, 120	0101000020E6100000A8565F5D15A84840D47D00529BC24A40
80964	7	72	\N	463	7211	\N	53.522607999999998	Самарская область, городской округ Тольятти, Автозаводский район, улица 40 лет Победы, 106	Россия, Самарская область, Тольятти, 40 Лет Победы, 106	0101000020E61000001615713AC9A848406150A6D1E4C24A40
80844	7	72	\N	55877	47999	\N	53.564098740056302	Ставропольский район, с. Тимофеевка, улица Школьная,61А	Россия, Самарская область, Тольятти	0101000020E61000000723F609A0B24840685A626534C84A40
80504	7	72	\N	5112	47691	\N	53.167605309420502	Самарская область, городской округ Сызрань, пр. 50 лет октября, 42-А	Россия, Самарская область, Сызрань	0101000020E61000002D211FF46C3C4840B3D2A41474954A40
80505	7	72	\N	5112	47806	\N	53.176321114927497	Самарская область, городской округ Сызрань, пр.Гагарина, 75	Россия, Самарская область, Сызрань	0101000020E6100000D218ADA3AA3F48408C4CC0AF91964A40
80503	7	72	\N	5112	47804	\N	53.166212678631602	Самарская область, городской округ Сызрань, пр.50 лет октября, 42-а	Россия, Самарская область, Сызрань	0101000020E610000051A39064563D4840C495B37746954A40
80502	7	72	\N	5112	47804	\N	53.174258363085997	Самарская область, городской округ Сызрань, пр.50 лет октября, 20	Россия, Самарская область, Сызрань	0101000020E6100000D542C9E4D43E48407F880D164E964A40
80501	7	72	\N	5112	47804	\N	53.165593717037801	Самарская область, городской округ Сызрань, пр.50 лет октября, 1	Россия, Самарская область, Сызрань	0101000020E61000005743E21E4B3D4840F834272F32954A40
80500	7	72	\N	5112	47804	\N	53.143140000000002	Самарская область, городской округ Сызрань, пр.50 лет октября, 14	Россия, Самарская область, Сызрань	0101000020E6100000C367EBE0603B4840EE5F596952924A40
80499	7	72	\N	5112	47802	\N	53.176527384630397	Самарская область, городской округ Сызрань, пр.Гагарина, 13	Россия, Самарская область, Сызрань	0101000020E6100000871A8524B33E484035EECD6F98964A40
80529	7	72	\N	5112	47938	\N	53.149497566870799	Самарская область, городской округ Сызрань, пер.Молодогвардейский, 24		0101000020E6100000B9A64066673B4840A1681EC022934A40
80486	7	72	\N	5112	48252	\N	53.136895000000003	г. Сызрань,  пер. Кемеровский, 1		0101000020E6100000FC34EECD6F3A484033FE7DC685914A40
80489	7	72	\N	5112	47766	\N	53.162981971068803	Самарская область, городской округ Сызрань, Щусева, 7	Россия, Самарская область, Сызрань	0101000020E610000058A835CD3B3C484018EB1B98DC944A40
80522	7	72	\N	5112	48313	\N	53.158990901876898	Самарская область, городской округ Сызрань, Школьная, 7		0101000020E610000005A568E55E3C4840DEAD2CD159944A40
80521	7	72	\N	5112	48023	\N	53.155276369809897	Самарская область, городской округ Сызрань, Челюскинцев, 25	Россия, Самарская область, Сызрань	0101000020E6100000DF3653211E3D484046ED7E15E0934A40
80492	7	72	\N	5112	48022	\N	53.175289751464199	Самарская область, городской округ Сызрань, Циолковского, 3	Россия, Самарская область, Сызрань	0101000020E61000009FCBD424783D48406DA818E76F964A40
80514	7	72	\N	5112	48324	\N	53.160848046802897	Самарская область, городской округ Сызрань, Фрунзе, 19	Россия, Самарская область, Сызрань	0101000020E610000053CDACA5803C484042D0D1AA96944A40
80518	7	72	\N	5112	47928	\N	53.1571336762131	Самарская область, городской округ Сызрань, Ульяновская, 145	Россия, Самарская область, Сызрань	0101000020E6100000B77C24253D3C48407A8B87F71C944A40
80517	7	72	\N	5112	47870	\N	53.170132560420598	Самарская область, городской округ Сызрань, Степана Разина, 24	Россия, Самарская область, Сызрань	0101000020E6100000DAE21A9FC93E4840357C0BEBC6954A40
80516	7	72	\N	5112	47870	\N	53.174896134698699	Самарская область, городской округ Сызрань, Степана Разина, 1	Россия, Самарская область, Сызрань	0101000020E610000077D66EBBD03E4840C119FCFD62964A40
80548	7	72	\N	5112	47746	\N	53.171989220952902	Самарская область, городской округ Сызрань, Советская, 81	Россия, Самарская область, Сызрань	0101000020E61000009DA1B8E34D3E4840C9224DBC03964A40
80544	7	72	\N	5112	47746	\N	53.178018076621299	Самарская область, городской округ Сызрань, Советская, 70	Россия, Самарская область, Сызрань	0101000020E610000060AC6F60723D4840B70C384BC9964A40
80520	7	72	\N	5112	48115	\N	53.171782929324699	Самарская область, городской округ Сызрань, Победы, 68	Россия, Самарская область, Сызрань	0101000020E61000004F7974232C3E48401F813FFCFC954A40
80497	7	72	\N	5112	48311	\N	53.144234048494702	Самарская область, городской округ Сызрань, Парижской Коммуны, 65	Россия, Самарская область, Сызрань	0101000020E61000004240BE840A3C4840527C7C4276924A40
80532	7	72	\N	5112	48475	\N	53.157752760405401	Самарская область, городской округ Сызрань, Новосибирская, 39	Россия, Самарская область, Сызрань	0101000020E6100000596DFE5F753C484046EC134031944A40
80550	7	72	\N	5112	47911	\N	53.143392884948199	Самарская область, городской округ Сызрань, Новомайская, 2а		0101000020E61000000CE8853B173C4840D8BCAAB35A924A40
80540	7	72	617	\N	8236	\N	53.143356732409003	Самарская область, городской округ Сызрань, Нефтебазная, 11	Россия, Самарская область, Сызрань	0101000020E61000000D6FD6E07D3B48408B53AD8559924A40
80543	7	72	\N	5112	47876	\N	53.128439603735998	"Самарская область, городской округ Сызрань, Маршала Жукова, ВУНЦ ВВС ""ВВА"""	Россия, Самарская область, Сызрань	0101000020E610000062A06B5F40354840C6BFCFB870904A40
80549	7	72	\N	5112	47871	\N	53.180240068870503	Самарская область, городской округ Сызрань, Людиновская, 23	Россия, Самарская область, Сызрань	0101000020E6100000B328ECA2E83D48402CB7B41A12974A40
80511	7	72	\N	5112	48314	\N	53.156927312822198	Самарская область, городской округ Сызрань, Ленина, 20	Россия, Самарская область, Сызрань	0101000020E610000053CDACA5803C4840016E162F16944A40
80530	7	72	\N	5112	47685	\N	53.143140000000002	Самарская область, городской округ Сызрань, Краснознаменная, 23	Россия, Самарская область, Сызрань	0101000020E6100000C367EBE0603B4840EE5F596952924A40
80487	7	72	\N	5112	47801	\N	53.182508772513103	Самарская область, городской округ Сызрань, Красина, 3	Россия, Самарская область, Сызрань	0101000020E6100000FCFCF7E0B53F4840E31C75745C974A40
80485	7	72	\N	5112	47955	\N	53.156927312822198	Самарская область, городской округ Сызрань, пер.Кемеровский, 1	Россия, Самарская область, Сызрань	0101000020E61000000B45BA9F533C4840016E162F16944A40
80546	7	72	\N	5112	47912	\N	53.157127126609197	Самарская область, городской округ Сызрань, Карла Маркса, 104	Россия, Самарская область, Сызрань	0101000020E610000073124A5F083D4840C828CFBC1C944A40
80528	7	72	\N	5112	47934	\N	53.153006219001902	Самарская область, городской округ Сызрань, Карбышева, 2	Россия, Самарская область, Сызрань	0101000020E6100000091B9E5E293D4840BF0B5BB395934A40
80526	7	72	\N	5112	47908	\N	53.136270498768297	Самарская область, городской округ Сызрань, Интернациональная, 178	Россия, Самарская область, Сызрань	0101000020E6100000E9279CDD5A3A484085B69C4B71914A40
80513	7	72	\N	5112	47908	\N	53.136167250277303	Самарская область, городской округ Сызрань, Интернациональная, 143	Россия, Самарская область, Сызрань	0101000020E61000009ECF807A333A4840B0E595EB6D914A40
80509	7	72	\N	5112	47729	\N	53.143140000000002	Самарская область, городской округ Сызрань, Звездная, 8	Россия, Самарская область, Сызрань	0101000020E6100000C367EBE0603B4840EE5F596952924A40
80508	7	72	\N	5112	47729	\N	53.157959119809199	Самарская область, городской округ Сызрань, Звездная, 48	Россия, Самарская область, Сызрань	0101000020E6100000CBD93BA3AD3C4840EF8D210038944A40
80506	7	72	\N	5112	47729	\N	53.136895000000003	г. Сызрань,  ул. Звездная, 8		0101000020E6100000FC34EECD6F3A484033FE7DC685914A40
80534	7	72	\N	5112	47769	\N	53.183539961580898	Самарская область, городской округ Сызрань, Заборовская, 20	Россия, Самарская область, Сызрань	0101000020E61000005E82531F4840484001C11C3D7E974A40
80542	7	72	\N	5112	48350	\N	53.158578192040203	Самарская область, городской округ Сызрань, Ерамасова, в/ч 13826	Россия, Самарская область, Сызрань	0101000020E61000000B45BA9F533C4840BBEEAD484C944A40
80539	7	72	\N	5112	47917	\N	53.1363736485605	Самарская область, городской округ Сызрань, Декабристов, 436	Россия, Самарская область, Сызрань	0101000020E6100000103CBEBD6B3A48402A0307B474914A40
80538	7	72	\N	5112	47917	\N	53.144975479437399	Самарская область, городской округ Сызрань, Декабристов, 191	Россия, Самарская область, Сызрань	0101000020E61000000CE8853B173C48406ADE718A8E924A40
80537	7	72	\N	5112	47917	\N	53.182921251129798	Самарская область, городской округ Сызрань, Декабристов, 72	Россия, Самарская область, Сызрань	0101000020E61000007E7214200A424840356090F469974A40
80536	7	72	\N	5112	47917	\N	53.179208800080701	Самарская область, городской округ Сызрань, Декабристов, 30	Россия, Самарская область, Сызрань	0101000020E61000006E693524EE3F48400E130D52F0964A40
80552	7	72	\N	5112	47914	\N	53.1598627584507	Самарская область, городской округ Сызрань, Дальневосточная, 38	Россия, Самарская область, Сызрань	0101000020E6100000C828CFBC1C3C4840946B0A6476944A40
80527	7	72	\N	5112	47932	\N	53.156514583049898	Самарская область, городской округ Сызрань, Гончарная, 17		0101000020E61000007DB1F7E28B3C4840AE2AFBAE08944A40
80523	7	72	\N	5112	48116	\N	53.161467077170002	Самарская область, городской округ Сызрань, Гоголя, 30	Россия, Самарская область, Сызрань	0101000020E6100000596DFE5F753C48400E315EF3AA944A40
80525	7	72	\N	5112	47867	\N	53.156514583049898	Самарская область, городской округ Сызрань, Гидротурбинная, 5	Россия, Самарская область, Сызрань	0101000020E610000021CCED5EEE3B4840AE2AFBAE08944A40
80524	7	72	\N	5112	47867	\N	53.152799835674799	Самарская область, городской округ Сызрань, Гидротурбинная, 28	Россия, Самарская область, Сызрань	0101000020E6100000BD1C76DF313C4840166A4DF38E934A40
80541	7	72	\N	5112	48162	\N	53.172195511584498	Самарская область, городской округ Сызрань, Бородинский проезд, 1	Россия, Самарская область, Сызрань	0101000020E61000008CBAD6DEA73E48404240BE840A964A40
80483	7	72	\N	5112	48128	\N	53.144337260968001	Самарская область, городской округ Сызрань, Байкальская, 6	Россия, Самарская область, Сызрань	0101000020E61000005B971AA19F3B4840274D83A279924A40
80496	7	72	\N	5112	47684	\N	53.159197255300199	Самарская область, городской округ Сызрань, Астраханская, 31	Россия, Самарская область, Сызрань	0101000020E6100000910E0F61FC3C4840874F3A9160944A40
80495	7	72	\N	5112	47684	\N	53.176114844228003	Самарская область, городской округ Сызрань, Астраханская, 38	Россия, Самарская область, Сызрань	0101000020E6100000503A9160AA434840E3AAB2EF8A964A40
80494	7	72	\N	5112	47684	\N	53.143140000000002	Самарская область, городской округ Сызрань, Астраханская, 2-А	Россия, Самарская область, Сызрань	0101000020E6100000C367EBE0603B4840EE5F596952924A40
80490	7	72	\N	5112	47684	\N	53.174052082420602	Самарская область, городской округ Сызрань, Астраханская, 12	Россия, Самарская область, Сызрань	0101000020E610000060AC6F60723F4840D6E6FF5547964A40
80551	7	72	\N	5112	47732	\N	53.143140000000002	Самарская область, городской округ Сызрань, 2-я Железнодорожная, 26	Россия, Самарская область, Сызрань	0101000020E6100000C367EBE0603B4840EE5F596952924A40
80187	7	72	\N	55917	48452	\N	53.276443144244297	Самарская область, городской округ Самара, Кировский район, Студеный овраг третья линия, 34А	Россия, Самарская область, Самара, Кировский район	0101000020E6100000707D586FD41A4940A41AF67B62A34A40
80225	7	72	\N	32	\N	\N	53.327879455566404	"Самарская область, городской округ Самара, Красноглинский район, Здание аэровокзала ОАО ""Международный аэропорт Курумоч"""	Россия, Самарская область, Самара, Красноглинский район	0101000020E6100000FC51D4997B1E4940C90567F0F7A94A40
80147	7	72	\N	32	\N	\N	53.249893	"Самарская область, городской округ Самара, Кировский район, Аэропорт ""Смышляевка"", нежилое здание литера А4"		0101000020E61000006FBA6587F82F4940EA3F6B7EFC9F4A40
79747	7	72	\N	32	49	\N	53.201892999999998	город Новокуйбышевск, Гагарина, 4	Россия, Самарская область, Самара, улица Юрия Гагарина, 4	0101000020E6100000669FC728CF1449404A253CA1D7994A40
80384	7	72	\N	32	1467	\N	53.208537	Самарская область, город Самара, Октябрьский район, Циолковского, 1	Россия, Самарская область, Самара, улица Циолковского, 1	0101000020E6100000297B4B395F104940C3802557B19A4A40
80365	7	72	\N	32	15792	\N	53.138542999999999	Самарская область, городской округ Самара, Куйбышевский район, Центральная, 11а	Россия, Самарская область, Самара, Куйбышевский район, улица Центральная, 11а	0101000020E61000002C0DFCA8861349407C0BEBC6BB914A40
80231	7	72	\N	32	723	\N	53.216183999999998	Самарская область, городской округ Самара, Промышленный район, Физкультурная, 104	Россия, Самарская область, Самара, улица Физкультурная, 104	0101000020E610000073BA2C263621494090F5D4EAAB9B4A40
80512	7	72	647	\N	1759	\N	53.142291914201103	Самарская область, городской округ Сызрань, Урицкого, 2		0101000020E6100000E2033BFE0B3C4840C03DCF9F36924A40
80230	7	72	\N	32	6472	\N	53.217801999999999	Самарская область, городской округ Самара, Промышленный район, Теннисная, 25в	Россия, Самарская область, Самара, улица Теннисная, 25в	0101000020E6100000E63E390A102349406F8099EFE09B4A40
80238	7	72	\N	32	28764	\N	53.216194999999999	Самарская область, городской округ Самара, Промышленный район, Средне-Садовая, 57	Россия, Самарская область, Самара, улица Среднесадовая, 57	0101000020E6100000DDCD531D721D494084471B47AC9B4A40
80431	7	72	\N	32	184	\N	53.219068999999998	Самарская область, город Самара, Советский район, Советской Армии, 161А	Россия, Самарская область, Самара, улица Советской Армии, 161а	0101000020E6100000AC00DF6DDE1A4940A148F7730A9C4A40
80409	7	72	\N	32	184	\N	53.235304999999997	Самарская область, город Самара, Октябрьский район, Советской Армии, 230	Россия, Самарская область, Самара, улица Советской Армии, 230	0101000020E6100000B727486C77174940EACA67791E9E4A40
95014	7	72	\N	32	47926	\N	53.204211999999998	Самарская область, городской округ Жигулевск, Полевая, д.22		0101000020E6100000B8020AF5F40F4940B2B96A9E239A4A40
79761	7	72	\N	32	16299	\N	53.163103999999997	город Новокуйбышевск, Пирогова, 16-б	Россия, Самарская область, Самара, улица Пирогова	0101000020E610000080608E1EBF09494063EC8497E0944A40
80385	7	72	\N	32	6716	\N	53.207253999999999	Самарская область, город Самара, Октябрьский район, Ново-Садовая, 11	Россия, Самарская область, Самара, улица Ново-Садовая, 11	0101000020E61000009EB7B1D9911049408BFB8F4C879A4A40
80254	7	72	\N	32	6716	\N	53.256509000000001	Самарская область, городской округ Самара, Промышленный район, Ново-Садовая, 377	Россия, Самарская область, Самара, улица Ново-Садовая, 377	0101000020E6100000711DE38A8B1B494099107349D5A04A40
80316	7	72	\N	32	7309	\N	53.180602999999998	Самарская область, городской округ Самара, Железнодорожный район, Мостовая, 12	Россия, Самарская область, Самара, улица Мостовая, 12	0101000020E61000007F85CC95411149409D47C5FF1D974A40
80339	7	72	\N	32	799	\N	53.196514999999998	Самарская область, городской округ Самара, Железнодорожный район, Мориса Тореза, 67А	Россия, Самарская область, Самара, улица Мориса Тореза, 67а	0101000020E61000002AC76471FF17494033164D6727994A40
80417	7	72	\N	32	47964	\N	53.1841277488831	Самарская область, городской округ Самара, Самарский район, Максима Горького, 65/67	Россия, Самарская область, Самара, улица Максима Горького, 65	0101000020E610000005E10A28D409494092239D8191974A40
80424	7	72	\N	32	434	\N	53.192225999999998	Самарская область, городской округ Самара, Самарский район, Льва Толстого, 23	Россия, Самарская область, Самара, улица Льва Толстого, 23	0101000020E6100000558847E2E50B49406FB88FDC9A984A40
80152	7	72	\N	32	5653	\N	53.229905000000002	Самарская область, городской округ Самара, Кировский район, Литвинова, 272	Россия, Самарская область, Самара, улица Литвинова, 272	0101000020E61000004F07B29E5A274940EC17EC866D9D4A40
80367	7	72	\N	32	413	\N	53.195759000000002	Самарская область, городской округ Самара, Ленинский район, Куйбышева, 151	Россия, Самарская область, Самара, улица Куйбышева, 151	0101000020E6100000ADFC3218230C4940E77283A10E994A40
80328	7	72	\N	32	48060	\N	53.199384000000002	Самарская область, городской округ Самара, Железнодорожный район, Тухачевского, 224		0101000020E61000006F675F79901449403FAC376A85994A40
80165	7	72	\N	32	5818	\N	53.230665000000002	Самарская область, городской округ Самара, Кировский район, проспект Юных Пионеров, 154А	Россия, Самарская область, Самара, проспект Юных Пионеров, 154а	0101000020E6100000F25B74B2D42049407AAA436E869D4A40
80159	7	72	\N	32	5760	\N	53.231068999999998	Самарская область, городской округ Самара, Кировский район, проспект Металлургов, 52	Россия, Самарская область, Самара, проспект Металлургов, 52	0101000020E610000004711E4E60224940490F43AB939D4A40
80397	7	72	\N	32	8147	\N	53.207102999999996	Самарская область, город Самара, Октябрьский район, Масленникова проспект, 26	Россия, Самарская область, Самара, проспект Масленникова, 26	0101000020E6100000745E6397A8144940A5F3E159829A4A40
80396	7	72	\N	32	8147	\N	53.208176000000002	Самарская область, город Самара, Октябрьский район, Масленникова проспект, 22	Россия, Самарская область, Самара, проспект Масленникова, 22	0101000020E6100000B9A981E673144940F3E7DB82A59A4A40
80395	7	72	\N	32	8147	\N	53.207614999999997	Самарская область, город Самара, Октябрьский район, Масленникова проспект, 37	Россия, Самарская область, Самара, проспект Масленникова, 37	0101000020E610000009FA0B3D621449405B94D920939A4A40
80389	7	72	\N	32	8092	\N	53.209104000000004	Самарская область, город Самара, Октябрьский район, Ленина,14а	Россия, Самарская область, Самара, проспект Ленина, 14а	0101000020E6100000E8BCC62E511149403DBB7CEBC39A4A40
80246	7	72	\N	32	5819	\N	53.245863	Самарская область, городской округ Самара, Промышленный район, пр.Кирова, 252	Россия, Самарская область, Самара, проспект Кирова, 252	0101000020E61000006C054D4BAC1C4940F2255470789F4A40
80227	7	72	\N	32	5819	\N	53.201801000000003	Самарская область, городской округ Самара, Промышленный район, пр.Кирова, 69	Россия, Самарская область, Самара, проспект Кирова, 69	0101000020E6100000C5C551B9892449406AA67B9DD4994A40
80173	7	72	\N	32	5819	\N	53.248600000000003	Самарская область, городской округ Самара, Кировский район, проспект Кирова, 319	Россия, Самарская область, Самара, проспект Кирова, 319	0101000020E6100000572426A8E11D49408FE4F21FD29F4A40
80171	7	72	\N	32	5819	\N	53.243507999999999	Самарская область, городской округ Самара, Кировский район, проспект Кирова, 277	Россия, Самарская область, Самара, проспект Кирова, 277	0101000020E6100000B8B06EBC3B1E49403D2828452B9F4A40
80170	7	72	\N	32	5819	\N	53.231371000000003	Самарская область, городской округ Самара, Кировский район, проспект Кирова, 199	Россия, Самарская область, Самара, проспект Кирова, 199	0101000020E6100000C90567F0F71F4940151F9F909D9D4A40
80168	7	72	\N	32	5819	\N	53.229101999999997	Самарская область, городской округ Самара, Кировский район, проспект Кирова, 193	Россия, Самарская область, Самара, проспект Кирова, 193	0101000020E6100000B151D66F262049405EB9DE36539D4A40
80166	7	72	\N	32	5819	\N	53.225560000000002	Самарская область, городской округ Самара, Кировский район, проспект Кирова, 177	Россия, Самарская область, Самара, проспект Кирова, 177	0101000020E6100000A7ECF483BA20494094A46B26DF9C4A40
80412	7	72	\N	32	247	\N	53.208720999999997	Самарская область, город Самара, Октябрьский район, Карла Маркса проспект, 183		0101000020E61000006327BC04A7164940847EA65EB79A4A40
80244	7	72	\N	32	247	\N	53.236452999999997	Самарская область, городской округ Самара, Промышленный район, пр.Карла Маркса, 336	Россия, Самарская область, Самара, проспект Карла Маркса, 336	0101000020E6100000D80FB1C1C21D494042058717449E4A40
80243	7	72	\N	32	247	\N	53.22963	Самарская область, городской округ Самара, Промышленный район, пр.Карла Маркса, 278	Россия, Самарская область, Самара, проспект Карла Маркса, 278	0101000020E61000002FDCB930D21B49401A170E84649D4A40
80241	7	72	\N	32	247	\N	53.228282	Самарская область, городской округ Самара, Промышленный район, пр.Карла Маркса, 276	Россия, Самарская область, Самара, проспект Карла Маркса, 276	0101000020E610000027BEDA519C1B4940FB213658389D4A40
80180	7	72	\N	32	247	\N	53.243862999999997	Самарская область, городской округ Самара, Кировский район, проспект Карла Маркса, 447	Россия, Самарская область, Самара, проспект Карла Маркса, 453	0101000020E6100000F3380CE6AF2049402BDA1CE7369F4A40
80172	7	72	\N	32	247	\N	53.243411000000002	Самарская область, городской округ Самара, Кировский район, проспект Карла Маркса, 394А	Россия, Самарская область, Самара, проспект Карла Маркса, 394а	0101000020E61000000CB1FA230C1F49404B3E7617289F4A40
80215	7	72	\N	32	48257	\N	53.369737021716901	Самарская область, городской округ Самара, Красноглинский район, пос.Южный, 31	Россия, Самарская область, Самара, Красноглинский район, 5-й Южный квартал, 31	0101000020E61000003DD68C0C72174940828FC18A53AF4A40
80233	7	72	\N	32	6507	\N	53.215974000000003	Самарская область, городской округ Самара, Промышленный район, пер.Штамповщиков, 5	Россия, Самарская область, Самара, переулок Штамповщиков, 5	0101000020E61000001B834E081D204940A6643909A59B4A40
80361	7	72	\N	32	47782	\N	53.120508223937399	Самарская область, городской округ Самара, Куйбышевский район, Ново-Молодежный переулок, 19	Россия, Самарская область, Самара, переулок Новомолодежный	0101000020E610000076FC1708020C494004745FCE6C8F4A40
80433	7	72	\N	32	552	\N	53.208893000000003	Самарская область, город Самара, Советский район, Лучистый переулок, 3А		0101000020E610000000732D5A8018494082AE7D01BD9A4A40
80345	7	72	\N	32	7656	\N	53.121302	Самарская область, городской округ Самара, Куйбышевский район, Долотный переулок, 4	Россия, Самарская область, Самара, переулок Долотный, 4	0101000020E610000098DD9387850A49403E78EDD2868F4A40
80200	7	72	\N	32	48110	\N	53.299906	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, квартал 4, 10	Россия, Самарская область, Самара, Красноглинский район, 4-й квартал Мехзавода, 10	0101000020E6100000060DFD135C244940E5EFDE5163A64A40
80203	7	72	\N	32	47980	\N	53.303651000000002	Самарская область, городской округ Самара, Красноглинский район, квартал 3, 46		0101000020E6100000E3FDB8FDF2234940E8323509DEA64A40
80204	7	72	\N	32	48000	\N	53.302385999999998	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, квартал 13, 13		0101000020E6100000A4A7C821E222494056629E95B4A64A40
80198	7	72	\N	32	48071	\N	53.299179000000002	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, квартал 10, 15	Россия, Самарская область, Самара, Красноглинский район, 10-й квартал Мехзавода, 15	0101000020E610000078CF81E50825494033535A7F4BA64A40
80337	7	72	\N	32	47915	\N	53.198321999999997	Самарская область, городской округ Самара, Железнодорожный район, Гагарина, 39	Россия, Самарская область, Самара, улица Юрия Гагарина, 39	0101000020E6100000098CF50D4C164940E509849D62994A40
80457	7	72	\N	32	48045	\N	53.199739999999998	Самарская область, город Самара, Советский район, Гагарина, 105А		0101000020E61000009D685721E5194940FDD98F1491994A40
80434	7	72	\N	32	48045	\N	53.201936000000003	Самарская область, город Самара, Советский район, Гагарина, 88А		0101000020E6100000D7BE805EB81949404AF1F109D9994A40
80400	7	72	\N	32	48045	\N	53.200609	Самарская область, город Самара, Октябрьский район, Гагарина, 18		0101000020E6100000F12BD670911549404224438EAD994A40
80349	7	72	\N	32	7700	\N	53.124803999999997	Самарская область, городской округ Самара, Куйбышевский район, Эльтонская, 1	Россия, Самарская область, Самара, Эльтонская улица, 1	0101000020E610000015376E313F0749407A34D593F98F4A40
80461	7	72	\N	32	48092	\N	53.183813999999998	Самарская область, город Самара, Советский район, Экспериментальная, 5		0101000020E6100000FCC401F4FB1E49400246973787974A40
79810	7	72	\N	32	48030	\N	53.240436000000003	Самарская область, городской округ Чапаевск, ул.Щорса, 33		0101000020E6100000168A743FA7284940FA635A9BC69E4A40
80381	7	72	\N	32	7373	\N	53.199854000000002	Самарская область, городской округ Самара, Ленинский район, Чернореченская, 67	Россия, Самарская область, Самара, Чернореченская улица, 67	0101000020E610000098DBBDDC27134940C6FCDCD094994A40
80323	7	72	\N	32	47986	\N	53.193854999999999	Самарская область, городской округ Самара, Железнодорожный район, Чернореченская, 21		0101000020E6100000D2AC6C1FF210494042959A3DD0984A40
80322	7	72	\N	32	47986	\N	53.193564000000002	Самарская область, городской округ Самара, Железнодорожный район, Чернореченская, 19		0101000020E610000023DA8EA9BB1049406BD784B4C6984A40
80184	7	72	\N	32	6011	\N	53.245021999999999	Самарская область, городской округ Самара, Кировский район, Черемшанская, 244	Россия, Самарская область, Самара, Черемшанская улица, 244	0101000020E6100000CBA145B6F3214940776682E15C9F4A40
80240	7	72	\N	32	47993	\N	53.22287	Самарская область, городской округ Самара, Промышленный район, Черемшанская, 2а		0101000020E6100000FA5FAE450B1C494038A11001879C4A40
80183	7	72	\N	32	47993	\N	53.243060999999997	Самарская область, городской округ Самара, Кировский район, Черемшанская, 222		0101000020E610000076C4211B482149406EF7729F1C9F4A40
80419	7	72	\N	32	47952	\N	53.184240000000003	Самарская область, городской округ Самара, Самарский район, Чапаевская, 74		0101000020E6100000F31E679AB00B4940BA4E232D95974A40
80491	7	72	\N	32	48020	\N	53.209702	Самарская область, городской округ Сызрань, Циолковского, 7		0101000020E6100000D670917BBA104940F1F3DF83D79A4A40
79995	7	72	\N	32	48691	\N	53.141027999999999	Зеленый Ключ деревня, Центральная, 39(школа)		0101000020E6100000B64DF1B8A8124940FFE89B340D924A40
80441	7	72	\N	32	47677	\N	53.2118069895172	Самарская область, город Самара, Советский район, Двадцать Второго Партсъезда, 31	Россия, Самарская область, Самара, улица ХХII Партсъезда, 31	0101000020E610000040A6B5696C1D49402D08E57D1C9B4A40
95019	7	72	\N	32	48104	\N	53.181536999999999	"Самарская область, городской округ Жигулевск, Фрунзе, д.36, ДК ""ЛУЧ"""		0101000020E610000050FBAD9D280B4940C901BB9A3C974A40
80351	7	72	\N	32	48067	\N	53.145279000000002	Самарская область, городской округ Самара, Куйбышевский район, Флотская, 9а		0101000020E6100000B58B69A67B054940D6E5948098924A40
80445	7	72	\N	32	47998	\N	53.210560000000001	Самарская область, город Самара, Советский район, Физкультурная, 92		0101000020E61000005E8429CAA51F494042EC4CA1F39A4A40
80444	7	72	\N	32	47998	\N	53.208455999999998	Самарская область, город Самара, Советский район, Физкультурная, 82		0101000020E61000001FA16648151F4940D653ABAFAE9A4A40
80232	7	72	\N	32	47998	\N	53.212992	Самарская область, городской округ Самара, Промышленный район, Физкультурная, 98б		0101000020E61000003370404B57204940A2276552439B4A40
80157	7	72	\N	32	47998	\N	53.222492000000003	Самарская область, городской округ Самара, Кировский район, Физкультурная, 126		0101000020E61000001DCBBBEA0123494092CF2B9E7A9C4A40
80360	7	72	\N	32	48036	\N	53.113394999999997	Самарская область, городской округ Самара, Куйбышевский район, Фасадная, 2а		0101000020E61000005E4BC8073D094940D44334BA838E4A40
80515	7	72	\N	32	47763	\N	53.189765000000001	Самарская область, городской округ Сызрань, Урицкого, 95		0101000020E6100000CC0BB08F4E114940757632384A984A40
80321	7	72	\N	32	47763	\N	53.189996999999998	Самарская область, городской округ Самара, Железнодорожный район, Урицкого, 3		0101000020E61000008FC536A96810494047AB5AD251984A40
80320	7	72	\N	32	47763	\N	53.190246000000002	Самарская область, городской округ Самара, Железнодорожный район, Урицкого, 1		0101000020E61000002384471B47104940F0181EFB59984A40
72819	7	71	\N	16298	51714	\N	56.759227000000003	г. Чайковский, ул. К.Мракса, 30А		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
80148	7	72	\N	32	48056	\N	53.252619000000003	Самарская область, городской округ Самара, Кировский район, Транзитная, 111		0101000020E610000061FE0A992B2B494093ACC3D155A04A40
80258	7	72	\N	32	48081	\N	53.265594999999998	Самарская область, городской округ Самара, Промышленный район, Тополей, 10		0101000020E6100000A8AB3B16DB1C4940957D5704FFA14A40
80181	7	72	\N	32	48048	\N	53.242871999999998	Самарская область, городской округ Самара, Кировский район, Ташкентская, 88		0101000020E6100000E21FB6F4682049409B8E006E169F4A40
80176	7	72	\N	32	48065	\N	53.255921074647397	Самарская область, городской округ Самара, Кировский район, Ташкентская, 164	Россия, Самарская область, Самара, Кировский район, Ташкентская улица, 164	0101000020E6100000E0BDA3C6841E494008AEF204C2A04A40
80373	7	72	\N	32	47923	\N	53.202253257392698	Самарская область, городской округ Самара, Ленинский район, Студенческий переулок, 2	Россия, Самарская область, Самара, Студенческий переулок, 2	0101000020E61000006A32E36DA50D49404A42226DE3994A40
80342	7	72	\N	32	48095	\N	53.175092999999997	Самарская область, городской округ Самара, Железнодорожный район, Структурная, 48		0101000020E61000001C0934D8D415494017618A7269964A40
80420	7	72	\N	32	48085	\N	53.183382000000002	Самарская область, городской округ Самара, Самарский район, Степана Разина, 46		0101000020E610000074417DCB9C0A49406956B60F79974A40
80418	7	72	\N	32	48085	\N	53.184866	Самарская область, городской округ Самара, Самарский район, Степана Разина, 49	Россия, Самарская область, Самара, улица Степана Разина, 49	0101000020E6100000B2F1608BDD0A4940381268B0A9974A40
80426	7	72	\N	32	47991	\N	53.225495000000002	Самарская область, город Самара, Советский район, Стара-Загора, 37А		0101000020E6100000D350A390641A4940AD342905DD9C4A40
80245	7	72	\N	32	47991	\N	53.237476999999998	Самарская область, городской округ Самара, Промышленный район, Стара-Загора, 151		0101000020E6100000D6E253008C1D4940AE4676A5659E4A40
80185	7	72	\N	32	47991	\N	53.252236000000003	Самарская область, городской округ Самара, Кировский район, Стара-Загора, 226А		0101000020E6100000B24B546F0D204940DB6FED4449A04A40
80179	7	72	\N	32	47991	\N	53.248885000000001	Самарская область, городской округ Самара, Кировский район, Стара-Загора, 269		0101000020E6100000622EA9DA6E20494084BBB376DB9F4A40
80239	7	72	\N	32	48107	\N	53.225597999999998	Самарская область, городской округ Самара, Промышленный район, Ставропольская, 116		0101000020E61000002829B000A61E494081053065E09C4A40
80319	7	72	\N	32	48063	\N	53.188151408157601	Самарская область, городской округ Самара, Железнодорожный район, Спортивная, 11	Россия, Самарская область, Самара, улица Спортивная, 11	0101000020E6100000A587A1D5C90F4940D7DAFB5415984A40
80261	7	72	\N	32	47981	\N	53.243326020784501	Самарская область, городской округ Самара, Промышленный район, Солнечная, 19/26		0101000020E610000008008E3D7B1849401D226E4E259F4A40
80264	7	72	\N	32	47977	\N	53.264093000000003	Самарская область, городской округ Самара, Промышленный район, Солнечная, 63		0101000020E61000000E87A5811F1B4940200DA7CCCDA14A40
80263	7	72	\N	32	47977	\N	53.256847999999998	Самарская область, городской округ Самара, Промышленный район, Солнечная, 43		0101000020E6100000683C11C4791A494081053065E0A04A40
80262	7	72	\N	32	47977	\N	53.246276999999999	Самарская область, городской округ Самара, Промышленный район, Солнечная, 27		0101000020E610000085EB51B81E194940E5603601869F4A40
80213	7	72	\N	32	48089	\N	53.348241000000002	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, Солдатская, 2		0101000020E6100000707D586FD41A49402C103D2993AC4A40
80453	7	72	\N	32	48042	\N	53.195462999999997	Самарская область, город Самара, Советский район, Советской Армии, 5А		0101000020E610000078978BF84E1C4940FD497CEE04994A40
80436	7	72	\N	32	48042	\N	53.203662000000001	Самарская область, город Самара, Советский район, Советской Армии, 74		0101000020E6100000A67C08AA461B49400FB8AE98119A4A40
80429	7	72	\N	32	48042	\N	53.216259999999998	Самарская область, город Самара, Советский район, Советской Армии, 141		0101000020E6100000E8BD3104001B49406BB75D68AE9B4A40
80408	7	72	\N	32	48042	\N	53.242472999999997	Самарская область, город Самара, Октябрьский район, Советской Армии, 271		0101000020E61000001E8CD82780164940DD94F25A099F4A40
80257	7	72	\N	32	48111	\N	53.262498000000001	Самарская область, городской округ Самара, Промышленный район, Силина, 10		0101000020E61000006AA164726A1D4940F9A1D28899A14A40
80356	7	72	\N	32	47950	\N	53.139142999999997	Самарская область, городской округ Самара, Куйбышевский район, Силаева, 1		0101000020E610000010EA2285B2104940D13B1570CF914A40
80493	7	72	\N	32	48021	\N	53.346124000000003	Самарская область, городской округ Сызрань, Лазо, 17		0101000020E61000006E693524EE1B49402C2E8ECA4DAC4A40
80211	7	72	\N	32	48021	\N	53.345866000000001	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, Сергея Лазо, 21		0101000020E61000000C790437521C494030664B5645AC4A40
80208	7	72	\N	32	48021	\N	53.345999999999997	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, Сергея Лазо, 23		0101000020E61000002D5BEB8B841C49403F355EBA49AC4A40
80206	7	72	\N	32	48021	\N	53.346279000000003	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, Сергея Лазо, 33		0101000020E6100000CD04C3B9861D49405325CADE52AC4A40
80448	7	72	\N	32	48027	\N	53.214281	Самарская область, город Самара, Советский район, Свободы, 81Б		0101000020E61000005F28603B181F4940BC934F8F6D9B4A40
80438	7	72	\N	32	48027	\N	53.209519	Самарская область, город Самара, Советский район, Свободы, 2А		0101000020E6100000C7F65AD07B1D49400072C284D19A4A40
80437	7	72	\N	32	48027	\N	53.209097999999997	Самарская область, город Самара, Советский район, Свободы, 2Б		0101000020E610000022FC8BA0311D49405AD427B9C39A4A40
72822	7	71	\N	16298	51512	\N	56.759227000000003	г.Чайковский, ул.К.Маркса, д.16/1		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
80163	7	72	\N	32	48027	\N	53.234378	Самарская область, городской округ Самара, Кировский район, Свободы, 193		0101000020E610000085EE92382B24494071732A19009E4A40
80160	7	72	\N	32	48027	\N	53.223208999999997	Самарская область, городской округ Самара, Кировский район, Свободы, 129		0101000020E61000006F0C01C0B12149402096CD1C929C4A40
95016	7	72	\N	32	47975	\N	53.181930999999999	Самарская область, городской округ Жигулевск, Самарская, д.16, здание школы №3		0101000020E61000006DC5FEB27B0C49407590D78349974A40
80375	7	72	\N	32	47975	\N	53.200463141339803	Самарская область, городской округ Самара, Ленинский район, Самарская, 205а		0101000020E6100000AF795567B50E49406E8786C5A8994A40
80369	7	72	\N	32	47975	\N	53.197215999999997	Самарская область, городской округ Самара, Ленинский район, Самарская, 152		0101000020E6100000F8C43A55BE0D4940BC1FB75F3E994A40
80422	7	72	\N	32	47985	\N	53.182923000000002	Самарская область, городской округ Самара, Самарский район, Садовая, 30		0101000020E6100000BB7EC16ED80C4940D65757056A974A40
79766	7	72	\N	32	48055	\N	53.180672999999999	город Новокуйбышевск, Садовая, 4		0101000020E6100000C24CDBBFB20C49409622F94A20974A40
80226	7	72	\N	32	48053	\N	53.201655000000002	Самарская область, городской округ Самара, Промышленный район, Рыльская, 22		0101000020E61000008884EFFD0D2049409609BFD4CF994A40
80161	7	72	\N	32	47956	\N	53.235323127669602	Самарская область, городской округ Самара, Кировский район, Республиканская, 50	Россия, Самарская область, Самара, улица Строителей, 50	0101000020E6100000ACA8C1340C234940917F66101F9E4A40
80391	7	72	\N	32	8110	\N	53.206558000000001	Самарская область, город Самара, Октябрьский район, Радонежская, 2а	Россия, Самарская область, Самара, Радонежская улица, 2а	0101000020E61000008F34B8AD2D124940145D177E709A4A40
80363	7	72	\N	32	7842	\N	53.124631000000001	Самарская область, городской округ Самара, Куйбышевский район, Пугачевский тракт, 57	Россия, Самарская область, Самара, Пугачевский тракт, 57	0101000020E6100000A4FB3905F90B4940AD889AE8F38F4A40
80362	7	72	\N	32	7842	\N	53.122653	Самарская область, городской округ Самара, Куйбышевский район, Пугачевский тракт, 27а	Россия, Самарская область, Самара, Пугачевский тракт, 27а	0101000020E610000086E3F90CA80B4940CEE0EF17B38F4A40
80452	7	72	\N	32	48018	\N	53.196342000000001	Самарская область, город Самара, Советский район, Промышленности, 276		0101000020E6100000E886A6ECF41B4940666A12BC21994A40
80450	7	72	\N	32	48018	\N	53.200451999999999	Самарская область, город Самара, Советский район, Промышленности, 319	Россия, Самарская область, Самара, улица Промышленности, 319	0101000020E610000035ECF7C43A1D49407A354069A8994A40
95089	7	72	\N	32	7460	\N	53.201315000000001	Самарская область, городской округ Жигулевск, Пролетарская, д.3, здание Школы №8	Россия, Самарская область, Самара, Пролетарская улица	0101000020E61000000F45813E91134940DD989EB0C4994A40
95087	7	72	\N	32	47931	\N	53.201315000000001	Самарская область, городской округ Жигулевск, Пролетарская, д.27, здание школы-интерната №2		0101000020E61000000F45813E91134940DD989EB0C4994A40
80329	7	72	\N	32	47931	\N	53.202227000000001	Самарская область, городской округ Самара, Железнодорожный район, Пролетарская, 175		0101000020E610000008C72C7B1214494021AF0793E2994A40
80386	7	72	\N	32	48102	\N	53.204130999999997	Самарская область, город Самара, Октябрьский район, Полевая, 80		0101000020E6100000AAB69BE09B104940C58CF0F6209A4A40
80443	7	72	\N	32	47907	\N	53.208041000000001	Самарская область, город Самара, Советский район, Победы, 22		0101000020E61000000133DFC14F1E4940139D6516A19A4A40
80158	7	72	\N	32	47907	\N	53.226346999999997	Самарская область, городской округ Самара, Кировский район, Победы, 154А	Россия, Самарская область, Самара, улица Победы, 154а	0101000020E6100000AAEE91CD552349401B4641F0F89C4A40
79852	7	72	\N	32	47974	\N	53.252603765874703	поселок Смышляевка, Пионерская, 30	Россия, Самарская область, Самара, Кировский район, Шоссейная улица (Смышляевка)	0101000020E610000091D442C9E43049405D6BEF5355A04A40
80382	7	72	\N	32	48101	\N	53.209735000000002	Самарская область, город Самара, Октябрьский район, Первомайская, 18		0101000020E6100000D5CA845FEA0F4940CDE9B298D89A4A40
80326	7	72	\N	32	48006	\N	53.192058000000003	Самарская область, городской округ Самара, Железнодорожный район, Пензенская, 65А		0101000020E61000005721E527D5124940B477465B95984A40
80324	7	72	\N	32	48006	\N	53.189349999999997	Самарская область, городской округ Самара, Железнодорожный район, Пензенская, 47		0101000020E6100000041BD7BFEB114940B1BFEC9E3C984A40
80460	7	72	\N	32	961	\N	53.189706000000001	Самарская область, город Самара, Советский район, Партизанская, 208	Россия, Самарская область, Самара, Партизанская улица, 208	0101000020E610000062F54718061A494070ED444948984A40
80332	7	72	\N	32	961	\N	53.194006000000002	Самарская область, городской округ Самара, Железнодорожный район, Партизанская, 78А	Россия, Самарская область, Самара, Партизанская улица, 78а	0101000020E61000000803CFBD87154940289D4830D5984A40
80330	7	72	\N	32	961	\N	53.196914	Самарская область, городской округ Самара, Железнодорожный район, Партизанская, 56	Россия, Самарская область, Самара, Партизанская улица, 56	0101000020E61000000403081F4A144940F10F5B7A34994A40
80331	7	72	\N	32	48094	\N	53.195112000000002	Самарская область, городской округ Самара, Железнодорожный район, Партизанская, 60		0101000020E6100000973AC8EBC11449405187156EF9984A40
80212	7	72	\N	32	48001	\N	53.344323000000003	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, ул. Парижской Коммуны, 5а		0101000020E6100000E6E61BD13D1B49405C21ACC612AC4A40
80334	7	72	\N	32	48025	\N	53.197232	Самарская область, городской округ Самара, Железнодорожный район, Мориса Тореза, 32		0101000020E6100000BDC62E51BD154940C2DCEEE53E994A40
80366	7	72	\N	32	48097	\N	53.138446000000002	Самарская область, городской округ Самара, Куйбышевский район, Охтинская, 25	Россия, Самарская область, Самара, Охтинская улица, 25	0101000020E610000087156EF9481E49408A213999B8914A40
80151	7	72	\N	32	48046	\N	53.244241000000002	Самарская область, городской округ Самара, Кировский район, Офицерская, 53		0101000020E6100000622CD32F11294940D2AB014A439F4A40
80392	7	72	\N	32	48038	\N	53.213406999999997	Самарская область, город Самара, Октябрьский район, Осипенко, 6		0101000020E61000000458E4D70F11494065DEAAEB509B4A40
80390	7	72	\N	32	48038	\N	53.208013999999999	Самарская область, город Самара, Октябрьский район, Осипенко, 32а		0101000020E61000009DF3531C07124940198EE733A09A4A40
79948	7	72	\N	32	16127	\N	53.244354000000001	с. Кинель-Черкассы, ул. Октябрьская, 62 Б	Россия, Самарская область, Самара, Октябрьская улица, 62	0101000020E61000008527F4FA932A4940CA52EBFD469F4A40
80327	7	72	\N	32	47788	\N	53.185042895170703	Самарская область, городской округ Самара, Железнодорожный район, Ново-Урицкая, 1	Россия, Самарская область, Самара, Новоурицкая улица, 1	0101000020E61000002E1A321EA512494047AD307DAF974A40
80346	7	72	\N	32	47767	\N	53.122360999999998	Самарская область, городской округ Самара, Куйбышевский район, Ново-Молодежный переулок, 3	Россия, Самарская область, Самара, переулок Новомолодежный, 3	0101000020E610000026016A6AD90A494026A77686A98F4A40
80364	7	72	\N	32	7855	\N	53.132162999999998	Самарская область, городской округ Самара, Куйбышевский район, Новокуйбышевское шоссе, 54	Россия, Самарская область, Самара, Новокуйбышевское шоссе, 54	0101000020E61000002A745E63970C4940E15E99B7EA904A40
80260	7	72	\N	32	48005	\N	53.245038000000001	Самарская область, городской округ Самара, Промышленный район, Ново-Вокзальная, 162		0101000020E61000003C4F3C670B1A49407D23BA675D9F4A40
80247	7	72	\N	32	48005	\N	53.238608999999997	Самарская область, городской округ Самара, Промышленный район, Ново-Вокзальная, 193а		0101000020E6100000DDB419A7211C494000C45DBD8A9E4A40
80235	7	72	\N	32	48005	\N	53.217509999999997	Самарская область, городской округ Самара, Промышленный район, Ново-Вокзальная, 19		0101000020E610000034A14962491F4940C746205ED79B4A40
80393	7	72	\N	32	47922	\N	53.213417999999997	Самарская область, город Самара, Октябрьский район, Ново-Садовая, 44		0101000020E6100000832F4CA60A1249405930F147519B4A40
80383	7	72	\N	32	47922	\N	53.212059000000004	Самарская область, город Самара, Октябрьский район, Ново-Садовая, 26а	Россия, Самарская область, Самара, улица Ново-Садовая, 26а	0101000020E6100000B91B446B4511494047E9D2BF249B4A40
80398	7	72	\N	32	48014	\N	53.213552999999997	Самарская область, город Самара, Октябрьский район, Николая Панова, 30	Россия, Самарская область, Самара, улица Николая Панова, 30	0101000020E6100000CB660E492D144940397B67B4559B4A40
80317	7	72	\N	32	48057	\N	53.182572999999998	Самарская область, городской округ Самара, Железнодорожный район, Неверова, 87	Россия, Самарская область, Самара, улица Неверова, 87	0101000020E61000002C62D8614C104940F910548D5E974A40
80413	7	72	\N	32	73	\N	53.225386999999998	Самарская область, город Самара, Октябрьский район, Московское шоссе, 77	Россия, Самарская область, Самара, Московское шоссе, 77	0101000020E6100000E1F08288D4184940C6F8307BD99C4A40
80411	7	72	\N	32	73	\N	53.230939999999997	Самарская область, город Самара, Октябрьский район, Московское шоссе, 120	Россия, Самарская область, Самара, Московское шоссе, 120	0101000020E61000005036E50AEF1849404BAB21718F9D4A40
80406	7	72	\N	32	73	\N	53.20796	Самарская область, город Самара, Октябрьский район, Московское шоссе, 18а		0101000020E61000004F58E201651549402670EB6E9E9A4A40
80401	7	72	\N	32	73	\N	53.210883000000003	Самарская область, город Самара, Октябрьский район, Московское шоссе, 32	Россия, Самарская область, Самара, Московское шоссе, 32	0101000020E610000098A3C7EF6D1649402524D236FE9A4A40
80252	7	72	\N	32	73	\N	53.239051000000003	Самарская область, городской округ Самара, Промышленный район, Московское шоссе, 125	Россия, Самарская область, Самара, Московское шоссе, 125	0101000020E61000006FA0C03BF91A4940BE892139999E4A40
80251	7	72	\N	32	73	\N	53.236857999999998	Самарская область, городской округ Самара, Промышленный район, Московское шоссе, 101	Россия, Самарская область, Самара, Московское шоссе, 101	0101000020E6100000A6B915C26A1A4940E2E5E95C519E4A40
80190	7	72	\N	32	47869	\N	53.280946688695799	Самарская область, городской округ Самара, Кировский район, МОУ СОШ №171, 18 км Московского шоссе	Россия, Самарская область, Самара, Московское 18 км шоссе	0101000020E610000015C440D7BE22494064744012F6A34A40
80189	7	72	\N	32	48271	\N	53.202430882503599	"Самарская область, городской округ Самара, Кировский район, НИИ ""Жигулевские сады"", 18 км Московского шоссе"	Россия, Самарская область, Самара, улица Юрия Гагарина, 3	0101000020E6100000384A5E9D6314494029594E42E9994A40
80449	7	72	\N	32	48025	\N	53.195576000000003	Самарская область, город Самара, Советский район, Мориса Тореза, 115		0101000020E610000059FAD005F5194940F6F065A208994A40
80338	7	72	\N	32	48025	\N	53.197065000000002	Самарская область, городской округ Самара, Железнодорожный район, Мориса Тореза, 52		0101000020E61000009335EA211A174940D717096D39994A40
80336	7	72	\N	32	48025	\N	53.197209999999998	Самарская область, городской округ Самара, Железнодорожный район, Мориса Тореза, 36		0101000020E610000017450F7C0C164940DA38622D3E994A40
80335	7	72	\N	32	48025	\N	53.197037999999999	Самарская область, городской округ Самара, Железнодорожный район, Мориса Тореза, 36А		0101000020E6100000643BDF4F8D154940DD088B8A38994A40
79746	7	72	\N	55034	77334	\N	53.085990872797503	город Новокуйбышевск, Миронова, 26	Россия	0101000020E610000043AED4B320F648400B60CAC0018B4A40
80368	7	72	\N	32	93	\N	53.199562	Самарская область, городской округ Самара, Ленинский район, ул.Молодогвардейская, 133	Россия, Самарская область, Самара, Молодогвардейская улица, 133	0101000020E61000004DD9E907750D49401EC3633F8B994A40
80421	7	72	\N	32	48087	\N	53.184930999999999	Самарская область, городской округ Самара, Самарский район, Молодогвардейская, 62		0101000020E61000003ECE3461FB0B49401F82AAD1AB974A40
80388	7	72	\N	32	48103	\N	53.202415999999999	Самарская область, город Самара, Октябрьский район, Мичурина, 52		0101000020E61000007EC51A2E72114940F4177AC4E8994A40
80169	7	72	\N	32	48099	\N	53.239007999999998	Самарская область, городской округ Самара, Кировский район, Майская, 47		0101000020E6100000AA60545227204940BEBD6BD0979E4A40
80150	7	72	\N	32	48028	\N	53.247354999999999	Самарская область, городской округ Самара, Кировский район, Магистральная, 133Б		0101000020E61000008FE4F21FD227494044C02154A99F4A40
80394	7	72	\N	32	48012	\N	53.212097	Самарская область, город Самара, Октябрьский район, Луначарского, 14а		0101000020E610000095F430B43A134940344A97FE259B4A40
80407	7	72	\N	32	48015	\N	53.211385	Самарская область, город Самара, Октябрьский район, Лукачева, 48		0101000020E6100000AF5DDA7058164940B7EEE6A90E9B4A40
80405	7	72	\N	32	48015	\N	53.211891999999999	Самарская область, город Самара, Октябрьский район, Лукачева, 46		0101000020E610000066DB696B441649405B24ED461F9B4A40
80402	7	72	\N	32	48015	\N	53.216566999999998	Самарская область, город Самара, Октябрьский район, Лукачева, 17		0101000020E6100000AE6708C72C1549404832AB77B89B4A40
80348	7	72	\N	32	48010	\N	53.104329999999997	Самарская область, городской округ Самара, Куйбышевский район, Липяговская, 3а		0101000020E610000081CD397826044940EFFE78AF5A8D4A40
95082	7	72	\N	32	47936	\N	53.180652000000002	Самарская область, городской округ Жигулевск, Куйбышева, д.26, здание школы №9		0101000020E61000002DEC6987BF0A49407FFACF9A1F974A40
80423	7	72	\N	32	47936	\N	53.191600000000001	Самарская область, городской округ Самара, Самарский район, Куйбышева, 131		0101000020E61000009CDD5A26C30B4940F1F44A5986984A40
80447	7	72	\N	32	48047	\N	53.208872	Самарская область, город Самара, Советский район, Красных Коммунаров, 28		0101000020E6100000AF2479AEEF1F49406A865451BC9A4A40
80446	7	72	\N	32	48047	\N	53.206800999999999	Самарская область, город Самара, Советский район, Красных Коммунаров, 16		0101000020E61000003D9CC0745A1F4940DAE38574789A4A40
80371	7	72	\N	32	47937	\N	53.188824615925398	Самарская область, городской округ Самара, Ленинский район, Красноармейская, 93а	Россия, Самарская область, Самара, Красноармейская улица, 93а	0101000020E610000022FE614B8F0E494067D5E76A2B984A40
80344	7	72	\N	32	7639	\N	53.185907999999998	Самарская область, городской округ Самара, Железнодорожный район, Комсомольская площадь, 1, каб.202	Россия, Самарская область, Самара, Комсомольская площадь, 1	0101000020E610000032AD4D637B0F49404A0856D5CB974A40
80377	7	72	\N	32	47954	\N	53.195887824075498	Самарская область, городской округ Самара, Ленинский район, Коммунистическая, 7	Россия, Самарская область, Самара, Коммунистическая улица, 7	0101000020E610000043E7357689104940E4D6A4DB12994A40
80325	7	72	\N	32	47929	\N	53.180325268283298	Самарская область, городской округ Самара, Железнодорожный район, Клиническая, 86	Россия, Самарская область, Самара, Железнодорожный район, Клиническая улица, 261	0101000020E6100000B0E600C11C1549405BD3BCE314974A40
80347	7	72	\N	32	48068	\N	53.116129999999998	Самарская область, городской округ Самара, Куйбышевский район, Кишиневская, 13		0101000020E610000049F7730AF2094940D00A0C59DD8E4A40
80214	7	72	\N	32	47987	\N	53.3649495883108	Самарская область, городской округ Самара, Красноглинский район, пос.Красная Глинка, квартал 5, 9	Россия, Самарская область, Самара, Красноглинский район, 5-й Южный квартал, 3	0101000020E6100000289A07B0C81749406D567DAEB6AE4A40
80229	7	72	\N	32	6464	\N	53.218027999999997	Самарская область, городской округ Самара, Промышленный район, Каховская, 7	Россия, Самарская область, Самара, Каховская улица, 7	0101000020E6100000B51A12F7582249405FCE6C57E89B4A40
79764	7	72	\N	32	48054	\N	53.198369999999997	город Новокуйбышевск, Карбышева, 8		0101000020E6100000EFE53E390A1A4940F6402B3064994A40
80354	7	72	\N	32	48031	\N	53.157277999999998	Самарская область, городской округ Самара, Куйбышевский район, Казачья, 1		0101000020E610000084D382177D0B4940AD307DAF21944A40
80462	7	72	\N	32	48327	\N	53.190434000000003	Самарская область, город Самара, Советский район, Кабельная, 45А		0101000020E61000004E999B6F44234940F3052D2460984A40
80149	7	72	\N	32	47990	\N	53.245598999999999	Самарская область, городской округ Самара, Кировский район, Изыскательская, 28		0101000020E6100000FB03E5B67D2B49401477BCC96F9F4A40
80153	7	72	\N	32	5679	\N	53.226773000000001	Самарская область, городской округ Самара, Кировский район, Зубчаниновское шоссе, 161	Россия, Самарская область, Самара, Зубчаниновское шоссе, 161	0101000020E6100000AFB14B546F254940D34ECDE5069D4A40
80256	7	72	\N	32	48002	\N	53.259498000000001	Самарская область, городской округ Самара, Промышленный район, Зои Космодемьянской, 8		0101000020E61000003D0AD7A3701D49404FB0FF3A37A14A40
79752	7	72	\N	32	48002	\N	53.260204000000002	город Новокуйбышевск, З.Космодемьянской, 5		0101000020E6100000D4282499D51D4940EA245B5D4EA14A40
80155	7	72	\N	32	48322	\N	53.21407	Самарская область, городской округ Самара, Кировский район, Земеца (Псковская), 24А		0101000020E6100000200DA7CCCD254940018750A5669B4A40
80440	7	72	\N	32	48043	\N	53.209696999999998	Самарская область, город Самара, Советский район, Запорожская, 24		0101000020E61000009FE74F1BD51B4940DF88EE59D79A4A40
80350	7	72	\N	32	48096	\N	53.143279999999997	Самарская область, городской округ Самара, Куйбышевский район, Белорусская, 112а		0101000020E6100000D236FE4465054940DF15C1FF56924A40
80228	7	72	\N	32	6455	\N	53.213093999999998	Самарская область, городской округ Самара, Промышленный район, Заводское шоссе, 68	Россия, Самарская область, Самара, Заводское шоссе, 68	0101000020E61000002E7079AC19254940A67C08AA469B4A40
80399	7	72	\N	32	48037	\N	53.212640999999998	Самарская область, город Самара, Октябрьский район, Ерошевского, 29		0101000020E6100000E5B33C0FEE144940F564FED1379B4A40
80156	7	72	\N	32	47992	\N	53.228724	Самарская область, городской округ Самара, Кировский район, Елизарова, 28А		0101000020E6100000E2CAD93BA3234940B8E7F9D3469D4A40
79854	7	72	\N	32	47939	\N	53.133696999999998	поселок Стройкерамика, Дружбы, 1а		0101000020E6100000D4981073490D49406249B9FB1C914A40
80451	7	72	\N	32	48090	\N	53.199292999999997	Самарская область, город Самара, Советский район, Днепровская, 2		0101000020E610000007B5DFDA891C49402EA9DA6E82994A40
80186	7	72	\N	32	48325	\N	53.266779999999997	Самарская область, городской округ Самара, Кировский район, Дальняя, 6		0101000020E6100000E6E786A6EC1E49400A9DD7D825A24A40
80353	7	72	\N	32	48069	\N	53.168982999999997	Самарская область, городской округ Самара, Куйбышевский район, Главная, 3		0101000020E6100000C5C89239960949403C4A253CA1954A40
80178	7	72	\N	32	48062	\N	53.252985000000002	Самарская область, городской округ Самара, Кировский район, Георгия Димитрова, 17		0101000020E61000008FA67A32FF1E494075B0FECF61A04A40
80259	7	72	\N	32	48029	\N	53.261766000000001	Самарская область, городской округ Самара, Промышленный район, Георгия Димитрова, 114		0101000020E610000037001B10211C4940359A5C8C81A14A40
80177	7	72	\N	32	48029	\N	53.255011000000003	Самарская область, городской округ Самара, Кировский район, Георгия Димитрова, 39		0101000020E61000006479573D601E4940658F5033A4A04A40
80174	7	72	\N	32	48029	\N	53.250464000000001	Самарская область, городской округ Самара, Кировский район, Георгия Димитрова, 50		0101000020E6100000FED2A23EC91D4940A56950340FA04A40
80164	7	72	\N	32	48093	\N	53.234501999999999	Самарская область, городской округ Самара, Кировский район, Гвардейская, 14		0101000020E6100000187AC4E8B92349405D6C5A29049E4A40
80162	7	72	\N	32	48093	\N	53.236448000000003	Самарская область, городской округ Самара, Кировский район, Гвардейская, 22		0101000020E61000007AC6BE64E3234940319A95ED439E4A40
80414	7	72	\N	32	48084	\N	53.223559999999999	Самарская область, город Самара, Октябрьский район, Гастелло, 47		0101000020E610000001F6D1A92B194940CD58349D9D9C4A40
80425	7	72	\N	32	48098	\N	53.185152000000002	Самарская область, городской округ Самара, Самарский район, Галактионовская, 37		0101000020E61000008A93FB1D8A0C4940FE648C0FB3974A40
80370	7	72	\N	32	48098	\N	53.196444	Самарская область, городской округ Самара, Ленинский район, Галактионовская, 141		0101000020E61000001D5BCF108E0D49406ABFB51325994A40
80207	7	72	\N	32	47924	\N	53.348396999999999	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, Гайдара, 9	Россия, Самарская область, Самара, улица Гайдара, 9	0101000020E6100000AA8251499D1C49402383DC4598AC4A40
80355	7	72	\N	32	48070	\N	53.133566999999999	Самарская область, городской округ Самара, Куйбышевский район, Восстания, 3		0101000020E61000000E10CCD1E30B4940946934B918914A40
80248	7	72	\N	32	48080	\N	53.240856000000001	Самарская область, городской округ Самара, Промышленный район, Воронежская, 232		0101000020E6100000800F5EBBB41B4940CF85915ED49E4A40
79767	7	72	\N	32	694	\N	53.216206	город Новокуйбышевск, Вольская, 47	Россия, Самарская область, Самара, Вольская улица, 55/27	0101000020E6100000705B5B785E1E4940789961A3AC9B4A40
80442	7	72	\N	32	48013	\N	53.212943000000003	Самарская область, город Самара, Советский район, Вольская, 13		0101000020E61000007AAA436E861D4940C1745AB7419B4A40
80237	7	72	\N	32	48013	\N	53.213864999999998	Самарская область, городской округ Самара, Промышленный район, Вольская, 40		0101000020E6100000CEE15AED611D49402861A6ED5F9B4A40
80234	7	72	\N	32	48013	\N	53.221747999999998	Самарская область, городской округ Самара, Промышленный район, Вольская, 96		0101000020E61000001E1A16A3AE1F494009FA0B3D629C4A40
80374	7	72	\N	32	7940	\N	53.209086999999997	Самарская область, городской округ Самара, Ленинский район, Волжский проспект, 41	Россия, Самарская область, Самара, Волжский проспект, 41	0101000020E610000082CAF8F7190F49406682E15CC39A4A40
80340	7	72	\N	32	48061	\N	53.189312000000001	Самарская область, городской округ Самара, Железнодорожный район, Волгина, 110		0101000020E610000051FA42C879174940C45E28603B984A40
80255	7	72	\N	32	47994	\N	53.255991000000002	Самарская область, городской округ Самара, Промышленный район, Бубнова, 7	Россия, Самарская область, Самара, улица Бубнова, 7	0101000020E6100000534145D5AF1C494001892650C4A04A40
80372	7	72	\N	32	48109	\N	53.194270000000003	Самарская область, городской округ Самара, Ленинский район, Братьев Коростелевых, 144		0101000020E6100000C5C551B9890E4940064CE0D6DD984A40
80318	7	72	\N	32	48059	\N	53.185362205098798	Самарская область, городской округ Самара, Железнодорожный район, Братьев Коростелевых, 17	Россия, Самарская область, Самара, улица Братьев Коростелевых, 17	0101000020E6100000EA059FE6E40D4940E8F527F1B9974A40
80387	7	72	\N	32	48076	\N	53.203505	Самарская область, город Самара, Октябрьский район, Больничная, 14а		0101000020E61000001B2FDD240611494047C9AB730C9A4A40
80427	7	72	\N	32	48041	\N	53.213655000000003	Самарская область, город Самара, Советский район, Блюхера, 25		0101000020E6100000F913950D6B1A49403ED00A0C599B4A40
80454	7	72	\N	32	868	\N	53.182032999999997	Самарская область, город Самара, Советский район, Бельский переулок, 9	Россия, Самарская область, Самара, Бельский переулок, 9	0101000020E61000005BB4006DAB19494079E57ADB4C974A40
80352	7	72	\N	32	48096	\N	53.145819000000003	Самарская область, городской округ Самара, Куйбышевский район, Белорусская, 44а		0101000020E61000009BAF928FDD07494056116E32AA924A40
80343	7	72	\N	32	28821	\N	53.171714000000001	Самарская область, городской округ Самара, Железнодорожный район, Белогородская, 2	Россия, Самарская область, Самара, Белгородская улица, 2	0101000020E61000001F680586AC184940F7216FB9FA954A40
80458	7	72	\N	32	879	\N	53.185336	Самарская область, город Самара, Советский район, Балаковская, 10А	Россия, Самарская область, Самара, Балаковская улица, 10а	0101000020E610000098DBBDDC27194940BF620D17B9974A40
80455	7	72	\N	32	48049	\N	53.185352000000002	Самарская область, город Самара, Советский район, Балаковская, 16		0101000020E61000000246973787194940C51F459DB9974A40
80459	7	72	\N	32	48011	\N	53.189743999999997	Самарская область, город Самара, Советский район, Аэродромная, 65		0101000020E6100000397CD289041949405D4E098849984A40
80341	7	72	\N	32	48011	\N	53.192118000000001	Самарская область, городской округ Самара, Железнодорожный район, Аэродромная, 16А		0101000020E6100000E86C01A1F5164940897C975297984A40
80416	7	72	\N	32	296	\N	53.201994999999997	Самарская область, городской округ Самара, Октябрьский район, Артемовская, 24а	Россия, Самарская область, Самара, Артемовская улица, 24а	0101000020E61000000FB9196EC01749404E7ADFF8DA994A40
80432	7	72	\N	32	48113	\N	53.202210999999998	Самарская область, город Самара, Советский район, Артемовская, 50		0101000020E61000002F3196E9971849401BF2CF0CE2994A40
80415	7	72	\N	32	48113	\N	53.201994999999997	Самарская область, город Самара, Октябрьский район, Артемовская, 24а		0101000020E61000000FB9196EC01749404E7ADFF8DA994A40
80439	7	72	\N	32	48044	\N	53.211540999999997	Самарская область, город Самара, Советский район, Антонова-Овсеенко, 85		0101000020E610000054ABAFAE0A1C4940AE6186C6139B4A40
80428	7	72	\N	32	48044	\N	53.211903	Самарская область, город Самара, Советский район, Антонова-Овсеенко,51		0101000020E6100000580053060E1A49404F7633A31F9B4A40
80253	7	72	\N	32	48082	\N	53.249068000000001	Самарская область, городской округ Самара, Промышленный район, Аминева, 26		0101000020E6100000F75965A6B41A4940753DD175E19F4A40
80182	7	72	\N	32	48064	\N	53.251702999999999	Самарская область, городской округ Самара, Кировский район, Алма-Атинская, 122		0101000020E61000000DE36E10AD2149400DA7CCCD37A04A40
80378	7	72	\N	32	48074	\N	53.194960999999999	Самарская область, городской округ Самара, Ленинский район, Г.С. Аксакова, 21		0101000020E6100000055262D7F61049406B7F677BF4984A40
80404	7	72	\N	32	48039	\N	53.229975000000003	Самарская область, город Самара, Октябрьский район, Академика Павлова, 85		0101000020E6100000B2632310AF174940E5F21FD26F9D4A40
80403	7	72	\N	32	48039	\N	53.222588999999999	Самарская область, город Самара, Октябрьский район, Академика Павлова, 1		0101000020E6100000B421FFCC2016494084B9DDCB7D9C4A40
80210	7	72	\N	32	47909	\N	53.343263999999998	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, им.академика Н.Д.Кузнецова, 7		0101000020E61000005628D2FD9C1C494073F22213F0AB4A40
80456	7	72	\N	32	48114	\N	53.194540000000003	Самарская область, город Самара, Советский район, Авроры, 117		0101000020E61000009B728577B9184940C6E1CCAFE6984A40
80359	7	72	\N	32	48086	\N	53.111486999999997	Самарская область, городской округ Самара, Куйбышевский район, Сорок Лет пионерии, 16		0101000020E6100000B24B546F0D0A4940EE76BD34458E4A40
80358	7	72	\N	32	48086	\N	53.111486999999997	Самарская область, городской округ Самара, Куйбышевский район, Сорок Лет Пионерии, 16		0101000020E6100000B24B546F0D0A4940EE76BD34458E4A40
80217	7	72	\N	32	48003	\N	53.387425999999998	Самарская область, городской округ Самара, Красноглинский район, пос.Красная Глинка, квартал 4, 28		0101000020E6100000C28A53AD851549405FCFD72C97B14A40
80195	7	72	\N	32	47983	\N	53.303651000000002	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, квартал  3, 46		0101000020E6100000E3FDB8FDF2234940E8323509DEA64A40
80219	7	72	\N	32	48078	\N	53.302252000000003	Самарская область, городской округ Самара, Красноглинский район, пос.Береза, квартал 2, 10		0101000020E6100000083A5AD59224494047938B31B0A64A40
80202	7	72	\N	32	48033	\N	53.303780000000003	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, квартал 15, 20		0101000020E6100000C24CDBBFB2224940E6965643E2A64A40
80197	7	72	\N	32	48106	\N	53.296849000000002	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, квартал 11, 15		0101000020E6100000E2067C7E18254940D76CE525FFA54A40
80216	7	72	\N	32	48091	\N	53.303984999999997	Самарская область, городской округ Самара, Красноглинский район, пос.Красная Глинка, квартал 1, 1		0101000020E610000073BB97FBE4244940BEBC00FBE8A64A40
80199	7	72	\N	32	47988	\N	53.298374715005203	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, квартал 6, 1	Россия, Самарская область, Самара, Красноглинский район, 6-й квартал Мехзавода, 6	0101000020E610000017F549EEB0234940D578E92631A64A40
80430	7	72	\N	32	47730	\N	53.216277032693398	Самарская область, город Самара, Советский район, Двадцать Второго Партсъезда, 56	Россия, Самарская область, Самара, улица ХХII Партсъезда, 56	0101000020E610000041800C1D3B1C494041F0F8F6AE9B4A40
80357	7	72	\N	32	48009	\N	53.116503000000002	Самарская область, городской округ Самара, Куйбышевский район, Фасадная, 19		0101000020E610000012DE1E84800A49406571FF91E98E4A40
80410	7	72	\N	32	48083	\N	53.231262999999998	Самарская область, город Самара, Октябрьский район, Советской Армии, 212		0101000020E6100000083BC5AA411849402EE3A6069A9D4A40
80435	7	72	\N	32	48088	\N	53.211719000000002	Самарская область, город Самара, Советский район, Антонова-Овсеенко, 53		0101000020E6100000C7681D554D1A49408E78B29B199B4A40
79855	7	72	\N	55868	\N	\N	53.054320192843001	поселок Рощинский, МОУ Рощинская СОШ	Россия	0101000020E610000033A83638113F494065C22FF5F3864A40
79850	7	72	\N	55868	\N	\N	53.047131233777698	"поселок Рощинский, Спортивная база ""Черноречье"""		0101000020E61000008670CCB2273F49405BD07B6308864A40
79798	7	72	\N	2221	47743	\N	53.654161785259099	г. Похвистнево, Центральная, 5	Россия, Самарская область, Похвистнево	0101000020E6100000813FFCFCF7104A409A249694BBD34A40
79788	7	72	\N	2221	47888	\N	53.653756999999999	г. Похвистнево, Революционная, 109	Россия, Самарская область, Похвистнево	0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79795	7	72	\N	2221	47832	\N	53.653756999999999	г. Похвистнево, Мира, 39		0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79794	7	72	\N	2221	47832	\N	53.649572556857102	г. Похвистнево, Мира, 22	Россия, Самарская область, Похвистнево	0101000020E6100000A8531EDD08114A40ABAE433525D34A40
79792	7	72	\N	2221	47661	\N	53.646104806980098	г. Похвистнево, Малиновского, 1а	Россия, Самарская область, Похвистнево	0101000020E610000036E7E099D0104A401B649291B3D24A40
79790	7	72	\N	2221	47852	\N	53.653756999999999	г.Похвистнево, Лермонтова, 35		0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79789	7	72	\N	2221	47660	\N	53.653756999999999	г.Похвистнево, Ленинградская, 2		0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79799	7	72	\N	2221	48268	\N	53.653756999999999	г. Похвистнево, Краснопутиловская, 1		0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79797	7	72	\N	2221	47854	\N	53.653756999999999	г. Похвистнево, Кооперативная, 45		0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79796	7	72	\N	2221	47833	\N	53.653756999999999	г. Похвистнево, Газовиков, 14		0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79793	7	72	\N	2221	47853	\N	53.653756999999999	г.Похвистнево, ул. Бережкова, 48 Дорожная компания	Россия, Самарская область, Похвистнево	0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
79791	7	72	\N	2221	47741	\N	53.653756999999999	г. Похвистнево, Андрея Васильева, 2		0101000020E6100000BCB0355B790F4A40FA43334FAED34A40
80603	7	72	\N	55924	48537	\N	52.8885877687609	с.Переволоки, Школьная, 2		0101000020E6100000CD02ED0E29A848401CCF6740BD714A40
79971	7	72	\N	55940	48681	\N	53.896998908460702	п.Первомайский, Садовая, 28		0101000020E6100000F67CCD72D9AE4940B9C5FCDCD0F24A40
79773	7	72	\N	2111	47846	\N	53.373218999999999	город Отрадный, Центральная, 1	Россия, Самарская область, Отрадный	0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79778	7	72	\N	2111	47738	\N	53.373218999999999	город Отрадный, Советская, 88		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79774	7	72	\N	2111	47738	\N	53.373218999999999	город Отрадный, Советская, 48		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79782	7	72	\N	2111	47655	\N	53.373218999999999	город Отрадный, Пионерская, 28		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79781	7	72	\N	2111	47655	\N	53.373218999999999	город Отрадный, Пионерская, 31		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79779	7	72	\N	2111	47656	\N	53.3732554360964	город Отрадный, Первомайская, 28	Россия, Самарская область, Отрадный	0101000020E6100000895C70067FAB4940C408E1D1C6AF4A40
79777	7	72	\N	2111	47656	\N	53.373218999999999	город Отрадный, Первомайская, 33		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79776	7	72	\N	2111	47656	\N	53.373323908637602	город Отрадный, Первомайская, 35	Россия, Самарская область, Отрадный	0101000020E6100000E86B96CB46AB4940EC67B114C9AF4A40
79775	7	72	\N	2111	47851	\N	53.373218999999999	город Отрадный, Отрадная, 7		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79785	7	72	\N	2111	47742	\N	53.373218999999999	город Отрадный, Ленинградская, 45		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79786	7	72	\N	2111	47740	\N	53.373218999999999	город Отрадный, Жигулевская, 2а		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79783	7	72	\N	2111	47657	\N	53.373460753135902	город Отрадный, Гайдара, 74	Россия, Самарская область, Отрадный	0101000020E6100000396403E962AB49406DAAEE91CDAF4A40
79784	7	72	\N	2111	47658	\N	53.372707952547501	г. Отрадный , ул. Гагарина, 50	Россия, Самарская область, Отрадный	0101000020E61000005DA8FC6B79AB4940927A4FE5B4AF4A40
79780	7	72	\N	2111	47654	\N	53.373218999999999	город Отрадный, Ленина, 62а		0101000020E61000009FE3A3C519AB4940779FE3A3C5AF4A40
79901	7	72	\N	55898	48279	\N	53.417294805848897	п. Октябрьский, ул Школьная, 1		0101000020E61000001BB96E4A79074A4065E42CEC69B54A40
80476	7	72	\N	4034	48050	\N	53.179543159487999	Самарская область, городской округ Октябрьск, улица Центральная, 14	Россия, Самарская область, Октябрьск	0101000020E6100000EDF0D7648D624840E59CD843FB964A40
80477	7	72	\N	4034	48051	\N	53.178845097850697	Самарская область, городской округ Октябрьск, улица Мира, 94	Россия, Самарская область, Октябрьск	0101000020E6100000630B410E4A5E4840CD069964E4964A40
80466	7	72	\N	4034	47949	\N	53.170879585887597	Самарская область, городской округ Октябрьск, улица Ленинградская, 87	Россия, Самарская область, Октябрьск	0101000020E61000000420EEEA555648402EC55565DF954A40
80470	7	72	\N	4034	47796	\N	53.178408743929097	Самарская область, городской округ Октябрьск, улица Ленина, 52	Россия, Самарская область, Октябрьск	0101000020E6100000A7CAF78C445E4840F2272A1BD6964A40
80467	7	72	\N	4034	47796	\N	53.180635000000002	г.Октябрьск,  ул. Ленина 42		0101000020E6100000C30C8D27825E4840A9C1340C1F974A40
80475	7	72	\N	4034	47681	\N	53.179079084039401	Самарская область, городской округ Октябрьск, улица Котовского, 32	Россия, Самарская область, Октябрьск	0101000020E6100000F984ECBC8D5D48404033880FEC964A40
80468	7	72	\N	4034	48024	\N	53.1796701219046	Самарская область, городской округ Октябрьск, улица Гоголя, 16	Россия, Самарская область, Октябрьск	0101000020E6100000EBFEB1101D5E48404209336DFF964A40
80469	7	72	\N	4034	47680	\N	53.180635000000002	г.Октябрьск, ул. Гая, 39		0101000020E6100000C30C8D27825E4840A9C1340C1F974A40
80474	7	72	\N	4034	47679	\N	53.1837711700855	Самарская область, городской округ Октябрьск, улица Аипова, 5	Россия, Самарская область, Октябрьск	0101000020E6100000EF1AF4A5B7614840037AE1CE85974A40
80479	7	72	\N	4034	48126	\N	53.168816571148902	Самарская область, городской округ Октябрьск, улица 3-го Октября, 17	Россия, Самарская область, Октябрьск	0101000020E6100000B3CD8DE9095748402101A3CB9B954A40
80481	7	72	\N	4034	47728	\N	53.187173898822998	Самарская область, городской округ Октябрьск, улица 3-го Октября, 153	Россия, Самарская область, Октябрьск	0101000020E6100000B27F9E060C624840AC545051F5974A40
79745	7	72	\N	55034	77365	\N	53.056707000000003	"город Новокуйбышевск, пр. Жележнодорожный, заводоуправление ООО ""Биаксплен НК"""	Россия	0101000020E6100000DC2A8881AEEB4840263ACB2C42874A40
79756	7	72	\N	55034	47989	\N	53.197125262741999	город Новокуйбышевск, Киевская, 15	Россия, Самарская область, Самара, Киевская улица, 15а	0101000020E6100000EE5A423EE8134940AC1C5A643B994A40
79763	7	72	\N	55034	48040	\N	53.0997659196059	город Новокуйбышевск, Дзержинского, 23-а	Россия	0101000020E6100000249C16BCE8F748405AA0DD21C58C4A40
79772	7	72	\N	55034	77384	\N	53.100412774262402	город Новокуйбышевск, Гранная, 14	Россия	0101000020E610000099F4F75278F44840F08B4B55DA8C4A40
80766	7	72	\N	55859	47812	\N	52.804783	"Нефтегорск, Нефтяников, 22 (ДК""Нефтяник""спортивный зал)"		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80769	7	72	\N	55859	47770	\N	52.804783	Нефтегорск, Буровиков, 6 (ДЮСШ)		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80196	7	72	\N	55872	77305	\N	53.313146061267901	Самарская область, городской округ Самара, Красноглинский район, пос.Мехзавод, Московское шоссе,8А	Россия, Самарская область, Самара, улица Холмистая, 8	0101000020E610000069C9E369F9254940C66F0A2B15A84A40
79722	7	72	\N	7140	48181	\N	53.216475000000003	Самарская область, город Кинель, Элеваторная, 24		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79731	7	72	\N	7140	47722	\N	53.217196713916003	Самарская область, город Кинель, п.Усть-Кинельский, Шоссейная, 76	Россия, Самарская область, Кинель	0101000020E6100000D845D1031F4F494008E57D1CCD9B4A40
79730	7	72	\N	7140	47722	\N	53.216475000000003	Самарская область, город Кинель, п.Усть-Кинельский, Шоссейная, 82		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79708	7	72	\N	7140	47722	\N	53.216475000000003	Самарская область, город Кинель, Шоссейная, 6		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79727	7	72	\N	7140	48565	\N	53.216475000000003	Самарская область, город Кинель, п.Лебедь, Школьная, 7		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79715	7	72	\N	7140	47659	\N	53.216475000000003	Самарская область, город Кинель, Ульяновская, 27а		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79711	7	72	\N	7140	47659	\N	53.216475000000003	Самарская область, город Кинель, Ульяновская, 1		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79724	7	72	\N	7140	47727	\N	53.228323185367401	Самарская область, город Кинель, Украинская, 50	Россия, Самарская область, Кинель	0101000020E6100000C712D6C6D84D49405AF624B0399D4A40
79728	7	72	\N	7140	47719	\N	53.216475000000003	Самарская область, город Кинель, п.Усть-Кинельский, Спортивная, 9		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79709	7	72	\N	7140	48177	\N	53.216475000000003	г. Кинель, ул. Советская, 46		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79707	7	72	\N	7140	47848	\N	53.216475000000003	Самарская область, город Кинель, Первомайская, 31а		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79706	7	72	\N	7140	47848	\N	53.216475000000003	Самарская область, город Кинель, Первомайская, 1а		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79720	7	72	\N	7140	48202	\N	53.216475000000003	Самарская область, город Кинель, Октябрьская, 1		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79735	7	72	\N	7140	47735	\N	53.216475000000003	Самарская область, город Кинель, п.Алексеевка, Невская, 35а		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79710	7	72	\N	7140	47822	\N	53.216475000000003	Самарская область, город Кинель, Набережная, 1а		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79723	7	72	\N	7140	48269	\N	53.2165784914461	Самарская область, город Кинель, Мостовая, 21	Россия, Самарская область, Кинель	0101000020E6100000E9D2BF24954F49403C84F1D3B89B4A40
79717	7	72	\N	7140	47827	\N	53.216475000000003	Самарская область, город Кинель, Мира, 42		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79718	7	72	\N	7140	47717	\N	53.216269376849198	Самарская область, город Кинель, Маяковского, 49	Россия, Самарская область, Кинель	0101000020E610000010E7E104A64F4940BE11DDB3AE9B4A40
79716	7	72	\N	7140	47717	\N	53.216475000000003	Самарская область, город Кинель, Маяковского, 72		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79713	7	72	\N	7140	47717	\N	53.2248207205838	Самарская область, город Кинель, Маяковского, 90а	Россия, Самарская область, Кинель	0101000020E6100000FA5FAE450B5049401D3A3DEFC69C4A40
79712	7	72	\N	7140	47717	\N	53.216475000000003	Самарская область, город Кинель, Маяковского, 79		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79726	7	72	\N	7140	48446	\N	53.216475000000003	Самарская область, город Кинель, п.Елшняги, Дачная, 14		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79734	7	72	\N	7140	47653	\N	53.216554140703103	Самарская область, город Кинель, п.Алексеевка, Гагарина, 8	Россия, Самарская область, Кинель	0101000020E61000002B14E97E4E4F4940B4E89D0AB89B4A40
79714	7	72	\N	7140	47725	\N	53.216475000000003	Самарская область, город Кинель, 27 Партсъезда, 5а		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79725	7	72	\N	7140	48646	\N	53.216475000000003	Самарская область, город Кинель, п.Горный, Центральная, 1б	Россия, Самарская область, Кинель	0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79721	7	72	\N	7140	47828	\N	53.216475000000003	Самарская область, город Кинель, 50 лет Октября, 25а		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
79719	7	72	\N	7140	47828	\N	53.216475000000003	Самарская область, город Кинель, 50 лет Октября, 80		0101000020E61000003BA92F4B3B4F494068B3EA73B59B4A40
94998	7	72	\N	61156	77386	\N	53.392715431016299	Самарская область, г.Жигулёвск, ул. Пионерская,23	Россия	0101000020E61000000C569C6A2DC0484007D3307C44B24A40
95086	7	72	\N	55973	77317	\N	53.396860377525499	"Самарская область, городской округ Жигулевск, Морквашинская, д.59, ГБОУ СПО ""Жигулёвский государственный колледж"" корп.В"	Россия	0101000020E6100000740CC85EEFC04840978BF84ECCB24A40
95083	7	72	\N	55973	77311	\N	53.395045272341797	Самарская область, городской округ Жигулевск, В-1, д.31, здание МОУ ДОД СЮТ	Россия	0101000020E6100000105839B4C8C0484063B9A5D590B24A40
80920	7	72	\N	55874	47973	\N	53.381589025048697	поселок Волжский Утес, Безымянная, 18а	Россия	0101000020E6100000681F2BF86D8C4840B5C189E8D7B04A40
95093	7	72	\N	50002	48228	\N	53.431108000000002	Самарская область, городской округ Жигулевск, село Богатырь, ул. Управленческая,1  здание ДК ЗАО ЖИЗ		0101000020E6100000FBB0DEA815FA4840A185048C2EB74A40
80135	7	72	1591	20162	48635	\N	54.301931000000003	с. Крепость Кондурча, ул. Бочкарева, 2		0101000020E610000000AB23473AA949400553CDACA5264B40
95090	7	72	\N	49999	\N	\N	53.436188000000001	Самарская область, городской округ Жигулевск, село Бахилова Поляна, здание гос.заповедника им. Спрыгина	Россия, Самарская область, село Бахилова Поляна	0101000020E61000004435255987D548402E742502D5B74A40
80914	7	72	671	4584	47710	\N	53.334859999999999	Шигоны, Советская, 131		0101000020E6100000B75ED38382524840895E46B1DCAA4A40
80915	7	72	671	25927	47711	\N	53.3899885192101	с.Шигоны, ул. Советская, 146	Россия, Самарская область, Шигонский район, село Шигоны	0101000020E610000092EC116A865648405E66D828EBB14A40
73753	7	72	671	46516	47709	\N	53.392656000000002	Усолье, Ленина, 56		0101000020E6100000D8B79388F0874840024A438D42B24A40
73427	7	72	671	46516	48124	\N	53.392656000000002	Усолье, Королева, 14		0101000020E6100000D8B79388F0874840024A438D42B24A40
80902	7	72	671	48747	48393	\N	53.420098000000003	Тайдаково, Ленина, 38	Россия, Самарская область, Шигонский район, село Тайдаково	0101000020E610000052448655BC734840B98E71C5C5B54A40
80909	7	72	671	25656	48288	\N	53.524465999999997	Суринск, Школьная, 29		0101000020E6100000F44E05DCF33C484095EEAEB321C34A40
80908	7	72	671	4698	48427	\N	53.704616000000001	с. Старый Тукшум, ул. Советская, 46	Россия, Самарская область, Шигонский район, село Старый Тукшум	0101000020E610000008B0C8AF1F464840821E6ADB30DA4A40
80122	7	72	671	55913	48421	\N	53.712630861958601	с. Сенькино, ул. Центральная, 25	Россия, Самарская область, Шигонский район, село Сенькино	0101000020E61000001F4AB4E4F1644840D28E1B7E37DB4A40
80918	7	72	671	49009	48435	\N	53.684873000000003	Подвалье, Колхозная, 53		0101000020E6100000B0FF3A376D6A4840EB7420EBA9D74A40
80912	7	72	671	48909	47825	\N	53.343850000000003	Пионерский, Советская, 18		0101000020E6100000FF59F3E32F534840645DDC4603AC4A40
80891	7	72	671	48537	47793	\N	53.608167999999999	Новодевичье, Ленинградская, 68б		0101000020E6100000D87E32C6876B4840A33CF372D8CD4A40
80757	7	72	671	55937	48664	\N	53.6521390212014	Новая Жизнь, Набережная, 50 (СДК)	Россия, Самарская область, Шигонский район, поселок Новая Жизнь	0101000020E61000001157CEDE193F48401BB96E4A79D34A40
80916	7	72	671	26025	48187	\N	53.332639	Муранка, Советская, 34	Россия, Самарская область, Шигонский район, село Муранка	0101000020E61000005CAAD216D7664840E42F2DEA93AA4A40
80911	7	72	671	25753	47698	\N	53.396082	Малячкино, Советская, 45а		0101000020E610000041EF8D21004C48406344A2D0B2B24A40
73411	7	72	671	46159	48571	\N	53.513759	Маза, Калинина, 52		0101000020E61000001D1F2DCE186E48404983DBDAC2C14A40
80917	7	72	671	26031	48562	\N	53.350589999999997	с.Львовка, ул. Советская, 3		0101000020E6100000E44A3D0B427B4840FE261422E0AC4A40
80919	7	72	671	49031	48430	\N	53.650998000000001	Луговской, Новостойка, 23		0101000020E6100000D311C0CDE25F484076E107E753D34A40
80913	7	72	671	48926	48546	\N	53.480125000000001	Кяхта, Центральная, 11а		0101000020E6100000501C40BFEF5F4840FA7E6ABC74BD4A40
80923	7	72	671	26272	48687	\N	53.531852000000001	Кузькино, Советская, 59		0101000020E6100000A3ACDF4C4C5B4840F627F1B913C44A40
80921	7	72	671	49067	48690	\N	53.306674999999998	село Комаровка, Спортивная, 2		0101000020E61000001C0A9FAD839148401AC05B2041A74A40
72906	7	72	671	49557	48398	\N	53.489089	Климовка, Новая, 15		0101000020E6100000006F8104C5814840ABEAE5779ABE4A40
80922	7	72	671	26264	48304	\N	53.501376999999998	Станция Бичевная, Заводская, 17		0101000020E6100000B47405DB88474840B9FB1C1F2DC04A40
80907	7	72	671	48833	48153	\N	53.586398000000003	Береговой, Школьная, 1		0101000020E610000089EFC4AC173F48404C38F4160FCB4A40
80910	7	72	671	48875	48154	\N	53.453538000000002	Байдеряково, Центральная, 121		0101000020E61000004DD87E32C645484023BF7E880DBA4A40
80142	7	72	1591	55899	48291	\N	54.435957000000002	ст. Шентала, ул. Попова, 7		0101000020E6100000E2E7BF07AFBB49402CBB6070CD374B40
80143	7	72	1591	55847	48307	\N	54.438224695405601	ст. Шентала, ул. Советская, 40	Россия, Самарская область, Шенталинский район, село Шентала	0101000020E61000005854C4E924BB494012A5BDC117384B40
80146	7	72	1591	55847	47673	\N	54.433901259525797	ст. Шентала, ул. Победы, 48	Россия, Самарская область, Шенталинский район, село Шентала	0101000020E61000009483D90418BC4940D15966118A374B40
80144	7	72	1591	55847	48319	\N	54.435723057000203	ст. Шентала, ул. Льва Толстого, 53		0101000020E6100000B9718BF9B9BB4940B98E71C5C5374B40
80145	7	72	1591	55847	48229	\N	54.4326708503148	ст. Шентала, ул. Вокзальная, 47	Россия, Самарская область, Шенталинский район, село Шентала	0101000020E61000003BC5AA4198BB4940BC7669C361374B40
80140	7	72	1591	20437	48287	\N	54.509616999999999	с. Четырла, ул. Ленина, 5А		0101000020E6100000C9E4D4CE30DB4940293E3E213B414B40
80139	7	72	1591	20359	48587	\N	54.529527000000002	с. Туарма, ул. Советская, 2	Россия, Самарская область, Шенталинский район, село Туарма	0101000020E6100000D313967840C94940ACAC6D8AC7434B40
80137	7	72	1591	55948	48702	\N	54.4941404829273	п. Толче-Речье, ул. Садовая, 6	Россия, Самарская область, Шенталинский район, село Толчеречье	0101000020E610000015AB06616EC549409ED2C1FA3F3F4B40
80132	7	72	1591	19934	48630	\N	54.560977999999999	с. Тимяшево, ул. Молодежная, 17		0101000020E6100000852348A5D8B9494043E38920CE474B40
80126	7	72	1591	19621	48585	\N	54.392512000000004	с. Татарское Абдикеево, ул. Школьная, 136		0101000020E61000006B459BE3DCE04940CFA44DD53D324B40
80123	7	72	1591	47051	48629	\N	54.302267000000001	с. Старое Суркино, ул. Школьная, 1	Россия, Самарская область, Шенталинский район, село Старое Суркино	0101000020E6100000C18C2958E3D049407CD45FAFB0264B40
80131	7	72	1591	19926	48466	\N	54.591380398437899	д. Старое Афонькино, ул. Центральная, 21	Россия, Самарская область, Шенталинский район, село Старое Афонькино	0101000020E6100000E27668588CCC494016C1FF56B24B4B40
80133	7	72	1591	19991	48632	\N	54.396228000000001	с. Старая Шентала, ул. Советская, 23		0101000020E6100000DCA16131EABE494037E15E99B7324B40
80141	7	72	1591	20538	48471	\N	54.525785999999997	д. Семеново Шарла, ул. Школьная, 1В		0101000020E6100000A0C1A6CEA3EA4940EA58A5F44C434B40
80130	7	72	1591	19826	48465	\N	54.603926000000001	с. Салейкино, ул. Советская, 46		0101000020E61000008F899466F3C24940209A79724D4D4B40
80897	7	72	1591	47152	48679	\N	54.485471243093599	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Романовка муниципального района Хворостянский Самарской области, Советская, 104	Россия, Самарская область, Шенталинский район, село Романовка	0101000020E61000002BF86D88F1AE49400514EAE9233E4B40
80129	7	72	1591	19820	48468	\N	54.457844999999999	с. Новый Кувак, ул. Журавлева, 49		0101000020E61000009D67EC4B36F049408DD13AAA9A3A4B40
80281	7	72	1591	45541	47682	\N	53.494566456146501	с. Красный Яр, ул. Комсомольская, 92	Россия, Самарская область, Красноярский район, село Красный Яр	0101000020E6100000CD0182397A32494055DB4DF04DBF4A40
80120	7	72	1591	19360	48636	\N	54.420993000000003	д. Костюнькино, ул. Центральная, 21		0101000020E61000001CEE23B726AB4940276C3F19E3354B40
80127	7	72	1591	19678	48567	\N	54.425535000000004	д. Карабикулово, ул. Центральная, 25		0101000020E61000004C38F4160FE34940D5264EEE77364B40
80124	7	72	1591	19538	48198	\N	54.467108000000003	с. Денискино, ул. Хакимова, 27		0101000020E610000021B0726891CF494099D9E731CA3B4B40
80242	7	72	1591	49223	48647	\N	54.328207999999997	с.Вязовка, Центральная, 1 в		0101000020E61000006AD95A5F24D449408D2441B8022A4B40
80136	7	72	1591	20171	48634	\N	54.505785000000003	д. Баландаево, ул. Молодежная, 2		0101000020E6100000D7BD158909CA494058E71890BD404B40
80134	7	72	1591	20062	48633	\N	54.348443000000003	с. Багана, ул. Школьная, 27		0101000020E6100000E7C6F48425B4494094C2BCC7992C4B40
80119	7	72	1591	19305	48356	\N	54.419238	с. Артюшкино, ул. Советская, 34		0101000020E61000002BF86D88F1AE4940C79E3D97A9354B40
80138	7	72	1591	47359	48638	\N	54.519302000000003	с. Аксаково, ул. Школьная, 39	Россия, Самарская область, Шенталинский район, село Аксаково	0101000020E6100000910A630B41D24940AB5FE97C78424B40
80101	7	72	959	18306	48583	\N	54.352778000000001	с. Шламка, Центральная, 68		0101000020E61000002B323A20096D4940C85F5AD4272D4B40
80117	7	72	959	19200	48416	\N	54.605609999999999	с. Чувашское Эштебенькино, Советская, 4		0101000020E6100000D7A6B1BD16944940B610E4A0844D4B40
80115	7	72	959	19101	48419	\N	54.478963999999998	с. Чувашское Урметьево, Центральная, 38	Россия, Самарская область, Челно-Вершинский район, село Чувашское Урметьево	0101000020E610000026AAB706B6A449400DFB3DB14E3D4B40
80102	7	72	959	46642	48462	\N	54.220137000000001	с. Чистовка, Школьная, 16		0101000020E6100000D61BB5C2F4754940DDD1FF722D1C4B40
80113	7	72	959	18629	48346	\N	54.413443999999998	с. Челно-Вершины, микрорайон Сельхозтехника, 16		0101000020E61000000C957F2DAF8A49401C5DA5BBEB344B40
80110	7	72	959	18629	48284	\N	54.413443999999998	с. Челно-Вершины, Центральная, 27		0101000020E61000000C957F2DAF8A49401C5DA5BBEB344B40
80109	7	72	959	18629	48241	\N	54.413443999999998	с. Челно-Вершины, Советская, 18		0101000020E61000000C957F2DAF8A49401C5DA5BBEB344B40
80108	7	72	959	18629	47765	\N	54.413443999999998	с. Челно-Вершины, Почтовая, 3А	Россия, Самарская область, Челно-Вершинский район, село Челно-Вершины	0101000020E61000000C957F2DAF8A49401C5DA5BBEB344B40
80107	7	72	959	18629	47765	\N	54.413443999999998	с. Челно-Вершины, Почтовая, 15		0101000020E61000000C957F2DAF8A49401C5DA5BBEB344B40
80111	7	72	959	18629	48286	\N	54.413443999999998	с. Челно-Вершины, Заводская, 2		0101000020E61000000C957F2DAF8A49401C5DA5BBEB344B40
80112	7	72	959	18629	48232	\N	54.413443999999998	с. Челно-Вершины, М. Джалиля, 44		0101000020E61000000C957F2DAF8A49401C5DA5BBEB344B40
80106	7	72	959	18580	48420	\N	54.335903999999999	с. Токмакла, Центральная, 11	Россия, Самарская область, Челно-Вершинский район, село Токмакла	0101000020E610000051D845D1039349403C4CFBE6FE2A4B40
80116	7	72	959	19104	48196	\N	54.591569	с. Старое Эштебенькино, Школьная, 6Б		0101000020E6100000B3791C06F3954940E9297288B84B4B40
80105	7	72	959	18573	48584	\N	54.527552999999997	с. Старое Аделяково, Школьная, 16А		0101000020E6100000F6285C8FC28349400EF450DB86434B40
80545	7	72	959	7960	47744	\N	54.333877999999999	Самарская область, городской округ Сызрань, Советская, 79		0101000020E61000009E5C5320B37549404C6DA983BC2A4B40
80104	7	72	959	18466	48282	\N	54.537416	с. Сиделькино, Советская, 22		0101000020E6100000CF68AB92C88E49406F2C280CCA444B40
80755	7	72	959	45817	48184	\N	54.470970000000001	с.Покровка, сельский клуб, ул. Первомайская,  6		0101000020E6100000C824236761994940D5B2B5BE483C4B40
80118	7	72	959	19206	48478	\N	54.537562000000001	с. Новое Эштебенькино, Главная, 5		0101000020E6100000E52B8194D89F494043C9E4D4CE444B40
80114	7	72	959	19014	48305	\N	54.483362999999997	с. Новое Аделяково, Озерная, 14	Россия, Самарская область, Челно-Вершинский район, село Новое Аделяково	0101000020E610000069C36169E0914940588CBAD6DE3D4B40
80098	7	72	959	18165	48623	\N	54.569381999999997	с. Новая Таяба, Центральная, 19		0101000020E610000053EC681CEAA749402D776682E1484B40
80100	7	72	959	18266	48581	\N	54.319065000000002	п. Малый Нурлат, Молодежная, 3		0101000020E6100000DD990986737549402D26361FD7284B40
80093	7	72	959	17965	48626	\N	54.475254999999997	с. Малое Девлезеркино, Школьная, 1А		0101000020E61000007E1CCD91959D49405721E527D53C4B40
79954	7	72	959	11235	47751	\N	54.241757	с.Кротовка, Куйбышевская, 21		0101000020E6100000D595CFF23C7A49401F4AB4E4F11E4B40
80095	7	72	959	18021	48137	\N	54.282955000000001	с. Красный Строитель, Школьная, 52А		0101000020E61000008D63247B84904940AE9E93DE37244B40
80099	7	72	959	18252	48463	\N	54.290323999999998	с. Краснояриха, Центральная, 10		0101000020E61000004C8DD0CFD46D4940389F3A5629254B40
79952	7	72	959	48185	48119	\N	54.310268000000001	с. Красная Горка, ул.Чапаевская,69		0101000020E6100000CE8C7E349C924940677FA0DCB6274B40
80097	7	72	959	18161	48412	\N	54.623393999999998	с. Красная Багана, Центральная, 18	Россия, Самарская область, Челно-Вершинский район, село Красная Багана	0101000020E6100000FAEDEBC0399D4940E542E55FCB4F4B40
80096	7	72	959	55892	48201	\N	54.630981961624997	с. Каменный Брод, Школьная, 13	Россия, Самарская область, Челно-Вершинский район, село Каменный Брод	0101000020E6100000D508FD4CBDA44940AE2EA704C4504B40
80094	7	72	959	46459	48627	\N	54.261330000000001	с. Зубовка, Фрунзе, 52А		0101000020E61000004FEB36A8FD8C49405ABBED4273214B40
80092	7	72	959	17863	48227	\N	54.424895999999997	с. Девлезеркино, Советская, 16В		0101000020E6100000543882548A994940C119FCFD62364B40
79836	7	72	959	45827	47745	\N	54.284768999999997	село  Воскресенка, Ленинская, 1		0101000020E6100000CAA5F10BAF6C494012F5824F73244B40
79925	7	72	959	47679	48192	\N	54.222631999999997	с.Александровка, А.Толстого, 8		0101000020E6100000836E2F698C804940838593347F1C4B40
80903	7	72	1751	55916	48447	\N	52.498762999999997	Самарская область, муниципальный район Хворостянский Самарской области, село Чувичи муниципального района Хворостянский Самарской области, Молодежная, 2	Россия, Самарская область, Хворостянский район, село Чувичи	0101000020E610000021037976F972484038BA4A77D73F4A40
80893	7	72	1751	55914	48432	\N	52.663622213623803	Самарская область, муниципальный район Хворостянский Самарской области, станция Чагра муниципального района Хворостянский Самарской области, Хлебная, 20		0101000020E61000003DD2E0B6B6A84840FB73D190F1544A40
80906	7	72	1751	55856	47918	\N	52.609348004640403	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Хворостянка муниципального района Хворостянский Самарской области, Школьная, 18	Россия, Самарская область, Хворостянский район, село Хворостянка	0101000020E6100000A7E8482EFF7B484006F1811DFF4D4A40
80905	7	72	1751	55856	47733	\N	52.614729410919502	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Хворостянка муниципального района Хворостянский Самарской области, Плясункова, 3	Россия, Самарская область, Хворостянский район, село Хворостянка	0101000020E6100000478D0931977A48408E739B70AF4E4A40
80904	7	72	1751	55856	47733	\N	52.608687222220297	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Хворостянка муниципального района Хворостянский Самарской области, Плясункова, 4	Россия, Самарская область, Хворостянский район, село Хворостянка	0101000020E61000006EF7729F1C7B48400C40A374E94D4A40
80887	7	72	1751	55935	48642	\N	52.855420449651099	Самарская область, муниципальный район Хворостянский Самарской области, поселок Тополек муниципального района Хворостянский Самарской области, Центральная, 20	Россия, Самарская область, Хворостянский район, село Тополек	0101000020E61000003A2174D0258A4840132C0E677E6D4A40
80901	7	72	1751	55949	48703	\N	52.790278000000001	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Студенцы муниципального района Хворостянский Самарской области, Новый поселок, 3	Россия, Самарская область, Хворостянский район, село Студенцы	0101000020E6100000A51133FB3C9A4840C85F5AD427654A40
80899	7	72	1751	55954	48708	\N	52.7961758434774	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Соловьево муниципального района Хворостянский Самарской области, Полевая, 1	Россия, Самарская область, Хворостянский район, село Соловьево	0101000020E61000009A44BDE0D374484018EE5C18E9654A40
80128	7	72	1751	55896	48263	\N	52.739632141871603	п. Романовка, ул. Школьная, 1	Россия, Самарская область, Хворостянский район, село Романовка	0101000020E61000000397C79A91B548409C89E942AC5E4A40
80895	7	72	1751	55906	48329	\N	52.515498681437798	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Прогресс муниципального района Хворостянский Самарской области, Молодежная, 5	Россия, Самарская область, Хворостянский район, село Прогресс	0101000020E610000044FAEDEBC0834840730F09DFFB414A40
80888	7	72	1751	55942	48686	\N	52.744963160331203	Самарская область, муниципальный район Хворостянский Самарской области, поселок Приовражный муниципального района Хворостянский Самарской области, Рабочая, 1	Россия, Самарская область, Хворостянский район, село Приовражный	0101000020E610000052B5DD04DF90484072DD94F25A5F4A40
80894	7	72	1751	55902	48303	\N	52.659042145834	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Новотулка муниципального района Хворостянский Самарской области, Советская, 35	Россия, Самарская область, Хворостянский район, село Новотулка	0101000020E6100000B401D880086148406058FE7C5B544A40
80889	7	72	1751	55903	48309	\N	52.668003578509897	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Новокуровка муниципального района Хворостянский Самарской области, Советская, 49	Россия, Самарская область, Хворостянский район, село Новокуровка	0101000020E610000073BA2C2636A5484071CCB22781554A40
80890	7	72	1751	55911	48392	\N	52.632624621392601	Самарская область, муниципальный район Хворостянский Самарской области, село Михайло-Лебяжье муниципального района Хворостянский Самарской области, Центральная, 15	Россия, Самарская область, Хворостянский район, село Михайло-Лебяжье	0101000020E61000002594BE10729E4840E5D022DBF9504A40
80886	7	72	1751	55888	48148	\N	52.820724959914997	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Масленниково муниципального района Хворостянский Самарской области, Советская, 3	Россия, Самарская область, Хворостянский район, село Масленниково	0101000020E61000002B2FF99FFC8B48403B014D840D694A40
80885	7	72	1751	55930	48569	\N	52.628591000985999	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Липовка муниципального района Хворостянский Самарской области, Советская, 8	Россия, Самарская область, Хворостянский район, село Липовка	0101000020E6100000C3B81B446B954840ACC77DAB75504A40
80898	7	72	1751	55915	48440	\N	52.794781	Самарская область, муниципальный район Хворостянский Самарской области, поселок Иерусалимский муниципального района Хворостянский Самарской области, Широкая, 3	Россия, Самарская область, Хворостянский район, село Иерусалимский	0101000020E61000006FD921FE61A94840B83D4162BB654A40
80892	7	72	1751	55941	48685	\N	52.701208869883096	Самарская область, муниципальный район Хворостянский Самарской области, село Елань муниципального района Хворостянский Самарской области, Неверова, 21	Россия, Самарская область, Хворостянский район, село Елань	0101000020E6100000B6B9313D61AB484097546D37C1594A40
80900	7	72	1751	55945	48697	\N	52.7567428149341	Самарская область, муниципальный район Хворостянский Самарской области, поселок Высотино муниципального района Хворостянский Самарской области, Лесная, 12	Россия, Самарская область, Хворостянский район, село Высотино	0101000020E61000002507EC6AF26848400C3D62F4DC604A40
80884	7	72	1751	55886	48118	\N	52.7149398004494	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Владимировка муниципального района Хворостянский Самарской области, Специалистоа, 6	Россия, Самарская область, Хворостянский район, село Владимировка	0101000020E6100000274D83A279784840164D6727835B4A40
80896	7	72	1751	25080	48448	\N	52.537840000000003	Самарская область, муниципальный район Хворостянский Самарской области, поселок Березовая Роща муниципального района Хворостянский Самарской области, Школьная, 26	Россия, Самарская область, Хворостянский район, село Березовая Роща	0101000020E610000064744012F6934840863DEDF0D7444A40
80883	7	72	1751	55905	48316	\N	52.6943984055657	Самарская область, муниципальный район Хворостянский Самарской области, сельское поселение Абашево муниципального района Хворостянский Самарской области, Школьная, 5	Россия, Самарская область, Хворостянский район, село Абашево	0101000020E6100000465ED6C40257484033349E08E2584A40
80498	7	72	617	55850	47686	\N	53.143140000000002	Самарская область, городской округ Сызрань, пр.50 лет октября, 4		0101000020E6100000C367EBE0603B4840EE5F596952924A40
80533	7	72	647	55908	\N	\N	53.160971000000004	Самарская область, городской округ Сызрань, станция Новообразцовое	Россия, Самарская область, Сызранский район	0101000020E610000072BF4351A02D48405E4D9EB29A944A40
80535	7	72	647	55870	47958	\N	53.143305125019602	Самарская область, городской округ Сызрань, Гаражная, 3	Россия, Самарская область, Сызранский район	0101000020E6100000857B65DEAA3B4840382D78D157924A40
80882	7	72	647	24377	48684	\N	53.319043000000001	"Самарская область, с. Чекалино, Железникова, 25 ""А"""		0101000020E6100000C075C58CF03848404582A966D6A84A40
80879	7	72	647	24228	47791	\N	53.324244	Самарская область, с. Усинское, К.Маркса, 30		0101000020E610000001F73C7FDA5848404DF6CFD380A94A40
80870	7	72	647	23784	48677	\N	53.123772000000002	Самарская область,с. Уваровка, Колхозная, 5	Россия, Самарская область, Сызранский район, село Уваровка	0101000020E6100000C70F9546CC2E48408C14CAC2D78F4A40
80827	7	72	647	21830	48504	\N	53.310246999999997	Самарская область,с. Трубетчино, Королева, 7		0101000020E6100000FE7E315BB21E48404F57772CB6A74A40
80611	7	72	647	47609	48662	\N	53.378548000000002	с.Троицкое, Вокзальная, 2		0101000020E61000003C2EAA4544314840ADFBC74274B04A40
80876	7	72	647	55871	47960	\N	53.380534828263499	"Самарская область, муниципальный район Сызранский Самарской области, сельское поселение Старая Рачейка муниципального района Сызранский Самарской области, Ленинская, 2""Б"""	Россия, Самарская область, Сызранский район, село Старая Рачейка	0101000020E61000000518963FDF024840DFFDF15EB5B04A40
80877	7	72	647	24139	48424	\N	53.448008999999999	Самарская область, с .Смолькино, Советская, 57		0101000020E6100000CBD58F4DF20F484026A8E15B58B94A40
80857	7	72	647	23179	48156	\N	53.211725000000001	Самарская область, пос.Сборный, Школьная, 3		0101000020E6100000CBD58F4DF24B4840705F07CE199B4A40
80875	7	72	647	24038	48248	\N	53.232891000000002	Самарская область, с. Рамено, Клубная, 6		0101000020E6100000EA5910CAFB2C484031444E5FCF9D4A40
80874	7	72	647	4304	48299	\N	53.240591999999999	с. Печерское, ул.Советская, 109		0101000020E610000013F241CF66814840F1D6F9B7CB9E4A40
80881	7	72	647	24333	48683	\N	53.252344000000001	Самарская область,с. Печерские Выселки, Советская, 29		0101000020E6100000B70BCD751A6D4840C1ABE5CE4CA04A40
79989	7	72	647	55895	48612	\N	53.284535558252202	Петровка деревня, Солнечная, 5(СДК)	Россия, Самарская область, Сызранский район, село Петровка	0101000020E6100000B0E600C11C4148407044F7AC6BA44A40
80706	7	72	647	55895	48250	\N	53.284124062238902	с. Петровка, ул. Советская,44	Россия, Самарская область, Сызранский район, село Петровка	0101000020E610000028F38FBE494148401D01DC2C5EA44A40
80869	7	72	647	23747	48511	\N	53.131563	"Самарская область,с. Новый Ризадей, Центральная, 16 ""А"""		0101000020E610000007B29E5A7D2148408C2E6F0ED7904A40
80858	7	72	647	55960	48710	\N	53.205608885046502	Самарская область,пос. Новые Озерки, Рабочая, 16	Россия, Самарская область, Сызранский район, село Новыи Озерки	0101000020E61000004A46CEC29E544840B3614D65519A4A40
80872	7	72	647	23919	48395	\N	53.173721999999998	Самарская область,пос. Новорепьевский, Кооперативная, 9		0101000020E6100000889FFF1EBC124840404CC2853C964A40
80871	7	72	647	23839	48510	\N	53.185271	"Самарская область, пос.Новозаборовский, Солнечная, 2""А"""		0101000020E610000011548D5E0D2C4840D8F2CAF5B6974A40
80868	7	72	647	23732	48245	\N	53.086134000000001	"Самарская область, с. Новая Рачейка, Юбилейная, 2""Б"""		0101000020E6100000CF4C309C6B2048406E895C70068B4A40
80860	7	72	647	23355	48561	\N	53.208143999999997	Самарская область, пос. Новая Крымза, Центральная, 11А		0101000020E610000065C39ACAA23E4840E76D6C76A49A4A40
80867	7	72	647	55904	48312	\N	53.264778956424898	"Самарская область, п.г.т. Междуреченск, ЖБК, 9""А"""	Россия, Самарская область, Сызранский район, поселок Междуреченск	0101000020E610000071581AF85191484073D53C47E4A14A40
80865	7	72	647	23570	48298	\N	53.246164	Самарская область, пос. Кошелевка, пер.Северный, 4		0101000020E61000004D83A27900434840EDB94C4D829F4A40
80800	7	72	647	20536	48503	\N	53.044890000000002	село Кашпир, Калиновская, 1		0101000020E610000053E9279CDD3448406FF59CF4BE854A40
80864	7	72	647	23504	48506	\N	53.273603000000001	"Самарская область, с. Ивашевка, Школьная, 16""А"""		0101000020E6100000B1DB6795993A4840338B506C05A34A40
80863	7	72	647	23448	48155	\N	53.228067000000003	"Самарская область, с. Заборовка, Почтовая, 2 ""в"""		0101000020E6100000685C3810921F4840FF25A94C319D4A40
72821	7	71	\N	16298	51512	\N	56.759227000000003	г.Чайковский, ул. К.Маркса, д.30А		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
80862	7	72	647	23447	48247	\N	53.282831999999999	Самарская область, с. Жемковка, Советская, 44	Россия, Самарская область, Сызранский район, село Жемковка	0101000020E61000008F183DB7D01548409221C7D633A44A40
80861	7	72	647	23360	48676	\N	53.307735000000001	"Самарская область, с. Демидовка, Лесная, 52 ""Б"""	Россия, Самарская область, Сызранский район, село Демидовка	0101000020E6100000A51309A69A294840D36A48DC63A74A40
80880	7	72	647	24317	48437	\N	53.312927000000002	Самарская область, с. Губино, Школьная, 10		0101000020E6100000E5F21FD26F5D48408884EFFD0DA84A40
80873	7	72	647	23925	48678	\N	53.201990000000002	Самарская область, пос. Взгорье, Пригородная, 15		0101000020E61000000A65E1EB6B2D48403D0FEECEDA994A40
80598	7	72	647	55894	48306	\N	53.289552154057603	с.Васильевка, Центральная, 52		0101000020E61000002101A3CB9B3F4840E63E390A10A54A40
80859	7	72	647	23276	47792	\N	53.193434000000003	Самарская область, пос.Варламово, Советская, 16		0101000020E6100000C9923996773548409DF7FF71C2984A40
80855	7	72	248	23091	47830	\N	53.610604000000002	Самарская область, муниципальный район Ставропольский Самарской области, село Ягодное, улица Советская, дом 63А	Россия, Самарская область, Ставропольский район, село Ягодное	0101000020E6100000AA61BF27D68548404567994528CE4A40
80854	7	72	248	23087	47818	\N	53.815154999999997	Самарская область, муниципальный район Ставропольский Самарской области, село Хрящевка, улица Полевая, дом 36/5		0101000020E610000089450C3B8C8B4840DF15C1FF56E84A40
80853	7	72	248	23007	47699	\N	53.642367	Самарская область, муниципальный район Ставропольский Самарской области, село Узюково, улица Ленина, дом 100Д		0101000020E610000074081C0934D84840CB83F41439D24A40
80845	7	72	248	55864	47899	\N	53.563984168563302	Самарская область, муниципальный район Ставропольский Самарской области, с.п. Тимофеевка, село Русская Борковка, улица Куйбышева, дом 44	Россия, Самарская область, Тольятти	0101000020E61000004A7F2F8507B34840CFBBB1A030C84A40
80851	7	72	248	22820	48514	\N	53.807803572937203	Самарская область, муниципальный район Ставропольский Самарской области, с.п. Ташелка , поселок Менжинский, улица Центральная, дом 13	Россия, Самарская область, Ставропольский район, село Ташелка	0101000020E6100000D714C8EC2CBA4840FBC9181F66E74A40
80850	7	72	248	22820	48514	\N	53.807244749839299	Самарская область, муниципальный район Ставропольский Самарской области, с.п. Ташелка, село Сосновка, улица Центральная, дом 21	Россия, Самарская область, Ставропольский район, село Ташелка	0101000020E6100000763579CA6ABA4840056EDDCD53E74A40
80849	7	72	248	22820	47696	\N	53.807499	Самарская область, муниципальный район Ставропольский Самарской области, с.п.Ташелка, село Ташелка, улица Менжинского, дом 56		0101000020E61000001364045438BA4840BF4692205CE74A40
80847	7	72	248	4152	47697	\N	53.281571999999997	Самарская область, муниципальный район Ставропольский Самарской области, с.п.Сосновый Солонец, село Сосновый Солонец, улица Куйбышева, дом 45		0101000020E6100000E6762FF7C9C3484012BC218D0AA44A40
95092	7	72	248	50001	47826	\N	53.439400999999997	Самарская область, городской округ Жигулевск, с. Солнечная Поляна, ул. Нефтянников, д.16 здание Школы №2		0101000020E610000059BE2EC37FF24840336ABE4A3EB84A40
80846	7	72	248	2572	48296	\N	53.177683000000002	Самарская область, муниципальный район Ставропольский Самарской области, село Севрюкаево, улица Овражная, дом 8		0101000020E610000058A835CD3BC0484010070951BE964A40
80842	7	72	248	55878	48017	\N	53.508853999999999	Самарская область, муниципальный район Ставропольский Самарской области, поселок Приморский, улица Советская, дом 10		0101000020E610000055C2137AFDB348402A38BC2022C14A40
80222	7	72	248	24320	47845	\N	53.486623999999999	Самарская область, городской округ Самара, Красноглинский район, пос.Прибрежный, Юности, 2А		0101000020E6100000F1129CFA40EE48406FB9FAB149BE4A40
80221	7	72	248	24320	47844	\N	53.486623999999999	Самарская область, городской округ Самара, Красноглинский район, пос.Прибрежный, Труда, 8А		0101000020E6100000F1129CFA40EE48406FB9FAB149BE4A40
80224	7	72	248	24320	47847	\N	53.486623999999999	Самарская область, городской округ Самара, Красноглинский район, пос.Прибрежный, Звездная, 13		0101000020E6100000F1129CFA40EE48406FB9FAB149BE4A40
80223	7	72	248	24320	47847	\N	53.486623999999999	Самарская область, городской округ Самара, Красноглинский район, пос.Прибрежный, Звездная, 11А		0101000020E6100000F1129CFA40EE48406FB9FAB149BE4A40
80840	7	72	248	22414	47885	\N	53.516179000000001	Самарская область, муниципальный район Ставропольский Самарской области, село Подстепки, улица Советская, дом 1А		0101000020E61000002979758E01914840E5F0492712C24A40
80841	7	72	248	22414	47819	\N	53.516179000000001	Самарская область, муниципальный район Ставропольский Самарской области, село Подстепки, улица Набережная, дом 71А		0101000020E61000002979758E01914840E5F0492712C24A40
80838	7	72	248	22298	48509	\N	53.632815919921597	Самарская область, муниципальный район Ставропольский Самарской области, с.п. Пискалы, село Новое Еремкино, улица Школьная, дом 8	Россия, Самарская область, Ставропольский район, село Пискалы	0101000020E610000047AB5AD251E8484059315C1D00D14A40
80837	7	72	248	22298	47817	\N	53.632762999999997	Самарская область, муниципальный район Ставропольский Самарской области, с.п. Пискалы, село Пискалы, улица Дружбы, дом 9		0101000020E61000005A84622B68E84840368FC360FED04A40
80839	7	72	248	22384	48560	\N	53.189791999999997	Самарская область, муниципальный район Ставропольский Самарской области, село Осиновка, улица Лазарева, дом 2		0101000020E6100000C77F812040D248406E85B01A4B984A40
80046	7	72	393	55936	48682	\N	53.81794	село Сосновка, М.Горького, 12	Россия, Самарская область, Похвистневский район, село Сосновка	0101000020E61000004B5CC7B8E2E649408D0B0742B2E84A40
80823	7	72	248	52181	48161	\N	53.608685999999999	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Васильевка, село Зеленовка, улица Советская, дом 72Б		0101000020E61000009946938B31BA48403BC43F6CE9CD4A40
80822	7	72	248	52181	48674	\N	53.608685999999999	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Васильевка, поселок Рассвет, улица Садовая, дом 93Б		0101000020E61000009946938B31BA48403BC43F6CE9CD4A40
80835	7	72	248	22218	48297	\N	53.804234000000001	Самарская область, муниципальный район Ставропольский Самарской области, село Новая Бинарадка, улица Центральная, дом 36А		0101000020E6100000F0BE2A172AF54840672AC423F1E64A40
80834	7	72	248	22161	47790	\N	53.676506000000003	Самарская область, муниципальный район Ставропольский Самарской области, село Нижнее Санчелеево, улица Красноармейская, дом 25		0101000020E610000010786000E1B748401EC6A4BF97D64A40
80833	7	72	248	22112	48302	\N	53.753513502336297	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Мусорка, село Ташла, улица Школьная, дом 20В	Россия, Самарская область, Ставропольский район, село Мусорка	0101000020E61000000C01C0B167DD4840018A912573E04A40
80832	7	72	248	22112	47789	\N	53.754683	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Мусорка, село Мусорка, улица Молодежная, дом 1А		0101000020E610000095F430B43ADD484070ECD97399E04A40
80828	7	72	248	21872	47816	\N	53.675130000000003	Самарская область, муниципальный район Ставропольский Самарской области, поселок Луначарский, улица Злобина, дом 3	Россия, Самарская область, Ставропольский район, село Луначарский	0101000020E610000067EE21E17B8948403546EBA86AD64A40
80825	7	72	248	21720	48387	\N	53.744147903680599	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Верхнее Санчелеево, село Лопатино, улица Советская, дом 32	Россия, Самарская область, Ставропольский район, село Лопатино	0101000020E6100000AF5C6F9BA9B0484021B1DD3D40DF4A40
80836	7	72	248	22296	48180	\N	53.853991000000001	Самарская область, муниципальный район Ставропольский Самарской области, село Кирилловка, улица Советская, дом 21		0101000020E61000002ACAA5F10BE74840070ABC934FED4A40
95091	7	72	248	50000	47892	\N	53.437635999999998	Самарская область, городской округ Жигулевск, село Зольное, ул.Первомайская,д.2а,здание школы №1		0101000020E61000000B7F86376BE64840B0C6D97404B84A40
80830	7	72	248	991	47694	\N	53.361479000000003	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Жигули, село Жигули, улица Центральная, дом 4		0101000020E6100000CE001764CBA648406C98A1F144AE4A40
80826	7	72	248	21821	47693	\N	53.642772999999998	Самарская область, муниципальный район Ставропольский Самарской области, село Выселки, улица Победы, дом 55		0101000020E61000006CEBA7FFACA548403BE0BA6246D24A40
80852	7	72	248	22947	48391	\N	53.776477199774597	Самарская область, муниципальный район Ставропольский Самарской области, с.п.Ташелка, село Верхний Сускан, улица Школьная, дом44	Россия, Самарская область, Ставропольский район, село Верхний Сускан	0101000020E6100000DCF29194F4A24840508C2C9963E34A40
80829	7	72	248	21935	47814	\N	53.728332999999999	Самарская область, муниципальный район Ставропольский Самарской области, село Верхние Белозерки, улица Мира, дом 7		0101000020E6100000F75AD07B639648407DCC07043ADD4A40
80824	7	72	248	21719	47787	\N	53.708714000000001	Самарская область, муниципальный район Ставропольский Самарской области,село Верхнее Санчелеево, улица Кооперативная, дом2		0101000020E6100000FFE89B340DC24840D21BEE23B7DA4A40
80831	7	72	248	22015	48396	\N	53.327911999999998	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Жигули, село Валы, улица Молодежная, дом8		0101000020E610000076543541D4B34840A4FB3905F9A94A40
80820	7	72	248	55907	48330	\N	53.262611999999997	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Большая Рязань, улица Коммунальная, дом 26А		0101000020E6100000F373435376A64840C1C41F459DA14A40
80848	7	72	248	22812	48388	\N	53.243738999999998	Самарская область, муниципальный район Ставропольский Самарской области, с.п. Сосновый Солонец, село Березовый Солонец, улица Советская, дом 39		0101000020E6100000D68BA19C68C748403FE1ECD6329F4A40
80819	7	72	248	21441	48244	\N	53.399932	Самарская область, муниципальный район Ставропольский Самарской области, село Бахилово, улица Бахиловская, дом 2А		0101000020E6100000FF3C0D1824D14840DB4FC6F830B34A40
80480	7	72	248	47940	48533	\N	53.354632000000002	с.Александровка, Центральная, 48		0101000020E6100000C6BFCFB870BC4840BB0ED59464AD4A40
80818	7	72	248	47940	77210	\N	53.349145025735098	Самарская область, сельское поселение Александровка муниципального района Ставропольский Самарской области, улица Фабричная, дом 31	Россия, Самарская область, Ставропольский район, село Александровка	0101000020E61000003E0455A357BB4840ED478AC8B0AC4A40
80843	7	72	7382	55866	47919	\N	53.5658020030125	Самарская область, муниципальный район Ставропольский Самарской области, с.п. Тимофеевка, село Тимофеевка, улица Школьная, дом 54А		0101000020E61000006EA5D76663B3484075012F336CC84A40
80091	7	72	583	17858	47761	\N	53.707483000000003	Самарская область, муниципальный район Сергиевский Самарской области, село Черновка, ул. Новостроевская, д. 13		0101000020E61000002CB81FF0C0624940EDBC8DCD8EDA4A40
80082	7	72	583	17371	48418	\N	53.877623999999997	Самарская область, муниципальный район Сергиевский Самарской области, село Чекалино, ул. Советская, д. 49а		0101000020E6100000DA8F149161754940A417B5FB55F04A40
80067	7	72	583	16666	48410	\N	54.012337000000002	Самарская область, муниципальный район Сергиевский Самарской области, село Успенка, ул. Полевая, д. 39	Россия, Самарская область, Сергиевский район, село Успенка	0101000020E6100000637B2DE8BD874940F0C3414294014B40
80073	7	72	583	16794	47670	\N	53.896617999999997	Самарская область, муниципальный район Сергиевский Самарской области, поселок Суходол, ул. Школьная, д. 68		0101000020E61000008925E5EE739C4940A180ED60C4F24A40
80072	7	72	583	16794	47760	\N	53.896617999999997	Самарская область, муниципальный район Сергиевский Самарской области, поселок Суходол, ул. Суворова, д. 118		0101000020E61000008925E5EE739C4940A180ED60C4F24A40
80071	7	72	583	16794	47902	\N	53.896617999999997	Самарская область, муниципальный район Сергиевский Самарской области, поселок Суходол, ул. Пушкина, д. 2		0101000020E61000008925E5EE739C4940A180ED60C4F24A40
80070	7	72	583	16794	47671	\N	53.903078072339198	Самарская область, муниципальный район Сергиевский Самарской области, поселок Суходол, ул. Мира, д. 12	Россия, Самарская область, Сергиевский район, поселок Суходол	0101000020E610000025CCB4FD2B9D494059DE550F98F34A40
80074	7	72	583	16971	47904	\N	53.920130999999998	Самарская область, муниципальный район Сергиевский Самарской области, поселок Сургут, ул. Сквозная, д. 35		0101000020E610000079245E9ECE994940948444DAC6F54A40
80075	7	72	583	16971	47905	\N	53.920130999999998	Самарская область, муниципальный район Сергиевский Самарской области, поселок Сургут, ул. Первомайская, д. 12а		0101000020E610000079245E9ECE994940948444DAC6F54A40
80085	7	72	583	17567	48582	\N	53.901584	Самарская область, муниципальный район Сергиевский Самарской области, село Старое Якушкино, ул. Центральная, д. 6	Россия, Самарская область, Сергиевский район, село Старое Якушкино	0101000020E61000008446B071FDB94940664CC11A67F34A40
80061	7	72	583	16359	48621	\N	54.135711000000001	Самарская область, муниципальный район Сергиевский Самарской области, село Старая Дмитриевка, ул. Центральная, д. 15		0101000020E610000037FE4465C37649408E5A61FA5E114B40
80083	7	72	583	17413	48461	\N	54.027788999999999	Самарская область, муниципальный район Сергиевский Самарской области, село Спасское, ул. Центральная, д. 5		0101000020E610000038A11001876C4940221807978E034B40
80804	7	72	583	17413	48294	\N	54.027788999999999	с. Спасское ул. Галактионовская,  49		0101000020E610000038A11001876C4940221807978E034B40
80087	7	72	583	17667	48193	\N	53.73048	Самарская область, муниципальный район Сергиевский Самарской области, село Сидоровка, ул. Рабочая, д. 1		0101000020E610000075C8CD7003B84940E8305F5E80DD4A40
80078	7	72	583	17117	47764	\N	53.920305999999997	Самарская область, муниципальный район Сергиевский Самарской области, поселок Серноводск, ул. Советская, д. 61		0101000020E6100000414AECDADEA0494002284696CCF54A40
80077	7	72	583	17117	47842	\N	53.920305999999997	Самарская область, муниципальный район Сергиевский Самарской области, поселок Серноводск, ул. Вокзальная, д. 17		0101000020E6100000414AECDADEA0494002284696CCF54A40
80065	7	72	583	16462	47903	\N	53.944951000000003	Самарская область, муниципальный район Сергиевский Самарской области, село Сергиевск, ул. Советская, д. 66		0101000020E6100000E4D87A867094494048A98427F4F84A40
80064	7	72	583	16462	47724	\N	53.944951000000003	Самарская область, муниципальный район Сергиевский Самарской области, село Сергиевск, ул. Ленина, д. 15		0101000020E6100000E4D87A867094494048A98427F4F84A40
80063	7	72	583	16462	47724	\N	53.944951000000003	Самарская область, муниципальный район Сергиевский Самарской области, село Сергиевск, ул. Ленина, д. 66		0101000020E6100000E4D87A867094494048A98427F4F84A40
95010	7	72	583	50011	47703	\N	53.894134999999999	Самарская область, муниципальный район Сергиевский Самарской области, поселок Светлодольск, ул. Полевая, д. 1		0101000020E61000006614CB2DAD944940BF9A030473F24A40
80076	7	72	583	17074	48542	\N	53.872464999999998	Самарская область, муниципальный район Сергиевский Самарской области, село Нероновка, ул. Центральная, д. 68а		0101000020E6100000B6B9313D61814940CBF3E0EEACEF4A40
80079	7	72	583	17261	48332	\N	53.825609999999998	Самарская область, муниципальный район Сергиевский Самарской области, село Мордовская Селитьба, ул. Кооперативная, д. 48		0101000020E6100000B64C86E3F95A494012A0A696ADE94A40
80060	7	72	583	16270	48620	\N	54.116948000000001	Самарская область, муниципальный район Сергиевский Самарской области, село Липовка, ул. Центральная, д. 16		0101000020E610000060AC6F607285494093AAED26F80E4B40
80089	7	72	583	17720	48138	\N	54.209443999999998	Самарская область, муниципальный район Сергиевский Самарской области, поселок Кутузовский, ул. Центральная, д. 26		0101000020E6100000C8EE0225059E4940F52B9D0FCF1A4B40
80090	7	72	583	17783	\N	\N	54.149751000000002	Самарская область, муниципальный район Сергиевский Самарской области, село Красный Городок, д. 3		0101000020E61000006C96CB46E79249408BC56F0A2B134B40
80088	7	72	583	17683	48195	\N	54.030676999999997	Самарская область, муниципальный район Сергиевский Самарской области, село Красносельское, ул. Школьная, д. 1		0101000020E610000044300E2E1D774940A4DE5339ED034B40
80084	7	72	583	3649	\N	\N	53.849052651601902	Сергиевский район с. Кармало-Аделяково ДК	Россия, Самарская область, Сергиевский район, село Кармало-Аделяково	0101000020E6100000618907944DB349400CC9C9C4ADEC4A40
95011	7	72	583	50012	48224	\N	53.968997999999999	"Самарская область, муниципальный район Сергиевский Самарской области, село Кандабулак, ул. Специалистов, д.4 СДК "		0101000020E6100000041BD7BFEB5D4940D8F15F2008FC4A40
95009	7	72	583	50010	47702	\N	53.831971000000003	Самарская область, муниципальный район Сергиевский Самарской области, село Калиновка, ул. Каськова, д. 17		0101000020E6100000136058FE7CA54940371C96067EEA4A40
80086	7	72	583	17566	\N	\N	53.771039999999999	Самарская область, муниципальный район Сергиевский Самарской области, село Захаркино, ул. Пролетарская, д. 5	Россия, Самарская область, Сергиевский район, село Захаркино	0101000020E61000001C7E37DDB2BB494034F44F70B1E24A40
79969	7	72	583	17358	48216	\N	53.826172103852201	п.Новая Елшанка, Мамаева, 12а	Россия, Самарская область, Сергиевский район, село Елшанка	0101000020E6100000A5C00298326C49407A6F0C01C0E94A40
80081	7	72	583	17358	48417	\N	53.825460999999997	Самарская область, муниципальный район Сергиевский Самарской области, село Елшанка, ул. Кольцова, д. 1		0101000020E61000000DC4B299436C4940CD8FBFB4A8E94A40
80069	7	72	583	16782	48136	\N	53.683914000000001	Самарская область, муниципальный район Сергиевский Самарской области, село Воротнее, пер. Почтовый, д. 5		0101000020E61000007F1475E61E96494066A3737E8AD74A40
95081	7	72	583	49998	48122	\N	53.723331000000002	Самарская область, муниципальный район Сергиевский Самарской области, село Верхняя Орлянка, ул. Советская, д. 26		0101000020E6100000E86C01A1F58849406C97361C96DC4A40
80066	7	72	583	16577	48365	\N	54.018458000000003	Самарская область, муниципальный район Сергиевский Самарской области, село Боровка, ул. Юбилейная, д. 34		0101000020E6100000378C82E0F1A54940BF2CEDD45C024B40
80080	7	72	583	17267	48625	\N	53.784793999999998	Самарская область, муниципальный район Сергиевский Самарской области, село Большая Чесноковка, ул. Центральная, д. 43	Россия, Самарская область, Сергиевский район, село Большая Чесноковка	0101000020E6100000E010AAD4EC5F49406B0C3A2174E44A40
80068	7	72	583	16675	48135	\N	53.952872999999997	Самарская область, муниципальный район Сергиевский Самарской области, поселок Антоновка, ул. Мичурина, д. 31а		0101000020E61000002C0FD253E4A84940E61E12BEF7F94A40
79959	7	72	94	47080	48453	\N	52.809224999999998	п.Федоровка, Юбилейная, 38, 1		0101000020E6100000CB4C69FD2D454840840D4FAF94674A40
80627	7	72	94	47080	48361	\N	52.809069157741	с. Федоровка, ул. Первомайская. 74	Россия, Самарская область, Приволжский район, село Федоровка	0101000020E6100000EA58A5F44C4548408D9AAF928F674A40
80814	7	72	94	47080	48386	\N	52.809224999999998	село Федоровка, Интернациональная, 3/а		0101000020E6100000CB4C69FD2D454840840D4FAF94674A40
80805	7	72	94	20776	48501	\N	52.866636999999997	поселок Томанский, Томана, 1		0101000020E61000007100FDBE7F574840744012F6ED6E4A40
80802	7	72	94	46817	48559	\N	52.957163000000001	поселок Степняки, Школьная, 15		0101000020E61000003A1F9E25C86A48407BF83251847A4A40
80813	7	72	94	20975	48167	\N	52.857334999999999	село Приволжье, Школьная, 7	Россия, Самарская область, Приволжский район, село Приволжье	0101000020E61000006EA301BC054C4840AB5B3D27BD6D4A40
80809	7	72	94	20975	47707	\N	52.857334999999999	село Приволжье, Строителей, 44		0101000020E61000006EA301BC054C4840AB5B3D27BD6D4A40
80810	7	72	94	20975	48292	\N	52.857334999999999	село Приволжье, Специалистов, 12		0101000020E61000006EA301BC054C4840AB5B3D27BD6D4A40
80811	7	72	94	20975	47813	\N	52.857334999999999	село Приволжье, Парковая, 16		0101000020E61000006EA301BC054C4840AB5B3D27BD6D4A40
80812	7	72	94	20975	48672	\N	52.857334999999999	село Приволжье, Мира, 38/г	Россия, Самарская область, Приволжский район, село Приволжье	0101000020E61000006EA301BC054C4840AB5B3D27BD6D4A40
80808	7	72	94	20969	48557	\N	52.795167999999997	село Озерецкое, Центральная, 19		0101000020E61000005470784144604840B169A510C8654A40
81069	7	72	94	826	47700	\N	53.122107	село Обшаровка, Терешковой, 16		0101000020E6100000E4A08499B66B48406CCEC133A18F4A40
80796	7	72	94	826	48151	\N	53.122107	село Обшаровка, Советская, 91		0101000020E6100000E4A08499B66B48406CCEC133A18F4A40
80795	7	72	94	826	47887	\N	53.122107	с. Обшаровка ул.  Победы,10		0101000020E6100000E4A08499B66B48406CCEC133A18F4A40
80801	7	72	94	116	47785	\N	52.996692000000003	п. Новоспасский ул. Школьная,1		0101000020E610000016FA60191B644840A9177C9A937F4A40
80793	7	72	94	20064	48505	\N	53.181375000000003	село Нижнепечерское, Сельская, 3/а		0101000020E61000004DD7135D17784840F0A7C64B37974A40
80807	7	72	94	55951	48705	\N	52.869918051039598	поселок Нижнеозерецкий, Луговая, 2	Россия, Самарская область, Приволжский район, село Нижнеозерецкое	0101000020E61000006AA33A1DC8684840D2191879596F4A40
80806	7	72	94	46918	47786	\N	52.901615999999997	поселок Ильмень, Школьная, 4		0101000020E6100000EDBB22F8DF60484071C6302768734A40
80803	7	72	94	20654	48152	\N	52.952095999999997	село Заволжье, Школьная, 22		0101000020E610000068774831404E484082531F48DE794A40
80816	7	72	94	47114	48680	\N	52.749115000000003	село Давыдовка, Пролетарская, 21		0101000020E6100000C1745AB741354840B6F81400E35F4A40
80799	7	72	94	20360	48675	\N	53.090752020849003	село Бестужевка, Победы, 48/а	Россия, Самарская область, Приволжский район, село Бестужевка	0101000020E6100000A8C64B37894B4840F705F4C29D8B4A40
80798	7	72	94	20360	48558	\N	53.092516000000003	село Бестужевка, Елизарова, 53		0101000020E6100000B08EE3874A4B4840AA2D7590D78B4A40
80715	7	72	393	49392	48779	\N	53.658869000000003	с. Таволжанка, ул. Школьная, 18		0101000020E61000004582A966D6064A4093ACC3D155D44A40
80050	7	72	393	45536	48618	\N	53.789374000000002	село Султангулово, Победы, 10		0101000020E6100000B21188D7F5254A4007280D350AE54A40
80058	7	72	393	16159	48415	\N	53.835611	село Стюхино, Советская, 27-А		0101000020E6100000FB928D075B224A40C4961E4DF5EA4A40
80056	7	72	393	16059	47672	\N	53.706870000000002	село Старый Аманак, Шулайкина, 109		0101000020E61000004E2A1A6B7FFB4940034356B77ADA4A40
80059	7	72	393	16205	47843	\N	53.690562999999997	село Старопохвистнево, Советская, 63-А		0101000020E6100000B875374F75104A40F0694E5E64D84A40
80057	7	72	393	16149	48226	\N	53.898533	село Староганькино, Центральная, 27-А		0101000020E610000065A6B4FE961E4A403AB01C2103F34A40
80053	7	72	393	15917	47841	\N	53.605325999999998	село Среднее Аверкино, Школьная, 2		0101000020E61000005A457F68E6074A4091B586527BCD4A40
80594	7	72	393	55936	\N	\N	53.817988082582701	п.Сосновка, помещение СДК	Россия, Самарская область, Похвистневский район, село Сосновка	0101000020E6100000ACC5A70018E749409E42AED4B3E84A40
79800	7	72	393	2054	48253	\N	53.420627617411398	пос. Октябрьский, г. Похвистнево, Кооперативная, 13	Россия, Самарская область, Похвистневский район, село Октябрьский	0101000020E61000003E42CD902A064A4015E46723D7B54A40
80034	7	72	393	15017	48363	\N	53.672383000000004	поселок Нугайка, Центральная, 30		0101000020E610000034828DEBDF1D4A4075B169A510D64A40
80045	7	72	393	15582	47668	\N	53.876170000000002	село Новое Мансуркино, Ленина, 88		0101000020E61000005ED5592DB0ED494040DEAB5626F04A40
80048	7	72	393	15688	48459	\N	53.579335999999998	село Нижнеягодное, Центральная, 15-Г		0101000020E61000009983A0A355E549409EB29AAE27CA4A40
80054	7	72	393	15973	48194	\N	53.645029999999998	село Нижнеаверкино, Терешковой, 13-Б		0101000020E6100000834E081D74034A402D78D15790D24A40
80044	7	72	393	15496	47901	\N	53.658615286965002	село Мочалеевка, Г.Тукая, 57	Россия, Самарская область, Похвистневский район, село Мочалеевка	0101000020E610000095B54DF1B8E64940D8D30E7F4DD44A40
80041	7	72	393	15347	48199	\N	53.509945999999999	село Малый Толкай, Советская, 35		0101000020E61000001E8997A773E54940EE5C18E945C14A40
80043	7	72	393	15492	47839	\N	53.629009000000003	село Малое Ибряйкино, Школьная, 1-А		0101000020E6100000022CF2EB87144A40E1F1ED5D83D04A40
80038	7	72	393	49583	48222	\N	53.858086	село Кротково, Центральная, 1		0101000020E610000016F88A6EBD104A40E69315C3D5ED4A40
80036	7	72	393	15100	48215	\N	53.573000999999998	село Красные Ключи, Лукьянова, 69-А		0101000020E6100000B0E76B96CBF44940A3C9C51858C94A40
80039	7	72	393	49601	\N	\N	53.905403	село Исаково, Ленина, 46	Россия, Самарская область, Похвистневский район, село Исаково	0101000020E6100000A35A441493074A40A359D93EE4F34A40
80035	7	72	393	15056	47758	\N	53.481990000000003	село Большой Толкай, Ленина, 93		0101000020E6100000DFC5FB71FBF94940E17F2BD9B1BD4A40
80037	7	72	393	15191	48413	\N	53.557437999999998	село Большая Ега, Центральная, 38	Россия, Самарская область, Похвистневский район, село Большая Ега	0101000020E6100000F12900C633FE494019C6DD205AC74A40
80055	7	72	393	16056	48619	\N	53.503883999999999	село Ахрат, Ленина, 2		0101000020E6100000E3E0D231E7034A40247D5A457FC04A40
80033	7	72	393	15007	47898	\N	53.730549000000003	село Алькино, Советская, 93-Б		0101000020E61000000C74ED0BE81F4A4011902FA182DD4A40
80040	7	72	393	15294	48472	\N	53.893476999999997	село Абдул-Завод, Ленина, 15		0101000020E6100000F984ECBC8DFD4940355D4F745DF24A40
80792	7	72	194	751	48673	\N	52.336705000000002	с. Тяглое Озеро ул. Молодежная, 56		0101000020E610000069AB92C83EF6484029B34126192B4A40
80782	7	72	194	19508	48502	\N	52.424560999999997	село Тростянь, Молодежная, 11		0101000020E610000081971936CABC48401A14CD0358364A40
80778	7	72	194	46349	48666	\N	52.278458999999998	село Тепловка, Чкалова, 5		0101000020E6100000FF5A5EB9DEE448407023658BA4234A40
80788	7	72	194	19733	48179	\N	52.406253999999997	село Пестравка, Октябрьская, 7		0101000020E6100000674815C5ABFA484041EF8D2100344A40
80787	7	72	194	19733	48669	\N	52.406253999999997	село Пестравка, Мира, 1		0101000020E6100000674815C5ABFA484041EF8D2100344A40
80789	7	72	194	19733	77323	\N	52.406253999999997	село Пестравка, Крайнюковская, 75		0101000020E6100000674815C5ABFA484041EF8D2100344A40
80791	7	72	194	19733	47784	\N	52.406253999999997	село Пестравка, 50 лет Октября, 65		0101000020E6100000674815C5ABFA484041EF8D2100344A40
80790	7	72	194	19733	47784	\N	52.406253999999997	село Пестравка, 50 лет Октября, 59	Россия, Самарская область, Пестравский район, село Пестравка	0101000020E6100000674815C5ABFA484041EF8D2100344A40
80783	7	72	194	19516	48176	\N	52.465164999999999	село Падовка, Клубная, 3		0101000020E6100000D02A33A5F5C14840361FD7868A3B4A40
80773	7	72	194	55938	48665	\N	52.281901606472303	поселок Овсянка, Садовая, 1	Россия, Самарская область, Пестравский район, село Овсянка	0101000020E6100000C093162EAB064940A8565F5D15244A40
80779	7	72	194	19359	48149	\N	52.306727000000002	село Мосты, Юбилейна, 11		0101000020E610000042D0D1AA96E848406DE690D442274A40
80775	7	72	194	46270	48389	\N	52.209060999999998	п. Михеевка ул. Центральная, 2		0101000020E6100000E44BA8E0F00649403DEFC682C21A4A40
80780	7	72	194	710	48175	\N	52.365375999999998	с. Михайло-Овсянка ул. Школьная,  34		0101000020E61000003387A4164ADE4840245F09A4C42E4A40
80781	7	72	194	19417	48668	\N	52.364269999999998	село Малоархангельское, Ленина, 27	Россия, Самарская область, Пестравский район, село Малоархангельское	0101000020E61000004C512E8D5FBE4840FB743C66A02E4A40
80772	7	72	194	46200	48173	\N	52.273924000000001	село Майское, Центральная, 11		0101000020E6100000A37895B54D05494075CB0EF10F234A40
80777	7	72	194	46324	48670	\N	52.277203	с. Ломовка ул. Коммунистическая, 8а		0101000020E61000008C2FDAE385E8484032AD4D637B234A40
80776	7	72	194	46278	48379	\N	52.200964999999997	поселок Лозовой, Центральная, 5Б		0101000020E61000003866D993C0FC484000529B38B9194A40
80774	7	72	194	46224	48671	\N	52.284833999999996	поселок Крюково, Хлеборобов, 21	Россия, Самарская область, Пестравский район, село Крюково	0101000020E61000006D1D1CEC4D1A4940F964C57075244A40
80785	7	72	194	46476	48384	\N	52.543936000000002	село Красная Поляна, Советская, 2	Россия, Самарская область, Пестравский район, село Красная Поляна	0101000020E6100000228B34F10EC84840FC8EE1B19F454A40
80786	7	72	194	19674	48383	\N	52.491771999999997	село Идакра, Центральная, 2Б		0101000020E610000024F0879FFFDA4840548B8862F23E4A40
80771	7	72	194	46168	48243	\N	52.397494999999999	село Высокое, Телеграфная, 23		0101000020E6100000639B5434D604494069A9BC1DE1324A40
80472	7	72	648	55849	47678	\N	53.180371000000001	Самарская область, городской округ Октябрьск, переулок Железнодорожный, 11а		0101000020E6100000CEDE196D555E4840CB129D6516974A40
80482	7	72	648	55849	47797	\N	53.180371000000001	Самарская область, городской округ Октябрьск, улица Вологина, 7		0101000020E6100000CEDE196D555E4840CB129D6516974A40
80478	7	72	648	55849	48121	\N	53.180371000000001	Самарская область, городской округ Октябрьск, улица 3-го Октября, 2		0101000020E6100000CEDE196D555E4840CB129D6516974A40
79770	7	72	7381	55857	47737	\N	53.056739	город Новокуйбышевск, поселок  Маяк, Куйбышева, 2		0101000020E61000000D52F01472E7484031B43A3943874A40
79953	7	72	68	45836	48214	\N	52.998095999999997	с. Семеновка, пер. Школьный, 22 А		0101000020E6100000234A7B832FF048405B22179CC17F4A40
95008	7	72	68	50009	48689	\N	53.049990000000001	г. Новокуйбышевск, пос. Шмидта, ул. Школьная, 4		0101000020E6100000FE7DC68503E548404390831266864A40
80758	7	72	1496	17356	47704	\N	52.905157000000003	"Утевка, Торговая, 13 (ДК""МИР"")"	Россия, Самарская область, Нефтегорский район, село Утевка	0101000020E61000009F71E140487849406C5F402FDC734A40
80759	7	72	1496	18265	48500	\N	52.731521000000001	Песчаный Дол, Озерная, 10 (Клуб)	Россия, Самарская область, Нефтегорский район, село Песчаный Дол	0101000020E61000003A3FC571E07549402AABE97AA25D4A40
80768	7	72	1496	18364	47690	\N	52.804783	Нефтегорск, проспект Победы, 1 (Культурно-оздоров.центр пенс.)		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80763	7	72	1496	18364	47805	\N	52.804783	Нефтегорск, Школьная, 9(школа №2 большой спортивный зал)		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80762	7	72	1496	18364	47805	\N	52.804783	Нефтегорск, Школьная, 9 (школа №2 малый спортивный зал)	Россия, Самарская область, Нефтегорский район, Нефтегорск	0101000020E61000002A560DC2DC9649403AB01C2103674A40
80767	7	72	1496	18364	47811	\N	52.804783	"Нефтегорск, Нефтяников, 22 (ДК""Нефтяник""танцевальный зал)"		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80765	7	72	1496	18364	47811	\N	52.804783	Нефтегорск, Нефтяников, 35 (школа №3 спортивный зал)		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80764	7	72	1496	18364	47811	\N	52.804783	Нефтегорск, Нефтяников, 35 (школа №3 актовый зал)		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80761	7	72	1496	18364	47884	\N	52.804783	Нефтегорск, Мира, 46 (школа №1)		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80770	7	72	1496	18364	47815	\N	52.804783	Нефтегорск, Зеленая, 7 (Школа искусств)		0101000020E61000002A560DC2DC9649403AB01C2103674A40
80753	7	72	1496	45787	48147	\N	52.779826	Кулешовка, Ленина, 2 (СДК)		0101000020E6100000A33F34F3E48C494006499F56D1634A40
80751	7	72	1496	45744	48172	\N	52.735398000000004	Зуевка, Школьная, 1 (Администрация поселения)		0101000020E610000014252191B68749409CC58B85215E4A40
80754	7	72	1496	55939	\N	\N	52.859406849417603	Ветлянка, Производственная зона, 3	Россия, Самарская область, Нефтегорский район, село Ветлянка	0101000020E6100000C614AC71368F49400B7A6F0C016E4A40
80750	7	72	1496	17861	48549	\N	52.894683999999998	Верхняя Домашка, переулок Школьный, 4 (СДК)		0101000020E610000033C4B12E6E55494092205C0185724A40
80752	7	72	1496	17971	48551	\N	52.742617000000003	Верхнесъезжее, Школьная, 1 (СДК)		0101000020E6100000AEB7CD54889D4940113AE8120E5F4A40
80748	7	72	1496	45694	47692	\N	52.706484000000003	Богдановка, переулок Школьный, 4(школа)		0101000020E6100000008FA850DD604940DA9255116E5A4A40
80747	7	72	1496	17687	48667	\N	52.920079999999999	Бариновка, Чапаевская, 3 (СДК)	Россия, Самарская область, Нефтегорский район, село Бариновка	0101000020E61000004D69FD2D016A494012DA722EC5754A40
80314	7	72	460	28559	48251	\N	53.491061000000002	Самарская область, Красноярский район, село Шилан, Мира, 58	Россия, Самарская область, Красноярский район, село Шилан	0101000020E6100000465ED6C4024F4940A8AB3B16DBBE4A40
80315	7	72	460	28648	48639	\N	53.464947000000002	Самарская область, Красноярский район, село Чапаево, Центральная, 70		0101000020E6100000889CBE9EAF594940C9AF1F6283BB4A40
80309	7	72	460	28369	48123	\N	53.544805517592003	Самарская область, Красноярский район, село Хорошенькое, Центральная, 67		0101000020E6100000D3F88557924C49401155F833BCC54A40
80306	7	72	460	28204	48223	\N	53.476689999999998	Самарская область, Красноярский район, село Хилково, Школьная, 2	Россия, Самарская область, Красноярский район, село Хилково	0101000020E6100000C5A9D6C22C7A4940452A8C2D04BD4A40
80307	7	72	460	28204	48160	\N	53.476689999999998	Самарская область, Красноярский район, село Хилково, Рабочая, 14		0101000020E6100000C5A9D6C22C7A4940452A8C2D04BD4A40
80282	7	72	460	27118	48359	\N	53.546984999999999	Самарская область, Красноярский район, поселок Угловой, Садовая, 4		0101000020E6100000433C122F4F3149408733BF9A03C64A40
80308	7	72	460	28284	48334	\N	53.514057999999999	Самарская область, Красноярский район, село Тростянка, переулок Школьный, 2		0101000020E6100000A626C11BD2664940A31F0DA7CCC14A40
80797	7	72	460	28284	48563	\N	53.514057999999999	с. Тростянка  ул.Полевая,18		0101000020E6100000A626C11BD2664940A31F0DA7CCC14A40
80304	7	72	460	28110	48219	\N	53.643994999999997	Самарская область, Красноярский район, село Старый Буян, Центральная, 104		0101000020E610000025ECDB49441E4940CDE49B6D6ED24A40
80292	7	72	460	4429	48709	\N	53.413602369095202	с. Ст.-Семейкино, ул. Рабочая, 38 б	Россия, Самарская область, Красноярский район, село Старосемейкино	0101000020E61000000CAEB9A3FF214940B4C70BE9F0B44A40
80305	7	72	460	28155	48516	\N	53.584895883383098	Самарская область, Красноярский район, село Старая Бинарадка, Фрунзе, 33		0101000020E61000005B41D3122BFB4840D6C743DFDDCA4A40
80313	7	72	460	28558	48431	\N	53.574888000000001	Самарская область, Красноярский район, поселок Светлый Ключ, Центральная, 6		0101000020E6100000C7116BF129624940726E13EE95C94A40
80299	7	72	460	27896	47759	\N	53.500889999999998	Самарская область, Красноярский район, поселок Светлое Поле, Советская, 3		0101000020E610000077A1B94E232149405C72DC291DC04A40
80273	7	72	460	26753	48213	\N	53.769289000000001	Самарская область, Красноярский район, село Русская Селитьба, Школьная, 50		0101000020E61000007D5EF1D4235349401616DC0F78E24A40
79847	7	72	460	55858	\N	\N	53.3687271806536	поселок Рощинский, Гарнизонный Дом офицеров		0101000020E6100000541F48DE392A49407B13437232AF4A40
80296	7	72	460	4851	48474	\N	53.683396000000002	с. Новый Буян, ул. Энергетиков, 12		0101000020E61000006E861BF0F9054940CE1B278579D74A40
80295	7	72	460	4851	48218	\N	53.683396000000002	Самарская область, Красноярский район, село Новый Буян, Школьная, 14		0101000020E61000006E861BF0F9054940CE1B278579D74A40
80294	7	72	460	4851	48159	\N	53.683396000000002	Самарская область, Красноярский район, село Новый Буян, Степная, 20		0101000020E61000006E861BF0F9054940CE1B278579D74A40
80297	7	72	460	4851	48512	\N	53.683396000000002	"Самарская область, Красноярский район, село Новый Буян, Лесной поселок, 1""б"""		0101000020E61000006E861BF0F9054940CE1B278579D74A40
80298	7	72	460	27847	48513	\N	53.782165999999997	"Самарская область, Красноярский район, деревня Новоурайкино, Центральная, 54""а"""		0101000020E61000006EC328081E0549408505F7031EE44A40
80289	7	72	460	27331	47676	\N	53.375619999999998	Самарская область, Красноярский район, поселок Новосемейкино, Школьная, 9		0101000020E6100000B1FA230C032C49409CDCEF5014B04A40
72068	7	71	\N	56211	62578	\N	58.076858000000001	г.Краснокамск, ул.Матросова, д.14Б	Россия	0101000020E61000002FDB4E5B23E04B40CE37A27BD6094D40
80287	7	72	460	27331	47676	\N	53.375619999999998	Самарская область, Красноярский район, поселок Новосемейкино, Школьная, 12		0101000020E6100000B1FA230C032C49409CDCEF5014B04A40
80290	7	72	460	27331	47865	\N	53.375619999999998	"Самарская область, Красноярский район, поселок Новосемейкино, Советская, 92""а"""		0101000020E6100000B1FA230C032C49409CDCEF5014B04A40
80291	7	72	460	27331	47866	\N	53.375619999999998	"Самарская область, Красноярский район, поселок Новосемейкино, Московская, 1""а"""		0101000020E6100000B1FA230C032C49409CDCEF5014B04A40
80288	7	72	460	27331	47863	\N	53.375619999999998	Самарская область, Красноярский район, поселок Новосемейкино, Мира, 2		0101000020E6100000B1FA230C032C49409CDCEF5014B04A40
79860	7	72	460	46388	48464	\N	53.655234999999998	село Николаевка, Советская, 18		0101000020E6100000018A912573124940E71890BDDED34A40
80300	7	72	460	27956	48333	\N	53.542212999999997	Самарская область, Красноярский район, село Молгачи, Гагарина, 108		0101000020E6100000D865F84F370E4940A73B4F3C67C54A40
80285	7	72	460	4761	47757	\N	53.508479000000001	п. Мирный, ул. Космодемьянской, 10		0101000020E61000004D10751F80224940F5D901D715C14A40
80286	7	72	460	4761	47864	\N	53.508479000000001	Самарская область, Красноярский район, поселок Мирный, Коммунистическая, 1		0101000020E61000004D10751F80224940F5D901D715C14A40
80284	7	72	460	4761	47862	\N	53.508479000000001	Самарская область, Красноярский район, поселок Мирный, Зои Космодемьянской, 20		0101000020E61000004D10751F80224940F5D901D715C14A40
80301	7	72	460	28021	48158	\N	53.444271000000001	Самарская область, Красноярский район, село Малая Царевщина, Набережная, 26		0101000020E6100000338CBB41B4164940D6C743DFDDB84A40
80283	7	72	460	27195	48450	\N	53.623598999999999	Самарская область, Красноярский район, село Малая Каменка, Центральная, 10		0101000020E61000001EFCC401F4314940BE688F17D2CF4A40
80311	7	72	460	28426	48442	\N	53.621426	Самарская область, Красноярский район, село Лопатино, Школьная, 1		0101000020E610000079CC4065FC4F49402A711DE38ACF4A40
80310	7	72	460	28385	48338	\N	53.566172000000002	Самарская область, Красноярский район, село Кривое Озеро, Победы, 4		0101000020E61000000ED76A0F7B41494099F4F75278C84A40
80280	7	72	460	4705	47756	\N	53.494681999999997	Самарская область, Красноярский район, село Красный Яр, Полевая, 5		0101000020E610000089601C5C3A324940BEF561BD51BF4A40
80279	7	72	460	4705	47747	\N	53.494681999999997	Самарская область, Красноярский район, село Красный Яр, Пионерская, 63		0101000020E610000089601C5C3A324940BEF561BD51BF4A40
80312	7	72	460	28479	48522	\N	53.583885000000002	Самарская область, Красноярский район, поселок Конезавод, Каштановая, 7		0101000020E6100000FD9FC37C79534940FFCF61BEBCCA4A40
80276	7	72	460	26844	47674	\N	53.738134000000002	Самарская область, Красноярский район, поселок Коммунарский, Центральная, 13		0101000020E61000009CDF30D1202949406808C72C7BDE4A40
80302	7	72	460	28026	48515	\N	53.534298	Самарская область, Красноярский район, село Колодинка, Колодинская, 1		0101000020E6100000A1BE654E971B4940BB287AE063C44A40
80277	7	72	460	26933	48568	\N	53.743411000000002	Самарская область, Красноярский район, село Калиновка, Школьная, 10		0101000020E610000060AB048BC31F49404B3E761728DF4A40
80303	7	72	460	28101	48120	\N	53.587460999999998	Самарская область, Красноярский район, село Екатериновка, Шоссейная, 25		0101000020E61000000DE02D90A026494075560BEC31CB4A40
80817	7	72	460	28101	48308	\N	53.587563553079299	село Екатериновка, Центральная, 23	Россия, Самарская область, Красноярский район, село Екатериновка	0101000020E6100000221B48179B2649404A27124C35CB4A40
80274	7	72	460	5213	47860	\N	53.432535000000001	Самарская область, Красноярский район, поселок Волжский, Князева, 62		0101000020E61000008E06F016480E49400CB08F4E5DB74A40
80275	7	72	460	5213	47861	\N	53.432535000000001	п.Волжский, Жилгородок, 25		0101000020E61000008E06F016480E49400CB08F4E5DB74A40
80293	7	72	460	2681	48331	\N	53.377446999999997	с. Водино, ул.Рабочая, 34А		0101000020E61000001FDAC70A7E354940957CEC2E50B04A40
80272	7	72	460	26659	48157	\N	53.692945999999999	Самарская область, Красноярский район, село Большая Раковка, Комсомольская, 75		0101000020E6100000A60D87A5814F49406FF25B74B2D84A40
80271	7	72	460	26654	48209	\N	53.666241999999997	Самарская область, Красноярский район, село Большая Каменка, Центральная, 37		0101000020E6100000EE5EEE93A34049405E9CF86A47D54A40
80220	7	72	460	24233	47850	\N	53.519637000000003	Самарская область, городской округ Самара, Красноглинский район, пос.Береза, Лесная, 8	Россия, Самарская область, Красноярский район, поселок Береза	0101000020E61000007B849A21551249405265187783C24A40
80278	7	72	460	47750	47683	\N	53.4373426940071	Самарская область, Красноярский район, село Белозерки, Дзержинского, 27	Россия, Самарская область, Красноярский район, село Белозерка	0101000020E610000062D7F6764B2E49403811FDDAFAB74A40
80560	7	72	460	46604	47873	\N	53.779729000000003	с. Алексеевка, ул. Комсомольская 6а, Здание школы (корпус 2)		0101000020E61000006BBA9EE8BA344940145FED28CEE34A40
80209	7	72	7380	55881	48077	\N	53.345027000000002	Самарская область, городской округ Самара, Красноглинский район, пос.Управленческий, Сергея Лазо, 23А		0101000020E6100000B37DC85BAE1C4940569E40D829AC4A40
80218	7	72	7380	55854	47721	\N	53.389767749119201	Самарская область, городской округ Самара, Красноглинский район, пос.Красная Глинка, квартал 4, Детская школа искусств №15		0101000020E61000001A6EC0E7871549407F83F6EAE3B14A40
80746	7	72	455	17668	48239	\N	52.890984000000003	Самарская область, Красноармейский район, посёлок Чапаевский, ул. Набережная, д. 27		0101000020E610000097A8DE1AD8EC484030A182C30B724A40
80741	7	72	455	17372	48554	\N	52.637210000000003	Самарская область, Красноармейский район, посёлок Софинский, ул. Молодежная, д.25		0101000020E61000005C9198A0861949409357E71890514A40
80733	7	72	455	16970	48663	\N	52.666595999999998	Самарская область, Красноармейский район, село Павловка, ул. Молодежная, д.12		0101000020E610000035EF384547DC48407CD2890453554A40
80645	7	72	455	48263	48265	\N	52.750717999999999	с. Новопавловка, Советская, 37		0101000020E610000056EF703B34F048405F42058717604A40
80737	7	72	455	48263	48699	\N	52.751082356268299	Самарская область, Красноармейский район, посёлок Ново-Павловка, ул.Первомайская, д.9	Россия, Самарская область, Красноармейский район, село Новопавловка	0101000020E610000008C72C7B12F04840A04E797423604A40
80742	7	72	455	17416	48385	\N	52.711651000000003	Самарская область, Красноармейский район, посёлок Новая Вязовка, ул. Самарская, д.17	Россия, Самарская область, Красноармейский район, село Новая-Вязовка	0101000020E610000069FE98D6A627494036954561175B4A40
80727	7	72	455	16673	48656	\N	52.595486000000001	Самарская область, Красноармейский район, посёлок Медведевский, ул.Победы, д.32	Россия, Самарская область, Красноармейский район, село Медведевский	0101000020E6100000293C6876DDF34840E99C9FE2384C4A40
80721	7	72	455	16362	48550	\N	52.775376000000001	Самарская область, Красноармейский район, посёлок Любицкий, ул. Главная, д.13		0101000020E6100000F7ADD689CB034940390D51853F634A40
80726	7	72	455	16670	48547	\N	52.502968000000003	Самарская область, Красноармейский район, посёлок Любимовка, ул. Мира, д.16		0101000020E6100000D3F6AFAC34E548409F77634161404A40
80738	7	72	455	17259	47794	\N	52.743468	Самарская область, Красноармейский район, посёлок Ленинский, пл. Центральная, д.2		0101000020E6100000F1D4230D6E114940AFCF9CF5295F4A40
80729	7	72	455	16792	48240	\N	52.651034000000003	Самарская область, Красноармейский район, посёлок Куйбышевский, ул. Советская, д.9		0101000020E6100000E814E46723CD4840C34A051555534A40
80731	7	72	455	16884	48657	\N	52.742469999999997	"Самарская область, Красноармейский район, село Криволучье-Ивановка, ул. Центральная, д. 18 ""а"""		0101000020E61000004A4563EDEFC648406C21C841095F4A40
80718	7	72	455	16208	47736	\N	52.714908000000001	Самарская область, Красноармейский район, село Красноармейское, пл. Центральная, д.1	Россия, Самарская область, Красноармейский район, село Красноармейское	0101000020E6100000FE8172DBBE0349400BD3F71A825B4A40
95022	7	72	455	16208	47652	\N	52.714908000000001	Самарская область, Красноармейский район, c.Красноармейское,  ул.Кирова, д.91,		0101000020E6100000FE8172DBBE0349400BD3F71A825B4A40
80719	7	72	455	16208	47652	\N	52.714908000000001	Самарская область, Красноармейский район, село Красноармейское, ул. Кирова, д.38		0101000020E6100000FE8172DBBE0349400BD3F71A825B4A40
80739	7	72	455	17263	48661	\N	52.717874999999999	Самарская область, Красноармейский район, посёлок Кочетковский, пер. Школьный, д.3		0101000020E61000008A3BDEE4B71A4940D9CEF753E35B4A40
80745	7	72	455	17574	48242	\N	52.916442000000004	Самарская область, Красноармейский район, село Колывань, ул.Советская, д.2		0101000020E610000036954561170349402657B1F84D754A40
80735	7	72	455	17075	48659	\N	52.673253000000003	Самарская область, Красноармейский район, посёлок Колыбеловка, ул.Космическая, д.17	Россия, Самарская область, Красноармейский район, село Колыбеловка	0101000020E6100000020F0C207CF448408A7780272D564A40
80728	7	72	455	16777	48378	\N	52.595398000000003	Самарская область, Красноармейский район, село Колокольцовка, ул. Школьная, д.8		0101000020E6100000BC07E8BE9CE748404A0D6D00364C4A40
80734	7	72	455	17064	48150	\N	52.673979000000003	Самарская область, Красноармейский район, посёлок Кировский, ул.Кирова, д.17		0101000020E6100000098B8A389DEC48406C98A1F144564A40
80744	7	72	455	17565	48692	\N	52.891700999999998	Самарская область, Красноармейский район, село Каменный Брод, ул. Центральная, д.30		0101000020E6100000EB39E97DE3FB4840BE67244223724A40
80724	7	72	455	16515	48443	\N	52.548136999999997	"Самарская область, Красноармейский район, посёлок Дубовка, ул. Центральная, д.18 ""а"""		0101000020E61000005ED89AADBC084940205D6C5A29464A40
80743	7	72	455	17469	48185	\N	52.896515000000001	Самарская область, Красноармейский район, село Дергачи, ул. Молодежная, д.9		0101000020E6100000C1AA7AF99D044940CDAFE600C1724A40
80732	7	72	455	16967	48380	\N	52.774689000000002	Самарская область, Красноармейский район, посёлок Гражданский, ул. Советская, д.67		0101000020E61000001D1D5723BBD8484015C9570229634A40
80722	7	72	455	16464	48660	\N	52.554965000000003	"Самарская область, Красноармейский район, село Волчанка, ул. Советская, д.51 ""б"""		0101000020E6100000A83462669FFD48405BB6D61709474A40
80736	7	72	455	17118	\N	\N	52.773010999999997	Самарская область, Красноармейский район, посёлок Братский, ул.Жидкова, д.5	Россия, Самарская область, Красноармейский район, село Братский	0101000020E6100000D68C0C7217F7484060394206F2624A40
80723	7	72	455	16474	48552	\N	52.626911999999997	Самарская область, Красноармейский район, село Арсентьевка, ул. Ленина, д.5		0101000020E6100000FF7A8505F7FF484027BC04A73E504A40
80730	7	72	455	2624	48658	\N	52.687421000000001	с.Андросовка,ул.Молодежная,3		0101000020E6100000D1950854FFCA4840B4CA4C69FD574A40
80725	7	72	455	16584	48555	\N	52.533354000000003	Самарская область, Красноармейский район, посёлок Алексеевский, ул. Читателей, д.1		0101000020E6100000B69E211CB3EA48406C98A1F144444A40
80005	7	72	392	13628	48613	\N	54.181573999999998	Самарская область, муниципальный район Кошкинский Самарской области, пос.Ягодный, Центральная, 14		0101000020E6100000153C855CA92F4940E6E61BD13D174B40
80027	7	72	392	14717	48406	\N	54.427075000000002	Самарская область, муниципальный район Кошкинский Самарской области, с. Юмратка, Большая, 56		0101000020E61000009C1727BEDA2B494038F8C264AA364B40
80010	7	72	392	13873	48578	\N	54.186357999999998	Самарская область, муниципальный район Кошкинский Самарской области, с. Шпановка, Специалистов, 1		0101000020E6100000B4722F302B5649408AAC3594DA174B40
80006	7	72	392	13681	48576	\N	54.099935000000002	Самарская область, муниципальный район Кошкинский Самарской области, с. Четыровка, Центральная, 31		0101000020E6100000E63DCE3461354940E65C8AABCA0C4B40
80014	7	72	392	14063	48615	\N	54.322310999999999	Самарская область, муниципальный район Кошкинский Самарской области, с.Тенеево, Центральная, 38		0101000020E6100000BA490C022B5149400E12A27C41294B40
80028	7	72	392	14731	48617	\N	54.313803	Самарская область, муниципальный район Кошкинский Самарской области, с. Степная Шентала, Центральная, 41		0101000020E6100000103FFF3D782949407F315BB22A284B40
80024	7	72	392	14537	48575	\N	54.380080999999997	Самарская область, муниципальный район Кошкинский Самарской области, с.Старое Юреево, Центральная, 71а		0101000020E610000071A94A5B5C2749405D6A847EA6304B40
80030	7	72	392	14832	48574	\N	54.336790999999998	Самарская область, муниципальный район Кошкинский Самарской области, с.Старое Фейзуллово, Озерная, 45а		0101000020E6100000600322C495274940274BADF71B2B4B40
80021	7	72	392	7078	48221	\N	54.472791000000001	с.Старое Максимкино, ул. Школьная, 3 ДК		0101000020E61000002FE1D05B3C2E4940EC6B5D6A843C4B40
80026	7	72	392	14626	\N	\N	54.410975999999998	Самарская область, муниципальный район Кошкинский Самарской области, с.Старая Кармала, Школьная, 14	Россия, Самарская область, Кошкинский район, село Старая Кармала	0101000020E6100000D7DAFB54152649406FB88FDC9A344B40
80012	7	72	392	13970	48438	\N	54.156652999999999	Самарская область, муниципальный район Кошкинский Самарской области, с.Старая Ивановка, Центральная, 2		0101000020E6100000F51263997E674940FFE89B340D144B40
80013	7	72	392	14054	48454	\N	54.299877000000002	Самарская область, муниципальный район Кошкинский Самарской области, с. Русская Васильевка, Луговая, 1		0101000020E610000073BB97FBE45A49404BE9995E62264B40
80009	7	72	392	13856	48467	\N	54.101270999999997	Самарская область, муниципальный район Кошкинский Самарской области, д.Рахмановка, Школьная, 6а	Россия, Самарская область, Кошкинский район, село Рахмановка	0101000020E6100000CE380D51854749404084B872F60C4B40
80001	7	72	392	13481	47723	\N	54.229579999999999	Самарская область, муниципальный район Кошкинский Самарской области, пос.Погрузная, Пионерская, 3	Россия, Самарская область, Кошкинский район, село Погрузная	0101000020E6100000134372327139494068E89FE0621D4B40
80002	7	72	392	13489	47897	\N	54.185403999999998	Самарская область, муниципальный район Кошкинский Самарской области, с. Орловка, Октябрьская, 50		0101000020E6100000B0726891ED28494017467A51BB174B40
80015	7	72	392	14149	48610	\N	54.268045999999998	Самарская область, муниципальный район Кошкинский Самарской области, д.Новое Фейзуллово, Центральная, 45	Россия, Самарская область, Кошкинский район, село Новое Фейзуллово	0101000020E61000002E1C08C9025249406CE9D1544F224B40
80023	7	72	392	14484	48408	\N	54.385859000000004	Самарская область, муниципальный район Кошкинский Самарской области, с. Новая Кармала, Рабочая, 38		0101000020E61000005D8B16A06D29494003EFE4D363314B40
80008	7	72	392	13771	48191	\N	54.107273999999997	Самарская область, муниципальный район Кошкинский Самарской области, с. Нижняя Быковка, Центральная, 10г		0101000020E6100000B7B41A12F758494005DB8827BB0D4B40
80004	7	72	392	13590	48189	\N	54.116241000000002	Самарская область, муниципальный район Кошкинский Самарской области, с. Надеждино, Центральная, 61		0101000020E6100000570A815CE22E494028BA2EFCE00E4B40
80025	7	72	392	14622	48455	\N	54.389586999999999	Самарская область, муниципальный район Кошкинский Самарской области, пос.Моховой, Лесная, 14		0101000020E6100000E7A6CD380D2149402FF99FFCDD314B40
80016	7	72	392	14156	48456	\N	54.374774000000002	Самарская область, муниципальный район Кошкинский Самарской области, с.Мамыково, Центральная, 24		0101000020E61000008D47A984275E494010B22C98F82F4B40
80022	7	72	392	14447	48579	\N	54.446323999999997	Самарская область, муниципальный район Кошкинский Самарской области, д.Малое Максимкино, Полевая, 18		0101000020E61000009A7B48F8DE294940BFB5132521394B40
80011	7	72	392	13916	48580	\N	54.200806999999998	Самарская область, муниципальный район Кошкинский Самарской области, д.Левый Салаван, Липовка, 27		0101000020E610000016F6B4C35F45494068E7340BB4194B40
80003	7	72	392	13581	48566	\N	54.149160000000002	Самарская область, муниципальный район Кошкинский Самарской области, д.Красновка, Школьная		0101000020E6100000AFD007CBD826494089EFC4AC17134B40
80000	7	72	392	7069	\N	\N	54.203077	с.Кошки, квартал 4 д 2 Техникум		0101000020E61000002140868E1D3C4940EFC8586DFE194B40
79996	7	72	392	7069	47762	\N	54.203077	Самарская область, муниципальный район Кошкинский Самарской области, с. Кошки, Советская, 30	Россия, Самарская область, Кошкинский район, село Кошки	0101000020E61000002140868E1D3C4940EFC8586DFE194B40
79997	7	72	392	7069	48188	\N	54.203077	Самарская область, муниципальный район Кошкинский Самарской области, с. Кошки, Победы, 5		0101000020E61000002140868E1D3C4940EFC8586DFE194B40
79999	7	72	392	7069	48186	\N	54.203077	Самарская область, муниципальный район Кошкинский Самарской области, с. Кошки, Первомайская, 94а		0101000020E61000002140868E1D3C4940EFC8586DFE194B40
79998	7	72	392	7069	47755	\N	54.203077	Самарская область, муниципальный район Кошкинский Самарской области, с. Кошки, Мира, 5		0101000020E61000002140868E1D3C4940EFC8586DFE194B40
80018	7	72	392	14254	48458	\N	54.251641999999997	Самарская область, муниципальный район Кошкинский Самарской области, с.Залесье, Центральная, 20		0101000020E6100000DD787764AC464940672618CE35204B40
80020	7	72	392	14338	48611	\N	54.386052999999997	Самарская область, муниципальный район Кошкинский Самарской области, с. Ерандаево, Центральная, 19	Россия, Самарская область, Кошкинский район, село Ерандаево	0101000020E61000007E52EDD3F1364940E7C2482F6A314B40
80029	7	72	392	55952	48706	\N	54.268412042935303	Самарская область, муниципальный район Кошкинский Самарской области, д.Городок, Полевая, 17а	Россия, Самарская область, Кошкинский район, село Городок	0101000020E6100000E884D041972E49404EED0C535B224B40
72069	7	71	\N	56211	51878	\N	58.073746999999997	г.Краснокамск, ул.Ленина, д.16	Россия	0101000020E61000006170CD1DFDE14B40CC96AC8A70094D40
80019	7	72	392	14337	48134	\N	54.350929999999998	Самарская область, муниципальный район Кошкинский Самарской области, с. Большое Ермаково, Школьная, 1а		0101000020E6100000058A58C4B0394940B7973446EB2C4B40
80017	7	72	392	14203	48614	\N	54.288142999999998	Самарская область, муниципальный район Кошкинский Самарской области, с. Большая Романовка, Романовская, 62		0101000020E610000004AE2B66843D494021C9ACDEE1244B40
80032	7	72	392	14908	48347	\N	54.255997000000001	Самарская область, муниципальный район Кошкинский Самарской области, с.Большая Константиновка, Центральная, 54		0101000020E6100000A662635E47264940E36F7B82C4204B40
80031	7	72	392	14908	48347	\N	54.255997000000001	с.Большая Константиновка, ул. Центральная, 52 ДК		0101000020E6100000A662635E47264940E36F7B82C4204B40
80007	7	72	392	13767	48577	\N	54.139023999999999	Самарская область, муниципальный район Кошкинский Самарской области, д.Белоозерная, Придорожная, 9	Россия, Самарская область, Кошкинский район, село Белоозерная	0101000020E6100000CB129D65163B4940F7ADD689CB114B40
80621	7	72	392	55889	48165	\N	54.3973317191139	село Андреевка, ул.Чапаева, д.131, здание школы	Россия, Самарская область, Кошкинский район, село Андреевка	0101000020E6100000E0BBCD1B273B4940BFD364C6DB324B40
80563	7	72	392	46650	48163	\N	54.337332000000004	с. Алексеевка, ул.Советская 58, Здание ТЭКСО		0101000020E610000047551344DD1D494078F2E9B12D2B4B40
79994	7	72	542	13122	48449	\N	54.340764999999998	Чувашское Абдикеево село, Центральная, 4(школа)		0101000020E61000007923F3C81FE249408B4F01309E2B4B40
79993	7	72	542	48931	48409	\N	54.33193	с.Черный ключ, ул. Центральная, 2 Школа		0101000020E6100000130D52F014EC4940D847A7AE7C2A4B40
79985	7	72	542	3840	48573	\N	54.359954999999999	с.Усакла, ул. Молодёжная, 16 А  Школа		0101000020E61000009813B4C9E1F549400E846401132E4B40
79988	7	72	542	7370	9889	\N	54.304752000000001	с.Старый Маклауш, ул. Школьная, 15  Школа		0101000020E6100000A296E656081F4A40FFB1101D02274B40
79984	7	72	542	12725	48606	\N	54.201587000000004	Старый Байтермиш село, Центральная, 20(СДК)		0101000020E61000008CDCD3D51DF349403E26529ACD194B40
79983	7	72	542	12654	48605	\N	54.145663999999996	Старые Сосны село, переулок Школьный, 5(школа)		0101000020E61000008DEF8B4B55044A402E1A321EA5124B40
79979	7	72	542	7228	48570	\N	54.244681999999997	с.Старое Семенкино, ул. Школьная, 1 ДК		0101000020E61000007B832F4CA61E4A40BEF561BD511F4B40
79987	7	72	542	7324	48320	\N	54.375869999999999	с.Старое Резябкино, ул. Молодёжная, 11 А Школа	Россия, Самарская область, Клявлинский район, село Старое Резяпкино	0101000020E6100000E5620CACE3F0494015C616821C304B40
79991	7	72	542	13019	48600	\N	54.360909999999997	Русское Добрино село, Молодежная, 62(СДК)		0101000020E610000059F96530463C4A405166834C322E4B40
79973	7	72	542	55918	48457	\N	54.263486999999998	ст.Пронино, ул. Центральная, 10 Школа		0101000020E6100000240ED940BAEE4940E8F527F1B9214B40
79982	7	72	542	12594	\N	\N	54.219636999999999	Новые Сосны село, Школьная, 14(СДК)	Россия, Самарская область, Клявлинский район, село Новые Сосны	0101000020E610000073BD6DA642064A40EBFEB1101D1C4B40
79980	7	72	542	12496	48407	\N	54.227038	Новое Семенкино село, Центральная, 60(школа)	Россия, Самарская область, Клявлинский район, село Новое Семенкино	0101000020E61000005B272EC72B1A4A408179C8940F1D4B40
79990	7	72	542	12930	48602	\N	54.397958000000003	с.Назаровка, ул. Молодёжная, 10 Школа		0101000020E6100000D86322A5D91C4A403E97A949F0324B40
79975	7	72	542	3316	47945	\N	54.264013212761697	Клявлино ж/д станция, Советская, 38(помещение админ. поселения)	Россия, Самарская область, Клявлинский район, село Клявлино	0101000020E6100000B324404D2D034A40035C902DCB214B40
79976	7	72	542	3316	47933	\N	54.258251409531503	Клявлино ж/д станция, Северная, 83(РДК)	Россия, Самарская область, Клявлинский район, село Клявлино	0101000020E6100000E9B7AF03E7024A406494675E0E214B40
79978	7	72	542	3316	48608	\N	54.271357999999999	с.Клявлино ул. Молодежная, 21 Школа		0101000020E6100000174A26A776024A4005C1E3DBBB224B40
79986	7	72	542	48801	48434	\N	54.408875000000002	Ерыкла село, Октябрьская, 45а(СДК)		0101000020E6100000543A58FFE7024A407593180456344B40
79981	7	72	542	3793	48428	\N	54.241636	с.Ерилкино, ул. Центральная, 23 Школа		0101000020E6100000AB949EE9252A4A40A4C4AEEDED1E4B40
79972	7	72	542	7226	48132	\N	54.235174000000001	с.Борискино-Игар, ул. Школьная, 10 Школа		0101000020E610000070CFF3A78DE649404C6F7F2E1A1E4B40
79992	7	72	542	6944	9965	\N	54.414417999999998	с.Балахоновка, ул. Молодежная, 2 Школа		0101000020E61000007FA2B2614D374A40D66F26A60B354B40
79923	7	72	364	9746	47665	\N	53.400914	Самарская область, муниципальный район Кинельский Самарской области, село Чубовка, Нефтяников, 1		0101000020E6100000D8101C97714749401841632651B34A40
79917	7	72	364	9481	48596	\N	53.201661000000001	Самарская область, муниципальный район Кинельский Самарской области, село Филипповка, Озерная, 7		0101000020E61000007CD28904537D494078F01307D0994A40
79729	7	72	364	55853	47716	\N	53.281600347255697	Самарская область, город Кинель, п.Усть-Кинельский, Тимирязева, 6	Россия, Самарская область, Кинельский район, поселок Усть-Кинельский	0101000020E610000003D0285DFA534940DC4603780BA44A40
79912	7	72	364	9268	48399	\N	53.225484000000002	Самарская область, муниципальный район Кинельский Самарской области, поселок Угорье, Школьная, 4		0101000020E6100000647616BD535F4940B9E2E2A8DC9C4A40
79924	7	72	364	9790	48207	\N	53.342108000000003	Самарская область, муниципальный район Кинельский Самарской области, село Сырейка, Советская, 18		0101000020E6100000C8CD70033E43494099D9E731CAAB4A40
79921	7	72	364	9638	48208	\N	53.323179000000003	Самарская область, муниципальный район Кинельский Самарской области, село Сколково, Советская, 39		0101000020E61000005B25581CCE5E494083E0F1ED5DA94A40
79916	7	72	364	9403	48532	\N	53.282573999999997	Самарская область, муниципальный район Кинельский Самарской области, село Покровка, Центральная, 120		0101000020E6100000C7F143A5116D4940965984622BA44A40
79915	7	72	364	9356	48422	\N	53.269694000000001	Самарская область, муниципальный район Кинельский Самарской области, село Павловка, Центральная, 77		0101000020E6100000F0332E1C086F4940B6F63E5585A24A40
79920	7	72	364	9581	47894	\N	53.341441000000003	Самарская область, Кинельский район, СЕЛО нОВЫЙ САРБАЙ, Школьная, 36		0101000020E610000014D044D8F0844940BC41B456B4AB4A40
79919	7	72	364	1918	47749	\N	53.061636999999997	с. Малая Малышевка, ул. Молодежная, 21		0101000020E61000007B698A00A77B49409D9CA1B8E3874A40
79908	7	72	364	9058	48593	\N	53.188827000000003	Самарская область, муниципальный район Кинельский Самарской области,поселок Кутулук, Центральная, 23		0101000020E61000006A15FDA19999494008CDAE7B2B984A40
79918	7	72	364	9486	47667	\N	53.058551999999999	Самарская область, муниципальный район Кинельский Самарской области, село Красносамарское, Кооперативная, 1		0101000020E6100000259529E620664940C58EC6A17E874A40
79913	7	72	364	9272	47893	\N	53.237935999999998	Самарская область, муниципальный район Кинельский Самарской области, поселок Комсомольский, 50 лет Октября, 21	Россия, Самарская область, Кинельский район, село Комсомольский	0101000020E610000016BF29AC546C49404145D5AF749E4A40
79911	7	72	364	9218	47838	\N	53.256960999999997	Самарская область, муниципальный район Кинельский Самарской области, поселок Кинельский, Рабочая, 4		0101000020E6100000BF45274BAD53494079AC1919E4A04A40
79903	7	72	364	55910	48364	\N	53.350338000000001	Самарская область, муниципальный район Кинельский Самарской области, Аул Казахский, Казахская, 79	Россия, Самарская область, Кинельский район, село Казахский	0101000020E6100000C11F7EFE7B6E4940E54526E0D7AC4A40
79909	7	72	364	9110	47720	\N	52.988833	Самарская область, муниципальный район Кинельский Самарской области, село Домашка, Большая, 1		0101000020E61000002FC214E5D2624940501A6A14927E4A40
79906	7	72	364	8961	48538	\N	53.295755999999997	Самарская область, муниципальный район Кинельский Самарской области, село Гурьевка, Центральная, 10-2		0101000020E6100000CFA0A17F8291494042CC2555DBA54A40
79914	7	72	364	9313	48404	\N	53.163502999999999	Самарская область, муниципальный район Кинельский Самарской области, село Грачевка, Пролетарская, 1		0101000020E61000005E4A5D328E8D494021E692AAED944A40
79904	7	72	364	8863	47664	\N	53.27328	Самарская область, муниципальный район Кинельский Самарской области, село Георгиевка, Специалистов, 19		0101000020E610000004ABEAE5777E49405053CBD6FAA24A40
79907	7	72	364	8863	48714	\N	53.2737538722184	Самарская область, муниципальный район Кинельский Самарской области, поселок Вертяевка, Комсомольская, 52	Россия, Самарская область, Кинельский район, село Георгиевка	0101000020E61000008194D8B5BD7B49401893FE5E0AA34A40
79922	7	72	364	9722	48283	\N	53.345016000000001	Самарская область, муниципальный район Кинельский Самарской области, село Бузаевка, Юбилейная, 57		0101000020E6100000FC1873D712544940624CFA7B29AC4A40
79905	7	72	364	8951	48362	\N	53.24756	Самарская область, муниципальный район Кинельский Самарской области, село Большая Малышевка, Школьная, 1		0101000020E61000003F6F2A52619249401DE6CB0BB09F4A40
79902	7	72	364	8780	47705	\N	53.326245	Самарская область, муниципальный район Кинельский Самарской области, село Богдановка, Конычева, 12 а		0101000020E6100000917F66101F724940E4BD6A65C2A94A40
79900	7	72	364	1994	47663	\N	53.155679999999997	с. Бобровка, ул. Кирова. 28 в		0101000020E6100000BC4049810556494015527E52ED934A40
79899	7	72	364	1866	48274	\N	53.419921000000002	с. Алакаевка, ул. Юбилейная, 37		0101000020E6100000887FD8D2A35F4940AAF3A8F8BFB54A40
79970	7	72	342	48522	47750	\N	53.337285000000001	с.Черновка, Школьная, 34		0101000020E6100000E27668588CB249403737A6272CAB4A40
79966	7	72	342	48448	48599	\N	53.417119	п.Чернигово, Солнечная, 1, 2		0101000020E61000002D25CB492899494026C5C72764B54A40
79940	7	72	342	47965	48423	\N	53.418193000000002	с.Тоузаково, Центральная, 32б		0101000020E6100000F20A444FCABA49404435255987B54A40
78719	7	72	342	46576	47714	\N	53.346586000000002	с.Тимашево, Фрунзе, 90		0101000020E61000007DCA3159DC95494030A017EE5CAC4A40
79967	7	72	342	46576	47753	\N	53.346586000000002	с. Тимашево, ул. Революционная, 62		0101000020E61000007DCA3159DC95494030A017EE5CAC4A40
79968	7	72	342	46576	47754	\N	53.346586000000002	с.Тимашево, Комсомольская, 31		0101000020E61000007DCA3159DC95494030A017EE5CAC4A40
79887	7	72	342	55958	\N	\N	53.558912969871898	Камышлинский район с. Степановка сельский клуб	Россия, Самарская область, Кинель-Черкасский район, село Степановка	0101000020E61000000F80B8AB57814940952710768AC74A40
80756	7	72	342	55901	48300	\N	53.541552091865398	Семеновка, Центральная, 56 (СДК)		0101000020E610000055336B2920AB4940AD8A709351C54A40
79935	7	72	342	47865	48401	\N	53.630355000000002	с.Сарбай, Революционная, 2		0101000020E610000059F8FA5A97C049405FEFFE78AFD04A40
79964	7	72	342	11731	47895	\N	53.384574000000001	п.Садгород, Школьная, 34		0101000020E61000000551F701489549402A7288B839B14A40
79965	7	72	342	48439	48572	\N	53.399329999999999	с.Репьевка, Победы, 2		0101000020E6100000F59ECA694F894940E527D53E1DB34A40
79963	7	72	342	11674	48426	\N	53.218243999999999	с.Пустовалово, Центральная, 29б		0101000020E6100000B72407EC6A9A49402C465D6BEF9B4A40
79951	7	72	342	11106	48624	\N	53.481861000000002	с.Прокопенки, Гоголя, 17		0101000020E6100000FCA9F1D24DCA4940E31B0A9FADBD4A40
79930	7	72	342	1660	48540	\N	53.418793999999998	с. Полудни, ул. Солнечная, 55		0101000020E6100000B8E68EFE97DD494069E1B20A9BB54A40
79962	7	72	342	48385	47849	\N	53.251508999999999	п.Подгорный, Физкультурная, 3	Россия, Самарская область, Кинель-Черкасский район, село Подгорный	0101000020E6100000AE2EA704C496494028D3687231A04A40
79960	7	72	342	48355	48597	\N	53.307068000000001	с.Новые Ключи, Советская, 36		0101000020E6100000A3586E6935F04940F6D214014EA74A40
79958	7	72	342	48319	48144	\N	53.337446	с.Муханово, Школьная, 1в	Россия, Самарская область, Кинель-Черкасский район, село Муханово	0101000020E6100000DF313CF6B3A449404015376E31AB4A40
79961	7	72	342	11573	48405	\N	53.399943	с.Лозовка, Заречная, 1		0101000020E6100000255CC823B8E74940CFA10C5531B34A40
79955	7	72	342	48260	47752	\N	53.28295	с.Кротовка, Школьная, 19		0101000020E6100000804754A86E9649409C33A2B437A44A40
80103	7	72	342	48260	48594	\N	53.283307688977899	с. Кротовка, Центральная, 3	Россия, Самарская область, Кинель-Черкасский район, село Кротовка	0101000020E610000095826E2F69964940FB58C16F43A44A40
79957	7	72	342	48260	47896	\N	53.282913360814099	с.Кротовка, Советская, 1г	Россия, Самарская область, Кинель-Черкасский район, село Кротовка	0101000020E61000009752978C639649407F4E417E36A44A40
79956	7	72	342	48260	47840	\N	53.28295	с.Кротовка, Полевая, 1а		0101000020E6100000804754A86E9649409C33A2B437A44A40
79932	7	72	342	10194	48400	\N	53.313614999999999	с.Коханы, Советская, 32	Россия, Самарская область, Кинель-Черкасский район, село Коханы	0101000020E61000004D124BCADDD749407C444C8924A84A40
79950	7	72	342	55861	47927	\N	53.462027118812301	с.Кинель-Черкассы, Советская, 8	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E61000009E5DBEF561BD49403B6F63B323BB4A40
79939	7	72	342	55861	48317	\N	53.462844159162699	с. Кинель-Черкассы, ул. Механизаторов, 1 р	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E6100000657094BC3ABD49402D93E1783EBB4A40
79937	7	72	342	55861	47948	\N	53.460285540626103	с.Кинель-Черкассы, Красноармейская, 54	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E61000000EBBEF181EC349404167D2A6EABA4A40
79942	7	72	342	55861	47781	\N	53.467728264312697	с.Кинель-Черкассы, Казакова, 45	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E610000086AC6EF59CC0494035B6D782DEBB4A40
79949	7	72	342	55861	47940	\N	53.469812120036799	с. Кинель-Черкассы, ул. Дружбы, 14	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E6100000A087DA368CBC494059A2B3CC22BC4A40
79947	7	72	342	55865	47913	\N	53.464098550962802	с.Кинель-Черкассы, Школьная, 1а	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E6100000FEB627486CBD49409B8D959867BB4A40
79944	7	72	342	55865	48007	\N	53.463563745838002	с. Кинель-Черкассы, ул. Московская, 2 е		0101000020E61000004417D4B7CCBF49402DCDAD1056BB4A40
79938	7	72	342	55865	48326	\N	53.463237617429897	с.Кинель-Черкассы, Красноармейская, 60а	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E61000001AFA27B858BD4940D921FE614BBB4A40
79936	7	72	342	55865	47972	\N	53.464671763305098	с.Кинель-Черкассы, Красноармейская, 50	Россия, Самарская область, Кинель-Черкасский район, село Кинель-Черкасы	0101000020E6100000056EDDCD53BD4940F7AE415F7ABB4A40
79945	7	72	342	55865	48318	\N	53.462334448688097	с.Кинель-Черкассы, Калинина, 48		0101000020E61000004FCC7A3194C3494018EAB0C22DBB4A40
79933	7	72	342	10256	48280	\N	53.655090999999999	с.Кабановка, Крыгина, 1в		0101000020E61000001955867137A44940B4739A05DAD34A40
79929	7	72	342	10051	48403	\N	53.496037000000001	с.Ерзовка, Центральная, 68		0101000020E610000011E4A08499D44940904DF2237EBF4A40
79928	7	72	342	10006	48598	\N	53.367212000000002	п.Дубовый Колок, Центральная, 8		0101000020E610000008E57D1CCD114A40715985CD00AF4A40
79931	7	72	342	47789	48402	\N	53.365470999999999	п.Вязники, Школьная, 1	Россия, Самарская область, Кинель-Черкасский район, село Вязники	0101000020E61000008333F8FBC5D449407651F4C0C7AE4A40
79943	7	72	342	10747	48211	\N	53.474894999999997	с.Вольная Солянка, Ленинская, 55		0101000020E61000006555849B8CA849405704FF5BC9BC4A40
79934	7	72	342	47838	48206	\N	53.632859000000003	с.Богородское, Молодежная, 1		0101000020E6100000452E3883BF95494059FD118601D14A40
80188	7	72	342	55893	48212	\N	53.618895901129299	с.Березовка, Школьная, 20	Россия, Самарская область, Кинель-Черкасский район, село Березовка	0101000020E6100000DB6B41EF8D7D494007D0EFFB37CF4A40
80647	7	72	342	55893	48527	\N	53.619202088910299	с. Березовка, Набережная, 20	Россия, Самарская область, Кинель-Черкасский район, село Березовка	0101000020E610000005508C2C997D494014CFD90242CF4A40
79927	7	72	342	47718	48281	\N	53.432153999999997	с.Березняки, Первомайская, 5		0101000020E61000000D7041B62C114A40F46A80D250B74A40
79926	7	72	342	9943	48529	\N	53.533912999999998	п.Безречье, Школьная, 1		0101000020E61000003C6876DD5B77494062F4DC4257C44A40
79941	7	72	342	10678	48425	\N	53.403035000000003	с.Алтухово, Центральная, 33б		0101000020E6100000AD8A709351B349405A12A0A696B34A40
79732	7	72	7379	55846	47799	\N	53.255019512126097	Самарская область, город Кинель, п.Алексеевка, Комсомольская, 15	Россия, Самарская область, Кинель городской округ, поселок Алексеевка	0101000020E61000002DEBFEB1103F4940B8E9CF7EA4A04A40
79733	7	72	7379	55846	47829	\N	53.253389855241899	Самарская область, город Кинель, п.Алексеевка, Зазина, 12	Россия, Самарская область, Кинель городской округ, поселок Алексеевка	0101000020E6100000917F66101F404940159161156FA04A40
79892	7	72	960	55961	\N	\N	54.020313848049398	Камышлинский район п. Чулпан сельский клуб	Россия, Самарская область, Камышлинский район, село Чулпан	0101000020E6100000F1660DDE57034A4052D32EA699024B40
79886	7	72	960	55962	\N	\N	54.105305605617502	Камышлинский район с. Татарский Байтуган дом культуры	Россия, Самарская область, Камышлинский район, село Татарский Байтуган	0101000020E610000041F50F2219224A404A09C1AA7A0D4B40
79896	7	72	960	55956	\N	\N	54.046190000000003	Камышлинский район с. Старое Усманово сельский клуб	Россия, Самарская область, Камышлинский район, село Старое Усманово	0101000020E6100000B56D1805C12D4A407DB3CD8DE9054B40
79893	7	72	960	55971	\N	\N	54.070589063612204	Камышлинский район с. Старое Ермаково сельский клуб	Россия, Самарская область, Камышлинский район, село Старое Ермаково	0101000020E6100000E0D6DD3CD5FB49408A3A730F09094B40
79888	7	72	960	55966	\N	\N	53.9849646914533	Камышлинский район с. Балыкла сельский клуб	Россия, Самарская область, Камышлинский район, село Старая Балыкла	0101000020E6100000309E4143FF144A40325A475513FE4A40
80815	7	72	960	47396	48390	\N	54.103614292116902	с. Софьино ул. Школьная, 1 школа	Россия, Самарская область, Камышлинский район, село Софьино	0101000020E6100000E44D7E8B4E084A4031B43A39430D4B40
79885	7	72	960	55959	\N	\N	54.088535	Камышлинский район с. Русский Байтуган дом культуры	Россия, Самарская область, Камышлинский район, село Русский Байтуган	0101000020E6100000DB148F8B6A214A4093C6681D550B4B40
79895	7	72	960	55965	\N	\N	54.116547709505497	Камышлинский район с. Новое Усманово сельский клуб	Россия, Самарская область, Камышлинский район, село Новое Усманово	0101000020E610000037A79201A02C4A4005357C0BEB0E4B40
79894	7	72	960	55955	\N	\N	54.058484999999997	Камышлинский район с. Новое Ермаково сельский клуб	Россия, Самарская область, Камышлинский район, село Новое Ермаково	0101000020E6100000A25F5B3FFDF349403D27BD6F7C074B40
79897	7	72	960	55967	\N	\N	54.053201896252403	Камышлинский район с. Никиткино сельский клуб	Россия, Самарская область, Камышлинский район, село Никиткино	0101000020E610000069A9BC1DE1344A40780AB952CF064B40
79898	7	72	960	55957	\N	\N	53.9696588629877	Камышлинский район с. Неклюдово сельский клуб	Россия, Самарская область, Камышлинский район, село Неклюдово	0101000020E6100000D6AA5D13D22E4A40D3A23EC91DFC4A40
79891	7	72	960	8209	\N	\N	54.116968343687098	Камышлинский район с. Камышла школа-интернат	Россия, Самарская область, Камышлинский район, село Камышла	0101000020E6100000F2B0506B9A114A40DA56B3CEF80E4B40
79890	7	72	960	8209	\N	\N	54.114295751636398	Камышлинский район с. Камышла дом культуры	Россия, Самарская область, Камышлинский район, село Камышла	0101000020E6100000DE91B1DAFC114A4025085740A10E4B40
79889	7	72	960	8209	\N	\N	54.114446999999998	Камышлинский район с. Камышла пом ПУ40	Россия, Самарская область, Камышлинский район, село Камышла	0101000020E6100000E161DA37F7114A400A100533A60E4B40
79882	7	72	329	7812	48335	\N	53.923662	д.Сухарь-Матак, Центральная, 10		0101000020E6100000834E081D74C749406B47718E3AF64A40
79880	7	72	329	55944	48696	\N	54.016109	д.Старый Шунгут, Центральная, 33	Россия, Самарская область, Исаклинский район, село Старый Шунгут	0101000020E61000007217618A72C94940EC1516DC0F024B40
79883	7	72	329	2156	48693	\N	54.080242090035	с.С.Вечканово, ул. Советская, 10а Школа		0101000020E61000002481069B3ADF494000E2AE5E450A4B40
79872	7	72	329	7375	48528	\N	54.178781000000001	с.Старая Чесноковка, Центральная, 10		0101000020E61000000400C79E3DA74940B612BA4BE2164B40
79884	7	72	329	7904	48273	\N	54.069661000000004	пос.Сокский, Школьная, 5А		0101000020E61000007FDAA84E07EE49404167D2A6EA084B40
79873	7	72	329	46651	48367	\N	54.122858999999998	с.Смольково, Юбилейная, 60А		0101000020E6100000761A69A9BCA949407782FDD7B90F4B40
79867	7	72	329	7136	48609	\N	54.077491000000002	с.Саперкино, Школьная, 23		0101000020E6100000DEB06D5166D14940FF5D9F39EB094B40
79881	7	72	329	7763	48394	\N	53.891694000000001	с.Самсоновка, ул. Молодежная, 1 Школа	Россия, Самарская область, Исаклинский район, село Самсоновка	0101000020E610000076E3DD91B1C049400C056C0723F24A40
79866	7	72	329	46502	48433	\N	54.055784000000003	пос.Пригорки, Центральная, 23		0101000020E61000007D76C075C5C84940EED11BEE23074B40
14616	7	72	329	6660	48564	\N	53.947769999999998	с.Новое Якушкино, Школьная, 12		0101000020E61000009D4830D5CCC24940A110018750F94A40
79878	7	72	329	7633	48203	\N	53.944600999999999	с.Новое Ганькино, Советская, 80		0101000020E61000000D6C956071EC49406B6281AFE8F84A40
79874	7	72	329	7499	48590	\N	54.082645999999997	д.Новая Чесноковка, Колхозная, 5		0101000020E61000009BFEEC478AB249409692E524940A4B40
79868	7	72	329	7224	48340	\N	53.822580000000002	с.Мордово-Ишуткино, Советская, 1		0101000020E6100000DA58897956D84940FE2B2B4D4AE94A40
79877	7	72	329	55947	48701	\N	53.802697981437298	с.Мордово-Аделяково, ул. Куйбышева, 26 Школа	Россия, Самарская область, Исаклинский район, село Мордово-Аделякова	0101000020E61000009FE74F1BD5CB49404548DDCEBEE64A40
79869	7	72	329	7227	48595	\N	53.852556999999997	с.Малое Ишуткино, Центральная, 42		0101000020E610000030630AD638DF4940E97C789620ED4A40
79864	7	72	329	46468	48445	\N	54.117761000000002	д.Красный Берег, Молодежная, 2		0101000020E6100000A5DC7D8E8FCE494044DFDDCA120F4B40
79870	7	72	329	46598	48534	\N	54.150874000000002	с.Ключи, Школьная, 17	Россия, Самарская область, Исаклинский район, село Ключи	0101000020E6100000205F420587B549408AE8D7D64F134B40
80125	7	72	329	55934	48628	\N	53.933375588531803	с. Каменка, ул. Управленческая, 1	Россия, Самарская область, Исаклинский район, село Каменка	0101000020E61000005628D2FD9CE04940876F61DD78F74A40
79862	7	72	329	6871	47715	\N	54.134433999999999	село Исаклы, Первомайская, 4 А		0101000020E6100000E1CFF0660DC4494038BC202235114B40
79861	7	72	329	6871	47718	\N	54.134433999999999	село Исаклы, Куйбышевская, 63	Россия, Самарская область, Исаклинский район, село Исаклы	0101000020E6100000E1CFF0660DC4494038BC202235114B40
80618	7	72	329	55925	48652	\N	53.798323006836803	село Ивановка, ул.Новая, д.1, здание школы		0101000020E610000007EDD5C743C749408352B4722FE64A40
79871	7	72	329	46619	48589	\N	54.202081999999997	пос.Зелёновский, Школьная, 37		0101000020E610000011FC6F253BBC49401D8EAED2DD194B40
79865	7	72	329	7070	48607	\N	54.091285999999997	д.Два Ключа, Новая, 5		0101000020E6100000A3C85A43A9C94940944A7842AF0B4B40
79879	7	72	329	7685	48336	\N	53.922474999999999	д.Ганькин Матак, Советская, 34		0101000020E61000009E7E501729E4494055302AA913F64A40
79876	7	72	329	7511	48133	\N	53.944960999999999	д.М.Микушкино, ул. Октябрьская, 16 Школа		0101000020E6100000A5A31CCC26D849406B7F677BF4F84A40
79875	7	72	329	7511	48131	\N	53.944960999999999	с.Большое Микушкино, Советская, 102		0101000020E6100000A5A31CCC26D849406B7F677BF4F84A40
79863	7	72	329	6940	48604	\N	54.205489	с.Багряш, Лесная, 6		0101000020E6100000D97BF1457BD849400858AB764D1A4B40
80269	7	72	1725	26559	48470	\N	53.976464999999997	с.Теплый Стан, Школьная, 15		0101000020E61000009CA4F9635A15494025581CCEFCFC4A40
80267	7	72	1725	26460	48586	\N	53.822394000000003	с.Сухие Аврали, Советская, 16		0101000020E6100000EA78CC40650849409C36E33444E94A40
80266	7	72	1725	26363	48231	\N	53.937080000000002	с.Никитинка, Школьная, 19		0101000020E6100000C100C287124749402BDEC83CF2F74A40
80265	7	72	1725	25652	48200	\N	53.976312	п. Нижняя Кондурча ул. Школьная 9 Школа		0101000020E6100000B5FF01D6AA2F49409F58A7CAF7FC4A40
80250	7	72	1725	25652	48200	\N	53.976312	пос.Нижняя Кондурча, Школьная, 9		0101000020E6100000B5FF01D6AA2F49409F58A7CAF7FC4A40
80268	7	72	1725	26506	48469	\N	53.773769999999999	с.Мулловка, Школьная, 43	Россия, Самарская область, Елховский район, село Мулловка	0101000020E6100000996725ADF81449401E5036E50AE34A40
80201	7	72	1725	23358	48451	\N	53.926138999999999	ФАП с. Кубань Озеро ул.Комсомольская 36 ДК		0101000020E61000002D944C4EEDFC48406B4606B98BF64A40
80236	7	72	1725	25000	48290	\N	53.826104000000001	с.Красные Дома, Победы, 3		0101000020E6100000FF4124438E2F4940228C9FC6BDE94A40
80175	7	72	1725	55848	47675	\N	53.868537968090898	с.Елховка, Школьная, 8	Россия, Самарская область, Елховский район, село Елховка	0101000020E6100000494DBB9866244940A8AAD0402CEF4A40
80270	7	72	1725	26568	48588	\N	54.019590000000001	с.Борма, Школьная, 69		0101000020E6100000580229B16B21494011AAD4EC81024B40
79846	7	72	268	6080	48130	\N	52.832604000000003	село Яблоновый Овраг, Николая Наумова, 29		0101000020E6100000FD135CACA8314940684293C4926A4A40
79858	7	72	268	6750	47748	\N	53.162326	Самарская область, Волжский район, с. Черноречье, ул. Победы, 6, Чернореченская средняя школа		0101000020E6100000ECDD1FEF553149402FA52E19C7944A40
79857	7	72	268	6698	48711	\N	53.183543999999998	Самарская область, Волжский район, с. Черновский, ул. Школьная,14		0101000020E61000004BEA0434113C494042B0AA5E7E974A40
79856	7	72	268	1303	47879	\N	52.880572999999998	Самарская область, Волжский район, с. Сухая Вязовка, ул. Советская,1а, Сухо-Вязовская средняя школа		0101000020E61000008DF161F6B21B4940CC5EB69DB6704A40
79853	7	72	268	55869	47925	\N	53.271098196232899	поселок Стройкерамика, Народная, МОУ Смышляевская СОШ №1	Россия, Самарская область, Волжский район, село Спутник	0101000020E6100000F12DAC1BEF3249406901DA56B3A24A40
79848	7	72	268	6188	48289	\N	53.094430484191797	село Спиридоновка, Школьная, 1	Россия, Самарская область, Волжский район, село Спиридоновка	0101000020E6100000417E3672DD52494072E14048168C4A40
79843	7	72	268	5959	48523	\N	53.035009000000002	Самарская область, Волжский район, п. Самарский, ул. Молодежная, 6		0101000020E6100000529CA38E8E1F49406808C72C7B844A40
79839	7	72	268	1124	48125	\N	52.911707	Самарская область, Волжский район, с. Ровно-Владимировка, ул. Центральная, 20, школа		0101000020E6100000D0D38041D22F49406344A2D0B2744A40
79844	7	72	268	5967	47666	\N	53.014471	поселок Просвет, Самарская, 4		0101000020E610000019541B9C883E4940C6DE8B2FDA814A40
79851	7	72	268	61378	79094	\N	53.250168000000002	поселок Смышляевка, Ново-Садовая, МОУ Смышляевская ООШ №2	Россия	0101000020E6100000253D0CAD4E324940BC40498105A04A40
79845	7	72	268	6069	47856	\N	52.817199000000002	село Подъем-Михайловка, Советская, 78		0101000020E6100000B2135E825343494076A911FA99684A40
79832	7	72	268	5273	47855	\N	53.301288999999997	поселок Петра Дубрава, Физкультурная, 6		0101000020E61000007F501729942F494080D250A390A64A40
79831	7	72	268	5273	47837	\N	53.301288999999997	поселок Петра Дубрава, Коммунаров, 4		0101000020E61000007F501729942F494080D250A390A64A40
80062	7	72	268	55912	48414	\N	52.7424497815894	с. Озерки, Школьная, 2	Россия, Самарская область, Волжский район, село Озерки	0101000020E6100000D120054F214549402575029A085F4A40
79842	7	72	268	5811	47706	\N	53.076019000000002	Самарская область, Волжский район, пос. Лопатино, ул. Школьная, 1,  Лопатинская средняя школа		0101000020E610000041D829560D1C4940F46F97FDBA894A40
79841	7	72	268	5811	48182	\N	53.076019000000002	Самарская область, Волжский район, с. Лопатино, ул. Советская, 13, школа		0101000020E610000041D829560D1C4940F46F97FDBA894A40
79816	7	72	268	4528	47834	\N	53.489201999999999	село Курумоч, проспект Ленина, 1		0101000020E610000004594FADBE044940A391CF2B9EBE4A40
78599	7	72	268	4528	47820	\N	53.489201999999999	село Курумоч, Победы, 2б		0101000020E610000004594FADBE044940A391CF2B9EBE4A40
79840	7	72	268	5808	48591	\N	52.984690999999998	Самарская область, Волжский район, пос. Калинка, ул. Советская, 49, школа		0101000020E61000000C40A374E915494030D5CC5A0A7E4A40
79837	7	72	268	45852	48204	\N	52.986930000000001	поселок Журавли, Школьная, 1		0101000020E61000008FFD2C9622FD48407CB8E4B8537E4A40
79838	7	72	268	5659	47857	\N	52.974639000000003	село Дубовый Умет, Советская, 111		0101000020E61000004C1B0E4B03254940FD3383F8C07C4A40
80708	7	72	555	6281	48171	\N	53.276021	с. Языково, ул. Кооперативная, 87		0101000020E6100000554B3ACAC1064A402E01F8A754A34A40
80695	7	72	555	5929	48495	\N	53.013896000000003	с. Широченка, ул. Центральная, 65 г		0101000020E6100000E370E65773C24940CAC51858C7814A40
80717	7	72	555	16162	48499	\N	52.824599999999997	с. Усманка, ул. Центральная, 23		0101000020E610000025CB49287DD949400B24287E8C694A40
80626	7	72	555	47889	48482	\N	53.193390999999998	село Тростянка, ул.Молодежная, д.41, здание школы		0101000020E61000004F3FA88B14FE49409D2B4A09C1984A40
80716	7	72	555	16151	48535	\N	52.767378000000001	Самарская область, Борский район, с. Старая Таволжанка, Восточная, 2		0101000020E6100000185E49F25CDB4940BFD53A7139624A40
80711	7	72	555	15876	48360	\N	53.123998999999998	Самарская область, Борский район, с. Соковнинка, Октябрьская, 81		0101000020E6100000986A662D05FA49404CDE0033DF8F4A40
80696	7	72	555	15190	48654	\N	52.926327149909099	Самарская область, Борский район, с.Покровка, Центральная, 160	Россия, Самарская область, Борский район, село Покровка	0101000020E61000008FDFDBF467BF49406E3315E291764A40
80712	7	72	555	15918	48653	\N	53.153196000000001	Самарская область, Борский район, с. Подсолнечное, Молодежная, 1		0101000020E6100000EB8F300C58024A4063F030ED9B934A40
80709	7	72	555	6291	48277	\N	53.222994	с. Подгорное, ул. Центральная, 27 б		0101000020E6100000D6FCF84B8BE64940249A40118B9C4A40
80704	7	72	555	6142	42041	\N	53.196056750864003	п. Новый Кутулак, ул. Школьная, 8	Россия, Самарская область, Борский район, село Новый Кутулук	0101000020E610000077499C1551CF49407193516518994A40
80710	7	72	555	55943	48694	\N	53.182403638165802	с. Ново-Геранькино, ул. Молодежная, 101 а	Россия, Самарская область, Борский район, село Новогеранькино	0101000020E610000056BABBCE86EC49406D54A70359974A40
80705	7	72	555	15593	47778	\N	53.045183000000002	Самарская область, Борский район, п. Новоборский, пер. Строителей, 3		0101000020E610000071C79BFC16DF4940E7AA798EC8854A40
80707	7	72	555	6187	48544	\N	53.246245000000002	д. Новая Покровка, ул. Звездная,13		0101000020E610000013F3ACA415FD4940DAE6C6F4849F4A40
80699	7	72	555	6071	48377	\N	53.123545	с. Неприк, ул. Садовая, 24 а		0101000020E61000000BB8E7F9D3EC4940CB4A9352D08F4A40
80784	7	72	555	19619	47695	\N	53.280471559223102	село Марьевка, Пенькова, 33	Россия, Самарская область, Борский район, село Марьевка	0101000020E610000073BC02D193CA4940CCB8A981E6A34A40
80688	7	72	555	5861	48493	\N	53.030628	Самарская обл, Борский р-н, п. Лесной, Центральная, 63		0101000020E61000007A8B87F71CF04940C32B499EEB834A40
80703	7	72	555	15499	48278	\N	53.105086999999997	Самарская область, Борский район, с. Коноваловка, Нижне-Ленинская, 8		0101000020E6100000C93A1C5DA5C549400C1EA67D738D4A40
80702	7	72	555	15495	48496	\N	52.963749	"Самарская область, Борский район, п. им. Клары Цеткин, Центральная, 71""А"""		0101000020E6100000BF61A2410AE84940BF4692205C7B4A40
80701	7	72	555	15407	48237	\N	52.972909000000001	"Самарская область, Борский район, с.Заплавное, Любимовка, 25""А"""	Россия, Самарская область, Борский район, село Заплавное	0101000020E6100000957CEC2E50DA4940F67D3848887C4A40
80167	7	72	555	55863	47823	\N	53.205210213420301	с. Елховка ул. Советская, д. 2 Б ДК	Россия, Самарская область, Борский район, село Елховка	0101000020E610000071766B990CD54940F5673F52449A4A40
80698	7	72	555	3432	48376	\N	53.131546999999998	с. Долматовка, ул. Молодежная, 8 а		0101000020E610000007F0164850DE494086713788D6904A40
80714	7	72	555	16055	48498	\N	52.713659	Самарская область, Борский район, с. Гостевка, Луговая, 1		0101000020E61000004985B18520D749407FBF982D595B4A40
80694	7	72	555	15050	48276	\N	52.992659000000003	Самарская область, Борский район, с.Гвардейцы, Школьная, 2		0101000020E6100000A14ACD1E68CB4940408A3A730F7F4A40
80821	7	72	555	15975	47930	\N	53.1807224604647	Самарская область, муниципальный район Ставропольский Самарской области, сельское поселение Васильевка, улица Школьная, дом 19	Россия, Самарская область, Борский район, село Васильевка	0101000020E610000060CB2BD7DB0A4A4078D503E621974A40
80121	7	72	555	15975	47930	\N	53.1809287089023	д. Васильевка, ул. Школьная, 3	Россия, Самарская область, Борский район, село Васильевка	0101000020E61000005DFB027AE10A4A40F1F274AE28974A40
80713	7	72	555	15975	48497	\N	53.181083000000001	Самарская область, Борский район, с. Васильевка, Центральная, 37		0101000020E610000053927538BA0A4A40486E4DBA2D974A40
80692	7	72	555	5866	47810	\N	53.030611999999998	Самарская область, Борский район, с.Борское, Степана Разина, 128		0101000020E6100000D55DD90583D94940BD6E1118EB834A40
80689	7	72	555	5866	47883	\N	53.030611999999998	Самарская область, Борский район, c.Борское, Советская, 28		0101000020E6100000D55DD90583D94940BD6E1118EB834A40
80690	7	72	555	5866	47889	\N	53.030611999999998	Самарская область, Борский район, с.Борское, Первомайская, 50		0101000020E6100000D55DD90583D94940BD6E1118EB834A40
80693	7	72	555	5866	47777	\N	53.030611999999998	Самарская область, Борский район, с.Борское, Ленинградская, 128		0101000020E6100000D55DD90583D94940BD6E1118EB834A40
80691	7	72	555	5866	47777	\N	53.030611999999998	с. Борское, ул. Ленинградская, 50		0101000020E6100000D55DD90583D94940BD6E1118EB834A40
80687	7	72	555	14728	48492	\N	53.103611000000001	с. Большое Алдаркино, ул. Молодежная, 22	Россия, Самарская область, Борский район, село Большое Алдаркино	0101000020E6100000D7187442E8F24940C0401020438D4A40
80697	7	72	555	15197	48543	\N	52.851391	Самарская область, Борский район, с.Благодаровка, Центральная, 89		0101000020E6100000A5A14621C9BA4940EB8D5A61FA6C4A40
80562	7	72	555	6081	48145	\N	52.904054000000002	с. Алексеевка, ул.Школьная 36, Здание школы (корпус 1)		0101000020E610000096E99788B7D44940B4E89D0AB8734A40
80666	7	72	123	13765	48489	\N	52.057547	п.Шумовский, ул.Школьная, д.5		0101000020E6100000BDE13E726B544940D07D39B35D074A40
80686	7	72	123	14719	48374	\N	52.202967999999998	д.Утекаево, ул.Степная, д.24/2		0101000020E6100000514B732B846D49403811FDDAFA194A40
80668	7	72	123	13861	48436	\N	51.938830000000003	п.Устряловский, ул.Центральная, д.8		0101000020E6100000A4367172BF7B49407940D9942BF84940
80684	7	72	123	55897	48272	\N	52.161863321140999	с.Украинка, ул.Школьная, д.25	Россия, Самарская область, Большечерниговский район, село Украинка	0101000020E61000004F7633A31F8549405AB741EDB7144A40
80673	7	72	123	14065	48530	\N	52.101931	п.Торшиловский, ул.Школьная, д.1		0101000020E6100000062B4EB5164E49406BB933130C0D4A40
80676	7	72	123	48811	48373	\N	52.038316999999999	п.Сестры, ул.Центральная, д.3	Россия, Самарская область, Большечерниговский район, село Сестры	0101000020E6100000F19BC24A051B4940BFF04A92E7044A40
80669	7	72	123	40260	9655	\N	51.888743166028597	п.Полянский, ул.Центральная, д.34	Россия, Самарская область, Большечерниговский район, село Полянский	0101000020E61000009888B7CEBF73494043C6A354C2F14940
80682	7	72	123	48922	48170	\N	51.932017000000002	п.Поляков, ул.Физкультурная, д.12		0101000020E6100000A855F48766684940742843554CF74940
80680	7	72	123	14433	48517	\N	52.113236999999998	п.Пензено, ул.Советская, д.18		0101000020E6100000D8F2CAF5B63949403CD9CD8C7E0E4A40
80659	7	72	123	248	48366	\N	52.233044	п. Пекилянка, ул. Набережная, 11		0101000020E6100000F19BC24A05574940B743C362D41D4A40
80681	7	72	123	14449	48507	\N	52.022736000000002	с.Новый Камелик, ул.Молодежная, д.36		0101000020E6100000B58993FB1D3A49408F386403E9024A40
80660	7	72	123	13482	48480	\N	52.140754000000001	п.Малая Черниговка, ул.Степная, д.33		0101000020E6100000C093162EAB5C4940FE63213A04124A40
80677	7	72	123	48821	\N	\N	52.159426000000003	п. Краснооктябрьский,  ул. Школьная, 1а	Россия, Самарская область, Большечерниговский район, село Краснооктябрьский	0101000020E6100000AF5E454607924940E910381268144A40
80679	7	72	123	48863	48536	\N	52.173529000000002	п.Костино, ул.Школьная, д.44		0101000020E61000003F56F0DB10A749402CF4C13236164A40
80678	7	72	123	48837	48368	\N	52.170464000000003	п.Исток, ул.Школьная, д.22	Россия, Самарская область, Большечерниговский район, село Исток	0101000020E6100000EC8502B683A149409B92ACC3D1154A40
80685	7	72	123	5719	48531	\N	52.181050999999997	п.Иргизский,  ул. Центральная, 22		0101000020E61000005D52B5DD047549403CF4DDAD2C174A40
80671	7	72	123	13973	48146	\N	52.155487000000001	п.Глушицкий, ул.Центральная, д.2а		0101000020E6100000EAB0C22D1F37494001FA7DFFE6134A40
80667	7	72	123	48655	48371	\N	51.954374000000001	п. Восточный, ул. Набережная, 2		0101000020E610000007F01648508C49408C135FED28FA4940
80670	7	72	123	13919	48650	\N	52.052525000000003	п.Верхние Росташи, ул.Школьная, д.1		0101000020E61000002FC4EA8F30964940789CA223B9064A40
80661	7	72	123	5596	48142	\N	52.093305999999998	с.Большая Черниговка, ул.Шоссейная, д.2		0101000020E610000048A643A7E76D4940A2427573F10B4A40
80665	7	72	123	5596	47808	\N	52.093305999999998	с.Большая Черниговка, ул.Советская, д.103		0101000020E610000048A643A7E76D4940A2427573F10B4A40
80662	7	72	123	5596	47808	\N	52.093305999999998	с.Большая Черниговка, ул.Советская, д.107		0101000020E610000048A643A7E76D4940A2427573F10B4A40
80664	7	72	123	5596	48236	\N	52.093305999999998	с. Б. Черниговка, ул. Полевая, 96		0101000020E610000048A643A7E76D4940A2427573F10B4A40
80663	7	72	123	5596	47890	\N	52.093305999999998	с. Б. Черниговка, Микрорайон, №7		0101000020E610000048A643A7E76D4940A2427573F10B4A40
80683	7	72	123	48923	48525	\N	51.987957999999999	п.Алексеевский, ул.Школьная, д.11	Россия, Самарская область, Большечерниговский район, село Алексеевский	0101000020E61000005CC98E8D406E494029E9616875FE4940
80675	7	72	123	14161	48372	\N	52.078341999999999	п.Аверьяновский, ул.Центральная, д.44		0101000020E6100000AA9ECC3FFA2849409DF3531C070A4A40
80658	7	72	123	13314	48235	\N	52.248381000000002	с.Августовка, ул.Космическая, д.1		0101000020E6100000191BBAD91F5E494051F9D7F2CA1F4A40
80657	7	72	123	13314	47824	\N	52.248381000000002	с.Августовка, ул.Кооперативная, д.8		0101000020E6100000191BBAD91F5E494051F9D7F2CA1F4A40
80640	7	72	766	24026	48264	\N	52.335026999999997	п. Южный, Центральная, 8		0101000020E6100000D5D006600388494074232C2AE22A4A40
80648	7	72	766	48316	48267	\N	52.397171	п. Фрунзенский, пл. Ленина, 11		0101000020E6100000527C7C4276664940B6F5D37FD6324A40
80641	7	72	766	12591	48490	\N	52.300130000000003	с. Таш-Кустьяново, Центральная, 22		0101000020E61000006B0C3A21749E49403546EBA86A264A40
80646	7	72	766	48270	48266	\N	52.362609999999997	с. Тамбовка, Советская, 26		0101000020E61000008A3E1F65C44B4940ED9925016A2E4A40
80631	7	72	766	12107	48483	\N	52.571268000000003	п. Среднедольск, Полевая, 11		0101000020E610000096067E54C35C49402CA0504F1F494A40
80637	7	72	766	48091	48553	\N	52.442411	п. Озерск, Заречная, 17		0101000020E610000020D099B4A9724940013274ECA0384A40
94999	7	72	766	12650	48713	\N	52.319521999999999	Самарская область, с. Муратшино, ул. Центральная, 10	Россия, Самарская область, Большеглушицкий район, село Муратшино	0101000020E610000022365838498F49401F2DCE18E6284A40
80635	7	72	766	12337	48355	\N	52.402225999999999	с. Морша, Центральная, 117		0101000020E61000007575C7629B604940EACC3D247C334A40
80632	7	72	766	12158	48261	\N	52.671047000000002	с. Мокша, Юбилейная, 13		0101000020E61000006CED7DAA0A3549401A8A3BDEE4554A40
80649	7	72	766	12929	48651	\N	52.390455000000003	п. Малый Каралык, Солнечная, 8		0101000020E6100000BEBED6A5466A4940A4C7EF6DFA314A40
80638	7	72	766	48125	48491	\N	52.351740999999997	п. Малороссийский, Центральная, 3	Россия, Самарская область, Большеглушицкий район, село Малороссийский	0101000020E6100000FF3C0D18247F4940C7D45DD9052D4A40
80643	7	72	766	12724	48190	\N	52.437255999999998	с. Малая Глушица, Советская, 56		0101000020E610000018963FDF161A494069FD2D01F8374A40
80630	7	72	766	12097	48369	\N	52.640062	п. Малая Вязовка, Степная, 33	Россия, Самарская область, Большеглушицкий район, село Малая Вязовка	0101000020E61000007079AC1919484940C8B4368DED514A40
80633	7	72	766	12245	48648	\N	52.568389000000003	п. Ледяйка, Центральная, 10	Россия, Самарская область, Большеглушицкий район, село Ледяйка	0101000020E61000009C189293893F4940FD3383F8C0484A40
80639	7	72	766	12495	48354	\N	52.295112000000003	п. Кочевной, Набережная, 2а		0101000020E6100000A9A27895B58349401E54E23AC6254A40
80644	7	72	766	55890	48178	\N	52.446026525181203	с. Константиновка, Центральная, 7	Россия, Самарская область, Большеглушицкий район, село Константиновка	0101000020E610000025ADF886C21349400611A96917394A40
80656	7	72	766	48452	48488	\N	52.289703000000003	пос. Кобзевка, Советская, 38		0101000020E61000009B1BD313964A4940CC46E7FC14254A40
80636	7	72	766	12389	48649	\N	52.513748999999997	п. Верхнедольск, Молодежная, 6		0101000020E610000040DAFF006B5F494025ADF886C2414A40
80634	7	72	766	12298	48485	\N	52.488888000000003	с. Большая Дергуновка, Советская, 97		0101000020E6100000D15D1267452A494014B4C9E1933E4A40
80651	7	72	766	5371	48140	\N	52.40166	с. Большая Глушица, Чапаевская, 86		0101000020E610000079944A78423D4940410E4A9869334A40
80652	7	72	766	5371	48166	\N	52.40166	с. Большая Глушица, Советская, 39	Россия, Самарская область, Большеглушицкий район, село Большая Глушица	0101000020E610000079944A78423D4940410E4A9869334A40
80654	7	72	766	5371	48234	\N	52.40166	с. Большая Глушица, Первомайская, 24		0101000020E610000079944A78423D4940410E4A9869334A40
80650	7	72	766	5371	47881	\N	52.40166	с.Большая Глушица, ул. Луговая, 34		0101000020E610000079944A78423D4940410E4A9869334A40
80653	7	72	766	5371	48141	\N	52.40166	с. Большая Глушица, Кировская, 40		0101000020E610000079944A78423D4940410E4A9869334A40
80655	7	72	766	5371	48168	\N	52.40166	с. Большая Глушица, Гагарина, 78		0101000020E610000079944A78423D4940410E4A9869334A40
80629	7	72	766	55891	48183	\N	52.597208999999999	с. Александровка, Центральная, 5	Россия, Самарская область, Большеглушицкий район, село Александровка	0101000020E61000005B3FFD67CD4D49403DF03158714C4A40
80628	7	72	726	47919	48358	\N	53.033422999999999	поселок Центральный, ул.Центральная, д.26, здание клуба	Россия, Самарская область, Богатовский район, село Центральный	0101000020E6100000EF906280448F494094F7713447844A40
80624	7	72	726	5059	48521	\N	53.012	с. Съезжее, ул. Молодежная, 33		0101000020E610000055DE8E705A9A4940A8C64B3789814A40
80625	7	72	726	11842	48259	\N	53.064348000000003	село Печинено, ул.Советская, д.1, здание администрации с/п		0101000020E61000001AFD6838659C494011C8258E3C884A40
80674	7	72	726	55922	48494	\N	53.034163049894502	п.Петровский, ул.Полевая, д.24	Россия, Самарская область, Богатовский район, село Петровский	0101000020E6100000C32D1F4949914940DBDD03745F844A40
80623	7	72	726	47824	48169	\N	52.978033000000003	село Максимовка, ул.Октябрьская, д.23, здание администрации с/п		0101000020E6100000EDB8E177D391494053B4722F307D4A40
80619	7	72	726	11569	\N	\N	53.068066000000002	село Кураповка, ул.Фурманова, д.131, здание нового клуба	Россия, Самарская область, Богатовский район, село Кураповка	0101000020E6100000ACE3F8A1D2AE49401AFCFD62B6884A40
80620	7	72	726	5325	48238	\N	53.051549000000001	п.Заливной, ул.Зеленая,1		0101000020E6100000C53BC09316B849401D925A2899864A40
80622	7	72	726	11675	48143	\N	53.024594999999998	село Виловатое, ул.Советская, д.78, здание школы	Россия, Самарская область, Богатовский район, село Виловатое	0101000020E610000085CD001764B949409352D0ED25834A40
80616	7	72	726	11336	47776	\N	53.060614000000001	село Богатое, ул.Чапаева, д.8, здание спортивной школы		0101000020E6100000AA656B7D91AA494002D71533C2874A40
80615	7	72	726	11336	47775	\N	53.060614000000001	"село Богатое, ул.Комсомольская, д.48, здание РДК ""Октябрь"""		0101000020E6100000AA656B7D91AA494002D71533C2874A40
80617	7	72	726	11336	47877	\N	53.060614000000001	село Богатое, ул.Заводская, д.33, здание клуба МЭЗ		0101000020E6100000AA656B7D91AA494002D71533C2874A40
80614	7	72	726	47659	48139	\N	53.184871000000001	с. Беловка, ул. Школьная, 27		0101000020E61000007BBB253960AF49404A7D59DAA9974A40
80612	7	72	726	11222	48255	\N	53.169285000000002	село Арзамасцевка, ул.Школьная, д.24, здание администрации с/п		0101000020E610000044DFDDCA12AF4940085A8121AB954A40
80613	7	72	726	11237	48357	\N	53.158990000000003	село Аверьяновка, ул.Молодежная, д.25, здание  школы		0101000020E61000000B47904AB1A749400E32C9C859944A40
80507	7	72	705	55862	47807	\N	52.957059999999998	ст.Звезда, Кооперативная, 7		0101000020E61000005B7D7555A0CE4840A6272CF1807A4A40
80609	7	72	705	55909	48349	\N	53.049216000000001	ст.Мыльная, Вокзальная, 2		0101000020E61000008C3045B9348A48405038BBB54C864A40
80878	7	72	705	24225	48301	\N	52.863192000606702	Самарская область, с. Троицкое, Бр.Краснеевых, 19	Россия, Самарская область, Безенчукский район, село Троицкое	0101000020E6100000CEFA9463B2DE48409C1551137D6E4A40
80610	7	72	705	47596	48233	\N	52.867925	с.Прибой, Центральная, 5		0101000020E61000005589B2B794D34840BE30992A186F4A40
80608	7	72	705	11045	48258	\N	53.074336000000002	с.Преполовенка, Школьная, 17		0101000020E6100000DA5548F9498148402E7590D783894A40
80606	7	72	705	47516	48254	\N	52.926941999999997	с.Песочное, Центральная, 48	Россия, Самарская область, Безенчукский район, село Песочное	0101000020E61000002FFA0AD28CB74840F8A41309A6764A40
80595	7	72	705	47300	47875	\N	52.848421999999999	п.Осинки, Маяковского, 17		0101000020E61000005C1B2AC6F9C148407C9A9317996C4A40
80602	7	72	705	55860	47780	\N	52.877037149851397	с.Ольгино, Школьная, 1	Россия, Самарская область, Безенчукский район, село Ольгино	0101000020E6100000F4311F10E88E4840E43098BF42704A40
80607	7	72	705	10974	48352	\N	52.837941000000001	с.Новомихайловка, Центральная, 12		0101000020E6100000ACC77DAB75B24840207D93A6416B4A40
80154	7	72	705	47653	48473	\N	53.040056	с.Никольское, Пролетарская, 2	Россия, Самарская область, Безенчукский район, село Никольское	0101000020E61000002F51BD35B0BB48401901158E20854A40
80601	7	72	705	47431	48164	\N	52.939886999999999	с.Натальино, Школьная, 15		0101000020E6100000DE3994A12A864840C0779B374E784A40
72704	7	72	705	11221	48688	\N	52.849820000000001	с.Макарьевка, Мира, 48		0101000020E6100000753BFBCA837C48404DBED9E6C66C4A40
72684	7	72	705	10259	48256	\N	52.993164	с.Купино, Купинская, 8		0101000020E610000070D1C952EBC7484043C879FF1F7F4A40
80604	7	72	705	10869	48348	\N	52.962826	с.Красноселки, Центральная, 1		0101000020E61000006B7EFCA545A5484087DEE2E13D7B4A40
80600	7	72	705	10681	48484	\N	53.149194000000001	с.Кануевка, Центральная, 67а	Россия, Самарская область, Безенчукский район, село Кануевка	0101000020E61000000C569C6A2DA448403561FBC918934A40
80605	7	72	705	47517	48645	\N	52.977404	п.Заволжский, Центральная, 2		0101000020E61000001E335019FFA84840637D03931B7D4A40
80599	7	72	705	47383	47880	\N	53.085833521318598	с.Екатериновка, Фрунзе, 42	Россия, Самарская область, Безенчукский район, село Екатериновка	0101000020E6100000C634D3BD4EB848404371C79BFC8A4A40
80749	7	72	705	45709	47783	\N	52.961275000000001	Дмитриевка, Советская, 8 (СДК)		0101000020E6100000FAEC80EB8AB9484030BB270F0B7B4A40
80591	7	72	705	4908	\N	\N	52.981822999999999	п.Безенчук, Советская, 172	Россия, Самарская область, Безенчукский район, поселок Безенчук	0101000020E61000002D23F59ECAB74840F5BA4560AC7D4A40
80590	7	72	705	4908	47687	\N	52.981822999999999	п.Безенчук, Чапаева, 23		0101000020E61000002D23F59ECAB74840F5BA4560AC7D4A40
80589	7	72	705	4908	47774	\N	52.981822999999999	п.Безенчук, Центральная, 89		0101000020E61000002D23F59ECAB74840F5BA4560AC7D4A40
80593	7	72	705	4908	47688	\N	52.981822999999999	п.Безенчук, Тимирязева, 25		0101000020E61000002D23F59ECAB74840F5BA4560AC7D4A40
80592	7	72	705	4908	47688	\N	52.981822999999999	п.Безенчук, Тимирязева, 94		0101000020E61000002D23F59ECAB74840F5BA4560AC7D4A40
80586	7	72	705	4908	47872	\N	52.981822999999999	п.Безенчук, Садовая, 37		0101000020E61000002D23F59ECAB74840F5BA4560AC7D4A40
80588	7	72	705	4908	47772	\N	52.981405882571103	п.Безенчук, ул. Пушкина,14а	Россия, Самарская область, Безенчукский район, поселок Безенчук	0101000020E6100000EC33677DCAB94840910C39B69E7D4A40
80587	7	72	705	4908	47771	\N	52.981822999999999	п.Безенчук, Комсомольская, 82		0101000020E61000002D23F59ECAB74840F5BA4560AC7D4A40
80576	7	72	664	9484	48641	\N	52.360442999999997	пос.Шариповка, ул.Прикотельная 5, Здание СДК	Россия, Самарская область, Алексеевский район, село Шариповка	0101000020E61000007BD7A02FBDA549403B8908FF222E4A40
80566	7	72	664	46699	48643	\N	52.605468000000002	пос.Субботинский, ул.Пионерская, 18	Россия, Самарская область, Алексеевский район, село Субботинский	0101000020E6100000B403AE2B66B649402463B5F97F4D4A40
80582	7	72	664	47045	48477	\N	52.536799999999999	с.Славинка, ул.Советская 47, Здание СДК		0101000020E6100000AE4A22FB207D4940143FC6DCB5444A40
80571	7	72	664	9264	48640	\N	52.776732000000003	пос.Седыши, ул. Рабочая, 2		0101000020E61000000E9F7422C1B04940DBE044F46B634A40
80584	7	72	664	9883	48345	\N	52.547628000000003	с.Самовольно-Ивановка, ул.Чапаевская 27, Здание школы		0101000020E61000007FF78E1A13704940DC2F9FAC18464A40
80570	7	72	664	9216	48637	\N	52.860466000000002	пос.Первокоммунарский, ул.Школьная 2, Здание школы	Россия, Самарская область, Алексеевский район, село Первокоммунарский	0101000020E6100000D1967329AEA84940F4A8F8BF236E4A40
80575	7	72	664	4523	48230	\N	52.506732999999997	с. Патровка, ул. Советская, 60		0101000020E61000009C6A2DCC42A94940E8667FA0DC404A40
80572	7	72	664	9275	48556	\N	52.720461	с.Осиповка, ул. Горького 23, Здание школы		0101000020E6100000B9FAB1497EA649409085E810385C4A40
80583	7	72	664	9791	48524	\N	52.557800999999998	с.Ореховка, ул. Кирова 83, Здание СДК		0101000020E61000001FDAC70A7E7149408A56EE0566474A40
80567	7	72	664	46720	48353	\N	52.540408999999997	с. Новотроевка,  ул. Пролетарская, 41		0101000020E61000003D5FB35C36A8494066BB421F2C454A40
80564	7	72	664	8955	48375	\N	52.611548999999997	с.Несмеяновка, ул. Победы 33, Здание СДК		0101000020E61000002121CA17B48C49406473D53C474E4A40
80581	7	72	664	9723	48444	\N	52.537878999999997	с.Летниково, ул.Захара Вобликова 150, Здание школы		0101000020E6100000D522A298BC7F4940431A1538D9444A40
80568	7	72	664	46752	48343	\N	52.437382999999997	пос.Ленинградский, ул.Черемушки, 10-2		0101000020E61000002174D0251C924940C669882AFC374A40
80579	7	72	664	9582	48342	\N	52.711378000000003	с.Корнеевка, ул.Центральная 12а, Здание СДК		0101000020E6100000D2890453CDAE4940058C2E6F0E5B4A40
80585	7	72	664	9942	48486	\N	52.469433000000002	с.Калашиновка, ул.Ленинская 34, Здание конторы колхоза		0101000020E6100000C3B81B446B8B4940E3546B61163C4A40
80565	7	72	664	46687	48337	\N	52.499935999999998	пос.Ильичевский, ул.Молодежная 17а, Здание школы		0101000020E61000008F899466F3964940E90B21E7FD3F4A40
80578	7	72	664	46952	48644	\N	52.70476	с.Герасимовка, ул.Школьная 12, Здание администрации с/с		0101000020E61000008011346612C14940B5C35F93355A4A40
80577	7	72	664	46933	48341	\N	52.409857000000002	пос.Гавриловский, ул.Прибрежная 11, Здание СДК		0101000020E610000035D1E7A38CB24940B284B53176344A40
80574	7	72	664	46865	48519	\N	52.459567999999997	с.Гавриловка, ул. Л.Толстого 8, Здание СДК	Россия, Самарская область, Алексеевский район, село Гавриловка	0101000020E61000001E15FF7744AB4940E124CD1FD33A4A40
80573	7	72	664	46843	48518	\N	52.669212000000002	с.Антоновка, ул.К.Маркса 2, Здание школы		0101000020E6100000522B4CDF6B9E49409E0B23BDA8554A40
80700	7	72	664	55900	48293	\N	52.582436618707902	с. Алексеевка, ул. Школьная, 53 в	Россия, Самарская область, Алексеевский район, село Алексеевка	0101000020E61000002CA0504F1FA349407C7DAD4B8D4A4A40
80569	7	72	664	46770	48225	\N	52.623474000000002	п. Авангард, ул. Рабочая, 1		0101000020E6100000A88C7F9F71A3494002F4FBFECD4F4A40
72425	7	71	\N	56219	51500	\N	57.698293999999997	п.ЮгоКамский, у.Советская, д.114		0101000020E61000005A9F724C16CB4B401B7FA2B261D94C40
72964	7	71	\N	58016	\N	\N	58.282353294028503	пос.Шибаново, помещение бывшей школы № 10	Россия, Пермский край, Чусовой	0101000020E61000001D1CEC4D0CE34C40B876A22424244D40
72950	7	71	\N	22804	51769	\N	58.279305999999998	г.Чусовой, пер.Чунжинский, д.6, станция юных натуралистов		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72958	7	71	\N	22804	51771	\N	58.279305999999998	г.Чусовой, ул.Юности, д.12, Профессиональное училище №9		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72956	7	71	\N	22804	51524	\N	58.279305999999998	г.Чусовой, Чайковского, 16		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72955	7	71	\N	22804	51524	\N	58.279305999999998	г.Чусовой, Чайковского, 14		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72943	7	71	\N	22804	51728	\N	58.279305999999998	г.Чусовой, ул.Попова, д.91 школа № 9		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72942	7	71	\N	22804	51728	\N	58.262483315547897	г.Чусовой, ул.Попова, д.91, школа № 9	Россия, Пермский край, Чусовой	0101000020E6100000BEBF417BF5EF4C40C460FE0A99214D40
72953	7	71	\N	22804	51523	\N	58.279305999999998	г.Чусовой, ул.Лысьвенская, д.99,  школа № 13		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72952	7	71	\N	22804	51523	\N	58.270081742193703	г.Чусовой, ул.Лысьвенская, д.99, школа № 13	Россия, Пермский край, Чусовой	0101000020E610000096CFF23CB8E54C40809E060C92224D40
72949	7	71	\N	22804	51520	\N	58.279305999999998	г.Чусовой, ул.Ленина, д.12, школа № 14		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72948	7	71	\N	22804	51520	\N	58.279305999999998	г.Чусовой, ул.Ленина, д.45, Культурноделовой центр		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72947	7	71	\N	22804	51520	\N	58.273518588413701	г.Чусовой культурноделовой центр, ул.Ленина, д.45, Культурноделовой центр	Россия, Пермский край, Чусовой	0101000020E6100000D15B3CBCE7EA4C40D5EAABAB02234D40
72944	7	71	\N	22804	51520	\N	58.2793062045452	г.Чусовой, Ленина, 3	Россия, Пермский край, Чусовой	0101000020E6100000FCC3961E4DE94C40CDC98B4CC0234D40
72941	7	71	\N	22804	51767	\N	58.279305999999998	г.Чусовой школа № 11, ул.Крупской, д.25		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72940	7	71	\N	22804	51767	\N	58.279305999999998	г.Чусовой, ул.Крупской, д.25, школа № 11		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72961	7	71	\N	22804	51772	\N	58.2793062045452	"""г. Чусовой, Коммунистическая, 2/3, """"Центр народной культуры"""""""	Россия, Пермский край, Чусовой	0101000020E6100000C5C8923996E94C40CDC98B4CC0234D40
72951	7	71	\N	22804	52117	\N	58.279305999999998	"""г.Чусовой, ул.Камгэс, д.16, контора ООО """"Металлургсервис"""""""		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72963	7	71	\N	22804	51525	\N	58.279305999999998	г.Чусовой, ул.50 лет ВЛКСМ, д.16, школа №7		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72962	7	71	\N	22804	51525	\N	58.275010799014098	г.Чусовой, ул.50 лет ВЛКСМ, д.16, школа № 7	Россия, Пермский край, Чусовой	0101000020E6100000E2067C7E18E74C402785798F33234D40
72960	7	71	\N	22804	51525	\N	58.279305999999998	г.Чусовой, ул.50 лет ВЛКСМ, д.21, Чусовской индустриал.техникум		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72957	7	71	\N	22804	51525	\N	58.2795548699062	г.Чусовой, ул.50 лет ВЛКСМ, д.11В, школа № 1	Россия, Пермский край, Чусовой	0101000020E6100000E90C8CBCACE94C4076374F75C8234D40
72945	7	71	\N	22804	51525	\N	58.279305999999998	г.Чусовой, ул.50 лет ВЛКСМ, д.2/3, школа №5		0101000020E6100000535C55F65DE94C40CDC98B4CC0234D40
72907	7	71	\N	56221	51522	\N	56.515457635480601	г.Чернушка, ул.Юбилейная, 19	Россия, Пермский край, Чернушинский район, Чернушка	0101000020E61000004CC631923D0A4C40153B1A87FA414C40
72915	7	71	\N	56221	51770	\N	56.489356518331803	г.Чернушка, ул.Коммунистическая, 13	Россия, Пермский край, Чернушинский район, Чернушка	0101000020E6100000A818E76F420B4C40CA880B40A33E4C40
72836	7	71	\N	16298	51719	\N	56.759227000000003	г.Чайковский, бульвар Текстильщиков, д.6		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72816	7	71	\N	16298	51511	\N	56.759227000000003	г.Чайковский, ул.Советская, д.2А		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72813	7	71	\N	16298	51511	\N	56.759227000000003	г.Чайковский, ул.Советская, 8/1		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72812	7	71	\N	16298	51511	\N	56.759227000000003	г.Чайковский, ул.Советская, д.49		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72811	7	71	\N	16298	51511	\N	56.759227000000003	г.Чайковский, ул.Советская, д.51		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72830	7	71	\N	16298	51513	\N	56.760641070867798	г.Чайковский, Проспект Победы, д.16	Россия, Пермский край, Чайковский	0101000020E6100000EA42ACFE08114B40957F2DAF5C614C40
72829	7	71	\N	16298	51513	\N	56.759227000000003	г.Чайковский, Проспект Победы, д.2		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72818	7	71	\N	16298	51764	\N	56.757152376479198	г.Чайковский, ул.Мира, д.2	Россия, Пермский край, Чайковский	0101000020E6100000C79DD2C1FA134B40ED0C535BEA604C40
72827	7	71	\N	16298	51648	\N	56.759227000000003	г. Чайковский, ул. Ленина, 56/1		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72826	7	71	\N	16298	51648	\N	56.7673346812064	г.Чайковский, ул.Ленина, д.63	Россия, Пермский край, Чайковский	0101000020E61000003DD52137C3134B40C009850838624C40
72825	7	71	\N	16298	51648	\N	56.759227000000003	г.Чайковский, ул.Ленина, д.39А		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72823	7	71	\N	16298	51650	\N	56.759227000000003	г.Чайковский, ул.Карла Маркса, д.16/1		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72839	7	71	\N	16298	51521	\N	56.759886970294701	г.Чайковский, ул.Зеленая, д.4/4	Россия, Пермский край, Чайковский	0101000020E610000049BA66F2CD104B40E9D32AFA43614C40
72838	7	71	\N	16298	51651	\N	56.759227000000003	г.Чайковский, ул.Декабристов, д.21		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72837	7	71	\N	16298	51651	\N	56.759227000000003	г.Чайковский, ул.Декабристов, д.9		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72828	7	71	\N	16298	51647	\N	56.770633907379803	г.Чайковский, ул.Вокзальная, д.51А	Россия, Пермский край, Чайковский	0101000020E610000048F8DEDFA0114B40C4978922A4624C40
72817	7	71	\N	16298	51647	\N	56.759227000000003	г.Чайковский, Вокзальная, д.11		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72855	7	71	\N	16298	52150	\N	56.768465877264198	г.Чайковский, ул.Бажова, д.21	Россия, Пермский край, Чайковский	0101000020E6100000600322C4950F4B40410B09185D624C40
72815	7	71	\N	16298	51645	\N	56.759227000000003	г.Чайковский, ул.Азина, д.1/1		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
72831	7	71	\N	16298	51649	\N	56.759227000000003	г.Чайковский, ул.40 лет Октября, д.18		0101000020E610000010B1C1C249104B40BF9EAF592E614C40
65327	7	71	\N	56226	51564	\N	56.694230295426401	с.Фоки, ул.Ленина, д.18	Россия, Пермский край, Чайковский городской округ, село Фоки	0101000020E6100000437573F1B72D4B4077F35487DC584C40
72372	7	71	\N	56231	51619	\N	57.900402999999997	п. Ферма, ул. Строителей, 2а		0101000020E61000009D47C5FF1D274C40321CCF6740F34C40
72979	7	71	\N	58113	\N	\N	58.213041986319901	с.Успенка, Административное здание Никифоровского сельского поселения	Россия, Пермский край, Чусовой городской округ, село Успенка	0101000020E61000003274ECA012894C405456D3F5441B4D40
72217	7	71	\N	56236	51680	\N	57.9432249995319	поселок Уральский, ул.Московская, д.14		0101000020E61000003DBA111615C54B4082E2C798BBF84C40
71843	7	71	\N	56233	51624	\N	58.938557000000003	п.Углеуральский, ул.Чернышевского, д.44		0101000020E6100000467C2766BDCA4C404837C2A222784D40
72422	7	71	\N	56232	51623	\N	58.034668000000003	п. Сылва, ул. Большевистская, д.41		0101000020E6100000B30B06D7DC614C40DF1B430070044D40
72724	7	71	\N	6221	51507	\N	59.631996000000001	Пермский край, город Соликамск, ул.Черняховского, д.20		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72727	7	71	\N	6221	51641	\N	59.631996000000001	Пермский край, город Соликамск, ул.Цифриновича, д.29		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72715	7	71	\N	6221	51759	\N	59.631996000000001	Пермский край, город Соликамск, ул.Фрунзе, д.114		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72716	7	71	\N	6221	51639	\N	59.631996000000001	Пермский край, город Соликамск, ул.Транспортная, д.2		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72733	7	71	\N	6221	51751	\N	59.631996000000001	"""Пермский край, город Соликамск,  ул. Советская,48"""		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72729	7	71	\N	6221	51706	\N	59.631996000000001	Пермский край, город Соликамск, ул.Сильвинитовая, д.20		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72718	7	71	\N	6221	51704	\N	59.631996000000001	Пермский край, город Соликамск, ул.Северная, д.31		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72719	7	71	\N	6221	51707	\N	59.631996000000001	Пермский край, город Соликамск, ул.Пр.Юбилейный, д.15		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72740	7	71	\N	6221	51710	\N	59.631996000000001	Пермский край, город Соликамск, ул.Правды, д.27		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72720	7	71	\N	6221	51640	\N	59.631996000000001	Пермский край, город Соликамск, ул.Пр.Юбилейный, д.49		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72730	7	71	\N	6221	51503	\N	59.631996000000001	"""Пермский край, город Соликамск,  ул. Парижской Коммуны,28"""		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72734	7	71	\N	6221	52019	\N	59.631996000000001	Пермский край, город Соликамск, ул.Осокина, д.26		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72738	7	71	\N	6221	51642	\N	59.631996000000001	Пермский край, город Соликамск, ул.Набережная, д.169		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72722	7	71	\N	6221	51506	\N	59.631996000000001	Пермский край, город Соликамск, ул.Молодежная, д.11		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72721	7	71	\N	6221	51506	\N	59.631996000000001	Пермский край, город Соликамск, ул.Молодежная, д.11 А		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72739	7	71	\N	6221	52020	\N	59.631996000000001	Пермский край, город Соликамск, ул.Мира, д.25		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72741	7	71	\N	6221	51700	\N	59.631996000000001	Пермский край, город Соликамск, ул.Металлургов, д.57		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72726	7	71	\N	6221	51508	\N	59.631996000000001	Пермский край, город Соликамск, ул.Культуры, 9		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72728	7	71	\N	6221	51760	\N	59.631996000000001	Пермский край, город Соликамск, ул.Карналлитовая, 98		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72736	7	71	\N	6221	51509	\N	59.631996000000001	Пермский край, город Соликамск, ул.Калийная, д.146		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72725	7	71	\N	6221	51535	\N	59.631996000000001	Пермский край, город Соликамск, ул.Добролюбова, д.16		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72717	7	71	\N	6221	51638	\N	59.631996000000001	Пермский край, город Соликамск, ул.Володарского, д.20		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72723	7	71	\N	6221	51758	\N	59.631996000000001	Пермский край, город Соликамск, ул.Белинского, д.15		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72737	7	71	\N	6221	51709	\N	59.631996000000001	Пермский край, город Соликамск, ул.20 лет Победы, д.179		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72735	7	71	\N	6221	51709	\N	59.631996000000001	Пермский край, город Соликамск, ул.20 лет Победы, д.138		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72732	7	71	\N	6221	51709	\N	59.631996000000001	Пермский край, город Соликамск, ул.20 лет Победы, д.94		0101000020E610000025B1A4DC7D624C40F699B33EE5D04D40
72418	7	71	\N	29156	52143	\N	58.232073	д.Скобелевка, у..Хохловская, д.4		0101000020E61000009DBB5D2F4D254C406EA46C91B41D4D40
72841	7	71	\N	56251	51851	\N	56.730521581074598	п.Прикамский, ул.Солнечная, д.3	Россия, Пермский край, Чайковский городской округ	0101000020E6100000D3D9C9E028054B401781B1BE815D4C40
71867	7	71	\N	56224	51546	\N	58.295070000000003	"""п. Полазна, 50 лет Октября, 3. МОУ """"Полазненская СОШ №1"""""""		0101000020E61000007BF65CA626354C40EF0390DAC4254D40
72403	7	71	\N	56214	51481	\N	57.636456000000003	с. Платошино, ул. Школьная, д.44		0101000020E6100000D40AD3F71A464C40E7ABE46377D14C40
72495	7	71	\N	83	51632	\N	57.951949833479297	г.Пермь, ул.Шоссе Космонавтов, д.395	Россия, Пермский край, Пермь, шоссе Космонавтов, 395	0101000020E61000002310AFEB170E4C40AEB6627FD9F94C40
72491	7	71	\N	83	51632	\N	57.973724678495998	г.Пермь, ул.Шоссе Космонавтов, д.195	Россия, Пермский край, Пермь, шоссе Космонавтов, 195	0101000020E6100000D6E5948098144C4018265305A3FC4C40
72626	7	71	\N	83	51702	\N	58.125844756752997	г.Пермь, ул.Александра Щербакова, д.33	Россия, Пермский край, Пермь, улица Щербакова, 33	0101000020E610000086AA984A3F314C40BCAE5FB01B104D40
72647	7	71	\N	83	2355	\N	57.997588999999998	г.Пермь, ул.Полины Осипенко, 46	Россия, Пермский край, Пермь, улица Полины Осипенко, 46	0101000020E6100000C7F143A511214C40B7EC10FFB0FF4C40
72793	7	71	\N	83	16009	\N	57.997641000000002	Пермский край,  Уинский район, пос.Аспинский, ул.Полевая, 4	Россия, Пермский край, Пермь, Дзержинский район, улица Полевая, 12	0101000020E6100000D3F9F02C411C4C400A1346B3B2FF4C40
72512	7	71	\N	83	255	\N	57.999158000000001	Пермский край, г.Пермь, Кировский район, ул.Ласьвинская, д.6	Россия, Пермский край, Пермь, улица Ласьвинская, 6	0101000020E6100000F7730AF2B3F94B40B5C4CA68E4FF4C40
72562	7	71	\N	83	1136	\N	58.017225000000003	г.Пермь, Мотовилихинский район, Ким, 90	Россия, Пермский край, Пермь, улица Ким, 90	0101000020E6100000C2887D0228244C4039D6C56D34024D40
72078	7	71	\N	83	15887	\N	58.139133000000001	Краснокамский район, д. НовоИвановка, ул.Железнодорожная, д.8	Россия, Пермский край, Пермь, улица Железнодорожная, 8	0101000020E61000006682E15CC3304C40AE65321CCF114D40
72440	7	71	\N	83	51859	\N	57.999442171711301	город Пермь, Дзержинский район, проспект Парковый, д.27,к.а		0101000020E6100000F94CF6CFD3144C40DA1F28B7EDFF4C40
72497	7	71	\N	83	51631	\N	57.974654450579003	г.Пермь, ул.Проспект  Декабристов, д.35а	Россия, Пермский край, Пермь, проспект Декабристов, 35а	0101000020E6100000F58079C894194C4032755776C1FC4C40
72475	7	71	\N	83	51631	\N	57.974466342691002	г.Пермь, ул.Проспект Декабристов, д.35а	Россия, Пермский край, Пермь, проспект Декабристов, 35а	0101000020E6100000C3F2E7DB82194C402F88484DBBFC4C40
72618	7	71	\N	83	51959	\N	58.099476000000003	г.Пермь, ул.Маршала Толбухина, д.33		0101000020E610000012DE1E8480264C40535E2BA1BB0C4D40
72519	7	71	\N	83	51879	\N	58.009988	Пермский край, г.Пермь, Кировский район, ул.Маршала Рыбалко, д.100		0101000020E6100000E9465854C4FB4B401DAD6A4947014D40
72489	7	71	\N	83	51922	\N	57.962924999999998	г.Пермь, ул.Космонавта Леонова, д.62а		0101000020E61000006BEF535568164C401AC05B2041FB4C40
72484	7	71	\N	83	51922	\N	57.974271999999999	г.Пермь, ул.Космонавта Леонова, д.14		0101000020E61000004757E9EE3A154C404AB4E4F1B4FC4C40
72483	7	71	\N	83	51922	\N	57.97504	г.Пермь, ул.Леонова, д.13а		0101000020E6100000B4CBB73EAC154C405B25581CCEFC4C40
72635	7	71	\N	83	51965	\N	58.084243999999998	г.Пермь, ул.Генерала Черняховского, д.51		0101000020E6100000ABEB504D49344C402E71E481C80A4D40
72633	7	71	\N	83	51965	\N	58.086027999999999	г.Пермь, ул.Генерала Черняховского, д.72		0101000020E61000005F79909E22334C4028452BF7020B4D40
72559	7	71	\N	83	54670	\N	58.019791614478997	г. Пермь, Мотовилихинский район, Бульвар Гагарина, д.10а	Россия, Пермский край, Пермь, бульвар Гагарина	0101000020E61000001F680586AC224C40795C548B88024D40
72631	7	71	\N	83	51904	\N	58.106271	г.Пермь, ул.Академика Веденеева, д.71		0101000020E610000054FF209221314C40B1C1C2499A0D4D40
72630	7	71	\N	83	51904	\N	58.106428000000001	г.Пермь, ул.Академика Веденеева, д.54		0101000020E610000071546EA296304C4079B0C56E9F0D4D40
72629	7	71	\N	83	51904	\N	58.110422	г.Пермь, ул.Академика Веденеева, д.26		0101000020E6100000D76839D0432F4C402461DF4E220E4D40
72528	7	71	\N	83	51920	\N	58.034677000000002	Пермский край, г.Пермь, Кировский район, ул.Адмирала Ушакова, д.24		0101000020E6100000C9C6832D76034C403276C24B70044D40
72521	7	71	\N	83	51875	\N	58.014778999999997	Пермский край, г.Пермь, Кировский район, ул.Ямпольская, д.16		0101000020E61000009FE74F1BD5FB4B4073D53C47E4014D40
72520	7	71	\N	83	51875	\N	58.014778999999997	г. Пермь, Кировский район, ул. Ямпольская, д.16		0101000020E61000009FE74F1BD5FB4B4073D53C47E4014D40
72580	7	71	\N	83	51895	\N	58.010331000000001	г.Пермь, Мотовилихинский район, Юрша, 56А		0101000020E6100000BD5296218E274C404791B58652014D40
72627	7	71	\N	83	51635	\N	58.127775187464401	г.Пермь, ул.Александра Щербакова, д.44	Россия, Пермский край, Пермь, улица Щербакова, 44	0101000020E61000004AD40B3ECD314C408A1F63EE5A104D40
72494	7	71	\N	83	51670	\N	58.008490000000002	г.Пермь, ул.Шоссе Космонавтов, д.194		0101000020E6100000AD68739CDB1E4C40E92B483316014D40
72517	7	71	\N	83	51954	\N	58.007460999999999	Пермский край, г.Пермь, Кировский район, ул.Шишкина, д.18		0101000020E6100000A7C98CB795FA4B406B7F677BF4004D40
72567	7	71	\N	83	51866	\N	58.166325999999998	г.Пермь, ул.Читалина, д.10		0101000020E61000007099D36531274C40BC3C9D2B4A154D40
72509	7	71	\N	83	51973	\N	57.995175000000003	Пермский край, г.Пермь, Кировский район, ул.Чистопольская, д.11		0101000020E6100000A11342075DF84B40FE65F7E461FF4C40
72642	7	71	\N	83	51946	\N	57.998099000000003	г.Пермь, ул.Чернышевского, 11		0101000020E610000000CADFBDA3224C40CD9541B5C1FF4C40
72488	7	71	\N	83	51974	\N	57.965341000000002	г.Пермь, ул.Чердынская, д.38а		0101000020E6100000E09EE74F1B174C40753E3C4B90FB4C40
72602	7	71	\N	83	51998	\N	58.056603000000003	г.Пермь, Мотовилихинский район, Целинная, 29 Б		0101000020E61000005E807D74EA2C4C4081ED60C43E074D40
72599	7	71	\N	83	51835	\N	58.0469048680784	г.Пермь, Мотовилихинский район, Харьковская, 21А		0101000020E6100000E3DEFC86892A4C406B82A8FB00064D40
72501	7	71	\N	83	51924	\N	58.030856	Пермский край, г.Пермь, Кировский район, ул.Фадеева, д.7		0101000020E6100000726C3D4338EC4B405471E316F3034D40
72588	7	71	\N	83	51900	\N	58.026820000000001	г.Пермь, Мотовилихинский район, Уральская, 78		0101000020E6100000EA245B5D4E254C407A7077D66E034D40
72591	7	71	\N	83	51941	\N	58.029398	г.Пермь, Мотовилихинский район, Уральская, 67		0101000020E61000002E8F352383264C40AE484C50C3034D40
72579	7	71	\N	83	51855	\N	58.008218999999997	г.Пермь, Мотовилихинский район, Уинская, 3		0101000020E6100000FD3383F8C0264C40581AF8510D014D40
72577	7	71	\N	83	51855	\N	58.004555894838902	г.Пермь, Мотовилихинский район, Уинская, 34	Россия, Пермский край, Пермь, Уинская улица, 34	0101000020E61000005EB9DE3653274C4013807F4A95004D40
72582	7	71	\N	83	54767	\N	58.015417999999997	г. Пермь, Мотовилихинский район, ул. Тургенева, д.18/1		0101000020E610000056664AEB6F254C4086E28E37F9014D40
72361	7	71	\N	83	64697	\N	58.046911000000001	п.Дружба, Трудовая, 2		0101000020E610000097395D16134D4C404D69FD2D01064D40
72682	7	71	\N	83	51847	\N	58.034002995215403	г.Пермь пос.Новые Ляды, ул.Транспортная, 2	Россия, Пермский край, Пермь, улица Транспортная	0101000020E6100000E08096AE60114C40A27BD6355A044D40
72625	7	71	\N	83	51964	\N	58.136287000000003	г.Пермь, ул.Томская, д.30		0101000020E6100000EED11BEE23314C405BEF37DA71114D40
72435	7	71	\N	83	51977	\N	58.007444082567702	город Пермь, Дзержинский район, ул.Толмачева, д.18	Россия, Пермский край, Пермь, улица Толмачева, 18	0101000020E6100000A9F92AF9D8194C409546CCECF3004D40
72569	7	71	\N	83	51897	\N	58.010755000000003	г.Пермь, Мотовилихинский район, Техническая, 22		0101000020E61000005D514A0856254C405EA27A6B60014D40
72566	7	71	\N	83	51897	\N	58.013658999999997	г.Пермь, Мотовилихинский район, Техническая, 10		0101000020E6100000D7DEA7AAD0244C40E525FF93BF014D40
72527	7	71	\N	83	51925	\N	58.022649000000001	Пермский край, г.Пермь, Кировский район, ул.Танцорова, д.7		0101000020E6100000191BBAD91F024C40C0249529E6024D40
72473	7	71	\N	83	51932	\N	57.981133999999997	г.Пермь, ул.Танкистов, д.56		0101000020E6100000A5F9635A9B1A4C40307F85CC95FD4C40
72469	7	71	\N	83	51932	\N	57.982894999999999	г.Пермь, ул.Танкистов, д.46		0101000020E6100000F4C29D0B231B4C407233DC80CFFD4C40
72467	7	71	\N	83	51932	\N	57.982894999999999	г. Пермь, ул.Танкистов, д.46		0101000020E6100000F4C29D0B231B4C407233DC80CFFD4C40
72628	7	71	\N	83	51963	\N	58.121988000000002	г.Пермь, ул.Таймырская, д.3		0101000020E6100000583CF54883314C409240834D9D0F4D40
72523	7	71	\N	83	51887	\N	58.019112	Пермский край, г.Пермь, Кировский район, ул.Сысольская, д.12		0101000020E6100000537AA69718FD4B40077B134372024D40
72678	7	71	\N	83	51917	\N	57.980986000000001	г.Пермь, ул.Суздальская, 1		0101000020E61000007638BA4A77254C40BCEA01F390FD4C40
72581	7	71	\N	83	51936	\N	58.010897999999997	г.Пермь, Мотовилихинский район, Старцева, 1А		0101000020E6100000683EE76ED7274C40C0CB0C1B65014D40
72576	7	71	\N	83	51936	\N	58.002958999999997	г.Пермь, Мотовилихинский район, Старцева, 9		0101000020E61000003E9468C9E3274C404B1DE4F560004D40
72600	7	71	\N	83	54389	\N	58.082839292103003	г. Пермь, Мотовилихинский район, ул. Соликамская, д.189	Россия, Пермский край, Пермь, Соликамская улица	0101000020E6100000368FC360FE2C4C40ABEAE5779A0A4D40
72663	7	71	\N	83	51949	\N	57.973168999999999	г.Пермь, ул.Солдатова, 43		0101000020E61000005FB532E1971E4C40923D42CD90FC4C40
72477	7	71	\N	83	51934	\N	57.987709000000002	г.Пермь, ул.Советской Армии, д.4		0101000020E61000007D772B4B74184C40817B9E3F6DFE4C40
72541	7	71	\N	83	51993	\N	58.015574999999998	г.Пермь, ул.Советская, д.33		0101000020E6100000E90E62670A1F4C404ED1915CFE014D40
72540	7	71	\N	83	51955	\N	58.014488	г.Пермь, ул.Советская, д.56		0101000020E61000007155D977451E4C409C1727BEDA014D40
72410	7	71	\N	83	66991	\N	58.018873999999997	д.Жебрии, у.Советская, д.6а		0101000020E61000002788BA0F40204C40525F96766A024D40
72552	7	71	\N	83	51960	\N	58.011389000000001	г.Пермь, ул.Советская, д.102 А		0101000020E610000054556820961B4C405F44DB3175014D40
72468	7	71	\N	83	51909	\N	57.982655999999999	г.Пермь, ул.Сивкова, д.3б		0101000020E6100000E9B985AE441C4C40ED9BFBABC7FD4C40
72646	7	71	\N	83	51844	\N	57.999692000000003	г.Пермь, ул.Сибирская, 80		0101000020E6100000A88C7F9F71214C4053094FE8F5FF4C40
72645	7	71	\N	83	51844	\N	58.003321	г.Пермь, ул.Сибирская, 55		0101000020E61000001DE38A8BA3204C40EC3191D26C004D40
72545	7	71	\N	83	51844	\N	58.011132000000003	г.Пермь, ул.Сибирская, д.29		0101000020E61000005EBEF561BD1F4C4034F8FBC56C014D40
72544	7	71	\N	83	51844	\N	58.012070999999999	г.Пермь, ул.Сибирская, д.23		0101000020E6100000B5FF01D6AA1F4C40711DE38A8B014D40
72662	7	71	\N	83	2570	\N	57.975785000000002	г.Пермь, Серебрянский проезд, 9	Россия, Пермский край, Пермь, Серебрянский проезд, 9	0101000020E6100000EBFF1CE6CB1D4C40B476DB85E6FC4C40
72429	7	71	\N	83	51923	\N	57.995604	город Пермь, Дзержинский район, ул.Связистов, д.22		0101000020E6100000541EDD088B1C4C4026E2ADF36FFF4C40
72487	7	71	\N	83	54408	\N	57.963331565306703	г. Пермь, Индустриальный район, ул. Архитектора Свиязева, д.17	Россия, Пермский край, Пермь, улица Свиязева, 17	0101000020E61000002CF4C13236184C405B9885764EFB4C40
72530	7	71	\N	83	51891	\N	58.038207999999997	Пермская область, город Пермь, Кировский район, ул.Светлогорская, д.5		0101000020E610000070EA03C93B054C400839EFFFE3044D40
72529	7	71	\N	83	51891	\N	58.038207999999997	Пермский край, г.Пермь, Кировский район, ул.Светлогорская, д.5		0101000020E610000070EA03C93B054C400839EFFFE3044D40
72679	7	71	\N	83	51950	\N	57.987237	г.Пермь, ул.Самаркандская, 102		0101000020E61000002F6CCD565E264C40593332C85DFE4C40
72615	7	71	\N	83	51903	\N	58.113093999999997	г.Пермь, ул.Репина, д.9		0101000020E61000007F4E417E36284C40D9AF3BDD790E4D40
72612	7	71	\N	83	51903	\N	58.113467534136099	г.Пермь, ул.Репина, д.76	Россия, Пермский край, Пермь, улица Репина, 76	0101000020E6100000BD8BF7E3F6234C403E92921E860E4D40
72610	7	71	\N	83	51903	\N	58.111256842710198	г.Пермь, ул.Репина, д.67 А	Россия, Пермский край, Пермь, улица Репина, 67а	0101000020E61000008AB0E1E995244C40BD395CAB3D0E4D40
72652	7	71	\N	83	51969	\N	58.002191000000003	г.Пермь, ул.Революции, 66		0101000020E610000027A089B0E11D4C403BAC70CB47004D40
72001	7	71	\N	83	51971	\N	57.998336999999999	с.УстьКишерть, Рабочая, 19		0101000020E61000006B44300E2E194C4081B1BE81C9FF4C40
72437	7	71	\N	83	51892	\N	57.996267000000003	город Пермь, Дзержинский район, ул.Рабочая, д.13		0101000020E610000005172B6A30194C40C28A53AD85FF4C40
72543	7	71	\N	83	51894	\N	58.002682	г.Пермь, ул.Пушкина, д.104		0101000020E61000005281936DE01C4C40D9243FE257004D40
72551	7	71	\N	83	51994	\N	58.003006999999997	г.Пермь, ул.Пушкина, д.107 А		0101000020E6100000D8F0F44A591C4C405C548B8862004D40
72643	7	71	\N	83	51873	\N	58.009046117877197	г.Пермь, ул.Пушкина, 42, корп.4		0101000020E6100000CD920035B5204C406E14596B28014D40
72644	7	71	\N	83	51869	\N	58.008679784557799	г.Пермь, ул.Пушкина, 44, корп.2		0101000020E61000000A4B3CA06C204C408C101E6D1C014D40
72496	7	71	\N	83	52227	\N	57.950069999999997	г.Пермь, ул.Промышленная, д.46		0101000020E610000016F88A6EBD104C409274CDE49BF94C40
72595	7	71	\N	83	51997	\N	58.030765000000002	г.Пермь, Мотовилихинский район, Постаногова, 1А		0101000020E6100000DE9387855A294C40446E861BF0034D40
72441	7	71	\N	83	51982	\N	57.995919000000001	город Пермь, Дзержинский район, Подлесная, 37		0101000020E61000001FF46C567D144C40863B17467AFF4C40
72503	7	71	\N	83	51913	\N	58.006869000000002	Пермский край, г.Пермь, Кировский район, ул.Победы, д.46		0101000020E6100000A872DA5372F64B40992D5915E1004D40
72432	7	71	\N	83	51979	\N	58.003188000000002	город Пермь, Дзержинский район, ул.Плеханова, д.41		0101000020E61000008CF50D4C6E1A4C40ADDEE17668004D40
72614	7	71	\N	83	51999	\N	58.111635	г.Пермь, ул.Писарева, д.35		0101000020E6100000537B116DC7264C40630B410E4A0E4D40
72434	7	71	\N	83	51553	\N	58.007503	город Пермь, Дзержинский район, ул.Петропавловская, д.185	Россия, Пермский край, Пермь, Петропавловская улица, 185	0101000020E6100000200890A163194C409ACFB9DBF5004D40
72436	7	71	\N	83	51753	\N	58.007169298340102	город Пермь, Дзержинский район, ул.Петропавловская, д.109	Россия, Пермский край, Пермь, Петропавловская улица, 109	0101000020E61000007E8FFAEB151A4C40C345EEE9EA004D40
72542	7	71	\N	83	51633	\N	58.0113813264581	г.Пермь, ул.Петропавловская, д.65	Россия, Пермский край, Пермь, Петропавловская улица, 65	0101000020E610000058C85C19541D4C40DC65BFEE74014D40
72536	7	71	\N	83	51633	\N	58.017568689368701	г.Пермь, ул.Петропавловская, д.7 А	Россия, Пермский край, Пермь, Петропавловская улица, 7а	0101000020E6100000F8DEDFA0BD204C40333674B33F024D40
72636	7	71	\N	83	51761	\N	58.0811623408431	г.Пермь, ул.Александра Пархоменко, д.2	Россия, Пермский край, Пермь, улица Пархоменко, 2	0101000020E61000003F709527102E4C40C7D63384630A4D40
72461	7	71	\N	83	7688	\N	57.995919000000001	город Пермь, Дзержинский район, Парковый проспект, 8а	Россия, Пермский край, Пермь, Парковый проспект, 8а	0101000020E610000040C1C58A1A124C40863B17467AFF4C40
72446	7	71	\N	83	7688	\N	57.995919000000001	город Пермь, Дзержинский район, Парковый проспект, д.8а	Россия, Пермский край, Пермь, Парковый проспект, 8а	0101000020E610000040C1C58A1A124C40863B17467AFF4C40
72445	7	71	\N	83	7688	\N	57.997087999999998	город Пермь, Дзержинский район, Парковый проспект, д.16	Россия, Пермский край, Пермь, Парковый проспект, 16	0101000020E6100000CB4752D2C3124C40F59D5F94A0FF4C40
72444	7	71	\N	83	7688	\N	57.996721000000001	город Пермь, Дзержинский район, Парковый проспект, д.28	Россия, Пермский край, Пермь, Парковый проспект, 28	0101000020E61000000744882B67134C40431EC18D94FF4C40
72442	7	71	\N	83	7688	\N	57.996721000000001	город Пермь, Дзержинский район, Парковый проспект, 28	Россия, Пермский край, Пермь, Парковый проспект, 28	0101000020E61000000744882B67134C40431EC18D94FF4C40
72443	7	71	\N	83	51658	\N	57.996644000000003	город Пермь, Дзержинский район, Парковый простпект, 28	Россия, Пермский край, Пермь, проспект Парковый, 28	0101000020E610000051C0763062134C4098E0D40792FF4C40
72661	7	71	\N	83	51952	\N	57.973379000000001	г.Пермь, ул.Обвинская, 10		0101000020E610000016C3D501101F4C407DCEDDAE97FC4C40
72660	7	71	\N	83	51952	\N	57.974009000000002	г.Пермь, ул.Обвинская, 10а		0101000020E6100000FCE1E7BF071F4C403D81B053ACFC4C40
72486	7	71	\N	83	54686	\N	57.968528999999997	г. Пермь, Индустриальный район, ул. Норильская,7		0101000020E61000008331225168194C40211D1EC2F8FB4C40
72671	7	71	\N	83	51868	\N	57.963251647679201	г.Пермь, ул.Новосибирская, 3а	Россия, Пермский край, Пермь, Новосибирская улица, 3	0101000020E610000066136058FE1E4C403EE76ED74BFB4C40
72640	7	71	\N	83	51905	\N	58.003765000000001	г.Пермь, ул.Николая Островского, 66		0101000020E6100000126A865451224C404AEF1B5F7B004D40
72639	7	71	\N	83	51905	\N	58.008934002662997	г.Пермь, ул.Николая Островского, 46а	Россия, Пермский край, Пермь, Свердловский район, улица Николая Островского, 46а	0101000020E6100000BEBF417BF5214C4047E9D2BF24014D40
72641	7	71	\N	83	51966	\N	58.003221000000003	г.Пермь, ул.Николая Островского, 68		0101000020E6100000C63368E89F224C4089D4B48B69004D40
72485	7	71	\N	83	51919	\N	57.969751000000002	г.Пермь, ул.Нефтяников, д.54		0101000020E6100000EFC517EDF1144C40B421FFCC20FC4C40
72654	7	71	\N	83	51948	\N	57.993428999999999	г.Пермь, ул.Нестерова, 18		0101000020E6100000A3E6ABE4631F4C40F1F274AE28FF4C40
72665	7	71	\N	83	51951	\N	57.974186000000003	г.Пермь, ул.Муромская, 32		0101000020E610000091B8C7D2871C4C404C1C7920B2FC4C40
72597	7	71	\N	83	51838	\N	58.039088999999997	г.Пермь, Мотовилихинский район, Мостовая, 6	Россия, Пермский край, Пермь, улица Мостовая, 6	0101000020E6100000B3B6291E17294C4011514CDE00054D40
72685	7	71	\N	83	51888	\N	58.050176244497599	г.Пермь пос.Новые Ляды, ул.Мира, 11	Россия, Пермский край, Пермь, поселок городского типа Новые Ляды, улица Мира	0101000020E610000072FDBB3E734A4C40A585CB2A6C064D40
72482	7	71	\N	83	52001	\N	57.978828999999998	г.Пермь, ул.Мира, д.72		0101000020E61000004E637B2DE8174C402DB0C7444AFD4C40
72464	7	71	\N	83	51987	\N	57.985615000000003	г.Пермь, ул.Мира, д.4		0101000020E6100000D0D6C1C1DE1A4C4039B9DFA128FE4C40
64815	7	71	\N	83	52007	\N	57.974347999999999	г.Пермь, ул.Мира, д.98		0101000020E61000008B6B7C26FB154C4025766D6FB7FC4C40
63936	7	71	\N	83	51976	\N	57.977125999999998	г.Пермь, ул.Мира, д.39		0101000020E61000003599F1B6D2174C402009FB7612FD4C40
64116	7	71	\N	83	51978	\N	57.975535999999998	г.Пермь, ул.Мира, д.92		0101000020E610000012A452EC68164C400B09185DDEFC4C40
72479	7	71	\N	83	51935	\N	57.981696999999997	г.Пермь, ул.Мира, д.26		0101000020E61000005280289831194C4068CA4E3FA8FD4C40
72683	7	71	\N	83	54647	\N	58.049274481726698	г.Пермь пос.Новые Ляды, ул.Мира, 1	Россия, Пермский край, Пермь, поселок городского типа Новые Ляды, улица Мира, 1	0101000020E61000004DF6CFD3804B4C408445459C4E064D40
72428	7	71	\N	83	51890	\N	57.991892999999997	город Пермь, Дзержинский район, ул.Мильчакова, д.22		0101000020E6100000D4D2DC0A611D4C40CF108E59F6FE4C40
72460	7	71	\N	83	51898	\N	58.003269000000003	город Пермь, Дзержинский район, Маяковского, 33		0101000020E61000009B559FABAD0E4C409A0B5C1E6B004D40
72448	7	71	\N	83	51898	\N	58.003269000000003	город Пермь, Дзержинский район, ул.Маяковского, д.33		0101000020E61000009B559FABAD0E4C409A0B5C1E6B004D40
72522	7	71	\N	83	51882	\N	58.015718	Пермский край, г.Пермь, Кировский район, ул.Маршала Рыбалко, д.101Б		0101000020E610000057E883656CFC4B40B1FA230C03024D40
72578	7	71	\N	83	51896	\N	58.009230000000002	г.Пермь, Мотовилихинский район, Макаренко, 25		0101000020E6100000643E20D099264C403012DA722E014D40
72658	7	71	\N	83	51907	\N	57.988529999999997	г.Пермь, ул.Льва Шатрова, 25		0101000020E610000076C075C58C224C40B48EAA2688FE4C40
72657	7	71	\N	83	51907	\N	57.987948000000003	г.Пермь, ул.Льва Шатрова, 5		0101000020E610000002D8800871214C4006137F1475FE4C40
72466	7	71	\N	83	51817	\N	57.987312848789799	г.Пермь, ул.Л.Толстого, д.12	Россия, Пермский край, Пермь, улица Льва Толстого, 12	0101000020E61000005DFC6D4F901C4C4034F5BA4560FE4C40
72465	7	71	\N	83	51817	\N	57.987417999999998	г.Пермь, ул.Льва Толстого, д.12		0101000020E610000094C2BCC7991C4C40A9BD88B663FE4C40
72549	7	71	\N	83	51870	\N	58.005507912067003	г.Пермь, ул.Луначарского, д.74/50	Россия, Пермский край, Пермь, улица Луначарского	0101000020E61000003694DA8B681D4C40E5EE737CB4004D40
72538	7	71	\N	83	51870	\N	58.011571000000004	г.Пермь, ул.Луначарского, д.24		0101000020E610000038A1100187204C40804A95287B014D40
72537	7	71	\N	83	51870	\N	58.012591	г.Пермь, ул.Луначарского, д.4		0101000020E6100000124BCADDE7204C40AA9CF6949C014D40
72672	7	71	\N	83	51967	\N	57.957605999999998	г.Пермь, ул.Лукоянова, 6		0101000020E6100000FE9B1727BE1E4C40083A5AD592FA4C40
72670	7	71	\N	83	51914	\N	57.966205000000002	г. Пермь, Свердловский район, ул. Лодыгина, д.16		0101000020E61000001BA19FA9D71D4C40A81DFE9AACFB4C40
72666	7	71	\N	83	51914	\N	57.966844000000002	г.Пермь, ул.Лодыгина, 48а		0101000020E610000095B9F946741B4C40BB2A508BC1FB4C40
72664	7	71	\N	83	51914	\N	57.966439000000001	г.Пермь, ул.Лодыгина, 34		0101000020E6100000B090B932A81C4C401B4AED45B4FB4C40
72518	7	71	\N	83	51918	\N	58.006754999999998	Пермский край, г.Пермь, Кировский район, ул.Липатова, д.2		0101000020E6100000A8C5E061DAFB4B40D00A0C59DD004D40
72452	7	71	\N	83	51825	\N	58.046120798769003	город Пермь, Дзержинский район, ул.Лепешинской, д.43	Россия, Пермский край, Пермь, улица Лепешинской	0101000020E6100000EA4141295A0D4C405454FD4AE7054D40
72539	7	71	\N	83	51871	\N	58.017096000000002	г.Пермь, ул.Ленина, д.7		0101000020E6100000026553AEF0204C403B72A43330024D40
72463	7	71	\N	83	54304	\N	58.004733076264699	город Пермь, Дзержинский район, ул.Ленина, д.89	Россия, Пермский край, Пермь, Дзержинский район	0101000020E6100000787DE6AC4F174C40221B48179B004D40
72586	7	71	\N	83	51933	\N	58.023831000000001	г.Пермь, Мотовилихинский район, Лебедева, 28		0101000020E61000005743E21E4B254C40C4D0EAE40C034D40
72563	7	71	\N	83	51933	\N	58.019607999999998	г.Пермь, Мотовилихинский район, Лебедева, 40		0101000020E61000005AA148F773244C40B75ED38382024D40
72514	7	71	\N	83	51989	\N	58.001800703837297	Пермский край, г.Пермь, Кировский район, ул.Ласьвинская, д.18	Россия, Пермский край, Пермь, Ласьвинская улица, 18	0101000020E6100000A33EC91D36F94B40D00CE2033B004D40
72505	7	71	\N	83	51989	\N	58.009419999999999	г. Пермь, Кировский район, ул. Ласьвинская, д.64а		0101000020E6100000F86EF3C649F74B40D3F6AFAC34014D40
72504	7	71	\N	83	51989	\N	58.009419999999999	Пермский край, г.Пермь, Кировский район, ул.Ласьвинская, д.64А		0101000020E6100000F86EF3C649F74B40D3F6AFAC34014D40
72447	7	71	\N	83	52013	\N	57.995061	город Пермь, Дзержинский район, ул.Куфонина, д.12		0101000020E61000009C6A2DCC42114C403543AA285EFF4C40
72548	7	71	\N	83	51927	\N	58.006683000000002	г.Пермь, ул.Куйбышева, д.39		0101000020E61000001500E319341E4C40373811FDDA004D40
72575	7	71	\N	83	51883	\N	57.993763000000001	г.Пермь, Мотовилихинский район, Крупской, 92		0101000020E610000083C0CAA145264C40C87C40A033FF4C40
72574	7	71	\N	83	51883	\N	57.995924000000002	г.Пермь, Мотовилихинский район, Крупской, 80		0101000020E6100000CBBF9657AE254C4098A608707AFF4C40
72240	7	71	\N	83	51883	\N	58.0221904282594	"""пгт. Октябрьский, Крупской, 11, контора """"Жилкомсервис"""""""	Россия, Пермский край, Пермь, улица Крупской	0101000020E6100000F6D37FD6FC224C402D26361FD7024D40
72651	7	71	\N	83	51940	\N	57.999015	г.Пермь, ул.Краснофлотская, 15		0101000020E6100000ED2C7AA7021E4C40529B38B9DFFF4C40
72603	7	71	\N	83	51939	\N	58.060326000000003	г.Пермь, Мотовилихинский район, Красноуральская, 37		0101000020E6100000D10836AE7F2D4C409C8C2AC3B8074D40
72676	7	71	\N	83	52000	\N	57.970444000000001	г.Пермь, ул.Краснополянская, 19		0101000020E61000005A65A6B4FE224C40BA4C4D8237FC4C40
72650	7	71	\N	83	51947	\N	58.006616999999999	г.Пермь, ул.Краснова, 18		0101000020E6100000E2C96E66F41F4C407F4C6BD3D8004D40
72451	7	71	\N	83	51899	\N	58.038364999999999	г. Пермь, Дзержинский район, ул. Костычева, д.33		0101000020E6100000122EE411DC104C40D027F224E9044D40
72450	7	71	\N	83	51899	\N	58.038364999999999	город Пермь, Дзержинский район, ул.Костычева, д.33		0101000020E6100000122EE411DC104C40D027F224E9044D40
72476	7	71	\N	83	4368	\N	57.991688000000003	г. Пермь, Индустриальный район, ш. Космонавтов, д.110	Россия, Пермский край, Пермь, Космонавтов шоссе, 110	0101000020E610000071581AF851194C40F7EAE3A1EFFE4C40
72241	7	71	\N	83	4368	\N	58.001112999999997	"""пгт.Октябрьский, Космонавтов, 17, КСК """"Алмазное"""""""		0101000020E6100000FB78E8BB5B1D4C40DB4C857824004D40
72493	7	71	\N	83	64759	\N	57.965595111072403	г. Пермь, ул. Космонавта Беляева, д.59		0101000020E610000094A0BFD023144C402F17F19D98FB4C40
72656	7	71	\N	83	2358	\N	57.990614999999998	г.Пермь, Комсомольский проспект, 79	Россия, Пермский край, Пермь, Комсомольский проспект, 79	0101000020E61000004B1E4FCB0F204C40A9F6E978CCFE4C40
72649	7	71	\N	83	2358	\N	58.002276999999999	г.Пермь, Комсомольский проспект, 48	Россия, Пермский край, Пермь, Комсомольский проспект, 48	0101000020E61000001442075DC21F4C403944DC9C4A004D40
72648	7	71	\N	83	2358	\N	57.998514	г.Пермь, Комсомольский проспект, 59	Россия, Пермский край, Пермь, Комсомольский проспект, 59	0101000020E6100000EFC8586DFE1F4C40904C874ECFFF4C40
72547	7	71	\N	83	2358	\N	58.008490000000002	г.Пермь, ул.Комсомольский проспект, д.29		0101000020E6100000AD68739CDB1E4C40E92B483316014D40
72598	7	71	\N	83	51996	\N	58.037241000000002	г.Пермь, Мотовилихинский район, Колыбалова, 44		0101000020E61000008753E6E61B2D4C4001892650C4044D40
72659	7	71	\N	83	51912	\N	57.986578999999999	г.Пермь, ул.Клары Цеткин, 10		0101000020E61000002BA6D24F381F4C40CFF57D3848FE4C40
72433	7	71	\N	83	51929	\N	58.004365999999997	город Пермь, Дзержинский район, ул.Кирова, д.226		0101000020E6100000D0D6C1C1DE1A4C406F9BA9108F004D40
72590	7	71	\N	83	51961	\N	58.025142000000002	г.Пермь, Мотовилихинский район, Ким, 60		0101000020E61000005C2041F163264C40C6E061DA37034D40
72564	7	71	\N	83	51961	\N	58.019112	г.Пермь, Мотовилихинский район, Ким, 78		0101000020E610000082CAF8F719254C40077B134372024D40
72585	7	71	\N	83	51839	\N	58.022989344706602	г.Пермь, Мотовилихинский район, Каспийская, 15	Россия, Пермский край, Пермь, Каспийская улица	0101000020E6100000560BEC3191284C407995B54DF1024D40
72054	7	71	\N	56211	62593	\N	58.082445999999997	г.Краснокамск, Рождественский проезд, д.5	Россия	0101000020E61000005B087250C2DA4B40CFD72C978D0A4D40
72583	7	71	\N	83	51839	\N	58.022670563003402	г. Пермь, Мотовилихинский район, ул. Каспийская, д.15 (пос.Архирейка)	Россия, Пермский край, Пермь, Каспийская улица	0101000020E610000016F9F5436C284C40A8C821E2E6024D40
72474	7	71	\N	83	51910	\N	57.975321999999998	г.Пермь, ул.Карпинского, д.86		0101000020E61000005D876A4AB21A4C40DF88EE59D7FC4C40
72471	7	71	\N	83	51910	\N	57.975794	г.Пермь, ул.Карпинского, д.79		0101000020E61000000A1346B3B21B4C4007D15AD1E6FC4C40
72470	7	71	\N	83	51910	\N	57.979444999999998	г.Пермь, ул.Карпинского, д.66		0101000020E61000009FAEEE586C1B4C40889D29745EFD4C40
72525	7	71	\N	83	51990	\N	58.026724000000002	Пермский край, г.Пермь, Кировский район, ул.Капитанская, д.22		0101000020E6100000FFE9060ABC014C40580229B16B034D40
72526	7	71	\N	83	51886	\N	58.024912999999998	Пермский край, г.Пермь, Кировский район, ул.Калинина, д.19		0101000020E61000002C9E7AA4C1014C40641F645930034D40
72619	7	71	\N	83	51962	\N	58.101416	г.Пермь, ул.Кабельщиков, д.21 А		0101000020E6100000CE33F6251B254C4044A51133FB0C4D40
72589	7	71	\N	83	51937	\N	58.022891999999999	г.Пермь, Мотовилихинский район, Инженерная, 5		0101000020E61000004E61A5828A264C4086AB0320EE024D40
72605	7	71	\N	83	51958	\N	58.064525000000003	г.Пермь, Мотовилихинский район, Ивана Франко, 43		0101000020E6100000DA03ADC0902D4C402063EE5A42084D40
72604	7	71	\N	83	51958	\N	58.062891999999998	г.Пермь, Мотовилихинский район, Ивана Франко, 49		0101000020E6100000506D7022FA2D4C400B9755D80C084D40
72613	7	71	\N	83	51942	\N	58.110878999999997	г.Пермь, ул.Звенигородская, д.11		0101000020E6100000D042024697274C4016687748310E4D40
72515	7	71	\N	83	51916	\N	58.004266000000001	Пермский край, г.Пермь, Кировский район, ул.Закамская, д.39		0101000020E6100000622EA9DA6EFA4B400C3ECDC98B004D40
72510	7	71	\N	83	51916	\N	57.997331000000003	Пермский край, г.Пермь, Кировский район, ул.Закамская, д.8		0101000020E610000096B4E21B0AF94B40BC24CE8AA8FF4C40
72677	7	71	\N	83	51915	\N	57.975378999999997	г.Пермь, ул.Загарьинская, 6		0101000020E61000009CFC169D2C234C40431A1538D9FC4C40
72546	7	71	\N	83	51501	\N	58.009652156792903	г.Пермь, ул.Екатерининская, д.71	Россия, Пермский край, Пермь, Екатерининская улица, 71	0101000020E610000060ADDA35211F4C40A62BD8463C014D40
72565	7	71	\N	83	51832	\N	58.016195670966297	г.Пермь, Мотовилихинский район, Дружбы, 18	Россия, Пермский край, Пермь, улица Дружбы	0101000020E6100000D1048A58C4244C40BB29E5B512024D40
72592	7	71	\N	83	51822	\N	58.045403201555303	г.Пермь, Мотовилихинский район, Днепровская, 32	Россия, Пермский край, Пермь, Днепровская улица	0101000020E610000049BC3C9D2B244C40F511F8C3CF054D40
72462	7	71	\N	83	52210	\N	58.009554000000001	город Пермь, Дзержинский район, Дзержинского, 3а		0101000020E61000009F03CB1132184C40E3C5C21039014D40
72492	7	71	\N	83	51953	\N	57.973211999999997	г.Пермь, ул.Дениса Давыдова, д.13		0101000020E6100000E9D495CFF2144C409109F83592FC4C40
72555	7	71	\N	83	54444	\N	58.050067369365301	г. Пермь, Ленинский район, ул. Профессора Дедюкина, д.8а	Россия, Пермский край, Пермь, улица Дедюкина, 8а	0101000020E6100000E3A6069ACF1B4C40EECD6F9868064D40
72554	7	71	\N	83	54444	\N	58.055243235827703	г. Пермь, Ленинский район, ул. Профессора Дедюкина, д.24	Россия, Пермский край, Пермь, улица Дедюкина, 24	0101000020E6100000B0E42A16BF1B4C409D2ADF3312074D40
72667	7	71	\N	83	51848	\N	57.963526000000002	г.Пермь, ул.Гусарова, 4		0101000020E61000004128EFE3681C4C40406CE9D154FB4C40
72431	7	71	\N	83	51970	\N	57.997593000000002	г. Пермь, Дзержинский район, ул. Голева,8		0101000020E6100000D8F4A0A0141B4C40F9DB9E20B1FF4C40
72430	7	71	\N	83	51970	\N	57.997593000000002	город Пермь, Дзержинский район, ул.Голева, д.8		0101000020E6100000D8F4A0A0141B4C40F9DB9E20B1FF4C40
72675	7	71	\N	83	51938	\N	57.972859	г.Пермь, ул.Героев Хасана, 89		0101000020E61000008ECEF9298E214C40444FCAA486FC4C40
72674	7	71	\N	83	51938	\N	57.954749999999997	г.Пермь, ул.Героев Хасана, 109/2а		0101000020E6100000E96514CB2D234C4091ED7C3F35FA4C40
72673	7	71	\N	83	51938	\N	57.950389999999999	г.Пермь, ул.Героев Хасана, 117		0101000020E610000007B5DFDA89224C4004392861A6F94C40
72632	7	71	\N	83	51945	\N	58.091465999999997	г.Пермь, ул.Генерала Доватора, д.1		0101000020E61000003046240A2D314C4014596B28B50B4D40
72606	7	71	\N	83	51995	\N	58.066087000000003	г.Пермь, Мотовилихинский район, Гашкова, 11		0101000020E610000059350873BB2D4C406BD8EF8975084D40
72601	7	71	\N	83	51995	\N	58.057769	г.Пермь, Мотовилихинский район, Гашкова, 45		0101000020E6100000FBE93F6B7E2C4C407FDC7EF964074D40
72508	7	71	\N	83	51928	\N	57.991759999999999	Пермский край, г.Пермь, Кировский район, ул.Гальперина, д.6		0101000020E6100000FC7266BB42F74B4090BDDEFDF1FE4C40
72572	7	71	\N	83	1088	\N	58.002276999999999	г.Пермь, Мотовилихинский район, Бульвар Гагарина, 54	Россия, Пермский край, Пермь, Гагарина бульвар, 54	0101000020E61000001920D1048A244C403944DC9C4A004D40
72571	7	71	\N	83	1088	\N	58.000864999999997	г.Пермь, Мотовилихинский район, Бульвар Гагарина, 75 А	Россия, Пермский край, Пермь, Гагарина бульвар, 75а	0101000020E6100000C91F0C3CF7244C40035B25581C004D40
72570	7	71	\N	83	1088	\N	58.004536999999999	г.Пермь, Мотовилихинский район, Бульвар Гагарина, 50	Россия, Пермский край, Пермь, Гагарина бульвар, 50	0101000020E6100000ED65DB696B244C409C4F1DAB94004D40
72568	7	71	\N	83	1088	\N	58.008280999999997	г.Пермь, Мотовилихинский район, бульвар Гагарина, 59	Россия, Пермский край, Пермь, Гагарина бульвар, 59	0101000020E6100000804754A86E244C40CE16105A0F014D40
72561	7	71	\N	83	1088	\N	58.016095	г.Пермь, Мотовилихинский район, Бульвар Гагарина, 37	Россия, Пермский край, Пермь, Гагарина бульвар, 37	0101000020E61000006E6B0BCF4B234C408750A5660F024D40
72560	7	71	\N	83	1088	\N	58.017620000000001	г.Пермь, Мотовилихинский район, Бульвар Гагарина, 33	Россия, Пермский край, Пермь, Гагарина бульвар, 33	0101000020E6100000CC9717601F234C40B5E0455F41024D40
72531	7	71	\N	83	51893	\N	58.044711	Пермский край, г.Пермь, Кировский район, ул.Высокая, д.6		0101000020E6100000406CE9D154054C40BF620D17B9054D40
72594	7	71	\N	83	51834	\N	58.032382518568902	г.Пермь, Мотовилихинский район, Восстания, 10	Россия, Пермский край, Пермь, улица Восстания, 10	0101000020E6100000EC2E505260294C4023F94A2025044D40
72502	7	71	\N	83	51926	\N	58.025728000000001	Пермский край, г.Пермь, Кировский район, ул.Воронежская, д.8		0101000020E610000016C1FF56B2EB4B40B64B1B0E4B034D40
72524	7	71	\N	83	51991	\N	58.026052	Пермский край, г.Пермь, Кировский район, ул.Волгодонская, д.20А		0101000020E61000008C118942CB004C4069FF03AC55034D40
72490	7	71	\N	83	51515	\N	57.964751253891798	г.Пермь, ул.Милиционера Власова, д.37		0101000020E6100000BB9866BAD7154C4043E4F4F57CFB4C40
72620	7	71	\N	83	51902	\N	58.098044000000002	г.Пермь, ул.Вильямса, д.71		0101000020E6100000C07ADCB75A254C40D6C8AEB48C0C4D40
72616	7	71	\N	83	51902	\N	58.105525	г.Пермь, ул.Вильямса, д.1		0101000020E61000004F07B29E5A274C4088F4DBD7810D4D40
72669	7	71	\N	83	54674	\N	57.964682000000003	г. Пермь, Свердловский район, ул. Вижайская, д.16		0101000020E6100000FBEB1516DC1D4C401B8524B37AFB4C40
72455	7	71	\N	83	51931	\N	58.044206000000003	город Пермь, Дзержинский район, ул.Ветлужская, д.62		0101000020E6100000C2FA3F87F90A4C40BC24CE8AA8054D40
72454	7	71	\N	83	51931	\N	58.045025000000003	город Пермь, Дзержинский район, ул.Ветлужская, д.89		0101000020E6100000D7C39789220C4C404F401361C3054D40
72453	7	71	\N	83	51931	\N	58.042637999999997	город Пермь, Дзержинский район, ул.Ветлужская, д.34		0101000020E61000002D414640850D4C408EC8772975054D40
72456	7	71	\N	83	51986	\N	58.050230999999997	город Пермь, Дзержинский район, ул.Вагонная, д.22		0101000020E61000001B0FB6D8ED0B4C40681F2BF86D064D40
72634	7	71	\N	83	51944	\N	58.085023999999997	г.Пермь, ул.Бушмакина, д.26		0101000020E610000088F6B182DF324C4003B00111E20A4D40
72680	7	71	\N	83	52218	\N	57.975269535078297	г.Пермь, ул.Братская, 177	Россия, Пермский край, Пермь, Братская улица, 175	0101000020E61000004243FF0417294C408D62B9A5D5FC4C40
72596	7	71	\N	83	51837	\N	58.026802674252501	г.Пермь, Мотовилихинский район, Борчаниновская, 28	Россия, Пермский край, Пермь, Борчаниновская улица	0101000020E61000007B336ABE4A2A4C40A437DC476E034D40
72553	7	71	\N	83	51824	\N	58.027596336602599	г.Пермь, ул.Борцов Революции, д.151	Россия, Пермский край, Пермь, улица Борцов Революции, 152б	0101000020E6100000CF4D9B711A1C4C400EC0064488034D40
72668	7	71	\N	83	51853	\N	57.965348334800098	г.Пермь, ул.Бородинская, 28	Россия, Пермский край, Пермь, Бородинская улица, 26	0101000020E6100000E695EB6D331D4C4027A1F48590FB4C40
72439	7	71	\N	83	51981	\N	57.999315000000003	город Пермь, Дзержинский район, ул.Боровая, д.16		0101000020E6100000A1116C5CFF164C407DB3CD8DE9FF4C40
72506	7	71	\N	83	51972	\N	58.00676	Пермский край, г.Пермь, Кировский район, ул.Богдана Хмельницкого, д.13а		0101000020E6100000BDFBE3BD6AF74B40E275FD82DD004D40
72655	7	71	\N	83	51908	\N	57.994191999999998	г.Пермь, ул.Белинского, 50		0101000020E61000006FD74B5304204C40F0F8F6AE41FF4C40
72481	7	71	\N	83	51911	\N	57.98216	г.Пермь, ул.Баумана, д.27		0101000020E610000059350873BB174C403DB83B6BB7FD4C40
72480	7	71	\N	83	51911	\N	57.985514999999999	г.Пермь, ул.Баумана, д.16		0101000020E6100000FA7B293C68184C40D55B035B25FE4C40
72478	7	71	\N	83	51911	\N	57.986640999999999	г.Пермь, ул.Баумана, д.5		0101000020E6100000B9E00CFE7E194C4045F295404AFE4C40
72617	7	71	\N	83	51943	\N	58.106271	г.Пермь, ул.Барнаульская, д.4		0101000020E6100000B247A81952274C40B1C1C2499A0D4D40
72573	7	71	\N	83	51956	\N	57.998069999999998	г.Пермь, Мотовилихинский район, Аркадия Гайдара, 13		0101000020E6100000A54C6A6803264C40328FFCC1C0FF4C40
72513	7	71	\N	83	51749	\N	58.0020628917759	Пермский край, г.Пермь, Кировский район, ул.Александра Невского, д.25	Россия, Пермский край, Пермь, улица Невского, 25	0101000020E6100000FB78E8BB5BF94B400DC4B29943004D40
72511	7	71	\N	83	51930	\N	58.000931999999999	Пермский край, г.Пермь, Кировский район, ул.Автозаводская, д.19		0101000020E6100000FF2268CC24F84B408BC22E8A1E004D40
72507	7	71	\N	83	51930	\N	57.994689000000001	Пермский край, г.Пермь, Кировский район, ул.Автозаводская, д.6		0101000020E61000000938842A35F74B4071581AF851FF4C40
72593	7	71	\N	83	51842	\N	58.035978	г.Пермь, Мотовилихинский район, 1905 года, 2		0101000020E6100000EB56CF49EF274C4010B056ED9A044D40
72623	7	71	\N	83	2010	\N	58.139702999999997	г.Пермь, 1й Павловский прд, д.2	Россия, Пермский край, Пермь, 1-й Павловский проезд, 2	0101000020E6100000B37BF2B050414C409813B4C9E1114D40
72653	7	71	\N	83	51519	\N	57.9989513994243	г.Пермь, ул.Глеба Успенского, 9		0101000020E610000006F357C85C1F4C403BA759A0DDFF4C40
72449	7	71	\N	83	51985	\N	58.036726000000002	город Пермь, Дзержинский район, ул.Транспортная, д.27а		0101000020E6100000F3380CE6AF104C40DA740470B3044D40
72438	7	71	\N	83	51984	\N	57.996378962191102	город Пермь, Дзержинский район, ул.Локомотивная, д.1	Россия, Пермский край, Пермь, улица Локомотивная, 1	0101000020E61000009929ADBF25184C40E9B5D95889FF4C40
72239	7	71	\N	83	51975	\N	58.006712	пгт. Октябрьский, Ленина, 63, администрация Октябрьского ГП		0101000020E6100000EA944737C21A4C40D13E56F0DB004D40
72622	7	71	\N	83	51850	\N	58.150908000000001	г.Пермь, ул.Корсуньская, д.31		0101000020E6100000B85B920376374C40365A0EF450134D40
72516	7	71	\N	83	51874	\N	58.002285999999998	Пермский край, г.Пермь, Кировский район, ул.Кировоградская, д.53		0101000020E6100000F94CF6CFD3FA4B408C9E5BE84A004D40
72472	7	71	\N	83	51988	\N	57.975794	г. Пермь, ул.Карпинского, д.79		0101000020E61000000A1346B3B21B4C4007D15AD1E6FC4C40
72550	7	71	\N	83	51514	\N	58.008490000000002	г.Пермь, ул.Екатерининская, д.174		0101000020E6100000AD68739CDB1E4C40E92B483316014D40
71852	7	71	\N	58014	62659	\N	58.837457764851898	п.Парма, ул.К. Маркса, д.34	Россия, Пермский край, Добрянка городской округ, село Парма	0101000020E6100000B894F3C5DE974C4004E3E0D2316B4D40
72346	7	71	\N	56229	51615	\N	57.893271234746202	г.Очер, Красногвардейская, 54	Россия, Пермский край, Очерский район, Очер	0101000020E610000032B08EE3875C4B408CBB41B456F24C40
72315	7	71	\N	56216	51495	\N	57.276373993903498	г.Оса, Пугачева, 12		0101000020E610000047AB5AD251B84B407BBB253960A34C40
72328	7	71	\N	56216	51611	\N	57.282835584779399	г. Оса, М.Горького, 63	Россия, Пермский край, Осинский район, Оса	0101000020E61000001615713AC9BA4B40D41055F833A44C40
72306	7	71	\N	56216	51611	\N	57.279116999999999	г.Оса, М.Горького, 71		0101000020E6100000471D1D5723B94B40FA60191BBAA34C40
72309	7	71	\N	56216	52041	\N	57.279116999999999	г.Оса, Ленина, 2		0101000020E6100000471D1D5723B94B40FA60191BBAA34C40
72204	7	71	\N	56213	51808	\N	57.936819668506701	г.Нытва, Ленина проспект, д.28а	Россия, Пермский край, Нытвенский район, Нытва	0101000020E61000005BB6D61709AD4B408E1EBFB7E9F74C40
72207	7	71	\N	56213	51482	\N	57.927619988518899	г.Нытва, ул.Чапаева, д.22		0101000020E61000003EB2B96A9EA94B40C98E8D40BCF64C40
72210	7	71	\N	56213	51608	\N	57.920403	г.Нытва, ул.Луговая, д.22		0101000020E61000002579AEEFC3AB4B40F511F8C3CFF54C40
71885	7	71	\N	58147	\N	\N	58.760171694727802	п. Нижний Лух, здание администрации	Россия, Пермский край, Добрянка городской округ, село Нижний Лух	0101000020E6100000EDF5EE8FF72A4C40DEAAEB504D614D40
72400	7	71	\N	58007	62602	\N	57.811435771616097	с.НМуллы, у.Советская, д.10	Россия	0101000020E6100000EF39B01C210D4C4006668522DDE74C40
71841	7	71	\N	58078	63196	\N	58.7760632251914	п.Нагорнский, ул.Советская, д.21		0101000020E6100000834D9D47C5C54C405D514A0856634D40
72194	7	71	\N	58035	62896	\N	57.757886421437703	д.Моховляна, ул.Молодежная, д.12		0101000020E6100000535DC0CB0C1B4D40520C906802E14C40
72193	7	71	\N	58150	63973	\N	57.781249373274697	с.Матвеево, ул.Центральная, д.93	Россия, Пермский край, Лысьва городской округ, село Матвеево	0101000020E6100000AE81AD122CEC4C4030849CF7FFE34C40
72398	7	71	\N	56217	51499	\N	58.0851282006888	с.Ляды, у.Мира, д.1		0101000020E61000008C4CC0AF91504C40A8FC6B79E50A4D40
72178	7	71	\N	15896	51464	\N	58.104888000000003	г.Лысьва, проспект Победы, д.19		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72164	7	71	\N	15896	51464	\N	58.088892974035303	г.Лысьва, проспект Победы, д.114	Россия, Пермский край, Лысьва	0101000020E6100000CF9ECBD424E84C40F2EB87D8600B4D40
72162	7	71	\N	15896	51464	\N	58.104333224203401	г.Лысьва, проспект Победы, д.118	Россия, Пермский край, Лысьва	0101000020E6100000F1D93A38D8E74C406072A3C85A0D4D40
72163	7	71	\N	15896	51799	\N	58.123059295525401	г.Лысьва, ул.Чапаева, д.75	Россия, Пермский край, Лысьва	0101000020E610000054008C67D0E84C403E3DB665C00F4D40
72179	7	71	\N	15896	51472	\N	58.104888000000003	г.Лысьва, ул.Чайковского, д.3		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72175	7	71	\N	15896	51466	\N	58.104888000000003	г.Лысьва, ул.Федосеева, д.16		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72174	7	71	\N	15896	51466	\N	58.097948886459697	г.Лысьва, ул.Федосеева, д.25	Россия, Пермский край, Лысьва	0101000020E61000006E19709692E74C4084D6C397890C4D40
72173	7	71	\N	15896	51466	\N	58.100698154743597	г.Лысьва, ул.Федосеева, д.31	Россия, Пермский край, Лысьва	0101000020E61000000795B88E71E74C40E5620CACE30C4D40
72158	7	71	\N	15896	51797	\N	58.104888000000003	г.Лысьва, ул.Уральская, д.23		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72157	7	71	\N	15896	51593	\N	58.104888000000003	г.Лысьва, ул.Строительная, д.83		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72165	7	71	\N	15896	51715	\N	58.104888000000003	г.Лысьва, ул.Смышляева, д.106		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72169	7	71	\N	15896	51801	\N	58.118063614118903	г.Лысьва, ул.Революции, д.15	Россия, Пермский край, Лысьва	0101000020E6100000BB7F2C4487E84C40DF6A9DB81C0F4D40
72159	7	71	\N	15896	51708	\N	58.104888000000003	г.Лысьва, ул.Разина, д.2		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72180	7	71	\N	15896	51534	\N	58.104888000000003	г.Лысьва, ул.Полярников, д.7		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72168	7	71	\N	15896	51595	\N	58.116812809703198	г.Лысьва, ул.Полевая, д.91	Россия, Пермский край, Лысьва	0101000020E6100000C9AEB48CD4E94C40B35F77BAF30E4D40
72160	7	71	\N	15896	51711	\N	58.104888000000003	г.Лысьва, ул.Орджоникидзе, д.35		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72170	7	71	\N	15896	51471	\N	58.104888000000003	г.Лысьва, ул.Никулина, д.76		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72176	7	71	\N	15896	51727	\N	58.104888000000003	г.Лысьва, ул.Мичурина, д.15		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72172	7	71	\N	15896	51467	\N	58.098891841286097	г.Лысьва, ул.Мира, д.4	Россия, Пермский край, Лысьва	0101000020E6100000FD69A33A1DE64C4003EB387EA80C4D40
72167	7	71	\N	15896	51467	\N	58.0993008259601	г.Лысьва, ул.Мира, д.45	Россия, Пермский край, Лысьва	0101000020E610000044C362D4B5E64C40E4BA29E5B50C4D40
72177	7	71	\N	15896	51732	\N	58.104888000000003	г.Лысьва, ул.Ленина, д.36		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72171	7	71	\N	15896	51717	\N	58.104888000000003	г.Лысьва, ул.Кузьмина, д.26		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72166	7	71	\N	15896	51594	\N	58.104888000000003	г.Лысьва, ул.Коммунаров, д.63		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72155	7	71	\N	15896	51795	\N	58.104888000000003	г.Лысьва, ул.Калинина, д.26		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72200	7	71	\N	15896	51803	\N	58.104888000000003	г.Лысьва, ул.Гайдара, д.28		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72156	7	71	\N	15896	51703	\N	58.104888000000003	г.Лысьва, ул.Быстрых, д.29		0101000020E610000083DE1B4300E84C4016DF50F86C0D4D40
72803	7	71	\N	15896	53174	\N	58.1052532921722	п.Лысьва, А.Жарова, 1	Россия, Пермский край, Лысьва	0101000020E6100000198F52094FE84C40276728EE780D4D40
72161	7	71	\N	15896	51465	\N	58.097346745587402	г.Лысьва, ул.Пожарского, д.4	Россия, Пермский край, Лысьва	0101000020E61000009D0E643DB5E44C408EAED2DD750C4D40
72192	7	71	\N	58033	62889	\N	57.780529758460702	п.Ломовка, ул.Школьная, д.1		0101000020E610000085ED27637CF24C4000C63368E8E34C40
72087	7	71	\N	58149	\N	\N	58.077744525265899	д.Ласьва, помещение ФАП	Россия	0101000020E6100000E1CFF0660DFC4B40B936548CF3094D40
72154	7	71	\N	32907	\N	\N	57.415666999999999	Пермский край, Кунгурский городской округ, п.Дальний		0101000020E6100000D0D1AA96747A4C406283859334B54C40
72143	7	71	\N	32907	51826	\N	57.417457441939398	Пермский край, Кунгурский городской округ, Свободы, 149	Россия, Пермский край, Кунгур	0101000020E6100000CCB56801DA7A4C403E3E213B6FB54C40
72142	7	71	\N	32907	51826	\N	57.429743623782201	Пермский край, Кунгурский городской округ, Свободы, 116		0101000020E6100000A29927D7147C4C407CD3F4D901B74C40
72141	7	71	\N	32907	51606	\N	57.430811394748403	Пермский край, Кунгурский городской округ, Пугачева, 63	Россия, Пермский край, Кунгур городской округ	0101000020E6100000E36DA5D7667B4C40E7E099D024B74C40
72125	7	71	\N	32907	51743	\N	57.417175140485597	Пермский край, Кунгурский городской округ, Просвещения, 12	Россия, Пермский край, Кунгур	0101000020E610000089F02F82C67A4C40BADA8AFD65B54C40
72123	7	71	\N	32907	51469	\N	57.413192114414898	Пермский край, Кунгурский городской округ, Полетаевская, 2	Россия, Пермский край, Кунгур городской округ	0101000020E610000011FFB0A5477F4C40037CB779E3B44C40
72124	7	71	\N	32907	51798	\N	57.417333974895001	Пермский край, Кунгурский городской округ, Плехановский тракт, 3	Россия, Пермский край, Кунгур	0101000020E61000007E8D2441B87A4C4022C154336BB54C40
72128	7	71	\N	32907	51806	\N	57.417827931015701	Пермский край, Кунгурский городской округ, Матросская, 15	Россия, Пермский край, Кунгур	0101000020E61000007BBDFBE3BD7A4C4032AD4D637BB54C40
72144	7	71	\N	32907	51840	\N	57.416824544546003	Пермский край, Кунгурский городской округ, МОПРа, 6	Россия, Пермский край, Кунгур	0101000020E6100000B62E35423F7B4C40DE9387855AB54C40
72134	7	71	\N	32907	51723	\N	57.413443599217501	Пермский край, Кунгурский городской округ, Ленина, 38	Россия, Пермский край, Кунгур	0101000020E61000001C08C902267A4C401C5DA5BBEBB44C40
72132	7	71	\N	32907	51723	\N	57.4162687942326	Пермский край, Кунгурский городской округ, Ленина, 75	Россия, Пермский край, Кунгур городской округ	0101000020E610000053E751F17F7B4C4058AB764D48B54C40
72148	7	71	\N	32907	51804	\N	57.416804644778601	Пермский край, Кунгурский городской округ, Красная, 38	Россия, Пермский край, Кунгур	0101000020E61000005C3CBCE7C07A4C4096E7C1DD59B54C40
72137	7	71	\N	32907	51876	\N	57.417179572662498	Пермский край, Кунгурский городской округ, Космонавтов, 12	Россия, Пермский край, Кунгур	0101000020E610000054A9D903AD7A4C40CC457C2766B54C40
72153	7	71	\N	32907	51613	\N	57.4169634808014	Пермский край, Кунгурский городской округ, Кирова, 33а	Россия, Пермский край, Кунгур	0101000020E6100000E3E2A8DC447B4C402F52280B5FB54C40
72146	7	71	\N	32907	51463	\N	57.418879589344101	Пермский край, Кунгурский городской округ, Каширина, 17б	Россия, Пермский край, Кунгур городской округ	0101000020E610000063450DA6617C4C4068791EDC9DB54C40
72145	7	71	\N	32907	51463	\N	57.420555739972201	Пермский край, Кунгурский городской округ, Каширина, 17	Россия, Пермский край, Кунгур городской округ	0101000020E6100000E94482A9667E4C407B116DC7D4B54C40
72130	7	71	\N	32907	51701	\N	57.416253326451503	Пермский край, Кунгурский городской округ, К.Маркса, 41	Россия, Пермский край, Кунгур	0101000020E6100000815D4D9EB27A4C4052EE3EC747B54C40
72129	7	71	\N	32907	51701	\N	57.417272195990002	Пермский край, Кунгурский городской округ, К.Маркса, 10	Россия, Пермский край, Кунгур	0101000020E61000005A492BBEA17A4C40ACC43C2B69B54C40
72152	7	71	\N	32907	51843	\N	57.422601892394503	Пермский край, Кунгурский городской округ, Заводская, 48в		0101000020E61000008315A75A0B7B4C40B29C84D217B64C40
72139	7	71	\N	32907	52191	\N	57.417982330503797	Пермский край, Кунгурский городской округ, Гоголя, 34	Россия, Пермский край, Кунгур	0101000020E6100000B62E35423F7B4C408928266F80B54C40
72149	7	71	\N	32907	51830	\N	57.417148728318601	Пермский край, Кунгурский городской округ, Гоголя, 1	Россия, Пермский край, Кунгур	0101000020E6100000F699B33EE57A4C409147702365B54C40
72150	7	71	\N	32907	51845	\N	57.417056104677599	Пермский край, Кунгурский городской округ, Гайдара, 21	Россия, Пермский край, Кунгур	0101000020E6100000E012807F4A7B4C40E04C4C1762B54C40
72136	7	71	\N	32907	51811	\N	57.4163415198528	Пермский край, Кунгурский городской округ, Газеты Искра, 25	Россия, Пермский край, Кунгур	0101000020E610000062DC0DA2B57A4C40C2F9D4B14AB54C40
72127	7	71	\N	32907	51796	\N	57.416897269058197	Пермский край, Кунгурский городской округ, Воровского, 35	Россия, Пермский край, Кунгур	0101000020E610000089F02F82C67A4C40776682E15CB54C40
72151	7	71	\N	32907	52127	\N	57.429491980089097	Пермский край, Кунгурский городской округ, Батальонная, 13		0101000020E6100000416150A6D17C4C4063F20698F9B64C40
72126	7	71	\N	32907	51612	\N	57.4250472846497	Пермский край, Кунгурский городской округ, Голованова, 106	Россия, Пермский край, Кунгур городской округ	0101000020E610000029B000A60C7E4C40A721AAF067B64C40
72384	7	71	\N	56218	51497	\N	57.647536000000002	п. Кукуштан, ул. Мира, Школа		0101000020E6100000C90391459A3E4C40C87DAB75E2D24C40
73194	7	71	\N	2524	51729	\N	59.003306000000002	г.Кудымкар, Строителей, 11		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73204	7	71	\N	2524	51663	\N	59.003569495814503	г.Кудымкар, Пионерская, 4	Россия, Пермский край, Кудымкар	0101000020E6100000FF9254A698534B40C423F1F274804D40
73190	7	71	\N	2524	51663	\N	59.014991960741099	г. Кудымкар, Пионерская, 4		0101000020E6100000810871E5EC554B40CFD90242EB814D40
73203	7	71	\N	2524	51527	\N	59.003306000000002	г.Кудымкар, Лихачева, 25		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73197	7	71	\N	2524	51527	\N	59.003306000000002	г.Кудымкар, Лихачева, 60		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73193	7	71	\N	2524	51539	\N	59.003306000000002	г.Кудымкар, Леваневского, 12		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73192	7	71	\N	2524	51539	\N	59.018621559811798	г.Кудымкар, Леваневского, 19	Россия, Пермский край, Кудымкар городской округ	0101000020E6100000EE05668522534B40397EA83462824D40
73205	7	71	\N	2524	51730	\N	59.003306000000002	г.Кудымкар, Кузнецова, 3		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73195	7	71	\N	2524	52285	\N	59.003306000000002	г.Кудымкар, Конституции, 1		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73191	7	71	\N	2524	51750	\N	59.003306000000002	г.Кудымкар, Загородная, 6		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73202	7	71	\N	2524	51661	\N	59.003306000000002	г.Кудымкар, Горького, 28		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73201	7	71	\N	2524	51528	\N	59.016674017845197	г.Кудымкар, Гагарина, 1		0101000020E6100000707B82C476554B40C558A65F22824D40
73200	7	71	\N	2524	51528	\N	59.003306000000002	г.Кудымкар, Гагарина, 9		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73199	7	71	\N	2524	51528	\N	59.003306000000002	г.Кудымкар, Гагарина, 11		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73196	7	71	\N	2524	51528	\N	59.003306000000002	г.Кудымкар, Гагарина, 21		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73206	7	71	\N	2524	51664	\N	59.003306000000002	г.Кудымкар, Братчикова, 1		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
73198	7	71	\N	2524	51660	\N	59.003306000000002	г.Кудымкар, 50 лет Октября, 12		0101000020E610000029779FE3A3534B40B7F0BC546C804D40
72065	7	71	\N	56211	62595	\N	58.086498207751497	г.Краснокамск, пр.Маяковского, д.9	Россия	0101000020E6100000B891B245D2E44B40AF95D05D120B4D40
72064	7	71	\N	56211	62595	\N	58.075882999999997	город Краснокамск, пр.Маяковского, д.9	Россия	0101000020E610000073F56393FCDE4B4043A9BD88B6094D40
72063	7	71	\N	56211	62592	\N	58.075243999999998	г.Краснокамск, пер.Банковский, д.4А	Россия	0101000020E6100000F24410E7E1DE4B40309C6B98A1094D40
72067	7	71	\N	56211	62600	\N	58.076484999999998	г.Краснокамск, ул.Энтузиастов, д.15	Россия	0101000020E610000085E97B0DC1DF4B4039D1AE42CA094D40
72061	7	71	\N	56211	51829	\N	58.075679000000001	г.Краснокамск, ул.Чапаева, д.35	Россия	0101000020E6100000B1FCF9B660DF4B403BFF76D9AF094D40
72060	7	71	\N	56211	51829	\N	58.075679000000001	г.Краснокамск, ул.Чапаева, д.33	Россия	0101000020E6100000B1FCF9B660DF4B403BFF76D9AF094D40
72070	7	71	\N	56211	62580	\N	58.071382999999997	г.Краснокамск, ул.Советская, д.29	Россия	0101000020E61000007C0BEBC6BBE14B40C43E011423094D40
72066	7	71	\N	56211	62577	\N	58.075861000000003	г.Краснокамск, ул.Коммунистическая, д.16	Россия	0101000020E610000098158A743FDF4B405C0531D0B5094D40
72058	7	71	\N	56211	81117	\N	58.077143999999997	г.Краснокамск, ул.Комарова, д.7	Россия	0101000020E610000071033E3F8CDE4B40938AC6DADF094D40
72062	7	71	\N	56211	62582	\N	58.075679000000001	г.Краснокамск, ул.К.Маркса, д.4А	Россия	0101000020E6100000B1FCF9B660DF4B403BFF76D9AF094D40
72059	7	71	\N	56211	62582	\N	58.082058500649502	г.Краснокамск, ул.К.Маркса, д.4Б	Россия	0101000020E61000007A8D5DA27AE14B40D6ABC8E8800A4D40
72057	7	71	\N	56211	62598	\N	58.076346000000001	г.Краснокамск, ул.К.Либкнехта, д.10	Россия	0101000020E610000077103B53E8DE4B401897AAB4C5094D40
72056	7	71	\N	56211	62598	\N	58.076346000000001	город Краснокамск, ул.К.Либкнехта, д.10	Россия	0101000020E610000077103B53E8DE4B401897AAB4C5094D40
72055	7	71	\N	56211	62586	\N	58.076515999999998	г.Краснокамск, ул.50 лет Октября, д.5	Россия	0101000020E6100000FBB0DEA815DE4B4074CFBA46CB094D40
72011	7	71	\N	56210	51459	\N	60.399992805880999	г.Красновишерск, Толстого, 38 Б		0101000020E6100000BB809719368A4C4081D07AF832334E40
72002	7	71	\N	56210	52125	\N	60.402538999999997	г.Красновишерск, Морчанская, 36		0101000020E6100000A1F2AFE595874C40A92EE06586334E40
72003	7	71	\N	56210	51457	\N	60.4197224544804	г.Красновишерск, Дзержинского, 23	Россия, Пермский край, Красновишерский район, Красновишерск	0101000020E6100000D449B6BA9C8A4C40B3B45373B9354E40
72010	7	71	\N	56210	51543	\N	60.402538999999997	г.Красновишерск, Гагарина, 42		0101000020E6100000A1F2AFE595874C40A92EE06586334E40
72013	7	71	\N	56210	52123	\N	60.417653474401902	г.Красновишерск, 1го Мая, 17	Россия, Пермский край, Красновишерский район, Красновишерск	0101000020E6100000BD8E3864038B4C40C4094CA775354E40
72381	7	71	\N	10335	51628	\N	57.982301906974101	д.Кондратово, у.КМаркса, д.1 А		0101000020E61000001D058882190D4C40CF656A12BCFD4C40
72380	7	71	\N	10335	51628	\N	57.977950999999997	д. Кондратово, ул. Карла Маркса, д.1а, МОУ Кондратовский дом спорта		0101000020E610000080289831050D4C40950B957F2DFD4C40
72370	7	71	\N	10335	51628	\N	57.977856407827197	д.Кондратово, у.Карла Маркса, д.1а	Россия, Пермский край, деревня Кондратово, улица Карла Маркса, 1а	0101000020E610000029E78BBD170D4C404419AA622AFD4C40
72138	7	71	\N	10335	51628	\N	57.979474000000003	Пермский край, Кунгурский городской округ, К.Маркса, 23		0101000020E61000009C19FD68380D4C4023A46E675FFD4C40
71980	7	71	\N	7570	51605	\N	58.979396546208598	поселок Южный Коспашский, Широковская, 97	Россия, Пермский край, Кизел городской округ, поселок Южный Коспашский	0101000020E6100000DA1D520C90E24C40776682E15C7D4D40
71978	7	71	\N	7570	51597	\N	59.090480999999997	поселок Северный Коспашский, Фурманова, 4		0101000020E61000003B55BE6724E44C4066F4A3E1948B4D40
71971	7	71	\N	7570	51675	\N	59.050046000000002	Кизел, Советская, 36		0101000020E6100000D06053E751D34C40D7A546E867864D40
71968	7	71	\N	7570	51675	\N	59.050046000000002	Кизел, Советская, 18		0101000020E6100000D06053E751D34C40D7A546E867864D40
71974	7	71	\N	7570	51677	\N	59.050046000000002	Кизел, Пролетарская, 104		0101000020E6100000D06053E751D34C40D7A546E867864D40
71970	7	71	\N	7570	51677	\N	59.050046000000002	Кизел, Пролетарская, 24		0101000020E6100000D06053E751D34C40D7A546E867864D40
71972	7	71	\N	7570	51532	\N	59.050046000000002	Кизел, Народной Памяти, 7		0101000020E6100000D06053E751D34C40D7A546E867864D40
71973	7	71	\N	7570	51584	\N	59.051701275671597	Кизел, Макаренко, 9	Россия, Пермский край, Кизел	0101000020E61000009D6340F67AD14C40D3156C239E864D40
71969	7	71	\N	7570	51453	\N	59.050046000000002	Кизел, Ленина, 16		0101000020E6100000D06053E751D34C40D7A546E867864D40
71975	7	71	\N	7570	51585	\N	59.050046000000002	Кизел, Крупской, 19		0101000020E6100000D06053E751D34C40D7A546E867864D40
59754	7	71	\N	7570	51556	\N	59.050046000000002	Кизел, Капитальный, 8		0101000020E6100000D06053E751D34C40D7A546E867864D40
71976	7	71	\N	7570	51586	\N	59.050046000000002	Кизел, Ашихмина, 29		0101000020E6100000D06053E751D34C40D7A546E867864D40
71607	7	71	\N	58030	62825	\N	59.249882763944498	Пермский край, Александровский МР, п. Ивакинский карьер, Мира, 15		0101000020E61000001381EA1F44BE4C40C669882AFC9F4D40
72996	7	71	\N	56265	52037	\N	58.016291839132499	Пермский край, городской округ ЗАТО Звездный, Ленина, 10	Россия, Пермский край, Пермь, улица Ленина, 10	0101000020E610000037A6272CF1204C40DD9733DB15024D40
71855	7	71	\N	1505	51577	\N	58.463196000000003	"""г. Добрянка, пер. Строителей, 7, МОУ """"Добрянская СОШ №2"""""""		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71857	7	71	\N	1505	51788	\N	58.463196000000003	"""г. Добрянка, Энгельса, 9, МОУ """"Добрянская СОШ №3"""""""		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71884	7	71	\N	1505	52004	\N	58.463196000000003	"""г. Добрянка, Трудовые резервы, 11, здание учреждения """"ЦПТ"""""""		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71862	7	71	\N	1505	51438	\N	58.476101823184997	"""г. Добрянка, Советская, ККЗ """"Орфей"""""""	Россия, Пермский край, Добрянка	0101000020E6100000BC22F8DF4A344C40B4C70BE9F03C4D40
71861	7	71	\N	1505	51792	\N	58.463196000000003	г. Добрянка, Победы, 101, здание техникума им.Сюзева		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71854	7	71	\N	1505	51697	\N	58.463196000000003	"""г. Добрянка, пер. Строителей, 6, ДК """"Союз"""""""		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71864	7	71	\N	1505	51439	\N	58.463848184740598	г.Добрянка, Маяковского, 2, СОШ №1	Россия, Пермский край, Добрянка	0101000020E6100000A304FD851E354C4052280B5F5F3B4D40
71863	7	71	\N	1505	51698	\N	58.463196000000003	"""г. Добрянка, Красногвардейская, 50, здание ООО """"ДитрансСтрой"""""""		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71860	7	71	\N	1505	51574	\N	58.463196000000003	"""г. Добрянка, Жуковского, 39,  ЦДОД """"Логос"""""""		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71859	7	71	\N	1505	51574	\N	58.463196000000003	г. Добрянка ул. Жуковского, д. 37а.		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71858	7	71	\N	1505	51574	\N	58.467477559945102	"""г. Добрянка, Жуковского, 26, """"СОШ № 4"""""""	Россия, Пермский край, Добрянка	0101000020E6100000CF6740BD19334C40BCCCB051D63B4D40
71856	7	71	\N	1505	51437	\N	58.463196000000003	г. Добрянка, Ветеранов Войны, 3, Школа искусств		0101000020E6100000276BD44334364C40ABD1AB014A3B4D40
71840	7	71	\N	120	51695	\N	58.868084000000003	г.Губаха, пр.Октябрьский, д.9 Б		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71838	7	71	\N	120	51695	\N	58.868084000000003	г.Губаха, пр.Октябрьский, д.14 А		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71839	7	71	\N	120	51435	\N	58.868084000000003	г.Губаха, пр.Октябрьский, д.17		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71833	7	71	\N	120	51434	\N	58.843533632903601	г.Губаха, пр.Ленина, д.31	Россия, Пермский край, Губаха	0101000020E610000072E0D57267C64C4033880FECF86B4D40
71832	7	71	\N	120	51434	\N	58.868084000000003	г.Губаха, пр.Ленина, д.14		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71837	7	71	\N	120	51787	\N	58.868084000000003	г.Губаха, пр.Ленина, д.52		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71835	7	71	\N	120	51787	\N	58.868084000000003	г.Губаха, пр.Ленина, д.28		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71827	7	71	\N	120	51572	\N	58.828994467146302	г.Губаха, ул.Парковая, д.10	Россия, Пермский край, Губаха	0101000020E6100000F8325184D4C54C40454AB3791C6A4D40
71836	7	71	\N	120	51569	\N	58.868084000000003	г.Губаха, ул. Космонавтов, 13		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71834	7	71	\N	120	51568	\N	58.868084000000003	г.Губаха, ул.Коммунистическая, д.11 А		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71842	7	71	\N	120	51575	\N	58.868084000000003	г.Губаха, ул.Дегтярёва, д.34		0101000020E6100000F12BD67091C94C40271763601D6F4D40
71830	7	71	\N	77	51674	\N	58.552073019589102	Пермский край, Гремячинский муниципальный район, Юбилейнинское сельское поселение, Шахтеров, 9	Россия, Пермский край, Гремячинск	0101000020E61000005359147651EA4C409700FC53AA464D40
71825	7	71	\N	77	52182	\N	58.549022000000001	Пермский край, Гремячинский муниципальный район, Гремячинское городское поселение, Ушакова, 45		0101000020E6100000FD4B529962E84C406B64575A46464D40
71828	7	71	\N	77	52003	\N	58.549022000000001	Пермский край, Гремячинский муниципальный район, Усьвинское сельское поселение, Труда, 20		0101000020E6100000FD4B529962E84C406B64575A46464D40
71826	7	71	\N	77	51823	\N	58.549022000000001	г. Гремячинск, ул. Ленина, 135		0101000020E6100000FD4B529962E84C406B64575A46464D40
71824	7	71	\N	77	51823	\N	58.551355219759799	Пермский край, Гремячинский муниципальный район, Гремячинское городское поселение, Ленина, 223	Россия, Пермский край, Гремячинск	0101000020E61000002975C93846EA4C4038BEF6CC92464D40
71823	7	71	\N	77	51823	\N	58.549052149799302	Пермский край, Гремячинский муниципальный район, Гремячинское городское поселение, Ленина, 193	Россия, Пермский край, Гремячинск	0101000020E6100000C2FC153257E84C40D6E6FF5547464D40
71821	7	71	\N	77	51823	\N	58.549022000000001	Пермский край, Гремячинский муниципальный район, Гремячинское городское поселение, Ленина, 173		0101000020E6100000FD4B529962E84C406B64575A46464D40
71820	7	71	\N	77	51823	\N	58.556020654854599	Пермский край, Гремячинский муниципальный район, Гремячинское городское поселение, Ленина, 135	Россия, Пермский край, Гремячинск	0101000020E61000001764CBF275EB4C40D27135B22B474D40
71822	7	71	\N	77	51854	\N	58.549231612977898	Пермский край, Гремячинский муниципальный район, Гремячинское городское поселение, Грибоедова, 5	Россия, Пермский край, Гремячинск	0101000020E61000009818CBF44BE84C4056F5F23B4D464D40
71806	7	71	\N	56238	51691	\N	58.375157367017401	г.Горнозаводск, Кирова, 6	Россия, Пермский край, Горнозаводский район, Горнозаводск	0101000020E61000004DF38E53742A4D40C8EE022505304D40
72371	7	71	\N	56230	51617	\N	57.866051368240697	с. Гамово, ул. 50 лет Октября, д.14	Россия, Пермский край, Пермский район, село Гамово	0101000020E61000001268B0A9F30C4C4084D558C2DAEE4C40
71872	7	71	\N	58052	\N	\N	58.272951750877098	п. Ветляны, здание ФАП п. Ветляны		0101000020E61000009BC6F65AD0614C405BB05417F0224D40
71779	7	71	\N	56207	51431	\N	58.076600651013699	г.Верещагино, ул.Ленина, д.57а	Россия, Пермский край, Верещагинский район, Верещагино	0101000020E6100000DC65BFEE74574B40A2EBC20FCE094D40
71776	7	71	\N	56207	51431	\N	58.082864000000001	г.Верещагино, ул.Ленина, д.15		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
71775	7	71	\N	56207	51431	\N	58.082864000000001	г.Верещагино, ул.Ленина, д.20		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
71774	7	71	\N	56207	51443	\N	58.088614467446703	г.Верещагино, ул.К.Маркса, д.124		0101000020E610000081971936CA544B40DFFB1BB4570B4D40
71766	7	71	\N	56207	51427	\N	58.082864000000001	г.Верещагино, ул.Железнодорожная, д.20		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
72976	7	71	\N	58112	\N	\N	58.083732213068302	п.Валежная, Здание почты пос.Валежная	Россия, Пермский край, Чусовой городской округ, село Валежная	0101000020E61000007F6DFDF49F7B4C4078D0ECBAB70A4D40
71726	7	71	\N	58119	63689	\N	58.221259000000003	деревня Брод, Зеленая, 2 бывшая школа		0101000020E6100000F452B131AF2B4C400C790437521C4D40
71887	7	71	\N	58223	\N	\N	58.601626000000003	п. БорЛенва, здание клуба п. БорЛенва		0101000020E6100000B4006DAB590D4C402F36AD14024D4D40
72326	7	71	\N	58107	63474	\N	58.221259000000003	с.Богомягково, Центральная, 5		0101000020E6100000F452B131AF2B4C400C790437521C4D40
72368	7	71	\N	56225	51551	\N	57.742248905341697	c.Бершеть, у.Школьная, д.9	Россия, Пермский край, Пермский район, село Бершеть	0101000020E61000006EA46C91B42F4C408E3EE60302DF4C40
71695	7	71	\N	22854	51479	\N	59.417316443056599	Пермский край, Березниковский городской округ, Юбилейная, 139	Россия, Пермский край, Березники	0101000020E61000001A34F44F70694C407C0C569C6AB54D40
71691	7	71	\N	22854	51479	\N	59.404857689765201	Пермский край, Березниковский городской округ, Юбилейная, 88	Россия, Пермский край, Березники	0101000020E6100000E9D1544FE66B4C4011C30E63D2B34D40
71687	7	71	\N	22854	51479	\N	59.412476780073497	Пермский край, Березниковский городской округ, Юбилейная, 78	Россия, Пермский край, Березники	0101000020E610000083DDB06D51684C4015ADDC0BCCB44D40
71686	7	71	\N	22854	51479	\N	59.411541578740596	Пермский край, Березниковский городской округ, Юбилейная, 32	Россия, Пермский край, Березники	0101000020E61000006A865451BC684C4018778368ADB44D40
71704	7	71	\N	22854	51545	\N	59.424391492015801	Пермский край, Березниковский городской округ, Черняховского, 73	Россия, Пермский край, Березники	0101000020E610000015527E52ED6B4C40BEDBBC7152B64D40
71668	7	71	\N	22854	51428	\N	59.412722881380503	Пермский край, Березниковский городской округ, Химиков, 10	Россия, Пермский край, Березники	0101000020E6100000A94BC63192674C404CA7751BD4B44D40
71667	7	71	\N	22854	51428	\N	59.411891598648097	Пермский край, Березниковский городской округ, Химиков, 4	Россия, Пермский край, Березники	0101000020E6100000C078060DFD674C40F5BD86E0B8B44D40
71661	7	71	\N	22854	51426	\N	59.4103164804784	Пермский край, Березниковский городской округ, Тельмана, 12	Россия, Пермский край, Березники	0101000020E61000005260014C19664C404583143C85B44D40
71660	7	71	\N	22854	51426	\N	59.399594973744598	Пермский край, Березниковский городской округ, Тельмана, 7	Россия, Пермский край, Березники	0101000020E6100000AA0A0DC4B2634C409352D0ED25B34D40
71681	7	71	\N	22854	51493	\N	59.404606060895397	Пермский край, Березниковский городской округ, Советский проспект, 71	Россия, Пермский край, Березники	0101000020E6100000F3583332C8694C40F8E12021CAB34D40
71699	7	71	\N	22854	51468	\N	59.410371173313401	Пермский край, Березниковский городской округ, Свердлова, 126	Россия, Пермский край, Березники	0101000020E610000077BF0AF0DD6A4C40081D740987B44D40
71697	7	71	\N	22854	51468	\N	59.4097914247536	Пермский край, Березниковский городской округ, Свердлова, 65	Россия, Пермский край, Березники	0101000020E6100000F819170E84684C40FA980F0874B44D40
71679	7	71	\N	22854	51468	\N	59.414254138080501	Пермский край, Березниковский городской округ, Свердлова, 23а	Россия, Пермский край, Березники	0101000020E6100000D34A21904B6C4C405C1E6B4606B54D40
71684	7	71	\N	22854	51570	\N	59.420116021571303	Пермский край, Березниковский городской округ, Пятилетки, 106	Россия, Пермский край, Березники	0101000020E61000002E910BCEE0694C405F43705CC6B54D40
71665	7	71	\N	22854	51570	\N	59.414866621307297	Пермский край, Березниковский городской округ, Пятилетки, 11	Россия, Пермский край, Березники	0101000020E6100000D829560DC2664C404698A25C1AB54D40
71693	7	71	\N	22854	51549	\N	59.413641643737698	Пермский край, Березниковский городской округ, Потемина, 3	Россия, Пермский край, Березники	0101000020E61000007CB94F8E026A4C4043209738F2B44D40
71673	7	71	\N	22854	51757	\N	59.418016359461902	Пермский край, Березниковский городской округ, О. Кошевого, 7	Россия, Пермский край, Березники	0101000020E61000009C340D8AE6674C40359A5C8C81B54D40
71683	7	71	\N	22854	51476	\N	59.391288936247498	Пермский край, Березниковский городской округ, Набережная, 47	Россия, Пермский край, Березники	0101000020E6100000213F1BB96E6C4C406C2409C215B24D40
71702	7	71	\N	22854	51505	\N	59.413466643312198	Пермский край, Березниковский городской округ, Мира, 98а	Россия, Пермский край, Березники	0101000020E61000007EE36BCF2C694C40D47C957CECB44D40
71701	7	71	\N	22854	51505	\N	59.413291641979399	Пермский край, Березниковский городской округ, Мира, 110	Россия, Пермский край, Березники	0101000020E6100000946A9F8EC7684C4066D993C0E6B44D40
71694	7	71	\N	22854	51505	\N	59.416091554413299	Пермский край, Березниковский городской округ, Мира, 56	Россия, Пермский край, Березники	0101000020E61000003885950A2A684C404910AE8042B54D40
71690	7	71	\N	22854	51505	\N	59.414341636364902	Пермский край, Березниковский городской округ, Мира, 48	Россия, Пермский край, Березники	0101000020E6100000E4BCFF8F13684C40FBAD9D2809B54D40
71688	7	71	\N	22854	51505	\N	59.414341636364902	Пермский край, Березниковский городской округ, Мира, 30	Россия, Пермский край, Березники	0101000020E61000009694BBCFF1674C40FBAD9D2809B54D40
71705	7	71	\N	22854	51458	\N	59.412975816965002	Пермский край, Березниковский городской округ, Ломоносова, 114	Россия, Пермский край, Березники	0101000020E6100000D1ADD7F4A0664C403604C765DCB44D40
71698	7	71	\N	22854	51458	\N	59.415643146560399	Пермский край, Березниковский городской округ, Ломоносова, 125	Россия, Пермский край, Березники	0101000020E61000002CF52C08E5694C40DAE731CA33B54D40
71678	7	71	\N	22854	51458	\N	59.415774388499898	Пермский край, Березниковский городской округ, Ломоносова, 105	Россия, Пермский край, Березники	0101000020E6100000B7EC10FFB0694C4078431A1538B54D40
71677	7	71	\N	22854	51458	\N	59.419941054719303	Пермский край, Березниковский городской округ, Ломоносова, 60	Россия, Пермский край, Березники	0101000020E6100000AAF1D24D62684C40F19F6EA0C0B54D40
71670	7	71	\N	22854	51458	\N	59.4145713182821	Пермский край, Березниковский городской округ, Ломоносова, 115	Россия, Пермский край, Березники	0101000020E610000069C4CC3E8F694C405D6F9BA910B54D40
71664	7	71	\N	22854	51433	\N	59.430175089651698	Пермский край, Березниковский городской округ, Ленина проспект, 33	Россия, Пермский край, Березники	0101000020E61000000DFB3DB14E674C40454772F90FB74D40
71675	7	71	\N	22854	51552	\N	59.4036814967317	Пермский край, Березниковский городской округ, Л. Толстого, 50	Россия, Пермский край, Березники	0101000020E61000007DCA3159DC674C401F82AAD1ABB34D40
71692	7	71	\N	22854	51614	\N	59.410491497238397	Пермский край, Березниковский городской округ, Комсомольская, 4	Россия, Пермский край, Березники	0101000020E6100000EA5C514A08684C40B32616F88AB44D40
71671	7	71	\N	22854	51444	\N	59.428562560524803	Пермский край, Березниковский городской округ, Дощеникова, 4	Россия, Пермский край, Березники	0101000020E610000009A4C4AEED6B4C4048A30227DBB64D40
72696	7	71	\N	22854	64464	\N	59.4207283984084	п.Березники, ул.Восточная, д.1	Россия, Пермский край, Березники	0101000020E610000063EDEF6C8F664C407841446ADAB54D40
71676	7	71	\N	22854	51450	\N	59.417666317635003	Пермский край, Березниковский городской округ, В. Бирюковой, 9	Россия, Пермский край, Березники	0101000020E6100000BCAFCA85CA654C405853591476B54D40
71669	7	71	\N	22854	52178	\N	59.414516632253097	Пермский край, Березниковский городской округ, Аксакова, 18	Россия, Пермский край, Березники	0101000020E6100000EA5C514A08684C4069519FE40EB54D40
71662	7	71	\N	22854	51578	\N	59.419941000000001	Пермский край, Березниковский городской округ, Азотчиков, 18	Россия, Пермский край, Березники	0101000020E6100000CA6C904946664C40F19F6EA0C0B54D40
71685	7	71	\N	22854	51470	\N	59.412766632536098	Пермский край, Березниковский городской округ, 30 лет Победы, 38	Россия, Пермский край, Березники	0101000020E6100000B8AE9811DE684C401CEF8E8CD5B44D40
72085	7	71	\N	58148	\N	\N	58.254437002742598	д.Ананичи, Ананичевский дом досуга	Россия, Пермский край, Краснокамск городской округ, село Ананичи	0101000020E61000001FDB32E02CEB4B4039F2406491204D40
71593	7	71	\N	21403	52011	\N	59.162658	Пермский край, город Александровск, Советская, 97		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71592	7	71	\N	21403	52114	\N	59.162658	Пермский край, город Александровск, Пионерская, 10		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71600	7	71	\N	21403	51560	\N	59.162658	Пермский край, город Александровск, Мехоношина, 19		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71599	7	71	\N	21403	51558	\N	59.162658	Пермский край, город Александровск, Ленина, 19		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71597	7	71	\N	21403	51558	\N	59.162658	Пермский край, город Александровск, Ленина, 21		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71598	7	71	\N	21403	51671	\N	59.162658	Пермский край, город Александровск, Кирова, 39		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71595	7	71	\N	21403	52066	\N	59.162658	Пермский край, город Александровск, Калинина, 3		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71596	7	71	\N	21403	51415	\N	59.162658	Пермский край, город Александровск, Войкова, 20		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
71594	7	71	\N	21403	52062	\N	59.162658	Пермский край, город Александровск, III Интернационала, 32		0101000020E6100000C6C1A563CEC94C40653733FAD1944D40
73227	7	71	372	47147	\N	\N	59.195016000000003	п. Комсомольский, Здание сельского клуба	Россия, Пермский край, Юсьвинский район, поселок разрушенный Комсомольский	0101000020E61000007500C45DBDBA4B402F19C748F6984D40
73233	7	71	372	4808	54496	\N	58.962169000000003	с.Юсьва, Центральная, 2		0101000020E6100000179AEB34D27A4B40CE1C925A287B4D40
73232	7	71	372	4808	51667	\N	58.962169000000003	с.Юсьва, Красноармейская, 18		0101000020E6100000179AEB34D27A4B40CE1C925A287B4D40
73231	7	71	372	4808	51667	\N	58.962169000000003	с.Юсьва, красноармейская, 14		0101000020E6100000179AEB34D27A4B40CE1C925A287B4D40
73239	7	71	372	5179	54500	\N	59.051493999999998	д.Чинагорт, Центральная, 109		0101000020E61000006F4562821A804B4059F8FA5A97864D40
73247	7	71	372	5648	54571	\N	59.180298000000001	п.Тукачево, Комсомольская, д. 2, кв. 1		0101000020E6100000C1E44691B5C84B4061C43E0114974D40
73246	7	71	372	58336	64750	\N	59.093749438556102	с.Тимино, Парковая, 9	Россия, Пермский край, Юсьвинский район, село Тимино	0101000020E61000005DF8C1F9D4B54B4030849CF7FF8B4D40
73253	7	71	372	5907	51731	\N	59.083629999999999	п.Пожва, Судомеханическая, 9		0101000020E6100000548CF337A10A4C40747B4963B48A4D40
73252	7	71	372	5907	51777	\N	59.089205073000798	п.Пожва, Ленина, 59	Россия, Пермский край, Юсьвинский район, поселок Пожва	0101000020E6100000C1745AB7410B4C40E1D1C6116B8B4D40
73243	7	71	372	5399	54513	\N	59.089334999999998	д.Пиканово, Центральная, 62		0101000020E6100000A3E9EC64709C4B40AFB14B546F8B4D40
73248	7	71	372	5672	52998	\N	59.011206999999999	с.Они, Центральная, 55		0101000020E6100000D99942E735DC4B403E3E213B6F814D40
73240	7	71	372	58290	64599	\N	59.093299687173499	д.НижняяВолпа, Центральная, 56		0101000020E6100000F7B0170AD8804B40C05B2041F18B4D40
73237	7	71	372	5092	52045	\N	58.87529	с.Мелюхино, Центральная, 7		0101000020E61000004A287D21E46A4B400742B28009704D40
73251	7	71	372	5748	52103	\N	59.004252000000001	п.Майкор, Октябрьская, 108		0101000020E6100000B0AD9FFEB3F04B40A7785C548B804D40
73249	7	71	372	5748	53738	\N	59.004252000000001	п.Майкор, Ленина, 98		0101000020E6100000B0AD9FFEB3F04B40A7785C548B804D40
69437	7	71	372	7097	54533	\N	58.987434	с.Купрос, Школьная, 1		0101000020E61000005D15A8C5E0C14B40AF7AC03C647E4D40
73244	7	71	372	5458	54479	\N	58.944569000000001	с.Крохалево, Центральная, 56		0101000020E61000007C8159A148B54B4060E811A3E7784D40
73010	7	71	372	56223	\N	\N	59.195016000000003	п. Комсомольский, Центр досуга		0101000020E61000007500C45DBDBA4B402F19C748F6984D40
73009	7	71	372	56223	\N	\N	59.195016000000003	п. Комсомольский, Администрация сельского поселения		0101000020E61000007500C45DBDBA4B402F19C748F6984D40
72968	7	71	372	56272	52073	\N	59.075271464811799	п.Калино, ул.Трудовая, д.12, центр досуга	Россия, Пермский край, Юсьвинский район, село Калино	0101000020E610000030F2B22616B64B402AABE97AA2894D40
73242	7	71	372	5353	54535	\N	59.052193000000003	с.Доег, Школьная, 3		0101000020E610000061FD9FC37C9F4B40420A9E42AE864D40
73226	7	71	372	56515	54271	\N	58.995681817970599	д.БольшаяМочга, Садовая, 3	Россия, Пермский край, Юсьвинский район, село Большая Мочга	0101000020E61000000A11700855CC4B40A29BFD81727F4D40
73236	7	71	372	47314	64536	\N	58.973860000000002	с.Бажино, Центральная, 39		0101000020E6100000F60D4C6E14914B40F870C971A77C4D40
73238	7	71	372	47368	52106	\N	59.031379999999999	с.Архангельское, Центральная, 43		0101000020E6100000ACC77DAB757C4B40CEDF844204844D40
73241	7	71	372	47436	52137	\N	59.019134000000001	с.Антипино, Мира, 4		0101000020E610000059880E8123954B40EF1EA0FB72824D40
73245	7	71	372	5498	64749	\N	58.988323999999999	с.Аксеново, Школьная, 2		0101000020E6100000D3669C86A8AE4B400BED9C66817E4D40
71944	7	71	372	56328	52246	\N	59.091219919799101	Азово, Совхозная, 4	Россия, Пермский край, Юсьвинский район, село Азово	0101000020E61000004ED1915CFEC54B40DD5ED218AD8B4D40
69285	7	71	562	3504	51557	\N	59.326827999999999	с. Юрла, Пионеров, 5		0101000020E6100000A8C5E061DA274B4063B5F97FD5A94D40
73207	7	71	562	3504	54426	\N	59.326827999999999	с. Юрла, Кузнецова,20		0101000020E6100000A8C5E061DA274B4063B5F97FD5A94D40
73208	7	71	562	3504	51445	\N	59.326827999999999	с. Юрла, Гагарина, 18		0101000020E6100000A8C5E061DA274B4063B5F97FD5A94D40
73218	7	71	562	58210	\N	\N	59.399747905647601	с. Юм, Здание сельского Дома Досуга	Россия, Пермский край, Юрлинский район, село Юм	0101000020E61000005B5EB9DE360B4B401A5245F12AB34D40
73224	7	71	562	4413	\N	\N	59.196237000000004	п. Чус, Здание МОУ Чусовская ООШ	Россия, Пермский край, Юрлинский район, село Чус	0101000020E6100000ADC090D5ADD44A40F1A1444B1E994D40
73219	7	71	562	4159	\N	\N	59.421515999999997	д. Чужья, Здание Чужьинского территориального участка	Россия, Пермский край, Юрлинский район, село Чужья	0101000020E6100000CDE67118CC1F4B40D05E7D3CF4B54D40
73230	7	71	562	56396	\N	\N	59.385213801882998	п. Чугайнов Хутор, Здание МОУ Сюрольская ООШ	Россия, Пермский край, Юрлинский район, село Чугайнов Хутор	0101000020E6100000E7C75F5AD4654B400DFB3DB14EB14D40
73215	7	71	562	3901	\N	\N	59.443958000000002	с. УстьЗула, Здание сельского Дома Досуга	Россия, Пермский край, Юрлинский район, село Усть-Зула	0101000020E610000002F04FA9123F4B401766A19DD3B84D40
72970	7	71	1738	24215	\N	\N	58.223039249818697	д.Вереино, Клуб	Россия, Пермский край, Чусовой городской округ, село Вереино	0101000020E61000005CCCCF0D4DB74C40C45DBD8A8C1C4D40
73228	7	71	562	47149	\N	\N	59.586886999999997	п. УстьБерезовка, Здание УстьБерезовского сельского поселения	Россия, Пермский край, Юрлинский район, село Усть-Березовка	0101000020E6100000546F0D6C95D44A4049B9FB1C1FCB4D40
73211	7	71	562	46800	\N	\N	59.254170999999999	д. Титова, Здание сельского Дома Досуга	Россия, Пермский край, Юрлинский район, село Титова	0101000020E610000075E789E76C214B40BA4BE2AC88A04D40
73217	7	71	562	4014	\N	\N	59.425978999999998	д. Пож, Здание Пожинского территориального участка	Россия, Пермский край, Юрлинский район, село Пож	0101000020E6100000158BDF1456524B4032E4D87A86B64D40
73225	7	71	562	4433	\N	\N	59.421368999999999	д. Петракова, Здание сельского клуба	Россия, Пермский край, Юрлинский район, село Петракова	0101000020E6100000BFB9BF7ADCF54A402C465D6BEFB54D40
73212	7	71	562	58208	\N	\N	59.240764554949003	д. Остров, Здание ФАП	Россия, Пермский край, Юрлинский район, село Остров	0101000020E6100000AE8218E8DA274B40BF823463D19E4D40
73210	7	71	562	3640	\N	\N	59.296272000000002	д. Лопва, Здание сельского клуба	Россия, Пермский край, Юрлинский район, село Лопва	0101000020E6100000EA5A7B9FAA204B403A5CAB3DECA54D40
73220	7	71	562	4168	\N	\N	59.444233537702601	д. Келич, Здание сельского клуба	Россия, Пермский край, Юрлинский район, село Келич	0101000020E610000095D6DF1280134B40B9E2E2A8DCB84D40
73209	7	71	562	3632	\N	\N	59.274912999999998	д. Зюздина, Здание начальной школы	Россия, Пермский край, Юрлинский район, село Зюздина	0101000020E6100000780DFAD2DB274B40641F645930A34D40
73222	7	71	562	47038	\N	\N	59.269469000000001	д. Зарубина, Здание сельского клуба	Россия, Пермский край, Юрлинский район, село Зарубина	0101000020E61000002A029CDEC5FF4A409624CFF57DA24D40
73223	7	71	562	47053	\N	\N	59.333397031912902	д. Елога, Здание Елогского территориального участка	Россия, Пермский край, Юрлинский район, село Елога	0101000020E6100000FB5A971AA1F54A40D1CABDC0ACAA4D40
73221	7	71	562	47015	\N	\N	59.274236999999999	д. Дубровка, Здание Дубровского территориального участка	Россия, Пермский край, Юрлинский район, село Дубровка	0101000020E6100000B344679945064B40342DB1321AA34D40
73213	7	71	562	3817	\N	\N	59.275602999999997	д. Вятчина, Здание Вятчинского территориального участка	Россия, Пермский край, Юрлинский район, село Вятчина	0101000020E6100000BA8784EFFD434B40F9D687F546A34D40
73216	7	71	562	3942	\N	\N	59.403877000000001	д. Верхняя Лобанова, Здание сельского клуба	Россия, Пермский край, Юрлинский район, село Верхняя Лобанова	0101000020E61000002C9D0FCF123A4B40A54DD53DB2B34D40
73214	7	71	562	3842	\N	\N	59.324427	д.Большая Половина, Сельский клуб		0101000020E61000004E637B2DE8434B403E78EDD286A94D40
72990	7	71	1738	46810	\N	\N	58.220936999999999	п.Центральный, Клуб		0101000020E6100000F67CCD72D9A84C40F9BCE2A9471C4D40
72981	7	71	1738	46810	\N	\N	58.220936999999999	"""п.Центральный, МУК """"Никифоровский ДК"""""""		0101000020E6100000F67CCD72D9A84C40F9BCE2A9471C4D40
72986	7	71	1738	46913	\N	\N	58.4325068250198	п.Утес, Здание Утесовской администрации	Россия, Пермский край, Чусовой городской округ, село Утес	0101000020E61000007D7901F6D1DF4C404225AE635C374D40
72977	7	71	1738	24578	\N	\N	58.161572999999997	"""с.Сёла, МУК """"Сёльский КДЦ"""""""		0101000020E6100000A7583508739F4C4053758F6CAE144D40
73059	7	71	1738	24578	63748	\N	58.161572999999997	д.Сёла, ул.Новая, д.1		0101000020E6100000A7583508739F4C4053758F6CAE144D40
72987	7	71	1738	25029	\N	\N	58.363802999999997	"""п.Скальный, МУК """"Скальнинский Дом культуры"""""""		0101000020E610000057B5A4A31CFC4C40E597C118912E4D40
72980	7	71	1738	56305	\N	\N	58.2077045976081	с.Никифорово, здание администрации Никифоровского сельского поселения	Россия, Пермский край, Чусовой городской округ, село Никифорово	0101000020E61000007380608E1E994C409B1BD313961A4D40
72971	7	71	1738	24249	\N	\N	58.279769999999999	д.Мульково, Фельдшерскоакушерский пункт		0101000020E610000086048C2E6FCE4C407233DC80CF234D40
72967	7	71	1738	23986	51773	\N	58.277368126494103	п.Лямино, ул.Первомайская, д.11	Россия, Пермский край, Чусовой городской округ, поселок Лямино	0101000020E61000005131CEDF84DE4C407D7A6CCB80234D40
72966	7	71	1738	23986	51773	\N	58.278269999999999	п.Лямино, Первомайская, д.2, поликлиника		0101000020E6100000FF3F4E9830DC4C409DBAF2599E234D40
72965	7	71	1738	23986	52053	\N	58.277639412610398	п.Лямино, ул.Мира, д.3, контора мастера Ляминского ЖЭУ	Россия, Пермский край, Чусовой городской округ, поселок Лямино	0101000020E61000002DAF5C6F9BDD4C400D8CBCAC89234D40
72973	7	71	1738	24372	\N	\N	58.102119999999999	"""пос.Кутамыш, филиал МУК """"Комарихинский ДК"""""""		0101000020E61000003FE5982CEEA34C403E22A644120D4D40
72982	7	71	1738	24812	\N	\N	58.294965963764	с.Копально, здание Копалинской школы	Россия, Пермский край, Чусовой городской округ, село Копально	0101000020E61000004ACE893DB4C14C404AB72572C1254D40
72975	7	71	1738	24382	\N	\N	58.096336999999998	"""п.Комарихинский, МУК """"Комарихинский дом культуры"""""""		0101000020E6100000EA76F695078F4C40873254C5540C4D40
72974	7	71	1738	24382	\N	\N	58.0964275379866	п.Комарихинский, школа № 91 пос.Комарихинский	Россия, Пермский край, Чусовой городской округ, поселок Комарихинский	0101000020E610000067994528B68E4C409835B1C0570C4D40
72969	7	71	1738	24131	51774	\N	58.249761999999997	п.Калино, ул.Заводская, д.1А, здание администрации		0101000020E6100000A0C211A452CE4C404BE48233F81F4D40
72989	7	71	1738	25123	\N	\N	58.357886999999998	"""п.Всесвятская, МУК """"Скальнинский Дом культуры"""""""		0101000020E61000002CD7DB662A084D40EF54C03DCF2D4D40
72991	7	71	1738	24589	\N	\N	58.169401999999998	"""п.Верхнечусовские Городки, МУК """"Верхнегородковский Дом культуры"""""""		0101000020E6100000B075A911FA8B4C4041F0F8F6AE154D40
72978	7	71	1738	24589	\N	\N	58.169401999999998	п.Верхнечусовские Городки, здание администрации  ВГородковского сельского поселения	Россия, Пермский край, Чусовой городской округ, поселок Верхнечусовские Городки	0101000020E6100000B075A911FA8B4C4041F0F8F6AE154D40
72983	7	71	1738	24841	\N	\N	58.308869000000001	с.Верхнее Калино, Дом культуры		0101000020E6100000AF97A60870D44C40C6DFF60489274D40
72080	7	71	1738	40395	\N	\N	58.208221999999999	д.Брагино,  Дом досуга д.Брагино		0101000020E6100000C39ACAA2B0934C406327BC04A71A4D40
72984	7	71	1738	46852	\N	\N	58.313842000000001	п.Бобровка, Фельдшерскоакушерский пункт		0101000020E6100000C39FE1CD1AA64C403D0E83F92B284D40
73163	7	71	1738	48506	52197	\N	58.0865454423095	п. Березовка, Парковая, 2	Россия, Пермский край, Чусовой городской округ, поселок Березовка	0101000020E610000072193735D08A4C40F05014E8130B4D40
72914	7	71	1652	20947	51725	\N	56.495052000000001	г.Чернушка, бульвар 48 Стрелковой Бригады, 1		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72913	7	71	1652	20947	51517	\N	56.495052000000001	г.Чернушка, ул.Юбилейная, 10		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72900	7	71	1652	20947	51748	\N	56.495052000000001	г.Чернушка, ул.Пушкина, 4А		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72909	7	71	1652	20947	51768	\N	56.495813759089998	г.Чернушка, ул.Нефтяников, 3	Россия, Пермский край, Чернушинский район, Чернушка	0101000020E6100000423F53AF5B0C4C40117349D5763F4C40
72905	7	71	1652	20947	52085	\N	56.495052000000001	г.Чернушка, ул.Мира, 36		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72901	7	71	1652	20947	51654	\N	56.495052000000001	г.Чернушка, ул.Луначарского		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72916	7	71	1652	20947	51657	\N	56.495052000000001	г.Чернушка, ул.Ленина, 133		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72911	7	71	1652	20947	51657	\N	56.495052000000001	г.Чернушка, ул.Ленина, 42		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72904	7	71	1652	20947	51657	\N	56.495052000000001	г.Чернушка, ул.Ленина, 6		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72908	7	71	1652	20947	51518	\N	56.495052000000001	г.Чернушка, ул.Красноармейская, 96		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72902	7	71	1652	20947	51554	\N	56.495052000000001	г.Чернушка, ул.Комсомольская, 36		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72912	7	71	1652	20947	51659	\N	56.495052000000001	г.Чернушка, ул.Коммунистическая, 17Б		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72910	7	71	1652	20947	51659	\N	56.495052000000001	г.Чернушка, ул.Коммунистическая, 33		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72903	7	71	1652	20947	51765	\N	56.495052000000001	г.Чернушка, ул.Горького, 50		0101000020E61000007BBE66B96C0C4C40E2E82ADD5D3F4C40
72938	7	71	1652	22695	\N	\N	56.521996868107401	с.Тюй, Администрация	Россия, Пермский край, Чернушинский район, село Тюй	0101000020E61000005FEE93A3003F4C4018CE35CCD0424C40
72936	7	71	1652	56281	\N	\N	56.369870106927898	с.Трушники, Дом культуры	Россия, Пермский край, Чернушинский район, село Трушники	0101000020E6100000876F61DD78074C40C1E270E6572F4C40
72934	7	71	1652	56278	\N	\N	56.431782132364702	с.Трун, Администрация	Россия, Пермский край, Чернушинский район, село Трун	0101000020E610000074B680D07A2A4C403080F0A144374C40
72933	7	71	1652	22493	\N	\N	56.427802	с.Тауш, Администрация		0101000020E6100000B18BA2073E0A4C40EA944737C2364C40
72932	7	71	1652	22433	\N	\N	56.552834458740399	с.Сульмаш, Администрация	Россия, Пермский край, Чернушинский район, село Сульмаш	0101000020E61000002BFBAE08FE094C40F50EB743C3464C40
72931	7	71	1652	62090	\N	\N	56.468716496105898	с.Слудка, Школа	Россия, Пермский край, Чернушинский район, село Слудка	0101000020E6100000E44EE960FDFD4B40548EC9E2FE3B4C40
72930	7	71	1652	22373	\N	\N	56.578389000000001	с.Рябки, Администрация		0101000020E6100000164B917C251C4C40DEAE97A6084A4C40
72926	7	71	1652	56297	\N	\N	56.493688700177998	с.Павловка, Дом культуры	Россия, Пермский край, Чернушинский район, село Павловка	0101000020E61000007DCEDDAE971A4C408EB27E33313F4C40
72939	7	71	1652	22768	\N	\N	56.4763009566935	с.Ореховая Гора, Администрация	Россия, Пермский край, Чернушинский район, село Ореховая Гора	0101000020E6100000828C800A472A4C40AB06616EF73C4C40
72927	7	71	1652	22245	\N	\N	56.526705999999997	с.Нижний Козьмяш, Администрация	Россия, Пермский край, Чернушинский район, село Нижний Козьмяш	0101000020E6100000E99E758D96294C40B14D2A1A6B434C40
72320	7	71	1652	56351	52323	\N	56.615582046467999	с.Комарово, Школьная, 1	Россия, Пермский край, Чернушинский район, село Комарово	0101000020E6100000F0F8F6AE41EB4B40CE001764CB4E4C40
72753	7	71	1652	58255	64529	\N	56.641174600344499	с. Ключи, Золина, 59	Россия, Пермский край, Чернушинский район, село Ключи	0101000020E6100000D993C0E61C2E4C40A301BC0512524C40
71898	7	71	1652	56355	62861	\N	56.692854997348299	с. Калиновка,  ул. Центральная, д. 10/2, здание Дома Досуга		0101000020E61000000AA359D93E284C405FEFFE78AF584C40
72918	7	71	1652	56484	\N	\N	56.545846818352402	д.Зверево, Клуб	Россия, Пермский край, Чернушинский район, село Зверево	0101000020E6100000651BB80375124C4053CF8250DE454C40
72924	7	71	1652	22082	\N	\N	56.395464098210603	с.Етыш, Администрация	Россия, Пермский край, Чернушинский район, село Етыш	0101000020E6100000A6D1E4620C164C40675F79909E324C40
72935	7	71	1652	22586	\N	\N	56.355902824429997	с.Есаул, Дом культуры		0101000020E610000001DF6DDE38254C402EC6C03A8E2D4C40
72937	7	71	1652	58273	\N	\N	56.322991731687701	д.ЕмашПавлово, Клуб	Россия, Пермский край, Чернушинский район, село Емаш-Павлово	0101000020E61000001AE0826C590C4C40506F46CD57294C40
72922	7	71	1652	62091	\N	\N	56.5233200526242	с.Брод, Клуб	Россия, Пермский край, Чернушинский район, село Брод	0101000020E6100000F6402B3064FF4B40DEAB5626FC424C40
72921	7	71	1652	21962	\N	\N	56.575315748451601	с.Бедряж, Администрация	Россия, Пермский край, Чернушинский район, село Бедряж	0101000020E6100000F6D214014EF14B40CA6E66F4A3494C40
72929	7	71	1652	22338	\N	\N	56.503174999999999	д.Ашша, Клуб	Россия, Пермский край, Чернушинский район, село Ашша	0101000020E61000002D793C2D3F104C401895D40968404C40
72928	7	71	1652	56349	\N	\N	56.446405781021099	д.Атняшка, Клуб	Россия, Пермский край, Чернушинский район, село Атняшка	0101000020E61000009DD9AED007174C407D5EF1D423394C40
72919	7	71	1652	56380	\N	\N	56.604393744645499	с.Ананьино, Администрация	Россия, Пермский край, Чернушинский район, село Ананьино	0101000020E61000001D93C5FD47084C4006F357C85C4D4C40
72917	7	71	1652	56254	51872	\N	56.523627677111101	пос.Азинский, ул.Буденного, 16	Россия, Пермский край, Чернушинский район, село усадьба 105-го Конезавода	0101000020E61000002CBAF59A1E084C408CA2073E06434C40
72992	7	71	456	23048	\N	\N	61.131711000000003	Пермский край, Чусовской муниципальный район, Чусовское городское поселение, пос. Совхозный, Детский сад № 2		0101000020E61000009B046F48A3564C4001C3F2E7DB904E40
72946	7	71	456	23048	52140	\N	61.131711000000003	Пермский край, Чусовской муниципальный район, Чусовское городское поселение, Бажова, 17, Конференцзал Вагонного депо		0101000020E61000009B046F48A3564C4001C3F2E7DB904E40
72876	7	71	456	19585	51655	\N	60.398988000000003	г.Чердынь, Яборова, 8		0101000020E6100000912BF52C083D4C408CBFED0912334E40
72877	7	71	456	19585	51721	\N	60.398988000000003	г.Чердынь, Успенская, 59		0101000020E6100000912BF52C083D4C408CBFED0912334E40
72878	7	71	456	19585	51722	\N	60.398988000000003	г.Чердынь, Прокопьевская, 83		0101000020E6100000912BF52C083D4C408CBFED0912334E40
72889	7	71	456	20337	52333	\N	60.425288999999999	п.Чепец, Центральная, клуб		0101000020E61000005E0F26C5C7D14B409D2CB5DE6F364E40
72887	7	71	456	56409	53181	\N	60.333267540195898	д.Урол, Вторая, 5	Россия, Пермский край, Чердынский район, село Урол	0101000020E610000000378B170B2B4C40D3669C86A82A4E40
73110	7	71	456	49198	\N	\N	61.425547000000002	пос.Сосновка, Косинская СОШ		0101000020E61000004E61A5828A724C4099F4F75278B64E40
72886	7	71	456	32976	52320	\N	60.368794999999999	с.Серегово, Героев, 35	Россия, Пермский край, Чердынский район, село Серегово	0101000020E61000009CA4F9635A414C40D3F6AFAC342F4E40
73094	7	71	456	48463	64743	\N	60.980927856700497	п.Серебрянка, ул.Набережная,24а, СОШ	Россия, Пермский край, Чердынский район, село Серебрянка	0101000020E6100000CF4BC5C6BCE24B4087DD770C8F7D4E40
72885	7	71	456	20102	51724	\N	60.321069000000001	п.Рябинино, Ленина, 20		0101000020E61000007B8670CCB23F4C403561FBC918294E40
72884	7	71	456	19982	52291	\N	60.186931000000001	с.Редикор, Набережная, 30		0101000020E6100000EE98BA2BBB3A4C40E6CDE15AED174E40
72883	7	71	456	8832	52337	\N	60.153948	с.Пянтег, ул.Набережная, 31		0101000020E6100000F0C4AC1743214C406EA46C91B4134E40
72895	7	71	456	20683	52082	\N	60.452407000000001	с.Покча, Мира, 32		0101000020E61000009FAC18AE0E3A4C40A1BDFA78E8394E40
72891	7	71	456	13987	52286	\N	60.825862000000001	"""п.Пильва, Школьная, МОУ """"Пильвинская школасад"""""""		0101000020E6100000CF9ECBD424024C402C8194D8B5694E40
72104	7	71	456	13987	64551	\N	60.825903885286301	д. Пильва, ул. Складская, 13	Россия, Пермский край, Чердынский район, село Пильва	0101000020E6100000A452EC681C024C405BD1E638B7694E40
72879	7	71	456	19766	52153	\N	60.732954999999997	п.Ныроб, Уральская, 13		0101000020E6100000F10F5B7A345B4C4047382D78D15D4E40
72881	7	71	456	19766	51656	\N	60.732954999999997	пос.Ныроб, Уждавиниса, 11		0101000020E6100000F10F5B7A345B4C4047382D78D15D4E40
72880	7	71	456	19766	51656	\N	60.732954999999997	п.Ныроб, Уждавиниса, 11		0101000020E6100000F10F5B7A345B4C4047382D78D15D4E40
72896	7	71	456	58909	\N	\N	60.422519926642501	пос.Кушмангорт, штаб ФБУ ОИК19 ГУФСИН РФ по ПК	Россия, Пермский край, Чердынский район	0101000020E610000094A30051300D4C40F5F3A62215364E40
72893	7	71	456	56331	52268	\N	60.166733564283803	п.Курган, Центральная, 7	Россия, Пермский край, Чердынский район, село Курган	0101000020E6100000404F030649114C40CD902A8A57154E40
68575	7	71	456	58905	66983	\N	60.103466729556096	д.Коэпты, Камская, 7	Россия, Пермский край, Чердынский район, село Коэлпы	0101000020E61000003CF54883DB204C408D9B1A683E0D4E40
72897	7	71	456	20788	53634	\N	60.402653999999998	с.Кольчуг, Центральная, 5		0101000020E610000038F4160FEF154C4042CD902A8A334E40
72882	7	71	456	2657	51536	\N	59.947693999999998	пос.Керчевский, Пушкина, 12		0101000020E610000017BCE82B48254C40C64E78094EF94D40
65943	7	71	456	2657	51536	\N	59.947693999999998	п.Керчевский, Пушкина, 12		0101000020E610000017BCE82B48254C40C64E78094EF94D40
65499	7	71	456	13299	64389	\N	60.648851372917498	с.Искор, Молодёжная, 12	Россия, Пермский край, Чердынский район, село Искор	0101000020E610000063D34A2190594C400B7DB08C0D534E40
66815	7	71	456	56368	\N	\N	59.922044882434903	п.Гремячево, клуб	Россия, Пермский край, Чердынский район, село Гремячево	0101000020E6100000AAD216D7F82C4C405C38109205F64D40
72890	7	71	456	20416	52169	\N	60.561005000000002	с.Вильгорт, Трактовая, 1		0101000020E6100000E63DCE34613B4C403DF20703CF474E40
72899	7	71	456	20884	52049	\N	61.130512000000003	п.Верхняя Колва, Набережная, 22		0101000020E61000004EB340BB43A04C4027DE019EB4904E40
72898	7	71	456	20838	53633	\N	60.829721999999997	п.Валай, Советская, 17		0101000020E61000008A743FA720BF4C40C7629B54346A4E40
72888	7	71	456	20241	52167	\N	60.4900589720976	с.Бондюг, Красноармейская, 21	Россия, Пермский край, Чердынский район, село Бондюг	0101000020E6100000CF4BC5C6BCF64B40240ED940BA3E4E40
72894	7	71	456	20608	52272	\N	60.275843999999999	с.Большие Долды, Советская, 28		0101000020E6100000B3B5BE48680F4C401F662FDB4E234E40
71714	7	71	456	56244	51778	\N	59.995814506791497	село Березовка, Пролетарская, 26 Клуб Энтузиаст	Россия, Пермский край, Чердынский район, село Березовка	0101000020E610000029266F8099EB4B40E1EEACDD76FF4D40
72872	7	71	1553	32877	53629	\N	57.410648999999999	с.Шлыки, ул.Спортивная, д.18		0101000020E61000001A14CD03586A4B404B917C2590B44C40
72871	7	71	1553	19324	52044	\N	57.375174999999999	д.Шабуры, ул.Школьная, д.7		0101000020E610000003EFE4D363674B406EA301BC05B04C40
72858	7	71	1553	18552	52171	\N	57.2950059916082	с.Частые, ул.Нагорная, д.3	Россия, Пермский край, Частинский район, село Частые	0101000020E6100000B3EC4960737C4B40D80FB1C1C2A54C40
72857	7	71	1553	18552	51653	\N	57.292493999999998	с.Частые, ул.Ленина, д.70		0101000020E610000014CC9882357C4B405B23827170A54C40
72856	7	71	1553	18552	51653	\N	57.292493999999998	с.Частые, ул.Ленина, д.38		0101000020E610000014CC9882357C4B405B23827170A54C40
72864	7	71	1553	18984	52264	\N	57.214438000000001	д.Средняя Головниха, ул.Центральная, д.21		0101000020E61000004D2EC6C03A724B40848252B4729B4C40
72874	7	71	1553	32890	52266	\N	57.555773000000002	с.Пихтовка, ул.Школьная, д.3		0101000020E6100000111B2C9CA4774B40FA7FD59123C74C40
72869	7	71	1553	19243	52330	\N	57.124549999999999	д.Пермяковка, ул.Центральная, д.11		0101000020E6100000D32EA699EE394B40C05B2041F18F4C40
72865	7	71	1553	19022	52067	\N	57.096499000000001	с.Ножовка, ул.Энтузиастов, д.6А		0101000020E61000004FE960FD9F5F4B40618C48145A8C4C40
72866	7	71	1553	19022	52076	\N	57.096499000000001	с.Ножовка, ул.Чапаева, д.1		0101000020E61000004FE960FD9F5F4B40618C48145A8C4C40
72875	7	71	1553	32909	\N	\N	57.445678000000001	с.Меркуши, ул.Куйбышева, д.9		0101000020E610000055850662D9884B40FA4509FA0BB94C40
72860	7	71	1553	32796	52325	\N	57.272469999999998	д.Мельничная, ул.Октябрьская, д.42		0101000020E61000009F01F566D4724B401092054CE0A24C40
72862	7	71	1553	32808	52265	\N	57.227716999999998	д.Кленовая, ул.Советская, д.25		0101000020E6100000B70BCD751A5D4B4022DFA5D4259D4C40
72863	7	71	1553	18918	52335	\N	57.166057000000002	с.Змеевка, ул.Школьная, д.9	Россия, Пермский край, Частинский район, село Змеевка	0101000020E6100000992A1895D4774B40CD22145B41954C40
73067	7	71	1832	28692	52288	\N	59.531471000000003	п.Усовский, ул.Центральная, д.16		0101000020E610000022FB20CB826B4C40DFE2E13D07C44D40
72861	7	71	1553	58256	\N	\N	57.298211330346497	д.Западная, д.44А	Россия, Пермский край, Частинский район, село Западная	0101000020E6100000AF230ED940704B405B272EC72BA64C40
72873	7	71	1553	19424	54003	\N	57.46461	д.Ельшата, ул.Механизаторов, д.8		0101000020E6100000FE7DC685035D4B4081B2295778BB4C40
72867	7	71	1553	58286	64588	\N	57.142242347356401	с.ВерхРождество, ул.Школьная, д.16	Россия, Пермский край, Частинский район, село Верхнее Рождество	0101000020E6100000EE5A423EE85D4B400F0F61FC34924C40
72870	7	71	1553	32866	52458	\N	57.138139477627703	д.Бугры, ул.Уральская, д.36	Россия, Пермский край, Частинский район, село Бугры	0101000020E6100000897D022846464B40ADA6EB89AE914C40
14699	7	71	7405	56237	\N	\N	56.637502854502401	п.Марковский, д.34	Россия, Пермский край, Чайковский городской округ, село Марково	0101000020E610000093FFC9DFBD0B4B400B0DC4B299514C40
72850	7	71	7405	56235	51669	\N	56.727319000000001	с.Альняш, ул.Ленина, д.92		0101000020E610000095F25A09DD5D4B403561FBC9185D4C40
72847	7	71	716	18096	52063	\N	56.719784869469201	д. Чумна, ул.Звездная, д.14	Россия, Пермский край, Чайковский городской округ, село Чумна	0101000020E6100000346612F582354B40609335EA215C4C40
72846	7	71	716	4995	51652	\N	56.692293999999997	с.Фоки, ул.Кирова, д.49		0101000020E6100000529ACDE3302E4B40C79BFC169D584C40
72849	7	71	716	48681	52065	\N	56.445016000000003	с. Уральское, ул. Школьная, 5		0101000020E61000000742B28009324B402F19C748F6384C40
72852	7	71	716	18327	52147	\N	56.681269999999998	с.Сосново, ул. Школьная, 33		0101000020E61000004FB0FF3A37494B407ADFF8DA33574C40
72851	7	71	716	18281	52329	\N	56.736739462540498	д.Маракуши, ул.Новая, д.5	Россия, Пермский край, Чайковский городской округ, село Маракуши	0101000020E610000061FA5E4370464B400858AB764D5E4C40
72843	7	71	716	17908	52030	\N	56.667627642479999	с.Кемуль, ул.Комсомольская, д.10	Россия, Пермский край, Чайковский городской округ, село Кемуль	0101000020E61000004B3B35971BFA4A406BF294D574554C40
72854	7	71	716	18442	52149	\N	56.596637375862997	с.Зипуново, ул.Зеленая, д.7	Россия, Пермский край, Чайковский городской округ, село Зипуново	0101000020E61000009D4A06802A424B40B24AE9995E4C4C40
72833	7	71	716	17406	52283	\N	56.855005942363903	д.Засечный, ул.Мира, д.30	Россия, Пермский край, Чайковский городской округ, село Засечный	0101000020E610000061A5828AAA394B4020F12BD6706D4C40
72848	7	71	716	56434	53626	\N	56.526951622113202	д.Завод Михайловский, ул.Пролетарская, д.40	Россия, Пермский край, Чайковский городской округ, село Завод Михайловский	0101000020E6100000E0A0BDFA78244B40E947C32973434C40
72845	7	71	716	56330	52262	\N	56.712690839195403	г.Гаревая, ул.Октябрьская, д.7	Россия, Пермский край, Чайковский городской округ, село Гаревая	0101000020E6100000E2CAD93BA3254B40A7936C75395B4C40
72834	7	71	716	17422	52023	\N	56.889468089979303	с.Вассята, ул.Советская, д.4	Россия, Пермский край, Чайковский городской округ, село Вассята	0101000020E61000006B0E10CCD1474B40556B6116DA714C40
72832	7	71	716	56262	52025	\N	56.842546633050802	с.Ваньки, ул.Молодежная, д.10	Россия, Пермский край, Чайковский городской округ, село Ваньки	0101000020E6100000C6A354C213304B40E52B8194D86B4C40
72408	7	71	716	56262	52215	\N	56.8448044380007	д. Ванюки, у.Зеленая, д.35а	Россия, Пермский край, Чайковский городской округ, село Ваньки	0101000020E61000002B155454FD2E4B40D7C39789226C4C40
72853	7	71	716	18370	52148	\N	56.546951999999997	п.Буренка, ул.Гаражная, д.10	Россия, Пермский край, Чайковский городской округ, село Буренка	0101000020E6100000CE1951DA1B464B40AB3DEC8502464C40
72844	7	71	716	17916	51720	\N	56.662832000000002	с.Большой Букор, ул.Победы, д.12		0101000020E6100000213D450E11214B40035FD1ADD7544C40
14626	7	71	572	32528	52326	\N	59.607411999999997	с.Щекино, Пионерская, 4		0101000020E6100000404CC2853CEA4B40569929ADBFCD4D40
72805	7	71	572	16003	52260	\N	59.369681999999997	п.Шемейный, Школьная, 8		0101000020E61000001C412AC58E084C40BEF561BD51AF4D40
72731	7	71	572	12489	52322	\N	59.399599000000002	п.Турлавы, Центральная, 42		0101000020E610000015A8C5E0613C4C40D5415E0F26B34D40
71890	7	71	572	3553	\N	\N	59.5950310238958	с. Сенькино, здание администрации	Россия, Пермский край, Усольский район, село Сенькино	0101000020E6100000F5DA6CACC4E64B40978DCEF929CC4D40
72802	7	71	572	15846	52058	\N	59.478704	с.Пыскор, Игумнова, 5		0101000020E61000008BC56F0A2B4B4C40713B342C46BD4D40
73008	7	71	572	47347	\N	\N	59.481360000000002	с.Плеханово, Центр досуга		0101000020E6100000EC134031B2484C4021CD58349DBD4D40
73007	7	71	572	47347	\N	\N	59.481360000000002	с. Плеханово, Администрация сельского поселения		0101000020E6100000EC134031B2484C4021CD58349DBD4D40
72807	7	71	572	56352	52327	\N	59.510465000000003	с.Ощепково, Школьная, 13	Россия, Пермский край, Усольский район, село Ощепково	0101000020E6100000CD58349D9D2C4C405760C8EA56C14D40
65117	7	71	572	32648	52173	\N	59.342216999999998	п.Орел, Советская, 72а		0101000020E610000058E71890BD4A4C404F9143C4CDAB4D40
72804	7	71	572	32648	52006	\N	59.342216999999998	п.Орел, 1 мая, 37		0101000020E610000058E71890BD4A4C404F9143C4CDAB4D40
72798	7	71	572	33047	53974	\N	59.125636999999998	п.Вогулка, Южный, 3		0101000020E6100000B9A81611C5624C4072158BDF14904D40
72806	7	71	572	58298	64606	\N	59.4498268858651	с.Вкондас, Центральная, 31	Россия, Пермский край, Усольский район, село Верх-Кондас	0101000020E6100000D7851F9C4F074C40CCED5EEE93B94D40
72780	7	71	1329	14781	53572	\N	56.949736000000001	Пермский край, Уинский район, д.Чесноковка, ул.Заречная, 1		0101000020E61000009C14E63DCE464C40BCEA01F390794C40
72777	7	71	1329	14647	52057	\N	56.908462999999998	Пермский край, Уинский район, с.Чайка, ул.Советская, 28		0101000020E6100000D3F6AFAC345D4C402250FD8348744C40
72774	7	71	1329	58305	64628	\N	56.8608857796577	Пермский край, Уинский район, д.УстьТелес, ул.Центральная, 36	Россия, Пермский край, Уинский район, село Усть-Телес	0101000020E6100000F2423A3C84614C40C9CA2F83316E4C40
72776	7	71	1329	14616	52257	\N	56.980449	Пермский край, Уинский район, с.Усановка, ул.Центральная, 13		0101000020E610000050508A56EE594C40AD32535A7F7D4C40
72767	7	71	1329	14171	51716	\N	56.877901999999999	Пермский край, Уинский район, с.Уинское, ул.Свободы, 29а		0101000020E6100000158DB5BFB3494C40E78BBD175F704C40
72769	7	71	1329	14171	54030	\N	56.8757431422979	Пермский край, Уинский район, с.Уинское, ул.Ольховая, 2	Россия, Пермский край, Уинский район, село Уинское	0101000020E6100000357D76C0754D4C40B859BC5818704C40
72768	7	71	1329	14171	52321	\N	56.877901999999999	Пермский край, Уинский район, с.Уинское, ул.8 Марта, 50		0101000020E6100000158DB5BFB3494C40E78BBD175F704C40
72792	7	71	1329	14171	51712	\N	56.877901999999999	Пермский край, Уинский район, с.Уинское, ул.30 лет Победы, 2		0101000020E6100000158DB5BFB3494C40E78BBD175F704C40
72775	7	71	1329	14571	51646	\N	56.958767999999999	Пермский край, Уинский район, с.Суда, ул.Центральная, 32		0101000020E6100000DD7BB8E4B8674C40C539EAE8B87A4C40
72779	7	71	1329	14767	53560	\N	56.979387891834598	Пермский край, Уинский район, д.Средний Сып, ул.Новая, 10	Россия, Пермский край, Уинский район, село Средний Сып	0101000020E610000053B29C84D23D4C40240C03965C7D4C40
72786	7	71	1329	56508	54234	\N	56.789325556955497	Пермский край,  Уинский район, д.Сосновка, ул.Центральная, 321	Россия, Пермский край, Уинский район, село Сосновка	0101000020E6100000F2B391EBA6104C40F6F065A208654C40
72770	7	71	1329	58722	66176	\N	56.841613558165903	Пермская край, Уинский район, д.Салаваты, ул.Заречная, 2	Россия, Пермский край, Уинский район, село Соловаты	0101000020E61000006612F5824F5B4C4089EDEE01BA6B4C40
72778	7	71	1329	14702	53542	\N	56.972830065376101	Пермский край,  Уинский район, с.Нижний Сып, ул.Ленина, 65	Россия, Пермский край, Уинский район, село Нижний Сып	0101000020E610000048DFA469504A4C40AA4885B1857C4C40
72790	7	71	1329	15269	53622	\N	56.874375794266101	Пермский край, Уинский район, д.Митрохи, ул.Центральная, 16	Россия, Пермский край, Уинский район, село Митрохи	0101000020E61000000C23BDA8DD0F4C402234828DEB6F4C40
72788	7	71	1329	15117	52258	\N	56.981704999999998	Пермский край, Уинский район, д.Ломь, ул.Школьная, 2		0101000020E61000003881E9B46E1B4C40EBA86A82A87D4C40
72789	7	71	1329	15220	52259	\N	56.935822000000002	Пермский край, Уинский район, д.Курмакаш, ул.Центральная, 14		0101000020E610000087C1FC1532154C404C70EA03C9774C40
72784	7	71	1329	15002	53613	\N	56.817565781634002	Пермский край,  Уинский район, д.Красногорка, ул.Центральная, 11	Россия, Пермский край, Уинский район, село Красногорка	0101000020E6100000B1C1C2499A174C402829B000A6684C40
72781	7	71	1329	14857	52427	\N	56.790310633057999	Пермский край, Уинский район, д.Кочешовка, ул.Юбилейная, 4	Россия, Пермский край, Уинский район, село Кочешовка	0101000020E6100000228AC91B60464C40A4552DE928654C40
72771	7	71	1329	14378	63413	\N	56.826030000000003	Пермский край, Уинский район, д.Иштеряки, пер.Восточный, 24		0101000020E6100000838593347F7A4C40E8C1DD59BB694C40
72772	7	71	1329	14421	52238	\N	56.846803999999999	Пермский край, Уинский район, с.Воскресенское, ул.Верхняя, 4		0101000020E6100000D4BA0D6ABF714C409D0FCF12646C4C40
72791	7	71	1329	15356	54048	\N	56.976263374384203	Пермский край, Уинский район, д.Верхний Сып, ул.Центральная, 8	Россия, Пермский край, Уинский район, село Верхний Сып	0101000020E6100000B91B446B452D4C40BEA59C2FF67C4C40
72783	7	71	1329	14941	53579	\N	56.908962723611403	Пермский край, Уинский район, д.Большой Ась, ул.Центральная, 33	Россия, Пермский край, Уинский район, село Большой Ась	0101000020E61000004679E6E5B0294C4014234BE658744C40
72773	7	71	1329	14460	54042	\N	56.879027999999998	Пермский край, Уинский район, с.Барсаи, ул.Юбилейная, 2		0101000020E61000005F7D3CF4DD6D4C40572250FD83704C40
72782	7	71	1329	14906	52158	\N	56.858877	Пермский край,  Уинский район, с.Аспа, ул.Школьная, 13		0101000020E6100000F624B03907294C40AF2479AEEF6D4C40
72755	7	71	1264	13622	53517	\N	57.058886190417702	дер. Шахарово, Центральная, 58	Россия, Пермский край, Суксунский район, село Шахарово	0101000020E6100000B742588D25B64C409C18929389874C40
73011	7	71	1264	47429	\N	\N	57.053984	с.Филипповка, помещение библиотеки	Россия, Пермский край, Суксунский район, село Филипповка	0101000020E6100000D68EE21C75C84C40EE409DF2E8864C40
72766	7	71	1264	14144	53146	\N	57.035857999999998	с. Торговище, Трактовая, 37г		0101000020E6100000B6BFB33D7AC34C4065A6B4FE96844C40
72765	7	71	1264	14095	54022	\N	57.009100807077303	с. Тис, Северная, 32	Россия, Пермский край, Суксунский район, село Тис	0101000020E61000009B1BD31396CC4C4032AEB8382A814C40
72764	7	71	1264	14012	64383	\N	56.964725000000001	с. Сыра, Колхозная, 10		0101000020E6100000978E39CFD8C74C401A51DA1B7C7B4C40
72762	7	71	1264	13918	52056	\N	57.106394999999999	дер. Сызганка, Молодёжная, 2		0101000020E6100000580053060EE44C409DBAF2599E8D4C40
72748	7	71	1264	13141	51763	\N	57.146628	пос. Суксун, Школьная, 1		0101000020E6100000429946938BB34C40C556D0B4C4924C40
72745	7	71	1264	13141	51643	\N	57.146628	пос. Суксун, Кирова, 45		0101000020E6100000429946938BB34C40C556D0B4C4924C40
72746	7	71	1264	13141	51644	\N	57.146628	пос. Суксун, Карла Маркса, 40		0101000020E6100000429946938BB34C40C556D0B4C4924C40
72747	7	71	1264	13141	51510	\N	57.1466279703099	пос. Суксун, Большевистская, 16	Россия, Пермский край, Суксунский район, поселок Суксун	0101000020E6100000F1A0D9756FB34C40C556D0B4C4924C40
72751	7	71	1264	13426	54017	\N	57.171092892281003	с. Советная, Советинская, 43	Россия, Пермский край, Суксунский район, село Советная	0101000020E610000091B75CFDD8A84C408AC91B60E6954C40
72750	7	71	1264	13358	52054	\N	57.176704000000001	с. Сабарка, Победы, 5		0101000020E610000073A25D85949B4C404489963C9E964C40
72761	7	71	1264	13909	52146	\N	57.122332	дер. Поедуги, Сосновая, 23		0101000020E6100000F8A6E9B303C44C408CA03193A88F4C40
72760	7	71	1264	13836	52236	\N	57.186987000000002	дер. Пепёлыши, Колхозная, 14		0101000020E610000005A73E90BCC14C407AE3A430EF974C40
71996	7	71	1264	56264	52034	\N	56.976869752556297	с.Осинцево, Пионерская, 1	Россия, Пермский край, Суксунский район, село Осинцево	0101000020E6100000B2D7BB3FDEB74C40C5387F130A7D4C40
72758	7	71	1264	13758	52234	\N	57.194532000000002	дер. Нижняя Истекаевка, Трактовая, 10		0101000020E610000049641F6459BE4C404303B16CE6984C40
73034	7	71	1264	27182	\N	\N	57.214934999999997	с. Бырма, Дом Культуры		0101000020E6100000ADDA3521ADD94C4004E275FD829B4C40
71987	7	71	1264	27182	\N	\N	57.215398931773699	д.Бырма, здание библиотеки д.Бырма	Россия, Пермский край, Суксунский район, село Бырма	0101000020E6100000BA13ECBFCED94C40A94BC631929B4C40
72752	7	71	1264	32747	52151	\N	56.992744000000002	с. Брёхово, Школьная, 7		0101000020E61000001F2BF86D88B74C406EA6423C127F4C40
72763	7	71	1264	32839	52005	\N	57.046273999999997	дер. Агафонково, Центральная, 18		0101000020E6100000A2D11DC4CEE04C40DA53724EEC854C40
73063	7	71	1832	48401	52100	\N	59.679371000000003	п.Черное, ул.Мира, д.19 а		0101000020E6100000CD751A69A9784C40E86C01A1F5D64D40
73053	7	71	1832	28047	51775	\N	59.839700999999998	п.Тюлькино, ул.Лесная, д.3		0101000020E61000007B87DBA161434C4091B586527BEB4D40
73058	7	71	1832	28250	51776	\N	59.724260000000001	с.Тохтуева, ул.Дружбы, д.4		0101000020E610000063D4B5F63E5D4C4086E63A8DB4DC4D40
71802	7	71	1832	56261	52024	\N	59.731453984665002	д.Соколово, ул.Ленина, д.14	Россия, Пермский край, Соликамский район, село Соколово	0101000020E6100000473D44A33B464C40A243E048A0DD4D40
73069	7	71	1832	48511	53688	\N	59.873318588316302	п.Сим, ул.Молодежная, 7	Россия, Пермский край, Соликамский район, село Сим	0101000020E6100000520E661360AC4C40DBFCBFEAC8EF4D40
72972	7	71	1832	58257	\N	\N	59.586843662895198	п.Селянка, Библиотека	Россия, Пермский край, Соликамский район, село Селянка	0101000020E610000043ACFE08C3744C404AED45B41DCB4D40
73061	7	71	1832	28391	51526	\N	59.653588999999997	с.Половодово, ул.Школьная, д.11		0101000020E61000003D61890794894C403E03EACDA8D34D40
71876	7	71	1832	56270	\N	\N	59.739421516927102	ст. Пальники, здание ж/д станции	Россия, Пермский край, Соликамский район, село Пальники	0101000020E6100000A3737E8AE3CC4B40B1F84D61A5DE4D40
73064	7	71	1832	48422	53962	\N	59.802807000000001	с.Осокино, ул.Центральная, д.10		0101000020E6100000EB01F39029874C40FCFF3861C2E64D40
73055	7	71	1832	28132	54115	\N	59.798999999999999	п.Нижнее Мошево, ул.Спортивная, д.1		0101000020E61000009702D2FE074E4C4083C0CAA145E64D40
73037	7	71	1832	47912	\N	\N	60.003636999999998	д. Красный Берег, Дом культуры		0101000020E61000002DD0EE9062D84C401C075E2D77004E40
73068	7	71	1832	47912	52116	\N	60.003636999999998	п.Красный Берег, ул.Гагарина, д.1		0101000020E61000002DD0EE9062D84C401C075E2D77004E40
73166	7	71	1832	58960	\N	\N	59.798380622857898	д. Кокорина, 15	Россия, Пермский край, Соликамский район, село Кокорино	0101000020E6100000444C89247A654C40B75F3E5931E64D40
73056	7	71	1832	28184	52871	\N	59.6891321745399	с.Касиб, ул.Набережная, д.31	Россия, Пермский край, Соликамский район, село Касиб	0101000020E6100000F607CA6DFB2C4C404450357A35D84D40
73054	7	71	1832	56316	52229	\N	59.828041126129598	п.Затон, ул.Советская, д.4	Россия, Пермский край, Соликамский район, село Затон	0101000020E6100000093543AA284A4C40A25F5B3FFDE94D40
73060	7	71	1832	28368	64452	\N	59.946562999999998	с.Жуланово, ул.Культуры, д.25		0101000020E6100000FA264D83A2574C40444DF4F928F94D40
73052	7	71	1832	28008	52110	\N	59.760548	п.Басим, ул.Пионерская, д.1		0101000020E6100000E8DA17D00BD94B40E48409A359E14D40
72700	7	71	927	56322	52239	\N	58.517451999999999	п.Юбилейный, ул.Школьная, д.3	Россия, Пермский край, Сивинский район, село Юбилейный	0101000020E6100000DC4944F817034B40F99FFCDD3B424D40
72714	7	71	927	11704	52052	\N	58.401311999999997	с.Шулынды, ул.Ленина, д.16		0101000020E6100000ECDE8AC404154B4005BF0D315E334D40
72695	7	71	927	56523	54288	\N	58.317257094265003	с.УстьБуб, ул.Красногвардейская, д.14	Россия, Пермский край, Сивинский район, село Усть-Буб	0101000020E610000040FCFCF7E0474B40AAB69BE09B284D40
72710	7	71	927	11601	51637	\N	58.378371999999999	с.Сива, ул.Советская, д.4		0101000020E61000002E008DD2A52F4B406EDC627E6E304D40
72713	7	71	927	11601	51504	\N	58.378371999999999	с.Сива, ул.Ленина, д.57		0101000020E61000002E008DD2A52F4B406EDC627E6E304D40
72712	7	71	927	11601	51504	\N	58.378371999999999	с.Сива, ул.Ленина, д.62		0101000020E61000002E008DD2A52F4B406EDC627E6E304D40
72699	7	71	927	33065	54008	\N	58.512324	с.Серьгино, ул.Школьная, д.2		0101000020E610000062105839B4224B405B7A34D593414D40
72701	7	71	927	11248	53511	\N	58.353001571418801	с.Серафимовское, ул.Ленина, д.1	Россия, Пермский край, Сивинский район, село Серафимовское	0101000020E61000001E53776517FC4A4017B6662B2F2D4D40
72703	7	71	927	11168	51636	\N	58.379151	п.Северный Коммунар, ул.Советская, д.3		0101000020E6100000478FDFDBF4014B40739F1C0588304D40
72705	7	71	927	11168	53134	\N	58.379151	п.Северный Коммунар, ул.Ленина, д.30а		0101000020E6100000478FDFDBF4014B40739F1C0588304D40
72698	7	71	927	10950	52231	\N	58.546537999999998	с.Сатино, ул.Школьная, д.22		0101000020E6100000772CB64945F34A40B8020AF5F4454D40
72709	7	71	927	11428	52157	\N	58.350147999999997	д.Савичи, ул.Техническая, д.90		0101000020E61000004BC972124A334B40416150A6D12C4D40
71799	7	71	927	58217	64375	\N	58.313998474542799	д.Кривчана, ул.Мира, д.9	Россия, Пермский край, Сивинский район, село Кривчана	0101000020E61000006EDBF7A8BF424B403481221631284D40
60369	7	71	927	58264	64546	\N	58.574353834836501	с. Краснояр, ул. Спорта, 7	Россия, Пермский край, Сивинский район, село Краснояр	0101000020E6100000B114C95702434B40D4298F6E84494D40
72391	7	71	927	58277	64568	\N	58.320794922435503	д.Кичаново, у.Безымяная, д.11	Россия, Пермский край, Сивинский район, село Кичаново	0101000020E61000003E3F8C101E334B4033DC80CF0F294D40
72707	7	71	927	11361	52144	\N	58.485652000000002	с.Кизьва, ул.Ленина, д.22		0101000020E6100000E9D7D64FFF454B40569E40D8293E4D40
73188	7	71	927	46331	64379	\N	58.430205999999998	д. Кекур, Попова, 12		0101000020E6100000E04A766C04444B4080457EFD10374D40
72925	7	71	927	48082	\N	\N	58.504736231078603	с.Калиновка, Администрация	Россия, Пермский край, Сивинский район, село Калиновка	0101000020E61000004B0169FF03044B40938E72309B404D40
73138	7	71	927	49592	\N	\N	58.410789000000001	д.Зыряново, Здание Зыряновского сельского клуба	Россия, Пермский край, Сивинский район, село Зыряново	0101000020E6100000F59F353FFE1A4B403D47E4BB94344D40
72697	7	71	927	56292	52154	\N	58.474224	с.Екатерининское, ул.Ленина, д.41	Россия, Пермский край, Сивинский район, село Екатерининское	0101000020E61000001900AAB871094B40397D3D5FB33C4D40
72706	7	71	927	58254	64525	\N	58.418131513799402	д.Дмитриево, ул.Центральная, д.12	Россия, Пермский край, Сивинский район, село Дмитриево	0101000020E6100000FEB8FDF2C93C4B409EB4705985354D40
72693	7	71	927	10734	51634	\N	58.294564000000001	с.Буб, ул.Бубинская, д.19		0101000020E610000078280AF489304B401B4AED45B4254D40
72694	7	71	927	10754	54015	\N	58.298364907312099	д.Бровилята, ул.Трудовая, д.22	Россия, Пермский край, Сивинский район, село Бровилята	0101000020E6100000282D5C5661394B40B1A206D330264D40
72692	7	71	927	10663	52017	\N	58.283948000000002	д.Большое Самылово, ул.Самыловская, д.13		0101000020E61000003541D47D00204B40DFE1766858244D40
72020	7	71	927	45904	63914	\N	58.205798999999999	д.Антипина, ул.Центральная, 13, здание администрации ВерхЯзьвинского СП		0101000020E6100000D0D556EC2F274B405646239F571A4D40
71981	7	71	927	56279	52094	\N	58.503358950344897	с.Андреево, Парковая, 5	Россия, Пермский край, Сивинский район, село Андреево	0101000020E6100000B07614E7A8234B40DA9255116E404D40
72369	7	71	849	26928	52437	\N	57.684241999999998	с.Янычи, у.Сибирский тракт, д.54 Б		0101000020E610000053927538BA364C405A46EA3D95D74C40
72426	7	71	849	6309	51498	\N	57.698293999999997	п.ЮгоКамский, у.Советская, д.110		0101000020E61000005A9F724C16CB4B401B7FA2B261D94C40
72423	7	71	849	6309	51498	\N	57.698293999999997	п.ЮгоКамский, у.Советская, д.159		0101000020E61000005A9F724C16CB4B401B7FA2B261D94C40
72427	7	71	849	6309	51747	\N	57.698293999999997	п.ЮгоКамский, у.Мира, д.1		0101000020E61000005A9F724C16CB4B401B7FA2B261D94C40
72424	7	71	849	6309	51746	\N	57.698293999999997	п. ЮгоКамский, ул. Декабристов, д.14		0101000020E61000005A9F724C16CB4B401B7FA2B261D94C40
72419	7	71	849	56247	51818	\N	57.725100476698302	п.Юг, у.Комсомольский проспект, д.3	Россия, Пермский край, Пермский район, поселок Юг	0101000020E610000008228B34F1164C40302AA913D0DC4C40
72394	7	71	849	28049	53996	\N	57.865164600468603	д.Чуваки, у.Верховая, д.10	Россия, Пермский край, Пермский район, село Чуваки	0101000020E61000008F368E588BFD4B4069520ABABDEE4C40
72405	7	71	849	28545	\N	\N	58.008032999999998	"""с.УстьКачка, Санаторий ЗАО Курорт """"УстьКачка"""""""		0101000020E6100000847F113466D64B40F624B03907014D40
72414	7	71	849	28545	51815	\N	58.008032999999998	с.УстьКачка, у.Победы, д.12		0101000020E6100000847F113466D64B40F624B03907014D40
72415	7	71	849	28545	51627	\N	58.008032999999998	с.УстьКачка, у.Краснознаменная, д.5		0101000020E6100000847F113466D64B40F624B03907014D40
72413	7	71	849	58154	64013	\N	57.988719921016298	с.Троица, у.Советская, д.18	Россия, Пермский край, Пермский район, село Троица	0101000020E61000001AFCFD62B6644C40587380608EFE4C40
72421	7	71	849	29322	51745	\N	58.034668000000003	п.Сылва, у.Молодежная, д.7		0101000020E6100000B30B06D7DC614C40DF1B430070044D40
72420	7	71	849	29322	51629	\N	58.034668000000003	п.Сылва, у.Заводской переулок, д.1		0101000020E6100000B30B06D7DC614C40DF1B430070044D40
72378	7	71	849	27319	52793	\N	57.9217521375313	д.Суздалы, у.Полевая, д.1	Россия, Пермский край, Пермский район, село Суздалы	0101000020E6100000A8C4758C2BDC4B40E48233F8FBF54C40
72411	7	71	849	61184	\N	\N	57.909335682198098	п. Сокол, Соколовская среднеобразовательная школа	Россия	0101000020E6100000A774B0FECF054C40A9893E1F65F44C40
72406	7	71	849	58153	63992	\N	57.556480465960398	с.Рождественское, у.Революционная, д.20	Россия, Пермский край, Пермский район, село Рождественское	0101000020E610000091459A7807DA4B40657094BC3AC74C40
73122	7	71	849	56267	\N	\N	57.4755340875925	п.Октябрьский, Здание Октябрьской начальной школы	Россия, Пермский край, Пермский район, поселок Октябрьский	0101000020E6100000C1559E40D8034C406B11514CDEBC4C40
72244	7	71	849	56267	52050	\N	57.4755340875925	пгт.Октябрьский, Граневая, 15, контора маслозавода	Россия, Пермский край, Пермский район, поселок Октябрьский	0101000020E6100000BD1DE1B4E0034C406B11514CDEBC4C40
72243	7	71	849	56267	52131	\N	57.4763875768815	пгт.Октябрьский, 18 Годовщины Октября, 68, гараж ДРСУ	Россия, Пермский край, Пермский район, поселок Октябрьский	0101000020E6100000F8C610001C054C407A1A3048FABC4C40
72404	7	71	849	56310	52217	\N	57.559685426243703	п.Новый, у.Первомайская, д.8	Россия, Пермский край, Пермский район, село Новый	0101000020E6100000D9EC48F59DD74B40E88711C2A3C74C40
72402	7	71	849	28402	52048	\N	57.617685999999999	с.Н.Пальник, у.Садовая, д.2		0101000020E6100000868F882991284C403999B85510CF4C40
72374	7	71	849	27131	52047	\N	57.880329000000003	д.Нестюково, у.Трактовая, д.50		0101000020E610000044BFB67EFA214C40365CE49EAEF04C40
72399	7	71	849	6640	51491	\N	57.804608000000002	п. Мулянка, ул. Октябрьская, д.21		0101000020E610000015FF774485304C40CC0C1B65FDE64C40
63898	7	71	849	58535	65387	\N	57.843631641621698	д.Мостовая, у.Мира, д.19	Россия, Пермский край, Пермский район, село Мостовая	0101000020E61000005CE84A04AA574C40F6ED2422FCEB4C40
72401	7	71	849	28128	51622	\N	57.862126000000004	с. Лобаново, ул. Культуры, д.15		0101000020E61000008C65FA25E2254C4002840F255AEE4C40
72396	7	71	849	28128	51622	\N	57.8619429813767	с.Лобаново, у.Культуры, д.15	Россия, Пермский край, Пермский район, село Лобаново	0101000020E610000001A260C614264C401002F22554EE4C40
72395	7	71	849	28086	51813	\N	57.654764	с.Курашим, у.Чурекова, д.2		0101000020E6100000ECA694D74A4E4C40904C874ECFD34C40
72389	7	71	849	27824	51494	\N	57.896743999999998	с.Култаево, у.Р.Кашина, д.89		0101000020E6100000EBABAB02B5F84B402E71E481C8F24C40
72383	7	71	849	10345	51744	\N	57.647536000000002	с.Кукуштан, у.Чапаева, д.50		0101000020E6100000C90391459A3E4C40C87DAB75E2D24C40
72386	7	71	849	10345	51621	\N	57.647536000000002	с.Кукуштан, у.Ульяновская, д.22		0101000020E6100000C90391459A3E4C40C87DAB75E2D24C40
72417	7	71	849	49152	51816	\N	57.990887000000001	п.Кр.Восход, у.Садовая, д.10		0101000020E6100000454948A46DDA4B400A849D62D5FE4C40
72382	7	71	849	33032	52204	\N	57.797524000000003	с.Кояново, у.Советская, д.133б		0101000020E6100000295DFA97A4284C4037E3344415E64C40
72392	7	71	849	27960	52046	\N	57.871203000000001	д. Косотуриха, ул. Центральная, д.22а		0101000020E6100000A8DF85ADD9F04B40AB96749483EF4C40
72397	7	71	849	33090	53501	\N	57.815778698916802	д.Касимово, у.Клубная, д.52	Россия, Пермский край, Пермский район, село Касимово	0101000020E610000062D7F6764B1E4C40BDE13E726BE84C40
72995	7	71	849	56246	51791	\N	57.732814230920603	Пермский край, городской округ ЗАТО Звездный, Бабичева, 5А	Россия, Пермский край, Пермский район, поселок Бершетские Дачи	0101000020E61000007407B13385284C40850662D9CCDD4C40
72376	7	71	849	32996	52107	\N	57.934272	д.Горшки, у.Школьная, д.4		0101000020E61000008AAE0B3F38DF4B40C5C8923996F74C40
72373	7	71	849	32986	52203	\N	57.896571999999999	п.Горный, у.Лямина, д.1		0101000020E6100000C5FEB27BF22A4C4031410DDFC2F24C40
72681	7	71	849	56311	65440	\N	57.907322532544697	г.Пермь пос.Голый Мыс, ул.Клубная, 2	Россия, Пермский край, Пермский район, село Голый Мыс	0101000020E6100000567E198C11C54B404DF4F92823F44C40
72757	7	71	849	8468	52324	\N	57.625423400347103	дер. Бырма, Школьная, 21	Россия, Пермский край, Пермский район, поселок Бырма	0101000020E6100000B03DB324401B4C40469561DC0DD04C40
72388	7	71	849	58251	\N	\N	57.924660139672397	"""Аэропорт """"Большое Савино"""", здание аэропорта"""	Россия, Пермский край, Пермский район, село Большое Савино	0101000020E6100000B64AB0389C014C40AEF545425BF64C40
72377	7	71	849	27251	52292	\N	57.900398000000003	д.Большакино, у.Центральная, д.22/2		0101000020E6100000747E8AE3C0E34B4021B1DD3D40F34C40
72993	7	71	849	58164	64101	\N	57.732535181356397	Пермский край, городской округ ЗАТО Звездный, Школьная, 8	Россия, Пермский край, Пермский район, поселок Бершетские Дачи	0101000020E6100000B18A37328F284C407216F6B4C3DD4C40
72390	7	71	849	27873	52205	\N	57.843667666834101	д.Башкултаево, у.Мавлютова, д.30	Россия, Пермский край, Пермский район, село Башкултаево	0101000020E610000068CF656A12F44B4043572250FDEB4C40
72387	7	71	849	27755	52206	\N	57.585549	д.Байболовка, у.Школьная, д.1 А		0101000020E61000006E4E2503403F4C404E9A0645F3CA4C40
72366	7	71	1781	32950	53957	\N	57.934429999999999	с.Токари, Центральная, 17		0101000020E6100000A6F10BAF24234B405D33F9669BF74C40
72359	7	71	1781	26458	52142	\N	57.933751000000001	д.Спешково, Центральная, 11		0101000020E61000008179C8940F474B40BCCD1B2785F74C40
63145	7	71	1781	32565	52172	\N	57.830737999999997	д.Семёново, Мира, 8		0101000020E61000004701A260C65A4B40B0C56E9F55EA4C40
72356	7	71	1781	48044	51616	\N	57.844076000000001	п.Павловский, Таборская, 26		0101000020E6100000D5B48B69A66B4B4054ABAFAE0AEC4C40
72358	7	71	1781	48044	51814	\N	57.844122225028698	п.Павловский, Октябрьская, 40	Россия, Пермский край, Очерский район, поселок Павловский	0101000020E610000023DDCF29C86B4B40C4EA8F300CEC4C40
72355	7	71	1781	48044	51814	\N	57.844076000000001	п.Павловский, Октябрьская, 5		0101000020E6100000D5B48B69A66B4B4054ABAFAE0AEC4C40
72347	7	71	1781	25794	52096	\N	57.888952000000003	г.Очер, Школьная, 97		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72344	7	71	1781	25794	51738	\N	57.888952000000003	г.Очер, Урицкого, 29		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72350	7	71	1781	25794	52141	\N	57.889408895227596	г.Очер, Советская, 20	Россия, Пермский край, Очерский район, Очер	0101000020E6100000F2B1BB40495D4B4050E27327D8F14C40
72351	7	71	1781	25794	51740	\N	57.888952000000003	г.Очер, Революционная, 95		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72349	7	71	1781	25794	51740	\N	57.888952000000003	г.Очер, Революционная, 6		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72345	7	71	1781	25794	52200	\N	57.888952000000003	г.Очер, Пушкина, 54а		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72353	7	71	1781	25794	52202	\N	57.888952000000003	г.Очер, О.Кошевого, 54		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72348	7	71	1781	25794	51739	\N	57.888952000000003	г.Очер, Коммунистическая, 6		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72352	7	71	1781	25794	51741	\N	57.888952000000003	г.Очер, Дорожный, 13а		0101000020E61000006B9C4D47005D4B405EDBDB2DC9F14C40
72363	7	71	1781	26626	53946	\N	57.798949	д.Нововознесенск, Мира, 9		0101000020E610000062122EE411404B400116F9F543E64C40
72354	7	71	1781	26206	52104	\N	57.863810999999998	д.Нижняя Талица, Школьная, 17		0101000020E61000003E03EACDA87B4B406876DD5B91EE4C40
72362	7	71	1781	32922	53945	\N	57.946545	д.Морозово, Раздольная, 33		0101000020E6100000242713B70A684B409E98F56228F94C40
72360	7	71	1781	32911	53943	\N	57.918534000000001	д.Лужково, Заречная, 88		0101000020E610000014984EEB365C4B40CD21A98592F54C40
72367	7	71	1781	26833	53964	\N	57.876434000000003	с.Кулики, Центральная, 12		0101000020E6100000E86C01A1F52C4B401E8D43FD2EF04C40
72364	7	71	1781	32939	64333	\N	57.898806	д.Киприно, Советская, 29		0101000020E610000050E09D7C7A3E4B406BB933130CF34C40
62363	7	71	1781	56503	54210	\N	58.014843862488	с.Дворец, Уральская, 15	Россия, Пермский край, Очерский район, село Дворец	0101000020E61000005A12A0A696774B405A457F68E6014D40
72337	7	71	1092	25446	51812	\N	57.711378000000003	д.Тулумбаиха, ул.Культуры, д.7		0101000020E61000000305DEC9A7A94B40058C2E6F0EDB4C40
72339	7	71	1092	32744	52051	\N	57.829248	с.Таборы, ул.Октября, д.8		0101000020E6100000116E32AA0C934B40FF2268CC24EA4C40
72343	7	71	1092	32780	63642	\N	57.750247999999999	с.Пономари, ул.Центральная, д.1		0101000020E61000006C21C841097B4B40D8F15F2008E04C40
72333	7	71	1092	25119	51625	\N	57.714858999999997	г.Оханск, ул.Ленина, д.66		0101000020E6100000698A00A777B14B402920ED7F80DB4C40
72331	7	71	1092	25119	51604	\N	57.714858999999997	г.Оханск, ул.Красная, д.8		0101000020E6100000698A00A777B14B402920ED7F80DB4C40
72330	7	71	1092	25119	51604	\N	57.703835614738203	г.Оханск, ул.Красная, д.56	Россия, Пермский край, Оханский район, Оханск	0101000020E61000000EF8FC3042B44B40ADDF4C4C17DA4C40
72332	7	71	1092	25119	51736	\N	57.714858999999997	г.Оханск, ул.Винокурова, д.2		0101000020E6100000698A00A777B14B402920ED7F80DB4C40
72341	7	71	1092	9658	54552	\N	57.668154000000001	с.Острожка, ул.Советска, д.35, Центр досуга		0101000020E6100000481ADCD616984B408658FD1186D54C40
72342	7	71	1092	32770	53937	\N	57.766774253413502	д.Мерзляки, ул.Центральная, д.5	Россия, Пермский край, Оханский район, село Мерзляки	0101000020E61000002C836A83138D4B4028B682A625E24C40
72754	7	71	1092	56260	52022	\N	57.513074098284903	с. Ключи, 40 лет Победы, 17	Россия, Пермский край, Оханский район, село Ключи	0101000020E610000041BB438A01BE4B40C636A968ACC14C40
72338	7	71	1092	56280	52095	\N	57.589791554199998	с.Казанка, ул.Садовая, д.1	Россия, Пермский край, Оханский район, село Казанка	0101000020E6100000C173EFE192AD4B40A2B8E34D7ECB4C40
71800	7	71	1092	58218	\N	\N	57.599783125884898	д.Заполье, здание клуба	Россия, Пермский край, Оханский район, село Заполье	0101000020E6100000292499D53BAA4B4030D978B0C5CC4C40
73036	7	71	1092	56227	\N	\N	57.6952845629338	д. Березовка, бывшее помещение ФАП	Россия, Пермский край, Оханский район, село Березовка	0101000020E610000060E5D022DB9D4B401E335019FFD84C40
71712	7	71	1092	56227	51580	\N	57.695912621485498	село Березовка, Ленина, 33 администрация района	Россия, Пермский край, Оханский район	0101000020E61000003315E291789F4B403DEE5BAD13D94C40
72335	7	71	1092	32711	52156	\N	57.470443000000003	с.Беляевка, ул.Камская, д.24		0101000020E61000006D37C1374DBD4B40EAD0E97937BC4C40
72334	7	71	1092	56277	52093	\N	57.520927608500003	с.Андреевка, ул.Победы, д.2	Россия, Пермский край, Оханский район, село Андреевка	0101000020E610000083C13577F49F4B400CC9C9C4ADC24C40
72375	7	71	1406	58228	64428	\N	57.258235181655699	д.Устиново, у.Советская, д.44	Россия, Пермский край, Осинский район, село Устиново	0101000020E61000003CC093162EAF4B405ED72FD80DA14C40
72311	7	71	1406	32557	52130	\N	57.274835000000003	д. Пермякова, Уральская, 6		0101000020E6100000BA4A77D7D9A64B40E96514CB2DA34C40
72325	7	71	1406	24903	52319	\N	57.459290000000003	с.Паль, Садовая, 1		0101000020E610000015527E52EDD34B409FB0C403CABA4C40
72308	7	71	1406	23645	51735	\N	57.279116999999999	г.Оса, Строителей, 31		0101000020E6100000471D1D5723B94B40FA60191BBAA34C40
72303	7	71	1406	23645	52129	\N	57.279116999999999	г. Оса, Советская, 45		0101000020E6100000471D1D5723B94B40FA60191BBAA34C40
72302	7	71	1406	23645	51490	\N	57.279116999999999	г. Оса, Пугачева, 12		0101000020E6100000471D1D5723B94B40FA60191BBAA34C40
72305	7	71	1406	23645	51488	\N	57.279116999999999	г.Оса, Мира, 10		0101000020E6100000471D1D5723B94B40FA60191BBAA34C40
72304	7	71	1406	23645	51488	\N	57.2868212141573	г. Оса, Мира, 10	Россия, Пермский край, Осинский район, Оса	0101000020E6100000280AF4893CBB4B402C67EF8CB6A44C40
72031	7	71	1028	10521	52249	\N	60.196328999999999	с.Губдор, ул. Советская, 3		0101000020E610000077483140A2514C40D120054F21194E40
72307	7	71	1406	23645	51603	\N	57.288505970908901	г.Оса, М.Горького, 78	Россия, Пермский край, Осинский район, Оса	0101000020E610000089997D1EA3BC4B409259BDC3EDA44C40
72300	7	71	1406	23645	51821	\N	57.2833062137247	г. Оса, ул. Интернациональная, 6, Центр детского творчества	Россия, Пермский край, Осинский район, Оса	0101000020E6100000D66F26A60BBB4B405B61FA5E43A44C40
72299	7	71	1406	23645	51485	\N	57.279116999999999	г. Оса, Горького, 63		0101000020E6100000471D1D5723B94B40FA60191BBAA34C40
72842	7	71	1406	56241	51726	\N	57.1213749245819	с.Ольховка, ул.Школьная, д.2	Россия, Пермский край, Осинский район, село Ольховка	0101000020E610000018963FDF169E4B40A8C64B37898F4C40
72313	7	71	1406	56323	52237	\N	57.214136763486302	с.Новозалесново, Советская, 7		0101000020E610000052B648DA8DA44B4089EE59D7689B4C40
72319	7	71	1406	32603	9943	\N	57.074606551473899	д.Нижняя Чермода, Молодежная, 3	Россия, Пермский край, Осинский район, село Нижняя Чермода	0101000020E610000067EDB60BCDD14B40BE86E0B88C894C40
72135	7	71	1406	15486	\N	\N	57.251441999999997	Пермский край, Кунгурский городской округ, Нефтяников, 35	Россия, Пермский край, Осинский район, село Нефтяников	0101000020E6100000ECA353573EB54B40A06B5F402FA04C40
72262	7	71	1406	58178	\N	\N	57.201409426694902	д.Мостовая, библиотека	Россия, Пермский край, Осинский район, село Мостовая	0101000020E61000007FBE2D58AACB4B405E0F26C5C7994C40
72321	7	71	1406	32611	52287	\N	57.252240999999998	пос.Лесной, Кирова, 2	Россия, Пермский край, Осинский район, село Лесной	0101000020E61000001C9947FE60EA4B40ECDADE6E49A04C40
72324	7	71	1406	32633	52317	\N	57.368225000000002	с.Кузнечиха, Чапаева, 28		0101000020E610000088B839950CCE4B40E9482EFF21AF4C40
72316	7	71	1406	56309	52213	\N	57.166179	с.Крылово, Ленина, 6	Россия, Пермский край, Осинский район, село Крылово	0101000020E6100000D09849D40BC64B4018247D5A45954C40
72322	7	71	1406	24773	52132	\N	57.295641000000003	с. Горы, Советская, 56		0101000020E61000003080F0A144C94B40AA2D7590D7A54C40
73065	7	71	1406	56326	\N	\N	57.2742615272739	пос.Горки, клуб	Россия, Пермский край, Осинский район, село Горки	0101000020E61000001897AAB4C5DF4B408D4468041BA34C40
72317	7	71	1406	56320	52233	\N	57.208792009659803	с.Гамицы, Мира, 1	Россия, Пермский край, Осинский район, село Галицы	0101000020E61000000EA320787CC34B404ED53DB2B99A4C40
72327	7	71	1406	24988	52289	\N	57.348019000000001	с.Верхняя Давыдовка, Молодежная, 6		0101000020E6100000444C89247AA94B407DB1F7E28BAC4C40
72292	7	71	1057	33084	53492	\N	57.137549	д.Щелканка, ул.Центральная, д.24		0101000020E6100000680586AC6E474C407B4CA4349B914C40
72282	7	71	1057	22832	54457	\N	57.086919000000002	с.Шляпники, ул.Ленина, д.44		0101000020E610000011548D5E0D7E4C4055336B29208B4C40
71951	7	71	1057	56287	52126	\N	57.061654947821701	д.Терехино, Терехинская, 1	Россия, Пермский край, Ординский район, село Терехино	0101000020E6100000E52A16BF29764C404451A04FE4874C40
72281	7	71	1057	9878	51602	\N	57.201383	с.Орда, ул.Трактовая, д.22а		0101000020E610000036ACA92C0A754C40357C0BEBC6994C40
72280	7	71	1057	9878	51779	\N	57.201383	с.Орда, ул.Советская, д.26		0101000020E610000036ACA92C0A754C40357C0BEBC6994C40
72298	7	71	1057	9878	52315	\N	57.201150112761397	с.Орда, ул.Пугачева, д.79	Россия, Пермский край, Ординский район, село Орда	0101000020E610000084D4EDEC2B754C4092CB7F48BF994C40
72279	7	71	1057	9878	54362	\N	57.1957950988146	с.Орда, ул.1 Мая, д.1	Россия, Пермский край, Ординский район, село Орда	0101000020E6100000103E9468C9754C4033DC80CF0F994C40
72296	7	71	1057	9280	54421	\N	57.101388999999998	с. Опачевка, ул.Советская, д.33		0101000020E6100000E99E758D96654C404A969350FA8C4C40
72286	7	71	1057	9965	54490	\N	56.920338999999998	с. Михино, ул. Советская д.23		0101000020E610000046EBA86A82804C40DE1D19ABCD754C40
72290	7	71	1057	33079	52759	\N	57.118304999999999	д.Михайловка, ул.Гаражная, д.2		0101000020E6100000F243A51133294C4005FA449E248F4C40
72285	7	71	1057	22970	52745	\N	56.931102000000003	д.Мерекаи, ул.Центральная, д.11		0101000020E61000009CC420B072724C40BF9EAF592E774C40
72284	7	71	1057	33052	52040	\N	56.975023999999998	с.Медянка, ул.Ленина, д.32а		0101000020E61000008A3F8A3A737B4C4055682096CD7C4C40
72288	7	71	1057	23120	52039	\N	57.079191000000002	с.Малый Ашап, ул.Советская, д.53		0101000020E6100000AE0FEB8D5A494C409B9141EE228A4C40
72294	7	71	1057	23384	52092	\N	57.088895000000001	с.Красный Ясыл, ул.Советская, д.54		0101000020E61000003B1DC87A6A534C4093E34EE9608B4C40
72293	7	71	1057	23354	52198	\N	57.175874999999998	с.Карьево, ул.Центральная, д.5		0101000020E610000028BA2EFCE0484C408D976E1283964C40
72283	7	71	1057	22873	53494	\N	57.041499999999999	с.Грызаны, ул.Центральная, д.38		0101000020E6100000F6D214014E6D4C405A643BDF4F854C40
72287	7	71	1057	23052	53935	\N	57.044241999999997	с.Вторые Ключики, ул.Заводская, д.13		0101000020E6100000959F54FB74584C40088ECBB8A9854C40
72297	7	71	1057	23533	52314	\N	57.166598	с.Верхний Кунгур, ул.Большая, д.18		0101000020E6100000F5824F73F26C4C401DCA501553954C40
72291	7	71	1057	23229	51809	\N	57.115558999999998	с.Ашап, пер.Советский, д.13		0101000020E6100000B6813B50A7424C4015E126A3CA8E4C40
72272	7	71	1510	56243	\N	\N	56.468983922836003	п.ЩучьеОзеро, СДК	Россия, Пермский край, Октябрьский район, поселок Щучье Озеро	0101000020E610000001DF6DDE38534C40732CEFAA073C4C40
72278	7	71	1510	56359	\N	\N	56.231177348205598	д.Шараповка, СДК	Россия, Пермский край, Октябрьский район, село Шараповка	0101000020E610000094DE37BEF6864C40304B3B35971D4C40
72277	7	71	1510	58111	\N	\N	56.2241397146298	д.УстьСаварово, СДК	Россия, Пермский край, Октябрьский район, село Усть-Саварово	0101000020E6100000506D7022FA8D4C40DBDC989EB01C4C40
61967	7	71	1510	56366	\N	\N	56.7188102861925	д.Уразметьево, СДК	Россия, Пермский край, Октябрьский район, село Уразметьево	0101000020E6100000DC291DACFF594C40D50451F7015C4C40
72256	7	71	1510	46049	51487	\N	56.640199000000003	п.Тюш, Первомайская, 12, СДК		0101000020E6100000D00EB8AE987F4C4049F7730AF2514C40
72275	7	71	1510	22523	\N	\N	56.331633737866298	с.Тюинск, СДК	Россия, Пермский край, Октябрьский район, село Тюинск	0101000020E61000000F09DFFB1B4C4C40EF1EA0FB722A4C40
72254	7	71	1510	21569	\N	\N	56.2432650999231	д.Тляково, СДК	Россия, Пермский край, Октябрьский район, село Тляково	0101000020E6100000D63BDC0E0D914C4077A1B94E231F4C40
71717	7	71	1510	58212	64350	\N	56.533482564239399	село Сосновка, Центральная, 27 администрация Сосновского СП	Россия, Пермский край, Октябрьский район, село Сосновка	0101000020E610000026E318C91E854C4069FCC22B49444C40
72246	7	71	1510	21208	52736	\N	56.502702999999997	с.Снежное, ул. Речная,11, учебный корпус техникума		0101000020E61000005073F22213964C40F04C689258404C40
72267	7	71	1510	56466	\N	\N	56.371373892041703	д.Седяш, СДК	Россия, Пермский край, Октябрьский район, село Седяш	0101000020E6100000B22E6EA3018A4C40D84AE82E892F4C40
72252	7	71	1510	21407	51484	\N	56.469065000000001	пгт.Сарс, Советская, ДК, 2 этаж		0101000020E6100000758F6CAE9A8B4C40605969520A3C4C40
72251	7	71	1510	21407	51484	\N	56.469065000000001	пгт.Сарс, Советская, ДК, 1 этаж		0101000020E6100000758F6CAE9A8B4C40605969520A3C4C40
32043	7	71	1510	56336	\N	\N	56.674819813251901	д.Самарово, СДК	Россия, Пермский край, Октябрьский район, село Самарова	0101000020E6100000E2B034F0A35E4C40E657738060564C40
72276	7	71	1510	22594	52128	\N	56.201909999999998	с.Русский Сарс, Зимина, СДК		0101000020E6100000357BA015188C4C40205ED72FD8194C40
72261	7	71	1510	56428	\N	\N	56.586850794725201	д.Редькино, административное здание	Россия, Пермский край, Октябрьский район, село Редькино	0101000020E6100000C4279D48307B4C40FD4FFEEE1D4B4C40
72266	7	71	1510	56346	\N	\N	56.338117724359698	с.Петропавловск, СДК	Россия, Пермский край, Октябрьский район, село Петропавловск	0101000020E61000002DAF5C6F9B8F4C402F185C73472B4C40
72238	7	71	1510	45764	51889	\N	56.5107053819764	пгт. Октябрьский, Ленина, 59, ГДК, 1 этаж	Россия, Пермский край, Октябрьский район, поселок Октябрьский	0101000020E610000033DC80CF0F9B4C40AC730CC85E414C40
72274	7	71	1510	56467	\N	\N	56.346509040249302	д.Новопетровка, СДК	Россия, Пермский край, Октябрьский район, село Новопетровка	0101000020E61000000798F90E7E5C4C4084622B685A2C4C40
72245	7	71	1510	21140	\N	\N	56.521765000000002	"""п.Ненастье, контора гаража ООО """"Газстройдеталь"""""""		0101000020E61000000937195586A74C4046990D32C9424C40
72248	7	71	1510	21290	\N	\N	56.424128356239599	д.Малый Сарс, СДК	Россия, Пермский край, Октябрьский район, село Малый Сарс	0101000020E610000092CF2B9E7A944C40B1A888D349364C40
72258	7	71	1510	21742	\N	\N	56.228660168008098	с.Леун, административное здание	Россия, Пермский край, Октябрьский район, село Леун	0101000020E61000000CCA349A5C664C40A1F31ABB441D4C40
72255	7	71	1510	46041	\N	\N	56.626381000000002	д.Колтаева	Россия, Пермский край, Октябрьский район, село Колтаева	0101000020E61000003CA583F57F6C4C40FBEAAA402D504C40
72226	7	71	1510	32660	52002	\N	56.666884000000003	с.Ишимово, Мира, 12, администрация		0101000020E6100000349E08E23C664C40E31C75745C554C40
60409	7	71	1510	58220	\N	\N	56.743619281427399	п.Зуевский, СДК	Россия, Пермский край, Октябрьский район, село Зуевский	0101000020E6100000AC1C5A643B6F4C4095D74AE82E5F4C40
62294	7	71	1510	17649	\N	\N	56.581877079956499	с.Енапаево, администрация	Россия, Пермский край, Октябрьский район, село Енапаево	0101000020E61000005951836918724C40B5A50EF27A4A4C40
72250	7	71	1510	45915	\N	\N	56.627357000000003	д. ВерхШуртан, административное здание		0101000020E61000000DFFE9060AA64C4056F5F23B4D504C40
72269	7	71	1510	22256	\N	\N	56.677031999999997	д.ВерхТюш, администрация		0101000020E6100000F86C1D1CEC8D4C40382C0DFCA8564C40
72265	7	71	1510	56342	\N	\N	56.488308000000004	д.ВерхИрень, СДК	Россия, Пермский край, Октябрьский район, село Верх-Ирень	0101000020E61000005A12A0A696794C40063065E0803E4C40
72249	7	71	1510	21322	\N	\N	56.474189830387203	д.Большой Сарс, библиотека	Россия, Пермский край, Октябрьский район, село Большой Сарс	0101000020E6100000DBBE47FDF58E4C408D0B0742B23C4C40
72257	7	71	1510	21702	\N	\N	56.1472388655475	д.Бияваш, СДК	Россия, Пермский край, Октябрьский район, село Бияваш	0101000020E6100000041E1840F87A4C400ED940BAD8124C40
72260	7	71	1510	21868	\N	\N	56.764544103959601	д.Бикбай, СДК	Россия, Пермский край, Октябрьский район, село Бикбай	0101000020E6100000C993A46B265D4C40302DEA93DC614C40
72259	7	71	1510	21802	\N	\N	56.759624550778099	с.Басино, администрация	Россия, Пермский край, Октябрьский район, село Басино	0101000020E6100000AC014A438D684C40AC1C5A643B614C40
72263	7	71	1510	21992	\N	\N	56.550631498726801	д.Атнягузи, СДК	Россия, Пермский край, Октябрьский район, село Атнягузи	0101000020E6100000F838D384ED7B4C40F7949C137B464C40
72271	7	71	1510	22362	\N	\N	56.8193262886684	с.Алтынное, административное здание	Россия, Пермский край, Октябрьский район, село Алтынное	0101000020E610000025ADF886C2914C409961A3ACDF684C40
72273	7	71	1510	56429	\N	\N	56.424420624123101	с.Алмаз, СДК	Россия, Пермский край, Октябрьский район, село Алмаз	0101000020E6100000BA1457957D534C40295E656D53364C40
72268	7	71	1510	22248	\N	\N	56.314957000287301	д.Адилева, СДК	Россия, Пермский край, Октябрьский район, село Адилева	0101000020E61000003F74417DCB904C40B952CF8250284C40
72218	7	71	1009	19667	52036	\N	58.018307	с.Шерья, ул.Школьная, д.1		0101000020E6100000BF29AC5450994B40D9243FE257024D40
72222	7	71	1009	19848	53909	\N	57.938761171933201	с.Чекмени, ул.Центральная, д.1	Россия, Пермский край, Нытвенский район, село Чекмени	0101000020E610000036E9B6442E924B4050E1085229F84C40
72225	7	71	1009	56215	51610	\N	58.124470412702799	ст.Чайковская, ул.Строительная, д.1	Россия, Пермский край, Нытвенский район, село Чайковская	0101000020E610000009DE904605C64B40A4AA09A2EE0F4D40
72224	7	71	1009	56215	51483	\N	58.132144364670502	ст.Чайкавская, ул.Коробейникова, д.4	Россия, Пермский край, Нытвенский район, село Чайковская	0101000020E610000038D89B1892C34B406A2E3718EA104D40
14622	7	71	1009	47999	51555	\N	58.045777999999999	с.Фролы, у.Садовая, д.14		0101000020E6100000022D5DC136964B402A70B20DDC054D40
72237	7	71	1009	19422	52731	\N	57.946417830805601	Пермский край, Нытвенский муниципальный район, Уральское городское поселение,  пос.Уральский, Центральная, 17, медпункт	Россия, Пермский край, Нытвенский район, поселок Уральский	0101000020E6100000990D32C9C8C74B40412C9B3924F94C40
72216	7	71	1009	19422	51489	\N	57.938841144349702	поселок Уральский, ул.Набережная, д.23		0101000020E61000008044132862C74B406C921FF12BF84C40
72215	7	71	1009	19422	51489	\N	57.9372206204268	поселок Уральский, ул.Набережная, д.20	Россия, Пермский край, Нытвенский район	0101000020E6100000E92B483316C74B40ED0F94DBF6F74C40
72214	7	71	1009	19422	51600	\N	57.943224999999998	поселок Уральский, ул.Московская, д.13		0101000020E6100000F261F6B2EDC44B4082E2C798BBF84C40
73229	7	71	1009	56350	\N	\N	58.178383934190997	п. Сюзьва, Здание сельского клуба	Россия, Пермский край, Нытвенский район, село Сюзьва	0101000020E6100000F56393FC88B14B4099107349D5164D40
72231	7	71	1009	20419	53452	\N	58.302697999999999	д.Постаноги, Советская, 12		0101000020E610000077853E58C6A24B404548DDCEBE264D40
72988	7	71	1009	56298	\N	\N	57.8953973791672	"""п.Половинка, филиал МУК """"Скальнинский Дом культуры"""""""	Россия, Пермский край, Нытвенский район, село Половинка	0101000020E610000016139B8F6BA34B40E0F76F5E9CF24C40
72229	7	71	1009	32683	52273	\N	58.200392999999998	с.Покровское, ул.Речная, д.6а		0101000020E61000001763601DC7B74B4075AC527AA6194D40
72234	7	71	1009	8751	52138	\N	57.920403	Пермский край, Нытвенский муниципальный район, Нытвенское городское поселение, г.Нытва, пр.Ленина, 44		0101000020E61000002579AEEFC3AB4B40F511F8C3CFF54C40
72206	7	71	1009	8751	51805	\N	57.920403	г.Нытва, ул.Оборина, д.1а		0101000020E61000002579AEEFC3AB4B40F511F8C3CFF54C40
72205	7	71	1009	8751	51598	\N	57.9317162107493	г.Нытва, Ленина проспект, д.24	Россия, Пермский край, Нытвенский район, Нытва	0101000020E6100000117349D576A74B4079944A7842F74C40
72202	7	71	1009	8751	51742	\N	57.920403	г.Нытва, ул.Королева, д.33		0101000020E61000002579AEEFC3AB4B40F511F8C3CFF54C40
72209	7	71	1009	8751	54464	\N	57.920403	Пермский край, Нытвенский муниципальный район, Нытвенское городское поселение, г.Нытва, Комсомольская, 28		0101000020E61000002579AEEFC3AB4B40F511F8C3CFF54C40
72203	7	71	1009	8751	51474	\N	57.938280442110397	г.Нытва, ул.К.Маркса, д.76а	Россия, Пермский край, Нытвенский район, Нытва	0101000020E6100000EFC7ED974FAA4B40D53E1D8F19F84C40
72201	7	71	1009	8751	51596	\N	57.938109260790903	г. Нытва, ул.К.Либкнехта, д.118	Россия, Пермский край, Нытвенский район, Нытва	0101000020E610000056B77A4E7AAD4B40A88AA9F413F84C40
72208	7	71	1009	8751	53904	\N	57.920403	г.Нытва, ул.Белинского, д.35		0101000020E61000002579AEEFC3AB4B40F511F8C3CFF54C40
72213	7	71	1009	19308	52088	\N	57.905664000000002	поселок Новоильинский, ул.Первомайская, д.36		0101000020E6100000A3C9C51858BD4B40109546CCECF34C40
72211	7	71	1009	19308	52088	\N	57.905664000000002	поселок Новоильинский, ул.Первомайская, д.22		0101000020E6100000A3C9C51858BD4B40109546CCECF34C40
72212	7	71	1009	19308	51807	\N	57.905664000000002	поселок Новоильинский, ул.Ленина, д.35		0101000020E6100000A3C9C51858BD4B40109546CCECF34C40
72223	7	71	1009	19905	52091	\N	57.933402999999998	д.Н.Гаревая, ул.Молодежная, 2а		0101000020E61000001E3691990BA44B40807EDFBF79F74C40
72393	7	71	1009	32689	64422	\N	58.121288268525397	д.Мокино, у.Шоссейная, д.4	Россия, Пермский край, Нытвенский район, село Мокино	0101000020E610000068EC4B361EAA4B40D9B27C5D860F4D40
72230	7	71	1009	32689	52108	\N	58.122838999999999	с.Мокино, ул.Пономарева, 13б		0101000020E61000004679E6E5B0A94B4030D63730B90F4D40
72073	7	71	1009	47047	\N	\N	58.103247000000003	"""п.Майский, МОУ """"Майская СОШ"""""""	Россия, Пермский край, Нытвенский район, поселок Майский	0101000020E610000038F581E49DC94B407F349C32370D4D40
72233	7	71	1009	58246	64498	\N	57.954495798182002	д.Заполье, Школьная, 2а	Россия, Пермский край, Нытвенский район, село Заполье	0101000020E6100000B3EDB43522B44B40D714C8EC2CFA4C40
72923	7	71	1009	22033	\N	\N	58.253490314346102	с.Деменево, Администрация	Россия, Пермский край, Нытвенский район, село Деменево	0101000020E610000026FE28EACC9F4B4078EE3D5C72204D40
72236	7	71	1009	20694	52276	\N	57.878141999999997	Пермский край, Нытвенский муниципальный район, Чекменевское сельское поселение, д.Груни, ул.Центральная, д.6 (Клуб)		0101000020E6100000198F52094F884B403C9F01F566F04C40
72227	7	71	1009	45480	51733	\N	58.219940999999999	с.Григорьевское, ул.Школьная, д.13а		0101000020E6100000F5F75278D0B04B405706D506271C4D40
72228	7	71	1009	56303	52196	\N	58.218777421134298	ст.Григорьевская, Октябрьская, 26	Россия, Пермский край, Нытвенский район, село Григорьевская	0101000020E61000000AF65FE7A6A94B40FA0E7EE2001C4D40
72235	7	71	1009	20604	\N	\N	58.0161277926317	Пермский край, Нытвенский муниципальный район, Нытвенское городское поселение, с.Воробьи, школа	Россия, Пермский край, Нытвенский район, село Воробьи	0101000020E610000082C5E1CCAFB64B406346787B10024D40
72221	7	71	1009	32632	52224	\N	57.967588999999997	д.Белобородово, ул.Дружбы, д.2а	Россия, Пермский край, Нытвенский район, село Белобородово	0101000020E6100000B64B1B0E4BA94B40137CD3F4D9FB4C40
71742	7	71	1530	28365	52279	\N	57.896934287491497	деревня Шаква, Центральная, 1  Дом культуры	Россия, Пермский край, Лысьва городской округ, село Шаква	0101000020E61000005A0F5F268AC44C40D255BABBCEF24C40
72187	7	71	1530	18058	52098	\N	57.888154509449002	д.Сова, ул.Совхозная, д.19	Россия, Пермский край, Лысьва городской округ, село Сова	0101000020E6100000F1B913ECBFB04C40B2632310AFF14C40
72199	7	71	1530	18635	52035	\N	57.687350893320598	п.Рассоленки, ул.Мира, д.7	Россия, Пермский край, Лысьва городской округ, село Рассоленки	0101000020E6100000338CBB41B4504D40BBEF181EFBD74C40
72184	7	71	1530	56333	52270	\N	58.0552453685846	д.Олени, ул.Центральная, д.1	Россия, Пермский край, Лысьва городской округ, село Олени	0101000020E6100000ADA23F34F3CA4C403E22A64412074D40
72181	7	71	1530	56509	54249	\N	58.178014471562399	п.Обманка2, ул.Шмидта, д.6	Россия, Пермский край, Лысьва городской округ, село Обманка 2-я	0101000020E610000090A0F831E6FA4C40751DAA29C9164D40
72185	7	71	1530	56332	52269	\N	57.834054178129797	с.Новорождественское, ул.Школьная, д.3	Россия, Пермский край, Лысьва городской округ, село Новорождественское	0101000020E610000047AB5AD251BE4C408B8C0E48C2EA4C40
72191	7	71	1530	18241	52190	\N	58.003162173379202	п.Невидимка, ул.Школьная, д.4	Россия, Пермский край, Лысьва городской округ, село Невидимка	0101000020E61000005F0A0F9A5DF34C40844BC79C67004D40
72183	7	71	1530	56315	52226	\N	58.091942198775897	д.Липовая1, ул.Полевая, д.4а	Россия, Пермский край, Лысьва городской округ, село Липовая 1-я	0101000020E610000075ADBD4F55DF4C407E9065C1C40B4D40
72196	7	71	1530	18494	51473	\N	57.797274999999999	п.Кын, ул.Заречная, д.131		0101000020E6100000041C42959A414D408E75711B0DE64C40
72197	7	71	1530	18494	52195	\N	57.797504121081197	п.Кын, ул.Железнодорожная, д.49	Россия, Пермский край, Лысьва городской округ, поселок Кын	0101000020E610000054AC1A84B9414D40F0366F9C14E64C40
72198	7	71	1530	18626	\N	\N	57.866060212580102	с.Кын, Кыновской дом культуры	Россия, Пермский край, Лысьва городской округ, село Кын	0101000020E6100000C05AB56B42524D40D72FD80DDBEE4C40
73101	7	71	913	49063	\N	\N	59.863852000000001	д.Чирково, клуб		0101000020E6100000AA8251499D7E4B40C74ACCB392EE4D40
72195	7	71	1530	56376	52718	\N	57.8624957670649	п.Кумыш, ул.Куйбышева, д.6а	Россия, Пермский край, Лысьва городской округ, село Кумыш	0101000020E61000004F75C8CD702F4D402577D84466EE4C40
72190	7	71	1530	18202	51802	\N	57.860742000000002	п.Кормовище, ул.Советская, д.35		0101000020E6100000D498107349034D4096253ACB2CEE4C40
72188	7	71	1530	18086	\N	\N	57.816716606365503	с.Канабеки, Дом культуры	Россия, Пермский край, Лысьва городской округ, село Канабеки	0101000020E61000006F6589CE32A34C402A8BC22E8AE84C40
72182	7	71	1530	56283	52105	\N	58.139803000000001	д.Заимка, ул.Ленина, д.3	Россия, Пермский край, Лысьва городской округ, село Заимка	0101000020E6100000A5F5B704E0E54C40FC709010E5114D40
71801	7	71	1530	46177	52310	\N	57.980724000000002	д.ВерхЛысьва, ул.Гагарина, д.14		0101000020E6100000939048DBF8F34C407F33315D88FD4C40
72189	7	71	1530	56534	54359	\N	57.782008373996398	д.ВерхКултым, ул.Ленина, д.13	Россия, Пермский край, Лысьва городской округ, село Верх-Култым	0101000020E6100000618907944DB74C40ED9A90D618E44C40
72409	7	71	2763	56282	52097	\N	58.1518052986263	д.Крохово, у.Казанский тракт, д.21	Россия, Пермский край, Пермь, Камское водохранилище (р. Кама)	0101000020E6100000D2AC6C1FF2304C40452FA3586E134D40
73033	7	71	1372	27133	\N	\N	57.287266000000002	с. Юговское, Администрация сельского поселения		0101000020E61000009FAF592E1B354C405AA0DD21C5A44C40
71910	7	71	1372	58261	64541	\N	57.361871615708601	д. Шубино, ул. Рязанова, 29/а	Россия, Пермский край, Кунгурский район, село Шубино	0101000020E6100000D655815A0C744C4047AB5AD251AE4C40
73017	7	71	1372	26400	\N	\N	57.433422999999998	п. Шадейка, Центр досуга		0101000020E6100000BB44F5D6C0644C40C72AA5677AB74C40
73022	7	71	1372	26644	\N	\N	57.570096304264901	д. Чувирята, Клуб	Россия, Пермский край, Кунгурский район, село Чувирята	0101000020E6100000CD76853E58684C404BCADDE7F8C84C40
73012	7	71	1372	56268	\N	\N	57.428739660882201	"""с. Филипповка, бывшая контора ООО """"Сылвенский"""""""	Россия, Пермский край, Кунгурский район, село Филипповка	0101000020E610000098DEFE5C34844C40573ECBF3E0B64C40
73024	7	71	1372	47671	\N	\N	57.52346	"""д. Уфа, бывшая контора ООО """"Кыласовское"""""""		0101000020E61000007593180456644C40D061BEBC00C34C40
73038	7	71	1372	27376	\N	\N	57.215193999999997	с. УстьТурка, Дом культуры		0101000020E6100000BCB0355B794B4C40D0251C7A8B9B4C40
73027	7	71	1372	26868	\N	\N	57.465235	с. Троельга, Средняя школа		0101000020E6100000293C6876DD454C402FFA0AD28CBB4C40
73045	7	71	1372	56300	\N	\N	57.333793070339098	д. Теплая, Средняя школа	Россия, Пермский край, Кунгурский район, село Теплая	0101000020E61000007C2766BD18664C401E51A1BAB9AA4C40
73000	7	71	1372	25605	\N	\N	57.779730000000001	с. Серга, Средняя школа		0101000020E610000093A641D13C724C40E4DA5031CEE34C40
73050	7	71	1372	27917	\N	\N	57.302667999999997	п.Семсовхоз, Администрация сельского поселения		0101000020E610000093E1783E03804C40DAC534D3BDA64C40
73049	7	71	1372	58693	\N	\N	57.343910787209602	п.Садоягодный, Техникуминтернат	Россия, Пермский край, Кунгурский район, село Садоягодное	0101000020E6100000284701A2607A4C4009DE904605AC4C40
73001	7	71	1372	52933	\N	\N	57.774383999999998	д. Пустынники, Помещение библиотеки	Россия, Пермский край, Кунгурский район, село Пустынники	0101000020E61000009EEFA7C64B7B4C40D845D1031FE34C40
73016	7	71	1372	47535	\N	\N	57.428505000000001	"""д. Поповка, лыжная база """"Снежинка"""""""	Россия, Пермский край, Кунгурский район, село Поповка	0101000020E610000089B5F81400714C4014967840D9B64C40
73035	7	71	1372	51951	\N	\N	57.205590999999998	д.Подъельничная, помещение библиотеки	Россия, Пермский край, Кунгурский район, село Подъельничная	0101000020E6100000D00CE2033B164C400CAD4ECE509A4C40
73023	7	71	1372	26709	\N	\N	57.603993000000003	"""д.Подъельник, бывшая столовая ООО """"Кыласовское"""""""		0101000020E61000007FD93D7958624C40A80183A44FCD4C40
72999	7	71	1372	25601	\N	\N	57.872399000000001	с.Насадка, Центр Досуга		0101000020E6100000DBC01DA853644C4014083BC5AAEF4C40
73014	7	71	1372	47497	\N	\N	57.615569999999998	с. Моховое, Центр досуга		0101000020E6100000C7B8E2E2A86C4C4009336DFFCACE4C40
72998	7	71	1372	47497	\N	\N	57.6158588348191	д. Моховое, помещение ФАП	Россия, Пермский край, Кунгурский район, село Моховое	0101000020E6100000CCF09F6EA06C4C4040F9BB77D4CE4C40
73047	7	71	1372	48101	\N	\N	57.419598000000001	"""д.Мериново, контора ООО """"ЛСК"""""""		0101000020E6100000CE33F6251B774C40C7BB2363B5B54C40
73032	7	71	1372	27104	\N	\N	57.313595999999997	с. Мазунино, Администрация сельского поселения		0101000020E610000015C8EC2C7A414C400514EAE923A84C40
71888	7	71	1372	56321	\N	\N	57.459374972675697	с. Липово, здание клуба с. Липово	Россия, Пермский край, Кунгурский район, село Липово	0101000020E61000001FD8F15F206E4C40CDCCCCCCCCBA4C40
73040	7	71	1372	27463	\N	\N	57.301073000000002	с.Ленск, Администрация сельского поселения		0101000020E6100000FCA886FD9E544C40B45A608F89A64C40
73028	7	71	1372	47730	\N	\N	57.511146430525301	д. Кужлево, ФАП д. Кужлево	Россия, Пермский край, Кунгурский район, село Кужлево	0101000020E6100000782975C938444C4098BD6C3B6DC14C40
73004	7	71	1372	25837	\N	\N	57.646744982968997	с.Кинделино, Начальная школа	Россия, Пермский край, Кунгурский район, село Кинделино	0101000020E610000061FE0A992B6B4C40FFEC478AC8D24C40
73006	7	71	1372	25901	\N	\N	57.546723	с. Каширино, Дом культуры		0101000020E610000052B5DD04DF6C4C404A7CEE04FBC54C40
73031	7	71	1372	32722	\N	\N	57.3307012772391	с. Калинино, Школаинтернат	Россия, Пермский край, Кунгурский район, село Калинино	0101000020E61000000F0D8B51D72A4C4093E00D6954AA4C40
72994	7	71	1372	32722	\N	\N	57.329385948421297	с. Калинино, Средняя школа	Россия, Пермский край, Кунгурский район, село Калинино	0101000020E61000000B7BDAE1AF2B4C4050E1085229AA4C40
73020	7	71	1372	26517	\N	\N	57.497033999999999	д. Казаево, Дом культуры		0101000020E6100000E57CB1F7E2574C40028063CF9EBF4C40
72997	7	71	1372	47135	\N	\N	57.950467000000003	пос.Ильича, помещение ФАП	Россия, Пермский край, Кунгурский район, поселок Ильича	0101000020E6100000E2E5E95C51684C40B07614E7A8F94C40
73005	7	71	1372	25853	\N	\N	57.577249000000002	с. Зарубино, Центр досуга		0101000020E61000001D588E90817A4C400953944BE3C94C40
73018	7	71	1372	47563	\N	\N	57.471237000000002	с. Жилино, Центр Досуга		0101000020E6100000FC1BB4571F654C4024D5777E51BC4C40
73235	7	71	913	58300	64616	\N	60.215318785437702	д.Трифаново, Молодёжная, д. 1, кв. 1		0101000020E61000001A1A4F04716A4B408D9AAF928F1B4E40
72859	7	71	1372	56276	52089	\N	57.512689781801697	д.Ерзовка, ул.Чапаева, д.22	Россия, Пермский край, Кунгурский район, село Ерзовка	0101000020E6100000350A4966F5904C403D7E6FD39FC14C40
73026	7	71	1372	56334	\N	\N	57.506744357238198	"""д. Ергач, магазин СПО """"Кыласовское"""""""	Россия, Пермский край, Кунгурский район, село Ергач	0101000020E61000007E3672DD944E4C40DCB8C5FCDCC04C40
73019	7	71	1372	26483	\N	\N	57.488337000000001	пос.Ергач, Средняя школа		0101000020E6100000D6C4025FD15B4C40A036AAD381BE4C40
73015	7	71	1372	58199	\N	\N	57.480363700754197	д. Дейково, бывшее помещение ФАП	Россия, Пермский край, Кунгурский район, село Дейково	0101000020E61000002A3BFDA02E704C407F164B917CBD4C40
72959	7	71	1372	23675	\N	\N	57.511499818373402	д. Гробово, Клуб	Россия, Пермский край, Кунгурский район, село Гробово	0101000020E6100000E7FD7F9C308F4C40B6F3FDD478C14C40
71879	7	71	1372	58268	\N	\N	57.491677455590903	с. Голубята, здание администрации	Россия, Пермский край, Кунгурский район, село Голубята	0101000020E6100000B43D7AC37D604C4003999D45EFBE4C40
73051	7	71	1372	27966	\N	\N	57.263131000000001	п.Голдыревский, Средняя школа		0101000020E61000008E3D7B2E53854C402AC8CF46AEA14C40
73041	7	71	1372	27526	\N	\N	57.292771999999999	"""д.Веслянка, контора АП """"Заря"""""""		0101000020E61000009F5A7D7555584C409E978A8D79A54C40
73043	7	71	1372	27618	\N	\N	57.390326000000002	п.Бымок, Дом культуры		0101000020E610000087FC3383F84E4C40A663CE33F6B14C40
73030	7	71	1372	26976	\N	\N	57.433767000000003	с.Бым, Дом культуры		0101000020E61000008D9944BDE0294C40C28A53AD85B74C40
73025	7	71	1372	56490	\N	\N	57.575383748130299	"""д. Ботово, магазин СПО """"Кыласовское"""""""	Россия, Пермский край, Кунгурский район, село Ботово	0101000020E6100000B5E0455F41524C402252D32EA6C94C40
72253	7	71	1372	56289	\N	\N	57.523358827980701	с.Богородск, библиотека	Россия, Пермский край, Кунгурский район, село Богородск	0101000020E61000005A9D9CA1B8274C409C887E6DFDC24C40
73044	7	71	1372	56382	\N	\N	57.389637132712799	д.Блины, бывшее помещение ФАП	Россия, Пермский край, Кунгурский район, село Блины	0101000020E61000008FE4F21FD23D4C40E1270EA0DFB14C40
73013	7	71	1372	47467	\N	\N	57.423431000000001	д.Беркутово, Дом Культуры		0101000020E6100000D1967329AE824C40698EACFC32B64C40
71713	7	71	1372	48933	51529	\N	57.191679000000001	село Березовка, Центральная, 33   Центр детского творчества		0101000020E6100000707CED9925074C403D2AFEEF88984C40
73039	7	71	1372	27409	\N	\N	57.190519000000002	д. Бажуки, Дом культуры		0101000020E6100000B6494563ED3F4C40212235ED62984C40
72868	7	71	1372	56274	52084	\N	57.2917850334861	с.Бабка, ул.Октябрьская, д.17	Россия, Пермский край, Кунгурский район, село Бабка	0101000020E6100000B9C3263273FD4B404F3BFC3559A54C40
72131	7	71	7404	56240	51699	\N	57.409301296996802	Пермский край, Кунгурский городской округ, Просвещения, 2	Россия, Пермский край, Кунгур городской округ	0101000020E61000007E569929AD7B4C402C9CA4F963B44C40
72147	7	71	7404	56240	51705	\N	57.432454809384303	Пермский край, Кунгурский городской округ, Голованова, 36		0101000020E6100000790261A7587D4C40EFFE78AF5AB74C40
72102	7	71	1074	13907	9845	\N	56.550566036633199	с. Федоровск, ул. Клубная, 1	Россия, Пермский край, Куединский район, село Федоровск	0101000020E6100000109370218FCA4B4010255AF278464C40
72095	7	71	1074	13571	53862	\N	56.420262887405002	с. Урталга, ул. Победы, 38	Россия, Пермский край, Куединский район, село Урталга	0101000020E6100000AD4F39268BBF4B40035C902DCB354C40
72118	7	71	1074	14649	53888	\N	56.414633000000002	д. Урада, ул. А. Игнатьева, 37		0101000020E6100000DEAAEB504D6F4B40D36BB3B112354C40
72117	7	71	1074	14617	52267	\N	56.493516	д. Узяр, ул. Центральная, 4		0101000020E6100000367689EAAD634B40C00644882B3F4C40
72094	7	71	1074	13522	52252	\N	56.455170000000003	д. Трегубовка, ул. Заречная, 16		0101000020E610000057276728EECC4B40670FB402433A4C40
72109	7	71	1074	14225	52102	\N	56.452294000000002	с. Старый Шагирт, ул. Школьная, 3		0101000020E610000021938C9C85994B40A91611C5E4394C40
72101	7	71	1074	13833	53870	\N	56.450980999999999	с. Русские Чикаши, ул. Дружбы, 2		0101000020E610000035423F53AFE74B40060FD3BEB9394C40
72107	7	71	1074	14147	53443	\N	56.349121765827597	п. Рабак, ул. Центральная, 8	Россия, Пермский край, Куединский район, поселок Рабак	0101000020E610000043E55FCB2BA14B4035289A07B02C4C40
71740	7	71	1074	56337	52301	\N	56.506719066963903	село Покровка, Центральная, 23 Дом культуры	Россия, Пермский край, Куединский район, село Покровка	0101000020E6100000F23FF9BB77D04B4083A10E2BDC404C40
72120	7	71	1074	14768	53446	\N	56.606484999999999	с. Пантелеевка, ул. Центральная, 38		0101000020E6100000FCABC77DAB6F4B40DD41EC4CA14D4C40
72116	7	71	1074	14567	52031	\N	56.504252999999999	с. Ошья, ул. Школьная, 7		0101000020E610000025C9737D1F704B4077F4BF5C8B404C40
72121	7	71	1074	13226	51692	\N	56.430221000000003	п. Куеда, ул. Школьная, д.23		0101000020E61000007C629D2ADFC94B40B686527B11374C40
72093	7	71	1074	13226	64557	\N	56.430458247680797	д. Куеда, ул. Центральная, 39	Россия, Пермский край, Куединский район, поселок Куеда	0101000020E61000003126FDBD14CA4B409A266C3F19374C40
72092	7	71	1074	13226	52026	\N	56.430221000000003	п. Куеда, ул. Трактовая, д.24		0101000020E61000007C629D2ADFC94B40B686527B11374C40
72122	7	71	1074	13226	51693	\N	56.430221000000003	п. Куеда, ул. Ленина, д. 15		0101000020E61000007C629D2ADFC94B40B686527B11374C40
72090	7	71	1074	13226	52189	\N	56.430221000000003	п. Куеда, ул. Комсомольская, д.13		0101000020E61000007C629D2ADFC94B40B686527B11374C40
72091	7	71	1074	13226	52124	\N	56.430221000000003	п. Куеда, ул. Карла Маркса, д.13б		0101000020E61000007C629D2ADFC94B40B686527B11374C40
72088	7	71	1074	13226	52124	\N	56.430221000000003	п. Куеда, ул. Карла Маркса, д.28		0101000020E61000007C629D2ADFC94B40B686527B11374C40
72089	7	71	1074	13226	51794	\N	56.430221000000003	п. Куеда, ул. Гагарина, д.27		0101000020E61000007C629D2ADFC94B40B686527B11374C40
72108	7	71	1074	32579	53128	\N	56.353619000000002	д. Кирга, ул. Садовая, 1		0101000020E61000002733DE567A954B40431F2C63432D4C40
72106	7	71	1074	32564	52693	\N	56.388720999999997	д. Кипчак, ул. Школьная, 2		0101000020E610000098DF6932E3B54B405B22179CC1314C40
73254	7	71	1074	47663	52120	\N	56.467846999999999	п.Кама, Пионерская, 8		0101000020E61000004C55DAE21A814B400F441669E23B4C40
72099	7	71	1074	13757	52255	\N	56.535744999999999	д. Искильда, ул. Пилорамная, 1		0101000020E6100000BF0AF0DDE6D34B406DFFCA4A93444C40
73042	7	71	1074	56353	\N	\N	56.450112057184803	д.Змеевка, клуб	Россия, Пермский край, Куединский район, село Змеевка	0101000020E6100000FEB627486C654B40C1C41F459D394C40
72103	7	71	1074	13924	53878	\N	56.667388000000003	с. Земплягаш, ул. Новая, 11		0101000020E61000004089CF9D60AD4B4016DF50F86C554C40
72115	7	71	1074	14515	52261	\N	56.674655912896	д. Дойная, ул. Школьная, 1	Россия, Пермский край, Куединский район, село Дойная	0101000020E610000007EDD5C743834B406C06B8205B564C40
72111	7	71	1074	56318	52232	\N	56.362436920053497	с. Центральная Усадьба 3го Госконезавода, ул. Советская, 24	Россия, Пермский край, Куединский район, село Госконезавод 3	0101000020E6100000139B8F6B438B4B4020EEEA55642E4C40
72110	7	71	1074	14292	52256	\N	56.525568999999997	д. Гожан, ул. Центральная, 1		0101000020E61000008C84B69C4B994B404D6551D845434C40
72114	7	71	1074	58293	64608	\N	56.682104534688399	д. ВерхУса, ул. Центральная, 17		0101000020E6100000C72E51BD35984B4013B875374F574C40
72112	7	71	1074	14376	52087	\N	56.454174999999999	с. Верхняя Сава, ул. Центральная, 37		0101000020E6100000228B34F10E8C4B4095D40968223A4C40
72096	7	71	1074	13624	53441	\N	56.561255000000003	с. Большой Талмаз, ул. Центральная, 14		0101000020E61000007F8978EBFCAD4B40B6DB2E34D7474C40
72097	7	71	1074	33136	63484	\N	56.523617000000002	д. Каскасал, ул. Центральная, 10		0101000020E6100000BE4F55A181BA4B409850C1E105434C40
72105	7	71	1074	14017	51591	\N	56.375121373390499	с. Большой Гондыр, ул. 40 лет Победы	Россия, Пермский край, Куединский район, село Большой Гондыр	0101000020E61000008731E9EFA5AA4B407B8505F703304C40
72119	7	71	1074	14700	52188	\N	56.594760999999998	с. Большие Кусты, ул. Зеленая, 147		0101000020E610000086E7A56263824B40D7F7E120214C4C40
72113	7	71	1074	14430	51685	\N	56.739953999999997	с. Большая Уса, ул. Школьная, 8		0101000020E6100000E4F90CA8378D4B40AE450BD0B65E4C40
72100	7	71	1074	13785	53442	\N	56.478521000000001	с. Бикбарда, ул. Школьная, 9		0101000020E610000073BC02D193DC4B4080B9162D403D4C40
72098	7	71	1074	13699	52688	\N	56.499229999999997	с. Аряж, ул. Центральная, 27		0101000020E6100000A8E15B5837CC4B404E97C5C4E63F4C40
73185	7	71	96	2264	52313	\N	59.351410999999999	д. Эрна, Центральная, 3		0101000020E610000012842BA050AF4B40323A2009FBAC4D40
73151	7	71	96	45549	52244	\N	59.134197999999998	д. Шадрина, Школьная, 13		0101000020E610000013286211C3304B4024986A662D914D40
73155	7	71	96	473	53703	\N	59.103172999999998	д. Тебенькова, Школьная, 3		0101000020E6100000C746205ED71D4B40446ADAC5348D4D40
73183	7	71	96	56532	54346	\N	59.187421551091902	д. СюзьПозья, Медицинская, 3	Россия, Пермский край, Кудымкарский район, село Сюзь-Позья	0101000020E6100000711B0DE02D6E4B408446B071FD974D40
73175	7	71	96	1668	53154	\N	58.766219999999997	д. Сылвож, Молодежная, 3		0101000020E6100000F33977BB5E604B4043C5387F13624D40
73186	7	71	96	46297	52109	\N	58.982449000000003	д. Степанова, Сазонова, 10		0101000020E610000083FB010F0C5A4B40747E8AE3C07D4D40
73149	7	71	96	58307	64631	\N	59.047576371464999	д. Кузьва, Центральная, 14	Россия, Пермский край, Кудымкарский район, село Старая Кузьва	0101000020E6100000EB6F09C03F254B4089096AF816864D40
73162	7	71	96	903	53708	\N	58.937397058928703	с. Самково, Транспортная, 17	Россия, Пермский край, Кудымкарский район, село Самково	0101000020E6100000BCB376DB850A4B402B2FF99FFC774D40
73177	7	71	96	1778	52290	\N	58.666255	д. Ракшина, Полевая, 7		0101000020E61000006283859334594B40F3E505D847554D40
73159	7	71	96	58342	64769	\N	58.894628457491599	д. Разина, Центральная, 2	Россия, Пермский край, Кудымкарский район, село Разина	0101000020E610000074452921583B4B40FE0A992B83724D40
73176	7	71	96	46055	\N	\N	58.734963999999998	д. Пятина, 7		0101000020E610000085949F54FB664B4061DEE34C135E4D40
73169	7	71	96	1316	52953	\N	59.076458000000002	д. Поносова, Садовая, 2		0101000020E61000005E2F4D11E0744B4040C23060C9894D40
73178	7	71	96	1811	52432	\N	58.6666666759482	с. Полва, Школьная, 9	Россия, Пермский край, Кудымкарский район, село Полва	0101000020E61000009B5434D6FE3A4B404529215855554D40
73187	7	71	96	2381	51537	\N	58.966242999999999	с. Пешнигорт, Голева, 15		0101000020E61000009E060C923E494B40957EC2D9AD7B4D40
73137	7	71	96	58279	\N	\N	58.858267477991802	д.Петухово, Здание Петуховского сельского клуба	Россия, Пермский край, Кудымкарский район, поселок Петухово	0101000020E61000000397C79A91654B40361E6CB1DB6D4D40
73152	7	71	96	56506	54230	\N	59.179379327798799	д. Перкова, Центральная, 10	Россия, Пермский край, Кудымкарский район, село Перкова	0101000020E61000003CDEE4B7E8324B406A4B1DE4F5964D40
73179	7	71	96	56286	52121	\N	59.219497291588397	с. Ошиб, Центральная, 3	Россия, Пермский край, Кудымкарский район, село Ошиб	0101000020E610000004ABEAE577704B40F9484A7A189C4D40
73150	7	71	96	121	54143	\N	59.068899999999999	с. Отево, Степана Караваева, 11		0101000020E610000002D4D4B2B5484B40E25817B7D1884D40
71922	7	71	96	45748	\N	\N	59.012103672037497	д.Москвина, здание школы	Россия, Пермский край, Кудымкарский район, село Москвина	0101000020E610000028B9C32632174B404D13B69F8C814D40
73161	7	71	96	45748	52311	\N	59.011702999999997	д. Москвина, Центральная, 1		0101000020E6100000C7BDF90D13174B40EE21E17B7F814D40
73170	7	71	96	1369	53716	\N	59.163156530209001	д. Мижуева, Колхозная, 8	Россия, Пермский край, Кудымкарский район, село Мижуева	0101000020E6100000083A5AD5925A4B40868E1D54E2944D40
73181	7	71	96	2039	54493	\N	59.269855	д. Мелехина, Центральная,11		0101000020E610000078EFA831218C4B40BFD4CF9B8AA24D40
73157	7	71	96	45665	52281	\N	59.114072	д. Мальцева, Мира, 12		0101000020E610000097FE25A94C294B40D5B14AE9998E4D40
73189	7	71	96	2470	51538	\N	59.020741000000001	д. Малая Серва, Зеленая, 1		0101000020E610000039D4EFC2D65C4B40DA571EA4A7824D40
73173	7	71	96	45983	52211	\N	58.721753	с. Ленинск, Попова, 9		0101000020E61000000932022A1C594B401B65FD66625C4D40
73154	7	71	96	418	52135	\N	59.127161000000001	с. Кува, Ленина, 1		0101000020E61000007D3F355EBA154B40D029C8CF46904D40
73168	7	71	96	1270	52193	\N	59.111258999999997	д. Корчевня, Центральная, 50а		0101000020E610000086747808E3714B405D3123BC3D8E4D40
73184	7	71	96	56520	54282	\N	59.1998829005964	д. Конанова, Дружбы, 29	Россия, Пермский край, Кудымкарский район, село Конанова	0101000020E6100000DD7A4D0F0A624B40600322C495994D40
73153	7	71	96	365	52971	\N	59.186438141065203	д. Карбас, Центральная, 16	Россия, Пермский край, Кудымкарский район, село Карбас	0101000020E6100000821FD5B0DF414B40A75D4C33DD974D40
73182	7	71	96	40406	52162	\N	59.094774999999998	д. Егорова, Медицинская, 10		0101000020E6100000C26856B60F2F4B403CBD5296218C4D40
73167	7	71	96	1216	52099	\N	59.107142000000003	с. Егва, Советская, 5		0101000020E6100000B6679604A8634B4097033DD4B68D4D40
73160	7	71	96	45723	54522	\N	59.028855999999998	д. Демина, Центральная, 27		0101000020E61000000BD5CDC5DF4E4B408D25AC8DB1834D40
73171	7	71	96	45949	64376	\N	59.177227000000002	д. Гурина, Центральная, 36		0101000020E61000007731CD74AF574B40EE7BD45FAF964D40
73107	7	71	913	30561	\N	\N	59.883397431088	д.Чазево, клуб	Россия, Пермский край, Косинский район, село Чазево	0101000020E61000005F7CD11E2F444B403831242713F14D40
73164	7	71	96	56547	54631	\N	58.931026843852401	п. Веселый Мыс, Транспортная, 3	Россия, Пермский край, Кудымкарский район, село Веселый Мыс	0101000020E6100000B131AF230EF94A40B4588AE42B774D40
73174	7	71	96	56307	52209	\N	58.834730267284797	с. ВерхЮсьва, Центральная, 15	Россия, Пермский край, Кудымкарский район, село Верх-Юсьва	0101000020E61000007500C45DBD544B40BB7EC16ED86A4D40
73158	7	71	96	56248	51827	\N	58.929791453343299	с. ВерхИньва, Октябрьская, 10	Россия, Пермский край, Кудымкарский район, село Верх-Иньва	0101000020E6100000340F60915F2B4B40BD8E386403774D40
73180	7	71	96	56517	54276	\N	59.234165079681603	п. ВелваБаза, Школьная, 6	Россия, Пермский край, Кудымкарский район, село Велва-База	0101000020E61000000266BE839F884B40156F641EF99D4D40
73165	7	71	96	1107	64577	\N	59.006507999999997	п. Буждом, Центральная, 7		0101000020E6100000E42CEC69870B4B40C8940F41D5804D40
73156	7	71	96	527	52282	\N	59.111359999999998	д. Большая Сидорова, Центральная, 19		0101000020E6100000A5C00298320E4B40910A630B418E4D40
73148	7	71	96	32491	51713	\N	59.141801000000001	с.Белоево, Ленина, 21		0101000020E6100000325871AAB53E4B4022C5008926924D40
73172	7	71	96	1499	54164	\N	59.132618999999998	д. Алекова, Колхозная, 5		0101000020E6100000CCB8A981E6574B4003EACDA8F9904D40
72076	7	71	4039	58125	63741	\N	58.138026000000004	Краснокамский район, ст. Шабуничи, ул. Железнодорожная, д.12		0101000020E61000008D9944BDE0D74B40B5FF01D6AA114D40
72075	7	71	1228	56304	52199	\N	58.141047	с.Черная, ул.Северная, д.6	Россия, Пермский край, Краснокамск городской округ, село Черная	0101000020E6100000C45E28603BDE4B407619FED30D124D40
72074	7	71	1228	47074	52685	\N	58.045783999999998	с.УстьСыны, ул.Совхозная, д.14		0101000020E6100000FFE7305F5ECA4B400C570740DC054D40
72083	7	71	1228	13002	51460	\N	58.180304999999997	с.Стряпунята, ул.Советская, д.4	Россия, Пермский край, Краснокамск городской округ, село Стряпунята	0101000020E6100000448A01124DFA4B401327F73B14174D40
73002	7	71	1228	25707	\N	\N	58.175823000000001	д. Осташата, Дом культуры		0101000020E6100000D865F84F370E4C403B71395E81164D40
72072	7	71	1228	12477	81120	\N	58.092737	п.Оверята, пер.Клубный, д.4	Россия, Пермский край, Краснокамск городской округ, поселок Оверята	0101000020E6100000459C4EB2D5ED4B40881057CEDE0B4D40
72071	7	71	1228	12477	81119	\N	58.092737	п.Оверята, ул.Строителей, д.7	Россия, Пермский край, Краснокамск городской округ, поселок Оверята	0101000020E6100000459C4EB2D5ED4B40881057CEDE0B4D40
72082	7	71	1228	62086	81122	\N	58.062545999999998	с.Мысы, ул.Центральная, д.1	Россия, Пермский край, Краснокамск городской округ, село Мысы	0101000020E610000043E55FCB2BF54B40703FE08101084D40
72053	7	71	1228	56313	81109	\N	58.072929000000002	д.КонецБор, ул.Циолковского, д.2	Россия, Пермский край, Краснокамск городской округ, село Конец Бор	0101000020E6100000D13DEB1A2DD34B400AF7CABC55094D40
71875	7	71	1228	56341	\N	\N	58.237229966285298	д. Залесная, здание администрации	Россия, Пермский край, Краснокамск городской округ, село Залесная	0101000020E61000003B730F09DFE54B40A6D0798D5D1E4D40
72015	7	71	1028	9759	53170	\N	60.129268039854999	п.Цепёл, ул. Первомайская,22,здание клуба	Россия, Пермский край, Красновишерский район, село Цепел	0101000020E610000011E15F048DAD4C40AD3594DA8B104E40
72026	7	71	1028	10260	53858	\N	60.332883000000002	"""д.Федорцова, ул. Центральная, 40,  здание бывшей конторы п/х """"Вишерское"""""""		0101000020E6100000F8C1F9D4B1644C407B32FFE89B2A4E40
72027	7	71	1028	10349	\N	\N	60.368291999999997	п.УстьЯзьва, здание школы	Россия, Пермский край, Красновишерский район, село Усть-Язьва	0101000020E610000069E04735EC654C4070B03731242F4E40
72046	7	71	1028	11239	\N	\N	60.552146835699702	пос.Сыпучи, здание клуба	Россия, Пермский край, Красновишерский район, село Сыпучи	0101000020E6100000A9FB00A436E74C40D1CABDC0AC464E40
72024	7	71	1028	10180	52083	\N	60.121259999999999	п.Северный Колчим, ул. Победы, 12, здание школы		0101000020E61000009831056B9CE34C400F289B72850F4E40
72310	7	71	1028	56294	52159	\N	60.258060641109701	п.Светлый, Промышленная, 6	Россия, Пермский край, Красновишерский район, нежилые населённые пункты Светлый	0101000020E6100000268A90BA9DCD4C40C0AF912408214E40
72038	7	71	1028	46315	53437	\N	60.444223999999998	"""п.Набережный, ул.Геологов, 1, здание ДК """"Геолог"""""""		0101000020E610000064CA87A06A8A4C40950C0055DC384E40
72047	7	71	1028	10518	52681	\N	60.445777999999997	пос.Мутиха, Силовая, 8		0101000020E61000002A1A6B7F67FD4C405DA3E5400F394E40
72014	7	71	1028	9164	\N	\N	60.402538999999997	"""г.Красновишерск, здание клуба """"Нефтяник"""""""	Россия, Пермский край, Красновишерский район, Красновишерск	0101000020E6100000A1F2AFE595874C40A92EE06586334E40
72009	7	71	1028	9164	51589	\N	60.414788514751699	г.Красновишерск, Школьная, 5	Россия, Пермский край, Красновишерский район, Красновишерск	0101000020E6100000815B77F3548B4C40CADE52CE17354E40
72008	7	71	1028	9164	51681	\N	60.399058560442903	г.Красновишерск, Спортивная, 18	Россия, Пермский край, Красновишерский район, Красновишерск	0101000020E610000047ACC5A7008A4C405516855D14334E40
72006	7	71	1028	9164	51789	\N	60.402538999999997	г.Красновишерск, Советская, 19		0101000020E6100000A1F2AFE595874C40A92EE06586334E40
72007	7	71	1028	9164	51679	\N	60.402538999999997	г.Красновишерск, Куйбышева, 11		0101000020E6100000A1F2AFE595874C40A92EE06586334E40
72004	7	71	1028	9164	53412	\N	60.399143492958103	г.Красновишерск, Комсомольская, 43	Россия, Пермский край, Красновишерский район, Красновишерск	0101000020E61000000DE198654F8A4C40B3B6291E17334E40
72005	7	71	1028	9164	51455	\N	60.402538999999997	г.Красновишерск, Дзержинского, 9 Б		0101000020E6100000A1F2AFE595874C40A92EE06586334E40
72012	7	71	1028	9164	52250	\N	60.402538999999997	г.Красновишерск, ул.7го Ноября, 24		0101000020E6100000A1F2AFE595874C40A92EE06586334E40
72049	7	71	1028	11405	52253	\N	60.476449000000002	пос.Золотанка, ул.Центральная, 16, здание клуба		0101000020E61000005C1E6B46064B4D40209BE447FC3C4E40
72040	7	71	1028	10987	52508	\N	60.4965806845115	д.Заговоруха, ул. Мира, 11, здание клуба	Россия, Пермский край, Красновишерский район, село Заговоруха	0101000020E6100000300DC347C4A44C40516859F78F3F4E40
72029	7	71	1028	10424	52248	\N	60.363438000000002	п.Данилов Луг, ул.Набережная, 11А,  здание клуба		0101000020E6100000925CFE43FA614C40D40FEA22852E4E40
72045	7	71	1028	46490	\N	\N	60.371704000000001	пос.Волынка, здание ФАП пос. Волынка МЛПУ КРБ	Россия, Пермский край, Красновишерский район, село Волынка	0101000020E6100000745DF8C1F9DA4C406DE525FF932F4E40
72043	7	71	1028	11084	53432	\N	60.459519999999998	п.Вишерогорск, ул. Пионерская, 9, здание СДК		0101000020E6100000098D60E3FAAD4C40D0ED258DD13A4E40
60217	7	71	1028	10907	52294	\N	60.145412	дер.Бычина, Новая, 10		0101000020E61000008109DCBA9BA34C40153944DC9C124E40
72018	7	71	1028	8968	52228	\N	60.099818693025902	с.ВерхЯзьва, ул. Советская, 28, здание администрации ВерхЯзьвинского СП	Россия, Пермский край, Красновишерский район, село Верх-Язьва	0101000020E61000009AEC9FA701B94C407C4276DEC60C4E40
72051	7	71	1028	11510	53436	\N	60.735852999999999	пос.Вёлс, ул. Северная, 15, здание школы		0101000020E6100000416150A6D1644D40EDD45C6E305E4E40
72048	7	71	1028	10591	53427	\N	60.596656000000003	пос.Вая, Гагарина, 17 Б		0101000020E61000005AA0DD21C5304D40297B4B395F4C4E40
72021	7	71	1028	10067	53421	\N	60.027624000000003	д.Ванькова,ул. Новая,6,  здание библиотеки		0101000020E6100000DA3C0E83F9D14C40D84AE82E89034E40
72035	7	71	1028	56500	54191	\N	60.229877743352297	п.Березовая Старица, ул. Трактовая, 6, здание клуба	Россия, Пермский край, Красновишерский район, село Березовая Старица	0101000020E6100000F65CA626C14B4C40F2086EA46C1D4E40
73141	7	71	934	45379	\N	\N	59.866973999999999	с.Юксеево, Здание Юксеевского Дома культуры	Россия, Пермский край, Кочевский район, село Юксеево	0101000020E610000094347F4C6B294B40BC3D0801F9EE4D40
73124	7	71	934	31406	\N	\N	59.543441999999999	д.Хазово, Здание Хазовской основной общеобразовательной школы	Россия, Пермский край, Кочевский район, село Хазово	0101000020E6100000CF83BBB3761F4B40ECA2E8818FC54D40
73125	7	71	934	7524	\N	\N	59.525477464416198	п.УстьЯнчер, Устьянчерский ФАП		0101000020E6100000B0045262D7084B406DE690D442C34D40
73143	7	71	934	58232	\N	\N	59.824980889372398	п.УстьСилайка, Здание УстьСилайской основной общеобразовательной школы	Россия, Пермский край, Кочевский район, село Усть-Силайка	0101000020E6100000CBF6216FB9FC4A40236937FA98E94D40
73147	7	71	934	58115	\N	\N	59.614400824266497	п.УстьОнолва, Здание УстьОнолвинской основной общеобразовательной школы	Россия, Пермский край, Кочевский район, село Усть-Онолва	0101000020E6100000B0C56E9F55684B409AD024B1A4CE4D40
73142	7	71	934	32207	\N	\N	59.887083218445902	п.Серва, Здание Сервинской основной общеобразовательной школы	Россия, Пермский край, Кочевский район, село Серва	0101000020E610000008E9297288184B4035EB8CEF8BF14D40
73126	7	71	934	31487	\N	\N	59.540298999999997	д.Сеполь, Здание Сепольской основной общеобразовательной школы	Россия, Пермский край, Кочевский район, село Сеполь	0101000020E61000000A12DBDD033E4B40DF87838428C54D40
73130	7	71	934	31686	\N	\N	59.678258	д.Пыстогово, Здание Пыстоговского сельского клуба	Россия, Пермский край, Кочевский район, село Пыстогово	0101000020E610000024ED461FF3374B400C207C28D1D64D40
73135	7	71	934	31897	\N	\N	59.730584	с.Пелым, Здание Пелымской средней общеобразовательной  школы	Россия, Пермский край, Кочевский район, село Пелым	0101000020E6100000D845D1031F2F4B408D7DC9C683DD4D40
73136	7	71	934	31983	\N	\N	59.760103999999998	д.Отопково, Здание Отопковского фельдшерскоакушерского пункта	Россия, Пермский край, Кочевский район, село Отопково	0101000020E61000004147AB5AD2334B4086C77E164BE14D40
73140	7	71	934	45356	\N	\N	59.824393999999998	д.Москвино,  Москвинский ФАП		0101000020E61000008E78B29B19314B4062821ABE85E94D40
73145	7	71	934	32331	\N	\N	59.697939917746297	п.Мараты, Здание Администрации Маратовского сельского поселения	Россия, Пермский край, Кочевский район, село Мараты	0101000020E610000014967840D9764B40FE48111956D94D40
73133	7	71	934	31889	\N	\N	59.653952865713698	д.МараПальник,  МараПальниковский ФАП		0101000020E6100000D6E1E82ADD5F4B40800F5EBBB4D34D40
73123	7	71	934	31359	\N	\N	59.594705342458603	д.Лягаево, Здание Лягаевского сельского клуба	Россия, Пермский край, Кочевский район, село Лягаево	0101000020E610000001C11C3D7E1B4B4043E21E4B1FCC4D40
73121	7	71	934	31258	\N	\N	59.598502000000003	д.Кышка, Здание Кышкинского сельского клуба	Россия, Пермский край, Кочевский район, село Кышка	0101000020E610000019390B7BDA354B40994BAAB69BCC4D40
73127	7	71	934	48272	\N	\N	59.536521	д.Кукушка,  Кукушкинский ФАП		0101000020E6100000143DF03158334B40014F5AB8ACC44D40
73128	7	71	934	16095	\N	\N	59.527797	п.Красная Курья, Здание Краснокурьинского фельдшерскоакушерского пункта	Россия, Пермский край, Кочевский район, село Красная Курья	0101000020E610000070E998F38C4D4B40A5F622DA8EC34D40
73118	7	71	934	31095	52133	\N	59.60107	с.Кочево, ул.Ленина, 10		0101000020E61000005B5CE333D9274B40A94D9CDCEFCC4D40
73119	7	71	934	31095	52043	\N	59.60107	с.Кочево, ул. А.Хомяковой, 1		0101000020E61000005B5CE333D9274B40A94D9CDCEFCC4D40
73120	7	71	934	31095	52136	\N	59.60107	с.Кочево, ул. 50 лет Октября, 11		0101000020E61000005B5CE333D9274B40A94D9CDCEFCC4D40
72759	7	71	934	56271	52061	\N	59.579874645023502	дер. Васькино, Пушкина, 47	Россия, Пермский край, Кочевский район, село Васькино	0101000020E6100000FDA204FD851C4B404E62105839CA4D40
73146	7	71	934	32400	\N	\N	59.665773062951999	п.Буждым, Здание Буждымского сельского клуба	Россия, Пермский край, Кочевский район, село Буждым	0101000020E6100000111C977153734B40A8C7B60C38D54D40
73131	7	71	934	31738	\N	\N	59.714708999999999	д.Борино, Боринский ФАП		0101000020E61000000CCD751A69414B401494A2957BDB4D40
73129	7	71	934	31661	\N	\N	59.654890000000002	с.Большая Коча, Здание Большекочинского культурнодосугового центра	Россия, Пермский край, Кочевский район, село Большая Коча	0101000020E6100000EEB5A0F7C64A4B401D3D7E6FD3D34D40
73144	7	71	934	32319	\N	\N	59.623606000000002	п.Акилово, Здание Акиловской основной общеобразовательной школы	Россия, Пермский край, Кочевский район, село Акилово	0101000020E61000003410CB660EFB4A4071CB4752D2CF4D40
73106	7	71	913	48181	\N	\N	59.642049	с.Чураки, Сельский клуб		0101000020E610000068EA758BC0A04B40FAB660A92ED24D40
73116	7	71	913	31004	\N	\N	60.12433	пос.Солым, Солымская начальная школа		0101000020E61000007768588CBA924B40B2F4A10BEA0F4E40
73104	7	71	913	30398	\N	\N	60.216327	д.Пятигоры, здание администрации СП	Россия, Пермский край, Косинский район, село Пятигоры	0101000020E610000022A98592C9634B40F31E679AB01B4E40
73102	7	71	913	7245	\N	\N	59.772658999999997	с.Пуксиб, Пуксибская ООШ		0101000020E6100000A9DDAF027C814B40E3FA777DE6E24D40
73103	7	71	913	9119	\N	\N	60.122286000000003	д.Порошево, Порошевская ООШ		0101000020E6100000DD5F3DEE5B714B401C615111A70F4E40
73114	7	71	913	30854	\N	\N	60.206842000000002	пос.Новая Светлица,Светличанская ООШ		0101000020E610000086AE44A0FAA14B4039B874CC791A4E40
73100	7	71	913	30180	\N	\N	60.012783347905099	д.Нижняя Коса, клуб	Россия, Пермский край, Косинский район, село Нижняя Коса	0101000020E610000058AD4CF8A57E4B40EE7893DFA2014E40
73105	7	71	913	7306	\N	\N	59.840663999999997	д.Левичи, Левичанская ООШ		0101000020E6100000A94C310741994B405776C1E09AEB4D40
73098	7	71	913	56242	51737	\N	59.944889022607498	с.Коса, ул.Ленина, д.76, Дом культуры		0101000020E61000008E78B29B197F4B40D2AC6C1FF2F84D40
73112	7	71	913	58141	\N	\N	59.979961103028302	пос.ВерхЛель, клуб	Россия, Пермский край, Косинский район, село Верх-Лель	0101000020E6100000B22D03CE52684B40802DAF5C6FFD4D40
73109	7	71	913	49159	\N	\N	59.854495	д.Бачманово, Бачмановская ООШ		0101000020E6100000632B685A62514B403ACC971760ED4D40
71993	7	71	984	58216	\N	\N	57.252379119280498	п.д/о Красный Яр, здание ООО «Санаторий «Красный Яр»	Россия, Пермский край, Кишертский район, село дом Отдыха Красный Яр	0101000020E6100000FA0B3D62F4BC4C403D997FF44DA04C40
71991	7	71	984	8666	\N	\N	57.278930965427001	с.Черный Яр, 34Б	Россия, Пермский край, Кишертский район, село Черный Яр	0101000020E610000046D1031F83B54C40986BD102B4A34C40
72000	7	71	984	56257	52219	\N	57.360795213104602	с.УстьКишерть, Строителей, 2А	Россия, Пермский край, Кишертский район, село Усть-Кишерть	0101000020E610000023DDCF29C89F4C40B9C7D2872EAE4C40
71999	7	71	984	56257	51983	\N	57.3650003592711	с.УстьКишерть, Советская, 40	Россия, Пермский край, Кишертский район, село Усть-Кишерть	0101000020E61000000A86730D33A04C401F85EB51B8AE4C40
59953	7	71	984	32569	63912	\N	57.437215999999999	д.Сухой Лог, Речная, 20		0101000020E61000002387889B53A94C40DBA4A2B1F6B74C40
71994	7	71	984	56526	54299	\N	57.367760920820103	с.СпасоБарда, Советская, 7	Россия, Пермский край, Кишертский район, село Спасо-Барда	0101000020E6100000D8648D7A88AE4C4044DFDDCA12AF4C40
71995	7	71	984	8845	\N	\N	57.320253867779201	с.Седа, 80	Россия, Пермский край, Кишертский район, село Седа	0101000020E6100000C26856B60FA34C40E3344415FEA84C40
71998	7	71	984	32523	64478	\N	57.418638000000001	с.Посад, Советская, 18		0101000020E61000006D718DCF64A14C40726E13EE95B54C40
71881	7	71	984	58224	\N	\N	57.2913361153281	с. Никулино, здание Никулинской СОШ	Россия, Пермский край, Кишертский район, село Никулино	0101000020E610000065E256410CEC4C40E012807F4AA54C40
71988	7	71	984	33105	64355	\N	57.238128000000003	с.Молебка, Средняя, 5		0101000020E6100000F931E6AE25F84C40862172FA7A9E4C40
71990	7	71	984	8628	52670	\N	57.266431336382297	с.Меча, Юбилейная, 16	Россия, Пермский край, Кишертский район, село Меча	0101000020E6100000740AF2B391C14C40FED137691AA24C40
71989	7	71	984	33111	52251	\N	57.356259000000001	с.Медведево, Центральная, 7	Россия, Пермский край, Кишертский район, село Медведево	0101000020E61000005B608F8994BE4C40EDF318E599AD4C40
71992	7	71	984	8715	\N	\N	57.2530297683521	д.Мазуевка, 61А	Россия, Пермский край, Кишертский район, село Мазуевка	0101000020E6100000ABECBB22F8AB4C4015747B4963A04C40
71984	7	71	984	8345	53369	\N	57.318867873966703	п.Лек, Комсомольская, 20	Россия, Пермский край, Кишертский район, село Лек	0101000020E6100000DA571EA4A7B24C40D7DEA7AAD0A84C40
73080	7	71	984	29252	\N	\N	57.237811000000001	п. Красный Яр, Дом культуры		0101000020E6100000D3872EA86FBD4C4085D04197709E4C40
71985	7	71	984	30166	52032	\N	57.4104254862266	п.Кордон, Советская, 9	Россия, Пермский край, Кишертский район, поселок Кордон	0101000020E610000020D4450A65F54C40FB3A70CE88B44C40
71986	7	71	984	30166	63704	\N	57.411290091381197	п.Кордон, Первомайская, вокзал ст.Кордон (красный уголок)	Россия, Пермский край, Кишертский район, поселок Кордон	0101000020E61000008237A45181F54C40FF959526A5B44C40
73099	7	71	984	30166	52101	\N	57.410319999999999	пос.Кордон, ул.Карла Маркса, д.88, Дом культуры		0101000020E61000003677F4BF5CF54C408672A25D85B44C40
72749	7	71	984	56263	52027	\N	57.339683998216998	дер. Киселево, Школьная, 14	Россия, Пермский край, Кишертский район, село Киселево	0101000020E61000009F724C16F7B54C40BB7CEBC37AAB4C40
73003	7	71	984	25779	\N	\N	57.443145000000001	с. Зуята, Дом культуры		0101000020E6100000CEFFAB8E1CA94C406631B1F9B8B84C40
71725	7	71	984	58200	64275	\N	57.396070427458298	деревня Заборье, Школьная, 2  Дом культуры	Россия, Пермский край, Кишертский район, село Заборье	0101000020E6100000990E9D9E77AB4C409F76F86BB2B24C40
71983	7	71	984	8277	53852	\N	57.389924000000001	д.Верхняя Солянка, Школьная, 14		0101000020E61000000CB265F9BAC64C4077F69507E9B14C40
71711	7	71	984	56284	52111	\N	57.253662143494097	село Березовка, Советская, 107 училище №68	Россия, Пермский край, Кишертский район, село Березовка	0101000020E61000003E97A949F0D84C40751E15FF77A04C40
71977	7	71	958	7956	51454	\N	59.091956000000003	поселок Шахта, Баумана, 9		0101000020E61000008D5F7825C9D34C40E355D636C58B4D40
71979	7	71	958	8060	51678	\N	59.043191	поселок Центральный Коспашский, Няровская, 7		0101000020E610000071FF91E9D0E14C40A33D5E4887854D40
71873	7	71	523	58219	\N	\N	58.330116966558499	п. Ярино, здание администрации	Россия, Пермский край, Карагайский район, село Ярино	0101000020E6100000083D9B559F894B40446D1B46412A4D40
71967	7	71	523	7523	52661	\N	58.705353000000002	с.Юрич, Центральная, 10		0101000020E6100000E7AA798EC8974B405891D101495A4D40
72219	7	71	523	56354	52332	\N	58.609632382863303	д.Шумиха, ул.Советская, д.1а	Россия, Пермский край, Карагайский район, село Шумиха	0101000020E6100000A4DFBE0E9C794B402B4CDF6B084E4D40
71883	7	71	523	3177	\N	\N	58.720414910654199	п. Челва, здание администрации п. Челва	Россия, Пермский край, Карагайский район, село Челва	0101000020E61000004CC631923D8C4B402046088F365C4D40
71815	7	71	1842	31827	52609	\N	58.415450999999997	п.Старый Бисер, Октябрьская, 12		0101000020E6100000A7CD380D51714D40950B957F2D354D40
73074	7	71	523	58334	64738	\N	58.508122477325202	п.Харино, Маяковского,26, Харинская ООШ	Россия, Пермский край, Карагайский район, село Харино	0101000020E61000006CCD565EF26F4B40663046240A414D40
71966	7	71	523	33008	64363	\N	58.474812	д.Фролово, Центральная, 3		0101000020E610000097E2AAB2EF944B40CADFBDA3C63C4D40
71946	7	71	523	6544	52245	\N	58.406365999999998	д.Сюзьвяки, Молодежная, 13		0101000020E6100000E606431D56984B40691A14CD03344D40
71965	7	71	523	33001	64346	\N	58.725785000000002	д.Старая Пашня, Центральная, 2		0101000020E6100000FA449E245D7B4B40B476DB85E65C4D40
72289	7	71	523	58226	64417	\N	58.502116306511397	с.Сосновка, ул.Молодежная, д.6	Россия, Пермский край, Карагайский район, село Сосновка	0101000020E610000096CFF23CB8674B4030664B5645404D40
72220	7	71	523	58271	64560	\N	58.485016127084897	с.Сергино, ул. Школьная, 29	Россия, Пермский край, Карагайский район, село Сергино	0101000020E6100000307F85CC95714B40B4041901153E4D40
71945	7	71	523	56245	51790	\N	58.185787340597102	д.Савино, Центральная, 8А	Россия, Пермский край, Карагайский район, село Савино	0101000020E6100000F3035779027D4B40CF8250DEC7174D40
71964	7	71	523	33000	52008	\N	58.520333000000001	с.Рождественск, Мира, 32		0101000020E61000006762BA10AB9D4B40C90391459A424D40
71962	7	71	523	7313	52080	\N	58.494993000000001	с.Обвинск, Советская, 21		0101000020E61000005BB4006DAB6B4B40DD5F3DEE5B3F4D40
73048	7	71	523	56324	\N	\N	58.5738479668831	д.Новоселы, Администрация сельского поселения	Россия, Пермский край, Карагайский район, село Новоселы	0101000020E61000006CB41CE8A16C4B400070ECD973494D40
71959	7	71	523	7137	\N	\N	58.693444999999997	с.Нердва, Республиканская, 27	Россия, Пермский край, Карагайский район, село Нердва	0101000020E6100000BCCADAA678864B40904946CEC2584D40
71960	7	71	523	7137	52119	\N	58.693444999999997	с.Нердва, Советская, 16		0101000020E6100000BCCADAA678864B40904946CEC2584D40
71957	7	71	523	49150	51452	\N	58.167042000000002	пос.Менделеево, Октябрьская, 5		0101000020E6100000CEE15AED617F4B407B87DBA161154D40
71958	7	71	523	49150	51451	\N	58.167042000000002	пос.Менделеево, Ленина, 42		0101000020E6100000CEE15AED617F4B407B87DBA161154D40
71955	7	71	523	6970	52186	\N	58.391081999999997	с.Козьмодемьянск, Школьный, 1		0101000020E61000006E4DBA2D91874B40F20698F90E324D40
71947	7	71	523	32955	51448	\N	58.267910046705303	с.Карагай, Энергетиков, 31А	Россия, Пермский край, Карагайский район, село Карагай	0101000020E6100000ED28CE5147774B40BC22F8DF4A224D40
71953	7	71	523	32955	51449	\N	58.268984000000003	с.Карагай, Российская, 2		0101000020E6100000B071FDBB3E774B40DA9255116E224D40
71949	7	71	523	32955	51583	\N	58.268984000000003	с.Карагай, Кирова, 4		0101000020E6100000B071FDBB3E774B40DA9255116E224D40
71952	7	71	523	32955	51672	\N	58.268984000000003	с.Карагай, Дзержинского, 2		0101000020E6100000B071FDBB3E774B40DA9255116E224D40
71954	7	71	523	32955	52184	\N	58.268984000000003	с.Карагай, Гагарина, 23		0101000020E6100000B071FDBB3E774B40DA9255116E224D40
71948	7	71	523	6625	53846	\N	58.435450000000003	д.Канюсята, Юбилейная, 16		0101000020E61000004D1421753B6D4B4088855AD3BC374D40
71956	7	71	523	32966	52247	\N	58.183031	д.Кадилово, Центральная, 49А		0101000020E61000002CD670917B8C4B40BC934F8F6D174D40
71963	7	71	523	7332	\N	\N	58.582758382867901	с.Воскресенск, Школьная, 28	Россия, Пермский край, Карагайский район, село Воскресенск	0101000020E6100000105A0F5F269E4B40BEBD6BD0974A4D40
71741	7	71	523	56338	52304	\N	58.780470098154197	деревня Ванькино, Центральная, 34 бывший ФАП	Россия, Пермский край, Карагайский район, село Ванькино	0101000020E61000007192E68F696F4B402BC1E270E6634D40
71943	7	71	523	6380	53359	\N	58.567498999999998	д.Антонята, Молодежная, 32		0101000020E6100000F833BC5983614B40A0C1A6CEA3484D40
71939	7	71	717	6093	51582	\N	58.787315999999997	г. Чермоз, Энгельса, 56		0101000020E6100000D07EA4880C134C400BCF4BC5C6644D40
71940	7	71	717	6093	52113	\N	58.787315999999997	г. Чермоз, Ломоносова, 36		0101000020E6100000D07EA4880C134C400BCF4BC5C6644D40
71938	7	71	717	6093	52113	\N	58.784107088808597	г. Чермоз, Ломоносова, 20	Россия, Пермский край, Ильинский район, Чермоз	0101000020E6100000CEAACFD556144C4047C8409E5D644D40
71929	7	71	717	48689	51581	\N	58.603411999999999	с.Сретенское, Центральная, 2		0101000020E6100000B69DB64604C74B40C901BB9A3C4D4D40
71919	7	71	717	5104	63691	\N	58.632717	с. Слудка, Кирова, 37		0101000020E6100000541B9C887E014C40C64FE3DEFC504D40
72702	7	71	717	11108	64377	\N	58.7672086092456	д.Сенино, ул.Ленина, д.10	Россия, Пермский край, Ильинский район, село Сенино	0101000020E610000056B8E52329CF4B4033198EE733624D40
71925	7	71	717	32732	53840	\N	58.441366000000002	д.Садки, Дениса Лузина, 20		0101000020E6100000164D672783C14B407EC85BAE7E384D40
71937	7	71	717	6064	\N	\N	58.841094064146503	с.Романово, Романовский СДК	Россия, Пермский край, Ильинский район, село Романово	0101000020E6100000508E0244C1084C40506EDBF7A86B4D40
72797	7	71	717	6064	52064	\N	58.840930962451303	с.Романово, Школьная, 17	Россия, Пермский край, Ильинский район, село Романово	0101000020E6100000244223D8B8084C40A69883A0A36B4D40
71926	7	71	717	5465	52192	\N	58.554577000000002	д.Посер, Победы, 8		0101000020E61000007842AF3F89C34B40910E0F61FC464D40
71917	7	71	717	4996	53831	\N	58.547767999999998	д. Пепеляева, Дзержинского, 23		0101000020E6100000F1D8CF6229D44B40CDE506431D464D40
71918	7	71	717	32662	63478	\N	58.574379	д.Новая Каменка, Октябрьская, 2		0101000020E6100000D9EDB3CA4CEB4B402D41464085494D40
72270	7	71	717	56345	\N	\N	58.773221002414303	д.Мосино, СДК	Россия, Пермский край, Ильинский район, село Мосино	0101000020E6100000B82231410DAF4B404BCADDE7F8624D40
71923	7	71	717	5293	\N	\N	58.372911999999999	д.Мартыновцы, филиал Москвинская ООШ		0101000020E61000001F0E12A27CF34B409A249694BB2F4D40
73021	7	71	717	5997	\N	\N	58.886569000000001	с. Кыласово, Администрация сельского поселения		0101000020E6100000E6CE4C309C0D4C40DF52CE177B714D40
71936	7	71	717	5997	\N	\N	58.8868649161397	с.Кыласово, Кыласовский СДК	Россия, Пермский край, Ильинский район, село Кыласово	0101000020E610000009FCE1E7BF0D4C40C87BD5CA84714D40
71928	7	71	717	56273	52077	\N	58.580075752695898	с.Кривец, Советская, 14	Россия, Пермский край, Ильинский район, село Кривец	0101000020E61000004F3E3DB665B24B40E5982CEE3F4A4D40
71931	7	71	717	56325	64471	\N	58.403102588364199	д.Комариха, Школьная, 9	Россия, Пермский край, Ильинский район, село Комариха	0101000020E6100000F91400E319064C40B2F50CE198334D40
71921	7	71	717	56325	52243	\N	58.402876999999997	д.Комариха, Центральная, 15	Россия, Пермский край, Ильинский район, село Комариха	0101000020E610000095490D6D00064C40C1A7397991334D40
71932	7	71	717	56327	\N	\N	58.7693917380942	с.Каргино, Каргинский сельский клуб	Россия, Пермский край, Ильинский район, село Каргино	0101000020E61000008C9E5BE84AB04B40EBE6E26F7B624D40
60061	7	71	717	58241	\N	\N	58.662820388867203	д.Ильята, 1		0101000020E610000057E9EE3A1BAE4B403F912749D7544D40
71916	7	71	717	32643	52070	\N	58.564505472981303	р.п. Ильинский, Чкалова, 17	Россия, Пермский край, Ильинский район, поселок Ильинский	0101000020E6100000B62E35423FD94B40D8B628B341484D40
71927	7	71	717	32643	63893	\N	58.565423491103999	р.п. Ильинский, Рабочая, 11а	Россия, Пермский край, Ильинский район, поселок Ильинский	0101000020E6100000F01989D008D84B40FFB3E6C75F484D40
71914	7	71	717	32643	52029	\N	58.565223000000003	р.п. Ильинский, Механизаторов, 9		0101000020E610000080B74082E2D74B4038F92D3A59484D40
71941	7	71	717	32643	52033	\N	58.565223000000003	р.п. Ильинский, Ленина, 62, СОШ№1		0101000020E610000080B74082E2D74B4038F92D3A59484D40
71915	7	71	717	32643	52033	\N	58.565223000000003	р.п. Ильинский, Ленина, 60		0101000020E610000080B74082E2D74B4038F92D3A59484D40
71942	7	71	717	32643	51447	\N	58.565223000000003	р.п. Ильинский, 50 лет Октября, 92		0101000020E610000080B74082E2D74B4038F92D3A59484D40
71933	7	71	717	32791	53353	\N	58.779755000000002	с.Ивановское, Аликина, 1		0101000020E6100000F14A92E7FAD04B403DF20703CF634D40
73029	7	71	717	47761	\N	\N	58.591371000000002	д. Ерши, Дом культуры		0101000020E6100000FDA19927D7C24B40C366800BB24B4D40
71935	7	71	717	5942	\N	\N	58.779567999999998	п. Ерёма, Ереминский сельский клуб	Россия, Пермский край, Ильинский район, село Ерема	0101000020E61000004C1AA37554E54B400A815CE2C8634D40
71930	7	71	717	32763	53843	\N	58.624063	с.Дмитриевское, Трактовая, 13		0101000020E610000074B4AA251DDF4B4063D2DF4BE14F4D40
71982	7	71	717	58225	\N	\N	58.565745023846198	д.Гари, 9	Россия, Пермский край, Ильинский район, село Гари	0101000020E61000001762F54718FE4B40117008556A484D40
71924	7	71	717	32725	53832	\N	58.431907000000002	с.Васильевское, Культуры, 11		0101000020E61000004260E5D022E94B40EDF483BA48374D40
72756	7	71	717	58262	64543	\N	58.584516837306197	дер. Бор, Центральная, 16	Россия, Пермский край, Ильинский район, село Бор	0101000020E61000000745F30016F54B405F7AFB73D14A4D40
72809	7	71	717	56296	52168	\N	58.596889342076103	с.Березовка, Молодежная, 35	Россия, Пермский край, Ильинский район, село Березовка	0101000020E61000000839EFFFE3EC4B40CB2BD7DB664C4D40
71913	7	71	582	4812	52242	\N	56.827178000000004	д. Ятыш, ул.Советская, 13		0101000020E610000041800C1D3BA24B4040FCFCF7E0694C40
71911	7	71	582	48374	52630	\N	56.756044688465103	д. Шумово, пр. Солнечный, 12	Россия, Пермский край, Еловский район, село Шумово	0101000020E61000003D0AD7A370754B40F4A62215C6604C40
71907	7	71	582	4427	52241	\N	57.023567999999997	д. Шульдиха, ул. Заречная, 44а		0101000020E610000021E527D53E4F4B40B69DB64604834C40
71901	7	71	582	4145	53339	\N	56.822040000000001	с. Суганка, ул. Ленина, 46		0101000020E61000002A1F82AAD1974B407E00529B38694C40
71912	7	71	582	4751	52646	\N	56.958832000000001	д. Плишкино, ул. Третья, 1		0101000020E6100000A088450C3B364B40DC2DC901BB7A4C40
71906	7	71	582	4411	53052	\N	57.001569000000003	с. Плишкари, ул Центральная, д. 47, здание администрации СП		0101000020E610000010070951BE884B40FED7B96933804C40
71905	7	71	582	32593	53828	\N	56.935817	с. Осиновик, ул.Юбилейная, 6		0101000020E610000061A75835085D4B403A05F9D9C8774C40
71904	7	71	582	4256	53824	\N	56.878619999999998	с. Нижняя Барда, ул.Центральная, 46		0101000020E6100000BF9D44847F874B4046CEC29E76704C40
73046	7	71	582	27748	\N	\N	57.050483999999997	с.Неволино, Средняя школа		0101000020E6100000A4C16D6DE1794B40527C7C4276864C40
71903	7	71	582	4247	52240	\N	56.900294902582097	д. Мичура, ул.Советская, 30	Россия, Пермский край, Еловский район, село Мичура	0101000020E61000007689EAAD817B4B404CE0D6DD3C734C40
71902	7	71	582	4165	53821	\N	56.801959002587402	с. Малая Уса, ул.Белокаменная, 3	Россия, Пермский край, Еловский район, село Малая Уса	0101000020E6100000D5CF9B8A54744B40CEDDAE97A6664C40
71909	7	71	582	4535	52623	\N	56.826722360550903	с. Куштомак, Центральная, 63	Россия, Пермский край, Еловский район, село Куштомак	0101000020E6100000CDAFE600C19E4B401D71C806D2694C40
71900	7	71	582	32562	53334	\N	57.116106000000002	с. Крюково, ул.Большая Северная, 43		0101000020E6100000B9A6406667874B40486FB88FDC8E4C40
71908	7	71	582	32606	64401	\N	57.010759	д. Кресты, ул. Уральская, 36		0101000020E610000092955F06637E4B409F91088D60814C40
71895	7	71	582	48037	51579	\N	57.048349999999999	с. Елово,  ул. Комсомольская, д. 56, здание филиала колледжа		0101000020E61000002976340EF5754B407C61325530864C40
71894	7	71	582	48037	51754	\N	57.048349999999999	с. Елово, ул.Карла Маркса, 17		0101000020E61000002976340EF5754B407C61325530864C40
71896	7	71	582	48037	51446	\N	57.052185659389501	с. Елово, ул.Белинского, 10	Россия, Пермский край, Еловский район, село Елово	0101000020E61000002EAEF199EC754B408FA7E507AE864C40
72336	7	71	582	56295	52170	\N	56.998886628237898	с.Дуброво, ул.Школьная, д.23	Россия, Пермский край, Еловский район, село Дуброво	0101000020E6100000672C9ACE4E464B4025B37A87DB7F4C40
71893	7	71	582	56295	52166	\N	56.998699261347603	с. Дуброво, ул. Чапаева, д. 30, здание администрации поселения	Россия, Пермский край, Еловский район, село Дуброво	0101000020E6100000645C717154464B4022C66B5ED57F4C40
73062	7	71	582	56288	52134	\N	56.814821983052497	с.Городище, ул.Мира, д.14	Россия, Пермский край, Еловский район, село Городище	0101000020E61000006C921FF12B644B40D90759164C684C40
71892	7	71	582	3647	53818	\N	56.861741000000002	с. Брюхово, ул. Злыгостева, д. 62, здание администрации поселения		0101000020E610000098DD9387856C4B40A94F72874D6E4C40
71961	7	71	404	56275	52090	\N	58.466754068970197	д.Ярино, Центральная, 5		0101000020E6100000A4349BC761484C407BA35698BE3B4D40
71889	7	71	404	3496	\N	\N	58.518250999999999	с. УстьГаревая, здание администрации	Россия, Пермский край, Добрянка городской округ, село Усть-Гаревая	0101000020E61000008751103CBE0F4C40450F7C0C56424D40
71882	7	71	404	3122	\N	\N	58.686218085119997	п. Таборы, здание ФАП п. Таборы	Россия, Пермский край, Добрянка городской округ, село Таборы	0101000020E6100000FCFB8C0B077C4C4098F6CDFDD5574D40
73066	7	71	404	56234	51666	\N	58.486035347067002	с.Родники, ул.Советская, д.6	Россия, Пермский край, Добрянка городской округ, село Родники	0101000020E6100000E738B709F7604C400EDB1665363E4D40
71870	7	71	404	2132	51442	\N	58.295070000000003	"""п. Полазна, Трухина, 83, здание УТТ """"Полазнанефть"""""""		0101000020E61000007BF65CA626354C40EF0390DAC4254D40
71814	7	71	1842	31755	52081	\N	58.543246000000003	п.Сараны, Кирова, 20		0101000020E61000001215AA9B8B614D4067D7BD1589454D40
71865	7	71	404	2132	52181	\N	58.294845569311398	п. Полазна, Советская, 10, здание воскресной школы	Россия, Пермский край, Добрянка городской округ, поселок Полазна	0101000020E6100000E10D6954E0344C409FAD8383BD254D40
71866	7	71	404	2132	51793	\N	58.295070000000003	"""п. Полазна, Пяткина, 32а, МОУ ДОД """"Полазненская СДЮСШОР"""""""		0101000020E61000007BF65CA626354C40EF0390DAC4254D40
71869	7	71	404	2132	51441	\N	58.295070000000003	"""п. Полазна, Нефтяников, 9, МУ """"Полазненский ЦТиД"""""""		0101000020E61000007BF65CA626354C40EF0390DAC4254D40
71868	7	71	404	2132	51440	\N	58.295070000000003	"""п. Полазна, Дружбы, 5, МОУ """"Полазненская СОШ №3"""""""		0101000020E61000007BF65CA626354C40EF0390DAC4254D40
71880	7	71	404	2962	\N	\N	58.7198084413521	с. Перемское, здание администрации Перемского СП	Россия, Пермский край, Добрянка городской округ, село Перемское	0101000020E610000059C4B0C3986A4C4018B325AB225C4D40
71878	7	71	404	2871	\N	\N	58.584709073973201	п. Кыж, здание ФАП п. Кыж	Россия, Пермский край, Добрянка городской округ, поселок Кыж	0101000020E6100000096CCEC133674C40A35698BED74A4D40
71871	7	71	404	2478	\N	\N	58.284109000000001	п. Дивья, здание Дивьинской СОШ	Россия, Пермский край, Добрянка городской округ, поселок Дивья	0101000020E6100000D593F947DF4C4C40E8BF07AF5D244D40
71886	7	71	404	3318	\N	\N	58.662483243119098	с. Висим, здание администрации	Россия, Пермский край, Добрянка городской округ, село Висим	0101000020E61000000A65E1EB6B1D4C40F793313ECC544D40
71877	7	71	404	2810	\N	\N	58.627315000000003	п. Вильва, здание дома культуры п. Вильва	Россия, Пермский край, Добрянка городской округ, поселок Вильва	0101000020E6100000DDB243FCC37C4C4027A5A0DB4B504D40
71810	7	71	404	2810	64449	\N	58.627048650614	п. Вильва, Береговая, 4	Россия, Пермский край, Добрянка городской округ, поселок Вильва	0101000020E61000001FA2D11DC47C4C40A8FE412443504D40
71663	7	71	404	10959	64440	\N	59.009123999350997	Пермский край, Березниковский городской округ, Яйвинская, 8	Россия, Пермский край, Добрянка городской округ, село Березниковский	0101000020E61000004EEE77280A284C40EACDA8F92A814D40
71666	7	71	404	10959	51689	\N	59.008282795902304	Пермский край, Березниковский городской округ, Юбилейная, 11	Россия, Пермский край, Добрянка городской округ, село Березниковский	0101000020E6100000EA3E00A94D284C406F0ED76A0F814D40
71700	7	71	404	10959	51544	\N	59.009315878702999	Пермский край, Березниковский городской округ, Свердлова, 154А	Россия, Пермский край, Добрянка городской округ, село Березниковский	0101000020E610000050560C5707284C402EAA454431814D40
71696	7	71	404	10959	51544	\N	59.009214999999998	Пермский край, Березниковский городской округ, Свердлова, 79		0101000020E61000004AB6BA9C12284C40FAD005F52D814D40
71680	7	71	404	10959	51544	\N	59.009214999999998	Пермский край, Березниковский городской округ, Свердлова, 27		0101000020E61000004AB6BA9C12284C40FAD005F52D814D40
71682	7	71	404	10959	51782	\N	59.009214999999998	Пермский край, Березниковский городской округ, Пятилетки, 140		0101000020E61000004AB6BA9C12284C40FAD005F52D814D40
71659	7	71	404	10959	51530	\N	59.009214999999998	Пермский край, Березниковский городской округ, Преображенского, 19		0101000020E61000004AB6BA9C12284C40FAD005F52D814D40
71703	7	71	404	10959	51683	\N	59.009214999999998	Пермский край, Березниковский городской округ, ул.Мира, 98а		0101000020E61000004AB6BA9C12284C40FAD005F52D814D40
71672	7	71	404	10959	51424	\N	59.009448697670699	Пермский край, Березниковский городской округ, Ленина проспект, 50	Россия, Пермский край, Добрянка городской округ, село Березниковский	0101000020E6100000522635B401284C406DFDF49F35814D40
71674	7	71	404	10959	51781	\N	59.009214999999998	Пермский край, Березниковский городской округ, К. Маркса, 49		0101000020E61000004AB6BA9C12284C40FAD005F52D814D40
71851	7	71	222	56285	52118	\N	58.849896000000001	п.Широковский, ул.Пионеров, д.9	Россия, Пермский край, Губаха городской округ, поселок Широковский	0101000020E610000065E256410CE44C4028806264C96C4D40
71853	7	71	222	56456	\N	\N	58.8390563238138	п.Шестаки, ж/д станция	Россия, Пермский край, Губаха городской округ, село Шестаки	0101000020E61000003198BF42E6AE4C409CC1DF2F666B4D40
71849	7	71	222	842	52263	\N	58.946226037854402	п.Углеуральский, ул.Углеуральская, д.17	Россия, Пермский край, Губаха городской округ, поселок Углеуральский	0101000020E610000063D4B5F63ECD4C40FD4FFEEE1D794D40
71844	7	71	222	842	51576	\N	58.9390002593614	п.Углеуральский, ул.Мира, д.32	Россия, Пермский край, Губаха городской округ, поселок Углеуральский	0101000020E61000000A65E1EB6BCB4C40D578E92631784D40
71848	7	71	222	842	52016	\N	58.938467889342199	п.Углеуральский, ул.Белинского, д.55	Россия, Пермский край, Губаха городской округ, поселок Углеуральский	0101000020E610000043ACFE08C3CA4C40D82B2CB81F784D40
71850	7	71	222	842	52309	\N	58.939207261038199	п.Углеуральский, ул.Базовая	Россия, Пермский край, Губаха городской округ, поселок Углеуральский	0101000020E61000005D876A4AB2CA4C404F965AEF37784D40
71847	7	71	222	842	51531	\N	58.938557000000003	п.Углеуральский, ул.2я Коммунистическая, д.106		0101000020E6100000467C2766BDCA4C404837C2A222784D40
71845	7	71	222	842	52015	\N	58.938557000000003	п.Углеуральский, ул.2ая Коммунистическая, д.105		0101000020E6100000467C2766BDCA4C404837C2A222784D40
71846	7	71	222	842	52180	\N	58.939029806349197	п.Улеуральский, ул.150 лет КУБ, д.32	Россия, Пермский край, Губаха городской округ, поселок Углеуральский	0101000020E610000020EC14AB06CB4C4040FB912232784D40
59745	7	71	222	58231	65680	\N	58.870033233536397	п.20 км, ул.Зеленая		0101000020E6100000D88349F1F1E34C406BB8C83D5D6F4D40
71829	7	71	7406	56239	51696	\N	58.746231942756701	г. Гремячинск, п. Шумихинский, ул. Мира, 19	Россия, Пермский край, Гремячинск городской округ, поселок Шумихинский	0101000020E61000002D5DC136E2D54C40459DB987845F4D40
71812	7	71	1842	31675	51785	\N	58.5172062379538	п.Теплая Гора, Советская, 75	Россия, Пермский край, Горнозаводский район, поселок Теплая Гора	0101000020E61000001CEBE2361A8A4D40C2A563CE33424D40
71813	7	71	1842	31675	51571	\N	58.527715999999998	п.Теплая Гора, 1го Мая, 11		0101000020E6100000D0ECBAB722894D40B8C9A8328C434D40
71817	7	71	1842	31891	52018	\N	58.562570999999998	п.Промысла, Советская, 2		0101000020E61000006364C91CCB934D40C956975302484D40
71809	7	71	1842	31444	51690	\N	58.431854999999999	п.Пашия, Ленина, 4		0101000020E610000032923D42CD224D409ACE4E0647374D40
71808	7	71	1842	31444	51690	\N	58.431854999999999	п.Пашия, Ленина, 7		0101000020E610000032923D42CD224D409ACE4E0647374D40
71807	7	71	1842	31444	51690	\N	58.431854999999999	п.Пашия, Ленина, 16		0101000020E610000032923D42CD224D409ACE4E0647374D40
71818	7	71	1842	32691	52185	\N	58.740073000000002	п.Медведка, Строек Коммунизма, 2		0101000020E6100000A0A86C58538D4D4089D349B6BA5E4D40
71811	7	71	1842	56256	51921	\N	58.2851933456975	п.КусьеАлександровский, Ленина, 2	Россия, Пермский край, Горнозаводский район, поселок Кусье-Александровский	0101000020E6100000AFEC82C135314D402906483481244D40
71805	7	71	1842	31256	51688	\N	58.382373000000001	г.Горнозаводск, Свердлова, 59		0101000020E61000000ADB4FC6F8284D40CCEF3499F1304D40
71803	7	71	1842	31256	51688	\N	58.382373000000001	г.Горнозаводск, Свердлова, 62		0101000020E61000000ADB4FC6F8284D40CCEF3499F1304D40
71804	7	71	1842	31256	51429	\N	58.382373000000001	г.Горнозаводск, 30 лет Победы, 14		0101000020E61000000ADB4FC6F8284D40CCEF3499F1304D40
73057	7	71	1842	28242	64569	\N	58.639626	с.Вильва, ул.Советская, д.3		0101000020E6100000429605137F204D40EDD5C743DF514D40
71816	7	71	1842	56308	52216	\N	58.513575087029402	п.Станция Бисер, Советская, 23		0101000020E610000090BB0853946F4D4088855AD3BC414D40
71891	7	71	951	56356	\N	\N	60.3797416711854	п. Камский, здание администрации	Россия, Пермский край, Гайнский район, поселок разрушенный Камский	0101000020E6100000B30A9B012E064B407575C7629B304E40
73088	7	71	951	29637	\N	\N	60.396552	п.Шордын, Здание ФАПА	Россия, Пермский край, Гайнский район, село Шордын	0101000020E610000053978C6324234B40EA944737C2324E40
73092	7	71	951	48442	\N	\N	60.180515	п.Чуртан, здание начальной школы	Россия, Пермский край, Гайнский район, село Чуртан	0101000020E61000009085E81038F04A40FEB7921D1B174E40
73076	7	71	951	29104	\N	\N	60.167098000000003	д.Чажегово, Дом культуры		0101000020E610000077D7D9907F324B400F9D9E7763154E40
73095	7	71	951	48698	64758	\N	60.479206604196797	п.УстьЧерная, ул.Больничная, 17, СОШ	Россия, Пермский край, Гайнский район, село Усть-Черная	0101000020E6100000ECDADE6E49544A40D481ACA7563D4E40
73077	7	71	951	8889	54620	\N	60.318941513952197	п.УстьВесляна, ул.Школьная,4,  Шуминская ООШ	Россия, Пермский край, Гайнский район, село Усть-Весляна	0101000020E6100000F3E32F2DEAFF4A4011A96917D3284E40
73078	7	71	951	7772	64731	\N	60.352499000000002	п.Сосновая, ул.Центральная,8а,здание начальной школы		0101000020E6100000DA1A118C83EB4A40B56FEEAF1E2D4E40
73081	7	71	951	48727	\N	\N	60.022179999999999	п.Сергеевский, Дом культуры		0101000020E6100000DE8FDB2F9F2A4B40095053CBD6024E40
73091	7	71	951	29785	\N	\N	60.183325000000004	п.Сейва, Дом культуры		0101000020E6100000020EA14ACDE04A4005C58F3177174E40
72365	7	71	951	26717	52334	\N	60.6745773490007	д.Пурга, Центральная, 4	Россия, Пермский край, Гайнский район, поселок Пурга	0101000020E610000067D5E76A2BFA4A4020D1048A58564E40
73093	7	71	951	8032	54410	\N	60.408207516523802	п.Оныл, ул. Школьная, 6а, ООШ	Россия, Пермский край, Гайнский район, село Оныл	0101000020E6100000EDF483BA48D34A4098FBE42840344E40
73085	7	71	951	29509	\N	\N	60.404550018404798	п.Луным, Начальная школа	Россия, Пермский край, Гайнский район, село Луным	0101000020E6100000E7E3DA5031584B4064CC5D4BC8334E40
73086	7	71	951	48800	\N	\N	60.650623000000003	п.Лель, Здание школы	Россия, Пермский край, Гайнский район, село Лель	0101000020E61000001747E5266A494B4041834D9D47534E40
73096	7	71	951	58347	64782	\N	60.772053691499103	п.Керос, ул.Ленина, 24, ООШ	Россия, Пермский край, Гайнский район, село Керосс	0101000020E6100000AEF199EC9F6D4A407C5F5CAAD2624E40
73087	7	71	951	7946	54587	\N	60.368234000000001	п.Кебраты, ул. Пионерская,19,СОШ		0101000020E610000004E275FD821B4B403CA3AD4A222F4E40
73083	7	71	951	48760	54569	\N	60.212980000000002	п.Касимовка, ул. Кунгурская, 6, ООШ		0101000020E6100000A8716F7EC3544B40DE59BBED421B4E40
73082	7	71	951	56389	\N	\N	60.052574349493597	д.Имасы, Начальная школа	Россия, Пермский край, Гайнский район, село Имасы	0101000020E6100000581F0F7D77394B40594FADBEBA064E40
73079	7	71	951	48396	\N	\N	60.068211787288	дер.Иванчино, здание начальной школы	Россия, Пермский край, Гайнский район, село Иванчино	0101000020E610000042CC2555DB1F4B40EE98BA2BBB084E40
73090	7	71	951	48864	\N	\N	60.566173999999997	п.Жемчужный, Основная школа		0101000020E6100000C6A52A6D71F94A4039ECBE6378484E40
73075	7	71	951	48358	\N	\N	60.264626	д.Данилово, Дом культуры		0101000020E6100000749A05DA1D2C4B40EDD5C743DF214E40
73072	7	71	951	56253	51860	\N	60.309166394205398	п.Гайны, Коммунистическая, 35	Россия, Пермский край, Гайнский район, поселок Гаины	0101000020E6100000E33785950A2A4B407F8461C092274E40
73071	7	71	951	56253	52220	\N	60.308300564983199	п.Гайны, Дзержинского, 7	Россия, Пермский край, Гайнский район, поселок Гаины	0101000020E610000064E94317D4294B407C293C6876274E40
73070	7	71	951	56253	52220	\N	60.308314704550199	п.Гайны, Дзержинского, 40		0101000020E6100000E33785950A2A4B40E1EEACDD76274E40
73073	7	71	951	56253	66977	\N	60.308928771705297	п.Гайны, Железнодорожная, Дом культуры		0101000020E6100000CC0A45BA9F294B409BE447FC8A274E40
73084	7	71	951	56550	54657	\N	60.236036930444399	п.Верхня Старица, ул. К.Маркса, 16а, ООШ	Россия, Пермский край, Гайнский район, село Верхняя Старица	0101000020E6100000990F087426574B40AFD2DD75361E4E40
73089	7	71	951	29669	\N	\N	60.556462000000003	п.Верхний Будым, основная школа		0101000020E6100000629E95B4E2154B40BFBB95253A474E40
73097	7	71	951	48999	\N	\N	60.209673018558099	дер.Базуево, Начальная школа	Россия, Пермский край, Гайнский район, село Базуево	0101000020E6100000B6F81400E3194B4057ED9A90D61A4E40
71796	7	71	1129	56339	\N	\N	58.005375229193497	д.Федяшино, здание клуба	Россия, Пермский край, Верещагинский район, село Федяшино	0101000020E6100000DD0A613596184B40A69BC420B0004D40
71781	7	71	1129	33099	53047	\N	58.029974000000003	пос.Субботники, ул.Советская, д.24		0101000020E6100000478FDFDBF44D4B407BDD2230D6034D40
71793	7	71	1129	30749	52596	\N	58.114440000000002	д.Соболята, ул.Центральная, д.39		0101000020E610000015731074B46A4B4058AD4CF8A50E4D40
71798	7	71	1129	30997	51687	\N	58.182879999999997	с.Сепыч, ул.Ленина, д.14		0101000020E61000000685419946114B40D68BA19C68174D40
71780	7	71	1129	33096	52072	\N	58.059317	д.Рябины, ул.Птицеводов, д.3		0101000020E61000009BFF571D39544B40658C0FB397074D40
71795	7	71	1129	30848	51567	\N	58.064092000000002	с.Путино, ул.Комсомольская, д.16		0101000020E61000007EC51A2E72274B40B6F7A92A34084D40
71997	7	71	1129	56266	52038	\N	58.051319813219202	с.Посад, Школьная, 3	Россия, Пермский край, Верещагинский район, село Посад	0101000020E6100000C58CF0F620324B40BBD05CA791064D40
71782	7	71	1129	10495	54463	\N	58.139437000000001	д.Нижнее Галино, ул.Советская, д.11		0101000020E61000000B96EA025E324B401A6D5512D9114D40
71720	7	71	1129	56475	\N	\N	58.010755742236903	деревня Мартелы, 9 бывший ФАП	Россия, Пермский край, Верещагинский район, село Мартелы	0101000020E6100000ECA694D74A104B402E1EDE7360014D40
71787	7	71	1129	33126	52078	\N	58.192400999999997	пос.Ленино, ул.Гагарина, д.14		0101000020E61000002F88484DBB484B40DD5B9198A0184D40
71794	7	71	1129	30818	53317	\N	58.105581999999998	д.Кукеты, ул.Молодежная, д.18		0101000020E6100000BE1589096A744B40EC8502B6830D4D40
71791	7	71	1129	30660	52012	\N	58.149175	пос.Кукетский, ул.Ленина, д.2		0101000020E6100000191D90847D6B4B40BE30992A18134D40
71783	7	71	1129	56258	52010	\N	58.085968590412897	д.Комары, ул.Молодежная, д.1	Россия, Пермский край, Верещагинский район, село Комары	0101000020E6100000D07F0F5EBB404B4023BC3D08010B4D40
71789	7	71	1129	30494	51425	\N	58.203070480751002	пос.Зюкайка, ул.Пугачева, д.42	Россия, Пермский край, Верещагинский район, поселок Зюкайка	0101000020E6100000E2067C7E185B4B403C66A032FE194D40
71790	7	71	1129	30494	51786	\N	58.202708000000001	пос.Зюкайка, ул.мичурина, д.1		0101000020E6100000E564E256415A4B409C51F355F2194D40
71788	7	71	1129	30494	52179	\N	58.202708000000001	пос.Зюкайка, ул.Ленина, д.1		0101000020E6100000E564E256415A4B409C51F355F2194D40
71950	7	71	1129	58240	64474	\N	58.128280414937898	с.Зюкай, Ленина, 9	Россия, Пермский край, Верещагинский район, село Зюкай	0101000020E61000001EC4CE143A5D4B408D5DA27A6B104D40
71785	7	71	1129	30305	52075	\N	58.152513999999996	с.Вознесенское, ул.Ленина, д.19		0101000020E61000002FE065868D504B405017299485134D40
71784	7	71	1129	30305	52075	\N	58.152513999999996	с.Вознесенское, ул.Ленина, д.11а		0101000020E61000002FE065868D504B405017299485134D40
71769	7	71	1129	10421	53298	\N	58.082864000000001	г.Верещагино, ул.Энергетиков, д.22		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
71773	7	71	1129	10421	51421	\N	58.093682466463903	г.Верещагино, ул.Ленина, д.10	Россия, Пермский край, Верещагинский район, Верещагино	0101000020E61000001EC2F869DC554B40A81C93C5FD0B4D40
71761	7	71	1129	10421	51421	\N	58.082864000000001	г.Верещагино, ул.Ленина, д.27		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
71778	7	71	1129	10421	51566	\N	58.064514544255999	г.Верещагино, ул.Коммунистическая, д.56	Россия, Пермский край, Верещагинский район	0101000020E6100000AF415F7AFB534B40FC8C0B0742084D40
71771	7	71	1129	10421	51686	\N	58.082864000000001	г.Верещагино, ул.Карла Маркса, д.2		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
71772	7	71	1129	10421	51422	\N	58.0879553472098	г.Верещагино, ул.К.Маркса, д.56	Россия, Пермский край, Верещагинский район, Верещагино	0101000020E6100000EFC8586DFE514B408542041C420B4D40
71777	7	71	1129	10421	54505	\N	58.083091116555003	г.Верещагино, Звезды,65	Россия, Пермский край, Верещагинский район, Верещагино	0101000020E61000003465A71FD4534B40C5CBD3B9A20A4D40
71768	7	71	1129	10421	51420	\N	58.082864000000001	г.Верещагино, ул.Железнодорожная, д.16		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
71767	7	71	1129	10421	51420	\N	58.083670767753802	г.Верещагино, ул.Железнодорожная, д.25	Россия, Пермский край, Верещагинский район, Верещагино	0101000020E6100000914259F8FA504B40D34F38BBB50A4D40
72357	7	71	1129	10421	52318	\N	58.078476301296	д.Верещагино, Дорожная, 10	Россия, Пермский край, Верещагинский район, Верещагино	0101000020E610000011E335AFEA524B40ADC266800B0A4D40
71770	7	71	1129	10421	51684	\N	58.082864000000001	г.Верещагино, ул.Верещагинская, д.8		0101000020E6100000A98592C9A9534B4004029D499B0A4D40
71797	7	71	1129	56259	52014	\N	57.998532715661199	пос.Бородулино, ул.1 Мая, д.41	Россия, Пермский край, Верещагинский район, село Бородулино	0101000020E61000000762D9CC21314B40077DE9EDCFFF4C40
71792	7	71	1129	32535	52074	\N	58.077371999999997	д.Бородули, ул.Центральная, д.11		0101000020E610000029B2D6506A614B4024D06053E7094D40
71786	7	71	1129	58243	\N	\N	58.130555490088803	д.Аникино, здание библиотеки	Россия, Пермский край, Верещагинский район, село Аникино	0101000020E61000003A90F5D4EA634B4026AAB706B6104D40
71764	7	71	1599	29334	53805	\N	57.745396999999997	Пермский край, Большесосновский муниципальный район, с. Юрково, Заречная, 24		0101000020E610000011A7936C754D4B40ACC43C2B69DF4C40
71763	7	71	1599	29326	51540	\N	57.495001999999999	Пермский край, Большесосновский муниципальный район, с. Черновское, Ленина, 8		0101000020E61000007905A22765464B4030BABC395CBF4C40
71762	7	71	1599	29251	53295	\N	57.521044000000003	Пермский край, Большесосновский муниципальный район, с. Тойкино, Молодежная, 3		0101000020E61000002522FC8BA02F4B4076E3DD91B1C24C40
71746	7	71	1599	28553	52303	\N	57.595514999999999	Пермский край, Большесосновский муниципальный район, с. Солоды, Молодежная, 13		0101000020E61000007520EBA9D5114B4083A3E4D539CC4C40
71760	7	71	1599	29170	52593	\N	57.357875999999997	Пермский край, Большесосновский муниципальный район, с. Полозово, Центральная, 22		0101000020E6100000BD00FBE8D4354B40FB027AE1CEAD4C40
71759	7	71	1599	29154	52176	\N	57.654249	Пермский край, Большесосновский муниципальный район, с. Петропавловск, Гагарина, 39 А		0101000020E61000009D11A5BDC1254B406938656EBED34C40
71758	7	71	1599	29105	52306	\N	57.663705999999998	Пермский край, Большесосновский муниципальный район, с. Пермяки, Мира, 16		0101000020E610000060394206F2124B4059147651F4D44C40
71757	7	71	1599	29039	52307	\N	57.339714000000001	Пермский край, Большесосновский муниципальный район, с. Нижний Лып, Нагорная, 6		0101000020E61000006D8C9DF0121C4B4026FF93BF7BAB4C40
71756	7	71	1599	29016	53284	\N	57.620057000000003	Пермский край, Большесосновский муниципальный район, с. Малая Соснова, Ленина, 6		0101000020E6100000971C774A07534B40F4531C075ECF4C40
72232	7	71	1599	58272	64561	\N	57.536147198530102	д.Луговая, Центральная, 3а	Россия, Пермский край, Большесосновский район, село Луговая	0101000020E6100000B95164ADA1164B409C6C0377A0C44C40
71755	7	71	1599	28959	53268	\N	57.249026999999998	Пермский край, Большесосновский муниципальный район, с. Лисья, Школьная, 13		0101000020E6100000172D40DB6A2E4B401669E21DE09F4C40
71754	7	71	1599	28934	53801	\N	57.632953999999998	Пермский край, Большесосновский муниципальный район, с. Левино, Специалистов, 1		0101000020E6100000D61C2098A3694B40AAEFFCA204D14C40
71765	7	71	1599	29414	52347	\N	57.387270000000001	Пермский край, Большесосновский муниципальный район, с. Красный Яр, Октябрьская, 5		0101000020E6100000821B295B24394B40685C381092B14C40
71753	7	71	1599	28886	52591	\N	57.745854000000001	Пермский край, Большесосновский муниципальный район, с. Кленовка, Новая, 4		0101000020E610000076F9D687F5284B409FCBD42478DF4C40
71752	7	71	1599	28808	53263	\N	57.717267999999997	Пермский край, Большесосновский муниципальный район, с. Заболотово, Школьная, 6		0101000020E61000003D49BA66F2394B40D13B1570CFDB4C40
71751	7	71	1599	56531	54328	\N	57.531054301984597	Пермский край, Большесосновский муниципальный район, с. ВерхПотка, Дружбы, 13	Россия, Пермский край, Большесосновский район, село Верх-Потка	0101000020E61000000A86730D33264B407A34D593F9C34C40
71748	7	71	1599	28580	51565	\N	57.673434	Пермский край, Большесосновский муниципальный район, с. Большая Соснова, Ленина, д. 31		0101000020E6100000143E5B07074D4B40DA01D71533D64C40
71747	7	71	1599	28580	51565	\N	57.673434	Пермский край, Большесосновский муниципальный район, с. Большая Соснова, ул.Ленина, д. 31		0101000020E6100000143E5B07074D4B40DA01D71533D64C40
71750	7	71	1599	28705	52009	\N	57.332149999999999	Пермский край, Большесосновский муниципальный район, с. Бердышево, Набережная, 13		0101000020E61000006876DD5B913A4B40E6AE25E483AA4C40
71749	7	71	1599	28690	53799	\N	57.640354844164399	Пермский край, Большесосновский муниципальный район, с. Баклуши, переулок Полевой, 2	Россия, Пермский край, Большесосновский район, село Баклуши	0101000020E6100000417E3672DD3A4B40406A1327F7D14C40
72186	7	71	997	32904	52271	\N	57.656542476410898	п.Шаква, ул.Центральная, д.1	Россия, Пермский край, Березовский район, село Шаква	0101000020E6100000B0E76B96CBA84C40A839799109D44C40
73234	7	71	997	48584	64419	\N	57.5367974077081	д.Харино, Центральная, 5	Россия, Пермский край, Березовский район, село Харино	0101000020E6100000A0E238F06AE34C40A3CB9BC3B5C44C40
71920	7	71	997	56301	52183	\N	57.5966580348815	с.Филатово, Никольского, 12	Россия, Пермский край, Березовский район, село Филатово	0101000020E610000072A59E05A1A84C40C972124A5FCC4C40
71719	7	71	997	27324	52275	\N	57.643498999999998	деревня Туясы, Центральная, 6 Дом культуры		0101000020E6100000001FBC7669BD4C401D01DC2C5ED24C40
71738	7	71	997	28175	53792	\N	57.432282297727802	поселок Тулумбасы, Железнодорожная, 8 бывший ФАП	Россия, Пермский край, Березовский район, село Тулумбасы	0101000020E6100000615111A793D04C4022533E0455B74C40
71737	7	71	997	28120	52590	\N	57.525368999999998	с.Таз Русский, Садовая, 10  ФАП		0101000020E61000009E60FF756EB04C4086AA984A3FC34C40
71724	7	71	997	32771	52357	\N	57.733673065924002	село Сая, Южная, 27 Дом культуры	Россия, Пермский край, Березовский район, село Сая	0101000020E6100000DC4AAFCDC6D64C40A77A32FFE8DD4C40
71728	7	71	997	56399	\N	\N	57.569918589670998	деревня Рыжково, 20 Дом культуры	Россия, Пермский край, Березовский район, село Рыжково	0101000020E61000002288F370029B4C403C2F151BF3C84C40
71718	7	71	997	27246	\N	\N	57.654820212319599	д.Пуздрино, 78	Россия, Пермский край, Березовский район, село Пуздрино	0101000020E610000033164D6727BB4C4024624A24D1D34C40
71745	7	71	997	28501	52302	\N	57.484999000000002	деревня Проносное, Центральная, 9 администрация сельского поселения		0101000020E6100000F06B2409C2C94C40DECB7D7214BE4C40
71744	7	71	997	32918	53261	\N	57.534312999999997	деревня Полушкино, Свободы, 3 Частный дом Потапова		0101000020E6100000A2D11DC4CEE04C40F0694E5E64C44C40
71743	7	71	997	58214	64359	\N	57.551701963491702	деревня Подволошино, Центральная, 3  Дом культуры	Россия, Пермский край, Березовский район, село Подволошино	0101000020E61000000DC7F31950E34C40A391CF2B9EC64C40
72407	7	71	997	28641	51630	\N	57.555528834682796	д.Песьянка, у.Мелиораторов, д.9	Россия, Пермский край, Березовский район, село Песьянка	0101000020E6100000420A9E42AEE64C40637D03931BC74C40
71739	7	71	997	32878	52589	\N	57.71172	деревня Перебор, Центральная, 49  Школа		0101000020E6100000CF8250DEC7A94C405EF415A419DB4C40
71716	7	71	997	27183	\N	\N	57.624090350369102	деревня Пентюрино, 54 сельский клуб	Россия, Пермский край, Березовский район, село Пентюрино	0101000020E61000007A71E2AB1DA54C405DE15D2EE2CF4C40
71723	7	71	997	27524	53757	\N	57.619407000000002	д.Метальниково, ул.Дружбы, 16		0101000020E6100000DFBF7971E2974C40EDF483BA48CF4C40
71734	7	71	997	56340	52308	\N	57.684445532566798	деревня Мачино, Молодежная, 6 бывший ФАП	Россия, Пермский край, Березовский район, село Мачино	0101000020E61000000EF3E505D8D34C4063F030ED9BD74C40
71736	7	71	997	58266	64553	\N	57.574908859000097	деревня Марково, Центральная, 14  Частный дом Ржанниковой	Россия, Пермский край, Березовский район, село Марково	0101000020E6100000417E3672DDBA4C4089963C9E96C94C40
71733	7	71	997	27965	52299	\N	57.611178576098602	деревня Малыши, Центральная, 18 ветучасток	Россия, Пермский край, Березовский район, село Малыши	0101000020E61000006F2A52616CD54C4041800C1D3BCE4C40
71715	7	71	997	32687	53754	\N	57.647468000000003	деревня Копчиково, Школьная, 7 сельская библиотека		0101000020E6100000567F8461C0AE4C40709A3E3BE0D24C40
71735	7	71	997	32848	52300	\N	57.569811999999999	д.Кляпово, Мичурина, 38 администрация СП		0101000020E6100000A2D45E44DBAF4C40266F8099EFC84C40
71729	7	71	997	27773	52277	\N	57.582475000000002	деревня Клычи, Школьная, 2 бывшая школа		0101000020E6100000A8716F7EC3A04C406ADE718A8ECA4C40
71727	7	71	997	27698	53160	\N	57.542028000000002	село Карнаухово, Школьная, 2  бывшая школа детский сад		0101000020E61000000D1AFA27B8984C4016C26A2C61C54C40
71732	7	71	997	27910	52393	\N	57.619160999999998	село Зернино, Мира, 12 Дом культуры		0101000020E610000066BFEE74E7D34C40B5FAEAAA40CF4C40
71730	7	71	997	27827	\N	\N	57.743867500162203	деревня Зарека, административное здание ИП Сергеев	Россия, Пермский край, Березовский район, село Зарека	0101000020E6100000053411363C9F4C403D450E1137DF4C40
71722	7	71	997	32745	52079	\N	57.660884000000003	деревня Дубовое, Школьная, 6  Правление колхоза		0101000020E61000000874266DAA964C408F39CFD897D44C40
71731	7	71	997	27866	52388	\N	57.764807472108501	деревня Батерики, Школьная, 7 Дом культуры	Россия, Пермский край, Березовский район, село Батерики	0101000020E61000005D35CF11F9A04C403D601E32E5E14C40
72264	7	71	997	56344	\N	\N	57.661397999738703	п.Бартым, СДК	Россия, Пермский край, Березовский район, село Бартым	0101000020E6100000821E6ADB30AE4C40E5D18DB0A8D44C40
71709	7	71	997	26862	52274	\N	57.516397995627301	село Асово, Советская, 57 администрации Асовского СП	Россия, Пермский край, Березовский район, село Асово	0101000020E6100000B91803EB38D64C4023DC645419C24C40
71710	7	71	997	26862	52340	\N	57.516151999999998	село Асово, Мира, 30 Школа		0101000020E6100000AA0F24EF1CD64C40EBE1CB4411C24C40
71721	7	71	997	32743	63656	\N	57.684136000000002	деревня Антонково, Нагорная, 2  Дом культуры		0101000020E61000000684D6C3979B4C401502B9C491D74C40
72323	7	71	982	32620	64506	\N	59.303049000000001	п. Рейд, Школьная, 1		0101000020E6100000BF4692205C5D4C40F20A444FCAA64D40
72800	7	71	982	8239	52059	\N	59.424363	г.Усолье, Чернышевского, 9		0101000020E6100000925D6919A9554C40F450DB8651B64D40
72799	7	71	982	8239	52161	\N	59.424363	г.Усолье, Солеваров, 161		0101000020E6100000925D6919A9554C40F450DB8651B64D40
72795	7	71	982	8239	52060	\N	59.424363	г.Усолье, Свободы, 155		0101000020E6100000925D6919A9554C40F450DB8651B64D40
72810	7	71	982	8239	52164	\N	59.424625889129899	г.Усолье, ул.Первомайская, 1б	Россия, Пермский край, Березники городской округ, Усолье	0101000020E610000043572250FD554C4002840F255AB64D40
72796	7	71	982	8239	52165	\N	59.424582153348901	г.Усолье, Елькина, 13\\1	Россия, Пермский край, Березники городской округ, Усолье	0101000020E6100000153B1A87FA554C40323CF6B358B64D40
72801	7	71	982	8239	52163	\N	59.424363	г.Усолье, 8 марта, 28		0101000020E6100000925D6919A9554C40F450DB8651B64D40
94310	7	71	982	47935	51755	\N	59.339013999999999	Усольский район,п.Железнодорожный, Центральная, 31	Россия, Пермский край, Березники городской округ, село Железнодорожный	0101000020E6100000718DCF64FF824C406D718DCF64AB4D40
71655	7	71	391	24341	53790	\N	57.0015	д. Шермейка, Советская, 6		0101000020E6100000AF93FAB2B4EB4B40D578E92631804C40
71654	7	71	391	24305	52586	\N	57.054659999999998	д. Шабарка, Центральная, 18		0101000020E61000004792205C01E74B401E335019FF864C40
71621	7	71	391	22773	52549	\N	56.992669999999997	д. Чалково, Зеленая, 2		0101000020E6100000E8F4BC1B0BCE4B4033DC80CF0F7F4C40
71653	7	71	391	24253	52584	\N	57.049925999999999	д. Федорки, Ленина, 50		0101000020E6100000C921E2E654A44B402C9CA4F963864C40
71628	7	71	391	23069	53773	\N	56.785117	д. Учкул, Нагорная, 5		0101000020E61000006C96CB46E7B84B404E44BFB67E644C40
71631	7	71	391	58018	62693	\N	57.056206000000003	д. УстьТунтор, Ленина, 22	Россия, Пермский край, Бардымский район, село Усть-Тунтор	0101000020E6100000185C7347FFCB4B4064EB19C231874C40
71651	7	71	391	56530	54326	\N	56.817350837801399	д. УстьАшап, Ленина, 44	Россия, Пермский край, Бардымский район, село Усть-Ашап	0101000020E6100000E6CB0BB08FD64B402C2D23F59E684C40
71652	7	71	391	24222	52582	\N	57.075772988453998	д. Уймуж, Советская, 24	Россия, Пермский край, Бардымский район, село Уймуж	0101000020E6100000446FF1F09EA94B40BC75FEEDB2894C40
71614	7	71	391	22415	52069	\N	56.819631000000001	д.Тюндюк, Ленина, 33		0101000020E61000003196E99788CF4B40D6E429ABE9684C40
71650	7	71	391	24095	52174	\N	56.772092999999998	д. Танып, Ленина, 20А		0101000020E6100000C9AB730CC8EA4B403A3C84F1D3624C40
58684	7	71	391	2044	52293	\N	56.847301000000002	д. Сюзянь, Ленина, 50		0101000020E610000083BEF4F6E7E24B401E6FF25B746C4C40
71649	7	71	391	24043	52297	\N	56.811059	д. Султанай, Мусы Джалиля, 5		0101000020E6100000431CEBE236DA4B40301004C8D0674C40
71622	7	71	391	22784	52295	\N	56.927343999999998	д. Старый Чад, Ленина, 10		0101000020E610000058FE7C5BB0B64B4027124C35B3764C40
71616	7	71	391	22541	53751	\N	56.810507000000001	д.Старый Ашап, Ленина, 5		0101000020E61000007B6B60AB04D54B40EC1681B1BE674C40
71648	7	71	391	24005	51673	\N	56.777231999999998	с. Сараши, Советская, 10		0101000020E6100000B3CD8DE909E14B40CCB392567C634C40
71645	7	71	391	23862	53256	\N	56.825645999999999	с. Печмень, Советская, 7		0101000020E610000029D027F224034C405F09A4C4AE694C40
71644	7	71	391	32519	53254	\N	56.766715583586397	д. Новый Чад, Дружбы, 23	Россия, Пермский край, Бардымский район, село Новый Чад	0101000020E61000005DA626C11BC24B40F4A8F8BF23624C40
71639	7	71	391	23597	53785	\N	56.672046999999999	с. Новый Ашап, Ленина, 49		0101000020E6100000ED65DB696BD84B40FD2FD7A205564C40
71642	7	71	391	32931	52575	\N	56.720937136531397	д. Новая Казанка, Мира, 52	Россия, Пермский край, Бардымский район, село Новая Казанка	0101000020E6100000B16D516683C04B40F9BCE2A9475C4C40
71641	7	71	391	32921	52538	\N	56.729659333088698	д. Никольск, Блюхера, 36	Россия, Пермский край, Бардымский район, село Никольск	0101000020E6100000834F73F222D54B40B41D5377655D4C40
71647	7	71	391	23941	53983	\N	56.915120999999999	д. Нижняя Искильда, Советская, 7		0101000020E610000033C2DB8310024C40007157AF22754C40
71620	7	71	391	32783	81099	\N	56.963729999999998	д. Мостовая, Центральная, 40	Россия, Пермский край, Бардымский район, село Мостовая	0101000020E61000001E51A1BAB9C84B40481630815B7B4C40
71637	7	71	391	23503	53775	\N	57.020364000000001	д. Куземьярово, Ленина, 19		0101000020E6100000BB438A0112C34B4004029D499B824C40
71638	7	71	391	23517	53783	\N	56.988972631026897	д. Кудаш, Ленина, 49	Россия, Пермский край, Бардымский район, село Кудаш	0101000020E610000042B456B439B64B4042D0D1AA967E4C40
71636	7	71	391	23439	52071	\N	56.894419999999997	с. 2 Краснояр, Карла Маркса, 9В		0101000020E61000005378D0ECBACF4B40B471C45A7C724C40
71635	7	71	391	23400	51563	\N	56.896774999999998	с. 1 Краснояр, Ленина, 69А		0101000020E61000004277499C15CD4B40696FF085C9724C40
71630	7	71	391	32840	53249	\N	57.062105000000003	д. Конюково, Ленина, 23		0101000020E61000006CEA3C2AFEC74B4084F57F0EF3874C40
71633	7	71	391	56343	52312	\N	56.787557	д. Константиновка, Ленина, 52	Россия, Пермский край, Бардымский район, село Константиновка	0101000020E610000032C9C859D8F54B40315EF3AACE644C40
71634	7	71	391	56371	52570	\N	56.775030060389199	д. Кармановка, Центральная, 26	Россия, Пермский край, Бардымский район, село Кармановка	0101000020E6100000C956975302044C409EB5DB2E34634C40
71624	7	71	391	32797	53766	\N	57.010195000000003	д. Ишимово, Ленина, 4		0101000020E6100000766D6FB724CB4B4097CADB114E814C40
71632	7	71	391	23254	53774	\N	57.033169000000001	д. Искирь, Ленина, 93		0101000020E610000086E8103812D84B40DA1EBDE13E844C40
71646	7	71	391	23913	53787	\N	56.858660999999998	д. Зязелга, Колхозная, 1		0101000020E610000009A52F849CF74B40E2AC889AE86D4C40
71093	7	70	1582	32661	53877	\N	53.687533999999999	село Чирково, Садовая, 22		0101000020E610000039471D1D57934640AC71361D01D84A40
72920	7	71	391	56348	\N	\N	57.1230597102847	с.Ермия, Администрация	Россия, Пермский край, Бардымский район, село Ермия	0101000020E61000003B191C25AFEE4B400FB9196EC08F4C40
71629	7	71	391	23130	51416	\N	57.086987999999998	с. Елпачиха, Советская, 2		0101000020E61000009C1551137DC24B407D923B6C228B4C40
71640	7	71	391	23617	53198	\N	56.602444377037401	д. Верхний Ашап, Фрунзе, 19	Россия, Пермский край, Бардымский район, село Верхний Ашап	0101000020E6100000139ED0EB4FDE4B40F1D58EE21C4D4C40
71643	7	71	391	58283	64585	\N	56.712654000000001	д. Верхний Шлык, Центральная, 23	Россия, Пермский край, Бардымский район, село Верхне-Шлык	0101000020E6100000255B5D4E09C44B408AAE0B3F385B4C40
71625	7	71	391	22945	53245	\N	56.874243609732503	д. Брюзли, Молодежная, 9	Россия, Пермский край, Бардымский район, село Брюзли	0101000020E61000002DD1596611EE4B40B35C363AE76F4C40
59579	7	71	391	45514	51668	\N	56.846223000000002	с. Бичурино, Ленина, 47		0101000020E61000006FB88FDC9AB64B40BF0F0709516C4C40
71623	7	71	391	62075	81100	\N	56.984698999999999	д. Березники, Советская, 11	Россия, Пермский край, Бардымский район, село Березники	0101000020E6100000066344A2D0C64B40B3B3E89D0A7E4C40
71626	7	71	391	22949	53768	\N	56.893486000000003	д. Батырбай, Мусы Джалиля, 12		0101000020E6100000AA0B789961E74B4089B7CEBF5D724C40
71627	7	71	391	32820	52298	\N	56.833092000000001	д. Бардабашка 1, Ленина, 22		0101000020E610000090DD054A0AAC4B40954737C2A26A4C40
71658	7	71	391	22601	51676	\N	56.925339999999998	с. Барда, Советская, 19		0101000020E6100000D2E5CDE15ACB4B401FD7868A71764C40
71657	7	71	391	22601	51417	\N	56.925339999999998	с. Барда, Ленина, 39		0101000020E6100000D2E5CDE15ACB4B401FD7868A71764C40
71617	7	71	391	22601	51417	\N	56.925339999999998	с.Барда, Ленина, 39		0101000020E6100000D2E5CDE15ACB4B401FD7868A71764C40
71618	7	71	391	22601	51756	\N	56.925339999999998	с. Барда, Кирова, 17		0101000020E6100000D2E5CDE15ACB4B401FD7868A71764C40
71619	7	71	391	22601	51562	\N	56.925339999999998	с.Барда, ул.Газовиков		0101000020E6100000D2E5CDE15ACB4B401FD7868A71764C40
71656	7	71	391	33006	63965	\N	57.003844553574503	д. Антуфьево, Центральная, 9	Россия, Пермский край, Бардымский район, село Антуфьево	0101000020E61000000B293FA9F6F94B4066A032FE7D804C40
71615	7	71	391	22505	52296	\N	56.845047000000001	д.Аклуши, Ленина, 41		0101000020E610000031CD74AF93CE4B409D4A06802A6C4C40
71613	7	71	391	58143	63920	\N	56.961239999999997	,д.Акбаш, Ленина, 8	Россия, Пермский край, Бардымский район, село Акбаш	0101000020E6100000A7203F1BB99E4B40B3CD8DE9097B4C40
71611	7	71	7456	58080	63208	\N	59.137830831283701	Пермский край, Александровский муниципальный район, п. Лытвенский, 9ой Пятилетки, 2		0101000020E61000009D2D20B41EC84C40FFAF3A72A4914D40
71602	7	71	1088	9589	51559	\N	59.335062000000001	Пермский край, Александровский МР, п. Яйва, Парковая, 11		0101000020E6100000304AD05FE8A14C40F110C64FE3AA4D40
71601	7	71	1088	9589	52068	\N	59.335062000000001	"""Пермский край, Александровский МР,   п. Яйва, ул. Коммунистическая, 9"""		0101000020E6100000304AD05FE8A14C40F110C64FE3AA4D40
71604	7	71	1088	9589	51561	\N	59.335062000000001	Пермский край, Александровский МР, п. Яйва, Заводская, 21		0101000020E6100000304AD05FE8A14C40F110C64FE3AA4D40
71603	7	71	1088	9589	51752	\N	59.335062000000001	Пермский край, Александровский МР, п. Яйва, 6 Пятилетки, 23		0101000020E6100000304AD05FE8A14C40F110C64FE3AA4D40
71610	7	71	1088	56314	52225	\N	59.160604601534601	Пермский край, Александровский муниципальный район, с. УстьИгум, Советская, 20	Россия, Пермский край, Александровск городской округ, село Усть-Игум	0101000020E61000006C98A1F144924C407B4963B48E944D40
71612	7	71	1088	22358	52115	\N	59.394013895984997	Пермский край, Александровский муниципальный район, п. Скопкортная, Ленина, 2	Россия, Пермский край, Александровск городской округ, село Скопкортная	0101000020E61000000266BE839FEA4C404415FE0C6FB24D40
72985	7	71	1088	58276	\N	\N	59.094182881497701	"""п.Мыс, филиал """"ВерхнеКалинского районого дома культуры"""""""	Россия, Пермский край, Александровск городской округ, село Мыс	0101000020E6100000E0F3C308E1834C406A6B44300E8C4D40
71609	7	71	1088	22249	53224	\N	59.151773560865998	Пермский край, Александровский МР, п. Луньевка, Пушкина, 8	Россия, Пермский край, Александровск городской округ, поселок Луньевка	0101000020E61000007EA8346266D74C400A3197546D934D40
71608	7	71	1088	56252	51856	\N	59.188938761481502	Пермский край, Александровский МР, п. КарьерИзвестняк, Мира, 1	Россия, Пермский край, Александровск городской округ, село Карьер Известняка	0101000020E610000093020B60CABC4C402FF834272F984D40
72318	7	71	1088	56290	52145	\N	59.092204180522302	с.Гремяча, Азина, 10	Россия, Пермский край, Александровск городской округ, село Гремяча	0101000020E6100000AA0CE36E10854C40BB473657CD8B4D40
71874	7	71	1088	47654	\N	\N	59.451853999999997	"""""""п. Гари, здание МОУ """"""""Гаринская ООШ"""""""""""""""	Россия, Пермский край, Александровск городской округ, поселок Гари	0101000020E6100000965AEF37DAD34C408C48145AD6B94D40
71605	7	71	1088	22075	51858	\N	59.221609036677201	Пермский край, Александровский МР, п. ВсеволодоВильва, Луначарского, 1 а, каб. 5	Россия, Пермский край, Александровск городской округ, поселок Всеволодо-Вильва	0101000020E61000005053CBD6FAB84C40E8BF07AF5D9C4D40
71606	7	71	1088	22075	52160	\N	59.219496999999997	Пермский край, Александровский МР, п. ВсеволодоВильва, Лоскутова, 7		0101000020E6100000429605137FB84C40F9484A7A189C4D40
72033	7	71	1088	46220	64360	\N	59.148119000000001	п.Булатово, ул. Центральная, 17, здание Булатовского филиала ГКАУ Соликамский ДИПИ		0101000020E61000003F8C101E6D924C4047753A90F5924D40
71365	7	70	\N	58936	67055	\N	53.081369000000002	Пензенская область, Пензенский район, Мичуринский сельсовет, станция Кривозеровка, ул.Железнодорожная, д.5-1		0101000020E6100000AD68739CDB64464041F4A44C6A8A4A40
70748	7	70	\N	12202	53344	\N	53.270108999999998	Пензенская область, Бессоновский район, Бессоновский сельсовет, село Ухтинка, Южная, 1 А		0101000020E6100000A5A2B1F67782464079AD84EE92A24A40
71411	7	70	\N	56420	53308	\N	52.466584134735903	Пензенская область, Сердобский район, город Сердобск, пер Строительный, 6	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000B35C363AE71B46401E6B4606B93B4A40
71414	7	70	\N	56420	53372	\N	52.464067244181997	Пензенская область, Сердобский район, город Сердобск, Советская, 1	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E61000003D9CC0745A1B46409013268C663B4A40
71415	7	70	\N	56420	53489	\N	52.464906018992401	Пензенская область, Сердобский район, город Сердобск, Сережникова, 10	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000F46DC1525D1A46406ADB300A823B4A40
71347	7	70	\N	56420	53486	\N	52.474576980594598	Пензенская область, Сердобский район, город Сердобск, Ленина, 61		0101000020E6100000B24AE9995E1C464086376BF0BE3C4A40
70617	7	70	\N	78	\N	\N	53.147930000000002	"Пензенская область, город Пенза, Первомайский район, ФКОУ ""Учебный центр УФСИН России по Пензенской области"""		0101000020E610000050C422861D7E4640740CC85EEF924A40
71399	7	70	\N	78	15946	\N	53.207666800715998	Пензенская область, Сердобский район, Сазанский сельсовет, Чаадаева, 2 б	Россия, Пензенская область, Пенза, улица Чаадаева, 2а	0101000020E61000003E5A9C31CC834640AEBA0ED5949A4A40
70564	7	70	\N	78	16304	\N	53.233446000000001	Пензенская область, город Пенза, Октябрьский район, Минская, 17	Россия, Пензенская область, Пенза, поселок Арбеково, улица Минская, 17	0101000020E6100000BC95253ACB784640E6B0FB8EE19D4A40
70487	7	70	\N	78	7929	\N	53.191831999999998	Пензенская область, город Пенза, Железнодорожный район, Касаткина, 8	Россия, Пензенская область, Пенза, улица Касаткина, 8	0101000020E610000095F25A09DD834640C32973F38D984A40
70509	7	70	\N	78	8141	\N	53.214302000000004	Пензенская область, город Пенза, Ленинский район, 8 Марта, 21-а	Россия, Пензенская область, Пенза, улица 8 Марта, 21а	0101000020E610000043739D465A7C4640D4BB783F6E9B4A40
70541	7	70	\N	78	53526	\N	53.223468790367498	Пензенская область, город Пенза, Октябрьский район, проспект Строителей, 47А	Россия, Пензенская область, Пенза, проспект Строителей, 47	0101000020E6100000603AADDBA0724640BD55D7A19A9C4A40
70457	7	70	\N	78	53526	\N	53.223128000000003	Пензенская область, город Заречный, Строителей, 11а	Россия, Пензенская область, Пенза, проспект Строителей, 11	0101000020E61000002BA5677A89774640346953758F9C4A40
70563	7	70	\N	78	53493	\N	53.229606156638397	Пензенская область, город Пенза, Октябрьский район, проспект Победы, 85	Россия, Пензенская область, Пенза, проспект Победы, 85	0101000020E610000085D0419770784640917BBABA639D4A40
70559	7	70	\N	78	53493	\N	53.232031263157701	Пензенская область, город Пенза, Октябрьский район, проспект Победы, 109	Россия, Пензенская область, Пенза, проспект Победы, 109	0101000020E6100000E44EE960FD7546403F541A31B39D4A40
70535	7	70	\N	78	53506	\N	53.187215384016902	Пензенская область, город Пенза, Ленинский район, Набережная реки Пензы, 3-а	Россия, Пензенская область, Пенза, набережная Реки Пензы, 3а	0101000020E6100000587380608E8246400B293FA9F6974A40
70561	7	70	\N	78	53498	\N	53.267928794224403	Пензенская область, город Пенза, Октябрьский район, Юбилейная, 13	Россия, Пензенская область, Пенза, улица Юбилейная	0101000020E6100000F52D73BA2C76464033535A7F4BA24A40
70616	7	70	\N	78	53594	\N	53.131822	Пензенская область, город Пенза, Первомайский район, Экспериментальная, 6А		0101000020E6100000A088450C3B8246405872158BDF904A40
70615	7	70	\N	78	53594	\N	53.132453825368998	Пензенская область, город Пенза, Первомайский район, Экспериментальная, 5		0101000020E6100000ABEAE5779A824640B91CAF40F4904A40
71386	7	70	1007	\N	53595	\N	52.565092345509001	Пензенская область, Сердобский район, Мещерский сельсовет, Школьная, 7	Россия, Пензенская область, Сердобский район	0101000020E6100000BB641C23D9134640999D45EF54484A40
70525	7	70	\N	78	53543	\N	53.200443680209801	Пензенская область, город Пенза, Ленинский район, Шевченко, 19	Россия, Пензенская область, Пенза, улица Шевченко, 17	0101000020E6100000C520B072687F4640F7562426A8994A40
70585	7	70	\N	78	53512	\N	53.180053455378101	Пензенская область, город Пенза, Первомайский район, Чкалова, 68	Россия, Пензенская область, Пенза, улица Чкалова, 68	0101000020E61000001A14CD0358804640FA4509FA0B974A40
70496	7	70	\N	78	53509	\N	53.210512814859499	Пензенская область, город Пенза, Железнодорожный район, Чаадаева, 119	Россия, Пензенская область, Пенза, улица Чаадаева, 119	0101000020E6100000A79196CADB87464001310917F29A4A40
71273	7	70	\N	78	53796	\N	53.123576999999997	с.Зеленодольское, Центральная, 33		0101000020E610000042CF66D5E7824640D6C4025FD18F4A40
70827	7	70	\N	78	53796	\N	53.120091000000002	Пензенская область, Городищенский район, Дигилёвский сельсовет, Центральная, 2		0101000020E610000048C0E8F2E6824640A0C552245F8F4A40
70618	7	70	\N	78	53796	\N	53.123722999999998	Пензенская область, город Пенза, Первомайский район, Центральная, 1		0101000020E61000007E02284696824640AA61BF27D68F4A40
70491	7	70	\N	78	53520	\N	53.201509999999999	Пензенская область, город Пенза, Железнодорожный район, Хользунова, 27/30		0101000020E61000002AC6F99B5086464092E86514CB994A40
70498	7	70	\N	78	53440	\N	53.206237023866201	Пензенская область, город Пенза, Железнодорожный район, Ушакова, 15	Россия, Пензенская область, Пенза, улица Орджоникидзе	0101000020E61000009012BBB6B7854640D21C59F9659A4A40
70560	7	70	\N	78	53523	\N	53.234012	Пензенская область, город Пенза, Октябрьский район, Ульяновская, 34А		0101000020E6100000B131AF230E7746408F6FEF1AF49D4A40
70612	7	70	\N	78	53500	\N	53.142055239530997	Пензенская область, город Пенза, Первомайский район, Терновского, 168	Россия, Пензенская область, Пенза, улица Терновского, 168	0101000020E6100000A4552DE928834640DC9DB5DB2E924A40
70611	7	70	\N	78	53500	\N	53.148393797569703	Пензенская область, город Пенза, Первомайский район, Терновского, 127А	Россия, Пензенская область, Пенза, улица Терновского, 127	0101000020E610000010035DFB0282464019761893FE924A40
70594	7	70	\N	78	53557	\N	53.155253000000002	Пензенская область, город Пенза, Первомайский район, Тепличная, 18		0101000020E6100000ACE122F7747B46408ECD8E54DF934A40
70488	7	70	\N	78	53519	\N	53.19529	Пензенская область, город Пенза, Железнодорожный район, Тарханова, 10А		0101000020E61000001BF4A5B73F854640309E4143FF984A40
70587	7	70	\N	78	53545	\N	53.174309999999998	Пензенская область, город Пенза, Первомайский район, Тамбовская, 20		0101000020E6100000F3565D876A804640D1AE42CA4F964A40
70614	7	70	\N	78	1579	\N	53.142000000000003	Пензенская область, город Пенза, Первомайский район, Сухумский проезд, 8	Россия, Пензенская область, Пенза, Сухумский проезд, 8	0101000020E6100000DBDE6E490E8246401904560E2D924A40
70521	7	70	\N	78	53521	\N	53.206612	Пензенская область, город Пенза, Ленинский район, Суворова, 190-а		0101000020E6100000CC7EDDE9CE7D4640077B1343729A4A40
70517	7	70	\N	78	53521	\N	53.207113999999997	Пензенская область, город Пенза, Ленинский район, Суворова, 198		0101000020E610000098C3EE3B867D4640994528B6829A4A40
70551	7	70	\N	78	53510	\N	53.221143003851402	Пензенская область, город Пенза, Октябрьский район, проспект Строителей, 7	Россия, Пензенская область, Пенза, Октябрьский район, микрорайон Арбеково	0101000020E6100000153AAFB14B784640A25EF0694E9C4A40
70627	7	70	\N	78	15374	\N	53.220142000000003	Пензенская область, город Заречный, Строителей, 20	Россия, Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 20	0101000020E6100000A6EF3504C7774640EF3CF19C2D9C4A40
70546	7	70	\N	78	15374	\N	53.220745999999998	Пензенская область, город Пенза, Октябрьский район, проспект Строителей, 46	Россия, Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 46	0101000020E6100000CD599F724C764640855CA967419C4A40
70545	7	70	\N	78	15374	\N	53.220492	Пензенская область, город Пенза, Октябрьский район, проспект Строителей, 52А	Россия, Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 52а	0101000020E6100000E0F3C308E1754640CB83F414399C4A40
70542	7	70	\N	78	15374	\N	53.219591999999999	Пензенская область, город Пенза, Октябрьский район, проспект Строителей, 140	Россия, Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 140	0101000020E61000001C7C6132557246404B3B35971B9C4A40
70508	7	70	\N	78	53546	\N	53.175271319644402	Пензенская область, город Пенза, Железнодорожный район, Ул. Спартаковская, 9,	Россия, Пензенская область, Пенза, Спартаковская улица, 9	0101000020E6100000DB5207793D8E4640F777B6476F964A40
70499	7	70	\N	78	53445	\N	53.1836210256809	Пензенская область, город Пенза, Железнодорожный район, Сосновая, 7	Россия, Пензенская область, Пенза, улица Сосновка, 7	0101000020E6100000D61BB5C2F4894640EEED96E480974A40
70592	7	70	\N	78	53280	\N	53.179292390178098	"Пензенская область, город Пенза, Первомайский район, ФГОУ СПО ""Пензенский аграрный техникум"""	Россия, Пензенская область, Пенза, улица Совхоз-техникум	0101000020E61000001268B0A9F37846409B374E0AF3964A40
70842	7	70	\N	78	53499	\N	53.184131999999998	Пензенская область, Городищенский район, Верхнеелюзанский сельсовет, Советская, 39		0101000020E6100000C68844A165814640D3122BA391974A40
70556	7	70	\N	78	53516	\N	53.224001999999999	Пензенская область, город Пенза, Октябрьский район, Собинова, 7		0101000020E610000060764F1E167446408A1EF818AC9C4A40
70555	7	70	\N	78	53516	\N	53.225911650120501	Пензенская область, город Пенза, Октябрьский район, Собинова, 9	Россия, Пензенская область, Пенза, улица Собинова, 9	0101000020E610000080D250A39074464011E335AFEA9C4A40
70544	7	70	\N	78	53516	\N	53.220514000000001	Пензенская область, город Пенза, Октябрьский район, Собинова, 6		0101000020E6100000C90391459A744640B32781CD399C4A40
70495	7	70	\N	78	53534	\N	53.208694000000001	Пензенская область, город Пенза, Железнодорожный район, Складская, 19		0101000020E610000009C1AA7AF98546408B6F287CB69A4A40
70610	7	70	\N	78	53530	\N	53.150047000000001	Пензенская область, город Пенза, Первомайский район, Ростовская, 58А		0101000020E61000003F027FF8F981464074EE76BD34934A40
70590	7	70	\N	78	53559	\N	53.170462000000001	Пензенская область, город Пенза, Первомайский район, Российская, 53		0101000020E6100000CF8250DEC77D4640FA9AE5B2D1954A40
70558	7	70	\N	78	53570	\N	53.229247000000001	Пензенская область, город Пенза, Октябрьский район, Рахманинова, 37А		0101000020E6100000EEB25F77BA75464062DA37F7579D4A40
70552	7	70	\N	78	53570	\N	53.227549000000003	Пензенская область, город Пенза, Октябрьский район, Рахманинова, 21		0101000020E610000071C79BFC16774640679E5C53209D4A40
70526	7	70	\N	78	53514	\N	53.199838	Пензенская область, город Пенза, Ленинский район, Пушкина, 31-а		0101000020E61000004F7974232C804640C03FA54A94994A40
70519	7	70	\N	78	53514	\N	53.199145033454698	Пензенская область, город Пенза, Ленинский район, Пушкина, 137	Россия, Пензенская область, Пенза, улица Пушкина, 137	0101000020E610000090A16307957E4640BA1457957D994A40
70489	7	70	\N	78	53581	\N	53.213396000000003	Пензенская область, город Пенза, Железнодорожный район, Проходная, 3		0101000020E6100000DAE3857478844640728C648F509B4A40
70481	7	70	\N	78	53529	\N	53.211002000000001	Пензенская область, город Пенза, Железнодорожный район, Пролетарская, 26А		0101000020E61000006BBA9EE8BA804640FFB1101D029B4A40
70577	7	70	\N	78	53544	\N	53.186371999999999	Пензенская область, город Пенза, Первомайский район, Попова, 14		0101000020E6100000F855B950F97D4640EF71A609DB974A40
70566	7	70	\N	78	13	\N	53.220821000000001	Пензенская область, город Пенза, Октябрьский район, проспект Победы, 41	Россия, Пензенская область, Пенза, Победы проспект, 41	0101000020E61000009B5AB6D6177D464090A2CEDC439C4A40
70565	7	70	\N	78	13	\N	53.221483999999997	Пензенская область, город Пенза, Октябрьский район, проспект Победы, 78	Россия, Пензенская область, Пенза, Победы проспект, 78	0101000020E6100000B7EC10FFB07B46402B4B7496599C4A40
70514	7	70	\N	78	13	\N	53.214447999999997	Пензенская область, город Пенза, Ленинский район, проспект Победы, 3	Россия, Пензенская область, Пенза, Победы проспект, 3	0101000020E6100000E8323509DE7E4640A7583508739B4A40
70513	7	70	\N	78	13	\N	53.216621000000004	Пензенская область, город Пенза, Ленинский район, проспект Победы, 25	Россия, Пензенская область, Пенза, Победы проспект, 25	0101000020E61000001FF64201DB7D46403C50A73CBA9B4A40
70529	7	70	\N	78	53571	\N	53.198791	Пензенская область, город Пенза, Ленинский район, Плеханова, 15		0101000020E61000006B60AB048B8146409CDEC5FB71994A40
70593	7	70	\N	78	53576	\N	53.167185000000003	Пензенская область, город Пенза, Первомайский район, Пермская, 1		0101000020E6100000FE9B1727BE7A4640DEB06D5166954A40
70501	7	70	\N	78	53564	\N	53.173900000000003	Пензенская область, город Пенза, Железнодорожный район, Перекоп, 4		0101000020E61000003E7AC37DE48446402063EE5A42964A40
70500	7	70	\N	78	53462	\N	53.200189614003001	Пензенская область, город Пенза, Железнодорожный район, Парковая, 2	Россия, Пензенская область, Пенза, Железнодорожный район	0101000020E61000009F55664AEB8346403D7E6FD39F994A40
70606	7	70	\N	78	53795	\N	53.168695999999997	Пензенская область, город Пенза, Первомайский район, Отдельная, 9		0101000020E610000015C5ABAC6D824640A67B9DD497954A40
70512	7	70	\N	78	53583	\N	53.214258999999998	Пензенская область, город Пенза, Ленинский район, Островского, 8		0101000020E6100000876A4AB20E7D4640D4EFC2D66C9B4A40
70547	7	70	\N	78	53538	\N	53.217995999999999	Пензенская область, город Пенза, Октябрьский район, Онежская, 11		0101000020E61000001C0934D8D47746405454FD4AE79B4A40
70486	7	70	\N	78	53533	\N	53.202696000000003	Пензенская область, город Пенза, Железнодорожный район, Октябрьская, 2		0101000020E610000039EE940ED6814640D88349F1F1994A40
70591	7	70	\N	78	53797	\N	53.174002000000002	Пензенская область, город Пенза, Первомайский район, Окружная, 115Б		0101000020E6100000EF552B137E7B464024B891B245964A40
71328	7	70	\N	78	54330	\N	53.233133000000002	Пензенская область, Пензенский район, Богословский сельсовет, поселок Приовражный, ул.Новая, д.13		0101000020E61000009B20EA3E00834640274F594DD79D4A40
70480	7	70	\N	78	53562	\N	53.217629000000002	Пензенская область, город Пенза, Железнодорожный район, Насосная, 1		0101000020E6100000C24D469561824640A2D45E44DB9B4A40
70553	7	70	\N	78	53553	\N	53.226638000000001	Пензенская область, город Пенза, Октябрьский район, Мусоргского, 17		0101000020E610000008C72C7B12764640F3035779029D4A40
70532	7	70	\N	78	53528	\N	53.196229000000002	Пензенская область, город Пенза, Ленинский район, Московская, 82-в		0101000020E61000004B0169FF038246406EC328081E994A40
70485	7	70	\N	78	53528	\N	53.201627999999999	Пензенская область, город Пенза, Железнодорожный район, Московская, 115		0101000020E61000009AED0A7DB08246409CFA40F2CE994A40
70497	7	70	\N	78	53470	\N	53.2181271500069	Пензенская область, город Пенза, Железнодорожный район, Молодогвардейская, 46А	Россия, Пензенская область, поселок Лесной, Молодогвардейская улица	0101000020E6100000EBAA402D068F4640F3AFE595EB9B4A40
70576	7	70	\N	78	53508	\N	53.244402000000001	Пензенская область, город Пенза, Октябрьский район, Можайского, 11		0101000020E610000085B1852007814640DB899290489F4A40
70579	7	70	\N	78	53556	\N	53.186269000000003	Пензенская область, город Пенза, Первомайский район, Мира, 62		0101000020E6100000D63730B9517C46401BA19FA9D7974A40
70578	7	70	\N	78	53556	\N	53.192253000000001	Пензенская область, город Пенза, Первомайский район, Мира, 15		0101000020E610000006F2ECF2AD7D464069C70DBF9B984A40
70562	7	70	\N	78	53554	\N	53.233041999999998	Пензенская область, город Пенза, Октябрьский район, Минская, 6А		0101000020E6100000047289230F784640164CFC51D49D4A40
70609	7	70	\N	78	53558	\N	53.155118000000002	Пензенская область, город Пенза, Первомайский район, Мебельная, 61Б		0101000020E61000001F4DF564FE814640AE8218E8DA934A40
70601	7	70	\N	78	53525	\N	53.159038000000002	Пензенская область, город Пенза, Первомайский район, Маркина, 2		0101000020E6100000942EFD4B527F46401F69705B5B944A40
70540	7	70	\N	78	53537	\N	53.226152999999996	Пензенская область, город Пенза, Октябрьский район, Лядова, 14		0101000020E6100000E42F2DEA937246403672DD94F29C4A40
70539	7	70	\N	78	53537	\N	53.225700000000003	Пензенская область, город Пенза, Октябрьский район, Лядова, 50		0101000020E6100000FAD005F52D714640865AD3BCE39C4A40
70482	7	70	\N	78	53532	\N	53.206774000000003	Пензенская область, город Пенза, Железнодорожный район, Луначарского, 10		0101000020E6100000847EA65EB7804640E1D40792779A4A40
70502	7	70	\N	78	53566	\N	53.180683999999999	Пензенская область, город Пенза, Железнодорожный район, Луговая, 1А		0101000020E6100000408A3A730F8546408A743FA720974A40
70479	7	70	\N	78	53563	\N	53.228482	Пензенская область, город Пенза, Железнодорожный район, Литвинова, 21А		0101000020E61000000DFD135CAC824640C2DCEEE53E9D4A40
70583	7	70	\N	78	53524	\N	53.182082000000001	Пензенская область, город Пенза, Первомайский район, Лермонтова, 8А		0101000020E6100000C097C283668146405B9885764E974A40
70580	7	70	\N	78	53531	\N	53.185809999999996	Пензенская область, город Пенза, Первомайский район, Ленинградская, 1А		0101000020E61000009BAA7B64737D464087A2409FC8974A40
70574	7	70	\N	78	53540	\N	53.215062000000003	Пензенская область, город Пенза, Октябрьский район, Ленина, 8А		0101000020E610000022382EE3A6804640624ED026879B4A40
70538	7	70	\N	78	53536	\N	53.218744999999998	Пензенская область, город Пенза, Октябрьский район, Ладожская, 125		0101000020E6100000C571E0D572714640EE940ED6FF9B4A40
70537	7	70	\N	78	53536	\N	53.219344	Пензенская область, город Пенза, Октябрьский район, Ладожская, 131		0101000020E61000008484285FD07046407349D576139C4A40
70573	7	70	\N	78	53541	\N	53.221150000000002	Пензенская область, город Пенза, Октябрьский район, Крупской, 5		0101000020E6100000AA285E656D7F464055C1A8A44E9C4A40
70493	7	70	\N	78	53565	\N	53.217213999999998	Пензенская область, город Пенза, Железнодорожный район, Красносельская, 29		0101000020E6100000952A51F696864640DE1D19ABCD9B4A40
70603	7	70	\N	78	53589	\N	53.168869000000001	Пензенская область, город Пенза, Первомайский район, Краснова, 19		0101000020E6100000A1F65B3B518046407427D87F9D954A40
70600	7	70	\N	78	53589	\N	53.164420999999997	Пензенская область, город Пенза, Первомайский район, Краснова, 121		0101000020E6100000FD321823127F464047E350BF0B954A40
70531	7	70	\N	78	53593	\N	53.185437999999998	Пензенская область, город Пенза, Ленинский район, Красная, 54		0101000020E6100000350BB43BA4804640C3B7B06EBC974A40
70507	7	70	\N	78	53567	\N	53.166218999999998	Пензенская область, город Пенза, Железнодорожный район, Конструкторская, 13		0101000020E6100000799109F8358E4640A67C08AA46954A40
70522	7	70	\N	78	53518	\N	53.208660999999999	Пензенская область, город Пенза, Ленинский район, Коммунистическая, 43-а		0101000020E610000040FB9122327E4640AF795567B59A4A40
70490	7	70	\N	78	53507	\N	53.212649892727498	Пензенская область, город Пенза, Железнодорожный район, Колхозная, 31	Россия, Пензенская область, Пенза, улица Колхозная, 32	0101000020E610000060CC96AC8A84464048BF7D1D389B4A40
70533	7	70	\N	78	53551	\N	53.192242	Пензенская область, город Пенза, Ленинский район, Кирова, 51		0101000020E6100000378AAC35948246407575C7629B984A40
70597	7	70	\N	78	53547	\N	53.163347000000002	Пензенская область, город Пенза, Первомайский район, Кижеватова, 13		0101000020E6100000C07971E2AB7D46402A73F38DE8944A40
70515	7	70	\N	78	53527	\N	53.212636000000003	Пензенская область, город Пенза, Ленинский район, Карпинского, 31		0101000020E6100000B5519D0E647D4640E4F90CA8379B4A40
70510	7	70	\N	78	53527	\N	53.211675999999997	Пензенская область, город Пенза, Ленинский район, Карпинского, 43-а		0101000020E61000006FA0C03BF97C46408EACFC32189B4A40
70605	7	70	\N	78	53577	\N	53.168286000000002	Пензенская область, город Пенза, Первомайский район, Калинина, 99Б		0101000020E610000000AC8E1CE9804640F52F49658A954A40
70608	7	70	\N	78	53513	\N	53.164448	Пензенская область, город Пенза, Первомайский район, Индустриальная, 48А		0101000020E6100000FACF9A1F7F83464041F2CEA10C954A40
71286	7	70	\N	78	53548	\N	53.173192999999998	с.Прудное, ул. Зеленая,10, здание МБУК «Прудненский ПБДЦ»,		0101000020E610000043554CA59F8E4640B4722F302B964A40
71285	7	70	\N	78	53548	\N	53.173192999999998	с.Прудное, Зеленая, 10		0101000020E610000043554CA59F8E4640B4722F302B964A40
70530	7	70	\N	78	53550	\N	53.192872999999999	Пензенская область, город Пенза, Ленинский район, Захарова, 20		0101000020E610000082AB3C81B07F464005A4FD0FB0984A40
70494	7	70	\N	78	53582	\N	53.214685000000003	Пензенская область, город Пенза, Железнодорожный район, Дружбы, 23		0101000020E6100000705D3123BC8746408CF84ECC7A9B4A40
70570	7	70	\N	78	53574	\N	53.225408999999999	Пензенская область, город Пенза, Октябрьский район, Докучаева, 20		0101000020E6100000971FB8CA137E4640AE9CBD33DA9C4A40
70569	7	70	\N	78	53574	\N	53.225408999999999	Пензенская область, город Пенза, Октябрьский район, ул.Докучаева,20		0101000020E6100000971FB8CA137E4640AE9CBD33DA9C4A40
70536	7	70	\N	78	53535	\N	53.176771000000002	Пензенская область, город Пенза, Ленинский район, Гоголя, 31		0101000020E610000065C5707500824640CCF09F6EA0964A40
70483	7	70	\N	78	53580	\N	53.210009999999997	Пензенская область, город Пенза, Железнодорожный район, Герцена, 37		0101000020E610000050FC1873D78046409EEA909BE19A4A40
70568	7	70	\N	78	15349	\N	53.230486999999997	Пензенская область, город Пенза, Октябрьский район, Германа Титова, 28	Россия, Пензенская область, Пенза, Германа Титова проезд, 38	0101000020E6100000809C3061347D46409A931799809D4A40
71344	7	70	\N	78	53549	\N	53.205291000000003	Пензенская область, Пензенский район, Засечный сельсовет, село Лебедевка, ул.Ворошилова, д.61		0101000020E6100000BED87BF1457F4640E294B9F9469A4A40
70524	7	70	\N	78	53549	\N	53.205328000000002	Пензенская область, город Пенза, Ленинский район, Ворошилова, 9		0101000020E6100000D388997D1E7F4640FF791A30489A4A40
70599	7	70	\N	78	53575	\N	53.165872999999998	Пензенская область, город Пенза, Первомайский район, Воронова, 20		0101000020E61000002A013109177E46400B2593533B954A40
70598	7	70	\N	78	53575	\N	53.164648	Пензенская область, город Пенза, Первомайский район, Воронова, 16		0101000020E6100000D9B0A6B2287E464008AD872F13954A40
70534	7	70	\N	78	53552	\N	53.193142999999999	Пензенская область, город Пенза, Ленинский район, Володарского, 49		0101000020E61000004CC11A67D3814640C539EAE8B8984A40
70589	7	70	\N	78	1189	\N	53.173867999999999	Пензенская область, город Пенза, Первомайский район, Водопьянова, 28	Россия, Пензенская область, Пенза, Водопьянова проезд, 28	0101000020E61000005070B1A2067F464014E97E4E41964A40
70613	7	70	\N	78	53561	\N	53.138019	Пензенская область, город Пенза, Первомайский район, Вадинская, 9А		0101000020E61000004AED45B41D834640029D499BAA914A40
70596	7	70	\N	78	53591	\N	53.155410000000003	Пензенская область, город Пенза, Первомайский район, Бурмистрова, 16А		0101000020E6100000A79201A08A7D464056BC9179E4934A40
70554	7	70	\N	78	53569	\N	53.224961	Пензенская область, город Пенза, Октябрьский район, Бородина, 16		0101000020E61000005A2BDA1CE77446400FF0A485CB9C4A40
70595	7	70	\N	78	53587	\N	53.136122999999998	Пензенская область, город Пенза, Первомайский район, Бийская, 1		0101000020E61000000FB56D18057B4640E09D7C7A6C914A40
70567	7	70	\N	78	53586	\N	53.221769999999999	Пензенская область, город Пенза, Октябрьский район, Беляева, 43		0101000020E61000001ABFF04A927D4640F19D98F5629C4A40
70518	7	70	\N	78	53539	\N	53.199147000000004	Пензенская область, город Пенза, Ленинский район, Бекешская, 14		0101000020E61000006B4606B98B7C46405B0C1EA67D994A40
70527	7	70	\N	78	53505	\N	53.200250310075901	Пензенская область, город Пенза, Ленинский район, Бакунина, 115	Россия, Пензенская область, Пенза, улица Бакунина, 111а	0101000020E610000010B3976DA77F46401283C0CAA1994A40
70484	7	70	\N	78	53505	\N	53.200512000000003	Пензенская область, город Пенза, Железнодорожный район, Бакунина, 88А		0101000020E61000003B527DE717814640503A9160AA994A40
70575	7	70	\N	78	53555	\N	53.239778999999999	Пензенская область, город Пенза, Октябрьский район, Аустрина, 129		0101000020E610000056B60F79CB81464040A20914B19E4A40
70506	7	70	\N	78	53496	\N	53.184710000000003	Пензенская область, город Пенза, Железнодорожный район, Антонова, 27А		0101000020E610000031B3CF6394874640419FC893A4974A40
70505	7	70	\N	78	53496	\N	53.183143802634099	Пензенская область, город Пенза, Железнодорожный район, Антонова, 72	Россия, Пензенская область, Пенза, улица Антонова	0101000020E610000035EB8CEF8B874640B43A394371974A40
70504	7	70	\N	78	53496	\N	53.187466999999998	Пензенская область, город Пенза, Железнодорожный район, Антонова, 6		0101000020E61000005E30B8E68E884640240A2DEBFE974A40
70503	7	70	\N	78	53496	\N	53.186338999999997	Пензенская область, город Пенза, Железнодорожный район, Антонова, 14		0101000020E6100000FAEFC16B97884640137CD3F4D9974A40
70511	7	70	\N	78	53515	\N	53.214302000000004	Пензенская область, город Пенза, Ленинский район, 8 марта, 21-а		0101000020E610000043739D465A7C4640D4BB783F6E9B4A40
70548	7	70	\N	78	16239	\N	53.222751000000002	Пензенская область, город Пенза, Октябрьский район, 5-й Виноградный проезд, 22	Россия, Пензенская область, Пенза, поселок Арбеково, 5-й Виноградный проезд, 22	0101000020E61000003082C64CA27846405E13D21A839C4A40
70492	7	70	\N	78	53584	\N	53.212004999999998	Пензенская область, город Пенза, Железнодорожный район, Медицинская, 1А		0101000020E6100000C808A8700487464053CBD6FA229B4A40
70571	7	70	\N	78	53588	\N	53.224891	Пензенская область, город Пенза, Октябрьский район, Леонова, 1А		0101000020E61000008BA6B393C17F46401615713AC99C4A40
70523	7	70	\N	78	53585	\N	53.208472999999998	Пензенская область, город Пенза, Ленинский район, Коммунистическая, 30		0101000020E610000034F279C5537F4640AC8C463EAF9A4A40
70607	7	70	\N	78	53590	\N	53.166353999999998	Пензенская область, город Пенза, Первомайский район, Индустриальная, 38		0101000020E6100000640795B88E83464086C77E164B954A40
70652	7	70	\N	7144	53416	\N	53.114756999999997	Пензенская область, город Кузнецк, Фабричная, 36		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70642	7	70	\N	7144	53255	\N	53.100969216829498	Пензенская область, город Кузнецк, Строителей, 87		0101000020E610000063804413284E474075745C8DEC8C4A40
70641	7	70	\N	7144	53255	\N	53.114756999999997	Пензенская область, город Кузнецк, Строителей, 123		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70667	7	70	\N	7144	53269	\N	53.114756999999997	Пензенская область, город Кузнецк, Рабочая, 331		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70665	7	70	\N	7144	53269	\N	53.114756999999997	Пензенская область, город Кузнецк, Рабочая, 346а		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70666	7	70	\N	7144	53266	\N	53.115766824855399	Пензенская область, город Кузнецк, Правды, 88в	Россия, Пензенская область, Кузнецк	0101000020E610000027DBC01DA84D47405F7AFB73D18E4A40
70645	7	70	\N	7144	53258	\N	53.1154828002663	Пензенская область, город Кузнецк, Осипенко, 49а		0101000020E610000029779FE3A34D47403A1F9E25C88E4A40
70659	7	70	\N	7144	53448	\N	53.114653712023703	Пензенская область, город Кузнецк, Орджоникидзе, 186а	Россия, Пензенская область, Кузнецк	0101000020E6100000FB3E1C24444D4740842D76FBAC8E4A40
70648	7	70	\N	7144	53257	\N	53.114966387092103	Пензенская область, город Кузнецк, Октябрьская, 1б	Россия, Пензенская область, Кузнецк городской округ	0101000020E61000005C1E6B46064F47407313B534B78E4A40
70647	7	70	\N	7144	53257	\N	53.114756999999997	Пензенская область, город Кузнецк, Октябрьская, 12а		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70644	7	70	\N	7144	53257	\N	53.114756999999997	Пензенская область, город Кузнецк, Октябрьская, 62а		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70643	7	70	\N	7144	53257	\N	53.115379518130098	Пензенская область, город Кузнецк, Октябрьская, 64	Россия, Пензенская область, Кузнецк	0101000020E6100000FCC22B499E4D4740664E97C5C48E4A40
70649	7	70	\N	7144	53262	\N	53.114756999999997	Пензенская область, город Кузнецк, Минская, 10а		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70662	7	70	\N	7144	53415	\N	53.115983473025899	Пензенская область, город Кузнецк, Ленина, 267	Россия, Пензенская область, Кузнецк	0101000020E610000071E82D1EDE4D47402CF2EB87D88E4A40
70660	7	70	\N	7144	53415	\N	53.114756999999997	Пензенская область, город Кузнецк, Ленина, 210		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70657	7	70	\N	7144	53415	\N	53.118374598863298	Пензенская область, город Кузнецк, Ленина, 116	Россия, Пензенская область, Кузнецк городской округ	0101000020E610000043ACFE08C34A4740FED478E9268F4A40
70661	7	70	\N	7144	53450	\N	53.112074358135402	Пензенская область, город Кузнецк, Кирова, 173	Россия, Пензенская область, Кузнецк городской округ	0101000020E6100000202922C32A504740AF5DDA70588E4A40
70664	7	70	\N	7144	53322	\N	53.114756999999997	Пензенская область, город Кузнецк, Калинина, 300		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70654	7	70	\N	7144	53413	\N	53.114756999999997	Пензенская область, город Кузнецк, Гагарина, 30		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70663	7	70	\N	7144	53331	\N	53.114756999999997	Пензенская область, город Кузнецк, Белинского, 130		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70658	7	70	\N	7144	53331	\N	53.114756999999997	Пензенская область, город Кузнецк, Белинского, 137		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70655	7	70	\N	7144	53331	\N	53.114021092768503	Пензенская область, город Кузнецк, Белинского, 109б	Россия, Пензенская область, Кузнецк	0101000020E6100000AB75E272BC4C47405307793D988E4A40
70653	7	70	\N	7144	53331	\N	53.111800396039101	Пензенская область, город Кузнецк, Белинского, 17	Россия, Пензенская область, Кузнецк	0101000020E6100000E8C072840C4E4740AED85F764F8E4A40
70651	7	70	\N	7144	53414	\N	53.114756999999997	Пензенская область, город Кузнецк, 60-летия ВЛКСМ, 3		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70668	7	70	\N	7144	53673	\N	53.114756999999997	Пензенская область, город Кузнецк, 1-я Бутурлинская, 47		0101000020E610000022533E04554D474058FE7C5BB08E4A40
70912	7	70	\N	56419	53466	\N	53.1798788254996	город Каменка, Чернышевского, 6	Россия, Пензенская область, Каменский район, Каменка	0101000020E6100000B3B27DC85B0446405C1E6B4606974A40
71074	7	70	1582	32549	54102	\N	53.656356000000002	село Сытинка, Совхозная, 14а		0101000020E61000006A183E22A67846404644317903D44A40
70913	7	70	\N	56419	53468	\N	53.183178746135901	город Каменка, Коллективная, 6	Россия, Пензенская область, Каменский район, Каменка	0101000020E6100000FFB0A547530546403128D36872974A40
70908	7	70	\N	56419	53282	\N	53.184925	город Каменка, Гражданская, 8		0101000020E6100000471E882CD20246403D9B559FAB974A40
70582	7	70	\N	60460	81152	\N	53.224583597660299	Пензенская область, город Заречный, проезд Молодежный, 2а	Россия	0101000020E6100000FC709010E59D4640399A232BBF9C4A40
70528	7	70	7508	\N	81153	\N	53.206857999999997	Пензенская область, город Заречный, Демакова, 4	Россия, Пензенская область, Пенза городской округ, село Селикса	0101000020E61000008D7DC9C6839746403E75AC527A9A4A40
70630	7	70	\N	58927	81145	\N	53.171466338232399	Пензенская область, город Заречный, проезд Молодежный, 2б	Россия	0101000020E6100000EC32FCA71B9846401F300F99F2954A40
70629	7	70	\N	\N	67034	\N	53.191733999999997	Пензенская область, город Заречный, Ленина, 66а	Россия	0101000020E610000066118AADA095464000C45DBD8A984A40
70626	7	70	\N	58927	67034	\N	53.179850123288503	Пензенская область, город Заречный, Ленина, 35а	Россия	0101000020E610000070ECD97399964640C217265305974A40
70718	7	70	\N	56427	53453	\N	52.965940910527202	г. Белинский, Советская площадь, 10	Россия, Пензенская область, Белинский район, Белинский	0101000020E6100000BA4E232D95B54540CA6E66F4A37B4A40
71525	7	70	1077	17853	53490	\N	52.889772999999998	р.п. Шемышейка, ул. Октябрьская, 5, здание межпоселенческого учреждения культуры,		0101000020E61000004FAF946588B1464091EEE714E4714A40
71524	7	70	1077	17853	53490	\N	52.889772999999998	Пензенская область, Шемышейский район, рабочий поселок Шемышейка, ул. Октябрьская, д. 5		0101000020E61000004FAF946588B1464091EEE714E4714A40
71526	7	70	1077	17853	53491	\N	52.889772999999998	Пензенская область, Шемышейский район, рабочий поселок Шемышейка, ул. Ленина, д. 34		0101000020E61000004FAF946588B1464091EEE714E4714A40
71523	7	70	1077	17755	54258	\N	52.966596000000003	с. Усть-Уза, ул. А.Ж. Богданова, 1в, здание сельского Дома культуры,		0101000020E610000057ED9A90D6A64640E338F06AB97B4A40
71522	7	70	1077	17755	53313	\N	52.966596000000003	Пензенская область, Шемышейский район, село Усть-Уза, ул. А.Ж. Богданова, д. 1 В		0101000020E610000057ED9A90D6A64640E338F06AB97B4A40
71351	7	70	1077	9522	54236	\N	52.860967000000002	Пензенская область, Пензенский район, Кондольский сельсовет, село Урлейка, ул.Школьная, д.35-а		0101000020E6100000CBF6216FB9904640B6F7A92A346E4A40
71519	7	70	1077	17589	54068	\N	52.874980999999998	Пензенская область, Шемышейский район, село Старое Назимкино, ул. Юбилейная, д. 4А		0101000020E61000004E4700378BA3464089CF9D60FF6F4A40
71518	7	70	1077	17562	53782	\N	52.903039	Пензенская область, Шемышейский район, село Старое Захаркино, Школьная площадь, д. 1		0101000020E610000099B9C0E5B19E46409B012EC896734A40
71517	7	70	1077	17493	53681	\N	52.924613000000001	Пензенская область, Шемышейский район, село Старое Демкино, ул. Совхозная, д. 25		0101000020E6100000083E062B4E9546406D3A02B859764A40
71520	7	70	1077	17654	53684	\N	53.023690000000002	с. Старая Яксарка, ул. Заречная, 29а, здание сельского Дома культуры,		0101000020E61000001CEBE2361AB64640029F1F4608834A40
71354	7	70	1077	9649	53834	\N	52.791246999999998	Пензенская область, Пензенский район, Кондольский сельсовет, село Спасско-Александровка, ул.Лесная, д.81		0101000020E6100000630D17B9A79946407007EA9447654A40
71516	7	70	1077	17415	53646	\N	52.683740999999998	Пензенская область, Шемышейский район, село Синодское, ул. Школьная, д. 2		0101000020E6100000215A2BDA1CB3464098F738D384574A40
71515	7	70	1077	17407	54254	\N	52.806471000000002	Пензенская область, Шемышейский район, село Русская Норка, ул. Центральная, 27		0101000020E6100000B6300BED9CB04640121615713A674A40
71514	7	70	1077	17340	54158	\N	53.031516000000003	Пензенская область, Шемышейский район, село Песчанка, ул. Молодежная, д. 26		0101000020E6100000EB73B515FBC946407FA65EB708844A40
71513	7	70	1077	17276	54157	\N	52.933695	Пензенская область, Шемышейский район, село Новый Мачим, ул. Специалистов, д. 8		0101000020E6100000A60F5D50DFDE464028B8585183774A40
71512	7	70	1077	17257	54067	\N	52.865788999999999	Пензенская область, Шемышейский район, село Наумкино, ул. Чехманова, д. 2А		0101000020E61000003F1EFAEE56A44640471E882CD26E4A40
71511	7	70	1077	17209	9881	\N	52.950952000000001	Пензенская область, Шемышейский район, село Наскафтым, ул. Ленина, д. 11		0101000020E6100000B189CC5CE0D046406C088ECBB8794A40
71510	7	70	1077	17150	53942	\N	52.849927999999998	Пензенская область, Шемышейский район, село Мордовская Норка, ул. Сельская, д. 20		0101000020E6100000EF004F5AB8BA464033FAD170CA6C4A40
71509	7	70	1077	32699	54162	\N	52.770384999999997	Пензенская область, Шемышейский район, село Мачкассы, ул. Октябрьская, д. 3		0101000020E6100000679B1BD313CA46401B2AC6F99B624A40
71508	7	70	1077	17059	54279	\N	53.076902297164203	Пензенская область, Шемышейский район, село Колдаис, ул. Советская, д. 3 Б		0101000020E6100000B33F506EDBC546409D7FBBECD7894A40
71506	7	70	1077	16924	53933	\N	52.773997000000001	Пензенская область, Шемышейский район, село Каржимант, ул. Школьная, д. 2		0101000020E6100000B5FE9600FCC34640DF196D5512634A40
71507	7	70	1077	16995	53932	\N	52.680728000000002	Пензенская область, Шемышейский район, село Каргалейка, ул. Лесная, д.2		0101000020E610000036AE7FD767C246405ABC581822574A40
71505	7	70	1077	16913	54252	\N	52.815429999999999	Пензенская область, Шемышейский район, село Воробьевка, ул. Молодежная, 11		0101000020E6100000857CD0B3599F4640B1169F0260684A40
71504	7	70	1077	16855	53781	\N	52.864299000000003	Пензенская область, Шемышейский район, село Армиево, ул. Центральная, 1		0101000020E610000038BEF6CC92C84640967B8159A16E4A40
71502	7	70	244	16767	53644	\N	52.685870999999999	Пензенская область, Тамалинский район, Ульяновский сельсовет, с. Ульяновка, Новая, 8		0101000020E6100000E109BDFE24A245402D23F59ECA574A40
71483	7	70	244	15631	53642	\N	52.540919000000002	Здание   школы   р.п. Тамала, ул. Центральная, 1		0101000020E61000004F779E78CE9E45407C6473D53C454A40
71481	7	70	244	15631	53374	\N	52.540919000000002	Пензенская область, Тамалинский район, рабочий поселок Тамала, Транспортная, 76		0101000020E61000004F779E78CE9E45407C6473D53C454A40
71480	7	70	244	15631	53371	\N	52.540919000000002	Пензенская область, Тамалинский район, рабочий поселок Тамала, Советская, 16		0101000020E61000004F779E78CE9E45407C6473D53C454A40
71484	7	70	244	15631	54274	\N	52.541194905870597	Пензенская область, Тамалинский район, рабочий поселок Тамала, Пролетарская, 43	Россия, Пензенская область, Тамалинский район, поселок Тамала	0101000020E61000009E077767ED9E45401EE1B4E045454A40
71485	7	70	244	15631	53802	\N	52.541247237413302	Пензенская область, Тамалинский район, рабочий поселок Тамала, Заводская, 9		0101000020E61000002B33A5F5B79E45407007EA9447454A40
71482	7	70	244	15631	53683	\N	52.544372809076599	здание  бывшей конторы сельхозтехники р.п. Тамала, ул. Железнодорожная,  21	Россия, Пензенская область, Тамалинский район, поселок Тамала	0101000020E610000047AD307DAF9F4540A7E9B303AE454A40
71499	7	70	244	16614	53930	\N	52.769295999999997	Пензенская область, Тамалинский район, Волче-Вражский сельсовет, п. Степной, Центральная, 17		0101000020E61000009370218FE0BC4540C878944A78624A40
71292	7	70	244	56468	53938	\N	52.823245884086901	с.Павловка, ул.Железнодорожная,1, здание магазина ООО «Маиское торговое предприятие»	Россия, Пензенская область, Тамалинский район, село Павловка	0101000020E6100000A185048C2E9745400A48FB1F60694A40
71440	7	70	244	56476	53981	\N	52.626469337041101	"с. Озерки, ул. Овражная, 66, здание школы, "	Россия, Пензенская область, Тамалинский район, село Озерки	0101000020E6100000D49B51F355A845409A7ADD2230504A40
71501	7	70	244	19385	53817	\N	52.747028488052301	Здание   Обвальского СДК, ул. Иванова 49- б,	Россия, Пензенская область, Тамалинский район, село Обвал	0101000020E61000003D450E11379F454020990E9D9E5F4A40
71490	7	70	244	16141	53929	\N	52.589528000000001	Пензенская область, Тамалинский район, Вишневский сельсовет, с. Никольское, Центральная, 4		0101000020E610000049F6083543B44540C4094CA7754B4A40
71186	7	70	244	963	54037	\N	52.828099000000002	"с. Наровчат, ул. Ленина, д. 2, здание МБУК ""Центральный районный Дом культуры"" "		0101000020E6100000DC627E6E68B24540D76CE525FF694A40
71496	7	70	244	56510	54260	\N	52.712947264348301	здание школы с. Мача, ул. Садовая 1	Россия, Пензенская область, Тамалинский район, село Мача	0101000020E6100000B491EBA694C145400264E8D8415B4A40
71486	7	70	244	19685	53791	\N	52.5010688362796	Здание  школы с. Малая Сергиевка, ул.  Школьная, 4	Россия, Пензенская область, Тамалинский район, село Малая Сергиевка	0101000020E610000096B20C71AC9745400C056C0723404A40
70681	7	70	244	56448	53713	\N	52.7380141597069	с. Липовка, Советская, 117	Россия, Пензенская область, Тамалинский район, село Липовка	0101000020E610000089247A19C5A44540BDFE243E775E4A40
71498	7	70	244	19333	54264	\N	52.800715041973604	Здание  школы  с. Куликовка, ул. Центральная  55-а	Россия, Пензенская область, Тамалинский район, село Куликовка	0101000020E61000007F33315D88B34540543541D47D664A40
70331	7	70	244	16628	53977	\N	52.801238897873901	с. Каменка, Передовик, 5а	Россия, Пензенская область, Тамалинский район, село Каменка	0101000020E6100000DBA2CC0699984540CFA3E2FF8E664A40
71500	7	70	244	16628	54155	\N	52.800961000000001	Пензенская область, Тамалинский район, Ульяновский сельсовет, с. Каменка, Молодежная, 17		0101000020E610000007EFAB72A19845408C2FDAE385664A40
71487	7	70	244	16008	54250	\N	52.481605000000002	Пензенская область, Тамалинский район, Малосергиевский сельсовет, с. Калиновка, Мира, 2		0101000020E6100000B5A9BA47368B4540884B8E3BA53D4A40
71489	7	70	244	19772	54266	\N	52.383563000000002	Здание  школы  с. Зубрилово, ул.  Центральная 22		0101000020E6100000BB0D6ABFB5B14540537AA69718314A40
71491	7	70	244	16182	54253	\N	52.518538999999997	Пензенская область, Тамалинский район, Вишневский сельсовет, с. Дуровка, Школьная, 1-а		0101000020E61000006C7C26FBE7B34540AB59677C5F424A40
71494	7	70	244	16318	54151	\N	52.773394833206503	Пензенская область, Тамалинский район, Мачинский сельсовет, с. Григорьевка, Центральная, 1	Россия, Пензенская область, Тамалинский район, село Григорьевка	0101000020E610000081785DBF60CD4540E9F17B9BFE624A40
71497	7	70	244	18722	54262	\N	52.7637808427259	Здание  школы с. Волчий – Враг,  ул. Молодежная 25	Россия, Пензенская область, Тамалинский район, село Волчий Враг	0101000020E6100000795DBF6037B4454031276893C3614A40
71492	7	70	244	19812	53788	\N	52.639342990401197	Здание  школы с. Вишневое, ул.  Крылова 49	Россия, Пензенская область, Тамалинский район, село Вишневое	0101000020E6100000EFE6A90EB9B9454098F6CDFDD5514A40
71488	7	70	244	16019	53928	\N	52.461955000000003	Пензенская область, Тамалинский район, Малосергиевский сельсовет, с. Варварино, Центральная, 9		0101000020E610000084656CE866A54540A29C6857213B4A40
71493	7	70	244	16306	53950	\N	52.655470000000001	Пензенская область, Тамалинский район, Вишневский сельсовет, с. Большая Сергеевка, Центральная, 8-а		0101000020E61000008FFF024180B245402BC1E270E6534A40
71503	7	70	244	16809	53931	\N	52.593964999999997	Пензенская область, Тамалинский район, Ульяновский сельсовет, с. Березовка, Молодежная, 14		0101000020E610000030BDFDB9689C4540FCFB8C0B074C4A40
70604	7	70	244	56473	53959	\N	52.666030291432001	с. Алексеевка, Середочка, 1	Россия, Пензенская область, Тамалинский район, село Алексеевка	0101000020E6100000444FCAA486A24540D313967840554A40
71454	7	70	1096	33029	54242	\N	53.445155999999997	с. Щукино, Школьная, 2		0101000020E6100000C1E3DBBB0631474020CF2EDFFAB84A40
71453	7	70	1096	33024	54064	\N	53.412030999999999	с. Шугурово, Лесная, 19		0101000020E6100000E412471E883C474016F88A6EBDB44A40
71452	7	70	1096	14298	54241	\N	53.379036999999997	с. Шкудим, Песчаная, 1		0101000020E61000004CDF6B088E394740AA7CCF4884B04A40
71451	7	70	1096	33016	53920	\N	53.363720000000001	с. Топоровка, Дачная, 69		0101000020E61000008E5BCCCF0D1B4740587380608EAE4A40
71450	7	70	1096	14236	53778	\N	53.328391000000003	с. Тешнярь, Учительская, 30		0101000020E6100000CA6FD1C9521F47407FA65EB708AA4A40
71449	7	70	1096	14170	53916	\N	53.423403	с. Татарский Сыромяс, Полевая, 4		0101000020E6100000E17B7F83F60047409F03CB1132B64A40
71443	7	70	1096	32975	53637	\N	53.296951	р.п. Сосновоборск, Театральная, 1		0101000020E61000005AF3E32F2D204740DBC1887D02A64A40
71447	7	70	1096	32975	53405	\N	53.2939409137037	р. п. Сосновоборск, Ленина, 65	Россия, Пензенская область, Сосновоборский район, поселок Сосновоборск	0101000020E6100000CF2C0950531F47400DFAD2DB9FA54A40
71446	7	70	1096	32975	53312	\N	53.296951	р. п. Сосновоборск, Кададинская, 28А		0101000020E61000005AF3E32F2D204740DBC1887D02A64A40
71445	7	70	1096	32975	53312	\N	53.297591958621297	р. п. Сосновоборск, Кададинская, 30Б	Россия, Пензенская область, Сосновоборский район, поселок Сосновоборск	0101000020E6100000429946938B1F47408FC6A17E17A64A40
71444	7	70	1096	32975	53370	\N	53.296951	р.п. Сосновоборск, Гагарина, 2		0101000020E61000005AF3E32F2D204740DBC1887D02A64A40
71442	7	70	1096	13842	53919	\N	53.420994	с. Русский Качим, Новая, 8		0101000020E61000003F8C101E6D564740F7E7A221E3B54A40
71441	7	70	1096	13791	54244	\N	53.364193	"с. Пичилейка, ул. Центральная, 2, здание администрации, "		0101000020E610000081CEA44DD5074740503750E09DAE4A40
71439	7	70	1096	13701	54144	\N	53.441654	с. Новополянское, Школьная, 26		0101000020E61000001FBC7669C3474740E412471E88B84A40
71438	7	70	1096	13630	54243	\N	53.454664000000001	с. Николо-Барнуки, Центральная, 33А		0101000020E610000016C3D501102947409355116E32BA4A40
71436	7	70	1096	13560	54145	\N	53.418343	с. Нижний Мывал, Школьная, 23		0101000020E61000002B4F20EC1415474059C16F438CB54A40
71435	7	70	1096	13508	54148	\N	53.249139	с. Нижний Катмис, Центральная, 4		0101000020E610000051F4C0C7600147403E9468C9E39F4A40
71437	7	70	1096	56498	54153	\N	53.2260991696849	"с. Нижняя Липовка, ул. Куракина, 28, здание администрации, "	Россия, Пензенская область, Сосновоборский район, село Нижная Липовка	0101000020E61000005DDF8783841247404354E1CFF09C4A40
71434	7	70	1096	13477	54239	\N	53.390143000000002	с. Мордовский Качим, Центральная, 66		0101000020E6100000C18C2958E3524740B5E1B034F0B14A40
71432	7	70	1096	13351	54246	\N	53.428210999999997	с. Малая Садовка, Садовая, 94		0101000020E6100000E4A3C519C3244740CB64389ECFB64A40
71431	7	70	1096	56514	54269	\N	53.467819590820902	"с. Кряжимское, ул. Новая, 20, здание администрации, "	Россия, Пензенская область, Сосновоборский район, село Кряжим	0101000020E61000000B62A06B5F16474016359886E1BB4A40
71355	7	70	1096	9726	53682	\N	53.392893000000001	Пензенская область, Пензенский район, Краснопольский сельсовет, село Краснополье, ул.Центральная, д.8		0101000020E610000036785F950BF34640E6E95C514AB24A40
71051	7	70	1096	47732	53744	\N	53.436009526864801	село Козловка, Ленина, 85А	Россия, Пензенская область, Сосновоборский район, село Козловка	0101000020E6100000B2101D02472E47404F5DF92CCFB74A40
71430	7	70	1096	13285	54139	\N	53.331068999999999	с. Кардафлей, Веленка, 16		0101000020E61000005B5EB9DE3603474016DC0F7860AA4A40
70975	7	70	1096	56477	54012	\N	53.399832613364097	д.Карауловка, Школьная, 59		0101000020E610000034D6FECEF61C4740486E4DBA2DB34A40
71428	7	70	1096	13193	53487	\N	53.241906999999998	с. Индерка, переулок Школьный, 20		0101000020E6100000D4298F6E8421474034D6FECEF69E4A40
71429	7	70	1096	13193	53404	\N	53.241906999999998	с. Индерка, переулок Центральный, 1		0101000020E6100000D4298F6E8421474034D6FECEF69E4A40
70841	7	70	1096	25005	53596	\N	53.150113637539903	Пензенская область, Городищенский район, Среднеелюзанский сельсовет, с.Средняя Елюзань, Складская, 2	Россия, Пензенская область, Сосновоборский район, село Елюзань	0101000020E610000020D26F5F07104740FC5580EF36934A40
70840	7	70	1096	25005	53283	\N	53.150104668146803	Пензенская область, Городищенский район, Среднеелюзанский сельсовет, с.Средняя Елюзань, Коммунальная, 3	Россия, Пензенская область, Сосновоборский район, село Елюзань	0101000020E6100000664AEB6F09104740A9FB00A436934A40
70839	7	70	1096	25005	53283	\N	53.150836020232703	Пензенская область, Городищенский район, Среднеелюзанский сельсовет, с.Средняя Елюзань, Коммунальная, 15	Россия, Пензенская область, Сосновоборский район, село Елюзань	0101000020E61000002E73BA2C261047409C8713984E934A40
71010	7	70	1096	25005	53989	\N	53.149993000000002	Пензенская область, Кузнецкий район, Сюзюмский сельсовет, ст.Елюзань, Веселая, 11		0101000020E61000008F52094FE80F474081D07AF832934A40
71427	7	70	1096	32859	53914	\N	53.316020000000002	с. Ёга, Учительская, 1		0101000020E6100000508F6D19700E4740E370E65773A84A40
70892	7	70	1096	56472	53954	\N	53.317001348126198	с. Дмитриевка, Школьная, 8	Россия, Пензенская область, Сосновоборский район, село Дмитриевка	0101000020E6100000051901158EFA46404FE61F7D93A84A40
71425	7	70	1096	32844	54062	\N	53.278643000000002	с. Водолей, Водолейская, 10А		0101000020E61000003A3B191C25FF46403221E692AAA34A40
71424	7	70	1096	13000	54063	\N	53.397236999999997	с. Верхний Катмис, Центральная, 127		0101000020E61000001FF7ADD6890947406DE179A9D8B24A40
71423	7	70	1096	12945	53918	\N	53.372359000000003	с. Вачелай, Центральная, 2		0101000020E61000006500A8E2C617474086AFAF75A9AF4A40
71421	7	70	1096	12866	53922	\N	53.227069	с. Альмяшевка, Центральная, 45А		0101000020E610000017BA1281EA074740BC77D498109D4A40
71382	7	70	1007	11034	53913	\N	52.547561999999999	Пензенская область, Сердобский район, село Софьино, Орловка, 24		0101000020E6100000DC9C4A0680F845402444F98216464A40
71389	7	70	1007	9330	53495	\N	52.476529259804899	Пензенская область, Сердобский район, Пригородный сельсовет, Школьная пл, 1	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E610000035D1E7A38C1C46403C4CFBE6FE3C4A40
71397	7	70	1007	9330	53779	\N	52.464788067255199	Пензенская область, Сердобский район, Сокольский сельсовет, Школьная, 4	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000CA880B40A31A464060C9552C7E3B4A40
71388	7	70	1007	9330	53779	\N	52.464368680728299	Пензенская область, Сердобский район, Новостуденовский сельсовет, Школьная, 4	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000A64412BD8C1A46405B238271703B4A40
71416	7	70	1007	9330	53318	\N	52.474131481865498	Пензенская область, Сердобский район, город Сердобск, Тюрина, 9		0101000020E6100000899AE8F3511C464088821953B03C4A40
71394	7	70	1007	9330	53367	\N	52.460594021290298	Пензенская область, Сердобский район, Рощинский сельсовет, Советская, 28	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E610000062855B3E921C4640EE5D83BEF43A4A40
71379	7	70	1007	\N	53717	\N	52.568253596418998	Пензенская область, Сердобский район, Долгоруковский сельсовет, Слепцова, 32	Россия, Пензенская область, Сердобский район	0101000020E61000006BB8C83D5D1546401DE90C8CBC484A40
71390	7	70	1007	9330	53503	\N	52.464788067255199	Пензенская область, Сердобский район, Пригородный сельсовет, Скворцовка, 4	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000527C7C42761A464060C9552C7E3B4A40
71393	7	70	1007	9330	53745	\N	52.463110497055197	Пензенская область, Сердобский район, Песчанский сельсовет, Первомайская, 6б	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000527C7C42761A4640AC394030473B4A40
71383	7	70	1007	9330	53742	\N	52.479044820098601	Пензенская область, Сердобский район, Кировский сельсовет, Новая, 10	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000AA0D4E44BF1C4640FA27B858513D4A40
71407	7	70	1007	9330	53406	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Набережная, 58		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71420	7	70	1007	9330	53328	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Максима Горького, 251г		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71418	7	70	1007	9330	53309	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Макарова, 7		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71417	7	70	1007	9330	53309	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Макарова, 2		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71406	7	70	1007	9330	53330	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Лесная, 37		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71413	7	70	1007	9330	53305	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Ленина, 291		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71412	7	70	1007	9330	53305	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Ленина, 271а		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71410	7	70	1007	9330	53305	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Ленина, 218		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71409	7	70	1007	9330	53305	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Ленина, 214		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71408	7	70	1007	9330	53305	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Ленина, 148		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71405	7	70	1007	9330	53366	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Куйбышева, 58		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71391	7	70	1007	9330	53502	\N	52.476529259804899	Пензенская область, Сердобский район, Пригородный сельсовет, Колхозная, 99	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E6100000221ADD41EC1C46403C4CFBE6FE3C4A40
71401	7	70	1007	9330	53403	\N	52.473712184803396	Пензенская область, Сердобский район, город Сердобск, Калинина, 31	Россия, Пензенская область, Сердобский район, Сердобск	0101000020E610000086CABF96571C464083DC4598A23C4A40
71403	7	70	1007	9330	53304	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Гагарина, 30		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71402	7	70	1007	9330	53304	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Гагарина, 16		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71404	7	70	1007	9330	53362	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Балашовская, 2е		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71419	7	70	1007	9330	53310	\N	52.473607999999999	Пензенская область, Сердобский район, город Сердобск, Энергетиков, 2		0101000020E6100000D7A02FBDFD1B4640DE8FDB2F9F3C4A40
71396	7	70	1007	11696	53609	\N	52.598636999999997	"Пензенская область, Сердобский район, село Секретарка, здание  филиала МОУ СОШ № 9 г.Сердобска ""Средняя школа с.Секретарка"", ул.Школьная, 2 а, "		0101000020E610000025B03907CF16464078962023A04C4A40
71392	7	70	1007	11519	54125	\N	52.390483000000003	Пензенская область, Сердобский район, село Салтыково, Центральная, 94		0101000020E610000086376BF0BE2A46406E52D158FB314A40
71380	7	70	1007	40345	9888	\N	52.541677539322599	Пензенская область, Сердобский район, Куракинский сельсовет, Ленинская, 25 а	Россия, Пензенская область, Сердобский район, село Куракино	0101000020E6100000543A58FFE7064640397B67B455454A40
71384	7	70	1007	11115	53777	\N	52.474639000000003	Пензенская область, Сердобский район, село Карповка, Московская, 134а		0101000020E6100000A81ABD1AA0084640FD3383F8C03C4A40
71385	7	70	1007	11166	54060	\N	52.480167999999999	Пензенская область, Сердобский район, село Камзолка, Светлая, 26а		0101000020E61000004833164D67F54540F94A2025763D4A40
71334	7	70	1007	8739	54132	\N	52.482762000000001	Пензенская область, Сердобский район, Зеленый Дол село, Садовая, 6а		0101000020E61000009EEFA7C64B23464033E02C25CB3D4A40
71360	7	70	1007	33061	54105	\N	52.442027000000003	Пензенская область, Сердобский район, Новостуденовский сельсовет, Новый Хутор, 21		0101000020E61000004B77D7D9903B464079793A5794384A40
70974	7	70	1007	33061	54195	\N	52.442198654816501	с.Зеленовка, Центральная, 1	Россия, Пензенская область, Сердобский район, село Зеленовка	0101000020E6100000D926158DB53B464076A911FA99384A40
71378	7	70	1007	10831	53911	\N	52.730632999999997	Пензенская область, Сердобский район, село Гуленовка, Комсомольская, 11		0101000020E6100000EF8D2100380C46406E30D461855D4A40
70921	7	70	1007	56446	53700	\N	52.409510065022999	с. Варваровка, Победы, 12	Россия, Пензенская область, Сердобский район, село Варваровка	0101000020E6100000C1A739799133464046B1DCD26A344A40
71377	7	70	1007	10798	54078	\N	52.359336999999996	Пензенская область, Сердобский район, село Байка, Советская, 10		0101000020E610000008AC1C5A641B4640129F3BC1FE2D4A40
71091	7	70	1582	28693	53993	\N	53.764595	село Старая Степановка, Центральная, 3а		0101000020E61000007E5704FF5B954640B2D7BB3FDEE14A40
71381	7	70	1007	32539	53961	\N	52.519661999999997	Пензенская область, Сердобский район, Ал.Ростовка село, Луговая, 71 а		0101000020E6100000DE91B1DAFC054640AA7CCF4884424A40
71340	7	70	976	9037	53776	\N	53.20008	"Пензенская область, Пензенский район, Ермоловский сельсовет, центральная усадьба совхоза ""Серп и Молот"", ул.Школьная, д.1-а"		0101000020E610000048DFA46950384640B64AB0389C994A40
71341	7	70	976	9092	54051	\N	53.155858000000002	Пензенская область, Пензенский район, Ермоловский сельсовет, село Черенцовка, ул.Центральная, д.2-а		0101000020E6100000EC2E505260354640F568AA27F3934A40
71521	7	70	976	17695	54255	\N	52.957256000000001	Пензенская область, Шемышейский район, село Усть-Мурза, ул. Советская, д. 15Б		0101000020E6100000E0BDA3C684A046402CF3565D877A4A40
71376	7	70	976	10758	53364	\N	52.977556	Пензенская область, Пензенский район, Старокаменский сельсовет, село Старая Каменка, ул.Молодежная, д.5		0101000020E610000056D7A19A927A46401901158E207D4A40
70691	7	70	976	47018	53999	\N	53.094068	с. Софьевка, Софьевская, 2Б		0101000020E61000000F7EE200FA3F4640D1CC936B0A8C4A40
71367	7	70	976	10337	54238	\N	52.960330999999996	Пензенская область, Пензенский район, Оленевский сельсовет,село Соловцовка, ул.Дачная, д.17-2		0101000020E610000089EAAD81AD724640E02A4F20EC7A4A40
71371	7	70	976	10509	54061	\N	53.105225384851799	Пензенская область, Пензенский район, Покрово-Березовский сельсовет, село Саловка, ул.Школьная, д.2	Россия, Пензенская область, Пензенский район, село Саловка	0101000020E6100000F086342A706646405DDC4603788D4A40
71373	7	70	976	10509	53483	\N	53.102746000000003	Пензенская область, Пензенский район, Саловский сельсовет, село Саловка, ул.Советская, д.4		0101000020E6100000680932022A664640BDE5EAC7268D4A40
71359	7	70	976	9896	54142	\N	53.024887	Пензенская область, Пензенский район, Кучкинский сельсовет, село Поперечное, ул.Школьная, д.12		0101000020E6100000CA501553E92D46403B8C497F2F834A40
70980	7	70	976	8977	53654	\N	53.139413224210102	д.Пановка, Чапаева, 12	Россия, Пензенская область, Пензенский район, село Пановка	0101000020E6100000BC94BA641C51464091D10149D8914A40
71339	7	70	976	8977	54146	\N	53.139282999999999	Пензенская область, Пензенский район, Ермоловский сельсовет, деревня Пановка, ул.Санаторская, д.27		0101000020E61000009563B2B8FF504640C3F17C06D4914A40
71366	7	70	976	10266	53677	\N	52.978071	Пензенская область, Пензенский район, Оленевский сельсовет, село Оленевка, ул.Школьная, д.2		0101000020E6100000B62FA017EE7046404015376E317D4A40
71368	7	70	976	10266	53984	\N	52.976339645529997	"Пензенская область, Пензенский район, Оленевский сельсовет, центральная усадьба совхоза ""Слава труду"", ул.Рабочая, д.9"		0101000020E6100000C860C5A9D670464069E388B5F87C4A40
70880	7	70	976	56488	54072	\N	52.941507207078303	с. Никифоровка, Московская, 21а	Россия, Пензенская область, Пензенский район, село Никифоровка	0101000020E61000000FEF39B01C8F464040FA264D83784A40
71331	7	70	976	8624	53680	\N	52.992150000000002	Пензенская область, Пензенский район, Большееланский сельсовет, село Надеждино, ул.Школьная, д.1-а		0101000020E61000000E846401135C4640FB5C6DC5FE7E4A40
71361	7	70	976	10031	53360	\N	53.033378999999996	Пензенская область, Пензенский район, Ленинский сельсовет, село Ленино, ул.Набережная, д.4		0101000020E610000027A435069D724640C4AF58C345844A40
71324	7	70	976	8272	53833	\N	52.995260999999999	Пензенская область, Пензенский район, Алферьевский сельсовет, деревня Лемзяйка, ул.Новая, д.3-1		0101000020E610000053094FE8F58B4640FCFD62B6647F4A40
71358	7	70	976	9876	54056	\N	53.009421000000003	Пензенская область, Пензенский район, Кучкинский сельсовет, село Кучки, пер.Школьный, д.11		0101000020E6100000420A9E42AE3E4640A47213B534814A40
71375	7	70	976	10735	53311	\N	53.137371000000002	Пензенская область, Пензенский район, Саловский сельсовет, село Константиновка, ул.Советская, д.12		0101000020E61000005ED5592DB05F46409C35785F95914A40
70936	7	70	976	56439	53652	\N	53.075713365885001	п. Калинина, Родниковая, 18	Россия, Пензенская область, Пензенский район, село Калинино	0101000020E61000004AB3791C06754640E770ADF6B0894A40
71336	7	70	976	8836	53907	\N	53.038989000000001	Пензенская область, Пензенский район, Воскресеновский сельсовет, деревня Ивановка, ул.Заречная, д.19-а		0101000020E61000004CFC51D499334640AEF36F97FD844A40
71338	7	70	976	8947	53706	\N	53.151862000000001	Пензенская область, Пензенский район, Ермоловский сельсовет, село Загоскино, ул.Экспериментальная, д.21		0101000020E61000007D03931B454A4640A9C0C93670934A40
71337	7	70	976	8892	53482	\N	53.165143999999998	Пензенская область, Пензенский район, Ермоловский сельсовет, село Ермоловка, ул.Октябрьская, д.13		0101000020E610000052280B5F5F414640B890477023954A40
71426	7	70	976	56465	53917	\N	53.262182828374897	с. Вязовка, Лесная, 6	Россия, Пензенская область, Пензенский район, село Вязовка	0101000020E61000008C852172FA524640994869368FA14A40
71335	7	70	976	8802	53357	\N	53.053930000000001	Пензенская область, Пензенский район, Воскресеновский сельсовет, село Воскресеновка, ул.Советская, д.7		0101000020E610000077BF0AF0DD7A4640FB22A12DE7864A40
71345	7	70	976	9252	54050	\N	53.119135	Пензенская область, Пензенский район, Засечный сельсовет, поселок Возрождение, ул.Возрожденская, д.102		0101000020E6100000593332C85D9246408C67D0D03F8F4A40
71329	7	70	976	8553	53636	\N	53.229332999999997	Пензенская область, Пензенский район, Богословский сельсовет, село Васильевка, ул.Набережная, д.2		0101000020E6100000DA56B3CEF85846406072A3C85A9D4A40
71330	7	70	976	8565	53307	\N	53.056446999999999	Пензенская область, Пензенский район, Большееланский сельсовет, село Большая Елань, ул.Садовая, д.2		0101000020E61000009FE74F1BD5574640897AC1A739874A40
71276	7	70	739	56447	53789	\N	53.888265609370499	р.п.Сура, Пролетарская, 23а	Россия, Пензенская область, Никольский район, поселок Сура	0101000020E61000000B24287E8CE146400A1346B3B2F14A40
71327	7	70	976	56527	54308	\N	53.069976614279398	Пензенская область, Пензенский район, Богословский сельсовет, село Малая Валяевка, ул.Центральная, д.28-в	Россия, Пензенская область, Пензенский район, село Большая Валяевка	0101000020E610000038F7578FFB824640713C9F01F5884A40
71326	7	70	976	8337	53299	\N	53.210871584942097	Пензенская область, Пензенский район, Богословский сельсовет, с.Богословка, ул.Советская, д.5	Россия, Пензенская область, Пензенский район, село Богословка	0101000020E61000005169C4CC3E67464031D28BDAFD9A4A40
71325	7	70	976	8337	53299	\N	53.210614	Пензенская область, Пензенский район, Богословский сельсовет, с.Богословка, ул.Советская, д.7		0101000020E6100000B5183C4CFB664640350A4966F59A4A40
71323	7	70	976	56469	53947	\N	53.120550999999999	"Пензенская область, Пензенский район, Алферьевский сельсовет,поселок ""Березовая роща"", ул.Центральная, д.3"		0101000020E6100000AFEDED96E4824640034015376E8F4A40
71374	7	70	976	10669	54054	\N	53.071035999999999	Пензенская область, Пензенский район, Саловский сельсовет, поселок Ардымский, ул.Центральная, д.3		0101000020E61000000BD5CDC5DF6E4640596B28B517894A40
71322	7	70	976	8162	53399	\N	53.027357000000002	Пензенская область, Пензенский район, Алферьевский сельсовет,с.Алферьевка, ул.Школьная, д.12		0101000020E61000003A747ADE8D9346408928266F80834A40
71073	7	70	1831	27918	53741	\N	53.159675	село Засурское, Школьная, 16		0101000020E610000040D9942BBC914640917EFB3A70944A40
71315	7	70	899	7830	\N	\N	53.368921	село Шейно, Гагарина, 12	Россия, Пензенская область, Пачелмский район, село Шейно	0101000020E6100000EF2076A6D099454060E7A6CD38AF4A40
71316	7	70	899	7858	53752	\N	53.406979999999997	село Черкасское, 1-ая Садовая, 2-а		0101000020E61000007C7C4276DE8C45402310AFEB17B44A40
70923	7	70	899	56501	54196	\N	53.446378553393998	с. Троицкое, Центральная, 8	Россия, Пензенская область, Пачелмский район, село Троицкое	0101000020E6100000F12A6B9BE2A94540834F73F222B94A40
70741	7	70	899	47986	54083	\N	53.162526	Топориха, Школьная, 3		0101000020E61000008509A359D99E4540F65FE7A6CD944A40
71308	7	70	899	7513	53481	\N	53.274721358488499	Пачелмский район, п. Титово, ул. Совхозная (здание Дома культуры), д. 9,	Россия, Пензенская область, Пачелмский район, село Титово	0101000020E610000050FD834886D645402043C70E2AA34A40
71307	7	70	899	7513	53481	\N	53.282390999999997	поселок Титово, Совхозная, 9		0101000020E61000006EC2BD326FD54540A5D7666325A44A40
71318	7	70	899	7957	54053	\N	53.447226000000001	село Татаро-Никольское, Школьная, 39		0101000020E6100000F46BEBA7FF824540E0F599B33EB94A40
71304	7	70	899	32709	54130	\N	53.439278000000002	село Старая Толковка, Советская, 14-а		0101000020E6100000629D2ADF33BA454018EDF1423AB84A40
71317	7	70	899	56512	54265	\N	53.4271654946428	село Русско-Никольское, Центральная, 41	Россия, Пензенская область, Пачелмский район, село РусскоНикольское	0101000020E6100000CD1E680586864540787FBC57ADB64A40
71309	7	70	899	32742	53675	\N	53.221905	село Решетино, Центральная, 2		0101000020E6100000C9570229B1CF4540D1E80E62679C4A40
70946	7	70	899	56492	54098	\N	53.219067426257403	с. Пустынь, Центральная, 90б	Россия, Пензенская область, Пачелмский район, село Пустынь	0101000020E610000058CA32C4B1C44540015130630A9C4A40
71301	7	70	899	6966	53297	\N	53.332951000000001	р.п. Пачелма, ул. Новая (здание Культурно-спортивного центра), д. 4А,		0101000020E6100000DA571EA4A7A84540D3156C239EAA4A40
71300	7	70	899	6966	53297	\N	53.332951000000001	рабочий поселок Пачелма, Новая, 4-а		0101000020E6100000DA571EA4A7A84540D3156C239EAA4A40
71299	7	70	899	6966	53400	\N	53.332951000000001	р.п. Пачелма, ул. Кирова (здание МОУ СОШ № 1 р.п.  Пачелма), д. 40,		0101000020E6100000DA571EA4A7A84540D3156C239EAA4A40
71298	7	70	899	6966	53400	\N	53.332951000000001	рабочий поселок Пачелма, Кирова, 40		0101000020E6100000DA571EA4A7A84540D3156C239EAA4A40
71297	7	70	899	6966	53396	\N	53.332951000000001	р.п.  Пачелма, ул. Драгунова (здание МБУ «Многофункциональный центр»), д. 14,		0101000020E6100000DA571EA4A7A84540D3156C239EAA4A40
71296	7	70	899	6966	53396	\N	53.332951000000001	рабочий поселок Пачелма, Драгунова, 14-а		0101000020E6100000DA571EA4A7A84540D3156C239EAA4A40
71313	7	70	899	7752	54156	\N	53.243589	село Пачелма, Совхозная, 1	Россия, Пензенская область, Пачелмский район, село Пачелма	0101000020E61000006762BA10ABAD45402A55A2EC2D9F4A40
71314	7	70	899	7773	54232	\N	53.202254000000003	село Новый Валовай, Школьная, 22		0101000020E61000006EF9484A7A9E45401BBE8575E3994A40
71303	7	70	899	7312	54129	\N	53.387324	село Новая Толковка, Театральная, 1		0101000020E6100000D34B8C65FAB545405B7A34D593B14A40
71306	7	70	899	7426	53903	\N	53.347414000000001	село Мокрый Мичкасс, Новая, 24		0101000020E6100000679C86A8C2CD45401616DC0F78AC4A40
70935	7	70	899	47307	53467	\N	53.192748999999999	с. Кобылкино, Школьная, 9а		0101000020E61000003EE76ED74BE1454019ABCDFFAB984A40
71302	7	70	899	56507	54233	\N	53.361867004090499	село Калиновка, Центральная, 54	Россия, Пензенская область, Пачелмский район, село Калиновка	0101000020E61000008E5C37A5BCAE4540354069A851AE4A40
71311	7	70	899	7674	53829	\N	53.251665000000003	село Ворона, Орловская, 3-а		0101000020E610000044149337C0B645402046088F36A04A40
71310	7	70	899	7594	\N	\N	53.235602	село Белынь, Советская, 12	Россия, Пензенская область, Пачелмский район, село Белынь	0101000020E61000009F8EC70C54BE4540A46FD234289E4A40
71279	7	70	739	61547	79369	\N	53.785064187618403	с.Столыпино, Школьный переулок, 4	Россия, Пензенская область, Никольский район, село Междуречье	0101000020E6100000D595CFF23CFE46402BA226FA7CE44A40
71272	7	70	739	56511	54267	\N	53.691125102129199	с.Зеленодольское, ул.Центральная,33, здание Зеленодольского филиала МБУК «Прудненский ПБДЦ»,		0101000020E6100000E370E657731247405839B4C876D84A40
71277	7	70	739	5996	54131	\N	53.884439	с.Усть-Инза, Новая, 27		0101000020E61000005303CDE7DCE746404A27124C35F14A40
71290	7	70	739	6687	53901	\N	53.545304999999999	с.Тюнярь, Поселки, 19		0101000020E610000055850662D9EA464032ACE28DCCC54A40
71275	7	70	739	56447	53705	\N	53.885206337718301	р.п.Сура, Сенная, 3	Россия, Пензенская область, Никольский район, поселок Сура	0101000020E61000005514AFB2B6E146408A1C226E4EF14A40
71251	7	70	463	4425	53352	\N	53.531697000000001	город Нижний Ломов, Московская, 54		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71294	7	70	739	56483	54046	\N	53.878295483613897	с.Субботино, Набережная, 10	Россия, Пензенская область, Никольский район, село Субботино	0101000020E6100000AF27BA2EFC084740C39E76F86BF04A40
71280	7	70	739	6174	54045	\N	53.68947	с.Старая Селя, Центральная, 45		0101000020E6100000FB07910C392447405CC98E8D40D84A40
71283	7	70	739	6319	54133	\N	53.566203999999999	с.Серман, Ленинская, 42		0101000020E6100000F0DC7BB8E42E4740A46E675F79C84A40
71090	7	70	739	45721	53623	\N	53.810274	"с.Родники, ул.Центральная, 16, здание  МОУ СОШ с.Родники, "		0101000020E6100000473A03232FFF46404966F50EB7E74A40
71293	7	70	739	56451	53786	\N	53.878835228027398	п.Ночка, Центральная, 52	Россия, Пензенская область, Никольский район, поселок Ночка	0101000020E6100000753FA7203F0D474043CA4FAA7DF04A40
71266	7	70	739	5175	53356	\N	53.709141000000002	г.Никольск, Школьная, 1		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71269	7	70	739	5175	53397	\N	53.709751732798999	г.Никольск, ул.Советская,148, здание ФОК «Олимп»,	Россия, Пензенская область, Никольский район, Никольск	0101000020E61000000AF2B391EB084740A3224E27D9DA4A40
71268	7	70	739	5175	53397	\N	53.709141000000002	г.Никольск, Советская, 148		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71271	7	70	739	5175	53480	\N	53.709141000000002	г.Никольск, Садовая, 21		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71274	7	70	739	5175	53300	\N	53.709141000000002	г.Никольск, Октябрьская, 288		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71262	7	70	739	5175	53294	\N	53.709141000000002	Пензенская область, Никольский район, город Никольск, Ленина, 134		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71265	7	70	739	5175	53296	\N	53.709141000000002	г.Никольск, Комсомольская, 1		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71263	7	70	739	5175	53390	\N	53.709141000000002	г.Никольск, Калинина, 6		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71264	7	70	739	5175	53392	\N	53.709141000000002	г.Никольск, Заводская, 2		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71267	7	70	739	5175	53355	\N	53.709141000000002	г.Никольск, Белинского, 24		0101000020E61000006EA12B11A80847405AA0DD21C5DA4A40
71288	7	70	739	6580	53771	\N	53.584007999999997	с.Нижний Шкафт, Центральная, 67		0101000020E6100000AB08371955D646401A4D2EC6C0CA4A40
70941	7	70	739	56458	53891	\N	53.788427730107202	с. Междуречье, Молодежная, 16		0101000020E61000004C1762F547FC464017A06D35EBE44A40
71291	7	70	739	6714	53704	\N	53.874279999999999	с.Маис, Школьная, 25		0101000020E61000006E6DE179A904474000C63368E8EF4A40
71295	7	70	739	6921	54128	\N	53.886572999999999	с.Кравково, Центральная, 54	Россия, Пензенская область, Никольский район, село Кравково	0101000020E6100000168A743FA712474020425C397BF14A40
70927	7	70	739	56493	54108	\N	53.869172655069796	с. Кочетовка, Центральная, 5	Россия, Пензенская область, Никольский район, село Кочетовка	0101000020E61000001E3691990BFA46407AC8940F41EF4A40
71281	7	70	739	32551	54047	\N	53.627668999999997	с.Карамалы, Октябрьская, 7		0101000020E6100000BA85AE44A010474044DB317557D04A40
71289	7	70	739	6637	54229	\N	53.609498000000002	с.Казарка, Советская, 29		0101000020E6100000B6F3FDD478E746401C7DCC0704CE4A40
71278	7	70	739	6070	53639	\N	53.786273000000001	с.Ильмино, Центральная, 5		0101000020E6100000B648DA8D3ED44640295DFA97A4E44A40
70633	7	70	739	56416	53456	\N	53.891968897840599	Пензенская область, город Заречный, Братская, 14	Россия, Пензенская область, Никольский район, село Заречный	0101000020E61000004E61A5828A0C4740DE054A0A2CF24A40
71270	7	70	739	5637	53902	\N	53.581544000000001	с.Большое Пермиево, Центральная, 22		0101000020E61000005E30B8E68E004740AF97A60870CA4A40
71284	7	70	739	6385	54055	\N	53.597802999999999	с.Базарная Кеньша, ул. Школьная,11, здание МБОУ СОШ с.Базарная Кеньша,		0101000020E61000001ADF1797AA204740B03907CF84CC4A40
71287	7	70	739	6538	54126	\N	53.631241000000003	с.Аришка, Нагорная, 2а		0101000020E610000089EFC4AC17C746407A724D81CCD04A40
71239	7	70	463	56453	53798	\N	53.535699999999999	село Усть-Каремша, Жулябина, 13е		0101000020E610000096236420CFDE4540CD3B4ED191C44A40
71235	7	70	463	3766	54228	\N	53.480483999999997	деревня Старая Мурава, Старая Мурава, 19		0101000020E61000003C33C170AECB45402920ED7F80BD4A40
71238	7	70	463	56482	54041	\N	53.620551700577202	село Сорокино, Лесная, 9а	Россия, Пензенская область, Нижнеломовский район, село Сорокино	0101000020E610000050E09D7C7AB04540D4BB783F6ECF4A40
71237	7	70	463	3856	54227	\N	53.592993	село Серый Ключ, Центральная, 77		0101000020E6100000AF09698D41C54540E3E0D231E7CB4A40
71240	7	70	463	4002	54044	\N	53.615203000000001	село Прянзерки, Центральная, 20		0101000020E610000079CA6ABA9EE6454057B3CEF8BECE4A40
71228	7	70	463	3417	53635	\N	53.539835861748102	село Пешая Слобода, Новенькая, 13	Россия, Пензенская область, Нижнеломовский район, село Пешая Слобода	0101000020E6100000DEC83CF207DD45400B9A965819C54A40
71220	7	70	463	2959	54225	\N	53.517988000000003	село Овчарное, Кремщина, 3		0101000020E61000004AB6BA9C12E0454038DC476E4DC24A40
71227	7	70	463	56435	\N	\N	53.529904380024199	"село Норовка, здание магазина ООО ""Верхнеломовское"""	Россия, Пензенская область, Нижнеломовский район, село Норовка	0101000020E610000017670C7382D245408202EFE4D3C34A40
71226	7	70	463	56435	53631	\N	53.530228295661502	село Норовка, Молодежная, 1	Россия, Пензенская область, Нижнеломовский район, село Норовка	0101000020E61000001C075E2D77D2454035B6D782DEC34A40
71232	7	70	463	3630	54224	\N	53.509549999999997	село Новый Шуструй, Центральная, 43		0101000020E61000005E6397A8DEAE4540A1D634EF38C14A40
71218	7	70	463	2809	54121	\N	53.572771000000003	село Новая Пятина, Парковая, 3		0101000020E61000005B24ED461FF34540728C648F50C94A40
71257	7	70	463	4425	53770	\N	53.531697000000001	г. Нижний Ломов, ул. Южная, 18, ЗАО «Хлебресурс»,		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71250	7	70	463	4425	53267	\N	53.531697000000001	г.Нижний Ломов, ул.Урицкого, 85, МОУ СОШ № 2 г.Нижний Ломов,		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71260	7	70	463	4425	53389	\N	53.531697000000001	город Нижний Ломов, Толстого, 1		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71255	7	70	463	4425	53327	\N	53.531697000000001	город Нижний Ломов, Розы Люксембург, 49		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71249	7	70	463	4425	53349	\N	53.531697000000001	город Нижний Ломов, Рабочая, 3		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71254	7	70	463	4425	53354	\N	53.531697000000001	город Нижний Ломов, Октябрьская, 63		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71252	7	70	463	4425	53352	\N	53.531697000000001	город Нижний Ломов, Московская, 83		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71261	7	70	463	4425	53395	\N	53.532256931771897	город Нижний Ломов, Маяковского, 15	Россия, Пензенская область, Нижнеломовский район, Нижний Ломов	0101000020E6100000D42B6519E2D64540960854FF20C44A40
71258	7	70	463	4425	53393	\N	53.531697000000001	город Нижний Ломов, Крылова, 6		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71256	7	70	463	4425	53435	\N	53.535273886699599	г.Нижний Ломов, ул.Карла Либкнехта, 183, библиотека микрорайона «Черемушки»,          филиал № 1 МУК «ЦМБ Нижнеломовского района Пензенской области»,		0101000020E6100000D40FEA2285D845401633C2DB83C44A40
71248	7	70	463	4425	53291	\N	53.531697000000001	город Нижний Ломов, Заводская, 13		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71253	7	70	463	4425	53769	\N	53.531697000000001	г.Нижний Ломов, ул.Вокзальная, д.13, помещение магазина ИП «Диков»,		0101000020E6100000F1D6F9B7CBD64540CF30B5A50EC44A40
71225	7	70	463	3221	53895	\N	53.374707000000001	село Мичкасские Выселки, Зеленая, 2б		0101000020E6100000A8ACA6EB89E44540884A2366F6AF4A40
71163	7	70	463	32130	54212	\N	53.685555999999998	Пензенская область, Наровчатский район, Большеколоярский сельсовет,  село Ляча, Молодежная, 1		0101000020E61000009BAA7B6473D94540CDC98B4CC0D74A40
71222	7	70	463	3066	54123	\N	53.393408000000001	с.Лещиново, Школьная, 1		0101000020E61000001C615111A7F745400DFE7E315BB24A40
71236	7	70	463	3805	53388	\N	53.623593999999997	с.Кувак-Никольское, ул.Центральная, д.7, администрация Кувак-Никольского сельсовета,		0101000020E61000000DC68844A1BF4540ACFD9DEDD1CF4A40
71224	7	70	463	3118	53293	\N	53.517549000000002	село Кривошеевка, Школьная, 113а		0101000020E6100000BA9F53909FD94540EC89AE0B3FC24A40
71223	7	70	463	3118	54040	\N	53.517549000000002	село Кривошеевка, Красноармейская, 16а		0101000020E6100000BA9F53909FD94540EC89AE0B3FC24A40
71247	7	70	463	4414	54034	\N	53.608215999999999	село Кривозерье, площадь Центральная, 1		0101000020E6100000A6F0A0D975ED4540B4739A05DACD4A40
71231	7	70	463	3556	53837	\N	53.504638999999997	село Козлятское, Ленина, 1а		0101000020E6100000B0743E3C4BCE4540A0A4C00298C04A40
71242	7	70	463	32992	54124	\N	53.620373999999998	село Кера, Ленина, 63а		0101000020E6100000E12879758E054640F4A44C6A68CF4A40
71241	7	70	463	4069	53897	\N	53.688377000000003	село Ива, Новая Деревня, 4		0101000020E6100000632AFD84B3FB4540C828CFBC1CD84A40
70632	7	70	463	56417	53253	\N	53.449446284835801	Пензенская область, город Заречный, Конституции СССР, 1		0101000020E6100000D05E7D3CF4C34540B5A84F7287B94A40
70631	7	70	\N	\N	53253	\N	53.252237000000001	Пензенская область, город Заречный, Конституции СССР, 37/2	Россия	0101000020E6100000D7DD3CD5219B4640ABEB504D49A04A40
71245	7	70	463	33004	53900	\N	53.626573999999998	село Голицыно, Московская, 43		0101000020E61000000F9A5DF7561046400F43AB9333D04A40
71244	7	70	463	33004	53900	\N	53.626573999999998	село Голицыно, Московская, 2а		0101000020E61000000F9A5DF7561046400F43AB9333D04A40
71259	7	70	463	5024	54167	\N	53.500177999999998	деревня Волженка, Буденного, 39а		0101000020E61000009BADBCE47FD44540DF162CD505C04A40
71217	7	70	463	2765	53699	\N	53.458416999999997	село Вирга, Школьная, 6		0101000020E6100000F3CCCB61F703464018778368ADBA4A40
71229	7	70	463	3465	53638	\N	53.472242000000001	село Верхний Ломов, Советская площадь, 13		0101000020E6100000B14F00C5C8C6454019E6046D72BC4A40
71230	7	70	463	3465	53767	\N	53.472242000000001	село Верхний Ломов, Советская площадь, 31		0101000020E6100000B14F00C5C8C6454019E6046D72BC4A40
71234	7	70	463	3465	53325	\N	53.472242000000001	село Верхний Ломов, Московская, 31		0101000020E6100000B14F00C5C8C6454019E6046D72BC4A40
71233	7	70	463	3465	53702	\N	53.472242000000001	село Верхний Ломов, Белинского, 55		0101000020E6100000B14F00C5C8C6454019E6046D72BC4A40
71221	7	70	463	2969	53763	\N	53.444668	село Большой Мичкас, Средняя, 32		0101000020E610000056BB26A435F64540F3C98AE1EAB84A40
71219	7	70	463	32841	53894	\N	53.548136	село Большие Хутора, Центральная, 113		0101000020E6100000CA52EBFD46E3454050E1085229C64A40
71216	7	70	463	2711	53893	\N	53.4890366975918	село Атмис, Новая, 53	Россия, Пензенская область, Нижнеломовский район, село Атмис	0101000020E61000000BD28C45D3F7454059C4B0C398BE4A40
71243	7	70	463	4155	54043	\N	53.603183000000001	село Аршиновка, Центральная, 1а		0101000020E6100000809A5AB6D6FD45406840BD1935CD4A40
71215	7	70	262	2622	53892	\N	52.699449999999999	Пензенская область, Неверкинский район, Неверкинский сельсовет, село Черталей, Школьная, 1		0101000020E61000009EB29AAE27604740F697DD9387594A40
71214	7	70	262	2615	54035	\N	52.768096999999997	Пензенская область, Неверкинский район, Сулеймановский сельсовет, село Сулеймановка, Школьная, 95		0101000020E6100000D95A5F24B4414740EE93A30051624A40
71213	7	70	262	2468	53628	\N	52.835607000000003	с.Старая Андреевка, ул.Победы, д.1-а, Здание Администрации сельсовета,		0101000020E6100000AF40F4A44C52474083A7902BF56A4A40
71212	7	70	262	2468	53628	\N	52.835607000000003	Пензенская область, Неверкинский район, Староандреевский сельсовет, село Старая Андреевка, Победы, 1 А		0101000020E6100000AF40F4A44C52474083A7902BF56A4A40
71211	7	70	262	2391	53898	\N	52.744891000000003	с.План, ул.Центральная, д.50, Администрация сельсовета,		0101000020E610000039F1D58EE2564740D90A9A96585F4A40
71210	7	70	262	2391	53898	\N	52.744891000000003	Пензенская область, Неверкинский район, Планский сельсовет, село План, Центральная, 50		0101000020E610000039F1D58EE2564740D90A9A96585F4A40
71209	7	70	262	2284	53476	\N	52.869719000000003	Пензенская область, Неверкинский район, Октябрьский сельсовет, село Октябрьское, переулок Советский, 8		0101000020E6100000B459F5B9DA3E4740DCDAC2F3526F4A40
71133	7	70	262	2284	53772	\N	52.869719000000003	"с.Октябрьское, пер.Советский, д.8, МУК ""Октябрьский поселенческий БДЦ"", "		0101000020E6100000B459F5B9DA3E4740DCDAC2F3526F4A40
71208	7	70	262	2266	54226	\N	52.877231000000002	Пензенская область, Неверкинский район, Бигеевский сельсовет, село Новое Чирково, Центральная, 1 А		0101000020E6100000861BF0F961704740C904FC1A49704A40
71205	7	70	262	1925	53753	\N	52.787984999999999	Пензенская область, Неверкинский район, Неверкинский сельсовет, село Неверкино, Полевая, 138		0101000020E61000003C670B08AD5D4740895E46B1DC644A40
71207	7	70	262	1925	54119	\N	52.787984999999999	Пензенская область, Неверкинский район, Неверкинский сельсовет, село Неверкино, Николаева, 2 А		0101000020E61000003C670B08AD5D4740895E46B1DC644A40
71206	7	70	262	1925	53627	\N	52.787984999999999	Пензенская область, Неверкинский район, Неверкинский сельсовет, село Неверкино, Молодежная, 9		0101000020E61000003C670B08AD5D4740895E46B1DC644A40
71203	7	70	262	1925	53350	\N	52.787984999999999	Пензенская область, Неверкинский район, Неверкинский сельсовет, село Неверкино, Ленина, 30		0101000020E61000003C670B08AD5D4740895E46B1DC644A40
71204	7	70	262	1925	53670	\N	52.787984999999999	Пензенская область, Неверкинский район, Неверкинский сельсовет, село Неверкино, Комсомольская, 31		0101000020E61000003C670B08AD5D4740895E46B1DC644A40
71202	7	70	262	1914	54223	\N	52.694330999999998	Пензенская область, Неверкинский район, Карноварский сельсовет, село Мансуровка, Школьная, 1 А		0101000020E61000006CED7DAA0A5B4740ABCC94D6DF584A40
71201	7	70	262	1833	54122	\N	52.817357000000001	Пензенская область, Неверкинский район, Староандреевский сельсовет, село Криволучье, Молодежная, 1 А		0101000020E6100000D13B1570CF5347400E1478279F684A40
71200	7	70	262	1783	53761	\N	52.672767	Пензенская область, Неверкинский район, Карноварский сельсовет, село Карновар, Мостовая, 30 А		0101000020E6100000B1F84D61A5604740FD69A33A1D564A40
71199	7	70	262	1723	54116	\N	52.749955	Пензенская область, Неверкинский район, Каменноовражский сельсовет, село Каменный Овраг, Новая, 1 А		0101000020E610000054E6E61BD1654740603C8386FE5F4A40
71198	7	70	262	1665	54221	\N	52.796245999999996	Пензенская область, Неверкинский район, Исикеевский сельсовет, село Исикеево, Дружбы, 14		0101000020E610000065355D4F744B474010C99063EB654A40
71197	7	70	262	1605	54036	\N	52.794933999999998	Пензенская область, Неверкинский район, Илим-Горский сельсовет,село Илим-Гора, Центральная, 94		0101000020E610000084F068E3887747403E3DB665C0654A40
71196	7	70	262	1554	53890	\N	52.696922999999998	Пензенская область, Неверкинский район, Планский сельсовет, село Елшанка, Центральная, 8 Б		0101000020E61000009CC24A05154F4740446ADAC534594A40
71195	7	70	262	1502	54029	\N	52.807298000000003	Пензенская область, Неверкинский район, Староандреевский сельсовет, село Джалилово, Школьная, 2		0101000020E61000000264E8D8415347402810768A55674A40
94436	7	70	262	1446	53998	\N	52.888088000000003	с.Демино, ул.Центральная, д.93, Администрация сельсовета,      тел.2-45-30		0101000020E610000019709692E53447402BFC19DEAC714A40
71194	7	70	262	1446	53667	\N	52.888088000000003	Пензенская область, Неверкинский район, Деминский сельсовет, село Демино, Центральная, 93		0101000020E610000019709692E53447402BFC19DEAC714A40
71193	7	70	262	1376	53672	\N	52.781269999999999	Пензенская область, Неверкинский район, Бикмурзинский сельсовет, село Бикмурзино, Речная, 20		0101000020E6100000E2783E03EA67474047ACC5A700644A40
71192	7	70	262	1317	54031	\N	52.809812999999998	Пензенская область, Неверкинский район, Бикмосеевский сельсвоет, село Бикмосеевка, Центральная, 57 В		0101000020E6100000C32CB4739A6947401570CFF3A7674A40
71191	7	70	262	1282	54220	\N	52.845495999999997	Пензенская область, Неверкинский район, Бигеевский сельсовет, село Бигеево, Центральная, 38		0101000020E6100000A565A4DE536D47400C738236396C4A40
71190	7	70	262	1222	53624	\N	52.882300999999998	Пензенская область, Неверкинский район, Березовский сельсовет, село Березовка, Дубровка, 29 В		0101000020E610000082FE428F18654740321D3A3DEF704A40
71189	7	70	262	1109	54028	\N	52.807875000000003	Пензенская область, Неверкинский район, Неверкинский сельсовет, село Алешкино, Набережная, 4 А		0101000020E61000006A15FDA199574740C520B07268674A40
71188	7	70	262	1106	53701	\N	52.785066	Пензенская область, Неверкинский район, Алеевский сельсовет, село Алеево, Центральная, 18 А		0101000020E610000011DF89592F704740CC99ED0A7D644A40
71180	7	70	74	620	54025	\N	53.906427000000001	Пензенская область, Наровчатский район, Наровчатский сельсовет, село Шиловка, Старая Шиловка, 33		0101000020E610000036035C902DD545400F9BC8CC05F44A40
71178	7	70	74	484	9832	\N	53.980132672723599	Пензенская область, Наровчатский район, Суркинский сельсовет, село Телешовка, Первомайская, 1а	Россия, Пензенская область, Наровчатский район, село Телешовка	0101000020E6100000853FC39B35C445407D5D86FF74FD4A40
71179	7	70	74	537	54024	\N	53.964908999999999	Пензенская область, Наровчатский район, Суркинский сельсовет, село Суркино, Пролетарская, 29		0101000020E6100000645930F147C74540DB4E5B2382FB4A40
71146	7	70	74	31354	54014	\N	53.811210000000003	Пензенская область, Наровчатский район, Плесковский сельсовет, село Студенец, Горького, 45а		0101000020E610000000FE2955A2BE45401618B2BAD5E74A40
70686	7	70	74	56491	54088	\N	53.744587231592902	с. Сосновка, Шведская, 1А	Россия, Пензенская область, Наровчатский район, село Сосновка	0101000020E61000006859F78F85E445406D0377A04EDF4A40
71160	7	70	74	56522	54285	\N	53.864936733871303	Пензенская область, Наровчатский район, Скановский сельсовет, Сканово, Школьная, 2	Россия, Пензенская область, Наровчатский район	0101000020E6100000378E588B4FE14540D80C7041B6EE4A40
71171	7	70	74	32482	54270	\N	53.831059631550403	Пензенская область, Наровчатский район, Плесковский сельсовет, село Садовое, Советская, 14	Россия, Пензенская область, Наровчатский район, село Садовое	0101000020E61000007FBF982D59C94540C381902C60EA4A40
71176	7	70	74	368	54213	\N	53.878298999999998	Пензенская область, Наровчатский район, Вьюнский сельсовет, село Савинки, Новинка, 21а		0101000020E6100000D369DD06B5B94540048E041A6CF04A40
71165	7	70	74	56513	54268	\N	53.750077199130601	с. Рождественское Тезиково, ул. Подлужная, д. 18, здание филиала МБОУ средней общеобразовательно школы с. Виляйки в с. Р.Тезиково,                                                                 3-32-41	Россия, Пензенская область, Наровчатский район, село Рождественно-Тезиково	0101000020E61000009DB98784EFD74540AB3DEC8502E04A40
71168	7	70	74	32326	54111	\N	53.807408000000002	Пензенская область, Наровчатский район, Потодеевский сельсовет, село Потодеево, Ленина, 53		0101000020E6100000EECC04C3B9D64540AF43352559E74A40
71173	7	70	74	90	53885	\N	53.836637000000003	с. Плесковка, ул. Комсомольская, д. 25, здание МБОУ средней общеобразовательной школы с. Плесковка                                            3-71-73		0101000020E6100000E275FD82DDBE4540D1CFD4EB16EB4A40
71172	7	70	74	90	53885	\N	53.836637000000003	Пензенская область, Наровчатский район, Плесковский сельсовет, село Плесковка, Комсомольская, 25		0101000020E6100000E275FD82DDBE4540D1CFD4EB16EB4A40
71177	7	70	74	423	54018	\N	53.927098000000001	Пензенская область, Наровчатский район, Суркинский сельсовет, село Паны, Зеленая, 5а		0101000020E6100000EF53556820C04540F017B325ABF64A40
71182	7	70	74	743	54219	\N	53.944845000000001	Пензенская область, Наровчатский район, Орловский сельсовет, село Орловка, Молодежная, 178		0101000020E6100000C2853C821BD74540026553AEF0F84A40
71161	7	70	74	32062	53665	\N	53.804685999999997	Пензенская область, Наровчатский район, Новопичурский сельсовет, Новые Пичуры, Молодежная, 2		0101000020E6100000BE2F2E5569E5454047C66AF3FFE64A40
71185	7	70	74	850	53386	\N	53.880251999999999	Пензенская область, Наровчатский район, Наровчатский сельсовет, село Наровчат, Советская, 48		0101000020E61000004209336DFFD845408A1EF818ACF04A40
71184	7	70	74	850	53351	\N	53.880251999999999	Пензенская область, Наровчатский район, Наровчатский сельсовет, село Наровчат, Ленина, 2		0101000020E61000004209336DFFD845408A1EF818ACF04A40
71187	7	70	74	1031	54026	\N	53.888303000000001	Пензенская область, Наровчатский район, Наровчатский сельсовет, село Мелюковка, Малинская, 1		0101000020E610000085B1852007D3454027F8A6E9B3F14A40
71170	7	70	74	32417	54006	\N	53.796438000000002	Пензенская область, Наровчатский район, Потодеевский сельсовет, село Масловка, Садовая, 53		0101000020E6100000B0ABC95356CD454055A52DAEF1E54A40
71181	7	70	74	633	54217	\N	53.957514000000003	Пензенская область, Наровчатский район, Орловский сельсовет, село Кадыковка, Сорокина, 86а		0101000020E6100000067FBF982DCF454028BB99D18FFA4A40
71174	7	70	74	239	53887	\N	53.853253000000002	Пензенская область, Наровчатский район, Вьюнский сельсовет, село Вьюнки, Молодежная, 3а		0101000020E6100000217365506DC44540611BF16437ED4A40
71166	7	70	74	32270	54218	\N	53.777734000000002	"с. Виляйки ул. Молодежная, д. 31, здание МБУК ""Библиотечно-досуговый центр"" Виляйского сельсовета                                                      3-21-51"		0101000020E6100000B745990D32D945405F7EA7C98CE34A40
71167	7	70	74	32270	53755	\N	53.777734000000002	Пензенская область, Наровчатский район, Виляйский сельсовет, село Виляйки, Молодежная, 31		0101000020E6100000B745990D32D945405F7EA7C98CE34A40
71175	7	70	74	252	54166	\N	53.850433000000002	Пензенская область, Наровчатский район, Вьюнский сельсовет, село Большой Чердак, Заречная, 1а		0101000020E61000002F6AF7AB00CD4540373811FDDAEC4A40
71164	7	70	74	32182	53632	\N	53.713500000000003	Пензенская область, Наровчатский район, Большеколоярский сельсовет, село Большой Колояр, Советская, 40		0101000020E610000023D74D29AFD9454017D9CEF753DB4A40
71162	7	70	74	32106	53884	\N	53.708601999999999	Пензенская область, Наровчатский район, Большекирдяшевский сельсовет, село Большое Кирдяшево, Центральная, 1		0101000020E61000008942CBBA7FE24540AAF06778B3DA4A40
71169	7	70	74	56450	53784	\N	53.838672671731999	Пензенская область, Наровчатский район, Большекавендровский сельсовет, село Большая Кавендра, Молодежная, 39	Россия, Пензенская область, Наровчатский район, село Большая Кавенда	0101000020E61000008351499D80D84540E48409A359EB4A40
71183	7	70	74	32587	54059	\N	53.930942000000002	Пензенская область, Наровчатский район, Азарапинский сельсовет, Лысовка, 59		0101000020E6100000890B40A374E34540863C821B29F74A40
71126	7	70	635	30328	54319	\N	53.620100999999998	Пензенская область, Мокшанский район, с.Юлово, ул.Центральная, 30 "А", помещение в здании администрации сельсовета		0101000020E6100000AB3FC230604D4640C39B35785FCF4A40
71143	7	70	635	31207	54312	\N	53.456834999999998	Пензенская область, Мокшанский район, с.Широкоис, ул.Мирная, 3, помещение в здании СДК		0101000020E6100000554B3ACAC11646408655BC9179BA4A40
71139	7	70	635	30990	54291	\N	53.584634000000001	Пензенская область, Мокшанский район, с.Чернозерье, ул.Базарная площадь, 4 "А", помещение в здании школы		0101000020E6100000F4A5B73F172B464099107349D5CA4A40
71124	7	70	635	30251	54307	\N	53.607629000000003	Пензенская область, Мокшанский район, с.Царевщино, ул.Центральная, 72, помещение в здании СДК		0101000020E6100000DB5207793D604640F48C7DC9C6CD4A40
70698	7	70	635	56480	54010	\N	53.661632051182302	Пензенская область, Бековский район, с. Хованщино, Клещевка, 1	Россия, Пензенская область, Мокшанский район, село Хованщина	0101000020E6100000BFF1B567962E464058FE7C5BB0D44A40
71129	7	70	635	30493	54295	\N	53.318660999999999	Пензенская область, Мокшанский район, с.Успенское, ул.Ермакова, 16, помещение в здании СДК		0101000020E61000009D668176873246405DC136E2C9A84A40
71150	7	70	635	31544	54303	\N	53.524016000000003	Пензенская область, Мокшанский район, с.Сумароково, ул.Маливиновка, 21, помещение в здании СДК		0101000020E6100000EBA9D55757634640564ACFF412C34A40
71148	7	70	635	31438	54300	\N	53.538702999999998	Пензенская область, Мокшанский район, с.Скачки, ул.Демин Конец, 3, помещение в здании СДК		0101000020E61000000E10CCD1E3314640E8A04B38F4C44A40
71128	7	70	635	30427	54315	\N	53.460571999999999	Пензенская область, Мокшанский район, с.Симбухово, ул.Школьная, 1 "Б", помещение в здании детского сада		0101000020E6100000B3791C06F343464006BAF605F4BA4A40
71138	7	70	635	30944	54289	\N	53.298727	Пензенская область, Мокшанский район, с.Рамзай, ул.Желиховского, 5, помещение в здании СДК		0101000020E6100000CDCB61F71D5D464052B7B3AF3CA64A40
71134	7	70	635	30737	54318	\N	53.277312999999999	Пензенская область, Мокшанский район, д.Пяша, ул.Строительная, 16, помещение в здании сельского клуба		0101000020E61000009B8F6B43C55E4640B9E00CFE7EA34A40
71142	7	70	635	31163	54293	\N	53.516725000000001	Пензенская область, Мокшанский район, с.Потьма, ул.Ленина, 13, помещение в здании школы		0101000020E61000000C76C3B6450B46404703780B24C24A40
71141	7	70	635	31091	54325	\N	53.455668830598498	Пензенская область, Мокшанский район, с.Подгорное, ул.Малая Хомяковка, 2, помещение в здании СДК		0101000020E610000078F01307D02B464088669E5C53BA4A40
71144	7	70	635	31261	54305	\N	53.476689999999998	Пензенская область, Мокшанский район, с.Плесс, ул.Садовая, 4, помещение в здании средней школы		0101000020E6100000D311C0CDE2394640452A8C2D04BD4A40
71153	7	70	635	31689	54324	\N	53.389944999999997	Пензенская область, Мокшанский район, п.Парижская Коммуна, ул.Рабочая, 11, помещение в здании СДК		0101000020E61000005C7171546E4A46408E1EBFB7E9B14A40
71136	7	70	635	30856	54301	\N	53.257764000000002	Пензенская область, Мокшанский район. п.Отрадный, ул.Школьная, 1, помещение в здании медпункта		0101000020E610000095F3C5DE8B254640070B2769FEA04A40
71130	7	70	635	30564	54316	\N	53.274137000000003	Пензенская область, Мокшанский район, с.Нечаевка, ул.Совхозная, 23, помещение в здании СДК		0101000020E610000098BD6C3B6D3B4640D1CFD4EB16A34A40
71131	7	70	635	30564	53385	\N	53.274137000000003	Мокшанский район, с.Нечаевка, ул.Рабочая, 2, помещение в здании администрации сельсовета,		0101000020E610000098BD6C3B6D3B4640D1CFD4EB16A34A40
71125	7	70	635	30303	54287	\N	53.632773	Пензенская область, Мокшанский район. С.Муратовка, ул.Школьная, 2, помещение в здании медпункта		0101000020E61000003EE94482A95A46405A65A6B4FED04A40
71154	7	70	635	31739	54323	\N	53.439684999999997	Пензенская область, Мокшанский район. Р.п.Мокшан, ул.Студенческая, 3, помещение в здании политехнического колледжа		0101000020E610000050C3B7B06E4E464058C51B9947B84A40
71156	7	70	635	31739	54309	\N	53.439684999999997	Пензенская область, Мокшанский район, р.п.Мокшан, ул.Советская, 34, помещение в здании агротехнологического колледжа		0101000020E610000050C3B7B06E4E464058C51B9947B84A40
71158	7	70	635	31739	65265	\N	53.439684999999997	Пензенская область, Мокшанский район, ул.Победы, 3 "А", помещение в здании ДЮСШ		0101000020E610000050C3B7B06E4E464058C51B9947B84A40
71157	7	70	635	31739	54297	\N	53.439684999999997	Пензенская область, Мокшанский район, р.п.Мокшан, ул.Куйбышева, 55, помещение в здании  МОУ СОШ №2		0101000020E610000050C3B7B06E4E464058C51B9947B84A40
71155	7	70	635	31739	54296	\N	53.439684999999997	Пензенская область, Мокшанский район, р.п.Мокшан, ул.Красное Польцо, 35а, помещение в здании школы		0101000020E610000050C3B7B06E4E464058C51B9947B84A40
71159	7	70	635	31739	54286	\N	53.439684999999997	Пензенская область, Мокшанский район, р.п.Мокшан, ул. 1-я Разведка, 2, помещение в здании МОУ СОШ №1		0101000020E610000050C3B7B06E4E464058C51B9947B84A40
71092	7	70	635	31260	54120	\N	53.473549259223297	село Михайловка, Центральная, 99	Россия, Пензенская область, Мокшанский район, село Михайловка	0101000020E61000005D3123BC3D3E4640D906EE409DBC4A40
71145	7	70	635	31260	54322	\N	53.473382999999998	Пензенская область, Мокшанский район, с.Михайловка, ул.Советская, 102, помещение в здании СДК		0101000020E610000016FA60191B3E4640BEBD6BD097BC4A40
71151	7	70	635	31590	54302	\N	53.364041999999998	Пензенская область, Мокшанский район, п.Мирный, ул.Совхозная, 53 "а", помещение в здании сельского клуба		0101000020E6100000CAFCA36FD25A46406A2FA2ED98AE4A40
71008	7	70	635	48787	53475	\N	53.655612147947501	село Лопатино, Фабричная, 2	Россия, Пензенская область, Мокшанский район, село Лопатино	0101000020E6100000BB287AE0636E4640BD6E1118EBD34A40
71048	7	70	635	56495	54118	\N	53.408426526489599	село Ивановка, Молодежная, 1А	Россия, Пензенская область, Мокшанский район, село Ивановка	0101000020E6100000C713419C871D4640D6E6FF5547B44A40
71147	7	70	635	31403	54310	\N	53.528823000000003	Пензенская область, Мокшанский район, с.Знаменское, ул.Центральная, 39, помещение в здании сельского клуба		0101000020E61000007AAA436E863D4640B22FD978B0C34A40
71343	7	70	635	31488	53302	\N	53.5512902514755	Пензенская область, Пензенский район, Засечный сельсовет, село Засечное, ул.Шоссейная, д.71-а	Россия, Пензенская область, Мокшанский район, село Засечное	0101000020E6100000A0A4C00298564640514EB4AB90C64A40
71342	7	70	635	31488	53363	\N	53.551000640229901	Пензенская область, Пензенский район, Засечный сельсовет,село Засечное, ул.Шоссейная, д.71-а	Россия, Пензенская область, Мокшанский район, село Засечное	0101000020E610000008E6E8F17B5546401A88653387C64A40
71149	7	70	635	31488	54313	\N	53.550483999999997	Пензенская область, Мокшанский район, с.Засечное, ул.пановка, 15, помещение в здании школы		0101000020E6100000C39B35785F554640527C7C4276C64A40
70628	7	70	635	58421	65029	\N	53.3070711387278	Пензенская область, город Заречный, Ленина, 52	Россия, Пензенская область, Мокшанский район, село Заречный	0101000020E6100000CDE9B298D832464067463F1A4EA74A40
71152	7	70	635	31657	\N	\N	53.413581999999998	Пензенская область, Мокшанский район. Д.Заречная, 13, помещение в здании администрации Юровского сельтсовета		0101000020E6100000E9995E622C4D46406D1B4641F0B44A40
71135	7	70	635	30809	54306	\N	53.345871000000002	Пензенская область, Мокшанский район, с.Елизаветино, ул.Центральная, 28, помещение в здании школы		0101000020E6100000F3C98AE1EA44464042D13C8045AC4A40
71140	7	70	635	31079	54321	\N	53.616549999999997	Пензенская область, Мокшанский район, с.Долгоруково, ул.Школьная, 10, помещение в здании школы		0101000020E6100000302AA913D01E4640A52C431CEBCE4A40
70876	7	70	635	31079	54163	\N	53.616991546429297	с. Долгоруково, Придорожная, 53	Россия, Пензенская область, Мокшанский район, село Долгоруково	0101000020E61000001E51A1BAB91E464063F20698F9CE4A40
71137	7	70	635	30895	54292	\N	53.357222999999998	Пензенская область, Мокшанский район, с.Дмитриевка, ул.Ждановская, 87, помещение в здании школы		0101000020E6100000CCD3B9A2941E46408330B77BB9AD4A40
71127	7	70	635	30384	54311	\N	53.443365	Пензенская область, Мокшанский район, с.Богородское, ул.Центральная, 31 "б", помещение в здании СДК		0101000020E610000073A25D859443464074982F2FC0B84A40
70973	7	70	635	48009	53472	\N	53.64629	с.Березовка, Центральная, 3		0101000020E6100000626A4B1DE46D4640ADDD76A1B9D24A40
71123	7	70	635	30174	54320	\N	53.644128000000002	Пензенская область, Мокшанский район, с.Алексеевка, ул.Алексеевка, д.172 помещение в здании школы		0101000020E6100000103D29931A2C46400D384BC972D24A40
71122	7	70	1603	30161	54109	\N	52.474041	Пензенская область, Малосердобинский район, Липовский сельсовет, с.Шингал, Луговая, 6		0101000020E6100000C4CDA9640068464048FB1F60AD3C4A40
71109	7	70	1603	29523	54190	\N	52.496980999999998	Пензенская область, Малосердобинский район, Майский сельсовет, с.Чунаки, Центральная, 140		0101000020E61000006AF6402B30A24640DFDDCA129D3F4A40
71103	7	70	1603	29246	54214	\N	52.362923000000002	Пензенская область, Малосердобинский район, Малосердобинский сельсовет, с.Топлое, Зажигина, 1		0101000020E61000002C9E7AA4C1834640ADFBC742742E4A40
71111	7	70	1603	29598	53698	\N	52.564962000000001	с. Старое Славкино, ул.Садовая, 12, здание администрации Старославкинского сельсовета,		0101000020E6100000EBC891CEC0904640CBBDC0AC50484A40
71110	7	70	1603	29598	53698	\N	52.564962000000001	Пензенская область, Малосердобинский район, Старославкинский сельсовет, с.Старое Славкино, Садовая, 12		0101000020E6100000EBC891CEC0904640CBBDC0AC50484A40
71105	7	70	1603	29325	54104	\N	52.457569999999997	с. Саполга, ул. Советская, д.2, здание МБОУ ООШ с.Саполга,		0101000020E61000004E5FCFD72C8B4640BBD05CA7913A4A40
71104	7	70	1603	29325	54104	\N	52.457569999999997	Пензенская область, Малосердобинский район, Малосердобинский сельсовет, с.Саполга, Советская, 2		0101000020E61000004E5FCFD72C8B4640BBD05CA7913A4A40
71112	7	70	1603	29666	54112	\N	52.528061999999998	Пензенская область, Малосердобинский район, Старославкинский сельсовет, с.Новое Славкино, Набережная, 37		0101000020E6100000EC18575C1C91464053211E8997434A40
71115	7	70	1603	29791	53881	\N	52.657812999999997	Пензенская область, Малосердобинский район, Дружаевский сельсовет, с.Новое Назимкино, Кооперативная, 2		0101000020E61000005F419AB1687C46401BF1643733544A40
71114	7	70	1603	29789	54013	\N	52.631908000000003	Пензенская область, Малосердобинский район, Дружаевский сельсовет, с.Новое Демкино, Звездная, 27		0101000020E61000001FDB32E02C854640570A815CE2504A40
71121	7	70	1603	30089	53882	\N	52.500594	Пензенская область, Малосердобинский район, Липовский сельсовет, с.Николаевка, Школьная, 3		0101000020E6100000AC014A438D6A46407349D57613404A40
71120	7	70	1603	30005	53889	\N	52.553073375417597	с. Марьевка, ул.Школьная, д.1,  здание МБОУ ООШ с.Марьевка,	Россия, Пензенская область, Малосердобинский район, село Марьевка	0101000020E6100000DDED7A698A6E46407AA69718CB464A40
71119	7	70	1603	30005	53889	\N	52.552982999999998	Пензенская область, Малосердобинский район, Липовский сельсовет, с.Марьевка, Школьная, 1		0101000020E6100000DDED7A698A6E46403A1F9E25C8464A40
71097	7	70	1603	19673	53750	\N	52.466245000000001	Пензенская область, Малосердобинский район, Малосердобинский сельсовет, с.Малая Сердоба, Строительная, 2		0101000020E6100000A2F0D93A387A4640367689EAAD3B4A40
71100	7	70	1603	19673	53663	\N	52.466245000000001	Пензенская область, Малосердобинский район, Малосердобинский сельсовет, с.Малая Сердоба, Советская, 23		0101000020E6100000A2F0D93A387A4640367689EAAD3B4A40
71099	7	70	1603	19673	53663	\N	52.466245000000001	Пензенская область, Малосердобинский район, Малосердобинский сельсовет, с.Малая Сердоба, Советская, 10		0101000020E6100000A2F0D93A387A4640367689EAAD3B4A40
71102	7	70	1603	19673	54101	\N	52.466245000000001	с. Малая Сердоба, ул. Пацаева, 29, здание МУП Малосердобинского сельсовета «ЖКХ»,		0101000020E6100000A2F0D93A387A4640367689EAAD3B4A40
71096	7	70	1603	19673	53743	\N	52.466245000000001	Пензенская область, Малосердобинский район, Малосердобинский сельсовет, с.Малая Сердоба, Октябрьская, 12		0101000020E6100000A2F0D93A387A4640367689EAAD3B4A40
71098	7	70	1603	19673	53749	\N	52.466245000000001	Пензенская область, Малосердобинский район, Малосердобинский сельсовет, с.Малая Сердоба, Ленинская, 91		0101000020E6100000A2F0D93A387A4640367689EAAD3B4A40
71101	7	70	1603	19673	54005	\N	52.466245000000001	с. Малая Сердоба ул. Калинина, 2а, здание ООО Агрофирма «Топлое»,		0101000020E6100000A2F0D93A387A4640367689EAAD3B4A40
71106	7	70	1603	29412	54106	\N	52.430162000000003	Пензенская область, Малосердобинский район, Майский сельсовет, с.Майское, 2-я Молодежная, 1а		0101000020E6100000BFD364C6DBA84640B1FD648C0F374A40
71107	7	70	1603	29412	54107	\N	52.430162000000003	с. Майское, ул. 2-ая Молодежная, д.1а, здание администрации Майского сельсовета,		0101000020E6100000BFD364C6DBA84640B1FD648C0F374A40
71117	7	70	1603	29922	54215	\N	52.582639999999998	Пензенская область, Малосердобинский район, Липовский сельсовет, с.Липовка, Школьная, 1а		0101000020E61000004ACE893DB47B4640B4AB90F2934A4A40
71118	7	70	1603	29954	54007	\N	52.596021999999998	Пензенская область, Малосердобинский район, Липовский сельсовет, с.Колемас, Дворянская, 15		0101000020E6100000D2510E661370464027D9EA724A4C4A40
71113	7	70	1603	29705	54009	\N	52.618268999999998	Пензенская область, Малосердобинский район, Ключевский сельсовет, Ключи, Главная, 8а		0101000020E6100000FF3D78EDD2984640B8904770234F4A40
71116	7	70	1603	29878	54193	\N	52.609158999999998	Пензенская область, Малосердобинский район, Дружаевский сельсовет, Дружаевка, Набережная, 35/1		0101000020E6100000569E40D82984464033880FECF84D4A40
71108	7	70	1603	29510	54076	\N	52.398494999999997	Пензенская область, Малосердобинский район, Майский сельсовет, с.Бадровка, Студеная, 24а		0101000020E610000040C39B3578A146404C4F58E201334A40
71083	7	70	1582	28370	54222	\N	53.645558999999999	село Старая Кутля, Максима Горького, 73		0101000020E6100000B69DB64604AB4640B95164ADA1D24A40
71068	7	70	1582	27695	54207	\N	53.558695	село Синорово, Титова, 40		0101000020E6100000C80C54C6BF9B464028B8585183C74A40
70996	7	70	1582	56444	53694	\N	53.642392116564103	п.Родниковский, Школьная, 1	Россия, Пензенская область, Лунинский район, село Родники	0101000020E6100000DD990986738D4640249BABE639D24A40
71070	7	70	1582	27777	53992	\N	53.813282999999998	село Напольный Вьяс, Бобровская, 2		0101000020E610000083BF5FCC96BA464046B247A819E84A40
70893	7	70	1582	19285	53936	\N	53.780357000000002	с. Маровка, Черокманова, 50		0101000020E61000002D5A80B6D5904640331AF9BCE2E34A40
71080	7	70	1582	28235	53662	\N	53.602991000000003	село Манторово, Свердлова, 97а		0101000020E6100000E9B81AD995A04640246420CF2ECD4A40
71088	7	70	1582	45614	53341	\N	53.584110000000003	рабочий поселок Лунино, Юбилейная, 2		0101000020E6100000EFE53E390A9C46401FA2D11DC4CA4A40
71086	7	70	1582	45614	53477	\N	53.5957532314101	рабочий поселок Лунино, Советская, 109	Россия, Пензенская область, Лунинский район, поселок Лунино	0101000020E6100000E71BD13DEB9C464038BF61A241CC4A40
71085	7	70	1582	45614	53477	\N	53.584110000000003	рабочий поселок Лунино, Советская, 39		0101000020E6100000EFE53E390A9C46401FA2D11DC4CA4A40
71087	7	70	1582	45614	53384	\N	53.584110000000003	рабочий поселок Лунино, Мясникова, 47		0101000020E6100000EFE53E390A9C46401FA2D11DC4CA4A40
71084	7	70	1582	45614	53333	\N	53.589975023177203	рабочий поселок Лунино, Мичурина, 43а	Россия, Пензенская область, Лунинский район, поселок Лунино	0101000020E610000077D9AF3BDD9B4640933A014D84CB4A40
71081	7	70	1582	45614	54272	\N	53.589277140372701	рабочий поселок Лунино, Максима Горького, 26	Россия, Пензенская область, Лунинский район, поселок Лунино	0101000020E610000051D9B0A6B29C46407BA4C16D6DCB4A40
71089	7	70	1582	45614	53361	\N	53.584110000000003	рабочий поселок Лунино, Ломоносова, 26		0101000020E6100000EFE53E390A9C46401FA2D11DC4CA4A40
71078	7	70	1582	56440	53660	\N	53.698357999999999	село Ломовка, Школьная, 45	Россия, Пензенская область, Лунинский район, село Ломовка	0101000020E6100000B8E4B8533AB04640327381CB63D94A40
71094	7	70	1582	32668	54117	\N	53.662613999999998	село Липяги, Звездная, 19		0101000020E6100000ACADD85F7687464095EF1989D0D44A40
71071	7	70	1582	27831	53659	\N	53.774472000000003	село Лесной Вьяс, Большая дорога, 69		0101000020E6100000309DD66D50BD464078D503E621E34A40
71082	7	70	1582	56481	54033	\N	53.623516786969503	поселок Краснооктябрьский, Колхозная, 4в		0101000020E61000000ABABDA431A0464001C0B167CFCF4A40
71079	7	70	1582	19083	54192	\N	53.747501	"с.Казачья Пелетьма, ул.Школьная, 12, здание  МОУ НОШ с.Казачья Пелетьма, "		0101000020E6100000DE9046054EB64640185DDE1CAEDF4A40
71077	7	70	1582	33050	54284	\N	53.535826259285599	"п.Иванырсинский лесозавод, ул.Заводская, д.7, кв.1, здание ФАПа, "	Россия, Пензенская область, Лунинский район, село Иванырсенский Лесозавод	0101000020E6100000B83EAC376AA946405A2C45F295C44A40
71076	7	70	1582	28050	53661	\N	53.561673999999996	село Иванырс, Юбилейная, 15		0101000020E610000033FB3C4679A64640BA8102EFE4C74A40
71075	7	70	1582	32556	53879	\N	53.520327999999999	село Екатериновка, Сельская площадь, 1		0101000020E610000034D593F9479B4640B7989F1B9AC24A40
71072	7	70	1582	27868	54209	\N	53.865743000000002	село Дарьевка, Центральная, 24		0101000020E610000062A3ACDF4CAA4640D7DEA7AAD0EE4A40
71069	7	70	1582	27763	53408	\N	53.810879999999997	село Большой Вьяс, Базарная, 14		0101000020E61000009E7AA4C16DBF4640807D74EACAE74A40
71066	7	70	1582	33130	53658	\N	53.592758000000003	село Болотниково, Муханова, 5		0101000020E61000006AFAEC80EB7A4640A038807EDFCB4A40
71065	7	70	1798	27539	53880	\N	52.647128000000002	село Чардым, Молодежная, 1А		0101000020E6100000315BB22AC2E14640B7291E17D5524A40
71064	7	70	1798	33120	53883	\N	52.502369999999999	село Точка, Центральная, 15		0101000020E61000004A0A2C8029F54640EA3E00A94D404A40
71061	7	70	1798	27364	53696	\N	52.645915000000002	село Суляевка, Верхняя, 95Б		0101000020E6100000868DB27E33F54640787FBC57AD524A40
71063	7	70	1798	27464	53620	\N	52.470205999999997	село Старый Карлыган, Центральная, 44		0101000020E610000019761893FEE846400531D0B52F3C4A40
71062	7	70	1798	27393	53736	\N	52.534219999999998	село Старый Вершаут, Центральная, 56		0101000020E6100000753E3C4B90E346403F6F2A5261444A40
71060	7	70	1798	56459	53836	\N	52.429567323500301	село Сорокино, Центральная, 16/1	Россия, Пензенская область, Лопатинский район, село Сорокино	0101000020E6100000ADDC0BCC0ABF46406D382C0DFC364A40
71059	7	70	1798	27244	53876	\N	52.688147000000001	село Пылково, Центральная, 40		0101000020E61000008CDB68006FEF464096EB6D3315584A40
71058	7	70	1798	56552	54667	\N	52.578443	село Пасечное, Песчаная, 28		0101000020E61000007522C15433DD4640D1CC936B0A4A4A40
71057	7	70	1798	33087	53994	\N	52.486261718771701	село Огаревка, Школьная, 6	Россия, Пензенская область, Лопатинский район, село Огаревка	0101000020E6100000E92B483316B74640CFA44DD53D3E4A40
70897	7	70	1798	56471	53951	\N	52.597774852482097	с. Николаевка, Колхозная, 11	Россия, Пензенская область, Лопатинский район, село Николаевка	0101000020E610000005C24EB16AEC4640E6AE25E4834C4A40
71055	7	70	1798	27103	54206	\N	52.699210000000001	село Луначарское, Центральная, 6		0101000020E6100000CFA3E2FF8ED84640A18499B67F594A40
71050	7	70	1798	33059	53991	\N	52.589117999999999	село Колбинка, Мостовая, 33		0101000020E61000009D2ADF3312BF464012BEF737684B4A40
71052	7	70	1798	26973	54204	\N	52.577796999999997	село Китунькино, Центральная, 1		0101000020E6100000349F73B7EB0147400B5D8940F5494A40
71049	7	70	1798	26831	54099	\N	52.618504000000001	село Камаевка, Центральная, 55		0101000020E6100000F01989D008CC4640FC389A232B4F4A40
71047	7	70	1798	33046	54203	\N	52.48189	село Дубровское, Школьная, 1		0101000020E61000004DD6A88768FC46407D224F92AE3D4A40
71046	7	70	1798	56433	53619	\N	52.541275038519899	село Даниловка, Школьная, 4	Россия, Пензенская область, Лопатинский район, село Даниловка	0101000020E6100000F38FBE49D3B046403A92CB7F48454A40
71045	7	70	1798	26641	54100	\N	52.541531999999997	село Генеральщино, Центральная, 74А		0101000020E6100000F240649126F2464065DEAAEB50454A40
71042	7	70	1798	33030	54021	\N	52.623199999999997	поселок Владимирский, Советская, 1А		0101000020E61000007C6308008ED74640006F8104C54F4A40
71044	7	70	1798	56519	54281	\N	52.548938372491897	село Вехово, Центральная, 2А	Россия, Пензенская область, Лопатинский район, село опытная Станция	0101000020E6100000E9B6442E38B546400DC4B29943464A40
71043	7	70	1798	26560	53973	\N	52.547009000000003	село Верешим, Центральная, 38		0101000020E6100000AA0EB9196EC6464010CF126404464A40
71041	7	70	1798	26447	54202	\N	52.736418	село Бузовлево, Центральная, 92		0101000020E610000031EF71A609D54640C617EDF1425E4A40
71040	7	70	1798	33025	54201	\N	52.618842999999998	село Буденновка, Мирная, 6А		0101000020E610000026AB22DC64CE4640E42D573F364F4A40
71039	7	70	1798	26351	53988	\N	52.467759999999998	село Берлик, Садовая, 44/1		0101000020E6100000FCC8AD49B7DB46404030478FDF3B4A40
71038	7	70	1798	33007	54097	\N	52.435938999999998	село Белогорье, Молодежная, 18		0101000020E6100000670E492D94F04640850662D9CC374A40
71014	7	70	1367	56563	54734	\N	53.127170326863002	Пензенская область, Кузнецкий район, Махалинский сельсовет, с.Татарская Пенделка, Школьная, 12ё	Россия, Пензенская область, Кузнецк городской округ	0101000020E6100000FE2955A2EC4747402384471B47904A40
71028	7	70	1367	25884	53382	\N	53.039465	Пензенская область, Кузнецкий район, Яснополянский сельсовет, с.Ясная Поляна, Заводская, 25		0101000020E61000003EB0E3BF40544740172B6A300D854A40
71001	7	70	1367	24603	53747	\N	53.271051	Пензенская область, Кузнецкий район, Явлейский сельсовет, с.Явлейка, Сурская, 1		0101000020E6100000EDF483BA48674740284696CCB1A24A40
70997	7	70	1367	24399	53972	\N	53.255830000000003	Пензенская область, Кузнецкий район, Явлейский сельсовет, с.Шелемис, Центральная, 63		0101000020E61000009EF0129CFA524740F8AA9509BFA04A40
71020	7	70	1367	25471	53655	\N	52.980401999999998	Пензенская область, Кузнецкий район, Чибирлейский сельсовет, с.Чибирлей, Сидорова, 156а		0101000020E610000066F9BA0CFF4F47406C770FD07D7D4A40
71002	7	70	1367	19980	53982	\N	53.356976000000003	с. Часы,  ул. Часовская, 59.  Фельдшерско-акушерский пункт.		0101000020E6100000E8BB5B59A25F47407CBABA63B1AD4A40
71018	7	70	1367	25402	54199	\N	52.984664000000002	Пензенская область, Кузнецкий район, Анненковский сельсовет, с.Тютнярь, Блохина, 34		0101000020E6100000D9AF3BDD792E474037C64E78097E4A40
70998	7	70	1367	20128	53980	\N	53.271895999999998	с. Тихменево, ул. Центральная, 7б. МУК «Тихменевский  БДЦ».		0101000020E61000006553AEF02E5F4740E4F4F57CCDA24A40
71034	7	70	1367	26123	53471	\N	53.095948999999997	Пензенская область, Кузнецкий район, Большетруевский сельсовет, с.Татарский Канадей, Школьная, 54		0101000020E61000006C5D6A847E764740BD8A8C0E488C4A40
71022	7	70	1367	25573	53944	\N	52.948031999999998	Пензенская область, Кузнецкий район, Тарлаковский сельсовет, с.Второе Тарлаково, Центральная, 69		0101000020E61000004A438D4292474740DEC7D11C59794A40
71009	7	70	1367	24979	53979	\N	53.226076999999997	Пензенская область, Кузнецкий район, Тарлаковский сельсовет, с.Первое Тарлаково, Центральная, 123а		0101000020E610000080290307B43047405BB05417F09C4A40
71011	7	70	1367	25067	53859	\N	53.146450999999999	Пензенская область, Кузнецкий район, Сюзюмский сельсовет, с.Сюзюм, Московская, 23		0101000020E61000000EF7915B931A4740B6BB07E8BE924A40
71448	7	70	1367	25067	54261	\N	53.147050933878702	с. Сюзюмское, Зелёная, 25	Россия, Пензенская область, Кузнецкий район, село Сюзюм	0101000020E6100000EBA7FFACF91947400BEC3191D2924A40
71027	7	70	1367	25803	53657	\N	53.079481000000001	Пензенская область, Кузнецкий район, Яснополянский сельсовет, с.Сухановка, Зеленая, 4		0101000020E610000075914259F8504740A2D3F36E2C8A4A40
71013	7	70	1367	19989	53733	\N	53.075980999999999	с. Старый Кряжим, ул. Ленина, 1.  Филиал №3 МБУК «Махалинский БДЦ».		0101000020E6100000BBB4E1B034184740060FD3BEB9894A40
71031	7	70	1367	25985	53873	\N	52.983269999999997	Пензенская область, Кузнецкий район, Комаровский сельсовет, с.Сосновка, Совхозная, 13		0101000020E6100000BA32A83638674740A79196CADB7D4A40
71019	7	70	1367	25448	53286	\N	53.046157000000001	Пензенская область, Кузнецкий район, Анненковский сельсовет, с.Радищево, Центральная, 95		0101000020E61000008E942D9276374740A1BDFA78E8854A40
71005	7	70	1367	24780	53326	\N	53.135215000000002	Пензенская область, Кузнецкий район, Посельский сельсовет, с.Поселки, Советская, 20		0101000020E61000005D6E30D4613F4740DE76A1B94E914A40
71004	7	70	1367	24780	53324	\N	53.135215000000002	Пензенская область, Кузнецкий район, Посельский сельсовет, с.Поселки, Ново-Зеленая, 9		0101000020E61000005D6E30D4613F4740DE76A1B94E914A40
71023	7	70	1367	25621	53329	\N	53.032708	Пензенская область, Кузнецкий район, Яснополянский сельсовет, с.Пионер, Заводская, 11		0101000020E610000014D1AFAD9F4C4740A62897C62F844A40
71006	7	70	1367	24858	53289	\N	53.166640000000001	Пензенская область, Кузнецкий район, Никольский сельсовет, с.Никольское, им.Терехина М.А, 245		0101000020E6100000ED7E15E0BB3547404C1AA37554954A40
71017	7	70	1367	25321	53970	\N	52.962891999999997	Пензенская область, Кузнецкий район, Анненковский сельсовет, с.Нижнее Аблязово, Садовая, 55-2		0101000020E6100000AFEB17EC862947403ECA880B407B4A40
71461	7	70	1367	14770	54247	\N	53.279473860480898	Пензенская область, Спасский район, Веденяпинский сельсовет, село Монастырское, Школьная, 18	Россия, Пензенская область, Кузнецкий район, село Монастырское	0101000020E6100000541D7233DC604740890AD5CDC5A34A40
71012	7	70	1367	25122	\N	\N	53.084771000000003	Пензенская область, Кузнецкий район, Махалинский сельсовет, с.Махалино, Рабочий городок совхоза, 15		0101000020E610000095287B4B391D47401A53B0C6D98A4A40
71033	7	70	1367	26086	53695	\N	53.080978999999999	Пензенская область, Кузнецкий район, Большетруевский сельсовет, с.Малый Труев, Больничная, 2б		0101000020E6100000C4793881E96E4740D65416855D8A4A40
71029	7	70	1367	25891	53734	\N	52.984718000000001	Пензенская область, Кузнецкий район, Комаровский сельсовет, с.Комаровка, Молодежная, 2а		0101000020E61000000953944BE35B47402AE44A3D0B7E4A40
71000	7	70	1367	24556	53976	\N	53.166196999999997	Пензенская область, Кузнецкий район, Явлейский сельсовет, с.Козляковка, Графская, 4		0101000020E6100000800C1D3BA85C4740BED87BF145954A40
71025	7	70	1367	25726	53875	\N	53.086793999999998	Пензенская область, Кузнецкий район, Яснополянский сельсовет, с.Каменка, Озерная, 1а		0101000020E6100000C34A05155541474098BED7101C8B4A40
70999	7	70	1367	24494	54096	\N	53.222676	Пензенская область, Кузнецкий район, Явлейский сельсовет, с.Казаковка, Школьный переулок, 3		0101000020E61000008F17D2E12164474053CDACA5809C4A40
71026	7	70	1367	25790	53985	\N	53.057772999999997	Пензенская область, Кузнецкий район, Яснополянский сельсовет, с.Злобинка, Центральная, 6а		0101000020E610000062821ABE85554740C0CB0C1B65874A40
71036	7	70	1367	20101	53303	\N	53.111687000000003	Пензенская область, Кузнецкий район, рабочий поселок Евлашево, р.п.Евлашево, Центральный переулок, 8		0101000020E6100000ADFBC742746A4740B63176C24B8E4A40
71035	7	70	1367	20101	53473	\N	53.111687000000003	Пензенская область, Кузнецкий район, рабочий поселок Евлашево, р.п.Евлашево, Центральная, 27		0101000020E6100000ADFBC742746A4740B63176C24B8E4A40
71030	7	70	1367	25972	54205	\N	53.280296	Пензенская область, Кузнецкий район, Комаровский сельсовет, с.Дворики, Дорожная, 63		0101000020E6100000F31C91EF525047408D9944BDE0A34A40
71015	7	70	1367	25210	53380	\N	52.913145999999998	Пензенская область, Кузнецкий район, рабочий поселок Верхозим, р.п.Верхозим, Проспект Победы, 1		0101000020E610000078B988EFC42E4740923CD7F7E1744A40
71032	7	70	1367	26050	53290	\N	53.089882000000003	Пензенская область, Кузнецкий район, Большетруевский сельсовет, с.Большой Труев, Прудная, 15а		0101000020E6100000B3614D6551724740E23FDD40818B4A40
71003	7	70	1367	24695	53856	\N	53.099798999999997	Пензенская область, Кузнецкий район, Посельский сельсовет, с.Благодатка, Центральная, 78		0101000020E610000030F31DFCC43547403596B036C68C4A40
71007	7	70	1367	24906	53497	\N	53.189145000000003	Пензенская область, Кузнецкий район, Тарлаковский сельсовет, с.Бестянка, Центральная, 76а		0101000020E610000057B439CE6D284740D99942E735984A40
71016	7	70	1367	25296	53407	\N	53.017493999999999	Пензенская область, Кузнецкий район, Анненковский сельсовет, с.Анненково, Юбилейная, 1		0101000020E61000009A6038D73031474028F04E3E3D824A40
71024	7	70	1367	25666	53874	\N	53.072032	Пензенская область, Кузнецкий район, Яснополянский сельсовет, с.Алексеевка, Школьная, 7		0101000020E6100000055262D7F6464740FB21365838894A40
71356	7	70	1003	9760	54136	\N	52.919032000000001	Пензенская область, Пензенский район, Краснопольский сельсовет, поселок Улановка, ул.Центральная, д.2		0101000020E6100000F16261889C6046401EFD2FD7A2754A40
71095	7	70	1003	56505	54216	\N	52.8834963031154	село Танеевка, Вольновка, 11-1	Россия, Пензенская область, Кондольский район, село Танеевка	0101000020E61000008126C286A7714640CB129D6516714A40
71369	7	70	1003	10432	53910	\N	52.763198000000003	Пензенская область, Пензенский район, Покрово-Березовский сельсовет, село Покрово-Березовка, ул.Совхозная, д.3		0101000020E6100000710168942E6B4640B22FD978B0614A40
71370	7	70	1003	10493	54058	\N	52.742649999999998	Пензенская область, Пензенский район, Покрово-Березовский сельсовет, село Новопавловка, ул.Даманская, д.10		0101000020E610000030DAE38574704640EC2FBB270F5F4A40
71349	7	70	1003	9370	53365	\N	52.823805999999998	Пензенская область, Пензенский район, Кондольский сельсовет, село Кондоль, ул.Южная, д.14		0101000020E6100000D49E927362854640D11F9A7972694A40
71350	7	70	1003	9370	54134	\N	52.823805999999998	Пензенская область, Пензенский район, Кондольский сельсовет, село Кондоль, ул.Совхозная, д.8		0101000020E6100000D49E927362854640D11F9A7972694A40
71348	7	70	1003	9370	53301	\N	52.823805999999998	Пензенская область, Пензенский район, Кондольский сельсовет, село Кондоль, ул.Осипова, д.36-а		0101000020E6100000D49E927362854640D11F9A7972694A40
71352	7	70	1003	9566	54137	\N	52.757590999999998	Пензенская область, Пензенский район, Кондольский сельсовет,село Колышлейка, ул.Луговая, д.12		0101000020E6100000DCD440F339834640395FECBDF8604A40
71357	7	70	1003	56442	53685	\N	52.899315489129201	Пензенская область, Пензенский район, Краснопольский сельсовет, село Князевка, ул.Центральная, д.2	Россия, Пензенская область, Кондольский район, село Князевка	0101000020E6100000AFD007CBD8784640B0E600C11C734A40
71372	7	70	1003	10592	54140	\N	52.812556000000001	Пензенская область, Пензенский район, Покрово-Березовский сельсовет, село Ермолаевка, ул.Молодежная, д.16		0101000020E6100000E95F92CA146946409415C3D501684A40
71353	7	70	1003	9588	54237	\N	52.750805	Пензенская область, Пензенский район, Кондольский сельсовет, село Волхонщино, ул.Центральная, д.2-а		0101000020E6100000E7A8A3E36A9A46402E56D4601A604A40
71333	7	70	1003	8721	54049	\N	52.708900999999997	Пензенская область, Пензенский район, Варыпаевский сельсовет, село Волхон-Умет, ул.Дорожная, д.59-а		0101000020E6100000710514EAE98F4640048D9944BD5A4A40
71332	7	70	1003	8674	53678	\N	52.690973999999997	Пензенская область, Пензенский район, Варыпаевский сельсовет,с.Варыпаево, ул.Школьная, д.1-а		0101000020E610000016A4198BA6994640723106D671584A40
70916	7	70	1003	46905	54084	\N	52.724246000000001	" с. Андреевка, ул. Кошелевского,20  здание МОУ ООШ, "		0101000020E610000068EC4B361E6C46402121CA17B45C4A40
70988	7	70	1379	32646	53690	\N	52.859090999999999	с.Хопер, Центральная, 10А		0101000020E6100000952710768A3F4640DBA4A2B1F66D4A40
70982	7	70	1379	56457	53820	\N	52.762789165639703	с.Пограничное, Школьная, 4А	Россия, Пензенская область, Колышлейский район, село совхоз Пограничный	0101000020E6100000A7B1BD16F4584640D05FE811A3614A40
70989	7	70	1379	56502	54198	\N	52.528739340192899	с.Чубаровка, Школьная, 1	Россия, Пензенская область, Колышлейский район, село Чубаровка	0101000020E610000022FAB5F5D3574640548F34B8AD434A40
58537	7	70	1379	32741	53953	\N	52.906340999999998	с.Халтурино, Садовая, 31		0101000020E6100000C2FA3F87F92A464010035DFB02744A40
70986	7	70	1379	32636	53735	\N	52.913086	с.Телегино, пер.Школьный, 5		0101000020E6100000C00644882B474640BD378600E0744A40
70985	7	70	1379	23795	53731	\N	52.699390358798702	с.Сумы, Центральная, 20	Россия, Пензенская область, Колышлейский район, село Сумы	0101000020E61000009357E718905D464021938C9C85594A40
70983	7	70	1379	23714	53732	\N	52.734541999999998	с.Старая Потловка, Центральная, 6		0101000020E61000006AF7AB00DF334640EBC4E578055E4A40
70981	7	70	1379	23613	53978	\N	52.665295999999998	д.Плещеевка, Центральная, 13		0101000020E6100000F660527C7C3446406E14596B28554A40
70979	7	70	1379	23513	53316	\N	52.666913000000001	д.Названовка, Пензенская, 2		0101000020E610000098C3EE3B864146407D23BA675D554A40
71468	7	70	1379	15062	54152	\N	52.825910750592897	Пензенская область, Спасский район, Кошелевский сельсовет, село Липяги, Новая, 1А	Россия, Пензенская область, Колышлейский район, село Липяги	0101000020E6100000FBE59315C31B46400D349F73B7694A40
70984	7	70	1379	48241	53383	\N	52.564847	с.Красная Горка, Мало Садовая, 1Б		0101000020E61000001EFCC401F4414640321F10E84C484A40
70991	7	70	1379	24055	53320	\N	52.699275999999998	р.п.Колышлей, Терешкина, 18		0101000020E610000099D4D0066045464058703FE081594A40
70995	7	70	1379	24055	53379	\N	52.699275999999998	р.п.Колышлей, Строителей, 7		0101000020E610000099D4D0066045464058703FE081594A40
70994	7	70	1379	24055	53288	\N	52.699275999999998	р.п.Колышлей, Садовая, 151		0101000020E610000099D4D0066045464058703FE081594A40
70992	7	70	1379	24055	53288	\N	52.7016218100757	р.п.Колышлей, Садовая, 50	Россия, Пензенская область, Колышлейский район, поселок Колышлей	0101000020E610000007EDD5C743454640BA13ECBFCE594A40
70993	7	70	1379	24055	53474	\N	52.699275999999998	р.п.Колышлей, Пензенская, 3		0101000020E610000099D4D0066045464058703FE081594A40
70990	7	70	1379	24055	53265	\N	52.699275999999998	р.п.Колышлей, Остапенко, 11		0101000020E610000099D4D0066045464058703FE081594A40
70977	7	70	1379	23421	53692	\N	52.796328000000003	с.Колтовское, Советская, 1А		0101000020E61000004298DBBDDC214640CE716E13EE654A40
70976	7	70	1379	20591	54194	\N	52.640067999999999	"с.Катковка, ул.Школьная д.3, здание МУК ""Катковский БДЦ"", "		0101000020E61000002BF9D85DA0604640AA9B8BBFED514A40
71246	7	70	1379	56462	53899	\N	52.705282091003198	село Голицыно, Петрова Слобода, 2а	Россия, Пензенская область, Колышлейский район, село Голицыно	0101000020E610000099BC0166BE3146408E3A3AAE465A4A40
70895	7	70	1379	56499	54187	\N	52.868387406424503	с. Бекетовка, Центральная, 63	Россия, Пензенская область, Колышлейский район, село Бекетовка	0101000020E610000014048F6FEF444640C2A2224E276F4A40
70956	7	70	1379	33095	53819	\N	52.667000000000002	д.Апраксино, Центральная, 65		0101000020E61000000A86730D333C46404C37894160554A40
70972	7	70	1369	20580	53617	\N	52.749747999999997	с. Чумаево, ул. Школьная, д. 2, здание МОУ ООШ с. Чумаево,		0101000020E6100000209738F240F44640E61E12BEF75F4A40
70961	7	70	1369	22718	53730	\N	52.76558	Старый Чирчим, Лесная, 2а		0101000020E6100000D7A546E8672E4740603C8386FE614A40
70962	7	70	1369	22718	53728	\N	52.76558	с. Старый Чирчим, ул. Лесная, д. 2а, здание МОУ СОШ с. Старый Чирчим,		0101000020E6100000D7A546E8672E4740603C8386FE614A40
70969	7	70	1369	23034	53729	\N	52.865718000000001	Русский Камешкир, Техническая, 2		0101000020E61000007E384888F20B47407EC7F0D8CF6E4A40
70968	7	70	1369	23034	53376	\N	52.865718000000001	Русский Камешкир, Радищева, 9		0101000020E61000007E384888F20B47407EC7F0D8CF6E4A40
70970	7	70	1369	23034	53651	\N	52.865718000000001	Русский Камешкир, Коммунальная, 10		0101000020E61000007E384888F20B47407EC7F0D8CF6E4A40
70971	7	70	1369	23034	53746	\N	52.865718000000001	Русский Камешкир, Кирова, 1		0101000020E61000007E384888F20B47407EC7F0D8CF6E4A40
70967	7	70	1369	20515	54188	\N	52.657212999999999	с. Порзово, ул. Центральная, д. 12, здание МОУ НОШ,		0101000020E61000003719558671074740C6C03A8E1F544A40
70964	7	70	1369	33135	53845	\N	52.758572000000001	Пестровка, Центральная, 45		0101000020E6100000D9E9077591124740A6D425E318614A40
70960	7	70	1369	22691	53656	\N	52.912439999999997	Новое Шаткино, Гагарина, 4		0101000020E61000005EF23FF9BB1D4740F7C77BD5CA744A40
95184	7	70	1369	22413	53969	\N	52.949286000000001	Приволжский ФО, Пензенская обл, с.Мордовский Камешкир, Центральная, 40		0101000020E61000009C6C0377A01247407C46223482794A40
70954	7	70	1369	22413	53969	\N	52.949286000000001	Мордовский Камешкир, Центральная, 40		0101000020E61000009C6C0377A01247407C46223482794A40
70958	7	70	1369	56470	53949	\N	52.855059710363101	Мамадыш, Школьный, 19	Россия, Пензенская область, Камешкирский район, село Мамадыш	0101000020E6100000CAFCA36FD2EA4640130F289B726D4A40
70955	7	70	1369	20786	53726	\N	52.843831999999999	с. Лапшово, ул. Центральная, д. 3, здание МОУ СОШ с. Лапшово,		0101000020E6100000F2B22616F8FE4640BDA8DDAF026C4A40
70957	7	70	1369	18556	53967	\N	52.827978999999999	с. Кулясово, ул. Молодежная, д. 25, здание МОУ ООШ с. Кулясово,		0101000020E6100000FFD0CC936BEA46402C634337FB694A40
70963	7	70	1369	33127	53854	\N	52.721257000000001	Камышенка, Сухая, 29		0101000020E610000089963C9E962D47406B813D26525C4A40
70965	7	70	1369	20336	53853	\N	52.710189	с. Дьячевка, ул. Сосновская, д. 3а, здание МОУ НОШ с. Дьячевка,		0101000020E61000001C0C7558E10A47404E7D2079E75A4A40
71462	7	70	1369	14786	53722	\N	52.942221000000004	Пензенская область, Спасский район, Дубровский сельсовет, село Дубровки, Новая, 5		0101000020E6100000D6355A0EF4EC46405E4D9EB29A784A40
70952	7	70	1369	20684	53825	\N	52.933059999999998	с. Большой Умыс, ул. Школьная, д. 1, здание МОУ ООШ с. Большой Умыс,		0101000020E6100000A9D903ADC00A4740569A94826E774A40
70966	7	70	1369	20451	54189	\N	52.619886999999999	с. Бегуч, ул. Центральная, д. 44, здание МОУ ООШ с. Бегуч,		0101000020E61000008B8C0E48C2184740971B0C75584F4A40
71320	7	70	1369	56486	54057	\N	52.871656989799199	село Алексеевка, Центральная, 31	Россия, Пензенская область, Камешкирский район, село Алексеевка	0101000020E61000000745F30016F346402C2AE274926F4A40
70950	7	70	1202	56443	53689	\N	53.169388946848898	с. Фёдоровка, Центральная, 5	Россия, Пензенская область, Каменский район, село Федоровка	0101000020E6100000F660527C7C204640ADA6EB89AE954A40
70939	7	70	1202	21678	54182	\N	53.056241	с. Усть-Атмис, Зеленая, 23		0101000020E6100000CB49287D21144640E0D8B3E732874A40
70944	7	70	1202	21967	53960	\N	53.188087000000003	с. Телятино, Кушкин-оч, 38		0101000020E610000089D00836AED54540C1E61C3C13984A40
70924	7	70	1202	32951	54173	\N	52.969850000000001	с. Соболевка, Ивановка, 33		0101000020E6100000DBFB54151A0A46404703780B247C4A40
70926	7	70	1202	21113	54176	\N	53.344683000000003	с. Скворечное, Речная, 6		0101000020E61000008CF2CCCB61F945405C3E92921EAC4A40
70945	7	70	1202	21982	53725	\N	52.927940999999997	с. Покровская Арчада, Драгунова, 22		0101000020E61000008FFB56EBC41B46400BCF4BC5C6764A40
70917	7	70	1202	56489	54081	\N	53.331308918883103	с. Низовка, Центральная, 78	Россия, Пензенская область, Каменский район, село Низовка	0101000020E610000029047289230946406BEF535568AA4A40
70940	7	70	1202	21766	54113	\N	53.120511854519002	с. Надеждинка, Шоссейная, 28	Россия, Пензенская область, Каменский район, село Надеждинка	0101000020E61000004B1E4FCB0F1846404563EDEF6C8F4A40
70949	7	70	1202	33067	53816	\N	53.092233999999998	с. Максимовка, Максимовская, 99		0101000020E6100000F7E80DF791FB454025CADE52CE8B4A40
70951	7	70	1202	33078	53615	\N	53.103405000000002	д. Кургановка, Верхний порядок, 34		0101000020E61000008524B37A871F4640179F02603C8D4A40
70931	7	70	1202	21307	53952	\N	53.162696849492498	с. Кувака, Центральная, 28	Россия, Пензенская область, Каменский район, село Кувака	0101000020E610000010406A132711464023145B41D3944A40
70942	7	70	1202	33041	53975	\N	52.845283999999999	с. Крыловка, Майская, 50		0101000020E6100000AA81E673EEEC454081EA1F44326C4A40
70930	7	70	1202	56452	53794	\N	53.246760298886301	"с.Кочалейка, ул. Школьная,23а, здание МОО ООШ, "	Россия, Пензенская область, Каменский район, село Кочелейка	0101000020E61000004F3C670B08FB454001FBE8D4959F4A40
70929	7	70	1202	21253	54094	\N	52.881425999999998	с. Клейменовка, Степная, 4		0101000020E61000001B62BCE6551146400BEC3191D2704A40
70934	7	70	1202	21479	53469	\N	53.135404000000001	с. Кикино, Центральная, 3		0101000020E6100000C84274081CE34540B1DF13EB54914A40
70932	7	70	1202	21391	53319	\N	53.160722999999997	с. Кевдо-Мельситово, Ленина, 16		0101000020E61000001BA19FA9D7F14540855B3E9292944A40
70915	7	70	1202	19569	53612	\N	53.184925	город Каменка, Юдина, 22		0101000020E6100000471E882CD20246403D9B559FAB974A40
70911	7	70	1202	19569	53375	\N	53.184925	город Каменка, Чернышевского, 5		0101000020E6100000471E882CD20246403D9B559FAB974A40
70903	7	70	1202	19569	53724	\N	53.184925	город Каменка, Театральный проезд, 6		0101000020E6100000471E882CD20246403D9B559FAB974A40
70909	7	70	1202	19569	53285	\N	53.184925	город Каменка, Суворова, 39		0101000020E6100000471E882CD20246403D9B559FAB974A40
70902	7	70	1202	19569	53377	\N	53.1833782357239	город Каменка, Садовая, 43	Россия, Пензенская область, Каменский район, Каменка	0101000020E6100000471E882CD2024640276728EE78974A40
70900	7	70	1202	19569	53315	\N	53.184925	город Каменка, Маловского, 2а		0101000020E6100000471E882CD20246403D9B559FAB974A40
70907	7	70	1202	19569	53373	\N	53.184925	город Каменка, Космонавтов, 5		0101000020E6100000471E882CD20246403D9B559FAB974A40
70914	7	70	1202	19569	53444	\N	53.184925	город Каменка, Коммунистическая, 24		0101000020E6100000471E882CD20246403D9B559FAB974A40
70910	7	70	1202	19569	53378	\N	53.184925	город Каменка, Ворошилова, 18а		0101000020E6100000471E882CD20246403D9B559FAB974A40
70904	7	70	1202	19569	53461	\N	53.184925	город Каменка, Болгарская, 14		0101000020E6100000471E882CD20246403D9B559FAB974A40
70906	7	70	1202	19569	53463	\N	53.184925	город Каменка, Баумана, 44		0101000020E6100000471E882CD20246403D9B559FAB974A40
70901	7	70	1202	19569	53723	\N	53.184925	город Каменка, Автохозяйская, 11		0101000020E6100000471E882CD20246403D9B559FAB974A40
70905	7	70	1202	19569	53321	\N	53.178686106483298	город Каменка, Белинская, 119	Россия, Пензенская область, Каменский район, Каменка	0101000020E61000007AC5538F340446406420CF2EDF964A40
70938	7	70	1202	21666	54181	\N	53.014074999999998	с.Казанская Арчада, Школьная, 13		0101000020E6100000B70A62A06B1D46407958A835CD814A40
70937	7	70	1202	56474	53965	\N	53.125796746963402	с. Знаменка, Центральная, 10	Россия, Пензенская область, Каменский район, село Знаменка	0101000020E6100000486AA16472044640AB77B81D1A904A40
70928	7	70	1202	21205	9808	\N	52.901474113492696	"с.Завиваловка, ул. Совхозная,1а, здание МОУ ООШ, "	Россия, Пензенская область, Каменский район, село Завиваловка	0101000020E6100000B01BB62DCA004640DF18028063734A40
70925	7	70	1202	21027	53616	\N	53.311909999999997	с. Головинщино, Первомайская, 10		0101000020E6100000FE80070610004640CEA5B8AAECA74A40
70922	7	70	1202	32940	54103	\N	53.075034000000002	с. Владыкино, Советская, 5		0101000020E610000041D3122BA3034640460BD0B69A894A40
70920	7	70	1202	18446	53814	\N	53.311957999999997	"с.Большие Верхи, ул. Центральная,15,  здание начальной школа, "		0101000020E6100000E25AED612F184640DFDC5F3DEEA74A40
70919	7	70	1202	20739	53822	\N	53.251945999999997	"с.Блиновка, ул. Школьная,13 ,  здание МОУ ООШ, "		0101000020E610000007B47405DB124640D32D3BC43FA04A40
70933	7	70	1202	21402	54074	\N	53.095566524694298	с. Безруково, Новая, 6	Россия, Пензенская область, Каменский район, село Безруково	0101000020E610000076FBAC3253F04540D6C9198A3B8C4A40
70948	7	70	1202	33066	53648	\N	53.177100000000003	с. Батрак, Советская, 20		0101000020E6100000A839799109FA4540910F7A36AB964A40
71282	7	70	1202	56463	53905	\N	52.895933241168201	с.Ахматовка, Центральная, 46	Россия, Пензенская область, Каменский район, село Ахматовка	0101000020E6100000D3A0681EC01846401E34BBEEAD724A40
70947	7	70	1202	56463	53905	\N	52.895881335524201	с. Ахматовка, Центральная, 69а	Россия, Пензенская область, Каменский район, село Ахматовка	0101000020E61000005A2C45F295184640CC0D863AAC724A40
70735	7	70	1202	47856	54082	\N	53.093932000000002	с. Аргамаково, Центральная, 3		0101000020E610000095287B4B39DB45402106BAF6058C4A40
70888	7	70	1451	19036	53808	\N	53.865271	с. Украинцево, Центральная, 37		0101000020E6100000F7216FB9FA634640AF963B33C1EE4A40
70898	7	70	1451	56521	54283	\N	53.770120935406403	"центральная усадьба свх. ""Уваровский"", Центральная, 1а"	Россия, Пензенская область, Иссинский район, село Уваровский	0101000020E6100000B55208E4125F46403E7B2E5393E24A40
70896	7	70	1451	46505	53815	\N	53.746499999999997	с. Уварово, Центральная, 87		0101000020E610000008AF5DDA70624640643BDF4F8DDF4A40
70894	7	70	1451	46458	53812	\N	53.789763000000001	с. Соловцово, Центральная, 16		0101000020E6100000728BF9B9A18B4640A14B38F416E54A40
70882	7	70	1451	46195	54002	\N	53.865296999999998	с. Приволье, Проезжая, 5		0101000020E6100000C74ACCB3928E4640D829560DC2EE4A40
70879	7	70	1451	18569	53940	\N	53.888143999999997	с. Знаменская Пестровка, Центральная, 25		0101000020E6100000062FFA0AD2924640BE11DDB3AEF14A40
70890	7	70	1451	19120	53813	\N	53.848483000000002	с. Новотрехсвятское, Центральная, 39		0101000020E6100000D881734694504640221B48179BEC4A40
70881	7	70	1451	18680	53934	\N	53.907938000000001	с. Никольская Пестровка, Нагорная, 8		0101000020E6100000C2F7FE06ED974640D865F84F37F44A40
71056	7	70	1451	56504	54211	\N	53.786352177842303	село Николаевка, Молодежная, 8	Россия, Пензенская область, Иссинский район, село Николаевка	0101000020E6100000697407B1336B46407592AD2EA7E44A40
70877	7	70	1451	46075	54160	\N	53.883589999999998	с. Кисловка, Речная, 64		0101000020E6100000C11F7EFE7B8446404C89247A19F14A40
70889	7	70	1451	19098	53809	\N	53.820926999999998	с. Кильмаевка, Центральная, 36		0101000020E6100000404E98309A5D4640A2B3CC2214E94A40
70886	7	70	1451	46298	54161	\N	53.849147000000002	с. Каменный Брод, Набережная, 8		0101000020E6100000FD2E6CCD565A46408E3F51D9B0EC4A40
70885	7	70	1451	18745	53459	\N	53.871302	рабочий поселок Исса, Черокманова, 18		0101000020E61000000DFD135CAC6C46403E78EDD286EF4A40
70884	7	70	1451	18745	53314	\N	53.871302	рабочий поселок Исса, Садовая, 6		0101000020E61000000DFD135CAC6C46403E78EDD286EF4A40
70883	7	70	1451	18745	53457	\N	53.871302	рабочий поселок Исса, Калинина, 23		0101000020E61000000DFD135CAC6C46403E78EDD286EF4A40
70887	7	70	1451	18993	54159	\N	53.892409999999998	с. Верхняя Салмовка, Демократическая, 23		0101000020E6100000AA9CF6949C574640CA4FAA7D3AF24A40
70837	7	70	1451	16455	54038	\N	53.896506000000002	с. Бутурлино, Молодежная, 8		0101000020E61000003B6D8D08C68946407A5567B5C0F24A40
70875	7	70	1451	46029	53687	\N	53.879705000000001	с. Булычево, Школьная, 7		0101000020E6100000164D6727837F46405890662C9AF04A40
70878	7	70	1451	46029	53915	\N	53.885822448809797	"центральная усадьба свх. ""Маяк"", Снежная, 39"	Россия, Пензенская область, Иссинский район, село Булычево	0101000020E61000005B9885764E7F4640E509849D62F14A40
70891	7	70	1451	19191	54070	\N	53.826917000000002	с. Архаровка, Приовражная, 17		0101000020E61000005260014C19804640D3C08F6AD8E94A40
70918	7	70	1451	56438	53653	\N	53.7545844949898	с. Анучино, Горка, 37		0101000020E610000027BEDA519C794640DD0A613596E04A40
70773	7	70	1451	56479	54004	\N	53.815974910453001	Пензенская область, Бессоновский район, Сосновский сельсовет, д.Александровка, Крюковка, 43 А	Россия, Пензенская область, Иссинский район, село Александровка	0101000020E610000095EF1989D076464043AD69DE71E84A40
70731	7	70	1468	56436	53640	\N	53.700084764890498	Чернышево, Центральная, 110В	Россия, Пензенская область, Земетчинский район, село Чернышево	0101000020E6100000B1BFEC9E3C564540C8B5A1629CD94A40
70862	7	70	1468	17698	54095	\N	53.804011000000003	Пензенская область, Земетчинский район, Морсовский сельсовет, село Чернояр, Школьная, 36		0101000020E6100000BFF38B12F41F4540E84F1BD5E9E64A40
70874	7	70	1468	18250	53614	\N	53.472954000000001	Пензенская область, Земетчинский район, Ушинский сельсовет, село Ушинка, Советская, 54		0101000020E61000006B65C22FF56745409641B5C189BC4A40
70873	7	70	1468	18250	53614	\N	53.472954000000001	Пензенская область, Земетчинский район, Ушинский сельсовет, село Ушинка, Советская, 56		0101000020E61000006B65C22FF56745409641B5C189BC4A40
70852	7	70	1468	17207	54032	\N	53.397317000000001	Пензенская область, Земетчинский район, Раевский сельсовет, село Усердино, Вторая часть, 30		0101000020E61000009FC9FE791A4445408A929048DBB24A40
70868	7	70	1468	18006	53835	\N	53.627754000000003	Пензенская область, Земетчинский район, Краснодубравский сельсовет, село Сядемка, Советская, 120		0101000020E6100000B75ED383824C454073F7393E5AD04A40
70870	7	70	1468	18093	53811	\N	53.515183	Пензенская область, Земетчинский район, Пролетарский сельсовет, село Старополянское, Юбилейная, 17		0101000020E610000057B439CE6D4E4540433A3C84F1C14A40
70857	7	70	1468	17418	53621	\N	53.600934000000002	Пензенская область, Земетчинский район, Салтыковский сельсовет, село Салтыково, Молодёжная, 27		0101000020E61000005072874D643A4540F986C267EBCC4A40
70855	7	70	1468	17344	53868	\N	53.481667999999999	Пензенская область, Земетчинский район, Пролетарский сельсовет, село Рянза, Лесная, 24		0101000020E610000007962364203B4540CEC3094CA7BD4A40
70850	7	70	1468	56496	54127	\N	53.5888427655659	Пензенская область, Земетчинский район, Пролетарский сельсовет, поселок Пролетарский, Центральная, 10 а	Россия, Пензенская область, Земетчинский район	0101000020E6100000A3CD716E1342454040BD19355FCB4A40
70859	7	70	1468	21331	53434	\N	53.648516000000001	п. Пашково, ул. Ленина, дом 1а, здание СДК,		0101000020E61000005FEE93A3003545406477819202D34A40
70860	7	70	1468	21331	53871	\N	53.648516000000001	п.Пашково, ул. 40 лет Победы, дом 6, контора участкового лесничества,		0101000020E61000005FEE93A3003545406477819202D34A40
70856	7	70	1468	17408	54091	\N	53.537444999999998	Пензенская область, Земетчинский район, Салтыковский сельсовет, село Оторма, Новая, 19		0101000020E61000009A0AF148BC40454009336DFFCAC44A40
70861	7	70	1468	17659	54093	\N	53.739007000000001	Пензенская область, Земетчинский район, Морсовский сельсовет, село Морсово, Заводская, 30		0101000020E6100000CB694FC939294540EE4108C897DE4A40
70851	7	70	1468	17147	53676	\N	53.435865999999997	Пензенская область, Земетчинский район, Матчерский сельсовет, село Матчерка, Центральная, 19 а		0101000020E610000078D503E6215B45401BB80375CAB74A40
70872	7	70	1468	18201	53643	\N	53.525118999999997	Пензенская область, Земетчинский район, Большеижморский сельсовет, село Малая Ижмора, Ивановка, 8		0101000020E61000001BF2CF0CE26745400DC1711937C34A40
70858	7	70	1468	17491	53866	\N	53.594473000000001	Пензенская область, Земетчинский район, Пролетарский сельсовет, деревня Лебедянка, Луговая, 31 а		0101000020E610000080B6D5AC3346454071ADF6B017CC4A40
70867	7	70	1468	17911	53804	\N	53.667228999999999	Пензенская область, Земетчинский район, Краснодубравский сельсовет, село Красная Дубрава, Ленина, 1 а		0101000020E61000005875560BEC574540ADF886C267D54A40
70866	7	70	1468	17911	53941	\N	53.667228999999999	Пензенская область, Земетчинский район, Краснодубравский сельсовет, село Красная Дубрава, Новый Посёлок, 27		0101000020E61000005875560BEC574540ADF886C267D54A40
70863	7	70	1468	17752	53869	\N	53.762269000000003	Пензенская область, Земетчинский район, Кирилловский сельсовет, село Кириллово, Школьный переулок, 3		0101000020E61000006C239EEC6656454098E0D40792E14A40
70854	7	70	1468	\N	53810	\N	53.186265342825202	Пензенская область, Земетчинский район, Раевский сельсовет, Советская, 527 в		0101000020E61000001CB3EC4960854640D9B11188D7974A40
70843	7	70	1468	16772	53428	\N	53.493609274828799	Пензенская область, Земетчинский район, рабочий поселок Земетчино, Смирнова, 103	Россия, Пензенская область, Земетчинский район, поселок Земетчино	0101000020E61000001C45D61A4A4D4540710168942EBF4A40
70849	7	70	1468	16772	53458	\N	53.493814	Пензенская область, Земетчинский район, рабочий поселок Земетчино, Пушкина, 5		0101000020E61000001C45D61A4A4D45404A27124C35BF4A40
70844	7	70	1468	16772	53426	\N	53.493814	Пензенская область, Земетчинский район, рабочий поселок Земетчино, Молодёжная, 1		0101000020E61000001C45D61A4A4D45404A27124C35BF4A40
70846	7	70	1468	16772	53431	\N	53.493814	Пензенская область, Земетчинский район, рабочий поселок Земетчино, Ленина, 150		0101000020E61000001C45D61A4A4D45404A27124C35BF4A40
70845	7	70	1468	16772	53433	\N	53.493814	Пензенская область, Земетчинский район, рабочий поселок Земетчино, Кулакова, 7 а		0101000020E61000001C45D61A4A4D45404A27124C35BF4A40
70847	7	70	1468	16772	53346	\N	53.493814	Пензенская область, Земетчинский район, рабочий поселок Земетчино, Кирова, 86		0101000020E61000001C45D61A4A4D45404A27124C35BF4A40
70848	7	70	1468	16772	53347	\N	53.493814	Пензенская область, Земетчинский район, рабочий поселок Земетчино, Белинского, 4		0101000020E61000001C45D61A4A4D45404A27124C35BF4A40
70853	7	70	1468	17253	53867	\N	53.389429	Пензенская область, Земетчинский район, Раевский сельсовет, село Долгово, Ленинская, 78 а		0101000020E6100000B41EBE4C142B4540978E39CFD8B14A40
70865	7	70	1468	17850	54092	\N	53.728178999999997	Пензенская область, Земетчинский район, Кирилловский сельсовет, село Гоголев Бор, Первомайская, 56		0101000020E61000000D6D0036204C454026512FF834DD4A40
70869	7	70	1468	18063	53645	\N	53.593494999999997	Пензенская область, Земетчинский район, Краснодубравский сельсовет, село Вяземка, Ленина, 228		0101000020E610000027DE019EB456454075ABE7A4F7CB4A40
70871	7	70	1468	18159	53610	\N	53.557872000000003	Пензенская область, Земетчинский район, Большеижморский сельсовет, село Большая Ижмора, Садовая, 2		0101000020E610000061E28FA2CE6A454054AD855968C74A40
70747	7	70	1468	56487	54071	\N	53.677240740638197	Пензенская область, Бессоновский район, Александровский сельсовет,село Александровка, Центральная, 6	Россия, Пензенская область, Земетчинский район, село Александровка	0101000020E61000002F4FE78A521C4540534145D5AFD64A40
70639	7	70	7508	62102	81159	\N	53.202945	Пензенская область, город Заречный, проспект Мира, 7	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70637	7	70	7508	62102	81159	\N	53.202945	Пензенская область, город Заречный, проспект Мира, 12	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70638	7	70	7508	62102	81160	\N	53.202945	Пензенская область, город Заречный, проспект Мира, 26	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70640	7	70	7508	62102	81161	\N	53.202945	Пензенская область, город Заречный, Литке, 29 корпус 6	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70621	7	70	7508	62102	81143	\N	53.202945	Пензенская область, город Заречный, Ленина, 10	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70620	7	70	7508	62102	81143	\N	53.202945	Пензенская область, город Заречный, Ленина, 7	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70625	7	70	7508	62102	81148	\N	53.202945	Пензенская область, город Заречный, Конституции СССР, 39а	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70635	7	70	7508	62102	81158	\N	53.202945	Пензенская область, город Заречный, Комсомольская, 10	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70634	7	70	7508	62102	81158	\N	53.202945	Пензенская область, город Заречный, Комсомольская, 9	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70636	7	70	7508	62102	81146	\N	53.202945	Пензенская область, город Заречный, Зеленая, 6	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70619	7	70	7508	62102	81146	\N	53.202945	Пензенская область, город Заречный, Зеленая, 14	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70624	7	70	7508	62102	81147	\N	53.202945	Пензенская область, город Заречный, Заречная, 22а	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70623	7	70	7508	62102	81147	\N	53.202945	Пензенская область, город Заречный, Заречная, 19	Россия, Пензенская область, Заречный городской округ	0101000020E610000081785DBF6099464080F10C1AFA994A40
70622	7	70	7508	62102	81147	\N	53.202326602484597	Пензенская область, город Заречный, Заречная, 40	Россия, Пензенская область, Заречный городской округ	0101000020E610000044DD0720B5994640840CE4D9E5994A40
70817	7	70	1375	15481	53608	\N	53.340601999999997	Пензенская область, Городищенский район, Юловский сельсовет, с.Юлово, Советская, 21		0101000020E6100000B115342DB1D24640E179A9D898AB4A40
70833	7	70	1375	16090	53721	\N	53.116757	Пензенская область, Городищенский район, рабочий поселок Чаадаевка, Молодежная, 9		0101000020E610000023F94A2025FC46401F4AB4E4F18E4A40
70834	7	70	1375	16090	53281	\N	53.116757	Пензенская область, Городищенский район, Чаадаевский сельсовет, с.Чаадаевка, Ленина, 96		0101000020E610000023F94A2025FC46401F4AB4E4F18E4A40
70831	7	70	1375	16090	53281	\N	53.116757	Пензенская область, Городищенский район, рабочий поселок Чаадаевка, Ленина, 26		0101000020E610000023F94A2025FC46401F4AB4E4F18E4A40
70830	7	70	1375	16174	53348	\N	53.142092232634397	Пензенская область, Городищенский район, рабочий поселок Чаадаевка, Строителей, 43	Россия, Пензенская область, Городищенский район, поселок Чаадаевка	0101000020E61000005C7347FFCBF34640F982161230924A40
70832	7	70	1375	16174	53287	\N	53.141060000000003	Пензенская область, Городищенский район, рабочий поселок Чаадаевка, Заводская, 5		0101000020E61000006D00362042F446400B630B410E924A40
70829	7	70	1375	16015	54180	\N	53.184424	Пензенская область, Городищенский район, Архангельский сельсовет, с.Уранка, Ленинская, 168		0101000020E6100000BC0512143FF646407B4CA4349B974A40
70813	7	70	1375	15271	53607	\N	53.069943000000002	Пензенская область, Городищенский район, Турдакский сельсовет, с.Трескино, Садовая, 21		0101000020E61000006EFAB31F29DE4640C5CA68E4F3884A40
70987	7	70	1375	15271	53641	\N	53.070376447984998	с.Трескино, Мира, 24		0101000020E6100000E76ED74B53DE46402F36AD1402894A40
70808	7	70	1375	15049	53277	\N	53.077652999999998	Пензенская область, Городищенский район, город Сурск, переулок Лесной, 10а		0101000020E61000000B9A965819D94640D8B79388F0894A40
70810	7	70	1375	15049	53278	\N	53.077652999999998	Пензенская область, Городищенский район, город Сурск, Школьная площадь, 4		0101000020E61000000B9A965819D94640D8B79388F0894A40
70809	7	70	1375	15049	53342	\N	53.077652999999998	Пензенская область, Городищенский район, город Сурск, Садовая, 5а		0101000020E61000000B9A965819D94640D8B79388F0894A40
70820	7	70	1375	15629	54179	\N	53.470970999999999	Пензенская область, Городищенский район, Верхнешкафтинский сельсовет, п.Стеклозавод, Шкафтинская, 2		0101000020E61000006E895C7006CF4640A52E19C748BC4A40
70811	7	70	1375	56461	53872	\N	53.0276601267148	Пензенская область, Городищенский район, Турдакский сельсовет, с.Старые Турдаки, Театральная, 8б	Россия, Пензенская область, Городищенский район, село Старый Турдаки	0101000020E6100000B7442E3883D9464024B4E55C8A834A40
70835	7	70	1375	16320	53963	\N	53.098782999999997	Пензенская область, Городищенский район, Чаадаевский сельсовет, с.Саловка, Луговая, 69б		0101000020E610000081971936CAF246404C33DDEBA48C4A40
70816	7	70	1375	15433	53864	\N	53.263274000000003	Пензенская область, Городищенский район, Русско-Ишимский сельсовет, с.Русский Ишим, Молодежная, 1б		0101000020E61000005376FA415DC246408DF161F6B2A14A40
70805	7	70	1375	56524	54294	\N	53.124511963130601	Пензенская область, Городищенский район, Канаевский сельсовет, Новые Забалки, Школьная, 12	Россия, Пензенская область, Городищенский район, село Новая Забалка	0101000020E6100000996379573DB84640D3FA5B02F08F4A40
70836	7	70	1375	16398	53264	\N	53.096020000000003	Пензенская область, Городищенский район, Нижнеелюзанский сельсовет, с.Нижняя Елюзань, Центральная, 93а		0101000020E61000004EB340BB4302474087E123624A8C4A40
70814	7	70	1375	15339	53968	\N	53.182513	Пензенская область, Городищенский район, Русско-Ишимский сельсовет, с.Мордовский Ишим, Школьная, 40		0101000020E6100000A80183A44FD14640240C03965C974A40
70815	7	70	1375	15349	54020	\N	53.221198000000001	Пензенская область, Городищенский район, Русско-Ишимский сельсовет, с.Можарка, Центральная, 136		0101000020E61000003D1059A489D1464066F84F37509C4A40
70818	7	70	1375	15520	54019	\N	53.455660999999999	Пензенская область, Городищенский район, Юловский сельсовет, с.Кардаво, Молодежная, 2		0101000020E61000003735D07CCEE746400588821953BA4A40
70807	7	70	1375	14940	53606	\N	53.108978999999998	Пензенская область, Городищенский район, Канаевский сельсовет, с.Канаевка, Советская, 64		0101000020E6100000CB9F6F0B96C84640B3791C06F38D4A40
70806	7	70	1375	14940	53606	\N	53.108978999999998	Пензенская область, Городищенский район, Канаевский сельсовет, с.Канаевка, Советская, 66		0101000020E6100000CB9F6F0B96C84640B3791C06F38D4A40
70838	7	70	1375	16490	54200	\N	53.019134999999999	Пензенская область, Городищенский район, Нижнеелюзанский сельсовет, с.Иванисовка, Молодежная, 28		0101000020E61000007651F4C0C70A4740BF9A030473824A40
70812	7	70	1375	56525	54298	\N	53.0811040271116	Пензенская область, Городищенский район, Турдакский сельсовет, п.Затон, Заводская, 5	Россия, Пензенская область, Городищенский район, село Затон	0101000020E6100000FB90B75CFDD0464093C9A99D618A4A40
70824	7	70	1375	15710	53424	\N	53.277033000000003	Пензенская область, Городищенский район, город Городище, Октябрьская, 30		0101000020E6100000DD5ED218ADD94640D6743DD175A34A40
70825	7	70	1375	15710	53425	\N	53.277033000000003	Пензенская область, Городищенский район, город Городище, Набережная, 17		0101000020E6100000DD5ED218ADD94640D6743DD175A34A40
70823	7	70	1375	15710	53345	\N	53.277033000000003	Пензенская область, Городищенский район, город Городище, Московская, 29		0101000020E6100000DD5ED218ADD94640D6743DD175A34A40
70826	7	70	1375	15710	53522	\N	53.278296480083199	Пензенская область, Городищенский район, Павло-Куракинский сельсовет, Ленина, здание администрации П-Куракинского	Россия, Пензенская область, Городищенский район, Городище	0101000020E610000015ADDC0BCCDA4640C64D0D349FA34A40
70822	7	70	1375	15710	53765	\N	53.277033000000003	Пензенская область, Городищенский район, город Городище, А.Матросова, 64		0101000020E6100000DD5ED218ADD94640D6743DD175A34A40
70821	7	70	1375	15646	54183	\N	53.422356999999998	Пензенская область, Городищенский район, Верхнешкафтинский сельсовет, с.Вышелей, ул.Молодежная, 31		0101000020E6100000CA52EBFD46BD46404B1E4FCB0FB64A40
70819	7	70	1375	15574	53863	\N	53.508901999999999	Пензенская область, Городищенский район, Верхнешкафтинский сельсовет, с.Верхний Шкафт, Молодежная, 2б		0101000020E61000005BCEA5B8AACC46403B6F63B323C14A40
71312	7	70	1375	56464	53906	\N	53.051303053627201	село Веденяпино, Новая, 6	Россия, Пензенская область, Городищенский район, село Веденяпино	0101000020E6100000FF40B96DDF054740E597C11891864A40
71422	7	70	1375	16002	54240	\N	53.176239331937403	с. Архангельское, Сибирь, 17	Россия, Пензенская область, Городищенский район, село Архангельское	0101000020E610000069368FC360EE4640CFA3E2FF8E964A40
70828	7	70	1375	16002	53478	\N	53.175552000000003	Пензенская область, Городищенский район, Архангельский сельсовет, с.Архангельское, Ленина, 70		0101000020E610000029AF95D05DEE4640AB5FE97C78964A40
71319	7	70	1375	16002	54231	\N	53.175775220573001	село Архангельское, Гагарина, 10	Россия, Пензенская область, Городищенский район, село Архангельское	0101000020E610000068CEFA9463EE46402A3A92CB7F964A40
70802	7	70	553	14766	53865	\N	53.660362999999997	с.Ягановка, Школьная, 21		0101000020E61000003D9D2B4A09954540853E58C686D44A40
70803	7	70	553	14766	53861	\N	53.660362999999997	с. Ягановка, ул. Верхняя, д. 11,		0101000020E61000003D9D2B4A09954540853E58C686D44A40
70800	7	70	553	14653	53860	\N	53.779634000000001	с.Татарская Лака, Школьная, 80а		0101000020E61000001DCC26C0B0724540C26C020CCBE34A40
70799	7	70	553	14614	53857	\N	53.748086999999998	с.Серго-Поливаново, Советская, 29а		0101000020E610000052D2C3D0EA66454008C89750C1DF4A40
70786	7	70	553	14000	54178	\N	53.691395	с.Ртищево, Плант, 19а		0101000020E61000005E2D77668267454018CFA0A17FD84A40
70795	7	70	553	48955	54011	\N	53.583415000000002	с. Рахмановка, ул. Советская, д. 1а,		0101000020E6100000D6C56D34807F4540787FBC57ADCA4A40
70794	7	70	553	48955	53718	\N	53.583415000000002	с.Рахмановка, Советская, 6		0101000020E6100000D6C56D34807F4540787FBC57ADCA4A40
70943	7	70	553	56441	53664	\N	53.788155634932799	с. Мочалейка, Финская, 39	Россия, Пензенская область, Вадинский район, село Мочалейка	0101000020E61000008D5DA27A6B784540B612BA4BE2E44A40
71433	7	70	553	13420	54147	\N	53.633921000000001	"с. Маркино, ул. Молодежная, 9, здание администрации, "		0101000020E6100000402FDCB930A84540B29FC55224D14A40
70804	7	70	553	14883	54185	\N	53.566851	с.Котел, Село, 57		0101000020E6100000B0A9F3A8F89F45403A5AD5928EC84A40
70798	7	70	553	14573	54090	\N	53.555652000000002	с.Коповка, Советская, 48		0101000020E61000008F6FEF1AF49145407FFACF9A1FC74A40
70793	7	70	553	13513	54073	\N	53.668702000000003	с. Каргалей, ул. Центральная, д. 84,		0101000020E61000003EAE0D15E39E45408962F20698D54A40
70776	7	70	553	13513	54073	\N	53.668702000000003	с.Каргалей, Центральная, 85		0101000020E61000003EAE0D15E39E45408962F20698D54A40
70801	7	70	553	14709	54016	\N	53.79139	с.Выборное, Молодежная, 8		0101000020E6100000F3C98AE1EA804540D3307C444CE54A40
58097	7	70	553	3418	53630	\N	53.686520999999999	с.Вадинск, Школьная, 47		0101000020E61000008080B56AD786454034828DEBDFD74A40
58048	7	70	553	3418	53630	\N	53.686520999999999	с.Вадинск, Школьная, 49		0101000020E61000008080B56AD786454034828DEBDFD74A40
70789	7	70	553	3418	54177	\N	53.686520999999999	с.Вадинск, Шаландина, 12		0101000020E61000008080B56AD786454034828DEBDFD74A40
70788	7	70	553	3418	53850	\N	53.686520999999999	с.Вадинск, Площадь Ленина, 1		0101000020E61000008080B56AD786454034828DEBDFD74A40
70787	7	70	553	3418	53850	\N	53.686520999999999	с.Вадинск, Площадь Ленина, 16а		0101000020E61000008080B56AD786454034828DEBDFD74A40
70791	7	70	553	3418	53720	\N	53.686520999999999	с.Вадинск, Молодежная, 12		0101000020E61000008080B56AD786454034828DEBDFD74A40
70792	7	70	553	3418	53851	\N	53.686520999999999	с.Вадинск, Максютова, 16а		0101000020E61000008080B56AD786454034828DEBDFD74A40
70790	7	70	553	3418	54089	\N	53.686520999999999	с.Вадинск, Дорожная, 1а		0101000020E61000008080B56AD786454034828DEBDFD74A40
70784	7	70	553	13905	53849	\N	53.708229000000003	с.Большая Лука, Советская, 81		0101000020E61000001421753BFB724540168A743FA7DA4A40
70768	7	70	1055	58938	67061	\N	53.318091000000003	Пензенская область, Бессоновский район, Кижеватовский сельсовет, пос.Полевой, Нефтяников, 10		0101000020E61000001D56B8E5239346407313B534B7A84A40
70765	7	70	1055	13005	53756	\N	53.405605999999999	Пензенская область, Бессоновский район, Грабовский сельсовет, село Чертково, Центральная, 45		0101000020E6100000FFEBDCB4197B4640DB87BCE5EAB34A40
70782	7	70	1055	13763	53343	\N	53.232647999999998	Пензенская область, Бессоновский район, Чемодановский сельсовет, село Чемодановка, Спортивная, 7 А		0101000020E6100000C172840CE49F46406ABDDF68C79D4A40
70781	7	70	1055	13763	53279	\N	53.232647999999998	Пензенская область, Бессоновский район, Чемодановский сельсовет, село Чемодановка, Генералова, 35		0101000020E6100000C172840CE49F46406ABDDF68C79D4A40
70780	7	70	1055	13696	54085	\N	53.230249999999998	Пензенская область, Бессоновский район, Степановский сельсовет,село Трофимовка, Совхозная, 12		0101000020E61000004AB8904770B14640B6F3FDD4789D4A40
70770	7	70	1055	13230	53764	\N	53.33137	Пензенская область, Бессоновский район, Полеологовский сельсовет, село Полеологово, Колхозная, 4		0101000020E6100000D578E926317A4640117008556AAA4A40
70779	7	70	1055	13629	53760	\N	53.253098000000001	Пензенская область, Бессоновский район, Степановский сельсовет,с.Степановка, Дорожная, 45 Б		0101000020E61000002D978DCEF9B546406D57E88365A04A40
70774	7	70	1055	13419	54086	\N	53.279665999999999	Пензенская область, Бессоновский район, Сосновский сельсовет, село Сосновка, Заречная, 8		0101000020E6100000EE05668522A74640CDE67118CCA34A40
70775	7	70	1055	13419	53292	\N	53.279665999999999	Пензенская область, Бессоновский район, Сосновский сельсовет,село Сосновка, Дорожная, 16		0101000020E6100000EE05668522A74640CDE67118CCA34A40
70771	7	70	1055	13296	53715	\N	53.461341120853703	Пензенская область, Бессоновский район, Проказнинский сельсовет,с.Пыркино, Центральная, 160 А	Россия, Пензенская область, Бессоновский район, село Пыркино	0101000020E6100000EB36A8FDD68E4640E7A6CD380DBB4A40
70772	7	70	1055	13348	54186	\N	53.520584999999997	Пензенская область, Бессоновский район, Проказнинский сельсовет, село Проказна, Школьная, 1		0101000020E61000002060ADDA35934640E2E47E87A2C24A40
70778	7	70	1055	13631	53714	\N	53.349322000000001	Пензенская область, Бессоновский район, Сосновский сельсовет, село Пазелки, Интернациональная, 3		0101000020E610000028D6A9F23DB14640FCE25295B6AC4A40
70777	7	70	1055	13570	53674	\N	53.31474	Пензенская область, Бессоновский район, Сосновский сельсовет, село Лопуховка, Завядя, 70 А		0101000020E6100000E2B19FC552AA46401C5F7B6649A84A40
70783	7	70	1055	13844	53762	\N	53.197209999999998	Пензенская область, Бессоновский район, Чемодановский сельсовет, село Лопатки, Центральная, 1 А		0101000020E6100000E7C6F484259E4640DA38622D3E994A40
71363	7	70	1055	56426	53449	\N	53.129629000000001	Пензенская область, Пензенский район, Леонидовский сельсовет, станция Леонидовка, ул.Школьная, д.48		0101000020E610000059DC7F643A9E46407DCEDDAE97904A40
70767	7	70	1055	13061	53340	\N	53.214221000000002	Пензенская область, Бессоновский район, Кижеватовский сельсовет, село Кижеватово, Молодежная, 65		0101000020E6100000DF87838428A54640E78EFE976B9B4A40
70766	7	70	1055	13061	53423	\N	53.214221000000002	Пензенская область, Бессоновский район, Кижеватовский сельсовет, село Кижеватово, Большая Дорога, 91		0101000020E6100000DF87838428A54640E78EFE976B9B4A40
71346	7	70	1055	9271	53409	\N	53.074281999999997	Пензенская область, Пензенский район, рабочий поселок Золотаревка, ул.Ленина, д.26		0101000020E610000004CB113290A946403A57941282894A40
70763	7	70	1055	12688	53605	\N	53.378110396477403	Пензенская область, Бессоновский район, Грабовский сельсовет, село Грабово, Юбилейная, 8		0101000020E61000004C70EA03C9874640312592E865B04A40
70764	7	70	1055	12688	53602	\N	53.378520999999999	Пензенская область, Бессоновский район, Грабовский сельсовет, село Грабово, Центральная, 181		0101000020E6100000C5E40D30F3874640B3EC496073B04A40
70760	7	70	1055	12688	53711	\N	53.378520999999999	Пензенская область, Бессоновский район, Грабовский сельсовет, село Грабово, Спиртзаводская, 8		0101000020E6100000C5E40D30F3874640B3EC496073B04A40
70758	7	70	1055	12688	53259	\N	53.378520999999999	Пензенская область, Бессоновский район, Грабовский сельсовет, село Грабово, Советская, 160		0101000020E6100000C5E40D30F3874640B3EC496073B04A40
70761	7	70	1055	12688	53603	\N	53.378520999999999	Пензенская область, Бессоновский район, Грабовский сельсовет, село Грабово, Ново-Западная, 15		0101000020E6100000C5E40D30F3874640B3EC496073B04A40
70762	7	70	1055	12688	53712	\N	53.378520999999999	Пензенская область, Бессоновский район, Грабовский сельсовет, село Грабово, Лесная, 31		0101000020E6100000C5E40D30F3874640B3EC496073B04A40
70759	7	70	1055	12688	53671	\N	53.378520999999999	Пензенская область, Бессоновский район, Грабовский сельсовет, село Грабово, Западная Поляна, 10		0101000020E6100000C5E40D30F3874640B3EC496073B04A40
70756	7	70	1055	12622	53460	\N	53.430388999999998	Пензенская область, Бессоновский район, Вазерский сельсовет, с.Вазерки, Новая, 6 Б		0101000020E6100000A9DBD9571E8A464071C79BFC16B74A40
70757	7	70	1055	12622	54165	\N	53.430388999999998	Пензенская область, Бессоновский район, Вазерский сельсовет, село Вазерки, Ера, 147		0101000020E6100000A9DBD9571E8A464071C79BFC16B74A40
70769	7	70	1055	13201	53759	\N	53.330392000000003	Пензенская область, Бессоновский район, Полеологовский сельсовет, село Блохино, Молодежная, 1 А		0101000020E6100000A8E507AEF2724640166EF9484AAA4A40
70752	7	70	1055	12290	53430	\N	53.336350000000003	Пензенская область, Бессоновский район, Бессоновский сельсовет, село Бессоновка, Центральная, 245		0101000020E6100000DE9387855A8546403B014D840DAB4A40
70749	7	70	1055	12290	53422	\N	53.336350000000003	Пензенская область, Бессоновский район, Бессоновский сельсовет, село Бессоновка, Сурская, 119 Б		0101000020E6100000DE9387855A8546403B014D840DAB4A40
70755	7	70	1055	12290	53338	\N	53.336350000000003	Пензенская область, Бессоновский район, Бессоновский сельсовет, село Бессоновка, Садовая, 10		0101000020E6100000DE9387855A8546403B014D840DAB4A40
70754	7	70	1055	12290	53338	\N	53.336350000000003	Пензенская область, Бессоновский район, Бессоновский сельсовет, село Бессоновка, Садовая, 67		0101000020E6100000DE9387855A8546403B014D840DAB4A40
70751	7	70	1055	12290	53439	\N	53.336350000000003	Пензенская область, Бессоновский район, Бессоновский сельсовет, село Бессоновка, Комсомольская, 1 Б/2		0101000020E6100000DE9387855A8546403B014D840DAB4A40
70753	7	70	1055	12290	53276	\N	53.336350000000003	Пензенская область, Бессоновский район, Бессоновский сельсовет, село Бессоновка, Кирова, 20 А		0101000020E6100000DE9387855A8546403B014D840DAB4A40
70750	7	70	1055	12290	53455	\N	53.335784477176801	Пензенская область, Бессоновский район, Бессоновский сельсовет,село Бессоновка, Жилгородок, 12 А	Россия, Пензенская область, Бессоновский район, село Бессоновка	0101000020E6100000A260C614AC854640914259F8FAAA4A40
70737	7	70	925	47894	54000	\N	52.955004000000002	Языково, Центральная, 3		0101000020E6100000A5F44C2F31C645404CC631923D7A4A40
70746	7	70	925	48070	53604	\N	52.974497999999997	Ширяево, Центральная, 7		0101000020E6100000240C03965C7F45403A02B859BC7C4A40
70740	7	70	925	56454	53806	\N	53.0799942524147	Шарово, Центральная, 18	Россия, Пензенская область, Белинский район, село Шарова	0101000020E610000099D4D0066091454028F04E3E3D8A4A40
71037	7	70	925	56425	53402	\N	52.918215468776701	с. Ульяновка, ул. Ленинская, 86. МБОУ ООШ с.Ульяновка.	Россия, Пензенская область, Белинский район, село Ульяновка	0101000020E610000097C4591135A745402BD9B11188754A40
70723	7	70	925	11037	53844	\N	52.968043999999999	Сяськино, Библиотечная, 14А		0101000020E6100000AF5DDA7058AE4540658BA4DDE87B4A40
70725	7	70	925	11105	53827	\N	53.086463999999999	Сулак, Садовая, 1		0101000020E61000005FF0694E5EC4454003249A40118B4A40
70744	7	70	925	7395	53748	\N	52.997619	Студенка, Центральная, 106		0101000020E6100000F50EB743C38E4540226FB9FAB17F4A40
71305	7	70	925	7395	53908	\N	52.997791429773002	село Студенка, Октябрьская, 27-а	Россия, Пензенская область, Белинский район, село Студенка	0101000020E6100000F8DEDFA0BD8E45401F9F909DB77F4A40
70720	7	70	925	10894	54170	\N	52.874491999999996	Среднеречье, Поселковая, 17		0101000020E6100000677BF486FBD445408B4E965AEF6F4A40
70745	7	70	925	12073	54172	\N	52.983660999999998	Сентяпино, Нагорная, 4		0101000020E6100000B83B6BB75D884540E2AC889AE87D4A40
70721	7	70	925	47606	53740	\N	52.845337999999998	Свищевка, Школьная, 1А		0101000020E61000001A6B7F677BE0454074081C09346C4A40
70730	7	70	925	11349	54169	\N	52.950305999999998	Пяркино, Сокоровка, 1		0101000020E6100000A228D027F2A24540A69883A0A3794A40
70742	7	70	925	11907	53420	\N	52.932935000000001	Пушанино, Пригородная, 158		0101000020E6100000D1CB28965BB045409A25016A6A774A40
70739	7	70	925	11788	53454	\N	53.027363000000001	Поим, Московская, 5		0101000020E6100000677FA0DCB69745406B0F7BA180834A40
70738	7	70	925	56449	53758	\N	53.107382969029402	Невежкино, Сельская, 34	Россия, Пензенская область, Белинский район, село Невежкино	0101000020E610000042CF66D5E7AA4540BC92E4B9BE8D4A40
70785	7	70	925	56422	54027	\N	52.901181572750097	д.Лопатино, Садовая, 39	Россия, Пензенская область, Белинский район, село Лопатино	0101000020E6100000EFCB99ED0A93454037DF88EE59734A40
71054	7	70	925	56422	53387	\N	52.900973975066201	село Лопатино, Пионерская, 18	Россия, Пензенская область, Белинский район, село Лопатино	0101000020E6100000C37FBA8102934540ED45B41D53734A40
71053	7	70	925	56422	53387	\N	52.901129673422801	село Лопатино, Пионерская, 27		0101000020E6100000C5E74EB0FF924540E5B8533A58734A40
70733	7	70	925	47825	53274	\N	52.991342000000003	Лермонтово, Центральная, 14		0101000020E6100000732A1900AAD445405C936E4BE47E4A40
68893	7	69	\N	1555	50182	\N	51.733853000000003	город Оренбург, ул. Механизаторов, д. 11		0101000020E6100000FD67CD8FBF8C4B40278925E5EEDD4940
70732	7	70	925	58918	67020	\N	53.097810262449798	Кутеевка, Молодежная, 3	Россия, Пензенская область, Белинский район, село Кушеевка	0101000020E6100000F52B9D0FCFD04540639CBF09858C4A40
70743	7	70	925	11945	53709	\N	52.909669999999998	Кукарки, Центральная, 84		0101000020E6100000417FA1478CA845407F130A1170744A40
70736	7	70	925	47893	53847	\N	52.976165195261999	Крюково, Центральная, 1	Россия, Пензенская область, Белинский район, село Крюково	0101000020E61000003CBEBD6BD0CB4540FB3F87F9F27C4A40
70729	7	70	925	11315	53669	\N	52.991504999999997	Корсаевка, Мостовая, 1		0101000020E6100000185DDE1CAE9B45400569C6A2E97E4A40
70728	7	70	925	56432	53611	\N	52.934484402689598	Козловка, Дружная, 15	Россия, Пензенская область, Белинский район, село Козловка	0101000020E6100000ABB4C5353E9B45405051F52B9D774A40
70797	7	70	925	56460	53855	\N	53.013116042884697	с. Ключи, ул. Пролетарка, д. 14,	Россия, Пензенская область, Белинский район, село Ключи	0101000020E61000008EE733A0DEBE4540F486FBC8AD814A40
70796	7	70	925	56460	53855	\N	53.013271336024602	с.Ключи, Пролетарка, 18	Россия, Пензенская область, Белинский район, село Ключи	0101000020E6100000921FF12BD6BE45401C7E37DDB2814A40
70724	7	70	925	11081	53848	\N	53.125452000000003	Кевдо-Вершина, Даманская, 9		0101000020E6100000EF6FD05E7DBC4540E19BA6CF0E904A40
70726	7	70	925	47699	53666	\N	52.925258999999997	Камынино, Мира, 3		0101000020E6100000156F641EF9B7454032AA0CE36E764A40
70734	7	70	925	11531	54174	\N	53.062714	Калдуссы, Школьная, 13		0101000020E6100000272F3201BFE245402C80290307884A40
70722	7	70	925	47633	53707	\N	52.968207	Волчково, Взлетная, 5		0101000020E6100000AB798EC877B945400F61FC34EE7B4A40
70727	7	70	925	11218	53693	\N	52.894364000000003	Верхние Поляны, Молодежная, 3		0101000020E61000009D6340F67AC54540215C01857A724A40
70716	7	70	925	10730	53336	\N	52.964855	г. Белинский, Ленина, 47		0101000020E61000005DC30C8D27B44540E8305F5E807B4A40
70717	7	70	925	10730	53272	\N	52.964855	г. Белинский, Белинская, 14		0101000020E61000005DC30C8D27B44540E8305F5E807B4A40
70719	7	70	925	10834	54080	\N	52.874322999999997	Балкашино, Центральная, 2		0101000020E61000003B51121269CF4540FF91E9D0E96F4A40
70710	7	70	1086	58495	\N	\N	52.572904000000001	Пензенская область, Бековский район, н.п. Первое отделение, Сельсоветская, 1		0101000020E6100000CC99ED0A7DD24540B1DF13EB54494A40
70705	7	70	1086	10175	53990	\N	52.718333999999999	Пензенская область, Бековский район, с. Яковлевка, Центральная, 1а		0101000020E610000085CFD6C1C1E045406CCD565EF25B4A40
70711	7	70	1086	10489	53803	\N	52.422353999999999	Пензенская область, Бековский район, с. Сосновка, Центральная усадьба, 6		0101000020E610000040170D198FC04540DAAA24B20F364A40
70713	7	70	1086	10489	54175	\N	52.422353999999999	Пензенская область, Бековский район, с. Сосновка, Комсомольская, 1		0101000020E610000040170D198FC04540DAAA24B20F364A40
70712	7	70	1086	10489	54001	\N	52.422353999999999	Пензенская область, Бековский район, с. Сосновка, Почтовая, 133		0101000020E610000040170D198FC04540DAAA24B20F364A40
70715	7	70	1086	10666	53335	\N	52.431381000000002	Пензенская область, Бековский район, п. Сахзавод, Огородная, 25		0101000020E6100000B2BB404981CD4540D28E1B7E37374A40
71495	7	70	1086	16392	54154	\N	52.670074999999997	Здание  школы д. Санниковка, ул. Молодежная 1		0101000020E6100000D2FF722D5ACA4540006F8104C5554A40
70704	7	70	1086	10118	53668	\N	52.614075	Пензенская область, Бековский район, с. Покровка, Садовая, 19		0101000020E610000013D731AEB8F04540462575029A4E4A40
70697	7	70	1086	56431	53601	\N	52.496547999999997	Пензенская область, Бековский район, п. Плодосовхоз, Спортивная, 2		0101000020E6100000EE7893DFA2DD4540757286E28E3F4A40
70703	7	70	1086	10073	54069	\N	52.616492000000001	Пензенская область, Бековский район, с. Никольское, Красная, 6а		0101000020E6100000AEF4DA6CACE84540711FB935E94E4A40
70701	7	70	1086	9897	53599	\N	52.544873000000003	Пензенская область, Бековский район, с. Мошки, ул. Садовая, 26		0101000020E6100000395E81E849E9454099BC0166BE454A40
70700	7	70	1086	9897	53599	\N	52.544873000000003	Пензенская область, Бековский район, с. Мошки, Садовая, 24		0101000020E6100000395E81E849E9454099BC0166BE454A40
70708	7	70	1086	10329	54079	\N	52.537528000000002	Пензенская область, Бековский район, с. Миткирей, Школьная, 62		0101000020E610000056D28A6F28CA45409757AEB7CD444A40
70706	7	70	1086	10207	53997	\N	52.688693000000001	Пензенская область, Бековский район, с. Мача-Родники, Почтовая, 16		0101000020E610000016855D143DD44540F8FD9B1727584A40
70978	7	70	1086	56437	53647	\N	52.577857196980503	с.Крутец, Школьная, 11	Россия, Пензенская область, Бековский район, село Крутец	0101000020E610000041F0F8F6AEBD4540E161DA37F7494A40
70702	7	70	1086	10030	54077	\N	52.641908999999998	Пензенская область, Бековский район, с. Ивановка, Центральная, 4		0101000020E6100000F60B76C3B6E545400801F9122A524A40
70709	7	70	1086	10348	53842	\N	52.585239000000001	Пензенская область, Бековский район, с. Затолокино, Школьная, 1а		0101000020E6100000FAD346753ACE454000AC8E1CE94A4A40
70699	7	70	1086	9870	53987	\N	52.515821000000003	Пензенская область, Бековский район, с. Волынщино, Шоссейная, 17		0101000020E61000006DE34F5436E4454086CB2A6C06424A40
70714	7	70	1086	10602	53429	\N	52.443981000000001	Пензенская область, Бековский район, с. Вертуновка, Школьная, 115		0101000020E6100000ABECBB22F8C94540CF85915ED4384A40
70693	7	70	1086	9568	53739	\N	52.458678999999997	Пензенская область, Бековский район, рабочий поселок Беково, Подбеково, 2б		0101000020E6100000B7D0950854D74540552E54FEB53A4A40
70696	7	70	1086	9568	53337	\N	52.453225924743499	Пензенская область, Бековский район, рабочий поселок Беково, Первомайская, 56	Россия, Пензенская область, Бековский район, поселок Беково	0101000020E6100000ED478AC8B0D8454034D93F4F033A4A40
70695	7	70	1086	9568	53419	\N	52.458678999999997	Пензенская область, Бековский район, рабочий поселок Беково, Базарная, 1		0101000020E6100000B7D0950854D74540552E54FEB53A4A40
70694	7	70	1086	9568	53686	\N	52.458678999999997	Пензенская область, Бековский район, рабочий поселок Беково, 2-я Октябрьская, 11		0101000020E6100000B7D0950854D74540552E54FEB53A4A40
70707	7	70	1086	10258	53958	\N	52.680388999999998	Пензенская область, Бековский район, с. Александровка, Молодежная, 3а		0101000020E61000004F7974232CCC454071C79BFC16574A40
71464	7	70	945	14905	53923	\N	53.815458	Пензенская область, Спасский район, Дубровский сельсовет, село Цепаево, Цепаево, 35		0101000020E6100000E84A04AA7FA245407BA180ED60E84A40
71473	7	70	945	15332	53925	\N	53.992395999999999	Пензенская область, Спасский район, Устьинский сельсовет, село Устье, Школьная, 24		0101000020E6100000E19A3BFA5FA04540325706D506FF4A40
71477	7	70	945	15351	53927	\N	53.926504000000001	Пензенская область, Спасский район, город Спасск, Совхозная, 45		0101000020E6100000EC8497E0D49745407DCEDDAE97F64A40
71476	7	70	945	15351	53488	\N	53.926504000000001	Пензенская область, Спасский район, город Спасск, Советская пл, 34		0101000020E6100000EC8497E0D49745407DCEDDAE97F64A40
71479	7	70	945	15351	53780	\N	53.926504000000001	Пензенская область, Спасский район, город Спасск, Ленина, 114		0101000020E6100000EC8497E0D49745407DCEDDAE97F64A40
71475	7	70	945	15351	53411	\N	53.926504000000001	Пензенская область, Спасский район, город Спасск, Красная, 17		0101000020E6100000EC8497E0D49745407DCEDDAE97F64A40
71478	7	70	945	15351	53368	\N	53.926504000000001	Пензенская область, Спасский район, город Спасск, Коммунальная, 66		0101000020E6100000EC8497E0D49745407DCEDDAE97F64A40
71474	7	70	945	15351	53368	\N	53.924528623419803	Пензенская область, Спасский район, город Спасск, Коммунальная, 2	Россия, Пензенская область, Беднодемьяновский район, Спасск	0101000020E6100000B37BF2B0509745400F9A5DF756F64A40
71471	7	70	945	15212	54150	\N	53.784778000000003	"с. Русский Шелдаис, ул. Садовая, 13, администрация Татарско-Шелдаисского сельсовета, "		0101000020E610000024D40CA9A2924540664F029B73E44A40
71472	7	70	945	56529	54317	\N	53.840514616852602	Пензенская область, Спасский район, Татарско-Шелдаисский сельсовет, село Русский Пимбур, Калинина, 1	Россия, Пензенская область, Беднодемьяновский район, село РусскийПимбур	0101000020E6100000888043A8528F45401366DAFE95EB4A40
71469	7	70	945	15132	53926	\N	53.726703000000001	Пензенская область, Спасский район, Рузановский сельсовет, село Рузаново, Совхозная, 26		0101000020E61000007AC5538F34A84540DA73999A04DD4A40
71457	7	70	945	14513	53921	\N	53.943376999999998	Пензенская область, Спасский район, Беднодемьяновский сельсовет, село Липлейка, Школьная, 10		0101000020E6100000ECA694D74A9445403866D993C0F84A40
71456	7	70	945	14513	54066	\N	53.943376999999998	Пензенская область, Спасский район, Беднодемьяновский сельсовет, село Липлейка, Центральная, 4А		0101000020E6100000ECA694D74A9445403866D993C0F84A40
71463	7	70	945	14850	54248	\N	53.823596000000002	Пензенская область, Спасский район, Дубровский сельсовет, п. Красный Восток, Красный Восток, 1Б		0101000020E6100000BF805EB873AD4540E78EFE976BE94A40
71467	7	70	945	15046	53924	\N	53.916238999999997	Пензенская область, Спасский район, Кошелевский сельсовет, село Кошелевка, Рабочая, 2А		0101000020E6100000607825C973A14540ED28CE5147F54A40
71466	7	70	945	14989	54197	\N	53.716099999999997	Пензенская область, Спасский район, Зубовский сельсовет, село Зубово, Сельская, 23		0101000020E610000015E63DCE34B145403255302AA9DB4A40
71465	7	70	945	14989	54273	\N	53.7161659032164	Пензенская область, Спасский район, Зубовский сельсовет, село Новозубово, Новая, 1	Россия, Пензенская область, Беднодемьяновский район, село Зубово	0101000020E6100000EF38454772B14540EA40D653ABDB4A40
70959	7	70	945	22609	54110	\N	53.820333254995496	с. Дубровки, ул. Молодежная, д. 12, здание МОУ ООШ с. Дубровки,	Россия, Пензенская область, Беднодемьяновский район, село Дубровки	0101000020E6100000F91400E319A845402F6AF7AB00E94A40
71458	7	70	945	14612	54245	\N	53.859822999999999	Пензенская область, Спасский район, Беднодемьяновский сельсовет, село Дерябкино, Московская, 47А		0101000020E61000003811FDDAFA9745409FAC18AE0EEE4A40
71459	7	70	945	7677	54149	\N	53.776249999999997	Пензенская область, Спасский район, Веденяпинский сельсовет, село Веденяпино, Школьная, 1		0101000020E61000006DAD2F12DAAC45408FC2F5285CE34A40
71470	7	70	945	15187	53955	\N	53.724491999999998	Пензенская область, Спасский район, Рузановский сельсовет, село Баранчеевка, Новая, 1		0101000020E6100000E5B8533A589F4540581B6327BCDC4A40
71460	7	70	945	14701	54065	\N	53.797176999999998	Пензенская область, Спасский район, Веденяпинский сельсовет, село Ахлебинино, Центральная, 6		0101000020E610000007077B1343AC4540CB0F5CE509E64A40
71455	7	70	945	14461	54075	\N	53.934271000000003	Пензенская область, Спасский район, Абашевский сельсовет, село Абашево, Центральная, 2Д		0101000020E610000042B3EBDE8AAC4540F54C2F3196F74A40
70689	7	70	999	56518	54280	\N	53.173659965107198	с. Шереметьево, Школьная, 1		0101000020E6100000747ADE8D05894540CA4FAA7D3A964A40
70424	7	70	999	46225	53823	\N	53.294829999999997	д. Чудная, Запрудная, 1А		0101000020E6100000D3C1FA3F8749454099F04BFDBCA54A40
71321	7	70	999	56485	54052	\N	53.269746930451703	село Троицкое, Школьная, 6	Россия, Пензенская область, Башмаковский район, село Троицкое	0101000020E6100000A3073E062B664540D998D71187A24A40
70687	7	70	999	46936	53418	\N	53.28407	с. Тимирязево, Советская, 1		0101000020E6100000AE0CAA0D4E6E45402AE3DF675CA44A40
70677	7	70	999	56494	54114	\N	53.304975346984598	п. Спиртзавод, 1-ая Заводская, 18	Россия, Пензенская область, Башмаковский район, село Спиртозавод	0101000020E6100000672B2FF99F7245407E8CB96B09A74A40
70685	7	70	999	9190	53273	\N	53.237552999999998	с. Соседка, Красноармейская, 7А		0101000020E61000000EBBEF181E5545408908FF22689E4A40
70684	7	70	999	9165	53839	\N	53.164448	с. Соломинка, Молодежная, 12		0101000020E6100000D0D2156C2352454041F2CEA10C954A40
70682	7	70	999	46822	53830	\N	53.200958999999997	с. Подгорное, Школьная, 8		0101000020E61000008EE6C8CA2F6545401E6B4606B9994A40
57805	7	70	999	46880	53966	\N	53.092390999999999	с. Петровское, Красная, 2		0101000020E610000020274C18CD604540EDB8E177D38B4A40
70688	7	70	999	46960	53939	\N	53.285012000000002	п. Новознаменский, Центральная, 33		0101000020E6100000917BBABA63734540D97BF1457BA44A40
70646	7	70	999	56445	53697	\N	53.0580594539299	с. Никульевка, Ясная, 11	Россия, Пензенская область, Башмаковский район, село Никульевка	0101000020E61000008D2441B8026C4540861E317A6E874A40
70690	7	70	999	47005	53597	\N	53.113038000000003	с. Митрофаново, Центральная, 5		0101000020E61000001900AAB8718B4540469A7807788E4A40
70683	7	70	999	46851	54171	\N	53.090066	с. Марат, Мира, 7А		0101000020E6100000B5503239B5794540A33D5E48878B4A40
71067	7	70	999	40464	54208	\N	53.277357214846397	село Липовка, Садовая, 114	Россия, Пензенская область, Башмаковский район, село Липовка	0101000020E6100000D386C3D2C05B45408928266F80A34A40
70680	7	70	999	56478	54023	\N	53.342491562516201	с. Кирилловка, Центральная, 35		0101000020E6100000DFC14F1C40594540219221C7D6AB4A40
70679	7	70	999	8952	54168	\N	53.195386999999997	с. Кандиевка, Школьная, 7		0101000020E6100000B3B794F3C57245402288F37002994A40
70678	7	70	999	46737	53737	\N	53.321565999999997	с. Знаменское, Совхозная, 8		0101000020E6100000588CBAD6DE774540B5C01E1329A94A40
58020	7	70	999	46599	53956	\N	53.138429000000002	п. Дружный, Новая, 24		0101000020E61000005053CBD6FA5E4540B4E89D0AB8914A40
70692	7	70	999	47037	53841	\N	53.236189000000003	с. Глебовка, Школьная, 6А		0101000020E610000041800C1D3B9645406556EF703B9E4A40
70516	7	70	999	48064	53948	\N	53.135565999999997	с. Высокое, Школьная, 1		0101000020E6100000E29178793A6945408A39083A5A914A40
70671	7	70	999	8564	53270	\N	53.216943999999998	рабочий поселок Башмаково, Строителей, 20		0101000020E6100000268A90BA9D8345401E882CD2C49B4A40
70675	7	70	999	8564	53417	\N	53.216943999999998	рабочий поселок Башмаково, Советская, 17А		0101000020E6100000268A90BA9D8345401E882CD2C49B4A40
70672	7	70	999	8564	53451	\N	53.216943999999998	рабочий поселок Башмаково, Лермонтова, 4		0101000020E6100000268A90BA9D8345401E882CD2C49B4A40
70670	7	70	999	8564	53727	\N	53.216943999999998	рабочий поселок Башмаково, Ленинская, 25		0101000020E6100000268A90BA9D8345401E882CD2C49B4A40
70676	7	70	999	8564	53271	\N	53.216943999999998	рабочий поселок Башмаково, Калинина, 5		0101000020E6100000268A90BA9D8345401E882CD2C49B4A40
70673	7	70	999	8564	53275	\N	53.216943999999998	рабочий поселок Башмаково, Губкина, 44А		0101000020E6100000268A90BA9D8345401E882CD2C49B4A40
70674	7	70	999	8564	53252	\N	53.216943999999998	рабочий поселок Башмаково, Шайкова, 18		0101000020E6100000268A90BA9D8345401E882CD2C49B4A40
71395	7	70	7415	56544	54616	\N	53.090619311333498	Пензенская область, Сердобский район, село Октябрьский, здание МДОУ- детсад № 2, ул.Школьная, 1,	Россия, Пензенская область, Башмаковский район	0101000020E610000039ED2939278C4540B7B24467998B4A40
68861	7	69	\N	56044	49843	\N	51.768098999999999	город Оренбург, пос. им Куйбышева, ул. Школьная, д. 1		0101000020E6100000FF21FDF6758C4B408F8B6A1151E24940
69576	7	69	\N	19350	49865	\N	51.024245000000001	Г.Ясный, ул. Свердлова, д.10		0101000020E6100000CC608C4814EE4D40B70BCD751A834940
69577	7	69	\N	19350	49829	\N	51.033976342771403	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование городское поселение город Ясный, Парковая, 21		0101000020E6100000DD989EB0C4F14D40A96C585359844940
68979	7	69	\N	22512	49749	\N	51.728448	село Южный урал, улица Буденного, дом 28А		0101000020E6100000E124CD1FD3844B40166BB8C83DDD4940
68995	7	69	\N	56057	50214	\N	51.777611999999998	село Черноречье, улица Степная, дом 32		0101000020E6100000F3203D450E8B4B40137D3ECA88E34940
68090	7	69	\N	45531	51177	\N	53.619295000000001	поселок Чапаево, Молодежная, здание сельского клуба, 10		0101000020E6100000508BC1C3B48D4A40C5C9FD0E45CF4A40
69219	7	69	\N	56181	51367	\N	51.709695000000004	с. Чапаевкое, Центральная (Чапаевская основная общеобразовательная школа), 10		0101000020E61000008A9466F3388E4B403F912749D7DA4940
69046	7	69	\N	56137	51028	\N	51.155161999999997	Оренбургская область, город Орск, Советский район, село Тукай, Центральная, 25	Россия, Оренбургская область, Орск городской округ, село Тукай	0101000020E6100000731074B4AA634D407DCA3159DC934940
67998	7	69	\N	56056	50213	\N	51.759303000000003	Оренбургская область, Адамовский район, Теренсайский сельсовет, п.Тере, Советская, 18		0101000020E6100000A0A86C58538D4B409A6038D730E14940
68977	7	69	\N	56058	50215	\N	51.849992273437103	х.Степановский, ул.Советская, д.1	Россия, Оренбургская область, хутор Степановский	0101000020E610000019761893FE804B404AEEB089CCEC4940
69397	7	69	\N	56048	50114	\N	51.765875000000001	Муниципальное  автономное общеобразовательное учреждение СОШ № 2, Карла-Маркса, 89		0101000020E6100000D595CFF23C904B4079E9263108E24940
69396	7	69	7397	\N	50114	\N	52.4420737783351	Муниципальное  автономное общеобразовательное учреждение СОШ №3, Карла-Маркса, 185	Россия, Оренбургская область, Сорочинск городской округ	0101000020E61000003B35971B0C914A40B9347EE195384A40
69599	7	69	\N	56048	50007	\N	52.424065816966497	Муниципальное  бюджетное общеобразовательное учреждение СОШ № 4, 2-микрорайон, 36А	Россия, Оренбургская область, Сорочинск	0101000020E6100000EF39B01C21934A403BAC70CB47364A40
69363	7	69	\N	56040	49938	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Шевченко, 1		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69355	7	69	\N	56040	49802	\N	51.169335354444499	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Вокзальная, 88		0101000020E610000087C1FC15327F4B40B988EFC4AC954940
68974	7	69	\N	49250	50501	\N	51.810811000000001	поселок Соловьевка, улица Центральная, дом 32А		0101000020E61000001C959BA8A5794B40581EA4A7C8E74940
68842	7	69	\N	56119	50839	\N	51.661366725560001	Оренбургская область, муниципальное образование город Оренбург, Промышленный район,с. Пруды, ул.Школьная, 7А	Россия, Оренбургская область, поселок Пруды	0101000020E61000004D2D5BEB8B824B40AAD381ACA7D44940
68968	7	69	\N	49163	50842	\N	51.875078000000002	село Приютово, улица Липовая, дом 3/1		0101000020E61000008E8F16670C774B407CB94F8E02F04940
68994	7	69	\N	49507	49835	\N	51.762267999999999	поселок Пригородный, улица Школьная, дом 1		0101000020E6100000D3BD4EEACBA24B40C76471FF91E14940
68993	7	69	\N	49507	49953	\N	51.762267999999999	поселок Пригородный, улица Советская, дом 4		0101000020E6100000D3BD4EEACBA24B40C76471FF91E14940
69586	7	69	\N	19872	49783	\N	51.837864000000003	село Подгородняя-Покровка, улица Кооперативная, дом 50	Россия, Оренбургская область, село Подгородняя Покровка	0101000020E61000004C8BFA24777C4B40753FA7203FEB4940
68975	7	69	\N	19872	49828	\N	51.837864000000003	село Подгородняя Покровка, улица Кооперативная, дом 46		0101000020E61000004C8BFA24777C4B40753FA7203FEB4940
69434	7	69	\N	49245	51071	\N	51.720739628767099	поселок Плодопитомник, Садовая, 1	Россия, Оренбургская область, поселок Плодопитомник	0101000020E610000012D89C8367944B40A375543541DC4940
69029	7	69	\N	24158	49849	\N	51.232477903733503	Оренбургская область, муниципальное образование город Орск, Октябрьский район, пр. Ленина, д. 81	Россия, Оренбургская область, Орск	0101000020E6100000B48EAA2688484D400E85CFD6C19D4940
69028	7	69	\N	24158	49849	\N	51.213161303371002	Оренбургская область, муниципальное образование город Орск, Октябрьский район, пр. Ленина, д. 51	Россия, Оренбургская область, Орск	0101000020E6100000E7559DD502414D402EE411DC489B4940
69068	7	69	\N	24158	49761	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Яблочная, 6А		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69061	7	69	\N	24158	49760	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Юлина, 12	Россия, Оренбургская область, Орск	0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69007	7	69	\N	24158	49883	\N	51.199986216690498	Оренбургская область, муниципальное образование город Орск, Ленинский район, Ю Фучика улица, 5	Россия, Оренбургская область, Орск	0101000020E610000040FB912232444D4035D4282499994940
69070	7	69	\N	24158	49854	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Энтузиастов, 4		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69048	7	69	\N	24158	49755	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Энгельса, 32		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69053	7	69	\N	24158	50045	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Чкалова, 116		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69062	7	69	\N	24158	49887	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Центральная, 35		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69032	7	69	\N	24158	49949	\N	51.232262359527702	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Тагильская, д. 35	Россия, Оренбургская область, Орск	0101000020E610000042226DE34F484D40410DDFC2BA9D4940
69064	7	69	\N	24158	50052	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Спортивная, 12		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69038	7	69	\N	24158	64040	\N	51.233986684753397	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Сорокина, д. 6	Россия, Оренбургская область, Орск	0101000020E61000006666666666484D4036583849F39D4940
69015	7	69	\N	24158	49910	\N	51.230969000000002	г. Орск, ул. Сормовская , 1 пос. Первомайский		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69050	7	69	\N	24158	49756	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Советская, 65/2		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69049	7	69	\N	24158	49756	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Советская, 69		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69077	7	69	\N	24158	49762	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Севастопольская, 40А	Россия, Оренбургская область, Орск	0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69023	7	69	\N	24158	50095	\N	51.2325317896263	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Рыбалко, д. 9	Россия, Оренбургская область, Орск	0101000020E6100000D0285DFA97484D4001A3CB9BC39D4940
69067	7	69	\N	24158	49852	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Просвещения, 40		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69066	7	69	\N	24158	49852	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Просвещения, 46		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69054	7	69	\N	24158	49759	\N	51.247778948093803	Оренбургская область, город Орск, Советский район, Подзорова, 79	Россия, Оренбургская область, Орск	0101000020E6100000C1AC50A4FB454D405BD1E638B79F4940
69035	7	69	\N	24158	50022	\N	51.233164944115202	Оренбургская область, муниципальное образование город Орск, Октябрьский район, Орское шоссе, д. 4	Россия, Оренбургская область, Орск	0101000020E6100000B48EAA2688484D4032C9C859D89D4940
69079	7	69	\N	24158	50883	\N	51.229810472748198	Оренбургская область, город Орск, Советский район, Орский проспект, 69	Россия, Оренбургская область, Орск	0101000020E610000066DAFE9595524D409A25016A6A9D4940
69069	7	69	\N	24158	49853	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Огородная, 28		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69076	7	69	\N	24158	50058	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Новая биофабрика, 77		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69075	7	69	\N	24158	50058	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Новая биофабрика, 80		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69014	7	69	\N	24158	50021	\N	51.194593482687601	Оренбургская область, муниципальное образование город Орск, Ленинский район, Никельщиков проспект, 54	Россия, Оренбургская область, Орск	0101000020E61000007FDB1324B6474D40E883656CE8984940
69074	7	69	\N	24158	49700	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Молодогвардейская, 63		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69002	7	69	\N	24158	49847	\N	51.214339803163398	Оренбургская область, муниципальное образование город Орск, Ленинский район, Макаренко улица, 7	Россия, Оренбургская область, Орск	0101000020E610000041649126DE3D4D40C11C3D7E6F9B4940
69024	7	69	\N	24158	66956	\N	51.226226604407998	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Макаренко, д. 19	Россия, Оренбургская область, Орск	0101000020E6100000B83CD68C0C484D40713C9F01F59C4940
69052	7	69	\N	24158	49757	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Коммунистов-большевиков, 1		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69587	7	69	\N	622	49732	\N	51.471527000000002	Оренбургская область,  город Кувандык, 20 лет Октября, 4а, здание СОШ №1		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
69041	7	69	\N	24158	49959	\N	51.234848823006402	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Комарова, д. 36	Россия, Оренбургская область, Орск	0101000020E6100000DE72F56393484D40C83F33880F9E4940
69055	7	69	\N	24158	50508	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Кирпичная, 134		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69051	7	69	\N	24158	50043	\N	51.205462983898997	Оренбургская область, город Орск, Советский район, Карла Маркса, 15	Россия, Оренбургская область, Орск	0101000020E6100000630CACE3F8474D40DFC4909C4C9A4940
69056	7	69	\N	24158	49758	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Камчатская, 7		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69060	7	69	\N	24158	49908	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Заводской переулок, 7		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69036	7	69	\N	24158	66957	\N	51.233555609536999	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Елшанская, д. 136		0101000020E61000006666666666484D406DE4BA29E59D4940
69042	7	69	\N	24158	49898	\N	51.2139279160371	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Гомельская, д. 82	Россия, Оренбургская область, Орск	0101000020E61000005D6E30D4614B4D406FD921FE619B4940
69037	7	69	\N	24158	49869	\N	51.2339698459541	Оренбургская область, муниципальное образование город Орск, Октябрьский район, Гайское шоссе, д. 14	Россия, Оренбургская область, Орск	0101000020E61000006762BA10AB494D40601F9DBAF29D4940
69010	7	69	\N	24158	64066	\N	51.233124530260604	Оренбургская область, муниципальное образование город Орск, Ленинский район, Гагарина площадь, 1	Россия, Оренбургская область, Орск	0101000020E61000003D821B295B484D40A4703D0AD79D4940
69065	7	69	\N	24158	49884	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Вокзальное шоссе, 18		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69063	7	69	\N	24158	50047	\N	51.209840219861803	Оренбургская область, город Орск, Советский район, Вокзальная, 28	Россия, Оренбургская область, Орск	0101000020E61000003F027FF8F94F4D4042B28009DC9A4940
69043	7	69	\N	24158	64071	\N	51.232693446924202	г. Орск, с. Строитель ул. Верхняя, 15	Россия, Оренбургская область, Орск	0101000020E6100000904AB1A371484D400A815CE2C89D4940
69057	7	69	\N	24158	49851	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Братская, 54		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69071	7	69	\N	24158	50056	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Больничный переулок, 20		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69044	7	69	\N	24158	64023	\N	51.230969000000002	"Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Беляева, д. 6 ""Б"""	Россия, Оренбургская область, Орск	0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69021	7	69	\N	24158	64023	\N	51.232477903733503	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Беляева, д. 8	Россия, Оренбургская область, Орск	0101000020E6100000183E22A644484D400E85CFD6C19D4940
69073	7	69	\N	24158	49855	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Байкальская, 13		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69059	7	69	\N	24158	49885	\N	51.229042547134299	Оренбургская область, город Орск, Советский район, Андреева, 2	Россия, Оренбургская область, Орск	0101000020E6100000C90391459A504D405930F147519D4940
69058	7	69	\N	24158	49885	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, Андреева, 5		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
69072	7	69	\N	24158	49888	\N	51.230969000000002	Оренбургская область, город Орск, Советский район, 1-й Домбаровский переулок, 11		0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
68851	7	69	\N	1555	4491	\N	51.799076999999997	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Юркина, 17	Россия, Оренбургская область, Оренбург, улица Юркина, 17	0101000020E6100000AE62F19BC28A4B402EFEB62748E64940
68881	7	69	\N	1555	4822	\N	51.770099999999999	город Оренбург, ул. Чкалова, д. 24/1	Россия, Оренбургская область, Оренбург, улица Чкалова, 24/1	0101000020E610000044BE4BA94B904B40265305A392E24940
68948	7	69	\N	1555	1963	\N	51.710073999999999	поселок Весенний, улица Центральная, дом 2	Россия, Оренбургская область, Оренбург, улица Центральная, 4	0101000020E6100000A73FFB91228E4B40B5DE6FB4E3DA4940
68007	7	69	\N	1555	1963	\N	51.710073999999999	Оренбургская область, Адамовский район, Юбилейный сельсовет, п.Жуламан, Центральная, 2	Россия, Оренбургская область, Оренбург, улица Центральная, 4	0101000020E6100000A73FFB91228E4B40B5DE6FB4E3DA4940
68877	7	69	\N	1555	4786	\N	51.774853	город Оренбург, ул. Туркестанская, д. 55/5	Россия, Оренбургская область, Оренбург, улица Туркестанская, 55/5	0101000020E610000033E197FA79914B408F1A13622EE34940
68919	7	69	\N	1555	3667	\N	51.777718	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Терешковой, 14	Россия, Оренбургская область, Оренбург, улица Терешковой, 10	0101000020E6100000C571E0D5728D4B4059C16F438CE34940
68788	7	69	\N	1555	3667	\N	51.822702999999997	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Терешковой, 269/1	Россия, Оренбургская область, Оренбург, улица Терешковой, 269/1	0101000020E6100000419FC893A48D4B4019A9F7544EE94940
68793	7	69	\N	1555	3734	\N	51.830880000000001	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Театральная, 7А	Россия, Оренбургская область, Оренбург, улица Театральная, 7а	0101000020E610000021787C7BD7904B4043739D465AEA4940
68928	7	69	\N	1555	5408	\N	51.786610000000003	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Совхозная, 31		0101000020E6100000AE0E80B8AB914B40715AF0A2AFE44940
68805	7	69	\N	1555	3883	\N	51.844029999999997	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Салмышская, 3/2	Россия, Оренбургская область, Оренбург, улица Салмышская, 3	0101000020E61000000C1EA67D73914B40E36BCF2C09EC4940
68811	7	69	\N	1555	3984	\N	51.830997000000004	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Родимцева, 5/1	Россия, Оренбургская область, Оренбург, улица Родимцева, 5	0101000020E61000002B323A2009934B407D09151C5EEA4940
69579	7	69	7393	\N	1476	\N	51.032745112365603	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование городское поселение город Ясный, Октябрьская, 8	Россия, Оренбургская область, Ясный городской округ	0101000020E6100000F4A8F8BF23F04D40C30DF8FC30844940
69091	7	69	\N	1555	1476	\N	51.788615999999998	ул. Октябрьская, 20а	Россия, Оренбургская область, Оренбург, улица Октябрьская, 20	0101000020E6100000B1524145D58B4B40198D7C5EF1E44940
68997	7	69	\N	1555	6195	\N	51.824205999999997	Оренбургская область, муниципальное образование город Орск, Ленинский район, Нефтяников улица, 2а	Россия, Оренбургская область, Оренбург, улица Нефтяников	0101000020E6100000E54350357A8D4B405F950B957FE94940
68855	7	69	\N	1555	4552	\N	51.806161000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Народная, 16/1	Россия, Оренбургская область, Оренбург, улица Народная, 16/2	0101000020E6100000056D72F8A48B4B40C4279D4830E74940
68924	7	69	\N	1555	5357	\N	51.790928000000001	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Мискинова, 32	Россия, Оренбургская область, Оренбург, улица Мискинова, 35	0101000020E61000000E30F31DFC8E4B40CFBEF2203DE54940
69604	7	69	\N	1555	1614	\N	51.777538999999997	Оренбургская область, муниципальное образование Светлинский район, муниципальное образование сельское поселение Озерный сельсовет пос.Казанча, Мира, 6	Россия, Оренбургская область, Оренбург, улица Мира, 6	0101000020E6100000446E861BF0954B40A92EE06586E34940
68832	7	69	\N	1555	4232	\N	51.776960000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Мебельная, 1а	Россия, Оренбургская область, Оренбург, улица Мебельная	0101000020E6100000AAB69BE09B884B406C26DF6C73E34940
69030	7	69	\N	1555	6506	\N	51.722316999999997	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Кутузова, д. 53	Россия, Оренбургская область, Оренбург, улица Кутузова	0101000020E6100000520DFB3DB18A4B40232C2AE274DC4940
69398	7	69	\N	1555	16233	\N	51.765875000000001	Муниципальное  автономное общеобразовательное учреждение СОШ № 7, Карла-Маркса, 18	Россия, Оренбургская область, Оренбург, улица Карла Маркса	0101000020E6100000D595CFF23C904B4079E9263108E24940
69395	7	69	\N	1555	16233	\N	51.765875000000001	"Муниципальное  автономное общеобразовательное учреждение  ""СОШ"" № 3, Карла-Маркса, 185"	Россия, Оренбургская область, Оренбург, улица Карла Маркса	0101000020E6100000D595CFF23C904B4079E9263108E24940
68922	7	69	\N	1555	5338	\N	51.814897999999999	ул. каргалинская, 26	Россия, Оренбургская область, Оренбург, улица Каргалинская	0101000020E6100000B1DF13EB548B4B40B4C9E1934EE84940
68857	7	69	\N	1555	4573	\N	51.812514999999998	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Калининградская, 23А	Россия, Оренбургская область, Оренбург, улица Калининградская, 23	0101000020E610000085E97B0DC1894B403541D47D00E84940
69589	7	69	\N	1555	3996	\N	51.832182000000003	ж/д разъезд № 20, улица Дружбы, дом 1/1	Россия, Оренбургская область, Оренбург, улица Дружбы, 3	0101000020E6100000DF4F8D976E924B40F22895F084EA4940
68819	7	69	\N	1555	1187	\N	51.831915000000002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Джангильдина, 11/1	Россия, Оренбургская область, Оренбург, улица Джангильдина, 11	0101000020E61000003065E08096944B40A306D3307CEA4940
68611	7	69	\N	1555	1187	\N	51.827539999999999	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Джангильдина, 6	Россия, Оренбургская область, Оренбург, улица Джангильдина, 4	0101000020E6100000643BDF4F8D934B40E010AAD4ECE94940
68818	7	69	\N	1555	3975	\N	51.827618000000001	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Брестская, 5/1	Россия, Оренбургская область, Оренбург, улица Брестская, 5	0101000020E610000040DCD5ABC8924B405CCAF962EFE94940
68852	7	69	\N	1555	4510	\N	51.808483000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Братьев Башиловых, 18	Россия, Оренбургская область, Оренбург, улица Братьев Башиловых, 18	0101000020E6100000695721E5278B4B409D2FF65E7CE74940
69006	7	69	\N	1555	6276	\N	51.770578999999998	Оренбургская область, муниципальное образование город Орск, Ленинский район, Б Хмельницкого улица, 8	Россия, Оренбургская область, Оренбург, улица Богдана Хмельницкого, 6	0101000020E6100000C40776FC178E4B4000FE2955A2E24940
68813	7	69	\N	1555	4012	\N	51.828480999999996	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, мкр. им. 70-летия ВЛКСМ, 29	Россия, Оренбургская область, Оренбург, улица 70 Лет ВЛКСМ, 29	0101000020E61000003D0FEECEDA914B40BE2D58AA0BEA4940
69031	7	69	\N	1555	50100	\N	51.792003000000001	"Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Ялтинская, д. 81 ""А"""		0101000020E6100000728BF9B9A1914B40BDAAB35A60E54940
68907	7	69	\N	1555	50164	\N	51.757424	Оренбургская область, муниципальное образование город Оренбург, Центральный район, яицкая, 23		0101000020E6100000842BA0504F8B4B404E9A0645F3E04940
68809	7	69	\N	1555	50222	\N	51.836556000000002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Юных Ленинцев, 9		0101000020E61000004837C2A222924B40E4A25A4414EB4940
69005	7	69	\N	1555	49877	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Юношеская улица, 3		0101000020E61000009C31CC09DA924B40C4279D4830E14940
69009	7	69	\N	1555	50226	\N	51.758436541801103	Оренбургская область, муниципальное образование город Орск, Ленинский район, Школьная улица, 1	Россия, Оренбургская область, Оренбург, Ленинский район	0101000020E610000064B2B8FFC8924B40C689AF7614E14940
68864	7	69	\N	1555	50423	\N	51.627108868929298	город Оренбург, пос. Бердянка, ул. Школьная, д. 14	Россия, Оренбургская область, Оренбург городской округ, село Бердянка	0101000020E610000087C1FC1532A94B407D03931B45D04940
68934	7	69	\N	1555	50174	\N	51.796793000000001	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Шевченко, 233а		0101000020E61000001B4AED45B4914B4043572250FDE54940
68880	7	69	\N	1555	50191	\N	51.763863000000001	город Оренбург, ул. Чкалова, д. 1		0101000020E6100000BC0853944B8F4B40EECF4543C6E14940
68906	7	69	\N	1555	50201	\N	51.757313395503701	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Чичерина, 1	Россия, Оренбургская область, Оренбург, улица Чичерина, 1	0101000020E61000000C5872158B8B4B40F7EAE3A1EFE04940
68884	7	69	\N	1555	50194	\N	51.760762999999997	город Оренбург, ул. Челюскинцев, д. 18		0101000020E6100000E50CC51D6F8E4B40E08096AE60E14940
68901	7	69	\N	1555	50145	\N	51.711905000000002	город Оренбург, ул. Центральная, д. 13		0101000020E6100000EBE0606F628E4B40F06DFAB31FDB4940
68310	7	69	\N	1555	50145	\N	51.712238999999997	с. Новочеркасское, ул. Центральная, д.20		0101000020E61000003B545392758E4B40C6F7C5A52ADB4940
68840	7	69	\N	1555	50220	\N	51.791407	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Химическая, 15		0101000020E6100000151A886533854B40A96917D34CE54940
68837	7	69	\N	1555	50220	\N	51.789088999999997	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Химическая, 7		0101000020E610000021C9ACDEE1844B4011514CDE00E54940
68917	7	69	\N	1555	50225	\N	51.777405999999999	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Харьковская, 14		0101000020E610000058E1968FA4904B406ADB300A82E34940
68930	7	69	\N	1555	5437	\N	51.791289999999996	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Флотский пер, 16	Россия, Оренбургская область, Оренбург, Флотский переулок, 16	0101000020E6100000587380608E924B406FD39FFD48E54940
69574	7	69	\N	1555	50147	\N	51.765974999999997	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование городское поселение город Ясный, Уральская, 11а		0101000020E6100000359BC76130914B40DC4603780BE24940
68879	7	69	\N	1555	50147	\N	51.765974999999997	город Оренбург, ул. Уральская, д. 1		0101000020E6100000359BC76130914B40DC4603780BE24940
68916	7	69	\N	1555	50172	\N	51.769119000000003	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Туркестанская, 6а		0101000020E610000034B91803EB8E4B40BADDCB7D72E24940
68883	7	69	\N	1555	50172	\N	51.766187000000002	город Оренбург, ул. Туркестанская, д. 11А		0101000020E6100000A321E3512A8F4B4068CF656A12E24940
68902	7	69	\N	1555	50190	\N	51.814970000000002	город Оренбург, ул. Транспортная, д. 12		0101000020E610000056F146E691954B404E9CDCEF50E84940
68897	7	69	\N	1555	50131	\N	51.707646670756702	город Оренбург, ул. Тобольская, д. 59А	Россия, Оренбургская область, Оренбург, улица Тобольская	0101000020E6100000871A8524B38E4B40670E492D94DA4940
68836	7	69	\N	1555	50197	\N	51.790410000000001	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Ткачева, 18		0101000020E6100000CC2555DB4D884B403737A6272CE54940
68835	7	69	\N	1555	50197	\N	51.788136999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Ткачева, 8		0101000020E610000018E945ED7E874B403FE257ACE1E44940
68913	7	69	\N	1555	50192	\N	51.774942000000003	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Терешковой, 8		0101000020E6100000F60CE198658D4B40FF25A94C31E34940
68912	7	69	\N	1555	50192	\N	51.773950999999997	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Терешковой, 33		0101000020E6100000D811876C208D4B406EDA8CD310E34940
68920	7	69	\N	1555	50227	\N	51.783434	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Сухарева, 50		0101000020E61000004F95EF19898C4B408849B89047E44940
69011	7	69	\N	1555	41569	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Строителей, 14	Россия, Оренбургская область, Оренбург, Ленинский район	0101000020E61000009C31CC09DA924B40C4279D4830E14940
69012	7	69	\N	1555	50234	\N	51.758436541801103	Оренбургская область, муниципальное образование город Орск, Ленинский район, Строителей, 20	Россия, Оренбургская область, Оренбург, Ленинский район	0101000020E610000064B2B8FFC8924B40C689AF7614E14940
68856	7	69	\N	1555	50184	\N	51.816099999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Станционная, 2а		0101000020E6100000C9E9EBF99A8B4B40FF21FDF675E84940
68843	7	69	\N	1555	50184	\N	51.816099999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Станционная, 2А		0101000020E6100000C9E9EBF99A8B4B40FF21FDF675E84940
69004	7	69	\N	1555	49969	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Станиславского улица, 42б		0101000020E61000009C31CC09DA924B40C4279D4830E14940
69003	7	69	\N	1555	49879	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Станиславского улица, 37		0101000020E61000009C31CC09DA924B40C4279D4830E14940
68890	7	69	\N	1555	50180	\N	51.768734000000002	город Оренбург, ул. Советская, д. 41		0101000020E6100000724EECA17D8C4B4061A92EE065E24940
68888	7	69	\N	1555	50180	\N	51.760747000000002	город Оренбург, ул. Советская, д. 24		0101000020E6100000C748F608358D4B40DBC35E2860E14940
68887	7	69	\N	1555	50180	\N	51.766204000000002	город Оренбург, ул. Советская, д. 48		0101000020E610000050DF32A7CB8C4B403E0801F912E24940
68886	7	69	\N	1555	50180	\N	51.756788999999998	город Оренбург, ул. Советская, д. 7		0101000020E6100000A59F70766B8D4B407C7C4276DEE04940
68885	7	69	\N	1555	50180	\N	51.756481999999998	город Оренбург, ул. Советская, д. 6		0101000020E6100000A4C2D842908D4B409F01F566D4E04940
68826	7	69	\N	1555	50180	\N	51.778587000000002	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Советская, 111		0101000020E610000088855AD3BC8B4B409E0B23BDA8E34940
68796	7	69	\N	1555	50181	\N	51.828225000000003	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Сергея Лазо, 8/2		0101000020E610000024B9FC87F48F4B40645DDC4603EA4940
68795	7	69	\N	1555	50181	\N	51.829082	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Сергея Лазо, 7		0101000020E6100000F931E6AE25904B40E4D9E55B1FEA4940
68794	7	69	\N	1555	50181	\N	51.827902000000002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Сергея Лазо, 9		0101000020E610000041F4A44C6A904B40812557B1F8E94940
69575	7	69	\N	1555	50144	\N	51.754876000000003	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование городское поселение город Ясный, Свердлова, 10		0101000020E61000005E6743FE998D4B408544DAC69FE04940
68927	7	69	\N	1555	50207	\N	51.789924999999997	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Самолетная, 91		0101000020E6100000944E24986A904B407AA52C431CE54940
69603	7	69	\N	1555	50159	\N	51.816962917886002	г.Оренбург, ул.Салмышская, 57, ТК "Квартал"	Россия, Оренбургская область, Оренбург, улица Салмышская, 58	0101000020E6100000ED0F94DBF6954B4062855B3E92E84940
68865	7	69	\N	1555	50159	\N	51.822103014864801	город Оренбург, ул. Салмышская, д. 46/1	Россия, Оренбургская область, Оренбург, улица Салмышская, 46	0101000020E61000008B16A06D35954B40C478CDAB3AE94940
68807	7	69	\N	1555	50159	\N	51.839855999999997	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Салмышская, 11		0101000020E610000095F0845E7F924B40B8ACC26680EB4940
68804	7	69	\N	1555	50159	\N	51.842374552057002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Салмышская, 4/1	Россия, Оренбургская область, Оренбург, улица Салмышская, 4к1	0101000020E6100000F14927124C914B40E7FBA9F1D2EB4940
68914	7	69	\N	1555	50202	\N	51.774630000000002	Оренбургская область, муниципальное образование город Оренбург, Центральный район, рыбаковская, 59		0101000020E6100000ACADD85F768D4B4010406A1327E34940
68817	7	69	\N	1555	50167	\N	51.835031999999998	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Просторная, 14/2		0101000020E61000001878EE3D5C944B40868E1D54E2EA4940
68816	7	69	\N	1555	50167	\N	51.835031999999998	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Просторная, 14/1		0101000020E61000001878EE3D5C944B40868E1D54E2EA4940
68815	7	69	\N	1555	50167	\N	51.838648999999997	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Просторная, 4		0101000020E610000075E789E76C934B405BE9B5D958EB4940
68791	7	69	\N	1555	49934	\N	51.879672489468597	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, п. Кушкуль, Просвещения, 4		0101000020E6100000FDF49F353F924B407C9A931799F04940
68785	7	69	\N	1555	50120	\N	51.801231999999999	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Промышленная, 3		0101000020E61000003F8C101E6D924B401C412AC58EE64940
68870	7	69	\N	1555	4712	\N	51.777031999999998	город Оренбург, Промысловый проезд, д. 11	Россия, Оренбургская область, Оренбург, Промысловый проезд, 11	0101000020E6100000E5D3635B06984B4005F9D9C875E34940
68827	7	69	\N	1555	50640	\N	51.777261000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Пролетарская, 99		0101000020E61000006058FE7C5B8C4B4067BAD7497DE34940
69598	7	69	\N	1555	16128	\N	51.776195999999999	пл.Привокзальная, д.1	Россия, Оренбургская область, Оренбург, Промышленный район, Привокзальная площадь, 1	0101000020E6100000D042024697894B409CA4F9635AE34940
67999	7	69	666	\N	16128	\N	51.600887850492803	Оренбургская область, Адамовский район, Теренсайский сельсовет, п.Тере, Привокзальная, 1	Россия, Оренбургская область, Адамовский район	0101000020E6100000075F984C15004E408847E2E5E9CC4940
68929	7	69	\N	1555	3655	\N	51.783862999999997	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Победы пр, 75	Россия, Оренбургская область, Оренбург, Победы проспект, 75	0101000020E6100000E94999D4D08E4B40B0C56E9F55E44940
68854	7	69	\N	1555	50223	\N	51.800870000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Минская, 1		0101000020E6100000E8C1DD59BB8B4B407C2C7DE882E64940
68925	7	69	\N	1555	3655	\N	51.789006000000001	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Победы пр, 118	Россия, Оренбургская область, Оренбург, Победы проспект, 118	0101000020E61000008BE07F2BD98F4B40842C0B26FEE44940
68918	7	69	\N	1555	3655	\N	51.777822999999998	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Победы пр, 13	Россия, Оренбургская область, Оренбург, Победы проспект, 13	0101000020E6100000F58590F3FE8D4B40CE893DB48FE34940
68787	7	69	\N	1555	3655	\N	51.815182	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Победы, 166/1	Россия, Оренбургская область, Оренбург, Победы проспект, 166/1	0101000020E610000037E15E99B7924B40D9243FE257E84940
69399	7	69	\N	1555	50211	\N	51.759503000000002	Муниципальное  бюджетное общеобразовательное учреждение СОШ № 1, Пионерская, 1		0101000020E6100000020D36751E8B4B40611BF16437E14940
68878	7	69	\N	1555	50112	\N	51.7676708481834	город Оренбург, ул. Пикетная, д. 63	Россия, Оренбургская область, Оренбург, улица Пикетная	0101000020E61000009A42E73576914B40378B170B43E24940
68910	7	69	\N	1555	4135	\N	51.771431999999997	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Парковый пр, 7	Россия, Оренбургская область, Оренбург, Парковый проспект, 7	0101000020E6100000994869368F8B4B403F8BA548BEE24940
68824	7	69	\N	1555	4135	\N	51.774585999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, пр.Парковый, 40	Россия, Оренбургская область, Оренбург, Парковый проспект, 40	0101000020E610000039268BFB8F8A4B4040F850A225E34940
68823	7	69	\N	1555	4135	\N	51.774769999999997	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, Пр.Парковый, 15	Россия, Оренбургская область, Оренбург, Парковый проспект, 15	0101000020E6100000AEBCE47FF2894B4001F6D1A92BE34940
68923	7	69	\N	1555	50204	\N	51.794203000000003	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Орджоникидзе, 226		0101000020E6100000790261A7588D4B404BB1A371A8E54940
68921	7	69	\N	1555	50204	\N	51.791145	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Орджоникидзе, 197		0101000020E6100000473A03232F8D4B406CB2463D44E54940
69017	7	69	\N	1555	50168	\N	51.825814999999999	Оренбургская область, муниципальное образование город Орск, Ленинский район, Онежская улица, 36		0101000020E61000005C3AE63C638D4B40EBC5504EB4E94940
69019	7	69	\N	1555	50111	\N	51.7771258970932	"Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Омская, д. 69 ""А"""		0101000020E610000072C3EFA65B944B40876F61DD78E34940
69269	7	69	\N	1555	51378	\N	51.788325999999998	п.Элеватор, ул.Октябрьская, 1		0101000020E61000003C16DBA4A28B4B40124BCADDE7E44940
68933	7	69	\N	1555	50169	\N	51.7956886650502	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Одесская, 148	Россия, Оренбургская область, Оренбург, улица Одесская	0101000020E6100000EB387EA834924B40BB641C23D9E54940
68859	7	69	\N	1555	50205	\N	51.813254999999998	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Ноябрьская, 41		0101000020E6100000BFB7E9CF7E8C4B407C2766BD18E84940
68858	7	69	\N	1555	50205	\N	51.813265999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Ноябрьская, 45		0101000020E6100000D026874F3A8D4B407079AC1919E84940
68833	7	69	\N	1555	50179	\N	51.778770999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Ногина, 6		0101000020E6100000126BF12900884B405F09A4C4AEE34940
68831	7	69	\N	1555	50179	\N	51.782420000000002	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Ногина, 46		0101000020E61000003D9E961FB8884B4040DEAB5626E44940
68860	7	69	\N	1555	50177	\N	51.808911999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Новая, 21/3		0101000020E6100000B5352218078D4B40C5ABAC6D8AE74940
69595	7	69	\N	1555	50173	\N	51.825542091709202	Специальная (коррекционная) общеобразовательная школа-интернат, Нефтянников, 18	Россия, Оренбургская область, Оренбург, улица Нефтяников	0101000020E61000003332C85D848D4B40BABC395CABE94940
68825	7	69	\N	1555	50217	\N	51.783078000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Невельская, 2		0101000020E610000007D15AD1E68A4B40CA1B60E63BE44940
68894	7	69	\N	1555	50107	\N	51.724628429360799	город Оренбург, ул. Нахимова, д. 33	Россия, Оренбургская область, Оренбург, улица Нахимова	0101000020E6100000B130444E5F8B4B4009E23C9CC0DC4940
68973	7	69	\N	1555	50643	\N	51.753627000000002	поселок Зауральный, улица Набережная, дом 15		0101000020E61000007C43E1B3758C4B40F9307BD976E04940
68784	7	69	\N	1555	50178	\N	51.801177000000003	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Монтажников, 14/2		0101000020E6100000A4A99ECC3F924B4059A7CAF78CE64940
68936	7	69	\N	1555	50044	\N	51.900530656767302	Пос Нижнесакмарский МОУ «СОШ № 37»,ул. Молодежная, 17		0101000020E610000019541B9C889C4B4060048D9944F34940
69008	7	69	\N	1555	49982	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Мира проспект, 15а		0101000020E61000009C31CC09DA924B40C4279D4830E14940
69000	7	69	\N	1555	49845	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Мира проспект, 16		0101000020E61000009C31CC09DA924B40C4279D4830E14940
68786	7	69	\N	1555	50126	\N	51.782244670376798	город Оренбург, ул. Мира, д. 22	Россия, Оренбургская область, Оренбург, улица Мира, 20	0101000020E610000061360186E5954B40D23AAA9A20E44940
69025	7	69	\N	1555	50148	\N	51.780337000000003	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Медногорская, д. 36		0101000020E61000001B65FD6662944B40EC6D3315E2E34940
68839	7	69	\N	1555	50116	\N	51.788733000000001	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Манежная, 9		0101000020E610000024F1F274AE824B405323F433F5E44940
68900	7	69	\N	1555	51379	\N	51.772227999999998	город Оренбург, ул. Мало-Восточная, д. 1А		0101000020E6100000E1455F419A934B401A87FA5DD8E24940
69039	7	69	\N	1555	50098	\N	51.757123	"Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Горького, д. 153 ""А"""		0101000020E6100000C808A870048D4B4053060E68E9E04940
68875	7	69	\N	1555	4763	\N	51.777768000000002	город Оренбург, Майский проезд, д. 8	Россия, Оренбургская область, Оренбург, Майский проезд, 8	0101000020E61000000DAA0D4E44934B400BF0DDE68DE34940
68849	7	69	\N	1555	50137	\N	51.795495000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Магнитогорская, 80		0101000020E61000006479573D60864B40D690B8C7D2E54940
68846	7	69	\N	1555	50187	\N	51.796686999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Львовская, 13		0101000020E610000096067E54C3884B40FD12F1D6F9E54940
68932	7	69	\N	1555	50183	\N	51.787607000000001	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Луговая, 85		0101000020E610000058E2016553944B40E38C614ED0E44940
68909	7	69	\N	1555	51353	\N	51.762804000000003	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Луганская, 5		0101000020E6100000048F6FEF1A884B4006A1BC8FA3E14940
69001	7	69	\N	1555	49867	\N	51.7536424795722	Оренбургская область, муниципальное образование город Орск, Ленинский район, Ленинского Комсомола улица, 16	Россия, Оренбургская область, Оренбург, Ленинский район	0101000020E61000001A53B0C6D9944B402E724F5777E04940
68999	7	69	\N	1555	41565	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Ленина проспект, 32	Россия, Оренбургская область, Оренбург, Ленинский район	0101000020E61000009C31CC09DA924B40C4279D4830E14940
68996	7	69	\N	1555	41565	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Ленина проспект, 84	Россия, Оренбургская область, Оренбург, Ленинский район	0101000020E61000009C31CC09DA924B40C4279D4830E14940
68560	7	69	325	\N	66975	\N	52.341398989896	Оренбургская область, Курманаевский район, Курманаевский сельсовет, площадь Ленина, 1	Россия, Оренбургская область, Курманаевский район	0101000020E61000007C80EECB99ED49408DF161F6B22B4A40
68908	7	69	\N	1555	50113	\N	51.7649476569798	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Курача, 24	Россия, Оренбургская область, Оренбург, улица Курача	0101000020E6100000B950F9D7F28A4B40FF91E9D0E9E14940
68834	7	69	\N	1555	50203	\N	51.785863999999997	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Красина, 43А		0101000020E610000054FCDF1115884B40478D093197E44940
68998	7	69	\N	1555	49699	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Короленко улица, 16		0101000020E61000009C31CC09DA924B40C4279D4830E14940
68799	7	69	\N	1555	50188	\N	51.835220999999997	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Конституции, 23		0101000020E610000051F4C0C7608F4B4059F78F85E8EA4940
69016	7	69	\N	1555	49882	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Коларова улица, 1		0101000020E61000009C31CC09DA924B40C4279D4830E14940
68891	7	69	\N	1555	50139	\N	51.764233573368799	город Оренбург, ул. Кобозева, д. 43	Россия, Оренбургская область, Оренбург, улица Кобозева	0101000020E6100000D49CBCC8048C4B40E23E726BD2E14940
68892	7	69	\N	1555	50209	\N	51.762228999999998	город Оренбург, ул. Кирова, д. 6		0101000020E6100000FDBB3E73D68B4B40098849B890E14940
68926	7	69	\N	1555	5382	\N	51.796292000000001	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Квартальный пер, 2	Россия, Оренбургская область, Оренбург, Квартальный переулок, 2	0101000020E6100000FA08FCE1E78F4B40810871E5ECE54940
68895	7	69	\N	1555	50094	\N	51.717897283946499	город Оренбург, ул. Карачинская, д. 50	Россия, Оренбургская область, Оренбург, улица Карачинская	0101000020E6100000B9E34D7E8B8C4B40C172840CE4DB4940
68874	7	69	\N	1555	4746	\N	51.780571000000002	город Оренбург, Знаменский проезд, д. 4	Россия, Оренбургская область, Оренбург, Знаменский проезд, 4	0101000020E6100000139B8F6B43934B405F9A22C0E9E34940
68850	7	69	\N	1555	50634	\N	51.791552000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул. Зиновьева, 2		0101000020E6100000EDD808C4EB864B40AD8A709351E54940
68789	7	69	\N	1555	50229	\N	51.823410000000003	ул. Заводская д.30		0101000020E6100000925D6919A98B4B408599B67F65E94940
68862	7	69	\N	1555	49786	\N	51.790036000000001	город Оренбург, пос. Ростоши, ул. Журевского, д. 15		0101000020E6100000DEE8633E209E4B40D2544FE61FE54940
69400	7	69	\N	1555	50103	\N	51.769854000000002	Муниципальное  бюджетное общеобразовательное учреждение СОШ № 117, Железнодорожная, 6		0101000020E61000009067976F7D8A4B40EF586C938AE24940
68812	7	69	\N	1555	50175	\N	51.832399000000002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Дружбы, 7/2		0101000020E61000008A3BDEE4B7924B408F1CE90C8CEA4940
68903	7	69	\N	1555	50212	\N	51.818728	город Оренбург, ул. Диагностики, д. 9		0101000020E610000067B4554964954B40E5284014CCE84940
68288	7	69	\N	19770	49724	\N	52.777102999999997	город Бузулук, 1 микрорайон, 8		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68801	7	69	\N	1555	3791	\N	51.835354000000002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Дзержинского, 26/4	Россия, Оренбургская область, Оренбург, Дзержинского проспект, 26	0101000020E61000001346B3B27D904B40994A3FE1ECEA4940
68798	7	69	\N	1555	3791	\N	51.829765999999999	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Дзержинского, 10	Россия, Оренбургская область, Оренбург, Дзержинского проспект, 10	0101000020E61000000778D2C2658F4B4097AAB4C535EA4940
68790	7	69	\N	1555	50133	\N	51.823988999999997	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Гастелло, 19		0101000020E61000006F2F698CD6894B40C2A1B77878E94940
68876	7	69	\N	1555	1275	\N	51.773789000000001	город Оренбург, просп. Гагарина, д. 1	Россия, Оренбургская область, Оренбург, Гагарина проспект, 1	0101000020E6100000DB6E826F9A924B40958098840BE34940
68873	7	69	\N	1555	1275	\N	51.773994999999999	город Оренбург, просп. Гагарина, д. 15	Россия, Оренбургская область, Оренбург, Гагарина проспект, 15	0101000020E6100000AC1919E42E944B403E22A64412E34940
68872	7	69	\N	1555	1275	\N	51.773733	город Оренбург, просп. Гагарина, д. 13	Россия, Оренбургская область, Оренбург, Гагарина проспект, 13	0101000020E61000008236397CD2934B40016BD5AE09E34940
68868	7	69	\N	1555	1275	\N	51.772891999999999	город Оренбург, просп. Гагарина, д. 25	Россия, Оренбургская область, Оренбург, Гагарина проспект, 25	0101000020E61000005891D10149964B4086AB0320EEE24940
68867	7	69	\N	1555	1275	\N	51.772641	город Оренбург, просп. Гагарина, д. 27/1	Россия, Оренбургская область, Оренбург, Гагарина проспект, 27/1	0101000020E6100000CC79C6BE64974B403D4679E6E5E24940
68866	7	69	\N	1555	1275	\N	51.771419999999999	город Оренбург, просп. Гагарина, д. 45	Россия, Оренбургская область, Оренбург, Гагарина проспект, 45	0101000020E6100000F3E2C4573B984B407BBDFBE3BDE24940
68869	7	69	\N	1555	50170	\N	51.776406287637997	город Оренбург, просп. Гагарина, д. 44/4	Россия, Оренбургская область, Оренбург, Ленинский район	0101000020E610000041D47D0052974B408735954561E34940
68802	7	69	\N	1555	50208	\N	51.838881999999998	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Всесоюзная, 10/1		0101000020E61000005CC823B891904B40FE99417C60EB4940
68931	7	69	\N	1555	50092	\N	51.785207920331501	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Восточная, 82а	Россия, Оренбургская область, Оренбург, улица Восточная	0101000020E6100000F59D5F94A0934B405E471CB281E44940
68853	7	69	\N	1555	50092	\N	51.778854000000003	город Оренбург, ул. Восточная, д. 15		0101000020E61000007EFFE6C589934B40ED2DE57CB1E34940
68803	7	69	\N	1555	50199	\N	51.843646	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Волгоградская, 1		0101000020E6100000EFA99CF694904B405BB39597FCEB4940
68889	7	69	\N	1555	49873	\N	51.790036000000001	город Оренбург, пос. Ростоши, ул. Вечерняя, 6		0101000020E6100000DEE8633E209E4B40D2544FE61FE54940
68896	7	69	\N	1555	50086	\N	51.715072149692404	город Оренбург, ул. Весенняя, д. 18	Россия, Оренбургская область, Оренбург, улица Весенняя	0101000020E6100000A759A0DD218F4B408524B37A87DB4940
68810	7	69	\N	1555	50219	\N	51.832399000000002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Брестская, 3		0101000020E61000006ABDDF68C7914B408F1CE90C8CEA4940
68847	7	69	\N	1555	4204	\N	51.795060999999997	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, пр.Братьев Коростелевых, 28/1	Россия, Оренбургская область, Оренбург, Братьев Коростелевых проезд, 28/1	0101000020E61000000E30F31DFC884B409BA9108FC4E54940
68845	7	69	\N	1555	4204	\N	51.804172999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, пр.Братьев Коростелевых, 54	Россия, Оренбургская область, Оренбург, Братьев Коростелевых проезд, 54	0101000020E6100000A1F831E6AE874B40C1A90F24EFE64940
68844	7	69	\N	1555	4204	\N	51.801310000000001	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, пр.Братьев Коростелевых, 141	Россия, Оренбургская область, Оренбург, Братьев Коростелевых проезд, 141	0101000020E61000000C570740DC874B4098FA795391E64940
68829	7	69	\N	1555	4204	\N	51.791896999999999	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, пр.Братьев Коростелевых, 26/1		0101000020E6100000DBF7A8BF5E894B40776682E15CE54940
68800	7	69	\N	1555	50176	\N	51.830490404740303	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Братская, 8/1	Россия, Оренбургская область, Оренбург, улица Братская, 8	0101000020E61000007218CC5F218F4B40D8D30E7F4DEA4940
68863	7	69	\N	1555	49945	\N	51.790036000000001	город Оренбург, пос. Ростоши, ул. Березовая Ростошь, д. 2А		0101000020E6100000DEE8633E209E4B40D2544FE61FE54940
68898	7	69	\N	1555	50110	\N	51.727781410420903	город Оренбург, ул. Беляевская, д. 57/1	Россия, Оренбургская область, Оренбург, улица Беляевская	0101000020E61000009D9FE238F08E4B4039D384ED27DD4940
68848	7	69	\N	1555	50189	\N	51.798464000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Бебеля, 118		0101000020E6100000E71A66683C874B4045847F1134E64940
68828	7	69	\N	1555	50196	\N	51.787478999999998	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Астраханская, 1а		0101000020E6100000ECA2E8818F8B4B40B5A4A31CCCE44940
68915	7	69	\N	1555	50186	\N	51.772134000000001	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Аксакова, 3		0101000020E610000092955F06638E4B4099107349D5E24940
68797	7	69	\N	1555	3788	\N	51.786722845280799	город Оренбург, ул. 75 Линия, д. 2	Россия, Оренбургская область, Оренбург, 75-я линия	0101000020E61000003A083A5AD5964B406901DA56B3E44940
68814	7	69	\N	1555	50185	\N	51.829338	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, мкр. им. 70-летия ВЛКСМ, 12		0101000020E6100000488787307E924B403FAA61BF27EA4940
68871	7	69	\N	1555	4720	\N	51.7814576606944	город Оренбург, ул. 10 Линия, д. 22	Россия, Оренбургская область, Оренбург, 10-я линия	0101000020E6100000E0F2583332964B404A99D4D006E44940
68808	7	69	\N	1555	50210	\N	51.836328000000002	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, Юных Ленинцев, 10		0101000020E6100000DECCE847C3914B40535DC0CB0CEB4940
69581	7	69	\N	1555	50122	\N	51.714779	Оренбургская область, муниципальное образование ЗАТО поселок Комаровский, Южная, 20а		0101000020E6100000C095ECD808904B400D6FD6E07DDB4940
68838	7	69	\N	1555	50200	\N	51.790771999999997	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Химическая, 10		0101000020E610000095D8B5BDDD844B40D74B530438E54940
68935	7	69	\N	1555	50193	\N	51.795907999999997	Оренбургская область, муниципальное образование город Оренбург, Центральный район, Томилинская, 242		0101000020E61000006A6D1ADB6B914B40F84F3750E0E54940
69099	7	69	\N	1555	51363	\N	51.783082999999998	ул. Ленинградская, 20		0101000020E6100000C5C8923996914B40DB8651103CE44940
68830	7	69	\N	1555	50198	\N	51.787429000000003	Оренбургская область, муниципальное образование город Оренбург, Промышленный район, ул.Культурная, 21		0101000020E6100000739D465A2A894B4004763579CAE44940
69597	7	69	\N	1555	49703	\N	51.823775320497198	"ФОК - Физкультурно оздоровительный комплекс ""Дружба"", Ворошилова, 22"	Россия, Оренбургская область, Оренбург, улица Ворошилова, 22	0101000020E6100000037CB779E38A4B4096218E7571E94940
69596	7	69	\N	1555	49703	\N	51.823507237783502	"Муниципальное бюджетное учреждение культуры ""Центр культуры и досуга ""Дружба"", Ворошилова, 18"		0101000020E610000090DAC4C9FD8A4B40778368AD68E94940
68734	7	69	\N	9385	50039	\N	51.208404000000002	Оренбургская область, город Новотроицк, Черемных, 3 А		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68717	7	69	\N	9385	49742	\N	51.208404000000002	Оренбургская область, город Новотроицк, Фрунзе, 18		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68716	7	69	\N	9385	49742	\N	51.208404000000002	Оренбургская область, город Новотроицк, Фрунзе, 8		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68729	7	69	\N	9385	49850	\N	51.208404000000002	Оренбургская область, город Новотроицк, Уральская, 44		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68737	7	69	\N	9385	49848	\N	51.208404000000002	Оренбургская область, город Новотроицк, Уметбаева, 19		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68736	7	69	\N	9385	49848	\N	51.208404000000002	Оренбургская область, город Новотроицк, Уметбаева, 1		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68714	7	69	\N	9385	49925	\N	51.195877895693798	Оренбургская область, город Новотроицк, Советская, 38 А	Россия, Оренбургская область, Новотроицк	0101000020E6100000454AB3791C2A4D40C100C28712994940
68738	7	69	\N	9385	49746	\N	51.208404000000002	Оренбургская область, город Новотроицк, Северная, 11		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68739	7	69	\N	9385	50041	\N	51.208404000000002	Оренбургская область, город Новотроицк, Рудницкого, 46		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68720	7	69	\N	9385	49932	\N	51.208404000000002	Оренбургская область, город Новотроицк, Пушкина, 50		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68733	7	69	\N	9385	49846	\N	51.215113029115102	Оренбургская область, город Новотроицк, Орская, 4	Россия, Оренбургская область, Новотроицк	0101000020E61000001157CEDE19274D40E4F8A1D2889B4940
68731	7	69	\N	9385	49846	\N	51.208404000000002	Оренбургская область, город Новотроицк, Орская, 9		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68732	7	69	\N	9385	50038	\N	51.2070128815826	Оренбургская область, город Новотроицк, Мира, 14	Россия, Оренбургская область, Новотроицк	0101000020E610000065E1EB6B5D264D40666CE8667F9A4940
68728	7	69	\N	9385	49858	\N	51.208404000000002	Оренбургская область, город Новотроицк, Металлургов, 23		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68726	7	69	\N	9385	49858	\N	51.192439792898703	Оренбургская область, город Новотроицк, Металлургов, 9	Россия, Оренбургская область, Новотроицк	0101000020E610000038BF61A2412C4D409B38B9DFA1984940
68746	7	69	\N	9385	50040	\N	51.208404000000002	Оренбургская область, город Новотроицк, Марии Корецкой, 37		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68722	7	69	\N	9385	49842	\N	51.208404000000002	Оренбургская область, город Новотроицк, М.Корецкой, 37		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68727	7	69	\N	9385	49933	\N	51.208404000000002	Оренбургская область, город Новотроицк, Комсомольский, 10		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68725	7	69	\N	9385	49745	\N	51.208404000000002	Оренбургская область, город Новотроицк, Зеленая, 71 А		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68715	7	69	\N	9385	49929	\N	51.208404000000002	Оренбургская область, город Новотроицк, Горького, 34		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68735	7	69	\N	9385	50609	\N	51.208404000000002	Оренбургская область, город Новотроицк, Гвардеец труда, 1		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68724	7	69	\N	9385	50036	\N	51.208404000000002	Оренбургская область, город Новотроицк, Гагарина, 7 А		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68730	7	69	\N	9385	50049	\N	51.208404000000002	Оренбургская область, город Новотроицк, Воинов-Интернационалистов, 5		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68721	7	69	\N	9385	49744	\N	51.208404000000002	Оренбургская область, город Новотроицк, Советская, 80		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
68719	7	69	\N	9385	49744	\N	51.208404000000002	Оренбургская область, город Новотроицк, Советская, 64		0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
69546	7	69	1324	56200	51404	\N	53.039292594339102	с.Малослабодка, ул.Школьная, 13		0101000020E610000012143FC6DC614B401AFB928D07854A40
68713	7	69	\N	9385	49744	\N	51.200852576078603	Оренбургская область, город Новотроицк, Советская, 18	Россия, Оренбургская область, Новотроицк	0101000020E61000001975ADBD4F2B4D40D926158DB5994940
68712	7	69	\N	9385	49744	\N	51.2004885933856	Оренбургская область, город Новотроицк, Советская, 10	Россия, Оренбургская область, Новотроицк	0101000020E6100000CDE847C3292B4D40971AA19FA9994940
68723	7	69	\N	9385	49697	\N	51.208404000000002	Оренбургская область, город Новотроицк, Зеленая, 47 А	Россия, Оренбургская область, Новотроицк	0101000020E6100000583A1F9E252A4D40842D76FBAC9A4940
69299	7	69	\N	56164	51370	\N	51.712238999999997	с.Нижнее Челяево, ул.Центральная, 41б		0101000020E61000003B545392758E4B40C6F7C5A52ADB4940
68619	7	69	\N	4803	49924	\N	51.402543999999999	Оренбургская область, город Медногорск, пер. Коммунальный, 5	Россия, Оренбургская область, Медногорск	0101000020E6100000A1BE654E97CB4C40BB99D18F86B34940
68629	7	69	\N	4803	50011	\N	51.457752999999997	г.Медногорск,  улица Тульская, дом 17	Россия, Оренбургская область, Медногорск	0101000020E6100000B29DEFA7C6C94C40AC527AA697BA4940
68622	7	69	\N	4803	49739	\N	51.405875999999999	Оренбургская область, город Медногорск, Советская, 33	Россия, Оренбургская область, Медногорск	0101000020E6100000C0CE4D9B71CA4C409B1DA9BEF3B34940
68621	7	69	\N	4803	49739	\N	51.406171000000001	Оренбургская область, город Медногорск, Советская, 23	Россия, Оренбургская область, Медногорск	0101000020E610000021904B1C79CA4C40B4CA4C69FDB34940
68630	7	69	\N	4803	9918	\N	51.458269999999999	Оренбургская область, город Медногорск, Моторная, 52	Россия, Оренбургская область, Медногорск	0101000020E610000028B517D176CC4C40745E6397A8BA4940
68620	7	69	\N	4803	50479	\N	51.404747999999998	Оренбургская область, город Медногорск, Молодежная, 5	Россия, Оренбургская область, Медногорск	0101000020E61000001D1CEC4D0CCB4C408A8F4FC8CEB34940
68618	7	69	\N	4803	50292	\N	51.399782999999999	Оренбургская область, город Медногорск, Мало-Садовая, 1А	Россия, Оренбургская область, Медногорск	0101000020E6100000D575A8A624CB4C40963FDF162CB34940
68626	7	69	\N	4803	50605	\N	51.416660999999998	Оренбургская область, город Медногорск, Лесная, 34	Россия, Оренбургская область, Медногорск	0101000020E6100000BAD7497D59CA4C406342CC2555B54940
68624	7	69	\N	4803	49798	\N	51.406922999999999	Оренбургская область, город Медногорск, Комсомольская, 22	Россия, Оренбургская область, Медногорск	0101000020E6100000D13DEB1A2DCB4C40BF7E880D16B44940
68627	7	69	\N	4803	50612	\N	51.462096000000003	Оренбургская область, город Медногорск, Коминтерна, 50А	Россия, Оренбургская область, Медногорск	0101000020E61000006F9BA9108FC84C4064CE33F625BB4940
68625	7	69	\N	4803	50281	\N	51.413870000000003	Оренбургская область, город Медногорск, Ключевая, 40	Россия, Оренбургская область, Медногорск	0101000020E61000004DF6CFD380CB4C40D46531B1F9B44940
68617	7	69	\N	4803	80956	\N	51.396118000000001	Оренбургская область, муниципальное образование город Медногорск, Гагарина, 1	Россия, Оренбургская область, Медногорск	0101000020E6100000350A4966F5CC4C40B0AD9FFEB3B24940
68623	7	69	\N	4803	49737	\N	51.407003000000003	Оренбургская область, город Медногорск, Советская, 37	Россия, Оренбургская область, Медногорск	0101000020E61000006FD6E07D55CA4C40DC2F9FAC18B44940
68978	7	69	\N	49307	49950	\N	51.871223999999998	поселок Ленина, улица Ленинская, дом 31		0101000020E6100000459DB98784874B40C2BE9D4484EF4940
68556	7	69	\N	622	49832	\N	51.471527000000002	Оренбургская область,  город Кувандык, пр. Мира, д. 24а, здание СОШ №2		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68557	7	69	\N	622	49920	\N	51.471527000000002	Оренбургская область,  город Кувандык, Школьная, д.5, здание МЦКД		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68554	7	69	\N	622	49919	\N	51.471527000000002	Оренбургская область, город Кувандык, Фестивальная, д.9, здание нач. школы		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68497	7	69	\N	622	49919	\N	51.471527000000002	Оренбургская область, город Кувандык, Фестивальная, д.9, здание городской начальной школы		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68555	7	69	\N	622	49986	\N	51.471527000000002	"Оренбургская область,  город Кувандык, Строителей, д.9а, здание ДК""Криолит"""		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68496	7	69	\N	622	49986	\N	51.470961416228	"Оренбургская область, город Кувандык, Строителей, д. 9а, ДК ""Криолит"""	Россия, Оренбургская область, Кувандык	0101000020E61000001A6CEA3C2AAE4C408258367348BC4940
68550	7	69	\N	622	49734	\N	51.471527000000002	Оренбургская область,  город Кувандык, Северная, д.2а, здание начальной школы СОШ №5		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68553	7	69	\N	622	50358	\N	51.478780329721801	Оренбургская область,  город Кувандык, Сакмарская, д.1а, здание основной школы №4	Россия, Оренбургская область, Кувандык городской округ	0101000020E610000022C66B5ED5AF4C404CFDBCA948BD4940
68558	7	69	\N	622	50474	\N	51.471527000000002	Оренбургская область,  город Кувандык, С.Юлаева, д.58, здание школы №6		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68549	7	69	\N	622	50426	\N	51.471527000000002	"Оренбургская область, город Кувандык, Речная, д.15, здание клуба ""Дорожник"""		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68544	7	69	\N	622	50006	\N	51.471527000000002	Оренбургская область,  город Кувандык, Оренбургская, 20		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68552	7	69	\N	622	49917	\N	51.471527000000002	Оренбургская область,  город Кувандык, Молодёжная , д.11, здание СОШ №5		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68546	7	69	\N	622	49831	\N	51.471527000000002	Оренбургская область, город Кувандык, М. Жукова, д.19а, здание гимназии №1		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68545	7	69	\N	622	49831	\N	51.485663476369403	Оренбургская область,   город Кувандык, М. Жукова, д.19а, гимназия №1	Россия, Оренбургская область, Кувандык городской округ	0101000020E6100000B83EAC376AAB4C404AF086342ABE4940
68547	7	69	\N	622	49732	\N	51.471527000000002	Оренбургская область, город Кувандык, 20 лет Октября, д.4а, здание СОШ №1	Россия, Оренбургская область, Кувандык	0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68551	7	69	\N	622	49918	\N	51.471527000000002	Оренбургская область, город Кувандык, Молодёжная, д.11, здание СОШ №5		0101000020E6100000A983BC1E4CAE4C402B172AFF5ABC4940
68991	7	69	\N	49471	49875	\N	51.734544999999997	село им. 9 января, улица Центральная, дом 2		0101000020E6100000329067976F7D4B405C38109205DE4940
68330	7	69	\N	19668	49692	\N	51.461140999999998	город Гай, пр.Победы, 17		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68331	7	69	\N	19668	49726	\N	51.461140999999998	город Гай, пер.Парковый, 3		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68324	7	69	\N	19668	49788	\N	51.461140999999998	город Гай, пер.Школьный, 4		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68327	7	69	\N	19668	50000	\N	51.461140999999998	город Гай, Советская, 14 А		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
69600	7	69	\N	19668	49790	\N	51.461140999999998	город Гай, пер.Парковый, 6		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
69582	7	69	\N	19668	49977	\N	51.461140999999998	город Гай, ул.Октябрьская, 60		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68328	7	69	\N	19668	49977	\N	51.461140999999998	город Гай, Октябрьская, 60		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68334	7	69	\N	19668	49782	\N	51.461140999999998	город Гай, Молодежная, 10		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68332	7	69	\N	19668	49782	\N	51.463171627464497	город Гай, Молодежная, 73 А	Россия, Оренбургская область, Гай городской округ	0101000020E610000092CCEA1D6E374D402236583849BB4940
68325	7	69	\N	19668	49727	\N	51.461140999999998	город Гай, Ленина, 16		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68326	7	69	\N	19668	49819	\N	51.461140999999998	город Гай, Коммунистическая, 5		0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68335	7	69	\N	19668	50626	\N	51.467467762298099	г.Гай п.Калиновка, Калинина, 21	Россия, Оренбургская область, Гай городской округ	0101000020E6100000D49CBCC8043A4D4098F6CDFDD5BB4940
68333	7	69	\N	19668	49731	\N	51.461140999999998	город Гай, Декабристов, 10 А	Россия, Оренбургская область, Гай	0101000020E6100000AC3C81B053384D4020EC14AB06BB4940
68329	7	69	\N	19668	49983	\N	51.463647971991598	город Гай, Ленина, 43	Россия, Оренбургская область, Гай	0101000020E6100000B1E1E995B2384D408B6D52D158BB4940
68295	7	69	\N	19770	\N	\N	52.777102999999997	город Бузулук, ВТК-4		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68937	7	69	\N	19770	50216	\N	52.777102999999997	город Бузулук, Щорса, 72		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68938	7	69	\N	19770	49947	\N	51.761618983906601	город Бузулук, Челюскинцев, 52	Россия, Оренбургская область, Оренбург, улица Челюскинцев	0101000020E6100000529E7939EC8E4B4091813CBB7CE14940
68268	7	69	\N	19770	49718	\N	52.777102999999997	город Бузулук, Фрунзе, 100		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68283	7	69	\N	19770	49818	\N	52.777102999999997	город Бузулук, Суворова, 70		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68276	7	69	\N	19770	49720	\N	52.7933386280611	город Бузулук, Серго, 7	Россия, Оренбургская область, Бузулук городской округ	0101000020E61000009B012EC8961F4A4018D2E1218C654A40
68286	7	69	\N	19770	49721	\N	52.777102999999997	город Бузулук, Свердловская, 67	Россия, Оренбургская область, Бузулук	0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68273	7	69	\N	19770	49816	\N	52.777102999999997	город Бузулук, Рожкова, 57		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68272	7	69	\N	19770	50342	\N	52.796642343921199	город Бузулук, Пушкина, 60		0101000020E6100000B7ED7BD45F214A405D4F745DF8654A40
68939	7	69	\N	19770	50382	\N	52.761914716352003	город Бузулук, Объездная, 2	Россия, Оренбургская область, Бузулук	0101000020E6100000E6CB0BB08F204A407AAA436E86614A40
68359	7	69	\N	19770	49975	\N	52.777102999999997	город Бузулук, Московская, 2 А		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68279	7	69	\N	19770	49993	\N	52.777102999999997	город Бузулук, Мельничная, 1		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68275	7	69	\N	19770	50595	\N	52.777102999999997	город Бузулук, Максима Горького, 40		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68282	7	69	\N	19770	50495	\N	52.785052215718601	город Бузулук, Линейная, 1		0101000020E610000086376BF0BE1E4A4067D47C957C644A40
68287	7	69	\N	19770	49722	\N	52.777102999999997	город Бузулук, Лизы Чайкиной, 1		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68271	7	69	\N	19770	49992	\N	52.777102999999997	город Бузулук, Ленина, 60	Россия, Оренбургская область, Бузулук	0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68270	7	69	\N	19770	49902	\N	52.777102999999997	город Бузулук, Крестьянская, 46		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68277	7	69	\N	19770	49948	\N	52.777102999999997	город Бузулук, Кирова/Рожкова, 4/30		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
69607	7	69	\N	19770	49909	\N	52.777102999999997	город Бузулук, Заводская, 71		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68269	7	69	\N	19770	49815	\N	52.777102999999997	город Бузулук, Гая, 35А		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68267	7	69	7396	\N	49815	\N	52.800313204843498	город Бузулук, Гая, 94	Россия, Оренбургская область, Бузулук городской округ	0101000020E61000000C207C28D11C4A4026C808A870664A40
68266	7	69	\N	19770	49815	\N	52.777102999999997	город Бузулук, Гая, 83		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68274	7	69	\N	19770	49901	\N	52.777102999999997	город Бузулук, Галактионова, 35		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68284	7	69	\N	19770	49997	\N	52.759728365374599	город Бузулук, Вокзальная, 15		0101000020E61000000ABC934F8F234A4081ED60C43E614A40
68293	7	69	\N	19770	49964	\N	52.777102999999997	город Бузулук, 4 микрорайон, 14А		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68294	7	69	\N	19770	49725	\N	52.777102999999997	город Бузулук, 3 микрорайон, 17А	Россия, Оренбургская область, Бузулук	0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68292	7	69	\N	19770	49725	\N	52.777102999999997	город Бузулук, 3 микрорайон, 8а		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68291	7	69	\N	19770	49725	\N	52.777206630914399	город Бузулук, 3 микрорайон, 17Е	Россия, Оренбургская область, Бузулук	0101000020E6100000BF45274BAD1F4A40739CDB847B634A40
68280	7	69	\N	19770	49817	\N	52.7700819210012	город Бузулук, 3 Линия, 9		0101000020E6100000FDA02E5228234A40809E060C92624A40
68290	7	69	\N	19770	49724	\N	52.777102999999997	город Бузулук, 1 микрорайон, 28		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68289	7	69	\N	19770	49724	\N	52.777102999999997	город Бузулук, 1 микрорайон, 30		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68281	7	69	7394	\N	49719	\N	52.768129741175201	город Бузулук, 1 Линия, 16	Россия, Оренбургская область, Бузулук городской округ	0101000020E6100000A0C6BDF90D234A40CA89761552624A40
68278	7	69	\N	19770	49719	\N	52.777102999999997	город Бузулук, 1 Линия, 40		0101000020E6100000FE648C0FB31F4A40CE4F711C78634A40
68205	7	69	\N	16051	50268	\N	53.626498007152101	город Бугуруслан, пер.Щорса, 2	Россия, Оренбургская область, Бугуруслан	0101000020E61000000F5F268A90344A403481221631D04A40
68215	7	69	\N	16051	49971	\N	53.628704999999997	город Бугуруслан, пер.Электриков, 1		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68199	7	69	\N	16051	49889	\N	53.628704999999997	город Бугуруслан, Широкая, 8-А		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68194	7	69	\N	16051	49797	\N	53.628704999999997	город Бугуруслан, Челюскина, 41		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68200	7	69	\N	16051	49811	\N	53.655608861683902	город Бугуруслан, Чапаевская, 93	Россия, Оренбургская область, Бугуруслан	0101000020E6100000117008556A384A404CFBE6FEEAD34A40
68197	7	69	\N	16051	49811	\N	53.628704999999997	город Бугуруслан, Чапаевская, 42		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68210	7	69	\N	16051	49813	\N	53.628704999999997	город Бугуруслан, Строителей, 2		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68202	7	69	\N	16051	49890	\N	53.628704999999997	город Бугуруслан, Победная, 76		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68209	7	69	\N	16051	49812	\N	53.628704999999997	город Бугуруслан, Некрасова, 48		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68208	7	69	\N	16051	49812	\N	53.628704999999997	город Бугуруслан, Некрасова, 22		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68206	7	69	\N	16051	49812	\N	53.628704999999997	город Бугуруслан, Некрасова, 89-А		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68195	7	69	\N	16051	49979	\N	53.656163340340299	город Бугуруслан, Московская, 18-А	Россия, Оренбургская область, Бугуруслан	0101000020E6100000D578E92631364A4031EC3026FDD34A40
68203	7	69	\N	16051	49891	\N	53.628704999999997	город Бугуруслан, Ленинградская, 95-А		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68196	7	69	\N	16051	49958	\N	53.628704999999997	город Бугуруслан, Куйбышевская, 3		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68201	7	69	\N	16051	49715	\N	53.628704999999997	город Бугуруслан, Красногвардейская, 64		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68198	7	69	\N	16051	49712	\N	53.628704999999997	город Бугуруслан, Коммунистическая, 29-А		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68204	7	69	\N	16051	49892	\N	53.628704999999997	город Бугуруслан, Белинского, 54		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68214	7	69	\N	16051	49814	\N	53.6283985429138	город Бугуруслан, 3-й микрорайон, 5	Россия, Оренбургская область, Бугуруслан	0101000020E6100000A5F3E15982364A4068EBE0606FD04A40
68212	7	69	\N	16051	49716	\N	53.628704999999997	город Бугуруслан, 2-й микрорайон, 4	Россия, Оренбургская область, Бугуруслан	0101000020E61000006C06B8205B364A4074EACA6779D04A40
68211	7	69	\N	16051	49716	\N	53.628704999999997	город Бугуруслан, 2-й микрорайон, 11		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68213	7	69	\N	16051	49895	\N	53.628704999999997	город Бугуруслан, 1-й Микрорайон, 19-Б		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68193	7	69	\N	16051	49878	\N	53.628704999999997	город Бугуруслан, Геологов, 16		0101000020E61000006C06B8205B364A4074EACA6779D04A40
68001	7	69	\N	56183	51373	\N	51.709695000000004	п.Бикмурзино, Центральная (школа), 12		0101000020E61000008A9466F3388E4B403F912749D7DA4940
67938	7	69	\N	3235	49807	\N	53.679082000000001	город Абдулино, Школьная, 35		0101000020E6100000B519A721AAD24A40B1A6B228ECD64A40
67937	7	69	\N	3235	49789	\N	53.679082000000001	г. Абдулино, ул. Советская, д. 1		0101000020E6100000B519A721AAD24A40B1A6B228ECD64A40
67933	7	69	\N	3235	49789	\N	53.680047460415899	город Абдулино, Советская, 186	Россия, Оренбургская область, Абдулино	0101000020E6100000261E5036E5D24A40185FB4C70BD74A40
67939	7	69	\N	3235	49941	\N	53.679082000000001	город Абдулино, Снежинская, 4		0101000020E6100000B519A721AAD24A40B1A6B228ECD64A40
67935	7	69	\N	3235	49940	\N	53.675384619322799	город Абдулино, Пролетарская, 50	Россия, Оренбургская область, Абдулино	0101000020E61000005DC47762D6D34A40BF9A030473D64A40
67932	7	69	\N	3235	49805	\N	53.692020686989601	город Абдулино, Коммунистическая, 85	Россия, Оренбургская область, Абдулино	0101000020E61000002786E464E2D24A409692E52494D84A40
67931	7	69	\N	3235	49805	\N	53.679082000000001	город Абдулино, Коммунистическая, 230		0101000020E6100000B519A721AAD24A40B1A6B228ECD64A40
67936	7	69	\N	3235	49708	\N	53.679082000000001	город Абдулино, Комарова, 27 А		0101000020E6100000B519A721AAD24A40B1A6B228ECD64A40
67930	7	69	\N	3235	49705	\N	53.679082000000001	город Абдулино, Заводская, 2	Россия, Оренбургская область, Абдулино	0101000020E6100000B519A721AAD24A40B1A6B228ECD64A40
67934	7	69	\N	3235	49707	\N	53.679082000000001	город Абдулино, Чкалова, 191		0101000020E6100000B519A721AAD24A40B1A6B228ECD64A40
69578	7	69	7393	58203	66966	\N	51.035411538765402	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование городское поселение город Ясный, Западная, 15	Россия, Оренбургская область, Ясный городской округ	0101000020E61000000CACE3F8A1EE4D4067F1626188844940
69580	7	69	1545	58901	66970	\N	51.033815041621402	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование городское поселение город Ясный, Ленина, 16	Россия, Оренбургская область, Ясный городской округ	0101000020E6100000C845B58828F04D409F8EC70C54844940
69570	7	69	1545	19027	50831	\N	51.223523999999998	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Комаровский сельсовет, с.Тыкаша, Центральная, 27а		0101000020E6100000E964A9F57E0F4E4080EF366F9C9C4940
69571	7	69	1545	19090	51156	\N	51.256076999999998	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Комаровский сельсовет, с.Ореховка, Школьная, 14а		0101000020E610000037C64E7809284E40FF209221C7A04940
69572	7	69	1545	19136	50239	\N	51.068702999999999	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Новосельский сельсовет, п.Новосельский, Набережная, 3		0101000020E6100000C13BF9F4D8084E408C118942CB884940
69558	7	69	1545	18381	51089	\N	51.167237999999998	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Кумакский сельсовет, п.Кумак, Школьная, 3а		0101000020E61000008D7E349C32114E400053060E68954940
69567	7	69	1545	18846	51015	\N	50.967931	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Еленовский сельсовет, с.Котансу, Новая, 21		0101000020E6100000A8FC6B79E5104E406DE4BA29E57B4940
69569	7	69	1545	18992	50242	\N	51.189627000000002	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Комаровский сельсовет, п.Комарово, Центральная, 4		0101000020E610000009A69A594B0B4E4024B891B245984940
69568	7	69	1545	18921	51004	\N	50.937483	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Еленовский сельсовет, с.Керуембай, Школьная, 1б		0101000020E61000004A253CA1D7134E402AC76471FF774940
69565	7	69	1545	18748	50435	\N	50.896994999999997	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Еленовский сельсовет, с.Еленовка, Пролетарская, 5		0101000020E61000001EFAEE5696E44D4077D66EBBD0724940
69563	7	69	1545	18670	50879	\N	50.966127	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Веселовский сельсовет, п.Веселовский, Садовая, 18		0101000020E6100000E57CB1F7E2314E402C64AE0CAA7B4940
69566	7	69	1545	18815	50823	\N	50.90446	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Еленовский сельсовет, с.Верхний Киембай, Центральная, 25а		0101000020E610000057957D5704F14D4024456458C5734940
69559	7	69	1545	18445	50826	\N	51.101546999999997	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Акжарский сельсовет, с.Акжарское, Советская, 7а		0101000020E6100000A52F849CF7B34D40E200FA7DFF8C4940
69524	7	69	1324	16686	50829	\N	52.9804397313614	с.Ялчкаево, ул.Центральная, 64	Россия, Оренбургская область, Шарлыкский район, село Ялчкаево	0101000020E61000006BD784B4C6764B405AD8D30E7F7D4A40
69528	7	69	1324	16904	50854	\N	52.581764	с.Юзеево, ул.Советская, 14		0101000020E61000005B9885764E854B40BDFE243E774A4A40
69555	7	69	1324	18115	49779	\N	52.922272999999997	с.Шарлык, ул.Советская, 27А	Россия, Оренбургская область, Шарлыкский район, село Шарлык	0101000020E61000002E573F36C95F4B40ED7DAA0A0D764A40
69552	7	69	1324	18115	49779	\N	52.922272999999997	с.Шарлык, ул.Советская, 18		0101000020E61000002E573F36C95F4B40ED7DAA0A0D764A40
69553	7	69	1324	18115	49736	\N	52.922272999999997	с.Шарлык, ул.Родимцева, 4	Россия, Оренбургская область, Шарлыкский район, село Шарлык	0101000020E61000002E573F36C95F4B40ED7DAA0A0D764A40
69554	7	69	1324	18115	49780	\N	52.922272999999997	с.Шарлык, ул.Калининская, 66	Россия, Оренбургская область, Шарлыкский район, село Шарлык	0101000020E61000002E573F36C95F4B40ED7DAA0A0D764A40
69532	7	69	1324	46827	50852	\N	52.899290999999998	пос.Урняк, ул.Мира, 4А		0101000020E6100000FEB7921D1B3B4B40274BADF71B734A40
69549	7	69	1324	47179	51323	\N	52.790745999999999	с.Титовка, ул.Молодежная, 7		0101000020E6100000C382FB010F5A4B40AEB8382A37654A40
69547	7	69	1324	17852	51202	\N	52.801091999999997	с.Слоновка ул.Клубная д.9		0101000020E6100000417DCB9C2EA74B402A8BC22E8A664A40
69544	7	69	1324	17708	50238	\N	53.090926000000003	с.Сарманай, ул.Школьная, 6		0101000020E6100000C9ACDEE176504B40952D9276A38B4A40
69519	7	69	1324	56150	51157	\N	52.679718000000001	с.Романовка, ул.Молодежная, 10	Россия, Оренбургская область, Шарлыкский район, село Романовка	0101000020E6100000CD5B751DAA994B405340DAFF00574A40
68127	7	69	1324	46312	50897	\N	52.847791000000001	с. Рождественка, Школьная, 5		0101000020E6100000BE66B96C744C4B40EC6B5D6A846C4A40
69526	7	69	1324	46312	51153	\N	52.847791000000001	с.Рождественка, ул.Молодежная, 8А	Россия, Оренбургская область, Шарлыкский район, село Рождественка	0101000020E6100000BE66B96C744C4B40EC6B5D6A846C4A40
69543	7	69	1324	17611	50828	\N	53.055039999999998	с.Ратчино, ул.Советская, 26		0101000020E61000002EC6C03A8E3B4B4065FCFB8C0B874A40
69542	7	69	1324	17611	50828	\N	53.055039999999998	с.Ратчино, ул.Советская, 10А		0101000020E61000002EC6C03A8E3B4B4065FCFB8C0B874A40
69538	7	69	1324	46949	50410	\N	53.139580000000002	с.Путятино, ул.Мира, 34		0101000020E6100000E161DA37F7634B407D96E7C1DD914A40
69556	7	69	1324	32504	50859	\N	52.893819999999998	пос.Приветливый, ул.Школьная, 2		0101000020E6100000E738B709F75E4B405F419AB168724A40
68252	7	69	1324	14080	\N	\N	52.886946999999999	с.Преображенка, ул.Мира, 1	Россия, Оренбургская область, Шарлыкский район, село Преображенка	0101000020E61000000F4240BE84804B408524B37A87714A40
69470	7	69	1324	14080	51327	\N	52.886946999999999	с. Преображенка, пер. Школьный, 8		0101000020E61000000F4240BE84804B408524B37A87714A40
69535	7	69	1324	14080	51331	\N	52.886946999999999	с.Преображенка, пер.Школьный, 4		0101000020E61000000F4240BE84804B408524B37A87714A40
68684	7	69	1324	58162	64073	\N	52.77528262741	"с.Покровка, Красноармейская  (здание ДК ""Юность""), 1А"	Россия, Оренбургская область, Шарлыкский район, село Покровка	0101000020E61000006D59BE2EC3A34B4088122D793C634A40
69545	7	69	1324	47094	51013	\N	53.019351999999998	пос.Перовка, ул.Школьная, 2		0101000020E6100000A25EF0694E584B405C8E57207A824A40
69534	7	69	1324	46863	51325	\N	52.788469999999997	с.Парадеево, ул.Парадеевская, 38А		0101000020E61000005CE509849D904B4045F0BF95EC644A40
69529	7	69	1324	16963	50877	\N	52.748815999999998	с.Новоникольское, пер.Культурный, 11		0101000020E61000005B7C0A80F1684B405B5CE333D95F4A40
69530	7	69	1324	16983	50436	\N	52.922967999999997	с.Новомусино, ул.Школьная, 1		0101000020E61000006D8D08C6C1354B4094A0BFD023764A40
69533	7	69	1324	56205	51414	\N	52.915029364977997	с.Новоархангельское, ул.Родимцева, 20	Россия, Оренбургская область, Шарлыкский район, село Новоархангеловка	0101000020E6100000888043A8526F4B401FF296AB1F754A40
69551	7	69	1324	47216	50857	\N	52.834708999999997	с.Мустафино, ул.Верхняя, 36		0101000020E610000010035DFB02644B40A35698BED76A4A40
69523	7	69	1324	46645	50821	\N	52.955351	с.Константиновка, ул.Центральная, 45А		0101000020E61000008577B988EF7C4B40B7990AF1487A4A40
69522	7	69	1324	16596	51098	\N	52.706997000000001	с.Колычево, ул.Средняя, 19		0101000020E61000002E01F8A7546F4B4060AFB0E07E5A4A40
69557	7	69	1324	18348	50999	\N	52.966428000000001	с.Кармалка, пер.Библиотечный, 1	Россия, Оренбургская область, Шарлыкский район, село Кармалка	0101000020E6100000EA3C2AFEEF584B4027F8A6E9B37B4A40
69525	7	69	1324	16761	51152	\N	52.881681999999998	с.Илькульган, ул.Новая, 11		0101000020E6100000F705F4C29D474B4066BCADF4DA704A40
69539	7	69	1324	56120	50847	\N	53.208041000000001	с.Изяк-Никитино, ул.Мира, 36	Россия, Оренбургская область, Шарлыкский район, село Изяк-Никитино	0101000020E6100000ABED26F8A6714B40139D6516A19A4A40
69541	7	69	1324	47019	51155	\N	53.213073000000001	с.Зобово, ул.Школьная, 8		0101000020E6100000B4226AA2CF554B408F54DFF9459B4A40
69540	7	69	1324	16521	61844	\N	52.6711167098033	с.Зирекло, ул.Центральная, 22	Россия, Оренбургская область, Шарлыкский район, село Зеркло	0101000020E6100000DD5CFC6D4F764B4013656F29E7554A40
69521	7	69	1324	16521	50824	\N	52.671615000000003	с.Зеркло, ул.Салмыш, 2		0101000020E610000087C5A86BED754B406440F67AF7554A40
69520	7	69	1324	46582	51322	\N	53.109222000000003	с.Дубровка, ул.Школьная, 8		0101000020E6100000C3F17C06D4454B407A008BFCFA8D4A40
69537	7	69	1324	46945	50723	\N	52.846774000000003	пос.Вишневка, ул.Советская, 9, 1		0101000020E6100000AFB2B6291E7B4B40338D2617636C4A40
69518	7	69	1324	46547	51104	\N	52.708972000000003	с.Богородское, ул.Молодежная, 1		0101000020E61000007DE9EDCF45874B40CEE33098BF5A4A40
69550	7	69	1324	17996	51324	\N	52.833044999999998	с.Бараково, ул.Новая, 3		0101000020E61000000E828E56B5544B40548CF337A16A4A40
69491	7	69	748	14996	49777	\N	52.345382000000001	п. Тюльган, ул. Октябрьская, 1 (здание библиотеки)	Россия, Оренбургская область, Тюльганский район, поселок Тюльган	0101000020E61000004F5C8E5720144C404450357A352C4A40
69490	7	69	748	14996	49735	\N	52.345382000000001	п. Тюльган, ул. М.Горького, 9 (здание дома культуры)		0101000020E61000004F5C8E5720144C404450357A352C4A40
69489	7	69	748	14996	49735	\N	52.345382000000001	п. Тюльган, ул. М.Горького, 20 (здание школы №1)		0101000020E61000004F5C8E5720144C404450357A352C4A40
69500	7	69	748	15525	\N	\N	52.555622	село Тугустемир, здание школы	Россия, Оренбургская область, Тюльганский район, село Тугустемир	0101000020E6100000D5230D6E6B0B4C401478279F1E474A40
69493	7	69	748	45989	80944	\N	52.325578	с. Троицкое, здание сельсовета	Россия, Оренбургская область, Тюльганский район, село Троицкое	0101000020E61000007B4FE5B4A7304C400726378AAC294A40
69497	7	69	748	12374	\N	\N	52.409258999999999	село Ташла, здание школы	Россия, Оренбургская область, Тюльганский район, село Ташла	0101000020E6100000E5417A8A1C1E4C40FD4B529962344A40
69433	7	69	748	12374	49774	\N	52.409258999999999	село Ташла, Довженко, 50		0101000020E6100000E5417A8A1C1E4C40FD4B529962344A40
69508	7	69	748	46347	\N	\N	52.319290000000002	с. Стретинка, здание ФАП	Россия, Оренбургская область, Тюльганский район, село Стретинка	0101000020E6100000E694809884FF4B404DF8A57EDE284A40
69496	7	69	748	15313	\N	\N	52.364490000000004	село Рудное, здание клуба	Россия, Оренбургская область, Тюльганский район, село Рудное	0101000020E6100000806264C91C2D4C400ADCBA9BA72E4A40
69509	7	69	748	15928	\N	\N	52.281914	с. Репьевка, здание школы	Россия, Оренбургская область, Тюльганский район, село Репьевка	0101000020E6100000C382FB010F1E4C406C2409C215244A40
69502	7	69	748	46187	80953	\N	52.482627999999998	село Разномойка, здание школы	Россия, Оренбургская область, Тюльганский район, село Разномойка	0101000020E6100000AD31E884D0EF4B4023111AC1C63D4A40
68349	7	69	748	46124	\N	\N	52.372233000000001	п.Подлесный, Центральная, 38	Россия, Оренбургская область, Тюльганский район, село Подлесный	0101000020E6100000E789E76C01174C40F9BEB854A52F4A40
69499	7	69	748	15479	\N	\N	52.448542000000003	село Новосергиевка, здание школы	Россия, Оренбургская область, Тюльганский район, село Новосергиевка	0101000020E61000006CB41CE8A1084C40F47002D369394A40
69516	7	69	748	14415	\N	\N	52.355893999999999	с.Нововасильевка, здание сельсовета	Россия, Оренбургская область, Тюльганский район, село Нововасильевка	0101000020E6100000FA47DFA4690E4C40DB6B41EF8D2D4A40
69494	7	69	748	62031	80945	\N	52.405723999999999	с. Николаевка, здание ФАП	Россия, Оренбургская область, Тюльганский район, село Николаевка	0101000020E6100000C8073D9B55354C40E59997C3EE334A40
69510	7	69	748	62041	80975	\N	52.287671000000003	с. Козловка, здание ФАП	Россия, Оренбургская область, Тюльганский район, село Козловка	0101000020E6100000C504357C0B194C40FA804067D2244A40
69511	7	69	748	46391	80979	\N	52.180455000000002	с. Ключи, здание школы	Россия, Оренбургская область, Тюльганский район, село Ключи	0101000020E6100000EE5F5969520C4C4029B3412619174A40
69501	7	69	748	62036	80949	\N	52.501337999999997	х. Калинин, здание клуба	Россия, Оренбургская область, Тюльганский район, село Калининский	0101000020E6100000C7D45DD905034C40FB1EF5D72B404A40
69495	7	69	748	62033	80946	\N	52.325409999999998	село Ивановка, здание школы	Россия, Оренбургская область, Тюльганский район, село Ивановка	0101000020E6100000EF5696E82C274C404BE5ED08A7294A40
69506	7	69	748	46290	80970	\N	52.284036	с. Екатеринославка, здание сельсовета	Россия, Оренбургская область, Тюльганский район, село Екатеринославка	0101000020E610000056F2B1BB40054C407E71A94A5B244A40
69254	7	69	748	46435	64181	\N	52.2139641113042	с.Екатериновка, ул.Школьная, 2	Россия, Оренбургская область, Тюльганский район, село Екатериновка	0101000020E61000002D05A4FD0FE24B40BB421F2C631B4A40
69513	7	69	748	46435	80982	\N	52.212246999999998	с. Екатериновка, здание школы	Россия, Оренбургская область, Тюльганский район, село Екатериновка	0101000020E610000037C30DF8FCE24B4049D6E1E82A1B4A40
69504	7	69	748	15703	\N	\N	52.374541999999998	с. Давлеткулово, здание клуба	Россия, Оренбургская область, Тюльганский район, село Давлеткулово	0101000020E610000067994528B6044C403D7D04FEF02F4A40
69498	7	69	748	15425	\N	\N	52.466124999999998	с. Городки, здание школы	Россия, Оренбургская область, Тюльганский район, село Городки	0101000020E6100000B47405DB88114C408B6CE7FBA93B4A40
69503	7	69	748	46206	80958	\N	52.351388999999998	с. Владимировка, здание школы	Россия, Оренбургская область, Тюльганский район, село Владимировка	0101000020E61000001A1538D906024C404A969350FA2C4A40
69512	7	69	748	16076	\N	\N	52.207312000000002	с. Благодарное, здание школы	Россия, Оренбургская область, Тюльганский район, село Благодарное	0101000020E610000081ED60C43EE94B40C0081A33891A4A40
69515	7	69	748	46485	80984	\N	52.193156999999999	с. Благовещенка, здание дома культуры	Россия, Оренбургская область, Тюльганский район, село Благовещенка	0101000020E6100000933655F7C8FA4B402AFF5A5EB9184A40
69507	7	69	748	15836	\N	\N	52.298819000000002	с. Аустяново, здание ФАП	Россия, Оренбургская область, Тюльганский район, село Аустяново	0101000020E6100000D4282499D50D4C40333674B33F264A40
69514	7	69	748	16198	\N	\N	52.197508999999997	с. Астрахановка, здание школы	Россия, Оренбургская область, Тюльганский район, село Астрахановка	0101000020E6100000BF4351A04FDA4B4034D593F947194A40
69492	7	69	748	15134	\N	\N	52.550047999999997	с. Алмала, здание сельсовета	Россия, Оренбургская область, Тюльганский район, село Алмала	0101000020E6100000605969520A2E4C40779D0DF967464A40
69505	7	69	748	46250	80963	\N	52.360086000000003	с. Алабердино, здание школы	Россия, Оренбургская область, Тюльганский район, село Алабердино	0101000020E61000005F97E13FDDF84B40ADDF4C4C172E4A40
68149	7	69	748	46763	50586	\N	52.202106999999998	с. Аксаково, пер. Аксаковский, 18		0101000020E6100000C6A6954220FD4B4076A565A4DE194A40
69454	7	69	1258	13158	49906	\N	52.546461000000001	с Тоцкое Второе, ул. Победы, 6 А		0101000020E6100000992842EA766A4A400DC51D6FF2454A40
69453	7	69	1258	13158	49906	\N	52.546461000000001	с. Тоцкое Второе, ул. Победы, 6 А		0101000020E6100000992842EA766A4A400DC51D6FF2454A40
69452	7	69	1258	13158	49776	\N	52.546461000000001	с. Тоцкое Второе, ул. Жукова, 1		0101000020E6100000992842EA766A4A400DC51D6FF2454A40
69451	7	69	1258	13158	49776	\N	52.546461000000001	с. Тоцкое Второе, ул. Жукова, 4	Россия, Оренбургская область, Тоцкий район, село Тоцкое Второе	0101000020E6100000992842EA766A4A400DC51D6FF2454A40
69448	7	69	1258	13014	50075	\N	52.523169000000003	с. Тоцкое, ул. Терешковой, 5		0101000020E6100000E1606F6248604A40F9A3A833F7424A40
69449	7	69	1258	13014	9890	\N	52.523169000000003	с. Тоцкое, ул. Красная Площадь, 1 б		0101000020E6100000E1606F6248604A40F9A3A833F7424A40
69447	7	69	1258	13014	9890	\N	52.523169000000003	Тоцкое, Красная Площадь, 1 б		0101000020E6100000E1606F6248604A40F9A3A833F7424A40
69479	7	69	1258	14497	50235	\N	52.430162000000003	п. Суворовский, ул. Победы, 9		0101000020E6100000D45FAFB0E0324A40B1FD648C0F374A40
69474	7	69	1258	45617	50816	\N	52.162106000000001	п. Свердлово, ул. Мира, 8		0101000020E610000023111AC1C6254A40213EB0E3BF144A40
69462	7	69	1258	13714	50837	\N	52.236320999999997	д. Сайфутдиново, ул. Парковая, 2		0101000020E610000046072461DF4A4A40D32D3BC43F1E4A40
69472	7	69	1258	14193	50815	\N	52.153779999999998	с. Саиновка, ул. Центральная, 21		0101000020E610000074B2D47ABF394A40B2632310AF134A40
69466	7	69	1258	13893	51074	\N	52.087090483521898	п. Рябинный, ул. Рябинная, 44	Россия, Оренбургская область, Тоцкий район, село Рябинный	0101000020E61000002592E86514614A4082E7DEC3250B4A40
69459	7	69	1258	56189	51382	\N	52.305794283205898	с. Приютиное, ул. Советская, 7	Россия, Оренбургская область, Тоцкий район, село Приютное	0101000020E6100000390D51853F514A4011A8FE4124274A40
69455	7	69	1258	49542	49907	\N	52.505631999999999	п. Пристанционный, ул. 2-я линия, 58		0101000020E61000003317B83CD6664A40D1E7A38CB8404A40
69486	7	69	1258	14813	51348	\N	52.616955108126199	станция Погоромное, ул. Элеваторная, 14	Россия, Оренбургская область, Тоцкий район, село Погромное	0101000020E6100000D28E1B7E373F4A40450DA661F84E4A40
69485	7	69	1258	14813	50247	\N	52.605003000000004	с. Погромное, ул. Ленина, 28		0101000020E6100000B20E4757E9404A40AF7D01BD704D4A40
69450	7	69	1258	49454	51312	\N	52.570183999999998	пос. Первое Мая, ул. Майская, 34 а		0101000020E610000053B3075A814F4A40EA5910CAFB484A40
69457	7	69	1258	56185	51375	\N	52.408068536224903	с. Павло-Антоновска, ул. Центральная, 5 Б	Россия, Оренбургская область, Тоцкий район, село Павло-Антоновка	0101000020E6100000DF8B2FDAE3594A4076C1E09A3B344A40
69477	7	69	1258	45684	50853	\N	52.100569999999998	с. Нововасильевка, ул. Центральная, 1 а		0101000020E6100000F3E49A0299174A40B77A4E7ADF0C4A40
69531	7	69	1258	46022	51326	\N	52.134734999999999	с.Николаевка, ул.Шоссейная, 3		0101000020E6100000E90AB6114F464A40335019FF3E114A40
69458	7	69	1258	13524	50813	\N	52.322875000000003	с. Невежкино, ул. Центральная, 2		0101000020E6100000280D350A49644A4017D9CEF753294A40
69475	7	69	1258	45639	50817	\N	52.158166999999999	п. Набережный, ул. Центральная, 13		0101000020E6100000F451465C00224A403927F6D03E144A40
69468	7	69	1258	13977	50660	\N	52.099933999999998	с. Мулюково, 1-я сторона, 1		0101000020E6100000CF656A12BC5D4A4015E126A3CA0C4A40
69460	7	69	1258	45361	51321	\N	52.351692	с. Марковка, ул. Новая, 7		0101000020E61000002BC3B81B44554A40E621533E042D4A40
69473	7	69	1258	14205	\N	\N	52.257406000000003	с. Мананниково, ул. Центральная, 18	Россия, Оренбургская область, Тоцкий район, село Мананниково	0101000020E610000094DE37BEF6384A40A8E507AEF2204A40
69467	7	69	1258	13951	51318	\N	52.161349000000001	с. Малая Ремизенка, ул. Нахаловка, 165		0101000020E61000001CD0D2156C614A40041F8315A7144A40
69476	7	69	1258	14356	50820	\N	52.161088999999997	с. Любимовка, ул. Центральная, 25		0101000020E6100000CAA99D616A2F4A40675F79909E144A40
69482	7	69	1258	14656	51076	\N	52.372579000000002	с. Логачевка, ул. Большой Плант, 1 А		0101000020E6100000FF942A51F62A4A4094162EABB02F4A40
69478	7	69	1258	14474	50846	\N	52.171745000000001	с. Кызыл-Мечеть, ул. Центральная, 5		0101000020E610000062DA37F757274A4032207BBDFB154A40
69464	7	69	1258	13808	51079	\N	52.215352000000003	с. Ковыляевка, ул. Центральная, 1 В		0101000020E61000006B2920ED7F5C4A40699082A7901B4A40
69481	7	69	1258	56117	50818	\N	52.395609999999998	с. Казанка, ул. Казанская, 6	Россия, Оренбургская область, Тоцкий район, село Казанка	0101000020E6100000862172FA7A3A4A403BFC3559A3324A40
69483	7	69	1258	14715	51078	\N	52.450814999999999	с. Злобинка, ул. Центральная, 15		0101000020E61000005B5F24B4E5324A40EBC5504EB4394A40
69471	7	69	1258	14132	51175	\N	52.109149000000002	п. Задорожный, ул.Школьная, 14		0101000020E6100000A87004A9143B4A4010B22C98F80D4A40
69487	7	69	1258	14869	50849	\N	52.527020999999998	с. Жидиловка, ул. Мира, 10		0101000020E6100000C07ADCB75A3B4A4011A7936C75434A40
69480	7	69	1258	45717	50851	\N	52.280715027598603	п. Дружный, ул. Дружнинская, 11	Россия, Оренбургская область, Тоцкий район, село Дружный	0101000020E6100000562B137EA92F4A40923F1878EE234A40
69465	7	69	1258	13853	50433	\N	52.111262000000004	п. Верхнебузулукский, ул. Молодёжная, 26		0101000020E6100000199128B4AC534A40CFA44DD53D0E4A40
69469	7	69	1258	14045	51077	\N	52.105316000000002	с. Большая Ремизенка, ул. Центральная, 1		0101000020E610000041B96DDFA3564A406EDFA3FE7A0D4A40
69461	7	69	1258	45368	50540	\N	52.181873962845103	с. Богдановка, пер. Парковый, 2	Россия, Оренбургская область, Тоцкий район, село Богдановка	0101000020E6100000C0B2D2A414504A4011FFB0A547174A40
69463	7	69	1258	13724	51319	\N	52.133319	с. Амерханово, ул. Школьная, 1		0101000020E6100000D6C6D8092F4D4A40BC77D49810114A40
69443	7	69	1156	49363	50533	\N	51.718125999999998	поселок Ясная Поляна, Комарова, 14		0101000020E61000006D585359148A4A402234828DEBDB4940
69409	7	69	1156	11227	50997	\N	51.762819999999998	село Шумаево, Центральная, 48/2		0101000020E6100000DA3C0E83F96F4A400B5EF415A4E14940
69419	7	69	1156	49035	50810	\N	51.988185000000001	село Широкое, Подгорная, 2		0101000020E6100000B6300BED9C544A40EAB298D87CFE4940
69441	7	69	1156	12764	50993	\N	52.080554999999997	село Шестаковка, Молодежная, 4		0101000020E61000002DCE18E6046F4A40BF4351A04F0A4A40
69408	7	69	1156	25520	50862	\N	51.796889017040499	с. Чернышовка, ул. Нагорная, 11/2	Россия, Оренбургская область, Ташлинский район, село Чернышовка	0101000020E6100000C44142942F784A4065C5707500E64940
69438	7	69	1156	12602	50253	\N	51.899557999999999	село Черноярово, Советская, 15		0101000020E6100000E469F981AB564A40766D6FB724F34940
69440	7	69	1156	12705	51072	\N	51.869345000000003	село Чеботаревка, Школьная, 3		0101000020E610000012143FC6DC574A4077F86BB246EF4940
69432	7	69	1156	49229	50071	\N	51.764175000000002	село Ташла, Советская, 113А		0101000020E6100000CFF753E3A55F4A40DDB5847CD0E14940
68487	7	69	1156	46279	51081	\N	51.766069999999999	поселок Степной, Горная, 1/1		0101000020E6100000300F99F221424A402E39EE940EE24940
69426	7	69	1156	56143	51068	\N	52.066914683678199	село Степановка, Советская, 24/1	Россия, Оренбургская область, Ташлинский район, село Степановка	0101000020E6100000FC1BB4571F854A40514EB4AB90084A40
69446	7	69	1156	49405	51320	\N	51.802402000000001	поселок Солнечный, Восточная, 8а		0101000020E610000047E7FC14C7814A405C1FD61BB5E64940
69423	7	69	1156	11890	50404	\N	51.494439	село Раннее, Набережная, 7		0101000020E61000004D309C6B984D4A40F86EF3C649BF4940
69425	7	69	1156	11985	51067	\N	51.683005000000001	село Пустобаево, Центральная, 35Б		0101000020E61000000647C9AB73344A40930035B56CD74940
69414	7	69	1156	56201	51402	\N	51.855941808366097	село Прокуроновка, Школьная, 1	Россия, Оренбургская область, Ташлинский район, село Прокуронка	0101000020E6100000817A336ABE6E4A40ECA2E8818FED4940
69421	7	69	1156	49061	50401	\N	51.883578	поселок Придолинный, Центральная, 3		0101000020E61000006D753925209A4A4088BB7A1519F14940
69418	7	69	1156	11613	51234	\N	51.944992999999997	село Новосельное, Центральная, 27		0101000020E61000001C075E2D77604A4076F9D687F5F84940
69417	7	69	1156	11604	50995	\N	51.928007999999998	село Новокаменка, Центральная, 26А		0101000020E6100000F75AD07B635A4A40933655F7C8F64940
69424	7	69	1156	11915	51070	\N	51.650773000000001	село Мирошкино, Школьная, 12	Россия, Оренбургская область, Ташлинский район, село Мирошкино	0101000020E6100000B7EEE6A90E3D4A40560F98874CD34940
69403	7	69	1156	48756	50806	\N	51.934933000000001	село Майское, Школьная, 24		0101000020E610000012BC218D0A764A40C07971E2ABF74940
69427	7	69	1156	12105	51313	\N	52.089753000000002	село Курташка, Дружбы, 8		0101000020E6100000B39AAE27BA7E4A40E4DBBB067D0B4A40
69436	7	69	1156	49283	51314	\N	51.645364000000001	село Кузьминка, Центральная, 18		0101000020E61000001327F73B14534A4004029D499BD24940
69422	7	69	1156	56154	51196	\N	51.874693999999998	п. Криницы, ул. Молодежная, 2/1	Россия, Оренбургская область, Ташлинский район, село Криница	0101000020E610000001F8A75489884A40F30016F9F5EF4940
69412	7	69	1156	48912	50812	\N	51.828214000000003	село Коммуна, Коммунаров, 5		0101000020E61000003D65355D4F5C4A40700B96EA02EA4940
69415	7	69	1156	11513	49905	\N	51.6233159874417	село Кинделя, Молодежная, 1	Россия, Оренбургская область, Ташлинский район, село Кинделя	0101000020E610000096218E75717F4A406A8995D1C8CF4940
69413	7	69	1156	11411	51317	\N	51.822079000000002	село Кандалинцево, Молодежная, 10		0101000020E61000001F85EB51B84E4A403CDD79E239E94940
69428	7	69	1156	12104	50991	\N	52.089022999999997	село Каменноимангулово, Дружбы, 16		0101000020E6100000178046E9D2754A40C0CB0C1B650B4A40
69411	7	69	1156	48901	50530	\N	51.848269000000002	поселок Калинин, Центральная, 7		0101000020E6100000C19140834D5B4A40F69A1E1494EC4940
69406	7	69	1156	11093	50659	\N	51.522395000000003	село Иртек, Центральная, 8А		0101000020E6100000B16EBC3B32564A40064CE0D6DDC24940
69445	7	69	1156	49386	50998	\N	51.690928	поселок Зерновой, Победы, 21		0101000020E6100000740987DEE2794A4002F2255470D84940
69410	7	69	1156	11243	50996	\N	51.938668999999997	село Заречное, Центральная, 8		0101000020E6100000E7ABE46377954A406F62484E26F84940
69431	7	69	1156	21395	50992	\N	51.794592999999999	поселок Западный, Клубная, 3		0101000020E6100000EB54F99E91304A40B5503239B5E54940
69430	7	69	1156	12243	51073	\N	51.679174000000003	поселок Жирнов, Школьная, 3		0101000020E610000038A3E6ABE44D4A409225732CEFD64940
69439	7	69	1156	12663	51021	\N	51.902164999999997	село Жигалино, Центральная, 4		0101000020E6100000F73DEAAF574A4A40444C89247AF34940
69407	7	69	1156	48825	51315	\N	51.819290000000002	село Вязовое, Школьная, 2		0101000020E6100000C6A52A6D71814A404DF8A57EDEE84940
69444	7	69	1156	49377	51064	\N	51.726573000000002	поселок Восходящий, Центральная, 21		0101000020E6100000D39FFD48118F4A400C94145800DD4940
69420	7	69	1156	11764	50811	\N	51.978351000000004	село Буренино, Центральная, 18		0101000020E61000009FAF592E1B6B4A402481069B3AFD4940
69416	7	69	1156	11526	51007	\N	51.570754000000001	село Бородинск, Советская, 46		0101000020E6100000BC9179E40F6A4A40D50792770EC94940
69404	7	69	1156	48767	50807	\N	51.668343999999998	село Болдырево, Центральная, 47		0101000020E610000069C537143E5D4A40293DD34B8CD54940
69402	7	69	1156	10908	50237	\N	52.003174000000001	село Благодарное, Советская, 24		0101000020E6100000F052EA9271864A404819710168004A40
69442	7	69	1156	12781	51065	\N	52.080323	село Баширово, Центральная, 7		0101000020E61000002F6EA301BC694A40ED0E2906480A4A40
69391	7	69	520	56141	51062	\N	52.438343000000003	Оренбургская область, муниципальное образование Сорочинский район, Рощинский сельсовет, п.Новый, Пушкина, д.5Б, сельский Клуб		0101000020E61000009C3237DF88A64A401CB7989F1B384A40
69322	7	69	520	7107	50871	\N	52.573566	с.Янтарное, ул.Молодежная, д.6		0101000020E6100000E99C9FE238844A407C0C569C6A494A40
69394	7	69	520	10520	50398	\N	52.349688999999998	Оренбургская область, Сорочинский район, Федоровский сельсовет, с.Федоровка, Центральная, д.51, СДК		0101000020E61000006058FE7C5B764A40AE62F19BC22C4A40
68041	7	69	520	10520	50453	\N	52.349688999999998	с.Федоровка, Центральная (дом культуры), 9		0101000020E61000006058FE7C5B764A40AE62F19BC22C4A40
69381	7	69	520	9880	51003	\N	52.526423999999999	Оренбургская область, Сорочинский район, Николаевский сельсовет, с.Уран, Центральная, д.5, СДК		0101000020E6100000AE7FD767CE8A4A402DEA93DC61434A40
69393	7	69	520	10492	51060	\N	52.304535000000001	Оренбургская область,  Сорочинский район, Федоровский сельсовет, с.Троицкое, Молодежная, д.23, СДК		0101000020E61000006F46CD57C97D4A4062BEBC00FB264A40
69392	7	69	520	10425	50531	\N	52.559092	Оренбургская область, Сорочинский район, Толкаевский сельсовет, с.Толкаевка, Гречушкина, д.3Г, СДК	Россия, Оренбургская область, Сорочинский район, село Толкаевка	0101000020E6100000A69D9ACB0DA44A4045BA9F5390474A40
69370	7	69	520	3171	51086	\N	52.328834999999998	Оренбургская область, Сорочинский район, Войковский сельсовет, с.Спасское, Центральная, д.5А, СДК		0101000020E6100000698A00A7779B4A40DC63E943172A4A40
69371	7	69	520	9364	50712	\N	52.351472000000001	Оренбургская область,  Сорочинский район, Войковский сельсовет, п.Сборовский, Школьная, д.11А, сельский Клуб		0101000020E610000017F549EEB08D4A40D8BAD408FD2C4A40
69377	7	69	520	9657	50804	\N	52.209508	Оренбургская область, Сорочинский район, Романовский сельсовет, с.Романовка, Центральная, д.1, СДК		0101000020E610000037C7B94DB8774A400C207C28D11A4A40
69388	7	69	520	10211	49870	\N	52.430256	Оренбургская область, Сорочинский район, Родинский сельсовет, п.Родинский, Садовая, д.13, СДК		0101000020E6100000EE23B726DDAA4A403274ECA012374A40
69386	7	69	520	10111	50527	\N	52.707329999999999	Оренбургская область, Сорочинский район, Пронькинский сельсовет, с.Пронькино, Ленинская, д.29, СДК		0101000020E610000017618A7269744A4066BD18CA895A4A40
69384	7	69	520	10029	50805	\N	52.194893	Оренбургская область, Сорочинский район,  Войковский сельсовет, с.Покровка, Центральная, д.7, СДК		0101000020E6100000725303CDE78E4A40139CFA40F2184A40
69385	7	69	520	10061	50716	\N	52.510218999999999	Оренбургская область, муниципальное образование Сорочинский район, с.Первокрасное, Советская, д.31, СДК		0101000020E6100000BC5CC47762C44A401F662FDB4E414A40
69383	7	69	520	56178	51362	\N	52.120370642106899	Оренбургская область, Сорочинский район, Войковский сельсовет, с.Новобелогорка, Центральная, д.44, СДК		0101000020E6100000B08C0DDDEC8D4A4083312251680F4A40
69382	7	69	520	9903	50711	\N	52.582825999999997	Оренбургская область, Сорочинский район, Николаевский сельсовет, с.Никольское, Центральная, д.24А, сельский Клуб		0101000020E6100000070ABC934F914A4016A1D80A9A4A4A40
68458	7	69	520	9903	50711	\N	52.582561707663103	с.Никольское, ул. Центральная, д. 10	Россия, Оренбургская область, Сорочинский район, село Никольское	0101000020E6100000DE8D058541914A4039F24064914A4A40
69380	7	69	520	9825	50432	\N	52.501904000000003	Оренбургская область, Сорочинский район, Николаевский сельсовет, с.Николаевка, Центральная, д.52А, СДК		0101000020E61000007D04FEF0F37F4A40A5DDE8633E404A40
68184	7	69	520	9825	50910	\N	52.501904000000003	с. Николаевка, Нагорная, 18		0101000020E61000007D04FEF0F37F4A40A5DDE8633E404A40
69368	7	69	520	9259	51217	\N	52.321339000000002	Оренбургская область, Сорочинский район, Бурдыгинский сельсовет, с.Надежденка, Центральная, д6/2, сельский Клуб		0101000020E6100000153B1A87FAB34A40F5F6E7A221294A40
69378	7	69	520	9721	51310	\N	52.478473000000001	Оренбургская область, Сорочинский район, Михайловский Второй сельсовет, с.Михайловка Вторая, Школьная, д.6, СДК		0101000020E6100000810706103EB24A406F826F9A3E3D4A40
69376	7	69	520	9590	50802	\N	52.232565000000001	Оренбургская область, Сорочинский район, Михайловский Первый сельсовет, с.Михайловка Первая, Молодежная, д.8, СДК		0101000020E6100000240B98C0AD814A40DD989EB0C41D4A40
69375	7	69	520	9569	51087	\N	52.157741000000001	Оренбургская область, Сорочинский район, Матвеевский сельсовет, с.Матвеевка, Центральная, д.37А, СДК		0101000020E6100000535E2BA1BBA44A40821E6ADB30144A40
69379	7	69	520	9750	51309	\N	52.458437000000004	Оренбургская область, Сорочинский район, Михайловский Второй сельсовет, с.Ивановка Вторая, Московская, д.82, СДК		0101000020E6100000971B0C7558B14A4060234910AE3A4A40
68947	7	69	520	56041	49824	\N	52.636760364548401	село Ивановка, улица Кольцевая, дом 8А	Россия, Оренбургская область, Сорочинский район, село Ивановка	0101000020E6100000963D096CCE874A4053B3075A81514A40
69372	7	69	520	9441	50623	\N	52.270219808272799	Оренбургская область, Сорочинский район, Гамалеевский сельсовет, п.Гамалеевка-1, Садовая, д.74А, средняя школа		0101000020E610000062F5471806BA4A40D15CA79196224A40
69373	7	69	520	9441	50541	\N	52.269907000000003	Оренбургская область, Сорочинский район, Гамалеевский сельсовет, с.Гамалеевка, Молодежная, д.15А, Здание администрации сельсовета		0101000020E6100000861DC6A4BFB94A4012FB04508C224A40
69369	7	69	520	9276	50254	\N	52.252411000000002	Оренбургская область, Сорочинский район, Войковский сельсовет, п.Войковский, Победы, д.2А, СДК		0101000020E6100000EE5A423EE8934A404913EF004F204A40
69367	7	69	520	9184	50255	\N	52.327063000000003	Оренбургская область, муниципальное образование Сорочинский район, с.Бурдыгино, Центральная, 95Б, сельский Дом культуры		0101000020E610000042CEFBFF38AB4A40A75D4C33DD294A40
69366	7	69	520	24767	\N	\N	52.625917000000001	с.Березовка, ул.Молодежная, д.8/1	Россия, Оренбургская область, Сорочинский район, село Березовка	0101000020E61000006840BD19357B4A4056815A0C1E504A40
69365	7	69	520	9114	51085	\N	52.643121999999998	Оренбургская область, Сорочинский район, Баклановский сельсовет, с.Баклановка, ул.Молодежная, 18, СДК		0101000020E6100000F0BF95ECD8804A4047AB5AD251524A40
69374	7	69	520	9519	51218	\N	52.211992000000002	Оренбургская область, Сорочинский район, Матвеевский сельсовет, с.Алексеевка, Молодежная, д.20Б, СДК		0101000020E610000058C9C7EE02A94A40BF81C98D221B4A40
69341	7	69	884	56093	50656	\N	51.179250000000003	Оренбургская область, Соль-Илецкий район, поселок Кирзавод, Центральная, 22а	Россия, Оренбургская область, Соль-Илецкий район, село кирпичный Завод	0101000020E6100000B306EFAB72754B406DE7FBA9F1964940
69339	7	69	884	7874	50575	\N	51.198256999999998	Оренбургская область, Соль-Илецкий район, поселок Шахтный, Центральная, 25		0101000020E61000008EB27E33318D4B40FE99417C60994940
69321	7	69	884	7048	50230	\N	51.105359	Оренбургская область, Соль-Илецкий район, село Чашкан, Южная, 2/3		0101000020E6100000300F99F221AA4B406DAB59677C8D4940
69325	7	69	884	7239	51057	\N	51.115041718373	Оренбургская область, Соль-Илецкий район, станция Цвиллинга, Элеваторная, 23	Россия, Оренбургская область, Соль-Илецкий район, село Цвиллинга	0101000020E61000008884EFFD0D4E4B404ED53DB2B98E4940
69345	7	69	884	8160	\N	\N	51.110498999999997	Оренбургская область, Соль-Илецкий район, село Угольное, Советская, 27	Россия, Оренбургская область, Соль-Илецкий район, село Угольное	0101000020E6100000E3DD91B1DA964B40CF9ECBD4248E4940
69435	7	69	884	8027	50532	\N	51.088208999999999	село Трудовое, пер.Почтовый, 3		0101000020E61000008124ECDB49704B403F1BB96E4A8B4940
69342	7	69	884	8027	50422	\N	51.088208999999999	Оренбургская область, Соль-Илецкий район, село Трудовое, Кооперативная, 25		0101000020E61000008124ECDB49704B403F1BB96E4A8B4940
69344	7	69	884	8136	50709	\N	50.697139999999997	Оренбургская область, Соль-Илецкий район, село Троицк, Школьная, 9		0101000020E6100000745C8DEC4A4F4B40E15D2EE23B594940
69343	7	69	884	8066	50555	\N	51.083592000000003	Оренбургская область, Соль-Илецкий район, село Тамар-Уткуль, Центральная, 18а		0101000020E6100000D200DE0209824B40871A8524B38A4940
69606	7	69	884	21017	51235	\N	51.200097	Оренбургская область, Соль-Илецкий район, село Сухоречка, Тополиная, 22		0101000020E61000005E4D9EB29A9E4B408C834BC79C994940
68405	7	69	884	21017	50302	\N	51.200097	Сухоречка, Молодежная, 49	Россия, Оренбургская область, Соль-Илецкий район, село Сухоречка	0101000020E61000005E4D9EB29A9E4B408C834BC79C994940
69356	7	69	884	8389	50059	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Южная, 31		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69352	7	69	884	8389	49927	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Цвиллинга, 18		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69353	7	69	884	8389	49801	\N	51.1567575250182	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Уральская, 34	Россия, Оренбургская область, Соль-Илецкий район, Соль-Илецк	0101000020E61000007AFB73D1907F4B4075B169A510944940
69364	7	69	884	8389	50250	\N	51.159256999999997	город Соль-Илецк, ул. Украинская, 2 «г»		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69361	7	69	884	8389	49939	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Орджоникидзе, 7		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69354	7	69	884	8389	49701	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Московская, 161		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69351	7	69	884	8389	49701	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Московская, 1		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69360	7	69	884	8389	49936	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Молодежная, 1		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69517	7	69	884	8389	50819	\N	51.159256999999997	Оренбургская область, г. Соль-Илецк, Ленинградская, 1/1		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69350	7	69	884	8389	49915	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Кирова, 52		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69358	7	69	884	8389	49803	\N	51.159365119141803	Оренбургская область, Соль-Илецкий район г.Соль-Илецк, Гонтаренко, 1	Россия, Оренбургская область, Соль-Илецкий район, Соль-Илецк	0101000020E61000004EECA17DAC7E4B404390831266944940
69357	7	69	884	8389	49935	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, город Соль-Илецк, Володарского, 111		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69362	7	69	884	8389	49806	\N	51.159203202993197	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Вокзальная, 79	Россия, Оренбургская область, Соль-Илецкий район, Соль-Илецк	0101000020E6100000A2B437F8C27E4B4069368FC360944940
69349	7	69	884	8389	49799	\N	51.159256999999997	Оренбургская область, Соль-Илецкий район, г.Соль-Илецк, Челкарская, 90		0101000020E610000010CD3CB9A67E4B405C548B8862944940
69605	7	69	884	22504	50717	\N	51.458947000000002	с.Смирновка, ул.Новая, 5		0101000020E61000000685419946AF4B4075CC79C6BEBA4940
69340	7	69	884	7949	50421	\N	51.197806	Оренбургская область, Соль-Илецкий район, село Саратовка, Калинина, 65		0101000020E61000006901DA56B3744B40EE79FEB451994940
69564	7	69	884	52595	50830	\N	51.253157000000002	Оренбургская область, муниципальное образование Ясненский район, муниципальное образование сельское поселение Веселовский сельсовет, п.Садовый, Центральная, 9		0101000020E6100000202A8D98D9354B4072E0D57267A04940
69338	7	69	884	7843	50233	\N	50.915654000000004	Оренбургская область, Соль-Илецкий район, село Покровка, Ахметгалиева, 21		0101000020E610000059147651F4444B40CE39782634754940
69334	7	69	884	7676	51058	\N	51.359993000000003	Оренбургская область, Соль-Илецкий район, село Перовка, Советская, 12		0101000020E61000003F1D8F19A8A64B40FCE4284014AE4940
69336	7	69	884	7747	\N	\N	50.974102000000002	Оренбургская область, Соль-Илецкий район, село Первомайское, Мира, 10	Россия, Оренбургская область, Соль-Илецкий район, село Первомайское	0101000020E6100000F373435376804B40EE7BD45FAF7C4940
69333	7	69	884	7600	50231	\N	50.996487999999999	Оренбургская область, Соль-Илецкий район, село Новоилецк, Советская, 59		0101000020E6100000191EFB592C1D4B40A06D35EB8C7F4940
69165	7	69	1861	30843	49860	\N	51.879109	п.Переволоцкий, Лениская, 119		0101000020E610000084B872F6CE184B40444FCAA486F04940
69332	7	69	884	7578	\N	\N	51.436242	Оренбургская область, Соль-Илецкий район, село Михайловка, Учительская, 4	Россия, Оренбургская область, Соль-Илецкий район, село Михайловка	0101000020E610000031074147ABB24B40219221C7D6B74940
69348	7	69	884	56155	51198	\N	51.154660884906598	Оренбургская область, Соль-Илецкий район, поселок Мирный, Островского, 1	Россия, Оренбургская область, Соль-Илецкий район, поселок разъезд 25	0101000020E61000001EC3633F8B8D4B40BB7B80EECB934940
69335	7	69	884	7682	50983	\N	51.388081999999997	Оренбургская область, Соль-Илецкий район, село Мещеряковка, Советская, 22		0101000020E6100000EA77616BB6A24B404815C5ABACB14940
69315	7	69	884	56139	51052	\N	51.324424	Оренбургская область, Соль-Илецкий район, станция Маячная, Элеваторная, 1		0101000020E61000000F7C0C569C7A4B40CD04C3B986A94940
69327	7	69	884	56078	50534	\N	51.350613657892197	Оренбургская область, Соль-Илецкий район, поселок Маякское, Целинная, 48	Россия, Оренбургская область, Соль-Илецкий район, село Маякский	0101000020E610000019E42EC214934B4087C267EBE0AC4940
69329	7	69	884	56118	50834	\N	51.368760000000002	Оренбургская область, Соль-Илецкий район, поселок Малопрудное, Первомайская, 11	Россия, Оренбургская область, Соль-Илецкий район, село Малопрудный	0101000020E61000003FC8B260E2934B405709168733AF4940
69331	7	69	884	7521	49773	\N	51.143143999999999	Оренбургская область, Соль-Илецкий район, село Линевка, Кызыл-Юлдузская, 58		0101000020E610000066D993C0E60E4B402F4FE78A52924940
69326	7	69	884	56088	50632	\N	51.0712439648226	Оренбургская область, Соль-Илецкий район, село Кумакское, Центральная, 30	Россия, Оренбургская область, Соль-Илецкий район, село Кумакский	0101000020E61000006E30D46185914B40A304FD851E894940
69320	7	69	884	6996	51306	\N	51.103271999999997	Оренбургская область, Соль-Илецкий район, село Казанка, Школьная, 1		0101000020E6100000F7CABC55D7B14B40D74B5304388D4940
69324	7	69	884	7217	49864	\N	51.034016999999999	Оренбургская область, Соль-Илецкий район, село Изобильное, Максима Горького, 1		0101000020E6100000800BB265F9484B40074147AB5A844940
69359	7	69	884	56124	\N	\N	51.163178000000002	город Соль-Илецк,ул. Зеленый Клин 1	Россия, Оренбургская область, Соль-Илецкий район, поселок Зеленый Клин	0101000020E61000007026A60BB1784B409EB64604E3944940
69330	7	69	884	7496	51308	\N	51.319921000000001	Оренбургская область, Соль-Илецкий район, село Елшанка, Магистральная, 13		0101000020E6100000F10F5B7A34814B40DD26DC2BF3A84940
69337	7	69	884	56148	51125	\N	50.963184544225903	Оренбургская область, Соль-Илецкий район, село Егинсай, Школьная, 6	Россия, Оренбургская область, Соль-Илецкий район, село Егенсай	0101000020E6100000C1E5B166648E4B40B77F65A5497B4940
69323	7	69	884	7147	50399	\N	51.419955999999999	Оренбургская область, Соль-Илецкий район,село Дружба, Речная, 33		0101000020E610000033DE567A6D864B4026E1421EC1B54940
69346	7	69	884	8250	50251	\N	51.189536059447001	Оренбургская область, Соль-Илецкий район, село Дивнополье, Советская, 42	Россия, Оренбургская область, Соль-Илецкий район, село Дивнополье	0101000020E6100000F59ECA694F414B4013B534B742984940
69318	7	69	884	6917	49772	\N	51.103351000000004	Оренбургская область, Соль-Илецкий район, село Григорьевка, Советская, 68		0101000020E6100000FFEBDCB419A74B402481069B3A8D4940
69319	7	69	884	6963	51051	\N	51.110216999999999	Оренбургская область, Соль-Илецкий район,село Возрождение, Луговая, 1		0101000020E61000003B1BF2CF0C9E4B404B3B35971B8E4940
69317	7	69	884	6841	50396	\N	51.080728999999998	Оренбургская область, Соль-Илецкий район, село Ветлянка, Советская, 56		0101000020E6100000E8F86871C6644B405D6BEF53558A4940
69316	7	69	884	6837	49863	\N	50.976154999999999	Оренбургская область, Соль-Илецкий район, село Буранное, Советская, 70а		0101000020E6100000925CFE43FA3B4B40D769A4A5F27C4940
69314	7	69	884	6707	50425	\N	51.279204999999997	Оренбургская область, Соль-Илецкий район, село Боевая Гора, Таврическая, 14		0101000020E61000003FC571E0D5724B4099F04BFDBCA34940
69328	7	69	884	56162	51334	\N	51.38852	Оренбургская область, Соль-Илецкий район, село Ащебутак, Зеленая, 36	Россия, Оренбургская область, Соль-Илецкий район, село Ащибутак	0101000020E610000062A06B5F40954B40C4EBFA05BBB14940
69313	7	69	473	46300	50696	\N	54.253799000000001	с.Яковлево, ул.Центральная дом 41		0101000020E610000048A643A7E7834A40F660527C7C204B40
69303	7	69	473	6172	50799	\N	54.028323398347403	д.Шабрино, ул.Бадановка, 20	Россия, Оренбургская область, Северный район, село Шабрино	0101000020E610000033DDEBA4BE804A40C05C8B16A0034B40
69282	7	69	473	5023	51171	\N	54.098948	п.Тургай, ул.Центральная дом 50а		0101000020E6100000657094BC3A394A409700FC53AA0C4B40
69298	7	69	473	46744	51053	\N	54.027562000000003	с.Трифоновка, ул.Центральная, 93а		0101000020E6100000A3E9EC6470504A40624ED02687034B40
69312	7	69	473	6633	50867	\N	54.251399999999997	с.Стародомосейкино, ул.Молодежная дом 14		0101000020E6100000A1664815C5494A40711B0DE02D204B40
69311	7	69	473	6570	50985	\N	54.231592251083001	с.Староборискино, ул.Советская, 41	Россия, Оренбургская область, Северный район, село Староборискино	0101000020E610000030BDFDB9683A4A40F30181CEA41D4B40
69307	7	69	473	6377	50392	\N	54.124257	с.Соковка, ул.Школьная, 2		0101000020E6100000075E2D77663E4A4048A643A7E70F4B40
69286	7	69	473	46500	51038	\N	54.040745000000001	с.Сергушкино, ул.Центральная, 95		0101000020E6100000670C7382369D4A40DE3CD52137054B40
69308	7	69	473	6388	51049	\N	54.154043000000001	с.Секретарка, ул.Школьная, 13		0101000020E61000002507EC6AF2724A40C09657AEB7134B40
69305	7	69	473	46889	50067	\N	54.093223999999999	с.Северное, ул.Советская, 25		0101000020E6100000C422861DC6444A40E59997C3EE0B4B40
69306	7	69	473	46889	50091	\N	54.093223999999999	с.Северное, ул.Осенняя, 2		0101000020E6100000C422861DC6444A40E59997C3EE0B4B40
69300	7	69	473	46788	50800	\N	53.986609999999999	с.Рычково, ул.Центральная, 22		0101000020E61000003222516859434A400AF4893C49FE4A40
69302	7	69	473	6094	50524	\N	54.028306999999998	с.Русский Кандыз, пл.Центральная, 6		0101000020E61000007E1CCD9195774A40BA9F53909F034B40
69163	7	69	1861	30843	49894	\N	51.879109	п.Переволоцкий, Ленинская, 85		0101000020E610000084B872F6CE184B40444FCAA486F04940
69291	7	69	473	5488	\N	\N	54.319758999999998	д.Ремчугово, ул.Центральная, 26	Россия, Оренбургская область, Северный район, село Ремчугово	0101000020E6100000A4C16D6DE14D4A4003CDE7DCED284B40
69289	7	69	473	5387	51083	\N	54.043145000000003	с.Пашкино, ул.Центральная, 74а	Россия, Оренбургская область, Северный район, село Пашкино	0101000020E6100000C0EC9E3C2C5E4A4033FE7DC685054B40
68976	7	69	473	49269	50567	\N	54.219594999999998	село Павловка, бульвар Молодежный, дом 3		0101000020E6100000DFFC868906714A40BCAE5FB01B1C4B40
68771	7	69	473	45370	\N	\N	53.947240000000001	село Октябрьское, Лесная, 2	Россия, Оренбургская область, Северный район, село Октябрьское	0101000020E6100000F12F82C64C3A4A4045BB0A293FF94A40
68748	7	69	473	45370	\N	\N	53.947240000000001	село Октябрьское, Коммунистическая, 1	Россия, Оренбургская область, Северный район, село Октябрьское	0101000020E6100000F12F82C64C3A4A4045BB0A293FF94A40
68747	7	69	473	45370	50490	\N	53.947240000000001	село Октябрьское, Луначарского, 41		0101000020E6100000F12F82C64C3A4A4045BB0A293FF94A40
68750	7	69	473	45370	50518	\N	53.947240000000001	село Октябрьское, Железнодорожная, 10		0101000020E6100000F12F82C64C3A4A4045BB0A293FF94A40
69295	7	69	473	5741	50984	\N	54.298180000000002	с.Новодомосейкино, ул.Молодежная, 15		0101000020E6100000431A1538D9704A40202922C32A264B40
69294	7	69	473	5673	50797	\N	54.133189000000002	с.Новоборискино, ул.Южная, 24б		0101000020E61000001F2C634337794A40EE974F560C114B40
69293	7	69	473	5632	51307	\N	54.134281000000001	с.Мордово-Добрино, ул.Чукаевская, 2а		0101000020E610000019AC38D55A824A40B2BCAB1E30114B40
69488	7	69	473	45872	51094	\N	54.326017999999998	с. Медведка, ул. Центральная, 41 а		0101000020E61000005C0531D0B5594A4023F433F5BA294B40
69287	7	69	473	56202	51413	\N	54.0744616456887	д.Кызыл Яр, ул.Лесная, 23		0101000020E610000085B4C6A0139A4A40BA6587F887094B40
69290	7	69	473	5467	50798	\N	54.229159000000003	с.Курская-Васильевка, ул.Заречная, 1		0101000020E6100000DC4603780B5A4A40C34A0515551D4B40
69284	7	69	473	5162	50796	\N	54.056027	с.Кряжлы, ул.Широкая, 41		0101000020E610000047567E198C934A40B4588AE42B074B40
69288	7	69	473	46534	51046	\N	53.992427999999997	с.Красноярка, ул.Черемушки, 9		0101000020E61000000CCEE0EF175B4A403DD175E107FF4A40
69456	7	69	473	49554	\N	\N	54.232126999999998	с. Кирсановка, ул. Советская, 62 Б	Россия, Оренбургская область, Северный район, село Кирсановка	0101000020E61000009A07B0C8AF774A4061C26856B61D4B40
69310	7	69	473	46996	50986	\N	54.193928	с.Камышлинка, ул.Центральная, 50		0101000020E6100000849F38807E3D4A40ACE3F8A1D2184B40
69283	7	69	473	5095	51035	\N	54.167248999999998	с.Каменногорское, ул.Центральная, 20		0101000020E6100000A04FE449D2654A40F4A44C6A68154B40
69280	7	69	473	4920	51304	\N	53.965846999999997	с.Кабаевка, ул.Молодежная, 3		0101000020E61000002788BA0F40984A4048F8DEDFA0FB4A40
69296	7	69	473	46384	50713	\N	54.279218	д.Жмакино, ул.Горная дом 43		0101000020E6100000B39AAE27BA684A402E3A596ABD234B40
69309	7	69	473	46987	51042	\N	54.297949000000003	ст.Дымка, ул.Вокзальная, 54		0101000020E6100000B3EF8AE07F3F4A401E705D3123264B40
69297	7	69	473	56142	51063	\N	53.927549682600002	с.Большедорожное, ул.Молодежная, 83	Россия, Оренбургская область, Северный район, село Большедорожный	0101000020E6100000D5264EEE77484A40D0B359F5B9F64A40
69304	7	69	473	46854	50801	\N	54.129458999999997	д.Богдановка, ул.Луговая, 15а	Россия, Оренбургская область, Северный район, село Богдановка	0101000020E6100000137CD3F4D94F4A402096CD1C92104B40
69281	7	69	473	4994	50395	\N	54.125596356534103	с.Бакаево, ул.Речная, 1а	Россия, Оренбургская область, Северный район, село Бакаево	0101000020E6100000B4E7323509344A4014419C8713104B40
69279	7	69	473	4884	51039	\N	53.992735000000003	с. Аксенкино, ул.Центральная, 9		0101000020E6100000B88FDC9A748D4A401B4CC3F011FF4A40
69278	7	69	662	46352	50528	\N	50.837215	п.Целинный, Воронежская, 2а		0101000020E6100000787E5182FE5C4E403E5C72DC296B4940
69277	7	69	662	4809	50529	\N	51.440806000000002	п.Тобольский, Бугурусланская, 6		0101000020E6100000008BFCFA21944E40B7F0BC546CB84940
69267	7	69	662	46060	50073	\N	50.825006999999999	п.Светлый, Торговая, 6	Россия, Оренбургская область, Светлинский район, поселок Светлый	0101000020E6100000CCEB8843366E4E404CFC51D499694940
69268	7	69	662	46060	50066	\N	50.825006999999999	п.Светлый, Промышленная, 34		0101000020E6100000CCEB8843366E4E404CFC51D499694940
69266	7	69	662	46060	49770	\N	50.825006999999999	п.Светлый, Овечкина, 9		0101000020E6100000CCEB8843366E4E404CFC51D499694940
69216	7	69	662	46060	49769	\N	50.8246259285254	п. Светлый, Мира (Светлинская средняя общеобразовательная школа), 4	Россия, Оренбургская область, Светлинский район, поселок Светлый	0101000020E610000001BD70E7C26E4E4035B742588D694940
68374	7	69	662	46660	50461	\N	50.875948000000001	поселок Полевой, Комсомольская, 11		0101000020E6100000021077F52AAC4E40917F66101F704940
69274	7	69	662	46231	50523	\N	51.102920791979201	п.Озерный, Чкалова, 3	Россия, Оренбургская область, Светлинский район, село Озерный	0101000020E610000055BDFC4E93734E402B89EC832C8D4940
69273	7	69	662	46212	51311	\N	51.143895999999998	п.Коскуль, квартал Новоселов, 4		0101000020E610000018EAB0C22D914E403A03232F6B924940
69271	7	69	662	46180	50573	\N	51.429890999999998	п.Восточный, Советская, 10		0101000020E6100000003CA24275A74E4020EC14AB06B74940
69270	7	69	662	46149	51173	\N	51.201490999999997	Пос.Актюбинский, ул.Целинная, д.44		0101000020E6100000BD72BD6DA6BA4E401BB80375CA994940
69256	7	69	337	3641	50394	\N	51.748358000000003	с.Шишма, Центральная ( сельский Дом культуры ), 26		0101000020E6100000B9895A9A5B3B4C4099D9E731CADF4940
69225	7	69	337	1907	49771	\N	51.882671999999999	с.Черный Отрог, Ленинская (Центр Досуга), 23		0101000020E610000009C21550A8014C40268C6665FBF04940
69226	7	69	337	1907	51056	\N	51.871209735070401	ст.Черный Отрог, Вокзальная( сельский Дом Культуры), 36		0101000020E6100000535C55F65D054C405DF92CCF83EF4940
69239	7	69	337	45506	49795	\N	51.809820000000002	с.Черкассы, ул.Советская, 15в		0101000020E61000003DEFC682C22A4C40C8D2872EA8E74940
69240	7	69	337	2775	50390	\N	51.847752	с.Федоровка Первая, ул.Советская, 1		0101000020E6100000D44334BA83164C402E8F352383EC4940
69242	7	69	337	2876	51302	\N	51.839610999999998	с.Татарский Саракташ, Центральная ( сельский клуб ), 14 а		0101000020E6100000306475ABE72E4C40512E8D5F78EB4940
69227	7	69	337	49570	51099	\N	51.864162	с. Студенцы, Школьный ( школа), 3		0101000020E61000004C5299620EEE4B40153944DC9CEE4940
69246	7	69	337	3120	50697	\N	52.055914000000001	с.Старый Сокулак, ул.Заречная, 3		0101000020E6100000AB7823F3C8334C40BCB1A03028074A40
69162	7	69	1861	30843	49894	\N	51.879109	п.Переволоцкий, Ленинская, 61		0101000020E610000084B872F6CE184B40444FCAA486F04940
69247	7	69	337	48749	50543	\N	52.006661999999999	с.Спасское, ул.Луговая, 101 «А»	Россия, Оренбургская область, Саракташский район, село Спасское	0101000020E61000005D6E30D461454C401F10E84CDA004A40
69220	7	69	337	1607	49900	\N	51.779423000000001	п. Саракташ, переулок Заводской ( клуб), 4		0101000020E61000008B53AD85592E4C4007600322C4E34940
68088	7	69	337	1607	50437	\N	51.779423000000001	Оренбургская область, Саракташский район,  Саракташ, Промышленная (здание ГИБДД №1), 11		0101000020E61000008B53AD85592E4C4007600322C4E34940
69222	7	69	337	1607	49904	\N	51.779423000000001	п.Саракташ, Первомайская (школа), 97		0101000020E61000008B53AD85592E4C4007600322C4E34940
69221	7	69	337	1607	50069	\N	51.779423000000001	п.Саракташ, Мира (кинотеатр), 88		0101000020E61000008B53AD85592E4C4007600322C4E34940
69224	7	69	337	1607	49775	\N	51.779423000000001	п.Саракташ, Красноармейская (клуб ГОУ НПО ПУ -56), 96		0101000020E61000008B53AD85592E4C4007600322C4E34940
69590	7	69	337	1607	81002	\N	51.792665	Оренбургская область, Саракташский район, Саракташский поссовет, Комсомольская (школа), 13	Россия, Оренбургская область, Саракташский район, село Саракташ	0101000020E61000008C118942CB2C4C4088D7F50B76E54940
69223	7	69	337	1607	49862	\N	51.779423000000001	п.Саракташ, Геологов (школа), 14 а		0101000020E61000008B53AD85592E4C4007600322C4E34940
68963	7	69	337	21774	50658	\N	51.943354999999997	село Пречистинка, улица Большая, дом 21		0101000020E610000066DD3F16A2E74B4050C24CDBBFF84940
69245	7	69	337	3064	51037	\N	51.897751999999997	д.Покурлей, Центральная (школа), 22		0101000020E6100000A1A3552DE93E4C4094F59B89E9F24940
69251	7	69	337	45743	50554	\N	51.866453	с.Петровское,  ул.Школьная, 13		0101000020E6100000AC38D55A98494C40B34291EEE7EE4940
69265	7	69	337	46034	50982	\N	51.658076000000001	с.Островное, Лабужского (школа), 8		0101000020E610000011001C7BF6F64B40292499D53BD44940
69236	7	69	337	56191	51384	\N	52.093762740558503	с.Новосокулак, пер. Школьный ( школа ), 5	Россия, Оренбургская область, Саракташский район, село Новый Сокулак	0101000020E61000007B319413ED284C4095490D6D000C4A40
69262	7	69	337	62049	81005	\N	51.537742999999999	с.Новочеркасск,  ул.Кольцевая, 1	Россия, Оренбургская область, Саракташский район, село Новочеркасск	0101000020E6100000992842EA761E4C4093533BC3D4C44940
69259	7	69	337	62056	81012	\N	51.616373000000003	с.Новогафарово, Культурная ( сельский клуб ), 12	Россия, Оренбургская область, Саракташский район, село Новотафарово	0101000020E610000087C267EBE0524C4097917A4FE5CE4940
69243	7	69	337	45591	51033	\N	51.964869	с.Новоселки, Заводская ( сельский клуб ), 1		0101000020E610000086AC6EF59C384C404DF6CFD380FB4940
69250	7	69	337	62057	81015	\N	52.157155000000003	с.Новомихайловка, Школьный (школа), 1	Россия, Оренбургская область, Саракташский район, село Новомихайловка	0101000020E610000088D860E1243F4C4092B3B0A71D144A40
69231	7	69	337	45367	81003	\N	51.990416000000003	с.Николаевка, ул.Парковая, 16	Россия, Оренбургская область, Саракташский район, село Николаевка	0101000020E61000004E5FCFD72C014C40B3B794F3C5FE4940
69230	7	69	337	45355	50578	\N	51.858576999999997	с.Никитино, Культурная (сельский Дом культуры), 10		0101000020E6100000E96514CB2D134C40840CE4D9E5ED4940
69114	7	69	337	47665	51027	\N	51.790616	п.Назаровка, Л.Толстого, 17а		0101000020E61000009203763579404C40E0D8B3E732E54940
69235	7	69	337	21972	50482	\N	52.103077439982997	с.Надеждинка, пер.Школьный, 1	Россия, Оренбургская область, Саракташский район, село Надеждинка	0101000020E6100000F4C5DE8B2F144C4022FC8BA0310D4A40
69244	7	69	337	2975	50648	\N	51.875439	с.Кульчумово, ул.Центральная, 1		0101000020E61000003BA6EECA2E244C404C5299620EF04940
69263	7	69	337	45986	50704	\N	51.565837999999999	с.Красногор, ул.Центральная, 2		0101000020E6100000C1C41F459D0F4C40C26A2C616DC84940
69258	7	69	337	3762	50795	\N	51.527695999999999	с.Кондуровка, Школьная ( сельский Дом культуры ), 6		0101000020E61000005114E81379584C40711DE38A8BC34940
69237	7	69	337	2611	\N	\N	51.999110000000002	с.Карагузино, ул.Центральная, 75	Россия, Оренбургская область, Саракташский район, село Карагузино	0101000020E6100000D731AEB838204C40A48D23D6E2FF4940
69264	7	69	337	4066	51193	\N	51.612729999999999	с.Камышино, ул.Школьная,  11		0101000020E61000009AEB34D2521F4C4098A3C7EF6DCE4940
69253	7	69	337	3499	51091	\N	51.786031000000001	с. Каировка, ул.Заречная, 27 (фойе здания средней общеобразовательной школы)		0101000020E6100000B0726891ED444C403352EFA99CE44940
69232	7	69	337	2275	50860	\N	51.926630000000003	с.Кабанкино, ул.Школьная, 29		0101000020E610000050E449D235014C400ABFD4CF9BF64940
68770	7	69	337	58180	64166	\N	51.940686376733801	село Ильинка, Центральная, 57	Россия, Оренбургская область, Саракташский район, село Ильинка	0101000020E61000003012DA722E054C400CE71A6668F84940
69229	7	69	337	2129	50989	\N	51.875044000000003	с.Изяк-Никитино, Полевая (клуб), 5		0101000020E6100000815B77F3540D4C40D047197101F04940
69257	7	69	337	3730	49926	\N	51.632261999999997	Оренбургская область,Саракташский район,село Желтое, Советская ( сельский Дом культуры ), 18		0101000020E6100000603E59315C4B4C40744012F6EDD04940
69238	7	69	337	45380	50494	\N	51.938214000000002	с.Гавриловка, ул.Школьная, 23	Россия, Оренбургская область, Саракташский район, село Гавриловка	0101000020E6100000DDB6EF517F134C401E53776517F84940
69234	7	69	337	2430	50475	\N	52.088977999999997	с.Вторая Александровка,  ул.Школьная, 5		0101000020E6100000D61F6118B0FC4B40200890A1630B4A40
69255	7	69	337	48857	50521	\N	51.757418999999999	с.Воздвиженка, ул.Школьная, 1	Россия, Оренбургская область, Саракташский район, село Воздвиженка	0101000020E6100000E773EE76BD364C403C2F151BF3E04940
69241	7	69	337	45554	50249	\N	51.859172999999998	с.Васильевка, ул. Школьная, 5		0101000020E6100000390B7BDAE1354C40984D8061F9ED4940
69249	7	69	337	3308	9915	\N	52.107196999999999	с.Бурунча, ул.Зеленая, 12	Россия, Оренбургская область, Саракташский район, село Бурунча	0101000020E6100000333674B33F424C405A9D9CA1B80D4A40
69233	7	69	337	2385	50845	\N	51.907420999999999	с.Биктимирово, ул.Сакмарская, 2		0101000020E61000001E8CD82780064C40105A0F5F26F44940
69252	7	69	337	62051	81007	\N	51.936346	с.Андреевка, Школьная ( сельский клуб ), 16	Россия, Оренбургская область, Саракташский район, село Андреевка	0101000020E6100000F3AFE595EB514C40C6DE8B2FDAF74940
68043	7	69	337	45840	64079	\N	51.811479955299397	с. Александровка, ул. Рощепкина, 11	Россия, Оренбургская область, Саракташский район, село Александровка	0101000020E61000005BD2510E66254C40D6AD9E93DEE74940
69209	7	69	121	49320	50576	\N	52.078479999999999	"с. Украинка, Лесная (здание сельского Дома культуры), 18""А"""		0101000020E6100000A5DB12B9E0CA4B40EEB1F4A10B0A4A40
69207	7	69	121	49295	50988	\N	52.084268999999999	с. Тимашево, Советская (Тимашевская средняя общеобразовательная школа), 44А		0101000020E6100000938AC6DADFED4B4087889B53C90A4A40
69202	7	69	121	539	49764	\N	51.950361000000001	Татарская Каргала, Советская (Тат-Каргалинская средняя общеобразоват. школа), 43		0101000020E6100000A8E15B5837964B406A32E36DA5F94940
69214	7	69	121	539	49765	\N	51.950361000000001	с. Татарская Каргала, Комсомольская (здание сельского дома культуры), 9		0101000020E6100000A8E15B5837964B406A32E36DA5F94940
68082	7	69	121	58187	64198	\N	52.149251297316702	п. Северный, ул. Школьная, 11	Россия, Оренбургская область, Сакмарский район, село Северный	0101000020E610000027D9EA724A9A4B4099F221A81A134A40
69200	7	69	121	56102	50715	\N	51.958731225344998	"п. Красный Коммунар, Железнодорожная (детская школа искусств ""Гармония""), 4"	Россия, Оренбургская область, Сакмарский район, село Сакмарская	0101000020E6100000C8B7770DFAAE4B40A85489B2B7FA4940
69198	7	69	121	241	49897	\N	51.986854000000001	с. Сакмара, Советская (детско-юношеская спортивная школа), 63		0101000020E6100000C2A6CEA3E2A94B40A1F65B3B51FE4940
69197	7	69	121	241	49861	\N	51.986854000000001	"с. Сакмара, Ленина (здание районного дома культуры ""Юность""), 2"		0101000020E6100000C2A6CEA3E2A94B40A1F65B3B51FE4940
69115	7	69	121	241	78084	\N	52.003187485039703	ул. 50 лет Победы, 54а	Россия	0101000020E61000002B85402E71A84B40DC627E6E68004A40
68984	7	69	121	49380	49914	\N	52.029158000000002	с.Никольское, ул.В.Т.Обухова д.3		0101000020E6100000B071FDBB3ED94B4059350873BB034A40
69204	7	69	121	643	\N	\N	52.005397000000002	с. Нижние Чебеньки, Центральная (здание фельдшерско-акушерского пункта), 10	Россия, Оренбургская область, Сакмарский район, село Нижние Чебеньки	0101000020E61000001D93C5FD47C44B408E3F51D9B0004A40
69212	7	69	121	49349	50356	\N	52.100420999999997	с. Марьевка, Школьная (Марьевская основная общеобразовательная школа), 15	Россия, Оренбургская область, Сакмарский район, село Марьевка	0101000020E610000071E6577380A44B40726A6798DA0C4A40
69199	7	69	121	56053	50128	\N	51.958652720884899	п. Красный Коммунар, Краснокоммунарская (Краснокоммунарская средняя школа), 30	Россия, Оренбургская область, Сакмарский район, село Сакмарская	0101000020E6100000A8195245F1AE4B402C9B3924B5FA4940
68254	7	69	121	56113	\N	\N	51.997194415610899	с.Старая Александровка, ул.Жилгородок, 7	Россия, Оренбургская область, Сакмарский район, село Дмитриевка	0101000020E61000004F594DD713C14B403BE2900DA4FF4940
69213	7	69	121	49368	50981	\N	52.046100000000003	с. Жданово, Янгизская (Начальная общеобразовательная школа), 12		0101000020E6100000FF428F183DB14B403D2CD49AE6054A40
69217	7	69	121	56069	50405	\N	52.125458000000002	с. Егорьевка, Культурная (здание сельского Дома культуры), 35	Россия, Оренбургская область, Сакмарский район, село Егорьевка	0101000020E61000003BC43F6CE9834B40C382FB010F104A40
69205	7	69	121	49556	71746	\N	52.004631412762699	п. Жилгородок, Центральная (Дмитриевская средняя общеобразовательная школа), 26	Россия, Оренбургская область, Сакмарский район, село Дмитриевка	0101000020E6100000DD26DC2BF3C24B401EC6A4BF97004A40
69210	7	69	121	1020	\N	\N	52.114238	"с. Григорьевка Первая, Победы (Центральная средняя общеобразовательная школа), 2""в"""	Россия, Оренбургская область, Сакмарский район, село Григорьевка 1-я	0101000020E61000009204E10A28CC4B40F0FACC599F0E4A40
69203	7	69	121	628	50228	\N	52.006196000000003	с. Верхние Чебеньки, Школьная (Верхнечебеньковская средняя общеобразов. школа), 2А		0101000020E610000033C34659BFCF4B40DAAED007CB004A40
69218	7	69	121	49442	50383	\N	52.168154999999999	с. Белоусовка, Школьная (Белоусовская общеобразовательная средняя школа), 256		0101000020E6100000D591239D816B4B4056D4601A86154A40
69201	7	69	121	474	\N	\N	51.975743999999999	с. Беловка, 9 Мая (здание администрации МО Беловский сельсовет), 24		0101000020E61000001CF0F96184B84B4055A2EC2DE5FC4940
69211	7	69	121	49339	50419	\N	52.049733000000003	"с. Архиповка, Школьная (Архиповская средняя общеобразовательная школа), 46""А"""		0101000020E61000000F7C0C569CB64B401844A4A65D064A40
69172	7	69	334	31490	51187	\N	53.131374000000001	П.Чистополье, ул.Центральная		0101000020E61000000DE4D9E55BE94A40B9C5FCDCD0904A40
69171	7	69	334	31449	50692	\N	53.270888999999997	П.Фадеевский,ул. Совхозная 7		0101000020E61000009FE3A3C519FD4A404EECA17DACA24A40
69174	7	69	334	48773	49793	\N	53.173954000000002	С. Софиевка, ул Казанская 32		0101000020E610000016DA39CD02394B401381EA1F44964A40
69170	7	69	334	48700	50868	\N	53.395550999999998	С. Сорокино, пер. Садовый 5А		0101000020E6100000FDBFEAC891E64A403673486AA1B24A40
69169	7	69	334	48695	51195	\N	53.362478000000003	С. Семеновка, ул.Южная 4		0101000020E6100000EB1C03B2D7014B407FC2D9AD65AE4A40
69196	7	69	334	49103	51179	\N	53.0315065892486	С.Романовка, ул.Крестьянская 63	Россия, Оренбургская область, Пономаревский район, село Романовка	0101000020E6100000E690D442C9084B402B4CDF6B08844A40
69182	7	69	334	22619	51388	\N	53.105960430419501	П.Река Дема, ул. Оренбургская 20		0101000020E61000000536E7E099364B409357E718908D4A40
69168	7	69	334	23222	51166	\N	53.212733	П. Равнинный, ул.Советская 9		0101000020E6100000C39B35785F094B40D6E3BED53A9B4A40
69194	7	69	334	22961	49911	\N	53.321846000000001	С.Пономаревка, ул.Советская 9А		0101000020E6100000481ADCD616104B40992CEE3F32A94A40
69193	7	69	334	22961	49911	\N	53.321846000000001	С.Пономаревка, ул.Советская 12		0101000020E6100000481ADCD616104B40992CEE3F32A94A40
69192	7	69	334	22961	49911	\N	53.3186692237323	С.Пономаревка, ул.Советская 16	Россия, Оренбургская область, Пономаревский район, село Пономаревка	0101000020E6100000FED30D14780F4B40E09F5225CAA84A40
68950	7	69	1244	21125	49752	\N	51.766142000000002	село Нежинка, улица Куйбышева, дом 47Б		0101000020E6100000107A36AB3EAF4B40C80BE9F010E24940
69195	7	69	334	22961	51090	\N	53.320509783712197	С.Пономаревка, ул Заречная 8А	Россия, Оренбургская область, Пономаревский район, село Пономаревка	0101000020E6100000FAF19716F50F4B403E05C07806A94A40
69191	7	69	334	22961	49796	\N	53.321846000000001	С.Пономаревка, ул. Гагарина 58		0101000020E6100000481ADCD616104B40992CEE3F32A94A40
69190	7	69	334	22942	50861	\N	53.169202386657503	с.Новобогородское,ул.Центральная 21	Россия, Оренбургская область, Пономаревский район, село Новобогородское	0101000020E6100000CAFB389A23F74A407A354069A8954A40
69188	7	69	334	22848	51169	\N	53.239924000000002	С.Нижние Кузлы, ул.Школьная 8		0101000020E61000005EB9DE3653434B4044C362D4B59E4A40
69173	7	69	334	22881	50470	\N	53.288657000000001	С. Наурузово, ул. Школьная 18		0101000020E6100000C1A8A44E40134B4078616BB6F2A44A40
69189	7	69	334	22881	50542	\N	53.288657000000001	С. Наурузово,ул.Советская 67А		0101000020E6100000C1A8A44E40134B4078616BB6F2A44A40
68754	7	69	334	47842	\N	\N	53.308784000000003	село Михайловка, Набережная, 16	Россия, Оренбургская область, Пономаревский район, село Михайловка	0101000020E6100000319413ED2A3A4B4098C3EE3B86A74A40
69187	7	69	334	48962	50858	\N	53.215266999999997	С.Максимовка, ул.Молодежная 34		0101000020E61000006B64575A462E4B403A747ADE8D9B4A40
68706	7	69	334	48633	50870	\N	53.359597999999998	с.Ключевка, Центральная  (здание Ключевского СДК), 39		0101000020E61000004E9CDCEF50344B407FDAA84E07AE4A40
69185	7	69	334	22726	51165	\N	53.196094000000002	С.Кирсаново, ул.Калинина 3		0101000020E6100000E0490B97551A4B408E78B29B19994A40
69184	7	69	334	48948	50844	\N	53.079318999999998	П. Жатва, ул Набережная 16		0101000020E6100000CAA99D616A194B40C879FF1F278A4A40
69183	7	69	334	22688	51410	\N	53.382994168088203	С..Ефр.Зыково, ул.Центральная 1		0101000020E6100000CB14731074F04A40384888F205B14A40
69181	7	69	334	31899	50386	\N	53.128990999999999	С.Дюсметьево, ул.ул.Центральная 87		0101000020E61000006C5D6A847E2A4B403A3DEFC682904A40
68490	7	69	334	23314	64115	\N	53.178958330941597	село Грачевка, Центральная, 46в	Россия, Оренбургская область, Пономаревский район, село Грачевка	0101000020E61000002DB5DE6FB42B4B40C5AD8218E8964A40
69179	7	69	334	45672	50556	\N	53.1663757791598	С.Воздвиженка,ул.Рабочий городок 46	Россия, Оренбургская область, Пономаревский район, село Воздвиженка	0101000020E6100000033E3F8C101E4B406E6B0BCF4B954A40
69180	7	69	334	20129	50742	\N	53.271993000000002	С.Верхние Кузлы, ул.Верхняя 28		0101000020E6100000A3957B8159414B40D7DEA7AAD0A24A40
69177	7	69	334	48819	51191	\N	53.426081000000003	С.Борисовка, ул. Молодежная 2		0101000020E6100000A7751BD47E014B4037397CD289B64A40
69178	7	69	334	16024	50856	\N	53.221995999999997	С.Беседино, ул.Центральная 27		0101000020E610000050711C78B5F04A40E1EB6B5D6A9C4A40
69176	7	69	334	1596	51164	\N	53.169122999999999	С.Алябьево, ул.Центральная 20		0101000020E6100000EF2076A6D0014B402E008DD2A5954A40
69127	7	69	334	56125	64212	\N	53.0435743909621	хутор Алексеевка, Самарская, 1	Россия, Оренбургская область, Пономаревский район, село Алексеевка	0101000020E61000004147AB5AD2234B405B7A34D593854A40
69123	7	69	1861	29153	50974	\N	52.051499999999997	с.Япрынцево, Школьная, 1		0101000020E6100000462575029A284B403BDF4F8D97064A40
69128	7	69	1861	49278	51397	\N	51.832420999999997	х. Южный, Южная, 26	Россия, Оренбургская область, Переволоцкий район, село Южный	0101000020E610000058E20165531C4B4076C075C58CEA4940
69156	7	69	1861	56116	50814	\N	51.753683000000002	с.Шуваловка, Школьная, 3	Россия, Оренбургская область, Переволоцкий район, село Шуваловский	0101000020E6100000A0FF1EBC76554B408D463EAF78E04940
69158	7	69	1861	56049	50065	\N	51.657589999999999	с.Чесноковка, Кушмухаметовых, 10	Россия, Оренбургская область, Переволоцкий район, село Чесноковка	0101000020E610000062BEBC00FB0A4B409C16BCE82BD44940
69167	7	69	1861	31254	50690	\N	51.964036	с.Филипповка, Молодежная, 12	Россия, Оренбургская область, Переволоцкий район, село Филипповка	0101000020E610000089CF9D60FF234B4055151A8865FB4940
69157	7	69	1861	48465	50577	\N	51.692413000000002	с.Татищево, Советская, 20		0101000020E61000008CDAFD2AC0274B40A2293BFDA0D84940
69130	7	69	1861	56084	50627	\N	51.870752933222903	жд. ст. Сырт, Железнодорожная, 9	Россия, Оренбургская область, Переволоцкий район, поселок Сырт	0101000020E6100000D09B8A5418434B406BF294D574EF4940
69134	7	69	1861	29639	50694	\N	52.007033	п.Судаковка, Школьный, 1		0101000020E61000009ECE15A584364B40137F1475E6004A40
69146	7	69	1861	48288	50977	\N	52.278089999999999	с.Суворовка, Заречная, 13		0101000020E610000073BC02D193284B401DACFF7398234A40
69149	7	69	1861	48344	50236	\N	52.287785999999997	с.Степановка, Горького, 58		0101000020E610000061FE0A992B414B40921FF12BD6244A40
69139	7	69	1861	48146	51032	\N	52.155845999999997	с.Сенное, Садовая, 33		0101000020E6100000A7052FFA0A324B40309B00C3F2134A40
69126	7	69	1861	47871	50232	\N	51.790989000000003	п.Садовый, Центральная, 43		0101000020E61000009696917A4F0B4B40753FA7203FE54940
69155	7	69	1861	30659	51300	\N	51.718466999999997	с.Рычковка, Северная, 8		0101000020E6100000A0C211A452404B40AB2006BAF6DB4940
69142	7	69	1861	30012	\N	\N	52.198315000000001	с.Рыжковка, Рыжковская, 18	Россия, Оренбургская область, Переволоцкий район, село Рыжковка	0101000020E61000003012DA722E3D4B4033A7CB6262194A40
69141	7	69	1861	29939	50979	\N	52.339070999999997	с.Родничное, Родничная, 33/2		0101000020E61000006153E751F13D4B40D102B4AD662B4A40
69153	7	69	1861	56101	50702	\N	51.802002418601603	с.Родничный Дол, Школьная, 3а	Россия, Оренбургская область, Переволоцкий район, село Родничий Дол	0101000020E61000008F71C5C551474B40CEA96400A8E64940
69125	7	69	1861	29236	50972	\N	52.019272000000001	с. Радовка, Молодежная, 18		0101000020E610000019C748F608194B4040DD408177024A40
69135	7	69	1861	56174	51355	\N	52.029101016548701	х.Пустошь-Адамовка, Центральная, 12	Россия, Оренбургская область, Переволоцкий район, село Пустошь-Адамовка	0101000020E610000055A35703942E4B40F4A3E194B9034A40
69145	7	69	1861	30165	49893	\N	52.244523000000001	с.Претория, Парковая, 2/1а	Россия, Оренбургская область, Переволоцкий район, село Претория	0101000020E6100000B3D1393FC5294B40560F98874C1F4A40
69164	7	69	1861	30843	49859	\N	51.879109	п.Переволоцкий, Советская, 21		0101000020E610000084B872F6CE184B40444FCAA486F04940
69159	7	69	1861	30843	50389	\N	51.875745746381099	п.Переволоцкий, Пионерская, 92	Россия, Оренбургская область, Переволоцкий район, поселок Переволоцкий	0101000020E61000003657CD7344184B4029CDE67118F04940
69160	7	69	1861	30843	50424	\N	51.879109	п.Переволоцкий, Молодежная, 29		0101000020E610000084B872F6CE184B40444FCAA486F04940
69166	7	69	1861	30843	50062	\N	51.869512944860197	п.Переволоцкий, Космическая, 16	Россия, Оренбургская область, Переволоцкий район, поселок Переволоцкий	0101000020E610000093C49272F7174B403239B5334CEF4940
69161	7	69	1861	30843	49766	\N	51.879109	п.Переволоцкий, Западная, 7	Россия, Оренбургская область, Переволоцкий район, поселок Переволоцкий	0101000020E610000084B872F6CE184B40444FCAA486F04940
69143	7	69	1861	30039	50224	\N	51.924359000000003	с.Мамалаевка, Клубная, 2/2		0101000020E610000058552FBFD3064B40B3614D6551F64940
69150	7	69	1861	30394	50675	\N	52.274216000000003	с.Кутлумбетово, Уран, 1		0101000020E61000004E29AF95D0494B401D05888219234A40
69148	7	69	1861	56167	51339	\N	52.327592000000003	с.Верхний Кунакбай, Солнечная, 18а	Россия, Оренбургская область, Переволоцкий район, село Кунакбай	0101000020E6100000FFB0A54753214B403337DF88EE294A40
69140	7	69	1861	48170	50569	\N	52.298912999999999	с.Кубанка, Пионерская, 92		0101000020E61000001903EB387E3A4B40B4ACFBC742264A40
69154	7	69	1861	48426	51029	\N	51.757865000000002	с.Краснополье, Набережная, 3		0101000020E6100000FC389A232B394B403BE466B801E14940
69136	7	69	1861	56087	50631	\N	52.316343395850303	с.Кичкасс, Ленинская, 21б	Россия, Оренбургская область, Переволоцкий район, село Кичкас	0101000020E6100000EC88433690344B40C6A86BED7D284A40
69133	7	69	1861	29599	51034	\N	52.019278	с.Кариновка, Центральная, 2		0101000020E6100000DB8651103C444B4022C495B377024A40
69144	7	69	1861	48230	51301	\N	51.959158000000002	с.Капитоновка, Школьная, 17/4		0101000020E610000049BBD1C77C0E4B4030D978B0C5FA4940
69147	7	69	1861	56172	51350	\N	52.2245933689033	с.Камышовка, Раздольная, 1б	Россия, Оренбургская область, Переволоцкий район, село Камышевка	0101000020E610000001A777F17E304B408CF4A276BF1C4A40
69131	7	69	1861	29505	50647	\N	51.693216999999997	с.Зубочистка, Восточная, 9б		0101000020E6100000C18C2958E31C4B40FF03AC55BBD84940
69132	7	69	1861	29521	50564	\N	51.667330999999997	с.Зубочистка Вторая, Центральная, 13	Россия, Оренбургская область, Переволоцкий район, село Зубочистка Вторая	0101000020E6100000AD510FD1E8184B40B14D2A1A6BD54940
69129	7	69	1861	29407	50522	\N	51.899107000000001	с.Донецкое, Советская, 55	Россия, Оренбургская область, Переволоцкий район, село Донецкое	0101000020E6100000FD6838656E344B40664D2CF015F34940
69138	7	69	1861	48107	50976	\N	52.334212000000001	с.Долиновка, Центральная, 34		0101000020E6100000427A8A1C223A4B4023F77475C72A4A40
69137	7	69	1861	29786	50978	\N	52.331102999999999	с.Габдрафиково, Школьная, 1б		0101000020E6100000C59107228B304B40C24D4695612A4A40
69151	7	69	1861	48366	50841	\N	52.269896000000003	с.Алмала, Школьная, 7		0101000020E6100000E08442041C4E4B401EA9BEF38B224A40
69152	7	69	1861	30497	50674	\N	52.238917999999998	с.Алисово, Союзная, 35		0101000020E61000006B4606B98B464B407E3672DD941E4A40
69124	7	69	1861	47837	50990	\N	52.074539000000001	с. Адамовка, Школьная, 2		0101000020E6100000CA6C9049461A4B4066A3737E8A094A40
69122	7	69	1861	29108	51296	\N	52.093234000000002	с.Абрамовка, Школьная, 1		0101000020E61000005DC5E23785234B4009707A17EF0B4A40
69084	7	69	1655	47087	50252	\N	51.696997000000003	с.Шапошниково, ул.Молодежная, д.20		0101000020E6100000AC55BB26A4A549407F349C3237D94940
69116	7	69	1655	47697	50509	\N	52.065814000000003	п.Фурманов, Рабочая, 18	Россия, Оренбургская область, Первомайский район, село Фурманов	0101000020E6100000CC28965B5ACF49403ACFD8976C084A40
69092	7	69	1655	47245	\N	\N	51.622757	п.Уральский, Спортивная, 2	Россия, Оренбургская область, Первомайский район, село Уральский	0101000020E6100000AA108FC4CBD34940732D5A80B6CF4940
69094	7	69	1655	47277	51293	\N	51.756638000000002	п.Ударный, Школьная, 15		0101000020E6100000DAE21A9FC91E4A4097749483D9E04940
69117	7	69	1655	47712	\N	\N	52.195847999999998	п.Тюльпан, Микрорайон, 10		0101000020E6100000EFAEB321FFC84940567E198C11194A40
69081	7	69	1655	27239	51226	\N	51.519934999999997	село Теплое, Кооперативная, 6		0101000020E61000009A3E3BE0BAC24940DB85E63A8DC24940
69103	7	69	1655	28232	50667	\N	51.928001999999999	п.Степнянка, Гагарина, 2а		0101000020E6100000C51B9947FED84940B14F00C5C8F64940
68191	7	69	1655	47615	50456	\N	52.042261000000003	с. Советское, Валерия Карпова, 29		0101000020E61000001250E10852E14940B972F6CE68054A40
69102	7	69	1655	47455	50565	\N	51.942106000000003	с.Соболево, Комсомольская, 6		0101000020E61000009B728577B9DC4940C5AEEDED96F84940
68967	7	69	1655	21961	50967	\N	51.933121999999997	село Сергиевка, улиц Центральная, дом 88/1		0101000020E6100000B96DDFA3FEF24940CC96AC8A70F74940
69118	7	69	1655	21961	50980	\N	51.933121999999997	с.Сергиевка, Первоцилинников, 4		0101000020E6100000B96DDFA3FEF24940CC96AC8A70F74940
69121	7	69	1655	47784	50512	\N	52.000307999999997	п.Революционный, Школьная, 10		0101000020E610000078F01307D0174A40ADF6B0170A004A40
69109	7	69	1655	56145	51115	\N	51.884623744985497	п.Пономарево, Строительная, 16	Россия, Оренбургская область, Первомайский район, село Пономарев	0101000020E6100000D5B48B69A6CD4940DCA0F65B3BF14940
69105	7	69	1655	47508	\N	\N	51.904536999999998	п.Первомайский, улица Гагарина, 10а	Россия, Оренбургская область, Первомайский район, село Первомайский	0101000020E6100000F7B0170AD8D24940CF8250DEC7F34940
69106	7	69	1655	47508	49987	\N	51.904536999999998	п.Первомайский, улица  Нефтяников, 5	Россия, Оренбургская область, Первомайский район, село Первомайский	0101000020E6100000F7B0170AD8D24940CF8250DEC7F34940
69107	7	69	1655	47508	49856	\N	51.903198230213	п.Первомайский, улица Гагарина, 10Б	Россия, Оренбургская область, Первомайский район, село Первомайский	0101000020E6100000B18BA2073ED2494004E8F7FD9BF34940
69086	7	69	1655	27455	50319	\N	51.790733000000003	Оренбургская область, с.Озерное, Центральная, 25а		0101000020E6100000DBA6785C54BB49401A6F2BBD36E54940
69119	7	69	1655	56190	51383	\N	51.938528341878303	п.Новостройка, Рязанская, 41а	Россия, Оренбургская область, Первомайский район, село Новая Стройка	0101000020E6100000008DD2A57FF74940AD307DAF21F84940
69120	7	69	1655	49115	50644	\N	51.989561000000002	с.Мирошкино, Центральная, 31	Россия, Оренбургская область, Первомайский район, село Мирошкино	0101000020E6100000338CBB41B4064A40D33252EFA9FE4940
69088	7	69	1655	27535	50561	\N	51.764023999999999	п.Малый Зайкин, Клубная, 8		0101000020E610000000AE64C7469E4940F7ADD689CBE14940
69110	7	69	1655	47594	50968	\N	51.852741999999999	п.Маевка, Школьная, 5а		0101000020E61000008C118942CBC449407BF65CA626ED4940
69096	7	69	1655	56186	51376	\N	51.848619999999997	п.Ляшево, Степная, 1а	Россия, Оренбургская область, Первомайский район, село Лящев	0101000020E6100000F623456458BD4940A25D85949FEC4940
69100	7	69	1655	47409	51030	\N	51.938457780210001	п.Лесопитомник, Набережная, 3	Россия, Оренбургская область, Первомайский район, село Лесопитомник	0101000020E61000005265187783D44940B45549641FF84940
69097	7	69	1655	47339	50537	\N	51.9364384880191	п.Ленинский, Школьная, 12а	Россия, Оренбургская область, Первомайский район, село Ленинский	0101000020E6100000A5BC564277B14940A75D4C33DDF74940
69089	7	69	1655	21779	50850	\N	51.802869999999999	п.Курлин, ул.Молодежная, д.1		0101000020E610000046D3D9C9E07C49404278B471C4E64940
69082	7	69	1655	40384	50513	\N	51.578702	село Красное, Ленина, 51		0101000020E6100000E1ECD63219BE49409D103AE812CA4940
69083	7	69	1655	47054	50966	\N	51.629047	с.Каменное, Школьная, 7		0101000020E610000043E21E4B1FBA4940CE52B29C84D04940
69098	7	69	1655	47374	51297	\N	51.979976000000001	п.Зори, Набережная, 8а		0101000020E6100000F06DFAB31FB54940B56E83DA6FFD4940
69095	7	69	1655	47301	\N	\N	51.879185999999997	п.Дружный, Набережная, 11	Россия, Оренбургская область, Первомайский район, село Дружный	0101000020E6100000705F07CE191D4A40EF8CB62A89F04940
68911	7	69	1655	48174	50646	\N	51.553576	п.Ветелки, Школьная, 3\\1		0101000020E610000070CFF3A78DD04940DDEC0F94DBC64940
69085	7	69	1655	27394	50670	\N	51.707104999999999	п.Вербовый Сырт, Наумова, 8		0101000020E610000027F56569A7A2494046EBA86A82DA4940
69090	7	69	1655	27623	51299	\N	51.836706999999997	п.Большой Зайкин, Школьная, 10		0101000020E6100000E0F599B33E934940C9AA083719EB4940
69093	7	69	1655	27783	51295	\N	51.711157	п.Большепрудный, Центральная, 26		0101000020E6100000098849B890074A4026A94C3107DB4940
69113	7	69	1655	47643	51298	\N	52.038201000000001	п Башкировка, Заречная, 9а		0101000020E6100000BD19355F25CF494056D636C5E3044A40
69045	7	69	1754	25574	51291	\N	51.192669000000002	Оренбургская область, муниципальное образование город Орск, Советский район, село Ора, Центральная, 1А		0101000020E6100000C1E10511A95B4D40FDF9B660A9984940
69022	7	69	1754	24508	\N	\N	51.162815999999999	Оренбургская область, муниципальное образование город Орск, Октябрьский район, пос. Джанаталап, здание школы № 12	Россия, Оренбургская область, Орск городской округ, село Джанаталап	0101000020E61000006F675F7990404D40FDA19927D7944940
68955	7	69	1244	46004	50848	\N	51.741444000000001	поселок Яровой, улица Школьная, д.14		0101000020E610000095BBCFF1D1D64B4060E811A3E7DE4940
68970	7	69	1244	22071	49827	\N	51.888217665577699	поселок Юный, улица Мира, дом 2А	Россия, Оренбургская область, Оренбургский район, поселок Юный	0101000020E6100000C1E3DBBB06714B40F9DB9E20B1F14940
68989	7	69	1244	49436	50502	\N	51.533825	поселок Экспериментальный, улица Лесная, дом 1		0101000020E6100000EF37DA71C3834B40C364AA6054C44940
68988	7	69	1244	49436	50497	\N	51.533825	поселок Экспериментальный, улица Культурная, дом 1		0101000020E6100000EF37DA71C3834B40C364AA6054C44940
68953	7	69	1244	26981	51346	\N	51.818738580719803	х.Чулошников, ул.Центральная, 23		0101000020E6100000A7B1BD16F4D44B40D97A8670CCE84940
68942	7	69	1244	20738	49792	\N	51.722166000000001	поселок Чкалов, улица Ленина, дом 44		0101000020E6100000E57FF277EFAE4B403E247CEF6FDC4940
68959	7	69	1244	49050	49825	\N	51.937475500468203	поселок Чебеньки, улица Школьная, дом 7	Россия, Оренбургская область, Оренбургский район, село Чебеньки	0101000020E6100000624CFA7B29DA4B407764AC36FFF74940
68958	7	69	1244	49050	50387	\N	51.937719999999999	поселок Чебеньки, улица Мало-Элеваторная, дом 4	Россия, Оренбургская область, Оренбургский район, село Чебеньки	0101000020E610000060E4654D2CDA4B400E677E3507F84940
68960	7	69	1244	49050	49857	\N	51.937719999999999	поселок Чебеньки, улица 8 Марта, дом 10		0101000020E610000060E4654D2CDA4B400E677E3507F84940
68965	7	69	1244	21867	51031	\N	51.991512999999998	село Струково, улица Просторная, дом 1		0101000020E610000046B3B27DC8674B408847E2E5E9FE4940
68992	7	69	1244	40364	9950	\N	51.736019593886503	село Старица, улица Центральная, дом 2	Россия, Оренбургская область, Оренбургский район, село Старица	0101000020E6100000E8F527F1B9734B40D99942E735DE4940
68990	7	69	1244	22959	51303	\N	51.497360999999998	поселок Светлогорка, улица Центральная, дом 12		0101000020E610000053D0ED258D8B4B4026A77686A9BF4940
68841	7	69	1244	15513	49778	\N	51.723298999999997	Оренбургская область, муниципальное образование город Оренбург, Промышленный район,п.Самородово, ул.Школьная, 34		0101000020E61000009FB0C403CAC04B40601DC70F95DC4940
68944	7	69	1244	48764	\N	\N	51.481135999999999	поселок Пугачевский, улица Центральная, дом 2	Россия, Оренбургская область, Оренбургский район, село Пугачевский	0101000020E61000006AA2CF4719AF4B40D1764CDD95BD4940
68954	7	69	1244	21311	50441	\N	51.754970999999998	поселок Приуральский, улица Центральная, д. 23		0101000020E6100000B8567BD80BD34B40D636C5E3A2E04940
68986	7	69	1244	47531	\N	\N	51.532055	поселок Первомайский, улица Воронова, дом 14	Россия, Оренбургская область, Оренбургский район, поселок Первомайский	0101000020E6100000AB7823F3C87F4B402E56D4601AC44940
67956	7	69	1244	47531	51272	\N	51.532055	пос.Первомайский, Центральная, 12		0101000020E6100000AB7823F3C87F4B402E56D4601AC44940
68985	7	69	1244	47531	49876	\N	51.532055	поселок Первомайский, улица Березина, дом 1		0101000020E6100000AB7823F3C87F4B402E56D4601AC44940
68987	7	69	1244	47531	50511	\N	51.532055	поселок Первомайский, улица Воронова, дом 26		0101000020E6100000AB7823F3C87F4B402E56D4601AC44940
68945	7	69	1244	56092	50652	\N	51.565004984818202	село Паника, улица Молодежная, дом 1	Россия, Оренбургская область, Оренбургский район, село Паника	0101000020E6100000056B9C4D47A24B40CA89761552C84940
69208	7	69	1244	48324	\N	\N	51.676689000000003	с. Никольское, Площадь Победы(здание администрации МО Никольский сельсовет), 1		0101000020E6100000EE04FBAF73414B400F48C2BE9DD64940
68980	7	69	1244	22547	49960	\N	51.722087999999999	село Нижняя Павловка, улица Советская, дом 60		0101000020E61000000553CDACA5664B40C26A2C616DDC4940
68982	7	69	1244	22547	50562	\N	51.722087999999999	село Нижняя павловка, улица Коммунальная, дом 6		0101000020E61000000553CDACA5664B40C26A2C616DDC4940
68981	7	69	1244	22547	49750	\N	51.722087999999999	село Нижняя Павловка, улица 50 лет Октября, дом 1В		0101000020E61000000553CDACA5664B40C26A2C616DDC4940
68951	7	69	1244	21125	49752	\N	51.766142000000002	село Нежинка, улица Куйбышева, дом 43		0101000020E6100000107A36AB3EAF4B40C80BE9F010E24940
69020	7	69	1244	21475	\N	\N	51.777712000000001	Оренбургская область, муниципальное образование город Орск, Октябрьский район, пос. Мирный, школа  пос. Мирный	Россия, Оренбургская область, Оренбургский район, село Мирный Путь	0101000020E6100000B6813B50A7F04B4077DA1A118CE34940
68957	7	69	1244	21475	51010	\N	51.775475561770698	поселок Мирный путь, улица Школьная, дом 11	Россия, Оренбургская область, Оренбургский район, село Мирный Путь	0101000020E6100000FDA19927D7F04B409C6A2DCC42E34940
68940	7	69	1244	20635	49872	\N	51.699168	поселок Караванный, улица Советская, дом 8		0101000020E610000074ECA012D7D14B40723447567ED94940
68952	7	69	1244	21247	51290	\N	51.774813999999999	село Каменноозерное, улица Центральная, дом 16		0101000020E6100000378B170B43C84B40D13DEB1A2DE34940
68971	7	69	1244	22146	\N	\N	51.993465	село Зубаревка, улица Молодежная, дом 9	Россия, Оренбургская область, Оренбургский район, село Зубаревка	0101000020E6100000DF3653211E554B403E5C72DC29FF4940
68946	7	69	1244	20960	51025	\N	51.509166999999998	поселок Джеланды, улица Прудная, дом 6		0101000020E610000084471B47ACBD4B40E9995E622CC14940
68983	7	69	1244	22687	49753	\N	51.684362	село Дедуровка, улица Рабочая, дом 6		0101000020E61000007993DFA2934F4B4005508C2C99D74940
68899	7	69	1244	56047	49946	\N	51.633833769526902	город Оренбург, с. Городище, ул. Больничная, д. 2	Россия, Оренбургская область, Оренбургский район, село Городище	0101000020E610000097C62FBC92324B40E38BF67821D14940
68969	7	69	1244	48321	50526	\N	51.907904000000002	поселок Горный, переулок Тупой, дом 1		0101000020E6100000E42EC214E5744B402CF4C13236F44940
68956	7	69	1244	48981	51002	\N	51.706653000000003	село Вязовка, улица Новая, дом 25		0101000020E610000079CE16105AE54B40664F029B73DA4940
68961	7	69	1244	21661	50838	\N	51.893372925299303	поселок Былинный, улица Молодежная, дом 9	Россия, Оренбургская область, Оренбургский район, село Былинный	0101000020E610000088B839950CC84B409010E50B5AF24940
68972	7	69	1244	22162	50218	\N	51.95252	село Бродецкое, переулок Школьный, дом 3		0101000020E61000006BF46A80D2544B409964E42CECF94940
68943	7	69	1244	20778	50557	\N	51.715274999999998	село Благословенка, улица Центральная, дом 14		0101000020E6100000F1F109D979A94B40BD5296218EDB4940
68941	7	69	1244	48719	51288	\N	51.669913999999999	поселок Береговой, улица Береговая, дом 45		0101000020E61000006B63EC8497DE4B40F790F0BDBFD54940
68962	7	69	1244	21683	51022	\N	51.851207000000002	поселок Бакалка, улица Молодежная, дом 4		0101000020E610000009FB761211E24B402A90D959F4EC4940
68949	7	69	1244	48852	\N	\N	51.761448999999999	"поселок Аэропорт, здание детского сада ""Скворушка"""	Россия, Оренбургская область, Оренбургский район, село Аэропорт	0101000020E6100000E90AB6114FA84B4034492C2977E14940
69040	7	69	7402	58173	64124	\N	51.230969000000002	Оренбургская область, муниципальное образование город Орск, Октябрьский район, ул. Новосибирская, д. 227	Россия, Оренбургская область, Орск	0101000020E61000001CEC4D0CC9474D40E6B16664909D4940
68777	7	69	1056	12520	50803	\N	52.353436000000002	поселок Шестимирский, Гагарина, 1		0101000020E61000009EEFA7C64B914B40529D0E643D2D4A40
68775	7	69	1056	45447	51163	\N	52.527782000000002	село Успенка, Советская, 80		0101000020E610000039D21918797B4B4070B54E5C8E434A40
68781	7	69	1056	12698	50499	\N	52.219717000000003	поселок Уранбаш, Больничная, 5		0101000020E6100000363E93FDF3764B4008B0C8AF1F1C4A40
68761	7	69	1056	11759	50961	\N	52.204872000000002	поселок Салмыш, Набережная, 10		0101000020E6100000F0E0270EA0A54B40DDEEE53E391A4A40
68776	7	69	1056	45457	50417	\N	52.407435	поселок Российский, переулок Солнечный, 16		0101000020E61000000168942EFD7D4B40751F80D426344A40
68780	7	69	1056	12656	50964	\N	52.256011000000001	село Портнов, Придорожная, 2		0101000020E61000008789062978744B404835ECF7C4204A40
69026	7	69	1056	40277	9698	\N	51.237856707983497	Оренбургская область, муниципальное образование город Орск, Октябрьский район, пр. Ленина, д. 41	Россия, Оренбургская область, Орск	0101000020E610000018EE5C18E9474D40F50F2219729E4940
68751	7	69	1056	46406	50318	\N	52.350245000000001	село Октябрьское, переулок Центральный, 17		0101000020E61000001B9C887E6DBF4B40344B02D4D42C4A40
69301	7	69	1056	46406	50863	\N	52.350245000000001	с.Октябрьское, ул.Молодежная дом 24а		0101000020E61000001B9C887E6DBF4B40344B02D4D42C4A40
69602	7	69	1056	46406	50538	\N	52.352189634326898	село Октябрьское, Луначарского, 43	Россия, Оренбургская область, Октябрьский район, село Октябрьское	0101000020E610000029594E42E9BF4B4037FDD98F142D4A40
68749	7	69	1056	46406	50418	\N	52.350245000000001	село Октябрьское, Дедовская, 43	Россия, Оренбургская область, Октябрьский район, село Октябрьское	0101000020E61000001B9C887E6DBF4B40344B02D4D42C4A40
68765	7	69	1056	49546	51151	\N	52.369483000000002	село Новотроицкое, Луговая, 8		0101000020E61000009240834D9DA74B40C8B60C384B2F4A40
68753	7	69	1056	9273	50314	\N	52.365372872039501	село Новоникитино, Школьная, 4	Россия, Оренбургская область, Октябрьский район, село Новоникитино	0101000020E61000005DC5E23785C94B40B3EBDE8AC42E4A40
68752	7	69	1056	11286	51016	\N	52.277886000000002	село Новобиккулово, Новобиккуловская, 21/3		0101000020E6100000C669882AFCAB4B401502B9C491234A40
68766	7	69	1056	11976	50498	\N	52.468823999999998	село Нижний Гумбет, Центральная, 112-А		0101000020E6100000EFC682C2A0B64B403ACAC16C023C4A40
68718	7	69	1056	9640	50958	\N	52.409654000000003	Междугорный, Школьная, 1		0101000020E6100000C5E3A25A44B04B407A56D28A6F344A40
68762	7	69	1056	56065	50328	\N	52.247020652849301	село Марьевка, Школьная, 2	Россия, Оренбургская область, Октябрьский район, село Марьевка	0101000020E61000006BBA9EE8BAA44B406D3656629E1F4A40
68769	7	69	1056	56133	50963	\N	52.653196999999999	село Кузьминовка, Школьная, 8-А	Россия, Оренбургская область, Октябрьский район, село Кузьминовка	0101000020E61000005531957EC2B54B40336C94F59B534A40
68755	7	69	1056	49388	50304	\N	52.332754000000001	поселок Краснооктябрьский, Интернатская, 11-А		0101000020E61000006CE9D1544FC44B407DCEDDAE972A4A40
68779	7	69	1056	45509	51287	\N	52.287461	село Комиссарово, Центральная, 48		0101000020E6100000740D33349E684B400FF0A485CB244A40
68763	7	69	1056	49521	50794	\N	52.301721000000001	село Каменка, Центральная, 70	Россия, Оренбургская область, Октябрьский район, село Каменка	0101000020E61000009E29745E639B4B401AC231CB9E264A40
69206	7	69	1056	49521	64220	\N	52.301294601165502	с. Каменка, Садовая (Каменская основная общеобразовательная школа), 1	Россия, Оренбургская область, Октябрьский район, село Каменка	0101000020E6100000350873BB979B4B4063B9A5D590264A40
68759	7	69	1056	11630	50610	\N	52.179918999999998	Второе Имангулово, Школьная, 3		0101000020E610000066BB421F2CAF4B40EA76F69507174A40
68760	7	69	1056	11699	50791	\N	52.211081	Первое Имангулово, Центральная, 19		0101000020E61000009EEBFB7090A84B404BE7C3B3041B4A40
68756	7	69	1056	49409	50970	\N	52.261032999999998	поселок Зеленый Дол, Центральная, 39		0101000020E610000039D55A9885D84B40A016838769214A40
68757	7	69	1056	23946	51186	\N	52.220289999999999	поселок Взгорье, улица Майская,4а		0101000020E61000002BF9D85DA0C84B4063D17476321C4A40
68768	7	69	1056	12098	50792	\N	52.561523999999999	село Верхний Гумбет, Центральная, 18-А		0101000020E610000010CAFB389AAF4B40A5F5B704E0474A40
68019	7	69	1056	45492	\N	\N	52.321064	с.Васильевка, Украинская (школа), 12	Россия, Оренбургская область, Октябрьский район, село Васильевка	0101000020E6100000CDE506431D7E4B4023F609A018294A40
68778	7	69	1056	45492	50614	\N	52.321064	село Васильевка, Школьная, 1		0101000020E6100000CDE506431D7E4B4023F609A018294A40
68773	7	69	1056	45420	49916	\N	52.453865999999998	село Буланово, Гагарина, 11		0101000020E6100000B073D3669C944B401762F547183A4A40
68758	7	69	1056	49440	50962	\N	52.189371999999999	поселок Броды, Новая, 1-А		0101000020E610000089D00836AEB54B40996379573D184A40
68764	7	69	1056	49525	51018	\N	52.318047	село Биккулово, Школьная, 10		0101000020E61000004ACE893DB4A74B40A3CB9BC3B5284A40
68774	7	69	1056	45424	51284	\N	52.519218000000002	село Белозерка, Школьная, 1		0101000020E6100000B75D68AED38A4B404DBF44BC75424A40
68783	7	69	1056	12779	50965	\N	52.145795	село Анатольевка, Центральная, 30		0101000020E61000009C69C2F693AB4B40CD751A69A9124A40
68741	7	69	1148	10788	\N	\N	51.150025999999997	с.Хабарное	Россия, Оренбургская область, Новотроицк городской округ, село Хабарное	0101000020E6100000D064FF3C0D1E4D405CC64D0D34934940
68740	7	69	1148	59502	\N	\N	51.136714396496501	с.Пригорное	Россия, Оренбургская область, Новотроицк городской округ, село Крык-Пшак	0101000020E610000052B9895A9A314D40E27327D87F914940
68744	7	69	1148	49249	\N	\N	51.29674	с.Новоникольск	Россия, Оренбургская область, Новотроицк городской округ, село Новоникольск	0101000020E6100000B2648EE55D214D4020B58993FBA54940
68742	7	69	1148	10865	\N	\N	51.191105999999998	п.Аккермановка	Россия, Оренбургская область, Новотроицк городской округ, поселок Аккермановка	0101000020E610000057CC086F0F1C4D40E108522976984940
68698	7	69	891	48493	49838	\N	52.572507904585301	п.Ясногорский, Парковая  (здание СДК), 17	Россия, Оренбургская область, Новосергиевский район, село Ясногорский	0101000020E6100000A930B610E4024B40645930F147494A40
68664	7	69	891	47849	51276	\N	51.954224000000004	с.Черепаново, Пушкина (здание Черепановского клуба), 7		0101000020E6100000290989B48DCD4A407787140324FA4940
68709	7	69	891	9265	\N	\N	52.203360000000004	с.Хуторка, Советская  (здание СДК), 52	Россия, Оренбургская область, Новосергиевский район, село Хуторка	0101000020E6100000A988D349B6E64A4044A852B3071A4A40
68700	7	69	891	8859	50793	\N	52.457279999999997	с.Хлебовка, Лесная  (здание клуба), 15		0101000020E6100000018A912573FC4A40B48EAA26883A4A40
68711	7	69	891	9327	50297	\N	52.127338000000002	с.Сузаново, Советская  (здание СДК), 4		0101000020E6100000942EFD4B52E74A40DFC4909C4C104A40
68694	7	69	891	8552	50515	\N	52.335614999999997	с.Судьбодаровка, Советская (здание СДК), 33А		0101000020E610000076FBAC32530A4B400586AC6EF52A4A40
68667	7	69	891	47900	50295	\N	52.089272000000001	с.Старобелогорка, Кооперативная  (здание СДК), 54		0101000020E6100000EF3A1BF2CF9E4A406939D0436D0B4A40
68702	7	69	891	8921	50553	\N	52.398417999999999	п.Среднеуранский, Школьная  (здание средней школы), 8		0101000020E61000007784D38217FB4A40A1116C5CFF324A40
68680	7	69	891	7872	50300	\N	51.854427663922102	с.Рыбкино, Чапаева  (здание СДК), 12	Россия, Оренбургская область, Новосергиевский район, село Рыбкино	0101000020E6100000C34A051555FB4A40B2648EE55DED4940
68666	7	69	891	56165	51337	\N	52.173778010213503	п.Родниковое Озеро, Луговая (здание начальной школы), 32	Россия, Оренбургская область, Новосергиевский район, село Родниковое Озеро	0101000020E6100000425E0F26C5C34A40D461855B3E164A40
68675	7	69	891	48047	50952	\N	51.833818000000001	с.Ржавка, Центральная  (здание школы), 3А		0101000020E610000090D8EE1EA0BF4A407768588CBAEA4940
68691	7	69	891	56198	51399	\N	52.317782999999999	с.Приуранка, Советская (здание сельского клуба), 1А	Россия, Оренбургская область, Новосергиевский район, село Приуранный	0101000020E610000087A4164A261B4B40C51C041DAD284A40
68699	7	69	891	48507	50973	\N	52.623883999999997	п.Привольный, Заречная  (здание школы), 13		0101000020E6100000D89DEE3CF1EA4A40B33F506EDB4F4A40
68683	7	69	891	56075	50507	\N	51.988657000000003	с.Покровка, Красноармейская  (здание клуба ПУ-55), 21	Россия, Оренбургская область, Новосергиевский район, село Покровка	0101000020E6100000E449D23593EF4A4012FB04508CFE4940
68682	7	69	891	56075	50506	\N	51.988869312667703	с.Покровка, Кооперативная  (здание средней школы), 12	Россия, Оренбургская область, Новосергиевский район, село Покровка	0101000020E61000004837C2A222F04A409D83674293FE4940
68685	7	69	891	8131	50486	\N	51.972920000000002	с.Платовка, Совхозная   (здание СДК), 22		0101000020E6100000E7C75F5AD4F34A40EACF7EA488FC4940
68657	7	69	891	6849	49836	\N	52.095320000000001	"п.Новосергиевка, Проспект Калинина (кинотеатр ""Колос""), 101"	Россия, Оренбургская область, Новосергиевский район, поселок Новосергиевка	0101000020E6100000A648BE1248D34A40CE531D72330C4A40
68659	7	69	891	6849	50034	\N	52.082684	"п.Новосергиевка, Мичурина (здание конторы ОАО ""Новосергиевский маслозавод""), 1"	Россия, Оренбургская область, Новосергиевский район, поселок Новосергиевка	0101000020E6100000F5D8960167D34A4084F3A963950A4A40
68656	7	69	891	6849	50028	\N	52.086509999999997	"п.Новосергиевка, Маяковского (здание МОУ ""НСОШ №1""), 2"		0101000020E6100000083D9B559FD34A4073637AC2120B4A40
68658	7	69	891	6849	50032	\N	52.086509999999997	"п.Новосергиевка, Красногвардейская (здание МОУ ""НСОШ №3""), 1"		0101000020E6100000083D9B559FD34A4073637AC2120B4A40
68660	7	69	891	6849	49837	\N	52.086509999999997	п.Новосергиевка, Карла Маркса (СДК южного микрорайона), 17Б		0101000020E6100000083D9B559FD34A4073637AC2120B4A40
68661	7	69	891	6849	49923	\N	52.086509999999997	"п.Новосергиевка, Горького (здание МОУ ""НСОШ №4""), 72"		0101000020E6100000083D9B559FD34A4073637AC2120B4A40
68669	7	69	891	7387	50786	\N	51.950200000000002	с.Новородниковка, Дружбы  (здание школы), 5		0101000020E6100000693BA6EECAA44A4061545227A0F94940
68670	7	69	891	7429	51285	\N	51.996997999999998	с.Новокинделька, переулок Тупой  (здание школы), 7	Россия, Оренбургская область, Новосергиевский район, село Новокинделька	0101000020E61000009354A69883B24A40B51666A19DFF4940
68692	7	69	891	8465	50959	\N	52.343015999999999	п.Нижний Кунакбай, Центральная  (здание школы), 15А		0101000020E6100000C22FF5F3A6124B409B00C3F2E72B4A40
68705	7	69	891	48614	50613	\N	52.430140000000002	с.Нестеровка, Грейдерная  (здание СДК), 1		0101000020E6100000F702B34291DA4A40C959D8D30E374A40
68674	7	69	891	7603	50290	\N	51.808739000000003	с.Мустаево, Школьная   (здание средней школы), 5		0101000020E6100000A20C553195B24A40F8FF71C284E74940
68690	7	69	891	48351	51097	\N	52.149695999999999	с.Мрясово, Центральная  (здание СДК), 38		0101000020E610000043A9BD88B6054B40C72B103D29134A40
68710	7	69	891	48710	50790	\N	52.159520000000001	с.Малахово, Речная  (здание Малаховской средней школы), 16		0101000020E6100000D105F52D73E64A406A87BF266B144A40
68663	7	69	891	7105	51274	\N	52.027501999999998	с.Лебяжка, Советская (здание Лебяжинского клуба), 27		0101000020E6100000DE54A4C2D8CA4A408C497F2F85034A40
68671	7	69	891	7497	51190	\N	51.968254000000002	с.Лапаз, ул.Правительственная,3		0101000020E6100000D1798D5DA2BE4A40501C40BFEFFB4940
68697	7	69	891	56204	51412	\N	52.593334554084301	с.Кутуш, Степная  (здание СДК), 4	Россия, Оренбургская область, Новосергиевский район, село Кутушево	0101000020E6100000E272BC02D1FB4A403D49BA66F24B4A40
68677	7	69	891	7744	50478	\N	51.879854000000002	с.Кулагино, Центральная  (здание школы), 19		0101000020E61000008CF678211DD24A409DA04D0E9FF04940
68689	7	69	891	48331	51292	\N	52.156458999999998	с.Кувай, переулок Клубный  (здание СДК), 4		0101000020E6100000B6B9313D61F34A401A1538D906144A40
68708	7	69	891	56152	51168	\N	52.213940000000001	п.Красная Поляна, Садовая  (здание Краснополянской школы), 24		0101000020E6100000DEC83CF207CF4A4033A7CB62621B4A40
68681	7	69	891	47033	50822	\N	52.012227000000003	с.Козловка, Новая  (здание клуба), 1А		0101000020E610000052103CBEBDE74A40699082A790014A40
69186	7	69	891	48940	50872	\N	52.469307000000001	С.Ключевка, ул.Центральная 35	Россия, Оренбургская область, Новосергиевский район, село Ключевка	0101000020E61000003106D671FCD44A4056647440123C4A40
68695	7	69	891	8638	50788	\N	52.350020000000001	с.Камышка, Мира (здание сельского клуба), 16Б		0101000020E61000000DC7F31950054B4014799274CD2C4A40
68673	7	69	891	56149	51150	\N	51.803998687349797	с.Измайловка, Школьная  (здание СДК), 13	Россия, Оренбургская область, Новосергиевский район, село Измайловка	0101000020E6100000EB8B84B69CA94A4023827170E9E64940
68662	7	69	891	7043	50785	\N	52.039065000000001	с.Землянка, Советская (здание Землянского СДК), 8А		0101000020E610000007B47405DBDC4A4089B5F81400054A40
68676	7	69	891	48077	51281	\N	51.908127	с.Дедово, Солнечная  (здание клуба), 11		0101000020E61000001D71C806D2D74A40ABCE6A813DF44940
68704	7	69	891	9047	50956	\N	52.384112999999999	п.Губовский, Школьная  (здание Губовского клуба), 17		0101000020E610000023D74D29AFF54A40F67B629D2A314A40
68688	7	69	891	62082	81113	\N	52.146019000000003	п.Горный, Школьная  (здание школы), 6	Россия, Оренбургская область, Новосергиевский район, село Горный	0101000020E6100000B39602D2FE074B401DCC26C0B0124A40
68672	7	69	891	47993	50303	\N	51.782286999999997	с.Герасимовка, ул.Победы (здание СДК), 2А		0101000020E61000002AC8CF46AEA34A40008BFCFA21E44940
68679	7	69	891	7833	51279	\N	51.796615000000003	с.Волостновка, Ленина  (здание ФАПа), 3А		0101000020E6100000226FB9FAB1E74A406440F67AF7E54940
68686	7	69	891	8169	51282	\N	51.948374000000001	с.Верхняя Платовка, Луговая  (здание СДК), 2А		0101000020E61000004F0647C9ABFD4A403830B95164F94940
68668	7	69	891	47933	50784	\N	52.011423000000001	с.Варшавка, Центральная  (здание школы), 19		0101000020E61000001D1D5723BBA24A400BB6114F76014A40
68701	7	69	891	8907	50957	\N	52.454788000000001	с.Берестовка, Старая  (здание СДК), 13	Россия, Оренбургская область, Новосергиевский район, село Берестовка	0101000020E6100000DD0A6135960C4B407F4E417E363A4A40
68665	7	69	891	47860	50375	\N	52.200915000000002	с.Барабановка, Центральная  (здание СДК), 156		0101000020E6100000478D093197BE4A404F232D95B7194A40
68703	7	69	891	9002	\N	\N	52.390262999999997	с.Балейка, Зиновьева  (здание Балейского клуба), 12	Россия, Оренбургская область, Новосергиевский район, село Балейка	0101000020E6100000F44D9A0645ED4A405FEB5223F4314A40
68693	7	69	891	48400	50787	\N	52.338174000000002	с.Ахмерово, Подгорная  (здание клуба), 8А		0101000020E6100000ACC43C2B690F4B40C32D1F49492B4A40
68687	7	69	891	62083	81114	\N	52.046722000000003	с.Александровка, Центральная  (здание школы), 4	Россия, Оренбургская область, Новосергиевский район, село Александровка	0101000020E6100000018750A566F54A407A008BFCFA054A40
68636	7	69	790	56063	50551	\N	51.364142999999999	Оренбургская область, Новоорский район, Новоорский поссовет,ст. Новоорск, Мостовая, 10		0101000020E610000055A52DAEF1834D409E08E23C9CAE4940
68639	7	69	790	5939	\N	\N	51.742040000000003	п.Энергетик,  ПУ-35 дом 14		0101000020E61000004E2B85402E674D407429AE2AFBDE4940
68641	7	69	790	5939	49990	\N	51.742040000000003	Оренбургская область, Новоорский район, Энергетикский п/с, п.Энергетик, Правдухина, 72		0101000020E61000004E2B85402E674D407429AE2AFBDE4940
68640	7	69	790	5939	49740	\N	51.742040000000003	Оренбургская область, Новоорский район, Энергетикский п/с, п.Энергетик, Пионерская, 16	Россия, Оренбургская область, Новоорский район, село Энергетик	0101000020E61000004E2B85402E674D407429AE2AFBDE4940
68646	7	69	790	58904	66982	\N	51.762154812908904	с.Чиликта, ул, Школьная 22	Россия, Оренбургская область, Новоорский район, село Чилекта	0101000020E6100000221ADD41ECA44D40CFBD874B8EE14940
68649	7	69	790	6403	50492	\N	51.366245999999997	Оренбургская область, Новоорский район, Чапаевский  с/с, с.Чапаевка, Школьная, 6		0101000020E610000024287E8CB9974D4039252026E1AE4940
68633	7	69	790	5581	50054	\N	51.38214	Оренбургская область, Новоорский район, Новоорский поссовет, Ленина ул, 38		0101000020E61000003E9468C9E3794D40293FA9F6E9B04940
69078	7	69	790	56076	50516	\N	51.277289039062801	Оренбургская область, город Орск, Советский район, село Ударник, Школьная, 10	Россия, Оренбургская область, Новоорский район, село Ударник	0101000020E6100000865968E734634D403145B9347EA34940
68648	7	69	790	6383	50641	\N	51.517927999999998	с.Тасбулак, ул.Центральная 15		0101000020E61000001A69A9BC1D934D4062D7F6764BC24940
68643	7	69	790	6089	51277	\N	51.528849999999998	Оренбургская область, Новоорский район, Будамшинский с/с,с.Скалистое, Центральная, 1 А		0101000020E61000008A558330B75B4D40AB3E575BB1C34940
68635	7	69	790	56038	49751	\N	51.373525630844398	Оренбургская область, Новоорский район, Новоорский поссовет, микрорайон Водстроя, 2	Россия, Оренбургская область, Новоорский район, поселок Новоорск	0101000020E6100000AA66D652407E4D40541A31B3CFAF4940
68654	7	69	790	56038	49743	\N	51.377494106768602	Оренбургская область, Новоорский р-н, Приреченский с/с,СПК Новоорское, Школьная, 9	Россия, Оренбургская область, Новоорский район, поселок Новоорск	0101000020E6100000E9D495CFF2804D40D63730B951B04940
68634	7	69	790	56038	50101	\N	51.378275905584402	Оренбургская область, Новоорский район, Новоорский поссовет, Ленина, 14	Россия, Оренбургская область, Новоорский район, поселок Новоорск	0101000020E6100000BE88B663EA804D404C6E14596BB04940
68637	7	69	790	56038	50298	\N	51.364519133924098	Оренбургская область, Новоорский район, Новоорский поссовет,ст. Новоорск, Клецова, 14 А	Россия, Оренбургская область, Новоорский район, поселок Новоорск	0101000020E610000064CA87A06A844D40A4E2FF8EA8AE4940
69484	7	69	790	45800	51088	\N	51.297747999999999	п. Молодежный, ул. Комсомольская, 20		0101000020E6100000744012F6EDA44D408639419B1CA64940
68652	7	69	790	6568	51289	\N	51.148212999999998	Оренбургская область, Новоорский район, Горьковский с/с,с.Можаровка, Школьный переулок, 4		0101000020E610000075B169A510884D40C8EBC1A4F8924940
68651	7	69	790	6542	50954	\N	51.251190000000001	Оренбургская область, Новоорский район, Горьковский с/с,с.Лужки, Степная, 8		0101000020E610000013D55B035B8D4D40878A71FE26A04940
68653	7	69	790	6631	49741	\N	51.321024000000001	Оренбургская область, Новоорский район, Кумакский с/с, с.Кумак, Садовая, 42		0101000020E6100000677C5F5CAA6C4D40959D7E5017A94940
69080	7	69	790	56059	50221	\N	51.176833843093497	Оренбургская область, город Орск, Советский район, село Крыловка, Центральная, 1	Россия, Оренбургская область, Новоорский район, село Крыловка	0101000020E61000000B0BEE073C784D4012691B7FA2964940
68655	7	69	790	6704	50782	\N	51.418838000000001	Оренбургская область, Новоорский р-н, Приреченский с/с,с.Красноуральск, Севастопольская, 1		0101000020E61000007B9FAA4203674D403929CC7B9CB54940
68647	7	69	790	6322	50611	\N	51.372324999999996	Оренбургская область, Новоорский район, Караганский с/с, с.Караганка, Ленина, 20		0101000020E6100000E7340BB43BB24D40D93D7958A8AF4940
68644	7	69	790	6176	51278	\N	51.702176999999999	Оренбургская область, Новоорский район, Будамшинский с/с, с.Заморское, Школьная, 9 А		0101000020E61000003753211E89794D406F8099EFE0D94940
68645	7	69	790	6220	50241	\N	51.684530000000002	с.Добровольское, ул. Комсомольская 21		0101000020E610000072F8A41309A24D40C190D5AD9ED74940
68638	7	69	790	5850	50477	\N	51.414603	Оренбургская область, Новоорский район, Новоорский поссовет,п. Гранитный, Школьная, 15		0101000020E610000068588CBAD68E4D4068E90AB611B54940
68650	7	69	790	6465	50483	\N	51.290438000000002	Оренбургская область, Новоорский район, Горьковский с/с, с.Горьковское, Шушаева, 2		0101000020E6100000FCE25295B6844D4001C287122DA54940
68642	7	69	790	6065	50371	\N	51.623036999999997	"Оренбургская область, Новоорский район, Будамшинский с/с, с.Будамша, Костюхина, 1""Б"""		0101000020E6100000293FA9F6E97C4D40569929ADBFCF4940
68631	7	69	7543	62047	81001	\N	51.468559999999997	Оренбургская область, город Медногорск, Горняков, 2А	Россия, Оренбургская область, Медногорск городской округ, село Ракитянка	0101000020E61000001F0F7D772BD14C405C1B2AC6F9BB4940
68614	7	69	552	46861	51148	\N	53.390143000000002	село Тимошкино, улица Школьная, д. 3		0101000020E6100000221807978EB74A40B5E1B034F0B14A40
68602	7	69	552	46142	51185	\N	53.552757999999997	Староякупово, ул. Центральная, 6		0101000020E61000001FD8F15F20BC4A401A4D2EC6C0C64A40
68588	7	69	552	56104	50720	\N	53.421712999999997	село Старокутлумбетьево, улица Центральная, д. 38	Россия, Оренбургская область, Матвеевский район, село Старокутлумбетово	0101000020E6100000054F2157EADF4A4026A60BB1FAB54A40
68601	7	69	552	3850	\N	\N	53.478752999999998	село Староаширово, улица Крайняя, д. 18	Россия, Оренбургская область, Матвеевский район, село Староаширово	0101000020E6100000C4E8B985AEC24A4052EE3EC747BD4A40
68607	7	69	552	4157	9838	\N	53.6082452178821	село Сарай - Гир, улица Советская, д. 100	Россия, Оренбургская область, Матвеевский район, село Сарай-Гир	0101000020E6100000390A100533B24A404E7ADFF8DACD4A40
68608	7	69	552	4157	50282	\N	53.607837000000004	село Сарай-Гир, улица Советская, д. 110		0101000020E610000035EECD6F98B24A403E26529ACDCD4A40
68612	7	69	552	4422	50835	\N	53.452475999999997	Садак, ул. Школьная, 1а		0101000020E61000009AEAC9FCA3C94A40C91CCBBBEAB94A40
68609	7	69	552	46767	50780	\N	53.552709999999998	поселок Пролетаровка, улица Набережная, д. 33		0101000020E61000002BC0779B37AC4A4009168733BFC64A40
68240	7	69	552	58172	64122	\N	53.2356952669682	с.Покровка, ул.Зеленая, 40-а	Россия, Оренбургская область, Матвеевский район, село Покровка	0101000020E6100000768D96033DE44A40556AF6402B9E4A40
68495	7	69	552	26852	50840	\N	53.368673999999999	Новоузели, ул. Садовая, 1в		0101000020E6100000B2BAD573D2CF4A405871AAB530AF4A40
68606	7	69	552	4007	9746	\N	53.2314460474661	село Новожедрино, улица Школьная, д. 1а	Россия, Оренбургская область, Матвеевский район, село Новожедрино	0101000020E6100000761C3F541AB74A401F65C405A09D4A40
68604	7	69	552	4007	50836	\N	53.2315490492294	Новожедрино, ул. Центральная, 36	Россия, Оренбургская область, Матвеевский район, село Новожедрино	0101000020E610000078EC67B114B74A40F435CB65A39D4A40
68603	7	69	552	3944	50833	\N	53.332375999999996	Новоаширово, ул. Верхняя, 1		0101000020E6100000910F7A36ABA84A40D6FCF84B8BAA4A40
68594	7	69	552	3506	50657	\N	53.257326999999997	деревня Нижненовокутлумбетьево, улица Речная, д. 8		0101000020E6100000D11F9A7972D54A405BB05417F0A04A40
68605	7	69	552	46680	50684	\N	53.215321000000003	Натальино, ул. Степная, 20		0101000020E6100000957EC2D9ADBB4A402E9276A38F9B4A40
68600	7	69	552	46119	49839	\N	53.509383999999997	Матвеевка, ул. Комсомольская, 17		0101000020E6100000E146CA1649BD4A40868DB27E33C14A40
68599	7	69	552	46119	49839	\N	53.509383999999997	село Матвеевка, улица Комсомольская, д. 17а		0101000020E6100000E146CA1649BD4A40868DB27E33C14A40
68593	7	69	552	3463	50950	\N	53.279294999999998	село Кульчум, улица Молодежная, д. 5а		0101000020E61000003929CC7B9CE74A40D97745F0BFA34A40
68598	7	69	552	3733	\N	\N	53.490358999999998	Кузькино, ул. Центральная, 20	Россия, Оренбургская область, Матвеевский район, село Кузькино	0101000020E61000007FA1478C9EAB4A404E266E15C4BE4A40
68595	7	69	552	26639	50438	\N	53.280334000000003	Кинельский, ул. Парковая, 5		0101000020E610000038BA4A77D7BF4A407BFA08FCE1A34A40
68678	7	69	552	26639	51354	\N	53.278170386572803	п.Киндельский, Луговая  (здание клуба), 19	Россия, Оренбургская область, Матвеевский район, село Кинельский	0101000020E6100000876C205D6CC04A403A5D16139BA34A40
68591	7	69	552	46054	51161	\N	53.232055000000003	Емельяновка, ул. Ковешникова, 1		0101000020E610000094675E0EBBDD4A40C8EF6DFAB39D4A40
68596	7	69	552	46495	51275	\N	53.177208	посселок Высотный, улица Школьная, д. 3		0101000020E61000006118B0E42ACE4A40774B72C0AE964A40
68592	7	69	552	3415	50953	\N	53.249139	село Верхненовокутлумбетьево, улица Центральная, д. 21б		0101000020E6100000B0E2546B61E24A403E9468C9E39F4A40
68615	7	69	552	46899	50781	\N	53.402481999999999	село Борискино, улица Молодежная, д. 2а		0101000020E610000028B682A625C24A40459DB98784B34A40
68597	7	69	552	3637	51159	\N	53.328083999999997	Африка, ул. Центральная 11		0101000020E61000008EAD6708C7C64A40A12B11A8FEA94A40
68616	7	69	552	45889	51180	\N	53.299733000000003	Азаматово, ул. Центральная, 31		0101000020E6100000B0FF3A376DBC4A401844A4A65DA64A40
69013	7	69	2799	56045	49899	\N	51.759286000000003	Оренбургская область, муниципальное образование город Орск, Ленинский район, Никельщиков проспект, 25		0101000020E61000009C31CC09DA924B40C4279D4830E14940
68574	7	69	325	2387	51149	\N	52.230936999999997	Оренбургская область, Курманаевский район, Андреевский сельсовет, село Ферапонтовка ул.Зеленая, 21		0101000020E6100000878BDCD3D5F34940DA37F7578F1D4A40
68576	7	69	325	2484	50779	\N	52.247988999999997	Оренбургская область, Курманаевский район, Байгоровский сельсовет, село Федоровка ул.Крестьянская, 26		0101000020E6100000C843DFDDCAFC49404562821ABE1F4A40
68568	7	69	325	2041	51266	\N	52.633788000000003	Оренбургская область, Курманаевский район, Лабазинский сельсовет, село Суриково ул. 8 Марта, 13-б		0101000020E61000006612F5824F054A40734C16F71F514A40
68567	7	69	325	1927	50943	\N	52.566352000000002	Оренбургская область, Курманаевский район, Лабазинский сельсовет, село Скворцовка ул.Набережная, 62а		0101000020E6100000F357C85C19124A401903EB387E484A40
68584	7	69	325	2960	51270	\N	52.248170999999999	Оренбургская область, Курманаевский район, Сергеевский сельсовет, село Сергеевка ул.Дорожная, 15		0101000020E6100000D74D29AF95C4494066683C11C41F4A40
68569	7	69	325	56132	50949	\N	52.525464999999997	Оренбургская область, Курманаевский район, Волжский сельсовет, село Семеновка ул.Школьная, 24	Россия, Оренбургская область, Курманаевский район, село Семеновка	0101000020E6100000DBC1887D02DA4940A818E76F42434A40
68572	7	69	325	2268	50008	\N	52.487017999999999	Оренбургская область, Курманаевский район, Ромашкинский сельсовет, село Ромашкино ул. Дорожная, 15		0101000020E610000019E42EC214E749401B48179B563E4A40
68564	7	69	325	1767	51265	\N	52.453493000000002	Оренбургская область, Курманаевский район, Кутушинский сельсовет, село Родионовка ул.Мира, 47		0101000020E61000007D91D09673F7494083FB010F0C3A4A40
68583	7	69	325	2866	51271	\N	52.317298000000001	Оренбургская область, Курманаевский район, Покровский сельсовет, село Покровка ул.Советская, 13		0101000020E6100000FCFCF7E0B5BF4940098B8A389D284A40
69573	7	69	325	1614	\N	\N	52.524253999999999	деревня Петровка, Родниковая, здание начальной школы, 60	Россия, Оренбургская область, Курманаевский район, село Петровка	0101000020E610000041BCAE5FB00F4A400A664CC11A434A40
68561	7	69	325	1614	\N	\N	52.524253999999999	Оренбургская область, Курманаевский район, Курманаевский сельсовет, село Петровка ул.Школьная, 1	Россия, Оренбургская область, Курманаевский район, село Петровка	0101000020E610000041BCAE5FB00F4A400A664CC11A434A40
68566	7	69	325	1911	50947	\N	52.625610999999999	Оренбургская область, Курманаевский район, Лабазинский сельсовет, село Озерки ул.Центральная, 17-б		0101000020E610000044A51133FB1C4A404982700514504A40
68400	7	69	325	1911	50457	\N	52.625610999999999	Озерки, Парковая, 11		0101000020E610000044A51133FB1C4A404982700514504A40
68579	7	69	325	2623	50472	\N	52.39649	Оренбургская область, Курманаевский район, Михайловский сельсовет, село Михайловка ул.Ленина, 14		0101000020E61000000F98874CF9F8494074982F2FC0324A40
68581	7	69	325	2754	51147	\N	52.418047999999999	Оренбургская область, Курманаевский район, Лаврентьевский сельсовет, село Лаврентьевка ул.Победы, 11		0101000020E6100000EA25C632FDD649404014CC9882354A40
68565	7	69	325	1819	49748	\N	52.608021999999998	Оренбургская область, Курманаевский район, Лабазинский сельсовет, село Лабазы ул.Зорина, 12		0101000020E6100000B471C45A7C164A40CF9F36AAD34D4A40
68563	7	69	325	1724	50283	\N	52.441367999999997	Оренбургская область, Курманаевский район, Кутушинский сельсовет, село Кутуши ул.Крестьянская, 36		0101000020E61000005089EB1857FE49401EC022BF7E384A40
68480	7	69	791	29876	51140	\N	52.818134999999998	село Красиково, Пушкинская, 19		0101000020E610000001A60C1CD0D24A40425BCEA5B8684A40
68559	7	69	325	56050	50080	\N	52.509061319872501	Оренбургская область, Курманаевский район, Курманаевский сельсовет, Строительная, 14		0101000020E61000008DB3E908E0084A40A4552DE928414A40
68580	7	69	325	2712	51294	\N	52.371259000000002	Оренбургская область, Курманаевский район, Михайловский сельсовет, село Кретовка ул.Мира, 14-а		0101000020E61000006E50FBAD9DF449403FAC376A852F4A40
68577	7	69	325	2538	50945	\N	52.333666999999998	Оренбургская область, Курманаевский район, Байгоровский сельсовет, село Краснояровка ул.Набережная, 20		0101000020E610000076E272BC02F949409160AA99B52A4A40
68582	7	69	325	2814	50476	\N	52.378269000000003	Оренбургская область, Курманаевский район, Костинский сельсовет, село Костино ул.Центральная, 7		0101000020E61000001B2D077AA8CD49409A0B5C1E6B304A40
68562	7	69	325	1667	50363	\N	52.476208	Оренбургская область, Курманаевский район, Кандауровский сельсовет, село Кандауровка пл.Свердлова, 1		0101000020E6100000A41820D104064A40FA0B3D62F43C4A40
68587	7	69	325	3112	49833	\N	52.209480999999997	Оренбургская область, Курманаевский район, Ефимовский сельсовет, село Ефимовка ул.Первомайская, 9		0101000020E6100000BD1C76DF31064A401211FE45D01A4A40
68590	7	69	325	3311	51286	\N	52.285544000000002	Оренбургская область, Курманаевский район, Васильевский сельсовет, село Егорьевка ул.Восточная, 30а		0101000020E6100000D9B45208E41A4A40D6C8AEB48C244A40
68585	7	69	325	2976	50955	\N	52.243431661472002	Оренбургская область, Курманаевский район, Грачевский сельсовет, село Грачевка ул.Пролетарская, 2	Россия, Оренбургская область, Курманаевский район, село Грачевка	0101000020E6100000A647533D99DB494062669FC7281F4A40
68586	7	69	325	21682	50843	\N	52.170518999999999	с. Гаршино, ул. Крестьянская, д. 20		0101000020E6100000467BBC900EED49405E2C0C91D3154A40
68570	7	69	325	2082	\N	\N	52.525903	Оренбургская область, Курманаевский район, Волжский сельсовет, село Бобровка ул.Центральная, 55	Россия, Оренбургская область, Курманаевский район, село Волжский	0101000020E6100000793D98141FD1494024EF1CCA50434A40
68571	7	69	325	2082	50606	\N	52.525903	Оренбургская область, Курманаевский район, Волжский сельсовет, поселок Волжский ул.Центральная, 5		0101000020E6100000793D98141FD1494024EF1CCA50434A40
68589	7	69	325	3228	50550	\N	52.179985000000002	Оренбургская область, Курманаевский район, Васильевский сельсовет, село Васильевка ул.Мутного, 12-а		0101000020E610000074B680D07A124A40A2629CBF09174A40
69536	7	69	325	46916	50866	\N	52.546427999999999	пос.Бобровка, ул.Школьная, 9		0101000020E6100000ECBDF8A23DCA494031CF4A5AF1454A40
68578	7	69	325	2621	50946	\N	52.296798000000003	Оренбургская область, Курманаевский район, Байгоровский сельсовет, село Байгоровка ул.Советская, 33		0101000020E61000008C0FB3976DF9494055C2137AFD254A40
68573	7	69	325	2279	50414	\N	52.316037999999999	Оренбургская область, Курманаевский район, Андреевский сельсовет, село Андреевка ул.Ленинская, 19		0101000020E61000007C5F5CAAD2F449408925E5EE73284A40
68502	7	69	63	56061	50273	\N	51.527504999999998	Оренбургская область, Кувандыкский район, ст. Дубиновка, Рабочая, д.16, здание клуба ХПП		0101000020E610000008AA46AF066C4C40FDBCA94885C34940
68542	7	69	63	491	50938	\N	51.298012999999997	Оренбургская область,  Кувандыкский район, с. Ялнаир, Школьная, д.20а, здание СК		0101000020E6100000D464C6DB4AE94C4034643C4A25A64940
68499	7	69	63	30812	51254	\N	51.547722999999998	Оренбургская область, Кувандыкский район, д. Юлгутла, С.Юлаева, д.39, здание сельского клуба		0101000020E61000001AF9BCE2A9674C402D228AC91BC64940
68523	7	69	63	56159	51267	\N	51.635756000000001	Оренбургская область,  Кувандыкский район, с. Б. Чураево, Школьная, д.9, здание СОШ	Россия, Оренбургская область, Кувандыкский район, село Чураево	0101000020E61000000EDAAB8F87C44C402E1EDE7360D14940
68505	7	69	63	31088	51257	\N	51.676426999999997	Оренбургская область, Кувандыкский район, с. Чеботарево, Центральная, д.5а, здание СДК		0101000020E6100000094FE8F5277F4C40D190F12895D64940
68512	7	69	63	31450	50348	\N	51.169955000000002	Оренбургская область,  Кувандыкский район, пос. Урал, переулок Школьный, д.2, здание СОШ		0101000020E61000003B6D8D08C6B54C405665DF15C1954940
68535	7	69	63	32489	50655	\N	51.732971999999997	Оренбургская область,  Кувандыкский район, с. Сарбай, Центральная, д.19, здание ФАПа		0101000020E61000002C0C91D3D7FF4C401D71C806D2DD4940
68543	7	69	63	431	50350	\N	51.468451871656598	Оренбургская область,  Кувандыкский район, ст. Сара, Элеваторная, д.9, здание СДК	Россия, Оренбургская область, Кувандыкский район, село Сара	0101000020E6100000E6400FB56DF44C4076DF313CF6BB4940
68541	7	69	63	431	50361	\N	51.393420999999996	Оренбургская область,  Кувандыкский район, с. Сара, Центральная, д.12а, здание администрации сельсовета		0101000020E6100000C85BAE7E6CEA4C40A1478C9E5BB24940
69591	7	69	63	20157	51162	\N	51.376458	Оренбургская область, муниципальное образование город Медногорск, село Рысаево, Центральная, 8	Россия, Оренбургская область, Кувандыкский район, село Рысаево	0101000020E6100000A13028D368C24C40A62897C62FB04940
68501	7	69	63	30896	51261	\N	51.522294000000002	Оренбургская область, Кувандыкский район, д. Русское Канчерово, Школьная, д.12, здание сельского клуба		0101000020E61000007B4CA4349B874C40D272A087DAC24940
68513	7	69	63	31493	51009	\N	51.099787999999997	Оренбургская область,  Кувандыкский район, пос. Ровный, Ровненская, д. 18/2, здание ФАПа		0101000020E6100000D767CEFA94A34C4041446ADAC58C4940
68216	7	69	63	17201	51096	\N	51.527360000000002	Кувандыкский район, д. Рамазаново, Центральная, д.13, здание ФАПа		0101000020E61000008B18761893B84C40FA9B508880C34940
68530	7	69	63	56114	50789	\N	51.684607999999997	Оренбургская область,  Кувандыкский район, с. Подлесное, Центральная, д.14а, здание бывшей нач. школы	Россия, Оренбургская область, Кувандыкский район, село Подлесная	0101000020E6100000D384ED2763044D403C4A253CA1D74940
68511	7	69	63	31404	51146	\N	51.188491999999997	Оренбургская область,  Кувандыкский район, с. Подгорное, Школьная, д.12, здание основной школы		0101000020E6100000C32B499EEBCD4C4060C77F8120984940
68517	7	69	63	31685	50909	\N	51.335324999999997	Оренбургская область,  Кувандыкский район, д. Пехотное, Центральная, д.12, здание ФАПа		0101000020E61000009E45EF54C0814C40FE43FAEDEBAA4940
68527	7	69	63	32120	51269	\N	51.386592	Оренбургская область,  Кувандыкский район,  д.Первомайск, Центральная, д.48а, здание СОШ		0101000020E61000003FE603029DB74C409772BED87BB14940
68531	7	69	63	32321	50471	\N	51.632938000000003	Оренбургская область,  Кувандыкский район, с. Оноприеновка, Мира, д.3а, здание СДК		0101000020E6100000EA2285B2F0E14C40A532C51C04D14940
68515	7	69	63	31586	50604	\N	51.245404999999998	Оренбургская область,  Кувандыкский район, с. Новоуральск, Советская, д.2б, здание СДК		0101000020E6100000C861307F859E4C402FA3586E699F4940
68534	7	69	63	32412	50607	\N	51.771908155203398	Оренбургская область,  Кувандыкский район, с. Новосимбирка, Мира, д.3, здание СДК	Россия, Оренбургская область, Кувандыкский район, село Новосимбирка	0101000020E610000030293E3E21F14C40A9C29FE1CDE24940
68537	7	69	63	115	50941	\N	51.483536999999998	Оренбургская область,  Кувандыкский район, пос. Новосаринский, Школьная, д.2, здание СОШ		0101000020E610000096218E7571F34C40F6B3588AE4BD4940
68503	7	69	63	\N	50934	\N	51.541426000000001	Оренбургская область, Кувандыкский район, д. Новосакмарск, Центральная, д.8, здание магазина ИП Галиуллин Х.Н	Россия, Оренбургская область, Кувандыкский район	0101000020E6100000CF2D742502734C40209A79724DC54940
68526	7	69	63	31006	50951	\N	51.539021489171503	Оренбургская область,  Кувандыкский район, с. Новосамарск, Новосамарская, д.24, здание СДК	Россия, Оренбургская область, Кувандыкский район, село Новосакмарск	0101000020E61000003128D368729F4C40B96DDFA3FEC44940
68528	7	69	63	32176	51268	\N	51.530256999999999	Оренбургская область,  Кувандыкский район,  с.Новопокровка, Молодёжная , д.1, здание СДК		0101000020E610000050E09D7C7AF24C40CFBC1C76DFC34940
68533	7	69	63	32401	51264	\N	51.635705000000002	Оренбургская область,  Кувандыкский район, д. Новоказанка, Горная, д.4а, здание СК		0101000020E61000003EE94482A9D84C40AC730CC85ED14940
68524	7	69	63	31979	\N	\N	51.523049999999998	Оренбургская область,  Кувандыкский район, д. Новая Ракитянка, Школьная, д.1, здание основной школы	Россия, Оренбургская область, Кувандыкский район, село Новая Ракитянка	0101000020E61000002AC93A1C5DD34C401E166A4DF3C24940
68520	7	69	63	56100	50703	\N	51.352983911284198	Оренбургская область,  Кувандыкский район, с. Никольское, Молодёжная, д.11, здание СК		0101000020E6100000C289E8D7D68D4C40710168942EAD4940
68504	7	69	63	31078	50275	\N	51.525303000000001	Оренбургская область, Кувандыкский район, с.Мухамедьярово, Советская , д.24, здание СДК		0101000020E6100000DE03745FCE7A4C40CFBEF2203DC34940
68518	7	69	63	31742	\N	\N	51.095058999999999	Оренбургская область,  Кувандыкский район, пос. Маячный, Советская, д.6, здание интерната Маячной СШ	Россия, Оренбургская область, Кувандыкский район, село Маячный	0101000020E61000007A8D5DA27AC14C406118B0E42A8C4940
68538	7	69	63	238	51260	\N	51.497191999999998	Оренбургская область,  Кувандыкский район, пос. Мазово, Центральная, д.10/3, здание ФАПа		0101000020E6100000145D177E70024D409AEAC9FCA3BF4940
68540	7	69	63	372	50940	\N	51.454014000000001	Оренбургская область,  Кувандыкский район, пос. Лесной, Центральная, д.17, здание ФАПа		0101000020E6100000FFE7305F5EEA4C408CF678211DBA4940
68507	7	69	63	31198	50603	\N	51.550882000000001	Оренбургская область,  Кувандыкский район, с. Куруил, Клубная, д.16, здание СДК		0101000020E6100000A8E0F08288924C4040FA264D83C64940
68510	7	69	63	31352	51258	\N	51.297792999999999	Оренбургская область,  Кувандыкский район, с. Краснощеково, Школьная, д.6, здание основной школы		0101000020E61000003F90BC7328A14C4026FDBD141EA64940
68519	7	69	63	31758	50685	\N	51.377142999999997	Оренбургская область,  Кувандыкский район,  с.Краснознаменка, Центральная, д.6, здание СДК		0101000020E6100000D21A834E089D4C402975C93846B04940
69593	7	69	63	20274	51000	\N	51.293112999999998	Оренбургская область, муниципальное образование город Медногорск, село Кидрясово, Молодежная, 4	Россия, Оренбургская область, Кувандыкский район, село Кидрясово	0101000020E610000047C8409E5DC44C4027840EBA84A54940
68529	7	69	63	32205	51262	\N	51.636315000000003	Оренбургская область,  Кувандыкский район, с. Карагай-Покровка, Школьная, д. 1, здание бывшей школы		0101000020E61000003EB324404DF34C40257A19C572D14940
68508	7	69	63	31269	50682	\N	51.617024999999998	Оренбургская область,  Кувандыкский район, с. Кайракла, Кайраклинская. д.61, здание сельской библиотеки		0101000020E61000000116F9F543864C403EE8D9ACFACE4940
68509	7	69	63	31264	50343	\N	51.235238000000003	Оренбургская область,  Кувандыкский район, с. Ильинка, Новая, д.1, здание СОШ		0101000020E6100000FC1A498270AD4C4063635E471C9E4940
69592	7	69	63	20191	51330	\N	51.415880000000001	Оренбургская область, муниципальное образование город Медногорск, село Идельбаево, Салавата Юлаева, 2	Россия, Оренбургская область, Кувандыкский район, село Идельбаево	0101000020E610000035D1E7A38CC24C40BE874B8E3BB54940
68522	7	69	63	31895	50278	\N	51.506509999999999	Оренбургская область,  Кувандыкский район, с.Ибрагимово, Советская, д.11, здание СДК		0101000020E610000063B83A00E2B84C40698CD651D5C04940
68498	7	69	63	30743	49830	\N	51.561947000000004	Оренбургская область, Кувандыкский район, с. Зиянчурино, переулок Садовый, д.4, здание СДК		0101000020E6100000A8380EBC5A744C40EC8A19E1EDC74940
68474	7	69	791	48591	\N	\N	52.792723000000002	поселок Клинок, Центральная, 28	Россия, Оренбургская область, Красногвардейский район, село Клинок	0101000020E6100000745FCE6C57BC4A40BDE47FF277654A40
68516	7	69	63	31656	\N	\N	51.295343000000003	Оренбургская область,  Кувандыкский район, пос. Залужье, Школьная, д.1а, здание нач. школы	Россия, Оренбургская область, Кувандыкский район, село Залужье	0101000020E61000009AD18F8653924C40200DA7CCCDA54940
68539	7	69	63	266	50936	\N	51.419888999999998	Оренбургская область,  Кувандыкский район, пос. Вьюжный, Центральная, д.10, здание сельской библиотеки		0101000020E6100000749B70AFCCF94C409E7939ECBEB54940
68532	7	69	63	32328	50705	\N	51.738371000000001	Оренбургская область,  Кувандыкский район, с. Верхненазаргулово, Школьная, д.1, здание основной школы		0101000020E6100000CD3AE3FBE2DC4C404CA8E0F082DE4940
68525	7	69	63	32057	50939	\N	51.511488	Оренбургская область,  Кувандыкский район, д. Васильевка, Луговая, д.9/2, здание ФАПа		0101000020E6100000CC457C2766934C40F225547078C14940
68632	7	69	63	56066	50366	\N	51.492494999999998	Оренбургская область, город Медногорск, поселок Блявтамак, Совхозная, 46	Россия, Оренбургская область, Кувандыкский район, село Блявтамак	0101000020E61000003DB665C059C84C40C5387F130ABF4940
69594	7	69	63	20323	51333	\N	51.397492	Оренбургская область, муниципальное образование город Медногорск, село Блява, Центральная, 52	Россия, Оренбургская область, Кувандыкский район, село Блява	0101000020E6100000DFC0E44691DD4C40F8359204E1B24940
68500	7	69	63	30855	50932	\N	51.542946000000001	Оренбургская область, Кувандыкский район, д. Башкирское Канчерово, Советская, д.10а, здание бывшей начальной школы		0101000020E6100000D218ADA3AA7F4C403CBF28417FC54940
68506	7	69	63	31154	50778	\N	51.653348999999999	Оренбургская область, Кувандыкский район, с. Барангулово, Школьная, д.1а, здание сельского клуба		0101000020E6100000A708707A17794C40E9EFA5F0A0D34940
68521	7	69	63	31880	50911	\N	51.3370945594638	Оренбургская область,  Кувандыкский район, д. Адаево, Дорожная, д.1/1, здание сельской библиотеки	Россия, Оренбургская область, Кувандыкский район, село Адаево	0101000020E61000006CCEC133A1A94C409352D0ED25AB4940
68489	7	69	791	30298	50602	\N	52.683866999999999	село Яшкино, площадь Мира, 9		0101000020E610000041B96DDFA3B84A4025E82FF488574A40
68468	7	69	791	59069	67474	\N	52.9027203796919	деревня Яиково, Школьная, 16	Россия, Оренбургская область, Красногвардейский район, село Верхнеяиково	0101000020E61000007B116DC7D4A34A40FAB836548C734A40
68485	7	69	791	30091	50699	\N	52.710898	поселок Юринский, Южная, 9		0101000020E61000005AA148F773E24A405A65A6B4FE5A4A40
68484	7	69	791	30038	50902	\N	52.780571999999999	село Юлты, Школьная, 39а		0101000020E6100000DB3521AD31DE4A402F1686C8E9634A40
68457	7	69	791	28806	51247	\N	52.966346999999999	село Утеево, Школьная, 1а		0101000020E61000005FB532E197F84A403ACB2C42B17B4A40
68460	7	69	791	28958	50466	\N	52.869866000000002	село Токское, пер.Школьный, 1		0101000020E610000025085740A1B24A4080F3E2C4576F4A40
68492	7	69	791	48903	51006	\N	52.617963000000003	поселок Степной, Степная, 2	Россия, Оренбургская область, Красногвардейский район, село Степной	0101000020E6100000878C47A984BB4A40AC915D69194F4A40
69429	7	69	791	48903	50407	\N	52.617963000000003	поселок Степной, Нижняя, 7		0101000020E6100000878C47A984BB4A40AC915D69194F4A40
68481	7	69	791	29918	50777	\N	52.844451999999997	село Староюлдашево, Победы, 84		0101000020E6100000ED0F94DBF6D14A405985CD00176C4A40
68452	7	69	791	48198	51141	\N	53.110486999999999	село Староникольское, Советская, 34		0101000020E6100000494BE5ED08CD4A400BD12170248E4A40
68483	7	69	791	30019	50698	\N	52.752211000000003	село Старобогдановка, Центральная, 32		0101000020E610000093C7D3F203F34A408258367348604A40
68463	7	69	791	29112	50654	\N	52.903213000000001	деревня Среднеильясово, Дружбы, 41		0101000020E61000006A6803B001B54A403929CC7B9C734A40
68494	7	69	791	48951	50467	\N	52.664368000000003	поселок Свердловский, Школьная, 3		0101000020E6100000F04DD36707D64A402541B8020A554A40
68482	7	69	791	48743	50411	\N	52.756298999999999	поселок Пушкинский, Пушкинская, 53а		0101000020E6100000B29E5A7D75EF4A40AE7FD767CE604A40
68465	7	69	791	48432	51142	\N	52.884757	поселок Пролетарка, Школьная, 21		0101000020E6100000469A780778A24A401BF4A5B73F714A40
68455	7	69	791	48258	51255	\N	52.964958000000003	село Преображенка, Молодежная, 2		0101000020E61000009EB30584D6F14A40BD0166BE837B4A40
68345	7	69	791	58175	64143	\N	52.974138929862001	с.Покровка, Новая, 2а	Россия, Оренбургская область, Красногвардейский район, село Покровка	0101000020E61000000D37E0F3C3E84A400B613596B07C4A40
68478	7	69	791	48671	50547	\N	52.832588000000001	село Подольск, Центральная, 118		0101000020E61000001CD2A8C0C9CA4A4062855B3E926A4A40
68470	7	69	791	29494	49730	\N	52.847659	село Плешаново, Советская, 2	Россия, Оренбургская область, Красногвардейский район, село Плешаново	0101000020E6100000349C3237DFBE4A407D941117806C4A40
68472	7	69	791	29494	50601	\N	52.849269999999997	село Плешаново, Ленина, 121		0101000020E6100000723788D68ABE4A40A9BC1DE1B46C4A40
68471	7	69	791	29494	49886	\N	52.849269999999997	село Плешаново, Дружбы, 44		0101000020E6100000723788D68ABE4A40A9BC1DE1B46C4A40
69561	7	69	791	18570	50827	\N	52.995977000000003	село Новоюласка, Дружбы, 7		0101000020E61000006EF7729F1CD34A40BB48A12C7C7F4A40
68491	7	69	791	48884	50937	\N	52.661872000000002	село Новопетровка, Зеленая, 49		0101000020E6100000A8C7B60C38CD4A40AE11C138B8544A40
68464	7	69	791	29151	50332	\N	52.974269999999997	поселок Нижнекристалка, Центральная, 47		0101000020E61000004B94BDA59CB34A40A9BC1DE1B47C4A40
68462	7	69	791	29045	50769	\N	52.913970999999997	деревня Нижнеильясово, Мира, 34		0101000020E6100000B56CAD2F12B24A40073F7100FD744A40
68466	7	69	791	56209	51436	\N	52.888874007069802	село Бахтиярово, Центральная, 54	Россия, Оренбургская область, Красногвардейский район, село Нижнебахтиярово	0101000020E6100000C365153603A64A40E2218C9FC6714A40
68475	7	69	791	29635	51139	\N	52.864702000000001	деревня Малоюлдашево, Центральная, 16а		0101000020E61000004012F6ED24C44A4095641D8EAE6E4A40
68479	7	69	791	29796	50334	\N	52.837442000000003	село Луговск, Центральная, 138	Россия, Оренбургская область, Красногвардейский район, село Луговск	0101000020E6100000E2CD1ABCAFC64A40FF25A94C316B4A40
68476	7	69	791	29662	51253	\N	52.772210000000001	село Кутерля, Мира, 49		0101000020E6100000B2683A3B19CE4A4074D2FBC6D7624A40
68453	7	69	791	28627	50774	\N	53.011578	поселок Кристалка, Центральная, 5		0101000020E6100000AC74779D0DBD4A4032AD4D637B814A40
68486	7	69	791	30162	50341	\N	52.6862414919187	село Кинзелька, Школьная, 7	Россия, Оренбургская область, Красногвардейский район, поселок Кинзелька	0101000020E61000003DB9A64066A14A405116BEBED6574A40
68477	7	69	791	29702	51144	\N	52.787751	село Калтан, Садовая, 54		0101000020E610000069ACFD9DEDC34A4016325706D5644A40
68467	7	69	791	29245	51143	\N	52.874084000000003	поселок Ишалка, Центральная, 49		0101000020E61000003333333333994A407BFA08FCE16F4A40
68170	7	69	791	45648	64111	\N	52.849341057490903	п. Ивановка, Береговая, 21	Россия, Оренбургская область, Красногвардейский район, село Ивановка	0101000020E6100000FF58880E81E54A407313B534B76C4A40
68459	7	69	791	45648	51184	\N	52.848976999999998	с. Ивановка, ул.Школьная, д. 1	Россия, Оренбургская область, Красногвардейский район, село Ивановка	0101000020E6100000732D5A80B6E54A4031074147AB6C4A40
68456	7	69	791	5582	50864	\N	53.015928000000002	село Ибряево, Чулпан, 59	Россия, Оренбургская область, Красногвардейский район, село Ибряево	0101000020E610000039807EDFBFEB4A409C8BBFED09824A40
69292	7	69	791	5582	50706	\N	53.015928000000002	с.Ибряево, ул.Восточная, 1б		0101000020E610000039807EDFBFEB4A409C8BBFED09824A40
68454	7	69	791	28695	50929	\N	52.908507999999998	село Залесово, Школьная, 10		0101000020E61000008522DDCF29E24A40C2137AFD49744A40
68493	7	69	791	48937	50906	\N	52.629190585148898	поселок Ермаково, Орская, 10/2	Россия, Оренбургская область, Красногвардейский район, село Ермаково	0101000020E6100000A5D8D138D4E14A4001F8A75489504A40
68461	7	69	791	22602	51181	\N	52.860911999999999	п. Долинск, ул. Советская, д. 70		0101000020E6100000D1217024D0B64A40F25D4A5D326E4A40
68488	7	69	791	48838	51145	\N	52.659185000000001	село Вознесенка, Школьная, 3		0101000020E6100000A7785C548BA44A40C381902C60544A40
68473	7	69	791	29512	50773	\N	52.889668999999998	деревня Верхнеильясово, М.Бурангулова, 11		0101000020E6100000177E703E75BA4A40ECA17DACE0714A40
68613	7	69	791	46849	51170	\N	52.608421	Александровка, ул. Касьянова, 54		0101000020E610000090C18A53AD9F4A408D9944BDE04D4A40
68417	7	69	1733	47545	51252	\N	52.028782	п. Майский, Школьная, 17		0101000020E61000002EE3A6069AE94D40535BEA20AF034A40
68448	7	69	1733	56158	51263	\N	52.0533	с.Чапаевка, Речная, 17	Россия, Оренбургская область, Кваркенский район, село Чапаевка	0101000020E6100000529ACDE3306A4D403B70CE88D2064A40
68444	7	69	1733	28236	50427	\N	52.205236999999997	с. Уртазым, Центральная, 1		0101000020E61000001763601DC76B4D40EE76BD34451A4A40
68439	7	69	1733	47943	51095	\N	52.194671999999997	с. Уральское, Школьная, 9		0101000020E6100000B7ED7BD45F754D4034B91803EB184A40
68447	7	69	1733	28359	50599	\N	52.035829	с. Таналык, Кооперативный, 4		0101000020E61000000B7A6F0C01784D40CB9F6F0B96044A40
68432	7	69	1733	56212	51475	\N	52.414212927261403	п. Свободный, Центральная, 25	Россия, Оренбургская область, Кваркенский район, село Свободное	0101000020E61000009E42AED4B3DC4D40FD497CEE04354A40
68436	7	69	1733	47882	50558	\N	52.2074	с. Просторы, пер. Школьный, 2	Россия, Оренбургская область, Кваркенский район, село Просторы	0101000020E61000008D4127840EAA4D405F984C158C1A4A40
68449	7	69	1733	48150	50608	\N	51.883277999999997	с.Приморск, Школьная, 3		0101000020E610000011AB3FC230724D405DA3E5400FF14940
68443	7	69	1733	47156	64161	\N	52.131482829184201	с. Покровка, Школьная, 13	Россия, Оренбургская область, Кваркенский район, село Покровка	0101000020E6100000E9103812686A4D40707D586FD4104A40
69548	7	69	1733	47156	51329	\N	52.131219000000002	с.Покровка, ул.Рыжкова, 6		0101000020E6100000853FC39B356A4D4092CEC0C8CB104A40
69275	7	69	1733	46271	50583	\N	51.994213999999999	п.Первомайский, пер.Школьный, 3		0101000020E6100000069CA56439D54D40D89C836742FF4940
68435	7	69	1733	56196	51395	\N	52.407226000000001	с. Новопотоцк, Школьная, 2	Россия, Оренбургская область, Кваркенский район, село Новопотоцкое	0101000020E6100000718FA50F5DB64D405B0A48FB1F344A40
68431	7	69	1733	27630	50775	\N	52.410498839670602	с. Новооренбург, Новая, 15	Россия, Оренбургская область, Кваркенский район, село Новооренбург	0101000020E61000002AABE97AA2C94D403605323B8B344A40
68441	7	69	1733	47974	\N	\N	52.226132999999997	с. Максим Горький, Южная, 11	Россия, Оренбургская область, Кваркенский район, село Максим Горький	0101000020E61000004E27D9EA727E4D40EFC517EDF11C4A40
68424	7	69	1733	47655	51154	\N	52.175158000000003	п. Лесная Поляна, Школьная, 18		0101000020E610000052BAF42F49D74D40FFD0CC936B164A40
68434	7	69	1733	47841	\N	\N	52.418646000000003	с. Кульма, Центральная, 8	Россия, Оренбургская область, Кваркенский район, село Кульма	0101000020E6100000DB1324B6BBAB4D40F54C2F3196354A40
68428	7	69	1733	27523	51250	\N	52.176152000000002	п. Красный Огородник, Степная, 7		0101000020E610000048A8195245ED4D40009013268C164A40
68421	7	69	1733	27176	50272	\N	51.963737000000002	п. Красноярский, Газовая, 6А		0101000020E610000033FE7DC685F34D40FB78E8BB5BFB4940
68420	7	69	1733	27176	49922	\N	51.963737000000002	п. Красноярский, Вокзальная, 4		0101000020E610000033FE7DC685F34D40FB78E8BB5BFB4940
68433	7	69	1733	47831	50313	\N	52.374139999999997	п. Коминтерн, пер. Школьный, 1		0101000020E61000000438BD8BF7AF4D400E10CCD1E32F4A40
68423	7	69	1733	47647	50598	\N	52.150928	п. Кировск, им.Кирова, 15		0101000020E61000000305DEC9A7CF4D407D06D49B51134A40
68416	7	69	1733	26924	49733	\N	52.083727000000003	с. Кваркено, Центральная, 27		0101000020E6100000B08F4E5DF9DC4D406765FB90B70A4A40
68415	7	69	1733	26924	49733	\N	52.083727000000003	с. Кваркено, Центральная, 2		0101000020E6100000B08F4E5DF9DC4D406765FB90B70A4A40
68429	7	69	1733	27528	50933	\N	52.37612	с. Зеленодольск, Центральная, 11	Россия, Оренбургская область, Кваркенский район, село Зеленодольск	0101000020E6100000B403AE2B66F24D408EAF3DB324304A40
68422	7	69	1733	56131	50948	\N	51.931584000000001	с. Екатериновка, Октябрьская, 1А	Россия, Оренбургская область, Кваркенский район, село Екатериновка	0101000020E61000001A1538D906FC4D400ABDFE243EF74940
68451	7	69	1733	28551	51251	\N	51.78237	с.Горный Ерик, Речная, 7		0101000020E6100000060E68E90A6A4D408EAF3DB324E44940
68450	7	69	1733	48158	50892	\N	51.940330000000003	с. Гоголевка, Центральная, 10		0101000020E61000002E1C08C9027E4D404EB9C2BB5CF84940
68437	7	69	1733	27903	50429	\N	52.127470000000002	с. Бриент, Советская, 15		0101000020E6100000A4E029E44AA74D404E9CDCEF50104A40
68440	7	69	1733	47959	51011	\N	52.169601999999998	с. Большевик, Школьная, 6		0101000020E61000006CB07092E6714D4008ABB184B5154A40
68425	7	69	1733	27369	50923	\N	52.231175	с.Болотовск, Лесная, 61		0101000020E6100000DBBE47FDF5FA4D408F537424971D4A40
68246	7	69	1489	48636	50763	\N	52.829835000000003	с.Новая Тепловка, ул.Нижний конец, 1		0101000020E610000066118AADA04D4A40C0098508386A4A40
68445	7	69	1733	56112	50776	\N	52.363439999999997	с. Березовка, Верхняя, 12	Россия, Оренбургская область, Кваркенский район, село Березовка	0101000020E610000005172B6A307B4D407407B133852E4A40
68427	7	69	1733	47720	50925	\N	52.265419999999999	п. Белоозерный, Раздольная, 11А		0101000020E610000049BE124889CD4D4027DA5548F9214A40
69175	7	69	1733	45624	50645	\N	52.153302784396701	С. Алексеевка, ул Центральная 48	Россия, Оренбургская область, Кваркенский район, село Алексеевка	0101000020E610000085950A2AAA584D4079B0C56E9F134A40
68094	7	69	1733	45624	64133	\N	52.153091603509601	село Алексеевка, Советская, здание сельского Дома культуры, 73	Россия, Оренбургская область, Кваркенский район, село Алексеевка	0101000020E610000085950A2AAA584D40BEA3C68498134A40
68426	7	69	1733	27402	50464	\N	52.227119999999999	с. Аландское, Школьная, 3		0101000020E6100000D7FA22A12DE54D403E22A644121D4A40
68419	7	69	1733	23600	50240	\N	52.051837999999996	п. Айдырлинский, ул. Школьная, 3		0101000020E610000020D26F5F07E24D405358A9A0A2064A40
68414	7	69	1351	26860	50463	\N	51.615012	Яман, Октябрьская, 2, Б		0101000020E6100000AA2D7590D7A74A40E35295B6B8CE4940
68391	7	69	1351	47017	51248	\N	51.538795	Шутово, Центральная, 4		0101000020E61000003BE0BA6246C64A40C91F0C3CF7C44940
68407	7	69	1351	26555	49823	\N	51.592849000000001	Студеное, Бокова, 113		0101000020E61000007E1EA33CF3944A40B03BDD79E2CB4940
68403	7	69	1351	47260	\N	\N	51.363075000000002	Степное, Дом Шадатовой С.		0101000020E6100000DCB75A272EF14A40637FD93D79AE4940
68412	7	69	1351	56071	50473	\N	51.625723472727401	Сладково, Школьная, 42, А	Россия, Оренбургская область, Илекский район, село Сладков	0101000020E610000003D0285DFABD4A4071ADF6B017D04940
68413	7	69	1351	56085	50629	\N	51.595965068185301	Рассыпное, Мира, 42	Россия, Оренбургская область, Илекский район, село Рассыпная	0101000020E6100000F60D4C6E14D14A40C347C49448CC4940
68410	7	69	1351	47413	50927	\N	51.611376999999997	Раздольное, Школьная, 12		0101000020E6100000DC0E0D8B51A34A406743FE9941CE4940
68401	7	69	1351	47214	49822	\N	51.357866999999999	Привольное, площадь Победы, 5		0101000020E61000005453927538D84A40A8A8FA95CEAD4940
68393	7	69	1351	47050	51244	\N	51.537629000000003	Подстепки, Московская, 8, А		0101000020E6100000DCD7817346E04A40CB30EE06D1C44940
68395	7	69	1351	47090	49913	\N	51.611327000000003	Нижнеозерное, Советская, 38		0101000020E6100000AAF06778B3F44A40B61490F63FCE4940
68411	7	69	1351	26711	50465	\N	51.611271833718703	Мухраново, Советская, 60	Россия, Оренбургская область, Илекский район, село Мухраново	0101000020E6100000D503E62153B24A40F27A30293ECE4940
68409	7	69	1351	47399	50922	\N	51.579228000000001	Крестовка, Центральная, 58		0101000020E6100000840CE4D9E5894A40B876A22424CA4940
68392	7	69	1351	47039	50596	\N	51.535417000000002	Красный Яр, Ленина, 25		0101000020E61000004A24D1CB28D44A40795C548B88C44940
68822	7	69	1351	14488	49943	\N	51.593195999999999	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, с. Краснохолм, Советская, 68		0101000020E61000002F34D769A4134B401B0FB6D8EDCB4940
68820	7	69	1351	14488	49709	\N	51.593195999999999	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, с. Краснохолм, России, 82	Россия, Оренбургская область, Илекский район, село Краснохолм	0101000020E61000002F34D769A4134B401B0FB6D8EDCB4940
68821	7	69	1351	14488	49711	\N	51.593195999999999	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, с. Краснохолм, Липова, 9		0101000020E61000002F34D769A4134B401B0FB6D8EDCB4940
68394	7	69	1351	25979	49821	\N	51.536593000000003	Кардаилово, Советская, 57		0101000020E61000004BE7C3B304F54A409B215514AFC44940
68442	7	69	1351	25979	51372	\N	51.536593000000003	с. Верхняя Кардаиловка, ул.Кузнецова, 16	Россия, Оренбургская область, Илекский район, село Кардаилово	0101000020E61000004BE7C3B304F54A409B215514AFC44940
68389	7	69	1351	25675	49738	\N	51.528334999999998	Илек, Токмаковская, 14, А		0101000020E6100000BB80971936B24A40842A357BA0C34940
68388	7	69	1351	25675	50003	\N	51.524278000000002	Илек, Октябрьская, 25	Россия, Оренбургская область, Илекский район, село Илек	0101000020E6100000D4298F6E84AF4A409301A08A1BC34940
68390	7	69	1351	25675	49820	\N	51.528334999999998	Илек, Пионерская, 49		0101000020E6100000BB80971936B24A40842A357BA0C34940
68406	7	69	1351	26507	50335	\N	51.416271000000002	Затонное, Советская, 55		0101000020E6100000BD18CA8976CB4A40F9A23D5E48B54940
68408	7	69	1351	26572	50928	\N	51.601101	Заживный, Центральная, 7		0101000020E61000008EB27E33319D4A40E44BA8E0F0CC4940
68396	7	69	1351	47123	50004	\N	51.431643000000001	Димитровский, Школьная, 1		0101000020E6100000D064FF3C0D1E4B400F46EC1340B74940
68380	7	69	1612	25302	50760	\N	50.75253	село Ушкатты, переулок Ярославский, 1а		0101000020E610000019C91EA166FA4D4023A12DE752604940
69588	7	69	1612	19978	51328	\N	51.010624	поселок Тюльпанный, Центральная, 2		0101000020E610000017105A0F5F604D40BF4692205C814940
68375	7	69	1612	46679	\N	\N	50.784050000000001	село Соколовка, Речная, 28	Россия, Оренбургская область, Домбаровский район, село Соколовка	0101000020E61000005872158BDF7E4D40E3361AC05B644940
68378	7	69	1612	46740	51259	\N	50.702872999999997	поселок Прибрежный, Центральная, 1а		0101000020E6100000D3F71A82E3C24D40E61E12BEF7594940
68377	7	69	1612	25129	50765	\N	50.851008	село Курмансай, переулок Торговый, 8а		0101000020E610000048C0E8F2E6C44D40335184D4ED6C4940
68366	7	69	1612	24684	51241	\N	50.708914	село Кужанберля, Первая, 4-1		0101000020E61000001E705D3123884D4099D6A6B1BD5A4940
68371	7	69	1612	24910	50454	\N	51.011037000000002	поселок Красночабанский, Новая, 3а		0101000020E61000001686C8E9EB654D40E20511A969814940
68361	7	69	1612	56188	51381	\N	50.934494226924699	п. Корсунский, Школьная, 1	Россия, Оренбургская область, Домбаровский район, село Корсуньский	0101000020E610000097C80567F09F4D407427D87F9D774940
68372	7	69	1612	24935	51242	\N	50.933622999999997	село Кинжебулак, Школьная, 2		0101000020E61000008B70935165644D408EE55DF580774940
68379	7	69	1612	25206	50771	\N	50.69961	поселок Караганда, Конторская, 7		0101000020E6100000B29DEFA7C6DB4D402FFA0AD28C594940
68365	7	69	1612	24594	51135	\N	50.855221	село Камсак, Школьная, 19-2		0101000020E6100000D9EDB3CA4C9F4D401CEDB8E1776D4940
68362	7	69	1612	56168	51343	\N	50.911842999999998	с.Истемисс,  ул. Набережная, дом №11	Россия, Оренбургская область, Домбаровский район, село Истемис	0101000020E61000000667F0F78B8B4D40130B7C45B7744940
69111	7	69	1612	56134	50975	\N	50.9283926968549	п.Зарево, Школьная, 1	Россия, Оренбургская область, Домбаровский район, село Зарево	0101000020E6100000F67F0EF3E5CD4D40EC6AF294D5764940
68376	7	69	1612	46709	\N	\N	50.899284999999999	село Екатеринославка, Речная, 7	Россия, Оренбургская область, Домбаровский район, село Екатеринославка	0101000020E6100000CDE506431D584D40456458C51B734940
68383	7	69	1612	25307	49729	\N	50.760581000000002	поселок Домбаровский, торговая площадь, 2		0101000020E610000010AD156D8EC54D40C07ADCB75A614940
68382	7	69	1612	25307	50597	\N	50.760581000000002	поселок Домбаровский, Стахановская, 169		0101000020E610000010AD156D8EC54D40C07ADCB75A614940
68381	7	69	1612	25307	49728	\N	50.760581000000002	поселок Домбаровский, Рабочая, 15		0101000020E610000010AD156D8EC54D40C07ADCB75A614940
68386	7	69	1612	25307	49912	\N	50.760581000000002	поселок Домбаровский, Куйбышева, 10		0101000020E610000010AD156D8EC54D40C07ADCB75A614940
68384	7	69	1612	25307	50766	\N	50.760581000000002	поселок Домбаровский, Весенняя, 11		0101000020E610000010AD156D8EC54D40C07ADCB75A614940
68385	7	69	1612	25307	50468	\N	50.760581000000002	поселок Домбаровский, осипенко, 16		0101000020E610000010AD156D8EC54D40C07ADCB75A614940
68363	7	69	1612	24504	50546	\N	50.860117000000002	село Домбаровка, Школьная, 18		0101000020E6100000D7C3978922AA4D40E8DD5850186E4940
68368	7	69	1612	24775	50458	\N	50.879517	поселок Голубой Факел, Газовиков, 10		0101000020E610000087191A4F04AB4D4055A3570394704940
68367	7	69	1612	24691	51134	\N	50.751953999999998	село Бояровка, Центральная, 12		0101000020E6100000AFCC5B751DA64D40560C570740604940
68369	7	69	1612	24795	51137	\N	50.829427000000003	село Богоявленка, Набережная, 41		0101000020E610000071E5EC9DD1DC4D40AFB5F7A92A6A4940
68370	7	69	1612	24795	50921	\N	50.829427000000003	село Богоявленка, Молодёжная, 36		0101000020E610000071E5EC9DD1DC4D40AFB5F7A92A6A4940
68360	7	69	1612	56052	50117	\N	51.044022727456003	село Ащебутак, Клубная, 26	Россия, Оренбургская область, Домбаровский район, село Ащибутак	0101000020E610000088BEBB95258E4D40CBA2B08BA2854940
68364	7	69	1612	46457	50770	\N	50.792301000000002	село Архангельское, Школьная, 11		0101000020E610000005172B6A30A14D4047CB811E6A654940
68373	7	69	1612	24983	50762	\N	50.999310999999999	поселок Аккудук, Молодёжная, 4		0101000020E610000083FB010F0C864D403BC43F6CE97F4940
68792	7	69	2990	56046	49942	\N	51.872594640110201	Оренбургская область, муниципальное образование город Оренбург, Дзержинский район, п. Каргала, Советская, 12	Россия, Оренбургская область, Оренбург, Дзержинский район	0101000020E6100000B48F15FC369C4B4099D36531B1EF4940
69601	7	69	1521	48178	51014	\N	53.016437000000003	с. Якутино, Старохуторская, 14а		0101000020E61000006BD784B4C66A4A40E1B88C9B1A824A40
68356	7	69	1521	46299	51215	\N	53.038311999999998	с.Ягодное, Центральная, 1		0101000020E6100000E5266A696E774A40AD855968E7844A40
68358	7	69	1521	46338	50768	\N	53.059792000000002	с. Урицкое, Степная, 40		0101000020E6100000C76647AAEF8A4A40FE47A643A7874A40
68354	7	69	1521	24054	50245	\N	53.138775000000003	с.Таллы, Майская, 12		0101000020E6100000BA2F67B62B884A404F401361C3914A40
68352	7	69	1521	23954	51213	\N	52.813673000000001	с.Старояшкино, Строительная, 2а	Россия, Оренбургская область, Грачевский район, село Старояшкино	0101000020E6100000467C2766BD784A40B151D66F26684A40
68357	7	69	1521	46304	50767	\N	53.002794000000002	с. Саблино, Центральная, 27		0101000020E61000003F373465A7A54A400150C58D5B804A40
68350	7	69	1521	56099	50688	\N	52.945129000000001	с.Русскоигнашкино, Первомайская, 5	Россия, Оренбургская область, Грачевский район, село Русское Игнашкино	0101000020E610000021037976F9844A4027C0B0FCF9784A40
68355	7	69	1521	24098	51138	\N	53.1016393598183	п.Революционер, Молодежная, 22	Россия, Оренбургская область, Грачевский район, село Революционер	0101000020E610000005F9D9C875774A40C37FBA81028D4A40
68015	7	69	1521	17882	64942	\N	52.791090347512203	с.Покровка, Ветеранов (дом культуры), 2	Россия, Оренбургская область, Грачевский район, село Покровка	0101000020E6100000EC681CEA77894A40A818E76F42654A40
68348	7	69	1521	46096	50680	\N	53.099317999999997	п. Победа, Сеннореченская, 78		0101000020E6100000C102983270644A40BAF3C473B68C4A40
68346	7	69	1521	56090	50637	\N	53.020429999999998	с.Петрохерсонец, Мира, 1	Россия, Оренбургская область, Грачевский район, село Петро-Херсонец	0101000020E6100000F4DF83D72E854A40BBED42739D824A40
68343	7	69	1521	49499	50695	\N	52.865814	с.Новоникольское, Советская, 20а	Россия, Оренбургская область, Грачевский район, село Новоникольское	0101000020E6100000DA01D71533904A40A0353FFED26E4A40
68353	7	69	1521	24011	51246	\N	52.784765999999998	с.Малояшкино, Школьная, 18		0101000020E61000004BE658DE55694A40A181583673644A40
69405	7	69	1521	47232	50809	\N	53.097316999999997	село Луговое, Зеленая, 1А		0101000020E6100000D316D7F84C784A40232C2AE2748C4A40
68342	7	69	1521	56074	50481	\N	52.949942	с.Ключи, переулок Центральный, 3	Россия, Оренбургская область, Грачевский район, село Ключи	0101000020E61000009CDCEF50145E4A40658C0FB397794A40
68344	7	69	1521	46010	51225	\N	52.914563000000001	п. Каликино, Озерная, 28б		0101000020E61000005EA0A4C002944A40DA907F6610754A40
68347	7	69	1521	23712	51136	\N	53.017184999999998	с.Ждамировка, Шевченко, 6		0101000020E610000099A0866F617D4A40AA7D3A1E33824A40
68341	7	69	1521	23434	\N	\N	52.901117999999997	с.Ероховка, Новая, 31	Россия, Оренбургская область, Грачевский район, село Ероховка	0101000020E6100000C66D3480B7544A4020EBA9D557734A40
68340	7	69	1521	48869	49930	\N	52.922195000000002	с.Грачевка, Юбилейная, 25	Россия, Оренбургская область, Грачевский район, село Грачевка	0101000020E61000006EDBF7A8BF6E4A4072C45A7C0A764A40
68339	7	69	1521	48869	49930	\N	52.922195000000002	с.Грачевка, Юбилейная, 9	Россия, Оренбургская область, Грачевский район, село Грачевка	0101000020E61000006EDBF7A8BF6E4A4072C45A7C0A764A40
68338	7	69	1521	48869	49967	\N	52.922195000000002	с.Грачевка, Советская, 7	Россия, Оренбургская область, Грачевский район, село Грачевка	0101000020E61000006EDBF7A8BF6E4A4072C45A7C0A764A40
69108	7	69	1521	47571	49767	\N	53.050232999999999	п.Володарский, Володарского, 2б		0101000020E6100000904946CEC2664A400917F2086E864A40
68337	7	69	1521	56098	50677	\N	52.953854	с.Верхнеигнашкино, Советская, 8	Россия, Оренбургская область, Грачевский район, село Верхигнашкино	0101000020E6100000C7DADFD91E894A4053944BE3177A4A40
68336	7	69	1521	40525	81097	\N	53.077745	с.Александровка, Центральная, 54	Россия, Оренбургская область, Грачевский район, село Александровка	0101000020E6100000BC3C9D2B4AA94A40B936548CF3894A40
68251	7	69	1489	48722	50917	\N	52.957152999999998	с.Новая Казанка, ул.Центральная, 20-а		0101000020E6100000772E8CF4A2464A40572250FD837A4A40
68351	7	69	1521	23916	51080	\N	52.941977999999999	с.Абрышкино, Новая, 21	Россия, Оренбургская область, Грачевский район, село Абрышкино	0101000020E6100000A5F8F884EC7C4A4097C62FBC92784A40
68321	7	69	618	45552	51178	\N	51.243116000000001	с.Хмелевка, ул. Центральная, д.27		0101000020E610000065DF15C1FFEE4C403291D26C1E9F4940
68311	7	69	618	45372	50918	\N	51.399597	п. Халилово, Ленина, 6		0101000020E6100000EDF1423A3C104D40344A97FE25B34940
68300	7	69	618	49455	51075	\N	51.591242999999999	с. Уральск, Нижняя, 57		0101000020E610000017B83CD68C524D40957EC2D9ADCB4940
68316	7	69	618	22328	50888	\N	51.309139999999999	д. Узембаево, Молодежная, 8,кв.2		0101000020E610000048A98427F4164D4056F146E691A74940
68298	7	69	618	49429	51103	\N	51.639003000000002	с. Терекла, Центральная, 6а		0101000020E6100000ECA694D74A4E4D40E085ADD9CAD14940
68313	7	69	618	22158	50679	\N	51.445999	д. Старохалилово, Дальняя, 1		0101000020E61000004888F2052D0E4D403C86C77E16B94940
68305	7	69	618	58937	67057	\N	51.397839374565002	п. Саверовка, Молодежная, 1а	Россия, Оренбургская область, Гайский район, село Северовка	0101000020E61000009E7E5017293A4D4063096B63ECB24940
68966	7	69	618	21880	50352	\N	51.338926000000001	село Репино, улица Центральная, дом 17		0101000020E6100000317898F6CD334D40CEE15AED61AB4940
68304	7	69	618	21880	50352	\N	51.338926000000001	п. Репино, Центральная, 22	Россия, Оренбургская область, Гайский район, село Репино	0101000020E6100000317898F6CD334D40CEE15AED61AB4940
68306	7	69	618	49548	51092	\N	51.531730000000003	п. Поповка, Школьная, 15		0101000020E61000007C65DEAAEB364D40AB2688BA0FC44940
68303	7	69	618	56187	51377	\N	51.431031284017998	с.Пласковское, ул. Молодежная, д.6 кв.1	Россия, Оренбургская область, Гайский район, село Пласковский	0101000020E610000059C4B0C398584D40F54718062CB74940
54124	7	69	618	46871	50649	\N	51.592194999999997	с. Писаревка, Степная, 13		0101000020E610000096AFCBF09F324D4067EDB60BCDCB4940
68743	7	69	618	10888	\N	\N	51.504638	п. Новорудный	Россия, Оренбургская область, Гайский район, поселок Новорудный	0101000020E61000009702D2FE07184D40D0285DFA97C04940
68319	7	69	618	22422	51102	\N	51.640607000000003	с. Новопетропавловка, Школьная, 15		0101000020E6100000C4B12E6EA3154D405A4B0169FFD14940
68309	7	69	618	49595	50330	\N	51.638528000000001	с. Новониколаевка, Школьная, 10		0101000020E6100000A8DF85ADD92C4D4047CA1649BBD14940
68320	7	69	618	45537	51232	\N	51.528126999999998	с.Новокиевка, ул.Школьная, 7		0101000020E6100000944DB9C2BB144D403A9160AA99C34940
69018	7	69	618	56121	\N	\N	51.288054401608299	г. Орск, Клуб поселка Новоказачий	Россия, Оренбургская область, Гайский район, село Новоказачий	0101000020E61000007EE4D6A4DB564D40B2BD16F4DEA44940
68312	7	69	618	22153	50920	\N	51.404097999999998	п. Нововоронежский, Новая, 2		0101000020E610000016A3AEB5F7134D408330B77BB9B34940
68299	7	69	618	21494	51210	\N	51.562412000000002	с. Новоактюбинск, Центральная, 49		0101000020E610000033E197FA79554D406170CD1DFDC74940
68314	7	69	618	22246	50889	\N	51.389650000000003	п. Нарбулатово, Школьная, 5а		0101000020E61000009FE925C632194D4076711B0DE0B14940
68317	7	69	618	56180	51365	\N	51.383692000000003	п. Лылово, Новостройка, 20	Россия, Оренбургская область, Гайский район, село Лылов	0101000020E6100000153B1A87FA054D4051DEC7D11CB14940
68301	7	69	618	21578	50263	\N	51.484659000000001	с. Колпакское, Школьная, 15		0101000020E610000031D3F6AFAC5C4D40255B5D4E09BE4940
68307	7	69	618	21905	50876	\N	51.511235999999997	с. Камейкино, Центральная, 10		0101000020E61000009B8D959867374D40D844662E70C14940
68308	7	69	618	49591	51008	\N	51.458145000000002	д. Ишкинино, Школьная, 22		0101000020E6100000D6ABC8E880244D40B8E9CF7EA4BA4940
68296	7	69	618	21389	\N	\N	51.673560999999999	п.Ириклинский, ул.Советская, д.25а	Россия, Оренбургская область, Гайский район, село Ириклинский	0101000020E6100000BCE9961DE2514D40376E313F37D64940
68318	7	69	618	22412	51239	\N	51.287987000000001	д. Ижберда, Новостройка, 24		0101000020E6100000C362D4B5F6024D402A560DC2DCA44940
68745	7	69	618	10984	\N	\N	51.136239000000003	ст. Губерля	Россия, Оренбургская область, Гайский район, село Губерля	0101000020E61000008EC9E2FE23F94C404AB8904770914940
68322	7	69	618	10984	51340	\N	51.134669681741997	с.Казачья Губерля., ул. Уральская, д.20	Россия, Оренбургская область, Гайский район, село Губерля	0101000020E6100000083E062B4EF94C404CE0D6DD3C914940
68315	7	69	618	22287	51209	\N	51.360014999999997	п. Гайнулино, Школьная, 7		0101000020E6100000B58828266F264D40E388B5F814AE4940
68297	7	69	618	49424	51132	\N	51.699531	с. Вишневое, Школьная, 2а		0101000020E6100000CE6DC2BD32454D40E3C4573B8AD94940
68323	7	69	618	22618	50891	\N	51.219529999999999	с. Белошапка, Центральная, 1		0101000020E6100000CC28965B5A0B4D40D53E1D8F199C4940
68302	7	69	618	21665	50898	\N	51.350695000000002	с. Банное, Школьная, 20		0101000020E6100000CF656A12BC5D4D4074EFE192E3AC4940
68241	7	69	1489	18455	50428	\N	52.860078999999999	с.Шахматовка, ул.Школьная, 1	Россия, Оренбургская область, Бузулукский район, село Шахматовка	0101000020E610000093A8177C9A414A40FA7C9411176E4A40
68255	7	69	1489	19187	50600	\N	52.791547000000001	с.Тупиковка, ул.Центральная, 76		0101000020E61000004AEF1B5F7B024A409B1F7F6951654A40
68260	7	69	1489	56062	50280	\N	53.105537220849797	с.Троицкое, ул.Садовая, 48	Россия, Оренбургская область, Бузулукский район, село Троицкое	0101000020E6100000B1DF13EB54434A404CC2853C828D4A40
68258	7	69	1489	48845	51230	\N	53.006754999999998	с.Твердилово, ул.Пушкина, 2		0101000020E61000005A84622B68344A40D00A0C59DD804A40
68256	7	69	1489	19274	49988	\N	52.814179000000003	с.Сухоречка, ул.Центральная, 3	Россия, Оренбургская область, Бузулукский район, село Сухоречка	0101000020E6100000C79BFC169D304A40850B790437684A40
68247	7	69	1489	18736	51131	\N	52.776215000000001	с.Старая Тепловка, ул.Молодежная, 7		0101000020E610000075560BEC31494A4013D55B035B634A40
68263	7	69	1489	19577	50452	\N	52.656934	с.Проскурино, ул.Центральная, 16	Россия, Оренбургская область, Бузулукский район, село Проскурино	0101000020E610000050560C5707F84940B3D0CE6916544A40
68250	7	69	1489	18926	50448	\N	52.988723999999998	с.Подколки, ул.Центральная, 1		0101000020E6100000EC6D3315E2414A4099620E828E7E4A40
68244	7	69	1489	18598	50758	\N	52.672351999999997	с.Перевозинка, ул.Центральная, 9		0101000020E6100000ABE7A4F78D1F4A4039B35DA10F564A40
68218	7	69	1489	48127	50924	\N	53.001027999999998	п.Партизанский, ул.Центральная, д.5		0101000020E6100000158E209562114A40AD307DAF21804A40
68248	7	69	1489	18822	49717	\N	52.83954	с.Палимовка, ул.Советская, 1	Россия, Оренбургская область, Бузулукский район, село Палимовка	0101000020E61000000D37E0F3C31A4A4088D7F50B766B4A40
68249	7	69	1489	18854	50907	\N	52.836976368736003	с.Новая Елшанка, ул.Южная, 11	Россия, Оренбургская область, Бузулукский район, село Новая Елшанка	0101000020E6100000EF586C938A124A40B9C49107226B4A40
68231	7	69	1489	17951	51130	\N	52.726635000000002	с.Никифоровка, пер.Школьный, 7		0101000020E6100000B94F8E0244414A4082902C60025D4A40
68221	7	69	1489	17449	51126	\N	52.708044999999998	с.Нижняя Вязовка, ул.Центральная, 1/3		0101000020E6100000361D01DC2C524A40548CF337A15A4A40
68242	7	69	1489	18508	50311	\N	53.153616999999997	с.Могутово, ул.Молодежная, 22		0101000020E6100000994869368F134A40088ECBB8A9934A40
68239	7	69	1489	48512	50261	\N	52.939833	п.Лисья Поляна, ул.Гагарина, 29		0101000020E6100000904B1C7920324A40CD599F724C784A40
68238	7	69	1489	48487	50450	\N	52.702843999999999	с.Липовка, ул.Молодежная, 1-а		0101000020E6100000990D32C9C8054A404C18CDCAF6594A40
68233	7	69	1489	48384	\N	\N	52.679647000000003	п.\\красногвардеец, ул.Заводская, 15	Россия, Оренбургская область, Бузулукский район, село Красногвардеец	0101000020E61000005B785E2A362E4A408AE942ACFE564A40
68235	7	69	1489	48384	50593	\N	52.679647000000003	п.Красногвардеец, ул.Советская, 9		0101000020E61000005B785E2A362E4A408AE942ACFE564A40
68232	7	69	1489	48384	49896	\N	52.679647000000003	п.Красногвардеец, ул.Октябрьская, 20		0101000020E61000005B785E2A362E4A408AE942ACFE564A40
68236	7	69	1489	56193	51386	\N	53.231038765593802	с.Красная Слободка, ул.Школьная, 47	Россия, Оренбургская область, Бузулукский район, село Красная Слободка	0101000020E61000007407B13385424A40DF8C9AAF929D4A40
68262	7	69	1489	19505	49866	\N	52.941851999999997	п.Колтубановский, пер.Школьный, 10		0101000020E610000046274BADF7034A400AD6389B8E784A40
68261	7	69	1489	19505	49981	\N	52.944757883152199	п.Колтубановский, ул.Советская, 13	Россия, Оренбургская область, Бузулукский район, поселок Колтубановский	0101000020E610000079CE16105A054A40335184D4ED784A40
68229	7	69	1489	19505	50594	\N	52.939475764362797	с.Колтубанка, ул.Заречная, 47	Россия, Оренбургская область, Бузулукский район, поселок Колтубановский	0101000020E6100000E413B2F336044A403EB0E3BF40784A40
68234	7	69	1489	48414	50759	\N	52.636912000000002	п.Кировский, ул.Садовая, 3	Россия, Оренбургская область, Бузулукский район, село Кировский	0101000020E610000096253ACB2C284A400937195586514A40
68230	7	69	1489	17885	50916	\N	52.663784	с.Каменная Сарма, ул.Центральная, 17-е		0101000020E6100000246420CF2E414A40D5CDC5DFF6544A40
68253	7	69	1489	56060	50271	\N	52.755590684885199	п.Искра, ул.Школьная, 5	Россия, Оренбургская область, Бузулукский район, село Искра	0101000020E6100000ADF71BEDB8154A407313B534B7604A40
68228	7	69	1489	17791	50588	\N	53.070023999999997	с.Жилинка, ул.Речная, 13		0101000020E61000005E656D533C5A4A40B1F7E28BF6884A40
68227	7	69	1489	17760	49978	\N	52.870871999999999	с.Елшанка Первая, ул.Советская, 14		0101000020E610000021C8410933034A404580D3BB786F4A40
68225	7	69	1489	48267	\N	\N	52.904358999999999	с.Елховка, ул.Западная, 11	Россия, Оренбургская область, Бузулукский район, село Елховка	0101000020E6100000890B40A374254A40F06B2409C2734A40
68245	7	69	1489	46964	50761	\N	52.698096999999997	с.Дмитриевка, ул.Школьная, 18	Россия, Оренбургская область, Бузулукский район, село Дмитриевка	0101000020E61000009D499BAA7B284A40C537143E5B594A40
68223	7	69	1489	48191	50913	\N	53.211644	с.Державино, ул.Советская, 15		0101000020E6100000E5EFDE51632C4A4083328D26179B4A40
68222	7	69	1489	48191	50913	\N	53.211644	с.Державино, ул.Советская, 43		0101000020E6100000E5EFDE51632C4A4083328D26179B4A40
68226	7	69	1489	48273	51240	\N	52.927103000000002	с.Воронцовка, ул.Молодежная, 2	Россия, Оренбургская область, Бузулукский район, село Воронцовка	0101000020E61000003FE3C28190204A400283A44FAB764A40
68219	7	69	1489	17355	50590	\N	52.754964000000001	с.Верхняя Вязовка, ул.Калинина, д.22-в		0101000020E610000018B5FB5580574A4024D40CA9A2604A40
68237	7	69	1489	48476	51231	\N	53.248578000000002	с.Булгаково, ул.Заречная, д.24, кв.2		0101000020E6100000A452EC681C3C4A40A7406667D19F4A40
68257	7	69	1489	56170	51347	\N	52.789228141370103	п.Бузулукское Лесничество, ул.Лесная, 28		0101000020E610000039F06AB933294A40338B506C05654A40
68259	7	69	1489	48847	51245	\N	53.084246	с.Березовка, ул.Центральная, 12-б		0101000020E6100000210725CCB4354A40CF68AB92C88A4A40
68217	7	69	1489	17218	50317	\N	52.818108000000002	с.Алдаркино, ул.Садовая, д.35		0101000020E61000001AC1C6F5EFEC4940494C50C3B7684A40
68285	7	69	7394	56042	49999	\N	52.782098903680499	город Бузулук, Школьная, 56	Россия, Оренбургская область, Бузулук городской округ	0101000020E61000002E04392861224A40FE9DEDD11B644A40
69583	7	69	1214	19688	51001	\N	53.789076999999999	д. Шестайкино, Центральная, 47 А		0101000020E6100000D6ABC8E8804A4A404D83A27900E54A40
68173	7	69	1214	15082	50881	\N	53.761592999999998	с. Турхановка, Центральная, 38		0101000020E6100000511212691B3B4A4067EE21E17BE14A40
68176	7	69	1214	56175	51356	\N	53.870531999999997	с.Старые Узели, Заречная, 18 А	Россия, Оренбургская область, Бугурусланский район, село Старые Узелки	0101000020E61000000B09185DDE784A408C0FB3976DEF4A40
68178	7	69	1214	15322	51216	\N	53.736514999999997	с. Старое Тюрино, Центральная, 31		0101000020E61000001F8315A75A5D4A40B8019F1F46DE4A40
68189	7	69	1214	15851	\N	\N	53.941887000000001	с. Сапожкино, Подгорная, 1 А	Россия, Оренбургская область, Бугурусланский район, село Сапожкино	0101000020E6100000CFDA6D179A754A4087C3D2C08FF84A40
68156	7	69	1214	14281	50750	\N	53.747725000000003	д. Саловка, Центральная, 19 А		0101000020E6100000C66CC9AA08294A4068B3EA73B5DF4A40
68159	7	69	1214	14411	50747	\N	53.847771999999999	с. Савруша, Центральная, 12		0101000020E6100000F6EB4E779E324A40753BFBCA83EC4A40
68188	7	69	1214	15794	51129	\N	53.915449000000002	с. Русская Бокла, Новая, 21		0101000020E6100000849F38807E694A40F513CE6E2DF54A40
68171	7	69	1214	15005	51123	\N	53.393661000000002	п. Резвый, Школьная, 4 А		0101000020E6100000F4DC425722464A40F75AD07B63B24A40
68180	7	69	1214	47410	51005	\N	53.3595252093968	п. Рабочий, Степная, 22	Россия, Оренбургская область, Бугурусланский район, село Рабочий	0101000020E6100000266E15C4403D4A40158C4AEA04AE4A40
68186	7	69	1214	47523	50757	\N	53.771816999999999	с. Пронькино, Центральная, 5 А		0101000020E6100000E275FD82DD4C4A4098BF42E6CAE24A40
68185	7	69	1214	15665	50589	\N	53.546289999999999	с. Поникла, Центральная, 61		0101000020E610000070952710763E4A40E010AAD4ECC54A40
68183	7	69	1214	58962	67101	\N	53.744041275784902	с. Полибино, Дорожная, 1	Россия, Оренбургская область, Бугурусланский район, село Палибино	0101000020E61000004A404CC285764A400BF148BC3CDF4A40
68179	7	69	1214	47398	50243	\N	53.402858000000002	с. Пилюгино, Чапаевская, 52		0101000020E61000005F984C158C344A404B77D7D990B34A40
68157	7	69	1214	33163	51332	\N	53.671406342520001	д. Передовка, Центральная, 41	Россия, Оренбургская область, Бугурусланский район, село Передовка	0101000020E610000065389ECF80244A40492BBEA1F0D54A40
68418	7	69	1214	47552	\N	\N	53.709535000000002	п. Октябрьский, Центральная, 11	Россия, Оренбургская область, Бугурусланский район, село Октябрьский	0101000020E61000006362F3716D504A40062FFA0AD2DA4A40
68166	7	69	1214	14750	50901	\N	53.607863999999999	с. Нуштайкино, Школьная, 23		0101000020E61000000B42791F471D4A403735D07CCECD4A40
68177	7	69	1214	15280	\N	\N	53.792332000000002	с. Нойкино, Центральная, 8	Россия, Оренбургская область, Бугурусланский район, село Нойкино	0101000020E6100000828DEBDFF55B4A4082C98D226BE54A40
68175	7	69	1214	15161	51116	\N	53.883988000000002	с. Нижнепавлушкино, Советская, 67		0101000020E61000002BBEA1F0D97E4A403A07CF8426F14A40
68187	7	69	1214	15759	50756	\N	53.795555	с. Мордовский Бугуруслан, Школьная, 40		0101000020E6100000637D03931B434A40AB9509BFD4E54A40
68172	7	69	1214	46875	50357	\N	53.676670316562699	с. Михайловка, Транспортная, 50	Россия, Оренбургская область, Бугурусланский район, село Михайловка	0101000020E6100000B22FD978B03B4A409817601F9DD64A40
69584	7	69	1214	46875	50413	\N	53.676084000000003	с. Михайловка, Рабочая, 25	Россия, Оренбургская область, Бугурусланский район, село Михайловка	0101000020E6100000DD257156443B4A40A8ACA6EB89D64A40
69585	7	69	1214	46875	50246	\N	53.676084000000003	с. Михайловка, Полевая, 1 В	Россия, Оренбургская область, Бугурусланский район, село Михайловка	0101000020E6100000DD257156443B4A40A8ACA6EB89D64A40
68154	7	69	1214	46875	50912	\N	53.676084000000003	с. Михайловка, Калинина Н.С, 32	Россия, Оренбургская область, Бугурусланский район, село Михайловка	0101000020E6100000DD257156443B4A40A8ACA6EB89D64A40
68163	7	69	1214	56129	50931	\N	53.613953929028398	с. Красноярка, Центральная, 14	Россия, Оренбургская область, Бугурусланский район, село Красноярка	0101000020E6100000CEC29E76F83F4A40CB9F6F0B96CE4A40
68169	7	69	1214	47177	51223	\N	53.827604216841799	с. Коровино, Почтовая, 3	Россия, Оренбургская область, Бугурусланский район, село Коровино	0101000020E6100000EEEC2B0FD2854A40F70489EDEEE94A40
68168	7	69	1214	14864	50905	\N	53.452514000000001	с. Коптяжево, Широкая, 2 А		0101000020E610000091B41B7DCC1D4A40B77D8FFAEBB94A40
68167	7	69	1214	14810	51120	\N	53.477696999999999	с. Кокошеевка, Школьная, 28		0101000020E61000000B45BA9F532E4A40DB32E02C25BD4A40
68162	7	69	1214	46373	51122	\N	53.573387274934802	д. Козловка, Дорожная, 10	Россия, Оренбургская область, Бугурусланский район, село Козловка	0101000020E6100000B5FD2B2B4D504A40CC79C6BE64C94A40
68165	7	69	1214	47099	50259	\N	53.574112999999997	с. Кирюшкино, Молодежная, 17		0101000020E6100000C87A6AF5D5274A40AE9AE7887CC94A40
68164	7	69	1214	56127	64206	\N	53.303663918396602	с. Ивановка, Центральная, 13	Россия, Оренбургская область, Бугурусланский район, село Ивановка	0101000020E61000006A32E36DA5434A407C7C4276DEA64A40
68190	7	69	1214	15911	\N	\N	53.991909	п. Земсков, Заречная, 4 А	Россия, Оренбургская область, Бугурусланский район, село Земсков	0101000020E6100000ADF9F19716694A40D5CDC5DFF6FE4A40
68182	7	69	1214	15522	50754	\N	53.415734999999998	пос. Затоновский, пер. Озерный, 2		0101000020E610000033C005D9B2364A40BA66F2CD36B54A40
68207	7	69	1214	47913	51228	\N	53.650176000000002	пос.Затон, Центральная, 6		0101000020E61000005C751DAA29234A40725298F738D34A40
68161	7	69	1214	14493	50587	\N	53.595616999999997	с. Завьяловка, Привокзальная, 4		0101000020E61000003A3DEFC682484A4087F8872D3DCC4A40
68181	7	69	1214	47427	51221	\N	53.323076999999998	д. Жуково, Фурманова, 13		0101000020E61000005A677C5F5C2A4A407E8B4E965AA94A40
68160	7	69	1214	14477	50265	\N	53.699198604056797	с. Елатомка, Советская, 1	Россия, Оренбургская область, Бугурусланский район, село Елатомка	0101000020E6100000556B6116DA4F4A40AD32535A7FD94A40
68153	7	69	1214	46838	51222	\N	53.719154000000003	с. Григорьевка, Заречная, 1		0101000020E610000049BBD1C77C864A40D064FF3C0DDC4A40
68192	7	69	1214	47626	51128	\N	53.745952000000003	п. Вишневка, Молодежная, 23		0101000020E6100000B935E9B644684A406231EA5A7BDF4A40
68174	7	69	1214	15140	50651	\N	53.925831000000002	с. Верхнепавлушкино, Совхозная, 23 А		0101000020E6100000C1C9367007844A40BE4F55A181F64A40
68155	7	69	1214	46893	50440	\N	53.666471999999999	с. Благодаровка, Чапаевская, 19 А		0101000020E6100000B891B245D2324A4090D959F44ED54A40
68152	7	69	1214	46826	50903	\N	53.721795999999998	с. Бестужевка, Центральная, 26		0101000020E6100000E8FA3E1C24824A401A31B3CF63DC4A40
68151	7	69	1214	14052	50585	\N	53.588315999999999	с. Баймаково, Придорожная, 3		0101000020E61000003FABCC94D6314A4055DB4DF04DCB4A40
68150	7	69	1214	56147	51124	\N	53.854663192049799	с. Алексеевка, Московская, 41 а	Россия, Оренбургская область, Бугурусланский район, село Алексеевка	0101000020E6100000102384471B454A40F60CE19865ED4A40
68133	7	69	1237	46450	51205	\N	51.405819000000001	с. Цветочное, Школьная, 12	Россия, Оренбургская область, Беляевский район, село Цветочное	0101000020E6100000710514EAE9FB4B40378C82E0F1B34940
68124	7	69	1237	46228	50749	\N	51.487485999999997	с. Херсоновка, Школьная, 21	Россия, Оренбургская область, Беляевский район, село Херсоновка	0101000020E6100000CD9541B5C11B4C4001A1F5F065BE4940
68129	7	69	1237	13011	51113	\N	51.444774000000002	с.Старицкое, Ленинская, 6б	Россия, Оренбургская область, Беляевский район, село Старицкое	0101000020E6100000B98AC56F0AD94B40390EBC5AEEB84940
68132	7	69	1237	13149	81060	\N	51.223680999999999	п. Сазан, Центральная, 3	Россия, Оренбургская область, Беляевский район, село Сазан	0101000020E6100000DA0418963F0B4C4048DE3994A19C4940
68139	7	69	1237	46571	51117	\N	51.385427999999997	п. Новоорловка, Центральная, 14	Россия, Оренбургская область, Беляевский район, село Новоорловка	0101000020E61000006F2F698CD6474C40397B67B455B14940
68136	7	69	1237	56157	51214	\N	51.038513000000002	с. Междуречье, Школьная, 14	Россия, Оренбургская область, Беляевский район, село Междуречье	0101000020E6100000A6EECA2E184A4C4045BC75FEED844940
68138	7	69	1237	46538	51112	\N	51.349758999999999	п. Листвянка, Школьная, 9	Россия, Оренбургская область, Беляевский район, село Листвянка	0101000020E61000004A42226DE35F4C40A73D25E7C4AC4940
68126	7	69	1237	12865	49954	\N	51.563246999999997	с.Крючковка, Центральная, 25		0101000020E61000004FE61F7D93F84B40F9484A7A18C84940
68140	7	69	1237	13527	50904	\N	51.349735000000003	с. Красноуральск, Школьная, 11	Россия, Оренбургская область, Беляевский район, село Красноуральск	0101000020E61000001A355F251F714C401FA2D11DC4AC4940
68128	7	69	1237	46344	81041	\N	51.368048999999999	с. Ключевка, Советская, 21	Россия, Оренбургская область, Беляевский район, село Ключевка	0101000020E610000089B7CEBF5DE64B40AA29C93A1CAF4940
68134	7	69	1237	62065	81070	\N	51.246946000000001	п.Карагач, Комсомольская, 11	Россия, Оренбургская область, Беляевский район, село Карагач	0101000020E6100000425C397B67344C4063F030ED9B9F4940
68122	7	69	1237	12709	50739	\N	51.381981000000003	с.Жанаталап, Центральная, 2а	Россия, Оренбургская область, Беляевский район, село Жанаталап	0101000020E6100000FC8EE1B19F3D4C40C158DFC0E4B04940
68146	7	69	1237	13804	51212	\N	51.454208999999999	п. Дубенский, Первомайская, 16	Россия, Оренбургская область, Беляевский район, поселок Дубенский	0101000020E6100000427C60C77F514C404146408523BA4940
68469	7	69	1237	46608	50005	\N	51.391779999999997	село Донское, Советская, 103		0101000020E61000000E83F92B646E4C400A9DD7D825B24940
68141	7	69	1237	46608	81081	\N	51.394035000000002	с. Донсоке, Казачья, 16	Россия, Оренбургская область, Беляевский район, село Донское	0101000020E61000009413ED2AA46E4C405C3D27BD6FB24940
68123	7	69	1237	12769	50447	\N	51.418908000000002	с.Днепровка, Южная, 10	Россия, Оренбургская область, Беляевский район, село Днепровка	0101000020E610000093E1783E032C4C40320400C79EB54940
68145	7	69	1237	13719	50896	\N	51.470444999999998	с. Гирьял, Победы, 30	Россия, Оренбургская область, Беляевский район, село Гирьял	0101000020E6100000AE2AFBAE08344C408AC8B08A37BC4940
68142	7	69	1237	13609	50746	\N	51.399726999999999	с. Верхнеозерное, Форштадская, 2	Россия, Оренбургская область, Беляевский район, село Верхнеозерное	0101000020E610000063635E471C5A4C40022A1C412AB34940
68135	7	69	1237	56146	51121	\N	51.274188000000002	с.Васильевка, Центральная, 34	Россия, Оренбургская область, Беляевский район, село Васильевка	0101000020E6100000D5B48B69A6274C40537AA69718A34940
68131	7	69	1237	13100	50258	\N	51.370265000000003	п. Буртинский, Спортивная, 17	Россия, Оренбургская область, Беляевский район, село Буртинский	0101000020E61000004D31074147FF4B403EEDF0D764AF4940
68137	7	69	1237	13375	50416	\N	51.350817999999997	п. Бурлыкский, Центральная, 8	Россия, Оренбургская область, Беляевский район, село Бурлыкский	0101000020E6100000FFCBB568015C4C408F6CAE9AE7AC4940
68125	7	69	1237	12846	51114	\N	51.509953000000003	с.Буранчи, Центральная, 9	Россия, Оренбургская область, Беляевский район, село Буранчи	0101000020E6100000FEB627486C054C40A1BFD02346C14940
68130	7	69	1237	13040	51160	\N	51.344051	461335 село Блюменталь, ул. Центральная 34		0101000020E61000003A90F5D4EADB4B40FB93F8DC09AC4940
68147	7	69	1237	13886	81087	\N	51.399881999999998	с. Беляевка, Ленинская 42в	Россия, Оренбургская область, Беляевский район, село Беляевка	0101000020E61000000AB952CF82344C40292158552FB34940
68904	7	69	1237	13886	49747	\N	51.392828999999999	Беляевка, Комсомольская, 37	Россия, Оренбургская область, Беляевский район, село Беляевка	0101000020E6100000D0B4C4CA68344C40CFF57D3848B24940
68148	7	69	1237	13886	49714	\N	51.399518999999998	с. Беляевка, Банковская, 9	Россия, Оренбургская область, Беляевский район, село Беляевка	0101000020E610000023827170E9344C40B890477023B34940
68143	7	69	1237	46648	50745	\N	51.566589999999998	п. Белогорский, Школьлная, 6	Россия, Оренбургская область, Беляевский район, село Белогорский	0101000020E61000002BF697DD93434C40CD1E680586C84940
68144	7	69	1237	13712	51118	\N	51.443061999999998	с. Алабайтал, Советская, 15	Россия, Оренбургская область, Беляевский район, село Алабайтал	0101000020E61000009D465A2A6F414C40D80C7041B6B84940
68121	7	69	1172	58189	64203	\N	53.592249819301799	село Яковлевка, Центральная, здание сельского Дома культуры, 4	Россия, Оренбургская область, Асекеевский район, село Яковлевка	0101000020E6100000CEA623809B834A402B8716D9CECB4A40
68120	7	69	1172	46139	50895	\N	53.418197999999997	поселок Юдинка, Киселева, здание средней школы, 40		0101000020E6100000AAD72D02636B4A4055A0168387B54A40
68117	7	69	1172	12469	51069	\N	53.555357999999998	"поселок Шамассовка, Центральная, здание сельского клуба, 8 ""Б"""		0101000020E6100000AF40F4A44C8E4A4036C98FF815C74A40
68119	7	69	1172	46134	49710	\N	53.492218000000001	поселок Чкаловский, переулок Парковый, здание сельского Дома культуры, 2		0101000020E610000029081EDFDE774A405340DAFF00BF4A40
68106	7	69	1172	26176	50893	\N	53.606293000000001	станция Филипповка, Привокзальная, здание сельского клуба, 4		0101000020E6100000EE5EEE93A3924A4099654F029BCD4A40
68118	7	69	1172	46097	50260	\N	53.362924	"село Троицкое, Садовая, здание сельского Дома культуры, 5 ""А"""		0101000020E6100000906802452C684A407D772B4B74AE4A40
68110	7	69	1172	12110	50687	\N	53.542507000000001	С.Старосултангулово,ул.Центральная,36а		0101000020E61000002E910BCEE0694A40F06C8FDE70C54A40
68116	7	69	1172	12420	50322	\N	53.480688000000001	"село Старомукменево, Центральная, здание сельского Дома культуры, 64 ""Б"""		0101000020E6100000B6847CD0B3894A4032CA332F87BD4A40
68113	7	69	1172	12295	50257	\N	53.475875000000002	село Старокульшарипово, Центральная, здание сельского Дома культуры, 107		0101000020E610000096236420CF824A40F4FDD478E9BC4A40
68093	7	69	1172	56153	51167	\N	53.585745657883002	Ст.Асекевео ул.Пришкольная 1	Россия, Оренбургская область, Асекеевский район, село Асекеево	0101000020E6100000BA6A9E23F26F4A40A4E194B9F9CA4A40
68446	7	69	1172	48066	51249	\N	53.460990000000002	с. Сосновка, Школьная, 25		0101000020E61000009C31CC09DA7C4A403BE466B801BB4A40
68108	7	69	1172	12035	51093	\N	53.742058999999998	село Самаркино, Центральная, здание сельского клуба, 34		0101000020E610000072512D228A974A40EA5910CAFBDE4A40
68112	7	69	1172	45967	50270	\N	53.393897000000003	село Рязановка, Центральная, здание сельского Дома культуры, 19		0101000020E610000096E7C1DD59974A400B7F86376BB24A40
68772	7	69	1172	58190	64208	\N	53.477534883234803	село Петровка, Народная, 80/1	Россия, Оренбургская область, Асекеевский район, село Петровка	0101000020E61000005B785E2A36524A4002D9EBDD1FBD4A40
68109	7	69	1172	45894	50581	\N	53.532274999999998	село Новосултангулово, Центральная, здание сельского Дома культуры, 78/10		0101000020E6100000F7915B936E6F4A403CBD529621C44A40
68114	7	69	1172	12322	51111	\N	53.445633000000001	село Новокульшарипово, Новая, здание сельского клуба, 32		0101000020E61000005708ABB184794A405A828C800AB94A40
68115	7	69	1172	12370	51203	\N	53.504950000000001	поселок Мулланур, Центральная, здание сельского клуба, 66		0101000020E6100000F4E0EEACDD7A4A40BF0E9C33A2C04A40
68107	7	69	1172	45854	50899	\N	53.688296999999999	село Мочегай, Школьная, здание сельского Дома культуры, 28		0101000020E61000001A1538D906944A40AB77B81D1AD84A40
68105	7	69	1172	45816	50894	\N	53.642761999999998	село Мартыновка, Центральная, здание сельского Дома культуры, 49		0101000020E61000002B6B9BE271994A40478E740646D24A40
68103	7	69	1172	11803	50737	\N	53.474144000000003	"село Лекаревка, Садовая, здание сельского Дома культуры, 9 ""А"""		0101000020E6100000F584251E505E4A401DCC26C0B0BC4A40
68102	7	69	1172	11762	50544	\N	53.517693999999999	село Кутлуево, Центральная, здание сельского Дома культуры, 4		0101000020E6100000D6FD63213A9E4A40EFAA07CC43C24A40
68111	7	69	1172	12195	50748	\N	53.472017000000001	поселок Курбанай, Центральная, здание сельского клуба, 16		0101000020E6100000DE3B6A4C88674A40F913950D6BBC4A40
68101	7	69	1172	45739	50445	\N	53.223905000000002	поселок Красногорский, Садовая, здание средней школы, 11		0101000020E6100000D13E56F0DB744A40983446EBA89C4A40
68100	7	69	1172	11621	50914	\N	53.653900999999998	село Кисла, Молодежная, здание средней школы, 8		0101000020E6100000396403E9626D4A402DE92807B3D34A40
69527	7	69	1172	46712	50855	\N	53.355471000000001	с.Казанка, ул.Центральная, 97		0101000020E61000004D2F3196E9494A4095D6DF1280AD4A40
68104	7	69	1172	11822	50738	\N	53.420521999999998	деревня Золотой Родник, Зеленая, здание основной школы, 388		0101000020E6100000A8AAD0402C554A40CF9F36AAD3B54A40
68099	7	69	1172	56037	49713	\N	53.553983000000002	станция Заглядино, Партизанская, здание сельского Дома культуры, 9		0101000020E610000019C5724BAB5D4A401EC539EAE8C64A40
68098	7	69	1172	45697	50734	\N	53.209885999999997	поселок Думино, Набережная, здание сельского клуба, 17		0101000020E61000007D59DAA9B98C4A40B2F1608BDD9A4A40
68767	7	69	1172	49563	50969	\N	53.477300999999997	село Воскресеновка, Центральная, 12-А		0101000020E6100000E5F0492712924A408EACFC3218BD4A40
68097	7	69	1172	58174	64141	\N	53.277810072932802	село Воздвиженка, Центральная, здание средней школы, 6	Россия, Оренбургская область, Асекеевский район, село Воздвиженка	0101000020E610000035B56CAD2F844A403A4030478FA34A40
68089	7	69	1172	11135	50678	\N	53.355964999999998	П.Брянчаниново,ул.Набережная, 16а		0101000020E61000005F07CE1951724A40A4C2D84290AD4A40
68096	7	69	1172	45662	50536	\N	53.309795999999999	С.Баландино, ул.Золотухина, 63 а		0101000020E61000002E3BC43F6C534A403F373465A7A74A40
68092	7	69	1172	11193	49791	\N	53.580019999999998	С.Асекеево, ул.Советская 16 а		0101000020E610000043E73576896A4A40518369183ECA4A40
68091	7	69	1172	11193	49944	\N	53.580019999999998	"село Асекеево, Набережная, здание районного Дома культуры, 13 ""А"""		0101000020E610000043E73576896A4A40518369183ECA4A40
68095	7	69	1172	11417	51204	\N	53.263888000000001	село Аксютино, Школьная, здание средней школы, 7		0101000020E610000046EBA86A82904A4047E7FC14C7A14A40
68048	7	69	224	9152	51197	\N	52.966081000000003	с. Яфарово, ул. Советская, 44		0101000020E610000016A58460551B4B40BC24CE8AA87B4A40
68049	7	69	224	9152	79086	\N	52.966081000000003	п. Комсомольский, ул. Комсомольская, 19	Россия, Оренбургская область, Александровский район, село Яфарово	0101000020E610000016A58460551B4B40BC24CE8AA87B4A40
68060	7	69	224	9718	\N	\N	52.703198999999998	с. Якут, ул. Советская, 7	Россия, Оренбургская область, Александровский район, село Якут	0101000020E610000056D7A19A921E4B403ACAC16C025A4A40
68046	7	69	224	9067	50725	\N	52.846625061417697	с. Юртаево, ул. Школьная, 12	Россия, Оренбургская область, Александровский район, село Юртаево	0101000020E610000061C26856B62D4B40EE7C3F355E6C4A40
68056	7	69	224	61390	79117	\N	52.805480000000003	п. Южный, ул. Центральная, 3	Россия, Оренбургская область, Александровский район, село Южный	0101000020E61000009B560A815C224B4082CAF8F719674A40
68069	7	69	224	10151	51220	\N	52.532044999999997	с. Шар, ул. Совхозная, 38А		0101000020E610000042959A3DD02C4B400A80F10C1A444A40
68054	7	69	224	9401	51107	\N	52.831074999999998	с. Чебоксарово, ул. Советская, 40		0101000020E610000024D1CB2896154B40F8C264AA606A4A40
68066	7	69	224	10032	50535	\N	52.466909000000001	с. Хортица, ул. Советская, 37		0101000020E610000001FC53AA441F4B40A29A92ACC33B4A40
68070	7	69	224	56108	50735	\N	52.396841000000002	с. Федоровка, ул. Октябрьская, 49	Россия, Оренбургская область, Александровский район, село Федоровка	0101000020E61000002C7DE882FA2E4B40215B96AFCB324A40
68053	7	69	224	49241	50869	\N	52.782806000000001	с. Успенка, ул. Советская, 43		0101000020E61000006536C82423094B40698EACFC32644A40
68055	7	69	224	61386	79109	\N	52.758436000000003	с. Тукай, ул. Школьная, 14А	Россия, Оренбургская область, Александровский район, село Тукай	0101000020E6100000B08C0DDDEC1D4B40F60D4C6E14614A40
68045	7	69	224	9052	51105	\N	52.795712999999999	с. Султакай, ул. Советская, 33		0101000020E6100000BA86191A4F304B40430070ECD9654A40
68080	7	69	224	45360	51200	\N	52.674143000000001	п. Романовский, ул. Центральная, 21		0101000020E6100000C74ACCB392584B40E6E95C514A564A40
68067	7	69	224	61399	79130	\N	52.455233	с. Петровка, ул. Гагарина, 56Б	Россия, Оренбургская область, Александровский район, село Петровка	0101000020E610000003B68311FB244B40AD872F13453A4A40
69390	7	69	224	10336	51026	\N	52.929856999999998	Оренбургская область, Сорочинский район, Рощинский сельсовет, п.Октябрьский, Октябрьская, д.24, СДК		0101000020E6100000772B4B7496054B40747ADE8D05774A40
68065	7	69	224	9953	51199	\N	52.548541999999998	с. Озерка, ул. Центральная, 108		0101000020E610000026A77686A9114B40C03DCF9F36464A40
68073	7	69	224	857	50874	\N	52.393962000000002	с. Новоспасское, ул. Школьная, 10	Россия, Оренбургская область, Александровский район, село Новоспасское	0101000020E6100000E3C4573B8A494B40F2EEC8586D324A40
68548	7	69	224	857	50942	\N	52.393962000000002	село Новоспасское, улица Центральная, д. 8		0101000020E6100000E3C4573B8A494B40F2EEC8586D324A40
68072	7	69	224	45994	50693	\N	52.424993389509403	с. Новоникольское, ул. Хуторская, 13	Россия, Оренбургская область, Александровский район, село Новоникольское	0101000020E6100000C7D9740470414B40B403AE2B66364A40
68051	7	69	224	49366	79098	\N	52.875888000000003	с. Новоникитино, ул. Пролетарская, 4	Россия, Оренбургская область, Александровский район, село Новоникитино	0101000020E61000006B990CC7F3FF4A40BC7A15191D704A40
68083	7	69	224	45414	51208	\N	52.556990999999996	с. Новомихайловка, ул. Новая, 9		0101000020E610000015731074B4444B404A95287B4B474A40
68078	7	69	224	61422	79158	\N	52.573988	с. Михайловка, пер. школьный, 2	Россия, Оренбургская область, Александровский район, село Михайловка	0101000020E6100000E7FC14C7815D4B40F225547078494A40
68064	7	69	224	56109	50743	\N	52.572153999999998	п. Мирный, ул. мира, 8Б	Россия, Оренбургская область, Александровский район, село Мирный	0101000020E6100000BA8784EFFD074B4046239F573C494A40
68075	7	69	224	10463	\N	\N	52.462668000000001	п. Марксовский, ул. Школьная, 2	Россия, Оренбургская область, Александровский район, село Марксовский	0101000020E6100000520B2593535D4B40EF737CB4383B4A40
68047	7	69	224	61374	79065	\N	52.747779999999999	п. Майский, ул. Майская, 45	Россия, Оренбургская область, Александровский район, село Майский	0101000020E61000001FBFB7E9CF324B402B4D4A41B75F4A40
68059	7	69	224	9647	51188	\N	52.612527999999998	с. Кутучево, ул. Новая, 16		0101000020E6100000204432E4D82A4B4030F14751674E4A40
68063	7	69	224	9856	50832	\N	52.671255000000002	с. Курпячево, ул. Центральная, 7		0101000020E6100000E89FE06245074B40642310AFEB554A40
68062	7	69	224	9824	50884	\N	52.647860000000001	с. Каяпкулово, ул. Сагита Агиша, 10		0101000020E6100000821B295B24134B407B319413ED524A40
68058	7	69	224	56195	51405	\N	52.621549400525097	с. Канчирово, ул. Сагита Агиша, 6		0101000020E61000009DBB5D2F4D234B4046EEE9EA8E4F4A40
68068	7	69	224	10114	51100	\N	52.416702000000001	с. Канцеровка, ул. Советская, 58		0101000020E61000001C9947FE60264B40C216BB7D56354A40
68074	7	69	224	61418	79153	\N	52.445177999999999	с. Каменка, ул. Мира, 68	Россия, Оренбургская область, Александровский район, село Каменка	0101000020E6100000D1EAE40CC52F4B400873BB97FB384A40
68050	7	69	224	49184	50248	\N	52.902816000000001	с. Каликино, ул. Советская, 3		0101000020E6100000C45A7C0A800B4B401C2785798F734A40
68084	7	69	224	45436	50730	\N	52.535424999999996	с. Исянгильдино, ул. Советская, 23		0101000020E6100000807EDFBF79494B40FB3A70CE88444A40
68057	7	69	224	56192	51385	\N	52.630934922134699	с. Зеленая Роща, ул. Ленина, 19	Россия, Оренбургская область, Александровский район, село Зеленая Роща	0101000020E610000027D87F9D9B284B406D73637AC2504A40
68077	7	69	224	49571	51106	\N	52.600622000000001	п. Загорский, ул. Школьная, 4		0101000020E6100000F56569A7E6724B400AA1832EE14C4A40
68071	7	69	224	10251	49874	\N	52.400561000000003	с. Ждановка, ул. Ленина, 17		0101000020E61000003EEDF0D764334B40CB86359545334A40
68079	7	69	224	49597	50729	\N	52.637963999999997	с. Добринка, ул. Центральная, 14		0101000020E610000091D10149D8534B403E03EACDA8514A40
68158	7	69	224	56128	50919	\N	52.499028029067702	с. Дмитриевка, Центральная, 46	Россия, Оренбургская область, Александровский район, село Дмитриевка	0101000020E6100000FCDEA63FFB634B40E7E44526E03F4A40
68076	7	69	224	56128	50919	\N	52.498663999999998	с. Дмитриевка, ул. Центральная, 10	Россия, Оренбургская область, Александровский район, село Дмитриевка	0101000020E6100000E36BCF2C09644B40A5D8D138D43F4A40
68052	7	69	224	49218	51183	\N	52.930351000000002	п. Дальний, ул. Молодежная, 8		0101000020E6100000A27BD6355AF04A408466D7BD15774A40
68061	7	69	224	48459	50753	\N	52.662619999999997	с. Георгиевка, ул. Школьная, 16		0101000020E6100000B779E3A4300F4B4077D66EBBD0544A40
68081	7	69	224	56107	50732	\N	52.691001999999997	с. Гавриловка, ул. Советская, 30	Россия, Оренбургская область, Александровский район, село Гавриловка	0101000020E6100000EE06D15AD14E4B403CBCE7C072584A40
68044	7	69	224	49108	51201	\N	52.636723000000003	п. Буранный, ул. Буранная, 27		0101000020E6100000F3380CE6AF364B4036CEA62380514A40
68964	7	69	224	49105	50560	\N	52.582202000000002	село Архангеловка, Центральная, дом 81		0101000020E61000000F26C5C727644B4039D55A98854A4A40
68087	7	69	224	56095	79166	\N	52.680007000000003	с. Александровка, ул. Эстрадная, 17/1	Россия, Оренбургская область, Александровский район, село Александровка	0101000020E6100000F419506F46354B408A0629780A574A40
68042	7	69	224	56095	79035	\N	52.678781000000001	с. Александровка, ул. Мичурина, 51	Россия, Оренбургская область, Александровский район, село Александровка	0101000020E6100000CBDB114E0B364B40B612BA4BE2564A40
68085	7	69	224	10953	51059	\N	52.597290999999998	с. Актыново, ул. Советская, 28		0101000020E61000000FD4298F6E364B40FA980F08744C4A40
68014	7	69	919	7575	\N	\N	50.970613999999998	с.Шулаксу, дом культуры		0101000020E61000007FBC57AD4CDA4B4016855D143D7C4940
68040	7	69	919	8811	50315	\N	50.770840999999997	п.Шкуновка, Центральная (дом культуры), 6	Россия, Оренбургская область, Акбулакский район, село Шкуновка	0101000020E61000000211E2CAD9AF4B403DB5FAEAAA624940
68039	7	69	919	56086	50630	\N	50.736280000000001	с.Шаповалово, Центральная (школа), 42	Россия, Оренбургская область, Акбулакский район, село Шаповаловка	0101000020E61000002CF015DD7AC94B4075594C6C3E5E4940
68037	7	69	919	56220	81092	\N	50.822358000000001	п.Ушкунь, Тамдинская (фельдшерско-акушерский пункт), 2	Россия, Оренбургская область, Акбулакский район, село Ушкуль	0101000020E6100000E413B2F336FE4B404FCDE50643694940
68038	7	69	919	8723	50878	\N	50.760120000000001	с.Тамдысай, Новая  (школа), 3	Россия, Оренбургская область, Акбулакский район, село Тамдысай	0101000020E610000079CBD58F4D004C408C84B69C4B614940
68027	7	69	919	47487	50545	\N	51.109136999999997	с.Советское, Центральная (школа), 9		0101000020E6100000309DD66D50254C404BE48233F88D4940
69104	7	69	919	47487	50568	\N	51.109136999999997	с. Советское, Заречная, 4а		0101000020E6100000309DD66D50254C404BE48233F88D4940
68034	7	69	919	8547	50574	\N	50.901874999999997	с.Сагарчин, Советская (школа), 1		0101000020E610000059FAD005F5F34B403D0AD7A370734940
69215	7	69	919	49384	51040	\N	51.148494999999997	с. Орловка, Центральная (Орловская основная общеобразовательная школа), 2		0101000020E6100000A6B6D4415E254C404C4F58E201934940
68033	7	69	919	8495	51101	\N	50.870604999999998	с.Новоуспеновка, Центральная (школа), 1Б		0101000020E6100000DB4FC6F830BD4B40F65D11FC6F6F4940
68031	7	69	919	48893	50434	\N	51.140087000000001	с.Новопавловка, Центральная  (дом культуры), 27		0101000020E6100000290989B48DCD4B4021CCED5EEE914940
33281	4	41	\N	16582	46238	\N	48.779257999999999	г. Биробиджан, Пионерская, 80		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
68023	7	69	919	7966	50669	\N	51.031491000000003	п.Новоодесский, Центральная (фельдшерско-акушерский пункт), 32/1		0101000020E6100000E60819C8B3B54B40268FA7E507844940
68029	7	69	919	8291	50316	\N	51.222413119847999	п.Новогригорьевка (дом культуры), Победы, 39	Россия, Оренбургская область, Акбулакский район, село Новогригорьевка	0101000020E6100000E27492AD2EF34B40469A7807789C4940
68243	7	69	919	48571	49723	\N	51.214604999999999	с.Новоалександровка, ул.Центральная, 45/1		0101000020E6100000BA2EFCE07CE64B406F47382D789B4940
68024	7	69	919	8034	50722	\N	50.971034000000003	п.Нагумановка, Нагумановская (дом культуры), 26		0101000020E6100000AFB0E07EC0BF4B40ECA694D74A7C4940
68016	7	69	919	7652	51050	\N	51.076756000000003	п.Меловой завод, Заводская (гостиница), 2		0101000020E610000005FC1A4982D44B40CAE2FE23D3894940
68032	7	69	919	48910	51109	\N	51.271734000000002	п.Межгорный, Школьная (дом культуры), 8А		0101000020E6100000B43A394371CB4B400B9B012EC8A24940
68020	7	69	919	48704	50672	\N	50.935321000000002	п.Майдан, Центральная (школа), 16/7		0101000020E610000047020D3675D64B408A213999B8774940
68022	7	69	919	48741	51048	\N	51.052670999999997	п.Кызылбулак, Биканова (дом культуры), 7		0101000020E6100000A4349BC761B04B404B395FECBD864940
68013	7	69	919	7516	\N	\N	50.930655000000002	п.Кулаксай, школа		0101000020E61000009AEC9FA701E74B40F06DFAB31F774940
68017	7	69	919	7696	50671	\N	51.023423999999999	п.Кужунтай, Центральная (дом культуры), 28		0101000020E61000006D718DCF64C74B4083F8C08EFF824940
68035	7	69	919	48956	51233	\N	50.876283999999998	п.Корниловка, Украинская (фельдшерско-акушерский пункт), 6		0101000020E6100000137EA99F37FB4B400801F9122A704940
68030	7	69	919	48871	51108	\N	51.115752000000001	с.Карповка, Центральная (дом культуры), 8А		0101000020E6100000B49080D1E5074C402A3927F6D08E4940
68028	7	69	919	8216	50726	\N	51.165821000000001	с.Карасай, Гайко (дом культуры), 36		0101000020E61000004A287D21E4F84B40B9FE5D9F39954940
68025	7	69	919	8070	50724	\N	50.994328000000003	п.Каракудук, Семенова (сельсовет), 44		0101000020E6100000F06B2409C2154C40A1BFD023467F4940
68018	7	69	919	48670	50325	\N	50.970398000000003	п.Кайракты, Школьная (школа), 4		0101000020E6100000F7729F1C05F64B404A0D6D00367C4940
68021	7	69	919	48723	50309	\N	50.9775440346666	с.Весеый Первый, Набережная (школа), 6	Россия, Оренбургская область, Акбулакский район, село Веселый Первый	0101000020E610000052EDD3F198C94B4055336B29207D4940
68026	7	69	919	8132	51236	\N	50.947857999999997	с.Веселый Второй, Центральная (школа), 36		0101000020E610000080BBECD79D224C4040A0336953794940
68036	7	69	919	8632	81090	\N	50.849409999999999	п.Акоба, Абдешева (фельшерско-акушерский пункт), 1	Россия, Оренбургская область, Акбулакский район, село Акоба	0101000020E610000020EF552B13F24B409B728577B96C4940
68010	7	69	919	7311	49868	\N	51.005585000000004	п.Акбулак, Терещенко (школа №3), 32		0101000020E61000009032E202D0CE4B40912C6002B7804940
68008	7	69	919	7311	49696	\N	51.005585000000004	п.Акбулак, ул.Советская, дом культуры, 39	Россия, Оренбургская область, Акбулакский район, поселок Акбулак	0101000020E61000009032E202D0CE4B40912C6002B7804940
68009	7	69	919	7311	49706	\N	51.005585000000004	п.Акбулак, ул.Оренбургская (актовый зал ЖКХ), 146		0101000020E61000009032E202D0CE4B40912C6002B7804940
68011	7	69	919	7311	49871	\N	51.005585000000004	"п.Акбулак, Комсомольская (кинотеатр ""Колос""), 20"		0101000020E61000009032E202D0CE4B40912C6002B7804940
68012	7	69	919	7311	49810	\N	51.005585000000004	п.Акбулак, Горбунова (школа-лицей), 21		0101000020E61000009032E202D0CE4B40912C6002B7804940
68002	7	69	666	56097	50676	\N	51.619162000000003	Оренбургская область, Адамовский район, Теренсайский сельсовет, с.Бело, Школьная, 13		0101000020E6100000323B8BDEA9084E4086764EB340CF4940
67969	7	69	666	56094	50666	\N	51.326613000000002	Оренбургская область, Адамовский район, Адамовский поссовет, п.Новоада, Старый, 12		0101000020E6100000BC581822A7E14D4067B96C74CEA94940
67987	7	69	666	56043	49841	\N	51.619162000000003	Оренбургская область, Адамовский район, Комсомольский сельсовет, п.Ком, Волгоградская, 10		0101000020E6100000323B8BDEA9084E4086764EB340CF4940
68006	7	69	666	56091	50642	\N	51.648361929152102	Оренбургская область, Адамовский район, Юбилейный сельсовет, п.Юбилейн, Советская, 13	Россия, Оренбургская область, Адамовский район, село Юбилейный	0101000020E610000028F4FA93F8AC4D400DFCA886FDD24940
67985	7	69	666	56126	50886	\N	51.856778375602303	Оренбургская область, Адамовский район, Елизаветинский сельсовет, п.Эн, Школьная, 4	Россия, Оренбургская область, Адамовский район, село Энбекши	0101000020E61000004948A46DFCCB4D4055F7C8E6AAED4940
68004	7	69	666	7121	49809	\N	51.813237999999998	Оренбургская область, Адамовский район, Шильдинский поссовет, п.Шильда, Садовая, 35а		0101000020E610000063B323D577E24D40A6EECA2E18E84940
68005	7	69	666	7121	50442	\N	51.813237999999998	Оренбургская область, Адамовский район, Шильдинский поссовет, п.Шильда, Комсомольская, 19а		0101000020E610000063B323D577E24D40A6EECA2E18E84940
67996	7	69	666	56089	50636	\N	51.670316292194698	Оренбургская область, Адамовский район, Совхозный сельсовет, п.Совхозн, Мира, 2а	Россия, Оренбургская область, Адамовский район, село Совхозный	0101000020E61000007D957CEC2E004E4026FE28EACCD54940
68000	7	69	666	56122	50865	\N	51.589875577786302	Оренбургская область, Адамовский район, Теренсайский сельсовет, п.Слюд, Школьная, 16	Россия, Оренбургская область, Адамовский район, село Слюдяной	0101000020E610000015376E313FAB4D40FF58880E81CB4940
67994	7	69	666	56105	50733	\N	51.313707856979399	Оренбургская область, Адамовский район, Обильновский сельсовет, п.Обил, Комсомольская, 6	Россия, Оренбургская область, Адамовский район, село Обильный	0101000020E61000001DC9E53FA46B4E402D3F709527A84940
67995	7	69	666	56151	51158	\N	51.571908053403597	Оренбургская область, Адамовский район, Обильновский сельсовет, п.Ново, Школьная, 1	Россия, Оренбургская область, Адамовский район, село Нововинницкий	0101000020E6100000CDAE7B2B12054E400F29064834C94940
67979	7	69	666	56151	51394	\N	51.568282600710099	Оренбургская область, Адамовский район, Адамовский поссовет, п.Нововин, Советская, 28		0101000020E610000063B83A00E2044E40B7EF517FBDC84940
67981	7	69	666	56203	51411	\N	51.393562347381902	Оренбургская область, Адамовский район, Адамовский поссовет, с.Нижняя, Октябрьская, 18		0101000020E6100000268A90BA9DE54D406479573D60B24940
67997	7	69	666	56199	51403	\N	51.768693159408897	Оренбургская область, Адамовский район, Совхозный сельсовет, п.Мещеряк, Советская, 2		0101000020E6100000D28BDAFD2AF24D4002D53F8864E24940
67990	7	69	666	6435	50305	\N	51.908127	Оренбургская область, Адамовский район, Майский сельсовет, п.Майский, Советская, 16		0101000020E6100000DFDFA0BDFAB24D40ABCE6A813DF44940
67973	7	69	666	56197	51398	\N	51.4312851865377	Оренбургская область, Адамовский район, Аниховский сельсовет, с.Красно, Советская, 13	Россия, Оренбургская область, Адамовский район, село Красноярск	0101000020E6100000D8497D59DA114E40B020CD5834B74940
68438	7	69	666	58185	64189	\N	51.567512217255597	п. Комсомольский, Школьная, 10	Россия, Оренбургская область, Адамовский район, село Комсомольский	0101000020E6100000A724EB7074514E40350BB43BA4C84940
67978	7	69	666	56106	50728	\N	51.718389000000002	Оренбургская область, Адамовский район, Брацлавский сельсовет, с.Камен, Школьный, 4	Россия, Оренбургская область, Адамовский район, село Каменецк	0101000020E6100000DB4FC6F830354E403067B62BF4DB4940
67976	7	69	666	56179	51369	\N	51.624333999999998	Оренбургская область, Адамовский район, Брацлавский сельсовет, с.Каинс, Островского, 11А	Россия, Оренбургская область, Адамовский район, село Каинсай	0101000020E6100000C09481035A1A4E40F3E32F2DEACF4940
67989	7	69	666	6367	\N	\N	51.536816999999999	Оренбургская область, Адамовский район, Комсомольский сельсовет, п.Заполье, Здание школы	Россия, Оренбургская область, Адамовский район, село Заполье	0101000020E61000005A2DB0C744364E40EA77616BB6C44940
67984	7	69	666	61196	77523	\N	51.764578394476104	Оренбургская область, Адамовский район, Елизаветинский сельсовет, с.Ел, Ленина, 12	Россия, Оренбургская область, Адамовский район, село Елизаветинка	0101000020E6100000ED0C535BEADE4D40DC9E20B1DDE14940
67971	7	69	666	56110	50751	\N	51.637504999999997	Оренбургская область, Адамовский район, Адамовский поссовет, п.Джусинский, ул. Тюлигенова, 6	Россия, Оренбургская область, Адамовский район, село Джусинск	0101000020E61000009561DC0DA2DD4D40AB048BC399D14940
67974	7	69	666	5578	\N	\N	51.393667999999998	Оренбургская область, Адамовский район, Аниховский сельсовет, с.Джасай, Центральная, 7	Россия, Оренбургская область, Адамовский район, село Джасай	0101000020E610000030A182C30B344E40A9BD88B663B24940
67970	7	69	666	56182	51371	\N	51.466955124904899	Оренбургская область, Адамовский район, Адамовский поссовет, п.Джарлин, Октябрьская, 1	Россия, Оренбургская область, Адамовский район, село Джарлинский	0101000020E61000006231EA5A7BF34D4012DA722EC5BB4940
67975	7	69	666	56068	50374	\N	51.666312610231103	Оренбургская область, Адамовский район, Брацлавский сельсовет, с.Брацл, Целинная, 40	Россия, Оренбургская область, Адамовский район, село Брацлавка	0101000020E610000061E0B9F770214E4028F38FBE49D54940
67986	7	69	666	56140	51054	\N	51.630276402235999	Оренбургская область, Адамовский район, Елизаветинский сельсовет, с.Ба, Школьная, 5	Россия, Оренбургская область, Адамовский район, село Баймурат	0101000020E6100000354415FE0CD14D4013BA4BE2ACD04940
67972	7	69	666	56080	50618	\N	51.4887132472902	Оренбургская область, Адамовский район, Аниховский сельсовет, с.Анихов, Ленина, 19	Россия, Оренбургская область, Адамовский район, село Аниховка	0101000020E6100000A8C4758C2B1E4E40A510C8258EBE4940
67977	7	69	666	5751	50665	\N	51.710906000000001	Оренбургская область, Адамовский район, Брацлавский сельсовет, с.Аневк, Советская, 9А		0101000020E61000005AF5B9DA8A1D4E40DD43C2F7FEDA4940
68003	7	69	666	56136	51390	\N	51.6403175572338	Оренбургская область, Адамовский район, Теренсайский сельсовет, с.Андр, Советская, 12	Россия, Оренбургская область, Адамовский район, село Андреевка	0101000020E61000004FE960FD9FC54D402385B2F0F5D14940
67982	7	69	666	5098	\N	\N	51.521633000000001	Оренбургская область, Адамовский район, Адамовский поссовет, п.Адамовка, Здание ДРСУ	Россия, Оренбургская область, Адамовский район, поселок Адамовка	0101000020E610000096EB6D3315F84D40D7C1C1DEC4C24940
67966	7	69	666	5098	49808	\N	51.521633000000001	Оренбургская область, Адамовский район, Адамовский поссовет, п.Адамовк, Школьная, 1а		0101000020E610000096EB6D3315F84D40D7C1C1DEC4C24940
67965	7	69	666	5098	49693	\N	51.521633000000001	Оренбургская область, Адамовский район, Адамовский поссовет, п.Адамовк, Пушкинская, 71		0101000020E610000096EB6D3315F84D40D7C1C1DEC4C24940
67968	7	69	666	5098	49794	\N	51.521633000000001	Оренбургская область, Адамовский район, Адамовский поссовет, п.Адамовк, Майская, 119		0101000020E610000096EB6D3315F84D40D7C1C1DEC4C24940
67967	7	69	666	5098	49794	\N	51.521633000000001	Оренбургская область, Адамовский район, Адамовский поссовет, п.Адамовк, Майская, 96		0101000020E610000096EB6D3315F84D40D7C1C1DEC4C24940
68430	7	69	604	47778	51283	\N	53.789656000000001	с. Адрианополь, Черемушки, 10		0101000020E6100000D219187959CF4A408B8BA37213E54A40
67963	7	69	604	4990	50408	\N	53.904077000000001	с.Чеганлы, Тукаевская, 11		0101000020E6100000B0FECF61BEC84A406C088ECBB8F34A40
67962	7	69	604	4931	50256	\N	53.726852000000001	с.Тирис - Усманово, Оренбургская, 24		0101000020E61000005D6F9BA910AB4A401F84807C09DD4A40
67964	7	69	604	5015	51045	\N	53.907228000000003	с.Степановка-2, Садовая, 14		0101000020E6100000E98024ECDBB34A40FC010F0C20F44A40
67961	7	69	604	4878	50320	\N	53.923222000000003	с.Старые Шалты, пер.Школьный, 5		0101000020E610000026E4839ECD9E4A404F7974232CF64A40
68610	7	69	604	4347	50689	\N	53.591496999999997	Радовка, ул. Центральная, 31		0101000020E610000040A0336953CD4A404F57772CB6CB4A40
62385	7	68	\N	629	17280	\N	54.955396	Нижегородская область, город Саров, ул.Ленина, д.28		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
67958	7	69	604	46032	50355	\N	53.7827178267788	с.Покровка, Советская, 2 А	Россия, Оренбургская область, Абдулинский район, село Покровка	0101000020E61000007E8B4E965AA94A40CAFE791A30E44A40
67947	7	69	604	4148	51012	\N	53.672511	с.Новый Тирис, Коммунистическая, 28		0101000020E6100000F488D1730BBF4A40A29927D714D64A40
67955	7	69	604	47511	50430	\N	53.662140000000001	с.Новоякупово, Школьная, 4 Б		0101000020E610000090F5D4EAABC94A40CDAFE600C1D44A40
67941	7	69	604	3810	51024	\N	54.003590000000003	с.Николькино, Центральная, 56		0101000020E6100000EECF4543C6C14A40DC4B1AA375004B40
67954	7	69	604	4510	51237	\N	53.509909	с.Нижний Курмей, Родниковая, 8		0101000020E610000048E2E5E95CF74A40D177B7B244C14A40
67952	7	69	604	4412	51044	\N	53.8123371852272	с.Малый Сурмет, Садовая, 5	Россия, Оренбургская область, Абдулинский район, село Малый Сурмет	0101000020E61000001D739EB12FAF4A40562AA8A8FAE74A40
67950	7	69	604	4261	51017	\N	53.536026999999997	с.Камыш - Садак, Школьная, 2		0101000020E61000005C8E57207AD84A40F16261889CC44A40
67948	7	69	604	47366	50488	\N	53.762982000000001	пос.Искра, Молодежная, 2 А		0101000020E61000006FB9FAB149D04A40E5B7E864A9E14A40
67960	7	69	604	4823	51020	\N	53.819577000000002	с.Исайкино, Школьная, 3		0101000020E61000008524B37A87974A40E3C62DE6E7E84A40
67946	7	69	604	56138	51041	\N	53.659936000000002	с.Зерикла, Центральная, 4	Россия, Оренбургская область, Абдулинский район, село Зерикла	0101000020E61000003481221631B24A40FEB968C878D44A40
67944	7	69	604	3945	51238	\N	53.545327	с.Емантаево, Васильевская, 2 А		0101000020E61000006939D0436DE94A401A506F46CDC54A40
67945	7	69	604	3995	51043	\N	53.462238999999997	с.Егорьевка, Молодежная, 1		0101000020E6100000D00D4DD9E9F34A40C6F7C5A52ABB4A40
67949	7	69	604	47384	50266	\N	53.709347345989002	пос.Венера, Совхозная, 6 А	Россия, Оренбургская область, Абдулинский район, село Венера	0101000020E6100000D690B8C7D2D14A400342EBE1CBDA4A40
67959	7	69	604	47584	50661	\N	53.838645	д.Васькино, Центральная, 7		0101000020E6100000BD1DE1B4E0914A401AFA27B858EB4A40
67957	7	69	604	56161	51280	\N	53.641305000000003	с. Васильевка, Московская, 11	Россия, Оренбургская область, Абдулинский район, село Васильевка	0101000020E6100000677DCA3159E24A4072E1404816D24A40
67943	7	69	604	3897	51047	\N	53.757168999999998	с.Булатовка, Центральная, 47		0101000020E610000010406A1327B54A40C345EEE9EAE04A40
67953	7	69	604	4428	50664	\N	53.797432000000001	с.Большой Сурмет, Школьная, 4		0101000020E61000007E9065C1C4B74A405664744012E64A40
67942	7	69	604	3849	50559	\N	53.717598000000002	с.Артемьевка, Советская, 38		0101000020E6100000293DD34B8CC14A4067D65240DADB4A40
69401	7	69	604	45620	\N	\N	53.820593000000002	село Алексеевка, Советская, 45А	Россия, Оренбургская область, Абдулинский район, село Алексеевка	0101000020E61000008CB96B09F9904A40CC29013109E94A40
67951	7	69	604	47435	50663	\N	53.480629	с.Авдеевка, Школьна, 4		0101000020E61000001900AAB871E34A402D41464085BD4A40
67940	7	69	604	47192	50662	\N	54.042664000000002	с.Абдрахманово, Школьная, 5		0101000020E6100000DE74CB0EF1BF4A40B85B920376054B40
62115	7	68	\N	50037	19482	\N	56.289427073636404	"Нижегородская область, город Нижний Новгород, д.Ближнее Константиново, ГОУ НПО ""Профессиональный лицей №41"", ул.Полевая, д.4"	Россия, Нижегородская область, Нижний Новгород, Нижегородский район, улица Полевая	0101000020E6100000451152B7B30B46402ACAA5F10B254C40
61692	7	68	\N	8797	16721	\N	56.208710000000004	Нижегородская область, Кстовский район, пос. Селекционной станции, клуб	Россия, Нижегородская область, поселок Селекционной Станции	0101000020E610000024D236FE44034640912C6002B71A4C40
62380	7	68	\N	49771	17283	\N	54.929396705544697	Нижегородская область, город Саров, ул.Ленина, д.52		0101000020E610000018778368ADAC454011001C7BF6764B40
62378	7	68	\N	49771	17325	\N	54.955396	Нижегородская область, город Саров, Казамазова ул, 5		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62392	7	68	\N	629	\N	\N	54.955396	Нижегородская область, город Саров, Силкина ул, 10/1	Россия, Нижегородская область, Саров	0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62384	7	68	\N	629	\N	\N	54.955396	Нижегородская область, город Саров, Куйбышева ул, 19/1	Россия, Нижегородская область, Саров	0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62375	7	68	\N	629	\N	\N	54.955396	Нижегородская область, город Саров, Зернова ул, 61	Россия, Нижегородская область, Саров	0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62374	7	68	\N	629	\N	\N	54.955396	Нижегородская область, город Саров, Димитрова ул, 3	Россия, Нижегородская область, Саров	0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62372	7	68	\N	629	\N	\N	54.955396	Нижегородская область, город Саров, Зернова ул, 2а	Россия, Нижегородская область, Саров	0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62377	7	68	\N	629	17715	\N	54.931185297686497	Нижегородская область, город Саров, Музрукова пр, 39	Россия, Нижегородская область, Саров городской округ	0101000020E6100000315BB22AC2A945404CC3F01131774B40
61954	7	68	\N	629	18573	\N	54.955396	Нижегородская область, город Саров, Юности ул, 11		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
61580	7	68	\N	629	17684	\N	54.955396	Нижегородская область, город Саров, Юности ул, 14		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62390	7	68	\N	629	17777	\N	54.944006414800597	Нижегородская область, город Саров, Шверника ул, 19		0101000020E610000064963D096CA84540289D4830D5784B40
62391	7	68	\N	629	17718	\N	54.955396	Нижегородская область, город Саров, Шверника ул, 40		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62387	7	68	\N	629	16843	\N	54.955396	Нижегородская область, город Саров, Чапаева ул, 16		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62373	7	68	\N	629	17274	\N	54.955396	Нижегородская область, город Саров, Павлика Морозова ул, 11	Россия, Нижегородская область, Саров	0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
61315	7	68	\N	629	17748	\N	54.947027685148399	Нижегородская область, город Саров, Московская ул, 5		0101000020E6100000CF13CFD902AA4540BA32A83638794B40
62330	7	68	\N	629	17643	\N	54.950301869472497	Нижегородская область, город Саров, Московская ул, 40а	Россия, Нижегородская область, Саров	0101000020E610000082AD122C0EA9454065A9F57EA3794B40
62111	7	68	\N	629	16811	\N	54.955396	Нижегородская область, город Саров, Курчатова ул, 29		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62388	7	68	\N	629	17081	\N	54.955396	Нижегородская область, город Саров, Куйбышева ул, 1		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62383	7	68	\N	629	17081	\N	54.9214536500766	Нижегородская область, город Саров, Куйбышева ул, 25		0101000020E610000060AE450BD0AC45405A626534F2754B40
62376	7	68	\N	629	17624	\N	54.955396	Нижегородская область, город Саров, Зернова ул, 64		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
61643	7	68	\N	629	17624	\N	54.9387465453283	Нижегородская область, город Саров, Зернова ул, 58	Россия, Нижегородская область, Саров городской округ	0101000020E61000005D35CF11F9A84540EB1B98DC28784B40
62201	7	68	\N	629	17134	\N	54.948054061377597	Нижегородская область, город Саров, Гоголя ул, 10	Россия, Нижегородская область, Саров городской округ	0101000020E61000005053CBD6FAA84540C66B5ED559794B40
62151	7	68	\N	629	19408	\N	54.948665428277302	Нижегородская область, город Саров, Гоголя ул, 12	Россия, Нижегородская область, Саров городской округ	0101000020E61000000B0E2F8848A945400FEECEDA6D794B40
61356	7	68	\N	629	17937	\N	54.955396	Нижегородская область, город Саров, Герцена ул, 5		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62389	7	68	\N	629	18417	\N	54.955396	Нижегородская область, город Саров, Гагарина ул, 22		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62386	7	68	\N	629	16710	\N	54.955396	Нижегородская область, город Саров, Гагарина ул, 6	Россия, Нижегородская область, Саров	0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62382	7	68	\N	629	17732	\N	54.955396	Нижегородская область, город Саров, Александровича ул, 16а		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62379	7	68	\N	629	17141	\N	54.937609978379903	Нижегородская область, город Саров, Академика Харитона ул, 17	Россия, Нижегородская область, Саров городской округ	0101000020E6100000912C6002B7A845408733BF9A03784B40
62381	7	68	\N	629	17770	\N	54.955396	Нижегородская область, город Саров, Академика Сахарова ул, 2		0101000020E61000000839EFFFE3A84540575D876A4A7A4B40
62216	7	68	\N	12248	\N	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Коммунистическая, д. 55	Россия, Нижегородская область, Павлово	0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62215	7	68	\N	12248	\N	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Коммунистическая, д. 3	Россия, Нижегородская область, Павлово	0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62213	7	68	\N	12248	\N	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Садовая, д. 1	Россия, Нижегородская область, Павлово	0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62209	7	68	\N	12248	17347	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Чкалова, д. 59		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62202	7	68	\N	12248	17719	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Трудовая, 73б		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62205	7	68	\N	12248	17723	\N	55.9753759423742	Нижегородская область, Павловский район, г. Павлово, ул. Суворова, д. 4	Россия, Нижегородская область, Павлово	0101000020E6100000925ED4EE578B4540D2A6EA1ED9FC4B40
62259	7	68	\N	12248	17356	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Пионерская, д. 40		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62222	7	68	\N	12248	17153	\N	55.953724368819103	Нижегородская область, Павловский район, г. Павлово, ул. Маяковского, д. 90а	Россия, Нижегородская область, Павлово	0101000020E6100000D9243FE25786454085B4C6A013FA4B40
62214	7	68	\N	12248	17153	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Маяковского, д. 4		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62207	7	68	\N	12248	17669	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. М. Горького, д. 23	Россия, Нижегородская область, Павлово	0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62223	7	68	\N	12248	9709	\N	55.969720507296501	Нижегородская область, Павловский район, г. Павлово, ул. Куйбышева, д. 45	Россия, Нижегородская область, Павлово	0101000020E610000044F81741638A4540499F56D11FFC4B40
62219	7	68	\N	12248	17733	\N	55.945025412701597	Нижегородская область, Павловский район, г. Павлово, ул. Высокая, д. 1	Россия, Нижегородская область, Павлово	0101000020E61000004A7D59DAA98B454082734694F6F84B40
62210	7	68	\N	12248	17736	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Аллея Ильича, д. 53		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62203	7	68	\N	12248	17139	\N	55.990764748933103	Нижегородская область, Павловский район, г. Павлово, ул. 9-я Северная, д.40, МУ СОК «Гармония»	Россия, Нижегородская область, Павлово	0101000020E6100000AFB0E07EC08D4540BF823463D1FE4B40
62143	7	68	\N	42	\N	\N	56.282055999999997	Нижегородская область, город Нижний Новгород, Советский район, Лицей № 28, проспект Гагарина, 8	Россия, Нижегородская область, Нижний Новгород, Советский район	0101000020E61000003B3602F1BA024640FED137691A244C40
62114	7	68	\N	42	\N	\N	56.244950000000003	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 48, пос.Черепичный, д.9	Россия, Нижегородская область, Нижний Новгород, поселок Черепичный, 9	0101000020E6100000912BF52C08014640DE9387855A1F4C40
62098	7	68	\N	42	\N	\N	56.179386227096003	Нижегородская область, город Нижний Новгород, Нижегородский район, санаторий им.ВЦСПС	Россия, Нижегородская область, Нижний Новгород, Нижегородский район	0101000020E61000000C772E8CF40246401DAED51EF6164C40
61877	7	68	\N	42	\N	\N	56.205504539399897	Нижегородская область, город Нижний Новгород, Автозаводский район, поселок Мостоотряд, 17б		0101000020E6100000BB9A3C6535E745400E15E3FC4D1A4C40
61897	7	68	\N	42	16800	\N	56.223129482680399	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Южное шоссе, 24г	Россия, Нижегородская область, Нижний Новгород, шоссе Южное, 24г	0101000020E6100000151C5E1091EE454004E5B67D8F1C4C40
61896	7	68	\N	42	16800	\N	56.220296170335899	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Южное шоссе, 6а	Россия, Нижегородская область, Нижний Новгород, шоссе Южное, 6а	0101000020E61000006A6D1ADB6BED454045B8C9A8321C4C40
61900	7	68	\N	42	16676	\N	56.230674429680498	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Южное шоссе, 49а	Россия, Нижегородская область, Нижний Новгород, шоссе Южное, 49а	0101000020E610000059DFC0E446EF4540CD04C3B9861D4C40
61898	7	68	\N	42	16676	\N	56.225959000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Южное шоссе, 33	Россия, Нижегородская область, Нижний Новгород, шоссе Южное, 33	0101000020E6100000A59F70766BEF4540529E7939EC1C4C40
62123	7	68	\N	42	17962	\N	56.236286553640603	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 45, ул.Тропинина, д.1	Россия, Нижегородская область, Нижний Новгород, улица Тропинина, 1	0101000020E6100000766C04E275F9454027BC04A73E1E4C40
62195	7	68	\N	42	3630	\N	56.368254999999998	Нижегородская область, город Нижний Новгород, Сормовский район, Стрелковая, 81	Россия, Нижегородская область, Нижний Новгород, улица Стрелковая, 81	0101000020E6100000E7340BB43BE8454053CBD6FA222F4C40
62178	7	68	\N	42	3405	\N	56.347549000000001	Нижегородская область, город Нижний Новгород, Сормовский район, Павла Мочалова, 9	Россия, Нижегородская область, Нижний Новгород, улица Павла Мочалова, 9	0101000020E61000006C4084B872EE4540F660527C7C2C4C40
62167	7	68	\N	42	3263	\N	56.386319	Нижегородская область, город Нижний Новгород, Сормовский район, Меднолитейная, 1а	Россия, Нижегородская область, Нижний Новгород, улица Меднолитейная, 1а	0101000020E61000006A2E3718EAE045406669A7E672314C40
62144	7	68	\N	42	17309	\N	56.3052880498809	Нижегородская область, город Нижний Новгород, Советский район, Гимназия им. А.С. Пушкина, Кулибина, 6	Россия, Нижегородская область, Нижний Новгород, улица Кулибина, 6	0101000020E6100000899AE8F351FE45403DEE5BAD13274C40
62049	7	68	\N	42	1553	\N	56.328448999999999	Нижегородская область, город Нижний Новгород, Московский район, ул. Куйбышева, д.29	Россия, Нижегородская область, Нижний Новгород, улица Куйбышева, 29	0101000020E61000001024EF1CCAF44540B3B3E89D0A2A4C40
61911	7	68	\N	42	7851	\N	56.244810000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Краснодонцев, 1а	Россия, Нижегородская область, Нижний Новгород, улица Краснодонцев, 1а	0101000020E610000058E1968FA4EC4540ECDD1FEF551F4C40
61876	7	68	\N	42	7456	\N	56.200327999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Земляничная, 1а	Россия, Нижегородская область, Нижний Новгород, улица Земляничная, 1а	0101000020E6100000CF488446B0E545408E3C1059A4194C40
62113	7	68	\N	42	17452	\N	56.2494834196591	Нижегородская область, город Нижний Новгород, Приокский район, Профессиональный лицей № 21, ул.Шапошникова, д.10	Россия, Нижегородская область, Нижний Новгород, улица Героя Советского Союза Шапошникова	0101000020E61000008E3D7B2E53FD454038F4160FEF1F4C40
61904	7	68	\N	42	7169	\N	56.236781000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Героя Смирнова, 39а	Россия, Нижегородская область, Нижний Новгород, улица Героя Советского Союза Смирнова, 39а	0101000020E61000002E73BA2C26EE454037A8FDD64E1E4C40
62148	7	68	\N	42	16795	\N	56.316585473164103	Нижегородская область, город Нижний Новгород, Советский район, Школа № 186, Генкиной, 84	Россия, Нижегородская область, Нижний Новгород, улица Генкиной, 84	0101000020E610000083FC6CE4BA034640BCB376DB85284C40
62156	7	68	\N	42	17498	\N	56.292342728144298	Нижегородская область, город Нижний Новгород, Советский район, Школа № 54, Ванеева, 104	Россия, Нижегородская область, Нижний Новгород, улица Ванеева, 104к3	0101000020E61000008C852172FA044640761BD47E6B254C40
62106	7	68	\N	42	17601	\N	56.269695144244402	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 48, ул.Бонч-Бруевича, д.11а	Россия, Нижегородская область, Нижний Новгород, улица Бонч-Бруевича, 11а	0101000020E610000031EE06D15AFD45408672A25D85224C40
62132	7	68	\N	42	17219	\N	56.292262275073902	Нижегородская область, город Нижний Новгород, Советский район, Профессиональный лицей №41, Бекетова, 8б	Россия, Нижегородская область, Нижний Новгород, улица Бекетова, 8б	0101000020E610000003250516C0FE454089EE59D768254C40
62131	7	68	\N	42	17219	\N	56.289935308519702	Нижегородская область, город Нижний Новгород, Советский район, Школа № 53, Бекетова, 19а	Россия, Нижегородская область, Нижний Новгород, улица Бекетова, 19а	0101000020E6100000BC900E0F610046409E7B0F971C254C40
62130	7	68	\N	42	17219	\N	56.291415037051998	Нижегородская область, город Нижний Новгород, Советский район, Школа № 173, Бекетова, 29а	Россия, Нижегородская область, Нижний Новгород, улица Бекетова, 29а	0101000020E6100000BCCE86FC330146402C4833164D254C40
62120	7	68	\N	42	19428	\N	56.233926662131402	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 32, ул.Лебедева, д.3	Россия, Нижегородская область, Нижний Новгород, улица Академика Лебедева, 3	0101000020E610000051888043A8FA45406153E751F11D4C40
62121	7	68	\N	42	16688	\N	56.233944999999999	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 32. ул.Лебедева, д.3	Россия, Нижегородская область, Нижний Новгород, улица Академика Лебедева, 3	0101000020E61000008907944DB9FA45400708E6E8F11D4C40
61918	7	68	\N	42	7896	\N	56.253512000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, пр. Октября, 22а	Россия, Нижегородская область, Нижний Новгород, проспект Октября, 22а	0101000020E6100000C70E2A711DEF45406092CA1473204C40
61917	7	68	\N	42	7896	\N	56.254817000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, пр. Октября, 23	Россия, Нижегородская область, Нижний Новгород, проспект Октября, 23	0101000020E61000002C0FD253E4EE454080BBECD79D204C40
61916	7	68	\N	42	7896	\N	56.250047000000002	Нижегородская область, город Нижний Новгород, Автозаводский район, пр. Октября, 14	Россия, Нижегородская область, Нижний Новгород, проспект Октября, 14	0101000020E61000008881AE7D01EF454041BB438A01204C40
61912	7	68	\N	42	7645	\N	56.243609999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, пр. Молодежный, 30а	Россия, Нижегородская область, Нижний Новгород, проспект Молодежный, 30а	0101000020E61000007DCD72D9E8EC4540417DCB9C2E1F4C40
61892	7	68	\N	42	7645	\N	56.244414999999996	Нижегородская область, город Нижний Новгород, Автозаводский район, пр-т Молодежный, 44б	Россия, Нижегородская область, Нижний Новгород, проспект Молодежный, 44б	0101000020E6100000E2CB441152EB45406FD39FFD481F4C40
62008	7	68	\N	42	478	\N	56.294615999999998	Нижегородская область, город Нижний Новгород, Ленинский район, пр. Ленина, 14а, школа № 62		0101000020E610000009C1AA7AF9F745406D7022FAB5254C40
62006	7	68	\N	42	478	\N	56.289720000000003	Нижегородская область, город Нижний Новгород, Ленинский район, пр. Ленина, 27, НКИ		0101000020E6100000070B2769FEF64540A27F828B15254C40
61993	7	68	\N	42	478	\N	56.282147699566103	Нижегородская область, город Нижний Новгород, Ленинский район, пр. Ленина, 45 (корпус 5), школа №180	Россия, Нижегородская область, Нижний Новгород, проспект Ленина, 45к5	0101000020E610000045F46BEBA7F54540DF50F86C1D244C40
61992	7	68	\N	42	478	\N	56.2823386745699	Нижегородская область, город Нижний Новгород, Ленинский район, пр.Ленина, 45 (корпус 5), школа №180	Россия, Нижегородская область, Нижний Новгород, проспект Ленина, 45к5	0101000020E61000003AAE4676A5F5454053B131AF23244C40
61984	7	68	\N	42	478	\N	56.278303543741103	Нижегородская область, город Нижний Новгород, Ленинский район, пр.Ленина, 55 (корпус 3), школа №60	Россия, Нижегородская область, Нижний Новгород, проспект Ленина, 55к3	0101000020E6100000B22AC24D46F54540492C29779F234C40
61982	7	68	\N	42	478	\N	56.274566486551599	Нижегородская область, город Нижний Новгород, Ленинский район, пр. Ленина, 61 (корпус 6), школа №184	Россия, Нижегородская область, Нижний Новгород, проспект Ленина, 61к6	0101000020E6100000543A58FFE7F44540F94B8BFA24234C40
61975	7	68	\N	42	478	\N	56.266032000000003	Нижегородская область, город Нижний Новгород, Ленинский район, пр. Ленина, 70а, школа №72		0101000020E61000007AABAE4335F5454041D829560D224C40
62198	7	68	\N	42	3665	\N	56.360655999999999	Нижегородская область, город Нижний Новгород, Сормовский район, проспект Кораблестроителей, 25а	Россия, Нижегородская область, Нижний Новгород, проспект Кораблестроителей, 25а	0101000020E61000008CBCAC8905E84540978DCEF9292E4C40
61913	7	68	\N	42	7863	\N	56.249105999999998	Нижегородская область, город Нижний Новгород, Автозаводский район, пр. Кирова, 29а	Россия, Нижегородская область, Нижний Новгород, проспект Кирова, 29а	0101000020E6100000FCFECD8B13ED4540629E95B4E21F4C40
62040	7	68	\N	42	17191	\N	56.317491309233603	Нижегородская область, город Нижний Новгород, Московский район, школа № 64, проспект Героев, д.20	Россия, Нижегородская область, Нижний Новгород, проспект Героев, 20	0101000020E6100000401878EE3DF245401DE38A8BA3284C40
62038	7	68	\N	42	1454	\N	56.317557000000001	Нижегородская область, город Нижний Новгород, Московский район, проспект Героев, д.20	Россия, Нижегородская область, Нижний Новгород, проспект Героев, 20	0101000020E61000007138F3AB39F24540D5CE30B5A5284C40
62119	7	68	\N	42	19572	\N	56.242438345103402	Нижегородская область, город Нижний Новгород, Приокский район, НГСХА, пр.Гагарина, д.97	Россия, Нижегородская область, Нижний Новгород, проспект Гагарина, 97	0101000020E610000005DF347D76FA454061A75835081F4C40
62109	7	68	\N	42	16810	\N	56.259946858548503	"Нижегородская область, город Нижний Новгород, Приокский район, МОУ ""Межшкольный учебный комбинат"" Приокского р, пр.Гагарина, д.154"	Россия, Нижегородская область, Нижний Новгород, проспект Гагарина, 154	0101000020E6100000F14BFDBCA9FC4540BED87BF145214C40
62141	7	68	\N	42	16788	\N	56.3038890097394	Нижегородская область, город Нижний Новгород, Советский район, Нижегородский строительный техникум, проспект Гагарина, 12	Россия, Нижегородская область, Нижний Новгород, проспект Гагарина, 12	0101000020E610000057E9EE3A1BFE45409C4EB2D5E5264C40
62140	7	68	\N	42	16788	\N	56.2994427550422	Нижегородская область, город Нижний Новгород, Советский район, Нижегородский государственный университет, проспект Гагарина, 23 корпус 2	Россия, Нижегородская область, Нижний Новгород, проспект Гагарина, 23к2	0101000020E61000009E62D520CCFD45401002F22554264C40
33279	4	41	\N	16582	46230	\N	48.779257999999999	г. Биробиджан, Осенняя, 23 А		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
62139	7	68	\N	42	16788	\N	56.298180482301902	Нижегородская область, город Нижний Новгород, Советский район, Нижегородский государственный университет, проспект Гагарина, 23 общежитие №4	Россия, Нижегородская область, Нижний Новгород, проспект Гагарина, 23	0101000020E610000002124DA088FD4540202922C32A264C40
62137	7	68	\N	42	16788	\N	56.292963973010004	Нижегородская область, город Нижний Новгород, Советский район, Школа № 47, проспект Гагарина, 44	Россия, Нижегородская область, Нижний Новгород, проспект Гагарина, 44	0101000020E6100000D8666325E6FD4540E27327D87F254C40
62136	7	68	\N	42	16788	\N	56.2921131148181	Нижегородская область, город Нижний Новгород, Советский район, Волго-Вятская академия гос.службы, проспект Гагарина, 46	Россия, Нижегородская область, Нижний Новгород, проспект Гагарина, 46	0101000020E6100000DD06B5DFDAFD454044DE72F563254C40
62112	7	68	\N	42	19802	\N	56.251372000000003	Нижегородская область, город Нижний Новгород, Приокский район, Клуб им.Кринова, пр.Гагарина, д.41		0101000020E610000088F37002D3FB4540A8902BF52C204C40
62100	7	68	\N	42	2297	\N	56.281480999999999	Нижегородская область, город Нижний Новгород, Приокский район, Общежитие НГМА, пр.Гагарина, д.68		0101000020E61000005CCB64389EFD454002B9C49107244C40
61935	7	68	\N	42	8023	\N	56.268310999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, пр. Бусыгина, 39	Россия, Нижегородская область, Нижний Новгород, проспект Бусыгина, 39	0101000020E61000001E882CD2C4F145401A14CD0358224C40
61930	7	68	\N	42	8023	\N	56.264622000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, пр. Бусыгина, 18а	Россия, Нижегородская область, Нижний Новгород, проспект Бусыгина, 18а	0101000020E6100000C405A051BAF24540ACE63922DF214C40
61878	7	68	\N	42	16826	\N	56.200415228435197	Нижегородская область, город Нижний Новгород, Автозаводский район, поселок Мостоотряд, 30	Россия, Нижегородская область, Нижний Новгород, улица Мостотряда, 30	0101000020E61000009D9D0C8E92E745405D50DF32A7194C40
62087	7	68	\N	42	2098	\N	56.318196	Нижегородская область, город Нижний Новгород, Нижегородский район, площадь Свободы, 3	Россия, Нижегородская область, Нижний Новгород, площадь Свободы, 3	0101000020E61000000FB9196EC0014640E8DB82A5BA284C40
62086	7	68	\N	42	2098	\N	56.318930000000002	Нижегородская область, город Нижний Новгород, Нижегородский район, площадь Свободы, 1	Россия, Нижегородская область, Нижний Новгород, площадь Свободы, 1	0101000020E610000087DC0C37E00146404DDBBFB2D2284C40
62506	7	68	\N	42	19562	\N	56.3216265051053	Нижегородская область, город Нижний Новгород, Канавинский район, пл. Революции, 2, Здание Московского вокзала	Россия, Нижегородская область, Нижний Новгород, площадь Революции, 2	0101000020E61000008736001B10F945405B41D3122B294C40
62081	7	68	\N	42	1992	\N	56.318739999999998	Нижегородская область, город Нижний Новгород, Нижегородский район, переулок Холодный, дом 15а	Россия, Нижегородская область, Нижний Новгород, переулок Холодный, 15а	0101000020E61000001D59F96530004640A9F6E978CC284C40
62078	7	68	\N	42	1992	\N	56.318739999999998	Нижегородская область, город Нижний Новгород, Нижегородский район, переулок Холодный, 15а	Россия, Нижегородская область, Нижний Новгород, переулок Холодный, 15а	0101000020E61000001D59F96530004640A9F6E978CC284C40
62071	7	68	\N	42	1907	\N	56.324154781111801	Нижегородская область, город Нижний Новгород, Нижегородский район, переулок Урожайный, 4	Россия, Нижегородская область, Нижний Новгород, переулок Урожайный, 4	0101000020E6100000779D0DF967FE4540DDEA39E97D294C40
62169	7	68	\N	42	3299	\N	56.379531	Нижегородская область, город Нижний Новгород, Сормовский район, пер.Общественный, 2	Россия, Нижегородская область, Нижний Новгород, переулок Общественный, 2	0101000020E6100000AA49F08634EA4540BA68C87894304C40
62117	7	68	\N	42	17269	\N	56.240468289538398	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 174, микрорайон Щербинки-I, д.30	Россия, Нижегородская область, Нижний Новгород, Приокский район, микрорайон Щербинки-1, 30	0101000020E61000000F441669E2FB454005DEC9A7C71E4C40
62118	7	68	\N	42	17476	\N	56.240545958147401	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 174. микрорайон Щербинки-I, д.30	Россия, Нижегородская область, Нижний Новгород, Приокский район, микрорайон Щербинки-1, 30	0101000020E6100000F10D85CFD6FB454081971936CA1E4C40
61963	7	68	\N	42	302	\N	56.326312999999999	Нижегородская область, город Нижний Новгород, Канавинский район, бульвар Мира, 4, школа №143		0101000020E6100000A27BD6355AFA45403CA1D79FC4294C40
62003	7	68	\N	42	888	\N	56.284789000000004	Нижегородская область, город Нижний Новгород, Ленинский район, бульвар Заречный, 16, школа № 106		0101000020E61000004F029B73F0F845405AA148F773244C40
62159	7	68	\N	42	17023	\N	56.285421837179797	Нижегородская область, город Нижний Новгород, Советский район, Школа № 187, бульвар 60 лет Октября, 5а	Россия, Нижегородская область, Нижний Новгород, бульвар 60-летия Октября, 5а	0101000020E61000001059A489770646408AC745B588244C40
62158	7	68	\N	42	17023	\N	56.2866594145421	Нижегородская область, город Нижний Новгород, Советский район, Школа № 187, бульвар 60 лет Октября, 5	Россия, Нижегородская область, Нижний Новгород, бульвар 60-летия Октября, 5	0101000020E6100000FF04172B6A064640520DFB3DB1244C40
33278	4	41	\N	16582	46230	\N	48.779257999999999	г. Биробиджан, Осенняя, 13		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
61944	7	68	\N	42	19625	\N	56.312620000000003	Нижегородская область, город Нижний Новгород, Канавинский район, Якорная, 121, школа №109		0101000020E6100000998235CEA6F14540AB09A2EE03284C40
62091	7	68	\N	42	19667	\N	56.311141999999997	Нижегородская область, город Нижний Новгород, Нижегородский район, Яблоневая, 6		0101000020E6100000433866D993064640BD344580D3274C40
61907	7	68	\N	42	19579	\N	56.242029000000002	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Юлиуса Фучика, 2		0101000020E610000051F52B9D0FEF454080D767CEFA1E4C40
61906	7	68	\N	42	19579	\N	56.234625000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Юлиуса Фучика, 12а		0101000020E61000006EBF7CB262F0454079E92631081E4C40
62180	7	68	\N	42	19645	\N	56.343103999999997	Нижегородская область, город Нижний Новгород, Сормовский район, Энгельса, 3		0101000020E610000060915F3FC4EE45403A90F5D4EA2B4C40
62179	7	68	\N	42	19645	\N	56.344546000000001	Нижегородская область, город Нижний Новгород, Сормовский район, Энгельса, 27		0101000020E6100000E6E61BD13DEF4540DBFB54151A2C4C40
61958	7	68	\N	42	19744	\N	56.302706999999998	Нижегородская область, город Нижний Новгород, Канавинский район, Электровозная, 15, школа №167 (второе здание)		0101000020E6100000D940BAD8B4F0454098A25C1ABF264C40
61921	7	68	\N	42	19604	\N	56.256163000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Школьная, 28		0101000020E6100000FE7BF0DAA5ED4540FEB8FDF2C9204C40
61910	7	68	\N	42	19604	\N	56.247660273290997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Школьная, 10	Россия, Нижегородская область, Нижний Новгород, улица Школьная, 10	0101000020E6100000705E9CF86AED45408143A852B31F4C40
62047	7	68	\N	42	19566	\N	56.327815000000001	Нижегородская область, город Нижний Новгород, Московский район, ул. Шаляпина, 25		0101000020E61000004966F50EB7F54540B21188D7F5294C40
62044	7	68	\N	42	19566	\N	56.327291000000002	Нижегородская область, город Нижний Новгород, Московский район, ул. Шаляпина, д.23		0101000020E6100000BD6F7CED99F5454038A3E6ABE4294C40
62043	7	68	\N	42	19566	\N	56.327291000000002	Нижегородская область, город Нижний Новгород, Московский район, ул. Шаляпина, д. 23		0101000020E6100000BD6F7CED99F5454038A3E6ABE4294C40
61969	7	68	\N	42	19777	\N	56.31897	Нижегородская область, город Нижний Новгород, Канавинский район, Чкалова, 5а, Техникум железнодор-го транс-та		0101000020E61000008461C092ABF84540DB334B02D4284C40
61968	7	68	\N	42	19777	\N	56.314152	Нижегородская область, город Нижний Новгород, Канавинский район, Чкалова, 26, школа №52		0101000020E61000001EDE736039F845408BFCFA2136284C40
62024	7	68	\N	42	19731	\N	56.333190000000002	Нижегородская область, город Нижний Новгород, Московский район, ул. Черняховского, д.8а		0101000020E6100000239F573CF5EC454058AD4CF8A52A4C40
62023	7	68	\N	42	19731	\N	56.333190000000002	Нижегородская область, город Нижний Новгород, Московский район, ул. Черняховского, д. 8а		0101000020E6100000239F573CF5EC454058AD4CF8A52A4C40
61919	7	68	\N	42	19662	\N	56.254331999999998	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Челюскинцев, 24		0101000020E610000078D2C26515EE4540C32973F38D204C40
61914	7	68	\N	42	19662	\N	56.251846641621803	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Челюскинцев, 17	Россия, Нижегородская область, Нижний Новгород, улица Челюскинцев, 17	0101000020E61000005303CDE7DCED4540404CC2853C204C40
61909	7	68	\N	42	19662	\N	56.247756000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Челюскинцев, 9		0101000020E6100000726E13EE95ED4540A3B1F677B61F4C40
62171	7	68	\N	42	19697	\N	56.360456999999997	Нижегородская область, город Нижний Новгород, Сормовский район, Чайковского, 12		0101000020E61000002C465D6BEFED4540A04E7974232E4C40
62026	7	68	\N	42	19733	\N	56.327945	Нижегородская область, город Нижний Новгород, Московский район, ул. Чаадаева, д.12а		0101000020E6100000FCA886FD9EEC454080F10C1AFA294C40
62022	7	68	\N	42	19733	\N	56.327714999999998	Нижегородская область, город Нижний Новгород, Московский район, ул. Чаадаева, д.2а		0101000020E6100000607825C973ED45404EB4AB90F2294C40
62025	7	68	\N	42	19760	\N	56.3307	Нижегородская область, город Нижний Новгород, Московский район, ул. Чаадаева, д.30а		0101000020E610000046EF54C03DEB4540C364AA60542A4C40
62061	7	68	\N	42	19599	\N	56.317348024311201	Нижегородская область, город Нижний Новгород, Нижегородский район, Фруктовая, 8	Россия, Нижегородская область, Нижний Новгород, улица Фруктовая, 4	0101000020E6100000B43BA41820074640BBB9F8DB9E284C40
62187	7	68	\N	42	19524	\N	56.340364999999998	Нижегородская область, город Нижний Новгород, Сормовский район, ул. Федосеенко, 25, школа № 81		0101000020E61000008D08C6C1A5E94540FDD98F14912B4C40
62186	7	68	\N	42	19524	\N	56.3387868052397	Нижегородская область, город Нижний Новгород, Сормовский район, Федосеенко, 37	Россия, Нижегородская область, Нижний Новгород, Сормовский район	0101000020E6100000639813B4C9E74540ADA7565F5D2B4C40
62185	7	68	\N	42	19524	\N	56.340364999999998	Нижегородская область, город Нижний Новгород, Сормовский район, Федосеенко, 25	Россия, Нижегородская область, Нижний Новгород, улица Федосеенко, 25	0101000020E61000008D08C6C1A5E94540FDD98F14912B4C40
61949	7	68	\N	42	19703	\N	56.292547999999996	Нижегородская область, город Нижний Новгород, Канавинский район, Ухтомского, 90, школа №167	Россия, Нижегородская область, Нижний Новгород, улица Ухтомского, 90	0101000020E610000029965B5A0DED45404E417E3672254C40
62079	7	68	\N	42	19804	\N	56.326287999999998	Нижегородская область, город Нижний Новгород, Нижегородский район, Ульянова, 1		0101000020E6100000D39FFD4811014640E38920CEC3294C40
62107	7	68	\N	42	16749	\N	56.265099882545002	"Нижегородская область, город Нижний Новгород, Приокский район, МОУ ""Вечерняя общеобразовательная школа №18"", ул.Углова, д.1в"		0101000020E61000004F1E166A4DFD4540B515FBCBEE214C40
62013	7	68	\N	42	19616	\N	56.302827000000001	Нижегородская область, город Нижний Новгород, Ленинский район, Тургайская, 5, школа № 101		0101000020E61000005AB741EDB7F8454043ACFE08C3264C40
61955	7	68	\N	42	19636	\N	56.324460999999999	Нижегородская область, город Нижний Новгород, Канавинский район, Тонкинская, 4, школа №121		0101000020E61000009561DC0DA2F74540EAE923F087294C40
61956	7	68	\N	42	19686	\N	56.323368000000002	"Нижегородская область, город Нижний Новгород, Канавинский район, Тонкинская, 2, МОУ ""Центр образования"""		0101000020E61000000CCB9F6F0BF845405649641F64294C40
62105	7	68	\N	42	17284	\N	56.2758885232995	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 11, ул.Терешковой, 4а	Россия, Нижегородская область, Нижний Новгород, улица Сурикова, 4а	0101000020E6100000774EB340BBFD4540BF29AC5450234C40
62104	7	68	\N	42	17284	\N	56.2758897543711	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 11, ул.Терешковой, д.4а	Россия, Нижегородская область, Нижний Новгород, улица Сурикова, 4а	0101000020E61000000CCC0A45BAFD45408FA50F5D50234C40
61959	7	68	\N	42	19556	\N	56.309979379518303	Нижегородская область, город Нижний Новгород, Канавинский район, Тепличная, 6а, детский сад №118	Россия, Нижегородская область, Нижний Новгород, улица Тепличная, 7а	0101000020E6100000FDBB3E73D6E7454030B95164AD274C40
62005	7	68	\N	42	19728	\N	56.284593999999998	Нижегородская область, город Нижний Новгород, Ленинский район, Сухопутная, 2, школа-интернат № 6		0101000020E61000008E3D7B2E53F74540A45181936D244C40
61926	7	68	\N	42	19690	\N	56.261457999999998	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Строкина, 2		0101000020E61000003D821B295BEE454087A3AB7477214C40
61925	7	68	\N	42	19690	\N	56.264311999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Строкина, 7		0101000020E6100000FA27B85851ED45405DF8C1F9D4214C40
61924	7	68	\N	42	19690	\N	56.261642999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Строкина, 12а		0101000020E61000004FE61F7D93EC4540191D90847D214C40
61895	7	68	\N	42	19626	\N	56.227874999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Старых производственников, 18		0101000020E61000009E95B4E21BEE4540BA490C022B1D4C40
61894	7	68	\N	42	19680	\N	56.229270999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Старых производственников, 13а		0101000020E6100000CF30B5A50EEE4540EA758BC0581D4C40
62188	7	68	\N	42	19785	\N	56.353684000000001	Нижегородская область, город Нижний Новгород, Сормовский район, Станиславского, 16		0101000020E6100000768A558330EB45402A8F6E84452D4C40
61890	7	68	\N	42	19620	\N	56.239713000000002	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Спутника, 24а		0101000020E6100000759483D904EA454089B663EAAE1E4C40
61889	7	68	\N	42	19654	\N	56.239497999999998	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Спутника, 2а		0101000020E6100000CB2BD7DB66EA45408CBAD6DEA71E4C40
62036	7	68	\N	42	19708	\N	56.332501000000001	Нижегородская область, город Нижний Новгород, Московский район, ул. Софьи Перовской, д.2		0101000020E6100000AA0F24EF1CF0454093718C648F2A4C40
62059	7	68	\N	42	19711	\N	56.332501000000001	Нижегородская область, город Нижний Новгород, Московский район, ул. Софьи Перовской, д. 2		0101000020E6100000AA0F24EF1CF0454093718C648F2A4C40
62055	7	68	\N	42	19711	\N	56.334792	Нижегородская область, город Нижний Новгород, Московский район, ул. Софьи Перовской, д. 5		0101000020E6100000978C63247BF04540317BD976DA2A4C40
62054	7	68	\N	42	19711	\N	56.334792	Нижегородская область, город Нижний Новгород, Московский район, ул. Софьи Перовской, д.5		0101000020E6100000978C63247BF04540317BD976DA2A4C40
61923	7	68	\N	42	19795	\N	56.257213	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Советской Армии, 15		0101000020E6100000E0BDA3C684EC4540938D075BEC204C40
61991	7	68	\N	42	19725	\N	56.290689	Нижегородская область, город Нижний Новгород, Ленинский район, Снежная, 2, школа №100		0101000020E61000004679E6E5B0F545404A27124C35254C40
61983	7	68	\N	42	19725	\N	56.275204000000002	Нижегородская область, город Нижний Новгород, Ленинский район, Снежная, 33, школа №107		0101000020E61000000BED9C6681F445403CDD79E239234C40
62074	7	68	\N	42	19740	\N	56.314022999999999	Нижегородская область, город Нижний Новгород, Нижегородский район, Славянская, 35		0101000020E6100000444FCAA4860046408D98D9E731284C40
62076	7	68	\N	42	19771	\N	56.314022999999999	Нижегородская область, город Нижний Новгород, Нижегородский район, Славянская, дом 35		0101000020E6100000444FCAA4860046408D98D9E731284C40
61974	7	68	\N	42	19607	\N	56.336798000000002	Нижегородская область, город Нижний Новгород, Канавинский район, Сергея Есенина, 37, школа №55		0101000020E610000049F25CDF87F74540DAAD65321C2B4C40
61960	7	68	\N	42	19607	\N	56.335380999999998	Нижегородская область, город Нижний Новгород, Канавинский район, Сергея Есенина, 11, школа №41		0101000020E6100000F660527C7CF845409259BDC3ED2A4C40
61973	7	68	\N	42	19671	\N	56.351862481646798	"Нижегородская область, город Нижний Новгород, Канавинский район, Сергея Акимова, 49, Подростковый клуб ""Планета"""		0101000020E610000067800BB265F74540425A63D0092D4C40
61972	7	68	\N	42	19671	\N	56.342480999999999	Нижегородская область, город Нижний Новгород, Канавинский район, Сергея Акимова, 35, школа №110		0101000020E610000082C5E1CCAFF645402D40DB6AD62B4C40
62176	7	68	\N	42	18198	\N	56.370350442688	Нижегородская область, город Нижний Новгород, Сормовский район, Свирская, 20	Россия, Нижегородская область, Нижний Новгород, Сормовский район	0101000020E6100000CE37A27BD6E545406C09F9A0672F4C40
61888	7	68	\N	42	19794	\N	56.237831999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Сазанова, 10а		0101000020E610000071033E3F8CEA45409CF86A47711E4C40
61971	7	68	\N	42	19684	\N	56.299230999999999	Нижегородская область, город Нижний Новгород, Канавинский район, Рубо, 5а, Профессиональное училище №39		0101000020E6100000E3C4573B8AF7454085798F334D264C40
62093	7	68	\N	42	19534	\N	56.302503000000002	Нижегородская область, город Нижний Новгород, Нижегородский район, Родионова, 201		0101000020E61000004EB51666A109464090F8156BB8264C40
62092	7	68	\N	42	19534	\N	56.3100506633617	Нижегородская область, город Нижний Новгород, Нижегородский район, Родионова, 190	Россия, Нижегородская область, Нижний Новгород, Нижегородский район	0101000020E6100000E90B21E7FD094640CA8B4CC0AF274C40
62067	7	68	\N	42	19534	\N	56.313008498954098	Нижегородская область, город Нижний Новгород, Нижегородский район, Родионова, дом 165 корпус 8	Россия, Нижегородская область, Нижний Новгород, улица Родионова, 165к4	0101000020E6100000637FD93D7908464075B169A510284C40
62090	7	68	\N	42	19742	\N	56.317777	Нижегородская область, город Нижний Новгород, Нижегородский район, Радужная, 10		0101000020E61000005F605628D2054640E335AFEAAC284C40
61951	7	68	\N	42	19769	\N	56.291992999999998	Нижегородская область, город Нижний Новгород, Канавинский район, Путейская, 23б, школа №168		0101000020E6100000ED0E290648EE454099D4D00660254C40
62174	7	68	\N	42	19609	\N	56.351813999999997	Нижегородская область, город Нижний Новгород, Сормовский район, Пугачева, 12		0101000020E6100000F913950D6BEE45403123BC3D082D4C40
62035	7	68	\N	42	19683	\N	56.325488999999997	Нижегородская область, город Нижний Новгород, Московский район, ул. Просвещенская, д.4		0101000020E610000087C3D2C08FF04540971AA19FA9294C40
61990	7	68	\N	42	19745	\N	56.292682999999997	"Нижегородская область, город Нижний Новгород, Ленинский район, Премудрова, 8, ДК ОАО ""Завод Красная Этна"""		0101000020E6100000E5F21FD26FF545402E8CF4A276254C40
61988	7	68	\N	42	19674	\N	56.294280999999998	"Нижегородская область, город Нижний Новгород, Ленинский район, Порт-Артурская, 12, ГОУ СПО ""Нижег.технолог.техн."""		0101000020E61000005F7AFB73D1F44540C66AF3FFAA254C40
62072	7	68	\N	42	1916	\N	56.321890000000003	Нижегородская область, город Нижний Новгород, Нижегородский район, переулок Плотничный, 18В	Россия, Нижегородская область, Нижний Новгород, Плотничный переулок, 18в	0101000020E610000091990B5C1EFF4540697407B133294C40
62085	7	68	\N	42	19717	\N	56.324950000000001	Нижегородская область, город Нижний Новгород, Нижегородский район, Пискунова, 35		0101000020E6100000C11C3D7E6F014640E86A2BF697294C40
61940	7	68	\N	42	19668	\N	56.269696000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Пермякова, 26		0101000020E61000008369183E22F0454057EE056685224C40
61939	7	68	\N	42	19668	\N	56.269696000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Пермякова, 26, школа № 125		0101000020E61000008369183E22F0454057EE056685224C40
61938	7	68	\N	42	19668	\N	56.267572000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Пермякова, 10а		0101000020E6100000F0BE2A172AEF4540A4A99ECC3F224C40
61977	7	68	\N	42	19647	\N	56.267662000000001	"Нижегородская область, город Нижний Новгород, Ленинский район, Партизанская, 10а, спортзал ""Энергия"" ОАО РУМО"		0101000020E61000007F8461C092F74540E43098BF42224C40
62146	7	68	\N	42	16827	\N	56.313031606139198	Нижегородская область, город Нижний Новгород, Советский район, Школа № 29, Ошарская, 70	Россия, Нижегородская область, Нижний Новгород, Ошарская улица, 70	0101000020E6100000925CFE43FA014640FD4CBD6E11284C40
62147	7	68	\N	42	19714	\N	56.312545	Нижегородская область, город Нижний Новгород, Советский район, Областное правление ВОС, Ошарская, 57а		0101000020E6100000F10D85CFD6014640A0C37C7901284C40
61970	7	68	\N	42	19698	\N	56.308025999999998	Нижегородская область, город Нижний Новгород, Канавинский район, Октябрьской революции, 23а, Детская железная дорога		0101000020E6100000C9E369F981F74540AA285E656D274C40
62080	7	68	\N	42	16456	\N	56.322040000000001	Нижегородская область, город Нижний Новгород, Нижегородский район, Октябрьская, дом 25	Россия, Нижегородская область, Нижний Новгород, Нижегородский район, Октябрьская улица, 25	0101000020E6100000EB36A8FDD60046407E00529B38294C40
61952	7	68	\N	42	19608	\N	56.311062	Нижегородская область, город Нижний Новгород, Канавинский район, Обухова, 52, школа №96		0101000020E6100000CF2EDFFAB0F64540A1832EE1D0274C40
61995	7	68	\N	42	19650	\N	56.275753999999999	Нижегородская область, город Нижний Новгород, Ленинский район, Норильская, 1, школа №177		0101000020E6100000EB19C231CBF64540DFDE35E84B234C40
62181	7	68	\N	42	19746	\N	56.345274000000003	Нижегородская область, город Нижний Новгород, Сормовский район, Никиты Рыбакова, 15		0101000020E6100000B91798158AEC45405E143DF0312C4C40
62063	7	68	\N	42	17613	\N	56.331149838937797	Нижегородская область, город Нижний Новгород, Нижегородский район, Нижне-Волжская набережная, 2	Россия, Нижегородская область, Нижний Новгород, Нижневолжская набережная, 2	0101000020E610000032C9C859D8FF454003098A1F632A4C40
62083	7	68	\N	42	19613	\N	56.327520999999997	Нижегородская область, город Нижний Новгород, Нижегородский район, Нестерова, 5		0101000020E6100000C39FE1CD1A02464069E04735EC294C40
62145	7	68	\N	42	19546	\N	56.312215019516003	Нижегородская область, город Нижний Новгород, Советский район, Нижегородский автотранспортный техникум, Невзоровых, 34		0101000020E6100000FFEBDCB4190146400B293FA9F6274C40
62134	7	68	\N	42	19793	\N	56.284889	"Нижегородская область, город Нижний Новгород, Советский район, Учебный центр ""Инфраком"", Нартова, 23"		0101000020E61000005A0D897B2CFF4540BDFE243E77244C40
62051	7	68	\N	42	19689	\N	56.334921000000001	Нижегородская область, город Нижний Новгород, Московский район, ул. Народная, 78		0101000020E61000001651137D3EF645402FDFFAB0DE2A4C40
62060	7	68	\N	42	17245	\N	56.3372099583543	Нижегородская область, город Нижний Новгород, Московский район, школа №118, ул. Народная, д.35		0101000020E6100000E0641BB803F545402CF180B2292B4C40
62050	7	68	\N	42	19533	\N	56.335961639931099	Нижегородская область, город Нижний Новгород, Московский район, ул. Народная, д.35	Россия, Нижегородская область, Нижний Новгород, улица Народная	0101000020E6100000263ACB2C42F54540715985CD002B4C40
62152	7	68	\N	42	19633	\N	56.304574463825197	Нижегородская область, город Нижний Новгород, Советский район, Детский клуб им.Маркина, Надежды Сусловой, 22	Россия, Нижегородская область, Нижний Новгород, улица Надежды Сусловой, 22	0101000020E61000002A029CDEC5054640209BE447FC264C40
62155	7	68	\N	42	17296	\N	56.299409349462302	Нижегородская область, город Нижний Новгород, Советский район, Школа № 44, Надежды Сусловой, 5 корпус 3	Россия, Нижегородская область, Нижний Новгород, улица Адмирала Васюнина, 5к3	0101000020E61000006ADD06B5DF0446406490BB0853264C40
62029	7	68	\N	42	17564	\N	56.313627561688499	Нижегородская область, город Нижний Новгород, Московский район, ул. Московское шоссе, д. 219а	Россия, Нижегородская область, Нижний Новгород, Московское шоссе, 219а	0101000020E610000062122EE411EE4540118E59F624284C40
62041	7	68	\N	42	145	\N	56.318840000000002	Нижегородская область, город Нижний Новгород, Московский район, Московское шоссе, д.79	Россия, Нижегородская область, Нижний Новгород, Московское шоссе, 79	0101000020E6100000191BBAD91FF645400D54C6BFCF284C40
62028	7	68	\N	42	145	\N	56.316664000000003	Нижегородская область, город Нижний Новгород, Московский район, Московское шоссе, д. 207а	Россия, Нижегородская область, Нижний Новгород, Московское шоссе, 207а	0101000020E6100000A25EF0694EF0454008E9297288284C40
62027	7	68	\N	42	145	\N	56.316664000000003	Нижегородская область, город Нижний Новгород, Московский район, Московское шоссе, д.207а	Россия, Нижегородская область, Нижний Новгород, Московское шоссе, 207а	0101000020E6100000A25EF0694EF0454008E9297288284C40
61953	7	68	\N	42	145	\N	56.325468999999998	Нижегородская область, город Нижний Новгород, Канавинский район, Московское шоссе, 1, НЭПК		0101000020E61000008CF2CCCB61F94540506EDBF7A8294C40
61945	7	68	\N	42	145	\N	56.312359999999998	Нижегородская область, город Нижний Новгород, Канавинский район, Московское шоссе, 248, школа №98		0101000020E61000008E226B0DA5EE45400E4A9869FB274C40
62039	7	68	\N	42	19498	\N	56.315518993886599	Нижегородская область, город Нижний Новгород, Московский район, центр образования, Московское шоссе, д.161	Россия, Нижегородская область, Нижний Новгород, Московское шоссе, 161	0101000020E6100000FE0A992B83F24540212235ED62284C40
61887	7	68	\N	42	19653	\N	56.233294000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Мончегорская, 33а		0101000020E6100000BDA94885B1E94540302DEA93DC1D4C40
61886	7	68	\N	42	19653	\N	56.2315138685221	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Мончегорская, 11а (корпус 3)	Россия, Нижегородская область, Нижний Новгород, Мончегорская улица, 11ак3	0101000020E610000041BAD8B452EA454077483140A21D4C40
61885	7	68	\N	42	19653	\N	56.234684999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Мончегорская, 32а		0101000020E61000008159A148F7E945404EEE77280A1E4C40
61883	7	68	\N	42	19653	\N	56.227625000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Мончегорская, 19а		0101000020E6100000B21188D7F5E945404260E5D0221D4C40
62189	7	68	\N	42	19756	\N	56.3583855465588	Нижегородская область, город Нижний Новгород, Сормовский район, Мокроусова, 21		0101000020E61000009817601F9DEA454011ACAA97DF2D4C40
62190	7	68	\N	42	19675	\N	56.356377000000002	Нижегородская область, город Нижний Новгород, Сормовский район, Мокроусова, 24		0101000020E610000099D6A6B1BDEA4540F705F4C29D2D4C40
62021	7	68	\N	42	19540	\N	56.335824290740902	Нижегородская область, город Нижний Новгород, Московский район, ул. Мирошникова, д.4а	Россия, Нижегородская область, Нижний Новгород, улица Мечникова, 4а	0101000020E61000009C525E2BA1EB4540209BE447FC2A4C40
62088	7	68	\N	42	19587	\N	56.324750000000002	Нижегородская область, город Нижний Новгород, Нижегородский район, улица Минина, 31а		0101000020E6100000F56915FDA103464021B0726891294C40
62020	7	68	\N	42	19617	\N	56.339351999999998	Нижегородская область, город Нижний Новгород, Московский район, ул. Мечникова, д.74		0101000020E61000001631EC3026EB454085EAE6E26F2B4C40
62019	7	68	\N	42	19617	\N	56.336872999999997	Нижегородская область, город Нижний Новгород, Московский район, ул. Мечникова, д.73а		0101000020E610000007EFAB72A1EA4540E4F38AA71E2B4C40
61932	7	68	\N	42	19796	\N	56.265867	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Мельникова, 31		0101000020E6100000F700DD9733F34540F60A0BEE07224C40
61997	7	68	\N	42	19582	\N	56.275798999999999	Нижегородская область, город Нижний Новгород, Ленинский район, Космонавта Комарова, 2а, Ниж.филиал МЭСИ		0101000020E6100000C425C79DD2F745407FA2B2614D234C40
62160	7	68	\N	42	17522	\N	56.281261257149602	Нижегородская область, город Нижний Новгород, Советский район, Школа № 49, Маршала Малиновского, 12	Россия, Нижегородская область, Нижний Новгород, улица Маршала Малиновского, 12	0101000020E610000010AD156D8E054640F451465C00244C40
62046	7	68	\N	42	19623	\N	56.325733999999997	Нижегородская область, город Нижний Новгород, Московский район, ул. Маршала Казакова, д.6		0101000020E6100000FB05BB61DBF64540FE98D6A6B1294C40
62042	7	68	\N	42	19623	\N	56.321626000000002	Нижегородская область, город Нижний Новгород, Московский район, ул. Маршала Казакова, д.3		0101000020E61000006A34B91803F745408BC56F0A2B294C40
61962	7	68	\N	42	19695	\N	56.331992	Нижегородская область, город Нижний Новгород, Канавинский район, Мануфактурная, 15, школа №95		0101000020E6100000F0DE516342FA45404E44BFB67E2A4C40
61961	7	68	\N	42	19695	\N	56.331947	Нижегородская область, город Нижний Новгород, Канавинский район, Мануфактурная, 16а, школа №2		0101000020E6100000EF5701BEDBFA4540AE80423D7D2A4C40
62066	7	68	\N	42	1827	\N	56.316105	Нижегородская область, город Нижний Новгород, Нижегородский район, Малая Покровская, 8	Россия, Нижегородская область, Нижний Новгород, Малая Покровская улица, 8	0101000020E61000006D904946CEFE4540118DEE2076284C40
61942	7	68	\N	42	19722	\N	56.271839999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Львовская, 35		0101000020E6100000BC41B456B4F1454050DF32A7CB224C40
61941	7	68	\N	42	19722	\N	56.268340999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Львовская, 1в		0101000020E61000004CFA7B293CF04540859675FF58224C40
62030	7	68	\N	42	19736	\N	56.337611000000003	Нижегородская область, город Нижний Новгород, Московский район, ул. Лучистая, д.14а		0101000020E610000056F2B1BB40CF45408BE255D6362B4C40
61915	7	68	\N	42	19770	\N	56.247740999999998	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Лоскутова, 11		0101000020E61000007CD6355A0EEE45406D7022FAB51F4C40
61946	7	68	\N	42	19635	\N	56.309274000000002	Нижегородская область, город Нижний Новгород, Канавинский район, Лесной городок, 6а, школа №181		0101000020E6100000621399B9C0EB454066C0594A96274C40
61905	7	68	\N	42	19660	\N	56.230212000000002	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Лескова, 68		0101000020E6100000A417B5FB55EC4540C9923996771D4C40
61893	7	68	\N	42	19660	\N	56.228785999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Лескова, 66 а, школа № 129		0101000020E610000093FE5E0A0FEC45402EE411DC481D4C40
62052	7	68	\N	42	19655	\N	56.348857867013699	Нижегородская область, город Нижний Новгород, Московский район, ул. Левинка, д.9	Россия, Нижегородская область, Нижний Новгород, улица Левинка, 9	0101000020E61000002B69C53714F4454057790261A72C4C40
62184	7	68	\N	42	19634	\N	56.343389000000002	Нижегородская область, город Нижний Новгород, Сормовский район, Культуры, 110		0101000020E610000048DC63E943EB45403067B62BF42B4C40
62183	7	68	\N	42	19634	\N	56.344542977718604	Нижегородская область, город Нижний Новгород, Сормовский район, Культуры, 111	Россия, Нижегородская область, Нижний Новгород, улица Культуры, 111	0101000020E6100000EA92718C64EB45406A882AFC192C4C40
62182	7	68	\N	42	19634	\N	56.348835999999999	Нижегородская область, город Нижний Новгород, Сормовский район, Культуры, 91		0101000020E6100000BC218D0A9CEC45406FD575A8A62C4C40
62177	7	68	\N	42	19634	\N	56.349708999999997	Нижегородская область, город Нижний Новгород, Сормовский район, Культуры, 1		0101000020E6100000C79BFC169DEE4540F50EB743C32C4C40
62048	7	68	\N	42	19661	\N	56.328448999999999	Нижегородская область, город Нижний Новгород, Московский район, ул. Куйбышева, д. 29		0101000020E61000001024EF1CCAF44540B3B3E89D0A2A4C40
62045	7	68	\N	42	19661	\N	56.327865000000003	Нижегородская область, город Нижний Новгород, Московский район, ул. Куйбышева, д.15		0101000020E610000051BB5F05F8F445406440F67AF7294C40
62153	7	68	\N	42	19726	\N	56.297015136653599	"Нижегородская область, город Нижний Новгород, Советский район, АНО ""Нижегородский УКЦ ""Станкоинформ"", Кузнечихинская, 73"	Россия, Нижегородская область, Нижний Новгород, Кузнечихинская улица	0101000020E610000006D49B51F3034640F2B5679604264C40
61891	7	68	\N	42	19656	\N	56.246631000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Красных партизан, 8а		0101000020E61000009C36E33444EB45400397C79A911F4C40
62031	7	68	\N	42	19758	\N	56.321885000000002	Нижегородская область, город Нижний Новгород, Московский район, ул. Красных Зорь, д.14а		0101000020E6100000FC36C478CDEF45405709168733294C40
62168	7	68	\N	42	19612	\N	56.381250000000001	Нижегородская область, город Нижний Новгород, Сормовский район, Красносормовская, 4б		0101000020E6100000067FBF982DE54540CDCCCCCCCC304C40
62142	7	68	\N	42	19658	\N	56.307921	Нижегородская область, город Нижний Новгород, Советский район, Общеж.Нижег.госуд. технического университета, Красносельская, 17		0101000020E61000003E26529ACDFD4540356090F469274C40
62073	7	68	\N	42	19590	\N	56.312623315019003	Нижегородская область, город Нижний Новгород, Нижегородский район, ул. Костина, 2, к. 51, ГПНО «Дирон»	Россия, Нижегородская область, Нижний Новгород, улица Костина, 2	0101000020E6100000FEF2C98AE1FE45401C7DCC0704284C40
61998	7	68	\N	42	19582	\N	56.273669141555501	Нижегородская область, город Нижний Новгород, Ленинский район, Космонавта Комарова, 2в, школа № 182	Россия, Нижегородская область, Нижний Новгород, Перекопская улица, 2в	0101000020E610000071CADC7C23F84540EA76F69507234C40
61531	7	68	\N	9699	19629	\N	56.232353000000003	"Нижегородская область, город Дзержинск, ул.Петрищева, 23, МОУ ""СОШ №71"""		0101000020E6100000ED2C7AA702B6454052103CBEBD1D4C40
61996	7	68	\N	42	19582	\N	56.280251999999997	Нижегородская область, город Нижний Новгород, Ленинский район, Космонавта Комарова, 6, школа №148		0101000020E61000009E29745E63F74540BD512B4CDF234C40
61882	7	68	\N	42	19791	\N	56.225347999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Космическая, 38		0101000020E61000005262D7F676E94540081C0934D81C4C40
62101	7	68	\N	42	2314	\N	56.279507000000002	Нижегородская область, город Нижний Новгород, Приокский район, Общежитие НГАСУ, пер.Корейский, д.6		0101000020E6100000151C5E1091FE45406500A8E2C6234C40
62102	7	68	\N	42	17028	\N	56.274074398485602	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 135. ул.Корейская, д.22	Россия, Нижегородская область, Нижний Новгород, Корейская улица, 22	0101000020E6100000234E27D9EAFE45408A5759DB14234C40
62103	7	68	\N	42	16685	\N	56.2740189976276	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 135, ул.Корейская, д.22	Россия, Нижегородская область, Нижний Новгород, Корейская улица, 22	0101000020E6100000D593F947DFFE4540C7BDF90D13234C40
61922	7	68	\N	42	19774	\N	56.253521999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Комсомольская, 10а		0101000020E610000047AE9B525EED45408368AD6873204C40
61965	7	68	\N	42	19606	\N	56.315745	Нижегородская область, город Нижний Новгород, Канавинский район, Коммунистическая, 75, школа №50		0101000020E61000003ACB2C42B1F94540117008556A284C40
62173	7	68	\N	42	19781	\N	56.357086000000002	Нижегородская область, город Нижний Новгород, Сормовский район, Коминтерна, 250		0101000020E6100000A5DC7D8E8FEE454003EE79FEB42D4C40
62053	7	68	\N	42	19781	\N	56.337800999999999	Нижегородская область, город Нижний Новгород, Московский район, ул. Коминтерна, д.21		0101000020E61000009D2D20B41EF045402EC72B103D2B4C40
62116	7	68	\N	42	19663	\N	56.238216999999999	Нижегородская область, город Нижний Новгород, Приокский район, ул.Кащенко, д.23		0101000020E610000090300C5872FD4540F52C08E57D1E4C40
62000	7	68	\N	42	19721	\N	56.276333999999999	Нижегородская область, город Нижний Новгород, Ленинский район, Каширская, 58, проф. лицей № 11		0101000020E61000003080F0A144F94540ED629AE95E234C40
61999	7	68	\N	42	19721	\N	56.276333999999999	Нижегородская область, город Нижний Новгород, Ленинский район, Каширская, 58, проф.лицей № 11		0101000020E61000003080F0A144F94540ED629AE95E234C40
61964	7	68	\N	42	19639	\N	56.340994000000002	Нижегородская область, город Нижний Новгород, Канавинский район, Карла Маркса, 17, школа №176		0101000020E61000001EDE736039F84540ED10FFB0A52B4C40
61947	7	68	\N	42	31	\N	56.304714814967397	"Нижегородская область, город Нижний Новгород, Канавинский район, пер. Камчатский, 4, подростковый клуб ""Атлант"""		0101000020E6100000EA944737C2EC4540E2CCAFE600274C40
62099	7	68	\N	42	16751	\N	56.288374128836701	Нижегородская область, город Нижний Новгород, Нижегородский район, Агродом	Россия, Нижегородская область, Нижний Новгород, Казанское шоссе, 17	0101000020E6100000172AFF5A5E09464023827170E9244C40
62082	7	68	\N	42	1794	\N	56.288242388260997	Нижегородская область, город Нижний Новгород, Нижегородский район, шоссе  Казанское, 12	Россия, Нижегородская область, Нижний Новгород, Казанское шоссе, 12к1	0101000020E6100000252191B6F1094640B4AA251DE5244C40
62064	7	68	\N	42	1794	\N	56.2869654227217	Нижегородская область, город Нижний Новгород, Нижегородский район, шоссе Казанское, 12	Россия, Нижегородская область, Нижний Новгород, Казанское шоссе, 12б	0101000020E6100000E0490B97550A46405F0CE544BB244C40
61966	7	68	\N	42	19642	\N	56.310057999999998	Нижегородская область, город Нижний Новгород, Канавинский район, Июльских дней, 1а, ЦДК Железнодорожников		0101000020E61000000E9E094D12F945407CEE04FBAF274C40
62015	7	68	\N	42	19589	\N	56.304236000000003	Нижегородская область, город Нижний Новгород, Ленинский район, Июльских дней, 8, Ниж.медиц.базовый колледж		0101000020E61000007F4DD6A887F8454008228B34F1264C40
62014	7	68	\N	42	19589	\N	56.303560117868201	Нижегородская область, город Нижний Новгород, Ленинский район, Июльских дней, 10, школа № 97	Россия, Нижегородская область, Нижний Новгород, улица Июльских Дней, 10к1	0101000020E61000004E27D9EA72F84540D72FD80DDB264C40
62069	7	68	\N	42	19694	\N	56.321984999999998	Нижегородская область, город Нижний Новгород, Нижегородский район, Ильинская, дом 47		0101000020E6100000103B53E8BCFE4540BA66F2CD36294C40
62200	7	68	\N	42	19713	\N	56.371132000000003	Нижегородская область, город Нижний Новгород, Сормовский район, Зайцева, 7		0101000020E6100000D3F8855792E64540E23FDD40812F4C40
62199	7	68	\N	42	19713	\N	56.366351000000002	Нижегородская область, город Нижний Новгород, Сормовский район, Зайцева, 18а		0101000020E6100000D27135B22BE74540AFEDED96E42E4C40
61987	7	68	\N	42	19783	\N	56.301788675438601	Нижегородская область, город Нижний Новгород, Ленинский район, Завкомовская, 1, школа №138	Россия, Нижегородская область, Нижний Новгород, Завкомовская улица	0101000020E61000003E4162BB7BF4454072A59E05A1264C40
62122	7	68	\N	42	17456	\N	56.230860713865603	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 17, ул.Жукова, д.18	Россия, Нижегородская область, Нижний Новгород, улица Маршала Жукова	0101000020E61000009EEDD11BEEF94540FF756EDA8C1D4C40
61936	7	68	\N	42	19665	\N	56.265332000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Дьяконова, 25а		0101000020E6100000BA313D6189F14540884A2366F6214C40
61927	7	68	\N	42	19665	\N	56.259073000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Дьяконова, 1б		0101000020E6100000F10EF0A485EF45406823D74D29214C40
62166	7	68	\N	42	19757	\N	56.387374999999999	Нижегородская область, город Нижний Новгород, Сормовский район, Дубравная, 21		0101000020E6100000BE839F3880DE4540DD24068195314C40
61985	7	68	\N	42	19640	\N	56.285668000000001	Нижегородская область, город Нижний Новгород, Ленинский район, Дружбы, 50, школа №123		0101000020E6100000D446753A90F54540C2C1DEC490244C40
61928	7	68	\N	42	19776	\N	56.257677999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Дружаева, 5б		0101000020E6100000BA68C87894F045400873BB97FB204C40
61937	7	68	\N	42	19741	\N	56.264716999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Дружаева, 15а		0101000020E61000003EEB1A2D07F04540FDD8243FE2214C40
62009	7	68	\N	42	19750	\N	56.319114999999996	Нижегородская область, город Нижний Новгород, Нижегородский район, Донецкая, 3		0101000020E6100000220038F6EC054640DE54A4C2D8284C40
61948	7	68	\N	42	19805	\N	56.290489000000001	Нижегородская область, город Нижний Новгород, Канавинский район, Движенцев, 7, школа №75		0101000020E61000002B508BC1C3EC4540836C59BE2E254C40
62012	7	68	\N	42	19501	\N	56.2909607389157	Нижегородская область, город Нижний Новгород, Ленинский район, Даргомыжского, 11а,Центр дополнит.образования	Россия, Нижегородская область, Нижний Новгород, улица Даргомыжского	0101000020E610000049641F6459F84540ABB4C5353E254C40
62010	7	68	\N	42	19501	\N	56.287776211296197	Нижегородская область, город Нижний Новгород, Ленинский район, Даргомыжского, 22а, школа № 94	Россия, Нижегородская область, Нижний Новгород, улица Адмирала Макарова	0101000020E61000000EBC5AEECCF845406F490ED8D5244C40
61979	7	68	\N	42	19549	\N	56.261167999999998	Нижегородская область, город Нижний Новгород, Ленинский район, Грекова, 9, библиотечно-инф.и досуг.центр		0101000020E6100000666A12BC21F745408061F9F36D214C40
61950	7	68	\N	42	19798	\N	56.287996	Нижегородская область, город Нижний Новгород, Канавинский район, Гороховецкая, 12, ДК станц. Горький-Сортировочный		0101000020E6100000C26856B60FED45407DB08C0DDD244C40
62578	7	68	\N	42	19513	\N	56.324111374652503	Нижегородская область, город Нижний Новгород, Канавинский район, Гордеевская, 3/5, ГУ Обл центр соц-труд. реабил	Россия, Нижегородская область, Нижний Новгород, Московское шоссе	0101000020E610000009A69A594BF945400EA320787C294C40
62133	7	68	\N	42	19637	\N	56.274549697932997	Нижегородская область, город Нижний Новгород, Советский район, Клуб поселка Сахарный Дол, Горбатовская, 16		0101000020E61000000BB43BA418004640F38E537424234C40
62004	7	68	\N	42	19753	\N	56.280321999999998	Нижегородская область, город Нижний Новгород, Ленинский район, Гончарова, 12, школа № 120		0101000020E6100000A5F3E15982F84540B62C5F97E1234C40
62002	7	68	\N	42	19780	\N	56.287261999999998	Нижегородская область, город Нижний Новгород, Ленинский район, Голубева, 4а, школа № 91		0101000020E6100000556CCCEB88F9454018B14F00C5244C40
62068	7	68	\N	42	19510	\N	56.319007862022197	Нижегородская область, город Нижний Новгород, Нижегородский район, Гоголя, 1		0101000020E6100000C6FA062637FE4540C8940F41D5284C40
61994	7	68	\N	42	19611	\N	56.277943	Нижегородская область, город Нижний Новгород, Ленинский район, Героя Чугунова, 9, школа №175		0101000020E6100000B2834A5CC7F645407993DFA293234C40
61903	7	68	\N	42	19569	\N	56.232739000000002	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Героя Смирнова, 52а		0101000020E610000017A06D35EBEC45407BC03C64CA1D4C40
61989	7	68	\N	42	19544	\N	56.2889392189443	"Нижегородская область, город Нижний Новгород, Ленинский район, Героя Самочкина, 18, детский клуб ""Парус"""	Россия, Нижегородская область, Нижний Новгород, улица Героя Советского Союза Самочкина	0101000020E6100000BFD7101C97F54540FCC401F4FB244C40
62032	7	68	\N	42	19688	\N	56.317957	Нижегородская область, город Нижний Новгород, Московский район, ул.Рябцева, д.10		0101000020E61000005322895E46EF45406344A2D0B2284C40
61976	7	68	\N	42	19678	\N	56.255462000000001	Нижегородская область, город Нижний Новгород, Ленинский район, Героя Попова, 12а, ПУ-интернат		0101000020E6100000E40F069E7BF5454075AF93FAB2204C40
61875	7	68	\N	42	19632	\N	56.205776	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Героя Ляхова, 109		0101000020E61000000C3ECDC98BE245409E2633DE561A4C40
62034	7	68	\N	42	19761	\N	56.323661999999999	Нижегородская область, город Нижний Новгород, Московский район, ул. Героя Давыдова, д. 13		0101000020E6100000266E15C440EF45409E7AA4C16D294C40
62033	7	68	\N	42	19784	\N	56.323661999999999	Нижегородская область, город Нижний Новгород, Московский район, ул. Героя Давыдова, д.13		0101000020E6100000266E15C440EF45409E7AA4C16D294C40
61908	7	68	\N	42	19521	\N	56.240117565256	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Героя Смирнова, 12	Россия, Нижегородская область, Нижний Новгород, проспект Молодежный, 12	0101000020E6100000D9EA724A40EE45402997C62FBC1E4C40
61874	7	68	\N	42	19573	\N	56.248055074846803	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Героя Бахтина, 1а	Россия, Нижегородская область, Нижний Новгород, улица Героя Советского Союза Бахтина, 1	0101000020E6100000DA20938C9CDF4540FD4D2844C01F4C40
62197	7	68	\N	42	19705	\N	56.358930999999998	Нижегородская область, город Нижний Новгород, Сормовский район, Героев Космоса, 43		0101000020E6100000D671FC5069E84540A2427573F12D4C40
62196	7	68	\N	42	19705	\N	56.357599	Нижегородская область, город Нижний Новгород, Сормовский район, Героев Космоса, 1		0101000020E6100000247B849A21E94540890AD5CDC52D4C40
61521	7	68	\N	9699	19629	\N	56.233874	"Нижегородская область, город Дзержинск, ул.Петрищева, 7, МОУ ""СОШ №13"""		0101000020E6100000D61EF64201B745403EB14E95EF1D4C40
62157	7	68	\N	42	16699	\N	56.292053450551997	Нижегородская область, город Нижний Новгород, Советский район, Школа № 24, Генерала Ивлиева, 32 корпус 4	Россия, Нижегородская область, Нижний Новгород, улица Генерала Ивлиева, 32к4	0101000020E6100000172D40DB6A0646406FD921FE61254C40
61957	7	68	\N	42	19724	\N	56.328004999999997	Нижегородская область, город Нижний Новгород, Канавинский район, Генерала Зимина, 75, школа №51		0101000020E6100000A260C614ACF7454055F65D11FC294C40
61986	7	68	\N	42	19673	\N	56.290649000000002	Нижегородская область, город Нижний Новгород, Ленинский район, Гвоздильная, 9, школа №99		0101000020E6100000DAAB8F87BEF34540BCCE86FC33254C40
62056	7	68	\N	42	19545	\N	56.334854358532702	Нижегородская область, город Нижний Новгород, Московский район, ул. Гвардейцев, д.4	Россия, Нижегородская область, Нижний Новгород, улица Гвардейцев, 4а	0101000020E610000031B5A50EF2F04540A777F17EDC2A4C40
61929	7	68	\N	42	19790	\N	56.263472	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Газовская, 18		0101000020E6100000C896E5EB32F24540B3B45373B9214C40
62172	7	68	\N	42	19799	\N	56.362028000000002	Нижегородская область, город Нижний Новгород, Сормовский район, Вузовская, 1		0101000020E6100000952BBCCB45EC45403F1EFAEE562E4C40
62175	7	68	\N	42	19610	\N	56.351982999999997	Нижегородская область, город Нижний Новгород, Сормовский район, Вождей Революции, 29		0101000020E61000008D5DA27A6BEC4540BDDF68C70D2D4C40
62110	7	68	\N	42	17987	\N	56.233839000000003	Нижегородская область, город Нижний Новгород, Приокский район, ул. Ветлужская, 2, Школа № 140		0101000020E610000074620FED63FD4540C2C3B46FEE1D4C40
62129	7	68	\N	42	16693	\N	56.295394505431403	Нижегородская область, город Нижний Новгород, Советский район, Школа № 122, Верхняя, 8	Россия, Нижегородская область, Нижний Новгород, улица Верхняя, 8	0101000020E61000007B681F2BF80146407233DC80CF254C40
62096	7	68	\N	42	17005	\N	56.2871091021306	Нижегородская область, город Нижний Новгород, Нижегородский район, Верхне-Печерская, 10	Россия, Нижегородская область, Нижний Новгород, Верхнепечерская улица, 10	0101000020E61000002D5F97E13F09464092B1DAFCBF244C40
62095	7	68	\N	42	17005	\N	56.297060355449503	Нижегородская область, город Нижний Новгород, Нижегородский район, Верхне-Печерская, 3а	Россия, Нижегородская область, Нижний Новгород, Верхнепечерская улица, 3а	0101000020E610000041D7BE805E0846409279E40F06264C40
62094	7	68	\N	42	17005	\N	56.296341674691703	Нижегородская область, город Нижний Новгород, Нижегородский район, Верхне-Печерская, 4а	Россия, Нижегородская область, Нижний Новгород, Верхнепечерская улица, 4а	0101000020E610000053910A630B0946403337DF88EE254C40
62062	7	68	\N	42	17005	\N	56.292896852204599	Нижегородская область, город Нижний Новгород, Нижегородский район, Верхне-Печерская, 5а	Россия, Нижегородская область, Нижний Новгород, Верхнепечерская улица, 5а	0101000020E61000001E3526C45C0846405B0C1EA67D254C40
61899	7	68	\N	42	19788	\N	56.22775	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Веденяпина, 30а		0101000020E610000050C422861DF04540FED478E9261D4C40
61931	7	68	\N	42	19603	\N	56.264356999999997	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Васнецова, 20		0101000020E610000050560C5707F24540FDBB3E73D6214C40
62193	7	68	\N	42	19505	\N	56.365189000000001	Нижегородская область, город Нижний Новгород, Сормовский район, Василия Иванова, 28		0101000020E61000008176871403EA4540F2ED5D83BE2E4C40
62191	7	68	\N	42	19505	\N	56.363704932714299	Нижегородская область, город Нижний Новгород, Сормовский район, Василия Иванова, 63	Россия, Нижегородская область, Нижний Новгород, улица Стрелковая, 63	0101000020E6100000EB8D5A61FAE845402332ACE28D2E4C40
62077	7	68	\N	42	19583	\N	56.321283886645801	Нижегородская область, город Нижний Новгород, Нижегородский район, Варварская, дом 15а	Россия, Нижегородская область, Нижний Новгород, Варварская улица, 15	0101000020E6100000E6779ACC78014640315D88D51F294C40
62128	7	68	\N	42	19677	\N	56.292197999999999	Нижегородская область, город Нижний Новгород, Советский район, Нижегородский институт развития образования, Ванеева, 203		0101000020E61000003C889D297404464072FA7ABE66254C40
61934	7	68	\N	42	19691	\N	56.270330999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Бурденко, 35		0101000020E6100000E6913F1878F24540280CCA349A224C40
62150	7	68	\N	42	16802	\N	56.3100217771145	Нижегородская область, город Нижний Новгород, Советский район, Школа № 151, Бориса Панина, 8/54		0101000020E610000072512D228A0346402F8507CDAE274C40
62149	7	68	\N	42	16802	\N	56.308886996148097	Нижегородская область, город Нижний Новгород, Советский район, Дом детского творчества, Бориса Панина, 5		0101000020E6100000003CA242750346406C94F59B89274C40
62154	7	68	\N	42	16761	\N	56.298723336280197	Нижегородская область, город Нижний Новгород, Советский район, Школа № 46, Бориса Корнилова, 10	Россия, Нижегородская область, Нижний Новгород, улица Бориса Корнилова, 10	0101000020E6100000A75D4C33DD05464011C8258E3C264C40
62170	7	68	\N	42	19670	\N	56.367946000000003	Нижегородская область, город Нижний Новгород, Сормовский район, Б.Починковская, 54		0101000020E610000071A94A5B5CEB4540D658C2DA182F4C40
62065	7	68	\N	42	19666	\N	56.322240000000001	Нижегородская область, город Нижний Новгород, Нижегородский район, Большая Покровская, 18		0101000020E610000063B48EAA2600464045BB0A293F294C40
62084	7	68	\N	42	19692	\N	56.326787000000003	Нижегородская область, город Нижний Новгород, Нижегородский район, Б.Печерская, 2		0101000020E6100000FA08FCE1E701464005E10A28D4294C40
62089	7	68	\N	42	19564	\N	56.321677832400901	Нижегородская область, город Нижний Новгород, Нижегородский район, Б.Печерская, 63в		0101000020E6100000B4E7323509044640DDEBA4BE2C294C40
62037	7	68	\N	42	19638	\N	56.315080999999999	Нижегородская область, город Нижний Новгород, Московский район, ул. Берёзовская, д. 2		0101000020E61000004A79AD84EEF04540A54BFF9254284C40
62135	7	68	\N	42	17035	\N	56.290603766598799	Нижегородская область, город Нижний Новгород, Советский район, Нижегородский музыкальный колледж им.М.А.Балакирева,Бекетова, 5в	Россия, Нижегородская область, Нижний Новгород, улица Бекетова, 5в	0101000020E61000003D0CAD4ECEFE45401C0B0A8332254C40
62194	7	68	\N	42	19747	\N	56.367691999999998	Нижегородская область, город Нижний Новгород, Сормовский район, Баренца, 7		0101000020E6100000CA52EBFD46E945401B800D88102F4C40
62192	7	68	\N	42	19749	\N	56.366793999999999	Нижегородская область, город Нижний Новгород, Сормовский район, Баренца, 18		0101000020E61000003F1C2444F9E845403C2F151BF32E4C40
62138	7	68	\N	42	19723	\N	56.297668000000002	Нижегородская область, город Нижний Новгород, Советский район, Нижегородский колледж бытового сервиса, Артельная, 9		0101000020E61000006ADC9BDF30FF45406A882AFC19264C40
61880	7	68	\N	42	19748	\N	56.220753999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Аркадия Гайдара, 20а		0101000020E610000046D26EF431EB4540083BC5AA411C4C40
61879	7	68	\N	42	19752	\N	56.218817000000001	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Аркадия Гайдара, 16		0101000020E610000065170CAEB9EB454088670932021C4C40
61884	7	68	\N	42	19602	\N	56.228416000000003	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Академика Павлова, 14а		0101000020E6100000E77283A10EEB45400BF148BC3C1D4C40
62007	7	68	\N	42	19651	\N	56.288266	Нижегородская область, город Нижний Новгород, Ленинский район, Академика Баха, 6, школа № 185		0101000020E610000005FD851E31F845403D4679E6E5244C40
61981	7	68	\N	42	19659	\N	56.271211000000001	Нижегородская область, город Нижний Новгород, Ленинский район, Адмирала Нахимова, 6, школа №160		0101000020E6100000EF37DA71C3F5454061A8C30AB7224C40
61980	7	68	\N	42	19659	\N	56.269405999999996	Нижегородская область, город Нижний Новгород, Ленинский район, Адмирала Нахимова, 10а, Нижег.дизелестр.техникум		0101000020E6100000855CA96741F645404FAC53E57B224C40
62011	7	68	\N	42	19729	\N	56.289285	Нижегородская область, город Нижний Новгород, Ленинский район, Адмирала Макарова, 1а, филиал Сочинского ГУ туризма		0101000020E61000000553CDACA5F84540971C774A07254C40
61902	7	68	\N	42	19664	\N	56.233443999999999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Автомеханическая, 12		0101000020E6100000698CD651D5EE454045B9347EE11D4C40
61901	7	68	\N	42	19664	\N	56.232999	Нижегородская область, город Нижний Новгород, Автозаводский район, ул. Автомеханическая, 13а		0101000020E61000005018946934EF4540178046E9D21D4C40
62058	7	68	\N	42	19630	\N	56.328603999999999	Нижегородская область, город Нижний Новгород, Московский район, ул.50-летия Победы, д.24		0101000020E610000037C30DF8FCF04540DAAA24B20F2A4C40
62057	7	68	\N	42	19630	\N	56.328603999999999	Нижегородская область, город Нижний Новгород, Московский район, ул.50-летия Победы, д. 24		0101000020E610000037C30DF8FCF04540DAAA24B20F2A4C40
62124	7	68	\N	42	16746	\N	56.226288878493101	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 134, ул.40 лет Победы, д.16	Россия, Нижегородская область, Нижний Новгород, улица 40 Лет Победы, 16	0101000020E61000001A6EC0E787F94540E738B709F71C4C40
62108	7	68	\N	42	17071	\N	56.261421128218103	Нижегородская область, город Нижний Новгород, Приокский район, Школа № 154, ул.40 лет Октября, д.2	Россия, Нижегородская область, Нижний Новгород, улица 40 Лет Октября, 2	0101000020E6100000B821C66B5EFD45406ABE4A3E76214C40
62070	7	68	\N	42	19739	\N	56.313657999999997	Нижегородская область, город Нижний Новгород, Нижегородский район, Третья Ямская, 1		0101000020E61000000D18247D5AFD45407B1002F225284C40
61873	7	68	\N	42	19516	\N	56.270141860691403	Нижегородская область, город Нижний Новгород, Автозаводский район, поселок Новое Доскино, 19 линия, 25	Россия, Нижегородская область, Нижний Новгород, улица 19-я Линия	0101000020E61000008FC536A968E0454055A3570394224C40
62075	7	68	\N	42	19773	\N	56.314956000000002	Нижегородская область, город Нижний Новгород, Нижегородский район, Маслякова, 1		0101000020E6100000ED9E3C2CD4FE4540E9D66B7A50284C40
61095	7	68	\N	49760	17185	\N	56.404707278107303	МБОУ Основная Общеобразовательная Школа № 20. Нижегородская область, город Бор, п. Неклюдово, ул. Новая, д. 6а		0101000020E61000007DCD72D9E8FE45402CBB6070CD334C40
61743	7	68	\N	13322	\N	\N	55.415793999999998	Нижегородская область, Кулебакский район, г.Кулебаки, ул.Труда, д.15, МОУ «Средняя общеобразовательная школа №8»	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61742	7	68	\N	13322	\N	\N	55.415793999999998	Нижегородская область, Кулебакский район, г.Кулебаки, ул.Ст.Разина, д.95, Горполиклиника	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61741	7	68	\N	13322	\N	\N	55.415793999999998	Нижегородская область, Кулебакский район, город Кулебаки, Футбольная, 3, школа №10	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61736	7	68	\N	13322	\N	\N	55.415793999999998	"Нижегородская область, Кулебакский район, город Кулебаки, пл.Ленина, 2, МУ ""Культурно-досуговый комплекс"	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61733	7	68	\N	13322	\N	\N	55.415793999999998	Нижегородская область, Кулебакский район, г.Кулебаки, ул.Бутова, д.75а, МУ «Городской центр досуга (к./т «Россия»)	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61727	7	68	\N	13322	\N	\N	55.415793999999998	Нижегородская область, Кулебакский район, город Кулебаки, Песочная, 53, Центр занятости населения	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61734	7	68	\N	13322	17338	\N	55.415793999999998	Нижегородская область, Кулебакский район, г.Кулебаки, пл.Ленина, д.2, МУ «Культурно-досуговый комплекс» (Дворец культуры)	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61726	7	68	\N	13322	17437	\N	55.431795501385203	Нижегородская область, Кулебакский район, город Кулебаки, Циолковского, 20, школа №9	Россия, Нижегородская область, Кулебаки	0101000020E610000015C440D7BE4045409545611745B74B40
61738	7	68	\N	13322	17324	\N	55.415793999999998	Нижегородская область, Кулебакский район, город Кулебаки, О.Кошевого, 132, школа №6	Россия, Нижегородская область, Кулебаки	0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61725	7	68	\N	13322	17916	\N	55.4270220576581	Нижегородская область, Кулебакский район, город Кулебаки, Мира, 23А, школа №3		0101000020E6100000488B33863941454015562AA8A8B64B40
61745	7	68	\N	13322	17144	\N	55.415793999999998	Нижегородская область, Кулебакский район, г.Кулебаки, ул.Маряхина, д.4, Помещение бывшей библиотеки №3		0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61732	7	68	\N	13322	17255	\N	55.416999314755202	Нижегородская область, Кулебакский район, город Кулебаки, Гоголя, 27, школа№1	Россия, Нижегородская область, Кулебаки	0101000020E6100000AE11C138B84245407BBB253960B54B40
61730	7	68	\N	13322	17438	\N	55.415793999999998	Нижегородская область, Кулебакский район, город Кулебаки, Воровского, 80, Детская художественная школа		0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61729	7	68	\N	13322	17034	\N	55.434142640282602	Нижегородская область, Кулебакский район, город Кулебаки, 60 лет ВЛКСМ, 14, ЦДТТ	Россия, Нижегородская область, Кулебаки	0101000020E6100000C97553CA6B414540C76471FF91B74B40
61666	7	68	\N	49702	17493	\N	56.157276048069903	Нижегородская область, Кстовский район, г. Кстово, пр. Рачкова, д. 12, Дом учащейся молодежи		0101000020E6100000AD33BE2F2E1B46400D39B69E21144C40
61672	7	68	\N	49702	19488	\N	56.149412289704998	Нижегородская область, Кстовский район, г. Кстово, ул. Школьная, д. 15, школа № 5		0101000020E6100000053411363C194640A2D0B2EE1F134C40
61671	7	68	\N	49702	19488	\N	56.1527300186183	Нижегородская область, Кстовский район, г. Кстово, ул. Школьная, д. 6, школа № 2		0101000020E610000043588D25AC1946401D8F19A88C134C40
61680	7	68	\N	49702	19720	\N	56.138172710729201	Нижегородская область, Кстовский район, г. Кстово, ул. Тургенева, д.3, Профессиональный лицей №36		0101000020E6100000664D2CF015194640591822A7AF114C40
61679	7	68	\N	49702	19649	\N	56.142610780843498	Нижегородская область, Кстовский район, г. Кстово, ул. Свободы, д. 1, школа №7		0101000020E6100000AA807B9E3F1946406286C61341124C40
61674	7	68	\N	49702	19649	\N	56.142670679150299	Нижегородская область, Кстовский район, г. Кстово, ул. Свободы, д. 1, школа № 7		0101000020E6100000A8E49CD843194640378B170B43124C40
61665	7	68	\N	49702	17233	\N	56.159296789589298	Нижегородская область, Кстовский район, г. Кстово, ул. Парковая, школа №8		0101000020E6100000855FEAE74D1B4640EBAC16D863144C40
61664	7	68	\N	49702	17233	\N	56.159224942831997	Нижегородская область, Кстовский район, г. Кстово, ул. Парковая, школа № 8		0101000020E6100000787DE6AC4F1B464051DA1B7C61144C40
61699	7	68	\N	49702	19676	\N	56.104378613259001	"Нижегородская область, Кстовский район, г. Кстово, ул. Островского, д.13, ""Центр внешкольной работы"""		0101000020E610000075CB0EF10F154640D1B1834A5C0D4C40
61669	7	68	\N	49702	19676	\N	56.150261750020697	"Нижегородская область, Кстовский район, г. Кстово, ул. Островского, д.5, МУП ""Тепловые сети"""		0101000020E6100000166A4DF38E1B464070EA03C93B134C40
61696	7	68	\N	49702	19732	\N	56.147873144595401	"Нижегородская область, Кстовский район, г. Кстово, 3 микрорайон, д. 1, помещение кафе ""Престиж"""		0101000020E6100000BF29AC54501746400F7BA180ED124C40
61534	7	68	\N	49699	\N	\N	56.200717350452301	Нижегородская область, город Дзержинск, пос.Желнино, поселковая Администрация		0101000020E6100000A8C7B60C38AF454028603B18B1194C40
61470	7	68	\N	9699	\N	\N	56.239398000000001	Нижегородская область, город Дзержинск, р.п. Горбатовка, административное здание	Россия, Нижегородская область, Дзержинск	0101000020E61000003E97A949F0BA4540295DFA97A41E4C40
61539	7	68	\N	9699	3664	\N	56.223546765791703	"Нижегородская область, город Дзержинск, ул.Удриса, 8, ""МОУ ""Гимназия №38"""	Россия, Нижегородская область, Дзержинск, улица Рудольфа Удриса	0101000020E6100000E61E12BEF7B34540390F27309D1C4C40
61497	7	68	\N	9699	3128	\N	56.251797000000003	"Нижегородская область, город Дзержинск, ул.Пирогова, 34-б, МОУ ""СОШ №70"""		0101000020E6100000FED478E926BD45408F1D54E23A204C40
61477	7	68	\N	9699	3219	\N	56.239398000000001	Нижегородская область, город Дзержинск, р.п. Гавриловка, административное здание	Россия, Нижегородская область, Дзержинск, улица Кирова, 1	0101000020E61000003E97A949F0BA4540295DFA97A41E4C40
61532	7	68	\N	9699	3532	\N	56.228701000000001	Нижегородская область, город Дзержинск, ул.Галкина,9-а, МБОУ «СОШ №17»		0101000020E6100000B2D7BB3FDEB3454000C80913461D4C40
61516	7	68	\N	9699	3330	\N	56.231698000000002	Нижегородская область, город Дзержинск, пр.Циолковского, 17-в	Россия, Нижегородская область, Дзержинск, проспект Циолковского, 17в	0101000020E6100000A65F22DE3AB945403946B247A81D4C40
61486	7	68	\N	9699	19735	\N	56.233989999999999	"Нижегородская область, город Дзержинск, ул.Октябрьская, 52, МОУ ""СОШ №30"""		0101000020E610000001DF6DDE38BD4540A7CB6262F31D4C40
61513	7	68	\N	9699	3330	\N	56.235691000000003	Нижегородская область, город Дзержинск, пр.Циолковского, 18а, МОУ СОШ №39	Россия, Нижегородская область, Дзержинск, проспект Циолковского, 18а	0101000020E610000060E7A6CD38B94540147B681F2B1E4C40
61544	7	68	\N	9699	3608	\N	56.245815	Нижегородская область, город Дзержинск, пр-т Свердлова, 33в, Спец.образ.школа №2		0101000020E6100000E0D6DD3CD5B14540E1EEACDD761F4C40
61543	7	68	\N	9699	3608	\N	56.251992000000001	"Нижегородская область, город Дзержинск, пр-т Свердлова, 21, МОУ ""СОШ №1"""		0101000020E61000000C91D3D7F3B14540446D1B4641204C40
61537	7	68	\N	9699	3608	\N	56.223992000000003	"Нижегородская область, город Дзержинск, пр.Свердлова, 88А, МОУ ""СОШ №27"""		0101000020E61000005072874D64B24540674815C5AB1C4C40
61535	7	68	\N	9699	3608	\N	56.223992000000003	Нижегородская область, город Дзержинск, пр. Свердлова, 88-а, МБОУ «СОШ №27»		0101000020E61000005072874D64B24540674815C5AB1C4C40
61526	7	68	\N	9699	3501	\N	56.244135	"Нижегородская область, город Дзержинск, пр.Ленинского комсомола, 12А, МОУ ""СОШ №18"""		0101000020E6100000C74ACCB392B445408C67D0D03F1F4C40
61510	7	68	\N	9699	2942	\N	56.240192999999998	Нижегородская область, город Дзержинск, пр.Ленина, 53, ГОУ СПО ДТК		0101000020E61000000E164ED2FCB9454033DDEBA4BE1E4C40
61508	7	68	\N	9699	2942	\N	56.246751000000003	Нижегородская область, город Дзержинск, пр Ленина, 5, МОУ ДОД ДЮСШ№1		0101000020E61000004D6551D845B74540AEA06989951F4C40
61489	7	68	\N	9699	2942	\N	56.239218000000001	Нижегородская область, город Дзержинск, пр.Ленина, 79,  ГОУ СПО ДХМТ		0101000020E6100000F94D61A582BC4540A94E07B29E1E4C40
61483	7	68	\N	9699	2942	\N	56.239218000000001	Нижегородская область, город Дзержинск, пр.Ленина, 79, ГОУ СПО ДХМТ		0101000020E6100000F94D61A582BC4540A94E07B29E1E4C40
61490	7	68	\N	9699	2794	\N	56.242488999999999	"Нижегородская область, город Дзержинск, пр.Дзержинского, 16, МОУ ""СОШ №10"""	Россия, Нижегородская область, Дзержинск, проспект Дзержинского, 16/22	0101000020E6100000A20C553195BC4540E3512AE1091F4C40
61473	7	68	\N	9699	2794	\N	56.242488999999999	Нижегородская область, город Дзержинск, пр.Дзержинского, 16, МОУ СОШ №10		0101000020E6100000A20C553195BC4540E3512AE1091F4C40
61538	7	68	\N	9699	3625	\N	56.223922000000002	"Нижегородская область, город Дзержинск, бульвар Химиков, 6А, МОУ ""СОШ №34"""		0101000020E61000001F2DCE18E6B245406E6DE179A91C4C40
61536	7	68	\N	9699	3625	\N	56.223922000000002	"Нижегородская область, город Дзержинск, бульвар Химиков, 6а, МОУ ""СОШ №34"""		0101000020E61000001F2DCE18E6B245406E6DE179A91C4C40
61677	7	68	\N	9699	3216	\N	56.238436999999998	Нижегородская область, Кстовский район, г. Кстово, бульвар Мира, д. 23, ДДЮТ		0101000020E61000007C4276DEC6B845400394861A851E4C40
61520	7	68	\N	9699	3216	\N	56.235135	"Нижегородская область, город Дзержинск, бульвар Мира, 36, МОУ ""СОШ №12"""	Россия, Нижегородская область, Дзержинск, бульвар Мира, 36	0101000020E61000005D6A847EA6B845408E9257E7181E4C40
61511	7	68	\N	9699	3216	\N	56.244574999999998	Нижегородская область, город Дзержинск, б-р Мира, 3, МОУ СОШ №40		0101000020E61000005051F52B9DB94540A835CD3B4E1F4C40
61503	7	68	\N	9699	3216	\N	56.247065999999997	Нижегородская область, город Дзержинск, б-р Мира, 2, ГОУ СПО  ДМК		0101000020E61000008600E0D8B3B945400DFAD2DB9F1F4C40
61548	7	68	\N	9699	3781	\N	56.228740999999999	"Нижегородская область, город Дзержинск, бул.Космонавтов, 26а, МОУ ДЮЦ ""Магнитная стрелка"""		0101000020E610000039B35DA10FB045408E209562471D4C40
61527	7	68	\N	9699	19786	\N	56.241093999999997	"Нижегородская область, город Дзержинск, ул.Щорса, 3, МОУ ""СОШ №33"""		0101000020E61000008F554ACFF4B2454083A10E2BDC1E4C40
61476	7	68	\N	9699	19707	\N	56.240648	Нижегородская область, город Дзержинск, ул.Черняховского, 24, Филиал ГОУ ВПО ВВАГС		0101000020E6100000D5CA845FEABD454085ECBC8DCD1E4C40
61475	7	68	\N	9699	19707	\N	56.240648	Нижегородская область, город Дзержинск, Черняховского, 24, филиал ВВАГС		0101000020E6100000D5CA845FEABD454085ECBC8DCD1E4C40
61541	7	68	\N	9699	19531	\N	56.222606938100903	"Нижегородская область, город Дзержинск, ул.Удриса, 8, МОУ ""Гимназия №38"""	Россия, Нижегородская область, Дзержинск, улица Рудольфа Удриса	0101000020E6100000B5C4CA68E4B345402B6EDC627E1C4C40
61533	7	68	\N	9699	19706	\N	56.227699999999999	"Нижегородская область, город Дзержинск, ул.Терешковой, 46А, МОУ ""СОШ №14"""		0101000020E6100000306475ABE7B645404CA60A46251D4C40
61518	7	68	\N	9699	19706	\N	56.228620999999997	"Нижегородская область, город Дзержинск, ул.Терешковой, 34, МОУ ""СОШ №9"""		0101000020E610000024287E8CB9B74540E316F373431D4C40
61545	7	68	\N	9699	19669	\N	56.230477	"Нижегородская область, город Дзержинск, ул.Строителей, 11а, МОУ ""СОШ №37"""		0101000020E6100000CBF5B6990AB3454077BD3445801D4C40
61542	7	68	\N	9699	19669	\N	56.232413999999999	"Нижегородская область, город Дзержинск, ул.Строителей, 8, МОУ ""СОШ №15"""		0101000020E6100000E4F90CA837B34540F790F0BDBF1D4C40
61502	7	68	\N	9699	19554	\N	56.255738000000001	"Нижегородская область, город Дзержинск, ул.Советская, 9Б, МОУ ""СОШ №3"""		0101000020E6100000FDBFEAC891BA4540172CD505BC204C40
61501	7	68	\N	9699	19554	\N	56.255606104342597	"Нижегородская область, город Дзержинск, ул.Советская, 9-б,  МОУ ""СОШ №3"""		0101000020E6100000E6CB0BB08FBA4540A85489B2B7204C40
61525	7	68	\N	9699	19628	\N	56.244140000000002	"Нижегородская область, город Дзержинск, ул.Самохвалова, 5А, МОУ ""СОШ №36"""		0101000020E610000041BAD8B452B645409ED2C1FA3F1F4C40
61507	7	68	\N	9699	19581	\N	56.250031999999997	Нижегородская область, город Дзержинск, Пожарского, 2, МОУ СОШ №32		0101000020E6100000A088450C3BB845400B7A6F0C01204C40
61506	7	68	\N	9699	19581	\N	56.250031999999997	Нижегородская область, город Дзержинск, Пожарского, 2, МОУ СОШ№ 32		0101000020E6100000A088450C3BB845400B7A6F0C01204C40
61498	7	68	\N	9699	19561	\N	56.251797000000003	"Нижегородская область, город Дзержинск, ул.Пирогова, 34-б,МОУ ""СОШ №70"""		0101000020E6100000FED478E926BD45408F1D54E23A204C40
60875	7	68	\N	6490	19801	\N	55.371889000000003	Нижегородская область, город Арзамас, 11 микрорайон, 51		0101000020E61000004B033FAA61EB4540FF5E0A0F9AAF4B40
61487	7	68	\N	9699	19580	\N	56.23545	Нижегородская область, город Дзержинск, ул.Октябрьская, 43-а, МОУ ДОД ДМШ №3		0101000020E6100000D13DEB1A2DBD4540EEEBC039231E4C40
61482	7	68	\N	9699	19580	\N	56.233989999999999	Нижегородская область, город Дзержинск, ул.Октябрьская, 52, МОУ СОШ №30		0101000020E610000001DF6DDE38BD4540A7CB6262F31D4C40
61485	7	68	\N	9699	2917	\N	56.229500398195697	"Нижегородская область, город Дзержинск, ул. Окская Набережная,26-а, МОУ ""СОШ №20"""		0101000020E6100000C4D155BABBBC45404C378941601D4C40
61484	7	68	\N	9699	2917	\N	56.229476493258304	"Нижегородская область, город Дзержинск, ул. Окская Набережная,26-а,  МОУ ""СОШ №20"""	Россия, Нижегородская область, Дзержинск, Окская набережная	0101000020E6100000BABF7ADCB7BC4540C39B35785F1D4C40
61481	7	68	\N	9699	2917	\N	56.231048000000001	"Нижегородская область, город Дзержинск, ул. Набережная Окская, 15, клуб ""Антей"""		0101000020E61000004CDE0033DFBD454032E719FB921D4C40
61492	7	68	\N	9699	19619	\N	56.244320000000002	"Нижегородская область, город Дзержинск, ул.Маяковского, 18, МОУ ""СОШ №5"""		0101000020E6100000FD32182312BB45401EE1B4E0451F4C40
61496	7	68	\N	9699	19622	\N	56.251587000000001	"Нижегородская область, город Дзержинск, ул. Матросова, 30Б, МОУ ""СОШ №68"""		0101000020E610000094DE37BEF6BA4540A48CB80034204C40
61495	7	68	\N	9699	19622	\N	56.251587000000001	"Нижегородская область, город Дзержинск, ул. Матросова, 30 б, МОУ ""СОШ №68"""		0101000020E610000094DE37BEF6BA4540A48CB80034204C40
61494	7	68	\N	9699	19622	\N	56.250202611709497	"Нижегородская область, город Дзержинск, ул.Матросова, 19, МОУ ""СОШ №7"""	Россия, Нижегородская область, Дзержинск, улица Матросова, 19	0101000020E61000008D0E48C2BEBB4540382EE3A606204C40
61524	7	68	\N	9699	19710	\N	56.241039000000001	"Нижегородская область, город Дзержинск, ул.Марковникова, 19, МОУ ""СОШ №24"""		0101000020E6100000299831056BB84540C007AF5DDA1E4C40
61509	7	68	\N	9699	19710	\N	56.241039000000001	Нижегородская область, город Дзержинск, Марковникова, 19, МОУ СОШ №24		0101000020E6100000299831056BB84540C007AF5DDA1E4C40
61547	7	68	\N	9699	19596	\N	56.231658000000003	"Нижегородская область, город Дзержинск, ул.Патоличева, 31, МОУ ""СОШ №21"""		0101000020E6100000FAD170CADCB04540ABED26F8A61D4C40
61546	7	68	\N	9699	19596	\N	56.232429000000003	"Нижегородская область, город Дзержинск, ул.Патоличева, 31а, МОУ ""СОШ №4"""		0101000020E61000008D09319754B145402DD2C43BC01D4C40
61504	7	68	\N	9699	19768	\N	56.242609000000002	Нижегородская область, город Дзержинск, ул.Кирова, 15,  МОУ ДОД ДМШ №1		0101000020E6100000A45181936DBA45408E5BCCCF0D1F4C40
61515	7	68	\N	9699	19687	\N	56.232458999999999	"Нижегородская область, город Дзержинск, Грибоедова, 31, ОАО ""НИИК"""		0101000020E61000008E01D9EBDDB9454097546D37C11D4C40
61514	7	68	\N	9699	19687	\N	56.241388999999998	"Нижегородская область, город Дзержинск, Грибоедова, 10, ГОУ СПО """"ДПК"""""""		0101000020E61000008FDE701FB9B945409C4EB2D5E51E4C40
61530	7	68	\N	9699	19555	\N	56.228701000000001	"Нижегородская область, город Дзержинск, ул.Галкина, 9, МОУ ""СОШ №17"""		0101000020E6100000B2D7BB3FDEB3454000C80913461D4C40
61522	7	68	\N	9699	19627	\N	56.236606000000002	Нижегородская область, город Дзержинск, ул.Гайдара, 49, ДПИ НГТУ		0101000020E610000047CA1649BBB74540C904FC1A491E4C40
61519	7	68	\N	9699	19627	\N	56.231192999999998	"Нижегородская область, город Дзержинск, ул.Гайдара, 74Б, МОУ ""СОШ №22"""		0101000020E61000009F1EDB32E0B84540350873BB971D4C40
61517	7	68	\N	9699	19627	\N	56.231192999999998	"Нижегородская область, город Дзержинск, ул.Гайдара, 74б, МОУ ""СОШ №22"""		0101000020E61000009F1EDB32E0B84540350873BB971D4C40
61512	7	68	\N	9699	19685	\N	56.240023000000001	Нижегородская область, город Дзержинск, Гагарина, 3, МОУ СОШ №2		0101000020E6100000DBC01DA853BA4540D7A4DB12B91E4C40
61488	7	68	\N	9699	19685	\N	56.240023000000001	"Нижегородская область, город Дзержинск, ул.Гагарина, 3, МОУ ""СОШ №2"""		0101000020E6100000DBC01DA853BA4540D7A4DB12B91E4C40
61479	7	68	\N	9699	17768	\N	56.239398000000001	Нижегородская область, город Дзержинск, р.п. Бабино, п. Петряевка, Встречная, 38а, детский сад №9п		0101000020E61000003E97A949F0BA4540295DFA97A41E4C40
61493	7	68	\N	9699	19681	\N	56.247495999999998	"Нижегородская область, город Дзержинск, ул.Ватутина, 54, МОУ ""СОШ №26"""		0101000020E610000089B663EAAEBA454006F2ECF2AD1F4C40
61491	7	68	\N	9699	19681	\N	56.245804999999997	Нижегородская область, город Дзержинск, ул.Ватутина, 19, ГОУ СПО ДПТ		0101000020E6100000E6CE4C309CBB4540BD18CA89761F4C40
61474	7	68	\N	9699	19681	\N	56.245804999999997	Нижегородская область, город Дзержинск, ул.Ватутина, 19, Политехнический техникум		0101000020E6100000E6CE4C309CBB4540BD18CA89761F4C40
61505	7	68	\N	9699	19624	\N	56.248093341446904	Нижегородская область, город Дзержинск, ул.Бутлерова, 38,  МОУ ДОД ДЮЦ		0101000020E61000001B9B1DA9BEB74540EAAEEC82C11F4C40
61529	7	68	\N	9699	19550	\N	56.234825000000001	"Нижегородская область, город Дзержинск, ул.Буденного, 19, МОУ ""СОШ №23"""		0101000020E610000018EB1B98DCB4454040A4DFBE0E1E4C40
61528	7	68	\N	9699	19550	\N	56.234825000000001	Нижегородская область, город Дзержинск, ул.Буденного, 19, корпус 2, МБОУ «СОШ №23»		0101000020E610000018EB1B98DCB4454040A4DFBE0E1E4C40
61523	7	68	\N	9699	19550	\N	56.240088	"Нижегородская область, город Дзержинск, ул.Буденного, 10А, МОУ ""СОШ №35"""		0101000020E6100000C1ABE5CE4CB64540BE141E34BB1E4C40
61388	7	68	\N	5618	\N	\N	56.639783000000001	Нижегородская область, Городецкий район, город Городец, ул. Фурманова, д. 13, школа № 7	Россия, Нижегородская область, Городец	0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61396	7	68	\N	5618	17568	\N	56.646176221246598	Нижегородская область, Городецкий район, город Городец, ул. Титова, д. 4, школа № 2 (спортзал)	Россия, Нижегородская область, Городец	0101000020E61000009087BEBB95BD4540E4BA29E5B5524C40
61393	7	68	\N	5618	17568	\N	56.646436296184703	Нижегородская область, Городецкий район, город Городец, ул. Титова, д. 4, школа № 2 (рекреация)	Россия, Нижегородская область, Городец	0101000020E6100000AA9CF6949CBD4540817A336ABE524C40
61399	7	68	\N	5618	17291	\N	56.6370310781043	Нижегородская область, Городецкий район, город Городец, ул. Свердлова, д. 17, школа № 1	Россия, Нижегородская область, Городец	0101000020E61000008124ECDB49BC4540E3C4573B8A514C40
61397	7	68	\N	5618	16698	\N	56.639783000000001	"Нижегородская область, Городецкий район, город Городец, ул. Новая, д. 50, ГУ ""Центр занятости населени"		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61386	7	68	\N	5618	16696	\N	56.639783000000001	Нижегородская область, Городецкий район, город Городец, ул. Нахимова, д. 10, школа № 4		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61394	7	68	\N	5618	18594	\N	56.639783000000001	Нижегородская область, Городецкий район, город Городец, ул. Набережная Революции, д. 5, Центр народных промыслов		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61400	7	68	\N	5618	17692	\N	56.623667009047303	Нижегородская область, Городецкий район, город Городец, ул. Механизаторов, д. 29, школа № 13	Россия, Нижегородская область, Городец	0101000020E6100000425F7AFB73BD4540164CFC51D44F4C40
61398	7	68	\N	5618	16691	\N	56.639783000000001	"Нижегородская область, Городецкий район, город Городец, ул. Мелиораторов, д. 18, Детский клуб ""Чайка"""		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61348	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, рабочий поселок Шиморское, с. Нижняя Верея, здание администрации	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61347	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, рабочий поселок Виля, с. Сноведь, школа	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61346	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, Новодмитриевский сельсовет, д. Покровка, Молодежная, 26, школа	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61342	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, Новодмитриевский сельсовет, с. Чупалейка, Специалистов, 1,  школа	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61341	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, Новодмитриевский сельсовет, д. Новая Деревня, здание администрации	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61339	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, рабочий поселок Виля, п. Виля, Московская, 1,  проволоченская школа	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61326	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, Туртапинский сельсовет, п. Дружба, м-н Дружба, 18,  школа	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61325	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, Туртапинский сельсовет, с. Туртапка, здание администрации	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61324	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, с. Мотмос, 40 лет Октября, 12а,  школа	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61322	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Красные Зори, 110,  контора горгаза	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61319	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, м-н Гоголя, 28/1,   школа 6	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61310	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, м-н Центральный, 11а,  школа 3	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61309	7	68	\N	138	\N	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Ленина, ДК Лепсе	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61303	7	68	\N	138	\N	\N	55.329242000000001	"Нижегородская область, город Выкса, город Выкса, м-н Жуковского, СК ""Металлург"""		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61306	7	68	\N	138	17194	\N	55.329186996629701	"Нижегородская область, город Выкса, город Выкса, м-.н Южный, ММДОУ  ""Ёлочка"""		0101000020E61000001E6D1CB11615454059A2B3CC22AA4B40
61321	7	68	\N	138	17635	\N	55.328813600237901	Нижегородская область, город Выкса , м-н Гоголя, д.21, МОУ ДОД  ДДК  ‘’Радуга ’’	Россия, Нижегородская область, Выкса	0101000020E610000064EB19C231154540C53BC09316AA4B40
61320	7	68	\N	138	17399	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, м-н Гоголя, 28/1,  школа 6		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61312	7	68	\N	138	17399	\N	55.325571679113203	"Нижегородская область, город Выкса, город Выкса, м-н Гоголя, 21, ДДК ""Радуга"""	Россия, Нижегородская область, Выкса	0101000020E61000005051F52B9D154540253FE257ACA94B40
61338	7	68	\N	138	17230	\N	55.329242000000001	Нижегородская область, город Выкса, рабочий поселок Виля, п. Виля, Школьный пер, 4,  школа		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61301	7	68	\N	138	19438	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Чкалова, 64,  общежитие ВМЗ		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61313	7	68	\N	138	17189	\N	55.328594931859101	Нижегородская область, город Выкса, город Выкса, Ульянова, 3,   ДДТ	Россия, Нижегородская область, Выкса	0101000020E6100000FAEFC16B971445408750A5660FAA4B40
33291	4	41	\N	16582	46255	\N	48.779257999999999	г. Биробиджан, Ленина, 40		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
61152	7	68	\N	138	17546	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Стахановская, 2, общежитие ВМЗ	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61308	7	68	\N	138	16732	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Слепнева, 19,  школа 10		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61317	7	68	\N	138	17199	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Романова, 1, ПУ 35		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61288	7	68	\N	138	17668	\N	55.329242000000001	"Нижегородская область, город Выкса, город Выкса, п. Строитель, МУ ""Молодежный центр"""		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61331	7	68	\N	138	17606	\N	55.316958172343	Нижегородская область, город Выкса, поселок Ближне-Песочное, Первомайская, 30а, школа 2	Россия, Нижегородская область, Выкса городской округ	0101000020E61000009128B4ACFB134540501A6A1492A84B40
61316	7	68	\N	138	16978	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Островского, 75,  школа 12		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61307	7	68	\N	138	16789	\N	55.329242000000001	Нижегородская область, город Выкса, ул.Новая, МОУ ДОД СюТУР	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61305	7	68	\N	138	17828	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Лепсе, 9  , металлургический  техникум		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61311	7	68	\N	138	16735	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Красные Зори, 26,  школа 8		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61238	7	68	\N	138	16702	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Гастелло, 68,  школа 4		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61314	7	68	\N	138	17354	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, Амбулаторная, 6,  школа 11		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61225	7	68	\N	138	16836	\N	55.329242000000001	"Нижегородская область, город Выкса, город Выкса, 1 Мая, клуб ""Факел"""		0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61304	7	68	\N	138	16793	\N	55.329242000000001	Нижегородская область, город Выкса, город Выкса, м-н Жуковского, 6/1,  школа 9	Россия, Нижегородская область, Выкса	0101000020E61000002B4F20EC141545401D3C139A24AA4B40
61468	7	68	\N	50053	19567	\N	56.3667008363485	"ОАО ""Борский водоканал"", Нижегородская область, город Бор, ул. Республиканская, д. 37а"		0101000020E6100000DAE6C6F4840946408B34F10EF02E4C40
61029	7	68	\N	50053	19563	\N	56.284881311037097	МБУК Октябрьский Дом культуры-музей .  Нижегородская область, город Бор, п. Октябрьский, ул. Октябрьская, д. 9а		0101000020E61000002FF7C951801846403A2009FB76244C40
62780	7	68	\N	50053	19743	\N	56.369295618352503	"МБОУ ДОД Дом детского творчества ""Каравелла"". Нижегородская область, город Бор, ул. Молодежная, д.4"		0101000020E610000072FDBB3E730A464095456117452F4C40
61032	7	68	\N	50053	77528	\N	56.347907723013797	ФОК поселка Октябрьский.  Нижегородская область, город Бор, п. Октябрьский, ул. Молодежня, д. 6	Россия	0101000020E61000006E4F90D8EE0A46402502D53F882C4C40
61023	7	68	\N	50053	19592	\N	56.354663217398297	МБОУ ДОД Детский сад № 25.  Нижегородская область, город Бор, ул. М. Горького, д. 70а		0101000020E6100000E2900DA48B094640F60CE198652D4C40
61002	7	68	\N	50053	19699	\N	56.3357013744345	Нижегородская область, город Бор, Коммунистическая ул, д. 11. МБОУ Лицей		0101000020E610000089F02F82C60E4640041E1840F82A4C40
61074	7	68	\N	50053	19535	\N	56.353144250393299	Нижегородская область, город Бор, ул. 8 Марта д. 13. МБОУ Средняя Общеобразовательная школа №4	Россия, Нижегородская область, Арзамас, улица 8 Марта, 9	0101000020E610000006F7031E180A4640AA6395D2332D4C40
61016	7	68	\N	40353	17444	\N	56.359647831760299	ГОУ СПО Нижегородский обл. колледж культуры.  Нижегородская область, город Бор, пер. Советский, д. 9		0101000020E610000029417FA147084640310917F2082E4C40
60999	7	68	\N	40353	16913	\N	56.362572591149899	Детская поликлиника городской больницы № 1. Нижегородская область, город Бор, ул. Энгельса, д.14		0101000020E6100000D82D02637D074640D0B4C4CA682E4C40
61011	7	68	\N	40353	16906	\N	56.361446450528298	ГОУ ДОД СДЮШОР по греко-римской борьбе. Нижегородская область, город Бор, ул. Фигнер, д. 2б		0101000020E6100000C1560916870B464090A2CEDC432E4C40
61010	7	68	\N	40353	16906	\N	56.359076625917098	МБОУ Основная общеобразовательная школа №5. Нижегородская область, город Бор, ул. Фигнер, д. 1		0101000020E6100000BA675DA3E50A464076DF313CF62D4C40
61012	7	68	\N	40353	16914	\N	56.356029584277103	МБОУ Средняя Общеобразовательная школа № 22. Нижегородская область, город Бор, ул. Суворова, д. 15		0101000020E610000084B872F6CE0A46408B321B64922D4C40
61073	7	68	\N	40353	17107	\N	56.355264644528503	"МБОУ ДОД ""Детская школа искусств"". Нижегородская область, город Бор, ул. Строительная, д. 12"		0101000020E610000072DF6A9DB80A4640EC34D252792D4C40
61006	7	68	\N	40353	16900	\N	56.364411009420699	"МБУК ""Стеклозаводский ДК"". Нижегородская область, город Бор, Стеклозаводское шоссе, д. 15"	Россия, Нижегородская область, Нижний Новгород, река Волга	0101000020E6100000D87E32C6870B4640BDA60705A52E4C40
61015	7	68	\N	40353	19444	\N	56.358671621064197	МБОУ средняя Общеобразовательная Школа №6.  Нижегородская область, город Бор, ул. Профсоюзная, д. 8а		0101000020E6100000DF15C1FF56084640D6FECEF6E82D4C40
61024	7	68	\N	40353	17675	\N	56.3639168998778	МБОУ Средняя Общеобразовательная Школа №1.  Нижегородская область, город Бор, ул. Плеханова, д. 1		0101000020E610000097AC8A7093074640AEBA0ED5942E4C40
61008	7	68	\N	40353	16759	\N	56.356282637361197	"МУК ""Борская межпоселенческая библиотека"". Нижегородская область, город Бор, ул. Первомайская, д. 9а"		0101000020E6100000FF209221C70A4640758F6CAE9A2D4C40
61467	7	68	\N	40353	17031	\N	56.355848378991297	МБОУ Средняя Общеобразовательная Школа №2, Нижегородская область, город Бор, ул. Октябрьская, д. 82		0101000020E6100000B3CEF8BEB80846406B2C616D8C2D4C40
61013	7	68	\N	40353	17031	\N	56.355979420188497	МБОУ Средняя Общеобразовательная Школа № 2. Нижегородская область, город Бор, ул. Октябрьская, д. 82		0101000020E6100000B3CEF8BEB8084640098849B8902D4C40
61009	7	68	\N	40353	19476	\N	56.358134368760297	"Нижегородская область, город Бор, ул. Нахимова, д. 33. МАУ  ""Управление благоустройства городского округа город Бор"""		0101000020E610000027F8A6E9B30B4640F7CABC55D72D4C40
61005	7	68	\N	40353	19474	\N	56.3441398660079	ГОУ СПО Борский стекольный индустриально-экономический техникум. Нижегородская область, город Бор, ул. Мира, д. 27	Россия, Нижегородская область, Нижний Новгород, улица Дунаева	0101000020E610000033FE7DC6850B46406B9F8EC70C2C4C40
61004	7	68	\N	40353	9911	\N	56.350389571603301	"Дом быта ""Ромашка"". Нижегородская область, город Бор, ул. Махалова, д. 3"		0101000020E6100000941799805F0B4640376C5B94D92C4C40
61003	7	68	\N	40353	9911	\N	56.348610070409002	МБОУ Борский межшкольный учебный комбинат. Нижегородская область, город Бор, ул. Махалова, д. 8	Россия, Нижегородская область, Пильнинский район	0101000020E6100000C2F7FE06ED0B46407F87A2409F2C4C40
61056	7	68	\N	40353	17146	\N	56.349197444408397	МБОУ Средняя Общеобразовательная Школа № 11.  Нижегородская область, город Бор, ул.Лермонтова, д. 2		0101000020E61000001A355F251F0D46403F6EBF7CB22C4C40
61007	7	68	\N	40353	17146	\N	56.349293415429997	МБОУ Средняя Общеобразовательная Школа № 11. Нижегородская область, город Бор, ул. Лермонтова, д. 2		0101000020E6100000C0E95DBC1F0D464062DC0DA2B52C4C40
61014	7	68	\N	40353	16915	\N	56.358179690701597	"МУК ""Культурный центр ""Теплоход"". Нижегородская область, город Бор, ул. Ленина, д. 152"		0101000020E6100000B5C6A01342074640670A9DD7D82D4C40
61026	7	68	\N	40353	16904	\N	56.333486764208601	Борский психоневрологический интернат.  Нижегородская область, город Бор, ул. Коммунистическая, д. 28		0101000020E6100000AE81AD122C1046401152B7B3AF2A4C40
61019	7	68	\N	40353	16744	\N	56.359379818358498	"ОАО ""Борский Автозавод"".  Нижегородская область, город Бор, ул. Кольцова, д. 16"		0101000020E6100000639CBF09850A4640126BF129002E4C40
61469	7	68	\N	40353	16909	\N	56.364260715916501	"ЗАО ""Борская ДПМК"". Нижегородская область, город Бор, ул. Интернациональная, д. 135а"		0101000020E6100000F486FBC8AD094640A81ABD1AA02E4C40
61018	7	68	\N	40353	16909	\N	56.361417416255698	"МБУК Центр культуры ""Октябрь"".  Нижегородская область, город Бор, ул. Интернациональная, д. 26"		0101000020E6100000F5D72B2CB8074640F69B89E9422E4C40
61020	7	68	\N	40353	16905	\N	56.365579470452303	МОУ Открытая (сменная) общеобразовательная школа.  Нижегородская область, город Бор, ул. Воровского, д. 73		0101000020E61000000664AF777F0846405C8DEC4ACB2E4C40
61022	7	68	\N	40353	16903	\N	56.357492317625201	МБОУ Средняя Общеобразовательная Школа №3.  Нижегородская область, город Бор, ул. Ванеева, д. 43а		0101000020E61000006077BAF3C4074640734A404CC22D4C40
61021	7	68	\N	40353	16903	\N	56.357504229964299	Средняя общеобразовательная школа №3.  Нижегородская область, город Бор, ул. Ванеева, д. 43а		0101000020E6100000376E313F370A46403718EAB0C22D4C40
61017	7	68	\N	40353	19527	\N	56.360029747589202	Нижегородская область, город Бор, ул. 8 Марта, д. 13. МБОУ Средняя Общеобразовательная школа №4		0101000020E6100000956247E35007464019CA8976152E4C40
61001	7	68	\N	40353	17052	\N	56.350897705959397	"МБОУ ДОД ЦВР ""Маяк"". Нижегородская область, город Бор, 2 микрорайон, д. 24"		0101000020E61000004128EFE3680A4640AC1DC539EA2C4C40
61000	7	68	\N	40353	17038	\N	56.358687906958501	МБОУ Средняя общеобразовательная школа №8. Нижегородская область, город Бор, 2 микрорайон, д. 8		0101000020E6100000B5A679C7290A4640DCBB067DE92D4C40
60911	7	68	\N	40353	17038	\N	56.3446812263618	Библиотека. Нижегородская область, город Бор, 2 микрорайон, д. 43		0101000020E6100000CDCEA2772A104640BB46CB811E2C4C40
60923	7	68	\N	14518	\N	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Чернышевского, 51	Россия, Нижегородская область, Богородск	0101000020E61000004981053065C24540B0AC3429050D4C40
60919	7	68	\N	14518	\N	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Свердлова, 3	Россия, Нижегородская область, Богородск	0101000020E61000004981053065C24540B0AC3429050D4C40
60914	7	68	\N	14518	\N	\N	56.10172	Нижегородская область, Богородский район, город Богородск, пер. Маяковского, 1	Россия, Нижегородская область, Богородск	0101000020E61000004981053065C24540B0AC3429050D4C40
60912	7	68	\N	14518	\N	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Ленина, 222	Россия, Нижегородская область, Богородск	0101000020E61000004981053065C24540B0AC3429050D4C40
60932	7	68	\N	14518	17581	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Механизаторов, 7а	Россия, Нижегородская область, Богородск	0101000020E61000004981053065C24540B0AC3429050D4C40
60916	7	68	\N	14518	17171	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Героя Усилова, 1		0101000020E61000004981053065C24540B0AC3429050D4C40
60892	7	68	\N	49824	17652	\N	56.515173206667903	Нижегородская область, Балахнинский район, город Балахна, ул. 40 лет Пионерской организации, д.16, Школа №14	Россия, Нижегородская область, Балахнинский район, поселок Правдинск	0101000020E61000002E71E481C8C645401F645930F1414C40
60853	7	68	\N	6490	3323	\N	55.406551853234703	Нижегородская область, город Арзамас, Парковая, 16/1	Россия, Нижегородская область, Арзамас, улица Парковая, 16к1	0101000020E610000074ECA012D7E94540CB0F5CE509B44B40
60873	7	68	\N	6490	19808	\N	55.376241999999998	Нижегородская область, город Арзамас, 11 микрорайон, 11		0101000020E610000049D6E1E82AEB4540D9B0A6B228B04B40
60845	7	68	\N	6490	3184	\N	55.407294999999998	Нижегородская область, город Арзамас, Мира, 1	Россия, Нижегородская область, Арзамас, улица Мира, 1	0101000020E6100000B20DDC813AEB45408369183E22B44B40
60844	7	68	\N	6490	3184	\N	55.409196000000001	Нижегородская область, город Арзамас, Мира, 19/3		0101000020E6100000D5B2B5BE48EC4540B7D3D68860B44B40
60843	7	68	\N	6490	3184	\N	55.409098999999998	Нижегородская область, город Арзамас, Мира, 19/2	Россия, Нижегородская область, Арзамас, улица Мира, 19к2	0101000020E6100000874F3A9160EC4540C4E9245B5DB44B40
60841	7	68	\N	6490	3064	\N	55.406354	Нижегородская область, город Арзамас, 9 мая, 29	Россия, Нижегородская область, Арзамас, улица 9 Мая, 29а	0101000020E610000009E1D1C611ED4540A54C6A6803B44B40
60862	7	68	\N	6490	3260	\N	55.394621999999998	Нижегородская область, город Арзамас, Проспект Ленина, 101	Россия, Нижегородская область, Арзамас, проспект Ленина, 101	0101000020E61000001F1329CDE6E945401C2444F982B24B40
60850	7	68	\N	6490	3260	\N	55.402214000000001	Нижегородская область, город Арзамас, Проспект Ленина, 200	Россия, Нижегородская область, Арзамас, проспект Ленина, 200	0101000020E6100000C89A9141EEEA454026FF93BF7BB34B40
60849	7	68	\N	6490	3260	\N	55.404260968041498	Нижегородская область, город Арзамас, Проспект Ленина, 206А		0101000020E610000067800BB265EB45402D060FD3BEB34B40
60866	7	68	\N	6490	3487	\N	55.385565999999997	Нижегородская область, город Арзамас, Площадь Соборная, 7	Россия, Нижегородская область, Арзамас, площадь Соборная, 7	0101000020E61000006B2A8BC22EE845408A39083A5AB14B40
60874	7	68	\N	6490	19530	\N	55.376049364112703	Нижегородская область, город Арзамас, Микрорайон Кирилловский, улица Центральная, 4	Россия, Нижегородская область, Арзамас, Кирилловский микрорайон, 7-я линия, 4	0101000020E6100000035E66D828F34540C558A65F22B04B40
60869	7	68	\N	6490	19646	\N	55.384554000000001	Нижегородская область, город Арзамас, Урицкого, 15		0101000020E6100000E94482A966E84540E3C5C21039B14B40
60840	7	68	\N	6490	19696	\N	55.409875999999997	Нижегородская область, город Арзамас, Семашко, 21		0101000020E61000005D52B5DD04E7454028B517D176B44B40
60851	7	68	\N	6490	19701	\N	55.399330999999997	Нижегородская область, город Арзамас, Севастопольская, 15		0101000020E6100000CBF44BC45BEB4540B5A338471DB34B40
60864	7	68	\N	6490	19779	\N	55.393768000000001	Нижегородская область, город Арзамас, Свободы, 9		0101000020E6100000AC5791D101E945400D1B65FD66B24B40
60867	7	68	\N	6490	78479	\N	55.391872883203703	Нижегородская область, город Арзамас, Пушкина, 138/1	Россия, Нижегородская область, Арзамас, улица Пушкина, 138	0101000020E61000003E07962364EA4540BB97FBE428B24B40
60858	7	68	\N	6490	19702	\N	55.402372	Нижегородская область, город Арзамас, Пландина, 25		0101000020E61000000186E5CFB7E74540BE69FAEC80B34B40
60855	7	68	\N	6490	19560	\N	55.405506000000003	Нижегородская область, город Арзамас, Парковая, 18		0101000020E6100000EF71A609DBE94540782AE09EE7B34B40
60854	7	68	\N	6490	19560	\N	55.405337000000003	Нижегородская область, город Арзамас, Парковая, 16		0101000020E6100000E1B20A9B01EA4540EC6D3315E2B34B40
60848	7	68	\N	6490	19576	\N	55.402640851965302	Нижегородская область, город Арзамас, Нижегородская, 3А	Россия, Нижегородская область, Арзамас, Нижегородская улица, 3	0101000020E6100000B3B45373B9EB4540AE8383BD89B34B40
60842	7	68	\N	6490	19552	\N	55.409011999999997	Нижегородская область, город Арзамас, Мира, 19/1		0101000020E6100000B70DA32078EC4540F5D555815AB44B40
60868	7	68	\N	6490	19500	\N	55.387371999999999	Нижегородская область, город Арзамас, Максима Горького, 56		0101000020E610000059A31EA2D1E945406CB1DB6795B14B40
60865	7	68	\N	6490	19500	\N	55.390540241823103	Нижегородская область, город Арзамас, Горького, 25	Россия, Нижегородская область, Арзамас, улица Максима Горького, 23	0101000020E6100000ED48F59D5FE84540D2E3F736FDB14B40
60870	7	68	\N	6490	19682	\N	55.380313999999998	Нижегородская область, город Арзамас, ул.Ленина, 99		0101000020E61000000491459A78EB4540001B1021AEB04B40
60837	7	68	\N	6490	19800	\N	55.415998000000002	Нижегородская область, город Арзамас, Красный Путь, 40		0101000020E61000007EAA0A0DC4EC4540C899266C3FB54B40
60863	7	68	\N	6490	19778	\N	55.392632999999996	Нижегородская область, город Арзамас, Карла Маркса, 36		0101000020E61000001899805F23E94540492A53CC41B24B40
60860	7	68	\N	6490	19559	\N	55.398400000000002	Нижегородская область, город Арзамас, Калинина, 29		0101000020E610000015E5D2F885E94540FB5C6DC5FEB24B40
60859	7	68	\N	6490	19559	\N	55.399355199815403	Нижегородская область, город Арзамас, Калинина, 13/А		0101000020E61000004A46CEC29EE845403E3F8C101EB34B40
60852	7	68	\N	6490	19559	\N	55.396473	Нижегородская область, город Арзамас, Калинина, 41/1		0101000020E610000042959A3DD0EA45409E5F94A0BFB24B40
60839	7	68	\N	6490	19709	\N	55.417219000000003	Нижегородская область, город Арзамас, Зеленая, 18		0101000020E6100000DEE34C13B6E745408A22A46E67B54B40
60838	7	68	\N	6490	19709	\N	55.419339999999998	Нижегородская область, город Арзамас, Зеленая, 34		0101000020E61000003BC6151747E74540CBF3E0EEACB54B40
60857	7	68	\N	6490	19648	\N	55.400762	Нижегородская область, город Арзамас, Жуковского, 2		0101000020E6100000C808A87004E9454062BD512B4CB34B40
60856	7	68	\N	6490	19648	\N	55.404591000000003	Нижегородская область, город Арзамас, Жуковского, 8		0101000020E61000002194F77134E94540C3A04CA3C9B34B40
60871	7	68	\N	6490	19751	\N	55.372881999999997	Нижегородская область, город Арзамас, Володарского, 80		0101000020E610000081D07AF832E945402FA2ED98BAAF4B40
60872	7	68	\N	6490	19565	\N	55.375350420730598	Нижегородская область, город Арзамас, Вахтерова, 18/4	Россия, Нижегородская область, Арзамас, 4-й Южный переулок, 18к4	0101000020E61000007097FDBAD3E94540DC4603780BB04B40
60847	7	68	\N	6490	19605	\N	55.400578000000003	Нижегородская область, город Арзамас, 9 мая, 7		0101000020E610000043041C4295EC4540A1BFD02346B34B40
60846	7	68	\N	6490	19605	\N	55.401083999999997	Нижегородская область, город Арзамас, 9 мая, 6		0101000020E6100000CD1DFD2FD7EC4540747973B856B34B40
60833	7	68	\N	6490	19605	\N	55.397277700351999	Нижегородская область, город Арзамас, 9 мая, 2	Россия, Нижегородская область, Арзамас, улица 9 Мая, 2к2	0101000020E61000001CD2A8C0C9EC4540CCB56801DAB24B40
60861	7	68	\N	6490	19548	\N	55.398758000000001	Нижегородская область, город Арзамас, 1 Мая, 53А		0101000020E61000006E3480B740E845405A828C800AB34B40
62759	7	68	933	8387	\N	\N	57.633454999999998	Нижегородская область, Шахунский район, Акатовский сельсовет, д. Щербаж, ул. 8-ое  Марта, д. 24-а, Щербажский сельский клуб	Россия, Нижегородская область, Шахунский район, село Щербаж	0101000020E6100000378B170B436647406C3EAE0D15D14C40
62741	7	68	933	7520	\N	\N	57.669434000000003	"Нижегородская область, Шахунский район, город Шахунья, ул. Советская, д.15, МОУ ""Шахунская СОШ"""	Россия, Нижегородская область, Шахунский район, Шахунья	0101000020E6100000C79FA86C584F47404D6A6803B0D54C40
62745	7	68	933	7520	16767	\N	57.669434000000003	"Нижегородская область, Шахунский район, город Шахунья, ул. Черняховского, д. 16, КРЦ ""Прогресс"""		0101000020E6100000C79FA86C584F47404D6A6803B0D54C40
62743	7	68	933	7520	17700	\N	57.669434000000003	Нижегородская область, Шахунский район, город Шахунья, ул.Чапаева, д. 1, Шахунский Городской ДК		0101000020E6100000C79FA86C584F47404D6A6803B0D54C40
62742	7	68	933	7520	17846	\N	57.677797492256502	"Нижегородская область, Шахунский район, город Шахунья, ул.Советская, д. 37, здание ОАО ""НТК"""	Россия, Нижегородская область, Шахунский район, Шахунья	0101000020E6100000ED629AE95E4D4740D829560DC2D64C40
62746	7	68	933	7520	17123	\N	57.669434000000003	"Нижегородская область, Шахунский район, город Шахунья, ул. Пасхина, д. 4, ФСК ""Надежда"""		0101000020E6100000C79FA86C584F47404D6A6803B0D54C40
62749	7	68	933	7520	16814	\N	57.669434000000003	Нижегородская область, Шахунский район, город Шахунья, ул. Ленина, д. 124, Шахунский центр образования		0101000020E6100000C79FA86C584F47404D6A6803B0D54C40
62748	7	68	933	7520	16814	\N	57.669434000000003	"Нижегородская область, Шахунский район, город Шахунья, ул. Ленина, д. 100, МОУ ""Шахунская СОШ №2"""		0101000020E6100000C79FA86C584F47404D6A6803B0D54C40
62747	7	68	933	7520	17126	\N	57.669434000000003	Нижегородская область, Шахунский район, город Шахунья, ул. Комсомольская, д. 5, МОУ гимназия им. А.С. Пушкина		0101000020E6100000C79FA86C584F47404D6A6803B0D54C40
62744	7	68	933	7520	17126	\N	57.674159112988299	"Нижегородская область, Шахунский район, город Шахунья, ул. Комсомольская, д. 27, МОУ ""Шахунская СОШ № 14"""	Россия, Нижегородская область, Шахунский район, Шахунья	0101000020E6100000FE9AAC510F4F4740ECA694D74AD64C40
62771	7	68	933	8916	17721	\N	57.534357	Нижегородская область, Шахунский район, Лужайский сельсовет, с. Черное, ул. Октябрьская, д.18, здание администрации		0101000020E61000001E6B4606B9334740C0B167CF65C44C40
62764	7	68	933	8635	\N	\N	57.746003000000002	Нижегородская область, Шахунский район, Хмелевицкий сельсовет, с. Хмелевицы, ул. Центральная, д. 40, сельский Дом Культуры	Россия, Нижегородская область, Шахунский район, село Хмелевицы	0101000020E610000056D3F544D72F4740E4DBBB067DDF4C40
62772	7	68	933	49638	16738	\N	57.715643	Нижегородская область, Шахунский район, Туманинский сельсовет, д. Туманино, ул. Молодежная, д. 21, сельский Дом культуры		0101000020E610000068EA758BC04E4740404E98309ADB4C40
62755	7	68	933	8135	16705	\N	58.020223000000001	"Нижегородская область, Шахунский район, поселок Сява, ул. Просвещения, д.4-а, МОУ ""Сявская СОШ"""		0101000020E610000012A5BDC1172A474042D0D1AA96024D40
62754	7	68	933	8135	17708	\N	58.020223000000001	Нижегородская область, Шахунский район, поселок Сява, ул. Ленина, д. 17, Сявский МП ДК		0101000020E610000012A5BDC1172A474042D0D1AA96024D40
62770	7	68	933	8893	\N	\N	57.691305	Нижегородская область, Шахунский район, Лужайский сельсовет, д. Никитиха, ул. Центральная, д. 74, здание администрации	Россия, Нижегородская область, Шахунский район, село Никитиха	0101000020E6100000DAE4F04927104740D847A7AE7CD84C40
62757	7	68	933	8298	17520	\N	57.641471000000003	Нижегородская область, Шахунский район, Акатовский сельсовет, д. Мелешиха, ул. Молодежная, д. 2-а, МС ДК		0101000020E610000065FF3C0D185047408D2AC3B81BD24C40
62758	7	68	933	8350	\N	\N	57.593170999999998	Нижегородская область, Шахунский район, Акатовский сельсовет, д. Мартяхино, ул. Школьная, д. 12	Россия, Нижегородская область, Шахунский район, село Мартяхино	0101000020E610000069A9BC1DE1604740C2F7FE06EDCB4C40
62765	7	68	933	8692	16690	\N	57.622540000000001	"Нижегородская область, Шахунский район, Хмелевицкий сельсовет, д. Малиновка, ул.Новая, д. 1-а, МДОУ ""Малиновский д/с"""		0101000020E6100000D8B628B341324740D6390664AFCF4C40
62769	7	68	933	8860	\N	\N	57.664659	Нижегородская область, Шахунский район, Лужайский сельсовет, п. Лужайки, ул. Школьная, д. 1-б, здание администрации	Россия, Нижегородская область, Шахунский район, село Лужайки	0101000020E61000002A560DC2DC444740FCFECD8B13D54C40
62766	7	68	933	8726	17420	\N	57.757370000000002	Нижегородская область, Шахунский район, Красногорский сельсовет, д. Красногор, ул. Центральная, д. 11, сельский Дом культуры		0101000020E6100000C971A774B02647405B7C0A80F1E04C40
60944	7	68	933	16037	17588	\N	57.642006000000002	Нижегородская область, Богородский район, Каменский сельсовет, п. Комсомольский, Поелвая, 7		0101000020E61000004FE8F527F12F4740FBEAAA402DD24C40
62763	7	68	933	8563	17332	\N	57.897085046986902	Нижегородская область, Шахунский район, Хмелевицкий сельсовет, с. Верховское, ул. Центральная, д. 5, здание администрации	Россия, Нижегородская область, Шахунский район, село Верховское	0101000020E6100000363E93FDF3304740B75D68AED3F24C40
62752	7	68	933	7914	17061	\N	57.964410000000001	"Нижегородская область, Шахунский район, поселок Вахтан, ул. Ленина, д. 12, МОУ ""Вахтанская СОШ"""	Россия, Нижегородская область, Шахунский район, поселок Вахтан	0101000020E610000078F17EDC7E574740BAF770C971FB4C40
62750	7	68	933	7914	17061	\N	57.964410000000001	"Нижегородская область, Шахунский район, поселок Вахтан, ул. Ленина, д. 17, МДОУ Вахтанский д/с ""Елочка"""	Россия, Нижегородская область, Шахунский район, поселок Вахтан	0101000020E610000078F17EDC7E574740BAF770C971FB4C40
62753	7	68	933	7914	17129	\N	57.964410000000001	Нижегородская область, Шахунский район, поселок Вахтан, ул. Карповская, д.35-а, МОУ ДОД Вахтанский ДЮЦ	Россия, Нижегородская область, Шахунский район, поселок Вахтан	0101000020E610000078F17EDC7E574740BAF770C971FB4C40
62751	7	68	933	7914	17129	\N	57.964410000000001	Нижегородская область, Шахунский район, п. Вахтан, улица Карповская, дом 20-а, Муниципальный поселковый Вахтанский Дворец культуры		0101000020E610000078F17EDC7E574740BAF770C971FB4C40
62768	7	68	933	8814	17472	\N	57.633232999999997	Нижегородская область, Шахунский район, Лужайский сельсовет, с. Большое Широкое, ул. Широковская, д. 10, здание администрации		0101000020E6100000EF3B86C77E1A4740BDDF68C70DD14C40
62761	7	68	933	8492	17330	\N	57.701684	"Нижегородская область, Шахунский район, Хмелевицкий сельсовет, д. Большая Свеча, ул. Школьная, д. 8, МОУ ""Большесвечанская ООШ"""		0101000020E6100000D2FD9C82FC244740301004C8D0D94C40
62760	7	68	933	8445	\N	\N	57.757322000000002	Нижегородская область, Шахунский район, Хмелевицкий сельсовет, д. Большая Музя, ул. Центральная, д. 35 -а, сельский Дом Культуры	Россия, Нижегородская область, Шахунский район, село Большая Музя	0101000020E6100000B1DF13EB543947404A4563EDEFE04C40
62767	7	68	933	8742	17525	\N	57.741588	"Нижегородская область, Шахунский район, Красногорский сельсовет, д. Андрианово, ул. Школьная, д. 2, МОУ ""Хмелевицкая СОШ"""		0101000020E610000040DD408177184740938D075BECDE4C40
62756	7	68	933	8221	18284	\N	57.602735000000003	Нижегородская область, Шахунский район, Акатовский сельсовет, д. Акаты, ул. Новая, д. 10, здание администрации	Россия, Нижегородская область, Шахунский район, село Акаты	0101000020E6100000F2423A3C84454740C993A46B26CD4C40
62719	7	68	828	50059	19558	\N	55.207915999999997	Нижегородская область, Шатковский район, Архангельский сельсовет, п. Светлогорск, ул.Ленина, д.4, здание администрации сельсовета	Россия, Нижегородская область, Шатковский район	0101000020E610000066FA25E2AD2746405628D2FD9C9A4B40
62736	7	68	828	7305	17312	\N	55.248919000000001	Нижегородская область, Шатковский район, Смирновский сельсовет, с. Языково, ул.Мира, д.11, Дом культуры		0101000020E61000000BEF7211DF4D4640302DEA93DC9F4B40
62711	7	68	828	5962	17097	\N	55.185281000000003	Нижегородская область, Шатковский район, поселок Шатки, ул.Центральная, д.22		0101000020E6100000CBF8F71917104640FCC8AD49B7974B40
62710	7	68	828	5962	17101	\N	55.185281000000003	Нижегородская область, Шатковский район, поселок Шатки, Ленина, 142	Россия, Нижегородская область, Шатковский район, поселок Шатки	0101000020E6100000CBF8F71917104640FCC8AD49B7974B40
62709	7	68	828	5962	17678	\N	55.185281000000003	Нижегородская область, Шатковский район, поселок Шатки, Железнодорожная, 27		0101000020E6100000CBF8F71917104640FCC8AD49B7974B40
62712	7	68	828	5962	17286	\N	55.185281000000003	Нижегородская область, Шатковский район, поселок Шатки, 1 Микрорайон, д.12		0101000020E6100000CBF8F71917104640FCC8AD49B7974B40
62713	7	68	828	5962	17491	\N	55.185281000000003	Нижегородская область, Шатковский район, поселок Шатки, 1 Мая, д.1		0101000020E6100000CBF8F71917104640FCC8AD49B7974B40
62735	7	68	828	7238	17727	\N	55.270913	Нижегородская область, Шатковский район, Смирновский сельсовет, с. Шарапово, ул.Центральная, д.24, школа		0101000020E61000001C261AA4E05B4640D787F546ADA24B40
62737	7	68	828	7330	\N	\N	55.284579000000001	Нижегородская область, Шатковский район, Староиванцевский сельсовет, д. Чапары, ул.Мира, д.80, Дом культуры	Россия, Нижегородская область, Шатковский район, село Чапары	0101000020E6100000D8F50B76C35446406F10AD156DA44B40
62733	7	68	828	7135	\N	\N	55.228119999999997	Нижегородская область, Шатковский район, Силинский сельсовет, с. Старое Иванцево, 1 Микрорайон, д.9, школа	Россия, Нижегородская область, Шатковский район, село Старое Иванцево	0101000020E61000007D5D86FF7449464021C84109339D4B40
62723	7	68	828	6674	17488	\N	55.218040000000002	Нижегородская область, Шатковский район, Кержемокский сельсовет, с. Спасское,  ул. 60 лет Октября д.4,  Дом культуры		0101000020E6100000075F984C152C4640249C16BCE89B4B40
62732	7	68	828	7124	\N	\N	55.312337999999997	Нижегородская область, Шатковский район, Силинский сельсовет, с. Смирново, ул.Советская,48, Дом культуры	Россия, Нижегородская область, Шатковский район, село Смирново	0101000020E61000007616BD530133464026A60BB1FAA74B40
62729	7	68	828	6938	17512	\N	55.101370000000003	Нижегородская область, Шатковский район, Красноборский сельсовет, с. Силино, ул.Советская, д.48, Дом культуры		0101000020E610000013471E882C2C4640D46531B1F98C4B40
62716	7	68	828	49777	17310	\N	55.118240520544099	Нижегородская область, Шатковский район, поселок Лесогорск, с. Понетаевка, ул.Советская, 40, административное здание	Россия, Нижегородская область, Шатковский район, село Понетаевка	0101000020E6100000809C306134F14540EE056685228F4B40
62728	7	68	828	6923	17120	\N	55.243721000000001	Нижегородская область, Шатковский район, Костянский сельсовет, с. Пасьяново, ул.Молодёжная. д.50, Дом культуры		0101000020E6100000D45FAFB0E0064640992CEE3F329F4B40
62721	7	68	828	6588	17041	\N	55.214815000000002	Нижегородская область, Шатковский район, Светлогорский сельсовет, с. Паново, ул. Советская, д.24, школа		0101000020E6100000250516C094F345405AD8D30E7F9B4B40
62730	7	68	828	7011	17326	\N	55.114522999999998	Нижегородская область, Шатковский район, Красноборский сельсовет, с. Новое, ул.Коммунистическая, д.29, клуб		0101000020E6100000FC71FBE593234640E5D18DB0A88E4B40
62715	7	68	828	6261	17686	\N	55.096245000000003	Нижегородская область, Шатковский район, поселок Лесогорск, Электриков, 4		0101000020E610000044DE72F563F74540A7B393C1518C4B40
62727	7	68	828	50044	19509	\N	55.267095444763903	Нижегородская область, Шатковский район, Костянский сельсовет, с. Красный Бор, ул.Молодёжная, д.7, Дом культуры	Россия, Нижегородская область, Шатковский район, село Красный Бор	0101000020E6100000DD3F16A243FE45406AF6402B30A24B40
62724	7	68	828	6742	16757	\N	55.305045999999997	Нижегородская область, Шатковский район, Кержемокский сельсовет, с. Костянка, ул.Школьная, д.1, школа		0101000020E6100000D4EFC2D66C3D464047E350BF0BA74B40
62717	7	68	828	49832	17691	\N	55.111052000000001	Нижегородская область, Шатковский район, поселок Лесогорск, с. Ключищи, Центральная, 54	Россия, Нижегородская область, Шатковский район, село Ключищи	0101000020E61000009E7B0F971CFF4540E413B2F3368E4B40
62722	7	68	828	6649	\N	\N	55.211295999999997	Нижегородская область, Шатковский район, Светлогорский сельсовет, с. Кержемок, ул.1 Мая, д.21А, Дом культуры	Россия, Нижегородская область, Шатковский район, село Кержемок	0101000020E610000056BB26A4351C464047E350BF0B9B4B40
62731	7	68	828	7066	\N	\N	55.065689999999996	Нижегородская область, Шатковский район, Силинский сельсовет, с. Калапино, ул.Молодёжная, д.29, здание школы	Россия, Нижегородская область, Шатковский район, село Калапино	0101000020E6100000C3F17C06D41946404DD6A88768884B40
62720	7	68	828	6514	\N	\N	55.150108000000003	Нижегородская область, Шатковский район, Светлогорский сельсовет, с. Елховка, ул. Советская,10, Дом культуры	Россия, Нижегородская область, Шатковский район, село Елховка	0101000020E6100000378E588B4FF945401A6F2BBD36934B40
62739	7	68	828	7418	\N	\N	55.316656999999999	Нижегородская область, Шатковский район, Староиванцевский сельсовет, с. Выползово, ул.Молодёжная, д.14, Дом культуры	Россия, Нижегородская область, Шатковский район, село Выползово	0101000020E61000003FAA61BF276446405586713788A84B40
62734	7	68	828	7205	16714	\N	55.255907999999998	Нижегородская область, Шатковский район, Смирновский сельсовет, с. Великий Враг, ул.Учительская, д.2, школа		0101000020E61000009B73F04C684246407364E597C1A04B40
62725	7	68	828	6790	17070	\N	55.333523	Нижегородская область, Шатковский район, Костянский сельсовет, с. Большие Печерки, ул.Центральная, д.61, школа		0101000020E6100000EC6CC83F334E46405EBBB4E1B0AA4B40
62718	7	68	828	6427	\N	\N	55.219498999999999	Нижегородская область, Шатковский район, Архангельский сельсовет, с. Архангельское, Центральная, 98	Россия, Нижегородская область, Шатковский район, село Архангельское	0101000020E6100000FC523F6F2A0C46409A40118B189C4B40
62693	7	68	689	5067	16988	\N	57.323283000000004	Нижегородская область, Шарангский район, Щенниковский сельсовет, с. Щенники, Центральная, 29		0101000020E61000002C0E677E35534740282D5C5661A94C40
62705	7	68	689	5746	\N	\N	56.983362	Нижегородская область, Шарангский район, Старорудкинский сельсовет, д. Щекотово, 45		0101000020E61000008CF337A110494740881057CEDE7D4C40
62690	7	68	689	4903	\N	\N	57.173752	Нижегородская область, Шарангский район, поселок Шаранга, Ленина, 21	Россия, Нижегородская область, Шарангский район, поселок Шаранга	0101000020E6100000D61EF64201454740ABCE6A813D964C40
62691	7	68	689	4903	17407	\N	57.173752	Нижегородская область, Шарангский район, поселок Шаранга, Парковая, 2		0101000020E6100000D61EF64201454740ABCE6A813D964C40
62689	7	68	689	4903	17454	\N	57.173752	Нижегородская область, Шарангский район, поселок Шаранга, Ленина, 19		0101000020E6100000D61EF64201454740ABCE6A813D964C40
62697	7	68	689	4903	17667	\N	57.173752	Нижегородская область, Шарангский район, р.п. Шаранга, ул.Большевиков, д. 22, здание детской школы искусств		0101000020E6100000D61EF64201454740ABCE6A813D964C40
62706	7	68	689	5795	\N	\N	57.121896999999997	Нижегородская область, Шарангский район, Черномужский сельсовет, д. Черномуж, Колхозная, 1	Россия, Нижегородская область, Шарангский район, село Черномуж	0101000020E610000029779FE3A33D4740813D26529A8F4C40
62707	7	68	689	5816	17445	\N	57.173762000000004	Нижегородская область, Шарангский район, Черномужский сельсовет, д. Туманка, Молодежная, 1		0101000020E610000098A59D9ACB3D4740CFA44DD53D964C40
62704	7	68	689	5691	17672	\N	56.964770000000001	Нижегородская область, Шарангский район, Старорудкинский сельсовет, с. Старая Рудка, Колхозная, 1	Россия, Нижегородская область, Шарангский район, село Старая Рудка	0101000020E61000002FE1D05B3C3E4740BA1457957D7B4C40
62701	7	68	689	5523	17482	\N	57.050238999999998	Нижегородская область, Шарангский район, Роженцовский сельсовет, с. Роженцово, Учительская, 8		0101000020E6100000C1C41F459D454740EBFD463B6E864C40
62700	7	68	689	5441	\N	\N	56.978492000000003	Нижегородская область, Шарангский район, Кушнурский сельсовет, д. Преображенка, 13		0101000020E61000005FD1ADD7F4604740E6B2D1393F7D4C40
62702	7	68	689	5548	\N	\N	57.024244000000003	Нижегородская область, Шарангский район, Роженцовский сельсовет, д. Поздеево, 67	Россия, Нижегородская область, Шарангский район, село Поздеево	0101000020E61000006BF0BE2A17404740E78F696D1A834C40
62696	7	68	689	5222	\N	\N	57.176343000000003	Нижегородская область, Шарангский район, Большерудкинский сельсовет, с. Пестово, Центральная, 36	Россия, Нижегородская область, Шарангский район, село Пестово	0101000020E6100000B9382A375157474074F04C6892964C40
62708	7	68	689	5903	18070	\N	57.135386932339301	"Нижегородская область, Шарангский район, Черномужский сельсовет, д. Мосуново, Колхозная, 1 ""а"""	Россия, Нижегородская область, Шарангский район, село Мосуново	0101000020E6100000D8D30E7F4D484740DBA6785C54914C40
62699	7	68	689	5412	\N	\N	57.007240000000003	Нижегородская область, Шарангский район, Кушнурский сельсовет, с. Кушнур, Центральная, 35	Россия, Нижегородская область, Шарангский район, село Кушнур	0101000020E6100000B64C86E3F95A47408D9C853DED804C40
62695	7	68	689	5205	17058	\N	57.236389000000003	Нижегородская область, Шарангский район, Большерудкинский сельсовет, с. Кугланур, Заречная, 21		0101000020E6100000062CB98AC55147402C11A8FE419E4C40
62703	7	68	689	5619	16937	\N	57.044780000000003	Нижегородская область, Шарангский район, Роженцовский сельсовет, п. Красная Горка, Центральная, 8		0101000020E6100000A22424D236324740E8C1DD59BB854C40
62687	7	68	689	4810	\N	\N	57.041024999999998	Нижегородская область, Шарангский район, Кушнурский сельсовет, д.Козлянур, 32		0101000020E61000001FDAC70A7E5B4740C1A8A44E40854C40
62692	7	68	689	5051	\N	\N	57.272826000000002	Нижегородская область, Шарангский район, Большеустинский сельсовет, с. Большое Устинское, Советская, 11	Россия, Нижегородская область, Шарангский район, село Большое Устинское	0101000020E6100000FCE42840143A4740CFBF5DF6EBA24C40
62698	7	68	689	5335	17743	\N	57.124637999999997	"Нижегородская область, Шарангский район, Большерудкинский сельсовет, с. Большая Рудка, Советская, 9 ""в"""		0101000020E61000006DE34F54365C47405FEB5223F48F4C40
62694	7	68	689	5159	17412	\N	57.274450999999999	Нижегородская область, Шарангский район, Щенниковский сельсовет, д. Астанчурга, Главная, 57		0101000020E61000002D5F97E13F51474060ADDA3521A34C40
62673	7	68	305	3827	\N	\N	56.765191999999999	Нижегородская область, Чкаловский район, город Чкаловск, Пушкина, 39	Россия, Нижегородская область, Чкаловский район, Чкаловск	0101000020E61000008F183DB7D09D45409694BBCFF1614C40
62674	7	68	305	3827	17024	\N	56.765191999999999	Нижегородская область, Чкаловский район, город Чкаловск, пл.Чкалова, здание ДКС		0101000020E61000008F183DB7D09D45409694BBCFF1614C40
62670	7	68	305	3827	17259	\N	56.769640672095903	Нижегородская область, Чкаловский район, город Чкаловск, Матросова, 23	Россия, Нижегородская область, Чкаловский район, Чкаловск	0101000020E6100000A0A696ADF59F45409354A69883624C40
62671	7	68	305	3827	16807	\N	56.765191999999999	Нижегородская область, Чкаловский район, город Чкаловск, Ломоносова, 59		0101000020E61000008F183DB7D09D45409694BBCFF1614C40
62672	7	68	305	3827	17240	\N	56.765191999999999	Нижегородская область, Чкаловский район, город Чкаловск, Комсомольская, 8		0101000020E61000008F183DB7D09D45409694BBCFF1614C40
62669	7	68	305	3827	17240	\N	56.765191999999999	Нижегородская область, Чкаловский район, город Чкаловск, Комсомольская, 15		0101000020E61000008F183DB7D09D45409694BBCFF1614C40
62676	7	68	305	4149	\N	\N	56.537045999999997	Нижегородская область, Чкаловский район, поселок Чистое, Ленина, 5А	Россия, Нижегородская область, Чкаловский район, поселок Чистое	0101000020E61000007F6ABC74938045404B395FECBD444C40
62686	7	68	305	4718	\N	\N	56.746085000000001	Нижегородская область, Чкаловский район, Пуреховский сельсовет, с.Соломаты, ул.Советская, д.6, здание Соломатовского ДК	Россия, Нижегородская область, Чкаловский район, село Соломаты	0101000020E61000004F90D8EE1E744540A18499B67F5F4C40
62684	7	68	305	4635	17591	\N	56.765804000000003	Нижегородская область, Чкаловский район, Новинский сельсовет, с. Сицкое, Парковая, 57		0101000020E6100000F9156BB8C8934540B0928FDD05624C40
62685	7	68	305	4690	17560	\N	56.643692999999999	Нижегородская область, Чкаловский район, Пуреховский сельсовет, с. Пурех, Ленина, 66		0101000020E610000009A9DBD95788454002D53F8864524C40
62683	7	68	305	4552	17447	\N	56.750684999999997	Нижегородская область, Чкаловский район, Новинский сельсовет, с.Новинки, ул.Кооперативная, д.10, здание Новинского «Центра ремесел и досуга»	Россия, Нижегородская область, Чкаловский район, село Новинки	0101000020E610000045DAC69FA8864540834C327216604C40
62681	7	68	305	4446	\N	\N	56.713929	Нижегородская область, Чкаловский район, Кузнецовский сельсовет, д. Кузнецово, Алексеева, 13	Россия, Нижегородская область, Чкаловский район, село Кузнецово	0101000020E6100000271763601D9945403F558506625B4C40
62679	7	68	305	4316	\N	\N	56.807886000000003	Нижегородская область, Чкаловский район, Котельницкий сельсовет, д. Котельницы, Центральная, 7	Россия, Нижегородская область, Чкаловский район, село Котельницы	0101000020E610000050A912656F9B4540B972F6CE68674C40
62626	7	68	305	1368	16729	\N	56.747051999999996	Нижегородская область, Тоншаевский район, Кодочиговский сельсовет, д. Кодочиги, площадь Центральная здание Кодочиговской с/администрации, 1		0101000020E6100000AC1DC539EA764540A83462669F5F4C40
62675	7	68	305	4139	17436	\N	56.832428	Нижегородская область, Чкаловский район, поселок Катунки, Чкалова, 1		0101000020E6100000D594641D8E9C454029232E008D6A4C40
62680	7	68	305	4139	16985	\N	56.832428	Нижегородская область, Чкаловский район, поселок Катунки, Садовая, 3		0101000020E6100000D594641D8E9C454029232E008D6A4C40
62688	7	68	305	4854	\N	\N	56.718394000000004	Нижегородская область, Чкаловский район, Соломатовский сельсовет, д.Железово, ул.Центральная, д.1, здание Железовского Центра досуга	Россия, Нижегородская область, Чкаловский район, село Железово	0101000020E6100000E0A128D0277E454042D2A755F45B4C40
62682	7	68	305	49734	\N	\N	56.683405999999998	Нижегородская область, Чкаловский район, Кузнецовский сельсовет, д. Высокая, Здание Высоковского СДК		0101000020E610000003D19332A9994540F1F109D979574C40
62678	7	68	305	50047	19514	\N	56.621982211462502	Нижегородская область, Чкаловский район, Вершиловский сельсовет, Чкалова, 31		0101000020E6100000A0A86C58539B4540B0592E1B9D4F4C40
62677	7	68	305	4243	17207	\N	56.791713999999999	Нижегородская область, Чкаловский район, Беловский сельсовет, с. Белое, Центральная, 54		0101000020E6100000516A2FA2ED7E454086E464E256654C40
62667	7	68	338	3709	17614	\N	57.433523999999998	Нижегородская область, Уренский район, Устанский сельсовет, п. Уста, Октябрьская, 22-а, средняя школа,фойе		0101000020E610000022533E0455D54640FB03E5B67DB74C40
62668	7	68	338	3709	17911	\N	57.433523999999998	Нижегородская область, Уренский район, Устанский сельсовет, п. Уста, Коммунистическая, 6-а, здание администрации		0101000020E610000022533E0455D54640FB03E5B67DB74C40
62639	7	68	338	1616	\N	\N	57.464615000000002	"Нижегородская область, Уренский район, город Урень, Плодосовхоз, 16-а, Здание ООО"" Северянка"",1 этаж"	Россия, Нижегородская область, Уренский район, Урень	0101000020E61000003543AA285EE54640931D1B8178BB4C40
62636	7	68	338	1616	\N	\N	57.464615000000002	Нижегородская область, Уренский район, город Урень, Коммунистическая, 43,здание бывшего лицея № 100	Россия, Нижегородская область, Уренский район, Урень	0101000020E61000003543AA285EE54640931D1B8178BB4C40
62635	7	68	338	1616	\N	\N	57.464615000000002	Нижегородская область, Уренский район, город Урень, Ленина, 268, здание Уренских электросетей	Россия, Нижегородская область, Уренский район, Урень	0101000020E61000003543AA285EE54640931D1B8178BB4C40
62630	7	68	338	1616	17392	\N	57.464615000000002	"Нижегородская область, Уренский район, город Урень, Центральная, 46-а, кафе ""Лагуна"""		0101000020E61000003543AA285EE54640931D1B8178BB4C40
62633	7	68	338	1616	17395	\N	57.464615000000002	Нижегородская область, Уренский район, город Урень, Труда, 49, здание инф.диагностическ.центра		0101000020E61000003543AA285EE54640931D1B8178BB4C40
62631	7	68	338	1616	16730	\N	57.464615000000002	"Нижегородская область, Уренский район, город Урень, ул.Льнозавод, ИП "" Серышев И.С."",бывшая весовая"		0101000020E61000003543AA285EE54640931D1B8178BB4C40
62634	7	68	338	1616	17575	\N	57.464615000000002	Нижегородская область, Уренский район, город Урень, Ленина, 171, коррекционная школа, уч.класс		0101000020E61000003543AA285EE54640931D1B8178BB4C40
62632	7	68	338	1616	17575	\N	57.464615000000002	Нижегородская область, Уренский район, город Урень, Ленина, 67, РДК,фойе,1 этаж		0101000020E61000003543AA285EE54640931D1B8178BB4C40
62638	7	68	338	1616	16792	\N	57.464615000000002	Нижегородская область, Уренский район, город Урень, Индустриальная, 12, средняя школа №2,фойе,1 этаж		0101000020E61000003543AA285EE54640931D1B8178BB4C40
62637	7	68	338	1616	16792	\N	57.464615000000002	Нижегородская область, Уренский район, город Урень, Индустриальная, 6-а, ДЮСШ,спортзал		0101000020E61000003543AA285EE54640931D1B8178BB4C40
62654	7	68	338	2992	17872	\N	57.583744000000003	Нижегородская область, Уренский район, Горевский сельсовет, д. Тулага, Комсомольская, 1-а,СДК,танцевальный зал		0101000020E6100000AC527AA697E646403D9E961FB8CA4C40
62665	7	68	338	3639	17897	\N	57.491746999999997	Нижегородская область, Уренский район, Темтовский сельсовет, с. Темта,  ул.Молодежная,  д.2-а,     Сельский дом культуры		0101000020E610000011AAD4EC81F04640FB73D190F1BE4C40
62662	7	68	338	3451	17231	\N	57.336173000000002	Нижегородская область, Уренский район, Семеновский сельсовет, с. Семеново, Смирнова, 44, СДК,комната отдыха		0101000020E6100000D926158DB5DB46402C6684B707AB4C40
62660	7	68	338	3345	17607	\N	57.567673999999997	Нижегородская область, Уренский район, Обходский сельсовет, п. Обход, Ленина, 9, здание сельской администрации		0101000020E6100000E9F010C64F1B47400E65A88AA9C84C40
62659	7	68	338	3302	17882	\N	57.363007000000003	Нижегородская область, Уренский район, Минеевский сельсовет, д. Минеево, Репина, 16, СДК,зрительный зал	Россия, Нижегородская область, Уренский район, село Минеево	0101000020E610000092B245D26EC446400B9C6C0377AE4C40
62666	7	68	338	3676	17907	\N	57.462311	Нижегородская область, Уренский район, Устанский сельсовет, д. Ломы, Комсомольская, 2-а,СДК,актовый зал		0101000020E6100000807EDFBF79CB464060CAC0012DBB4C40
62664	7	68	338	3536	\N	\N	57.401592000000001	"Нижегородская область, Уренский район, Семеновский сельсовет, д. Красный Яр, Санаторий ""Красный ЯР"", клуб"		0101000020E6100000B39597FC4FD84640E92ADD5D67B34C40
62652	7	68	338	2863	\N	\N	57.631971	Нижегородская область, Уренский район, Вязовский сельсовет, д. Копылиха, Центральная, 44-а, медпункт	Россия, Нижегородская область, Уренский район, село Копылиха	0101000020E6100000C76647AAEFD046409D82FC6CE4D04C40
62656	7	68	338	3100	17877	\N	57.676479999999998	Нижегородская область, Уренский район, Карпунихинский сельсовет, с. Карпуниха, Махалова, 103, СДК,танцевальный зал		0101000020E61000008EAD6708C7E64640F4328AE596D64C40
62651	7	68	338	2844	17220	\N	57.656792000000003	Нижегородская область, Уренский район, Вязовский сельсовет, д. Вязовая, Школьная, 2, начальная школа		0101000020E6100000336E6AA0F9DC46402123A0C211D44C40
62648	7	68	338	2650	16989	\N	57.464033999999998	Нижегородская область, Уренский район, Ворошиловский сельсовет, д. Большой Терсень, Мира, 3, СДК,танцевальный зал		0101000020E61000004A09C1AA7ADB4640B41D537765BB4C40
62658	7	68	338	3219	17881	\N	57.648195999999999	Нижегородская область, Уренский район, Красногорский сельсовет, с. Большой Красногор, Советская, 1, СДК,зрительный зал		0101000020E6100000FE80070610004740F2B22616F8D24C40
62645	7	68	338	2497	16982	\N	57.486846999999997	Нижегородская область, Уренский район, Большепесочнинский сельсовет, д. Большое Песочное, Центральная, 2, СДК,зрительный зал		0101000020E610000061FBC9181F0A4740EE93A30051BE4C40
62650	7	68	338	2748	17864	\N	57.509383999999997	Нижегородская область, Уренский район, Ворошиловский сельсовет, д. Большое Никитино, Молодежная, 14, СДК,фойе		0101000020E6100000431EC18D94E14640868DB27E33C14C40
62647	7	68	338	2609	17409	\N	57.494635000000002	"Нижегородская область, Уренский район, Ворошиловский сельсовет, д. Большое Непряхино, Школьная, 1, здание детсада ""Малыш"""		0101000020E61000004E8061F9F3D546407E3A1E3350BF4C40
62663	7	68	338	3523	17421	\N	57.302312999999998	Нижегородская область, Уренский район, Семеновский сельсовет, д. Большое Лопатино, Первомайская, мед.пункт		0101000020E6100000E0D8B3E732CF4640EC134031B2A64C40
62655	7	68	338	3050	16801	\N	57.400126723263597	Нижегородская область, Уренский район, Карповский сельсовет, с. Карпово, ул. Школьная, д. 11-а	Россия, Нижегородская область, Уренский район, село Большое Карпово	0101000020E6100000B20FB22C980A4740909F8D5C37B34C40
62653	7	68	338	2952	\N	\N	57.567987000000002	Нижегородская область, Уренский район, Горевский сельсовет, с. Большое Горево, Советская, 19, СДК,танцевальный зал	Россия, Нижегородская область, Уренский район, село Большое Горево	0101000020E6100000E8F4BC1B0BEE4640CEC64ACCB3C84C40
62657	7	68	338	3196	\N	\N	57.668894999999999	Нижегородская область, Уренский район, Карпунихинский сельсовет, д. Большая Козляна, Школьная, 1,малокомплектная школа,уч.класс	Россия, Нижегородская область, Уренский район, село Большая Козляна	0101000020E61000006A865451BCEE46409DBAF2599ED54C40
62646	7	68	338	2509	17855	\N	57.514938999999998	Нижегородская область, Уренский район, Большепесочнинский сельсовет, д. Большая Елховка, Центральная, 35, ФАП		0101000020E610000025ADF886C2114740AC376A85E9C14C40
62644	7	68	338	2423	17406	\N	57.505873999999999	Нижегородская область, Уренский район, Большеарьевский сельсовет, д. Большая Арья, Центральная, 8, здание сельской администрации		0101000020E6100000E606431D56FA4640C7F2AE7AC0C04C40
62643	7	68	338	2166	16736	\N	57.489139999999999	"Нижегородская область, Уренский район, рабочий поселок Арья, Юбилейная, 10, кафе ""Манхэттен"""		0101000020E61000002503401537FC46402D95B7239CBE4C40
62640	7	68	338	2166	16976	\N	57.489139999999999	Нижегородская область, Уренский район, рабочий поселок Арья, Школьная, 1, средняя школа,уч.класс,1 этаж		0101000020E61000002503401537FC46402D95B7239CBE4C40
62642	7	68	338	2166	17202	\N	57.489139999999999	Нижегородская область, Уренский район, рабочий поселок Арья, Строителей, 10-а, Арьевская ДЮСШ,спортзал		0101000020E61000002503401537FC46402D95B7239CBE4C40
62641	7	68	338	2166	16975	\N	57.489139999999999	Нижегородская область, Уренский район, рабочий поселок Арья, Карла Маркса, 10, здание администрации р.п.Арья		0101000020E61000002503401537FC46402D95B7239CBE4C40
62627	7	68	126	1435	16728	\N	57.609003000000001	Нижегородская область, Тоншаевский район, Кодочиговский сельсовет, п. Южный, Центральная здание Южной ООШ, 12		0101000020E6100000026553AEF0B847403C1570CFF3CD4C40
62614	7	68	126	635	16949	\N	57.802819937376199	Нижегородская область, Тоншаевский район, Большекувербский сельсовет, д. Ширта, Молодежная здание сельского Дома культуры, 28		0101000020E6100000C712D6C6D8874740904946CEC2E64C40
62624	7	68	126	1271	\N	\N	57.972014000000001	Нижегородская область, Тоншаевский район, Одошнурский сельсовет, п. Шерстки, Клубная здание сельского Дома культуры, 8		0101000020E6100000AB23473A03B9474088A06AF46AFC4C40
62618	7	68	126	920	19433	\N	57.769343999999997	Нижегородская область, Тоншаевский район, поселок Шайгино, Вокзальная здание Шайгинской поселковой администрации, 20	Россия, Нижегородская область, Тоншаевский район, поселок Шайгино	0101000020E610000079573D601E6E4740D9AF3BDD79E24C40
62612	7	68	126	261	\N	\N	57.735823000000003	Нижегородская область, Тоншаевский район, р.п. Тоншаево, ул. Центральная, д.45, здание Тоншаевского РайПО	Россия, Нижегородская область, Тоншаевский район, поселок Тоншаево	0101000020E6100000B22AC24D468347408352B4722FDE4C40
62611	7	68	126	261	\N	\N	57.735823000000003	Нижегородская область, Тоншаевский район, поселок Тоншаево, п. Кировский, Клубная здание Дома культуры, 3		0101000020E6100000B22AC24D468347408352B4722FDE4C40
62608	7	68	126	261	\N	\N	57.735823000000003	Нижегородская область, Тоншаевский район, поселок Тоншаево, Центральная здание районного Дома культуры, 18	Россия, Нижегородская область, Тоншаевский район, поселок Тоншаево	0101000020E6100000B22AC24D468347408352B4722FDE4C40
62609	7	68	126	261	16723	\N	57.735823000000003	Нижегородская область, Тоншаевский район, поселок Тоншаево, Свердлова здание Тоншаевской районной администрации, 2А		0101000020E6100000B22AC24D468347408352B4722FDE4C40
62610	7	68	126	261	16947	\N	57.735823000000003	Нижегородская область, Тоншаевский район, поселок Тоншаево, Заречная здание Дома культуры, 46		0101000020E6100000B22AC24D468347408352B4722FDE4C40
62621	7	68	126	1079	\N	\N	57.675806999999999	Нижегородская область, Тоншаевский район, Ложкинский сельсовет, д. Сухой Овраг, Центральная здание сельского Дома культуры, 3		0101000020E61000007CB8E4B85388474035B401D880D64C40
62774	7	68	126	9065	\N	\N	57.746930045431597	Нижегородская область, Тоншаевский район, Увийский сельсовет, д. Ромачи, Центральная здание медпункта, 9А	Россия, Нижегородская область, Тоншаевский район, село Ромачи	0101000020E6100000821C9430D39E47405D33F9669BDF4C40
62617	7	68	126	741	17558	\N	57.860641999999999	"Нижегородская область, Тоншаевский район, поселок Пижма, Кирова здание Дома культуры ""Юбилейный"", 3"		0101000020E6100000247D5A457F8E474032C85D8429EE4C40
62616	7	68	126	741	17558	\N	57.861393939798802	Нижегородская область, Тоншаевский район, поселок Пижма, Кирова здание Пижемской поселковой администрации, 45А	Россия, Нижегородская область, Тоншаевский район, поселок Пижма	0101000020E61000002331410DDF8E47403D7C992842EE4C40
62615	7	68	126	741	17561	\N	57.860641999999999	Нижегородская область, Тоншаевский район, р.п. Пижма, ул. Калинина, д. № 8, здание МОУ Пижемской средней общеобразовательной школы		0101000020E6100000247D5A457F8E474032C85D8429EE4C40
62628	7	68	126	1487	\N	\N	57.681634000000003	Нижегородская область, Тоншаевский район, Ошминский сельсовет, с. Ошминское, Центральная здание сельского Дома культуры, 36В	Россия, Нижегородская область, Тоншаевский район, село Ошминское	0101000020E6100000948444DAC6AB4740BCEB6CC83FD74C40
62620	7	68	126	1022	\N	\N	57.677413999999999	Нижегородская область, Тоншаевский район, Березятский сельсовет, д. Гагаринское, Центральная здание сельского Дома культуры, 2		0101000020E61000003E93FDF33470474020ED7F80B5D64C40
62622	7	68	126	1149	17077	\N	57.583019999999998	Нижегородская область, Тоншаевский район, Ложкинский сельсовет, с. Вякшенер, Центральная здание сельского Дома культуры, 19		0101000020E6100000FCE07CEA588D4740FB743C66A0CA4C40
62623	7	68	126	1214	16786	\N	57.950628999999999	Нижегородская область, Тоншаевский район, Одошнурский сельсовет, п. Буреполом, Октябрская здание Одошнурской сельской администрации, 5		0101000020E6100000B54E5C8E57AE474089D00836AEF94C40
62629	7	68	126	1570	17471	\N	57.712383000000003	Нижегородская область, Тоншаевский район, Увийский сельсовет, д. Большие Селки, Центральная здание Дома культуры, 52		0101000020E610000010B22C98F8954740FA9CBB5D2FDB4C40
62613	7	68	126	624	17815	\N	57.832962000000002	Нижегородская область, Тоншаевский район, деревня Большая Куверба, Центральная здание сельского Дома культуры, 11А		0101000020E6100000452DCDAD10924740C767B27F9EEA4C40
62619	7	68	126	964	16957	\N	57.69435	Нижегородская область, Тоншаевский район, Березятский сельсовет, д. Березята, ул. Центральная д. № 36, здание бывшего МОУ для детей дошкольного и младшего школьного возраста Березятская начальная общеобразовательная школа-сад		0101000020E610000030293E3E217D474022FDF675E0D84C40
62605	7	68	42	50	16720	\N	57.325654	Нижегородская область, Тонкинский район, Трошково, Хутор, 15 а	Россия, Нижегородская область, Тонкинский район, село Трошково	0101000020E61000005610035DFB084740E2E7BF07AFA94C40
62597	7	68	42	32150	17209	\N	57.372559000000003	Нижегородская область, Тонкинский район, р.п. Тонкино, Ленина, 3 Б		0101000020E6100000BCEA01F3903947404D6A6803B0AF4C40
62596	7	68	42	32150	17441	\N	57.372559000000003	Нижегородская область, Тонкинский район, р.п. Тонкино ул. Гагарина, дом 9		0101000020E6100000BCEA01F3903947404D6A6803B0AF4C40
62606	7	68	42	130	17160	\N	57.269973999999998	Нижегородская область, Тонкинский район, Пакалевский сельсовет, д. Степановское, Центральная, 4		0101000020E6100000377007EA94FB464099620E828EA24C40
62740	7	68	42	7495	\N	\N	57.394011999999996	Нижегородская область, Тонкинский район, Вязовский сельсовет, д. Старые Краи, здание начальной школы, 36		0101000020E6100000484E266E15604740A31D37FC6EB24C40
62607	7	68	42	250	17368	\N	57.221397000000003	Нижегородская область, Тонкинский район, Пакалевский сельсовет, с. Полянское, Центральная, 2		0101000020E6100000828FC18A53FB46405D37A5BC569C4C40
62604	7	68	42	14876	16695	\N	57.278858999999997	Нижегородская область, Тонкинский район, Пахутино, Молодежная, 20 а		0101000020E61000004AD235936F184740FE98D6A6B1A34C40
62565	7	68	42	14952	17480	\N	57.270563000000003	Нижегородская область, Тонкинский район, Пакали, Центральная, 42 б		0101000020E6100000F0BF95ECD8084740FB40F2CEA1A24C40
62601	7	68	42	32345	17550	\N	57.378678000000001	Нижегородская область, Тонкинский район, Кодочиги, Центральная, 23		0101000020E610000004560E2DB25547407BDB4C8578B04C40
62600	7	68	42	32301	\N	\N	57.427515999999997	Нижегородская область, Тонкинский район, Вязовка, Коммунистическая, 14	Россия, Нижегородская область, Тонкинский район, село Вязовка	0101000020E6100000FAB836548C534740244223D8B8B64C40
62776	7	68	42	9141	\N	\N	57.420737000000003	Нижегородская область, Тонкинский район, Бердниковский сельсовет, д. Вая, здание фельдшерского акушерского пункта, 58		0101000020E6100000CB49287D213A4740CC9BC3B5DAB54C40
62602	7	68	42	32391	\N	\N	57.309421	Нижегородская область, Тонкинский район, Б.Содомово, Школьная, 10	Россия, Нижегородская область, Тонкинский район, село Большое Содомово	0101000020E6100000FD6A0E10CC1F47400AD9791B9BA74C40
62603	7	68	42	32444	17105	\N	57.328186000000002	Нижегородская область, Тонкинский район, Б.Сидорово, Специалистов, 5	Россия, Нижегородская область, Тонкинский район, село Большое Сидорово	0101000020E61000007CB8E4B853164740A680B4FF01AA4C40
62598	7	68	42	32222	16942	\N	57.389544999999998	"Нижегородская область, Тонкинский район, Бердниковский сельсовет, д. Большое Ларионово, Молодежная, 1""а"""	Россия, Нижегородская область, Тонкинский район, село Большое Ларионово	0101000020E6100000FA7B293C6828474000A94D9CDCB14C40
62599	7	68	42	32250	17598	\N	57.422094000000001	Нижегородская область, Тонкинский район, Бердники, Школьная, 18		0101000020E6100000280AF4893C4347403EEB1A2D07B64C40
62594	7	68	1101	32043	18536	\N	55.857593999999999	Нижегородская область, Спасский район, Турбанский сельсовет, д. Турбанка, Рабочая, 29		0101000020E61000001651137D3EE04640779FE3A3C5ED4B40
62582	7	68	1101	10350	16747	\N	55.739680999999997	Нижегородская область, Спасский район, Базловский сельсовет, д. Тукай, здание сельского Дома культуры,  ул. Полевая, д. 110 «в»		0101000020E61000006F9C14E63DD046407D3CF4DDADDE4B40
62581	7	68	1101	31457	\N	\N	55.926226999999997	Нижегородская область, Спасский район, Новоусадский сельсовет, с. Тубанаевка, Верхняя, 10	Россия, Нижегородская область, Спасский район, село Тубанаевка	0101000020E6100000D95E0B7A6FD846400AD6389B8EF64B40
62593	7	68	1101	31961	17466	\N	55.807592	"Нижегородская область, Спасский район, Маклаковский сельсовет, с. Татарское Маклаково, Энгельса, 1 ""а"""		0101000020E6100000BC5983F755C946407041B62C5FE74B40
62592	7	68	1101	31961	17148	\N	55.807592	"Нижегородская область, Спасский район, Маклаковский сельсовет, с. Татарское Маклаково, Советская, 8 ""а"""		0101000020E6100000BC5983F755C946407041B62C5FE74B40
62590	7	68	1101	21589	\N	\N	55.858311	Нижегородская область, Спасский район, Спасский сельсовет, с. Спасское, пос.Юбилейный, 1-б	Россия, Нижегородская область, Спасский район, село Спасское	0101000020E6100000D15D126745D8464006668522DDED4B40
62588	7	68	1101	21589	17763	\N	55.858311	Нижегородская область, Спасский район, Спасский сельсовет, с. Спасское, пл.Революции, 59		0101000020E6100000D15D126745D8464006668522DDED4B40
61052	7	68	1101	21589	18258	\N	55.858311	"Нижегородская область, город Бор, Линдовский сельсовет, с. Спасское, ул. Центральная д.8. МБДОУ Спасский детский сад ""Подсолнушек"""		0101000020E6100000D15D126745D8464006668522DDED4B40
62589	7	68	1101	21589	17633	\N	55.858311	Нижегородская область, Спасский район, Спасский сельсовет, с. Спасское, Октябрьская, 69		0101000020E6100000D15D126745D8464006668522DDED4B40
62586	7	68	1101	31711	\N	\N	55.946047999999998	Нижегородская область, Спасский район, Вазьянский сельсовет, д. Сосновка, Мира, 16	Россия, Нижегородская область, Спасский район, село Сосновка	0101000020E61000000C1EA67D73B746401D39D21918F94B40
62585	7	68	1101	31643	17025	\N	55.783898999999998	Нижегородская область, Спасский район, Маклаковский сельсовет, с. Русское Маклаково, Советская, 103		0101000020E6100000FB75A73B4FC04640FD2E6CCD56E44B40
62583	7	68	1101	31549	16770	\N	55.943582999999997	"Нижегородская область, Спасский район, Новоусадский сельсовет, с. Новый Усад, Молодежная, 12""а"""		0101000020E6100000E0DA899290D64640E107E753C7F84B40
62587	7	68	1101	31749	16923	\N	55.820349	Нижегородская область, Спасский район, Спасский сельсовет, с. Масловка, Торговая, 35		0101000020E61000009FAF592E1BDD464035272F3201E94B40
62580	7	68	1101	31395	17426	\N	55.931441999999997	"Нижегородская область, Спасский район, Новоусадский сельсовет, с. Красный Ватрас, Советская, 15 ""а"""		0101000020E6100000D90A9A9658DF4640770FD07D39F74B40
60813	7	68	1101	9805	\N	\N	55.957549999999998	Нижегородская область, Арзамасский район, Кирилловский сельсовет, с.Кирилловка, ул. 9 Мая, д.28	Россия, Нижегородская область, Спасский район, село Кирилловка	0101000020E61000007BD80B056CC94640742497FF90FA4B40
62574	7	68	1101	31118	17272	\N	55.768470999999998	"Нижегородская область, Спасский район, Базловский сельсовет, д. Ишеево, Мира, 94 ""Б"""		0101000020E61000005A9F724C16DB46405376FA415DE24B40
62584	7	68	1101	31587	18453	\N	55.977646999999997	Нижегородская область, Спасский район, Новоусадский сельсовет, с. Ивановское, Почтовая, 56		0101000020E61000008461C092ABD246402904728923FD4B40
62591	7	68	1101	31905	17357	\N	55.840432	Нижегородская область, Спасский район, Спасский сельсовет, с. Елховка, Свободы, 35		0101000020E61000004CDF6B088ED146408541994693EB4B40
62576	7	68	1101	31178	17646	\N	55.906466000000002	Нижегородская область, Спасский район, Высокоосельский сельсовет, с. Горки, Центральная, 131		0101000020E610000026FC523F6FBC4640CD77F01307F44B40
62579	7	68	1101	31350	\N	\N	55.921365000000002	Нижегородская область, Спасский район, Высокоосельский сельсовет, с. Высокий Оселок, Полевая, 16	Россия, Нижегородская область, Спасский район, село Высокий Оселок	0101000020E6100000200A664CC1C84640EB56CF49EFF54B40
62577	7	68	1101	10321	\N	\N	56.000360999999998	Нижегородская область, Спасский район, Вазьянский сельсовет, с. Вазьянка, здание администрации сельсовета,  ул. Советская, д. 94 «В»	Россия, Нижегородская область, Спасский район, село Вазьянка	0101000020E61000004FE78A5242BA4640D09849D40B004C40
62575	7	68	1101	31141	17661	\N	55.853561999999997	Нижегородская область, Спасский район, Высокоосельский сельсовет, с. Бронский Ватрас, Центральная, 94		0101000020E6100000A514747B49BB4640DE8D058541ED4B40
62573	7	68	1101	31068	17069	\N	55.756149452954801	Нижегородская область, Спасский район, Базловский сельсовет, с. Базлово, Молодежная, 12	Россия, Нижегородская область, Спасский район, село Базлово	0101000020E6100000E36BCF2C09D8464099F38C7DC9E04B40
62595	7	68	1101	32100	17538	\N	55.871895000000002	"Нижегородская область, Спасский район, Турбанский сельсовет, с. Антоново, Молодежная, 10 ""а"""		0101000020E610000083177D0569E84640E1455F419AEF4B40
62571	7	68	1050	30970	17068	\N	55.872909999999997	Нижегородская область, Сосновский район, Яковский сельсовет, с. Яковское, Восточная, 58, здание администрации		0101000020E6100000C495B37746B14540F92CCF83BBEF4B40
62552	7	68	1050	49625	16700	\N	55.8106014657386	Нижегородская область, Сосновский район, Виткуловский сельсовет, д. Сурулово, Фрунзе, 8, здание школы	Россия, Нижегородская область, Сосновский район, село Сурудово	0101000020E610000045DAC69FA89E45406D8D08C6C1E74B40
62561	7	68	1050	30463	\N	\N	55.792645	Нижегородская область, Сосновский район, Крутецкий сельсовет, д. Стечкино, Спортивная, 4, здание сельского клуба	Россия, Нижегородская область, Сосновский район, село Стечкино	0101000020E610000011FFB0A5478B4540412B306475E54B40
62450	7	68	1201	11618	17218	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, пос. Молодежный, 14А		0101000020E610000024D5777E51BC46409468C9E369C34B40
62540	7	68	1050	9266	\N	\N	55.800823000000001	Нижегородская область, Сосновский район, поселок Сосновское, пер.Школьный, 8, Сосновская СОШ №1	Россия, Нижегородская область, Сосновский район, поселок Сосновское	0101000020E6100000813E9127499545403B71395E81E64B40
62544	7	68	1050	9266	17526	\N	55.790629863632901	"Нижегородская область, Сосновский район, поселок Сосновское, Совхозная, 1-А, ООО ""Сосновскдорремстрой"""	Россия, Нижегородская область, Сосновский район, поселок Сосновское	0101000020E610000096404AECDA924540459E245D33E54B40
62547	7	68	1050	9266	17313	\N	55.800823000000001	Нижегородская область, Сосновский район, поселок Сосновское, Профсоюзная, 24, Сосновская ЦРБ		0101000020E6100000813E9127499545403B71395E81E64B40
62538	7	68	1050	9266	16833	\N	55.800823000000001	"Нижегородская область, Сосновский район, поселок Сосновское, Октябрьская, 12, детсад ""Колокольчик"""	Россия, Нижегородская область, Сосновский район, поселок Сосновское	0101000020E6100000813E9127499545403B71395E81E64B40
62539	7	68	1050	9266	17502	\N	55.800823000000001	Нижегородская область, Сосновский район, поселок Сосновское, Нижегородская, 4, школа № 2		0101000020E6100000813E9127499545403B71395E81E64B40
62778	7	68	1050	9266	17331	\N	55.800823000000001	Нижегородская область, Сосновский район, р.п. Сосновское, ул. Ленина, д. 25, здание Земского Собрания		0101000020E6100000813E9127499545403B71395E81E64B40
62542	7	68	1050	9266	17331	\N	55.800823000000001	"Нижегородская область, Сосновский район, поселок Сосновское, Ленина, 96, детсад ""Тополек"""		0101000020E6100000813E9127499545403B71395E81E64B40
62537	7	68	1050	9266	17331	\N	55.803998659539097	Нижегородская область, Сосновский район, поселок Сосновское, Ленина, 23, САПТ техникум	Россия, Нижегородская область, Сосновский район, поселок Сосновское	0101000020E6100000F60D4C6E1495454023827170E9E64B40
62543	7	68	1050	9266	16991	\N	55.800823000000001	Нижегородская область, Сосновский район, поселок Сосновское, Комсомольская, 22, Дискотечный зал		0101000020E6100000813E9127499545403B71395E81E64B40
62541	7	68	1050	9266	16991	\N	55.800823000000001	Нижегородская область, Сосновский район, поселок Сосновское, Комсомольская, 18, Дом пионеров		0101000020E6100000813E9127499545403B71395E81E64B40
62549	7	68	1050	29870	\N	\N	55.785969000000001	Нижегородская область, Сосновский район, Виткуловский сельсовет, д. Созоново, Калинина, 51, здание Дома культуры	Россия, Нижегородская область, Сосновский район, село Созоново	0101000020E61000001D5A643BDFA14540BD55D7A19AE44B40
62560	7	68	1050	30376	\N	\N	55.772786000000004	Нижегородская область, Сосновский район, Крутецкий сельсовет, д. Сиуха, Озерная, 1А, здание Дома культуры	Россия, Нижегородская область, Сосновский район, село Сиуха	0101000020E6100000B7B585E7A59245404167D2A6EAE24B40
62570	7	68	1050	14359	\N	\N	55.783777000000001	Нижегородская область, Сосновский район, Селитьбинский сельсовет, с. Селитьба, ул. Центральная, д. № 166, здание МУП «Теплоснаб»	Россия, Нижегородская область, Сосновский район, село Селитьба	0101000020E6100000F392FFC9DFBD4540B22D03CE52E44B40
62569	7	68	1050	14359	17462	\N	55.783777000000001	Нижегородская область, Сосновский район, Селитьбинский сельсовет, с. Селитьба, пер. Северный, д. 10, здание администрации		0101000020E6100000F392FFC9DFBD4540B22D03CE52E44B40
62558	7	68	1050	30259	17124	\N	55.734789999999997	Нижегородская область, Сосновский район, Крутецкий сельсовет, д. Рыльково, Фабричная, 46, здание клуба		0101000020E6100000A3CEDC43C28D4540C3B645990DDE4B40
62567	7	68	1050	30756	17270	\N	55.655706000000002	Нижегородская область, Сосновский район, Рожковский сельсовет, с. Рожок, Микрорайон, 7, здание школы		0101000020E6100000B58AFED0CC9945403FE5982CEED34B40
62563	7	68	1050	30563	17518	\N	55.735216000000001	Нижегородская область, Сосновский район, Панинский сельсовет, д. Рагозино, ул. Шуваловой, д. 74, здание сельского клуба		0101000020E6100000C269C18BBE7845407BBFD18E1BDE4B40
62562	7	68	1050	30478	17064	\N	55.752738999999998	Нижегородская область, Сосновский район, Панинский сельсовет, с. Панино, Советская, 56А, здание Дома культуры		0101000020E6100000066344A2D07645403DB665C059E04B40
62566	7	68	1050	30673	\N	\N	55.643982999999999	Нижегородская область, Сосновский район, Рожковский сельсовет, с. Николаевка, Школьная, 16, здание библиотеки	Россия, Нижегородская область, Сосновский район, село Николаевка	0101000020E6100000B8567BD80BA745400917F2086ED24B40
62559	7	68	1050	30354	17125	\N	55.824713000000003	Нижегородская область, Сосновский район, Крутецкий сельсовет, с. Матюшево, Младенцева, 1А, здание медпункта		0101000020E610000031410DDFC28A454004CB113290E94B40
62556	7	68	1050	30177	17321	\N	55.763260000000002	Нижегородская область, Сосновский район, Елизаровский сельсовет, д. Малахово, Совхозная, 7, здание детского сада		0101000020E6100000F148BC3C9D814540282CF180B2E14B40
62568	7	68	1050	30805	\N	\N	55.797325999999998	Нижегородская область, Сосновский район, Виткуловский сельсовет, д. Макасово, Гагарина, 16Б, здание детского сад	Россия, Нижегородская область, Сосновский район, село Макасово	0101000020E610000050C763062A994540102043C70EE64B40
62564	7	68	1050	30571	\N	\N	55.665070999999998	Нижегородская область, Сосновский район, Рожковский сельсовет, с. Лесуново, Восточная, 39, здание администрации	Россия, Нижегородская область, Сосновский район, село Лесуново	0101000020E610000029232E008D9045404E42E90B21D54B40
62557	7	68	1050	30249	18216	\N	55.772835999999998	Нижегородская область, Сосновский район, Крутецкий сельсовет, с. Крутые, Советская, 12, сельская администрация		0101000020E61000003B730F09DF8F4540F295404AECE24B40
62555	7	68	1050	30159	17703	\N	55.753118999999998	Нижегородская область, Сосновский район, Елизаровский сельсовет, с. Клещариха, Овражная, 13, здание Дома культуры		0101000020E6100000B37BF2B050874540847F113466E04B40
62572	7	68	1050	30070	\N	\N	55.805562999999999	Нижегородская область, Сосновский район, Елизаровский сельсовет, с. Елизарово, Советская, 78, здание администрации	Россия, Нижегородская область, Сосновский район, село Елизарово	0101000020E61000000C957F2DAF8445400FEF39B01CE74B40
62553	7	68	1050	30070	18187	\N	55.805562999999999	Нижегородская область, Сосновский район, Елизаровский сельсовет, с. Елизарово, Парковая, 11, здание Дома культуры		0101000020E61000000C957F2DAF8445400FEF39B01CE74B40
62545	7	68	1050	29687	\N	\N	55.888159999999999	Нижегородская область, Сосновский район, Давыдковский сельсовет, с. Давыдково, Центральная, 14, здание администрации	Россия, Нижегородская область, Сосновский район, село Давыдково	0101000020E6100000C98FF8156B9C4540C4CE143AAFF14B40
62551	7	68	1050	29964	\N	\N	55.841816999999999	Нижегородская область, Сосновский район, Виткуловский сельсовет, с. Глядково, Ворошилова, 1А, здание клуба	Россия, Нижегородская область, Сосновский район, село Глядково	0101000020E6100000A12FBDFDB9964540C11BD2A8C0EB4B40
62550	7	68	1050	29885	17317	\N	55.762251999999997	Нижегородская область, Сосновский район, Виткуловский сельсовет, д. Волчиха, Ленина, 1Б, здание медпункта		0101000020E6100000C3D50110779B4540C1A7397991E14B40
62548	7	68	1050	29798	17111	\N	55.803539999999998	Нижегородская область, Сосновский район, Виткуловский сельсовет, с. Виткулово, Белова, 38А, здание Дома культуры		0101000020E61000001844A4A65D9A454090831266DAE64B40
62546	7	68	1050	29692	17112	\N	55.602316999999999	Нижегородская область, Сосновский район, Рожковский сельсовет, с. Венец, Советская, 4, здание бывшей администрации		0101000020E6100000CB49287D21864540946934B918CD4B40
62554	7	68	1050	30080	18200	\N	55.818812000000001	Нижегородская область, Сосновский район, Елизаровский сельсовет, д. Богданово, Молодежная, 8, здание школы		0101000020E610000018CFA0A17F7C454043C9E4D4CEE84B40
62777	7	68	1050	9199	17143	\N	55.830164000000003	Нижегородская область, Сосновский район, Яковский сельсовет, с. Бараново, Молодежная, 23, здание детского сада		0101000020E6100000A6423C122FA9454085285FD042EA4B40
62524	7	68	1117	28718	17102	\N	57.040491000000003	Нижегородская область, Сокольский район, д. Фатеево, Восточная, 4		0101000020E61000003B342C465DCF4540246420CF2E854C40
62511	7	68	1117	27983	\N	\N	57.140571999999999	Нижегородская область, Сокольский район, р.п. Сокольское, ул. Лесная, д. 20, муниципальное бюджетное дошкольное учреждение «Детский сад № 4»	Россия, Нижегородская область, Сокольский район, село Сокольское	0101000020E610000066A208A9DB974540DD5D6743FE914C40
62509	7	68	1117	21394	\N	\N	57.143019000000002	Нижегородская область, Сокольский район, р.п. Сокольское, Кирова, 11	Россия, Нижегородская область, Сокольский район, поселок Сокольское	0101000020E61000006A34B9180395454073DA53724E924C40
62510	7	68	1117	21394	18245	\N	57.141645692447597	Нижегородская область, Сокольский район, р.п. Сокольское, Садовая, 15	Россия, Нижегородская область, Сокольский район, поселок Сокольское	0101000020E61000009604A8A965954540FBCDC47421924C40
62508	7	68	1117	21394	17261	\N	57.143019000000002	Нижегородская область, Сокольский район, р.п. Сокольское, Калинина, 2	Россия, Нижегородская область, Сокольский район, поселок Сокольское	0101000020E61000006A34B9180395454073DA53724E924C40
62507	7	68	1117	21394	17374	\N	57.131737640471997	Нижегородская область, Сокольский район, р.п. Сокольское, Докучаева, 52	Россия, Нижегородская область, Сокольский район, поселок Сокольское	0101000020E610000082E3326E6A944540FAD170CADC904C40
62531	7	68	1117	15740	16995	\N	57.315891000000001	Нижегородская область, Сокольский район, д. Селянцево, Большое Бухарино, 22		0101000020E61000004AF1F109D9A14540E50CC51D6FA84C40
62530	7	68	1117	15717	17067	\N	57.269181000000003	Нижегородская область, Сокольский район, д. Пушкарево, Школьная, 16	Россия, Нижегородская область, Сокольский район, село Пушкарево	0101000020E61000002E3718EAB0A0454030DAE38574A24C40
62512	7	68	1117	28190	17289	\N	57.126617000000003	Нижегородская область, Сокольский район, д. Пудово, Зеленая, 2		0101000020E6100000BA66F2CD369745400F0F61FC34904C40
62535	7	68	1117	10240	17689	\N	57.395012000000001	Нижегородская область, Сокольский район, с. Пелегово, Школьная, 6		0101000020E6100000BB5F05F86EB3454087C3D2C08FB24C40
62522	7	68	1117	28643	17762	\N	56.929977000000001	Нижегородская область, Сокольский район, д. Никольское, Школьная, 3		0101000020E61000002E742502D5B545401F84807C09774C40
62515	7	68	1117	28319	\N	\N	57.111165	Нижегородская область, Сокольский район, д. Мурзино, Школьная, 2	Россия, Нижегородская область, Сокольский район, село Мурзино	0101000020E61000007B2E5393E0B94540DCBA9BA73A8E4C40
62526	7	68	1117	23156	17305	\N	57.03145	Нижегородская область, Сокольский район, д. Молчаново, Центральная, 19		0101000020E61000006CEC12D55BA34540C7BAB88D06844C40
62518	7	68	1117	28441	\N	\N	57.273384999999998	Нижегородская область, Сокольский район, с. Мамонтово, Центральная, 45	Россия, Нижегородская область, Сокольский район, село Мамонтово	0101000020E6100000E789E76C01CF4540C51B9947FEA24C40
62536	7	68	1117	10252	16835	\N	57.452409746702301	Нижегородская область, Сокольский район, п. Летняя База, Шелехонская, 136	Россия, Нижегородская область, Сокольский район, село Летняя База	0101000020E6100000BD546CCCEBBC454012312592E8B94C40
62519	7	68	1117	28498	\N	\N	57.307519999999997	Нижегородская область, Сокольский район, п. Лесной, Школьная, 37	Россия, Нижегородская область, Сокольский район, село Лесной	0101000020E6100000F69B89E942CA4540D66EBBD05CA74C40
62532	7	68	1117	10120	16817	\N	57.348771999999997	Нижегородская область, Сокольский район, п. Куртюга, ул. Придорожная, д. 3, клуб поселка Куртюга		0101000020E61000003410CB660EA9454058E1968FA4AC4C40
62517	7	68	1117	28412	17671	\N	57.286710999999997	Нижегородская область, Сокольский район, д. Кузнецово, Центральная, 23		0101000020E6100000726DA818E7C34540A43330F2B2A44C40
62529	7	68	1117	28972	17693	\N	57.195951000000001	Нижегородская область, Сокольский район, д. Кудрино, Поселковая, 1		0101000020E61000006F9EEA909B9B45402B4F20EC14994C40
62513	7	68	1117	28209	17215	\N	57.179583000000001	Нижегородская область, Сокольский район, д. Коренево, Соколова, 22		0101000020E6100000B29DEFA7C6A9454073F56393FC964C40
62534	7	68	1117	29180	17170	\N	57.258870999999999	Нижегородская область, Сокольский район, д. Ковригино, Молодежная, 2		0101000020E6100000902FA182C3AD4540007157AF22A14C40
62516	7	68	1117	15228	17092	\N	57.266640000000002	Нижегородская область, Сокольский район, п. Запашка, ул. Молодежная, д.18, Запашкинский Дом культуры		0101000020E6100000CF4E0647C9BF454019E76F4221A24C40
62525	7	68	1117	28792	16755	\N	56.999524000000001	Нижегородская область, Сокольский район, д. Заболотное, ул. Молодежная, д. 2, Заболтновский дом культуры		0101000020E61000004C8C65FA25A0454097C80567F07F4C40
62521	7	68	1117	28603	17298	\N	56.946486	Нижегородская область, Сокольский район, д. Дресвищи, ул. Школьная д.18, Муниципальное казенное образовательное учреждение «Дресвищенская основная общеобразовательная школа»		0101000020E61000004698A25C1AAB4540990F087426794C40
62514	7	68	1117	28262	\N	\N	57.136777000000002	Нижегородская область, Сокольский район, с. Дорофеево, Центральная, 5	Россия, Нижегородская область, Сокольский район, село Дорофеево	0101000020E610000014B01D8CD8A5454029ECA2E881914C40
62527	7	68	1117	28879	17513	\N	57.068652999999998	Нижегородская область, Сокольский район, с. Георгиевское, Центральная, 3		0101000020E610000070B6B9313DA94540DAE21A9FC9884C40
62523	7	68	1117	15467	17408	\N	57.04363	Нижегородская область, Сокольский район, с. Гари, Молодежная, 3		0101000020E6100000399A232BBFC44540EF8FF7AA95854C40
62533	7	68	1117	10154	17161	\N	57.356628000000001	Нижегородская область, Сокольский район, д. Вилеж, Школьная, 6		0101000020E61000007D94111780C04540406B7EFCA5AD4C40
62528	7	68	1117	28900	17787	\N	57.098964000000002	Нижегородская область, Сокольский район, д. Боталово, Центральная, 8		0101000020E6100000F10EF0A485A345409DBD33DAAA8C4C40
62520	7	68	1117	28535	18073	\N	56.962933999999997	Нижегородская область, Сокольский район, д. Березово, Школьная, 1		0101000020E6100000917F66101FBE45406D1ADB6B417B4C40
62161	7	68	5773	50071	\N	\N	56.275379000000001	Нижегородская область, город Нижний Новгород, Советский район, д. Кузнечиха, 60		0101000020E610000057790261A7044640AA807B9E3F234C40
62500	7	68	1805	50050	19526	\N	55.214287608725797	Нижегородская область, Сеченовский район, Сеченовский сельсовет, пос. Теплостанского совхоза ул. Школьная дом 18 в	Россия, Нижегородская область, Краснооктябрьский район	0101000020E6100000B39602D2FEFB46406FF607CA6D9B4B40
62486	7	68	1805	50070	19621	\N	55.126836627706503	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, п. Талызинского совхоза, ул. Молодежная, дом 12	Россия, Нижегородская область, Сеченовский район, село совхоз Талызинский	0101000020E61000003ACAC16C02F046401D76DF313C904B40
62501	7	68	1805	27707	17453	\N	55.254595000000002	Нижегородская область, Сеченовский район, Сеченовский сельсовет, с. Ясное, ул. Центральная, дом 30		0101000020E6100000768D96033DF64640D15CA79196A04B40
62505	7	68	1805	27886	\N	\N	55.042824000000003	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, с. Шемарино, ул. Молодежная, дом 1	Россия, Нижегородская область, Сеченовский район, село Шемарино	0101000020E61000003B51121269F54640F1BDBF417B854B40
62503	7	68	1805	27795	17056	\N	55.055120836013202	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, с. Торговое Талызино, ул. Центральная, дом 47	Россия, Нижегородская область, Сеченовский район, село Торговое Талызино	0101000020E6100000F8DD74CB0EE74640522976340E874B40
62504	7	68	1805	27804	\N	\N	55.023727999999998	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, с. Скрипино, ул. Сельская, дом 4	Россия, Нижегородская область, Сеченовский район, село Скрипино	0101000020E61000000188BB7A15F54640EFFFE38409834B40
62499	7	68	1805	27546	\N	\N	55.227421999999997	Нижегородская область, Сеченовский район, Сеченовский сельсовет, с. Сеченово, ул. 70 лет Октября, дом 1	Россия, Нижегородская область, Сеченовский район, село Сеченово	0101000020E610000016DD7A4D0FF246400932022A1C9D4B40
62498	7	68	1805	27546	17451	\N	55.227421999999997	Нижегородская область, Сеченовский район, Сеченовский сельсовет, с. Сеченово, пл. Советская, дом 3	Россия, Нижегородская область, Сеченовский район, село Сеченово	0101000020E610000016DD7A4D0FF246400932022A1C9D4B40
62488	7	68	1805	27073	17932	\N	55.220818000000001	Нижегородская область, Сеченовский район, Кочетовский сельсовет, с. Рогожка, ул. Школьная, дом 7		0101000020E61000002541B8020A0547401F2FA4C3439C4B40
62496	7	68	1805	27452	17043	\N	55.331608000000003	Нижегородская область, Сеченовский район, Мурзицкий сельсовет, с. Ратово, ул. Большая линия, дом 23		0101000020E6100000CCB8A981E6154740C68B852172AA4B40
62489	7	68	1805	27140	17935	\N	55.180177	Нижегородская область, Сеченовский район, Кочетовский сельсовет, д. Николаевка, ул. Школьная, дом 21а		0101000020E6100000EFFE78AF5AFF4640E63E390A10974B40
62495	7	68	1805	27396	17042	\N	55.294217000000003	Нижегородская область, Сеченовский район, Мурзицкий сельсовет, с. Мурзицы, ул. Кооперативная, дом 17		0101000020E6100000A0FB7266BB1A4740B07614E7A8A54B40
62494	7	68	1805	27366	\N	\N	55.094276999999998	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, с. Митрополье, ул. Школьная, дом 10	Россия, Нижегородская область, Сеченовский район, село Митрополье	0101000020E61000009CFD8172DBFA4640EBE1CB44118C4B40
62497	7	68	1805	27495	17260	\N	55.191119999999998	Нижегородская область, Сеченовский район, Сеченовский сельсовет, с. Мамлейка, ул. Центральная, дом 1в		0101000020E610000068CEFA9463F6464046CEC29E76984B40
62493	7	68	1805	27303	17625	\N	55.043185000000001	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, с. Липовка, ул. Школьная дом 52		0101000020E610000009185DDE1C024740C156091687854B40
62492	7	68	1805	27275	17627	\N	55.360095999999999	Нижегородская область, Сеченовский район, Красноостровский сельсовет, с. Левашовка, ул. Почтовая, дом 49а		0101000020E610000054FD4AE7C3F74640D0B52FA017AE4B40
62491	7	68	1805	50073	19719	\N	55.326298057061202	Нижегородская область, Сеченовский район, Красноостровский сельсовет, с. Красный Остров, ул. Советская, дом 28	Россия, Нижегородская область, Сеченовский район, село Красный Остров	0101000020E61000000B5D8940F503474007600322C4A94B40
62490	7	68	1805	27171	\N	\N	55.290135999999997	Нижегородская область, Сеченовский район, Сеченовский сельсовет, с. Красное, ул. Молодежная, дом 1	Россия, Нижегородская область, Сеченовский район, село Красное	0101000020E61000004C6C3EAE0DFD464035B22B2D23A54B40
62487	7	68	1805	27048	17248	\N	55.243659000000001	Нижегородская область, Сеченовский район, Кочетовский сельсовет, с. Кочетовка, ул. Колхозная, дом 39		0101000020E6100000988A8D791D0F47402330D637309F4B40
62481	7	68	1805	26766	17565	\N	55.254938000000003	Нижегородская область, Сеченовский район, Болтинский сельсовет, с. Ильинка, ул. Школьная, дом 7		0101000020E6100000C76647AAEFE64640FB40F2CEA1A04B40
62485	7	68	1805	26959	\N	\N	55.099598	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, с. Верхнее Талызино, ул. Советская, дом 13а	Россия, Нижегородская область, Сеченовский район, село Верхнее Талызино	0101000020E6100000E78F696D1AEB46409E5F94A0BF8C4B40
62483	7	68	1805	26855	\N	\N	55.251624	Нижегородская область, Сеченовский район, Васильевский сельсовет, с. Васильевка, ул. Колхозная, дом 42	Россия, Нижегородская область, Сеченовский район, село Васильевка	0101000020E61000002BF9D85DA0D84640C171193735A04B40
62502	7	68	1805	27741	17963	\N	55.025539000000002	Нижегородская область, Сеченовский район, Торгово -Талызинский сельсовет, д. Булдаково, ул. Запрудная, дом 33		0101000020E61000009C33A2B437E04640E3E2A8DC44834B40
62482	7	68	1805	26817	17016	\N	55.200060999999998	Нижегородская область, Сеченовский район, Васильевский сельсовет, с. Болховское, ул. Малые Выселки, 20		0101000020E61000007444BE4BA9D346403F1A4E999B994B40
62480	7	68	1805	26748	16737	\N	55.327336000000003	Нижегородская область, Сеченовский район, Болтинский сельсовет, с. Болтинка, ул. Школьная, 11		0101000020E610000073BD6DA642EA4640D8666325E6A94B40
62484	7	68	1805	26905	17431	\N	55.142055999999997	Нижегородская область, Сеченовский район, Верхнеталызинский сельсовет, с. Богатиловка, ул. Краснопартизанская, дом 26В		0101000020E6100000AAB5300BEDF64640AC1919E42E924B40
62479	7	68	1805	26707	17428	\N	55.270062000000003	Нижегородская область, Сеченовский район, Болтинский сельсовет, д. Бахметьевка, ул. Молодежная, дом 23	Россия, Нижегородская область, Сеченовский район, село Бахметьевка	0101000020E61000004ED1915CFEE9464039F2406491A24B40
62477	7	68	1805	26602	17424	\N	55.181259221261698	Нижегородская область, Сеченовский район, Сеченовский сельсовет, с. Алферьево, ул. Первомайская, дом 11а	Россия, Нижегородская область, Сеченовский район, село Алферьево	0101000020E6100000E620E86855E74640868DB27E33974B40
62478	7	68	1805	26613	17425	\N	55.343732000000003	Нижегородская область, Сеченовский район, Болтинский сельсовет, с. Александровка, ул. Андреева, дом 2		0101000020E610000099840B7904E946405A4B0169FFAB4B40
62471	7	68	1201	26307	17227	\N	55.472468999999997	Нижегородская область, Сергачский район, Лопатинский сельсовет, с. Яново, Школьная, 1	Россия, Нижегородская область, Сергачский район, село Яново	0101000020E61000003FAC376A85A74640D9AF3BDD79BC4B40
62470	7	68	1201	26236	17592	\N	55.477443999999998	Нижегородская область, Сергачский район, Шубинский сельсовет, с. Шубино, Советская, 4		0101000020E6100000527C7C4276B24640F1D58EE21CBD4B40
62451	7	68	1201	25375	17844	\N	55.622573000000003	Нижегородская область, Сергачский район, Толбинский сельсовет, с. Толба, Южная, 13А	Россия, Нижегородская область, Сергачский район, село Толба	0101000020E61000008C2D043928A54640B22FD978B0CF4B40
62465	7	68	1201	26037	17414	\N	55.491675999999998	Нижегородская область, Сергачский район, Староберезовский сельсовет, с. Старая Березовка, Садовая, 2		0101000020E610000021CEC3094CDD4640321D3A3DEFBE4B40
62457	7	68	1201	25690	17405	\N	55.707293999999997	Нижегородская область, Сергачский район, Андреевский сельсовет, с. Сосновка, Молодежная, 5		0101000020E6100000118C834BC7C6464019541B9C88DA4B40
62446	7	68	1201	11618	\N	\N	55.526668999999998	Нижегородская область, Сергачский район, г.Сергач, ул.Школьная, д.10	Россия, Нижегородская область, Сергачский район, Сергач	0101000020E610000024D5777E51BC46409468C9E369C34B40
62444	7	68	1201	11618	\N	\N	55.526668999999998	Нижегородская область, Сергачский район, г.Сергач, м-н  Юбилейный, д. 20а		0101000020E610000024D5777E51BC46409468C9E369C34B40
62425	7	68	1201	11618	\N	\N	55.5269627049557	Нижегородская область, Сергачский район, город Сергач, пос. Юбилейный, 15А	Россия, Нижегородская область, Сергачский район, Сергач	0101000020E610000021054F2157BC4640DD99098673C34B40
62443	7	68	1201	11618	17394	\N	55.5263784609024	Нижегородская область, Сергачский район, г.Сергач, м-н  Юбилейный, д. 5а	Россия, Нижегородская область, Сергачский район, Сергач	0101000020E6100000F888981249BC4640BDAAB35A60C34B40
62449	7	68	1201	11618	16969	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Ульянова, 157		0101000020E610000024D5777E51BC46409468C9E369C34B40
62442	7	68	1201	11618	16969	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Ульянова, 1В		0101000020E610000024D5777E51BC46409468C9E369C34B40
62439	7	68	1201	11618	17572	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Советская, 49	Россия, Нижегородская область, Сергачский район, Сергач	0101000020E610000024D5777E51BC46409468C9E369C34B40
62441	7	68	1201	11618	16966	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Свердлова, 70		0101000020E610000024D5777E51BC46409468C9E369C34B40
62440	7	68	1201	11618	16965	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, М. Горького, 35	Россия, Нижегородская область, Сергачский район, Сергач	0101000020E610000024D5777E51BC46409468C9E369C34B40
62436	7	68	1201	11618	17571	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Лесная, 30		0101000020E610000024D5777E51BC46409468C9E369C34B40
62447	7	68	1201	11618	16790	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Краснодонцев, 106	Россия, Нижегородская область, Сергачский район, Сергач	0101000020E610000024D5777E51BC46409468C9E369C34B40
62448	7	68	1201	11618	16974	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Гусева, 54		0101000020E610000024D5777E51BC46409468C9E369C34B40
62445	7	68	1201	11618	17576	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, Вокзальная, 50		0101000020E610000024D5777E51BC46409468C9E369C34B40
62414	7	68	1201	11618	17552	\N	55.526668999999998	Нижегородская область, Сергачский район, город Сергач, 60 лет Октября, 3		0101000020E610000024D5777E51BC46409468C9E369C34B40
62453	7	68	1201	25493	\N	\N	55.499316	Нижегородская область, Сергачский район, Пожарский сельсовет, с. Пожарки, Советская, 2	Россия, Нижегородская область, Сергачский район, село Пожарки	0101000020E6100000D9B27C5D86C146404D2F3196E9BF4B40
62472	7	68	1201	15135	18100	\N	55.379327000000004	Нижегородская область, Сергачский район, Лопатинский сельсовет, с.Пица, ул. Центральная,д.16б		0101000020E6100000533D997FF4A54640B2BE81C98DB04B40
62459	7	68	1201	25768	17157	\N	55.577092999999998	Нижегородская область, Сергачский район, Толбинский сельсовет, с. Мокрый Майдан, Школьная, 7		0101000020E610000033FE7DC685B1464011E0F42EDEC94B40
62476	7	68	1201	26549	17205	\N	55.557994000000001	Нижегородская область, Сергачский район, Камкинский сельсовет, с. Луговое, Луговая, 3		0101000020E61000002507EC6AF29846409FAEEE586CC74B40
62454	7	68	1201	25525	16980	\N	55.406987999999998	Нижегородская область, Сергачский район, Лопатинский сельсовет, с. Лопатино, Ивлиева, 27		0101000020E6100000DCB8C5FCDC9C4640A6EECA2E18B44B40
62474	7	68	1201	50072	19704	\N	55.394388996291198	Нижегородская область, Сергачский район, Лопатинский сельсовет, с. Кошкарово, Зеленая, 12	Россия, Нижегородская область, Сергачский район, село Кошкарево	0101000020E61000000E9F7422C19846407973B8567BB24B40
62469	7	68	1201	26224	\N	\N	55.489249000000001	Нижегородская область, Сергачский район, Кочко-Пожарский сельсовет, с. Кочко - Пожарки, Советская, 28	Россия, Нижегородская область, Сергачский район, село Кочко-Пожарки	0101000020E610000058207A5226BD4640E44C13B69FBE4B40
62452	7	68	1201	25435	17195	\N	55.533938999999997	Нижегородская область, Сергачский район, Камкинский сельсовет, с. Камкино, Почтовая, 35		0101000020E610000082E50819C89946408B87F71C58C44B40
62467	7	68	1201	26112	17859	\N	55.483418	Нижегородская область, Сергачский район, Староберезовский сельсовет, д. Каменка, Колхозная, 7		0101000020E6100000F4FC69A33AE346401C261AA4E0BD4B40
62475	7	68	1201	26486	17895	\N	55.468311	Нижегородская область, Сергачский район, Камкинский сельсовет, с. Грибаново, Школьная, 64		0101000020E610000071AE6186C69B4640B4AD669DF1BB4B40
62468	7	68	1201	26165	17416	\N	55.458023269785798	Нижегородская область, Сергачский район, Ачкинский сельсовет, д. Вязовка, Овражная, 38А	Россия, Нижегородская область, Сергачский район, село Вязовка	0101000020E6100000A9F8BF232AD646406CE8667FA0BA4B40
62456	7	68	1201	25623	17201	\N	55.675539000000001	Нижегородская область, Сергачский район, Андреевский сельсовет, с. Воскресенское, Советская, 8		0101000020E61000004E5FCFD72CDD46401616DC0F78D64B40
62460	7	68	1201	25838	18509	\N	55.728220999999998	Нижегородская область, Сергачский район, Андреевский сельсовет, с. Вершинино, Зеленая, 26		0101000020E61000003DD68C0C72C1464055A1815836DD4B40
62461	7	68	1201	25885	\N	\N	55.757283000000001	Нижегородская область, Сергачский район, Андреевский сельсовет, с. Борисовка, Школьная, 3	Россия, Нижегородская область, Сергачский район, село Борисовка	0101000020E610000023F3C81F0CD046408C683BA6EEE04B40
62458	7	68	1201	25721	17595	\N	55.596305000000001	Нижегородская область, Сергачский район, Богородский сельсовет, с. Богородское, Молодежная, 9		0101000020E61000008176871403C446407CB8E4B853CC4B40
62464	7	68	1201	26023	17221	\N	55.563212999999998	Нижегородская область, Сергачский район, Ачкинский сельсовет, с. Ачка, Ленина, 94А		0101000020E61000006BD8EF8975CA46404DD7135D17C84B40
62462	7	68	1201	25888	17222	\N	55.685192999999998	Нижегородская область, Сергачский район, Андреевский сельсовет, с. Андреевка, пос. Молодежный, 5		0101000020E6100000884677103BCB46405C397B67B4D74B40
62284	7	68	1465	17152	17008	\N	55.446232999999999	Нижегородская область, Перевозский район, с.Ичалки, Кирова, 7		0101000020E6100000A10F96B1A13F4640AFB2B6291EB94B40
62463	7	68	1201	25963	16799	\N	55.604086000000002	Нижегородская область, Сергачский район, Богородский сельсовет, с. Анда, Советская, 26А	Россия, Нижегородская область, Сергачский район, село Анда	0101000020E6100000DF50F86C1DCC464059FCA6B052CD4B40
62455	7	68	1201	25591	17851	\N	55.467610999999998	Нижегородская область, Сергачский район, Ачкинский сельсовет, с. Акузово, Центральная, 82		0101000020E61000007F6B274A42D04640FB1F60ADDABB4B40
62473	7	68	1201	26376	17860	\N	55.354450999999997	Нижегородская область, Сергачский район, Лопатинский сельсовет, с. Абаимово, Молодежная, 15		0101000020E6100000477364E597A346406A847EA65EAD4B40
62408	7	68	1084	49810	17540	\N	56.857947000000003	Нижегородская область, Семеновский район, город Семенов, Боковской сельсовет, д. Шалдежка, Октябрьская, 12, администрация сельсовета	Россия, Нижегородская область, Семеновский район, село Шалдежка	0101000020E6100000CE6F9868906C4640C5591135D16D4C40
62433	7	68	1084	49816	17582	\N	56.847168665952402	Нижегородская область, Семеновский район, город Семенов, Шалдежский сельсовет, д. Шалдеж, Новая, 36А, Дом культуры	Россия, Нижегородская область, Семеновский район, село Шалдеж	0101000020E61000002594BE1072604640AF97A608706C4C40
62429	7	68	1084	49721	17002	\N	56.652601650514697	Нижегородская область, Семеновский район, город Семенов, Хахальский сельсовет, д. Хахалы, Центральная, 9, средняя школа	Россия, Нижегородская область, Семеновский район, село Хахалы	0101000020E61000002C6684B707574640F0A65B7688534C40
62409	7	68	1084	49781	\N	\N	56.978467000000002	Нижегородская область, Семеновский район, город Семенов, Ивановский сельсовет, д. Фундриково, 82, администрация сельсовета	Россия, Нижегородская область, Семеновский район, село Фундриково	0101000020E6100000FA980F08742246408D9B1A683E7D4C40
62426	7	68	1084	49634	16725	\N	56.662294877496898	Нижегородская область, Семеновский район, город Семенов, Тарасихинский сельсовет, д. Успенье, Центральная, 45, Дом культуры	Россия, Нижегородская область, Семеновский район, село Успенье	0101000020E6100000C0CC77F0131B4640F4A62215C6544C40
62421	7	68	1084	49737	\N	\N	57.187235999999999	Нижегородская область, Семеновский район, город Семенов, Огибновский сельсовет, с. Успенское, 1, администрация сельсовета	Россия, Нижегородская область, Семеновский район, село Успенское	0101000020E6100000336ABE4A3E40464022516859F7974C40
62438	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, поселок Сухобезводное, д. Олониха, Молодежная, 3, медпункт	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62437	7	68	1084	10423	\N	\N	56.786867999999998	"Нижегородская область, Семеновский район, город Семенов, поселок Сухобезводное, р.п. Сухобезводное, Лесная, 44А, детский центр ""Радуга"""	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62435	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, поселок Сухобезводное, р.п. Сухобезводное, Спортивная, 2, Дом культуры	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62434	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Шалдежский сельсовет, д. Безводное, Центральная, 14-1, медпункт	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62411	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Ивановский сельсовет, д. Перелаз, 33, почтовое отделение	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62402	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Заводская, 19, средняя школа № 3	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62398	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Республика Советов, 1 А, средняя школа № 1	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62397	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Краюшкина, 1, Лицей № 1	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62396	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Чкалова, 18 В, музейно-туристический центр	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62395	7	68	1084	10423	\N	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Спортивная, 64 А, детская художественная школа	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000861E317A6E3F46406C223317B8644C40
62399	7	68	1084	10423	17350	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, пл. Ленина, 5, Центр культуры и искусства		0101000020E6100000861E317A6E3F46406C223317B8644C40
62393	7	68	1084	10423	17346	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Чернышевского, 4, Лицей № 30		0101000020E6100000861E317A6E3F46406C223317B8644C40
62424	7	68	1084	10423	17277	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Тарасихинский сельсовет, п. ст. Тарасиха, Центральная, 2, Дом культуры		0101000020E6100000861E317A6E3F46406C223317B8644C40
62394	7	68	1084	10423	17724	\N	56.786982909072101	Нижегородская область, Семеновский район, город Семенов, Пионерская, 37, средняя школа № 2	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E6100000BEDC27470140464005C1E3DBBB644C40
62401	7	68	1084	10423	16773	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Октябрьская, 20, городской Дом культуры		0101000020E6100000861E317A6E3F46406C223317B8644C40
62420	7	68	1084	10423	18113	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Огибновский сельсовет, п. Фанерное, Красноармейская, 2А, Дом культуры		0101000020E6100000861E317A6E3F46406C223317B8644C40
62413	7	68	1084	10423	16779	\N	56.786867999999998	Нижегородская область, Семеновский район, город Семенов, Малозиновьевский сельсовет, д. Малое Зиновьево, Колхозная, 147, Дом культуры		0101000020E6100000861E317A6E3F46406C223317B8644C40
62400	7	68	1084	10423	16927	\N	56.7939405711235	Нижегородская область, Семеновский район, город Семенов, 1-е Мая, 27, техникум МОД	Россия, Нижегородская область, Семеновский район, Семенов	0101000020E61000006D753925203E46400DFAD2DB9F654C40
62430	7	68	1084	49788	17396	\N	56.674626934943298	Нижегородская область, Семеновский район, город Семенов, Хахальский сельсовет, с. Светлое, Школьная, 30, администрация сельсовета	Россия, Нижегородская область, Семеновский район, село Светлое	0101000020E6100000C689AF76143F4640D2FF722D5A564C40
62410	7	68	1084	49772	17292	\N	56.958638101366603	Нижегородская область, Семеновский район, город Семенов, Ивановский сельсовет, д. Полом, Ковернинская, 8, администрация сельсовета	Россия, Нижегородская область, Семеновский район, село Полом	0101000020E61000005053CBD6FA2E4640F75965A6B47A4C40
62422	7	68	1084	49758	17174	\N	56.778356032790199	Нижегородская область, Семеновский район, город Семенов, Пафнутовский сельсовет, д. Пафнутово, И.Козлова, 66, Дом культуры	Россия, Нижегородская область, Семеновский район, село Пафнутово	0101000020E6100000BF0F0709512446409C525E2BA1634C40
62427	7	68	1084	49645	16785	\N	56.733127279410503	Нижегородская область, Семеновский район, город Семенов, Тарасихинский сельсовет, п. ст. Осинки, Лесная, 6, Дом культуры	Россия, Нижегородская область, Семеновский район, село Осинки	0101000020E6100000698B6B7C262D46404568041BD75D4C40
62419	7	68	1084	49636	\N	\N	57.077424999999998	Нижегородская область, Семеновский район, город Семенов, Огибновский сельсовет, д. Огибное, Микрорайон, 5, Дом культуры	Россия, Нижегородская область, Семеновский район, село Огибное	0101000020E6100000C24EB16A104A46404772F90FE9894C40
62418	7	68	1084	23787	17366	\N	57.053004999999999	Нижегородская область, Семеновский район, д.Никитино, Дом культуры, ул.Верхняя, д.12А		0101000020E6100000D0D6C1C1DE50464022C32ADEC8864C40
62416	7	68	1084	49712	16944	\N	56.746096310899702	Нижегородская область, Семеновский район, город Семенов, Медведевский сельсовет, д. Медведево, Нижняя, 61А, Дом культуры	Россия, Нижегородская область, Семеновский район, село Медведево	0101000020E61000000611A969173D464095D6DF12805F4C40
62428	7	68	1084	49782	17379	\N	56.752865094496102	Нижегородская область, Семеновский район, город Семенов, Тарасихинский сельсовет, д. Кулагино, Центральная, 31А, Дом культуры	Россия, Нижегородская область, Семеновский район, село Кулагино	0101000020E6100000FFE9060ABC214640CAA65CE15D604C40
62432	7	68	1084	49784	\N	\N	56.8733087579432	Нижегородская область, Семеновский район, город Семенов, Шалдежский сельсовет, д. Кондратьево, 18А, медпункт	Россия, Нижегородская область, Семеновский район, село Кондратьево	0101000020E61000001F1494A295454640B726DD96C86F4C40
62405	7	68	1084	49711	16933	\N	56.9069	Нижегородская область, Семеновский район, город Семенов, Беласовский сельсовет, п. Керженец, Новая, 1А, Дом культуры	Россия, Нижегородская область, Семеновский район, село Керженец	0101000020E6100000399B8E006E504640075F984C15744C40
62412	7	68	1084	49654	16818	\N	57.246080999999997	Нижегородская область, Семеновский район, город Семенов, Ильино-Заборский сельсовет, с. Ильино-Заборское, Медведева, 12, Дом культуры	Россия, Нижегородская область, Семеновский район, село Ильино-Заборское	0101000020E6100000E0A128D0273246405F950B957F9F4C40
62423	7	68	1084	49786	17386	\N	56.852012770330298	Нижегородская область, Семеновский район, город Семенов, Пафнутовский сельсовет, д. Зубово, Панельная, 7, детский сад	Россия, Нижегородская область, Семеновский район, село Зубово	0101000020E610000064CDC820770F4640286211C30E6D4C40
62431	7	68	1084	49719	16967	\N	56.832146999999999	Нижегородская область, Семеновский район, город Семенов, Шалдежский сельсовет, д. Зименки, Школьная, 35, детский сад	Россия, Нижегородская область, Семеновский район, село Зименки	0101000020E610000072F90FE9B74D4640753BFBCA836A4C40
62415	7	68	1084	49644	16781	\N	56.8734039516034	Нижегородская область, Семеновский район, город Семенов, Малозиновьевский сельсовет, д. Елфимово, Молодежная, 2Б, Дом культуры	Россия, Нижегородская область, Семеновский район, село Елфимово	0101000020E6100000D0B9DBF5D21E46400919C8B3CB6F4C40
62282	7	68	1465	17030	17503	\N	55.593404999999997	Нижегородская область, Перевозский район, с.Дубское, Центральная, 2а		0101000020E6100000F296AB1F9B5446403524EEB1F4CB4B40
62417	7	68	1084	49819	17599	\N	56.783598796442398	Нижегородская область, Семеновский район, город Семенов, Медведевский сельсовет, д. Дьяково, Центральная, 55А, арендуемое помещение	Россия, Нижегородская область, Семеновский район, село Дъяково	0101000020E6100000C6C03A8E1F424640D316D7F84C644C40
62407	7	68	1084	49655	\N	\N	56.890291970956604	Нижегородская область, Семеновский район, город Семенов, Боковской сельсовет, д. Боковая, 104, администрация сельсовета	Россия, Нижегородская область, Семеновский район, село Боковая	0101000020E6100000F65D11FC6F814640FAF19716F5714C40
62406	7	68	1084	49755	\N	\N	56.965082049909199	Нижегородская область, Семеновский район, город Семенов, Беласовский сельсовет, д. Богоявление, 92А, Дом культуры	Россия, Нижегородская область, Семеновский район, село Богоявление	0101000020E6100000F52D73BA2C504640A9FA95CE877B4C40
62404	7	68	1084	49735	17059	\N	56.918531182286898	Нижегородская область, Семеновский район, город Семенов, Беласовский сельсовет, д. Беласовка, Мичуринская, 3, средняя школа	Россия, Нижегородская область, Семеновский район, село Беласовка	0101000020E6100000B1FB8EE1B14D46405CAE7E6C92754C40
62357	7	68	1211	20994	17073	\N	54.662438000000002	Нижегородская область, Починковский район, Василевский сельсовет, с. Шишадеево, ул.Большая, д.48, Фельдшерско-акушерский пункт		0101000020E6100000B14E95EF1961464057D0B4C4CA544B40
62371	7	68	1211	21670	\N	\N	54.523566000000002	Нижегородская область, Починковский район, Василевский сельсовет, с. Шагаево, ул.Центральная, д.11, Здание сельской администрации	Россия, Нижегородская область, Починковский район, село Шагаево	0101000020E61000007905A2276556464016A6EF3504434B40
62370	7	68	1211	21593	17132	\N	54.557088	Нижегородская область, Починковский район, Наруксовский сельсовет, с. Учуево - Майдан, ул.Центральная, д.5, Здание сельской администрации		0101000020E6100000EC18575C1C3F46403D7FDAA84E474B40
62369	7	68	1211	21554	16701	\N	54.878925000000002	Нижегородская область, Починковский район, Ужовский сельсовет, с. Ужово, ул.Ленина, д.50, Дом культуры		0101000020E61000003C670B08AD7346408351499D80704B40
62344	7	68	1211	20284	\N	\N	54.795842	Нижегородская область, Починковский район, Ужовский сельсовет, п. Ужовка, ул.Советская, д.43, Здание сельской администрации	Россия, Нижегородская область, Починковский район, село Ужовка	0101000020E6100000499F56D11F74464041649126DE654B40
62368	7	68	1211	21516	17730	\N	54.706963000000002	Нижегородская область, Починковский район, Починковский сельсовет, с. Тагаево, ул. 1 Мая, д.47, Дом культуры		0101000020E61000002C45F29540624640B43D7AC37D5A4B40
62361	7	68	1211	21207	17501	\N	54.768338999999997	Нижегородская область, Починковский район, Ризоватовский сельсовет, с. Сырятино, ул.Парковая, д.17, Дом культуры		0101000020E6100000B35E0CE544614640E49EAEEE58624B40
62365	7	68	1211	21387	17345	\N	54.531005999999998	Нижегородская область, Починковский район, Пеля-Хованский сельсовет, с. Симбухово, ул.Школьная, д.32, Здание сельской администрации		0101000020E61000000229B16B7B7B464069FD2D01F8434B40
62364	7	68	1211	21300	17506	\N	54.716284000000002	Нижегородская область, Починковский район, Кочкуровский сельсовет, с. Саитовка, ул.Ленина, д.131, Филиал МБОУ Починковской ср.школы		0101000020E6100000663387A416804640F452B131AF5B4B40
62362	7	68	1211	21213	\N	\N	54.779473000000003	Нижегородская область, Починковский район, Ризоватовский сельсовет, с. Ризоватово, ул.Молодежная, д.2, Дом культуры	Россия, Нижегородская область, Починковский район, село Ризоватово	0101000020E61000001CF0F96184504640B98E71C5C5634B40
62360	7	68	1211	50058	19553	\N	54.789798044714097	Нижегородская область, Починковский район, Ризоватовский сельсовет, с. Пузская Слобода, ул.Комсомольская, д.1А, МБОУ Пузско-Слободская ср.общ.школа	Россия, Нижегородская область, Починковский район, село Пузская Слобода	0101000020E6100000E9B985AE446246401D39D21918654B40
62354	7	68	1211	11881	\N	\N	54.700830000000003	Нижегородская область, Починковский район, Починковский сельсовет, с. Починки, ул.Советская, д.22, МБОУ Газопроводская сред.общ.школа	Россия, Нижегородская область, Починковский район, село Починки	0101000020E6100000927538BA4A6D4640210725CCB4594B40
62334	7	68	1211	11881	17300	\N	54.700830000000003	Нижегородская область, Починковский район, Починковский сельсовет, с. Починки, пл.Ленина, д.31, МБОУ ДОД Детская школа искусств		0101000020E6100000927538BA4A6D4640210725CCB4594B40
62333	7	68	1211	11881	18079	\N	54.700830000000003	Нижегородская область, Починковский район, Починковский сельсовет, с. Починки, пл.Ленина, д.44, Районный Дворец культуры		0101000020E6100000927538BA4A6D4640210725CCB4594B40
62335	7	68	1211	11881	17062	\N	54.700830000000003	Нижегородская область, Починковский район, Починковский сельсовет, с. Починки, ул.Луначарского, д.47, МКСОУ Починковская спец.школа-интер		0101000020E6100000927538BA4A6D4640210725CCB4594B40
62337	7	68	1211	11881	17307	\N	54.700830000000003	"Нижегородская область, Починковский район, Починковский сельсовет, с. Починки, ул.Коммунистическая, д.13, Клуб ""Факел"""		0101000020E6100000927538BA4A6D4640210725CCB4594B40
62336	7	68	1211	11881	16794	\N	54.700830000000003	Нижегородская область, Починковский район, Починковский сельсовет, с. Починки, улица Заречная, дом 10	Россия, Нижегородская область, Починковский район, село Починки	0101000020E6100000927538BA4A6D4640210725CCB4594B40
85219	4	34	\N	639	45289	\N	62.028191	Республика Саха (Якутия), город Якутск, Птицефабрика, 14		0101000020E6100000A0C03BF97436604051853FC39B034F40
62359	7	68	1211	21119	18175	\N	54.615961578442501	Нижегородская область, Починковский район, Пеля-Хованский сельсовет, с. Пеля - Хованская, ул.Центральная, д.142 А, Дом культуры	Россия, Нижегородская область, Починковский район	0101000020E610000086E5CFB70579464015CAC2D7D74E4B40
62358	7	68	1211	21037	18172	\N	54.510072000000001	Нижегородская область, Починковский район, Пеля-Хованский сельсовет, с. Панкратово, ул.Комсомольская, д.4, Дом культуры	Россия, Нижегородская область, Починковский район, село Панкратово	0101000020E6100000B9DE3653218446407B4D0F0A4A414B40
62338	7	68	1211	19915	17489	\N	54.642893999999998	Нижегородская область, Починковский район, Починковский сельсовет, с. Новоспасское, ул.Ленина, д.10, Дом культуры		0101000020E61000001AFB928D07694640B665C0594A524B40
62351	7	68	1211	20669	\N	\N	54.842247	Нижегородская область, Починковский район, Ризоватовский сельсовет, с. Новое Урюпино, ул.Лесная, д.79, Фельдшерско-акушерский пункт	Россия, Нижегородская область, Починковский район, село Новое Урюпино	0101000020E61000001CCF6740BD474640BA13ECBFCE6B4B40
62466	7	68	1211	26121	19461	\N	54.840448000000002	Нижегородская область, Сергачский район, Староберезовский сельсовет, д. Новая Березовка, Первомайская, 11А		0101000020E6100000D7F9B7CB7E6346408BFED0CC936B4B40
62356	7	68	1211	20961	16992	\N	54.620683	Нижегородская область, Починковский район, Василевский сельсовет, с. Никитино, ул.Ленина, д.105, МБОУ Никитинская сред.общ.школа		0101000020E6100000F99E91088D5E46407217618A724F4B40
62355	7	68	1211	20897	17720	\N	54.628762000000002	Нижегородская область, Починковский район, Наруксовский сельсовет, с. Наруксово, ул.Агафонова, д.7, Дом культуры		0101000020E61000003961C26856464640D97BF1457B504B40
62352	7	68	1211	18187	16840	\N	54.530928000000003	Нижегородская область, Починковский район, Маресевский сельсовет, с. Маресево, ул.Ленина, д.1, Дом культуры		0101000020E61000007138F3AB396A4640EE43DE72F5434B40
62350	7	68	1211	20623	\N	\N	54.794134	Нижегородская область, Починковский район, Ризоватовский сельсовет, с. Мадаево, ул.Кооперативная, д.19, Дом культуры	Россия, Нижегородская область, Починковский район, село Мадаево	0101000020E610000017B9A7AB3B4046402252D32EA6654B40
62349	7	68	1211	20558	17108	\N	54.580106999999998	Нижегородская область, Починковский район, Наруксовский сельсовет, с. Криуша, ул.Мира, д.3, Дом культуры	Россия, Нижегородская область, Починковский район, село Криуша	0101000020E61000008F554ACFF4504640209738F2404A4B40
62348	7	68	1211	20518	18164	\N	54.756267000000001	Нижегородская область, Починковский район, Кочкуровский сельсовет, с. Кочкурово, ул.Советская, д.1, Дом культуры	Россия, Нижегородская область, Починковский район, село Кочкурово	0101000020E6100000C5C9FD0E457F4640A305685BCD604B40
62347	7	68	1211	20444	\N	\N	54.660713999999999	Нижегородская область, Починковский район, Наруксовский сельсовет, п. Коммунар, ул.Заводская, д.21, Здание сельской администрации	Россия, Нижегородская область, Починковский район, село Коммунар	0101000020E61000006231EA5A7B2B46403201BF4692544B40
62367	7	68	1211	21480	17118	\N	54.504069999999999	Нижегородская область, Починковский район, Пеля-Хованский сельсовет, д. Каменка, ул.Советская, д.8, Фельдшерско-акушерский пункт		0101000020E610000093382BA2266E46408672A25D85404B40
62346	7	68	1211	20396	16753	\N	54.766142000000002	Нижегородская область, Починковский район, Ужовский сельсовет, с. Ильинское, ул.Ленина, д.33, Дом культуры		0101000020E6100000A148F7730A724640C80BE9F010624B40
62366	7	68	1211	21401	17508	\N	54.498376999999998	Нижегородская область, Починковский район, Пеля-Хованский сельсовет, с. Журавлиха, ул.Центральная, д.70 А, Дом культуры		0101000020E610000083E0F1ED5D7746400F0A4AD1CA3F4B40
62343	7	68	1211	20205	17496	\N	54.655802999999999	Нижегородская область, Починковский район, Починковский сельсовет, с. Дуброво, ул.Кооперативная, д.146, Дом культуры		0101000020E6100000F65FE7A6CD56464031CF4A5AF1534B40
62353	7	68	1211	20803	\N	\N	54.587567999999997	Нижегородская область, Починковский район, Маресевский сельсовет, с. Дивеев Усад, ул.Первомайская, д.5, МБОУ Дивеев-Усадская сред.общ.школа	Россия, Нижегородская область, Починковский район, село Дивеев Усад	0101000020E6100000938C9C853D6746408B16A06D354B4B40
62342	7	68	1211	20119	18020	\N	54.552593000000002	Нижегородская область, Починковский район, Василевский сельсовет, с. Василевка, ул.Молодежная, д.7, МБОУ Василевская основная общ.школа		0101000020E6100000234DBC033C5D4640D07F0F5EBB464B40
62340	7	68	1211	20011	17314	\N	54.888365999999998	Нижегородская область, Починковский район, Василево-Майданский сельсовет, с. Василев Майдан, ул. 1 Мая, д.17, Дом культуры		0101000020E6100000F9A3A833F76046406D7022FAB5714B40
62345	7	68	1211	20317	17695	\N	54.776685000000001	Нижегородская область, Починковский район, Ужовский сельсовет, с. Байково, ул.Макарова, д.27, Дом культуры		0101000020E6100000431F2C63436D46409A25016A6A634B40
62341	7	68	1211	20108	17275	\N	54.860632000000003	Нижегородская область, Починковский район, Василево-Майданский сельсовет, п. Арзинка, ул.Заводская, д.28А, Дом культуры	Россия, Нижегородская область, Починковский район, село Арзинка	0101000020E6100000C806D2C5A65946400FF27A30296E4B40
62339	7	68	1211	19959	\N	\N	54.697183000000003	Нижегородская область, Починковский район, Наруксовский сельсовет, с. Азрапино, ул.Советская, д.96, Дом культуры	Россия, Нижегородская область, Починковский район, село Азрапино	0101000020E61000008670CCB227474640E129E44A3D594B40
62324	7	68	1209	12108	\N	\N	55.414285999999997	Нижегородская область, Пильнинский район, Языковский сельсовет, с. Языково, помещение администрации сельсовета	Россия, Нижегородская область, Пильнинский район, село Языково	0101000020E61000007CEF6FD05E2547406798DA5207B54B40
62312	7	68	1209	18541	17053	\N	55.489182	Нижегородская область, Пильнинский район, Тенекаевский сельсовет, д. Юморга, Школьная, 34,помещение ФАПа		0101000020E6100000BE11DDB3AEE746405CE509849DBE4B40
62317	7	68	1209	11990	17590	\N	55.532466999999997	Нижегородская область, Пильнинский район, Тенекаевский сельсовет, с. Тенекаево, ул. Советская, 86, здание  администрации  сельсовета		0101000020E61000008272DBBE470147408099EFE027C44B40
62318	7	68	1209	11990	16717	\N	55.532466999999997	Нижегородская область, Пильнинский район, Тенекаевский сельсовет, с. Тенекаево, Новая, 28, здание Княжегорской  школы		0101000020E61000008272DBBE470147408099EFE027C44B40
62308	7	68	1209	18314	\N	\N	55.601655000000001	Нижегородская область, Пильнинский район, Большеандосовский сельсовет, с. Столбищи, Школьная, 47,Дом культуры	Россия, Нижегородская область, Пильнинский район, село Столбищи	0101000020E6100000772D211FF4E04640C93CF20703CD4B40
62332	7	68	1209	19588	17597	\N	55.423758558543902	Нижегородская область, Пильнинский район, Новомочалеевский сельсовет, с. Старомочалеи, Набережная, 25, сельский клуб	Россия, Нижегородская область, Пильнинский район, село Старомочалей	0101000020E610000048C153C895F446405D3123BC3DB64B40
62296	7	68	1209	11816	\N	\N	55.560845	Нижегородская область, Пильнинский район, р.п. Пильна, Урицкого, 64	Россия, Нижегородская область, Пильнинский район, Пильна	0101000020E610000062BA10AB3FF646400490DAC4C9C74B40
62298	7	68	1209	11816	17930	\N	55.560845	Нижегородская область, Пильнинский район, р.п. Пильна, Юбилейная, 12, агропромышленный техникум		0101000020E610000062BA10AB3FF646400490DAC4C9C74B40
62295	7	68	1209	11816	17200	\N	55.560845	Нижегородская область, Пильнинский район, р.п. Пильна, ул. Тарлыкова, 8, РКДЦ		0101000020E610000062BA10AB3FF646400490DAC4C9C74B40
62297	7	68	1209	11816	17435	\N	55.560845	Нижегородская область, Пильнинский район, р.п. Пильна, ул. Блохина, 13, здание Пильнинской средней школы № 2		0101000020E610000062BA10AB3FF646400490DAC4C9C74B40
62328	7	68	1209	19392	\N	\N	55.411230000000003	Нижегородская область, Пильнинский район, Петряксинский сельсовет, с. Петряксы, Октябрьская, 13,Дом культуры	Россия, Нижегородская область, Пильнинский район, село Петряксы	0101000020E6100000185FB4C70B0547402A91442FA3B44B40
62322	7	68	1209	12101	18039	\N	55.454968000000001	Нижегородская область, Пильнинский район, Языковский сельсовет, с. Озерки,  ул. Полевая, 7, сельский клуб		0101000020E6100000F4DDAD2CD11D4740FF5C34643CBA4B40
62309	7	68	1209	18400	\N	\N	55.592576000000001	Нижегородская область, Пильнинский район, Большеандосовский сельсовет, с. Ожгибовка, Кирова, 25А, сельский клуб	Россия, Нижегородская область, Пильнинский район, село Ожгибовка	0101000020E6100000560DC2DCEEE746407F32C687D9CB4B40
62331	7	68	1209	19552	\N	\N	55.407463	Нижегородская область, Пильнинский район, Новомочалеевский сельсовет, с. Новомочалеи, Центральная, 55, Дом культуры	Россия, Нижегородская область, Пильнинский район, село Новомочалей	0101000020E6100000A33CF372D8F346403FAA61BF27B44B40
62323	7	68	1209	19144	17089	\N	55.446523999999997	Нижегородская область, Пильнинский район, Языковский сельсовет, с. Наваты, ул. Пролетарская, сельский  клуб		0101000020E61000005D52B5DD042347408670CCB227B94B40
62299	7	68	1209	17896	\N	\N	55.620300999999998	Нижегородская область, Пильнинский район, с. Можаров Майдан, ул. Буденного, 1 а, Дом  культуры	Россия, Нижегородская область, Пильнинский район, село Можаров Майдан	0101000020E6100000EB8CEF8B4BF146408A56EE0566CF4B40
62321	7	68	1209	19046	16822	\N	55.480398000000001	Нижегородская область, Пильнинский район, Медянский сельсовет, с. Медяна, Гагарина, 35, Дом культуры		0101000020E6100000596DFE5F751447402B8881AE7DBD4B40
62314	7	68	1209	18684	\N	\N	55.501345000000001	Нижегородская область, Пильнинский район, Тенекаевский сельсовет, с. Мамешево, здания бывшей начальной школы		0101000020E6100000A14B38F416F54640AE81AD122CC04B40
62303	7	68	1209	18083	16743	\N	55.768374999999999	Нижегородская область, Пильнинский район, Деяновский сельсовет, с. Мальцево, Молодежная, 19, СДК		0101000020E61000004F5DF92CCFEB46403108AC1C5AE24B40
62311	7	68	1209	18504	\N	\N	55.571646999999999	Нижегородская область, Пильнинский район, Большеандосовский сельсовет, с. Малое Андосово, Коммунальная, 4, сельский  Дом культуры	Россия, Нижегородская область, Пильнинский район, село Малое Андосово	0101000020E6100000035E66D828D54640A2ED98BA2BC94B40
62306	7	68	1209	18237	17046	\N	55.830306	Нижегородская область, Пильнинский район, Курмышский сельсовет, с. Курмыш, ул. Трудовая, 46, здание  администрации сельсовета		0101000020E61000009BABE6392209474017D68D7747EA4B40
62327	7	68	1209	19289	16824	\N	55.383163000000003	Нижегородская область, Пильнинский район, Красногорский сельсовет, с. Красная Горка, ул. Кооперативная, 7, Дом культуры		0101000020E61000003E761728290E4740C504357C0BB14B40
62326	7	68	1209	19289	16824	\N	55.383163000000003	Нижегородская область, Пильнинский район, Красногорский сельсовет, с. Красная  Горка, ул. Кооперативная, 7, Дом  культуры		0101000020E61000003E761728290E4740C504357C0BB14B40
62316	7	68	1209	18767	17637	\N	55.511592999999998	Нижегородская область, Пильнинский район, Тенекаевский сельсовет, с. Кисленка, Центральная, 70,Дом культуры		0101000020E61000000589EDEE01FA464067EE21E17BC14B40
62319	7	68	1209	12037	\N	\N	55.503951000000001	Нижегородская область, Пильнинский район, Медянский сельсовет, с. Каменка, ул. Советская, 7,  сельский клуб	Россия, Нижегородская область, Пильнинский район, село Каменка	0101000020E610000065FCFB8C0B094740ACE4637781C04B40
62329	7	68	1209	19454	17297	\N	55.431089999999998	Нижегородская область, Пильнинский район, Петряксинский сельсовет, с. Калиновка, Школьная, 9А,сельский клуб		0101000020E6100000B54FC76306044740FAD005F52DB74B40
62313	7	68	1209	18634	17457	\N	55.492910999999999	Нижегородская область, Пильнинский район, Тенекаевский сельсовет, с. Жданово, Советская, 10,здание территориального подразде		0101000020E6100000789B374E0AEF4640596B28B517BF4B40
62304	7	68	1209	18153	17943	\N	55.794477000000001	Нижегородская область, Пильнинский район, Деяновский сельсовет, с. Деяново, Октябрьская, 40, здание администрации сельсовет	Россия, Нижегородская область, Пильнинский район, село Деяново	0101000020E61000002997C62FBCF646404C361E6CB1E54B40
62302	7	68	1209	18052	17278	\N	55.725721	Нижегородская область, Пильнинский район, Бортсурманский сельсовет, с.Бортсурманы, ул. Нагорная, 27, здание администрации сельсовета		0101000020E6100000F8A92A3410EF46409D82FC6CE4DC4B40
62310	7	68	1209	18427	17049	\N	55.564194999999998	Нижегородская область, Пильнинский район, Большеандосовский сельсовет, с. Большое Андосово, Давыдова, 58,здание администрации сельсовета		0101000020E610000066834C3272E246408AC8B08A37C84B40
62305	7	68	1209	18185	\N	\N	55.817667999999998	Нижегородская область, Пильнинский район, Деяновский сельсовет, д. Беловка, Новая линия, 71,  дом	Россия, Нижегородская область, Пильнинский район, село Беловка	0101000020E6100000A0A696ADF5F746402C7E5358A9E84B40
62325	7	68	1209	19234	16772	\N	55.378380999999997	Нижегородская область, Пильнинский район, Языковский сельсовет, с. Барятино,  ул. Фролова, 62, сельский  клуб		0101000020E610000049641F64591A4740C136E2C96EB04B40
62315	7	68	1209	18714	17267	\N	55.478250000000003	Нижегородская область, Пильнинский район, Тенекаевский сельсовет, с. Балеевка, Колхозная, 3,частный дом	Россия, Нижегородская область, Пильнинский район, село Балеевка	0101000020E61000004339D1AE42FA4640F0A7C64B37BD4B40
62320	7	68	1209	18976	17666	\N	55.510109	Нижегородская область, Пильнинский район, Медянский сельсовет, с. Бакшандино, Лесная, 74,здание ФАПа		0101000020E610000038A27BD6350E4740983270404BC14B40
62300	7	68	1209	17968	17439	\N	55.646054999999997	Нижегородская область, Пильнинский район, Можаров - Майданский сельсовет, с. Арьевка, Молодежная, 10А, сельский клуб		0101000020E610000099F04BFDBCEF4640693524EEB1D24B40
62280	7	68	1465	16958	\N	\N	55.489601	Нижегородская область, Перевозский район, пос.Дзержинского, Лесная, 6	Россия, Нижегородская область, Перевозский район, село имени Дзержинского	0101000020E6100000A587A1D5C93D4640618BDD3EABBE4B40
62291	7	68	1465	17486	\N	\N	55.625439999999998	Нижегородская область, Перевозский район, с.Ягодное, Центральная, 53а	Россия, Нижегородская область, Перевозский район, село Ягодное	0101000020E61000008CDAFD2AC03746401CCEFC6A0ED04B40
61881	7	68	1465	29440	17187	\N	55.688060999999998	Нижегородская область, Перевозский район, с.Шпилево, Микрорайон, 13		0101000020E61000007F6B274A424846409753026212D84B40
62293	7	68	1465	49766	17252	\N	55.599305999999999	Нижегородская область, Перевозский район, пос.Центральный, Центральная, 25		0101000020E6100000AA622AFD844D4640F6251B0FB6CC4B40
62290	7	68	1465	17443	17235	\N	55.571485000000003	Нижегородская область, Перевозский район, с.Тилинино, Молодежная, 14		0101000020E6100000A6B5696CAF314640C993A46B26C94B40
62289	7	68	1465	17375	17615	\N	55.630826999999996	Нижегородская область, Перевозский район, с.Танайково, Молодежная, 21		0101000020E61000004B5AF10D8541464086376BF0BED04B40
62285	7	68	1465	17182	17232	\N	55.421531999999999	Нижегородская область, Перевозский район, с.Сунеево, Центральная, 7		0101000020E6100000696E85B01A3D4640D61BB5C2F4B54B40
62281	7	68	1465	17009	\N	\N	55.562755000000003	Нижегородская область, Перевозский район, с.Ревезень, Школьная, 37а	Россия, Нижегородская область, Перевозский район, село Ревезень	0101000020E610000055DB4DF04D3746408B54185B08C84B40
62279	7	68	1465	16731	\N	\N	55.594306000000003	Нижегородская область, Перевозский район, город Перевоз, Советская, 5а	Россия, Нижегородская область, Перевозский район, поселок Перевоз	0101000020E6100000FCE3BD6A6546464086E8103812CC4B40
62278	7	68	1465	16731	\N	\N	55.594306000000003	Нижегородская область, Перевозский район, город Перевоз, пр-т Советский, 2	Россия, Нижегородская область, Перевозский район, поселок Перевоз	0101000020E6100000FCE3BD6A6546464086E8103812CC4B40
62276	7	68	1465	16731	19459	\N	55.594306000000003	Нижегородская область, Перевозский район, город Перевоз, пр-т Советский, 27		0101000020E6100000FCE3BD6A6546464086E8103812CC4B40
62277	7	68	1465	16731	17604	\N	55.597164511208902	Нижегородская область, Перевозский район, город Перевоз, пр-т Советский, 9	Россия, Нижегородская область, Перевозский район, поселок Перевоз	0101000020E6100000E90AB6114F4646406DA818E76FCC4B40
62286	7	68	1465	16731	17009	\N	55.594306000000003	Нижегородская область, Перевозский район, город Перевоз, 4 микрорайон, 1		0101000020E6100000FCE3BD6A6546464086E8103812CC4B40
62287	7	68	1465	17279	17459	\N	55.753169	Нижегородская область, Перевозский район, с.Палец, Шиянова, 22		0101000020E61000009CDCEF50143E464036AE7FD767E04B40
62288	7	68	1465	17346	17242	\N	55.728727999999997	Нижегородская область, Перевозский район, д.Каменка, Школьная, 30	Россия, Нижегородская область, Перевозский район, село Каменка	0101000020E610000037E2C96E662E4640F9D687F546DD4B40
62292	7	68	1465	17556	17015	\N	55.655574000000001	Нижегородская область, Перевозский район, с.Вельдеманово, Молодежная, 4		0101000020E6100000C5E6E3DA50534640D00D4DD9E9D34B40
62283	7	68	1465	17093	17889	\N	55.520226999999998	Нижегородская область, Перевозский район, с.Б.Кемары, Центральная, 5		0101000020E610000081053065E052464083BF5FCC96C24B40
62268	7	68	1230	16338	16984	\N	54.867522999999998	Нижегородская область, Первомайский район, Петровский сельсовет, с. Шутилово, Больничная, 47		0101000020E61000006B9DB81CAF0E46408FC360FE0A6F4B40
62274	7	68	1230	16645	19462	\N	55.134244000000002	Нижегородская область, Первомайский район, Большемакателемский сельсовет, с. Успенское, Кооперативная, 34		0101000020E6100000232F6B6281E1454095D74AE82E914B40
62265	7	68	1230	16187	17404	\N	55.022902000000002	Нижегородская область, Первомайский район, поселок Сатис, 1 мая, 22		0101000020E61000008080B56AD7E84540AA81E673EE824B40
62267	7	68	1230	16283	17589	\N	54.872931999999999	Нижегородская область, Первомайский район, Петровский сельсовет, д. Петровка, Центральная, 90		0101000020E6100000EEED96E480FB4540E1D05B3CBC6F4B40
62263	7	68	1230	12521	\N	\N	54.867016	Нижегородская область, Первомайский район, г. Первомайск, ул. Мочалина д.1, строение 2	Россия, Нижегородская область, Первомайский район, Первомайск	0101000020E610000001309E4143E74540EB8D5A61FA6E4B40
62261	7	68	1230	12521	19447	\N	54.871365302961898	Нижегородская область, Первомайский район, город Первомайск, Октябрьская, 19	Россия, Нижегородская область, Первомайский район, Первомайск	0101000020E6100000E3E2A8DC44E7454084F068E3886F4B40
62264	7	68	1230	12521	17850	\N	54.867016	Нижегородская область, Первомайский район, город Первомайск, Мочалина, 11		0101000020E610000001309E4143E74540EB8D5A61FA6E4B40
62262	7	68	1230	12521	17585	\N	54.867016	Нижегородская область, Первомайский район, город Первомайск, Ленина, 13 а		0101000020E610000001309E4143E74540EB8D5A61FA6E4B40
62260	7	68	1230	12521	17584	\N	54.867016	Нижегородская область, Первомайский район, город Первомайск, пл.Ульянова, 2 б		0101000020E610000001309E4143E74540EB8D5A61FA6E4B40
62269	7	68	1230	16409	16987	\N	54.877392	Нижегородская область, Первомайский район, Петровский сельсовет, с. Обухово, Полевая, 3		0101000020E6100000990F087426074640D2E28C614E704B40
62271	7	68	1230	16504	\N	\N	54.832287000000001	Нижегородская область, Первомайский район, Петровский сельсовет, с. Николаевка, Молодежная, 11 б	Россия, Нижегородская область, Первомайский район, село Николаевка	0101000020E6100000C5E6E3DA50F1454067F16261886A4B40
62270	7	68	1230	16416	16797	\N	54.813853000000002	Нижегородская область, Первомайский район, Петровский сельсовет, с. Нелей, Молодежная, 18		0101000020E61000002EE6E786A6FE45403160C9552C684B40
62273	7	68	1230	16595	17413	\N	55.102555000000002	Нижегородская область, Первомайский район, Большемакателемский сельсовет, с. Малый Макателем, Клубная, 28		0101000020E6100000C8409E5DBEDB45404985B185208D4B40
62275	7	68	1230	16717	16998	\N	55.020105000000001	Нижегородская область, Первомайский район, Большемакателемский сельсовет, с. Кошелиха, Школьная, 25		0101000020E61000006F490ED8D5C4454038BEF6CC92824B40
62272	7	68	1230	16556	16997	\N	55.064338999999997	Нижегородская область, Первомайский район, Большемакателемский сельсовет, с. Большой Макателем, Молодежная, 15		0101000020E6100000713B342C46D74540BD6DA6423C884B40
62266	7	68	1230	16242	16981	\N	54.946823999999999	Нижегородская область, Первомайский район, Большемакателемский сельсовет, п. Берещино, Советская, 19	Россия, Нижегородская область, Первомайский район, село Берещино	0101000020E610000082FFAD64C7DA4540B188618731794B40
62252	7	68	981	12474	\N	\N	55.959082000000002	Нижегородская область, Павловский район, д. Ясенцы, ул. Юбилейная, д. 8	Россия, Нижегородская область, Павловский район, село Ясенцы	0101000020E6100000A1866F61DD9A45405517F032C3FA4B40
62250	7	68	981	12474	17573	\N	55.959082000000002	Нижегородская область, Павловский район, д.Ясенцы, ул.Центральная, 43, здание сельской администрации		0101000020E6100000A1866F61DD9A45405517F032C3FA4B40
62248	7	68	981	15372	\N	\N	55.897033999999998	Нижегородская область, Павловский район, д. Ярымово, ул. Нет, д. 23	Россия, Нижегородская область, Павловский район, село Ярымово	0101000020E6100000001FBC766991454035B39602D2F24B40
62258	7	68	981	15821	\N	\N	55.994909382442003	Нижегородская область, Павловский район, д. Щепачиха, ул. Нет, д. 65а	Россия, Нижегородская область, Павловский район, село Щепачиха	0101000020E61000002E8CF4A2766D45407FBF982D59FF4B40
62256	7	68	981	15727	17184	\N	56.119785	Нижегородская область, Павловский район, с. Чмутово, ул. Школьная, д. 1		0101000020E6100000A515DF50F892454093C6681D550F4C40
62247	7	68	981	15306	\N	\N	55.859605000000002	Нижегородская область, Павловский район, д. Чернеево, ул. Школьная, д. 3а	Россия, Нижегородская область, Павловский район, село Чернеево	0101000020E61000004D327216F68A4540323D618907EE4B40
62236	7	68	981	14707	17779	\N	55.993907	Нижегородская область, Павловский район, р.п. Тумботино, ул. Школьная, д. 17а		0101000020E61000006B7F677BF4824540FB21365838FF4B40
62234	7	68	981	14707	17164	\N	55.999313581252899	Нижегородская область, Павловский район, р.п. Тумботино, ул. Пролетарская, д. 14а	Россия, Нижегородская область, Павловский район, поселок Тумботино	0101000020E610000020274C18CD824540AC376A85E9FF4B40
62235	7	68	981	14707	17773	\N	55.996600763041101	Нижегородская область, Павловский район, р.п. Тумботино, ул. Буденного, д. 27	Россия, Нижегородская область, Павловский район, поселок Тумботино	0101000020E6100000446B459BE382454098141F9F90FF4B40
62253	7	68	981	15613	17831	\N	55.927427000000002	Нижегородская область, Павловский район, с. Таремское, ул. Школьная, д. 10а		0101000020E610000091B75CFDD8844540B5368DEDB5F64B40
62237	7	68	981	14838	\N	\N	55.980493000000003	Нижегородская область, Павловский район, д. Ст. Щербинино, ул. Нет, д. 138	Россия, Нижегородская область, Павловский район, село Старое Щербинино	0101000020E6100000D9278062647745407D7A6CCB80FD4B40
62241	7	68	981	12363	17382	\N	55.939428999999997	Нижегородская область, Павловский район, д.Пурка, ул. Центральная, д.42, сельский Дом культуры		0101000020E610000053CC41D0D1704540FDF49F353FF84B40
62257	7	68	981	15799	\N	\N	56.120226000000002	Нижегородская область, Павловский район, д. Попадьино, ул. Нет, д. 1а		0101000020E6100000C30E63D2DF8B45408010C990630F4C40
62221	7	68	981	40284	17545	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Пилота, д. 45, школа №14		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62208	7	68	981	40286	19414	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Чкалова, д. 58		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62220	7	68	981	40286	19415	\N	55.971935000000002	"Нижегородская область, Павловский район, г. Павлово, ул. Покровская, д. 1-а, ФОК ""Звезда"""		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62211	7	68	981	40286	19429	\N	55.9607964677665	Нижегородская область, Павловский район, г. Павлово, ул. Лермонтова, д. 16а		0101000020E6100000FBE93F6B7E8E45405610035DFBFA4B40
62217	7	68	981	40286	19412	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Коммунистическая, д. 71		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62254	7	68	981	15661	17389	\N	55.906855	Нижегородская область, Павловский район, д. Молявино, ул. Новая, д. 49	Россия, Нижегородская область, Павловский район, село Молявино	0101000020E6100000EC51B81E85814540679B1BD313F44B40
62243	7	68	981	15112	\N	\N	55.911492000000003	Нижегородская область, Павловский район, д. М. Иголкино, ул. Нет, д. 94	Россия, Нижегородская область, Павловский район, село Малое Иголкино	0101000020E61000005F9A22C0E9714540674815C5ABF44B40
62246	7	68	981	15266	19439	\N	55.912782999999997	Нижегородская область, Павловский район, д. Лаптево, ул. Заводская, д. 5		0101000020E61000004227840EBA8A454021ACC612D6F44B40
62242	7	68	981	15080	\N	\N	55.933438000000002	Нижегородская область, Павловский район, д. Кряжи, ул. Нет, д. 69		0101000020E61000000533A6608D6B4540FD6B79E57AF74B40
62239	7	68	981	14937	16954	\N	56.033560000000001	Нижегородская область, Павловский район, д. Комарово, ул. Центральная, д. 167		0101000020E610000029ECA2E881A14540153AAFB14B044C40
62245	7	68	981	15211	16756	\N	55.952826999999999	Нижегородская область, Павловский район, д. Кишкино, ул. Нагорная, д. 1а		0101000020E6100000FC1D8A027DA2454076DF313CF6F94B40
62244	7	68	981	49635	16727	\N	55.954822999999998	Нижегородская область, Павловский район, д. Грудцино, ул. Школьная, д. 20		0101000020E6100000C8D0B1834AAA4540FB3BDBA337FA4B40
62232	7	68	981	14544	\N	\N	56.128414999999997	Нижегородская область, Павловский район, г. Горбатов, ул. Советская, д. 4а	Россия, Нижегородская область, Павловский район, Горбатов	0101000020E6100000B18A37328F8845406DA818E76F104C40
62231	7	68	981	14544	\N	\N	56.128414999999997	Нижегородская область, Павловский район, г. Горбатов, ул. Свердлова, д. 17	Россия, Нижегородская область, Павловский район, Горбатов	0101000020E6100000B18A37328F8845406DA818E76F104C40
62233	7	68	981	14544	17371	\N	56.134637666949303	Нижегородская область, Павловский район, г. Горбатов, ул. Набережная, д. 2	Россия, Нижегородская область, Павловский район, Горбатов	0101000020E6100000417E3672DD884540416667D13B114C40
62225	7	68	981	14262	\N	\N	55.990569000000001	Нижегородская область, Павловский район, г. Ворсма, ул. Завьялова, д. 24	Россия, Нижегородская область, Павловский район, Ворсма	0101000020E610000026FBE769C0A2454039B709F7CAFE4B40
62228	7	68	981	14262	17363	\N	55.990569000000001	Нижегородская область, Павловский район, г. Ворсма, ул. Строителей, д. 10		0101000020E610000026FBE769C0A2454039B709F7CAFE4B40
62226	7	68	981	14262	16940	\N	55.990569000000001	Нижегородская область, Павловский район, г. Ворсма, ул. Ленина, д. 86		0101000020E610000026FBE769C0A2454039B709F7CAFE4B40
62230	7	68	981	14262	17759	\N	55.990569000000001	Нижегородская область, Павловский район, г. Ворсма, ул. Гагарина, д. 9		0101000020E610000026FBE769C0A2454039B709F7CAFE4B40
62229	7	68	981	14262	17759	\N	55.990569000000001	Нижегородская область, Павловский район, г. Восрма, ул. Гагарина, д. 22		0101000020E610000026FBE769C0A2454039B709F7CAFE4B40
62227	7	68	981	14262	17159	\N	55.990569000000001	Нижегородская область, Павловский район, г. Ворсма, ул. Весенняя, д. 1		0101000020E610000026FBE769C0A2454039B709F7CAFE4B40
62240	7	68	981	14990	17789	\N	55.943275	Нижегородская область, Павловский район, с. Вареж, ул. Школьная, д. 19		0101000020E6100000D6A88768747545403411363CBDF84B40
62255	7	68	981	15714	\N	\N	56.074573999999998	Нижегородская область, Павловский район, д. Борок, ул. Новая, д. 2	Россия, Нижегородская область, Павловский район, село Борок	0101000020E6100000B7B6F0BC54964540E2900DA48B094C40
62097	7	68	981	8215	\N	\N	55.986657000000001	Нижегородская область, Павловский район, с. Б. Окское, ул. Нет, д. 51а		0101000020E61000007A8F334DD88645404BAFCDC64AFE4B40
62249	7	68	981	15439	17180	\N	55.945937000000001	Нижегородская область, Павловский район, с. Б. Давыдово, ул. Озерная, д. 3а		0101000020E610000068E7340BB48F4540C689AF7614F94B40
62238	7	68	981	32512	\N	\N	56.025979999999997	Нижегородская область, Павловский район, с. Абабково, ул. Центральная, д. 290	Россия, Нижегородская область, Павловский район, село Абабково	0101000020E6100000CA1AF5108D944540CF2C095053034C40
61872	7	68	1042	29064	\N	\N	55.514167	Нижегородская область, Навашинский район, р.п. Теша, Кооперативная, 3а, помещение Дома Досуга	Россия, Нижегородская область, Навашинский район, поселок Теша	0101000020E61000007DCEDDAE976845405AD76839D0C14B40
84153	4	34	\N	639	45231	\N	62.028191	Республика Саха (Якутия), город Якутск, Пояркова, 8/2		0101000020E6100000A0C03BF97436604051853FC39B034F40
61867	7	68	1042	28807	16726	\N	55.515343999999999	Нижегородская область, Навашинский район, Натальинский сельсовет, п. Степурино, Школьная, 21, сельская библиотека		0101000020E61000004B0169FF035645404C18CDCAF6C14B40
61864	7	68	1042	28668	17173	\N	55.601635000000002	Нижегородская область, Навашинский район, Большеокуловский сельсовет, с. Сонино, Трудовая, 92, сельская администрация		0101000020E610000010B3976DA737454082902C6002CD4B40
61871	7	68	1042	29001	17147	\N	55.615639000000002	Нижегородская область, Навашинский район, Натальинский сельсовет, д. Салавирь, Советская, 84а, сельская администрация		0101000020E6100000A088450C3B6C454032923D42CDCE4B40
61870	7	68	1042	28968	17979	\N	55.575474999999997	Нижегородская область, Навашинский район, Натальинский сельсовет, д. Рогово, Школьная, 117, сельский дом культуры		0101000020E61000008061F9F36D5945403255302AA9C94B40
61860	7	68	1042	10060	17783	\N	55.634217	Нижегородская область, Навашинский район, Поздняковский сельсовет, с.Поздняково, ул.Богатова, д.59а, помещение сельского Дома культуры		0101000020E610000058CA32C4B11E45409BC8CC052ED14B40
61858	7	68	1042	28415	17778	\N	55.589151999999999	Нижегородская область, Навашинский район, Большеокуловский сельсовет, с. Новошино, Пролетарская, 30, сельский дом культуры		0101000020E6100000C9022670EB1E4540BE2F2E5569CB4B40
61866	7	68	1042	28795	17562	\N	55.530183999999998	Нижегородская область, Навашинский район, Натальинский сельсовет, с. Натальино, Кооперативная, 37, сельская администрация		0101000020E61000003A3DEFC682424540656EBE11DDC34B40
62775	7	68	1042	9126	\N	\N	55.53051	Нижегородская область, Навашинский район, город Навашино, пос. Силикатный, 31, помещение МОУ СОШ №2	Россия, Нижегородская область, Навашинский район, Навашино	0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61855	7	68	1042	9126	\N	\N	55.53051	Нижегородская область, Навашинский район, г.Навашино, пос.Силикатный, д.31, помещение муниципального бюджетного образовательного учреждения средняя общеобразовательная школа №2		0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61852	7	68	1042	9126	\N	\N	55.53051	Нижегородская область, Навашинский район, город Навашино, 1 Мая, 6, помещение МОУ ДОД ДДТ	Россия, Нижегородская область, Навашинский район, Навашино	0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
60963	7	68	1042	9126	17991	\N	55.53051	Нижегородская область, Навашинский район, город Навашино, Трудовая, 4, районная библиотека		0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61854	7	68	1042	9126	16782	\N	55.53051	"Нижегородская область, Навашинский район, город Навашино, Советская, 51, библиотека ""Домик Кирсановой"""		0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61853	7	68	1042	9126	16946	\N	55.53051	Нижегородская область, Навашинский район, город Навашино, Почтовая, 3, детская районная библиотека		0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61868	7	68	1042	9126	16945	\N	55.53051	Нижегородская область, Навашинский район, город Навашино, Лепсе, 6, школа №3		0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61849	7	68	1042	9126	16945	\N	55.511616751400702	Нижегородская область, Навашинский район, город Навашино, Лепсе, 6, помещение МОУ СОШ №3	Россия, Нижегородская область, Навашинский район, Навашино	0101000020E610000017B9A7AB3B1A4540F08975AA7CC14B40
61851	7	68	1042	9126	17555	\N	55.53051	Нижегородская область, Навашинский район, город Навашино, Ленина, 30, помещение МОУ Гимназия		0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61850	7	68	1042	9126	17007	\N	55.519793226253803	Нижегородская область, Навашинский район, г.Навашино, ул. 50 лет Октября, д.20, помещение муниципального бюджетного образовательного учреждения средняя общеобразовательная школа №4	Россия, Нижегородская область, Навашинский район, Навашино	0101000020E6100000F2B4FCC0551A454049D8B79388C24B40
60962	7	68	1042	9126	17007	\N	55.53051	Нижегородская область, Навашинский район, г.Навашино, ул. 50 лет Октября, д.20, помещение муниципального бюджетного образовательного учреждения средняя		0101000020E610000019E3C3EC65194540B9196EC0E7C34B40
61863	7	68	1042	28646	16959	\N	55.741809000000003	Нижегородская область, Навашинский район, Поздняковский сельсовет, с. Монаково, Зеленая, 33б, сельский дом культуры		0101000020E610000046240A2DEB2E45407270E998F3DE4B40
61857	7	68	1042	28330	\N	\N	55.579774999999998	Нижегородская область, Навашинский район, Большеокуловский сельсовет, д. Малое Окулово, Пионерская, 1а, сельский дом культуры	Россия, Нижегородская область, Навашинский район, село Малое Окулово	0101000020E6100000E108522976104540EA04341136CA4B40
61862	7	68	1042	28602	19431	\N	55.670203999999998	Нижегородская область, Навашинский район, Поздняковский сельсовет, с. Коробково, Школьная, 34а, сельский дом культуры		0101000020E6100000DB89929048234540FED2A23EC9D54B40
61861	7	68	1042	28525	17168	\N	55.718882000000001	Нижегородская область, Навашинский район, Поздняковский сельсовет, с. Ефаново, Молодежная, 18, дом сельского дома культуры	Россия, Нижегородская область, Навашинский район, село Ефаново	0101000020E610000058E4D70FB12345406FD74B5304DC4B40
61865	7	68	1042	28716	17811	\N	55.625337999999999	Нижегородская область, Навашинский район, Большеокуловский сельсовет, д. Горицы, Советская, 49, сельский дом культуры		0101000020E6100000A6EECA2E18384540187959130BD04B40
61869	7	68	1042	49718	16963	\N	55.520466999999996	Нижегородская область, Навашинский район, Натальинский сельсовет, д. Валтово, Советская, 20, сельская администрация		0101000020E6100000178046E9D2494540D8D2A3A99EC24B40
61856	7	68	1042	28322	\N	\N	55.559201000000002	Нижегородская область, Навашинский район, Большеокуловский сельсовет, с. Большое Окулово, Клубная, 8а, районный дом культуры	Россия, Нижегородская область, Навашинский район, село Большое Окулово	0101000020E6100000E76F4221021C4540FC71FBE593C74B40
61768	7	68	390	24273	\N	\N	56.015720999999999	Нижегородская область, Лысковский район, с. Чернуха, Клуб	Россия, Нижегородская область, Лысковский район, село Чернуха	0101000020E6100000AA46AF0628934640226E4E2503024C40
61823	7	68	390	49632	\N	\N	56.136590242138901	Нижегородская область, Лысковский район, Черномазский сельсовет, Сельская администрация	Россия, Нижегородская область, Лысковский район, село Черная Маза	0101000020E61000002D793C2D3F924640F67AF7C77B114C40
61839	7	68	390	49752	\N	\N	56.083166106079702	Нижегородская область, Лысковский район, Ушаковка, магазин	Россия, Нижегородская область, Лысковский район, село Ушаковка	0101000020E6100000850A0E2F88924640CF11F92EA50A4C40
61840	7	68	390	3389	\N	\N	56.040551000000001	Нижегородская область, Лысковский район, с. Трофимово, Дом культуры	Россия, Нижегородская область, Лысковский район, село Трофимово	0101000020E610000094FAB2B4538B4640F96871C630054C40
61831	7	68	390	49799	\N	\N	56.105269	Нижегородская область, Лысковский район, с. Просек, школа	Россия, Нижегородская область, Лысковский район, село Просек	0101000020E6100000C9022670EB9646402D246074790D4C40
61832	7	68	390	27223	\N	\N	56.000044000000003	Нижегородская область, Лысковский район, Петровка, клуб		0101000020E6100000F8DF4A766CAE4640D047197101004C40
61844	7	68	390	27794	\N	\N	56.050505999999999	Нижегородская область, Лысковский район, Кисловский сельсовет, с. Окинино, контора	Россия, Нижегородская область, Лысковский район, село Окинино	0101000020E610000032E9EFA5F06C46403A2009FB76064C40
61835	7	68	390	27358	\N	\N	55.961682000000003	Нижегородская область, Лысковский район, с. Никольское, сельская администрация		0101000020E61000005F99B7EA3A9A46407193516518FB4B40
61845	7	68	390	27807	\N	\N	55.996071999999998	Нижегородская область, Лысковский район, п. Нива, Дом культуры	Россия, Нижегородская область, Лысковский район, село Нива	0101000020E6100000689604A8A96546400C3B8C497FFF4B40
61838	7	68	390	27491	\N	\N	56.023369000000002	Нижегородская область, Лысковский район, д. Неверово, комбинат стройматериалов		0101000020E6100000813FFCFCF7884640C05E61C1FD024C40
61837	7	68	390	27456	\N	\N	55.952680999999998	Нижегородская область, Лысковский район, Леньковский сельсовет, д. Малиновка, сельская администрация		0101000020E6100000758E01D9EB814640A2427573F1F94B40
61846	7	68	390	12415	\N	\N	56.089271988544397	Нижегородская область, Лысковский район, п. Макарьево	Россия, Нижегородская область, Лысковский район, поселок Макарьево	0101000020E61000000EF3E505D88746406939D0436D0B4C40
61842	7	68	390	9379	\N	\N	55.990271999999997	Нижегородская область, Лысковский район, с. Ляпуны, клуб		0101000020E6100000D0B52FA0177E46407F129F3BC1FE4B40
61821	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, Дом детского творчества		0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61820	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, швейная фабрика	Россия, Нижегородская область, Лысковский район, Лысково	0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61819	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, Чехова, средняя школа №3	Россия, Нижегородская область, Лысковский район, Лысково	0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61818	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, Ленина, ПАП		0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61816	7	68	390	16552	\N	\N	56.025426320537299	Нижегородская область, Лысковский район, город Лысково, ЦЗН	Россия, Нижегородская область, Лысковский район, Лысково	0101000020E61000001D03B2D7BB854640EB3BBF2841034C40
61814	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, детский дом		0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61813	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, школа №5	Россия, Нижегородская область, Лысковский район, Лысково	0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61812	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, школа №2	Россия, Нижегородская область, Лысковский район, Лысково	0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61809	7	68	390	16552	\N	\N	56.027796000000002	"Нижегородская область, Лысковский район, город Лысково, красный уголок филиала ПО ""Автпровод"""		0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61808	7	68	390	16552	\N	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, Контора мехлесхоза	Россия, Нижегородская область, Лысковский район, Лысково	0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61815	7	68	390	16552	16706	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, Мичурина, ДК		0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61811	7	68	390	16552	16706	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, Мичурина, 75 (фойе административного здания)		0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
61810	7	68	390	16552	16706	\N	56.027796000000002	Нижегородская область, Лысковский район, город Лысково, Мичурина, 75 (столовая Агротехникума)		0101000020E6100000CB4DD4D2DC844640D57ABFD18E034C40
84023	4	34	\N	639	45231	\N	62.028191	Республика Саха (Якутия), город Якутск, Пояркова, 15		0101000020E6100000A0C03BF97436604051853FC39B034F40
61817	7	68	390	16552	17660	\N	56.0301484440511	Нижегородская область, Лысковский район, город Лысково, 50 лет ВЛКСМ, соцзащита		0101000020E61000000A1346B3B28546401805C1E3DB034C40
61843	7	68	390	27733	\N	\N	56.001911999999997	д. Летнево, Кириковский сельсовет, Лысковский район, Нижегородская обл, школа		0101000020E61000007FC16ED8B674464027BC04A73E004C40
61806	7	68	390	15531	\N	\N	55.967925000000001	Нижегородская область, Лысковский район, с. Леньково, школа	Россия, Нижегородская область, Лысковский район, село Леньково	0101000020E61000002DE92807B39746408BFD65F7E4FB4B40
61827	7	68	390	49773	\N	\N	56.065884709709799	Нижегородская область, Лысковский район, д. Кременки, восьмилетняя школа	Россия, Нижегородская область, Лысковский район, село Кременки	0101000020E61000007D1F0E12A2B84640032670EB6E084C40
61830	7	68	390	27137	\N	\N	56.081491999999997	Нижегородская область, Лысковский район, с. Красный Оселок, школа	Россия, Нижегородская область, Лысковский район, село Красный Оселок	0101000020E6100000C1E61C3C13A446405C7171546E0A4C40
61841	7	68	390	24388	\N	\N	56.023203000000002	Нижегородская область, Лысковский район, с. Кириково, сельская администрация	Россия, Нижегородская область, Лысковский район, село Кириково	0101000020E6100000AFB0E07EC07D4640A515DF50F8024C40
61834	7	68	390	3341	\N	\N	55.924885000000003	Нижегородская область, Лысковский район, с. Елховка, клуб		0101000020E6100000909E228788AF4640CEC7B5A162F64B40
61824	7	68	390	7948	\N	\N	56.117832999999997	Нижегородская область, Лысковский район, с.Великовское, с/администрация	Россия, Нижегородская область, Лысковский район, село Великовское	0101000020E6100000537B116DC7AE4640DDB1D826150F4C40
61826	7	68	390	20277	\N	\N	56.032966999999999	Нижегородская область, Лысковский район, с. Варганы, начальная школа	Россия, Нижегородская область, Лысковский район, село Варганы	0101000020E6100000085A8121ABB74640726C3D4338044C40
61822	7	68	390	16587	\N	\N	56.123663999999998	Нижегородская область, Лысковский район, Валковский сельсовет, с.Валки, школа		0101000020E6100000B81E85EB517E4640A5D8D138D40F4C40
61836	7	68	390	27403	\N	\N	55.932813000000003	Нижегородская область, Лысковский район, Леньковский сельсовет, д. Валава, клуб		0101000020E6100000742843554C7B46404F24986A66F74B40
61833	7	68	390	2021	\N	\N	55.989764000000001	Нижегородская область, Лысковский район, с. Берендеевка, сельская администрация		0101000020E6100000E8F692C668A346400B613596B0FE4B40
61828	7	68	390	22701	\N	\N	56.038434000000002	Нижегородская область, Лысковский район, с. Белозериха, школа	Россия, Нижегородская область, Лысковский район, село Белозериха	0101000020E6100000F20C1AFA27AC4640F986C267EB044C40
61825	7	68	390	13044	\N	\N	56.107629000000003	Нижегородская область, Лысковский район, с. Бармино, Дом культуры		0101000020E6100000634337FB03C14640F48C7DC9C60D4C40
61829	7	68	390	27072	\N	\N	56.035874	Нижегородская область, Лысковский район, с. Асташиха, клуб		0101000020E6100000C05FCC96ACA446406B63EC8497044C40
61783	7	68	1502	24970	\N	\N	55.012991999999997	Нижегородская область, Лукояновский район, Шандровский сельсовет, с. Шандрово, Центральная, 3	Россия, Нижегородская область, Лукояновский район, село Шандрово	0101000020E6100000672783A3E4274640088ECBB8A9814B40
61755	7	68	1502	23647	\N	\N	55.125922000000003	Нижегородская область, Лукояновский район, Лопатинский сельсовет, с. Чуфарово, Ленина, 9-А	Россия, Нижегородская область, Лукояновский район, село Чуфарово	0101000020E6100000FC8C0B074252464068EC4B361E904B40
61799	7	68	1502	25722	18204	\N	55.038981	Нижегородская область, Лукояновский район, Большеарский сельсовет, с. Чиргуши, Ватракшонка, 43		0101000020E6100000E9F351465C5C46402B155454FD844B40
61767	7	68	1502	49776	17308	\N	55.043700999999999	Нижегородская область, Лукояновский район, город Лукоянов, с. Ульяново, 1-Мая Станция юнных натуралистов, 2-В	Россия, Нижегородская область, Лукояновский район, село Ульяново	0101000020E6100000516C054D4B344640B8E68EFE97854B40
61772	7	68	1502	24476	17271	\N	54.949213	Нижегородская область, Лукояновский район, Тольско-Майданский сельсовет, с. Тольский Майдан, Ленина, 125		0101000020E61000009C69C2F69353464012F8C3CF7F794B40
61789	7	68	1502	25209	17341	\N	55.085161999999997	Нижегородская область, Лукояновский район, Лопатинский сельсовет, д. Сонино, Аряева, 45		0101000020E61000006E32AA0CE3424640546EA296E68A4B40
61778	7	68	1502	49831	17680	\N	54.839370000000002	Нижегородская область, Лукояновский район, рабочий поселок им. Степана Разина, с. Санки, Центральная, 40	Россия, Нижегородская область, Лукояновский район, село Санки	0101000020E61000008D47A984271C46402C9FE579706B4B40
61784	7	68	1502	25035	19441	\N	55.020826999999997	Нижегородская область, Лукояновский район, Шандровский сельсовет, с. Салдаманово, Базарная, 1-А		0101000020E61000008E20956247234640D8EF8975AA824B40
61782	7	68	1502	24941	\N	\N	55.000208000000001	Нижегородская область, Лукояновский район, Шандровский сельсовет, с. Салдаманов Майдан, Шихарева, 114	Россия, Нижегородская область, Лукояновский район, село Салдаманов Майдан	0101000020E610000090F8156BB82046404A99D4D006804B40
61795	7	68	1502	25518	17316	\N	55.121293999999999	Нижегородская область, Лукояновский район, Большеарский сельсовет, с. Саврасово, Молодежная, 4-А		0101000020E6100000ADA23F34F3584640BB99D18F868F4B40
61786	7	68	1502	25104	16834	\N	55.074576999999998	Нижегородская область, Лукояновский район, Шандровский сельсовет, с. Поя, Школьная, 1		0101000020E61000009E7C7A6CCB284640530438BD8B894B40
61770	7	68	1502	24368	17688	\N	54.995151999999997	Нижегородская область, Лукояновский район, Кудеяровский сельсовет, с. Иванцево, пл.Победы, 12		0101000020E6100000D2A6EA1ED930464045460724617F4B40
61777	7	68	1502	49657	16831	\N	54.7489926103054	Нижегородская область, Лукояновский район, рабочий поселок им. Степана Разина, с. Покровка, Центральная, 46	Россия, Нижегородская область, Лукояновский район, село Покровка	0101000020E6100000BC7669C3612946406AF7AB00DF5F4B40
61797	7	68	1502	25713	17116	\N	55.070739652067999	Нижегородская область, Лукояновский район, Большеарский сельсовет, с. Пичингуши, Советская, 89	Россия, Нижегородская область, Лукояновский район, село Пичингуши	0101000020E61000002EE23B31EB694640704221020E894B40
61781	7	68	1502	49746	17110	\N	54.801714946153503	Нижегородская область, Лукояновский район, рабочий поселок им. Степана Разина, с. Печи, Школьная, 10	Россия, Нижегородская область, Лукояновский район, село Печи	0101000020E6100000C07ADCB75A29464038DBDC989E664B40
61793	7	68	1502	25422	18176	\N	55.181764999999999	Нижегородская область, Лукояновский район, Лопатинский сельсовет, с. Перемчалки, Золина, 20-А		0101000020E61000009C4EB2D5E54A46405A47551344974B40
61798	7	68	1502	25695	17117	\N	55.066360000000003	Нижегородская область, Лукояновский район, Большеарский сельсовет, с. Новоселки, Клубная, 146	Россия, Нижегородская область, Лукояновский район, село Новоселки	0101000020E6100000DB368C82E06346409CE1067C7E884B40
61776	7	68	1502	50030	19460	\N	54.822007999999997	Нижегородская область, Лукояновский район, рабочий поселок им. Степана Разина, с. Новомихайловка, Кадышева, 24	Россия, Нижегородская область, Лукояновский район, село Новомихайловка	0101000020E6100000BF61A2410A3446407286E28E37694B40
61800	7	68	1502	25769	16922	\N	55.002661000000003	Нижегородская область, Лукояновский район, Большеарский сельсовет, с. Никулино, Советская, 70		0101000020E6100000D8666325E65D4640C2FC153257804B40
61804	7	68	1502	25968	\N	\N	55.039445000000001	Нижегородская область, Лукояновский район, Большемаресьевский сельсовет, с. Нехорошево, Сельская, 39	Россия, Нижегородская область, Лукояновский район, село Нехорошево	0101000020E6100000C0B167CF65704640D07EA4880C854B40
61787	7	68	1502	25152	19445	\N	55.128553378425998	Нижегородская область, Лукояновский район, Лопатинский сельсовет, с. Неверово, Западная, 1-А	Россия, Нижегородская область, Лукояновский район, село Неверово	0101000020E6100000BA69334E43344640BE66B96C74904B40
61771	7	68	1502	24376	\N	\N	54.989471000000002	Нижегородская область, Лукояновский район, Тольско-Майданский сельсовет, с. Мерлиновка, Ленина, 96	Россия, Нижегородская область, Лукояновский район, село Мерлиновка	0101000020E6100000AEBCE47FF247464093AB58FCA67E4B40
61773	7	68	1502	50031	19465	\N	54.909352119048599	Нижегородская область, Лукояновский район, Тольско-Майданский сельсовет, с. Малое Мамлеево, Новикова, 85		0101000020E610000013B875374F454640AE4676A565744B40
61802	7	68	1502	25886	16765	\N	55.000853999999997	Нижегородская область, Лукояновский район, Большемаресьевский сельсовет, с. Малая Поляна, Заречная, 90		0101000020E610000065A54929E87646400F09DFFB1B804B40
61766	7	68	1502	23883	\N	\N	55.034508000000002	Нижегородская область, Лукояновский район, город Лукоянов, с. Ульяново, Пролетарская, 76-А	Россия, Нижегородская область, Лукояновский район, Лукоянов	0101000020E61000009BE61DA7E83C4640A6B915C26A844B40
61765	7	68	1502	23883	\N	\N	55.034508000000002	Нижегородская область, Лукояновский район, город Лукоянов, Дзержинского, 43	Россия, Нижегородская область, Лукояновский район, Лукоянов	0101000020E61000009BE61DA7E83C4640A6B915C26A844B40
61763	7	68	1502	23883	\N	\N	55.034508000000002	Нижегородская область, Лукояновский район, город Лукоянов, Октябрьская, 47	Россия, Нижегородская область, Лукояновский район, Лукоянов	0101000020E61000009BE61DA7E83C4640A6B915C26A844B40
61762	7	68	1502	23883	17676	\N	55.034508000000002	Нижегородская область, Лукояновский район, город Лукоянов, пл. Мира Районный дом культуры, 8А		0101000020E61000009BE61DA7E83C4640A6B915C26A844B40
61764	7	68	1502	23883	17679	\N	55.034508000000002	Нижегородская область, Лукояновский район, город Лукоянов, Микрорайон №1, 15А		0101000020E61000009BE61DA7E83C4640A6B915C26A844B40
61761	7	68	1502	23883	17758	\N	55.034508000000002	Нижегородская область, Лукояновский район, город Лукоянов, Кирова Лукояновская средняя школа №1, 34		0101000020E61000009BE61DA7E83C4640A6B915C26A844B40
61791	7	68	1502	25420	\N	\N	55.110506999999998	Нижегородская область, Лукояновский район, Лопатинский сельсовет, с. Лопатино, Новая Линия, 9	Россия, Нижегородская область, Лукояновский район, село Лопатино	0101000020E6100000DC2F9FAC184A4640527DE717258E4B40
61769	7	68	1502	24277	17490	\N	55.021101000000002	Нижегородская область, Лукояновский район, Кудеяровский сельсовет, с. Кудеярово, Державина, 16		0101000020E61000003BE5D18DB03A4640DA740470B3824B40
61788	7	68	1502	25207	\N	\N	55.106546000000002	Нижегородская область, Лукояновский район, Лопатинский сельсовет, с. Крюковка, 1-Мая, 65	Россия, Нижегородская область, Лукояновский район, село Крюковка	0101000020E61000004A287D21E43E464083C2A04CA38D4B40
61803	7	68	1502	25900	17511	\N	54.959718000000002	Нижегородская область, Лукояновский район, Большемаресьевский сельсовет, с. Красная Поляна, Лесная, 24		0101000020E6100000D49CBCC8046E4640F7B0170AD87A4B40
61779	7	68	1502	17483	\N	\N	54.891705999999999	Нижегородская область, Лукояновский район, рабочий поселок им. Степана Разина, Ленина, 94	Россия, Нижегородская область, Лукояновский район, поселок Имени Степана Разина	0101000020E6100000DD25715644254640D0D2156C23724B40
61780	7	68	1502	17483	17127	\N	54.891705999999999	Нижегородская область, Лукояновский район, р.п. Степана Разина,  ул.Школьная, д.15		0101000020E6100000DD25715644254640D0D2156C23724B40
61801	7	68	1502	25830	17122	\N	54.995803000000002	Нижегородская область, Лукояновский район, Большемаресьевский сельсовет, с. Елфимово, Советская, 80-А		0101000020E6100000F964C570756A46401D210379767F4B40
61796	7	68	1502	25587	17504	\N	55.068900999999997	Нижегородская область, Лукояновский район, Большеарский сельсовет, д. Докучаево, Зеленая, 72-А		0101000020E61000008B1BB7989F5B4640B2D47ABFD1884B40
61774	7	68	1502	24574	17655	\N	54.873538000000003	Нижегородская область, Лукояновский район, Тольско-Майданский сельсовет, с. Гари, 1-Мая, 34		0101000020E6100000AC55BB26A43D464019E8DA17D06F4B40
61792	7	68	1502	25376	17729	\N	55.156821000000001	Нижегородская область, Лукояновский район, Лопатинский сельсовет, д. Владимировка, Чкалова, 15-Б		0101000020E6100000BAA29410AC464640BB29E5B512944B40
61805	7	68	1502	26021	18507	\N	55.033423999999997	Нижегородская область, Лукояновский район, Большемаресьевский сельсовет, с. Большое Маресьево, Советская, 2		0101000020E61000006EC328081E7746406473D53C47844B40
61775	7	68	1502	50045	19518	\N	55.002805242455203	Нижегородская область, Лукояновский район, Тольско-Майданский сельсовет, с. Большое Мамлеево, Колхозная, 10	Россия, Нижегородская область, Лукояновский район, село Большое Мамлево	0101000020E61000009758198D7C404640F5A10BEA5B804B40
61794	7	68	1502	25483	16763	\N	55.063045000000002	Нижегородская область, Лукояновский район, Большеарский сельсовет, с. Большая Аря, Сластяева, 1		0101000020E6100000B1C398F4F75246409296CADB11884B40
61785	7	68	1502	25073	\N	\N	55.037990000000001	Нижегородская область, Лукояновский район, Шандровский сельсовет, с. Атингеево, Молодежная, 1-А	Россия, Нижегородская область, Лукояновский район, село Атингеево	0101000020E6100000C59272F7391E46409BC937DBDC844B40
61790	7	68	1502	25295	\N	\N	55.142380000000003	Нижегородская область, Лукояновский район, Лопатинский сельсовет, с. Александровка, Колхозная, 91	Россия, Нижегородская область, Лукояновский район, село Александровка	0101000020E6100000723271AB203E464060CD018239924B40
61748	7	68	1292	23303	\N	\N	55.407882999999998	Нижегородская область, Кулебакский район, с.Шилокша, ул.Школьная, д.8, школа	Россия, Нижегородская область, Кулебакский район, село Шилокша	0101000020E6100000221B48179B5A454014CC988235B44B40
61750	7	68	1292	23303	16686	\N	55.407882999999998	Нижегородская область, Кулебакский район, Тепловский сельсовет, д. Шилокша, Школьная, 8, школа		0101000020E6100000221B48179B5A454014CC988235B44B40
61747	7	68	1292	13578	\N	\N	55.235056	Нижегородская область, Кулебакский район, д.Серебрянка, ул.Новая, д.1, школа	Россия, Нижегородская область, Кулебакский район, село Серебрянка	0101000020E6100000E94317D4B75C4540425DA450169E4B40
61760	7	68	1292	17593	17036	\N	55.457040999999997	Нижегородская область, Кулебакский район, с.Саваслейка, ул.Революции, д.1, 1 этаж, Здание администрации Саваслейского сельсовета	Россия, Нижегородская область, Кулебакский район, село Саваслейка	0101000020E6100000CEC7B5A1622845402FF7C95180BA4B40
61758	7	68	1292	23782	\N	\N	55.434533000000002	Нижегородская область, Кулебакский район, п.Первомайский, ул.Зеленая, д.1а, 1 этаж, клуб	Россия, Нижегородская область, Кулебакский район, село Первомайский	0101000020E610000048533D997F364540320400C79EB74B40
61757	7	68	1292	16820	\N	\N	55.450665000000001	Нижегородская область, Кулебакский район, с.Мурзицы, ул.Новая Стройка, д.5 а, 1 этаж, Здание Районного Дома Культуры	Россия, Нижегородская область, Кулебакский район, село Мурзицы	0101000020E6100000F01307D0EF3D4540D6390664AFB94B40
61759	7	68	1292	17555	17083	\N	55.442941447639001	Нижегородская область, Кулебакский район, п.Молочная Ферма, ул.Рабочая, д.14а, 1 этаж, клуб	Россия, Нижегородская область, Кулебакский район, поселок Молочной Фермы	0101000020E61000001D058882194945405D876A4AB2B84B40
61746	7	68	1292	13529	\N	\N	55.302596999999999	Нижегородская область, Кулебакский район, с.Михайловка, ул.Труда, д.2, школа	Россия, Нижегородская область, Кулебакский район, село Михайловка	0101000020E6100000DB368C82E0634540116F9D7FBBA64B40
61749	7	68	1292	17715	17638	\N	55.416816513276203	Нижегородская область, Кулебакский район, с.Ломовка, ул.Школьная, д.26, школа	Россия, Нижегородская область, Кулебакский район, село Ломовка	0101000020E6100000AB24B20FB26445405BB56B425AB54B40
61737	7	68	1292	49765	80901	\N	55.416818999999997	Нижегородская область, Кулебакский район, г.Кулебаки, ул.Некрасова, д.12, Контора ОАО «Кулебакский завод металлических конструкций»		0101000020E6100000990D32C9C83F4540FBAC32535AB54B40
61731	7	68	1292	49765	17247	\N	55.415793999999998	"Нижегородская область, Кулебакский район, город Кулебаки, Ад.Макарова, 72, Детский комбинат ""Светлячок"""		0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61728	7	68	1292	49731	17022	\N	55.415793999999998	Нижегородская область, Кулебакский район, город Кулебаки, Циолковского, 41, ДОСААФ		0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61744	7	68	1292	49731	17198	\N	55.413862964426301	Нижегородская область, Кулебакский район, г.Кулебаки, ул.Ст.Разина, д.164А, Молодежный центр	Россия, Нижегородская область, Кулебаки	0101000020E6100000CFD8976C3C44454021037976F9B44B40
61739	7	68	1292	49731	17641	\N	55.396180328301398	Нижегородская область, Кулебакский район, город Кулебаки, Догадина, 31, школа №7	Россия, Нижегородская область, Кулебаки	0101000020E610000099D6A6B1BD44454026AAB706B6B24B40
61752	7	68	1292	16722	19792	\N	55.3916135340775	Нижегородская область, Кулебакский район, р.п.Гремячево-1, пл.Свободы, д.2, школа	Россия, Нижегородская область, Кулебакский район, поселок Гремячево	0101000020E6100000056C0723F6834540EF53556820B24B40
61753	7	68	1292	16722	16704	\N	55.390831850437401	Нижегородская область, Кулебакский район, р.п.Гремячево-2, ул.Ленина, д.44, школа	Россия, Нижегородская область, Кулебакский район, поселок Гремячево	0101000020E61000002A7288B8398345407A1D71C806B24B40
61751	7	68	1292	16722	17509	\N	55.3893514563457	Нижегородская область, Кулебакский район, р.п.Гремячево-1, ул.Гагарина, д.73, д/с «Теполек»	Россия, Нижегородская область, Кулебакский район, поселок Гремячево	0101000020E61000007731CD74AF8345401BD5E940D6B14B40
61754	7	68	1292	23574	18034	\N	55.336179999999999	Нижегородская область, Кулебакский район, р.п.Велетьма, ул.Первомайская, 1 этаж, Здание администрации		0101000020E6100000DA8EA9BBB2354540DEC83CF207AB4B40
61756	7	68	1292	23574	16823	\N	55.336179999999999	Нижегородская область, Кулебакский район, поселок Велетьма, Первомайская, Администрация р.п.Велетьма	Россия, Нижегородская область, Кулебакский район, поселок Велетьма	0101000020E6100000DA8EA9BBB2354540DEC83CF207AB4B40
61740	7	68	7005	50018	19405	\N	55.415793999999998	Нижегородская область, Кулебакский район, г.Кулебаки, ул.Футбольная , д.3, МОУ «Средняя общеобразовательная школа №10»		0101000020E6100000541EDD088B424540BFEFDFBC38B54B40
61710	7	68	926	9627	\N	\N	56.078352000000002	Нижегородская область, Кстовский район, с. Шелокша, школа с. Шелокша	Россия, Нижегородская область, Кстовский район, село Шелокша	0101000020E610000078094E7D20134640C1C93670070A4C40
61713	7	68	926	21673	\N	\N	56.067469000000003	Нижегородская область, Кстовский район, с. Шава, ул. Новая, д. 8, фельдшерский пункт	Россия, Нижегородская область, Кстовский район, село Шава	0101000020E61000008011346612334640363FFED2A2084C40
61724	7	68	926	22253	\N	\N	55.971431000000003	Нижегородская область, Кстовский район, д. Чернышиха, д. 4, здание сельской администрации		0101000020E6100000187D0569C654464009A9DBD957FC4B40
61709	7	68	926	21520	17873	\N	56.026015000000001	Нижегородская область, Кстовский район, с. Чернуха, ул. Школьная, д. 47, дом культуры		0101000020E6100000C47762D68B1546404C1AA37554034C40
61691	7	68	926	49749	\N	\N	56.1913243728604	Нижегородская область, Кстовский район, д. Фроловское, школа		0101000020E61000009BE5B2D1390B46404F78094E7D184C40
61688	7	68	926	50016	\N	\N	56.225613594793003	Нижегородская область, Кстовский район, д. Федяково, школа	Россия, Нижегородская область, село Федяково, улица Школьная	0101000020E6100000840F255AF206464087C267EBE01C4C40
61683	7	68	926	50039	\N	\N	56.246387640449598	Нижегородская область, Кстовский район, д. Утечино, д. 5, здание ФАП	Россия, Нижегородская область, деревня Утечино, 5	0101000020E6100000EAD0E979370A46403D1059A4891F4C40
61715	7	68	926	7407	\N	\N	56.010311999999999	Нижегородская область, Кстовский район, с. Слободское, клуб	Россия, Нижегородская область, Кстовский район, село Слободское	0101000020E610000087C0914083314640D06053E751014C40
61689	7	68	926	49706	\N	\N	56.237123254921698	Нижегородская область, Кстовский район, д. Ржавка, школа		0101000020E6100000F646AD307D0D46409010E50B5A1E4C40
61718	7	68	926	9391	16734	\N	56.039163000000002	Нижегородская область, Кстовский район, с.Работки, ул. Ленина, д.184, школа		0101000020E61000009CF9D51C204E46404C1B0E4B03054C40
61717	7	68	926	9391	16734	\N	56.039163000000002	Нижегородская область, Кстовский район, с. Работки, ул. Ленина, д. 184, школа		0101000020E61000009CF9D51C204E46404C1B0E4B03054C40
61721	7	68	926	22101	17234	\N	55.964458	Нижегородская область, Кстовский район, д. Прокошево, ул. Молькова, д. 1-А, дом культуры		0101000020E610000058E6ADBA0E3B4640CB2E185C73FB4B40
61722	7	68	926	49764	17237	\N	55.964458	Нижегородская область, Кстовский район, д. Прокошево, ул. Молькова, д. 8-А, здание сельской администрации		0101000020E610000058E6ADBA0E3B4640CB2E185C73FB4B40
61716	7	68	926	49620	\N	\N	56.022548585984403	Нижегородская область, Кстовский район, д. Подлесово, школа	Россия, Нижегородская область, Кстовский район, село Подлесово	0101000020E61000004B3E7617282946405CC7B8E2E2024C40
61698	7	68	926	12842	\N	\N	56.121400999999999	Нижегородская область, Кстовский район, с. Новые Ключищи, медпункт		0101000020E610000086A92D7590014640D15966118A0F4C40
61708	7	68	926	9450	16776	\N	56.120475873314703	Нижегородская область, Кстовский район, д. Новоликеево, ул. Ленина, д. 3, здание сельской администрации	Россия, Нижегородская область, Кстовский район, село Новоликеево	0101000020E6100000FFCF61BEBC1E4640F8F9EFC16B0F4C40
61706	7	68	926	9450	16776	\N	56.117833954971303	Нижегородская область, Кстовский район, с. Новоликеево, ул. Ленина, д. 3, здание сельской администрации	Россия, Нижегородская область, Кстовский район, село Новоликеево	0101000020E610000044FAEDEBC01F4640AE2D3C2F150F4C40
61704	7	68	926	13037	19457	\N	56.120562999999997	Нижегородская область, Кстовский район, д. Михальчиково, ул. Школьная, клуб	Россия, Нижегородская область, Кстовский район, село Михальчиково	0101000020E61000001A6F2BBD362B4640C70DBF9B6E0F4C40
61720	7	68	926	22057	\N	\N	56.003256	Нижегородская область, Кстовский район, д. Малиновка, д.6, медпункт	Россия, Нижегородская область, Кстовский район, село Малиновка	0101000020E6100000B3CD8DE90953464005C24EB16A004C40
61705	7	68	926	21296	\N	\N	56.024194000000001	Нижегородская область, Кстовский район, д. Лавровка, д. 3, магазин		0101000020E61000004A7F2F85074946403561FBC918034C40
61684	7	68	926	50036	19486	\N	56.289884684228902	Нижегородская область, Кстовский район, д. Кузьминка, ул. Талалушкина, здание ФАП		0101000020E6100000008BFCFA210C4640EC4CA1F31A254C40
61673	7	68	926	49700	17474	\N	56.144982214232698	Нижегородская область, Кстовский район, г. Кстово, пл. Мира, школа №4		0101000020E610000016139B8F6B1946401C412AC58E124C40
33308	4	41	\N	16582	46242	\N	48.779257999999999	г. Биробиджан, Космонавтов, 13		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
61668	7	68	926	49700	19471	\N	56.1471477186535	Нижегородская область, Кстовский район, г. Кстово, пл. Ленина, д. 2-А, библиотека		0101000020E6100000DB148F8B6A194640FED5E3BED5124C40
61675	7	68	926	49700	19615	\N	56.146649682202103	Нижегородская область, Кстовский район, г. Кстово, бульвар Мира, д. 2-А, центр. детская библиотека		0101000020E6100000FFB1101D02194640ADFA5C6DC5124C40
61681	7	68	926	49700	19403	\N	56.139809400808097	Нижегородская область, Кстовский район, г. Кстово, ул. Чванова, школа № 6		0101000020E6100000111956F1461A4640DE57E542E5114C40
61670	7	68	926	49700	19403	\N	56.105327439475502	"Нижегородская область, Кстовский район, г. Кстово, ул. Чванова, д. 1-А, актовый зал ОАО ""Нижегородоблгаз"""		0101000020E61000002FC1A90F241346406231EA5A7B0D4C40
61661	7	68	926	49700	19766	\N	56.137828149875801	Нижегородская область, Кстовский район, г. Кстово, ул. Советская, д. 50, школа № 1		0101000020E61000006B2C616D8C1746408E3C1059A4114C40
61667	7	68	926	49700	17586	\N	56.102375864554404	Нижегородская область, Кстовский район, г. Кстово, ул. Лукерьинская, д. 3, детский сад № 50		0101000020E6100000CA6E66F4A317464099F221A81A0D4C40
61678	7	68	926	49700	19532	\N	56.148438259843502	Нижегородская область, Кстовский район, г. Кстово, ул. Зеленая, д. 1-А, шахматная школа		0101000020E61000008061F9F36D174640E8BD310400134C40
61662	7	68	926	49700	16908	\N	56.1139237950336	Нижегородская область, Кстовский район, г. Кстово, ул. Береговая, детский сад №5		0101000020E6100000AE9CBD33DA124640601DC70F950E4C40
61676	7	68	926	49700	17079	\N	56.115209649503498	Нижегородская область, Кстовский район, г. Кстово, 2 микрорайон, школа №3		0101000020E6100000EF703B342C14464009168733BF0E4C40
61723	7	68	926	22174	\N	\N	55.947806999999997	Нижегородская область, Кстовский район, с. Игумново, д. 23, медпункт		0101000020E61000009947FE60E05B4640BEF561BD51F94B40
61703	7	68	926	21219	16936	\N	56.157423000000001	Нижегородская область, Кстовский район, д. Зименки, ул. Центральная, школа	Россия, Нижегородская область, Кстовский район, село Зименки	0101000020E610000001C11C3D7E214640B151D66F26144C40
61711	7	68	926	21587	\N	\N	56.038709380752103	Нижегородская область, Кстовский район, с. Запрудное, школа с. Запрудное	Россия, Нижегородская область, Кстовский район, село Запрудное	0101000020E6100000C4279D4830394640CA87A06AF4044C40
61690	7	68	926	20407	\N	\N	56.210301999999999	Нижегородская область, Кстовский район, пос. Ждановский, ул. Школьная, школа	Россия, Нижегородская область, Кстовский район, село Ждановский	0101000020E61000007689EAAD810D464046240A2DEB1A4C40
61687	7	68	926	20407	17832	\N	56.208256824265597	Нижегородская область, Кстовский район, пос. Ждановский, ул. Зеленая, дом культуры	Россия, Нижегородская область, Кстовский район, село Ждановский	0101000020E61000008CF84ECC7A0D4640E014562AA81A4C40
61694	7	68	926	49791	\N	\N	56.162506	Нижегородская область, Кстовский район, пос. Дружный, здание ДОУ № 49		0101000020E610000043C5387F13F64540AFB321FFCC144C40
61695	7	68	926	49715	16952	\N	56.139641672776897	Нижегородская область, Кстовский район, с. Вязовка, ул. Широкая, школа		0101000020E61000009016670C73F64540F392FFC9DF114C40
61719	7	68	926	21980	17611	\N	56.048374000000003	Нижегородская область, Кстовский район, пос. Волжский, ул. Центральная, дом культуры		0101000020E610000001309E414349464005FD851E31064C40
61707	7	68	926	21393	16741	\N	56.104280000000003	"Нижегородская область, Кстовский район, д. Ветчак, ул. Магистральная, магазин ПО ""Новоликеевское"""		0101000020E61000001895D409682646403ED00A0C590D4C40
61702	7	68	926	12964	17212	\N	56.153517999999998	Нижегородская область, Кстовский район, с. Великий Враг, ул. Школьная, школа		0101000020E61000005874EB353D1E464075AC527AA6134C40
61697	7	68	926	12768	\N	\N	56.129036999999997	Нижегородская область, Кстовский район, с. Большое Мокрое, ул. Школьная, школа	Россия, Нижегородская область, Кстовский район, село Большое Мокрое	0101000020E610000067F2CD36370A4640AA7CCF4884104C40
61686	7	68	926	49807	17536	\N	56.221166565797702	Нижегородская область, Кстовский район, с. Большая Ельня, пл. Жданова, здание бывшей сельской адм-ции		0101000020E61000007C9E3F6D540D46402BFA43334F1C4C40
61693	7	68	926	50042	19499	\N	56.186318999999997	Нижегородская область, Кстовский район, с. Ближнее Борисово, ул. Центральная, д. 2-г, здание сельской адм-ции		0101000020E61000009E29745E63F74540CCCF0D4DD9174C40
61701	7	68	926	21118	\N	\N	56.145423999999998	Нижегородская область, Кстовский район, с. Безводное, ул. Советская, д.16-А	Россия, Нижегородская область, Кстовский район, село Безводное	0101000020E6100000164B917C252C4640D906EE409D124C40
61700	7	68	926	21118	17203	\N	56.145423999999998	Нижегородская область, Кстовский район, с. Безводное, ул. Веры Архангельской, дом культуры		0101000020E6100000164B917C252C4640D906EE409D124C40
61654	7	68	926	49649	\N	\N	56.267440494146797	Нижегородская область, Кстовский район, д. Афонино, школа д. Афонино	Россия, Нижегородская область, деревня Афонино, улица Овражная (Афонино)	0101000020E6100000E8D9ACFA5C0B464035D252793B224C40
61682	7	68	926	49649	19467	\N	56.2631397779191	Нижегородская область, Кстовский район, д. Афонино, ул. Магистральная, д. 73-А, сельская администрация	Россия, Нижегородская область, деревня Афонино, улица Магистральная	0101000020E61000002FDB4E5B230C46407D224F92AE214C40
61639	7	68	1499	17822	\N	\N	55.352015000000002	Нижегородская область, Краснооктябрьский район, Кечасовский сельсовет, с. Чернуха, ул. Центральная, д. 6, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Чернуха	0101000020E6100000FF3F4E9830B04640C959D8D30EAD4B40
61659	7	68	1499	18890	18000	\N	55.330362999999998	Нижегородская область, Краснооктябрьский район, Чембилеевский сельсовет, с. Чембилей, ул. Школьная, д. 25, Здание школы		0101000020E61000002BC3B81B44DD46407B67B45549AA4B40
61632	7	68	1499	17474	\N	\N	55.251598000000001	Нижегородская область, Краснооктябрьский район, Салганский сельсовет, с. Федоровка, ул. Красная, д. 49, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Федоровка	0101000020E610000099BA2BBB60A8464098DEFE5C34A04B40
61652	7	68	1499	18518	17751	\N	55.4009	Нижегородская область, Краснооктябрьский район, Уразовский сельсовет, с. Уразовка, ул. Кооперативная, д. 45, Здание дома культуры		0101000020E610000060CAC0012DCF4640B37BF2B050B34B40
61637	7	68	1499	50048	19515	\N	55.411991086185097	Нижегородская область, Краснооктябрьский район, Ендовищенский сельсовет, с. Трехозерки, ул. Центральная, д. 129, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Трехозерье	0101000020E6100000E92ADD5D67C14640889FFF1EBCB44B40
61650	7	68	1499	18405	17464	\N	55.4520979414308	Нижегородская область, Краснооктябрьский район, Семеновский сельсовет, с. Семеновка, ул. Ленина, д. 68, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Семеновка	0101000020E6100000D32EA699EECB4640234BE658DEB94B40
61647	7	68	1499	18243	\N	\N	55.112793000000003	Нижегородская область, Краснооктябрьский район, Саргинский сельсовет, с. Сарга, ул. Центральная, д.43, Здание сельской администрации	Россия, Нижегородская область, Краснооктябрьский район, село Сарга	0101000020E6100000890CAB7823C14640DF1B4300708E4B40
61645	7	68	1499	50076	19738	\N	55.256005281418098	Нижегородская область, Краснооктябрьский район, Салганский сельсовет, с. Салганы, ул. 1 Мая, д. 7, Здание администрации с/с	Россия, Нижегородская область, Краснооктябрьский район, село Салган	0101000020E6100000365A0EF450BF4640664E97C5C4A04B40
61651	7	68	1499	18432	17359	\N	55.465707999999999	Нижегородская область, Краснооктябрьский район, Пошатовский сельсовет, д. Пошатово, ул. Кооператвная, д. 1а, Здание селького ДК		0101000020E61000000A83328D26C9464027BEDA519CBB4B40
61657	7	68	1499	18771	18560	\N	55.448284999999998	Нижегородская область, Краснооктябрьский район, Уразовский сельсовет, д. Овечий Овраг, ул. Колхозная, д. 14, Здание селького ДК		0101000020E6100000880E812381D84640C824236761B94B40
61648	7	68	1499	18302	18534	\N	55.151378999999999	Нижегородская область, Краснооктябрьский район, Саргинский сельсовет, д. Михайловка, ул. Центральная, д. 64, Здание селького ДК		0101000020E610000019028063CFBE46408D26176360934B40
61660	7	68	1499	49729	17018	\N	55.299353852485197	Нижегородская область, Краснооктябрьский район, Медянский сельсовет, с. Медяна, ул. Ленина, д. 62, Здание дома культуры	Россия, Нижегородская область, Краснооктябрьский район, село Медяны	0101000020E610000094313ECC5ED64640A1F65B3B51A64B40
61646	7	68	1499	49759	17177	\N	54.530928000000003	Нижегородская область, Краснооктябрьский район, Маресевский сельсовет, с. Маресево, ул. Школьная, д.2а, Здание сельской администрации		0101000020E61000007138F3AB396A4640EE43DE72F5434B40
61641	7	68	1499	17962	17645	\N	55.221480999999997	Нижегородская область, Краснооктябрьский район, Салганский сельсовет, д. Малая Мажарка, ул. Молодежная, д. 1, Здание начальной школы		0101000020E6100000E1270EA0DFB54640BAD7497D599C4B40
61658	7	68	1499	50041	19494	\N	55.422068000000003	Нижегородская область, Краснооктябрьский район, Уразовский сельсовет, д. Кузьминка, ул. Школьная, д. 5а, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Кузьминка	0101000020E6100000C74B378941CE46401558005306B64B40
61656	7	68	1499	18702	17156	\N	55.392423999999998	Нижегородская область, Краснооктябрьский район, Уразовский сельсовет, д. Красный Яр, ул. Советская, д. 10/1, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Красный Яр	0101000020E61000005C7347FFCBC946402F151BF33AB24B40
61644	7	68	1499	18091	\N	\N	55.335130999999997	Нижегородская область, Краснооктябрьский район, Ключищинский сельсовет, с. Ключищи, ул. Школьная, д. 2а, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Ключищи	0101000020E61000000B45BA9F53C6464019709692E5AA4B40
61640	7	68	1499	17899	17060	\N	55.214784000000002	Нижегородская область, Краснооктябрьский район, Салганский сельсовет, с. Китово, ул. Гавриловка, д. 12, Здание селького ДК		0101000020E61000006C06B8205BBE46401FDAC70A7E9B4B40
61638	7	68	1499	17804	16919	\N	55.315472999999997	Нижегородская область, Краснооктябрьский район, Кечасовский сельсовет, с. Кечасово, ул. Советская, д. 93, Здание дома культуры		0101000020E61000000FEF39B01CB14640B0E2546B61A84B40
61636	7	68	1499	17717	16709	\N	55.414143000000003	Нижегородская область, Краснооктябрьский район, Ендовищенский сельсовет, д. Карга, ул. Центральная, д. 113, Здание селького ДК	Россия, Нижегородская область, Краснооктябрьский район, село Карга	0101000020E610000055682096CDB44640056F48A302B54B40
61649	7	68	1499	18310	17460	\N	55.147905999999999	Нижегородская область, Краснооктябрьский район, Саргинский сельсовет, с. Ерпелево, ул. Центральная, д. 116, Здание селького ДК		0101000020E610000034D769A4A5C84640EB707495EE924B40
61635	7	68	1499	17652	16769	\N	55.378785000000001	Нижегородская область, Краснооктябрьский район, Ендовищенский сельсовет, с. Ендовищи, ул. Школьная, д. 7,  Здание школы		0101000020E610000009C556D0B4BA4640919BE1067CB04B40
61616	7	68	1450	16723	17128	\N	57.169687000000003	Нижегородская область, Краснобаковский район, р.п. Ветлужский, ул. им.Чкалова, 20		0101000020E610000066A032FE7D90464037C7B94DB8954C40
61634	7	68	1499	17559	\N	\N	55.410826	Нижегородская область, Краснооктябрьский район, Большерыбушкинский сельсовет, с. Большое Рыбушкино, ул. Центральная, д.45, Здание школы	Россия, Нижегородская область, Краснооктябрьский район, село Большое Рыбушкино	0101000020E61000003BC5AA4198E346405A2C45F295B44B40
61633	7	68	1499	17559	16842	\N	55.4107665160507	Нижегородская область, Краснооктябрьский район, Большерыбушкинский сельсовет, с. Большое Рыбушкино, ул. Колхозная, д.58, Здание дома культуры	Россия, Нижегородская область, Краснооктябрьский район, село Большое Рыбушкино	0101000020E61000001079CBD58FE3464055A3570394B44B40
61655	7	68	1499	18677	18551	\N	55.413494	Нижегородская область, Краснооктябрьский район, Уразовский сельсовет, д. Антяровка, ул. Кооперативная, д. 32  Здание селького ДК		0101000020E6100000FAB48AFED0CC4640CE8B135FEDB44B40
61631	7	68	1499	17438	18411	\N	55.214075000000001	Нижегородская область, Краснооктябрьский район, Салганский сельсовет, с. Александрово, ул. Северная, д.106, Здание школы	Россия, Нижегородская область, Краснооктябрьский район, село Александрово	0101000020E6100000AA0F24EF1CA4464013F241CF669B4B40
61642	7	68	1499	50035	19480	\N	55.188010488982499	Нижегородская область, Краснооктябрьский район, Салганский сельсовет, с. Акулинино, ул. Колхозная, д. 12, Здание начальной школы	Россия, Нижегородская область, Краснооктябрьский район, село Акулино	0101000020E6100000CF4BC5C6BCB0464015A930B610984B40
61653	7	68	1499	18546	18543	\N	55.375520999999999	Нижегородская область, Краснооктябрьский район, Уразовский сельсовет, д. Актуково, ул. Школьная, д. 2а  Здание селького ДК		0101000020E610000007616EF772D1464009FB761211B04B40
61629	7	68	1450	17281	17334	\N	57.299833	Нижегородская область, Краснобаковский район, п. Шеманиха, ул. Сельсоветская, 6		0101000020E61000002C4A09C1AAB046407BA180ED60A64C40
61628	7	68	1450	17281	17714	\N	57.299833	Нижегородская область, Краснобаковский район, п. Шеманиха, ул. Свободы, 1	Россия, Нижегородская область, Краснобаковский район, поселок Шеманиха	0101000020E61000002C4A09C1AAB046407BA180ED60A64C40
61622	7	68	1450	17014	\N	\N	57.140431	Нижегородская область, Краснобаковский район, п. Чибирь, ул. Центральная, 1	Россия, Нижегородская область, Краснобаковский район, село Чибирь	0101000020E61000003BFDA02E526E46401B2C9CA4F9914C40
61623	7	68	1450	17028	17000	\N	57.231502999999996	Нижегородская область, Краснобаковский район, с. Чемашиха, ул. Школьная, 1		0101000020E61000001FBB0B941480464083F6EAE3A19D4C40
61624	7	68	1450	17096	16766	\N	57.103245999999999	Нижегородская область, Краснобаковский район, с. Чащиха, ул. Новая, 12		0101000020E61000000F43AB9333944640AEB8382A378D4C40
61621	7	68	1450	50067	19595	\N	57.196911999999998	Нижегородская область, Краснобаковский район, п. Пруды, ул. Центральная, 17	Россия, Нижегородская область, Краснобаковский район, село Пруды	0101000020E610000043E1B375706446405018946934994C40
61627	7	68	1450	17247	17082	\N	57.240422000000002	Нижегородская область, Краснобаковский район, с. Носовая, ул. Молодежная, д.42, здание Администрации Чащихинского сельсовета		0101000020E61000008A5A9A5B21CA4640959EE925C69E4C40
61630	7	68	1450	16425	\N	\N	57.127760000000002	Нижегородская область, Краснобаковский район, р.п. Красные Баки, ул. Синявина, 60, МОУ Краснобаковская средняя школа № 2	Россия, Нижегородская область, Краснобаковский район, поселок Красные Баки	0101000020E61000000F2A711DE392464055DE8E705A904C40
61611	7	68	1450	16425	\N	\N	57.127760000000002	Нижегородская область, Краснобаковский район, р.п. Красные Баки, ул. Свободы, 57	Россия, Нижегородская область, Краснобаковский район, поселок Красные Баки	0101000020E61000000F2A711DE392464055DE8E705A904C40
61614	7	68	1450	16425	17322	\N	57.127760000000002	Нижегородская область, Краснобаковский район, р.п. Красные Баки, ул. им.Чкалова, 2		0101000020E61000000F2A711DE392464055DE8E705A904C40
61613	7	68	1450	16425	17705	\N	57.127760000000002	Нижегородская область, Краснобаковский район, р.п. Красные Баки, ул. им.Синявина, 60		0101000020E61000000F2A711DE392464055DE8E705A904C40
61612	7	68	1450	16425	17121	\N	57.127760000000002	Нижегородская область, Краснобаковский район, р.п. Красные Баки, ул. им.Мичурина, 2а		0101000020E61000000F2A711DE392464055DE8E705A904C40
61620	7	68	1450	16896	\N	\N	56.957878999999998	Нижегородская область, Краснобаковский район, д. Козлово, 42		0101000020E61000001E1A16A3AE914640394371C79B7A4C40
61626	7	68	1450	17187	17717	\N	57.117631000000003	Нижегородская область, Краснобаковский район, с. Кириллово, ул. им. генерала Тихомирова, 58б		0101000020E61000004487C09140B7464076FF58880E8F4C40
61037	7	68	1450	20893	\N	\N	57.064149999999998	Нижегородская область, Краснобаковский район, с. Зубилиха, 120		0101000020E6100000580053060E924640EA04341136884C40
61615	7	68	1450	50060	19586	\N	57.161458636879701	Нижегородская область, Краснобаковский район, п.Затон, ул. Береговая, 6, здание клуба	Россия, Нижегородская область, Краснобаковский район, поселок Ветлужских Судовых Мастерских	0101000020E6100000E6797077D69846408B5242B0AA944C40
61619	7	68	1450	16862	17519	\N	57.191886401926801	Нижегородская область, Краснобаковский район, с. Дмитриевское, ул. Молодежная, 1б	Россия, Нижегородская область, Краснобаковский район, село Дмитриевское	0101000020E61000004D1421753B8D4640B6476FB88F984C40
61617	7	68	1450	16723	\N	\N	57.169687000000003	Нижегородская область, Краснобаковский район, р.п. Ветлужский, пер. Заводской, 2	Россия, Нижегородская область, Краснобаковский район, поселок Ветлужский	0101000020E610000066A032FE7D90464037C7B94DB8954C40
61618	7	68	1450	16723	16750	\N	57.169687000000003	Нижегородская область, Краснобаковский район, р.п. Ветлужский, ул. Фестивальная, 1	Россия, Нижегородская область, Краснобаковский район, поселок Ветлужский	0101000020E610000066A032FE7D90464037C7B94DB8954C40
61625	7	68	1450	17151	17131	\N	57.226050999999998	Нижегородская область, Краснобаковский район, п. Быструха, ул. Центральная, 23	Россия, Нижегородская область, Краснобаковский район, село Быструха	0101000020E6100000D978B0C56EA14640321D3A3DEF9C4C40
61599	7	68	1274	15826	16844	\N	57.168354999999998	Нижегородская область, Ковернинский район, Большемостовский сельсовет, д. Шадрино, Сельская, 63	Россия, Нижегородская область, Ковернинский район, село Шадрино	0101000020E610000006465ED6C4C845401D8F19A88C954C40
61604	7	68	1274	16107	17411	\N	56.970573999999999	Нижегородская область, Ковернинский район, Хохломский сельсовет, с. Хохлома, Центральная, 2		0101000020E6100000C405A051BAF24540882CD2C43B7C4C40
61605	7	68	1274	16120	\N	\N	56.995735000000003	Нижегородская область, Ковернинский район, Хохломский сельсовет, д. Тарасово, Профсоюзная, 11	Россия, Нижегородская область, Ковернинский район, село Тарасово	0101000020E610000016A75A0BB3F64540C53D963E747F4C40
61602	7	68	1274	15980	16994	\N	57.020001000000001	Нижегородская область, Ковернинский район, Скоробогатовский сельсовет, д. Сухоноска, Юбилейная, 19		0101000020E61000005CCAF962EFE3454093718C648F824C40
61603	7	68	1274	16036	17833	\N	56.947997999999998	Нижегородская область, Ковернинский район, Скоробогатовский сельсовет, д. Семино, Центральная, 3		0101000020E61000003FA88B14CAE4454032569BFF57794C40
61609	7	68	1274	16334	\N	\N	57.290281	Нижегородская область, Ковернинский район, Горевский сельсовет, д. Рамешки, дом 87 (здание фельдшерско-акушерского пункта)		0101000020E6100000290472892327464039D384ED27A54C40
61607	7	68	1274	16250	\N	\N	57.187192000000003	Нижегородская область, Ковернинский район, Горевский сельсовет, д. Понурово, Юбилейная, 1	Россия, Нижегородская область, Ковернинский район, село Понурово	0101000020E61000009818CBF44B02464053094FE8F5974C40
61030	7	68	1274	49745	19475	\N	57.281192058267202	ГОУ СПО Борский технолого-экономический техникум.  Нижегородская область, город Бор, п. Октябрьский, ул. Октябрьская, д. 19	Россия, Нижегородская область, Ковернинский район, село Октябрьский	0101000020E6100000DF347D76C0F34540CBF27519FEA34C40
61594	7	68	1274	15529	18196	\N	57.126562999999997	Нижегородская область, Ковернинский район, р.п. Ковернино, пер. Рабочий, 1	Россия, Нижегородская область, Ковернинский район, поселок Ковернино	0101000020E6100000B267CF656AEA45401BF1643733904C40
61593	7	68	1274	15529	16832	\N	57.126562999999997	Нижегородская область, Ковернинский район, р.п. Ковернино, Карла Маркса, 25	Россия, Нижегородская область, Ковернинский район, поселок Ковернино	0101000020E6100000B267CF656AEA45401BF1643733904C40
61592	7	68	1274	15529	16832	\N	57.126562999999997	Нижегородская область, Ковернинский район, р.п. Ковернино, Карла Маркса, 8		0101000020E6100000B267CF656AEA45401BF1643733904C40
61597	7	68	1274	15726	\N	\N	57.234400999999998	Нижегородская область, Ковернинский район, Большемостовский сельсовет, д. Каменное, Заречная, 49	Россия, Нижегородская область, Ковернинский район, село Каменное	0101000020E6100000BB287AE063F0454029931ADA009E4C40
61601	7	68	1274	15956	16921	\N	57.050460000000001	Нижегородская область, Ковернинский район, Гавриловский сельсовет, д. Демино, Заречная, 15		0101000020E6100000AB06616EF7F44540CAE0287975864C40
61608	7	68	1274	16274	17505	\N	57.230308999999998	Нижегородская область, Ковернинский район, Горевский сельсовет, с. Горево, Медведева, 22		0101000020E61000008847E2E5E91A4640BB7CEBC37A9D4C40
61600	7	68	1274	49806	17529	\N	57.088526527314201	Нижегородская область, Ковернинский район, Гавриловский сельсовет, д. Гавриловка, ул. Садовая, д.2 (МБОУ Гавриловская средняя общеобразовательная школа)	Россия, Нижегородская область, Ковернинский район, село Гавриловка	0101000020E6100000594E42E90BE3454010E84CDA548B4C40
61595	7	68	1274	15655	17510	\N	57.149059000000001	Нижегородская область, Ковернинский район, Большемостовский сельсовет, д. Большие Мосты, Северня, 9		0101000020E61000003EAE0D15E3EA45405516855D14934C40
61598	7	68	1274	15804	16839	\N	57.222814999999997	Нижегородская область, Ковернинский район, Большемостовский сельсовет, д. Большие Круты, Молодежная, 35	Россия, Нижегородская область, Ковернинский район, село Большие Круты	0101000020E610000014B1886187DF45407407B133859C4C40
61596	7	68	1274	15719	17706	\N	57.096749000000003	Нижегородская область, Ковернинский район, Большемостовский сельсовет, д. Бетино, Молодежная, 14-а		0101000020E6100000C1AC50A4FBFB4540DA756F45628C4C40
61610	7	68	1274	16406	17507	\N	57.316357000000004	Нижегородская область, Ковернинский район, Горевский сельсовет, с. Белбаж, Школьная, 3		0101000020E6100000AD4F39268B1746402B6EDC627EA84C40
61606	7	68	1274	16193	\N	\N	57.0563	Нижегородская область, Ковернинский район, Хохломский сельсовет, д. Анисимово, Молодежная, 57	Россия, Нижегородская область, Ковернинский район, село Анисимово	0101000020E61000009ACFB9DBF50C4640E561A1D634874C40
61586	7	68	168	15221	17078	\N	55.788727000000002	Нижегородская область, Княгининский район, п. Возрождение, Школьная, 46	Россия, Нижегородская область, Княгининский район, село совхоз Возрождение	0101000020E61000008BC404357CA34640713C9F01F5E44B40
61421	7	68	837	7419	16996	\N	56.896897000000003	Нижегородская область, Городецкий район, Бриляковский сельсовет, д. Шадрино, ул. Школьная, д. 2, Дом культуры		0101000020E61000004704E3E0D2D74540B5705985CD724C40
61589	7	68	168	15373	17106	\N	55.720854000000003	Нижегородская область, Княгининский район, Белкинский сельсовет, с. Урга, Центральная, 116	Россия, Нижегородская область, Княгининский район, село Урга	0101000020E6100000D13FC1C58A9E46406C98A1F144DC4B40
61583	7	68	168	15079	17166	\N	55.806742	Нижегородская область, Княгининский район, с. Троицкое, Советская, 3		0101000020E6100000B3CEF8BEB8A84640A227655243E74B40
61591	7	68	168	15447	\N	\N	55.870717999999997	Нижегородская область, Княгининский район, д. Соловьево, Молодежная, 1	Россия, Нижегородская область, Княгининский район, село Соловьево	0101000020E6100000DE019EB470834640EE04FBAF73EF4B40
61587	7	68	168	15275	\N	\N	55.689917999999999	Нижегородская область, Княгининский район, Возрожденский сельсовет, с. Покров, Ветеранов, 4	Россия, Нижегородская область, Княгининский район, село Покров	0101000020E61000003596B036C69E4640FB75A73B4FD84B40
61588	7	68	168	15314	17497	\N	55.880262999999999	Нижегородская область, Княгининский район, Ананьевский сельсовет, с. Островское, Садовая, 4		0101000020E610000012842BA0509346407E703E75ACF04B40
61581	7	68	168	521	\N	\N	55.817996999999998	Нижегородская область, Княгининский район, город Княгинино, Ленина, 40	Россия, Нижегородская область, Княгининский район, Княгинино	0101000020E6100000003ACC9717844640F19C2D20B4E84B40
61579	7	68	168	521	17100	\N	55.817996999999998	Нижегородская область, Княгининский район, город Княгинино, Свободы, 5		0101000020E6100000003ACC9717844640F19C2D20B4E84B40
61578	7	68	168	521	17100	\N	55.817996999999998	Нижегородская область, Княгининский район, город Княгинино, Свободы, 43		0101000020E6100000003ACC9717844640F19C2D20B4E84B40
61577	7	68	168	521	17065	\N	55.817996999999998	Нижегородская область, Княгининский район, город Княгинино, Октябрьская, 20 А		0101000020E6100000003ACC9717844640F19C2D20B4E84B40
61576	7	68	168	521	17065	\N	55.821911083259202	Нижегородская область, Княгининский район, город Княгинино, Октябрьская, 20	Россия, Нижегородская область, Княгининский район, Княгинино	0101000020E6100000473EAF78EA854640809C306134E94B40
61590	7	68	168	13162	\N	\N	55.834704000000002	Нижегородская область, Княгининский район, д. Бубенки, Школьная, 4	Россия, Нижегородская область, Княгининский район, село Бубенки	0101000020E610000055BDFC4E9375464092EBA694D7EA4B40
61584	7	68	168	15105	\N	\N	55.729092999999999	Нижегородская область, Княгининский район, Соловьевский сельсовет, д. Большая Андреевка, Новостаринская, 55	Россия, Нижегородская область, Княгининский район, село Большая Андреевка	0101000020E6100000930035B56C7B46400B5F5FEB52DD4B40
61585	7	68	168	13152	17492	\N	55.750753000000003	Нижегородская область, Княгининский район, с. Белка, Молодежная, 7		0101000020E6100000158E209562934640DC2F9FAC18E04B40
61582	7	68	168	15033	16918	\N	55.841994	Нижегородская область, Княгининский район, с. Ананье, Малкина, 14		0101000020E6100000215A2BDA1CA34640D0B69A75C6EB4B40
61573	7	68	1300	50078	19764	\N	54.999571666529299	Нижегородская область, Дивеевский район, Дивеевский сельсовет, с. Яковлевка, Лесная, 1,КЛУБ	Россия, Нижегородская область, Дивеевский район, село Яколевка	0101000020E6100000CD3E8F519EA14540A8FFACF9F17F4B40
61572	7	68	1300	14540	17302	\N	55.085951000000001	Нижегородская область, Дивеевский район, Глуховский сельсовет, с. Суворово, Молодежная, 11а, ДОМ КУЛЬТУРЫ		0101000020E6100000C092AB58FCBA45407D073F71008B4B40
61571	7	68	1300	14525	17294	\N	55.173259404282703	Нижегородская область, Дивеевский район, Ивановский сельсовет, с. Стуклово, Молодежная, 5а,ДОМ КУЛЬТУРЫ		0101000020E610000006D847A7AEC045406C5ED5592D964B40
61570	7	68	1300	14471	\N	\N	55.145564999999998	Нижегородская область, Дивеевский район, Ивановский сельсовет, с. Смирново, Культурная, 31. КЛУБ	Россия, Нижегородская область, Дивеевский район, село Смирново	0101000020E61000008A58C4B0C3AC45409B38B9DFA1924B40
61569	7	68	1300	14390	\N	\N	54.919589999999999	Нижегородская область, Дивеевский район, Сатисский сельсовет, п. Сатис, Советская, 20, Дом культуры	Россия, Нижегородская область, Дивеевский район, село Сатис	0101000020E61000007EFFE6C5899D454044DD0720B5754B40
61568	7	68	1300	14385	17087	\N	55.017999000000003	Нижегородская область, Дивеевский район, Дивеевский сельсовет, д. Осиновка, Новая, 48, Дом интернат		0101000020E6100000268C6665FBA045402C2E8ECA4D824B40
61567	7	68	1300	14326	\N	\N	55.230635999999997	Нижегородская область, Дивеевский район, Верякушский сельсовет, с. Ореховец, Шоссейная, 31, Дом культуры	Россия, Нижегородская область, Дивеевский район, село Ореховец	0101000020E61000003CDA38622DD04540DFA3FE7A859D4B40
61566	7	68	1300	14266	17287	\N	55.214742999999999	Нижегородская область, Дивеевский район, Верякушский сельсовет, с. Онучино, Школьная, 22, клуб		0101000020E610000049D6E1E82AC54540C005D9B27C9B4B40
61565	7	68	1300	14238	\N	\N	55.049849000000002	Нижегородская область, Дивеевский район, Глуховский сельсовет, д. Лихачи, ул. Центральная, дом 111, здание мед. Пункта	Россия, Нижегородская область, Дивеевский район, село Лихачи	0101000020E6100000EEE87FB916BD4540815EB87361864B40
61564	7	68	1300	14190	16935	\N	55.110460000000003	Нижегородская область, Дивеевский район, Елизарьевский сельсовет, д. Круглые Паны, Кооперативная, 65, Клуб		0101000020E6100000429946938BAD454012C2A38D238E4B40
61563	7	68	1300	14108	17086	\N	55.002800000000001	Нижегородская область, Дивеевский район, Дивеевский сельсовет, с. Кременки, Новостройка, 16, сельская администрация	Россия, Нижегородская область, Дивеевский район, село Кременки	0101000020E6100000AE450BD0B6B04540E3361AC05B804B40
84491	4	34	\N	639	45171	\N	62.028191	Республика Саха (Якутия), город Якутск, Пионерская, 9		0101000020E6100000A0C03BF97436604051853FC39B034F40
61562	7	68	1300	14103	\N	\N	55.198642999999997	Нижегородская область, Дивеевский район, Ивановский сельсовет, с. Конново, Трудовая, 47а,Дом культуры	Россия, Нижегородская область, Дивеевский район, село Конново	0101000020E6100000DF89592F86BC4540274A42226D994B40
61561	7	68	1300	14053	\N	\N	55.177585999999998	Нижегородская область, Дивеевский район, Верякушский сельсовет, с. Ичалово, переулок Больничный, 1а, Клуб	Россия, Нижегородская область, Дивеевский район, село Ичалово	0101000020E61000009203763579D845401D1D5723BB964B40
61560	7	68	1300	13984	17465	\N	55.154285000000002	Нижегородская область, Дивеевский район, Ивановский сельсовет, с. Ивановское, Микрарайон, 9а, сельская администрация		0101000020E61000008F6FEF1AF4B74540B6A1629CBF934B40
61559	7	68	1300	13953	16815	\N	55.066133000000001	Нижегородская область, Дивеевский район, Елизарьевский сельсовет, с. Елизарьево, 9 Мая, 35А, СЕЛЬСКАЯ АДИТНИСТРАЦИЯ		0101000020E61000006116DA39CDAA4540DB17D00B77884B40
61558	7	68	1300	13789	\N	\N	55.039769999999997	Нижегородская область, Дивеевский район, Дивеевский сельсовет, с. Дивеево, Арзамасская, 31, Сельская администрация	Россия, Нижегородская область, Дивеевский район, село Дивеево	0101000020E6100000282D5C56619F454053AEF02E17854B40
61557	7	68	1300	13789	\N	\N	55.039769999999997	Нижегородская область, Дивеевский район, Дивеевский сельсовет, с. Дивеево, Заречная, 157, магазин РАЙПО	Россия, Нижегородская область, Дивеевский район, село Дивеево	0101000020E6100000282D5C56619F454053AEF02E17854B40
61556	7	68	1300	13789	17063	\N	55.039769999999997	Нижегородская область, Дивеевский район, Дивеевский сельсовет, с. Дивеево, Октябрьская, 43, Дом культуры		0101000020E6100000282D5C56619F454053AEF02E17854B40
61555	7	68	1300	13744	16986	\N	55.109816000000002	Нижегородская область, Дивеевский район, Глуховский сельсовет, с. Глухово, Почтовая, 73а,Дом культуры		0101000020E6100000AF40F4A44CC44540ED4960730E8E4B40
61554	7	68	1300	13692	16683	\N	55.165796	Нижегородская область, Дивеевский район, Верякушский сельсовет, с. Верякуши, Советская, 32, школа	Россия, Нижегородская область, Дивеевский район, село Верякуши	0101000020E6100000707A17EFC7CD454060E7A6CD38954B40
61553	7	68	1300	13657	17531	\N	55.091670000000001	Нижегородская область, Дивеевский район, Дивеевский сельсовет, с. Большое Череватово, ул. Центральная, дом 110,   сельская администрация		0101000020E610000038A45181939D45401D03B2D7BB8B4B40
61471	7	68	7009	50051	19528	\N	56.262157915120902	Нижегородская область, город Дзержинск, р.п. Горбатовка, Весенняя, 5, здание столовой ПМК-5	Россия, Нижегородская область, деревня Горбатовка, улица Весенняя	0101000020E6100000357BA01518DE45404031B2648E214C40
61500	7	68	6977	49789	17400	\N	56.314605843240898	"Нижегородская область, город Дзержинск, пос.Пыра, ул.Чкалова, д.12, МОУ ""СОШ №6"""	Россия, Нижегородская область, Дзержинск городской округ, поселок Пыра	0101000020E6100000E4310395F1AD45400C90680245284C40
61499	7	68	6977	49815	\N	\N	56.303531	Нижегородская область, город Дзержинск, р.п. Пыра, пос.Пыра, Административное здание пос.Пыра		0101000020E61000005853591476AD45403D29931ADA264C40
61480	7	68	6977	49643	\N	\N	56.220813999999997	Нижегородская область, город Дзержинск, р.п. Бабино, административное здание	Россия, Нижегородская область, Дзержинск городской округ, поселок Бабино	0101000020E61000003C6BB75D68CE4540DD3F16A2431C4C40
61472	7	68	6977	49643	\N	\N	56.221285555973303	Нижегородская область, город Дзержинск, р.п. Бабино, МОУ СОШ №25	Россия, Нижегородская область, Дзержинск городской округ, поселок Бабино	0101000020E61000004E7CB5A338CF454005888219531C4C40
61478	7	68	6977	49643	16956	\N	56.220813999999997	Нижегородская область, город Дзержинск, р.п. Бабино, п. Петряевка, библиотека	Россия, Нижегородская область, Дзержинск городской округ, поселок Бабино	0101000020E61000003C6BB75D68CE4540DD3F16A2431C4C40
61456	7	68	985	9075	\N	\N	55.868217999999999	Нижегородская область, Дальнеконстантиновский район, Тепелевский сельсовет, с. Тепелево, Школьная, 1а, основная школа	Россия, Нижегородская область, Дальнеконстантиновский район, село Тепелево	0101000020E6100000221B48179B0E464036E675C421EF4B40
61461	7	68	985	9285	\N	\N	55.77711	Нижегородская область, Дальнеконстантиновский район, Сарлейский сельсовет, с. Татарское, ул. Молодежная , д. 137 , здание школы	Россия, Нижегородская область, Дальнеконстантиновский район, село Татарское	0101000020E6100000B5FD2B2B4D0C464081B2295778E34B40
61450	7	68	985	49642	19718	\N	55.766704124647802	Нижегородская область, Дальнеконстантиновский район, Суроватихинский сельсовет, п. ст. Суроватиха, Центральная, 18, сельская администрация		0101000020E6100000D07EA4880CF345402FDB4E5B23E24B40
61451	7	68	985	49642	16775	\N	55.765898367908299	Нижегородская область, Дальнеконстантиновский район, Суроватихинский сельсовет, п. ст. Суроватиха, М.Горького, Дом культуры, 15	Россия, Нижегородская область, Дальнеконстантиновский район, село Суроватиха	0101000020E61000002B4D4A41B7F34540310917F208E24B40
61445	7	68	985	8587	18010	\N	55.781033000000001	Нижегородская область, Дальнеконстантиновский район, Сарлейский сельсовет, с. Сарлей, Шоссейная, 8а, сельский Дом культуры		0101000020E6100000ED9FA70183024640630CACE3F8E34B40
61453	7	68	985	8928	17654	\N	55.925884000000003	Нижегородская область, Дальнеконстантиновский район, Дубравский сельсовет, с. Румянцево, Центральная, 43, столовая		0101000020E610000010035DFB02124640E1F1ED5D83F64B40
61444	7	68	985	8532	17074	\N	55.709774000000003	Нижегородская область, Дальнеконстантиновский район, Сарлейский сельсовет, с. Румстиха, Шоссейная, 39, начальная школа-детский сад		0101000020E610000009A4C4AEEDFD45408BC6DADFD9DA4B40
61446	7	68	985	8609	17427	\N	55.775039	Нижегородская область, Дальнеконстантиновский район, Белозеровский сельсовет, с. Помра, Молодежная, 23, основная школа		0101000020E6100000A9DBD9571E284640F10F5B7A34E34B40
61460	7	68	985	9198	17742	\N	56.005651	Нижегородская область, Дальнеконстантиновский район, Нижегородский сельсовет, п. Нижегородец, Ленина, сельская администрация, 9а		0101000020E6100000C1C760C5A9FE45404818062CB9004C40
61459	7	68	985	49710	16932	\N	56.005651	Нижегородская область, Дальнеконстантиновский район, Нижегородский сельсовет, п. Нижегородец, 50 лет Октября, средняя школа, 4		0101000020E6100000C1C760C5A9FE45404818062CB9004C40
61452	7	68	985	8879	\N	\N	55.771621000000003	Нижегородская область, Дальнеконстантиновский район, Суроватихинский сельсовет, с. Муравьиха, 222, средняя школа		0101000020E61000001805C1E3DBEF454013F4177AC4E24B40
61448	7	68	985	8708	17722	\N	55.679366999999999	Нижегородская область, Дальнеконстантиновский район, Маргушинский сельсовет, с. Маргуша, Новоселов, 8, административное здание		0101000020E6100000E90AB6114F1A4640A67D737FF5D64B40
61447	7	68	985	8686	17469	\N	55.762869999999999	Нижегородская область, Дальнеконстантиновский район, Малопицкий сельсовет, с. Малая Пица, 40 лет Победы, 11а, торговый центр		0101000020E610000016DD7A4D0F184640BD8C62B9A5E14B40
61457	7	68	985	9134	16716	\N	55.842604999999999	Нижегородская область, Дальнеконстантиновский район, Тепелевский сельсовет, д. Лазазей, Молодежная, 14		0101000020E610000014048F6FEF16464019390B7BDAEB4B40
61466	7	68	985	9160	\N	\N	55.928379999999997	Нижегородская область, Дальнеконстантиновский район, Кужутский сельсовет, д. Кужутки, Центральная, 32	Россия, Нижегородская область, Дальнеконстантиновский район, село Кужутки	0101000020E6100000151A8865330746405721E527D5F64B40
61458	7	68	985	9160	\N	\N	55.928379999999997	Нижегородская область, Дальнеконстантиновский район, Кужутский сельсовет, д. Кужутки, Молодежная, 21, основная школа	Россия, Нижегородская область, Дальнеконстантиновский район, село Кужутки	0101000020E6100000151A8865330746405721E527D5F64B40
61464	7	68	985	9406	19507	\N	55.944460684038802	Нижегородская область, Дальнеконстантиновский район, Дубравский сельсовет, п. Дубрава, Центральная, 13, средняя школа	Россия, Нижегородская область, Дальнеконстантиновский район, село Дубрава	0101000020E6100000C79C67EC4B20464079AC1919E4F84B40
61449	7	68	985	8753	\N	\N	55.739046999999999	Нижегородская область, Дальнеконстантиновский район, Суроватихинский сельсовет, п. Дубки, 108, контора лесхоза	Россия, Нижегородская область, Дальнеконстантиновский район, село Дубки	0101000020E61000006823D74D29F345407C9A931799DE4B40
61439	7	68	985	8308	\N	\N	55.809291999999999	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Советская, 93, районный Дом культуры	Россия, Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново	0101000020E61000003B8A73D4D10B46400C7558E196E74B40
61442	7	68	985	8308	17276	\N	55.809291999999999	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Советская, 53, поселковая администрация		0101000020E61000003B8A73D4D10B46400C7558E196E74B40
61441	7	68	985	8308	17276	\N	55.809291999999999	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Советская, 189а, административное здание ТУСМ		0101000020E61000003B8A73D4D10B46400C7558E196E74B40
61440	7	68	985	8308	17223	\N	55.809291999999999	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Пионерская, 1а, ЦРБ		0101000020E61000003B8A73D4D10B46400C7558E196E74B40
61443	7	68	985	8308	17337	\N	55.809291999999999	"Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Молодежная, 7, администратвное здание ЗАО ""Ритм"		0101000020E61000003B8A73D4D10B46400C7558E196E74B40
61455	7	68	985	9033	\N	\N	55.825699	Нижегородская область, Дальнеконстантиновский район, Богоявленский сельсовет, с. Богоявление, Шоссейная, 144а, сельская администрация	Россия, Нижегородская область, Дальнеконстантиновский район, село Богоявление	0101000020E6100000081D740987FE454082AB3C81B0E94B40
61463	7	68	985	9377	\N	\N	55.812423000000003	Нижегородская область, Дальнеконстантиновский район, Белозеровский сельсовет, с. Берсеменово,  правление колхоза «Победитель»		0101000020E6100000E3FBE252952C464055C2137AFDE74B40
61462	7	68	985	9324	18539	\N	55.831730999999998	Нижегородская область, Дальнеконстантиновский район, Белозеровский сельсовет, с. Белозерово, Центальная, 50, сельская администрация		0101000020E6100000DC80CF0F23224640E108522976EA4B40
61454	7	68	985	8979	16931	\N	55.852297999999998	Нижегородская область, Дальнеконстантиновский район, Богоявленский сельсовет, с. Арманиха, Центральная, 106, административное здание		0101000020E6100000D464C6DB4AF345401D39D21918ED4B40
61424	7	68	837	7583	17515	\N	56.717469999999999	Нижегородская область, Городецкий район, Тимирязевский сельсовет, п. им. Тимирязева, ул. Молодежная, д. 1а, здание администрации		0101000020E610000056D28A6F28B4454039EE940ED65B4C40
85273	4	34	\N	639	45246	\N	62.028191	Республика Саха (Якутия), город Якутск, П. Алексеева, 49		0101000020E6100000A0C03BF97436604051853FC39B034F40
61423	7	68	837	7554	\N	\N	56.810098000000004	Нижегородская область, Городецкий район, Федуринский сельсовет, д. Федурино, ул. Центральная, д. 19, Федуринская школа	Россия, Нижегородская область, Городецкий район, село Федурино	0101000020E610000041F4A44C6AB045400B47904AB1674C40
61428	7	68	837	7723	\N	\N	56.685704999999999	Нижегородская область, Городецкий район, Кумохинский сельсовет, с. Строчково, ул. Юбилейная, д. 1б, Строчковская СОШ	Россия, Нижегородская область, Городецкий район, село Строчково	0101000020E610000028EFE3688EC2454012DA722EC5574C40
61431	7	68	837	7866	\N	\N	56.666587	Нижегородская область, Городецкий район, Смольковский сельсовет, с. Смольки, ул. Дорожная, д.2, здание администрации	Россия, Нижегородская область, Городецкий район, село Смольки	0101000020E6100000645C717154D2454029780AB952554C40
61419	7	68	837	7341	17196	\N	56.924987000000002	Нижегородская область, Городецкий район, Смиркинский сельсовет, п. Смиркино, ул. Мира, д. 44, здание администрации		0101000020E610000006651A4D2ECA4540D21C59F965764C40
61430	7	68	837	7844	19406	\N	56.704684	Нижегородская область, Городецкий район, Кумохинский сельсовет, д. Серково, пр. Ленина, д. 12, Серковская школа		0101000020E61000003D2828452BC94540DA01D715335A4C40
61427	7	68	837	7700	17524	\N	56.757306999999997	Нижегородская область, Городецкий район, Ковригинский сельсовет, д. Мошкино, ул. Центральная, д. 5, клуб		0101000020E61000005AD76839D0C7454014048F6FEF604C40
61429	7	68	837	50021	\N	\N	56.688167	Нижегородская область, Городецкий район, Кумохинский сельсовет, д. Кудашиха, д. 52,здание Кумохинской администр		0101000020E610000059C16F438CD14540DD9733DB15584C40
61426	7	68	837	7667	\N	\N	56.722188000000003	Нижегородская область, Городецкий район, Ковригинский сельсовет, д. Ковригино, ул. Мира, д. 1, здание администрации	Россия, Нижегородская область, Городецкий район, село Ковригино	0101000020E610000037A8FDD64EC2454026C808A8705C4C40
61434	7	68	837	8010	\N	\N	56.550379999999997	Нижегородская область, Городецкий район, Николо-Погостинский сельсовет, п. Ильинский, д. 3, Ильинская школа	Россия, Нижегородская область, Городецкий район, село Ильинский	0101000020E6100000B70BCD751ACF4540AD2F12DA72464C40
61435	7	68	837	8091	17415	\N	56.539506218509402	Нижегородская область, Городецкий район, Зиняковский сельсовет, с. Зиняки, ул. Молодежная, д. 1, здание администрации	Россия, Нижегородская область, Городецкий район, село Зиняки	0101000020E610000018080264E8EA454076FF58880E454C40
61437	7	68	837	8167	17650	\N	56.474021999999998	Нижегородская область, Городецкий район, Зиняковский сельсовет, с. Зарубино, ул. Комсомольская, д. 6, Зарубинская школа		0101000020E6100000105A0F5F26F04540D1CABDC0AC3C4C40
61414	7	68	837	6492	\N	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Пушкина, д. 41, школа № 18 (спортивный зал)	Россия, Нижегородская область, Городецкий район, Заволжье	0101000020E6100000779FE3A3C5B14540865968E734514C40
61406	7	68	837	6492	\N	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Графтио, д. 10а, школа № 8	Россия, Нижегородская область, Городецкий район, Заволжье	0101000020E6100000779FE3A3C5B14540865968E734514C40
61404	7	68	837	6492	\N	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Мичурина, д.5, Дворец культуры (балетный зал)	Россия, Нижегородская область, Городецкий район, Заволжье	0101000020E6100000779FE3A3C5B14540865968E734514C40
61403	7	68	837	6492	\N	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, пр. Мира, д. 18, Заволжский автомоторный техн	Россия, Нижегородская область, Городецкий район, Заволжье	0101000020E6100000779FE3A3C5B14540865968E734514C40
61409	7	68	837	6492	16768	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, пр. Дзержинского, д. 58, Городская больница № 1		0101000020E6100000779FE3A3C5B14540865968E734514C40
61401	7	68	837	6492	18109	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Школьная, д. 12, школа № 6		0101000020E6100000779FE3A3C5B14540865968E734514C40
61413	7	68	837	6492	16971	\N	56.628998700330001	Нижегородская область, Городецкий район, город Заволжье, ул. Пушкина, д. 41, школа № 18 (актовый зал)	Россия, Нижегородская область, Городецкий район, Заволжье	0101000020E6100000319A95ED43B44540BD1B0B0A83504C40
61412	7	68	837	6492	16971	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Пушкина, д. 41, школа № 18 (1 этаж)		0101000020E6100000779FE3A3C5B14540865968E734514C40
61411	7	68	837	6492	16971	\N	56.636590889770901	Нижегородская область, Городецкий район, город Заволжье, ул. Пушкина, д. 4, школа № 15	Россия, Нижегородская область, Городецкий район, Заволжье	0101000020E6100000BF28417FA1B34540C7F65AD07B514C40
61410	7	68	837	6492	16971	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Пушкина, д.3, школа № 17 (рекреация 1 этажа)		0101000020E6100000779FE3A3C5B14540865968E734514C40
61407	7	68	837	6492	16971	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Пушкина, д. 3, школа № 17 (спортивный зал)		0101000020E6100000779FE3A3C5B14540865968E734514C40
61415	7	68	837	6492	17032	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Пономарева, д. 1а, Центр  детского творчества		0101000020E6100000779FE3A3C5B14540865968E734514C40
61160	7	68	1446	26608	16679	\N	57.858401000000001	Нижегородская область, Ветлужский район, город Ветлуга, Бахирева, 35а		0101000020E6100000A7936C7539E3464046ED7E15E0ED4C40
61402	7	68	837	6492	17875	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Пирогова, д. 10, школа № 3		0101000020E6100000779FE3A3C5B14540865968E734514C40
61417	7	68	837	6492	18185	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Молодежная, д. 1, школа № 19		0101000020E6100000779FE3A3C5B14540865968E734514C40
61405	7	68	837	6492	16764	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Мичурина, д. 5, Дворец культуры (выстав. зал)		0101000020E6100000779FE3A3C5B14540865968E734514C40
61416	7	68	837	6492	18182	\N	56.634427000000002	Нижегородская область, Городецкий район, город Заволжье, ул. Грунина, д. 8а, библиотека, филиал № 1		0101000020E6100000779FE3A3C5B14540865968E734514C40
61422	7	68	837	7484	\N	\N	56.795535000000001	"Нижегородская область, Городецкий район, Бриляковский сельсовет, д. Дроздово, д. 31, МОУ ""Дроздоская школа-сад"""		0101000020E6100000CD57C9C7EED0454064E94317D4654C40
61385	7	68	837	49802	17479	\N	56.639783000000001	Нижегородская область, Городецкий район, город Городец, пл. Ватутина, д. 6, Центр культуры и искусства		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61392	7	68	837	49802	17687	\N	56.639783000000001	"Нижегородская область, Городецкий район, город Городец, ул. Кирова, д. 2, Досуговый центр ""Метеор"""		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61436	7	68	837	8147	\N	\N	56.580173000000002	Нижегородская область, Городецкий район, Зиняковский сельсовет, с. Воронино, д. 15, Дом культуры		0101000020E6100000AB048BC399DD4540D882DE1B434A4C40
61714	7	68	837	9720	\N	\N	56.639412	Нижегородская область, Кстовский район, с. Варварское, ул. Центральная, д.94, здание клуба	Россия, Нижегородская область, Городецкий район, село Варварское	0101000020E6100000B8AF03E78CC84540C1559E40D8514C40
61425	7	68	837	7602	\N	\N	56.756607000000002	Нижегородская область, Городецкий район, Тимирязевский сельсовет, п. Буревестник, Дом культуры		0101000020E61000009A266C3F19AF45405C76887FD8604C40
61420	7	68	837	7414	17647	\N	56.859074	Нижегородская область, Городецкий район, Бриляковский сельсовет, с. Бриляково, ул. Школьная, д. 1, Бриляковская школа		0101000020E61000006DC5FEB27BD04540056C0723F66D4C40
61433	7	68	837	49778	\N	\N	56.592396999999998	Нижегородская область, Городецкий район, Николо-Погостинский сельсовет, п. Аксентис, д. 53, МОУ Аксентисская ООШ		0101000020E610000038F3AB3940D04540CF9F36AAD34B4C40
61365	7	68	590	4541	17450	\N	55.322122	Нижегородская область, Гагинский район, Юрьевский сельсовет, с. Юрьево, Ленина, 2а		0101000020E6100000912749D74C7A46403BA92F4B3BA94B40
61352	7	68	590	3837	17925	\N	55.251280000000001	Нижегородская область, Гагинский район, Гагинский сельсовет, д. Шерстино, Школьная, 16		0101000020E610000082751C3F54844640C7116BF129A04B40
61382	7	68	590	5451	\N	\N	55.120134999999998	Нижегородская область, Гагинский район, Ушаковский сельсовет, с. Ушаково, Молодежная, 4	Россия, Нижегородская область, Гагинский район, село Ушаково	0101000020E610000056629E95B47246406F0D6C95608F4B40
61353	7	68	590	3922	17440	\N	55.268379000000003	Нижегородская область, Гагинский район, Гагинский сельсовет, д. Тяпино, Центральная, 47	Россия, Нижегородская область, Гагинский район, село Тяпино	0101000020E6100000CF11F92EA584464073F7393E5AA24B40
61361	7	68	590	4322	\N	\N	55.283261000000003	Нижегородская область, Гагинский район, Ветошкинский сельсовет, с. Тарханово, Центральная, 20	Россия, Нижегородская область, Гагинский район, село Тарханово	0101000020E61000005ED5592DB09B4640BB9D7DE541A44B40
61375	7	68	590	5077	17473	\N	55.189321	Нижегородская область, Гагинский район, Большеаратский сельсовет, с. Сыченки, Героя Платова, 16		0101000020E6100000668522DDCF61464017B9A7AB3B984B40
61355	7	68	590	4024	17249	\N	55.181739999999998	Нижегородская область, Гагинский район, Гагинский сельсовет, с. Субботино, Центральная, 14		0101000020E6100000ADC090D5AD82464001309E4143974B40
61360	7	68	590	4305	17040	\N	55.224125000000001	Нижегородская область, Гагинский район, Покровский сельсовет, с. Соболево, Центральная, 2	Россия, Нижегородская область, Гагинский район, село Соболево	0101000020E61000007C7BD7A02F994640A69BC420B09C4B40
61357	7	68	590	4143	17365	\N	55.1823251661177	Нижегородская область, Гагинский район, Покровский сельсовет, село Покров, ул.Центральная, д.4	Россия, Нижегородская область, Гагинский район, село Покров	0101000020E6100000763579CA6A944640211FF46C56974B40
61354	7	68	590	3926	17618	\N	55.195189999999997	Нижегородская область, Гагинский район, Гагинский сельсовет, с. Паново - Осаново, Калинина, 79		0101000020E6100000C9772975C9884640CC4065FCFB984B40
61368	7	68	590	4722	16684	\N	55.347422999999999	Нижегородская область, Гагинский район, Юрьевский сельсовет, с. Паново - Леонтьево, Колхозная, 1а		0101000020E61000002123A0C21178464069705B5B78AC4B40
61370	7	68	590	50019	19407	\N	55.3722980062525	Нижегородская область, Гагинский район, Юрьевский сельсовет, с. Ново - Еделево, Савинская, 43б	Россия, Нижегородская область, Гагинский район, село Новоеделево	0101000020E610000046B6F3FDD46A4640E02EFB75A7AF4B40
61383	7	68	590	5528	17093	\N	55.121138999999999	Нижегородская область, Гагинский район, Ушаковский сельсовет, с. Новое Молчаново, Высокая, 16		0101000020E6100000F705F4C29D67464094A2957B818F4B40
61364	7	68	590	4526	17047	\N	55.368133999999998	Нижегородская область, Гагинский район, Ветошинский сельсовет, с. Новоблаговещенское, Трудовая, 42		0101000020E61000009818CBF44B8A4640D845D1031FAF4B40
61273	7	68	47	31911	17378	\N	56.800750000000001	Нижегородская область, Воскресенский район, Богородский сельсовет, д. Задворка, Мира, 2		0101000020E61000002CF3565D87BC4640D122DBF97E664C40
61371	7	68	590	4901	19454	\N	55.358564999999999	Нижегородская область, Гагинский район, Юрьевский сельсовет, с. Никольское, Центральная, 23а	Россия, Нижегородская область, Гагинский район, село Никольское	0101000020E61000009835B1C057744640C03E3A75E5AD4B40
61362	7	68	590	4400	\N	\N	55.307721000000001	Нижегородская область, Гагинский район, Ветошкинский сельсовет, с. Муратовка, Завражная, 44	Россия, Нижегородская область, Гагинский район, село Муратовка	0101000020E6100000384E0AF31E9D46406EA5D76663A74B40
61372	7	68	590	4924	16816	\N	55.252772999999998	Нижегородская область, Гагинский район, Большеаратский сельсовет, с. Моисеевка, Школьная, 11		0101000020E6100000ACC5A700186F4640E9279CDD5AA04B40
61366	7	68	590	4636	17559	\N	55.354435000000002	Нижегородская область, Гагинский район, Юрьевский сельсовет, с. Мишуково, Центральная, 33а		0101000020E6100000EFC9C342AD7F464065C746205EAD4B40
61379	7	68	590	5302	16694	\N	55.12988	Нижегородская область, Гагинский район, Ушаковский сельсовет, с. Ляпня, Зверева, 91		0101000020E6100000703E75AC52804640C63368E89F904B40
61359	7	68	590	4250	17443	\N	55.222856999999998	Нижегородская область, Гагинский район, Покровский сельсовет, с. Ломакино, Мира, 1а		0101000020E61000008FFAEB1516904640A3570394869C4B40
61367	7	68	590	4699	17455	\N	55.308408	Нижегородская область, Гагинский район, Юрьевский сельсовет, село Курбатово, ул.Зеленая, д.20 А		0101000020E61000000801F9122A80464092E9D0E979A74B40
61373	7	68	590	5000	18025	\N	55.220283999999999	Нижегородская область, Гагинский район, Большеаратский сельсовет, с. Карауловка, Центральная, 10		0101000020E6100000DE3EABCC9472464081EA1F44329C4B40
61376	7	68	590	5165	18032	\N	55.185378999999998	Нижегородская область, Гагинский район, Большеаратский сельсовет, с. Какино, Ленина, 2а		0101000020E6100000E1606F6248704640BE2EC37FBA974B40
61384	7	68	590	5546	17862	\N	55.146465999999997	Нижегородская область, Гагинский район, Ушаковский сельсовет, с. Итманово, Центральная, 6		0101000020E6100000CF842689255F4640EBFCDB65BF924B40
61358	7	68	590	4154	17446	\N	55.1643208423421	Нижегородская область, Гагинский район, Покровский сельсовет, с. Исупово, Большая дорога, 20	Россия, Нижегородская область, Гагинский район, село Исупово	0101000020E6100000F1660DDE57994640E485747808954B40
61381	7	68	590	5411	17090	\N	55.078772000000001	Нижегородская область, Гагинский район, Ушаковский сельсовет, с. Ивково, Запрудная, 35		0101000020E61000008D98D9E73182464096EB6D33158A4B40
61377	7	68	590	5215	17670	\N	55.147432999999999	Нижегородская область, Гагинский район, Большеаратский сельсовет, село Зверево, ул.Центральная, д.3А		0101000020E610000049827005147A4640F3ACA415DF924B40
62779	7	68	590	3711	\N	\N	55.233449	Нижегородская область, Гагинский район, Гагинский сельсовет, с. Гагино, ул.Коммунистическая, д.75	Россия, Нижегородская область, Гагинский район, село Гагино	0101000020E6100000077B134372844640572426A8E19D4B40
61350	7	68	590	3711	17027	\N	55.233449	Нижегородская область, Гагинский район, Гагинский сельсовет, с. Гагино, Терехина, 12	Россия, Нижегородская область, Гагинский район, село Гагино	0101000020E6100000077B134372844640572426A8E19D4B40
61374	7	68	590	3711	17281	\N	55.233449	Нижегородская область, Гагинский район, Гагинский сельсовет, с. Гагино, Ленина, 27а		0101000020E6100000077B134372844640572426A8E19D4B40
61351	7	68	590	3711	17281	\N	55.233449	Нижегородская область, Гагинский район, Гагинский сельсовет, с. Гагино, Ленина, 53		0101000020E6100000077B134372844640572426A8E19D4B40
61349	7	68	590	3711	17617	\N	55.233449	Нижегородская область, Гагинский район, Гагинский сельсовет, с. Гагино, Коммунистическая, 10		0101000020E6100000077B134372844640572426A8E19D4B40
61363	7	68	590	4454	17632	\N	55.292442999999999	Нижегородская область, Гагинский район, Ветошинский сельсовет, с. Ветошкино, Школьная, 1		0101000020E610000051853FC39B874640D978B0C56EA54B40
61380	7	68	590	5330	18050	\N	55.085559000000003	Нижегородская область, Гагинский район, Ушаковский сельсовет, с. Большая Уда, Рябовой, 3а		0101000020E6100000882CD2C43B7A46407270E998F38A4B40
61369	7	68	590	4797	\N	\N	55.364511999999998	Нижегородская область, Гагинский район, Юрьевский сельсовет, с. Березники, Въездная, 1а	Россия, Нижегородская область, Гагинский район, село Березники	0101000020E6100000942EFD4B526F4640F17F4754A8AE4B40
61335	7	68	6955	49795	\N	\N	55.324979999999996	Нижегородская область, город Выкса, рабочий поселок Шиморское, здание администрации	Россия, Нижегородская область, Выксунский район, поселок Шиморское	0101000020E6100000A4367172BF03454052EDD3F198A94B40
61334	7	68	6955	49795	17419	\N	55.324979999999996	Нижегородская область, город Выкса, рабочий поселок Шиморское, м-н Совхозный, 2а,  ДТ	Россия, Нижегородская область, Выксунский район, поселок Шиморское	0101000020E6100000A4367172BF03454052EDD3F198A94B40
61336	7	68	6955	49722	17003	\N	55.292008000000003	Нижегородская область, город Выкса, рабочий поселок Шиморское, д. Тамбалес, Калинина, 13,  школа	Россия, Нижегородская область, Выксунский район, село Тамбалес	0101000020E6100000E12879758E054540CF15A58460A54B40
61343	7	68	6955	49821	\N	\N	55.20805	Нижегородская область, город Выкса, Новодмитриевский сельсовет, с. Полдеревка, школа	Россия, Нижегородская область, Выксунский район, село Полдеревка	0101000020E61000003961C2685646454066F7E461A19A4B40
61345	7	68	6955	49727	\N	\N	55.171900000000001	Нижегородская область, город Выкса, с. Новодмитриевка ,  МОУ  Новодмитриевская СОШ	Россия, Нижегородская область, Выксунский район, село Новодмитриевка	0101000020E610000005DF347D763045405917B7D100964B40
61327	7	68	6955	49726	\N	\N	55.417318953066903	Нижегородская область, город Выкса , п. Дружба , МОУ СОШ посёлка Дружба	Россия, Нижегородская область, Выксунский район, село Дружба	0101000020E6100000BF982D5915174540ED7F80B56AB54B40
61328	7	68	6955	49714	\N	\N	55.397443038064601	Нижегородская область, город Выкса, поселок Досчатое, клуб ДЗМО	Россия, Нижегородская область, Выксунский район, поселок Досчатое	0101000020E610000011E4A084990C454017838769DFB24B40
61329	7	68	6955	49714	16950	\N	55.395587999999996	"Нижегородская область, город Выкса, поселок Досчатое, Гагарина, 144,  клуб Метиз"""	Россия, Нижегородская область, Выксунский район, поселок Досчатое	0101000020E6100000CD76853E580E45405358A9A0A2B24B40
61344	7	68	6955	49869	\N	\N	55.079112000000002	Нижегородская область, город Выкса, Новодмитриевский сельсовет, п. Димара, Дом Досуга	Россия, Нижегородская область, Выксунский район, село Димара	0101000020E6100000639CBF09854445404F5C8E57208A4B40
61333	7	68	6955	49798	\N	\N	55.324118175942097	Нижегородская область, город Выкса, поселок Ближне-Песочное, д. Грязная, ДТ	Россия, Нижегородская область, Выксунский район, село Грязная	0101000020E610000012D90759160A4540C005D9B27CA94B40
61337	7	68	6955	50017	\N	\N	55.247293374733701	Нижегородская область, город Выкса, рабочий поселок Виля, п. Виля, здание администрации	Россия, Нижегородская область, Выксунский район, поселок Виля	0101000020E61000008A75AA7CCF1A4540CEC3094CA79F4B40
61340	7	68	6955	49720	16970	\N	55.228808000000001	Нижегородская область, город Выкса, рабочий поселок Виля, с. Верхняя Верея, Школьная, ДТ	Россия, Нижегородская область, Выксунский район, село Верхняя Верея	0101000020E61000009E3F6D54A70D454016889E94499D4B40
61332	7	68	6955	49650	16805	\N	55.300801955382198	Нижегородская область, город Выкса, поселок Ближне-Песочное, с. Борковка, Ленина, школа	Россия, Нижегородская область, Выксунский район, село Борковка	0101000020E61000000D52F014720D4540234910AE80A64B40
61330	7	68	6955	49762	\N	\N	55.349716000000001	Нижегородская область, город Выкса, поселок Ближне-Песочное, библиотека	Россия, Нижегородская область, Выксунский район, поселок Ближне-Песочное	0101000020E61000003ECBF3E0EE0A4540A8716F7EC3AC4B40
61318	7	68	6980	49724	17013	\N	55.332520074262803	Нижегородская область, город Выкса, город Выкса, м-н  Гоголя, 17,  общежитие 3		0101000020E610000019FF3EE3C21945400AA2EE0390AA4B40
61323	7	68	6980	49724	17594	\N	55.320347343973097	Нижегородская область, город Выкса, город Выкса, с. Мотмос, 1 Мая, 1,  начальная школа	Россия, Нижегородская область, Выкса городской округ	0101000020E6100000E3FA777DE6124540942F682101A94B40
61280	7	68	47	32226	18564	\N	56.818961000000002	Нижегородская область, Воскресенский район, Владимирский сельсовет, д. Шадрино, Фабричная, 70		0101000020E6100000FE43FAEDEB82464088D9CBB6D3684C40
61282	7	68	47	32299	17158	\N	56.993817	Нижегородская область, Воскресенский район, Староустинский сельсовет, с. Староустье, Школьная, 2а		0101000020E6100000959C137B68B94640BB9A3C65357F4C40
61299	7	68	47	872	16961	\N	56.959277999999998	Нижегородская область, Воскресенский район, Воздвиженский сельсовет, п. Северный, Железнодорожная, 12		0101000020E6100000213A048E04EA4640DAE21A9FC97A4C40
61284	7	68	47	32394	17556	\N	56.903872999999997	Нижегородская область, Воскресенский район, Капустихинский сельсовет, д. Русениха, Молодежная, 1а		0101000020E6100000B267CF656AAE4640635E471CB2734C40
61283	7	68	47	32343	17553	\N	56.946432000000001	Нижегородская область, Воскресенский район, Староустинский сельсовет, д. Раскаты, Новая, 4		0101000020E6100000AB5E7EA7C9B04640A6F10BAF24794C40
61278	7	68	47	32149	17754	\N	56.920610000000003	Нижегородская область, Воскресенский район, Благовещенский сельсовет, с. Погатиха, Интернациональная, 45		0101000020E6100000618907944D9546406F2F698CD6754C40
61293	7	68	47	49785	17383	\N	56.621637405940497	Нижегородская область, Воскресенский район, Егоровский сельсовет, д. Осиновка, Школьная, 94	Россия, Нижегородская область, Воскресенский район, село Осиновка	0101000020E6100000469561DC0DC64640E57D1CCD914F4C40
61291	7	68	47	366	17165	\N	56.559666999999997	Нижегородская область, Воскресенский район, Нестиарский сельсовет, с. Нестиары, Зеленая, 3		0101000020E610000037894160E5AA464041D3122BA3474C40
61287	7	68	47	55	\N	\N	56.780639999999998	Нижегородская область, Воскресенский район, Нахратовский сельсовет, д. Марфино, Полевая, 14	Россия, Нижегородская область, Воскресенский район, село Марфино	0101000020E61000008EE55DF580B3464087F9F202EC634C40
61302	7	68	47	1013	17181	\N	57.036543999999999	Нижегородская область, Воскресенский район, Воздвиженский сельсовет, д. Малое Содомово, Больничная, 18		0101000020E6100000D828EB3713CD4640B96E4A79AD844C40
61289	7	68	47	49757	17169	\N	56.749929999999999	Нижегородская область, Воскресенский район, Нахратовский сельсовет, д. Кучиново, Прямая, 19а		0101000020E6100000367689EAADAF46400725CCB4FD5F4C40
61290	7	68	47	255	17373	\N	56.764437000000001	Нижегородская область, Воскресенский район, Красноярский сельсовет, п. Красный Яр, Советская, 2в (ДК)		0101000020E61000006AA67B9DD4DD46401A6D5512D9614C40
61285	7	68	47	32499	19420	\N	56.831609999999998	Нижегородская область, Воскресенский район, Капустихинский сельсовет, д. Капустиха, Клубная, 1а		0101000020E61000002EE57CB1F7AE464066834C32726A4C40
61271	7	68	47	49811	17547	\N	56.807493993067801	Нижегородская область, Воскресенский район, поселок Воскресенское, п. Калиниха, Береговая, 22	Россия, Нижегородская область, Воскресенский район, поселок Калиниха	0101000020E610000046425BCEA5B84640ADDBA0F65B674C40
61295	7	68	47	619	16955	\N	56.891027000000001	Нижегородская область, Воскресенский район, Глуховский сельсовет, д. Елкино, Школьная, 52		0101000020E6100000069D103AE8BC46402F6D382C0D724C40
61286	7	68	47	32466	18579	\N	56.641852	Нижегородская область, Воскресенский район, Нахратовский сельсовет, д. Елдеж, Набережная, 23		0101000020E6100000D8D64FFF599F4640A46FD23428524C40
61292	7	68	47	374	17167	\N	56.590628000000002	Нижегородская область, Воскресенский район, Егоровский сельсовет, д. Егорово, Центральная, 1		0101000020E6100000041BD7BFEBCF46400B0DC4B2994B4C40
61275	7	68	47	32005	17360	\N	56.726928999999998	Нижегородская область, Воскресенский район, Богородский сельсовет, с. Докукино, Центральная, 14	Россия, Нижегородская область, Воскресенский район, село Докукино	0101000020E61000001422E010AAD84640CAC16C020C5D4C40
61294	7	68	47	511	17557	\N	56.869554999999998	Нижегородская область, Воскресенский район, Глуховский сельсовет, с. Глухово, Школьная, 3		0101000020E610000099107349D5BE4640618907944D6F4C40
61274	7	68	47	31963	17149	\N	56.753093	Нижегородская область, Воскресенский район, Богородский сельсовет, д. Галибиха, Пролетарская, 55		0101000020E6100000C32D1F4949CF46405BECF65965604C40
61268	7	68	47	31639	\N	\N	56.838459999999998	Нижегородская область, Воскресенский район, поселок Воскресенское, Синявина, 10	Россия, Нижегородская область, Воскресенский район, поселок Воскресенское	0101000020E61000008237A45181B74640888043A8526B4C40
61267	7	68	47	31639	18522	\N	56.838459999999998	Нижегородская область, Воскресенский район, поселок Воскресенское, пл. Ленина, 2		0101000020E61000008237A45181B74640888043A8526B4C40
61270	7	68	47	31639	16929	\N	56.838459999999998	Нижегородская область, Воскресенский район, поселок Воскресенское, Ленина, 102		0101000020E61000008237A45181B74640888043A8526B4C40
61269	7	68	47	31639	16929	\N	56.835227487290702	Нижегородская область, Воскресенский район, поселок Воскресенское, Ленина, 129	Россия, Нижегородская область, Воскресенский район, поселок Воскресенское	0101000020E61000006C5F402FDCB746403CDEE4B7E86A4C40
61296	7	68	47	634	17176	\N	56.959910999999998	Нижегородская область, Воскресенский район, Воздвиженский сельсовет, с. Воздвиженское, Ленина, 56		0101000020E6100000EF1EA0FB72CE46400B09185DDE7A4C40
61279	7	68	47	32154	\N	\N	56.821893000000003	Нижегородская область, Воскресенский район, Владимирский сельсовет, с. Владимирское, Советская, 47	Россия, Нижегородская область, Воскресенский район, село Владимирское	0101000020E6100000D1782288F38E4640DAE731CA33694C40
61300	7	68	47	916	17175	\N	56.918379000000002	Нижегородская область, Воскресенский район, Воздвиженский сельсовет, с. Большое Поле, Новая, 2	Россия, Нижегородская область, Воскресенский район, село Большое Поле	0101000020E61000000A65E1EB6BF74640A62A6D718D754C40
61298	7	68	47	771	\N	\N	56.935355000000001	Нижегородская область, Воскресенский район, Воздвиженский сельсовет, с. Большое Иевлево, Молодежная, 27	Россия, Нижегородская область, Воскресенский район, село Большое Иевлево	0101000020E6100000F372D87DC7D8464036936FB6B9774C40
61297	7	68	47	744	19437	\N	56.963169999999998	Нижегородская область, Воскресенский район, Воздвиженский сельсовет, с. Большие Отары, Луговая, 14		0101000020E61000007F677BF486C14640813E9127497B4C40
61272	7	68	47	31847	16777	\N	56.777321000000001	Нижегородская область, Воскресенский район, Богородский сельсовет, с. Богородское, Комсомольская, 4		0101000020E610000026C79DD2C1C446403CBF28417F634C40
61277	7	68	47	32091	17658	\N	56.941802000000003	Нижегородская область, Воскресенский район, Благовещенский сельсовет, с. Благовещенское, Советская, 67		0101000020E6100000B60F79CBD5A7464059A7CAF78C784C40
61281	7	68	47	32263	17367	\N	56.810758	Нижегородская область, Воскресенский район, Владимирский сельсовет, д. Бараново, Советская, 1		0101000020E61000002159C0046E9F4640357C0BEBC6674C40
61276	7	68	47	32037	\N	\N	56.924255000000002	Нижегородская область, Воскресенский район, Благовещенский сельсовет, д. Асташиха, Специалистов, 18	Россия, Нижегородская область, Воскресенский район, село Асташиха	0101000020E6100000457F68E6C9A946400E15E3FC4D764C40
61266	7	68	1540	50080	19803	\N	56.085591000000001	Нижегородская область, Воротынский район, Отарский сельсовет, п. Шереметьево, Советская, 72, сельский клуб	Россия, Нижегородская область, Воротынский район, село Шереметьево	0101000020E6100000A5BBEB6CC8FB46407DEA58A5F40A4C40
61265	7	68	1540	31557	17344	\N	56.064404000000003	Нижегородская область, Воротынский район, Чугуновский сельсовет, с. Чугуны, Советская, 1, Здание Администрации сельсовета		0101000020E61000002481069B3AD94640A5DDE8633E084C40
61264	7	68	1540	31483	18475	\N	56.161184402533003	Нижегородская область, Воротынский район, Фокинский сельсовет, с. Фокино, Мира, 5А, Дом культуры	Россия, Нижегородская область, Воротынский район, село Фокино	0101000020E610000065C6DB4AAFE94640B95164ADA1144C40
61263	7	68	1540	31464	\N	\N	55.883237000000001	Нижегородская область, Воротынский район, Семьянский сельсовет, д. Тришкино, сельский клуб		0101000020E61000004148163081FB4640FFCEF6E80DF14B40
61262	7	68	1540	31390	17527	\N	56.131264999999999	Нижегородская область, Воротынский район, Фокинский сельсовет, с. Сомовка, Свободы, сельский клуб		0101000020E610000031EBC5504EDC4640020EA14ACD104C40
61261	7	68	1540	31340	17726	\N	56.021859999999997	Нижегородская область, Воротынский район, Семьянский сельсовет, с. Семьяны, Малова, 20А , сельский клуб		0101000020E6100000B262B83A00FE4640978BF84ECC024C40
84056	4	34	\N	639	45246	\N	62.028191	Республика Саха (Якутия), город Якутск, П. Алексеева, 25		0101000020E6100000A0C03BF97436604051853FC39B034F40
61260	7	68	1540	31280	17339	\N	56.187044999999998	Нижегородская область, Воротынский район, Михайловский сельсовет, с. Разнежье, Ленина, 91А, сельский клуб		0101000020E6100000D65240DAFFD64640AEF02E17F1174C40
61259	7	68	1540	31223	18017	\N	55.965944	Нижегородская область, Воротынский район, Огнев-Майданский сельсовет, с. Покров - Майдан, Советская, 37, здание администрации сельсовета		0101000020E6100000C2FC153257E646403BE2900DA4FB4B40
61257	7	68	1540	31147	17523	\N	56.122098000000001	Нижегородская область, Воротынский район, Отарский сельсовет, с. Отары, Молодежная, 225, сельский клуб		0101000020E61000002619390B7BF24640197442E8A00F4C40
61256	7	68	1540	31122	17340	\N	56.098405999999997	Нижегородская область, Воротынский район, Отарский сельсовет, с. Осинки, Петровская, 65, сельский клуб		0101000020E6100000841266DAFEEB464076DD5B91980C4C40
61258	7	68	1540	31180	17336	\N	56.024254999999997	Нижегородская область, Воротынский район, Огнев-Майданский сельсовет, с. Огнев - Майдан, Кооперативная, 2А,сельский клуб	Россия, Нижегородская область, Воротынский район, село Огнев-Майдан	0101000020E6100000B3D2A41474F34640DAE1AFC91A034C40
61255	7	68	1540	31067	17716	\N	56.186062999999997	Нижегородская область, Воротынский район, Михайловский сельсовет, с. Михайловское, Победы, 8, Администрация сельсовета		0101000020E6100000CE893DB48FE3464071FF91E9D0174C40
61253	7	68	1540	30966	17133	\N	56.048917000000003	Нижегородская область, Воротынский район, Красногорский сельсовет, с. Львово, Центральная, 55, частный дом		0101000020E6100000F4177AC4E8C54640F69B89E942064C40
61254	7	68	1540	30988	17279	\N	56.107092000000002	Нижегородская область, Воротынский район, Отарский сельсовет, п. Лысая Гора, Сурская, 71, сельский клуб		0101000020E6100000F3380CE6AFFA4640E5D4CE30B50D4C40
61252	7	68	1540	30885	\N	\N	56.023470000000003	Нижегородская область, Воротынский район, Красногорский сельсовет, д. Липовка, Октябрьская, 55, частный дом	Россия, Нижегородская область, Воротынский район, село Липовка	0101000020E610000064247B849ACF4640F437A11001034C40
61249	7	68	1540	30758	17349	\N	56.380757000000003	Нижегородская область, Воротынский район, Каменский сельсовет, п. Кузьмияр, Центральная, 14, детский сад		0101000020E6100000E5B67D8FFABD46408E5C37A5BC304C40
61247	7	68	1540	30644	\N	\N	56.072795999999997	Нижегородская область, Воротынский район, Чугуновский сельсовет, с. Криуши, Загуменная, сельский клуб	Россия, Нижегородская область, Воротынский район, село Криуши	0101000020E6100000B8567BD80BE34640CAA31B6151094C40
61250	7	68	1540	30797	17470	\N	56.005400000000002	Нижегородская область, Воротынский район, Красногорский сельсовет, п. Красная Горка, Береговая, 16, дом культуры		0101000020E61000009F5BE84A04CE4640FFB27BF2B0004C40
61251	7	68	1540	30882	\N	\N	55.903388	Нижегородская область, Воротынский район, Семьянский сельсовет, с. Кекино, сельский клуб		0101000020E6100000FC1873D712024740A7CCCD37A2F34B40
61248	7	68	1540	30674	17521	\N	56.192821000000002	Нижегородская область, Воротынский район, Каменский сельсовет, с. Каменка, Заводская, 44А, Администрация сельсовета		0101000020E61000007FFB3A70CECA4640B37DC85BAE184C40
61246	7	68	1540	26612	\N	\N	55.979067000000001	Нижегородская область, Воротынский район, Семьянский сельсовет, с.Ивановка, д.40, частный дом	Россия, Нижегородская область, Воротынский район, село Ивановка	0101000020E6100000FF93BF7B47FB4640E2CB441152FD4B40
61245	7	68	1540	30562	17711	\N	56.024827999999999	Нижегородская область, Воротынский район, Огнев-Майданский сельсовет, с. Елвашка, Нагорная, 6, сельский клуб		0101000020E610000001857AFA08EA464036035C902D034C40
61236	7	68	1540	26604	\N	\N	56.060298000000003	Нижегородская область, Воротынский район, поселок Воротынец, Мира, 7, Агротехникум	Россия, Нижегородская область, Воротынский район, поселок Воротынец	0101000020E6100000DD99098673ED4640D20149D8B7074C40
61233	7	68	1540	26604	\N	\N	56.060298000000003	Нижегородская область, Воротынский район, поселок Воротынец, переулок Строителей, 9	Россия, Нижегородская область, Воротынский район, поселок Воротынец	0101000020E6100000DD99098673ED4640D20149D8B7074C40
61234	7	68	1540	26604	17514	\N	56.060298000000003	"Нижегородская область, Воротынский район, поселок Воротынец, Микройрайон Молодежный, 2, начальная школа ""Родничок"""		0101000020E6100000DD99098673ED4640D20149D8B7074C40
61207	7	68	1540	26604	18004	\N	56.060298000000003	Нижегородская область, Воротынский район, поселок Воротынец, Космонавтов, 8, МОУ Воротынская средняя школа		0101000020E6100000DD99098673ED4640D20149D8B7074C40
61235	7	68	1540	26604	18220	\N	56.060298000000003	Нижегородская область, Воротынский район, п.Воротынец, КДЦ «Мир», ул.Зубова дом 40		0101000020E6100000DD99098673ED4640D20149D8B7074C40
61237	7	68	1540	26604	18249	\N	56.060298000000003	Нижегородская область, Воротынский район, поселок Воротынец, Демьяна Бедного, 1, Администрация р.п.Воротынец		0101000020E6100000DD99098673ED4640D20149D8B7074C40
61239	7	68	1540	30239	\N	\N	56.128124	Нижегородская область, Воротынский район, поселок Васильсурск, Советская, 62, Администрация р.п.Васильсурск	Россия, Нижегородская область, Воротынский район, поселок Васильсурск	0101000020E61000005AB8ACC26602474096EA025E66104C40
61241	7	68	1540	30355	17707	\N	55.986234000000003	Нижегородская область, Воротынский район, Красногорский сельсовет,с. Быковка, Школьная, 68, сельский клуб		0101000020E61000009CC24A0515D74640051A6CEA3CFE4B40
61243	7	68	1540	30462	18269	\N	55.963289000000003	Нижегородская область, Воротынский район, Белавский сельсовет, с. Березов Майдан, Школьная, 82, сельский клуб		0101000020E6100000144031B2640247405CCCCF0D4DFB4B40
61244	7	68	1540	30467	\N	\N	56.114806000000002	Нижегородская область, Воротынский район, Фокинский сельсовет, д. Белогорка, Зубрилова, сельский клуб	Россия, Нижегородская область, Воротынский район, село Белогорка	0101000020E610000069A8514832D546403AB187F6B10E4C40
61242	7	68	1540	30380	17712	\N	55.993515000000002	Нижегородская область, Воротынский район, Белавский сельсовет, с. Белавка, Горького, 38, сельский клуб		0101000020E61000000989B48D3F0B4740F08AE07F2BFF4B40
61240	7	68	1540	30267	17323	\N	56.013522999999999	Нижегородская область, Воротынский район, Красногорский сельсовет, с. Ахпаевка, Центральная, 35, сельский клуб		0101000020E610000069C4CC3E8FE14640355F251FBB014C40
61215	7	68	888	29115	\N	\N	56.249667000000002	Нижегородская область, Володарский район, поселок Юганец, Центральная - 16, школа  44	Россия, Нижегородская область, Володарский район, поселок Юганец	0101000020E610000006D671FC509D4540FAF19716F51F4C40
61214	7	68	888	29115	17225	\N	56.249667000000002	Нижегородская область, Володарский район, поселок Юганец, Центральная -1, клуб в/ч  п. Юганец		0101000020E610000006D671FC509D4540FAF19716F51F4C40
61230	7	68	888	29792	18193	\N	56.294756	Нижегородская область, Володарский район, поселок Центральный, Мирошниченко - 8, ДК п. Центральный		0101000020E6100000A0FF1EBC766545405F268A90BA254C40
61231	7	68	888	29872	17702	\N	56.419936	Нижегородская область, Володарский район, поселок Фролищи, Школьная - 9, школа  47		0101000020E6100000DB5031CEDF524540DF347D76C0354C40
61226	7	68	888	29634	16697	\N	56.279957000000003	Нижегородская область, Володарский район, поселок Смолино, ул. 1 Мая     д. 2, здание Смолинской поселковой админ		0101000020E61000009354A698838A4540A5A487A1D5234C40
61209	7	68	888	28797	18162	\N	56.2178333825658	Нижегородская область, Володарский район, поселок Решетиха, Кирова - 3а, средняя школа 42	Россия, Нижегородская область, Володарский район, поселок Решетиха	0101000020E6100000AEF204C24EA54540AA7EA5F3E11B4C40
61210	7	68	888	28797	16829	\N	56.218080999999998	Нижегородская область, Володарский район, поселок Решетиха, Кирова-25, начальная школа 51	Россия, Нижегородская область, Володарский район, поселок Решетиха	0101000020E61000007993DFA293A5454082700514EA1B4C40
61208	7	68	888	28797	17495	\N	56.214028157864703	Нижегородская область, Володарский район, поселок Решетиха, Затылкова 1а, ДК  им. Луначарского	Россия, Нижегородская область, Володарский район, поселок Решетиха	0101000020E61000004A26A77686A54540D236FE44651B4C40
61222	7	68	888	29430	18451	\N	56.285702999999998	Нижегородская область, Володарский район, Золинский сельсовет, п. Новосмолинский, Танковая  - 25, Дом офицеров		0101000020E6100000B9347EE1958445403EAF78EA91244C40
61223	7	68	888	29430	16689	\N	56.285702999999998	Нижегородская область, Володарский район, Золинский сельсовет, п. Новосмолинский, Танковая - 54, школа  48	Россия, Нижегородская область, Володарский район, поселок Новосмолинский	0101000020E6100000B9347EE1958445403EAF78EA91244C40
61224	7	68	888	29537	17500	\N	56.232342271037901	Нижегородская область, Володарский район, Ильинский сельсовет, с. Мячково, Советская - 17а, клуб  СДК  с. Мячково	Россия, Нижегородская область, Володарский район, село Мячково	0101000020E61000004DDBBFB2D26445405EBEF561BD1D4C40
62726	7	68	888	6817	17311	\N	56.317587546995298	Нижегородская область, Володарский район, Мулинский сельсовет, п. Мулино, Новая - 23, школа  59	Россия, Нижегородская область, Володарский район, поселок Мулино	0101000020E6100000309C6B98A179454010CD3CB9A6284C40
61227	7	68	888	6817	16762	\N	56.314971	Нижегородская область, Володарский район, п. Мулино, Новая - 23, школа  59		0101000020E61000004D0F0A4AD17A45401E1840F850284C40
61229	7	68	888	6817	16724	\N	56.313479211906603	Нижегородская область, Володарский район, п. Мулино, Гвардейская - 60, ГДО  п. Мулино	Россия, Нижегородская область, Володарский район, поселок Мулино	0101000020E6100000ECA353573E7B4540CC7D721420284C40
61228	7	68	888	6817	16724	\N	56.314971	Нижегородская область, Володарский район, п. Мулино, Гвардейская - 74, молодежный  центр п. Мулино		0101000020E61000004D0F0A4AD17A45401E1840F850284C40
61216	7	68	888	29186	17319	\N	56.210182000000003	Нижегородская область, Володарский район, поселок Красная Горка, Ленина - 12а, школа  43		0101000020E61000004F04711E4E8845409C1A683EE71A4C40
61219	7	68	888	29240	18226	\N	56.229876712229398	Нижегородская область, Володарский район, поселок Ильиногорск, Угарова - 9, школа  53	Россия, Нижегородская область, Володарский район, поселок Ильиногорск	0101000020E61000005A0F5F268A7A4540228D0A9C6C1D4C40
61218	7	68	888	29240	18226	\N	56.227719252585203	Нижегородская область, Володарский район, поселок Ильиногорск, Угарова - 2, ДК  п. Ильиногорск	Россия, Нижегородская область, Володарский район, поселок Ильиногорск	0101000020E6100000C651B9895A7A4540C3D66CE5251D4C40
61217	7	68	888	29240	17318	\N	56.226768999999997	Нижегородская область, Володарский район, поселок Ильиногорск, Угарова - 2, ДК п.Ильиногорск		0101000020E6100000799274CDE47B4540915F3FC4061D4C40
61220	7	68	888	19877	\N	\N	56.231203000000001	Нижегородская область, Володарский район, Ильинский сельсовет, п. Ильино, Комсомольская - 6, ДК п. Ильино	Россия, Нижегородская область, Володарский район, село Ильино	0101000020E6100000F1F3DF83D774454059DE550F981D4C40
61221	7	68	888	29392	18414	\N	56.2788719748037	Нижегородская область, Володарский район, Золинский сельсовет, с. Золино, Школьная - 24, школа - интернат  п. Золино	Россия, Нижегородская область, Володарский район, село Золино	0101000020E610000009C03FA54A7E454093E2E313B2234C40
61211	7	68	888	9050	17682	\N	56.215160255586198	Нижегородская область, Володарский район, город Володарск, Октябрьская -34, школа  49		0101000020E610000097C79A914194454024B4E55C8A1B4C40
61213	7	68	888	9050	17621	\N	56.239723895111702	"Нижегородская область, Володарский район, город Володарск, Мичурина 2б, ФОК  ""ТРИУМФ"""	Россия, Нижегородская область, Володарский район, Володарск	0101000020E6100000D11E2FA4C39745407D08AA46AF1E4C40
62773	7	68	888	9050	17033	\N	56.228371000000003	Нижегородская область, Володарский район, город Володарск, Мичурина - 19а, школа  50		0101000020E6100000BD1AA034D49645406B2DCC423B1D4C40
61165	7	68	888	9050	17033	\N	56.228371000000003	Нижегородская область, Володарский район, город Володарск, Мичурина -19а, школа  50		0101000020E6100000BD1AA034D49645406B2DCC423B1D4C40
61212	7	68	888	9050	16740	\N	56.224528876074899	Нижегородская область, Володарский район, город Володарск, Клубная -3, городской Дом культуры	Россия, Нижегородская область, Володарский район, Володарск	0101000020E61000006A847EA65E9745407500C45DBD1C4C40
61189	7	68	888	9050	16740	\N	56.228371000000003	Нижегородская область, Володарский район, город Володарск, Клубная - 3, городской Дом культуры		0101000020E6100000BD1AA034D49645406B2DCC423B1D4C40
61206	7	68	1818	28722	16993	\N	54.788345999999997	Нижегородская область, Вознесенский район, Бахтызинский сельсовет, с. Суморьево, Советская, 3, помещение сельского ДК		0101000020E6100000124A5F083973454059F78F85E8644B40
61203	7	68	1818	28596	17690	\N	54.861424999999997	Нижегородская область, Вознесенский район, Нарышкинский сельсовет, с. Сарминский Майдан, Советская, 14,  сельский Дом культуры		0101000020E6100000363D2828457D4540787AA52C436E4B40
61197	7	68	1818	28316	17483	\N	54.845047000000001	Нижегородская область, Вознесенский район, Криушинский сельсовет, д. Починки, Школьная, 1, помещение сельской библиотеки		0101000020E6100000BA84436FF15845409D4A06802A6C4B40
61204	7	68	1818	28647	17640	\N	54.852615	Нижегородская область, Вознесенский район, Полховско-Майданский сельсовет, с. Полховский Майдан, Молодежная, 116, помещение школы	Россия, Нижегородская область, Вознесенский район, село Полховский Майдан	0101000020E610000078B471C45A5245401E8A027D226D4B40
61195	7	68	1818	28220	17673	\N	54.839551	Нижегородская область, Вознесенский район, Бутаковский сельсовет, с. Новоселки, Кооперативная, 2А, сельский Дом культуры		0101000020E61000002F8672A25D6145407C293C68766B4B40
61200	7	68	1818	28439	17484	\N	54.882933999999999	Нижегородская область, Вознесенский район, Нарышкинский сельсовет, с. Нарышкино, Ленина, 6Б, сельская администрация		0101000020E61000005680EF366F864540634337FB03714B40
61199	7	68	1818	28411	17213	\N	54.911009999999997	Нижегородская область, Вознесенский район, Мотызлейский сельсовет, с. Мотызлей, Ленина, 55, сельская администрация		0101000020E610000052448655BC7345401B2AC6F99B744B40
61198	7	68	1818	28333	17683	\N	54.835917000000002	Нижегородская область, Вознесенский район, Криушинский сельсовет, с. Линейка, Советская, 3А, сельский Дом культуры		0101000020E610000086E28E37F9434540D1950854FF6A4B40
61205	7	68	1818	28666	17982	\N	55.004761999999999	Нижегородская область, Вознесенский район, Сарминский сельсовет, п. Куриха, Мелькинская, 39А, сельская администрация		0101000020E610000099D9E731CA6D4540BC218D0A9C804B40
61196	7	68	1818	28267	17095	\N	54.820031999999998	Нижегородская область, Вознесенский район, Криушинский сельсовет, с. Криуша, Советская, 83, сельский Дом культуры		0101000020E61000009E961FB8CA53454034D6FECEF6684B40
61202	7	68	1818	28530	\N	\N	54.954864000000001	Нижегородская область, Вознесенский район, Нарышкинский сельсовет, с. Илев, Новая, 52, сельская библиотека	Россия, Нижегородская область, Вознесенский район, село Илев	0101000020E61000006B7EFCA5457F45405A10CAFB387A4B40
61201	7	68	1818	28494	17304	\N	54.827952000000003	Нижегородская область, Вознесенский район, Нарышкинский сельсовет, п. Заря, Заречная, 3А, сельская библиотека		0101000020E6100000E068C70DBF8D45403354C554FA694B40
61185	7	68	1818	27729	\N	\N	54.892364000000001	Нижегородская область, Вознесенский район, рабочий поселок Вознесенское, Школьная, 7, МОУ Вознесенская СОШ № 2	Россия, Нижегородская область, Вознесенский район, поселок Вознесенское	0101000020E61000003B35971B0C6145405A10CAFB38724B40
61186	7	68	1818	27729	17745	\N	54.892364000000001	Нижегородская область, Вознесенский район, рабочий поселок Вознесенское, Садовая, 2, помещение танцевального зала РДК		0101000020E61000003B35971B0C6145405A10CAFB38724B40
61184	7	68	1818	27729	17282	\N	54.892364000000001	"Нижегородская область, Вознесенский район, рабочий поселок Вознесенское, Индустриальная, 1,  магазин ""Полюс"""		0101000020E61000003B35971B0C6145405A10CAFB38724B40
61187	7	68	1818	27729	16680	\N	54.8921166807582	"Нижегородская область, Вознесенский район, рабочий поселок Вознесенское, Заречная, 6, НОУ ""Вознесенская автошкола"""	Россия, Нижегородская область, Вознесенский район, поселок Вознесенское	0101000020E610000085251E5036614540529ACDE330724B40
61192	7	68	1818	28069	\N	\N	54.929414999999999	Нижегородская область, Вознесенский район, Благодатовский сельсовет, д. Варнаево, Садовая, 51, сельский Дом культуры	Россия, Нижегородская область, Вознесенский район, село Варнаево	0101000020E610000011363CBD525E4540B7B41A12F7764B40
61193	7	68	1818	28144	\N	\N	54.800891	Нижегородская область, Вознесенский район, Бутаковский сельсовет, с. Бутаково, Ленина, 109, сельский Дом культуры	Россия, Нижегородская область, Вознесенский район, село Бутаково	0101000020E610000038691A14CD6345409354A69883664B40
61191	7	68	1818	28056	\N	\N	54.954202000000002	Нижегородская область, Вознесенский район, Благодатовский сельсовет, д. Букалей, Солнечная, 51, сельский клуб	Россия, Нижегородская область, Вознесенский район, село Букалей	0101000020E61000001938A0A52B5845408FE3874A237A4B40
61194	7	68	1818	28183	\N	\N	54.823163999999998	Нижегородская область, Вознесенский район, Бутаковский сельсовет, с. Борки, Ленина, 28, сельский клуб	Россия, Нижегородская область, Вознесенский район, село Борки	0101000020E6100000207A5226356C45404D9F1D705D694B40
61190	7	68	1818	27998	18044	\N	55.010122000000003	Нижегородская область, Вознесенский район, Благодатовский сельсовет, с. Благодатовка, Первомайская, 24, сельская администрация		0101000020E610000096D05D12675B45402D7C7DAD4B814B40
61177	7	68	1818	27398	\N	\N	54.862233000000003	Нижегородская область, Вознесенский район, Бахтызинский сельсовет, с. Бахтызино, Кирова, 26А, помещение сельского ДК	Россия, Нижегородская область, Вознесенский район, село Бахтызино	0101000020E610000038DBDC989E7045401844A4A65D6E4B40
61188	7	68	1818	27925	17622	\N	54.903618999999999	Нижегородская область, Вознесенский район, Нарышкинский сельсовет, с. Аламасово, Ленина, 41А, помещение сельского ДК	Россия, Нижегородская область, Вознесенский район, село Аламасово	0101000020E61000001C0C7558E1924540A98592C9A9734B40
61166	7	68	1446	21964	\N	\N	57.996142999999996	Нижегородская область, Ветлужский район, р.п.им.М.И.Калинина, ул.Кирова, д1, здание  МОУ Калининская средняя общеобразовательная  школа	Россия, Нижегородская область, Ветлужский район, поселок имени М. И.Калинина	0101000020E61000000B462575028E4640D591239D81FF4C40
61167	7	68	1446	21964	17623	\N	57.996142999999996	Нижегородская область, Ветлужский район, р.п.им. М.И. Калинина, ул.Ленина, д.9,  здание дома культуры		0101000020E61000000B462575028E4640D591239D81FF4C40
61179	7	68	1446	16411	\N	\N	57.936976999999999	Нижегородская область, Ветлужский район, с.Турань, д.12А,  здание  администрации  Туранского   сельсовета	Россия, Нижегородская область, Ветлужский район, село Турань	0101000020E610000058207A5226AD4640560DC2DCEEF74C40
61174	7	68	1446	27270	\N	\N	57.736510000000003	Нижегородская область, Ветлужский район, Мошкинский сельсовет, с. Стрелица, Здание администрации Мошкинского сельсовета		0101000020E61000000133DFC14FA64640A796ADF545DE4C40
61175	7	68	1446	27296	\N	\N	57.709983999999999	Нижегородская область, Ветлужский район, Мошкинский сельсовет, д. Скулябиха, Здание администрации Мошкинского сельсовета		0101000020E6100000217365506D9E4640755776C1E0DA4C40
61180	7	68	1446	27548	\N	\N	58.004250999999996	Нижегородская область, Ветлужский район, Макарьевский сельсовет, д. Скрябино, Сельский дом культуры	Россия, Нижегородская область, Ветлужский район, село Скрябино	0101000020E610000052BAF42F49F14640D6FCF84B8B004D40
61181	7	68	1446	27608	\N	\N	57.963583999999997	Нижегородская область, Ветлужский район, Макарьевский сельсовет, д. Пустошь, Здание сельского дома культуры		0101000020E61000000553CDACA5E84640747973B856FB4C40
61183	7	68	1446	27699	\N	\N	57.748216999999997	Нижегородская область, Ветлужский район, Новоуспенский сельсовет, с. Новоуспенское, Здание администрации Новоуспенского сельсовета		0101000020E61000005740A19E3E044740D6A71C93C5DF4C40
61178	7	68	1446	16344	17263	\N	57.932968000000002	Нижегородская область, Ветлужский район, с.Новопокровское, ул.Ленинская, д.2, здание администрации Проновского сельсовета		0101000020E6100000FB20CB8289974640761BD47E6BF74C40
61172	7	68	1446	27169	\N	\N	57.832521	Нижегородская область, Ветлужский район, Волыновский сельсовет, д. Махони, Здание дома культуры		0101000020E6100000EB55647440B64640DA1D520C90EA4C40
61182	7	68	1446	27641	\N	\N	57.873524000000003	Нижегородская область, Ветлужский район, Макарьевский сельсовет, д. Маркуша, Здание сельского дома культуры		0101000020E6100000FFAECF9CF5ED4640B4226AA2CFEF4C40
61169	7	68	1446	26999	\N	\N	57.860957999999997	Нижегородская область, Ветлужский район, Крутцовский сельсовет, д. Крутцы, Дом Культуры, 30	Россия, Нижегородская область, Ветлужский район, село Крутцы	0101000020E61000009F55664AEBDD4640629D2ADF33EE4C40
61168	7	68	1446	26999	\N	\N	57.860017769678798	Нижегородская область, Ветлужский район, Крутцовский сельсовет, д. Крутцы, Здание администрации Крутцовского сельсовета, 28	Россия, Нижегородская область, Ветлужский район, село Крутцы	0101000020E6100000C76471FF91DD464054FCDF1115EE4C40
61176	7	68	1446	27375	\N	\N	57.818798999999999	Нижегородская область, Ветлужский район, Мошкинский сельсовет, д. Галкино, Здание администрации Мошкинского сельсовета		0101000020E6100000F7E978CC409D4640AE7FD767CEE84C40
61173	7	68	1446	27233	\N	\N	57.809916000000001	Нижегородская область, Ветлужский район, Волыновский сельсовет, с. Волынцы, Здание администрации Волыновского сельсовета	Россия, Нижегородская область, Ветлужский район, село Волынцы	0101000020E6100000A7936C7539BD4640EA40D653ABE74C40
61164	7	68	1446	26608	\N	\N	57.858401000000001	Нижегородская область, Ветлужский район, город Ветлуга, Максима Горького, 80	Россия, Нижегородская область, Ветлужский район, Ветлуга	0101000020E6100000A7936C7539E3464046ED7E15E0ED4C40
61162	7	68	1446	26608	\N	\N	57.858401000000001	Нижегородская область, Ветлужский район, город Ветлуга, ул. Ленина, 25а	Россия, Нижегородская область, Ветлужский район, Ветлуга	0101000020E6100000A7936C7539E3464046ED7E15E0ED4C40
85235	4	34	\N	639	45174	\N	62.028191	Республика Саха (Якутия), город Якутск, Дзержинского, 13		0101000020E6100000A0C03BF97436604051853FC39B034F40
61163	7	68	1446	49767	\N	\N	57.857323086007803	Нижегородская область, Ветлужский район, город Ветлуга, территория СХТ, 5	Россия, Нижегородская область, Ветлужский район, Ветлуга	0101000020E610000025581CCEFCE24640E78D93C2BCED4C40
61171	7	68	1446	49767	17254	\N	57.858401000000001	Нижегородская область, Ветлужский район, город Ветлуга, Спортивная, 3, Ветлужская СОШ		0101000020E6100000A7936C7539E3464046ED7E15E0ED4C40
61161	7	68	1446	49767	17616	\N	57.858300833613498	Нижегородская область, Ветлужский район, город Ветлуга, ул. Бахирева, 50	Россия, Нижегородская область, Ветлужский район, Ветлуга	0101000020E61000001CD0D2156CE34640E28FA2CEDCED4C40
61170	7	68	1446	27075	\N	\N	57.866568999999998	Нижегородская область, Ветлужский район, Волыновский сельсовет, с. Белышево, Здание администрации Волыновского сельсовета	Россия, Нижегородская область, Ветлужский район, село Белышево	0101000020E6100000C72B103D29C346401C5DA5BBEBEE4C40
61146	7	68	1675	26022	17602	\N	55.895732000000002	Нижегородская область, Вачский район, Новосельский сельсовет, с. Яковцево, Советская, 13а, помещение дома культуры		0101000020E610000043E21E4B1F52454087FD9E58A7F24B40
61155	7	68	1675	26328	\N	\N	55.954822999999998	Нижегородская область, Вачский район, Чулковский сельсовет, с.Чулково, ул.Садовая  д.2, помещение школы	Россия, Нижегородская область, Вачский район, село Чулково	0101000020E61000002D26361FD7604540FB3BDBA337FA4B40
61154	7	68	1675	26328	17906	\N	55.954822999999998	Нижегородская область, Вачский район, Чулковский сельсовет, с. Чулково, Набережная, 24,помешение сельской администрации		0101000020E61000002D26361FD7604540FB3BDBA337FA4B40
61147	7	68	1675	26036	\N	\N	55.751061999999997	Нижегородская область, Вачский район, Филинский сельсовет, с. Филинское, Больничная, 30, помещение дома культуры	Россия, Нижегородская область, Вачский район, село Филинское	0101000020E610000051137D3ECA3E454059A2B3CC22E04B40
61148	7	68	1675	26036	17229	\N	55.751061999999997	Нижегородская область, Вачский район, Филинский сельсовет, с. Филинское, Больничная, 15,  пом. сельской администрации		0101000020E610000051137D3ECA3E454059A2B3CC22E04B40
61143	7	68	1675	25887	17600	\N	55.840466999999997	Нижегородская область, Вачский район, Новосельский сельсовет, с. Федурино, Школьная, 57, помещение библиотеки	Россия, Нижегородская область, Вачский район, село Федурино	0101000020E61000002426A8E15B5E4540012F336C94EB4B40
61140	7	68	1675	25719	\N	\N	55.837873999999999	Нижегородская область, Вачский район, Казаковский сельсовет, д. Сколково, Центральная, 48	Россия, Нижегородская область, Вачский район, село Сколково	0101000020E6100000232F6B628149454098158A743FEB4B40
61134	7	68	1675	25419	\N	\N	55.829541999999996	Нижегородская область, Вачский район, Арефинский сельсовет, д. Сергеево, 166а, Дом досуга		0101000020E6100000246420CF2E7745404754A86E2EEA4B40
61135	7	68	1675	25481	\N	\N	55.833500999999998	Нижегородская область, Вачский район, Арефинский сельсовет, с. Польцо, 249 , помещение детского сада	Россия, Нижегородская область, Вачский район, село Польцо	0101000020E61000005BB05417F066454076172829B0EA4B40
61142	7	68	1675	25835	19464	\N	55.806069934519698	Нижегородская область, Вачский район, Новосельский сельсовет, с. Новоселки, ул. Ленина, 91,Помещение сельской администрации	Россия, Нижегородская область, Вачский район, село Новоселки	0101000020E610000036AB3E575B574540B324404D2DE74B40
61132	7	68	1675	25344	17853	\N	55.827979999999997	Нижегородская область, Вачский район, Арефинский сельсовет, д. Медоварцево, 143, здание Медоварцевской школы		0101000020E6100000BA6B09F9A06D4540FCDEA63FFBE94B40
61145	7	68	1675	25956	17246	\N	55.836387999999999	Нижегородская область, Вачский район, Новосельский сельсовет, д. Лесниково, Школьная, 1а , помещение клуба		0101000020E61000009D2D20B41E524540286211C30EEB4B40
61153	7	68	1675	26311	\N	\N	55.822164999999998	Нижегородская область, Вачский район, Филинский сельсовет, с. Клин, Торговая, 15,помещение дома культуры	Россия, Нижегородская область, Вачский район, село Клин	0101000020E6100000581EA4A7C83D45403A75E5B33CE94B40
61136	7	68	1675	25528	16990	\N	55.763807	Нижегородская область, Вачский район, Казаковский сельсовет, с. Казаково, Заводская, 45, помещение школы		0101000020E61000005CE674594C6245405ABA826DC4E14B40
61137	7	68	1675	25590	17863	\N	55.732655999999999	Нижегородская область, Вачский район, Казаковский сельсовет, д. Звягино, молодежная, 21, Школа-сад		0101000020E6100000F27B9BFEEC614540ED9BFBABC7DD4B40
61133	7	68	1675	25374	\N	\N	55.821066999999999	Нижегородская область, Вачский район, Арефинский сельсовет, с. Епифаново, 133, ДК-библиотека		0101000020E61000006DC669882A724540946934B918E94B40
61150	7	68	1675	26164	17418	\N	55.694353	Нижегородская область, Вачский район, Филинский сельсовет, с. Давыдово, Большая слобода, 216, помещение дома культуры		0101000020E61000008881AE7D015145409370218FE0D84B40
61131	7	68	1675	25299	19452	\N	55.876671999999999	Нижегородская область, Вачский район, Арефинский сельсовет, д. Верхополье, Зеленая, 9, помещение школы		0101000020E6100000CEC7B5A162744540D2A8C0C936F04B40
61157	7	68	1675	21807	\N	\N	55.802346	Нижегородская область, Вачский район, р.п. Вача, ул.Ленина, д.8а, помещение Центра детского творчества	Россия, Нижегородская область, Вачский район, поселок Вача	0101000020E6100000CA6C904946604540C8091346B3E64B40
61138	7	68	1675	21807	\N	\N	55.802346	Нижегородская область, Вачский район, поселок Вача, Советская, 240, помещение детсада	Россия, Нижегородская область, Вачский район, поселок Вача	0101000020E6100000CA6C904946604540C8091346B3E64B40
61156	7	68	1675	21807	16687	\N	55.800653398902398	Нижегородская область, Вачский район, р.п. Вача, ул.Советская, д.3, помещение Вачской средней общеобразовательной школы	Россия, Нижегородская область, Вачский район, поселок Вача	0101000020E61000009A3E3BE0BA624540DE3829CC7BE64B40
61159	7	68	1675	21807	16678	\N	55.802346	Нижегородская область, Вачский район, поселок Вача, ул. Ленина, д.2 Учебный корпус школы интерната	Россия, Нижегородская область, Вачский район, поселок Вача	0101000020E6100000CA6C904946604540C8091346B3E64B40
61158	7	68	1675	21807	17243	\N	55.802346	Нижегородская область, Вачский район, поселок Вача, Больничная, 21, Центр занятости населения		0101000020E6100000CA6C904946604540C8091346B3E64B40
61149	7	68	1675	26110	\N	\N	55.794052000000001	Нижегородская область, Вачский район, Филинский сельсовет, д. Болотниково, 6, помещение медпункта		0101000020E6100000677C5F5CAA3A454065A9F57EA3E54B40
61151	7	68	1675	26220	\N	\N	55.716453000000001	Нижегородская область, Вачский район, Филинский сельсовет, с. Березовка, Центральная, 209, помещение дома культуры	Россия, Нижегородская область, Вачский район, село Березовка	0101000020E610000039D6C56D344E4540800F5EBBB4DB4B40
61144	7	68	1675	25898	\N	\N	55.790246000000003	Нижегородская область, Вачский район, Новосельский сельсовет, с. Беляйково, Глебово, 1а, помещение клуба	Россия, Нижегородская область, Вачский район, село Беляйково	0101000020E61000005DE15D2EE24F4540BDE5EAC726E54B40
61141	7	68	1675	25770	18098	\N	55.778497000000002	Нижегородская область, Вачский район, Казаковский сельсовет, д. Белогузово, Большой порядок, 38, Дом досуга		0101000020E610000033C4B12E6E6545405E8429CAA5E34B40
61129	7	68	1675	25205	17848	\N	55.874268999999998	Нижегородская область, Вачский район, Арефинский сельсовет, с. Арефино, Пестрякова, 44, Сельская администрация		0101000020E61000004EB6813B506F45400C74ED0BE8EF4B40
61130	7	68	1675	25205	17197	\N	55.874268999999998	Нижегородская область, Вачский район, Арефинский сельсовет, с. Арефино, Первомайская, 60, Дом культуры		0101000020E61000004EB6813B506F45400C74ED0BE8EF4B40
61139	7	68	1675	25688	17217	\N	55.7946666363205	Нижегородская область, Вачский район, Казаковский сельсовет, с. Алтунино, советская, 79,помещение сельской администрации	Россия, Нижегородская область, Вачский район, село Алтунино	0101000020E6100000838769DFDC694540EF1AF4A5B7E54B40
61120	7	68	1010	24800	16972	\N	57.361507000000003	Нижегородская область, Варнавинский район, п. Черемушки, Советская, 18		0101000020E6100000799109F835524640362383DC45AE4C40
61127	7	68	1010	25105	16791	\N	57.482154000000001	Нижегородская область, Варнавинский район, п. Северный, Молодежная, 25		0101000020E610000040A374E95F4A46405BD1E638B7BD4C40
61126	7	68	1010	25072	16917	\N	57.339646000000002	Нижегородская область, Варнавинский район, с. Новоникольское, ул. Центральная, д.41 – Дом культуры	Россия, Нижегородская область, Варнавинский район, село Новоникольское	0101000020E610000014419C8713684640CE1B278579AB4C40
61124	7	68	1010	24962	17834	\N	57.428040000000003	Нижегородская область, Варнавинский район, д. Михаленино, Школьная, 2	Россия, Нижегородская область, Варнавинский район, село Михаленино	0101000020E610000069A9BC1DE18646409FB0C403CAB64C40
61119	7	68	1010	24757	\N	\N	57.299807999999999	Нижегородская область, Варнавинский район, п. Мирный, Школьная, 6	Россия, Нижегородская область, Варнавинский район, село Мирный	0101000020E6100000B22FD978B05F4640228AC91B60A64C40
61122	7	68	1010	24878	16787	\N	57.296374999999998	Нижегородская область, Варнавинский район, с. Макарий, Молодежная, 25		0101000020E6100000AD6A4947398246400E2DB29DEFA54C40
61117	7	68	1010	24652	17179	\N	57.715614000000002	Нижегородская область, Варнавинский район, п. Красный Луч, Ленинская, 8		0101000020E610000022C154336B814640A647533D99DB4C40
61125	7	68	1010	24651	\N	\N	57.444612999999997	Нижегородская область, Варнавинский район, д. Зверниха, 45	Россия, Нижегородская область, Варнавинский район, село Зверниха	0101000020E6100000677E3507087E46402F302B14E9B84C40
61121	7	68	1010	24851	\N	\N	57.629147000000003	Нижегородская область, Варнавинский район, с. Горки, 17А	Россия, Нижегородская область, Варнавинский район, село Горки	0101000020E610000063F030ED9B89464032B08EE387D04C40
61118	7	68	1010	24703	16968	\N	57.234220999999998	Нижегородская область, Варнавинский район, п. Восход, ул. Центральная, д.13– здание школы		0101000020E6100000D41055F8335C4640A98427F4FA9D4C40
61114	7	68	1010	24490	\N	\N	57.400573999999999	Нижегородская область, Варнавинский район, поселок Варнавино, Нижегородская, 39	Россия, Нижегородская область, Варнавинский район, поселок Варнавино	0101000020E610000075594C6C3E8A46405FD0420246B34C40
61115	7	68	1010	24490	17137	\N	57.400573999999999	Нижегородская область, Варнавинский район, поселок Варнавино, III Интернационала, 1А		0101000020E610000075594C6C3E8A46405FD0420246B34C40
61123	7	68	1010	24934	16973	\N	57.360196000000002	Нижегородская область, Варнавинский район, с. Богородское, Первомайская, 1	Россия, Нижегородская область, Варнавинский район, село Богородское	0101000020E610000020B75F3E5981464034130CE71AAE4C40
61116	7	68	1010	24614	16964	\N	57.664966999999997	Нижегородская область, Варнавинский район, д. Антониха, Антонихинская, 14		0101000020E6100000F6D1A92B9F894640A9F57EA31DD54C40
61110	7	68	1703	24280	\N	\N	55.426304000000002	Нижегородская область, Вадский район, Новомирский сельсовет, п.Новый Мир, ул.Школьная, д.1, сельсовет	Россия, Нижегородская область, Вадский район, село совхоз Новый Мир	0101000020E610000093718C648F384640B613252191B64B40
42046	7	67	\N	369	49013	\N	58.621664000000003	Кировская область, Муниципальное образование город Киров, Лепсе, 18		0101000020E61000009CBF098508D24840DF8C9AAF924F4D40
61102	7	68	1703	23879	16784	\N	55.491579000000002	Нижегородская область, Вадский район, Стрельский сельсовет, с.Щедровка, ул.Микрорайон, д.8, «Щедровский детский сад»		0101000020E610000042CEFBFF380746404033880FECBE4B40
61113	7	68	1703	24479	17566	\N	55.407080000000001	Нижегородская область, Вадский район, Дубенский сельсовет, с.Холостой Майдан, ул,Майская, д.31, административное здание подсобного хозяйства «Майский»		0101000020E6100000B05758703F104640876D8B321BB44B40
61109	7	68	1703	23064	17381	\N	55.458357999999997	Нижегородская область, Вадский район, Новомирский сельсовет, с.Умай, ул.Центральная, д.3, ДК		0101000020E61000008046E9D2BF2A464013EE9579ABBA4B40
61101	7	68	1703	22803	\N	\N	55.521445	Нижегородская область, Вадский район, с.Стрелка, ул.Пешелань, д.33а, «Стрельская основная общеобразовательная школа»	Россия, Нижегородская область, Вадский район, село Стрелка	0101000020E610000027C286A757144640D4D4B2B5BEC24B40
61106	7	68	1703	22935	16958	\N	55.648204	Нижегородская область, Вадский район, Круто-Майданский сельсовет, с.Свобода, ул.Молодежная, д.1, школа		0101000020E6100000672783A3E427464075914259F8D24B40
61112	7	68	1703	25423	17384	\N	55.440579999999997	Нижегородская область, Вадский район, Дубенский сельсовет, с.Петлино, ул.Микрорайон, д.11, ДК		0101000020E61000006631B1F9B8164640C6A2E9EC64B84B40
61107	7	68	1703	24150	17563	\N	55.515822999999997	Нижегородская область, Вадский район, Лопатинский сельсовет, с.Лопатино, ул.Лопатинская, д.45а, ДК		0101000020E61000005837DE1D1929464026C3F17C06C24B40
61103	7	68	1703	22857	\N	\N	55.587218999999997	Нижегородская область, Вадский район, Круто-Майданский сельсовет, с.Крутой Майдан, ул.Микрорайон, д.7, «Крутомайданская основная  общеобразовательная  школа»	Россия, Нижегородская область, Вадский район, село Крутой Майдан	0101000020E610000063F20698F90846407F4B00FE29CB4B40
61104	7	68	1703	22857	16951	\N	55.587218999999997	Нижегородская область, Вадский район, Круто-Майданский сельсовет, с.Крутой Майдан, ул.Микрорайон, д.10, здание сельского Дома культуры		0101000020E610000063F20698F90846407F4B00FE29CB4B40
61105	7	68	1703	22864	16953	\N	55.616585000000001	Нижегородская область, Вадский район, Круто-Майданский сельсовет, с.Зеленые Горы, ул.Садовая, д.11, ДК		0101000020E6100000F6D214014E1B4640221ADD41ECCE4B40
61100	7	68	1703	22764	\N	\N	55.585296	Нижегородская область, Вадский район, Круто-Майданский сельсовет, с.Елховка, ул.Молодежная, д.60, ДК	Россия, Нижегородская область, Вадский район, село Елховка	0101000020E6100000ECC1A4F8F8244640643DB5FAEACA4B40
61111	7	68	1703	23112	\N	\N	55.365555000000001	Нижегородская область, Вадский район, Дубенский сельсовет, с.Дубенское, ул.Новая, д.1, ДК	Россия, Нижегородская область, Вадский район, село Дубенское	0101000020E6100000A911FA997A234640D4F19881CAAE4B40
61097	7	68	1703	22706	\N	\N	55.532792999999998	Нижегородская область, Вадский район, Вадский сельсовет, с. Вад, Полевая, 2	Россия, Нижегородская область, Вадский район, село Вад	0101000020E6100000BCB0355B79194640D4449F8F32C44B40
61098	7	68	1703	22706	16713	\N	55.532792999999998	Нижегородская область, Вадский район, Вадский сельсовет, с. Вад, Просвещения, 33, школа		0101000020E6100000BCB0355B79194640D4449F8F32C44B40
61096	7	68	1703	22706	17066	\N	55.532792999999998	Нижегородская область, Вадский район, Вадский сельсовет, с.Вад, ул.50 пет Октября д.16, РДК		0101000020E6100000BCB0355B79194640D4449F8F32C44B40
61108	7	68	1703	49733	19483	\N	55.470074940522998	Нижегородская область, Вадский район, Лопатинский сельсовет, п.Анненковский Карьер, ул.Центральная, д.1, школа	Россия, Нижегородская область, Вадский район, село Анненковского Карьера	0101000020E6100000A5D93C0E832F464067D5E76A2BBC4B40
61092	7	68	1536	22581	\N	\N	55.382880999999998	Нижегородская область, Бутурлинский район, с. Ягубовка, ул. Трудовая, д.104 Б, Сельский Дом культуры	Россия, Нижегородская область, Бутурлинский район, село Ягубовка	0101000020E610000087F8872D3D5A464040A19E3E02B14B40
61090	7	68	1536	22482	16938	\N	55.539003000000001	Нижегородская область, Бутурлинский район, с. Уварово, ул. Советская, д. 74, администрация Уваровского сельсовета		0101000020E61000000F4240BE8480464013B9E00CFEC44B40
61091	7	68	1536	22535	17154	\N	55.465769000000002	Нижегородская область, Бутурлинский район, с. Тарталей, ул. Октябрьская, д. 56, Сельский клуб		0101000020E6100000AF5A99F04B8D4640CD3E8F519EBB4B40
61067	7	68	1536	21970	17904	\N	55.588949	Нижегородская область, Бутурлинский район, с.Смагино, ул. Сутягина, д. 58, Сельский Дом культуры		0101000020E610000009E1D1C61165464086014BAE62CB4B40
61085	7	68	1536	23109	17750	\N	55.520701000000003	Нижегородская область, Бутурлинский район, с. Пергалей, ул.Мира, д.60, Сельский Дом культуры		0101000020E6100000E068C70DBF6146404CFF9254A6C24B40
61089	7	68	1536	22450	17362	\N	55.456102000000001	Нижегородская область, Бутурлинский район, с. Лукъяново, ул. Центральная, Фельдшерско-акушерский  пункт		0101000020E61000009C50888043684640F2D1E28C61BA4B40
61082	7	68	1536	22983	16930	\N	55.637545000000003	Нижегородская область, Бутурлинский район, с. Крутец, ул. Ленина , д. 126а, Сельский клуб		0101000020E61000006B7D91D0969146403A5D16139BD14B40
61083	7	68	1536	23019	\N	\N	55.636203999999999	Нижегородская область, Бутурлинский район, с. Кремницкое,ул. Молодежная, д.1а, МБДОУ Детский сад «Колокольчик»	Россия, Нижегородская область, Бутурлинский район, село Кремницкое	0101000020E610000038A11001877C4640CDCAF6216FD14B40
61086	7	68	1536	23144	16939	\N	55.444696	Нижегородская область, Бутурлинский район, с. Кочуново, ул. Центральная, д.16, Сельский Дом культуры		0101000020E6100000494C50C3B77E4640BD546CCCEBB84B40
61084	7	68	1536	23062	16778	\N	55.475892999999999	Нижегородская область, Бутурлинский район, с. Кетрось, ул. Новая, д. 17, МБДОУ Кетросский детский сад		0101000020E610000083DA6FED445B46409AB2D30FEABC4B40
61087	7	68	1536	22342	17150	\N	55.472822000000001	Нижегородская область, Бутурлинский район, с. Кеньшево, ул. Нагорная, д. 16 Б, Сельский клуб		0101000020E6100000950F41D5E87D4640276A696E85BC4B40
61081	7	68	1536	22938	17740	\N	55.590240999999999	Нижегородская область, Бутурлинский район, с. Каменищи, ул. 1 Мая , д. 69а, административное здание ООО Вперед		0101000020E610000033FD12F1D681464011E15F048DCB4B40
61088	7	68	1536	22410	17753	\N	55.425057000000002	Нижегородская область, Бутурлинский район, с. Инкино, ул.Школьная, д.15в, Сельский Дом культуры		0101000020E6100000EB387EA834704640CBF78C4468B64B40
61080	7	68	1536	22860	17739	\N	55.597289521439599	Нижегородская область, Бутурлинский район, с. Валгусы,ул. Молодежная, д.4, МОУ Валгусская СОШ (социокультурный  центр)	Россия, Нижегородская область, Бутурлинский район, село Валгусы	0101000020E6100000DBF7A8BF5E6F46402A1DACFF73CC4B40
61078	7	68	1536	18239	17532	\N	55.572569000000001	Нижегородская область, Бутурлинский район, р.п. Бутурлино, ул. П.Бегина , д.1, МБОУ Базинская ООШ(социокультурный центр)		0101000020E6100000A034D428247346400ADAE4F049C94B40
61076	7	68	1536	18239	16771	\N	55.571287519384498	Нижегородская область, Бутурлинский район, р.п. Бутурлино, ул. Ленина, д.105, Районный Дворец культуры	Россия, Нижегородская область, Бутурлинский район, поселок Бутурлино	0101000020E61000001841632651734640734C16F71FC94B40
61077	7	68	1536	18239	17737	\N	55.568836413232802	Нижегородская область, Бутурлинский район, р.п. Бутурлино, Комсомольская, 7 (Бутурлинский сельскохозяйственн)		0101000020E61000002524D236FE704640CB64389ECFC84B40
61093	7	68	1536	22626	17551	\N	55.374594999999999	Нижегородская область, Бутурлинский район, с. Борнуково, ул. Центральная, д.126 А, Сельский Дом культуры		0101000020E6100000AA622AFD84634640601F9DBAF2AF4B40
61094	7	68	1536	22679	17648	\N	55.382446999999999	Нижегородская область, Бутурлинский район, с. Б-Якшень, ул.Спортивная, д.1а,  Якшенская ООШ - филиал МБОУ Ягубовской СОШ		0101000020E61000000D39B69E2148464006BAF605F4B04B40
61079	7	68	1536	22862	17738	\N	55.658819999999999	Нижегородская область, Бутурлинский район, с. Б-Бакалды, ул. Первомайская , д.75, Сельский Дом культуры		0101000020E61000006420CF2EDF5E4640B1F9B83654D44B40
61069	7	68	983	49713	16948	\N	56.252483105555498	МБОУ Ямновская Средняя Общеобразовательная Школа. Нижегородская область, город Бор, Ямновский сельсовет, с. Ямново, ул. Школьная, д. 18		0101000020E6100000E657738060464640E2E5E95C51204C40
61046	7	68	983	49818	\N	\N	56.529347000000001	Клуб.  Нижегородская область, город Бор, Кантауровский сельсовет, п. Шпалозавода, Клуб	Россия, Нижегородская область, Борский район, село Шпалозавода	0101000020E6100000A9BF5E61C10546402C9E7AA4C1434C40
61062	7	68	983	49707	16920	\N	56.251222859327299	МБОУ Чистоборская Основная Общеобразовательная Школа. Нижегородская область, город Бор, Редькинский сельсовет, п. Чистое-Борское, ул. Ленина, д. 5		0101000020E6100000B476DB85E63446406380441328204C40
61053	7	68	983	49628	\N	\N	56.764266618313997	Чистопольское представительство Линдовского территориального управления администрации городского округа город Бор. Нижегородская область, город Бор, Линдовский сельсовет, с. Чистое Пооле	Россия, Нижегородская область, Борский район, село Чистое Поле	0101000020E61000003FFD67CD8F034640BD344580D3614C40
61038	7	68	983	49708	\N	\N	56.418880000000001	ФАП.  Нижегородская область, город Бор, Ситниковский сельсовет, д. Тайново, д. 67а		0101000020E6100000944E24986AFC454068791EDC9D354C40
61040	7	68	983	21041	17115	\N	56.445588000000001	МБУК Ситниковский Дом Культуры,  Нижегородская область, город Бор, Ситниковский сельсовет, п. Ситники, ул. Центральная, д. 21		0101000020E610000006F2ECF2AD054640BABE0F0709394C40
61064	7	68	983	49805	\N	\N	56.504453154503103	Рустайское представительство Останкинского территориального управления администрации городского округа город Бор. Нижегородская область, город Бор, Останкинский сельсовет, п. Рустай	Россия, Нижегородская область, Борский район, село Рустай	0101000020E61000004F9143C4CD6746403EAF78EA91404C40
61061	7	68	983	50027	\N	\N	56.274856083558298	Рожновское представительство Редькинского территориального управления администрации городского округа город Бор.Нижегородская область, город Бор, Редькинский сельсовет, д. Рожново		0101000020E6100000D1EB4FE273294640008E3D7B2E234C40
61043	7	68	983	21206	\N	\N	56.448998726997502	ГОУ Рекшинское ПУ-интернат,  Нижегородская область, город Бор, Ситниковский сельсовет, д. Рекшино, д. 93	Россия, Нижегородская область, Борский район, село Рекшино	0101000020E6100000637D03931B014640E6779ACC78394C40
61060	7	68	983	49748	\N	\N	56.319839000000002	МБУК Редькинский СКК. Нижегородская область, город Бор, Редькинский сельсовет, с. Редькино, д. 19	Россия, Нижегородская область, Борский район, село Редькино	0101000020E6100000520FD1E80E1A4640207EFE7BF0284C40
61044	7	68	983	50026	\N	\N	56.496134821831902	ГОУ Поповская специальная школа-интернат.  Нижегородская область, город Бор, Ситниковский сельсовет, д. Попово	Россия, Нижегородская область, Борский район, поселок Попово	0101000020E6100000EF54C03DCF0B464053B3075A813F4C40
60964	7	68	1428	17036	17186	\N	55.067596999999999	Нижегородская область, Большеболдинский район, с. Аносово, ул. Ленина, д. 1А		0101000020E610000096CE876709A646406327BC04A7884B40
61072	7	68	983	50024	19422	\N	56.186296746894399	МБОУ Плотинковская Основная Общеобразовательная Школа. Нижегородская область, город Бор, Ямновский сельсовет, д. Плотинка, ул. Школьная, д. 236	Россия, Нижегородская область, Борский район, село Плотинка	0101000020E610000087C0914083634640E52B8194D8174C40
61068	7	68	983	49742	17145	\N	56.1045151115257	МБОУ Затонская Средняя Общеобразовательная Школа. Нижегородская область, город Бор, сельсовет Память Парижской Коммуны, п. Память Парижской Коммуны, ул. Школьная, д. 11	Россия, Нижегородская область, Борский район, поселок Память Парижской Коммуны	0101000020E6100000890B40A3743F464081785DBF600D4C40
61066	7	68	983	49742	17088	\N	56.107196999999999	"МБУК ""Дом Культуры-музей"". Нижегородская область, город Бор, сельсовет Память Парижской Коммуны, п. Память Парижской Коммуны, ул. Зеленая, д. 1"	Россия, Нижегородская область, Борский район, поселок Память Парижской Коммуны	0101000020E6100000BF81C98D223F46405A9D9CA1B80D4C40
61063	7	68	983	49629	16711	\N	56.272450356318402	МБОУ Останкинская Средняя Общеобразовательная Школа. Нижегородская область, город Бор, Останкинский сельсовет, с. Останкино, ул. Школьная, д. 13	Россия, Нижегородская область, Борский район, село Останкино	0101000020E61000003D7D04FEF0354640C9E53FA4DF224C40
61054	7	68	983	21675	\N	\N	56.392124000000003	"МБОУ Детский сад ""Пчелка"". Нижегородская область, город Бор, Краснослободский сельсовет, д. Оманово, д.8"	Россия, Нижегородская область, Борский район, село Оманово	0101000020E61000006F0D6C95600F464005FD851E31324C40
61031	7	68	983	49756	17155	\N	56.300001585135199	МБОУ Октябрьская Средняя Общеобразовательная Школа.  Нижегородская область, город Бор, п. Октябрьский, ул. Победы, д. 15а		0101000020E61000008C82E0F1ED174640075E2D7766264C40
60961	7	68	983	20794	17610	\N	56.396863674048099	"МБОУ Неклюдовский детский сад ""Рукавичка"". Нижегородская область, город Бор, кварт. Дружба, д. 14"		0101000020E610000022FE614B8F004640D97A8670CC324C40
61036	7	68	983	20794	17698	\N	56.406027000000002	"МБОУ ДОД детский сад №8 ""Жемчужинка"".  Нижегородская область, город Бор, п. Неклюдово, ул. Лесная, д. 5"		0101000020E6100000B685E7A562FF4540812557B1F8334C40
61035	7	68	983	20794	17315	\N	56.406027000000002	Нижегородская область, город Бор, п. Неклюдово, ул. Клубная, д. 4а. МУК Неклюдовский Дом Культуры		0101000020E6100000B685E7A562FF4540812557B1F8334C40
61033	7	68	983	20794	17534	\N	56.406027000000002	МБОУ Средняя Общеобразовательная Школа № 12. Нижегородская область, город Бор,  п. Неклюдово, ул. Дружбы, д. 1а	Россия, Нижегородская область, Борский район, поселок Неклюдово	0101000020E6100000B685E7A562FF4540812557B1F8334C40
61034	7	68	983	20794	17697	\N	56.406027000000002	"Производственное подразделение ВГГП ""Волгагеология"".  Нижегородская область, город Бор, п. Неклюдово, ул. Вокзальная, д. 88"		0101000020E6100000B685E7A562FF4540812557B1F8334C40
61050	7	68	983	8243	\N	\N	56.617699999999999	Нижегородская область, город Бор, с. Линда, ул. Дзержинского , д.40. Линдовское территориальное управление администрации городского округа	Россия, Нижегородская область, Борский район, село Линда	0101000020E610000032CB9E04360D46409E5E29CB104F4C40
61049	7	68	983	8243	16719	\N	56.6172240596024	МБУК  Линдовский ДКС.  Нижегородская область, город Бор, Линдовский сельсовет, с. Линда, ул. Школьная, д. 11а	Россия, Нижегородская область, Борский район, село Линда	0101000020E61000009E978A8D790D464035272F32014F4C40
61047	7	68	983	8243	16719	\N	56.616193939282098	МБОУ Линдовская Средняя Общеобразовательная Школа.  Нижегородская область, город Бор, Линдовский сельсовет, с. Линда, ул. Школьная, д. 7а	Россия, Нижегородская область, Борский район, село Линда	0101000020E6100000514B732B840B4640E7FEEA71DF4E4C40
61438	7	68	983	8243	17333	\N	56.6145561331385	Нижегородская область, город Бор, Линдовский сельсовет, с. Линда, ул. Дзержинского, д.40, Линдовское территориальное управление администрации городского округа	Россия, Нижегородская область, Борский район, село Линда	0101000020E6100000D09A1F7F690B4640C1C760C5A94E4C40
61055	7	68	983	49703	16912	\N	56.431829316904398	МБУК Краснослободский СКК. Нижегородская область, город Бор, Краснослободский сельсовет, д. Красная слобода, ул. Центральная, д. 24	Россия, Нижегородская область, Борский район, село Красная Слобода	0101000020E6100000D236FE4465174640713B342C46374C40
61051	7	68	983	50038	\N	\N	56.3656371585204	Ковровское представительство Линдовского территориального управления администрации городского округа город Бор.  Нижегородская область, город Бор, Линдовский сельсовет, д. Коврово, помещение Ковровского представительства		0101000020E610000001309E41430D4640919A7631CD2E4C40
61057	7	68	983	50023	\N	\N	56.473038611513502	Клуб. Нижегородская область, город Бор, Краснослободский сельсовет,п. Керженец, помещение клуба		0101000020E6100000DFC4909C4C364640C45DBD8A8C3C4C40
61575	7	68	983	49801	17475	\N	56.492492450011603	МБОУ Кантауровская Средняя Общеобразовательная Школа. Нижегородская область, город Бор, Кантауровский сельсовет, с. Кантаурово, ул. Совхозная, д. 15б	Россия, Нижегородская область, Борский район, село Кантаурово	0101000020E6100000921FF12BD604464054C554FA093F4C40
60957	7	68	1389	49858	\N	\N	56.077426474120003	"Нижегородская область, Богородский район, Шапкинский сельсовет, д. Высоково, помещение спортивной базы ""Снежинка"""		0101000020E6100000B2A19BFD81C2454018EE5C18E9094C40
61042	7	68	983	49801	17475	\N	56.494500000000002	"МБУК ""Кантауровский социально-культурный комплекс"".  Нижегородская область, город Бор, Ситниковский сельсовет, с. Кантаурово, ул. Совхозная, д. 20А"	Россия, Нижегородская область, Борский район, село Кантаурово	0101000020E6100000CEE2C5C2100546409EEFA7C64B3F4C40
61045	7	68	983	49704	\N	\N	56.547663923910399	Дом культуры.  Нижегородская область, город Бор, Кантауровский сельсовет, д. Каликино, ДК	Россия, Нижегородская область, Борский район, село Каликино	0101000020E6100000BE6A65C22F07464028999CDA19464C40
61039	7	68	983	49631	\N	\N	56.394067074025699	Нижегородская область, город Бор, Ситниковский сельсовет, д. Ивонькино, помещение Ивонькинского представительства	Россия, Нижегородская область, Борский район, село Ивонькино	0101000020E61000002B155454FD06464067B796C970324C40
61071	7	68	983	49775	\N	\N	56.405822999999998	Нижегородская область, город Бор, с. Ивановское, Ямновский сельсовет, Бывшая школа села Ивановское	Россия, Нижегородская область, Борский район, село Ивановское	0101000020E6100000910F7A36AB1A4640787B1002F2334C40
61070	7	68	983	49830	17677	\N	56.218201000000001	Библиотека. Нижегородская область, город Бор, Ямновский сельсовет, д. Завражное, ул. Клубная, д.6, кв. 4		0101000020E6100000560F98874C4146402D7AA702EE1B4C40
61574	7	68	983	14639	16752	\N	56.475915999999998	"Нижегородская область, город Бор, Ситниковский сельсовет,  п. Железнодорожный ул. Центральная, д. 6. МБУК ""Центр досуга"""		0101000020E610000069519FE40E07464052D2C3D0EA3C4C40
61041	7	68	983	14639	16752	\N	56.475915999999998	"Нижегородская область, город Бор, Ситниковский сельсовет, п. Железнодорожный, ул.Центральная д.6. МБУК ""Центр досуга"""		0101000020E610000069519FE40E07464052D2C3D0EA3C4C40
61058	7	68	983	21888	\N	\N	56.370154999999997	Нижегородская область, город Бор, Краснослободский сельсовет, с. Городищи , д.2. Городищенксое представительство Краснослободского территориального управления администрации городского округа		0101000020E6100000FC00A43671304640B6B9313D612F4C40
61059	7	68	983	49827	\N	\N	56.350539527329197	"ООО ""Гласс-Продакт"". Нижегородская область, город Бор, Редькинский сельсовет, д. Владимирово, д. 5"	Россия, Нижегородская область, Борский район, село Владимирово	0101000020E61000006F9D7FBBEC1146404DF8A57EDE2C4C40
61075	7	68	983	50081	19811	\N	56.389469435590698	"Демонстрационный дом , Нижегородская область, город Бор, жилой район ""Боталово-3"", ул. Филатова, д. 6"	Россия, Нижегородская область, Борский район, село Боталово	0101000020E61000004D672783A304464025E7C41EDA314C40
61028	7	68	983	49787	17393	\N	56.348255035191102	МБУК Большепикинский дом культуры.  Нижегородская область, город Бор, п. Большое Пиконо, ул. 1 Мая, д. 10	Россия, Нижегородская область, Борский район, поселок Большое Пикино	0101000020E6100000DD955D30B818464091D5AD9E932C4C40
60960	7	68	983	49787	17393	\N	56.349384999999998	МБУК Большепикинский дом культуры. Нижегородская область, город Бор, п. Большое Пикино, ул. 1 Мая, д.10	Россия, Нижегородская область, Борский район, поселок Большое Пикино	0101000020E61000008F5033A48A184640425BCEA5B82C4C40
61065	7	68	983	49812	\N	\N	56.421538537586102	"МУК ""Большеорловский социально-культурный комплекс"". Нижегородская область, город Бор, Останкинский сельсовет, п. Большеорловское"	Россия, Нижегородская область, Борский район, село Большеорловское	0101000020E61000006BB8C83D5D4D4640897E6DFDF4354C40
60998	7	68	1526	18775	\N	\N	55.827747000000002	Нижегородская область, Большемурашкинский район, село Холязино, Дом культуры	Россия, Нижегородская область, Большемурашкинский район, село Холязино	0101000020E61000001E8CD827806246405A2E1B9DF3E94B40
60991	7	68	1526	49769	\N	\N	55.821406000000003	Нижегородская область, Большемурашкинский район, поселок Советский, сельский Дом культуры		0101000020E6100000D26F5F07CE5746407D5EF1D423E94B40
60990	7	68	1526	18316	\N	\N	55.708896000000003	Нижегородская область, Большемурашкинский район, село Рождествено, Дом культуры	Россия, Нижегородская область, Большемурашкинский район, село Рождествено	0101000020E6100000D63730B951664640F321A81ABDDA4B40
60994	7	68	1526	18542	\N	\N	55.832970000000003	Нижегородская область, Большемурашкинский район, село Курлаково, помещение сельской администрации	Россия, Нижегородская область, Большемурашкинский район, село Курлаково	0101000020E61000009296CADB115046404A46CEC29EEA4B40
60996	7	68	1526	18674	\N	\N	55.884518999999997	Нижегородская область, Большемурашкинский район, с.Кишкино, Дом культуры	Россия, Нижегородская область, Большемурашкинский район, село Кишкино	0101000020E6100000115663096B59464066D828EB37F14B40
60995	7	68	1526	18625	\N	\N	55.830016999999998	Нижегородская область, Большемурашкинский район, село Карабатово, Дом культуры	Россия, Нижегородская область, Большемурашкинский район, село Карабатово	0101000020E6100000D996016729434640E00F3FFF3DEA4B40
60997	7	68	1526	18703	\N	\N	55.896070000000002	"Нижегородская область, Большемурашкинский район, село Ивановское, помещение ОАО ""Суворовское"""		0101000020E61000000553CDACA57046409F76F86BB2F24B40
60993	7	68	1526	18498	\N	\N	55.781069000000002	Нижегородская область, Большемурашкинский район, село Григорово, Сельский Дом культуры		0101000020E61000003D821B295B504640B075A911FAE34B40
60791	7	68	992	8793	\N	\N	55.328626999999997	Нижегородская область, Арзамасский район, с.Кожино, ФАП с.Кожино		0101000020E610000081AFE8D66BF0454092CA147310AA4B40
60992	7	68	1526	18428	\N	\N	55.742792000000001	Нижегородская область, Большемурашкинский район, село Вершинино, Детский сад	Россия, Нижегородская область, Большемурашкинский район, село Вершинино	0101000020E6100000D80C7041B65E46407FDDE9CE13DF4B40
60987	7	68	1526	18050	\N	\N	55.779231000000003	Нижегородская область, Большемурашкинский район, Большое Мурашкино, Школьная, 20	Россия, Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино	0101000020E610000020B3B3E89D624640C38366D7BDE34B40
60985	7	68	1526	18050	\N	\N	55.779231000000003	Нижегородская область, Большемурашкинский район, Большое Мурашкино, Старо-Луговая, 20	Россия, Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино	0101000020E610000020B3B3E89D624640C38366D7BDE34B40
60986	7	68	1526	18050	18012	\N	55.779231000000003	Нижегородская область, Большемурашкинский район, Большое Мурашкино, п.Меховщиков		0101000020E610000020B3B3E89D624640C38366D7BDE34B40
60989	7	68	1526	18050	17264	\N	55.779231000000003	Нижегородская область, Большемурашкинский район, Большое Мурашкино, Спортивная, 2а		0101000020E610000020B3B3E89D624640C38366D7BDE34B40
60984	7	68	1526	18050	17951	\N	55.779231000000003	Нижегородская область, Большемурашкинский район, Большое Мурашкино, Свободы, 80		0101000020E610000020B3B3E89D624640C38366D7BDE34B40
60988	7	68	1526	18050	17956	\N	55.779231000000003	Нижегородская область, Большемурашкинский район, Большое Мурашкино, 6-й микрорайон, 2		0101000020E610000020B3B3E89D624640C38366D7BDE34B40
60983	7	68	1428	18000	17939	\N	54.980038	Нижегородская область, Большеболдинский район, с. Чиреси, ул. Восточная, д. 15А		0101000020E61000001A886533878E46402B6B9BE2717D4B40
60982	7	68	1428	17964	17257	\N	55.125304	Нижегородская область, Большеболдинский район, с. Черновское, ул. Центральная, д. 4		0101000020E6100000FA62EFC517AF46406C0723F609904B40
60981	7	68	1428	17901	17039	\N	55.104723	Нижегородская область, Большеболдинский район, д. Усад, ул. Центральная, д. 1		0101000020E6100000F67F0EF3E5AD4640CB113290678D4B40
60979	7	68	1428	17797	17253	\N	55.039662	Нижегородская область, Большеболдинский район, с. Сумароково, ул. Школьная, д. 59		0101000020E610000036CCD078228A46406D72F8A413854B40
60978	7	68	1428	17721	16813	\N	55.130456000000002	Нижегородская область, Большеболдинский район, с. Старое Ахматово, ул. Балашова, д. 38		0101000020E61000003B730F09DF9F464093C83EC8B2904B40
60980	7	68	1428	17817	17256	\N	54.998829000000001	Нижегородская область, Большеболдинский район, с. Сергеевка, ул. Ленина, д. 14А		0101000020E6100000CD02ED0E29984640F0A5F0A0D97F4B40
60976	7	68	1428	17646	16681	\N	54.979945000000001	Нижегородская область, Большеболдинский район, с. Пикшень, ул. Ленина, д. 1	Россия, Нижегородская область, Большеболдинский район, село Пикшень	0101000020E610000095D5743DD1AF46407A7077D66E7D4B40
60977	7	68	1428	17714	16812	\N	54.974178999999999	Нижегородская область, Большеболдинский район, с. Пермеево, ул. Молодежная, д. 21		0101000020E61000005C02F04FA99A464099B9C0E5B17C4B40
60975	7	68	1428	50055	19539	\N	54.9228907616071	Нижегородская область, Большеболдинский район, с. Новая Слобода, ул. Советская, д. 14б	Россия, Нижегородская область, Большеболдинский район, село Новая Слобода	0101000020E61000007ADFF8DA33914640E962D34A21764B40
60974	7	68	1428	17560	\N	\N	55.106845	Нижегородская область, Большеболдинский район, с. Молчаново, ул. Свободы, д. 22	Россия, Нижегородская область, Большеболдинский район, село Молчаново	0101000020E6100000AD855968E79A4640DD5ED218AD8D4B40
60973	7	68	1428	17487	\N	\N	54.915444999999998	Нижегородская область, Большеболдинский район, с. Кондрыкино, ул. Красная, д. 38	Россия, Нижегородская область, Большеболдинский район, село Кондрыкино	0101000020E6100000685DA3E540854640B324404D2D754B40
60972	7	68	1428	17447	17549	\N	55.047358000000003	Нижегородская область, Большеболдинский район, с. Илларионово, ул. Советская, д. 140		0101000020E6100000C25087156E9346401C9AB2D30F864B40
60969	7	68	1428	17278	\N	\N	55.035730000000001	Нижегородская область, Большеболдинский район, с. Большое Казариново, ул. Комсомольская, д. 2А, Здание Дома культуры	Россия, Нижегородская область, Большеболдинский район, поселок Большое Казариново	0101000020E6100000F8DD74CB0EA7464038BEF6CC92844B40
60968	7	68	1428	15909	17239	\N	55.000368000000002	Нижегородская область, Большеболдинский район, с. Большое Болдино, ул. Пушкинская, д. 144		0101000020E6100000B7CF2A33A5A7464083FB010F0C804B40
60966	7	68	1428	15909	16999	\N	55.000368000000002	Нижегородская область, Большеболдинский район, с. Большое Болдино, ул. Красная, д. 12		0101000020E6100000B7CF2A33A5A7464083FB010F0C804B40
60941	7	68	1428	15909	17355	\N	55.000368000000002	Нижегородская область, Большеболдинский район, с. Большое Болдино, ул. Кооперативная, д. 7		0101000020E6100000B7CF2A33A5A7464083FB010F0C804B40
60967	7	68	1428	15909	16677	\N	55.000368000000002	Нижегородская область, Большеболдинский район, с. Большое Болдино, ул. Восточная, д. 28		0101000020E6100000B7CF2A33A5A7464083FB010F0C804B40
60970	7	68	1428	17337	\N	\N	54.936481000000001	Нижегородская область, Большеболдинский район, с. Большие Поляны, ул. Сорокина, д, 7А	Россия, Нижегородская область, Большеболдинский район, село Большие Поляны	0101000020E6100000778192020B784640A629029CDE774B40
60971	7	68	1428	17380	\N	\N	54.896475000000002	Нижегородская область, Большеболдинский район, п. Большевик, ул. Центральная, д. 11А	Россия, Нижегородская область, Большеболдинский район, село Большевик	0101000020E6100000E23B31EBC57846403F575BB1BF724B40
60965	7	68	1428	17099	16722	\N	55.083694000000001	Нижегородская область, Большеболдинский район, с. Апраксино, ул. Гагарина, д. 75		0101000020E6100000AB22DC6454B546408B6F287CB68A4B40
60933	7	68	1389	49656	\N	\N	56.154485378245298	Нижегородская область, Богородский район, Алешковский сельсовет, д. Швариха, Школа	Россия, Нижегородская область, Богородский район, село Швариха	0101000020E6100000492BBEA1F0B345407D5C1B2AC6134C40
60954	7	68	1389	16545	\N	\N	56.016475999999997	Нижегородская область, Богородский район, Шапкинский сельсовет, с. Шапкино, помещение сельской администрации		0101000020E61000000664AF777FC645409E95B4E21B024C40
60956	7	68	1389	16653	\N	\N	56.074685000000002	Нижегородская область, Богородский район, Шапкинский сельсовет, п. Центральный, Дом культуры	Россия, Нижегородская область, Богородский район, село Центральный	0101000020E61000001C25AFCE31C045403A4030478F094C40
60951	7	68	1389	16407	\N	\N	55.897554	Нижегородская область, Богородский район, Хвощёвский сельсовет, с. Хвощевка, помещение сельской администрации		0101000020E610000044BE4BA94BC645406E32AA0CE3F24B40
60931	7	68	1389	15440	\N	\N	56.137886000000002	Нижегородская область, Богородский район, Алешковский сельсовет, д. Ушаково, Дом культуры	Россия, Нижегородская область, Богородский район, село Ушаково	0101000020E61000009A3E3BE0BAAC4540C3499A3FA6114C40
60929	7	68	1389	49740	\N	\N	56.037820094674601	Нижегородская область, Богородский район, Алешковский сельсовет, д. Теряево, школа		0101000020E6100000884B8E3BA5AF45403F912749D7044C40
60940	7	68	1389	49630	16712	\N	56.179339382943503	Нижегородская область, Богородский район, Дуденевский сельсовет, д. Сысоевка, Совхозная, помещение ФАП	Россия, Нижегородская область, Богородский район, село Сысоевка	0101000020E6100000E910381268CC4540DCF29194F4164C40
60958	7	68	1389	16737	\N	\N	55.989542	Нижегородская область, Богородский район, Шапкинский сельсовет, д. Солонское, Дом культуры	Россия, Нижегородская область, Богородский район, село Солонское	0101000020E610000068CD8FBFB4B645405C02F04FA9FE4B40
60950	7	68	1389	16330	\N	\N	55.895439000000003	Нижегородская область, Богородский район, Хвощёвский сельсовет, с. Оранки, помещение филиала Хвощевскрй сельской администрации	Россия, Нижегородская область, Богородский район, село Оранки	0101000020E6100000848252B472DB45400F48C2BE9DF24B40
60935	7	68	1389	49829	\N	\N	56.174312419357598	Нижегородская область, Богородский район, Доскинский сельсовет, п. Окский, Дом культуры		0101000020E6100000E2AE5E4546E3454072A609DB4F164C40
60946	7	68	1389	49793	\N	\N	56.203902148650599	Нижегородская область, Богородский район, Новинский сельсовет, п. Новинки, Дом культуры	Россия, Нижегородская область, поселок Новинки, улица Центральная	0101000020E610000031B610E4A0F0454064CBF275191A4C40
60955	7	68	1389	16585	\N	\N	55.979610999999998	Нижегородская область, Богородский район, Шапкинский сельсовет, с. Лукино, помещение школы		0101000020E6100000A45016BEBECC4540A3E6ABE463FD4B40
60952	7	68	1389	16414	\N	\N	56.040204000000003	Нижегородская область, Богородский район, Шапкинский сельсовет, с. Лакша, помещение филиала Шапкинской сельской администрации		0101000020E6100000069E7B0F97D045408E95986725054C40
60947	7	68	1389	49639	\N	\N	56.186651237872901	Нижегородская область, Богородский район, Новинский сельсовет, д. Кусаковка, Помещение ФАП	Россия, Нижегородская область, деревня Кусаковка, улица Центральная	0101000020E6100000211E8997A7F545400262122EE4174C40
60948	7	68	1389	49736	17072	\N	56.163556088240597	Нижегородская область, Богородский район, Новинский сельсовет, п. Кудьма, Дом культуры	Россия, Нижегородская область, поселок Кудьма, улица Пушкина	0101000020E610000085402E71E4EF454044882B67EF144C40
60949	7	68	1389	16278	17867	\N	55.845198000000003	Нижегородская область, Богородский район, Хвощёвский сельсовет, д.Ключищи, ул.Дорожная, 8, Помещение начальной школы		0101000020E61000001DE736E15EC745408352B4722FEC4B40
60943	7	68	1389	15986	\N	\N	56.066695000000003	Нижегородская область, Богородский район, Каменский сельсовет, с. Каменки, помещение сельской администрации	Россия, Нижегородская область, Богородский район, село Каменки	0101000020E61000007EE02A4F20EE454043E7357689084C40
60945	7	68	1389	15986	17856	\N	56.066695000000003	Нижегородская область, Богородский район, Каменский сельсовет, с. Каменки, Зеленая, 37		0101000020E61000007EE02A4F20EE454043E7357689084C40
60942	7	68	1389	49754	\N	\N	55.934076312033099	Нижегородская область, Богородский район, Каменский сельсовет, д. Инютино, помещение филиала Каменской сельской администрации	Россия, Нижегородская область, Богородский район, село Инютино	0101000020E6100000FA28232E00F145403FFD67CD8FF74B40
60938	7	68	1389	15732	\N	\N	56.180306999999999	Нижегородская область, Богородский район, Дуденевский сельсовет, с. Дуденево, помещение сельской администрации		0101000020E61000009411178046C14540B41EBE4C14174C40
60934	7	68	1389	49741	\N	\N	56.166118249045603	Нижегородская область, Богородский район, Доскинский сельсовет, с. Доскино, Школа	Россия, Нижегородская область, село Доскино, улица Ульянова	0101000020E6100000923CD7F7E1DE454072A3C85A43154C40
60928	7	68	1389	49641	\N	\N	56.098568601589903	Нижегородская область, Богородский район, Алешковский сельсовет, д. Демидово, помещение ФАП	Россия, Нижегородская область, Богородский район, село Демидово	0101000020E61000009E60FF756EBC454020B3B3E89D0C4C40
60925	7	68	1389	49641	17397	\N	56.102325834314001	Нижегородская область, Богородский район, город Богородск, 3-ий микрорайон, 4а	Россия, Нижегородская область, Богородский район, село Демидово	0101000020E6100000D0F1D1E28CBB4540E7C3B304190D4C40
60936	7	68	1389	49739	\N	\N	56.146748000000002	Нижегородская область, Богородский район, Доскинский сельсовет, п. Буревестник, Дом культуры	Россия, Нижегородская область, поселок Буревестник	0101000020E6100000346612F582E54540706072A3C8124C40
60920	7	68	1389	49723	19453	\N	56.108423047836197	Нижегородская область, Богородский район, город Богородск, пер. К. Маркса, 1		0101000020E6100000DD09F65FE7C045402E910BCEE00D4C40
60922	7	68	1389	49723	17192	\N	56.102583667361799	Нижегородская область, Богородский район, город Богородск, Чернышевского, 42		0101000020E61000005436ACA92CBE4540E38BF678210D4C40
60917	7	68	1389	49723	19436	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Урицкого, 69	Россия, Нижегородская область, Богородск	0101000020E61000004981053065C24540B0AC3429050D4C40
60921	7	68	1389	49723	17390	\N	56.102775541992997	"Нижегородская область, Богородский район, город Богородск, ул.Пушкина, 24, столовая ОАО ""Богородский машиностроительный завод"""	Россия, Нижегородская область, Богородск	0101000020E61000000C5C1E6B46C24540276893C3270D4C40
60959	7	68	1389	49723	17006	\N	56.10172	Нижегородская область, Богородский район, город Богородск, ул.Ленина, д.101, Фойе районного Дома культуры		0101000020E61000004981053065C24540B0AC3429050D4C40
60926	7	68	1389	49723	17006	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Ленина, 101		0101000020E61000004981053065C24540B0AC3429050D4C40
60915	7	68	1389	49723	19402	\N	56.1002331251931	Нижегородская область, Богородский район, город Богородск, Добролюбова, 2		0101000020E6100000D0285DFA97C24540707D586FD40C4C40
60913	7	68	1389	49723	17182	\N	56.10172	Нижегородская область, Богородский район, город Богородск, Данилова, 36		0101000020E61000004981053065C24540B0AC3429050D4C40
60918	7	68	1389	49723	19442	\N	56.096398194140001	Нижегородская область, Богородский район, город Богородск, Героя Салова, 15		0101000020E6100000C7BAB88D06C045402DB308C5560C4C40
60924	7	68	1389	49723	17388	\N	56.1009706832765	Нижегородская область, Богородский район, город Богородск, 3-ий микрорайон, 15а		0101000020E6100000AFE9414129BC4540166C239EEC0C4C40
60939	7	68	1389	15801	17841	\N	56.123793999999997	Нижегородская область, Богородский район, Дуденевский сельсовет, д.Березовка, ул.Комсомольская, Школа		0101000020E610000052280B5F5FC9454073B8567BD80F4C40
60953	7	68	1389	16499	\N	\N	56.034706999999997	Нижегородская область, Богородский район, Шапкинский сельсовет, с. Афанасьево, Дом досуга		0101000020E6100000FF2268CC24DC45409CF86A4771044C40
60930	7	68	1389	15376	\N	\N	56.112848999999997	Нижегородская область, Богородский район, Алешковский сельсовет, с. Арапово, помещение филиала Алешковской сельской администрации		0101000020E6100000BAD7497D59A04540723106D6710E4C40
60927	7	68	1389	15223	\N	\N	56.066634999999998	Нижегородская область, Богородский район, Алешковский сельсовет, с. Алешково, Дом Фольклора	Россия, Нижегородская область, Богородский район, село Алешково	0101000020E6100000BB0ED59464B545406DE2E47E87084C40
60904	7	68	916	14118	\N	\N	56.608258999999997	Нижегородская область, Балахнинский район, д.Шеляухово, д.58А		0101000020E61000004223D8B8FEB74540B33F506EDB4D4C40
60906	7	68	916	14241	\N	\N	56.561781000000003	Нижегородская область, Балахнинский район, п.Совхозный, Дом Досуга		0101000020E6100000B1DEA815A6BD4540D1419770E8474C40
60903	7	68	916	49817	19772	\N	56.403044283673701	Нижегородская область, Балахнинский район, р.п.Большое Козино, Пушкина, 1, СОШ №20		0101000020E6100000D89B189293D94540AD6C1FF296334C40
60902	7	68	916	49817	19789	\N	56.4037127992883	Нижегородская область, Балахнинский район, р.п.Большое Козино, Матросова, 12, библиотека		0101000020E6100000D9CEF753E3DB45402BFC19DEAC334C40
60901	7	68	916	49817	17593	\N	56.412478260687202	"Нижегородская область, Балахнинский район,р.п.Большое Козино, Большешкольная, 64, ДК ""Возрождение"""		0101000020E610000059DDEA39E9DB4540E5284014CC344C40
61418	7	68	916	7288	17701	\N	56.615436000000003	Нижегородская область, Городецкий район, поселок Первомайский, ул. Центральная, д. 4, здание администрации		0101000020E6100000C53A55BE67AE4540FA635A9BC64E4C40
60900	7	68	916	13950	16780	\N	56.439830999999998	Нижегородская область, Балахнинский район, р.п.Малое Козино, Октября, 74, библиотека		0101000020E610000071E5EC9DD1D645402C62D8614C384C40
60898	7	68	916	13792	\N	\N	56.440448000000004	Нижегородская область, Балахнинский район, р.п.Лукино, Победы, 1, ДК им.Горького	Россия, Нижегородская область, Балахнинский район, поселок Лукино	0101000020E6100000B3B6291E17D1454058CB9D9960384C40
60897	7	68	916	13792	17542	\N	56.440448000000004	Нижегородская область, Балахнинский район, р.п.Лукино, Победы, 18, СОШ №18	Россия, Нижегородская область, Балахнинский район, поселок Лукино	0101000020E6100000B3B6291E17D1454058CB9D9960384C40
60909	7	68	916	14384	\N	\N	56.455064999999998	Нижегородская область, Балахнинский район, Коневский сельсовет, д.Конево, Советская, 1, здание администрации	Россия, Нижегородская область, Балахнинский район, село Конево	0101000020E6100000F04DD367079A4540F146E6913F3A4C40
60907	7	68	916	14272	18576	\N	56.530403999999997	Нижегородская область, Балахнинский район, д.Истомино, ул.Генерала Маргелова, СОШ		0101000020E61000008CBAD6DEA7BA454073D53C47E4434C40
60908	7	68	916	14328	\N	\N	56.475509000000002	Нижегородская область, Балахнинский район, Замятинский сельсовет, д.Замятино, Здание администрации		0101000020E6100000DAC70A7E1BB4454012FA997ADD3C4C40
60895	7	68	916	13602	\N	\N	56.472574999999999	"Нижегородская область, Балахнинский район, р.п.Гидроторф, ул.Космонавтов, 4, МБОУ ДОД ""Детская музыкальная школа №1"""	Россия, Нижегородская область, Балахнинский район, поселок Гидроторф	0101000020E610000064CDC82077C545401FF46C567D3C4C40
60893	7	68	916	13602	16934	\N	56.469344880967903	Нижегородская область, Балахнинский район, р.п. Гидроторф, Садовая, 16, ДК им.Димитрова	Россия, Нижегородская область, Балахнинский район, поселок Гидроторф	0101000020E6100000C4CE143AAFC5454043C5387F133C4C40
60896	7	68	916	13602	17539	\N	56.472574999999999	Нижегородская область, Балахнинский район, р.п. Гидроторф, Административная, 14, филиал СОШ №10		0101000020E610000064CDC82077C545401FF46C567D3C4C40
60894	7	68	916	13602	17539	\N	56.472574999999999	Нижегородская область, Балахнинский район, р.п. Гидроторф, Административная, 4, ЦДТ	Россия, Нижегородская область, Балахнинский район, поселок Гидроторф	0101000020E610000064CDC82077C545401FF46C567D3C4C40
60905	7	68	916	14183	\N	\N	56.537253999999997	Нижегородская область, Балахнинский район, д.Большие Могильцы, библиотека		0101000020E6100000118B187618C3454095D233BDC4444C40
60889	7	68	916	40312	17894	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, пр.Дзержинского, 34, С/п СОШ №11		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60885	7	68	916	40312	17735	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, пр.Дзержинского, 2А, С/п СОШ №11		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60882	7	68	916	40312	17662	\N	56.488134069726001	Нижегородская область, Балахнинский район, город Балахна, Энгельса, 70, Городской КСК	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E6100000C6FD47A643CB45406808C72C7B3E4C40
60880	7	68	916	40312	17662	\N	56.488395238003299	Нижегородская область, Балахнинский район, город Балахна, Энгельса, 39. отдел ГЗ и ПБ	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E61000005AF624B039CD4540D44334BA833E4C40
60883	7	68	916	40312	17725	\N	56.488407016501696	"Нижегородская область, Балахнинский район, город Балахна, Синякова, 4, ""ФОК г.Балахна"""	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E6100000E4BCFF8F13CC45409911DE1E843E4C40
60876	7	68	916	40312	17734	\N	56.489422086682801	"Нижегородская область, Балахнинский район, город Балахна, ул.Свердлова, 24,МБУ ""Межшкольный учебн.комбинат"""	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E6100000ADDF4C4C17CC4540B1F84D61A53E4C40
60891	7	68	916	40312	16715	\N	56.488501999999997	"Нижегородская область, Балахнинский район, город Балахна, Олимпийская, 2, ФОК ""Олимпийский"""		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60878	7	68	916	40312	16708	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, ул.Дзержинского, 21, Политехнический колледж	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60890	7	68	916	40312	16774	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, Горького, 33. С/п ЦВР		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60888	7	68	916	40312	16774	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, ул.Горького, 13. СОШ №12		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60877	7	68	916	12841	\N	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, ул.Ульяновой, 82, ГОУ СПО БТТ	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60887	7	68	916	12841	16928	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, пр.Дзержинксого, 36, Городской КСК		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60886	7	68	916	12841	17140	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, пр.Дхержинского, 2А, С/п СОШ №11		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60879	7	68	916	12841	16924	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, пл.Минина, 1, Дом Москвы		0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60881	7	68	916	12841	16910	\N	56.489131247981902	"Нижегородская область, Балахнинский район, город Балахна, ул. ЦКК, 33, МДОУ ""Детский сад № 27"""	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E61000001A506F46CDCB4540DA3A38D89B3E4C40
60884	7	68	916	12841	17136	\N	56.488501999999997	Нижегородская область, Балахнинский район, город Балахна, Первомайская, 1, помещение столовой	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E610000093C49272F7CB4540EA03C93B873E4C40
60910	7	68	916	12841	9755	\N	56.490021563472503	Нижегородская область, Балахнинский район, город Балахна, Волжский рейд, 1, С/п ЦВР	Россия, Нижегородская область, Балахнинский район, Балахна	0101000020E61000009240834D9DCB45400729780AB93E4C40
60899	7	68	916	13890	17152	\N	56.417546000000002	Нижегородская область, Балахнинский район, р.п.Первое Мая, Садовая, 39, МУК ДК 1 Мая		0101000020E61000003317B83CD6D24540AE49B72572354C40
60793	7	68	992	8877	17946	\N	55.38796	Нижегородская область, Арзамасский район, с.Шерстино, ул.Советская, 96 А, Дом культуры		0101000020E610000070B54E5C8EB54540FD135CACA8B14B40
60835	7	68	992	49732	\N	\N	55.2730153460341	Нижегородская область, Арзамасский район, Шатовский сельсовет, Шатовская СОШ	Россия, Нижегородская область, Арзамасский район, село Шатовка	0101000020E6100000EE26F8A6E9D94540A228D027F2A24B40
60832	7	68	992	10680	\N	\N	55.599905999999997	Нижегородская область, Арзамасский район, Чернухинский сельсовет, с. Чернуха, ул.Ленина, 57, Дом культуры	Россия, Нижегородская область, Арзамасский район, село Чернуха	0101000020E6100000D0D4EB1681E145404B5645B8C9CC4B40
42047	7	67	\N	369	49026	\N	58.625874436107502	Кировская область, Муниципальное образование город Киров, Шинников, 30а		0101000020E61000003A3DEFC682D0484057B5A4A31C504D40
60830	7	68	992	10680	\N	\N	55.599905999999997	Нижегородская область, Арзамасский район, Чернухинский сельсовет, с. Чернуха, ул.Ленина, 191, детский сад № 23	Россия, Нижегородская область, Арзамасский район, село Чернуха	0101000020E6100000D0D4EB1681E145404B5645B8C9CC4B40
60831	7	68	992	10680	17694	\N	55.599905999999997	Нижегородская область, Арзамасский район, Чернухинский сельсовет, с. Чернуха, ул.Ленина, 61, здание администрации		0101000020E6100000D0D4EB1681E145404B5645B8C9CC4B40
60829	7	68	992	10623	16828	\N	55.435917000000003	Нижегородская область, Арзамасский район, Абрамовский сельсовет, с.Хватовка, ул.Советская, 31, Дом культуры		0101000020E6100000A0C4E74EB0DF45409E62D520CCB74B40
60820	7	68	992	10161	\N	\N	55.362219000000003	Нижегородская область, Арзамасский район, Кирилловский сельсовет, д.Успенское 1-ое, ул.Центральная, 78, Административное здание	Россия, Нижегородская область, Арзамасский район, село Успенское 1-е	0101000020E61000004E266E15C4124640B37E33315DAE4B40
60828	7	68	992	10589	17463	\N	55.331806999999998	Нижегородская область, Арзамасский район, Слизневский сельсовет, с. Степаново, ул.Центральная, д.63		0101000020E6100000A30392B06FC14540BCCADAA678AA4B40
60824	7	68	992	10362	\N	\N	55.324012000000003	Нижегородская область, Арзамасский район, Слизневский сельсовет, с.Слизнево, Слизневская ООШ		0101000020E6100000081EDFDE35C645407BC1A73979A94B40
60819	7	68	992	10362	\N	\N	55.321720118012003	Нижегородская область, Арзамасский район, Слизневский сельсовет, здание магазина		0101000020E610000017EFC7ED97C545400C3CF71E2EA94B40
60827	7	68	992	10512	16825	\N	55.365740000000002	Нижегородская область, Арзамасский район, Слизневский сельсовет, с.Семеново, ул.Центральная, 132, Дом культуры		0101000020E61000002C64AE0CAAC54540666B7D91D0AE4B40
60822	7	68	992	10262	\N	\N	55.541060999999999	Нижегородская область, Арзамасский район, Балахонихинский сельсовет, с.Селема, ул.Центральная, 28, Сельский клуб	Россия, Нижегородская область, Арзамасский район, село Селема	0101000020E61000000971E5EC9DD145400E12A27C41C54B40
60817	7	68	992	10010	17094	\N	55.657996505602803	Нижегородская область, Арзамасский район, Чернухинский сельсовет, с.Пустынь, ул.Красная, д.44 А, Дом культуры	Россия, Нижегородская область, Арзамасский район, село Пустынь	0101000020E6100000CBA2B08BA2CD4540DDEEE53E39D44B40
60812	7	68	992	9767	17293	\N	55.484279999999998	Нижегородская область, Арзамасский район, Кирилловский сельсовет, с.Протопоповка, ул. Новая, д.3, Административное здание		0101000020E61000003B38D89B18F44540AE0D15E3FCBD4B40
60834	7	68	992	10868	18170	\N	55.622202000000001	Нижегородская область, Арзамасский район, Чернухинский сельсовет, п. Пошатово, ул.Фабричная, 5, сельский клуб		0101000020E61000007573F1B73DDB4540BEC0AC50A4CF4B40
60821	7	68	992	10225	18076	\N	55.3099831325802	Нижегородская область, Арзамасский район, Бебяевский сельсовет, с.Пешелань, ул. Юбилейная, 24, Дом культуры	Россия, Нижегородская область, Арзамасский район, село Пешелань	0101000020E61000009B012EC896F5454072A8DF85ADA74B40
60816	7	68	992	9968	\N	\N	55.303713999999999	Нижегородская область, Арзамасский район, с.Новый Усад, ул.Юбилейная, д.20, Новоусадская ООШ	Россия, Нижегородская область, Арзамасский район, село Новый Усад	0101000020E610000082A8FB00A4E645402EABB019E0A64B40
60823	7	68	992	10308	17485	\N	55.534734	Нижегородская область, Арзамасский район, Балахонихинский сельсовет, с.Никольское, ул.Центральная, 64, Дом культуры		0101000020E6100000F697DD9387CB45409607E92972C44B40
60818	7	68	992	10077	16916	\N	55.642347000000001	Нижегородская область, Арзамасский район, Чернухинский сельсовет, с.Наумовка, ул.Молодежная, 19, Наумовская ООШ		0101000020E6100000BA6B09F9A0BF454084D72E6D38D24B40
60814	7	68	992	9865	17477	\N	55.586308000000002	Нижегородская область, Арзамасский район, Ломовский сельсовет, с.Мотовилово, ул.Лесная, д.1, Административное здание		0101000020E610000057EBC4E578EB45400CB1FA230CCB4B40
60811	7	68	992	9691	17290	\N	55.443491000000002	Нижегородская область, Арзамасский район, Кирилловский сельсовет, с.Морозовка, ул.Советская, 2, ФАП		0101000020E61000007D93A641D1F8454001892650C4B84B40
60785	7	68	992	8525	17628	\N	55.407043999999999	Нижегородская область, Арзамасский район, д.Мерлино, ул.Центральная, 58, сельский клуб		0101000020E6100000FBE8D495CFD045403A048E041AB44B40
60810	7	68	992	9650	\N	\N	55.539737000000002	Нижегородская область, Арзамасский район, п.Ломовка, ул.Зеленая, д.2, Дом культуры	Россия, Нижегородская область, Арзамасский район, село Ломовка	0101000020E6100000E412471E88EA454078B81D1A16C54B40
60807	7	68	992	9506	\N	\N	55.481147999999997	Нижегородская область, Арзамасский район, Балахонихинский сельсовет, д. Лидовка, ФАП с.Лидовка		0101000020E6100000C4211B4817C345409544F64196BD4B40
60797	7	68	992	9077	17449	\N	55.606309000000003	Нижегородская область, Арзамасский район, Ломовский сельсовет, с.Криуша, ул.Центральная, 62, ФАП		0101000020E6100000425DA45016FE45409F2287889BCD4B40
60808	7	68	992	9548	\N	\N	55.397756000000001	Нижегородская область, Арзамасский район, с.Красное, пл. 1 Мая, д. 8, Дом культуры	Россия, Нижегородская область, Арзамасский район, село Красное	0101000020E61000002E3C2F151BDF4540D6E429ABE9B24B40
60788	7	68	992	8683	17934	\N	55.459864000000003	Нижегородская область, Арзамасский район, с.Котиха, ул.Кирова, 1 Б, сельский клуб		0101000020E610000047E9D2BF24BF4540CB4DD4D2DCBA4B40
60806	7	68	992	9456	\N	\N	55.478647389861798	Нижегородская область, Арзамасский район, Балахонихинский сельсовет, с. Костылиха, ФАП с.Костылиха	Россия, Нижегородская область, Арзамасский район, село Костылиха	0101000020E6100000F9F36DC152C545400DAA0D4E44BD4B40
60805	7	68	992	9413	\N	\N	55.517791000000003	Нижегородская область, Арзамасский район, Балахонихинский сельсовет, с. Ковакса, здание Коваксинской СОШ	Россия, Нижегородская область, Арзамасский район, село Ковакса	0101000020E610000060CC96AC8AC04540E294B9F946C24B40
60809	7	68	992	9602	16692	\N	55.408583	Нижегородская область, Арзамасский район, с.Кичанзино, ул. Новая линия, 23, Детский сад		0101000020E6100000F163CC5D4BDC4540CD599F724CB44B40
60786	7	68	992	8590	17929	\N	55.438343000000003	Нижегородская область, Арзамасский район, с.Каменка, пл.Заводская, 14, Дом культуры		0101000020E6100000BBB88D06F0DA45401CB7989F1BB84B40
60804	7	68	992	9382	17657	\N	55.209009999999999	Нижегородская область, Арзамасский район, Бебяевский сельсовет, с.Казаково, ул.Садовая, 17, Дом культуры		0101000020E61000006FD575A8A6E64540BB44F5D6C09A4B40
60783	7	68	992	8453	17433	\N	55.404851992368798	Нижегородская область, Арзамасский район, д.Забелино, ул.Большая площадь, 12А, сельский клуб	Россия, Нижегородская область, Арзамасский район, село Забелино	0101000020E61000007B30293E3ED945402FDCB930D2B34B40
60801	7	68	992	9027	\N	\N	55.379593	Нижегородская область, Арзамасский район, р.п. Выездное, ул.Советская, д.76а	Россия, Нижегородская область, Арзамасский район, поселок Выездное	0101000020E610000015527E52EDE345403065E08096B04B40
60799	7	68	992	9027	\N	\N	55.379593	Нижегородская область, Арзамасский район, р.п. Выездное, детский сад № 34	Россия, Нижегородская область, Арзамасский район, поселок Выездное	0101000020E610000015527E52EDE345403065E08096B04B40
60796	7	68	992	9027	17631	\N	55.379593	Нижегородская область, Арзамасский район, рабочий поселок Выездное, ул. 5 линия, д.14а		0101000020E610000015527E52EDE345403065E08096B04B40
60802	7	68	992	9027	17965	\N	55.379593	Нижегородская область, Арзамасский район, р.п. Выездное, ул.Сельхозтехника, 20, ООШ Сельхозтехника		0101000020E610000015527E52EDE345403065E08096B04B40
60800	7	68	992	9027	17262	\N	55.381361577550898	Нижегородская область, Арзамасский район, р.п. Выездное, ул. Куликова, 1, Выездновская СОШ	Россия, Нижегородская область, Арзамасский район, поселок Выездное	0101000020E6100000D8F2CAF5B6E34540F5F75278D0B04B40
60798	7	68	992	9027	17639	\N	55.3737191863992	Нижегородская область, Арзамасский район, р.п. Выездное, ул. 7 Линия, д.7, Вечерняя СОШ	Россия, Нижегородская область, Арзамасский район, поселок Выездное	0101000020E6100000992D5915E1E4454069723106D6AF4B40
60815	7	68	992	9906	\N	\N	55.603486091362399	Нижегородская область, Арзамасский район, Ломовский сельсовет, с. Вторусское, ФАП с.Вторусское	Россия, Нижегородская область, Арзамасский район, село Вторусское	0101000020E6100000BFB5132521EF454003CC7C073FCD4B40
60795	7	68	992	8984	17045	\N	55.585799999999999	Нижегородская область, Арзамасский район, Ломовский сельсовет, с. Волчиха, ул.К.Маркса, д.15		0101000020E610000097E315889EF4454097FF907EFBCA4B40
60794	7	68	992	8930	17044	\N	55.401110000000003	Нижегородская область, Арзамасский район, Большетумановский сельсовет, с.Водоватово, пл.Кирова, 22		0101000020E610000022AAF06778C945409E0C8E9257B34B40
60825	7	68	992	10411	17634	\N	55.323818000000003	Нижегородская область, Арзамасский район, Слизневский сельсовет, с.Ветошкино, ул.Центральная, 98, Дом культуры	Россия, Нижегородская область, Арзамасский район, село Ветошкино	0101000020E6100000B438639813BE454096ED43DE72A94B40
60784	7	68	992	8460	17434	\N	55.375909999999998	Нижегородская область, Арзамасский район,с.Веригино, ул.К.Маркса, д.15		0101000020E610000002D53F8864D44540A31EA2D11DB04B40
60803	7	68	992	9319	\N	\N	55.344484999999999	Нижегородская область, Арзамасский район, с.Васильев Враг, столовая СПК им.Чкалова		0101000020E6100000CDC8207711DA4540357BA01518AC4B40
60826	7	68	992	10485	\N	\N	55.342939000000001	Нижегородская область, Арзамасский район, Слизневский сельсовет, с. Булдаково, ул.Центральная, д. 96, кв.2	Россия, Нижегородская область, Арзамасский район, село Булдаково	0101000020E610000090F8156BB8BE4540F0C2D66CE5AB4B40
60792	7	68	992	8850	\N	\N	55.385601999999999	Нижегородская область, Арзамасский район, с.Большое Туманово, пл.Победы, 30, Административное здание	Россия, Нижегородская область, Арзамасский район, село Большое Туманово	0101000020E610000048533D997FBE4540D7A205685BB14B40
60790	7	68	992	49709	16926	\N	55.348178434081099	Нижегородская область, Арзамасский район, д.Березовка, ул.Школьная, 2, Дом культуры		0101000020E6100000A7AFE76B96ED4540E597C11891AC4B40
60836	7	68	992	49803	\N	\N	55.2647983610157	Нижегородская область, Арзамасский район, Шатовский сельсовет, ФАП с.Беговатово	Россия, Нижегородская область, Арзамасский район, село Беговатово	0101000020E610000045D95BCAF9CC4540EA059FE6E4A14B40
60789	7	68	992	8713	\N	\N	55.309221999999998	Нижегородская область, Арзамасский район, д.Бебяево, д. 34 А, Дом культуры		0101000020E61000008CD9925511F84540139A249694A74B40
60787	7	68	992	8612	17629	\N	55.475883000000003	Нижегородская область, Арзамасский район, п.Балахониха, ул.Советская, д.27в (административное здание)		0101000020E610000091813CBB7CAF454077DCF0BBE9BC4B40
60782	7	68	992	8401	18057	\N	55.40869	Нижегородская область, Арзамасский район, Абрамовский сельсовет, с. Абрамово, пл.Победы, д.6, Административное здание		0101000020E61000004F948444DAD44540E31934F44FB44B40
60781	7	68	907	8318	17019	\N	55.137070000000001	Нижегородская область, Ардатовский район, с.Чуварлей-Майдан, Советская, 39, здание сельской администрации		0101000020E610000074EACA6779724540A1A17F828B914B40
42065	7	67	\N	369	49013	\N	58.614896999999999	Кировская область, Муниципальное образование город Киров, Лепсе, 31		0101000020E61000001C42959A3DD048404AB4E4F1B44E4D40
60780	7	68	907	8307	17241	\N	55.178640000000001	Нижегородская область, Ардатовский район, с. Хрипуново, Центральная, 23, здание сельской администрации		0101000020E61000008A5759DB14994540F4E0EEACDD964B40
60774	7	68	907	7978	\N	\N	55.359251	Нижегородская область, Ардатовский район, с. Туркуши, Школьная, 1, школа	Россия, Нижегородская область, Ардатовский район, село Туркуши	0101000020E6100000C3D4963AC88145401407D0EFFBAD4B40
60778	7	68	907	8171	16674	\N	55.297313000000003	Нижегородская область, Ардатовский район, с. Стексово, Садовая, 27А, дом культуры		0101000020E61000004FB0FF3A37B545407CD6355A0EA64B40
60773	7	68	907	7422	\N	\N	55.385091000000003	Нижегородская область, Ардатовский район, с. Саконы, Кооперативная, 12А, сельский дом культуры	Россия, Нижегородская область, Ардатовский район, село Саконы	0101000020E61000000B9755D80C924540F27D71A94AB14B40
60762	7	68	907	7422	\N	\N	55.385091000000003	Нижегородская область, Ардатовский район, п. Саконы, Северная, 18, школа	Россия, Нижегородская область, Ардатовский район, село Саконы	0101000020E61000000B9755D80C924540F27D71A94AB14B40
60772	7	68	907	7870	17869	\N	55.318024000000001	Нижегородская область, Ардатовский район, с. Размазлей, Центральная, 7, здание Дома культуры	Россия, Нижегородская область, Ардатовский район, село Размазлей	0101000020E61000007F4B00FE298F4540EBABAB02B5A84B40
60756	7	68	907	7123	17620	\N	55.260792000000002	Нижегородская область, Ардатовский район, с. Поляна, Школьная, 1/02, сельский клуб		0101000020E61000003FC4060B278F45407B87DBA161A14B40
60771	7	68	907	7853	17076	\N	55.181348999999997	Нижегородская область, Ардатовский район, с. Надежино, Гусева, 33, здание Дома культуры		0101000020E61000004415FE0C6FA44540C614AC7136974B40
60760	7	68	907	7270	\N	\N	55.465667000000003	Нижегородская область, Ардатовский район, поселок Мухтолово, Южная, 35А, школа №2	Россия, Нижегородская область, Ардатовский район, поселок Мухтолово	0101000020E6100000EBFD463B6E984540C9E9EBF99ABB4B40
60759	7	68	907	7270	17251	\N	55.465667000000003	Нижегородская область, Ардатовский район, поселок Мухтолово, Школьная, 75А, школа №1		0101000020E6100000EBFD463B6E984540C9E9EBF99ABB4B40
60758	7	68	907	7270	16838	\N	55.465667000000003	"Нижегородская область, Ардатовский район, поселок Мухтолово, ул.Почтовая, 25, МОУ ДОД ""Мухтоловская детская школа искусств"""		0101000020E6100000EBFD463B6E984540C9E9EBF99ABB4B40
60770	7	68	907	7798	17048	\N	55.133986999999998	Нижегородская область, Ардатовский район, с. Михеевка, Советская, 51, здание Дома культуры		0101000020E61000008F19A88C7F914540698B6B7C26914B40
60769	7	68	907	7727	17268	\N	55.379286	Нижегородская область, Ардатовский район, Личадеевский сельсовет, с. Личадеево, Центральная, 45А, дом культуры		0101000020E6100000AC8DB1135EA8454053EA92718CB04B40
60768	7	68	907	7704	17051	\N	55.373787	Нижегородская область, Ардатовский район, с. Липовка, Центральная, 25А, сельский клуб		0101000020E61000000F0EF626869C4540C1559E40D8AF4B40
60755	7	68	907	7115	17208	\N	55.291403000000003	Нижегородская область, Ардатовский район, с. Леметь, Новая, 1/1, бывшая школа	Россия, Нижегородская область, Ардатовский район, село Леметь	0101000020E6100000541D7233DC8A4540687A89B14CA54B40
60777	7	68	907	8143	\N	\N	55.250509999999998	Нижегородская область, Ардатовский район, с. Кузятово, Новая, 13, школа	Россия, Нижегородская область, Ардатовский район, село Кузятово	0101000020E61000001BD82AC1E2A4454015A930B610A04B40
60766	7	68	907	7596	\N	\N	55.210382000000003	Нижегородская область, Ардатовский район, с. Кужендеево, Центральная, 1А, здание администрации с/с	Россия, Нижегородская область, Ардатовский район, село Кужендеево	0101000020E610000098BED7101C8B454063D520CCED9A4B40
60776	7	68	907	8083	17010	\N	55.267583999999999	Нижегородская область, Ардатовский район, с. Круглово, Школьная, 11, администрация ООО Металлург		0101000020E6100000E9482EFF219B45406877483140A24B40
60765	7	68	907	7579	\N	\N	55.280087000000002	Нижегородская область, Ардатовский район, с. Котовка, Молодежная, 23А, здание сельского Дома культуры	Россия, Нижегородская область, Ардатовский район, село Котовка	0101000020E6100000C79C67EC4B80454073840CE4D9A34B40
60764	7	68	907	7542	17949	\N	55.135998999999998	Нижегородская область, Ардатовский район, д. Каркалей, 1 Мая, 34Г, здание администрации с/с		0101000020E6100000BE13B35E0C674540F4A44C6A68914B40
60775	7	68	907	8003	17075	\N	55.238331000000002	Нижегородская область, Ардатовский район, п. Идеал, Лесная, 1А, дом культуры		0101000020E61000000C03965CC5BE4540BE4F55A1819E4B40
60763	7	68	907	7483	17653	\N	55.184392000000003	Нижегородская область, Ардатовский район, с. Журелейка, Молодежная, 31, сельский дом культуры		0101000020E6100000E275FD82DD82454070D234289A974B40
60767	7	68	907	7662	16745	\N	55.360694000000002	Нижегородская область, Ардатовский район, с. Голяткино, Школьная, 2, школа		0101000020E6100000AE8383BD89A3454085EE92382BAE4B40
60761	7	68	907	7413	16841	\N	55.499626999999997	Нижегородская область, Ардатовский район, п. Венец, Северная, 13, школа		0101000020E6100000761A69A9BC7D45406B990CC7F3BF4B40
60779	7	68	907	8244	17430	\N	55.154851000000001	Нижегородская область, Ардатовский район, с. Атемасово, Школьная, 2, школа		0101000020E6100000910A630B41A045405F605628D2934B40
60754	7	68	907	36370	17596	\N	55.240064554717499	Нижегородская область, Ардатовский район, поселок Ардатов, Суслова, 7, здание ЗАГСа	Россия, Нижегородская область, Ардатовский район, Ардатов	0101000020E6100000F12DAC1BEF8C454006F52D73BA9E4B40
60748	7	68	907	36370	17398	\N	55.248808793262903	Нижегородская область, Ардатовский район, поселок Ардатов, Свердлова, 42, школа №1	Россия, Нижегородская область, Ардатовский район, Ардатов	0101000020E61000000282397AFC8A4540A9F92AF9D89F4B40
60752	7	68	907	36370	17206	\N	55.226836443745299	"Нижегородская область, Ардатовский район, поселок Ардатов, Зуева, 70, ООО ""УК Ардатов"""	Россия, Нижегородская область, Ардатовский район, Ардатов	0101000020E610000089B3226AA28B454019C748F6089D4B40
60750	7	68	907	36370	17206	\N	54.765720999999999	Нижегородская область, Ардатовский район, поселок Ардатов, Зуева, 19, Детская школа искусств		0101000020E6100000E76F422102224740226E4E2503624B40
60751	7	68	907	36370	16979	\N	54.765720999999999	Нижегородская область, Ардатовский район, поселок Ардатов, 30 лет ВЛКСМ, 35, дом культуры		0101000020E6100000E76F422102224740226E4E2503624B40
60749	7	68	907	49761	17210	\N	55.239467130304597	Нижегородская область, Ардатовский район, поселок Ардатов, Кооперативная, 41, здание бывшего лесхоза		0101000020E6100000CE3637A6278C454051BCCADAA69E4B40
60753	7	68	907	49761	17214	\N	55.232094322360702	Нижегородская область, Ардатовский район, поселок Ардатов, Зуева, 57, школа №2	Россия, Нижегородская область, Ардатовский район, Ардатов	0101000020E610000023A30392B08B454085CC9541B59D4B40
62212	7	68	6974	49751	17353	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул.  Шмидта, д. 38	Россия, Нижегородская область, Павлово	0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62206	7	68	6974	49751	17528	\N	55.964858952236597	Нижегородская область, Павловский район, г. Павлово, ул. Чапаева, д. 41	Россия, Нижегородская область, Павлово	0101000020E6100000FEB5BC72BD8945402920ED7F80FB4B40
62204	7	68	6974	49751	17343	\N	55.971935000000002	Нижегородская область, Павловский район, г. Павлово, ул. Суворова, д. 1		0101000020E6100000AA2B9FE5798A45403C6BB75D68FC4B40
62218	7	68	6974	49751	19399	\N	55.945176777016499	Нижегородская область, Павловский район, г. Павлов, ул. Высокая, д. 1	Россия, Нижегородская область, Павлово	0101000020E610000039D1AE42CA8B454038F7578FFBF84B40
61387	7	68	6982	49743	17096	\N	56.639783000000001	Нижегородская область, Городецкий район, город Городец, ул. Шишкина, д. 9, школа № 12		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61389	7	68	6982	49743	17099	\N	56.664734547649502	"Нижегородская область, Городецкий район, город Городец, ул. Фурманова, д. 10а, Досуговый центр ""Спутник"""		0101000020E61000007D5D86FF74BB4540D7C0560916554C40
61391	7	68	6982	49743	17685	\N	56.639783000000001	Нижегородская область, Городецкий район, город Городец, ул. Краснофлотская, д. 12, школа № 5		0101000020E6100000122F4FE78ABC4540B5C4CA68E4514C40
61390	7	68	6982	49743	17328	\N	56.661866155645598	Нижегородская область, Городецкий район, город Городец, ул. Зафабричная, д. 6, Педагогический колледж	Россия, Нижегородская область, Городец	0101000020E61000006798DA5207BB4540CC2A6C06B8544C40
42805	7	67	\N	55970	48753	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Свободы, 27А		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42808	7	67	\N	55970	49109	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Ленина, 52		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42601	7	67	\N	6838	48729	\N	58.720103000000002	Кировская область, город Слободской, проспект Гагарина, 25		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42600	7	67	\N	6838	48729	\N	58.7088191773245	Кировская область, город Слободской, проспект Гагарина, 10	Россия, Кировская область, Слободской	0101000020E610000061A92EE06518494047E4BB94BA5A4D40
42590	7	67	\N	6838	48809	\N	58.720103000000002	Кировская область, город Слободской, Школьная, 3		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42597	7	67	\N	6838	48798	\N	58.720103000000002	Кировская область, город Слободской, Совесткая, 100		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42592	7	67	\N	6838	48798	\N	58.720103000000002	Кировская область, город Слободской, Советская, 91		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42591	7	67	\N	6838	48798	\N	58.720103000000002	Кировская область, город Слободской, Советская, 69		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42588	7	67	\N	6838	48798	\N	58.720103000000002	Кировская область, город Слободской, Советская, 14		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42603	7	67	\N	6838	48730	\N	58.720103000000002	Кировская область, город Слободской, Слободская, 90		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42602	7	67	\N	6838	48730	\N	58.720103000000002	Кировская область, город Слободской, Слободская, 53		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42589	7	67	\N	6838	48807	\N	58.720103000000002	Кировская область, город Слободской, Первомайская, 1		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42593	7	67	\N	6838	48728	\N	58.720103000000002	Кировская область, город Слободской, Ленина, 69		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42599	7	67	\N	6838	48745	\N	58.720103000000002	Кировская область, город Слободской, Корто, 12		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42598	7	67	\N	6838	48934	\N	58.720103000000002	Кировская область, город Слободской, Кирова, 27		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42594	7	67	\N	6838	48933	\N	58.731789367891899	Кировская область, город Слободской, Железнодорожная, 11а	Россия, Кировская область, Слободской	0101000020E6100000E02EFB75A715494049490F43AB5D4D40
42596	7	67	\N	6838	48878	\N	58.720103000000002	Кировская область, город Слободской, Грина, 43		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42495	7	67	\N	6838	48721	\N	58.720103000000002	Кировская область, город Слободской, Гоголя, 97		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42298	7	67	\N	6838	48781	\N	58.720103000000002	Кировская область, город Слободской, Вятская, 40		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42595	7	67	\N	6838	48935	\N	58.720103000000002	Кировская область, город Слободской, Ленина, 77		0101000020E61000005D6E30D4611949403160C9552C5C4D40
42158	7	67	\N	31734	49084	\N	58.603543999999999	Кировская область, Муниципальное образование город Кирово-Чепецк, Сосновая, 11		0101000020E61000007F15E0BBCDE5484038D906EE404D4D40
42472	7	67	\N	55978	48802	\N	58.540151000000002	Кировская область, Орловский район, г.Орлов, В.Сокованова, 6		0101000020E6100000FF976BD1027248406BF3FFAA23454D40
42395	7	67	\N	55977	48792	\N	58.669951914707497	Кировская область, Омутнинский район, г.Омутнинск, Свободы, 35	Россия, Кировская область, Омутнинский район, Омутнинск	0101000020E6100000B6BC72BD6D164A40E5F1B4FCC0554D40
42398	7	67	\N	55977	49095	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Садовая, 51		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42415	7	67	\N	55977	49488	\N	58.672848106087798	Кировская область, Омутнинский район, дер. Осокина, Пригородная, 11	Россия, Кировская область, Омутнинский район, Омутнинск	0101000020E6100000F33AE2900D104A40EA961DE21F564D40
42378	7	67	\N	55977	48949	\N	58.6654805812151	Кировская область, Омутнинский район, г.Омутнинск, Комсомольская, 38	Россия, Кировская область, Омутнинский район, Омутнинск	0101000020E6100000F2D3B837BF174A40008E3D7B2E554D40
42326	7	67	\N	55977	48788	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Воровского, 13		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42314	7	67	\N	55983	48871	\N	59.393659159202102	Кировская область, Мурашинский муниципальный район, г.Мураши, Пионерская (МОКУ ДДТ(Дом детского творчества)), 5	Россия, Кировская область, Мурашинский район, Мураши	0101000020E61000009D137B681F7D48405663096B63B24D40
42315	7	67	\N	55983	48865	\N	59.397948924426103	Кировская область, Мурашинский муниципальный район, г. Мураши, Кирова  (МУК ЦКД «Феникс»(бывший ДкК ж/д), 23	Россия, Кировская область, Мурашинский район, Мураши	0101000020E61000008BE07F2BD97B4840EA3C2AFEEFB24D40
42311	7	67	\N	55976	49234	\N	56.519644999999997	Кировская область , город Малмыж, Октябрьская, 6		0101000020E61000004ACFF41263594940D44334BA83424C40
42308	7	67	\N	55976	48786	\N	56.519644999999997	Кировская область , город Малмыж, К-Маркса, 61		0101000020E61000004ACFF41263594940D44334BA83424C40
42272	7	67	\N	55975	48838	\N	60.629410790599998	Кировская область, Муниципальное образование Лузский район, город Луза, Рабочая, 21	Россия, Кировская область, Лузский район, Луза	0101000020E6100000C9E6AA798EA047400F5F268A90504E40
42271	7	67	\N	55975	48782	\N	60.622920000000001	Кировская область, Муниципальное образование Лузский район, город Луза, Калинина, 9а		0101000020E61000004A287D21E4A047401D03B2D7BB4F4E40
42194	7	67	\N	1207	48832	\N	58.311658000000001	Кировская область, город Котельнич, Школьная, 2		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42204	7	67	\N	1207	48834	\N	58.311658000000001	Кировская область, город Котельнич, Урицкого, 19		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42208	7	67	\N	1207	48767	\N	58.311658000000001	Кировская область, город Котельнич, Советская, 130		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42203	7	67	\N	1207	48767	\N	58.311658000000001	Кировская область, город Котельнич, Советская, 46		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42124	7	67	\N	1207	48767	\N	58.311658000000001	Кировская область, город Котельнич, Советская, 170	Россия, Кировская область, Котельнич	0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42035	7	67	\N	1207	48767	\N	58.311387038773098	Кировская область, город Котельнич, Советская, 153	Россия, Кировская область, Котельнич	0101000020E61000009D121093702D484025B37A87DB274D40
41966	7	67	\N	1207	48765	\N	58.311658000000001	Кировская область, город Котельнич, Победы, 40		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42207	7	67	\N	1207	48778	\N	58.311658000000001	Кировская область, город Котельнич, Октябрьская, 109		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42205	7	67	\N	1207	48778	\N	58.311658000000001	Кировская область, город Котельнич, Октябрьская, 91		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42210	7	67	\N	1207	48859	\N	58.311658000000001	Кировская область, город Котельнич, Мелиораторов, 2А		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
41927	7	67	\N	1207	49191	\N	58.311658000000001	Кировская область, город Котельнич, Заречная, 1А		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
42209	7	67	\N	1207	48946	\N	58.311658000000001	Кировская область, город Котельнич, Дениса Белых, 12		0101000020E610000063D2DF4BE1294840B5C4CA68E4274D40
41850	7	67	\N	55981	48829	\N	58.556043258547398	Кировская область, Кирово-Чепецкий район, г. Кирово-Чепецк, Мира пр., д. 52	Россия, Кировская область, Кирово-Чепецк городской округ	0101000020E6100000C5C72764E7034940BA15C26A2C474D40
41852	7	67	\N	55981	48827	\N	58.550454000000002	Кировская область, Кирово-Чепецкий район, г. Кирово-Чепецк, Фестивальная ул., д. 14/2		0101000020E6100000FE28EACC3D084940E8F9D34675464D40
42151	7	67	\N	55981	48831	\N	58.550454000000002	Кировская область, Кирово-Чепецкий район, г. Кирово-Чепецк, Революции ул., д. 20		0101000020E6100000FE28EACC3D084940E8F9D34675464D40
42176	7	67	\N	55981	49678	\N	58.550454000000002	Кировская область, Кирово-Чепецкий район, г. Кирово-Чепецк, Островского ул., д. 6	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E6100000FE28EACC3D084940E8F9D34675464D40
41849	7	67	\N	55981	48911	\N	58.550454000000002	Кировская область, Кирово-Чепецкий район, г. Кирово-Чепецк, Лермонтова проезд , д. 1		0101000020E6100000FE28EACC3D084940E8F9D34675464D40
42172	7	67	\N	55981	49374	\N	58.547851790817397	Кировская область, Кирово-Чепецкий район, г. Кирово-Чепецк,  Комсомольская ул., д. 6а	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E6100000D4449F8F320849402B86AB0320464D40
42167	7	67	\N	55981	77489	\N	58.549915632631198	Кировская область, Муниципальное образование город Кирово-Чепецк, Ком. Утробина, 5		0101000020E6100000FB58C16F4308494009C6C1A563464D40
42165	7	67	\N	55981	77531	\N	58.539408590980898	Кировская область, Муниципальное образование город Кирово-Чепецк, А.Некрасвоа, 21	Россия, Кировская область, Кирово-Чепецк городской округ	0101000020E61000004563EDEF6C0549408315A75A0B454D40
42162	7	67	\N	55981	49072	\N	58.532390479951403	Кировская область, Муниципальное образование город Кирово-Чепецк, 60 лет Октября, 8А	Россия, Кировская область, Кирово-Чепецк городской округ	0101000020E61000008F6E844545FC4840D55B035B25444D40
42061	7	67	\N	369	6977	\N	58.610069000000003	Кировская область, Муниципальное образование город Киров, Физкультурников, 15	Россия, Кировская область, Киров, улица Физкультурников, 15	0101000020E610000009FCE1E7BFCF4840D7A6B1BD164E4D40
41674	7	67	\N	369	2348	\N	58.601959000000001	Кировская область, Афанасьевский район, д.Ичетовкины, Солнечная, 5	Россия, Кировская область, Киров, улица Солнечная, 5	0101000020E6100000B45A608F89D04840354415FE0C4D4D40
42030	7	67	\N	369	16124	\N	58.641846000000001	Кировская область, Муниципальное образование город Киров, Свердлова, 21	Россия, Кировская область, Киров, Октябрьский район, улица Свердлова, 21	0101000020E61000008E5BCCCF0DCF4840C2887D0228524D40
42091	7	67	\N	369	15338	\N	58.611151999999997	Кировская область, город Киров, Первомайский район, Розы Люксембург, 40	Россия, Кировская область, Киров, Первомайский район, улица Розы Люксембург, 40	0101000020E6100000EB8F300C58D6484047718E3A3A4E4D40
41944	7	67	\N	369	5824	\N	58.587505999999998	Кировская область, Муниципальное образование город Киров, Риммы Юровской, 11	Россия, Кировская область, Киров, улица Риммы Юровской, 11	0101000020E6100000583B8A73D4CB4840151A8865334B4D40
42089	7	67	\N	369	15562	\N	58.615014000000002	Кировская область, город Киров, Первомайский район, Профсюзная, 4/9	Россия, Кировская область, Киров, Первомайский район, улица Профсоюзная, 4	0101000020E6100000E46723D74DD74840844A5CC7B84E4D40
42015	7	67	\N	369	16111	\N	58.50759	Кировская область, Нововятский район города Кирова, г.Киров, Орджоникидзе ул., 13	Россия, Кировская область, Киров, Нововятский район, улица Орджоникидзе, 13	0101000020E610000026A8E15B58D9484069E388B5F8404D40
42028	7	67	\N	369	6662	\N	58.639826999999997	Кировская область, Муниципальное образование город Киров, Олега Кошевого, 14	Россия, Кировская область, Киров, улица Олега Кошевого, 14	0101000020E61000003333333333CF4840840CE4D9E5514D40
42075	7	67	\N	369	7127	\N	58.609226	Кировская область, Муниципальное образование город Киров, Менделеева, 1	Россия, Кировская область, Киров, улица Менделеева, 1	0101000020E61000000514EAE923CC4840BBEF181EFB4D4D40
42070	7	67	\N	369	7056	\N	58.607027000000002	Кировская область, Муниципальное образование город Киров, Ломоносова, 29б	Россия, Кировская область, Киров, улица Ломоносова, 29б	0101000020E6100000A33CF372D8CD4840FE648C0FB34D4D40
42149	7	67	\N	369	1164	\N	58.5007304986161	Кировская область, Муниципальное образование город Кирово-Чепецк, проезд Лермонтова, 1	Россия, Кировская область, Киров, улица Лермонтова, 1	0101000020E61000002385B2F0F5DB48402310AFEB17404D40
42159	7	67	\N	369	15362	\N	58.614924999999999	Кировская область, Муниципальное образование город Кирово-Чепецк, Ленина, 6/2	Россия, Кировская область, Киров, Первомайский район, улица Ленина, 6/6	0101000020E61000007920B24813D74840143FC6DCB54E4D40
42101	7	67	\N	369	3636	\N	58.598184000000003	Кировская область, город Киров, Первомайский район, Карла Маркса, 88	Россия, Кировская область, Киров, улица Карла Маркса, 88/44	0101000020E61000005F268A90BAD54840C87E164B914C4D40
41973	7	67	\N	369	15717	\N	58.587890000000002	Кировская область, Муниципальное образование город Киров, Калинина, 53	Россия, Кировская область, Киров, Ленинский район, улица Калинина, 53	0101000020E6100000E44BA8E0F0D048409ED2C1FA3F4B4D40
42100	7	67	\N	369	5810	\N	58.601832000000002	Кировская область, город Киров, Первомайский район, Дрелевского, 12а	Россия, Кировская область, Киров, улица Дрелевского, 12а	0101000020E610000088BCE5EAC7D64840D8D7BAD4084D4D40
41943	7	67	\N	369	5810	\N	58.601481	Кировская область, Муниципальное образование город Киров, Дрелевского, 34	Россия, Кировская область, Киров, улица Дрелевского, 34/73	0101000020E61000004225AE635CD548402B155454FD4C4D40
41981	7	67	\N	369	6221	\N	58.576363999999998	Кировская область, Муниципальное образование город Киров, слобода Петелины, 19	Россия, Кировская область, Киров, слобода Петелины, 19	0101000020E610000006F6984869CE4840BE4BA94BC6494D40
41997	7	67	\N	369	5691	\N	58.593921999999999	Кировская область, Муниципальное образование город Киров, Строителей проспект, 21	Россия, Кировская область, Киров, проспект Строителей, 21	0101000020E6100000E59B6D6E4CCB4840FD2FD7A2054C4D40
41941	7	67	\N	369	5691	\N	58.594794	Кировская область, Муниципальное образование город Киров, проспект Строителей, 44	Россия, Кировская область, Киров, проспект Строителей, 44	0101000020E61000000FB9196EC0CB4840B3EDB435224C4D40
41989	7	67	\N	369	6293	\N	58.596561999999999	Кировская область, Муниципальное образование город Киров, площадь Маршала Конева	Россия, Кировская область, Киров, площадь Маршала Конева	0101000020E6100000D828EB3713CD4840A704C4245C4C4D40
42024	7	67	\N	369	48969	\N	58.490403961780103	Кировская область, город Киров, Нововятский район, мкр Радужный, пер. Школьный, 3	Россия, Кировская область, Киров, Нововятский район, переулок Школьный	0101000020E6100000C3499A3FA6DB4840EEE9EA8EC53E4D40
42023	7	67	\N	369	16231	\N	58.490332000000002	Кировская область, город Киров, Нововятский район, мкр. Радужный, пер.Школьный, 4	Россия, Кировская область, Киров, Нововятский район, переулок Школьный, 4	0101000020E610000000C79E3D97DB48405517F032C33E4D40
42053	7	67	\N	369	49075	\N	58.604725000000002	Кировская область, Муниципальное образование город Киров, Энгельса, 74		0101000020E6100000B56B425A63D448406C09F9A0674D4D40
42112	7	67	\N	369	49035	\N	58.611643999999998	Кировская область, город Киров, Первомайский район, Школьная, 1		0101000020E61000009813B4C9E1DF4840B665C0594A4E4D40
42503	7	67	\N	369	49242	\N	58.535471999999999	Кировская область, Муниципальное образование Подосиновский район, Утмановское сельское поселение, Центральная, 20		0101000020E610000083DF8618AFD548403CF6B3588A444D40
41954	7	67	\N	369	49025	\N	58.570095000000002	Кировская область, Муниципальное образование город Киров, Харьковская, 6		0101000020E61000008B389D64ABD348407B4E7ADFF8484D40
42157	7	67	\N	369	48953	\N	58.561157999999999	Кировская область, Муниципальное образование город Кирово-Чепецк, Фестивальная, 14/2		0101000020E6100000ECA17DACE0D34840C3F17C06D4474D40
42040	7	67	\N	369	48988	\N	58.634051999999997	Кировская область, Муниципальное образование город Киров, Уральская, 9		0101000020E61000000D33349E08D0484050FBAD9D28514D40
42039	7	67	\N	369	48988	\N	58.634422000000001	Кировская область, город Киров, Октябрьский район, Уральская, 7		0101000020E61000007C7E18213CD0484074EE76BD34514D40
42009	7	67	\N	369	49100	\N	58.525566941378798	Кировская область, Нововятский район города Кирова, г.Киров, Сошени сл., Трудовая, 19	Россия, Кировская область, Киров, слобода Сошени, улица Трудовая, 19	0101000020E6100000D1B2EE1F0BD74840AD6D8AC745434D40
42094	7	67	\N	369	49029	\N	58.608531999999997	Кировская область, город Киров, Первомайский район, Труда, 57		0101000020E6100000A2B77878CFD54840E4486760E44D4D40
42051	7	67	\N	369	49029	\N	58.608921000000002	Кировская область, Муниципальное образование город Киров, Труда, 67а		0101000020E6100000302FC03E3AD548407F6C921FF14D4D40
42017	7	67	\N	369	49057	\N	58.505178999999998	Кировская область, город Киров, Нововятский район, ул.Тренера Пушкарева, 2		0101000020E610000068AED3484BDB484020D099B4A9404D40
41977	7	67	\N	369	49044	\N	58.579611	Кировская область, Муниципальное образование город Киров, Сурикова, 44		0101000020E61000002E573F36C9D1484070B378B1304A4D40
41968	7	67	\N	369	49044	\N	58.584757000000003	Кировская область, Муниципальное образование город Киров, Сурикова, 21		0101000020E61000008542041C42D14840B58D3F51D94A4D40
42064	7	67	\N	369	6989	\N	58.604444000000001	Кировская область, Муниципальное образование город Киров, Студенческий проезд, 11а		0101000020E6100000A532C51C04CF4840B821C66B5E4D4D40
42063	7	67	\N	369	6989	\N	58.604477000000003	Кировская область, Муниципальное образование город Киров, Студенческий проезд, 11	Россия, Кировская область, Киров, Студенческий проезд, 11	0101000020E6100000A438471D1DCF4840941799805F4D4D40
42062	7	67	\N	369	6989	\N	58.605114	Кировская область, Муниципальное образование город Киров, Студенческий проезд, 9	Россия, Кировская область, Киров, Студенческий проезд, 9	0101000020E6100000FD8348861CCF4840062D2460744D4D40
41995	7	67	\N	369	49020	\N	58.594794	Кировская область, Муниципальное образование город Киров, Строителей проспект, 44		0101000020E61000000FB9196EC0CB4840B3EDB435224C4D40
42166	7	67	\N	369	48973	\N	58.6055455843101	Кировская область, Муниципальное образование город Кирово-Чепецк, Сосновая, 24/2	Россия, Кировская область, Киров, деревня Порошино, улица Сосновая	0101000020E6100000865968E734E548409F1C0588824D4D40
42161	7	67	\N	369	48980	\N	58.605898329727403	Кировская область, Муниципальное образование город Кирово-Чепецк, Сосновая, 20	Россия, Кировская область, Киров, деревня Порошино, улица Сосновая	0101000020E6100000A35BAFE941E548401D5BCF108E4D4D40
42164	7	67	\N	369	49103	\N	58.602231000000003	Кировская область, Муниципальное образование город Кирово-Чепецк, Сосновая, 1		0101000020E610000010CAFB389AE5484096D1C8E7154D4D40
42066	7	67	\N	369	48997	\N	58.616041000000003	Кировская область, Муниципальное образование город Киров, Сормовская, 38		0101000020E61000004F745DF8C1CF484061FF756EDA4E4D40
41991	7	67	\N	369	49049	\N	58.592421000000002	Кировская область, Муниципальное образование город Киров, Солнечная, 21		0101000020E6100000828DEBDFF5CD4840583B8A73D44B4D40
42014	7	67	\N	369	15632	\N	58.512818000000003	Кировская область, город Киров, Нововятский район, ул.Советская, 17	Россия, Кировская область, Киров, Нововятский район, Советская улица, 17	0101000020E6100000BAF94674CFD848406B662D05A4414D40
42021	7	67	\N	369	49023	\N	58.488450999999998	Кировская область, город Киров, Нововятский район, ул.Советская, 170		0101000020E610000018963FDF16DE48406859F78F853E4D40
42427	7	67	\N	369	49254	\N	58.512818000000003	Кировская область, Опаринский район, Вазюкское сельское поселение, Советская, 17		0101000020E6100000BAF94674CFD848406B662D05A4414D40
42507	7	67	\N	369	48966	\N	58.507200056893602	Кировская область, Муниципальное образование Подосиновский район, Подосиновское городское поселение, Советская, 38	Россия, Кировская область, Киров, Нововятский район, Советская улица	0101000020E6100000BAC0E5B166DA4840FE43FAEDEB404D40
42008	7	67	\N	369	49077	\N	58.536492000000003	"Кировская область, город Киров, Нововятский район, слобода ""Село Красное"", ул.Советская, 15"		0101000020E61000005C21ACC612D84840674815C5AB444D40
42016	7	67	\N	369	49055	\N	58.506500000000003	Кировская область, город Киров, Нововятский район, ул.Советская, 48	Россия, Кировская область, Киров, Нововятский район, Советская улица, 48	0101000020E610000080EF366F9CDA484046B6F3FDD4404D40
42257	7	67	\N	369	49665	\N	58.518546999999998	Кировская область, Муниципальное образование Лузский район, п. Северные Полянки, Советская, 3		0101000020E6100000C2F869DC9BD748402E3883BF5F424D40
42115	7	67	\N	369	49036	\N	58.644838	Кировская область, город Киров, Первомайский район, Семашко, 2		0101000020E610000020EBA9D557DD4840E99B340D8A524D40
42095	7	67	\N	369	49031	\N	58.610500999999999	Кировская область, город Киров, Первомайский район, Свободы, 25		0101000020E6100000BD1B0B0A83D64840709692E5244E4D40
42097	7	67	\N	369	49043	\N	58.607899000000003	Кировская область, город Киров, Первомайский район, Свободы, 47		0101000020E6100000F99E91088DD64840B4226AA2CF4D4D40
42060	7	67	\N	369	49063	\N	58.612727	Кировская область, Муниципальное образование город Киров, Романа Ердякова, 24		0101000020E61000002F34D769A4D1484027309DD66D4E4D40
42048	7	67	\N	369	49063	\N	58.616574999999997	Кировская область, Муниципальное образование город Киров, Романа Ердякова, 23	Россия, Кировская область, Киров, улица Романа Ердякова, 23	0101000020E610000029ED0DBE30D14840FE43FAEDEB4E4D40
42050	7	67	\N	369	49027	\N	58.611629999999998	Кировская область, Муниципальное образование город Киров, Розы Люксембург, 87		0101000020E6100000E606431D56D4484051A04FE4494E4D40
42090	7	67	\N	369	49079	\N	58.611334999999997	Кировская область, город Киров, Первомайский район, Розы Люксембург, 66		0101000020E61000009CC0745AB7D5484038F3AB39404E4D40
42093	7	67	\N	369	49001	\N	58.612318999999999	Кировская область, город Киров, Первомайский район, Розы Люксембург, 3		0101000020E610000029266F8099D7484016DC0F78604E4D40
42155	7	67	\N	369	49008	\N	58.514806	Кировская область, Муниципальное образование город Кирово-Чепецк, Пушкина, 5		0101000020E61000002DCC423BA7D948406DE4BA29E5414D40
42013	7	67	\N	369	48970	\N	58.509687	Кировская область, город Киров, Нововятский район, ул.Пушкина, 27		0101000020E61000003E26529ACDD748402219726C3D414D40
42011	7	67	\N	369	49019	\N	58.511746000000002	Кировская область, город Киров, Нововятский район, ул.Пушкина, 32		0101000020E61000003B8F8AFF3BD84840EEED96E480414D40
41979	7	67	\N	369	48986	\N	58.581276000000003	Кировская область, Муниципальное образование город Киров, Пугачева, 18		0101000020E610000042E8A04B38D0484090F98040674A4D40
41972	7	67	\N	369	48986	\N	58.586019	Кировская область, город Киров, Ленинский район, Пугачева, 8		0101000020E610000037001B1021D04840D5EAABAB024B4D40
42057	7	67	\N	369	49090	\N	58.615248542846103	Кировская область, Муниципальное образование город Киров, Профсоюзная, 69		0101000020E6100000C39D0B23BDD44840C7F2AE7AC04E4D40
42119	7	67	\N	369	49059	\N	58.61553	Кировская область, город Киров, Первомайский район, Профсоюзная, 43		0101000020E61000002FA86F99D3D548407BDAE1AFC94E4D40
42107	7	67	\N	369	49004	\N	58.590170000000001	Кировская область, город Киров, Первомайский район, Пролетарская, 11а		0101000020E6100000AC1BEF8E8CD74840488AC8B08A4B4D40
41992	7	67	\N	369	49069	\N	58.593438999999996	Кировская область, Муниципальное образование город Киров, Производственная, 20А		0101000020E6100000FA4674CFBACE4840E19524CFF54B4D40
42018	7	67	\N	369	48998	\N	58.491753000000003	Кировская область, город Киров, Нововятский район, ул. Проектная, 29	Россия, Кировская область, Киров, улица Проектная, 29	0101000020E610000000FE2955A2DA4840DE5A26C3F13E4D40
41982	7	67	\N	369	49644	\N	58.568907000000003	Кировская область, Муниципальное образование город Киров, Потребкооперации, 2		0101000020E6100000558847E2E5CF484095BBCFF1D1484D40
41931	7	67	\N	369	48858	\N	58.578418999999997	Кировская область, Муниципальное образование город Киров, Ивана Попова, 37	Россия, Кировская область, Киров, улица Попова, 37	0101000020E610000073F6CE68ABD04840483140A2094A4D40
42517	7	67	\N	369	49011	\N	58.615225000000002	Кировская область, Муниципальное образование Подосиновский район, Пушемское сельское поселение, Первомайская, 15	Россия, Кировская область, Киров, Первомайская улица, 15	0101000020E61000005B40683D7CD948403F575BB1BF4E4D40
42420	7	67	\N	369	49011	\N	58.615552999999998	Кировская область, Муниципальное образование Опаринский район, Опаринское городское поселение, Первомайская, 3		0101000020E61000005FEE93A300D9484033FAD170CA4E4D40
42154	7	67	\N	369	49011	\N	58.615253000000003	Кировская область, Муниципальное образование город Кирово-Чепецк, Первомайская, 13		0101000020E6100000CF49EF1B5FD9484009E23C9CC04E4D40
42113	7	67	\N	369	49058	\N	58.640580999999997	Кировская область, город Киров, Первомайский район, Павла Корчагина, 66		0101000020E610000031B43A3943DD484030B8E68EFE514D40
42102	7	67	\N	369	49080	\N	58.595998999999999	Кировская область, город Киров, Первомайский район, Орловская, 12		0101000020E6100000D234289A07D848406FB9FAB1494C4D40
42012	7	67	\N	369	49081	\N	58.507975999999999	Кировская область, город Киров, Нововятский район, ул.Опарина, 14	Россия, Кировская область, Киров, улица Опарина, 14	0101000020E610000045BDE0D39CD848409293895B05414D40
42056	7	67	\N	369	142	\N	58.616396999999999	Кировская область, Муниципальное образование город Киров, Октябрьский проспект, 36	Россия, Кировская область, Киров, Октябрьский проспект, 36	0101000020E6100000AD4D637B2DD448401F2DCE18E64E4D40
42055	7	67	\N	369	142	\N	58.611756999999997	Кировская область, Муниципальное образование город Киров, Октябрьский проспект, 97	Россия, Кировская область, Киров, Октябрьский проспект, 97	0101000020E6100000AB2006BAF6D34840AE0CAA0D4E4E4D40
42049	7	67	\N	369	142	\N	58.615375	Кировская область, Муниципальное образование город Киров, Октябрьский проспект, 38	Россия, Кировская область, Киров, Октябрьский проспект, 38	0101000020E61000005DFDD8243FD4484054E3A59BC44E4D40
42045	7	67	\N	369	142	\N	58.622545000000002	Кировская область, Муниципальное образование город Киров, Октябрьский проспект, 67	Россия, Кировская область, Киров, Октябрьский проспект, 67	0101000020E610000064CF9ECBD4D24840E8A4F78DAF4F4D40
42042	7	67	\N	369	142	\N	58.632407999999998	Кировская область, город Киров, Октябрьский район, Октябрьский проспект, 31	Россия, Кировская область, Киров, Октябрьский проспект, 31	0101000020E61000002F88484DBBD0484048DDCEBEF2504D40
42041	7	67	\N	369	142	\N	58.636285999999998	Кировская область, Муниципальное образование город Киров, Октябрьский проспект, 21	Россия, Кировская область, Киров, Октябрьский проспект, 21	0101000020E6100000261AA4E029D048408A73D4D171514D40
33310	4	41	\N	16582	46258	\N	48.779257999999999	г. Биробиджан, Карла Маркса, 10		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
41962	7	67	\N	369	142	\N	58.597161999999997	Кировская область, Муниципальное образование город Киров, проспект Октябрьский, 129	Россия, Кировская область, Киров, Октябрьский проспект, 129	0101000020E61000004E0B5EF415D44840FC34EECD6F4C4D40
41961	7	67	\N	369	142	\N	58.595329	Кировская область, Ленинский район города Кирова, г.Киров, пр-т Октябрьский, дом 133	Россия, Кировская область, Киров, Октябрьский проспект, 133	0101000020E61000007EACE0B721D4484021AE9CBD334C4D40
41960	7	67	\N	369	142	\N	58.596505999999998	Кировская область, Муниципальное образование город Киров, проспект Октябрьский, 131	Россия, Кировская область, Киров, Октябрьский проспект, 131	0101000020E6100000F1BBE9961DD4484013EF004F5A4C4D40
41950	7	67	\N	369	142	\N	58.588866000000003	Кировская область, Муниципальное образование город Киров, проспект Октябрьский, 104	Россия, Кировская область, Киров, Октябрьский проспект, 104	0101000020E61000008FC536A968D44840F9DC09F65F4B4D40
41946	7	67	\N	369	142	\N	58.597186000000001	Кировская область, Муниципальное образование город Киров, проспект Октябрьский, 82	Россия, Кировская область, Киров, Октябрьский проспект, 82	0101000020E6100000BC79AA436ED4484085D04197704C4D40
42020	7	67	\N	369	49074	\N	58.493296000000001	Кировская область, город Киров, Нововятский район, ул.Октябрьская, 19		0101000020E610000009A69A594BDF4840B29FC552243F4D40
42019	7	67	\N	369	49022	\N	58.494500000000002	Кировская область, город Киров, Нововятский район, ул.Октябрьская, 25		0101000020E6100000E8A04B38F4DE48409EEFA7C64B3F4D40
41978	7	67	\N	369	48849	\N	58.581985000000003	Кировская область, Муниципальное образование город Киров, Некрасова, 38	Россия, Кировская область, Киров, улица Некрасова, 38/25	0101000020E61000002920ED7F80D148409CE1067C7E4A4D40
41976	7	67	\N	369	48849	\N	58.581918999999999	Кировская область, Муниципальное образование город Киров, Некрасова, 20		0101000020E6100000718E3A3AAED24840E4F560527C4A4D40
41974	7	67	\N	369	48849	\N	58.582692999999999	Кировская область, Муниципальное образование город Киров, Некрасова, 57		0101000020E6100000EF8D210038D04840D74D29AF954A4D40
42099	7	67	\N	369	6272	\N	58.604509999999998	Кировская область, город Киров, Первомайский район, Московская, 1В	Россия, Кировская область, Киров, Московская улица, 1в	0101000020E61000004EEFE2FDB8D748406F0D6C95604D4D40
42098	7	67	\N	369	48977	\N	58.603600608623402	Кировская область, город Киров, Первомайский район, Московская, 35	Россия, Кировская область, Киров, Московская улица	0101000020E6100000DAAB8F87BED548409C6A2DCC424D4D40
42076	7	67	\N	369	48977	\N	58.602736999999998	Кировская область, Муниципальное образование город Киров, Московская, 181		0101000020E6100000DC63E94317CC4840698B6B7C264D4D40
42058	7	67	\N	369	48977	\N	58.603529999999999	Кировская область, Муниципальное образование город Киров, Московская, 103		0101000020E6100000A20A7F8637D14840D3139678404D4D40
42052	7	67	\N	369	48977	\N	58.604309109932601	Кировская область, Муниципальное образование город Киров, Московская, 39	Россия, Кировская область, Киров, Московская улица, 39	0101000020E6100000657094BC3AD54840D8D64FFF594D4D40
41986	7	67	\N	369	48977	\N	58.601354000000001	Кировская область, Муниципальное образование город Киров, Московская, 156		0101000020E61000000BB5A679C7CB4840CEA8F92AF94C4D40
41945	7	67	\N	369	49056	\N	58.598002000000001	Кировская область, Муниципальное образование город Киров, Молодой Гвардии, 52		0101000020E61000007E52EDD3F1D44840A7785C548B4C4D40
42516	7	67	\N	369	49655	\N	58.633803999999998	Кировская область, Муниципальное образование Подосиновский район, Октябрьское сельское поселение, Молодежная, 1		0101000020E61000007B4CA4349BCD484078094E7D20514D40
42067	7	67	\N	369	49078	\N	58.613393000000002	Кировская область, Муниципальное образование город Киров, Мира, 34		0101000020E6100000B1C403CAA6CE4840344C6DA9834E4D40
42173	7	67	\N	369	48861	\N	58.612901668946797	Кировская область, Муниципальное образование город Кирово-Чепецк, пр. Мира, 37	Россия, Кировская область, Киров, Октябрьский район, улица Мира, 37	0101000020E6100000823CBB7CEBCD484095D39E92734E4D40
41951	7	67	\N	369	49021	\N	58.587505999999998	Кировская область, Муниципальное образование город Киров, Милицейская, 67		0101000020E6100000D07F0F5EBBD44840151A8865334B4D40
42108	7	67	\N	369	49034	\N	58.586516000000003	Кировская область, город Киров, Первомайский район, Милицейская, 50		0101000020E61000000344C18C29D64840564ACFF4124B4D40
42424	7	67	\N	369	48854	\N	58.592824	Кировская область, Муниципальное образование Опаринский район, Маромицкое сельское поселение, Конева, 9		0101000020E6100000116F9D7FBBCC4840572426A8E14B4D40
41993	7	67	\N	369	48854	\N	58.591000125492499	Кировская область, Муниципальное образование город Киров, Маршала И.С. Коненва, 13	Россия, Кировская область, Киров, улица Маршала Конева	0101000020E61000003FE257ACE1CC4840CFF753E3A54B4D40
42029	7	67	\N	369	49052	\N	58.640731000000002	Кировская область, Муниципальное образование город Киров, Макаренко, 7		0101000020E6100000A71FD4450ACF48404644317903524D40
42034	7	67	\N	369	6737	\N	58.632609000000002	Кировская область, город Киров, Октябрьский район, Луганская, 2	Россия, Кировская область, Киров, Луганская улица, 2	0101000020E61000005646239F57CE4840E013EB54F9504D40
42069	7	67	\N	369	48975	\N	58.610352424839	Кировская область, Муниципальное образование город Киров, ломоносова, 11	Россия, Кировская область, Киров, улица Ломоносова, 9	0101000020E610000088F4DBD781CD48402B86AB03204E4D40
42110	7	67	\N	369	7493	\N	58.593091999999999	Кировская область, город Киров, Первомайский район, Лесозаводская, 18а	Россия, Кировская область, Киров, Лесозаводская улица, 18а	0101000020E6100000D9942BBCCBD9484076C24B70EA4B4D40
42033	7	67	\N	369	6695	\N	58.635921000000003	Кировская область, город Киров, Октябрьский район, Ленинградская, 1	Россия, Кировская область, Киров, Ленинградская улица, 1	0101000020E6100000D350A39064CE484079EBFCDB65514D40
42032	7	67	\N	369	6695	\N	58.635095999999997	Кировская область, Муниципальное образование город Киров, Ленинградская, 3	Россия, Кировская область, Киров, Ленинградская улица, 3	0101000020E6100000E15F048D99CE484003E962D34A514D40
42031	7	67	\N	369	49073	\N	58.635921000000003	Кировская область, Муниципальное образование город Киров, Ленинградская, 1		0101000020E6100000D350A39064CE484079EBFCDB65514D40
42425	7	67	\N	369	49272	\N	58.612261394137597	Кировская область, Муниципальное образование Опаринский район, Заринское сельское поселение, Ленина, 23	Россия, Кировская область, Киров, Первомайский район, улица Ленина, 25	0101000020E6100000B22B2D23F5D64840E1CE85915E4E4D40
42104	7	67	\N	369	49003	\N	58.593195000000001	Кировская область, город Киров, Первомайский район, Ленина, 105		0101000020E6100000A5DAA7E331D748404B9352D0ED4B4D40
42455	7	67	\N	369	49247	\N	58.610726	Кировская область, Оричевский район, пгт Мирный, Ленина, 33а		0101000020E6100000C66CC9AA08D74840906802452C4E4D40
42092	7	67	\N	369	49000	\N	58.612315000000002	Кировская область, город Киров, Первомайский район, Ленина, 25		0101000020E61000009AB2D30FEAD64840D5EC8156604E4D40
42109	7	67	\N	369	49053	\N	58.586300000000001	Кировская область, Первомайский район города Кирова, г.Киров, ул. Ленина,127а	Россия, Кировская область, Киров, Первомайский район, улица Ленина, 127а	0101000020E61000003BC6151747D7484089D2DEE00B4B4D40
42106	7	67	\N	369	49053	\N	58.591214294666202	Кировская область, город Киров, Первомайский район, Ленина, 111	Россия, Кировская область, Киров, Первомайский район, улица Ленина, 111	0101000020E61000002634492C29D74840FB777DE6AC4B4D40
41999	7	67	\N	369	49053	\N	58.612834999999997	Кировская область, Муниципальное образование город Киров, микрорайон Лянгасово, Ленина, 16		0101000020E61000003CA3AD4A22D748400D6C9560714E4D40
42022	7	67	\N	369	49030	\N	58.491838000000001	Кировская область, город Киров, Нововятский район, ул.Ленина, 14		0101000020E61000009B5434D6FEDE48400C772E8CF43E4D40
42169	7	67	\N	369	49253	\N	58.610804999999999	Кировская область, Муниципальное образование город Кирово-Чепецк, Ленина, 26		0101000020E6100000D862B7CF2AD74840DC9DB5DB2E4E4D40
42006	7	67	\N	369	49087	\N	58.561143999999999	Кировская область, Муниципальное образование город Киров, Ленина, 200		0101000020E61000002E90A0F831D848405E2C0C91D3474D40
41959	7	67	\N	369	49041	\N	58.575941999999998	Кировская область, Муниципальное образование город Киров, Ленина, 166А		0101000020E610000055302AA913D848404832AB77B8494D40
41958	7	67	\N	369	49016	\N	58.578235999999997	Кировская область, Муниципальное образование город Киров, Ленина, 158А		0101000020E6100000C83F33880FD8484057AF22A3034A4D40
42111	7	67	\N	369	48985	\N	58.621110999999999	Кировская область, город Киров, Первомайский район, Красный Химик, 2/3		0101000020E61000004ED1915CFED94840CA17B490804F4D40
42105	7	67	\N	369	15454	\N	58.592106999999999	Кировская область, город Киров, Первомайский район, Красноармейская, 19	Россия, Кировская область, Киров, Ленинский район, Красноармейская улица, 19	0101000020E610000024438EAD67D64840C85D8429CA4B4D40
41980	7	67	\N	369	49046	\N	58.576739000000003	Кировская область, Муниципальное образование город Киров, Красина, 49		0101000020E61000009FE74F1BD5CF4840F4A96395D2494D40
41929	7	67	\N	369	49046	\N	58.576644999999999	Кировская область, Муниципальное образование город Киров, Красина, 41	Россия, Кировская область, Киров, улица Красина, 41	0101000020E610000015747B4963D048407233DC80CF494D40
42122	7	67	\N	369	49226	\N	58.631672000000002	Кировская область, город Киров, Первомайский район, п. Сидоровка, ул.Космонавтов, 18а		0101000020E6100000A60EF27A30DB484043E6CAA0DA504D40
41994	7	67	\N	369	48808	\N	58.589817488854202	Кировская область, Муниципальное образование город Киров, Космонавта Владислава Волкова, 6	Россия, Кировская область, Киров, улица Космонавта Волкова, 6	0101000020E6100000FED7B96933CC4840FACF9A1F7F4B4D40
41952	7	67	\N	369	48994	\N	58.584207999999997	Кировская область, Муниципальное образование город Киров, Комсомольская, 3		0101000020E610000069A8514832D54840E107E753C74A4D40
41975	7	67	\N	369	49015	\N	58.578414000000002	Кировская область, Муниципальное образование город Киров, Комсомольская, 41А		0101000020E61000008F56B5A4A3D2484037C64E78094A4D40
41998	7	67	\N	369	49070	\N	58.584358000000002	Кировская область, Муниципальное образование город Киров, микрорайон Лянгасово, Комсомольская, 10		0101000020E610000093A8177C9AD54840F793313ECC4A4D40
42615	7	67	\N	369	49258	\N	58.581262000000002	Кировская область, Муниципальное образование Советский район, с.Ильинск, Комсомольская, 22, здание Дома культуры		0101000020E6100000529E7939ECD448402B3410CB664A4D40
41928	7	67	\N	369	49661	\N	58.578404999999997	Кировская область, Ленинский район города Кирова, г.Киров, Комсомольская ул., дом  42		0101000020E61000002FA3586E69D34840E36BCF2C094A4D40
42073	7	67	\N	369	48999	\N	58.60586	Кировская область, Муниципальное образование город Киров, Кольцова, 18		0101000020E610000067D311C0CDCC48402FFA0AD28C4D4D40
42072	7	67	\N	369	48999	\N	58.607224000000002	Кировская область, Муниципальное образование город Киров, Кольцова, 9		0101000020E610000029232E008DCC484054AC1A84B94D4D40
41957	7	67	\N	369	49066	\N	58.586689999999997	Кировская область, Муниципальное образование город Киров, Ключевая, 9		0101000020E6100000F86C1D1CECD94840F3716DA8184B4D40
42114	7	67	\N	369	49005	\N	58.641002999999998	Кировская область, город Киров, Первомайский район, Клубная, 9		0101000020E6100000C3F5285C8FDC4840A6D1E4620C524D40
42718	7	67	359	1836	49299	\N	56.967830999999997	Кировская область, Уржумский район, с.Шурма, Пролетарская, 45		0101000020E61000004128EFE3682C49400987DEE2E17B4C40
41948	7	67	\N	369	49062	\N	58.592565999999998	Кировская область, Муниципальное образование город Киров, Карла Маркса, 115		0101000020E610000067EE21E17BD548405B5CE333D94B4D40
42145	7	67	\N	369	49007	\N	58.586703999999997	Кировская область, Муниципальное образование город Кирово-Чепецк, ул.Калинина, 32		0101000020E610000064E76D6C76D048405837DE1D194B4D40
42511	7	67	\N	369	48955	\N	58.505315000000003	Кировская область, Муниципальное образование Подосиновский район, Пинюгское городское поселение, индустриальная, 19		0101000020E610000042226DE34FDA4840D1967329AE404D40
42026	7	67	\N	369	49009	\N	58.504567155832703	Кировская область, город Киров, Нововятский район, мкр.Радужный, ул. Индустриальная, 20	Россия, Кировская область, Киров, улица Индустриальная	0101000020E6100000D882DE1B43DA484007D2C5A695404D40
42429	7	67	\N	369	49256	\N	58.637523000000002	Кировская область, Муниципальное образование Опаринский район, Речное сельское поселение, Заречная, 1		0101000020E610000092CD55F31CDD484052B9895A9A514D40
41953	7	67	\N	369	48996	\N	58.574402999999997	Кировская область, Муниципальное образование город Киров, Есенина, 9		0101000020E6100000E54350357AD34840B5DC990986494D40
42037	7	67	\N	369	48958	\N	58.633053985927504	Кировская область, Октябрьский район города Кирова, ул. Дзержинского, 23	Россия, Кировская область, Киров, улица Дзержинского, 21	0101000020E61000008541994693CF48400E4DD9E907514D40
42036	7	67	\N	369	48958	\N	58.632930901423997	Кировская область, Муниципальное образование город Киров, Дзержинского, 25	Россия, Кировская область, Киров, Уральская улица, 25	0101000020E6100000568330B77BCF4840F2CF0CE203514D40
41967	7	67	\N	369	48992	\N	58.585746999999998	Кировская область, Муниципальное образование город Киров, Горького, 51А		0101000020E61000009C887E6DFDD24840745DF8C1F94A4D40
41965	7	67	\N	369	48992	\N	58.594447000000002	Кировская область, Муниципальное образование город Киров, Горького, 20		0101000020E610000036B1C05774D34840481ADCD6164C4D40
42054	7	67	\N	369	49028	\N	58.608671999999999	Кировская область, Муниципальное образование город Киров, Горбуновой, 13		0101000020E6100000239EEC6646D34840D6FECEF6E84D4D40
42044	7	67	\N	369	48974	\N	58.627755999999998	Кировская область, Муниципальное образование город Киров, Гайдара, 5		0101000020E6100000D32EA699EED1484013EF004F5A504D40
42043	7	67	\N	369	48974	\N	58.627755999999998	Кировская область, Муниципальное образование город Киров, Гайдара, 3		0101000020E6100000D32EA699EED1484013EF004F5A504D40
42146	7	67	\N	369	49089	\N	58.607424999999999	Кировская область, Муниципальное образование город Кирово-Чепецк, ул.Вятская Набережная, 5		0101000020E610000015AB06616EDF4840EBE2361AC04D4D40
42152	7	67	\N	369	49065	\N	58.607424999999999	Кировская область, Муниципальное образование город Кирово-Чепецк, Вятская Набережная, 5	Россия, Кировская область, Киров, Вятская улица, 5	0101000020E610000015AB06616EDF4840EBE2361AC04D4D40
41984	7	67	\N	369	49018	\N	58.595207000000002	Кировская область, Муниципальное образование город Киров, Воровского, 84		0101000020E610000063F19BC24ACF4840D6AC33BE2F4C4D40
41963	7	67	\N	369	48990	\N	58.594194000000002	Кировская область, Муниципальное образование город Киров, Воровского, 79		0101000020E6100000DD989EB0C4D348405EBD8A8C0E4C4D40
42103	7	67	\N	369	49061	\N	58.593480999999997	Кировская область, город Киров, Первомайский район, Воровского, 16а		0101000020E61000008A93FB1D8AD6484010E6762FF74B4D40
41971	7	67	\N	369	48995	\N	58.591459999999998	Кировская область, Муниципальное образование город Киров, Воровского, 74А		0101000020E61000007506465ED6D04840327216F6B44B4D40
41983	7	67	\N	369	49071	\N	58.597856	Кировская область, Муниципальное образование город Киров, Воровского, 121		0101000020E6100000EA04341136CE4840D3DB9F8B864C4D40
41996	7	67	\N	369	49050	\N	58.596501000000004	Кировская область, Муниципальное образование город Киров, Воровского, 108		0101000020E61000007940D9942BCC484002840F255A4C4D40
41990	7	67	\N	369	49050	\N	58.596097999999998	Кировская область, Муниципальное образование город Киров, Воровского, 86		0101000020E6100000350A4966F5CE4840029B73F04C4C4D40
41987	7	67	\N	369	49068	\N	58.597608000000001	Кировская область, Муниципальное образование город Киров, Воровского, 153		0101000020E610000009FB761211CC4840FBE93F6B7E4C4D40
41985	7	67	\N	369	49067	\N	58.599778999999998	Кировская область, Муниципальное образование город Киров, Воровского, 133А		0101000020E6100000A723809BC5CD4840EEE9EA8EC54C4D40
41970	7	67	\N	369	49047	\N	58.592792000000003	Кировская область, Муниципальное образование город Киров, Воровского, 78		0101000020E61000007E01BD70E7D048404CAAB69BE04B4D40
42068	7	67	\N	369	49082	\N	58.614677	Кировская область, Муниципальное образование город Киров, Вологодская, 8		0101000020E6100000D0D38041D2CD48403C4D66BCAD4E4D40
42120	7	67	\N	369	49060	\N	58.608221999999998	Кировская область, город Киров, Первомайский район, с. Порошино, ул.Боровицкая, 22		0101000020E6100000D5928E7230E74840965AEF37DA4D4D40
42116	7	67	\N	369	49037	\N	58.641981000000001	Кировская область, Первомайский район города Кирова, г.Киров, ул. Боровая, 20		0101000020E61000000FF10F5B7ADE4840A2D3F36E2C524D40
42096	7	67	\N	369	49054	\N	58.611100999999998	Кировская область, город Киров, Первомайский район, Большевиков, 43		0101000020E6100000745C8DEC4AD74840C5C6BC8E384E4D40
41956	7	67	\N	369	49038	\N	58.582509999999999	Кировская область, Муниципальное образование город Киров, Блюхера, 38		0101000020E61000006EF8DD74CBD64840E6CB0BB08F4A4D40
42148	7	67	\N	369	48978	\N	58.585769999999997	Кировская область, Муниципальное образование город Кирово-Чепецк, ул.Азина, 1		0101000020E610000099D53BDC0ED748402C7DE882FA4A4D40
41949	7	67	\N	369	49064	\N	58.586094000000003	Кировская область, Муниципальное образование город Киров, Азина, 55		0101000020E6100000EEED96E480D54840E030D120054B4D40
42738	7	67	359	27997	49543	\N	57.042293000000001	Кировская область, Уржумский район, с.Шевнино, Кирова, 28-а		0101000020E6100000DD239BABE6074940C4EC65DB69854C40
42074	7	67	\N	369	48769	\N	58.604506399347898	Кировская область, Муниципальное образование город Киров, Андрея Упита, 9	Россия, Кировская область, Киров, улица А.Упита, 9	0101000020E6100000910DA48B4DCB48402E1EDE73604D4D40
42118	7	67	\N	369	49039	\N	58.660442000000003	Кировская область, город Киров, Первомайский район, 60 лет Комсомола, 17		0101000020E610000079AD84EE92D64840D2730B5D89544D40
42117	7	67	\N	369	49039	\N	58.657156000000001	Кировская область, город Киров, Первомайский район, 60 лет Комсомола, 4		0101000020E61000001FF818AC38D74840622F14B01D544D40
41955	7	67	\N	369	49040	\N	58.564847999999998	Кировская область, Муниципальное образование город Киров, 4-й Пятилетки, 40	Россия, Кировская область, Киров, улица 4-й Пятилетки, 40	0101000020E6100000E560360186D34840029B73F04C484D40
42168	7	67	\N	369	48989	\N	58.498595999999999	Кировская область, Муниципальное образование город Кирово-Чепецк, Школьная, 4А		0101000020E61000007B319413EDDA48404DF564FED13F4D40
42160	7	67	\N	369	48993	\N	58.487815355437199	Кировская область, Муниципальное образование город Кирово-Чепецк, Сосновая, 5А	Россия, Кировская область, Киров, Нововятский район, улица Сосновая	0101000020E610000074999A046FE04840C6BFCFB8703E4D40
42038	7	67	\N	369	48987	\N	58.641854652371997	Кировская область, Муниципальное образование город Киров, Подгорная, 18	Россия, Кировская область, Киров, улица Подгорная, 18/21	0101000020E610000083FB010F0CD0484015E3FC4D28524D40
41930	7	67	\N	369	49048	\N	58.567438000000003	Кировская область, Муниципальное образование город Киров, Ленина, 198		0101000020E6100000AD4ECE50DCD74840FB40F2CEA1484D40
41765	7	67	\N	369	49476	\N	58.6106269854358	Кировская область, Муниципальное образование Верхнекамский район. пос.Камский, Ленина, 32	Россия, Кировская область, Киров, Первомайский район, улица Ленина, 33	0101000020E61000000AF8359204D74840FD868906294E4D40
42426	7	67	\N	369	49650	\N	58.616607684167803	Кировская область, Муниципальное образование Опаринский район, Альмежское сельское поселение, Карла Маркса, 10	Россия, Кировская область, Киров, улица Карла Маркса, 10	0101000020E6100000E509849D62D54840DA39CD02ED4E4D40
41988	7	67	\N	369	48984	\N	58.601489999999998	Кировская область, Муниципальное образование город Киров, Дрелевского, 40		0101000020E610000064B14D2A1AD548407E6FD39FFD4C4D40
41964	7	67	\N	369	49042	\N	58.590938999999999	Кировская область, Муниципальное образование город Киров, Горького, 37		0101000020E610000084D4EDEC2BD3484029779FE3A34B4D40
41969	7	67	\N	369	49045	\N	58.591689000000002	Кировская область, Муниципальное образование город Киров, Воровского, 74		0101000020E61000004C89247A19D1484094331477BC4B4D40
42004	7	67	\N	369	77522	\N	58.5586622090266	Кировская область, Муниципальное образование город Киров, Аэропорт, 2А	Россия, Кировская область, Киров, Ленинский район	0101000020E610000011A8FE4124CB48404CC2853C82474D40
41822	7	67	\N	11679	9800	\N	56.228377877141199	"Кировская область, город Вятские Поляны, Шорина, 24 ""а"""	Россия, Кировская область, Вятские Поляны	0101000020E61000007FDAA84E078849401D90847D3B1D4C40
41817	7	67	\N	11679	48773	\N	56.2266924927779	"Кировская область, город Вятские Поляны, Школьная, 55 ""а"""	Россия, Кировская область, Вятские Поляны	0101000020E6100000DFC325C79D884940E621533E041D4C40
41823	7	67	\N	11679	48888	\N	56.226179000000002	Кировская область, город Вятские Поляны, Тойменка, 2		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41795	7	67	\N	11679	48888	\N	56.226179000000002	Кировская область, город Вятские Поляны, Тойменка, 23		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41813	7	67	\N	11679	48818	\N	56.226179000000002	Кировская область, город Вятские Поляны, Советская, 24		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41741	7	67	\N	11679	48818	\N	56.226179000000002	Кировская область, город Вятские Поляны, Советская, 13		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41815	7	67	\N	11679	48824	\N	56.226179000000002	Кировская область, город Вятские Поляны, Пароходная, 32		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41824	7	67	\N	11679	48904	\N	56.226179000000002	Кировская область, город Вятские Поляны, Ленина, 244-246		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41814	7	67	\N	11679	48904	\N	56.226179000000002	Кировская область, город Вятские Поляны, Ленина, 81		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41818	7	67	\N	11679	48762	\N	56.226179000000002	Кировская область, город Вятские Поляны, Кукина, 14-48		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41828	7	67	\N	11679	48893	\N	56.226179000000002	Кировская область, город Вятские Поляны, Кирова, 1		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41826	7	67	\N	11679	48913	\N	56.226179000000002	Кировская область, город Вятские Поляны, Дзержинского, 55		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41821	7	67	\N	11679	48890	\N	56.226179000000002	Кировская область, город Вятские Поляны, Гагарина, 30 а		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41820	7	67	\N	11679	48890	\N	56.226179000000002	Кировская область, город Вятские Поляны, Гагарина, 17		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41819	7	67	\N	11679	48890	\N	56.226179000000002	"Кировская область, город Вятские Поляны, Гагарина, 7 ""а"""	Россия, Кировская область, Вятские Поляны	0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41816	7	67	\N	11679	48910	\N	56.226179000000002	Кировская область, город Вятские Поляны, Азина, 45		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41825	7	67	\N	11679	48912	\N	56.226179000000002	"Кировская область, город Вятские Поляны, Ленина, 323 ""а"""		0101000020E6100000E3E313B2F38649406005F86EF31C4C40
41705	7	67	\N	55980	48822	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Здравоохранения, 1		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
42804	7	67	87	6761	48748	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Чапаева, 9А		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
33295	4	41	\N	16582	46308	\N	48.779257999999999	г. Биробиджан, Гоголя, 26		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
42810	7	67	87	6761	48755	\N	57.302876992896302	Кировская область, Яранский район, город Яранск, Тургенева, 57	Россия, Кировская область, Яранский район, Яранск	0101000020E610000059880E8123F14740F5DA6CACC4A64C40
42813	7	67	87	6761	49316	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Северная, 15		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42802	7	67	87	6761	48819	\N	57.298927955642	Кировская область, Яранский район, город Яранск, Садовая, 1Б	Россия, Кировская область, Яранский район, Яранск	0101000020E610000052280B5F5FEF4740E9EDCF4543A64C40
42807	7	67	87	6761	48752	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Некрасова, 61		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42803	7	67	87	6761	48797	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Мира, 17		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42812	7	67	87	6761	48816	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Кирова, 65		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42809	7	67	87	6761	49161	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Карла Маркса, 138	Россия, Кировская область, Яранский район, Яранск	0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42811	7	67	87	6761	48814	\N	57.298977000000001	Кировская область, Яранский район, г. Яранск, Рудницкого ул., дом 50		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42806	7	67	87	6761	48751	\N	57.298977000000001	Кировская область, Яранский район, город Яранск, Кирова, 28		0101000020E610000000C8091346EF4740CBA0DAE044A64C40
42832	7	67	87	57427	58541	\N	57.0236343321018	Кировская область, Яранский район, село Энгенер, Мира, 2		0101000020E61000008A558330B70D48406E895C7006834C40
42835	7	67	87	104	49420	\N	57.123632000000001	Кировская область, Яранский район, д. Шкаланка, Октябрьская ул., дом 2		0101000020E6100000A8E3310395F947409A5E622CD38F4C40
42820	7	67	87	31873	49548	\N	57.275750000000002	Кировская область, Яранский район, село Уртма, Набережная, 1		0101000020E6100000BFD4CF9B8ABC47409EEFA7C64BA34C40
42833	7	67	87	32416	49319	\N	57.279822000000003	Кировская область, Яранский район, село Сердеж, Школьная, 17		0101000020E6100000958098840B254840C5591135D1A34C40
42830	7	67	87	32310	49111	\N	57.103672000000003	Кировская область, Яранский район, село Салобеляк, Свободы, 21		0101000020E6100000AB22DC645407484066C1C41F458D4C40
42825	7	67	87	32068	49553	\N	57.420794999999998	Кировская область, Яранский район, деревня Савичи, Черепановская, 8А		0101000020E6100000280CCA349A0E484000A94D9CDCB54C40
42828	7	67	87	56009	49450	\N	57.386508416274097	Кировская область, Яранский район, село Рождественское, Школьный пер, 6	Россия, Кировская область, Яранский район, село Рождественск	0101000020E6100000E3A9471ADCEC474039D2191879B14C40
42829	7	67	87	32251	49599	\N	57.331766000000002	Кировская область, Яранский район, деревня Пушкино, Школьная, 8		0101000020E61000000AF65FE7A61B48405EF6EB4E77AA4C40
42824	7	67	87	6826	49551	\N	57.349155000000003	Кировская область, Яранский район, д. Пиштань, Советская ул., дом 73А		0101000020E6100000317A6EA12BF94740111E6D1CB1AC4C40
42822	7	67	87	31967	49554	\N	57.142316000000001	Кировская область, Яранский район, село Первомайское, Центральная, 19А		0101000020E61000005C04C6FA06C8474049D9226937924C40
42827	7	67	87	32157	49166	\N	57.384529000000001	Кировская область, Яранский район, местечко Опытное Поле, Школьная, 6		0101000020E61000006214048F6FF547408AAE0B3F38B14C40
42826	7	67	87	32135	49217	\N	57.191382836925101	Кировская область, Яранский район, село Никулята, Труда, 3	Россия, Кировская область, Яранский район, село Никулята	0101000020E6100000D6AD9E93DE3748405401F73C7F984C40
42823	7	67	87	31988	49327	\N	57.378318999999998	Кировская область, Яранский район, село Никола, Никольская, 11		0101000020E6100000890B40A3740948404B3ACAC16CB04C40
42834	7	67	87	32467	49603	\N	57.236865999999999	Кировская область, Яранский район, деревня Мари-Ушем, Центральная, 5		0101000020E61000008A05BEA25B19484065C405A0519E4C40
42787	7	67	87	30232	49314	\N	57.179406999999998	Кировская область, Яранский район, село Лум, Мира, 36		0101000020E6100000384BC97212F4474034D6FECEF6964C40
42819	7	67	87	31804	49598	\N	57.395695000000003	Кировская область, Яранский район, село Лом, Школьная, 1А		0101000020E6100000DFFDF15EB5D647406A183E22A6B24C40
42821	7	67	87	32518	49550	\N	57.206361000000001	Кировская область, Яранский район, село Кугушерга, Свободы, 15		0101000020E6100000118FC4CBD3D14740BE1589096A9A4C40
42818	7	67	87	31786	49317	\N	57.311107	Кировская область, Яранский район, село Кугалки, Зеленая, 1		0101000020E610000058C6866EF6D347404147AB5AD2A74C40
42836	7	67	87	119	49427	\N	57.031675	Кировская область, Яранский район, село Каракша, Космодемьянская, 41		0101000020E6100000B000A60C1CF64740E78C28ED0D844C40
42815	7	67	87	31637	\N	\N	57.342905000000002	Кировская область, Яранский район, деревня Иваново, 33		0101000020E6100000C87DAB75E2F047404451A04FE4AB4C40
42817	7	67	87	30923	49110	\N	57.245618	Кировская область, Яранский район, местечко Знаменка, Колхозная, 27		0101000020E6100000E198654F02EB47408BA71E69709F4C40
42800	7	67	87	30923	49235	\N	57.245618	Кировская область, Яранский район, местечко Знаменка, Кирова, 28		0101000020E6100000E198654F02EB47408BA71E69709F4C40
42816	7	67	87	31694	49422	\N	57.291204999999998	Кировская область, Яранский район, деревня Демино, Центральная, 46		0101000020E6100000CA6ABA9EE8F6474041B7973446A54C40
42814	7	67	87	31609	49423	\N	57.079137000000003	Кировская область, Яранский район, село Высоково, Лобова, 19		0101000020E61000000BF0DDE68DEF4740A8734529218A4C40
42831	7	67	87	32330	49601	\N	57.136361999999998	Кировская область, Яранский район, деревня Верхоуслино, Полевая, 15А		0101000020E61000003A3B191C2515484065355D4F74914C40
42795	7	67	1882	30617	48942	\N	59.040844	"Кировская область, Юрьянский район,п.Юрья,здание детского сада ""калинка"", Энгельса, 19"		0101000020E61000006A32E36DA5A34840711E4E603A854D40
42796	7	67	1882	30617	48944	\N	59.040844	"Кировская область, Муниципальное образование Юрьянский район,п.Юрья,Центр культуры и досуга ""Космос"", Ленина, 17"		0101000020E61000006A32E36DA5A34840711E4E603A854D40
42797	7	67	1882	30617	48945	\N	59.040844	Кировская область, Муниципальное образование Юрьянский район,п.Юрья,спорткомплекс, Дачная, 12		0101000020E61000006A32E36DA5A34840711E4E603A854D40
42782	7	67	1882	30011	49311	\N	59.077641	Кировская область, Юрьянский район,п.Северный,здание администрации поселения, Юбилейная, 2		0101000020E610000000E31934F4A5484014EAE923F0894D40
42793	7	67	1882	30551	49318	\N	58.803722999999998	Кировская область, Юрьянский район,д.Подгорцы,здание школы, Кольцевая, 3а		0101000020E61000007F8978EBFCBD484081053065E0664D40
42488	7	67	1882	56035	49702	\N	59.068731898628499	Кировская область, Юрьянский район, ЗАТО пос. Первомайский, Волкова ул., дом 12	Россия, Кировская область, Юрьянский район, поселок Первомайский	0101000020E610000020425C397BA548402618CE35CC884D40
42801	7	67	1882	30788	48744	\N	58.739097000000001	Кировская область, Юрьянский район,п.Мурыгино,здание Мурыгинского центра культуры и досуга (мраморный зал), Набережная, 7		0101000020E6100000E0BA624678BB48402EC901BB9A5E4D40
42798	7	67	1882	30788	48744	\N	58.739097000000001	Кировская область, Юрьянский район,п.Мурыгино,Мурыгинский центр культуры и досуга (дискозал), Набережная, 7		0101000020E6100000E0BA624678BB48402EC901BB9A5E4D40
42799	7	67	1882	30788	48747	\N	58.739097000000001	Кировская область, Муниципальное образование Юрьянский район,п.Мурыгино,здание средней школы, красных курсантов, 6		0101000020E6100000E0BA624678BB48402EC901BB9A5E4D40
42788	7	67	1882	30296	49597	\N	58.896467999999999	Кировская область, Юрьянский район,с.Монастырское,здание дома культуры, Тополиная, 18	Россия, Кировская область, Юрьянский район, село Монастырское	0101000020E610000012FA997ADDB448408CF4A276BF724D40
42792	7	67	1882	56001	49268	\N	58.776350168240299	Кировская область, Юрьянский район,с.Медяны,здание администрации поселения, Советская, 9	Россия, Кировская область, Юрьянский район, село Медяна	0101000020E61000007366BB421FAE4840F31FD26F5F634D40
42789	7	67	1882	30318	49600	\N	58.884709000000001	Кировская область, Юрьянский район,д.Ложкари,здание администрации поселения, Исаковская, 31		0101000020E61000002AAA7EA5F3CB48400ABDFE243E714D40
42678	7	67	1882	56010	49545	\N	58.915351845478199	Кировская область, Муниципальное образование Унинский район, д. Комарово, Школьная, 30	Россия, Кировская область, Юрьянский район, село Комарово	0101000020E61000009D2D20B41EB64840022A1C412A754D40
42784	7	67	1882	30111	49421	\N	58.987090999999999	Кировская область, Юрьянский район, д.Кокино,здание администрации поселения, Центральная, 11		0101000020E61000000377A04E79C64840859675FF587E4D40
42783	7	67	1882	30032	49418	\N	59.034033000000001	Кировская область, Юрьянский район, д.Ивановщина,здание дома культуры, Колхозная, 2		0101000020E610000058923CD7F7A948400DFE7E315B844D40
42790	7	67	1882	30402	49162	\N	58.814312000000001	Кировская область, Юрьянский район,с.Загарье,здание администрации поселения, Советская, 30		0101000020E61000001CD3139678CE4840C45E28603B684D40
42791	7	67	1882	30447	49220	\N	58.730553802893802	Кировская область, Юрьянский район, п.Гирсово,здание дома культуры, Заводская, 8	Россия, Кировская область, Юрьянский район, село Гирсово	0101000020E610000025CB49287DC7484022FB20CB825D4D40
42785	7	67	1882	30149	49602	\N	58.988912999999997	Кировская область, Юрьянский район,д.Высоково, здание дома культуры, Советская, 28		0101000020E610000087A5811FD5A648406CCB80B3947E4D40
42781	7	67	1882	29930	49595	\N	59.152009	Кировская область, Юрьянский район,с.Верходворье,здание школы, Советская, 4		0101000020E61000005EBA490C029348404DD9E90775934D40
42786	7	67	1882	30172	49160	\N	59.029263	Кировская область, Юрьянский район, с.Верховино,здание дома культуры, Сычугова, 2		0101000020E6100000CAFCA36FD2964840CEFDD5E3BE834D40
42794	7	67	1882	30597	49552	\N	58.894776	Кировская область, Юрьянский район,с.Великорецкое,здание дома культуры, Центральная, 25		0101000020E610000044A7E7DD58864840739F1C0588724D40
42780	7	67	1882	56011	49546	\N	59.225345970433501	Кировская область, Юрьянский район, ст.Великая, Комсомольская, 8-1	Россия, Кировская область, Юрьянский район, село Великая	0101000020E61000003ECBF3E0EE84484068244223D89C4D40
42779	7	67	1862	29838	49167	\N	58.686199999999999	Кировская область, Шабалинский район, с. Черновское, Набережная, 4	Россия, Кировская область, Шабалинский район, село Черновское	0101000020E610000028B8585183B34740F241CF66D5574D40
42371	7	67	1862	55999	49206	\N	58.655913314324202	Кировская область, Муниципальное образование Нолинский район,  д.Чащино, Первомайская, 16	Россия, Кировская область, Шабалинский район, село Чащино	0101000020E61000006E85B01A4BB24740B8020AF5F4534D40
42778	7	67	1862	29823	49594	\N	58.550980000000003	Кировская область, Шабалинский район, с. Соловецкое, Советская, 11		0101000020E6100000BE310400C790474003603C8386464D40
42775	7	67	1862	29677	49674	\N	58.192068999999996	Кировская область, Шабалинский район, Деревня Содом,ул.Мира д.1		0101000020E61000007C0E2C47C88E4740A7C98CB795184D40
42768	7	67	1862	29356	49417	\N	58.294606000000002	Кировская область, Шабалинский район, с. Семёновское, Победы, 18		0101000020E61000001903EB387EAC47404A9A3FA6B5254D40
42772	7	67	1862	29547	\N	\N	58.367173000000001	Кировская область, Шабалинский район, с. Прокопьевское, 4		0101000020E61000002D05A4FD0F684740B37C5D86FF2E4D40
42776	7	67	1862	29700	49216	\N	58.448642999999997	Кировская область, Шабалинский район, с. Новотроицкое, Кооперативная, 4		0101000020E61000001D7233DC80894740274A42226D394D40
42770	7	67	1862	29421	49593	\N	58.520614999999999	Кировская область, Шабалинский район, с. Николаевское, Запрудная, 21		0101000020E6100000A88C7F9F715747404D672783A3424D40
42767	7	67	1862	29296	49416	\N	58.383020000000002	Кировская область, Шабалинский район, д. Луни, Центральная, 8Б		0101000020E610000048C0E8F2E6A8474062DBA2CC06314D40
33299	4	41	\N	16582	46265	\N	48.779257999999999	г. Биробиджан, Волочаевская, 5		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
42764	7	67	1862	55969	48964	\N	58.308635298351298	Кировская область, Шабалинский район, пгт. Ленинское, Фрунзе, 21б	Россия, Кировская область, Шабалинский район, поселок Ленинское	0101000020E6100000E01115AA9B8D474053B3075A81274D40
42766	7	67	1862	55969	48821	\N	58.308906	Кировская область, Шабалинский район, пгт. Ленинское, Площадь Ленина, 2	Россия, Кировская область, Шабалинский район, поселок Ленинское	0101000020E6100000F722DA8EA98D4740E3C4573B8A274D40
42763	7	67	1862	55969	48821	\N	58.306557212124098	Кировская область, Шабалинский район, пгт. Ленинское, Площадь Ленина, 1	Россия, Кировская область, Шабалинский район, поселок Ленинское	0101000020E6100000FA2AF9D85D8C474010AE80423D274D40
42765	7	67	1862	55969	48749	\N	58.308876257368702	Кировская область, Шабалинский район, пгт. Ленинское, Гусарова, 14	Россия, Кировская область, Шабалинский район, поселок Ленинское	0101000020E6100000B62DCA6C908D47407842AF3F89274D40
42771	7	67	1862	29495	\N	\N	58.453167999999998	Кировская область, Шабалинский район, с. Колосово, Центральная, 15	Россия, Кировская область, Шабалинский район, село Колосово	0101000020E61000002EE411DC486F4740FFCBB568013A4D40
42769	7	67	1862	29404	49155	\N	58.331829999999997	Кировская область, Шабалинский район, п. Гостовский, Школьная, 5		0101000020E6100000A5828AAA5F57474074EACA67792A4D40
42773	7	67	1862	29564	49309	\N	58.141461	Кировская область, Шабалинский район, с. Высокораменское, Свободы, 25		0101000020E6100000389F3A56298B47406954E0641B124D40
42774	7	67	1862	29629	49331	\N	58.242573684677602	Кировская область, Шабалинский район, с. Высокогорье, Школьная, 6	Россия, Кировская область, Шабалинский район, село Высокогорье	0101000020E6100000CEC64ACCB3984740116E32AA0C1F4D40
42777	7	67	1862	29776	49312	\N	58.542579000000003	Кировская область, Шабалинский район, с. Архангельское, Советская, 34		0101000020E6100000BEBC00FBE87247408A3F8A3A73454D40
42758	7	67	1841	28904	\N	\N	58.327491999999999	Кировская область, Фалёнский район, д.Юсово, Мира, 30	Россия, Кировская область, Фаленский район, село Юсово	0101000020E610000078D503E621D94940CFD90242EB294D40
42143	7	67	1841	55998	49163	\N	57.886330259514303	Кировская область, Муниципальное образование Кирово-Чепецкий район, д.Чуваши, ул.Советская, д.4	Россия, Кировская область, Фаленский район, село Чуваши	0101000020E61000004E603AADDBD649405ABBED4273F14C40
42757	7	67	1841	28857	49591	\N	57.973908999999999	Кировская область, Фалёнский район, д.Филейка, Коммуны, 38а		0101000020E61000007CB779E3A4B04940D923D40CA9FC4C40
42762	7	67	1841	28963	48813	\N	58.353921	Кировская область, Фалёнский район, поселок городского типа Фалёнки, Первомайская, 4		0101000020E61000001DE736E15ECD49400E2F88484D2D4D40
42759	7	67	1841	28963	48743	\N	58.353921	Кировская область, Фалёнский район, поселок городского типа Фалёнки, Коммуны, 31		0101000020E61000001DE736E15ECD49400E2F88484D2D4D40
42760	7	67	1841	28963	48941	\N	58.353921	Кировская область, Фалёнский район, поселок городского типа Фалёнки, Воробьева, 13		0101000020E61000001DE736E15ECD49400E2F88484D2D4D40
42761	7	67	1841	28963	49156	\N	58.353921	Кировская область, Фалёнский район, поселок городского типа Фалёнки, Береговая, 1		0101000020E61000001DE736E15ECD49400E2F88484D2D4D40
42756	7	67	1841	28800	49218	\N	58.014937000000003	Кировская область, Фалёнский район, с.Талица, Ленина, 23		0101000020E6100000D74CBED9E6C049400C40A374E9014D40
42755	7	67	1841	28774	49549	\N	58.203319	Кировская область, Фалёнский район, с.Святица, Свердлова, 11		0101000020E610000094C2BCC799CA4940E5D3635B061A4D40
42754	7	67	1841	28701	49584	\N	57.911636000000001	Кировская область, Фалёнский район, с.Полом, Садовая, 2а		0101000020E61000003E079623649A49409AED0A7DB0F44C40
42753	7	67	1841	28676	49587	\N	58.130828000000001	Кировская область, Фалёнский район, д.Подоплеки, Советская, 2	Россия, Кировская область, Фаленский район, село Подоплеки	0101000020E6100000B8955E9B8DB3494057B3CEF8BE104D40
42752	7	67	1841	28612	49313	\N	58.141803000000003	Кировская область, Фалёнский район, д.Петруненки, Труда, 24		0101000020E610000031EE06D15AC14940C3BCC79926124D40
42751	7	67	1841	28586	49303	\N	57.927605999999997	Кировская область, Фалёнский район, д.Паньшонки, Труда, 24		0101000020E610000037C1374D9FC3494064C91CCBBBF64C40
42747	7	67	1841	28395	49225	\N	58.204486000000003	Кировская область, Фалёнский район, п.Октябрьский, Садовая, 12а		0101000020E61000007A354069A8C34940B43EE5982C1A4D40
42750	7	67	1841	28526	49544	\N	58.399948999999999	Кировская область, Фалёнский район, с.Николаево, Юбилейная, 18		0101000020E6100000B136C64E78E14940B188618731334D40
42341	7	67	1841	28526	49649	\N	58.399671740342797	Кировская область, Муниципальное образование Нагорский район, Чеглаковское сельское поселение, с.Николаево, Школьная, 2	Россия, Кировская область, Фаленский район, село Николаево	0101000020E6100000567DAEB662E149403F90BC7328334D40
42749	7	67	1841	28496	49579	\N	58.458629999999999	Кировская область, Фалёнский район, с.Низево, Школьная, 9		0101000020E610000099F04BFDBCC94940747B4963B43A4D40
42748	7	67	1841	28442	49578	\N	58.271487999999998	Кировская область, Фалёнский район, д.Малахи, Баранниковская, 21		0101000020E6100000C158DFC0E4C64940D3A0681EC0224D40
42746	7	67	1841	28341	49213	\N	58.397784000000001	Кировская область, Фалёнский район, д.Леваны, Школьная, 2а		0101000020E6100000E0A128D027C04940A06F0B96EA324D40
42745	7	67	1841	28300	49575	\N	58.054403000000001	Кировская область, Фалёнский район, д.Вогульцы, Юбилейная, 1		0101000020E610000038F6ECB94CD14940F3E670ADF6064D40
42744	7	67	1841	28246	49114	\N	58.025061000000001	Кировская область, Фалёнский район, с.Верхосунье, Пионерская, 20а		0101000020E61000003DF19C2D20AA4940D9B3E73235034D40
42743	7	67	1841	28222	49415	\N	57.981439999999999	Кировская область, Фалёнский район, с.Белая, Школьная, 2		0101000020E6100000AD855968E7D649403D7E6FD39FFD4C40
42740	7	67	359	1836	49164	\N	56.967830999999997	Кировская область, Уржумский район, с.Шурма, пер.Школьный, 1		0101000020E61000004128EFE3682C49400987DEE2E17B4C40
42734	7	67	359	27802	49301	\N	57.180441000000002	Кировская область, Уржумский район, с.Цепочкино, Кирова, 34	Россия, Кировская область, Уржумский район, село Цепочкино	0101000020E6100000FE463B6EF80B4940C4EDD0B018974C40
42692	7	67	359	25893	49391	\N	57.109777000000001	Кировская область, Уржумский район, г.Уржум, Новокузнечная, 90-а		0101000020E6100000B5FE9600FCFF48402F6D382C0D8E4C40
42698	7	67	359	25893	48883	\N	57.109777000000001	Кировская область, Уржумский район, г.Уржум, Красная, 161		0101000020E6100000B5FE9600FCFF48402F6D382C0D8E4C40
42697	7	67	359	25893	48882	\N	57.109777000000001	Кировская область, Уржумский район, г.Уржум, Кировский тракт, 32		0101000020E6100000B5FE9600FCFF48402F6D382C0D8E4C40
42694	7	67	359	25893	48739	\N	57.109777000000001	Кировская область, Уржумский район, г.Уржум, Кирова, 69		0101000020E6100000B5FE9600FCFF48402F6D382C0D8E4C40
42696	7	67	359	25893	48741	\N	57.109777000000001	Кировская область, Уржумский район, г.Уржум, Дрелевского, 1		0101000020E6100000B5FE9600FCFF48402F6D382C0D8E4C40
42695	7	67	359	25893	48740	\N	57.109777000000001	Кировская область, Уржумский район, г.Уржум, Гоголя, 57		0101000020E6100000B5FE9600FCFF48402F6D382C0D8E4C40
42693	7	67	359	25893	48740	\N	57.109777000000001	Кировская область, Уржумский район, г.Уржум, Гоголя, 91		0101000020E6100000B5FE9600FCFF48402F6D382C0D8E4C40
42714	7	67	359	26903	49569	\N	56.951571999999999	Кировская область, Уржумский район, д.Тюм-Тюм, Садовая, 17		0101000020E610000008E3A7716F36494008E57D1CCD794C40
42733	7	67	359	27787	49571	\N	56.917459999999998	Кировская область, Уржумский район, д.Толгозино, Комсомольская, 27		0101000020E6100000AB949EE925FE4840AFB14B546F754C40
42735	7	67	359	27884	49304	\N	57.129494000000001	Кировская область, Уржумский район, д.Теребиловка, Советская, 16		0101000020E6100000BB80971936FE48409D83674293904C40
42707	7	67	359	26590	49539	\N	56.840857	Кировская область, Уржумский район, д.Танабаево, Молодежная, 2		0101000020E61000001B0DE02D902A49406CCEC133A16B4C40
42704	7	67	359	26430	49535	\N	57.090896000000001	Кировская область, Уржумский район, д.Берсениха, Садовая, 20		0101000020E6100000BEC0AC50A4F948402AABE97AA28B4C40
42739	7	67	359	6669	49541	\N	57.024455000000003	Кировская область, Уржумский район, д. Собакино, ул Лесная д.1		0101000020E6100000221CB3EC49024940A29C685721834C40
42731	7	67	359	27688	49306	\N	56.958683999999998	Кировская область, Уржумский район, д.Савиново, Юбилейная, 7		0101000020E6100000C84274081C0F494067994528B67A4C40
42728	7	67	359	27543	49302	\N	57.123739	Кировская область, Уржумский район, д.Русское Тимкино, 8 марта, 1		0101000020E61000003B511212690B4940B01EF7ADD68F4C40
42729	7	67	359	27609	48943	\N	57.058669000000002	Кировская область, Уржумский район, с.Русский Турек, Пристанская, 1	Россия, Кировская область, Уржумский район, село Русский Турек	0101000020E6100000CA3159DC7F1C4940FF243E7782874C40
42705	7	67	359	26488	49403	\N	57.030631999999997	Кировская область, Уржумский район, д.Русская Биляморь, Трудовая, 13		0101000020E6100000EF004F5AB8F64840041BD7BFEB834C40
42726	7	67	359	27437	49411	\N	57.281258000000001	Кировская область, Уржумский район, с.Рождественское, Труда, 2		0101000020E6100000B4E386DF4DFD484083DE1B4300A44C40
42723	7	67	359	27318	49412	\N	57.123533999999999	Кировская область, Уржумский район, д.Поповка, Молодежная, 2		0101000020E6100000E563778192F44840D7F84CF6CF8F4C40
42725	7	67	359	27337	49572	\N	56.988821000000002	Кировская область, Уржумский район, п.Пиляндыш, Советская, 35	Россия, Кировская область, Уржумский район, село Пиляндыш	0101000020E61000003EE94482A93A49408C4CC0AF917E4C40
42720	7	67	359	27161	49255	\N	57.330478999999997	Кировская область, Уржумский район, с.Петровское, Кирова, 63		0101000020E6100000A070766B99FC4840E481C8224DAA4C40
42722	7	67	359	27254	49542	\N	57.364190999999998	Кировская область, Уржумский район, д.Орешник, Советская, 11	Россия, Кировская область, Уржумский район, село Орешник	0101000020E6100000508A56EE05FC4840AF3F89CF9DAE4C40
42421	7	67	359	55988	48956	\N	56.870407116401701	Кировская область, Муниципальное образование Опаринский район, Опаринское городское поселение, Железнодорожная, 44	Россия, Кировская область, Уржумский район, село Опарино	0101000020E61000009CC58B8521044940D09A1F7F696F4C40
42719	7	67	359	27138	49555	\N	57.001989999999999	Кировская область, Уржумский район, д.Овсянниково, Школьная, 15		0101000020E61000005D6A847EA6E44840A375543541804C40
42713	7	67	359	6645	49540	\N	56.930925000000002	Кировская область, Уржумский район, д.Нижний Унур, Молодежная, 38		0101000020E6100000BDC804FC1AF14840B003E78C28774C40
42701	7	67	359	26298	49567	\N	57.221139000000001	Кировская область, Уржумский район, д.Шуэть, Центральная, 22		0101000020E6100000F3E505D847EF4840616F62484E9C4C40
42708	7	67	359	26607	49537	\N	56.794800000000002	Кировская область, Уржумский район, д.Манкинерь, Центральная, 25		0101000020E610000023D923D40C3349402F6EA301BC654C40
42742	7	67	359	56029	49687	\N	56.999705798332997	Кировская область, Уржумский район, д.Макиснерь, Школьная, 23	Россия, Кировская область, Уржумский район, село Максинерь	0101000020E610000051BF0B5BB3254940B8CEBF5DF67F4C40
42607	7	67	359	56032	49691	\N	56.948327013771802	Кировская область, Уржумский район, с.Лопьял, Школьная, 21	Россия, Кировская область, Уржумский район, село Лопъял	0101000020E61000008335CEA623FE4840F77475C762794C40
42717	7	67	359	56022	49653	\N	57.111115557030899	Кировская область, Уржумский район, поч.Лебедевский, Кооперативная, 1	Россия, Кировская область, Уржумский район, село Лебедевский	0101000020E610000030F2B22616CC4840FB07910C398E4C40
42712	7	67	359	26792	49212	\N	56.825217000000002	Кировская область, Уржумский район, с.Лазарево, Октябрьская, 6		0101000020E610000047E7FC14C7194940378DEDB5A0694C40
42730	7	67	359	56025	49663	\N	57.026061166625603	Кировская область, Уржумский район, д.Кизерь, Новая	Россия, Кировская область, Уржумский район, село Кизерь	0101000020E6100000DA3C0E83F91D4940BC5983F755834C40
42700	7	67	359	26234	49298	\N	57.187105000000003	Кировская область, Уржумский район, д.Зоткино, Полевая, 4		0101000020E6100000D862B7CF2AED484084F57F0EF3974C40
42711	7	67	359	26778	49538	\N	56.888579	Кировская область, Уржумский район, д.Ешпаево, Советская, 33-а		0101000020E6100000F33E8EE6C8104940C974E8F4BC714C40
42737	7	67	359	27963	49582	\N	57.167399000000003	Кировская область, Уржумский район, д.Дюково, Трактовая, 2		0101000020E61000003B8C497F2F0949400A3197546D954C40
42710	7	67	359	26725	49158	\N	56.896863000000003	Кировская область, Уржумский район, п.Донаурово, Лесная, 10		0101000020E61000008869DFDC5F43494009FF2268CC724C40
42716	7	67	359	26982	49409	\N	56.900407000000001	Кировская область, Уржумский район, д.Витля, Зеленая, 28-а		0101000020E61000007FF6234564F44840740B5D8940734C40
42721	7	67	359	27219	49410	\N	57.262307999999997	Кировская область, Уржумский район, д.Вершинята, Трудовая, 2-а		0101000020E6100000C782C2A04CF3484055BDFC4E93A14C40
42741	7	67	359	28129	49440	\N	56.950977999999999	Кировская область, Уржумский район, с.Верхняя Шурма, Майская, 26		0101000020E61000008331225168294940959BA8A5B9794C40
42709	7	67	359	26697	48742	\N	57.084992	Кировская область, Уржумский район, с.Буйское, Кирова, 4		0101000020E61000008DF0F62004DC4840F8359204E18A4C40
42706	7	67	359	26516	49104	\N	56.860565000000001	Кировская область, Уржумский район, с.Большой Рой, Трудовая, 5а		0101000020E610000041D47D0052334940878A71FE266E4C40
42703	7	67	359	26408	49568	\N	57.068705999999999	Кировская область, Уржумский район, д.Богданово, Школьная, 1		0101000020E6100000EC12D55B03034940FD84B35BCB884C40
42702	7	67	359	26326	49107	\N	57.200681000000003	Кировская область, Уржумский район, с.Байса, Школьная, 1		0101000020E610000007B309302CC34840DCF63DEAAF994C40
42715	7	67	359	26964	49547	\N	56.987462000000001	Кировская область, Уржумский район, с.Ашлань, Почтовая, 13		0101000020E6100000EC4B361E6CF948407905A227657E4C40
42736	7	67	359	27904	49414	\N	57.154488000000001	Кировская область, Уржумский район, д.Антонково, Центральная, 1	Россия, Кировская область, Уржумский район, село Антонково	0101000020E61000006BB933130C054940EECF4543C6934C40
42699	7	67	359	26205	49106	\N	57.069899999999997	Кировская область, Уржумский район, п.Андреевский, Молодежная, 20		0101000020E6100000B900344A97444940C5FEB27BF2884C40
42732	7	67	359	27724	49413	\N	56.932723000000003	Кировская область, Уржумский район, с.Актыгашево, Садовая, 24		0101000020E61000007C9A9317991849400F9D9E7763774C40
42727	7	67	359	27498	49308	\N	57.228242999999999	Кировская область, Уржумский район, д.Адово, Школьная, 17		0101000020E61000002A58E36C3AD448403D450E11379D4C40
42691	7	67	1759	25877	49563	\N	57.524427000000003	Кировская область, Муниципальное образование Унинский район, д. Чуваши, Профсоюзная, 21		0101000020E6100000B3614D6551984940D811876C20C34C40
42690	7	67	1759	25805	49564	\N	57.699289	Кировская область, Муниципальное образование Унинский район, с. Уть, Советская, 32		0101000020E610000044882B67EFE04940EDB94C4D82D94C40
42689	7	67	1759	25612	48738	\N	57.752423999999998	Кировская область, Муниципальное образование Унинский район, пгт. Уни, Ленина, 21		0101000020E6100000C00644882BBF4940DD5CFC6D4FE04C40
42687	7	67	1759	25612	48738	\N	57.752423999999998	Кировская область, Муниципальное образование Унинский район, пгт. Уни, Ленина, 24		0101000020E6100000C00644882BBF4940DD5CFC6D4FE04C40
42688	7	67	1759	25612	48940	\N	57.752423999999998	Кировская область, Муниципальное образование Унинский район, пгт. Уни, Колхозная, 10		0101000020E6100000C00644882BBF4940DD5CFC6D4FE04C40
42686	7	67	1759	25612	48737	\N	57.752423999999998	Кировская область, Муниципальное образование Унинский район, пгт. Уни, 40 лет Победы, 4		0101000020E6100000C00644882BBF4940DD5CFC6D4FE04C40
42685	7	67	1759	25580	49566	\N	57.824646999999999	Кировская область, Муниципальное образование Унинский район, д. Удмуртский Сурвай, переулок Школьный, 1	Россия, Кировская область, Унинский район, село Удмуртский Сурвай	0101000020E6100000984F560C57CB49404CDF6B088EE94C40
42684	7	67	1759	25509	49293	\N	57.796832999999999	Кировская область, Муниципальное образование Унинский район, с. Сосновка, Советская, 49		0101000020E610000080B74082E2D74940D1AFAD9FFEE54C40
42681	7	67	1759	25380	49533	\N	57.638764000000002	Кировская область, Муниципальное образование Унинский район, с. Сардык, Кооперативная, 51А		0101000020E610000047E4BB94BAC249405BEECC04C3D14C40
42679	7	67	1759	25284	49532	\N	57.686725000000003	Кировская область, Муниципальное образование Унинский район, д. Малый Полом, Центральная, 8		0101000020E6100000AD6D8AC745A349403D2CD49AE6D74C40
42677	7	67	1759	25165	49419	\N	57.611148999999997	Кировская область, Муниципальное образование Унинский район, д. Князево, Новая, 12		0101000020E61000000E828E56B5A04940D6FD63213ACE4C40
42676	7	67	1759	25146	49290	\N	57.671523000000001	Кировская область, Муниципальное образование Унинский район, д. Канахинцы, Административная, 4		0101000020E610000002D369DD06CD494083C13577F4D54C40
42675	7	67	1759	25085	49389	\N	57.823224000000003	Кировская область, Муниципальное образование Унинский район, с. Елгань, Центральная, 7		0101000020E6100000AB75E272BC9A494023A46E675FE94C40
42674	7	67	1759	25068	49286	\N	57.794103999999997	Кировская область, Муниципальное образование Унинский район, с. Верхолемье, Центральная, 13		0101000020E610000063450DA661EE4940B7CF2A33A5E54C40
42673	7	67	1759	25008	49394	\N	57.597656000000001	Кировская область, Муниципальное образование Унинский район, д. Булатовцы, Молодёжная, 16		0101000020E6100000A1832EE1D0D149400C21E7FD7FCC4C40
42672	7	67	1759	24964	49390	\N	57.721983000000002	Кировская область, Муниципальное образование Унинский район, д. Барашки, Коммунальная, 1		0101000020E6100000BDC62E51BD8749404DA25EF069DC4C40
42671	7	67	1759	24938	49560	\N	57.821674999999999	Кировская область, Муниципальное образование Унинский район, д. Астрахань, Советская, 34		0101000020E61000004FAF946588A149406C787AA52CE94C40
42654	7	67	592	24092	49637	\N	57.471198000000001	Кировская область, Тужинский район, село Шешурга, Центральная, 4		0101000020E61000003F726BD26DC9474066F84F3750BC4C40
42669	7	67	592	3719	48880	\N	57.626404999999998	Кировская область, Тужинский район, п. Тужа, Фокина ул., дом 18		0101000020E6100000207F69519FF647408386FE092ED04C40
42657	7	67	592	3719	48735	\N	57.626404999999998	Кировская область, Тужинский район, поселок городского типа  Тужа, Набережная, 5		0101000020E6100000207F69519FF647408386FE092ED04C40
42670	7	67	592	3719	48936	\N	57.626404999999998	Кировская область, Тужинский район, поселок городского типа Тужа, Горького, 10		0101000020E6100000207F69519FF647408386FE092ED04C40
42668	7	67	592	24799	\N	\N	57.486789000000002	Кировская область, Тужинский район, деревня Полушнур, здание ФАПа	Россия, Кировская область, Тужинский район, село Полушнур	0101000020E610000012A452EC68164840BA86191A4FBE4C40
42667	7	67	592	24733	\N	\N	57.613010000000003	Кировская область, Тужинский район, деревня Покста, Покстинский сельский дом культуры		0101000020E61000001A3048FAB40E48407C0F971C77CE4C40
42666	7	67	592	24719	49283	\N	57.487625999999999	Кировская область, Тужинский район, деревня Пиштенур, Центральная, 36		0101000020E610000039639813B4EB4740F3565D876ABE4C40
42665	7	67	592	24642	49388	\N	57.567765000000001	Кировская область, Тужинский район, село Пачи, Центральная, 3	Россия, Кировская область, Тужинский район, село Пачи	0101000020E6100000EED11BEE231548401F680586ACC84C40
42664	7	67	592	24625	49281	\N	57.490479999999998	Кировская область, Тужинский район, село Ныр, Советская, 13		0101000020E610000073F7393E5AFA4740C9AB730CC8BE4C40
42663	7	67	592	24550	49559	\N	57.512768000000001	Кировская область, Тужинский район, село Михайловское, Центральная, 67		0101000020E610000085950A2AAADC4740B937BF61A2C14C40
42661	7	67	592	24459	\N	\N	57.712589999999999	Кировская область, Тужинский район, деревня Коврижата, Коврижатская сельская библиотека		0101000020E61000002310AFEB17E6474073BA2C2636DB4C40
42662	7	67	592	24495	49558	\N	57.781298999999997	Кировская область, Тужинский район, село Караванное, Школьная, 1		0101000020E610000034D593F947D74740E1B20A9B01E44C40
42660	7	67	592	24387	49557	\N	57.519660999999999	Кировская область, Тужинский район, деревня Греково, Школьная, 13		0101000020E610000016889E94490B4840DA006C4084C24C40
42659	7	67	592	24346	\N	\N	57.58963	Кировская область, Тужинский район, деревня Вынур, здание детского сада	Россия, Кировская область, Тужинский район, село Вынур	0101000020E6100000F9669B1BD3254840C85EEFFE78CB4C40
42658	7	67	592	24287	\N	\N	57.458703999999997	Кировская область, Тужинский район, деревня Васькино, адм. здание Михайловского с/п		0101000020E6100000D8D5E429ABD74740AE450BD0B6BA4C40
42656	7	67	869	23408	49214	\N	57.819806	Кировская область, Муниципальное образование Сунский район, Сунское городское поселение, пгт Суна, Советская, 31		0101000020E6100000C7B94DB85708494044882B67EFE84C40
42640	7	67	869	23408	48811	\N	57.819806	Кировская область, Муниципальное образование Сунский район, Сунское городское поселение, пгт Суна, Дружбы, 22		0101000020E6100000C7B94DB85708494044882B67EFE84C40
42653	7	67	869	52566	49536	\N	57.780714000000003	Кировская область, Муниципальное образование Сунский район, Кокуйское сельское поселение, д. Смыки, Школьная, 4	Россия, Кировская область, Сунский район, село Смыки	0101000020E6100000E4BF401020FB4840C2C3B46FEEE34C40
42652	7	67	869	24014	49528	\N	57.822768000000003	Кировская область, Муниципальное образование Сунский район, Кокуйское сельское поселение, с. Плелое, Школьная, 7		0101000020E6100000960A2AAA7E1F494001193A7650E94C40
42647	7	67	869	56015	49596	\N	57.900594198803297	Кировская область, Муниципальное образование Сунский район, Большевистское сельское поселение, п. Новый, Механизаторская, 2	Россия, Кировская область, Сунский район, село Новый	0101000020E6100000560DC2DCEEE94840A67C08AA46F34C40
42649	7	67	869	23856	\N	\N	57.769181000000003	Кировская область, Муниципальное образование Сунский район, Кокуйское сельское поселение, с. Нестино, Советская, 17		0101000020E6100000CD3B4ED19116494030DAE38574E24C40
42648	7	67	869	52550	49384	\N	57.882917999999997	Кировская область, Муниципальное образование Сунский район, Большевистское сельское поселение, д. Мурино, Советская, 36		0101000020E6100000895DDBDB2D2749405D86FF7403F14C40
42646	7	67	869	23679	49556	\N	57.933163999999998	Кировская область, Сунский район, Курчум село, Школьная ул., дом 1		0101000020E6100000D099B4A9BA254940FBE6FEEA71F74C40
42644	7	67	869	52536	49383	\N	57.867440000000002	Кировская область, Муниципальное образование Сунский район, Кокуйское сельское поселение, д. Краснополье, Школьная, 6 а		0101000020E6100000CA6E66F4A3F54840029F1F4608EF4C40
42643	7	67	869	23576	49381	\N	57.812893000000003	Кировская область, Сунский район, Кокуй д., Космонавтов ул., дом 11		0101000020E61000004415FE0C6F224940DC12B9E00CE84C40
42651	7	67	869	56034	49698	\N	57.982662010908498	Кировская область, Муниципальное образование Сунский район, Большевистское сельское поселение, д. Дворища, Школьная, 22	Россия, Кировская область, Сунский район, село Дворище 1-е	0101000020E6100000F0366F9C14044940CF8250DEC7FD4C40
42650	7	67	869	52555	49275	\N	57.754565999999997	Кировская область, Муниципальное образование Сунский район, Кокуйское сельское поселение, д. Гребёнки, Центральная, 7	Россия, Кировская область, Сунский район, село Гребенки	0101000020E6100000A306D3307C0E49403656629E95E04C40
42642	7	67	869	23525	49278	\N	57.912683000000001	Кировская область, Муниципальное образование Сунский район, Большевистское сельское поселение, с. Верхосунье, Лопатина, 2		0101000020E61000009E996038D7EC4840BE4EEACBD2F44C40
42655	7	67	869	52572	49531	\N	57.804133	Кировская область, Муниципальное образование Сунский район, Кокуйское сельское поселение, д. Большие Туры, Молодёжная, 3 а		0101000020E61000008CF2CCCB61E94840335184D4EDE64C40
42549	7	67	132	6236	49372	\N	58.341003999999998	Кировская область, Свечинский район, Ацвеж с., Калинина ул., дом 3		0101000020E6100000404B57B08DE0474010E7E104A62B4D40
42641	7	67	869	23480	49157	\N	57.851514999999999	Кировская область, Муниципальное образование Сунский район, Большевистское сельское поселение, п. Большевик, переулок Центральный, 1		0101000020E6100000293C6876DD094940D7868A71FEEC4C40
42639	7	67	1676	56026	49669	\N	57.134043170066299	Кировская область, Муниципальное образование Советский район, д.Шаваржаки, Молодежная, 9, здание библиотеки	Россия, Кировская область, Советский район, село Шаваржаково	0101000020E6100000253B3602F1724840FDA02E5228914C40
42637	7	67	1676	23293	49530	\N	57.409404000000002	Кировская область, Муниципальное образование Советский район, д.Фокино, Ветеранов, 31, здание Дома культуры		0101000020E6100000F04C689258864840016DAB5967B44C40
42636	7	67	1676	23240	49265	\N	57.743595999999997	Кировская область, Муниципальное образование Советский район, с.Суводь, Лесная, 1, здание администрации  с.п		0101000020E6100000473D44A33B924840DCB75A272EDF4C40
42634	7	67	1676	22835	48879	\N	57.599615	Кировская область, Муниципальное образование Советский район, г.Советск, Советская, 84, здание МОУ ООШ №4		0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42633	7	67	1676	22835	48938	\N	57.599615	Кировская область, Муниципальное образование Советский район, г.Советск, Олега Кошевого, 10, здание МОУ СОШ с УИОП №2		0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42635	7	67	1676	22835	49101	\N	57.599615	"Кировская область, Муниципальное образование Советский район, г.Советск, Мира, 26а, здание ГОУ НПО ""Суводский ЛСТ"""		0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42631	7	67	1676	22835	48736	\N	57.5973109403512	Кировская область, Муниципальное образование Советский район, г.Советск, Ленина, 50, здание школы искусств	Россия, Кировская область, Советский район, Советск	0101000020E61000005969520ABA7D48404145D5AF74CC4C40
42628	7	67	1676	22835	48731	\N	57.599615	"Кировская область, Муниципальное образование Советский район, г.Советск, Крупской, 26, здание ГОУ СПО ""ИПК"""		0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42627	7	67	1676	22835	48750	\N	57.599615	Кировская область, Муниципальное образование Советский район, г.Советск, Красноармейская, 47, здание школы - интерната сл/сл		0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42630	7	67	1676	22835	48732	\N	57.599615	Кировская область, Муниципальное образование Советский район, г.Советск, Карла Маркса, 21, здание РДНТ		0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42632	7	67	1676	22835	48881	\N	57.599615	Кировская область, Муниципальное образование Советский район, г.Советск, Карла Либкнехта, 21, здание МОУ СОШ с УИОП №1	Россия, Кировская область, Советский район, Советск	0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42629	7	67	1676	22835	48733	\N	57.599615	Кировская область, Муниципальное образование Советский район, г.Советск, Ленина, 24, здание ГОУ лицей г.Советска		0101000020E61000005969520ABA7D484074982F2FC0CC4C40
42626	7	67	1676	22782	49590	\N	57.626823999999999	Кировская область, Муниципальное образование Советский район, с.Ситемка, Центральная, 7, здание Дома культуры		0101000020E6100000FBE59315C39F4840882CD2C43BD04C40
42625	7	67	1676	22757	48810	\N	57.571776	Кировская область, Муниципальное образование Советский район, д.Родыгино, Юбилейная, 5а, здание Дома культуры		0101000020E610000044300E2E1D774840A051BAF42FC94C40
42624	7	67	1676	22696	49365	\N	57.726832000000002	Кировская область, Муниципальное образование Советский район, с.Прозорово, Школьная, 8, здание школы		0101000020E61000006D1E87C1FCA54840D8D7BAD408DD4C40
42623	7	67	1676	56028	49675	\N	57.546435311905199	Кировская область, Муниципальное образование Советский район, пос.Новый, Фабричная, 16, здание библиотеки-клуба	Россия, Кировская область, Советский район, село Новый	0101000020E6100000103E9468C9794840E4310395F1C54C40
42622	7	67	1676	22612	49262	\N	57.354107999999997	Кировская область, Муниципальное образование Советский район, с.Муша, Советская, 9, здание школы		0101000020E610000008AA46AF067C484040A0336953AD4C40
42621	7	67	1676	22590	49676	\N	57.437452999999998	Кировская область, Муниципальное образование Советский район, с.Мокино, Кирова, 11а, здание школы		0101000020E61000005C57CC086F974840BF44BC75FEB74C40
42620	7	67	1676	22520	49527	\N	57.223103000000002	Кировская область, Муниципальное образование Советский район, д.Лошкари, Советская, 7, здание Дома культуры		0101000020E61000001971016894744840DB519CA38E9C4C40
42619	7	67	1676	22490	49525	\N	57.563696	Кировская область, Муниципальное образование Советский район, д.Лесниково, Советская, 36, здание Дома культуры		0101000020E61000003BC780ECF56248406971C63027C84C40
42618	7	67	1676	22420	48937	\N	57.418036999999998	Кировская область, Муниципальное образование Советский район, с.Колянур, Советская, 14, здание Дома культуры		0101000020E610000050A912656F6548404CC2853C82B54C40
42617	7	67	1676	22401	49524	\N	57.795302999999997	Кировская область, Муниципальное образование Советский район, д.Кожа, Советская, 8, здание Дома культуры		0101000020E61000005E85949F5475484091B41B7DCCE54C40
42616	7	67	1676	22365	49210	\N	57.193849999999998	Кировская область, Муниципальное образование Советский район, с.Кичма, Ленина, 1, здание школы		0101000020E6100000F25CDF8783764840302AA913D0984C40
42613	7	67	1676	22234	49522	\N	57.763814000000004	Кировская область, Муниципальное образование Советский район, с.Зашижемье, Молодежная, 21, здание школы		0101000020E610000095BA641C236B48400D1D3BA8C4E14C40
42536	7	67	1500	18217	49326	\N	56.958570999999999	Кировская область, Санчурский район, с. Сметанино, Центральная, 124		0101000020E610000066F84F37509847406FF25B74B27A4C40
42612	7	67	1676	22164	49656	\N	57.482097339680799	Кировская область, Муниципальное образование Советский район, д.Дуброва, Школьная, 7, здание школы	Россия, Кировская область, Советский район, село Дуброва	0101000020E61000000F09DFFB1B7E4840F73FC05AB5BD4C40
42003	7	67	1676	24482	48825	\N	57.308078999999999	Кировская область, Муниципальное образование город Киров, поселок Дороничи, Центральная, 2А		0101000020E6100000D89E5912A0764840CDCAF6216FA74C40
42611	7	67	1676	22142	49105	\N	57.593518000000003	Кировская область, Муниципальное образование Советский район, д.Грехово, Красная, 35, здание Дома культуры	Россия, Кировская область, Советский район, село Грехово	0101000020E6100000999D45EF548248402ECBD765F8CB4C40
42610	7	67	1676	22079	49496	\N	57.368264000000003	Кировская область, Муниципальное образование Советский район, д.Воробьева Гора, Школьная, 3, здание школы	Россия, Кировская область, Советский район, село Воробьева Гора	0101000020E61000001492CCEA1D924840A725564623AF4C40
42609	7	67	1676	22036	49361	\N	57.571086000000001	Кировская область, Муниципальное образование Советский район, д.Верхопижемье, Советская, 29, здание Дома культуры		0101000020E6100000662FDB4E5B7148400B9A965819C94C40
42608	7	67	1676	21988	49354	\N	57.307782000000003	Кировская область, Муниципальное образование Советский район, д.Васичи, Ленина, 2, здание Дома культуры		0101000020E61000000F48C2BE9D70484014268C6665A74C40
42606	7	67	1676	21904	49380	\N	57.730763000000003	Кировская область, Муниципальное образование Советский район, с.Васильково, Краснооктябрьская, 7, здание школы		0101000020E6100000B4E89D0AB85B48403D1059A489DD4C40
42605	7	67	1676	21832	49378	\N	57.605027996163699	Кировская область, Муниципальное образование Советский район, д.Борок, Набережная, 35, здание Дома культуры	Россия, Кировская область, Советский район, село Борок	0101000020E6100000F7764B72C05648400795B88E71CD4C40
42638	7	67	1676	23321	49529	\N	57.491262999999996	Кировская область, Муниципальное образование Советский район, д.Челка, Советская, 15, здание школы		0101000020E6100000946934B9186748400F5EBBB4E1BE4C40
42559	7	67	30	19429	49097	\N	58.631058000000003	Кировская область, Слободской район, дер. Шихово, ул. Солнечная, д.1		0101000020E61000006D7022FAB5E9484089F02F82C6504D40
42583	7	67	30	20712	9925	\N	58.932203999999999	Кировская область, Слободской район, с.Шестаково, ул. Советская, д. 25	Россия, Кировская область, Слободской район, село Шестаково	0101000020E6100000F949B54FC7154940A699EE7552774D40
42582	7	67	30	20712	9925	\N	58.932203999999999	Кировская область, Слободской район,с. Шестаково, ул. Советская, д. 25		0101000020E6100000F949B54FC7154940A699EE7552774D40
42586	7	67	30	20866	49521	\N	59.052975000000004	Кировская область, Слободской район, пос. Центральный, ул.Советская, д.46		0101000020E6100000E6B1666490234940B84082E2C7864D40
42585	7	67	30	20866	49203	\N	59.052975000000004	Кировская область, Слободской район, пос. Центральный, ул. Профсоюзная, д. 11		0101000020E6100000E6B1666490234940B84082E2C7864D40
42587	7	67	30	20972	49589	\N	59.112312000000003	Кировская область, Слободской район, пос.Сухоборка, Советская, д.31		0101000020E61000006F2F698CD6FB48406479573D608E4D40
42558	7	67	30	19396	49386	\N	58.546078000000001	Кировская область, Слободской район, дер. Сунцовы, ул. Набережная, д.44		0101000020E61000000F45813E91ED4840558847E2E5454D40
42571	7	67	30	19943	48806	\N	58.719602999999999	Кировская область, Слободской район, дер. Стулово, ул. Трактовая, д.33А		0101000020E6100000D27135B22B1349403F8D7BF31B5C4D40
42570	7	67	30	19943	48806	\N	58.719602999999999	Кировская область, Слободской район, дер. Стулово, ул. Трактовая, д.43		0101000020E6100000D27135B22B1349403F8D7BF31B5C4D40
42569	7	67	30	19943	48806	\N	58.719602999999999	Кировская область, Слободской район, дер.Стулово, ул. Трактовая, д. 42	Россия, Кировская область, Слободской район, село Стулово	0101000020E6100000D27135B22B1349403F8D7BF31B5C4D40
42580	7	67	30	20602	49586	\N	58.773643999999997	Кировская область, Слободской район, дер. Стеклофилины, ул. Заводская, д.8		0101000020E61000009CE1067C7E1A4940915F3FC406634D40
42581	7	67	30	6534	49585	\N	58.853527	Кировская область, Слободской район, с.Совье, Молодежная ул., дом 2		0101000020E610000069AB92C83EF6484062A06B5F406D4D40
42577	7	67	30	20434	49151	\N	58.644078999999998	Кировская область, Слободской район, дер.Светозарево, ул.Молодежная, д.1		0101000020E6100000B3B3E89D0A2E49402B85402E71524D40
42572	7	67	30	20148	49202	\N	58.749814000000001	Кировская область, Слободской район, дер.Салтыки, ул.Молодежная, д.9		0101000020E61000008A5759DB142749409E0AB8E7F95F4D40
42576	7	67	30	6452	49518	\N	58.551265999999998	Кировская область, Слободской район, с. Роговое, Советская ул., дом 20		0101000020E61000005D16139B8F5D4940C8B260E28F464D40
42574	7	67	30	6342	49201	\N	58.854844	Кировская область, Слободской район, п. Октябрьский, Ленина ул., дом 20		0101000020E610000092E86514CB374940469737876B6D4D40
42557	7	67	30	19322	49580	\N	58.681395999999999	Кировская область, Слободской район, дер. Митино, ул.Санаторная, д. 2		0101000020E61000008EE9094B3CE8484007D0EFFB37574D40
42584	7	67	30	20845	49523	\N	59.035274000000001	Кировская область, Слободской район, с.Лекма, ул. Профсоюзная, д.12		0101000020E610000022A7AFE76BFA48401633C2DB83844D40
41851	7	67	30	61182	77488	\N	58.549852453821899	Кировская область, Муниципальное образование город Кирово-Чепецк, пр.Мира, 52	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E61000000116F9F543084940F2D1E28C61464D40
42163	7	67	30	61182	77492	\N	58.550026742936602	Кировская область, Муниципальное образование город Кирово-Чепецк, пр.Кирова, 8	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E6100000D47E6B274A0849406075E44867464D40
42524	7	67	1500	17458	49096	\N	56.939745000000002	Кировская область, Санчурский район, пгт Санчурск, Яранская, 3		0101000020E61000005ED6C4025F9F47402ECA6C9049784C40
42150	7	67	30	61182	77473	\N	58.5485962145382	Кировская область, Муниципальное образование город Кирово-Чепецк, проезд Лермонтова, 3А	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E6100000520E661360084940B45BCB6438464D40
42175	7	67	30	61182	77496	\N	58.5499818782502	Кировская область, Муниципальное образование город Кирово-Чепецк, пр.Кирова, 1	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E6100000D47E6B274A084940C0B167CF65464D40
42153	7	67	30	61182	77507	\N	58.550206201105901	Кировская область, Муниципальное образование город Кирово-Чепецк, пр.Кирова, 27	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E6100000D8B628B341084940100874266D464D40
42170	7	67	30	61182	77512	\N	58.550166506580503	Кировская область, Муниципальное образование город Кирово-Чепецк, Мелиораторов, 1	Россия, Кировская область, Слободской район, Кирово-Чепецк	0101000020E6100000027E8D2441084940522B4CDF6B464D40
42578	7	67	30	20507	49208	\N	58.620198000000002	Кировская область, Слободской район, с.Карино, ул. К.Маркса, д.14		0101000020E6100000EA944737C22A4940B685E7A5624F4D40
42573	7	67	30	20169	48877	\N	58.779446999999998	Кировская область, Слободской район, с. Ильинское, ул. Набережная, д.9		0101000020E6100000624D6551D83749408FFB56EBC4634D40
42560	7	67	30	19495	49199	\N	58.650958000000003	Кировская область, Слободской район, дер. Зониха, ул. Труда, д. 2		0101000020E6100000018750A566F14840E8887C9752534D40
42575	7	67	30	6447	49520	\N	58.615281000000003	Кировская область, Слободской район, с.Закаринье, Советская ул., дом 10		0101000020E61000001FBB0B94144A4940D36C1E87C14E4D40
42579	7	67	30	20564	49207	\N	58.761273000000003	Кировская область, Слободской район, дер.Денисовы, ул. Советская, д.7		0101000020E6100000E6B2D1393F114940F629C76471614D40
42562	7	67	30	1746	49351	\N	58.639367999999997	Кировская область, Слободской район, с.Волково, Верхняя ул., дом 27а		0101000020E6100000E0DA899290FC4840F10D85CFD6514D40
42564	7	67	30	19524	48932	\N	58.684147000000003	Кировская область, Слободской район, пгт Вахруши, пер.Школьный, д.2		0101000020E610000034DB15FA600349400954FF2092574D40
42568	7	67	30	19524	48805	\N	58.684147000000003	Кировская область, Слободской район, пгт Вахруши, ул. Ленина, д. 1		0101000020E610000034DB15FA600349400954FF2092574D40
42565	7	67	30	19524	48805	\N	58.684147000000003	Кировская область, Слободской район, пгт Вахруши, ул. Ленина, д.9		0101000020E610000034DB15FA600349400954FF2092574D40
42561	7	67	30	19524	48805	\N	58.684147000000003	Кировская область, Слободской район, пгт Вахруши, ул.Ленина, д. 78		0101000020E610000034DB15FA600349400954FF2092574D40
42566	7	67	30	19524	48725	\N	58.684147000000003	Кировская область, Слободской район, пгт Вахруши, ул. Горького, д. 1		0101000020E610000034DB15FA600349400954FF2092574D40
42567	7	67	30	19524	48726	\N	58.684147000000003	Кировская область, Слободской район, пгт Вахруши, ул. Ленина, д.4		0101000020E610000034DB15FA600349400954FF2092574D40
42563	7	67	30	19626	\N	\N	58.603636999999999	Кировская область, Слободской район, пос. Боровица, д. 37		0101000020E61000007C9C69C2F6F94840E9D32AFA434D4D40
42556	7	67	30	19227	49519	\N	58.702427	Кировская область, Слободской район, с. Бобино, ул. Советская, д.6		0101000020E6100000452E3883BFE14840E869C020E9594D40
42555	7	67	30	19227	49238	\N	58.702427	Кировская область, Слободской район, с. Бобино, ул. Мира, д. 18 А		0101000020E6100000452E3883BFE14840E869C020E9594D40
42547	7	67	132	6305	49340	\N	58.266798000000001	Кировская область, Свечинский район, Юма с., Коммуны ул., дом 18	Россия, Кировская область, Свечинский район, село Юма	0101000020E610000024F0879FFFCA4740B151D66F26224D40
42548	7	67	132	1740	49296	\N	58.259990000000002	Кировская область, Свечинский район, Шмелево дер., Свободы ул., дом 25		0101000020E6100000C22FF5F3A6E64740BEA4315A47214D40
42554	7	67	132	5914	49154	\N	58.537187000000003	Кировская область, Свечинский район, Успенское с., Кооперативная ул., дом 3Б		0101000020E6100000C0081A3389C647400E6B2A8BC2444D40
42541	7	67	132	294	48876	\N	58.278505447788497	Кировская область, Свечинский район, Свеча пгт, Свободы ул., дом 6	Россия, Кировская область, Свечинский район, поселок Свеча	0101000020E610000038BEF6CC92C04740E162450DA6234D40
42542	7	67	132	294	48724	\N	58.288040000000002	Кировская область, Свечинский район, пгт Свеча, Привокзальная, 8		0101000020E6100000695721E527C147404DF8A57EDE244D40
42543	7	67	132	294	49335	\N	58.2812181276609	Кировская область, Свечинский район, Свеча пгт, Мира ул., дом 12	Россия, Кировская область, Свечинский район, поселок Свеча	0101000020E61000001A51DA1B7CC34740F58590F3FE234D40
42544	7	67	132	6138	49673	\N	58.274309000000002	Кировская область, Свечинский район, Самоулки дер., Труда ул., дом 1А		0101000020E61000003CF88903E8BD4740CEFFAB8E1C234D40
42545	7	67	132	6020	49346	\N	58.327894000000001	Кировская область, Свечинский район, Рыбаковщина дер., Механизаторов ул., дом 16		0101000020E61000005C3E92921EC24740FE463B6EF8294D40
42551	7	67	132	6012	49099	\N	58.436396999999999	Кировская область, Свечинский район, Рига дер., Советская ул., дом 1		0101000020E610000045D4449F8FE2474048895DDBDB374D40
42550	7	67	132	5187	49348	\N	58.405928000000003	Кировская область, Свечинский район, Октябрьское с., Советская ул., дом 32		0101000020E61000004260E5D022CD4740EE43DE72F5334D40
42552	7	67	132	5930	49581	\N	58.503613000000001	Кировская область, Свечинский район, Круглыжи с., Советская ул., дом 46		0101000020E610000016A4198BA6D54740946B0A6476404D40
42546	7	67	132	6109	49526	\N	58.398251000000002	Кировская область, Свечинский район, Ивановское с., Мира ул., дом 4	Россия, Кировская область, Свечинский район, село Ивановское	0101000020E610000012A0A696ADB54740B64C86E3F9324D40
42079	7	67	132	4868	48856	\N	58.664673999999998	Кировская область, Муниципальное образование город Киров, поселок Ганино, школьный переулок, 18		0101000020E6100000271422E010CA47403140A20914554D40
42553	7	67	132	5834	49376	\N	58.468274999999998	Кировская область, Свечинский район, Благовещенское с., Центральная ул., дом 10		0101000020E610000068CBB91457BF47406744696FF03B4D40
42523	7	67	1500	17458	49152	\N	56.939745000000002	Кировская область, Санчурский район, пгт Санчурск, Свердлова, 69		0101000020E61000005ED6C4025F9F47402ECA6C9049784C40
42522	7	67	1500	17458	48930	\N	56.939745000000002	Кировская область, Санчурский район, пгт Санчурск, Ленина, 46		0101000020E61000005ED6C4025F9F47402ECA6C9049784C40
42521	7	67	1500	17458	48931	\N	56.939745000000002	Кировская область, Санчурский район, пгт Санчурск, Зевахина, 2		0101000020E61000005ED6C4025F9F47402ECA6C9049784C40
42538	7	67	1500	18317	49576	\N	56.944688999999997	Кировская область, Санчурский район, д. Мельниково, Центральная, 1		0101000020E6100000310917F2088E47400AF2B391EB784C40
42534	7	67	1500	18152	49215	\N	57.064976999999999	Кировская область, Санчурский район, с. Матвинур, Школьная, 2		0101000020E6100000E2E6543200B8474000FF942A51884C40
42528	7	67	1500	17854	49517	\N	57.074607	Кировская область, Санчурский район, с. Марийская Лиса, Заречная, 4		0101000020E61000005B785E2A36A04740BE86E0B88C894C40
42532	7	67	1500	18057	49284	\N	56.967243000000003	Кировская область, Санчурский район, с. Люмпанур, Школьная, 7		0101000020E610000028B517D1766C474079245E9ECE7B4C40
42535	7	67	1500	18193	49369	\N	57.032908999999997	Кировская область, Санчурский район, д. Люй, Лесная, 24		0101000020E61000008E59F624B0C747403D5FB35C36844C40
42537	7	67	1500	18283	49371	\N	57.020319000000001	Кировская область, Санчурский район, с. Кувшинское, Приозерная, 6		0101000020E6100000A4AB74779D934740643E20D099824C40
42529	7	67	1500	17894	49153	\N	57.106140000000003	Кировская область, Санчурский район, с. Корляки, Дзержинского, 4		0101000020E61000006F675F79907647401366DAFE958D4C40
42525	7	67	1500	17689	49205	\N	56.951970000000003	Кировская область, Санчурский район, с. Городище, Школьная, 13		0101000020E6100000F818AC38D5A44740F6622827DA794C40
42527	7	67	1500	17776	49367	\N	57.002215999999997	Кировская область, Санчурский район, с.Галицкое, Свободы, 9а		0101000020E61000002B155454FDA8474093C3279D48804C40
42533	7	67	1500	18067	49368	\N	56.994076999999997	Кировская область, Санчурский район, с. Вотчина, Советская, 3		0101000020E6100000030AF5F4117A4740575A46EA3D7F4C40
42526	7	67	1500	56012	\N	\N	56.979323176083803	Кировская область, Санчурский район, д.Большой Ихтиал	Россия, Кировская область, Санчурский район, село Большой Ихтаил	0101000020E610000034BC5983F7B947403D9CC0745A7D4C40
42539	7	67	1500	18379	\N	\N	56.893259	Кировская область, Санчурский район, д. Большая Шишовка, 54	Россия, Кировская область, Санчурский район, село Большая Шишовка	0101000020E6100000D4F02DAC1BA34740C8ED974F56724C40
42530	7	67	1500	17935	49375	\N	57.056857999999998	Кировская область, Санчурский район, д. Большая Поломка, Речная, 1а		0101000020E61000008C81751C3F7847400B42791F47874C40
42540	7	67	1500	18452	49377	\N	56.907238999999997	Кировская область, Санчурский район, с. Алексеиха, Школьная, 3		0101000020E6100000D7DF12807FB04740EF53556820744C40
42505	7	67	122	2100	49373	\N	60.219223999999997	Кировская область, Подосиновский район, Яхреньга село, Мира ул., дом 39		0101000020E6100000CEE0EF17B3754740C83F33880F1C4E40
42515	7	67	122	61192	\N	\N	60.219092930547397	Кировская область, Муниципальное образование Подосиновский район, Щеткинское сельское поселение, МОУ основная общеобразовательная школа	Россия, Кировская область, Подосиновский район, село Щеткино	0101000020E61000009AED0A7DB0B647402AE44A3D0B1C4E40
42513	7	67	122	61188	\N	\N	60.4447096269895	Кировская область, Муниципальное образование Подосиновский район, Шолгское сельское поселение, администрация поселения	Россия, Кировская область, Подосиновский район, село Шолга	0101000020E6100000B9AB5791D17F4740221ADD41EC384E40
42506	7	67	122	16662	\N	\N	60.171931999999998	Кировская область, Муниципальное образование Подосиновский район, п Ровдино, административное здание		0101000020E61000004B5645B8C9684740649126DE01164E40
42504	7	67	122	16662	\N	\N	60.171931999999998	Кировская область, Муниципальное образование Подосиновский район, п. Ровдино, административное здание		0101000020E61000004B5645B8C9684740649126DE01164E40
42508	7	67	122	55991	48968	\N	60.279931890147402	Кировская область, Муниципальное образование Подосиновский район, Подосиновское городское поселение, Боровая, 6	Россия, Кировская область, Подосиновский район, поселок Подосиновец	0101000020E6100000E8A221E3518847404C8DD0CFD4234E40
42510	7	67	122	55989	48961	\N	60.251193999999998	Кировская область, Муниципальное образование Подосиновский район, Пинюгское городское поселение, Индустриальная, 19	Россия, Кировская область, Подосиновский район, поселок Пинюг	0101000020E6100000261B0FB6D8E34740C879FF1F27204E40
42519	7	67	122	246	49280	\N	60.466630000000002	Кировская область, Подосиновский район, Лунданка пос., Мира ул, дом 18 (администрация Лунданкского с/п)		0101000020E6100000F833BC5983BD47408FAA2688BA3B4E40
42514	7	67	122	61198	\N	\N	60.469606442012299	Кировская область, Муниципальное образование Подосиновский район, Зареченское сельское поселение, МОУ основная общеобразовательная школа	Россия, Кировская область, Подосиновский район, село Заречье	0101000020E61000005C936E4BE4844740B000A60C1C3C4E40
42512	7	67	122	55995	49086	\N	60.375693264433203	Кировская область, Муниципальное образование Подосиновский район, Демьяновское городское поселение, Школьная, 5	Россия, Кировская область, Подосиновский район, село Демьяново	0101000020E6100000F4177AC4E8834740062B4EB516304E40
42520	7	67	122	61187	\N	\N	60.406024195577501	Кировская область, Муниципальное образование Подосиновский район, Верхнемалье сельское поселение, начальная школа-детский сад	Россия, Кировская область, Подосиновский район, поселок Верхнемалье	0101000020E6100000BC7669C361C3474010B22C98F8334E40
42494	7	67	1426	16146	49408	\N	57.346668999999999	Кировская область, Пижанский район, с. Сретенское, Труда, 2		0101000020E6100000105A0F5F26524840BDC458A65FAC4C40
42500	7	67	1426	16431	49516	\N	57.330280000000002	Кировская область, Пижанский район, д. Русская Шуйма, Молодежная, 15		0101000020E610000019FF3EE3C22B4840EE42739D46AA4C40
42490	7	67	1426	15893	48803	\N	57.460191000000002	Кировская область, Пижанский район, пгт. Пижанка, Труда, 27		0101000020E610000011A62897C6434840EF74E789E7BA4C40
42489	7	67	1426	15893	48720	\N	57.460191000000002	Кировская область, Пижанский район, пгт. Пижанка, Заречная, 45		0101000020E610000011A62897C6434840EF74E789E7BA4C40
42502	7	67	1426	16524	48926	\N	57.529775999999998	Кировская область, Пижанский район, д. Павлово, Октябрьская, 8		0101000020E6100000CA1B60E63B364840541A31B3CFC34C40
42501	7	67	1426	16494	49198	\N	57.574513000000003	Кировская область, Пижанский район, д. Обухово, Коммуны, 7		0101000020E6100000C0081A33894E48403D1059A489C94C40
42492	7	67	1426	16020	49279	\N	57.414231999999998	Кировская область, Пижанский район, ,д. Мари-Ошаево, Северная, 3		0101000020E61000009487855AD33E4840747ADE8D05B54C40
42491	7	67	1426	15994	49277	\N	57.389696000000001	Кировская область, Пижанский район, д. Кашнур, Черемушки, 1		0101000020E6100000310917F208524840E6B0FB8EE1B14C40
42496	7	67	1426	16235	49276	\N	57.314324999999997	Кировская область, Пижанский район, д. Второй Ластик, Советская, 42 а		0101000020E61000001FDB32E02C39484058A835CD3BA84C40
42498	7	67	1426	16317	49363	\N	57.233801999999997	Кировская область, Пижанский район, с. Казаково, Мира, 1		0101000020E61000005E2C0C91D3534840A4DE5339ED9D4C40
42497	7	67	1426	16285	49149	\N	57.284235000000002	Кировская область, Пижанский район, с. Воя, Школьная, 19		0101000020E610000093ACC3D15546484075B0FECF61A44C40
42509	7	67	1426	56005	49382	\N	57.538291618562802	Кировская область, Муниципальное образование Подосиновский район, деревня Борок, Центральная, 50	Россия, Кировская область, Пижанский район, село Борок	0101000020E6100000D673D2FBC637484066D993C0E6C44C40
42499	7	67	1426	16405	48722	\N	57.421706	Кировская область, Пижанский район, д. Безводное, Школьная, 7		0101000020E61000008CDB68006F2B484074435376FAB54C40
42493	7	67	1426	16100	49407	\N	57.365758999999997	Кировская область, Пижанский район, д. Ахманово, Советская, 5		0101000020E61000007104A9143B404840DC9BDF30D1AE4C40
42479	7	67	789	15429	49405	\N	58.681902000000001	Кировская область, Орловский район, д.Шадричи, Мира, 14а		0101000020E6100000A25D85949F4E4840DB89929048574D40
42487	7	67	789	15791	49570	\N	58.826360999999999	Кировская область, Орловский район, с.Чудиново, Заречная, 12		0101000020E610000089618731E98748404DD87E32C6694D40
42486	7	67	789	15741	49232	\N	58.727074000000002	Кировская область, Орловский район, д.Цепели, Мира, 6		0101000020E6100000297B4B395F984840CEE2C5C2105D4D40
42477	7	67	789	5604	49270	\N	58.631920000000001	Кировская область, Орловский район, Тохтино с., Кирова ул., дом 22 (Советская ул, дом 2)		0101000020E61000006CB587BD504248401BD82AC1E2504D40
42483	7	67	789	15596	49636	\N	58.707605999999998	Кировская область, Орловский район, д.Степановщина, Новая, 6б		0101000020E610000065E1EB6B5D684840083A5AD5925A4D40
42481	7	67	789	15458	49406	\N	58.726322000000003	Кировская область, Орловский район, д.Солоницыны, Молодежная, 5	Россия, Кировская область, Орловский район, село Солоницыны	0101000020E6100000D192C7D3F2474840C32E8A1EF85C4D40
42467	7	67	789	14848	\N	\N	58.780197999999999	Кировская область, Орловский район, с.Соловецкое, 58		0101000020E610000011C4793881674840CA332F87DD634D40
42478	7	67	789	15382	49273	\N	58.616655000000002	Кировская область, Орловский район, с.Русаново, Советская, 25		0101000020E6100000A2CF4719715B48401BF5108DEE4E4D40
42476	7	67	789	15274	49269	\N	58.559600000000003	Кировская область, Орловский район, д.Поляки, Советская, 8		0101000020E6100000A7ECF483BA564840BA6B09F9A0474D40
42473	7	67	789	14931	48874	\N	58.540151000000002	Кировская область, Орловский район, г.Орлов, Строителей, 20		0101000020E6100000FF976BD1027248406BF3FFAA23454D40
42470	7	67	789	14931	48723	\N	58.540151000000002	Кировская область, Орловский район, г.Орлов, Ст.Халтурина, 36		0101000020E6100000FF976BD1027248406BF3FFAA23454D40
42469	7	67	789	14931	48723	\N	58.540151000000002	Кировская область, Орловский район, г.Орлов, Ст.Халтурина, 2	Россия, Кировская область, Орловский район, Орлов	0101000020E6100000FF976BD1027248406BF3FFAA23454D40
42471	7	67	789	14931	48927	\N	58.540151000000002	Кировская область, Орловский район, г.Орлов, Ленина, 57	Россия, Кировская область, Орловский район, Орлов	0101000020E6100000FF976BD1027248406BF3FFAA23454D40
42474	7	67	789	15156	49404	\N	58.527583999999997	Кировская область, Орловский район, д.Моржи, Мира, 1		0101000020E61000009FABADD85F6C484049F25CDF87434D40
42485	7	67	789	15702	49143	\N	58.661107000000001	Кировская область, Орловский район, д.Кузнецы, Школьная, 10		0101000020E610000097AC8A70938348400E1478279F544D40
42484	7	67	789	15654	\N	\N	58.843397000000003	Кировская область, Орловский район, Коробовщина дер., помещение Б-Юринского клуба муниципального казенного учреждения Центр культуры и досуга Чудиновского сельского поселения	Россия, Кировская область, Орловский район, село Коробовщина	0101000020E610000056F487669E744840B345D26EF46B4D40
42482	7	67	789	15577	49514	\N	58.641092	Кировская область, Орловский район, с.Колково, Шубина, 1		0101000020E61000005CE509849D74484016DD7A4D0F524D40
42442	7	67	1245	13644	\N	\N	58.476095999999998	Кировская область, Оричевский район, пос. Юбилейный, 32		0101000020E6100000D1CB28965B9A4840D2E0B6B6F03C4D40
42451	7	67	1245	14081	49266	\N	58.331442000000003	Кировская область, Оричевский район, с. Шалегово, Труда, 1		0101000020E610000036CCD07822744840AB4203B16C2A4D40
42450	7	67	1245	14019	49565	\N	58.339219	Кировская область, Оричевский район, дер. Усовы, Советская, 18	Россия, Кировская область, Оричевский район, село Усовы	0101000020E6100000810871E5EC9F4840469737876B2B4D40
42449	7	67	1245	13986	48801	\N	58.491598000000003	Кировская область, Оричевский район, пос. Торфяной, Юбилейная, 17		0101000020E6100000990CC7F3199A4840B763EAAEEC3E4D40
42448	7	67	1245	13930	49264	\N	58.069133000000001	Кировская область, Оричевский район, пос. Суводи, Ленина, 18		0101000020E6100000518369183E4448408509A359D9084D40
33298	4	41	\N	16582	46265	\N	48.779257999999999	г. Биробиджан, Волочаевская, 41		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
42466	7	67	1245	14733	49194	\N	58.463647999999999	Кировская область, Оричевский район, пгт Стрижи, Рабочая, 37		0101000020E6100000F790F0BDBFA148408B6D52D1583B4D40
42468	7	67	1245	14733	48872	\N	58.463647999999999	Кировская область, Оричевский район, пгт Стрижи, Комсомольская, 26		0101000020E6100000F790F0BDBFA148408B6D52D1583B4D40
42465	7	67	1245	14733	49150	\N	58.463647999999999	Кировская область, Оричевский район, пгт Стрижи, Кирова, 11а		0101000020E6100000F790F0BDBFA148408B6D52D1583B4D40
42447	7	67	1245	13894	49263	\N	58.404305999999998	Кировская область, Оричевский район, с. Спас-Талица, Советская, 12		0101000020E6100000EFE6A90EB97F4840CDC98B4CC0334D40
42445	7	67	1245	13795	49211	\N	58.323408999999998	Кировская область, Оричевский район, с. Пустоши, Старосельская, 9		0101000020E6100000E9297288B8834840B41D537765294D40
42444	7	67	1245	13728	49515	\N	58.234281000000003	Кировская область, Оричевский район, с. Пищалье, Школьная, 6	Россия, Кировская область, Оричевский район, село Пищалье	0101000020E6100000A510C8258E5A48407F8978EBFC1D4D40
42443	7	67	1245	13688	49400	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, Якимовой, 18		0101000020E61000007461A417B5874840555051F52B334D40
42460	7	67	1245	13688	48924	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, Юбилейная, 1а	Россия, Кировская область, Оричевский район, поселок Оричи	0101000020E61000007461A417B5874840555051F52B334D40
42463	7	67	1245	13688	48799	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, Молодая Гвардия, 32		0101000020E61000007461A417B5874840555051F52B334D40
42462	7	67	1245	13688	48799	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, Молодая Гвардия, 63		0101000020E61000007461A417B5874840555051F52B334D40
42459	7	67	1245	13688	49200	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, Комсомольская, 57а		0101000020E61000007461A417B5874840555051F52B334D40
42458	7	67	1245	13688	49200	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, Комсомольская, 3	Россия, Кировская область, Оричевский район, поселок Оричи	0101000020E61000007461A417B5874840555051F52B334D40
42461	7	67	1245	13688	48719	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, Карла Маркса, 22		0101000020E61000007461A417B5874840555051F52B334D40
42464	7	67	1245	13688	49098	\N	58.399779000000002	Кировская область, Оричевский район, пгт Оричи, 40 лет Победы, 13	Россия, Кировская область, Оричевский район, поселок Оричи	0101000020E61000007461A417B5874840555051F52B334D40
42446	7	67	1245	13824	49401	\N	58.233030999999997	Кировская область, Оричевский район, с. Монастырщина, Советская, 18		0101000020E6100000C8242367616D484022FAB5F5D31D4D40
42457	7	67	1245	55979	48962	\N	58.305352233046897	Кировская область, Оричевский район, пгт Мирный, Степана Халтурина, 35	Россия, Кировская область, Оричевский район, поселок Мирный	0101000020E6100000BE4A3E761752484054E23AC615274D40
42456	7	67	1245	55979	48804	\N	58.306346149637598	Кировская область, Оричевский район, пгт Мирный, Радченко, 23	Россия, Кировская область, Оричевский район, поселок Мирный	0101000020E6100000BBF083F3A951484055A1815836274D40
42441	7	67	1245	13611	49147	\N	58.209018999999998	Кировская область, Оричевский район, дер. Кучелапы, Советская, 22		0101000020E6100000DFE1766858BA48400E9F7422C11A4D40
42440	7	67	1245	13555	48922	\N	58.210019000000003	Кировская область, Оричевский район, с. Коршик, Почтовая, 8		0101000020E61000004CFA7B293CA44840F24410E7E11A4D40
42436	7	67	1245	13357	\N	\N	58.262258000000003	"Кировская область, Оричевский район, пос. Колос, спальный корпус ООО ""Санаторий Колос"""		0101000020E61000002D99637957C34840A48E8EAB91214D40
42439	7	67	1245	13519	49193	\N	58.415652999999999	Кировская область, Оричевский район, с. Истобенск, Степана Халтурина, 13		0101000020E61000006C21C84109654840FDBD141E34354D40
42438	7	67	1245	13457	49197	\N	58.497678999999998	Кировская область, Оричевский район, пос. Зенгино, Комсомольская, 6		0101000020E6100000927538BA4A834840F7730AF2B33F4D40
42614	7	67	1245	14122	\N	\N	58.350235191338598	Кировская область, Муниципальное образование Советский район, пос.Зеленый, 15, здание психоневролог интерната	Россия, Кировская область, Оричевский район, село Зеленый	0101000020E6100000BD715298F76A484010751F80D42C4D40
42452	7	67	1245	14122	49315	\N	58.350039000000002	Кировская область, Оричевский район, пос. Зеленый, Советская, 6		0101000020E6100000412D060FD36A48408BA9F413CE2C4D40
42454	7	67	1245	14211	49402	\N	58.329146000000001	Кировская область, Оричевский район, пос. Быстряги, Советская, 4		0101000020E61000000394861A855E4840FBCDC474212A4D40
42437	7	67	1245	13412	49148	\N	58.530853999999998	Кировская область, Оричевский район, с. Быстрица, Московская, 23		0101000020E6100000DA0242EBE19B4840B3791C06F3434D40
42423	7	67	1245	12784	49237	\N	58.343313999999999	Кировская область, Оричевский район, с. Адышево, Советская, 11		0101000020E6100000D5EDEC2B0FBE4840252191B6F12B4D40
42435	7	67	1240	13326	\N	\N	59.469974000000001	Кировская область, Опаринский район, деревня Стрельская, основная общеобразовательная школа		0101000020E61000006B60AB048BE3474033FCA71B28BC4D40
42434	7	67	1240	13268	\N	\N	59.876134	Кировская область, Опаринский район, поселок Северный, здание детского сада	Россия, Кировская область, Опаринский район, поселок Северный	0101000020E6100000FA980F0874E64740F374AE2825F04D40
42433	7	67	1240	12737	\N	\N	59.8438983018426	Кировская область, Опаринский район, поселок Чурсья, основная общеобразовательная школа	Россия, Кировская область, Опаринский район, поселок Опарино	0101000020E610000094347F4C6B234840759483D904EC4D40
42422	7	67	1240	12737	48870	\N	59.849590999999997	Кировская область, Опаринский район, поселок городского типа Опарино, пер. Советский, 3		0101000020E61000003B394371C7234840EBFCDB65BFEC4D40
42432	7	67	1240	13175	\N	\N	59.848312	Кировская область, Опаринский район, деревня Нижняя Паломица, основная общеобразовательная школа		0101000020E610000009DFFB1BB4A94740F566D47C95EC4D40
42431	7	67	1240	13128	49267	\N	59.715874999999997	Кировская область, Опаринский район, с. Молома, Советская, администрация сельского поселения		0101000020E6100000DEC9A7C7B6CC47401283C0CAA1DB4D40
42430	7	67	1240	13073	49562	\N	59.947284000000003	Кировская область, Муниципальное образование Опаринский район, Опаринское городское поселение, поселок Латышский, Центральная, 14		0101000020E6100000ADF9F197161748401503249A40F94D40
42428	7	67	1240	12987	49398	\N	59.430945000000001	Кировская область, Муниципальное образование Опаринский район, Стрельское сельское поселение, поселок Верхняя Волманга, ул.Школьная, 3	Россия, Кировская область, Опаринский район, село Верхняя Волманга	0101000020E6100000A1D79FC4E7B44740F7AFAC3429B74D40
42419	7	67	769	12621	49310	\N	58.561819999999997	Кировская область, Омутнинский район, пос. Шахровка, Новая, 22		0101000020E6100000D52137C30D1A4A408E1EBFB7E9474D40
42414	7	67	769	12381	48718	\N	58.851115999999998	Кировская область, Омутнинский район, пос. Черная Холуница, Ленина, 7		0101000020E610000093E52494BEDA4940198D7C5EF16C4D40
42416	7	67	769	12445	49307	\N	58.641540999999997	Кировская область, Омутнинский район, дер. Плетеневская, Центральная, 12		0101000020E610000016A58460551B4A408505F7031E524D40
42406	7	67	769	55992	49195	\N	59.038651183130099	Кировская область, Омутнинский район, пгт Песковка, Шлаковая, 24	Россия, Кировская область, Омутнинский район, поселок Песковка	0101000020E61000002AAC5450512D4A40967A1684F2844D40
42407	7	67	769	55992	49285	\N	59.040847999999997	Кировская область, Омутнинский район, пгт Песковка, Ленина, 79	Россия, Кировская область, Омутнинский район, поселок Песковка	0101000020E61000005A9F724C162D4A40B20DDC813A854D40
42409	7	67	769	55992	48982	\N	59.040730087825203	Кировская область, Омутнинский район, пгт Песковка, Ленина, 77		0101000020E6100000E84EB0FF3A2D4A40A9FB00A436854D40
42410	7	67	769	55992	48981	\N	59.040951249663898	Кировская область, Омутнинский район, пгт Песковка, Школьная, 66	Россия, Кировская область, Омутнинский район, поселок Песковка	0101000020E6100000E57E87A2402D4A4087DEE2E13D854D40
42390	7	67	769	5413	49186	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Трудовых Резервов, 107		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42391	7	67	769	5413	48846	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Северная, 81		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42397	7	67	769	5413	49145	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Пролетарская, 25		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42399	7	67	769	5413	48867	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Кооперации, 91	Россия, Кировская область, Омутнинский район, Омутнинск	0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42339	7	67	769	5413	49184	\N	58.670488436069398	Кировская область, Омутнинский район, г.Омутнинск, Комсомольская, 18	Россия, Кировская область, Омутнинский район, Омутнинск	0101000020E6100000E275FD82DD164A40232E008DD2554D40
42392	7	67	769	5413	48951	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, ул.Коковихина, 99		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42400	7	67	769	5413	48952	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Западная, 12		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42396	7	67	769	5413	48785	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, Воровского, 3	Россия, Кировская область, Омутнинский район, Омутнинск	0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42389	7	67	769	5413	49395	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, 9 Мая, 1		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42394	7	67	769	5413	48851	\N	58.672096000000003	Кировская область, Омутнинский район, г.Омутнинск, 30 лет Победы, 22		0101000020E61000007AC7293A92174A40DFE2E13D07564D40
42393	7	67	769	5413	48851	\N	58.671650870603997	Кировская область, Омутнинский район, г.Омутнинск, 30 лет Победы, 16	Россия, Кировская область, Омутнинский район, Омутнинск	0101000020E61000003A5CAB3DEC174A40B0A9F3A8F8554D40
42405	7	67	769	11909	49358	\N	58.86251	Кировская область, Омутнинский район, пос. Метрострой, Лесная, 16		0101000020E6100000BC900E0F612A4A408A3C49BA666E4D40
42411	7	67	769	12234	48852	\N	58.99971	Кировская область, Омутнинский район, пос. Лесные Поляны, Комсомольская, 14		0101000020E61000009FE8BAF083354A40F9BD4D7FF67F4D40
42408	7	67	769	12085	49510	\N	59.126316000000003	Кировская область, Омутнинский район, пос.Котчиха, Комсомольская, 6		0101000020E6100000D9942BBCCB2B4A40147B681F2B904D40
42412	7	67	769	12289	49397	\N	58.872503999999999	Кировская область, Омутнинский район, дер. Зимино, Школьная, 25		0101000020E610000097C9703C9F314A4089D00836AE6F4D40
42417	7	67	769	12535	49196	\N	58.661251497877998	Кировская область, Омутнинский район, с. Залазна, Октябрьская, 8	Россия, Кировская область, Омутнинский район, село Залазна	0101000020E61000007B319413ED404A4041B96DDFA3544D40
42413	7	67	769	12307	49561	\N	58.709980999999999	Кировская область, Омутнинский район, дер. Ежово, Логовая, 18		0101000020E61000008BC22E8A1E2A4A4004E44BA8E05A4D40
42401	7	67	769	11741	48793	\N	58.783546999999999	Кировская область, Омутнинский район, пгт Восточный, Пионерская, 2		0101000020E6100000240B98C0AD1F4A4080F0A1444B644D40
42402	7	67	769	11741	48795	\N	58.783546999999999	Кировская область, Омутнинский район, пгт Восточный, Азина, 11		0101000020E6100000240B98C0AD1F4A4080F0A1444B644D40
42403	7	67	769	11741	48875	\N	58.783546999999999	Кировская область, Омутнинский район, пгт Восточный, 30 лет Победы, 4		0101000020E6100000240B98C0AD1F4A4080F0A1444B644D40
42404	7	67	769	11878	48853	\N	58.773927999999998	Кировская область, Омутнинский район, пос. Белореченк, П. Русских, 16		0101000020E6100000A8C64B3789254A40B6BA9C1210634D40
42418	7	67	769	12564	49146	\N	58.672783000000003	Кировская область, Омутнинский район, пос. Белорецк, Ленина, 19		0101000020E6100000703FE081013E4A400327DBC01D564D40
42377	7	67	736	10635	49508	\N	57.471401	Кировская область, Муниципальное образование Нолинский район, с.Юртик, Школьный переулок, 1а		0101000020E6100000F243A511331349409E2633DE56BC4C40
42385	7	67	736	11058	49140	\N	57.536409999999997	Кировская область, Муниципальное образование Нолинский район, с.Швариха, Советская, 40		0101000020E6100000EDBAB72231CF4840A99F3715A9C44C40
42388	7	67	736	11119	49509	\N	57.532094999999998	Кировская область, Нолинский район, Хмелевка д., Луговая ул., дом 2		0101000020E6100000DA73999A04BB4840BCAE5FB01BC44C40
42384	7	67	736	10942	49139	\N	57.814653	Кировская область, Муниципальное образование Нолинский район, с.Татаурово, Большевиков, 17		0101000020E61000009E95B4E21BC848404D4BAC8C46E84C40
42380	7	67	736	10752	49141	\N	57.546472000000001	Кировская область, Муниципальное образование Нолинский район, д.Рябиновщина, Строителей, 21		0101000020E6100000E3C3EC65DBF34840011764CBF2C54C40
42383	7	67	736	56002	49320	\N	57.531633549585699	Кировская область, Муниципальное образование Нолинский район, п.Птицефабрики, Шварихинское шоссе, 1	Россия, Кировская область, Нолинский район, село Птицефабрика	0101000020E610000084F068E388ED484088B839950CC44C40
42379	7	67	736	10698	49093	\N	57.556362	Кировская область, Муниципальное образование Нолинский район, д.Перевоз, Советская, 46а	Россия, Кировская область, Нолинский район, село Перевоз	0101000020E6100000E12538F5810049405B5EB9DE36C74C40
42369	7	67	736	10116	48869	\N	57.558529999999998	Кировская область, Муниципальное образование Нолинский район, г.Нолинск, Фрунзе, 51		0101000020E610000077D9AF3BDDF74840DDEA39E97DC74C40
42368	7	67	736	10116	48947	\N	57.558529999999998	Кировская область, Муниципальное образование Нолинский район, г.Нолинск, Спартака, 36		0101000020E610000077D9AF3BDDF74840DDEA39E97DC74C40
42367	7	67	736	10116	48844	\N	57.558529999999998	Кировская область, Муниципальное образование Нолинский район, г.Нолинск, Ленина, 11в		0101000020E610000077D9AF3BDDF74840DDEA39E97DC74C40
42376	7	67	736	10553	48845	\N	57.387259999999998	Кировская область, Муниципальное образование Нолинский район, п.Медведок, Герцена, 76		0101000020E6100000A626C11BD2044940448655BC91B14C40
42374	7	67	736	10477	49360	\N	57.730898000000003	Кировская область, Муниципальное образование Нолинский район, с.Лудяна, Советская, 9		0101000020E6100000C45DBD8A8CDA48401D5BCF108EDD4C40
42372	7	67	736	10383	49138	\N	57.642251999999999	Кировская область, Муниципальное образование Нолинский район, с.Кырчаны, Полевая, 7		0101000020E61000006CEA3C2AFE13494032E5435035D24C40
42373	7	67	736	5126	49505	\N	57.856332000000002	Кировская область, Нолинский район, Карачи д., Коммуны ул., дом 1		0101000020E6100000EF7211DF89C74840574277499CED4C40
42375	7	67	736	5266	49356	\N	57.693060000000003	Кировская область, Нолинский район, Верхоишеть с., Школьная ул., дом 2	Россия, Кировская область, Нолинский район, село Верхоишеть	0101000020E61000006138D73043BD48403815A930B6D84C40
42382	7	67	736	10847	49507	\N	57.486711	Кировская область, Муниципальное образование Нолинский район, д.Варнаки, Зеленая, 61/2		0101000020E610000004E8F7FD9BE548403ECDC98B4CBE4C40
42381	7	67	736	5275	49635	\N	57.483972999999999	Кировская область, Нолинский район, Ботыли с., Школьная ул., дом 1А		0101000020E6100000863AAC70CBEF4840D192C7D3F2BD4C40
42370	7	67	736	10264	48847	\N	57.283067000000003	Кировская область, Муниципальное образование Нолинский район, п.Аркуль, Заводская, 15		0101000020E610000053EBFD463B064940D6C9198A3BA44C40
42025	7	67	7390	55993	48991	\N	58.521282999999997	Кировская область, город Киров, Нововятский район, мкр. Радужный, ул. Конституции, 17		0101000020E61000008C81751C3FDA4840FA7ABE66B9424D40
42366	7	67	733	10076	49651	\N	57.657474999999998	Кировская область, Муниципальное образование Немский район, село Соколово, Центральная, 7		0101000020E6100000E3C4573B8A33494003780B2428D44C40
42365	7	67	733	10045	49387	\N	57.552889999999998	Кировская область, Муниципальное образование Немский район, деревня Слудка, Школьная, 12		0101000020E610000061360186E553494089247A19C5C64C40
42364	7	67	733	5108	48727	\N	57.505389999999998	Кировская область, Муниципальное образование Немский район, Немское городское поселение, пгт.Нема, Советская, 42		0101000020E610000035B401D880404940DBDC989EB0C04C40
42363	7	67	733	5108	48727	\N	57.505389999999998	Кировская область, Муниципальное образование Немский район, Немское городское поселение, пгт.Нема, Советская, 31		0101000020E610000035B401D880404940DBDC989EB0C04C40
42362	7	67	733	5108	49359	\N	57.505389999999998	Кировская область, Немский район, Нема пос., Набережная ул., дом 26		0101000020E610000035B401D880404940DBDC989EB0C04C40
42361	7	67	733	9813	\N	\N	57.560837999999997	Кировская область, Муниципальное образование Немский район, село Марково, Юбилейная, 10	Россия, Кировская область, Немский район, село Марково	0101000020E61000000150C58D5B6A4940512D228AC9C74C40
42360	7	67	733	9774	49353	\N	57.617666999999997	Кировская область, Муниципальное образование Немский район, село Колобово, переулок Советский, 1		0101000020E6100000D9D138D4EF504940C26856B60FCF4C40
42359	7	67	733	61367	78894	\N	57.741942000000002	Кировская область, Муниципальное образование Немский район, Ильинское сельское поселение, советская, 34	Россия, Кировская область, Немский район, село Ильинское	0101000020E6100000789ACC785B334940B1C398F4F7DE4C40
42358	7	67	733	9676	49671	\N	57.693334999999998	Кировская область, Муниципальное образование Немский район, деревня Городище, переулок Центральный, 2	Россия, Кировская область, Немский район, село Городище	0101000020E610000092CA14731024494009168733BFD84C40
42357	7	67	733	9600	49506	\N	57.56317	Кировская область, Муниципальное образование Немский район, село Васильевское, Школьная, 6		0101000020E610000083F92B64AE2649404E0B5EF415C84C40
42356	7	67	733	61365	78875	\N	57.635299000000003	Кировская область, Муниципальное образование Немский район, Архангельское сельское поселение, улица Молодежная, 44а	Россия, Кировская область, Немский район, село Архангельское	0101000020E6100000698EACFC321849403C17467A51D14C40
42343	7	67	449	52092	\N	\N	59.179385000000003	Кировская область, Муниципальное образование Нагорский район, Чеглаковское сельское поселение, д.Шевырталово, Дом культуры	Россия, Кировская область, Нагорский район, село Шевырталово	0101000020E610000044C4CDA9645A49404D327216F6964D40
42354	7	67	449	9445	48790	\N	59.711233	Кировская область, Нагорский район, Синегорье село, Октябрьская ул., дом 34		0101000020E6100000A741D13C80594940016BD5AE09DB4D40
42353	7	67	449	9433	\N	\N	59.606147	Кировская область, Муниципальное образование Нагорский район, Синегорское сельское поселение, п.Первомайск, Здание школы	Россия, Кировская область, Нагорский район, село Первомайск	0101000020E61000007D7A6CCB80494940C5C8923996CD4D40
42350	7	67	449	9302	\N	\N	59.751418999999999	Кировская область, Муниципальное образование Нагорский район, Кобринское сельское поселение, п.Орлецы	Россия, Кировская область, Нагорский район, село Орлецы	0101000020E6100000F7AC6BB41C884940E84B6F7F2EE04D40
42345	7	67	449	52099	\N	\N	59.426926999999999	Кировская область, Муниципальное образование Нагорский район, Мулинское сельское поселение, д.Назаровцы, Дом культуры		0101000020E6100000CA3159DC7F7E4940C3633F8BA5B64D40
42338	7	67	449	8569	48866	\N	59.320872999999999	Кировская область, Муниципальное образование Нагорский район, Нагорское городское поселение, пгт.Нагорск, Советская, 169		0101000020E6100000E65DF58079664940AF95D05D12A94D40
42337	7	67	449	8569	48866	\N	59.320872999999999	Кировская область, Муниципальное образование Нагорский район, Нагорское городское поселение, пгт.Нагорск, Советская, 183		0101000020E6100000E65DF58079664940AF95D05D12A94D40
42336	7	67	449	8569	48866	\N	59.320872999999999	Кировская область, Муниципальное образование Нагорский район, Нагорское городское поселение, пгт.Нагорск, Советская, 37		0101000020E6100000E65DF58079664940AF95D05D12A94D40
42340	7	67	449	8569	49633	\N	59.320872999999999	Кировская область, Муниципальное образование Нагорский район, Чеглаковское сельское поселение, пгт.Нагорск, Механизаторов, 2		0101000020E6100000E65DF58079664940AF95D05D12A94D40
42334	7	67	449	8569	48791	\N	59.320872999999999	Кировская область, Муниципальное образование Нагорский район, Нагорское городское поселение, пгт.Нагорск, Леушина, 21		0101000020E6100000E65DF58079664940AF95D05D12A94D40
42346	7	67	449	9115	49355	\N	59.334443	Кировская область, Нагорский район, Мулино село, Советская ул., дом 14		0101000020E6100000DC9DB5DB2E74494025B03907CFAA4D40
42347	7	67	449	2546	\N	\N	59.277096999999998	Кировская область, Нагорский район, Липовое поселок, здание школы	Россия, Кировская область, Нагорский район, село Липовое	0101000020E610000011AB3FC230824940EC681CEA77A34D40
42351	7	67	449	52106	\N	\N	59.509653	Кировская область, Муниципальное образование Нагорский район, Синегорское сельское поселение, д,Липовка, Дом культуры		0101000020E6100000062B4EB51664494076A73B4F3CC14D40
42352	7	67	449	9365	49393	\N	59.591729000000001	Кировская область, Нагорский район, Крутой Лог поселок, Советская ул., д.2		0101000020E610000022FFCC203E644940228C9FC6BDCB4D40
42344	7	67	449	52095	\N	\N	59.545817999999997	Кировская область, Муниципальное образование Нагорский район, Мулинское сельское поселение, д.Качонки, Библиотека		0101000020E6100000983446EBA8AC4940B8C83D5DDDC54D40
42342	7	67	449	8944	\N	\N	59.160170999999998	Кировская область, Муниципальное образование Нагорский район, Чеглаковское сельское поселение, с.Заево, Дом культуры	Россия, Кировская область, Нагорский район, село Заево	0101000020E610000064575A46EA4749404162BB7B80944D40
42348	7	67	449	9200	49503	\N	59.479695999999997	Кировская область, Нагорский район, Бажелка поселок, Ленина ул., дом 28		0101000020E610000080643A747A084940D102B4AD66BD4D40
42323	7	67	942	8035	\N	\N	59.604720999999998	Кировская область, Мурашинский муниципальный район, п.Тылай, Клуб - филиал		0101000020E610000000C63368E86F48402A1A6B7F67CD4D40
42324	7	67	942	56023	49660	\N	59.6284625544832	Кировская область, Мурашинский муниципальный район, п.Староверческий, Первомайская (МОКУ основная общеобразовательная школа), 5		0101000020E6100000A0353FFED24E48407FDFBF7971D04D40
42328	7	67	942	8278	\N	\N	59.192259999999997	Кировская область, Мурашинский муниципальный район, д.Пермята, клуб-филиал	Россия, Кировская область, Мурашинский район, село Пермята	0101000020E610000026DF6C73633448401B2AC6F99B984D40
42329	7	67	942	8353	\N	\N	59.253599999999999	Кировская область, Мурашинский муниципальный район, с.Паломохино, МУК сельский Дом культуры с Паломохино	Россия, Кировская область, Мурашинский район, село Паломохино	0101000020E6100000A1F5F065A22A4840FF21FDF675A04D40
42320	7	67	942	7854	49190	\N	59.442740999999998	Кировская область, Мурашинский муниципальный район, п.Октябрьский, Футбольная (МОКУ Средняя общеобразовательная школа ), 2а		0101000020E61000005E2A36E67572484096CCB1BCABB84D40
42319	7	67	942	7854	49231	\N	59.442740999999998	Кировская область, Мурашинский муниципальный район, п. Октябрьский, Коммунистическая (МУК Октябрьский сельский Дом культуры), 5		0101000020E61000005E2A36E67572484096CCB1BCABB84D40
42333	7	67	942	7625	\N	\N	59.395760000000003	Кировская область, Мурашинский муниципальный район, г.Мураши, п.Новый, помещение ФАП	Россия, Кировская область, Мурашинский район, Мураши	0101000020E6100000981936CAFA7D484051888043A8B24D40
42331	7	67	942	7625	\N	\N	59.395760000000003	Кировская область, Мурашинский муниципальный район, г.Мураши, д.Шленники, Здание Дома ветеранов	Россия, Кировская область, Мурашинский район, Мураши	0101000020E6100000981936CAFA7D484051888043A8B24D40
42318	7	67	942	7625	48784	\N	59.395760000000003	Кировская область, Мурашинский муниципальный район, г.Мураши, Халтурина (МОКУ СОШ им.С.С.Ракитиной), 51		0101000020E6100000981936CAFA7D484051888043A8B24D40
42316	7	67	942	7625	48864	\N	59.395760000000003	Кировская область, Мурашинский муниципальный район, г. Мураши, Пионерская (МОКУ средняя общеобразовательная школа № 2), 37		0101000020E6100000981936CAFA7D484051888043A8B24D40
42317	7	67	942	7625	48954	\N	59.395760000000003	Кировская область, Мурашинский муниципальный район, г.Мураши, К.Маркса (Здание администрации района), 28	Россия, Кировская область, Мурашинский район, Мураши	0101000020E6100000981936CAFA7D484051888043A8B24D40
42325	7	67	942	8145	\N	\N	59.087795	Кировская область, Мурашинский муниципальный район, с.Казаковщина, клуб-филиал		0101000020E6100000CFF9298E033B48404CE0D6DD3C8B4D40
42332	7	67	942	8494	\N	\N	59.407696999999999	Кировская область, Мурашинский муниципальный район, д.Даниловка, МОКУ начальная общеобразовательная школа		0101000020E6100000D026874F3A8D4840B2D6506A2FB44D40
42330	7	67	942	8376	\N	\N	59.324987	Кировская область, Мурашинский муниципальный район, с.Верхораменье, Здание администрации	Россия, Кировская область, Мурашинский район, село Верхораменье	0101000020E61000007A8CF2CCCB3F484005508C2C99A94D40
42327	7	67	942	8242	\N	\N	59.124363000000002	Кировская область, Мурашинский муниципальный район, с.Боровица, Здание администрации	Россия, Кировская область, Мурашинский район, село Боровица	0101000020E61000000261A758353248408EEA7420EB8F4D40
42269	7	67	942	8242	\N	\N	59.124200755658499	Кировская область, Муниципальное образование Лузский район, п. Боровица	Россия, Кировская область, Мурашинский район, село Боровица	0101000020E6100000EC4FE27327324840B49080D1E58F4D40
42321	7	67	942	7915	48850	\N	59.509694000000003	Кировская область, Мурашинский муниципальный район, п.Безбожник, Почтовая (МОКУ Средняя общеобразовательная школа), 38		0101000020E610000093A9825149674840D57B2AA73DC14D40
42322	7	67	942	7915	48787	\N	59.509694000000003	Кировская область, Мурашинский муниципальный район, п. Безбожник, Первомайская (МУК Безбожниковский сельский Дом культуры ), 9		0101000020E610000093A9825149674840D57B2AA73DC14D40
42304	7	67	808	7143	49192	\N	56.652481999999999	Кировская область , Малмыжский район , с.Тат-Верх-Гоньба, Мира, 36б		0101000020E6100000DAFE9595263B4940459DB98784534C40
42303	7	67	808	7103	49136	\N	56.559170999999999	Кировская область, Малмыжский район, с.Старый Ирюк, Садовая, 2		0101000020E6100000E692AAED2648494091EF52EA92474C40
42289	7	67	808	6441	49630	\N	56.419880999999997	Кировская область , Малмыжский район , д.Старый Буртек, Школьная, 3		0101000020E6100000390EBC5AEE6649401B9B1DA9BE354C40
42283	7	67	808	6116	49500	\N	56.385666000000001	Кировская область , Малмыжский район , с.Старый Бурец, Центральная, 4а		0101000020E61000000BD0B69A75724940EE96E4805D314C40
42305	7	67	808	7200	49091	\N	56.745699999999999	Кировская область, Малмыжский район, с.Старая Тушка, Набережная, 16		0101000020E610000015E29178794049404850FC18735F4C40
42301	7	67	808	7008	48841	\N	56.535496999999999	Кировская область, Малмыжский район , с.Савали, Октябрьская, 79		0101000020E6100000B685E7A562514940950D6B2A8B444C40
42299	7	67	808	6913	48840	\N	56.681610999999997	Кировская область, Малмыжский район, с.Рожки, Молодежная, Здание средней школы		0101000020E6100000B40419011542494003CC7C073F574C40
42297	7	67	808	6827	49350	\N	56.651615999999997	Кировская область, Малмыжский район, с.Ральники, Школьная, 4а		0101000020E6100000B398D87C5C0F494071C6302768534C40
42293	7	67	808	6646	49357	\N	56.458423000000003	Кировская область , Малмыжский район , д.Преображенка, Шахтерская, 3		0101000020E6100000FC6EBA6587804940FB5DD89AAD3A4C40
42296	7	67	808	6765	\N	\N	56.641331999999998	Кировская область , Малмыжский район , д.Порез, Здание начальной школы	Россия, Кировская область, Малмыжский район, село Порез	0101000020E610000052651877832049406BF0BE2A17524C40
42680	7	67	808	6765	49294	\N	56.641631361158503	Кировская область, Муниципальное образование Унинский район, с. Порез, Ленина, 24	Россия, Кировская область, Малмыжский район, село Порез	0101000020E610000060066344A2204940C58CF0F620524C40
42295	7	67	808	6737	49229	\N	56.823045	Кировская область , Малмыжский район , пос.Плотбище, Советская, 27	Россия, Кировская область, Малмыжский район, село Плотбище	0101000020E61000003D7E6FD39F4749407311DF8959694C40
42288	7	67	808	6334	49182	\N	56.512067000000002	Кировская область , Малмыжский район , д.Пахотная, Большая, здание конторы		0101000020E61000001310937021594940302E55698B414C40
42294	7	67	808	6666	48862	\N	56.400478999999997	Кировская область , Малмыжский район , с.Новая Смаиль, Школьная, 2		0101000020E6100000EC18575C1C5549400DDE57E542334C40
42284	7	67	808	6131	49501	\N	56.599474000000001	Кировская область , Малмыжский район , д.Новый Кокуй, Школьная, 6	Россия, Кировская область, Малмыжский район, село Новый Кокуй	0101000020E6100000DC291DACFF854940B2666490BB4C4C40
42302	7	67	808	7032	49352	\N	56.604132	Кировская область, Малмыжский район, д.Новый Ирюк, Центральная, 18		0101000020E6100000E8BF07AF5D484940C93B8732544D4C40
42291	7	67	808	6531	49632	\N	56.652492000000002	Кировская область, Малмыжский район , д.Мелеть, Юбилейная, 4	Россия, Кировская область, Малмыжский район, село Мелеть	0101000020E6100000A1681EC02267494069739CDB84534C40
42292	7	67	808	6556	49181	\N	56.500348000000002	Кировская область , Малмыжский район , с.Мари-Малмыж, Школьная, 32		0101000020E6100000E738B709F76E49403C4F3C670B404C40
42281	7	67	808	6011	49305	\N	56.354956000000001	Кировская область, Малмыжский район , д.Малый Китяк, Центральная, 48		0101000020E61000001094DBF63D6249406EC2BD326F2D4C40
42307	7	67	808	7316	48842	\N	56.519644999999997	Кировская область , город Малмыж, Чернышевского, 3		0101000020E61000004ACFF41263594940D44334BA83424C40
42310	7	67	808	7316	49233	\N	56.519644999999997	Кировская область, город Малмыж, Тимирязева, 6		0101000020E61000004ACFF41263594940D44334BA83424C40
42313	7	67	808	7316	48863	\N	56.519644999999997	Кировская область, город Малмыж, Лесная, 7а	Россия, Кировская область, Малмыжский район, Малмыж	0101000020E61000004ACFF41263594940D44334BA83424C40
42312	7	67	808	7316	48843	\N	56.519644999999997	Кировская область , город Малмыж, Комсомольская, 18		0101000020E61000004ACFF41263594940D44334BA83424C40
42309	7	67	808	7316	49228	\N	56.519644999999997	Кировская область , город Малмыж, К-Маркса, 7		0101000020E61000004ACFF41263594940D44334BA83424C40
42290	7	67	808	6451	49347	\N	56.686956000000002	Кировская область , Малмыжский район , с.Константиновка, пер.Школьный, 3		0101000020E61000001EDE7360397049403FE5982CEE574C40
42306	7	67	808	7250	49631	\N	56.789366999999999	Кировская область, Малмыжский район, д.Кинерь, Школьная, 15		0101000020E61000004FB2D5E5943A494054C554FA09654C40
42287	7	67	808	6243	48839	\N	56.505057999999998	Кировская область , Малмыжский район, с.Калинино, Пролетарская, 92		0101000020E6100000C79E3D97A9514940A54A94BDA5404C40
42286	7	67	808	6243	48839	\N	56.505057999999998	Кировская область, Малмыжский район , с.Калинино, Пролетарская, 57		0101000020E6100000C79E3D97A9514940A54A94BDA5404C40
42285	7	67	808	6225	49628	\N	56.530821000000003	Кировская область , Малмыжский район , с.Каксинвай, Молодежная, 21		0101000020E6100000DD442DCDAD8E4940D88349F1F1434C40
42300	7	67	808	6962	49349	\N	56.594791000000001	Кировская область , Малмыжский район , с.Гоньба, пер.Мирный, 3а		0101000020E61000009ED32CD0EE584940427A8A1C224C4C40
42279	7	67	808	5916	49499	\N	56.526006000000002	Кировская область, Малмыжский район , д.Большой Сатнур, Зеленая, 18		0101000020E610000042226DE34F784940F9BF232A54434C40
42280	7	67	808	5932	49627	\N	56.340719	Кировская область , Малмыжский район , с.Большой Китяк, Тишина, 11а		0101000020E61000004B75012F336049401B1021AE9C2B4C40
42278	7	67	808	5839	49135	\N	56.589939000000001	Кировская область, Малмыжский район, д.Арык, Школьная, 6		0101000020E61000009A7CB3CD8D69494046D1031F834B4C40
42277	7	67	808	5762	49227	\N	56.739114999999998	Кировская область , Малмыжский район ,с.Аджим, Советская, 15а		0101000020E6100000931B45D61A224940D47D00529B5E4C40
42211	7	67	412	47793	\N	\N	60.900551	Лузский р-н, п. Христофорово, Первомайская ул., д.35, здание администрации Христофоровского сельского поселения	Россия, Кировская область, Лузский район, поселок Христофорово	0101000020E61000000E2C47C840A04740A7B0524145734E40
42270	7	67	412	5422	\N	\N	60.654107000000003	Кировская область, Муниципальное образование Лузский район, с. Учка	Россия, Кировская область, Лузский район, село Учка	0101000020E6100000711E4E603ADD4740D78A36C7B9534E40
42266	7	67	412	5192	\N	\N	60.384152999999998	Кировская область, Муниципальное образование Лузский район, п. Уга	Россия, Кировская область, Лузский район, село Уга	0101000020E61000000DE2033BFE2D484084D4EDEC2B314E40
42255	7	67	412	4624	\N	\N	60.955396999999998	Кировская область, Муниципальное образование Лузский район, д. Сирино	Россия, Кировская область, Лузский район, село Сирино	0101000020E6100000B6A1629CBFE5474027D9EA724A7A4E40
42268	7	67	412	5285	\N	\N	60.587868	Кировская область, Муниципальное образование Лузский район, д. Папулово	Россия, Кировская область, Лузский район, село Папулово	0101000020E610000018CDCAF621034840B62E35423F4B4E40
42259	7	67	412	4840	49295	\N	60.649168000000003	Кировская область, Муниципальное образование Лузский район, д. Озерская, Озерная, 26	Россия, Кировская область, Лузский район, село Озерская	0101000020E6100000033FAA61BF9747400CCEE0EF17534E40
42276	7	67	412	4539	49189	\N	60.622920000000001	Кировская область, Муниципальное образование Лузский район, город Луза, О.Кошевого, 13	Россия, Кировская область, Лузский район, Луза	0101000020E61000004A287D21E4A047401D03B2D7BB4F4E40
42274	7	67	412	4539	48836	\N	60.622920000000001	Кировская область, Муниципальное образование Лузский район, город Луза, Маяковского, 52		0101000020E61000004A287D21E4A047401D03B2D7BB4F4E40
42275	7	67	412	4539	49224	\N	60.622920000000001	Кировская область, Муниципальное образование Лузский район, город Луза, З. Космодемьянской, 21а		0101000020E61000004A287D21E4A047401D03B2D7BB4F4E40
42273	7	67	412	4539	48837	\N	60.622920000000001	Кировская область, Муниципальное образование Лузский район, город Луза, В. Козлова, 7		0101000020E61000004A287D21E4A047401D03B2D7BB4F4E40
42262	7	67	412	4943	\N	\N	60.733719999999998	Кировская область, Муниципальное образование Лузский район, пгт Лальск, Фабричная, 12	Россия, Кировская область, Лузский район, поселок Лальск	0101000020E61000000C3CF71E2ECB4740E7357689EA5D4E40
42261	7	67	412	4943	48950	\N	60.733719999999998	Кировская область, Муниципальное образование Лузский район, пгт Лальск, Набережный переулок, 8		0101000020E61000000C3CF71E2ECB4740E7357689EA5D4E40
42263	7	67	412	4943	49142	\N	60.733719999999998	Кировская область, Муниципальное образование Лузский район, пгт Лальск, Клубная, 6	Россия, Кировская область, Лузский район, поселок Лальск	0101000020E61000000C3CF71E2ECB4740E7357689EA5D4E40
42260	7	67	412	4874	\N	\N	60.623987999999997	Кировская область, Муниципальное образование Лузский район, д. Каравайково	Россия, Кировская область, Лузский район, село Каравайково	0101000020E61000001B48179B56944740588CBAD6DE4F4E40
42256	7	67	412	4686	\N	\N	60.844150999999997	Кировская область, Муниципальное образование Лузский район, д. Животово	Россия, Кировская область, Лузский район, село Животово	0101000020E6100000FA449E245DD747405EF1D4230D6C4E40
42258	7	67	412	4779	\N	\N	60.663313000000002	Кировская область, Муниципальное образование Лузский район, д. Ефаново	Россия, Кировская область, Лузский район, село Ефаново	0101000020E61000006F29E78BBDA947407E01BD70E7544E40
42264	7	67	412	5100	\N	\N	60.705894999999998	Кировская область, Муниципальное образование Лузский район, д. Аксеновская	Россия, Кировская область, Лузский район, село Аксеновская	0101000020E61000009A249694BBF9474078B471C45A5A4E40
42265	7	67	412	56036	\N	\N	60.470819952582403	Кировская область, Муниципальное образование Лузский район, д. Андреева Гора	Россия, Кировская область, Лузский район, село Адреева Гора	0101000020E610000004763579CA184840C0266BD4433C4E40
42252	7	67	575	4448	49681	\N	57.330692999999997	Кировская область, Лебяжский район, с. Синцово, Центральная ул., дом 5		0101000020E61000001781B1BE819F48401002F22554AA4C40
42245	7	67	575	4088	49668	\N	57.419564000000001	Кировская область, Лебяжский район, д. Редькино, Центральная ул., дом 2а		0101000020E6100000BC3E73D6A7C048401B4AED45B4B54C40
42251	7	67	575	4399	49680	\N	57.337032000000001	Кировская область, Лебяжский район, п. Окунево, Советская ул., дом 1		0101000020E61000008A5759DB14AF48404DDA54DD23AB4C40
42250	7	67	575	4341	49677	\N	57.372805999999997	Кировская область, Лебяжский район, д. Михеевщина, Производственная ул., дом 5		0101000020E6100000CEA78E554AC1484054E0641BB8AF4C40
42249	7	67	575	4262	49679	\N	57.382491999999999	Кировская область, Лебяжский район, с. Мелянда, Молодежная ул., дом 5		0101000020E610000083893F8A3AD54840A67D737FF5B04C40
42236	7	67	575	3589	\N	\N	57.291263999999998	Кировская область, Лебяжский район, д. Мари-Байса, дом 18	Россия, Кировская область, Лебяжский район, село Мари-Байса	0101000020E61000000858AB764DD648404640852348A54C40
42243	7	67	575	3967	49672	\N	57.244765999999998	Кировская область, Лебяжский район, д. Малый Рын, Центральная ул., дом 8а		0101000020E6100000B2A19BFD81BE48401C96067E549F4C40
42253	7	67	575	56030	49689	\N	57.415793541398699	Кировская область, Лебяжский район, пгт. Лебяжье, Комсомольская ул., дом 4	Россия, Кировская область, Лебяжский район, поселок Лебяжье	0101000020E61000009CA6CF0EB8C24840BFEFDFBC38B54C40
42248	7	67	575	4226	49683	\N	57.191986999999997	Кировская область, Лебяжский район, с. Лаж, Советская ул., дом 31		0101000020E6100000F19E03CB119E4840EA20AF0793984C40
42246	7	67	575	4093	49682	\N	57.051116	Кировская область, Лебяжский район, с. Кузнецово, Мира ул., дом 32		0101000020E6100000DE76A1B94EA14840B32616F88A864C40
42244	7	67	575	3977	49667	\N	57.465398999999998	Кировская область, Лебяжский район, с. Красное, Центральная ул., дом 43а		0101000020E6100000AA0A0DC4B2BD4840A94BC63192BB4C40
42242	7	67	575	3877	49688	\N	57.250681999999998	Кировская область, Лебяжский район, д. Кокорево, Северная ул., дом 14		0101000020E6100000FA9AE5B2D1C7484012D9075916A04C40
42241	7	67	575	3874	49685	\N	57.123607	Кировская область, Лебяжский район, д. Индыгойка, Полевая ул., дом 3		0101000020E6100000B003E78C28B548404147AB5AD28F4C40
42240	7	67	575	3799	49684	\N	57.157901000000003	Кировская область, Лебяжский район, д. Изиморка, Центральная ул., дом 9б	Россия, Кировская область, Лебяжский район, село Изиморка	0101000020E61000005395B6B8C6B34840BB80971936944C40
42387	7	67	575	56004	49362	\N	57.080628242826101	Кировская область, Муниципальное образование Нолинский район, с.Зыково, Октябрьская, 1	Россия, Кировская область, Лебяжский район, село Зыково	0101000020E61000006CB07092E6A748402992AF04528A4C40
42239	7	67	575	3759	49666	\N	57.453741000000001	Кировская область, Лебяжский район, д.Елькино, Новая ул., дом 4		0101000020E6100000B41F2922C3AC48405BED612F14BA4C40
42238	7	67	575	3710	49686	\N	57.325454999999998	Кировская область, Лебяжский район, д. Елизарово, Черемушки ул., дом 15		0101000020E61000000E677E3507C44840EBA86A82A8A94C40
42237	7	67	575	3679	49664	\N	57.343677	Кировская область, Лебяжский район, с. Вотское, Тополиная ул., дом 2		0101000020E61000007D2079E750E8484096B1A19BFDAB4C40
42235	7	67	575	3582	49670	\N	57.290849999999999	Кировская область, Лебяжский район, с. Ветошкино, Свободы ул., дом 43		0101000020E6100000EB8F300C58DC48405305A3923AA54C40
42247	7	67	575	4198	\N	\N	57.213025000000002	Кировская область, Лебяжский район, д. Васичи, дом 33		0101000020E6100000D0ECBAB722A948407E1D3867449B4C40
42225	7	67	414	3006	49626	\N	58.041184999999999	Кировская область, Куменский район, с. Рябиново, Молодежная, 2а	Россия, Кировская область, Куменский район, село Рябиново	0101000020E610000028603B18B1E14840FA0AD28C45054D40
42226	7	67	414	3047	49222	\N	58.288083	Кировская область, Куменский район, п. Речной, Ленина, 8		0101000020E610000032E4D87A86E848404CC45BE7DF244D40
42218	7	67	414	2560	49624	\N	58.165818000000002	Кировская область, Куменский район, д. Плотники, Октябрьская, 18		0101000020E61000003CA583F57FF44840488B338639154D40
42214	7	67	414	2340	49370	\N	58.135404000000001	Кировская область, Куменский район, д. Парфеновщина, Мира, 2	Россия, Кировская область, Куменский район, село Парфеновщина	0101000020E6100000787AA52C43FC4840B1DF13EB54114D40
42227	7	67	414	3097	49223	\N	58.265396000000003	Кировская область, Куменский район, п. Олимпийский, Мира, 1		0101000020E6100000E59997C3EEE948409F3E027FF8214D40
42232	7	67	414	3396	49241	\N	58.19547	Кировская область, Куменский район, пгт Нижнеивкино, Октябрьский, 7		0101000020E61000001E17D522A2C24840B0AC342905194D40
42233	7	67	414	3396	48776	\N	58.19547	Кировская область, Куменский район, пгт. Нижнеивкино, Курортная, 1		0101000020E61000001E17D522A2C24840B0AC342905194D40
42231	7	67	414	3357	49385	\N	58.052259999999997	Кировская область, Куменский район, д. Моряны, Труда, 2	Россия, Кировская область, Куменский район, село Моряны	0101000020E6100000A0FF1EBC76F34840C971A774B0064D40
42228	7	67	414	3164	48833	\N	58.104902000000003	Кировская область, Куменский район, пгт. Кумены, Поселковая, 10		0101000020E6100000352905DD5EF648407BA4C16D6D0D4D40
33283	4	41	\N	16582	46225	\N	48.779257999999999	г. Биробиджан, Бумагина, 5 А		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
42230	7	67	414	3164	48775	\N	58.104902000000003	Кировская область, Куменский район, пгт Кумены, Гагарина, 49		0101000020E6100000352905DD5EF648407BA4C16D6D0D4D40
42229	7	67	414	3164	48775	\N	58.104902000000003	Кировская область, Куменский район, пгт. Кумены, Гагарина, 20		0101000020E6100000352905DD5EF648407BA4C16D6D0D4D40
42221	7	67	414	2776	48774	\N	58.157077000000001	Кировская область, Куменский район, п. Краснооктябрьский, Краснооктябрьская, 6а	Россия, Кировская область, Куменский район, село Краснооктябрьский	0101000020E61000003A2174D02516494016FA60191B144D40
42216	7	67	414	2448	49379	\N	58.043585999999998	Кировская область, Куменский район, д.Желны, Новая, 22		0101000020E6100000309FAC18AE3C49401F48DE3994054D40
42219	7	67	414	2663	49178	\N	58.158197999999999	Кировская область, Куменский район, с. Вожгалы, Заречная, 9а		0101000020E61000000C3B8C497F194940742502D53F144D40
42217	7	67	414	2541	48860	\N	58.194611999999999	Кировская область, Куменский район, п. Вичевщина, Северихина, 33		0101000020E61000003BFBCA83F40A49405FB4C70BE9184D40
42215	7	67	414	2436	49498	\N	58.082929999999998	Кировская область, Куменский район, с. Верхобыстрица, Хохрякова, 23		0101000020E61000003CF6B3588A2E4940BBED42739D0A4D40
42224	7	67	414	2911	49287	\N	58.120989999999999	Кировская область, Куменский район, с. Быково, Советская, 13		0101000020E61000004981053065D848404F92AE997C0F4D40
42213	7	67	414	2326	49260	\N	58.083824999999997	Кировская область, Куменский район, д. Большой Перелаз, Советская, 22		0101000020E6100000D1CB28965B02494029CB10C7BA0A4D40
42212	7	67	414	2214	49634	\N	58.052922000000002	Кировская область, Куменский район, с. Березник, Юбилейная, 8		0101000020E610000048C2BE9D444E4940959EE925C6064D40
42223	7	67	414	2214	49282	\N	58.052922000000002	Кировская область, Куменский район, д. Березник, Центральный, 6		0101000020E610000048C2BE9D444E4940959EE925C6064D40
42222	7	67	414	2791	49271	\N	58.077190999999999	Кировская область, Куменский район, с. Бельтюги, Клубная, 5		0101000020E6100000FF243E77821F4940D4450A65E1094D40
42234	7	67	414	3486	49092	\N	58.203428000000002	Кировская область, Куменский район, д. Барановщина, Новая, 7		0101000020E6100000613596B036C848409C8BBFED091A4D40
42220	7	67	414	2678	49261	\N	58.146183000000001	Кировская область, Куменский район, д. Ардашиха, Дружбы, 1		0101000020E610000011E335AFEA1C4940971DE21FB6124D40
42199	7	67	110	1509	\N	\N	58.446739999999998	Кировская область, Котельничский район, с.Юрьево, здание МОУ СОШ с.Юрьево	Россия, Кировская область, Котельничский район, село Юрьево	0101000020E6100000D2AA96749445484053E8BCC62E394D40
42198	7	67	110	1408	\N	\N	58.502090000000003	Кировская область, Котельничский район, п.Юбилейный, здание МУК Юбилейный Дворец культуры	Россия, Кировская область, Котельничский район, село Юбилейный	0101000020E610000039B69E211C1D484007D3307C44404D40
42197	7	67	110	1392	\N	\N	58.446966000000003	Кировская область, Котельничский район, д.Шалеевщина, здание МОУ ООШ д.Шалеевщина	Россия, Кировская область, Котельничский район, село Шалеевщина	0101000020E6100000C7A17E17B60A48404436902E36394D40
42196	7	67	110	1309	\N	\N	57.865808000000001	Кировская область, Котельничский район, с.Чистополье, здание МОУ ООШ с.Чистополье	Россия, Кировская область, Котельничский район, село Чистополье	0101000020E61000004DDC2A8881F24740BE4EEACBD2EE4C40
42195	7	67	110	1260	\N	\N	58.628669000000002	Кировская область, Котельничский район, с.Сретенье, здание МУК Центр досуга и библиотечного обслуживания	Россия, Кировская область, Котельничский район, село Сретенье	0101000020E6100000FEB968C8780648402881CD3978504D40
42193	7	67	110	1162	\N	\N	58.686915999999997	Кировская область, Котельничский район, с.Спасское, здание ООШ с.Спасское	Россия, Кировская область, Котельничский район, село Спасское	0101000020E6100000D508FD4CBD284840B08C0DDDEC574D40
42192	7	67	110	1062	\N	\N	58.081207999999997	Кировская область, Котельничский район, п.Светлый, здание МОУ Отворская СОШ	Россия, Кировская область, Котельничский район, поселок Светлый	0101000020E6100000889CBE9EAFCB474037161406650A4D40
42185	7	67	110	52760	\N	\N	58.295462000000001	Кировская область, Котельничский район, д.Роминская, помещение Роминского ФАП	Россия, Кировская область, Котельничский район, село Роминская	0101000020E6100000E0A0BDFA78184840FA9AE5B2D1254D40
42191	7	67	110	1033	\N	\N	58.250804000000002	Кировская область, Котельничский район, д.Родичи, здание МОУ ООШ д.Родичи	Россия, Кировская область, Котельничский район, село Родичи	0101000020E61000003C4A253CA11748405EDA70581A204D40
42190	7	67	110	945	\N	\N	58.201957999999998	Кировская область, Котельничский район, с.Покровское, здание МОУ СОШ с.Покровское	Россия, Кировская область, Котельничский район, село Покровское	0101000020E610000099B855100319484031957EC2D9194D40
42188	7	67	110	819	\N	\N	58.424816	Кировская область, Котельничский район, с.Молотниково, здание МОУ ООШ с.Молотниково	Россия, Кировская область, Котельничский район, село Молотниково	0101000020E610000068D0D03FC1234840A568E55E60364D40
42187	7	67	110	808	\N	\N	58.575969999999998	Кировская область, Котельничский район, с.Макарье, здание МУК Центр досуга и библиотечного обслуживания	Россия, Кировская область, Котельничский район, село Макарье	0101000020E6100000B935E9B64416484012BD8C62B9494D40
42178	7	67	110	185	\N	\N	58.331012000000001	Кировская область, Котельничский район, п.Ленинская Искра, здание МОУ Спицинская общеобразовательная школа	Россия, Кировская область, Котельничский район, село Ленинская Искра	0101000020E610000092CF2B9E7A364840B24AE9995E2A4D40
42134	7	67	1887	30529	48828	\N	58.505813000000003	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Пасегово, ул.Школьная, д.15		0101000020E6100000994869368FC148402272FA7ABE404D40
42202	7	67	110	1636	\N	\N	58.584902	Кировская область, Котельничский район, Курино село, здание администрации Макарьевского сельского поселения	Россия, Кировская область, Котельничский район, село Курино	0101000020E6100000821FD5B0DF314840B8AE9811DE4A4D40
42186	7	67	110	703	\N	\N	58.474750999999998	Кировская область, Котельничский район, с.Красногорье, здание ООШ с.Красногорье	Россия, Кировская область, Котельничский район, село Красногорье	0101000020E61000007500C45DBD324840245F09A4C43C4D40
42183	7	67	110	558	\N	\N	58.179985000000002	Кировская область, Котельничский район, п.Комсомольский, здание МОУ СОШ п.Комсомольский	Россия, Кировская область, Котельничский район, село Комсомольский	0101000020E6100000C9E4D4CE30014840A2629CBF09174D40
42201	7	67	110	1627	\N	\N	58.095689999999998	Кировская область, Котельничский район, Козловаж село, здание администрации Комсомольского сельского поселения	Россия, Кировская область, Котельничский район, село Козловаж	0101000020E61000002A70B20DDCF74740F146E6913F0C4D40
42182	7	67	110	442	\N	\N	58.327075999999998	Кировская область, Котельничский район, п.Карпушино, здание администрации сельского поселения	Россия, Кировская область, Котельничский район, село Карпушино	0101000020E6100000A911FA997A0D48403BA759A0DD294D40
42184	7	67	110	581	\N	\N	58.281529999999997	Кировская область, Котельничский район, д.Караул, здание администрации Котельничского сельского поселения	Россия, Кировская область, Котельничский район, село Караул	0101000020E61000009AEAC9FCA3254840E36BCF2C09244D40
42181	7	67	110	435	\N	\N	58.343828999999999	Кировская область, Котельничский район, д.Зайцевы, здание МОУ основная общеобразовательная школа д.Зайцевы	Россия, Кировская область, Котельничский район, село Зайцевы	0101000020E61000006FD921FE612148404C35B396022C4D40
42200	7	67	110	1525	\N	\N	58.381245999999997	Кировская область, Котельничский район, Екатерина село, здание администрации Карпушинского сельского поселения	Россия, Кировская область, Котельничский район, село Екатерина	0101000020E6100000B8CD5488470848408BDD3EABCC304D40
42180	7	67	110	321	\N	\N	58.080641999999997	Кировская область, Котельничский район, ст.Ежиха, здание администрации сельского поселения	Россия, Кировская область, Котельничский район, поселок Ежиха	0101000020E61000000EA0DFF76FDA47408E57207A520A4D40
42179	7	67	110	301	\N	\N	58.081921999999999	Кировская область, Котельничский район, с.Вишкиль, здание администрации сельского поеселения	Россия, Кировская область, Котельничский район, село Вишкиль	0101000020E61000000F7C0C569C28484055698B6B7C0A4D40
42189	7	67	110	926	\N	\N	57.947181	Кировская область, Котельничский район, с.Боровка, здание МУК Центр досуга и библиотечного обслуживания	Россия, Кировская область, Котельничский район, село Боровка	0101000020E610000070EA03C93B2B484040321D3A3DF94C40
42177	7	67	110	161	\N	\N	58.264246	Кировская область, Котельничский район, с.Александровское, здание начальной школы с.Александровское	Россия, Кировская область, Котельничский район, село Александровское	0101000020E6100000FB7953910AFB4740A60C1CD0D2214D40
41829	7	67	110	161	49513	\N	58.264444473257001	Кировская область, Даровский район, с.Александровское, Кооперативная, 16	Россия, Кировская область, Котельничский район, село Александровское	0101000020E610000014ED2AA4FCFA4740CCCF0D4DD9214D40
42005	7	67	7389	55972	48768	\N	58.547162	Кировская область, Муниципальное образование город Киров, поселок Чистые Пруды, Советская, 2		0101000020E6100000BCCE86FC33D1484096CE876709464D40
42144	7	67	1887	31044	48717	\N	58.465423000000001	Кировская область, Муниципальное образование Кирово-Чепецкий район, д.Шутовщина, ул.Октябрьская, д.3		0101000020E6100000B6679604A8DB484032E719FB923B4D40
42142	7	67	1887	30948	48770	\N	58.301349999999999	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Филиппово, ул.Заева, д.41		0101000020E610000097AE601BF13E4940265305A392264D40
42141	7	67	1887	30888	9724	\N	58.407899470325297	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Фатеево, ул.Советская, д.8	Россия, Кировская область, Кирово-Чепецкий район, село Фатеево	0101000020E610000094C0E61C3CFB48401A89D00836344D40
42683	7	67	1887	56013	49583	\N	58.472095797772297	Кировская область, Муниципальное образование Унинский район, д. Сибирь, Школьная, 5	Россия, Кировская область, Кирово-Чепецкий район, село Сибирь	0101000020E61000000664AF777FAE4840454948A46D3C4D40
42139	7	67	1887	30784	49085	\N	58.296596999999998	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Селезениха, ул.Новая, д.10		0101000020E610000094C0E61C3C5B4940BD8BF7E3F6254D40
42138	7	67	1887	30740	48830	\N	58.442219000000001	Кировская область, Муниципальное образование Кирово-Чепецкий район, ж.д.Просница, ул.Большевиков, д.8а		0101000020E6100000575BB1BFEC1C4940BD55D7A19A384D40
42137	7	67	1887	30678	49183	\N	58.517310999999999	Кировская область, Муниципальное образование Кирово-Чепецкий район, п.Пригородный, ул.Комсомольская, д. 1а		0101000020E6100000FDC1C073EFFD4840376E313F37424D40
42135	7	67	1887	30569	48789	\N	58.370103999999998	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Полом, ул.Петра Родыгина, д.11	Россия, Кировская область, Кирово-Чепецкий район, село Полом	0101000020E61000007A185A9D9C2B4940340F60915F2F4D40
7993	4	37	\N	718	22571	\N	48.382809000000002	Хабаровский край, г. Хабаровск, ул. Панфиловцев, д.22		0101000020E6100000A3B1F677B6E36040A7CEA3E2FF304840
42133	7	67	1887	30472	49364	\N	58.240743000000002	Кировская область, Муниципальное образование Кирово-Чепецкий район, д.Марковцы, ул.Березовая, д.5		0101000020E61000002C499EEBFB3A4940D7DEA7AAD01E4D40
42131	7	67	1887	30375	49165	\N	58.439176000000003	Кировская область, Муниципальное образование Кирово-Чепецкий район, д.Малый Конып, ул.Новая, 9 а		0101000020E610000078B988EFC42E494014984EEB36384D40
42132	7	67	1887	30434	48925	\N	58.444747999999997	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Кстинино, ул.Советская, д.59	Россия, Кировская область, Кирово-Чепецкий район, село Кстинино	0101000020E610000041834D9D47E348400F7BA180ED384D40
42130	7	67	1887	30344	48892	\N	58.342587000000002	Кировская область, Муниципальное образование Кирово-Чепецкий район, п.Ключи, ул.Дружбы, 6	Россия, Кировская область, Кирово-Чепецкий район, поселок Ключи	0101000020E61000003E92921E8620494073840CE4D92B4D40
42171	7	67	1887	32285	48857	\N	58.556567000000001	Кировская область, Муниципальное образование город Кирово-Чепецк, Каринторф, ул. Лесная, 8А		0101000020E6100000CAE0287975184940348463963D474D40
42129	7	67	1887	30278	48777	\N	58.205528999999999	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Каринка, ул.Школьная, 10		0101000020E61000000C3ECDC98B4A494096B036C64E1A4D40
42128	7	67	1887	30243	49259	\N	58.391241999999998	Кировская область, Муниципальное образование Кирово-Чепецкий район, д.Дресвяново, ул.Безымянная, 2 а		0101000020E61000001AFCFD62B6E448402B69C53714324D40
42127	7	67	1887	30193	\N	\N	58.381732	Кировская область, Муниципальное образование Кирово-Чепецкий район, п.Быстрицкий, Быстрицкий туберкулезный санаторий, диагностический корпус		0101000020E6100000D76B7A5050C2484018EB1B98DC304D40
42126	7	67	1887	30106	49221	\N	58.334702	Кировская область, Муниципальное образование Кирово-Чепецкий район, с.Бурмакино, Школьная, 10		0101000020E610000081ECF5EE8FE54840F1F3DF83D72A4D40
42140	7	67	1887	56016	\N	\N	58.463510955855803	Кировская область, Муниципальное образование Кирово-Чепецкий район, ж.д.станция Бумкомбинат, помещение ж/д вокзала	Россия, Кировская область, Кирово-Чепецкий район, село Бумкомбинат	0101000020E61000001C0A9FAD830949400A2B1554543B4D40
42156	7	67	7391	60509	77143	\N	58.550520250682602	Кировская область, Муниципальное образование город Кирово-Чепецк, пр.Мира, 61/3		0101000020E61000003A3DEFC6820249409FE5797077464D40
42077	7	67	1752	55968	48734	\N	58.597373081706799	Кировская область, город Киров, Октябрьский район, поселок Садаковский, Бамовский переулок, 1а	Россия, Кировская область, Киров городской округ, село Садаковский	0101000020E61000005B5F24B4E5C64840B741EDB7764C4D40
42082	7	67	1752	28131	48812	\N	58.566949999999999	Кировская область, Муниципальное образование город Киров, село Русское, Коммуны, 60		0101000020E610000015E3FC4D28A64840CD3B4ED191484D40
42121	7	67	1752	55990	48965	\N	58.58099	Кировская область, город Киров, Первомайский район, д. Малая Субботиха, ул.Центральная, 20	Россия, Кировская область, Киров городской округ, село Малая Субботиха	0101000020E610000075C93846B2E14840CAA65CE15D4A4D40
42001	7	67	1752	55987	48948	\N	58.521043368144198	Кировская область, Муниципальное образование город Киров, микрорайон Лянгасово, Молодежный проезд, 5	Россия, Кировская область, Киров городской округ, поселок Лянгасово	0101000020E6100000467C2766BDBA4840A5677A89B1424D40
42000	7	67	1752	55987	48967	\N	58.521736183494397	Кировская область, Муниципальное образование город Киров, микрорайон Лянгасово, Комсомольская, 49	Россия, Кировская область, Киров городской округ, поселок Лянгасово	0101000020E61000005F5E807D74BA4840AB92C83EC8424D40
42078	7	67	1752	27972	48920	\N	58.61253	Кировская область, Муниципальное образование город Киров, поселок Костино, Парковая, 17	Россия, Кировская область, Киров городской округ, село Костино	0101000020E6100000247EC51A2EBE4840D1E80E62674E4D40
42002	7	67	1752	24454	\N	\N	58.507702999999999	Кировская область, Муниципальное образование город Киров, поселок Захарищевы, 5		0101000020E610000053EBFD463BB44840618A7269FC404D40
42080	7	67	1752	28030	\N	\N	58.666209000000002	Кировская область, Муниципальное образование город Киров, Большая Гора деревня	Россия, Кировская область, Киров городской округ, село Большая Гора	0101000020E61000009FE6E44526CC484083A6255646554D40
42081	7	67	1752	28078	48772	\N	58.614249999999998	Кировская область, Муниципальное образование город Киров, село Бахта, Юбилейная, 4	Россия, Кировская область, Киров городской округ, село Бахта	0101000020E610000081CCCEA277B44840B4C876BE9F4E4D40
41920	7	67	655	20567	49534	\N	57.122194999999998	Кировская область, Кильмезский район, д. Четай, Советская, 2		0101000020E6100000A7B393C1517C49400B5EF415A48F4C40
41908	7	67	655	19823	49128	\N	56.983907000000002	Кировская область, Кильмезский район, п. Чернушка, пер. Школьный, 14		0101000020E6100000A81DFE9AAC6549401AA721AAF07D4C40
41911	7	67	655	20014	49623	\N	56.954487999999998	Кировская область, Кильмезский район, д. Тат-Кильмезь, Школьная, 1		0101000020E61000005378D0ECBA7D49405436ACA92C7A4C40
41925	7	67	655	20839	49629	\N	57.308185999999999	Кировская область, Кильмезский район, д. Тат-Бояры, Лесная, 14		0101000020E6100000800D881057764940E38A8BA372A74C40
41912	7	67	655	20049	49494	\N	56.932510999999998	Кировская область, Кильмезский район, д. Селино, Советская, 12		0101000020E61000006A6B44300E5E494083143C855C774C40
41909	7	67	655	19924	49493	\N	57.084781999999997	Кировская область, Кильмезский район, п. Саринка, Школьная, 3		0101000020E6100000D1E7A38CB86A49400DA5F622DA8A4C40
41923	7	67	655	20716	49300	\N	57.213248999999998	Кировская область, Кильмезский район, д. Рыбная Ватага, Школьная, 1		0101000020E6100000D89AADBCE47D4940CD7344BE4B9B4C40
41919	7	67	655	20503	49292	\N	57.085247000000003	Кировская область, Кильмезский район, д. Паска, Советская, 2		0101000020E6100000BB270F0BB5904940838AAA5FE98A4C40
41918	7	67	655	20428	49461	\N	57.416001000000001	Кировская область, Кильмезский район, п. Осиновка, Школьная, 2		0101000020E610000096CD1C925A6C4940390D51853FB54C40
41915	7	67	655	20271	49622	\N	56.856825000000001	Кировская область, Кильмезский район, д. Надежда, Верхняя, 97		0101000020E6100000787E5182FEBE494096B20C71AC6D4C40
41917	7	67	655	20403	49497	\N	56.881188000000002	Кировская область, Кильмезский район, д. Моторки, Набережная, 69	Россия, Кировская область, Кильмезский район, село Моторки	0101000020E61000006DCA15DEE5BC494057D0B4C4CA704C40
41907	7	67	655	19811	49502	\N	56.842309999999998	Кировская область, Кильмезский район, д. Малыши, Красиловская, 7		0101000020E61000000E12A27C419B4940008C67D0D06B4C40
41913	7	67	655	20156	49236	\N	56.927438000000002	Кировская область, Кильмезский район, д. Малая Кильмезь, Зеленая, 1		0101000020E61000002C616D8C9D844940A988D349B6764C40
41924	7	67	655	20878	49462	\N	57.243461000000003	Кировская область, Кильмезский район, д. Кульма, Центральная, 50		0101000020E61000003DD2E0B6B6664940FD6CE4BA299F4C40
41914	7	67	655	19528	48916	\N	56.950748888628901	Кировская область, Кильмезский район, пгт. Кильмезь, Школьная, 7а	Россия, Кировская область, Кильмезский район, поселок Кильмезь	0101000020E6100000F243A511338B494034DAAA24B2794C40
41902	7	67	655	19528	49125	\N	56.951822999999997	Кировская область, Кильмезский район, пгт. Кильмезь, Скобелева, 37 А		0101000020E61000000490DAC4C98B4940514A0856D5794C40
41921	7	67	655	19528	9852	\N	56.944932532054999	Кировская область, Кильмезский район, пгт. Кильмезь, Больничная, 3	Россия, Кировская область, Кильмезский район, поселок Кильмезь	0101000020E61000009AB2D30FEA884940A1F48590F3784C40
41905	7	67	655	19716	49621	\N	56.975191000000002	Кировская область, Кильмезский район, д. Карманкино, Молодежная, 6		0101000020E610000021054F2157A64940412D060FD37C4C40
41926	7	67	655	56019	49643	\N	57.242823000000001	Кировская область, Кильмезский район, уч. Каменный Перебор, Школьная, 3а	Россия, Кировская область, Кильмезский район, село Каменный Перебор	0101000020E61000004354E1CFF07A4940BADBF5D2149F4C40
41910	7	67	655	19939	49344	\N	56.926372000000001	Кировская область, Кильмезский район, д. Зимник, Школьная, 1		0101000020E610000042E8A04B389A49400EF7915B93764C40
42386	7	67	655	56007	49392	\N	57.609095000000003	Кировская область, Муниципальное образование Нолинский район, д.Еремино, Центральная, 20		0101000020E6100000EE5F596952BC48401D9430D3F6CD4C40
41906	7	67	655	4444	49495	\N	56.796087622418902	Кировская область, Кильмезский район, 613582 д. Дамаскино Советская 64	Россия, Кировская область, Кильмезский район, село Дамаскино	0101000020E610000015ADDC0BCCA04940785E2A36E6654C40
41904	7	67	655	4391	49463	\N	56.919296383911799	Кировская область, Кильмезский район, 613588 д. Вихарево Школьная 1 А	Россия, Кировская область, Кильмезский район, село Вихарево	0101000020E61000000C5C1E6B46AC4940FCABC77DAB754C40
41903	7	67	655	19601	49492	\N	56.774948999999999	Кировская область, Кильмезский район, д. Бураши, Школьная, 2		0101000020E610000048C153C895864940B188618731634C40
41922	7	67	655	20678	49297	\N	56.772773999999998	Кировская область, Кильмезский район, д. Большой Порек, пер. Школьный, 3		0101000020E6100000CF81E508196A49407C992842EA624C40
41916	7	67	655	20302	49460	\N	56.786123000000003	Кировская область, Кильмезский район, д. Азиково, Заречная, 86		0101000020E6100000F7CB272B86B5494014D1AFAD9F644C40
41892	7	67	1556	19026	49188	\N	57.217371999999997	Кировская область, Кикнурский район, с. Шапта, Советская, 1	Россия, Кировская область, Кикнурский район, село Шапта	0101000020E610000050A8A78FC087474076887FD8D29B4C40
41889	7	67	1556	18853	49485	\N	57.191333	Кировская область, Кикнурский район, с. Цекеево, Просвещения, 18		0101000020E61000005CE49EAEEE964740A2D288997D984C40
41890	7	67	1556	18905	\N	\N	57.130412999999997	Кировская область, Кикнурский район, с. Улеш, 43	Россия, Кировская область, Кикнурский район, село Улеш	0101000020E61000008EE6C8CA2F91474093FC885FB1904C40
41897	7	67	1556	19291	49457	\N	57.438034999999999	Кировская область, Кикнурский район, с. Тырышкино, пер. Кооперативный, 8		0101000020E61000000F09DFFB1B7A47406EC0E78711B84C40
41901	7	67	1556	19497	49620	\N	57.369390000000003	Кировская область, Кикнурский район, д. Турусиново, Труда, 22		0101000020E61000007AFB73D190A3474017BCE82B48AF4C40
41896	7	67	1556	19225	49617	\N	57.382156999999999	Кировская область, Кикнурский район, с. Русские Краи, Молодежная, 16		0101000020E61000003A048E041A684740FF774485EAB04C40
41888	7	67	1556	18798	49454	\N	57.259241000000003	Кировская область, Кикнурский район, с. Потняк, Советская, 8		0101000020E610000023D923D40CAB4740246420CF2EA14C40
41894	7	67	1556	19109	49343	\N	57.218809999999998	Кировская область,  Кикнурский район, с. Падерино, Полевая, 4		0101000020E6100000C7F2AE7AC0704740D50451F7019C4C40
41899	7	67	1556	19389	49465	\N	57.438606	"Кировская область, Кикнурский район, с. Макарье, Труда, 29 ""а"""		0101000020E6100000554B3ACAC18E474029EACC3D24B84C40
41900	7	67	1556	19421	49619	\N	57.469093000000001	Кировская область, Кикнурский район, с. Кокшага, Кирова, 22		0101000020E6100000C0E95DBC1FAF47402AE44A3D0BBC4C40
41886	7	67	1556	18607	48764	\N	57.305346999999998	Кировская область, Кикнурский район, поселок городского типа Кикнур, Советская, 37		0101000020E6100000857B65DEAA9B47404277499C15A74C40
41884	7	67	1556	18607	48763	\N	57.305346999999998	Кировская область, Кикнурский район, поселок городского типа Кикнур, Пушкина, 4		0101000020E6100000857B65DEAA9B47404277499C15A74C40
41885	7	67	1556	18607	48939	\N	57.305346999999998	Кировская область, Кикнурский район, поселок городского типа Кикнур, Просвещения, 21		0101000020E6100000857B65DEAA9B47404277499C15A74C40
41898	7	67	1556	19317	49458	\N	57.33231	"Кировская область, Кикнурский район, д. Ваштранга, Новая, 2 ""а"""	Россия, Кировская область, Кикнурский район, село Ваштранга	0101000020E610000008C89750C18F47401F11532289AA4C40
41893	7	67	1556	19087	49489	\N	57.211289000000001	Кировская область, Кикнурский район, д. Березовка, Центральная, 3		0101000020E61000007974232C2A7E4740958098840B9B4C40
41887	7	67	1556	18742	49339	\N	57.364386000000003	Кировская область, Кикнурский район,  с. Беляево, Школьная, 3		0101000020E6100000E7374C3448B74740658F5033A4AE4C40
41891	7	67	1556	18953	\N	\N	57.153331000000001	"Кировская область, Кикнурский район, д. Абрамово, 54 ""б"""		0101000020E6100000E86B96CB46854740433BA759A0934C40
41883	7	67	1328	18557	49123	\N	58.488092999999999	Кировская область, Муниципальное образование Зуевский район, Чепецкое сельское поселение, пос.Чепецкий, Железнодорожная, 17		0101000020E61000003F6F2A52619849400934D8D4793E4D40
41882	7	67	1328	18474	49179	\N	58.178134	Кировская область, Муниципальное образование Зуевский район, Сунское сельское поселение, с.Суна, Коммунистическая, 10		0101000020E61000004B77D7D990A3494020274C18CD164D40
41880	7	67	1328	18385	49452	\N	58.297311000000001	Кировская область, Муниципальное образование Зуевский район, Соколовское сельское поселение, дер.Старки, Кирова, 13		0101000020E6100000D80DDB16658E4940DBDE6E490E264D40
41878	7	67	1328	18293	49219	\N	58.269609000000003	Кировская область, Муниципальное образование Зуевский район, Соколовское сельское поселение, пос.Соколовка, Центральная, 16		0101000020E6100000389ECF807A9D494088DA368C82224D40
41877	7	67	1328	18224	49180	\N	58.447257999999998	Кировская область, Муниципальное образование Зуевский район, Семушинское сельское поселение, пос.Семушино, Ленина, 6		0101000020E6100000DC12B9E00C664940EB6F09C03F394D40
41875	7	67	1328	18156	49616	\N	58.466076999999999	Кировская область, Муниципальное образование Зуевский район, Сезеневское сельское поселение, с.Сезенево, Новая, 2а		0101000020E610000032022A1C418449407A354069A83B4D40
41871	7	67	1328	17931	49448	\N	58.196081999999997	Кировская область, Муниципальное образование Зуевский район, Мухинское сельское поселение, с.Рябово, Кирова, 2		0101000020E61000000D501A6A14684940C9AA083719194D40
41872	7	67	1328	17987	\N	\N	58.124203000000001	Кировская область, Муниципальное образование Зуевский район, Октябрьское сельское поселение, пос.Октябрьский, Ленина, 11	Россия, Кировская область, Зуевский район, село Октябрьский	0101000020E61000000E87A5811F934940558847E2E50F4D40
41881	7	67	1328	18451	49455	\N	58.201143000000002	Кировская область, Муниципальное образование Зуевский район, Сунское сельское поселение, дер.Мусихи, Торговая, 13		0101000020E6100000DC0F786000974940E068C70DBF194D40
41868	7	67	1328	17773	49338	\N	58.065215999999999	Кировская область, Муниципальное образование Зуевский район, Лемское сельское поселение, с.Лема, Школьная, 4		0101000020E61000007DCEDDAE976E4940859675FF58084D40
42453	7	67	1328	14165	48873	\N	58.445411999999997	Кировская область, Оричевский район, пгт Лёвинцы, 70 лет Октября, 121		0101000020E6100000E2900DA48B7B49407B9FAA4203394D40
41863	7	67	1328	17549	49121	\N	58.406390000000002	Кировская область, Муниципальное образование Зуевский район, Косинское городское поселение, пос.Косино, Свободы, 1		0101000020E61000001ADCD6169EA34940F2B5679604344D40
41865	7	67	1328	17549	49122	\N	58.406390000000002	Кировская область, Муниципальное образование Зуевский район, Косинское городское поселение, пос.Косино, Никулина, 14а		0101000020E61000001ADCD6169EA34940F2B5679604344D40
41864	7	67	1328	17549	49177	\N	58.407020687856402	Кировская область, Муниципальное образование Зуевский район, Косинское городское поселение, пос.Косино, Кирова, 21	Россия, Кировская область, Зуевский район, поселок Косино	0101000020E61000006286C61341A4494082E49D4319344D40
41879	7	67	1328	18324	49337	\N	58.330680999999998	Кировская область, Муниципальное образование Зуевский район, Соколовское сельское поселение, с.Коса, Советская, 8		0101000020E61000007940D9942BA049404C3448C1532A4D40
41867	7	67	1328	17765	49185	\N	58.428223000000003	Кировская область, Муниципальное образование Зуевский район, Кордяжское сельское поселение, пос.Кордяга, Школьная, 10а		0101000020E61000006FD39FFD488349409032E202D0364D40
41866	7	67	1328	56020	49647	\N	58.380567297632403	Кировская область, Муниципальное образование Зуевский район, Зуевское сельское поселение, д.Зуи, Молодежная, 1	Россия, Кировская область, Зуевский район, село Зуи	0101000020E6100000ECA694D74A904940EA77616BB6304D40
41856	7	67	1328	17066	49176	\N	58.404252660877397	Кировская область, Зуевский район, город Зуевка, Южная, 16	Россия, Кировская область, Зуевский район, Зуевка	0101000020E610000062F71DC363914940AA27F38FBE334D40
41855	7	67	1328	17066	48900	\N	58.403711999999999	Кировская область, Зуевский район, город Зуевка, Торговая, 10		0101000020E6100000635FB2F1609149405A80B6D5AC334D40
41862	7	67	1328	17066	48766	\N	58.403711999999999	Кировская область, Зуевский район, город Зуевка, Свердлова, 24		0101000020E6100000635FB2F1609149405A80B6D5AC334D40
41860	7	67	1328	17066	48766	\N	58.403711999999999	Кировская область, Зуевский район, город Зуевка, Свердлова, 132	Россия, Кировская область, Зуевский район, Зуевка	0101000020E6100000635FB2F1609149405A80B6D5AC334D40
41861	7	67	1328	17066	48826	\N	58.403711999999999	Кировская область, Зуевский район, город Зуевка, Пушкина, 4		0101000020E6100000635FB2F1609149405A80B6D5AC334D40
41854	7	67	1328	17066	49245	\N	58.403711999999999	Кировская область, Зуевский район, город Зуевка, Куйбышева, 3		0101000020E6100000635FB2F1609149405A80B6D5AC334D40
41858	7	67	1328	17066	48895	\N	58.403711999999999	Кировская область, Зуевский район, город Зуевка, Исполкомовская, 109	Россия, Кировская область, Зуевский район, Зуевка	0101000020E6100000635FB2F1609149405A80B6D5AC334D40
41859	7	67	1328	17066	48917	\N	58.403804339461701	Кировская область, Зуевский район, город Зуевка, Восточная, 16А	Россия, Кировская область, Зуевский район, Зуевка	0101000020E6100000128942CBBA9149403BFF76D9AF334D40
41857	7	67	1328	17066	49187	\N	58.405153686017201	Кировская область, Зуевский район, город Зуевка, 1-я Советская, 16	Россия, Кировская область, Зуевский район, Зуевка	0101000020E61000008F6D197096904940FBEB1516DC334D40
41873	7	67	1328	18060	49512	\N	58.108953	Кировская область, Муниципальное образование Зуевский район, Октябрьское сельское поселение, дер.Городище, Полевая, 1		0101000020E61000007099D365318949408AE6012CF20D4D40
41874	7	67	1328	18079	49453	\N	58.324269000000001	Кировская область, Муниципальное образование Зуевский район, Пасынковское сельское поселение, дер.Большие Пасынки, Школьная, 1		0101000020E610000036E84B6F7F804940A60D87A581294D40
41876	7	67	1328	52226	49456	\N	58.460813999999999	Кировская область, Муниципальное образование Зуевский район, Семушинское сельское поселение, стан.Ардаши, Новая		0101000020E610000060AE450BD0504940FCC401F4FB3A4D40
41846	7	67	1053	16683	49342	\N	58.781923999999997	Кировская область, Даровский район, д.Хохловщина, Советская, 2б		0101000020E6100000A75B76887FE647408FFAEB1516644D40
41847	7	67	1053	56024	49662	\N	59.218506127823403	Кировская область, Даровский район, п.Суборь, Школьная, 11	Россия, Кировская область, Даровской район, село Субарь	0101000020E6100000B9382A3751F5474069FD2D01F89B4D40
41845	7	67	1053	16663	49336	\N	58.911898999999998	Кировская область, Даровский район, с.Пиксур, Советская, 17		0101000020E6100000444FCAA486004840A7203F1BB9744D40
41844	7	67	1053	16589	49618	\N	58.788356	Кировская область, Даровский район, с.Окатьево, Молодежная, 21		0101000020E610000091EEE714E43748407DCD72D9E8644D40
41843	7	67	1053	16523	49615	\N	59.259175999999997	Кировская область, Даровский район, д.Кривецкая, Набережная, 1		0101000020E6100000B95510035DF547403CF4DDAD2CA14D40
41842	7	67	1053	16502	49133	\N	59.20449	Кировская область, Даровский район, с.Красное, Труда, 1		0101000020E6100000B587BD50C0F04740F52D73BA2C9A4D40
42349	7	67	1053	9235	49137	\N	58.883253000000003	Кировская область, Нагорский район, Кобра поселок, Строителей ул., дом 2		0101000020E610000037363B527D274840058C2E6F0E714D40
41840	7	67	1053	9235	49132	\N	58.883253000000003	Кировская область, Даровский район, с.Кобра, Мира, 24		0101000020E610000037363B527D274840058C2E6F0E714D40
41839	7	67	1053	16321	49334	\N	59.060971000000002	Кировская область, Даровский район, п.Ивановка, Набережная, 10		0101000020E6100000AA66D652402048409180D1E5CD874D40
41838	7	67	1053	16143	48894	\N	58.766331999999998	Кировская область, Даровский район, поселок городского типа Даровской, Советская, 2		0101000020E61000007193516518FB47406BF0BE2A17624D40
41835	7	67	1053	16143	48894	\N	58.766287284253004	Кировская область, Даровский район, поселок городского типа Даровской, Советская, 42	Россия, Кировская область, Даровской район, поселок Даровской	0101000020E6100000BA83D89942FB4740CB2C42B115624D40
41848	7	67	1053	16143	48715	\N	58.766331999999998	Кировская область, Даровской район, пгт Даровской, Октябрьская ул., дом 19а		0101000020E61000007193516518FB47406BF0BE2A17624D40
41837	7	67	1053	16143	48915	\N	58.766331999999998	Кировская область, Даровский район, поселок городского типа Даровской, Кооперативная, 5		0101000020E61000007193516518FB47406BF0BE2A17624D40
41836	7	67	1053	16143	49169	\N	58.766331999999998	Кировская область, Даровский район, поселок городского типа Даровской, Зеленая, 27		0101000020E61000007193516518FB47406BF0BE2A17624D40
41833	7	67	1053	16023	49486	\N	59.089449999999999	Кировская область, Даровский район, с.Вонданка, Школьная, 5		0101000020E61000008AE42B8194EA47404850FC18738B4D40
41832	7	67	1053	15984	49332	\N	58.859623999999997	Кировская область, Даровский район, с.Верховонданка, Кооперативная, 3		0101000020E6100000F03499F1B6D44740A86DC328086E4D40
41834	7	67	1053	16104	49614	\N	58.83399	Кировская область, Даровский район, д.Бобровы, Набережная, 11		0101000020E6100000F56393FC88F3474074982F2FC06A4D40
41831	7	67	1053	16104	49646	\N	58.832981405958598	Кировская область, Даровский район, д.Первые Бобровы, Зеленая, 23	Россия, Кировская область, Даровской район, село Бобровы	0101000020E6100000A73B4F3C67F347403D98141F9F6A4D40
41830	7	67	1053	15897	49424	\N	58.910231000000003	Кировская область, Даровский район, п.Бечева, Центральная, 3		0101000020E61000002B51F6967232484017670C7382744D40
41810	7	67	1290	14934	49484	\N	56.164090000000002	Кировская область, Вятскополянский район, деревня Ямышка, Молодежная, 19а	Россия, Кировская область, Вятскополянский район, село Ямышка	0101000020E6100000E4BB94BA64B04940E2CCAFE600154C40
41811	7	67	1290	15003	49174	\N	56.169392999999999	Кировская область, Вятскополянский район, деревня Чекашево, Школьная, 37а		0101000020E6100000D7A02FBDFD934940EE9579ABAE154C40
41809	7	67	1290	14889	9873	\N	56.194203000000002	Кировская область, Вятскополянский район, поселок Усть-Люга, Октябрьская, 2а		0101000020E6100000737FF5B86FAB49407EE4D6A4DB184C40
41805	7	67	1290	48794	49613	\N	56.203477999999997	Кировская область, Вятскополянский район, дер.Старый Пинигерь, Школьная, 1б		0101000020E61000006EA301BC057849404DBA2D910B1A4C40
41803	7	67	1290	14597	49611	\N	56.249056000000003	Кировская область, Вятскополянский район, деревня Средняя Тойма, Центральная, 49б		0101000020E6100000F644D7851F7A4940B16F2711E11F4C40
41806	7	67	1290	14721	49120	\N	56.123362999999998	Кировская область, Вятскополянский район, деревня Средние Шуни, Советская, 1	Россия, Кировская область, Вятскополянский район, село Средние Шуни	0101000020E6100000959F54FB749E4940AA44D95BCA0F4C40
41785	7	67	1290	13515	48757	\N	56.251641999999997	Кировская область, Вятскополянский район, город Сосновка, Спортивная, 14		0101000020E610000065C8B1F50CA34940672618CE35204C40
41783	7	67	1290	13515	48757	\N	56.251641999999997	Кировская область, Вятскополянский район, город Сосновка, Спортивная, 4а		0101000020E610000065C8B1F50CA34940672618CE35204C40
41782	7	67	1290	13515	48823	\N	56.251641999999997	Кировская область, Вятскополянский район, город Сосновка, Пролетарская, 64		0101000020E610000065C8B1F50CA34940672618CE35204C40
41781	7	67	1290	13515	48891	\N	56.251641999999997	Кировская область, Вятскополянский район, город Сосновка, Куйбышева, 8		0101000020E610000065C8B1F50CA34940672618CE35204C40
41784	7	67	1290	13515	48909	\N	56.251641999999997	Кировская область, Вятскополянский район, город Сосновка, Комсомольская, 1		0101000020E610000065C8B1F50CA34940672618CE35204C40
41780	7	67	1290	13515	48761	\N	56.251713468131904	Кировская область, Вятскополянский район, город Сосновка, Дзержинского, 33	Россия, Кировская область, Вятскополянский район, Сосновка	0101000020E6100000C34483143CA34940317DAF2138204C40
41786	7	67	1290	13515	49172	\N	56.251641999999997	Кировская область, Вятскополянский район, город Сосновка, Ворошилова, 21		0101000020E610000065C8B1F50CA34940672618CE35204C40
41808	7	67	1290	14858	49459	\N	56.136552000000002	Кировская область, Вятскополянский район, деревня Сосмак, Кирова, 41/1	Россия, Кировская область, Вятскополянский район, село Сосмак	0101000020E61000006B48DC63E9994940091A33897A114C40
41800	7	67	1290	14468	49173	\N	56.321156999999999	Кировская область, Вятскополянский район, село Слудка, Молодежная, 8		0101000020E61000009CC0745AB7834940D4F02DAC1B294C40
41802	7	67	1290	14538	49447	\N	56.365054000000001	Кировская область, Вятскополянский район, село Новый Бурец, ул.Центральная, 23		0101000020E610000075B169A51072494012A3E716BA2E4C40
41804	7	67	1290	14628	49171	\N	56.242614000000003	Кировская область, Вятскополянский район, деревня Нижняя Тойма, Центральная, 189		0101000020E6100000F700DD9733814940A0C6BDF90D1F4C40
41807	7	67	1290	14804	49144	\N	56.119222999999998	Кировская область, Вятскополянский район, деревня Нижние Шуни, Центральная, 27/1	Россия, Кировская область, Вятскополянский район, село Нижние Шуни	0101000020E61000000D198F5209A549402BF702B3420F4C40
41801	7	67	1290	14523	49449	\N	56.289755	Кировская область, Вятскополянский район, деревня Нижние Изиверки, ул.Центральная, 16-1		0101000020E610000011ACAA97DF8549401E6D1CB116254C40
41870	7	67	1290	55985	48928	\N	56.259825749626003	Кировская область, Муниципальное образование Зуевский район, Мухинское сельское поселение, с.Мухино, Советская, 14		0101000020E6100000D7506A2FA2874940435376FA41214C40
41794	7	67	1290	14180	49610	\N	56.185156999999997	Кировская область, Вятскополянский район, деревня Куршино, ул.Большая, 23		0101000020E6100000CEFE40B96D9F49400FD07D39B3174C40
41796	7	67	1290	14274	49175	\N	56.211562999999998	Кировская область, Вятскополянский район, село Кулыги, ул.Школьная, 2		0101000020E61000009FE40E9BC89E49409605137F141B4C40
41787	7	67	1290	13822	49446	\N	56.246850999999999	Кировская область, Вятскополянский район, пгт Красная Поляна, Сосновая, 26		0101000020E61000003BE3FBE25295494011FE45D0981F4C40
41788	7	67	1290	13822	49126	\N	56.245171716062003	Кировская область, Вятскополянский район, пгт Красная Поляна, Свободы, 3	Россия, Кировская область, Вятскополянский район, поселок Красная Поляна	0101000020E61000005DFDD8243F9449408CF2CCCB611F4C40
41789	7	67	1290	13822	48889	\N	56.246850999999999	Кировская область, Вятскополянский район, пгт Красная Поляна, Молодежная, 2а		0101000020E61000003BE3FBE25295494011FE45D0981F4C40
41792	7	67	1290	13822	48758	\N	56.246850999999999	Кировская область, Вятскополянский район, пгт Красная Поляна, Дружбы, 33		0101000020E61000003BE3FBE25295494011FE45D0981F4C40
41791	7	67	1290	13822	48758	\N	56.246373079828103	Кировская область, Вятскополянский район, пгт Красная Поляна, Дружбы, 20	Россия, Кировская область, Вятскополянский район, поселок Красная Поляна	0101000020E61000003F373465A793494007CF8426891F4C40
41790	7	67	1290	13822	48758	\N	56.244311482376403	Кировская область, Вятскополянский район, пгт Красная Поляна, Дружбы, 17	Россия, Кировская область, Вятскополянский район, поселок Красная Поляна	0101000020E6100000126745D444934940CB863595451F4C40
41797	7	67	1290	14307	49490	\N	56.412242999999997	Кировская область, Вятскополянский район, поселок Казанка, Школьная, 4б		0101000020E61000008B6B7C26FB974940A180ED60C4344C40
41812	7	67	1290	15013	49119	\N	56.168450999999997	Кировская область, Вятскополянский район, село Ершовка, Молодежная, 5		0101000020E61000005E10919A768349403FFD67CD8F154C40
41798	7	67	1290	14370	49134	\N	56.374192999999998	Кировская область, Вятскополянский район, деревня Дым-Дым-Омга, Новая, 1		0101000020E6100000EF3845477297494031B2648EE52F4C40
41793	7	67	1290	14125	49483	\N	56.285943000000003	Кировская область, Вятскополянский район, деревня Гремячка, Центральная, 4		0101000020E6100000E17EC00303AA494094C2BCC799244C40
41799	7	67	1290	14399	49487	\N	56.421971999999997	Кировская область, Вятскополянский район, деревня Виноградово, Новая, 10		0101000020E610000011001C7BF6944940F2E9B12D03364C40
41779	7	67	185	1986	49481	\N	58.075710999999998	Кировская область, Верхошижемский район, Угор д., Школьная ул., дом 3		0101000020E61000000070ECD973BB48404679E6E5B0094D40
41778	7	67	185	1403	49444	\N	58.123337999999997	Кировская область, Верхошижемский район, Сырда д., Школьный переулок., дом 10	Россия, Кировская область, Верхошижемский район, село Сырда	0101000020E6100000B95510035DB94840512D228AC90F4D40
41777	7	67	185	2208	49116	\N	58.000441000000002	Кировская область, Верхошижемский район, Среднеивкино с., Школьная ул., дом 13	Россия, Кировская область, Верхошижемский район, село Среднеивкино	0101000020E6100000E413B2F336B84840ED4960730E004D40
41776	7	67	185	1383	49441	\N	58.139209000000001	Кировская область, Верхошижемский район, Пунгино д., Советская ул., дом 2		0101000020E61000000A698D41278E48408927BB99D1114D40
41775	7	67	185	1335	49609	\N	57.873140999999997	Кировская область, Верхошижемский район, Мякиши с., Школьная ул., дом 2		0101000020E6100000EC6B5D6A84864840FBE59315C3EF4C40
41774	7	67	185	1237	49607	\N	58.029403000000002	Кировская область, Верхошижемский район, Косино с., Школьная ул., дом 12		0101000020E61000004EF04DD367794840C0B33D7AC3034D40
33306	4	41	\N	16582	46299	\N	48.779257999999999	г. Биробиджан, Биршоссе 2-ой км, 17		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
41773	7	67	185	1226	49445	\N	58.035348999999997	Кировская область, Верхошижемский район, Калачиги д., Школьная ул., дом 1		0101000020E61000000A2DEBFEB1CE48402079E75086044D40
41772	7	67	185	1158	49491	\N	57.869799999999998	Кировская область, Верхошижемский район, Зониха с., Советская ул., дом 8		0101000020E6100000A19FA9D72DA24840C8073D9B55EF4C40
41771	7	67	185	2319	49573	\N	57.936971999999997	Кировская область, Верхошижемский район, Воронье д., Советская ул., дом 3		0101000020E6100000AA66D65240BE484044A2D0B2EEF74C40
41768	7	67	185	664	48898	\N	58.003464000000001	Кировская область, Верхошижемский район, Верхошижемье пгт., Школьная ул., дом 1	Россия, Кировская область, Верхошижемский район, поселок Верхошижемье	0101000020E6100000C70E2A711D8D48404F5B238271004D40
41769	7	67	185	664	48907	\N	58.003464000000001	Кировская область, Верхошижемский район, Верхошижемье пгт., Пионерская ул., дом 8		0101000020E6100000C70E2A711D8D48404F5B238271004D40
41767	7	67	185	664	48716	\N	58.003464000000001	Кировская область, Верхошижемский район, Верхошижемье пгт., Кирова ул., дом 32		0101000020E6100000C70E2A711D8D48404F5B238271004D40
41770	7	67	185	2665	49439	\N	57.891745	Кировская область, Верхошижемский район, Верхолипово с., Попова ул., дом 12		0101000020E6100000E6B2D1393F7348408EAF3DB324F24C40
41763	7	67	172	12732	49612	\N	59.717993999999997	Кировская область, Муниципальное образование Верхнекамский район, пос.Чус, Комсомольская, 12		0101000020E61000007D5A457F686A4A40B35C363AE7DB4D40
41766	7	67	172	12881	49442	\N	60.057411000000002	Кировская область, Муниципальное образование Верхнекамский район, пос.Тупрунка, Школьная, 11		0101000020E6100000A31EA2D11DBA4A4020B75F3E59074E40
41754	7	67	172	12305	49239	\N	59.739680999999997	Кировская область, Муниципальное образование Верхнекамский район, пос.Созимский, Набережная, 9		0101000020E61000002D060FD3BE1F4A407D3CF4DDADDE4D40
41755	7	67	172	12305	49112	\N	59.739680999999997	Кировская область, Муниципальное образование Верхнекамский район, пос.Созимский, Коммунальная, 1		0101000020E61000002D060FD3BE1F4A407D3CF4DDADDE4D40
41749	7	67	172	12075	48820	\N	59.419409999999999	Кировская область, Муниципальное образование Верхнекамский район, пос.Светлополянск, Новая, 2		0101000020E6100000D6C8AEB48C2E4A40C4CE143AAFB54D40
41750	7	67	172	12075	48905	\N	59.419409999999999	Кировская область, Муниципальное образование Верхнекамский район, пос.Светлополянск, Дзержинского, 11		0101000020E6100000D6C8AEB48C2E4A40C4CE143AAFB54D40
41753	7	67	172	12151	48906	\N	59.608341000000003	Кировская область, Муниципальное образование Верхнекамский район, пос.Рудничный, Строительная, 1		0101000020E6100000BE16F4DE183C4A4071E82D1EDECD4D40
41752	7	67	172	12151	48759	\N	59.608341000000003	Кировская область, Муниципальное образование Верхнекамский район, пос.Рудничный, Пушкина, 2		0101000020E6100000BE16F4DE183C4A4071E82D1EDECD4D40
41751	7	67	172	12151	48759	\N	59.608341000000003	Кировская область, Муниципальное образование Верхнекамский район, пос.Рудничный, Пушкина, 4	Россия, Кировская область, Верхнекамский район, поселок Рудничный	0101000020E6100000BE16F4DE183C4A4071E82D1EDECD4D40
41761	7	67	172	12662	49479	\N	59.893740999999999	Кировская область, Муниципальное образование Верхнекамский район, с.Пушья, Новая, 2	Россия, Кировская область, Верхнекамский район, село Пушья	0101000020E6100000CDB1BCAB1E744A40130CE71A66F24D40
41748	7	67	172	12016	49443	\N	59.189166999999998	Кировская область, Муниципальное образование Верхнекамский район, пос.Пещера, Нижняя, 1		0101000020E61000004D124BCADD294A40C03DCF9F36984D40
41764	7	67	172	12782	49341	\N	59.537278999999998	Кировская область, Муниципальное образование Верхнекамский район, пос.Ожмегово, Октябрьская, 1	Россия, Кировская область, Верхнекамский район, село Ожмегово	0101000020E61000009C6C0377A0644A40EEE9EA8EC5C44D40
41759	7	67	172	12569	49130	\N	59.728437999999997	Кировская область, Муниципальное образование Верхнекамский район, с.Лойно, Падерина, 69		0101000020E6100000AA99B51490524A40F294D5743DDD4D40
41760	7	67	172	12569	49118	\N	59.728437999999997	Кировская область, Муниципальное образование Верхнекамский район, с.Лойно, Ленина, 20		0101000020E6100000AA99B51490524A40F294D5743DDD4D40
41757	7	67	172	12424	49288	\N	59.789574999999999	Кировская область, Муниципальное образование Верхнекамский район, пос.Лесной, Центральная, 3		0101000020E6100000BB7F2C4487104A409E5E29CB10E54D40
41758	7	67	172	12424	49330	\N	59.789574999999999	Кировская область, Муниципальное образование Верхнекамский район, пос.Лесной, Мопра, 15		0101000020E6100000BB7F2C4487104A409E5E29CB10E54D40
41756	7	67	172	12424	48908	\N	59.789574999999999	Кировская область, Муниципальное образование Верхнекамский район, пос.Лесной, Ленина, 18		0101000020E6100000BB7F2C4487104A409E5E29CB10E54D40
42267	7	67	172	56003	\N	\N	59.791945253564599	Кировская область, Муниципальное образование Лузский район, д. Куликово	Россия, Кировская область, Верхнекамский район, село Куликово	0101000020E6100000B08C0DDDEC614A40889D29745EE54D40
41747	7	67	172	11958	49608	\N	59.229152999999997	Кировская область, Муниципальное образование Верхнекамский район, д.Кочкино, Новая, 18		0101000020E6100000DA1EBDE13E204A40E063B0E2549D4D40
41744	7	67	172	544	48914	\N	59.346845999999999	Кировская область, Муниципальное образование Верхнекамский район, г.Кирс, Набережная, 1		0101000020E610000022E2E654321E4A40CC5F217365AC4D40
41739	7	67	172	544	48902	\N	59.346845999999999	Кировская область, Верхнекамский район, г.Кирc, Ленина ул., дом 4		0101000020E610000022E2E654321E4A40CC5F217365AC4D40
41743	7	67	172	544	48756	\N	59.346845999999999	Кировская область, Муниципальное образование Верхнекамский район, г.Кирс, Кирова, 19		0101000020E610000022E2E654321E4A40CC5F217365AC4D40
84800	4	34	\N	639	45174	\N	62.028191	Республика Саха (Якутия), город Якутск, Дзержинского, 16/1		0101000020E6100000A0C03BF97436604051853FC39B034F40
41742	7	67	172	544	48756	\N	59.346845999999999	Кировская область, Муниципальное образование Верхнекамский район,г.Кирс, Кирова, 23		0101000020E610000022E2E654321E4A40CC5F217365AC4D40
41740	7	67	172	544	48756	\N	59.346845999999999	Кировская область, Муниципальное образование Верхнекамский район, г.Кирс, Кирова, 24		0101000020E610000022E2E654321E4A40CC5F217365AC4D40
41745	7	67	172	544	49437	\N	59.346845999999999	Кировская область, Верхнекамский район, г.Кирc, Гарь пос., Индустриальная ул., дом 22	Россия, Кировская область, Верхнекамский район, Кирс	0101000020E610000022E2E654321E4A40CC5F217365AC4D40
41762	7	67	172	12719	49482	\N	59.959029999999998	Кировская область, Муниципальное образование Верхнекамский район, с.Кай, Дзержинского, 27		0101000020E61000001118EB1B987C4A4002F1BA7EC1FA4D40
41746	7	67	172	11910	49345	\N	59.377209999999998	Кировская область, Муниципальное образование Верхнекамский район, пос.Барановка, Советская, 29		0101000020E6100000AF963B33C1F64940B1DCD26A48B04D40
41738	7	67	198	11559	49606	\N	57.771200999999998	Кировская область, Богородский район, с.Хороши, Молодежная, 1		0101000020E6100000B91798158A4E49403DD2E0B6B6E24C40
41737	7	67	198	11495	49436	\N	57.923715999999999	Кировская область, Богородский район, с.Ухтым, Кирова, 5		0101000020E6100000CF876709328049405E656D533CF64C40
41736	7	67	198	11441	49604	\N	57.972019000000003	Кировская область, Богородский район, д.Таранки, Мира, 12		0101000020E610000059880E81234949409A0B5C1E6BFC4C40
41735	7	67	198	11424	49435	\N	57.796098999999998	Кировская область, Богородский район, с.Спасское, Советская, 25		0101000020E610000059349D9D0C7649406CB07092E6E54C40
41734	7	67	198	750	49329	\N	57.888396999999998	Кировская область, Богородский район, с.Рождественское, Заречная ул., д.3		0101000020E61000001CEF8E8CD53C4940A86E2EFEB6F14C40
41733	7	67	198	11288	49480	\N	57.952328999999999	Кировская область, Богородский район, с.Ошлань, Новая, 10	Россия, Кировская область, Богородский район, село Ошлань	0101000020E61000006C96CB46E74049402504ABEAE5F94C40
41732	7	67	198	11271	49478	\N	57.973799	Кировская область, Богородский район, с.Караул, Советская, 17		0101000020E610000024B4E55C8A8D494052F01472A5FC4C40
41731	7	67	198	1647	49433	\N	57.936732999999997	Кировская область, Богородский район, с.Верховойское, Юбилейная, д.2		0101000020E6100000D32EA699EE5F4940BF0AF0DDE6F74C40
41727	7	67	198	55997	49248	\N	57.830306999999998	Кировская область, Богородский район, поселок городского типа Богородское, Советская, 2	Россия, Кировская область, Богородский район, поселок Богородское	0101000020E6100000E607AEF204604940E751F17F47EA4C40
41730	7	67	198	55997	49113	\N	57.830507744987699	Кировская область, Богородский район, поселок городского типа Богородское, Коммуны, 9	Россия, Кировская область, Богородский район, поселок Богородское	0101000020E61000000514EAE9236049407F880D164EEA4C40
41729	7	67	198	55997	49102	\N	57.8301872431988	Кировская область, Богородский район, поселок городского типа Богородское, 1 Мая, 44	Россия, Кировская область, Богородский район, поселок Богородское	0101000020E6100000077C7E18216049403D484F9143EA4C40
41728	7	67	198	55997	49102	\N	57.831611415361898	Кировская область, Богородский район, поселок городского типа Богородское, 1 Мая, 11	Россия, Кировская область, Богородский район, поселок Богородское	0101000020E6100000580053060E60494037FFAF3A72EA4C40
41719	7	67	486	10763	49475	\N	59.007255000000001	Кировская область, Белохолуницкий район, Юдино деревня, Советская, 3		0101000020E6100000BB6070CD1D814940C2DD59BBED804D40
41724	7	67	486	10902	49477	\N	59.216797999999997	Кировская область, Белохолуницкий район, Троица село, Набережная, 14		0101000020E61000004E98309A95AD49404AEB6F09C09B4D40
41716	7	67	486	10539	49473	\N	59.037663000000002	Кировская область, Белохолуницкий район, Сырьяны село, Советская, 40А		0101000020E61000001BD47E6B275A494077A22424D2844D40
41718	7	67	486	10638	49472	\N	58.9557	Кировская область, Белохолуницкий район, Ракалово деревня, Луговая, 5		0101000020E6100000613596B036764940C364AA60547A4D40
41715	7	67	486	10470	49432	\N	58.908112000000003	Кировская область, Белохолуницкий район, Прокопье село, Новая, 13		0101000020E6100000DFC5FB71FB4B4940768D96033D744D40
41721	7	67	486	10755	49117	\N	59.187156999999999	Кировская область, Белохолуницкий район, Полом село, Энгельса, 49		0101000020E6100000F4FA93F8DC694940D61BB5C2F4974D40
41726	7	67	486	3046	49131	\N	59.349204	Кировская область, Белохолуницкий район, Подрезчиха посёлок, Свободы ул, д.10		0101000020E6100000D7DCD1FF72BB4940F2D077B7B2AC4D40
41723	7	67	486	10843	49170	\N	58.887554999999999	Кировская область, Белохолуницкий район, Климковка посёлок, Кооперации, 5		0101000020E61000003B71395E819E49405D33F9669B714D40
41725	7	67	486	3009	49438	\N	59.153103000000002	Кировская область, Белохолуницкий район, Каменное посёлок, Школьная ул, д.10		0101000020E6100000704221020EC14940B2F50CE198934D40
41720	7	67	486	10693	49605	\N	59.130740000000003	Кировская область, Белохолуницкий район, Иванцево село, Советская, 24		0101000020E6100000AF5FB01BB67F4940B8239C16BC904D40
41722	7	67	486	10815	48754	\N	59.226750000000003	Кировская область, Белохолуницкий район, Дубровка посёлок, Свободы, 2А		0101000020E61000001137A792019449401B2FDD24069D4D40
41714	7	67	486	10412	49431	\N	58.790557	Кировская область, Белохолуницкий район, Гурёнки деревня, Советская, 10		0101000020E6100000F355F2B1BB564940DB4FC6F830654D40
41717	7	67	486	10554	49289	\N	59.057949999999998	Кировская область, Белохолуницкий район, Всехсвятское село, Школьная, 14		0101000020E6100000DC645419C66D4940CF66D5E76A874D40
41713	7	67	486	10384	49470	\N	58.749566000000002	Кировская область, Белохолуницкий район, Быданово деревня, Советская, 15		0101000020E610000074EB353D28664940C61858C7F15F4D40
41702	7	67	486	2909	48899	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Школьная, 5А		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41704	7	67	486	2909	48901	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Строителей, 7А		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41707	7	67	486	2909	48885	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Смирнова, 20		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41712	7	67	486	2909	49434	\N	58.842722692667202	Кировская область, Белохолуницкий район, Белая Холуница город, Федосята деревня, Салтыкова ул, д.15	Россия, Кировская область, Белохолуницкий район, Белая Холуница	0101000020E610000004AF963B336B4940234BE658DE6B4D40
41708	7	67	486	2909	49204	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Победы, 6	Россия, Кировская область, Белохолуницкий район, Белая Холуница	0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41706	7	67	486	2909	49328	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Великое Поле деревня, Новая, 2А		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41711	7	67	486	2909	49469	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Мелиораторов, 2		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41710	7	67	486	2909	49209	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Западная, 20		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41703	7	67	486	2909	49129	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Бастракова, 61		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41709	7	67	486	2909	48887	\N	58.842424000000001	Кировская область, Белохолуницкий район, Белая Холуница город, Советская, 49		0101000020E61000002BC3B81B446B4940C9AEB48CD46B4D40
41691	7	67	246	9299	\N	\N	58.594625000000001	Кировская область, Афанасьевский район, д.Шердынята	Россия, Кировская область, Афанасьевский район, село Шердынята	0101000020E61000005470784144C24A40273108AC1C4C4D40
41694	7	67	246	9437	\N	\N	58.728565000000003	Кировская область, Афанасьевский район, д.Фроловская	Россия, Кировская область, Афанасьевский район, село Фроловская	0101000020E6100000C2FA3F87F9924A405001309E415D4D40
41692	7	67	246	1035	49464	\N	58.701121999999998	Кировская область, Афанасьевский район, Томызь пос., Школьная ул., дом 22, здание  НОШ		0101000020E6100000B3EA73B515794A40C8409E5DBE594D40
41680	7	67	246	8810	\N	\N	59.303190999999998	Кировская область, Афанасьевский район, п.Сюзьва	Россия, Кировская область, Афанасьевский район, село Сюзьва	0101000020E61000005DA79196CA874A4084B872F6CEA64D40
41681	7	67	246	56017	\N	\N	58.6720833680589	Кировская область, Афанасьевский район, д.Слобода	Россия, Кировская область, Афанасьевский район, село Слобода	0101000020E610000065FF3C0D18D64A404A99D4D006564D40
41701	7	67	246	1633	49592	\N	58.994138	Кировская область, Афанасьевский район, Савинцы с., Центральная ул., дом 37, здание ООШ		0101000020E610000028D192C7D3B44A40FDDAFAE93F7F4D40
41698	7	67	246	9594	\N	\N	58.696905000000001	Кировская область, Афанасьевский район, д.Ромаши	Россия, Кировская область, Афанасьевский район, село Ромаши	0101000020E6100000A48B4D2B85B44A409EB5DB2E34594D40
41697	7	67	246	1519	49324	\N	59.019815000000001	Кировская область, Афанасьевский район, Пура дер., Школьная ул., дом 11, здание НОШ		0101000020E61000006B60AB048B974A40317C444C89824D40
41695	7	67	246	2893	49325	\N	58.780110000000001	Кировская область, Афанасьевский район, Пашино с., Центральная ул., дом 16		0101000020E61000004819710168AA4A402BA4FCA4DA634D40
41628	7	67	246	6312	\N	\N	58.997729999999997	Кировская область, Афанасьевский район, д.Ожегино	Россия, Кировская область, Афанасьевский район, село Ожегино	0101000020E6100000B08C0DDDECA54A40791EDC9DB57F4D40
41693	7	67	246	1081	49474	\N	58.825358999999999	Кировская область, Афанасьевский район, Московская дер., Центральная ул., дом 24, здание Центра коми-пермяцкой культуры	Россия, Кировская область, Афанасьевский район, село Московская	0101000020E6100000BA8102EFE48F4A40C93A1C5DA5694D40
41690	7	67	246	9233	49333	\N	58.56006	Кировская область, Афанасьевский район, п.Лытка, Советская, 2А		0101000020E6100000705B5B785E804A401DE6CB0BB0474D40
41687	7	67	246	9122	\N	\N	58.881607000000002	Кировская область, Афанасьевский район, д.Кувакуш	Россия, Кировская область, Афанасьевский район, село Кувакуш	0101000020E6100000E5ED08A705D34A405C76887FD8704D40
41696	7	67	246	1506	49468	\N	58.767330999999999	Кировская область, Афанасьевский район, Камский пос., Северная ул., дом 6, здание НОШ		0101000020E61000008A743FA720A94A407E1AF7E637624D40
41688	7	67	246	977	\N	\N	58.953797000000002	Кировская область, Афанасьевский район, Илюши дер., дом 57, здание  Илюшовского сельского Дома культуры		0101000020E61000005BD2510E66A54A40EF022505167A4D40
41488	7	67	246	31170	\N	\N	59.062077000000002	Кировская область, Афанасьевский район, д.Жарковы	Россия, Кировская область, Афанасьевский район, село Жарковы	0101000020E6100000D600A5A146A94A40BA6A9E23F2874D40
41686	7	67	246	9072	\N	\N	58.481422999999999	Кировская область, Афанасьевский район, д.Ефремята	Россия, Кировская область, Афанасьевский район, село Ефремята	0101000020E6100000C1C8CB9A58BC4A406745D4449F3D4D40
41689	7	67	246	9197	\N	\N	58.798791000000001	Кировская область, Афанасьевский район, д.Езжа	Россия, Кировская область, Афанасьевский район, село Езжа	0101000020E610000047054EB681D14A4069AB92C83E664D40
41685	7	67	246	2784	49115	\N	58.561467999999998	Кировская область, Афанасьевский район, Гордино с., Мира ул., дом 34		0101000020E610000013807F4A95C64A4011E0F42EDE474D40
41682	7	67	246	2559	49577	\N	59.144838	Кировская область, Афанасьевский район, Георгиево с., Труда ул., дом 8	Россия, Кировская область, Афанасьевский район, село Георгиево	0101000020E6100000C70F9546CC964A40E99B340D8A924D40
41675	7	67	246	8567	\N	\N	58.882109	Кировская область, Афанасьевский район, д.Верхняя Тимофеевская	Россия, Кировская область, Афанасьевский район, село Верхняя Тимофеевская	0101000020E610000032FFE89B348F4A40EE409DF2E8704D40
41684	7	67	246	1851	49322	\N	58.657268999999999	Кировская область, Афанасьевский район, Верхнее Камье с., Школьная ул., дом 6, здание ООШ		0101000020E610000026FF93BF7BB74A405AD6FD6321544D40
41683	7	67	246	2457	49396	\N	58.513095	Кировская область, Афанасьевский район, Васёнки дер., Новая ул., дом 13, здание НОШ		0101000020E610000018EC866D8BCE4A40DD5ED218AD414D40
41677	7	67	246	8679	\N	\N	59.312713000000002	Кировская область, Афанасьевский район, д.Ванино	Россия, Кировская область, Афанасьевский район, село Ванино	0101000020E610000051A3906456754A405C04C6FA06A84D40
41679	7	67	246	56000	49257	\N	59.189651667022403	Кировская область, Афанасьевский район, п.Бор, Гагарина, 2	Россия, Кировская область, Афанасьевский район, село Бор	0101000020E61000003C69E1B20A8B4A407DCF488446984D40
41678	7	67	246	2782	49127	\N	59.067720999999999	Кировская область, Афанасьевский район, Бисерово с., Советская ул., дом 33		0101000020E6100000DE76A1B94EA14A404F20EC14AB884D40
41676	7	67	246	8613	\N	\N	59.339454000000003	Кировская область, Афанасьевский район, п.Афонята	Россия, Кировская область, Афанасьевский район, село Афонята	0101000020E610000076E09C11A5794A408A3F8A3A73AB4D40
41673	7	67	246	2668	48886	\N	58.859884999999998	Кировская область, Афанасьевский район, Афанасьево пгт., Красных Партизан ул., дом 3		0101000020E61000005BD1E638B7A14A4015A930B6106E4D40
41699	7	67	246	9678	\N	\N	58.961931999999997	Кировская область, Афанасьевский район, д.Архипята	Россия, Кировская область, Афанасьевский район, село Архипята	0101000020E6100000CD02ED0E29C44A40E97C7896207B4D40
41672	7	67	429	7009	49429	\N	57.824646999999999	Кировская область, Арбажский район, с.Шембеть, Первомайская ул., д.1а		0101000020E6100000CAA7C7B60C2248404CDF6B088EE94C40
41671	7	67	429	8369	49574	\N	57.800618	Кировская область, Арбажский район, с.Шараница, Механизаторов, 5		0101000020E6100000965D30B8E6504840624B8FA67AE64C40
41670	7	67	429	8348	49168	\N	57.862341999999998	Кировская область, Арбажский район, с.Сорвижи, Советская, 28		0101000020E6100000349C3237DF424840CEFBFF3861EE4C40
41669	7	67	429	8273	49428	\N	57.791556999999997	Кировская область, Арбажский район, д.Пишнур, Советская, 58		0101000020E61000004F1F813FFCF84740BEF561BD51E54C40
41668	7	67	429	8236	49471	\N	57.763328999999999	Кировская область, Арбажский район, д.Мосуны, Октябрьская, 13		0101000020E61000002A53CC41D0234840508BC1C3B4E14C40
41667	7	67	429	8173	49425	\N	57.917420999999997	Кировская область, Арбажский район, д.Криуша, Труда, 6		0101000020E61000009160AA99B5344840F1D4230D6EF54C40
41666	7	67	429	2337	49321	\N	57.880952000000001	Кировская область, Арбажский район, с.Кормино, Советская ул., д.26		0101000020E610000028D4D347E031484043ACFE08C3F04C40
41665	7	67	429	8053	49426	\N	57.742274999999999	Кировская область, Арбажский район, д.Гулины, Молодежная, 5		0101000020E6100000297AE063B0324840B7D100DE02DF4C40
41664	7	67	429	6954	49323	\N	57.768738999999997	Кировская область, Арбажский район, с.Верхотулье, Свободы ул., д.1		0101000020E6100000C45F9335EA0748407214200A66E24C40
41663	7	67	429	7982	49467	\N	57.671807000000001	Кировская область, Арбажский район, д. Б.Кугунур, Школьная, 17		0101000020E61000001349F4328A134840A81C93C5FDD54C40
41662	7	67	429	7924	49466	\N	57.656421000000002	Кировская область, Арбажский район, д.Басманы, Новая, 4		0101000020E6100000A8E507AEF23C48402DB4739A05D44C40
41661	7	67	429	6910	48796	\N	57.678885999999999	Кировская область, Арбажский район, пгт.Арбаж, Советская ул., д.36		0101000020E61000003753211E892748402BDB87BCE5D64C40
41660	7	67	429	6910	48796	\N	57.679667641098398	Кировская область, Арбажский район, поселок городского типа Арбаж, Советская, д.5	Россия, Кировская область, Арбажский район, поселок Арбаж	0101000020E610000046B6F3FDD4284840A1116C5CFFD64C40
13640	4	42	\N	61558	79383	\N	66.3109334014041	Чукотский автономный округ, Иультинский муниципальный район, городское поселение Эгвекинот, Гагарина, 5	Россия	0101000020E6100000658BA4DDE86466C0D28F8653E6935040
13615	4	42	\N	55649	45978	\N	64.737989999999996	Анадырский муниципальный район, городское поселение Угольные Копи, ул. Советская, 24		0101000020E6100000DB520779BD3566409AB1683A3B2F5040
13613	4	42	\N	55649	45974	\N	64.7414904103168	Анадырский муниципальный район, городское поселение Угольные Копи, Портовая, 10а	Россия, Чукотский автономный округ, Анадырский район	0101000020E6100000AE2CD159E6356640E8137992742F5040
13657	4	42	\N	55648	45972	\N	69.697241000000005	город Певек, Пугачёва, 54		0101000020E610000026A94C31074C65408B1BB7989F6C5140
13632	4	42	\N	55646	45967	\N	68.055574450930294	г. Билибино, Ленина, 2	Россия, Чукотский автономный округ, Билибинский район	0101000020E610000033FAD170CACE6440812040868E035140
13611	4	42	\N	21786	45281	\N	64.736654999999999	город Анадырь, Строителей, 9		0101000020E61000001DC70F95462F6640D55B035B252F5040
13610	4	42	\N	21786	45285	\N	64.736654999999999	город Анадырь, Отке, 25		0101000020E61000001DC70F95462F6640D55B035B252F5040
13609	4	42	\N	21786	45284	\N	64.736654999999999	город Анадырь, Ленина, 23		0101000020E61000001DC70F95462F6640D55B035B252F5040
13612	4	42	\N	21786	45980	\N	64.724537772776102	город Анадырь, село Тавайваам, Колхозная, 21		0101000020E61000001BB96E4AF930664064ADA1D45E2E5040
13608	4	42	\N	21786	45968	\N	64.736654999999999	город Анадырь, Мира, 6 а		0101000020E61000001DC70F95462F6640D55B035B252F5040
87908	4	42	1281	13399	45323	\N	65.506812999999994	Лорино, Ленина, 3		0101000020E6100000A81DFE9A2C896740020CCB9F6F605040
13644	4	42	1281	23419	45312	\N	65.586849999999998	Лаврентия, Советская, 15		0101000020E6100000F17EDC7E799F6740166A4DF38E655040
13658	4	42	1524	24099	45971	\N	69.919820999999999	село Янранай, Заозерная, 5		0101000020E6100000C70DBF9B6E516540234BE658DE7A5140
13655	4	42	1524	23934	45295	\N	69.697241000000005	город Певек, Советская, 22		0101000020E610000026A94C31074C65408B1BB7989F6C5140
13656	4	42	1524	23934	45278	\N	69.697241000000005	город Певек, Полярная, 17		0101000020E610000026A94C31074C65408B1BB7989F6C5140
13649	4	42	1735	61551	\N	\N	65.617954999999995	Провиденский муниципальный район, городское поселение Провидения МУ "районный центр культуры"		0101000020E6100000EF586C930A2D674094D920938C675040
13653	4	42	1735	61552	\N	\N	64.510898305344597	Провиденский муниципальный район, городское поселение Провидения, село Новое Чаплино администрация	Россия	0101000020E6100000E04A766C849C65C0E065868DB2205040
13639	4	42	1719	55367	45275	\N	66.687539000000001	Чукотский автономный округ, Иультинский муниципальный район, городское поселение Эгвекинот, Советская, 11		0101000020E610000064E597C1989766405FEE93A300AC5040
13643	4	42	1719	52771	45973	\N	67.046781999999993	Чукотский автономный округ, Иультинский муниципальный район, сельское поселение Амгуэма, Северная, 16		0101000020E610000001A777F17EA36640A702EE79FEC25040
13638	4	42	1705	23159	45975	\N	67.843350999999998	с. Кепервеем, Кавракая, 8		0101000020E6100000ED647094BCC4644021037976F9F55040
13631	4	42	1705	22792	45259	\N	68.055831999999995	г. Билибино, Ленина, 6		0101000020E610000053E751F1FFCD64407F8461C092035140
13633	4	42	1705	22792	45305	\N	68.055831999999995	г. Билибино, Берзина, 6		0101000020E610000053E751F1FFCD64407F8461C092035140
13630	4	42	1705	22792	45257	\N	68.055831999999995	г. Билибино, Арктика, дом 3, корпус 4	Россия, Чукотский автономный округ, Билибинский район, Билибино	0101000020E610000053E751F1FFCD64407F8461C092035140
13626	4	42	7218	52731	\N	\N	63.127378	Чукотский автономный округ, Анадырский муниципальный район, сельское поселение Алькатваам, Советская, 11	Россия, Чукотский автономный округ, Беринговский район, село Алькатваам	0101000020E610000082751C3FD46066406D1D1CEC4D904F40
13625	4	42	1682	55373	45298	\N	65.435554999999994	Чукотский автономный округ, Анадырский муниципальный район, городское поселение Беринговский, Мандрикова, 12		0101000020E6100000129F3BC1FE906540FE261422E05B5040
13614	4	42	1682	55647	45969	\N	64.738524127590097	Чукотский автономный округ, Анадырский муниципальный район, городское поселение Угольные Копи, Первомайская, 27	Россия, Чукотский автономный округ, Анадырский район	0101000020E6100000DD7C23BA67366640E9D32AFA432F5040
13617	4	42	1682	52702	45318	\N	64.674228999999997	Чукотский автономный округ, Анадырский муниципальный район, сельское поселение Марково, Берзина, 19		0101000020E61000005E2EE23B314D6540F2406491262B5040
13623	4	42	1682	55651	45981	\N	65.199869855916504	Чукотский автономный округ, Анадырский муниципальный район, сельское поселение Канчалан, Центральная, 33	Россия, Чукотский автономный округ, Анадырский район	0101000020E6100000DE73603942186640E65C8AABCA4C5040
8462	4	37	\N	50556	22769	\N	48.542977999999998	Хабаровский край, район имени Лазо, п. Третий Сплавной Участок, ул. Речная, д.14/2		0101000020E6100000D5CE30B5A5E060404739984D80454840
8694	4	37	\N	718	\N	\N	48.532551960682902	г.Хабаровск, здание Аэропорта		0101000020E6100000A9328CBBC1E56040AFB5F7A92A444840
8047	4	37	\N	718	2077	\N	48.535496999999999	Хабаровский край, г. Хабаровск, Краснофлотский район, ул.Профессора Даниловского М.П, д.22	Россия, Хабаровский край, Хабаровск, улица профессора Даниловского, 22	0101000020E6100000E7FEEA715FE16040950D6B2A8B444840
8046	4	37	\N	718	2077	\N	48.537233000000001	Хабаровский край, г. Хабаровск, Краснофлотский район, ул.Профессора Даниловского М.П, д.24А	Россия, Хабаровский край, Хабаровск, улица профессора Даниловского, 24а	0101000020E6100000546EA29666E160407EAA0A0DC4444840
7950	4	37	\N	718	664	\N	48.457994999999997	Хабаровский край, г. Хабаровск, ул. Юности, д.32	Россия, Хабаровский край, Хабаровск, улица Юности, 32	0101000020E61000007C2766BD98E36040A25D85949F3A4840
4707	4	37	\N	718	1482	\N	48.444006000000002	Хабаровский край, г.Хабаровск, ул.Шмаковская, д.8А	Россия, Хабаровский край, Хабаровск, улица Шмаковская, 8ка	0101000020E6100000F1811DFF85E46040289D4830D5384840
8510	4	37	\N	718	218	\N	48.428147000000003	Хабаровский край, Охотский район, п. Новая Иня, ул. Школьная, д. 1	Россия, Хабаровский край, Хабаровск, улица Школьная, 1	0101000020E61000000760032244E46040B5705985CD364840
8507	4	37	\N	718	218	\N	48.430346999999998	Хабаровский край, Охотский район, с. Булгин, ул. Школьная, д. 16	Россия, Хабаровский край, Хабаровск, улица Школьная, 16	0101000020E6100000682101A34BE460404277499C15374840
7921	4	37	\N	718	218	\N	48.435344999999998	Хабаровский край, г.Хабаровск, ул.Школьная, д.17	Россия, Хабаровский край, Хабаровск, улица Школьная, 17	0101000020E6100000BF620D1739E4604012BD8C62B9374840
7920	4	37	\N	718	218	\N	48.434657000000001	Хабаровский край, г.Хабаровск, ул.Школьная, д.32	Россия, Хабаровский край, Хабаровск, улица Школьная, 32	0101000020E61000007F6B274A42E460401EFD2FD7A2374840
8084	4	37	\N	718	2644	\N	48.476598000000003	Хабаровский край, г. Хабаровск, Центральный район, ул.Шеронова, д.56	Россия, Хабаровский край, Хабаровск, улица Шеронова, 56	0101000020E6100000C8073D9B55E2604065ABCB29013D4840
8035	4	37	\N	718	1925	\N	48.515602999999999	Хабаровский край, город Хабаровск, Кировский район, улица Шелеста, д.73 В	Россия, Хабаровский край, Хабаровск, улица Шелеста, 73в	0101000020E610000077F86BB2C6E16040185C7347FF414840
8069	4	37	\N	718	2406	\N	48.491174999999998	Хабаровский край, г. Хабаровск, Центральный район, ул. Шабадина, д.14	Россия, Хабаровский край, Хабаровск, улица Шабадина, 14	0101000020E6100000A0C55224DFE2604070CE88D2DE3E4840
8014	4	37	\N	718	1652	\N	48.508493999999999	Хабаровский край, город Хабаровск, Кировский район, улица Чкалова, д.17	Россия, Хабаровский край, Хабаровск, улица Чкалова, 17	0101000020E61000003F1A4E991BE160402A1BD65416414840
7940	4	37	\N	718	513	\N	48.506202000000002	Хабаровский край, г.Хабаровск, ул.Чехова, д.20	Россия, Хабаровский край, Хабаровск, улица Чехова, 22	0101000020E610000072A3C85A43E26040BC95253ACB404840
7984	4	37	\N	718	1202	\N	48.396366999999998	Хабаровский край, г. Хабаровск, ул. Черняховского, д.5	Россия, Хабаровский край, Хабаровск, улица Черняховского, 5	0101000020E61000009D84D217C2E36040581B6327BC324840
7973	4	37	\N	718	1030	\N	48.398228000000003	Хабаровский край, г. Хабаровск, ул. Фурманова, д.1	Россия, Хабаровский край, Хабаровск, улица Фурманова, 1	0101000020E6100000E4DA50314EE36040FE2C9622F9324840
8024	4	37	\N	718	1782	\N	48.482087	Хабаровский край, город Хабаровск, Кировский район, улица Фрунзе, д.119	Россия, Хабаровский край, Хабаровск, улица Фрунзе, 119	0101000020E61000007077D66EBBE16040D369DD06B53D4840
8037	4	37	\N	718	1946	\N	48.517769999999999	Хабаровский край, город Хабаровск, Кировский район, улица Фоломеева, д.10	Россия, Хабаровский край, Хабаровск, улица Фоломеева, 10	0101000020E61000004E64E60297E16040CA6C904946424840
8013	4	37	\N	718	842	\N	48.435738999999998	Хабаровский край, г. Хабаровск, ул. Флегонтова, д.8	Россия, Хабаровский край, Хабаровск, улица Флегонтова, 8	0101000020E61000008522DDCFA9E36040BE4BA94BC6374840
7966	4	37	\N	718	901	\N	48.406201000000003	Хабаровский край, г. Хабаровск, ул. Ургальская, д.8	Россия, Хабаровский край, Хабаровск, улица Ургальская, 8	0101000020E6100000B1C1C2499AE360401F4DF564FE334840
8007	4	37	\N	718	1561	\N	48.366081999999999	Хабаровский край, г. Хабаровск, ул. Ульяновская, д.154	Россия, Хабаровский край, Хабаровск, улица Ульяновская, 154	0101000020E6100000D52137C30DE16040BFD364C6DB2E4840
8051	4	37	\N	718	2135	\N	48.536200999999998	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Уборевича, д.79	Россия, Хабаровский край, Хабаровск, улица Уборевича, 79	0101000020E6100000F1D7648DFAE060408F8AFF3BA2444840
8050	4	37	\N	718	2052	\N	48.538640999999998	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Трехгорная, д.43	Россия, Хабаровский край, Хабаровск, улица Трехгорная, 43	0101000020E610000076AA7CCFC8E0604072A43330F2444840
8049	4	37	\N	718	2052	\N	48.539751000000003	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Трехгорная, д.63	Россия, Хабаровский край, Хабаровск, улица Трехгорная, 63	0101000020E6100000D31742CEFBE06040DD7D8E8F16454840
8048	4	37	\N	718	2052	\N	48.542786999999997	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Трехгорная, д.80А	Россия, Хабаровский край, Хабаровск, улица Трехгорная, 80а	0101000020E610000006685BCD3AE16040D3D85E0B7A454840
8045	4	37	\N	718	2052	\N	48.542028999999999	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Трехгорная, д.74А	Россия, Хабаровский край, Хабаровск, улица Трехгорная, 74а	0101000020E610000071917BBA3AE16040E63DCE3461454840
8055	4	37	\N	718	1458	\N	48.551774999999999	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.218А	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 218а	0101000020E61000007769C36169E160400DE02D90A0464840
8054	4	37	\N	718	1458	\N	48.549354000000001	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.186А	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 186а	0101000020E61000009FE5797077E16040A1F65B3B51464840
8044	4	37	\N	718	1458	\N	48.538313000000002	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.175	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 175	0101000020E61000004B5AF10D85E160407E01BD70E7444840
8043	4	37	\N	718	1458	\N	48.535896999999999	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.171	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 171	0101000020E6100000CFD72C978DE160402383DC4598444840
8042	4	37	\N	718	1458	\N	48.534692	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.169	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 169	0101000020E6100000508A56EE85E1604067B796C970444840
8041	4	37	\N	718	1458	\N	48.534429000000003	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.152	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 152	0101000020E61000001422E010AAE160405A84622B68444840
8040	4	37	\N	718	1458	\N	48.530159047832498	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.136, аудит.124л	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 136	0101000020E61000007444BE4BA9E160400C570740DC434840
8036	4	37	\N	718	1458	\N	48.515382000000002	Хабаровский край, город Хабаровск, Кировский район, улица Тихоокеанская, д.115	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 115	0101000020E6100000FDBFEAC891E160403A799109F8414840
8020	4	37	\N	718	1458	\N	48.488529999999997	"Хабаровский край, город Хабаровск"", Кировский район, улица Тихоокеанская, д.17"	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 17	0101000020E6100000825660C86AE16040B48EAA26883E4840
8019	4	37	\N	718	1458	\N	48.488315	Хабаровский край, город Хабаровск, Кировский район, улица Тихоокеанская, д.45	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 45	0101000020E6100000863DEDF057E16040B8921D1B813E4840
8015	4	37	\N	718	1458	\N	48.505934000000003	Хабаровский край, город Хабаровск, Кировский район, улица Тихоокеанская, д.58	Россия, Хабаровский край, Хабаровск, улица Тихоокеанская, 58	0101000020E61000006D1ADB6B41E160409DF7FF71C2404840
8000	4	37	\N	718	1464	\N	48.368799000000003	Хабаровский край, г. Хабаровск, ул. Ташкентская, д.22	Россия, Хабаровский край, Хабаровск, улица Ташкентская, 22	0101000020E610000076543541D4E2604015E63DCE342F4840
7968	4	37	\N	718	934	\N	48.401583000000002	Хабаровский край, г.Хабаровск, ул. Сурикова, д.4А	Россия, Хабаровский край, Хабаровск, улица Сурикова, 4ка	0101000020E610000080272D5C56E3604096D05D1267334840
7982	4	37	\N	718	1123	\N	48.393101000000001	Хабаровский край, г. Хабаровск, ул. Суворова, д.55	Россия, Хабаровский край, Хабаровск, улица Суворова, 55	0101000020E610000048E17A14AEE360403083312251324840
7980	4	37	\N	718	1123	\N	48.392335000000003	Хабаровский край, г. Хабаровск, ул. Суворова, д.38	Россия, Хабаровский край, Хабаровск, улица Суворова, 38	0101000020E6100000CFD902426BE36040C009850838324840
7979	4	37	\N	718	1123	\N	48.392651999999998	Хабаровский край, г. Хабаровск, ул. Суворова, д.40	Россия, Хабаровский край, Хабаровск, улица Суворова, 40	0101000020E61000005853591476E36040C05AB56B42324840
7996	4	37	\N	718	1393	\N	48.37594	Хабаровский край, г. Хабаровск, ул. Строительная, д.12	Россия, Хабаровский край, Хабаровск, улица Строительная, 12	0101000020E6100000EF8CB62A09E360400EA14ACD1E304840
7974	4	37	\N	718	1042	\N	48.398873999999999	Хабаровский край, г. Хабаровск, ул. Союзная, д.1	Россия, Хабаровский край, Хабаровск, улица Союзная, 1	0101000020E6100000492C29771FE36040C39CA04D0E334840
8580	4	37	\N	718	242	\N	48.487509000000003	Хабаровский край, Ульчский район, с.Киселевска, ул. Советская, д.21	Россия, Хабаровский край, Хабаровск, улица Советская, 19	0101000020E61000004B72C0AEA6E16040BAC0E5B1663E4840
8031	4	37	\N	718	242	\N	48.491540000000001	Хабаровский край, город Хабаровск, Кировский район, улица Советская, д.52	Россия, Хабаровский край, Хабаровск, улица Советская, 52	0101000020E61000009EB30584D6E16040825660C8EA3E4840
8022	4	37	\N	718	242	\N	48.486924000000002	Хабаровский край, город Хабаровск, Кировский район, улица Советская, д.24	Россия, Хабаровский край, Хабаровск, улица Советская, 24	0101000020E6100000B75F3E59B1E160409AD18F86533E4840
7943	4	37	\N	718	561	\N	48.472273000000001	Хабаровский край, г. Хабаровск, ул. Слободская, д.12	Россия, Хабаровский край, Хабаровск, улица Слободская, 12	0101000020E6100000C51F459DB9E2604054E41071733C4840
7757	4	37	\N	718	6638	\N	48.503635000000003	Хабаровский край, г.Хабаровск, ул.Сигнальная, д.4	Россия, Хабаровский край, Хабаровск, улица Сигнальная, 4	0101000020E6100000CEC7B5A162E260407C0F971C77404840
5348	4	37	\N	718	466	\N	48.492984999999997	Хабаровский край, г.Хабаровск, ул.Серышева, д.47	Россия, Хабаровский край, Хабаровск, улица Серышева, 47	0101000020E6100000BD1B0B0A03E260409335EA211A3F4840
8066	4	37	\N	718	15461	\N	48.559390999999998	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Сергеевская, д.15	Россия, Хабаровский край, Хабаровск, поселок Березовка, улица Сергеевская, 15	0101000020E6100000E5EE737CB4E360409F56D11F9A474840
7929	4	37	\N	718	359	\N	48.500745999999999	Хабаровский край, г.Хабаровск, ул.Свердлова, д.28	Россия, Хабаровский край, Хабаровск, улица Свердлова, 28	0101000020E610000051A2258F27E3604029CDE67118404840
8052	4	37	\N	718	2157	\N	48.529549000000003	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Санаторная, д.38	Россия, Хабаровский край, Хабаровск, улица Санаторная, 38	0101000020E6100000AF97A608F0E060409450FA42C8434840
8060	4	37	\N	718	2245	\N	48.564894000000002	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Руднева, д.68	Россия, Хабаровский край, Хабаровск, улица Руднева, 68	0101000020E6100000A9BD88B663E1604073DA53724E484840
8059	4	37	\N	718	2245	\N	48.564149	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Руднева, д.39	Россия, Хабаровский край, Хабаровск, улица Руднева, 39	0101000020E6100000FA0D130D52E160401A89D00836484840
7989	4	37	\N	718	1232	\N	48.389037999999999	Хабаровский край, г. Хабаровск, ул. Рокоссовского, д.35	Россия, Хабаровский край, Хабаровск, улица Рокоссовского, 35	0101000020E6100000AF93FAB2B4E360405C7347FFCB314840
7988	4	37	\N	718	1232	\N	48.388302000000003	Хабаровский край, г. Хабаровск, ул. Рокоссовского, д.32	Россия, Хабаровский край, Хабаровск, улица Рокоссовского, 32	0101000020E610000071E2AB1DC5E36040577C43E1B3314840
7986	4	37	\N	718	1232	\N	48.389420999999999	Хабаровский край, г. Хабаровск, ул. Рокоссовского, д.40	Россия, Хабаровский край, Хабаровск, улица Рокоссовского, 40	0101000020E6100000E28FA2CEDCE3604014B01D8CD8314840
7948	4	37	\N	718	631	\N	48.455461999999997	Хабаровский край, г. Хабаровск, ул. Ремесленная, д.8	Россия, Хабаровский край, Хабаровск, улица Ремесленная, 8	0101000020E6100000F3734353F6E260400E492D944C3A4840
8094	4	37	\N	718	2806	\N	48.482511000000002	Хабаровский край, г. Хабаровск, Центральный район, ул.Пушкина, д.60	Россия, Хабаровский край, Хабаровск, улица Пушкина, 60	0101000020E61000003127689343E26040EA7AA2EBC23D4840
7957	4	37	\N	718	759	\N	48.451636999999998	Хабаровский край, г. Хабаровск, ул. Путевая, д.2А	Россия, Хабаровский край, Хабаровск, улица Путевая, 2	0101000020E610000077BB5E9AA2E36040EF54C03DCF394840
7956	4	37	\N	718	759	\N	48.449187000000002	Хабаровский край, г. Хабаровск, ул. Путевая, д.10А	Россия, Хабаровский край, Хабаровск, улица Путевая, 10а	0101000020E61000008ACA863595E36040E964A9F57E394840
8085	4	37	\N	718	2647	\N	48.477792000000001	Хабаровский край, г. Хабаровск, Центральный район, ул.Постышева, д.13	Россия, Хабаровский край, Хабаровск, улица Постышева, 13	0101000020E6100000734A404CC2E260402D25CB49283D4840
8063	4	37	\N	718	2311	\N	48.579625	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Портовая, д.9	Россия, Хабаровский край, Хабаровск, улица Портовая, 9	0101000020E610000077D66EBB50E16040D578E926314A4840
8509	4	37	\N	718	7463	\N	48.561864999999997	Хабаровский край, Охотский район, с. Иня, ул. Победы, д. 31	Россия, Хабаровский край, Хабаровск, улица Победы, 31	0101000020E61000004CA8E0F002E160402EE23B31EB474840
8001	4	37	\N	718	1478	\N	48.351844999999997	Хабаровский край, г. Хабаровск, ул. Пассажирская, д.5	Россия, Хабаровский край, Хабаровск, улица Пассажирская, 1	0101000020E6100000DC813AE5D1E260406C21C841092D4840
8091	4	37	\N	718	2748	\N	48.487802000000002	Хабаровский край, г. Хабаровск, Центральный район, ул.Панькова, д.13	Россия, Хабаровский край, Хабаровск, улица Панькова, 13	0101000020E6100000FB5B02F04FE260403276C24B703E4840
7991	4	37	\N	718	1081	\N	48.384478999999999	Хабаровский край, г. Хабаровск, ул. Панфиловцев, д.38	Россия, Хабаровский край, Хабаровск, улица Панфиловцев, 38	0101000020E61000003AE63C63DFE36040D87F9D9B36314840
7990	4	37	\N	718	1081	\N	48.386710999999998	Хабаровский край, г. Хабаровск, ул. Панфиловцев, д.21А		0101000020E61000005A2C45F295E360407100FDBE7F314840
7977	4	37	\N	718	1081	\N	48.382229000000002	Хабаровский край, г. Хабаровск, ул. Панфиловцев, д.16А	Россия, Хабаровский край, Хабаровск, улица Панфиловцев, 16ка	0101000020E6100000BF28417FA1E36040994A3FE1EC304840
8018	4	37	\N	718	1707	\N	48.494244000000002	Хабаровский край, город Хабаровск, Кировский район, улица Орджоникидзе, д.12	Россия, Хабаровский край, Хабаровск, улица Орджоникидзе, 12	0101000020E6100000C992399677E16040431F2C63433F4840
7919	4	37	\N	718	205	\N	48.426341999999998	Хабаровский край, г.Хабаровск, ул.Огородная, д.1	Россия, Хабаровский край, Хабаровск, улица Огородная, 1	0101000020E61000001C2444F982E46040A374E95F92364840
8074	4	37	\N	718	2489	\N	48.477679000000002	Хабаровский край, г. Хабаровск, Центральный район, ул.Мухина, д.6	Россия, Хабаровский край, Хабаровск, улица Мухина, 6	0101000020E61000004F7633A39FE26040357EE195243D4840
8089	4	37	\N	718	2689	\N	48.479762999999998	Хабаровский край, г. Хабаровск, Центральный район, ул. Муравьева Амурского, д.33	Россия, Хабаровский край, Хабаровск, улица Муравьева-Амурского, 33	0101000020E6100000033FAA613FE26040596ABDDF683D4840
8088	4	37	\N	718	2689	\N	48.473413999999998	Хабаровский край, г. Хабаровск, Центральный район, ул.Муравьева Амурского, д.20	Россия, Хабаровский край, Хабаровск, улица Муравьева-Амурского, 20	0101000020E61000009755D80CF0E16040F9BB77D4983C4840
8087	4	37	\N	718	2689	\N	48.471885	Хабаровский край, г. Хабаровск, Центральный район, ул. Муравьева Амурского, д.4	Россия, Хабаровский край, Хабаровск, улица Муравьева-Амурского, 4	0101000020E61000007BF7C77BD5E160408A3C49BA663C4840
8095	4	37	\N	718	2811	\N	48.489826000000001	Хабаровский край, г. Хабаровск, Центральный район, ул. Московская, д.10	Россия, Хабаровский край, Хабаровск, улица Московская, 10	0101000020E6100000F451465C80E26040815D4D9EB23E4840
7995	4	37	\N	718	1377	\N	48.380799000000003	Хабаровский край, г. Хабаровск, ул. Монтажная, д.40	Россия, Хабаровский край, Хабаровск, улица Монтажная, 40	0101000020E61000005F45460724E36040BDAC8905BE304840
7934	4	37	\N	718	444	\N	48.513644999999997	Хабаровский край, г.Хабаровск, ул.Мирная, д.16	Россия, Хабаровский край, Хабаровск, улица Мирная, 16	0101000020E61000008B6F287CB6E4604080608E1EBF414840
8004	4	37	\N	718	1514	\N	48.365913999999997	Хабаровский край, г. Хабаровск, ул. Мате Залки, д.50	Россия, Хабаровский край, Хабаровск, улица Мате Залки, 50	0101000020E6100000E6CDE15A6DE1604003931B45D62E4840
7992	4	37	\N	718	1318	\N	48.381798000000003	Хабаровский край, г. Хабаровск, ул. Малиновского, д.19	Россия, Хабаровский край, Хабаровск, улица Малиновского, 19	0101000020E610000011E50B5AC8E36040D0D6C1C1DE304840
8058	4	37	\N	718	2242	\N	48.564726999999998	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Майская, д.19А	Россия, Хабаровский край, Хабаровск, улица Майская, 19а	0101000020E6100000F16778B306E1604087156EF948484840
8032	4	37	\N	718	1890	\N	48.489575000000002	Хабаровский край, город Хабаровск, Кировский район, улица Льва Толстого, д.29	Россия, Хабаровский край, Хабаровск, улица Льва Толстого, 29	0101000020E61000006494675E0EE2604038F8C264AA3E4840
8082	4	37	\N	718	2610	\N	48.476664	Хабаровский край, г. Хабаровск, Центральный район, ул.Лермонтова, д.2	Россия, Хабаровский край, Хабаровск, улица Лермонтова, 2	0101000020E6100000161747E526E360401C977153033D4840
8070	4	37	\N	718	2423	\N	48.485055000000003	Хабаровский край, г. Хабаровск, Центральный район, ул. Ленинградская, д.21	Россия, Хабаровский край, Хабаровск, улица Ленинградская, 21	0101000020E6100000200890A1E3E2604072E14048163E4840
4892	4	37	\N	718	2423	\N	48.494770000000003	Хабаровский край, г.Хабаровск, ул.Ленинградская, д.71	Россия, Хабаровский край, Хабаровск, улица Ленинградская, 71	0101000020E61000007CB60E0E76E260405E85949F543F4840
8080	4	37	\N	718	2433	\N	48.467202	Хабаровский край, г. Хабаровск, Центральный район, ул.Ленина, д.6	Россия, Хабаровский край, Хабаровск, улица Ленина, 6	0101000020E6100000520ABABD24E260401A506F46CD3B4840
8077	4	37	\N	718	2433	\N	48.471018999999998	Хабаровский край, г. Хабаровск, Центральный район, ул. Ленина, д.24	Россия, Хабаровский край, Хабаровск, улица Ленина, 24	0101000020E61000008B8A389D64E26040B665C0594A3C4840
8076	4	37	\N	718	2433	\N	48.474245000000003	Хабаровский край, г. Хабаровск, Центральный район, ул.Ленина, д.39	Россия, Хабаровский край, Хабаровск, улица Ленина, 39	0101000020E6100000F88C446884E2604051A5660FB43C4840
8075	4	37	\N	718	2433	\N	48.469692999999999	Хабаровский край, г. Хабаровск, Центральный район, ул. Ленина, д.19	Россия, Хабаровский край, Хабаровск, улица Ленина, 19	0101000020E6100000A30227DB40E260407F1475E61E3C4840
8073	4	37	\N	718	2433	\N	48.480778999999998	Хабаровский край, г. Хабаровск, Центральный район, ул. Ленина, д.58	Россия, Хабаровский край, Хабаровск, улица Ленина, 58	0101000020E610000023BE13B3DEE2604042CD902A8A3D4840
8072	4	37	\N	718	2433	\N	48.478993000000003	Хабаровский край, г. Хабаровск, Центральный район, ул. Ленина, д.57	Россия, Хабаровский край, Хабаровск, улица Ленина, 57	0101000020E6100000D578E926B1E26040A80183A44F3D4840
33282	4	41	\N	16582	46253	\N	48.779257999999999	г. Биробиджан, 40 лет Победы, 25 Б		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
8071	4	37	\N	718	2433	\N	48.481830000000002	Хабаровский край, г. Хабаровск, Центральный район, ул. Ленина, д.73	Россия, Хабаровский край, Хабаровск, улица Ленина, 73	0101000020E61000009C8A5418DBE26040A81DFE9AAC3D4840
5490	4	37	\N	718	3226	\N	48.500745999999999	Хабаровский край, г.Хабаровск, ул.Лазо, д.3	Россия, Хабаровский край, Хабаровск, улица Лазо, 3	0101000020E6100000C078060D7DE2604029CDE67118404840
6534	4	37	\N	718	7625	\N	48.445565999999999	Хабаровский край, г. Хабаровск, ул. Кубяка, д.7	Россия, Хабаровский край, Хабаровск, улица Кубяка, 7	0101000020E6100000FA0B3D6274E36040D21A834E08394840
8061	4	37	\N	718	2273	\N	48.567129999999999	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Краснофлотская, д.8	Россия, Хабаровский край, Хабаровск, улица Краснофлотская, 8	0101000020E61000004850FC1873E160404D4A41B797484840
8248	4	37	\N	718	787	\N	48.432332000000002	Хабаровский край, г. Хабаровск, ул. Краснореченская,96	Россия, Хабаровский край, Хабаровск, улица Краснореченская, 96	0101000020E6100000419C871398E36040D481ACA756374840
7997	4	37	\N	718	787	\N	48.379787999999998	Хабаровский край, г. Хабаровск, ул. Краснореченская, д.19	Россия, Хабаровский край, Хабаровск, улица Краснореченская, 19	0101000020E6100000F86F5E9CF8E26040E5B4A7E49C304840
7976	4	37	\N	718	787	\N	48.390479999999997	Хабаровский край, г. Хабаровск, ул. Краснореченская, д.45	Россия, Хабаровский край, Хабаровск, улица Краснореченская, 45	0101000020E610000060764F1E16E36040FCDEA63FFB314840
7967	4	37	\N	718	787	\N	48.409550000000003	Хабаровский край, г. Хабаровск, ул. Краснореченская, д.107А	Россия, Хабаровский край, Хабаровск, улица Краснореченская, 107	0101000020E610000020EBA9D557E36040D50968226C344840
7963	4	37	\N	718	787	\N	48.421899000000003	Хабаровский край, г. Хабаровск, ул. Краснореченская, д.145	Россия, Хабаровский край, Хабаровск, улица Краснореченская, 145	0101000020E6100000931D1B8178E36040899B53C900364840
7959	4	37	\N	718	787	\N	48.444448000000001	Хабаровский край, г. Хабаровск, ул. Краснореченская, д.104	Россия, Хабаровский край, Хабаровск, улица Краснореченская, 104	0101000020E6100000DB6E826F9AE36040E5620CACE3384840
7958	4	37	\N	718	787	\N	48.446474000000002	Хабаровский край, г. Хабаровск, ул.Краснореченская,д.112	Россия, Хабаровский край, Хабаровск, улица Краснореченская, 112	0101000020E610000097AC8A7093E36040D5415E0F26394840
7931	4	37	\N	718	383	\N	48.520204	Хабаровский край, г.Хабаровск, ул.Краснодарская, д.47	Россия, Хабаровский край, Хабаровск, улица Краснодарская, 47	0101000020E6100000637FD93D79E36040CB9F6F0B96424840
7930	4	37	\N	718	383	\N	48.519381000000003	Хабаровский край, г.Хабаровск, ул.Краснодарская, д.51	Россия, Хабаровский край, Хабаровск, улица Краснодарская, 51	0101000020E6100000496760E465E36040F7949C137B424840
8092	4	37	\N	718	2771	\N	48.488774999999997	Хабаровский край, г. Хабаровск, Центральный район, ул.Красина, д.7	Россия, Хабаровский край, Хабаровск, улица Красина, 7	0101000020E6100000AE2EA70444E260401B0DE02D903E4840
7593	4	37	\N	718	4813	\N	48.480891999999997	Хабаровский край, г.Хабаровск, ул.Костромская, д.44	Россия, Хабаровский край, Хабаровск, улица Костромская, 44	0101000020E61000004DF564FED1E360403A747ADE8D3D4840
7951	4	37	\N	718	685	\N	48.456681000000003	Хабаровский край, г. Хабаровск, ул. Космическая, д.7	Россия, Хабаровский край, Хабаровск, улица Космическая, 7	0101000020E6100000950ED6FFB9E3604030DAE385743A4840
7953	4	37	\N	718	697	\N	48.454158999999997	Хабаровский край, г. Хабаровск, ул. Королева, д.3	Россия, Хабаровский край, Хабаровск, улица Королева, 3	0101000020E6100000DDD0949D7EE360408F17D2E1213A4840
7952	4	37	\N	718	697	\N	48.454529999999998	Хабаровский край, г. Хабаровск, ул. Королева, д.4Б		0101000020E610000011FE45D098E360408386FE092E3A4840
7922	4	37	\N	718	186	\N	48.441662999999998	Хабаровский край, г.Хабаровск, ул.Клубная, д.34	Россия, Хабаровский край, Хабаровск, улица Клубная, 34	0101000020E6100000FB5A971A21E46040376DC66988384840
8079	4	37	\N	718	298	\N	48.486255	Хабаровский край, г. Хабаровск, Центральный район, ул. Карла Маркса, д.68	Россия, Хабаровский край, Хабаровск, улица Карла Маркса, 68	0101000020E6100000EFA99CF694E260401C42959A3D3E4840
7936	4	37	\N	718	298	\N	48.498609000000002	Хабаровский край, г.Хабаровск, ул.Карла Маркса, д.95	Россия, Хабаровский край, Хабаровск, улица Карла Маркса, 95	0101000020E6100000C1CAA14536E36040E23E726BD23F4840
7935	4	37	\N	718	298	\N	48.505647000000003	Хабаровский край, г.Хабаровск, ул.Карла Маркса, д.107	Россия, Хабаровский край, Хабаровск, улица Карла Маркса, 107	0101000020E6100000AC36FFAF3AE360400729780AB9404840
7928	4	37	\N	718	298	\N	48.504752000000003	Хабаровский край, г.Хабаровск, ул.Карла Маркса, д.111	Россия, Хабаровский край, Хабаровск, улица Карла Маркса, 111	0101000020E61000000DAB782373E36040994BAAB69B404840
7927	4	37	\N	718	298	\N	48.504888999999999	Хабаровский край, г.Хабаровск, ул.Карла Маркса, д.113	Россия, Хабаровский край, Хабаровск, улица Карла Маркса, 113	0101000020E6100000126BF12980E36040198EE733A0404840
7926	4	37	\N	718	298	\N	48.503832000000003	Хабаровский край, г.Хабаровск, ул.Карла Маркса, д.136	Россия, Хабаровский край, Хабаровск, улица Карла Маркса, 136	0101000020E6100000931D1B8178E36040D25625917D404840
7925	4	37	\N	718	298	\N	48.499229999999997	Хабаровский край, г.Хабаровск, ул.Карла Маркса, д.120	Россия, Хабаровский край, Хабаровск, улица Карла Маркса, 120	0101000020E6100000D177B7B244E360404E97C5C4E63F4840
8025	4	37	\N	718	1766	\N	48.481715999999999	Хабаровский край, город Хабаровск, Кировский район, улица Калинина, д.117	Россия, Хабаровский край, Хабаровск, улица Калинина, 117	0101000020E6100000CBF3E0EEACE16040DFFAB0DEA83D4840
74090	4	36	\N	55290	59495	\N	44.591017280409098	Приморский край, г. Спасск-Дальний, Советская, 108/1		0101000020E610000071C63027E8996040A530EF71A64B4640
8023	4	37	\N	718	1766	\N	48.484032999999997	Хабаровский край, город Хабаровск, Кировский район, улица Калинина, д.152	Россия, Хабаровский край, Хабаровск, улица Калинина, 152	0101000020E610000045F12A6B9BE16040A69718CBF43D4840
8064	4	37	\N	718	2337	\N	48.575011000000003	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Ильича, д.35	Россия, Хабаровский край, Хабаровск, улица Ильича, 35	0101000020E6100000F1A1444B9EE160408EEBDFF599494840
8057	4	37	\N	718	2216	\N	48.558501999999997	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Зои Космодемьянской, д.26	Россия, Хабаровский край, Хабаровск, улица Зои Космодемьянской, 26	0101000020E6100000FB57569A14E16040136058FE7C474840
8021	4	37	\N	718	1426	\N	48.488822999999996	Хабаровский край, город Хабаровск, Кировский район, улица Знаменщикова, д.12	Россия, Хабаровский край, Хабаровск, улица Знаменщикова, 12	0101000020E6100000AA108FC4CBE160402C4487C0913E4840
8406	4	37	\N	718	6536	\N	48.449420000000003	Хабаровский край, Комсомольский район, с. Чёрный Мыс, ул. Зеленая, д. 12	Россия, Хабаровский край, Хабаровск, улица Зеленая, 12	0101000020E610000067F0F78B59E460408C15359886394840
8029	4	37	\N	718	1832	\N	48.481501000000002	Хабаровский край, город Хабаровск, Кировский район, улица Запарина, д.114	Россия, Хабаровский край, Хабаровск, улица Запарина, 114	0101000020E61000005019FF3EE3E16040E3FE23D3A13D4840
8017	4	37	\N	718	1683	\N	48.497163999999998	Хабаровский край, город Хабаровск, Кировский район, улица Забайкальская, д.7	Россия, Хабаровский край, Хабаровск, улица Забайкальская, 7	0101000020E6100000FF5D9F396BE16040D05FE811A33F4840
6763	4	37	\N	718	2591	\N	48.460773000000003	Хабаровский край, г.Хабаровск, ул.Жуковского, д.4	Россия, Хабаровский край, Хабаровск, улица Жуковского, 4	0101000020E6100000C5E6E3DAD0E560409EF0129CFA3A4840
8078	4	37	\N	718	2552	\N	48.471975	Хабаровский край, г. Хабаровск, Центральный район, ул. Дзержинского, д.3	Россия, Хабаровский край, Хабаровск, улица Дзержинского, 3	0101000020E610000014ECBFCE4DE26040CAC342AD693C4840
7932	4	37	\N	718	405	\N	48.509993000000001	Хабаровский край, г.Хабаровск, ул.Данчука, д.14	Россия, Хабаровский край, Хабаровск, улица Данчука, 14	0101000020E610000084656CE8E6E460402F185C7347414840
6749	4	37	\N	718	2383	\N	48.469042000000002	Хабаровский край, г.Хабаровск, ул.Горького, д.6	Россия, Хабаровский край, Хабаровск, улица Горького, 6	0101000020E61000006891ED7CBFE56040A8397991093C4840
7978	4	37	\N	718	1061	\N	48.392507999999999	Хабаровский край, г. Хабаровск, ул. Герцена, д.12	Россия, Хабаровский край, Хабаровск, улица Герцена, 12	0101000020E61000009C19FD6838E360408DB5BFB33D324840
7975	4	37	\N	718	1061	\N	48.394171999999998	Хабаровский край, г. Хабаровск, ул. Герцена, д.2	Россия, Хабаровский край, Хабаровск, улица Герцена, 2	0101000020E610000065E256410CE36040DC7F643A74324840
7704	4	37	\N	718	2925	\N	48.451594999999998	Хабаровский край, г.Хабаровск, ул.Гагарина, д.1Ж	Россия, Хабаровский край, Хабаровск, улица Гагарина, 1ж	0101000020E6100000B2D7BB3FDEE56040C0046EDDCD394840
7489	4	37	\N	718	2925	\N	48.459794000000002	Хабаровский край, г.Хабаровск, ул.Гагарина, д.13	Россия, Хабаровский край, Хабаровск, улица Гагарина, 13	0101000020E61000000727A25FDBE56040D272A087DA3A4840
7444	4	37	\N	718	2925	\N	48.454068999999997	Хабаровский край, г.Хабаровск, ул.Гагарина, д.2Г	Россия, Хабаровский край, Хабаровск, улица Гагарина, 2кг	0101000020E6100000EB707495EEE560404F90D8EE1E3A4840
5739	4	37	\N	718	6256	\N	48.506906999999998	Хабаровский край, г.Хабаровск, ул.Вяземская, д.7А	Россия, Хабаровский край, Хабаровск, улица Вяземская, 7а	0101000020E6100000EE60C43E81E26040868E1D54E2404840
7983	4	37	\N	718	1011	\N	48.394649999999999	Хабаровский край, г. Хабаровск, ул. Ворошилова, д.36	Россия, Хабаровский край, Хабаровск, улица Ворошилова, 36	0101000020E6100000AE9E93DEB7E36040E6AE25E483324840
7981	4	37	\N	718	1011	\N	48.395606999999998	Хабаровский край, г. Хабаровск, ул. Ворошилова, д.42	Россия, Хабаровский край, Хабаровск, улица Ворошилова, 42	0101000020E61000003C3080F0A1E36040CA880B40A3324840
7972	4	37	\N	718	1011	\N	48.398466999999997	Хабаровский край, г. Хабаровск, ул. Ворошилова, д.55	Россия, Хабаровский край, Хабаровск, улица Ворошилова, 53	0101000020E61000007D94111780E3604082C476F700334840
6217	4	37	\N	718	1306	\N	48.528511000000002	Хабаровский край, г.Хабаровск, ул.Воронежская, д.129	Россия, Хабаровский край, Хабаровск, улица Воронежская, 129	0101000020E6100000E1B3757030E26040C3499A3FA6434840
6051	4	37	\N	718	1306	\N	48.51728	Хабаровский край, г.Хабаровск, ул.Воронежская, д.77	Россия, Хабаровский край, Хабаровск, улица Воронежская, 77	0101000020E6100000D525E31849E26040FC6F253B36424840
7339	4	37	\N	718	1431	\N	48.456412	Хабаровский край, г.Хабаровск, ул.Воровского, д.24А		0101000020E6100000A9DC442DCDE5604040C05AB56B3A4840
7235	4	37	\N	718	1431	\N	48.454422000000001	Хабаровский край, г.Хабаровск, ул.Воровского, д.24Б	Россия, Хабаровский край, Хабаровск, улица Воровского, 24б	0101000020E6100000F1492712CCE560409D4A06802A3A4840
7108	4	37	\N	718	1431	\N	48.455641	Хабаровский край, г.Хабаровск, ул.Воровского, д.12	Россия, Хабаровский край, Хабаровск, улица Воровского, 12	0101000020E6100000BD1C76DFB1E56040BEDBBC71523A4840
7949	4	37	\N	718	544	\N	48.458249631403298	Хабаровский край, г. Хабаровск, ул. Волочаевская, д.1	Россия, Хабаровский край, Хабаровск, улица Волочаевская	0101000020E6100000A0DE8C9A2FE360402DB29DEFA73A4840
7946	4	37	\N	718	544	\N	48.459350999999998	Хабаровский край, г. Хабаровск, ул. Волочаевская, д.6Б	Россия, Хабаровский край, Хабаровск, улица Волочаевская, 6	0101000020E610000012A0A6962DE3604044317903CC3A4840
74121	4	36	\N	55290	59507	\N	44.584684399595702	Приморский край,  г. Спасск-Дальний, Складская, 6		0101000020E610000038109205CC9960404B3FE1ECD64A4640
7945	4	37	\N	718	544	\N	48.463951999999999	Хабаровский край, г. Хабаровск, ул. Волочаевская, д.30	Россия, Хабаровский край, Хабаровск, улица Волочаевская, 30	0101000020E61000002DCE18E604E36040F77475C7623B4840
7942	4	37	\N	718	544	\N	48.467972000000003	Хабаровский край, г. Хабаровск, ул. Волочаевская, д.83	Россия, Хабаровский край, Хабаровск, улица Волочаевская, 83	0101000020E6100000DF50F86C9DE26040CCB8A981E63B4840
7985	4	37	\N	718	1210	\N	48.402043999999997	Хабаровский край, г. Хабаровск, ул. Вологодская, д.24	Россия, Хабаровский край, Хабаровск, улица Вологодская, 24	0101000020E6100000A5F622DA0EE46040C9C6832D76334840
8016	4	37	\N	718	1682	\N	48.496912999999999	Хабаровский край, город Хабаровск, Кировский район, улица Брестская, д.51	Россия, Хабаровский край, Хабаровск, улица Брестская, 51	0101000020E61000003D9E961FB8E1604087FA5DD89A3F4840
7938	4	37	\N	718	484	\N	48.505158000000002	Хабаровский край, г.Хабаровск, ул.Большая, д.85	Россия, Хабаровский край, Хабаровск, улица Большая, 85	0101000020E61000008D7BF31BA6E2604009A87004A9404840
7937	4	37	\N	718	484	\N	48.500715999999997	Хабаровский край, г.Хабаровск, ул.Большая, д.30	Россия, Хабаровский край, Хабаровск, улица Большая, 30	0101000020E6100000EDD632190EE36040BE4A3E7617404840
5662	4	37	\N	718	5393	\N	48.506219999999999	Хабаровский край, г.Хабаровск, ул.Больничная, д.2Ж	Россия, Хабаровский край, Хабаровск, улица Больничная, 2ж	0101000020E610000045D4449F0FE26040624A24D1CB404840
8038	4	37	\N	718	1976	\N	48.510081999999997	Хабаровский край, город Хабаровск, Кировский район, улица Бойко-Павлова, д.20	Россия, Хабаровский край, Хабаровск, улица Бойко-Павлова, 20	0101000020E61000001101875025E160409E23F25D4A414840
8067	4	37	\N	718	15468	\N	48.554220000000001	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Богородская, д.6	Россия, Хабаровский край, Хабаровск, поселок Березовка, улица Богородская, 6	0101000020E6100000C1711937B5E36040026553AEF0464840
8008	4	37	\N	718	1565	\N	48.359358999999998	Хабаровский край, г. Хабаровск, ул. Балашовская, д.13	Россия, Хабаровский край, Хабаровск, улица Балашовская, 13	0101000020E6100000AD6BB41C68E06040FA42C879FF2D4840
7970	4	37	\N	718	953	\N	48.406165000000001	Хабаровский край, г. Хабаровск, ул. Аксенова, д.55	Россия, Хабаровский край, Хабаровск, улица Аксенова, 55	0101000020E61000001FF46C56FDE36040D2E3F736FD334840
7969	4	37	\N	718	953	\N	48.406320999999998	Хабаровский край, г. Хабаровск, ул. Аксенова, д.30А		0101000020E6100000F8A8BF5EE1E36040C956975302344840
8003	4	37	\N	718	1499	\N	48.365327000000001	Хабаровский край, г. Хабаровск, ул. Автобусная, д.10А		0101000020E6100000211D1EC278E1604043ACFE08C32E4840
8062	4	37	\N	718	2307	\N	48.574992999999999	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Авроры, д.12	Россия, Хабаровский край, Хабаровск, улица Авроры, 12	0101000020E6100000419E5DBE75E16040E736E15E99494840
8690	4	37	\N	718	18940	\N	48.497020999999997	Желездонодорожный вокзал, станция Хабаровс-1		0101000020E61000006FBC3B3256E260406D3656629E3F4840
7924	4	37	\N	718	22350	\N	48.493921999999998	Хабаровский край, г.Хабаровск, пр-т 60-летия Октября, д.212		0101000020E6100000BCCB457C27E3604030630AD6383F4840
8083	4	37	\N	718	22496	\N	48.463479999999997	Хабаровский край, г. Хабаровск, Центральный район, пер. Облачный, д.3		0101000020E6100000A1F2AFE515E36040CF2C0950533B4840
6656	4	37	\N	718	21711	\N	48.471559682554798	Хабаровский край, г.Хабаровск, кв.ДОС (Большой Аэродром), д.42А	Россия, Хабаровский край, Хабаровск, ДОС квартал, 42	0101000020E6100000EBC37AA3D6E36040060DFD135C3C4840
6559	4	37	\N	718	21711	\N	48.474775544322803	Хабаровский край, г.Хабаровск, кв.ДОС (Большой Аэродром), д.1А	Россия, Хабаровский край, Хабаровск, ДОС квартал	0101000020E6100000FE45D098C9E360407D76C075C53C4840
8065	4	37	\N	718	22573	\N	48.561483000000003	Хабаровский край, г. Хабаровск, Краснофлотский район, кв-л Энергетик, д.11		0101000020E610000012161571BAE360404721C9ACDE474840
8371	4	37	\N	718	77141	\N	48.555204000000003	Хабаровский край, г.Хабаровск,кв-л 70Лет Октября,д.7		0101000020E61000000C923EADA2E36040E04DB7EC10474840
6642	4	37	\N	718	22319	\N	48.466748325965398	Хабаровский край, г.Хабаровск, ул.Шкотова, д.14	Россия, Хабаровский край, Хабаровск, улица Шкотова	0101000020E6100000124C35B316E4604099BC0166BE3B4840
7955	4	37	\N	718	22235	\N	48.447500652762898	Хабаровский край, г. Хабаровск, ул. Шимановская, д.2А		0101000020E61000003A2009FB76E36040B2F677B647394840
7939	4	37	\N	718	22356	\N	48.505428294237497	Хабаровский край, г.Хабаровск, ул.Чехова, д.1А	Россия, Хабаровский край, Хабаровск, улица Чехова	0101000020E6100000317DAF2138E26040C93D5DDDB1404840
7964	4	37	\N	718	22765	\N	48.412559000000002	Хабаровский край, г. Хабаровск, ул. Центральная, д.15		0101000020E6100000C30FCEA78EE36040D255BABBCE344840
7962	4	37	\N	718	22592	\N	48.434408367638	Хабаровский край, г. Хабаровск, ул. Флегонтова, д.2А		0101000020E61000000E4E44BFB6E36040758F6CAE9A374840
8010	4	37	\N	718	1600	\N	48.466413000000003	Хабаровский край, г. Хабаровск, пер. Фабричный, д.23А		0101000020E61000008D2441B882E26040F2B6D26BB33B4840
7947	4	37	\N	718	621	\N	48.460821000000003	Хабаровский край, г. Хабаровск, пер. Трубный, д.7	Россия, Хабаровский край, Хабаровск, Трубный переулок, 7	0101000020E6100000E50CC51DEFE26040AF27BA2EFC3A4840
8011	4	37	\N	718	22351	\N	48.4728683456716	Хабаровский край, г. Хабаровск, ул. Слободская, д.27	Россия, Хабаровский край, Хабаровск, улица Слободская	0101000020E610000083C2A04CA3E2604097A949F0863C4840
5300	4	37	\N	718	22535	\N	48.496448000000001	Хабаровский край, г.Хабаровск, ул.Серышева, д.53		0101000020E6100000D4B9A29410E260401215AA9B8B3F4840
7987	4	37	\N	718	22570	\N	48.387901999999997	Хабаровский край, г. Хабаровск, ул. Рокоссовского, д.32А		0101000020E61000000C790437D2E36040C806D2C5A6314840
7954	4	37	\N	718	22324	\N	48.462602343274902	Хабаровский край, г. Хабаровск, ул. Пионерская, д.50	Россия, Хабаровский край, Хабаровск, улица Пионерская	0101000020E610000065E3C116BBE260403788D68A363B4840
8534	4	37	\N	718	22768	\N	48.472022000000003	Хабаровский край, Солнечный район, поселок ДСЗ, улица Новая, дом 20		0101000020E6100000001E51A1BAE560400B7F86376B3C4840
8009	4	37	\N	718	22192	\N	48.436660000000003	Хабаровский край, г. Хабаровск, пос. Уссурийский, ул. Насыпная, д.7		0101000020E6100000AD6EF59CF4E1604056BC9179E4374840
8513	4	37	\N	718	22619	\N	48.465235999999997	Хабаровский край, Охотский район, с. Резиденция, ул. Набережная, д. 8		0101000020E61000003A933655F7E16040FF756EDA8C3B4840
8508	4	37	\N	718	22619	\N	48.465235999999997	Хабаровский край, Охотский район, с. Вострецово, ул. Набережная, д. 7		0101000020E61000003A933655F7E16040FF756EDA8C3B4840
8093	4	37	\N	718	18981	\N	48.479877141299603	Хабаровский край, г. Хабаровск, Центральный район, ул.Муравьева Амурского, д.35	Россия, Хабаровский край, Хабаровск, улица Муравьева-Амурского, 33	0101000020E61000000400C79E3DE26040228D0A9C6C3D4840
8012	4	37	\N	718	1629	\N	48.461281	Хабаровский край, г. Хабаровск, пер. Молдавский, д.10		0101000020E61000001A170E84E4E2604012A27C410B3B4840
7933	4	37	\N	718	416	\N	48.514338000000002	Хабаровский край, г.Хабаровск, Матвеевское шоссе, д.23	Россия, Хабаровский край, Хабаровск, Матвеевское шоссе, 23	0101000020E6100000F2B1BB40C9E46040878BDCD3D5414840
8006	4	37	\N	718	22557	\N	48.362639999999999	Хабаровский край, г. Хабаровск, ул. Магаданская, д.11А		0101000020E6100000AA7EA5F361E16040581CCEFC6A2E4840
4716	4	37	\N	718	1607	\N	48.493240999999998	Хабаровский край, г.Хабаровск, пер.Ленинградский, д.9	Россия, Хабаровский край, Хабаровск, Ленинградский переулок, 9	0101000020E6100000D21A834E88E26040EE056685223F4840
8005	4	37	\N	718	22333	\N	48.393807000000002	Хабаровский край, г. Хабаровск, Краснореченская квартироно-эксплутационная часть района МОРФ, Хабаровск-41		0101000020E6100000ABED26F826E36040CBF78C4468324840
7918	4	37	\N	718	22537	\N	48.433800283266997	Хабаровский край, г.Хабаровск, ул.Клубная, д.1		0101000020E610000016DBA4A231E460409D8026C286374840
7998	4	37	\N	718	22525	\N	48.380505999999997	Хабаровский край, г.Хабаровск, ул.Каширская, д.21		0101000020E6100000D95F764F9EE2604044F7AC6BB4304840
7944	4	37	\N	718	22472	\N	48.468653526441699	Хабаровский край, г. Хабаровск, пер. Казарменный, д.15	Россия, Хабаровский край, Хабаровск, Картографический переулок	0101000020E61000003F19E3C3ECE26040DE91B1DAFC3B4840
8056	4	37	\N	718	2210	\N	48.481489000000003	Хабаровский край, г. Хабаровск, Центральный район, пер. Кадровый, д.8а	Россия, Хабаровский край, Хабаровск, Кадровый переулок, 8а	0101000020E6100000F67D384808E360401F317A6EA13D4840
7965	4	37	\N	718	893	\N	48.413420000000002	Хабаровский край, г. Хабаровск, пр-д Иртышский, д.6	Россия, Хабаровский край, Хабаровск, Иртышский проезд, 6	0101000020E6100000EFC7ED974FE3604094C151F2EA344840
6520	4	37	\N	718	7453	\N	48.466545000000004	Хабаровский край, г. Хабаровск, пер. Дзержинского, д.9	Россия, Хабаровский край, Хабаровск, Дзержинского переулок, 9	0101000020E610000093E4B9BE8FE26040618E1EBFB73B4840
6667	4	37	\N	718	21918	\N	48.460732	Хабаровский край, г.Хабаровск, ул.Георгиевская, д.37		0101000020E610000055C1A8A4CEE160403F1C2444F93A4840
8081	4	37	\N	718	22353	\N	48.468707000000002	Хабаровский край, г. Хабаровск, Центральный район, ул.Гамарника, д.11		0101000020E6100000ACFD9DED51E2604001344A97FE3B4840
6712	4	37	\N	718	1568	\N	48.481836000000001	Хабаровский край, г.Хабаровск, Восточное шоссе, д.2А	Россия, Хабаровский край, Хабаровск, Восточное шоссе, 2	0101000020E61000000A68226CF8E460408A0453CDAC3D4840
6690	4	37	\N	718	1568	\N	48.478780872585197	Хабаровский край, г.Хабаровск, Восточное шоссе, д.49	Россия, Хабаровский край, Хабаровск, Восточное шоссе	0101000020E6100000D4BB783F6EE460401C7920B2483D4840
7994	4	37	\N	718	22555	\N	48.382510000000003	Хабаровский край, г. Хабаровск, ул. Ворошилова, д.3А		0101000020E610000076A6D0798DE360404D327216F6304840
7941	4	37	\N	718	22559	\N	48.465159	Хабаровский край, г. Хабаровск, ул. Блюхера, д.2А		0101000020E61000001CCEFC6A8EE26040543882548A3B4840
7877	4	37	\N	718	22323	\N	48.431548999999997	Хабаровский край, г.Хабаровск, ул.Балтийская		0101000020E6100000138255F5F2E360408DCF64FF3C374840
7961	4	37	\N	718	816	\N	48.441381999999997	Хабаровский край, г. Хабаровск, пер. Байкальский, д.6	Россия, Хабаровский край, Хабаровск, Байкальский переулок, 6	0101000020E6100000FB78E8BB5BE36040838593347F384840
7960	4	37	\N	718	816	\N	48.440258	Хабаровский край, г. Хабаровск, пер. Байкальский, д.4А	Россия, Хабаровский край, Хабаровск, Байкальский переулок, 4ка	0101000020E610000085B69C4B71E36040B4E6C75F5A384840
7999	4	37	\N	718	22541	\N	48.377136	Хабаровский край, г. Хабаровск, ул. Артемовская, д.86А		0101000020E6100000873254C5D4E26040771211FE45304840
8086	4	37	\N	718	1802	\N	48.482672000000001	Хабаровский край, г. Хабаровск, Центральный район, Амурский бульвар, д.34	Россия, Хабаровский край, Хабаровск, Амурский бульвар, 34	0101000020E6100000861F9C4F1DE26040F3583332C83D4840
8033	4	37	\N	718	1802	\N	48.489539000000001	Хабаровский край, город Хабаровск, Кировский район, бульвар Амурский, д.43	Россия, Хабаровский край, Хабаровск, Амурский бульвар, 43	0101000020E61000009EB29AAE27E26040EB8EC536A93E4840
8030	4	37	\N	718	1802	\N	48.483668999999999	Хабаровский край, город Хабаровск, Кировский район, бульвар Амурский, д.27	Россия, Хабаровский край, Хабаровск, Амурский бульвар, 27	0101000020E6100000AA7CCF4804E26040658BA4DDE83D4840
8026	4	37	\N	718	1802	\N	48.476263000000003	Хабаровский край, город Хабаровск, Кировский район, бульвар Амурский, д.1	Россия, Хабаровский край, Хабаровск, Амурский бульвар, 1	0101000020E6100000EB7420EBA9E16040BEA59C2FF63C4840
8002	4	37	\N	718	22330	\N	48.381449944045301	Хабаровский край, г. Хабаровск, ул. Алеутская, д.27	Россия, Хабаровский край, Хабаровск, улица Алеутская	0101000020E6100000F8C1F9D431E260409487855AD3304840
73995	4	36	\N	9761	44885	\N	43.114483	"Приморский край, город Партизанск, Свердлова, 7 ""а"""		0101000020E610000077DCF0BB69A4604057790261A78E4540
7923	4	37	\N	718	264	\N	48.481243999999997	Хабаровский край, г.Хабаровск, пр-т 60-летия Октября, д.156	Россия, Хабаровский край, Хабаровск, 60 Лет Октября проспект, 156	0101000020E6100000FA5FAE458BE36040B7B24467993D4840
8034	4	37	\N	718	22764	\N	48.491844	Хабаровский край, город Хабаровск, Кировский район, улица Герасимова, д.16		0101000020E61000005C72DC291DE26040EE5D83BEF43E4840
7971	4	37	\N	718	22495	\N	48.402858000000002	Хабаровский край, г. Хабаровск, ул. Архангельская, д.50		0101000020E6100000763579CAEAE360404B77D7D990334840
8499	4	37	\N	61564	79395	\N	59.362213011232299	Хабаровский край, Охотский район, р.п. Охотск, ул. Коммунистическая, д. 61		0101000020E6100000210725CCB4E76140D097DEFE5CAE4D40
8129	4	37	\N	49990	\N	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, Клуб жилого мкр.Старт		0101000020E6100000CDB051D66F20614045292158554D4940
8145	4	37	\N	49990	21868	\N	50.539613031674399	Хабаровский край, г.Комсомольск-на-Амуре, пр.Октябрьский, д.26, корп.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000378C82E0712061408CBFED0912454940
8141	4	37	\N	49990	21868	\N	50.536026775137898	Хабаровский край, г.Комсомольск-на-Амуре, пр.Октябрьский, д.19	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000A80018CFA0206140F16261889C444940
8122	4	37	\N	49990	21930	\N	50.578538230091901	Хабаровский край, г.Комсомольск-на-Амуре, пр.Московский, д.22, корп.4	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000003197546DB721614023BF7E880D4A4940
8121	4	37	\N	49990	21930	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, пр.Московский, д.24		0101000020E6100000CDB051D66F20614045292158554D4940
8120	4	37	\N	49990	21930	\N	50.582992182665798	Хабаровский край, г.Комсомольск-на-Амуре, пр.Московский, д.20	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000323ECC5EB621614031EA5A7B9F4A4940
8148	4	37	\N	49990	22252	\N	50.604317209682499	Хабаровский край, г.Комсомольск-на-Амуре, пр.Мира, д.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000F96706F1812061405BB56B425A4D4940
8176	4	37	\N	49990	21946	\N	50.540936014191999	Хабаровский край, г.Комсомольск-на-Амуре, пр.Ленина, д.74, корп.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000084BD8921B91F6140529D0E643D454940
8162	4	37	\N	49990	21946	\N	50.547622145660199	Хабаровский край, г.Комсомольск-на-Амуре, пр.Ленина, д.44, корп.4	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000065A6B4FE16206140F9484A7A18464940
8159	4	37	\N	49990	21946	\N	50.606320693582099	Хабаровский край, г.Комсомольск-на-Амуре, пр.Ленина, д.11	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000007C6308008E20614063F030ED9B4D4940
8138	4	37	\N	49990	21946	\N	50.541236842219	Хабаровский край, г.Комсомольск-на-Амуре, пр.Ленина, д.45		0101000020E6100000A5A14621C91F61404D31074147454940
8102	4	37	\N	49990	21925	\N	50.604381646814701	Хабаровский край, г.Комсомольск-на-Амуре, пр.Копылова, д.43	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000B01D8CD8A72061404225AE635C4D4940
8137	4	37	\N	49990	22242	\N	50.536628492228601	Хабаровский край, г.Комсомольск-на-Амуре, пр.Интернациональный, д.33, корп.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000073F38DE81E206140170FEF39B0444940
8136	4	37	\N	49990	22242	\N	50.536095152468697	Хабаровский край, г.Комсомольск-на-Амуре, пр.Интернациональный, д.31, корп.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000008C135FED282061404A46CEC29E444940
8108	4	37	\N	49990	22063	\N	50.607863680438101	Хабаровский край, г.Комсомольск-на-Амуре, ул.Щорса, д.50		0101000020E61000004E44BFB67E2061403735D07CCE4D4940
8165	4	37	\N	49990	22086	\N	50.541551342184597	Хабаровский край, г.Комсомольск-на-Амуре, ул.Чапаева, д.1	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000088B9A46ABB1F6140DC0E0D8B51454940
8111	4	37	\N	49990	22267	\N	50.606351843985799	Хабаровский край, г.Комсомольск-на-Амуре, ул.Сусанина, д.55	Россия, Хабаровский край, Комсомольский район	0101000020E610000060B01BB6AD2061409EEE3CF19C4D4940
8109	4	37	\N	49990	22267	\N	50.605235110395903	Хабаровский край, г.Комсомольск-на-Амуре, ул.Сусанина, д.67	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000049F608354320614081B22957784D4940
8179	4	37	\N	49990	21970	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Сортировочная, д.7, корп.2		0101000020E6100000CDB051D66F20614045292158554D4940
8101	4	37	\N	49990	22040	\N	50.583176616355097	Хабаровский край, г.Комсомольск-на-Амуре, ул.Советская, д.11	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000001DE4F56052226140C3633F8BA54A4940
8184	4	37	\N	49990	22278	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, Северное шоссе, д.10, корп.3		0101000020E6100000CDB051D66F20614045292158554D4940
8158	4	37	\N	49990	21944	\N	50.546993225031102	Хабаровский край, г.Комсомольск-на-Амуре, ул.Севастопольская, д.51	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000041B8020A752061400A12DBDD03464940
8170	4	37	\N	49990	22273	\N	50.606238763654098	Хабаровский край, г.Комсомольск-на-Амуре, ул.Пирогова, д.21		0101000020E61000004B2366F679206140A647533D994D4940
8166	4	37	\N	49990	22273	\N	50.550212936268103	Хабаровский край, г.Комсомольск-на-Амуре, ул.Пирогова, д.34, корп.3		0101000020E61000008F183DB7501F6140C26A2C616D464940
8096	4	37	\N	49990	22293	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Пермская, д.5, корп.3		0101000020E6100000CDB051D66F20614045292158554D4940
8156	4	37	\N	49990	22294	\N	50.607768098659598	Хабаровский край, г.Комсомольск-на-Амуре, ул.Партизанская, д.10		0101000020E61000008A3DB48F9520614015C78157CB4D4940
8181	4	37	\N	49990	22102	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Охотская, д.1		0101000020E6100000CDB051D66F20614045292158554D4940
8105	4	37	\N	49990	22018	\N	50.589904534057602	Хабаровский край, г.Комсомольск-на-Амуре, ул.Орехова, д.67	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000A0353FFE522261409A5FCD01824B4940
8150	4	37	\N	49990	21940	\N	50.535643860243901	Хабаровский край, г.Комсомольск-на-Амуре, ул.Орджоникидзе, д.4	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000D42AFA43B320614039268BFB8F444940
8152	4	37	\N	49990	22400	\N	50.609037954926201	Хабаровский край, г.Комсомольск-на-Амуре, пр.Мира, д.23		0101000020E610000070E998F38C206140B8020AF5F44D4940
8188	4	37	\N	49990	22307	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Мачтовая, д.9		0101000020E6100000CDB051D66F20614045292158554D4940
8097	4	37	\N	49990	21906	\N	50.5805876473746	Хабаровский край, г.Комсомольск-на-Амуре, ул.Ломоносова, д.18	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000C2DF2F66CB2261409B3924B5504A4940
8154	4	37	\N	49990	22255	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Летчиков, д.19		0101000020E6100000CDB051D66F20614045292158554D4940
8117	4	37	\N	49990	21786	\N	50.590806069892501	Хабаровский край, г.Комсомольск-на-Амуре, ул.Ленинградская, д.63	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000000AA2EE0310226140EA23F0879F4B4940
8116	4	37	\N	49990	21786	\N	50.606470898077603	Хабаровский край, г.Комсомольск-на-Амуре, ул.Ленинградская, д.64		0101000020E6100000D2C26515B6206140787C7BD7A04D4940
8115	4	37	\N	49990	21786	\N	50.582035848186301	Хабаровский край, г.Комсомольск-на-Амуре, ул.Ленинградская, д.35	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000004CB1132102261401E8CD827804A4940
8106	4	37	\N	49990	21786	\N	50.606081730891198	Хабаровский край, г.Комсомольск-на-Амуре, ул.Ленинградская, д.79	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000008E05854199206140DE585018944D4940
8124	4	37	\N	49990	22072	\N	50.608007052739701	Хабаровский край, г.Комсомольск-на-Амуре, ул.Лазо, д.23		0101000020E610000028D714C86C2061409A5E622CD34D4940
8112	4	37	\N	49990	22072	\N	50.593558378727003	Хабаровский край, г.Комсомольск-на-Амуре, ул.Лазо, д.79	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000CE37A27B56216140BC2363B5F94B4940
8110	4	37	\N	49990	21848	\N	50.600817414695697	Хабаровский край, г.Комсомольск-на-Амуре, ул.Культурная, д.18	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000004CC11A6753216140BFF04A92E74C4940
8107	4	37	\N	49990	21848	\N	50.599847787351301	Хабаровский край, г.Комсомольск-на-Амуре, ул.Культурная, д.3	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000000AAB8710B2261401749BBD1C74C4940
8185	4	37	\N	49990	22104	\N	50.570366995252101	Хабаровский край, г.Комсомольск-на-Амуре, ул.Копровая, д.1	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000060E4654DAC1F6140DBDB2DC901494940
8143	4	37	\N	49990	22069	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Комсомольская, д.45		0101000020E6100000CDB051D66F20614045292158554D4940
8151	4	37	\N	49990	22166	\N	50.561825301939997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Кирова, д.24	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000B1F84D61A5206140A089B0E1E9474940
8103	4	37	\N	49990	21779	\N	50.590778750879799	Хабаровский край, г.Комсомольск-на-Амуре, ул.Калинина, д.29	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000657094BC3A226140F01472A59E4B4940
8100	4	37	\N	49990	21779	\N	50.609461232690798	Хабаровский край, г.Комсомольск-на-Амуре, ул.Калинина, д.7	Россия, Хабаровский край, Комсомольский район	0101000020E6100000CD5A0A487B206140FF976BD1024E4940
8172	4	37	\N	49990	22173	\N	50.549098708772803	Хабаровский край, г.Комсомольск-на-Амуре, ул.Дикопольцева, д.34, корп.5	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000A4518193ED1E614016A243E048464940
8149	4	37	\N	49990	21876	\N	50.5280396172992	Хабаровский край, г.Комсомольск-на-Амуре, ул.Дзержинского, д.12	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000001E520C90682061406B7D91D096434940
8178	4	37	\N	49990	22250	\N	50.6059895592415	Хабаровский край, г.Комсомольск-на-Амуре, ул.Вокзальная, д.80, корп.3		0101000020E6100000D270CADC7C206140FDD98F14914D4940
8133	4	37	\N	49990	21937	\N	50.606798615303298	Хабаровский край, г.Комсомольск-на-Амуре, Аллея Труда, д.55, корп.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000062F54718862061406D1FF296AB4D4940
8171	4	37	\N	50483	22276	\N	50.609140361188103	Хабаровский край, г.Комсомольск-на-Амуре, ул.Гамарника, д.16	Россия, Хабаровский край, Комсомольский район	0101000020E6100000CAFE791AB0206140BC57AD4CF84D4940
8451	4	37	7534	61571	79407	\N	47.877603202333802	Хабаровский край, район имени Лазо, с. Второй Сплавной Участок, ул. Центральная, д. 4	Россия, Хабаровский край, Имени Лазо район	0101000020E610000089450C3B8CEF60408DEF8B4B55F04740
8460	4	37	7003	49969	18954	\N	47.778267999999997	Хабаровский край, район имени Лазо, с. Бичевая, ул. Набережная, д. 22		0101000020E610000052B9895A1AF46040FCC22B499EE34740
8090	4	37	7082	50509	22466	\N	48.477304282670403	Хабаровский край, г. Хабаровск, Центральный район, пер. Призывной, д.1	Россия, Хабаровский край, Хабаровск, Призывной переулок	0101000020E6100000F1129CFA40E36040FF1F274C183D4840
8626	4	37	249	3570	19183	\N	48.513137999999998	Хабаровский край, Хабаровский район, с.Чистополье, ул.Центральная, д.8		0101000020E61000002F34D76924E86040DC2A8881AE414840
8625	4	37	249	50956	24158	\N	48.4687491747503	Хабаровский край, Хабаровский район, с.Черная речка, ул.Центральная, д.30	Россия, Хабаровский край, Хабаровский район, село Черная Речка	0101000020E6100000EE0A7DB00CEA604030849CF7FF3B4840
8609	4	37	249	2564	22202	\N	48.878583999999996	Хабаровский край, Хабаровский район, с.Челны, ул.Набережная, д.3		0101000020E6100000FD3383F8C0006140F964C57075704840
8600	4	37	249	2073	21941	\N	48.596812	Хабаровский край, Хабаровский район, с.Федоровка, ул.Зеленая, д.13а		0101000020E610000002BC051294E5604020EEEA55644C4840
8608	4	37	249	2548	19272	\N	48.759650999999998	Хабаровский край, Хабаровский район, с.Улика-Национальное, ул.Юбилейная, д.10		0101000020E6100000F1F6200464C76040D5AF743E3C614840
8585	4	37	249	50488	22320	\N	48.508417433628097	Хабаровский край, Хабаровский район, с.Тополево, ул.Школьная, д.4а	Россия, Хабаровский край, село Тополево, улица Школьная	0101000020E61000008ECC237FB0E560407FDDE9CE13414840
8584	4	37	249	50488	22320	\N	48.507981000000001	Хабаровский край, Хабаровский район, с.Тополево, ул. Школьная, д.4		0101000020E610000045813E91A7E56040A4FE7A8505414840
8615	4	37	249	2914	21742	\N	48.602257999999999	Хабаровский край, Хабаровский район, с.Таежное, ул.Интернациональная, д.13		0101000020E6100000DC2DC9013BF360408FE046CA164D4840
8599	4	37	249	50445	21934	\N	48.331969000000001	Хабаровский край, Хабаровский район, с.Сосновка, ул.площадь Мира, д.4		0101000020E6100000E7340BB43BE260409624CFF57D2A4840
8598	4	37	249	50445	22289	\N	48.331969000000001	Хабаровский край, Хабаровский район, с.Сосновка, ул.Шоссейная, д.34		0101000020E6100000E7340BB43BE260409624CFF57D2A4840
8588	4	37	249	1372	22309	\N	48.559139999999999	Хабаровский край, Хабаровский район, с.Смирновка, ул.Молодежная, д.26		0101000020E6100000605628D2FDE9604056F146E691474840
8612	4	37	249	2749	19276	\N	48.750397	Хабаровский край, Хабаровский район, с.Сикачи-Алян, ул.Октябрьская, д.1а		0101000020E6100000BEA59C2F76F460401D0247020D604840
8624	4	37	249	3462	19282	\N	48.472529999999999	Хабаровский край, Хабаровский район, с.Сергеевка, ул.Партизанская, д.5		0101000020E6100000E7AA798E48EC60407F30F0DC7B3C4840
8631	4	37	249	50449	21990	\N	48.402493	Хабаровский край, Хабаровский район, с.Ракитное, ул.Центральная, д.28а		0101000020E6100000F37519FE53E6604039EFFFE384334840
8605	4	37	249	2364	19268	\N	49.054789999999997	Хабаровский край, Хабаровский район, с.Победа, пер.Безымянный, д.4		0101000020E6100000C6A354C293CA6040EC12D55B03874840
8614	4	37	249	2902	22125	\N	48.682755999999998	Хабаровский край, Хабаровский район, с.Петропавловка, ул.Советская, д.29		0101000020E6100000B7EEE6A90EF16040EA92718C64574840
8606	4	37	249	2415	21861	\N	49.063473999999999	Хабаровский край, Хабаровский район, с.Пасека, ул.Пионерская, д.7		0101000020E61000008A8EE4F21FCB6040BA1281EA1F884840
8607	4	37	249	2469	22122	\N	48.850141999999998	Хабаровский край, Хабаровский район, с.Новокуровка, ул.Советская, д.30		0101000020E61000002E1C08C902CA60405F7AFB73D16C4840
8633	4	37	249	1021	19290	\N	48.348612000000003	Хабаровский край, Хабаровский район, с.Некрасовка, ул.Ленина, д.20		0101000020E6100000AD86C43D96E76040207F69519F2C4840
8582	4	37	249	1021	19290	\N	48.348612000000003	Хабаровский край, Хабаровский район, с.Некрасовка, ул.Ленина, д.1		0101000020E6100000AD86C43D96E76040207F69519F2C4840
8604	4	37	249	2320	21860	\N	48.993822999999999	Хабаровский край, Хабаровский район, с.Нумовка, ул.Центральная, д.19		0101000020E6100000F1F274AEA8AD60409D819197357F4840
8602	4	37	249	50467	22121	\N	48.604188000000001	Хабаровский край, Хабаровский район, с.Нагорное, ул.Центральная, д.8а		0101000020E610000023C0E95D3CE260405D514A08564D4840
8601	4	37	249	50493	22338	\N	48.619478999999998	Хабаровский край, Хабаровский район, с.Мичуринское, ул.Парковая, д.7		0101000020E6100000333509DE90E3604086C77E164B4F4840
8628	4	37	249	3678	22198	\N	48.485920999999998	Хабаровский край, Хабаровский район, с.Мирное, ул.Рабочая, д.6		0101000020E61000009C86A8C21FE7604045B8C9A8323E4840
8586	4	37	249	50447	21983	\N	48.549050000000001	Хабаровский край, Хабаровский район, с.Матвеевка, ул.Центральная, д.38б		0101000020E6100000BA4DB857E6E5604035EF384547464840
8593	4	37	249	50447	22342	\N	48.557786	Хабаровский край, Хабаровский район, с.Осиновая речка, ул.40 лет Победы, д.5		0101000020E6100000A165DD3F16E6604055151A8865474840
8613	4	37	249	2805	21871	\N	48.730594000000004	Хабаровский край, Хабаровский район, с.Малышево, ул.Первомайская, д.33		0101000020E6100000EE0A7DB08CF36040B153AC1A845D4840
8603	4	37	249	2216	18901	\N	49.196655	Хабаровский край, Хабаровский район,с.Кукан, ул.Новая, д.1		0101000020E6100000B421FFCC20AF604025CCB4FD2B994840
8595	4	37	249	1761	19156	\N	48.350175	Хабаровский край, Хабаровский район, с.Краснореченское, ул.Мостовая, д.6		0101000020E61000001F4C8A8FCFDF60403B70CE88D22C4840
8596	4	37	249	1848	19262	\N	48.222504999999998	Хабаровский край, Хабаровский район, п.Корфовский, ул.Таежная, д.2а		0101000020E6100000207BBDFBE3E160402619390B7B1C4840
8597	4	37	249	1848	19263	\N	48.222504999999998	Хабаровский край, Хабаровский район, п.Корфовский, ул.Владивостокская, д.24		0101000020E6100000207BBDFBE3E160402619390B7B1C4840
8594	4	37	249	1714	21980	\N	48.348959000000001	Хабаровский край, Хабаровский район, с.Корсаково, ул.Школьная, д.6		0101000020E61000005D70067FBFDE60408B5242B0AA2C4840
8590	4	37	249	1514	21773	\N	48.586067999999997	Хабаровский край, Хабаровский район, с.Константиновка, ул.Международная, д.14/1		0101000020E61000006D7022FA35EE6040B69DB646044B4840
8619	4	37	249	3138	22012	\N	48.478211000000002	Хабаровский край, Хабаровский район, с.Князе-Волконское 1, ул.квартал ДОС, д.МОУ СОШ с.Князе-Волконское 1		0101000020E6100000B492567CC3EE604032CB9E04363D4840
8617	4	37	249	3138	22012	\N	48.4793523039543	Хабаровский край, Хабаровский район, с.Князе-Волконское 1, ул.квартал ДОС, д.Гарнизонный Дом офицеров	Россия, Хабаровский край, Хабаровский район, село Князе-Волконское	0101000020E6100000EE96E480DDEE6040D7A205685B3D4840
8620	4	37	249	3138	21756	\N	48.478211000000002	Хабаровский край, Хабаровский район, с. Князе-Волконское, ул.Никитенко, д.18		0101000020E6100000B492567CC3EE604032CB9E04363D4840
8623	4	37	249	3374	19179	\N	48.432948000000003	Хабаровский край, Хабаровский район, с.Калинка, ул.Авиаторов, д.3		0101000020E6100000BB0F406A93ED60402F6F0ED76A374840
8591	4	37	249	1521	19155	\N	48.268058000000003	Хабаровский край, Хабаровский район, с.Казакевичево, ул.Новожилова, д.13		0101000020E6100000F24410E761D7604031B77BB94F224840
8583	4	37	249	50505	22435	\N	48.368853000000001	Хабаровский край, Хабаровский район, с.Ильинка, ул.Совхозная, д.32а		0101000020E6100000836C59BEAEE3604008043A93362F4840
8587	4	37	249	1318	22114	\N	48.600285999999997	Хабаровский край, Хабаровский район, с.Заозерное, ул.Петра Черкасова, д.5а		0101000020E6100000FDBE7FF362E76040921FF12BD64C4840
8610	4	37	249	2659	22203	\N	48.799582000000001	Хабаровский край, Хабаровский район, с.Елабуга, ул.Новая, д.1		0101000020E610000063997E8978FB6040323CF6B358664840
8629	4	37	249	3693	21740	\N	48.385209000000003	Хабаровский край, Хабаровский район, с.Дружба, ул.Центральная, д.23		0101000020E61000003201BF4612EA6040FC8F4C874E314840
8632	4	37	249	50451	21993	\N	48.408492000000003	Хабаровский край, Хабаровский район, с.Гаровка 2, ул.ДОС, д.18а		0101000020E61000008524B37A07E76040BD56427749344840
8630	4	37	249	50491	22334	\N	48.445690999999997	Хабаровский край, Хабаровский район, с.Гаровка1, ул.Центральная, д.46а		0101000020E61000006214048FEFE660408E8F16670C394840
8589	4	37	249	1418	21851	\N	48.563183000000002	Хабаровский край, Хабаровский район, с.Галкино, ул.Мира, д.15а		0101000020E610000059A31EA2D1EB6040E3546B6116484840
8611	4	37	249	2703	18941	\N	48.739114999999998	Хабаровский край, Хабаровский район, с.Вятское, ул.Набережная, д.53		0101000020E610000014EB54F91EF76040D47D00529B5E4840
8627	4	37	249	3583	19255	\N	48.482678	Хабаровский край, Хабаровский район, с.Восточное, ул.Клубная, д.1		0101000020E610000024D6E25380E86040D53F8864C83D4840
8592	4	37	249	1619	22193	\N	48.300164000000002	Хабаровский край, Хабаровский район, с.Бычиха, ул.Новая, д.12		0101000020E6100000091A33897ADA6040E1B721C66B264840
8622	4	37	249	3359	19177	\N	48.423239000000002	Хабаровский край, Хабаровский район, с.Благодатное, ул.Школьная, д.1		0101000020E6100000F2B5679684EF604025B20FB22C364840
8616	4	37	249	2999	22128	\N	48.574922000000001	Хабаровский край, Хабаровский район,с.Анастасьевка, ул.Бойко Павлова, д.28		0101000020E61000000EA14ACD1EF260401EE0490B97494840
8567	4	37	65	50522	22575	\N	52.216836000000001	Хабаровский край, Ульчский район, с.Булава (Новая), Набережная, 3		0101000020E6100000193DB7D0156A6140384C3448C11B4A40
8579	4	37	65	823	21714	\N	51.341040999999997	Хабаровский край, Ульчский район, п.Циммермановка, Железнодорожная, 35		0101000020E61000001D93C5FDC76761402DCC423BA7AB4940
8559	4	37	65	32152	19239	\N	52.376317999999998	Хабаровский край, Ульчский район, с.Ухта, Центральная, 4		0101000020E6100000C4279D48B08C6140B4722F302B304A40
8555	4	37	65	32067	22100	\N	52.930214999999997	Хабаровский край, Ульчский район, с.Тыр, Ленина, 20		0101000020E61000001CEA77616B786140D39FFD4811774A40
8553	4	37	65	4028	21829	\N	53.129899000000002	Ульчский район, с. Тахта, ул. Комсомольская, д.17		0101000020E61000005E4A5D320E7B61403D64CA87A0904A40
8557	4	37	65	32079	22299	\N	52.785839000000003	Хабаровский край, Ульчский район, с.Сусанино, Центральная, 80		0101000020E6100000D38558FD91826140EF75525F96644A40
8574	4	37	65	532	22308	\N	51.568319000000002	Хабаровский край, Ульчский район, с.Софийск, Центральная, 17		0101000020E610000096B20C712C7B614004594FADBEC84940
8575	4	37	65	532	22109	\N	51.568319000000002	Хабаровский край, Ульчский район, с.Софийск, Кирова, 11		0101000020E610000096B20C712C7B614004594FADBEC84940
8563	4	37	65	32409	22028	\N	52.256914999999999	Хабаровский край, Ульчский район, с.Солонцы, Школьная, 4		0101000020E61000000F4240BE04886140096D3997E2204A40
8566	4	37	65	32495	22304	\N	52.160420999999999	Хабаровский край, Ульчский район, с.Савинское, Амурская, 9		0101000020E6100000EEB3CA4CE98B6140BA4BE2AC88144A40
8578	4	37	65	813	19152	\N	51.416687000000003	Хабаровский край, Ульчский район, п.Решающий, Советская, 17		0101000020E61000008FC6A17E177161408DD5E6FF55B54940
8558	4	37	65	32134	22302	\N	52.438876	Хабаровский край, Ульчский район, с.Нижняя Гавань, Амурская, 21		0101000020E6100000499F56D19F8D6140E97FB9162D384A40
8569	4	37	65	208	21978	\N	51.727103	Хабаровский край, Ульчский район, с.Мариинское, Ленина, 3		0101000020E61000002A70B20D5C86614068E90AB611DD4940
8571	4	37	65	318	21835	\N	51.709566000000002	Хабаровский край, Ульчский район, п.Мариинский Рейд, Пионерская, 18		0101000020E61000002B8881AE7D866140412D060FD3DA4940
8564	4	37	65	32405	19137	\N	52.229050999999998	Хабаровский край, Ульчский район, с.Кольчем, Озерная, 7		0101000020E610000067F2CD36B7856140DC0E0D8B511D4A40
8581	4	37	65	971	22111	\N	51.464703999999998	Хабаровский край, Ульчский район, п.Ключевой, Школьный, 2		0101000020E6100000F56393FC885F61400229B16B7BBB4940
8554	4	37	65	30490	21964	\N	52.972448	Ульчский район, с. Кальма, пер. Школьный,9/1, сельская библиотека		0101000020E6100000016BD5AE89776140C287122D797C4A40
8576	4	37	65	663	19351	\N	51.545903000000003	Хабаровский край, Ульчский район, с.Калиновка, Таежная, 13		0101000020E61000000F9C33A2B4766140E7E44526E0C54940
8565	4	37	65	32415	19349	\N	52.092115999999997	Хабаровский край, Ульчский район, с.Дуди, Школьная, 2		0101000020E6100000062FFA0A528661401BB80375CA0B4A40
8573	4	37	65	482	21837	\N	51.475684000000001	Хабаровский край, Ульчский район, п.Де-Кастри, Клубная, 3		0101000020E6100000D47D00529B986140809D9B36E3BC4940
8577	4	37	65	713	19150	\N	51.432091999999997	Хабаровский край, Ульчский район, с.Быстринск, Набережная, 12		0101000020E6100000096EA46C116F61407E6E68CA4EB74940
8568	4	37	65	50527	22599	\N	51.942030277827897	Хабаровский край, Ульчский район, с.Булава (Старая), Советская, 9	Россия, Хабаровский край, Ульчский район, село Булава	0101000020E6100000DCBC7152188D6140EAEC647094F84940
8572	4	37	65	434	19242	\N	51.645592999999998	Хабаровский край, Ульчский район, с.Большие Санники, Аптечная, 4		0101000020E61000000B0E2F88C88E614065C39ACAA2D24940
74004	4	36	\N	9761	44730	\N	43.111289634569602	Приморский край, Партизанский городской округ, Садовая, 2		0101000020E61000003F1D8F19A8A36040982F2FC03E8E4540
8561	4	37	65	32220	19136	\N	52.370049999999999	Хабаровский край, Ульчский район, с.Богородское, Партизанская, 7		0101000020E6100000F04DD367878E614041F163CC5D2F4A40
8560	4	37	65	32220	21830	\N	52.370049999999999	Хабаровский край, Ульчский район, с.Богородское, Парковая, 8		0101000020E6100000F04DD367878E614041F163CC5D2F4A40
8562	4	37	65	32220	22184	\N	52.370049999999999	Хабаровский край, Ульчский район, с.Богородское, Ключевая, 2а		0101000020E6100000F04DD367878E614041F163CC5D2F4A40
8556	4	37	65	32059	19301	\N	52.766609000000003	Хабаровский край, Ульчский район, с.Аннинские Миниральные Воды, Центральная, 2		0101000020E61000006A31789876856140DEE8633E20624A40
8549	4	37	1919	31714	21957	\N	54.715648999999999	Хабаровский край, Тугуро-Чумиканский район, с. Чумикан, ул. Таранца, д. 30		0101000020E6100000A357039406EA60402235ED629A5B4B40
8552	4	37	1919	31845	22097	\N	54.510092999999998	Хабаровский край, Тугуро-Чумиканский район, с. Удское, ул. Совхозная, д. 16		0101000020E6100000624CFA7B29CD6040927538BA4A414B40
8547	4	37	1919	31629	21953	\N	53.773359999999997	Хабаровский край, Тугуро-Чумиканский район, с. Тугур, ул. Карпова, д. 18		0101000020E6100000C9772975491A61406C04E275FDE24A40
8548	4	37	1919	31709	22298	\N	54.533701999999998	Хабаровский край, Тугуро-Чумиканский район, с. Тором, ул. Центральная, д. 6		0101000020E6100000035DFB02FAF96040A7E7DD5850444B40
8550	4	37	1919	31774	21960	\N	54.691474999999997	Хабаровский край, Тугуро-Чумиканский район, с. Неран, ул. Мира, д. 14		0101000020E6100000E486DF4DB7E860403480B74082584B40
8551	4	37	1919	31834	21962	\N	54.699019	Хабаровский край, Тугуро-Чумиканский район, с. Алгазея, пер. Победы, д. 6		0101000020E6100000F19C2D2034E660402D24607479594B40
8512	4	37	673	50959	24161	\N	51.191732000000002	Хабаровский край, Охотский район, п. Новое Устье, ул. Школьная, д. 3	Россия, Хабаровский край, Солнечный район	0101000020E61000008DD0CFD4EBFE604060CC96AC8A984940
8541	4	37	673	31327	22083	\N	51.395561999999998	Хабаровский край, Солнечный район, село Эворон, улица Вокзальная, дом 17		0101000020E610000019390B7BDA0A61402AC58EC6A1B24940
8533	4	37	673	30954	19048	\N	51.012698	Хабаровский край, Солнечный район, поселок Хурмули, улица Клубная, дом 3		0101000020E61000008E959867A51C6140C05C8B16A0814940
8540	4	37	673	31283	22170	\N	51.292994999999998	Хабаровский край, Солнечный район, поселок Харпичан, улица Юбилейная, дом 35		0101000020E610000021020EA1CA1061401D7233DC80A54940
8531	4	37	673	4616	21948	\N	50.696756999999998	Хабаровский край, Солнечный район, поселок Хальгасо, ул. Южная, д1/б		0101000020E6100000815F2349901C6140292158552F594940
8525	4	37	673	30438	21939	\N	50.717720999999997	Хабаровский край, Солнечный район, рабочий поселок Солнечный, улица Парковая, дом 7/В		0101000020E6100000FF78AF5A1914614082531F48DE5B4940
8523	4	37	673	30438	21939	\N	50.717720999999997	Хабаровский край, Солнечный район, рабочий поселок Солнечный, улица Парковая, дом 3		0101000020E6100000FF78AF5A1914614082531F48DE5B4940
8530	4	37	673	30438	19205	\N	50.717720999999997	Хабаровский край, Солнечный район, рабочий поселок Солнечный, улица Ленина, дом 22		0101000020E6100000FF78AF5A1914614082531F48DE5B4940
8529	4	37	673	30438	19205	\N	50.717720999999997	Хабаровский край, Солнечный район, рабочий поселок Солнечный, улица Ленина, дом 11		0101000020E6100000FF78AF5A1914614082531F48DE5B4940
8528	4	37	673	30438	19205	\N	50.717720999999997	Хабаровский край, Солнечный район, рабочий поселок Солнечный, улица Ленина, дом 23/В		0101000020E6100000FF78AF5A1914614082531F48DE5B4940
8527	4	37	673	30438	19205	\N	50.717720999999997	Хабаровский край, Солнечный район, рабочий поселок Солнечный, улица Ленина, дом 20/А		0101000020E6100000FF78AF5A1914614082531F48DE5B4940
8526	4	37	673	30438	19205	\N	50.717720999999997	Хабаровский край, Солнечный район, рабочий поселок Солнечный, улица Ленина, дом 23/Б		0101000020E6100000FF78AF5A1914614082531F48DE5B4940
8535	4	37	673	31055	19287	\N	50.822496999999998	Хабаровский край, Солнечный район, поселок Лиан, улица Весны, дом 11		0101000020E6100000A9A3E36AE41D61407007EA9447694940
8538	4	37	673	31186	21947	\N	51.261797999999999	Хабаровский край, Солнечный район, село Кондон, улица А. Самара, дом 20		0101000020E61000003D0B42799F1261404014CC9882A14940
8542	4	37	673	31407	19298	\N	51.565882999999999	Хабаровский край, Солнечный район, поселок Дуки, улица А. Никифорова, дом 10		0101000020E61000008010C990E3F96040622EA9DA6EC84940
8546	4	37	673	4678	9689	\N	51.120073172762297	Хабаровский край, Солнечный район, поселок Джамку, улица Центральная, дом 1/А		0101000020E6100000E1968FA4A4D46040F910548D5E8F4940
8532	4	37	673	30907	21765	\N	50.764187999999997	Хабаровский край, Солнечный район, рабочий поселок Горный, улица Комсомольская, дом 25/А		0101000020E61000003E59315C1D0E614071FF91E9D0614940
8536	4	37	673	31113	22041	\N	51.198200999999997	Хабаровский край, Солнечный район, поселок Горин, улица Центральная, дом 38		0101000020E610000001344A97FE1461406A847EA65E994940
8537	4	37	673	31113	18933	\N	51.198200999999997	Хабаровский край, Солнечный район, поселок Горин, улица Вокзальная, дом 20		0101000020E610000001344A97FE1461406A847EA65E994940
8544	4	37	673	31451	22090	\N	51.675091999999999	Хабаровский край, Солнечный район, поселок Березовый, улица Школьная, дом 12		0101000020E6100000A2D0B2EE9FF5604047E5266A69D64940
8543	4	37	673	31451	22088	\N	51.675091999999999	Хабаровский край, Солнечный район, поселок Березовый, улица Пионерская, дом 14		0101000020E6100000A2D0B2EE9FF5604047E5266A69D64940
8545	4	37	673	31550	21950	\N	51.415249000000003	Хабаровский край, Солнечный район, поселок Амгунь, улица Ленина, дом 11		0101000020E610000063F19BC2CAE260402E5915E126B54940
8195	4	37	652	4353	21838	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Чкалова, д.12		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8200	4	37	652	4353	19288	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Флерова, д.1		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
33356	4	41	1601	45455	46288	\N	48.545923999999999	с. им. Тельмана, ул. Школьная, д. 9		0101000020E6100000234DBC033CDF6040FE0C6FD6E0454840
8198	4	37	652	4353	22188	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г. Советская Гавань, ул. Суворова,1		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8201	4	37	652	4353	22189	\N	48.961815000000001	"Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Сахалинская, здание ООО ""Гектор"""		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8196	4	37	652	4353	22107	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Полины Осипенко, д.1		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8194	4	37	652	4353	22306	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Пионерская, д.1		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8190	4	37	652	4353	22106	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Первомайская, д.52		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8193	4	37	652	4353	19211	\N	48.963340949981799	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Ленина, д.4	Россия, Хабаровский край, Советско-Гаванский район, Советская Гавань	0101000020E6100000E57B4622B4886140AEF204C24E7B4840
8191	4	37	652	4353	19211	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Ленина, д.17		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8199	4	37	652	4353	19243	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Кишиневская, д.5		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8192	4	37	652	4353	19148	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Киевская, д.2		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8189	4	37	652	4353	19148	\N	48.962422570522499	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул.Киевская, д.31	Россия, Хабаровский край, Советско-Гаванский район, Советская Гавань	0101000020E6100000F3E2C457BB88614088F546AD307B4840
8197	4	37	652	4353	22108	\N	48.961815000000001	Хабаровский край, Советско-Гаванский район, г.Советская Гавань, ул. Калинина, д.5		0101000020E6100000E622BE13B3886140B0E600C11C7B4840
8203	4	37	652	15043	19246	\N	48.999344000000001	Хабаровский край, Советско-Гаванский район, п.Майский, ул. Черемховская, д.19А		0101000020E610000080492A534C87614017BA1281EA7F4840
8204	4	37	652	15043	21721	\N	48.999344000000001	Хабаровский край, Советско-Гаванский район, п.Майский, ул. Селенгинская, д.14		0101000020E610000080492A534C87614017BA1281EA7F4840
8208	4	37	652	15248	21722	\N	48.998947999999999	Хабаровский край, Советско-Гаванский район, п.Лососина, ул. Украинская, д.1		0101000020E610000057EC2FBB278A6140CA332F87DD7F4840
8207	4	37	652	15144	22168	\N	49.033518999999998	Хабаровский край, Советско-Гаванский район, п.Заветы Ильича, ул. Николаева, д.10		0101000020E6100000FD6CE4BAA9886140B665C0594A844840
8206	4	37	652	15144	21982	\N	49.033518999999998	Хабаровский край, Советско-Гаванский район, п.Заветы Ильича, ул. Невельского, здание Дома офицеров		0101000020E6100000FD6CE4BAA9886140B665C0594A844840
8205	4	37	652	15144	21982	\N	49.033518999999998	Хабаровский край, Советско-Гаванский район, п.Заветы Ильича, ул. Невельского, д.10		0101000020E6100000FD6CE4BAA9886140B665C0594A844840
8202	4	37	652	5623	21767	\N	48.895645000000002	Хабаровский край, Советско-Гаванский район, с. Гатка, ул. Клубная, д.1		0101000020E610000007B64AB038846140B8E9CF7EA4724840
8511	4	37	7076	50557	22771	\N	48.543126999999998	Хабаровский край, Охотский район, п. Морской, ул. Речная, д. 25		0101000020E6100000E831CA33AFE060408C497F2F85454840
8498	4	37	7076	50411	79698	\N	59.364070032899598	Хабаровский край, Охотский район, р.п. Охотск, ул. Победы, д. 5	Россия	0101000020E6100000A1BFD023C6E7614034BA83D899AE4D40
8503	4	37	7076	50411	79662	\N	59.366048804030697	Хабаровский край, Охотский район, р.п. Охотск, ул. Ленина, д. 10	Россия	0101000020E6100000B796C970BCE76140E3DD91B1DAAE4D40
8502	4	37	7076	50411	79662	\N	59.361794525450001	Хабаровский край, Охотский район, р.п. Охотск, ул. Ленина, д. 20	Россия	0101000020E610000001C3F2E75BE761409C6D6E4C4FAE4D40
8501	4	37	7076	50411	21696	\N	51.191732000000002	Хабаровский край, Охотский район, р.п. Охотск, ул. Карпинского, д. 17		0101000020E61000008DD0CFD4EBFE604060CC96AC8A984940
8504	4	37	7076	50411	79690	\N	59.364846528681099	Хабаровский край, Охотский район, р.п. Охотск, ул. Вострецова, д. 17	Россия	0101000020E6100000CE531D72B3E761409885764EB3AE4D40
8500	4	37	7076	50411	79676	\N	59.363406737005697	Хабаровский край, Охотский район, р.п. Охотск, ул. 40 лет Победы, д. 57	Россия	0101000020E610000030F0DC7BB8E761409911DE1E84AE4D40
8506	4	37	7076	61617	79486	\N	59.421199975674099	Хабаровский край, Охотский район, п. Аэропорт, ул. Центральная, д. 13		0101000020E61000000325051640E26140A089B0E1E9B54D40
8505	4	37	7076	61579	79432	\N	60.0837518472675	Хабаровский край, Охотский район, с. Арка, ул. Таежная, д. 12		0101000020E61000002E7590D783CA6140BF7CB262B80A4E40
8235	4	37	911	16616	19163	\N	53.084007999999997	Хабаровский край, Николаевский район, п.Чныррах, УИК-ул.Флотская, д.6 место голосования -ул.Центральная, д.25		0101000020E6100000BB97FBE4289C61401A4D2EC6C08A4A40
8242	4	37	911	16931	21760	\N	53.542287999999999	Хабаровский край, Николаевский район, с.Чля, УИК-ул.Школьная д.20а место глосования-ул.Центральная,д.26		0101000020E61000007A8F334D58866140B28174B169C54A40
8232	4	37	911	50439	21870	\N	53.167200999999999	Хабаровский край, Николаевский район, п.Пуир, УИК-ул.Набережная,д.11 место голосования-ул.Набережная, д.5		0101000020E6100000BB5F05F8EEAD6140E36DA5D766954A40
8234	4	37	911	16520	22005	\N	53.009236999999999	Хабаровский край, Николаевский район, с.Оремиф, УИК-здание администрации место голосования-ул.Школьная, д.1а		0101000020E610000061FBC9181FA36140E27492AD2E814A40
8233	4	37	911	7277	19275	\N	53.041626000000001	Хабаровский край, Николаевский район, п. Озерпах, ул.Невельского, д.4		0101000020E61000008B1A4CC3F0A76140E754320054854A40
33340	4	41	1601	55682	46235	\N	48.598587999999999	пос. Смидович, ул. Советская, д. 64		0101000020E61000002FFB75A73BBA604097E315889E4C4840
8211	4	37	911	7166	19247	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Школьная, д.219		0101000020E61000008670CCB227976140346953758F924A40
8213	4	37	911	7166	21725	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Чихачёва, д.4		0101000020E61000008670CCB227976140346953758F924A40
8214	4	37	911	7166	21739	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Чихачева, д.8		0101000020E61000008670CCB227976140346953758F924A40
8227	4	37	911	7166	21755	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Читинская, д.6		0101000020E61000008670CCB227976140346953758F924A40
8230	4	37	911	7166	21862	\N	53.145003000000003	Хабаровский край, Николаевский район,  г.Николаевск-на-Амуре, ул.Хабаровская, д.54		0101000020E61000008670CCB227976140346953758F924A40
8229	4	37	911	7166	21856	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Советская, д.38		0101000020E61000008670CCB227976140346953758F924A40
8220	4	37	911	7166	21856	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Советская, д.75		0101000020E61000008670CCB227976140346953758F924A40
8209	4	37	911	7166	21856	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Советская, д.173		0101000020E61000008670CCB227976140346953758F924A40
8224	4	37	911	7166	19203	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Сибирская, д.102		0101000020E61000008670CCB227976140346953758F924A40
8221	4	37	911	7166	19203	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Сибирская, д.165		0101000020E61000008670CCB227976140346953758F924A40
8219	4	37	911	7166	19203	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Сибирская, д.181		0101000020E61000008670CCB227976140346953758F924A40
8217	4	37	911	7166	19203	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Аиуре, ул.Сибирская,193		0101000020E61000008670CCB227976140346953758F924A40
8215	4	37	911	7166	19203	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Сибирская, д.193		0101000020E61000008670CCB227976140346953758F924A40
8210	4	37	911	7166	22117	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Северная, д.185		0101000020E61000008670CCB227976140346953758F924A40
8218	4	37	911	7166	21855	\N	53.145003000000003	Хабаровский край, Николаевский район,  г.Николаевск-на-Амуре, ул.Свободная, д.29		0101000020E61000008670CCB227976140346953758F924A40
8226	4	37	911	7166	18902	\N	53.145003000000003	Хабаровский край, Николаевский район,  г.Николаевск-на-Амуре, ул.Приамурская, д.69		0101000020E61000008670CCB227976140346953758F924A40
8212	4	37	911	7166	22118	\N	53.145003000000003	Хабаровский край, Николаевский район,  г.Николаевск-на-Амуре, ул.Попова, д.24		0101000020E61000008670CCB227976140346953758F924A40
8225	4	37	911	7166	21751	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Пионерская, д.111		0101000020E61000008670CCB227976140346953758F924A40
8223	4	37	911	7166	22120	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул. М.Горького, д.79		0101000020E61000008670CCB227976140346953758F924A40
8216	4	37	911	7166	19038	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Луначарского, д.138		0101000020E61000008670CCB227976140346953758F924A40
8222	4	37	911	7166	21749	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Кантера, д.2		0101000020E61000008670CCB227976140346953758F924A40
8231	4	37	911	7166	19274	\N	53.145003000000003	Хабаровский край, Николаевский район, г.Николаевск-на-Амуре, ул.Аэродромная, д.1		0101000020E61000008670CCB227976140346953758F924A40
8245	4	37	911	17109	18919	\N	52.857013999999999	Хабаровский край, Николаевский район, п.Нижнее Пронге, ул.Центральная, д.68		0101000020E61000001232906797A66140691B7FA2B26D4A40
8247	4	37	911	17212	19284	\N	52.119796000000001	Хабаровский край, Николаевский район, с.Нигирь, ул.Школьная, д.20		0101000020E6100000D0807A336AA961408718AF79550F4A40
8243	4	37	911	17006	21878	\N	53.934832999999998	Хабаровский край, Николаевский район, р.п.Многовершинный, УИК-ул.Черкашина, д.1а место глосования-ул.Черкашина, д.37		0101000020E6100000573ECBF3607D61405C1C959BA8F74A40
8238	4	37	911	16748	\N	\N	53.261265000000002	Хабаровский край, Николаевский район, р.п.Маго, здание дома культуры островной части		0101000020E610000065C5707580856140734BAB2171A14A40
8240	4	37	911	16748	22129	\N	53.261265000000002	Хабаровский край, Николаевский район, р.п.Маго, ул.Мира, д.4		0101000020E610000065C5707580856140734BAB2171A14A40
8239	4	37	911	16748	19173	\N	53.261265000000002	Хабаровский край, Николаевский район, р. п.Маго, ул.50 лет ССР, д.3		0101000020E610000065C5707580856140734BAB2171A14A40
8246	4	37	911	17133	19281	\N	52.214795000000002	Хабаровский край, Николаевский район, р.п.Лазарев, ул.Портовая, д.5		0101000020E610000037C64E7889B06140132C0E677E1B4A40
8236	4	37	911	16615	22006	\N	53.113714000000002	Хабаровский край, Николаевский район,  с.Красное, ул.Советская, д.37б		0101000020E6100000D3D85E0B7A9B6140768C2B2E8E8E4A40
8244	4	37	911	17041	21879	\N	53.080741000000003	Хабаровский край, Николаевский район, с.Константиновка, УИКул.Строительная д.1а место голосованияул.Строительная,д3а		0101000020E6100000721AA20AFF986140223999B8558A4A40
8237	4	37	911	16706	19170	\N	53.231813000000002	Хабаровский край,Николаевский  район, с.Иннокентьевка, УИК-ул.Набережная,д.15 место голосования-ул.Центральная д.5		0101000020E6100000427BF5F1508A6140D2E4620CAC9D4A40
8488	4	37	1843	28833	19226	\N	49.439717000000002	Хабаровский край, Нанайский район, с.Троицкое, ул.Шоссейная, д.12б		0101000020E6100000567E198C91116140643F8BA548B84840
33338	4	41	1601	55682	46273	\N	48.598587999999999	пос. Смидович, ул. Лермонтова, д. 2		0101000020E61000002FFB75A73BBA604097E315889E4C4840
8491	4	37	1843	28833	21943	\N	49.439717000000002	Хабаровский край, Нанайский район, с.Троицкое, ул.Кола Бельды, д.3		0101000020E6100000567E198C91116140643F8BA548B84840
8492	4	37	1843	28833	22110	\N	49.439717000000002	Хабаровский край, Нанайский район, с.Троицкое, ул.Калинина, д.171		0101000020E6100000567E198C91116140643F8BA548B84840
8490	4	37	1843	28833	22110	\N	49.439717000000002	Хабаровский край, Нанайский район, с.Троицкое, ул.Калинина, д.94		0101000020E6100000567E198C91116140643F8BA548B84840
8489	4	37	1843	28833	22284	\N	49.439717000000002	Хабаровский край, Нанайский район, с.Троицкое, ул.40 лет Победы, д.1		0101000020E6100000567E198C91116140643F8BA548B84840
8493	4	37	1843	29048	22045	\N	49.469062000000001	Хабаровский край, Нанайский район, с.Славянка, ул.Набережная, д.32		0101000020E6100000313F3734E5186140EFE53E390ABC4840
8479	4	37	1843	28410	19304	\N	48.957484999999998	Хабаровский край, Нанайский район, с.Синда, ул.Пассара, д.14		0101000020E610000024B6BB07680961408DB454DE8E7A4840
8485	4	37	1843	28672	21840	\N	49.327215000000002	Хабаровский край, Нанайский район, с.Нижняя Манома, ул.Почтовая, д.16		0101000020E61000004BB1A371281461405DE15D2EE2A94840
8483	4	37	1843	28593	19292	\N	49.284557999999997	Хабаровский край, Нанайский район, с.Найхин, ул.Школьная, д.14		0101000020E610000061360186E50E614057E883656CA44840
8478	4	37	1843	28327	22151	\N	48.915928000000001	Хабаровский край, Нанайский район, с.Маяк, ул.Центральная, д.23а		0101000020E6100000B6BE4868CB076140CFBEF2203D754840
8494	4	37	1843	29087	22263	\N	49.507938000000003	Хабаровский край, Нанайский район, с.Лидога, ул.Первомайская, д.9а		0101000020E61000003DD52137C31C6140A532C51C04C14840
8496	4	37	1843	29190	22049	\N	49.681089999999998	Хабаровский край, Нанайский район, с.Иннокентьевка, ул.Школьная, д.1		0101000020E61000009F5A7D75D51C6140FAD005F52DD74840
8480	4	37	1843	61764	79647	\N	49.106034000000001	Хабаровский край, Нанайский район, с.Дубовый Мыс, ул.Юбилейная, д.16	Россия, Хабаровский край, Нанайский район	0101000020E6100000B1321AF93C1F6140CD21A985928D4840
8495	4	37	1843	29148	22047	\N	49.670352000000001	Хабаровский край, Нанайский район, п.Джонка, ул.Комсомольская, д.44		0101000020E6100000C53C2B69451E614073672618CED54840
8484	4	37	1843	28606	18960	\N	49.438417000000001	Хабаровский край, Нанайский район, с.Джари, ул.Калинина, д.180		0101000020E6100000A52C431C6B10614056815A0C1EB84840
8482	4	37	1843	28533	19204	\N	49.263809999999999	Хабаровский край, Нанайский район, с.Даерга, ул.Зеленая, д.17а		0101000020E61000005FECBDF8220F6140CB2DAD86C4A14840
8481	4	37	1843	28507	21857	\N	49.168700999999999	Хабаровский край, Нанайский район, с.Дада, ул.Лесная, д.11а		0101000020E61000008B4F01301E0F6140B8E68EFE97954840
8486	4	37	1843	28734	22270	\N	49.322988000000002	Хабаровский край, Нанайский район, с.Верхняя Манома, ул.Комсомольская, д.6		0101000020E61000005B7C0A80712261400F80B8AB57A94840
8497	4	37	1843	29225	18966	\N	49.844552	Хабаровский край, Нанайский район, с.Верхний Нерген, ул.Зеленая, д.10		0101000020E61000005471E31673196140BDE2A9471AEC4840
8487	4	37	1843	28768	22271	\N	49.214753999999999	Хабаровский край, Нанайский район, с.Арсеньево, ул.Лесопильная, д.6		0101000020E6100000FC34EECD6F226140B4571F0F7D9B4840
8068	4	37	7080	50489	22462	\N	48.522084	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.139А		0101000020E61000008AE42B8194E16040E7E104A6D3424840
8053	4	37	7080	50489	22462	\N	48.549436999999998	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.194А		0101000020E6100000EA5C514A88E160402E1B9DF353464840
8039	4	37	7080	50489	22462	\N	48.5300509342973	Хабаровский край, г. Хабаровск, Краснофлотский район, ул. Тихоокеанская, д.136, аудит.225ц		0101000020E610000074EB353DA8E16040261B0FB6D8434840
8407	4	37	620	25108	22065	\N	51.068216	Хабаровский край, Комсомольский район, п. Ягодный, ул. Школьная, д. 6		0101000020E6100000CC7EDDE9CE4D61402F88484DBB884940
8415	4	37	620	25430	21852	\N	50.406892999999997	Хабаровский край, Комсомольский район, с. Хурба, ул. Добровольского, д. 1		0101000020E61000006E6E4C4FD81B614054FCDF1115344940
8414	4	37	620	25430	22194	\N	50.406892999999997	"Хабаровский край, Комсомольский район, с. Хурба, УИК-ул. Гайдара, д.9, пом.для голосов-ул. Гайдара, д.1"		0101000020E61000006E6E4C4FD81B614054FCDF1115344940
8403	4	37	620	24943	21727	\N	50.340217000000003	Хабаровский край, Комсомольский район, п. Уктур, ул. Центральная, д. 9		0101000020E6100000BF47FDF58A4F614089450C3B8C2B4940
8401	4	37	620	24867	22311	\N	50.268304999999998	Хабаровский край, Комсомольский район, п. Снежный, ул. Торговая, д. 16		0101000020E61000007CB94F8E023E6140382D78D157224940
8422	4	37	620	25827	22204	\N	50.363644000000001	Хабаровский край, Комсомольский район, с. Селихино, ул. Садовая, д. 18		0101000020E610000010406A13273061407DB1F7E28B2E4940
8411	4	37	620	50477	22228	\N	50.651136000000001	"Хабаровский край, Комсомольский район, с. Бельго, УИК-ул. Набережная, д.27, пом.для голосов-ул. Школьная, д.1"		0101000020E610000089B7CEBF5D286140C79FA86C58534940
8419	4	37	620	25686	22002	\N	50.491261000000002	"Хабаровский край, Комсомольский район, с. Пивань, УИК-ул.Совгаванская, д.30,пом.для гол.-ул.Совгаванская, д.32"		0101000020E610000066683C11C42261406F66F4A3E13E4940
8417	4	37	620	25586	22000	\N	50.453021999999997	"Хабаровский край, Комсомольский район, с. Новый Мир, УИК-ул. Школьная, д.7, пом.для голосов-ул. Центральная, д.27"		0101000020E6100000A2629CBF091F61402B2FF99FFC394940
8405	4	37	620	25018	22099	\N	51.179572	Хабаровский край, Комсомольский район, с. Новоильиновка, ул. Школьная, д. 33б		0101000020E61000000A12DBDD035461407FA31D37FC964940
8409	4	37	620	25191	19266	\N	50.796680000000002	Хабаровский край, Комсомольский район, с. Нижние Халбы, ул. Школьная, д. 6		0101000020E61000003673486AA13D61404BB0389CF9654940
8408	4	37	620	25145	22201	\N	50.920867000000001	Хабаровский край, Комсомольский район, с. Нижнетамбовское, ул. Кретова, д. 6		0101000020E61000003830B951E44561409A7B48F8DE754940
8416	4	37	620	25527	21998	\N	50.378512999999998	"Хабаровский край, Комсомольский район, п. Молодёжный, УИК-ул. Садовая, д.29, пом.для голосов-ул. Таёжная, д.9"		0101000020E6100000C53C2B69451E6140300E2E1D73304940
8098	4	37	620	5366	\N	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Амурская, д.4	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000CDB051D66F20614045292158554D4940
8119	4	37	620	5366	22373	\N	50.605296559173098	Хабаровский край, г.Комсомольск-на-Амуре, пр.Победы, д.47, корп.3	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000B6679604A8206140F7AE415F7A4D4940
8135	4	37	620	5366	22376	\N	50.605405801244501	Хабаровский край, г.Комсомольск-на-Амуре, пр.Первостроителей, д.11	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000000C23BDA85D206140AE669DF17D4D4940
8147	4	37	620	5366	18907	\N	50.536529773547599	Хабаровский край, г.Комсомольск-на-Амуре, пр.Октябрьский, д.10, корп.4	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000A87004A99420614054A9D903AD444940
8123	4	37	620	5366	22374	\N	50.605310214446	Хабаровский край, г.Комсомольск-на-Амуре, пр.Московский, д.28	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000001D386744692061408CF84ECC7A4D4940
8161	4	37	620	5366	19235	\N	50.6061060539352	Хабаровский край, г.Комсомольск-на-Амуре, пр.Ленина, д.27	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000295AB9179820614066F4A3E1944D4940
8130	4	37	620	5366	19220	\N	50.609028140981003	Хабаровский край, г.Комсомольск-на-Амуре, пр.Интернациональный, д.1	Россия, Хабаровский край, Комсомольский район	0101000020E6100000CC7C073F71206140952C27A1F44D4940
8177	4	37	620	5366	24150	\N	50.540987719146401	Хабаровский край, г.Комсомольск-на-Амуре, пр.Ленина, д.79, корп.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000008D2782380F1F6140A4C343183F454940
8127	4	37	620	5366	19313	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, пер.Сельский, д.22		0101000020E6100000CDB051D66F20614045292158554D4940
8187	4	37	620	5366	19144	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, мкр.Дружба, д.4		0101000020E6100000CDB051D66F20614045292158554D4940
8186	4	37	620	5366	19144	\N	50.604166999999997	"Хабаровский край, г.Комсомольск-на-Амуре, мкр.Дружба, ""Средняя общеобразовательная школа № 35"""		0101000020E6100000CDB051D66F20614045292158554D4940
8134	4	37	620	5366	19019	\N	50.560014262950602	Хабаровский край, г.Комсомольск-на-Амуре, Бульвар Юности, д.6, корп.3	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000003140A20914216140ADA6EB89AE474940
8125	4	37	620	5366	18974	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Щорса, д.83, корп.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000CDB051D66F20614045292158554D4940
8118	4	37	620	5366	22412	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Тепличная, д.1		0101000020E6100000CDB051D66F20614045292158554D4940
8114	4	37	620	5366	19058	\N	50.584464643424901	Хабаровский край, г.Комсомольск-на-Амуре, ул.Советская, д.8	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000E509849D622261400D54C6BFCF4A4940
8146	4	37	620	5366	19036	\N	50.5429499014109	Хабаровский край, г.Комсомольск-на-Амуре, ул.Севастопольская, д.20	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000012A27C418B2061407DAEB6627F454940
8167	4	37	620	\N	19236	\N	50.610168251627698	Хабаровский край, г.Комсомольск-на-Амуре, ул.Пирогова, д.30	Россия, Хабаровский край, Комсомольский район	0101000020E61000008EE89E758D2061406A882AFC194E4940
8157	4	37	620	5366	19066	\N	50.557988293731697	Хабаровский край, г.Комсомольск-на-Амуре, ул.Пионерская, д.73	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000C05C8B16A0206140BDC799266C474940
8164	4	37	620	5366	22388	\N	50.610130276832599	Хабаровский край, г.Комсомольск-на-Амуре, пр.Первостроителей, д.41	Россия, Хабаровский край, Комсомольский район	0101000020E610000029B2D6506A2061407C2766BD184E4940
8175	4	37	620	5366	19237	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, Магистральное шоссе, д.47, корп.2		0101000020E6100000CDB051D66F20614045292158554D4940
8174	4	37	620	5366	19237	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, Магистральное шоссе, д.39, корп.2		0101000020E6100000CDB051D66F20614045292158554D4940
8173	4	37	620	5366	19237	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, Магистральное шоссе, д.25, корп.3		0101000020E6100000CDB051D66F20614045292158554D4940
8113	4	37	620	5366	19047	\N	50.599837971478898	Хабаровский край, г.Комсомольск-на-Амуре, ул.Культурная, д.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000001F9DBAF2D9216140F372D87DC74C4940
8144	4	37	620	5366	22348	\N	50.605228282749003	Хабаровский край, г.Комсомольск-на-Амуре, ул.Краснофлотская, д.44, корп.2	Россия, Хабаровский край, Комсомольский район	0101000020E61000009BC8CC052E206140CE4F711C784D4940
8160	4	37	620	5366	19072	\N	50.549731446269902	Хабаровский край, г.Комсомольск-на-Амуре, ул.Красногвардейская, д.35	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000091D1014958206140774CDD955D464940
8155	4	37	620	5366	19072	\N	50.604890739713902	Хабаровский край, г.Комсомольск-на-Амуре, ул.Красногвардейская, д.10	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000002096CD1C9220614087527B116D4D4940
8183	4	37	620	5366	22362	\N	50.6026337048242	Хабаровский край, г.Комсомольск-на-Амуре, Комсомольское шоссе, д.26	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000274F594DD720614095BA641C234D4940
8142	4	37	620	5366	19317	\N	50.553965569092597	Хабаровский край, г.Комсомольск-на-Амуре, ул.Комсомольская, д.44	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E610000022533E04D5206140488C9E5BE8464940
8180	4	37	620	5366	22181	\N	50.576051483393002	Хабаровский край, г.Комсомольск-на-Амуре, ул.Комитетская, д.21	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000FC6D4F9058206140FFE9060ABC494940
8153	4	37	620	5366	19230	\N	50.549006852180703	Хабаровский край, г.Комсомольск-на-Амуре, ул.Кирова, д.41	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000DA756F45E2206140362383DC45464940
8104	4	37	620	5366	18947	\N	50.607419906244402	Хабаровский край, г.Комсомольск-на-Амуре, ул.Калинина, д.18	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000253CA1D79F206140D97745F0BF4D4940
8099	4	37	620	5366	18947	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Калинина, д.1, корп.2		0101000020E6100000CDB051D66F20614045292158554D4940
8131	4	37	620	5366	19221	\N	50.524104091574003	Хабаровский край, г.Комсомольск-на-Амуре, ул.Гагарина, д.2, корп.3	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000003AB187F631206140F5D901D715434940
8126	4	37	620	5366	19219	\N	50.601217294770997	Хабаровский край, г.Комсомольск-на-Амуре, Восточное шоссе, д.26	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000C311A4526C2061404D66BCADF44C4940
8168	4	37	620	5366	19079	\N	50.543971553974103	Хабаровский край, г.Комсомольск-на-Амуре, ул.Вокзальная, д.79	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000B5334C6D291F614048F8DEDFA0454940
8163	4	37	620	5366	19025	\N	50.545752876544597	Хабаровский край, г.Комсомольск-на-Амуре, ул.Васянина, д.20	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000F52EDE8FDB1F6140D158FB3BDB454940
8140	4	37	620	5366	19025	\N	50.605736939715499	Хабаровский край, г.Комсомольск-на-Амуре, ул.Васянина, д.2	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E61000006C770FD07D206140137D3ECA884D4940
8139	4	37	620	5366	19025	\N	50.604166999999997	Хабаровский край, г.Комсомольск-на-Амуре, ул.Васянина, д.1		0101000020E6100000CDB051D66F20614045292158554D4940
8182	4	37	620	5366	22300	\N	50.603152631915698	Хабаровский край, г.Комсомольск-на-Амуре, ул.Вагонная, д.8	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000711DE38A8B206140FDBD141E344D4940
8132	4	37	620	5366	19225	\N	50.530423341564699	Хабаровский край, г.Комсомольск-на-Амуре, Аллея Труда, д.57, корп.6	Россия, Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	0101000020E6100000005471E316206140EA059FE6E4434940
8404	4	37	620	24952	19256	\N	50.191935999999998	Хабаровский край, Комсомольский район, п. Кенай, ул. Пионерская, д. 7		0101000020E610000017D4B7CCE95261406876DD5B91184940
8400	4	37	620	24785	22191	\N	50.188499	Хабаровский край, Комсомольский район, с. Даппы, ул. Центральная, д. 4		0101000020E6100000BE1589096A2C6140132A38BC20184940
8402	4	37	620	24883	21724	\N	50.315466999999998	Хабаровский край, Комсомольский район, р. п. Гурское, ул. Школьная, д. 2		0101000020E6100000CB30EE0651436140CEFBFF3861284940
8412	4	37	620	25336	22119	\N	50.718867000000003	Хабаровский край, Комсомольский район, п. Галичный, ул. Советская, д. 14		0101000020E6100000D31742CE7B2661403A9677D5035C4940
8420	4	37	620	7927	21864	\N	50.365707	"Хабаровский край, Комсомольский район, с. Гайтер, УИК-ул.Октябрьская, д.16,пом.для голосов-ул.Октябрьская,д.28"		0101000020E6100000FCE07CEAD82761408A75AA7CCF2E4940
8418	4	37	620	25629	21986	\N	50.424056	Хабаровский край, Комсомольский район, с. Верхняя Эконь, ул. Школьная, д. 14		0101000020E61000000B444FCAA422614017D68D7747364940
8410	4	37	620	25230	19159	\N	50.667546999999999	Хабаровский край, Комсомольский район, с. Верхнетамбовское, ул. Набережная, д. 25		0101000020E61000000A4D124BCA2C61407EC51A2E72554940
8421	4	37	620	5849	19248	\N	50.386245000000002	Хабаровский край, Комсомольский район, с. Большая Картель, ул. Хабаровская, д. 9а		0101000020E61000006F9F55664A2C61402C9FE57970314940
8413	4	37	620	25393	21996	\N	51.096071999999999	"Хабаровский край, Комсомольский район, с. Боктор, УИК-ул. Школьная, д.5, пом.для голосов-ул. Школьная, д.7"		0101000020E610000051853FC31B2D6140D90759164C8C4940
8028	4	37	7079	50482	22288	\N	48.508630968624097	Хабаровский край, город Хабаровск, Кировский район, ул.Чкавлова,д.17	Россия, Хабаровский край, Хабаровск, улица Чкалова, 17	0101000020E610000044300E2E1DE16040AB5D13D21A414840
8521	4	37	1885	30036	19199	\N	52.421765999999998	Хабаровский край, район имени Полины Осипенко, с. Веселая Горка, ул. Школьная, д. 12		0101000020E610000000AB2347BA0F61404948A46DFC354A40
8518	4	37	1885	30036	19199	\N	52.421765999999998	Хабаровский край, район имени Полины Осипенко, с. Владимировка, ул. Школьная, д. 2		0101000020E610000000AB2347BA0F61404948A46DFC354A40
8522	4	37	1885	30036	19293	\N	52.421765999999998	Хабаровский край, район имени Полины Осипенко, с. Главный Стан, ул. Центральная, д. 26		0101000020E610000000AB2347BA0F61404948A46DFC354A40
8516	4	37	1885	30036	19293	\N	52.421765999999998	Хабаровский край, район имени Полины Осипенко, с. Оглонги, ул. Центральная, д. 73		0101000020E610000000AB2347BA0F61404948A46DFC354A40
8519	4	37	1885	30036	21745	\N	52.421765999999998	Хабаровский край, район имени Полины Осипенко, с. им. Полины Осипенко, ул. Амгуньская, д. 80		0101000020E610000000AB2347BA0F61404948A46DFC354A40
8517	4	37	1885	30036	19295	\N	52.421765999999998	Хабаровский край, район имени Полины Осипенко, с. Херпучи, ул. 60 лет Октября, д. 64		0101000020E610000000AB2347BA0F61404948A46DFC354A40
33339	4	41	1601	19715	46261	\N	48.598587999999999	пос. Смидович, ул. Кирова, д. 14		0101000020E61000002FFB75A73BBA604097E315889E4C4840
8515	4	37	1885	50481	22249	\N	52.906062263107998	Хабаровский край, район имени Полины Осипенко, с. Удинск, ул.. Набережная, д. 11	Россия, Хабаровский край, Имени Полины Осипенко район, село Удинск	0101000020E6100000E256410C745B6140FD12F1D6F9734A40
8520	4	37	1885	50479	22236	\N	52.315672733681502	Хабаровский край, район имени Полины Осипенко, с. Бриакан, ул. Черенева, д. 32	Россия, Хабаровский край, Имени Полины Осипенко район, село Бриакан	0101000020E6100000F8AA9509BFFA6040779D0DF967284A40
8465	4	37	661	27791	22148	\N	47.112091999999997	Хабаровский край, район имени Лазо, п. Южный, ул. Школьная, д. 1А		0101000020E610000050FEEE1D35F360405512D907598E4740
8436	4	37	661	26440	22015	\N	48.006045999999998	Хабаровский край, район имени Лазо, с. Черняево, ул. Первомайская, д. 5		0101000020E6100000CFC0C8CB1AD66040C422861DC6004840
8440	4	37	661	26529	22135	\N	47.88364	Хабаровский край, район имени Лазо, р.п.  Хор, пер. Степной, д. 2		0101000020E61000000A83328DA6DE6040FEB7921D1BF14740
8438	4	37	661	26529	22132	\N	47.88364	Хабаровский край, район имени Лазо, р.п.  Хор, ул. Советская, д. 15		0101000020E61000000A83328DA6DE6040FEB7921D1BF14740
8442	4	37	661	26529	21886	\N	47.88364	Хабаровский край, район имени Лазо, р.п.  Хор, ул. Менделеева, д. 12А		0101000020E61000000A83328DA6DE6040FEB7921D1BF14740
8439	4	37	661	26529	22209	\N	47.88364	Хабаровский край, район имени Лазо, р.п.  Хор, ул. Ленина, д. 6		0101000020E61000000A83328DA6DE6040FEB7921D1BF14740
8441	4	37	661	26529	21883	\N	47.88364	Хабаровский край, район имени Лазо, р.п.  Хор, ул. Безымянная, д. 3		0101000020E61000000A83328DA6DE6040FEB7921D1BF14740
8447	4	37	661	50454	22021	\N	47.841686000000003	Хабаровский край, район имени Лазо, с. Хака, ул. Центральная, д. 2		0101000020E6100000D6C6D8092FDE604023C0E95DBCEB4740
8423	4	37	661	25851	22004	\N	47.995013	Хабаровский край, район имени Лазо, п. Сукпай, ул. Центральная, д. 18		0101000020E610000079CA6ABA9E196140240C03965CFF4740
8424	4	37	661	25851	22196	\N	47.995013	Хабаровский край, район имени Лазо, п. Сукпай, ул. Городская, д. 51		0101000020E610000079CA6ABA9E196140240C03965CFF4740
8468	4	37	661	27935	21776	\N	47.677663000000003	Хабаровский край, район имени Лазо, п. Среднехорский, ул. Центральная, д. 11		0101000020E6100000A05225CA5E076140C95A43A9BDD64740
8467	4	37	661	27877	22312	\N	47.152025000000002	Хабаровский край, район имени Лазо, п. Солонцовый, ул. Школьная, д. 41А		0101000020E6100000E9F17B9BFE0261405396218E75934740
8452	4	37	661	27185	18928	\N	48.004309999999997	Хабаровский край, район имени Лазо, с. Соколовка, ул. Специалистов, д. 1		0101000020E61000009BADBCE47FEC6040DB85E63A8D004840
8472	4	37	661	28081	19309	\N	48.131956000000002	Хабаровский край, район имени Лазо, п. Сита, ул. Клубная, д. 2Б		0101000020E61000001970969265ED6040684128EFE3104840
8477	4	37	661	28314	18958	\N	48.119512	Хабаровский край, район имени Лазо, п. Сидима, ул. Пушкина, д. 32		0101000020E61000004913EF004F01614062BD512B4C0F4840
8458	4	37	661	27460	22014	\N	47.853230000000003	Хабаровский край, район имени Лазо, с. Святогорье, ул. Юбилейная, д. 7		0101000020E6100000A5A2B1F677ED6040A9FB00A436ED4740
8457	4	37	661	4496	22130	\N	47.868960000000001	Хабаровский край, район имени Лазо, с. Прудки, ул. Зеленая, д. 14/1		0101000020E61000005C3D27BDEFF360401EC4CE143AEF4740
8456	4	37	661	27330	22030	\N	47.898122000000001	Хабаровский край, район имени Лазо, с. Полётное, ул. Колхозная, д. 28		0101000020E6100000DD5ED2182DF36040B8E864A9F5F24740
8455	4	37	661	27327	19267	\N	47.935454	Хабаровский край, район имени Лазо, с. Петровичи, ул. Центральная, д. 50А		0101000020E610000014ECBFCE4DF16040C974E8F4BCF74740
8432	4	37	661	50412	\N	\N	47.968670382291798	Хабаровский край, район имени Лазо, п. Переяславка-2, здание Дома офицеров	Россия, Хабаровский край, Имени Лазо район, поселок Переяславка	0101000020E61000001EC3633F0BE26040E44EE960FDFB4740
8430	4	37	661	26090	19192	\N	47.966099	Хабаровский край, район имени Лазо, р.п. Переяславка, пер. Ленина, д. 12		0101000020E6100000FE7DC68583E2604062D9CC21A9FB4740
8431	4	37	661	26090	19251	\N	47.966099	Хабаровский край, район имени Лазо, р.п. Переяславка, ул. Центральная, д. 19		0101000020E6100000FE7DC68583E2604062D9CC21A9FB4740
8429	4	37	661	26090	19278	\N	47.966099	Хабаровский край, район имени Лазо, р.п. Переяславка, ул. Октябрьская, д. 52		0101000020E6100000FE7DC68583E2604062D9CC21A9FB4740
8428	4	37	661	26090	19278	\N	47.966099	Хабаровский край, район имени Лазо, р.п. Переяславка, ул. Октябрьская, д. 48		0101000020E6100000FE7DC68583E2604062D9CC21A9FB4740
8474	4	37	661	28164	22260	\N	48.096716000000001	Хабаровский край, район имени Лазо, п. Обор, ул. Мира, д. 1		0101000020E61000007100FDBEFFF56040FE7F9C30610C4840
8446	4	37	661	26918	22138	\N	47.849843999999997	Хабаровский край, район имени Лазо, п. Новостройка, ул. Советская, д. 7		0101000020E6100000965E9B8D95DE6040D5592DB0C7EC4740
8437	4	37	661	26505	22207	\N	48.113978000000003	Хабаровский край, район имени Лазо, с. Невельское, ул. Центральная, д. 22		0101000020E610000072C45A7C8AD56040543BC3D4960E4840
8427	4	37	661	25982	19277	\N	48.198031	Хабаровский край, район имени Лазо, р.п. Мухен, ул. Спортивная, д. 1		0101000020E61000005F950B95FF0361400E4C6E1459194840
8425	4	37	661	25982	19167	\N	48.198031	Хабаровский край, район имени Лазо, р.п.  Мухен, ул. Комсомольская, д. 1		0101000020E61000005F950B95FF0361400E4C6E1459194840
8426	4	37	661	25982	22009	\N	48.198031	Хабаровский край, район имени Лазо, р.п. Мухен, ул. Кедровая, д. 4		0101000020E61000005F950B95FF0361400E4C6E1459194840
8434	4	37	661	26325	19253	\N	47.968476000000003	Хабаровский край, район имени Лазо, с. Могилевка, ул. Советская, д. 25А		0101000020E6100000F4A9639552DE6040FF7A8505F7FB4740
8454	4	37	661	27249	21912	\N	47.971522	Хабаровский край, район имени Лазо, с. Марусино, ул. Набережная, д. 22		0101000020E6100000B6D8EDB3CAEE604019AC38D55AFC4740
8463	4	37	661	27708	22256	\N	47.690559	Хабаровский край, район имени Лазо, п. Кутузовка, ул. Центральная, д. 28		0101000020E610000080F10C1AFAF66040AF7AC03C64D84740
73933	4	36	\N	1410	44347	\N	42.799387000000003	"Приморский край, г. Находка, ул. Владивостокская, д. 45 ""а"""		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
8470	4	37	661	28005	19305	\N	48.103720000000003	Хабаровский край, район имени Лазо, с. Кругликово, ул. Пионерская, д. 38		0101000020E6100000FEEDB25FF7E3604077F86BB2460D4840
8445	4	37	661	26881	21762	\N	47.856887999999998	Хабаровский край, район имени Лазо, с. Кондратьевка, ул. Центральная, д. 35А		0101000020E610000051F4C0C7E0DF6040DC2A8881AEED4740
8459	4	37	661	27508	22208	\N	47.828622000000003	Хабаровский край, район имени Лазо, п. Кия, ул. Магазинная, д. 9		0101000020E610000052B81E856BF46040815F234910EA4740
8435	4	37	661	26377	21882	\N	47.985799	Хабаровский край, район имени Лазо, с. Киинск, ул. Набережная, д. 29		0101000020E61000003A79910978DA6040FAB660A92EFE4740
8466	4	37	661	27832	21914	\N	47.393242999999998	Хабаровский край, район имени Лазо, п. Катэн, ул. Набережная, д. 7		0101000020E6100000D36BB3B112036140C23060C955B24740
8473	4	37	661	28142	19310	\N	48.061712	Хабаровский край, район имени Лазо, п. Золотой, ул. Пионерская, д. 21		0101000020E61000005E2EE23BB10C6140A8E2C62DE6074840
8471	4	37	661	28048	19258	\N	48.064703999999999	Хабаровский край, район имени Лазо, с. Зоевка, ул. Совхозная, д. 4		0101000020E6100000545227A009E46040CFF57D3848084840
8450	4	37	661	50963	24167	\N	47.945608921135097	Хабаровский край, район имени Лазо, с. Екатеринославка, ул. Новикова, д. 32	Россия, Хабаровский край, Имени Лазо район	0101000020E6100000AA7F10C910E46040D1E638B709F94740
8476	4	37	661	28248	21907	\N	48.086221000000002	Хабаровский край, район имени Лазо, п. Дурмин, ул. Комсомольская, д. 12		0101000020E6100000541EDD080BFB60403D9D2B4A090B4840
8444	4	37	661	26808	22137	\N	47.886406999999998	Хабаровский край, район имени Лазо, с. Дрофа, ул. Центральная, д. 28		0101000020E610000043C70E2A71E0604005F9D9C875F14740
8464	4	37	661	27718	21913	\N	47.374890999999998	Хабаровский край, район имени Лазо, п. Долми, пер. Пионерский, д. 87		0101000020E6100000394206F2ECF360404948A46DFCAF4740
8433	4	37	661	26314	21881	\N	47.958092999999998	Хабаровский край, район имени Лазо, с. Гродеково, ул. Первомайская, д. 14А		0101000020E6100000A2EBC20F4EE0604065C39ACAA2FA4740
8449	4	37	661	27002	21890	\N	47.957639999999998	Хабаровский край, район имени Лазо, с. Георгиевка, ул. Центральная, д. 2		0101000020E6100000E1ED410848E86040B4AB90F293FA4740
8448	4	37	661	27002	21890	\N	47.957639999999998	Хабаровский край, район имени Лазо, с. Георгиевка, ул. Центральная, д. 61		0101000020E6100000E1ED410848E86040B4AB90F293FA4740
8469	4	37	661	27957	21915	\N	47.667524	Хабаровский край, район имени Лазо, с. Гвасюги, ул. Джанси Кимонко, д. 1		0101000020E61000003A22DFA5D4056140C6A52A6D71D54740
8453	4	37	661	27222	19302	\N	47.898133999999999	Хабаровский край, район имени Лазо, с. Васильевка, ул. Центральная, д. 9		0101000020E6100000EB3713D385EE60407CB60E0EF6F24740
8461	4	37	661	27553	22134	\N	47.778267999999997	Хабаровский край, район имени Лазо, с. Бичевая, ул. Школьная, д. 51		0101000020E610000052B9895A1AF46040FCC22B499EE34740
8443	4	37	661	55348	45210	\N	47.868046999999997	Хабаровский край, район имени Лазо, п. База-Дрофа, ул. Комсомольская, д. 1	Россия, Хабаровский край, Имени Лазо район	0101000020E61000004F22C2BF080A61400932022A1CEF4740
8388	4	37	658	24185	19353	\N	47.279189000000002	Хабаровский край, Вяземский район, п.Шумный, ул.Центральная, д.3		0101000020E610000070253B3682DF604094331477BCA34740
8374	4	37	658	50951	24148	\N	47.365811002456297	Хабаровский край, Вяземский район, с.Шереметьево, ул.Центральная, д.14а	Россия, Хабаровский край, Вяземский район, село Шереметьево	0101000020E61000005F97E13F5DC860402FC214E5D2AE4740
8380	4	37	658	23791	22305	\N	47.493912999999999	Хабаровский край, Вяземский район, с.Отрадное, ул.Шоссейная, д.16		0101000020E61000005CE49EAE6ED66040DD088B8A38BF4740
8387	4	37	658	24170	19352	\N	47.353700000000003	Хабаровский край, Вяземский район, п.Медвежий, ул.Школьная, д.8		0101000020E6100000CC7D7214A0E66040304CA60A46AD4740
8384	4	37	658	4463	22029	\N	47.760336000000002	Хабаровский край, Вяземский район, с. Кукелево, ул. Набережная, 13А		0101000020E6100000425DA45096D8604059FCA6B052E14740
8382	4	37	658	23899	22185	\N	47.641607	Хабаровский край, Вяземский район, с.Красицкое, ул.Центральная, д.53		0101000020E610000085798F33CDDB60403DF19C2D20D24740
8377	4	37	658	23691	21977	\N	47.420546000000002	Хабаровский край, Вяземский район, с.Котиково, ул.Центральная, д.19а		0101000020E610000067EE21E1FBD16040583B8A73D4B54740
8375	4	37	658	23604	21973	\N	47.428697	Хабаровский край, Вяземский район, с.Кедрово, ул.Школьная, д.5		0101000020E610000034F44F70B1CB60405872158BDFB64740
8386	4	37	658	24103	19149	\N	47.671467999999997	Хабаровский край, Вяземский район, с.Капитоновка, ул.Центральная, д.34		0101000020E610000095B7239C16E26040BF27D6A9F2D54740
8381	4	37	658	7890	22024	\N	47.613235000000003	Хабаровский край, Вяземский район, с.Забайкальское, ул. Центральная, д.14		0101000020E6100000A7751BD4FED560409CE1067C7ECE4740
8385	4	37	658	24058	21842	\N	47.769638999999998	Хабаровский край, Вяземский район, п.Дормидонтовка, ул.Пашина, д.10		0101000020E6100000ED9C6681F6DC6040F25CDF8783E24740
8383	4	37	658	23955	22186	\N	47.711461999999997	Хабаровский край, Вяземский район, с.Дормидонтовка, ул.Центральная, д.31		0101000020E6100000780AB9524FDD6040622CD32F11DB4740
8373	4	37	658	23481	21834	\N	47.255972	Хабаровский край, Вяземский район, с.Глебово, ул.Бонивура, д.19		0101000020E610000052F01472A5CB60408A58C4B0C3A04740
8399	4	37	658	24302	22169	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Шолохова, д.29		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8396	4	37	658	24302	21849	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Чехова, д.40		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8398	4	37	658	24302	22115	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Театральная, д.6		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8391	4	37	658	24302	21716	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Стоцкого, д.81		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8390	4	37	658	24302	19244	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Морозова, д.1		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8394	4	37	658	24302	21981	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Милицейская, д.68		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8397	4	37	658	24302	19153	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Котляра, д.37		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8395	4	37	658	24302	22112	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Коммунистическая, д.10		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8393	4	37	658	24302	22112	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Коммунистическая, д.12		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8392	4	37	658	24302	21718	\N	47.538564000000001	Хабаровский край, Вяземский район, г.Вяземский, ул.Вяземская, д.88		0101000020E6100000D4EE57013ED86040C76647AAEFC44740
8376	4	37	658	23629	19240	\N	47.432580000000002	Хабаровский край, Вяземский район, с.Виноградовка, ул.Центральная, д.12		0101000020E6100000897B2C7DE8CF6040AC730CC85EB74740
8346	4	37	658	23629	22344	\N	48.611581000000001	Хабаровский край, Вяземский район, с.Садовое, ул.Мира, д.7		0101000020E6100000A7936C7539E4604070ED4449484E4840
8372	4	37	658	23422	19348	\N	47.23997	Хабаровский край, Вяземский район, с.Видное, ул.Центральная, д.12		0101000020E6100000406CE9D154C56040B4024356B79E4740
8378	4	37	658	23725	19146	\N	47.480333999999999	Хабаровский край, Вяземский район, с.Венюково, ул.Кооперативная, д.15		0101000020E6100000BA6A9E2372D260401494A2957BBD4740
8379	4	37	658	23768	22145	\N	47.481102	Хабаровский край, Вяземский район, с.Аван, ул.Садовая, д.10		0101000020E610000024B4E55C0AD56040250516C094BD4740
8361	4	37	948	22922	22096	\N	51.522517999999998	Хабаровский край, Верхнебуреинский район, поселок Этыркэн, ул.Школьная, д.9		0101000020E610000061360186E570604021C9ACDEE1C24940
8363	4	37	948	23022	19080	\N	50.842720999999997	Хабаровский край, Верхнебуреинский район, станция Эльга, ул.Амурская, д.1		0101000020E61000003AE63C63DF89604082531F48DE6B4940
8341	4	37	948	22040	21816	\N	51.633491999999997	Хабаровский край, Верхнебуреинский район, поселок Шахтинский, ул.Центральная, д.5		0101000020E610000032923D424DA8604089230F4416D14940
8362	4	37	948	7707	19193	\N	50.866819	Хабаровский край, Верхнебуреинский район, село Чекунда, ул. Центральная, д.6		0101000020E6100000B6114F76338860409546CCECF36E4940
8353	4	37	948	7825	\N	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, п.ЦЭС, д.12		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8349	4	37	948	7825	22080	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Центральная, д.24		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8348	4	37	948	7825	22080	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Центральная, д.39		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8343	4	37	948	7825	22290	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Ургальская ГРП, д.19		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8347	4	37	948	7825	22078	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Строительная, д.2		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8350	4	37	948	7825	22238	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Пионерская, д.17		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8344	4	37	948	7825	22077	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Парковая, д.8		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8352	4	37	948	7825	19332	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Магистральная, д.24		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8351	4	37	948	7825	19332	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Магистральная, д.2		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8370	4	37	948	7825	22303	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Лесная, д.3		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8368	4	37	948	7825	45233	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.Амурская, д,7, кв.1		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8345	4	37	948	7825	22167	\N	51.131169	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, ул.60 лет Октября, д.4		0101000020E6100000BA4E232D15A06040E09F5225CA904940
8364	4	37	948	23066	19336	\N	50.413626999999998	Хабаровский край, Верхнебуреинский район, село Ушман, ул.Школьная, д.6		0101000020E6100000B7D100DE828860400DDFC2BAF1344940
8359	4	37	948	22839	21954	\N	51.131881	Хабаровский край, Верхнебуреинский район, поселок Усть-Ургал, ул.Центральная, д.6		0101000020E6100000AB048BC3999060405DFB027AE1904940
8366	4	37	948	7796	22101	\N	50.044463	Хабаровский край, Верхнебуреинский район, поселок Тырма, ул.Октябрьская, д.12		0101000020E6100000F86F5E9CF8846040E770ADF6B0054940
8367	4	37	948	7796	19342	\N	50.044463	Хабаровский край, Верхнебуреинский район, поселок Тырма, ул. Вокзальная, д.30		0101000020E6100000F86F5E9CF8846040E770ADF6B0054940
8357	4	37	948	22763	21952	\N	50.652073000000001	"Хабаровский край, Верхнебуреинский район, поселок Сулук, УИК- ул.Ленина, д.2, голосование - ул.40 лет Победы, д.7"		0101000020E6100000EE056685A2B2604064CDC82077534940
8342	4	37	948	22096	19328	\N	51.158037	Хабаровский край, Верхнебуреинский район, село Средний Ургал, ул.Советская, д.6		0101000020E6100000DFA9807B1E9E60406B47718E3A944940
8340	4	37	948	21999	22076	\N	52.256072000000003	"Хабаровский край, Верхнебуреинский район, поселок Софийск, УИК- ул.Почтовая, д.9, голосование - ул.Советская, д.1"		0101000020E6100000AE64C746A0BF6040EEB5A0F7C6204A40
8356	4	37	948	22731	22239	\N	50.818195000000003	"Хабаровский край, Верхнебуреинский район, поселок Солони, УИК- ул.Центральная, д.6, голосование - ул.Центральная, д.1"		0101000020E610000063D4B5F63EA7604018601F9DBA684940
8365	4	37	948	7720	21963	\N	50.339441000000001	Хабаровский край, Верхнебуреинский район, поселок Согда, ул. Центральная, д.8		0101000020E6100000849F3880FE886040F5F57CCD722B4940
8355	4	37	948	22643	22089	\N	51.073661000000001	Хабаровский край, Верхнебуреинский район, поселок Новый Ургал, ул.Донецкая, д.6		0101000020E6100000BD38F1D58E926040CEFE40B96D894940
8354	4	37	948	22643	19333	\N	51.073661000000001	Хабаровский край, Верхнебуреинский район, поселок Новый Ургал, ул.60 лет образования СССР, д.2		0101000020E6100000BD38F1D58E926040CEFE40B96D894940
8358	4	37	948	22796	22094	\N	50.804313999999998	"Хабаровский край, Верхнебуреинский район, поселок Герби, УИК- ул.Саратовская, д.14А, голосование - ул.Школьная, д.6"		0101000020E6100000C991CEC0C8C3604083DBDAC2F3664940
8360	4	37	948	22887	21956	\N	51.354126000000001	"Хабаровский край, Верхнебуреинский район, поселок Алонка, УИК- ул.Вокзальная, д.4, голосование - ул.Сергея Лазо, д.1"		0101000020E61000003509DE90468E6040E754320054AD4940
8369	4	37	948	23299	19343	\N	50.013230999999998	Хабаровский край, Верхнебуреинский район, село Аланап, ул.Советская, д.4А		0101000020E61000001E8D43FDAE7F60408D25AC8DB1014940
8334	4	37	654	21704	19319	\N	49.348934999999997	Хабаровский край, Ванинский район, с. Уська-Орочское, ул. Киевская, д. 13		0101000020E61000008ECA4DD45281614002B7EEE6A9AC4840
8335	4	37	654	7656	19227	\N	49.66384	Хабаровский край, Ванинский район, п. Тумнин, ул. Комсомольская, д. 9		0101000020E6100000486AA164F282614069E388B5F8D44840
8336	4	37	654	21819	22164	\N	49.884124999999997	Хабаровский край, Ванинский район, с. Тулучи, ул. Центральная, д. 16		0101000020E61000004E0B5EF4957E6140BA490C022BF14840
8329	4	37	654	21452	21814	\N	49.122444999999999	Хабаровский край, Ванинский район, п. Токи, пер. Магаданский, д. 1		0101000020E6100000B37DC85B2E8A614084471B47AC8F4840
8330	4	37	654	21452	22285	\N	49.122444999999999	Хабаровский край, Ванинский район, п.Токи, ул. Железнодорожная, д. 10		0101000020E6100000B37DC85B2E8A614084471B47AC8F4840
8331	4	37	654	21452	22286	\N	49.122444999999999	Хабаровский край, Ванинский район, п. Токи, ул. Амурская, клуб п. Токи-2		0101000020E6100000B37DC85B2E8A614084471B47AC8F4840
8318	4	37	654	20909	22143	\N	49.062806999999999	"Хабаровский край, Ванинский район, р.п. Октябрьский, УИК - ул. Вокзальная,  4, голосованияе - ул. Центральная, 1А"		0101000020E6100000541F48DE39886140DD7A4D0F0A884840
8320	4	37	654	20909	18982	\N	49.062806999999999	Хабаровский край, Ванинский район, р.п. Октябрьский, ул. Новодорожная, д. 9		0101000020E6100000541F48DE39886140DD7A4D0F0A884840
8317	4	37	654	20909	19299	\N	49.062806999999999	Хабаровский край, Ванинский район, р.п.. Октябрьский, ул. Космонавтов, д. 1		0101000020E6100000541F48DE39886140DD7A4D0F0A884840
8319	4	37	654	20909	19314	\N	49.062806999999999	Хабаровский край, Ванинский район, р.п. Октябрьский, ул. Дарвина, д. 33		0101000020E6100000541F48DE39886140DD7A4D0F0A884840
8333	4	37	654	4386	19270	\N	49.238118	Хабаровский край, ванинский район, п. Монгохто, ул. Театральная, д. 14А		0101000020E610000058E542E55F876140624B8FA67A9E4840
8337	4	37	654	21859	19206	\N	50.132989000000002	Хабаровский край, Ванинский район, с. Кенада, ул. Советская, д. 23		0101000020E61000008C683BA66E72614027DD96C805114940
8332	4	37	654	21617	22287	\N	49.282871999999998	Хабаровский край, Ванинский район,  с. Датта, ул. Шуляпина, д. 1		0101000020E6100000AD1402B9C48B6140207A522635A44840
8339	4	37	654	21914	21911	\N	50.102549000000003	"Хабаровский край, Ванинский район, р.п. Высокогорный, УИК - ул. Мира, д. 4, голосование - ул. Октябрьская, д.12, д. 4"		0101000020E610000055A6988320646140679E5C53200D4940
8338	4	37	654	21914	21911	\N	50.102549000000003	"Хабаровский край, Ванинский район, р.п. Высокогорный, УИК- ул. Мира, д.2, голосование- ул. Октябрьская,  д.12"		0101000020E610000055A6988320646140679E5C53200D4940
8321	4	37	654	21080	21804	\N	49.092615000000002	Хабаровский край, Ванинский район, р.п. Ванино, пл. Маяковского, д. 1		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8323	4	37	654	21080	19231	\N	49.092615000000002	Хабаровский край, Ванинский район, р.п. Ванино, ул. Чехова, д. 5		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8324	4	37	654	21080	19315	\N	49.092615000000002	Хабаровский край, Ванинский район, р.п. Ванино, ул. Невского, д. 4		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8327	4	37	654	21080	22243	\N	49.092615000000002	Хабаровский край, Ванинский район, п. Ванино, ул. Молодежная, д. 6		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8326	4	37	654	21080	22279	\N	49.092615000000002	Хабаровский край, Ванинский район, п. Ванино, пл. Мира, д. 1		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8328	4	37	654	21080	22283	\N	49.092615000000002	Хабаровский край, Ванинский район, п. Ванино, ул. Клубная, д. 12		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8325	4	37	654	21080	19202	\N	49.092615000000002	Хабаровский край, Ванинский район, п. Ванино, ул. Киевская, д. 2		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8322	4	37	654	21080	21806	\N	49.092615000000002	Хабаровский край, Ванинский район, р.п. Ванино, ул. 2 Линия, д. 7		0101000020E61000006B64575AC68861403D0FEECEDA8B4840
8306	4	37	1283	20253	19217	\N	47.133932000000001	Хабаровский край, Бикинский район, с. Пушкино, ул. Кирова, д. 4		0101000020E61000008865338724CC6040A6F10BAF24914740
8303	4	37	1283	20087	21782	\N	46.716121000000001	Хабаровский край, Бикинский район, с. Покровка, ул. Центральная, д. 8		0101000020E61000001EFE9AACD1C060404A7D59DAA95B4740
8287	4	37	1283	19212	19311	\N	46.799052000000003	Хабаровский край, Бикинский район, с. Оренбургское, ул. Мира, д. 18		0101000020E6100000014F5AB8ACC76040D6E6FF5547664740
8307	4	37	1283	20358	22291	\N	47.095481999999997	Хабаровский край, Бикинский район, с. Лончаково, ул. Уссурийская, д. 2		0101000020E6100000A053909F0DC76040A7AD11C1388C4740
8304	4	37	1283	20141	22262	\N	46.733437000000002	Хабаровский край, Бикинский район, с. Лесопильное, пер. Красноармейский, д. 2		0101000020E61000005BCD3AE3FBCA604093567C43E15D4740
8310	4	37	1283	20460	21931	\N	47.150824	Хабаровский край, Бикинский район, с. Лермонтовка, Южный городок, д. 4		0101000020E6100000F88C446804CA6040D8B969334E934740
8311	4	37	1283	20460	21932	\N	47.150824	Хабаровский край, Бикинский район, с. Лермонтовка, ул. Центральная, д. 16		0101000020E6100000F88C446804CA6040D8B969334E934740
8309	4	37	1283	20460	19260	\N	47.151175280613202	Хабаровский край, Бикинский район, с. Лермонтовка, ул. Пролетарская, д.10	Россия, Хабаровский край, Бикинский район, село Лермонтовка	0101000020E610000029266F8019CA6040857CD0B359934740
8312	4	37	1283	20460	18967	\N	47.148774573659601	Хабаровский край, Бикинский район, с. Лермонтовка, ул. Дорожная, д. 22-б	Россия, Хабаровский край, Бикинский район, село Лермонтовка	0101000020E6100000B1A54753BDCA604030BB270F0B934740
8308	4	37	1283	20377	19218	\N	47.206696000000001	Хабаровский край, Бикинский район, с. Добролюбово, ул. Центральная, д. 51		0101000020E6100000EBA9D55757CA6040651BB803759A4740
8305	4	37	1283	20225	18965	\N	46.982140000000001	Хабаровский край, Бикинский район, с. Бойцово, ул. Центральная, д.18		0101000020E6100000D4F2035779CA6040F60B76C3B67D4740
8302	4	37	1283	13440	19229	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, пер. Энергетический, д. 3		0101000020E6100000CB129D6516C8604063B6645584694740
8169	4	37	1283	13440	9708	\N	46.821994507294399	Хабаровский край, Бикинский район, г. Бикин, ул. Фабричная,33	Россия, Хабаровский край, Бикинский район, Бикин	0101000020E61000001840F85022C86040DE3CD52137694740
8295	4	37	1283	13440	21780	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Первомайская, д. 13		0101000020E6100000CB129D6516C8604063B6645584694740
8301	4	37	1283	13440	19026	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Октябрьская, д. 12		0101000020E6100000CB129D6516C8604063B6645584694740
8300	4	37	1283	13440	19026	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Октябрьская, д. 10		0101000020E6100000CB129D6516C8604063B6645584694740
8291	4	37	1283	13440	22257	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Набережная, д. 62		0101000020E6100000CB129D6516C8604063B6645584694740
8298	4	37	1283	13440	18983	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Зеленая, д. 11-а		0101000020E6100000CB129D6516C8604063B6645584694740
8299	4	37	1283	13440	21935	\N	46.824351	Хабаровский край, Бикинский район, г.  Бикин, ул. Зачеславского, д. 30		0101000020E6100000CB129D6516C8604063B6645584694740
8294	4	37	1283	13440	18916	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Железнодорожная, д. 11		0101000020E6100000CB129D6516C8604063B6645584694740
8293	4	37	1283	13440	21916	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Дзержинского, д. 3		0101000020E6100000CB129D6516C8604063B6645584694740
8292	4	37	1283	13440	21916	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, ул. Дзержинского, д. 60		0101000020E6100000CB129D6516C8604063B6645584694740
8297	4	37	1283	13440	21798	\N	46.824351	Хабаровский край, Бикинский район, г. Бикин, Восточный городок, Здание школы № 3		0101000020E6100000CB129D6516C8604063B6645584694740
8296	4	37	1283	13440	21798	\N	46.824351	Хабаровский край, Бикинский район, г.  Бикин, Восточный городок, Здание Дома офицеров		0101000020E6100000CB129D6516C8604063B6645584694740
8316	4	37	7081	50562	22781	\N	48.486576999999997	Хабаровский край, Аяно-Майский район, с.Нелькан, ул. Советская, д. 9а		0101000020E6100000433BA759A0E160402EFEB627483E4840
8315	4	37	7081	50495	79700	\N	57.543335906480202	Хабаровский край, Аяно-Майский район, с.Джигда, ул. Совхозная, д.2		0101000020E61000008BFD65F764FC6040A65EB7088CC54C40
8314	4	37	7081	61809	79709	\N	56.434399113616301	Хабаровский край, Аяно-Майский район, с. Аян, ул. Советская, д. 8	море Охотское	0101000020E610000030629F000A4661402235ED629A374C40
8313	4	37	7081	61574	79412	\N	58.462499999999999	Хабаровский край, Аяно-Майский район, с.Аим, ул. 40 лет Победы, д. 8	Россия	0101000020E610000022FDF675E0C4604033333333333B4D40
8269	4	37	864	50470	22162	\N	50.326934999999999	Хабаровский край, Амурский район, ст.Мылки, ул. Вокзальная, д.1		0101000020E61000009946938BB118614079758E01D9294940
8270	4	37	864	7360	19285	\N	50.094476999999998	Хабаровский край, Амурский район, п. Эльбан, ул. Школьная, д.27А		0101000020E6100000AEBCE47FF20F6140B29C84D2170C4940
8275	4	37	864	7360	22147	\N	50.094476999999998	Хабаровский край, Амурский район, п. Эльбан, ул. Центральная, д.18		0101000020E6100000AEBCE47FF20F6140B29C84D2170C4940
8274	4	37	864	7360	18956	\N	50.094476999999998	Хабаровский край, Амурский район, п.Эльбан, ул.Микрорайон 2, д.28		0101000020E6100000AEBCE47FF20F6140B29C84D2170C4940
8273	4	37	864	7360	18956	\N	50.094476999999998	Хабаровский край, Амурский район, п. Эльбан, ул. Микрорайон 2, д.9А		0101000020E6100000AEBCE47FF20F6140B29C84D2170C4940
8272	4	37	864	7360	18956	\N	50.094476999999998	Хабаровский край, Амурский район, п. Эльбан, ул. Микрорайон 2, д.12		0101000020E6100000AEBCE47FF20F6140B29C84D2170C4940
8271	4	37	864	7360	21775	\N	50.094476999999998	Хабаровский край, Амурский район, п. Эльбан, ул. Микрорайон 1, д.26А		0101000020E6100000AEBCE47FF20F6140B29C84D2170C4940
8290	4	37	864	19399	21853	\N	49.085752999999997	Хабаровский край, Амурский район, п. Форель, ул. Школьная, д.7		0101000020E61000004982700514E5604056444DF4F98A4840
8276	4	37	864	18642	\N	\N	50.021005000000002	"Хабаровский край, Амурский район, п. Тейсин, клуб ""Факел"""		0101000020E6100000DEC9A7C7B60D6140B806B64AB0024940
8286	4	37	864	19184	\N	\N	49.586126	Хабаровский край, Амурский район, п. Сельгон, здание станции Сельгон		0101000020E610000054A703594FED6040EBAA402D06CB4840
8285	4	37	864	19145	22140	\N	49.36777	Хабаровский край, Амурский район, п. Санболи, ул. Молодежная, д.1		0101000020E61000003E23111AC1E5604097395D1613AF4840
8279	4	37	864	18825	21885	\N	50.215811000000002	Хабаровский край, Амурский район, с. Падали, ул. Станционная, д.26		0101000020E6100000226FB9FAB1146140FC8EE1B19F1B4940
8277	4	37	864	7437	18957	\N	50.090397000000003	Хабаровский край, Амурский район, с.Омми, ул. Центральная, д.7		0101000020E6100000E129E44A3D1961400954FF20920B4940
8280	4	37	864	18852	21777	\N	50.306153000000002	Хабаровский край, Амурский район, п. Малмыж, пер. Пионерский, д.2		0101000020E610000097E13FDDC01561404149810530274940
8288	4	37	864	19295	22199	\N	49.239522999999998	"Хабаровский край, Амурский район, п. Литовко, УИК - ул. Вокзальная, 16, место голосования - ул.Таежная, 12"		0101000020E6100000D1C952EB7DE56040E5D18DB0A89E4840
8289	4	37	864	19323	22043	\N	49.179197000000002	Хабаровский край, Амурский район, п. Лесной, ул. Горная, д.1		0101000020E610000095B9F94674E560404A4563EDEF964840
8278	4	37	864	7461	22042	\N	50.256512000000001	Хабаровский край, Амурский район, п.Известковый, ул.Центральная, д.14А		0101000020E6100000F4C29D0BA31461400A849D62D5204940
8284	4	37	864	7558	22023	\N	49.849960000000003	Хабаровский край, Амурский район, с. Джуен, ул. Центральная, д.6		0101000020E610000029AE2AFB2E0861403F74417DCBEC4840
8249	4	37	864	17300	\N	\N	48.826985999999998	Хабаровский край, Амурский район, с. Голубичное, дом дежурной по станции Коробко Е.Ю		0101000020E6100000062CB98A45DD6040FB1F60ADDA694840
8281	4	37	864	18933	19198	\N	50.131475999999999	Хабаровский край, Амурский район, с. Вознесенское, ул. Шерого, д.30А		0101000020E61000006919A9F7D41D6140BD1AA034D4104940
8283	4	37	864	19052	22136	\N	49.897855999999997	Хабаровский край, Амурский район, с. Болонь, ул. Вокзальная, д.15		0101000020E61000005859DB148F046140394206F2ECF24840
8282	4	37	864	7548	19307	\N	49.887898	Хабаровский край, Амурский район, с. Ачан, ул.Советская, д.23		0101000020E6100000F12A6B9BE2136140871744A4A6F14840
8268	4	37	864	6510	18963	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Строителей, д.47		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8263	4	37	864	6510	18963	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Строителей, д.35		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8261	4	37	864	6510	18963	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Строителей, д.16		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8259	4	37	864	6510	18963	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Строителей, д.11		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8258	4	37	864	6510	19194	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Победы, д.14А		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8265	4	37	864	6510	19207	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Октябрьский, д.22		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8262	4	37	864	6510	19207	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Октябрьский, д.2А		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8260	4	37	864	6510	19196	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Мира, д.46А		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8253	4	37	864	6510	19196	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Мира, д.22А		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8128	4	37	864	6510	19196	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Мира, д.40		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8267	4	37	864	6510	19191	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Комсомольский, д.81А		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8266	4	37	864	6510	19191	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Комсомольский, д.63		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8264	4	37	864	6510	19191	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Комсомольский, д.47		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8255	4	37	864	6510	19191	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Комсомольский, д.7А		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8254	4	37	864	6510	19191	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Комсомольский, д.42		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8250	4	37	864	6510	21761	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, ул. Школьная, д.9		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8252	4	37	864	6510	21884	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, ул. Лесная, д.3А		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8257	4	37	864	6510	21828	\N	50.255752000000001	Хабаровский край, Амурский район, г.Амурск, пр-т Комсомольский, д.48		0101000020E6100000B22C98F8A31A61407CF1457BBC204940
8251	4	37	864	6510	18926	\N	50.2157847861669	Хабаровский край, Амурский район, г.Амурск, ул. Амурская, д.5	Россия, Хабаровский край, городской округ Амурск	0101000020E6100000AAF3A8F8BF1C6140D2FBC6D79E1B4940
85523	4	40	\N	61554	79378	\N	43.847574888815402	Сахалинская область, Южно-Курильский район, с. Головнино, Нагорная, Дом культуры	Россия	0101000020E6100000ED6305BF0D3062401FF46C567DEC4540
85518	4	40	\N	61541	79364	\N	44.017778150145098	Сахалинская область, Южно-Курильский район,пгт.Южно-Курильск, пл.Ленина, 1 (актовый зал администрации МО)	Россия	0101000020E61000003656629E153962404D4BAC8C46024640
85591	4	40	\N	23754	\N	\N	47.102987828238099	"Сахалинская область, город Южно-Сахалинск, село Санаторное, Детский сад №29 ""Василек"""	Россия, Сахалинская область, Анивский район, село Санаторный	0101000020E6100000B2135E8253D46140B3F0F5B52E8D4740
85590	4	40	\N	23754	45924	\N	47.045975155907598	"Сахалинская область, город Южно-Сахалинск, село Новая Деревня, Красный уголок ГУСП ""Крмсомолец"""		0101000020E6100000B03C484F91D6614080B74082E2854740
85562	4	40	\N	23754	45746	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, проспект Победы, 80, Гимназия №2		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85561	4	40	\N	23754	45746	\N	46.960618862571799	Сахалинская область, город Южно-Сахалинск, проспект Победы, 68, Филиал РГТЭУ	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000FE2955A26CD7614047753A90F57A4740
85596	4	40	\N	23754	45727	\N	46.962264212862699	Сахалинская область, город Южно-Сахалинск, проспект Мира, 379, Дом-интернат для престарелых	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000006A15FDA199D761401F0F7D772B7B4740
85322	4	40	1394	15503	45876	\N	47.326619000000001	Сахалинская область, г.Долинск, Советская, 13-а, помещение спортзала ДЮСШ		0101000020E6100000BD512B4C5FD9614049A0C1A6CEA94740
85595	4	40	\N	23754	45727	\N	47.015078522201499	Сахалинская область, город Южно-Сахалинск, проспект Мира, 1, Психоневрологический интернат	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000522976348ED761409EEDD11BEE814740
85582	4	40	\N	23754	45727	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, проспект Мира, 428 А, Медицинский колледж		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85580	4	40	\N	23754	45727	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, проспект Мира, 426, ОАО ""Дальморнефтегеофизика"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85576	4	40	\N	23754	45727	\N	46.964883974624101	"Сахалинская область, город Южно-Сахалинск, проспект Мира, 424, ООО ""Сахалин-Шельф-Сервис"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E610000051F4C0C760D761408237A451817B4740
85551	4	40	\N	23754	45727	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, проспект Мира, 107, АУ ПТУ Сахалинской области		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85550	4	40	\N	23754	45727	\N	46.964144550847898	Сахалинская область, город Южно-Сахалинск, проспект Мира, 103, СОШ №13	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000CFF8BEB854D761400CCD751A697B4740
85536	4	40	\N	23754	45727	\N	46.9670897903477	"Сахалинская область, город Южно-Сахалинск, проспект Мира, 83, ДК ""Родина"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E610000019C5724BABD76140F224E99AC97B4740
85534	4	40	\N	23754	45727	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, проспект Мира, 17, Молочный комбинат		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85605	4	40	\N	23754	45939	\N	46.88520630419	"Сахалинская область, город Южно-Сахалинск, пл. район  Хомутово, ФГУП ""Аэропорт ""Южно-Сахалинск"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000C042E6CA20D761408A1C226E4E714740
85526	4	40	\N	23754	45847	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, пл. район  Ново-Александровск, пер. Железнодорожный, 12а, СОШ №32		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85538	4	40	\N	23754	45792	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, пер.Мартовский, 8б, МОУ ""Кадетская школа"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85530	4	40	\N	23754	45793	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, пл. район  Луговое, ул. им. В.Гайдука, 1, Библиотека филлиал №18		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85587	4	40	\N	23754	45944	\N	46.961911642086697	"Сахалинская область, город Южно-Сахалинск, жилой квартал Весточка, Дом культуры ""Электрон"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000CFF8BEB854D76140A2D0B2EE1F7B4740
85594	4	40	\N	23754	45920	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, село Старорусское, ул. Центральная, 12, ""Старорусский дом культуры"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85559	4	40	\N	23754	45799	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Хабаровская, 78, Областная библиотека		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85602	4	40	\N	23754	45856	\N	46.9551095065776	"Сахалинская область, город Южно-Сахалинск, ул. Усадебная, 12, Детский сад №32 ""Буратино"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000F01989D008D86140910A630B417A4740
85537	4	40	\N	23754	45743	\N	46.962793064642803	Сахалинская область, город Южно-Сахалинск, ул. Украинская, 112, Центр агрохимслужбы	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000C559113551D76140ABE80FCD3C7B4740
85533	4	40	\N	23754	45743	\N	46.949369413112798	Сахалинская область, город Южно-Сахалинск, ул. Украинская, 17б, Библиотека-центр досуга	Россия, Сахалинская область, Южно-Сахалинск	0101000020E610000083C1357774D76140096B63EC84794740
85532	4	40	\N	23754	45743	\N	46.963615712511398	"Сахалинская область, город Южно-Сахалинск, ул. Украинская, 11, ООО ""ЖЭУ №14"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000137D3ECA08D7614080F3E2C4577B4740
85553	4	40	\N	23754	45797	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Тихоокеанская, 18, СОШ №23		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85527	4	40	\N	23754	45810	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, пл. район  Ново-Александровск, ул. Советская, 78, Детская школа искусств №4		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85604	4	40	\N	23754	45916	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, пл. район  Ново-Александровск, ул. Северный городок, Общежитие Северного городка		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85542	4	40	\N	23754	45849	\N	46.930523478989599	Сахалинская область, город Южно-Сахалинск, ул. Северная, 32, СОШ №9	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000006A15FDA199D761408196AE601B774740
85544	4	40	\N	23754	45869	\N	46.959678639544997	"Сахалинская область, город Южно-Сахалинск, ул. Сахалинская, 106а, ООО ""Старыйдом-ЖЭУ -5"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E610000026A60BB17AD7614039D4EFC2D67A4740
85535	4	40	\N	23754	45826	\N	46.970020178419702	Сахалинская область, город Южно-Сахалинск, ул. Садовая, 5, СОШ №4	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000001CEDB8E177D76140A33B889D297C4740
85571	4	40	\N	23754	45802	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Пуркаева, 78а, СОШ №22		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85554	4	40	\N	23754	45798	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Поповича, 20а, Молодежно-подростковый центр		0101000020E6100000F46BEBA77FD86140098849B8907B4740
82796	4	34	\N	639	45407	\N	62.028191	Республика Саха (Якутия), город Якутск, Тургенева, 4		0101000020E6100000A0C03BF97436604051853FC39B034F40
85573	4	40	\N	23754	45800	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Пограничная, 5, Профессиональный лицей №2		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85569	4	40	\N	23754	45800	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, ул. Пограничная, 45, ОАО ""Сахалинавтотранс"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85567	4	40	\N	23754	45800	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Пограничная, 18, СОШ №8		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85566	4	40	\N	23754	45800	\N	46.952626436886298	Сахалинская область, город Южно-Сахалинск, ул. Пограничная, 48, СОШ №3	Россия, Сахалинская область, Южно-Сахалинск	0101000020E610000001A777F1FED66140DFA815A6EF794740
85482	4	40	\N	23754	45800	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Пограничная, 68, СахГУ		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85528	4	40	\N	23754	45791	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, пл. район  Ново-Александровск, ул. Науки, 5, Мол.-подростковый центр ""Южный"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85584	4	40	\N	23754	45794	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Ленина, 266а, Центр воспитательной работы		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85583	4	40	\N	23754	45794	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Ленина, 467а, Детский сад №3		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85565	4	40	\N	23754	45794	\N	46.9300531035273	Сахалинская область, город Южно-Сахалинск, ул. Ленина, 303а, СОШ №16	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000006B7D91D096D76140FA4509FA0B774740
85564	4	40	\N	23754	45794	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Ленина, 290, Главный корпус СахГУ		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85563	4	40	\N	23754	45794	\N	46.949570191960497	Сахалинская область, город Южно-Сахалинск, ул. Ленина, 284, Педагогический колледж СахГУ	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000C68844A1E5D66140A1A17F828B794740
85539	4	40	\N	23754	45794	\N	46.9538018689423	Сахалинская область, город Южно-Сахалинск, ул. Ленина, 111, Институт развития образования	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000FF91E9D069D76140016E162F167A4740
85548	4	40	\N	23754	45795	\N	46.956622799884101	Сахалинская область, город Южно-Сахалинск, ул.Курильская, 54, СОШ №5	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000FE2955A26CD76140FBCC599F727A4740
85593	4	40	\N	23754	77156	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, село Березняки, ул. Крайняя, 8а, Дом культуры ""Родник"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85579	4	40	\N	23754	45747	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Комсомольская, 308, СОШ №6		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85578	4	40	\N	23754	45747	\N	46.966059135748601	Сахалинская область, город Южно-Сахалинск, ул. Комсомольская, 300, СОШ №26	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000003EEAAF5758D76140D48041D2A77B4740
85577	4	40	\N	23754	45747	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, ул. Комсомольская, 300б, ООО ""УК ЖЭУ №10"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85575	4	40	\N	23754	45747	\N	46.9641788654801	"Сахалинская область, город Южно-Сахалинск, ул. Комсомольская, 276, ООО ""ЖЭУ-9"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000005586713788D66140B83EAC376A7B4740
85556	4	40	\N	23754	45747	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Комсомольская, 191а, Лицей №1		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85557	4	40	\N	23754	45796	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, Коммунистический проспект, 33, Институт экономики СахГУ		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85552	4	40	\N	23754	45796	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, Коммунистический проспект, 20, Дворец детского творчества		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85592	4	40	\N	23754	45843	\N	47.173385220917197	Сахалинская область, город Южно-Сахалинск, село Синегорск, ул. Коммунистическая, 49, СОШ №18		0101000020E61000007B67B455C9D06140F94ECC7A31964740
85531	4	40	\N	23754	45848	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, пл. район  Луговое, ул. Комарова, 5, Городская поликлиника №5		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85546	4	40	\N	23754	45828	\N	46.9679050273093	Сахалинская область, город Южно-Сахалинск, ул Железнодорожная, 65, Депо подвижного сотава ОАО РЖД	Россия, Сахалинская область, Южно-Сахалинск	0101000020E610000033897AC1A7D661404451A04FE47B4740
85572	4	40	\N	23754	45801	\N	46.956152655118501	Сахалинская область, город Южно-Сахалинск, ул. Емельянова, 19а, СОШ №21	Россия, Сахалинская область, Южно-Сахалинск	0101000020E6100000EB39E97D63D76140747CB438637A4740
85570	4	40	\N	23754	45801	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Емельянова, 35, Гимназия №1 им А.С.Пушкина		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85529	4	40	\N	23754	45846	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, пл. район  Луговое, ул. Дружбы, 75, ГУСП ""Комсомолец"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85541	4	40	\N	23754	45806	\N	46.9558588125292	"Сахалинская область, город Южно-Сахалинск, ул. Достоевского, 2А, ООО ""Сахалинская механизированная колонна"""	Россия, Сахалинская область, Южно-Сахалинск	0101000020E610000027A1F48510D761402B4B7496597A4740
85545	4	40	\N	23754	45850	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Деповская, 42, Училище №17		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85574	4	40	\N	23754	45851	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Горького, 25, СКБ САМИ ДО РАН		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85568	4	40	\N	23754	45851	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Горького, 26, Колледж бизнеса и информатики		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85555	4	40	\N	23754	45851	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Горького, 7/1, Детская спортивная школа		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85547	4	40	\N	23754	45745	\N	46.950780014840802	Сахалинская область, город Южно-Сахалинск, ул. Вокзальная, 55, Дом культуры железнодорожников	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000007808E3A771D761406FD8B628B3794740
85558	4	40	\N	23754	45827	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, ул. Антона Буюклы, 14, НОШ №7		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85560	4	40	\N	23754	45764	\N	46.9545071157061	Сахалинская область, город Южно-Сахалинск, ул. Амурская, 121, СОШ №1	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000000E863AAC70D76140CB660E492D7A4740
85586	4	40	\N	23754	45803	\N	46.965353999999998	Сахалинская область, город Южно-Сахалинск, пл. район  Хомутово, ул. 2-я Центральная, 39, Отдел по упралению территорией		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85585	4	40	\N	23754	45803	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, пл. район  Хомутово, ул. 2-я Центральная, 33, МУЗ ""Амбулатория Хомутово"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
85525	4	40	\N	23754	45825	\N	46.965353999999998	"Сахалинская область, город Южно-Сахалинск, пл. район  Ново-Александровск, ул. 2-я Красносельская, 14а, ДК ""Радуга"""		0101000020E6100000F46BEBA77FD86140098849B8907B4740
95024	4	40	\N	23754	45818	\N	46.963204390168201	Сахалинская область, город Южно-Сахалинск, ул. Чехова, 4А, МБУ "Молодежно-подростковый центр "Южны", Шахматный клуб	Россия, Сахалинская область, Южно-Сахалинск	0101000020E61000009E978A8D79D761402DB0C7444A7B4740
85485	4	40	\N	55616	45790	\N	49.073943958216098	Сахалинская область, Углегорский район, г.Углегорск, Победы, 142, помещение администрации УМР	Россия, Сахалинская область, Углегорский район, Углегорск	0101000020E61000002B3410CBE6C1614022DE3AFF76894840
85484	4	40	\N	55616	45744	\N	49.077552720293198	Сахалинская область, Углегорский район, г.Углегорск, Заводская, 8, помещение МБОУ ДОД ДШИ		0101000020E610000083FB010F0CC26140755AB741ED894840
85427	4	40	\N	61562	79392	\N	50.666582864655503	Сахалинская область, Северо-Курильский район, Дом культуры, Парковая, 6	Россия	0101000020E6100000750470B378836340E8887C9752554940
85414	4	40	\N	55614	45735	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.Октябрьская, д.31 (здание МБОУ СОШ № 2)		0101000020E6100000340F60915FE36140853E58C6869C4840
85412	4	40	\N	55614	45735	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.Октябрьская, д.63 (здание МБОУ ДОД ДШИ)		0101000020E6100000340F60915FE36140853E58C6869C4840
85410	4	40	\N	55614	45741	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.2-я Восточная, д.29 (здание МБОУ СОШ № 8)		0101000020E6100000340F60915FE36140853E58C6869C4840
85302	4	40	\N	55642	45953	\N	46.788817468712203	Сахалинская область, Анивский район, п.Петропавловское, Клубная, 15 (дом культуры)	Россия, Сахалинская область, Р-495	0101000020E61000000ADB4FC678D06140B1C398F4F7644740
85407	4	40	\N	55615	\N	\N	53.586002000000001	"Сахалинская область, г.Оха, ООО ""Сахалинский аропорт Оха"""		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85398	4	40	\N	55615	45873	\N	53.586002000000001	Сахалинская область, г.Оха, ул.Школьная, 15 (школа №3)		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85392	4	40	\N	55615	45736	\N	53.582886540802001	"Сахалинская область, г.Оха, ул.Ленина, 24 (НГДУ ""Оханефтегаз"" )"		0101000020E6100000CCD4247843DE6140BC218D0A9CCA4A40
85391	4	40	\N	55615	45773	\N	53.586002000000001	Сахалинская область, г.Оха, ул.Карла Маркса, 26/1 (Центр образования г.Охи)		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85378	4	40	\N	55615	45771	\N	53.586002000000001	"Сахалинская область, г.Оха, ул.50 лет Октября, 25/2 (филиал УМНГ ООО""РН-СМНМ"")"		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85366	4	40	\N	55613	45733	\N	48.621575999999997	Сахалинская область, Макаровский район, город Макаров, Милютина, 3 (Дом культуры)		0101000020E61000008E91EC11EAD861403FFD67CD8F4F4840
85359	4	40	\N	61555	79379	\N	45.1872102329786	Сахалинская область, Курильский район, город Курильск, ул.Андрея Евдокимова, д.17, районный Дом культуры	Россия, остров Итуруп	0101000020E610000094F947DF24806240F9BD4D7FF6974640
85345	4	40	\N	55620	45781	\N	46.632269000000001	"Сахалинская область, г. Корсаков, Овражная, 8, здание соц.-реаб.центра ""Радуга"""		0101000020E61000006F641EF903D9614027A3CA30EE504740
85350	4	40	\N	55620	45762	\N	46.632269000000001	Сахалинская область, г. Корсаков, Краснофлотская, 1, здание школы № 1		0101000020E61000006F641EF903D9614027A3CA30EE504740
85356	4	40	\N	55620	45763	\N	46.632269000000001	Сахалинская область, г. Корсаков, Восточная, 29, здание начальной школы № 5		0101000020E61000006F641EF903D9614027A3CA30EE504740
85520	4	40	\N	61543	\N	\N	44.042953123142397	Сахалинская область, Южно-Курильский район, п. Горячий Пляж, клуб Службы в р.п. Южно-Курильске	Россия	0101000020E61000000A2C802903396240EE21E17B7F054640
85310	4	40	\N	55618	45754	\N	46.717583155393299	Сахалинская область, г.Анива, Ленина, 6 (школа искусств)	Россия, Сахалинская область, Анивский район, Анива	0101000020E6100000CA6B257417D1614031957EC2D95B4740
85308	4	40	\N	55618	45757	\N	46.718809659146999	Сахалинская область, г.Анива, Калинина, 52 (дом детского творчества)		0101000020E6100000D4F02DAC1BD16140D50451F7015C4740
33353	4	41	1601	55683	46275	\N	48.520586000000002	пос. Приамурский, ул. Дзержинского, д. 4		0101000020E6100000ACE4637701DD6040B360E28FA2424840
85543	4	40	\N	55618	45946	\N	46.718291528722098	Сахалинская область, г. Анива, Заречная, 2 (контора ДРСУ)	Россия, Сахалинская область, Анивский район, Анива	0101000020E6100000CB85CABF16D161403D7D04FEF05B4740
85291	4	40	\N	55628	45885	\N	50.896124672418701	Сахалинская область, г.Александровск- Сахалинский, Цапко, 43, помещение СОШ № 6	Россия, Сахалинская область, Александровск-Сахалинский район, Александровск-Сахалинский	0101000020E61000002EAC1BEF0EC5614062105839B4724940
85588	4	40	7375	55625	45854	\N	46.995426280431097	"Сахалинская область, город Южно-Сахалинск, село Дальнее, ул. Новая, 20, ""Дальненский дом культуры"""	Россия, Сахалинская область, городской округ Южно-Сахалинск, село Дальнее	0101000020E61000006B7F677B74D5614047CB811E6A7F4740
85524	4	40	7532	61560	\N	\N	43.793250330666503	Сахалинская область, Южно-Курильский район, с.Малокурильское, морбригада	Россия	0101000020E6100000D49E9273E25A6240A8C64B3789E54540
85521	4	40	7532	61567	79398	\N	43.787415305138801	"Сахалинская область, Южно-Курильский район, с. Крабозаводское, Торговая, Д/к ""Утро Родины"""	Россия	0101000020E6100000FEEDB25FF75A62409FB0C403CAE44540
85502	4	40	1749	55629	45888	\N	47.147653893801703	Сахалинская область, Холмский район, село Яблочное, улица Центральная, 16 (Сельская управа)	Россия, Сахалинская область, Холмский район, село Яблочный	0101000020E6100000957F2DAFDCC16140D28F8653E6924740
85501	4	40	1749	55629	45888	\N	47.147361110985102	Сахалинская область, Холмский район, село Яблочное, ул.Центральная, 52 (Сельская школа)	Россия, Сахалинская область, Холмский район, село Яблочный	0101000020E610000096B37746DBC1614059DAA9B9DC924740
85500	4	40	1749	55629	45929	\N	47.147771006473903	Сахалинская область, Холмский район, село Яблочное, ул.Зеленая, 24 (спортивная база)	Россия, Сахалинская область, Холмский район, село Яблочный	0101000020E6100000B1C05774EBC161400B26FE28EA924740
85496	4	40	1749	24431	45852	\N	47.433380964542302	Сахалинская область, Холмский район, село Чехов, пер.Бумажный, 6 (спортивный клуб)	Россия, Сахалинская область, Холмский район	0101000020E610000005DD5ED218C1614098DA520779B74740
85497	4	40	1749	24431	45824	\N	47.432740332054202	Сахалинская область, Холмский район, село Чехов, ул.Ленина, 54 (Кинотеатр)	Россия, Сахалинская область, Холмский район	0101000020E6100000FCA5457D12C16140E5D5390664B74740
85517	4	40	1749	25404	45789	\N	46.964830999999997	Сахалинская область, Холмский район, село Чапланово, село Чапланово, ул.Речная, 26-а (Сельский Дом культуры)		0101000020E6100000EA059FE664C761405F950B957F7B4740
85513	4	40	1749	24822	45787	\N	47.05744	Сахалинская область, Холмский район, город  Холмск, пл.Ленина, 3 (Кинодосуговый центр)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85514	4	40	1749	24822	45823	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Школьная, 33 (Детская школа искусств)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85508	4	40	1749	24822	45731	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Советская, 124 (Центр. районная библиотека)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85511	4	40	1749	24822	45786	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Победы, 12 (Лицей)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85503	4	40	1749	24822	45943	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул. Переселенческая, 2 (Сельский Дом культуры)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85510	4	40	1749	24822	45822	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Первомайская, 7 (Школа)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85509	4	40	1749	24822	45785	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Морская, 14 (Центр.район. дом культуры)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85507	4	40	1749	24822	45845	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Матросова, 2 (Школа)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85506	4	40	1749	24822	45904	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Макарова, 1 (Мореходное училище)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85505	4	40	1749	24822	45784	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Крузенштерна, 2 (Общежитие)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85504	4	40	1749	24822	45784	\N	47.05744	Сахалинская область, Холмский район, город  Холмск, ул.Крузенштерна, 7 (Детский сад)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85515	4	40	1749	24822	45788	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Комсомольская, 6 (Школа)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85512	4	40	1749	24822	45742	\N	47.05744	Сахалинская область, Холмский район, город Холмск, ул.Капитанская, 10 (Коррекционная школа)		0101000020E6100000EC33677DCAC16140BABDA4315A874740
85516	4	40	1749	55623	45829	\N	46.939839869100297	Сахалинская область, Холмский район, село Правда, ул.Центральная, 27 (Сельский Дом культуры)	Россия, Сахалинская область, Холмский район	0101000020E61000009204E10A28C061407FBC57AD4C784740
85499	4	40	1749	24582	45942	\N	47.262515	Сахалинская область, Холмский район, село Пионеры, ул.Школьная, 3 (Филиал централиз. библ.системы)		0101000020E6100000ECBE6378ECC06140CFDA6D179AA14740
85495	4	40	1749	24427	45949	\N	47.465423999999999	Сахалинская область, Холмский район, село Новосибирское, Новосибирское, 60 (Сельская управа)		0101000020E61000004A5F0839EFBE614002637D0393BB4740
85498	4	40	1749	24540	45783	\N	47.304980999999998	Сахалинская область, Холмский район, село Костромское, ул.Центральная, 1 (Сельский Дом культуры)		0101000020E610000042942F68A1C0614060730E9E09A74740
85494	4	40	1715	55641	\N	\N	48.883790677895902	Сахалинская область, Углегорский район, с.Поречье, помещение МБОУ СОШ с.Поречье		0101000020E6100000236AA2CF47C06140E4BF401020714840
85475	4	40	1715	23403	45881	\N	49.170174000000003	Сахалинская область, Углегорский район, г.Шахтерск, Победы, 1, помещение МБОУ ДЮСШ		0101000020E6100000A31D37FC6EC361409450FA42C8954840
85481	4	40	1715	23403	45777	\N	49.170174000000003	Сахалинская область, Углегорский район, г.Шахтерск, Мира, 8, помещение администрации ШГП		0101000020E6100000A31D37FC6EC361409450FA42C8954840
85480	4	40	1715	23403	45777	\N	49.170174000000003	Сахалинская область, Углегорский район, г.Шахтерск, Мира, 15А, помещение МБОУ СОШ № 2		0101000020E6100000A31D37FC6EC361409450FA42C8954840
85479	4	40	1715	23403	45777	\N	49.170174000000003	Сахалинская область, Углегорский район, г.Шахтерск, Мира, 8А, помещение Дворца культуры		0101000020E6100000A31D37FC6EC361409450FA42C8954840
85477	4	40	1715	23403	45841	\N	49.170174000000003	Сахалинская область, Углегорский район, г.Шахтерск, Ленина, 12, помещение МБОУ ДОД ДШИ		0101000020E6100000A31D37FC6EC361409450FA42C8954840
85478	4	40	1715	23403	45780	\N	49.170174000000003	Сахалинская область, Углегорский район, г.Шахтерск, Коммунистическая, 1А, помещение МБОУ СОШ № 1		0101000020E6100000A31D37FC6EC361409450FA42C8954840
85488	4	40	1715	23827	45914	\N	49.066997999999998	Сахалинская область, Углегорский район, г.Углегорск, Угольная, 7 А, помещение АТП		0101000020E610000086E28E37F9C16140DE72F56393884840
85489	4	40	1715	23827	45860	\N	49.076020724632798	Сахалинская область, Углегорский район, г.Углегорск, Приморская, 35, помещение МБОУ СОШ № 2	Россия, Сахалинская область, Углегорский район, Углегорск	0101000020E6100000567DAEB6E2C1614094675E0EBB894840
85486	4	40	1715	23827	45778	\N	49.066997999999998	Сахалинская область, Углегорский район, г.Углегорск, Победы, 153 А, помещение библиотеки		0101000020E610000086E28E37F9C16140DE72F56393884840
85483	4	40	1715	23827	45778	\N	49.066997999999998	Сахалинская область, Углегорский район, г.Углегорск, Победы, 238, помещение МУС РСК Углегорский		0101000020E610000086E28E37F9C16140DE72F56393884840
85487	4	40	1715	23827	45902	\N	49.066997999999998	Сахалинская область, Углегорский район, г.Углегорск, Войтинского, 22, помещение ГУП ДРСУ		0101000020E610000086E28E37F9C16140DE72F56393884840
85474	4	40	1715	23371	45921	\N	49.385371999999997	Сахалинская область, Углегорский район, п.Тельновский, Советская, 125, помещение бывшей больницы		0101000020E6100000BC7A15191DC46140A565A4DE53B14840
85469	4	40	1715	23132	\N	\N	48.843335000000003	Сахалинская область, Углегорский район, с.Ольшанка, помещение клуба	Россия, Сахалинская область, Углегорский район, село Ольшанка	0101000020E610000077DCF0BB69BE61403D49BA66F26B4840
85493	4	40	1715	24276	45918	\N	49.061095000000002	Сахалинская область, Углегорский район, с.Ольховка, Центральная, 16, помещение администрации		0101000020E61000002EE411DC48C361407D7901F6D1874840
85492	4	40	1715	24231	\N	\N	48.987285	Сахалинская область, Углегорский район, с.Никольское, помещение Дома культуры	Россия, Сахалинская область, Углегорский район, село Никольское	0101000020E6100000CCD24ECD65C461406A6AD95A5F7E4840
85490	4	40	1715	24125	45917	\N	48.895105999999998	Сахалинская область, Углегорский район, с.Медвежье, Есенина, 4, помещение клуба		0101000020E61000005F9B8D9598C86140083A5AD592724840
85473	4	40	1715	23357	9819	\N	49.442992095981197	Сахалинская область, Углегорский район, с.Лесогорское, Пионерская, 11, помещение администрации	Россия, Сахалинская область, Углегорский район, село Лесогорское	0101000020E6100000D5EB168131C46140DF313CF6B3B84840
85491	4	40	1715	24224	45895	\N	48.942397999999997	Сахалинская область, Углегорский район, с.Краснополье, Новая, 1, помещение МБОУ СОШ		0101000020E6100000FF243E7782C661406CE8667FA0784840
85472	4	40	1715	23264	45874	\N	49.650981000000002	"Сахалинская область, Углегорский район, п.Бошняково, Советская, 5, помещение ДК ""Океан"""		0101000020E610000005DD5ED298C56140A0A86C5853D34840
85471	4	40	1715	23264	45940	\N	49.650981000000002	Сахалинская область, Углегорский район, п.Бошняково, Заводская, 5, помещение МБОУ СОШ с.Бошняково		0101000020E610000005DD5ED298C56140A0A86C5853D34840
85468	4	40	1694	23098	45840	\N	50.640974999999997	Сахалинская область, Тымовский район, с.Ясное, Титова, 2 (здание сельского клуба)		0101000020E6100000AED85F76CFD66140DC4603780B524940
85454	4	40	1694	22458	45938	\N	51.203195000000001	Сахалинская область, Тымовский район, с.Чир-Унвд, Советская, 7  (здание школы)		0101000020E61000004084B872F6D56140F9DA334B029A4940
85459	4	40	1694	22735	45839	\N	50.848784000000002	Сахалинская область, пгт.Тымовское, Харитонова, 14 (здание краеведческого музея)		0101000020E610000032FFE89B34D561401DAF40F4A46C4940
85462	4	40	1694	22735	45842	\N	50.848784000000002	Сахалинская область, пгт.Тымовское, Торговая, 9 (здание школы №1)		0101000020E610000032FFE89B34D561401DAF40F4A46C4940
85461	4	40	1694	22735	45894	\N	50.848784000000002	Сахалинская область, пгт.Тымовское, Советская, 4 (здание профлицея №7)		0101000020E610000032FFE89B34D561401DAF40F4A46C4940
85463	4	40	1694	22735	45776	\N	50.848784000000002	Сахалинская область, пгт.Тымовское, Криворучко, 21 (здание школы №3)		0101000020E610000032FFE89B34D561401DAF40F4A46C4940
85460	4	40	1694	22735	45775	\N	50.848784000000002	Сахалинская область, пгт.Тымовское, Кировская, 68-А (здание дома культуры)		0101000020E610000032FFE89B34D561401DAF40F4A46C4940
85457	4	40	1694	22604	45893	\N	51.017423999999998	Сахалинская область, Тымовский район, с.Молодежное, Советская, 16 (здание школы)		0101000020E61000000B09185DDED461402F151BF33A824940
85522	4	40	1694	61545	\N	\N	50.350879999999997	"Сахалинская область, Южно-Курильский район, с. Малокурильское, Д/к ""Океан"""	Россия, Сахалинская область, Тымовский район	0101000020E61000000A11700855DF61400569C6A2E92C4940
33355	4	41	1601	55683	46237	\N	48.520586000000002	пос. Приамурский, ул. Вокзальная, д. 25		0101000020E6100000ACE4637701DD6040B360E28FA2424840
85465	4	40	1694	22993	45901	\N	50.786465	Сахалинская область, Тымовский район, с.Красная Тымь, Новая, 1 (здание администрации с/о)		0101000020E6100000D6FCF84B8BD561406D3997E2AA644940
85466	4	40	1694	23000	45872	\N	50.708993999999997	Сахалинская область, Тымовский район, с.Кировское, Центральная, 73 (здание дома культуры)		0101000020E61000001D3C139A24D76140B587BD50C05A4940
85467	4	40	1694	55640	45941	\N	50.653260968317703	Сахалинская область, Тымовский район, с.Зональное, Школьная, 12 (здание дома культуры)	Россия, Сахалинская область, Тымовский район	0101000020E6100000FE99417CE0D861404A60730E9E534940
85464	4	40	1694	22907	45884	\N	50.835093999999998	Сахалинская область, Тымовский район, с.Восход, Космическая, 13 (здание школы)		0101000020E610000075E95F924AD36140FC8A355CE46A4940
85458	4	40	1694	22658	45896	\N	50.899614	Сахалинская область, Тымовский район, с.Воскресеновка, Школьная, 9 (здание администрации с/о)		0101000020E6100000B24B546F8DD561400A83328D26734940
85470	4	40	1694	23184	45962	\N	50.692706000000001	Сахалинская область, Тымовский район, с.Белоречье, Советская, 8 (здание клуба)		0101000020E6100000A51309A69ADB61401ADF1797AA584940
85453	4	40	1694	22452	45891	\N	51.348618999999999	Сахалинская область, Тымовский район, c.Арги-Паги, Комсомольская, 1 (здание школы)		0101000020E61000009FABADD85FD76140D2E1218C9FAC4940
85456	4	40	1694	22564	45965	\N	51.131892000000001	Сахалинская область, Тымовский район, с.Адо-Тымово, Советская, 3 (здание администрации с/о)		0101000020E61000002497FF907ED56140514D49D6E1904940
85449	4	40	1679	22295	45937	\N	47.904096000000003	Сахалинская область, Томаринский район, с.Черемшанка, ул.Ленина, д.12 (здание начальной школы)		0101000020E6100000A73CBA1116C66140E338F06AB9F34740
85452	4	40	1679	22305	45820	\N	47.765073000000001	Сахалинская область, Томаринский район, г.Томари, ул.Новая, д.1 (здание РОНО)		0101000020E6100000535C55F65DC26140BC067DE9EDE14740
85450	4	40	1679	22305	45890	\N	47.765073000000001	"Сахалинская область, Томаринский район, г.Томари, ул.Калинина, д.35 (помещение ЗАО ""Тепло"")"		0101000020E6100000535C55F65DC26140BC067DE9EDE14740
85451	4	40	1679	22305	45821	\N	47.765073000000001	Сахалинская область, Томаринский район, г.Томари, ул.А.Буюклы, д.4а (районный дом культуры)		0101000020E6100000535C55F65DC26140BC067DE9EDE14740
85448	4	40	1679	22208	45963	\N	47.897736000000002	Сахалинская область, Томаринский район, с.Пензенское, ул.Вокзальная, д.4 (здание дома культуры)		0101000020E61000001618B2BAD5C461408F386403E9F24740
85445	4	40	1679	22069	45960	\N	48.3221993471413	Сахалинская область, Томаринский район, с.Парусное, ул.Центральная, д.3 (здание ОУТ)	Россия, Сахалинская область, Томаринский район, село Парусное	0101000020E6100000CCD42478C3C46140E6E61BD13D294840
85441	4	40	1679	21922	45857	\N	48.411422000000002	Сахалинская область, Томаринский район, с.Красногорск, ул.Победы, д.17(помещение дома культуры)		0101000020E6100000D905836BEEC261406E6DE179A9344840
85444	4	40	1679	21922	45889	\N	48.411422000000002	Сахалинская область, Томаринский район, с.Красногорск, ул.Карла Маркса, д.31 (здание администрации)		0101000020E6100000D905836BEEC261406E6DE179A9344840
85443	4	40	1679	21922	45889	\N	48.411422000000002	Сахалинская область, Томаринский район, с.Красногорск, ул.Карла Маркса, д.38 (помещение детской библиотеки)		0101000020E6100000D905836BEEC261406E6DE179A9344840
85446	4	40	1679	55637	45928	\N	47.988717904988398	Сахалинская область, Томаринский район, с.Ильинское, пер.Гвардейский, д.15 (помещение ОУТ)	Россия, Сахалинская область, Томаринский район, село Ильинский	0101000020E610000089963C9E96C66140B77BB94F8EFE4740
85447	4	40	1679	55637	45961	\N	47.989347534391797	Сахалинская область, Томаринский район, с.Ильинское, ул.Ломоносова, д.8а (помещение лесничества)	Россия, Сахалинская область, Томаринский район, село Ильинский	0101000020E610000072E1404896C66140772E8CF4A2FE4740
85435	4	40	1662	21544	45883	\N	49.748227	Сахалинская область, Смирныховский район, Смирных поселок, Центральная, 46 (контора ГУП Смирныховское ДРСУ)		0101000020E61000005BD3BCE394DA6140FA7DFFE6C5DF4840
85434	4	40	1662	21544	45959	\N	49.748227	Сахалинская область, Смирныховский район, Смирных поселок, Торговая, 22 (помещение конторы ЦЛХ)		0101000020E61000005BD3BCE394DA6140FA7DFFE6C5DF4840
85437	4	40	1662	21544	45809	\N	49.748227	Сахалинская область, Смирныховский район, Смирных поселок, Маяковского, 9 (помещение Центра досуга РДК)		0101000020E61000005BD3BCE394DA6140FA7DFFE6C5DF4840
85436	4	40	1662	21544	45819	\N	49.748227	"Сахалинская область, Смирныховский район, Смирных, 8 марта, 32 (спортивный комплекс ""Арена"")"		0101000020E61000005BD3BCE394DA6140FA7DFFE6C5DF4840
85429	4	40	1662	21343	45958	\N	49.959429999999998	Сахалинская область, Смирныховский район, Рощино село, Парковая, 9 (помещение администрации)		0101000020E6100000878C47A984D8614090662C9ACEFA4840
85432	4	40	1662	21442	45739	\N	49.838170193445698	Сахалинская область, Смирныховский район, Победино село, Центральная, 60 (помещение Дома культуры)	Россия, Сахалинская область, Смирныховский район, село Победино	0101000020E610000054ABAFAE0ADA6140813E912749EB4840
85431	4	40	1662	21436	45899	\N	49.969552999999998	Сахалинская область, Смирныховский район, Первомайск село, Суворова, 1 (помещение администрации)		0101000020E6100000E448676064E861408D5E0D501AFC4840
85428	4	40	1662	21266	45738	\N	50.191324999999999	Сахалинская область, Смирныховский район, Онор село, Транспортная, 2 (помещение Дома культуры с.Онор)		0101000020E6100000A9DE1AD82AD661401FF46C567D184940
85439	4	40	1662	21728	45900	\N	49.544333000000002	Сахалинская область, Смирныховский район, Буюклы село, Школьная, (помещение администрации с. Буюклы)		0101000020E61000006B6116DAB9DB6140199128B4ACC54840
84101	4	34	\N	639	45243	\N	62.028191	Республика Саха (Якутия), город Якутск, Стадухина, 78		0101000020E6100000A0C03BF97436604051853FC39B034F40
85438	4	40	1662	21728	45897	\N	49.544333000000002	Сахалинская область, Смирныховский район, Буюклы село, Космонавтов, (помещение Дома культуры)		0101000020E61000006B6116DAB9DB6140199128B4ACC54840
85421	4	40	1617	20917	45911	\N	49.204033937912598	Сахалинская область, Поронайский район, с.Тихменево, ул.Ленина, д.44 (здание администрации)	Россия, Сахалинская область, Поронайский район, село Тихменево	0101000020E610000040683D7C99DC6140D3A23EC91D9A4840
85415	4	40	1617	20174	45879	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, пр-т А.Буюклы, д.2 (здание МБОУ СОШ № 1)		0101000020E6100000340F60915FE36140853E58C6869C4840
85416	4	40	1617	20174	45936	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.Торфяная, д.23 (здание лицея-интерната № 3)		0101000020E6100000340F60915FE36140853E58C6869C4840
85409	4	40	1617	20174	45817	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.Победы, д.72 (здание вечерней школы)		0101000020E6100000340F60915FE36140853E58C6869C4840
85408	4	40	1617	20174	45817	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.Победы, д.72 (здание МБОУ СОШ № 7)		0101000020E6100000340F60915FE36140853E58C6869C4840
85413	4	40	1617	20174	45724	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.Октябрьская, д.76 (здание УОКИС)		0101000020E6100000340F60915FE36140853E58C6869C4840
85411	4	40	1617	20174	45770	\N	49.222862999999997	Сахалинская область, Поронайский район, г.Поронайск, ул.Гагарина, д.38 (здание МБОУ ДОД ДЮСШ)		0101000020E6100000340F60915FE36140853E58C6869C4840
85425	4	40	1617	21163	45913	\N	49.465479000000002	Сахалинская область, Поронайский район, с.Малиновка, ул.Школьная, д.14 (здание МБОУ СОШ)		0101000020E610000095D6DF1200DD6140C6FCDCD094BB4840
85423	4	40	1617	21062	45910	\N	49.292808000000001	Сахалинская область, Поронайский район, с.Майское, ул.Ленина, д.9 (здание Досугового центра)		0101000020E61000002446CF2D74DC6140EB0088BB7AA54840
85422	4	40	1617	20983	45875	\N	49.280591999999999	Сахалинская область, Поронайский район, с.Леонидово, ул.Калинина, д.16 (здание администрации)		0101000020E61000006FF085C9D4DB614076C24B70EAA34840
85424	4	40	1617	21068	45912	\N	49.359650000000002	Сахалинская область, Поронайский район, с.Забайкалец, ул.Советская, д.8 (здание администрации)		0101000020E61000006ADC9BDFB0DB6140D200DE0209AE4840
85420	4	40	1617	20863	45870	\N	49.101557999999997	Сахалинская область, Поронайский район, с.Гастелло, ул.Центральная, д.54 (здание администрации)		0101000020E6100000A27DACE037DE6140D65240DAFF8C4840
85419	4	40	1617	20851	45772	\N	48.980981999999997	Сахалинская область, Поронайский район, с.Восток, ул.Гагарина, д.10а (здание ДК Энергетик)		0101000020E6100000BF4351A04FDD61407AFB73D1907D4840
85418	4	40	1617	20755	45805	\N	48.990257999999997	Сахалинская область, Поронайский район, п.Вахрушев, ул.Центральная, д.99Б (здание Дома культуры)		0101000020E6100000588D25AC0DDC61401A4D2EC6C07E4840
85402	4	40	1431	19837	45838	\N	53.389026000000001	Сахалинская область, Охинский район, с.Тунгор, ул.Нефтяников, 17 (библиотека)		0101000020E6100000250516C094DE614098A59D9ACBB14A40
85397	4	40	1431	15958	45737	\N	53.586002000000001	"Сахалинская область, г.Оха, ул.Советская, 26 (ОАО ""Сахалинморнефтемонтаж"")"		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85395	4	40	1431	15958	45737	\N	53.586002000000001	Сахалинская область, г.Оха, ул.Советская, 1 (Дом детства и юношества)		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85393	4	40	1431	15958	45835	\N	53.586002000000001	Сахалинская область, г.Оха, ул.Победы, 6 (техникум)		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85406	4	40	1431	15958	45769	\N	53.586002000000001	"Сахалинская область,  г.Оха, ул.Карла Маркса, 54/1 (спорткомплекс ""Дельфин"")"		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85394	4	40	1431	15958	45769	\N	53.586002000000001	Сахалинская область, г.Оха, ул.Карла Маркса, 14А (школа №2)		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85396	4	40	1431	15958	45836	\N	53.586002000000001	"Сахалинская область, г.Оха, ул.Дзержинского, 17/1 (ООО ""Управдом №3"")"		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85325	4	40	1431	15958	45812	\N	53.586002000000001	Сахалинская область, г.Оха, ул. 60 лет СССР, 32/1 (школа №1)		0101000020E61000004CC5C6BC0EDE6140FFB1101D02CB4A40
85403	4	40	1431	19884	45882	\N	53.683916942053401	Сахалинская область, Охинский район, с.Некрасовка, ул.Октябрьская, 1 (школа-интернат)	Россия, Сахалинская область, Охинский район, село Некрасовка	0101000020E61000001B2AC6F91BD46140D7169E978AD74A40
85405	4	40	1431	20042	45957	\N	53.582668772298497	Сахалинская область, Охинский район, с.Москальво, ул.Советская, 3 (школа)	Россия, Сахалинская область, Охинский район, село Москальво	0101000020E61000006DC7D45D59D061404FB2D5E594CA4A40
85400	4	40	1431	55636	45923	\N	53.582502776676598	"Сахалинская область, Охинский район, с.Лагури, ул.Ленина, 53 , ООО ""Управдом Лагури"""	Россия, Сахалинская область, Охинский район	0101000020E61000009414580053D86140346953758FCA4A40
85401	4	40	1431	55626	45865	\N	53.4910803123419	Сахалинская область, Охинский район, с.Восточное, ул.Школьная, 11А (школа)	Россия, Сахалинская область, Охинский район, село Восточный	0101000020E6100000F86BB2463DE261401EDC9DB5DBBE4A40
85390	4	40	1511	19216	45880	\N	51.535880905374498	Сахалинская область, Ногликский район, с.Ныш, ул.Советская, д.11, здание СДК с.Ныш	Россия, Сахалинская область, Ногликский район, село Ныш	0101000020E61000004888F2052DD861401EC6A4BF97C44940
85383	4	40	1511	18843	45871	\N	51.795757000000002	Сахалинская область, Ногликский район, п. Ноглики, ул. Штернберга, д.4а, филиал Тымовского лицея №7		0101000020E6100000354415FE8CE461401348895DDBE54940
85388	4	40	1511	18843	45767	\N	51.795757000000002	Сахалинская область, Ногликский район, п. Ноглики, ул. Советская, д.60, здание краевед. музея		0101000020E6100000354415FE8CE461401348895DDBE54940
85387	4	40	1511	18843	45767	\N	51.795757000000002	Сахалинская область, Ногликский район, п. Ноглики, ул. Советская, д.41, здание СОШ №2		0101000020E6100000354415FE8CE461401348895DDBE54940
85386	4	40	1511	18843	45752	\N	51.795757000000002	Сахалинская область, Ногликский район, п. Ноглики, ул.Пограничная, д.11А, Районный Центр Досуга		0101000020E6100000354415FE8CE461401348895DDBE54940
85384	4	40	1511	18843	45768	\N	51.795757000000002	"Сахалинская область, Ногликский район, п. Ноглики, ул. Мостовая, д.8, НГУП ""Дорожник"""		0101000020E6100000354415FE8CE461401348895DDBE54940
85389	4	40	1511	19158	45927	\N	51.708461	Сахалинская область, Ногликский район, с. Катангли, ул. Советская, д.9, здание СОШ		0101000020E61000006BF294D574E76140E8BE9CD9AEDA4940
85360	4	40	1511	17691	\N	\N	52.043247000000001	Сахалинская область, Курильский район, село Горячие Ключи, Средняя общеобразовательная школа с. Горячие Ключи		0101000020E6100000193BE125B8E261403753211E89054A40
85382	4	40	1511	55624	45834	\N	52.342917	Сахалинская область, Ногликский район, с. Вал, ул.Комсомольская, д.2, здание СОШ с.Вал		0101000020E6100000D388997D1EE26140081F4AB4E42B4A40
85370	4	40	1534	55634	45919	\N	46.749703498993398	Сахалинская область, Невельский район, Невельское городское поселение, c.Ясноморское, ул. Заречная, 35 (местная администрация)	Россия, Сахалинская область, Невельский район, село Ясноморский	0101000020E6100000529B38B9DFBC6140465B9544F65F4740
85380	4	40	1534	18692	45892	\N	46.4300231137479	Сахалинская область, Невельский район, Шебунинское сельское поселение, с.Шебунино, ул. Дачная, 4А (местная администрация)	Россия, Сахалинская область, Невельский район, село Шебунино	0101000020E610000069A9BC1D61BB61408FC360FE0A374740
85372	4	40	1534	18212	45782	\N	46.679662	Сахалинская область, Невельский район, Невельское городское поселение, г.Невельск, ул. Школьная, 42 (СОШ №2)		0101000020E61000004F05DCF37CBB6140BF2A172AFF564740
85381	4	40	1534	18212	45766	\N	46.679662	"Сахалинская область, Невельский район, Невельское городское поселение, г.Невельск, ул. Приморская, 53 (ООО ""Невельское АТП"")"		0101000020E61000004F05DCF37CBB6140BF2A172AFF564740
85371	4	40	1534	18212	45761	\N	46.675290364984001	Сахалинская область, Невельский район, Невельское городское поселение, г.Невельск, ул. Победы, 2 (библиотека)	Россия, Сахалинская область, Невельский район, Невельск	0101000020E61000003BC780EC75BB61406DA818E76F564740
85373	4	40	1534	18212	45765	\N	46.679662	Сахалинская область, Невельский район, Невельское городское поселение, г.Невельск, ул. Ленина, 56А (ДК им.Невельского)		0101000020E61000004F05DCF37CBB6140BF2A172AFF564740
85374	4	40	1534	18212	45734	\N	46.679662	Сахалинская область, Невельский район, Невельское городское поселение, г.Невельск, ул. Гоголя, 5 (СОШ №3)		0101000020E61000004F05DCF37CBB6140BF2A172AFF564740
85375	4	40	1534	18463	45956	\N	46.650243000000003	Сахалинская область, Невельский район, Невельское городское поселение, с.Колхозное, ул. Гагарина, 35 (ДК с.Колхозное)		0101000020E6100000075C57CC08BD6140FAB9A1293B534740
85379	4	40	1534	55621	45774	\N	46.564490449039198	Сахалинская область, Невельский район, Горнозаводское сельское поселение, с.Горнозаводское, ул. Советская, 7 (Лицей №5)		0101000020E6100000DA74047033BB6140A375543541484740
85377	4	40	1534	55621	45774	\N	46.559754254346302	"Сахалинская область, Невельский район, Горнозаводское сельское поселение, с.Горнозаводское, ул. Советская, 33 (ДК ""Шахтер"")"	Россия, Сахалинская область, Невельский район, село Горнозаводск	0101000020E61000003BC8EBC124BB614010E7E104A6474740
85376	4	40	1534	55621	45837	\N	46.563661645003798	Сахалинская область, Невельский район, Горнозаводское сельское поселение, с.Горнозаводское, ул. Клубная, 10 (СОШ с.Горнозаводска)	Россия, Сахалинская область, Невельский район, село Горнозаводск	0101000020E61000005114E813F9BA6140BDFF8F1326484740
85363	4	40	1516	17857	45954	\N	48.570242	Сахалинская область, Макаровский район, село Поречье, Школьная, 8 (сельский Дом культуры)		0101000020E610000044696FF005D861401F679AB0FD484840
85367	4	40	1516	55631	45906	\N	48.885824573872199	Сахалинская область, Макаровский район, село Новое, Центральная, 22 (Дом культуры)	Россия, Сахалинская область, Макаровский район, село Новое	0101000020E6100000BBB7223141DE6140567DAEB662714840
85365	4	40	1516	17867	45728	\N	48.621575999999997	Сахалинская область, Макаровский район, город Макаров, 50 лет Октября, 32 (администрация МО)		0101000020E61000008E91EC11EAD861403FFD67CD8F4F4840
85364	4	40	1516	17867	45728	\N	48.621575999999997	"Сахалинская область, Макаровский район, город Макаров, 50 лет Октября, 9 ""А"" (Центральная библиотека)"		0101000020E61000008E91EC11EAD861403FFD67CD8F4F4840
85361	4	40	1516	18070	\N	\N	48.753084879393498	Сахалинская область, Курильский район, село Горный, Средняя общеобразовательная школа с. Буревестник	Россия, Сахалинская область, Макаровский район, село Горное	0101000020E610000039B5334CEDD96140D80DDB1665604840
85368	4	40	1516	18070	45948	\N	48.752572867747602	Сахалинская область, Макаровский район, село Горное, Шахтерская, 51 (библиотека)	Россия, Сахалинская область, Макаровский район, село Горное	0101000020E61000009AD18F86D3D96140226DE34F54604840
85362	4	40	1516	55633	45915	\N	48.278034938070803	Сахалинская область, Макаровский район, село Восточное, Привокзальная, 8 (школа)	Россия, Сахалинская область, Макаровский район, село Восточный	0101000020E61000003C1570CFF3D361405A12A0A696234840
85358	4	40	7533	61550	79372	\N	45.256134566942897	Сахалинская область, Курильский район, село Рейдово, ул. Мира, д.7, сельский Дом культуры	Россия, остров Итуруп	0101000020E6100000FFCBB56881806240342E1C08C9A04640
85336	4	40	1440	16479	45864	\N	46.7837282671954	Сахалинская область, Корсаковский район, с. Чапаево, Школьная, 18, здание школы с. Чапаево	Россия, Сахалинская область, Корсаковский район, село Чапаево	0101000020E6100000D49CBCC804DE6140D17AF83251644740
85340	4	40	1440	16671	\N	\N	46.697558000000001	Сахалинская область, Корсаковский район, с. Третья Падь, здание клуба	Россия, Сахалинская область, Корсаковский район, село Третья Падь	0101000020E6100000185E49F2DCD7614016889E9449594740
85339	4	40	1440	16669	45866	\N	46.7286	Сахалинская область, Корсаковский район, с. Соловьевка, Центральная, 24, здание клуба		0101000020E61000007D3ECA880BD86140CCEEC9C3425D4740
85337	4	40	1440	16560	45955	\N	46.649042999999999	Сахалинская область, Корсаковский район, с. Раздольное, Школьная, 1, здание школы с. Раздольное		0101000020E610000093718C640FDA61404F594DD713534740
85332	4	40	1440	55644	45964	\N	46.608264351458402	Сахалинская область, Корсаковский район, с. Пихтовое, Крутая, 3, здание клуба		0101000020E6100000C879FF1FA7EA6140C5AA4198DB4D4740
85334	4	40	1440	16361	45926	\N	46.859214999999999	Сахалинская область, Корсаковский район, с. Охотское, Центральная, 14, здание начальной школы		0101000020E6100000857AFA08FCE46140C79DD2C1FA6D4740
85333	4	40	1440	55619	45760	\N	46.610173694302901	Сахалинская область, Корсаковский район, с.Озерское, Центральная, 57в, здание школы с. Озерское	Россия, Сахалинская область, Корсаковский район, село Озерский	0101000020E610000077BF0AF0DDE361404C6F7F2E1A4E4740
85331	4	40	1440	16254	45862	\N	46.365169379704398	Сахалинская область, Корсаковский район, с. Новиково, Советская, 32, здание Новиковского управления	Россия, Сахалинская область, Корсаковский район, село Новиково	0101000020E6100000B7EC10FFB0EB6140AB4198DBBD2E4740
85335	4	40	1440	16418	45947	\N	46.907108999999998	Сахалинская область, Корсаковский район, с. Лесное, Морская, 39, здание клуба		0101000020E61000000A80F10C9AE261402174D0251C744740
85352	4	40	1440	16799	45759	\N	46.632269000000001	Сахалинская область, г. Корсаковс, Советская, 14, здание Детской школы искусств		0101000020E61000006F641EF903D9614027A3CA30EE504740
85344	4	40	1440	16799	45925	\N	46.632269000000001	Сахалинская область, г. Корсаков, Портовая, 10, здание морского вокзала		0101000020E61000006F641EF903D9614027A3CA30EE504740
85351	4	40	1440	16799	45815	\N	46.632269000000001	Сахалинская область, г. Корсаков, Подгорная, 41, здание школы № 6		0101000020E61000006F641EF903D9614027A3CA30EE504740
85355	4	40	1440	16799	45816	\N	46.632269000000001	Сахалинская область, г. Корсаков, Первомайская, 40а, здание д/сада № 28	Россия, Сахалинская область, Корсаковский район, Корсаков	0101000020E61000006F641EF903D9614027A3CA30EE504740
85346	4	40	1440	16799	45813	\N	46.632269000000001	Сахалинская область, г. Корсаков, Окружная, 49, здание автокомбината		0101000020E61000006F641EF903D9614027A3CA30EE504740
85343	4	40	1440	16799	45813	\N	46.632269000000001	Сахалинская область, г. Корсаков, Окружная, 118а, здание школы № 3		0101000020E61000006F641EF903D9614027A3CA30EE504740
85347	4	40	1440	16799	45814	\N	46.632269000000001	Сахалинская область, г. Корсаков, Невельская, 11, здание школы № 4		0101000020E61000006F641EF903D9614027A3CA30EE504740
85357	4	40	1440	16799	45726	\N	46.632269000000001	Сахалинская область, г. Корсаков, Морская, 12, здание школы № 2		0101000020E61000006F641EF903D9614027A3CA30EE504740
85349	4	40	1440	16799	45725	\N	46.632269000000001	"Сахалинская область, г. Корсаков, пер. Молодежный, 7, здание КДЦ ""Океан"""		0101000020E61000006F641EF903D9614027A3CA30EE504740
85354	4	40	1440	16799	45758	\N	46.632269000000001	Сахалинская область, г. Корсаков, Корсаковская, 16, здание Дома детства и юношества		0101000020E61000006F641EF903D9614027A3CA30EE504740
85348	4	40	1440	16799	45858	\N	46.632269000000001	Сахалинская область, г. Корсаков, Зеленая, 7/1, здание д/сада № 8		0101000020E61000006F641EF903D9614027A3CA30EE504740
85342	4	40	1440	16799	45867	\N	46.632269000000001	"Сахалинская область, г. Корсаков, Железнодорожная, 1, здание д/сада № 3 ""Ромашка"""		0101000020E61000006F641EF903D9614027A3CA30EE504740
85338	4	40	1440	16568	\N	\N	46.761710999999998	Сахалинская область, Корсаковский район, с. Дачное, здание школы с. Дачное	Россия, Сахалинская область, Корсаковский район, село Дачное	0101000020E61000005CCCCF0DCDD761407100FDBE7F614740
85341	4	40	1440	55639	\N	\N	46.6817339853433	Сахалинская область, Корсаковский район, с. Первая Падь, здание библиотеки	Россия, Сахалинская область, Корсаковский район, село Вторая Падь	0101000020E6100000F33977BBDED761401F49490F43574740
85328	4	40	1394	16061	45832	\N	47.316325999999997	Сахалинская область, Долинский район, с.Углезаводск, ул.Ленина, 16, помещение Дома культуры		0101000020E61000000D71AC8BDBD36140EF6FD05E7DA84740
85315	4	40	1394	15493	45749	\N	47.410119999999999	Сахалинская область, Долинский район, с.Стародубское, Набережная, 19а, помещение школы		0101000020E6100000B550323935DA6140BFB7E9CF7EB44740
85326	4	40	1394	15819	45833	\N	47.253917000000001	Сахалинская область, Долинский район, с.Сокол, ул.Совхозная, 26, помещение амбулатории		0101000020E6100000CCB4FD2B2BD8614000732D5A80A04740
85324	4	40	1394	15819	45804	\N	47.253917000000001	Сахалинская область, Долинский район, с.Сокол, ул.Лесная, 45, помещение школы		0101000020E6100000CCB4FD2B2BD8614000732D5A80A04740
85314	4	40	1394	15393	45898	\N	47.495088000000003	Сахалинская область, Долинский район, с.Советское, Центральная, 127, СОШ с.Советское		0101000020E61000009581035A3AD561402F52280B5FBF4740
95023	4	40	1394	16053	45868	\N	47.326521	Сахалинская область, Долинский район, с.Покровка, ул.Березовая, 10, помещение школы		0101000020E610000024B4E55C8AD66140863AAC70CBA94740
85320	4	40	1394	15503	45811	\N	47.326619000000001	Сахалинская область, г.Долинск, Хабаровская, 13, помещение школы № 2		0101000020E6100000BD512B4C5FD9614049A0C1A6CEA94740
84368	4	34	\N	639	45253	\N	62.028191	Республика Саха (Якутия), город Якутск, С. Данилова, 34		0101000020E6100000A0C03BF97436604051853FC39B034F40
85319	4	40	1394	15503	45831	\N	47.326619000000001	Сахалинская область, г.Долинск, Октябрьская, 7а, помещение лыжной базы		0101000020E6100000BD512B4C5FD9614049A0C1A6CEA94740
85318	4	40	1394	15503	45756	\N	47.326619000000001	Сахалинская область, г.Долинск, Ленина, 31, помещение городской библиотеки		0101000020E6100000BD512B4C5FD9614049A0C1A6CEA94740
85317	4	40	1394	15503	45755	\N	47.326619000000001	Сахалинская область, г.Долинск, Комсомольская, 25, помещение школы № 1		0101000020E6100000BD512B4C5FD9614049A0C1A6CEA94740
85316	4	40	1394	15503	45750	\N	47.326619000000001	Сахалинская область, г.Долинск, ул.Владивостокская, 21, помещение Центра занятости		0101000020E6100000BD512B4C5FD9614049A0C1A6CEA94740
85312	4	40	1394	15297	45877	\N	47.850454999999997	Сахалинская область, Долинский район, с.Взморье, Пионерская, 15, помещение школы		0101000020E6100000AABBB20B86D061401EDC9DB5DBEC4740
85330	4	40	1394	55622	45808	\N	47.317909	Сахалинская область, Долинский район, с.Быков, ул.Шахтерская, 15, помещение школы		0101000020E610000050E09D7CFAD16140520DFB3DB1A84740
85329	4	40	1394	55622	45808	\N	47.315515879558603	Сахалинская область, Долинский район, с.Быков, ул.Шахтерская, 13, помещение музыкальной школы	Россия, Сахалинская область, Долинский район	0101000020E61000000C3D62F4DCD16140B0AE0AD462A84740
85300	4	40	1356	14739	45933	\N	46.852398999999998	Сахалинская область, Анивский район, п.Успенское, пер.Почтовый, 2 (школа)		0101000020E61000006D3997E2AAD26140511212691B6D4740
85297	4	40	1356	14624	45730	\N	46.921512999999997	Сахалинская область, Анивский район, п.Троицкое, ул.Центральная, 16а (школа)		0101000020E61000007BF65CA6A6D461405FEB5223F4754740
85606	4	40	1356	14624	45855	\N	46.921512999999997	Сахалинская область, Анивский район, п.Троицкое, Советская, 13 (сельский совет)		0101000020E61000007BF65CA6A6D461405FEB5223F4754740
85304	4	40	1356	14624	45861	\N	46.921512999999997	Сахалинская область, Анивский район, п.Троицкое, Невельская, 13 (детский сад)		0101000020E61000007BF65CA6A6D461405FEB5223F4754740
85305	4	40	1356	14968	45886	\N	46.624898999999999	Сахалинская область, Анивский район, п.Таранай, Лесная, 18 (средняя школа)		0101000020E610000077DB85E6BACD6140CC26C0B0FC4F4740
85303	4	40	1356	14912	45935	\N	46.701228999999998	Сахалинская область, Анивский район, п.Рыбацкое, Береговая, 5 (дом культуры)		0101000020E6100000A359D93EE4D06140DE0033DFC1594740
85306	4	40	1356	15023	45905	\N	46.778258999999998	Сахалинская область, Анивский район, с.Огоньки, Школьная, 18 (школа)		0101000020E6100000E10B93A982CC6140A968ACFD9D634740
85298	4	40	1356	14635	45931	\N	46.891542999999999	Сахалинская область ,Анивский район, п.Новотроицкое, Центральная, 25а (библиотека)		0101000020E6100000F0A31AF6FBD5614026FDBD141E724740
85299	4	40	1356	14677	45932	\N	46.804999000000002	Сахалинская область ,Анивский район, п.Мицулевка, Рабочая, 11 (библиотека-клуб)		0101000020E6100000B9FFC87468D7614007280D350A674740
85589	4	40	1356	55645	45966	\N	47.078868983264897	"Сахалинская область, город Южно-Сахалинск, село Ключи, ул. Советская, 22, Дом культуры ""Ключи"""	Россия, Сахалинская область, Анивский район, село Ключи	0101000020E61000008A3E1F6544D5614088D51F61188A4740
85307	4	40	1356	15093	45908	\N	46.813763000000002	Сахалинская область, Анивский район, п.Высокое, Луговая, 9 (сельский клуб)		0101000020E610000025C9737D1FCA6140F1D8CF6229684740
85301	4	40	1356	14820	45934	\N	46.747084999999998	Сахалинская область, Анивский район, с.Воскресенское, Новая, 1а (библиотека-клуб)		0101000020E6100000A08A1BB718D16140842A357BA05F4740
85607	4	40	1356	15097	45863	\N	46.711915831864196	Сахалинская область, г.Анива, Победы, 60 (школа № 2)	Россия, Сахалинская область, Анивский район	0101000020E61000007BFA08FC61D16140E4BF4010205B4740
85309	4	40	1356	15097	45748	\N	46.716875000000002	Сахалинская область, г.Анива, Ленина, 16 (школа № 1)		0101000020E6100000438D4292D9D06140F6285C8FC25B4740
85311	4	40	1356	15097	45922	\N	46.716875000000002	Сахалинская область, г.Анива, им. Пудова, 79 (контора АТП)		0101000020E6100000438D4292D9D06140F6285C8FC25B4740
85288	4	40	1314	29759	81103	\N	50.8289117313604	ул.Бугайского,2	Россия, Сахалинская область, Александровск-Сахалинский район, село Михайловка	0101000020E61000008D614ED0A6C5614088A1D5C9196A4940
85286	4	40	1314	14068	45859	\N	51.047840999999998	Сахалинская область, Александровск-Сахалинский район, с.Мгачи, Советская, 36А, помещение администрации		0101000020E6100000BAD7497DD9C86140373465A71F864940
85285	4	40	1314	14057	45951	\N	51.097468999999997	Сахалинская область, Александровск-Сахалинский район, с.Мангидай, пер.Школьный, 1, помещение школы		0101000020E6100000F9F6AE415FC86140D9AF3BDD798C4940
85289	4	40	1314	14245	45952	\N	50.824249727319199	Сахалинская область, Александровск-Сахалинский район, с.Дуэ, Чехова, 114, помещение администрации	Россия, Сахалинская область, Александровск-Сахалинский район, село Дуэ	0101000020E6100000637D03939BC361402FDD240681694940
85287	4	40	1314	14113	45950	\N	50.944012303365497	Сахалинская область, Александровск-Сахалинский район, с.Арково, Советская, 16, помещение администрации	Россия, Сахалинская область, Александровск-Сахалинский район, село Арково	0101000020E6100000A01518B2BAC861400A849D62D5784940
85294	4	40	1314	14250	9813	\N	50.902852000000003	"Сахалинская область, г.Александровск- Сахалинский, Советская, 1, помещение ЦДТ ""Радуга"""		0101000020E61000006A32E36D25C56140699082A790734940
85292	4	40	1314	14250	9813	\N	50.895690422485998	Сахалинская область, г.Александровск- Сахалинский, Советская, 58, помещение колледжа	Россия, Сахалинская область, Александровск-Сахалинский район, Александровск-Сахалинский	0101000020E6100000255B5D4E09C5614058AD4CF8A5724940
85295	4	40	1314	14250	45830	\N	50.902852000000003	Сахалинская область, г.Александровск- Сахалинский, Кирова, 44А, помещение техшколы РОСТО		0101000020E61000006A32E36D25C56140699082A790734940
84361	4	34	\N	639	45436	\N	62.028191	Республика Саха (Якутия), город Якутск, Рыдзинского, 5		0101000020E6100000A0C03BF97436604051853FC39B034F40
85293	4	40	1314	14250	45807	\N	50.902852000000003	Сахалинская область, г.Александровск- Сахалинский, Дальневосточная, 3, помещение СОШ № 2		0101000020E61000006A32E36D25C56140699082A790734940
85290	4	40	1314	14250	45930	\N	50.902852000000003	Сахалинская область, г. Александровск- Сахалинский, Аболтина, 19, помещение соц.-реабилит. центра		0101000020E61000006A32E36D25C56140699082A790734940
84675	4	34	\N	61702	79585	\N	68.2213340007699	Республика Саха (Якутия), Верхоянский район, Черюмчинский наслег с.Черюмча, Центральная, 2/2		0101000020E61000006688635D5CDF60408BDF14562A0E5140
85118	4	34	\N	55508	45565	\N	62.814292493666798	Республика Саха (Якутия), Усть-Алданский район, Легёйский 2-й наслег, с.Тулуна, Братья Габышевых, 18	Россия	0101000020E6100000A20A7F86376260407DB262B83A684F40
85083	4	34	\N	61646	\N	\N	63.029488999999998	Республика Саха (Якутия), Томпонский район, Теплоключевский наслег, с.Развилка, нет		0101000020E6100000EBE40CC51D456140BE4BA94BC6834F40
84575	4	34	\N	61795	79689	\N	69.933994503312604	Республика Саха (Якутия), Аллаиховский район, Быянгнырский наслег с.Нычалах, Центральная, 6	Россия	0101000020E61000000B7A6F0C8145624029E8F692C67B5140
85055	4	34	\N	61699	79578	\N	62.219816675479102	Республика Саха (Якутия), Сунтарский район, Нахаринский наслег, с.Нахара, Павлова, 18	Россия	0101000020E610000000AE64C746175D406B0DA5F6221C4F40
84637	4	34	\N	61719	79599	\N	64.131876173721494	Республика Саха (Якутия), Верхневилюйский район, Ботулунский наслег, с.Ботулу, Центральная, 17/1	Россия	0101000020E6100000A14CA3C9C5F15D4026C808A870085040
84950	4	34	\N	61763	79646	\N	63.7415987690175	Республика Саха (Якутия), Нюрбинский район, Чукарский наслег, с. Чукар, Лесная, 18	Россия	0101000020E610000089450C3B8C7E5D4087DF4DB7ECDE4F40
85057	4	34	\N	61706	79586	\N	63.262137978112598	Республика Саха (Якутия), Таттинский район, Хара-Алданский наслег, с. Хара-Алдан, Новая, 20	Россия	0101000020E61000004B3D0B4279A66040F984ECBC8DA14F40
84688	4	34	\N	61643	79518	\N	63.7335457349308	Республика Саха (Якутия), Вилюйский район, с. Хампа, Героя Кондакова, 13	Россия	0101000020E61000003D2B69C537BB5E40490ED8D5E4DD4F40
84754	4	34	\N	61605	79473	\N	61.816404476582797	Республика Саха (Якутия), Ленский район, Толонский наслег, с. Толон, Терешкина Н.Д, 28	Россия	0101000020E61000000002D6AA5D865C406B2920ED7FE84E40
85099	4	34	\N	61655	79531	\N	62.468510100000003	Республика Саха (Якутия), Усть-Алданский район, Курбусахский наслег, с. Окоемовка, Окоемова, 15	Россия	0101000020E61000004C8BFA24F76A6040ABECBB22F83B4F40
84811	4	34	\N	61348	78673	\N	62.157862247631201	Республика Саха (Якутия), Мегино-Кангаласский район, Жабыльский наслег, с. Норгана, Петрова, 14/1	Россия	0101000020E6100000158C4AEA84626040FDA36FD234144F40
85096	4	34	\N	61693	79575	\N	62.630410686436903	Республика Саха (Якутия), Усть-Алданский район, Хоринский наслег, с. Маягас, Петра Алексеева, 33/1		0101000020E6100000E7C589AF76646040F304C24EB1504F40
84738	4	34	\N	61704	79583	\N	63.562168741996501	Республика Саха (Якутия), Кобяйский район, Кобяйский наслег, с. Кобяй, Егорова, 12	Россия	0101000020E6100000FC7266BB42A05F409AE95E27F5C74F40
84734	4	34	\N	61739	79620	\N	63.9386169	Республика Саха (Якутия), Кобяйский район, Куокуйский наслег, с. Кальвица, Рыбацкая, 31	Россия	0101000020E6100000766F456282C15F401D3C139A24F84F40
84801	4	34	\N	61742	79622	\N	61.707809304993603	Республика Саха (Якутия), Мегино-Кангаласский район, Алтанский наслег, с. Елечей, Чапаева, 20	Россия	0101000020E6100000137D3ECA0868604040683D7C99DA4E40
85280	4	34	\N	55424	\N	\N	59.266015000000003	Республика Саха (Якутия), Нюрбинский район, Бордонский наслег, вахтовый пос. Накын, Модуль Е		0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
84600	4	34	\N	55443	45465	\N	71.628415708739098	Республика Саха (Якутия), Булунский район, п. Тикси, Ленинская, 13 А	море Лаптевых	0101000020E610000064CC5D4B481C60401F12BEF737E85140
85279	4	34	\N	639	\N	\N	62.028191	Республика Саха (Якутия), город Якутск, Сергеляхское шоссе, 10 км	Россия, Республика Саха (Якутия), Якутск	0101000020E6100000A0C03BF97436604051853FC39B034F40
83709	4	34	\N	639	45165	\N	62.028191	Республика Саха (Якутия), город Якутск, Ярославского, 21		0101000020E6100000A0C03BF97436604051853FC39B034F40
83127	4	34	\N	639	45165	\N	62.028191	Республика Саха (Якутия), город Якутск, Ярославского, 27		0101000020E6100000A0C03BF97436604051853FC39B034F40
85225	4	34	\N	639	45291	\N	62.028191	Республика Саха (Якутия), город Якутск, Я.Потапова, 4		0101000020E6100000A0C03BF97436604051853FC39B034F40
85226	4	34	\N	639	45244	\N	62.028191	Республика Саха (Якутия), город Якутск, Я. Потапова, 4		0101000020E6100000A0C03BF97436604051853FC39B034F40
85240	4	34	\N	639	45293	\N	62.028191	Республика Саха (Якутия), город Якутск, Энергетиков переулок, 2А		0101000020E6100000A0C03BF97436604051853FC39B034F40
83810	4	34	\N	639	45245	\N	62.028191	Республика Саха (Якутия), город Якутск, Шавкунова, 63		0101000020E6100000A0C03BF97436604051853FC39B034F40
85232	4	34	\N	639	45217	\N	62.028191	Республика Саха (Якутия), город Якутск, Чайковского, 2		0101000020E6100000A0C03BF97436604051853FC39B034F40
85231	4	34	\N	639	45217	\N	62.028191	Республика Саха (Якутия), город Якутск, Чайковского, 30		0101000020E6100000A0C03BF97436604051853FC39B034F40
85229	4	34	\N	639	45217	\N	62.028191	Республика Саха (Якутия), город Якутск, Чайковского, 32/1		0101000020E6100000A0C03BF97436604051853FC39B034F40
85228	4	34	\N	639	45217	\N	62.022626694462502	Республика Саха (Якутия), город Якутск, Чайковского, 13	Россия, Республика Саха (Якутия), Якутск	0101000020E61000009607E92972366040D8800871E5024F40
84235	4	34	\N	639	45288	\N	62.028191	Республика Саха (Якутия), город Якутск, Халтурина, 4/1		0101000020E6100000A0C03BF97436604051853FC39B034F40
85241	4	34	\N	639	45296	\N	62.002376941688198	Республика Саха (Якутия), город Якутск, Ф. Попова, 3	Россия, Республика Саха (Якутия), Якутск	0101000020E61000007A8D5DA27A3660409DA1B8E34D004F40
85246	4	34	\N	639	45240	\N	62.016900024380803	Республика Саха (Якутия), город Якутск, Очиченко, 1/1	Россия, Республика Саха (Якутия), Якутск	0101000020E61000002EAEF1996C356040B5A679C729024F40
82760	4	34	\N	639	45313	\N	62.028191	Республика Саха (Якутия), город Якутск, Островского, 1		0101000020E6100000A0C03BF97436604051853FC39B034F40
85141	4	34	\N	639	45334	\N	62.028191	Республика Саха (Якутия), город Якутск, Ойунского, 24		0101000020E6100000A0C03BF97436604051853FC39B034F40
85258	4	34	\N	639	45222	\N	62.028191	Республика Саха (Якутия), город Якутск, мкрн. Марха, О. Кошевого, 67		0101000020E6100000A0C03BF97436604051853FC39B034F40
84947	4	34	\N	639	79428	\N	62.348118999999997	Республика Саха (Якутия), Нюрбинский район, Кангаласский наслег, с. Кангаласс, Молодежная, 11		0101000020E61000001B9DF3531C3F6040E00ED4298F2C4F40
85278	4	34	\N	639	45249	\N	62.028191014621399	Республика Саха (Якутия), город Якутск, Можайского, 15/4	Россия, Республика Саха (Якутия), Якутск	0101000020E610000083177D056936604051853FC39B034F40
85249	4	34	\N	639	45249	\N	62.028191	Республика Саха (Якутия), город Якутск, Можайского, 25		0101000020E6100000A0C03BF97436604051853FC39B034F40
81629	4	34	\N	639	45249	\N	62.028191	Республика Саха (Якутия), город Якутск, Можайского, 23		0101000020E6100000A0C03BF97436604051853FC39B034F40
85227	4	34	\N	639	45237	\N	62.028191	Республика Саха (Якутия), город Якутск, Маяковского, 79		0101000020E6100000A0C03BF97436604051853FC39B034F40
85256	4	34	\N	639	45221	\N	62.028191	Республика Саха (Якутия), город Якутск, мкрн. Марха, Маганский тракт, 2 км		0101000020E6100000A0C03BF97436604051853FC39B034F40
85222	4	34	\N	639	45247	\N	62.028191	Республика Саха (Якутия), город Якутск, Л. Чайкиной, 2а		0101000020E6100000A0C03BF97436604051853FC39B034F40
81911	4	34	\N	639	45310	\N	62.028191	Республика Саха (Якутия), город Якутск, Лермонтова, 40		0101000020E6100000A0C03BF97436604051853FC39B034F40
85266	4	34	\N	639	45180	\N	62.028191	Республика Саха (Якутия), город Якутск, мкрн. Кангалассы, Ленина, 5	Россия, Республика Саха (Якутия), Якутск	0101000020E6100000A0C03BF97436604051853FC39B034F40
85224	4	34	\N	639	45180	\N	62.028191	Республика Саха (Якутия), город Якутск, Ленина, 50		0101000020E6100000A0C03BF97436604051853FC39B034F40
85223	4	34	\N	639	45180	\N	62.028191	Республика Саха (Якутия), город Якутск, Ленина, 43		0101000020E6100000A0C03BF97436604051853FC39B034F40
84852	4	34	\N	639	45180	\N	62.028191	Республика Саха (Якутия), город Якутск, Ленина, 2		0101000020E6100000A0C03BF97436604051853FC39B034F40
83972	4	34	\N	639	45180	\N	62.021739534623002	Республика Саха (Якутия), город Якутск, Ленина, 5	Россия, Республика Саха (Якутия), Якутск	0101000020E6100000D0251C7A8B366040ED815660C8024F40
83775	4	34	\N	639	45180	\N	62.028191	Республика Саха (Якутия), город Якутск, Ленина, 16		0101000020E6100000A0C03BF97436604051853FC39B034F40
82745	4	34	\N	639	45180	\N	62.028191	Республика Саха (Якутия), город Якутск, Ленина, 40		0101000020E6100000A0C03BF97436604051853FC39B034F40
85269	4	34	\N	639	45250	\N	62.028191	Республика Саха (Якутия), город Якутск, Кулаковского, 48		0101000020E6100000A0C03BF97436604051853FC39B034F40
82671	4	34	\N	639	45250	\N	62.028191	Республика Саха (Якутия), город Якутск, Кулаковского, 6/2		0101000020E6100000A0C03BF97436604051853FC39B034F40
82658	4	34	\N	639	45250	\N	62.028191	Республика Саха (Якутия), город Якутск, Кулаковского, 36	Россия, Республика Саха (Якутия), Якутск	0101000020E6100000A0C03BF97436604051853FC39B034F40
85248	4	34	\N	639	45218	\N	62.037220782370198	Республика Саха (Якутия), город Якутск, Кузьмина, 15/3	Россия, Республика Саха (Якутия), Якутск	0101000020E6100000B0389CF955376040BADC60A8C3044F40
85221	4	34	\N	639	45290	\N	62.028191	Республика Саха (Якутия), город Якутск, Красильникова, 15		0101000020E6100000A0C03BF97436604051853FC39B034F40
85276	4	34	\N	639	45164	\N	62.028191	Республика Саха (Якутия), город Якутск, Кирова, 20		0101000020E6100000A0C03BF97436604051853FC39B034F40
82869	4	34	\N	639	45164	\N	62.028191	Республика Саха (Якутия), город Якутск, Кирова, 23		0101000020E6100000A0C03BF97436604051853FC39B034F40
82828	4	34	\N	639	45164	\N	62.028191	Республика Саха (Якутия), город Якутск, Кирова, 25		0101000020E6100000A0C03BF97436604051853FC39B034F40
85242	4	34	\N	639	45241	\N	62.028191	Республика Саха (Якутия), город Якутск, Кальвица, 14/1		0101000020E6100000A0C03BF97436604051853FC39B034F40
85238	4	34	\N	639	45241	\N	62.028191	Республика Саха (Якутия), город Якутск, Кальвица, 5		0101000020E6100000A0C03BF97436604051853FC39B034F40
84247	4	34	\N	639	45241	\N	62.028191	Республика Саха (Якутия), город Якутск, Кальвица, 24		0101000020E6100000A0C03BF97436604051853FC39B034F40
85272	4	34	\N	639	45224	\N	62.028191	Республика Саха (Якутия), город Якутск, Каландаришвили, 17		0101000020E6100000A0C03BF97436604051853FC39B034F40
85271	4	34	\N	639	45224	\N	62.028191	Республика Саха (Якутия), город Якутск, Каландаришвили, 31		0101000020E6100000A0C03BF97436604051853FC39B034F40
85104	4	34	\N	639	45224	\N	62.028191	Республика Саха (Якутия), город Якутск, Каландаришвили, 34		0101000020E6100000A0C03BF97436604051853FC39B034F40
85251	4	34	\N	639	45198	\N	62.028191	Республика Саха (Якутия), город Якутск, с. Табага, Кааландаришвили, 10		0101000020E6100000A0C03BF97436604051853FC39B034F40
85257	4	34	\N	639	45307	\N	62.1006757809768	Республика Саха (Якутия), город Якутск, мкрн. Марха, Заводская, 10		0101000020E61000009241EE22CC376040FDBE7FF3E20C4F40
81730	4	34	\N	639	45270	\N	62.028191	Республика Саха (Якутия), город Якутск, Жуковского, 5		0101000020E6100000A0C03BF97436604051853FC39B034F40
84482	4	34	\N	639	45316	\N	62.028191	Республика Саха (Якутия), город Якутск, Жорницкого, 7/11А		0101000020E6100000A0C03BF97436604051853FC39B034F40
84383	4	34	\N	639	45316	\N	62.028191	Республика Саха (Якутия), город Якутск, Жорницкого, 13		0101000020E6100000A0C03BF97436604051853FC39B034F40
85237	4	34	\N	639	45174	\N	62.028191	Республика Саха (Якутия), город Якутск, Дзержинского, 38		0101000020E6100000A0C03BF97436604051853FC39B034F40
33341	4	41	1601	49474	46287	\N	48.613827000000001	с. Песчаное, ул. 40 лет Победы, д. 2		0101000020E6100000C7D45DD985BB60406E3315E2914E4840
84504	4	34	\N	639	45174	\N	62.037543303082998	Республика Саха (Якутия), город Якутск, Дзержинского, 55	Россия, Республика Саха (Якутия), Якутск	0101000020E6100000FF4124438E376040CC988235CE044F40
84258	4	34	\N	639	45174	\N	62.028191	Республика Саха (Якутия), город Якутск, Дзержинского, 43		0101000020E6100000A0C03BF97436604051853FC39B034F40
84190	4	34	\N	639	45174	\N	62.028191	Республика Саха (Якутия), город Якутск, Дзержинского, 17		0101000020E6100000A0C03BF97436604051853FC39B034F40
84149	4	34	\N	639	45174	\N	62.028191	Республика Саха (Якутия), город Якутск, Дзержинского, 5		0101000020E6100000A0C03BF97436604051853FC39B034F40
84002	4	34	\N	639	45174	\N	62.028191	Республика Саха (Якутия), город Якутск, Дзержинского, 2		0101000020E6100000A0C03BF97436604051853FC39B034F40
85255	4	34	\N	639	45213	\N	62.015932108503698	Республика Саха (Якутия), город Якутск, мкрн. Марха, Газовиков, 19	Россия, Республика Саха (Якутия), Якутск	0101000020E61000007CB779E3A4356040DD7A4D0F0A024F40
81335	4	34	\N	639	45269	\N	62.028191	Республика Саха (Якутия), город Якутск, Богатырева, 21		0101000020E6100000A0C03BF97436604051853FC39B034F40
85275	4	34	\N	639	45215	\N	62.028191	Республика Саха (Якутия), город Якутск, Билибина, 6		0101000020E6100000A0C03BF97436604051853FC39B034F40
85230	4	34	\N	639	45215	\N	62.028191	Республика Саха (Якутия), город Якутск, Билибина, 14		0101000020E6100000A0C03BF97436604051853FC39B034F40
85243	4	34	\N	639	9945	\N	62.028191	Республика Саха (Якутия), город Якутск, Бестужева-Марлинского, 23/1		0101000020E6100000A0C03BF97436604051853FC39B034F40
85239	4	34	\N	639	9945	\N	62.028191	Республика Саха (Якутия), город Якутск, Бестужева-Марлинского, 24		0101000020E6100000A0C03BF97436604051853FC39B034F40
85236	4	34	\N	639	9945	\N	62.028191	Республика Саха (Якутия), город Якутск, Бестужева-Марлинского, 5		0101000020E6100000A0C03BF97436604051853FC39B034F40
85204	4	34	\N	639	45337	\N	62.028191	Республика Саха (Якутия), город Якутск, Белинского, 58		0101000020E6100000A0C03BF97436604051853FC39B034F40
85274	4	34	\N	639	45252	\N	62.028191	Республика Саха (Якутия), город Якутск, Бекетова, 6		0101000020E6100000A0C03BF97436604051853FC39B034F40
85267	4	34	\N	639	45214	\N	62.028191	Республика Саха (Якутия), город Якутск, Автодорожная, 40/4		0101000020E6100000A0C03BF97436604051853FC39B034F40
85220	4	34	\N	639	45214	\N	62.030368158274101	Республика Саха (Якутия), город Якутск, Автодорожная, 36	Россия, Республика Саха (Якутия), Якутск	0101000020E61000008B4E965AEF366040276C3F19E3034F40
85247	4	34	\N	639	45242	\N	62.028191	Республика Саха (Якутия), город Якутск, 50 лет Советской Армии, 35/1		0101000020E6100000A0C03BF97436604051853FC39B034F40
85245	4	34	\N	639	45242	\N	62.028191	Республика Саха (Якутия), город Якутск, 50 лет Советской Армии, 86\\1		0101000020E6100000A0C03BF97436604051853FC39B034F40
85244	4	34	\N	639	45242	\N	62.028191	Республика Саха (Якутия), город Якутск, 50 лет Советской Армии, 47		0101000020E6100000A0C03BF97436604051853FC39B034F40
85234	4	34	\N	639	45338	\N	62.028191	Республика Саха (Якутия), город Якутск, 202 микрорайон, 21		0101000020E6100000A0C03BF97436604051853FC39B034F40
85199	4	34	\N	55602	45705	\N	61.812422854844201	Республика Саха (Якутия), Чурапчинский район, Ожулунский наслег, с. Юрях-Кюеря, Юрях-Кюеринская, 27	Россия	0101000020E6100000A6D6FB8D768A604055C2137AFDE74E40
84595	4	34	\N	55496	45549	\N	72.812461689915693	Республика Саха (Якутия), Анабарский район, Юрюнг-Хаинский национальный наслег, Алроса, 7	Россия	0101000020E6100000CEFBFF3861505C4089CF9D60FF335240
84592	4	34	\N	54265	35830	\N	61.375331929626803	Республика Саха (Якутия), Амгинский район, Эмисский наслег, К. Урастырова, 49	Россия	0101000020E6100000524832ABF7656040369204E10AB04E40
85014	4	34	\N	61866	79798	\N	66.038526000000005	Республика Саха (Якутия), Оленекский район, Шологонский наслег, с.Эйик, Центральная, 15	Россия	0101000020E6100000DD5ED218AD595D40ED82C13577825040
85072	4	34	\N	55346	45219	\N	62.370013287269103	Республика Саха (Якутия), Таттинский район, Таттинский наслег, с. Ытык-Кюель, Пекарского, 28	Россия	0101000020E610000071E481C8A2B16040240C03965C2F4F40
85070	4	34	\N	55346	45207	\N	62.367143048258001	Республика Саха (Якутия), Таттинский район, Таттинский наслег, с.Ытык-Кюель, Ойунского, 1	Россия	0101000020E6100000C05FCC96ACB1604048FAB48AFE2E4F40
85028	4	34	\N	55503	45561	\N	62.858800350931403	Республика Саха (Якутия), Сунтарский район, Шеинский наслег, с.Шея, Советская, 25	Россия	0101000020E61000006DE690D442635D4004E78C28ED6D4F40
85067	4	34	\N	61737	79618	\N	62.099606999999999	Республика Саха (Якутия), Таттинский район, Амгинский наслег, с. Чычымах, Школьная, 4/1	Россия	0101000020E61000000C1EA67DF3C96040F1B913ECBF0C4F40
85069	4	34	\N	55597	45697	\N	62.256600038576302	Республика Саха (Якутия), Таттинский район, Усть-Амгинский наслег, с. Чымнай, Самырова, 64	Россия	0101000020E61000005C74B2D4FAD06040A913D044D8204F40
84918	4	34	\N	55476	45523	\N	68.752337800702406	Республика Саха (Якутия), Нижнеколымский район, Поселок Черский, Молодежная, 38	Россия	0101000020E6100000F56915FD212B64406F62484E26305140
85033	4	34	\N	55560	45722	\N	62.547166305313901	Республика Саха (Якутия), Сунтарский район, Хоринский наслег, с.Хоро, Сатыс, 47	Россия	0101000020E6100000F33CB83B6B725D40D7BD158909464F40
84628	4	34	\N	55560	45635	\N	62.548313972254299	Республика Саха (Якутия), Верхневилюйский район, Хоринский наслег, с.Хоро, Булгунняхтах, 3	Россия	0101000020E6100000B08C0DDDEC735D402FF834272F464F40
84856	4	34	\N	55403	45386	\N	66.451233586459693	Республика Саха (Якутия), Момский район, Момский национальный наслег, с. Хонуу, Спортивная, 1/3	Россия	0101000020E610000069E047356CE76140F8359204E19C5040
84869	4	34	\N	55573	45659	\N	62.849939253861699	Республика Саха (Якутия), Намский район, Салбанский наслег,с.Хонгор-Бие, Ларионова, 16	Россия	0101000020E61000006DA983BC9E106040274C18CDCA6C4F40
84606	4	34	\N	61682	79559	\N	70.910046821112402	Республика Саха (Якутия), Булунский район, с. Хара-Улах, Колесова, 12	море Лаптевых	0101000020E6100000A4552DE9A85A6040ABB4C5353EBA5140
85074	4	34	\N	55351	45220	\N	62.660491466854701	Республика Саха (Якутия), Томпонский район, Поселок Хандыга, Охлопкова, 3	Россия	0101000020E61000001FD95C354FF16040B32616F88A544F40
85076	4	34	\N	55351	45346	\N	62.657728099894904	Республика Саха (Якутия), Томпонский район, Поселок Хандыга, Магаданская, 30а	Россия	0101000020E610000059C345EE69F16040EDD45C6E30544F40
84920	4	34	\N	55582	45677	\N	68.669352000000003	Республика Саха (Якутия), Нижнеколымский район, Халарчинский наслег, Черского, 8	Россия	0101000020E6100000B42094F771DB6340C860C5A9D62A5140
85206	4	34	\N	55548	\N	\N	61.7465967659491	Республика Саха (Якутия), Чурапчинский район, Хадарский наслег, с. Орга, нет улиц, нет	Россия	0101000020E61000009B02999D458960405725917D90DF4E40
84855	4	34	\N	55376	\N	\N	66.406646858354193	Республика Саха (Якутия), Мирнинский район, Город Удачный, Новый Город, СОШ №19	Россия	0101000020E610000050FEEE1D35125C400F812381069A5040
84853	4	34	\N	55376	45365	\N	66.407393624943396	Республика Саха (Якутия), Мирнинский район, Город Удачный, Новый Город, Общественный центр, шахматный клуб		0101000020E610000023145B41D3125C408BA548BE129A5040
84700	4	34	\N	55598	45699	\N	63.829128830193802	Республика Саха (Якутия), Вилюйский район, с. Тымпы, Коммунаров, 3/1	Россия	0101000020E6100000213D450E11D95E40259529E620EA4F40
84739	4	34	\N	61762	79645	\N	63.687607	Республика Саха (Якутия), Кобяйский район, Тыайинский наслег, с. Тыайа, Октябрьская, 22	Россия	0101000020E610000084D90418967D5F4016C0948103D84F40
84620	4	34	\N	55574	45663	\N	61.988483142926498	Республика Саха (Якутия), Верхневилюйский район, Туобуйинский наслег, с.Тобуя, С.Платонова, 21	Россия	0101000020E6100000D0285DFA97845E4074D3669C86FE4E40
85084	4	34	\N	55497	45553	\N	64.077831169410899	Республика Саха (Якутия), Томпонский район, Томпонский наслег, с.Тополиное, Советская, 3	Россия	0101000020E6100000B8CB7EDDE9FE60405CE7DF2EFB045040
84565	4	34	\N	55448	45479	\N	58.953221469037203	Республика Саха (Якутия), Алданский район, Город Томмот, микрорайон Синегорье, Зеленая, 11	Россия, Республика Саха (Якутия), Алданский район, Томмот	0101000020E6100000FA9AE5B2D1915F40226E4E25037A4D40
85052	4	34	\N	55458	45500	\N	62.174130245447301	Республика Саха (Якутия), Сунтарский район, Тойбохойский наслег, с.Тойбохой, октябрьская, 40	Россия	0101000020E61000003F1F65C405335D4051A04FE449164F40
84972	4	34	\N	55523	45582	\N	60.359442853438097	Республика Саха (Якутия), Олекминский район, Чапаевский наслег, село Тинная, Школьная, 5	Россия	0101000020E610000091B932A8363F5D4058E36C3A022E4E40
84599	4	34	\N	55444	45478	\N	71.630797727386394	Республика Саха (Якутия), Булунский район, п. Тикси, Академика Федорова, 28 А		0101000020E6100000E868554B3A1B6040761893FE5EE85140
84601	4	34	\N	55444	45467	\N	71.624445560481306	Республика Саха (Якутия), Булунский район, п. Тикси, 50 лет СевМорПути, 8		0101000020E6100000D68BA19C681B60408E075BECF6E75140
84966	4	34	\N	55522	\N	\N	64.247689927185306	Республика Саха (Якутия), Оймяконский район, Терютский наслег, с. Терють, Школа	Россия	0101000020E61000004DD7135D97C16140F6622827DA0F5040
84701	4	34	\N	61800	79696	\N	63.766480000000001	Республика Саха (Якутия), Вилюйский район, с. Тасагар, Октябрьская, 24	Россия	0101000020E6100000D31742CEFBAB5E40E08442041CE24F40
85040	4	34	\N	55357	45301	\N	62.155632155197097	Республика Саха (Якутия), Сунтарский район, Сунтарский наслег, с.Сунтар, Папанина, 40	Россия	0101000020E6100000FFD0CC936B695D40041BD7BFEB134F40
85037	4	34	\N	55357	45396	\N	62.1645305273438	Республика Саха (Якутия), Сунтарский район, Сунтарский наслег, с.Сунтар, Вилюйская, 32	Россия	0101000020E6100000BCEB6CC83F695D40CE16105A0F154F40
85038	4	34	\N	55357	45235	\N	62.157907332361297	Республика Саха (Якутия), Сунтарский район, Сунтарский наслег, с.Сунтар, В.павлова, 5	Россия	0101000020E6100000BE688F17D2685D409D67EC4B36144F40
84582	4	34	\N	55557	45631	\N	61.541921194110799	Республика Саха (Якутия), Амгинский район, Сулгаччинский наслег, М. Харачаса, 13	Россия	0101000020E6100000DB17D00BF79C60400002D6AA5DC54E40
84673	4	34	\N	55531	45595	\N	62.988576039750903	Республика Саха (Якутия), Верхоянский район, Столбинский наслег с.Столбы, Набережная, 7	Россия	0101000020E610000025C9737D9F31604025CE8AA8897E4F40
84886	4	34	\N	55428	45432	\N	62.980738557769399	Республика Саха (Якутия), Намский район, Хатырыкский наслег,с.Столбы, Аммосова, 45	Россия	0101000020E61000002330D637B0316040B47405DB887D4F40
85016	4	34	\N	55085	45199	\N	67.459757078487598	Республика Саха (Якутия), Среднеколымский район, Город Среднеколымск, Ярославского, 11	Россия	0101000020E61000000B09185D5E356340DAC69FA86CDD5040
85015	4	34	\N	55085	42093	\N	67.458834901464201	Республика Саха (Якутия), Среднеколымский район, Город Среднеколымск, Навроцкого, 5	Россия	0101000020E6100000B1FD648C0F366340A6D0798D5DDD5040
85214	4	34	\N	55401	45383	\N	61.9602263926853	Республика Саха (Якутия), Чурапчинский район, Чурапчинский наслег, с. Чурапча, Ленина, 35	Россия	0101000020E6100000B6F292FFC98E60406B6281AFE8FA4E40
85211	4	34	\N	55401	45503	\N	62.0074960614823	Республика Саха (Якутия), Чурапчинский район, Чурапчинский наслег, с. Чурапча, Карла-Маркса, 29	Россия	0101000020E610000026E1421EC18D6040E86C01A1F5004F40
85064	4	34	\N	55409	45394	\N	68.635360000000006	Республика Саха (Якутия), Таттинский район, Октябрьский наслег, с. Черкех, Ойунского, 52		0101000020E6100000D8648D7A88F45840F14BFDBCA9285140
85127	4	34	\N	61741	79621	\N	59.1660464594435	Республика Саха (Якутия), Усть-Майский район, Село Белькачи, Школьная, 10	Россия	0101000020E610000016F6B4C35F7C6040D9D0CDFE40954D40
84842	4	34	\N	39557	45304	\N	63.044688416452097	Республика Саха (Якутия), Мирнинский район, Поселок Светлый, Советская, 15	Россия	0101000020E6100000A1100187505B5C4007431D56B8854F40
84695	4	34	\N	61760	79643	\N	61.570459	Республика Саха (Якутия), Вилюйский район, с. Сатагай, Центральная, 8	Россия	0101000020E610000091B75CFD58706040BC5AEECC04C94E40
33342	4	41	1601	49485	46282	\N	48.569366000000002	с. Партизанское, ул. Партизанская, д. 2б		0101000020E6100000876D8B329BCE604028BA2EFCE0484840
84598	4	34	\N	55477	45526	\N	71.9644692966001	Республика Саха (Якутия), Анабарский район, Саскылахский национальный наслег, Октябрьская, 19/1	Россия	0101000020E61000004968CBB914865C405F402FDCB9FD5140
84596	4	34	\N	55477	45524	\N	71.961680001082698	Республика Саха (Якутия), Анабарский район, Саскылахский национальный наслег, Молодежная, 25	Россия	0101000020E6100000D316D7F84C865C40E84D452A8CFD5140
84748	4	34	\N	55561	45638	\N	60.912055054869498	Республика Саха (Якутия), Кобяйский район, Мукучунский наслег, с. Сайылык, Октябрьская, 47	Россия	0101000020E61000007EC7F0D8CFB75E409F93DE37BE744E40
85135	4	34	\N	55391	45366	\N	60.786593519007603	Республика Саха (Якутия), Усть-Майский район, Поселок Эльдикан, Алданская, 53	Россия	0101000020E610000033E02C254BE560406B9DB81CAF644E40
84578	4	34	\N	55381	45347	\N	70.622973472314001	Республика Саха (Якутия), Аллаиховский район, Поселок Чокурдах, Ленина, 2	Россия	0101000020E61000001EA5129E507C6240A05225CADEA75140
84845	4	34	\N	55378	45329	\N	63.017950793797503	Республика Саха (Якутия), Мирнинский район, Поселок Чернышевский, Космонавтов, 10/3	Россия	0101000020E61000001B6327BC041E5C401AF7E6374C824F40
84843	4	34	\N	55378	45348	\N	63.0179600859027	Республика Саха (Якутия), Мирнинский район, Поселок Чернышевский, Гидростроителей, 1	Россия	0101000020E6100000B6679604A81C5C406E5166834C824F40
85075	4	34	\N	55377	45315	\N	62.662267780543303	Республика Саха (Якутия), Томпонский район, Поселок Хандыга, Кудрявого, 34	Россия	0101000020E61000001EC4CE14BAF16040FA97A432C5544F40
85073	4	34	\N	55377	45433	\N	62.662352353231398	Республика Саха (Якутия), Томпонский район, Поселок Хандыга, Алданская, 7	Россия	0101000020E61000004BADF71B6DF16040583849F3C7544F40
84956	4	34	\N	55369	45476	\N	64.549846234575597	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Трудовая, 14  здание ОГАИ	Россия	0101000020E61000007F33315D08E7614088F546AD30235040
84958	4	34	\N	55369	45280	\N	64.551785616283496	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Ленина, 25-а  здание к-т Север	Россия	0101000020E610000027A5A0DB4BE7614001193A7650235040
85131	4	34	\N	55474	45547	\N	60.438303948663602	Республика Саха (Якутия), Усть-Майский район, Поселок Усть-Мая, Первомайская, 18	Россия	0101000020E61000009ECE15A584D160405EDA70581A384E40
85133	4	34	\N	55474	45519	\N	60.440982937388199	Республика Саха (Якутия), Усть-Майский район, Поселок Усть-Мая, Горького, 51	Россия	0101000020E6100000D7A3703D8AD16040C68B852172384E40
85132	4	34	\N	55474	45520	\N	60.4324995414783	Республика Саха (Якутия), Усть-Майский район, Поселок Усть-Мая, пер. Алданский, 5	Россия	0101000020E61000009A081B9EDED160408FC2F5285C374E40
84759	4	34	\N	55365	\N	\N	59.507319877335597	Республика Саха (Якутия), Ленский район, вахтовый поселок Талакан, Административное здание центральной, инженерно-технологической службы	Россия	0101000020E61000001EA5129ED0A36040A94D9CDCEFC04D40
84728	4	34	\N	55534	45609	\N	63.941044289214098	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Горбунова, 22	Россия	0101000020E610000056B60F79CBDE5F406B0C3A2174F84F40
84761	4	34	\N	55335	45178	\N	59.630994402049403	Республика Саха (Якутия), Ленский район, Поселок Пеледуй, Центральная, 16	Россия	0101000020E61000008DEF8B4B552F5C4072FC5069C4D04D40
84651	4	34	\N	55408	45392	\N	65.429842935376797	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Пристанская, 14	Россия	0101000020E610000070B54E5C0E95624088DA368C825B5040
84649	4	34	\N	55408	45422	\N	65.741115906322193	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Ленина, 11	Россия	0101000020E6100000E162450D26DC6240B6A2CD716E6F5040
85077	4	34	\N	55386	45357	\N	62.218204582480602	Республика Саха (Якутия), Томпонский район, Поселок Джебарики-Хая, Советская, 9	Россия	0101000020E61000003753211E09FA60406E693524EE1B4F40
84756	4	34	\N	55420	45450	\N	59.447971588016998	Республика Саха (Якутия), Ленский район, Поселок Витим, Ленина, 45	Россия	0101000020E6100000A2ED98BA2B245C4009C3802557B94D40
84655	4	34	\N	55412	45399	\N	67.658680000000004	Республика Саха (Якутия), Верхоянский район, Поселок Батагай, Трохачева, 20		0101000020E6100000E76D6C76A4D56040E0A128D027EA5040
84656	4	34	\N	55412	45482	\N	67.650318023934403	Республика Саха (Якутия), Верхоянский район, Поселок Батагай, Аммосова, 40	Россия	0101000020E6100000E76D6C76A4D56040028063CF9EE95040
84841	4	34	\N	55389	45360	\N	62.446504017797999	Республика Саха (Якутия), Мирнинский район, Поселок Алмазный, Речная, 6	Россия	0101000020E610000098874CF910955C403FC4060B27394F40
84848	4	34	\N	55359	45238	\N	65.939628558836006	Республика Саха (Якутия), Мирнинский район, Поселок Айхал, Энтузиастов, 1	Россия	0101000020E61000006C3D433866DE5B40E257ACE1227C5040
84846	4	34	\N	55359	45279	\N	65.940164779820407	Республика Саха (Якутия), Мирнинский район, Поселок Айхал, Советская, 12	Россия	0101000020E6100000FA62EFC517DC5B4001F6D1A92B7C5040
84847	4	34	\N	55359	45331	\N	65.939885962735602	"Республика Саха (Якутия), Мирнинский район, Поселок Айхал, Бойко, 1 ""А"""	Россия	0101000020E61000005DFB027AE1DB5B40F8FD9B17277C5040
84919	4	34	\N	55432	45443	\N	59.266015000000003	Республика Саха (Якутия), Нижнеколымский район, Олёринский наслег, Набережная, 9		0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
85009	4	34	\N	55342	79684	\N	60.397405800000001	Республика Саха (Якутия), Олекминский район, Город Олёкминск, село Авиапорт, Кузьмина, 2	Россия	0101000020E61000009E5C5320B31D5E40F99D2633DE324E40
85004	4	34	\N	55342	45345	\N	60.380789337683801	Республика Саха (Якутия), Олекминский район, Город Олёкминск, Гагарина, 58	Россия	0101000020E61000007E569929AD1A5E4099D6A6B1BD304E40
85002	4	34	\N	55342	45201	\N	60.378749742851497	Республика Саха (Якутия), Олекминский район, Город Олёкминск, 50 лет Победы, 58	Россия	0101000020E6100000091A33897A1A5E4014AE47E17A304E40
85005	4	34	\N	55338	45551	\N	60.383508598164198	Республика Саха (Якутия), Олекминский район, Город Олёкминск, Спасская, 111	Россия	0101000020E61000007E569929AD1A5E405F5CAAD216314E40
84985	4	34	\N	55338	45434	\N	60.378069849435398	Республика Саха (Якутия), Олекминский район, Олёкминский наслег, село Олекминское, Первомайская, 31	Россия	0101000020E61000005C751DAA290F5E40A3CC069964304E40
84939	4	34	\N	55338	45186	\N	60.381977382455801	Республика Саха (Якутия), Олекминский район, Город Олёкминск, Молодежная, 19	Россия	0101000020E61000002101A3CB9B1A5E407F69519FE4304E40
85006	4	34	\N	55338	45558	\N	60.383508598164198	Республика Саха (Якутия), Олекминский район, Город Олёкминск, Мелиораторов, 3	Россия	0101000020E61000000805A568E51A5E405F5CAAD216314E40
85024	4	34	\N	61767	79650	\N	68.275233	Республика Саха (Якутия), Среднеколымский район, Ойусардах, Мира, 2	Россия	0101000020E6100000AF5FB01BB6566340EB71DF6A9D115140
84938	4	34	\N	61752	79634	\N	63.339670889602203	Республика Саха (Якутия), Нюрбинский район, Нюрбачанский наслег, с. Нюрбачан, П. Николаева, 17	Россия	0101000020E61000003F389F3A56875D402733DE567AAB4F40
84931	4	34	\N	55411	45397	\N	63.276044097122899	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, кв. Энергетик, 22	Россия	0101000020E6100000B3EE1F0BD1975D40E620E86855A34F40
84927	4	34	\N	55411	45397	\N	63.279440870940498	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, кв. Энергетик, 55а	Россия	0101000020E61000003E3C4B9011965D40AD1402B9C4A34F40
84922	4	34	\N	55411	45501	\N	63.282532000000003	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, Убоян, 26		0101000020E61000002BDF3312A1955D40680932022AA44F40
84925	4	34	\N	55411	45424	\N	63.282532000000003	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, Степана Васильева, 33		0101000020E61000002BDF3312A1955D40680932022AA44F40
84923	4	34	\N	55411	45427	\N	63.282532000000003	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, пер. Чусовского, 7		0101000020E61000002BDF3312A1955D40680932022AA44F40
84928	4	34	\N	55411	45425	\N	63.275730290468097	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, Октябрьская, 5	Россия	0101000020E6100000AE7E6C921F975D405743E21E4BA34F40
84924	4	34	\N	55411	45499	\N	63.282532000000003	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, Манчары, 14		0101000020E61000002BDF3312A1955D40680932022AA44F40
84930	4	34	\N	55411	45428	\N	63.282532000000003	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, Ленина, 52		0101000020E61000002BDF3312A1955D40680932022AA44F40
84929	4	34	\N	55411	45428	\N	63.282532000000003	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, Ленина, 32/1		0101000020E61000002BDF3312A1955D40680932022AA44F40
84926	4	34	\N	55411	45449	\N	63.279137970489103	Республика Саха (Якутия), Нюрбинский район, г. Нюрба, Комсомольская, 62	Россия	0101000020E61000003411363CBD985D40128942CBBAA34F40
85010	4	34	\N	55609	45716	\N	60.389067485767796	Республика Саха (Якутия), Олекминский район, Город Олёкминск, село Нефтебаза, Набережная, 2	Россия	0101000020E61000009372F7393E265E40F6798CF2CC314E40
84892	4	34	\N	26979	45274	\N	56.663825644118099	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Южно-Якутская, 8	Россия, Республика Саха (Якутия), Нерюнгри	0101000020E6100000753DD175E12D5F40041E1840F8544C40
84894	4	34	\N	26979	45177	\N	56.660138848110698	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Чурапчинская, 16	Россия, Республика Саха (Якутия), Нерюнгри	0101000020E61000001079CBD58F2E5F4036E84B6F7F544C40
84893	4	34	\N	26979	45177	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Чурапчинская, 33		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84904	4	34	\N	26979	45189	\N	56.663166246031999	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Ленина, 12/1	Россия, Республика Саха (Якутия), Нерюнгри	0101000020E6100000E71BD13DEB2D5F40D9E89C9FE2544C40
84898	4	34	\N	26979	45189	\N	56.657491694333899	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Ленина, 13/2	Россия, Республика Саха (Якутия), Нерюнгри	0101000020E61000009C51F355F22D5F40D9B0A6B228544C40
84896	4	34	\N	26979	45183	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Кравченко, 7		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84895	4	34	\N	26979	45183	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Кравченко, 16/1		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84902	4	34	\N	26979	45185	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, карла Маркса, 7/1		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84901	4	34	\N	26979	45185	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Карла Маркса, 7/1		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84900	4	34	\N	26979	45185	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Карла Маркса, 15		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84897	4	34	\N	26979	45185	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Карла Маркса, 29		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84916	4	34	\N	26979	45228	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Поселок Золотинка, Железнодорожная, 8		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84905	4	34	\N	26979	45192	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Дружбы Народов, 12/2		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84903	4	34	\N	26979	45192	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Дружбы Народов, 7		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84911	4	34	255	\N	79384	\N	56.860642802231702	Республика Саха (Якутия), Нерюнгринский район, Поселок Чульман, с. Большое Хатыми, Геологическая, 2	Россия, Республика Саха (Якутия), Хангаласский район, М-56 шоссе	0101000020E6100000E15F048D99395F400344C18C296E4C40
84906	4	34	\N	26979	45232	\N	56.6617482655099	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Аммосова, 6/3	Россия, Республика Саха (Якутия), Нерюнгри	0101000020E6100000101FD8F15F2E5F40C2189128B4544C40
84914	4	34	\N	26979	45401	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Поселок Хани, 70 лет Отктября, СОШ №16		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84978	4	34	\N	55482	45531	\N	60.254774452252697	Республика Саха (Якутия), Олекминский район, Нерюктяйинский 1-й наслег, село 1-Нерюктяйинск, Центральная, 15	Россия	0101000020E61000000E1478279FEC5D4080EF366F9C204E40
84877	4	34	\N	55334	45176	\N	62.715902782656201	Республика Саха (Якутия), Намский район, Ленский наслег,с.Намцы, Платонова, 18	Россия	0101000020E61000005AD427B9C3346040DC0DA2B5A25B4F40
84874	4	34	\N	55345	45205	\N	62.7023458051926	Республика Саха (Якутия), Намский район, Ленский наслег,с.Намцы, Студенческая, 1	Россия	0101000020E610000081E84999D4346040FB3C4679E6594F40
84828	4	34	\N	33793	\N	\N	62.538449	Республика Саха (Якутия), Мирнинский район, г.Мирный, АЭРОПОРТ, актовый зал Аэропорта	Россия	0101000020E61000002D5DC136E27D5C402EC896E5EB444F40
84834	4	34	\N	33793	45193	\N	62.542727839742703	Республика Саха (Якутия), Мирнинский район, г.Мирный, Тихонова, 5/1	Россия	0101000020E6100000A2ED98BA2B7E5C40CE4F711C78454F40
84832	4	34	\N	33793	45325	\N	62.528931031710499	"Республика Саха (Якутия), Мирнинский район, г.Мирный, Советская, 11 ""А"""	Россия	0101000020E6100000CFBF5DF6EB7C5C40986BD102B4434F40
84825	4	34	\N	33793	45314	\N	62.5325802832485	"Республика Саха (Якутия), Мирнинский район, г.Мирный, Ленинградский проспект, 9 ""А"""	Россия	0101000020E6100000CA1649BBD17D5C407940D9942B444F40
84824	4	34	\N	33793	45314	\N	62.531945945818201	Республика Саха (Якутия), Мирнинский район, г.Мирный, Ленинградский проспект, 7/4	Россия	0101000020E6100000F23FF9BB777D5C40779E78CE16444F40
84831	4	34	\N	33793	45184	\N	62.5338489174652	Республика Саха (Якутия), Мирнинский район, г.Мирный, Ленина, 30	Россия	0101000020E61000006A4C88B9A47D5C404B00FE2955444F40
84830	4	34	\N	33793	45184	\N	62.534641999999998	Республика Саха (Якутия), Мирнинский район, Ленина, 1	Россия	0101000020E6100000A6D24F38BB7D5C40B58828266F444F40
83572	4	34	\N	33793	45184	\N	62.539000096498597	Республика Саха (Якутия), Мирнинский район, г.Мирный, Ленина, 17	Россия	0101000020E610000030F0DC7BB87D5C40A245B6F3FD444F40
84835	4	34	\N	33793	45344	\N	62.535428207713601	Республика Саха (Якутия), Мирнинский район, г.Мирный, Куницына, 18	Россия	0101000020E610000064744012F67D5C406DAE9AE788444F40
84827	4	34	\N	33793	45239	\N	62.543996040483002	"Республика Саха (Якутия), Мирнинский район, г.Мирный, Комсомольская, 2 ""А"""	Россия	0101000020E6100000F23FF9BB777D5C40D19332A9A1454F40
84826	4	34	\N	33793	45239	\N	62.538922912443603	Республика Саха (Якутия), Мирнинский район, г.Мирный, Комсомольская, 12	Россия	0101000020E6100000A2ED98BA2B7E5C40F607CA6DFB444F40
84823	4	34	\N	33793	45441	\N	62.534166067552	Республика Саха (Якутия), Мирнинский район г.Мирный, Звездная, 7	Россия	0101000020E610000056EF703B347D5C404C512E8D5F444F40
83546	4	34	\N	33793	45473	\N	62.532891020016898	Республика Саха (Якутия), Мирнинский район, г.Мирный, Вилюйская, 7	Россия	0101000020E61000008C9DF0129C7D5C4097AAB4C535444F40
84829	4	34	\N	33793	45194	\N	62.547446009202801	Республика Саха (Якутия), Мирнинский район, 40 Лет Октября, 12	Россия	0101000020E610000043E55FCB2B7E5C40BB29E5B512464F40
85085	4	34	\N	55491	45541	\N	62.700202864592903	Республика Саха (Якутия), Томпонский район, Мегино-Алданский наслег, с.Мегино-Алдан, Октябрьская, 19	Россия	0101000020E610000044A7E7DDD8D36040D2C77C40A0594F40
84974	4	34	\N	55583	45678	\N	59.904676110199901	Республика Саха (Якутия), Олекминский район, Мачинский наслег, село Мача, Строда, 26	Россия	0101000020E610000000732D5A80635D40F1BC546CCCF34D40
84740	4	34	\N	61776	79659	\N	63.722701000000001	Республика Саха (Якутия), Кобяйский район, Люччегинский 2-й наслег, с.Мастах, Советская, 20	Россия	0101000020E6100000569E40D8290C5F40ACE4637781DC4F40
85049	4	34	\N	61773	79656	\N	62.398181999999998	Республика Саха (Якутия), Сунтарский район, Мар-Кюёльский наслег, с.Мар-Кель, Молодежная, 19	Россия	0101000020E61000003D64CA87A0405D408DEDB5A0F7324F40
84949	4	34	\N	55463	45507	\N	63.524958522584797	Республика Саха (Якутия), Нюрбинский район, Тюмюкский наслег, с. Маар, Молодежная, 4	Россия	0101000020E6100000EF7211DF89BF5D40D55E44DB31C34F40
84953	4	34	\N	55406	45390	\N	63.507320184830299	Республика Саха (Якутия), Нюрбинский район, Бордонский наслег, с. Малыкай, Мегежекского, 6	Россия	0101000020E6100000A0FF1EBC76415D40A94D9CDCEFC04F40
84723	4	34	\N	61818	79726	\N	67.154700000000005	Республика Саха (Якутия), Жиганский район, Линдинский наслег, н.Баханы, Линдинская, 2	Россия	0101000020E6100000D95F764F1E925E403D2CD49AE6C95040
84767	4	34	\N	55333	\N	\N	60.721073975112503	"Республика Саха (Якутия), Ленский район, Город Ленск, Аэропорт ""Ленск"""	Россия	0101000020E61000001A36CAFACDB95C407AFF1F274C5C4E40
82622	4	34	\N	55333	45410	\N	60.720737620036303	Республика Саха (Якутия), Ленский район, Город Ленск, Якутская, 15	Россия	0101000020E6100000239F573CF5BB5C40027E8D24415C4E40
83290	4	34	\N	55333	45322	\N	60.722083019143497	Республика Саха (Якутия), Ленский район, Город Ленск, Проспект Дружбы, 21	Россия	0101000020E61000006C43C5387FB95C40B0FF3A376D5C4E40
82207	4	34	\N	55333	45262	\N	60.728136615634703	Республика Саха (Якутия), Ленский район, Город Ленск, Пролетарская, 28	Россия	0101000020E6100000C3D4963AC8BB5C40F700DD97335D4E40
84773	4	34	\N	55333	45271	\N	60.727464050324102	Республика Саха (Якутия), Ленский район, Город Ленск, Победы, 11	Россия	0101000020E61000007BBB253960BA5C403882548A1D5D4E40
82188	4	34	\N	55333	45271	\N	60.729481703866803	Республика Саха (Якутия), Ленский район, Город Ленск, Победы, 30	Россия	0101000020E610000020459DB987B85C40A5828AAA5F5D4E40
84772	4	34	\N	55333	45398	\N	60.722083019143497	Республика Саха (Якутия), Ленский район, Город Ленск, Первомайская, 2	Россия	0101000020E6100000DD9A745B22BA5C40B0FF3A376D5C4E40
84775	4	34	\N	55333	45356	\N	60.738223399838397	Республика Саха (Якутия), Ленский район, Город Ленск, Ойунского, 36	Россия	0101000020E61000000FD3BEB9BFBC5C40D7135D177E5E4E40
33349	4	41	1601	55685	46277	\N	48.551751000000003	пос. Николаевка, ул. Строительная, д. 10		0101000020E6100000D1419770E8D860408544DAC69F464840
82298	4	34	\N	55333	45636	\N	60.730826735581601	Республика Саха (Якутия), Ленский район, Город Ленск, Нюйская, 14	Россия	0101000020E6100000499EEBFB70BC5C40530438BD8B5D4E40
82894	4	34	\N	55333	45639	\N	60.722755697499501	Республика Саха (Якутия), Ленский район, Город Ленск, Мелиораторов, 3	Россия	0101000020E6100000B8B06EBC3BB95C406F7EC344835C4E40
84770	4	34	\N	55333	45173	\N	60.717373874954198	Республика Саха (Якутия), Ленский район, Город Ленск, Ленина, 61	Россия	0101000020E61000006C43C5387FB95C40178046E9D25B4E40
84766	4	34	\N	55333	45261	\N	60.725293387326097	Республика Саха (Якутия), Ленский район, Город Ленск, Каландарашвили, 28	Россия	0101000020E61000002F51BD35B0BA5C404582A966D65C4E40
84765	4	34	\N	55333	45261	\N	60.728067816267597	Республика Саха (Якутия), Ленский район, Город Ленск, ул. Каландарашвили, 16	Россия	0101000020E6100000E2900DA48BBA5C40CFA10C55315D4E40
83521	4	34	\N	55333	45409	\N	60.736206297299802	Республика Саха (Якутия), Ленский район, Город Ленск, Бамовский проезд, 1	Россия	0101000020E61000000FD3BEB9BFBC5C403B8F8AFF3B5E4E40
83066	4	34	\N	55333	45320	\N	60.718046652235898	Республика Саха (Якутия), Ленский район, Город Ленск, Айхальская, 33	Россия	0101000020E6100000F436363B52B95C40D6FECEF6E85B4E40
84699	4	34	\N	61811	79723	\N	63.057794999999999	Республика Саха (Якутия), Вилюйский район, с. Лекечен, Центральная, 24	Россия	0101000020E6100000DA8F149161FE5E40A86F99D365874F40
84936	4	34	\N	55473	45518	\N	63.2134854485167	Республика Саха (Якутия), Нюрбинский район, Кюндядинский наслег, с. Кюндядя, Ленина, 64	Россия	0101000020E61000009D2B4A09C1895D40E197FA79539B4F40
85030	4	34	\N	55464	45508	\N	62.706824127484801	Республика Саха (Якутия), Сунтарский район, Кутанинский наслег, с.Кутана, В.Крыжановского, 32	Россия	0101000020E6100000809E060C92645D4092037635795A4F40
84617	4	34	\N	55579	45668	\N	63.273572427889697	Республика Саха (Якутия), Верхневилюйский район, Едюгейский наслег,с.Куду, Куду, 22	Россия	0101000020E6100000E5B8533A581B5E40F88C446804A34F40
84705	4	34	\N	55563	45642	\N	64.5549010027256	Республика Саха (Якутия), Вилюйский район, с. Кирово, Братьев Семеновых, 24	Россия	0101000020E610000058E36C3A028F5E4022E17B7F83235040
84627	4	34	\N	61352	78682	\N	63.479393690582199	Республика Саха (Якутия), Верхневилюйский район, Кентикский наслег, с.Кентик, Г.Миронова, 11		0101000020E6100000A5A31CCC26095E4006F357C85CBD4F40
84719	4	34	\N	55394	45370	\N	66.769639267125797	Республика Саха (Якутия), Жиганский район, Жиганский наслег, с.Жиганск, Кычкина, 11	Россия	0101000020E6100000239F573CF5D75E4079AEEFC341B15040
85050	4	34	\N	55581	45717	\N	59.9967575706522	Республика Саха (Якутия), Сунтарский район, Жарханский наслег, с.Жархан, Тихоновой, 7	Россия	0101000020E61000001FF296AB1FF35D40600322C495FF4D40
84941	4	34	\N	55581	45674	\N	63.503771135262603	Республика Саха (Якутия), Нюрбинский район, Жарханский наслег, с. Жархан, Доры Жирковой, 5	Россия	0101000020E6100000BC067DE9EDB05D402CD670917BC04F40
84616	4	34	\N	55470	45515	\N	63.601505709639703	Республика Саха (Якутия), Верхневилюйский район, Едюгейский наслег, с.Едюгей, Зеленая, 4	Россия	0101000020E6100000DD442DCDADDC5D40842C0B26FECC4F40
85208	4	34	\N	55472	45517	\N	61.851943082299101	Республика Саха (Якутия), Чурапчинский район, Хоптогинский наслег, с. Дирин, Марыкчанская, 10	Россия	0101000020E6100000AF997CB34D8460402F87DD770CED4E40
85061	4	34	\N	55436	45455	\N	62.413763140714899	Республика Саха (Якутия), Таттинский район, Игидейский наслег, с.Дэбдиргэ, Боярова, 27	Россия	0101000020E6100000056B9C4D479B6040BEA59C2FF6344F40
84758	4	34	\N	61624	79499	\N	59.438267000000003	"Республика Саха (Якутия), Ленский район, Поселок Витим, Декабристов, 1 ""А"""	Россия	0101000020E6100000DE73603942245C4041F50F2219B84D40
84680	4	34	\N	54266	45521	\N	63.751026976042297	"Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Ярославского, 70 ""а"""	Россия	0101000020E610000067614F3BFC675E40DDB419A721E04F40
81704	4	34	\N	54266	35831	\N	63.747073595771397	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Чиряева, 30/1	Россия	0101000020E610000007978E39CF675E4090D8EE1EA0DF4F40
84682	4	34	\N	54266	45488	\N	63.743171123229303	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Чапаева, 45/1		0101000020E6100000CEA5B8AAEC675E40F52A323A20DF4F40
84678	4	34	\N	54266	45489	\N	63.756803995844898	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Партизана Семенова, 18	Россия	0101000020E610000067614F3BFC675E40B2BD16F4DEE04F40
84677	4	34	\N	54266	45544	\N	63.742815489081003	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Мира, 17		0101000020E6100000CB10C7BAB8675E4037FDD98F14DF4F40
84679	4	34	\N	54266	45363	\N	63.745248771669502	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Марка Жиркова, 38	Россия	0101000020E610000031EA5A7B9F665E403830B95164DF4F40
81544	4	34	\N	54266	45406	\N	63.7440321566311	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Ленина, 28	Россия	0101000020E61000008D60E3FA77685E40B796C9703CDF4F40
84681	4	34	\N	54266	45387	\N	63.752851426049403	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Иона Попова, 11	Россия	0101000020E610000067614F3BFC675E4065E1EB6B5DE04F40
84683	4	34	\N	54266	79482	\N	63.749358394687803	Республика Саха (Якутия), Вилюйский район, г. Вилюйск пригород (с. Сосновка), Б.Н.Степанова, 4	Россия	0101000020E610000020B8CA1308685E407C7F83F6EADF4F40
81737	4	34	\N	54266	45509	\N	63.738218723768	Республика Саха (Якутия), Вилюйский район, г. Вилюйск, Аммосова, 14	Россия	0101000020E61000002D9622F94A685E409624CFF57DDE4F40
84659	4	34	\N	55421	45419	\N	67.553631119002404	Республика Саха (Якутия), Верхоянский район, Город Верхоянск, Новгородова, 44	Россия	0101000020E6100000DBBE47FD75AD604050C3B7B06EE35040
84612	4	34	\N	61879	79846	\N	63.447171022928003	Республика Саха (Якутия), Верхневилюйский район, Верхневилюйский наслег, с.Верхневилюск, Ветеринаров, 8	Россия	0101000020E61000008AE76C01A1145E401C5C3AE63CB94F40
84610	4	34	\N	54711	45282	\N	59.266015000000003	Республика Саха (Якутия), Верхневилюйский район, Верхневилюйский наслег, с.Верхневилюйск, Школьная, 1		0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
84613	4	34	\N	54711	38893	\N	63.442969807968801	Республика Саха (Якутия), Верхневилюйский район, Верхневилюйский наслег, с.Верхневилюйск, Героя Васильева, 47	Россия	0101000020E61000005B5D4E0988145E40F88DAF3DB3B84F40
84609	4	34	\N	54711	38893	\N	63.443315636261403	Республика Саха (Якутия), Верхневилюйский район, Верхневилюйский наслег, с.Верхневилюйск, Героя Васильева, 2 Б		0101000020E610000085EE92382B145E4093E52494BEB84F40
84998	4	34	\N	61793	79687	\N	62.772223057613601	Республика Саха (Якутия), Олекминский район, Чаринский наслег, село Бясь-Кюель, Центральная, 6	Россия	0101000020E6100000187AC4E8B9C45F40081C0934D8624F40
84884	4	34	\N	61588	79449	\N	62.8834293816765	Республика Саха (Якутия), Намский район, Бетюнский наслег,с.Бютяй-Юрдя, Кириллина, 35	Россия	0101000020E6100000B62FA017EE31604043AB933314714F40
84814	4	34	\N	55460	45504	\N	61.632497801195498	Республика Саха (Якутия), Мегино-Кангаласский район, Бютейдяхский наслег, с. Бютейдях, Анисимова, 22	Россия	0101000020E61000004F0647C9AB6A60408864C8B1F5D04E40
84603	4	34	\N	55559	45634	\N	71.985303521471494	Республика Саха (Якутия), Булунский район, с. Быков, Советская, 2	море Лаптевых	0101000020E6100000D34B8C65FA2360408D2782380FFF5140
84605	4	34	\N	61731	79611	\N	69.313089808050194	Республика Саха (Якутия), Булунский район, с. Борогон, Жиркова, 6	Россия	0101000020E6100000E2934E2498EA604019ADA3AA09545140
84690	4	34	\N	55440	79517	\N	60.342399999999998	Республика Саха (Якутия), Вилюйский район, с. Бетюнг, Колхозная, 5А	Россия	0101000020E61000001F85EB51B8165E40401361C3D32B4E40
85019	4	34	\N	61582	79435	\N	67.179434115463906	Республика Саха (Якутия), Среднеколымский район, с.Березовка, Ягловского, 8	Россия	0101000020E6100000DD239BABE69163409772BED87BCB5040
84968	4	34	\N	55571	\N	\N	63.451136556445803	Республика Саха (Якутия), Оймяконский район, Борогонский 1-й наслег, с. Берег-Юрдэ, Детский сад	Россия	0101000020E6100000A73B4F3CE7DC6140FE8172DBBEB94F40
85217	4	34	\N	55388	45358	\N	67.780584594403095	Республика Саха (Якутия), Эвено-Бытантайский район, село Батагай-Алыта, Шадрина, 2	Россия	0101000020E6100000624B8FA6FA4C6040E2AFC91AF5F15040
84745	4	34	\N	55540	45606	\N	64.331979533802297	Республика Саха (Якутия), Кобяйский район, Люччегинский 1-й наслег, с. Багадя, Егорова, 1	Россия	0101000020E6100000554B3ACAC1ED5D4045BB0A293F155040
85087	4	34	\N	61770	79653	\N	62.856839346775899	Республика Саха (Якутия), Томпонский район, Баягантайский наслег, с.Ары-Толон, Переулок Школьный, 9,кор.1	Россия	0101000020E61000003F558506E2C86040FB777DE6AC6D4F40
84580	4	34	\N	55366	45326	\N	60.898457362168898	Республика Саха (Якутия), Амгинский район, Амгинский наслег, Партизанская, 28	Россия	0101000020E610000066BD18CA097F60405FEE93A300734E40
84581	4	34	\N	55366	45273	\N	60.897955625386501	Республика Саха (Якутия), Амгинский район, Амгинский наслег, Ленина, 44	Россия	0101000020E610000066BD18CA097F60409D9FE238F0724E40
84579	4	34	\N	55366	45381	\N	60.903307076174301	Республика Саха (Якутия), Амгинский район, Амгинский наслег, Короленко, 9	Россия	0101000020E61000006F0ED76A0F7F6040BA9F53909F734E40
84537	4	34	\N	62066	81072	\N	68.396326999999999	Республика Саха (Якутия), Абыйский район, Абыйский наслег, с. Абый, Баронова, 11	Россия	0101000020E6100000F5108DEEA022624065E1EB6B5D195140
84585	4	34	\N	55422	45420	\N	61.036800848781603	Республика Саха (Якутия), Амгинский район, Абагинский наслег, Партизанская, 13		0101000020E6100000A04FE44952896040E4BA29E5B5844E40
84983	4	34	\N	55422	45657	\N	60.324775066696297	Республика Саха (Якутия), Олекминский район, Абагинский наслег, село Абага, Кудрина-Абагинского, 15	Россия	0101000020E61000007DB262B83A045E407AC7293A92294E40
85277	4	34	567	55354	45226	\N	61.907160308779901	Республика Саха (Якутия), город Якутск, с. Хатассы, Совхозная, 31	Россия, Республика Саха (Якутия), городской округ Якутск, село Хатассы	0101000020E610000035971B0C75346040A31EA2D11DF44E40
85252	4	34	567	55354	45226	\N	61.9057840184106	Республика Саха (Якутия), город Якутск, с. Хатассы, Совхозная, 31А	Россия, Республика Саха (Якутия), городской округ Якутск, село Хатассы	0101000020E6100000FB78E8BB5B346040BA9EE8BAF0F34E40
85263	4	34	567	55374	45308	\N	62.254010686448702	Республика Саха (Якутия), город Якутск, с. Тулагино, Первомайская, 2	Россия, Республика Саха (Якутия), городской округ Якутск, село Тулагино	0101000020E6100000E44A3D0BC23B604081E9B46E83204F40
85253	4	34	567	55426	45430	\N	61.970172808467403	Республика Саха (Якутия), город Якутск, с. Пригородный, Совхозная, 27	Россия, Республика Саха (Якутия), городской округ Якутск, село Пригородный	0101000020E61000000989B48D3F3660402A3BFDA02EFC4E40
84943	4	34	567	29293	45415	\N	62.102892181243703	Республика Саха (Якутия), Нюрбинский район, Таркайинский наслег, с. Марха, Советская, 31	Россия, Республика Саха (Якутия), городской округ Якутск, поселок городского типа Марха	0101000020E6100000876C205DEC3760409082A7902B0D4F40
85254	4	34	567	29293	45272	\N	62.1003540104143	Республика Саха (Якутия), город Якутск, мкрн. Марха, О. Кошевого, 45	Россия, Республика Саха (Якутия), городской округ Якутск, поселок городского типа Марха	0101000020E61000004419AA62AA376040EB025E66D80C4F40
85259	4	34	567	55363	45264	\N	62.104456328687299	Республика Саха (Якутия), город Якутск, с. Маган, Алымова, 3		0101000020E6100000D449B6BA1C3160407CEF6FD05E0D4F40
85264	4	34	567	55402	45385	\N	62.325396228829703	Республика Саха (Якутия), город Якутск, с. Капитоновка, Семенова, 14	Россия, Республика Саха (Якутия), городской округ Якутск, село Капитоновка	0101000020E61000003C139A24163E6040E61F7D93A6294F40
85261	4	34	567	55337	45251	\N	62.148581356966702	"Республика Саха (Якутия), город Якутск, Городской округ ""Поселок Жатай"", Строда, 1"	Россия, Республика Саха (Якутия), городской округ Якутск, село Жатай	0101000020E61000002444F982963A60404BE7C3B304134F40
85262	4	34	567	55337	45181	\N	62.146011174650901	"Республика Саха (Якутия), город Якутск, Городской округ ""Поселок Жатай"", Северная, 4"	Россия, Республика Саха (Якутия), городской округ Якутск, село Жатай	0101000020E610000013B70A62203A60409AED0A7DB0124F40
85260	4	34	567	55337	45181	\N	62.1574593004772	"Республика Саха (Якутия), город Якутск, Городской округ ""Поселок Жатай"", Северная, 50"	Россия, Республика Саха (Якутия), городской округ Якутск, село Жатай	0101000020E61000002FFD4B52993A6040FEBAD39D27144F40
84910	4	34	117	27669	45333	\N	56.860925000000002	Республика Саха (Якутия), Нерюнгринский район, Поселок Чульман, Циолковского, 6А		0101000020E610000094F947DFA4395F4087A757CA326E4C40
84908	4	34	117	27669	45276	\N	56.860925000000002	Республика Саха (Якутия), Нерюнгринский район, Поселок Чульман, Геологическая, 18		0101000020E610000094F947DFA4395F4087A757CA326E4C40
84907	4	34	117	27669	45330	\N	56.860925000000002	Республика Саха (Якутия), Нерюнгринский район, Поселок Чульман, Гаражная, 2		0101000020E610000094F947DFA4395F4087A757CA326E4C40
84909	4	34	117	55358	45236	\N	56.860925000000002	Республика Саха (Якутия), Нерюнгринский район, Поселок Чульман, Островского, 18		0101000020E610000094F947DFA4395F4087A757CA326E4C40
84854	4	34	117	55371	\N	\N	56.862726000000002	Республика Саха (Якутия), Мирнинский район, Город Удачный, Новый Город, СОШ №24		0101000020E6100000B9E34D7E8B27604057B439CE6D6E4C40
84851	4	34	117	55371	\N	\N	56.862726000000002	Республика Саха (Якутия), Мирнинский район, Город Удачный, Новый Город, Общественный центр, спортзал		0101000020E6100000B9E34D7E8B27604057B439CE6D6E4C40
84812	4	34	117	23267	\N	\N	56.669623999999999	Республика Саха (Якутия), Нерюнгринский район, Поселок Серебряный Бор, 39		0101000020E61000009DF3531C07365F40F04E3E3DB6554C40
84915	4	34	117	28028	45445	\N	56.222037221601298	Республика Саха (Якутия), Нерюнгринский район, Село Иенгра, 40 лет Победы, 5	Россия, Республика Саха (Якутия), городской округ Нерюнгри, село Иенгра	0101000020E6100000475A2A6F47365F4040C05AB56B1C4C40
84912	4	34	117	27941	45190	\N	56.578327315431402	Республика Саха (Якутия), Нерюнгринский район, Поселок Беркакит, Школьная, 5	Россия, Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Беркакит	0101000020E61000006A32E36DA5315F4068B27F9E064A4C40
84913	4	34	117	27941	9761	\N	56.577996080759	Республика Саха (Якутия), Нерюнгринский район, Поселок Беркакит, Муссы Джалиля, 7А	Россия, Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Беркакит	0101000020E610000042EA76F695315F40029CDEC5FB494C40
85250	4	34	7374	55604	45709	\N	61.8460570045754	Республика Саха (Якутия), город Якутск, с. Табага, Лесная, 12	Россия, Республика Саха (Якутия), городской округ Якутск, поселок городского типа Табага	0101000020E6100000A2CF471971336040A4C684984BEC4E40
85265	4	34	7374	55605	45711	\N	62.2809700880753	Республика Саха (Якутия), город Якутск, с. Кильдямцы, Труда, 24	Россия, Республика Саха (Якутия), городской округ Якутск, село Кильдемцы	0101000020E6100000255987A32B3A60401D9430D3F6234F40
85218	4	34	7538	61749	79631	\N	68.1740173160116	Республика Саха (Якутия), Эвено-Бытантайский район, село Кустур, Аммосова Е.И, 7	Россия	0101000020E610000013EE9579AB746040ADFC3218230B5140
85216	4	34	7538	61717	79597	\N	67.283102	Республика Саха (Якутия), Эвено-Бытантайский район, село Джаргалах, Центральная, 2	Россия	0101000020E610000019575C1C95506040A9DBD9571ED25040
85189	4	34	7314	61886	79857	\N	62.135933999999999	Республика Саха (Якутия), Чурапчинский район, Болтогинский наслег, уч. Кындал, Центральная, 1	Россия	0101000020E610000093DFA293A59760400D350A4966114F40
85202	4	34	7314	61608	79476	\N	62.139000000000003	Республика Саха (Якутия), Чурапчинский район, Сыланский наслег, с.Тея, Монастырева, 11	Россия	0101000020E61000009CC1DF2FE68D60406F1283C0CA114F40
85190	4	34	7314	61827	79745	\N	61.992320599999999	Республика Саха (Якутия), Чурапчинский район, Хатылинский наслег, с. Харбала-1, Партизанская, 16	Россия	0101000020E61000008A0629788A9260402711E15F04FF4E40
85210	4	34	7314	61829	79747	\N	61.737229446148	Республика Саха (Якутия), Чурапчинский район, Хаяхсытский наслег, с. Туора-Кюель, Комсомольская, 16	Россия	0101000020E610000033A5F5B7047E6040D65416855DDE4E40
85187	4	34	7314	61794	79688	\N	62.010775099999996	Республика Саха (Якутия), Чурапчинский район, Бахсытский наслег, с. Толон, Новая, 1	Россия	0101000020E61000002BC1E270E65E5D40A54E401361014F40
85195	4	34	7314	61841	79761	\N	62.255412970518201	Республика Саха (Якутия), Чурапчинский район, Кытанахский наслег, с. Килэнки, Октябрьская, 4	Россия	0101000020E61000001C7BF65C268B604093FC885FB1204F40
85205	4	34	7314	54732	38912	\N	61.756338140323599	Республика Саха (Якутия), Чурапчинский район, Хадарский наслег, с. Юрюнг-Кюель, Сергеева, 28	Россия	0101000020E6100000F4A44C6A688060406C5CFFAECFE04E40
85186	4	34	7314	55584	45679	\N	62.193865513691101	Республика Саха (Якутия), Чурапчинский район, Алагарский наслег, с. Чепара, Протодьяконова, 78		0101000020E6100000CAC16C020C6D604036E7E099D0184F40
85215	4	34	7314	55398	45378	\N	62.012655286828902	Республика Саха (Якутия), Чурапчинский район, Чурапчинский наслег, с. Чурапча, Спортивная, 2		0101000020E6100000957D57047F8D6040C190D5AD9E014F40
85213	4	34	7314	55398	45384	\N	61.998695092934597	Республика Саха (Якутия), Чурапчинский район, Чурапчинский наслег, с. Чурапча, Ленина, 53	Россия	0101000020E6100000BA2EFCE0FC8D6040E0D6DD3CD5FF4E40
85209	4	34	7314	55569	45654	\N	61.331523708007303	Республика Саха (Якутия), Чурапчинский район, Чакырский наслег, с. Чакыр, Эрилик-Эристина, 2		0101000020E610000004E8F7FD9B95604068EBE0606FAA4E40
85193	4	34	7314	54722	38902	\N	61.748079336369003	Республика Саха (Якутия), Чурапчинский район, Соловьевский наслег, уч. Хахыйах, Хомподоева, 8	Россия	0101000020E610000091B41B7D4CB5604085E97B0DC1DF4E40
85188	4	34	7314	61626	79500	\N	62.045915990334997	Республика Саха (Якутия), Чурапчинский район, Болтогинский наслег, С. Харбала-2, Новгородова		0101000020E61000008EAED2DDF59860407B2E5393E0054F40
85200	4	34	7314	55486	45536	\N	62.166235874395397	Республика Саха (Якутия), Чурапчинский район, Сыланский наслег, с. Усун-Кюель, Макарова, 5		0101000020E6100000459BE3DC268660407CB5A33847154F40
85201	4	34	7314	61703	79582	\N	62.162382773854802	Республика Саха (Якутия), Чурапчинский район, Сыланский наслег, с. Улахан-Кюель, Мельницкая, 14	Россия	0101000020E6100000658BA4DDE8876040933655F7C8144F40
85197	4	34	7314	55547	45620	\N	61.973946387310598	Республика Саха (Якутия), Чурапчинский район, Тёлёйский наслег, с. Телей, Телейская, 6а	Россия	0101000020E61000003D5FB35CB6856040F6083543AAFC4E40
85212	4	34	7314	55405	45389	\N	61.984784390475497	Республика Саха (Якутия), Чурапчинский район, Чурапчинский наслег, с. Чурапча, Петровского, 29	Россия	0101000020E61000004A07EBFF9C8E6040E1CFF0660DFE4E40
85192	4	34	7314	54261	35828	\N	61.829494658935097	Республика Саха (Якутия), Чурапчинский район, Соловьевский наслег, с. Мырыла, Амгинская, 40	Россия	0101000020E61000003E7782FDD7B46040079964E42CEA4E40
85207	4	34	7314	54712	\N	\N	61.991770536235201	Республика Саха (Якутия), Чурапчинский район, Хоптогинский наслег, с. Мельжехси, нет улиц, нет	Россия	0101000020E6100000C7BDF90D93846040840F255AF2FE4E40
85196	4	34	7314	55469	45514	\N	61.994582928565201	Республика Саха (Якутия), Чурапчинский район, Мугудайский наслег, с.Маралай, Октярьская, 81		0101000020E610000021938C9C057E60402B14E97E4EFF4E40
85198	4	34	7314	55471	45516	\N	61.905980251107799	Республика Саха (Якутия), Чурапчинский район, Ожулунский наслег, Дябыла, Карла-Маркса, 25	Россия	0101000020E61000001E882CD2C48A6040406A1327F7F34E40
85203	4	34	7314	55511	45573	\N	62.180898663133	Республика Саха (Якутия), Чурапчинский район, Сыланский наслег, с. Бэрэ, Сивцева, 14		0101000020E61000007F68E6C9358060408670CCB227174F40
84574	4	34	255	8207	45632	\N	61.194134589144497	Республика Саха (Якутия), Аллаиховский район, Бёрёлёхский наслег с.Чкалово, Центральная, 16	Россия, Республика Саха (Якутия), Хангаласский район, село Чкалов	0101000020E61000001AA88C7F9FEF5F4026016A6AD9984E40
85161	4	34	255	8207	45592	\N	61.1940521502219	Республика Саха (Якутия), Хангаласский район, Тит-Арынский наслег, с.Чкалов, Мира, 16	Россия, Республика Саха (Якутия), Хангаласский район, село Чкалов	0101000020E61000000A302C7FBEEF5F4098DC28B2D6984E40
85167	4	34	255	32622	45591	\N	61.424377	Республика Саха (Якутия), Хангаласский район, Бестяхский наслег, с.Чаран, Михайлова		0101000020E6100000744012F6ED18604059164CFC51B64E40
84973	4	34	255	8957	45361	\N	61.658740999999999	Республика Саха (Якутия), Олекминский район, Чапаевский наслег, село Чапаево, Сосновая, 21		0101000020E61000008849B890C72C604065C405A051D44E40
85177	4	34	255	8957	45612	\N	61.658740999999999	Республика Саха (Якутия), Хангаласский район, Октёмский наслег, с.Чапаево, Саввина, 1		0101000020E61000008849B890C72C604065C405A051D44E40
85180	4	34	255	33145	79464	\N	61.535795	Республика Саха (Якутия), Хангаласский район, Жемконский 1-й наслег, с.Хоточчу, Варламовых, 15		0101000020E610000027DBC01D282D60401F2E39EE94C44E40
85012	4	34	255	32628	45676	\N	61.217523999999997	Республика Саха (Якутия), Оленекский район, Кирбейский наслег, с.Харьялах, Октябрьская, 4		0101000020E610000071AFCC5B75FA5F402C0C91D3D79B4E40
84890	4	34	255	32628	45645	\N	61.217523999999997	Республика Саха (Якутия), Намский район, Кебекёнский наслег,с.Харыялаах, Набережная, 14		0101000020E610000071AFCC5B75FA5F402C0C91D3D79B4E40
84747	4	34	255	20054	79519	\N	61.819916929693598	Республика Саха (Якутия), Кобяйский район, Мукучунский наслег, с. Сайылык, Саввинова, 3	Россия, Республика Саха (Якутия), Хангаласский район, село Улахан-Сайылык	0101000020E6100000BD1B0B0A831560409B374E0AF3E84E40
84631	4	34	255	20054	78681	\N	61.820160000000001	Республика Саха (Якутия), Верхневилюйский район, Мейикский наслег, с.Меик, С. Буучугураса, 3		0101000020E6100000B4B0A71D7E15604062BEBC00FBE84E40
85162	4	34	255	8871	45429	\N	61.299577999999997	Республика Саха (Якутия), Хангаласский район, Мальжагарский 2-й наслег, с.Улахан-Ан, Б.Трофимова, 1		0101000020E6100000C45F93356A086040F04C689258A64E40
85176	4	34	255	8871	45529	\N	61.299990827095598	Республика Саха (Якутия), Хангаласский район, Жерский наслег, с.Улах-Ан, Ленская, 49	Россия, Республика Саха (Якутия), Хангаласский район, село Улахан-Ан	0101000020E6100000A7EA1ED95C086040130CE71A66A64E40
84820	4	34	255	9020	45469	\N	61.710914498819101	Республика Саха (Якутия), Мегино-Кангаласский район, Жанхадинский наслег, с. Техтюр, Октябрьская, 12	Россия, Республика Саха (Якутия), Хангаласский район, село Тёхтюр	0101000020E61000000C1EA67DF32E60406022DE3AFFDA4E40
84810	4	34	255	8059	45650	\N	61.178711	Республика Саха (Якутия), Мегино-Кангаласский район, Доллунский наслег, с. Тумул, Школьная, 5		0101000020E6100000897E6DFDF4E15F40BD378600E0964E40
85159	4	34	255	8059	79465	\N	61.178711	Республика Саха (Якутия), Хангаласский район, Тумульский наслег, с.Тумул, Семилетка, 12		0101000020E6100000897E6DFDF4E15F40BD378600E0964E40
85181	4	34	255	32527	45393	\N	61.483020000000003	Республика Саха (Якутия), Хангаласский район, Жемконский 1-й наслег, с.Тит-Эбэ, Жданова, 19		0101000020E6100000855B3E92122A60402FA86F99D3BD4E40
85102	4	34	255	32663	\N	\N	61.223410999999999	Республика Саха (Якутия), Усть-Алданский район, Тит-Арынский наслег, с. Тит-Ары, Алексея Егорова, 10	Россия, Республика Саха (Якутия), Хангаласский район, село Тит-Ары	0101000020E61000002CF015DD7AEE5F4088484DBB989C4E40
85146	4	34	7540	61857	\N	\N	69.324657777690106	Усть-Янский район, Уяндинский национальный наслег, с. Уянди, нет улиц, д. 35	Россия	0101000020E6100000BDFF8F13A69D6140A0185932C7545140
85160	4	34	255	32663	45589	\N	61.223990341689202	Республика Саха (Якутия), Хангаласский район, Тит-Арынский наслег, с.Тит-Арыы, Центральная, 46	Россия, Республика Саха (Якутия), Хангаласский район, село Тит-Ары	0101000020E6100000CBBDC0AC50EE5F40C6504EB4AB9C4E40
85179	4	34	255	55543	45613	\N	61.7121773661666	Республика Саха (Якутия), Хангаласский район, Техтюрский наслег, с.Техтюр, Каландрашвили, 11	Россия, Республика Саха (Якутия), Хангаласский район, село Тёхтюр	0101000020E6100000487023650B2F604050FBAD9D28DB4E40
85158	4	34	255	8043	45403	\N	61.132826999999999	Республика Саха (Якутия), Хангаласский район, Синский наслег, с.Синск, Орджоникидзе, 40		0101000020E61000006FB9FAB149B55F404D83A27900914E40
85171	4	34	255	8642	45462	\N	61.48659	Республика Саха (Якутия), Хангаласский район, Город Покровск, мкр Кыл-Бастах, Южная, 6	Россия, Республика Саха (Якутия), Хангаласский район, поселок городского типа Покровск	0101000020E6100000992A1895D4246040C347C49448BE4E40
85173	4	34	255	8642	45283	\N	61.48659	Республика Саха (Якутия), Хангаласский район, Город Покровск, Орджоникидзе, 52		0101000020E6100000992A1895D4246040C347C49448BE4E40
85170	4	34	255	55350	45610	\N	61.488151206501797	Республика Саха (Якутия), Хангаласский район, Город Покровск, мкр Звероферма, Центральная, 7	Россия, Республика Саха (Якутия), Хангаласский район, поселок городского типа Покровск	0101000020E6100000F20BAF24F92460403E4162BB7BBE4E40
85172	4	34	255	55350	45216	\N	61.488395482368603	Республика Саха (Якутия), Хангаласский район, Город Покровск, мкр Кирзавод, Б.Ксенофонтова, 106	Россия, Республика Саха (Якутия), Хангаласский район, поселок городского типа Покровск	0101000020E6100000DD990986F3246040D44334BA83BE4E40
85178	4	34	255	9009	45286	\N	61.674929961943597	Республика Саха (Якутия), Хангаласский район, Октёмский наслег, с.Октемцы, Е.Андреева, 1	Россия, Республика Саха (Якутия), Хангаласский район, село Октёмцы	0101000020E6100000060FD3BEB92D60406E8B321B64D64E40
85175	4	34	255	55361	45258	\N	61.542874271897702	Республика Саха (Якутия), Хангаласский район, Немюгинский наслег, с.Ой, Ленина, 65	Россия, Республика Саха (Якутия), Хангаласский район, село Ой	0101000020E6100000215A2BDA9C256040A2EC2DE57CC54E40
85169	4	34	255	8545	45336	\N	61.397123999999998	Республика Саха (Якутия), Хангаласский район, Поселок Мохсоголлох, Комсомольская, 12		0101000020E6100000A31EA2D11D1E6040753A90F5D4B24E40
85168	4	34	255	8545	45212	\N	61.397123999999998	Республика Саха (Якутия), Хангаласский район, Поселок Мохсоголлох, Заводская, 11		0101000020E6100000A31EA2D11D1E6040753A90F5D4B24E40
85182	4	34	255	32537	45382	\N	61.430612000000004	Республика Саха (Якутия), Хангаласский район, Жемконский 2-й наслег, с.Кердем, Школьная, 14		0101000020E6100000CB694FC939266040F1A1444B1EB74E40
85156	4	34	255	33037	45708	\N	60.9674236934951	Республика Саха (Якутия), Хангаласский район, Мальжагарский 5-й наслег, с.Кытыл-Дюра, ул.И.Никифорова, 26/2	Россия, Республика Саха (Якутия), Хангаласский район, село Кытыл-Дюра	0101000020E6100000899AE8F3517B5F40C9AEB48CD47B4E40
85164	4	34	255	61683	79560	\N	61.239189069980199	Республика Саха (Якутия), Хангаласский район, Мальжагарский 1-й наслег, с.Кытанах-Кырдал, Центральная, 4	Россия, Республика Саха (Якутия), Хангаласский район, село Кытанах-Кырдал (Тойон-Ары)	0101000020E6100000C0779B374E0C60400F48C2BE9D9E4E40
85183	4	34	255	9223	45611	\N	61.359543000000002	Республика Саха (Якутия), Хангаласский район, Качикатский наслег, с.Кысыл-Юрюйя, Ларионова, 31		0101000020E610000088BCE5EAC7206040BC40498105AE4E40
85185	4	34	255	9227	\N	\N	61.319321000000002	Республика Саха (Якутия), Хангаласский район, Качикатский наслег, с.ДРСУ, ДРСУ, б/н	Россия, Республика Саха (Якутия), Хангаласский район, село Качикатцы	0101000020E6100000F6B704E01F1E604088F6B182DFA84E40
85184	4	34	255	9227	45490	\N	61.319321000000002	Республика Саха (Якутия), Хангаласский район, Качикатский наслег, с.Качикатцы, Ленина, 14		0101000020E6100000F6B704E01F1E604088F6B182DFA84E40
85155	4	34	255	7895	45585	\N	60.811582999999999	Республика Саха (Якутия), Хангаласский район, Иситский наслег, с.Исит, Юбилейная, 53		0101000020E6100000D11E2FA4C3545F40AA7EA5F3E1674E40
85157	4	34	255	29555	45680	\N	61.105085000000003	Республика Саха (Якутия), Хангаласский район, Мальжагарский 4-й наслег, с.Едяй, Октябрьская, 16		0101000020E6100000684128EFE3975F406C26DF6C738D4E40
85163	4	34	255	14110	45335	\N	61.300403000000003	Республика Саха (Якутия), Хангаласский район, Мальжагарский 1-й наслег, с.Булгунняхтах, Советская, 78		0101000020E61000006D8D08C641156040664F029B73A64E40
85166	4	34	255	55349	45211	\N	61.363160999999998	Республика Саха (Якутия), Хангаласский район, Бестяхский наслег, с.Бестях, Новая, 15		0101000020E61000005EF23FF9BB1B60406117450F7CAE4E40
84724	4	34	255	55349	79490	\N	61.365674265317999	Республика Саха (Якутия), Жиганский район, Бестяхский наслег, н.Бестях, Нагорная, 4		0101000020E61000009DA1B8E3CD1B6040AE7FD767CEAE4E40
84750	4	34	255	20228	79380	\N	61.134442999999997	Республика Саха (Якутия), Кобяйский район, Кировский наслег, с. Батамай, Семенова, 12		0101000020E61000002592E86514D65F408B16A06D35914E40
85149	4	34	7540	61853	79773	\N	70.813019400000002	Усть-Янский район, Омолойский национальный наслег, с. Хайыр, ул. Иннокентия Барабанского, д. 7	Россия	0101000020E61000006DE34F5436B06040B401D88008B45140
85144	4	34	7540	61854	79774	\N	69.603382931980093	Усть-Янский район, Силянняхский национальный наслег, с. Сайылык, ул. Набережная, д. 4	Россия	0101000020E6100000F0A485CBAA87604097FDBAD39D665140
85151	4	34	7540	61852	79772	\N	70.753136950926802	Усть-Янский район, Казачинский национальный наслег, с. Казачье, ул. Барона Толля, д. 11	Россия	0101000020E610000047CCECF398076140151A886533B05140
85152	4	34	7540	61858	79776	\N	70.913104399999995	Усть-Янский район, Усть-Янский национальный наслег, с. Усть-Янск, ул. Мира, д. 1	Россия	0101000020E6100000685E0EBB6F0E61403276C24B70BA5140
85153	4	34	7540	61856	\N	\N	70.729776425216301	Усть-Янский район, Туматский национальный наслег, с. Тумат, нет улиц, д. 61	Россия	0101000020E6100000CE5147C755676140F75965A6B4AE5140
85148	4	34	7540	61859	79777	\N	70.002455400000002	Усть-Янский район, Поселок Усть-Куйга, ул. 50 лет Октября, 11	Россия	0101000020E610000093C5FD47A6F160408C2D043928805140
85147	4	34	7540	61859	79777	\N	69.972909721187904	Усть-Янский район, Поселок Усть-Куйга, ул. 50 лет Октября, д. 11	Россия	0101000020E61000005B25581CCEF56040E3FC4D28447E5140
85150	4	34	7540	61860	79778	\N	71.441389400000006	Усть-Янский район, Поселок Нижнеянск, ул. Молодежная, д. 5	Россия	0101000020E61000002C9D0FCF920461401BF4A5B73FDC5140
85145	4	34	7540	61855	79775	\N	69.313590700000006	Усть-Янский район, Поселок Депутатский, м-н Арктика, д. 17	Россия	0101000020E6100000F9DB9E20317F61407A54FCDF11545140
85134	4	34	7334	54723	38904	\N	60.478660038701598	Республика Саха (Якутия), Усть-Майский район, Эжанский национальный наслег, А.Иванова, 4	Россия	0101000020E6100000CE4F711C78E56040A1F31ABB443D4E40
85129	4	34	7334	55588	45686	\N	60.346560288313398	Республика Саха (Якутия), Усть-Майский район, с. Троицк, Мирушниченко, 13А	Россия	0101000020E61000008978EBFCDBCE6040060DFD135C2C4E40
85128	4	34	7334	61753	79635	\N	59.641106636548201	Республика Саха (Якутия), Усть-Майский район, Село Усть-Миль, Лесная, 15	Россия	0101000020E6100000A5F5B704E0A260404B1E4FCB0FD24D40
85142	4	34	7334	61692	79570	\N	59.756681661702302	Республика Саха (Якутия), Усть-Майский район, Поселок Югорёнок, Ленина, 10	Россия	0101000020E6100000A435069D1036614066BCADF4DAE04D40
85136	4	34	7334	61849	79769	\N	60.799970100000003	Республика Саха (Якутия), Усть-Майский район, Поселок Эльдикан, п. Новый Эльдикан, Промплощадка, 5	Россия	0101000020E610000090BC7328C3E56040FCE3BD6A65664E40
85139	4	34	7334	55504	45562	\N	60.294455732127403	Республика Саха (Якутия), Усть-Майский район, Поселок Солнечный, Октябрьская, 2		0101000020E61000000762D9CC21316140340EF5BBB0254E40
85140	4	34	7334	61613	79481	\N	60.482387686854999	Республика Саха (Якутия), Усть-Майский район, Поселок Звездочка, Дражников, 9	Россия	0101000020E610000002D369DD86346140CEFDD5E3BE3D4E40
85125	4	34	240	55135	43251	\N	63.2035903053808	Республика Саха (Якутия), Усть-Алданский район, Чериктейский наслег, с.Чериктей, Айхал, 13	Россия	0101000020E6100000C1E270E65761604075E5B33C0F9A4F40
85112	4	34	240	32751	45643	\N	62.621355999999999	Республика Саха (Якутия), Усть-Алданский район, Борогонский наслег, с.Элэсин, Сынахская, 2		0101000020E6100000A2EF6E65095160403196E997884F4F40
85095	4	34	240	61628	79502	\N	62.522416999999997	Республика Саха (Якутия), Усть-Алданский район, Хоринский 1-й наслег, с. Чаран, Героя Бурцева, 42	Россия, Республика Саха (Якутия), Усть-Алданский район	0101000020E6100000425BCEA5B84F6040EDEF6C8FDE424F40
85109	4	34	240	5597	45617	\N	62.469624333045303	Республика Саха (Якутия), Усть-Алданский район, Суоттунский наслег, с.Хоногор, Тимофея Татаринова, 19	Россия, Республика Саха (Якутия), Усть-Алданский район, село Хоногор	0101000020E610000082E2C798BB43604057B5A4A31C3C4F40
85114	4	34	240	55586	45683	\N	62.520354745686902	Республика Саха (Якутия), Усть-Алданский район, Легёйский наслег, с.Хомустах, Ивана Бурнашева, 19	Россия, Республика Саха (Якутия), Усть-Алданский район	0101000020E6100000F65CA626414F6040B1A71DFE9A424F40
85098	4	34	240	55429	45437	\N	62.8725100793528	Республика Саха (Якутия), Усть-Алданский район, Курбусахский наслег, с. Ус-Кюель, Героя Егорова, 17	Россия	0101000020E6100000FB5B02F04F5A60406BB75D68AE6F4F40
85138	4	34	240	5721	45586	\N	62.555824999999999	Республика Саха (Якутия), Усть-Майский район, Кюпский национальный наслег, с. Тумул, Ноторская, 12		0101000020E61000008524B37A074960404CA60A4625474F40
84885	4	34	240	5721	45372	\N	62.555824999999999	Республика Саха (Якутия), Намский район, Модутский наслег,с,Тумул, Аммосова, 35		0101000020E61000008524B37A074960404CA60A4625474F40
85101	4	34	240	61632	79506	\N	62.647476171715802	Республика Саха (Якутия), Усть-Алданский район, Баягантайский наслег, с.Танда, Андросова, 21/1		0101000020E61000004A9A3FA6B57F6040F2785A7EE0524F40
85100	4	34	240	5119	45495	\N	62.560810909142702	Республика Саха (Якутия), Усть-Алданский район, Берт-Усовский наслег, с. Сырдах, Елизаветы Бурцевой, 11	Россия, Республика Саха (Якутия), Усть-Алданский район, село Сырдах	0101000020E6100000D15AD1E6385C6040581EA4A7C8474F40
85110	4	34	240	5668	45614	\N	62.476415238980998	Республика Саха (Якутия), Усть-Алданский район, Суоттунский наслег, с.Сасылыкан, Остойкинская, 2	Россия, Республика Саха (Якутия), Усть-Алданский район, село Сасылыкан	0101000020E6100000A3073E06AB5460407429AE2AFB3C4F40
85108	4	34	240	5589	45405	\N	62.449593999999998	Республика Саха (Якутия), Усть-Алданский район, Суоттунский наслег, с.Огородтах, Анатолия Константинова, 5		0101000020E61000009981CAF877446040293DD34B8C394F40
85122	4	34	240	55524	45583	\N	63.1290995542955	Республика Саха (Якутия), Усть-Алданский район, Дюпсюнский наслег, с.Бээди, Центральная, 10	Россия	0101000020E610000038F4160F6F576040F1F44A5986904F40
85097	4	34	240	55553	45627	\N	60.647652036288299	Республика Саха (Якутия), Усть-Алданский район, Курбусахский наслег, с. Балаганнах, Михаила Николаева, 5		0101000020E61000005F43705CC64C5E403198BF42E6524E40
84746	4	34	240	5493	\N	\N	62.450830000000003	Республика Саха (Якутия), Кобяйский район, Люччегинский 1-й наслег, с. Арылах, Яковлева, 7	Россия, Республика Саха (Якутия), Усть-Алданский район, село Арылах	0101000020E61000009204E10A285E6040210725CCB4394F40
84836	4	34	240	5493	45311	\N	62.450830000000003	Республика Саха (Якутия), Мирнинский район, Чуонинский наслег, п. Арылах, Центральная, 53		0101000020E61000009204E10A285E6040210725CCB4394F40
85194	4	34	240	5493	79470	\N	62.450830000000003	Республика Саха (Якутия), Чурапчинский район, Арылахский наслег, с. Арылах, Комсомольская, 13		0101000020E61000009204E10A285E6040210725CCB4394F40
85026	4	34	240	5493	78667	\N	62.450830000000003	Республика Саха (Якутия), Сунтарский район, Тюбяй-Жарханский наслег, с.Тюбяй-Жархан, Зверева, 33	Россия, Республика Саха (Якутия), Усть-Алданский район, село Арылах	0101000020E61000009204E10A285E6040210725CCB4394F40
85107	4	34	240	5493	45706	\N	62.450830000000003	Республика Саха (Якутия), Усть-Алданский район, Ольтёхский наслег, с.Арылах, Данилова, 12		0101000020E61000009204E10A285E6040210725CCB4394F40
85113	4	34	240	5230	45718	\N	62.509489000000002	Республика Саха (Якутия), Усть-Алданский район, Борогонский наслег, с.Ары-Тит, Аржакова, 5		0101000020E61000004391EEE794416040FC5580EF36414F40
85081	4	34	7371	61671	79548	\N	62.785307680752702	Республика Саха (Якутия), Томпонский район, Теплоключевский наслег, с.Теплый Ключ, Советская, 6	Россия	0101000020E6100000EFA99CF694196140C2A4F8F884644F40
85089	4	34	7371	61840	79760	\N	61.875050000000002	Республика Саха (Якутия), Томпонский район, Охот-Перевозовский наслег, с.Охотский Перевоз, Советская, 15	Россия	0101000020E6100000F73B1405FAF06040B22E6EA301F04E40
85080	4	34	7371	61833	79751	\N	62.653607899999997	Республика Саха (Якутия), Томпонский район, Сасыльский наслег, с.Кескил, Петра Алексеева, 11	Россия	0101000020E610000093196F2B3DE06040B5334C6DA9534F40
85082	4	34	7371	61685	79562	\N	62.775106000000001	Республика Саха (Якутия), Томпонский район, Теплоключевский наслег, н.п.Аэропорт, Авиационная	Россия	0101000020E6100000FA7E6ABCF4196140797764AC36634F40
85088	4	34	7371	55596	45696	\N	62.937037997956899	Республика Саха (Якутия), Томпонский район, Баягантайский наслег, с.Ударник, Феклы Павловой, 19		0101000020E6100000AB7AF99DA6CD6040FC8D76DCF0774F40
85079	4	34	7371	61667	79544	\N	62.604191894838401	Республика Саха (Якутия), Томпонский район, Ынгинский наслег, с.Сайды, Амгинская, 14	Россия	0101000020E6100000B8955E9B0DEF60409E40D829564D4F40
85078	4	34	7371	61748	79630	\N	62.588032375885398	Республика Саха (Якутия), Томпонский район, Ынгинский наслег, с.Новый, Центральная, 6		0101000020E6100000185A9D9CA1F060403080F0A1444B4F40
85086	4	34	7371	55483	45533	\N	62.812262469127297	Республика Саха (Якутия), Томпонский район, Баягантайский наслег, с.Крест-Хальджай, Центральная, 27		0101000020E6100000342C465D6BD060404BE48233F8674F40
85059	4	34	7366	61665	79542	\N	62.631914500000001	Республика Саха (Якутия), Таттинский район, Уолбинский наслег, с. Уолба, И.Слепцова, 18	Россия	0101000020E61000004F5C8E5720B36040096D3997E2504F40
85062	4	34	7366	55590	45688	\N	61.730492894478701	Республика Саха (Якутия), Таттинский район, Жулейский наслег, с. Туора-Кюель, Табахырова, 23	Россия	0101000020E6100000F25CDF87837D60407D7A6CCB80DD4E40
85058	4	34	7366	55449	45480	\N	63.012657467377302	Республика Саха (Якутия), Таттинский район, Алданский наслег, с. Усть-Татта, А.Данилова, 1	Россия	0101000020E6100000840CE4D9E5AC604061889CBE9E814F40
85065	4	34	7366	55456	45494	\N	62.1189480026054	Республика Саха (Якутия), Таттинский район, Тыарасинский наслег, с. Кыйы, Сабарайкина, 39	Россия	0101000020E610000099D3653131A060405AF624B0390F4F40
85066	4	34	7366	61577	79427	\N	61.907733481242403	Республика Саха (Якутия), Таттинский район, Дайа-Амгинский наслег, с. Дайа-Амга, Кашкина, 4	Россия	0101000020E6100000C828CFBC1CB46040FF3F4E9830F44E40
85063	4	34	7366	55413	45400	\N	62.272812825231497	Республика Саха (Якутия), Таттинский район, Жохсогонский наслег, с.Боробул, Кулаковского, 34/2	Россия	0101000020E61000004A46CEC21EAE60403A765089EB224F40
85035	4	34	7367	61697	79576	\N	62.024943158859799	Республика Саха (Якутия), Сунтарский район, Кемпендяйский наслег, с.Кемпендяй, школьная, 9	Россия	0101000020E61000007555A01683A55D40CFA10C5531034F40
85039	4	34	7367	55414	45402	\N	62.141081895884	Республика Саха (Якутия), Сунтарский район, Сунтарский наслег, с.Сунтар, Октябрьская, 59	Россия	0101000020E61000008065A54929695D40F20698F90E124F40
85042	4	34	7316	55427	45431	\N	62.164935727476397	Республика Саха (Якутия), Сунтарский район, Сунтарский наслег, с.Сунтар, Ленина, 79	Россия	0101000020E6100000BF654E97C56A5D406EF7729F1C154F40
85034	4	34	7316	61839	79758	\N	62.346660499999999	Республика Саха (Якутия), Сунтарский район, Кюндяйинский наслег, с.Кюндяя, Юбилейная, 46	Россия	0101000020E6100000D07F0F5EBB6C5D406A6AD95A5F2C4F40
85053	4	34	7316	61686	79563	\N	62.098091935875999	Республика Саха (Якутия), Сунтарский район, Куокунинский наслег, с.Куокуну, Октябрьская, 42	Россия	0101000020E610000055FB743C660E5D40E7FF55478E0C4F40
85048	4	34	7316	61846	79766	\N	62.232871509236197	Республика Саха (Якутия), Сунтарский район, Аллагинский наслег, с.Аллага, Кузнецкая, 39	Россия	0101000020E610000048E2E5E95C435D40BA13ECBFCE1D4F40
85032	4	34	7316	55417	45411	\N	62.485587039463603	Республика Саха (Якутия), Сунтарский район, Эльгяйский наслег, с.Эльгяй, Сивцева, 38		0101000020E6100000AF264F594D5F5D406F2EFEB6273E4F40
85056	4	34	7316	61659	79535	\N	62.607014258421302	Республика Саха (Якутия), Сунтарский район, Вилючанский наслег, с.Вилючан, Ленина, 36	Россия	0101000020E6100000B9A81611C5EA5C40691B7FA2B24D4F40
85044	4	34	7316	55546	45619	\N	62.157871	Республика Саха (Якутия), Сунтарский район, Хаданский наслег, с.Хадан, Кэскил, 18		0101000020E610000063EFC517ED685D4050FEEE1D35144F40
85051	4	34	7316	61781	79668	\N	62.286289500000002	Республика Саха (Якутия), Сунтарский район, Арылахский наслег, с.Усун-Кель, Кокорина, 1	Россия	0101000020E610000041B62C5F97365D40FF959526A5244F40
85036	4	34	7316	61616	79485	\N	62.163024999999998	Республика Саха (Якутия), Сунтарский район, Устьинский наслег, с.Устье, геодезическая, 4		0101000020E6100000E71890BDDE6F5D4017B7D100DE144F40
85027	4	34	7316	55555	45629	\N	62.886537176387499	Республика Саха (Якутия), Сунтарский район, Тюбяйский наслег, с.Тюбяй, Хаппар, 2		0101000020E6100000466117450F5F5D40D3D85E0B7A714F40
85043	4	34	7316	61727	79607	\N	62.023263536999004	Республика Саха (Якутия), Сунтарский район, Туойдахский наслег. с.Туойдах, Ананьева, 38		0101000020E6100000593332C85D6E5D404A969350FA024F40
85031	4	34	7316	61666	79543	\N	62.581236251847599	Республика Саха (Якутия), Сунтарский район, Толонский наслег, с.Толон, Центральная, 37	Россия	0101000020E6100000AF05BD37865F5D4001A1F5F0654A4F40
85047	4	34	7316	54267	35832	\N	62.001941029170503	Республика Саха (Якутия), Сунтарский район, Тенкинский наслег, с.Тенькя, Федорова, 10	Россия	0101000020E6100000684293C492255D40C2C2499A3F004F40
85029	4	34	7316	55591	45689	\N	62.777053775179098	Республика Саха (Якутия), Сунтарский район, Кюкяйский наслег, с.Кюкяй, Самсонова, 17	Россия	0101000020E6100000685E0EBBEF6D5D40ED9C668176634F40
85054	4	34	7316	61751	79633	\N	60.8777661575241	Республика Саха (Якутия), Сунтарский район, Крестяхский наслег, с.Крестях, Советская, 26	Россия, Республика Саха (Якутия), Хангаласский район	0101000020E610000085CC9541B5695F4037C5E3A25A704E40
85045	4	34	7316	54707	38889	\N	62.0204974357693	Республика Саха (Якутия), Сунтарский район, Илимнирский наслег, с.Илимнир, Сунтарская, 20	Россия	0101000020E61000005BD07B63085B5D4043554CA59F024F40
85046	4	34	7316	55407	45391	\N	62.646779488886999	Республика Саха (Якутия), Сунтарский район, Бордонский наслег, с.Бордон, Мира, 45	Россия	0101000020E61000008C6A11514C595D40AB5E7EA7C9524F40
85021	4	34	7537	61718	79598	\N	68.397617999999994	Республика Саха (Якутия), Среднеколымский район, с.Эбях, Молодежная, 3	Россия	0101000020E61000000E30F31DFCD762404293C49272195140
85017	4	34	7537	61745	79626	\N	68.438003247449302	Республика Саха (Якутия), Среднеколымский район, с.Аргахтах, 40 лет Победы, 6	Россия	0101000020E61000007FDFBF79712863403123BC3D081C5140
85022	4	34	7537	61691	79569	\N	67.843276989225004	Республика Саха (Якутия), Среднеколымский район, с.Сылгы-Ытар, Чукрова, 29	Россия	0101000020E6100000B821C66B5E5A6340041E1840F8F55040
85020	4	34	7537	61714	79594	\N	68.682741238132706	Республика Саха (Якутия), Среднеколымский район, с.Алеко-Кюель, Молодежная, 3	Россия	0101000020E6100000635E471C32FC6240DAA84E07B22B5140
85011	4	34	7362	55385	45354	\N	68.514971194053501	Республика Саха (Якутия), Оленекский район, Оленекский наслег, с.Оленек, Октябрьская, 64		0101000020E61000009599D2FA5B1D5C40DCD8EC48F5205140
85013	4	34	7362	55501	45559	\N	70.142318314737196	Республика Саха (Якутия), Оленекский район, Жилиндинский наслег, с.Жилинда, Октябрьская, 20	Россия	0101000020E6100000643DB5FAEA7E5C4075E8F4BC1B895140
84987	4	34	200	55499	45556	\N	60.401857649849603	Республика Саха (Якутия), Олекминский район, Мальжагарский наслег, село Юнкюр, 60 лет Октября, 15		0101000020E610000027BF45274B135E4067D13B1570334E40
84982	4	34	200	54262	35829	\N	60.303315985054802	Республика Саха (Якутия), Олекминский район, Абагинский наслег, село Центральная Абага, Карла Миллера, 3	Россия	0101000020E610000076E272BC02005E40412D060FD3264E40
84990	4	34	200	61789	79681	\N	60.671134982080197	Республика Саха (Якутия), Олекминский район, Хоринский наслег, село Хоринцы, Центральная, 12	Россия	0101000020E6100000E202D0285D5B5E40B9196EC0E7554E40
84991	4	34	200	55526	45587	\N	60.570032763731497	Республика Саха (Якутия), Олекминский район, Урицкий наслег, село Урицкое, Центральная, 3а		0101000020E6100000CA1649BBD1995E40055262D7F6484E40
84996	4	34	200	61622	79495	\N	60.511059000000003	Республика Саха (Якутия), Олекминский район, Жарханский национальный наслег, село Уолбут, пер.Школьный, 8	Россия, Республика Саха (Якутия), Олекминский район	0101000020E61000007AFCDEA63F7F5F40CAA99D616A414E40
84986	4	34	200	61784	79672	\N	60.429786	Республика Саха (Якутия), Олекминский район, Улахан-Мунгкунский наслег, село Улахан-Мунгку, Верхняя, 2	Россия	0101000020E610000089B7CEBF5D0E5E40AB23473A03374E40
84999	4	34	200	61836	79754	\N	59.056269800000003	Республика Саха (Якутия), Олекминский район, Тянский национальный наслег, село Тяня, Алеши Алексеева, 8	Россия	0101000020E610000021E7FD7F9CF25D407ADFF8DA33874D40
84988	4	34	200	61681	79558	\N	60.340653781933	Республика Саха (Якутия), Олекминский район, Троицкий наслег, село Троицк, Центральная, 1/1	Россия	0101000020E610000055320054F1CE604034A0DE8C9A2B4E40
84995	4	34	200	54724	38905	\N	59.980638143015099	Республика Саха (Якутия), Олекминский район, Жарханский национальный наслег, село Токко, Ойунского, 9	Россия	0101000020E6100000FCA71B28F0F55D40809BC58B85FD4D40
84989	4	34	200	61678	79555	\N	60.480472125174501	Республика Саха (Якутия), Олекминский район, Солянский наслег, село Солянка, Советская, 61		0101000020E610000023F3C81F0C2E5E406552431B803D4E40
85008	4	34	200	61668	\N	\N	60.386295421245599	Республика Саха (Якутия), Олекминский район, Город Олёкминск, село Селиваново	Россия	0101000020E6100000B03C484F911E5E40DDCD531D72314E40
84993	4	34	200	31751	45675	\N	60.585597	Республика Саха (Якутия), Олекминский район, Саныяхтахский наслег, село Саныяхтах, Гагарина, 17		0101000020E6100000B7EBA52902045F405FD1ADD7F44A4E40
85003	4	34	200	54730	45197	\N	60.379769556282902	Республика Саха (Якутия), Олекминский район, Город Олёкминск, Урицкого, 2	Россия	0101000020E6100000F6622827DA1A5E403F00A94D9C304E40
85007	4	34	200	54730	38910	\N	60.377391767725904	Республика Саха (Якутия), Олекминский район, Город Олёкминск, Тахватулина, 37а	Россия	0101000020E61000007C2C7DE8821B5E40D2E28C614E304E40
84979	4	34	200	61757	79640	\N	60.264800999999999	Республика Саха (Якутия), Олекминский район, Нерюктяйинский 2-й наслег, село 2-Нерюктяйинск, Центральная, 22		0101000020E61000004BAC8C463EF95D405B79C9FFE4214E40
84992	4	34	200	55565	45647	\N	60.607663291958701	Республика Саха (Якутия), Олекминский район, Саныяхтахский наслег, село Марха, Лесная, 6		0101000020E6100000EC504D49D6D35E40A0FEB3E6C74D4E40
84994	4	34	200	31756	45673	\N	60.684258999999997	Республика Саха (Якутия), Олекминский район, Саныяхтахский наслег, село Малыкан, Лесная, 3		0101000020E6100000BE4BA94BC62E5F40307F85CC95574E40
84984	4	34	200	61801	79704	\N	60.3406537819329	Республика Саха (Якутия), Олекминский район, Кяччинский наслег, село Кяччи, Центральная, 18	Россия	0101000020E61000007905A22765085E4034A0DE8C9A2B4E40
84980	4	34	200	55084	42073	\N	60.214483243388301	Республика Саха (Якутия), Олекминский район, Кыллахский наслег, село Кыллах, Майская, 21	Россия	0101000020E610000007D2C5A695FD5D402446CF2D741B4E40
84997	4	34	200	61803	79701	\N	60.502930768219002	Республика Саха (Якутия), Олекминский район, Киндигирский национальный наслег, село Куду-Кюель, Петра Карташова, 9	Россия, Республика Саха (Якутия), Олекминский район	0101000020E6100000C21550A8A7805F408192020B60404E40
84975	4	34	200	55533	45597	\N	59.7888383427725	Республика Саха (Якутия), Олекминский район, Дельгейский наслег, село Иннях, мкрн.Нижний, 21	Россия	0101000020E61000000726378AAC9D5D40C8EBC1A4F8E44D40
84976	4	34	200	61798	79695	\N	59.906253950733102	Республика Саха (Якутия), Олекминский район, Дельгейский наслег, село Дельгей, Центральная, 19		0101000020E6100000EF5696E82CA75D4041EF8D2100F44D40
84981	4	34	200	61779	79666	\N	60.511059000000003	Республика Саха (Якутия), Олекминский район, Кыллахский наслег, село Даппарай, Партизанская, 5	Россия, Республика Саха (Якутия), Олекминский район	0101000020E61000007AFCDEA63F7F5F40CAA99D616A414E40
84977	4	34	200	61609	79477	\N	60.124845258844999	Республика Саха (Якутия), Олекминский район, Дабанский наслег, село Дабан, Центральная, 7	Россия	0101000020E6100000C860C5A9D6CB5D40D908C4EBFA0F4E40
84964	4	34	7315	54716	\N	\N	63.3066406673694	Республика Саха (Якутия), Оймяконский район, Ючюгейский наслег, с. Ючюгей, Школа	Россия	0101000020E61000006DCA15DEE5C561406E4E250340A74F40
84969	4	34	7315	54725	\N	\N	63.472388653520902	Республика Саха (Якутия), Оймяконский район, Борогонский 1-й наслег, с. Хара-Тумул, Детский сад	Россия	0101000020E6100000DFBF797162D76140BDFE243E77BC4F40
84955	4	34	7315	55433	45695	\N	64.560056000000003	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, м-н Нерский, 61		0101000020E61000006D91B41BFDE661406EFB1EF5D7235040
84959	4	34	7315	55433	45656	\N	64.557693282255102	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, м-н Индигирский, здание ДРСУ-3	Россия	0101000020E61000006D91B41BFDE66140520DFB3DB1235040
84957	4	34	7315	55433	45444	\N	64.560056000000003	"Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Молодежная, 1  здание ОП ""Теплоэнергосервис"""		0101000020E61000006D91B41BFDE661406EFB1EF5D7235040
84962	4	34	7315	55433	45672	\N	64.551026007329497	"Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Ленина, 1  здание ДК ""Металлург"""	Россия	0101000020E61000000AD80E46ECE66140B94F8E0244235040
84961	4	34	7315	55433	45463	\N	64.560056000000003	"Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Коммунистическая, 15 здание   МУДО ""Пегас"""		0101000020E61000006D91B41BFDE661406EFB1EF5D7235040
84960	4	34	7315	55580	45671	\N	64.553980083243204	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Автотранспортная, 2   контора ЗЭС	Россия	0101000020E6100000018750A5E6E66140D6A8876874235040
84963	4	34	7315	61648	79523	\N	64.179770000000005	Республика Саха (Якутия), Оймяконский район, Поселок Артык, Центральная, 8  Дом культуры	Россия	0101000020E6100000664D2CF01524624053B3075A810B5040
84965	4	34	7315	55520	\N	\N	63.164516485007603	Республика Саха (Якутия), Оймяконский район, Сордоннохский наслег, с. Орто-Балаган, Школа		0101000020E6100000F33E8EE6C800624099D53BDC0E954F40
84967	4	34	7315	55507	\N	\N	63.456146747538298	Республика Саха (Якутия), Оймяконский район, Борогонский 1-й наслег, с. Оймякон, Школа		0101000020E6100000A702EE79FED8614092955F0663BA4F40
84971	4	34	7315	54263	\N	\N	63.248514158505003	Республика Саха (Якутия), Оймяконский район, Борогонский 2-й наслег, с. Куйдусун, РЭС	Россия	0101000020E61000001B84B9DD4BE76140904C874ECF9F4F40
84945	4	34	7368	61847	79767	\N	63.599966600000002	Республика Саха (Якутия), Нюрбинский район, Аканинский наслег, с. Акана, П.С. Егорова, 15	Россия	0101000020E6100000A818E76F42C65D40F1D6F9B7CBCC4F40
84951	4	34	7368	55606	45712	\N	63.645309781648301	Республика Саха (Якутия), Нюрбинский район, Мархинский наслег, с. Егольжа, Центральная, 29а	Россия	0101000020E61000001AC231CB9E915D4011E4A08499D24F40
84940	4	34	7368	55461	45505	\N	63.429575647489798	Республика Саха (Якутия), Нюрбинский район, Чаппангдинский наслег, с. Чаппанда, Аммосова, 1	Россия	0101000020E61000005E81E84999A65D40C092AB58FCB64F40
84935	4	34	7368	61848	79768	\N	63.334047602203597	Республика Саха (Якутия), Нюрбинский район, Сюлинский наслег, с. Сюльцы, Дмитрия Федорова, 10/1		0101000020E61000007DCA3159DC8F5D40A9A5B915C2AA4F40
84932	4	34	7368	55425	45426	\N	63.287787078289099	Республика Саха (Якутия), Нюрбинский район, Октябрьский наслег, с. Антоновка, Октябрьская, 25		0101000020E6100000207C28D192985D40639B5434D6A44F40
84952	4	34	7368	61631	79505	\N	63.590006000000002	Республика Саха (Якутия), Нюрбинский район, Мальжагарский наслег, с. Мальжагар, Ленина, 45	Россия	0101000020E610000050172994855E5D40CE380D5185CB4F40
84933	4	34	7368	61850	\N	\N	63.270806014262398	Республика Саха (Якутия), Нюрбинский район, Октябрьский наслег, Нефтебаза, Нефтебаза, 1	Россия	0101000020E6100000C6F99B5088A05D40C1C760C5A9A24F40
84942	4	34	7368	61663	79540	\N	63.5873499454502	Республика Саха (Якутия), Нюрбинский район, Таркайинский наслег, с. Киров, Револия Иванова, 41	Россия	0101000020E61000004A26A77686AC5D401EA7E8482ECB4F40
84937	4	34	7368	55558	45640	\N	63.178476791349901	Республика Саха (Якутия), Нюрбинский район, Кюндядинский наслег, с. Аранастах, Аранастахская, 20	Россия	0101000020E61000003C4ED1915C785D404A0B9755D8964F40
84921	4	34	7361	62081	81112	\N	69.059282625262398	Республика Саха (Якутия), Нижнеколымский район, Походский наслег, Набережная, 21	Россия	0101000020E6100000C1FEEBDCB42164405C8DEC4ACB435140
84917	4	34	7361	55380	45340	\N	68.741597936157007	Республика Саха (Якутия), Нижнеколымский район, Поселок Черский, ул.Октябрьская, 1		0101000020E6100000DFE2E13D872B6440DB317557762F5140
84899	4	34	6894	40346	9891	\N	56.660992	Республика Саха (Якутия), Нерюнгринский район, Город Нерюнгри, Карла Маркса, 8/2		0101000020E6100000E9B7AF03E72D5F407575C7629B544C40
84889	4	34	1301	55556	45630	\N	63.080525512513198	Республика Саха (Якутия), Намский район, Фрунзенский наслег,с.Фрунзе, Д.Потапова, 18	Россия	0101000020E61000002382717069386040253D0CAD4E8A4F40
84883	4	34	1301	57575	59514	\N	62.4772771329474	Республика Саха (Якутия), Намский район, Хатынг-Арынский наслег,с.Красная Деревня, Решетникова, 10	Россия, Республика Саха (Якутия), Намский район	0101000020E6100000ABE7A4F70D2360400611A969173D4F40
84881	4	34	1301	55612	45721	\N	62.728508327755002	Республика Саха (Якутия), Намский район, Хатынг-Арынский наслег,с.Аппаны, Лена, 22	Россия	0101000020E6100000630D17B9A7326040EB6F09C03F5D4F40
84863	4	34	1301	55465	45510	\N	62.454628423853102	Республика Саха (Якутия), Намский район, Едейский наслег,с.Ымыяхтаах, Центральная, 9	Россия, Республика Саха (Якутия), Намский район, село Ымыяхтах	0101000020E6100000AAD55757853C604046EC1340313A4F40
84871	4	34	1301	61649	79524	\N	62.482996	Республика Саха (Якутия), Намский район, Хомустахский 2-й наслег,с.Хатас, Леонтьева, 2	Россия, Республика Саха (Якутия), Намский район	0101000020E6100000BDA8DDAF02236040A60C1CD0D23D4F40
84891	4	34	1301	54260	35827	\N	63.355646083537401	Республика Саха (Якутия), Намский район, Арбынский наслег,с.Сыгыннах, Слепцова, 23	Россия	0101000020E6100000705E9CF8EA366040037AE1CE85AD4F40
84887	4	34	1301	61602	79469	\N	63.039404978855302	Республика Саха (Якутия), Намский район, Село Маймага, Н.Ф.Собакина, 19	Россия	0101000020E6100000F5F411F8C3306040422619390B854F40
84866	4	34	1301	25839	45491	\N	62.584591917903502	Республика Саха (Якутия), Намский район, Партизанский наслег,с.Партизан, Школьная, 23	Россия, Республика Саха (Якутия), Намский район, село Партизан	0101000020E61000003815A930B63860406AC020E9D34A4F40
84867	4	34	1301	55567	45652	\N	62.626682919593797	Республика Саха (Якутия), Намский район, Никольский наслег,с.Никольцы, Е.Протопопова, 30	Россия, Республика Саха (Якутия), Намский район, село Никольский	0101000020E61000005C548B88E2366040C6FA062637504F40
84878	4	34	1301	54203	45545	\N	62.708401447814097	Республика Саха (Якутия), Намский район, Ленский наслег,с.Намцы, Чернышевского, 36	Россия	0101000020E61000005C5837DE1D35604013BA4BE2AC5A4F40
84879	4	34	1301	54203	38903	\N	62.719369845239299	Республика Саха (Якутия), Намский район, Ленский наслег,с.Намцы, Ойунского, 2	Россия	0101000020E6100000506EDBF7283560409CDCEF50145C4F40
84876	4	34	1301	54203	45417	\N	62.710859054282501	Республика Саха (Якутия), Намский район, Ленский наслег,с.Намцы, И.Винокурова, 8	Россия	0101000020E6100000C6BFCFB8F03460409C887E6DFD5A4F40
84875	4	34	1301	55487	45537	\N	62.716533188013699	Республика Саха (Якутия), Намский район, Ленский наслег,с.Намцы, Ленина, 24	Россия	0101000020E6100000E48233F8FB3460409CC0745AB75B4F40
84870	4	34	1301	55521	45581	\N	62.735503600854599	Республика Саха (Якутия), Намский район, Искровский наслег,с.Кюрен Ат, Захара Винокурова, 4	Россия	0101000020E610000094BDA59C2F276040E109BDFE245E4F40
84865	4	34	1301	16869	79410	\N	62.532426999999998	Республика Саха (Якутия), Намский район, Хомустахский 1-й наслег,с.Кысыл-Сыр, Северная, 3	Россия, Республика Саха (Якутия), Намский район, село Кысыл-Сыр	0101000020E6100000E353008C67386040F240649126444F40
84686	4	34	1301	16869	45373	\N	62.5320330596101	"Республика Саха (Якутия), Вилюйский район, п. Кысыл-Сыр, Ленина, 12 ""в"""	Россия, Республика Саха (Якутия), Намский район, село Кысыл-Сыр	0101000020E61000004F594DD79338604046B247A819444F40
84685	4	34	1301	16869	45364	\N	62.532426999999998	Республика Саха (Якутия), Вилюйский район, п. Кысыл-Сыр, Интернациональная, 3		0101000020E6100000E353008C67386040F240649126444F40
94438	4	34	1301	16869	45451	\N	62.532426999999998	Республика Саха (Якутия), Вилюйский район, п. Кысыл-Сыр, Газовиков, 1		0101000020E6100000E353008C67386040F240649126444F40
84864	4	34	1301	16869	45448	\N	62.532426999999998	Республика Саха (Якутия), Намский район, Хомустахский 1-й наслег,с,Кысыл-Сыр, Аммосова, 76		0101000020E6100000E353008C67386040F240649126444F40
84873	4	34	1301	26078	45456	\N	62.658552999999998	Республика Саха (Якутия), Намский район, Хамагаттинский наслег,с.Крест-Кытыл, Охлопкова - Соттоя, 9		0101000020E61000008BFB8F4C8736604062D7F6764B544F40
84872	4	34	1301	26078	45456	\N	62.658861543393698	Республика Саха (Якутия), Намский район, Хамагаттинский наслег,с.Крест-Кытыл, Охлопкова - Соттоя, 7	Россия, Республика Саха (Якутия), Намский район, село Крест-Кытыл	0101000020E6100000B1DB679599366040E0490B9755544F40
84868	4	34	1301	25937	45703	\N	62.583540999999997	Республика Саха (Якутия), Намский район, Тастахский наслег,с.Ергелех, Аммосова, 3		0101000020E6100000DF701FB9B51B60400470B378B14A4F40
84882	4	34	1301	55489	45539	\N	62.773529063215001	Республика Саха (Якутия), Намский район, Хатынг-Арынский наслег,с.Графский Берег, Центральная, 18	Россия	0101000020E6100000D40AD3F71A346040F9C08EFF02634F40
84888	4	34	1301	61768	79651	\N	63.2931128284024	Республика Саха (Якутия), Намский район, Тюбинский наслег,с.Булус, Центральная, 34	Россия	0101000020E61000002E39EE940E2F604027840EBA84A54F40
84880	4	34	1301	55570	45655	\N	62.758227783330902	Республика Саха (Якутия), Намский район, Хатынг-Арынский наслег,с.Аппаны, Лена, 29		0101000020E6100000430070ECD9336040AC74779D0D614F40
84860	4	34	7336	61835	79753	\N	65.376949376192897	Республика Саха (Якутия), Момский район, Тебюлехский национальный наслег, с. Чумпу-Кытыл, Центральная, 31	Россия	0101000020E61000009013268CE6E46140A2D0B2EE1F585040
33350	4	41	1601	55685	46241	\N	48.551751000000003	пос. Николаевка, ул. Лазо, д. 40а		0101000020E6100000D1419770E8D860408544DAC69F464840
84857	4	34	7336	61581	\N	\N	66.433369649995996	Республика Саха (Якутия), Момский район, Момский национальный наслег, участок Суон-Тиит, 16	Россия	0101000020E6100000E57CB1F7E2E7614052448655BC9B5040
84859	4	34	7336	55519	45580	\N	66.259129866396805	Республика Саха (Якутия), Момский район, Соболохский национальный наслег, с. Соболох, Тихона Толомона, 25	Россия	0101000020E6100000575A46EA3DEA614066DAFE9595905040
84861	4	34	7336	55516	45578	\N	65.157324675147393	Республика Саха (Якутия), Момский район, Улахан-Чистайский национальный наслег, с. Сасыр, Н.И.Слепцова, 13	Россия	0101000020E6100000E12879750E636240F775E09C114A5040
84862	4	34	7336	55517	45579	\N	66.799146634952905	Республика Саха (Якутия), Момский район, Чыбагалахский национальный наслег, с. Кулун-Ельбют, М.Черемкина, 28		0101000020E610000010786000E1D76140946C753925B35040
84858	4	34	7336	54731	38911	\N	66.489324337052906	Республика Саха (Якутия), Момский район, Индигирский национальный наслег, с. Буор-Сысы, Кэскил, 41	Россия	0101000020E61000004C1AA37554E1614077499C15519F5040
84838	4	34	7352	61799	79694	\N	63.236286	Республика Саха (Якутия), Мирнинский район, Садынский национальный наслег, п. Сюльдюкар, Центральная, 9	Россия	0101000020E6100000CBF27519FE6F5C405740A19E3E9E4F40
84837	4	34	7352	61661	79538	\N	62.103835172400203	Республика Саха (Якутия), Мирнинский район, Чуонинский наслег, п. Заря, Иванова, 25	Россия	0101000020E61000009C36E334448B5C400F971C774A0D4F40
84844	4	34	7352	55437	45457	\N	52.004727000000003	Республика Саха (Якутия), Мирнинский район, Поселок Чернышевский, Энтузиастов, Кадетская школа-интернат		0101000020E6100000A13028D368F641404034F3E49A004A40
84850	4	34	7352	55490	45540	\N	66.409491276110202	Республика Саха (Якутия), Мирнинский район, Город Удачный, 50 лет ЯАССР, 7		0101000020E61000006C95607138145C406840BD19359A5040
84833	4	34	7352	55352	45223	\N	62.5325802832485	Республика Саха (Якутия), Мирнинский район, г.Мирный, Тихонова, 3	Россия	0101000020E61000007AC4E8B9857E5C407940D9942B444F40
84849	4	34	7352	55136	43252	\N	65.938507999999999	Республика Саха (Якутия), Мирнинский район, Поселок Айхал, Иванова, 4		0101000020E61000001CEBE2361ADF5B4033C2DB83107C5040
84794	4	34	496	61744	79625	\N	63.441892444941899	Республика Саха (Якутия), Мегино-Кангаласский район, Дойдунский наслег, с. Хапчагай, Центральная, 3	Россия	0101000020E6100000E1D4079277D55E40992EC4EA8FB84F40
85071	4	34	496	55379	45339	\N	61.677005999999999	Республика Саха (Якутия), Таттинский район, Таттинский наслег, с. Ытык-Кюель, Ойунского, 24		0101000020E6100000D8101C97F13F60400F99F221A8D64E40
84809	4	34	496	55512	45574	\N	61.732855801191398	Республика Саха (Якутия), Мегино-Кангаласский район, Ходоринский наслег, с. Чуйя, Скрябина, 22	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Чюйя	0101000020E6100000A0353FFED24B6040B456B439CEDD4E40
84804	4	34	496	32761	45649	\N	61.567715999999997	Республика Саха (Якутия), Мегино-Кангаласский район, Нахаринский 2-й наслег, с. Хочо, Советская, 2		0101000020E610000014EB54F99E5760403DB5FAEAAAC84E40
84818	4	34	496	23557	45496	\N	61.833579	Республика Саха (Якутия), Мегино-Кангаласский район, Хоробутский наслег, с. Хоробут, Сергучева, 4		0101000020E6100000C32973F30D586040F2D077B7B2EA4E40
85094	4	34	496	5873	\N	\N	61.840339	Республика Саха (Якутия), Усть-Алданский район, Мюрюнский наслег, с. Мындаба, Ленина, 25	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Хомустах	0101000020E61000004293C492723B6040D446753A90EB4E40
84643	4	34	496	5873	\N	\N	61.840339	Республика Саха (Якутия), Верхневилюйский район, Хомустахский наслег, с.Хомустах, Центральная, 1	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Хомустах	0101000020E61000004293C492723B6040D446753A90EB4E40
84944	4	34	496	5873	78657	\N	61.840339	Республика Саха (Якутия), Нюрбинский район, Хорулинский наслег, с. Хорула, Ленина, 46а	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Хомустах	0101000020E61000004293C492723B6040D446753A90EB4E40
84793	4	34	496	32666	45692	\N	61.542733468162197	Республика Саха (Якутия), Мегино-Кангаласский район, Тыллыминский 2-й наслег, с. Хатылыма, Лукина, 3	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Хатылыма	0101000020E6100000F46DC1525D3C6040E0BA624678C54E40
84817	4	34	496	23463	45359	\N	61.783987468044302	Республика Саха (Якутия), Мегино-Кангаласский район, Хаптагайский наслег, с. Хаптагай, Советская, 3	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Хаптагай	0101000020E6100000FC8BA031933960409DBE9EAF59E44E40
84661	4	34	496	55446	45470	\N	62.034329999999997	Республика Саха (Якутия), Верхоянский район, Табалахский наслег с.Улахан-Кюель, М-Потаповой, 13		0101000020E61000006494675E0E536040C6A2E9EC64044F40
84821	4	34	496	23662	45439	\N	62.192838000000002	Республика Саха (Якутия), Мегино-Кангаласский район, Тюнгюлюнский наслег, с. Тюнгюлю, Партизанская, 13		0101000020E6100000A0F99CBBDD56604089B663EAAE184F40
84970	4	34	496	2972	\N	\N	62.153173000000002	Республика Саха (Якутия), Оймяконский район, Борогонский 2-й наслег, с. Томтор, Школа		0101000020E61000002E910BCE60416040ABD0402C9B134F40
84798	4	34	496	2972	45660	\N	62.152169190755302	Республика Саха (Якутия), Мегино-Кангаласский район, Томторский наслег, с. Томтор, Пономарева, 10	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Томтор	0101000020E610000099620E828E416040863B17467A134F40
85060	4	34	496	2972	45486	\N	62.152143703244199	Республика Саха (Якутия), Таттинский район, Баягинский наслег, с. Томтор, Баягантайская, 23/2	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Томтор	0101000020E6100000A65EB7088C4160402D24607479134F40
84803	4	34	496	32752	45648	\N	61.3828900921404	Республика Саха (Якутия), Мегино-Кангаласский район, Нахаринский 1-й наслег, с. Телиги, Саввина, 6/1	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Телиги	0101000020E6100000C32CB4731A56604094FB1D8A02B14E40
84797	4	34	496	22565	\N	\N	62.222045000000001	Республика Саха (Якутия), Мегино-Кангаласский район, Арангасский наслег, с. Тарат, Ворошилова, 18	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Тарат	0101000020E6100000EACE13CFD9556040C39E76F86B1C4F40
84816	4	34	496	23407	45438	\N	61.664147	Республика Саха (Якутия), Мегино-Кангаласский район, Тарагайский наслег, с. Табага, Совхозная, 12	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Табага	0101000020E6100000D74B5304385E6040465ED6C402D54E40
84806	4	34	496	22997	45570	\N	61.923147	Республика Саха (Якутия), Мегино-Кангаласский район, Батаринский наслег, с. Сымах, Колесова, 18		0101000020E610000041D653ABAF5E604044334FAE29F64E40
84805	4	34	496	22808	45566	\N	61.905912000000001	Республика Саха (Якутия), Мегино-Кангаласский район, Мелдехсинский наслег, с. Суола, Птицына, 3		0101000020E6100000ED832C0B26526040E886A6ECF4F34E40
84802	4	34	496	22808	45567	\N	61.905912000000001	Республика Саха (Якутия), Мегино-Кангаласский район, Морукский наслег, с. Суола, Калинина, 19		0101000020E6100000ED832C0B26526040E886A6ECF4F34E40
84808	4	34	496	32801	45637	\N	61.676029	Республика Саха (Якутия), Мегино-Кангаласский район, Рассолодинский наслег, с. Россолода, Петрова-Халлааскы, 9		0101000020E6100000637C98BDEC346040E412471E88D64E40
84819	4	34	496	23563	45375	\N	61.726191	Республика Саха (Якутия), Мегино-Кангаласский район, Харанский наслег, с. Петровка, Харанская, 11/1	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Петровка	0101000020E6100000D80C70413648604024D3A1D3F3DC4E40
84791	4	34	496	22306	45170	\N	61.875419000000001	Республика Саха (Якутия), Мегино-Кангаласский район, Нерюктяйинский наслег, с. Павловск, Молодежная, 4		0101000020E6100000F0FD0DDA2B3B604005A6D3BA0DF04E40
84789	4	34	496	55375	45309	\N	61.959606999999998	Республика Саха (Якутия), Мегино-Кангаласский район, Поселок Нижний Бестях, Ленина, 37		0101000020E61000008A3E1F65443D60409F01F566D4FA4E40
84790	4	34	496	18838	45300	\N	61.957263223502501	Республика Саха (Якутия), Мегино-Кангаласский район, Поселок Нижний Бестях, Ленина, 107	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, поселок городского типа Нижний Бестях	0101000020E6100000632AFD84333D6040DE550F9887FA4E40
84807	4	34	496	22998	45568	\N	62.356822999999999	Республика Саха (Якутия), Мегино-Кангаласский район, Мегюренский наслег, с. Матта, Механизаторов		0101000020E61000001BBD1AA0B4546040F5BA4560AC2D4F40
84787	4	34	496	22074	45306	\N	61.734963999999998	Республика Саха (Якутия), Мегино-Кангаласский район, Село Майя, Манчаары, 11		0101000020E6100000BC07E8BE1C49604061DEE34C13DE4E40
84788	4	34	496	22074	45175	\N	61.734963999999998	Республика Саха (Якутия), Мегино-Кангаласский район, Село Майя, Майинская, 13		0101000020E6100000BC07E8BE1C49604061DEE34C13DE4E40
84786	4	34	496	22074	45172	\N	61.734963999999998	Республика Саха (Якутия), Мегино-Кангаласский район, Село Майя, Героя Попова, 51		0101000020E6100000BC07E8BE1C49604061DEE34C13DE4E40
84813	4	34	496	32831	79420	\N	61.636938000000001	Республика Саха (Якутия), Мегино-Кангаласский район, Тыллыминский 1-й наслег, с. Ломтука, Семена Назарова, 1		0101000020E61000006DC7D45DD942604032CA332F87D14E40
84799	4	34	496	22665	78872	\N	60.973855999999998	Республика Саха (Якутия), Мегино-Кангаласский район, Чыамайыкинский наслег, с. Даркылах, Советская, 12		0101000020E6100000A73E90BCF34B6040B6813B50A77C4E40
84796	4	34	496	22559	79385	\N	61.786543999999999	Республика Саха (Якутия), Мегино-Кангаласский район, Мегюренский наслег, с. Беке, Октябрьская, 4		0101000020E61000002BDF3312214C6040B96E4A79ADE44E40
84795	4	34	496	22466	45646	\N	61.479642346201203	Республика Саха (Якутия), Мегино-Кангаласский район, Холгуминский наслег, с. Бырама, Матросова, 20/1	Россия, Республика Саха (Якутия), Мегино-Кангаласский район, село Бырама	0101000020E61000005AF624B0395E6040DEE4B7E864BD4E40
85106	4	34	496	5485	79509	\N	62.394702000000002	Республика Саха (Якутия), Усть-Алданский район, Ольтёхский наслег, с.Бейдинга, Пестрякова, 4/1		0101000020E6100000E449D235935B604039D55A9885324F40
84815	4	34	496	6203	45413	\N	62.254061	Республика Саха (Якутия), Мегино-Кангаласский район, Мегинский наслег, с. Балыктах, Балыктахская, 2		0101000020E6100000C939B187F65660403318231285204F40
84785	4	34	7329	61708	79588	\N	68.402172172631097	Республика Саха (Якутия), Ленский район, Наторский наслег, с. Натора, пер. Школьный, 8	Россия	0101000020E610000099BA2BBB60FB5E407BD7A02FBD195140
84782	4	34	7329	55611	45720	\N	60.762418714987298	Республика Саха (Якутия), Ленский район, Салдыкельский наслег, с. Батамай, Центральная, 17	Россия	0101000020E6100000B8B06EBC3BE65C40AD6C1FF296614E40
84763	4	34	7329	61657	79533	\N	60.15784	Республика Саха (Якутия), Ленский район, Ярославский наслег, с. Ярославский, Полярная, 1	Россия	0101000020E610000032AB77B81D7D5C401500E31934144E40
84777	4	34	7329	61820	79728	\N	60.857550787997504	Республика Саха (Якутия), Ленский район, Орто-Нахаринский наслег, с. Чамча, пер. Клубный, 11		0101000020E6100000732D5A80B6AC5C4078D32D3BC46D4E40
84764	4	34	7329	55601	45704	\N	60.236439799395399	Республика Саха (Якутия), Ленский район, Ярославский наслег, с. Хамра, Центральная, 8		0101000020E6100000874ECFBBB1875C40AEBB79AA431E4E40
84784	4	34	7329	61790	79685	\N	60.491844367828499	Республика Саха (Якутия), Ленский район, Нюйский наслег, с. Турукта, Боровая, 5	Россия	0101000020E61000008A1C226E4E215D40EE5D83BEF43E4E40
84762	4	34	7329	55390	45362	\N	59.585411293911903	Республика Саха (Якутия), Ленский район, Поселок Пеледуй, Центральная, 3	Россия	0101000020E610000050A73CBA112F5C40FDDB65BFEECA4D40
84760	4	34	7329	55390	45362	\N	59.629642029926401	Республика Саха (Якутия), Ленский район, Поселок Пеледуй, Центральная, 18	Россия	0101000020E6100000A98592C9A92D5C401118EB1B98D04D40
84755	4	34	7329	55368	45277	\N	59.437759054492098	Республика Саха (Якутия), Ленский район, Поселок Витим, Октябрьская, 30	Россия	0101000020E6100000C9C859D8D3235C40CC43A67C08B84D40
84757	4	34	7329	55368	45423	\N	59.429964986941002	Республика Саха (Якутия), Ленский район, Поселок Витим, Аэропорт, 1	Россия	0101000020E6100000F86D88F19A225C405BB6D61709B74D40
84776	4	34	7329	61707	79587	\N	60.8121060647969	Республика Саха (Якутия), Ленский район, Орто-Нахаринский наслег, с. Орто-Нахара, Центральная, 26/1	Россия	0101000020E6100000611BF16437A55C405471E316F3674E40
84779	4	34	7329	61821	79730	\N	60.908257851914598	Республика Саха (Якутия), Ленский район, Мурбайский наслег, с. Северная Нюя, Школьная, 3	Россия	0101000020E61000000806103E94B45C40492A53CC41744E40
84783	4	34	7329	55439	45459	\N	60.541504338816303	Республика Саха (Якутия), Ленский район, Нюйский наслег, с. Нюя, Октябрьская, 21	Россия	0101000020E6100000F62686E4640E5D409C53C90050454E40
84781	4	34	7329	54709	38891	\N	60.749165458711197	Республика Саха (Якутия), Ленский район, Салдыкельский наслег, с. Мурья, Углестроителей, 7	Россия	0101000020E6100000E2CD1ABCAFD45C40672783A3E45F4E40
84768	4	34	7329	55341	45621	\N	60.719392164401	Республика Саха (Якутия), Ленский район, Город Ленск, Фурманова, 43		0101000020E6100000A4E4D53906BA5C4084807C09155C4E40
84774	4	34	7329	55341	45195	\N	60.719392164401	"Республика Саха (Якутия), Ленский район, Город Ленск, Победы, 15 ""А"""	Россия	0101000020E6100000DF6A9DB81CBA5C4084807C09155C4E40
84771	4	34	7329	55341	45191	\N	60.719392164401	Республика Саха (Якутия), Ленский район, Город Ленск, Ленина, 59	Россия	0101000020E610000077D66EBBD0BA5C4084807C09155C4E40
84778	4	34	7329	55514	45576	\N	61.4443303093529	Республика Саха (Якутия), Ленский район, Мурбайский наслег, с. Дорожный, Лесная, 9	Россия	0101000020E610000056F2B1BB40965C40DB5031CEDFB84E40
84780	4	34	7329	61712	79592	\N	60.970678527477503	Республика Саха (Якутия), Ленский район, Беченчинский наслег, с. Беченча, Советская, 32/1	Россия	0101000020E6100000E2CD1ABCAFDB5C40FDF49F353F7C4E40
85174	4	34	5322	37846	45452	\N	54.066485999999998	Республика Саха (Якутия), Хангаласский район, Город Покровск, мкр Селекционный, Тимирязева, 1/1		0101000020E610000048C0E8F2E6CE454028D2FD9C82084B40
84751	4	34	7326	61689	79566	\N	63.498424148086897	Республика Саха (Якутия), Кобяйский район, Ситтинский наслег, с. Ситта, Кирова, 14	Россия	0101000020E6100000658BA4DDE800604050C58D5BCCBF4F40
84743	4	34	7326	61771	79654	\N	63.5628714817407	Республика Саха (Якутия), Кобяйский район, Арыктахский наслег, с. Арыттах, Молодежная, 22	Россия	0101000020E61000000E6954E0644C5F40F46E2C280CC84F40
84749	4	34	7326	54726	38906	\N	64.008558861234107	Республика Саха (Якутия), Кобяйский район, Кировский наслег, с. Сеген-Кюель, Алексеева, 4	Россия	0101000020E6100000062B4EB5164A604089450C3B8C005040
84753	4	34	7326	54704	38886	\N	65.290676033256105	Республика Саха (Якутия), Кобяйский район, Ламынхинский наслег, с. Себян-Кюель, Ламутского, 52		0101000020E610000039B874CCF93F6040DB6E826F9A525040
84752	4	34	7326	54704	38886	\N	65.289131395239096	Республика Саха (Якутия), Кобяйский район, Ламынхинский наслег, Себян-Кюель, Ламутского, 52	Россия	0101000020E6100000F163CC5D4B406040A0504F1F81525040
84730	4	34	7326	55441	45605	\N	63.937418112303902	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Советская, 19		0101000020E6100000E2900DA48BDE5F4043572250FDF74F40
84733	4	34	7326	55441	45700	\N	63.937117587442899	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Нефтебаза, 9		0101000020E6100000CC07043A93DE5F40183F8D7BF3F74F40
84727	4	34	7326	55441	45599	\N	63.933794562697599	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Ленина, 2	Россия	0101000020E610000031B77BB94FDE5F408C15359886F74F40
84725	4	34	7326	55441	45599	\N	63.936211347144898	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Ленина, 51	Россия	0101000020E6100000CC07043A93DE5F40E69315C3D5F74F40
84731	4	34	7326	55441	45461	\N	63.926540963566602	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Кочнева, 17	Россия	0101000020E6100000691A14CD03DF5F409AB33EE598F64F40
84732	4	34	7326	55441	79443	\N	63.942412399251999	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Геолог, 19	Россия	0101000020E6100000AC55BB26A4DE5F40D1ADD7F4A0F84F40
84726	4	34	7326	55441	79488	\N	63.930168994221802	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Алексеева, 3	Россия	0101000020E6100000CC07043A93DE5F4063601DC70FF74F40
84744	4	34	7326	55541	45607	\N	63.722901658165597	Республика Саха (Якутия), Кобяйский район, Арыктахский наслег, с. Люксюгун, Кралина, 9		0101000020E6100000C39D0B23BD3E5F40431B800D88DC4F40
84736	4	34	7326	55505	45563	\N	63.561250363571602	Республика Саха (Якутия), Кобяйский район, Кобяйский наслег, с.Кобяй, Калинина, 4		0101000020E61000002272FA7ABEA05F40A4703D0AD7C74F40
84737	4	34	7326	55423	45421	\N	63.5670662589663	Республика Саха (Якутия), Кобяйский район, Кобяйский наслег с. Кобяй, Терехова, 6/2	Россия	0101000020E6100000709A3E3BE0A05F403656629E95C84F40
84735	4	34	7326	55536	45601	\N	63.964515482813397	Республика Саха (Якутия), Кобяйский район, Куокуйский наслег, с.Аргас, Иванова, 15/2	Россия	0101000020E6100000452E3883BFA75F402FC03E3A75FB4F40
84722	4	34	7317	54268	35833	\N	67.328183748433801	"Республика Саха (Якутия), Жиганский район, Эвенкийское муниципальное образование ""Кыстатыам"", н.Кыстатыам, Шемякова, 5"	Россия	0101000020E6100000486E4DBA2DD45E4082C476F700D55040
84720	4	34	7317	61778	79665	\N	66.768491999999995	Республика Саха (Якутия), Жиганский район, Жиганский наслег, с.Жиганск, Чкалова, 6		0101000020E6100000AB5D13D21AD85E4035CF11F92EB15040
33351	4	41	1601	55685	46263	\N	48.551751000000003	пос. Николаевка, ул. Кубанская, д. 2		0101000020E6100000D1419770E8D860408544DAC69F464840
84694	4	34	1114	17311	79421	\N	61.867956092953797	Республика Саха (Якутия), Вилюйский район, с.Эбя, Гоголева, 16	Россия, Республика Саха (Якутия), Горный район, село Эбя	0101000020E61000006BD44334BAA95F40F92EA52E19EF4E40
84716	4	34	1114	18486	79376	\N	62.567067000000002	"Республика Саха (Якутия), Горный район, Маганинский наслег, с.Орто-Сурт, Мира, 9""а"""		0101000020E6100000DD7C23BA67485F4007D2C5A695484F40
84710	4	34	1114	18163	45374	\N	62.148747999999998	Республика Саха (Якутия), Горный район, Одунунский наслег, Магарас, Октябрьская, 10		0101000020E610000029CC7B9CE901604036ACA92C0A134F40
84718	4	34	1114	18526	45669	\N	62.5717	Республика Саха (Якутия), Горный район, Октябрьский наслег, с.Кюерелях, Школьная, 3		0101000020E6100000A9A5B915C2B55F40C58F31772D494F40
84717	4	34	1114	18479	79377	\N	62.341045000000001	Республика Саха (Якутия), Горный район, Малтанинский наслег, с.Кептин, Советская, 31		0101000020E61000007FC2D9AD651C5F406FBBD05CA72B4F40
84714	4	34	1114	18354	\N	\N	62.018420999999996	Республика Саха (Якутия), Горный район, Шологонский наслег, с.Ерт, Т.С.Захаровой, 2	Россия, Республика Саха (Якутия), Горный район, село Ерт	0101000020E6100000AB7823F3C8725F40A1478C9E5B024F40
84713	4	34	1114	18273	79375	\N	61.885140999999997	Республика Саха (Якутия), Горный район, Мытахский наслег, с.Дикимдя, Строда, 1		0101000020E610000051C1E10511A25F40A3ACDF4C4CF14E40
84934	4	34	1114	18273	79448	\N	61.885140999999997	Республика Саха (Якутия), Нюрбинский район, Дикимдинский наслег, с. Дикимдя, Озерная, 5		0101000020E610000051C1E10511A25F40A3ACDF4C4CF14E40
84709	4	34	1114	61675	79552	\N	61.939694000000003	Республика Саха (Якутия), Горный район, Атамайский наслег, с.Бяс-Кюель, Лонгинова, 19	Россия, Республика Саха (Якутия), Горный район	0101000020E6100000A79201A08A945F40AC1F9BE447F84E40
84711	4	34	1114	18066	45268	\N	62.097664999999999	Республика Саха (Якутия), Горный район, Бердигестяхский наслег, с.Бердигестях, С.П.Данилова, 14		0101000020E61000005A1135D1E7AC5F405F7B6649800C4F40
84708	4	34	1114	18066	45341	\N	62.097664999999999	Республика Саха (Якутия), Горный район, Бердигестяхский наслег, с.Бердигестях, Октябрьская, 18		0101000020E61000005A1135D1E7AC5F405F7B6649800C4F40
84712	4	34	1114	18066	45328	\N	62.097664999999999	"Республика Саха (Якутия), Горный район, Бердигестяхский наслег, с.Бердигестях, С.П.Данилова, 61 ""а"""		0101000020E61000005A1135D1E7AC5F405F7B6649800C4F40
84715	4	34	1114	18357	45670	\N	62.362001999999997	Республика Саха (Якутия), Горный район, Кировский наслег, с.Асыма, Чээмпи, 2		0101000020E61000007A1A3048FAA85F40158BDF14562E4F40
84687	4	34	7332	61664	79541	\N	63.734847261407701	Республика Саха (Якутия), Вилюйский район, с.Хампа, Ст. Гоголева, 39	Россия	0101000020E6100000B4CBB73EACBB5E4028486C770FDE4F40
81792	4	34	7332	61837	79755	\N	64.442007000000004	Республика Саха (Якутия), Вилюйский район, с. Кюбяинде, Победы, 9	Россия	0101000020E6100000E223624A24895E409966BAD7491C5040
84707	4	34	7332	55478	45525	\N	63.5526774000895	Республика Саха (Якутия), Вилюйский район, с. Чинекя, Комсомольская, 3а	Россия	0101000020E61000007CB8E4B853635E402E20B41EBEC64F40
84691	4	34	7332	61733	79613	\N	63.835132686498497	Республика Саха (Якутия), Вилюйский район, с. Чай, Советская, 20	Россия	0101000020E610000073B8567BD8E15E40BA675DA3E5EA4F40
84697	4	34	7332	55459	45502	\N	64.526257139854096	Республика Саха (Якутия), Вилюйский район, с. Усун, Ойунского, 24	Россия	0101000020E6100000BAA46ABB09435E40A112D731AE215040
84704	4	34	7332	55493	45543	\N	63.877848105274701	Республика Саха (Якутия), Вилюйский район, с. Тосу, Ленина, 18	Россия	0101000020E61000008F8AFF3BA2675E40F46DC1525DF04F40
84703	4	34	7332	61654	79530	\N	64.371411036587801	Республика Саха (Якутия), Вилюйский район, с. Тербяс, Тюнгская, 2	Россия	0101000020E61000003D0B42791F235E40FA97A432C5175040
84706	4	34	7332	55538	45603	\N	63.595482400287501	Республика Саха (Якутия), Вилюйский район, с. Сыдыбыл, Октябрьская, 27		0101000020E61000007DB262B83A5E5E40A7AD11C138CC4F40
84696	4	34	7332	62076	81101	\N	64.494118070296807	Республика Саха (Якутия), Вилюйский район, с. Кеданда, Юбилейная, 11	Россия	0101000020E61000002C0DFCA886875E405B971AA19F1F5040
84689	4	34	7332	54727	38907	\N	62.8392690792815	Республика Саха (Якутия), Вилюйский район, с. Илбенге, М.А.Алексеева, 26	Россия	0101000020E610000098C3EE3B86195F40F8C5A52A6D6B4F40
84693	4	34	7332	61638	79513	\N	63.772077000000003	Республика Саха (Якутия), Вилюйский район, с. Екюндю, Ф.Константинова, 1/5		0101000020E61000008E209562478B5E40357F4C6BD3E24F40
84702	4	34	7332	55009	41201	\N	64.382114380615903	Республика Саха (Якутия), Вилюйский район, с. Балагачча, Миронова, 7	Россия	0101000020E6100000D2191879598E5E400056478E74185040
84674	4	34	7327	61715	79595	\N	67.602947063373406	Республика Саха (Якутия), Верхоянский район, Янский наслег с.Юттях, Советская, 10а	Россия	0101000020E61000003B72A433B0CE60402A8E03AF96E65040
84667	4	34	7327	61826	79744	\N	60.398296199999997	Республика Саха (Якутия), Верхоянский район, Сартанский наслег с.Юнкюр, Центральная, 23	Россия	0101000020E6100000508C2C9963135E405610035DFB324E40
84662	4	34	7327	61887	79859	\N	67.647997000000004	Республика Саха (Якутия), Верхоянский район, Адыччинский наслег с.Бетенкес, Школьная, 11	Россия	0101000020E6100000DFA4695034F26040FEB968C878E95040
84665	4	34	7327	55593	45691	\N	67.204403219106993	Республика Саха (Якутия), Верхоянский район, Борулахский наслег с.Томтор, Центральная, 2	Россия	0101000020E61000008C65FA2562836040130D52F014CD5040
84670	4	34	7327	54705	38887	\N	67.202274429567098	Республика Саха (Якутия), Верхоянский район, Дулгалахский наслег с.Томтор, Эллэ, 23	Россия	0101000020E61000007F4E417EB683604031B5A50EF2CC5040
84666	4	34	7327	54720	38900	\N	67.091225480196499	Республика Саха (Якутия), Верхоянский район, Борулахский наслег с.Токума, Аргаа, 2		0101000020E610000026C3F17C06CA6040F7E461A1D6C55040
84671	4	34	7327	61755	79638	\N	66.666547345515497	Республика Саха (Якутия), Верхоянский район, Суордахский наслег с.Суордах, Центральная, 11	Россия	0101000020E6100000D5E8D500A5786040CD8FBFB4A8AA5040
84663	4	34	7327	61746	79628	\N	68.700035699000097	Республика Саха (Якутия), Верхоянский район, Эгинский наслег с.Сайды, Колхозная, 33	Россия	0101000020E6100000153C855CA9CE60407381CB63CD2C5140
84660	4	34	7327	55550	45624	\N	67.543394071833703	Республика Саха (Якутия), Верхоянский район, Поселок Эсе-Хая, Шадрина, 6	Россия	0101000020E61000009FE925C6B2D56040EEB5A0F7C6E25040
84658	4	34	7327	55475	45698	\N	67.658680000000004	Республика Саха (Якутия), Верхоянский район, Поселок Батагай  микрорайон Аэропорт, Центральная, 1/1		0101000020E6100000E76D6C76A4D56040E0A128D027EA5040
84654	4	34	7327	55475	45522	\N	67.657819230197205	Республика Саха (Якутия), Верхоянский район, Поселок Батагай, Ленина, 19		0101000020E610000098F6CDFDD5D46040FFEBDCB419EA5040
84669	4	34	7327	61728	79608	\N	67.577500000000001	Республика Саха (Якутия), Верхоянский район, Бабушкинский наслег с.Боронук, Центральная, 27	Россия	0101000020E6100000CC5EB69DB6AE6040295C8FC2F5E45040
84657	4	34	7327	61645	79521	\N	67.6597249965575	Республика Саха (Якутия), Верхоянский район, Поселок Батагай, Малоозерная, 4	Россия	0101000020E6100000DE1CAED59ED56040A1D634EF38EA5040
84676	4	34	7327	61698	79577	\N	65.928112518859393	Республика Саха (Якутия), Верхоянский район, Барыласский наслег с.Барылас, Портовская, 4		0101000020E61000007E3672DD14986040847F1134667B5040
84644	4	34	7328	61644	79520	\N	65.744081316574295	Республика Саха (Якутия), Верхнеколымский район, Угольнинский наслег, Дорожная, 17	Россия	0101000020E610000096ED43DEF2B76240CC24EA059F6F5040
84646	4	34	7328	61633	79507	\N	66.347707999999997	Республика Саха (Якутия), Верхнеколымский район, Арылахский наслег с. УСУН-КЮЕЛЬ, Спортивная, 9		0101000020E6100000938D075B6CD06240AF230ED940965040
84653	4	34	7328	55595	79434	\N	65.733356152640098	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Молодежная, 5		0101000020E61000005BB22AC24DD76240D314014EEF6E5040
84650	4	34	7328	55595	45694	\N	65.419262652535195	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Ленина, 17	Россия	0101000020E6100000E3A59BC4A0936240105B7A34D55A5040
84652	4	34	7328	55595	79442	\N	65.740127360377201	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Заводская, 1	Россия	0101000020E610000043AA285EE5DB6240BEF8A23D5E6F5040
84647	4	34	7328	54708	38890	\N	65.493793788385901	Республика Саха (Якутия), Верхнеколымский район, Нелемнский национальный наслег,с Нелемное, Текки Одулока, 19	Россия	0101000020E6100000F0332E1C88E26240813D26529A5F5040
84639	4	34	7330	61831	79749	\N	64.377483571939806	Республика Саха (Якутия), Верхневилюйский район, Сургулукский наслег, с.Сургулук, Центральная, 5	Россия	0101000020E6100000302FC03E3AEF5D40D9B0A6B228185040
84621	4	34	7330	61735	79616	\N	58.711399530334702	Республика Саха (Якутия), Верхневилюйский район, Намский наслег, с.Нам, Хомустах, 2	Россия, Республика Саха (Якутия), Алданский район	0101000020E6100000C77F812040595F40EC2FBB270F5B4D40
84632	4	34	7330	61637	79512	\N	63.793632000000002	Республика Саха (Якутия), Верхневилюйский район, Мейикский наслег, с.Май, Передовиков, 7	Россия	0101000020E610000085B1852007F75D409087BEBB95E54F40
84635	4	34	7330	57576	59516	\N	59.190706547161099	Республика Саха (Якутия), Верхневилюйский район, Магасский наслег, с.Магасс, П.Васильева, 5	Россия, Республика Саха (Якутия), Алданский район	0101000020E6100000B35F77BAF3FD5F40240F441669984D40
84640	4	34	7330	61807	79707	\N	63.948894415998403	Республика Саха (Якутия), Верхневилюйский район, Кырыкыйский наслег, с.Кырыкый, Советская, 2	Россия	0101000020E610000045B9347EE1345E4071AFCC5B75F94F40
84638	4	34	7330	61690	79567	\N	64.257342632959507	Республика Саха (Якутия), Верхневилюйский район, Ботулунский наслег, с.Кетердях, Проезжая, 4	Россия	0101000020E61000009294F430B4F45D40B136C64E78105040
84615	4	34	7330	61353	78683	\N	63.601171999999998	Республика Саха (Якутия), Верхневилюйский район, Едюгейский наслег, с.Едюгей, Школьная, 11	Россия	0101000020E61000007CB8E4B853DC5D40ADA23F34F3CC4F40
84641	4	34	7330	61842	79770	\N	63.6868835	Республика Саха (Якутия), Верхневилюйский район, Дюллюкинский наслег, с.Дюллюкю, Будургэй, 1	Россия	0101000020E6100000EC504D49D61D5E40A5129ED0EBD74F40
84633	4	34	7330	61700	79579	\N	63.881177779108697	Республика Саха (Якутия), Верхневилюйский район, Далырский наслег, с.Далыр, Октябрьская, 1	Россия	0101000020E6100000D34F38BBB5105E4033FAD170CAF04F40
84629	4	34	7330	61680	79557	\N	62.555084064105301	Республика Саха (Якутия), Верхневилюйский район, Хоринский наслег, с.Хоро, Булгунняхтах, 2	Россия	0101000020E6100000884677103B745D40354415FE0C474F40
84625	4	34	7330	55607	45713	\N	63.513877645044602	Республика Саха (Якутия), Верхневилюйский район, Тамалаканский наслег, с.Тамалакан, Семена Руфова, 17		0101000020E61000004209336DFF355E4023111AC1C6C14F40
84624	4	34	7330	61660	79537	\N	63.496980481996701	Республика Саха (Якутия), Верхневилюйский район, Оросунский наслег, с.Оросу, Набережная, 23	Россия	0101000020E610000054C6BFCFB8305E400F62670A9DBF4F40
84618	4	34	7330	62073	81094	\N	62.517352445164803	Республика Саха (Якутия), Верхневилюйский район, Оргётский наслег, с.Оргет, Комсомольская, 15	Россия	0101000020E61000001900AAB871455E409642209738424F40
84630	4	34	7330	61851	79771	\N	63.718483300000003	Республика Саха (Якутия), Верхневилюйский район, Онхойский наслег, с.Онхой, Центральная, 31		0101000020E6100000492BBEA1F0F65D40B1DD3D40F7DB4F40
84622	4	34	7330	61603	79471	\N	62.711869392920399	Республика Саха (Якутия), Верхневилюйский район, Намский наслег, Ленина, 30	Россия	0101000020E6100000B7B6F0BCD4346040A304FD851E5B4F40
84634	4	34	7330	55506	45564	\N	63.551484703514298	Республика Саха (Якутия), Верхневилюйский район, Далырский наслег, с.Кюлят, Тамах, 7		0101000020E61000004AEB6F09C03F5E40069E7B0F97C64F40
84698	4	34	7330	61782	79669	\N	64.836595117746299	Республика Саха (Якутия), Вилюйский район, с. Кюлекян, Центральная, 1	Россия	0101000020E610000007978E39CF3A5E40D13FC1C58A355040
84642	4	34	7330	61845	79765	\N	63.696024999999999	Республика Саха (Якутия), Верхневилюйский район, Дюллюкинский наслег, с.Дюллюкю, Чыыйык, 11	Россия	0101000020E6100000D39FFD48111F5E406519E25817D94F40
84614	4	34	7330	55462	45506	\N	63.445102799332297	Республика Саха (Якутия), Верхневилюйский район, Верхневилюйский наслег, с.Верхневилюйск, Дмитрия Спиридонова, 23	Россия	0101000020E6100000527C7C4276145E40FE2C9622F9B84F40
84619	4	34	7330	61597	79461	\N	63.033233359687898	Республика Саха (Якутия), Верхневилюйский район, Быраканский наслег, с.Быракан, П.А.Васильева, 38	Россия	0101000020E6100000EFE2FDB8FD4F5E40F1129CFA40844F40
84636	4	34	7330	61709	79589	\N	64.135627212234397	Республика Саха (Якутия), Верхневилюйский район, Ботулунский наслег, с.Ботулу, Центральная, 25/1	Россия	0101000020E6100000274A42226DF15D40185DDE1CAE085040
84623	4	34	7330	61629	79503	\N	63.528861471747398	Республика Саха (Якутия), Верхневилюйский район, Балаганнахский наслег, с.Балаганнах, Боороо, 29	Россия	0101000020E6100000E3E313B2F3225E409F909DB7B1C34F40
84608	4	34	7363	62077	81107	\N	72.585254502675994	Республика Саха (Якутия), Булунский район, с. Тюметинский, Центральная, 1	Россия	0101000020E610000098C0ADBB794C5E40833463D174255240
84602	4	34	7363	55387	\N	\N	71.6279109400176	Республика Саха (Якутия), Булунский район, п. Тикси, Нет улиц, 407		0101000020E61000002E1A321E251B60401D739EB12FE85140
84607	4	34	7363	55578	45667	\N	69.911380468775604	Республика Саха (Якутия), Булунский район, с. Сиктях, Береговая, 6	Россия	0101000020E6100000E6EB32FCA7465F409F8EC70C547A5140
84604	4	34	7363	55485	45535	\N	70.684349511135693	Республика Саха (Якутия), Булунский район, с. Кюсюр, Советская, 10	Россия	0101000020E61000005C3B511212D75F402041F163CCAB5140
84597	4	34	7539	61834	79752	\N	71.967194500000005	Республика Саха (Якутия), Анабарский район, Саскылахский национальный наслег, Авиаторов, 3	Россия	0101000020E6100000CFBEF2203D865C40B476DB85E6FD5140
84587	4	34	299	55419	45416	\N	60.592781000000002	Республика Саха (Якутия), Амгинский район, Чапчылганский наслег, 50 лет МТС, 11	Россия, Республика Саха (Якутия), Амгинский район	0101000020E6100000C1525DC04B3D60405858703FE04B4E40
84588	4	34	299	61832	79750	\N	60.845914100000002	Республика Саха (Якутия), Амгинский район, Чакырский наслег, Ленина, 43	Россия	0101000020E610000003EACDA8F97A6040419DF2E8466C4E40
85068	4	34	299	3441	45492	\N	60.500351999999999	Республика Саха (Якутия), Таттинский район, Средне-Амгинский наслег, с. Харбалах, Николаева, 1		0101000020E610000007B47405DB4060407D3ECA880B404E40
84626	4	34	299	3441	79390	\N	60.500351999999999	Республика Саха (Якутия), Верхневилюйский район, Харбалахский наслег, с.Харбалах, Исидора Барахова, 10		0101000020E610000007B47405DB4060407D3ECA880B404E40
84589	4	34	299	61614	79483	\N	60.742371209054802	Республика Саха (Якутия), Амгинский район, Майский наслег, Октябрьская, 22		0101000020E610000074417DCB9C736040D93F4F03065F4E40
84591	4	34	299	32707	78752	\N	61.279584	Республика Саха (Якутия), Амгинский район, Амгино-Нахаринский, П. Яковлева, 29		0101000020E610000022C50089265C6040103E9468C9A34E40
84584	4	34	299	61716	79596	\N	61.182332457450102	Республика Саха (Якутия), Амгинский район, Мяндигинский наслег, Мира, 2	Россия	0101000020E610000000FDBE7F73916040D481ACA756974E40
84590	4	34	299	55494	45546	\N	60.612699356114	Республика Саха (Якутия), Амгинский район, Болугурский наслег, Ленина, 48	Россия	0101000020E6100000753BFBCA836E60405DA5BBEB6C4E4E40
84586	4	34	299	55451	45483	\N	60.901865843134701	Республика Саха (Якутия), Амгинский район, Бетюнский наслег, М.Нестерева, 65	Россия	0101000020E610000011AB3FC2B0856040EAAF575870734E40
84593	4	34	299	55447	45472	\N	61.4685529447408	Республика Саха (Якутия), Амгинский район, Алтанский наслег, Петрова, 25		0101000020E61000005B272EC72B706040AAB8718BF9BB4E40
84576	4	34	7536	61621	79493	\N	69.809487152903301	Республика Саха (Якутия), Аллаиховский район, Юкагирский наслег с. Оленегорск, Щерьачкова, 12		0101000020E6100000F1113125926F624061E28FA2CE735140
84577	4	34	7536	61786	79677	\N	71.523238736623398	Республика Саха (Якутия), Аллаиховский район, Русско-Устьинский наслег С. Русское Устье, Центральная, 12/1	море Восточно-Сибирское	0101000020E610000024B4E55C8ABE6240793F6EBF7CE15140
85023	4	34	159	61797	79692	\N	59.266015000000003	Республика Саха (Якутия), Среднеколымский район, с.Сватай, Победы, 6	Россия, Республика Саха (Якутия), Алданский район	0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
84539	4	34	159	61796	79691	\N	59.266015000000003	Республика Саха (Якутия), Абыйский район, Майорский национальный наслег, с. Куберганя, Центральная, 1	Россия, Республика Саха (Якутия), Алданский район	0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
84570	4	34	159	11395	78830	\N	58.530239000000002	Республика Саха (Якутия), Алданский район, село Якокут, Октябрьская, 3		0101000020E610000024B4E55C8A6D5F4029081EDFDE434D40
84554	4	34	159	61738	79619	\N	58.897275139431002	Республика Саха (Якутия), Алданский район, Поселок Якокит, Советская, 38	Россия, Республика Саха (Якутия), Алданский район, село Якоит	0101000020E610000030BABC395C755F405B423EE8D9724D40
84559	4	34	159	55577	45666	\N	58.579878000000001	Республика Саха (Якутия), Алданский район, село Ыллымах, Буровая, 2		0101000020E6100000F1BBE9961DAC5F40BFD53A71394A4D40
84742	4	34	159	55576	79458	\N	58.750490999999997	Республика Саха (Якутия), Кобяйский район, Нижилинский наслег, с. Чагда, Северная, 1/5		0101000020E6100000B537F8C2645360409E78CE1610604D40
84573	4	34	159	55576	45665	\N	58.750490999999997	Республика Саха (Якутия), Алданский район, село Чагда, Матросова, 4		0101000020E6100000B537F8C2645360409E78CE1610604D40
84571	4	34	159	11467	45471	\N	58.9208319413504	Республика Саха (Якутия), Алданский район, село Хатыстыр, 50 лет Октября, 14	Россия, Республика Саха (Якутия), Алданский район, село Хатыстыр	0101000020E61000004F5C8E57204A5F401D8EAED2DD754D40
84672	4	34	159	32561	79446	\N	60.661439000000001	Республика Саха (Якутия), Верхоянский район, Эльгесский наслег с.Хайысардах, Школьная, 7	Россия, Республика Саха (Якутия), Алданский район, село Хайысардах	0101000020E610000091B932A8B60B604044A67C08AA544E40
84558	4	34	159	55600	45702	\N	60.315433778872404	Республика Саха (Якутия), Алданский район, село Улуу, Центральная, 4	Россия, Республика Саха (Якутия), Алданский район, село Улу	0101000020E6100000240F441669DB5F40F3052D2460284E40
84572	4	34	159	11481	78842	\N	59.253990999999999	Республика Саха (Якутия), Алданский район, село Угоян, Центральная, 41		0101000020E6100000BE11DDB3AE525F403A3DEFC682A04D40
84563	4	34	159	10962	45302	\N	58.955607000000001	Республика Саха (Якутия), Алданский район, Город Томмот, микрорайон Алексеевск, Школьная, 13		0101000020E610000077499C1551915F40126A8654517A4D40
84561	4	34	159	10962	45685	\N	58.955607000000001	Республика Саха (Якутия), Алданский район, Город Томмот, Укуланская, 7		0101000020E610000077499C1551915F40126A8654517A4D40
84560	4	34	159	10962	79387	\N	58.955607000000001	Республика Саха (Якутия), Алданский район, Город Томмот, микрорайон Пятилетка, Совхозная, 18/1		0101000020E610000077499C1551915F40126A8654517A4D40
84564	4	34	159	10962	45263	\N	58.955607000000001	Республика Саха (Якутия), Алданский район, Город Томмот, Ленина, 24		0101000020E610000077499C1551915F40126A8654517A4D40
84562	4	34	159	10962	45169	\N	58.956937280460501	Республика Саха (Якутия), Алданский район, Город Томмот, Захарова, 12	Россия, Республика Саха (Якутия), Алданский район, Томмот	0101000020E61000004F20EC14AB915F408BAA5FE97C7A4D40
84840	4	34	159	55404	45388	\N	58.547843	Республика Саха (Якутия), Мирнинский район, Ботуобуйинский наслег, п. Таас-Юрях, Степана Попова, 13		0101000020E6100000C0EC9E3C2C0F6040D82B2CB81F464D40
84729	4	34	159	61350	78678	\N	59.266015000000003	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Горбунова, 33	Россия, Республика Саха (Якутия), Алданский район	0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
84557	4	34	159	55364	45321	\N	58.821241000000001	Республика Саха (Якутия), Алданский район, Поселок Нижний Куранах, Юбилейная, 15-а		0101000020E61000009E60FF756E615F403291D26C1E694D40
84556	4	34	159	55364	45267	\N	58.821241000000001	Республика Саха (Якутия), Алданский район, Поселок Нижний Куранах, Школьная, 25		0101000020E61000009E60FF756E615F403291D26C1E694D40
84555	4	34	159	55364	45267	\N	58.819193223972498	Республика Саха (Якутия), Алданский район, Поселок Нижний Куранах, Школьная, 19		0101000020E610000076374F75C8615F405A0EF450DB684D40
85018	4	34	159	61650	79525	\N	59.266015000000003	Республика Саха (Якутия), Среднеколымский район, с.Налимск, Слепцова, 37	Россия, Республика Саха (Якутия), Алданский район	0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
84568	4	34	159	11327	45351	\N	58.571069634165703	Республика Саха (Якутия), Алданский район, Поселок Ленинский, Ленина, 36	Россия, Республика Саха (Якутия), Алданский район, поселок городского типа Ленинский	0101000020E610000012C2A38D235C5F4005DD5ED218494D40
84569	4	34	159	11335	45474	\N	58.492297999999998	Республика Саха (Якутия), Алданский район, Поселок Лебединый, Октябрьская, 23	Россия, Республика Саха (Якутия), Алданский район, поселок городского типа Лебединый	0101000020E610000007793D9814605F406FF1F09E033F4D40
84566	4	34	159	61758	79641	\N	59.0135414487495	Республика Саха (Якутия), Алданский район, село Кутана, Школьная, 4		0101000020E6100000E5B7E864A9766040DB1324B6BB814D40
84553	4	34	159	10605	45684	\N	58.755271	Республика Саха (Якутия), Алданский район, Поселок Верхний Куранах, Разрезная, 1		0101000020E6100000E3C62DE6E75E5F40014F5AB8AC604D40
84645	4	34	159	61815	79720	\N	59.266015000000003	Республика Саха (Якутия), Верхнеколымский район, Верхнеколымский наслег, Советская, 17		0101000020E6100000F19E03CB11E05F406B9F8EC70CA24D40
84567	4	34	159	11281	45569	\N	58.041981	Республика Саха (Якутия), Алданский район, село Большой Нимныр, Школьная, 19		0101000020E61000002D26361FD75E5F40D50627A25F054D40
84546	4	34	159	10186	45166	\N	58.607514999999999	Республика Саха (Якутия), Алданский район, Город Алдан, микрорайон Солнечный, Строителей, 8		0101000020E6100000CD8FBFB4A8575F402B6A300DC34D4D40
84549	4	34	159	10186	45317	\N	58.607514999999999	Республика Саха (Якутия), Алданский район, Город Алдан, Пролетарская, 1а		0101000020E6100000CD8FBFB4A8575F402B6A300DC34D4D40
84548	4	34	159	10186	45256	\N	58.607514999999999	Республика Саха (Якутия), Алданский район, Город Алдан, Октябрьская, 1		0101000020E6100000CD8FBFB4A8575F402B6A300DC34D4D40
84547	4	34	159	10186	45254	\N	58.607514999999999	Республика Саха (Якутия), Алданский район, Город Алдан, Ленина, 27		0101000020E6100000CD8FBFB4A8575F402B6A300DC34D4D40
84550	4	34	159	10186	45255	\N	58.607514999999999	Республика Саха (Якутия), Алданский район, Город Алдан, Калинина, 2/5		0101000020E6100000CD8FBFB4A8575F402B6A300DC34D4D40
84552	4	34	159	10186	45327	\N	58.6078705587285	Республика Саха (Якутия), Алданский район, Город Алдан, Гагарина, 10	Россия, Республика Саха (Якутия), Алданский район, Алдан	0101000020E61000001A506F46CD585F40EA9788B7CE4D4D40
84551	4	34	159	10186	45265	\N	58.605633770999297	Республика Саха (Якутия), Алданский район, Город Алдан, Билибина, 26-а	Россия, Республика Саха (Якутия), Алданский район, Алдан	0101000020E61000006878B306EF575F403FAC376A854D4D40
84545	4	34	159	10186	45324	\N	58.605006660803703	Республика Саха (Якутия), Алданский район, Город Алдан, 50 лет ВЛКСМ, 14	Россия, Республика Саха (Якутия), Алданский район, Алдан	0101000020E6100000E199D024B1575F40F06C8FDE704D4D40
84544	4	34	159	10186	45324	\N	58.605454597809498	Республика Саха (Якутия), Алданский район, Город Алдан, 50 лет ВЛКСМ, 123	Россия, Республика Саха (Якутия), Алданский район, Алдан	0101000020E610000009168733BF575F408F19A88C7F4D4D40
74156	4	36	\N	8394	44417	\N	43.7991973398439	Приморский край, г. Уссурийск, Октябрьская, 58		0101000020E61000003E25E7C41E7F6040D90759164CE64540
84542	4	34	7333	61695	79573	\N	68.747605145933804	Республика Саха (Якутия), Абыйский район, Уолбутский наслег, с. Кенг-Кюель, Маркова С.П, 1, 1	Россия	0101000020E61000004FCE50DC71386340DE54A4C2D82F5140
84543	4	34	7333	54721	38901	\N	68.552930634134	Республика Саха (Якутия), Абыйский район, Урасалахский наслег, с. Сутуруоха, Ефимова, 11	Россия	0101000020E610000062156F641E456240747CB43863235140
84541	4	34	7333	55594	45693	\N	68.376874057688894	Республика Саха (Якутия), Абыйский район, Абыйский наслег, с. Деску, Оттох-Атахская, 10		0101000020E61000007E198C11891062409D2D20B41E185140
84538	4	34	7333	55343	45203	\N	68.533842042985995	Республика Саха (Якутия), Абыйский район, Поселок Белая Гора, Ефимова, 7, 2	Россия	0101000020E61000001A8A3BDE64466240CDCEA2772A225140
85191	4	34	7364	55481	45530	\N	61.634614347315299	Республика Саха (Якутия), Чурапчинский район, Болугурский наслег, с. Мындагай, Ленина, 11	Россия	0101000020E610000078F17EDC7EA66040B8CA13083BD14E40
84741	4	34	7331	61726	79606	\N	63.725777000000001	Республика Саха (Якутия), Кобяйский район, Люччегинский 2-й наслег, с. Мастах, Советская, 10/1	Россия	0101000020E61000005D3123BC3D0F5F403198BF42E6DC4F40
84594	4	34	7372	55529	45593	\N	61.563942011008898	Республика Саха (Якутия), Амгинский район, Сатагайский наслег, Лукина, 27		0101000020E61000007311DF89596F6040A06B5F402FC84E40
84540	4	34	7335	54728	38908	\N	68.366646366774106	Республика Саха (Якутия), Абыйский район, Мугурдахский наслег, с. Сыаганнах, Ильяховой, 31	Россия	0101000020E6100000C6FA062637F4614064CDC82077175140
74382	4	36	\N	55256	44392	\N	42.972391859490898	Приморский край, город Фокино, Центральная, 25	Россия, Приморский край, Шкотовский район, город Фокино	0101000020E610000095B7239C168D60402E724F57777C4540
74377	4	36	\N	55256	44392	\N	42.973148183351697	Приморский край, город Фокино, Центральная, 1	Россия, Приморский край, Шкотовский район, город Фокино	0101000020E610000096D1C8E7158D60407B15191D907C4540
74380	4	36	\N	55256	44463	\N	42.973589367944399	Приморский край, город Фокино, Усатого, 18	Россия, Приморский край, Шкотовский район, город Фокино	0101000020E6100000024A438D428D6040675F79909E7C4540
74379	4	36	\N	55256	44461	\N	42.973652394054497	Приморский край, город Фокино, Постникова, 18	Россия, Приморский край, Шкотовский район, город Фокино	0101000020E610000029CC7B9CE98C6040AED7F4A0A07C4540
74378	4	36	\N	55256	44461	\N	42.975621927214902	Приморский край, город Фокино, Постникова, 4	Россия	0101000020E6100000ADFC3218238D60400AA1832EE17C4540
74383	4	36	\N	55256	44466	\N	42.969902227279498	Приморский край, город Фокино, Карла Маркса, 37А	Россия, Приморский край, Шкотовский район, город Фокино	0101000020E6100000E3DF675C388D60409929ADBF257C4540
74384	4	36	\N	55256	44851	\N	42.967349461015203	Приморский край, город Фокино, Дальняя, 28	Россия, Приморский край, Шкотовский район, город Фокино	0101000020E6100000E2AB1DC5398D6040BE688F17D27B4540
74176	4	36	\N	8394	44421	\N	43.793446566220801	Приморский край, г. Уссурийск, Чичерина, 146		0101000020E6100000BEC11726537F6040FE0DDAAB8FE54540
74178	4	36	\N	8394	44573	\N	43.820983052148797	Приморский край, г. Уссурийск, Тургенева, 113	Россия, Приморский край, городской округ Уссурийск	0101000020E6100000A6B6D441DE7E604036C98FF815E94540
74177	4	36	\N	8394	44573	\N	43.802344486726	Приморский край, г. Уссурийск, Тургенева, 3		0101000020E6100000315EF3AA4E7F604027124C35B3E64540
74188	4	36	\N	8394	44591	\N	43.796920410989799	Приморский край, г. Уссурийск, Топоркова, 126		0101000020E610000015014EEFE27F6040A0C37C7901E64540
74190	4	36	\N	8394	44376	\N	43.802205000000001	Приморский край, г. Уссурийск, Теодора Тихого, 9		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74163	4	36	\N	8394	44367	\N	43.802205000000001	Приморский край, г. Уссурийск, Советская, 35		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74152	4	36	\N	8394	44367	\N	43.814667262424301	Приморский край, г. Уссурийск, Советская, 15		0101000020E61000001152B7B32F7E6040B2101D0247E84540
74187	4	36	\N	8394	44373	\N	43.802585372572302	Приморский край, г Уссурийск, Слободская, 5		0101000020E6100000F2423A3C847F60404DA1F31ABBE64540
74185	4	36	\N	8394	44373	\N	43.802205000000001	Приморский край, г. Уссурийск, Слободская, 49		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74204	4	36	\N	8394	44893	\N	43.802205000000001	Приморский край, г. Уссурийск, Сельскохозяйственная, 23		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74180	4	36	\N	8394	44590	\N	43.802865109747003	Приморский край, г. Уссурийск, Садовая, 1	Россия, Приморский край, город Уссурийск	0101000020E61000001DAD6A49477F6040300DC347C4E64540
74182	4	36	\N	8394	44370	\N	43.809353088004301	Приморский край, г. Уссурийск, Русская, 10	Россия, Приморский край, городской округ Уссурийск	0101000020E61000005000C5C8927F6040B2F50CE198E74540
74181	4	36	\N	8394	44370	\N	43.811031663979598	Приморский край, г. Уссурийск, Русская, 35	Россия, Приморский край, городской округ Уссурийск	0101000020E6100000ED45B41DD37F6040360186E5CFE74540
74531	4	36	\N	8394	43253	\N	43.779704623632703	692508 Приморский край, г. Уссурийск Раздольная (здание общежития сельскохозяйственной академии) 12		0101000020E6100000ED6305BF8D7E60408BC3995FCDE34540
74164	4	36	\N	8394	44366	\N	43.7980938562253	Приморский край, г. Уссурийск, Пушкина, 11		0101000020E61000003CDC0E0D0B7E60402191B6F127E64540
74155	4	36	\N	8394	44366	\N	43.800044366163903	Приморский край, г. Уссурийск, Пушкина, 88		0101000020E61000002252D32EA67E604036AE7FD767E64540
74183	4	36	\N	8394	44519	\N	43.8056546388556	Приморский край, г. Уссурийск, пр.Блюхера, 44		0101000020E610000015C8EC2C7A7F6040F06DFAB31FE74540
74196	4	36	7435	\N	44422	\N	43.8019563233523	Приморский край, г. Уссурийск, пер.Тихий, 4-1	Россия, Приморский край, городской округ Уссурийск	0101000020E6100000A83AE466B87F60405D6A847EA6E64540
74192	4	36	7438	\N	44789	\N	43.801785006147803	Приморский край, г. Уссурийск, пер.Мурзинцева, 26	Россия, Приморский край, городской округ Уссурийск	0101000020E6100000A9A27895B57F604031B610E4A0E64540
74162	4	36	\N	8394	44417	\N	43.795832427788298	Приморский край, г. Уссурийск, Октябрьская, 59		0101000020E6100000B6BB07E83E7E60401D8EAED2DDE54540
74170	4	36	\N	8394	44604	\N	43.817479542160903	Приморский край, г. Уссурийск, Никитина, 6	Россия, Приморский край, город Уссурийск	0101000020E61000002A1DACFFF37C60402A91442FA3E84540
74530	4	36	\N	8394	43254	\N	43.802205000000001	692508 Приморский край, г. Уссурийск Некрасова (здание филиала Дальневосточного университета) 35		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74174	4	36	\N	8394	43254	\N	43.804784382013601	Приморский край, г. Уссурийск, Некрасова, 115		0101000020E6100000874F3A91607E60400A2C802903E74540
74171	4	36	\N	8394	43254	\N	43.822886202506197	Приморский край, г. Уссурийск, Некрасова, 209		0101000020E61000005B9885764E7E60400A2B155454E94540
74169	4	36	\N	8394	43254	\N	43.839010036757003	Приморский край, г. Уссурийск, Некрасова, 291	Россия, Приморский край, городской округ Уссурийск	0101000020E61000000DE36E102D7E60402C82FFAD64EB4540
74203	4	36	\N	8394	44374	\N	43.8019563233523	Приморский край, г. Уссурийск, Ленинградская, 42	Россия, Приморский край, городской округ Уссурийск	0101000020E610000091EEE714647E60405D6A847EA6E64540
74168	4	36	\N	8394	44374	\N	43.811062377337699	Приморский край, г. Уссурийск, Ленинградская, 59		0101000020E61000003FABCC94D67D6040A1832EE1D0E74540
74197	4	36	\N	8394	44408	\N	43.802205000000001	Приморский край, г. Уссурийск, Ленина, 80		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74014	4	36	\N	8394	44408	\N	43.802205000000001	Приморский край, г. Уссурийск, Ленина, 144		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74166	4	36	\N	8394	44517	\N	43.801116730764797	Приморский край, г. Уссурийск, Крестьянская, 55		0101000020E610000087A8C29F617E604083A279008BE64540
74172	4	36	7435	\N	44420	\N	43.806245163013202	Приморский край, г. Уссурийск, Короленко, 11а	Россия, Приморский край, городской округ Уссурийск	0101000020E61000006E52D158FB7E604021C8410933E74540
74173	4	36	\N	8394	44369	\N	43.804271546110499	Приморский край, г. Уссурийск, Комсомольская, 77	Россия, Приморский край, городской округ Уссурийск	0101000020E610000026E2ADF36F7E6040548B8862F2E64540
74200	4	36	\N	8394	44522	\N	43.812662849055997	Приморский край, г. Уссурийск, Комарова, 55		0101000020E61000009D0E643D357E6040AAD5575705E84540
74151	4	36	\N	8394	44416	\N	43.802205000000001	Приморский край, г.  Уссурийск, Карбышева, 27		0101000020E610000083A3E4D5397F604006D847A7AEE64540
73962	4	36	\N	8394	44355	\N	43.796485584382403	Приморский край, г. Уссурийск, Ильюшина, 3		0101000020E61000007A522635347F604066DCD440F3E54540
74165	4	36	\N	8394	44419	\N	43.800417364745201	Приморский край, г. Уссурийск, Горького, 69а		0101000020E61000007B698A00277E6040CB14731074E64540
74161	4	36	7435	\N	44419	\N	43.796135510827398	Приморский край, г. Уссурийск, Горького, 22	Россия, Приморский край, городской округ Уссурийск	0101000020E61000001D1CEC4D0C7F60408995D1C8E7E54540
74199	4	36	\N	8394	42825	\N	43.767606987787303	Приморский край, г. Уссурийск, Владивостокское шоссе, 113а		0101000020E610000045292158557F6040209738F240E24540
74193	4	36	\N	8394	42825	\N	43.7579892918993	Приморский край, г. Уссурийск, Владивостокское шоссе, 36		0101000020E610000095D74AE8AE7F604027DD96C805E14540
74191	4	36	\N	8394	42825	\N	43.801427557460698	Приморский край, г. Уссурийск, Владивостокское шоссе, 26а		0101000020E6100000AB5E7EA7497F6040A20C553195E64540
74167	4	36	\N	8394	44518	\N	43.8043647893318	Приморский край, г. Уссурийск, Амурская, 41		0101000020E6100000D21DC4CE147E60400586AC6EF5E64540
74150	4	36	\N	8394	44515	\N	43.787104526487802	Приморский край, г. Уссурийск, Агеева, 59		0101000020E6100000EC504D49567E604050C24CDBBFE44540
74149	4	36	\N	8394	44515	\N	43.791954382544901	Приморский край, г. Уссурийск, Агеева, 75а		0101000020E6100000FB73D190F17D6040DBF7A8BF5EE54540
74189	4	36	\N	55268	59508	\N	43.798179338083997	Приморский край, г. Уссурийск, пр.Блюхера, 10		0101000020E610000042B3EBDE8A7F60404FADBEBA2AE64540
74159	4	36	\N	55268	59478	\N	43.799174027021898	Приморский край, г. Уссурийск, Тимирязева, 33	Россия, Приморский край, город Уссурийск	0101000020E61000000394861A057F604021E868554BE64540
74157	4	36	\N	55268	59477	\N	43.799702448737797	Приморский край, г. Уссурийск, Пушкина, 77		0101000020E6100000704221028E7E6040DD4598A25CE64540
74202	4	36	\N	55268	59490	\N	43.795101913588297	Приморский край, г. Уссурийск, Полушкина, 75		0101000020E61000000D8AE601AC7F6040FA7DFFE6C5E54540
74175	4	36	\N	55268	45161	\N	43.811077916105702	Приморский край, г. Уссурийск, Пионерская, 92	Россия, Приморский край, городской округ Уссурийск	0101000020E61000008ECC237F307E6040A7406667D1E74540
74154	4	36	\N	55268	59500	\N	43.794946483874803	Приморский край, г. Уссурийск, Краснознаменная, 80		0101000020E61000005ED89AADBC7E6040030B60CAC0E54540
74153	4	36	\N	55268	59497	\N	43.784213077602899	Приморский край, г. Уссурийск, Калинина, 2		0101000020E61000000684D6C3977E60408D0C721761E44540
74206	4	36	\N	55268	59480	\N	43.802205000000001	Приморский край, г. Уссурийск, Дальневосточная, 17		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74160	4	36	\N	55268	44927	\N	43.802205000000001	Приморский край, г. Уссурийск, Володарского, 61		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74158	4	36	\N	55268	44927	\N	43.791052836726301	Приморский край, г. Уссурийск, Володарского, 14	Россия, Приморский край, городской округ Уссурийск	0101000020E61000006806F1811D7E60408B33863941E54540
74205	4	36	\N	55268	44787	\N	43.801520805151902	Приморский край, г. Уссурийск, Вокзальная площадь, 1		0101000020E61000000F80B8AB577F60405307793D98E64540
74207	4	36	\N	55268	44576	\N	43.802205000000001	Приморский край, г. Уссурийск, Артемовская, 1б		0101000020E610000083A3E4D5397F604006D847A7AEE64540
74143	4	36	\N	55268	44784	\N	43.802205000000001	Приморский край, г. Уссурийск, Андрея Кушнира, 23		0101000020E610000083A3E4D5397F604006D847A7AEE64540
73899	4	36	\N	55285	44662	\N	43.327811020873099	Приморский край, Надеждинский муниципальный район, Тавричанское сельское поселение, п. Тавричанка, Осипенко, 19	Россия	0101000020E6100000B56D1805C17B60407022FAB5F5A94540
73895	4	36	\N	55288	44772	\N	43.328312293405098	Приморский край, Надеждинский муниципальный район, Тавричанское сельское поселение, п. Тавричанка, Квартальная, 9	Россия	0101000020E610000096766A2EB77B60403271AB2006AA4540
74109	4	36	\N	55290	59505	\N	44.583377701255401	Приморский край, г. Спасск-Дальний, Цементная, 2	Россия, Приморский край, город Спасск-Дальний	0101000020E6100000B43D7AC3FD9960405B9A5B21AC4A4640
74122	4	36	\N	55290	59509	\N	44.590035959374497	Приморский край,  г. Спасск-Дальний, Приморская, 47	Россия, Приморский край, город Спасск-Дальний	0101000020E610000044149337409A604038BBB54C864B4640
74134	4	36	\N	55290	59506	\N	44.5902473904262	Приморский край, г. Спасск-Дальний, Октябрьская, 14	Россия, Приморский край, город Спасск-Дальний	0101000020E61000004609FA0B3D9A6040F3C7B4368D4B4640
74126	4	36	\N	55290	59489	\N	44.588318607423602	Приморский край, г. Спасск-Дальний, Краснознаменная, 52		0101000020E610000054E3A59B449A6040C64E78094E4B4640
74127	4	36	\N	55290	44783	\N	44.586689999999997	Приморский край, г. Спасск-Дальний, Красногвардейская, 73		0101000020E6100000BD8E3864039A6040F3716DA8184B4640
74117	4	36	\N	55290	59499	\N	44.607390613285801	Приморский край, г. Спасск-Дальний, Комсомольская, 78		0101000020E6100000007157AF229A60403F7100FDBE4D4640
74123	4	36	\N	55290	59511	\N	44.586689999999997	Приморский край,  г. Спасск-Дальний, 9-го Октября, 1		0101000020E6100000BD8E3864039A6040F3716DA8184B4640
74112	4	36	\N	4638	44913	\N	44.602138990517702	Приморский край, Спасский городской округ, г. Спасск-Дальний, пер.Мухинский		0101000020E6100000DE76A1B9CE996040B55208E4124D4640
74133	4	36	\N	4638	44365	\N	44.5903700560186	Приморский край, г. Спасск-Дальний, Цементная, 22	Россия, Приморский край, город Спасск-Дальний	0101000020E610000013F3ACA4959A60400F45813E914B4640
74108	4	36	\N	4638	44365	\N	44.567583685430797	Приморский край, г. Спасск-Дальний, Цементная, 29		0101000020E61000009AED0A7DB0986040CEDDAE97A6484640
74116	4	36	\N	4638	44371	\N	44.601994672227598	Приморский край, г. Спасск-Дальний, Советская, 64а		0101000020E61000003F8BA5483E9A604082AD122C0E4D4640
74115	4	36	\N	4638	44371	\N	44.601274153273799	Приморский край, г. Спасск-Дальний, Советская, 64		0101000020E61000003F575BB13F9A6040B1F7E28BF64C4640
74043	4	36	\N	4638	44371	\N	44.593068633105098	Приморский край, г. Спасск-Дальний, Советская, 110		0101000020E6100000BB4560AC6F9A6040BEA25BAFE94B4640
74135	4	36	\N	4638	44824	\N	44.590150958796102	Приморский край, г. Спасск-Дальний, пер. Мухинский	Россия, Приморский край, город Спасск-Дальний	0101000020E6100000C9AEB48CD4996040D15966118A4B4640
74114	4	36	\N	4638	44415	\N	44.598698607716003	Приморский край,  г. Спасск-Дальний, Ленинская, 28		0101000020E61000007380608E1E9A6040EF92382BA24C4640
74113	4	36	\N	4638	44415	\N	44.582974556025803	Приморский край, г. Спасск-Дальний, Ленинская, 47		0101000020E610000087A6ECF4839960405BB1BFEC9E4A4640
74129	4	36	\N	4638	44364	\N	44.586689999999997	Приморский край,  г. Спасск-Дальний, Краснознаменная, 48		0101000020E6100000BD8E3864039A6040F3716DA8184B4640
74125	4	36	\N	4638	44364	\N	44.586689999999997	Приморский край, г. Спасск-Дальний, Краснознаменная, 38	Россия, Приморский край, город Спасск-Дальний	0101000020E6100000BD8E3864039A6040F3716DA8184B4640
74124	4	36	\N	4638	44364	\N	44.595685993399698	Приморский край, г. Спасск-Дальний, Краснознаменная, ДОСА		0101000020E61000002AE620E8689A6040B05758703F4C4640
74130	4	36	\N	4638	9716	\N	44.592458565434903	Приморский край, г. Спасск-Дальний, Красногвардейская, 104/6	Россия, Приморский край, город Спасск-Дальний	0101000020E61000007506465E569A6040459C4EB2D54B4640
74128	4	36	\N	4638	9716	\N	44.578642214496497	Приморский край, г. Спасск-Дальний, Красногвардейская, 75/1		0101000020E6100000C3482F6A779A6040C80BE9F0104A4640
74120	4	36	\N	4638	44949	\N	44.586689999999997	Приморский край, г. Спасск-Дальний, Заводская, 17		0101000020E6100000BD8E3864039A6040F3716DA8184B4640
74119	4	36	\N	4638	44363	\N	44.613215210499398	Приморский край, г. Спасск-Дальний, Ершова, 27		0101000020E610000089B7CEBF5D9A6040543541D47D4E4640
74107	4	36	\N	4638	44507	\N	44.565359453702001	Приморский край, город Спасск-Дальний, Дербенева, 25а		0101000020E61000007B832F4CA6986040E8BF07AF5D484640
74110	4	36	\N	4638	44509	\N	44.569447372288103	Приморский край, г. Спасск-Дальний, Герцена, 2		0101000020E6100000513239B53399604014E7A8A3E3484640
74118	4	36	\N	4638	44860	\N	44.591474034620298	Приморский край, г. Спасск-Дальний, Вокзальная, 57	Россия, Приморский край, город Спасск-Дальний	0101000020E6100000766EDA8C539A60409737876BB54B4640
74132	4	36	\N	4638	44840	\N	44.591070945922098	Приморский край, г. Спасск-Дальний, Ангарская	Россия, Приморский край, город Спасск-Дальний	0101000020E6100000C24F1C403F9A6040984EEB36A84B4640
74111	4	36	\N	55259	44448	\N	44.586689999999997	Приморский край, г. Спасск-Дальний, 1-я Загородная, 22		0101000020E6100000BD8E3864039A6040F3716DA8184B4640
74029	4	36	\N	55286	44671	\N	43.135546158555698	Приморский край, Партизанский городской округ, Центральная, 9		0101000020E61000002DEC69873FA46040438D429259914540
73997	4	36	\N	55286	59488	\N	43.114483	Приморский край, город Партизанск, Техникумовская, 1		0101000020E610000077DCF0BB69A4604057790261A78E4540
73992	4	36	\N	55286	59502	\N	43.114483	Приморский край, город Партизанск, Тепличная, 1-а		0101000020E610000077DCF0BB69A4604057790261A78E4540
74026	4	36	\N	55286	59504	\N	43.123521764279303	Приморский край, Партизанский городской округ, Советская, 46-а		0101000020E61000000858AB764DA46040132BA391CF8F4540
74022	4	36	\N	55286	59498	\N	43.124361555206299	Приморский край, Партизанский городской округ, Партизанская, 159		0101000020E6100000683F524406A46040BD6E1118EB8F4540
73996	4	36	\N	55286	59503	\N	43.114483	Приморский край, город Партизанск, Осинрвая, 1		0101000020E610000077DCF0BB69A4604057790261A78E4540
74009	4	36	\N	55286	59493	\N	43.143354379402403	Приморский край, Партизанский городской округ, Ленинская, 36		0101000020E6100000B5334C6D29A460401AE0826C59924540
74028	4	36	\N	55286	45167	\N	43.133420710811599	Приморский край, Партизанский городской округ, Клубная, 3		0101000020E61000006380441328A46040C0CC77F013914540
74006	4	36	\N	55286	59492	\N	43.132291659213799	Приморский край, Партизанский городской округ, 50 Лет ВЛКСМ, 55		0101000020E61000004948A46DFCA36040DFC2BAF1EE904540
74001	4	36	\N	9761	44358	\N	43.121729909525698	"Приморский край, Партизанский городской округ, центральная, 2 ""б"""	Россия, Приморский край, город Партизанск	0101000020E6100000FBEB1516DCA36040967840D9948F4540
74000	4	36	\N	9761	44358	\N	43.1233960218105	Приморский край, город Партизанск, Центральная, 19		0101000020E6100000B7B2446799A46040863AAC70CB8F4540
33352	4	41	1601	45354	46236	\N	48.551751000000003	пос. Николаевка, ул. Комсомольская, д. 54		0101000020E6100000D1419770E8D860408544DAC69F464840
74016	4	36	\N	9761	44627	\N	43.120400113629898	"Приморский край, Партизанский городской округ, Пушкинская, 82- ""а"""		0101000020E6100000EC2E505260A460401D386744698F4540
74021	4	36	\N	9761	44357	\N	43.131191562650102	Приморский край, Партизанский городской округ, Партизанская, 110		0101000020E6100000E97FB916ADA4604098BF42E6CA904540
74013	4	36	\N	9761	44761	\N	43.106761830237701	Приморский край, Партизанский городской округ, Обогатительная, 6		0101000020E6100000122EE411DCA46040503A9160AA8D4540
74008	4	36	\N	9761	44706	\N	43.124871023528797	Приморский край, Партизанский городской округ, Ленинская, 26		0101000020E6100000D6A71C93C5A46040029CDEC5FB8F4540
74011	4	36	\N	9761	44575	\N	43.114483	Приморский край, город Партизанск, Лазо, 8		0101000020E610000077DCF0BB69A4604057790261A78E4540
74002	4	36	\N	9761	44703	\N	43.127922586698602	Приморский край, Партизанский городской округ, Коренова, 10		0101000020E6100000AE6186C693A46040FFB3E6C75F904540
74027	4	36	\N	9761	44638	\N	43.126435763867299	Приморский край, Партизанский городской округ, Кирова, 27		0101000020E6100000A6423C12AFA46040BE840A0E2F904540
74018	4	36	\N	9761	45155	\N	43.125769489788297	Приморский край, Партизанский городской округ, Калинина, 60		0101000020E6100000E9818FC10AA46040E1ECD63219904540
73993	4	36	\N	9761	44502	\N	43.1186176151176	Приморский край, город Партизанск, Индустриальная, 11		0101000020E6100000EA94473742A46040C45BE7DF2E8F4540
74007	4	36	\N	9761	44652	\N	43.114483	Приморский край, Партизанский городской округ, 50 Лет ВЛКСМ, 38	Россия, Приморский край, город Партизанск	0101000020E610000077DCF0BB69A4604057790261A78E4540
73922	4	36	\N	1410	44400	\N	42.799200706874799	"Приморский край, г. Находка, проспект Мира, д. 24 ""б"""	Россия, Приморский край, город Находка	0101000020E61000009B3924B5D09C60401AF7E6374C664540
73948	4	36	\N	1410	44353	\N	42.799387000000003	Приморский край, г. Находка, ул. Юбилейная, д. 12		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73946	4	36	\N	1410	44353	\N	42.780915692078501	Приморский край, г. Находка, ул. Юбилейная, д. 2		0101000020E610000023F94A20259B60402976340EF5634540
73913	4	36	\N	1410	44473	\N	42.841028734470001	Приморский край, г. Находка, ул. Шоссейная, д. 117		0101000020E6100000842A357BA09D604069FE98D6A66B4540
73925	4	36	\N	1410	44570	\N	42.825287333804297	"Приморский край, г. Находка, Школьный переулок, д. 10 ""а"""		0101000020E61000009A79724D819C604030682101A3694540
73951	4	36	\N	1410	44406	\N	42.778813435925798	Приморский край, г. Находка, ул. Спортивная, д. 6		0101000020E6100000F9BCE2A9479B60408E59F624B0634540
73942	4	36	\N	1410	44354	\N	42.799387000000003	Приморский край, г. Находка, ул. Северная, д. 10		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73918	4	36	\N	1410	44345	\N	42.799387000000003	"Приморский край, г. Находка, ул. Пугачева, д. 2 ""а"""		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73924	4	36	\N	1410	44346	\N	42.836536115465002	Приморский край, г. Находка, ул. Постышева, д. 17		0101000020E6100000C9E4D4CEB09C60409DF6949C136B4540
73923	4	36	\N	1410	44346	\N	42.799387000000003	"Приморский край, г. Находка, ул. Постышева, д. 51 ""а"""		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73929	4	36	\N	1410	44402	\N	42.816576526563203	Приморский край, г. Находка, ул. Пограничная, д. 44	Россия, Приморский край, город Находка	0101000020E610000040F7E5CC769B604039D55A9885684540
73952	4	36	\N	1410	44571	\N	42.778892469412497	"Приморский край, г. Находка, ул. Пирогова, д. 13 ""а"""		0101000020E610000064744012769B6040DA8EA9BBB2634540
73945	4	36	\N	1410	44352	\N	42.799387000000003	Приморский край, г. Находка, Находкинский проспект, д. 108		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73931	4	36	\N	1410	44352	\N	42.811587805872897	Приморский край, г. Находка, Находкинский проспект, д. 44		0101000020E6100000DECB7D72149C6040BCE9961DE2674540
73938	4	36	\N	1410	44349	\N	42.799387000000003	"Приморский край, г. Находка, ул. Нахимовская, д. 21 ""а"""		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73937	4	36	\N	1410	44349	\N	42.804904770700503	Приморский край, г. Находка, ул. Нахимовская, д. 23		0101000020E61000001E54E23AC69B604085B1852007674540
73936	4	36	\N	1410	44349	\N	42.803593356934698	"Приморский край, г. Находка, ул. Нахимовская, д. 7 ""а"""		0101000020E61000008F554ACFF49B6040B325AB22DC664540
73901	4	36	\N	1410	44494	\N	42.799387000000003	Приморский край, г. Находка, с. Анна, ул. Набережная, д. 17		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73939	4	36	\N	1410	44498	\N	42.800385805277998	Приморский край, г. Находка, ул. Молодежная, д. 16		0101000020E610000035ED629AE99B60409016670C73664540
73928	4	36	7436	\N	44401	\N	42.788241413890702	"Приморский край, г. Находка, ул. Мичурина, д. 10 ""а"""	Россия, Приморский край, городской округ Находка	0101000020E610000064778192829C6040E42EC214E5644540
73921	4	36	\N	1410	44344	\N	42.799387000000003	Приморский край, г. Находка, ул. Малиновского, д. 25		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
74490	4	36	\N	1410	44430	\N	42.7854123820956	Приморский край, г. Находка, Макарова, 19		0101000020E6100000882AFC195E9C604067F1626188644540
73935	4	36	\N	1410	44350	\N	42.809423403661	Приморский край, г. Находка, ул. Луначарского, д. 13		0101000020E610000005341136BC9B6040ABD0402C9B674540
73934	4	36	7437	\N	44496	\N	42.791528616862898	Приморский край, г. Находка, ул. Ленинская, д. 22	Россия, Приморский край, городской округ Находка	0101000020E610000039B9DFA1A89C6040F46A80D250654540
73903	4	36	\N	1410	44493	\N	42.799387000000003	"Приморский край, г. Находка, п. Южно-Морской, ул. Комсомольская, д. 2 ""а"""		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73912	4	36	\N	1410	44572	\N	42.781374069211303	Приморский край, г. Находка, ул. Кирова, д. 13	Россия, Приморский край, город Находка	0101000020E61000000C93A982519B6040ECF82F1004644540
73902	4	36	\N	1410	44372	\N	42.799387000000003	Приморский край, г. Находка, п. Южно-Морской, ул. Заводская, д. 16		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73944	4	36	\N	1410	44403	\N	42.799387000000003	Приморский край, г. Находка, ул. Добролюбова, д. 18		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73920	4	36	\N	1410	44495	\N	42.840791873494197	"Приморский край, г. Находка, ул. Дзержинского, д. 9 ""а"""		0101000020E6100000BA111615719C6040855E7F129F6B4540
73919	4	36	\N	1410	44495	\N	42.842931484457203	Приморский край, г. Находка, ул. Дзержинского, д. 3	Россия, Приморский край, город Находка	0101000020E6100000990CC7F3999C60406DE4BA29E56B4540
73932	4	36	7437	\N	44347	\N	42.789513645514397	Приморский край, г. Находка, ул. Владивостокская, д. 22	Россия, Приморский край, городской округ Находка	0101000020E61000001B2AC6F99B9C6040F8DD74CB0E654540
73941	4	36	\N	1410	42808	\N	42.795138731870999	Приморский край, г. Находка, ул. Верхне-Морская, д. 6	Россия, Приморский край, город Находка	0101000020E6100000CF31207BBD9B60401763601DC7654540
73950	4	36	\N	1410	44407	\N	42.824477847385197	Приморский край, г. Находка, ул. Бокситогорская, д. 20	Россия, Приморский край, город Находка	0101000020E6100000C5ABAC6D0A9C6040C022BF7E88694540
74414	4	36	\N	1410	44601	\N	42.799387000000003	"Приморский край, г. Находка, Арсеньева, 14 ""а"""		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73949	4	36	\N	55271	59476	\N	42.779176989123599	"Приморский край, г. Находка, ул. Спортивная, д. 3 ""а"""		0101000020E6100000637B2DE83D9B6040CF656A12BC634540
73947	4	36	\N	55271	59476	\N	42.790935985089703	Приморский край, г. Находка, ул. Спортивная, д. 12	Россия, Приморский край, город Находка	0101000020E6100000E09C11A53D9B6040529D0E643D654540
73916	4	36	\N	55271	44574	\N	42.797617206899197	Приморский край, г. Находка, ул. Садовая, д. 1	Россия, Приморский край, город Находка	0101000020E6100000766EDA8CD39C6040E8DD585018664540
73927	4	36	\N	55271	59475	\N	42.798070891776597	"Приморский край, г. Находка, ул. Мичурина, д. 12 ""а"""	Россия, Приморский край, город Находка	0101000020E6100000E886A6ECF49C60406971C63027664540
73926	4	36	\N	55271	44692	\N	42.799387000000003	Приморский край, г. Находка, ул. Красноармейская, д. 7		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73908	4	36	\N	55271	59483	\N	42.799387000000003	Приморский край, г. Находка, п. Врангель, Восточный проспект, д. 7		0101000020E6100000B08C0DDDEC9C60407DEC2E5052664540
73940	4	36	\N	55271	59486	\N	42.796530201338399	"Приморский край, г. Находка, ул. Верхне-Морская, д. 104 ""а"""		0101000020E6100000111B2C9CA49B60403524EEB1F4654540
74508	4	36	\N	55271	59481	\N	42.796417981270501	Приморский край, г. Находка, Астафьева, 15		0101000020E61000000DC17119B79C60400EF96706F1654540
74507	4	36	\N	55271	59481	\N	42.8133871786725	Приморский край, г. Находка, Астафьева, 123		0101000020E6100000A8734529219C6040EBFEB1101D684540
73905	4	36	\N	55276	44545	\N	42.870203009261097	Приморский край, г. Находка, п. Ливадия, ул. Набережная, д. 4	Россия, Приморский край, городской округ Находка	0101000020E610000092770E6528956040C7F0D8CF626F4540
73815	4	36	\N	55280	59482	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Кравчука, 1 а		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73818	4	36	\N	55280	59510	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Григоренко, 17		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73806	4	36	\N	55280	44561	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Вокзальная, 76		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73803	4	36	\N	88	44880	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, имени Двенадцати, 9		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73804	4	36	\N	88	44486	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Юго-Западный микрорайон, 10		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73821	4	36	\N	88	44336	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Челюскина, 10		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73819	4	36	\N	88	44336	\N	45.4764813731313	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Челюскина, д.10	Россия, Приморский край, город Лесозаводск	0101000020E6100000FF5C34643CAD60402B155454FDBC4640
73822	4	36	\N	88	43197	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Урицкого, 18		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73810	4	36	7355	\N	44395	\N	45.469959512339997	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Пушкинская, 33	Россия, Приморский край, городской округ Лесозаводск	0101000020E6100000E52B819458AC6040CE3637A627BC4640
73808	4	36	\N	88	44395	\N	45.472858210928898	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Пушкинская, 10	Россия, Приморский край, город Лесозаводск	0101000020E61000006C5D6A84FEAC604074D3669C86BC4640
73814	4	36	\N	88	44484	\N	45.470442639193003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Пролетарская, 7		0101000020E61000003D0D18247DAC6040EAD0E97937BC4640
73820	4	36	\N	88	44555	\N	45.479138209720603	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Паровозная, 1	Россия, Приморский край, городской округ Лесозаводск	0101000020E6100000925CFE437AAD6040AB22DC6454BD4640
73816	4	36	\N	88	44776	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, ул. Октябрьская, 81		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73807	4	36	\N	88	44554	\N	45.475756759449297	г. Лесозаводск, Мира, 4	Россия, Приморский край, город Лесозаводск	0101000020E6100000267156444DAD6040EAEBF99AE5BC4640
73823	4	36	7355	\N	44337	\N	45.469959512339997	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Ленинская, 37		0101000020E61000004E9A0645F3AC6040CE3637A627BC4640
73812	4	36	\N	88	43244	\N	45.488236000000001	Приморский край, Лесозаводский городской округг. Лесозаводск, Калининская, 27 а		0101000020E6100000F4A8F8BFA3AD60406C5D6A847EBE4640
73811	4	36	\N	88	43244	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г.Лесозаводск, Калининская, 29 а		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73802	4	36	\N	88	44553	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Дзержинского, 26		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73805	4	36	\N	88	44828	\N	45.4692952061108	Приморский край, Лесозаводский городской округ, г. Лесозаводск, Белова, 8		0101000020E61000001F64593071AC60409296CADB11BC4640
73794	4	36	\N	88	43242	\N	45.474549000000003	Приморский край, Лесозаводский городской округ, г. Лесозаводск, 9 Января, 28		0101000020E6100000817C09159CAC6040BDAC8905BEBC4640
73911	4	36	\N	55306	45015	\N	42.715016109991801	Приморский край, г. Находка, с. Козьмино, ул. Набережная, д. 23	море Японское	0101000020E6100000F6798CF2CCA06040F10EF0A4855B4540
74487	4	36	\N	55332	45168	\N	45.934679000000003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Хоровского, 1а		0101000020E61000009F3A56293DB8604006A1BC8FA3F74640
73700	4	36	\N	55332	59474	\N	45.934679000000003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Советская, 47		0101000020E61000009F3A56293DB8604006A1BC8FA3F74640
73699	4	36	\N	55332	59501	\N	45.929771567389203	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Рябухи, 75		0101000020E6100000E8DD585098B76040465ED6C402F74640
73689	4	36	\N	55332	59491	\N	45.9288731608587	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Ленина, 69а		0101000020E61000002AABE97A22B8604097917A4FE5F64640
74539	4	36	\N	32880	45159	\N	45.931478499446399	692132 Приморский край, Дальнереченский городской округ, г. Дальнереченск Ясная, 11		0101000020E61000000CE8853B17B86040C478CDAB3AF74640
73694	4	36	\N	32880	44629	\N	45.927705210473	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Рябухи, 59		0101000020E610000071395E8168B76040F8AA9509BFF64640
73697	4	36	\N	32880	44628	\N	45.934679000000003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Полтавская, 127		0101000020E61000009F3A56293DB8604006A1BC8FA3F74640
73693	4	36	\N	32880	44621	\N	45.933784271077101	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Личенко, 57		0101000020E610000083A6255646B8604098C3EE3B86F74640
73690	4	36	\N	32880	44619	\N	45.934679000000003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Ленина, 33		0101000020E61000009F3A56293DB8604006A1BC8FA3F74640
73685	4	36	\N	32880	44619	\N	45.930073359637603	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Ленина, 101		0101000020E6100000AD6EF59C74B7604041F2CEA10CF74640
73705	4	36	\N	32880	44646	\N	45.9306999054172	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Кошевого, 1а		0101000020E6100000EF7211DF09B860409031772D21F74640
73687	4	36	\N	32880	44626	\N	45.931837846826497	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Калинина, 91а	Россия, Приморский край, город Дальнереченск	0101000020E61000005C0531D035B86040C495B37746F74640
73691	4	36	\N	32880	44654	\N	45.934679000000003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Заводская, 18		0101000020E61000009F3A56293DB8604006A1BC8FA3F74640
73686	4	36	\N	32880	44645	\N	45.934679000000003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Героев Даманского, 11		0101000020E61000009F3A56293DB8604006A1BC8FA3F74640
73695	4	36	\N	32880	44631	\N	45.926357544655303	Приморский край, Дальнереченский городской округ, г. Дальнереченск, 50 лет Октября, 81		0101000020E6100000179CC1DFAFB76040A93121E692F64640
73704	4	36	\N	32880	44624	\N	45.934679000000003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, 45 лет Октября, 45		0101000020E61000009F3A56293DB8604006A1BC8FA3F74640
73702	4	36	\N	32880	44624	\N	45.918989722364003	Приморский край, Дальнереченский городской округ, г. Дальнереченск, 45 лет Октября, 68		0101000020E610000029B000A68CB86040EFACDD76A1F54640
73676	4	36	\N	55263	59472	\N	44.552501999999997	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Проспект 50 лет Октября, 124		0101000020E6100000E20165532EF26040BF7CB262B8464640
73674	4	36	\N	55263	59472	\N	44.550535207392201	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Проспект 50 лет Октября, 49		0101000020E610000033880FECF8F16040D5264EEE77464640
73671	4	36	\N	55263	44478	\N	44.552501999999997	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Пионерская, 17		0101000020E6100000E20165532EF26040BF7CB262B8464640
73666	4	36	\N	4988	44831	\N	44.552501999999997	Приморский край, Дальнегорский городской округ, г. Дальнегорск, ул. Школьная, 14		0101000020E6100000E20165532EF26040BF7CB262B8464640
73678	4	36	\N	4988	43180	\N	44.557531538396603	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Химиков, 8а		0101000020E61000002D93E1783EF360409B3C65355D474640
73677	4	36	\N	4988	43110	\N	44.552501999999997	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Проспект 50 лет Октября, 127		0101000020E6100000E20165532EF26040BF7CB262B8464640
73675	4	36	\N	4988	43110	\N	44.556672385466101	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Проспект 50 лет Октября, 63		0101000020E6100000923D42CD90F26040A94C310741474640
73673	4	36	\N	4988	43110	\N	44.552501999999997	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Проспект 50 лет Октября, 47		0101000020E6100000E20165532EF26040BF7CB262B8464640
73669	4	36	\N	4988	43098	\N	44.552501999999997	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Приморская 23		0101000020E6100000E20165532EF26040BF7CB262B8464640
73679	4	36	\N	4988	44615	\N	44.557408803045597	Приморский край, Дальнегорский городской округ, г. Дальнегорск, Первомайская, 8а	Россия, Приморский край, город Дальнегорск	0101000020E610000034A0DE8C1AF460407FBF982D59474640
74549	4	36	\N	1538	\N	\N	43.071143849647903	690001 Приморский край, город Владивосток, Первомайский район, полуостров Назимова  здание временной конторы подрядчика	Россия, Приморский край, Владивосток, улица Бархатная	0101000020E6100000FE43FAEDEB7D60403FA7203F1B894540
73657	4	36	\N	1538	\N	\N	43.106934000000003	Приморский край, Владивостокский городской округ, Фрунзенский район, с. Береговое, МОУ СОШ № 49		0101000020E610000026AB22DCE47B60404D6A6803B08D4540
73400	4	36	\N	55260	44512	\N	44.152288971666501	Приморский край, г. Арсеньев, ул. Жуковского, 54		0101000020E61000005C001AA5CBA860403145B9347E134640
74506	4	36	\N	1538	619	\N	43.125328000000003	Приморский край, Владивостокский городской округ, Ленинский район, Адмирала Юмашева, 40	Россия, Приморский край, Владивосток, улица адмирала Юмашева, 40	0101000020E61000009C69C2F6937E6040F5A276BF0A904540
73539	4	36	\N	1538	5394	\N	43.089936999999999	Приморский край, город Владивосток, Первомайский район, Каштановая, 5/А	Россия, Приморский край, Владивосток, улица Каштановая, 5а	0101000020E6100000567DAEB6627D6040A5D93C0E838B4540
73607	4	36	\N	1538	6152	\N	43.2115130615366	Приморский край, город Владивосток, Советский район, Верещагина, 24	Россия, Приморский край, Владивосток, улица Верещагина, 22	0101000020E6100000C61858C7F17E6040E4D6A4DB129B4540
73613	4	36	\N	1538	44618	\N	43.178976549724403	Приморский край, город Владивосток, Советский район, Проспект 100-летия Владивостока, 155	Россия, Приморский край, Владивосток, 100 Лет Владивостоку проспект, 155	0101000020E6100000E8A562635E7D60403CDEE4B7E8964540
73497	4	36	\N	1538	44668	\N	43.125999	Приморский край, город Владивосток, Ленинский район, Адмирала Юмашева, 20а		0101000020E61000001E32E543507E6040132A38BC20904540
73496	4	36	\N	1538	44668	\N	43.124755	Приморский край, город Владивосток, Ленинский район, Адмирала Юмашева, 12г		0101000020E6100000E413B2F3367E60409981CAF8F78F4540
73641	4	36	\N	1538	44768	\N	43.117984	"Приморский край, город Владивосток, Фрунзенский район, Адм. Фокина, 11, МБОУ ""Средняя вечерняя школа №2"		0101000020E6100000ECA353573E7C6040C3B986191A8F4540
73602	4	36	\N	1538	44912	\N	43.208947999999999	Приморский край, город Владивосток, Советский район, Адмирала Угрюмова, клуб Военного городка		0101000020E6100000D253E410F18260404548DDCEBE9A4540
74499	4	36	\N	1538	44738	\N	43.124301000000003	Приморский край, Владивостокский городской округ, Ленинский район, Адмирала Кузнецова, 40а		0101000020E610000051853FC39B7E604018EE5C18E98F4540
73498	4	36	\N	1538	44738	\N	43.124301000000003	Приморский край, город Владивосток, Ленинский район, Адмирала Кузнецова, 40а		0101000020E610000051853FC39B7E604018EE5C18E98F4540
73632	4	36	\N	1538	44705	\N	43.087375000000002	Приморский край, Владивостокский городской округ, Фрунзенский район, Ялтинская, 18	Россия, Приморский край, Владивосток, улица Ялтинская, 18	0101000020E610000086713788567B604077BE9F1A2F8B4540
73506	4	36	\N	1538	44368	\N	43.122649420541201	Приморский край, город Владивосток, Ленинский район, Щитовая, 43	Россия, Приморский край, Владивосток, Ленинский район	0101000020E610000060C8EA56CF7E60408DF161F6B28F4540
73563	4	36	\N	1538	44643	\N	43.153016000000001	Приморский край, г. Владивосток, Первореченский район, ул.Шошина, д.25		0101000020E6100000B6847CD0B37D6040E3E13D0796934540
73561	4	36	\N	1538	44643	\N	43.153016000000001	Приморский край, г. Владивосток, Первореченский район, ул.Шошина, д.27		0101000020E6100000B6847CD0B37D6040E3E13D0796934540
73489	4	36	\N	1538	44736	\N	43.119076	Приморский край, город Владивосток, Ленинский район, Шилкинская, 19		0101000020E6100000F4893C49BA7D604087DEE2E13D8F4540
73500	4	36	\N	1538	44687	\N	43.118616000000003	Приморский край, город Владивосток, Ленинский район, Шепеткова, 60	Россия, Приморский край, Владивосток, улица Шепеткова, 60	0101000020E6100000EAB0C22D1F7E6040246420CF2E8F4540
73614	4	36	\N	1538	44698	\N	43.179141000000001	Приморский край, город Владивосток, Советский район, Чкалова, 15		0101000020E610000051A5660F347D6040B62FA017EE964540
73549	4	36	\N	1538	44665	\N	43.094920000000002	Приморский край, город Владивосток, Первомайский район, Черемуховая, 2		0101000020E6100000A930B610E47C604040DEAB56268C4540
73548	4	36	\N	1538	44665	\N	43.098903	Приморский край, город Владивосток, Первомайский район, Черемуховая, 20		0101000020E6100000CAFACDC4F47C6040F73C7FDAA88C4540
73547	4	36	\N	1538	44665	\N	43.101951	Приморский край, город Владивосток, Первомайский район, Черемуховая, 17		0101000020E6100000137D3ECA087D6040B265F9BA0C8D4540
73611	4	36	\N	1538	44759	\N	43.184643000000001	Приморский край, город Владивосток, Советский район, Чапаева, 5		0101000020E610000033FD12F1567D6040B937BF61A2974540
73546	4	36	\N	1538	44709	\N	43.094473000000001	Приморский край, город Владивосток, Первомайский район, Херсонская, 4		0101000020E61000007D923B6CA27C604071ADF6B0178C4540
74519	4	36	\N	1538	44641	\N	43.098676065060801	Приморский край, Владивостокский городской округ, Первомайский район, Харьковская, 7	Россия, Приморский край, Владивосток, улица Харьковская	0101000020E6100000390F27301D7D60403673486AA18C4540
73542	4	36	\N	1538	44641	\N	43.103096000000001	Приморский край, город Владивосток, Первомайский район, Харьковская, 36/А		0101000020E6100000750305DEC97C6040992CEE3F328D4540
73535	4	36	\N	1538	44641	\N	43.098818000000001	Приморский край, город Владивосток, Первомайский район, Харьковская, 7		0101000020E61000000890A163077D6040C9207711A68C4540
73653	4	36	\N	1538	44660	\N	43.134130999999996	Приморский край, город Владивосток, Фрунзенский район, Хабаровская, 24б,  МБОУ СОШ № 18		0101000020E6100000BD19355FA57C60409C3061342B914540
73652	4	36	\N	1538	44660	\N	43.134130999999996	Приморский край, город Владивосток, Фрунзенский район, Хабаровская, 24б, МБОУ СОШ № 18		0101000020E6100000BD19355FA57C60409C3061342B914540
73649	4	36	\N	1538	44660	\N	43.134169999999997	Приморский край, город Владивосток, Фрунзенский район, Хабаровская, 18, ГОУ СПО Влад.художест.училище		0101000020E61000002AE44A3D8B7C60405A0D897B2C914540
73648	4	36	\N	1538	44660	\N	43.132677000000001	"Приморский край, город Владивосток, Фрунзенский район, Хабаровская, 7, МБОУ ДОД ""Детс.юнош.центр"""		0101000020E6100000C79DD2C17A7C604038F7578FFB904540
74518	4	36	\N	1538	45150	\N	43.1025727212768	Приморский край, Владивостокский городской округ, Ленинский район, Фадеева, 35	Россия, Приморский край, Владивосток, улица Фадеева, 35	0101000020E6100000723106D6717E6040EF39B01C218D4540
73605	4	36	\N	1538	44749	\N	43.234805000000001	Приморский край, город Владивосток, Советский район, Успенского, 19		0101000020E610000096E7C1DD59806040F9F719170E9E4540
73604	4	36	\N	1538	44749	\N	43.242213999999997	Приморский край, город Владивосток, Советский район, Успенского, 73		0101000020E6100000F581E49DC380604011514CDE009F4540
73477	4	36	\N	1538	44647	\N	43.120932000000003	Приморский край, город Владивосток, Ленинский район, Уборевича, 25		0101000020E61000009D8026C2867C60401B8524B37A8F4540
73476	4	36	\N	1538	44647	\N	43.116128303402498	Приморский край, город Владивосток, Ленинский район, Уборевича, 5	Россия, Приморский край, Владивосток, улица Уборевича	0101000020E6100000E083D72E6D7C604030134548DD8E4540
73475	4	36	\N	1538	44647	\N	43.116298999999998	Приморский край, город Владивосток, Ленинский район, Уборевича, 8		0101000020E6100000AE49B725727C60405CC7B8E2E28E4540
73560	4	36	\N	1538	44653	\N	43.159908354418597	Приморский край, г. Владивосток, Первореченский район, ул.Тухачевского, д.28	Россия, Приморский край, Владивосток, улица Тухачевского	0101000020E61000009E996038D77D6040342F87DD77944540
74498	4	36	\N	1538	44679	\N	43.115403999999998	Приморский край, Владивостокский городской округ, Ленинский район, Тунгусская, 59		0101000020E610000006685BCDBA7D6040EEE9EA8EC58E4540
73493	4	36	\N	1538	44679	\N	43.115732999999999	Приморский край, город Владивосток, Ленинский район, Тунгусская, 24		0101000020E61000004E42E90BA17D6040B308C556D08E4540
74495	4	36	\N	1538	44702	\N	43.121727999999997	Приморский край, Владивостокский городской округ, Ленинский район, Толстого, 27		0101000020E6100000A530EF71267D6040F58079C8948F4540
74494	4	36	\N	1538	44702	\N	43.123576999999997	Приморский край, Владивостокский городской округ, Ленинский район, Толстого, 54		0101000020E61000002250FD83487D6040D6C4025FD18F4540
73487	4	36	\N	1538	44702	\N	43.121727999999997	Приморский край, город Владивосток, Ленинский район, Толстого, 27		0101000020E6100000A530EF71267D6040F58079C8948F4540
73486	4	36	\N	1538	44702	\N	43.123576999999997	Приморский край, город Владивосток, Ленинский район, Толстого, 54		0101000020E61000002250FD83487D6040D6C4025FD18F4540
73524	4	36	\N	1538	44713	\N	43.098422999999997	Приморский край, город Владивосток, Первомайский район, Талалихина, 5		0101000020E61000007D3D5FB35C7E60404C16F71F998C4540
74500	4	36	\N	1538	44757	\N	43.117770840312403	Приморский край, Владивостокский городской округ, Ленинский район, Суханова, 1а		0101000020E610000069AA27F38F7C604067B5C01E138F4540
73482	4	36	\N	1538	44757	\N	43.117510000000003	Приморский край, город Владивосток, Ленинский район, Суханова, 3		0101000020E61000007993DFA2937C6040FB7953910A8F4540
73637	4	36	\N	1538	44690	\N	43.107025999999998	Приморский край, город Владивосток, Фрунзенский район, Станюковича, 28, ПИППКРО		0101000020E610000018CC5F21F37B60402DE92807B38D4540
74548	4	36	\N	1538	44739	\N	43.117173999999999	690013 Приморский край, Владивостокский городской округ, Ленинский район Спиридонова 40		0101000020E610000023861DC6247E604083F8C08EFF8E4540
74547	4	36	\N	1538	44739	\N	43.116536000000004	690013 Приморский край, Владивостокский городской округ, Ленинский район Спиридонова 36		0101000020E61000001899805F237E60404167D2A6EA8E4540
73502	4	36	\N	1538	44739	\N	43.113830999999998	Приморский край, город Владивосток, Ленинский район, Спиридонова, 9		0101000020E610000023861DC6247E6040AF22A303928E4540
73586	4	36	\N	1538	44634	\N	43.138986000000003	Приморский край, г. Владивосток, Первореченский район, ул.Снеговая, д.35		0101000020E61000008C9FC6BDF97E60400A4D124BCA914540
73587	4	36	\N	1538	44724	\N	43.130505999999997	Приморский край, г. Владивосток, Первореченский район, ул.Сельская, д.1		0101000020E61000007E022846167E604044F7AC6BB4904540
73513	4	36	\N	1538	44661	\N	43.114621	Приморский край, Владивостокский городской округ, Ленинский район, Светланская, 119а		0101000020E6100000BA490C022B7D6040A837A3E6AB8E4540
73495	4	36	\N	1538	44661	\N	43.113613999999998	Приморский край, город Владивосток, Ленинский район, Светланская, 207		0101000020E61000003F558506E27D6040122F4FE78A8E4540
73491	4	36	\N	1538	44661	\N	43.113950000000003	Приморский край, город Владивосток, Ленинский район, Светланская, 147		0101000020E61000001F2DCE18667D60408AB0E1E9958E4540
73484	4	36	\N	1538	44661	\N	43.114621	Приморский край, город Владивосток, Ленинский район, Светланская, 119а		0101000020E6100000BA490C022B7D6040A837A3E6AB8E4540
73518	4	36	\N	1538	44656	\N	43.091866000000003	Приморский край, город Владивосток, Первомайский район, Сахалинская, 23/А		0101000020E610000069E388B5F87E6040A3CEDC43C28B4540
73517	4	36	\N	1538	44656	\N	43.095202999999998	Приморский край, город Владивосток, Первомайский район, Сахалинская, 57		0101000020E6100000F5126399FE7E604094BDA59C2F8C4540
73583	4	36	\N	1538	44697	\N	43.128953000000003	Приморский край, г. Владивосток, Первореченский район, ул.Сабанеева, д.8		0101000020E6100000289A07B0487E60404DDC2A8881904540
73627	4	36	\N	1538	44667	\N	43.175874	Приморский край, город Владивосток, Советский район, Русская, 57		0101000020E6100000DA1CE736E17D6040BD1B0B0A83964540
73625	4	36	\N	1538	44667	\N	43.175564999999999	Приморский край, город Владивосток, Советский район, Русская, 96а		0101000020E610000063416150267E60403FA9F6E978964540
73624	4	36	\N	1538	44667	\N	43.170639999999999	Приморский край, город Владивосток, Советский район, Русская, 67/2		0101000020E610000095658863DD7D6040D9B11188D7954540
73623	4	36	\N	1538	44667	\N	43.171081000000001	Приморский край, город Владивосток, Советский район, Русская, 43		0101000020E6100000F5A276BF8A7D6040C6FB71FBE5954540
73619	4	36	\N	1538	44667	\N	43.165734999999998	Приморский край, город Владивосток, Советский район, Русская, 40		0101000020E61000006C5B94D9207D6040BA66F2CD36954540
73618	4	36	\N	1538	44667	\N	43.166263776781399	Приморский край, город Владивосток, Советский район, Енисейская, 7а		0101000020E61000001E537765177D60404640852348954540
73617	4	36	\N	1538	44667	\N	43.168101999999998	Приморский край, город Владивосток, Советский район, Русская, 21		0101000020E61000003C50A73C3A7D60403332C85D84954540
73483	4	36	\N	1538	44684	\N	43.11674	Приморский край, город Владивосток, Ленинский район, Пушкинская, 39		0101000020E61000005F0D501AEA7C604049111956F18E4540
73597	4	36	\N	1538	44744	\N	43.297511	Приморский край, город Владивосток, Советский район, п. Трудовое, Путятинская, 135		0101000020E61000007E5704FFDB816040A29927D714A64540
73541	4	36	\N	1538	44755	\N	43.087572999999999	Приморский край, город Владивосток, Первомайский район, Приморская, 5		0101000020E61000006325E659C97C60409D819197358B4540
74517	4	36	\N	1538	45141	\N	43.121656000000002	Приморский край, Владивостокский городской округ, Ленинский район, Прапорщика Комарова, 35а		0101000020E610000050172994857C60405CAE7E6C928F4540
73565	4	36	\N	1538	44720	\N	43.157764999999998	Приморский край, г. Владивосток, Первореченский район, ул.Постышева, д.37		0101000020E6100000C4B0C398747D60400ABABDA431944540
73540	4	36	\N	1538	44695	\N	43.085524999999997	Приморский край, город Владивосток, Первомайский район, Поселковая 2-я, 51		0101000020E610000002B859BCD87C6040C5FEB27BF28A4540
73595	4	36	\N	1538	44644	\N	43.301448000000001	Приморский край, город Владивосток, Советский район, п.Трудовое, Порт-Артурская (бывшая Восточная), 48		0101000020E6100000D388997D9E826040E9B81AD995A64540
73529	4	36	\N	1538	44715	\N	43.098607000000001	Приморский край, город Владивосток, Первомайский район, Полярная, 7		0101000020E61000007B116DC7D47D60400E1478279F8C4540
73550	4	36	\N	1538	44756	\N	43.258156999999997	Приморский край, город Владивосток, Первомайский район, Подгорная, 23		0101000020E6100000541B9C887E816040E21DE0490BA14540
73663	4	36	\N	1538	45146	\N	43.124465999999998	Приморский край, город Владивосток, Фрунзенский район, Пограничная, 26, Общежитие ДВФУ		0101000020E6100000121615713A7C604062BB7B80EE8F4540
73588	4	36	\N	1538	44673	\N	43.126564999999999	Приморский край, г. Владивосток, Первореченский район, ул.Писаревская, д.6/8		0101000020E610000072C3EFA65B7D6040BCE82B4833904540
73608	4	36	\N	1538	44745	\N	43.216200999999998	Приморский край, город Владивосток, Советский район, Пирогова, 7		0101000020E61000000954FF20927E6040662E7079AC9B4540
73515	4	36	\N	1538	44740	\N	43.094203	Приморский край, город Владивосток, Первомайский район, Пацаева, 2		0101000020E61000003E40F7E54C7F6040B1170AD80E8C4540
74025	4	36	\N	1538	1551	\N	43.124558	Приморский край, Партизанский городской округ, Калинина, 12-а	Россия, Приморский край, Владивосток, Партизанский проспект, 12а	0101000020E6100000EC32FCA79B7C6040433A3C84F18F4540
74015	4	36	\N	1538	1551	\N	43.125445999999997	Приморский край, Партизанский городской округ, Вокзальная, 1	Россия, Приморский край, Владивосток, Партизанский проспект, 1	0101000020E61000006F2BBD369B7C6040FEB4519D0E904540
74012	4	36	\N	1538	1551	\N	43.128630999999999	Приморский край, Партизанский городской округ, Кутузова, 52	Россия, Приморский край, Владивосток, Партизанский проспект, 52	0101000020E61000006552431B007D60403A2009FB76904540
74005	4	36	\N	1538	1551	\N	43.125445999999997	Приморский край, Партизанский городской округ, Московская, 1	Россия, Приморский край, Владивосток, Партизанский проспект, 1	0101000020E61000006F2BBD369B7C6040FEB4519D0E904540
73998	4	36	\N	1538	1551	\N	43.128610999999999	Приморский край, Партизанский городской округ, Разгонова, 37	Россия, Приморский край, Владивосток, Партизанский проспект, 37	0101000020E6100000D7D9907FE67C6040F373435376904540
73577	4	36	\N	1538	1551	\N	43.129308000000002	Приморский край, г. Владивосток, Первореченский район, Партизанский проспект, д.62а	Россия, Приморский край, Владивосток, Партизанский проспект, 62а	0101000020E61000009C35785F157D60403B8E1F2A8D904540
73610	4	36	\N	1538	44765	\N	43.199576999999998	Приморский край, город Владивосток, Советский район, Пальчевского, 17		0101000020E61000002828452B777D6040530438BD8B994540
73576	4	36	\N	1538	5825	\N	43.129722999999998	Приморский край, г. Владивосток, Первореченский район, пр-т. Острякова, д.2а	Россия, Приморский край, Владивосток, Острякова проспект, 2а	0101000020E6100000ADA7565FDD7C6040FE4465C39A904540
73600	4	36	\N	1538	44642	\N	43.256462999999997	Приморский край, город Владивосток, Советский район, Опорная, 6		0101000020E61000003352EFA91C81604028D192C7D3A04540
73537	4	36	\N	1538	44753	\N	43.092247999999998	Приморский край, город Владивосток, Первомайский район, Олега Кошевого, 26		0101000020E6100000CFF57D38487D60408A8F4FC8CE8B4540
73644	4	36	\N	1538	44726	\N	43.125295000000001	Приморский край, город Владивосток, Фрунзенский район, Октябрьская, 13, ГОУ СПО Гидрометеорол.техникум		0101000020E61000006CB587BD507C604019ADA3AA09904540
73642	4	36	\N	1538	5915	\N	43.120136000000002	Приморский край, город Владивосток, Фрунзенский район, Океанский проспект, 19, ФГАОУ ВПО ДВФУ	Россия, Приморский край, Владивосток, Океанский проспект, 19	0101000020E61000003CDBA3375C7C60404089CF9D608F4540
73585	4	36	\N	1538	5915	\N	43.132828000000003	Приморский край, г. Владивосток, Первореченский район, Океанский проспект, д.102а	Россия, Приморский край, Владивосток, Океанский проспект, 102а	0101000020E61000001956F146E67C60401EFF058200914540
73584	4	36	\N	1538	5915	\N	43.133572000000001	Приморский край, г. Владивосток, Первореченский район, Океанский проспект, д.143	Россия, Приморский край, Владивосток, Океанский проспект, 143	0101000020E61000005DDC4603F87C6040A6D425E318914540
73566	4	36	\N	1538	44721	\N	43.155712999999999	Приморский край, г. Владивосток, Первореченский район, ул.Овчинникова, д.34		0101000020E61000005EF415A4197D6040F1475167EE934540
73552	4	36	\N	1538	44670	\N	43.095301999999997	Приморский край, Владивостокский городской округ, Первомайский район, Никифорова, 41/А		0101000020E610000007CF8426897E6040279F1EDB328C4540
73523	4	36	\N	1538	44670	\N	43.095301999999997	Приморский край, город Владивосток, Первомайский район, Никифорова, 41/А		0101000020E610000007CF8426897E6040279F1EDB328C4540
73512	4	36	\N	1538	44639	\N	43.124347	Приморский край, Владивостокский городской округ, Ленинский район, Нерчинская, 32		0101000020E61000006556EF70BB7C6040882D3D9AEA8F4540
73479	4	36	\N	1538	44639	\N	43.123550999999999	Приморский край, город Владивосток, Ленинский район, Нерчинская, 21		0101000020E6100000C2853C829B7C6040AD31E884D08F4540
73478	4	36	\N	1538	44639	\N	43.123718359160499	Приморский край, город Владивосток, Ленинский район, Нерчинская, 32	Россия, Приморский край, Владивосток, улица Нерчинская	0101000020E6100000CDACA580B47C604098F6CDFDD58F4540
74501	4	36	\N	1538	546	\N	43.118267000000003	Приморский край, Владивостокский городской округ, Ленинский район, пер. Некрасовский, 1	Россия, Приморский край, Владивосток, Некрасовский переулок, 1	0101000020E6100000643E20D0997C60401899805F238F4540
73485	4	36	\N	1538	44686	\N	43.121780999999999	Приморский край, город Владивосток, Ленинский район, Некрасовская, 58		0101000020E61000001502B9C4117D604018231285968F4540
73510	4	36	\N	1538	44746	\N	43.107210000000002	Приморский край, город Владивосток, Ленинский район, Нейбута, 26		0101000020E6100000E22021CA977E6040EFE6A90EB98D4540
74521	4	36	\N	1538	44731	\N	43.148564	Приморский край, г. Владивосток, Первореченский район, ул.Невская, д.20А		0101000020E6100000707D586F547D604075AE282504934540
73507	4	36	\N	1538	44693	\N	43.116497000000003	Приморский край, город Владивосток, Ленинский район, Невельского, 31		0101000020E61000008A0629788A7E6040838AAA5FE98E4540
73570	4	36	\N	1538	44640	\N	43.151800450990997	Приморский край, г. Владивосток, Первореченский район, ул.Нахимова, д.6	Россия, Приморский край, Владивосток, улица Нахимова	0101000020E6100000BAD7497D597D604033C4B12E6E934540
73578	4	36	\N	1538	5855	\N	43.127656999999999	Приморский край, г. Владивосток, Первореченский район, Народный проспект, д.27а	Россия, Приморский край, Владивосток, Народный проспект, 27а	0101000020E6100000BCE6559D557D6040800D881057904540
73640	4	36	\N	1538	44750	\N	43.113067999999998	"Приморский край, город Владивосток, Фрунзенский район, Набережная, 1, МБОУ ""Средняя школа № 13"""		0101000020E6100000B5183C4CFB7B6040B01C2103798E4540
73639	4	36	\N	1538	44750	\N	43.113067999999998	"Приморский край, город Владивосток, Фрунзенский район, Набережная, 1, МБОУ ""Средняя школа  №1"""		0101000020E6100000B5183C4CFB7B6040B01C2103798E4540
73492	4	36	\N	1538	44737	\N	43.112909999999999	Приморский край, город Владивосток, Ленинский район, Муравьева-Амурского, 5		0101000020E6100000E945ED7E957D604018B2BAD5738E4540
73634	4	36	\N	1538	44727	\N	43.092182000000001	Приморский край, город Владивосток, Фрунзенский район, Морозова, 5		0101000020E6100000C1374D9F9D7B6040D3A3A99ECC8B4540
73601	4	36	\N	1538	44920	\N	43.25515	Приморский край, город Владивосток, Советский район, Минеральная, 17		0101000020E6100000ADA23F347381604086C954C1A8A04540
73609	4	36	\N	1538	44769	\N	43.213678000000002	Приморский край, город Владивосток, Советский район, Маковского, 41		0101000020E6100000EE7A698A807E6040F6EFFACC599B4540
74538	4	36	\N	1538	44742	\N	43.132019	Приморский край, город Владивосток, Первореченский район Луговая 56а		0101000020E6100000552E54FE357E6040AEB9A3FFE5904540
74537	4	36	\N	1538	44742	\N	43.131228999999998	Приморский край, город Владивосток, Первореченский район Луговая 54		0101000020E610000016687748317E6040B5A4A31CCC904540
74536	4	36	\N	1538	44742	\N	43.130215999999997	Приморский край, город Владивосток, Первореченский район Луговая 48		0101000020E61000002C8194D8357E60403DB5FAEAAA904540
73554	4	36	\N	1538	44742	\N	43.128281999999999	Приморский край, г. Владивосток, Первореченский район, ул.Луговая, д.52а		0101000020E6100000E97FB9162D7E60402E55698B6B904540
73596	4	36	\N	1538	44725	\N	43.297721000000003	Приморский край, город Владивосток, Советский район, п.Трудовое, Лермонтова, 91/3		0101000020E6100000433866D9138260408D2AC3B81BA64540
73593	4	36	\N	1538	44725	\N	43.309635	Приморский край, город Владивосток, Советский район, п.Трудовое, Лермонтова, 30		0101000020E6100000151E34BB6E8260403659A31EA2A74540
73594	4	36	\N	1538	44767	\N	43.300345999999998	Приморский край, город Владивосток, Советский район, п.Трудовое, Лермонтова, 69/1		0101000020E6100000600322C41582604001BEDBBC71A64540
73504	4	36	\N	1538	44741	\N	43.108566000000003	Приморский край, город Владивосток, Ленинский район, Куйбышева, 1		0101000020E61000004CC631923D7E604091BA9D7DE58D4540
74496	4	36	\N	1538	397	\N	43.121715000000002	Приморский край, Владивостокский городской округ, Ленинский район, проспект Красного Знамени, 123	Россия, Приморский край, Владивосток, Красного Знамени проспект, 123	0101000020E610000088F37002D37D604061376C5B948F4540
74491	4	36	\N	1538	397	\N	43.127453000000003	Приморский край, г. Владивосток, Первореченский район, пр-т. Красного Знамени, д. 43	Россия, Приморский край, Владивосток, Красного Знамени проспект, 45	0101000020E6100000D9226937FA7C60407863416150904540
73647	4	36	\N	1538	397	\N	43.129131000000001	Приморский край, город Владивосток, Фрунзенский район, проспект Красного Знамени, 25а, МБОУ СОШ № 17	Россия, Приморский край, Владивосток, Красного Знамени проспект, 23	0101000020E610000054E57B46A27C60402CF3565D87904540
73646	4	36	\N	1538	397	\N	43.1292877100582	Приморский край, город Владивосток, Фрунзенский район, пр-т Красного Знамени, 25а	Россия, Приморский край, Владивосток, Красного Знамени проспект	0101000020E61000006FF25B74B27C6040F4E159828C904540
73645	4	36	\N	1538	397	\N	43.1291703288273	Приморский край, город Владивосток, Фрунзенский район, пр-т Красного Знамени, 25а, МБОУ СОШ №17	Россия, Приморский край, Владивосток, Красного Знамени проспект	0101000020E6100000DB32E02CA57C6040EACF7EA488904540
73533	4	36	\N	1538	44752	\N	43.096803000000001	Приморский край, город Владивосток, Первомайский район, Вязовая, 1		0101000020E610000023BC3D08817D6040CD936B0A648C4540
73490	4	36	\N	1538	397	\N	43.121715000000002	Приморский край, город Владивосток, Ленинский район, проспект Красного Знамени, 123	Россия, Приморский край, Владивосток, Красного Знамени проспект, 123	0101000020E610000088F37002D37D604061376C5B948F4540
73580	4	36	\N	1538	44732	\N	43.128189999999996	Приморский край, г. Владивосток, Первореченский район, ул.Котельникова, д.7		0101000020E61000005D6A847EA67D60404DD6A88768904540
73519	4	36	\N	1538	44711	\N	43.088673	Приморский край, город Владивосток, Первомайский район, Космонавтов, 15		0101000020E6100000CFF41263197F6040E48409A3598B4540
73494	4	36	\N	1538	44664	\N	43.112805000000002	Приморский край, город Владивосток, Ленинский район, Ковальчука, 6/8		0101000020E6100000153C855CA97D6040A3E9EC64708E4540
73612	4	36	\N	1538	44766	\N	43.184499000000002	Приморский край, город Владивосток, Советский район, Кирова, 93		0101000020E6100000BFB51325217D60408692C9A99D974540
73562	4	36	\N	1538	44717	\N	43.155785000000002	Приморский край, г. Владивосток, Первореченский район, ул.Карбышева, д.11		0101000020E610000047205ED7AF7D60408B1A4CC3F0934540
73501	4	36	\N	1538	44689	\N	43.110916000000003	Приморский край, город Владивосток, Ленинский район, Каплунова, 12		0101000020E6100000CB2BD7DB667E6040344DD87E328E4540
73574	4	36	\N	1538	44659	\N	43.140512000000001	Приморский край, г. Владивосток, Первореченский район, ул. Камская, д.5б		0101000020E610000047E5266A697D60400859164CFC914540
73545	4	36	\N	1538	44669	\N	43.094538999999997	Приморский край, город Владивосток, Первомайский район, Калинина, 253/А		0101000020E61000008352B472AF7C604028999CDA198C4540
73543	4	36	\N	1538	44669	\N	43.098514999999999	Приморский край, город Владивосток, Первомайский район, Калинина, 153		0101000020E6100000B8C9A8328C7C60402D95B7239C8C4540
73532	4	36	\N	1538	44669	\N	43.102137383283598	Приморский край, город Владивосток, Первомайский район, Калинина, 29	Россия, Приморский край, Владивосток, улица Калинина, 29	0101000020E6100000E621533E847D6040145B41D3128D4540
73635	4	36	\N	1538	44648	\N	43.094952999999997	"Приморский край, город Владивосток, Фрунзенский район, Казанская, 4/6, МБОУ ""Средняя школа №6"""		0101000020E6100000CE55F31C917B60401BD47E6B278C4540
73633	4	36	\N	1538	44648	\N	43.0949064350024	"Приморский край, Владивостокский городской округ, Фрунзенский район, Казанская, 4/6,  МБОУ ""Средняя школа №6"""	Россия, Приморский край, Владивосток, улица Казанская, 6	0101000020E6100000DECB7D72947B6040DB183BE1258C4540
73559	4	36	\N	1538	44672	\N	43.161349000000001	Приморский край, г. Владивосток, Первореченский район, ул.Иртышская, д.40/1		0101000020E61000005DFDD824BF7D6040041F8315A7944540
73557	4	36	\N	1538	44672	\N	43.159455000000001	Приморский край, г. Владивосток, Первореченский район, ул.Иртышская, д.6		0101000020E61000006682E15C437D604083177D0569944540
73556	4	36	\N	1538	44672	\N	43.160336000000001	Приморский край, г. Владивосток, Первореченский район, ул.Иртышская, д.10		0101000020E6100000EB538EC9627D60408C2FDAE385944540
73534	4	36	\N	1538	44675	\N	43.100628	Приморский край, город Владивосток, Первомайский район, Интернациональная, 48		0101000020E61000002368CC246A7D6040EC87D860E18C4540
73558	4	36	\N	1538	44719	\N	43.152470000000001	Приморский край, г. Владивосток, Первореченский район, ул.Ильичева, д.26		0101000020E61000002DE92807337D604081CF0F2384934540
73579	4	36	\N	1538	44758	\N	43.130572000000001	Приморский край, г. Владивосток, Первореченский район, ул.Жигура, д.52а		0101000020E6100000AA7F10C9907D6040FCE25295B6904540
73516	4	36	\N	1538	44710	\N	43.095084999999997	Приморский край, город Владивосток, Первомайский район, Добровольского, 20		0101000020E6100000FFCD8B135F7F60408AABCABE2B8C4540
73575	4	36	\N	1538	5815	\N	43.145603999999999	Приморский край, г. Владивосток, Первореченский район, Днепровский переулок, д.2	Россия, Приморский край, Владивосток, Днепровский переулок, 2	0101000020E61000005F24B4E55C7D60405915E126A3924540
74505	4	36	\N	1538	44922	\N	43.119695	Приморский край, Владивостокский городской округ, Ленинский район, Державина, 15		0101000020E61000004696CCB1BC7C6040533F6F2A528F4540
74504	4	36	\N	1538	44922	\N	43.121609999999997	Приморский край, Владивостокский городской округ, Ленинский район, Державина, 21		0101000020E6100000C3F17C06D47C6040EB6E9EEA908F4540
74503	4	36	\N	1538	44922	\N	43.120964999999998	Приморский край, Владивостокский городской округ, Ленинский район, Державина, 19		0101000020E6100000E1ED4108C87C6040F67AF7C77B8F4540
74502	4	36	\N	1538	44922	\N	43.120234000000004	Приморский край, Владивостокский городской округ, Ленинский район, Державина, 17		0101000020E61000007F6B274AC27C604003EFE4D3638F4540
73481	4	36	\N	1538	44922	\N	43.124558	Приморский край, город Владивосток, Ленинский район, Державина, 57		0101000020E6100000E144F46BEB7C6040433A3C84F18F4540
73622	4	36	\N	1538	44747	\N	43.169884000000003	Приморский край, город Владивосток, Советский район, Давыдова, 3		0101000020E610000043AA285E657D60408D0E48C2BE954540
73526	4	36	\N	1538	44714	\N	43.096466999999997	Приморский край, город Владивосток, Первомайский район, Гризодубовой, 57		0101000020E6100000E7E104A6537E60405512D907598C4540
73525	4	36	\N	1538	44714	\N	43.096823000000001	Приморский край, город Владивосток, Первомайский район, Гризодубовой, 50		0101000020E61000006AC2F693317E6040144031B2648C4540
73514	4	36	\N	1538	44637	\N	43.125344632450897	Приморский край, Владивостокский городской округ, Ленинский район, Гоголя, 41	Россия, Приморский край, Владивосток, улица Гоголя, 41	0101000020E610000087890629F87C6040CBDB114E0B904540
73538	4	36	\N	1538	44754	\N	43.090470000000003	Приморский край, город Владивосток, Первомайский район, Героев-Тихоокеанцев, 14		0101000020E61000006A34B918837D604073A25D85948B4540
73564	4	36	\N	1538	44696	\N	43.161783	Приморский край, г. Владивосток, Первореченский район, ул.Героев Варяга, д.2		0101000020E610000066F84F37D07D60403E062B4EB5944540
73389	4	36	\N	55260	59485	\N	44.168353832361802	Приморский край, г. Арсеньев, ул. 9 Мая, 83		0101000020E610000014E7A8A3E3A860404D13B69F8C154640
73569	4	36	\N	1538	44722	\N	43.148439000000003	Приморский край, г. Владивосток, Первореченский район, ул.Вострецова, д.9		0101000020E61000000490DAC4497D6040B939950C00934540
73599	4	36	\N	1538	6069	\N	43.262562000000003	Приморский край, город Владивосток, Советский район, Восточный проспект, 34	Россия, Приморский край, Владивосток, Восточный проспект, 34	0101000020E6100000664D2CF0958160401096B1A19BA14540
73505	4	36	\N	1538	44704	\N	43.104255000000002	Приморский край, город Владивосток, Ленинский район, Воропаева, 31		0101000020E6100000BC033C69617E6040E5B8533A588D4540
73568	4	36	\N	1538	44743	\N	43.150767000000002	Приморский край, г. Владивосток, Первореченский район, ул.Волховская, д.15		0101000020E6100000B37E33315D7D6040742843554C934540
73589	4	36	\N	1538	43081	\N	43.1331675477403	Приморский край, г. Владивосток, Первореченский район, ул.Военное шоссе, д.1а	Россия, Приморский край, Владивосток, Военное шоссе, 1а	0101000020E6100000F8E120214A7D6040D66F26A60B914540
73555	4	36	\N	1538	44718	\N	43.099687000000003	Приморский край, Владивостокский городской округ, Первомайский район, Вилкова, 7		0101000020E61000008CD7BCAAB37D60400E6B2A8BC28C4540
73664	4	36	\N	1538	44676	\N	43.102483999999997	Приморский край, город Владивосток, Фрунзенский район, Верхнепортовая, 50а, Общежитие МГУ им.Невельского		0101000020E6100000A6457D92BB7B60407F2E1A321E8D4540
73638	4	36	\N	1538	44676	\N	43.106664000000002	Приморский край, город Владивосток, Фрунзенский район, Верхнепортовая, 18, ИПК ФГОУ ВПО ДГТРУ		0101000020E61000004B04AA7F107C60408DD47B2AA78D4540
73636	4	36	\N	1538	44676	\N	43.104367000000003	Приморский край, город Владивосток, Фрунзенский район, Верхнепортовая, 40, Детская художествен. школа № 1		0101000020E61000008D9944BDE07B60400DE4D9E55B8D4540
73655	4	36	\N	1538	44333	\N	43.018975929040401	Приморский край, Владивостокский городской округ, Фрунзенский район, с. остров Русский, ул. Верхненабережная, 15, МОУ СОШ № 15	Россия, Приморский край, Русский остров	0101000020E61000001B649291337B604057B439CE6D824540
74497	4	36	\N	1538	44678	\N	43.111429000000001	Приморский край, Владивостокский городской округ, Ленинский район, Ватутина, 24		0101000020E61000003D81B053AC7E6040BA69334E438E4540
73509	4	36	\N	1538	44708	\N	43.108856000000003	Приморский край, город Владивосток, Ленинский район, Ватутина, 18		0101000020E610000088D51F61987E604098FC4FFEEE8D4540
73508	4	36	\N	1538	44708	\N	43.111429000000001	Приморский край, город Владивосток, Ленинский район, Ватутина, 24		0101000020E61000003D81B053AC7E6040BA69334E438E4540
74493	4	36	\N	1538	44748	\N	43.165734999999998	Приморский край, г. Владивосток, Первореченский район, ул.Бородинская, д.18		0101000020E610000073F38DE89E7D6040BA66F2CD36954540
73626	4	36	\N	1538	44748	\N	43.166715000000003	Приморский край, город Владивосток, Советский район, Бородинская, 27		0101000020E6100000098B8A389D7D60405760C8EA56954540
73620	4	36	\N	1538	44748	\N	43.165275000000001	Приморский край, город Владивосток, Советский район, Бородинская, 7		0101000020E61000002A560DC25C7D604057EC2FBB27954540
73551	4	36	\N	1538	44694	\N	43.088692000000002	Приморский край, Владивостокский городской округ, Первомайский район, Борисенко, 104		0101000020E61000001C23D923D47E60405BB56B425A8B4540
73528	4	36	\N	1538	44694	\N	43.100791999999998	Приморский край, город Владивосток, Первомайский район, Борисенко, 22		0101000020E61000001C28F04E3E7E604066D993C0E68C4540
73521	4	36	\N	1538	44694	\N	43.090088000000002	Приморский край, город Владивосток, Первомайский район, Борисенко, 102		0101000020E6100000E6965643E27E60408BE1EA00888B4540
73520	4	36	\N	1538	44694	\N	43.088692000000002	Приморский край, город Владивосток, Первомайский район, Борисенко, 104		0101000020E61000001C23D923D47E60405BB56B425A8B4540
73643	4	36	\N	1538	44636	\N	43.121060529170897	Приморский край, город Владивосток, Фрунзенский район, Батарейная, 6, Ср. школа №46	Россия, Приморский край, Владивосток, улица Батарейная	0101000020E61000000397C79A117C604018E945ED7E8F4540
73582	4	36	\N	1538	44723	\N	43.131427000000002	Приморский край, г. Владивосток, Первореченский район, ул.Баляева, д.46		0101000020E6100000D8666325E67D6040DC679599D2904540
73581	4	36	\N	1538	44723	\N	43.131202999999999	Приморский край, г. Владивосток, Первореченский район, ул.Баляева, д.38		0101000020E6100000B01BB62DCA7D60408C118942CB904540
73650	4	36	\N	1538	44701	\N	43.134979999999999	Приморский край, город Владивосток, Фрунзенский район, Амурская, 14, МБОУ СОШ № 26		0101000020E6100000545227A0897C60409ACE4E0647914540
73662	4	36	\N	1538	45147	\N	43.126117000000001	Приморский край, город Владивосток, Фрунзенский район, Алеутская, 65, Общежитие ДВФУ	Россия, Приморский край, Владивосток, улица Алеутская, 65	0101000020E610000033E02C254B7C60401D3C139A24904540
73499	4	36	\N	1538	44655	\N	43.122892999999998	Приморский край, город Владивосток, Ленинский район, Адмирала Кузнецова, 54в		0101000020E6100000A038807E5F7E604023F433F5BA8F4540
73606	4	36	\N	1538	44663	\N	43.226120283915897	Приморский край, город Владивосток, Советский район, Шестая, 8а		0101000020E610000083C0CAA1C57F60405B7C0A80F19C4540
73592	4	36	\N	1538	44919	\N	43.301125999999996	Приморский край, город Владивосток, Советский район, п. Трудовое, 50 лет Октября, 22		0101000020E6100000234BE6585E836040D6FCF84B8BA64540
73553	4	36	\N	1538	44716	\N	43.098495	Приморский край, Владивостокский городской округ, Первомайский район, 50 лет ВЛКСМ, 27		0101000020E6100000D6C9198ABB7D6040E6E8F17B9B8C4540
73531	4	36	\N	1538	44716	\N	43.099975999999998	Приморский край, город Владивосток, Первомайский район, 50 лет ВЛКСМ, 24/1		0101000020E61000006473D53CC77D604044317903CC8C4540
73530	4	36	\N	1538	44716	\N	43.098495	Приморский край, город Владивосток, Первомайский район, 50 лет ВЛКСМ, 27		0101000020E6100000D6C9198ABB7D6040E6E8F17B9B8C4540
73598	4	36	\N	1538	44763	\N	43.271830999999999	Приморский край, город Владивосток, Советский район, 4-я Восточная, 93		0101000020E6100000E3FBE25215826040FD84B35BCBA24540
73522	4	36	\N	1538	44733	\N	43.095171000000001	Приморский край, город Владивосток, Первомайский район, Строительная 2-я, 7		0101000020E6100000F7C95180A87E6040894336902E8C4540
74520	4	36	\N	1538	44762	\N	43.085524999999997	Приморский край, Владивостокский городской округ, Первомайский район, Поселковая 2-я, 51		0101000020E610000002B859BCD87C6040C5FEB27BF28A4540
74522	4	36	\N	1538	44614	\N	43.148877127954698	Приморский край, г. Владивосток, Первореченский район, пр-т. 100-летия Владивостока, д.29	Россия, Приморский край, Владивосток, 100 Лет Владивостоку проспект, 29а	0101000020E610000005DF347DF67C60403410CB660E934540
73572	4	36	\N	1538	44614	\N	43.150026859953897	Приморский край, г. Владивосток, Первореченский район, пр-т.100-летия Владивостока, д.32а	Россия, Приморский край, Владивосток, 100 Лет Владивостоку проспект, 32а	0101000020E610000056D7A19A127D60402D42B11534934540
73571	4	36	\N	1538	44614	\N	43.148872095451097	Приморский край, г.Владивосток, Первореченский район, пр-т 100-летия Владивостока, д.29	Россия, Приморский край, Владивосток, 100 Лет Владивостоку проспект, 29а	0101000020E610000015E29178F97C604022A5D93C0E934540
73621	4	36	\N	1538	44481	\N	43.1777784148263	Приморский край, город Владивосток, Советский район, Проспект 100-летия Владивостока, 128а	Россия, Приморский край, Владивосток, 100 Лет Владивостоку проспект, 128а	0101000020E61000001538D9066E7D604062F9F36DC1964540
73616	4	36	\N	1538	44481	\N	43.171842108288203	Приморский край, город Владивосток, Советский район, Проспект 100-летия Владивостока, 133а	Россия, Приморский край, Владивосток, 100 Лет Владивостоку проспект, 133	0101000020E6100000AD1402B9447D6040240A2DEBFE954540
73573	4	36	\N	1538	8193	\N	43.143498999999998	Приморский край, г. Владивосток, Первореченский район, пр-т. 100-летия Владивостока, д.18	Россия, Приморский край, Владивосток, 100 Лет Владивостоку проспект, 18	0101000020E61000005EF415A4197D60401D01DC2C5E924540
73631	4	36	\N	1538	45145	\N	43.226554999999998	Приморский край, город Владивосток, Советский район, Десятая, 10		0101000020E61000003B1DC87A6A7F604065DF15C1FF9C4540
73503	4	36	\N	1538	44700	\N	43.111307197823898	Приморский край, город Владивосток, Ленинский район, Ивановская, 28		0101000020E6100000DE8D0585C17D60406E68CA4E3F8E4540
73474	4	36	\N	55124	44616	\N	43.103319999999997	город Большой Камень, улица Прибрежная, дом 16		0101000020E6100000A06B5F402F8B6040E882FA96398D4540
73471	4	36	\N	55124	44510	\N	43.103319999999997	город Большой Камень, улица Карла Маркса, дом 47		0101000020E6100000A06B5F402F8B6040E882FA96398D4540
73468	4	36	\N	55124	44510	\N	43.1140893742865	город Большой Камень, улица Карла Маркса, дом 49	Россия, Приморский край, Шкотовский район, город Большой Камень	0101000020E6100000ED9E3C2C548B6040ABEAE5779A8E4540
73469	4	36	\N	55124	44335	\N	43.1088071464726	город Большой Камень, улица Гагарина, дом 15	Россия, Приморский край, Шкотовский район, город Большой Камень	0101000020E6100000E9F010C64F8B6040B6494563ED8D4540
73466	4	36	\N	55124	44508	\N	43.111550503642597	город Большой Камень, улица Аллея Труда, дом 16а	Россия, Приморский край, Шкотовский район, город Большой Камень	0101000020E61000007B6AF5D5558B6040056B9C4D478E4540
73470	4	36	\N	55124	43055	\N	43.114295701992198	город Большой Камень, улица Академика Курчатова, дом 28	Россия	0101000020E61000007D073F71808B604025085740A18E4540
73415	4	36	\N	1306	3854	\N	43.347408999999999	Приморский край, Артемовский городской округ, г. Артем, Фрунзе, 20	Россия, Приморский край, Артем, улица Фрунзе, 18	0101000020E6100000BF9A0304F384604004ABEAE577AC4540
73440	4	36	\N	1306	3960	\N	43.375225999999998	Приморский край, Артемовский городской округ, г. Артем, Кирова, 138	Россия, Приморский край, Артем, улица Кирова, 138	0101000020E61000005EBD8A8C8E876040F04DD36707B04540
73892	4	36	\N	1306	1291	\N	43.353741999999997	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, п. Новый, Ленина, 16	Россия, Приморский край, Артем, площадь Ленина, 8	0101000020E61000004AEB6F09C08560405E9CF86A47AD4540
73890	4	36	\N	1306	1291	\N	43.354894999999999	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, п. Новый, Ленина, 1	Россия, Приморский край, Артем, площадь Ленина, 3	0101000020E610000087FBC8ADC9856040C84109336DAD4540
73453	4	36	\N	1306	1291	\N	43.354922000000002	Приморский край, Артемовский городской округ, г. Артем, Ленина, 2	Россия, Приморский край, Артем, площадь Ленина, 4	0101000020E610000008AEF204C2856040C25087156EAD4540
73452	4	36	\N	1306	1291	\N	43.353657959620399	Приморский край, Артемовский городской округ, г. Артем, Ленина, 9/2	Россия, Приморский край, Артем, площадь Ленина, 7	0101000020E6100000EC33677DCA85604001FC53AA44AD4540
73451	4	36	\N	1306	1291	\N	43.353768000000002	Приморский край, Артемовский городской округ, г. Артем, Ленина, 9	Россия, Приморский край, Артем, площадь Ленина, 7	0101000020E6100000F163CC5DCB856040882F134548AD4540
73425	4	36	\N	1306	1291	\N	43.35228	Приморский край, Артемовский городской округ, г. Артем, площадь Ленина, 15	Россия, Приморский край, Артем, площадь Ленина, 15	0101000020E610000041446ADAC58560407784D38217AD4540
73413	4	36	\N	1306	44729	\N	43.352693000000002	Приморский край, Артемовский городской округ, г. Артем, Щорса, 22		0101000020E6100000B0373124A78460409A43520B25AD4540
73421	4	36	\N	1306	44751	\N	43.364621999999997	Приморский край, Артемовский городской округ, г. Артем, Чайковского, 53		0101000020E6100000732CEFAA8785604078B306EFABAE4540
73420	4	36	\N	1306	44445	\N	43.356574702640799	Приморский край, Артемовский городской округ, г. Артем, Б.Хмельницкого, 16	Россия, Приморский край, Артем, улица Хмельницкого	0101000020E6100000C05E61C17D8560401DC9E53FA4AD4540
73423	4	36	\N	1306	44680	\N	43.354363999999997	Приморский край, Артемовский городской округ, г. Артем, Фрунзе, 69/1		0101000020E6100000CD8FBFB4A88560409B70AFCC5BAD4540
73419	4	36	\N	1306	44680	\N	43.350202000000003	Приморский край, Артемовский городской округ, г. Артем, Фрунзе, 32Б		0101000020E6100000D369DD0635856040357F4C6BD3AC4540
73416	4	36	\N	1306	44680	\N	43.34836	Приморский край, Артемовский городской округ, г. Артем, Фрунзе, 28		0101000020E6100000079B3A8F0A856040069E7B0F97AC4540
73414	4	36	\N	1306	44680	\N	43.345711000000001	Приморский край, Артемовский городской округ, г. Артем, Фрунзе, 6		0101000020E6100000FFE9060ABC846040096F0F4240AC4540
73454	4	36	\N	1306	44827	\N	43.362813000000003	Приморский край, Артемовский городской округ, г. Артем, Стрельникова, 46		0101000020E6100000C2853C821B86604026C808A870AE4540
73447	4	36	\N	1306	44829	\N	43.346005425371999	Приморский край, Артемовский городской округ, с. Оленье, Силина, 21		0101000020E6100000EC6B5D6A8489604051A04FE449AC4540
73449	4	36	\N	1306	44734	\N	43.345599999999997	Приморский край, Артемовский городской округ, г. Артем, Севастопольская, 12		0101000020E6100000042159C004856040B1BFEC9E3CAC4540
73417	4	36	\N	1306	44734	\N	43.348188999999998	Приморский край, Артемовский городской округ, г. Артем, Севастопольская, 27		0101000020E6100000315D88D51F856040D9E9077591AC4540
73407	4	36	\N	1306	44650	\N	43.331724999999999	Приморский край, Артемовский городской округ, г. Артем, Сахалинская, 1		0101000020E6100000FC709010E5826040FF21FDF675AA4540
73410	4	36	\N	1306	44674	\N	43.328892000000003	Приморский край, Артемовский городской округ, г. Артем, Ремзаводская, 5		0101000020E610000083DBDAC27383604041F50F2219AA4540
74450	4	36	\N	1306	44666	\N	43.351278857500098	"Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Летно-Хвалынское, Первомайская, 4 ""А"""	Россия, Приморский край, Артем, Первомайская улица	0101000020E6100000674815C5AB856040C362D4B5F6AC4540
73424	4	36	\N	1306	1481	\N	43.352063000000001	Приморский край, Артемовский городской округ, г. Артем, Партизанская, 3	Россия, Приморский край, Артем, Партизанская улица, 3	0101000020E6100000E814E467A3856040DA907F6610AD4540
73457	4	36	\N	1306	44876	\N	43.443527000000003	Приморский край, Артемовский городской округ, с. Кролевцы, Мухина, 6	Россия, Приморский край, Артем городской округ, село Кролевцы	0101000020E61000003C69E1B20A8860404EF2237EC5B84540
73450	4	36	\N	1306	44683	\N	43.456439000000003	Приморский край, Артемовский городской округ, г. Артем, Михайловская, 1		0101000020E61000008B506C054D8960403ACFD8976CBA4540
73897	4	36	\N	1306	44635	\N	43.357799	Приморский край, Надеждинский муниципальный район, Тавричанское сельское поселение, п. Тавричанка, Лазо, 5		0101000020E6100000E4688EACFC85604050C58D5BCCAD4540
73432	4	36	\N	1306	44635	\N	43.357320999999999	Приморский край, Артемовский городской округ, г. Артем, Лазо, 20		0101000020E61000004D309C6B188660404696CCB1BCAD4540
73426	4	36	\N	1306	44682	\N	43.354121999999997	Приморский край, Артемовский городской округ, г. Артем, Кооперативная, 6		0101000020E610000079EBFCDBE5856040A565A4DE53AD4540
73439	4	36	\N	1306	44685	\N	43.368344999999998	Приморский край, Артемовский городской округ, г. Артем, Кирова, 92		0101000020E61000004DBD6E11188760409352D0ED25AF4540
73438	4	36	\N	1306	44685	\N	43.366653999999997	Приморский край, Артемовский городской округ, г. Артем, Кирова, 89		0101000020E6100000D314014EEF8660404A79AD84EEAE4540
73437	4	36	\N	1306	44685	\N	43.365519999999997	Приморский край, Артемовский городской округ, г. Артем, Кирова, 83/1		0101000020E6100000C498F4F7D28660405704FF5BC9AE4540
73436	4	36	\N	1306	44685	\N	43.359707	Приморский край, Артемовский городской округ, г. Артем, Кирова, 66		0101000020E6100000554D10759F866040369204E10AAE4540
73434	4	36	\N	1306	44685	\N	43.356428999999999	Приморский край, Артемовский городской округ, г. Артем, Кирова, 62		0101000020E610000026C808A870866040492C29779FAD4540
73433	4	36	\N	1306	44685	\N	43.356056000000002	Приморский край, Артемовский городской округ, г. Артем, Кирова, 57		0101000020E610000058C85C1954866040B5C5353E93AD4540
73428	4	36	\N	1306	44685	\N	43.356200000000001	Приморский край, Артемовский городской округ, г. Артем, Кирова, 21		0101000020E610000023DBF97EEA856040E86A2BF697AD4540
73422	4	36	\N	1306	44685	\N	43.355407	Приморский край, Артемовский городской округ, г. Артем, Кирова, 3		0101000020E610000018B0E42A968560407EE200FA7DAD4540
73409	4	36	\N	1306	3769	\N	43.338118999999999	Приморский край, Артемовский городской округ, г. Артем, Карагандинская, 26	Россия, Приморский край, Артем, Карагандинская улица, 26	0101000020E61000009B560A815C836040FF93BF7B47AB4540
73435	4	36	\N	1306	44918	\N	43.363705000000003	Приморский край, Артемовский городской округ, г. Артем, Калинина, 20		0101000020E6100000199128B4AC8660402332ACE28DAE4540
73429	4	36	\N	1306	4042	\N	43.364511	Приморский край, Артемовский городской округ, г. Артем, Интернациональная, 58	Россия, Приморский край, Артем, Интернациональная улица, 58	0101000020E61000003126FDBD148660402104E44BA8AE4540
73431	4	36	\N	1306	44921	\N	43.370291000000002	Приморский край, Артемовский городской округ, г. Артем, Достоевского, 50		0101000020E6100000D4F203577986604067800BB265AF4540
73460	4	36	\N	1306	3817	\N	43.346384692356203	Приморский край, Артемовский городской округ, г. Артем, Донбасская, 17	Россия, Приморский край, Артем, Донбасская улица	0101000020E61000008A592F86F28360409869FB5756AC4540
73412	4	36	\N	1306	3817	\N	43.346541292221197	Приморский край, Артемовский городской округ, г. Артем, Донбасская, 22	Россия, Приморский край, Артем, Донбасская улица	0101000020E61000000EF96706F183604090DC9A745BAC4540
73444	4	36	\N	1306	4223	\N	43.366836999999997	Приморский край, Артемовский городской округ, г. Артем, Днепростроевская, 4	Россия, Приморский край, Артем, Днепростроевская улица, 6а	0101000020E610000025085740218A60403BFBCA83F4AE4540
73446	4	36	\N	1306	44651	\N	43.368216903639201	Приморский край, Артемовский городской округ, г. Артем, Днепростроевская, 11	Россия, Приморский край, Артем, Днепростроевская улица	0101000020E61000008753E6E61B8A6040666A12BC21AF4540
73445	4	36	\N	1306	44651	\N	43.366836999999997	Приморский край, Артемовский городской округ, г. Артем, Днепростроевская, 6		0101000020E610000025085740218A60403BFBCA83F4AE4540
74488	4	36	\N	1306	345	\N	43.357917	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Некрасова, 6	Россия, Приморский край, Артем, Дальнереченский переулок, 6	0101000020E61000005F5D15A8458560405AD76839D0AD4540
73701	4	36	\N	1306	345	\N	43.357805999999997	Приморский край, Дальнереченский городской округ, г. Дальнереченск, 45 лет Октября, 1	Россия, Приморский край, Артем, Дальнереченский переулок, 2	0101000020E61000003866D9934085604002284696CCAD4540
73698	4	36	\N	1306	345	\N	43.357805999999997	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Чернышевского, 2	Россия, Приморский край, Артем, Дальнереченский переулок, 2	0101000020E61000003866D9934085604002284696CCAD4540
73692	4	36	\N	1306	345	\N	43.358139999999999	Приморский край, Дальнереченский городской округ, г. Дальнереченск, Полтавская, 13	Россия, Приморский край, Артем, Дальнереченский переулок, 12	0101000020E610000031444E5F4F856040D9B11188D7AD4540
73406	4	36	\N	1306	44630	\N	43.333386586556799	Приморский край, Артемовский городской округ, г. Артем, Гагарина, 135	Россия, Приморский край, Артем, улица Гагарина	0101000020E61000000458E4D78F826040AEF4DA6CACAA4540
73459	4	36	\N	1306	44623	\N	43.380284000000003	Приморский край, Артемовский городской округ, г. Артем, Ворошилова, 13		0101000020E610000061376C5B1489604096986725ADB04540
73442	4	36	\N	1306	44623	\N	43.3801069082038	Приморский край, Артемовский городской округ, г. Артем, Ворошилова, 11	Россия, Приморский край, Артем, улица Ворошилова	0101000020E6100000997FF44D1A89604087FD9E58A7B04540
73430	4	36	\N	1306	4068	\N	43.374983	Приморский край, Артемовский городской округ, г. Артем, Волочаевская, 42	Россия, Приморский край, Артем, Волочаевская улица, 42	0101000020E6100000ED6305BF0D8660402AC76471FFAF4540
73441	4	36	\N	1306	45134	\N	43.384228999999998	Приморский край, Артемовский городской округ, г. Артем, Виноградная, 2/1		0101000020E61000002EE3A6069A8760405F96766A2EB14540
73418	4	36	\N	1306	44681	\N	43.346170000000001	Приморский край, Артемовский городской округ, г. Артем, Ватутина, 4		0101000020E610000082C5E1CC2F8560409C6D6E4C4FAC4540
73461	4	36	\N	1306	44735	\N	43.375599000000001	Приморский край, Артемовский городской округ, г. Артем, Бабушкина, 12		0101000020E61000007A34D5937987604085B4C6A013B04540
73408	4	36	\N	1306	3768	\N	43.330820000000003	Приморский край, Артемовский городской округ, г. Артем, 1-ая Рабочая, 37	Россия, Приморский край, Артем, 1-я Рабочая улица, 37	0101000020E610000040DF162CD58260406E6E4C4F58AA4540
73455	4	36	\N	55291	44788	\N	43.395024999999997	Приморский край, Артемовский городской округ, с. Кневичи, Авиационная, 7		0101000020E610000042AF3F894F8660401B0DE02D90B24540
73386	4	36	\N	11414	44806	\N	44.168434917841303	Приморский край, г. Арсеньев, ул. Таежная, 1		0101000020E6100000A6608DB3E9A860403A4030478F154640
73399	4	36	\N	11414	44351	\N	44.158688411514198	Приморский край, г. Арсеньев, ул. Садовая, 19	Россия, Приморский край, город Арсеньев	0101000020E6100000206118B0E4A8604042226DE34F144640
73391	4	36	\N	11414	44465	\N	44.155707	Приморский край, г. Арсеньев, ул. Мира, 11		0101000020E6100000D881734694A860400F61FC34EE134640
73385	4	36	\N	11414	44560	\N	44.155707	Приморский край, г. Арсеньев, ул.Луговая, 29А		0101000020E6100000D881734694A860400F61FC34EE134640
73393	4	36	\N	11414	42958	\N	44.161057610443898	Приморский край, г. Арсеньев, ул. Ломоносова, 42А		0101000020E61000006E6DE179A9A860402C616D8C9D144640
73396	4	36	\N	11414	44447	\N	44.155707	Приморский край, г. Арсеньев, ул. Ленинская, 43		0101000020E6100000D881734694A860400F61FC34EE134640
73394	4	36	\N	11414	44447	\N	44.157904450107601	Приморский край, г. Арсеньев, ул. Ленинская, 23		0101000020E61000005EDBDB2DC9A860402CF4C13236144640
73367	4	36	\N	11414	44447	\N	44.159441468013497	Приморский край, г. Арсеньев, ул. Ленинская, 29А	Россия, Приморский край, город Арсеньев	0101000020E6100000F261F6B2EDA860401E520C9068144640
73402	4	36	\N	11414	44610	\N	44.172577850336403	Приморский край, г. Арсеньев, ул. Клиновая, 1А		0101000020E610000030F0DC7BB8A860402A01310917164640
73395	4	36	\N	11414	44455	\N	44.156830830770801	Приморский край, г. Арсеньев, ул. Калининская, 1	Россия, Приморский край, город Арсеньев	0101000020E61000009A5C8C8175A86040DEFFC70913144640
73390	4	36	\N	11414	44464	\N	44.162700739424899	Приморский край, г. Арсеньев, ул. 25 лет Арсеньеву, 17		0101000020E61000001E6CB1DBE7A860406403E962D3144640
73401	4	36	\N	55260	44499	\N	44.148666045996102	Приморский край, г. Арсеньев, ул. Советская, 39А		0101000020E610000092E865144BA960407903CC7C07134640
73404	4	36	\N	55260	44513	\N	44.164237631522496	Приморский край, г. Арсеньев, ул. Сазыкина, 13		0101000020E6100000506F46CD57A86040566133C005154640
73397	4	36	\N	55260	59496	\N	44.1558653289581	Приморский край, г. Арсеньев, ул. Островского, 20		0101000020E6100000ECBFCE4D9BA86040A7CB6262F3134640
73387	4	36	\N	55260	44450	\N	44.155707	Приморский край, г. Арсеньев, ул.Олега Кошевого, 3		0101000020E6100000D881734694A860400F61FC34EE134640
73405	4	36	\N	55260	59471	\N	44.166415469872398	Приморский край, г. Арсеньев, ул. Октябрьская, 41		0101000020E6100000D8F0F44A59A860402C4833164D154640
73392	4	36	\N	55260	59471	\N	44.1593101665514	Приморский край, г. Арсеньев, ул. Октябрьская, 63/2	Россия, Приморский край, город Арсеньев	0101000020E61000004E4700378BA860407FF6234564144640
73388	4	36	\N	55260	44469	\N	44.155707	Приморский край, г. Арсеньев, ул. Кирзаводская, 10А		0101000020E6100000D881734694A860400F61FC34EE134640
73398	4	36	\N	55260	44511	\N	44.158954878766501	Приморский край, г. Арсеньев, ул. Калининская, 3А		0101000020E61000003F390A1085A8604091442FA358144640
73656	4	36	7358	55284	\N	\N	43.059300808996802	Приморский край, Владивостокский городской округ, Фрунзенский район, с. остров Русский, о.Русский, пос. Подножье, МБОУ СОШ № 20	Россия, Приморский край, Владивосток, улица поселок Поспелово	0101000020E6100000EF74E789677C60405FCFD72C97874540
74003	4	36	1203	55294	44889	\N	43.220319158418	Приморский край, Партизанский городской округ, п. Углекаменск, Советская, 39	Россия, Приморский край, городской округ Партизанск, село Углекаменск	0101000020E610000097A949F086A76040FED7B969339C4540
74032	4	36	1203	11702	45092	\N	43.160237000000002	Приморский край, Партизанский городской округ, с. Тигровое, Тигровая, 155		0101000020E6100000534145D5AF9B6040F94D61A582944540
74023	4	36	1203	55297	44915	\N	43.200405000000003	"Приморский край, Партизанский городской округ, с. Казанка, Луговая, 6 ""а"""	Россия, Приморский край, городской округ Партизанск, село Казанка	0101000020E6100000A52DAEF119A760403A7AFCDEA6994540
74030	4	36	1203	55309	45044	\N	43.289299118772	Приморский край, Партизанский городской округ, .с. Бровничи, Советская, 61	Россия, Приморский край, городской округ Партизанск, село Бровничи	0101000020E6100000E90DF791DBA06040FCE1E7BF07A54540
74010	4	36	1203	55296	44914	\N	43.274069454698598	Приморский край, Партизанский городской округ, с. Авангард, Кирова, 33	Россия, Приморский край, городской округ Партизанск, село Авангард	0101000020E6100000618BDD3E2BA7604078EC67B114A34540
73906	4	36	7357	55311	45063	\N	42.878567528566101	Приморский край, г. Находка, п. Средний, ул. Светлая, д. 10	Россия, Приморский край, городской округ Находка, поселок Ливадия	0101000020E6100000643F8BA5C8966040F4A78DEA74704540
73904	4	36	7357	55281	44568	\N	42.875569058609898	Приморский край, г. Находка, п. Ливадия, ул. Луговая, д. 2	Россия, Приморский край, городской округ Находка, поселок Ливадия	0101000020E61000008D7DC9C6039660401A321EA512704540
73907	4	36	7357	55307	45018	\N	42.928023000000003	Приморский край, г. Находка, с. Душкино, ул. Комарова, д. 13	Россия, Приморский край, городской округ Находка, село Душкино	0101000020E6100000FA62EFC517966040C9772975C9764540
73813	4	36	7354	55248	44338	\N	45.484982263920401	Приморский край, Лесозаводский городской округг. Лесозаводск, Будника, 77	Россия, Приморский край, городской округ Лесозаводск	0101000020E6100000B3791C06F3AD60400893E2E313BE4640
74477	4	36	140	55255	44388	\N	43.332033000000003	Приморский край, Шкотовский район, пгт Шкотово, Советская, 45		0101000020E6100000ADDC0BCC8A8B6040AD18AE0E80AA4540
74473	4	36	140	460	44800	\N	43.342249000000002	Приморский край, Шкотовский район, с. Центральное, Чапаева, 20		0101000020E61000006BB933130C9660405B0BB3D0CEAB4540
74376	4	36	140	28253	44383	\N	42.940821999999997	Приморский край, город Фокино, Комсомольская, 12		0101000020E610000062D68BA19C8C6040BCADF4DA6C784540
74381	4	36	140	28253	43027	\N	42.940821999999997	Приморский край, город Фокино, Карла Маркса, 29Б		0101000020E610000062D68BA19C8C6040BCADF4DA6C784540
74475	4	36	140	591	44969	\N	43.346314	Приморский край, Шкотовский район, с. Стеклянуха, Центральная, 24		0101000020E610000035D252793B8F6040CF12640454AC4540
74482	4	36	140	55275	44541	\N	43.280535	Приморский край, Шкотовский район, пгт Смоляниново, Школьная, 1А		0101000020E61000008E06F016C88E604012312592E8A34540
74472	4	36	140	55275	44869	\N	43.280535	Приморский край, Шкотовский район, пгт Смоляниново, Пушкинская, 84		0101000020E61000008E06F016C88E604012312592E8A34540
74481	4	36	140	55275	44611	\N	43.280535	Приморский край, Шкотовский район, пгт Смоляниново, Маяковского, 15		0101000020E61000008E06F016C88E604012312592E8A34540
74480	4	36	140	55275	44611	\N	43.280535	Приморский край, Шкотовский район, пгт Смоляниниво, Маяковского, 37		0101000020E61000008E06F016C88E604012312592E8A34540
74483	4	36	140	1068	44543	\N	43.235508000000003	Приморский край, Шкотовский район, с. Романовка, Ленинская, 60		0101000020E61000007D410B09988E604023F94A20259E4540
74385	4	36	140	28675	44900	\N	42.860546999999997	Приморский край, п.Путятин, Центральная, 31		0101000020E6100000AEB8382A378D6040E0D57267266E4540
73462	4	36	140	55282	44612	\N	43.146323262909199	городской округ ЗАТО Большой Камень, село Петровка, улица Школьная, дом 1	Россия, Приморский край, Шкотовский район, село Петровка	0101000020E61000002429E961688C604089D349B6BA924540
74479	4	36	140	859	44602	\N	43.216735349368598	Приморский край, Шкотовский район, п. Новонежино, Почтовая, 1А	Россия, Приморский край, Шкотовский район, поселок Новонежино	0101000020E61000007495EEAE339360400473F4F8BD9B4540
74471	4	36	140	331	44910	\N	43.443337	Приморский край, Шкотовский район, с. Многоудобное, Зальпе, 2Г		0101000020E6100000B5C2F4BD868E6040AA0D4E44BFB84540
74388	4	36	140	28704	44386	\N	42.879021999999999	Приморский край, п.Дунай, Морская, 16		0101000020E6100000D2E3F736FD8A6040753BFBCA83704540
74387	4	36	140	28704	44429	\N	42.879021999999999	Приморский край, п.Дунай, Ленина, 15		0101000020E6100000D2E3F736FD8A6040753BFBCA83704540
74386	4	36	140	55273	44535	\N	42.879021999999999	Приморский край, п.Дунай, Морская, 18А		0101000020E6100000D2E3F736FD8A6040753BFBCA83704540
73464	4	36	140	15899	43034	\N	43.118239374028398	город Большой Камень, улица имени В.А.Маслакова, дом 14б	Россия, Приморский край, Шкотовский район, город Большой Камень	0101000020E61000000C3D62F45C8B60404E0E9F74228F4540
73473	4	36	140	15899	43064	\N	43.110112025211897	город Большой Камень, улица Ленина, дом 3	Россия, Приморский край, Шкотовский район, город Большой Камень	0101000020E6100000B4226AA2CF8A6040D6726726188E4540
73472	4	36	140	15899	43064	\N	43.108925058353499	город Большой Камень, улица Ленина, дом 22	Россия, Приморский край, Шкотовский район, город Большой Камень	0101000020E61000008BE07F2BD98A6040C05B2041F18D4540
73465	4	36	140	15899	43041	\N	43.103319999999997	город Большой Камень, улица Карла Маркса, дом 2		0101000020E6100000A06B5F402F8B6040E882FA96398D4540
73467	4	36	140	57572	59484	\N	43.103319999999997	город Большой Камень, улица Адмирала Макарова, дом 10		0101000020E6100000A06B5F402F8B6040E882FA96398D4540
74478	4	36	140	759	44821	\N	43.178063000000002	Приморский край, Шкотовский район, с. Анисимовка, Смольная, 4А		0101000020E6100000AD68739C5B99604057D0B4C4CA964540
74325	4	36	594	3734	44477	\N	44.338898	Приморский край, Черниговский муниципальный район, Черниговское сельское поселение, с. Черниговка, Октябрьская, 142		0101000020E6100000A0C37C790192604004577902612B4640
74323	4	36	594	3734	44530	\N	44.338898	Приморский край, Черниговский муниципальный район, Черниговское сельское поселение, с. Черниговка, Ленинская, 72		0101000020E6100000A0C37C790192604004577902612B4640
74322	4	36	594	3734	44530	\N	44.3390242146654	Приморский край, Черниговский муниципальный район, Черниговское сельское поселение, с. Черниговка, Ленинская, 56	Россия, Приморский край, Черниговский район, село Черниговка	0101000020E61000009E7AA4C16D92604091477023652B4640
74321	4	36	594	3734	44528	\N	44.338898	Приморский край, Черниговский муниципальный район, Черниговское сельское поселение, с. Черниговка, Заводская, 8		0101000020E6100000A0C37C790192604004577902612B4640
74324	4	36	594	3734	44382	\N	44.338898	Приморский край, Черниговский муниципальный район, Черниговское сельское поселение, с. Черниговка, Буденного, 23		0101000020E6100000A0C37C790192604004577902612B4640
74345	4	36	594	26889	44815	\N	44.264361000000001	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, с. Халкидон, Советская, 9		0101000020E6100000D80DDB16658D60403FABCC94D6214640
74334	4	36	594	26352	44899	\N	44.083494000000002	Приморский край, Черниговский муниципальный район, Снегуровское сельское поселение, с. Снегуровка, Парковая, 23		0101000020E6100000DBDC989EB0926040C4B46FEEAF0A4640
74327	4	36	594	26048	45109	\N	44.457904999999997	Приморский край, Черниговский муниципальный район, Дмитриевское сельское поселение, с. Синий Гай, Советская, 5		0101000020E6100000D311C0CDE292604062D68BA19C3A4640
74348	4	36	594	55310	45052	\N	44.200992999999997	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, пгт. Сибирцево, Заводская, 1		0101000020E6100000247F30F05C8E6040CADC7C23BA194640
74338	4	36	594	26487	44600	\N	44.200992999999997	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, пгт. Сибирцево, Постышева, 13		0101000020E6100000247F30F05C8E6040CADC7C23BA194640
74339	4	36	594	26487	44384	\N	44.200992999999997	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, пгт. Сибирцево, Ленинская, 14		0101000020E6100000247F30F05C8E6040CADC7C23BA194640
74342	4	36	594	26487	44426	\N	44.200992999999997	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, пгт. Сибирцево, Кутузова, 1		0101000020E6100000247F30F05C8E6040CADC7C23BA194640
74337	4	36	594	26487	44863	\N	44.200992999999997	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, пгт. Сибирцево, Красноармейская, 16-а		0101000020E6100000247F30F05C8E6040CADC7C23BA194640
74336	4	36	594	26427	45117	\N	44.139197536677301	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, с. Орехово, Центральная, 17	Россия, Приморский край, Черниговский район, село Орехово	0101000020E6100000AD33BE2F2E8C604095D5743DD1114640
74343	4	36	594	26769	44532	\N	44.194142999999997	Приморский край, Черниговский муниципальный район, Сибирцевское городское поселение, с. Монастырище, Титова 1-а		0101000020E6100000EB6E9EEA908F6040A8DF85ADD9184640
74328	4	36	594	26122	45108	\N	44.379390000000001	Приморский край, Черниговский муниципальный район, Дмитриевское сельское поселение, с. Меркушевка, Центральная, 13		0101000020E6100000E4A3C51943996040F836FDD98F304640
74333	4	36	594	26287	44962	\N	44.139006000000002	Приморский край, Черниговский муниципальный район, Снегуровское сельское поселение, с. Вассиановка, Ленинская, 5		0101000020E6100000BD1E4C8A8F94604051F9D7F2CA114640
74329	4	36	594	26125	44973	\N	44.401285000000001	Приморский край, Черниговский муниципальный район, Черниговское сельское поселение, с. Алтыновка, Комсомольская, 38		0101000020E6100000CA17B490009160400CB08F4E5D334640
74335	4	36	594	26404	45011	\N	44.078114906506599	Приморский край, Черниговский муниципальный район, Снегуровское сельское поселение, с. Абражеевка, Клубная, 2-а	Россия, Приморский край, Черниговский район, село Абражеевка	0101000020E6100000DA91EA3B3F8F6040DC291DACFF094640
74296	4	36	1753	24474	44597	\N	44.170780999999998	Приморский край, Хорольский муниципальный район, Ярославское городское поселение, п. Ярославский, проспект Ленина, 1		0101000020E6100000931CB0AB498760409BE3DC26DC154640
74294	4	36	1753	24474	44862	\N	44.170780999999998	Приморский край, Хорольский муниципальный район, Ярославское городское поселение, п. Ярославский, Школьная, 16		0101000020E6100000931CB0AB498760409BE3DC26DC154640
74297	4	36	1753	24474	44598	\N	44.170780999999998	Приморский край, Хорольский муниципальный район, Ярославское городское поселение, п. Ярославский, Советская, 48		0101000020E6100000931CB0AB498760409BE3DC26DC154640
74293	4	36	1753	24474	44476	\N	44.170780999999998	Приморский край, Хорольский муниципальный район, Ярославское городское поселение, п. Ярославский, Матросова, 3		0101000020E6100000931CB0AB498760409BE3DC26DC154640
74295	4	36	1753	55270	44529	\N	44.170780999999998	Приморский край, Хорольский муниципальный район, Ярославское городское поселение, п. Ярославский, Матросова, 4		0101000020E6100000931CB0AB498760409BE3DC26DC154640
74280	4	36	1724	23713	44378	\N	42.871879999999997	Приморский край, Хасанский муниципальный район, пгт. Славянка, Молодежная, 8а		0101000020E6100000B6DAC35EA86C6040AB048BC3996F4540
74304	4	36	1753	55304	44961	\N	44.449704252845997	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, железнодорожная станция Хорольск, Новая, 4	Россия, Приморский край, Хорольский район, село Хорольск	0101000020E61000009D0FCF1264836040B07092E68F394640
74302	4	36	1753	24819	44394	\N	44.424523000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Хороль, Ленинская, 77		0101000020E6100000ED629AE95E8260402DB308C556364640
74301	4	36	1753	24819	44394	\N	44.424523000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Хороль, Ленинская, 47		0101000020E6100000ED629AE95E8260402DB308C556364640
74300	4	36	1753	24819	44394	\N	44.424523000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Хороль, Ленинская, 49		0101000020E6100000ED629AE95E8260402DB308C556364640
74303	4	36	1753	24819	44396	\N	44.424523000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Хороль, Лазо, 23		0101000020E6100000ED629AE95E8260402DB308C556364640
74305	4	36	1753	24819	44599	\N	44.424523000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Хороль, Красноармейская, 4а		0101000020E6100000ED629AE95E8260402DB308C556364640
74306	4	36	1753	24819	45107	\N	44.424523000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Хороль, Комсомольская, 72		0101000020E6100000ED629AE95E8260402DB308C556364640
74307	4	36	1753	24819	44381	\N	44.424523000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Хороль, Волочаевская, 3		0101000020E6100000ED629AE95E8260402DB308C556364640
74315	4	36	1753	25501	45010	\N	44.2430680735377	Приморский край, Хорольский муниципальный район, Благодатненское сельское поселение, с. Усачевка, Центральная, 2в	Россия, Приморский край, Хорольский район, село Усачевка	0101000020E610000083BEF4F6E77A6040215A2BDA1C1F4640
74318	4	36	1753	25618	44816	\N	44.479711000000002	Приморский край, Хорольский муниципальный район, Сиваковское сельское поселение, с. Сиваковка, Центральная, 3		0101000020E61000009B215514AF8B60400744882B673D4640
74313	4	36	1753	25405	44972	\N	44.311407000000003	Приморский край, Хорольский муниципальный район, Благодатненское сельское поселение, с. Приозерное, Ленинская, 14а		0101000020E6100000D6FECEF6E87E60406C5F402FDC274640
74314	4	36	1753	25417	45104	\N	44.339554999999997	Приморский край, Хорольский муниципальный район, Благодатненское сельское поселение, с. Прилуки, Центральная, 17а		0101000020E61000001B66683C917A6040BD18CA89762B4640
74308	4	36	1753	25127	44814	\N	44.441116000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Поповка, Первомайская, 72		0101000020E6100000CA6FD1C9527F604005DF347D76384640
74319	4	36	1753	25708	45050	\N	44.381715999999997	Приморский край, Хорольский муниципальный район, Сиваковское сельское поселение, с. Петровичи, Юбилейная, здание ФАПа		0101000020E61000009A417C60C7886040122EE411DC304640
74317	4	36	1753	25609	44404	\N	44.493395999999997	Приморский край, Хорольский муниципальный район, Новодевицкое сельское поселение, с. Новодевица, Лазо, 30		0101000020E610000031D28BDAFD85604015FDA199273F4640
74312	4	36	1753	25333	45053	\N	44.358184000000001	Приморский край, Хорольский муниципальный район, Благодатненское сельское поселение, с. Новобельмановка, Центральная, 38		0101000020E61000006AF5D55581856040A9F92AF9D82D4640
74316	4	36	1753	25540	44864	\N	44.287782	Приморский край, Хорольский муниципальный район, Лучкинское сельское поселение, с. Лучки, Колхозная, 18		0101000020E610000069FCC22B498860405130630AD6244640
74310	4	36	1753	55313	45088	\N	44.536039527839101	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Луговое, Центральная, 5	Россия, Приморский край, Хорольский район, село Луговой	0101000020E61000009A5C8C81F582604086AC6EF59C444640
74309	4	36	1753	25197	44898	\N	44.427233000000001	Приморский край, Хорольский муниципальный район, Хорольское сельское поселение, с. Ленинское, Гагарина, 14		0101000020E6100000F92EA52E99856040D0622992AF364640
74299	4	36	1753	24764	45058	\N	44.149543000000001	Приморский край, Хорольский муниципальный район, Ярославское городское поселение, с. Дальзаводское, Павлика Морозова, 15		0101000020E6100000601F9DBA72836040412C9B3924134640
74298	4	36	1753	24683	44444	\N	44.189605	Приморский край, Хорольский муниципальный район, Ярославское городское поселение, с. Вознесенка, Первомайская, 3а		0101000020E61000001DE90C8C3C8660403C1405FA44184640
74311	4	36	1753	25280	44870	\N	44.321390999999998	Приморский край, Хорольский муниципальный район, Благодатненское сельское поселение, с. Благодатное, Октябрьская, 43		0101000020E61000004BE48233F8826040471D1D5723294640
74271	4	36	1724	23377	44956	\N	42.757823000000002	Приморский край, Хасанский муниципальный район, с. Цуканово, Молодежная, 25		0101000020E610000013D6C6D8095960400C94145800614540
74270	4	36	1724	55292	44796	\N	42.423853000000001	Приморский край, Хасанский муниципальный район, пгт. Хасан, Вокзальная, 7		0101000020E6100000C2F69331BE546040DFA7AAD040364540
74290	4	36	1724	24289	44971	\N	43.238200999999997	Приморский край, Хасанский муниципальный район, с. Филипповка, Комарова, 25а		0101000020E6100000E277D32D3B716040EF6FD05E7D9E4540
74282	4	36	1724	23713	44793	\N	42.871879999999997	Приморский край, Хасанский муниципальный район, пгт. Славянка, Нерпинская, 27		0101000020E6100000B6DAC35EA86C6040AB048BC3996F4540
74284	4	36	1724	23713	44812	\N	42.871879999999997	Приморский край, Хасанский муниципальный район, пгт. Славянка, Набережная, 21б		0101000020E6100000B6DAC35EA86C6040AB048BC3996F4540
74283	4	36	1724	23713	44443	\N	42.871879999999997	Приморский край, Хасанский муниципальный район, пгт. Славянка, Ленинская, 51а		0101000020E6100000B6DAC35EA86C6040AB048BC3996F4540
74279	4	36	1724	55254	44380	\N	42.871879999999997	Приморский край, Хасанский муниципальный район, пгт. Славянка, Молодежная, 7		0101000020E6100000B6DAC35EA86C6040AB048BC3996F4540
74278	4	36	1724	55254	44551	\N	42.871879999999997	Приморский край, Хасанский муниципальный район, пгт. Славянка, Героев Хасана, 5		0101000020E6100000B6DAC35EA86C6040AB048BC3996F4540
74281	4	36	1724	55254	44608	\N	42.868091971351099	Приморский край, Хасанский муниципальный район, пгт. Славянка, 50 лет Октября, 10а		0101000020E6100000B5C01E13A96C6040A9F57EA31D6F4540
74287	4	36	1724	55269	44527	\N	43.086961000000002	Приморский край, Хасанский муниципальный район, пгт. Приморский, Центральная, 46б		0101000020E610000051F52B9D8F7260408483BD89218B4540
74273	4	36	1724	55278	44548	\N	42.654919999999997	Приморский край, Хасанский муниципальный район, пгт. Посьет, Портовая, 18		0101000020E6100000D2FC31ADCD59604087BF266BD4534540
74286	4	36	1724	55330	45156	\N	43.023623056581002	Приморский край, Хасанский муниципальный район, с. Перевозное, Лазо, 19	Россия, Приморский край, Хасанский район, село Перевозная	0101000020E61000003E761728A97160407A37161406834540
74272	4	36	1724	55253	44379	\N	42.713965000000002	Приморский край, Хасанский муниципальный район, пгт. Краскино, Ленина, 22		0101000020E61000000BB43BA4185960408CBE8234635B4540
74276	4	36	1724	55279	44549	\N	42.646379000000003	Приморский край, Хасанский муниципальный район, пгт. Зарубино, Нагорная, 8а		0101000020E61000000917F2086E6260401DE90C8CBC524540
74275	4	36	1724	23591	44391	\N	42.646379000000003	Приморский край, Хасанский муниципальный район, пгт. Зарубино, Строительная, 24а		0101000020E61000000917F2086E6260401DE90C8CBC524540
74291	4	36	1724	24373	44795	\N	43.301678000000003	Приморский край, Хасанский муниципальный район, с. Занадворовка, Центральная, 12		0101000020E6100000295B24ED467360401BF67B629DA64540
74274	4	36	1724	23520	44792	\N	42.690894999999998	Приморский край, Хасанский муниципальный район, с. Гвоздево, Новая, 1		0101000020E610000000FF942A515D604026FC523F6F584540
74285	4	36	1724	24064	44861	\N	42.969709000000002	Приморский край, Хасанский муниципальный район, с. Безверхово, пер.Школьный, 3а		0101000020E6100000348639419B6F604085D1AC6C1F7C4540
74288	4	36	1724	24201	44596	\N	43.190019999999997	Приморский край, Хасанский муниципальный район, с. Барабаш, Школьная, 1		0101000020E6100000024A438DC26F6040FFCA4A9352984540
74289	4	36	1724	24201	44526	\N	43.190019999999997	Приморский край, Хасанский муниципальный район, с. Барабаш, Восточная Слобода, 1а		0101000020E6100000024A438DC26F6040FFCA4A9352984540
74277	4	36	1724	23677	44811	\N	42.647652999999998	Приморский край, Хасанский муниципальный район, с. Андреевка, Набережная, 9		0101000020E610000028EE78935F6460400114234BE6524540
74267	4	36	750	23230	45101	\N	45.236097999999998	Приморский край, Ханкайский муниципальный район, Новокачалинское сельское поселение, с. Турий Рог, Пограничная, 24		0101000020E6100000B4E908E0667F604054539275389E4640
74269	4	36	750	23308	44959	\N	45.183165000000002	Приморский край, Ханкайский муниципальный район, Первомайское сельское поселение, с. Рассказово, Рабочая, 16а		0101000020E6100000CFF57D3848796040CC6262F371974640
74265	4	36	750	23122	44957	\N	45.046258999999999	Приморский край, Ханкайский муниципальный район, Новокачалинское сельское поселение, с. Платоно-Александровское, Ленина, 2		0101000020E61000009C86A8C29F7F6040A5129ED0EB854640
74268	4	36	750	23236	45049	\N	45.135745999999997	Приморский край, Ханкайский муниципальный район, Первомайское сельское поселение, с. Первомайское, Ленина, 33		0101000020E6100000FAD170CA5C7B60400A48FB1F60914640
74250	4	36	750	22437	45106	\N	44.764335217814597	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Пархоменко, Центральная, 1б	Россия, Приморский край, Ханкайский район, село Пархоменко	0101000020E61000003694DA8BE87E60401618B2BAD5614640
74262	4	36	750	22966	44960	\N	44.918081000000001	Приморский край, Ханкайский муниципальный район, Октябрьское сельское поселение, с. Октябрьское, Советская, 19а		0101000020E61000000B0C59DD6A8060401C0A9FAD83754640
74252	4	36	750	22528	44858	\N	44.655132999999999	Приморский край, Ханкайский муниципальный район, Новоселищенское сельское поселение, с. Новоселище, Пролетарская, 8		0101000020E61000002504ABEA657B6040E3C3EC65DB534640
74260	4	36	750	22869	44931	\N	44.889913999999997	Приморский край, Ханкайский муниципальный район, Октябрьское сельское поселение, с. Новониколаевка, Жданова, 17		0101000020E610000094F947DF248360405320B3B3E8714640
74266	4	36	750	23163	44813	\N	45.099339999999998	Приморский край, Ханкайский муниципальный район, Новокачалинское сельское поселение, с. Новокачалинск, Калинина, 17		0101000020E6100000836C59BE2E806040A297512CB78C4640
74255	4	36	750	22694	44901	\N	44.572591000000003	Приморский край, Ханкайский муниципальный район, Новоселищенское сельское поселение, с. Мельгуновка, Ленинская, 30а		0101000020E61000006D3CD862377E6040F27D71A94A494640
74261	4	36	750	22911	44903	\N	44.941206999999999	Приморский край, Ханкайский муниципальный район, Октябрьское сельское поселение, с. Майское, Почтовая, 11		0101000020E6100000C79FA86CD87F604015E2917879784640
74259	4	36	750	22838	45013	\N	44.895232999999998	Приморский край, Ханкайский муниципальный район, Октябрьское сельское поселение, с. Люблино, Новая, 9, кв.2		0101000020E610000094675E0E3B81604065A6B4FE96724640
74263	4	36	750	23023	45051	\N	44.990389	Приморский край, Ханкайский муниципальный район, Комиссаровское сельское поселение, с. Комиссарово, Советская, 16ж		0101000020E6100000C1E61C3C13796040B9A81611C57E4640
73841	4	36	410	2182	44398	\N	43.932932999999998	с. Михайловка, Красноармейская, 12		0101000020E61000005FD3838252806040F92D3A596AF74540
74246	4	36	750	22154	\N	\N	44.735143999999998	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Камень-Рыболов, городок №1		0101000020E61000003CA1D79F44816040E1ECD632195E4640
74247	4	36	750	22154	44897	\N	44.735143999999998	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Камень-Рыболов, Трактовая, 119		0101000020E61000003CA1D79F44816040E1ECD632195E4640
74244	4	36	750	22154	44390	\N	44.735143999999998	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Камень-Рыболов, Пионерская, 8		0101000020E61000003CA1D79F44816040E1ECD632195E4640
74248	4	36	750	22154	44524	\N	44.735143999999998	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Камень-Рыболов, Мира, 10		0101000020E61000003CA1D79F44816040E1ECD632195E4640
74243	4	36	750	22154	44544	\N	44.735143999999998	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Камень-Рыболов, Кирова, 10		0101000020E61000003CA1D79F44816040E1ECD632195E4640
74258	4	36	750	22805	42663	\N	44.896113999999997	Приморский край, Ханкайский муниципальный район, Ильинское сельское поселение, с. Ильинка, Столетия, 1	Россия, Приморский край, Ханкайский район, село Ильинка	0101000020E610000003CE52B21C7F60406EBE11DDB3724640
74264	4	36	750	23060	45102	\N	44.878093	Приморский край, Ханкайский муниципальный район, Комиссаровское сельское поселение, с. Дворянка, Сидельникова, 26		0101000020E6100000F486FBC8AD7260405BECF65965704640
74251	4	36	750	22500	44896	\N	44.659576999999999	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Владимиро-Петровка, Молодежная, 7		0101000020E6100000B2BAD573D2826040CE18E6046D544640
74249	4	36	750	22392	44605	\N	44.721017000000003	Приморский край, Ханкайский муниципальный район, Камень-Рыболовское сельское поселение, с. Астраханка, Березюка, 1		0101000020E6100000DAACFA5CED816040166EF9484A5C4640
74254	4	36	750	22647	44932	\N	44.722214999999998	Приморский край, Ханкайский муниципальный район, Новоселищенское сельское поселение, с. Алексеевка, Школьная, 15а		0101000020E6100000E481C8224D7C60401FD7868A715C4640
73654	4	36	7359	55301	\N	\N	43.035174566420402	Приморский край, Владивостокский городской округ, Фрунзенский район, с. остров Русский, Поселок Аякс, МБОУ СОШ № 5	Россия, Приморский край, Русский остров	0101000020E610000090847D3B897C60408351499D80844540
74220	4	36	1637	21042	44951	\N	43.730894378658697	Приморский край, Уссурийский район, с. Яконовка, Центральная, 76/1	Россия, Приморский край, Уссурийский район, село Яконовка	0101000020E6100000799274CD64766040DB6B41EF8DDD4540
74229	4	36	1637	21459	45100	\N	43.750307999999997	Приморский край, Уссурийский район, с. Утесное, Раздольная, 2		0101000020E610000023861DC6247E6040ADF6B0170AE04540
74216	4	36	1637	20848	45046	\N	43.859446743505103	Приморский край, Уссурийский район, с. Улитовка, Новая, 59	Россия, Приморский край, Уссурийский район, село Улитовка	0101000020E6100000083E062B4E7560409AD2FA5B02EE4540
74224	4	36	1637	21217	44594	\N	43.859724	Приморский край, Уссурийский район, п. Тимирязевский, Воложенина, 2в		0101000020E61000000F09DFFB9B7E60400CCB9F6F0BEE4540
74223	4	36	1637	21209	44790	\N	43.972078000000003	Приморский край, Уссурийский район, с. Степное, Центральная, 4		0101000020E61000008E075BECF67960409F94490D6DFC4540
74226	4	36	1637	21330	44895	\N	43.807039000000003	Приморский край, Уссурийский район, с. Раковка, Советская, 1а		0101000020E6100000FB78E8BB5B8560405CCCCF0D4DE74540
74232	4	36	1637	21575	45099	\N	43.691431000000001	Приморский край, Уссурийский район, п. Партизан, Партизанская, 8		0101000020E61000009BCB0D86BA7E604065389ECF80D84540
74241	4	36	1637	21147	44375	\N	43.856259999999999	Приморский край, с. Новоникольск, Советская, 79		0101000020E61000009A7CB3CD8D7B6040BD6F7CED99ED4540
74222	4	36	1637	21147	44375	\N	43.856259999999999	Приморский край, Уссурийский район, с. Новоникольск, Советская, 70		0101000020E61000009A7CB3CD8D7B6040BD6F7CED99ED4540
74212	4	36	1637	20609	44953	\N	43.877954000000003	Приморский край, Уссурийский район, с. Николо-Львовское, Пархоменко, 2а		0101000020E6100000BA10AB3FC26B60403AB2F2CB60F04540
74217	4	36	1637	20881	45048	\N	43.744708000000003	Приморский край, Уссурийский район, с. Монакино, Угловая, 8/2		0101000020E6100000FBE769C0A06E6040E8887C9752DF4540
74231	4	36	1637	21572	45045	\N	43.734743000000002	Приморский край, Уссурийский район, с. Линевичи, Центральная, 2		0101000020E6100000881057CEDE7A604083FB010F0CDE4540
74219	4	36	1637	20989	45097	\N	43.751578000000002	Приморский край, Уссурийский район, с. Кроуновка, Советская, 35		0101000020E610000082A8FB0024756040513239B533E04540
74230	4	36	1637	21510	44954	\N	43.692144164157803	Приморский край, Уссурийский район, с. Красный Яр, Советская, 36	Россия, Приморский край, Уссурийский район, село Красный Яр	0101000020E61000003735D07C4E7D6040B20FB22C98D84540
74218	4	36	1637	20952	44424	\N	43.779330999999999	Приморский край, Уссурийский район, с. Корсаковка, Комсомольская, 12		0101000020E61000005F5D15A84576604026E1421EC1E34540
74234	4	36	1637	21696	44958	\N	43.625399302530802	Приморский край, Уссурийский район, с.  Кондратеновка, Баневура, 36	Россия, Приморский край, Уссурийский район, село Кондратеновка	0101000020E6100000020EA14A4D856040BEF90D130DD04540
74236	4	36	1637	21791	44808	\N	43.619666000000002	Приморский край, Уссурийский район, с. Каменушка, Школьная, 15		0101000020E6100000D175E10767876040B9382A3751CF4540
74237	4	36	1637	21869	44810	\N	43.698112000000002	Приморский край, Уссурийский район, с. Заречное, Пионерская, 1а		0101000020E61000007E1B62BC66836040FB78E8BB5BD94540
74233	4	36	1637	21664	45004	\N	43.660401999999998	Приморский край, Уссурийский район, с. Дубовый Ключ, Садовая, 5		0101000020E6100000B151D66F26846040431B800D88D44540
53964	4	39	\N	231	45999	\N	59.556319999999999	Магаданская область, город Магадан, Пролетарская, 110		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
74235	4	36	1637	55321	45136	\N	43.695354516547702	Приморский край, Уссурийский район, с. Горно-Таежное, Солнечная, 9а	Россия, Приморский край, Уссурийский район, село Горнотаежное	0101000020E6100000BD0166BE03856040170E846401D94540
74227	4	36	1637	21361	45047	\N	43.762393000000003	Приморский край, Уссурийский район, с. Глуховка, Октябрьская, 44		0101000020E6100000187783682D83604084D9041896E14540
74240	4	36	1637	21289	42840	\N	43.894065252144202	Приморский край, Уссурийский район, с. Воздвиженка, Чайковского, 3	Россия, Приморский край, Уссурийский район, село Воздвиженка	0101000020E6100000AF25E4831E7E6040C6BFCFB870F24540
74225	4	36	1637	21289	44523	\N	43.897540999999997	Приморский край, Уссурийский район, с. Воздвиженка, Ленинская, 59		0101000020E61000007407B133057E6040D9E89C9FE2F24540
74239	4	36	1637	21289	44859	\N	43.897540999999997	Приморский край, Уссурийский район, с. Воздвиженка, Жуковского, 5		0101000020E61000007407B133057E6040D9E89C9FE2F24540
74221	4	36	1637	21092	44475	\N	43.806342000000001	Приморский край, Уссурийский район, с. Борисовка, Советская, 55		0101000020E61000006D5512D9077A604014B2F33636E74540
74228	4	36	1637	21418	45095	\N	43.817380735905303	Приморский край, Уссурийский район, с. Боголюбовка, Новая, 2а	Россия, Приморский край, Уссурийский район, село Боголюбовка	0101000020E610000089D2DEE08B88604096AFCBF09FE84540
74215	4	36	1637	20787	45009	\N	43.804981186470698	Приморский край, Уссурийский район, с. Богатырка, Центральная, 13	Россия, Приморский край, Уссурийский район, село Богатырка	0101000020E61000005039268B7B73604060730E9E09E74540
74238	4	36	1637	21876	45062	\N	43.719017000000001	Приморский край, Уссурийский район, с. Баневурово, Школьная, 32		0101000020E61000001878EE3D5C8160404F22C2BF08DC4540
74144	4	36	1455	17063	44999	\N	46.171422999999997	Приморский край, Тернейский муниципальный район, Усть-Соболевское сельское поселение, с. Усть-Соболевка, Советская, 16		0101000020E6100000AC55BB26244061401F645930F1154740
74138	4	36	1455	16771	44514	\N	45.073207122149199	Приморский край, Тернейский муниципальный район, Тернейское городское поселение, пгт. Терней, Партизанская, 70	Россия, Приморский край, Тернейский район, поселок городского типа Терней	0101000020E61000001A34F44FF01261404C6BD3D85E894640
74139	4	36	1455	55267	44516	\N	45.072598999999997	Приморский край, Тернейский муниципальный район, Тернейское городское поселение, пгт. Терней, Партизанская, 71		0101000020E6100000E8667FA0DC126140745C8DEC4A894640
74145	4	36	1455	17091	44857	\N	46.541134	Приморский край, Тернейский муниципальный район, Светлое городское поселение, пгт. Светлая, Школьная, 33		0101000020E6100000971E4DF5644A6140786000E143454740
74147	4	36	1455	17203	45123	\N	47.247103000000003	Приморский край, Тернейский муниципальный район, Самаргинское сельское поселение, с. Самарга, Береговая, 13		0101000020E6100000DE567A6DB65961402BDF3312A19F4740
74136	4	36	1455	16633	44586	\N	44.759847999999998	Приморский край, Тернейский муниципальный район, Пластунское городское поселение, пгт. Пластун, Третий квартал, 6		0101000020E6100000D9EA724A400961402BF702B342614640
74137	4	36	1455	16633	44506	\N	44.759847999999998	Приморский край, Тернейский муниципальный район, Пластунское городское поселение, пгт. Пластун, Лермонтова, 12-А		0101000020E6100000D9EA724A400961402BF702B342614640
74146	4	36	1455	17160	45118	\N	47.185329727837903	Приморский край, Тернейский муниципальный район, Единкинское сельское поселение, с. Перетычиха, Школьная, 18	Россия, Приморский край, Тернейский район, село Перетычиха	0101000020E6100000F888981249546140DD7BB8E4B8974740
74140	4	36	1455	16866	44871	\N	45.411400999999998	Приморский край, Тернейский муниципальный район, Кемское сельское поселение, с. Малая Кема, Спортивная, 10		0101000020E610000069C87894CA2461405645B8C9A8B44640
74141	4	36	1455	16912	44906	\N	45.846896000000001	Приморский край, Тернейский муниципальный район, Амгунское сельское поселение, с. Амгу, Молодежная, 8		0101000020E61000005D6DC5FEB23561407E8E8F1667EC4640
74148	4	36	1455	17256	45121	\N	47.592432000000002	Приморский край, Тернейский муниципальный район, Удэгейское сельское поселение, с. Агзу, Крючкова, 10		0101000020E6100000A017EE5C984C61404C8DD0CFD4CB4740
74448	4	36	616	4015	44431	\N	44.835065999999998	Приморский край, Спасский муниципальный район, Чкаловское сельское поселение, с. Чкаловское, Торговый, 12		0101000020E61000003276C24B70A1604032005471E36A4640
74535	4	36	616	4015	44433	\N	44.835066003202797	692200 Приморский край, Спасский муниципальный район, Чкаловское сельское поселение, с. Чкаловское ул. Терешкевича, д. 54	Россия, Приморский край, Спасский район, село Чкаловское	0101000020E6100000EE06D15A51A1604032005471E36A4640
74449	4	36	616	4015	44433	\N	44.835065999999998	Приморский край, Спасский муниципальный район, Чкаловское сельское поселение, с. Чкаловское, Терешкевича, 55		0101000020E61000003276C24B70A1604032005471E36A4640
74447	4	36	616	31650	44818	\N	44.629576	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Хвалынка, Советская, 29		0101000020E6100000F6F065A2889C60405A2C45F295504640
74446	4	36	616	31573	45113	\N	44.614891	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Татьяновка, пер. Новый, 2, 1		0101000020E6100000757286E20EA2604068CD8FBFB44E4640
74445	4	36	616	31562	44966	\N	44.696193999999998	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Степное, Центральная, 6		0101000020E61000008CF2CCCBE1976040F1D58EE21C594640
74442	4	36	616	30579	44537	\N	44.614306999999997	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Спасское, пер. Студенческий, 26		0101000020E6100000B9196EC067996040185A9D9CA14E4640
38815	4	35	1863	45404	46214	\N	55.121155000000002	с. Долиновка, ул. Елисеевская, 14		0101000020E6100000D446753A10E263409A5FCD01828F4B40
74534	4	36	616	30579	44539	\N	44.616023236997698	692211 Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Спасское Комсомольская 108	Россия, Приморский край, Спасский район, село Спасское	0101000020E6100000FED137699A996040BA4A77D7D94E4640
74443	4	36	616	30579	44539	\N	44.614306999999997	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Спасское, Комсомольская, 104		0101000020E6100000B9196EC067996040185A9D9CA14E4640
74444	4	36	616	30579	44387	\N	44.614306999999997	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Спасское, 70 лет Октября, 2		0101000020E6100000B9196EC067996040185A9D9CA14E4640
74441	4	36	616	31363	45012	\N	44.8063280190133	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Сосновка, Советская, 49, 1	Россия, Приморский край, Спасский район, село Сосновка	0101000020E6100000A565A4DED3996040AFEC82C135674640
74440	4	36	616	31303	45060	\N	44.574350000000003	"Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Славинка, Преображенская, 1 ""А"""		0101000020E6100000C190D5AD1E9D6040933A014D84494640
74439	4	36	616	31233	44446	\N	44.822639000000002	Приморский край, Спасский муниципальный район, Чкаловское сельское поселение, железнодорожная станция Свиягино, Партизанская, 12		0101000020E6100000B4739A055AA2604003B5183C4C694640
74437	4	36	616	31155	44905	\N	44.520941999999998	Приморский край, Спасский муниципальный район, Прохорское сельское поселение, с. Прохоры, Ленинская, 66		0101000020E610000082919735B1966040718E3A3AAE424640
74436	4	36	616	31109	44902	\N	44.772077000000003	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Новосельское, Центральная, 20		0101000020E6100000CF6BEC1255966040357F4C6BD3624640
74434	4	36	616	31013	44974	\N	44.599662000000002	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Нововладимировка, ул.Центральная, 18		0101000020E61000001E1B8178DDA36040B55373B9C14C4640
74433	4	36	616	30968	44965	\N	44.564171999999999	Приморский край, Спасский муниципальный район, Прохорское сельское поселение, с. Новинка, Тополиная, 6		0101000020E6100000427A8A1CA2996040D2A8C0C936484640
74432	4	36	616	30887	9665	\N	44.635978000000001	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Нахимовка, Садовая, 3,1		0101000020E61000004C70EA03C9A36040DD7C23BA67514640
74431	4	36	616	30880	45057	\N	44.468647941369397	Приморский край, Спасский муниципальный район, Прохорское сельское поселение, с. Малые Ключи, пер. Октябрьский, 2	Россия, Приморский край, Спасский район, село Малые Ключи	0101000020E6100000A7E6728321966040FCAA5CA8FC3B4640
74430	4	36	616	55319	45138	\N	44.723112536672197	Приморский край, Спасский муниципальный район, Чкаловское сельское поселение, с. Кронштадтка, Борисова, 6		0101000020E610000009C556D034A36040FE277FF78E5C4640
74420	4	36	616	30295	\N	\N	44.519052000000002	Приморский край, Спасский муниципальный район, Краснокутское сельское поселение, с. Красный Кут, ДОС, 1		0101000020E61000004DA088458C9A60403276C24B70424640
74429	4	36	616	30295	44963	\N	44.519052000000002	Приморский край, Спасский муниципальный район, Краснокутское сельское поселение, с. Красный Кут, Октябрьская, 82		0101000020E61000004DA088458C9A60403276C24B70424640
74428	4	36	616	30685	45111	\N	44.671802	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Константиновка, Средняя, 3		0101000020E6100000B6D8EDB3CA9F604096B1A19BFD554640
74427	4	36	616	55300	\N	\N	44.516841045978801	Приморский край, Спасский муниципальный район, Прохорское сельское поселение, железнодорожная станция Кнорринг, здание ЖД станции	Россия, Приморский край, Спасский район	0101000020E6100000C2BD326F55946040B01D8CD827424640
74425	4	36	616	30532	45114	\N	44.918030000000002	Приморский край, Спасский муниципальный район, Чкаловское сельское поселение, с. Зеленодольское, Школьная, 3		0101000020E61000000917F2086EA260409A5FCD0182754640
74424	4	36	616	30499	44975	\N	44.524141999999998	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Зеленовка, Первомайская, 36		0101000020E6100000F452B131AFA06040E23AC61517434640
74423	4	36	616	30460	45056	\N	44.4126226060257	"Приморский край, Спасский муниципальный район, Краснокутское сельское поселение, с. Евсеевка, Кедровая, 13 ""А"""	Россия, Приморский край, Спасский район, село Евсеевка	0101000020E6100000AAEFFCA2849C6040E94999D4D0344640
74422	4	36	616	30366	44803	\N	44.878118000000001	Приморский край, Спасский муниципальный район, Духовское сельское поселение, с. Духовское, пер. Школьный, 13		0101000020E6100000C72B103DA9A46040B403AE2B66704640
74421	4	36	616	30360	44798	\N	44.549444000000001	Приморский край, Спасский муниципальный район, Дубовское сельское поселение, с. Дубовское, Молодежная, 35		0101000020E6100000460C3B8C499B6040E17D552E54464640
74419	4	36	616	30222	45055	\N	44.748345	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Гайворон, Ленинская, 37		0101000020E610000003D2FE07D89860400490DAC4C95F4640
74418	4	36	616	30194	44817	\N	44.573591999999998	Приморский край, Спасский муниципальный район, Спасское сельское поселение, с. Воскресенка, пер.Школьный, 4		0101000020E61000000684D6C397976040A59F70766B494640
74417	4	36	616	30147	44866	\N	44.454912999999998	"Приморский край, Спасский муниципальный район, Краснокутское сельское поселение, с. Вишневка, пер. Школьный, 1 ""А"""		0101000020E6100000C37FBA81829B60403BC3D4963A3A4640
73456	4	36	125	15571	4388	\N	43.404870000000003	Приморский край, Артемовский городской округ, с. Кневичи, переулок Чуркина, 12		0101000020E6100000F60A0BEE07866040D690B8C7D2B34540
74415	4	36	616	30054	44904	\N	44.634836	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Буссевка, Советская, 27		0101000020E6100000D05E7D3C749F60406729594E42514640
74533	4	36	616	30054	45162	\N	44.636977398533404	692221 Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Буссевка Светлая 19	Россия, Приморский край, Спасский район, село Буссевка	0101000020E6100000BFD6A546689F6040F0A65B7688514640
74413	4	36	616	29943	45125	\N	44.705727000000003	Приморский край, Спасский муниципальный район, Хвалынское сельское поселение, с. Анненка, Гагарина, 2, 2	Россия, Приморский край, Спасский район, село Анненка	0101000020E61000008509A359599E6040BD732843555A4640
74412	4	36	616	29915	44479	\N	44.77122	"Приморский край, Спасский муниципальный район, Александровское сельское поселение, с. Александровка, Уборевича, 63 ""А"""		0101000020E610000051D845D1839E6040B4024356B7624640
74105	4	36	668	55323	45140	\N	46.601829249720197	Приморский край, Пожарский муниципальный район, Соболинское сельское поселение, с. Ясеневое, ул. Широкая, дом 6	Россия, Приморский край, Пожарский район, село Ясеневый	0101000020E61000002CF3565D07ED6040676490BB084D4740
74101	4	36	668	14943	44782	\N	46.535170000000001	Приморский край, Пожарский муниципальный район, Федосьевское сельское поселение, с. Федосьевка, ул. Советская, 29		0101000020E6100000AC8C463EAFC8604071E6577380444740
74104	4	36	668	55315	45122	\N	46.674909587171598	Приморский край, Пожарский муниципальный район, Соболинское сельское поселение, с. Соболиное, ул. Родниковая, дом 4	Россия, Приморский край, Пожарский район, село Соболиный	0101000020E61000003E079623E4ED604026DF6C7363564740
74102	4	36	668	14998	42655	\N	46.860202095163999	Приморский край, Пожарский муниципальный район, Светлогорское сельское поселение, с. Светлогорье, ул. В Хомякова, дом 2	Россия, Приморский край, Пожарский район, село Светлогорье	0101000020E6100000DE59BBED42CE604016FA60191B6E4740
74086	4	36	668	14228	44361	\N	46.254956999999997	Приморский край, Пожарский муниципальный район, Пожарское сельское поселение, с. Пожарское, ул. Ленинская, 27		0101000020E6100000FB0626370AC260407171546EA2204740
74085	4	36	668	14179	45040	\N	46.223903	Приморский край, Пожарский муниципальный район, Пожарское сельское поселение, совхоз Пожарский, ул. Центральная, здание 22		0101000020E6100000C9CB9A5860C06040F73C7FDAA81C4740
74083	4	36	668	14099	44440	\N	46.183472999999999	Приморский край, Пожарский муниципальный район, Губеровское сельское поселение, с. Новостройка, ул.Заводская, дом 12		0101000020E61000008192020BE0BD60407959130B7C174740
74087	4	36	668	14289	45000	\N	46.276837	Приморский край, Пожарский муниципальный район, Пожарское сельское поселение, с. Никитовка, ул. Зелёная, дом 25а		0101000020E6100000E1606F62C8C3604050A912656F234740
74092	4	36	668	14514	44837	\N	46.338101999999999	Приморский край, Пожарский муниципальный район, Нагорненское сельское поселение, с. Нагорное, ул. Юбилейная, 7		0101000020E61000007A39ECBE63CC6040295B24ED462B4740
74099	4	36	668	14565	44823	\N	46.441678000000003	Приморский край, Пожарский муниципальный район, Лучегорское городское поселение, пгт. Лучегорск, третий микрорайон, 30		0101000020E61000007959130B7CC960406DAE9AE788384740
74097	4	36	668	14565	44362	\N	46.441678000000003	Приморский край, Пожарский муниципальный район, Лучегорское городское поселение, пгт. Лучегорск, первый микрорайон, дом 12		0101000020E61000007959130B7CC960406DAE9AE788384740
74095	4	36	668	55266	\N	\N	46.441678000000003	Приморский край, Пожарский муниципальный район, Лучегорское городское поселение, пгт. Лучегорск, общественный центр, 2		0101000020E61000007959130B7CC960406DAE9AE788384740
74096	4	36	668	55266	44582	\N	46.441678000000003	Приморский край, Пожарский муниципальный район, Лучегорское городское поселение, пгт. Лучегорск, второй микрорайон, здание 23		0101000020E61000007959130B7CC960406DAE9AE788384740
74094	4	36	668	55266	44585	\N	46.441678000000003	Приморский край, Пожарский муниципальный район, Лучегорское городское поселение, пгт. Лучегорск, четвертый микрорайон, дом 4		0101000020E61000007959130B7CC960406DAE9AE788384740
74093	4	36	668	55266	44581	\N	46.441678000000003	Приморский край, Пожарский муниципальный район, Лучегорское городское поселение, пгт. Лучегорск, ул. Ленина, 35а		0101000020E61000007959130B7CC960406DAE9AE788384740
74089	4	36	668	14377	45094	\N	46.397769593880497	Приморский край, Пожарский муниципальный район, Игнатьевское сельское поселение, с. Ласточка, ул. Вокзальная, дом 1	Россия, Приморский край, Пожарский район, село Ласточка	0101000020E6100000A9BF5E61C1C360403BAA9A20EA324740
74106	4	36	668	4555	45093	\N	46.541251000000003	Приморский край, Пожарский муниципальный район, Краснояровское сельское поселение, с. Красный Яр, ул. Арсеньева, дом 9а		0101000020E61000007D24253D8CEB6040B2F677B647454740
74091	4	36	668	14463	45041	\N	46.406319000000003	Приморский край, Пожарский муниципальный район, Игнатьевское сельское поселение, с. Игнатьевка, ул. Советская, 11		0101000020E61000004A7B832F4CC46040295FD04202344740
74082	4	36	668	14029	45039	\N	46.161791999999998	Приморский край, Пожарский муниципальный район, Губеровское сельское поселение, с. Знаменка, ул. Вёселая, здание 14		0101000020E61000009B1BD31316BF60409160AA99B5144740
74088	4	36	668	14301	44979	\N	46.362839999999998	Приморский край, Пожарский муниципальный район, Игнатьевское сельское поселение, с. Емельяновка, ул. Пограничная, дом 13		0101000020E6100000FF23D3A153C160401FD7868A712E4740
38817	4	35	1863	29501	46176	\N	55.605896999999999	п. Атласово, ул Ленинградская, 2		0101000020E6100000F38DE89E75F463404CDF6B088ECD4B40
74084	4	36	668	14150	44785	\N	46.202100999999999	"Приморский край, Пожарский муниципальный район, Губеровское сельское поселение, с. Губерово, ул. Совхозная, дом 15""А"""		0101000020E6100000BAA1293B7DBE604094BE1072DE194740
74103	4	36	668	55265	44505	\N	46.565176098996197	Приморский край, Пожарский муниципальный район, Верхнеперевальское сельское поселение, с. Верхний Перевал, ул. Школьная, дом 2	Россия, Приморский край, Пожарский район, село Верхний Перевал	0101000020E61000008507CDAE7BD56040F73DEAAF57484740
74069	4	36	1251	13423	45037	\N	44.381905392744997	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, п. Таловый, Центральная, 1 А	Россия, Приморский край, Пограничный район, поселок Таловый	0101000020E6100000616D8C9DF0716040E6965643E2304640
74067	4	36	1251	13343	44995	\N	44.300144000000003	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, с. Софье-Алексеевское, Центральная, 10		0101000020E6100000A24621C92C6B60409A0B5C1E6B264640
74072	4	36	1251	13567	44887	\N	44.332552999999997	Приморский край, Пограничный муниципальный район, Сергеевское сельское поселение, с. Сергеевка, Колхозная, 22 А		0101000020E610000024F1F2742E756040E597C118912A4640
74070	4	36	1251	55328	45152	\N	44.399325630751498	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, с. Садовое, Верхняя, 15	Россия, Приморский край, Пограничный район, село Садовый	0101000020E6100000CEC133A149736040A438471D1D334640
74080	4	36	1251	13920	45091	\N	44.691034999999999	Приморский край, Пограничный муниципальный район, Жариковское сельское поселение, с. Рубиновка, Набережная, 13		0101000020E6100000CB8635954576604018B2BAD573584640
74057	4	36	1251	55258	44413	\N	44.407873000000002	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, пгт. Пограничный, Орлова, 14		0101000020E6100000BBB72231416C6040F1F5B52E35344640
74062	4	36	1251	55258	44868	\N	44.407873000000002	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, пгт. Пограничный, Лазо, 101		0101000020E6100000BBB72231416C6040F1F5B52E35344640
74058	4	36	1251	55258	44578	\N	44.407873000000002	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, пгт. Пограничный, Дубовика, 8		0101000020E6100000BBB72231416C6040F1F5B52E35344640
74061	4	36	1251	55258	44579	\N	44.407873000000002	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, пгт. Пограничный, Гагарина, 9		0101000020E6100000BBB72231416C6040F1F5B52E35344640
74060	4	36	1251	55258	44579	\N	44.407873000000002	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, пгт. Пограничный, Гагарина, 8		0101000020E6100000BBB72231416C6040F1F5B52E35344640
74059	4	36	1251	12859	44865	\N	44.407873000000002	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, пгт. Пограничный, Советская, 63		0101000020E6100000BBB72231416C6040F1F5B52E35344640
74063	4	36	1251	12859	44504	\N	44.407873000000002	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, пгт. Пограничный, Лазо, 141		0101000020E6100000BBB72231416C6040F1F5B52E35344640
74075	4	36	1251	13703	44888	\N	44.452243000000003	Приморский край, Пограничный муниципальный район, Жариковское сельское поселение, с. Нестеровка, Советская, 22		0101000020E61000000BB8E7F953786040276C3F19E3394640
74076	4	36	1251	13750	44360	\N	44.591465999999997	Приморский край, Пограничный муниципальный район, Жариковское сельское поселение, с. Жариково, Кооперативная, 26		0101000020E61000005D70067F3F77604014596B28B54B4640
74079	4	36	1251	13906	45116	\N	44.595168999999999	Приморский край, Пограничный муниципальный район, Жариковское сельское поселение, с. Духовское, Ленина, 15 А		0101000020E610000027D87F9D1B716040E84B6F7F2E4C4640
74064	4	36	1251	13200	45038	\N	44.464768999999997	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, с. Бойкое, Ленина, 20		0101000020E6100000CE52B29C046F6040E998F38C7D3B4640
74078	4	36	1251	13793	44890	\N	44.486400994094701	Приморский край, Пограничный муниципальный район, Жариковское сельское поселение, с. Богуславка, Школьная, 55	Россия, Приморский край, Пограничный район, село Богуславка	0101000020E610000048895DDB5B726040F0DE5163423E4640
74065	4	36	1251	13225	44409	\N	44.369449000000003	Приморский край, Пограничный муниципальный район, Пограничное городское поселение, с. Барано-Оренбургское, Победы, 21 А		0101000020E6100000D3D85E0B7A6E60401C45D61A4A2F4640
74049	4	36	738	12498	45096	\N	42.783158	Приморский край, Партизанский муниципальный район, Владимиро-Александровское сельское поселение, с. Хмыловка, 40 лет Победы, 1-а	Россия, Приморский край, Партизанский район, село Хмыловка	0101000020E61000002B1213D4F0A36040E6CC76853E644540
74038	4	36	738	11975	44886	\N	43.207147730845698	Приморский край, Партизанский муниципальный район, Новицкое сельское поселение, с. Фроловка, Партизанская, 20		0101000020E61000006474401276A8604045B75ED3839A4540
74036	4	36	738	11834	44359	\N	43.327501394888898	Приморский край, Партизанский муниципальный район, Сергеевское сельское поселение, с. Сергеевка, пер. Школьный, 4	Россия, Приморский край, Партизанский район, село Сергеевка	0101000020E610000099654F029BAB60402234828DEBA94540
74037	4	36	738	11834	44835	\N	43.323678999999998	Приморский край, Партизанский муниципальный район, Сергеевское сельское поселение, с. Сергеевка, Ручейная, 1а		0101000020E6100000D47E6B274AAB604074B33F506EA94540
53962	4	39	\N	231	46000	\N	59.556319999999999	Магаданская область, город Магадан, Речная, 61/1		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
74044	4	36	738	55326	45148	\N	43.004873213943902	Приморский край, Партизанский муниципальный район, Золотодолинское сельское поселение, с. Перетино, Черняховского, 4	Россия, Приморский край, Партизанский район, село Сергеевка	0101000020E61000001A170E84E4A4604014D1AFAD9F804540
74055	4	36	738	12793	44836	\N	42.912224000000002	Приморский край, Партизанский муниципальный район, Новолитовское сельское поселение, с. Новолитовск, Черняховского, 35		0101000020E6100000573F36C98F9960402B508BC1C3744540
74042	4	36	738	12197	42775	\N	43.054504999999999	Приморский край, Партизанский муниципальный район, Новицкое сельское поселение, с. Новицкое, Лазо, 7		0101000020E6100000B9FAB1497EA56040F73B1405FA864540
74050	4	36	738	12573	45036	\N	43.014023999999999	Приморский край, Партизанский муниципальный район, Екатериновское сельское поселение, с. Новая Сила, Центральная, 1-а		0101000020E6100000691CEA7761A36040F7ADD689CB814540
74041	4	36	738	12005	44603	\N	43.091701	Приморский край, Партизанский муниципальный район, Новицкое сельское поселение, п. Николаевка, Фадеева, 19		0101000020E6100000FA264D83A2A660405801BEDBBC8B4540
74034	4	36	738	11796	44779	\N	43.475792505377001	Приморский край, Партизанский муниципальный район, Сергеевское сельское поселение, с. Молчановка, Ключевая, 3	Россия, Приморский край, Партизанский район, село Молчановка	0101000020E610000047CCECF398AB60403755F7C8E6BC4540
74045	4	36	738	12340	44405	\N	42.945079	Приморский край, Партизанский муниципальный район, Золотодолинское сельское поселение, с. Золотая Долина, Центральная, 68		0101000020E61000003AEAE8B89AA3604075914259F8784540
74046	4	36	738	12340	44838	\N	42.932466605278698	Приморский край, Партизанский муниципальный район, Золотодолинское сельское поселение, с. Золотая Долина, Лётная, 11	Россия, Приморский край, Партизанский район, село Золотая Долина	0101000020E6100000BADA8AFD65A36040B4CC22145B774540
74052	4	36	738	12686	44412	\N	42.922576999999997	Приморский край, Партизанский муниципальный район, Екатериновское сельское поселение, с. Екатериновка, Советская, 6-а		0101000020E6100000E59CD8437BA160405985CD0017764540
74053	4	36	738	12686	44414	\N	42.922576999999997	Приморский край, Партизанский муниципальный район, Екатериновское сельское поселение, с. Екатериновка, Молодежная, 13		0101000020E6100000E59CD8437BA160405985CD0017764540
74054	4	36	738	12762	44998	\N	42.874259154625598	Приморский край, Партизанский муниципальный район, Екатериновское сельское поселение, с. Голубовка, 60 лет СССР, 1	Россия, Приморский край, Партизанский район, село Голубовка	0101000020E6100000E38BF67821A06040E99D0AB8E76F4540
73910	4	36	738	55252	44566	\N	42.720769516678899	Приморский край, г. Находка, п. Врангель, ул. Первостроителей, д. 10	Россия, Приморский край, Партизанский район, поселок Врангель	0101000020E610000043AA285E65A160400EF8FC30425C4540
73873	4	36	738	55252	59515	\N	42.7201366484679	Приморский край, г. Находка, п. Врангель, ул. Железнодорожная, д. 3	Россия, Приморский край, Партизанский район, поселок Врангель	0101000020E6100000392861A66DA16040DDD1FF722D5C4540
73885	4	36	738	55252	45001	\N	42.729537000000001	Приморский край, г. Находка, п.Врангель, ул. Внутрипортовая, д. 23	Россия, Приморский край, Партизанский район, поселок Врангель	0101000020E6100000B6BC72BD6DA26040691CEA77615D4540
73909	4	36	738	55252	44348	\N	42.7188076040608	Приморский край, г. Находка, п. Врангель, ул. Бабкина, д. 5	Россия, Приморский край, Партизанский район, поселок Врангель	0101000020E61000008750A5668FA16040350D8AE6015C4540
74056	4	36	738	5168	44873	\N	42.914878999999999	Приморский край, Партизанский муниципальный район, Новолитовское сельское поселение, п. Волчанец, Озерная, 10		0101000020E61000007D957CEC2E9860400A664CC11A754540
74048	4	36	738	12433	44411	\N	42.890906000000001	Приморский край, Партизанский муниципальный район, Владимиро-Александровское сельское поселение, с. Владимиро-Александровское, Лазо, 125		0101000020E61000001A88653387A26040B4E7323509724540
74047	4	36	738	12433	44474	\N	42.890906000000001	Приморский край, Партизанский муниципальный район, Владимиро-Александровское сельское поселение, с. Владимиро-Александровское, Комсомольская, 30		0101000020E61000001A88653387A26040B4E7323509724540
74051	4	36	738	12620	44854	\N	42.952595000000002	Приморский край, Партизанский муниципальный район, Екатериновское сельское поселение, п. Боец Кузнецов, Первомайская, 8		0101000020E61000001BF67B621DA26040A4AA09A2EE794540
73985	4	36	1029	9408	44996	\N	43.569544	Приморский край, Ольгинский муниципальный район, с. Щербаковка, Центральная, 28		0101000020E6100000D811876C20D4604007D15AD1E6C84540
73984	4	36	1029	9369	44947	\N	43.975627000000003	Приморский край, Ольгинский муниципальный район, Молдавановское сельское поселение, с. Фурманово, Центральная, 12		0101000020E6100000E4310395F1D560401C0C7558E1FC4540
73990	4	36	1029	9651	44849	\N	43.870251672197497	Приморский край, Ольгинский муниципальный район, Тимофеевское сельское поселение, п. Тимофеевка, Ленина, 1а	Россия, Приморский край, Ольгинский район, поселок Тимофеевка	0101000020E610000036069D10BAEE6040A9A3E36A64EF4540
73991	4	36	1029	9733	45033	\N	43.938794000000001	Приморский край, Ольгинский муниципальный район, Веселояровское сельское поселение, п. Ракушка, Адмирала Федюковского, 24-4		0101000020E610000099BA2BBB60EE60402CD7DB662AF84540
73980	4	36	1029	9196	44833	\N	43.767066999999997	Приморский край, Ольгинский муниципальный район, Пермское сельское поселение, с. Пермское, Центральная, 18		0101000020E6100000EF1CCA5095E56040A06B5F402FE24540
73977	4	36	1029	9089	44356	\N	43.756351000000002	Приморский край, Ольгинский муниципальный район, Ольгинское городское поселение, пгт. Ольга, Партизанская, 1		0101000020E6100000F38FBE49D3E9604001A60C1CD0E04540
73982	4	36	1029	9281	45119	\N	43.8215790069493	Приморский край, Ольгинский муниципальный район, Пермское сельское поселение, с. Новониколаевка, Центральная, 19	Россия, Приморский край, Ольгинский район, село Новониколаевка	0101000020E6100000CE6E2D93E1E060404A0A2C8029E94540
73987	4	36	1029	9523	44834	\N	43.350594999999998	Приморский край, Ольгинский муниципальный район, Моряк-Рыболовское сельское поселение, п. Моряк-Рыболов, Школьная, 3		0101000020E61000008A01124D20D960401092054CE0AC4540
73986	4	36	1029	9447	44993	\N	43.409114000000002	Приморский край, Ольгинский муниципальный район, Моряк-Рыболовское сельское поселение, с. Маргаритово, Школьная, 13		0101000020E610000033E202D028D86040FA2AF9D85DB44540
73989	4	36	1029	9593	44948	\N	43.329082999999997	Приморский край, Ольгинский муниципальный район, Милоградовское сельское поселение, с. Лиственное, Таежная, 32		0101000020E6100000B81D1A1623D16040B45549641FAA4540
73981	4	36	1029	9257	45008	\N	43.773629	Приморский край, Ольгинский муниципальный район, Пермское сельское поселение, с. Ветка, Буденного, 5		0101000020E610000053793BC2E9E360405C1E6B4606E34540
73976	4	36	1029	9039	44832	\N	43.956110000000002	Приморский край, Ольгинский муниципальный район, Веселояровское сельское поселение, с. Веселый ЯР, Набережная, 57		0101000020E6100000E353008CE7EE604075B0FECF61FA4540
73960	4	36	454	7952	45103	\N	43.945855999999999	Приморский край, Октябрьский муниципальный район, Покровское сельское поселение, с. Покровка, Красноармейская, 34		0101000020E6100000094E7D2079746040D95C35CF11F94540
73900	4	36	579	55329	45153	\N	43.324436011884004	Приморский край, Надеждинский муниципальный район, Тавричанское сельское поселение, п. Тавричанка, РВС-1, Клуб	Россия	0101000020E61000009E5E29CB907B604091D26C1E87A94540
73872	4	36	579	55327	45149	\N	43.510020060730703	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Тихий, Таежная, 20	Россия, Приморский край, Надеждинский район, село Тихое	0101000020E610000080812040867960402827DA5548C14540
73881	4	36	579	4267	44991	\N	43.512037999999997	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Тимофеевка, Центральная, 15		0101000020E61000007ADFF8DA337E6040952710768AC14540
73868	4	36	579	3629	45085	\N	43.641570999999999	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, с. Тереховка, Ленина, 4		0101000020E610000085268925657D6040F0879FFF1ED24540
73884	4	36	579	4432	44945	\N	43.476140000000001	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, п. Таежный, Мира, 8		0101000020E6100000861F9C4F9D7E6040A228D027F2BC4540
73898	4	36	579	55289	44712	\N	43.327268256488203	Приморский край, Надеждинский муниципальный район, Тавричанское сельское поселение, п. Тавричанка, Парковая, 15-А		0101000020E6100000A92F4B3BB57B60407F83F6EAE3A94540
73894	4	36	579	4997	45024	\N	43.395325999999997	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, п. Соловей-Ключ, Центральная, 30		0101000020E610000061A5828AAA81604016A1D80A9AB24540
73878	4	36	579	3907	44778	\N	43.535150999999999	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Раздольное, Пирогова, 40-А		0101000020E61000000A82C7B7F77C6040FAB5F5D37FC44540
73874	4	36	579	3907	44397	\N	43.535026154635098	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Раздольное, Ленинская, 1	Россия, Приморский край, Надеждинский район, поселок Раздольное	0101000020E6100000D0639467DE7C60403E4162BB7BC44540
73877	4	36	579	3907	44399	\N	43.535150999999999	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Раздольное, Лазо, 320		0101000020E61000000A82C7B7F77C6040FAB5F5D37FC44540
73875	4	36	579	3907	44399	\N	43.535150999999999	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Раздольное, Лазо, 36-А		0101000020E61000000A82C7B7F77C6040FAB5F5D37FC44540
73876	4	36	579	3907	44563	\N	43.535150999999999	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Раздольное, Котовского, 1-Б		0101000020E61000000A82C7B7F77C6040FAB5F5D37FC44540
73893	4	36	579	4922	44439	\N	43.336177999999997	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, с. Прохладное, Амурская, 3		0101000020E6100000D255BABBCE8060403DD175E107AB4540
73879	4	36	579	4169	44847	\N	43.592812000000002	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Оленевод, Шоссейная, 9-А		0101000020E6100000E5D022DB797B604093567C43E1CB4540
73891	4	36	579	55287	44688	\N	43.366292735185503	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, п. Новый, Первомайская, 37	Россия, Приморский край, Надеждинский район, поселок городского типа Новый	0101000020E61000008B8C0E48C28060407AE063B0E2AE4540
73871	4	36	579	3776	45089	\N	43.455404999999999	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, с. Нежино, Шоссейная, 14-А		0101000020E6100000EB353D28A8786040AAB706B64ABA4540
73883	4	36	579	4415	44872	\N	43.446989000000002	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, п. Кипарисово-2, Пролетарская, 7		0101000020E6100000247CEF6FD07D6040FC5580EF36B94540
73882	4	36	579	4345	44882	\N	43.477409000000002	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, с. Кипарисово-1, Советская, 1		0101000020E6100000FFCEF6E88D7D604075E8F4BC1BBD4540
73886	4	36	579	4551	45031	\N	43.359116999999998	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, п. Западный, Курбаева, 2-А		0101000020E61000006E4F90D8EE7E60400438BD8BF7AD4540
73896	4	36	579	55295	44907	\N	43.308759577536399	Приморский край, Надеждинский муниципальный район, Тавричанское сельское поселение, п. Девятый Вал, Набивайло, 14	море Японское	0101000020E6100000B34291EEE77A60400F289B7285A74540
73869	4	36	579	55324	45142	\N	43.641151510555403	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Городечный, Свободы, 12	Россия, Приморский край, Надеждинский район, село Городечное	0101000020E6100000F4DF83D7AE7E6040EBE1CB4411D24540
73888	4	36	579	4640	44492	\N	43.370939999999997	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, с. Вольно-Надеждинское, Пушкина, 51		0101000020E6100000A24621C9AC7F60409D6340F67AAF4540
73887	4	36	579	4640	44438	\N	43.370939999999997	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, с. Вольно-Надеждинское, Ленина, 39-А		0101000020E6100000A24621C9AC7F60409D6340F67AAF4540
73889	4	36	579	4640	44564	\N	43.370939999999997	Приморский край, Надеждинский муниципальный район, Надеждинское сельское поселение, с. Вольно-Надеждинское, Дрегиса, 5		0101000020E6100000A24621C9AC7F60409D6340F67AAF4540
73870	4	36	579	55303	44946	\N	43.646977036573197	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, железнодорожная станция Барановский, Тополинная, 1	Россия, Приморский край, Надеждинский район, село Барановский	0101000020E61000008B71FE26947D6040D1217024D0D24540
73880	4	36	579	4251	44950	\N	43.558681	Приморский край, Надеждинский муниципальный район, Раздольненское сельское поселение, п. Алексеевка, Ленина, 56		0101000020E61000008DB3E908607F6040C3F2E7DB82C74540
73865	4	36	410	3455	44881	\N	43.979500000000002	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, с. Ширяевка, Октябрьская, 34		0101000020E61000005EF23FF93B9260404C37894160FD4540
73866	4	36	410	3502	45087	\N	43.992057000000003	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, с. Тарасовка, Ломоносова, 18/а		0101000020E6100000B7442E38039560404A6249B9FBFE4540
73848	4	36	410	2480	44990	\N	44.080495999999997	Приморский край, Михайловский муниципальный район, Сунятсенское сельское поселение, с. Степное, Совхозная, 37		0101000020E6100000CADFBDA3467B6040BABA63B14D0A4640
73846	4	36	410	2390	44942	\N	43.905900998609198	Приморский край, Михайловский муниципальный район, Михайловское сельское поселение, с. Песчаное, Флотская, 38	Россия, Приморский край, Михайловский район, село Песчаное	0101000020E61000007FDFBF7971836040F4346090F4F34540
73849	4	36	410	2521	44489	\N	44.002153999999997	Приморский край, Михайловский муниципальный район, Сунятсенское сельское поселение, с. Первомайское, Школьная, 27		0101000020E6100000E4874A23667F60401DC70F9546004640
73864	4	36	410	3419	45029	\N	43.8115154278711	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, с. Отрадное, Садовая, 15	Россия, Приморский край, Михайловский район, село Отрадное	0101000020E6100000422619390B916040529B38B9DFE74540
73858	4	36	410	3076	44491	\N	43.960327999999997	Приморский край, Михайловский муниципальный район, Осиновское сельское поселение, с. Осиновка, Комсомольская, 4/а		0101000020E6100000FD67CD8FBF8760406FB72407ECFA4540
74544	4	36	410	2822	44559	\N	44.0209219060281	Приморский край, Михайловский муниципальный район, Новошахтинское городское поселение, пгт. Новошахтинский Ленинская 12	Россия, Приморский край, Михайловский район, поселок городского типа Новошахтинский	0101000020E6100000A8A78FC01F8560402AE27492AD024640
73855	4	36	410	55250	44340	\N	44.023366000000003	Приморский край, Михайловский муниципальный район, Новошахтинское городское поселение, пгт. Новошахтинский, Ленинская, 8/а		0101000020E6100000CD902A8A578560404FEB36A8FD024640
73854	4	36	410	55250	44340	\N	44.023366000000003	Приморский край, Михайловский муниципальный район, Новошахтинское городское поселение, пгт. Новошахтинский, Ленинская, 5		0101000020E6100000CD902A8A578560404FEB36A8FD024640
73853	4	36	410	2752	45027	\N	44.234898000000001	Приморский край, Михайловский муниципальный район, Григорьевское сельское поселение, с. Новожатково, Центральная, 2/а		0101000020E6100000C05C8B16A07D6040AAF23D23111E4640
73863	4	36	410	3319	45082	\N	43.888324650535402	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, с. Николаевка, Ленинская, 60	Россия, Приморский край, Михайловский район, село Николаевка	0101000020E61000003F73D6A71C8E60400F9C33A2B4F14540
73847	4	36	410	2435	44941	\N	43.980674	Приморский край, Михайловский муниципальный район, Михайловское сельское поселение, с. Некруглово, Школьная, 2		0101000020E6100000DEFFC70913826040CD04C3B986FD4540
73842	4	36	410	2182	44780	\N	43.932932999999998	с. Михайловка, Ленинская, 38	Россия, Приморский край, Михайловский район, село Михайловка	0101000020E61000005FD3838252806040F92D3A596AF74540
73843	4	36	410	2182	44398	\N	43.932932999999998	Приморский край, Михайловский муниципальный район, Михайловское сельское поселение, с. Михайловка, Красноармейская, 33		0101000020E61000005FD3838252806040F92D3A596AF74540
73844	4	36	410	2182	44556	\N	43.932932999999998	Приморский край, Михайловский муниципальный район, Михайловское сельское поселение, с. Михайловка, Колхозная, 83		0101000020E61000005FD3838252806040F92D3A596AF74540
73857	4	36	410	2965	44884	\N	44.073599341107297	Приморский край, Михайловский муниципальный район, Кремовское сельское поселение, с. Ляличи, Школьная, 28	Россия, Приморский край, Михайловский район, село Ляличи	0101000020E6100000C26856B68F8C6040580229B16B094640
73867	4	36	410	3547	45084	\N	43.960205000000002	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, с. Лубянка, Ленина, 27/а		0101000020E610000035F0A31AF6936040543A58FFE7FA4540
73856	4	36	410	2964	44490	\N	44.035732000000003	Приморский край, Михайловский муниципальный район, Кремовское сельское поселение, с. Кремово, Колхозная, 25/а		0101000020E6100000408A3A738F886040D9B5BDDD92044640
73862	4	36	410	3312	42706	\N	43.967154000000001	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, с. Ивановка, Краснознаменная, 24/б		0101000020E61000006D3A02B8598F60400919C8B3CBFB4540
73850	4	36	410	2610	45077	\N	44.059511000000001	Приморский край, Михайловский муниципальный район, Григорьевское сельское поселение, с. Дубки, 40 лет Победы, 1/а		0101000020E610000020628385937E60404A60730E9E074640
73859	4	36	410	3115	45115	\N	43.901738000000002	Приморский край, Михайловский муниципальный район, Осиновское сельское поселение, с. Даниловка, Ленинская, 44		0101000020E6100000BDE47FF2F7886040BDC799266CF34540
73852	4	36	410	2714	44794	\N	44.159219	Приморский край, Михайловский муниципальный район, Григорьевское сельское поселение, с. Григорьевка, Калинина, 12		0101000020E6100000FD153257068060406FF3C64961144640
73860	4	36	410	55314	45098	\N	43.987758372742697	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, п. Горный, Ленина, 5	Россия, Приморский край, Михайловский район, село Горное	0101000020E610000012C138B8F48A6040622EA9DA6EFE4540
73861	4	36	410	3216	45028	\N	43.951749	Приморский край, Михайловский муниципальный район, Ивановское сельское поселение, с. Горбатка, Ленинская, 25		0101000020E6100000C2A6CEA3628C6040178046E9D2F94540
73851	4	36	410	2628	44848	\N	44.090162999999997	Приморский край, Михайловский муниципальный район, Григорьевское сельское поселение, с. Абрамовка, Советская, 26		0101000020E61000000ABE69FAEC806040952710768A0B4640
73832	4	36	147	1557	44987	\N	45.557628000000001	Приморский край, Лесозаводский городской округ, с. Филаретовка, Почтовая, 10		0101000020E610000090BDDEFD71B06040BDAAB35A60C74640
73828	4	36	147	1322	44830	\N	45.501232000000002	Приморский край, Лесозаводский городской округ, с. Урожайное, Ленинская, 37		0101000020E6100000BA83D899C2AE6040B6DAC35E28C04640
73829	4	36	147	1378	45025	\N	45.464840000000002	Приморский край, Лесозаводский городской округ, с. Тургенево, Октябрьская, 27 б		0101000020E6100000C80C54C6BFB46040B3EF8AE07FBB4640
73837	4	36	147	1829	44846	\N	45.272499000000003	Приморский край, Лесозаводский городской округ, с. Тихменево, Советская, 36		0101000020E610000011548D5E0DAF6040AB984A3FE1A24640
73824	4	36	147	1102	44983	\N	45.575313999999999	Приморский край, Лесозаводский городской округ, с.Тамга, Центральная, 33		0101000020E61000007B1684F2BEB3604029779FE3A3C94640
73830	4	36	147	1450	44822	\N	45.518626324082199	Приморский край, Лесозаводский городской округ, с. Ружино, Советская, 44	Россия, Приморский край, Лесозаводский район, село Ружино	0101000020E61000003599F1B652B260407A6D365662C24640
73838	4	36	147	1912	44855	\N	45.431941000000002	Приморский край, Лесозаводский городской округ, с. Полевое, Дзержинского, 174		0101000020E6100000DC813AE551AC60409966BAD749B74640
73826	4	36	147	1224	44775	\N	45.638769000000003	Приморский край, Лесозаводский городской округ, с. Пантелеймоновка, Центральная, 39		0101000020E61000009AB51490F6B260406D59BE2EC3D14640
73827	4	36	147	1280	45022	\N	45.718111	Приморский край, Лесозаводский городской округ, с. Невское, Центральная, 16		0101000020E610000069E388B578B56040EDF2AD0FEBDB4640
73840	4	36	147	2040	44878	\N	45.548375999999998	Приморский край, Лесозаводский городской округ, с. Марково, Волкова, 10		0101000020E6100000E4839ECD2AAB6040A5F44C2F31C64640
73836	4	36	147	1779	45081	\N	45.468347999999999	Приморский край, Лесозаводский городской округ, с. Лесное, Школьная, 10 а		0101000020E6100000E60297C79AB16040D192C7D3F2BB4640
73833	4	36	147	1611	44777	\N	45.404580000000003	Приморский край, Лесозаводский городской округ, с. Курское, Советская, 1		0101000020E61000001CB62DCAECAF6040CF4E0647C9B34640
73835	4	36	147	1718	44988	\N	45.254950999999998	Приморский край, Лесозаводский городской округ, с. Иннокентьевка, Школьная, 1		0101000020E6100000C40AB77C24B360408F8AFF3BA2A04640
73825	4	36	147	1121	44940	\N	45.645460999999997	Приморский край, Лесозаводский городской округ, с. Ильмовка, Центральная, 39		0101000020E610000085CC9541B5B86040F6EB4E779ED24640
73831	4	36	147	1497	45006	\N	45.5556170810925	Приморский край, Лесозаводский городской округ, с. Елизаветовка, Центральная, 24	Россия, Приморский край, Лесозаводский район, село Елизаветовка	0101000020E61000006901DA56B3B66040020D36751EC74640
73839	4	36	147	1919	45083	\N	45.397098999999997	Приморский край, Лесозаводский городской округ, с. Донское, Молодежная, 2а		0101000020E6100000AD2F12DA72AB60401C23D923D4B24640
73834	4	36	147	1663	44943	\N	45.306815999999998	Приморский край, Лесозаводский городской округ, с. Глазовка, Центральная, 30		0101000020E6100000DC114E0B5EB06040DCF126BF45A74640
73789	4	36	651	31679	45076	\N	43.052245999999997	Приморский край, Лазовский муниципальный район, Беневское сельское поселение, с. Чистоводное, Центральная, 8		0101000020E610000009522976B4B1604064AC36FFAF864540
73798	4	36	651	32105	44985	\N	43.223520000000001	Приморский край, Лазовский муниципальный район, Чернорученское сельское поселение, с. Черноручье, Шевченко, 23 Б		0101000020E610000052280B5FDFC860403F00A94D9C9C4540
73796	4	36	651	31986	45032	\N	43.356973000000004	Приморский край, Лазовский муниципальный район, Лазовское сельское поселение, с. Старая Каменка, Центральная, 39		0101000020E610000082FFAD64C7C160400B47904AB1AD4540
73797	4	36	651	32061	45086	\N	43.294552000000003	Приморский край, Лазовский муниципальный район, Чернорученское сельское поселение, с. Сокольчи, Шоссейная, 56		0101000020E61000007AE063B062C76040577C43E1B3A54540
74552	4	36	651	55331	45163	\N	42.901800818058	692998 Приморский край, Лазовский муниципальный район, Преображенское городское поселение, пгт. Преображение 30 лет Победы 2А		0101000020E6100000323A2009FBBC6040034015376E734540
74550	4	36	651	4416	44483	\N	42.899753355064	692998 Приморский край, Лазовский муниципальный район, Преображенское городское поселение, пгт. Преображение Морская 6	Россия, Приморский край, Лазовский район, поселок городского типа Преображение	0101000020E61000000CCD751AE9BC60402BBD361B2B734540
73785	4	36	651	4416	44483	\N	42.900601999999999	Приморский край, Лазовский муниципальный район, Преображенское городское поселение, пгт. Преображение, Морская, 6		0101000020E610000064213A040EBD6040295B24ED46734540
73786	4	36	651	4416	44826	\N	42.900601999999999	Приморский край, Лазовский муниципальный район, Преображенское городское поселение, пгт. Преображение, Заречная, 34		0101000020E610000064213A040EBD6040295B24ED46734540
74542	4	36	651	4416	44552	\N	42.900601999999999	Приморский край, Лазовский муниципальный район, Преображенское городское поселение, пгт. Преображение ул. 30 лет Победы 2А		0101000020E610000064213A040EBD6040295B24ED46734540
73787	4	36	651	4416	44552	\N	42.900601999999999	Приморский край, Лазовский муниципальный район, Преображенское городское поселение, пгт. Преображение, 30 лет Победы, 2А		0101000020E610000064213A040EBD6040295B24ED46734540
73792	4	36	651	55298	44924	\N	43.384940624902498	Приморский край, Лазовский муниципальный район, Лазовское сельское поселение, с. Лазо, Центральная, 30	Россия, Приморский край, Лазовский район, село Лазо	0101000020E6100000C1FF56B2E3BC6040DCF126BF45B14540
73795	4	36	651	55298	44916	\N	43.206792	Приморский край, Лазовский муниципальный район, Лазовское сельское поселение, с. Лазо, Советская, 83	Россия, Приморский край, Лазовский район	0101000020E6100000C6FCDCD014BB604087890629789A4540
74543	4	36	651	55298	45158	\N	43.386232006650097	692980 Приморский край, Лазовский муниципальный район, Лазовское сельское поселение, с. Лазо31037 Некрасовская 26	Россия, Приморский край, Лазовский район, село Лазо	0101000020E61000000C01C0B1E7BC60409755D80C70B14540
74541	4	36	651	55298	45158	\N	43.385494729669396	692980 Приморский край, Лазовский муниципальный район, Лазовское сельское поселение, с. Лазо Некрасовская 9	Россия, Приморский край, Лазовский район, село Лазо	0101000020E610000080EF366F1CBD6040C1E270E657B14540
73791	4	36	651	31759	45079	\N	43.266527000000004	Приморский край, Лазовский муниципальный район, Лазовское сельское поселение, с. Кишиневка, Школьная, 3		0101000020E6100000D32EA6996EBB60402140868E1DA24540
73788	4	36	651	31659	45074	\N	42.907370999999998	Приморский край, Лазовский муниципальный район, Беневское сельское поселение, с. Киевка, 50 лет Октября, 37		0101000020E61000000FB56D1885B660405E2BA1BB24744540
73799	4	36	651	32137	9974	\N	43.224755000000002	Приморский край, Лазовский муниципальный район, Чернорученское сельское поселение, с. Данильченково, Партизанская, 6		0101000020E6100000F0FB372F4ECC6040664E97C5C49C4540
73801	4	36	651	32217	45075	\N	43.070892999999998	Приморский край, Лазовский муниципальный район, Валентиновское сельское поселение, с. Глазковка, Тигровая, 26		0101000020E6100000B03C484F91C56040F641960513894540
73800	4	36	651	32185	44801	\N	43.118167999999997	Приморский край, Лазовский муниципальный район, Валентиновское сельское поселение, с. Валентин, Первомайская, 17		0101000020E61000009432A9A18DC9604084B70721208F4540
73790	4	36	651	31744	44845	\N	43.167529999999999	Приморский край, Лазовский муниципальный район, Беневское сельское поселение, с. Беневское, Центральная, 50		0101000020E610000073D712F241B86040A88C7F9F71954540
74540	4	36	646	31351	45157	\N	46.442372445719997	Приморский край, Красноармейский муниципальный район, Востокское городское поселение, пгт. Восток Молодежная 3а	Россия, Приморский край, Красноармейский район, поселок городского типа Восток	0101000020E61000005F27F56569FA604043554CA59F384740
73748	4	36	517	29679	45071	\N	45.117857000000001	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Шмаковка, пер. Школьный, 1		0101000020E610000028D4D347E0AB6040664D2CF0158F4640
73758	4	36	517	30170	44939	\N	45.042203000000001	Приморский край, Кировский муниципальный район, Хвищанское сельское поселение, с. Хвищанка, Петровская, 22		0101000020E6100000020EA14ACDBE604084656CE866854640
73762	4	36	517	30345	44875	\N	45.196060000000003	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, с. Уссурка, Школьная, 4-а	Россия, Приморский край, Кировский район, село Уссурка	0101000020E6100000F92D3A596AB06040E2067C7E18994640
73739	4	36	517	29270	44843	\N	45.046024000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Увальное, Первомайская, 2- А		0101000020E61000009AB4A9BA47AF6040626A4B1DE4854640
53940	4	39	\N	231	45994	\N	59.556319999999999	Магаданская область, город Магадан, Пушкина, 8		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
73737	4	36	517	29177	45061	\N	44.953634863263403	Приморский край, Кировский муниципальный район, Руновское сельское поселение, с. Степановка, Центральная, 24	Россия, Приморский край, Кировский район, село Степановка	0101000020E61000005B608F8994AF604015A930B6107A4640
73735	4	36	517	29078	44977	\N	44.964872	Приморский край, Кировский муниципальный район, Руновское сельское поселение, с. Руновка, Кооперативная, 6		0101000020E61000007F33315D08AB6040BE69FAEC807B4640
73749	4	36	517	55308	45042	\N	45.165734940595101	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Родниковое, Центральная, 2	Россия, Приморский край, Кировский район, село Родниковый	0101000020E6100000643BDF4F8DAC6040BA66F2CD36954640
73752	4	36	517	29860	45035	\N	45.075622000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Преображенка, Советская, 12-а		0101000020E610000085D1AC6C1FB46040D76D50FBAD894640
73751	4	36	517	29831	44770	\N	45.129939999999998	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Павло-Федоровка, Почтовая, 32		0101000020E6100000C5CA68E473A860409B38B9DFA1904640
73755	4	36	517	29996	44984	\N	44.932842000000001	Приморский край, Кировский муниципальный район, Крыловское сельское поселение, с. Межгорье, Шоссейная, 7		0101000020E610000030D5CC5A8AB46040E92ADD5D67774640
73760	4	36	517	30253	45007	\N	44.793183999999997	Приморский край, Кировский муниципальный район, Крыловское сельское поселение, с. Марьяновка, Почтовая, 12		0101000020E61000004B3ACAC16CB76040F0DAA50D87654640
73740	4	36	517	29331	45017	\N	45.110396000000001	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Луговое, Центральная, 1		0101000020E61000006FBA6587F8AD6040FBCDC474218E4640
73733	4	36	517	29005	44934	\N	45.002034000000002	Приморский край, Кировский муниципальный район, Руновское сельское поселение, с. Комаровка, Советская, 28		0101000020E61000008448861C5BA9604073BD6DA642804640
74524	4	36	517	3421	44911	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Уткинская, 53		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
74525	4	36	517	3421	44802	\N	45.085894725701401	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Советская, 91	Россия, Приморский край, Кировский район, поселок городского типа Кировский	0101000020E6100000FFB27BF230B06040E9F17B9BFE8A4640
73746	4	36	517	3421	44802	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Советская, 55-а		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
73747	4	36	517	3421	44825	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Набережная, 61		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
74523	4	36	517	3421	44482	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Ленинская, 130		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
73744	4	36	517	3421	44482	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Ленинская, 39		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
73742	4	36	517	3421	44482	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Ленинская, 92		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
73743	4	36	517	55293	44879	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Пролетарская, 2		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
73745	4	36	517	55293	45078	\N	45.091914002828702	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Площадь Свободы, 46		0101000020E6100000D784B4C620B06040B40584D6C38B4640
73768	4	36	517	55293	44955	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Колхозная, 29		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
73741	4	36	517	55293	44809	\N	45.090273000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, пгт. Кировский, Гагарина, 87		0101000020E61000007FBDC282FBAF60401D5BCF108E8B4640
73761	4	36	517	55312	45072	\N	44.843060177931299	Приморский край, Кировский муниципальный район, Горненское городское поселение, пгт. Горный, Приисковая, 20-а		0101000020E61000001EFD2FD7A2BE60406B48DC63E96B4640
74528	4	36	517	3635	44982	\N	45.232999999999997	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, п. Горные Ключи, Пр. Лазурный, 1		0101000020E610000081423D7D04B06040E7FBA9F1D29D4640
73767	4	36	517	3635	44774	\N	45.232999999999997	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, п. Горные Ключи, Юбилейная, 43		0101000020E610000081423D7D04B06040E7FBA9F1D29D4640
73764	4	36	517	3635	44844	\N	45.232999999999997	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, п. Горные Ключи, Санаторная, 5		0101000020E610000081423D7D04B06040E7FBA9F1D29D4640
73763	4	36	517	3635	44471	\N	45.232999999999997	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, п. Горные Ключи, 60 лет СССР, 10		0101000020E610000081423D7D04B06040E7FBA9F1D29D4640
73766	4	36	517	55302	44944	\N	45.229664311456801	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, п. Горные Ключи, ул. Юбилейная, 17		0101000020E61000008AC745B508B06040C68844A1659D4640
73769	4	36	517	55302	45023	\N	45.232999999999997	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, п. Горные Ключи, Профсоюзная, 1		0101000020E610000081423D7D04B06040E7FBA9F1D29D4640
74527	4	36	517	55302	44980	\N	45.232999999999997	Приморский край, Кировский муниципальный район, Горноключевское городское поселение, п. Горные Ключи, Октябрьская, 21		0101000020E610000081423D7D04B06040E7FBA9F1D29D4640
73759	4	36	517	30182	45005	\N	44.857714000000001	Приморский край, Кировский муниципальный район, Крыловское сельское поселение, с. Владимировка, Центральная, 1		0101000020E610000076A911FA99B5604022A98592C96D4640
73757	4	36	517	30102	45073	\N	44.922542	Приморский край, Кировский муниципальный район, Крыловское сельское поселение, с. Большие Ключи, Верхняя, 22, кв. 2		0101000020E6100000A0C552245FBB6040DD9733DB15764640
73736	4	36	517	29144	45066	\N	44.926217999999999	Приморский край, Кировский муниципальный район, Руновское сельское поселение, с. Афанасьевка, Первомайская, 17		0101000020E6100000E99AC937DBAC6040B77BB94F8E764640
73754	4	36	517	29952	44937	\N	45.059828287700803	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Архангеловка, Центральная, 9	Россия, Приморский край, Кировский район, село Архангеловка	0101000020E61000001B47ACC5A7B160404BB1A371A8874640
73734	4	36	517	29071	44935	\N	44.909745000000001	Приморский край, Кировский муниципальный район, Руновское сельское поселение, с. Антоновка, Центральная, 34		0101000020E610000062D68BA19CAA60408A592F8672744640
73750	4	36	517	29781	45021	\N	45.130163000000003	Приморский край, Кировский муниципальный район, Кировское городское поселение, с. Авдеевка, Центральная, 18		0101000020E610000080D767CEFAA960401B13622EA9904640
73727	4	36	1829	28681	44771	\N	44.351204000000003	Приморский край, Кавалеровский муниципальный район, Хрустальненское городское поселение, пгт. Хрустальный, ул. Фрунзе, 1		0101000020E61000000B9755D80CE36040B91CAF40F42C4640
73726	4	36	1829	28681	44436	\N	44.351204000000003	Приморский край, Кавалеровский муниципальный район, Хрустальненское городское поселение, пгт. Хрустальный, ул.Комсомольская, 98		0101000020E61000000B9755D80CE36040B91CAF40F42C4640
73711	4	36	1829	28015	45067	\N	44.252152000000002	Приморский край, Кавалеровский муниципальный район, Устиновское сельское поселение, с. Устиновка, Центральная, 10 в		0101000020E6100000E59B6D6E4CE760407DCF488446204640
73710	4	36	1829	27970	44933	\N	44.249175999999999	Приморский край, Кавалеровский муниципальный район, Устиновское сельское поселение, с. Суворово, Вобликова, 27		0101000020E610000051DEC7D11CEB60405B79C9FFE41F4640
73712	4	36	1829	28062	44938	\N	44.235697999999999	Приморский край, Кавалеровский муниципальный район, Устиновское сельское поселение, с. Синегорье, Речная, 19 а		0101000020E610000046973787EBE36040C6DD205A2B1E4640
73729	4	36	1829	28837	44773	\N	44.3073541051169	Приморский край, Кавалеровский муниципальный район, Рудненское городское поселение, пгт. Рудный, ул. Поворотная, 46	Россия, Приморский край, Кавалеровский район, село Рудный	0101000020E61000004D4A41B717DE6040BB25396057274640
73725	4	36	1829	55249	44339	\N	44.266700168368203	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Арсеньева, 166 а	Россия, Приморский край, Кавалеровский район, поселок городского типа Кавалерово	0101000020E61000004696CCB1BCE16040EEEBC03923224640
73721	4	36	1829	55249	44339	\N	44.289700651652097	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Арсеньева, 97	Россия, Приморский край, Кавалеровский район, поселок городского типа Кавалерово	0101000020E610000081E84999D4E160402B4F20EC14254640
73720	4	36	1829	55277	44546	\N	44.296112000000001	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Арсеньева, 83		0101000020E610000081E84999D4E1604001FA7DFFE6254640
73724	4	36	1829	28261	43213	\N	44.296112000000001	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Рабочая, 47		0101000020E610000081E84999D4E1604001FA7DFFE6254640
73722	4	36	1829	28261	44468	\N	44.296112000000001	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Первомайская, 36		0101000020E610000081E84999D4E1604001FA7DFFE6254640
73718	4	36	1829	28261	44468	\N	44.296112000000001	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Первомайская, 55		0101000020E610000081E84999D4E1604001FA7DFFE6254640
73717	4	36	1829	28261	44468	\N	44.272809110556501	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Первомайская, 154	Россия, Приморский край, Кавалеровский район, поселок городского типа Кавалерово	0101000020E6100000C442AD69DEE16040F986C267EB224640
73723	4	36	1829	28261	43199	\N	44.296112000000001	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Гагарина, 16		0101000020E610000081E84999D4E1604001FA7DFFE6254640
73719	4	36	1829	28261	42651	\N	44.296112000000001	Приморский край, Кавалеровский муниципальный район, Кавалеровское городское поселение, пгт. Кавалерово, Арсеньева, 57		0101000020E610000081E84999D4E1604001FA7DFFE6254640
73448	4	36	125	15214	44632	\N	43.420533080156098	Приморский край, Артемовский городской округ, с. Суражевка, Ярославская, 52	Россия, Приморский край, Артем городской округ, село Суражевка, Ярославская улица	0101000020E6100000E3E313B2738A6040C3F17C06D4B54540
73708	4	36	1829	27885	45016	\N	44.217166035398101	Приморский край, Кавалеровский муниципальный район, Зеркальненское сельское поселение, с. Зеркальное, Школьная, 1	Россия, Приморский край, Кавалеровский район, село Зеркальное	0101000020E6100000E76D6C76A4F16040CDE67118CC1B4640
73714	4	36	1829	55257	44393	\N	44.269970000000001	Приморский край, Кавалеровский муниципальный район, Горнореченское городское поселение, пгт. Горнореченский, Строительная, 24		0101000020E61000009563B2B87FE36040587380608E224640
73715	4	36	1829	55257	44820	\N	44.269970000000001	Приморский край, Кавалеровский муниципальный район, Горнореченское городское поселение, пгт. Горнореченский, Советская, 12		0101000020E61000009563B2B87FE36040587380608E224640
73713	4	36	1829	28066	45003	\N	44.406894000000001	Приморский край, Кавалеровский муниципальный район, Высокогорское городское поселение, пгт. Высокогорск, Арсеньева, 38		0101000020E6100000F564FED1B7EC60402578431A15344640
73709	4	36	1829	27919	44929	\N	44.249071999999998	Приморский край, Кавалеровский муниципальный район, Зеркальненское сельское поселение, с. Богополь, Рабочая, 2 а		0101000020E610000085CE6BEC92EE6040B62C5F97E11F4640
74460	4	36	71	32238	44964	\N	45.577244	Приморский край, Дальнереченский муниципальный район, Ракитненское сельское поселение, с. Ясная Поляна, Центральная, 29		0101000020E6100000E833A0DE0CCA6040F7E7A221E3C94640
74453	4	36	71	31896	44967	\N	45.831204999999997	Приморский край, Дальнереченский муниципальный район, Веденкинское сельское поселение, с. Стретенка, Лободы, 36		0101000020E61000001EA4A7C8A1C16040C6A2E9EC64EA4640
74452	4	36	71	31878	44968	\N	45.883716	Приморский край, Дальнереченский муниципальный район, Веденкинское сельское поселение, с. Соловьевка, Центральная, 10Б		0101000020E6100000B1A54753BDBE6040D9791B9B1DF14640
74456	4	36	71	32045	44542	\N	45.972248999999998	Приморский край, Дальнереченский муниципальный район, Сальское сельское поселение, с. Сальское, Советская, 15		0101000020E610000011A9691753B86040CB48BDA772FC4640
74465	4	36	71	32421	44970	\N	45.11656	Приморский край, Дальнереченский муниципальный район, Малиновское сельское поселение, с. Пожига, Школьная, 24		0101000020E6100000DD989EB044CC6040C9022670EB8E4640
74454	4	36	71	31973	45059	\N	45.789662	Приморский край, Дальнереченский муниципальный район, Веденкинское сельское поселение, с. Новотроицкое, Пионерская, 5		0101000020E6100000AC1BEF8E8CC360406D72F8A413E54640
74455	4	36	71	32020	44976	\N	45.701314000000004	Приморский край, Дальнереченский муниципальный район, Веденкинское сельское поселение, с. Междуречье, П.Марценюка, 24А		0101000020E6100000C170AE6186C360400D1D3BA8C4D94640
74461	4	36	71	32245	44799	\N	45.405687	Приморский край, Дальнереченский муниципальный район, Малиновское сельское поселение, с. Малиново, Школьная, 29		0101000020E610000037C478CDABC96040C8B4368DEDB34640
74438	4	36	71	31176	45110	\N	45.675539000000001	Приморский край, Дальнереченский муниципальный район, Ракитненское сельское поселение, с. Лобановка, Центральная, 31		0101000020E61000007429AE2AFBC760401616DC0F78D64640
73793	4	36	71	27782	44633	\N	45.870590411944498	Приморский край, Лазовский муниципальный район, Лазовское сельское поселение, с. Лазо, Некрасовская, 26	Россия, Приморский край, Дальнереченский район, село Лазо	0101000020E610000075C93846B2B46040C11C3D7E6FEF4640
73706	4	36	71	27782	44807	\N	45.870533999999999	Приморский край, Дальнереченский городской округ, с. Лазо, Лазо, 37		0101000020E61000006A15FDA119B560402D077AA86DEF4640
73707	4	36	71	27782	44622	\N	45.875686570183397	Приморский край, Дальнереченский городской округ, с. Лазо, Калинина, 40	Россия, Приморский край, Дальнереченский район, село Лазо	0101000020E6100000D6C743DFDDB460402444F98216F04640
74463	4	36	71	32324	45112	\N	45.473658	Приморский край, Дальнереченский муниципальный район, Малиновское сельское поселение, с. Зимники, Майская, 15		0101000020E6100000892991442FC8604090BE49D3A0BC4640
74486	4	36	71	1239	44819	\N	45.820923999999998	Приморский край, Дальнереченский городской округ, с. Грушевое, Лазо, 36		0101000020E6100000BDFF8F13A6B360403140A20914E94640
74451	4	36	71	31824	44389	\N	45.876230999999997	Приморский край, Дальнереченский муниципальный район, Веденкинское сельское поселение, с. Веденка, Мелехина, 40		0101000020E61000003483F8C00EBD6040E55E605628F04640
73682	4	36	701	26692	44617	\N	44.444533999999997	Приморский край, Дальнегорский городской округ, с. Сержантово, ул. Линейная, 9		0101000020E61000002AAA7EA5F3F76040E3FA777DE6384640
73684	4	36	701	55283	44620	\N	44.365717132012897	Приморский край, Дальнегорский городской округ, с. Рудная пристань, Арсеньева	Россия, Приморский край, Дальнегорский район, поселок городского типа Рудная Пристань	0101000020E61000005EBC1FB75FFA6040AD4B8DD0CF2E4640
74485	4	36	701	55262	44467	\N	44.581580119068001	Приморский край, Шкотовский район, п. Подъяпольский, Центральная, 2Б	Россия, Приморский край, Дальнегорский район, село Подъяпольское	0101000020E6100000253FE257ACEE6040FC00A436714A4640
73683	4	36	701	26738	44936	\N	44.386535000000002	Приморский край, Дальнегорский городской округ, д. Мономахово, ул. Школьная, 17		0101000020E6100000EA944737C2F8604033E197FA79314640
73665	4	36	701	25907	44459	\N	44.628484999999998	Приморский край, Дальнегорский городской округ, пгт. Краснореченский, Октябрьская 17		0101000020E61000005890662C1AEB604066834C3272504640
73458	4	36	125	15709	45020	\N	43.453513999999998	Приморский край, Артемовский городской округ, с. Ясное, Чернышева, 2		0101000020E6100000D12346CF2D8560409A232BBF0CBA4540
74470	4	36	125	259	44432	\N	43.389293000000002	Приморский край, Шкотовский район, п. Штыково, Гидроузла, 6		0101000020E6100000A5DDE863BE8B6040E7C75F5AD4B14540
73384	4	36	1169	12199	\N	\N	44.195849000000003	Приморский край, Анучинский муниципальный район, Чернышевское сельское поселение, с. Чернышевка, в\\ч 12758, клуб		0101000020E610000068CD8FBF34A4604027FA7C9411194640
73383	4	36	1169	12199	44449	\N	44.195849000000003	Приморский край, Анучинский муниципальный район, Чернышевское сельское поселение, с. Чернышевка, Советская, 21		0101000020E610000068CD8FBF34A4604027FA7C9411194640
73380	4	36	1169	12007	44981	\N	44.180503999999999	Приморский край, Анучинский муниципальный район, Чернышевское сельское поселение, с. Тихоречное, Молодежная, 20		0101000020E61000002C0FD253E4A060400A664CC11A174640
73369	4	36	1169	11504	44989	\N	44.100903000000002	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Таежка, Советская, 33а		0101000020E61000003F541A3133A76040BE88B663EA0C4640
73366	4	36	1169	11351	44997	\N	44.004221472477198	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Старогордеевка, Комарова, 16	Россия, Приморский край, Анучинский район, село Старогордеевка	0101000020E61000000EF3E505D8A360406C7A50508A004640
73376	4	36	1169	11840	45019	\N	43.886608000000003	Приморский край, Анучинский муниципальный район, Виноградовское  сельское поселение, с. Староварваровка, Мира, 25		0101000020E61000008F37F92DBA9D60409D2FF65E7CF14540
73373	4	36	1169	11695	45070	\N	43.850870999999998	Приморский край, Анучинский муниципальный район, Виноградовское  сельское поселение, с. Смольное, Центральная, 3		0101000020E61000004E9D47C5FF9C6040B20E4757E9EC4540
73377	4	36	1169	11898	44926	\N	44.221727000000001	Приморский край, Анучинский муниципальный район, Гражданское сельское поселение, с. Рисовое, Увальная, 10		0101000020E6100000184339D1AEA36040F2D1E28C611C4640
73378	4	36	1169	11913	44805	\N	44.198092000000003	Приморский край, Анучинский муниципальный район, Гражданское сельское поселение, с. Пухово, Школьная, 5		0101000020E6100000B07268916DA86040B4CC22145B194640
73381	4	36	1169	12091	45124	\N	44.153883	Приморский край, Анучинский муниципальный район, Чернышевское сельское поселение, с. Новотроицкое, Молодежная, 9		0101000020E6100000691A14CD83A1604087342A70B2134640
73368	4	36	1169	11433	44804	\N	44.032550000000001	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Новогордеевка, Комсомольская, 1А		0101000020E6100000DC2C5E2C8CA460400EBE30992A044640
73364	4	36	1169	11250	9961	\N	43.972020000000001	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Нововарваровка, Ленинская, 3		0101000020E6100000925CFE437A9F60406A87BF266BFC4540
73372	4	36	1169	11615	45014	\N	43.884399000000002	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Муравейка, Партизанская, 20		0101000020E61000001B834E089DA86040BCCE86FC33F14540
73382	4	36	1169	12112	44928	\N	44.140565000000002	Приморский край, Анучинский муниципальный район, Чернышевское сельское поселение, с. Корниловка, Первомайская, 29		0101000020E61000003E247CEF6FA560402BFBAE08FE114640
73375	4	36	1169	11791	45068	\N	43.741059999999997	Приморский край, Анучинский муниципальный район, Виноградовское  сельское поселение, с. Ильмаковка, Центральная, 14		0101000020E61000001EC2F869DC9E6040D72FD80DDBDE4540
73371	4	36	1169	11600	45065	\N	43.835695999999999	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Еловка, Школьный, 1А		0101000020E61000002A53CC4150A76040F2B22616F8EA4540
73365	4	36	1169	11310	44925	\N	43.859679	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Гродеково, Центральная, 37б		0101000020E610000076172829B0A460406C0723F609EE4540
73379	4	36	1169	11972	44842	\N	44.218581	Приморский край, Анучинский муниципальный район, Гражданское сельское поселение, с. Гражданка, Юбилейная, 13А		0101000020E6100000161406659AA5604074435376FA1B4640
73374	4	36	1169	11737	45064	\N	43.761474999999997	Приморский край, Анучинский муниципальный район, Виноградовское  сельское поселение, с. Виноградовка, Советская, 36		0101000020E6100000F4C13236749E60405DDC460378E14540
73363	4	36	1169	11101	44923	\N	43.963177000000002	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Анучино, Центральная, 1		0101000020E6100000359886E1A3A1604034A1496249FB4540
73361	4	36	1169	11101	44558	\N	43.964971664277201	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Анучино, Лазо, 4	Россия, Приморский край, Анучинский район, село Анучино	0101000020E6100000344A97FEA5A1604022C7D63384FB4540
73362	4	36	1169	11101	9957	\N	43.963177000000002	Приморский край, Анучинский муниципальный район, Анучинское сельское поселение, с. Анучино, Горького, 37		0101000020E6100000359886E1A3A1604034A1496249FB4540
53976	4	39	\N	55653	46013	\N	59.898894739382001	Магаданская область, город Магадан, п.Сокол, Гагарина, 13-а	Россия, Магаданская область	0101000020E61000002CD8463C59D86240DBC4C9FD0EF34D40
54003	4	39	\N	55652	46008	\N	62.777307999999998	Магаданская область, Сусуманский район, город Сусуман, Ленина, 30		0101000020E6100000223317B8BC846240A7751BD47E634F40
53975	4	39	\N	55654	46028	\N	59.909931469508699	Магаданская область, г. Магадан, пос. Сокол, Гагарина, 20-а	Россия, Магаданская область, поселок Сокол	0101000020E610000098C3EE3B86D86240EC4E779E78F44D40
53971	4	39	\N	231	\N	\N	59.556319999999999	Магаданская область, город Магадан, 13 км основной трассы		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53954	4	39	\N	231	46005	\N	59.556319999999999	Магаданская область, город Магадан, Шандора Шимича, 6		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53967	4	39	\N	231	45983	\N	59.556319999999999	Магаданская область, город Магадан, Ш.Шимича, 18		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53963	4	39	\N	231	45999	\N	59.556319999999999	Магаданская область, город Магадан, Пролетарская, 75/2		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53953	4	39	\N	231	45999	\N	59.556319999999999	Магаданская область, город Магадан, Пролетарская, 33, корп.2		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53960	4	39	\N	231	45996	\N	59.565048527832502	Магаданская область, город Магадан, Портовая, 36/10	Россия, Магаданская область	0101000020E610000068942EFD4BD962409AD18F8653C84D40
53941	4	39	\N	231	45996	\N	59.556319999999999	Магаданская область, город Магадан, Портовая, 13		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53973	4	39	\N	231	46032	\N	59.556319999999999	Магаданская область, город Магадан, Пионерская, 1		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53965	4	39	\N	231	46026	\N	59.556319999999999	город Магадан, Первомайская, 46		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53944	4	39	\N	231	46016	\N	59.556319999999999	Магаданская область, город Магадан, Парковая, 22		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53959	4	39	\N	231	46001	\N	59.556319999999999	Магаданская область, город Магадан, Октябрьская, 15		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53943	4	39	\N	231	45997	\N	59.556319999999999	Магаданская область, город Магадан, Новая, 29-в		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53950	4	39	\N	231	46017	\N	59.556319999999999	Магаданская область, город Магадан, Наровчатова, 23		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53958	4	39	\N	231	45988	\N	59.556319999999999	Магаданская область, город Магадан, Набережная р. Магаданки, 59 коп.4		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53957	4	39	\N	231	45988	\N	59.556319999999999	Магаданская область, город Магадан, Набережная р. Магаданки, 59 корп.4		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53946	4	39	\N	231	46025	\N	59.556319999999999	Магаданская область, город Магадан, Марчеканская, 2/1		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53972	4	39	\N	231	46019	\N	59.556319999999999	Магаданская область, город Магадан, Майская, 14		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53949	4	39	\N	231	45985	\N	59.556319999999999	Магаданская область, город Магадан, Лукса, 7		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53939	4	39	\N	231	45985	\N	59.556319999999999	Магаданская область, город Магадан, Лукса, 8-а		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53974	4	39	\N	231	46014	\N	59.556319999999999	Магаданская область, г. Магадан, пос. Уптар, Красноярская, 10		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53942	4	39	\N	231	45995	\N	59.556319999999999	Магаданская область, город Магадан, Комсомольская площадь, 1		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53956	4	39	\N	231	46010	\N	59.556319999999999	Магаданская область, город Магадан, Комсомольская, 47-а		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53969	4	39	\N	231	45998	\N	59.556319999999999	Магаданская область, город Магадан, Колымская, 8		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53952	4	39	\N	231	45979	\N	59.556319999999999	Магаданская область, город Магадан, Карла Маркса, 53		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53951	4	39	\N	231	45979	\N	59.556319999999999	Магаданская область, город Магадан, Карла Маркса, 62-в		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53966	4	39	\N	231	45982	\N	59.556319999999999	Магаданская область, город Магадан, Зайцева, 27		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53968	4	39	\N	231	45984	\N	59.556319999999999	Магаданская область, город Магадан, Берзина, 1		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53977	4	39	\N	231	46035	\N	59.556319999999999	Магаданская область, город Магадан, Арманская, 26		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53945	4	39	\N	231	46022	\N	59.556319999999999	Магаданская область, город Магадан, Марчеканское шоссе, 16-а		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53970	4	39	\N	231	46027	\N	59.556319999999999	Магаданская область, город Магадан, Колымская, 9		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53961	4	39	\N	231	46004	\N	59.556319999999999	Магаданская область, город Магадан, Карла Маркса, 1		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
53955	4	39	\N	231	46004	\N	59.554795540201503	Магаданская область, город Магадан, Карла Маркса, 67-в	Россия, Магаданская область	0101000020E6100000DF6E490E58DA6240CFF9298E03C74D40
53947	4	39	\N	231	46004	\N	59.556319999999999	Магаданская область, город Магадан, Карла Маркса, 35		0101000020E61000001B6327BC04DA62402C0E677E35C74D40
54026	4	39	1922	31995	46054	\N	62.526874999999997	Магаданская область, Ягоднинский р-он, п. Ягодное, ул. Школьная 9.		0101000020E610000035EB8CEF0BB462403D0AD7A370434F40
54027	4	39	1922	31995	46055	\N	62.526874999999997	Магаданская область, Ягоднинский р-он, пос. Ягодное, ул. Ленина 42		0101000020E610000035EB8CEF0BB462403D0AD7A370434F40
54030	4	39	1922	32187	46051	\N	62.082787000000003	686230, Магаданская область, Ягоднинский район, поселок Синегорье, Когодовского, 15		0101000020E610000083E0F1ED5DCF624059C4B0C3980A4F40
54028	4	39	1922	32081	46056	\N	62.546557	686230, Магаданская область, Ягоднинский район, поселок Сенокосный, Подгорная, 20		0101000020E6100000335019FFBEB562402F336C94F5454F40
54031	4	39	1922	32214	46052	\N	62.253227000000003	686230, Магаданская область, Ягоднинский район, поселок Оротукан, Спортивная, 8		0101000020E61000001424B6BB87F562406BBB09BE69204F40
54029	4	39	1922	32142	46058	\N	62.34328	686230, Магаданская область, Ягоднинский район, поселок Дебин, Мацкевича, 15		0101000020E610000098309A95EDD7624079AF5A99F02B4F40
54025	4	39	1922	31953	46053	\N	62.651246999999998	Магаданская область, Ягоднинский р-он, пос. Бурхала, ул. Нагорная, д. 20.		0101000020E61000007C6473D53CA362401E4FCB0F5C534F40
54024	4	39	101	31926	46043	\N	61.142308	Магаданская область, Хасынский район, поселок Талая, Зеленая, 4		0101000020E6100000C79E3D97A90C6340C6FA062637924E40
54018	4	39	101	31617	46012	\N	60.055110999999997	Магаданская область, Хасынский район, поселок Стекольный, Советская, 7		0101000020E610000037C7B94DB8D762402E5393E00D074E40
54022	4	39	101	140	\N	\N	60.103616000000002	Магаданская область, Хасынский район, поселок Палатка, Ленина, 80	Россия, Магаданская область, Хасынский район, поселок Палатка	0101000020E610000046D1031F03DE6240D2AB014A430D4E40
54021	4	39	101	140	45993	\N	60.103616000000002	Магаданская область, Хасынский район, поселок Палатка, Юбилейная, 10		0101000020E610000046D1031F03DE6240D2AB014A430D4E40
54019	4	39	101	140	46046	\N	60.103616000000002	Магаданская область, Хасынский район, поселок Палатка, снп. Хасын, Цареградского, 16		0101000020E610000046D1031F03DE6240D2AB014A430D4E40
54020	4	39	101	140	46020	\N	60.103616000000002	Магаданская область, Хасынский район, поселок Палатка, Ленина, 44		0101000020E610000046D1031F03DE6240D2AB014A430D4E40
54023	4	39	101	31861	46048	\N	60.841354000000003	Магаданская область, Хасынский район, поселок Атка, Санаторная, 1		0101000020E61000003DBA111615F96240ED2DE57CB16B4E40
54015	4	39	1914	55655	46044	\N	61.554368738811597	Магаданская область, Тенькинский район, поселок им.Гастелло, Гагарина, 27		0101000020E6100000C1AA7AF91D80624047753A90F5C64E40
54013	4	39	1914	31358	45992	\N	61.119880000000002	Магаданская область, Тенькинский район, поселок Усть-Омчуг, Победы, 21		0101000020E6100000F33D23111AB46240E5B8533A588F4E40
54012	4	39	1914	31358	46002	\N	61.119880000000002	Магаданская область, Тенькинский район, поселок Усть-Омчуг, Горняцкая, 41		0101000020E6100000F33D23111AB46240E5B8533A588F4E40
54014	4	39	1914	31467	46042	\N	61.498376999999998	Магаданская область, Тенькинский район, поселок Транспортный, Шоссейная, 21		0101000020E610000015191D90048662400F0A4AD1CABF4E40
54017	4	39	1914	31563	46036	\N	61.642519	Магаданская область, Тенькинский район, поселок Омчак, Новая, 13		0101000020E61000000E85CFD6C17B6240810706103ED24E40
54016	4	39	1914	31563	46038	\N	61.642519	Магаданская область, Тенькинский район, поселок Омчак, Клубная, 26		0101000020E61000000E85CFD6C17B6240810706103ED24E40
54011	4	39	1914	31268	\N	\N	60.612608000000002	Магаданская область, Тенькинский район, поселок Мадаун, д.18		0101000020E61000009A99999999D662404DA25EF0694E4E40
54006	4	39	1905	31071	46034	\N	63.075114999999997	Магаданская область, Сусуманский район, поселок Широкий, Октябрьская, 7а		0101000020E61000007DE9EDCF4581624032384A5E9D894F40
54007	4	39	1905	31085	46030	\N	62.716208999999999	Магаданская область, Сусуманский район, поселок Холодный, Халезина, 1		0101000020E610000079CA6ABA1E7D6240E90C8CBCAC5B4F40
54002	4	39	1905	30873	45989	\N	62.777307999999998	Магаданская область, Сусуманский район, город Сусуман, Советская, 7		0101000020E6100000223317B8BC846240A7751BD47E634F40
54004	4	39	1905	30873	46037	\N	62.777307999999998	Магаданская область, Сусуманский район, город Сусуман, Светлая, 6		0101000020E6100000223317B8BC846240A7751BD47E634F40
54005	4	39	1905	30873	46021	\N	62.777307999999998	Магаданская область, Сусуманский район, город Сусуман, Пионерская, 31		0101000020E6100000223317B8BC846240A7751BD47E634F40
54010	4	39	1905	31253	45991	\N	63.044817999999999	Магаданская область, Сусуманский район, поселок Мяунджа, Октябрьская, 18		0101000020E6100000B58993FB1D666240D522A298BC854F40
54009	4	39	1905	31166	46040	\N	63.013840000000002	Магаданская область, Сусуманский район, пос. Кедровый, Клубная, 1		0101000020E6100000EB707495EE61624036B05582C5814F40
54008	4	39	1905	31156	46047	\N	62.691729000000002	Магаданская область, Сусуманский район, пос. Большевик, Трассовская, 1		0101000020E6100000FE43FAED6B726240EF586C938A584F40
54000	4	39	1900	30704	46015	\N	62.930807999999999	Магаданская область, Среднеканский район, поселок Сеймчан, Промышленная, 12		0101000020E6100000D107CBD8500C6340766D6FB724774F40
53999	4	39	1900	30704	45990	\N	62.930807999999999	Магаданская область, Среднеканский район, поселок Сеймчан, Дзержинского, 25		0101000020E6100000D107CBD8500C6340766D6FB724774F40
54001	4	39	1900	30776	46057	\N	62.721116000000002	Магаданская область, Среднеканский район, село Верхний Сеймчан, Холодченко, 16-а		0101000020E6100000512E8D5FF80E6340A94F72874D5C4F40
53995	4	39	1893	30480	46009	\N	61.921868000000003	Магаданская область, Северо-Эвенский  район, поселок Эвенск, Победы, 35		0101000020E6100000EB19C2314BE763404E9D47C5FFF54E40
53998	4	39	1893	30626	\N	\N	61.809711	Магаданская область, Северо-Эвенский  район, село Чайбуха	Россия, Магаданская область, Северо-Эвенский район, село Чайбуха	0101000020E6100000E4F8A1D2080D6440111B2C9CA4E74E40
53997	4	39	1893	30596	\N	\N	61.953360000000004	Магаданская область, Северо-Эвенский  район, село Гижига	Россия, Магаданская область, Северо-Эвенский район, село Гижига	0101000020E6100000789ACC78DB0B644044A852B307FA4E40
53996	4	39	1893	30555	\N	\N	62.176679999999998	Магаданская область, Северо-Эвенский  район, село Гарманда	Россия, Магаданская область, Северо-Эвенский район, село Гарманда	0101000020E6100000AB2688BA0FE36340BBED42739D164F40
53993	4	39	1891	30327	46024	\N	62.516601000000001	Магаданская область, Омсукчанский район, поселок Омсукчан, Ленина, 14		0101000020E6100000CB65A3737E7863405B0A48FB1F424F40
53992	4	39	1891	30327	46024	\N	62.516601000000001	Магаданская область, Омсукчанский район, поселок Омсукчан, Ленина, 29		0101000020E6100000CB65A3737E7863405B0A48FB1F424F40
53994	4	39	1891	30458	46023	\N	62.574869999999997	Магаданская область, Омсукчанский район, поселок Дукат, проспект Победы, 4		0101000020E6100000E3DF675C386B6340CBB9145795494F40
53988	4	39	62	30160	46033	\N	60.518326999999999	Магаданская область, Ольский район, село Яна, Годяева, 1А		0101000020E6100000E292E34E6986624020D1048A58424E40
53980	4	39	62	29749	46029	\N	59.581820999999998	Магаданская область, Ольский район, село Ямск, Набережная, 8		0101000020E610000082ACA7565F44634021904B1C79CA4D40
53979	4	39	62	29727	46041	\N	60.200778	Магаданская область, Ольский район, село Тахтоямск, Советская, 23		0101000020E61000004969368F43556340CEE0EF17B3194E40
53989	4	39	62	30207	46050	\N	59.720295	Магаданская область, Ольский район, село Тауйск, 50 лет Октября, 22		0101000020E610000062670A9D57AA6240753C66A032DC4D40
53991	4	39	62	30291	46039	\N	59.765546000000001	Магаданская область, Ольский район, село Талон, Молодежная, 1А		0101000020E6100000A5DB12B9E0946240B4CA4C69FDE14D40
53985	4	39	62	75	45987	\N	59.572498000000003	Магаданская область, Ольский район, поселок Ола, пл.Ленина, 5		0101000020E6100000E3C798BB96E9624041834D9D47C94D40
53984	4	39	62	75	45986	\N	59.572498000000003	Магаданская область, Ольский район, поселок Ола, Советская, 31		0101000020E6100000E3C798BB96E9624041834D9D47C94D40
53986	4	39	62	75	46011	\N	59.572498000000003	Магаданская область, Ольский район, поселок Ола, Ленина, 54		0101000020E6100000E3C798BB96E9624041834D9D47C94D40
53983	4	39	62	75	46018	\N	59.572498000000003	Магаданская область, Ольский район, поселок Ола, Кирова, 1		0101000020E6100000E3C798BB96E9624041834D9D47C94D40
53981	4	39	62	29804	46045	\N	59.754919000000001	Магаданская область, Ольский район, село Клепка, Школьная, 1		0101000020E6100000CC28965B5AEF62408410902FA1E04D40
53982	4	39	62	29868	46031	\N	59.664585000000002	Магаданская область, Ольский район, село Гадля, Центральная, 7		0101000020E61000002B3064752BEA6240C2340C1F11D54D40
53990	4	39	62	30230	46049	\N	59.659526	Магаданская область, Ольский район, село Балаганное, Советская, 13		0101000020E6100000F3AB394030A362404C6E14596BD44D40
53987	4	39	62	30075	46003	\N	59.671540579534103	Магаданская область, Ольский район, поселок Армань, Пушкина, 17	Россия, Магаданская область, Ольский район, поселок Армань	0101000020E61000006074797338C462402976340EF5D54D40
38727	4	35	\N	23070	46072	\N	53.061560999999998	г.Петропавловск-Камчатский, проспект Рыбаков, 7, Камчатское музыкальное училище		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38742	4	35	\N	23070	46069	\N	53.061560999999998	г.Петропавловск-Камчатский, проспект Победы, 41, Гор. объед. управляющая компания		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38737	4	35	\N	23070	46069	\N	53.061560999999998	"г.Петропавловск-Камчатский, проспект Победы, 6 ""а"", Средняя школа  № 36"		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38735	4	35	\N	23070	46094	\N	53.061560999999998	г.Петропавловск-Камчатский, проспект Карла Маркса, 33/1, Камчатская краевая библиотека		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38734	4	35	\N	23070	46094	\N	53.061560999999998	г.Петропавловск-Камчатский, проспект Карла Маркса, 15/1, Средняя школа  № 11		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38728	4	35	\N	23070	46073	\N	53.061560999999998	г.Петропавловск-Камчатский, проспект 50 лет Октября, 25-а, Расчетно-кассовый центр по ЖКХ		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38725	4	35	\N	23070	46073	\N	53.061560999999998	г.Петропавловск-Камчатский, проспект 50 лет Октября, 1/1, КГТУ (корпус Дома культуры)		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38693	4	35	\N	23070	46059	\N	53.061560999999998	г.Петропавловск-Камчатский, площадь Щедрина, 3, Дом офицеров флота		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38726	4	35	\N	23070	46144	\N	53.061560999999998	г.Петропавловск-Камчатский, бульвар рыбацкой славы, 21, Средняя школа  № 33		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38741	4	35	\N	23070	46076	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Якорная, 11, Средняя школа  № 45		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38704	4	35	\N	23070	46198	\N	53.055485578000898	г.Петропавловск-Камчатский, улица Щорса, Клуб в/ч 41097	Россия, Камчатский край, Елизовский район	0101000020E610000010E7E10426D4634064B14D2A1A874A40
38736	4	35	\N	23070	46140	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Чубарова, 1, Профессиональное училище № 2		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38757	4	35	\N	23070	46171	\N	53.0491502197847	г.Петропавловск-Камчатский, улица Спортивная, 9, Домоуправление № 1	Россия, Камчатский край	0101000020E6100000CEFFAB8E9CD36340984C158C4A864A40
38744	4	35	\N	23070	46134	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Светлая, 1, Общеобразовательная школа  № 37		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38681	4	35	\N	23070	46065	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Сахалинская, 1, Гор. дом культуры ""СРВ"""		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38686	4	35	\N	23070	46153	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Садовая, 6 ""а"", Средняя школа  № 10"		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38719	4	35	\N	23070	46152	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Савченко, 12, Средняя школа  № 42		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38691	4	35	\N	23070	46115	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Рябиковская, 83/1, Средняя школа  № 6		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38687	4	35	\N	23070	46112	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Пономарева, 13, Средняя школа  № 24		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38702	4	35	\N	23070	46083	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Пограничная, 103, Средняя школа № 9		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38701	4	35	\N	23070	46083	\N	53.053080837943597	"г.Петропавловск-Камчатский, улица Пограничная, 31""а"", Камчатский дворец детск. творчества"	Россия, Камчатский край	0101000020E6100000E945ED7E15D46340FD84B35BCB864A40
38699	4	35	\N	23070	46083	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Пограничная, 4, КамГУ им. В. Беринга		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38679	4	35	\N	23070	46064	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Петра Ильичева, 80, Средняя школа 17		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38678	4	35	\N	23070	46064	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Петра Ильичева, 63, Библиотека Матросского клуба		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38705	4	35	\N	23070	46170	\N	53.049977748281698	"г.Петропавловск-Камчатский, улица Первомайская 15 ""а"", Средняя школа  № 41"		0101000020E6100000FE648C0FB3D363407FC2D9AD65864A40
38688	4	35	\N	23070	46110	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Океанская, 69, Гор. объед. управляющая компания		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38685	4	35	\N	23070	46110	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Океанская, 125, Дом дет. творчества ""Юность"""		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38706	4	35	\N	23070	46155	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Новая, 6, Средняя школа  № 41		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38740	4	35	\N	23070	46098	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Молчанова, 16/1, Средняя школа № 26		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38739	4	35	\N	23070	46098	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Молчанова, 12, Камч. управ. по гидрометеорологии		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38694	4	35	\N	23070	46149	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Ленинская, 69, КамГУ, корп. соц.эконом. факультета		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38721	4	35	\N	23070	46116	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Ленинградская 120 ""а"", КГТУ (корпус-бассейн)"		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38692	4	35	\N	23070	46118	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Курильская, 1, Детско-юношеская спорт. школа №5		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38722	4	35	\N	23070	46117	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Кроноцкая, 6/1, Средняя школа № 30		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38695	4	35	\N	23070	46151	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Космонавтов, 43, Центр культуры и досуга Сероглазка		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38715	4	35	\N	23070	46070	\N	53.061560999999998	г.Петропавловск-Камчатский, Космический проезд, 14, Средняя школа  № 39		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38682	4	35	\N	23070	46071	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Комсомольс-кая, 2 ""А"", Камчатский политехнический техникум"		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38698	4	35	\N	23070	46111	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Ключевская, 35, КГТУ (главный корпус)		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38697	4	35	\N	23070	46111	\N	53.049977748281698	г.Петропавловск-Камчатский, улица Ключевская, 11, Камчатский кооперативный техникум	Россия, Камчатский край	0101000020E61000001C28F04EBED363407FC2D9AD65864A40
38684	4	35	\N	23070	46147	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Кирова, 4, Средняя школа  № 5		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38690	4	35	\N	23070	46062	\N	53.040460206544601	г.Петропавловск-Камчатский, улица Капитана Драбкина, 18, Детский дом-школа № 2	Россия, Камчатский край, Елизовский район	0101000020E6100000213A048E04D56340E96514CB2D854A40
38689	4	35	\N	23070	46062	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Капитана Драбкина, 16, Средняя школа № 12	Россия, Камчатский край, Петропавловск-Камчатский	0101000020E61000008813984EEBD36340C2DA183BE1874A40
38683	4	35	\N	23070	46156	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Зеленая Роща, 24, Средняя школа  № 3		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38712	4	35	\N	23070	46066	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Звездная, 34, Средняя школа  № 31		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38710	4	35	\N	23070	46066	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Звездная, 26, Центр культуры и досуга ""Апрель"""		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38709	4	35	\N	23070	46066	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Звездная, 11/1, Средняя школа  № 27		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38680	4	35	\N	23070	46086	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Заводская, 20, Помещение бывшей гор. библиотеки		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38724	4	35	\N	23070	46089	\N	53.0491502197847	г.Петропавловск-Камчатский, улица Дзержинского  24, Средняя школа  № 30	Россия, Камчатский край	0101000020E610000032AF230E59D36340984C158C4A864A40
38707	4	35	\N	23070	46113	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Дальняя, 42, Средняя школа  № 32		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38731	4	35	\N	23070	46122	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Давыдова, 15, Средняя школа  № 8		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38703	4	35	\N	23070	46125	\N	53.051219011089799	г.Петропавловск-Камчатский, улица Гастелло, 7, Средняя школа  № 9	Россия, Камчатский край	0101000020E61000006A847EA6DED3634088F71C588E864A40
38708	4	35	\N	23070	46092	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Кирдищева Г.Ф., 8, Средняя школа  № 28		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38720	4	35	\N	23070	46061	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Вольского, 32, ООО ""Восток-Сервис"""		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38718	4	35	\N	23070	46061	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Вольского, 4/2, Средняя школа № 40		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38717	4	35	\N	23070	46061	\N	53.050805260811998	г.Петропавловск-Камчатский, улица Вольского, 4/2, Средняя школа  № 40	Россия, Камчатский край	0101000020E6100000FE648C0FB3D3634094BC3AC780864A40
38730	4	35	\N	23070	46121	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Ватутина, 1, Средняя школа  № 43		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38729	4	35	\N	23070	46121	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Ватутина, 1 ""а"", Средняя школа  № 7"		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38733	4	35	\N	23070	46091	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Бохняка, 18, Гор. объед. управляющая компания		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38732	4	35	\N	23070	46091	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Бохняка, 13, Камчатский педагогический колледж		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38743	4	35	\N	23070	46077	\N	53.066677944852302	г.Петропавловск-Камчатский, улица Бийская, 2, Средняя школа  № 20	Россия, Камчатский край, Елизовский район, Моховая	0101000020E61000005704FF5BC9D263406DAE9AE788884A40
38696	4	35	\N	23070	46150	\N	53.061560999999998	"г.Петропавловск-Камчатский, улица Беринга, 104 ""А"", Управление по недропользованию"		0101000020E61000008813984EEBD36340C2DA183BE1874A40
33348	4	41	1601	20264	46344	\N	48.535133000000002	с. Ключевое, ул. Советская, д. 11		0101000020E6100000A20DC00644D760405401F73C7F444840
38700	4	35	\N	23070	46060	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Атласова, 24, П.-Камчатский офицерский клуб		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38755	4	35	\N	23070	46194	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Аммональная падь, 1, Клуб военного госпиталя		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38716	4	35	\N	23070	46090	\N	53.061560999999998	г. Петропавловск-Камчатский, ул. Академика Королева, 23, Средняя школа  № 34		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38713	4	35	\N	23070	46090	\N	53.051219011089799	г.Петропавловск-Камчатский, улица Академика Королева, 23, Средняя школа  № 34	Россия, Камчатский край	0101000020E6100000CEFFAB8E9CD3634088F71C588E864A40
38756	4	35	\N	23070	46193	\N	53.061560999999998	г.Петропавловск-Камчатский, улица 2-я Шевченко, 5, Нежилое помещение		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38738	4	35	\N	23070	46074	\N	53.061560999999998	г.Петропавловск-Камчатский, проспект Победы, 6, Бассейн		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38754	4	35	\N	23070	46204	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Фурманова, 12, Средняя школа  № 9		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38723	4	35	\N	23070	46120	\N	53.061560999999998	г.Петропавловск-Камчатский, улица Зеркальная, 48, Профессиональное училище  № 4		0101000020E61000008813984EEBD36340C2DA183BE1874A40
38791	4	35	\N	55668	46168	\N	53.183155999999997	Камчатский край, г.Елизово, Санаторная, 6		0101000020E61000008D4292593DCC63407808E3A771974A40
38790	4	35	\N	55668	46135	\N	53.183155999999997	Камчатский край, г.Елизово, Рабочей смены, 1		0101000020E61000008D4292593DCC63407808E3A771974A40
38781	4	35	\N	55668	46164	\N	53.183155999999997	Камчатский край, г.Елизово, Мурманская, 4		0101000020E61000008D4292593DCC63407808E3A771974A40
38767	4	35	\N	55660	46100	\N	52.943870503318998	Камчатский край, Вилючинский городской округ, Победы, 9	Россия, Камчатский край, Вилючинск	0101000020E6100000C68844A1E5CC63404852D2C3D0784A40
38766	4	35	\N	55660	46100	\N	52.938997841360099	Камчатский край, Вилючинский городской округ, Победы, 5	Россия, Камчатский край, Вилючинск	0101000020E6100000B91AD99516CD63403481221631784A40
38772	4	35	\N	55660	46129	\N	52.937233460473102	Камчатский край, Вилючинский городской округ, Мира, 8а	Россия, Камчатский край, Вилючинск	0101000020E6100000F6ED2422FCCC6340B1DD3D40F7774A40
38759	4	35	\N	55660	46215	\N	52.933084789170898	Камчатский край, Вилючинский городской округ, Владивостокская, 4А		0101000020E6100000441669E21DCD6340AFB14B546F774A40
38765	4	35	\N	55660	46166	\N	52.937338488785599	Камчатский край, Вилючинский городской округ, 50 лет ВЛКСМ, 6	Россия, Камчатский край, Вилючинск	0101000020E610000089B5F81400CD634026A60BB1FA774A40
38837	4	35	1889	30428	46109	\N	56.224938000000002	Камчатский край, Усть-Камчатский муниципальный район, Усть-Камчатское сельское поселение, п.Усть-Камчатск, Советская, 1		0101000020E610000069C878944A4F644057D0B4C4CA1C4C40
38835	4	35	1889	30428	46175	\N	56.2244084017536	Камчатский край, Усть-Камчатский муниципальный район, Ключевское сельское поселение, Кирова, 60	Россия, Камчатский край, Усть-Камчатский район	0101000020E6100000CC2555DBCD506440FA7ABE66B91C4C40
38838	4	35	1889	30428	46148	\N	56.224938000000002	Камчатский край, Усть-Камчатский муниципальный район, Усть-Камчатское сельское поселение, п.Усть-Камчатск, Горького, 53		0101000020E610000069C878944A4F644057D0B4C4CA1C4C40
38833	4	35	1889	30247	46199	\N	56.252656999999999	Камчатский край, Усть-Камчатский муниципальный район, Козыревское сельское поселение, с.Майское, Комсомольская, 9		0101000020E6100000A0C37C7901026440800D881057204C40
38839	4	35	1889	30537	46190	\N	56.249527	Камчатский край, Усть-Камчатский муниципальный район, Усть-Камчатское сельское поселение, с.Крутоберегово, Новая, 4-А		0101000020E610000070D05E7DBC566440083C3080F01F4C40
38832	4	35	1889	30204	46108	\N	56.041379999999997	Камчатский край, Усть-Камчатский муниципальный район, Козыревское сельское поселение, п.Козыревск, Ленинская, 54		0101000020E610000076340EF5BBFB6340AF5A99F04B054C40
38836	4	35	1889	55662	\N	\N	56.311525603263497	Камчатский край, Усть-Камчатский муниципальный район, Ключевское сельское поселение, п.Ключи-1, войсковая часть	Россия, Камчатский край, Усть-Камчатский район	0101000020E610000054E3A59B441A644046ED7E15E0274C40
38834	4	35	1889	55666	46130	\N	56.317677000000003	Камчатский край, Усть-Камчатский муниципальный район, Ключевское сельское поселение, п.Ключи, Красноармейская, 3		0101000020E6100000DF347D76C01A644080D8D2A3A9284C40
38824	4	35	1873	55674	46205	\N	52.379288031066402	с. Кавалерское, ул. Блюхера, 27	Россия, Камчатский край, Усть-Большерецкий район	0101000020E61000008C2C9963F9A06340F4E159828C304A40
38823	4	35	1873	29738	46063	\N	52.821330000000003	с. Усть-Большерецк, ул. Ленинская, 9		0101000020E6100000D0ED258DD1886340A29C685721694A40
38819	4	35	1873	29578	46178	\N	51.468026000000002	пос.Паужетка, ул.Энергетиков, 9		0101000020E610000010768A55039A6340BFD6A546E8BB4940
38822	4	35	1873	48905	46107	\N	52.655617999999997	пос.Октябрьский, Комсомольская, 3		0101000020E61000001749BBD1C78763409F55664AEB534A40
38821	4	35	1873	29640	46084	\N	51.488680000000002	пос.Озерновский, ул.Октябрьская, 20		0101000020E6100000DD7A4D0F0A906340CA1AF5108DBE4940
38820	4	35	1873	29630	46163	\N	51.504711	с.Запорожье, Центральная, 39а		0101000020E6100000BC02D193B29063403A77BB5E9AC04940
38825	4	35	1873	29867	46157	\N	52.925460000000001	с. Апача, ул. Юбилейная, 16		0101000020E61000006B64575A46A46340CAE0287975764A40
38841	4	35	1898	52608	46197	\N	56.847507999999998	"Камчатский край, Тигильский муниципальный район, сельское поселение ""село Хайрюзово"", Набережная, 40"		0101000020E610000036C98FF895A06340978C63247B6C4C40
38842	4	35	1898	52611	46169	\N	57.099266999999998	"Камчатский край, Тигильский муниципальный район, сельское поселение ""село Усть-Хайрюзово"", Школьная, 6-а"		0101000020E6100000596B28B5979763403849F3C7B48C4C40
38785	4	35	1821	27738	46136	\N	53.183155999999997	Камчатский край, г.Елизово, 40 лет Октября, 9		0101000020E61000008D4292593DCC63407808E3A771974A40
38845	4	35	1898	52624	46131	\N	57.761456000000003	"Камчатский край, Тигильский муниципальный район, сельское поселение ""село Тигиль"", Партизанская, 21"		0101000020E6100000A438471D9DD56340E7ABE46377E14C40
38844	4	35	1898	52622	46192	\N	57.726726999999997	"Камчатский край, Тигильский муниципальный район, сельское поселение ""село Седанка"", Советская, 16"		0101000020E6100000FD3383F840C96340620FED6305DD4C40
38848	4	35	1898	55656	46068	\N	59.088164562926998	"Камчатский край, городской округ ""поселок Палана"", ул. Поротова, 31"	Россия, Камчатский край, Тигильский район	0101000020E6100000022A1C41AAFE63406FD39FFD488B4D40
38847	4	35	1898	52631	46208	\N	59.463527999999997	"Камчатский край, Тигильский муниципальный район, сельское поселение ""село Лесная"", Депутатская, 7"		0101000020E61000002618CE35CC116440E063B0E254BB4D40
38843	4	35	1898	52614	46202	\N	57.198779999999999	"Камчатский край, Тигильский муниципальный район, сельское поселение ""село Ковран"", 50лет Октября, 20"		0101000020E6100000F6EE8FF72A9C6340A88C7F9F71994C40
38846	4	35	1898	52628	46209	\N	58.307597000000001	"Камчатский край, Тигильский муниципальный район, сельское поселение ""село Воямполка"", Гагарина, 13"		0101000020E6100000543A58FF67EC634082ACA7565F274D40
38829	4	35	1884	55665	46128	\N	54.2966940234449	Камчатский край, Соболевский муниципальный район, Соболевское сельское поселение, ул. Советская, 26	Россия, Камчатский край, Соболевский район, село Соболево	0101000020E6100000425C397B677E6340B075A911FA254B40
38828	4	35	1884	55665	46220	\N	54.2966940234449	Камчатский край, Соболевский муниципальный район, Устьевое сельское поселение, Речная, 5	Россия, Камчатский край, Соболевский район, село Соболево	0101000020E6100000E8120EBD457E6340B075A911FA254B40
38830	4	35	1884	55665	46206	\N	54.301996947931599	Камчатский край, Соболевский муниципальный район, Крутогоровское сельское поселение, Заводская, 19	Россия, Камчатский край, Соболевский район	0101000020E61000006C2409C2957E6340BC3E73D6A7264B40
38831	4	35	1884	55680	46226	\N	55.606164415230403	"Камчатский край, Соболевский муниципальный район, Ичинское сельское поселение, Геологическая, 25""А"""	Россия, Камчатский край, Соболевский район	0101000020E6100000D600A5A1C67363409B012EC896CD4B40
38851	4	35	1920	55678	46222	\N	62.058541407931699	"сельское поселение ""село Таловка"", Центральная, 11"	Россия, Камчатский край, Пенжинский район	0101000020E61000009CA38E8E2BD66440D13C80457E074F40
38867	4	35	1920	55679	46224	\N	63.1699196077086	"сельское поселение ""село Слаутное"", Давыдова, 13"	Россия, Камчатский край, Пенжинский район	0101000020E61000002DB1321A79FE6440D97745F0BF954F40
38864	4	35	1920	31768	\N	\N	62.422690000000003	с.Парень, Администрация села		0101000020E6100000CEFBFF38E1626440522CB7B41A364F40
38866	4	35	1920	31872	46187	\N	62.708959	село Оклан, Мира, 12		0101000020E61000006EDFA3FE7AD26440399A232BBF5A4F40
38807	4	35	1920	55671	46183	\N	62.493417169300002	"сельское поселение ""село Манилы"", Ленинская, 3"	Россия, Камчатский край, Пенжинский район	0101000020E6100000E99C9FE2B8A964402D25CB49283F4F40
38865	4	35	1920	55676	46229	\N	62.480166429087902	"сельское поселение ""село Каменское"", ул. Ленина, 3"		0101000020E6100000F3E32F2D6AC6644058535914763D4F40
38868	4	35	1920	55677	46223	\N	63.721679768290798	"сельское поселение ""село Аянка"", 60 лет Октября, 1"		0101000020E61000006F490ED855F26440B1169F0260DC4F40
38859	4	35	1918	52666	46173	\N	60.955855999999997	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Хаилино"", Центральная, 10-А"		0101000020E6100000AAD216D7F8DA6440BAD7497D597A4E40
38858	4	35	1918	52662	46085	\N	60.433414999999997	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Тиличики"", Молодежная, 10-А"		0101000020E61000003A747ADE8DC16440444C89247A374E40
38861	4	35	1918	55675	46213	\N	60.829190589867899	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Средние Пахачи"", Центральная, 49"	Россия, Камчатский край, Олюторский район	0101000020E610000024ED461FF32165409B9141EE226A4E40
38860	4	35	1918	52669	46188	\N	60.561137000000002	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Пахачи"", Центральная, 33"		0101000020E61000008C6665FB90246540ACC95356D3474E40
38857	4	35	1918	52661	46211	\N	60.37162	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Корф"", Советская, 37"		0101000020E610000032207BBD7BC064400F45813E912F4E40
38856	4	35	1918	52658	46179	\N	60.188448000000001	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Вывенка"", Центральная, 17"		0101000020E6100000679B1BD393AE6440917F66101F184E40
38863	4	35	1918	52678	46219	\N	61.007078999999997	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Ачайваям"", Каюю, 11-А"		0101000020E6100000BFB7E9CFFE4F654083BEF4F6E7804E40
38862	4	35	1918	52673	46189	\N	60.457726999999998	"Камчатский край, Олюторский муниципальный район, сельское поселение ""село Апука"", Морская, 11"		0101000020E6100000431B800D8832654083BF5FCC963A4E40
38810	4	35	1863	29162	46203	\N	54.397784999999999	с.Шаромы, Советская, 13		0101000020E6100000632827DAD5C6634070EB6E9EEA324B40
38816	4	35	1863	45451	46185	\N	55.272570000000002	п. Таежный, ул. Крупская, 10		0101000020E610000043AA285EE5EB634074EFE192E3A24B40
38809	4	35	1863	48693	46201	\N	54.168318999999997	с.Пущино, Центральная, 15		0101000020E61000003315E29178C06340D0251C7A8B154B40
38812	4	35	1863	29250	46127	\N	54.695528000000003	с.Мильково, Строительная, 9		0101000020E6100000425C397BE7D36340E5B9BE0F07594B40
38813	4	35	1863	29250	46141	\N	54.695528000000003	с.Мильково, Победы, 8		0101000020E6100000425C397BE7D36340E5B9BE0F07594B40
38814	4	35	1863	29250	46145	\N	54.695528000000003	с.Мильково, Партизанская, 21		0101000020E6100000425C397BE7D36340E5B9BE0F07594B40
38811	4	35	1863	29250	46080	\N	54.695528000000003	с.Мильково, Томская, 20		0101000020E6100000425C397BE7D36340E5B9BE0F07594B40
38818	4	35	1863	48840	46195	\N	55.539226999999997	п.Лазо, Омская, 17		0101000020E6100000CA8CB7955EF86340620FED6305C54B40
38854	4	35	1909	52655	46210	\N	59.490606999999997	"Камчатский край, Карагинский муниципальный район, сельское поселение ""село Тымлат"", Комарова, 15"		0101000020E6100000C51F459DB96564402618CE35CCBE4D40
38853	4	35	1909	55667	46133	\N	59.2512241827704	"Камчатский край, Карагинский муниципальный район, городское поселение ""поселок Оссора"", Советская, 64"	Россия, Камчатский край, Карагинский район	0101000020E6100000FFE7305F5E62644033FCA71B28A04D40
38850	4	35	1909	52643	46207	\N	59.034689999999998	"Камчатский край, Карагинский муниципальный район, сельское поселение ""село Кострома"", Центральная, 14"		0101000020E61000001C5E10919A656440C6BFCFB870844D40
38852	4	35	1909	52650	46217	\N	59.113346431447802	"Камчатский край, Карагинский муниципальный район, сельское поселение ""село Карага"", ул. Обухова, 31"		0101000020E6100000492C29771F646440F390291F828E4D40
38855	4	35	1909	52653	46184	\N	59.957908000000003	"Камчатский край, Карагинский муниципальный район, сельское поселение ""село Ильпырское"", Калининская, 9"		0101000020E61000003C11C479B8856440D449B6BA9CFA4D40
38849	4	35	1909	52640	46174	\N	58.564608	"Камчатский край, Карагинский муниципальный район, сельское поселение ""село Ивашка"", ул. Левченко, 18"		0101000020E6100000BC77D49890496440AD872F1345484D40
38774	4	35	1821	55670	46180	\N	53.149096999999998	Камчатский край, Елизовский муниципальный район, п.Новый, Молодежная, 5		0101000020E6100000C093162EABEC63404277499C15934A40
38793	4	35	1821	55664	46119	\N	53.085111655168703	Камчатский край, Елизовский муниципальный район, п.Вулканный, Центральная, 35	Россия, Камчатский край, Елизовский район	0101000020E61000007689EAAD01CB6340A33F34F3E48A4A40
38798	4	35	1821	28618	46161	\N	52.933109000000002	Камчатский край, Елизовский муниципальный район, п. Термальный, ул. Ленина, 1		0101000020E61000008AC745B508C76340384D9F1D70774A40
38799	4	35	1821	28618	46167	\N	52.933109000000002	Камчатский край, Елизовский муниципальный район, п.Термальный, Крашенинникова, 2		0101000020E61000008AC745B508C76340384D9F1D70774A40
38795	4	35	1821	28472	46162	\N	53.074407000000001	Камчатский край, Елизовский муниципальный район, с.Сосновка, Центральная, 5		0101000020E6100000E5D022DB79C96340F7CB272B86894A40
38808	4	35	1821	29086	46132	\N	53.146089000000003	Камчатский край, Елизовский муниципальный район, п.Сокоч, Юбилейная, 11		0101000020E6100000A60EF27A30B6634016A75A0BB3924A40
38803	4	35	1821	55673	46191	\N	53.350481431030197	Камчатский край, Елизовский муниципальный район, с.Северные Коряки, Дачная, 9	Россия, Камчатский край, Елизовский район	0101000020E610000060E7A6CDB8C66340486FB88FDCAC4A40
38800	4	35	1821	28698	46139	\N	53.268450000000001	Камчатский край, Елизовский муниципальный район, п.Раздольный, Ролдугина, 17		0101000020E610000072C5C55139C963403C4ED1915CA24A40
38773	4	35	1821	27493	46158	\N	53.094710999999997	Камчатский край, Елизовский муниципальный район, п.Пионерский, Бонивура, 2/1		0101000020E610000020459DB907D1634025C9737D1F8C4A40
38796	4	35	1821	28540	46177	\N	52.960417999999997	Камчатский край, Елизовский муниципальный район, с.Паратунка, Нагорная, 30		0101000020E6100000478FDFDBF4C76340AF3E1EFAEE7A4A40
38797	4	35	1821	28540	46154	\N	52.960417999999997	Камчатский край, Елизовский муниципальный район, с.Паратунка, Мирная, 7		0101000020E6100000478FDFDBF4C76340AF3E1EFAEE7A4A40
38794	4	35	1821	28456	46106	\N	53.044257000000002	Камчатский край, Елизовский муниципальный район, с.Николаевка, Елизовская, 12		0101000020E610000095F430B4BACA63403ECF9F36AA854A40
38776	4	35	1821	55659	46087	\N	53.119411875053203	Камчатский край, Елизовский муниципальный район, п.Нагорный, Первомайская, 7а	Россия, Камчатский край, Елизовский район	0101000020E6100000172EABB099CF6340FE5F75E4488F4A40
38806	4	35	1821	29006	46160	\N	53.251137	Камчатский край, Елизовский муниципальный район, п.Лесной, Школьная, 11а		0101000020E610000059164CFCD1C0634064E8D84125A04A40
38801	4	35	1821	28769	46172	\N	53.280797	Камчатский край, Елизовский муниципальный район, с.Коряки, Геологов, 13		0101000020E610000076E09C11A5C663404FE8F527F1A34A40
38802	4	35	1821	28769	46126	\N	53.280797	Камчатский край, Елизовский муниципальный район, с.Коряки, Вилкова, 1/1		0101000020E610000076E09C11A5C663404FE8F527F1A34A40
38804	4	35	1821	28926	46182	\N	53.276222184799401	Камчатский край, Елизовский муниципальный район, п.Зеленый, Атласова, 12/2	Россия, Камчатский край, Елизовский район	0101000020E6100000020CCB9FEFC56340C537143E5BA34A40
38780	4	35	1821	27738	\N	\N	53.183155999999997	Камчатский край, г.Елизово, Попова, 24	Россия, Камчатский край, Елизовский район, Елизово	0101000020E61000008D4292593DCC63407808E3A771974A40
38784	4	35	1821	27738	46075	\N	53.183155999999997	Камчатский край, г.Елизово, Тимирязевский переулок, 9		0101000020E61000008D4292593DCC63407808E3A771974A40
38782	4	35	1821	27738	46078	\N	53.183155999999997	Камчатский край, г.Елизово, Рябикова, 27		0101000020E61000008D4292593DCC63407808E3A771974A40
38789	4	35	1821	27738	46105	\N	53.183155999999997	Камчатский край, г.Елизово, Пограничная, 27		0101000020E61000008D4292593DCC63407808E3A771974A40
38783	4	35	1821	27738	46137	\N	53.183155999999997	Камчатский край, г.Елизово, Ленина, 22		0101000020E61000008D4292593DCC63407808E3A771974A40
38778	4	35	1821	27738	46102	\N	53.183155999999997	Камчатский край, г.Елизово, Котельная, 2		0101000020E61000008D4292593DCC63407808E3A771974A40
38788	4	35	1821	27738	46104	\N	53.183155999999997	Камчатский край, г.Елизово, Зеленая, 5		0101000020E61000008D4292593DCC63407808E3A771974A40
38779	4	35	1821	27738	46101	\N	53.183155999999997	Камчатский край, г.Елизово, Звездная, Клуб аэропорта		0101000020E61000008D4292593DCC63407808E3A771974A40
38792	4	35	1821	27738	46099	\N	53.183155999999997	Камчатский край, г.Елизово, Завойко, 123 А		0101000020E61000008D4292593DCC63407808E3A771974A40
38786	4	35	1821	27738	46079	\N	53.183155999999997	Камчатский край , г.Елизово, Виталия Кручины, 30		0101000020E61000008D4292593DCC63407808E3A771974A40
38787	4	35	1821	27738	9722	\N	53.183155999999997	Камчатский край, г. Елизово, ул. Беринга, 16		0101000020E61000008D4292593DCC63407808E3A771974A40
38777	4	35	1821	27674	46200	\N	53.13729	Камчатский край, Елизовский муниципальный район, п.Двуречье, Центральная, 27		0101000020E6100000B939950C00D06340AF08FEB792914A40
38764	4	35	1821	55669	46146	\N	52.945529604184003	Камчатский край, Вилючинский городской округ, Вилкова, 35	Россия, Камчатский край, Елизовский район	0101000020E6100000C68844A1E5CC634085B1852007794A40
38769	4	35	1821	55658	46096	\N	52.943593946536701	Камчатский край, Вилючинский городской округ, Центральный, 1	Россия, Камчатский край, Елизовский район	0101000020E6100000A8C5E061DACC6340D5592DB0C7784A40
38768	4	35	1821	55658	46096	\N	52.931840109848501	Камчатский край, Вилючинский городской округ, Центральный, 6	Россия, Камчатский край, Елизовский район	0101000020E6100000F6ED2422FCCC6340658D7A8846774A40
38771	4	35	1821	55658	46097	\N	52.935067004491501	Камчатский край, Вилючинский городской округ, Спортивная, 8	Россия, Камчатский край, Елизовский район	0101000020E6100000B1169F02E0CC6340CF488446B0774A40
38761	4	35	1821	55658	46082	\N	52.930700945540302	Камчатский край, Вилючинский городской округ, Приморская, 6		0101000020E61000001DCA5015D3CC634060ADDA3521774A40
38770	4	35	1821	55658	46093	\N	52.9449842630926	Камчатский край, Вилючинский городской округ, Мира, 20	Россия, Камчатский край, Елизовский район	0101000020E61000007BBFD18E1BCD6340239F573CF5784A40
38758	4	35	1821	55658	46103	\N	52.930180481466202	Камчатский край, Вилючинский городской округ, Кронштадтская, 10	Россия, Камчатский край, Елизовский район	0101000020E6100000265305A312CD634057B2632310774A40
38762	4	35	1821	55658	46095	\N	52.950612025350701	Камчатский край, Вилючинский городской округ, Крашенинникова, 30а	Россия, Камчатский край, Елизовский район	0101000020E61000002F6CCD56DECC6340B3976DA7AD794A40
38763	4	35	1821	55658	46123	\N	52.947188641112497	Камчатский край, Вилючинский городской округ, Гусарова, 49	Россия, Камчатский край, Елизовский район	0101000020E6100000265305A312CD6340C310397D3D794A40
38805	4	35	1821	28947	46159	\N	53.264237999999999	Камчатский край, Елизовский муниципальный район, п.Березняки, Строительная, 2		0101000020E6100000AD872F13C5C26340232E008DD2A14A40
38826	4	35	1879	29890	46124	\N	55.930518999999997	Камчатский край, Быстринский район, с.Эссо, адрес помещения для голосования: ул.Южная, д.3, адрес УИК: ул.Терешковой, 1		0101000020E61000002FA2ED983AD663403FA7203F1BF74B40
38827	4	35	1879	29940	46196	\N	56.056930000000001	Камчатский край, Быстринский район, с.Анавгай, адрес помещения для голосования: ул.Советская, д.4, адрес УИК: ул.Ленинская, 36		0101000020E6100000DC4944F817DF6340A514747B49074C40
38840	4	35	1896	55672	46186	\N	55.198994765719299	Камчатский край, Алеутский муниципальный район, 50 лет Октября, 13	Россия, Камчатский край, Алеутский район, село Никольское	0101000020E610000007B5DFDA89C06440A4880CAB78994B40
33320	4	41	\N	55681	46232	\N	49.125205000000001	поселок Хинганск, Ленина, 9		0101000020E6100000BE874B8E3B666040D925AAB706904840
33319	4	41	\N	55686	46244	\N	49.011566000000002	город Облучье, Тварковского, 8А		0101000020E6100000700A2B15D46160406EDFA3FE7A814840
33318	4	41	\N	55686	46280	\N	49.011566000000002	город Облучье, Районная, 69А		0101000020E6100000700A2B15D46160406EDFA3FE7A814840
33345	4	41	\N	55691	46290	\N	48.566242000000003	пос. Волочаевка-2, ул. Школьная, д. 2		0101000020E6100000B8E5232969D2604092CF2B9E7A484840
33300	4	41	\N	55684	46292	\N	48.779257999999999	г. Биробиджан, проспект 60-летия СССР, 12		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33413	4	41	\N	55684	46247	\N	48.779257999999999	г. Биробиджан, Шолом-Алейхема, 117		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33287	4	41	\N	55684	46247	\N	48.779257999999999	г. Биробиджан, Шолом-Алейхема, 57		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33296	4	41	\N	55684	46240	\N	48.779257999999999	г. Биробиджан, Комсомольская, 1		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33311	4	41	\N	55684	46259	\N	48.779257999999999	г. Биробиджан, Карла Маркса, 25		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33309	4	41	\N	16582	46268	\N	48.779257999999999	г. Биробиджан, Юбилейная, 9		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33293	4	41	\N	16582	46243	\N	48.779257999999999	г. Биробиджан, Шолом-Алейхема, 11		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33284	4	41	\N	16582	46243	\N	48.779257999999999	г. Биробиджан, Шолом-Алейхема, 81		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33280	4	41	\N	16582	46243	\N	48.779257999999999	г. Биробиджан, Шолом-Алейхема, 92		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33277	4	41	\N	16582	46243	\N	48.779257999999999	г. Биробиджан, Шолом-Алейхема, 115		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33307	4	41	\N	16582	46267	\N	48.779257999999999	г. Биробиджан, Школьная, 23		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33304	4	41	\N	16582	46257	\N	48.779257999999999	г. Биробиджан, Широкая, 70 А		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33288	4	41	\N	16582	46251	\N	48.779257999999999	г. Биробиджан, Швейный, 6 Б		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33289	4	41	\N	16582	46324	\N	48.779257999999999	г. Биробиджан, Черноморская, 6		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33297	4	41	\N	16582	46231	\N	48.779257999999999	г. Биробиджан, Чапаева, 2		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33294	4	41	\N	16582	46304	\N	48.779257999999999	г. Биробиджан, Транспортная, 25		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33290	4	41	\N	16582	46254	\N	48.779257999999999	г. Биробиджан, Строительная, 19		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33305	4	41	\N	16582	46233	\N	48.779257999999999	г. Биробиджан, Советская, 74		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33303	4	41	\N	16582	46233	\N	48.779257999999999	г. Биробиджан, Советская, 66 Б		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33302	4	41	\N	16582	46233	\N	48.779257999999999	г. Биробиджан, Советская, 72 А		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33301	4	41	\N	16582	46233	\N	48.779257999999999	г. Биробиджан, Советская, 49		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33312	4	41	\N	16582	46327	\N	48.779257999999999	г. Биробиджан, Пригородная, 6 б		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33292	4	41	\N	16582	46238	\N	48.779257999999999	г. Биробиджан, Пионерская, 21		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33286	4	41	\N	16582	46238	\N	48.779257999999999	г. Биробиджан, Пионерская, 34		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33285	4	41	\N	16582	46238	\N	48.779257999999999	г. Биробиджан, Пионерская, 60		0101000020E6100000CC2A6C06B89C6040BC92E4B9BE634840
33347	4	41	1601	49577	\N	\N	48.550964	с. Камышовка, ул. Советская, д. 3	Россия, Еврейская автономная область, Смидовичский район, село Камышовка	0101000020E610000075E95F924AD36040FDA204FD85464840
33415	4	41	1601	46672	46353	\N	48.592163999999997	с. Даниловка, ул. Садовая, д.18		0101000020E6100000CF4C309C6BD360402CEFAA07CC4B4840
33344	4	41	1601	19999	46284	\N	48.566242000000003	пос. Волочаевка-2, ул. Советская, д. 54		0101000020E6100000B8E5232969D2604092CF2B9E7A484840
33343	4	41	1601	19957	46301	\N	48.562657999999999	с. Волочаевка-1, ул. Вокзальная, д. 1а		0101000020E61000004012F6EDA4CF6040986A662D05484840
33337	4	41	1601	19650	46325	\N	48.594900000000003	с. Белгородское, ул. Шоссейная, д. 26		0101000020E6100000B6BB07E83EB76040F931E6AE254C4840
33336	4	41	1601	19583	\N	\N	48.627138000000002	с. Аур, ул. Комсомольская, д. 7в	Россия, Еврейская автономная область, Смидовичский район, село Аур	0101000020E610000085B01A4BD8AD6040180AD80E46504840
33363	4	41	1645	21065	46350	\N	47.917521999999998	село Столбовое, ул.Верхняя, д.7а		0101000020E6100000D4EE5701BE61604025AE635C71F54740
33362	4	41	1645	21055	46313	\N	47.831494999999997	село Самара, ул.Почтовая, д.1		0101000020E6100000CF2EDFFA30676040CDE49B6D6EEA4740
33367	4	41	1645	45668	46314	\N	47.762571000000001	село Садовое, ул.Школьная, д.18		0101000020E6100000C904FC1A496E604063F030ED9BE14740
33370	4	41	1645	45735	46328	\N	47.821344000000003	село Ручейки, ул.Ленина, д.1		0101000020E610000009DE9046857460400762D9CC21E94740
33361	4	41	1645	20991	46289	\N	47.735599000000001	село Пузино, пер.Клубный, д. 1а		0101000020E6100000D7A546E8E766604033FCA71B28DE4740
33364	4	41	1645	45626	46322	\N	47.841807000000003	село Полевое, ул.Советская, д.10		0101000020E61000005C04C6FA066860409E45EF54C0EB4740
33360	4	41	1645	45532	46337	\N	47.750359000000003	село Озерное, ул.Амурская, д.17		0101000020E610000058C85C195464604030A182C30BE04740
33368	4	41	1645	21299	46323	\N	47.743699999999997	село Нагибово, ул.Центральная, д.13в		0101000020E6100000D237691A147160408104C58F31DF4740
33365	4	41	1645	45635	46348	\N	47.840192999999999	село Луговое, ул.Магистральная, д.5		0101000020E6100000A7785C548B6A604000AAB8718BEB4740
33359	4	41	1645	20883	46276	\N	47.749614000000001	село Екатерино-Никольское, ул.Пограничная, д.64		0101000020E610000066834C32F25E6040D74FFF59F3DF4740
33369	4	41	1645	21366	46321	\N	47.765678000000001	село Доброе, ул.Советская, д.18		0101000020E6100000B5334C6DA975604023A298BC01E24740
33366	4	41	1645	55695	46320	\N	47.770004512622897	село Благословенное, ул.Советская, д.37	Россия, Еврейская автономная область, Октябрьский район, село Благославенное	0101000020E6100000CA6E66F4236C6040D4601A868FE24740
33357	4	41	1645	20785	9847	\N	47.695205072433403	село Амурзет, ул.Крупской, д.18	Россия, Еврейская автономная область, Октябрьский район, село Амурзет	0101000020E610000066F9BA0CFF6260400282397AFCD84740
33358	4	41	1645	20785	46245	\N	47.695205000000001	село Амурзет, ул.Калинина, д.27		0101000020E6100000530438BD0B6360400282397AFCD84740
33328	4	41	1543	55687	46270	\N	49.008895000000003	поселок Теплоозерск, Лазо, 11А		0101000020E6100000506F46CD577C6040890CAB7823814840
33329	4	41	1543	55687	46249	\N	49.008895000000003	поселок Теплоозерск, Бонивура, 11		0101000020E6100000506F46CD577C6040890CAB7823814840
33335	4	41	1543	55697	\N	\N	48.962170454724102	село Семисточное	Россия, Еврейская автономная область, Облученский район, село Семисточный	0101000020E61000001BD5E940569360409E98F562287B4840
33323	4	41	1543	18919	46318	\N	48.597580999999998	село Радде, Центральная, 5		0101000020E61000006823D74D2953604001DBC1887D4C4840
33321	4	41	1543	49205	46307	\N	48.888418999999999	село Пашково, Набережная, 24		0101000020E610000052B5DD04DF5460409012BBB6B7714840
33314	4	41	1543	55688	46281	\N	49.011566000000002	город Облучье, Ключевая, 50		0101000020E6100000700A2B15D46160406EDFA3FE7A814840
33316	4	41	1543	55688	46264	\N	49.011566000000002	город Облучье, Интернациональная, 26		0101000020E6100000700A2B15D46160406EDFA3FE7A814840
33315	4	41	1543	18371	46262	\N	49.011566000000002	город Облучье, Пролетарская, 3		0101000020E6100000700A2B15D46160406EDFA3FE7A814840
33317	4	41	1543	18371	46286	\N	49.011566000000002	город Облучье, Денисова, 34		0101000020E6100000700A2B15D46160406EDFA3FE7A814840
33313	4	41	1543	18371	46295	\N	49.011566000000002	город Облучье, Горького, 118		0101000020E6100000700A2B15D46160406EDFA3FE7A814840
33330	4	41	1543	55693	46306	\N	49.012848747513701	поселок Лондоко-завод, Комсомольская, 1А		0101000020E6100000C0081A33097E6040A6643909A5814840
33331	4	41	1543	19325	46250	\N	49.204636999999998	поселок Кульдур, Раскопенского, 18А		0101000020E6100000F4DDAD2C517460409946938B319A4840
33325	4	41	1543	55689	46271	\N	48.989738000000003	поселок Известковый, Ведина, 1		0101000020E6100000F7730AF2B3716040E2CD1ABCAF7E4840
33326	4	41	1543	19079	\N	\N	48.971756999999997	село Двуречье, Совхозная, 6	Россия, Еврейская автономная область, Облученский район, село Двуречье	0101000020E6100000871744A4A67260405C548B88627C4840
33334	4	41	1543	19471	46345	\N	49.015909441459002	село Будукан, Школьная, 10А	Россия, Еврейская автономная область, Облученский район, село Будукан	0101000020E610000042B0AA5E7E876040255B5D4E09824840
33327	4	41	1543	19140	46272	\N	49.000053000000001	поселок Биракан, Октябрьская, 34А		0101000020E61000003E0796236477604023A298BC01804840
33332	4	41	1543	19386	46234	\N	49.001027999999998	поселок Бира, 40 лет Победы, 18		0101000020E6100000B119E082EC8E6040AD307DAF21804840
33333	4	41	1543	55690	46283	\N	49.001027999999998	поселок Бира, Онищенко, 48		0101000020E6100000B119E082EC8E6040AD307DAF21804840
33324	4	41	1543	18981	46336	\N	48.695936000000003	село Башурово, переулок Амурский, 2		0101000020E61000001FA1664815536040F60D4C6E14594840
33396	4	41	1696	22622	46347	\N	48.077407999999998	с. Чурки, им. 27 съезда КПСС, 6		0101000020E61000001442075D4295604071395E81E8094840
33401	4	41	1696	22836	46343	\N	48.210552	с. Унгун, Центральная, 7		0101000020E61000004A41B797348D6040BF0D315EF31A4840
33405	4	41	1696	46489	46332	\N	47.890365000000003	с. Степное, Школьная, 1		0101000020E6100000F38FBE49D37C60406440F67AF7F14740
33417	4	41	1696	23583	46355	\N	48.090156999999998	Ленинский район, с. Преображеновка, пер. Школьный, д.1		0101000020E610000056EF703BB47C6040B340BB438A0B4840
33398	4	41	1696	46326	46311	\N	48.091777717481001	с. Октябрьское, Юбилейная, 6	Россия, Еврейская автономная область, Ленинский район, село Октябрьское	0101000020E61000004EF1B8A896906040033FAA61BF0B4840
33403	4	41	1696	46443	46330	\N	48.253211999999998	с. Новотроицкое, Центральная, 24		0101000020E6100000218FE046CA7E6040357A354069204840
33410	4	41	1696	55694	46319	\N	47.809798576937801	с. Новое, Шоссейная, 48	Россия, Еврейская автономная область, Ленинский район, село Новое	0101000020E61000002AAA7EA5F38A6040B0AA5E7EA7E74740
33393	4	41	1696	46221	46335	\N	47.961266000000002	с. Нижне-Ленинское, пер. Вилкова, 1		0101000020E61000008FAB915D69956040DD60A8C30AFB4740
33412	4	41	1696	45545	\N	\N	47.944544999999998	с. Ленинское, ПУ-2		0101000020E610000027A1F48510946040D74CBED9E6F84740
33392	4	41	1696	45545	46248	\N	47.951406987054	с. Ленинское, Школьная, 10	Россия, Еврейская автономная область, Ленинский район, село Ленинское	0101000020E6100000A777F17EDC936040BE175FB4C7F94740
33390	4	41	1696	45545	46246	\N	47.944544999999998	с. Ленинское, Октябрьская, 6		0101000020E610000027A1F48510946040D74CBED9E6F84740
33391	4	41	1696	45545	46297	\N	47.944544999999998	с. Ленинское, Ленина, 11		0101000020E610000027A1F48510946040D74CBED9E6F84740
33394	4	41	1696	22542	46310	\N	47.986275999999997	станция Ленинск, Школьная, 1		0101000020E610000001309E41C3936040336ABE4A3EFE4740
33402	4	41	1696	22868	46309	\N	48.240017999999999	с. Лазарево, Ушакова, 2а		0101000020E61000001500E319348E6040C539EAE8B81E4840
33411	4	41	1696	46606	46305	\N	47.889688	с. Кукелево, Комсомольская, 1-а		0101000020E6100000CA181F66AF90604063D2DF4BE1F14740
33407	4	41	1696	46518	46334	\N	47.855007999999998	с. Кирово, Кооперативная, 1		0101000020E6100000C80A7E1BE2816040C0E8F2E670ED4740
33408	4	41	1696	46549	46333	\N	47.779685000000001	с. Квашнино, Центральная, 3		0101000020E6100000B090B932288460404417D4B7CCE34740
33395	4	41	1696	46246	46360	\N	48.008848999999998	с. Калинино, Школьная, 5		0101000020E61000003C2D3F701593604018CDCAF621014840
33409	4	41	1696	23200	46303	\N	47.797404999999998	с. Дежнево, Пограничная, 20		0101000020E61000004696CCB13C8660405C55F65D11E64740
33400	4	41	1696	46383	46312	\N	48.136164999999998	с. Горное, Центральная, 8		0101000020E610000003B68311FB8D60400FEECEDA6D114840
33397	4	41	1696	46309	46317	\N	48.042884000000001	с. Воскресеновка, Советская, 11-а		0101000020E61000008BE07F2B599C6040C6C210397D054840
33406	4	41	1696	23078	46341	\N	47.782040000000002	с. Венцелево, Центральная, 9		0101000020E61000002619390BFB7D6040F91400E319E44740
33404	4	41	1696	22975	46279	\N	47.974738000000002	с. Биджан, Пионерская, 32		0101000020E61000006ADB300A027E60409015FC36C4FC4740
33418	4	41	1696	23638	46354	\N	47.940392000000003	с. Башмак, ул.Новая д.20		0101000020E6100000ACCABE2B02816040C4B5DAC35EF84740
33416	4	41	1696	22742	\N	\N	48.124491999999996	Ленинский район, Бабстово, ФГОУ СПО БХСТ		0101000020E6100000A31D37FC6E8F60408B4E965AEF0F4840
33399	4	41	1696	22742	46252	\N	48.124491999999996	с. Бабстово, Ленина, 14		0101000020E6100000A31D37FC6E8F60408B4E965AEF0F4840
33379	4	41	1668	45900	46349	\N	48.319311094511299	с. Русская Поляна, Школьная, 1-2	Россия, Еврейская автономная область, Биробиджанский район, село Русская Поляна	0101000020E6100000988922A46EA760406420CF2EDF284840
33388	4	41	1668	55696	46352	\N	48.845496522416397	с. Раздольная, Набережная, 1а	Россия, Еврейская автономная область, Биробиджанский район	0101000020E61000009AED0A7D309B6040DDEEE53E396C4840
33371	4	41	1668	21451	46278	\N	48.742424	с. Птичник, Переселенческая, 8а		0101000020E6100000BABBCE867C9E6040FCE1E7BF075F4840
33372	4	41	1668	21451	46291	\N	48.742424	с. Птичник, ул. 40 лет Победы, 2		0101000020E6100000BABBCE867C9E6040FCE1E7BF075F4840
33375	4	41	1668	45819	46340	\N	48.615398999999996	с. Пронькино, Юбилейная, 19		0101000020E6100000486AA164729F6040DC7EF964C54E4840
33378	4	41	1668	45876	46315	\N	48.401750999999997	с. Петровка, Садовая, 6		0101000020E61000002ECA6C90C9A560405111A7936C334840
33386	4	41	1668	22178	46331	\N	48.407187999999998	с. Опытное Поле, Дорожная, 4		0101000020E61000002041F1634C9660406DA983BC1E344840
33377	4	41	1668	21755	46256	\N	48.489485999999999	с. Найфельд, Школьная, 11		0101000020E6100000A453573E4BA36040C8EC2C7AA73E4840
33382	4	41	1668	22005	46346	\N	48.296340000000001	с. Надеждинское, Центральная, 34		0101000020E61000003E5E488707A66040923F1878EE254840
33387	4	41	1668	46080	46326	\N	48.281401000000002	с. Красивое, Юбилейная, 11		0101000020E6100000E8BB5B5922916040E607AEF204244840
33389	4	41	1668	46112	46351	\N	48.879745999999997	с. Кирга, Центральная, 13		0101000020E610000049F25CDF879B6040B66455849B704840
33380	4	41	1668	45939	46339	\N	48.461565459889201	с. Казанка, Школьная, 22	Россия, Еврейская автономная область, Биробиджанский район, село Казанка	0101000020E61000003ECE3461FBA1604037FDD98F143B4840
33322	4	41	1668	62080	81111	\N	48.586505122129303	село Заречное, Центральная, 13		0101000020E61000001421753BFB97604062F88898124B4840
33376	4	41	1668	21685	46329	\N	48.569896	с. Желтый Яр, Центральная, 12		0101000020E6100000556D37C1B7A16040840F255AF2484840
33381	4	41	1668	45941	46296	\N	48.395313999999999	с. Дубовое, 40 лет Победы, 12		0101000020E610000040170D198FA3604052D32EA699324840
33383	4	41	1668	45985	46342	\N	48.204858999999999	с. Головино, пер. Юбилейный, 4		0101000020E61000002F3201BF46A6604048A5D8D1381A4840
33374	4	41	1668	21530	46298	\N	48.687472999999997	с. Валдгейм, пер. Молодежный, 9		0101000020E61000007B134372329F604006F1811DFF574840
33373	4	41	1668	21530	46338	\N	48.687472999999997	с. Валдгейм, Центральная, 35		0101000020E61000007B134372329F604006F1811DFF574840
33385	4	41	1668	22120	46300	\N	48.420195	с. Бирофельд, Центральная, 47		0101000020E6100000B96DDFA37E996040AB7823F3C8354840
33384	4	41	1668	46018	46316	\N	48.386189999999999	с. Алексеевка, Советская, 9а		0101000020E6100000C07B478D899A6040680586AC6E314840
17197	4	38	\N	3781	46775	\N	48.976298999999997	Амурская область, Архаринский район, село Ядрино, ул. Центральная, д. 26		0101000020E6100000A59F7076EB6060400A0F9A5DF77C4840
17909	4	38	\N	6039	46471	\N	51.998970999999997	Амурская область, город Шимановск, микрорайон 2, корпус № 2		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17908	4	38	\N	6039	46423	\N	51.998970999999997	Амурская область, город Шимановск, микрорайон 1, корпус № 4		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17907	4	38	\N	6039	46420	\N	51.998970999999997	Амурская область, город Шимановск, ул. Пограничная, д. 25а		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17910	4	38	\N	6039	46422	\N	51.998970999999997	Амурская область, город Шимановск, ул. Плеханова, д. 3		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17901	4	38	\N	6039	46524	\N	51.998970999999997	Амурская область, город Шимановск, ул. Первомайская, д. 9		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17900	4	38	\N	6039	46523	\N	51.998970999999997	Амурская область, город Шимановск, ул. Некрасова, д. 58		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17905	4	38	\N	6039	46419	\N	51.998970999999997	Амурская область, город Шимановск, ул. Ленина, д. 33		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17902	4	38	\N	6039	46419	\N	51.998970999999997	Амурская область, город Шимановск, ул. Ленина, д. 26		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17904	4	38	\N	6039	46550	\N	51.998970999999997	Амурская область, город Шимановск, ул. Красноармейская, д. 67		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17899	4	38	\N	6039	46474	\N	51.998970999999997	Амурская область, город Шимановск, ул. Гайдара, д. 41		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17906	4	38	\N	6039	46468	\N	51.998970999999997	Амурская область, город Шимановск, ул. Ворошилова, д. 54		0101000020E610000060EAE74D45EB5F4082531F48DEFF4940
17640	4	38	\N	55748	46764	\N	50.852894999999997	Амурская область, Ромненский район, с. Чергали, Школьная, 3		0101000020E610000068041BD7BF2C604001F6D1A92B6D4940
17519	4	38	\N	55733	46659	\N	52.782750999999998	Амурская область, Магдагачинский район, поселок городского типа Ушумун, пер. Школьный, 13		0101000020E61000005376FA415DA25F40A5F44C2F31644A40
94952	4	38	\N	3466	\N	\N	55.155549595561801	"Амурская область,Тындинский район, Олекминский сельсовет, ООО ""Олекминский рудник"", учебный класс"	Россия, Амурская область, городской округ Тында	0101000020E6100000FFCBB568012F5F404772F90FE9934B40
17866	4	38	\N	3466	46466	\N	55.139327677346003	Амурская область, город Тында, Школьная, 5	Россия, Амурская область, Тында	0101000020E610000060E97C78962F5F4063B5F97FD5914B40
17834	4	38	\N	3466	46466	\N	55.154370043049099	Амурская область, Тындинский район, Лопчинский сельсовет, Школьная,1	Россия, Амурская область, городской округ Тында	0101000020E6100000EA5910CAFB2E5F40E4BD6A65C2934B40
17856	4	38	\N	3466	46820	\N	55.140019000000002	Амурская область, город Тында, Чкалова, 3		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17851	4	38	\N	3466	46819	\N	55.140019000000002	Амурская область, город Тында, Хвойная, 1		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17873	4	38	\N	3466	46522	\N	55.140019000000002	Амурская область, город Тында, Фестивальная, 13		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17859	4	38	\N	3466	46416	\N	55.140019000000002	Амурская область, город Тында, Спортивная, 20/а	Россия, Амурская область, Тында	0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17848	4	38	\N	3466	46561	\N	55.155353005909198	Амурская область, Тындинский район, Юкталинский сельсовет, Сосновая,3	Россия, Амурская область, городской округ Тында	0101000020E610000013D6C6D8092F5F40F12A6B9BE2934B40
17855	4	38	\N	3466	46593	\N	55.140019000000002	Амурская область, город Тында, Советская, 57		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17846	4	38	\N	3466	46892	\N	55.150769733841997	Амурская область, Тындинский район, Хорогочинский сельсовет, Свердловская, ТОЦ	Россия, Амурская область, Тында	0101000020E61000005854C4E9242F5F40E59B6D6E4C934B40
17860	4	38	\N	3466	47143	\N	55.140019000000002	Амурская область, город Тында, Радистов, 8		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17862	4	38	\N	3466	46418	\N	55.151912529456801	Амурская область, город Тында, Профсоюзная, 5	Россия, Амурская область, Тында	0101000020E61000005E81E849992F5F402B6B9BE271934B40
17861	4	38	\N	3466	46418	\N	55.140019000000002	Амурская область, город Тында, Профсоюзная, 3		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17858	4	38	\N	3466	46681	\N	55.140019000000002	Амурская область, город Тында, Победы,1		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17852	4	38	\N	3466	46646	\N	55.140019000000002	Амурская область, город Тында, Первомайская, 36		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17867	4	38	\N	3466	46545	\N	55.140019000000002	Амурская область, город Тында, Октябрьская, 16		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17868	4	38	\N	3466	46469	\N	55.140019000000002	Амурская область, город Тында, Московский Бульвар, 13		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17831	4	38	\N	3466	46460	\N	55.155479042258399	Амурская область, Тындинский район, Дипкунский сельсовет, Мира, КОЦ	Россия, Амурская область, Тында	0101000020E6100000B62C5F97E12F5F407E1B62BCE6934B40
17829	4	38	\N	3466	46460	\N	55.1605623029022	Амурская область, Тындинский район, Беленький сельсовет, Мира, ТОЦ	Россия, Амурская область, Тында	0101000020E6100000FFCBB568012F5F407C7DAD4B8D944B40
17854	4	38	\N	3466	46592	\N	55.140019000000002	Амурская область, город Тында, Летная, 9		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17872	4	38	\N	3466	46534	\N	55.140019000000002	Амурская область, город Тында, Лесная, 4		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17830	4	38	\N	3466	46534	\N	53.880628999999999	Амурская область, Тындинский район, Восточный сельсовет, Лесная, 1		0101000020E61000005E81E84999F45E4060747973B8F04A40
17845	4	38	\N	3466	46655	\N	55.1540781252721	Амурская область, Тындинский район, Урканский сельсовет, Ленинская,1	Россия, Амурская область, городской округ Тында	0101000020E610000087BF266BD42E5F403C84F1D3B8934B40
17847	4	38	\N	3466	46695	\N	55.159852480928102	Амурская область, Тындинский район, Чильчинский сельсовет, Ленина,3	Россия, Амурская область, Тында	0101000020E610000074081C09342F5F40A019C40776944B40
17865	4	38	\N	3466	46520	\N	55.140019000000002	Амурская область, город Тында, Красная Пресня, 62		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17863	4	38	\N	3466	46520	\N	55.140019000000002	Амурская область, город Тында, Красная Пресня, 27		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17874	4	38	\N	3466	46547	\N	55.140019000000002	Амурская область, город Тында, Кирова, 3		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17875	4	38	\N	3466	46526	\N	55.140019000000002	Амурская область, город Тында, Киевкая, 5		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17835	4	38	\N	3466	46658	\N	55.1532887558024	Амурская область, Тындинский район, Моготский сельсовет, Железнодорожная, 9	Россия, Амурская область, городской округ Тында	0101000020E61000003997E2AAB22E5F4014EB54F99E934B40
17876	4	38	\N	3466	46821	\N	55.140019000000002	Амурская область, город Тында, Дружная, 1-а		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17850	4	38	\N	3466	46733	\N	55.139327677346003	Амурская область, город Тында, Геологов, 1	Россия, Амурская область, Тында	0101000020E6100000D63A71395E2F5F4063B5F97FD5914B40
17870	4	38	\N	3466	46620	\N	55.139917681346901	Амурская область, город Тында, Амурская, 20-а	Россия, Амурская область, Тында	0101000020E61000004B77D7D9902F5F40950F41D5E8914B40
17853	4	38	\N	3466	46647	\N	55.140019000000002	Амурская область, город Тында, Алтайская, 19		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17871	4	38	\N	3466	46680	\N	55.140019000000002	Амурская область, город Тында, 8-е Марта, 12		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17843	4	38	\N	3466	46633	\N	55.155257686454902	Амурская область, Тындинский район, Олекминский сельсовет, 70 лет Октября, 11	Россия, Амурская область, городской округ Тында	0101000020E6100000FE63213A042F5F40A038807EDF934B40
17864	4	38	\N	3466	46473	\N	55.140019000000002	Амурская область, город Тында, Красная Пресня, 37		0101000020E6100000C23060C9552F5F40C9E88024EC914B40
17517	4	38	\N	55729	46615	\N	52.634307999999997	Амурская область, Магдагачинский район, поселок городского типа Сиваки, Амурская, 2		0101000020E61000005456D3F544B05F40ABCB290131514A40
17701	4	38	\N	7235	46408	\N	51.395165335839202	Амурская область, город Свободный, Чубаровых, 17	Россия, Амурская область, Свободный	0101000020E6100000A0A9D72D020460400DC347C494B24940
17713	4	38	\N	7235	46543	\N	51.392803000000001	Амурская область, город Свободный, Управленческая, 50		0101000020E61000009EEE3CF11C046040A662635E47B24940
17722	4	38	\N	7235	46532	\N	51.392803000000001	Амурская область, город Свободный, Театральный, 2		0101000020E61000009EEE3CF11C046040A662635E47B24940
17704	4	38	\N	7235	46644	\N	51.383243665322802	Амурская область, город Свободный, Михайло-Чесноковская, 4/1	Россия, Амурская область, городской округ Свободный	0101000020E6100000B26664903B046040B131AF230EB14940
17717	4	38	\N	7235	46517	\N	51.392803000000001	Амурская область, город Свободный, Механический, 1		0101000020E61000009EEE3CF11C046040A662635E47B24940
17718	4	38	\N	7235	46409	\N	51.392803000000001	Амурская область, город Свободный, Матросова, 50		0101000020E61000009EEE3CF11C046040A662635E47B24940
17702	4	38	\N	7235	46512	\N	51.400239153561301	Амурская область, город Свободный, Малиновского, 71	Россия, Амурская область, городской округ Свободный	0101000020E61000003FFF3D786D036040B8CA13083BB34940
17703	4	38	\N	7235	46406	\N	51.392803000000001	Амурская область, город Свободный, Лермонтова, 44		0101000020E61000009EEE3CF11C046040A662635E47B24940
17710	4	38	\N	7235	46413	\N	51.392803000000001	Амурская область, город Свободный, Ленина, 39		0101000020E61000009EEE3CF11C046040A662635E47B24940
17708	4	38	\N	7235	46413	\N	51.392803000000001	Амурская область, город Свободный, Ленина, 44		0101000020E61000009EEE3CF11C046040A662635E47B24940
17707	4	38	\N	7235	46413	\N	51.392803000000001	Амурская область, город Свободный, Ленина, 84		0101000020E61000009EEE3CF11C046040A662635E47B24940
17706	4	38	\N	7235	46413	\N	51.392803000000001	Амурская область, город Свободный, Ленина, 95		0101000020E61000009EEE3CF11C046040A662635E47B24940
17711	4	38	\N	7235	46515	\N	51.392803000000001	Амурская область, город Свободный, Кручинина, 6		0101000020E61000009EEE3CF11C046040A662635E47B24940
17714	4	38	\N	7235	46514	\N	51.392803000000001	Амурская область, город Свободный, Котовского, 54		0101000020E61000009EEE3CF11C046040A662635E47B24940
17716	4	38	\N	7235	46516	\N	51.392803000000001	Амурская область, город Свободный, Комарова, 32		0101000020E61000009EEE3CF11C046040A662635E47B24940
17723	4	38	\N	7235	46535	\N	51.392803000000001	Амурская область, город Свободный, Кирпичный, 96		0101000020E61000009EEE3CF11C046040A662635E47B24940
17720	4	38	\N	7235	46463	\N	51.396292899780001	Амурская область, город Свободный, Кирова, 95	Россия, Амурская область, Свободный	0101000020E6100000D95F764F1E0460401E51A1BAB9B24940
17721	4	38	\N	7235	46464	\N	51.396453978062297	Амурская область, город Свободный, Каменчука, 27	Россия, Амурская область, Свободный	0101000020E610000081B22957F8036040272F3201BFB24940
17700	4	38	\N	7235	46511	\N	51.392803000000001	Амурская область, город Свободный, Бузулинское шоссе, 1		0101000020E61000009EEE3CF11C046040A662635E47B24940
17709	4	38	\N	7235	46513	\N	51.392803000000001	Амурская область, город Свободный, 50 лет Октября, 31		0101000020E61000009EEE3CF11C046040A662635E47B24940
17715	4	38	\N	7235	46407	\N	51.394735780322399	Амурская область, город Свободный, 40 лет Октября, 75	Россия, Амурская область, Свободный	0101000020E6100000A92EE06506046040E54691B586B24940
17712	4	38	\N	7235	46407	\N	51.392803000000001	Амурская область, город Свободный, 40 лет Октября, 92		0101000020E61000009EEE3CF11C046040A662635E47B24940
17705	4	38	\N	7235	46533	\N	51.392803000000001	Амурская область, город Свободный, 50 лет Октября, 84/1		0101000020E61000009EEE3CF11C046040A662635E47B24940
17638	4	38	\N	8466	46461	\N	49.783814	Амурская область, город Райчихинск, Шахтерская, 4		0101000020E61000008908FF22682D6040CF12640454E44840
17636	4	38	\N	8466	46559	\N	49.783814	Амурская область, город Райчихинск, Северная, 54		0101000020E61000008908FF22682D6040CF12640454E44840
17634	4	38	\N	8466	46459	\N	49.783814	Амурская область, город Райчихинск, Пономаренко, 13		0101000020E61000008908FF22682D6040CF12640454E44840
17633	4	38	\N	8466	46459	\N	49.783814	Амурская область, город Райчихинск, Пономаренко, 85		0101000020E61000008908FF22682D6040CF12640454E44840
17632	4	38	\N	8466	46402	\N	49.783814	Амурская область, город Райчихинск, Победы, 53		0101000020E61000008908FF22682D6040CF12640454E44840
17631	4	38	\N	8466	46402	\N	49.783814	Амурская область, город Райчихинск, Победы, 62		0101000020E61000008908FF22682D6040CF12640454E44840
17628	4	38	\N	8466	46402	\N	49.783814	Амурская область, город Райчихинск, Победы, 11		0101000020E61000008908FF22682D6040CF12640454E44840
17629	4	38	\N	8466	46405	\N	49.783814	Амурская область, город Райчихинск, Пионерская, 31		0101000020E61000008908FF22682D6040CF12640454E44840
17630	4	38	\N	8466	46531	\N	49.783814	Амурская область, город Райчихинск, Музыкальная, 31		0101000020E61000008908FF22682D6040CF12640454E44840
17637	4	38	\N	8466	46507	\N	49.783814	Амурская область, город Райчихинск, Ворошилова, 4		0101000020E61000008908FF22682D6040CF12640454E44840
17635	4	38	\N	8466	46505	\N	49.783814	Амурская область, город Райчихинск, Апанасенко, 5		0101000020E61000008908FF22682D6040CF12640454E44840
17913	4	38	\N	55717	46608	\N	49.746794843715001	Амурская область, Поселок городского типа Прогресс, ул.Набережная, 3	Россия, Амурская область, городской округ Райчихинск, поселок городского типа Прогресс	0101000020E61000004D4EED0C533560407DE882FA96DF4840
17916	4	38	\N	55717	46536	\N	49.747354000000001	Амурская область, Поселок городского типа Прогресс, ул.Ленинградская, 40		0101000020E6100000263ACB2C423560407444BE4BA9DF4840
17920	4	38	\N	55737	46689	\N	49.781884218214699	Амурская область, Поселок городского типа Новорайчихинск, ул.Поярковская, 6	Россия, Амурская область, городской округ Райчихинск, поселок городского типа Новорайчихинск	0101000020E61000007D7A6CCB0033604001A260C614E44840
17510	4	38	\N	55701	46397	\N	53.452818999999998	Амурская область, Магдагачинский район, поселок городского типа Магдагачи, Калинина, 26		0101000020E6100000373811FDDA735F40F30016F9F5B94A40
17475	4	38	\N	16732	46672	\N	53.739061	Амурская область, город Зея, мкр.Солнечный, 3б		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17468	4	38	\N	16732	46499	\N	53.739061	Амурская область, город Зея, мкр.Светлый, 38		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17467	4	38	\N	16732	46499	\N	53.758275831489897	Амурская область, город Зея, мкр.Светлый, 48	Россия, Амурская область, Зея	0101000020E61000003FFD67CD8FD25F40BDAB1E300FE14A40
17466	4	38	\N	16732	46499	\N	53.739061	Амурская область, город Зея, мкр.Светлый, 30		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17464	4	38	\N	16732	46367	\N	53.739061	Амурская область, город Зея, ул.Шохина, 7		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17470	4	38	\N	16732	46452	\N	53.739061	Амурская область, город Зея, ул.Народная, 26		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17469	4	38	\N	16732	46452	\N	53.739061	Амурская область, город Зея, ул.Народная, 21		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17471	4	38	\N	16732	46498	\N	53.739061	Амурская область, город Зея, ул.Мухина, 142		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17473	4	38	\N	16732	46566	\N	53.739061	Амурская область, город Зея, ул.Ленина, 231		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17472	4	38	\N	16732	46566	\N	53.739061	Амурская область, город Зея, ул.Ленина, 161		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17474	4	38	\N	16732	46451	\N	53.739061	Амурская область, город Зея, ул.Б.Хмельницкого, 94а		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17465	4	38	\N	16732	46509	\N	53.739061	Амурская область, город Зея, пр.40-летия Победы, 67		0101000020E61000005551BCCADACE5F40E15F048D99DE4A40
17781	4	38	\N	55722	46582	\N	53.958351	Амурская область, Сковородинский район, поселок городского типа Ерофей Павлович, Партизанская,34, администрация поселка		0101000020E61000007B14AE47E17C5E40618BDD3EABFA4A40
17398	4	38	\N	55725	46610	\N	49.808638000000002	поселок городского типа Бурея, Октбярьская, 85		0101000020E6100000C9AEB48CD4396040C426327381E74840
17395	4	38	\N	55725	46594	\N	49.808638000000002	поселок городского типа Бурея, Амурская, 11		0101000020E6100000C9AEB48CD4396040C426327381E74840
17356	4	38	\N	55698	\N	\N	50.366271451526302	Амурская область, город Благовещенск, п.Моховая падь		0101000020E610000086AFAF75A9E75F40923CD7F7E12E4940
17358	4	38	\N	55698	46493	\N	50.296817675740201	Амурская область, город Благовещенск, пер.Южный, 2	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000B4E908E066E15F409C6ED921FE254940
17291	4	38	\N	55698	46421	\N	50.310863068382297	Амурская область, город Благовещенск, Строителей, 107	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000E9B81AD995E35F40AA44D95BCA274940
17293	4	38	\N	55698	46500	\N	50.350887407697599	Амурская область, город Благовещенск, с.Садовое, Садовая, 1		0101000020E610000059349D9D0CE55F40B8CB7EDDE92C4940
17368	4	38	\N	55698	46387	\N	50.297477435269798	Амурская область, город Благовещенск, Октябрьская, 50	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000DBFD2AC077E15F40F627F1B913264940
17339	4	38	\N	55698	46487	\N	50.296597753852602	Амурская область, город Благовещенск, Ленина, 180, корпус 8	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000C85BAE7E6CE15F408E075BECF6254940
17320	4	38	\N	55698	46385	\N	50.2948383419508	Амурская область, город Благовещенск, Кантемирова, 6/2		0101000020E6100000EF6FD05E7DE15F401CCF6740BD254940
17321	4	38	\N	55698	46491	\N	50.296377830942703	Амурская область, город Благовещенск, Игнатьевское шоссе, 21	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000DDCD531D72E15F407FA0DCB6EF254940
17377	4	38	\N	55698	46391	\N	50.297257516448902	Амурская область, город Благовещенск, Зе, Зейская 171/179	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E61000002BF697DD93E15F40B83CD68C0C264940
17319	4	38	\N	55698	46440	\N	50.297257516448902	Амурская область, город Благовещенск, Дьяченко, 4	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E61000001899805F23E15F40B83CD68C0C264940
17370	4	38	\N	55698	46388	\N	50.296817675740201	Амурская область, город Благовещенск, Горького, 95		0101000020E6100000EF6FD05E7DE15F409C6ED921FE254940
17369	4	38	\N	55698	46388	\N	50.293243818404001	Амурская область, город Благовещенск, Горького, 129		0101000020E6100000C746205ED7E15F40C6DFF60489254940
17247	4	38	\N	55699	46555	\N	50.902448999999997	Амурская область, город Белогорск, Ломоносова, 18		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17257	4	38	\N	55699	46782	\N	50.902448999999997	Амурская область, город Белогорск, Авиационная, 56		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17242	4	38	\N	55699	46389	\N	50.902448999999997	Амурская область, город Белогорск, 50 лет ВЛКСМ, 37		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17241	4	38	\N	55699	46389	\N	50.901797536311697	Амурская область, город Белогорск, 50 лет ВЛКСМ, 24		0101000020E6100000103FFF3DF80F604092CCEA1D6E734940
17176	4	38	\N	55741	46710	\N	49.422016999999997	Амурская область, Архаринский район, поселок городского типа Архара, ул. Калинина, д.2		0101000020E61000008143A852B342604092AD2EA704B64840
17914	4	38	881	6663	46472	\N	49.747354000000001	Амурская область, Поселок городского типа Прогресс, ул.Ленинградская, 9		0101000020E6100000263ACB2C423560407444BE4BA9DF4840
17918	4	38	881	6663	46684	\N	49.747354000000001	"Амурская область, Поселок городского типа Прогресс, ул.Бурейская, 1""а"""		0101000020E6100000263ACB2C423560407444BE4BA9DF4840
17911	4	38	881	55704	46826	\N	49.747354000000001	Амурская область, Поселок городского типа Прогресс, ул.Тишкина, 114		0101000020E6100000263ACB2C423560407444BE4BA9DF4840
17915	4	38	881	55704	46552	\N	49.747354000000001	Амурская область, Поселок городского типа Прогресс, ул.Советская, 16		0101000020E6100000263ACB2C423560407444BE4BA9DF4840
17917	4	38	881	55704	46424	\N	49.747354000000001	Амурская область, Поселок городского типа Прогресс, ул.Крымская, 10		0101000020E6100000263ACB2C423560407444BE4BA9DF4840
17921	4	38	881	55735	46683	\N	49.782662000000002	Амурская область, Поселок городского типа Новорайчихинск, ул.Светлая, 14		0101000020E6100000AD18AE0E0033604036E9B6442EE44840
17919	4	38	881	55735	46827	\N	49.782662000000002	Амурская область, Поселок городского типа Новорайчихинск, ул.Депутатская, 21		0101000020E6100000AD18AE0E0033604036E9B6442EE44840
17240	4	38	6892	40273	9697	\N	50.902448823803603	Амурская область, город Белогорск, 9 мая, 2	Россия, Амурская область, городской округ Белогорск	0101000020E6100000B75D68AED30F604069A7E67283734940
17898	4	38	709	5998	47055	\N	52.123495394292199	Амурская область, Шимановский район, Чагоянский с/с, Чагоян село, Советская, 20	Россия, Амурская область, Шимановский район, поселок Чагоян	0101000020E610000073F1B73DC1066040191C25AFCE0F4A40
17897	4	38	709	5943	47053	\N	51.876907000000003	Амурская область, Шимановский район, Ушаковский с/с, Ушаково село, Школьная, 1		0101000020E610000018946934B9A35F401651137D3EF04940
17896	4	38	709	5889	47187	\N	52.445940999999998	Амурская область, Шимановский район, Ураловский с/совет, Ураловка село, Октябрьская, 10,3		0101000020E610000093C5FD472604604007793D9814394A40
17895	4	38	709	5851	46824	\N	51.4687858713664	Амурская область, Шимановский район, Симоновский с/с, Симоново село, Советская, 3	Россия, Амурская область, Шимановский район, поселок Симоново	0101000020E61000004912842BA0BF5F404D69FD2D01BC4940
17894	4	38	709	5775	47150	\N	51.918404000000002	Амурская область, Шимановский район, Селетканский с/с, Селеткан село, Школьная, 1		0101000020E6100000A2D45E44DBF95F40FF4124438EF54940
17893	4	38	709	5743	46735	\N	51.964564000000003	Амурская область, Шимановский район, Своб-труд. с/с, Свободный Труд с, Центральная, 6		0101000020E61000008CBE823463D25F40117349D576FB4940
17892	4	38	709	5679	47152	\N	51.952325999999999	Амурская область, Шимановский район, Селетканский с/с, Светильное село, Советская, 1		0101000020E6100000293DD34B8CF55F40B49080D1E5F94940
17891	4	38	709	5630	46825	\N	51.647733000000002	Амурская область, Шимановский район, Саскалинский с/с, Саскаль село, Школьная, 32		0101000020E61000009D6516A1D8BA5F401EC539EAE8D24940
17890	4	38	709	5543	46657	\N	52.053100999999998	Амурская область, Шимановский район, Петрушинский с/с, Петруши село, Советская, 33		0101000020E6100000460A65E1EBE95F4044317903CC064A40
17889	4	38	709	5544	47151	\N	51.849271000000002	Амурская область, Шимановский район, Н-Георгиев. с/с, Новогеоргиевка с, Советская, 24		0101000020E6100000CBF27519FEC65F407A3881E9B4EC4940
17888	4	38	709	5461	46742	\N	52.104945999999998	Амурская область, Шимановский район, Н-Воскр. с/с, Нововоскресеновка с, Советская, 1		0101000020E6100000228AC91B60A45F404AECDADE6E0D4A40
17887	4	38	709	5382	46682	\N	52.271344999999997	Амурская область, Шимановский район, Мухинский сельсовет, Мухино село, Калинина, 22		0101000020E61000003221E692AACD5F407077D66EBB224A40
17886	4	38	709	5373	46762	\N	52.021405999999999	Амурская область, Шимановский район, Малиновский с/с, Малиновка село, Советская, 18		0101000020E6100000C6A52A6D71F15F4016F88A6EBD024A40
17885	4	38	709	5294	46822	\N	52.419530999999999	Амурская область, Шимановский район, Ураловский с/с, Кухтерин Луг село, Баргулинская, 11		0101000020E6100000B39597FC4F0360403F541A31B3354A40
17884	4	38	709	5232	46731	\N	52.306947000000001	Амурская область, Шимановский район, Мухинский с/с, Ключевое село, Мухина, 5А		0101000020E61000003E7958A835CE5F407B4D0F0A4A274A40
17883	4	38	709	5147	47063	\N	52.162747000000003	Амурская область, Шимановский район, Береинский с/с, Берея станция, им. Сергея Лазо, 7/2		0101000020E6100000882D3D9AEADD5F40D542C9E4D4144A40
17881	4	38	709	5069	47052	\N	52.139555000000001	Амурская область, Шимановский район, Петрушинский с/с, Базисное село, Школьная, 3		0101000020E6100000FE28EACC3DEB5F40247F30F0DC114A40
17880	4	38	709	4984	46786	\N	52.164045000000002	Амурская область, Шимановский район, Нововоскрес. с/с, Аносово село, Управленческая, 30А		0101000020E6100000649291B3B0A55F404209336DFF144A40
17878	4	38	709	4949	46823	\N	51.738481999999998	Амурская область, Шимановский район, Актайский с/с, Актай село, Трудовая, 30		0101000020E61000006B7F677BF4CF5F40A357039486DE4940
17844	4	38	419	61339	78612	\N	55.312530961427598	Амурская область, Тындинский район, Нюкжинский сельсовет, Зейская, 7	Россия, Амурская область, Тындинский район, поселок Усть-Уркима	0101000020E6100000D74D29AF95CA5E403BFE0B0401A84B40
17840	4	38	419	55720	46553	\N	54.2231418276222	Амурская область, Тындинский район, Соловьевский сельсовет, Школьная, 18		0101000020E61000008CBAD6DEA71B5F40992EC4EA8F1C4B40
17841	4	38	419	61333	78579	\N	55.021220531278203	Амурская область, Тындинский район, Тутаульский сельсовет, Подмосковная, 4	Россия, Амурская область, Тындинский район, поселок Тутаул	0101000020E6100000600322C495DD5F40847EA65EB7824B40
17839	4	38	419	55759	78599	\N	55.112178022263699	Амурская область, Тындинский район, Первомайский сельсовет, Центральная,16	Россия, Амурская область, Тындинский район, поселок Первомайское	0101000020E61000000D350A4966355F4054AA44D95B8E4B40
17838	4	38	419	55759	46850	\N	55.112320723989001	Амурская область, Тындинский район, Первомайский сельсовет, Полевая партия, 26	Россия, Амурская область, Тындинский район, поселок Первомайское	0101000020E610000094A5D6FB8D355F40B7D3D688608E4B40
17837	4	38	419	61297	78449	\N	54.432828293945697	Амурская область, Тындинский район, Муртыгитский сельсовет, Лесная,5	Россия, Амурская область, Тындинский район, поселок Муртыгит	0101000020E610000034DB15FA60F75E4084656CE866374B40
17836	4	38	419	61557	79382	\N	55.488667	Амурская область, Тындинский район, Маревский сельсовет, Тульская,2		0101000020E6100000A5164A26A7F95E4035D1E7A38CBE4B40
17833	4	38	419	61563	79393	\N	55.276001664506303	Амурская область, Тындинский район, Ларбинский сельсовет, Мира, 5		0101000020E6100000A35A441493D15E40B7D0950854A34B40
17832	4	38	419	61303	78476	\N	55.191053286765602	Амурская область, Тындинский район, Кувыктинский сельсовет, Первостроителей, 6	Россия, Амурская область, Тындинский район, поселок Кувыкта	0101000020E6100000CB64389ECF0D5F40BE66B96C74984B40
17849	4	38	419	61354	78686	\N	54.624463615678103	Амурская область, Тындинский район, Аносовский сельсовет, Мира, 3Б-3	Россия, Амурская область, Тындинский район, поселок Аносовский	0101000020E61000006A85E97B0DFE5E40C2C3B46FEE4F4B40
17813	4	38	243	1301	47031	\N	50.154176	село Чуевка, ул.Луговая, 24/1	Россия, Амурская область, Тамбовский район, поселок Чуевка	0101000020E61000007E39B35DA1066040FFE9060ABC134940
17817	4	38	243	47548	46667	\N	50.203721999999999	село Толстовка, ул.Пионерская, 9		0101000020E6100000C652245F09FC5F40E4BCFF8F131A4940
17802	4	38	243	47199	46538	\N	50.098833999999997	село Тамбовка, ул.Техническая, 48Б		0101000020E61000008D43FD2EEC016040CEDDAE97A60C4940
17801	4	38	243	47199	46417	\N	50.098833999999997	село Тамбовка, ул.Ленинская, 83		0101000020E61000008D43FD2EEC016040CEDDAE97A60C4940
17800	4	38	243	47199	46417	\N	50.098833999999997	село Тамбовка, ул.Ленинская, 98		0101000020E61000008D43FD2EEC016040CEDDAE97A60C4940
17807	4	38	243	962	47040	\N	49.966673	село Свободка, ул.Свободная, 8		0101000020E6100000868DB27E33FE5F408E76DCF0BBFB4840
17814	4	38	243	47493	46660	\N	50.156455000000001	село Садовое, ул.Юбилейная, 10		0101000020E610000030134548DDF75F40D925AAB706144940
17820	4	38	243	47598	47146	\N	50.005172999999999	село Рощино, ул.Озёрная, 9		0101000020E61000002B4B749659F95F403EE94482A9004940
17823	4	38	243	1865	46726	\N	49.816769999999998	село Резуновка, ул.Школьная, 6		0101000020E6100000CC7A319413F05F404D2D5BEB8BE84840
17819	4	38	243	55716	46530	\N	50.020043999999999	село Раздольное, ул.Ленина, 12	Россия, Амурская область, Тамбовский район, поселок Раздольное	0101000020E6100000AD174339D1F45F40923D42CD90024940
17804	4	38	243	47269	46816	\N	50.063710999999998	село Придорожное, ул.Ленина, 2		0101000020E610000078F01307500560409EB29AAE27084940
17805	4	38	243	55746	46753	\N	49.970044999999999	село Привольное, ул.Пионерская, 5	Россия, Амурская область, Тамбовский район, поселок Привольное	0101000020E61000000A83328DA6046040FC523F6F2AFC4840
17816	4	38	243	1478	46913	\N	50.203867000000002	село Орлецкое, ул.Школьная, 4		0101000020E6100000DDB419A7A1026040E8DD5850181A4940
17808	4	38	243	40510	10067	\N	50.000017674817002	село Новоалександровка, ул.Центральная, 33	Россия, Амурская область, Тамбовский район, поселок Новоалександровка	0101000020E61000002FA86F99D3086040A6B4FE9600004940
17828	4	38	243	55740	46699	\N	50.061387000000003	село Николаевка, ул.Амурская, 21	Россия, Амурская область, Тамбовский район, поселок Николаевка	0101000020E6100000C53C2B69C5EA5F4025B37A87DB074940
17812	4	38	243	46089	46780	\N	50.211719000000002	село Липовка, ул.Озёрная, 16/2		0101000020E6100000AABBB20B860560408E78B29B191B4940
17809	4	38	243	1058	47140	\N	50.055632000000003	село Лиманное, ул.Набережная, 4/2		0101000020E6100000A2410A9EC2096040384E0AF31E074940
17818	4	38	243	47558	46624	\N	50.083634000000004	село Лермонтовка, ул.Ленина, 61		0101000020E6100000F8E0B54B1BF75F40B66AD784B40A4940
17810	4	38	243	47418	47048	\N	50.224716000000001	село Лазаревка, ул.Центральная, 30		0101000020E6100000D314014EEF0A6040A8716F7EC31C4940
17826	4	38	243	2090	47051	\N	49.996324999999999	село Куропатино, пер.Школьный, 3		0101000020E61000001D03B2D7BBEA5F40F697DD9387FF4840
17824	4	38	243	40404	47047	\N	49.984192	село Красное, ул.Центральная, 1А		0101000020E6100000111AC1C6F5E05F400F7EE200FAFD4840
17803	4	38	243	55739	46691	\N	50.061156100658202	село Косицино, ул.Речная, 8	Россия, Амурская область, Тамбовский район, поселок Косицыно	0101000020E6100000E48233F8FB00604022FAB5F5D3074940
17825	4	38	243	1983	46810	\N	49.895802000000003	село Корфово, ул.Набережная, 4		0101000020E610000057276728EEE25F4080D8D2A3A9F24840
17811	4	38	243	1183	46401	\N	50.139547999999998	село Козьмодемьяновка, ул.Комсомольская, 54/2		0101000020E61000007B87DBA1E1076040711C78B5DC114940
17806	4	38	243	47311	46619	\N	50.018163000000001	село Жариково, пер.Школьный, 7		0101000020E610000001A4367172006040A67F492A53024940
17827	4	38	243	47726	47144	\N	49.951431999999997	село Духовское, ул.Центральная, 11		0101000020E610000008E3A7716FED5F40162F1686C8F94840
94309	4	38	243	1770	47066	\N	49.904291000000001	село Муравьевка, ул.Школьная, 19Амурская область, Тамбовский район, с. Гильчин, ул. Садовая, 24		0101000020E6100000D28DB0A888F75F409888B7CEBFF34840
94951	4	38	243	1770	47062	\N	49.904291000000001	Амурская область, Тамбовский район с. Гильчин, ул. Калинина, 16		0101000020E6100000D28DB0A888F75F409888B7CEBFF34840
17786	4	38	37	55757	\N	\N	54.062234254539099	Амурская область, Сковородинский район, Тахтамыгдинский сельсовет, ж.д.ст.Мадалан, МОУ ООШ	Россия, Амурская область, Сковородинский район	0101000020E61000005B069CA564DA5E408159A148F7074B40
17785	4	38	37	55712	\N	\N	54.044894999999997	Амурская область, Сковородинский район, поселок городского типа Уруша, поселковая библиотека		0101000020E610000095607138F3B85E4080608E1EBF054B40
17783	4	38	37	55712	\N	\N	54.044894999999997	Амурская область, Сковородинский район, поселок городского типа Уруша, МОУ СОШ		0101000020E610000095607138F3B85E4080608E1EBF054B40
17784	4	38	37	32076	46597	\N	54.044894999999997	Амурская область, Сковородинский район, поселок городского типа Уруша, Карьерская,58, МОУ ДОУ №6		0101000020E610000095607138F3B85E4080608E1EBF054B40
17787	4	38	37	32259	46621	\N	54.111058	Амурская область, Сковородинский район, Тахтамыгдинский сельсовет, с.Тахтамыгда, Якимаса, МОУ СОШ		0101000020E610000060234910AEE65E40C6FA0626370E4B40
17769	4	38	1808	55703	46412	\N	51.091546000000001	пгт Серышево, Советская, 44		0101000020E6100000FF93BF7B470C6040310A82C7B78B4940
17792	4	38	37	32462	46479	\N	53.690776	Амурская область, Сковородинский район, Талданский сельсовет, с.Талдан, Лисина, МОУ СОШ		0101000020E61000003A9677D503345F404C6E14596BD84A40
17794	4	38	37	175	\N	\N	53.685972	Амурская область, Сковородинский район, Джалиндинский сельсовет, п.Среднерейновский, библиотека		0101000020E61000008C868C47A9F55E4061FC34EECDD74A40
17788	4	38	37	32304	47179	\N	54.131141999999997	Амурская область, Сковородинский район, Солнечный сельсовет, п.Солнечный, Пионерская,13, МОУ СОШ	Россия, Амурская область, Сковородинский район, поселок Солнечный	0101000020E6100000A5129ED0EBEA5E40E690D442C9104B40
17777	4	38	37	45	46415	\N	53.983428000000004	Амурская область, Сковородинский район, город Сковородино, Победы,9, Центральная районная библиотека		0101000020E6100000F0DAA50D87FC5E4040FCFCF7E0FD4A40
17775	4	38	37	45	46415	\N	53.983428000000004	Амурская область, Сковородинский район, город Сковородино, Победы,28, МОУ ДОД СР центр внешкольной работы		0101000020E6100000F0DAA50D87FC5E4040FCFCF7E0FD4A40
17774	4	38	37	45	46414	\N	53.983428000000004	Амурская область, Сковородинский район, город Сковородино, Дзержинского,7, МОУ СОШ№3		0101000020E6100000F0DAA50D87FC5E4040FCFCF7E0FD4A40
17773	4	38	37	45	46675	\N	53.983428000000004	Амурская область, Сковородинский район, город Сковородино, Воровского,43, МОУ СОШ №2		0101000020E6100000F0DAA50D87FC5E4040FCFCF7E0FD4A40
17778	4	38	37	45	46645	\N	53.983428000000004	Амурская область, Сковородинский район, город Сковородино, Василевского,20, МОУ СОШ №1		0101000020E6100000F0DAA50D87FC5E4040FCFCF7E0FD4A40
17776	4	38	37	45	46540	\N	53.983428000000004	Амурская область, Сковородинский район, город Сковородино, 60 лет СССР,11, музыкальная школа		0101000020E6100000F0DAA50D87FC5E4040FCFCF7E0FD4A40
17507	4	38	37	18893	46998	\N	53.499122	с.Орловка, Амурская, 3		0101000020E6100000F31FD26F5FEC5E40685BCD3AE3BF4A40
17790	4	38	37	32378	\N	\N	53.982894000000002	Амурская область, Сковородинский район, Неверский сельсовет, с.Невер, клуб		0101000020E6100000B9382A3751095F40A2B77878CFFD4A40
17791	4	38	37	32378	46590	\N	53.9807828503507	"Амурская область, Сковородинский район, Неверский сельсовет, село Невер, Партизанская, 205, офис ИП ""Карапетян К.Г."""	Россия, Амурская область, Сковородинский район, поселок Невер	0101000020E6100000D4B5F63E55095F4084BC1E4C8AFD4A40
17793	4	38	37	2323	\N	\N	53.880628999999999	Амурская область, Сковородинский район, город Сковородино, п.Лесной, клуб	Россия, Амурская область, Сковородинский район, поселок Лесной	0101000020E61000005E81E84999F45E4060747973B8F04A40
17780	4	38	37	55710	46477	\N	53.958351	Амурская область, Сковородинский район, поселок городского типа Ерофей Павлович, Пушкина, СПОШ №50		0101000020E61000007B14AE47E17C5E40618BDD3EABFA4A40
17779	4	38	37	55710	46519	\N	53.958351	Амурская область, Сковородинский район, поселок городского типа Ерофей Павлович, Октябрьская,17, МОУ СОШ		0101000020E61000007B14AE47E17C5E40618BDD3EABFA4A40
17782	4	38	37	462	\N	\N	53.960831193711101	Амурская область, Сковородинский район, поселок городского типа Ерофей Павлович, ж.д.ст.Большая Омутная, МОУ НОШ	Россия, Амурская область, Сковородинский район, поселок городского типа Ерофей Павлович	0101000020E61000001AC39CA04D7C5E40D2FD9C82FCFA4A40
17799	4	38	37	462	46755	\N	53.958351	Амурская область, Сковородинский район, поселок городского типа Ерофей Павлович, с.Игнашино, Пионерская,3, МОУ ООШ		0101000020E61000007B14AE47E17C5E40618BDD3EABFA4A40
17797	4	38	37	229	\N	\N	53.480483999999997	"Амурская область, Сковородинский район, Джалиндинский сельсовет, с.джалинда, торговый центр ""Катюша"""		0101000020E61000004FB2D5E594F95E402920ED7F80BD4A40
17795	4	38	37	229	\N	\N	53.480483999999997	Амурская область, Сковородинский район, Джалиндинский сельсовет, с.Джалинда, администрация села		0101000020E61000004FB2D5E594F95E402920ED7F80BD4A40
17789	4	38	37	32334	46654	\N	54.117497	Амурская область, Сковородинский район, Солнечный сельсовет, п.Бам, Амурская,1, МОУ СОШ		0101000020E61000003048FAB48AEC5E40663046240A0F4B40
17798	4	38	37	404	\N	\N	53.385545999999998	Амурская область, Сковородинский район, Албазинский сельсовет, с.Албазино, администрация села	Россия, Амурская область, Сковородинский район, поселок Албазино	0101000020E61000004149810530055F40438D429259B14A40
17766	4	38	1808	46504	46837	\N	50.933396000000002	с.Широкий Лог, Октябрьская, 11		0101000020E6100000C1012D5D41226040CE1B278579774940
17764	4	38	1808	46454	46806	\N	51.057330999999998	с.Фроловка, Октябрьская, 33		0101000020E6100000DF3312A1111860400306499F56874940
17624	4	38	1808	55752	46809	\N	51.147314000000001	село Украинка, Советская, 47	Россия, Амурская область, Серышевский район, поселок городского типа Украинка	0101000020E61000002429E96168106040191F662FDB924940
17760	4	38	1808	30986	47160	\N	51.093305999999998	Ударное, Центральная, 5 а		0101000020E6100000B14F00C5480A6040A2427573F18B4940
17170	4	38	1808	45877	46618	\N	50.956542794791901	с.Томское (жилье), Украинская, 39	Россия, Амурская область, Серышевский район, поселок Томское	0101000020E61000004E4700370B0D6040DF1B4300707A4940
16818	4	38	1808	45877	46600	\N	50.958002999999998	Томское, Ленина, 31		0101000020E61000000BD3F71A020D6040253CA1D79F7A4940
17520	4	38	1808	46143	46722	\N	50.958638999999998	Тавричанка, Центральная, 57		0101000020E6100000A185048CAE0A6040C7D5C8AEB47A4940
17761	4	38	1808	46390	46836	\N	51.164793000000003	Сосновка, Центральная, 19		0101000020E6100000DAC69FA86C1860400CCEE0EF17954940
17768	4	38	1808	46552	47010	\N	51.010142000000002	Соколовка, Центральная, 26		0101000020E61000008672A25D85266040742843554C814940
17771	4	38	1808	55703	46542	\N	51.091546000000001	пгт Серышево, им.Святителя Иннокентия, б/н - гарнизонный Дом офицеров (ГДО		0101000020E6100000FF93BF7B470C6040310A82C7B78B4940
17772	4	38	1808	55703	46521	\N	51.091546000000001	пгтСерышево, Чехова, 3		0101000020E6100000FF93BF7B470C6040310A82C7B78B4940
17770	4	38	1808	55718	46539	\N	51.091546000000001	пгт Серышево, Горького, 1		0101000020E6100000FF93BF7B470C6040310A82C7B78B4940
17753	4	38	1808	46208	46737	\N	50.907862000000002	Рождественка, пер.Пионерский, 1		0101000020E6100000971B0C75D81B6040FDA36FD234744940
17759	4	38	1808	46357	46616	\N	51.06456	Поляна, Школьная, 4 а		0101000020E6100000C3B986191A0D60409C50888043884940
17754	4	38	1808	30677	47006	\N	50.911405999999999	Паруновка, Советская, 15		0101000020E6100000E275FD82DD16604068B0A9F3A8744940
17755	4	38	1808	46258	46808	\N	51.249465000000001	Озерное, пер.Релочный, 5		0101000020E61000005B94D92093086040923F1878EE9F4940
17728	4	38	1808	55773	47214	\N	51.219377999999999	с.Ново-Охочье, Центральная, 18	Россия, Амурская область, Серышевский район, поселок Новоохочье	0101000020E6100000349D9D0C0E1260401FBB0B94149C4940
17746	4	38	1808	30292	46866	\N	51.030216000000003	Милехино, Южная, 10		0101000020E61000001FA0FB72661E604071E82D1EDE834940
17748	4	38	1808	55772	47199	\N	51.054653000000002	Липовка, Серышевская, 19	Россия, Амурская область, Серышевский район, поселок Липовка	0101000020E6100000E92B4833960760406CD097DEFE864940
17749	4	38	1808	55758	46840	\N	51.264052999999997	Лиманное, Школьная, 25	Россия, Амурская область, Серышевский район, поселок Лиманное	0101000020E610000085CC9541B51A604091B41B7DCCA14940
17750	4	38	1808	46151	46835	\N	51.344524	Лермонтово, Ленина, 12 а		0101000020E61000005AB8ACC2E6156040F357C85C19AC4940
17751	4	38	1808	46157	47139	\N	50.984479999999998	Лебяжье, Иванова, 23		0101000020E61000009A417C60C704604075C8CD70037E4940
17744	4	38	1808	46016	47168	\N	51.228566999999998	Ключики, Центральная, 7а	Россия, Амурская область, Серышевский район, поселок Ключики	0101000020E6100000B20E4757E9066040F0F8F6AE419D4940
17747	4	38	1808	46082	46730	\N	51.068804999999998	Казанка, Кирова, 16		0101000020E610000065C74620DE01604090662C9ACE884940
17757	4	38	1808	46320	47009	\N	51.214829999999999	Добрянка, Центральная, 51		0101000020E6100000C6E061DAB70C60408F19A88C7F9B4940
17763	4	38	1808	31133	47007	\N	51.161465999999997	Державинка, Центральная, 26		0101000020E610000033A9A10D401B60403DB5FAEAAA944940
17745	4	38	1808	30213	46732	\N	51.081401999999997	Водораздельное, Переселенческая, 6		0101000020E6100000857B65DEAA1D60401CEA77616B8A4940
17670	4	38	1808	26814	47124	\N	51.190292999999997	с.Верное, Партизанская, 21		0101000020E6100000813E91274916604030D461855B984940
16753	4	38	1808	55777	47224	\N	51.307882415068001	Введеново, Центральная, 8	Россия, Амурская область, Серышевский район, поселок Введеновка	0101000020E610000088F19A57F5066040778368AD68A74940
17236	4	38	1808	49413	46670	\N	50.955530000000003	Бочкаревка, Школьная, 14		0101000020E6100000111C9771530E6040672C9ACE4E7A4940
17765	4	38	1808	31240	46744	\N	51.046681	с.Борисполь, Советская, 8		0101000020E61000001BF16437331260401B2C9CA4F9854940
17743	4	38	1808	30125	46591	\N	51.181467318352198	Большая Сазанка, Школьная, б/н - Дом культуры	Россия, Амурская область, Серышевский район, поселок Большая Сазанка	0101000020E6100000FA9AE5B2D1046040D026874F3A974940
17756	4	38	1808	46286	46738	\N	51.131163000000001	Белоногово, Колхозная, 7		0101000020E6100000DD3F16A2430B6040FEB8FDF2C9904940
17421	4	38	1808	48724	46956	\N	50.927498	Белогорка, Центральная, 45		0101000020E610000017D34CF73A1360407E8D2441B8764940
17742	4	38	1808	55726	46596	\N	51.275874999999999	ст.Арга, Серышевская, 31		0101000020E61000008C118942CB0760405A643BDF4FA34940
17762	4	38	1808	31114	47175	\N	51.177765000000001	Автономовка, пер.Школьный, 2		0101000020E6100000C217265385206040CDAFE600C1964940
17729	4	38	1025	55724	46589	\N	53.070154000000002	Амурская область, Селемджинский район, поселок городского типа Экимчан, Центральная, 36		0101000020E61000005DFA97A4329E604080D767CEFA884A40
17724	4	38	1025	29490	46694	\N	53.0703119296168	Амурская область, Селемджинский район, Златоустовский сельсовет, Советская, 26	Россия, Амурская область, Селемджинский район, поселок городского типа Экимчан	0101000020E610000070EF1AF4259E60401842CEFBFF884A40
17737	4	38	1025	29755	47195	\N	52.449294000000002	Амурская область, Селемджинский район, поселок городского типа Февральск, Звездная, 1		0101000020E6100000F0BE2A17AA5B6040FF243E7782394A40
17736	4	38	1025	55751	46807	\N	52.449294000000002	Амурская область, Селемджинский район, поселок городского типа Февральск, Юбилейная, 1		0101000020E6100000F0BE2A17AA5B6040FF243E7782394A40
17735	4	38	1025	55702	46697	\N	52.449294000000002	Амурская область, Селемджинский район, поселок городского типа Февральск, с. Февральское, Центральная, 29		0101000020E6100000F0BE2A17AA5B6040FF243E7782394A40
17738	4	38	1025	55702	46537	\N	52.449294000000002	Амурская область, Селемджинский район, поселок городского типа Февральск, Магистральная, 3		0101000020E6100000F0BE2A17AA5B6040FF243E7782394A40
17739	4	38	1025	55702	46410	\N	52.449294000000002	Амурская область, Селемджинский район, поселок городского типа Февральск, Ленина, 4		0101000020E6100000F0BE2A17AA5B6040FF243E7782394A40
17730	4	38	1025	55734	46661	\N	53.134988	Амурская область, Селемджинский район, поселок городского типа Токур, Ворожейкина, 19		0101000020E6100000B7B3AF3C489C60401DAD6A4947914A40
17734	4	38	1025	29693	46613	\N	52.790882000000003	Амурская область, Селемджинский район, Стойбинский сельсовет, с. Стойба, Майская, 19		0101000020E6100000DD240681957660405F7F129F3B654A40
17733	4	38	1025	55731	\N	\N	52.572610449834301	"Амурская область, Селемджинский район, ОАО ""Маломырский рудник"""	Россия, Амурская область, Селемджинский район, поселок Селемджинск	0101000020E610000029983105EB63604068AED3484B494A40
17725	4	38	1025	29316	\N	\N	52.884099999999997	Амурская область, Селемджинский район, Златоустовский сельсовет, п. Ольгинск	Россия, Амурская область, Селемджинский район, поселок Ольгинск	0101000020E61000002448A5D851AD6040613255302A714A40
17731	4	38	1025	29582	47226	\N	52.764876999999998	Амурская область, Селемджинский район, поселок городского типа Огоджа, Садыкова, 1		0101000020E6100000A1116C5C7F916040363B527DE7614A40
17741	4	38	1025	30031	47162	\N	52.334398999999998	Амурская область, Селемджинский район, Норский сельсовет, с. норск, Новая, 16		0101000020E6100000CE8AA889BE3C604055682096CD2A4A40
17732	4	38	1025	8932	46783	\N	52.959018999999998	Амурская область, Селемджинский район, поселок городского типа Коболдо, Центральная,15		0101000020E6100000C408E1D1469760400E9F7422C17A4A40
17740	4	38	1025	30025	46727	\N	51.758723000000003	Амурская область, Селемджинский район, Исинский сельсовет, с. Иса, Центральная, 6А		0101000020E6100000363B527DE76060408CDCD3D51DE14940
17727	4	38	1025	29391	46743	\N	52.863593000000002	Амурская область, Селемджинский район, Ивановский сельсовет, с. Ивановское, Ленина, 3		0101000020E6100000624ED02607AD6040FB0626378A6E4A40
17726	4	38	1025	55728	\N	\N	52.9669855225088	"Амурская область, Селемджинский район, ОАО ""Албынский рудник"""	Россия, Амурская область, Селемджинский район, поселок Златоустовск	0101000020E610000022FE614B0FB360404DD87E32C67B4A40
17669	4	38	700	55761	46908	\N	54.548149000000002	Амурская область, Свободненский район, Малосазанский сельсовет, п.Орлиный, ФРУНЗЕ, 41		0101000020E6100000997E8978EB286040E52A16BF29464B40
17675	4	38	700	27042	47169	\N	51.473047000000001	Амурская область, Свободненский район, Дмитриевский сельсовет,п.Юхта-3, Сосновый бор, 5	Россия, Амурская область, Свободненский район, поселок Юхта-3	0101000020E6100000ED9A90D618056040473CD9CD8CBC4940
17678	4	38	700	27175	46725	\N	51.645688	Амурская область, Свободненский район, Черновский сельсовет,с.Черновка, распоповой, 17		0101000020E6100000747B4963B4046040B7B585E7A5D24940
17679	4	38	700	27175	46799	\N	51.645688	Амурская область, Свободненский район, Черновский сельсовет,с.Черновка, Новая, 4/1		0101000020E6100000747B4963B4046040B7B585E7A5D24940
17660	4	38	700	26337	47131	\N	51.465702999999998	Амурская область, Свободненский район, Черниговский сельсовет, с.Черниговка, Октябрьская, 18		0101000020E6100000965F0663440860401553E9279CBB4940
17673	4	38	700	26950	46801	\N	51.448137000000003	Амурская область, Свободненский район, Усть-Перский сельсовет, с.Усть-Пера, Южная, 11		0101000020E61000003D98141F9F04604054909F8D5CB94940
17877	4	38	700	55714	46510	\N	51.761817000000001	Амурская область, поселок Углегорск, улица  Маршала   Неделина, 12		0101000020E610000046990D32C9036040B7442E3883E14940
17699	4	38	700	28121	46862	\N	51.540514000000002	Амурская область, Свободненский район, Талалинский сельсовет, с.Талали, Калинина, 75	Россия, Амурская область, Свободненский район, поселок Талали	0101000020E6100000650113B875D05F40DC8310902FC54940
17689	4	38	700	27680	47178	\N	51.148066	Амурская область, Свободненский район, Сычевский сельсовет, с.Сычевка, Школьная, 1		0101000020E6100000EFACDD76A1DD5F4024D3A1D3F3924940
17695	4	38	700	27958	47001	\N	51.525561000000003	Амурская область, Свободненский район, Семеновский сельсовет, с.Сукромли, Центральная, 19/1		0101000020E6100000A0A4C00298F65F40CB86359545C34940
17686	4	38	700	27547	46803	\N	51.362366000000002	Амурская область, Свободненский район, Костюковский сельсовет, с.Серебрянка, Центральная, 28		0101000020E610000049111956F1F15F405797530262AE4940
17694	4	38	700	27916	47038	\N	51.533529000000001	Амурская область, Свободненский район, Семеновский сельсовет, с.Семеновка, Дзержинского, 42		0101000020E6100000A016838769F05F40DA3BA3AD4AC44940
17684	4	38	700	27449	47134	\N	51.271469000000003	Амурская область, Свободненский район, Рогачевский сельсовет, с.Рогачевка, Центральная, 46		0101000020E61000001B2E724F57F55F405D70067FBFA24940
17680	4	38	700	7438	47059	\N	51.692905000000003	Амурская область, Свободненский район, Черновский сельсовет,с.Разливная, Сосновая, 1		0101000020E6100000994528B682046040111E6D1CB1D84940
17666	4	38	700	26617	46724	\N	51.312579999999997	Амурская область, Свободненский район, Новгородский сельсовет, п.Подгорный, Центральная, 45		0101000020E61000000B444FCA240360401CB1169F02A84940
17693	4	38	700	27878	46834	\N	51.110392142515799	Амурская область, Свободненский район, Петропавловский сельсовет, с.Петропавловка, Центральная, 9-а	Россия, Амурская область, Свободненский район, поселок Петропавловка	0101000020E61000001BF1643733BB5F40B9DE3653218E4940
17698	4	38	700	28085	47159	\N	51.403339000000003	Амурская область, Свободненский район, Новостепановский сельсовет, с.Новостепановка, Центральная, 8		0101000020E6100000C075C58CF0D15F40C619C39CA0B34940
17677	4	38	700	27123	46833	\N	51.668272000000002	Амурская область, Свободненский район, Нижнебузулинский сельсовет,с.Новоострополь, Центральная, 20		0101000020E6100000185DDE1C2E096040906AD8EF89D54940
17664	4	38	700	26532	46831	\N	51.618099000000001	Амурская область, Свободненский район, Желтояровский сельсовет, с.Новоникольск, Старожилов, 11/1	Россия, Амурская область, Свободненский район, поселок Новоникольск	0101000020E610000008C89750411460405C5837DE1DCF4940
17683	4	38	700	27395	47126	\N	51.400232000000003	Амурская область, Свободненский район, Новоивановский сельсовет,с.Новоивановка, Нижняя, 10		0101000020E61000008A3DB48F15FF5F4006685BCD3AB34940
17665	4	38	700	26584	46632	\N	51.233049999999999	Амурская область, Свободненский район, Новгородский сельсовет,  с.Новгородка, Центральная, 3		0101000020E6100000BA2EFCE07C036040992A1895D49D4940
17676	4	38	700	27082	46648	\N	51.624932000000001	Амурская область, Свободненский район, Нижнебузулинский сельсовет,с.Нижние Бузули, Ленина, 32-а		0101000020E6100000F38FBE4953066040A81C93C5FDCF4940
17671	4	38	700	26851	46832	\N	51.143532688751698	Амурская область, Свободненский район, Москвитинский сельсовет, с.Москвитино, Гагарина, 5	Россия, Амурская область, Свободненский район, поселок Москвитино	0101000020E6100000BE13B35E0CFE5F40C972124A5F924940
17696	4	38	700	28002	47004	\N	51.574917999999997	Амурская область, Свободненский район, Маркучинский сельсовет, с.маркучи, Лазо, 40		0101000020E61000000586AC6EF5EC5F40DCF0BBE996C94940
17688	4	38	700	27636	46882	\N	51.270296999999999	Амурская область, Свободненский район, Костюковский сельсовет, с.Малый Эргель, Зеленая, 3/2		0101000020E6100000A453573ECBEB5F407C9A931799A24940
17652	4	38	1030	26001	46736	\N	50.609335000000002	Амурская область, Ромненский район, с. Верхнебелое, Зеленая, 3		0101000020E6100000C0B2D2A4941D604072A774B0FE4D4940
17668	4	38	700	26736	47153	\N	51.228155000000001	Амурская область, Свободненский район, Малосазанский сельсовет, с.Малая сазанка, Советская, 8		0101000020E6100000F9BF232A540260409EB5DB2E349D4940
17685	4	38	700	27494	47135	\N	51.318142000000002	Амурская область, Свободненский район, Костюковский сельсовет, с.Костюковка, Лермонтова, 2		0101000020E6100000CE35CCD078EB5F40F5BD86E0B8A84940
17697	4	38	700	28036	46687	\N	51.465612999999998	Амурская область, Свободненский район, Климоуцевский сельсовет, с.Климоуцы, Косова, 37		0101000020E61000000E4B033FAAE65F40D5CBEF3499BB4940
17672	4	38	700	55774	47216	\N	51.1082527554561	Амурская область, Свободненский район, Москвитинский сельсовет, с.Источное, 60 лет Октября, 8/1	Россия, Амурская область, Свободненский район, поселок Источный	0101000020E6100000B8E7F9D346FD5F40D158FB3BDB8D4940
17687	4	38	700	27596	46804	\N	51.348028999999997	Амурская область, Свободненский район, Костюковский сельсовет, с.Зиговка, Ждановская, 29		0101000020E6100000E355D636C5E85F40A087DA368CAC4940
17691	4	38	700	27775	47011	\N	51.139527999999999	Амурская область, Свободненский район, Загорно-Селитьбинский сельсовет, с.Загорная Селитьба, Советская, 45	Россия, Амурская область, Свободненский район, поселок Загорная Селитьба	0101000020E6100000F7EAE3A1EFCF5F402A70B20DDC914940
17663	4	38	700	26480	46830	\N	51.547505000000001	Амурская область, Свободненский район, Желтояровский сельсовет, с.Заган, Центральная, 37		0101000020E610000044882B67EF0F6040C0B2D2A414C64940
17661	4	38	700	26398	47037	\N	51.528480000000002	Амурская область, Свободненский район, Желтояровский сельсовет, с.Желтоярово, Молодежная, 6/1	Россия, Амурская область, Свободненский район, поселок Желтоярово	0101000020E610000097CADB114E0E6040884B8E3BA5C34940
17674	4	38	700	26998	46630	\N	51.495700999999997	Амурская область, Свободненский район, Дмитриевский сельсовет, с.Дмитриевка, Трудовая, 1/1		0101000020E61000000C7904375204604018CC5F2173BF4940
17690	4	38	700	27734	47156	\N	51.008775999999997	Амурская область, Свободненский район, Сычевский сельсовет, с.Гуран, Школьная, 8		0101000020E61000004CAAB69BE0D25F40AE7E6C921F814940
17682	4	38	700	27346	47125	\N	51.783852000000003	Амурская область, Свободненский район, Голубинский сельсовет,с.Голубое, Кирова, 5-2		0101000020E6100000376F9C14E6FD5F40BD73284355E44940
17681	4	38	700	27301	47127	\N	51.745497999999998	Амурская область, Свободненский район, Курганский сельсовет,с.Глухари, Клубная, 4		0101000020E61000003CDA38622D026040E09D7C7A6CDF4940
17662	4	38	700	26434	46723	\N	51.509228999999998	Амурская область, Свободненский район, Желтояровский сельсовет, с.Гащенка, Центральная, 8		0101000020E61000002638F581E40B60405F96766A2EC14940
17692	4	38	700	8841	47068	\N	51.219366000000001	Амурская область, Свободненский район, Петропавловский сельсовет, с.Буссе, Центральная,7		0101000020E6100000FF58880E81BA5F405BED612F149C4940
17667	4	38	700	26681	47132	\N	51.281717999999998	Амурская область, Свободненский район, Новгородский сельсовет, с.Бардагон, Набережная, 33		0101000020E6100000E38C614E50046040E658DE550FA44940
17639	4	38	1030	25363	47116	\N	50.858018999999999	Амурская область, Ромненский район, с. Смоляное, Трудовая, 4	Россия, Амурская область, Ромненский район, поселок Смоляное	0101000020E61000003410CB660E2F60405E2C0C91D36D4940
17650	4	38	1030	55763	47026	\N	50.6316318780476	Амурская область, Ромненский район, с. Святорусовка, Школьная, 49	Россия, Амурская область, Ромненский район, поселок Святоруссовка	0101000020E6100000E5D022DBF9246040B58D3F51D9504940
17648	4	38	1030	25789	46462	\N	50.721969000000001	Амурская область, Ромненский район, с. Ромны, Школьная, 22		0101000020E6100000849CF7FF71296040E8DCED7A695C4940
17647	4	38	1030	25789	46404	\N	50.721969000000001	Амурская область, Ромненский район, с. Ромны, Гагарина, 23		0101000020E6100000849CF7FF71296040E8DCED7A695C4940
17658	4	38	1030	26250	47123	\N	50.510179999999998	Амурская область, Ромненский район, с. Рогозовка, Советская, 1		0101000020E61000007E1CCD9195146040618907944D414940
17654	4	38	1030	9034	46656	\N	50.589221000000002	Амурская область, Ромненский район, с. Поздеевка, Мелиоративная,18		0101000020E6100000A31F0DA74C1C6040E78EFE976B4B4940
17655	4	38	1030	9034	46622	\N	50.589221000000002	Амурская область, Ромненский район, с. Поздеевка, Дзержинского, 52		0101000020E6100000A31F0DA74C1C6040E78EFE976B4B4940
17644	4	38	1030	25624	46714	\N	50.915846999999999	Амурская область, Ромненский район, с. Новый Быт, Рабочая, 21		0101000020E6100000A8716F7EC3236040E29178793A754940
17653	4	38	1030	26042	47057	\N	50.617542999999998	Амурская область, Ромненский район, с. Новороссийка, Центральная, 16		0101000020E6100000AB21718F251B6040D66F26A60B4F4940
17643	4	38	1030	25567	46796	\N	50.74438	Амурская область, Ромненский район, с. Новониколаевка, Трудовая, 20		0101000020E6100000320400C71E316040F3E505D8475F4940
17649	4	38	1030	25855	47028	\N	50.622245999999997	Амурская область, Ромненский район, с. Любимое, советская, 46		0101000020E6100000F64201DBC12660408D08C6C1A54F4940
17645	4	38	1030	8975	47060	\N	50.792603	Амурская область, Ромненский район, с. Каховка, 70 Лет Октября, 58А		0101000020E6100000F9A067B3EA26604012DBDD0374654940
17646	4	38	1030	25736	46718	\N	50.680045178376098	Амурская область, Ромненский район, с. Калиновка, Зеленая, 8	Россия, Амурская область, Ромненский район, поселок Калиновка	0101000020E61000007DE882FA162C60407767EDB60B574940
17651	4	38	1030	25965	47117	\N	50.622092000000002	Амурская область, Ромненский район, с. Знаменка, Центральная, 55		0101000020E61000004A44F817C1216040378DEDB5A04F4940
17656	4	38	1030	26162	47154	\N	50.516857999999999	Амурская область, Ромненский район, с. Дальневосточное, Садовая, 10		0101000020E6100000F1113125121C60408656276728424940
17657	4	38	1030	26198	46805	\N	50.517912000000003	Амурская область, Ромненский район, с. Григорьевка, Восточная, 46		0101000020E6100000DD06B5DF5A1960405D1ABFF04A424940
17659	4	38	1030	26280	47035	\N	50.607117000000002	Амурская область, Ромненский район, с. Вознесеновка, Набережная, 8		0101000020E6100000EE5C18E9451660403EEC8502B64D4940
17641	4	38	1030	25470	46795	\N	50.786413000000003	Амурская область, Ромненский район, с. Братолюбовка, Советская, 18		0101000020E61000008179C8948F2D60401B13622EA9644940
17642	4	38	1030	25526	47025	\N	50.686337999999999	Амурская область, Ромненский район, с. Амаранка, Советская, 8		0101000020E610000075C8CD7003336040430070ECD9574940
17615	4	38	978	24240	46794	\N	50.301487000000002	Амурская область, Октябрьский район, с.Южное, Ветеранов, 17		0101000020E6100000325A475513206040A795422097264940
14690	4	38	978	49182	47073	\N	50.29365	Черемушки, Северная, 2		0101000020E61000001D56B8E523196040363CBD5296254940
17604	4	38	978	55776	47223	\N	50.082791882033	Амурская область, Октябрьский район, с.Увальное, Центральная, 7 А	Россия, Амурская область, Октябрьский район, поселок Увальный	0101000020E6100000205ED72FD81A60406A2FA2ED980A4940
17603	4	38	978	55771	47165	\N	50.017109136567299	Амурская область, Октябрьский район, с.Трудовое, Веселая, 5	Россия, Амурская область, Октябрьский район, поселок Трудовой	0101000020E6100000A2B8E34D7E176040CFBBB1A030024940
16185	4	38	978	47107	46916	\N	50.536797	Смелое, Школьная, 14		0101000020E6100000F67EA31DB7266040A3CB9BC3B5444940
17613	4	38	978	24124	46986	\N	50.225056000000002	Амурская область, Октябрьский район, с.Сергее-Федоровка, Лесная, 32	Россия, Амурская область, Октябрьский район, поселок Сергее-Федоровка	0101000020E610000062F71DC3E325604061E28FA2CE1C4940
17609	4	38	978	23959	46900	\N	50.350029999999997	Амурская область, Октябрьский район, с.Романовка, Центральная, 67		0101000020E6100000F984ECBC8D296040374F75C8CD2C4940
17617	4	38	978	55787	47308	\N	50.416893016787199	Амурская область, Октябрьский район, с.Прибрежное, Молодежная, 1	Россия, Амурская область, Октябрьский район, поселок Прибрежный	0101000020E6100000D2E5CDE1DA2560403677F4BF5C354940
17608	4	38	978	23893	46720	\N	50.429777000000001	Амурская область, Октябрьский район, с.Преображеновка, Советская, 14		0101000020E610000069C4CC3E8F14604058C9C7EE02374940
17599	4	38	978	23460	46703	\N	50.161317945587598	Амурская область, Октябрьский район, с.Покровка, Центральная, 7	Россия, Амурская область, Октябрьский район, поселок Покровка	0101000020E6100000C9207711A6146040C9207711A6144940
17605	4	38	978	23748	46586	\N	50.328058741500598	Амурская область, Октябрьский район, с.Песчаноозерка, Чкалова, 100	Россия, Амурская область, Октябрьский район, поселок Песчаноозерка	0101000020E61000002D793C2DBF15604049145AD6FD294940
17607	4	38	978	23836	46839	\N	50.414636999999999	Амурская область, Октябрьский район, с.Переясловка, Первая, 23		0101000020E61000004B3ACAC16C196040145B41D312354940
17614	4	38	978	24221	46797	\N	50.245055999999998	Амурская область, Октябрьский район, с.Панино, Молодежная, 11		0101000020E61000000F61FC346E1C604023D8B8FE5D1F4940
17612	4	38	978	24110	46793	\N	50.231988999999999	Амурская область, Октябрьский район, с.Новомихайловка, Рабочая, 1		0101000020E61000004BAB21710F2860401004C8D0B11D4940
17598	4	38	978	23427	46666	\N	50.165261999999998	Амурская область, Октябрьский район, с.Николо-Александровка, Мухина, 31 А		0101000020E6100000897E6DFDF40F6040C2A2224E27154940
17626	4	38	978	55743	46717	\N	50.401367222217402	Амурская область, Октябрьский район, с.Нагорное, Нагорная, 2	Россия, Амурская область, Октябрьский район, поселок Нагорный	0101000020E61000008EE733A05E1F6040C9586DFE5F334940
17593	4	38	978	55738	46690	\N	50.257448912807199	Амурская область, Октябрьский район, с.Мухинское, Центральная, 36		0101000020E6100000D34F38BBB5156040A7B1BD16F4204940
17610	4	38	978	23989	46800	\N	50.314328000000003	Амурская область, Октябрьский район, с.Марьяновка, Новая, 2 а		0101000020E61000000C1EA67D732E6040CA1B60E63B284940
17602	4	38	978	23621	46706	\N	50.162191999999997	Амурская область, Октябрьский район, с.Максимовка, Ленина, 33		0101000020E6100000439259BDC31960401FD61BB5C2144940
17535	4	38	978	20443	46843	\N	50.476053254293298	Амурская область, Октябрьский район, с.Короли, Линейная, 28	Россия, Амурская область, Октябрьский район, поселок Короли	0101000020E6100000F7764B72C0206040D314014EEF3C4940
17601	4	38	978	23595	46702	\N	49.974975999999998	Амурская область, Октябрьский район, с.Ильиновка, Центральная, 45		0101000020E61000003201BF469211604044317903CCFC4840
17618	4	38	978	24419	47033	\N	50.369982	Амурская область, Октябрьский район, с.Екатеринославка, м-н Таежный		0101000020E6100000D9EDB3CA4C236040E90DF7915B2F4940
17619	4	38	978	24419	46587	\N	50.369982	Амурская область, Октябрьский район, с.Екатеринославка, Южная, б/н		0101000020E6100000D9EDB3CA4C236040E90DF7915B2F4940
17620	4	38	978	24419	46721	\N	50.369982	Амурская область, Октябрьский район, с.Екатеринославка, Пролетарская, 21		0101000020E6100000D9EDB3CA4C236040E90DF7915B2F4940
17625	4	38	978	24419	46527	\N	50.369982	Амурская область, Октябрьский район, с.Екатеринославка, Ленина, 110		0101000020E6100000D9EDB3CA4C236040E90DF7915B2F4940
17622	4	38	978	24419	46527	\N	50.369982	Амурская область, Октябрьский район, с.Екатеринославка, Ленина, 50		0101000020E6100000D9EDB3CA4C236040E90DF7915B2F4940
17621	4	38	978	24419	46614	\N	50.369982	Амурская область, Октябрьский район, с.Екатеринославка, Куйбышевская, 72		0101000020E6100000D9EDB3CA4C236040E90DF7915B2F4940
17623	4	38	978	24419	46403	\N	50.369982	Амурская область, Октябрьский район, с.Екатеринославка, Коммунальная, 60		0101000020E6100000D9EDB3CA4C236040E90DF7915B2F4940
16106	4	38	978	45454	46746	\N	50.524194999999999	Георгиевка, Георгиевская, 30		0101000020E6100000B4AD669DF122604005DD5ED218434940
17616	4	38	978	55715	46525	\N	50.347825443900398	Амурская область, Октябрьский район, с.Восточное, Юбилейная, 27	Россия, Амурская область, Октябрьский район, поселок Восточный	0101000020E610000069705B5BF823604098DD9387852C4940
17606	4	38	978	23808	46458	\N	50.345460000000003	Амурская область, Октябрьский район, с.Варваровка, Молодежная, м-н 1 д.10		0101000020E6100000FFCEF6E80D126040C0098508382C4940
17600	4	38	978	23540	46791	\N	50.036501999999999	Амурская область, Октябрьский район, с.Борисоглебка, Молодежная, 2		0101000020E61000009F5912A0A61360408A1EF818AC044940
17418	4	38	978	8194	47087	\N	50.085287000000001	Амурская область, Завитинский район, село Албазинка, улица Центральная, 8		0101000020E61000001D226E4E2521604011E335AFEA0A4940
17579	4	38	988	55767	47118	\N	49.829143999999999	Амурская об.,Михайловский район,Воскресеновский сел.,ст.Воскресеновка, Железнодорожная, ж/д вокзал	Россия, Амурская область, Михайловский район	0101000020E61000002BDD5D67431D60405AD6FD6321EA4840
17575	4	38	988	55769	47121	\N	49.910871209558799	Амурская обл., Михайловский р-н, Ильиновский с-т с.Ярославка, улица Центральная, 23, кв.2	Россия, Амурская область, Михайловский район, поселок Ярославка	0101000020E6100000A94C310741106040FAEFC16B97F44840
17581	4	38	988	22690	46899	\N	49.778497000000002	Амурская область, Михайловский район, Дубовской сельсовет, с.Шурино, Центральная, 4		0101000020E6100000D7DCD1FFF21A60405E8429CAA5E34840
17577	4	38	988	22471	47012	\N	49.895308999999997	Амурская обл., Михайловский р-н, Воскресеновский с-т, село Шумиловка, улица Рабочая, 5		0101000020E6100000DF6FB4E38621604040683D7C99F24840
17595	4	38	988	23291	47111	\N	49.584513999999999	Амурская область, Михайловский район, Чесноковский сельсовет,с.Шадрино, Центральная, 1		0101000020E61000000FF27A30A91A6040EE06D15AD1CA4840
17594	4	38	988	23239	46642	\N	49.558587000000003	Амурская область, Михайловский район, Чесноковский сельс., с.Чесноково, Ленина, 18		0101000020E61000008BFED0CC131A6040427C60C77FC74840
17588	4	38	988	22955	47015	\N	49.738762000000001	Амурская обл., Михайловский р-н, Зеленоборский с-т., с.Черемисино, Садовая, 1	Россия, Амурская область, Михайловский район, поселок Черемисино	0101000020E61000003FFED2A2BE14604087C3D2C08FDE4840
17582	4	38	988	22707	46829	\N	49.670363999999999	Амурская область, Михайловский район, Дубовской сельсовет,с.Привольное, Полевая, 4 кв.1		0101000020E610000040868E1DD41B60403735D07CCED54840
17569	4	38	988	8362	46627	\N	49.625625999999997	Амурская обл., Михайловский р-н, Поярковский с-т, с.Поярково, Советская,18		0101000020E61000006B60AB040B1560407EC3448314D04840
17570	4	38	988	8362	46439	\N	49.625625999999997	Амурская обл., Михайловский р-н, Поярковский с-т, с.Поярково, Садовая, 33		0101000020E61000006B60AB040B1560407EC3448314D04840
17567	4	38	988	8362	46677	\N	49.625625999999997	Амурская обл., Михайловский р-н, Поярковский с-т, с.Поярково, Пионерская, 1		0101000020E61000006B60AB040B1560407EC3448314D04840
17568	4	38	988	8362	46400	\N	49.625625999999997	Амурская обл., Михайловский р-н, Поярковский с-т, с.Поярково, Ленина, 37		0101000020E61000006B60AB040B1560407EC3448314D04840
17566	4	38	988	8362	46503	\N	49.625625999999997	Амурская обл., Михайловский р-н, Поярковский с-т, с.Поярково, Кольцевая, 2		0101000020E61000006B60AB040B1560407EC3448314D04840
17565	4	38	988	8362	46585	\N	49.625625999999997	Амурская обл., Михайловский р-н, Поярковский с-т, с.Поярково, улица Гарнизонная, 2		0101000020E61000006B60AB040B1560407EC3448314D04840
17572	4	38	988	22279	46785	\N	49.977657999999998	Амурская обл., Михайловский р-н, Михайловский с-т, с. Петропавловка, улица Центральная, 21а		0101000020E61000007380608E9E1C60401D56B8E523FD4840
17592	4	38	988	23176	46665	\N	49.565950000000001	Амурская обл, Михайловский рай., Новочесноковский сел.,с.Новочесноково, Совхозная, 6		0101000020E61000009B3924B550206040EA95B20C71C84840
17574	4	38	988	55768	47120	\N	49.9133	Амурская обл., Михайловский р-н, Ильиновский с-т, с.Нижнеильиновка, улица Октябрьская, 10		0101000020E6100000FD67CD8F3F116040E9B7AF03E7F44840
17584	4	38	988	22798	47110	\N	49.830666000000001	Амурская обл., Михайловский район, Коршуновский сел.,с.Нижнезавитинка, Центральная, 10 кв.2		0101000020E6100000172D40DB6A16604017F3734353EA4840
17571	4	38	988	22223	46628	\N	49.9145220390307	Амурская обл., Михайловский р-н, Михайловский с-т, с. Михайловка, улица Михайловских  партизан, 2	Россия, Амурская область, Михайловский район, поселок Михайловка	0101000020E6100000D28DB0A8081B60407BBC900E0FF54840
17591	4	38	988	23096	47184	\N	49.465947999999997	Амурская обл., Михайловский район, Новочесноковский сел..,с.Куприяново, Набережная, 3		0101000020E6100000728C648F502060407CD11E2FA4BB4840
17587	4	38	988	22928	46700	\N	49.840572999999999	Амурская обл., Михайловский район, Зеленоборский сельс., с.Красный Яр, Партизанская, 33		0101000020E610000087DEE2E1BD176040477364E597EB4840
17585	4	38	988	22813	46788	\N	49.718432999999997	Амурская обл., Михайловский рай., Коршуновский сел., с.Красный Восток, Центральная, 11		0101000020E61000004FCFBBB120136040FFAECF9CF5DB4840
17596	4	38	988	23342	47024	\N	49.602331	Амурская обл., Михайловский район, Чесноковский сел.,с.Красная Орловка, Центральная, 14		0101000020E61000001283C0CAA1186040F92EA52E19CD4840
17583	4	38	988	22747	46787	\N	49.772156000000003	Амурская обл., Михайловский район, Коршуновский сельсовет,с.Коршуновка, Специалистов, 27		0101000020E610000046088F368E14604081B4FF01D6E24840
17590	4	38	988	23083	46704	\N	49.389060335378097	Амурская обл., Михайловский район, Калининский сельсовет,с.Калинино, Шадрина, 1	Россия, Амурская область, Михайловский район, поселок Калинино	0101000020E6100000B6DAC35E282960404417D4B7CCB14840
17578	4	38	988	22546	47107	\N	49.741346999999998	Амурская обл., Михайловский район, Воскресеновский сельс.,с.Кавказ, Дорожная, 22/1	Россия, Амурская область, Михайловский район, поселок Кавказ	0101000020E61000004434BA83D81E60406DFE5F75E4DE4840
17586	4	38	988	55730	46617	\N	49.687924756205298	Амурская обл., Михайловский район, Зеленоборский сельс., с.Зеленый Бор, Центральная, 13	Россия, Амурская область, Михайловский район, поселок Зеленый Бор	0101000020E6100000740987DE62146040E78C28ED0DD84840
17580	4	38	988	22650	47023	\N	49.714058999999999	Амурская область, Михайловский район, Дубовской сельсовет, с.Дубовое, Советская, 2-б	Россия, Амурская область, Михайловский район, поселок Дубовое	0101000020E6100000A1A3552DE91860400D350A4966DB4840
17597	4	38	988	23372	46641	\N	49.652369	Амурская обл., Михайловский район, Димский сельсовет, с.Дим, Центральная, 6		0101000020E610000071C63027E80D60404DF6CFD380D34840
17576	4	38	988	46528	47114	\N	49.833362000000001	Амурская обл., Михайловский р-н, Воскресеновский с-т с.Воскресеновка, улица Школьная, 2	Россия, Амурская область, Михайловский район, поселок Воскресеновка	0101000020E610000064CC5D4B481F604055DD239BABEA4840
17767	4	38	988	46528	46740	\N	49.833362000000001	Воскресеновка, Центральная, 15		0101000020E610000064CC5D4B481F604055DD239BABEA4840
17589	4	38	988	23008	46790	\N	49.537984000000002	Амурская обл., Михайловский район, Калининский сельс., с.Винниково, Шадрина, 1		0101000020E61000004415FE0C6F296040B9E2E2A8DCC44840
17573	4	38	988	22317	46828	\N	49.981909999999999	Амурская обл., Михайловский р-н, Михайловский с-т, с. Арсентьевка, переулок Школьный, 2		0101000020E610000003B5183CCC1B6040C4CE143AAFFD4840
17544	4	38	1611	20946	46971	\N	51.543987000000001	Амурская область, Мазановский район, с.Юбилейное, Центральная, 1		0101000020E61000000B462575021B60407E39B35DA1C54940
17548	4	38	1611	21145	46848	\N	51.490682	Амурская область, Мазановский район, с.Христиновка, Озерная, 7/2		0101000020E61000001AC231CB9E196040315EF3AACEBE4940
17538	4	38	1611	20615	46844	\N	51.936914999999999	Амурская область, Мазановский район, с.Ульма, Центральная, 1		0101000020E61000002A91442FA3326040E010AAD4ECF74940
17537	4	38	1611	20555	46747	\N	51.944213940146902	Амурская область, Мазановский район, с.Угловое, Центральная, 26	Россия, Амурская область, Мазановский район, поселок Угловое	0101000020E6100000F8C3CF7F8F2B604072361D01DCF84940
17533	4	38	1611	20305	46767	\N	51.763165999999998	Амурская область, Мазановский район, с.Таскино, Советская, 43		0101000020E6100000BF0B5BB395226040A6B5696CAFE14940
17556	4	38	1611	21511	46765	\N	51.679582000000003	Амурская область, Мазановский район, с.Сохатино, Зейская, 7		0101000020E6100000FE7BF0DA251B6040A379008BFCD64940
17550	4	38	1611	21225	46771	\N	51.411233000000003	Амурская область, Мазановский район, с.Сапроново, 30 лет Победы, 11		0101000020E61000001F1494A2951B60409B046F48A3B44940
17546	4	38	1611	21033	46846	\N	51.532940000000004	Амурская область, Мазановский район, с.Романкауцы, Цветочная, 2		0101000020E610000083DA6FEDC4216040795DBF6037C44940
17545	4	38	1611	20988	46845	\N	51.548260999999997	Амурская область, Мазановский район, с.Раздольное, Амурская, 15		0101000020E6100000EA25C632FD2060400C569C6A2DC64940
17532	4	38	1611	20254	46693	\N	51.756475999999999	Амурская область, Мазановский район, с.Путятино, Джалова, 10		0101000020E6100000AD4B8DD0CF216040BD1AA034D4E04940
17555	4	38	1611	21455	47105	\N	51.640864999999998	Амурская область, Мазановский район, с.Практичи, Советская, 41		0101000020E6100000CD5B751D2A176040551344DD07D24940
17562	4	38	1611	21797	46770	\N	51.385990999999997	Амурская область, Мазановский район, с.Поповка, Центральная, 34		0101000020E6100000E28FA2CE5C0B604071C6302768B14940
17531	4	38	1611	20202	46741	\N	51.714661	Амурская область, Мазановский район, п.Пионерск, Центральная, 1		0101000020E6100000037D224F921E6040035DFB027ADB4940
17557	4	38	1611	21540	46994	\N	51.489224	Амурская область, Мазановский район, с.Петровка, Центральная, 21а		0101000020E6100000D68BA19CE81260408B355CE49EBE4940
17553	4	38	1611	21353	46880	\N	51.327373000000001	Амурская область, Мазановский район, Дмитриевский сельсовет, с.Паутовка, Минская, 9	Россия, Амурская область, Мазановский район, поселок Паутовка	0101000020E610000016DC0F78E0226040F54BC45BE7A94940
17539	4	38	1611	20668	46750	\N	52.148795	Амурская область, Мазановский район, с.Новороссийка, Набережная, 29		0101000020E6100000CBF44BC4DB2E60407767EDB60B134A40
17530	4	38	1611	20022	46650	\N	51.657898000000003	Амурская область, Мазановский район, с.Новокиевский Увал, пер. Амурский, б/н		0101000020E610000003250516401D60404A0D6D0036D44940
17528	4	38	1611	20022	46399	\N	51.657898000000003	Амурская область, Мазановский район, с.Новокиевский Увал, Школьная, 9		0101000020E610000003250516401D60404A0D6D0036D44940
17529	4	38	1611	20022	46502	\N	51.657898000000003	Амурская область, Мазановский район, с.Новокиевский Увал, Луговая, 78		0101000020E610000003250516401D60404A0D6D0036D44940
17527	4	38	1611	19950	46639	\N	51.675868000000001	Амурская область, Мазановский район, с.Новокиевка, Колхозная, 1а		0101000020E61000005A4A9693501D6040DB34B6D782D64940
17563	4	38	1611	21844	47016	\N	51.371616000000003	Амурская область, Мазановский район, с.Молчаново, Олимпийская, 7		0101000020E61000000377A04EF90A6040CE55F31C91AF4940
17559	4	38	1611	21633	46997	\N	51.451813999999999	Амурская область, Мазановский район, с.Михайловка, Центральная, 26 кв.2		0101000020E6100000E3361AC05B156040FEEF880AD5B94940
17554	4	38	1611	21421	46992	\N	51.333506999999997	Амурская область, Мазановский район, с.Маргаритовка, Новая, 4		0101000020E610000097CADB11CE26604058FE7C5BB0AA4940
17540	4	38	1611	20733	46752	\N	52.286844000000002	Амурская область, Мазановский район, п.Майский, пер.Лесной, 13		0101000020E6100000ADF6B0178A326040E486DF4DB7244A40
17542	4	38	1611	20822	46584	\N	51.628577999999997	Амурская область, Мазановский район, с.Мазаново, Ленина, 18		0101000020E610000092AF0452621A6040177E703E75D04940
17560	4	38	1611	21695	\N	\N	51.476424000000002	Амурская область, Мазановский район, с.Леонтьевка, Центральная, 10 кв.2	Россия, Амурская область, Мазановский район, поселок Леонтьевка	0101000020E61000004582A966D6106040C7832D76FBBC4940
17561	4	38	1611	21739	46583	\N	51.456018423860598	Амурская область, Мазановский район, с.Красноярово, Школьная, 18	Россия, Амурская область, Мазановский район, поселок Красноярово	0101000020E61000006CEA3C2AFE0D604094313ECC5EBA4940
17534	4	38	1611	20386	46768	\N	51.828741999999998	Амурская область, Мазановский район, с.Козловка, Центральная, 17		0101000020E6100000DE205A2B5A2660402B69C53714EA4940
17541	4	38	1611	20768	47101	\N	52.283186000000001	Амурская область, Мазановский район, п.Ивановский, Больничная, 2а		0101000020E6100000325706D586316040B05758703F244A40
17547	4	38	1611	21084	46847	\N	51.489722999999998	Амурская область, Мазановский район, с.Дружное, Орловой, 4		0101000020E610000034643C4A25206040AC8C463EAFBE4940
17552	4	38	1611	21313	46849	\N	51.343769999999999	Амурская область, Мазановский район, Дмитриевский сельсовет, с.Дмитриевка, переулок Школьный, 2		0101000020E6100000B63176C2CB1D604047ACC5A700AC4940
17536	4	38	1611	20504	47058	\N	51.865940999999999	Амурская область, Мазановский район, с.Богословка, Молодежная, 1		0101000020E61000001AE1ED4188276040FDA19927D7EE4940
17551	4	38	1611	21265	46989	\N	51.381780999999997	Амурская область, Мазановский район, Дмитриевский сельсовет, с.Бичура, Школьная, 2		0101000020E6100000B5E0455F411B6040F99D2633DEB04940
17543	4	38	1611	20868	46640	\N	51.592928000000001	Амурская область, Мазановский район, с.Белоярово, пер.Школьный, 4		0101000020E6100000BD8A8C0EC8186040FC709010E5CB4940
17558	4	38	1611	21596	47103	\N	51.476194	Амурская область, Мазановский район, с.Антоновка, Центральная, 22		0101000020E6100000E6E61BD13D1260409546CCECF3BC4940
17549	4	38	1611	21174	46754	\N	51.435034000000002	Амурская область, Мазановский район, с.Алексеевка, Лесная, 12		0101000020E6100000D0D4EB1601196040F452B131AFB74940
17512	4	38	1578	19196	46637	\N	52.790872	Амурская область,Магдагачинский район,Черняевский сельсовет,с.Черняево, Мухинская, 5		0101000020E610000036ACA92C0A805F403BA92F4B3B654A40
17521	4	38	1578	19630	46739	\N	52.950218999999997	Амурская область, Магдагачинский район, Чалганский сельсовет, с.Чалганы, Советская, 21		0101000020E61000006403E962D39B5F40D784B4C6A0794A40
17518	4	38	1578	19465	46478	\N	52.782750999999998	Амурская область, Магдагачинский район, поселок городского типа Ушумун, Комсомольская, 17		0101000020E61000005376FA415DA25F40A5F44C2F31644A40
17523	4	38	1578	19713	46457	\N	53.111065000000004	Амурская область, Магдагачинский район, Тыгдинский сельсовет, с.Тыгда, Советская, 3		0101000020E6100000DB6D179AEB945F40795DBF60378E4A40
17522	4	38	1578	19713	46457	\N	53.111065000000004	Амурская область, Магдагачинский район, Тыгдинский сельсовет, с.Тыгда, Советская, 8		0101000020E6100000DB6D179AEB945F40795DBF60378E4A40
17515	4	38	1578	19713	46457	\N	53.111788089894901	"ОАО ""Покровский рудник"", помещение столовой"	Россия, Амурская область, Магдагачинский район, поселок Тыгда	0101000020E61000001424B6BB07955F40E90AB6114F8E4A40
17514	4	38	1578	19284	46874	\N	53.135058999999998	Амурская обл.,Магдагачинский район,Толбузинский сельсовет,с.Толбузино, Погрничная		0101000020E61000004D4BAC8C465C5F40E603029D49914A40
17516	4	38	1578	19362	46571	\N	52.634307999999997	Амурская область, Магдагачинский район, поселок городского типа Сиваки, Вокзальная, 5		0101000020E61000005456D3F544B05F40ABCB290131514A40
17509	4	38	1578	55708	46455	\N	53.452818999999998	Амурская область, Магдагачинский район, поселок городского типа Магдагачи, К.Маркса, 17		0101000020E6100000373811FDDA735F40F30016F9F5B94A40
17508	4	38	1578	18969	46569	\N	53.452818999999998	Амурская область, Магдагачинский район, поселок городского типа Магдагачи, Комсомольская, 40		0101000020E6100000373811FDDA735F40F30016F9F5B94A40
17511	4	38	1578	18969	46570	\N	53.452818999999998	Амурская область, Магдагачинский район, поселок городского типа Магдагачи, К.Маркса, 20		0101000020E6100000373811FDDA735F40F30016F9F5B94A40
17513	4	38	1578	19232	46749	\N	52.563779235927903	Амурская обл.,Магдагачинский район,Кузнецовский сельсовет,с.Кузнецово, Амурская, 15	Россия, Амурская область, Магдагачинский район, поселок Кузнецово	0101000020E610000051A5660FB48A5F40F69507E929484A40
17524	4	38	1578	19793	46612	\N	53.337117999999997	Амурская область, Магдагачинский район, Дактуйский сельсовет, с.Дактуй, Проезжая, 3		0101000020E6100000DF6A9DB81C8B5F404B72C0AE26AB4A40
17526	4	38	1578	19900	47099	\N	53.686307999999997	Амурская область, Магдагачинский район, Гудачинский сельсовет, с.Гудачи, Школьная, 17	Россия, Амурская область, Магдагачинский район, поселок Гудачи	0101000020E6100000C03DCF9F364F5F40D87DC7F0D8D74A40
17525	4	38	1578	19856	46649	\N	53.582132000000001	Амурская область, Магдагачинский район, Гонжинский сельсовет, с. Гонжа, Кооперативная, 4		0101000020E61000001A4F04711E585F4040FA264D83CA4A40
16942	4	38	810	23569	46920	\N	49.816642999999999	с.Средняя Полтавка, Молодежная, 10		0101000020E610000049B9FB1C1F066040F0C000C287E84840
15977	4	38	810	8734	46701	\N	49.743232999999996	с.Семидомка, Ленина, 43		0101000020E6100000DCF5D21401F25F406B274A4222DF4840
15897	4	38	810	45855	46745	\N	49.686644999999999	с. Октябрьское, Центральная, 11		0101000020E61000006E6DE179A9F75F40207BBDFBE3D74840
16427	4	38	810	55742	46715	\N	49.811754000000001	с.Новотроицкое, Советская, 55	Россия, Амурская область, Константиновский район, поселок Новотроицкое	0101000020E6100000FF58880E81026040D732198EE7E74840
17492	4	38	810	55756	46838	\N	49.573819	с.Новопетровка, Стрельцова, 27А	Россия, Амурская область, Константиновский район, поселок Новопетровка	0101000020E6100000B1F84D61A50860406669A7E672C94840
16576	4	38	810	5772	46541	\N	49.713242999999999	с.Нижняя Полтавка, Пионерская, 2А		0101000020E61000001F4B1FBAA0076040EB8CEF8B4BDB4840
16202	4	38	810	19589	46603	\N	49.774245000000001	с.Крестовоздвиженка, Школьная, 5		0101000020E6100000BD19355F25FE5F40B70BCD751AE34840
17506	4	38	810	45804	46453	\N	49.615827000000003	с. Константиновка, Ленина, 84		0101000020E6100000A75B76887FFF5F40357F4C6BD3CE4840
17505	4	38	810	45804	46453	\N	49.615827000000003	c. Константиновка, Ленина, 84		0101000020E6100000A75B76887FFF5F40357F4C6BD3CE4840
17504	4	38	810	45804	46453	\N	49.615827000000003	с.Константиновка, Ленина, 84		0101000020E6100000A75B76887FFF5F40357F4C6BD3CE4840
15799	4	38	810	31788	47072	\N	49.715345999999997	с.Коврижка, Ленина, 29		0101000020E6100000BCC96FD1C9F55F4086A92D7590DB4840
16347	4	38	810	45674	46609	\N	49.731547999999997	с.Ключи, Школьная, 24		0101000020E61000003332C85D8402604023BA675DA3DD4840
17084	4	38	810	30128	46922	\N	49.837452999999996	с.Золотоножка, Школьная, 7		0101000020E6100000A86F99D3E50B6040F277EFA831EB4840
17067	4	38	810	29340	46769	\N	49.910690000000002	с.Зеньковка, Советская, 19		0101000020E610000036E84B6FFF0B6040AA656B7D91F44840
15495	4	38	810	47101	46858	\N	49.612675000000003	с.Войково, Центральная, 26		0101000020E6100000FCE3BD6AE5056040D50968226CCE4840
16845	4	38	810	18743	46604	\N	49.897224000000001	с.Верхняя Полтавка, Советская, 40/1		0101000020E61000008CDCD3D59D066040D9976C3CD8F24840
16411	4	38	810	29483	46792	\N	49.8532657790198	с.Верхний Уртуй, Ленина, 52	Россия, Амурская область, Константиновский район, поселок Верхний Уртуй	0101000020E6100000A9BF5E61C1FF5F40F564FED137ED4840
17503	4	38	1397	18706	46679	\N	50.405415132719497	"Амурская обл, Ивановский р-н, Черемховский сельсовет, с. Черемхово, Кирова, 117 ""А"""	Россия, Амурская область, Ивановский район, поселок Черемхово	0101000020E61000002F3196E997F25F40672783A3E4334940
17481	4	38	1397	17590	47093	\N	50.285339999999998	Амурская область, Ивановский район, Ивановский сельсовет, с. Успеновка, Дрогошевского, 36		0101000020E61000009C6A2DCC42026040CD1E680586244940
17496	4	38	1397	18340	46968	\N	50.761744	Амурская область, Ивановский район, Троицкий сельсовет, с. Троицкое, Комсомольская, 2		0101000020E6100000D0D2156C23FC5F404DF6CFD380614940
17494	4	38	1397	55744	46728	\N	50.680176613206903	Амурская обл, Ивановский р-н, Новоивановский сельсовет, с. Среднебелое-2, Строителей, 1		0101000020E61000008B54185B88016040E63E390A10574940
17495	4	38	1397	18264	46626	\N	50.680230999999999	Амурская область, Ивановский район, Новоивановский сельсовет, с. Среднебелое, Молодежная, 1		0101000020E61000009F9273628F016040D95C35CF11574940
17493	4	38	1397	18100	46470	\N	50.657955000000001	Амурская область, Ивановский район, Среднебельский сельсовет, с. Среднебелая, Садовая, 25а		0101000020E61000007C2766BD18006040AE9E93DE37544940
17491	4	38	1397	18100	46568	\N	50.657955000000001	Амурская обл, Ивановский район, Среднебельский сельсовет, с. Среднебелая, Амурская, 14		0101000020E61000007C2766BD18006040AE9E93DE37544940
17497	4	38	1397	18384	47100	\N	50.602840999999998	Амурская область, Ивановский район, Приозерный сельсовет, с. Солнечное, Зеленая, 34		0101000020E61000001C97715303FF5F400ED8D5E4294D4940
17498	4	38	1397	18429	46678	\N	50.644895453354899	Амурская обл, Ивановский район, Семиозерский сельсовет, с. Семиозерка, Кирова, 32/2	Россия, Амурская область, Ивановский район, поселок Семиозерка	0101000020E6100000CC4065FCFBF45F404D2D5BEB8B524940
17482	4	38	1397	17648	46841	\N	50.326573000000003	Амурская обл, Ивановский р., Правовосточный сельсовет, с. Правовосточное, Центральная, 28		0101000020E6100000A5F622DA0E066040D960E124CD294940
17501	4	38	1397	18578	46580	\N	50.505614000000001	Амурская обл, Ивановский р-н, Петропавловский сельсовет, с. Петропавловка, Кооперативный, 20		0101000020E61000006F4BE48233F35F402B33A5F5B7404940
17489	4	38	1397	17975	46814	\N	50.611666999999997	"Амурская обл, Ивановский район, Николаевский сельсовет, с. Новопокровка, Школьная, 22 ""а"""		0101000020E61000001F2DCE18E60660406E85B01A4B4E4940
17490	4	38	1397	18039	46686	\N	50.555841000000001	Амурская обл, Ивановский р-н, Новоалексеевский сельсовет, с.Новоалексеевка, Гвардейская, 51/1		0101000020E610000069E4F38AA7026040526342CC25474940
17488	4	38	1397	17953	47097	\N	50.602361000000002	Амурская обл, Ивановский район, Николаевский сельсовет, с. Николаевка, Центральная, 1		0101000020E610000028F4FA93F80A604064B14D2A1A4D4940
17479	4	38	1397	17476	46977	\N	50.426563000000002	Амурская область, Ивановский район, Ивановский сельсовет, с. Луговое, Садовая, 35		0101000020E610000004C8D0B1030460408257CB9D99364940
17436	4	38	1397	15350	47174	\N	50.272652000000001	Амурская область, Ивановский район, Ивановский сельсовет, с. Крещеновка, Центральная, 19		0101000020E6100000F487669E5CFD5F403198BF42E6224940
17486	4	38	1397	17839	46673	\N	50.457971000000001	Амурская обл, Ивановский р-н, Константиноградовский сельсовет, с. Константиноградовка, Ветеранов, 68		0101000020E61000007BA356983E0960401AC231CB9E3A4940
17478	4	38	1397	17342	46395	\N	50.360886000000001	Амурская область, Ивановский район, Ивановский сельсовет, с. Ивановка, Пионерская, 26		0101000020E610000091291F82AAFF5F40C9CA2F83312E4940
17477	4	38	1397	17342	46454	\N	50.360886000000001	Амурская область, Ивановский район, Ивановский сельсовет, с. Ивановка, Партизанская, 97		0101000020E610000091291F82AAFF5F40C9CA2F83312E4940
17476	4	38	1397	17342	46567	\N	50.360886000000001	Амурская область, Ивановский район, Ивановский сельсовет, с. Ивановка, Галушкина, 7		0101000020E610000091291F82AAFF5F40C9CA2F83312E4940
17487	4	38	1397	17891	46638	\N	50.473126000000001	Амурская обл, Ивановский р-н, Ерковецкий сельсовет, с. Ерковцы, Советская, 101		0101000020E610000036ACA92C8A0D604093718C648F3C4940
17480	4	38	1397	17534	46611	\N	50.407995999999997	Амурская область, Ивановский район, Дмитриевский сельсовет, с. Дмитриевка, Набережная, 59		0101000020E6100000B6BE4868CBFB5F400C73823639344940
17484	4	38	1397	17742	47095	\N	50.391212000000003	Амурская обл, Ивановский район, Анновский сельсовет, с. Большеозерка, Центральная, 21		0101000020E610000051FA42C8F9046040C1E61C3C13324940
17502	4	38	1397	18665	46980	\N	50.444940000000003	Амурская обл, Ивановский район, Черемховский сельсовет, с. Богородское, Партизанская, 18		0101000020E6100000C171193735F45F4054573ECBF3384940
17499	4	38	1397	18493	46501	\N	50.570900999999999	"Амурская область, Ивановский район, Березовский сельсовет, с. Березовка, Юбилейная, 24 ""а"""		0101000020E6100000EC51B81E85F75F407920B24813494940
17500	4	38	1397	18493	46394	\N	50.570900999999999	Амурская область, Ивановский район, Березовский сельсовет, с. Березовка, Ленина, 14		0101000020E6100000EC51B81E85F75F407920B24813494940
17485	4	38	1397	17800	46842	\N	50.3790087977629	Амурская область, Ивановский район, Анновский сельсовет, с. Анновка, Молодежный, 1	Россия, Амурская область, Ивановский район, поселок Анновка	0101000020E6100000D2C5A695420B6040E1F1ED5D83304940
17483	4	38	1397	17686	46817	\N	50.287590000000002	Амурская обл, Ивановский р-н, Андреевский сельсовет, с. Андреевка, Центральная, 15		0101000020E610000068244223D80760400D54C6BFCF244940
17449	4	38	1386	15998	46983	\N	53.128608	Амурская область, Зейский район, Юбилейненский сельсовет, п.Юбилейный, ул.Центральная, д.45/А	Россия, Амурская область, Зейский район, поселок Юбилейный	0101000020E6100000AA2D7590D7D65F408200193A76904A40
17445	4	38	1386	15788	46962	\N	53.337274000000001	Амурская область, Зейский район, Чалбачинский сельсовет, с.Чалбачи, ул. Амурская, д.14	Россия, Амурская область, Зейский район, поселок Чалбачи	0101000020E6100000933A014D84C25F4043E55FCB2BAB4A40
17456	4	38	1386	16328	46969	\N	54.597760999999998	Амурская область, Зейский район, Хвойненский сельсовет, п.Хвойный, ул.Первооткрывателей, д.6	Россия, Амурская область, Зейский район, поселок Хвойный	0101000020E61000002D7C7DAD4BF55F4081E9B46E834C4B40
17447	4	38	1386	15886	46898	\N	53.265853999999997	Амурская область, Зейский район, Умлеканский сельсовет, с.Умлекан, ул.Универсальная, д.6		0101000020E61000007D40A03369C85F4061C1FD8007A24A40
17461	4	38	1386	16573	\N	\N	53.548960000000001	Амурская область, Зейский район, Тунгалинский сельсовет, п.Тунгала, ул.Школьная, д.52	Россия, Амурская область, Зейский район, поселок Тунгала	0101000020E61000006ABE4A3EF62D6040F5673F5244C64A40
17433	4	38	1386	55732	46652	\N	53.701423620067203	Амурская область, Зейский район, Сосновоборский сельсовет, с.Сосновый Бор, ул. Новая, д.2/А	Россия, Амурская область, Зейский район, поселок Сосновый Бор	0101000020E6100000E4688EACFCCA5F409450FA42C8D94A40
17454	4	38	1386	16237	46959	\N	54.193939	Амурская область, Зейский район, Снежногорский сельсовет, п.Снежногорский, ул.Ленина, д.2		0101000020E61000006B49473998FD5F40A0353FFED2184B40
17446	4	38	1386	15855	46981	\N	53.299501999999997	Амурская область, Зейский район, Сианский сельсовет,  с.Сиан, ул.Трейберта, д.8		0101000020E610000073F56393FCBC5F40158BDF1456A64A40
17448	4	38	1386	15940	47193	\N	53.236044	Амурская область, Зейский район, Умлеканский сельсовет, с.Рублевка, ул.Центральная, д.15		0101000020E61000009432A9A10DCB5F40613596B0369E4A40
17450	4	38	1386	16042	46759	\N	52.992752000000003	Амурская область, Зейский район, Поляковский сельсовет, п. Поляковский, ул.Рабочая, д.8		0101000020E6100000E1421EC18DE25F40F1845E7F127F4A40
17452	4	38	1386	16124	46988	\N	53.014064070444903	Амурская область, Зейский район, Октябрьский сельсовет, с.Октябрьский, ул.Чехова, д.2/А	Россия, Амурская область, Зейский район, поселок Октябрьский	0101000020E610000016F9F543EC146040850662D9CC814A40
17453	4	38	1386	16124	46623	\N	53.019447119435704	Амурская область, Зейский район, Октябрьский сельсовет, с. Октябрьский, ул.Спортивная, д.40	Россия, Амурская область, Зейский район, поселок Октябрьский	0101000020E6100000A1BC8FA3B9146040AE80423D7D824A40
17460	4	38	1386	16548	47182	\N	53.961466000000001	Амурская область, Зейский район, Огоронский сельсовет, п.Огорон, ул.Первостроителей, д.20		0101000020E6100000FC71FBE593246040A41B615111FB4A40
17438	4	38	1386	15421	46366	\N	53.574283999999999	Амурская область, Зейский район, Овсянковский сельсовет, с.Овсянка, пер.Светлый, д.3		0101000020E61000006E3315E291B95F40DB4E5B2382C94A40
17437	4	38	1386	15421	46364	\N	53.574283999999999	Амурская область, Зейский район, Овсянковский сельсовет, с.Овсянка, ул. Ленина, д.90		0101000020E61000006E3315E291B95F40DB4E5B2382C94A40
17441	4	38	1386	15601	46930	\N	53.595590000000001	Амурская область, Зейский район, Николаевский сельсовет, с.Николаевка-2, ул. Центральная, д.10/А		0101000020E61000006937FA980FC25F408EE9094B3CCC4A40
17439	4	38	1386	15507	46895	\N	53.630803	Амурская область, Зейский район, Ивановский сельсовет, с.Ивановка, ул.Советская, д.7		0101000020E6100000E2E47E87A2AE5F40FE9B1727BED04A40
17451	4	38	1386	16080	46760	\N	54.280569	Амурская область, Зейский район, Золотогорский сельсовет, с.Золотая Гора, ул.Школьная, д.14		0101000020E6100000C7681D554DA85F40BEA25BAFE9234B40
17435	4	38	1386	55727	46599	\N	53.722546778033298	Амурская область, Зейский район, Сосновоборский сельсовет, с.Заречная Слобода, ул. Школьная, д.32	Россия, Амурская область, Зейский район, поселок Заречная Слобода	0101000020E6100000295B24ED46D15F4055698B6B7CDC4A40
17462	4	38	1386	16640	46651	\N	53.350890999999997	Амурская область, Зейский район, Дугдинский сельсовет, п.Дугда, пл.Тухачевского, д.1		0101000020E61000005C21ACC612406040F9BA0CFFE9AC4A40
17434	4	38	1386	15258	\N	\N	53.74494	Амурская область, Зейский район, Сосновоборский сельсовет, с.Гулик, ул,Трудовая, д.4	Россия, Амурская область, Зейский район, поселок Гулик	0101000020E6100000F015DD7A4DC65F40BABDA4315ADF4A40
17457	4	38	1386	16401	46685	\N	54.647379999999998	Амурская область, Зейский район, Горненский сельсовет, п.Горный, ул.Советская, д.1		0101000020E61000001B7FA2B2610D6040D00A0C59DD524B40
17459	4	38	1386	16483	\N	\N	54.620474999999999	"Амурская область, Зейский район, Верхнезейский сельсовет, п.Верхнезейск, МУК ""СКК п. Верхнезейск"", Блок №73"		0101000020E610000032C687D94B116040287E8CB96B4F4B40
17458	4	38	1386	16429	46813	\N	54.708689999999997	Амурская область, Зейский район, Бомнакский сельсовет, с.Бомнак, ул.Федосеева, д.29		0101000020E61000003CBD5296211B604049809A5AB65A4B40
17443	4	38	1386	15698	47190	\N	53.463751000000002	Амурская область, Зейский район, Николаевский сельсовет, с.Березовка, ул.Почтовая, д.8		0101000020E610000067B62BF4C1BD5F40603E59315CBB4A40
17455	4	38	1386	16264	46465	\N	54.358423000000002	Амурская область, Зейский район, Береговой сельсовет, п.Береговой, ул.Ленина, д.6		0101000020E610000091EEE714E4DE5F402E910BCEE02D4B40
17440	4	38	1386	15558	47180	\N	53.507514999999998	Амурская область, Зейский район, Амуро-Балтийский сельсовет, с.Амуро-Балтийск, ул.Юбилейная, д.17		0101000020E610000071AE6186C6B25F405E9D6340F6C04A40
17442	4	38	1386	15641	47188	\N	53.595269999999999	Амурская область, Зейский район, Николаевский сельсовет, с.Александровка, ул.Центральня, д.13/А		0101000020E610000015E63DCE34BD5F401C25AFCE31CC4A40
17444	4	38	1386	15743	47192	\N	53.390830999999999	Амурская область, Зейский район, Алгачинский сельсовет, с.Алгач, пер. Сосновый, д.14		0101000020E6100000BE13B35E0CBF5F40A9A10DC006B24A40
17428	4	38	966	55760	46852	\N	50.139449999999997	Амурская область, город Завитинск, село Червоная Армия, улица Центральная, 14	Россия, Амурская область, Завитинский район, поселок Червоная Армия	0101000020E6100000F6F065A2882F6040AEB6627FD9114940
17410	4	38	966	14124	47080	\N	49.919187999999998	Амурская область, Завитинский район, село Федоровка, улица Южная, 11-2		0101000020E61000009B58E02BBA2860401570CFF3A7F54840
17417	4	38	966	14459	47092	\N	50.105021999999998	Амурская область, Завитинский район, село Успеновка, улица Центральная, 46		0101000020E61000007F30F0DCFB27604025AE635C710D4940
17412	4	38	966	14232	46748	\N	50.040899000000003	Амурская область, Завитинский район, село Преображеновка, улица  Центральная, 28А		0101000020E6100000D5E76A2BF62D604035B8AD2D3C054940
17411	4	38	966	14172	47083	\N	49.889249999999997	Амурская область, Завитинский район, село Подоловка, улица Чкалова, 33		0101000020E610000049A297512C266040E7FBA9F1D2F14840
17420	4	38	966	55753	46812	\N	50.208846726497796	Амурская область, город Завитинск, село Новоалексеевка, улица Центральная, 13-2	Россия, Амурская область, Завитинский район, поселок Новоалексеевка	0101000020E6100000EB0088BBFA2A6040116F9D7FBB1A4940
17407	4	38	966	13976	47141	\N	49.812520999999997	Амурская область, Завитинский район, село Ленино, улица Свободная, 5	Россия, Амурская область, Завитинский район, поселок Ленино	0101000020E61000005ABC5818222A6040172829B000E84840
17409	4	38	966	8062	47079	\N	49.958449999999999	Амурская область, Завитинский район, село Куприяновка, ул. Комсомольская,23		0101000020E6100000A4552DE9A82A6040F46C567DAEFA4840
17416	4	38	966	8142	46957	\N	50.093471000000001	Амурская область, Завитинский район, село Камышенка, ул. Школьная,6	Россия, Амурская область, Завитинский район, поселок Камышенка	0101000020E6100000E692AAEDA62A6040ED0F94DBF60B4940
17414	4	38	966	14320	46954	\N	49.971598	Амурская область, Завитинский район, село Иннокентьевка, улица Центральная, 7		0101000020E61000005C1FD61BB5256040F46DC1525DFC4840
17429	4	38	966	14592	\N	\N	50.106062000000001	Амурская область, город Завитинск, ПО Озерный, Здание клуба		0101000020E61000002EC6C03A0E2E604097AC8A70930D4940
17426	4	38	966	14592	46528	\N	50.106062000000001	Амурская область, город Завитинск, улица Чкалова, 16		0101000020E61000002EC6C03A0E2E604097AC8A70930D4940
17427	4	38	966	14592	46363	\N	50.106062000000001	Амурская область, город Завитинск, улица Линейная, 6В		0101000020E61000002EC6C03A0E2E604097AC8A70930D4940
17425	4	38	966	14592	46361	\N	50.106062000000001	Амурская область, город Завитинск, улица Куйбышева, 30		0101000020E61000002EC6C03A0E2E604097AC8A70930D4940
17423	4	38	966	14592	46496	\N	50.106062000000001	Амурская область, город Завитинск, улица Красноармейская, 56		0101000020E61000002EC6C03A0E2E604097AC8A70930D4940
17424	4	38	966	14592	46386	\N	50.106062000000001	Амурская область, город Завитинск, улица Кооперативная, 104		0101000020E61000002EC6C03A0E2E604097AC8A70930D4940
17422	4	38	966	14592	46450	\N	50.106062000000001	Амурская область, город Завитинск, улица Комсомольская, 97		0101000020E61000002EC6C03A0E2E604097AC8A70930D4940
17415	4	38	966	14363	46719	\N	49.992097999999999	Амурская область, Завитинский район, село Демьяновка, улица Нижняя, 13/2		0101000020E61000005F45460724276040A8363811FDFE4840
17432	4	38	966	8294	46758	\N	50.219327	Амурская область, Завитинский район, село Верхнеильиновка, улица Центральная, 3		0101000020E610000032C9C859583660409D103AE8121C4940
17413	4	38	966	14259	46860	\N	50.057645000000001	Амурская область, Завитинский район, село Валуево, улица Центральная, 7		0101000020E6100000698D41270432604093E34EE960074940
17430	4	38	966	15064	47171	\N	50.224491	Амурская область, Завитинский район, село Болдыревка, улица Октябрьская, 32В		0101000020E61000003A22DFA5D42F6040889FFF1EBC1C4940
17419	4	38	966	8231	47085	\N	50.183762999999999	Амурская область, Завитинский район, село Белый Яр, улица Центральная, 13		0101000020E6100000C8073D9B55266040809BC58B85174940
17408	4	38	966	14039	\N	\N	49.864415000000001	Амурская область, Завитинский район, село Антоновка, улица Молодежная, 17	Россия, Амурская область, Завитинский район, поселок Антоновка	0101000020E610000036E7E099D02B6040FF959526A5EE4840
17431	4	38	966	15114	46965	\N	50.262684999999998	Амурская область, Завитинский район, село Аврамовка, улица Центральная, 8	Россия, Амурская область, Завитинский район, поселок Аврамовка	0101000020E61000005FD218ADA32D60402B137EA99F214940
17402	4	38	40	13743	47091	\N	49.674964000000003	с.Усть-Кивда, Центральная, 26		0101000020E61000000E4C6E14593660401AFD683865D64840
17393	4	38	40	13276	\N	\N	50.262818000000003	поселок городского типа Талакан, здание Талаканской СОШ №5	Россия, Амурская область, Бурейский район, поселок городского типа Талакан	0101000020E6100000E5B9BE0F874860406B662D05A4214940
17392	4	38	40	13276	\N	\N	50.262818000000003	поселок городского типа Талакан, здание Талаканской СОШ №6	Россия, Амурская область, Бурейский район, поселок городского типа Талакан	0101000020E6100000E5B9BE0F874860406B662D05A4214940
15816	4	38	40	48	46692	\N	49.750909999999998	с.Старая Райчиха, Центральная, 14		0101000020E6100000FF0758AB76276040A31EA2D11DE04840
17404	4	38	40	48415	\N	\N	50.069141000000002	с.Семеновка, здание культурного центра	Россия, Амурская область, Бурейский район, поселок Семеновка	0101000020E61000000E8810574E3A604008E8BE9CD9084940
17403	4	38	40	48402	46961	\N	50.018053000000002	с.Родионовка, Школьная, 2		0101000020E6100000EBE1CB44913860401F4C8A8F4F024940
17390	4	38	40	12980	46448	\N	49.800404999999998	поселок городского типа Новобурейский, Советская, 80		0101000020E61000006A4DF38ED33B60400647C9AB73E64840
17388	4	38	40	12980	46448	\N	49.800404999999998	поселок городского типа Новобурейский, Советская, 60		0101000020E61000006A4DF38ED33B60400647C9AB73E64840
17386	4	38	40	55700	46396	\N	49.800404999999998	поселок городского типа Новобурейский, Чайковского, 1		0101000020E61000006A4DF38ED33B60400647C9AB73E64840
17389	4	38	40	55700	46495	\N	49.800404999999998	поселок городского типа Новобурейский, Советская, 53		0101000020E61000006A4DF38ED33B60400647C9AB73E64840
17387	4	38	40	55700	46447	\N	49.800404999999998	поселок городского типа Новобурейский, Лесная, 36		0101000020E61000006A4DF38ED33B60400647C9AB73E64840
17391	4	38	40	55723	46588	\N	49.791189000000003	с.Николаевка, Юбилейная, 31	Россия, Амурская область, Бурейский район, поселок Николаевка	0101000020E6100000079ACFB95B3D60403CFA5FAE45E54840
17400	4	38	40	48348	\N	\N	49.795777000000001	с.Муравка, здание школы	Россия, Амурская область, Бурейский район, поселок Муравка	0101000020E61000002BFC19DE2C3360405AF44E05DCE54840
17401	4	38	40	48373	46398	\N	49.781854000000003	с.Малиновка, Октябрьская, 1		0101000020E6100000B169A510C83A6040971FB8CA13E44840
17399	4	38	40	13600	\N	\N	49.849704000000003	с.Кивдо-Тюкан, здание администрации	Россия, Амурская область, Бурейский район, поселок Кивдо-Тюкан	0101000020E6100000FE0C6FD6E0356040E4A3C519C3EC4840
17405	4	38	40	13887	47090	\N	49.896469000000003	с.Долдыкан, Молодежная, 9 А		0101000020E6100000B876A224243C60405D70067FBFF24840
15614	4	38	40	49255	46789	\N	49.662911999999999	с.Виноградовка, переулок Школьный, 9		0101000020E61000005D6A847E262D60401F10E84CDAD44840
17397	4	38	40	13380	46578	\N	49.808638000000002	поселок городского типа Бурея, Кировская, 83		0101000020E6100000C9AEB48CD4396040C426327381E74840
17396	4	38	40	55707	46449	\N	49.808638000000002	поселок городского типа Бурея, Октябрьская, 61		0101000020E6100000C9AEB48CD4396040C426327381E74840
17394	4	38	40	55707	46676	\N	49.808638000000002	поселок городского типа Бурея, Мухинская, 22		0101000020E6100000C9AEB48CD4396040C426327381E74840
15766	4	38	40	30127	46664	\N	49.812800000000003	с.Безозерное, Центральная, 1		0101000020E6100000761A69A9BC2060402B1895D409E84840
17406	4	38	40	48446	46756	\N	49.562770999999998	с.Алексеевка, Новая, 12		0101000020E610000054026212AE2E6040901150E108C84840
17290	4	38	912	7764	46635	\N	50.338987476939998	Амурская область, Благовещенский район, Чигиринский сельсовет, с.Чигири адрес помещения для голосования ул.Тепличная, 1, адрес УИК, ул. Новая, 4	Россия, Амурская область, Благовещенский район, поселок Чигири	0101000020E61000007520EBA9D5E05F4074620FED632B4940
17276	4	38	912	7764	46368	\N	50.336663999999999	Амурская область, Благовещенский район, Чигиринский сельсовет, с.Чигири, Новая, 4		0101000020E6100000A3CB9BC3B5E05F40CADE52CE172B4940
17266	4	38	912	7361	46379	\N	50.324283999999999	Амурская область, Благовещенский район, Усть-Ивановский сельсовет, с.Усть-Ивановка, Ленина, 54/1		0101000020E61000004852D2C3D0EF5F40DB4E5B2382294940
17274	4	38	912	7695	46939	\N	50.138554999999997	Амурская область, Благовещенский район, Грибский сельсовет, с.Удобное, Свободная, 2		0101000020E61000007A50508A56F35F4040D9942BBC114940
17282	4	38	912	8057	46475	\N	50.742789999999999	Амурская область, Благовещенский район, Сергеевский сельсовет, с.Сергеевка, Пограничная, 9		0101000020E61000008D09319754D35F40DEE522BE135F4940
17264	4	38	912	7247	47078	\N	50.290773000000002	Амурская область, Благовещенский район, Волковский сельсовет, с.Ровное, Центральная, 24		0101000020E6100000A0FF1EBC76F15F40A8C7B60C38254940
17286	4	38	912	8289	47076	\N	50.866615000000003	Амурская область, Благовещенский район, Новопетровский сельсовет, с.Прядчино, Центральная, 48		0101000020E6100000D42AFA4333F25F408D9C853DED6E4940
17292	4	38	912	55706	46432	\N	50.308513727527	Амурская область, город Благовещенск, с. Плодопитомник, Центральная, 1 а	Россия, Амурская область, Благовещенский район, поселок Плодопитомник	0101000020E610000066BE839F38DF5F40D82D02637D274940
17275	4	38	912	7742	46712	\N	50.129184000000002	"Амурская область, Благовещенский район, Грибский сельсовет, с.Передовое, Центральная, 20 ""Б"""		0101000020E6100000E92B483316EE5F404F95EF1989104940
17284	4	38	912	47342	46636	\N	50.498952771926099	Амурская область, Благовещенский район, Новотроицкий сельсовет, с.Новотроицкое и с.Кани-Курган, Гагарина, 17	Россия, Амурская область, Благовещенский район, поселок Новотроицкое	0101000020E61000005DE2C80391E35F40DC9E20B1DD3F4940
17285	4	38	912	8224	46606	\N	50.783377999999999	Амурская область, Благовещенский район, Новопетровский сельсовет, с.Новопетровка, Школьная, 29		0101000020E610000088D7F50B76F05F40F433F5BA45644940
17288	4	38	912	8377	46949	\N	50.643306000000003	Амурская область, Благовещенский район, Новопетровский сельсовет, с.Новинка, Центральная, 31		0101000020E610000056F487669EEA5F4009A9DBD957524940
17289	4	38	912	8452	\N	\N	50.970726999999997	Амурская область, Благовещенский район, Натальинский сельсовет, с.Натальино, Торговая, 20	Россия, Амурская область, Благовещенский район, поселок Натальино	0101000020E6100000BCCE86FC33F55F400E2C47C8407C4940
17280	4	38	912	7975	46802	\N	50.633890392940998	Амурская область, Благовещенский район, Михайловский сельсовет, с.Михайловка, Коммунальная, 6	Россия, Амурская область, Благовещенский район, поселок Михайловка	0101000020E6100000C5FF1D51A1D75F4077A1B94E23514940
17279	4	38	912	7928	46577	\N	50.543540999999998	Амурская область, Благовещенский район, Марковский сельсовет, с.Марково, 60 лет Октября, 32		0101000020E61000006765FB90B7D75F407F8461C092454940
17270	4	38	912	55750	46784	\N	50.205646238922597	Амурская область, Благовещенский район, Гродековский сельсовет, с.Кани-Курган, Центральная, 19	Россия, Амурская область, Благовещенский район, поселок Каникурган	0101000020E6100000E2B034F0A3E85F40D046AE9B521A4940
17278	4	38	912	7868	46575	\N	50.445382000000002	Амурская область, Благовещенский район, Чигиринский сельсовет, с.Игнатьево, Школьная, 16		0101000020E61000001EA4A7C821D95F40111D024702394940
17271	4	38	912	55745	46751	\N	50.248145582918397	Амурская область, Благовещенский район, Гродековский сельсовет, с.Заречное, Магистральная, 10	Россия, Амурская область, Благовещенский район, поселок Заречный	0101000020E61000007CD3F4D901EB5F400D51853FC31F4940
17287	4	38	912	8359	46716	\N	50.685436000000003	Амурская область, Благовещенский район, Новопетровский сельсовет, с.Егорьевка, пер. Клубный, 4		0101000020E6100000AB92C83EC8EC5F4023C0E95DBC574940
17273	4	38	912	7654	46815	\N	50.174031999999997	Амурская область, Благовещенский район, Грибский сельсовет, с.Дроново, пер.Новый, 1		0101000020E610000034F279C553F55F408E3A3AAE46164940
17281	4	38	912	8022	\N	\N	50.654352000000003	Амурская область, Благовещенский район, Михайловский сельсовет, с.Грязнушка, Школьная, 14	Россия, Амурская область, Благовещенский район, поселок Грязнушка	0101000020E6100000397B67B455DF5F403E096CCEC1534940
17269	4	38	912	7486	46975	\N	50.121969999999997	Амурская область, Благовещенский район, Гродековский сельсовет, с.Гродеково, Центральная, 8		0101000020E61000009EB30584D6E45F40EB8B84B69C0F4940
17272	4	38	912	55736	46688	\N	50.206086926640602	Амурская область, Благовещенский район, Грибский сельсовет, с. Грибское адрес помещения для голосования ул.Центральная, 47, адрес УИК ул. Медицинская, 15	Россия, Амурская область, Благовещенский район, поселок Грибское	0101000020E61000002672C119FCEF5F40BC900E0F611A4940
17265	4	38	912	7302	46951	\N	50.300429000000001	Амурская область, Благовещенский район, Усть-Ивановский сельсовет, с.Владимировка, Центральная, 28 пом.1		0101000020E610000023BA675DA3E85F408FE21C7574264940
17345	4	38	912	7847	\N	\N	50.2809806869152	Амурская область, город Благовещенск, Клуб села Верхнеблаговещенское	Россия, Амурская область, Благовещенский район, поселок Верхнеблаговещенское	0101000020E6100000302FC03E3ADB5F4010E6762FF7234940
17277	4	38	912	7847	46629	\N	50.283262000000001	Амурская область, Благовещенский район, Чигиринский сельсовет, с.Верхнеблаговещенское, Ленина, 68		0101000020E610000017A06D35EBDA5F408B19E1ED41244940
17268	4	38	912	7446	\N	\N	50.325827553316799	Амурская область, город Благовещенск	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000B87878CF81E25F40800F5EBBB4294940
17325	4	38	912	7446	46558	\N	50.327365999999998	Амурская область, город Благовещенск, п. Аэропорт, 10		0101000020E610000041D47D0052E25F4042E90B21E7294940
17315	4	38	912	7446	46671	\N	50.327365999999998	Амурская область, город Благовещенск, Школьная, 7		0101000020E610000041D47D0052E25F4042E90B21E7294940
17360	4	38	912	7446	46443	\N	50.327365999999998	Амурская область, город Благовещенск, Широкая, 61		0101000020E610000041D47D0052E25F4042E90B21E7294940
17348	4	38	912	7446	46595	\N	50.291539268297598	Амурская область, город Благовещенск, Шимановского, 8	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E610000072FA7ABE66E35F401841632651254940
17380	4	38	912	7446	46446	\N	50.327365999999998	Амурская область, город Благовещенск, Чайковского, 95/3		0101000020E610000041D47D0052E25F4042E90B21E7294940
17372	4	38	912	7446	46446	\N	50.327365999999998	Амурская область, город Благовещенск, Чайковского, 87		0101000020E610000041D47D0052E25F4042E90B21E7294940
17362	4	38	912	7446	46446	\N	50.290211948959097	Амурская область, город Благовещенск, Чайковского, 175	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E610000042B115342DE45F401074B4AA25254940
17336	4	38	912	7446	46446	\N	50.327365999999998	Амурская область, город Благовещенск, Чайковского, 14		0101000020E610000041D47D0052E25F4042E90B21E7294940
17332	4	38	912	7446	46446	\N	50.327365999999998	Амурская область, город Благовещенск, Чайковского, 307		0101000020E610000041D47D0052E25F4042E90B21E7294940
17263	4	38	912	7446	46554	\N	50.298369667144499	Амурская область, Благовещенский район, Волковский сельсовет с.Волково, Центральная, 11	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E610000029B3412619E15F40C30DF8FC30264940
17354	4	38	912	7446	46563	\N	50.296586908068903	Амурская область, город Благовещенск, Фрунзе, 57/59	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000E063B0E254E15F409AB51490F6254940
17361	4	38	912	7446	46494	\N	50.327365999999998	Амурская область, город Благовещенск, Трудовая, 182		0101000020E610000041D47D0052E25F4042E90B21E7294940
17312	4	38	912	7446	46436	\N	50.327365999999998	Амурская область, город Благовещенск, Тенистая, 103		0101000020E610000041D47D0052E25F4042E90B21E7294940
17373	4	38	912	7446	46441	\N	50.327365999999998	Амурская область, город Благовещенск, Театральная, 2		0101000020E610000041D47D0052E25F4042E90B21E7294940
17359	4	38	912	7446	46441	\N	50.327365999999998	Амурская область, город Благовещенск, Театральная, 276		0101000020E610000041D47D0052E25F4042E90B21E7294940
17349	4	38	912	7446	46441	\N	50.327365999999998	Амурская область, город Благовещенск, Театральная, 28		0101000020E610000041D47D0052E25F4042E90B21E7294940
17342	4	38	912	7446	46441	\N	50.327365999999998	Амурская область, город Благовещенск, Театральная, 185		0101000020E610000041D47D0052E25F4042E90B21E7294940
17331	4	38	912	7446	46441	\N	50.327365999999998	Амурская область, город Благовещенск, Театральная, 96		0101000020E610000041D47D0052E25F4042E90B21E7294940
17344	4	38	912	7446	46438	\N	50.327365999999998	Амурская область, город Благовещенск, Студенческая, 43/3		0101000020E610000041D47D0052E25F4042E90B21E7294940
17323	4	38	912	7446	46438	\N	50.301985545829901	Амурская область, город Благовещенск, Студенческая, 34/5, 4 корпус	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E61000009E62D520CCE15F40C8EC2C7AA7264940
17322	4	38	912	7446	46438	\N	50.327365999999998	Амурская область, город Благовещенск, Студенческая, 28		0101000020E610000041D47D0052E25F4042E90B21E7294940
17366	4	38	912	7446	46445	\N	50.276360566884499	Амурская область, город Благовещенск, Северная, 107	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000FFE7305F5EE25F40E77118CC5F234940
17308	4	38	912	7446	46377	\N	50.327365999999998	Амурская область, город Благовещенск, Свободная, 261		0101000020E610000041D47D0052E25F4042E90B21E7294940
17343	4	38	912	7446	46380	\N	50.327365999999998	Амурская область, город Благовещенск, Релочная, 22		0101000020E610000041D47D0052E25F4042E90B21E7294940
17340	4	38	912	7446	46560	\N	50.327365999999998	Амурская область, город Благовещенск, Рабочая, 95		0101000020E610000041D47D0052E25F4042E90B21E7294940
17365	4	38	912	7446	46381	\N	50.327365999999998	Амурская область, город Благовещенск, Пушкина, 189		0101000020E610000041D47D0052E25F4042E90B21E7294940
17350	4	38	912	7446	46381	\N	50.327365999999998	Амурская область, город Благовещенск, ул. Пушкина, 44		0101000020E610000041D47D0052E25F4042E90B21E7294940
17371	4	38	912	7446	46497	\N	50.327365999999998	Амурская область, город Благовещенск, Политехническая, 86		0101000020E610000041D47D0052E25F4042E90B21E7294940
17357	4	38	912	7446	46488	\N	50.327365999999998	Амурская область, город Благовещенск, Пограничная, 124/3		0101000020E610000041D47D0052E25F4042E90B21E7294940
17314	4	38	912	7446	46373	\N	50.327365999999998	Амурская область, город Благовещенск, Пионерская, 157		0101000020E610000041D47D0052E25F4042E90B21E7294940
17313	4	38	912	7446	46373	\N	50.327365999999998	Амурская область, город Благовещенск, Пионерская, 104	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E610000041D47D0052E25F4042E90B21E7294940
17298	4	38	912	7446	46373	\N	50.327365999999998	Амурская область, город Благовещенск, Пионерская, 1		0101000020E610000041D47D0052E25F4042E90B21E7294940
17376	4	38	912	7446	46392	\N	50.327365999999998	Амурская область, город Благовещенск, Первомайская, 36		0101000020E610000041D47D0052E25F4042E90B21E7294940
17364	4	38	912	7446	46444	\N	50.314188274754102	Амурская область, город Благовещенск, Островского, 150	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E61000005C7347FFCBE35F40D865F84F37284940
17381	4	38	912	7446	46384	\N	50.327365999999998	Амурская область, город Благовещенск, Октябрьская, 155		0101000020E610000041D47D0052E25F4042E90B21E7294940
17327	4	38	912	7446	46384	\N	50.327365999999998	Амурская область, город Благовещенск, Октябрьская, 239		0101000020E610000041D47D0052E25F4042E90B21E7294940
17330	4	38	912	7446	46506	\N	50.327365999999998	Амурская область, город Благовещенск, Нагорная, 4		0101000020E610000041D47D0052E25F4042E90B21E7294940
17310	4	38	912	7446	46378	\N	50.291968311231699	Амурская область, город Благовещенск, Ломоносова, 144	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E610000039807EDFBFDF5F4040BD19355F254940
17346	4	38	912	7446	46562	\N	50.327365999999998	Амурская область, город Благовещенск, Ленина, 297		0101000020E610000041D47D0052E25F4042E90B21E7294940
95200	4	38	912	7446	46359	\N	50.327365999999998	Амурская область, г. Благовещенск, ул.Ленина, 1(здание лицея № 1)		0101000020E610000041D47D0052E25F4042E90B21E7294940
17379	4	38	912	7446	46359	\N	50.327365999999998	Амурская область, город Благовещенск, Ленина, 80		0101000020E610000041D47D0052E25F4042E90B21E7294940
17347	4	38	912	7446	46359	\N	50.327365999999998	Амурская область, город Благовещенск, Ленина, 104		0101000020E610000041D47D0052E25F4042E90B21E7294940
17338	4	38	912	7446	46359	\N	50.327365999999998	Амурская область, город Благовещенск, Ленина, 160		0101000020E610000041D47D0052E25F4042E90B21E7294940
17337	4	38	912	7446	46359	\N	50.327365999999998	Амурская область, город Благовещенск, Ленина, 144		0101000020E610000041D47D0052E25F4042E90B21E7294940
17294	4	38	912	7446	46359	\N	50.327365999999998	Амурская область, город Благовещенск, Ленина, 196		0101000020E610000041D47D0052E25F4042E90B21E7294940
17335	4	38	912	7446	46508	\N	50.327365999999998	Амурская область, город Благовещенск, Лазо, 41		0101000020E610000041D47D0052E25F4042E90B21E7294940
17353	4	38	912	7446	46383	\N	50.327365999999998	Амурская область, город Благовещенск, Краснофлотская, 83/95		0101000020E610000041D47D0052E25F4042E90B21E7294940
17374	4	38	912	7446	46435	\N	50.265839109361899	Амурская область, город Благовещенск, Красноармейская, 56		0101000020E610000067B96C74CEE35F402C80290307224940
17307	4	38	912	7446	46435	\N	50.327365999999998	Амурская область, город Благовещенск, Красноармейская, 227		0101000020E610000041D47D0052E25F4042E90B21E7294940
17306	4	38	912	7446	46435	\N	50.276140549922701	Амурская область, город Благовещенск, Красноармейская, 157	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E61000000E4B033FAAE35F40D90A9A9658234940
17305	4	38	912	7446	46435	\N	50.327365999999998	Амурская область, город Благовещенск, Красноармейская, 161		0101000020E610000041D47D0052E25F4042E90B21E7294940
17296	4	38	912	7446	46557	\N	50.327365999999998	Амурская область, город Благовещенск, Комсомольская, 21		0101000020E610000041D47D0052E25F4042E90B21E7294940
17316	4	38	912	7446	46374	\N	50.260956910439198	Амурская область, город Благовещенск, Калинина, 130/2	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000B5FE9600FCE05F40C554FA0967214940
17311	4	38	912	7446	46374	\N	50.327365999999998	Амурская область, город Благовещенск, Калинина, 114		0101000020E610000041D47D0052E25F4042E90B21E7294940
17309	4	38	912	7446	46374	\N	50.327365999999998	Амурская область, город Благовещенск, Калинина, 103		0101000020E610000041D47D0052E25F4042E90B21E7294940
17295	4	38	912	7446	46374	\N	50.297257516448902	Амурская область, город Благовещенск, Калинина, 13	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E610000006F7031E18E15F40B83CD68C0C264940
17326	4	38	912	7446	46362	\N	50.2968176757403	Амурская область, город Благовещенск, Институтская, 3	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000685DA3E540E15F409C6ED921FE254940
17324	4	38	912	7446	46362	\N	50.297257516448902	Амурская область, город Благовещенск, Институтская, 15	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000503A9160AAE15F40B83CD68C0C264940
17328	4	38	912	7446	46467	\N	50.302535286022099	Амурская область, город Благовещенск, Игнатьевское шоссе, 19	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000EF6FD05E7DE15F409B728577B9264940
17318	4	38	912	7446	46467	\N	50.327365999999998	Амурская область, город Благовещенск, Игнатьевское шоссе, 5		0101000020E610000041D47D0052E25F4042E90B21E7294940
17351	4	38	912	7446	46358	\N	50.327365999999998	Амурская область, город Благовещенск, Зейская, 30		0101000020E610000041D47D0052E25F4042E90B21E7294940
17334	4	38	912	7446	46358	\N	50.327365999999998	Амурская область, город Благовещенск, Зейская, 34		0101000020E610000041D47D0052E25F4042E90B21E7294940
17329	4	38	912	7446	46358	\N	50.296147061126099	Амурская область, город Благовещенск, Зейская, 89	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000E063B0E254E15F407DE71725E8254940
17300	4	38	912	7446	46358	\N	50.2983571003316	Амурская область, город Благовещенск, Зейская, 297	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000DDCD531D72E15F402FC4EA8F30264940
17299	4	38	912	7446	46375	\N	50.2974665896879	Амурская область, город Благовещенск, Загородная, 54	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000F9BA0CFFE9E05F40D2510E6613264940
17355	4	38	912	7446	46504	\N	50.477812230640701	Амурская область, город Благовещенск, с.Белогорье, Заводская, 18		0101000020E610000013B875374FEA5F4074D190F1283D4940
17304	4	38	912	7446	46376	\N	50.294827495763897	Амурская область, город Благовещенск, Горького, 231	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000CA6DFB1EF5E25F40287D21E4BC254940
17303	4	38	912	7446	46376	\N	50.267613352368102	Амурская область, город Благовещенск, Горького, 153	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E610000019CBF44BC4E15F40027E8D2441224940
17301	4	38	912	7446	46376	\N	50.297686507537101	Амурская область, город Благовещенск, Горького, 157	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000B94F8E0244E15F40E1B88C9B1A264940
17333	4	38	912	7446	46625	\N	50.327365999999998	Амурская область, город Благовещенск, Воронкова, 26		0101000020E610000041D47D0052E25F4042E90B21E7294940
17297	4	38	912	7446	46431	\N	50.327365999999998	Амурская область, город Благовещенск, Б. Хмельницкого, 1		0101000020E610000041D47D0052E25F4042E90B21E7294940
17378	4	38	912	7446	46365	\N	50.327365999999998	Амурская область, город Благовещенск, Амурская, 151		0101000020E610000041D47D0052E25F4042E90B21E7294940
17375	4	38	912	7446	46365	\N	50.298577014041499	Амурская область, город Благовещенск, Амурская, 97	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E6100000B6B9313D61E15F403D2B69C537264940
17302	4	38	912	7446	46365	\N	50.327365999999998	Амурская область, город Благовещенск, Амурская, 223/1		0101000020E610000041D47D0052E25F4042E90B21E7294940
17363	4	38	912	7446	46564	\N	50.327365999999998	Амурская область, город Благовещенск, Театральная, 179		0101000020E610000041D47D0052E25F4042E90B21E7294940
17367	4	38	912	7446	46565	\N	50.327365999999998	Амурская область, город Благовещенск, Свободная, 33		0101000020E610000041D47D0052E25F4042E90B21E7294940
17341	4	38	912	7446	46442	\N	50.313748591459003	Амурская область, город Благовещенск, Островского, 273	Россия, Амурская область, Благовещенский район, Благовещенск	0101000020E61000004701A260C6E35F408C135FED28284940
17317	4	38	912	7446	46390	\N	50.327365999999998	Амурская область, город Благовещенск, Дьяченко, 5/3		0101000020E610000041D47D0052E25F4042E90B21E7294940
17283	4	38	912	8141	46940	\N	50.806362999999997	Амурская область, Благовещенский район, Сергеевский сельсовет, с.Бибиково, Лесная, 1		0101000020E6100000DD94F25A09CE5F402BDA1CE736674940
17211	4	38	600	4514	\N	\N	50.610776000000001	Амурская область, Белогорский район, Озерянский сельсовет,с.Чернетчено, Мира, 15	Россия, Амурская область, Белогорский район, поселок Чернетчено	0101000020E6100000AEF54542DB106040429770E82D4E4940
17226	4	38	600	5308	46766	\N	50.731313999999998	Амурская область, Белогорский район, Успеновский сельсовет,с.Успеновка, Школьная, 4		0101000020E61000004CDF6B080E026040B08D78B29B5D4940
15880	4	38	600	5308	46698	\N	50.731313999999998	с.Успеновка, Центральная, 2		0101000020E61000004CDF6B080E026040B08D78B29B5D4940
17220	4	38	600	4992	46357	\N	50.780490999999998	Амурская область, Белогорский район, Томичевский сельсовет, с.Томичи, Комсомольская, 4А		0101000020E6100000060FD3BEB907604042E90B21E7634940
17230	4	38	600	5536	46713	\N	50.984633000000002	Амурская область, Белогорский район, Светиловский с/с, с.Светиловка, Школьная, 4		0101000020E610000082531F48DEFD5F40FCC74274087E4940
17219	4	38	600	4947	47019	\N	50.692084000000001	Амурская область, Белогорский район, Лохвицкий сельсовет, с.Савельевка, Центральная, 20а		0101000020E6100000D8F0F44AD9066040DD0A613596584940
17213	4	38	600	4603	46669	\N	50.826166999999998	Амурская область, Белогорский район, Пригородный с/с, с.Пригородное, Садовая, 5		0101000020E61000002F51BD35B010604068041BD7BF694940
17222	4	38	600	5072	47129	\N	50.731195	Амурская область, Белогорский район, Томичевский сельсовет, с.Поляное, Почтовая, 4, кв.2	Россия, Амурская область, Белогорский район, поселок Поляное	0101000020E61000009E40D829560A6040D6FF39CC975D4940
17200	4	38	600	3899	46851	\N	50.872129000000001	Амурская область, Белогорский район, Васильевский с/с, с.Павловка, Центральная, 34/2		0101000020E6100000F88DAF3D3317604054724EECA16F4940
17210	4	38	600	4470	47045	\N	50.642980000000001	Амурская область, Белогорский район, Озерянский сельсовет, с.Озеряне, Центральная, 44		0101000020E610000088F6B182DF176040B5FD2B2B4D524940
17216	4	38	600	4786	46761	\N	50.618583000000001	Амурская область, Белогорский район, Некрасовский с/с, с.Новоселитьба, Центральная, 13		0101000020E610000030BABC39DC0D6040486E4DBA2D4F4940
17217	4	38	600	4817	47061	\N	50.691575999999998	Амурская область, Белогорский район, Некрасовский с/с, с.Новоназаровка, Нижняя, 7	Россия, Амурская область, Белогорский район, поселок Новоназаровка	0101000020E610000098DEFE5CB40E60406859F78F85584940
17202	4	38	600	3996	47203	\N	50.869729999999997	Амурская область, Белогорский район, Новинский сельсовет, с.Новое, ул.Школьная,2	Россия, Амурская область, Белогорский район, поселок Новое	0101000020E6100000AD3594DA8B1F6040CF2C0950536F4940
17228	4	38	600	5393	47013	\N	50.878329999999998	Амурская область, Белогорский район, Великокнязевский, с.Новоандреевка, Набережная, 33		0101000020E6100000DE9046054EF85F403F8C101E6D704940
17233	4	38	600	5687	46371	\N	50.923535000000001	Амурская область, Белогорский район, Никольский сельсовет, с.Никольское, пер.Школьный, 6		0101000020E6100000D673D2FB460960400EDB166536764940
17260	4	38	600	55747	46757	\N	50.857271191618899	Амурская область, город Белогорск, с. Низинное, ул. Новая, 24, здание клуба	Россия, Амурская область, Белогорский район, поселок Низинное	0101000020E61000007383A10E2B0D604094675E0EBB6D4940
17215	4	38	600	4734	47054	\N	50.677686000000001	Амурская область, Белогорский район, Некрасовский с/с, с.Некрасовка, Садовая, 72		0101000020E6100000C3BAF1EE480B6040817A336ABE564940
17212	4	38	600	4553	47064	\N	50.741154000000002	Амурская область, Белогорский район, Пригородный сельсовет, с.Мирное, Центральная, 12А		0101000020E61000006A847EA65E13604059A65F22DE5E4940
17198	4	38	600	3786	47039	\N	50.904345999999997	Амурская область, Белогорский район, Васильевский с/с, с.Междугранка, Юбилейная, 11/1		0101000020E6100000C5025FD1AD1260405B22179CC1734940
17224	4	38	600	5208	46778	\N	50.834758000000001	Амурская область, Белогорский район, Кустанаевский с/с, с.Лукьяновка, Садовая, 20		0101000020E61000005182FE428F0660408509A359D96A4940
17203	4	38	600	4087	46995	\N	50.761043000000001	Амурская область, Белогорский район, Новинский сельсовет, с.Луговое, Центральная, 4		0101000020E6100000C687D9CBB6216040C4EC65DB69614940
17218	4	38	600	4877	46668	\N	50.732841999999998	Амурская область, Белогорский район, Лохвицкий сельсовет, с.Лохвицы, Школьная, 73		0101000020E6100000B5705985CD0660404F9143C4CD5D4940
17815	4	38	600	47510	46605	\N	50.779111999999998	село Лозовое, ул.Школьная, 8		0101000020E61000006EFAB31F290A6040E8F527F1B9634940
17223	4	38	600	5133	46763	\N	50.800198000000002	Амурская область, Белогорский район, Кустанаевский сельсовет, с.Кустанаевка, Центральная, 33		0101000020E61000007CF2B0506B0860408D2958E36C664940
17201	4	38	600	3949	46928	\N	50.873305000000002	Амурская область, Белогорский район, Васильевский сельсовет, с.Круглое, Сельская, 11		0101000020E610000055A4C2D8421B604076374F75C86F4940
17227	4	38	600	5383	46777	\N	50.861457999999999	Амурская область, Белогорский район, Великокнязевский, с.Комиссаровка, Новая, 6		0101000020E6100000B5C2F4BD86FF5F4054707841446E4940
17232	4	38	600	5638	46779	\N	50.939408	Амурская область, Белогорский район, Никольский с/с, с.Ключи, Рабочая, 40А		0101000020E61000002AE620E868056040E6CC76853E784940
17231	4	38	600	5547	46711	\N	50.937908999999998	Амурская область, Белогорский район, Никольский с/с, с.Киселеозерка, Школьная, 8А		0101000020E610000090A339B2F2036040E1CFF0660D784940
17225	4	38	600	55749	46781	\N	50.881833316588803	Амурская область, Белогорский район, Кустанаевский с/с, с.Камышовка, Степная, 16	Россия, Амурская область, Белогорский район, поселок Камышевка	0101000020E61000006B82A8FB800760404CC45BE7DF704940
17209	4	38	600	4377	46945	\N	50.623029000000002	Амурская область, Белогорский район, Озерянский сельсовет, с.Заречное, Комсомольская, 12		0101000020E61000003DBA111615146040D4BA0D6ABF4F4940
17204	4	38	600	4132	47198	\N	50.683798000000003	Амурская область, Белогорский район, Амурский сельсовет, с.Дубровка, Центральная, 1		0101000020E61000004E9A0645731B6040FD885FB186574940
17208	4	38	600	4220	46370	\N	50.730043000000002	Амурская область, Белогорский район, Возжаевский сельсовет,с.Возжаевка, м-н Южный		0101000020E6100000FDBE7FF3E21660403DD68C0C725D4940
17207	4	38	600	4220	46774	\N	50.730043000000002	Амурская область, Белогорский район, Возжаевский сельсовет,с.Возжаевка, Центральная, 9		0101000020E6100000FDBE7FF3E21660403DD68C0C725D4940
17206	4	38	600	4220	46492	\N	50.730043000000002	Амурская область, Белогорский район, Возжаевский сельсовет,с.Возжаевка, Гагарина, 18		0101000020E6100000FDBE7FF3E21660403DD68C0C725D4940
17229	4	38	600	5455	46634	\N	50.916704000000003	Амурская область, Белогорский район, Великокнязевский, с.Великонязевка, Мира, 76		0101000020E61000006891ED7C3FFA5F40630E828E56754940
17199	4	38	600	3865	46482	\N	50.887535999999997	Амурская область, Белогорский район, Васильевский с/с, с.Васильевка, Школьная, 14б		0101000020E61000002DAF5C6F9B136040E60297C79A714940
17214	4	38	600	4642	47050	\N	50.769361000000004	Амурская область, Белогорский район, Белоцерковский с/с,с.Белоцерковка, Школьная, 25		0101000020E6100000842BA050CF0F6040B0E8D66B7A624940
17244	4	38	600	5033	46486	\N	50.902448999999997	Амурская область, город Белогорск, пер. Летний, 21		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17250	4	38	600	5033	46548	\N	50.902448999999997	Амурская область, город Белогорск, Шевченко, 63		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17234	4	38	600	5033	46425	\N	50.902448999999997	Амурская область, город Белогорск, Ударная, 24		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17249	4	38	600	5033	46433	\N	50.902448999999997	Амурская область, город Белогорск, Производственная, 11		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17235	4	38	600	5033	46428	\N	50.902448999999997	Амурская область, город Белогорск, Партизанская, 26		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17258	4	38	600	5033	46434	\N	50.902448999999997	Амурская область, город Белогорск, Никольское шоссе, 164		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17254	4	38	600	5033	46434	\N	50.902448999999997	Амурская область, город Белогорск, Никольское шоссе, 31		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17237	4	38	600	5033	46372	\N	50.8957186234109	Амурская область, город Белогорск, Набережная, 90	Россия, Амурская область, Белогорский район, Белогорск	0101000020E6100000DD28B2D650106040F2B391EBA6724940
17246	4	38	600	5033	46544	\N	50.902448999999997	Амурская область, город Белогорск, Матросская, 62		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17238	4	38	600	5033	9933	\N	50.902448999999997	Амурская область, город Белогорск, Ленина, 100		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17221	4	38	600	5033	9933	\N	50.902448999999997	Амурская область, город Белогорск, Ленина, 16		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17239	4	38	600	5033	46484	\N	50.902448999999997	Амурская область, город Белогорск, Красноармейская, 6		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17248	4	38	600	5033	46485	\N	50.902448999999997	Амурская область, город Белогорск, Кирова, 267		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17243	4	38	600	5033	46485	\N	50.902448999999997	Амурская область, город Белогорск, Кирова, 249/2		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17253	4	38	600	5033	46430	\N	50.902448999999997	Амурская область, город Белогорск, Калининская, 57		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17262	4	38	600	5033	46864	\N	50.877910881793397	Амурская область, город Белогорск, Вокзальная, 16	Россия, Амурская область, Белогорский район, Белогорск	0101000020E6100000973C9E969F1060403AE63C635F704940
17252	4	38	600	5033	46549	\N	50.902448999999997	Амурская область, город Белогорск, Благовещенская, 16		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17251	4	38	600	5033	46549	\N	50.902448999999997	Амурская область, город Белогорск, Благовещенская, 65А		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17256	4	38	600	5033	46551	\N	50.902448999999997	Амурская область, город Белогорск, Авиационная, 42		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17255	4	38	600	5033	46551	\N	50.902448999999997	Амурская область, город Белогорск, Авиационная, 5А		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17245	4	38	600	5033	46427	\N	50.902448999999997	Амурская область, город Белогорск, 9 мая, 212А		0101000020E6100000A7B1BD16F40E604069A7E67283734940
17205	4	38	600	4175	46573	\N	50.741090999999997	Амурская область, Белогорский район, Амурский сельсовет, с.Амурское, Школьная, 1		0101000020E610000003CE52B29C176040122EE411DC5E4940
17178	4	38	428	2672	46904	\N	49.434345	Амурская область, Архаринский район, село Черноберезовка, ул. Зеленая, д. 12 кв. 1		0101000020E61000008D2441B8824860402F17F19D98B74840
17196	4	38	428	3704	46861	\N	49.618955	Амурская область, Архаринский район, село Черниговка, ул. Советская, д. 3		0101000020E6100000895FB1860B3E60400C59DDEA39CF4840
17195	4	38	428	3671	46943	\N	49.229104999999997	Амурская область, Архаринский район, село Урил, ул. Лесная, д. 13		0101000020E6100000B2F1608B5D4F6040CF2C0950539D4840
17194	4	38	428	3620	46776	\N	49.449847072062298	Амурская область, Архаринский район, село Северное, ул. Амурская, д. 20	Россия, Амурская область, Архаринский район, поселок Северное	0101000020E6100000E0D6DD3CD5316040139A249694B94840
17192	4	38	428	3479	46574	\N	49.355009000000003	Амурская область, Архаринский район, село Отважное, ул. Центральная, д. 29 кв. 1		0101000020E61000003B71395E81436040916456EF70AD4840
17189	4	38	428	3338	46708	\N	49.652467999999999	Амурская область, Архаринский район, село Новоспасск, ул. Школьная, д. 4		0101000020E61000009483D90418396040E0D7481284D34840
17191	4	38	428	3477	46773	\N	49.235618000000002	Амурская область, Архаринский район, село Новосергеевка, ул. Центральная, д. 12		0101000020E610000096D05D1267496040AA2C0ABB289E4840
17752	4	38	428	3477	47136	\N	49.235618000000002	Новосергеевка, Октябрьская, 67		0101000020E610000096D05D1267496040AA2C0ABB289E4840
17185	4	38	428	3134	47196	\N	48.906163999999997	Амурская область, Архаринский район, село Новопокровка, ул. Центральная, д. 2 кв. 2		0101000020E61000007D7555A0964660400168942EFD734840
17187	4	38	428	3250	47017	\N	49.257666	Амурская область, Архаринский район, село Ленинское, ул. Ленинская, д. 49		0101000020E6100000E8667FA05C3E604044A51133FBA04840
17186	4	38	428	3142	46598	\N	49.1019795965803	Амурская область, Архаринский район, село Кундур, ул. Центральная, д. 5	Россия, Амурская область, Архаринский район, поселок Кундур	0101000020E6100000A52E19C7485860404C6C3EAE0D8D4840
17188	4	38	428	3284	47003	\N	49.284264999999998	Амурская область, Архаринский район, село Красный Исток, ул. Центральная, д. 1		0101000020E6100000C5C9FD0E45416040DF32A7CB62A44840
17183	4	38	428	2991	46926	\N	48.973193999999999	Амурская область, Архаринский район, село Касаткино, ул. Гапонова, д. 20		0101000020E610000062F4DC4257426040EB54F99E917C4840
17193	4	38	428	3578	47205	\N	49.311624000000002	Амурская область, Архаринский район, село Каменный Карьер, ул. Центральная, д. 18		0101000020E61000001C96067ED44560400953944BE3A74840
17182	4	38	428	2924	46707	\N	49.299095000000001	Амурская область, Архаринский район, село Иннокентьевка, ул. Калинина, д. 51		0101000020E61000000BD28C4553366040D5B2B5BE48A64840
17184	4	38	428	3032	46923	\N	49.080466000000001	Амурская область, Архаринский район, село Журавлевка, ул. Центральная, д. 20		0101000020E6100000D4D51D8BED3F60405038BBB54C8A4840
17190	4	38	428	3382	47200	\N	49.685234000000001	Амурская область, Архаринский район, село Домикан, ул. Центральная, д. 10		0101000020E6100000035FD1ADD73B6040BB0D6ABFB5D74840
17181	4	38	428	2879	46772	\N	49.471590999999997	Амурская область, Архаринский район, село Грибовка, ул. Центральная, д. 46		0101000020E6100000DE8E705AF04B6040410B09185DBC4840
17180	4	38	428	2818	\N	\N	49.275561000000003	Амурская область, Архаринский район, село Вольное, ул. Центральная, д. 17	Россия, Амурская область, Архаринский район, поселок Вольное	0101000020E61000000EBC5AEE4C3D6040CB86359545A34840
17172	4	38	428	55705	46483	\N	49.422016999999997	Амурская область, Архаринский район, поселок городского типа Архара, ул. Школьная, д. 4		0101000020E61000008143A852B342604092AD2EA704B64840
17175	4	38	428	55705	46429	\N	49.422016999999997	Амурская область, Архаринский район, поселок городского типа Архара, ул. Ленина, д. 109		0101000020E61000008143A852B342604092AD2EA704B64840
17173	4	38	428	2322	46356	\N	49.422016999999997	Амурская область, Архаринский район, поселок городского типа Архара, ул. Восточная, д. 159		0101000020E61000008143A852B342604092AD2EA704B64840
17171	4	38	428	2322	46356	\N	49.422016999999997	Амурская область, Архаринский район, поселок городского типа Архара, ул. Восточная, д. 69		0101000020E61000008143A852B342604092AD2EA704B64840
17174	4	38	428	2322	46369	\N	49.422016999999997	Амурская область, Архаринский район, поселок городского типа Архара, ул. Больничная, д. 9		0101000020E61000008143A852B342604092AD2EA704B64840
17177	4	38	428	2669	46572	\N	49.403807	Амурская область, Архаринский район, село Аркадьевка, ул. Паромная, д. 2		0101000020E61000003A5D16139B446040AC72A1F2AFB34840
17179	4	38	428	2769	47138	\N	49.431170000000002	Амурская область, Архаринский район, село Антоновка, ул. Центральная, д. 4		0101000020E61000008C69A67B1D3E604017821C9430B74840
\.


--
-- Data for Name: street; Type: TABLE DATA; Schema: public; Owner: -
--

COPY street (id, locality_id, bounds_left, bounds_right, bounds_top, bounds_bottom, name, box) FROM stdin;
57312	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57332	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Хрущева	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57355	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Хомутникова	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57428	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Северный	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57359	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	С.Стальского 	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57318	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Рокчинского	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57322	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Пушкина	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57328	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Николаева	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57313	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Мира	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57348	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Лесная	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57326	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Ленина 	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57315	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Ленина	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57324	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Леваневского	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57358	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Илишкина	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57445	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Добровольского	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57364	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Губаревича	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57365	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Гагарина	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57327	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	Волгоградская	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57317	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	8микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57323	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	8 микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57357	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	8 Марта	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57344	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	6 микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57339	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	5 микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57330	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	4 микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57360	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	3 мкр	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57351	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	3 микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57346	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	28 Армии	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57342	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	2 микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57349	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	1мкр	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57356	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	1 микрорайон	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57363	11360	44.199852	44.325814000000001	46.371060999999997	46.290489000000001	 Маяковского 	0103000020E61000000100000005000000250516C094194640836C59BE2E254740250516C09419464018E945ED7E2F47401B4AED45B429464018E945ED7E2F47401B4AED45B4294640836C59BE2E254740250516C094194640836C59BE2E254740
57458	57159	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	микрорайон	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57373	57159	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Свердлова	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57415	57159	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Пришкольная	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57456	57159	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Колхозная	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57387	57159	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Дружбы	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57388	32542	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	Ленина	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
57336	32542	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	Клыкова	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
57427	32542	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	Кирова	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
57353	57153	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	Лиджиева	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
57335	57153	45.328665999999998	45.364077000000002	46.184826999999999	46.156387000000002	Леджинова	0103000020E6100000010000000500000050A73CBA11AA464081423D7D0414474050A73CBA11AA46407A354069A8174740E71C3C139AAE46407A354069A8174740E71C3C139AAE464081423D7D0414474050A73CBA11AA464081423D7D04144740
57471	57204	45.087198999999998	45.110815000000002	46.110596000000001	46.090674	Советская	0103000020E61000000100000005000000389F3A56298B46407B4CA4349B0B4740389F3A56298B4640C2887D02280E47400074982F2F8E4640C2887D02280E47400074982F2F8E46407B4CA4349B0B4740389F3A56298B46407B4CA4349B0B4740
57461	57195	45.078924999999998	45.101211999999997	46.217692999999997	46.203285999999999	60 лет Октября	0103000020E610000001000000050000001CEBE2361A8A464009DE9046051A47401CEBE2361A8A4640B8C83D5DDD1B47403BFBCA83F48C4640B8C83D5DDD1B47403BFBCA83F48C464009DE9046051A47401CEBE2361A8A464009DE9046051A4740
57345	57155	42.253787000000003	42.295611999999998	46.350636999999999	46.329259999999998	переулок Школьный	0103000020E610000001000000050000003293A8177C204540C3F01131252A47403293A8177C2045403FE257ACE12C47400F27309DD62545403FE257ACE12C47400F27309DD6254540C3F01131252A47403293A8177C204540C3F01131252A4740
57325	22386	42.253787000000003	42.295611999999998	46.350636999999999	46.329259999999998	Ленина	0103000020E610000001000000050000003293A8177C204540C3F01131252A47403293A8177C2045403FE257ACE12C47400F27309DD62545403FE257ACE12C47400F27309DD6254540C3F01131252A47403293A8177C204540C3F01131252A4740
57390	22377	42.207245	42.263461	46.209117999999997	46.195357999999999	имени Карла Маркса	0103000020E6100000010000000500000038A11001871A45408881AE7D0119474038A11001871A4540A180ED60C41A4740BF620D17B9214540A180ED60C41A4740BF620D17B92145408881AE7D0119474038A11001871A45408881AE7D01194740
57338	46412	42.235605	42.284446000000003	46.291784999999997	46.272091000000003	Школьная	0103000020E6100000010000000500000015E3FC4D281E45409A44BDE0D322474015E3FC4D281E45404F3BFC355925474030BDFDB9682445404F3BFC355925474030BDFDB9682445409A44BDE0D322474015E3FC4D281E45409A44BDE0D3224740
57366	22275	42.522751	42.563211000000003	46.247317000000002	46.208705999999999	Ленина	0103000020E61000000100000005000000C4793881E94245404F3DD2E0B61A4740C4793881E9424540575F5D15A81F4740ADDF4C4C17484540575F5D15A81F4740ADDF4C4C174845404F3DD2E0B61A4740C4793881E94245404F3DD2E0B61A4740
57409	57169	42.328004999999997	42.370477999999999	46.420920000000002	46.405810000000002	Школьная	0103000020E6100000010000000500000055F65D11FC294540E4310395F133474055F65D11FC294540BD1DE1B4E035474099F1B6D26B2F4540BD1DE1B4E035474099F1B6D26B2F4540E4310395F133474055F65D11FC294540E4310395F1334740
57443	45563	42.157451000000002	42.200947999999997	46.548316999999997	46.536211999999999	Центральная	0103000020E610000001000000050000007BDCB75A2714454083DC4598A24447407BDCB75A27144540A06B5F402F4647402A1900AAB8194540A06B5F402F4647402A1900AAB819454083DC4598A24447407BDCB75A2714454083DC4598A2444740
57467	57199	42.350436000000002	42.377654999999997	46.221845999999999	46.205500999999998	Спортивный переулок	0103000020E61000000100000005000000A8AB3B16DB2C4540CC2555DB4D1A4740A8AB3B16DB2C4540CC5F2173651C4740DF15C1FF56304540CC5F2173651C4740DF15C1FF56304540CC2555DB4D1A4740A8AB3B16DB2C4540CC2555DB4D1A4740
57404	22025	42.522751	42.552027000000002	46.179867000000002	46.153109000000001	Школьная	0103000020E61000000100000005000000C4793881E942454094DC611399134740C4793881E94245409850C1E10517474027C11BD2A84645409850C1E10517474027C11BD2A846454094DC611399134740C4793881E942454094DC611399134740
57403	21882	42.385857000000001	42.402422000000001	46.267431000000002	46.249510000000001	Кооперативная	0103000020E6100000010000000500000062F71DC363314540320395F1EF1F474062F71DC363314540E277D32D3B2247407098689082334540E277D32D3B2247407098689082334540320395F1EF1F474062F71DC363314540320395F1EF1F4740
57453	2227	42.215806000000001	42.239457999999999	46.460577999999998	46.448036999999999	Пионерская	0103000020E61000000100000005000000EA23F0879F1B4540F032C34659394740EA23F0879F1B4540E8A04B38F43A4740FE614B8FA61E4540E8A04B38F43A4740FE614B8FA61E4540F032C34659394740EA23F0879F1B4540F032C34659394740
57389	33019	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	переулок Мацакова	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
57432	33019	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	Хомутникова	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
57376	33019	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	Советская	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
57400	33019	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	Кирова	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
57402	33019	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	Городовикова	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
57383	57165	46.706285999999999	46.736479000000003	47.577182999999998	47.536903000000002	переулок Школьный	0103000020E61000000100000005000000B3CF6394675A4740E90FCD3CB9C44740B3CF6394675A47405167EE21E1C947406C98A1F1445E47405167EE21E1C947406C98A1F1445E4740E90FCD3CB9C44740B3CF6394675A4740E90FCD3CB9C44740
57429	57175	46.162823000000003	46.172964999999998	47.029021	47.023620999999999	Центральная	0103000020E61000000100000005000000B0045262D7144740D93F4F0306834740B0045262D7144740D8F2CAF5B6834740232D95B723164740D8F2CAF5B6834740232D95B723164740D93F4F0306834740B0045262D7144740D93F4F0306834740
57442	57185	44.199618000000001	44.209724000000001	46.367511	46.356354000000003	Школьная	0103000020E61000000100000005000000B2D826158D1946403FE603029D2D4740B2D826158D194640CBF5B6990A2F4740D9976C3CD81A4640CBF5B6990A2F4740D9976C3CD81A46403FE603029D2D4740B2D826158D1946403FE603029D2D4740
57450	57187	45.465336000000001	45.479996	45.826897000000002	45.813757000000003	Интернациональная	0103000020E6100000010000000500000063D34A2190BB46400FF27A3029E8464063D34A2190BB46408C14CAC2D7E94640FC1A498270BD46408C14CAC2D7E94640FC1A498270BD46400FF27A3029E8464063D34A2190BB46400FF27A3029E84640
57405	32999	45.807423	45.827742999999998	45.258473000000002	45.245789000000002	Комсомольская	0103000020E61000000100000005000000E48409A359E74640B85B9203769F4640E48409A359E7464013F3ACA415A14640183F8D7BF3E9464013F3ACA415A14640183F8D7BF3E94640B85B9203769F4640E48409A359E74640B85B9203769F4640
57470	57203	46.535966000000002	46.550285000000002	45.440764000000001	45.429715000000002	Советская	0103000020E610000001000000050000004CE2AC889A444740E2CCAFE600B746404CE2AC889A44474088A06AF46AB846405C3D27BD6F46474088A06AF46AB846405C3D27BD6F464740E2CCAFE600B746404CE2AC889A444740E2CCAFE600B74640
57465	57198	46.055241000000002	46.074528000000001	44.983905	44.975501999999999	Ленина	0103000020E61000000100000005000000FD321823120747405F97E13FDD7C4640FD3218231207474079AF5A99F07D464072512D228A09474079AF5A99F07D464072512D228A0947405F97E13FDD7C4640FD321823120747405F97E13FDD7C4640
57420	57170	46.839021000000002	46.846738000000002	45.745150000000002	45.739916999999998	Ленина	0103000020E6100000010000000500000020D4450A656B47409160AA99B5DE464020D4450A656B4740A54E401361DF4640E62329E9616C4740A54E401361DF4640E62329E9616C47409160AA99B5DE464020D4450A656B47409160AA99B5DE4640
57397	32984	46.022435000000002	46.057755999999998	45.337316999999999	45.321202999999997	Некрасова	0103000020E6100000010000000500000094A46B26DF02474044300E2E1DA9464094A46B26DF02474042B115342DAB4640EA92718C6407474042B115342DAB4640EA92718C6407474044300E2E1DA9464094A46B26DF02474044300E2E1DA94640
57399	32984	46.022435000000002	46.057755999999998	45.337316999999999	45.321202999999997	Ленина	0103000020E6100000010000000500000094A46B26DF02474044300E2E1DA9464094A46B26DF02474042B115342DAB4640EA92718C6407474042B115342DAB4640EA92718C6407474044300E2E1DA9464094A46B26DF02474044300E2E1DA94640
57347	32984	46.022435000000002	46.057755999999998	45.337316999999999	45.321202999999997	Аллея Памяти	0103000020E6100000010000000500000094A46B26DF02474044300E2E1DA9464094A46B26DF02474042B115342DAB4640EA92718C6407474042B115342DAB4640EA92718C6407474044300E2E1DA9464094A46B26DF02474044300E2E1DA94640
57375	57161	45.347664999999999	45.370671000000002	45.411482999999997	45.393853	Ленина	0103000020E610000001000000050000005F7B664980AC46403B376DC669B246405F7B664980AC464013EE9579ABB44640AE49B72572AF464013EE9579ABB44640AE49B72572AF46403B376DC669B246405F7B664980AC46403B376DC669B24640
57398	32962	46.642712000000003	46.678178000000003	44.957416000000002	44.936185999999999	переулок Кооперативный	0103000020E61000000100000005000000965F0663445247408D7C5EF1D4774640965F0663445247406555849B8C7A4640F06E6589CE5647406555849B8C7A4640F06E6589CE5647408D7C5EF1D4774640965F0663445247408D7C5EF1D4774640
57422	32962	46.642712000000003	46.678178000000003	44.957416000000002	44.936185999999999	Советская	0103000020E61000000100000005000000965F0663445247408D7C5EF1D4774640965F0663445247406555849B8C7A4640F06E6589CE5647406555849B8C7A4640F06E6589CE5647408D7C5EF1D4774640965F0663445247408D7C5EF1D4774640
57437	32962	46.642712000000003	46.678178000000003	44.957416000000002	44.936185999999999	Д. Адьянова	0103000020E61000000100000005000000965F0663445247408D7C5EF1D4774640965F0663445247406555849B8C7A4640F06E6589CE5647406555849B8C7A4640F06E6589CE5647408D7C5EF1D4774640965F0663445247408D7C5EF1D4774640
57423	57172	45.623052999999999	45.640318000000001	45.809907000000003	45.796152999999997	Мира	0103000020E610000001000000050000005C566133C0CF46405FCE6C57E8E546405C566133C0CF464097E65608ABE746402385B2F0F5D1464097E65608ABE746402385B2F0F5D146405FCE6C57E8E546405C566133C0CF46405FCE6C57E8E54640
57378	32888	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	Чапаева	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
57331	32888	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	Физкультурная	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
57352	32888	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	Пушкина	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
57361	32888	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	Октябрьская	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
57426	32888	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	Ленина	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
57370	32888	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	Колхозная	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
57354	32888	44.214575000000004	44.289817999999997	46.432125999999997	46.406523999999997	Геологическая	0103000020E6100000010000000500000005C58F31771B464001857AFA0834474005C58F31771B46402AE09EE74F37474064E597C1182546402AE09EE74F37474064E597C11825464001857AFA0834474005C58F31771B464001857AFA08344740
57394	32778	43.753686000000002	43.786150999999997	47.674593000000002	47.660854999999998	Хомутникова	0103000020E61000000100000005000000FEB968C878E04540F4328AE596D44740FEB968C878E04540268E3C1059D64740DD5B9198A0E44540268E3C1059D64740DD5B9198A0E44540F4328AE596D44740FEB968C878E04540F4328AE596D44740
57449	57186	44.246994999999998	44.293348000000002	47.738914000000001	47.725774999999999	Ленина	0103000020E6100000010000000500000044A33B889D1F464090A0F831E6DC474044A33B889D1F46403D47E4BB94DE47406B2C616D8C2546403D47E4BB94DE47406B2C616D8C25464090A0F831E6DC474044A33B889D1F464090A0F831E6DC4740
57441	57183	43.854053999999998	43.888505000000002	47.514591000000003	47.496513	Школьная	0103000020E610000001000000050000004D8237A451ED4540F984ECBC8DBF47404D8237A451ED454071E82D1EDEC147408FAA2688BAF1454071E82D1EDEC147408FAA2688BAF14540F984ECBC8DBF47404D8237A451ED4540F984ECBC8DBF4740
57454	57183	43.854053999999998	43.888505000000002	47.514591000000003	47.496513	Бадмаева	0103000020E610000001000000050000004D8237A451ED4540F984ECBC8DBF47404D8237A451ED454071E82D1EDEC147408FAA2688BAF1454071E82D1EDEC147408FAA2688BAF14540F984ECBC8DBF47404D8237A451ED4540F984ECBC8DBF4740
57337	57154	44.490250000000003	44.535525	47.790559000000002	47.756405000000001	Ленина	0103000020E61000000100000005000000986E1283C03E4640F4C308E1D1E04740986E1283C03E46407C478D0931E547405F984C158C4446407C478D0931E547405F984C158C444640F4C308E1D1E04740986E1283C03E4640F4C308E1D1E04740
57372	57154	44.490250000000003	44.535525	47.790559000000002	47.756405000000001	Дорожная	0103000020E61000000100000005000000986E1283C03E4640F4C308E1D1E04740986E1283C03E46407C478D0931E547405F984C158C4446407C478D0931E547405F984C158C444640F4C308E1D1E04740986E1283C03E4640F4C308E1D1E04740
57419	32825	44.407083999999998	44.435974000000002	47.525239999999997	47.49879	Колхозная	0103000020E61000000100000005000000C85C19541B34464032C9C859D8BF4740C85C19541B344640884677103BC3474002F4FBFECD374640884677103BC3474002F4FBFECD37464032C9C859D8BF4740C85C19541B34464032C9C859D8BF4740
57472	57205	44.369948000000001	44.397238999999999	47.822778	47.804541	Школьная	0103000020E610000001000000050000003D9CC0745A2F464044A51133FBE647403D9CC0745A2F464024EF1CCA50E947400ED940BAD832464024EF1CCA50E947400ED940BAD832464044A51133FBE647403D9CC0745A2F464044A51133FBE64740
57464	57191	44.480547999999999	44.510902000000002	47.656405999999997	47.639142	Центральная	0103000020E610000001000000050000004014CC98823D464001C0B167CFD147404014CC98823D4640F7729F1C05D4474002BB9A3C65414640F7729F1C05D4474002BB9A3C6541464001C0B167CFD147404014CC98823D464001C0B167CFD14740
57455	57191	44.480547999999999	44.510902000000002	47.656405999999997	47.639142	Зеленая	0103000020E610000001000000050000004014CC98823D464001C0B167CFD147404014CC98823D4640F7729F1C05D4474002BB9A3C65414640F7729F1C05D4474002BB9A3C6541464001C0B167CFD147404014CC98823D464001C0B167CFD14740
57374	57160	44.025381000000003	44.070197999999998	47.608581999999998	47.589593999999998	Лесная	0103000020E610000001000000050000004B7842AF3F0346407BF5F1D077CB47404B7842AF3F0346409677D503E6CD47404F1F813FFC0846409677D503E6CD47404F1F813FFC0846407BF5F1D077CB47404B7842AF3F0346407BF5F1D077CB4740
57380	57164	44.597410000000004	44.622599000000001	47.616418000000003	47.599316999999999	Дорожная	0103000020E61000000100000005000000D5264EEE774C4640EA77616BB6CC4740D5264EEE774C46403755F7C8E6CE4740DBC2F352B14F46403755F7C8E6CE4740DBC2F352B14F4640EA77616BB6CC4740D5264EEE774C4640EA77616BB6CC4740
57425	18955	43.758338999999999	43.774760000000001	46.133682999999998	46.121822000000002	Дружбы	0103000020E6100000010000000500000003249A4011E1454077F700DD970F474003249A4011E14540FD8348861C114740DE1FEF552BE34540FD8348861C114740DE1FEF552BE3454077F700DD970F474003249A4011E1454077F700DD970F4740
57362	18763	43.482035000000003	43.532986999999999	46.111721000000003	46.089030000000001	Московская	0103000020E610000001000000050000008143A852B3BD4540732EC555650B47408143A852B3BD454062A3ACDF4C0E4740B91803EB38C4454062A3ACDF4C0E4740B91803EB38C44540732EC555650B47408143A852B3BD4540732EC555650B4740
57343	18763	43.482035000000003	43.532986999999999	46.111721000000003	46.089030000000001	Канукова	0103000020E610000001000000050000008143A852B3BD4540732EC555650B47408143A852B3BD454062A3ACDF4C0E4740B91803EB38C4454062A3ACDF4C0E4740B91803EB38C44540732EC555650B47408143A852B3BD4540732EC555650B4740
57385	18763	43.482035000000003	43.532986999999999	46.111721000000003	46.089030000000001	Ильина	0103000020E610000001000000050000008143A852B3BD4540732EC555650B47408143A852B3BD454062A3ACDF4C0E4740B91803EB38C4454062A3ACDF4C0E4740B91803EB38C44540732EC555650B47408143A852B3BD4540732EC555650B4740
57333	18763	43.482035000000003	43.532986999999999	46.111721000000003	46.089030000000001	Гагарина	0103000020E610000001000000050000008143A852B3BD4540732EC555650B47408143A852B3BD454062A3ACDF4C0E4740B91803EB38C4454062A3ACDF4C0E4740B91803EB38C44540732EC555650B47408143A852B3BD4540732EC555650B4740
57466	18686	44.152330999999997	44.170521999999998	46.240723000000003	46.227974000000003	Гагарина	0103000020E610000001000000050000005F950B957F1346404E2B85402E1D47405F950B957F1346409032E202D01E4740CF9F36AAD31546409032E202D01E4740CF9F36AAD31546404E2B85402E1D47405F950B957F1346404E2B85402E1D4740
57371	32706	44.176397000000001	44.197777000000002	45.887976000000002	45.875014	Советская	0103000020E61000000100000005000000670E492D9416464065C5707500F04640670E492D9416464003D19332A9F146405473B9C15019464003D19332A9F146405473B9C15019464065C5707500F04640670E492D9416464065C5707500F04640
57452	18440	44.231535000000001	44.248154	46.264333999999998	46.252988000000002	Степная	0103000020E610000001000000050000008F705AF0A21D4640E62329E9612047408F705AF0A21D4640459C4EB2D5214740902FA182C31F4640459C4EB2D5214740902FA182C31F4640E62329E9612047408F705AF0A21D4640E62329E961204740
57459	18549	43.881489000000002	43.898834999999998	46.122703000000001	46.114407	Школьная	0103000020E610000001000000050000005264ADA1D4F045407CB779E3A40E47405264ADA1D4F04540800F5EBBB40F474005C078060DF34540800F5EBBB40F474005C078060DF345407CB779E3A40E47405264ADA1D4F045407CB779E3A40E4740
57438	57179	45.396399000000002	45.408095000000003	47.235626000000003	47.224831999999999	Октябрьская	0103000020E610000001000000050000006495D233BDB24640118C834BC79C47406495D233BDB246402D0B26FE289E4740A054FB743CB446402D0B26FE289E4740A054FB743CB44640118C834BC79C47406495D233BDB24640118C834BC79C4740
57451	57188	45.505167	45.527588999999999	47.802076999999997	47.787005000000001	Советская	0103000020E610000001000000050000005C02F04FA9C04640ED647094BCE447405C02F04FA9C04640D8EF8975AAE647405B5D4E0988C34640D8EF8975AAE647405B5D4E0988C34640ED647094BCE447405C02F04FA9C04640ED647094BCE44740
57439	57180	45.513340999999997	45.54233	47.449503999999997	47.420003999999999	Северная	0103000020E6100000010000000500000014596B28B5C146403718EAB0C2B5474014596B28B5C14640E9B5D95889B94740E1D1C6116BC54640E9B5D95889B94740E1D1C6116BC546403718EAB0C2B5474014596B28B5C146403718EAB0C2B54740
57436	57177	45.751340999999996	45.765552	47.666364999999999	47.652546000000001	Квартал	0103000020E610000001000000050000006C921FF12BE046405C9198A086D347406C921FF12BE046407A19C5724BD5474096B1A19BFDE146407A19C5724BD5474096B1A19BFDE146405C9198A086D347406C921FF12BE046405C9198A086D34740
57368	57157	45.283732000000001	45.308346	47.885930000000002	47.875686999999999	Советская	0103000020E61000000100000005000000126A865451A446402444F98216F04740126A865451A44640CC457C2766F147401CEDB8E177A74640CC457C2766F147401CEDB8E177A746402444F98216F04740126A865451A446402444F98216F04740
57386	32600	45.411633999999999	45.457583	47.865955999999997	47.835917000000002	Советская	0103000020E61000000100000005000000F9F5436CB0B44640D1950854FFEA4740F9F5436CB0B4464032E36DA5D7EE4740501A6A1492BA464032E36DA5D7EE4740501A6A1492BA4640D1950854FFEA4740F9F5436CB0B44640D1950854FFEA4740
57334	32600	45.411633999999999	45.457583	47.865955999999997	47.835917000000002	Матросова	0103000020E61000000100000005000000F9F5436CB0B44640D1950854FFEA4740F9F5436CB0B4464032E36DA5D7EE4740501A6A1492BA464032E36DA5D7EE4740501A6A1492BA4640D1950854FFEA4740F9F5436CB0B44640D1950854FFEA4740
57396	32600	45.411633999999999	45.457583	47.865955999999997	47.835917000000002	Ломоносова	0103000020E61000000100000005000000F9F5436CB0B44640D1950854FFEA4740F9F5436CB0B4464032E36DA5D7EE4740501A6A1492BA464032E36DA5D7EE4740501A6A1492BA4640D1950854FFEA4740F9F5436CB0B44640D1950854FFEA4740
57392	32600	45.411633999999999	45.457583	47.865955999999997	47.835917000000002	Горького	0103000020E61000000100000005000000F9F5436CB0B44640D1950854FFEA4740F9F5436CB0B4464032E36DA5D7EE4740501A6A1492BA464032E36DA5D7EE4740501A6A1492BA4640D1950854FFEA4740F9F5436CB0B44640D1950854FFEA4740
57463	17762	44.866213000000002	44.883181999999998	47.705502000000003	47.696812000000001	Г.Даваева	0103000020E610000001000000050000005E2F4D11E06E4640EDBAB72231D947405E2F4D11E06E46409DA1B8E34DDA47403B35971B0C7146409DA1B8E34DDA47403B35971B0C714640EDBAB72231D947405E2F4D11E06E4640EDBAB72231D94740
57457	17682	44.706771000000003	44.723120000000002	47.823202000000002	47.813248999999999	пер.Школьный	0103000020E610000001000000050000007061DD78775A46409A40118B18E847407061DD78775A46403B00E2AE5EE94740B18A37328F5C46403B00E2AE5EE94740B18A37328F5C46409A40118B18E847407061DD78775A46409A40118B18E84740
57321	17573	44.603887	44.645892000000003	47.949553999999999	47.930655000000002	Ленина	0103000020E6100000010000000500000062BD512B4C4D4640F06DFAB31FF7474062BD512B4C4D46409BE447FC8AF94740C05FCC96AC5246409BE447FC8AF94740C05FCC96AC524640F06DFAB31FF7474062BD512B4C4D4640F06DFAB31FF74740
57382	17539	44.395173	44.455359999999999	48.146019000000003	48.125689000000001	А.Хадыкина	0103000020E6100000010000000500000090A1630795324640C53BC0931610484090A16307953246401DCC26C0B01248400AF4893C493A46401DCC26C0B01248400AF4893C493A4640C53BC0931610484090A1630795324640C53BC09316104840
57319	17366	44.661945000000003	44.695695000000001	47.968885999999998	47.930968999999997	Советская	0103000020E6100000010000000500000018601F9DBA5446407F4B00FE29F7474018601F9DBA544640B0C6D97404FC4740D07EA4880C594640B0C6D97404FC4740D07EA4880C5946407F4B00FE29F7474018601F9DBA5446407F4B00FE29F74740
57316	17366	44.661945000000003	44.695695000000001	47.968885999999998	47.930968999999997	40 лет Победы	0103000020E6100000010000000500000018601F9DBA5446407F4B00FE29F7474018601F9DBA544640B0C6D97404FC4740D07EA4880C594640B0C6D97404FC4740D07EA4880C5946407F4B00FE29F7474018601F9DBA5446407F4B00FE29F74740
57435	17345	45.663342	45.677554000000001	48.026653000000003	48.018034999999998	Китидова	0103000020E6100000010000000500000018080264E8D4464078978BF84E02484018080264E8D446408FAB915D6903484012A3E716BAD646408FAB915D6903484012A3E716BAD6464078978BF84E02484018080264E8D4464078978BF84E024840
57447	17268	45.204760999999998	45.239086	48.046408	48.037101	Э.Овла	0103000020E61000000100000005000000853FC39B359A46400FD3BEB9BF044840853FC39B359A4640EA2285B2F00548403A77BB5E9A9E4640EA2285B2F00548403A77BB5E9A9E46400FD3BEB9BF044840853FC39B359A46400FD3BEB9BF044840
57424	57173	46.844302999999996	46.864749000000003	45.450104000000003	45.426881000000002	Советская	0103000020E610000001000000050000001475E61E126C474053245F09A4B646401475E61E126C47403FE603029DB94640D61F6118B06E47403FE603029DB94640D61F6118B06E474053245F09A4B646401475E61E126C474053245F09A4B64640
57431	57173	46.844302999999996	46.864749000000003	45.450104000000003	45.426881000000002	Орджоникидзе	0103000020E610000001000000050000001475E61E126C474053245F09A4B646401475E61E126C47403FE603029DB94640D61F6118B06E47403FE603029DB94640D61F6118B06E474053245F09A4B646401475E61E126C474053245F09A4B64640
64946	57171	46.844302999999996	46.864749000000003	45.450104000000003	45.426881000000002	Пушкина	0103000020E610000001000000050000001475E61E126C474053245F09A4B646401475E61E126C47403FE603029DB94640D61F6118B06E47403FE603029DB94640D61F6118B06E474053245F09A4B646401475E61E126C474053245F09A4B64640
57418	33143	47.317886000000001	47.344206999999997	45.381174000000001	45.361026000000003	Школьная	0103000020E610000001000000050000009AED0A7DB0A84740BB80971936AE46409AED0A7DB0A84740F20A444FCAB04640F20698F90EAC4740F20A444FCAB04640F20698F90EAC4740BB80971936AE46409AED0A7DB0A84740BB80971936AE4640
57381	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	переулок Почтовый	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57410	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	микрорайон	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57350	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Советская	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57414	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Свердлова	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57444	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Садовая	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57413	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Рабочая	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57393	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Колхозная	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57401	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Кирова	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57412	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Канукова	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57395	33051	47.321668000000003	47.403351999999998	45.409103999999999	45.368796000000003	Ермолинская	0103000020E61000000100000005000000BA15C26A2CA94740A47213B534AF4640BA15C26A2CA94740D65416855DB446405A63D009A1B34740D65416855DB446405A63D009A1B34740A47213B534AF4640BA15C26A2CA94740A47213B534AF4640
57416	33140	47.310493000000001	47.353180999999999	45.450406999999998	45.440010999999998	Советская	0103000020E610000001000000050000008751103CBEA74740AC70CB4752B846408751103CBEA74740DA71C3EFA6B94640C748F60835AD4740DA71C3EFA6B94640C748F60835AD4740AC70CB4752B846408751103CBEA74740AC70CB4752B84640
57391	57166	47.421883999999999	47.455185	45.615851999999997	45.600195999999997	Ленина	0103000020E61000000100000005000000535A7F4B00B647405298F738D3CC4640535A7F4B00B647408D96033DD4CE46409C50888043BA47408D96033DD4CE46409C50888043BA47405298F738D3CC4640535A7F4B00B647405298F738D3CC4640
57448	57166	47.421883999999999	47.455185	45.615851999999997	45.600195999999997	Кирова	0103000020E61000000100000005000000535A7F4B00B647405298F738D3CC4640535A7F4B00B647408D96033DD4CE46409C50888043BA47408D96033DD4CE46409C50888043BA47405298F738D3CC4640535A7F4B00B647405298F738D3CC4640
57468	57201	45.194107000000002	45.204968000000001	47.345830999999997	47.337923000000004	Школьная	0103000020E610000001000000050000005C76887FD89846407AC8940F41AB47405C76887FD8984640B378B13044AC4740FF5C34643C9A4640B378B13044AC4740FF5C34643C9A46407AC8940F41AB47405C76887FD89846407AC8940F41AB4740
57434	15604	44.508450000000003	44.527557000000002	47.401294999999998	47.394122000000003	Октябрьская	0103000020E610000001000000050000005BD3BCE3144146402B51F69672B247405BD3BCE3144146402F8672A25DB3474050E3DEFC864346402F8672A25DB3474050E3DEFC864346402B51F69672B247405BD3BCE3144146402B51F69672B24740
57417	16032	44.789873999999998	44.807175999999998	46.858930999999998	46.845230999999998	Октябрьская	0103000020E61000000100000005000000F8FA5A971A6546405E488787306C4740F8FA5A971A654640A2427573F16D4740DC0E0D8B51674640A2427573F16D4740DC0E0D8B516746405E488787306C4740F8FA5A971A6546405E488787306C4740
57446	15880	44.863554000000001	44.887593000000003	47.250368999999999	47.233637000000002	Кошевого	0103000020E610000001000000050000003D2AFEEF886E46405A1135D1E79D47403D2AFEEF886E4640537765170CA047404B94BDA59C714640537765170CA047404B94BDA59C7146405A1135D1E79D47403D2AFEEF886E46405A1135D1E79D4740
57433	15974	45.041851999999999	45.054831999999998	47.414296999999998	47.395902999999997	Бадмаева	0103000020E61000000100000005000000D7A205685B854640B3B112F3ACB24740D7A205685B8546405BEA20AF07B547401B6327BC048746405BEA20AF07B547401B6327BC04874640B3B112F3ACB24740D7A205685B854640B3B112F3ACB24740
57462	15845	45.492536999999999	45.509883000000002	47.087094999999998	47.076822999999997	Центральная	0103000020E61000000100000005000000F488D1730BBF4640514A0856D5894740F488D1730BBF46409352D0ED258B4740A8E49CD843C146409352D0ED258B4740A8E49CD843C14640514A0856D5894740F488D1730BBF4640514A0856D5894740
57408	15375	44.499322999999997	44.551417000000001	47.316290000000002	47.297899000000001	Номто Очирова	0103000020E61000000100000005000000FF91E9D0E93F46406C41EF8D21A64740FF91E9D0E93F4640A306D3307CA84740AEBA0ED594464640A306D3307CA84740AEBA0ED5944646406C41EF8D21A64740FF91E9D0E93F46406C41EF8D21A64740
57407	15375	44.499322999999997	44.551417000000001	47.316290000000002	47.297899000000001	Ленина	0103000020E61000000100000005000000FF91E9D0E93F46406C41EF8D21A64740FF91E9D0E93F4640A306D3307CA84740AEBA0ED594464640A306D3307CA84740AEBA0ED5944646406C41EF8D21A64740FF91E9D0E93F46406C41EF8D21A64740
57379	15375	44.499322999999997	44.551417000000001	47.316290000000002	47.297899000000001	Заречная	0103000020E61000000100000005000000FF91E9D0E93F46406C41EF8D21A64740FF91E9D0E93F4640A306D3307CA84740AEBA0ED594464640A306D3307CA84740AEBA0ED5944646406C41EF8D21A64740FF91E9D0E93F46406C41EF8D21A64740
57384	15375	44.499322999999997	44.551417000000001	47.316290000000002	47.297899000000001	А. Мучкаева	0103000020E61000000100000005000000FF91E9D0E93F46406C41EF8D21A64740FF91E9D0E93F4640A306D3307CA84740AEBA0ED594464640A306D3307CA84740AEBA0ED5944646406C41EF8D21A64740FF91E9D0E93F46406C41EF8D21A64740
57411	15785	44.347273999999999	44.434213	46.941099999999999	46.929777999999999	Центральная	0103000020E6100000010000000500000024607479732C464028452BF70277474024607479732C4640FF21FDF675784740C03FA54A94374640FF21FDF675784740C03FA54A9437464028452BF70277474024607479732C464028452BF702774740
57406	14839	44.457183000000001	44.501452	47.112963000000001	47.097493999999998	Школьная	0103000020E61000000100000005000000C2A4F8F8843A464032C7F2AE7A8C4740C2A4F8F8843A46403B545392758E4740C44142942F4046403B545392758E4740C44142942F40464032C7F2AE7A8C4740C2A4F8F8843A464032C7F2AE7A8C4740
57460	15744	44.440959999999997	44.451208999999999	47.020131999999997	47.0122	Мира	0103000020E610000001000000050000000D6C9560713846406F8104C58F8147400D6C95607138464031CD74AF9382474097546D37C139464031CD74AF9382474097546D37C13946406F8104C58F8147400D6C9560713846406F8104C58F814740
57469	57202	44.478186000000001	44.511208000000003	47.244644000000001	47.229354000000001	Манджиева	0103000020E61000000100000005000000D9B3E732353D4640789ACC785B9D4740D9B3E732353D4640D1949D7E509F47400FBA84436F414640D1949D7E509F47400FBA84436F414640789ACC785B9D4740D9B3E732353D4640789ACC785B9D4740
57367	15647	44.909376999999999	44.932194000000003	47.047100999999998	47.030163000000002	Чапчаева	0103000020E61000000100000005000000075E2D77667446404E469561DC834740075E2D7766744640F04DD3670786474083C30B2252774640F04DD3670786474083C30B22527746404E469561DC834740075E2D77667446404E469561DC834740
57440	46265	41.982010000000002	42.012318999999998	46.265293999999997	46.250793999999999	Школьная	0103000020E61000000100000005000000282CF180B2FD44403A048E041A204740282CF180B2FD44409AE95E27F5214740490F43AB930145409AE95E27F5214740490F43AB930145403A048E041A204740282CF180B2FD44403A048E041A204740
56682	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	квартал 407-е	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56616	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Шоссейная	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56594	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Чкалова	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56731	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Хакурате	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56714	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Тульская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56630	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Советская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56652	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Пушкина	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56589	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Пролетарская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56643	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Привокзальная	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56745	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Пржевальского	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56770	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Пионерская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56615	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Первомайская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56755	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Мичурина	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56591	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	МОПРа	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56721	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Ленина	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56679	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Ленина	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56637	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Курганная	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56611	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Крестьянская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56625	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Краснооктябрьская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56657	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Красногвардейская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56648	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Комсомольская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56649	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Заводская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56712	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Железнодорожная	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56596	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Димитрова	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56618	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Депутатская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56707	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Гоголя	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56678	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Герцена	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56713	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Апшеронская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56610	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	8 Марта	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56672	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	7-й переулок	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56710	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	2-я Ветеранов	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56716	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	2 Ветеранов	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56614	57030	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	12 Марта	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
67075	58944	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Ленина	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
66891	58881	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Комсомольская	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
56702	57050	39.166367000000001	39.212145	44.897570000000002	44.872298999999998	Пушкина	0103000020E610000001000000050000001B118C834B954340B0AA5E7EA76F46401B118C834B95434074EFE192E372464045813E91279B434074EFE192E372464045813E91279B4340B0AA5E7EA76F46401B118C834B954340B0AA5E7EA76F4640
56696	57050	39.166367000000001	39.212145	44.897570000000002	44.872298999999998	Ленина	0103000020E610000001000000050000001B118C834B954340B0AA5E7EA76F46401B118C834B95434074EFE192E372464045813E91279B434074EFE192E372464045813E91279B4340B0AA5E7EA76F46401B118C834B954340B0AA5E7EA76F4640
9922	40357	39.887956000000003	40.365850999999999	45.122836999999997	44.913594000000003	Шовгенова	0103000020E61000000100000005000000BC24CE8AA8F1434032E9EFA5F0744640BC24CE8AA8F143408FDE701FB98F4640BD1AA034D42E44408FDE701FB98F4640BD1AA034D42E444032E9EFA5F0744640BC24CE8AA8F1434032E9EFA5F0744640
56732	57055	40.029414000000003	40.049239999999998	45.058382999999999	45.043233999999998	Школьная	0103000020E61000000100000005000000B40584D6C3034440A20914B188854640B40584D6C303444039D2191879874640D8D30E7F4D06444039D2191879874640D8D30E7F4D064440A20914B188854640B40584D6C3034440A20914B188854640
56733	57056	40.175884000000003	40.194192000000001	45.080097000000002	45.059184999999999	Мурата Шовгенова	0103000020E61000000100000005000000E1F1ED5D83164440F6B4C35F93874640E1F1ED5D83164440FDC0559E408A46408A929048DB184440FDC0559E408A46408A929048DB184440F6B4C35F93874640E1F1ED5D83164440F6B4C35F93874640
56724	57053	40.218572000000002	40.254739000000001	45.030163999999999	45.00956	Краснооктябрьская	0103000020E6100000010000000500000021E9D32AFA1B4440C5AC17433981464021E9D32AFA1B44401EC2F869DC83464004029D499B2044401EC2F869DC83464004029D499B204440C5AC17433981464021E9D32AFA1B4440C5AC174339814640
56752	25097	39.946328999999999	39.966262999999998	44.973162000000002	44.957863000000003	Советская	0103000020E61000000100000005000000D120054F21F94340348639419B7A4640D120054F21F94340E0DA8992907C4640DC2A8881AEFB4340E0DA8992907C4640DC2A8881AEFB4340348639419B7A4640D120054F21F94340348639419B7A4640
56808	57091	40.232146	40.253776999999999	44.923991000000001	44.913651000000002	Кочубея	0103000020E61000000100000005000000D8F2CAF5B61D4440967A1684F2744640D8F2CAF5B61D444030664B56457646400EBDC5C37B20444030664B56457646400EBDC5C37B204440967A1684F2744640D8F2CAF5B61D4440967A1684F2744640
56775	25372	40.282811000000002	40.312095999999997	44.988003999999997	44.974915000000003	Карла Маркса	0103000020E610000001000000050000007BF99D26332444409FB0C403CA7C46407BF99D2633244440992842EA767E4640309B00C3F2274440992842EA767E4640309B00C3F22744409FB0C403CA7C46407BF99D26332444409FB0C403CA7C4640
56783	57080	40.164844000000002	40.185963999999998	45.079338999999997	45.049016999999999	Ленина	0103000020E610000001000000050000008E78B29B1915444059F96530468646408E78B29B191544400F26C5C7278A4640DE1D19ABCD1744400F26C5C7278A4640DE1D19ABCD17444059F96530468646408E78B29B1915444059F9653046864640
56734	57057	40.092889	40.117421999999998	45.09939	45.087333000000001	Школьная	0103000020E610000001000000050000003E9468C9E30B4440486E4DBA2D8B46403E9468C9E30B444054C6BFCFB88C46405BEA20AF070F444054C6BFCFB88C46405BEA20AF070F4440486E4DBA2D8B46403E9468C9E30B4440486E4DBA2D8B4640
56815	57096	40.147911000000001	40.154890999999999	44.979768	44.972389999999997	Красноармейская	0103000020E61000000100000005000000FDDB65BFEE1244408D7A8846777C4640FDDB65BFEE1244406BD5AE09697D4640EDB8E177D31344406BD5AE09697D4640EDB8E177D31344408D7A8846777C4640FDDB65BFEE1244408D7A8846777C4640
56693	57049	40.203921000000001	40.233995999999998	45.023839000000002	45.001199	50 лет ВЛКСМ	0103000020E61000000100000005000000DBFB54151A1A4440DAE4F04927804640DBFB54151A1A444047AF06280D83464089B2B794F31D444047AF06280D83464089B2B794F31D4440DAE4F04927804640DBFB54151A1A4440DAE4F04927804640
56824	25136	39.984867000000001	39.995987999999997	44.948875000000001	44.936523999999999	Школьная	0103000020E610000001000000050000006FF4311F10FE4340A5F5B704E07746406FF4311F10FE4340FA7E6ABC74794640AE9AE7887CFF4340FA7E6ABC74794640AE9AE7887CFF4340A5F5B704E07746406FF4311F10FE4340A5F5B704E0774640
56826	57101	40.254550000000002	40.273594000000003	45.094650000000001	45.089177999999997	Краснооктябрьская	0103000020E6100000010000000500000031992A1895204440E7C2482F6A8B464031992A18952044408048BF7D1D8C4640E030D120052344408048BF7D1D8C4640E030D12005234440E7C2482F6A8B464031992A1895204440E7C2482F6A8B4640
56784	57081	40.176279999999998	40.187302000000003	45.049442999999997	45.038832999999997	Ленина	0103000020E610000001000000050000002D78D15790164440B680D07AF88446402D78D157901644401002F22554864640DA3C0E83F91744401002F22554864640DA3C0E83F9174440B680D07AF88446402D78D15790164440B680D07AF8844640
56747	25226	40.071517999999998	40.094138000000001	45.014581	44.987347999999997	Пролетарская	0103000020E61000000100000005000000A489778027094440B0E2546B617E4640A4897780270944404D124BCADD814640CAA7C7B60C0C44404D124BCADD814640CAA7C7B60C0C4440B0E2546B617E4640A489778027094440B0E2546B617E4640
56816	25053	39.901701000000003	39.929423	45.013823000000002	44.996935000000001	Ушанева	0103000020E61000000100000005000000A0E238F06AF343406F9EEA909B7F4640A0E238F06AF343406077BAF3C48146403A933655F7F643406077BAF3C48146403A933655F7F643406F9EEA909B7F4640A0E238F06AF343406F9EEA909B7F4640
56781	57079	40.295881000000001	40.321367000000002	44.997329999999998	44.978676999999998	Краснооктябрьская	0103000020E61000000100000005000000FF40B96DDF254440772CB649457D4640FF40B96DDF254440EBA86A82A87F4640BF81C98D22294440EBA86A82A87F4640BF81C98D22294440772CB649457D4640FF40B96DDF254440772CB649457D4640
56760	57069	39.509504999999997	39.529133000000002	44.905952999999997	44.889678000000004	Красная	0103000020E610000001000000050000000113B87537C1434040FCFCF7E07146400113B87537C14340465B9544F6734640001E51A1BAC34340465B9544F6734640001E51A1BAC3434040FCFCF7E07146400113B87537C1434040FCFCF7E0714640
56774	24202	39.145175000000002	39.158209999999997	44.879019	44.864888999999998	Ленина	0103000020E6100000010000000500000031992A1895924340C7D5C8AEB46E464031992A189592434004C8D0B18370464038F3AB394094434004C8D0B18370464038F3AB3940944340C7D5C8AEB46E464031992A1895924340C7D5C8AEB46E4640
56827	57102	39.106349999999999	39.123831000000003	44.956809999999997	44.947899	Школьная	0103000020E61000000100000005000000FDF675E09C8D43409F7422C154794640FDF675E09C8D43402D3E05C0787A4640919DB7B1D98F43402D3E05C0787A4640919DB7B1D98F43409F7422C154794640FDF675E09C8D43409F7422C154794640
56690	23996	39.076858999999999	39.113895999999997	44.997278999999999	44.971957000000003	Школьная	0103000020E610000001000000050000009EB30584D6894340240F4416697C46409EB30584D689434069FE98D6A67F46409692E524948E434069FE98D6A67F46409692E524948E4340240F4416697C46409EB30584D6894340240F4416697C4640
56723	23996	39.076858999999999	39.113895999999997	44.997278999999999	44.971957000000003	Ленина	0103000020E610000001000000050000009EB30584D6894340240F4416697C46409EB30584D689434069FE98D6A67F46409692E524948E434069FE98D6A67F46409692E524948E4340240F4416697C46409EB30584D6894340240F4416697C4640
56793	57082	39.363574	39.378521999999997	44.968870000000003	44.961556000000002	Пролетарская	0103000020E6100000010000000500000084D6C39789AE4340E4A25A44147B464084D6C39789AE4340AB09A2EE037C46408368AD6873B04340AB09A2EE037C46408368AD6873B04340E4A25A44147B464084D6C39789AE4340E4A25A44147B4640
56820	57099	39.361229000000002	39.374811999999999	44.949359999999999	44.935234999999999	Красная	0103000020E61000000100000005000000F3AE7AC03CAE43408B89CDC7B5774640F3AE7AC03CAE4340B610E4A084794640FD12F1D6F9AF4340B610E4A084794640FD12F1D6F9AF43408B89CDC7B5774640F3AE7AC03CAE43408B89CDC7B5774640
56750	57067	39.255318000000003	39.273032999999998	44.903297000000002	44.871079000000002	Ленина	0103000020E61000000100000005000000420A9E42AEA04340BF9D44847F6F4640420A9E42AEA0434097C9703C9F73464048DDCEBEF2A2434097C9703C9F73464048DDCEBEF2A24340BF9D44847F6F4640420A9E42AEA04340BF9D44847F6F4640
56659	57039	39.365504999999999	39.399866000000003	44.900717999999998	44.878833999999998	Октябрьская	0103000020E6100000010000000500000022C32ADEC8AE4340724EECA17D70464022C32ADEC8AE4340927538BA4A734640246420CF2EB34340927538BA4A734640246420CF2EB34340724EECA17D70464022C32ADEC8AE4340724EECA17D704640
56772	57074	39.495348	39.509748000000002	44.941589999999998	44.925879999999999	Первомайская	0103000020E61000000100000005000000CB11329067BF43409F02603C83764640CB11329067BF4340CD1E680586784640C899266C3FC14340CD1E680586784640C899266C3FC143409F02603C83764640CB11329067BF43409F02603C83764640
56736	57059	39.408507999999998	39.426537000000003	44.916766000000003	44.898521000000002	Октябрьская	0103000020E61000000100000005000000C2137AFD49B4434076E272BC02734640C2137AFD49B44340D90A9A965875464059C4B0C398B64340D90A9A965875464059C4B0C398B6434076E272BC02734640C2137AFD49B4434076E272BC02734640
56801	57086	39.376249000000001	39.391916000000002	44.929760000000002	44.918534000000001	Хакурате	0103000020E610000001000000050000008C135FED28B04340CD21A985927546408C135FED28B0434082902C6002774640BB63B14D2AB2434082902C6002774640BB63B14D2AB24340CD21A985927546408C135FED28B04340CD21A98592754640
56825	24649	39.446416999999997	39.464365000000001	44.883367999999997	44.866543999999998	Шоссейная	0103000020E6100000010000000500000070B0373124B94340C345EEE9EA6E464070B0373124B943409D2ADF33127146401A34F44F70BB43409D2ADF33127146401A34F44F70BB4340C345EEE9EA6E464070B0373124B94340C345EEE9EA6E4640
56845	57103	39.072951000000003	39.651007999999997	45.030616999999999	44.806161000000003	Школьная	0103000020E61000000100000005000000F29A577556894340C4279D4830674640F29A577556894340CFD90242EB83464099B7EA3A54D34340CFD90242EB83464099B7EA3A54D34340C4279D4830674640F29A577556894340C4279D4830674640
56805	57088	39.464688000000002	39.487549999999999	44.990752000000001	44.975821000000003	Хакурате	0103000020E61000000100000005000000FD6B79E57ABB434001E0D8B3E77C4640FD6B79E57ABB43402A3927F6D07E46401895D40968BE43402A3927F6D07E46401895D40968BE434001E0D8B3E77C4640FD6B79E57ABB434001E0D8B3E77C4640
56814	57095	39.165253	39.185994999999998	44.909764000000003	44.896707999999997	Красная	0103000020E610000001000000050000006F48A30227954340E107E753C77246406F48A30227954340018A912573744640191C25AFCE974340018A912573744640191C25AFCE974340E107E753C77246406F48A30227954340E107E753C7724640
56773	57075	39.394196999999998	39.425108000000002	44.960318000000001	44.936746999999997	Школьная	0103000020E6100000010000000500000035971B0C75B2434024D06053E777464035971B0C75B243404CE141B3EB7A46404DA25EF069B643404CE141B3EB7A46404DA25EF069B6434024D06053E777464035971B0C75B2434024D06053E7774640
56802	57087	39.426681000000002	39.440002999999997	44.996290999999999	44.988329999999998	Советов	0103000020E610000001000000050000008C69A67B9DB64340EDD3F198817E46408C69A67B9DB643404A26A776867F46402992AF0452B843404A26A776867F46402992AF0452B84340EDD3F198817E46408C69A67B9DB64340EDD3F198817E4640
56660	57040	39.549830999999998	39.579636999999998	44.943286999999998	44.915075000000002	Хакурате	0103000020E61000000100000005000000DAA9B9DC60C643409031772D21754640DAA9B9DC60C64340F8DEDFA0BD7846409946938B31CA4340F8DEDFA0BD7846409946938B31CA43409031772D21754640DAA9B9DC60C643409031772D21754640
56691	57048	39.273634999999999	39.297099000000003	44.888043000000003	44.860660000000003	Школьная	0103000020E610000001000000050000003E05C07806A34340D97C5C1B2A6E46403E05C07806A343408B389D64AB71464050560C5707A643408B389D64AB71464050560C5707A64340D97C5C1B2A6E46403E05C07806A34340D97C5C1B2A6E4640
56719	57052	39.453907999999998	39.488627999999999	44.858021000000001	44.828116999999999	Ленина	0103000020E6100000010000000500000046B247A819BA43407D21E4BCFF69464046B247A819BA4340FF23D3A1D36D464077F4BF5C8BBE4340FF23D3A1D36D464077F4BF5C8BBE43407D21E4BCFF69464046B247A819BA43407D21E4BCFF694640
56743	13653	39.166367000000001	39.212145	44.897570000000002	44.872298999999998	Ленина	0103000020E610000001000000050000001B118C834B954340B0AA5E7EA76F46401B118C834B95434074EFE192E372464045813E91279B434074EFE192E372464045813E91279B4340B0AA5E7EA76F46401B118C834B954340B0AA5E7EA76F4640
56585	13653	39.166367000000001	39.212145	44.897570000000002	44.872298999999998	Ленина	0103000020E610000001000000050000001B118C834B954340B0AA5E7EA76F46401B118C834B95434074EFE192E372464045813E91279B434074EFE192E372464045813E91279B4340B0AA5E7EA76F46401B118C834B954340B0AA5E7EA76F4640
56663	13653	39.166367000000001	39.212145	44.897570000000002	44.872298999999998	А.И. Хуаде	0103000020E610000001000000050000001B118C834B954340B0AA5E7EA76F46401B118C834B95434074EFE192E372464045813E91279B434074EFE192E372464045813E91279B4340B0AA5E7EA76F46401B118C834B954340B0AA5E7EA76F4640
56796	57083	38.683145000000003	39.131898	45.064495000000001	44.819180000000003	Братьев Пченушай	0103000020E6100000010000000500000085B69C4B71574340C6C4E6E3DA68464085B69C4B71574340B5E0455F4188464033349E08E2904340B5E0455F4188464033349E08E2904340C6C4E6E3DA68464085B69C4B71574340C6C4E6E3DA684640
56656	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Школьная	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56639	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Пушкина	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56626	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Ленина	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56654	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Лаухина	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56674	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Космическая	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56686	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Заводская	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56623	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Гагарина	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56622	23063	38.926400000000001	38.966194999999999	45.002383999999999	44.967646000000002	Андрухаева	0103000020E61000000100000005000000D881734694764340780DFAD2DB7B4640D8817346947643404F04711E4E80464084471B47AC7B43404F04711E4E80464084471B47AC7B4340780DFAD2DB7B4640D881734694764340780DFAD2DB7B4640
56653	11525	38.886837999999997	38.925960000000003	44.941437000000001	44.907069999999997	Чкалова	0103000020E61000000100000005000000CE6C57E8837143406397A8DE1A744640CE6C57E883714340471FF30181784640BCB376DB85764340471FF30181784640BCB376DB857643406397A8DE1A744640CE6C57E8837143406397A8DE1A744640
56620	11525	38.886837999999997	38.925960000000003	44.941437000000001	44.907069999999997	Седина	0103000020E61000000100000005000000CE6C57E8837143406397A8DE1A744640CE6C57E883714340471FF30181784640BCB376DB85764340471FF30181784640BCB376DB857643406397A8DE1A744640CE6C57E8837143406397A8DE1A744640
56627	11525	38.886837999999997	38.925960000000003	44.941437000000001	44.907069999999997	Маяковского	0103000020E61000000100000005000000CE6C57E8837143406397A8DE1A744640CE6C57E883714340471FF30181784640BCB376DB85764340471FF30181784640BCB376DB857643406397A8DE1A744640CE6C57E8837143406397A8DE1A744640
56694	11525	38.886837999999997	38.925960000000003	44.941437000000001	44.907069999999997	Ленина	0103000020E61000000100000005000000CE6C57E8837143406397A8DE1A744640CE6C57E883714340471FF30181784640BCB376DB85764340471FF30181784640BCB376DB857643406397A8DE1A744640CE6C57E8837143406397A8DE1A744640
56662	11525	38.886837999999997	38.925960000000003	44.941437000000001	44.907069999999997	Красная	0103000020E61000000100000005000000CE6C57E8837143406397A8DE1A744640CE6C57E883714340471FF30181784640BCB376DB85764340471FF30181784640BCB376DB857643406397A8DE1A744640CE6C57E8837143406397A8DE1A744640
56651	57037	39.031556999999999	39.075996000000004	44.898713000000001	44.872535999999997	Пушкина	0103000020E61000000100000005000000DD7A4D0F0A844340944A7842AF6F4640DD7A4D0F0A844340BABE0F07097346403C50A73CBA894340BABE0F07097346403C50A73CBA894340944A7842AF6F4640DD7A4D0F0A844340944A7842AF6F4640
56821	23710	38.863742000000002	38.880361000000001	45.001052000000001	44.994137000000002	Заречная	0103000020E6100000010000000500000040170D198F6E43402D5F97E13F7F464040170D198F6E434036CCD0782280464041D653ABAF70434036CCD0782280464041D653ABAF7043402D5F97E13F7F464040170D198F6E43402D5F97E13F7F4640
56799	57085	38.746026999999998	38.763849999999998	45.048921	45.035590999999997	Хакурате	0103000020E610000001000000050000006C770FD07D5F43401684F23E8E8446406C770FD07D5F4340378B170B43864640598638D6C5614340378B170B43864640598638D6C56143401684F23E8E8446406C770FD07D5F43401684F23E8E844640
56619	57034	38.973075999999999	39.013986000000003	44.935355999999999	44.909891999999999	Совмена	0103000020E61000000100000005000000E1421EC18D7C43402E724F5777744640E1421EC18D7C4340060FD3BEB97746400A4D124BCA814340060FD3BEB97746400A4D124BCA8143402E724F5777744640E1421EC18D7C43402E724F5777744640
56718	57034	38.973075999999999	39.013986000000003	44.935355999999999	44.909891999999999	Натухаевская	0103000020E61000000100000005000000E1421EC18D7C43402E724F5777744640E1421EC18D7C4340060FD3BEB97746400A4D124BCA814340060FD3BEB97746400A4D124BCA8143402E724F5777744640E1421EC18D7C43402E724F5777744640
56762	12310	38.932338000000001	38.955739000000001	44.911053000000003	44.890712000000001	Ленина	0103000020E61000000100000005000000B66801DA56774340CF13CFD902724640B66801DA567743401BF67B629D7446408141D2A7557A43401BF67B629D7446408141D2A7557A4340CF13CFD902724640B66801DA56774340CF13CFD902724640
56664	57041	38.884205999999999	38.903601000000002	45.046889999999998	45.024928000000003	Ленина	0103000020E61000000100000005000000A77686A92D7143409A6038D730834640A77686A92D7143403541D47D0086464003D19332A97343403541D47D0086464003D19332A97343409A6038D730834640A77686A92D7143409A6038D730834640
56817	57097	38.694419000000003	38.716912999999998	45.05986	45.043343	Школьная	0103000020E610000001000000050000004B5CC7B8E258434059C16F438C8546404B5CC7B8E2584340562B137EA9874640E38920CEC35B4340562B137EA9874640E38920CEC35B434059C16F438C8546404B5CC7B8E258434059C16F438C854640
56728	22713	39.022475	39.035276000000003	44.966670000000001	44.946694000000001	Ленина	0103000020E6100000010000000500000022FDF675E0824340E3A8DC442D79464022FDF675E08243401D03B2D7BB7B4640B72A89EC838443401D03B2D7BB7B4640B72A89EC83844340E3A8DC442D79464022FDF675E0824340E3A8DC442D794640
56689	57047	38.692999	38.738247999999999	44.996048999999999	44.975456999999999	Схакумидова	0103000020E610000001000000050000009294F430B4584340BFD364C6DB7C46409294F430B4584340541B9C887E7F4640302B14E97E5E4340541B9C887E7F4640302B14E97E5E4340BFD364C6DB7C46409294F430B4584340BFD364C6DB7C4640
56746	22743	38.945901999999997	38.962853000000003	44.880999000000003	44.863458000000001	Павлова	0103000020E61000000100000005000000499C1551137943401BBCAFCA856E4640499C15511379434084674293C470464081ED60C43E7B434084674293C470464081ED60C43E7B43401BBCAFCA856E4640499C1551137943401BBCAFCA856E4640
56789	57066	38.901435999999997	38.918017999999996	44.909399999999998	44.900226000000004	Ленина	0103000020E61000000100000005000000F1B73D41627343402481069B3A734640F1B73D4162734340BF7D1D3867744640D591239D81754340BF7D1D3867744640D591239D817543402481069B3A734640F1B73D41627343402481069B3A734640
56749	57066	38.901435999999997	38.918017999999996	44.909399999999998	44.900226000000004	Дружбы	0103000020E61000000100000005000000F1B73D41627343402481069B3A734640F1B73D4162734340BF7D1D3867744640D591239D81754340BF7D1D3867744640D591239D817543402481069B3A734640F1B73D41627343402481069B3A734640
56813	57094	38.829687	38.849603000000002	44.939841999999999	44.924456999999997	Хатита	0103000020E610000001000000050000004B75012F336A434075C7629B547646404B75012F336A434020B41EBE4C784640B0CA85CABF6C434020B41EBE4C784640B0CA85CABF6C434075C7629B547646404B75012F336A434075C7629B54764640
56771	57073	38.980441999999996	38.997644999999999	44.870575000000002	44.857523	Ленина	0103000020E61000000100000005000000FACF9A1F7F7D4340AE484C50C36D4640FACF9A1F7F7D43408CDB68006F6F46404B02D4D4B27F43408CDB68006F6F46404B02D4D4B27F4340AE484C50C36D4640FACF9A1F7F7D4340AE484C50C36D4640
56806	57089	38.683145000000003	39.131898	45.064495000000001	44.819180000000003	Заводская	0103000020E6100000010000000500000085B69C4B71574340C6C4E6E3DA68464085B69C4B71574340B5E0455F4188464033349E08E2904340B5E0455F4188464033349E08E2904340C6C4E6E3DA68464085B69C4B71574340C6C4E6E3DA684640
56685	57045	38.990161999999998	39.012098999999999	45.003014999999998	44.984938	Площадь Памяти	0103000020E61000000100000005000000F8DEDFA0BD7E4340384BC972127E4640F8DEDFA0BD7E4340DF32A7CB628046403BA8C4758C814340DF32A7CB628046403BA8C4758C814340384BC972127E4640F8DEDFA0BD7E4340384BC972127E4640
56761	12216	38.885122000000003	38.898938000000001	44.964993	44.950330000000001	Рабочая	0103000020E610000001000000050000002D7C7DAD4B7143402F34D769A47946402D7C7DAD4B71434039EFFFE3847B4640DA907F661073434039EFFFE3847B4640DA907F66107343402F34D769A47946402D7C7DAD4B7143402F34D769A4794640
56658	57038	38.766365	38.795029999999997	45.010171999999997	44.976458000000001	Жане	0103000020E6100000010000000500000047E6913F1862434073F56393FC7C464047E6913F18624340DEAAEB504D81464060AB048BC3654340DEAAEB504D81464060AB048BC365434073F56393FC7C464047E6913F1862434073F56393FC7C4640
56905	57110	39.765732	40.482658999999998	44.793356000000003	43.761000000000003	Школьная	0103000020E6100000010000000500000016C0948103E24340C520B07268E1454016C0948103E24340EE0A7DB08C6546405E0F26C5C73D4440EE0A7DB08C6546405E0F26C5C73D4440C520B07268E1454016C0948103E24340C520B07268E14540
75535	60675	39.765732	40.482658999999998	44.793356000000003	43.761000000000003	Промышленная	0103000020E6100000010000000500000016C0948103E24340C520B07268E1454016C0948103E24340EE0A7DB08C6546405E0F26C5C73D4440EE0A7DB08C6546405E0F26C5C73D4440C520B07268E1454016C0948103E24340C520B07268E14540
56777	57077	40.154935999999999	40.179073000000002	44.461939000000001	44.446072000000001	Школьный переулок	0103000020E610000001000000050000008D7C5EF1D4134440A6D425E3183946408D7C5EF1D41344409CDF30D1203B46405E4C33DDEB1644409CDF30D1203B46405E4C33DDEB164440A6D425E3183946408D7C5EF1D4134440A6D425E318394640
56742	57063	40.131059	40.147101999999997	44.501927999999999	44.479480000000002	Комсомольская	0103000020E61000000100000005000000596C938AC6104440058BC3995F3D4640596C938AC61044402D793C2D3F4046408D96033DD41244402D793C2D3F4046408D96033DD4124440058BC3995F3D4640596C938AC6104440058BC3995F3D4640
56692	17220	40.152250000000002	40.174537000000001	44.505149000000003	44.490051999999999	Клубная	0103000020E61000000100000005000000736891ED7C13444071AB2006BA3E4640736891ED7C134440B64DF1B8A84046409278793A57164440B64DF1B8A84046409278793A5716444071AB2006BA3E4640736891ED7C13444071AB2006BA3E4640
56684	22098	39.928623000000002	39.991101	44.721632	44.645187	Краснооктябрьская	0103000020E610000001000000050000001EA8531EDDF64340F566D47C955246401EA8531EDDF64340A0DFF76F5E5C46403604C765DCFE4340A0DFF76F5E5C46403604C765DCFE4340F566D47C955246401EA8531EDDF64340F566D47C95524640
56650	22098	39.928623000000002	39.991101	44.721632	44.645187	Интернациональная	0103000020E610000001000000050000001EA8531EDDF64340F566D47C955246401EA8531EDDF64340A0DFF76F5E5C46403604C765DCFE4340A0DFF76F5E5C46403604C765DCFE4340F566D47C955246401EA8531EDDF64340F566D47C95524640
56807	57090	40.275444999999998	40.288884000000003	44.212178000000002	44.202950999999999	Советская	0103000020E61000000100000005000000616C21C84123444062D8614CFA194640616C21C841234440217711A6281B4640392BA226FA244440217711A6281B4640392BA226FA24444062D8614CFA194640616C21C84123444062D8614CFA194640
56609	18483	40.147452999999999	40.166361999999999	44.559913999999999	44.544395000000002	Ленина	0103000020E610000001000000050000003A596ABDDF1244408F8D40BCAE4546403A596ABDDF12444049490F43AB47464009A69A594B15444049490F43AB47464009A69A594B1544408F8D40BCAE4546403A596ABDDF1244408F8D40BCAE454640
56667	16951	40.15896	40.204225999999998	44.534320999999998	44.489609000000002	Советская	0103000020E61000000100000005000000A3AF20CD58144440E469F981AB3E4640A3AF20CD5814444073486AA164444640177FDB13241A444073486AA164444640177FDB13241A4440E469F981AB3E4640A3AF20CD58144440E469F981AB3E4640
56720	16951	40.15896	40.204225999999998	44.534320999999998	44.489609000000002	Первомайская	0103000020E61000000100000005000000A3AF20CD58144440E469F981AB3E4640A3AF20CD5814444073486AA164444640177FDB13241A444073486AA164444640177FDB13241A4440E469F981AB3E4640A3AF20CD58144440E469F981AB3E4640
56668	16951	40.15896	40.204225999999998	44.534320999999998	44.489609000000002	Комсомольская	0103000020E61000000100000005000000A3AF20CD58144440E469F981AB3E4640A3AF20CD5814444073486AA164444640177FDB13241A444073486AA164444640177FDB13241A4440E469F981AB3E4640A3AF20CD58144440E469F981AB3E4640
56778	57078	40.161332000000002	40.177464999999998	44.474746000000003	44.461700999999998	Садовая	0103000020E610000001000000050000002EE6E786A6144440E7C3B304193B46402EE6E786A614444013F4177AC43C4640A297512CB716444013F4177AC43C4640A297512CB7164440E7C3B304193B46402EE6E786A6144440E7C3B304193B4640
56673	18322	40.082469000000003	40.103876	44.564121	44.544722999999998	Шоссейная	0103000020E6100000010000000500000088F71C588E0A44408330B77BB945464088F71C588E0A444050FEEE1D354846406E6B0BCF4B0D444050FEEE1D354846406E6B0BCF4B0D44408330B77BB945464088F71C588E0A44408330B77BB9454640
56676	18544	40.147030999999998	40.160721000000002	44.548307000000001	44.536287000000002	Советская	0103000020E61000000100000005000000C43F6CE9D11244408E226B0DA5444640C43F6CE9D11244407D957CEC2E464640E5637781921444407D957CEC2E464640E5637781921444408E226B0DA5444640C43F6CE9D11244408E226B0DA5444640
56709	12776	40.091883000000003	40.113675999999998	44.674301999999997	44.666924000000002	Советская	0103000020E61000000100000005000000790778D2C20B4440717500C45D554640790778D2C20B44404ED026874F564640882B67EF8C0E44404ED026874F564640882B67EF8C0E4440717500C45D554640790778D2C20B4440717500C45D554640
56819	12776	40.091883000000003	40.113675999999998	44.674301999999997	44.666924000000002	Западная	0103000020E61000000100000005000000790778D2C20B4440717500C45D554640790778D2C20B44404ED026874F564640882B67EF8C0E44404ED026874F564640882B67EF8C0E4440717500C45D554640790778D2C20B4440717500C45D554640
56607	33093	40.111277999999999	40.15119	44.653190000000002	44.613805999999997	Нагорная	0103000020E61000000100000005000000D461855B3E0E4440560BEC31914E4640D461855B3E0E44408109DCBA9B534640BABDA4315A1344408109DCBA9B534640BABDA4315A134440560BEC31914E4640D461855B3E0E4440560BEC31914E4640
56641	33093	40.111277999999999	40.15119	44.653190000000002	44.613805999999997	Маяковского	0103000020E61000000100000005000000D461855B3E0E4440560BEC31914E4640D461855B3E0E44408109DCBA9B534640BABDA4315A1344408109DCBA9B534640BABDA4315A134440560BEC31914E4640D461855B3E0E4440560BEC31914E4640
56617	22324	40.110836999999997	40.126018999999999	44.665987999999999	44.647348999999998	Школьная	0103000020E61000000100000005000000E71725E82F0E4440950C0055DC524640E71725E82F0E4440A4C343183F5546405AD6FD6321104440A4C343183F5546405AD6FD6321104440950C0055DC524640E71725E82F0E4440950C0055DC524640
56818	57098	40.279811000000002	40.331184999999998	44.364131999999998	44.340857999999997	Советская	0103000020E61000000100000005000000D107CBD8D02344403C4A253CA12B4640D107CBD8D0234440AAB69BE09B2E46407FF62345642A4440AAB69BE09B2E46407FF62345642A44403C4A253CA12B4640D107CBD8D02344403C4A253CA12B4640
56759	22228	39.99288	40.014493000000002	44.689177000000001	44.672885000000001	Ленина	0103000020E610000001000000050000001E6D1CB116FF4340077C7E18215646401E6D1CB116FF4340E413B2F336584640AE8218E8DA014440E413B2F336584640AE8218E8DA014440077C7E18215646401E6D1CB116FF4340077C7E1821564640
56744	57064	40.168905000000002	40.198934999999999	44.624879999999997	44.611097999999998	Комсомольская	0103000020E61000000100000005000000C190D5AD9E15444054539275384E4640C190D5AD9E15444055F65D11FC4F4640CF83BBB37619444055F65D11FC4F4640CF83BBB37619444054539275384E4640C190D5AD9E15444054539275384E4640
56729	17878	40.130960000000002	40.160415	44.567279999999997	44.551769999999998	Шоссейная	0103000020E61000000100000005000000C68A1A4CC3104440FB743C66A0464640C68A1A4CC310444062D68BA19C484640D8648D7A8814444062D68BA19C484640D8648D7A88144440FB743C66A0464640C68A1A4CC3104440FB743C66A0464640
56786	17878	40.130960000000002	40.160415	44.567279999999997	44.551769999999998	Дружбы	0103000020E61000000100000005000000C68A1A4CC3104440FB743C66A0464640C68A1A4CC310444062D68BA19C484640D8648D7A8814444062D68BA19C484640D8648D7A88144440FB743C66A0464640C68A1A4CC3104440FB743C66A0464640
56701	17481	40.174554999999998	40.201962999999999	44.414980999999997	44.397820000000003	Школьная	0103000020E61000000100000005000000382D78D157164440EDD808C4EB324640382D78D1571644400EBBEF181E354640430070ECD91944400EBBEF181E354640430070ECD9194440EDD808C4EB324640382D78D157164440EDD808C4EB324640
56741	17580	40.398567999999997	40.425769000000003	44.370119000000003	44.333843000000002	Советская	0103000020E61000000100000005000000B69DB64604334440D07F0F5EBB2A4640B69DB646043344406A50340F602F464048533D997F3644406A50340F602F464048533D997F364440D07F0F5EBB2A4640B69DB64604334440D07F0F5EBB2A4640
56804	17994	40.274878999999999	40.293663000000002	44.145766000000002	44.128065999999997	Советская	0103000020E61000000100000005000000B8AD2D3C2F23444061DD787764104640B8AD2D3C2F234440336FD575A8124640CB85CABF96254440336FD575A8124640CB85CABF9625444061DD787764104640B8AD2D3C2F23444061DD787764104640
56612	32525	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Краснооктябрьская	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56655	32525	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	Гайдара	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56621	32525	40.044668000000001	40.160029000000002	44.654215999999998	44.564827000000001	12 Марта	0103000020E61000000100000005000000C09657AEB7054440EB724A404C484640C09657AEB70544408D429259BD534640AFB48CD47B1444408D429259BD534640AFB48CD47B144440EB724A404C484640C09657AEB7054440EB724A404C484640
56642	18142	40.038297999999998	40.071356000000002	44.48912	44.439700000000002	Кооперативная	0103000020E6100000010000000500000048C0E8F2E60444408E06F0164838464048C0E8F2E6044440E6E8F17B9B3E4640CB2F833122094440E6E8F17B9B3E4640CB2F8331220944408E06F0164838464048C0E8F2E60444408E06F01648384640
56677	19069	40.283422000000002	40.328769000000001	44.692073000000001	44.651395000000001	Школьная	0103000020E61000000100000005000000C47B0E2C4724444093E34EE960534640C47B0E2C47244440E9B81AD9955846402578431A152A4440E9B81AD9955846402578431A152A444093E34EE960534640C47B0E2C4724444093E34EE960534640
56629	19069	40.283422000000002	40.328769000000001	44.692073000000001	44.651395000000001	Краснооктябрьская	0103000020E61000000100000005000000C47B0E2C4724444093E34EE960534640C47B0E2C47244440E9B81AD9955846402578431A152A4440E9B81AD9955846402578431A152A444093E34EE960534640C47B0E2C4724444093E34EE960534640
56671	18236	40.057361	40.107360999999997	44.585419000000002	44.567453999999998	Шоссейная	0103000020E610000001000000050000006E88F19A5707444000FE2955A24846406E88F19A5707444080BA8102EF4A4640D4EE5701BE0D444080BA8102EF4A4640D4EE5701BE0D444000FE2955A24846406E88F19A5707444000FE2955A2484640
56680	18236	40.057361	40.107360999999997	44.585419000000002	44.567453999999998	Кубанская	0103000020E610000001000000050000006E88F19A5707444000FE2955A24846406E88F19A5707444080BA8102EF4A4640D4EE5701BE0D444080BA8102EF4A4640D4EE5701BE0D444000FE2955A24846406E88F19A5707444000FE2955A2484640
56606	15404	40.170026999999997	40.178677999999998	44.702959	44.692464000000001	Октябрьская	0103000020E61000000100000005000000EF37DA71C315444024D40CA9A2584640EF37DA71C3154440E5B67D8FFA594640E141B3EBDE164440E5B67D8FFA594640E141B3EBDE16444024D40CA9A2584640EF37DA71C315444024D40CA9A2584640
56809	15404	40.170026999999997	40.178677999999998	44.702959	44.692464000000001	Красная	0103000020E61000000100000005000000EF37DA71C315444024D40CA9A2584640EF37DA71C3154440E5B67D8FFA594640E141B3EBDE164440E5B67D8FFA594640E141B3EBDE16444024D40CA9A2584640EF37DA71C315444024D40CA9A2584640
56812	22357	40.083457000000003	40.093589999999999	44.736218999999998	44.728971000000001	Гагарина	0103000020E61000000100000005000000A7CF0EB8AE0A4440C05DF6EB4E5D4640A7CF0EB8AE0A4440CFD8976C3C5E4640C79DD2C1FA0B4440CFD8976C3C5E4640C79DD2C1FA0B4440C05DF6EB4E5D4640A7CF0EB8AE0A4440C05DF6EB4E5D4640
56669	17658	40.160505000000001	40.207847000000001	44.318933999999999	44.280864999999999	Мира	0103000020E6100000010000000500000018EC866D8B144440A7CB6262F323464018EC866D8B1444408ECA4DD4D22846402EC901BB9A1A44408ECA4DD4D22846402EC901BB9A1A4440A7CB6262F323464018EC866D8B144440A7CB6262F3234640
56640	17658	40.160505000000001	40.207847000000001	44.318933999999999	44.280864999999999	Железнодорожная	0103000020E6100000010000000500000018EC866D8B144440A7CB6262F323464018EC866D8B1444408ECA4DD4D22846402EC901BB9A1A44408ECA4DD4D22846402EC901BB9A1A4440A7CB6262F323464018EC866D8B144440A7CB6262F3234640
56703	17658	40.160505000000001	40.207847000000001	44.318933999999999	44.280864999999999	Дальняя	0103000020E6100000010000000500000018EC866D8B144440A7CB6262F323464018EC866D8B1444408ECA4DD4D22846402EC901BB9A1A44408ECA4DD4D22846402EC901BB9A1A4440A7CB6262F323464018EC866D8B144440A7CB6262F3234640
56638	17658	40.160505000000001	40.207847000000001	44.318933999999999	44.280864999999999	Гагарина	0103000020E6100000010000000500000018EC866D8B144440A7CB6262F323464018EC866D8B1444408ECA4DD4D22846402EC901BB9A1A44408ECA4DD4D22846402EC901BB9A1A4440A7CB6262F323464018EC866D8B144440A7CB6262F3234640
56681	21928	40.038415000000001	40.081713999999998	44.634918999999996	44.621878000000002	Клубная	0103000020E61000000100000005000000825660C8EA0444400B0DC4B2994F4640825660C8EA044440F44D9A06455146400BD0B69A750A4440F44D9A06455146400BD0B69A750A44400B0DC4B2994F4640825660C8EA0444400B0DC4B2994F4640
56599	17943	40.190015000000002	40.221124000000003	44.245657000000001	44.215254000000002	Советская	0103000020E61000000100000005000000EE5F596952184440A62A6D718D1B4640EE5F596952184440498446B0711F46402C2E8ECA4D1C4440498446B0711F46402C2E8ECA4D1C4440A62A6D718D1B4640EE5F596952184440A62A6D718D1B4640
56769	57072	39.999833000000002	40.041801999999997	44.387095000000002	44.363185000000001	Ленина	0103000020E61000000100000005000000153B1A87FAFF4340EAB298D87C2E4640153B1A87FAFF4340FAB836548C314640257497C459054440FAB836548C314640257497C459054440EAB298D87C2E4640153B1A87FAFF4340EAB298D87C2E4640
56776	57076	40.126764999999999	40.142170999999998	44.564492999999999	44.548442000000001	Школьная	0103000020E6100000010000000500000083A3E4D5391044405DE0F2583346464083A3E4D53910444014E97E4E4148464045B8C9A83212444014E97E4E4148464045B8C9A8321244405DE0F2583346464083A3E4D5391044405DE0F25833464640
56779	57076	40.126764999999999	40.142170999999998	44.564492999999999	44.548442000000001	Пионерская	0103000020E6100000010000000500000083A3E4D5391044405DE0F2583346464083A3E4D53910444014E97E4E4148464045B8C9A83212444014E97E4E4148464045B8C9A8321244405DE0F2583346464083A3E4D5391044405DE0F25833464640
56661	21997	40.008169000000002	40.040975000000003	44.621479999999998	44.606388000000003	переулок Клубный	0103000020E61000000100000005000000A7EB89AE0B014440EB573A1F9E4D4640A7EB89AE0B0144401D8F19A88C4F4640107A36AB3E0544401D8F19A88C4F4640107A36AB3E054440EB573A1F9E4D4640A7EB89AE0B014440EB573A1F9E4D4640
56756	57068	40.190635	40.211061999999998	44.394978999999999	44.380834	Лесная	0103000020E610000001000000050000008A3C49BA66184440399A232BBF3046408A3C49BA66184440ABCDFFAB8E324640D4B66114041B4440ABCDFFAB8E324640D4B66114041B4440399A232BBF3046408A3C49BA66184440399A232BBF304640
56782	17350	40.202689999999997	40.237527	44.409436999999997	44.374842000000001	Полевая	0103000020E61000000100000005000000F59CF4BEF1194440689599D2FA2F4640F59CF4BEF1194440DC627E6E683446406075E448671E4440DC627E6E683446406075E448671E4440689599D2FA2F4640F59CF4BEF1194440689599D2FA2F4640
56700	17350	40.202689999999997	40.237527	44.409436999999997	44.374842000000001	Клубная	0103000020E61000000100000005000000F59CF4BEF1194440689599D2FA2F4640F59CF4BEF1194440DC627E6E683446406075E448671E4440DC627E6E683446406075E448671E4440689599D2FA2F4640F59CF4BEF1194440689599D2FA2F4640
56603	17350	40.202689999999997	40.237527	44.409436999999997	44.374842000000001	Винника	0103000020E61000000100000005000000F59CF4BEF1194440689599D2FA2F4640F59CF4BEF1194440DC627E6E683446406075E448671E4440DC627E6E683446406075E448671E4440689599D2FA2F4640F59CF4BEF1194440689599D2FA2F4640
56758	16868	39.896993000000002	39.929898999999999	45.066119	45.039923000000002	Красная	0103000020E61000000100000005000000D7DEA7AAD0F24340DAAD65321C854640D7DEA7AAD0F2434076525F9676884640A3CA30EE06F7434076525F9676884640A3CA30EE06F74340DAAD65321C854640D7DEA7AAD0F24340DAAD65321C854640
56613	57033	39.647019	39.678612999999999	45.203375999999999	45.178648000000003	Школьная	0103000020E610000001000000050000000072C284D1D2434077BF0AF0DD9646400072C284D1D2434049658A39089A4640FAD170CADCD6434049658A39089A4640FAD170CADCD6434077BF0AF0DD9646400072C284D1D2434077BF0AF0DD964640
56634	57033	39.647019	39.678612999999999	45.203375999999999	45.178648000000003	Мира	0103000020E610000001000000050000000072C284D1D2434077BF0AF0DD9646400072C284D1D2434049658A39089A4640FAD170CADCD6434049658A39089A4640FAD170CADCD6434077BF0AF0DD9646400072C284D1D2434077BF0AF0DD964640
56666	57042	39.931659000000003	39.974499999999999	45.066068000000001	45.040616999999997	Братьев Шекультировых	0103000020E610000001000000050000001503249A40F74340B05417F0328546401503249A40F74340F4A78DEA74884640DBF97E6ABCFC4340F4A78DEA74884640DBF97E6ABCFC4340B05417F0328546401503249A40F74340B05417F032854640
56757	11623	39.755006000000002	39.772621999999998	45.105274999999999	45.093753	Красная	0103000020E6100000010000000500000053245F09A4E0434071732A19008C464053245F09A4E043400F0BB5A6798D4640C6151747E5E243400F0BB5A6798D4640C6151747E5E2434071732A19008C464053245F09A4E0434071732A19008C4640
56753	16593	39.678820000000002	39.710988	45.012625	44.990043999999997	Красная	0103000020E6100000010000000500000074EFE192E3D64340EECC04C3B97E464074EFE192E3D64340560E2DB29D8146409AEC9FA701DB4340560E2DB29D8146409AEC9FA701DB4340EECC04C3B97E464074EFE192E3D64340EECC04C3B97E4640
56727	16446	39.611418999999998	39.638306	45.093989000000001	45.076296999999997	Школьная	0103000020E61000000100000005000000969350FA42CE434036E49F19C4894640969350FA42CE43408597E0D4078C4640986BD102B4D143408597E0D4078C4640986BD102B4D1434036E49F19C4894640969350FA42CE434036E49F19C4894640
56739	16543	39.694549000000002	39.718525	45.069524000000001	45.052346999999997	Чучваги	0103000020E61000000100000005000000193C4CFBE6D843409885764EB3864640193C4CFBE6D84340C0249529E6884640E02D90A0F8DB4340C0249529E6884640E02D90A0F8DB43409885764EB3864640193C4CFBE6D843409885764EB3864640
56698	16181	39.534388999999997	39.618093999999999	45.156978000000002	45.089063000000003	Первомайская	0103000020E61000000100000005000000CB2BD7DB66C443404F24986A668B4640CB2BD7DB66C443408318E8DA179446404AED45B41DCF43408318E8DA179446404AED45B41DCF43404F24986A668B4640CB2BD7DB66C443404F24986A668B4640
56604	16181	39.534388999999997	39.618093999999999	45.156978000000002	45.089063000000003	Мира	0103000020E61000000100000005000000CB2BD7DB66C443404F24986A668B4640CB2BD7DB66C443408318E8DA179446404AED45B41DCF43408318E8DA179446404AED45B41DCF43404F24986A668B4640CB2BD7DB66C443404F24986A668B4640
56665	16181	39.534388999999997	39.618093999999999	45.156978000000002	45.089063000000003	50 лет Октября	0103000020E61000000100000005000000CB2BD7DB66C443404F24986A668B4640CB2BD7DB66C443408318E8DA179446404AED45B41DCF43408318E8DA179446404AED45B41DCF43404F24986A668B4640CB2BD7DB66C443404F24986A668B4640
56722	11077	39.643228000000001	39.778199999999998	45.131326999999999	45.067200999999997	Юбилейная	0103000020E610000001000000050000008DEF8B4B55D2434016A1D80A9A8846408DEF8B4B55D24340780AB952CF904640A4DFBE0E9CE34340780AB952CF904640A4DFBE0E9CE3434016A1D80A9A8846408DEF8B4B55D2434016A1D80A9A884640
56754	11077	39.643228000000001	39.778199999999998	45.131326999999999	45.067200999999997	Молодежная	0103000020E610000001000000050000008DEF8B4B55D2434016A1D80A9A8846408DEF8B4B55D24340780AB952CF904640A4DFBE0E9CE34340780AB952CF904640A4DFBE0E9CE3434016A1D80A9A8846408DEF8B4B55D2434016A1D80A9A884640
56780	11077	39.643228000000001	39.778199999999998	45.131326999999999	45.067200999999997	Клубная	0103000020E610000001000000050000008DEF8B4B55D2434016A1D80A9A8846408DEF8B4B55D24340780AB952CF904640A4DFBE0E9CE34340780AB952CF904640A4DFBE0E9CE3434016A1D80A9A8846408DEF8B4B55D2434016A1D80A9A884640
56730	57054	39.842008	39.871059000000002	45.098123999999999	45.076017	Центральная	0103000020E61000000100000005000000357C0BEBC6EB43405378D0ECBA894640357C0BEBC6EB4340F279C5538F8C464078F17EDC7EEF4340F279C5538F8C464078F17EDC7EEF43405378D0ECBA894640357C0BEBC6EB43405378D0ECBA894640
56823	16716	39.733787999999997	39.766154	45.021469000000003	44.994219999999999	Почтовая	0103000020E610000001000000050000003F19E3C3ECDD4340BA83D899427F46403F19E3C3ECDD43405D70067FBF8246408CD9925511E243405D70067FBF8246408CD9925511E24340BA83D899427F46403F19E3C3ECDD4340BA83D899427F4640
56636	16746	39.825145999999997	39.856417	45.046202000000001	45.022863999999998	Советская	0103000020E610000001000000050000006D3656629EE94340BC202235ED8246406D3656629EE94340418177F2E9854640855E7F129FED4340418177F2E9854640855E7F129FED4340BC202235ED8246406D3656629EE94340BC202235ED824640
56738	57061	39.694082000000002	39.717384000000003	44.986876000000002	44.965127000000003	Клубная	0103000020E61000000100000005000000035FD1ADD7D8434049BE1248897B4640035FD1ADD7D84340899AE8F3517E46403B56293DD3DB4340899AE8F3517E46403B56293DD3DB434049BE1248897B4640035FD1ADD7D8434049BE1248897B4640
56748	57065	39.293630999999998	40.017412999999998	45.218488999999998	44.957397	Советская	0103000020E61000000100000005000000BF0B5BB395A54340EE2422FC8B7A4640BF0B5BB395A5434093C49272F79B46403BC3D4963A02444093C49272F79B46403BC3D4963A024440EE2422FC8B7A4640BF0B5BB395A54340EE2422FC8B7A4640
56740	57062	39.483463	39.510026000000003	45.07687	45.062368999999997	Шоссейная	0103000020E61000000100000005000000BCE9961DE2BD434061A417B5FB874640BCE9961DE2BD434092054CE0D68946400B0E2F8848C1434092054CE0D68946400B0E2F8848C1434061A417B5FB874640BCE9961DE2BD434061A417B5FB874640
56670	57043	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Краснооктябрьская	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
56798	57084	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Ленина	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
56675	57044	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Школьная	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
67094	58958	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Мира	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
79561	61684	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Промышленная	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
56635	57036	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Заводская	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
79568	61122	37.601492999999998	37.603369999999998	54.099328	54.095605999999997	Центральная	0103000020E61000000100000005000000EFE2FDB8FDCC424093A641D13C0C4B40EFE2FDB8FDCC4240DEC9A7C7B60C4B409AB1683A3BCD4240DEC9A7C7B60C4B409AB1683A3BCD424093A641D13C0C4B40EFE2FDB8FDCC424093A641D13C0C4B40
66955	58894	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Свободного Мира	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
66876	58880	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Ленина	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
56688	57046	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	Гагарина	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
67089	58953	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	пер. Кооперативный	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
56735	57058	40.363470999999997	40.376989999999999	44.764808000000002	44.745367999999999	Прямая	0103000020E61000000100000005000000AF05BD37862E444012BEF737685F4640AF05BD37862E44400EDC813AE5614640A3755435413044400EDC813AE5614640A37554354130444012BEF737685F4640AF05BD37862E444012BEF737685F4640
56810	57092	40.414099999999998	40.436441000000002	44.875920999999998	44.861541000000003	Шоссейная	0103000020E6100000010000000500000005A3923A01354440E294B9F9466E464005A3923A013544409770E82D1E70464018D1764CDD3744409770E82D1E70464018D1764CDD374440E294B9F9466E464005A3923A01354440E294B9F9466E4640
56597	14799	40.332883000000002	40.368600000000001	44.822485	44.790177	Почтовая	0103000020E610000001000000050000007B32FFE89B2A444094861A85246546407B32FFE89B2A4440AC394030476946401EA7E8482E2F4440AC394030476946401EA7E8482E2F444094861A85246546407B32FFE89B2A444094861A8524654640
56822	57100	40.230215000000001	40.241435000000003	44.841316999999997	44.833807	Луговая	0103000020E610000001000000050000003A0664AF771D444083161230BA6A46403A0664AF771D4440CF488446B06B46400D8E9257E71E4440CF488446B06B46400D8E9257E71E444083161230BA6A46403A0664AF771D444083161230BA6A4640
56631	57035	40.181246999999999	40.199196000000001	44.875346	44.864179999999998	Центральная	0103000020E61000000100000005000000C2BF081A33174440BBED42739D6E4640C2BF081A331744409B5775560B7046403CBF28417F1944409B5775560B7046403CBF28417F194440BBED42739D6E4640C2BF081A33174440BBED42739D6E4640
56602	14291	40.15605	40.193078	44.949354	44.912956000000001	переулок Советский	0103000020E6100000010000000500000039454772F9134440EF5701BEDB74464039454772F9134440D4298F6E84794640DEC9A7C7B6184440D4298F6E84794640DEC9A7C7B6184440EF5701BEDB74464039454772F9134440EF5701BEDB744640
56601	14994	40.111260000000001	40.146616999999999	44.814678000000001	44.769024999999999	Советская	0103000020E610000001000000050000002EAD86C43D0E4440386744696F6246402EAD86C43D0E4440A662635E47684640D1048A58C4124440A662635E47684640D1048A58C4124440386744696F6246402EAD86C43D0E4440386744696F624640
56587	57029	40.334913	40.374465999999998	44.904012000000002	44.855893000000002	Ленина	0103000020E61000000100000005000000AC00DF6DDE2A44400BF0DDE68D6D4640AC00DF6DDE2A444085984BAAB673464062BB7B80EE2F444085984BAAB673464062BB7B80EE2F44400BF0DDE68D6D4640AC00DF6DDE2A44400BF0DDE68D6D4640
56633	57027	40.334913	40.374465999999998	44.904012000000002	44.855893000000002	Элеваторная	0103000020E61000000100000005000000AC00DF6DDE2A44400BF0DDE68D6D4640AC00DF6DDE2A444085984BAAB673464062BB7B80EE2F444085984BAAB673464062BB7B80EE2F44400BF0DDE68D6D4640AC00DF6DDE2A44400BF0DDE68D6D4640
56583	57027	40.334913	40.374465999999998	44.904012000000002	44.855893000000002	Ленина	0103000020E61000000100000005000000AC00DF6DDE2A44400BF0DDE68D6D4640AC00DF6DDE2A444085984BAAB673464062BB7B80EE2F444085984BAAB673464062BB7B80EE2F44400BF0DDE68D6D4640AC00DF6DDE2A44400BF0DDE68D6D4640
56726	57027	40.334913	40.374465999999998	44.904012000000002	44.855893000000002	Гагарина	0103000020E61000000100000005000000AC00DF6DDE2A44400BF0DDE68D6D4640AC00DF6DDE2A444085984BAAB673464062BB7B80EE2F444085984BAAB673464062BB7B80EE2F44400BF0DDE68D6D4640AC00DF6DDE2A44400BF0DDE68D6D4640
56768	57071	40.296106000000002	40.304065000000001	44.758209000000001	44.746417999999998	Крестьянская	0103000020E610000001000000050000001F1329CDE6254440A79201A08A5F46401F1329CDE6254440354415FE0C614640DB6D179AEB264440354415FE0C614640DB6D179AEB264440A79201A08A5F46401F1329CDE6254440A79201A08A5F4640
56595	14223	39.947029999999998	39.966828999999997	44.817126999999999	44.796292000000001	Центральная	0103000020E610000001000000050000005A2A6F4738F94340810871E5EC6546405A2A6F4738F94340DCD6169E9768464085E97B0DC1FB4340DCD6169E9768464085E97B0DC1FB4340810871E5EC6546405A2A6F4738F94340810871E5EC654640
56592	57031	40.022371	40.093499999999999	44.901623999999998	44.840026000000002	Центральная	0103000020E610000001000000050000007DB08C0DDD02444015E5D2F8856B46407DB08C0DDD024440F4A44C6A687346408716D9CEF70B4440F4A44C6A687346408716D9CEF70B444015E5D2F8856B46407DB08C0DDD02444015E5D2F8856B4640
56697	57031	40.022371	40.093499999999999	44.901623999999998	44.840026000000002	Красноармейская	0103000020E610000001000000050000007DB08C0DDD02444015E5D2F8856B46407DB08C0DDD024440F4A44C6A687346408716D9CEF70B4440F4A44C6A687346408716D9CEF70B444015E5D2F8856B46407DB08C0DDD02444015E5D2F8856B4640
56598	57031	40.022371	40.093499999999999	44.901623999999998	44.840026000000002	Красная	0103000020E610000001000000050000007DB08C0DDD02444015E5D2F8856B46407DB08C0DDD024440F4A44C6A687346408716D9CEF70B4440F4A44C6A687346408716D9CEF70B444015E5D2F8856B46407DB08C0DDD02444015E5D2F8856B4640
56628	57031	40.022371	40.093499999999999	44.901623999999998	44.840026000000002	Боевая	0103000020E610000001000000050000007DB08C0DDD02444015E5D2F8856B46407DB08C0DDD024440F4A44C6A687346408716D9CEF70B4440F4A44C6A687346408716D9CEF70B444015E5D2F8856B46407DB08C0DDD02444015E5D2F8856B4640
56699	57031	40.022371	40.093499999999999	44.901623999999998	44.840026000000002	 Ленина	0103000020E610000001000000050000007DB08C0DDD02444015E5D2F8856B46407DB08C0DDD024440F4A44C6A687346408716D9CEF70B4440F4A44C6A687346408716D9CEF70B444015E5D2F8856B46407DB08C0DDD02444015E5D2F8856B4640
56767	14833	40.405529999999999	40.418033999999999	44.776671999999998	44.754573999999998	Октябрьская	0103000020E6100000010000000500000000C63368E8334440B9347EE19560464000C63368E833444005DCF3FC69634640DB4E5B238235444005DCF3FC69634640DB4E5B2382354440B9347EE19560464000C63368E8334440B9347EE195604640
56763	57070	40.247695999999998	40.269120999999998	44.915565999999998	44.902313999999997	Центральная	0103000020E61000000100000005000000CDACA580B41F4440895C70067F734640CDACA580B41F44402EAA4544317546405AD5928E722244402EAA4544317546405AD5928E72224440895C70067F734640CDACA580B41F4440895C70067F734640
55118	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	пл.Ленина	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39809	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	бульвар Аллейный	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40028	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Энтузиастов	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40303	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Шевченко	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40030	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Фучика	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39813	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Федосеева	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40830	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Тюменский	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40176	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Текстильная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39816	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Стрельникова	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40324	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Спортивный	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41214	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Сокольнический	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40150	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Советская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40174	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Сельская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39817	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Сапрыкина	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39996	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Садовая	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39776	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Рудничный	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40020	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Пролетарская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55168	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Пограничная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40024	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Победы революции	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40841	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Победа Революции	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40961	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Платова	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40251	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Питерская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41384	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Паустовского	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40834	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Панфилова	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39819	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Островского	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55709	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Муранова	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40850	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Монгольский	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40845	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Михайлова	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40021	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Мировая Коммуна	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40032	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Милиционная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40008	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Маяковского	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40835	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Майская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40130	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Лозовая	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40642	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Ленинского Комсомола	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55210	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Лебедева	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41390	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Красинская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55177	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Кошевого	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40844	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Короткий	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55211	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Индустриальная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55212	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Есенина	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40329	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Еременко	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40848	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Дубинина	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55096	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Достоевского	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41375	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Донской	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40836	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Депутатская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40170	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Дачная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39812	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Георгиевская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40846	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Врубовая	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39821	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Ворошилова	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41210	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Волошина	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41272	54820	40.074950000000001	40.087679000000001	47.729380999999997	47.723022999999998	Веселый	0103000020E61000000100000005000000E86A2BF697094440BEA085048CDC4740E86A2BF69709444071A94A5B5CDD4740E3C5C210390B444071A94A5B5CDD4740E3C5C210390B4440BEA085048CDC4740E86A2BF697094440BEA085048CDC4740
40173	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Бугроватый	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
39807	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Безымянная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40026	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Баррикадная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40244	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Базарная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55199	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Азовская	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
40175	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	60 лет Победы	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41386	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	50 лет ВЛКСМ	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41373	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	10 лет За индустриализацию	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41377	54820	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	1-й Милиционный	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55178	56619	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Свердлова	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
6812	193	38.848227999999999	38.944051999999999	47.222836999999998	47.203426999999998	улица Чехова	0103000020E6100000010000000500000097C62FBC926C4340CB0F5CE5099A474097C62FBC926C43405CAB3DEC859C474098DC28B2D67843405CAB3DEC859C474098DC28B2D6784340CB0F5CE5099A474097C62FBC926C4340CB0F5CE5099A4740
7523	193	38.915089999999999	38.915162000000002	47.259824999999999	47.256062999999997	улица Сергея Лазо	0103000020E61000000100000005000000C5724BAB217543409A5B21ACC6A04740C5724BAB2175434073D712F241A147405F4546072475434073D712F241A147405F454607247543409A5B21ACC6A04740C5724BAB217543409A5B21ACC6A04740
6857	193	38.878563999999997	38.936487999999997	47.220413000000001	47.204884	улица Розы Люксембург	0103000020E61000000100000005000000B2B8FFC874704340A1BC8FA3399A4740B2B8FFC8747043407F4E417E369C4740588CBAD6DE7743407F4E417E369C4740588CBAD6DE774340A1BC8FA3399A4740B2B8FFC874704340A1BC8FA3399A4740
7436	193	38.904544000000001	38.922609000000001	47.250424000000002	47.249389999999998	улица Пальмиро Тольятти	0103000020E6100000010000000500000082E50819C873434087F9F202EC9F474082E50819C87343401711C5E40DA0474065FF3C0D187643401711C5E40DA0474065FF3C0D1876434087F9F202EC9F474082E50819C873434087F9F202EC9F4740
75	193	38.917667999999999	38.926732000000001	47.264741000000001	47.245702000000001	улица Морозова	0103000020E61000000100000005000000F94A202576754340E947C329739F4740F94A20257675434086747808E3A147400E1478279F76434086747808E3A147400E1478279F764340E947C329739F4740F94A202576754340E947C329739F4740
4289	193	38.879472	38.880586000000001	47.245818	47.236654000000001	улица Менделеева	0103000020E61000000100000005000000B5DFDA8992704340DA3BA3AD4A9E4740B5DFDA89927043405262D7F6769F474061A8C30AB77043405262D7F6769F474061A8C30AB7704340DA3BA3AD4A9E4740B5DFDA8992704340DA3BA3AD4A9E4740
6836	193	38.891427999999998	38.927881999999997	47.274377999999999	47.260331999999998	улица Маршала Жукова	0103000020E610000001000000050000008D5E0D501A724340170D198F52A147408D5E0D501A724340F65E7CD11EA3474006465ED6C4764340F65E7CD11EA3474006465ED6C4764340170D198F52A147408D5E0D501A724340170D198F52A14740
375	193	38.900734999999997	38.917237	47.234971000000002	47.223008	улица Ленина	0103000020E6100000010000000500000068AED3484B734340895FB1868B9C474068AED3484B73434014419C87139E474030D7A2056875434014419C87139E474030D7A20568754340895FB1868B9C474068AED3484B734340895FB1868B9C4740
6933	193	38.891725000000001	38.935805000000002	47.214494999999999	47.203929000000002	улица Карла Либкнехта	0103000020E610000001000000050000004703780B247243405EDA70581A9A47404703780B24724340E8137992749B474076374F75C8774340E8137992749B474076374F75C87743405EDA70581A9A47404703780B247243405EDA70581A9A4740
5652	193	38.895128999999997	38.931753999999998	47.269675999999997	47.255555999999999	улица Инициативная	0103000020E61000000100000005000000C0594A9693724340F6251B0FB6A04740C0594A96937243400F4240BE84A2474066F50EB7437743400F4240BE84A2474066F50EB743774340F6251B0FB6A04740C0594A9693724340F6251B0FB6A04740
7334	193	38.916131999999998	38.918143999999998	47.261187999999997	47.221269999999997	улица Дзержинского	0103000020E61000000100000005000000D76839D043754340FFCA4A93529C4740D76839D043754340C70DBF9B6EA1474062821ABE85754340C70DBF9B6EA1474062821ABE85754340FFCA4A93529C4740D76839D043754340FFCA4A93529C4740
7617	193	38.893251999999997	38.929670000000002	47.272195000000004	47.258149000000003	улица 1-я Линия	0103000020E61000000100000005000000158BDF1456724340603FC4060BA14740158BDF14567243403F912749D7A247404209336DFF7643403F912749D7A247404209336DFF764340603FC4060BA14740158BDF1456724340603FC4060BA14740
41281	193	38.793359000000002	38.960768999999999	47.284757999999997	47.187893000000003	переулок Трудовых Резервов	0103000020E610000001000000050000005F7EA7C98C654340DC12B9E00C9847405F7EA7C98C6543401EA33CF372A447405C01857AFA7A43401EA33CF372A447405C01857AFA7A4340DC12B9E00C9847405F7EA7C98C654340DC12B9E00C984740
55451	193	38.903789000000003	38.944859999999998	47.206133000000001	47.200476000000002	Шевченко	0103000020E6100000010000000500000006BEA25BAF73434003D19332A999474006BEA25BAF7343402DD0EE90629A474037A6272CF17843402DD0EE90629A474037A6272CF178434003D19332A999474006BEA25BAF73434003D19332A9994740
55458	193	38.926732000000001	38.935527	47.266564000000002	47.264741000000001	Шаумяна	0103000020E610000001000000050000000E1478279F76434086747808E3A147400E1478279F7643403E25E7C41EA2474033C34659BF7743403E25E7C41EA2474033C34659BF77434086747808E3A147400E1478279F76434086747808E3A14740
55425	193	38.848227999999999	38.944051999999999	47.222836999999998	47.203426999999998	Чехова	0103000020E6100000010000000500000097C62FBC926C4340CB0F5CE5099A474097C62FBC926C43405CAB3DEC859C474098DC28B2D67843405CAB3DEC859C474098DC28B2D6784340CB0F5CE5099A474097C62FBC926C4340CB0F5CE5099A4740
55426	193	38.915089999999999	38.924145000000003	47.256062999999997	47.255813000000003	Черняховского	0103000020E61000000100000005000000C5724BAB217543402272FA7ABEA04740C5724BAB217543409A5B21ACC6A0474087E123624A7643409A5B21ACC6A0474087E123624A7643402272FA7ABEA04740C5724BAB217543402272FA7ABEA04740
55449	193	38.901274000000001	38.935006000000001	47.231636999999999	47.209567	Фрунзе	0103000020E61000000100000005000000185E49F25C73434011A96917D39A4740185E49F25C73434093C5FD47A69D47402AC8CF46AE77434093C5FD47A69D47402AC8CF46AE77434011A96917D39A4740185E49F25C73434011A96917D39A4740
55342	193	38.869078000000002	38.872501	47.223798000000002	47.217762999999998	Фадеева	0103000020E6100000010000000500000028D6A9F23D6F4340B1A371A8DF9B474028D6A9F23D6F43408274B169A59C4740185DDE1CAE6F43408274B169A59C4740185DDE1CAE6F4340B1A371A8DF9B474028D6A9F23D6F4340B1A371A8DF9B4740
5459	193	38.931403000000003	38.940412999999999	47.211641999999998	47.200648000000001	Украинский переулок	0103000020E61000000100000005000000BA32A8363877434000016BD5AE994740BA32A83638774340E23AC615179B4740DBDD03745F784340E23AC615179B4740DBDD03745F78434000016BD5AE994740BA32A8363877434000016BD5AE994740
6086	193	38.928151	38.937198000000002	47.212659000000002	47.201211000000001	Тургеневский переулок	0103000020E61000000100000005000000F65FE7A6CD764340384C3448C1994740F65FE7A6CD7643409C19FD68389B474035F0A31AF67743409C19FD68389B474035F0A31AF6774340384C3448C1994740F65FE7A6CD764340384C3448C1994740
55371	193	38.879148000000001	38.886200000000002	47.250320000000002	47.215277999999998	Транспортная	0103000020E61000000100000005000000022CF2EB877043402EC6C03A8E9B4740022CF2EB8770434072C45A7C0AA047408CDB68006F71434072C45A7C0AA047408CDB68006F7143402EC6C03A8E9B4740022CF2EB877043402EC6C03A8E9B4740
6838	193	38.90157	38.917183000000001	47.221625000000003	47.199734999999997	Смирновский переулок	0103000020E61000000100000005000000018750A566734340EB6E9EEA90994740018750A566734340EE7C3F355E9C47403DB9A64066754340EE7C3F355E9C47403DB9A64066754340EB6E9EEA90994740018750A566734340EB6E9EEA90994740
39745	193	38.793359000000002	38.960768999999999	47.284757999999997	47.187893000000003	Сергея Шило	0103000020E610000001000000050000005F7EA7C98C654340DC12B9E00C9847405F7EA7C98C6543401EA33CF372A447405C01857AFA7A43401EA33CF372A447405C01857AFA7A4340DC12B9E00C9847405F7EA7C98C654340DC12B9E00C984740
55359	193	38.915089999999999	38.915162000000002	47.259824999999999	47.256062999999997	Сергея Лазо	0103000020E61000000100000005000000C5724BAB217543409A5B21ACC6A04740C5724BAB2175434073D712F241A147405F4546072475434073D712F241A147405F454607247543409A5B21ACC6A04740C5724BAB217543409A5B21ACC6A04740
55397	193	38.883631000000001	38.895147000000001	47.218094000000001	47.203181999999998	Свободы	0103000020E61000000100000005000000AB5D13D21A714340649126DE019A4740AB5D13D21A71434017BA1281EA9B4740670E492D9472434017BA1281EA9B4740670E492D94724340649126DE019A4740AB5D13D21A714340649126DE019A4740
55193	193	38.843376999999997	38.917560000000002	47.225548000000003	47.214807	С. И. Шило	0103000020E610000001000000050000006B990CC7F36B4340D7F9B7CB7E9B47406B990CC7F36B4340D0D6C1C1DE9C4740130F289B72754340D0D6C1C1DE9C4740130F289B72754340D7F9B7CB7E9B47406B990CC7F36B4340D7F9B7CB7E9B4740
55361	193	38.878563999999997	38.936487999999997	47.220413000000001	47.204884	Розы Люксембург	0103000020E61000000100000005000000B2B8FFC874704340A1BC8FA3399A4740B2B8FFC8747043407F4E417E369C4740588CBAD6DE7743407F4E417E369C4740588CBAD6DE774340A1BC8FA3399A4740B2B8FFC874704340A1BC8FA3399A4740
55433	193	38.892183000000003	38.909008	47.272010999999999	47.265560999999998	Поселковая	0103000020E610000001000000050000000A86730D33724340E90B21E7FDA147400A86730D337243407D93A641D1A24740B4E6C75F5A7443407D93A641D1A24740B4E6C75F5A744340E90B21E7FDA147400A86730D33724340E90B21E7FDA14740
55373	193	38.917237	38.943458999999997	47.223008	47.206004999999998	Петровская	0103000020E6100000010000000500000030D7A20568754340FFE7305F5E9A474030D7A20568754340895FB1868B9C4740F50EB743C3784340895FB1868B9C4740F50EB743C3784340FFE7305F5E9A474030D7A20568754340FFE7305F5E9A4740
55454	193	38.864550999999999	38.872770000000003	47.227426999999999	47.212971000000003	Пархоменко	0103000020E61000000100000005000000AF5C6F9BA96E43408BFF3BA2429B4740AF5C6F9BA96E43401B9DF3531C9D4740087767EDB66F43401B9DF3531C9D4740087767EDB66F43408BFF3BA2429B4740AF5C6F9BA96E43408BFF3BA2429B4740
55358	193	38.885418999999999	38.925680999999997	47.236818999999997	47.213760000000001	Октябрьская	0103000020E61000000100000005000000E620E86855714340B398D87C5C9B4740E620E868557143402409C215509E4740A8C30AB77C7643402409C215509E4740A8C30AB77C764340B398D87C5C9B4740E620E86855714340B398D87C5C9B4740
6776	193	38.935796000000003	38.943252000000001	47.209769000000001	47.199826999999999	Некрасовский переулок	0103000020E6100000010000000500000023DDCF29C8774340CCED5EEE9399474023DDCF29C8774340795BE9B5D99A47407CF1457BBC784340795BE9B5D99A47407CF1457BBC784340CCED5EEE9399474023DDCF29C8774340CCED5EEE93994740
55446	193	38.903385	38.912036000000001	47.259996000000001	47.241492999999998	Московская	0103000020E610000001000000050000003659A31EA2734340419B1C3EE99E47403659A31EA2734340A08B868C47A1474028637C98BD744340A08B868C47A1474028637C98BD744340419B1C3EE99E47403659A31EA2734340419B1C3EE99E4740
55428	193	38.895713000000001	38.926138999999999	47.263879000000003	47.252068999999999	Москатова	0103000020E6100000010000000500000010CD3CB9A6724340EFAA07CC43A0474010CD3CB9A6724340F48C7DC9C6A147406B4606B98B764340F48C7DC9C6A147406B4606B98B764340EFAA07CC43A0474010CD3CB9A6724340EFAA07CC43A04740
55319	193	38.938527000000001	38.951920999999999	47.272207000000002	47.260019999999997	Михайловская	0103000020E61000000100000005000000DDB419A7217843402827DA5548A14740DDB419A721784340035FD1ADD7A2474014B01D8CD8794340035FD1ADD7A2474014B01D8CD87943402827DA5548A14740DDB419A7217843402827DA5548A14740
55377	193	38.891427999999998	38.927881999999997	47.274377999999999	47.260331999999998	Маршала Жукова	0103000020E610000001000000050000008D5E0D501A724340170D198F52A147408D5E0D501A724340F65E7CD11EA3474006465ED6C4764340F65E7CD11EA3474006465ED6C4764340170D198F52A147408D5E0D501A724340170D198F52A14740
55330	193	38.875807000000002	38.879894	47.246429999999997	47.220713000000003	Ломоносова	0103000020E61000000100000005000000CF4D9B711A704340AA66D652409C4740CF4D9B711A7043406B60AB048B9F47402BF9D85DA07043406B60AB048B9F47402BF9D85DA0704340AA66D652409C4740CF4D9B711A704340AA66D652409C4740
55424	193	38.896251999999997	38.918638000000001	47.204859999999996	47.200445999999999	Ломакина	0103000020E61000000100000005000000BF7CB262B8724340984EEB36A8994740BF7CB262B872434018213CDA389A4740726E13EE9575434018213CDA389A4740726E13EE95754340984EEB36A8994740BF7CB262B8724340984EEB36A8994740
6895	193	38.925178000000002	38.933092000000002	47.214568	47.209640999999998	Лермонтовский переулок	0103000020E61000000100000005000000467D923B6C7643404B732B84D59A4740467D923B6C7643405262D7F6769B47406214048F6F7743405262D7F6769B47406214048F6F7743404B732B84D59A4740467D923B6C7643404B732B84D59A4740
55268	193	38.900734999999997	38.917237	47.234971000000002	47.223008	Ленина	0103000020E6100000010000000500000068AED3484B734340895FB1868B9C474068AED3484B73434014419C87139E474030D7A2056875434014419C87139E474030D7A20568754340895FB1868B9C474068AED3484B734340895FB1868B9C4740
6935	193	38.889757000000003	38.896405000000001	47.205728999999998	47.202429000000002	Красногвардейский переулок	0103000020E610000001000000050000008C31B08EE371434089618731E99947408C31B08EE37143405D6BEF53559A4740467C2766BD7243405D6BEF53559A4740467C2766BD72434089618731E99947408C31B08EE371434089618731E9994740
55393	193	38.890844000000001	38.899774000000001	47.252215999999997	47.235638000000002	Котлостроительная	0103000020E610000001000000050000003EEB1A2D07724340F1D8CF62299E47403EEB1A2D0772434093C3279D48A0474043E55FCB2B73434093C3279D48A0474043E55FCB2B734340F1D8CF62299E47403EEB1A2D07724340F1D8CF62299E4740
55311	193	38.927261999999999	38.928905999999998	47.232004000000003	47.223767000000002	Конторская	0103000020E610000001000000050000006A696E85B07643404776A565A49C47406A696E85B076434046459C4EB29D474072874D64E676434046459C4EB29D474072874D64E67643404776A565A49C47406A696E85B07643404776A565A49C4740
6834	193	38.910518000000003	38.920695000000002	47.214550000000003	47.200561999999998	Комсомольский переулок	0103000020E61000000100000005000000AD3594DA8B7443400169FF03AC994740AD3594DA8B744340ACADD85F769B47409D4B7155D9754340ACADD85F769B47409D4B7155D97543400169FF03AC994740AD3594DA8B7443400169FF03AC994740
55399	193	38.874800999999998	38.884889000000001	47.240955	47.240623999999997	Комарова	0103000020E6100000010000000500000009C1AA7AF96F4340FC5069C4CC9E474009C1AA7AF96F434062670A9DD79E47408ACBF10A4471434062670A9DD79E47408ACBF10A44714340FC5069C4CC9E474009C1AA7AF96F4340FC5069C4CC9E4740
55476	193	38.393411	39.448068999999997	47.616667	46.898662000000002	Кирова	0103000020E610000001000000050000007E71A94A5B32434038143E5B077347407E71A94A5B324340DFC2BAF1EECE4740FBAC32535AB94340DFC2BAF1EECE4740FBAC32535AB9434038143E5B077347407E71A94A5B32434038143E5B07734740
55459	193	38.882787	38.883235999999997	47.246369000000001	47.222586	Калинина	0103000020E61000000100000005000000BF2A172AFF7043401346B3B27D9C4740BF2A172AFF704340C6DFF604899F47402E5393E00D714340C6DFF604899F47402E5393E00D7143401346B3B27D9C4740BF2A172AFF7043401346B3B27D9C4740
55375	193	38.880586000000001	38.903385	47.203181999999998	47.197598999999997	Инструментальная	0103000020E6100000010000000500000061A8C30AB7704340745C8DEC4A99474061A8C30AB7704340649126DE019A47403659A31EA2734340649126DE019A47403659A31EA2734340745C8DEC4A99474061A8C30AB7704340745C8DEC4A994740
55455	193	38.895128999999997	38.931753999999998	47.269675999999997	47.255555999999999	Инициативная	0103000020E61000000100000005000000C0594A9693724340F6251B0FB6A04740C0594A96937243400F4240BE84A2474066F50EB7437743400F4240BE84A2474066F50EB743774340F6251B0FB6A04740C0594A9693724340F6251B0FB6A04740
55335	193	38.917264000000003	38.922958999999999	47.239908999999997	47.238458999999999	Заводская	0103000020E610000001000000050000002AE620E868754340EB3713D3859E47402AE620E8687543400E828E56B59E474041464085237643400E828E56B59E47404146408523764340EB3713D3859E47402AE620E868754340EB3713D3859E4740
6825	193	38.933514000000002	38.941761	47.211024000000002	47.201473999999997	Добролюбовский переулок	0103000020E61000000100000005000000D82D02637D774340457F68E6C9994740D82D02637D774340E7559DD5029B4740FAD2DB9F8B784340E7559DD5029B4740FAD2DB9F8B784340457F68E6C9994740D82D02637D774340457F68E6C9994740
55376	193	38.916131999999998	38.918143999999998	47.261187999999997	47.221269999999997	Дзержинского	0103000020E61000000100000005000000D76839D043754340FFCA4A93529C4740D76839D043754340C70DBF9B6EA1474062821ABE85754340C70DBF9B6EA1474062821ABE85754340FFCA4A93529C4740D76839D043754340FFCA4A93529C4740
55423	193	38.926659999999998	38.944878000000003	47.217623000000003	47.204407000000003	Греческая	0103000020E6100000010000000500000074417DCB9C764340680932022A9A474074417DCB9C764340C0ED0912DB9B4740DE5A26C3F1784340C0ED0912DB9B4740DE5A26C3F1784340680932022A9A474074417DCB9C764340680932022A9A4740
55301	193	38.885517	38.901255999999997	47.23751	47.227004000000001	Восточная	0103000020E61000000100000005000000A986FD9E58714340D50792770E9D4740A986FD9E587143408A3C49BA669E474071A94A5B5C7343408A3C49BA669E474071A94A5B5C734340D50792770E9D4740A986FD9E58714340D50792770E9D4740
55398	193	38.872914000000002	38.875078999999999	47.245052999999999	47.233068000000003	Вишневая	0103000020E610000001000000050000003B1C5DA5BB6F434040DF162CD59D47403B1C5DA5BB6F4340B2648EE55D9F47404C35B39602704340B2648EE55D9F47404C35B3960270434040DF162CD59D47403B1C5DA5BB6F434040DF162CD59D4740
6894	193	38.890180000000001	38.894230999999998	47.230418999999998	47.216037	Большой проспект	0103000020E61000000100000005000000D2C6116BF1714340ECDCB419A79B4740D2C6116BF171434042B0AA5E7E9D4740E10852297672434042B0AA5E7E9D4740E108522976724340ECDCB419A79B4740D2C6116BF1714340ECDCB419A79B4740
6900	193	38.922232000000001	38.932355999999999	47.222946999999998	47.221392999999999	Большой Садовый переулок	0103000020E610000001000000050000008FA9BBB20B7643401B48179B569C47408FA9BBB20B764340E3DEFC86899C47405C1D007157774340E3DEFC86899C47405C1D0071577743401B48179B569C47408FA9BBB20B7643401B48179B569C4740
40153	193	38.793359000000002	38.960768999999999	47.284757999999997	47.187893000000003	Большая Бульварная	0103000020E610000001000000050000005F7EA7C98C654340DC12B9E00C9847405F7EA7C98C6543401EA33CF372A447405C01857AFA7A43401EA33CF372A447405C01857AFA7A4340DC12B9E00C9847405F7EA7C98C654340DC12B9E00C984740
55378	193	38.935338000000002	38.939174000000001	47.263855	47.253371999999999	Бабушкина	0103000020E61000000100000005000000605AD427B97743406EDC627E6EA04740605AD427B97743406BF12900C6A1474073A087DA367843406BF12900C6A1474073A087DA367843406EDC627E6EA04740605AD427B97743406EDC627E6EA04740
56581	193	38.926138999999999	38.934502999999999	47.264527000000001	47.262949999999996	Афоновых	0103000020E610000001000000050000006B4606B98B764340D93D7958A8A147406B4606B98B7643405AF44E05DCA14740C78157CB9D7743405AF44E05DCA14740C78157CB9D774340D93D7958A8A147406B4606B98B764340D93D7958A8A14740
55443	193	38.892273000000003	38.935464000000003	47.227297999999998	47.207712999999998	Александровская	0103000020E610000001000000050000004A0D6D00367243401EFAEE56969A47404A0D6D00367243401D39D219189D4740ED4ACB48BD7743401D39D219189D4740ED4ACB48BD7743401EFAEE56969A47404A0D6D00367243401EFAEE56969A4740
7651	193	38.901767999999997	38.916508999999998	47.280802999999999	47.263665000000003	7-й Новый переулок	0103000020E61000000100000005000000274A42226D734340C80C54C6BFA14740274A42226D73434031CF4A5AF1A34740ADBEBA2A5075434031CF4A5AF1A34740ADBEBA2A50754340C80C54C6BFA14740274A42226D734340C80C54C6BFA14740
55306	193	38.889685999999998	38.926031000000002	47.276468999999999	47.262490999999997	3-я Линия	0103000020E61000000100000005000000C2DA183BE1714340463F1A4E99A14740C2DA183BE1714340CDAD105663A34740850A0E2F88764340CDAD105663A34740850A0E2F88764340463F1A4E99A14740C2DA183BE1714340463F1A4E99A14740
7390	193	38.907688	38.917569	47.244630999999998	47.235773000000002	3-й Артиллерийский переулок	0103000020E610000001000000050000005F7CD11E2F744340D12346CF2D9E47405F7CD11E2F7443403C4B9011509F47406669A7E6727543403C4B9011509F47406669A7E672754340D12346CF2D9E47405F7CD11E2F744340D12346CF2D9E4740
7552	193	38.888328999999999	38.894832999999998	47.264130000000002	47.256247000000002	17-й Новый переулок	0103000020E61000000100000005000000508BC1C3B47143405C59A2B3CCA04740508BC1C3B47143403DF20703CFA14740D73043E3897243403DF20703CFA14740D73043E3897243405C59A2B3CCA04740508BC1C3B47143405C59A2B3CCA04740
7409	193	38.905755999999997	38.917667999999999	47.246344000000001	47.246043999999998	14-й Артиллерийский переулок	0103000020E61000000100000005000000F01307D0EF73434042B0AA5E7E9F4740F01307D0EF7343406DC83F33889F4740F94A2025767543406DC83F33889F4740F94A20257675434042B0AA5E7E9F4740F01307D0EF73434042B0AA5E7E9F4740
6839	193	38.923875000000002	38.931753999999998	47.279262000000003	47.269675999999997	1-й Новый переулок	0103000020E61000000100000005000000C74B3789417643400F4240BE84A24740C74B378941764340FE8172DBBEA3474066F50EB743774340FE8172DBBEA3474066F50EB7437743400F4240BE84A24740C74B3789417643400F4240BE84A24740
55369	193	38.848227999999999	38.944051999999999	47.222836999999998	47.203426999999998	 Чехова	0103000020E6100000010000000500000097C62FBC926C4340CB0F5CE5099A474097C62FBC926C43405CAB3DEC859C474098DC28B2D67843405CAB3DEC859C474098DC28B2D6784340CB0F5CE5099A474097C62FBC926C4340CB0F5CE5099A4740
55267	193	38.872914000000002	38.884763	47.233099000000003	47.232731999999999	 Театральная	0103000020E610000001000000050000003B1C5DA5BB6F4340C85D8429CA9D47403B1C5DA5BB6F43407BDD2230D69D4740FDDAFAE93F7143407BDD2230D69D4740FDDAFAE93F714340C85D8429CA9D47403B1C5DA5BB6F4340C85D8429CA9D4740
55271	193	38.896234	38.900860999999999	47.218657	47.216405000000002	 Площадь Мира	0103000020E6100000010000000500000019C8B3CBB77243406FD8B628B39B474019C8B3CBB77243404F05DCF3FC9B4740F59ECA694F7343404F05DCF3FC9B4740F59ECA694F7343406FD8B628B39B474019C8B3CBB77243406FD8B628B39B4740
55352	193	38.869275999999999	38.875447000000001	47.220640000000003	47.219208000000002	 Плеханова	0103000020E610000001000000050000004E999B6F446F4340C382FB010F9C47404E999B6F446F4340401878EE3D9C4740CF30B5A50E704340401878EE3D9C4740CF30B5A50E704340C382FB010F9C47404E999B6F446F4340C382FB010F9C4740
55097	56609	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	Атаманский проспект	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
55111	56609	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	Араканцева	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
55174	56609	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	16-й переулок	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
55183	56620	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Кутузова	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
55186	56620	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Коломийцева	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
182	378	39.773358000000002	39.774841000000002	47.242801999999998	47.235686999999999	улица Школьная	0103000020E61000000100000005000000CC0C1B65FDE24340D28BDAFD2A9E4740CC0C1B65FDE24340A2B3CC22149F4740CB4C69FD2DE34340A2B3CC22149F4740CB4C69FD2DE34340D28BDAFD2A9E4740CC0C1B65FDE24340D28BDAFD2A9E4740
1960	378	39.705508999999999	39.734442999999999	47.274774999999998	47.265512000000001	улица Фурмановская	0103000020E610000001000000050000004F04711E4EDA43400859164CFCA147404F04711E4EDA43401361C3D32BA3474058E36C3A02DE43401361C3D32BA3474058E36C3A02DE43400859164CFCA147404F04711E4EDA43400859164CFCA14740
5573	378	39.700218	39.720447999999998	47.218161000000002	47.214146	улица Тургеневская	0103000020E61000000100000005000000070951BEA0D94340DC48D922699B4740070951BEA0D943409F211CB3EC9B4740FB3BDBA337DC43409F211CB3EC9B4740FB3BDBA337DC4340DC48D922699B4740070951BEA0D94340DC48D922699B4740
2733	378	39.800083000000001	39.809812000000001	47.282704000000003	47.279629	улица Туполева	0103000020E61000000100000005000000F48AA71E69E64340B00111E2CAA34740F48AA71E69E64340653909A52FA4474045F46BEBA7E74340653909A52FA4474045F46BEBA7E74340B00111E2CAA34740F48AA71E69E64340B00111E2CAA34740
6139	378	39.621256000000002	39.681497	47.265891000000003	47.256839999999997	улица Таганрогская	0103000020E61000000100000005000000CE380D5185CF4340FE261422E0A04740CE380D5185CF43407FA65EB708A247403BA92F4B3BD743407FA65EB708A247403BA92F4B3BD74340FE261422E0A04740CE380D5185CF4340FE261422E0A04740
492	378	39.749336999999997	39.762048999999998	47.230431000000003	47.228039000000003	улица Советская	0103000020E6100000010000000500000064575A46EADF4340359BC761309D474064575A46EADF4340077E54C37E9D4740897956D28AE14340077E54C37E9D4740897956D28AE14340359BC761309D474064575A46EADF4340359BC761309D4740
5557	378	39.699354999999997	39.719531000000003	47.220744000000003	47.216569999999997	улица Серафимовича	0103000020E61000000100000005000000A4A5F27684D94340B9A5D590B89B4740A4A5F27684D94340E564E256419C4740A6BA809719DC4340E564E256419C4740A6BA809719DC4340B9A5D590B89B4740A4A5F27684D94340B9A5D590B89B4740
1446	378	39.697082000000002	39.741135999999997	47.230792000000001	47.221356	улица Пушкинская	0103000020E61000000100000005000000AD50A4FB39D94340FE62B664559C4740AD50A4FB39D94340D7169E978A9D4740B2F1608BDDDE4340D7169E978A9D4740B2F1608BDDDE4340FE62B664559C4740AD50A4FB39D94340FE62B664559C4740
3808	378	39.627741	39.696911999999998	47.214128000000002	47.189864999999998	улица Портовая	0103000020E61000000100000005000000DEAD2CD159D04340D8D30E7F4D984740DEAD2CD159D043403694DA8B689B47405018946934D943403694DA8B689B47405018946934D94340D8D30E7F4D984740DEAD2CD159D04340D8D30E7F4D984740
6017	378	39.705292999999998	39.711159000000002	47.263145000000002	47.249617000000001	улица Погодина	0103000020E61000000100000005000000828C800A47DA434048C32973F39F4740828C800A47DA43408F8D40BCAEA14740C7A0134207DB43408F8D40BCAEA14740C7A0134207DB434048C32973F39F4740828C800A47DA434048C32973F39F4740
6532	378	39.564427999999999	39.615794000000001	47.222262000000001	47.195149000000001	улица Пескова	0103000020E610000001000000050000002D793C2D3FC843406E6C76A4FA9847402D793C2D3FC843406092CA14739C474059897956D2CE43406092CA14739C474059897956D2CE43406E6C76A4FA9847402D793C2D3FC843406E6C76A4FA984740
2898	378	39.767268000000001	39.783653000000001	47.308163999999998	47.265951999999999	улица Орская	0103000020E6100000010000000500000038A27BD635E24340242713B70AA2474038A27BD635E24340FBE6FEEA71A74740C634D3BD4EE44340FBE6FEEA71A74740C634D3BD4EE44340242713B70AA2474038A27BD635E24340242713B70AA24740
580	378	39.775829000000002	39.788781999999998	47.266331000000001	47.261353	улица Молодежная	0103000020E61000000100000005000000EA245B5D4EE3434012DBDD0374A14740EA245B5D4EE343409B745B2217A2474034D6FECEF6E443409B745B2217A2474034D6FECEF6E4434012DBDD0374A14740EA245B5D4EE3434012DBDD0374A14740
5777	378	39.672288999999999	39.711312	47.241768	47.236507000000003	улица Мечникова	0103000020E61000000100000005000000F33AE2900DD64340362383DC459E4740F33AE2900DD64340139CFA40F29E47404DA088450CDB4340139CFA40F29E47404DA088450CDB4340362383DC459E4740F33AE2900DD64340362383DC459E4740
2940	378	39.768048999999998	39.774616000000002	47.255073000000003	47.247897999999999	улица Металлургическая	0103000020E61000000100000005000000DD5CFC6D4FE24340355F251FBB9F4740DD5CFC6D4FE24340DB8B683BA6A04740AB7AF99D26E34340DB8B683BA6A04740AB7AF99D26E34340355F251FBB9F4740DD5CFC6D4FE24340355F251FBB9F4740
2859	378	39.781469999999999	39.786042999999999	47.266880999999998	47.261775	улица Мелитопольская	0103000020E610000001000000050000000E677E3507E4434088F4DBD781A147400E677E3507E443403E76172829A24740F71F990E9DE443403E76172829A24740F71F990E9DE4434088F4DBD781A147400E677E3507E4434088F4DBD781A14740
5299	378	39.681398000000002	39.736922999999997	47.237381999999997	47.225847999999999	улица Малюгиной	0103000020E61000000100000005000000A8C7B60C38D74340FAEE5696E89C4740A8C7B60C38D743405C548B88629E4740C9552C7E53DE43405C548B88629E4740C9552C7E53DE4340FAEE5696E89C4740A8C7B60C38D74340FAEE5696E89C4740
4410	378	39.694764999999997	39.74295	47.232664	47.221691999999997	улица Максима Горького	0103000020E61000000100000005000000E5B33C0FEED8434075E44867609C4740E5B33C0FEED84340707A17EFC79D4740174850FC18DF4340707A17EFC79D4740174850FC18DF434075E44867609C4740E5B33C0FEED8434075E44867609C4740
4867	378	39.634632000000003	39.662424999999999	47.229078999999999	47.224251000000002	улица Лесопарковая	0103000020E610000001000000050000005F7F129F3BD14340338CBB41B49C47405F7F129F3BD14340A699EE75529D4740C286A757CAD44340A699EE75529D4740C286A757CAD44340338CBB41B49C47405F7F129F3BD14340338CBB41B49C4740
5206	378	39.690596999999997	39.735323999999999	47.235461000000001	47.226171999999998	улица Лермонтовская	0103000020E610000001000000050000009CDB847B65D84340ADA23F34F39C47409CDB847B65D84340E23D0796239E474061FBC9181FDE4340E23D0796239E474061FBC9181FDE4340ADA23F34F39C47409CDB847B65D84340ADA23F34F39C4740
4990	378	39.666260999999999	39.671148000000002	47.211232000000003	47.202630999999997	улица Кулагина	0103000020E61000000100000005000000D5CC5A0A48D54340F01307D0EF994740D5CC5A0A48D5434031EF71A6099B47404E637B2DE8D5434031EF71A6099B47404E637B2DE8D54340F01307D0EF994740D5CC5A0A48D54340F01307D0EF994740
4892	378	39.647972000000003	39.663027	47.214342000000002	47.213822	улица Крупской	0103000020E61000000100000005000000A35C1ABFF0D243402995F0845E9B4740A35C1ABFF0D243406214048F6F9B4740B8AE9811DED443406214048F6F9B4740B8AE9811DED443402995F0845E9B4740A35C1ABFF0D243402995F0845E9B4740
5360	378	39.725855000000003	39.744503999999999	47.222977999999998	47.219293	улица Красных Зорь	0103000020E61000000100000005000000AD510FD1E8DC4340F19E03CB119C4740AD510FD1E8DC43401EDD088B8A9C4740DFDE35E84BDF43401EDD088B8A9C4740DFDE35E84BDF4340F19E03CB119C4740AD510FD1E8DC4340F19E03CB119C4740
929	378	39.690390000000001	39.739275999999997	47.233685999999999	47.220646000000002	улица Красноармейская	0103000020E6100000010000000500000023BE13B35ED8434022FFCC203E9C474023BE13B35ED843403BC43F6CE99D4740DD5B9198A0DE43403BC43F6CE99D4740DD5B9198A0DE434022FFCC203E9C474023BE13B35ED8434022FFCC203E9C4740
6427	378	39.621893	39.638620000000003	47.237253000000003	47.233142000000001	улица Калининградская	0103000020E61000000100000005000000404E98309ACF43407AA9D898D79D4740404E98309ACF43405FF0694E5E9E47402849D74CBED143405FF0694E5E9E47402849D74CBED143407AA9D898D79D4740404E98309ACF43407AA9D898D79D4740
2616	378	39.730139999999999	39.754035999999999	47.288699999999999	47.271448999999997	улица Казахская	0103000020E610000001000000050000002FC03E3A75DD434015C440D7BEA247402FC03E3A75DD4340772D211FF4A44740DA006C4084E04340772D211FF4A44740DA006C4084E0434015C440D7BEA247402FC03E3A75DD434015C440D7BEA24740
5978	378	39.662219	39.685063	47.247604000000003	47.245953	улица Зоологическая	0103000020E6100000010000000500000019E59997C3D4434032AD4D637B9F474019E59997C3D44340ED2DE57CB19F47408E59F624B0D74340ED2DE57CB19F47408E59F624B0D7434032AD4D637B9F474019E59997C3D4434032AD4D637B9F4740
6478	378	39.606191000000003	39.642733999999997	47.235363	47.232290999999996	улица Еременко	0103000020E610000001000000050000009510ACAA97CD4340DB1324B6BB9D47409510ACAA97CD43401FD8F15F209E47407D03931B45D243401FD8F15F209E47407D03931B45D24340DB1324B6BB9D47409510ACAA97CD4340DB1324B6BB9D4740
2133	378	39.701402999999999	39.707835000000003	47.299169999999997	47.282924000000001	улица Добровольского	0103000020E610000001000000050000007C28D192C7D9434073A087DA36A447407C28D192C7D94340DFF8DA334BA647406AFB57569ADA4340DFF8DA334BA647406AFB57569ADA434073A087DA36A447407C28D192C7D9434073A087DA36A44740
2714	378	39.787362999999999	39.803595999999999	47.298533999999997	47.267480999999997	улица Днепропетровская	0103000020E610000001000000050000004C8A8F4FC8E4434093A641D13CA247404C8A8F4FC8E443403D5FB35C36A647402499D53BDCE643403D5FB35C36A647402499D53BDCE6434093A641D13CA247404C8A8F4FC8E4434093A641D13CA24740
2842	378	39.775703	39.797657999999998	47.273038999999997	47.264190999999997	улица Глинки	0103000020E610000001000000050000005D34643C4AE34340E272BC02D1A147405D34643C4AE343402AC423F1F2A2474046B247A819E643402AC423F1F2A2474046B247A819E64340E272BC02D1A147405D34643C4AE34340E272BC02D1A14740
55200	378	39.676456999999999	39.679645999999998	47.232743999999997	47.230516999999999	улица Гайдара	0103000020E610000001000000050000003C139A2496D643400516C094819D47403C139A2496D643408C2B2E8ECA9D4740B96DDFA3FED643408C2B2E8ECA9D4740B96DDFA3FED643400516C094819D47403C139A2496D643400516C094819D4740
55205	378	39.745626999999999	39.750459999999997	47.237791999999999	47.22824	улица Верхненольная	0103000020E61000000100000005000000DE019EB470DF4340CCD1E3F7369D4740DE019EB470DF43400EA0DFF76F9E4740637AC2120FE043400EA0DFF76F9E4740637AC2120FE04340CCD1E3F7369D4740DE019EB470DF4340CCD1E3F7369D4740
6076	378	39.676304000000002	39.686689000000001	47.306294999999999	47.261225000000003	улица Вавилова	0103000020E61000000100000005000000B613252191D64340E5F21FD26FA14740B613252191D64340D3F6AFAC34A74740F0C2D66CE5D74340D3F6AFAC34A74740F0C2D66CE5D74340E5F21FD26FA14740B613252191D64340E5F21FD26FA14740
4901	378	39.664158999999998	39.668174999999998	47.219439999999999	47.215890000000002	улица Балакирева	0103000020E610000001000000050000000A2C802903D5434048C49448A29B47400A2C802903D5434095B7239C169C47409D8026C286D5434095B7239C169C47409D8026C286D5434048C49448A29B47400A2C802903D5434048C49448A29B4740
3754	378	39.839222999999997	39.843741000000001	47.253200999999997	47.250228	улица Аксайская	0103000020E610000001000000050000008786C5A86BEB434091459A7807A047408786C5A86BEB43404128EFE368A04740ADA580B4FFEB43404128EFE368A04740ADA580B4FFEB434091459A7807A047408786C5A86BEB434091459A7807A04740
3270	378	39.750712	39.757593	47.243774999999999	47.229574	улица 14-я Линия	0103000020E610000001000000050000007D5BB05417E0434086014BAE629D47407D5BB05417E043408C4AEA04349F4740DA56B3CEF8E043408C4AEA04349F4740DA56B3CEF8E0434086014BAE629D47407D5BB05417E0434086014BAE629D4740
3246	378	39.751547000000002	39.754781000000001	47.228436000000002	47.220426000000003	улица 1-я Линия	0103000020E6100000010000000500000016342DB132E0434014984EEB369C474016342DB132E04340529D0E643D9D47403352EFA99CE04340529D0E643D9D47403352EFA99CE0434014984EEB369C474016342DB132E0434014984EEB369C4740
55255	378	39.761096000000002	39.892896999999998	47.274279999999997	47.1845	станция Кизитеринка	0103000020E61000000100000005000000E78EFE976BE14340560E2DB29D974740E78EFE976BE1434033F9669B1BA3474027D9EA724AF2434033F9669B1BA3474027D9EA724AF24340560E2DB29D974740E78EFE976BE14340560E2DB29D974740
78529	378	39.678621999999997	39.756174000000001	47.250644000000001	47.248987	проспект Ленина	0103000020E610000001000000050000004D2CF015DDD64340881057CEDE9F47404D2CF015DDD643402578431A15A04740F20A444FCAE043402578431A15A04740F20A444FCAE04340881057CEDE9F47404D2CF015DDD64340881057CEDE9F4740
40569	378	39.678621999999997	39.756174000000001	47.250644000000001	47.248987	проспект Ленина	0103000020E610000001000000050000004D2CF015DDD64340881057CEDE9F47404D2CF015DDD643402578431A15A04740F20A444FCAE043402578431A15A04740F20A444FCAE04340881057CEDE9F47404D2CF015DDD64340881057CEDE9F4740
55209	378	39.501958999999999	39.859766999999998	47.345292999999998	47.158563999999998	пер. Саратовский	0103000020E610000001000000050000006877483140C0434056293DD34B9447406877483140C04340D4449F8F32AC47400B9755D80CEE4340D4449F8F32AC47400B9755D80CEE434056293DD34B9447406877483140C0434056293DD34B944740
55402	378	39.731703000000003	39.757162000000001	47.292746999999999	47.285527999999999	Штахановского	0103000020E610000001000000050000004BB1A371A8DD4340D00B772E8CA447404BB1A371A8DD43404580D3BB78A5474011E335AFEAE043404580D3BB78A5474011E335AFEAE04340D00B772E8CA447404BB1A371A8DD4340D00B772E8CA44740
3056	378	39.737920000000003	39.824769000000003	47.272537	47.235210000000002	Шолохова проспект	0103000020E610000001000000050000003C889D2974DE434099D87C5C1B9E47403C889D2974DE434098F90E7EE2A2474098E0D40792E9434098F90E7EE2A2474098E0D40792E9434099D87C5C1B9E47403C889D2974DE434099D87C5C1B9E4740
55406	378	39.742780000000003	39.763179999999998	47.237882999999997	47.232664	Ченцова	0103000020E61000000100000005000000BB0F406A13DF4340707A17EFC79D4740BB0F406A13DF43401EA33CF3729E47400B7BDAE1AFE143401EA33CF3729E47400B7BDAE1AFE14340707A17EFC79D4740BB0F406A13DF4340707A17EFC79D4740
55198	378	39.683554000000001	39.687821	47.219574999999999	47.216146999999999	Чебанова	0103000020E6100000010000000500000066868DB27ED74340731074B4AA9B474066868DB27ED7434075029A081B9C47404240BE840AD8434075029A081B9C47404240BE840AD84340731074B4AA9B474066868DB27ED74340731074B4AA9B4740
5657	378	39.694037000000002	39.705418999999999	47.238508000000003	47.212786999999999	Халтуринский переулок	0103000020E61000000100000005000000639B5434D6D84340C901BB9A3C9B4740639B5434D6D84340CDEA1D6E879E47400F7D772B4BDA4340CDEA1D6E879E47400F7D772B4BDA4340C901BB9A3C9B4740639B5434D6D84340C901BB9A3C9B4740
55328	378	39.694575999999998	39.701664000000001	47.242282000000003	47.239603000000002	Фрунзе	0103000020E61000000100000005000000124BCADDE7D843400283A44FAB9E4740124BCADDE7D843406A34B918039F4740E9633E20D0D943406A34B918039F4740E9633E20D0D943400283A44FAB9E4740124BCADDE7D843400283A44FAB9E4740
55285	378	39.783231000000001	39.80312	47.306452999999998	47.304461000000003	Фасадная	0103000020E61000000100000005000000501BD5E940E4434028F4FA93F8A64740501BD5E940E443406B6116DA39A74740BB61DBA2CCE643406B6116DA39A74740BB61DBA2CCE6434028F4FA93F8A64740501BD5E940E4434028F4FA93F8A64740
55413	378	39.726736000000002	39.758113999999999	47.287942999999999	47.280644000000002	Украинская	0103000020E61000000100000005000000B6696CAF05DD4340C9E88024ECA34740B6696CAF05DD43405A0EF450DBA44740E3512AE109E143405A0EF450DBA44740E3512AE109E14340C9E88024ECA34740B6696CAF05DD4340C9E88024ECA34740
55354	378	39.800083000000001	39.809812000000001	47.282704000000003	47.279629	Туполева	0103000020E61000000100000005000000F48AA71E69E64340B00111E2CAA34740F48AA71E69E64340653909A52FA4474045F46BEBA7E74340653909A52FA4474045F46BEBA7E74340B00111E2CAA34740F48AA71E69E64340B00111E2CAA34740
55452	378	39.648761999999998	39.665039999999998	47.270733999999997	47.264527000000001	Тимошенко	0103000020E610000001000000050000009B711AA20AD343405AF44E05DCA147409B711AA20AD3434027F56569A7A247401344DD0720D5434027F56569A7A247401344DD0720D543405AF44E05DCA147409B711AA20AD343405AF44E05DCA14740
55316	378	39.662785	39.750712	47.243774999999999	47.226925000000001	Текучева	0103000020E61000000100000005000000C2A38D23D6D4434089D2DEE00B9D4740C2A38D23D6D443408C4AEA04349F47407D5BB05417E043408C4AEA04349F47407D5BB05417E0434089D2DEE00B9D4740C2A38D23D6D4434089D2DEE00B9D4740
3153	378	39.732852999999999	39.744846000000003	47.243689000000003	47.224079000000003	Театральный проспект	0103000020E6100000010000000500000043E38920CEDD4340365CE49EAE9C474043E38920CEDD43408EB27E33319F474039471D1D57DF43408EB27E33319F474039471D1D57DF4340365CE49EAE9C474043E38920CEDD4340365CE49EAE9C4740
55365	378	39.621256000000002	39.681497	47.265891000000003	47.256839999999997	Таганрогская	0103000020E61000000100000005000000CE380D5185CF4340FE261422E0A04740CE380D5185CF43407FA65EB708A247403BA92F4B3BD743407FA65EB708A247403BA92F4B3BD74340FE261422E0A04740CE380D5185CF4340FE261422E0A04740
55439	378	39.715308999999998	39.740443999999997	47.227952999999999	47.222929000000001	Суворова	0103000020E6100000010000000500000069C4CC3E8FDB43403D2AFEEF889C474069C4CC3E8FDB434036035C902D9D47407C4276DEC6DE434036035C902D9D47407C4276DEC6DE43403D2AFEEF889C474069C4CC3E8FDB43403D2AFEEF889C4740
55460	378	39.771903000000002	39.774715	47.259946999999997	47.258938000000001	Студенческая	0103000020E610000001000000050000009757AEB7CDE2434088D860E124A147409757AEB7CDE24340BED87BF145A147403E5C72DC29E34340BED87BF145A147403E5C72DC29E3434088D860E124A147409757AEB7CDE2434088D860E124A14740
6312	378	39.61318	39.699688000000002	47.215505	47.210932	Стачки проспект	0103000020E61000000100000005000000D847A7AE7CCE434006D7DCD1FF9A4740D847A7AE7CCE4340EF8FF7AA959B4740ABB35A608FD94340EF8FF7AA959B4740ABB35A608FD9434006D7DCD1FF9A4740D847A7AE7CCE434006D7DCD1FF9A4740
4814	378	39.679322999999997	39.685476000000001	47.219360999999999	47.214348000000001	Ставского проспект	0103000020E61000000100000005000000D6355A0EF4D6434044FB58C16F9B4740D6355A0EF4D6434049827005149C4740B11875ADBDD7434049827005149C4740B11875ADBDD7434044FB58C16F9B4740D6355A0EF4D6434044FB58C16F9B4740
55409	378	39.698312999999999	39.743524999999998	47.226460000000003	47.216881999999998	Социалистическая	0103000020E6100000010000000500000092AF045262D94340A88B14CAC29B474092AF045262D9434014ED2AA4FC9C47401361C3D32BDF434014ED2AA4FC9C47401361C3D32BDF4340A88B14CAC29B474092AF045262D94340A88B14CAC29B4740
55407	378	39.787129999999998	39.824283999999999	47.231006000000001	47.226441000000001	Солидарности	0103000020E61000000100000005000000A9D903ADC0E443409DBCC804FC9C4740A9D903ADC0E443400397C79A919D4740DB4E5B2382E943400397C79A919D4740DB4E5B2382E943409DBCC804FC9C4740A9D903ADC0E443409DBCC804FC9C4740
5179	378	39.715426000000001	39.723672999999998	47.236365999999997	47.217635000000001	Соколова проспект	0103000020E61000000100000005000000A35A441493DB434084BBB376DB9B4740A35A441493DB434073F1B73D419E4740C5FF1D51A1DC434073F1B73D419E4740C5FF1D51A1DC434084BBB376DB9B4740A35A441493DB434084BBB376DB9B4740
55421	378	39.633383000000002	39.63738	47.232505000000003	47.215040000000002	Содружества	0103000020E61000000100000005000000D36BB3B112D143407AAA436E869B4740D36BB3B112D1434008944DB9C29D4740EF8FF7AA95D1434008944DB9C29D4740EF8FF7AA95D143407AAA436E869B4740D36BB3B112D143407AAA436E869B4740
55471	378	39.548743999999999	39.575189999999999	47.233508999999998	47.216808	Совхозная	0103000020E6100000010000000500000028F04E3E3DC643406EC1525DC09B474028F04E3E3DC643402C29779FE39D47403D7E6FD39FC943402C29779FE39D47403D7E6FD39FC943406EC1525DC09B474028F04E3E3DC643406EC1525DC09B4740
55322	378	39.749336999999997	39.762048999999998	47.230431000000003	47.228039000000003	Советская	0103000020E6100000010000000500000064575A46EADF4340359BC761309D474064575A46EADF4340077E54C37E9D4740897956D28AE14340077E54C37E9D4740897956D28AE14340359BC761309D474064575A46EADF4340359BC761309D4740
5591	378	39.701833999999998	39.713450000000002	47.240667000000002	47.213779000000002	Соборный переулок	0103000020E61000000100000005000000459C4EB2D5D943402AC93A1C5D9B4740459C4EB2D5D94340FC1C1F2DCE9E474065AA605452DB4340FC1C1F2DCE9E474065AA605452DB43402AC93A1C5D9B4740459C4EB2D5D943402AC93A1C5D9B4740
55404	378	39.765659999999997	39.770574000000003	47.254834000000002	47.253445999999997	Сержантова	0103000020E610000001000000050000007CED992501E24340A8A624EB70A047407CED992501E2434056F487669EA04740EF92382BA2E2434056F487669EA04740EF92382BA2E24340A8A624EB70A047407CED992501E24340A8A624EB70A04740
55419	378	39.699354999999997	39.719531000000003	47.220744000000003	47.216569999999997	Серафимовича	0103000020E61000000100000005000000A4A5F27684D94340B9A5D590B89B4740A4A5F27684D94340E564E256419C4740A6BA809719DC4340E564E256419C4740A6BA809719DC4340B9A5D590B89B4740A4A5F27684D94340B9A5D590B89B4740
5556	378	39.706136999999998	39.716189999999997	47.237076000000002	47.214163999999997	Семашко переулок	0103000020E610000001000000050000006EBF7CB262DA434082FDD7B9699B47406EBF7CB262DA43405055A181589E474072DC291DACDB43405055A181589E474072DC291DACDB434082FDD7B9699B47406EBF7CB262DA434082FDD7B9699B4740
55383	378	39.764347999999998	39.775182000000001	47.251151999999998	47.247776000000002	Селиванова	0103000020E61000000100000005000000AA61BF27D6E14340EA5DBC1FB79F4740AA61BF27D6E143409929ADBF25A047405439ED2939E343409929ADBF25A047405439ED2939E34340EA5DBC1FB79F4740AA61BF27D6E14340EA5DBC1FB79F4740
3348	378	39.762740000000001	39.766612000000002	47.229489000000001	47.228729999999999	Свободы площадь	0103000020E61000000100000005000000EFACDD76A1E143409ACE4E06479D4740EFACDD76A1E1434058E542E55F9D47404F5C8E5720E2434058E542E55F9D47404F5C8E5720E243409ACE4E06479D4740EFACDD76A1E143409ACE4E06479D4740
55469	378	39.767259000000003	39.782359	47.230638999999996	47.227964999999998	Сарьяна	0103000020E61000000100000005000000E547FC8A35E24340FAD005F52D9D4740E547FC8A35E2434050172994859D47409A5DF75624E4434050172994859D47409A5DF75624E44340FAD005F52D9D4740E547FC8A35E24340FAD005F52D9D4740
55308	378	39.761023999999999	39.764519	47.285179999999997	47.284880000000001	Ректорская	0103000020E610000001000000050000004DBC033C69E143406AA4A5F276A447404DBC033C69E1434094BC3AC780A44740D71533C2DBE1434094BC3AC780A44740D71533C2DBE143406AA4A5F276A447404DBC033C69E143406AA4A5F276A44740
3571	378	39.804026999999998	39.804259999999999	47.23554	47.225498999999999	Расковой переулок	0103000020E61000000100000005000000ED0C535BEAE64340EE23B726DD9C4740ED0C535BEAE643402E73BA2C269E474090BDDEFDF1E643402E73BA2C269E474090BDDEFDF1E64340EE23B726DD9C4740ED0C535BEAE64340EE23B726DD9C4740
4914	378	39.662371999999998	39.665560999999997	47.216110999999998	47.213791000000001	Рабочая площадь	0103000020E610000001000000050000009FE40E9BC8D44340EE96E4805D9B47409FE40E9BC8D4434026A77686A99B47401C3F541A31D5434026A77686A99B47401C3F541A31D54340EE96E4805D9B47409FE40E9BC8D44340EE96E4805D9B4740
55466	378	39.697082000000002	39.741135999999997	47.230792000000001	47.221356	Пушкинская	0103000020E61000000100000005000000AD50A4FB39D94340FE62B664559C4740AD50A4FB39D94340D7169E978A9D4740B2F1608BDDDE4340D7169E978A9D4740B2F1608BDDDE4340FE62B664559C4740AD50A4FB39D94340FE62B664559C4740
55356	378	39.653801999999999	39.692169	47.223106000000001	47.213056000000002	Профсоюзная	0103000020E610000001000000050000009A07B0C8AFD34340B91B446B459B47409A07B0C8AFD343404CC5C6BC8E9C47400B2769FE98D843404CC5C6BC8E9C47400B2769FE98D84340B91B446B459B47409A07B0C8AFD34340B91B446B459B4740
5077	378	39.621758999999997	39.625917999999999	47.197752000000001	47.189931999999999	Пржевальского переулок	0103000020E61000000100000005000000307F85CC95CF4340603B18B14F984740307F85CC95CF4340FB5B02F04F99474026FDBD141ED04340FB5B02F04F99474026FDBD141ED04340603B18B14F984740307F85CC95CF4340603B18B14F984740
55384	378	39.627741	39.696911999999998	47.214128000000002	47.189864999999998	Портовая	0103000020E61000000100000005000000DEAD2CD159D04340D8D30E7F4D984740DEAD2CD159D043403694DA8B689B47405018946934D943403694DA8B689B47405018946934D94340D8D30E7F4D984740DEAD2CD159D04340D8D30E7F4D984740
55431	378	39.776519999999998	39.786797	47.259793999999999	47.248981000000001	Полторацкого	0103000020E610000001000000050000004F58E20165E34340A629029CDE9F47404F58E20165E3434038D906EE40A14740A3CB9BC3B5E4434038D906EE40A14740A3CB9BC3B5E44340A629029CDE9F47404F58E20165E34340A629029CDE9F4740
55374	378	39.632376999999998	39.641216	47.235816	47.215902999999997	Петрозаводская	0103000020E610000001000000050000000DDFC2BAF1D04340DC0DA2B5A29B47400DDFC2BAF1D04340D0EFFB372F9E474002D6AA5D13D24340D0EFFB372F9E474002D6AA5D13D24340DC0DA2B5A29B47400DDFC2BAF1D04340DC0DA2B5A29B4740
6041	378	39.692608999999997	39.700172999999999	47.255598999999997	47.252443	Педагогический переулок	0103000020E6100000010000000500000027F56569A7D84340548D5E0D50A0474027F56569A7D84340F5F1D077B7A047406745D4449FD94340F5F1D077B7A047406745D4449FD94340548D5E0D50A0474027F56569A7D84340548D5E0D50A04740
55430	378	39.700541000000001	39.704825999999997	47.286279999999998	47.278993	Пацаева	0103000020E61000000100000005000000EA40D653ABD943400E68E90AB6A34740EA40D653ABD94340DBBFB2D2A4A447406CAF05BD37DA4340DBBFB2D2A4A447406CAF05BD37DA43400E68E90AB6A34740EA40D653ABD943400E68E90AB6A34740
107	378	39.697935999999999	39.707017999999998	47.235154999999999	47.213025999999999	Островского переулок	0103000020E61000000100000005000000BC5983F755D943404E999B6F449B4740BC5983F755D94340D53E1D8F199E474077D7D9907FDA4340D53E1D8F199E474077D7D9907FDA43404E999B6F449B4740BC5983F755D943404E999B6F449B4740
1919	378	39.710000000000001	39.715381000000001	47.271363000000001	47.257542999999998	Оренбургский переулок	0103000020E610000001000000050000007B14AE47E1DA43402828452BF7A047407B14AE47E1DA4340172CD505BCA247400397C79A91DB4340172CD505BCA247400397C79A91DB43402828452BF7A047407B14AE47E1DA43402828452BF7A04740
55429	378	39.710000000000001	39.715381000000001	47.271363000000001	47.257542999999998	Оренбургский	0103000020E610000001000000050000007B14AE47E1DA43402828452BF7A047407B14AE47E1DA4340172CD505BCA247400397C79A91DB4340172CD505BCA247400397C79A91DB43402828452BF7A047407B14AE47E1DA43402828452BF7A04740
55347	378	39.677633999999998	39.738287999999997	47.303092999999997	47.296481	Орбитальная	0103000020E610000001000000050000002E54FEB5BCD643405471E316F3A547402E54FEB5BCD64340C1525DC0CBA64740BE839F3880DE4340C1525DC0CBA64740BE839F3880DE43405471E316F3A547402E54FEB5BCD643405471E316F3A54740
1817	378	39.719701999999998	39.719855000000003	47.246918999999998	47.244667999999997	Обуховский переулок	0103000020E61000000100000005000000D26EF4311FDC43405930F147519F4740D26EF4311FDC434069E1B20A9B9F4740596E693524DC434069E1B20A9B9F4740596E693524DC43405930F147519F4740D26EF4311FDC43405930F147519F4740
2461	378	39.740651	39.746858000000003	47.285179999999997	47.273882	Обский переулок	0103000020E61000000100000005000000F65FE7A6CDDE4340467BBC900EA34740F65FE7A6CDDE434094BC3AC780A44740C460FE0A99DF434094BC3AC780A44740C460FE0A99DF4340467BBC900EA34740F65FE7A6CDDE4340467BBC900EA34740
55333	378	39.701763	39.720196000000001	47.218651000000001	47.214886999999997	Обороны	0103000020E610000001000000050000007C45B75ED3D94340F3AACE6A819B47407C45B75ED3D943406D1E87C1FC9B4740E25AED612FDC43406D1E87C1FC9B4740E25AED612FDC4340F3AACE6A819B47407C45B75ED3D94340F3AACE6A819B4740
55327	378	39.661239999999999	39.668596999999998	47.224575000000002	47.222109000000003	Некрасовская	0103000020E610000001000000050000004D672783A3D44340DA9255116E9C47404D672783A3D44340E63FA4DFBE9C4740139A249694D54340E63FA4DFBE9C4740139A249694D54340DA9255116E9C47404D672783A3D44340DA9255116E9C4740
55385	378	39.688180000000003	39.697620999999998	47.284568	47.279519000000001	Неклиновская	0103000020E6100000010000000500000072E1404816D8434029CE5147C7A3474072E1404816D843407BBE66B96CA447405C001AA54BD943407BBE66B96CA447405C001AA54BD9434029CE5147C7A3474072E1404816D8434029CE5147C7A34740
6059	378	39.696129999999997	39.697567999999997	47.251292999999997	47.249775999999997	Народного Ополчения площадь	0103000020E61000000100000005000000DAE1AFC91AD94340B0A9F3A8F89F4740DAE1AFC91AD943405B5B785E2AA04740395E81E849D943405B5B785E2AA04740395E81E849D94340B0A9F3A8F89F4740DAE1AFC91AD94340B0A9F3A8F89F4740
55331	378	39.750236000000001	39.767259000000003	47.227964999999998	47.224789000000001	Мясникова	0103000020E610000001000000050000001424B6BB07E0434012C0CDE2C59C47401424B6BB07E04340FAD005F52D9D4740E547FC8A35E24340FAD005F52D9D4740E547FC8A35E2434012C0CDE2C59C47401424B6BB07E0434012C0CDE2C59C4740
55299	378	39.699660999999999	39.719971000000001	47.219715999999998	47.215505	Московская	0103000020E61000000100000005000000B1A4DC7D8ED94340EF8FF7AA959B4740B1A4DC7D8ED94340373465A71F9C4740C2887D0228DC4340373465A71F9C4740C2887D0228DC4340EF8FF7AA959B4740B1A4DC7D8ED94340EF8FF7AA959B4740
1909	378	39.712640999999998	39.721893999999999	47.267291	47.236469999999997	Михаила Нагибина проспект	0103000020E61000000100000005000000F564FED137DB4340183E22A6449E4740F564FED137DB4340F0C16B9736A24740DD96C80567DC4340F0C16B9736A24740DD96C80567DC4340183E22A6449E4740F564FED137DB4340183E22A6449E4740
55381	378	39.741261999999999	39.754440000000002	47.301907	47.295814999999997	Миронова	0103000020E610000001000000050000003FE257ACE1DE434047551344DDA547403FE257ACE1DE43407CB779E3A4A64740AA656B7D91E043407CB779E3A4A64740AA656B7D91E0434047551344DDA547403FE257ACE1DE434047551344DDA54740
197	378	39.770609999999998	39.771417999999997	47.251573999999998	47.251299000000003	Мира площадь	0103000020E610000001000000050000003BFC3559A3E243403E42CD902AA047403BFC3559A3E243400F43AB9333A04740DAC534D3BDE243400F43AB9333A04740DAC534D3BDE243403E42CD902AA047403BFC3559A3E243403E42CD902AA04740
55462	378	39.770609999999998	39.771417999999997	47.251573999999998	47.251299000000003	Мира	0103000020E610000001000000050000003BFC3559A3E243403E42CD902AA047403BFC3559A3E243400F43AB9333A04740DAC534D3BDE243400F43AB9333A04740DAC534D3BDE243403E42CD902AA047403BFC3559A3E243403E42CD902AA04740
55463	378	39.668534000000001	39.684955000000002	47.222653000000001	47.220713000000003	Минераловодская	0103000020E61000000100000005000000CD21A98592D54340AA66D652409C4740CD21A98592D543409BADBCE47F9C4740A81DFE9AACD743409BADBCE47F9C4740A81DFE9AACD74340AA66D652409C4740CD21A98592D54340AA66D652409C4740
55357	378	39.672288999999999	39.711312	47.241768	47.236507000000003	Мечникова	0103000020E61000000100000005000000F33AE2900DD64340362383DC459E4740F33AE2900DD64340139CFA40F29E47404DA088450CDB4340139CFA40F29E47404DA088450CDB4340362383DC459E4740F33AE2900DD64340362383DC459E4740
55389	378	39.681398000000002	39.736922999999997	47.237381999999997	47.225847999999999	Малюгиной	0103000020E61000000100000005000000A8C7B60C38D74340FAEE5696E89C4740A8C7B60C38D743405C548B88629E4740C9552C7E53DE43405C548B88629E4740C9552C7E53DE4340FAEE5696E89C4740A8C7B60C38D74340FAEE5696E89C4740
55392	378	39.613152999999997	39.620851000000002	47.260063000000002	47.194256000000003	Малиновского	0103000020E61000000100000005000000DE3829CC7BCE4340A1866F61DD984740DE3829CC7BCE434028F38FBE49A147402E58AA0B78CF434028F38FBE49A147402E58AA0B78CF4340A1866F61DD984740DE3829CC7BCE4340A1866F61DD984740
55408	378	39.694764999999997	39.74295	47.232664	47.221691999999997	Максима Горького	0103000020E61000000100000005000000E5B33C0FEED8434075E44867609C4740E5B33C0FEED84340707A17EFC79D4740174850FC18DF4340707A17EFC79D4740174850FC18DF434075E44867609C4740E5B33C0FEED8434075E44867609C4740
55332	378	39.625954	39.662649999999999	47.245806000000002	47.216042999999999	Мадояна	0103000020E610000001000000050000007366BB421FD04340CEC3094CA79B47407366BB421FD043408E942D92769F4740E25817B7D1D443408E942D92769F4740E25817B7D1D44340CEC3094CA79B47407366BB421FD04340CEC3094CA79B4740
55470	378	39.67051	39.674588999999997	47.211036	47.203530999999998	Литвинова	0103000020E610000001000000050000000BD28C45D3D54340705CC64D0D9A47400BD28C45D3D54340AB23473A039B4740E49EAEEE58D64340AB23473A039B4740E49EAEEE58D64340705CC64D0D9A47400BD28C45D3D54340705CC64D0D9A4740
55323	378	39.749606999999997	39.768569999999997	47.224716000000001	47.220964000000002	Листопадова	0103000020E6100000010000000500000024ED461FF3DF4340F3CB608C489C474024ED461FF3DF4340A8716F7EC39C4740E657738060E24340A8716F7EC39C4740E657738060E24340F3CB608C489C474024ED461FF3DF4340F3CB608C489C4740
55475	378	39.690596999999997	39.735323999999999	47.235461000000001	47.226171999999998	Лермонтовская	0103000020E610000001000000050000009CDB847B65D84340ADA23F34F39C47409CDB847B65D84340E23D0796239E474061FBC9181FDE4340E23D0796239E474061FBC9181FDE4340ADA23F34F39C47409CDB847B65D84340ADA23F34F39C4740
55447	378	39.701664000000001	39.707081000000002	47.242466	47.242282000000003	Лениногорская	0103000020E61000000100000005000000E9633E20D0D943406A34B918039F4740E9633E20D0D943402B323A20099F4740BE4F55A181DA43402B323A20099F4740BE4F55A181DA43406A34B918039F4740E9633E20D0D943406A34B918039F4740
55474	378	39.678621999999997	39.756174000000001	47.250644000000001	47.248987	Ленина проспект	0103000020E610000001000000050000004D2CF015DDD64340881057CEDE9F47404D2CF015DDD643402578431A15A04740F20A444FCAE043402578431A15A04740F20A444FCAE04340881057CEDE9F47404D2CF015DDD64340881057CEDE9F4740
40631	378	39.678621999999997	39.756174000000001	47.250644000000001	47.248987	Ленина проспект	0103000020E610000001000000050000004D2CF015DDD64340881057CEDE9F47404D2CF015DDD643402578431A15A04740F20A444FCAE043402578431A15A04740F20A444FCAE04340881057CEDE9F47404D2CF015DDD64340881057CEDE9F4740
5969	378	39.678621999999997	39.756174000000001	47.250644000000001	47.248987	Ленина проспект	0103000020E610000001000000050000004D2CF015DDD64340881057CEDE9F47404D2CF015DDD643402578431A15A04740F20A444FCAE043402578431A15A04740F20A444FCAE04340881057CEDE9F47404D2CF015DDD64340881057CEDE9F4740
55355	378	39.733671000000001	39.753163999999998	47.301271999999997	47.291488000000001	Лелюшенко	0103000020E6100000010000000500000006836BEEE8DD43409696917A4FA5474006836BEEE8DD4340AA99B51490A6474024438EAD67E04340AA99B51490A6474024438EAD67E043409696917A4FA5474006836BEEE8DD43409696917A4FA54740
55412	378	39.697198999999998	39.716217	47.257556000000001	47.251482000000003	Ларина	0103000020E61000000100000005000000E6E61BD13DD943402FC4EA8F30A04740E6E61BD13DD94340BD715298F7A047406CEBA7FFACDB4340BD715298F7A047406CEBA7FFACDB43402FC4EA8F30A04740E6E61BD13DD943402FC4EA8F30A04740
55461	378	39.772064999999998	39.787362999999999	47.267480999999997	47.262644000000002	Курчатова	0103000020E6100000010000000500000070B1A206D3E24340CD3E8F519EA1474070B1A206D3E2434093A641D13CA247404C8A8F4FC8E4434093A641D13CA247404C8A8F4FC8E44340CD3E8F519EA1474070B1A206D3E24340CD3E8F519EA14740
56146	378	39.544809000000001	39.594369	47.183723000000001	47.167636999999999	Кумженская	0103000020E6100000010000000500000082C8224DBCC54340BE4C14217595474082C8224DBCC54340F2423A3C84974740CC608C4814CC4340F2423A3C84974740CC608C4814CC4340BE4C14217595474082C8224DBCC54340BE4C142175954740
55396	378	39.689698	39.694018999999997	47.257469999999998	47.251654000000002	Кропоткина	0103000020E61000000100000005000000ED0E290648D843402CF4C13236A04740ED0E290648D84340BED9E6C6F4A04740BCE6559DD5D84340BED9E6C6F4A04740BCE6559DD5D843402CF4C13236A04740ED0E290648D843402CF4C13236A04740
55348	378	39.644449999999999	39.646498000000001	47.262411	47.258631999999999	Кривоноса	0103000020E610000001000000050000001FF46C567DD243407BD976DA1AA147401FF46C567DD243402A8E03AF96A14740F7764B72C0D243402A8E03AF96A14740F7764B72C0D243407BD976DA1AA147401FF46C567DD243407BD976DA1AA14740
5438	378	39.729799	39.738827000000001	47.241878	47.220467999999997	Крепостной переулок	0103000020E61000000100000005000000A6D3BA0D6ADD434042E8A04B389C4740A6D3BA0D6ADD43409ACFB9DBF59E47406E3315E291DE43409ACFB9DBF59E47406E3315E291DE434042E8A04B389C4740A6D3BA0D6ADD434042E8A04B389C4740
6520	378	39.607170000000004	39.612219000000003	47.198070000000001	47.194231000000002	Красноярский переулок	0103000020E61000000100000005000000618E1EBFB7CD4340486FB88FDC984740618E1EBFB7CD4340CC28965B5A994740B37E33315DCE4340CC28965B5A994740B37E33315DCE4340486FB88FDC984740618E1EBFB7CD4340486FB88FDC984740
55411	378	39.690390000000001	39.739275999999997	47.233685999999999	47.220646000000002	Красноармейская	0103000020E6100000010000000500000023BE13B35ED8434022FFCC203E9C474023BE13B35ED843403BC43F6CE99D4740DD5B9198A0DE43403BC43F6CE99D4740DD5B9198A0DE434022FFCC203E9C474023BE13B35ED8434022FFCC203E9C4740
55417	378	39.825937000000003	39.835836	47.237448999999998	47.233490000000003	Краеведческая	0103000020E6100000010000000500000037C7B94DB8E94340B6F81400E39D474037C7B94DB8E94340E4BB94BA649E4740E4688EACFCEA4340E4BB94BA649E4740E4688EACFCEA4340B6F81400E39D474037C7B94DB8E94340B6F81400E39D4740
55400	378	39.711734	39.719656999999998	47.300294000000001	47.273325999999997	Космонавтов проспект	0103000020E61000000100000005000000C3B986191ADB4340C092AB58FCA24740C3B986191ADB4340AF97A60870A6474032AB77B81DDC4340AF97A60870A6474032AB77B81DDC4340C092AB58FCA24740C3B986191ADB4340C092AB58FCA24740
2213	378	39.715677999999997	39.715902	47.283731000000003	47.283456000000001	Космонавтов площадь	0103000020E61000000100000005000000BC3B32569BDB434070ED444948A44740BC3B32569BDB434042EE224C51A447400C923EADA2DB434042EE224C51A447400C923EADA2DB434070ED444948A44740BC3B32569BDB434070ED444948A44740
55351	378	39.715677999999997	39.715902	47.283731000000003	47.283456000000001	Космонавтов	0103000020E61000000100000005000000BC3B32569BDB434070ED444948A44740BC3B32569BDB434042EE224C51A447400C923EADA2DB434042EE224C51A447400C923EADA2DB434070ED444948A44740BC3B32569BDB434070ED444948A44740
2118	378	39.683590000000002	39.720367000000003	47.296224000000002	47.281781000000002	Королева проспект	0103000020E61000000100000005000000B3EF8AE07FD743402DD1596611A44740B3EF8AE07FD74340292504ABEAA547400F0F61FC34DC4340292504ABEAA547400F0F61FC34DC43402DD1596611A44740B3EF8AE07FD743402DD1596611A44740
55465	378	39.766612000000002	39.782170999999998	47.232137999999999	47.229489000000001	Комсомольская	0103000020E610000001000000050000004F5C8E5720E2434058E542E55F9D47404F5C8E5720E243405514AFB2B69D47409770E82D1EE443405514AFB2B69D47409770E82D1EE4434058E542E55F9D47404F5C8E5720E2434058E542E55F9D4740
6286	378	39.613439999999997	39.646292000000003	47.209144999999999	47.207731000000003	Коммунистический проспект	0103000020E610000001000000050000007407B13385CE4340C5AEEDED969A47407407B13385CE43409B8F6B43C59A47404ED53DB2B9D243409B8F6B43C59A47404ED53DB2B9D24340C5AEEDED969A47407407B13385CE4340C5AEEDED969A4740
55416	378	39.767771000000003	39.778694000000002	47.247762999999999	47.241677000000003	Коммунаров	0103000020E610000001000000050000009BE8F35146E2434003999D45EF9E47409BE8F35146E243405514AFB2B69F4740B4CBB73EACE343405514AFB2B69F4740B4CBB73EACE3434003999D45EF9E47409BE8F35146E2434003999D45EF9E4740
2017	378	39.68721	39.721310000000003	47.292068	47.286279999999998	Комарова бульвар	0103000020E61000000100000005000000F9BD4D7FF6D74340DBBFB2D2A4A44740F9BD4D7FF6D74340A41AF67B62A547408E23D6E253DC4340A41AF67B62A547408E23D6E253DC4340DBBFB2D2A4A44740F9BD4D7FF6D74340DBBFB2D2A4A44740
55435	378	39.748896999999999	39.761958999999997	47.275992000000002	47.271889000000002	Киргизская	0103000020E6100000010000000500000048895DDBDBDF434032923D42CDA2474048895DDBDBDF434094FAB2B453A3474049F25CDF87E1434094FAB2B453A3474049F25CDF87E1434032923D42CDA2474048895DDBDBDF434032923D42CDA24740
55420	378	39.613377	39.625118000000001	47.198994999999996	47.197752000000001	Каширская	0103000020E610000001000000050000002E8F352383CE4340FB5B02F04F9947402E8F352383CE4340A4880CAB789947400A12DBDD03D04340A4880CAB789947400A12DBDD03D04340FB5B02F04F9947402E8F352383CE4340FB5B02F04F994740
55391	378	39.621893	39.638620000000003	47.237253000000003	47.233142000000001	Калининградская	0103000020E61000000100000005000000404E98309ACF43407AA9D898D79D4740404E98309ACF43405FF0694E5E9E47402849D74CBED143405FF0694E5E9E47402849D74CBED143407AA9D898D79D4740404E98309ACF43407AA9D898D79D4740
55353	378	39.730139999999999	39.754035999999999	47.288699999999999	47.271448999999997	Казахская	0103000020E610000001000000050000002FC03E3A75DD434015C440D7BEA247402FC03E3A75DD4340772D211FF4A44740DA006C4084E04340772D211FF4A44740DA006C4084E0434015C440D7BEA247402FC03E3A75DD434015C440D7BEA24740
55467	378	39.628917999999999	39.634990999999999	47.232419999999998	47.208067999999997	Зорге	0103000020E61000000100000005000000D0EE906280D043400CACE3F8A19A4740D0EE906280D04340D97745F0BF9D47408E20956247D14340D97745F0BF9D47408E20956247D143400CACE3F8A19A4740D0EE906280D043400CACE3F8A19A4740
55427	378	39.804242000000002	39.815759	47.272629000000002	47.266362000000001	Зои Космодемьянской	0103000020E61000000100000005000000EA08E066F1E64340D672672618A24740EA08E066F1E643407978CF81E5A24740763579CA6AE843407978CF81E5A24740763579CA6AE84340D672672618A24740EA08E066F1E64340D672672618A24740
5263	378	39.727983999999999	39.736330000000002	47.240551000000004	47.219948000000002	Журавлева переулок	0103000020E61000000100000005000000710168942EDD43400A698D41279C4740710168942EDD434093020B60CA9E47402788BA0F40DE434093020B60CA9E47402788BA0F40DE43400A698D41279C4740710168942EDD43400A698D41279C4740
55362	378	39.606191000000003	39.642733999999997	47.235363	47.232290999999996	Еременко	0103000020E610000001000000050000009510ACAA97CD4340DB1324B6BB9D47409510ACAA97CD43401FD8F15F209E47407D03931B45D243401FD8F15F209E47407D03931B45D24340DB1324B6BB9D47409510ACAA97CD4340DB1324B6BB9D4740
5734	378	39.689528000000003	39.699786000000003	47.239156000000001	47.215505	Доломановский переулок	0103000020E6100000010000000500000091D6187442D84340EF8FF7AA959B474091D6187442D843403352EFA99C9E47406E19709692D943403352EFA99C9E47406E19709692D94340EF8FF7AA959B474091D6187442D84340EF8FF7AA959B4740
2488	378	39.752085999999998	39.757233999999997	47.289335999999999	47.271729999999998	Днепровский переулок	0103000020E61000000100000005000000C5E3A25A44E04340C9AB730CC8A24740C5E3A25A44E0434019C748F608A54740AAB5300BEDE0434019C748F608A54740AAB5300BEDE04340C9AB730CC8A24740C5E3A25A44E04340C9AB730CC8A24740
3463	378	39.778092000000001	39.786239999999999	47.246398999999997	47.245762999999997	Дзержинского переулок	0103000020E61000000100000005000000BEA3C68498E343408EC87729759F4740BEA3C68498E3434030629F008A9F47404D672783A3E4434030629F008A9F47404D672783A3E443408EC87729759F4740BEA3C68498E343408EC87729759F4740
5033	378	39.682467000000003	39.686967000000003	47.205900999999997	47.202612999999999	Деревянко переулок	0103000020E61000000100000005000000B4CC22145BD743404A5F0839EF994740B4CC22145BD743405A9BC6F65A9A47403337DF88EED743405A9BC6F65A9A47403337DF88EED743404A5F0839EF994740B4CC22145BD743404A5F0839EF994740
55444	378	39.668228999999997	39.685476000000001	47.222109000000003	47.219360999999999	Гусева	0103000020E61000000100000005000000909E228788D5434049827005149C4740909E228788D54340DA9255116E9C4740B11875ADBDD74340DA9255116E9C4740B11875ADBDD7434049827005149C4740909E228788D5434049827005149C4740
6130	378	39.670096999999998	39.674750000000003	47.271191999999999	47.260240000000003	Госпитальный переулок	0103000020E61000000100000005000000E8120EBDC5D54340378E588B4FA14740E8120EBDC5D54340EA77616BB6A24740EE7C3F355ED64340EA77616BB6A24740EE7C3F355ED64340378E588B4FA14740E8120EBDC5D54340378E588B4FA14740
55437	378	39.774588999999999	39.778506	47.247414999999997	47.236384999999999	Горсоветская	0103000020E61000000100000005000000B16B7BBB25E34340EA211ADD419E4740B16B7BBB25E3434019C5724BAB9F4740B1DEA815A6E3434019C5724BAB9F4740B1DEA815A6E34340EA211ADD419E4740B16B7BBB25E34340EA211ADD419E4740
55324	378	39.787497999999999	39.837687000000003	47.236317	47.225028000000002	Герцена	0103000020E610000001000000050000002CD505BCCCE443409757AEB7CD9C47402CD505BCCCE44340923EADA23F9E474066A4DE5339EB4340923EADA23F9E474066A4DE5339EB43409757AEB7CD9C47402CD505BCCCE443409757AEB7CD9C4740
5719	378	39.687632000000001	39.694018999999997	47.235534000000001	47.223449000000002	Гвардейский переулок	0103000020E610000001000000050000006FD74B5304D8434076A911FA999C47406FD74B5304D843404C8C65FA259E4740BCE6559DD5D843404C8C65FA259E4740BCE6559DD5D8434076A911FA999C47406FD74B5304D8434076A911FA999C4740
5895	378	39.712713000000001	39.715730999999998	47.236794000000003	47.23554	Гагарина площадь	0103000020E610000001000000050000008F37F92D3ADB43402E73BA2C269E47408F37F92D3ADB4340CCF10A444F9E4740DFDDCA129DDB4340CCF10A444F9E4740DFDDCA129DDB43402E73BA2C269E47408F37F92D3ADB43402E73BA2C269E4740
55366	378	39.733482000000002	39.782924999999999	47.287680000000002	47.276958	Вятская	0103000020E61000000100000005000000331AF9BCE2DD4340CB2E185C73A34740331AF9BCE2DD43404DDBBFB2D2A44740431CEBE236E443404DDBBFB2D2A44740431CEBE236E44340CB2E185C73A34740331AF9BCE2DD4340CB2E185C73A34740
55291	378	39.611617000000003	39.642600000000002	47.194256000000003	47.188437999999998	Всесоюзная	0103000020E61000000100000005000000BD56427749CE43406DA983BC1E984740BD56427749CE4340A1866F61DD9847406E3480B740D24340A1866F61DD9847406E3480B740D243406DA983BC1E984740BD56427749CE43406DA983BC1E984740
5129	378	39.712857	39.723734999999998	47.235638000000002	47.211404000000002	Ворошиловский проспект	0103000020E61000000100000005000000C2DCEEE53EDB43402E1F49490F9B4740C2DCEEE53EDB4340F1D8CF62299E47403BFC3559A3DC4340F1D8CF62299E47403BFC3559A3DC43402E1F49490F9B4740C2DCEEE53EDB43402E1F49490F9B4740
55349	378	39.708823000000002	39.724176	47.286824000000003	47.282594000000003	Волкова	0103000020E6100000010000000500000089D349B6BADA4340DE054A0A2CA4474089D349B6BADA43409DDA19A6B6A44740284696CCB1DC43409DDA19A6B6A44740284696CCB1DC4340DE054A0A2CA4474089D349B6BADA4340DE054A0A2CA44740
55450	378	39.63747	39.663682999999999	47.198504999999997	47.190465000000003	Войкова	0103000020E610000001000000050000002F17F19D98D143402E043928619847402F17F19D98D14340D68BA19C68994740A1F48590F3D44340D68BA19C68994740A1F48590F3D443402E043928619847402F17F19D98D143402E04392861984740
55438	378	39.674984000000002	39.679862	47.216189999999997	47.215242000000003	Верещагина	0103000020E6100000010000000500000061A92EE065D64340E25CC30C8D9B474061A92EE065D6434072DC291DAC9B474086E5CFB705D7434072DC291DAC9B474086E5CFB705D74340E25CC30C8D9B474061A92EE065D64340E25CC30C8D9B4740
55390	378	39.678505000000001	39.738557999999998	47.238556000000003	47.225419000000002	Варфоломеева	0103000020E6100000010000000500000014967840D9D64340D272A087DA9C474014967840D9D64340DE21C500899E47407E198C1189DE4340DE21C500899E47407E198C1189DE4340D272A087DA9C474014967840D9D64340D272A087DA9C4740
55394	378	39.676304000000002	39.686689000000001	47.306294999999999	47.261225000000003	Вавилова	0103000020E61000000100000005000000B613252191D64340E5F21FD26FA14740B613252191D64340D3F6AFAC34A74740F0C2D66CE5D74340D3F6AFAC34A74740F0C2D66CE5D74340E5F21FD26FA14740B613252191D64340E5F21FD26FA14740
55202	378	39.501958999999999	39.859766999999998	47.345292999999998	47.158563999999998	В.Нольная	0103000020E610000001000000050000006877483140C0434056293DD34B9447406877483140C04340D4449F8F32AC47400B9755D80CEE4340D4449F8F32AC47400B9755D80CEE434056293DD34B9447406877483140C0434056293DD34B944740
55197	378	39.501958999999999	39.859766999999998	47.345292999999998	47.158563999999998	В.Закруткина	0103000020E610000001000000050000006877483140C0434056293DD34B9447406877483140C04340D4449F8F32AC47400B9755D80CEE4340D4449F8F32AC47400B9755D80CEE434056293DD34B9447406877483140C0434056293DD34B944740
55453	378	39.640264000000002	39.646569999999997	47.215620999999999	47.21537	Быковского	0103000020E610000001000000050000003067B62BF4D143400F45813E919B47403067B62BF4D1434058AA0B78999B4740904946CEC2D2434058AA0B78999B4740904946CEC2D243400F45813E919B47403067B62BF4D143400F45813E919B4740
55464	378	39.763179999999998	39.773529000000003	47.241101999999998	47.237882999999997	Буйнакская	0103000020E610000001000000050000000B7BDAE1AFE143401EA33CF3729E47400B7BDAE1AFE1434006802A6EDC9E4740F9C08EFF02E3434006802A6EDC9E4740F9C08EFF02E343401EA33CF3729E47400B7BDAE1AFE143401EA33CF3729E4740
5632	378	39.699525999999999	39.710439999999998	47.244698999999997	47.213594999999998	Буденновский проспект	0103000020E61000000100000005000000D15966118AD9434068CBB914579B4740D15966118AD94340942EFD4B529F474097E2AAB2EFDA4340942EFD4B529F474097E2AAB2EFDA434068CBB914579B4740D15966118AD9434068CBB914579B4740
55387	378	39.789347999999997	39.796076999999997	47.273882	47.266587999999999	Брестская	0103000020E61000000100000005000000DD94F25A09E54340C6C03A8E1FA24740DD94F25A09E54340467BBC900EA34740840CE4D9E5E54340467BBC900EA34740840CE4D9E5E54340C6C03A8E1FA24740DD94F25A09E54340C6C03A8E1FA24740
55379	378	39.704825999999997	39.707647000000001	47.282038	47.278993	Борко	0103000020E610000001000000050000006CAF05BD37DA43400E68E90AB6A347406CAF05BD37DA4340581D39D219A44740670E492D94DA4340581D39D219A44740670E492D94DA43400E68E90AB6A347406CAF05BD37DA43400E68E90AB6A34740
55422	378	39.695807000000002	39.742986000000002	47.227499999999999	47.217542999999999	Большая Садовая	0103000020E61000000100000005000000F8A92A3410D94340A33CF372D89B4740F8A92A3410D9434085EB51B81E9D474064B14D2A1ADF434085EB51B81E9D474064B14D2A1ADF4340A33CF372D89B4740F8A92A3410D94340A33CF372D89B4740
55350	378	39.722710999999997	39.723547000000003	47.301350999999997	47.297922999999997	Беляева	0103000020E61000000100000005000000CFBA46CB81DC4340F4DC425722A64740CFBA46CB81DC4340F6CE68AB92A64740390F27309DDC4340F6CE68AB92A64740390F27309DDC4340F4DC425722A64740CFBA46CB81DC4340F4DC425722A64740
2682	378	39.753064999999999	39.759281999999999	47.281891000000002	47.268318000000001	Беломорский переулок	0103000020E610000001000000050000009161156F64E04340CD76853E58A247409161156F64E04340B404190115A4474082380F2730E14340B404190115A4474082380F2730E14340CD76853E58A247409161156F64E04340CD76853E58A24740
55395	378	39.634416000000002	39.652875999999999	47.217274000000003	47.214385	Андрея Сладкова	0103000020E610000001000000050000009207228B34D1434061E0B9F7709B47409207228B34D14340B4226AA2CF9B4740F12BD67091D34340B4226AA2CF9B4740F12BD67091D3434061E0B9F7709B47409207228B34D1434061E0B9F7709B4740
55472	378	39.675020000000004	39.696966000000003	47.210822	47.197732999999999	Амбулаторная	0103000020E61000000100000005000000AE122C0E67D64340842BA0504F994740AE122C0E67D643407FA31D37FC9A47404436902E36D943407FA31D37FC9A47404436902E36D94340842BA0504F994740AE122C0E67D64340842BA0504F994740
6119	378	39.667088	39.669485999999999	47.268935999999997	47.263182	Авиамоторный переулок	0103000020E61000000100000005000000EBC6BB2363D54340AC72A1F2AFA14740EBC6BB2363D54340C85BAE7E6CA247409F909DB7B1D54340C85BAE7E6CA247409F909DB7B1D54340AC72A1F2AFA14740EBC6BB2363D54340AC72A1F2AFA14740
3229	378	39.785324000000003	39.841217	47.243695000000002	47.233471999999999	40-летия Победы проспект	0103000020E61000000100000005000000C861307F85E443400F441669E29D4740C861307F85E443407099D365319F47406CEBA7FFACEB43407099D365319F47406CEBA7FFACEB43400F441669E29D4740C861307F85E443400F441669E29D4740
55315	378	39.614275999999997	39.633383000000002	47.225878000000002	47.224930000000001	339-й Стрелковой Дивизии	0103000020E61000000100000005000000DD5B9198A0CE4340D4F19881CA9C4740DD5B9198A0CE43406571FF91E99C4740D36BB3B112D143406571FF91E99C4740D36BB3B112D14340D4F19881CA9C4740DD5B9198A0CE4340D4F19881CA9C4740
55334	378	39.614275999999997	39.633383000000002	47.225878000000002	47.224930000000001	339-й Стрелковой Дивизии	0103000020E61000000100000005000000DD5B9198A0CE4340D4F19881CA9C4740DD5B9198A0CE43406571FF91E99C4740D36BB3B112D143406571FF91E99C4740D36BB3B112D14340D4F19881CA9C4740DD5B9198A0CE4340D4F19881CA9C4740
55418	378	39.769837000000003	39.773645999999999	47.231875000000002	47.222537000000003	31-я Линия	0103000020E610000001000000050000001920D1048AE243403293A8177C9C47401920D1048AE2434048E17A14AE9D4740325706D506E3434048E17A14AE9D4740325706D506E343403293A8177C9C47401920D1048AE243403293A8177C9C4740
55329	378	39.763998000000001	39.767187	47.239449999999998	47.231386000000001	28-я линия	0103000020E61000000100000005000000CE1ABCAFCAE143404A60730E9E9D4740CE1ABCAFCAE143407B832F4CA69E47404B75012F33E243407B832F4CA69E47404B75012F33E243404A60730E9E9D4740CE1ABCAFCAE143404A60730E9E9D4740
55382	378	39.760790999999998	39.763683999999998	47.240392	47.233240000000002	24-я Линия	0103000020E61000000100000005000000AA0B789961E143403D0FEECEDA9D4740AA0B789961E143402A1C412AC59E47403E3DB665C0E143402A1C412AC59E47403E3DB665C0E143403D0FEECEDA9D4740AA0B789961E143403D0FEECEDA9D4740
55445	378	39.765345000000003	39.767851999999998	47.229238000000002	47.223160999999998	23-я Линия	0103000020E610000001000000050000001D9430D3F6E143400F5F268A909C47401D9430D3F6E143400F80B8AB579D474087156EF948E243400F80B8AB579D474087156EF948E243400F5F268A909C47401D9430D3F6E143400F5F268A909C4740
55368	378	39.597064000000003	39.665677000000002	47.210461000000002	47.203507000000002	2-я Краснодарская	0103000020E610000001000000050000003ACFD8976CCC4340E8C072840C9A47403ACFD8976CCC4340AF0AD462F09A4740865968E734D54340AF0AD462F09A4740865968E734D54340E8C072840C9A47403ACFD8976CCC4340E8C072840C9A4740
40655	378	39.501958999999999	39.859766999999998	47.345292999999998	47.158563999999998	2-я Володарская	0103000020E610000001000000050000006877483140C0434056293DD34B9447406877483140C04340D4449F8F32AC47400B9755D80CEE4340D4449F8F32AC47400B9755D80CEE434056293DD34B9447406877483140C0434056293DD34B944740
40746	378	39.688153	39.700091999999998	47.262895	47.259946999999997	2-й Пятилетки	0103000020E6100000010000000500000078D2C26515D84340BED87BF145A1474078D2C26515D8434016A4198BA6A147407A185A9D9CD9434016A4198BA6A147407A185A9D9CD94340BED87BF145A1474078D2C26515D84340BED87BF145A14740
55442	378	39.749760000000002	39.761347999999998	47.232114000000003	47.229868000000003	1-я Майская	0103000020E61000000100000005000000ABECBB22F8DF4340CF328B506C9D4740ABECBB22F8DF4340CD785BE9B59D47400070ECD973E14340CD785BE9B59D47400070ECD973E14340CF328B506C9D4740ABECBB22F8DF4340CF328B506C9D4740
55473	378	39.655768999999999	39.663288000000001	47.211709999999997	47.200893000000001	1-я Круговая	0103000020E61000000100000005000000855D143DF0D34340677FA0DCB6994740855D143DF0D343403A1E3350199B474025EA059FE6D443403A1E3350199B474025EA059FE6D44340677FA0DCB6994740855D143DF0D34340677FA0DCB6994740
55244	378	39.785656000000003	39.790515999999997	47.258406000000001	47.254111999999999	 Урожайная	0103000020E61000000100000005000000FEF3346090E44340B5C2F4BD86A04740FEF3346090E443408B8BA37213A147407C7BD7A02FE543408B8BA37213A147407C7BD7A02FE54340B5C2F4BD86A04740FEF3346090E44340B5C2F4BD86A04740
55370	378	39.621256000000002	39.681497	47.265891000000003	47.256839999999997	 Таганрогская	0103000020E61000000100000005000000CE380D5185CF4340FE261422E0A04740CE380D5185CF43407FA65EB708A247403BA92F4B3BD743407FA65EB708A247403BA92F4B3BD74340FE261422E0A04740CE380D5185CF4340FE261422E0A04740
55441	378	39.720987000000001	39.744791999999997	47.222279999999998	47.217444999999998	 Седова	0103000020E61000000100000005000000ABEB504D49DC4340E0D6DD3CD59B4740ABEB504D49DC43400647C9AB739C47404529215855DF43400647C9AB739C47404529215855DF4340E0D6DD3CD59B4740ABEB504D49DC4340E0D6DD3CD59B4740
55367	378	39.741261999999999	39.754440000000002	47.301907	47.295814999999997	 Миронова	0103000020E610000001000000050000003FE257ACE1DE434047551344DDA547403FE257ACE1DE43407CB779E3A4A64740AA656B7D91E043407CB779E3A4A64740AA656B7D91E0434047551344DDA547403FE257ACE1DE434047551344DDA54740
55456	378	39.694764999999997	39.74295	47.232664	47.221691999999997	 Максима Горького	0103000020E61000000100000005000000E5B33C0FEED8434075E44867609C4740E5B33C0FEED84340707A17EFC79D4740174850FC18DF4340707A17EFC79D4740174850FC18DF434075E44867609C4740E5B33C0FEED8434075E44867609C4740
55251	378	39.734820999999997	39.745187000000001	47.296999999999997	47.292869000000003	 Думенко	0103000020E61000000100000005000000FEB4519D0EDE434091813CBB7CA54740FEB4519D0EDE4340BC74931804A64740C233A14962DF4340BC74931804A64740C233A14962DF434091813CBB7CA54740FEB4519D0EDE434091813CBB7CA54740
55380	378	39.708823000000002	39.724176	47.286824000000003	47.282594000000003	 Волкова	0103000020E6100000010000000500000089D349B6BADA4340DE054A0A2CA4474089D349B6BADA43409DDA19A6B6A44740284696CCB1DC43409DDA19A6B6A44740284696CCB1DC4340DE054A0A2CA4474089D349B6BADA4340DE054A0A2CA44740
55414	378	39.780042000000002	39.799939999999999	47.274206	47.265585000000002	 Волжская	0103000020E61000000100000005000000D3C08F6AD8E3434072A774B0FEA14740D3C08F6AD8E34340F92EA52E19A347409161156F64E64340F92EA52E19A347409161156F64E6434072A774B0FEA14740D3C08F6AD8E3434072A774B0FEA14740
55410	378	39.695807000000002	39.742986000000002	47.227499999999999	47.217542999999999	 Большая Садовая	0103000020E61000000100000005000000F8A92A3410D94340A33CF372D89B4740F8A92A3410D9434085EB51B81E9D474064B14D2A1ADF434085EB51B81E9D474064B14D2A1ADF4340A33CF372D89B4740F8A92A3410D94340A33CF372D89B4740
55386	378	39.614275999999997	39.633383000000002	47.225878000000002	47.224930000000001	 339-й Стрелковой Дивизии	0103000020E61000000100000005000000DD5B9198A0CE4340D4F19881CA9C4740DD5B9198A0CE43406571FF91E99C4740D36BB3B112D143406571FF91E99C4740D36BB3B112D14340D4F19881CA9C4740DD5B9198A0CE4340D4F19881CA9C4740
55108	56611	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	пер.Красный	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
55110	56611	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	Пионерская	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
55107	56611	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	Думенко	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
55119	56611	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	Дорожная	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
40562	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Энергетическая	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40947	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Энгельса	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40948	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Щербакова	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55238	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Школьная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40204	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Харьковская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40335	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Союзная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40942	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Советской Конституции	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39836	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Советская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39858	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Радио	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55232	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Рабоче-Крестьянская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39834	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Рабочая	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40186	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Просвещения	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55264	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Пирогова	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55595	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Перова	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55794	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Назаренко	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55231	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Молодогвардейцев	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
41173	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Молдавская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40949	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Моисеенко	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40944	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Мичурина	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55800	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Маяковского	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40189	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Малосадовая	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39837	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Магистральная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40332	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Ленинградская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40940	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Ленина	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40337	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Курская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39861	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Краснофлотская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39934	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Котельникова	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39789	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Королева	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39838	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Киевская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55814	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Казахстанская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55813	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Грессовская	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40191	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Грессовсая	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
41172	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Горького	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55228	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Горняцкая	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55230	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Восточная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
39862	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Вокзальная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55598	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	Войкова	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40643	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	60 лет Октября	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
56299	54821	39.785584	40.019596	47.849257000000001	47.722447000000003	 Поленова	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55100	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Театральная	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55093	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Платовский проспект	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55106	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Платовский пр-т	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55719	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Панфилова	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55145	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Михайловская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55151	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Макаренко	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39892	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Крылова	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55697	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Интернатный пер	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55166	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Дубовского	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55143	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Дворцовая	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39898	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Гвардейская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39895	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Буденновская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39868	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Баклановский проспект	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55124	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Баклановский пр-т	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39896	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Б.Хмельницкого	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55122	54826	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Александровская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
55121	56614	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Руднева	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
55150	56614	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Ленина	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
55184	56614	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Ворошилова	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
55120	56613	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Черноморская	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55153	56613	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	3-го Интернационала	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
56203	56821	39.992026000000003	40.138658	47.916677	47.850557999999999	Коммунистическая	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
55141	56612	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	Коммунистическая	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
55154	56612	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	Донская	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
55117	56612	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	25 Октября	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
41123	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	переулок Придорожный	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
55149	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	пер.Советский	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40070	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Ученическая	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39970	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Танкистов	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
41140	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Строителей	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
55148	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Советская	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39973	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Просторный	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40519	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Победы	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40072	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Пивоварова	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40092	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Парковая	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39759	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Парк Культуры	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40508	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Островского	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
41124	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Освобождения	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39760	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Мусина	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
41118	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Мира	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40238	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Микрорайон 60-лет Октября	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40239	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Луначарского	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40509	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Ленина	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40488	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Крупской	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40236	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Красная	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40074	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Котовского	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
41120	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Коммунистический	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40066	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Кирова	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40068	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	К.Маркса	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39771	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Западная	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40235	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Желябова	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
55851	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Дружбы	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
41129	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Героев Пионеров	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40241	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Гагарина	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40338	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Ворошилова	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
40067	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Володарского	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39981	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Вокзальная	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39984	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Больничная	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39763	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Башкевича	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
39972	54808	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Астаховский	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
55173	56615	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Мира	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
55175	56615	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Колодина	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
55155	56615	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Калинина	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
40330	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Школьная	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
39824	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Строительная	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
40177	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Советская	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
40179	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Рижская	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
40178	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Осташенко	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
55213	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Обухова	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
40853	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Ивановская	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
40852	54823	40.106974999999998	40.131202000000002	48.047516000000002	48.002983999999998	Горького	0103000020E61000000100000005000000AB3E575BB10D4440A4349BC761004840AB3E575BB10D4440B404190115064840BC95253ACB104440B404190115064840BC95253ACB104440A4349BC761004840AB3E575BB10D4440A4349BC761004840
40501	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	проспект Мира	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
55613	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	переулок Октябрьский	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
39843	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	переулок Молодежный	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
40500	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	переулок Гагарина	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
40496	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Экскаваторная	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
40065	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Шевченко	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
39695	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Цветкова	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
40039	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Тимирязева	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
40492	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Советская	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
39758	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Пролетарская	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
55833	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Обогатителей	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
40506	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Некрасова	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
39967	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Мичурина	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
41115	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Королева	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
55542	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Второй Аварийный	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
40493	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Братьев Дорошевых	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
39694	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	3 микрорайон	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
55253	54811	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	12 квартал	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
55136	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	пер. Волжский	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
39848	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Щорса	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40967	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Школьная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40863	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Шахтерская	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40042	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Чкалова	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40356	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Трамвайная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40199	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Степная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
39829	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Российская	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55524	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Розы Люксембург	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55809	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Пушкина	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40864	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Молодежная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40034	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Мира	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40259	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Милицейская	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40858	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Льва Толстого	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40354	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Ленинградская	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40351	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Кутузова	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40041	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Куйбышева	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55223	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Крупской	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40263	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Криничная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40349	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Кооперативная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40866	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Комсомольская	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55131	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Колодезная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55594	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Карла Маркса	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
39826	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Герцена	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40036	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Бургустинская	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
39828	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Болгарский	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
40200	54824	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Ардинцева	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55172	56617	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Мира	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
41098	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	переулок Октябрьский	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40121	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	бульвар Великой Победы	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
39914	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Энтузиастов	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
55144	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Черникова	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40102	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Строителей	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
39912	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Степная	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40279	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Советская	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
41095	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Молодежная	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40595	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Мира	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
41104	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Маршала Кошевого	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40589	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	М. Горького	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40119	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Ленина	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
41101	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Курчатова	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
41094	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Кооперативная	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40596	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	К. Маркса	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40280	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Горького	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
41102	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Гагарина	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40267	54830	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	50 Лет ВЛКСМ	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
40988	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Энтузиастов	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
39974	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Энгельса	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
55504	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Щаденко	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
39976	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Театральная	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40984	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Строительная	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
39904	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Светлая	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40418	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Пролетарская	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40206	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Мичурина	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40005	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Машиностроителей	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40982	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Копаева	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40205	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Калинина	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40419	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Горького	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40361	54829	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Геологическая	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
55113	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	пл. Ленина	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40246	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Южная	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
39994	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Эстакадная	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40146	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Энгельса	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40659	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Тельмана	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40341	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Ставропольская	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55241	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Совхозная	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
39867	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Северный массив	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40198	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Первомайское кольцо	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
41259	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Октябьская	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40136	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Молдавская	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40660	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Матросова	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
39995	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	М.Горького	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
41145	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Луначарского	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40483	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Ленина	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40650	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Коммунистическая	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55254	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Комарова	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40037	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Коваливского	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55249	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Калинина	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
39979	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Железнодорожный тупик	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40347	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Гастелло	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
39839	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Воровского	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
39724	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Белорусская	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
40134	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Авиагородок	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
39723	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	50 лет Октября	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
41260	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	1-й Пятилетки	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55250	54817	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	 Северный массив	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55101	11987	39.849248000000003	39.911726000000002	47.282783999999999	47.246375	Шолохова	0103000020E61000000100000005000000C2189128B4EC4340A8C64B37899F4740C2189128B4EC434081EA1F4432A44740DA740470B3F4434081EA1F4432A44740DA740470B3F44340A8C64B37899F4740C2189128B4EC4340A8C64B37899F4740
55099	11987	39.849248000000003	39.911726000000002	47.282783999999999	47.246375	Шевченко	0103000020E61000000100000005000000C2189128B4EC4340A8C64B37899F4740C2189128B4EC434081EA1F4432A44740DA740470B3F4434081EA1F4432A44740DA740470B3F44340A8C64B37899F4740C2189128B4EC4340A8C64B37899F4740
55129	11987	39.849248000000003	39.911726000000002	47.282783999999999	47.246375	Садовая	0103000020E61000000100000005000000C2189128B4EC4340A8C64B37899F4740C2189128B4EC434081EA1F4432A44740DA740470B3F4434081EA1F4432A44740DA740470B3F44340A8C64B37899F4740C2189128B4EC4340A8C64B37899F4740
55245	11987	39.849248000000003	39.911726000000002	47.282783999999999	47.246375	Платова	0103000020E61000000100000005000000C2189128B4EC4340A8C64B37899F4740C2189128B4EC434081EA1F4432A44740DA740470B3F4434081EA1F4432A44740DA740470B3F44340A8C64B37899F4740C2189128B4EC4340A8C64B37899F4740
55159	11987	39.849248000000003	39.911726000000002	47.282783999999999	47.246375	Крупской	0103000020E61000000100000005000000C2189128B4EC4340A8C64B37899F4740C2189128B4EC434081EA1F4432A44740DA740470B3F4434081EA1F4432A44740DA740470B3F44340A8C64B37899F4740C2189128B4EC4340A8C64B37899F4740
40262	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	проспект Зои Космодемьянской	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40313	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	переулок Степана Разина	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40312	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	переулок Социалистический	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
39755	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	переулок Осипенко	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40311	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Черноморский переулок	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
55237	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Толстого	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
56208	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Соловьиный пер	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40161	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Пушкина	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40772	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Победы	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40770	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Петровский бульвар	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
41363	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Первомайская	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40160	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Московская	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
55821	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Мира 	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40158	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Мира	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40151	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Макаровского	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40011	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Ленинградская	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
41274	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Куйбышева	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
39863	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Красногоровская	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40761	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Красноармейский переулок	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
39757	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Кондаурова	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40157	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Дзержинского	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40767	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Григория Мирошниченко	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
40955	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Васильева	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
41357	54819	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Андреевская	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
55163	1920	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Якутский	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55207	1920	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Мичурина	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55206	1920	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Милиционная	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55203	1920	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Ленинского Комсомола	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55214	1920	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Калинина	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
55216	1920	40.090328999999997	40.372337000000002	47.814059	47.664872000000003	Ворошилова	0103000020E61000000100000005000000B07092E68F0B4440580394861AD54740B07092E68F0B4440DA01D71533E847409E0B23BDA82F4440DA01D71533E847409E0B23BDA82F4440580394861AD54740B07092E68F0B4440580394861AD54740
41222	20596	39.785584	40.019596	47.849257000000001	47.722447000000003	Привокзальная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55716	20596	39.785584	40.019596	47.849257000000001	47.722447000000003	Перспективная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55235	20596	39.785584	40.019596	47.849257000000001	47.722447000000003	Молодогвардейцев	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55695	20596	39.785584	40.019596	47.849257000000001	47.722447000000003	Маркса	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55571	20596	39.785584	40.019596	47.849257000000001	47.722447000000003	Линейная	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
55139	20596	39.785584	40.019596	47.849257000000001	47.722447000000003	Ленина	0103000020E6100000010000000500000064213A048EE44340F20BAF2479DC474064213A048EE4434015731074B4EC4740F390291F8202444015731074B4EC4740F390291F82024440F20BAF2479DC474064213A048EE44340F20BAF2479DC4740
40518	12804	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Советская	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
32956	12804	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Железнодорожников	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
55182	12804	40.148046000000001	40.312752000000003	48.417001999999997	48.137163000000001	Ворошилова	0103000020E61000000100000005000000DD26DC2BF3124440529CA38E8E114840DD26DC2BF3124440EC2E5052603548401AE1ED4108284440EC2E5052603548401AE1ED4108284440529CA38E8E114840DD26DC2BF3124440529CA38E8E114840
55723	1460	39.854934	40.049976999999998	48.360909999999997	48.270252999999997	Юго-Западное шоссе	0103000020E61000000100000005000000861E317A6EED4340AC527AA697224840861E317A6EED43405166834C322E4840AE4676A5650644405166834C322E4840AE4676A565064440AC527AA697224840861E317A6EED4340AC527AA697224840
39845	14830	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Красная Горка	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55218	14830	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Комсомольская	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55224	14830	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Карла Маркса	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55807	14830	39.859453000000002	40.053606000000002	48.073748000000002	48.009566999999997	Железнодорожная	0103000020E610000001000000050000007CB94F8E02EE4340770FD07D390148407CB94F8E02EE43409D12109370094840486FB88FDC0644409D12109370094840486FB88FDC064440770FD07D390148407CB94F8E02EE4340770FD07D39014840
55158	1116	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Центральная	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
55140	1116	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Октябрьское шоссе	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
55162	1116	42.074330000000003	42.255789999999998	47.605379999999997	47.482343999999998	Вокзальный	0103000020E610000001000000050000004C8E3BA583094540FEB5BC72BDBD47404C8E3BA58309454084D382177DCD474069520ABABD20454084D382177DCD474069520ABABD204540FEB5BC72BDBD47404C8E3BA583094540FEB5BC72BDBD4740
39938	5338	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Машиностроителей	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
55133	5338	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Калинина	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40979	5338	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	Большая	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
40299	2228	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	переулок Книжный	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55128	2228	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Куйбышева	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55242	2228	39.666378000000002	39.787129999999998	47.158422999999999	47.073202000000002	Авиагородок	0103000020E610000001000000050000000F63D2DF4BD543403B00E2AE5E8947400F63D2DF4BD5434094F7713447944740A9D903ADC0E4434094F7713447944740A9D903ADC0E443403B00E2AE5E8947400F63D2DF4BD543403B00E2AE5E894740
55165	589	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Севастопольская	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
55116	589	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Макаровского	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
55240	589	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Литейный проезд	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
55204	589	39.379725999999998	39.473787999999999	47.127305	47.058477000000003	Измайлова	0103000020E610000001000000050000006FB88FDC9AB04340BB48A12C7C8747406FB88FDC9AB0434003CFBD874B9047405E9ECE15A5BC434003CFBD874B9047405E9ECE15A5BC4340BB48A12C7C8747406FB88FDC9AB04340BB48A12C7C874740
55970	5809	41.707403999999997	41.739958999999999	49.491906999999998	49.458616999999997	пер.Центральный	0103000020E61000000100000005000000A087DA368CDA4440DF313CF6B3BA4840A087DA368CDA444034D6FECEF6BE4840C0B0FCF9B6DE444034D6FECEF6BE4840C0B0FCF9B6DE4440DF313CF6B3BA4840A087DA368CDA4440DF313CF6B3BA4840
56353	5655	41.693551999999997	41.710270000000001	49.756498000000001	49.714210000000001	пер.Центральный	0103000020E61000000100000005000000A609DB4FC6D84440F33CB83B6BDB4840A609DB4FC6D84440A5BE2CEDD4E048403BAA9A20EADA4440A5BE2CEDD4E048403BAA9A20EADA4440F33CB83B6BDB4840A609DB4FC6D84440F33CB83B6BDB4840
56092	5592	41.765211000000001	41.810962000000004	49.822378999999998	49.795242000000002	Центральная	0103000020E610000001000000050000000DC51D6FF2E14440EC33677DCAE548400DC51D6FF2E1444066F50EB743E948403E26529ACDE7444066F50EB743E948403E26529ACDE74440EC33677DCAE548400DC51D6FF2E14440EC33677DCAE54840
55798	6139	41.953173999999997	41.98413	49.768101000000001	49.751916999999999	Центральная	0103000020E61000000100000005000000E1B20A9B01FA44403927F6D03EE04840E1B20A9B01FA44403083312251E248409981CAF8F7FD44403083312251E248409981CAF8F7FD44403927F6D03EE04840E1B20A9B01FA44403927F6D03EE04840
56088	5918	41.831012000000001	41.884281999999999	49.490748000000004	49.466358	Степная	0103000020E61000000100000005000000B24AE9995EEA44402E1D739EB1BB4840B24AE9995EEA4440E94999D4D0BE484082380F2730F14440E94999D4D0BE484082380F2730F144402E1D739EB1BB4840B24AE9995EEA44402E1D739EB1BB4840
55998	28470	41.936753000000003	41.962381999999998	49.592596999999998	49.584871	Береговая	0103000020E6100000010000000500000007B7B585E7F744407DB08C0DDDCA484007B7B585E7F74440965AEF37DACB4840292158552FFB4440965AEF37DACB4840292158552FFB44407DB08C0DDDCA484007B7B585E7F744407DB08C0DDDCA4840
56192	6184	41.921221000000003	41.941065000000002	49.824976999999997	49.807039000000003	Центральная	0103000020E61000000100000005000000B8B1D991EAF544405CCCCF0D4DE74840B8B1D991EAF54440E179A9D898E94840833463D174F84440E179A9D898E94840833463D174F844405CCCCF0D4DE74840B8B1D991EAF544405CCCCF0D4DE74840
56167	5436	42.024814999999997	42.047336000000001	49.593665999999999	49.581710999999999	Лесная	0103000020E61000000100000005000000A1B94E232D0345409A5C8C8175CA4840A1B94E232D034540A25F5B3FFDCB484034F6251B0F064540A25F5B3FFDCB484034F6251B0F0645409A5C8C8175CA4840A1B94E232D0345409A5C8C8175CA4840
55935	56784	41.663108000000001	41.697595	49.641677000000001	49.630147999999998	Чехова	0103000020E61000000100000005000000A5DB12B9E0D44440E5D18DB0A8D04840A5DB12B9E0D4444036CCD07822D24840336DFFCA4AD9444036CCD07822D24840336DFFCA4AD94440E5D18DB0A8D04840A5DB12B9E0D44440E5D18DB0A8D04840
56352	5429	41.990184999999997	42.011439000000003	49.571249000000002	49.548780999999998	Родниковая	0103000020E61000000100000005000000B0FECF61BEFE444045D5AF743EC64840B0FECF61BEFE4440B56FEEAF1EC94840117349D576014540B56FEEAF1EC94840117349D57601454045D5AF743EC64840B0FECF61BEFE444045D5AF743EC64840
40629	5985	41.498896000000002	41.561374000000001	49.618471	49.601576999999999	переулок Победы	0103000020E61000000100000005000000780DFAD2DBBF44404D83A27900CD4840780DFAD2DBBF44402043C70E2ACF484090696D1ADBC744402043C70E2ACF484090696D1ADBC744404D83A27900CD4840780DFAD2DBBF44404D83A27900CD4840
56188	5819	41.782305999999998	41.817698999999998	49.465251000000002	49.447085999999999	Южная	0103000020E6100000010000000500000077BB5E9A22E44440EE3F321D3AB9484077BB5E9A22E4444035B742588DBB4840677C5F5CAAE8444035B742588DBB4840677C5F5CAAE84440EE3F321D3AB9484077BB5E9A22E44440EE3F321D3AB94840
56209	5270	41.676088999999997	41.689303000000002	49.915289999999999	49.906089000000001	Зеленая	0103000020E61000000100000005000000B91798158AD64440F7216FB9FAF34840B91798158AD644408C2D043928F548407104A9143BD844408C2D043928F548407104A9143BD84440F7216FB9FAF34840B91798158AD64440F7216FB9FAF34840
56061	4917	41.908070000000002	41.926412999999997	49.601309000000001	49.594028000000002	Плоткина	0103000020E61000000100000005000000473D44A33BF444404374081C09CC4840473D44A33BF444402EE57CB1F7CC48406CCB80B394F644402EE57CB1F7CC48406CCB80B394F644404374081C09CC4840473D44A33BF444404374081C09CC4840
41243	5727	41.745303999999997	41.801699999999997	49.447519	49.417299999999997	Школьная	0103000020E61000000100000005000000FBC9181F66DF4440764F1E166AB54840FBC9181F66DF444058AB764D48B94840029A081B9EE6444058AB764D48B94840029A081B9EE64440764F1E166AB54840FBC9181F66DF4440764F1E166AB54840
55803	5497	41.813118000000003	41.859470999999999	49.769567000000002	49.748221000000001	переулок Больничный	0103000020E61000000100000005000000FCE4284014E844401897AAB4C5DF4840FCE4284014E84440598AE42B81E24840226E4E2503EE4440598AE42B81E24840226E4E2503EE44401897AAB4C5DF4840FCE4284014E844401897AAB4C5DF4840
56098	6068	41.386526000000003	41.419511999999997	49.566388000000003	49.532528999999997	Центральная	0103000020E61000000100000005000000E08618AF79B14440F69507E929C44840E08618AF79B14440666CE8667FC84840C823B891B2B54440666CE8667FC84840C823B891B2B54440F69507E929C44840E08618AF79B14440F69507E929C44840
39717	5277	41.833582	41.85718	49.573177000000001	49.550096000000003	Центральная	0103000020E610000001000000050000006344A2D0B2EA444089D4B48B69C648406344A2D0B2EA4440E2E82ADD5DC9484084640113B8ED4440E2E82ADD5DC9484084640113B8ED444089D4B48B69C648406344A2D0B2EA444089D4B48B69C64840
56317	5110	41.543622999999997	41.571795000000002	49.753208999999998	49.735612000000003	Решетовская	0103000020E610000001000000050000003C2D3F7095C54440C845B58828DE48403C2D3F7095C54440C4060B2769E0484017821C9430C94440C4060B2769E0484017821C9430C94440C845B58828DE48403C2D3F7095C54440C845B58828DE4840
56067	5969	41.439751000000001	41.459766000000002	49.598576000000001	49.588538	Центральная	0103000020E6100000010000000500000010B1C1C249B84440043A933655CB484010B1C1C249B84440D3156C239ECC484008E8BE9CD9BA4440D3156C239ECC484008E8BE9CD9BA4440043A933655CB484010B1C1C249B84440043A933655CB4840
56446	56913	42.033448	42.050040000000003	49.619427999999999	49.611286	Платова	0103000020E61000000100000005000000ED0E2906480445405740A19E3ECE4840ED0E290648044540041DAD6A49CF4840F5BEF1B567064540041DAD6A49CF4840F5BEF1B5670645405740A19E3ECE4840ED0E2906480445405740A19E3ECE4840
55623	5113	41.545006999999998	41.682808000000001	49.918213000000002	49.878349	Клубная	0103000020E61000000100000005000000A88B14CAC2C54440B6BC72BD6DF04840A88B14CAC2C544408BE1EA0088F548403DB9A64066D744408BE1EA0088F548403DB9A64066D74440B6BC72BD6DF04840A88B14CAC2C54440B6BC72BD6DF04840
56050	5113	41.545006999999998	41.682808000000001	49.918213000000002	49.878349	Западная	0103000020E61000000100000005000000A88B14CAC2C54440B6BC72BD6DF04840A88B14CAC2C544408BE1EA0088F548403DB9A64066D744408BE1EA0088F548403DB9A64066D74440B6BC72BD6DF04840A88B14CAC2C54440B6BC72BD6DF04840
55489	4976	41.621831	41.647396999999998	49.715358000000002	49.686050000000002	пер.Школьный	0103000020E61000000100000005000000CA51802898CF4440DDB5847CD0D74840CA51802898CF44404B77D7D990DB4840A643A7E7DDD244404B77D7D990DB4840A643A7E7DDD24440DDB5847CD0D74840CA51802898CF4440DDB5847CD0D74840
55488	4530	41.759110999999997	41.796598000000003	49.590541000000002	49.573726000000001	Почтовая	0103000020E6100000010000000500000055849B8C2AE14440B56E83DA6FC9484055849B8C2AE144403CF9F4D896CB48408E075BECF6E544403CF9F4D896CB48408E075BECF6E54440B56E83DA6FC9484055849B8C2AE14440B56E83DA6FC94840
55956	5649	41.742753	41.777850000000001	49.736688999999998	49.690531999999997	Школьная	0103000020E61000000100000005000000C100C28712DF4440B56B425A63D84840C100C28712DF444056293DD34BDE4840C898BB9690E3444056293DD34BDE4840C898BB9690E34440B56B425A63D84840C100C28712DF4440B56B425A63D84840
56133	31179	41.536059999999999	41.565919999999998	49.573790000000002	49.560550999999997	Подгорная	0103000020E61000000100000005000000CD58349D9DC44440BB5E9A22C0C74840CD58349D9DC44440CC6262F371C948407F130A1170C84440CC6262F371C948407F130A1170C84440BB5E9A22C0C74840CD58349D9DC44440BB5E9A22C0C74840
55109	4694	41.700164000000001	41.757700999999997	49.644261	49.621791999999999	пер.Красный	0103000020E6100000010000000500000014EB54F99ED944400C7558E196CF484014EB54F99ED944404C8BFA2477D24840C092AB58FCE044404C8BFA2477D24840C092AB58FCE044400C7558E196CF484014EB54F99ED944400C7558E196CF4840
39929	4694	41.700164000000001	41.757700999999997	49.644261	49.621791999999999	Шолохова	0103000020E6100000010000000500000014EB54F99ED944400C7558E196CF484014EB54F99ED944404C8BFA2477D24840C092AB58FCE044404C8BFA2477D24840C092AB58FCE044400C7558E196CF484014EB54F99ED944400C7558E196CF4840
41175	4694	41.700164000000001	41.757700999999997	49.644261	49.621791999999999	Сосновая	0103000020E6100000010000000500000014EB54F99ED944400C7558E196CF484014EB54F99ED944404C8BFA2477D24840C092AB58FCE044404C8BFA2477D24840C092AB58FCE044400C7558E196CF484014EB54F99ED944400C7558E196CF4840
55955	4601	41.686185999999999	41.713889999999999	49.543841999999998	49.520798999999997	Молодежная	0103000020E610000001000000050000008D7C5EF1D4D744400E65A88AA9C248408D7C5EF1D4D744407A185A9D9CC5484081785DBF60DB44407A185A9D9CC5484081785DBF60DB44400E65A88AA9C248408D7C5EF1D4D744400E65A88AA9C24840
32959	1346	41.361885000000001	41.379500999999998	49.553829999999998	49.533768999999999	Горская	0103000020E61000000100000005000000DCF4673F52AE44402F4FE78A52C44840DCF4673F52AE444097C5C4E6E3C648404FE61F7D93B0444097C5C4E6E3C648404FE61F7D93B044402F4FE78A52C44840DCF4673F52AE44402F4FE78A52C44840
40147	1240	41.717232000000003	41.761564	49.602119999999999	49.585220999999997	Ленина	0103000020E6100000010000000500000085D21742CEDB444059F78F85E8CA484085D21742CEDB44403E22A64412CD4840CDE7DCED7AE144403E22A64412CD4840CDE7DCED7AE1444059F78F85E8CA484085D21742CEDB444059F78F85E8CA4840
56066	5056	41.526761999999998	41.561886000000001	49.736927999999999	49.704259999999998	Школьная	0103000020E610000001000000050000004563EDEF6CC34440C3F0113125DA48404563EDEF6CC34440DBC01DA853DE4840460A65E1EBC74440DBC01DA853DE4840460A65E1EBC74440C3F0113125DA48404563EDEF6CC34440C3F0113125DA4840
56312	4858	41.931910999999999	41.950839000000002	49.676316	49.657040000000002	Агеева	0103000020E610000001000000050000002EE411DC48F74440F91400E319D448402EE411DC48F744407AE1CE8591D648407461A417B5F944407AE1CE8591D648407461A417B5F94440F91400E319D448402EE411DC48F74440F91400E319D44840
56311	4534	41.631964000000004	41.657286999999997	49.616230000000002	49.604799999999997	Городская	0103000020E61000000100000005000000EB1F4432E4D04440764F1E166ACD4840EB1F4432E4D044403468E89FE0CE4840008BFCFA21D444403468E89FE0CE4840008BFCFA21D44440764F1E166ACD4840EB1F4432E4D04440764F1E166ACD4840
55778	3030	40.283062000000001	40.314934999999998	49.507815000000001	49.479920999999997	Южная	0103000020E61000000100000005000000C45E28603B244440F1D4230D6EBD4840C45E28603B24444089B5F81400C14840D1AE42CA4F28444089B5F81400C14840D1AE42CA4F284440F1D4230D6EBD4840C45E28603B244440F1D4230D6EBD4840
55635	3485	40.317154000000002	40.368178	49.307353999999997	49.274943	Центральная	0103000020E61000000100000005000000D6E5948098284440CFA10C5531A34840D6E5948098284440BB25396057A74840A88DEA74202F4440BB25396057A74840A88DEA74202F4440CFA10C5531A34840D6E5948098284440CFA10C5531A34840
55626	1803	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	переулок Деповской	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
55732	1803	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	Фрунзе	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
40261	1803	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	Садовая	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
40145	1803	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	Пролетарская	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
39992	1803	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	Петровского	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
40566	1803	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	Октябрьская	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
55730	1803	40.123162000000001	40.181579999999997	49.396549	49.360219000000001	Комсомольская	0103000020E61000000100000005000000130EBDC5C30F4440EC32FCA71BAE4840130EBDC5C30F444079211D1EC2B24840C8CD70033E17444079211D1EC2B24840C8CD70033E174440EC32FCA71BAE4840130EBDC5C30F4440EC32FCA71BAE4840
55780	3739	40.632030999999998	40.699351	49.593612999999998	49.574252000000001	Широкая	0103000020E6100000010000000500000072874D64E6504440D0D4EB1681C9484072874D64E65044407FBDC282FBCB484063B66455845944407FBDC282FBCB484063B6645584594440D0D4EB1681C9484072874D64E6504440D0D4EB1681C94840
56234	2566	40.063326000000004	40.092340999999998	49.488067999999998	49.442991999999997	Ленина	0103000020E61000000100000005000000467EFD101B084440DF313CF6B3B84840467EFD101B084440B01C210379BE48403B8A73D4D10B4440B01C210379BE48403B8A73D4D10B4440DF313CF6B3B84840467EFD101B084440DF313CF6B3B84840
39931	3699	40.478886000000003	40.529839000000003	49.524811	49.469237999999997	Социалистическая	0103000020E610000001000000050000009241EE224C3D44402D05A4FD0FBC48409241EE224C3D444060CAC0012DC348409B92ACC3D143444060CAC0012DC348409B92ACC3D14344402D05A4FD0FBC48409241EE224C3D44402D05A4FD0FBC4840
55941	56790	40.807768000000003	40.852657000000001	49.387343000000001	49.345278	Советская	0103000020E61000000100000005000000AF601BF1646744409F03CB1132AC4840AF601BF164674440D2AA967494B148404DDA54DD236D4440D2AA967494B148404DDA54DD236D44409F03CB1132AC4840AF601BF1646744409F03CB1132AC4840
56582	57026	40.562268000000003	40.589523	49.257337	49.240958999999997	Советская	0103000020E610000001000000050000002ECBD765F8474440A35698BED79E48402ECBD765F84744407F86376BF0A04840B29E5A7D754B44407F86376BF0A04840B29E5A7D754B4440A35698BED79E48402ECBD765F8474440A35698BED79E4840
56496	56956	40.166237000000002	40.194344999999998	49.393980999999997	49.384931999999999	Комарова	0103000020E610000001000000050000004D310741471544408997A77345B148404D31074147154440681F2BF86DB248401092054CE0184440681F2BF86DB248401092054CE01844408997A77345B148404D310741471544408997A77345B14840
56060	56806	40.717533000000003	40.764406999999999	49.262445999999997	49.227535000000003	Партизанская	0103000020E610000001000000050000008066101FD85B444002D9EBDD1F9D48408066101FD85B4440A67B9DD497A14840AFEAAC16D8614440A67B9DD497A14840AFEAAC16D861444002D9EBDD1F9D48408066101FD85B444002D9EBDD1F9D4840
39993	2502	40.113774999999997	40.170315000000002	49.410237000000002	49.390889999999999	Российская	0103000020E610000001000000050000001B0DE02D900E4440AE2AFBAE08B248401B0DE02D900E4440F94D61A582B448405682C5E1CC154440F94D61A582B448405682C5E1CC154440AE2AFBAE08B248401B0DE02D900E4440AE2AFBAE08B24840
55564	4160	40.755054999999999	40.819006000000002	49.281649000000002	49.259171000000002	Молодежная	0103000020E6100000010000000500000034D769A4A56044402B89EC832CA1484034D769A4A5604440BEF90D130DA44840289D4830D5684440BEF90D130DA44840289D4830D56844402B89EC832CA1484034D769A4A56044402B89EC832CA14840
56559	57011	40.255951000000003	40.284669999999998	49.589444	49.559030999999997	Мира	0103000020E6100000010000000500000073309B00C32044409F39EB538EC7484073309B00C32044406669A7E672CB48407F130A11702444406669A7E672CB48407F130A11702444409F39EB538EC7484073309B00C32044409F39EB538EC74840
55553	3532	40.343347999999999	40.379199999999997	49.275801999999999	49.245480999999998	Школьная	0103000020E61000000100000005000000D192C7D3F22B44400A65E1EB6B9F4840D192C7D3F22B4440F015DD7A4DA34840545227A089304440F015DD7A4DA34840545227A0893044400A65E1EB6B9F4840D192C7D3F22B44400A65E1EB6B9F4840
55852	56709	40.549807999999999	40.569831999999998	49.574339000000002	49.557564999999997	Лесная	0103000020E61000000100000005000000228AC91B604644407632384A5EC74840228AC91B604644409FE8BAF083C948406D1B4641F04844409FE8BAF083C948406D1B4641F04844407632384A5EC74840228AC91B604644407632384A5EC74840
55600	3600	40.211323	40.257173000000002	49.221563000000003	49.191091	Ленина	0103000020E6100000010000000500000041F2CEA10C1B4440ACC77DAB7598484041F2CEA10C1B44407880272D5C9C484005357C0BEB2044407880272D5C9C484005357C0BEB204440ACC77DAB7598484041F2CEA10C1B4440ACC77DAB75984840
56534	56988	40.395558000000001	40.402510999999997	49.432651999999997	49.423651999999997	Степная	0103000020E61000000100000005000000E9D500A5A132444047718E3A3AB64840E9D500A5A13244404546072461B74840DFA3FE7A853344404546072461B74840DFA3FE7A8533444047718E3A3AB64840E9D500A5A132444047718E3A3AB64840
55678	3205	40.261251000000001	40.303697	49.418278000000001	49.366250000000001	Юбилейная	0103000020E610000001000000050000000E863AAC702144407B14AE47E1AE48400E863AAC7021444072512D228AB548405872158BDF26444072512D228AB548405872158BDF2644407B14AE47E1AE48400E863AAC702144407B14AE47E1AE4840
55808	3205	40.261251000000001	40.303697	49.418278000000001	49.366250000000001	Октябрьская	0103000020E610000001000000050000000E863AAC702144407B14AE47E1AE48400E863AAC7021444072512D228AB548405872158BDF26444072512D228AB548405872158BDF2644407B14AE47E1AE48400E863AAC702144407B14AE47E1AE4840
55483	3205	40.261251000000001	40.303697	49.418278000000001	49.366250000000001	Кирова	0103000020E610000001000000050000000E863AAC702144407B14AE47E1AE48400E863AAC7021444072512D228AB548405872158BDF26444072512D228AB548405872158BDF2644407B14AE47E1AE48400E863AAC702144407B14AE47E1AE4840
55936	56785	40.622697000000002	40.641427	49.463166999999999	49.430590000000002	Победы	0103000020E610000001000000050000009E280989B44F444009FEB7921DB748409E280989B44F444010CB660E49BB4840BDE2A9471A52444010CB660E49BB4840BDE2A9471A52444009FEB7921DB748409E280989B44F444009FEB7921DB74840
56494	56954	40.292566999999998	40.309202999999997	49.433090999999997	49.425767999999998	Центральная	0103000020E61000000100000005000000C571E0D57225444077D7D9907FB64840C571E0D5722544409198A0866FB748409C69C2F6932744409198A0866FB748409C69C2F69327444077D7D9907FB64840C571E0D57225444077D7D9907FB64840
55680	3634	40.458207000000002	40.476317000000002	49.398771000000004	49.388199	Октябрьская	0103000020E610000001000000050000002EE6E786A63A444082AB3C81B0B148402EE6E786A63A4440EFCB99ED0AB34840B1C398F4F73C4440EFCB99ED0AB34840B1C398F4F73C444082AB3C81B0B148402EE6E786A63A444082AB3C81B0B14840
56402	56874	40.336951999999997	40.371051999999999	49.533031999999999	49.515331000000003	Лесная	0103000020E6100000010000000500000030293E3E212B4440B8CEBF5DF6C1484030293E3E212B444059DC7F643AC44840C58EC6A17E2F444059DC7F643AC44840C58EC6A17E2F4440B8CEBF5DF6C1484030293E3E212B4440B8CEBF5DF6C14840
56463	56928	40.394866999999998	40.410254999999999	49.395611000000002	49.385671000000002	Мира	0103000020E6100000010000000500000083A279008B3244400002D6AA5DB1484083A279008B3244400C789961A3B248409F02603C833444400C789961A3B248409F02603C833444400002D6AA5DB1484083A279008B3244400002D6AA5DB14840
55481	3994	40.66057	40.685713999999997	49.348759000000001	49.333326999999997	переулок Тихий	0103000020E61000000100000005000000FF5BC98E8D544440D8EF8975AAAA4840FF5BC98E8D544440C4978922A4AC48406534F279C5574440C4978922A4AC48406534F279C5574440D8EF8975AAAA4840FF5BC98E8D544440D8EF8975AAAA4840
56461	56927	40.825474	40.850968000000002	49.486159999999998	49.479188999999998	Центральная	0103000020E6100000010000000500000062D9CC21A96944402DCDAD1056BD484062D9CC21A9694440CA4FAA7D3ABE4840A5F8F884EC6C4440CA4FAA7D3ABE4840A5F8F884EC6C44402DCDAD1056BD484062D9CC21A96944402DCDAD1056BD4840
56354	56847	40.253517000000002	40.288981999999997	49.543883000000001	49.520097999999997	Полетаева	0103000020E6100000010000000500000072FDBB3E73204440855B3E9292C2484072FDBB3E73204440D9EC48F59DC54840FB90B75CFD244440D9EC48F59DC54840FB90B75CFD244440855B3E9292C2484072FDBB3E73204440855B3E9292C24840
56071	56808	41.002037999999999	41.044879000000002	49.379871000000001	49.367229999999999	Центральная	0103000020E61000000100000005000000B4ACFBC742804440170E846401AF4840B4ACFBC74280444073D9E89C9FB048407BA35698BE85444073D9E89C9FB048407BA35698BE854440170E846401AF4840B4ACFBC742804440170E846401AF4840
41174	3881	40.635120999999998	40.664766	49.418970000000002	49.367781999999998	Лисичкина	0103000020E610000001000000050000005C001AA54B5144405B07077B13AF48405C001AA54B514440A80018CFA0B5484012BF620D17554440A80018CFA0B5484012BF620D175544405B07077B13AF48405C001AA54B5144405B07077B13AF4840
55816	3881	40.635120999999998	40.664766	49.418970000000002	49.367781999999998	Кирова	0103000020E610000001000000050000005C001AA54B5144405B07077B13AF48405C001AA54B514440A80018CFA0B5484012BF620D17554440A80018CFA0B5484012BF620D175544405B07077B13AF48405C001AA54B5144405B07077B13AF4840
56408	56880	42.005825000000002	42.033250000000002	48.028405999999997	48.019922000000001	Центральная	0103000020E61000000100000005000000E63FA4DFBE004540473CD9CD8C024840E63FA4DFBE0045404D81CCCEA2034840C74B3789410445404D81CCCEA2034840C74B378941044540473CD9CD8C024840E63FA4DFBE004540473CD9CD8C024840
40230	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Советская	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
39692	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Победы	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
40060	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Набережная	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
40062	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Московская	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
55491	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Маяковского	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
40232	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Ломоносова	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
40486	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Ленина	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
40061	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Донская	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
55797	1189	42.045647000000002	42.117665000000002	47.666674	47.634922000000003	Артемова	0103000020E610000001000000050000008C14CAC2D705454066C1C41F45D147408C14CAC2D7054540F88BD99255D5474022718FA50F0F4540F88BD99255D5474022718FA50F0F454066C1C41F45D147408C14CAC2D705454066C1C41F45D14740
56286	11332	42.202635999999998	42.236826000000001	47.730271999999999	47.710656	Центральная	0103000020E61000000100000005000000027FF8F9EF194540645A9BC6F6DA4740027FF8F9EF1945409E978A8D79DD4740D76B7A50501E45409E978A8D79DD4740D76B7A50501E4540645A9BC6F6DA4740027FF8F9EF194540645A9BC6F6DA4740
56285	12014	42.146680000000003	42.179710999999998	47.780842	47.768954999999998	Центральная	0103000020E61000000100000005000000187D0569C61245403F8C101E6DE24740187D0569C6124540EFAB72A1F2E34740A0DD21C500174540EFAB72A1F2E34740A0DD21C5001745403F8C101E6DE24740187D0569C61245403F8C101E6DE24740
55535	11473	42.001314999999998	42.009148000000003	47.646991999999997	47.636823	Центральная	0103000020E6100000010000000500000043FF04172B004540992B836A83D1474043FF04172B004540066344A2D0D247407369FCC22B014540066344A2D0D247407369FCC22B014540992B836A83D1474043FF04172B004540992B836A83D14740
56473	56916	41.797649	41.809694999999998	47.776161000000002	47.769803000000003	Школьная	0103000020E61000000100000005000000F357C85C19E644406DAE9AE788E24740F357C85C19E6444020B75F3E59E347400B5EF415A4E7444020B75F3E59E347400B5EF415A4E744406DAE9AE788E24740F357C85C19E644406DAE9AE788E24740
40233	11104	42.146464999999999	42.162536000000003	47.684742	47.671146	Винзаводская	0103000020E610000001000000050000001B81785DBF124540AD6BB41CE8D547401B81785DBF1245404C1938A0A5D747401A36CAFACD1445404C1938A0A5D747401A36CAFACD144540AD6BB41CE8D547401B81785DBF124540AD6BB41CE8D54740
55895	56748	41.94782	41.975821000000003	47.788294	47.766683999999998	Мира	0103000020E61000000100000005000000533F6F2A52F94440E82E89B322E24740533F6F2A52F9444007D15AD1E6E4474001E0D8B3E7FC444007D15AD1E6E4474001E0D8B3E7FC4440E82E89B322E24740533F6F2A52F94440E82E89B322E24740
40490	12111	42.267395999999998	42.297956999999997	47.986426000000002	47.966002000000003	Мира	0103000020E61000000100000005000000658A39083A22454070EF1AF4A5FB4740658A39083A22454049F6083543FE4740A04E79742326454049F6083543FE4740A04E79742326454070EF1AF4A5FB4740658A39083A22454070EF1AF4A5FB4740
55834	11698	41.984948000000003	42.015346999999998	47.843676000000002	47.831204999999997	Ленина	0103000020E610000001000000050000005C21ACC612FE4440C6A2E9EC64EA47405C21ACC612FE4440C6353E93FDEB4740BD8BF7E3F6014540C6353E93FDEB4740BD8BF7E3F6014540C6A2E9EC64EA47405C21ACC612FE4440C6A2E9EC64EA4740
55290	56638	41.954234	41.990059000000002	47.636015	47.623742999999997	Советская	0103000020E610000001000000050000009A5DF75624FA4440F10D85CFD6CF47409A5DF75624FA4440FA6184F068D14740240ED940BAFE4440FA6184F068D14740240ED940BAFE4440F10D85CFD6CF47409A5DF75624FA4440F10D85CFD6CF4740
56268	11530	41.901746000000003	41.925389000000003	47.628771	47.614170999999999	Центральная	0103000020E6100000010000000500000040A6B5696CF344406893C3279DCE474040A6B5696CF344402CD670917BD04740018A912573F644402CD670917BD04740018A912573F644406893C3279DCE474040A6B5696CF344406893C3279DCE4740
56016	11914	41.973044999999999	41.982638999999999	47.744790999999999	47.733054000000003	Молодежная	0103000020E61000000100000005000000A64412BD8CFC4440DB19A6B6D4DD4740A64412BD8CFC444075ADBD4F55DF47401763601DC7FD444075ADBD4F55DF47401763601DC7FD4440DB19A6B6D4DD4740A64412BD8CFC4440DB19A6B6D4DD4740
39966	1066	42.030304000000001	42.071896000000002	47.669193	47.634326999999999	Победы	0103000020E6100000010000000500000010786000E103454022FC8BA031D1474010786000E103454027DBC01DA8D547404B5B5CE33309454027DBC01DA8D547404B5B5CE33309454022FC8BA031D1474010786000E103454022FC8BA031D14740
56455	56922	41.873699999999999	41.894199999999998	47.604183999999997	47.599086	Центральная	0103000020E61000000100000005000000F241CF66D5EF4440E8BE9CD9AECC4740F241CF66D5EF44401B62BCE655CD4740A60A462575F244401B62BCE655CD4740A60A462575F24440E8BE9CD9AECC4740F241CF66D5EF4440E8BE9CD9AECC4740
55538	11517	41.804152999999999	41.839978000000002	47.620590999999997	47.607112000000001	Победы	0103000020E610000001000000050000007AFD497CEEE644402C8194D8B5CD47407AFD497CEEE644409198A0866FCF474004AE2B6684EB44409198A0866FCF474004AE2B6684EB44402C8194D8B5CD47407AFD497CEEE644402C8194D8B5CD4740
55832	11977	42.21754	42.263345000000001	47.854970999999999	47.829813999999999	Театральный	0103000020E6100000010000000500000032C9C859D81B4540A8E15B5837EA474032C9C859D81B4540A30392B06FED47405648F949B5214540A30392B06FED47405648F949B5214540A8E15B5837EA474032C9C859D81B4540A8E15B5837EA4740
56554	57006	41.982298	41.993886000000003	47.939534999999999	47.931125999999999	Советская	0103000020E610000001000000050000008E76DCF0BBFD4440473A03232FF747408E76DCF0BBFD44404339D1AE42F84740E4F90CA837FF44404339D1AE42F84740E4F90CA837FF4440473A03232FF747408E76DCF0BBFD4440473A03232FF74740
55831	11397	41.977086999999997	41.997523999999999	47.681218000000001	47.667099	Садовая	0103000020E61000000100000005000000622CD32F11FD4440DF18028063D54740622CD32F11FD444028B9C32632D74740D07CCEDDAEFF444028B9C32632D74740D07CCEDDAEFF4440DF18028063D54740622CD32F11FD4440DF18028063D54740
55876	56731	42.140436999999999	42.159148999999999	47.880896	47.864505000000001	Центральная	0103000020E61000000100000005000000FD12F1D6F91145403F1D8F19A8EE4740FD12F1D6F9114540AF963B33C1F04740761893FE5E144540AF963B33C1F04740761893FE5E1445403F1D8F19A8EE4740FD12F1D6F91145403F1D8F19A8EE4740
55344	56656	40.704138999999998	41.33596	46.917597999999998	46.229301999999997	Транспортная	0103000020E61000000100000005000000486B0C3A215A4440257497C4591D4740486B0C3A215A44400070ECD973754740D061BEBC00AB44400070ECD973754740D061BEBC00AB4440257497C4591D4740486B0C3A215A4440257497C4591D4740
40956	9482	41.007015000000003	41.055802	46.540371	46.524456999999998	Степная	0103000020E610000001000000050000006DCA15DEE580444042942F68214347406DCA15DEE5804440795A7EE02A45474094861A8524874440795A7EE02A45474094861A852487444042942F68214347406DCA15DEE580444042942F6821434740
55343	9482	41.007015000000003	41.055802	46.540371	46.524456999999998	Советская	0103000020E610000001000000050000006DCA15DEE580444042942F68214347406DCA15DEE5804440795A7EE02A45474094861A8524874440795A7EE02A45474094861A852487444042942F68214347406DCA15DEE580444042942F6821434740
40227	9482	41.007015000000003	41.055802	46.540371	46.524456999999998	Механизаторов	0103000020E610000001000000050000006DCA15DEE580444042942F68214347406DCA15DEE5804440795A7EE02A45474094861A8524874440795A7EE02A45474094861A852487444042942F68214347406DCA15DEE580444042942F6821434740
40058	9482	41.007015000000003	41.055802	46.540371	46.524456999999998	Западная	0103000020E610000001000000050000006DCA15DEE580444042942F68214347406DCA15DEE5804440795A7EE02A45474094861A8524874440795A7EE02A45474094861A852487444042942F68214347406DCA15DEE580444042942F6821434740
41112	9482	41.007015000000003	41.055802	46.540371	46.524456999999998	3-я линия	0103000020E610000001000000050000006DCA15DEE580444042942F68214347406DCA15DEE5804440795A7EE02A45474094861A8524874440795A7EE02A45474094861A852487444042942F68214347406DCA15DEE580444042942F6821434740
55937	56786	40.885427999999997	40.906402999999997	46.702094000000002	46.687005999999997	Советская	0103000020E61000000100000005000000397B67B455714440F01307D0EF574740397B67B455714440E25B5837DE59474086FF740305744440E25B5837DE59474086FF740305744440F01307D0EF574740397B67B455714440F01307D0EF574740
55912	56764	40.827593999999998	40.844833000000001	46.691153999999997	46.668816	Центральная	0103000020E61000000100000005000000D32EA699EE69444051853FC39B554740D32EA699EE694440F23FF9BB7758474071CADC7C236C4440F23FF9BB7758474071CADC7C236C444051853FC39B554740D32EA699EE69444051853FC39B554740
39965	10255	41.031305000000003	41.087198000000001	46.632133000000003	46.619166999999997	Центральная	0103000020E61000000100000005000000C4995FCD0184444097E13FDD404F4740C4995FCD0184444077DCF0BBE95047406823D74D298B444077DCF0BBE95047406823D74D298B444097E13FDD404F4740C4995FCD0184444097E13FDD404F4740
56267	9949	40.888131999999999	40.894609000000003	46.493166000000002	46.482537000000001	Октябрьская	0103000020E61000000100000005000000FA43334FAE714440130EBDC5C33D4740FA43334FAE714440E4BF4010203F474088DA368C82724440E4BF4010203F474088DA368C82724440130EBDC5C33D4740FA43334FAE714440130EBDC5C33D4740
55715	9270	40.767659000000002	40.858325999999998	46.379038999999999	46.334927999999998	Школьная	0103000020E6100000010000000500000073BD6DA642624440E141B3EBDE2A474073BD6DA6426244404B749659843047403BA759A0DD6D44404B749659843047403BA759A0DD6D4440E141B3EBDE2A474073BD6DA642624440E141B3EBDE2A4740
55713	9270	40.767659000000002	40.858325999999998	46.379038999999999	46.334927999999998	Молодёжная	0103000020E6100000010000000500000073BD6DA642624440E141B3EBDE2A474073BD6DA6426244404B749659843047403BA759A0DD6D44404B749659843047403BA759A0DD6D4440E141B3EBDE2A474073BD6DA642624440E141B3EBDE2A4740
55872	56728	41.002110000000002	41.089892999999996	46.426504999999999	46.411079000000001	Центральная	0103000020E610000001000000050000004E7FF623458044404489963C9E3447404E7FF623458044404D4A41B797364740D591239D818B44404D4A41B797364740D591239D818B44404489963C9E3447404E7FF623458044404489963C9E344740
55533	9727	40.960006	40.999181	46.542943999999999	46.536987000000003	Мира	0103000020E610000001000000050000005DFB027AE17A444047B071FDBB4447405DFB027AE17A44409BC761307F4547406DE4BA29E57F44409BC761307F4547406DE4BA29E57F444047B071FDBB4447405DFB027AE17A444047B071FDBB444740
56272	9884	41.000996000000001	41.028188	46.496076000000002	46.484175	Зеленая	0103000020E61000000100000005000000A2B60DA32080444039454772F93D4740A2B60DA3208044404E2A1A6B7F3F4740E01115AA9B8344404E2A1A6B7F3F4740E01115AA9B83444039454772F93D4740A2B60DA32080444039454772F93D4740
56284	10405	41.230704000000003	41.238402999999998	46.743471999999997	46.741885000000003	Новая	0103000020E6100000010000000500000038876BB5879D44404D327216F65E474038876BB5879D4440F0BE2A172A5F4740572250FD839E4440F0BE2A172A5F4740572250FD839E44404D327216F65E474038876BB5879D44404D327216F65E4740
55597	10597	41.100349999999999	41.113402000000001	46.754722999999998	46.734375	Гагарина	0103000020E61000000100000005000000A913D044D88C444000000000005E4740A913D044D88C4440FE4465C39A60474087A6ECF4838E4440FE4465C39A60474087A6ECF4838E444000000000005E4740A913D044D88C444000000000005E4740
56490	56950	40.827522000000002	40.836353000000003	46.443323999999997	46.438648000000001	Центральная	0103000020E610000001000000050000003A5CAB3DEC694440583A1F9E253847403A5CAB3DEC69444015C440D7BE384740AC74779D0D6B444015C440D7BE384740AC74779D0D6B4440583A1F9E253847403A5CAB3DEC694440583A1F9E25384740
40229	10505	40.938544999999998	40.955218000000002	46.849767999999997	46.832317000000003	Торговая	0103000020E610000001000000050000008369183E22784440D2730B5D896A47408369183E22784440FA97A432C56C474078465B95447A4440FA97A432C56C474078465B95447A4440D2730B5D896A47408369183E22784440D2730B5D896A4740
55799	948	41.010860000000001	41.055442999999997	46.548124999999999	46.537909999999997	Макаренко	0103000020E61000000100000005000000D36A48DC638144407E18213CDA444740D36A48DC638144405C8FC2F52846474064E597C1188744405C8FC2F52846474064E597C1188744407E18213CDA444740D36A48DC638144407E18213CDA444740
40228	948	41.010860000000001	41.055442999999997	46.548124999999999	46.537909999999997	Ленина	0103000020E61000000100000005000000D36A48DC638144407E18213CDA444740D36A48DC638144405C8FC2F52846474064E597C1188744405C8FC2F52846474064E597C1188744407E18213CDA444740D36A48DC638144407E18213CDA444740
55593	10500	40.989659000000003	41.011541999999999	46.710115000000002	46.699973999999997	Крупской	0103000020E6100000010000000500000096986725AD7E444070067FBF9859474096986725AD7E444014B35E0CE55A4740E54350357A81444014B35E0CE55A4740E54350357A81444070067FBF9859474096986725AD7E444070067FBF98594740
55534	10189	40.943674999999999	40.999181	46.422696999999999	46.390197000000001	Молодежная	0103000020E61000000100000005000000C286A757CA784440A8FFACF9F1314740C286A757CA784440048F6FEF1A3647406DE4BA29E57F4440048F6FEF1A3647406DE4BA29E57F4440A8FFACF9F1314740C286A757CA784440A8FFACF9F1314740
55724	10189	40.943674999999999	40.999181	46.422696999999999	46.390197000000001	Красная	0103000020E61000000100000005000000C286A757CA784440A8FFACF9F1314740C286A757CA784440048F6FEF1A3647406DE4BA29E57F4440048F6FEF1A3647406DE4BA29E57F4440A8FFACF9F1314740C286A757CA784440A8FFACF9F1314740
56365	996	40.969276999999998	40.978008000000003	46.589108000000003	46.572972999999998	Виноградная	0103000020E61000000100000005000000EBE1CB44117C4440D93EE42D57494740EBE1CB44117C4440EFE714E4674B4740FA9CBB5D2F7D4440EFE714E4674B4740FA9CBB5D2F7D4440D93EE42D57494740EBE1CB44117C4440D93EE42D57494740
55830	10339	41.121262000000002	41.125889000000001	46.505982000000003	46.500672000000002	Абрикосовая	0103000020E61000000100000005000000B01F6283858F4440EF02250516404740B01F6283858F4440AE2EA704C44047408CF678211D904440AE2EA704C44047408CF678211D904440EF02250516404740B01F6283858F4440EF02250516404740
55829	10564	41.079023999999997	41.095247000000001	46.847037	46.821964999999999	Центральная	0103000020E61000000100000005000000AFCC5B751D8A444073BA2C2636694740AFCC5B751D8A444040C05AB56B6C47406405BF0D318C444040C05AB56B6C47406405BF0D318C444073BA2C2636694740AFCC5B751D8A444073BA2C2636694740
9726	9938	40.910096000000003	40.948884999999997	46.489027999999998	46.473737	Гусева	0103000020E61000000100000005000000371C96067E744440DCF3FC69A33C4740371C96067E744440056A3178983E47401D554D1075794440056A3178983E47401D554D1075794440DCF3FC69A33C4740371C96067E744440DCF3FC69A33C4740
56018	9999	40.843054000000002	40.858460000000001	46.655419999999999	46.635029000000003	пер. Школьный	0103000020E6100000010000000500000089618731E96B44407C8159A14851474089618731E96B4440799274CDE45347404B766C04E26D4440799274CDE45347404B766C04E26D44407C8159A14851474089618731E96B44407C8159A148514740
56334	24678	40.894860000000001	40.904139999999998	47.760838999999997	47.749735000000001	Центральная	0103000020E61000000100000005000000D13FC1C58A72444052D50451F7DF4740D13FC1C58A724440BB421F2C63E14740B28009DCBA734440BB421F2C63E14740B28009DCBA73444052D50451F7DF4740D13FC1C58A72444052D50451F7DF4740
55156	2399	40.859431000000001	40.888733999999999	47.648114999999997	47.637611999999997	переулок Почтовый	0103000020E610000001000000050000009415C3D5016E4440C1C41F459DD147409415C3D5016E44400586AC6EF5D24740F06B2409C27144400586AC6EF5D24740F06B2409C2714440C1C41F459DD147409415C3D5016E4440C1C41F459DD14740
40118	2399	40.859431000000001	40.888733999999999	47.648114999999997	47.637611999999997	Ленина	0103000020E610000001000000050000009415C3D5016E4440C1C41F459DD147409415C3D5016E44400586AC6EF5D24740F06B2409C27144400586AC6EF5D24740F06B2409C2714440C1C41F459DD147409415C3D5016E4440C1C41F459DD14740
40117	2399	40.859431000000001	40.888733999999999	47.648114999999997	47.637611999999997	Донецкая	0103000020E610000001000000050000009415C3D5016E4440C1C41F459DD147409415C3D5016E44400586AC6EF5D24740F06B2409C27144400586AC6EF5D24740F06B2409C2714440C1C41F459DD147409415C3D5016E4440C1C41F459DD14740
40212	24899	41.005164000000001	41.054445999999999	47.838959000000003	47.803179	Центральная	0103000020E61000000100000005000000EB8EC536A9804440C0EAC891CEE64740EB8EC536A9804440AAD72D0263EB4740F2B22616F8864440AAD72D0263EB4740F2B22616F8864440C0EAC891CEE64740EB8EC536A9804440C0EAC891CEE64740
56218	24850	40.800429000000001	40.824558000000003	47.836775000000003	47.824604999999998	Калинина	0103000020E610000001000000050000008FE21C75746644401D8F19A88CE947408FE21C7574664440228E75711BEB4740DDD3D51D8B694440228E75711BEB4740DDD3D51D8B6944401D8F19A88CE947408FE21C75746644401D8F19A88CE94740
39910	2345	40.634546	40.668529999999997	47.553221999999998	47.531525000000002	Ленина	0103000020E6100000010000000500000060E7A6CD38514440D200DE0209C4474060E7A6CD38514440BFB67EFACFC647408B321B6492554440BFB67EFACFC647408B321B6492554440D200DE0209C4474060E7A6CD38514440D200DE0209C44740
39709	23972	40.571376999999998	40.605342	47.519143	47.510556000000001	Центральная	0103000020E61000000100000005000000E257ACE122494440676325E659C14740E257ACE12249444042791F4773C247409772BED87B4D444042791F4773C247409772BED87B4D4440676325E659C14740E257ACE122494440676325E659C14740
55999	24116	40.695397999999997	40.714073999999997	47.649698999999998	47.631473	 Центральная	0103000020E6100000010000000500000016DA39CD025944404CA7751BD4D0474016DA39CD02594440389F3A5629D347404276DEC6665B4440389F3A5629D347404276DEC6665B44404CA7751BD4D0474016DA39CD025944404CA7751BD4D04740
39911	24575	40.933568000000001	40.960428	47.758246	47.742252000000001	Советская	0103000020E61000000100000005000000CB4BFE277F774440FFB1101D02DF4740CB4BFE277F774440522976340EE14740D314014EEF7A4440522976340EE14740D314014EEF7A4440FFB1101D02DF4740CB4BFE277F774440FFB1101D02DF4740
56335	24766	40.807274	40.824468000000003	47.803536000000001	47.794814000000002	Донская	0103000020E610000001000000050000009F7422C15467444094331477BCE547409F7422C1546744404F948444DAE647409D4CDC2A886944404F948444DAE647409D4CDC2A8869444094331477BCE547409F7422C15467444094331477BCE54740
40578	23858	40.468879000000001	40.516345999999999	47.489595999999999	47.465173999999998	Мерзлякова	0103000020E61000000100000005000000FE63213A043C4440897956D28ABB4740FE63213A043C44404F20EC14ABBE4740D0B52FA0174244404F20EC14ABBE4740D0B52FA017424440897956D28ABB4740FE63213A043C4440897956D28ABB4740
40211	23858	40.468879000000001	40.516345999999999	47.489595999999999	47.465173999999998	Интернациональная	0103000020E61000000100000005000000FE63213A043C4440897956D28ABB4740FE63213A043C44404F20EC14ABBE4740D0B52FA0174244404F20EC14ABBE4740D0B52FA017424440897956D28ABB4740FE63213A043C4440897956D28ABB4740
55650	24212	40.763193999999999	40.782553	47.677359000000003	47.659931999999998	Центральная	0103000020E6100000010000000500000070404B57B0614440BCCADAA678D4474070404B57B06144405D5320B3B3D647407F315BB22A6444405D5320B3B3D647407F315BB22A644440BCCADAA678D4474070404B57B0614440BCCADAA678D44740
32952	24071	40.684995999999998	40.698945999999999	47.595512999999997	47.585504	Шубина	0103000020E6100000010000000500000006F2ECF2AD574440AED689CBF1CA474006F2ECF2AD574440E2AB1DC539CC4740C3D5011077594440E2AB1DC539CC4740C3D5011077594440AED689CBF1CA474006F2ECF2AD574440AED689CBF1CA4740
55636	23800	40.448962999999999	40.460614	47.515315000000001	47.504707000000003	Виноградная	0103000020E61000000100000005000000990E9D9E77394440F9872D3D9AC04740990E9D9E77394440B21188D7F5C14740350A4966F53A4440B21188D7F5C14740350A4966F53A4440F9872D3D9AC04740990E9D9E77394440F9872D3D9AC04740
56384	56858	40.459932000000002	40.471358000000002	47.543284	47.529474999999998	Центральная	0103000020E610000001000000050000002331410DDF3A4440598638D6C5C347402331410DDF3A4440543882548AC547409F5A7D75553C4440543882548AC547409F5A7D75553C4440598638D6C5C347402331410DDF3A4440598638D6C5C34740
56144	24379	40.816355999999999	40.831116000000002	47.662117000000002	47.652455000000003	Гагарина	0103000020E610000001000000050000005AF2785A7E6844404C8E3BA583D347405AF2785A7E6844401590F63FC0D4474057975302626A44401590F63FC0D4474057975302626A44404C8E3BA583D347405AF2785A7E6844404C8E3BA583D34740
56340	24823	40.784277000000003	40.803564000000001	47.834138000000003	47.821174999999997	Школьная	0103000020E61000000100000005000000A4005130636444407AA52C431CE94740A400513063644440E92CB308C5EA4740191F662FDB664440E92CB308C5EA4740191F662FDB6644407AA52C431CE94740A4005130636444407AA52C431CE94740
56080	24145	40.711981000000002	40.725375	47.657170999999998	47.649904999999997	Большая Садовая	0103000020E61000000100000005000000CB2F8331225B4440E140481630D34740CB2F8331225B44409770E82D1ED44740022B8716D95C44409770E82D1ED44740022B8716D95C4440E140481630D34740CB2F8331225B4440E140481630D34740
55655	24693	40.835912999999998	40.855262000000003	47.791956999999996	47.765332999999998	Центральная	0103000020E610000001000000050000008FA67A32FF6A444058C6866EF6E147408FA67A32FF6A44404C6BD3D85EE547407BC1A739796D44404C6BD3D85EE547407BC1A739796D444058C6866EF6E147408FA67A32FF6A444058C6866EF6E14740
56336	2462	40.923462000000001	40.939399000000002	47.689084999999999	47.672463	Толстого	0103000020E61000000100000005000000A48CB800347644409162804413D64740A48CB800347644400395F1EF33D847409372F7393E7844400395F1EF33D847409372F7393E7844409162804413D64740A48CB800347644409162804413D64740
41093	24481	40.901535000000003	40.935608000000002	47.671515999999997	47.651865999999998	Комсомольская	0103000020E610000001000000050000008599B67F65734440EAAF575870D347408599B67F65734440D05E7D3CF4D5474020F0C000C2774440D05E7D3CF4D5474020F0C000C2774440EAAF575870D347408599B67F65734440EAAF575870D34740
56577	24481	40.901535000000003	40.935608000000002	47.671515999999997	47.651865999999998	Гагарина	0103000020E610000001000000050000008599B67F65734440EAAF575870D347408599B67F65734440D05E7D3CF4D5474020F0C000C2774440D05E7D3CF4D5474020F0C000C2774440EAAF575870D347408599B67F65734440EAAF575870D34740
56137	30583	41.369942999999999	41.380094	47.889682000000001	47.881416000000002	Советская	0103000020E610000001000000050000002B31CF4A5AAF4440E8154F3DD2F047402B31CF4A5AAF444081EB8A19E1F14740F2B391EBA6B0444081EB8A19E1F14740F2B391EBA6B04440E8154F3DD2F047402B31CF4A5AAF4440E8154F3DD2F04740
41171	515	41.247107	41.269511000000001	48.247135	48.235481	Школьный переулок	0103000020E610000001000000050000006CCEC133A19F444029EACC3D241E48406CCEC133A19F44403659A31EA21F4840C57421567FA244403659A31EA21F4840C57421567FA2444029EACC3D241E48406CCEC133A19F444029EACC3D241E4840
41170	91	41.214255999999999	41.327713000000003	48.207856	48.182203999999999	площадь Калинина	0103000020E61000000100000005000000637C98BD6C9B4440A699EE7552174840637C98BD6C9B4440812381069B1A4840AEBCE47FF2A94440812381069B1A4840AEBCE47FF2A94440A699EE7552174840637C98BD6C9B4440A699EE7552174840
40144	91	41.214255999999999	41.327713000000003	48.207856	48.182203999999999	Соревнования переулок	0103000020E61000000100000005000000637C98BD6C9B4440A699EE7552174840637C98BD6C9B4440812381069B1A4840AEBCE47FF2A94440812381069B1A4840AEBCE47FF2A94440A699EE7552174840637C98BD6C9B4440A699EE7552174840
39988	91	41.214255999999999	41.327713000000003	48.207856	48.182203999999999	Пионерский переулок	0103000020E61000000100000005000000637C98BD6C9B4440A699EE7552174840637C98BD6C9B4440812381069B1A4840AEBCE47FF2A94440812381069B1A4840AEBCE47FF2A94440A699EE7552174840637C98BD6C9B4440A699EE7552174840
55239	91	41.214255999999999	41.327713000000003	48.207856	48.182203999999999	Октябрьская	0103000020E61000000100000005000000637C98BD6C9B4440A699EE7552174840637C98BD6C9B4440812381069B1A4840AEBCE47FF2A94440812381069B1A4840AEBCE47FF2A94440A699EE7552174840637C98BD6C9B4440A699EE7552174840
55567	91	41.214255999999999	41.327713000000003	48.207856	48.182203999999999	Ленина	0103000020E61000000100000005000000637C98BD6C9B4440A699EE7552174840637C98BD6C9B4440812381069B1A4840AEBCE47FF2A94440812381069B1A4840AEBCE47FF2A94440A699EE7552174840637C98BD6C9B4440A699EE7552174840
55569	997	41.294134	41.318784000000001	48.417437999999997	48.408019000000003	Школьная	0103000020E610000001000000050000002252D32EA6A54440C59272F7393448402252D32EA6A54440C70DBF9B6E354840793E03EACDA84440C70DBF9B6E354840793E03EACDA84440C59272F7393448402252D32EA6A54440C59272F739344840
56231	708	41.153089999999999	41.166412000000001	48.288666999999997	48.281753999999999	Школьный переулок	0103000020E610000001000000050000001DACFF739893444033C2DB83102448401DACFF73989344409B374E0AF3244840BBD408FD4C9544409B374E0AF3244840BBD408FD4C95444033C2DB83102448401DACFF739893444033C2DB8310244840
55740	1413	41.393973000000003	41.421165000000002	48.125545000000002	48.110621000000002	Административная	0103000020E61000000100000005000000E6400FB56DB244401BA034D4280E4840E6400FB56DB244409296CADB11104840249C16BCE8B544409296CADB11104840249C16BCE8B544401BA034D4280E4840E6400FB56DB244401BA034D4280E4840
56201	1575	41.349435	41.368667000000002	47.924942999999999	47.900877000000001	Молодежная	0103000020E61000000100000005000000F4893C49BAAC4440FB5B02F04FF34740F4893C49BAAC444002D53F8864F64740A60EF27A30AF444002D53F8864F64740A60EF27A30AF4440FB5B02F04FF34740F4893C49BAAC4440FB5B02F04FF34740
56232	947	41.221856000000002	41.252353999999997	48.408444000000003	48.395536	Заводская	0103000020E61000000100000005000000F03504C7659C4440013274ECA0324840F03504C7659C4440AC1F9BE447344840E481C8224DA04440AC1F9BE447344840E481C8224DA04440013274ECA0324840F03504C7659C4440013274ECA0324840
40564	762	41.159835999999999	41.195974999999997	48.254136000000003	48.223945999999998	Ленина	0103000020E610000001000000050000009A5C8C8175944440F6083543AA1C48409A5C8C81759444403E5E488787204840B3EA73B5159944403E5E488787204840B3EA73B515994440F6083543AA1C48409A5C8C8175944440F6083543AA1C4840
55574	762	41.159835999999999	41.195974999999997	48.254136000000003	48.223945999999998	Клубная	0103000020E610000001000000050000009A5C8C8175944440F6083543AA1C48409A5C8C81759444403E5E488787204840B3EA73B5159944403E5E488787204840B3EA73B515994440F6083543AA1C48409A5C8C8175944440F6083543AA1C4840
55958	588	41.142435999999996	41.163268000000002	48.322856999999999	48.310496000000001	Школьная	0103000020E61000000100000005000000F3E2C4573B924440F8C43A55BE274840F3E2C4573B9244407024D06053294840DE3D40F7E59444407024D06053294840DE3D40F7E5944440F8C43A55BE274840F3E2C4573B924440F8C43A55BE274840
56350	1246	41.393793000000002	41.423797	48.305432000000003	48.296987999999999	Молодежная	0103000020E6100000010000000500000066321CCF67B24440F8A6E9B30326484066321CCF67B2444071935165182748404B92E7FA3EB6444071935165182748404B92E7FA3EB64440F8A6E9B30326484066321CCF67B24440F8A6E9B303264840
55676	878	41.232115	41.256287999999998	48.369534999999999	48.347444000000003	Ленина	0103000020E610000001000000050000009DF4BEF1B59D44408198840B792C48409DF4BEF1B59D44401ADD41EC4C2F4840BA2D910BCEA044401ADD41EC4C2F4840BA2D910BCEA044408198840B792C48409DF4BEF1B59D44408198840B792C4840
55563	1348	41.510727000000003	41.552705000000003	48.147835000000001	48.134247000000002	Центральная	0103000020E61000000100000005000000941799805FC14440064B75012F114840941799805FC14440221ADD41EC124840F8AA9509BFC64440221ADD41EC124840F8AA9509BFC64440064B75012F114840941799805FC14440064B75012F114840
55737	1307	41.464948999999997	41.485143000000001	48.251376	48.237287999999999	Мира	0103000020E6100000010000000500000069A7E67283BB4440DBDD03745F1E484069A7E67283BB4440E97FB9162D2048401171732A19BE4440E97FB9162D2048401171732A19BE4440DBDD03745F1E484069A7E67283BB4440DBDD03745F1E4840
55777	1073	41.394044999999998	41.415838000000001	48.467953999999999	48.456721999999999	Харченко	0103000020E610000001000000050000007F130A1170B244408EAED2DD753A48407F130A1170B244402504ABEAE53B48408F37F92D3AB544402504ABEAE53B48408F37F92D3AB544408EAED2DD753A48407F130A1170B244408EAED2DD753A4840
56229	641	41.127290000000002	41.147959999999998	48.291065000000003	48.275123000000001	Розы Люксембург	0103000020E61000000100000005000000CE8DE9094B9044404FB0FF3A37234840CE8DE9094B9044405001309E41254840DE8E705AF09244405001309E41254840DE8E705AF09244404FB0FF3A37234840CE8DE9094B9044404FB0FF3A37234840
55734	194	41.099944999999998	41.122089000000003	48.092835000000001	48.074506	Южный переулок	0103000020E6100000010000000500000009336DFFCA8C44408AADA0698909484009336DFFCA8C44404B766C04E20B4840C619C39CA08F44404B766C04E20B4840C619C39CA08F44408AADA0698909484009336DFFCA8C44408AADA06989094840
55581	1535	41.513601999999999	41.541279000000003	47.996062000000002	47.973205	Центральная	0103000020E610000001000000050000008194D8B5BDC14440DFA63FFB91FC47408194D8B5BDC14440E964A9F57EFF47407C8159A148C54440E964A9F57EFF47407C8159A148C54440DFA63FFB91FC47408194D8B5BDC14440DFA63FFB91FC4740
55160	56616	41.037773000000001	41.683301999999998	48.554696999999997	47.853580999999998	П. Морозова	0103000020E61000000100000005000000FED5E3BED584444055BE672442ED4740FED5E3BED58444403B18B14F004748404CA59F7076D744403B18B14F004748404CA59F7076D7444055BE672442ED4740FED5E3BED584444055BE672442ED4740
55305	56616	41.037773000000001	41.683301999999998	48.554696999999997	47.853580999999998	Островского переулок	0103000020E61000000100000005000000FED5E3BED584444055BE672442ED4740FED5E3BED58444403B18B14F004748404CA59F7076D744403B18B14F004748404CA59F7076D7444055BE672442ED4740FED5E3BED584444055BE672442ED4740
55432	54931	41.096918000000002	41.149487999999998	48.182665999999998	48.148003000000003	Театральная	0103000020E6100000010000000500000066321CCF678C4440DE5A26C3F112484066321CCF678C4440AA0B7899611748407D923B6C22934440AA0B7899611748407D923B6C22934440DE5A26C3F112484066321CCF678C4440DE5A26C3F1124840
55562	1696	41.255552000000002	41.314948000000001	48.049835000000002	48.036124999999998	Молодежная	0103000020E61000000100000005000000B5368DEDB5A04440B4C876BE9F044840B5368DEDB5A044401C9947FE6006484066F84F3750A844401C9947FE6006484066F84F3750A84440B4C876BE9F044840B5368DEDB5A04440B4C876BE9F044840
55682	1186	41.454689999999999	41.492517999999997	48.398705999999997	48.384622999999998	Советская	0103000020E61000000100000005000000BCE82B4833BA44400B2593533B314840BCE82B4833BA4440075C57CC083348407D586FD40ABF4440075C57CC083348407D586FD40ABF44400B2593533B314840BCE82B4833BA44400B2593533B314840
56046	1650	41.320715	41.345903999999997	48.049425999999997	48.033901999999998	Мира	0103000020E61000000100000005000000172B6A300DA944406EA296E656044840172B6A300DA944403AC95697530648401DC70F9546AC44403AC95697530648401DC70F9546AC44406EA296E656044840172B6A300DA944406EA296E656044840
39936	458	41.126607	41.154508999999997	48.216994	48.182552000000001	Космонавтов	0103000020E61000000100000005000000EB387EA834904440E2E82ADD5D174840EB387EA834904440D0B69A75C61B484005F86EF3C6934440D0B69A75C61B484005F86EF3C6934440E2E82ADD5D174840EB387EA834904440E2E82ADD5D174840
41168	458	41.126607	41.154508999999997	48.216994	48.182552000000001	Волгодонская	0103000020E61000000100000005000000EB387EA834904440E2E82ADD5D174840EB387EA834904440D0B69A75C61B484005F86EF3C6934440D0B69A75C61B484005F86EF3C6934440E2E82ADD5D174840EB387EA834904440E2E82ADD5D174840
56233	1458	41.534109999999998	41.565640999999999	48.058616000000001	48.032353000000001	70 лет Октября	0103000020E61000000100000005000000B83B6BB75DC44440B876A22424044840B83B6BB75DC44440DC82A5BA800748406C239EEC66C84440DC82A5BA800748406C239EEC66C84440B876A22424044840B83B6BB75DC44440B876A22424044840
56432	56898	40.971361000000002	41.004041000000001	48.594804000000003	48.576126000000002	Ленина	0103000020E6100000010000000500000010CEA78E557C44400A302C7FBE49484010CEA78E557C4440D7C39789224C4840EC6B5D6A84804440D7C39789224C4840EC6B5D6A848044400A302C7FBE49484010CEA78E557C44400A302C7FBE494840
56567	57016	39.979171000000001	40.005654	48.660136000000001	48.639868	Центральная	0103000020E610000001000000050000008718AF7955FD4340E3E0D231E75148408718AF7955FD4340C57421567F544840B98B3045B9004440C57421567F544840B98B3045B9004440E3E0D231E75148408718AF7955FD4340E3E0D231E7514840
56403	56875	39.784461999999998	39.808348000000002	48.805788999999997	48.781989000000003	Заречная	0103000020E61000000100000005000000357A354069E44340776A2E3718644840357A354069E44340FF3C0D1824674840BDE47FF277E74340FF3C0D1824674840BDE47FF277E74340776A2E3718644840357A354069E44340776A2E3718644840
40260	30874	40.322426999999998	40.399375999999997	48.761158999999999	48.718184000000001	Степная	0103000020E61000000100000005000000772CB6494529444057410C74ED5B4840772CB649452944402D077AA86D6148405567B5C01E3344402D077AA86D6148405567B5C01E33444057410C74ED5B4840772CB6494529444057410C74ED5B4840
40093	30874	40.322426999999998	40.399375999999997	48.761158999999999	48.718184000000001	Победы	0103000020E61000000100000005000000772CB6494529444057410C74ED5B4840772CB649452944402D077AA86D6148405567B5C01E3344402D077AA86D6148405567B5C01E33444057410C74ED5B4840772CB6494529444057410C74ED5B4840
39987	30874	40.322426999999998	40.399375999999997	48.761158999999999	48.718184000000001	Островского	0103000020E61000000100000005000000772CB6494529444057410C74ED5B4840772CB649452944402D077AA86D6148405567B5C01E3344402D077AA86D6148405567B5C01E33444057410C74ED5B4840772CB6494529444057410C74ED5B4840
55779	30874	40.322426999999998	40.399375999999997	48.761158999999999	48.718184000000001	Мира	0103000020E61000000100000005000000772CB6494529444057410C74ED5B4840772CB649452944402D077AA86D6148405567B5C01E3344402D077AA86D6148405567B5C01E33444057410C74ED5B4840772CB6494529444057410C74ED5B4840
55620	30874	40.322426999999998	40.399375999999997	48.761158999999999	48.718184000000001	Ленина	0103000020E61000000100000005000000772CB6494529444057410C74ED5B4840772CB649452944402D077AA86D6148405567B5C01E3344402D077AA86D6148405567B5C01E33444057410C74ED5B4840772CB6494529444057410C74ED5B4840
55621	30874	40.322426999999998	40.399375999999997	48.761158999999999	48.718184000000001	Грибоедова	0103000020E61000000100000005000000772CB6494529444057410C74ED5B4840772CB649452944402D077AA86D6148405567B5C01E3344402D077AA86D6148405567B5C01E33444057410C74ED5B4840772CB6494529444057410C74ED5B4840
56445	56912	40.930649000000003	40.964021000000002	48.688758	48.677003999999997	Дорожная	0103000020E610000001000000050000000E87A5811F7744406EA12B11A85648400E87A5811F774440DF6DDE382958484020D4450A657B4440DF6DDE382958484020D4450A657B44406EA12B11A85648400E87A5811F7744406EA12B11A8564840
56487	56947	40.454523999999999	40.542011000000002	48.767425000000003	48.744129000000001	Советская	0103000020E61000000100000005000000A19FA9D72D3A4440AA807B9E3F5F4840A19FA9D72D3A444000917EFB3A6248404089CF9D6045444000917EFB3A6248404089CF9D60454440AA807B9E3F5F4840A19FA9D72D3A4440AA807B9E3F5F4840
56391	56864	39.791809999999998	39.872990999999999	48.777363999999999	48.746589	Южная	0103000020E61000000100000005000000A852B3075AE54340D446753A905F4840A852B3075AE543403B8BDEA980634840E659492BBEEF43403B8BDEA980634840E659492BBEEF4340D446753A905F4840A852B3075AE54340D446753A905F4840
56224	56826	40.691194000000003	40.735418000000003	48.659545999999999	48.645826999999997	Новоалексеевская	0103000020E610000001000000050000008198840B79584440D8EF8975AA5248408198840B79584440931ADA006C544840E371512D225E4440931ADA006C544840E371512D225E4440D8EF8975AA5248408198840B79584440D8EF8975AA524840
56204	30769	40.310685999999997	40.339575000000004	48.735531999999999	48.723526999999997	Школьная	0103000020E610000001000000050000009BA9108FC4274440F16261889C5C48409BA9108FC4274440AB949EE9255E484005C58F31772B4440AB949EE9255E484005C58F31772B4440F16261889C5C48409BA9108FC4274440F16261889C5C4840
56070	56807	40.003335999999997	40.088684999999998	48.737237	48.660356	Правобережная	0103000020E61000000100000005000000217365506D004440D3DB9F8B86544840217365506D004440593332C85D5E4840A852B3075A0B4440593332C85D5E4840A852B3075A0B4440D3DB9F8B86544840217365506D004440D3DB9F8B86544840
56462	56807	40.003335999999997	40.088684999999998	48.737237	48.660356	Левобережная	0103000020E61000000100000005000000217365506D004440D3DB9F8B86544840217365506D004440593332C85D5E4840A852B3075A0B4440593332C85D5E4840A852B3075A0B4440D3DB9F8B86544840217365506D004440D3DB9F8B86544840
56453	56920	40.955047	40.978501999999999	48.793498999999997	48.775530000000003	Садовая	0103000020E610000001000000050000004B92E7FA3E7A444090882991446348404B92E7FA3E7A444050340F60916548400989B48D3F7D444050340F60916548400989B48D3F7D444090882991446348404B92E7FA3E7A44409088299144634840
55933	56782	39.729754	39.785682999999999	48.778457000000003	48.729899000000003	Центральная	0103000020E6100000010000000500000006103E9468DD43400A3197546D5D484006103E9468DD4340D02B9E7AA4634840F702B34291E44340D02B9E7AA4634840F702B34291E443400A3197546D5D484006103E9468DD43400A3197546D5D4840
55776	30231	39.742545999999997	39.810144000000001	48.621087000000003	48.603943999999998	Менжинского	0103000020E6100000010000000500000047E350BF0BDF4340C64E78094E4D484047E350BF0BDF4340427C60C77F4F48407B8670CCB2E74340427C60C77F4F48407B8670CCB2E74340C64E78094E4D484047E350BF0BDF4340C64E78094E4D4840
55603	30231	39.742545999999997	39.810144000000001	48.621087000000003	48.603943999999998	Лесхозный	0103000020E6100000010000000500000047E350BF0BDF4340C64E78094E4D484047E350BF0BDF4340427C60C77F4F48407B8670CCB2E74340427C60C77F4F48407B8670CCB2E74340C64E78094E4D484047E350BF0BDF4340C64E78094E4D4840
56235	56829	40.600301999999999	40.686819	48.663854999999998	48.646065	 пер. Советский	0103000020E6100000010000000500000098DC28B2D64C44408D0B0742B252484098DC28B2D64C44409E245D33F9544840BEA25BAFE95744409E245D33F9544840BEA25BAFE95744408D0B0742B252484098DC28B2D64C44408D0B0742B2524840
56351	31381	40.214691999999999	40.224941000000001	48.662337000000001	48.653869	Центральная	0103000020E610000001000000050000003E5B07077B1B4440226FB9FAB15348403E5B07077B1B444023F77475C7544840C843DFDDCA1C444023F77475C7544840C843DFDDCA1C4440226FB9FAB15348403E5B07077B1B4440226FB9FAB1534840
56549	57001	40.623882999999999	40.680782999999998	48.697066	48.674397999999997	Молодежная	0103000020E61000000100000005000000E3C3EC65DB4F4440703E75AC52564840E3C3EC65DB4F4440A7936C75395948401D56B8E523574440A7936C75395948401D56B8E523574440703E75AC52564840E3C3EC65DB4F4440703E75AC52564840
56361	56850	40.086044000000001	40.108592000000002	48.82647	48.809029000000002	Героев	0103000020E610000001000000050000002E02637D030B4440FF4124438E6748402E02637D030B44400490DAC4C9694840BA4DB857E60D44400490DAC4C9694840BA4DB857E60D4440FF4124438E6748402E02637D030B4440FF4124438E674840
56400	56872	40.294561000000002	40.331473000000003	48.710076000000001	48.660314	Центральная	0103000020E61000000100000005000000AAD6C22CB4254440A48B4D2B85544840AAD6C22CB425444056D636C5E35A4840E6400FB56D2A444056D636C5E35A4840E6400FB56D2A4440A48B4D2B85544840AAD6C22CB4254440A48B4D2B85544840
56097	30284	40.773434999999999	40.784511000000002	48.649053000000002	48.645713999999998	Южная	0103000020E61000000100000005000000774A07EBFF624440E048A0C1A6524840774A07EBFF624440732F302B14534840172D40DB6A644440732F302B14534840172D40DB6A644440E048A0C1A6524840774A07EBFF624440E048A0C1A6524840
55885	56738	39.953344999999999	40.004297000000001	48.633229999999998	48.600476999999998	Центральная	0103000020E610000001000000050000000E677E3507FA434006802A6EDC4C48400E677E3507FA43404C6C3EAE0D514840473CD9CD8C0044404C6C3EAE0D514840473CD9CD8C00444006802A6EDC4C48400E677E3507FA434006802A6EDC4C4840
55873	56729	40.805656999999997	40.851714000000001	48.738264999999998	48.693027999999998	Новая	0103000020E610000001000000050000009065C1C41F6744402C9B3924B55848409065C1C41F6744400664AF777F5E4840CEC5DFF6046D44400664AF777F5E4840CEC5DFF6046D44402C9B3924B55848409065C1C41F6744402C9B3924B5584840
56558	57010	40.565564999999999	40.582354000000002	48.600185000000003	48.572173999999997	Школьная	0103000020E610000001000000050000009161156F644844408DCF64FF3C4948409161156F644844405F46B1DCD24C4840EF586C938A4A44405F46B1DCD24C4840EF586C938A4A44408DCF64FF3C4948409161156F644844408DCF64FF3C494840
56418	56889	39.749355000000001	39.804251000000001	48.698047000000003	48.676515999999999	Круглая	0103000020E610000001000000050000000B0C59DDEADF4340419C8713985648400B0C59DDEADF43401409A69A595948403D635FB2F1E643401409A69A595948403D635FB2F1E64340419C8713985648400B0C59DDEADF4340419C871398564840
56395	56867	40.577755000000003	40.594400999999998	48.641077000000003	48.623958000000002	Ленина	0103000020E61000000100000005000000DD0C37E0F3494440EE0912DBDD4F4840DD0C37E0F3494440E19BA6CF0E524840D7DAFB54154C4440E19BA6CF0E524840D7DAFB54154C4440EE0912DBDD4F4840DD0C37E0F3494440EE0912DBDD4F4840
55917	56769	40.278885000000002	40.339278999999998	48.639856000000002	48.617978999999998	Мира площадь	0103000020E61000000100000005000000282CF180B2234440B14E95EF194F4840282CF180B22344401F1329CDE65148401B9C887E6D2B44401F1329CDE65148401B9C887E6D2B4440B14E95EF194F4840282CF180B2234440B14E95EF194F4840
56477	56795	39.820466000000003	39.901646999999997	48.666265000000003	48.609037999999998	Центральная	0103000020E610000001000000050000006FBDA60705E94340B8020AF5F44D48406FBDA60705E9434017BCE82B48554840ACC43C2B69F3434017BCE82B48554840ACC43C2B69F34340B8020AF5F44D48406FBDA60705E94340B8020AF5F44D4840
55953	56795	39.820466000000003	39.901646999999997	48.666265000000003	48.609037999999998	Дубовская	0103000020E610000001000000050000006FBDA60705E94340B8020AF5F44D48406FBDA60705E9434017BCE82B48554840ACC43C2B69F3434017BCE82B48554840ACC43C2B69F34340B8020AF5F44D48406FBDA60705E94340B8020AF5F44D4840
55731	30760	40.434922999999998	40.454335	48.742086	48.728780999999998	Центральная	0103000020E610000001000000050000009CA38E8EAB3744401C7920B2485D48409CA38E8EAB374440E4688EACFC5E4840CE3637A6273A4440E4688EACFC5E4840CE3637A6273A44401C7920B2485D48409CA38E8EAB3744401C7920B2485D4840
55954	32235	39.802796000000001	39.8123	48.826399000000002	48.821587999999998	Школьная	0103000020E6100000010000000500000008AEF204C2E643409D64ABCB2969484008AEF204C2E643403B394371C769484039454772F9E743403B394371C769484039454772F9E743409D64ABCB2969484008AEF204C2E643409D64ABCB29694840
56415	56886	40.521799000000001	40.554335999999999	48.646796999999999	48.626668000000002	Степная	0103000020E61000000100000005000000F20A444FCA42444091B932A836504840F20A444FCA42444051137D3ECA5248406B7F677BF446444051137D3ECA5248406B7F677BF446444091B932A836504840F20A444FCA42444091B932A836504840
56314	32088	39.838692999999999	39.867671999999999	48.712887000000002	48.699354999999997	Интернациональная	0103000020E610000001000000050000002B31CF4A5AEB4340A4A5F276845948402B31CF4A5AEB43402D5F97E13F5B4840D4D347E00FEF43402D5F97E13F5B4840D4D347E00FEF4340A4A5F276845948402B31CF4A5AEB4340A4A5F27684594840
56107	31470	40.190069000000001	40.211503	48.752405000000003	48.739798	13 Героев	0103000020E61000000100000005000000E17D552E54184440B7D26BB3B15E4840E17D552E54184440672C9ACE4E604840C100C287121B4440672C9ACE4E604840C100C287121B4440B7D26BB3B15E4840E17D552E54184440B7D26BB3B15E4840
56077	31576	40.077744000000003	40.128283000000003	48.788234000000003	48.733535000000003	Центральная	0103000020E61000000100000005000000E9BAF083F309444056BC9179E45D4840E9BAF083F309444032CC09DAE4644840FFD0CC936B10444032CC09DAE4644840FFD0CC936B10444056BC9179E45D4840E9BAF083F309444056BC9179E45D4840
56228	31887	39.958914	39.985405999999998	48.558478000000001	48.551155000000001	Лесная	0103000020E6100000010000000500000099D6A6B1BDFA434071033E3F8C46484099D6A6B1BDFA43408BC404357C4748401EA4A7C821FE43408BC404357C4748401EA4A7C821FE434071033E3F8C46484099D6A6B1BDFA434071033E3F8C464840
56226	31501	40.275435999999999	40.296528000000002	48.789012	48.772989000000003	Школьная	0103000020E610000001000000050000000E12A27C412344407995B54DF16248400E12A27C4123444066136058FE644840952C27A1F425444066136058FE644840952C27A1F42544407995B54DF16248400E12A27C412344407995B54DF1624840
55677	56680	40.324592000000003	40.348244000000001	48.720663000000002	48.696007000000002	Придорожная	0103000020E6100000010000000500000089450C3B8C294440BF64E3C11659484089450C3B8C294440F83768AF3E5C48409D836742932C4440F83768AF3E5C48409D836742932C4440BF64E3C11659484089450C3B8C294440BF64E3C116594840
40560	54932	41.062179999999998	41.104024000000003	48.669066999999998	48.640076999999998	Башмакова И.В	0103000020E610000001000000050000008E3BA583F5874440FDF50A0BEE5148408E3BA583F58744409AEAC9FCA3554840E3FF8EA8508D44409AEAC9FCA3554840E3FF8EA8508D4440FDF50A0BEE5148408E3BA583F5874440FDF50A0BEE514840
56063	29953	40.832104000000001	40.887358999999996	48.807153999999997	48.781852999999998	Молодежная	0103000020E61000000100000005000000766F4562826A4440C6A354C213644840766F4562826A4440F46A80D250674840D767CEFA94714440F46A80D250674840D767CEFA94714440C6A354C213644840766F4562826A4440C6A354C213644840
56200	29775	42.043976000000001	42.066029999999998	49.053704000000003	49.036278000000003	Гагарина	0103000020E610000001000000050000008AE76C01A10545403BC8EBC1A48448408AE76C01A10545400BD5CDC5DF8648400647C9AB730845400BD5CDC5DF8648400647C9AB730845403BC8EBC1A48448408AE76C01A10545403BC8EBC1A4844840
55556	29615	42.164431	42.182119	48.906725999999999	48.893785999999999	Дорожная	0103000020E610000001000000050000006BB933130C154540B3CF6394677248406BB933130C1545406937FA980F744840787DE6AC4F1745406937FA980F744840787DE6AC4F174540B3CF6394677248406BB933130C154540B3CF639467724840
56065	29694	42.078642000000002	42.144309	48.844735	48.823652000000003	Речная	0103000020E61000000100000005000000C80BE9F0100A45407BA4C16D6D694840C80BE9F0100A4540AE64C746206C48405DC2A1B778124540AE64C746206C48405DC2A1B7781245407BA4C16D6D694840C80BE9F0100A45407BA4C16D6D694840
56210	14946	41.977034000000003	42.004826999999999	49.055109000000002	49.039873999999998	Центральная	0103000020E61000000100000005000000408A3A730FFD4440F8FA5A971A854840408A3A730FFD44408E5BCCCF0D874840A391CF2B9E0045408E5BCCCF0D874840A391CF2B9E004540F8FA5A971A854840408A3A730FFD4440F8FA5A971A854840
39775	29416	42.097479999999997	42.136960999999999	49.018082999999997	48.997824999999999	Горева	0103000020E61000000100000005000000CD0182397A0C4540CB10C7BAB87F4840CD0182397A0C454089CE328B50824840EAE923F08711454089CE328B50824840EAE923F087114540CB10C7BAB87F4840CD0182397A0C4540CB10C7BAB87F4840
56074	14910	42.149932	42.169201000000001	49.021532999999998	49.009155	Мартыненко	0103000020E61000000100000005000000DB4FC6F83013454025CCB4FD2B814840DB4FC6F8301345407364E597C1824840AAB9DC60A81545407364E597C1824840AAB9DC60A815454025CCB4FD2B814840DB4FC6F83013454025CCB4FD2B814840
56045	29828	42.070242999999998	42.095979	49.127215	49.117427999999997	Лесная	0103000020E61000000100000005000000EFE2FDB8FD0845403DD175E1078F4840EFE2FDB8FD084540C347C49448904840280D350A490C4540C347C49448904840280D350A490C45403DD175E1078F4840EFE2FDB8FD0845403DD175E1078F4840
56349	29527	42.336008999999997	42.353068	49.012327999999997	49.001956	Любимая	0103000020E61000000100000005000000B114C957022B4540F7031E1840804840B114C957022B45409C69C2F693814840CFA10C55312D45409C69C2F693814840CFA10C55312D4540F7031E1840804840B114C957022B4540F7031E1840804840
56348	29450	41.987679	42.018599000000002	48.994656999999997	48.978687999999998	Молодежная	0103000020E6100000010000000500000016F9F5436CFE44406B7EFCA5457D484016F9F5436CFE444065DEAAEB507F4840815EB8736102454065DEAAEB507F4840815EB873610245406B7EFCA5457D484016F9F5436CFE44406B7EFCA5457D4840
56053	29683	42.226253	42.252977999999999	48.880338000000002	48.864226000000002	Школьная	0103000020E610000001000000050000009ACFB9DBF51C45402C2D23F59E6E48409ACFB9DBF51C454089B663EAAE704840C24D46956120454089B663EAAE704840C24D4695612045402C2D23F59E6E48409ACFB9DBF51C45402C2D23F59E6E4840
56062	29597	42.286709999999999	42.307792999999997	48.995147000000003	48.984264000000003	Центральная	0103000020E61000000100000005000000D4B7CCE9B2244540A950DD5CFC7D4840D4B7CCE9B224454034DB15FA607F48400778D2C26527454034DB15FA607F48400778D2C265274540A950DD5CFC7D4840D4B7CCE9B2244540A950DD5CFC7D4840
56005	31309	42.254441999999997	42.268447000000002	48.895212999999998	48.885457000000002	Озерная	0103000020E610000001000000050000004A5D328E91204540D481ACA7567148404A5D328E912045401EFAEE5696724840CBDAA6785C2245401EFAEE5696724840CBDAA6785C224540D481ACA7567148404A5D328E91204540D481ACA756714840
55775	29511	42.414675000000003	42.445819	49.001773	48.984546999999999	Школьная	0103000020E6100000010000000500000002BC051214354540FD2FD7A2057E484002BC051214354540068200193A804840BC77D49810394540068200193A804840BC77D49810394540FD2FD7A2057E484002BC051214354540FD2FD7A2057E4840
55633	56677	41.078045000000003	41.097008000000002	47.384666000000003	47.367860999999998	пер. Школьный	0103000020E61000000100000005000000E44EE960FD894440A73CBA1116AF4740E44EE960FD8944400BF148BC3CB14740A6B915C26A8C44400BF148BC3CB14740A6B915C26A8C4440A73CBA1116AF4740E44EE960FD894440A73CBA1116AF4740
55298	56643	40.901004999999998	40.930092000000002	47.573481000000001	47.554006999999999	Гагарина	0103000020E610000001000000050000002844C02154734440A6608DB3E9C647402844C021547344404EF04DD367C94740B82231410D7744404EF04DD367C94740B82231410D774440A6608DB3E9C647402844C02154734440A6608DB3E9C64740
39707	54814	41.132266999999999	41.154698000000003	47.376044999999998	47.355086	переулок Советский	0103000020E6100000010000000500000086AB0320EE9044403CA2427573AD474086AB0320EE9044408369183E22B04740D960E124CD9344408369183E22B04740D960E124CD9344403CA2427573AD474086AB0320EE9044403CA2427573AD4740
55842	56701	41.363115999999998	41.382043000000003	47.533861000000002	47.511291999999997	Пионерская	0103000020E61000000100000005000000C153C8957AAE44406C5A290472C14740C153C8957AAE444010CEA78E55C447403755F7C8E6B0444010CEA78E55C447403755F7C8E6B044406C5A290472C14740C153C8957AAE44406C5A290472C14740
55346	56658	40.683909	40.707777	47.435724999999998	47.416595000000001	Молодежная	0103000020E61000000100000005000000543882548A574440AC5626FC52B54740543882548A574440598638D6C5B7474035EECD6F985A4440598638D6C5B7474035EECD6F985A4440AC5626FC52B54740543882548A574440AC5626FC52B54740
55848	56706	41.011470000000003	41.034332999999997	47.400221000000002	47.382286999999998	Гагарина	0103000020E610000001000000050000004C7155D977814440CD57C9C7EEB047404C7155D977814440121615713AB347403716140665844440121615713AB347403716140665844440CD57C9C7EEB047404C7155D977814440CD57C9C7EEB04740
56456	4374	40.795057	40.806080000000001	47.569401999999997	47.554402000000003	Центральная	0103000020E610000001000000050000005ABA826DC4654440236B0DA5F6C647405ABA826DC465444074232C2AE2C84740D7FA22A12D67444074232C2AE2C84740D7FA22A12D674440236B0DA5F6C647405ABA826DC4654440236B0DA5F6C64740
55925	56777	40.822150000000001	40.842784999999999	47.441344999999998	47.414723000000002	Мира	0103000020E61000000100000005000000053411363C69444013F3ACA415B54740053411363C69444066A032FE7DB847409947FE60E06B444066A032FE7DB847409947FE60E06B444013F3ACA415B54740053411363C69444013F3ACA415B54740
9658	1115	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	проспект Закруткина	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
55770	1115	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	Серегина	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
39704	1115	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	Ленина	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
56215	1115	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	Зеленая	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
41054	1115	40.731788999999999	40.880253000000003	47.548003999999999	47.502313999999998	Авилова	0103000020E6100000010000000500000049490F43AB5D444056293DD34BC0474049490F43AB5D4440E109BDFE24C647405B9A5B21AC704440E109BDFE24C647405B9A5B21AC70444056293DD34BC0474049490F43AB5D444056293DD34BC04740
56417	56888	41.133318000000003	41.162998000000002	47.317022999999999	47.307974999999999	Юрия Гагарина	0103000020E61000000100000005000000ECFB709010914440287E8CB96BA74740ECFB709010914440378AAC3594A847401EA8531EDD944440378AAC3594A847401EA8531EDD944440287E8CB96BA74740ECFB709010914440287E8CB96BA74740
56441	56909	40.78125	40.789667000000001	47.446263000000002	47.432713999999997	Калинина	0103000020E610000001000000050000000000000000644440BB421F2C63B7474000000000006444401A355F251FB947407FDDE9CE136544401A355F251FB947407FDDE9CE13654440BB421F2C63B747400000000000644440BB421F2C63B74740
41090	22637	40.933038000000003	40.967748999999998	47.574472	47.557034999999999	Октябрьская	0103000020E610000001000000050000006FF607CA6D7744401ADD41EC4CC747406FF607CA6D774440DE3B6A4C88C947404CDE0033DF7B4440DE3B6A4C88C947404CDE0033DF7B44401ADD41EC4CC747406FF607CA6D7744401ADD41EC4CC74740
55525	2113	40.942165000000003	40.953851999999998	47.483544000000002	47.473903	Тоговая	0103000020E61000000100000005000000CA37DBDC98784440F73C7FDAA8BC4740CA37DBDC98784440A91611C5E4BD4740B29C84D2177A4440A91611C5E4BD4740B29C84D2177A4440F73C7FDAA8BC4740CA37DBDC98784440F73C7FDAA8BC4740
55440	56664	41.077218000000002	41.102299000000002	47.517707000000001	47.502381	Октябрьская	0103000020E61000000100000005000000CE548847E2894440DE9046054EC04740CE548847E289444084F4143944C24740EEB43522188D444084F4143944C24740EEB43522188D4440DE9046054EC04740CE548847E2894440DE9046054EC04740
56439	56907	41.045436000000002	41.076104000000001	47.228986999999996	47.221533000000001	Степная	0103000020E61000000100000005000000D107CBD8D08544400DFE7E315B9C4740D107CBD8D0854440C51A2E724F9D4740228C9FC6BD894440C51A2E724F9D4740228C9FC6BD8944400DFE7E315B9C4740D107CBD8D08544400DFE7E315B9C4740
55754	56693	40.940477000000001	40.967174	47.419522000000001	47.399574999999999	Ананченко	0103000020E61000000100000005000000F2D1E28C617844404CA60A4625B34740F2D1E28C61784440ECF99AE5B2B5474050C58D5BCC7B4440ECF99AE5B2B5474050C58D5BCC7B44404CA60A4625B34740F2D1E28C617844404CA60A4625B34740
55558	22878	41.280712999999999	41.294736	47.488086000000003	47.482374	Ленина	0103000020E61000000100000005000000F1475167EEA344406938656EBEBD4740F1475167EEA3444057D11F9A79BE4740187AC4E8B9A5444057D11F9A79BE4740187AC4E8B9A544406938656EBEBD4740F1475167EEA344406938656EBEBD4740
39705	1693	40.829669000000003	40.861604	47.587983999999999	47.570836999999997	Студенческая	0103000020E61000000100000005000000A5C00298326A4440622CD32F11C94740A5C00298326A44401F49490F43CB4740280D350A496E44401F49490F43CB4740280D350A496E4440622CD32F11C94740A5C00298326A4440622CD32F11C94740
56419	56890	40.696987999999997	40.738643000000003	47.445684	47.436571999999998	Ленина	0103000020E610000001000000050000002BDA1CE736594440B62C5F97E1B747402BDA1CE736594440DC2C5E2C0CB94740AD3594DA8B5E4440DC2C5E2C0CB94740AD3594DA8B5E4440B62C5F97E1B747402BDA1CE736594440B62C5F97E1B74740
56579	57025	40.991275999999999	41.010607999999998	47.373927000000002	47.357160999999998	Школьная	0103000020E61000000100000005000000A4A7C821E27E44400D349F73B7AD4740A4A7C821E27E4440B30B06D7DCAF4740B9895A9A5B814440B30B06D7DCAF4740B9895A9A5B8144400D349F73B7AD4740A4A7C821E27E44400D349F73B7AD4740
40415	54909	41.074092	41.105829	47.345342000000002	47.320596999999999	Степана Здоровцева	0103000020E610000001000000050000009772BED87B8944400D198F5209A947409772BED87B894440B6F7A92A34AC4740F4FBFECD8B8D4440B6F7A92A34AC4740F4FBFECD8B8D44400D198F5209A947409772BED87B8944400D198F5209A94740
55657	22800	41.203296999999999	41.218164000000002	47.483390999999997	47.473373000000002	Пушкина	0103000020E61000000100000005000000FD2FD7A2059A44409BE7887C97BC4740FD2FD7A2059A444022179CC1DFBD4740109546CCEC9B444022179CC1DFBD4740109546CCEC9B44409BE7887C97BC4740FD2FD7A2059A44409BE7887C97BC4740
40576	2002	41.272961000000002	41.318019999999997	47.528002999999998	47.516021000000002	30 лет Победы	0103000020E61000000100000005000000AF0AD462F0A244404D86E3F90CC24740AF0AD462F0A244404E98309A95C34740A9BC1DE1B4A844404E98309A95C34740A9BC1DE1B4A844404D86E3F90CC24740AF0AD462F0A244404D86E3F90CC24740
55903	56756	41.192273999999998	41.210994999999997	47.520305	47.509143999999999	Центральная	0103000020E6100000010000000500000080EF366F9C984440317A6EA12BC1474080EF366F9C984440FF78AF5A99C247404C4F58E2019B4440FF78AF5A99C247404C4F58E2019B4440317A6EA12BC1474080EF366F9C984440317A6EA12BC14740
55345	56657	41.130138000000002	41.185383999999999	47.509746	47.458339000000002	Школьная	0103000020E61000000100000005000000C2FBAA5CA89044409DBD33DAAABA4740C2FBAA5CA890444027A25F5B3FC14740D099B4A9BA97444027A25F5B3FC14740D099B4A9BA9744409DBD33DAAABA4740C2FBAA5CA89044409DBD33DAAABA4740
55634	2043	41.000205999999999	41.022016999999998	47.493073000000003	47.480012000000002	Центральная	0103000020E61000000100000005000000A9A10DC00680444002D8800871BD4740A9A10DC00680444033C51C041DBF47405F7AFB73D182444033C51C041DBF47405F7AFB73D182444002D8800871BD4740A9A10DC00680444002D8800871BD4740
56433	56902	40.817442999999997	40.827396999999998	47.603582000000003	47.598697000000001	Речная	0103000020E610000001000000050000000CACE3F8A16844404E9B711AA2CC47400CACE3F8A1684440263ACB2C42CD47407DE71725E8694440263ACB2C42CD47407DE71725E86944404E9B711AA2CC47400CACE3F8A16844404E9B711AA2CC4740
56475	56938	40.899512999999999	40.914596000000003	47.422772000000002	47.411783999999997	Центральная	0103000020E61000000100000005000000D6A9F23D237344400E828E56B5B44740D6A9F23D237344400FD594641DB64740B686527B117544400FD594641DB64740B686527B117544400E828E56B5B44740D6A9F23D237344400E828E56B5B44740
55944	56793	40.977595000000001	40.991087999999998	47.447316999999998	47.436821999999999	Школьная	0103000020E61000000100000005000000D7DD3CD5217D44402F1686C8E9B74740D7DD3CD5217D4440F0F8F6AE41B94740A1BAB9F8DB7E4440F0F8F6AE41B94740A1BAB9F8DB7E44402F1686C8E9B74740D7DD3CD5217D44402F1686C8E9B74740
55270	56627	41.118279999999999	42.177439	47.041088999999999	46.143811999999997	Ленина	0103000020E61000000100000005000000ACE28DCC238F4440DC627E6E68124740ACE28DCC238F4440D89C83674285474079043752B6164540D89C83674285474079043752B6164540DC627E6E68124740ACE28DCC238F4440DC627E6E68124740
41111	28061	41.611015000000002	41.648484000000003	46.554087000000003	46.534481999999997	Димитрова	0103000020E61000000100000005000000C72E51BD35CE44407C26FBE769444740C72E51BD35CE4440C311A452EC46474059FD118601D34440C311A452EC46474059FD118601D344407C26FBE769444740C72E51BD35CE44407C26FBE769444740
56112	29777	41.247	41.257024999999999	46.927526	46.920676	Ленина	0103000020E61000000100000005000000560E2DB29D9F4440261B0FB6D8754740560E2DB29D9F44404818062CB976474090A0F831E6A044404818062CB976474090A0F831E6A04440261B0FB6D8754740560E2DB29D9F4440261B0FB6D8754740
56139	28304	41.247646000000003	41.305686999999999	46.419646999999998	46.405355999999998	 Молодежная	0103000020E610000001000000050000001C7E37DDB29F4440629E95B4E23347401C7E37DDB29F4440A86E2EFEB6354740FBE769C020A74440A86E2EFEB6354740FBE769C020A74440629E95B4E23347401C7E37DDB29F4440629E95B4E2334740
55661	27428	41.377327000000001	41.387450999999999	46.763173999999999	46.755636000000003	Центральная	0103000020E61000000100000005000000EB724A404CB0444013D731AEB8604740EB724A404CB04440299485AFAF614740B8E68EFE97B14440299485AFAF614740B8E68EFE97B1444013D731AEB8604740EB724A404CB0444013D731AEB8604740
55513	27531	41.207932	41.224263000000001	46.992775000000002	46.975481000000002	Победы	0103000020E610000001000000050000005CE509849D9A4440486FB88FDC7C47405CE509849D9A4440A9A44E40137F4740F75965A6B49C4440A9A44E40137F4740F75965A6B49C4440486FB88FDC7C47405CE509849D9A4440486FB88FDC7C4740
55639	28466	41.180928999999999	41.200665000000001	46.527433000000002	46.508853999999999	Пришкольная	0103000020E61000000100000005000000F1F274AE289744402A38BC2022414740F1F274AE2897444064EAAEEC82434740D6390664AF99444064EAAEEC82434740D6390664AF9944402A38BC2022414740F1F274AE289744402A38BC2022414740
55579	27690	41.706721000000002	41.816783000000001	46.301167999999997	46.250526000000001	Полевая	0103000020E61000000100000005000000BE326FD575DA44401B66683C11204740BE326FD575DA4440054D4BAC8C264740E27668588CE84440054D4BAC8C264740E27668588CE844401B66683C11204740BE326FD575DA44401B66683C11204740
40611	27690	41.706721000000002	41.816783000000001	46.301167999999997	46.250526000000001	Калинина	0103000020E61000000100000005000000BE326FD575DA44401B66683C11204740BE326FD575DA4440054D4BAC8C264740E27668588CE84440054D4BAC8C264740E27668588CE844401B66683C11204740BE326FD575DA44401B66683C11204740
75533	29910	41.505848999999998	41.510907000000003	46.656317000000001	46.651944	Крайняя	0103000020E610000001000000050000006EDBF7A8BFC044406669A7E6725347406EDBF7A8BFC04440886709320254474014268C6665C14440886709320254474014268C6665C144406669A7E6725347406EDBF7A8BFC044406669A7E672534740
40284	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	переулок Морской	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
56125	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	микрорайон Плодопитомник	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
40286	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Юннатов	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
39916	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Школьная площадь	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
41108	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Халтурина	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
40287	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Фрунзе	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
41055	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Свободы	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
39713	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Прямая	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
39921	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Промышленная	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
40288	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Островского	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
39712	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Новостройка	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
40285	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Ленина	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
40281	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Ковпака	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
39920	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Кирова	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
41107	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Карла Маркса	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
39923	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Верхняя	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
39918	2683	41.488188000000001	41.575819000000003	46.503475999999999	46.451383999999997	Береговая	0103000020E610000001000000050000005B26C3F17CBE444005F86EF3C63947405B26C3F17CBE44401329CDE6714047402DB5DE6FB4C944401329CDE6714047402DB5DE6FB4C9444005F86EF3C63947405B26C3F17CBE444005F86EF3C6394740
55665	28418	41.612614000000001	41.621704999999999	46.447142999999997	46.443404999999998	Московская	0103000020E610000001000000050000002F89B3226ACE444002F1BA7EC13847402F89B3226ACE444052D158FB3B3947403D61890794CF444052D158FB3B3947403D61890794CF444002F1BA7EC13847402F89B3226ACE444002F1BA7EC1384740
55659	27779	42.111995999999998	42.150731999999998	46.355918000000003	46.336117000000002	Чапаева	0103000020E6100000010000000500000033A48AE2550E45409850C1E1052B474033A48AE2550E4540640795B88E2D4740F73AA92F4B134540640795B88E2D4740F73AA92F4B1345409850C1E1052B474033A48AE2550E45409850C1E1052B4740
55755	28712	41.375836	41.401114999999997	46.450918000000001	46.441777999999999	Школьная	0103000020E610000001000000050000006954E0641BB04440D00B772E8C3847406954E0641BB04440C09657AEB7394740AF777FBC57B34440C09657AEB7394740AF777FBC57B34440D00B772E8C3847406954E0641BB04440D00B772E8C384740
56247	29852	41.573771000000001	41.586768999999997	46.616722000000003	46.604824000000001	Советская	0103000020E610000001000000050000005532005471C94440FFEA71DF6A4D47405532005471C94440A35C1ABFF04E47403FA7203F1BCB4440A35C1ABFF04E47403FA7203F1BCB4440FFEA71DF6A4D47405532005471C94440FFEA71DF6A4D4740
56219	28074	41.862327999999998	41.880617000000001	46.517034000000002	46.498854999999999	Центральная	0103000020E6100000010000000500000069368FC360EE444019390B7BDA3F474069368FC360EE4440C5758C2B2E4247409CA6CF0EB8F04440C5758C2B2E4247409CA6CF0EB8F0444019390B7BDA3F474069368FC360EE444019390B7BDA3F4740
39924	27879	41.830401999999999	41.915202999999998	46.412533000000003	46.371825999999999	Советская	0103000020E610000001000000050000003944DC9C4AEA4440B8E68EFE972F47403944DC9C4AEA4440A9C29FE1CD344740BD19355F25F54440A9C29FE1CD344740BD19355F25F54440B8E68EFE972F47403944DC9C4AEA4440B8E68EFE972F4740
55637	27879	41.830401999999999	41.915202999999998	46.412533000000003	46.371825999999999	Новостройка	0103000020E610000001000000050000003944DC9C4AEA4440B8E68EFE972F47403944DC9C4AEA4440A9C29FE1CD344740BD19355F25F54440A9C29FE1CD344740BD19355F25F54440B8E68EFE972F47403944DC9C4AEA4440B8E68EFE972F4740
55663	27879	41.830401999999999	41.915202999999998	46.412533000000003	46.371825999999999	Гагарина	0103000020E610000001000000050000003944DC9C4AEA4440B8E68EFE972F47403944DC9C4AEA4440A9C29FE1CD344740BD19355F25F54440A9C29FE1CD344740BD19355F25F54440B8E68EFE972F47403944DC9C4AEA4440B8E68EFE972F4740
56113	29832	41.273859000000002	41.284962	46.825695000000003	46.820756000000003	Школьная	0103000020E610000001000000050000008E5BCCCF0DA3444076FF58880E6947408E5BCCCF0DA3444041BCAE5FB0694740274D83A279A4444041BCAE5FB0694740274D83A279A4444076FF58880E6947408E5BCCCF0DA3444076FF58880E694740
55536	28227	41.439365000000002	41.452112	46.428766000000003	46.410693999999999	Солнечная	0103000020E61000000100000005000000E700C11C3DB84440EB54F99E91344740E700C11C3DB8444081D1E5CDE1364740881057CEDEB9444081D1E5CDE1364740881057CEDEB94440EB54F99E91344740E700C11C3DB84440EB54F99E91344740
55938	56787	41.721147999999999	41.731290000000001	46.350524999999998	46.342886	Центральная	0103000020E61000000100000005000000B4C9E1934EDC4440CD203EB0E32B4740B4C9E1934EDC444017B7D100DE2C474028F224E99ADD444017B7D100DE2C474028F224E99ADD4440CD203EB0E32B4740B4C9E1934EDC4440CD203EB0E32B4740
55997	28159	41.652993000000002	41.662568999999998	46.626866999999997	46.615434999999998	Нефтяников	0103000020E610000001000000050000002BC24D4695D3444029E8F692C64E47402BC24D4695D3444087F8872D3D504740F52B9D0FCFD4444087F8872D3D504740F52B9D0FCFD4444029E8F692C64E47402BC24D4695D3444029E8F692C64E4740
40290	28256	41.324399	41.393227000000003	46.430667	46.408195999999997	Ленина	0103000020E6100000010000000500000074ED0BE885A94440D32D3BC43F34474074ED0BE885A94440B43BA41820374740BD73284355B24440B43BA41820374740BD73284355B24440D32D3BC43F34474074ED0BE885A94440D32D3BC43F344740
41234	11240	41.567140999999999	41.595196000000001	46.558425	46.538747000000001	Ленина	0103000020E61000000100000005000000419C871398C84440B8E864A9F5444740419C871398C8444068226C787A474740E25AED612FCC444068226C787A474740E25AED612FCC4440B8E864A9F5444740419C871398C84440B8E864A9F5444740
55606	11240	41.567140999999999	41.595196000000001	46.558425	46.538747000000001	Буденного	0103000020E61000000100000005000000419C871398C84440B8E864A9F5444740419C871398C8444068226C787A474740E25AED612FCC444068226C787A474740E25AED612FCC4440B8E864A9F5444740419C871398C84440B8E864A9F5444740
55692	29941	41.262990000000002	41.273786999999999	46.513312999999997	46.507328000000001	пер. Школьный	0103000020E61000000100000005000000689604A8A9A144402C2CB81FF0404740689604A8A9A144404ACE893DB4414740F488D1730BA344404ACE893DB4414740F488D1730BA344402C2CB81FF0404740689604A8A9A144402C2CB81FF0404740
41110	27659	41.637281999999999	41.695528000000003	46.221246999999998	46.179254999999998	Ленина	0103000020E610000001000000050000002C2AE27492D144407E52EDD3F11647402C2AE27492D1444047AB5AD2511C4740E5B9BE0F07D9444047AB5AD2511C4740E5B9BE0F07D944407E52EDD3F11647402C2AE27492D144407E52EDD3F1164740
40626	28010	41.660054000000002	41.715139000000001	46.545794999999998	46.518163000000001	Коржова	0103000020E6100000010000000500000008CC43A67CD44440A67F492A5342474008CC43A67CD4444000A94D9CDC4547400D8CBCAC89DB444000A94D9CDC4547400D8CBCAC89DB4440A67F492A5342474008CC43A67CD44440A67F492A53424740
39925	2726	41.320078000000002	41.356468	46.515453000000001	46.493259000000002	Учебная	0103000020E61000000100000005000000A515DF50F8A8444095BA641C233F4740A515DF50F8A8444003D0285DFA414740070951BEA0AD444003D0285DFA414740070951BEA0AD444095BA641C233F4740A515DF50F8A8444095BA641C233F4740
41238	2726	41.320078000000002	41.356468	46.515453000000001	46.493259000000002	Ленина	0103000020E61000000100000005000000A515DF50F8A8444095BA641C233F4740A515DF50F8A8444003D0285DFA414740070951BEA0AD444003D0285DFA414740070951BEA0AD444095BA641C233F4740A515DF50F8A8444095BA641C233F4740
41236	2726	41.320078000000002	41.356468	46.515453000000001	46.493259000000002	Крупской	0103000020E61000000100000005000000A515DF50F8A8444095BA641C233F4740A515DF50F8A8444003D0285DFA414740070951BEA0AD444003D0285DFA414740070951BEA0AD444095BA641C233F4740A515DF50F8A8444095BA641C233F4740
40289	27613	41.815939	41.853721999999998	46.343384	46.295757000000002	Юбилейная	0103000020E61000000100000005000000F6436CB070E844401348895DDB254740F6436CB070E844401EFCC401F42B474017F032C346ED44401EFCC401F42B474017F032C346ED44401348895DDB254740F6436CB070E844401348895DDB254740
41109	27517	41.326033000000002	41.345005999999998	46.843173	46.833655	Центральная	0103000020E6100000010000000500000059350873BBA94440CD920035B56A474059350873BBA9444063EFC517ED6B47403E76172829AC444063EFC517ED6B47403E76172829AC4440CD920035B56A474059350873BBA94440CD920035B56A4740
55521	27813	41.904513000000001	41.935271	46.500802999999998	46.472552	Октябрьская	0103000020E6100000010000000500000047E7FC14C7F3444067D47C957C3C474047E7FC14C7F344408D5E0D501A404740D8F2CAF5B6F744408D5E0D501A404740D8F2CAF5B6F7444067D47C957C3C474047E7FC14C7F3444067D47C957C3C4740
56126	24069	39.431494999999998	39.450018999999998	47.524583	47.517122999999998	 Октябрьская	0103000020E610000001000000050000009AB1683A3BB743403481221631C247409AB1683A3BB74340CF84268925C3474010CAFB389AB94340CF84268925C3474010CAFB389AB943403481221631C247409AB1683A3BB743403481221631C24740
55294	54827	39.696570000000001	39.732844	47.624077	47.594067000000003	Пушкинская	0103000020E61000000100000005000000F7AFAC3429D94340015130630ACC4740F7AFAC3429D94340C89750C1E1CF4740F0880AD5CDDD4340C89750C1E1CF4740F0880AD5CDDD4340015130630ACC4740F7AFAC3429D94340015130630ACC4740
55257	54827	39.696570000000001	39.732844	47.624077	47.594067000000003	Кирова	0103000020E61000000100000005000000F7AFAC3429D94340015130630ACC4740F7AFAC3429D94340C89750C1E1CF4740F0880AD5CDDD4340C89750C1E1CF4740F0880AD5CDDD4340015130630ACC4740F7AFAC3429D94340015130630ACC4740
39879	54827	39.696570000000001	39.732844	47.624077	47.594067000000003	Гвардейцев-Танкистов	0103000020E61000000100000005000000F7AFAC3429D94340015130630ACC4740F7AFAC3429D94340C89750C1E1CF4740F0880AD5CDDD4340C89750C1E1CF4740F0880AD5CDDD4340015130630ACC4740F7AFAC3429D94340015130630ACC4740
56131	23599	39.406126999999998	39.432060999999997	47.695295999999999	47.677292000000001	Чапаева	0103000020E61000000100000005000000E48233F8FBB34340D5EB1681B1D64740E48233F8FBB3434012859675FFD8474043705CC64DB7434012859675FFD8474043705CC64DB74340D5EB1681B1D64740E48233F8FBB34340D5EB1681B1D64740
55573	24375	39.755895000000002	39.783042000000002	47.557873999999998	47.544713999999999	Булановой	0103000020E61000000100000005000000DF1AD82AC1E0434030D63730B9C54740DF1AD82AC1E04340F4A44C6A68C747407DB262B83AE44340F4A44C6A68C747407DB262B83AE4434030D63730B9C54740DF1AD82AC1E0434030D63730B9C54740
55796	24380	39.837291	39.867421	47.442307	47.425826000000001	Первомайская	0103000020E61000000100000005000000191EFB592CEB4340ACE4637781B64740191EFB592CEB43405CE509849DB847408B6EBDA607EF43405CE509849DB847408B6EBDA607EF4340ACE4637781B64740191EFB592CEB4340ACE4637781B64740
55891	56744	39.674821999999999	39.695231999999997	47.692433000000001	47.678317999999997	Центральная	0103000020E61000000100000005000000874F3A9160D64340E124CD1FD3D64740874F3A9160D64340E9D500A5A1D84740FB90B75CFDD84340E9D500A5A1D84740FB90B75CFDD84340E124CD1FD3D64740874F3A9160D64340E124CD1FD3D64740
55689	24115	39.241556000000003	39.258578999999997	47.628613000000001	47.618295000000003	Волошилова	0103000020E610000001000000050000008813984EEB9E4340E223624A24CF47408813984EEB9E4340946B0A6476D047405837DE1D19A14340946B0A6476D047405837DE1D19A14340E223624A24CF47408813984EEB9E4340E223624A24CF4740
56450	56917	39.816451000000001	39.833841999999997	47.533557000000002	47.520736999999997	Суворова	0103000020E61000000100000005000000ACE4637781E8434098689082A7C24740ACE4637781E84340A4C684984BC44740FF03AC55BBEA4340A4C684984BC44740FF03AC55BBEA434098689082A7C24740ACE4637781E8434098689082A7C24740
55690	24218	39.574516000000003	39.611662000000003	47.475883000000003	47.465223000000002	Клубная	0103000020E61000000100000005000000AE8383BD89C943406B2C616D8CBB4740AE8383BD89C9434077DCF0BBE9BC47405D1ABFF04ACE434077DCF0BBE9BC47405D1ABFF04ACE43406B2C616D8CBB4740AE8383BD89C943406B2C616D8CBB4740
55496	56666	39.533175999999997	39.550423000000002	47.628825999999997	47.621094999999997	Первомайская	0103000020E610000001000000050000008C81751C3FC44340C45A7C0A80CF47408C81751C3FC44340EF6FD05E7DD04740ADFBC74274C64340EF6FD05E7DD04740ADFBC74274C64340C45A7C0A80CF47408C81751C3FC44340C45A7C0A80CF4740
55849	56707	39.653675999999997	39.671956999999999	47.519252999999999	47.507506999999997	Центральная	0103000020E610000001000000050000000D17B9A7ABD34340DBBE47FDF5C047400D17B9A7ABD34340C9ACDEE176C24740BDA8DDAF02D64340C9ACDEE176C24740BDA8DDAF02D64340DBBE47FDF5C047400D17B9A7ABD34340DBBE47FDF5C04740
55877	56732	39.634182000000003	39.644863000000001	47.598557	47.590226000000001	Ленина	0103000020E610000001000000050000001FDB32E02CD14340DC9F8B868CCB47401FDB32E02CD143405CE509849DCC474042B3EBDE8AD243405CE509849DCC474042B3EBDE8AD24340DC9F8B868CCB47401FDB32E02CD14340DC9F8B868CCB4740
56377	56852	39.595914	39.620832999999998	47.808225999999998	47.799747000000004	Первомайская	0103000020E61000000100000005000000419DF2E846CC43407D09151C5EE64740419DF2E846CC434071E316F373E7474087A3AB7477CF434071E316F373E7474087A3AB7477CF43407D09151C5EE64740419DF2E846CC43407D09151C5EE64740
55282	56635	39.348491000000003	39.399372	47.622984000000002	47.585115000000002	Ленина	0103000020E61000000100000005000000A5F9635A9BAC434014B35E0CE5CA4740A5F9635A9BAC434034F790F0BDCF47401478279F1EB3434034F790F0BDCF47401478279F1EB3434014B35E0CE5CA4740A5F9635A9BAC434014B35E0CE5CA4740
55869	56725	39.715443999999998	39.738197999999997	47.725816999999999	47.713256999999999	Октябрьская	0103000020E61000000100000005000000490F43AB93DB4340505260014CDB4740490F43AB93DB4340BFF04A92E7DC47407EFCA5457DDE4340BFF04A92E7DC47407EFCA5457DDE4340505260014CDB4740490F43AB93DB4340505260014CDB4740
55856	56713	39.515497000000003	39.551879	47.765405999999999	47.745136000000002	Красноармейская	0103000020E61000000100000005000000D31742CEFBC143404089CF9D60DF4740D31742CEFBC14340C214E5D2F8E14740B22C98F8A3C64340C214E5D2F8E14740B22C98F8A3C643404089CF9D60DF4740D31742CEFBC143404089CF9D60DF4740
56472	56936	39.581667000000003	39.597765000000003	47.781162999999999	47.768597	Чапаева	0103000020E61000000100000005000000CB14731074CA4340E066F16261E24740CB14731074CA434031EC3026FDE34740C3D8429083CC434031EC3026FDE34740C3D8429083CC4340E066F16261E24740CB14731074CA4340E066F16261E24740
55914	56766	39.438879999999997	39.463501999999998	47.849397000000003	47.835287999999998	Садовая	0103000020E610000001000000050000002A6F47382DB84340E15E99B7EAEA47402A6F47382DB843400729780AB9EC4740B7D0950854BB43400729780AB9EC4740B7D0950854BB4340E15E99B7EAEA47402A6F47382DB84340E15E99B7EAEA4740
55599	56675	39.469718999999998	39.508535000000002	47.740743999999999	47.719445999999998	Просвещения	0103000020E61000000100000005000000A8A78FC01FBC4340779E78CE16DC4740A8A78FC01FBC4340A75A0BB3D0DE474089EFC4AC17C14340A75A0BB3D0DE474089EFC4AC17C14340779E78CE16DC4740A8A78FC01FBC4340779E78CE16DC4740
55926	56778	39.878200999999997	39.899346999999999	47.651634999999999	47.626184000000002	Советская	0103000020E610000001000000050000004128EFE368F04340A5A31CCC26D047404128EFE368F04340E8F692C668D34740BB6070CD1DF34340E8F692C668D34740BB6070CD1DF34340A5A31CCC26D047404128EFE368F04340A5A31CCC26D04740
56289	8826	43.401437999999999	43.414518000000001	46.313426	46.302463000000003	Школьная	0103000020E6100000010000000500000092AF045262B3454002A08A1BB726474092AF045262B34540A9DBD9571E2847403ACD02ED0EB54540A9DBD9571E2847403ACD02ED0EB5454002A08A1BB726474092AF045262B3454002A08A1BB7264740
41086	8379	43.636420000000001	43.699041000000001	46.577334	46.544871000000001	Первомайская	0103000020E610000001000000050000009A42E73576D14540F8C43A55BE4547409A42E73576D14540376F9C14E649474015C8EC2C7AD94540376F9C14E649474015C8EC2C7AD94540F8C43A55BE4547409A42E73576D14540F8C43A55BE454740
40482	8379	43.636420000000001	43.699041000000001	46.577334	46.544871000000001	Октябрьская	0103000020E610000001000000050000009A42E73576D14540F8C43A55BE4547409A42E73576D14540376F9C14E649474015C8EC2C7AD94540376F9C14E649474015C8EC2C7AD94540F8C43A55BE4547409A42E73576D14540F8C43A55BE454740
40226	8379	43.636420000000001	43.699041000000001	46.577334	46.544871000000001	Ленинская	0103000020E610000001000000050000009A42E73576D14540F8C43A55BE4547409A42E73576D14540376F9C14E649474015C8EC2C7AD94540376F9C14E649474015C8EC2C7AD94540F8C43A55BE4547409A42E73576D14540F8C43A55BE454740
56283	8962	42.945624000000002	42.974235	46.645826	46.626055999999998	Центральная	0103000020E6100000010000000500000007280D350A79454077BB5E9A2250474007280D350A7945400874266DAA5247402DCF83BBB37C45400874266DAA5247402DCF83BBB37C454077BB5E9A2250474007280D350A79454077BB5E9A22504740
55554	9146	43.389895000000003	43.421776000000001	46.659156000000003	46.649729000000001	Советская	0103000020E61000000100000005000000DDEF5014E8B14540A321E3512A534740DDEF5014E8B14540297B4B395F5447406D1E87C1FCB54540297B4B395F5447406D1E87C1FCB54540A321E3512A534740DDEF5014E8B14540A321E3512A534740
55722	8866	43.111542999999998	43.148167000000001	46.544437000000002	46.522392000000004	Ленина	0103000020E61000000100000005000000828C800A478E454095D8B5BDDD424740828C800A478E4540BEDD921CB045474058ACE122F7924540BEDD921CB045474058ACE122F792454095D8B5BDDD424740828C800A478E454095D8B5BDDD424740
41087	8772	43.583796	43.635800000000003	46.370328000000001	46.349834999999999	Богданова	0103000020E610000001000000050000008FC4CBD3B9CA454082FFAD64C72C47408FC4CBD3B9CA454084656CE8662F4740FE65F7E461D1454084656CE8662F4740FE65F7E461D1454082FFAD64C72C47408FC4CBD3B9CA454082FFAD64C72C4740
56273	9222	43.501716999999999	43.524445	46.608625000000004	46.595993999999997	Садовая	0103000020E61000000100000005000000726C3D4338C045405D4E0988494C4740726C3D4338C0454096438B6CE74D47407EC6850321C3454096438B6CE74D47407EC6850321C345405D4E0988494C4740726C3D4338C045405D4E0988494C4740
55548	9061	43.131782000000001	43.162863999999999	46.347365000000003	46.330125000000002	Южная	0103000020E61000000100000005000000CA198A3BDE904540C74B3789412A4740CA198A3BDE9045403563D174762C47400ED940BAD89445403563D174762C47400ED940BAD8944540C74B3789412A4740CA198A3BDE904540C74B3789412A4740
55710	8777	43.485278000000001	43.514294	46.277571999999999	46.258316000000001	Ленина	0103000020E61000000100000005000000F1BBE9961DBE45404B04AA7F10214740F1BBE9961DBE45408524B37A87234740B743C362D4C145408524B37A87234740B743C362D4C145404B04AA7F10214740F1BBE9961DBE45404B04AA7F10214740
55828	8953	43.015495000000001	43.055075000000002	46.573852000000002	46.553584999999998	Ленинская	0103000020E6100000010000000500000032207BBDFB81454030478FDFDB46474032207BBDFB814540425F7AFB73494740E2E995B20C874540425F7AFB73494740E2E995B20C87454030478FDFDB46474032207BBDFB81454030478FDFDB464740
55531	9108	43.364221000000001	43.387478000000002	46.463856	46.449514999999998	Ленинская	0103000020E610000001000000050000001AC231CB9EAE4540DD0720B5893947401AC231CB9EAE4540D50627A25F3B4740B2F50CE198B14540D50627A25F3B4740B2F50CE198B14540DD0720B5893947401AC231CB9EAE4540DD0720B589394740
56290	8594	43.599516999999999	43.613844999999998	46.708551999999997	46.692464999999999	Веревкина	0103000020E61000000100000005000000B1321AF9BCCC4540F44F70B1A2584740B1321AF9BCCC4540F8C1F9D4B15A474014E8137992CE4540F8C1F9D4B15A474014E8137992CE4540F44F70B1A2584740B1321AF9BCCC4540F44F70B1A2584740
55591	8505	43.714672	43.755374000000003	46.729711999999999	46.695982000000001	40 лет Победы	0103000020E61000000100000005000000F7AE415F7ADB4540664D2CF015594740F7AE415F7ADB4540D7BFEB33675D4740D61F6118B0E04540D7BFEB33675D4740D61F6118B0E04540664D2CF015594740F7AE415F7ADB4540664D2CF015594740
55539	8653	43.806345	43.857585	46.481153999999997	46.457605000000001	Ленина	0103000020E6100000010000000500000085251E5036E7454038BEF6CC923A474085251E5036E74540772B4B74963D474024456458C5ED4540772B4B74963D474024456458C5ED454038BEF6CC923A474085251E5036E7454038BEF6CC923A4740
55827	8702	43.875641000000002	43.904989	46.352043000000002	46.335706000000002	Буденного	0103000020E61000000100000005000000B404190115F045401689096AF82A4740B404190115F0454093E4B9BE0F2D4740B01EF7ADD6F3454093E4B9BE0F2D4740B01EF7ADD6F345401689096AF82A4740B404190115F045401689096AF82A4740
55532	8052	41.727266	41.747388000000001	46.663955000000001	46.645127000000002	Ленина	0103000020E6100000010000000500000012BF620D17DD4440206283859352474012BF620D17DD44400282397AFC54474020B6F468AADF44400282397AFC54474020B6F468AADF4440206283859352474012BF620D17DD44402062838593524740
56280	8041	41.616342000000003	41.634326000000001	47.132786000000003	47.119126000000001	Лесная	0103000020E610000001000000050000005C936E4BE4CE4440390D51853F8F47405C936E4BE4CE4440EFAEB321FF9047405280289831D14440EFAEB321FF9047405280289831D14440390D51853F8F47405C936E4BE4CE4440390D51853F8F4740
39962	7761	41.346677	41.375594	47.111564999999999	47.093260999999998	Пионерская	0103000020E6100000010000000500000040A374E95FAC4440027FF8F9EF8B474040A374E95FAC44406A300DC3478E47407349D57613B044406A300DC3478E47407349D57613B04440027FF8F9EF8B474040A374E95FAC4440027FF8F9EF8B4740
39690	7364	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	переулок Красный	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
39685	7364	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	Матвеева	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
40225	7364	41.691234999999999	41.743687000000001	46.720593999999998	46.690623000000002	Горького	0103000020E61000000100000005000000DF6C73637AD84440C66E9F5566584740DF6C73637AD84440CFD8976C3C5C4740EDBAB72231DF4440CFD8976C3C5C4740EDBAB72231DF4440C66E9F5566584740DF6C73637AD84440C66E9F5566584740
56265	8212	41.604233000000001	41.631784000000003	46.810766000000001	46.792797	Свободная	0103000020E61000000100000005000000FD14C78157CD4440F7AE415F7A654740FD14C78157CD4440B85A272EC76747406B11514CDED04440B85A272EC76747406B11514CDED04440F7AE415F7A654740FD14C78157CD4440F7AE415F7A654740
40057	8265	41.868606999999997	41.893194000000001	46.647762	46.632894	Каштанов	0103000020E61000000100000005000000D009A1832EEF4440D5EAABAB02514740D009A1832EEF4440B8CB7EDDE9524740E17D552E54F24440B8CB7EDDE9524740E17D552E54F24440D5EAABAB02514740D009A1832EEF4440D5EAABAB02514740
56269	7755	41.135069999999999	41.147826000000002	47.164971999999999	47.152326000000002	Школьная	0103000020E61000000100000005000000DA5548F9499144404E2A1A6B7F934740DA5548F949914440BB6070CD1D954740CFBF5DF6EB924440BB6070CD1D954740CFBF5DF6EB9244404E2A1A6B7F934740DA5548F9499144404E2A1A6B7F934740
55825	8269	42.188704000000001	42.213039000000002	46.637714000000003	46.611386000000003	Школьная	0103000020E61000000100000005000000EC4FE27327184540BB9D7DE5414E4740EC4FE27327184540C619C39CA0514740E3E2A8DC441B4540C619C39CA0514740E3E2A8DC441B4540BB9D7DE5414E4740EC4FE27327184540BB9D7DE5414E4740
55528	7903	41.428953	41.452364000000003	47.010302000000003	47.001213	Центральная	0103000020E61000000100000005000000B34291EEE7B644403FAA61BF27804740B34291EEE7B64440AD8A709351814740A2F14410E7B94440AD8A709351814740A2F14410E7B944403FAA61BF27804740B34291EEE7B644403FAA61BF27804740
55826	8106	41.674706	41.696165999999998	46.850976000000003	46.840257000000001	Фермерская	0103000020E610000001000000050000001E3526C45CD64440179E978A8D6B47401E3526C45CD6444028D714C8EC6C4740274BADF71BD9444028D714C8EC6C4740274BADF71BD94440179E978A8D6B47401E3526C45CD64440179E978A8D6B4740
55712	7908	41.742896999999999	41.768687	47.015033000000003	47.006301000000001	Ленина	0103000020E61000000100000005000000F4A5B73F17DF44404F779E78CE804740F4A5B73F17DF44402EAEF199EC81474020EEEA5564E244402EAEF199EC81474020EEEA5564E244404F779E78CE804740F4A5B73F17DF44404F779E78CE804740
55589	7687	41.14302	41.164355	47.057034000000002	47.047542999999997	Целинная	0103000020E610000001000000050000004356B77A4E924440AD1397E3158647404356B77A4E9244404A61DEE34C87474090F7AA95099544404A61DEE34C87474090F7AA9509954440AD1397E3158647404356B77A4E924440AD1397E315864740
56014	7961	41.589123000000001	41.603127999999998	47.019683000000001	47.005982000000003	Огнева	0103000020E610000001000000050000002429E96168CB4440AE2EA704C48047402429E96168CB4440C2A4F8F884824740A4A65D4C33CD4440C2A4F8F884824740A4A65D4C33CD4440AE2EA704C48047402429E96168CB4440AE2EA704C4804740
39691	7813	41.542707	41.573932999999997	46.943057000000003	46.915523999999998	Гремучая	0103000020E61000000100000005000000B727486C77C54440FF59F3E32F754740B727486C77C54440C7A17E17B67847402E8CF4A276C94440C7A17E17B67847402E8CF4A276C94440FF59F3E32F754740B727486C77C54440FF59F3E32F754740
55526	6555	41.180309000000001	41.231898999999999	46.113425999999997	46.089767999999999	Ленина	0103000020E610000001000000050000005516855D14974440191D90847D0B47405516855D149744400F4240BE840E4740D07CCEDDAE9D44400F4240BE840E4740D07CCEDDAE9D4440191D90847D0B47405516855D14974440191D90847D0B4740
41085	7068	41.237701999999999	41.336849000000001	46.252876000000001	46.221403000000002	Ростовская	0103000020E61000000100000005000000CE18E6046D9E44403F1EFAEE561C4740CE18E6046D9E4440BEF8A23D5E2047405C5837DE1DAB4440BEF8A23D5E2047405C5837DE1DAB44403F1EFAEE561C4740CE18E6046D9E44403F1EFAEE561C4740
39959	7068	41.237701999999999	41.336849000000001	46.252876000000001	46.221403000000002	Комсомольская	0103000020E61000000100000005000000CE18E6046D9E44403F1EFAEE561C4740CE18E6046D9E4440BEF8A23D5E2047405C5837DE1DAB4440BEF8A23D5E2047405C5837DE1DAB44403F1EFAEE561C4740CE18E6046D9E44403F1EFAEE561C4740
40476	7068	41.237701999999999	41.336849000000001	46.252876000000001	46.221403000000002	Буденного	0103000020E61000000100000005000000CE18E6046D9E44403F1EFAEE561C4740CE18E6046D9E4440BEF8A23D5E2047405C5837DE1DAB4440BEF8A23D5E2047405C5837DE1DAB44403F1EFAEE561C4740CE18E6046D9E44403F1EFAEE561C4740
41084	6937	41.375557999999998	41.425944000000001	46.266527000000004	46.235405	Центральная площадь	0103000020E6100000010000000500000026E0D74812B044404E2844C0211E474026E0D74812B044402140868E1D224740B6F63E5585B644402140868E1D224740B6F63E5585B644404E2844C0211E474026E0D74812B044404E2844C0211E4740
41081	6287	41.031574999999997	41.131098999999999	46.214188	46.164625999999998	площадь им. В.И. Ленина	0103000020E61000000100000005000000832F4CA60A8444402009FB7612154740832F4CA60A8444400B992B836A1B4740E7C41EDAC79044400B992B836A1B4740E7C41EDAC79044402009FB7612154740832F4CA60A8444402009FB7612154740
39956	6287	41.031574999999997	41.131098999999999	46.214188	46.164625999999998	Орджоникидзе	0103000020E61000000100000005000000832F4CA60A8444402009FB7612154740832F4CA60A8444400B992B836A1B4740E7C41EDAC79044400B992B836A1B4740E7C41EDAC79044402009FB7612154740832F4CA60A8444402009FB7612154740
39684	6287	41.031574999999997	41.131098999999999	46.214188	46.164625999999998	Народная	0103000020E61000000100000005000000832F4CA60A8444402009FB7612154740832F4CA60A8444400B992B836A1B4740E7C41EDAC79044400B992B836A1B4740E7C41EDAC79044402009FB7612154740832F4CA60A8444402009FB7612154740
40466	6287	41.031574999999997	41.131098999999999	46.214188	46.164625999999998	Бабина	0103000020E61000000100000005000000832F4CA60A8444402009FB7612154740832F4CA60A8444400B992B836A1B4740E7C41EDAC79044400B992B836A1B4740E7C41EDAC79044402009FB7612154740832F4CA60A8444402009FB7612154740
55711	7024	41.439131000000003	41.496138000000002	46.291947	46.276445000000002	Дружбы	0103000020E6100000010000000500000074D4D17135B844404512BD8C6223474074D4D17135B844402995F0845E254740C426327381BF44402995F0845E254740C426327381BF44404512BD8C6223474074D4D17135B844404512BD8C62234740
40470	6614	41.242598000000001	41.290128000000003	46.042608000000001	45.990430000000003	Ленина	0103000020E610000001000000050000009A0986730D9F4440187D0569C6FE46409A0986730D9F44402446CF2D74054740B3D30FEA22A544402446CF2D74054740B3D30FEA22A54440187D0569C6FE46409A0986730D9F4440187D0569C6FE4640
55529	6806	41.470194999999997	41.529905999999997	46.136868	46.086798999999999	площадь Школьная	0103000020E6100000010000000500000011DF89592FBC4440AA29C93A1C0B474011DF89592FBC444039EFFFE38411474022FAB5F5D3C3444039EFFFE38411474022FAB5F5D3C34440AA29C93A1C0B474011DF89592FBC4440AA29C93A1C0B4740
41082	6806	41.470194999999997	41.529905999999997	46.136868	46.086798999999999	Кирова	0103000020E6100000010000000500000011DF89592FBC4440AA29C93A1C0B474011DF89592FBC444039EFFFE38411474022FAB5F5D3C3444039EFFFE38411474022FAB5F5D3C34440AA29C93A1C0B474011DF89592FBC4440AA29C93A1C0B4740
56266	6752	41.322457999999997	41.384154000000002	46.104148000000002	46.060096000000001	Московская	0103000020E61000000100000005000000B22AC24D46A944406A4FC939B1074740B22AC24D46A94440CFF8BEB8540D4740555051F52BB14440CFF8BEB8540D4740555051F52BB144406A4FC939B1074740B22AC24D46A944406A4FC939B1074740
40473	6752	41.322457999999997	41.384154000000002	46.104148000000002	46.060096000000001	Ленина	0103000020E61000000100000005000000B22AC24D46A944406A4FC939B1074740B22AC24D46A94440CFF8BEB8540D4740555051F52BB14440CFF8BEB8540D4740555051F52BB144406A4FC939B1074740B22AC24D46A944406A4FC939B1074740
55527	6885	41.647432999999999	41.664760999999999	46.104004000000003	46.089548999999998	Ленина	0103000020E61000000100000005000000F3ACA415DFD24440DB317557760B4740F3ACA415DFD244409C53C900500D4740005471E316D544409C53C900500D4740005471E316D54440DB317557760B4740F3ACA415DFD24440DB317557760B4740
40478	7326	41.143270999999999	41.205317999999998	46.338686000000003	46.318356000000001	переулок Советский	0103000020E610000001000000050000008CBB41B456924440213EB0E3BF2847408CBB41B45692444079CE16105A2B4740DBA337DC479A444079CE16105A2B4740DBA337DC479A4440213EB0E3BF2847408CBB41B456924440213EB0E3BF284740
56452	56919	42.220880999999999	42.245558000000003	46.961461	46.933605999999997	Школьная	0103000020E6100000010000000500000065A71FD4451C4540B8ACC2668077474065A71FD4451C454092B06F27117B4740B6A2CD716E1F454092B06F27117B4740B6A2CD716E1F4540B8ACC2668077474065A71FD4451C4540B8ACC26680774740
56469	56933	42.423892000000002	42.446869999999997	46.743022000000003	46.723385999999998	Транспортная	0103000020E610000001000000050000009D84D217423645402F3196E9975C47409D84D21742364540B11A4B581B5F474021C8410933394540B11A4B581B5F474021C84109333945402F3196E9975C47409D84D217423645402F3196E9975C4740
56457	56923	41.895277999999998	41.917628000000001	47.057532000000002	47.045461000000003	Молодежная	0103000020E61000000100000005000000056A317898F244402A1F82AAD1854740056A317898F244409B3C65355D8747406BF294D574F544409B3C65355D8747406BF294D574F544402A1F82AAD1854740056A317898F244402A1F82AAD1854740
56553	57005	42.220657000000003	42.239916999999998	47.009914000000002	46.991200999999997	Дорожная	0103000020E610000001000000050000001651137D3E1C45409961A3ACDF7E47401651137D3E1C4540E3E2A8DC448147409160AA99B51E4540E3E2A8DC448147409160AA99B51E45409961A3ACDF7E47401651137D3E1C45409961A3ACDF7E4740
56276	56838	42.676264000000003	42.685957000000002	46.720433	46.712395000000001	Микояновская	0103000020E6100000010000000500000028BB99D18F564540BE6A65C22F5B474028BB99D18F564540C6FA0626375C47402CBB6070CD574540C6FA0626375C47402CBB6070CD574540BE6A65C22F5B474028BB99D18F564540BE6A65C22F5B4740
56012	4531	42.519562000000001	42.533675000000002	46.591392999999997	46.578443	Школьная	0103000020E61000000100000005000000471FF30181424540D1CC936B0A4A4740471FF30181424540AA0A0DC4B24B4740AED85F764F444540AA0A0DC4B24B4740AED85F764F444540D1CC936B0A4A4740471FF30181424540D1CC936B0A4A4740
56007	3209	42.851903	42.863491000000003	46.487172999999999	46.479365999999999	Южная	0103000020E61000000100000005000000A12E52280B6D45403C6876DD5B3D4740A12E52280B6D4540423F53AF5B3E4740F7B182DF866E4540423F53AF5B3E4740F7B182DF866E45403C6876DD5B3D4740A12E52280B6D45403C6876DD5B3D4740
56399	56871	41.961492999999997	41.988881999999997	46.752667000000002	46.743485	Луговая	0103000020E610000001000000050000009D2ADF3312FB4440850838842A5F47409D2ADF3312FB4440A4E36A645760474031CD74AF93FE4440A4E36A645760474031CD74AF93FE4440850838842A5F47409D2ADF3312FB4440850838842A5F4740
55523	56670	41.889645000000002	41.921455000000002	46.830374999999997	46.821323999999997	Веселая	0103000020E6100000010000000500000064062AE3DFF14440BFB513252169474064062AE3DFF144403F355EBA496A47402BDEC83CF2F544403F355EBA496A47402BDEC83CF2F54440BFB513252169474064062AE3DFF14440BFB5132521694740
56526	56984	42.195064000000002	42.218688999999998	47.041303999999997	47.025593000000001	 Транспортная	0103000020E6100000010000000500000040506EDBF7184540D600A5A14683474040506EDBF7184540D4981073498547405A7F4B00FE1B4540D4981073498547405A7F4B00FE1B4540D600A5A14683474040506EDBF7184540D600A5A146834740
55919	56771	42.367998	42.391947000000002	46.674103000000002	46.657232999999998	 Школьная	0103000020E61000000100000005000000287FF78E1A2F45400D6D003620544740287FF78E1A2F45405891D10149564740F661BD512B3245405891D10149564740F661BD512B3245400D6D003620544740287FF78E1A2F45400D6D003620544740
55604	56676	42.196851000000002	42.231445000000001	46.769593999999998	46.747906	Коммунистическая	0103000020E61000000100000005000000AB97DF6932194540B83D4162BB5F4740AB97DF69321945405299620E826247404FE960FD9F1D45405299620E826247404FE960FD9F1D4540B83D4162BB5F4740AB97DF6932194540B83D4162BB5F4740
41080	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	переулок Почтовый	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
40224	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	переулок П.Ф. Костенко	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
55147	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	пер. Чапаевский	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
55135	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	пер. Октябрьский	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
39882	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	Рябиновая	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
39955	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	Пролетарская	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
39954	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	Пионерская	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
40465	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	Красноармейская	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
40054	5805	42.004145000000001	42.089179000000001	46.890495999999999	46.852725999999997	Коммунальная	0103000020E6100000010000000500000091B8C7D28700454075392520266D474091B8C7D287004540029CDEC5FB714740B83EAC376A0B4540029CDEC5FB714740B83EAC376A0B454075392520266D474091B8C7D28700454075392520266D4740
56278	4759	42.045071999999998	42.071914	47.003566999999997	46.992811000000003	Степная	0103000020E610000001000000050000008FFB56EBC4054540F60D4C6E147F47408FFB56EBC4054540232C2AE274804740F10F5B7A34094540232C2AE274804740F10F5B7A34094540F60D4C6E147F47408FFB56EBC4054540F60D4C6E147F4740
56263	56835	42.665241999999999	42.696575000000003	46.620410999999997	46.592044000000001	Антоновская	0103000020E610000001000000050000007BF65CA62655454082E50819C84B47407BF65CA626554540118AADA0694F4740091B9E5E29594540118AADA0694F4740091B9E5E2959454082E50819C84B47407BF65CA62655454082E50819C84B4740
56275	4527	42.702925999999998	42.7301	46.437983000000003	46.428468000000002	Приозерная	0103000020E6100000010000000500000009C1AA7AF9594540F7B0170AD836474009C1AA7AF95945401C9AB2D30F384740A167B3EA735D45401C9AB2D30F384740A167B3EA735D4540F7B0170AD836474009C1AA7AF9594540F7B0170AD8364740
55841	56700	42.001368999999997	42.018957999999998	47.066954000000003	47.052264000000001	Магистральная	0103000020E61000000100000005000000361D01DC2C0045400B613596B0864740361D01DC2C0045400F2BDCF291884740B0FF3A376D0245400F2BDCF291884740B0FF3A376D0245400B613596B0864740361D01DC2C0045400B613596B0864740
55866	56723	42.033842999999997	42.055007000000003	46.843640999999998	46.821162999999999	Колхозный переулок	0103000020E610000001000000050000006919A9F754044540B6D782DE1B6947406919A9F7540445404948A46DFC6B47408A0629780A0745404948A46DFC6B47408A0629780A074540B6D782DE1B6947406919A9F754044540B6D782DE1B694740
56282	56840	42.168014999999997	42.185451999999998	46.838574000000001	46.828384	Новоселов	0103000020E61000000100000005000000641EF98381154540CC43A67C086A4740641EF9838115454051A39064566B4740287D21E4BC17454051A39064566B4740287D21E4BC174540CC43A67C086A4740641EF98381154540CC43A67C086A4740
55714	56684	42.783721	42.818261	46.577966000000004	46.557997	пер. Театральный	0103000020E610000001000000050000001E1840F850644540102219726C4747401E1840F850644540981936CAFA494740CF4BC5C6BC684540981936CAFA494740CF4BC5C6BC684540102219726C4747401E1840F850644540102219726C474740
56508	56967	42.088155	42.123522000000001	46.778494000000002	46.760001000000003	Почтовый переулок	0103000020E610000001000000050000004CFDBCA9480B4540B2F677B6476147404CFDBCA9480B4540ED10FFB0A5634740132BA391CF0F4540ED10FFB0A5634740132BA391CF0F4540B2F677B6476147404CFDBCA9480B4540B2F677B647614740
41079	4972	42.193652999999998	42.231284000000002	47.023860999999997	46.994624999999999	переулок Красноармейский	0103000020E61000000100000005000000DAE21A9FC91845405A643BDF4F7F4740DAE21A9FC91845402E5393E00D834740460BD0B69A1D45402E5393E00D834740460BD0B69A1D45405A643BDF4F7F4740DAE21A9FC91845405A643BDF4F7F4740
32951	4972	42.193652999999998	42.231284000000002	47.023860999999997	46.994624999999999	Кирова	0103000020E61000000100000005000000DAE21A9FC91845405A643BDF4F7F4740DAE21A9FC91845402E5393E00D834740460BD0B69A1D45402E5393E00D834740460BD0B69A1D45405A643BDF4F7F4740DAE21A9FC91845405A643BDF4F7F4740
55261	56624	42.614963000000003	42.651417000000002	46.664166000000002	46.645572000000001	Школьная	0103000020E6100000010000000500000002A08A1BB74E45404E9B711AA252474002A08A1BB74E4540BD8E3864035547407B87DBA161534540BD8E3864035547407B87DBA1615345404E9B711AA252474002A08A1BB74E45404E9B711AA2524740
55134	4755	41.990724	42.029082000000002	46.948483000000003	46.938245000000002	пер. Центральный	0103000020E6100000010000000500000060AE450BD0FE4440595183691878474060AE450BD0FE4440EFE714E4677947407E737FF5B8034540EFE714E4677947407E737FF5B8034540595183691878474060AE450BD0FE44405951836918784740
55892	56745	41.888872999999997	41.907629999999997	46.789223999999997	46.775765999999997	Центральная	0103000020E6100000010000000500000011A62897C6F14440A3ACDF4C4C63474011A62897C6F14440F19BC24A056547402A6F47382DF44440F19BC24A056547402A6F47382DF44440A3ACDF4C4C63474011A62897C6F14440A3ACDF4C4C634740
56514	56970	41.827365	41.842897000000001	46.941617000000001	46.932726000000002	Солнечная	0103000020E61000000100000005000000726DA818E7E944408010C99063774740726DA818E7E94440C72DE6E786784740C172840CE4EB4440C72DE6E786784740C172840CE4EB44408010C99063774740726DA818E7E944408010C99063774740
55824	4418	42.635562	42.664513999999997	46.552146999999998	46.534067	Садовая	0103000020E61000000100000005000000494A7A185A514540B96FB54E5C444740494A7A185A514540D1CABDC0AC464740F8DD74CB0E554540D1CABDC0AC464740F8DD74CB0E554540B96FB54E5C444740494A7A185A514540B96FB54E5C444740
55969	56797	42.177142000000003	42.190860000000001	46.712376999999996	46.700344999999999	пер. Кооперативный	0103000020E61000000100000005000000C05FCC96AC1645406475ABE7A4594740C05FCC96AC16454017B6662B2F5B4740AA0EB9196E18454017B6662B2F5B4740AA0EB9196E1845406475ABE7A4594740C05FCC96AC1645406475ABE7A4594740
56524	56982	42.278345999999999	42.290914000000001	46.942391999999998	46.934005999999997	Пушкинская	0103000020E61000000100000005000000787C7BD7A0234540462234828D774740787C7BD7A02345408A01124DA07847406AF981AB3C2545408A01124DA07847406AF981AB3C254540462234828D774740787C7BD7A0234540462234828D774740
56138	56816	42.242486	42.252924	46.805492000000001	46.783492000000003	Колхозная	0103000020E6100000010000000500000072DEFFC7091F4540BD5642774964474072DEFFC7091F45404698A25C1A674740CF2F4AD05F2045404698A25C1A674740CF2F4AD05F204540BD5642774964474072DEFFC7091F4540BD56427749644740
56260	56833	42.883136999999998	42.905450999999999	46.618022000000003	46.605832999999997	Запрудная	0103000020E610000001000000050000009B711AA20A71454035EB8CEF8B4D47409B711AA20A714540B11A4B581B4F4740B49080D1E5734540B11A4B581B4F4740B49080D1E573454035EB8CEF8B4D47409B711AA20A71454035EB8CEF8B4D4740
55879	56734	42.019587000000001	42.040320000000001	46.839333000000003	46.818005999999997	Садовый переулок	0103000020E61000000100000005000000A036AAD38102454044F7AC6BB4684740A036AAD3810245400FBA84436F6B4740F7AFAC34290545400FBA84436F6B4740F7AFAC342905454044F7AC6BB4684740A036AAD38102454044F7AC6BB4684740
56440	56908	42.246608999999999	42.270226000000001	46.716856	46.695945000000002	Победы	0103000020E610000001000000050000001BF33AE2901F45404968CBB9145947401BF33AE2901F45407FF8F9EFC15B4740B343FCC3962245407FF8F9EFC15B4740B343FCC3962245404968CBB9145947401BF33AE2901F45404968CBB914594740
40442	21138	40.035091999999999	40.053705000000001	47.495714999999997	47.485444000000001	Восточная	0103000020E61000000100000005000000F52C08E57D0444400C056C0723BE4740F52C08E57D0444407D91D09673BF4740DB5031CEDF0644407D91D09673BF4740DB5031CEDF0644400C056C0723BE4740F52C08E57D0444400C056C0723BE4740
56359	26890	40.331615999999997	40.345953999999999	47.632584000000001	47.622978000000003	Центральная	0103000020E61000000100000005000000486AA164722A444052103CBEBDCF4740486AA164722A444087FC3383F8D04740CFF57D38482C444087FC3383F8D04740CFF57D38482C444052103CBEBDCF4740486AA164722A444052103CBEBDCF4740
56217	20220	40.595073999999997	40.609492000000003	47.856011000000002	47.847110999999998	Майская	0103000020E61000000100000005000000965984622B4C44407A8A1C226EEC4740965984622B4C44401502B9C491ED47403A9677D5034E44401502B9C491ED47403A9677D5034E44407A8A1C226EEC4740965984622B4C44407A8A1C226EEC4740
39908	21703	40.096958000000001	40.136619000000003	47.538716000000001	47.50394	Школьная	0103000020E61000000100000005000000F48AA71E690C4440B8921D1B81C04740F48AA71E690C44407DEA58A5F4C4474091813CBB7C1144407DEA58A5F4C4474091813CBB7C114440B8921D1B81C04740F48AA71E690C4440B8921D1B81C04740
41047	21703	40.096958000000001	40.136619000000003	47.538716000000001	47.50394	Московская	0103000020E61000000100000005000000F48AA71E690C4440B8921D1B81C04740F48AA71E690C44407DEA58A5F4C4474091813CBB7C1144407DEA58A5F4C4474091813CBB7C114440B8921D1B81C04740F48AA71E690C4440B8921D1B81C04740
40094	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	проспект Ермака	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39641	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Энгельса	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
41017	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Чехова	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39643	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Центральная	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40265	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Троицкая	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40268	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Свободы	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40096	6945	39.614060000000002	39.715803000000001	47.345292999999998	47.225712999999999	Ростовский выезд	0103000020E6100000010000000500000011E4A08499CE43401AA4E029E49C474011E4A08499CE4340D4449F8F32AC474079B0C56E9FDB4340D4449F8F32AC474079B0C56E9FDB43401AA4E029E49C474011E4A08499CE43401AA4E029E49C4740
40373	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Пушкинская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
56327	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Просторный переулок	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40097	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Просвещения	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39642	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Платовский проспект	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40400	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Петрова	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40245	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Первомайская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40271	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Парковый проспект	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
32958	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Новый городок	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40270	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Молодежная	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39645	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Мелиховская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40398	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Мацоты	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40098	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Клещева	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40269	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Калинина	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
41006	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Заводская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
41003	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Ермака	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40397	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Гвардейская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40099	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Высоковольтная	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40381	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Буденновская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
39640	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Баклановский проспект	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40210	6945	40.022038999999999	40.267225000000003	47.501376999999998	47.389344999999999	Александровская	0103000020E61000000100000005000000471E882CD202444039EE940ED6B14740471E882CD2024440B9FB1C1F2DC0474039D6C56D34224440B9FB1C1F2DC0474039D6C56D3422444039EE940ED6B14740471E882CD202444039EE940ED6B14740
40112	20846	40.178310000000003	40.194282000000001	47.650117999999999	47.633896	Мокроусова	0103000020E610000001000000050000005F46B1DCD216444059880E8123D147405F46B1DCD21644403D450E1137D34740CA198A3BDE1844403D450E1137D34740CA198A3BDE18444059880E8123D147405F46B1DCD216444059880E8123D14740
55506	21083	39.923718000000001	39.970125000000003	47.555332	47.531063000000003	Советская	0103000020E61000000100000005000000FF5C34643CF64340CE8E54DFF9C34740FF5C34643CF643400D36751E15C747401904560E2DFC43400D36751E15C747401904560E2DFC4340CE8E54DFF9C34740FF5C34643CF64340CE8E54DFF9C34740
56344	20956	39.962211000000003	39.980958999999999	47.774895000000001	47.761093000000002	Центральная	0103000020E61000000100000005000000FD6CE4BA29FB4340761BD47E6BE14740FD6CE4BA29FB4340BE6A65C22FE34740C2DB831090FD4340BE6A65C22FE34740C2DB831090FD4340761BD47E6BE14740FD6CE4BA29FB4340761BD47E6BE14740
40437	19983	40.299430000000001	40.310155999999999	47.773902	47.763697999999998	Клубная	0103000020E610000001000000050000007CB8E4B853264440A30227DBC0E147407CB8E4B8532644408D2782380FE347403F541A31B32744408D2782380FE347403F541A31B3274440A30227DBC0E147407CB8E4B853264440A30227DBC0E14740
55654	21584	40.420845999999997	40.436818000000002	47.674295000000001	47.662365999999999	Ленина	0103000020E6100000010000000500000082531F48DE354440BDFDB968C8D4474082531F48DE3544409C6D6E4C4FD64740EE26F8A6E93744409C6D6E4C4FD64740EE26F8A6E9374440BDFDB968C8D4474082531F48DE354440BDFDB968C8D44740
39905	21324	40.459626	40.472382000000003	47.593446999999998	47.578715000000003	Ленина	0103000020E6100000010000000500000016325706D53A4440325A475513CA474016325706D53A444064744012F6CB47400B9C6C03773C444064744012F6CB47400B9C6C03773C4440325A475513CA474016325706D53A4440325A475513CA4740
56331	21573	40.536073000000002	40.558602999999998	47.663567	47.659731999999998	Рослова	0103000020E6100000010000000500000062A2410A9E444440F50F221972D4474062A2410A9E44444038DA71C3EFD447404739984D8047444038DA71C3EFD447404739984D80474440F50F221972D4474062A2410A9E444440F50F221972D44740
56081	21047	40.077689999999997	40.083969000000003	47.659744000000003	47.654232999999998	Вишневая	0103000020E61000000100000005000000F59CF4BEF1094440637B2DE8BDD34740F59CF4BEF1094440BADDCB7D72D447405D70067FBF0A4440BADDCB7D72D447405D70067FBF0A4440637B2DE8BDD34740F59CF4BEF1094440637B2DE8BDD34740
55631	21668	40.331895000000003	40.351191	47.693488000000002	47.679476000000001	Клубная	0103000020E610000001000000050000005C5A0D897B2A44405D35CF11F9D647405C5A0D897B2A44409015FC36C4D8474024D3A1D3F32C44409015FC36C4D8474024D3A1D3F32C44405D35CF11F9D647405C5A0D897B2A44405D35CF11F9D64740
55246	21414	40.137985	40.196230999999997	47.423399000000003	47.378168000000002	Советская	0103000020E61000000100000005000000562B137EA911444066321CCF67B04740562B137EA91144405E143DF031B647400EBBEF181E1944405E143DF031B647400EBBEF181E19444066321CCF67B04740562B137EA911444066321CCF67B04740
41044	21414	40.137985	40.196230999999997	47.423399000000003	47.378168000000002	Октябрьская	0103000020E61000000100000005000000562B137EA911444066321CCF67B04740562B137EA91144405E143DF031B647400EBBEF181E1944405E143DF031B647400EBBEF181E19444066321CCF67B04740562B137EA911444066321CCF67B04740
39682	21414	40.137985	40.196230999999997	47.423399000000003	47.378168000000002	Кооперативная	0103000020E61000000100000005000000562B137EA911444066321CCF67B04740562B137EA91144405E143DF031B647400EBBEF181E1944405E143DF031B647400EBBEF181E19444066321CCF67B04740562B137EA911444066321CCF67B04740
40114	21414	40.137985	40.196230999999997	47.423399000000003	47.378168000000002	Кирпичная	0103000020E61000000100000005000000562B137EA911444066321CCF67B04740562B137EA91144405E143DF031B647400EBBEF181E1944405E143DF031B647400EBBEF181E19444066321CCF67B04740562B137EA911444066321CCF67B04740
40445	21211	40.067134000000003	40.117412999999999	47.558700999999999	47.506034	Советская	0103000020E610000001000000050000008F39CFD8970844400055DCB8C5C047408F39CFD8970844400A9FAD8383C747400890A163070F44400A9FAD8383C747400890A163070F44400055DCB8C5C047408F39CFD8970844400055DCB8C5C04740
40575	21211	40.067134000000003	40.117412999999999	47.558700999999999	47.506034	Горького	0103000020E610000001000000050000008F39CFD8970844400055DCB8C5C047408F39CFD8970844400A9FAD8383C747400890A163070F44400A9FAD8383C747400890A163070F44400055DCB8C5C047408F39CFD8970844400055DCB8C5C04740
56090	56810	40.336511999999999	40.361378000000002	47.668894999999999	47.654961	Центральная	0103000020E61000000100000005000000145B41D3122B4440E69315C3D5D34740145B41D3122B44409DBAF2599ED5474038BF61A2412E44409DBAF2599ED5474038BF61A2412E4440E69315C3D5D34740145B41D3122B4440E69315C3D5D34740
39663	54810	40.023862999999999	40.046185999999999	47.695441000000002	47.680508000000003	Чистова	0103000020E61000000100000005000000CF4A5AF10D0344404C55DAE21AD74740CF4A5AF10D03444016A6EF3504D947403BC43F6CE905444016A6EF3504D947403BC43F6CE90544404C55DAE21AD74740CF4A5AF10D0344404C55DAE21AD74740
39660	20598	40.192889999999998	40.206975	47.656478999999997	47.639080999999997	Чапаева	0103000020E61000000100000005000000DBDC989EB01844405B3FFD67CDD14740DBDC989EB018444061C1FD8007D44740780B24287E1A444061C1FD8007D44740780B24287E1A44405B3FFD67CDD14740DBDC989EB01844405B3FFD67CDD14740
56279	20105	40.292718999999998	40.309562999999997	47.690443999999999	47.681254000000003	Центральная	0103000020E610000001000000050000007BF5F1D0772544407522C15433D747407BF5F1D07725444016DC0F7860D847409C86A8C29F27444016DC0F7860D847409C86A8C29F2744407522C15433D747407BF5F1D0772544407522C15433D74740
55518	19895	40.383305	40.401468999999999	47.782851999999998	47.764012999999998	 Ленина	0103000020E6100000010000000500000057B2632310314440035C902DCBE1474057B2632310314440D9CD8C7E34E44740CDAD105663334440D9CD8C7E34E44740CDAD105663334440035C902DCBE1474057B2632310314440035C902DCBE14740
55658	20455	40.592227000000001	40.610075999999999	47.778807	47.758034000000002	Советская	0103000020E6100000010000000500000073672618CE4B4440C7A0134207E1474073672618CE4B4440AC72A1F2AFE3474089096AF8164E4440AC72A1F2AFE3474089096AF8164E4440C7A0134207E1474073672618CE4B4440C7A0134207E14740
40195	22006	40.182172999999999	40.218823999999998	47.679476000000001	47.642864000000003	переулок Шоссейный	0103000020E610000001000000050000006B9BE271511744404CE3175E49D247406B9BE271511744405D35CF11F9D647403ACAC16C021C44405D35CF11F9D647403ACAC16C021C44404CE3175E49D247406B9BE271511744404CE3175E49D24740
55187	22006	40.182172999999999	40.218823999999998	47.679476000000001	47.642864000000003	Ленина	0103000020E610000001000000050000006B9BE271511744404CE3175E49D247406B9BE271511744405D35CF11F9D647403ACAC16C021C44405D35CF11F9D647403ACAC16C021C44404CE3175E49D247406B9BE271511744404CE3175E49D24740
40116	22006	40.182172999999999	40.218823999999998	47.679476000000001	47.642864000000003	Крупской	0103000020E610000001000000050000006B9BE271511744404CE3175E49D247406B9BE271511744405D35CF11F9D647403ACAC16C021C44405D35CF11F9D647403ACAC16C021C44404CE3175E49D247406B9BE271511744404CE3175E49D24740
40276	22006	40.182172999999999	40.218823999999998	47.679476000000001	47.642864000000003	4-й переулок	0103000020E610000001000000050000006B9BE271511744404CE3175E49D247406B9BE271511744405D35CF11F9D647403ACAC16C021C44405D35CF11F9D647403ACAC16C021C44404CE3175E49D247406B9BE271511744404CE3175E49D24740
55176	56618	40.182172999999999	40.218823999999998	47.679476000000001	47.642864000000003	Дзержинского	0103000020E610000001000000050000006B9BE271511744404CE3175E49D247406B9BE271511744405D35CF11F9D647403ACAC16C021C44405D35CF11F9D647403ACAC16C021C44404CE3175E49D247406B9BE271511744404CE3175E49D24740
55967	26887	40.006704999999997	40.022011999999997	47.781005	47.766404999999999	Центральная	0103000020E610000001000000050000001EDC9DB5DB004440D53E1D8F19E247401EDC9DB5DB0044409981CAF8F7E347404D0F0A4AD10244409981CAF8F7E347404D0F0A4AD1024440D53E1D8F19E247401EDC9DB5DB004440D53E1D8F19E24740
56328	20415	40.409841999999998	40.441633000000003	47.443885999999999	47.375946999999996	Центральная	0103000020E610000001000000050000007C43E1B375344440C00303081FB047407C43E1B3753444407D93A641D1B84740CDEA1D6E873844407D93A641D1B84740CDEA1D6E87384440C00303081FB047407C43E1B375344440C00303081FB04740
41048	21881	40.114026000000003	40.132657999999999	47.567991999999997	47.548515000000002	Российская	0103000020E6100000010000000500000065726A67980E4440C72E51BD35C6474065726A67980E4440DF313CF6B3C84740C1C6F5EFFA104440DF313CF6B3C84740C1C6F5EFFA104440C72E51BD35C6474065726A67980E4440C72E51BD35C64740
55752	21881	40.114026000000003	40.132657999999999	47.567991999999997	47.548515000000002	 им. Петрушко	0103000020E6100000010000000500000065726A67980E4440C72E51BD35C6474065726A67980E4440DF313CF6B3C84740C1C6F5EFFA104440DF313CF6B3C84740C1C6F5EFFA104440C72E51BD35C6474065726A67980E4440C72E51BD35C64740
55629	21870	40.174007000000003	40.198144999999997	47.465997000000002	47.453867000000002	Садовая	0103000020E61000000100000005000000362383DC45164440E8DD585018BA4740362383DC451644405E8429CAA5BB4740D66EBBD05C1944405E8429CAA5BB4740D66EBBD05C194440E8DD585018BA4740362383DC45164440E8DD585018BA4740
40113	20987	40.127896	40.142512000000004	47.702446000000002	47.694544	Железнодорожная	0103000020E6100000010000000500000005A568E55E10444007D15AD1E6D8474005A568E55E1044405F9A22C0E9D94740CFA44DD53D1244405F9A22C0E9D94740CFA44DD53D12444007D15AD1E6D8474005A568E55E10444007D15AD1E6D84740
39658	19849	39.873835	39.899042000000001	47.751147000000003	47.736181000000002	Победы Революции	0103000020E61000000100000005000000D28C45D3D9EF4340E277D32D3BDE4740D28C45D3D9EF434088BEBB9525E047407FDDE9CE13F3434088BEBB9525E047407FDDE9CE13F34340E277D32D3BDE4740D28C45D3D9EF4340E277D32D3BDE4740
40438	20236	40.294758999999999	40.333674000000002	47.416381999999999	47.397494999999999	Ленина	0103000020E61000000100000005000000D099B4A9BA25444069A9BC1DE1B24740D099B4A9BA254440505260014CB5474044C362D4B52A4440505260014CB5474044C362D4B52A444069A9BC1DE1B24740D099B4A9BA25444069A9BC1DE1B24740
56329	20688	40.328868	40.335659	47.594996999999999	47.583699000000003	Центральная	0103000020E61000000100000005000000B859BC58182A44409DDA19A6B6CA4740B859BC58182A4440EB1B98DC28CC4740D5CDC5DFF62A4440EB1B98DC28CC4740D5CDC5DFF62A44409DDA19A6B6CA4740B859BC58182A44409DDA19A6B6CA4740
55995	20588	40.533073000000002	40.546942999999999	47.752425000000002	47.743355000000001	Школьная	0103000020E61000000100000005000000B8B06EBC3B444440B728B34126DF4740B8B06EBC3B444440AED85F764FE0474058E36C3A02464440AED85F764FE0474058E36C3A02464440B728B34126DF4740B8B06EBC3B444440B728B34126DF4740
56169	52150	40.463723000000002	40.471125000000001	47.740107000000002	47.725561999999996	Логвинова	0103000020E6100000010000000500000096B377465B3B4440349C3237DFDC474096B377465B3B4440354580D3BBDE4740FCA9F1D24D3C4440354580D3BBDE4740FCA9F1D24D3C4440349C3237DFDC474096B377465B3B4440349C3237DFDC4740
56332	20110	40.439576000000002	40.460991999999997	47.843578999999998	47.839086000000002	Галенко	0103000020E61000000100000005000000A20DC006443844400744882B67EB4740A20DC00644384440D34B8C65FAEB4740DBDB2DC9013B4440D34B8C65FAEB4740DBDB2DC9013B44400744882B67EB4740A20DC006443844400744882B67EB4740
40275	20706	40.155852000000003	40.170062999999999	47.604286999999999	47.593592999999998	Школьная	0103000020E61000000100000005000000138255F5F21344403811FDDAFACB4740138255F5F2134440F032C34659CD47403CA1D79FC4154440F032C34659CD47403CA1D79FC41544403811FDDAFACB4740138255F5F21344403811FDDAFACB4740
40439	20340	40.326182000000003	40.354604000000002	47.407387999999997	47.394024000000002	Комарова	0103000020E610000001000000050000009E45EF54C029444068EBE0606FB247409E45EF54C029444034643C4A25B44740F183F3A9632D444034643C4A25B44740F183F3A9632D444068EBE0606FB247409E45EF54C029444068EBE0606FB24740
56000	21293	40.034229000000003	40.042557000000002	47.638661999999997	47.630282999999999	Заповедная	0103000020E6100000010000000500000093C9A99D61044440C51C041DADD0474093C9A99D61044440569929ADBFD14740A29BFD8172054440569929ADBFD14740A29BFD8172054440C51C041DADD0474093C9A99D61044440C51C041DADD04740
56040	19998	40.210011000000002	40.214880000000001	47.765073000000001	47.758222000000004	Центральная	0103000020E610000001000000050000006F66F4A3E11A4440CA8D226B0DE147406F66F4A3E11A4440BC067DE9EDE1474041481630811B4440BC067DE9EDE1474041481630811B4440CA8D226B0DE147406F66F4A3E11A4440CA8D226B0DE14740
55576	19806	39.914205000000003	39.943534999999997	47.706296000000002	47.676904	Ленина	0103000020E610000001000000050000007B6B60AB04F543400B444FCAA4D647407B6B60AB04F54340D7A546E867DA4740D0D03FC1C5F84340D7A546E867DA4740D0D03FC1C5F843400B444FCAA4D647407B6B60AB04F543400B444FCAA4D64740
56044	28828	42.516660999999999	42.642380000000003	48.897742000000001	48.852732000000003	Центральная	0103000020E61000000100000005000000300F99F22142454058207A52266D4840300F99F221424540711FB935E972484060CD018239524540711FB935E972484060CD01823952454058207A52266D4840300F99F22142454058207A52266D4840
55836	28610	42.434950000000001	42.479030000000002	48.554757000000002	48.540275000000001	Первомайская	0103000020E6100000010000000500000096B20C71AC37454057EC2FBB2745484096B20C71AC374540111D024702474840C5E6E3DA503D4540111D024702474840C5E6E3DA503D454057EC2FBB2745484096B20C71AC37454057EC2FBB27454840
56096	29333	42.182011000000003	42.194254999999998	48.666032999999999	48.655154000000003	Казачья	0103000020E610000001000000050000009241EE224C174540FBEB1516DC5348409241EE224C1745404487C09140554840D00A0C59DD1845404487C09140554840D00A0C59DD184540FBEB1516DC5348409241EE224C174540FBEB1516DC534840
55551	28929	42.269812000000002	42.295028000000002	48.551352000000001	48.522973	Ленина	0103000020E61000000100000005000000C0081A338922454073D87DC7F0424840C0081A3389224540C74ACCB392464840C0B33D7AC3254540C74ACCB392464840C0B33D7AC325454073D87DC7F0424840C0081A338922454073D87DC7F0424840
56309	28960	42.145296999999999	42.191982000000003	48.484475000000003	48.466341999999997	Школьная	0103000020E610000001000000050000007C9A93179912454028603B18B13B48407C9A931799124540645DDC46033E4840D9B5BDDD92184540645DDC46033E4840D9B5BDDD9218454028603B18B13B48407C9A93179912454028603B18B13B4840
56059	28868	42.430242999999997	42.446781000000001	48.895805000000003	48.880474	Дорожная	0103000020E610000001000000050000009D2ADF3312374540397D3D5FB37048409D2ADF3312374540F14BFDBCA9724840B2BCAB1E30394540F14BFDBCA9724840B2BCAB1E30394540397D3D5FB37048409D2ADF3312374540397D3D5FB3704840
40539	28310	42.466749999999998	42.529012000000002	48.550314	48.526094000000001	Лесхозная	0103000020E6100000010000000500000039B4C876BE3B4540984F560C5743484039B4C876BE3B4540F6436CB07046484085984BAAB6434540F6436CB07046484085984BAAB6434540984F560C5743484039B4C876BE3B4540984F560C57434840
39773	28310	42.466749999999998	42.529012000000002	48.550314	48.526094000000001	Ленина	0103000020E6100000010000000500000039B4C876BE3B4540984F560C5743484039B4C876BE3B4540F6436CB07046484085984BAAB6434540F6436CB07046484085984BAAB6434540984F560C5743484039B4C876BE3B4540984F560C57434840
39985	28310	42.466749999999998	42.529012000000002	48.550314	48.526094000000001	Коммунистическая	0103000020E6100000010000000500000039B4C876BE3B4540984F560C5743484039B4C876BE3B4540F6436CB07046484085984BAAB6434540F6436CB07046484085984BAAB6434540984F560C5743484039B4C876BE3B4540984F560C57434840
39986	28310	42.466749999999998	42.529012000000002	48.550314	48.526094000000001	Грызлова	0103000020E6100000010000000500000039B4C876BE3B4540984F560C5743484039B4C876BE3B4540F6436CB07046484085984BAAB6434540F6436CB07046484085984BAAB6434540984F560C5743484039B4C876BE3B4540984F560C57434840
56184	29012	42.108429999999998	42.128768000000001	48.560225000000003	48.549824999999998	переулок Торговый	0103000020E61000000100000005000000E0F3C308E10D4540F8C264AA60464840E0F3C308E10D454068B3EA73B5474840BB6246787B10454068B3EA73B5474840BB6246787B104540F8C264AA60464840E0F3C308E10D4540F8C264AA60464840
55546	28707	42.491041000000003	42.514352000000002	48.684201999999999	48.651933999999997	Центральная	0103000020E6100000010000000500000061FF756EDA3E45404293C4927253484061FF756EDA3E4540CCED5EEE93574840EC504D49D6414540CCED5EEE93574840EC504D49D64145404293C4927253484061FF756EDA3E45404293C49272534840
56196	29174	42.228130999999998	42.252718000000002	48.741146999999998	48.730373999999998	Центральная	0103000020E61000000100000005000000151A8865331D4540A2EC2DE57C5D4840151A8865331D4540A643A7E7DD5E4840268E3C1059204540A643A7E7DD5E4840268E3C1059204540A2EC2DE57C5D4840151A8865331D4540A2EC2DE57C5D4840
55772	28605	42.371592	42.405009	48.543633999999997	48.531894000000001	Чирская	0103000020E6100000010000000500000045BA9F53902F45402578431A1544484045BA9F53902F4540307F85CC95454840F7CABC55D7334540307F85CC95454840F7CABC55D73345402578431A1544484045BA9F53902F45402578431A15444840
56047	29079	42.019047999999998	42.099590999999997	48.715456000000003	48.701597	Терешковой	0103000020E61000000100000005000000F086342A7002454061FC34EECD594840F086342A700245400EDDEC0F945B4840EBFCDB65BF0C45400EDDEC0F945B4840EBFCDB65BF0C454061FC34EECD594840F086342A7002454061FC34EECD594840
56308	24901	42.622545000000002	42.653618000000002	48.760952000000003	48.742674000000001	Центральная	0103000020E61000000100000005000000E8A4F78DAF4F454075CB0EF10F5F4840E8A4F78DAF4F4540B4E908E066614840D9092FC1A9534540B4E908E066614840D9092FC1A953454075CB0EF10F5F4840E8A4F78DAF4F454075CB0EF10F5F4840
56043	28549	42.574764000000002	42.602656000000003	48.570981000000003	48.551065000000001	Речная	0103000020E610000001000000050000008675E3DD91494540317C444C894648408675E3DD9149454096D1C8E7154948407D5EF1D4234D454096D1C8E7154948407D5EF1D4234D4540317C444C894648408675E3DD91494540317C444C89464840
56198	29281	42.245880999999997	42.291398999999998	48.630406999999998	48.617252000000001	Мира	0103000020E6100000010000000500000098DA5207791F4540FFB1101D024F484098DA5207791F4540B115342DB1504840268BFB8F4C254540B115342DB1504840268BFB8F4C254540FFB1101D024F484098DA5207791F4540FFB1101D024F4840
55550	28784	42.509796999999999	42.534052000000003	48.757317	48.745662000000003	Школьная	0103000020E61000000100000005000000A94C3107414145405BEF37DA715F4840A94C31074141454038DA71C3EF604840842EE1D05B44454038DA71C3EF604840842EE1D05B4445405BEF37DA715F4840A94C3107414145405BEF37DA715F4840
56048	29229	42.194021999999997	42.225867000000001	48.637725000000003	48.608144000000003	Восточная	0103000020E610000001000000050000002D5A80B6D51845401BA19FA9D74D48402D5A80B6D5184540BA6B09F9A0514840711FB935E91C4540BA6B09F9A0514840711FB935E91C45401BA19FA9D74D48402D5A80B6D51845401BA19FA9D74D4840
56058	28674	42.683163	42.698523999999999	48.631704999999997	48.621856000000001	Сосновая	0103000020E610000001000000050000002B6B9BE271574540236937FA984F48402B6B9BE2715745401EDC9DB5DB5048404DBC033C695945401EDC9DB5DB5048404DBC033C69594540236937FA984F48402B6B9BE271574540236937FA984F4840
56064	29145	42.329137000000003	42.360111000000003	48.768577000000001	48.748918000000003	Ленина	0103000020E61000000100000005000000A8734529212A454060B1868BDC5F4840A8734529212A454099BA2BBB6062484006F7031E182E454099BA2BBB6062484006F7031E182E454060B1868BDC5F4840A8734529212A454060B1868BDC5F4840
56199	29067	42.093885999999998	42.122632000000003	48.786102999999997	48.764752000000001	Школьная	0103000020E61000000100000005000000B0C6D974040C45407AC6BE64E3614840B0C6D974040C4540CC24EA059F644840B7B8C667B20F4540CC24EA059F644840B7B8C667B20F45407AC6BE64E3614840B0C6D974040C45407AC6BE64E3614840
56358	2233	38.404603999999999	38.41789	47.284703	47.269266000000002	Калинина	0103000020E6100000010000000500000057EA5910CA3343405EF6EB4E77A2474057EA5910CA3343405B09DD2571A44740A8A9656B7D3543405B09DD2571A44740A8A9656B7D3543405EF6EB4E77A2474057EA5910CA3343405EF6EB4E77A24740
56390	56863	38.396572999999997	38.403706	47.364834000000002	47.354304999999997	Солнечная	0103000020E6100000010000000500000001BD70E7C232434096E7C1DD59AD474001BD70E7C2324340043C69E1B2AE4740789961A3AC334340043C69E1B2AE4740789961A3AC33434096E7C1DD59AD474001BD70E7C232434096E7C1DD59AD4740
55498	89	38.707256000000001	38.721888999999997	47.162951	47.156492999999998	Октябрьская	0103000020E610000001000000050000002CF3565D875A4340C6866EF6079447402CF3565D875A4340DDEC0F94DB944740CB2BD7DB665C4340DDEC0F94DB944740CB2BD7DB665C4340C6866EF6079447402CF3565D875A4340C6866EF607944740
56248	31740	39.203251999999999	39.216053000000002	47.332604000000003	47.325068000000002	Молодежная	0103000020E610000001000000050000005D6C5A29049A4340F27C06D49BA947405D6C5A29049A4340684293C492AA4740F299EC9FA79B4340684293C492AA4740F299EC9FA79B4340F27C06D49BA947405D6C5A29049A4340F27C06D49BA94740
40762	882	38.372399999999999	38.398325	47.343204999999998	47.329276	Ленина	0103000020E61000000100000005000000E4839ECDAA2F4340C9AD49B725AA4740E4839ECDAA2F43406E693524EEAB4740F0164850FC3243406E693524EEAB4740F0164850FC324340C9AD49B725AA4740E4839ECDAA2F4340C9AD49B725AA4740
39932	31102	38.879641999999997	38.917596000000003	47.382542999999998	47.342435999999999	Ленина	0103000020E610000001000000050000001118EB1B987043408D7C5EF1D4AB47401118EB1B987043402828452BF7B04740607825C9737543402828452BF7B04740607825C9737543408D7C5EF1D4AB47401118EB1B987043408D7C5EF1D4AB4740
56258	1347	38.574295999999997	38.601802999999997	47.296382999999999	47.284543999999997	Мира	0103000020E610000001000000050000009F1C058882494340F22213F06BA447409F1C058882494340910BCEE0EFA547403DD175E1074D4340910BCEE0EFA547403DD175E1074D4340F22213F06BA447409F1C058882494340F22213F06BA44740
55783	30883	38.782812999999997	38.804479999999998	47.323138	47.314103000000003	Садовая	0103000020E610000001000000050000001BF1643733644340AA49F08634A847401BF1643733644340240C03965CA947409E245D33F9664340240C03965CA947409E245D33F9664340AA49F08634A847401BF1643733644340AA49F08634A84740
55683	31818	39.245094999999999	39.269196999999998	47.510294000000002	47.496786999999998	пр. им. Победы	0103000020E61000000100000005000000E1B4E0455F9F4340FA0967B796BF4740E1B4E0455F9F43402AAC545051C1474035971B0C75A243402AAC545051C1474035971B0C75A24340FA0967B796BF4740E1B4E0455F9F4340FA0967B796BF4740
41294	31651	39.251562999999997	39.317005000000002	47.284153000000003	47.271552999999997	Ленина	0103000020E610000001000000050000001BF1643733A04340BA10AB3FC2A247401BF1643733A04340B80721205FA4474091D5AD9E93A84340B80721205FA4474091D5AD9E93A84340BA10AB3FC2A247401BF1643733A04340BA10AB3FC2A24740
41290	31238	39.011586999999999	39.040134999999999	47.345874000000002	47.313442999999999	Кооперативная	0103000020E610000001000000050000008507CDAE7B8143407F1475E61EA847408507CDAE7B814340B344679945AC47406536C82423854340B344679945AC47406536C824238543407F1475E61EA847408507CDAE7B8143407F1475E61EA84740
55479	256	38.666741999999999	38.678652999999997	47.193416999999997	47.182326000000003	Дзержинского	0103000020E61000000100000005000000506F46CD57554340F29A577556974740506F46CD57554340C6BE64E3C1984740882AFC19DE564340C6BE64E3C1984740882AFC19DE564340F29A577556974740506F46CD57554340F29A577556974740
55684	1807	38.409464	38.427377	47.148833000000003	47.138725999999998	им. Приходько П.Е	0103000020E61000000100000005000000D671FC50693443406D8D08C6C1914740D671FC506934434065C8B1F50C93474003081F4AB436434065C8B1F50C93474003081F4AB43643406D8D08C6C1914740D671FC50693443406D8D08C6C1914740
56236	30657	38.653931999999998	38.670596000000003	47.383823999999997	47.373775000000002	им. Ленина	0103000020E6100000010000000500000068E7340BB4534340FD87F4DBD7AF474068E7340BB4534340BFB5132521B147400A6AF816D6554340BFB5132521B147400A6AF816D6554340FD87F4DBD7AF474068E7340BB4534340FD87F4DBD7AF4740
56116	2276	38.359535999999999	38.372804000000002	47.204253999999999	47.197432999999997	Гагарина	0103000020E6100000010000000500000009DE9046052E434059130B7C4599474009DE9046052E4340E109BDFE249A4740B4E89D0AB82F4340E109BDFE249A4740B4E89D0AB82F434059130B7C4599474009DE9046052E434059130B7C45994740
55963	32094	39.158641000000003	39.178843999999998	47.410826999999998	47.400342999999999	Космическая	0103000020E61000000100000005000000026729594E9443405D177E703EB34740026729594E9443402AA8A8FA95B44740FC8A355CE49643402AA8A8FA95B44740FC8A355CE49643405D177E703EB34740026729594E9443405D177E703EB34740
41291	31469	39.032544999999999	39.078313999999999	47.291158000000003	47.263646999999999	Ленина	0103000020E61000000100000005000000FC523F6F2A8443402158552FBFA14740FC523F6F2A84434001FC53AA44A54740D3687231068A434001FC53AA44A54740D3687231068A43402158552FBFA14740FC523F6F2A8443402158552FBFA14740
55570	1867	38.370944000000001	38.386144000000002	47.147587999999999	47.139308	Луговая	0103000020E61000000100000005000000DF52CE177B2F43401C0934D8D4914740DF52CE177B2F43401AA4E029E4924740F8C5A52A6D3143401AA4E029E4924740F8C5A52A6D3143401C0934D8D4914740DF52CE177B2F43401C0934D8D4914740
41204	30229	38.891948999999997	38.928628000000003	47.437944000000002	47.388375000000003	переулок им. Маяковского	0103000020E61000000100000005000000965984622B724340C1CAA145B6B14740965984622B7243405EBD8A8C0EB8474030134548DD7643405EBD8A8C0EB8474030134548DD764340C1CAA145B6B14740965984622B724340C1CAA145B6B14740
55114	30229	38.891948999999997	38.928628000000003	47.437944000000002	47.388375000000003	пер. Тургеневский	0103000020E61000000100000005000000965984622B724340C1CAA145B6B14740965984622B7243405EBD8A8C0EB8474030134548DD7643405EBD8A8C0EB8474030134548DD764340C1CAA145B6B14740965984622B724340C1CAA145B6B14740
40007	30229	38.891948999999997	38.928628000000003	47.437944000000002	47.388375000000003	Привокзальная	0103000020E61000000100000005000000965984622B724340C1CAA145B6B14740965984622B7243405EBD8A8C0EB8474030134548DD7643405EBD8A8C0EB8474030134548DD764340C1CAA145B6B14740965984622B724340C1CAA145B6B14740
40757	30229	38.891948999999997	38.928628000000003	47.437944000000002	47.388375000000003	Ленина	0103000020E61000000100000005000000965984622B724340C1CAA145B6B14740965984622B7243405EBD8A8C0EB8474030134548DD7643405EBD8A8C0EB8474030134548DD764340C1CAA145B6B14740965984622B724340C1CAA145B6B14740
41296	32126	38.862251000000001	38.875473999999997	47.190176999999998	47.176293000000001	Ворошилова	0103000020E61000000100000005000000BEF8A23D5E6E4340C2C1DEC490964740BEF8A23D5E6E4340C7B94DB857984740C83F33880F704340C7B94DB857984740C83F33880F704340C2C1DEC490964740BEF8A23D5E6E4340C2C1DEC490964740
55977	949	38.308034999999997	38.324511000000001	47.333013999999999	47.329892999999998	Мичурина	0103000020E61000000100000005000000FD82DDB06D274340F4160FEF39AA4740FD82DDB06D274340198EE733A0AA47409C18929389294340198EE733A0AA47409C18929389294340F4160FEF39AA4740FD82DDB06D274340F4160FEF39AA4740
55788	30585	38.735399999999998	38.758792	47.404935999999999	47.388582999999997	Ленина	0103000020E610000001000000050000003CBD5296215E43400A647616BDB147403CBD5296215E43408D7C5EF1D4B34740B43BA418206143408D7C5EF1D4B34740B43BA418206143400A647616BDB147403CBD5296215E43400A647616BDB14740
55700	1241	38.663812999999998	38.682794999999999	47.282966999999999	47.266154	Клубная	0103000020E610000001000000050000006FD40AD3F75443408CD9925511A247406FD40AD3F7544340726C3D4338A44740A86F99D365574340726C3D4338A44740A86F99D3655743408CD9925511A247406FD40AD3F75443408CD9925511A24740
56094	31976	39.211139000000003	39.225960999999998	47.449925	47.442374999999998	Ленина	0103000020E6100000010000000500000080F44D9A069B4340B4C876BE9FB8474080F44D9A069B43408F53742497B94740F295404AEC9C43408F53742497B94740F295404AEC9C4340B4C876BE9FB8474080F44D9A069B4340B4C876BE9FB84740
55505	31511	39.067326999999999	39.079256999999998	47.305787000000002	47.299506000000001	Центральная	0103000020E61000000100000005000000A391CF2B9E884340577A6D3656A64740A391CF2B9E8843405F45460724A74740527DE717258A43405F45460724A74740527DE717258A4340577A6D3656A64740A391CF2B9E884340577A6D3656A64740
55632	760	38.805306999999999	38.815196999999998	47.183208	47.174742999999999	Транспортная	0103000020E61000000100000005000000B41EBE4C146743403B1A87FA5D964740B41EBE4C14674340CB2E185C739747400E66136058684340CB2E185C739747400E661360586843403B1A87FA5D964740B41EBE4C146743403B1A87FA5D964740
39748	32236	38.835445	38.864792999999999	47.192559000000003	47.174804999999999	Коминтерна	0103000020E61000000100000005000000A94D9CDCEF6A4340B1169F0260964740A94D9CDCEF6A434076C6F7C5A5984740A5677A89B16E434076C6F7C5A5984740A5677A89B16E4340B1169F0260964740A94D9CDCEF6A4340B1169F0260964740
56238	32395	38.720910000000003	38.744042	47.242784	47.236066000000001	Центральная	0103000020E6100000010000000500000000AE64C7465C434049D92269379E474000AE64C7465C4340FCFECD8B139F4740DB6CACC43C5F4340FCFECD8B139F4740DB6CACC43C5F434049D92269379E474000AE64C7465C434049D92269379E4740
55966	1539	38.521070999999999	38.536952999999997	47.218882999999998	47.209524999999999	им. Ленина	0103000020E610000001000000050000006FF25B74B2424340E25817B7D19A47406FF25B74B24243403F53AF5B049C47409A3E3BE0BA4443403F53AF5B049C47409A3E3BE0BA444340E25817B7D19A47406FF25B74B2424340E25817B7D19A4740
56202	2176	38.350256000000002	38.374231999999999	47.225853999999998	47.214402999999997	Шолохова	0103000020E61000000100000005000000289D4830D52C43400795B88E719B4740289D4830D52C4340DCD5ABC8E89C4740EF8E8CD5E62F4340DCD5ABC8E89C4740EF8E8CD5E62F43400795B88E719B4740289D4830D52C43400795B88E719B4740
56052	2119	38.401173	38.416139000000001	47.254094000000002	47.239786000000002	Ленина	0103000020E61000000100000005000000E48409A359334340F304C24EB19E4740E48409A3593343400F0EF62686A047408ACBF10A443543400F0EF62686A047408ACBF10A44354340F304C24EB19E4740E48409A359334340F304C24EB19E4740
41230	883	38.819409999999998	38.865116999999998	47.324933000000001	47.277262999999998	переулок Школьный	0103000020E61000000100000005000000F701486DE268434007B29E5A7DA34740F701486DE26843401232906797A94740581B6327BC6E43401232906797A94740581B6327BC6E434007B29E5A7DA34740F701486DE268434007B29E5A7DA34740
40305	883	38.819409999999998	38.865116999999998	47.324933000000001	47.277262999999998	Садовая	0103000020E61000000100000005000000F701486DE268434007B29E5A7DA34740F701486DE26843401232906797A94740581B6327BC6E43401232906797A94740581B6327BC6E434007B29E5A7DA34740F701486DE268434007B29E5A7DA34740
41286	883	38.819409999999998	38.865116999999998	47.324933000000001	47.277262999999998	Ленина	0103000020E61000000100000005000000F701486DE268434007B29E5A7DA34740F701486DE26843401232906797A94740581B6327BC6E43401232906797A94740581B6327BC6E434007B29E5A7DA34740F701486DE268434007B29E5A7DA34740
56104	31795	39.104221000000003	39.122556000000003	47.372194	47.362153999999997	пер. Молодежный	0103000020E6100000010000000500000039471D1D578D4340CB0EF10F5BAE474039471D1D578D43403BE2900DA4AF4740DCF63DEAAF8F43403BE2900DA4AF4740DCF63DEAAF8F4340CB0EF10F5BAE474039471D1D578D4340CB0EF10F5BAE4740
40764	1412	38.457873999999997	38.491022000000001	47.183508000000003	47.157815999999997	Чехова	0103000020E6100000010000000500000027D87F9D9B3A43408C648F503394474027D87F9D9B3A4340F646AD307D974740EACE13CFD93E4340F646AD307D974740EACE13CFD93E43408C648F503394474027D87F9D9B3A43408C648F5033944740
55735	31570	39.193908999999998	39.223077000000004	47.289195999999997	47.279232	Красногвардейская	0103000020E6100000010000000500000035B39602D298434093FFC9DFBDA3474035B39602D29843402711E15F04A54740B2BE81C98D9C43402711E15F04A54740B2BE81C98D9C434093FFC9DFBDA3474035B39602D298434093FFC9DFBDA34740
55974	1188	38.472571000000002	38.485992000000003	47.376966000000003	47.367483	Садовая	0103000020E61000000100000005000000DE04DF347D3C4340016BD5AE09AF4740DE04DF347D3C43401BDA006C40B047400F0F61FC343E43401BDA006C40B047400F0F61FC343E4340016BD5AE09AF4740DE04DF347D3C4340016BD5AE09AF4740
55805	31567	39.131261000000002	39.154428000000003	47.292825999999998	47.285967999999997	Первомайская	0103000020E61000000100000005000000C11E1329CD904340ECD973999AA44740C11E1329CD90434091B586527BA5474019CBF44BC493434091B586527BA5474019CBF44BC4934340ECD973999AA44740C11E1329CD904340ECD973999AA44740
56099	30691	38.620631000000003	38.632803000000003	47.356313	47.341813000000002	им. Ленина	0103000020E6100000010000000500000020F12BD6704F4340802C4487C0AB474020F12BD6704F4340E01115AA9BAD4740C5E74EB0FF504340E01115AA9BAD4740C5E74EB0FF504340802C4487C0AB474020F12BD6704F4340802C4487C0AB4740
55978	454	38.586855	38.613813	47.236224999999997	47.221997999999999	Клубная	0103000020E610000001000000050000003E3F8C101E4B434082E3326E6A9C47403E3F8C101E4B4340B1BFEC9E3C9E4740096EA46C914E4340B1BFEC9E3C9E4740096EA46C914E434082E3326E6A9C47403E3F8C101E4B434082E3326E6A9C4740
56244	1690	38.238587000000003	38.268068999999997	47.170442999999999	47.162877000000002	пер. Кольцевой	0103000020E610000001000000050000001920D1048A1E4340A3224E27D99447401920D1048A1E4340836A8313D19547402409C21550224340836A8313D19547402409C21550224340A3224E27D99447401920D1048A1E4340A3224E27D9944740
55961	32019	39.160366000000003	39.167957000000001	47.475968000000002	47.468086	Красносельская	0103000020E61000000100000005000000F7B182DF8694434094DBF63DEABB4740F7B182DF86944340A5F8F884ECBC474030116F9D7F954340A5F8F884ECBC474030116F9D7F95434094DBF63DEABB4740F7B182DF8694434094DBF63DEABB4740
56501	56960	38.510156000000002	38.520155000000003	47.203536999999997	47.194158000000002	Набережная	0103000020E61000000100000005000000D9EDB3CA4C414340DE205A2BDA984740D9EDB3CA4C41434052431B800D9A4740EAEC64709442434052431B800D9A4740EAEC647094424340DE205A2BDA984740D9EDB3CA4C414340DE205A2BDA984740
39749	637	38.529093000000003	38.561720000000001	47.205306999999998	47.190465000000003	Ленина	0103000020E6100000010000000500000072C5C551B94343402E0439286198474072C5C551B9434340E751F17F479A47402BC1E270E6474340E751F17F479A47402BC1E270E64743402E0439286198474072C5C551B94343402E04392861984740
55704	31177	39.051929999999999	39.083542000000001	47.365834999999997	47.349293000000003	Кооперативная	0103000020E6100000010000000500000034D769A4A586434062DC0DA2B5AC474034D769A4A5864340B75D68AED3AE4740D5EB1681B18A4340B75D68AED3AE4740D5EB1681B18A434062DC0DA2B5AC474034D769A4A586434062DC0DA2B5AC4740
55802	56697	38.724144000000003	38.748578000000002	47.173028000000002	47.159163999999997	Октябрьская	0103000020E610000001000000050000001DCC26C0B05C4340AB59677C5F9447401DCC26C0B05C43406AA510C825964740A7406667D15F43406AA510C825964740A7406667D15F4340AB59677C5F9447401DCC26C0B05C4340AB59677C5F944740
56237	32035	39.046306999999999	39.057751000000003	47.456457	47.450626	Металлургическая	0103000020E61000000100000005000000B6494563ED854340185DDE1CAEB94740B6494563ED854340E083D72E6DBA4740D927806264874340E083D72E6DBA4740D927806264874340185DDE1CAEB94740B6494563ED854340185DDE1CAEB94740
41299	114	38.666930000000001	38.69238	47.159984999999999	47.149873999999997	Октябрьская	0103000020E61000000100000005000000535C55F65D554340A6423C122F934740535C55F65D554340DF6C73637A944740C63368E89F584340DF6C73637A944740C63368E89F584340A6423C122F934740535C55F65D554340A6423C122F934740
56251	1311	38.583998000000001	38.608648000000002	47.253824999999999	47.242576	Миусская	0103000020E61000000100000005000000F7764B72C04A4340B265F9BA0C9F4740F7764B72C04A43401FF46C567DA047404E637B2DE84D43401FF46C567DA047404E637B2DE84D4340B265F9BA0C9F4740F7764B72C04A4340B265F9BA0C9F4740
55699	196	38.628348000000003	38.650751999999997	47.148654999999998	47.141043000000003	Октябрьская	0103000020E61000000100000005000000E6400FB56D504340352A70B20D924740E6400FB56D50434085B18520079347403EE76ED74B53434085B18520079347403EE76ED74B534340352A70B20D924740E6400FB56D504340352A70B20D924740
55962	30540	38.781995999999999	38.788058999999997	47.440784000000001	47.434036999999996	Полевая	0103000020E6100000010000000500000029CDE67118644340812040868EB7474029CDE67118644340CF4C309C6BB84740C328081EDF644340CF4C309C6BB84740C328081EDF644340812040868EB7474029CDE67118644340812040868EB74740
55495	1117	38.461827	38.485965	47.327047	47.309246000000002	Транспортная	0103000020E6100000010000000500000074B4AA251D3B43409C35785F95A7474074B4AA251D3B4340A1A014ADDCA947401500E319343E4340A1A014ADDCA947401500E319343E43409C35785F95A7474074B4AA251D3B43409C35785F95A74740
56356	32247	38.813831999999998	38.827081999999997	47.184353000000002	47.176696999999997	2-я Степная	0103000020E610000001000000050000001938A0A52B6843409126DE019E9647401938A0A52B684340B2F50CE1989747401D8EAED2DD694340B2F50CE1989747401D8EAED2DD6943409126DE019E9647401938A0A52B6843409126DE019E964740
56109	32336	38.789648999999997	38.801901999999998	47.242258	47.238452000000002	Центральная	0103000020E61000000100000005000000D828EB371365434039D55A98859E4740D828EB3713654340E198654F029F47406A4C88B9A4664340E198654F029F47406A4C88B9A466434039D55A98859E4740D828EB371365434039D55A98859E4740
56083	31898	39.279294	39.297350000000002	47.537475000000001	47.521053999999999	Центральная	0103000020E6100000010000000500000009FCE1E7BFA3434099B9C0E5B1C2474009FCE1E7BFA3434074B515FBCBC4474099BB96900FA6434074B515FBCBC4474099BB96900FA6434099B9C0E5B1C2474009FCE1E7BFA3434099B9C0E5B1C24740
40307	31042	38.83099	38.846089999999997	47.276345999999997	47.269908000000001	переулок Ореховый	0103000020E61000000100000005000000CAA65CE15D6A4340E27668588CA24740CAA65CE15D6A4340B130444E5FA347407FBC57AD4C6C4340B130444E5FA347407FBC57AD4C6C4340E27668588CA24740CAA65CE15D6A4340E27668588CA24740
56239	337	38.632390000000001	38.680368999999999	47.242313000000003	47.231074	им. Ленина	0103000020E61000000100000005000000A228D027F25043405B7A34D5939D4740A228D027F2504340A532C51C049F47402A1BD65416574340A532C51C049F47402A1BD654165743405B7A34D5939D4740A228D027F25043405B7A34D5939D4740
55260	56623	38.743844000000003	38.771673999999997	47.178088000000002	47.167783999999997	Ленина	0103000020E61000000100000005000000B5A9BA47365F4340626534F279954740B5A9BA47365F4340B0E76B96CB9647403596B036C6624340B0E76B96CB9647403596B036C6624340626534F279954740B5A9BA47365F4340626534F279954740
41339	1652	38.331293000000002	38.353166999999999	47.159255999999999	47.137217999999997	Октябрьская	0103000020E6100000010000000500000066321CCF672A43401536035C9091474066321CCF672A43408CD827806294474062838593342D43408CD827806294474062838593342D43401536035C9091474066321CCF672A43401536035C90914740
55497	2055	38.36842	38.386718999999999	47.232706999999998	47.223638999999999	Школьная	0103000020E610000001000000050000009E98F562282F4340198EE733A09C47409E98F562282F43406F46CD57C99D4740F4DE1802803143406F46CD57C99D4740F4DE180280314340198EE733A09C47409E98F562282F4340198EE733A09C4740
39747	31304	39.006700000000002	39.035921999999999	47.298253000000003	47.276676000000002	Советская	0103000020E610000001000000050000000D71AC8BDB80434047CB811E6AA347400D71AC8BDB8043408A7780272DA647407C9A9317998443408A7780272DA647407C9A93179984434047CB811E6AA347400D71AC8BDB80434047CB811E6AA34740
55478	30459	38.847653000000001	38.881152	47.436523999999999	47.416674999999998	пер. Памятный	0103000020E610000001000000050000009BADBCE47F6C4340C8073D9B55B547409BADBCE47F6C4340A5F5B704E0B747400A67B796C9704340A5F5B704E0B747400A67B796C9704340C8073D9B55B547409BADBCE47F6C4340C8073D9B55B54740
55477	30459	38.847653000000001	38.881152	47.436523999999999	47.416674999999998	Школьная	0103000020E610000001000000050000009BADBCE47F6C4340C8073D9B55B547409BADBCE47F6C4340A5F5B704E0B747400A67B796C9704340A5F5B704E0B747400A67B796C9704340C8073D9B55B547409BADBCE47F6C4340C8073D9B55B54740
40758	31374	38.978501999999999	38.998651000000002	47.282373999999997	47.272348000000001	Школьная	0103000020E610000001000000050000000989B48D3F7D4340C5909C4CDCA247400989B48D3F7D4340CF9ECBD424A44740118FC4CBD37F4340CF9ECBD424A44740118FC4CBD37F4340C5909C4CDCA247400989B48D3F7D4340C5909C4CDCA24740
56373	705	38.493096999999999	38.590825000000002	47.157926000000003	47.124755	Садовая	0103000020E61000000100000005000000BB6070CD1D3F43409981CAF8F78F4740BB6070CD1D3F434014984EEB3694474061545227A04B434014984EEB3694474061545227A04B43409981CAF8F78F4740BB6070CD1D3F43409981CAF8F78F4740
55975	705	38.493096999999999	38.590825000000002	47.157926000000003	47.124755	Октябрьская	0103000020E61000000100000005000000BB6070CD1D3F43409981CAF8F78F4740BB6070CD1D3F434014984EEB3694474061545227A04B434014984EEB3694474061545227A04B43409981CAF8F78F4740BB6070CD1D3F43409981CAF8F78F4740
55840	705	38.493096999999999	38.590825000000002	47.157926000000003	47.124755	Ленина	0103000020E61000000100000005000000BB6070CD1D3F43409981CAF8F78F4740BB6070CD1D3F434014984EEB3694474061545227A04B434014984EEB3694474061545227A04B43409981CAF8F78F4740BB6070CD1D3F43409981CAF8F78F4740
55681	30790	38.801003999999999	38.813580000000002	47.311494000000003	47.298357000000003	им. Победы	0103000020E610000001000000050000008BFB8F4C876643402FC4EA8F30A647408BFB8F4C876643403B730F09DFA747400057B263236843403B730F09DFA747400057B263236843402FC4EA8F30A647408BFB8F4C876643402FC4EA8F30A64740
56102	1574	38.547435999999998	38.576532999999998	47.241016000000002	47.224587	Энгельса	0103000020E610000001000000050000009753026212464340AA0D4E44BF9C4740975302621246434008E8BE9CD99E47404A0856D5CB49434008E8BE9CD99E47404A0856D5CB494340AA0D4E44BF9C47409753026212464340AA0D4E44BF9C4740
55611	28343	38.786478000000002	38.808504999999997	47.182737000000003	47.171736000000003	Цветочная	0103000020E610000001000000050000000283A44FAB644340DFC5FB71FB9547400283A44FAB64434074620FED6397474084D382177D67434074620FED6397474084D382177D674340DFC5FB71FB9547400283A44FAB644340DFC5FB71FB954740
55973	56798	39.242355000000003	39.257851000000002	47.431916000000001	47.423715999999999	Нижняя	0103000020E61000000100000005000000D482177D059F43405E656D533CB64740D482177D059F4340404F030649B74740D61EF64201A14340404F030649B74740D61EF64201A143405E656D533CB64740D482177D059F43405E656D533CB64740
40640	13597	39.472701000000001	39.519638	47.297196	47.272371999999997	Туманяна	0103000020E61000000100000005000000ACE4637781BC43404D2CF015DDA24740ACE4637781BC43404240BE840AA6474022E17B7F83C243404240BE840AA6474022E17B7F83C243404D2CF015DDA24740ACE4637781BC43404D2CF015DDA24740
40131	13597	39.472701000000001	39.519638	47.297196	47.272371999999997	Синявская	0103000020E61000000100000005000000ACE4637781BC43404D2CF015DDA24740ACE4637781BC43404240BE840AA6474022E17B7F83C243404240BE840AA6474022E17B7F83C243404D2CF015DDA24740ACE4637781BC43404D2CF015DDA24740
41275	13597	39.472701000000001	39.519638	47.297196	47.272371999999997	Октябрьская	0103000020E61000000100000005000000ACE4637781BC43404D2CF015DDA24740ACE4637781BC43404240BE840AA6474022E17B7F83C243404240BE840AA6474022E17B7F83C243404D2CF015DDA24740ACE4637781BC43404D2CF015DDA24740
40148	13597	39.472701000000001	39.519638	47.297196	47.272371999999997	Мясникяна	0103000020E61000000100000005000000ACE4637781BC43404D2CF015DDA24740ACE4637781BC43404240BE840AA6474022E17B7F83C243404240BE840AA6474022E17B7F83C243404D2CF015DDA24740ACE4637781BC43404D2CF015DDA24740
41276	13597	39.472701000000001	39.519638	47.297196	47.272371999999997	6-я линия	0103000020E61000000100000005000000ACE4637781BC43404D2CF015DDA24740ACE4637781BC43404240BE840AA6474022E17B7F83C243404240BE840AA6474022E17B7F83C243404D2CF015DDA24740ACE4637781BC43404D2CF015DDA24740
55584	25864	39.422395999999999	39.455382	47.275044000000001	47.262858000000001	пер.Макаренко	0103000020E6100000010000000500000009FB761211B64340F9BEB854A5A1474009FB761211B64340037B4CA434A34740F29716F549BA4340037B4CA434A34740F29716F549BA4340F9BEB854A5A1474009FB761211B64340F9BEB854A5A14740
55801	25697	39.573169	39.590156	47.362423	47.349854000000001	Селиверстова	0103000020E610000001000000050000005F0A0F9A5DC94340F92F1004C8AC47405F0A0F9A5DC94340BB287AE063AE4740E3C4573B8ACB4340BB287AE063AE4740E3C4573B8ACB4340F92F1004C8AC47405F0A0F9A5DC94340F92F1004C8AC4740
55403	56662	39.434244	39.457321999999998	47.490034999999999	47.482745999999999	Школьная	0103000020E61000000100000005000000FB3DB14E95B743402D23F59ECABD4740FB3DB14E95B743409B728577B9BE4740E3DEFC8689BA43409B728577B9BE4740E3DEFC8689BA43402D23F59ECABD4740FB3DB14E95B743402D23F59ECABD4740
56194	25715	39.656973000000001	39.671489000000001	47.456274000000001	47.448962000000002	Ворошилова	0103000020E6100000010000000500000071ADF6B017D44340C992399677B9474071ADF6B017D44340EF01BA2F67BA4740D74FFF59F3D54340EF01BA2F67BA4740D74FFF59F3D54340C992399677B9474071ADF6B017D44340C992399677B94740
56422	56893	39.469988000000001	39.484963	47.272415000000002	47.264215	 Ленина	0103000020E6100000010000000500000098C1189128BC43406B0E10CCD1A1474098C1189128BC43404DF8A57EDEA247409162804413BE43404DF8A57EDEA247409162804413BE43406B0E10CCD1A1474098C1189128BC43406B0E10CCD1A14740
56565	57017	39.643704999999997	39.654232999999998	47.311995000000003	47.304254	Трудовая	0103000020E61000000100000005000000C6A2E9EC64D24340AED689CBF1A64740C6A2E9EC64D24340FDC1C073EFA74740637B2DE8BDD34340FDC1C073EFA74740637B2DE8BDD34340AED689CBF1A64740C6A2E9EC64D24340AED689CBF1A64740
55273	56629	39.610269000000002	39.639733999999997	47.289726999999999	47.277441000000003	Ленина	0103000020E610000001000000050000009E616A4B1DCE4340E7C8CA2F83A347409E616A4B1DCE434054E23AC615A54740D311C0CDE2D1434054E23AC615A54740D311C0CDE2D14340E7C8CA2F83A347409E616A4B1DCE4340E7C8CA2F83A34740
40747	25055	39.496803	39.533841000000002	47.319172999999999	47.294432999999998	Советская	0103000020E6100000010000000500000000C79E3D97BF43407CEE04FBAFA5474000C79E3D97BF434013622EA9DAA84740C921E2E654C4434013622EA9DAA84740C921E2E654C443407CEE04FBAFA5474000C79E3D97BF43407CEE04FBAFA54740
40749	25055	39.496803	39.533841000000002	47.319172999999999	47.294432999999998	8-я линия	0103000020E6100000010000000500000000C79E3D97BF43407CEE04FBAFA5474000C79E3D97BF434013622EA9DAA84740C921E2E654C4434013622EA9DAA84740C921E2E654C443407CEE04FBAFA5474000C79E3D97BF43407CEE04FBAFA54740
55583	56674	39.624533999999997	39.647226000000003	47.339865000000003	47.333685000000003	Туманяна	0103000020E61000000100000005000000BA9EE8BAF0CF43403815A930B6AA4740BA9EE8BAF0CF43400C0742B280AB47407A8F334DD8D243400C0742B280AB47407A8F334DD8D243403815A930B6AA4740BA9EE8BAF0CF43403815A930B6AA4740
55278	56633	39.483956999999997	39.532682000000001	47.256962000000001	47.232205999999998	Школьная	0103000020E61000000100000005000000CBD58F4DF2BD4340ADF71BEDB89D4740CBD58F4DF2BD43404A287D21E4A047407D957CEC2EC443404A287D21E4A047407D957CEC2EC44340ADF71BEDB89D4740CBD58F4DF2BD4340ADF71BEDB89D4740
40304	25912	39.292310999999998	39.318218000000002	47.337533000000001	47.323357000000001	Новая	0103000020E610000001000000050000006AA164726AA5434062F71DC363A947406AA164726AA543400F29064834AB4740D07F0F5EBBA843400F29064834AB4740D07F0F5EBBA8434062F71DC363A947406AA164726AA5434062F71DC363A94740
40750	25788	39.671875999999997	39.70205	47.399434999999997	47.380553999999997	Советская	0103000020E61000000100000005000000D07B630800D64340552E54FEB5B04740D07B630800D643405AF0A2AF20B3474012143FC6DCD943405AF0A2AF20B3474012143FC6DCD94340552E54FEB5B04740D07B630800D64340552E54FEB5B04740
39844	25788	39.671875999999997	39.70205	47.399434999999997	47.380553999999997	Оганяна	0103000020E61000000100000005000000D07B630800D64340552E54FEB5B04740D07B630800D643405AF0A2AF20B3474012143FC6DCD943405AF0A2AF20B3474012143FC6DCD94340552E54FEB5B04740D07B630800D64340552E54FEB5B04740
55492	26039	39.367949000000003	39.384971999999998	47.458297000000002	47.448492999999999	Центральная	0103000020E6100000010000000500000047CCECF318AF434012BEF73768B9474047CCECF318AF43406E6DE179A9BA474017F032C346B143406E6DE179A9BA474017F032C346B1434012BEF73768B9474047CCECF318AF434012BEF73768B94740
56093	27439	41.865068000000001	41.887642	48.261220000000002	48.244152	Мира	0103000020E610000001000000050000007768588CBAEE444062A06B5F401F48407768588CBAEE4440D3872EA86F2148402C47C8409EF14440D3872EA86F2148402C47C8409EF1444062A06B5F401F48407768588CBAEE444062A06B5F401F4840
55949	27974	41.984543000000002	41.997120000000002	47.883125999999997	47.869872999999998	Степная	0103000020E61000000100000005000000BC40498105FE444032569BFF57EF4740BC40498105FE4440A71FD4450AF147400118CFA0A1FF4440A71FD4450AF147400118CFA0A1FF444032569BFF57EF4740BC40498105FE444032569BFF57EF4740
56346	27660	42.018293	42.038621999999997	48.144558000000004	48.120474999999999	Центральная	0103000020E61000000100000005000000745FCE6C57024540287E8CB96B0F4840745FCE6C57024540063065E080124840FB73D190F1044540063065E080124840FB73D190F1044540287E8CB96B0F4840745FCE6C57024540287E8CB96B0F4840
56185	28259	41.696382	41.728020999999998	48.377321999999999	48.367463999999998	Садовая	0103000020E61000000100000005000000F4C29D0B23D944408A3A730F092F4840F4C29D0B23D94440D90759164C3048408EE6C8CA2FDD4440D90759164C3048408EE6C8CA2FDD44408A3A730F092F4840F4C29D0B23D944408A3A730F092F4840
55952	28014	41.848754	41.861510000000003	47.909362999999999	47.900762	Лютиковая	0103000020E61000000100000005000000B22C98F8A3EC444062BD512B4CF34740B22C98F8A3EC4440A298BC0166F44740A796ADF545EE4440A298BC0166F44740A796ADF545EE444062BD512B4CF34740B22C98F8A3EC444062BD512B4CF34740
56183	28075	41.710583999999997	41.734515000000002	48.307015	48.290897000000001	Степная	0103000020E61000000100000005000000CA87A06AF4DA444094C0E61C3C254840CA87A06AF4DA4440D3307C444C274840F2B5679604DE4440D3307C444C274840F2B5679604DE444094C0E61C3C254840CA87A06AF4DA444094C0E61C3C254840
56230	27778	41.880510000000001	41.891640000000002	48.011315000000003	48.003031999999997	Разлатный	0103000020E6100000010000000500000086E63A8DB4F04440B56B425A6300484086E63A8DB4F04440257A19C57201484019E76F4221F24440257A19C57201484019E76F4221F24440B56B425A6300484086E63A8DB4F04440B56B425A63004840
56091	27422	42.080078999999998	42.099555000000002	48.314444999999999	48.299463000000003	Покровская	0103000020E61000000100000005000000560C5707400A454058AEB7CD54264840560C5707400A454003B2D7BB3F2848409F93DE37BE0C454003B2D7BB3F2848409F93DE37BE0C454058AEB7CD54264840560C5707400A454058AEB7CD54264840
55675	27902	41.907414000000003	41.974294	47.977524000000003	47.939903000000001	Центральная	0103000020E610000001000000050000005EF7562426F44440C634D3BD4EF847405EF7562426F444400E87A5811FFD4740325871AAB5FC44400E87A5811FFD4740325871AAB5FC4440C634D3BD4EF847405EF7562426F44440C634D3BD4EF84740
56223	27147	41.818849	41.842098	48.455694999999999	48.441806	Энтузиастов	0103000020E6100000010000000500000060AE450BD0E844409A9658198D38484060AE450BD0E84440B1F9B836543A4840750305DEC9EB4440B1F9B836543A4840750305DEC9EB44409A9658198D38484060AE450BD0E844409A9658198D384840
56189	28230	41.609020999999998	41.647765	48.381833999999998	48.368805000000002	Школьная	0103000020E61000000100000005000000E2C96E66F4CD4440F7CC9200352F4840E2C96E66F4CD44401C40BFEFDF304840293FA9F6E9D244401C40BFEFDF304840293FA9F6E9D24440F7CC9200352F4840E2C96E66F4CD4440F7CC9200352F4840
55674	27816	41.727670000000003	41.747971999999997	48.029744000000001	48.010235999999999	Придорожная	0103000020E61000000100000005000000E223624A24DD4440F59ECA694F014840E223624A24DD444049A0C1A6CE0348406F29E78BBDDF444049A0C1A6CE0348406F29E78BBDDF4440F59ECA694F014840E223624A24DD4440F59ECA694F014840
40088	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Филонова	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
41166	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Ляшенко	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
40531	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Луначарского	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
40090	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Ленина	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
40258	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Кирова	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
39766	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Карла Маркса	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
39982	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Дзержинского	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
40257	1764	41.791037000000003	41.869630999999998	48.376257000000003	48.336066000000002	Ворошилова	0103000020E6100000010000000500000086764EB340E5444016A6EF35042B484086764EB340E544400FF27A30293048403C4B901150EF44400FF27A30293048403C4B901150EF444016A6EF35042B484086764EB340E5444016A6EF35042B4840
39768	27295	41.861986000000002	41.897801999999999	48.344946999999998	48.323816000000001	Дорожная	0103000020E6100000010000000500000010CEA78E55EE4440F5F57CCD7229484010CEA78E55EE444039ED2939272C484046240A2DEBF2444039ED2939272C484046240A2DEBF24440F5F57CCD7229484010CEA78E55EE4440F5F57CCD72294840
56095	27522	41.826529999999998	41.841028999999999	48.207616000000002	48.196404000000001	Солнечная	0103000020E61000000100000005000000D9942BBCCBE94440DC662AC423194840D9942BBCCBE944402C103D29931A484069FE98D6A6EB44402C103D29931A484069FE98D6A6EB4440DC662AC423194840D9942BBCCBE94440DC662AC423194840
55549	28156	41.629260000000002	41.673205000000003	48.410955999999999	48.392615999999997	Котельникова	0103000020E610000001000000050000002A5778978BD0444073F1B73D413248402A5778978BD04440280CCA349A3448407940D9942BD64440280CCA349A3448407940D9942BD6444073F1B73D413248402A5778978BD0444073F1B73D41324840
56345	27537	41.898457999999998	41.923825999999998	48.199443000000002	48.185074999999998	Центральная	0103000020E610000001000000050000002F6AF7AB00F344405227A089B01748402F6AF7AB00F344404435255987194840E5982CEE3FF644404435255987194840E5982CEE3FF644405227A089B01748402F6AF7AB00F344405227A089B0174840
55672	27689	41.806147000000003	41.831021	48.045395999999997	48.034022	Дружбы	0103000020E610000001000000050000005F622CD32FE7444019AC38D55A0448405F622CD32FE7444042AF3F89CF05484005A568E55EEA444042AF3F89CF05484005A568E55EEA444019AC38D55A0448405F622CD32FE7444019AC38D55A044840
55951	27354	42.012616000000001	42.031229000000003	48.275584000000002	48.263302000000003	Школьная	0103000020E6100000010000000500000003B4AD669D014540577C43E1B321484003B4AD669D01454083A6255646234840E9D7D64FFF03454083A6255646234840E9D7D64FFF034540577C43E1B321484003B4AD669D014540577C43E1B3214840
56177	27276	42.048171000000004	42.066146000000003	48.447142999999997	48.436324999999997	Гурина	0103000020E61000000100000005000000CDCEA2772A064540AEB6627FD9374840CDCEA2772A06454052D158FB3B3948407061DD787708454052D158FB3B3948407061DD7877084540AEB6627FD9374840CDCEA2772A064540AEB6627FD9374840
55774	27081	41.758679999999998	41.796149	48.428612999999999	48.383372000000001	Центральная	0103000020E610000001000000050000008C101E6D1CE14440DF196D55123148408C101E6D1CE14440FAD170CADC3648401EDFDE35E8E54440FAD170CADC3648401EDFDE35E8E54440DF196D55123148408C101E6D1CE14440DF196D5512314840
55547	28065	41.617024999999998	41.638396	48.304132000000003	48.290135999999997	Стадионная	0103000020E610000001000000050000003EE8D9ACFACE444035B22B2D232548403EE8D9ACFACE444063D520CCED264840D8F2CAF5B6D1444063D520CCED264840D8F2CAF5B6D1444035B22B2D232548403EE8D9ACFACE444035B22B2D23254840
55618	27163	41.916863999999997	41.961680999999999	48.390815000000003	48.366715999999997	Центральная	0103000020E610000001000000050000009B70AFCC5BF54440C075C58CF02E48409B70AFCC5BF54440A4E4D53906324840A017EE5C18FB4440A4E4D53906324840A017EE5C18FB4440C075C58CF02E48409B70AFCC5BF54440C075C58CF02E4840
56111	29224	41.800991000000003	41.817169	48.168492999999998	48.148471999999998	Молодежная	0103000020E61000000100000005000000F7B182DF86E64440942F682101134840F7B182DF86E644406E4DBA2D911548400B2769FE98E844406E4DBA2D911548400B2769FE98E84440942F682101134840F7B182DF86E64440942F682101134840
56056	28140	41.700738999999999	41.738242999999997	48.224767999999997	48.206077999999998	Центральная	0103000020E610000001000000050000001004C8D0B1D9444069368FC3601A48401004C8D0B1D94440FA97A432C51C48401EC022BF7EDE4440FA97A432C51C48401EC022BF7EDE444069368FC3601A48401004C8D0B1D9444069368FC3601A4840
56085	27232	41.995753999999998	42.014493000000002	48.458993	48.443933999999999	Мира	0103000020E610000001000000050000003B6EF8DD74FF44408ECA4DD4D23848403B6EF8DD74FF4440E50B5A48C03A4840AE8218E8DA014540E50B5A48C03A4840AE8218E8DA0145408ECA4DD4D23848403B6EF8DD74FF44408ECA4DD4D2384840
56010	29168	42.058267999999998	42.074455999999998	48.396935999999997	48.384945999999999	Быстрая	0103000020E61000000100000005000000A033695375074540EE5C18E945314840A033695375074540724D81CCCE324840D87E32C687094540724D81CCCE324840D87E32C687094540EE5C18E945314840A033695375074540EE5C18E945314840
55950	27607	41.803758000000002	41.830114000000002	48.146765000000002	48.127096999999999	Молодежная	0103000020E61000000100000005000000FEF2C98AE1E64440B935E9B644104840FEF2C98AE1E6444046990D32C9124840D3F9F02C41EA444046990D32C9124840D3F9F02C41EA4440B935E9B644104840FEF2C98AE1E64440B935E9B644104840
55565	27882	41.731999999999999	41.752904000000001	47.910632	47.895995999999997	Центральная	0103000020E6100000010000000500000004560E2DB2DD444064AC36FFAFF2474004560E2DB2DD44407558E1968FF44740888384285FE044407558E1968FF44740888384285FE0444064AC36FFAFF2474004560E2DB2DD444064AC36FFAFF24740
55931	56781	41.679448999999998	41.732745999999999	48.633074999999998	48.617936999999998	Заречная	0103000020E610000001000000050000006326512FF8D6444082FE428F184F48406326512FF8D644402575029A085148402D23F59ECADD44402575029A085148402D23F59ECADD444082FE428F184F48406326512FF8D6444082FE428F184F4840
56442	56781	41.679448999999998	41.732745999999999	48.633074999999998	48.617936999999998	Березовый переулок	0103000020E610000001000000050000006326512FF8D6444082FE428F184F48406326512FF8D644402575029A085148402D23F59ECADD44402575029A085148402D23F59ECADD444082FE428F184F48406326512FF8D6444082FE428F184F4840
56435	56904	41.930796999999998	41.949131999999999	48.573723000000001	48.565586000000003	Школьная	0103000020E61000000100000005000000821B295B24F74440A9893E1F65484840821B295B24F7444044FB58C16F49484025CB49287DF9444044FB58C16F49484025CB49287DF94440A9893E1F65484840821B295B24F74440A9893E1F65484840
56513	56972	41.539122999999996	41.580221000000002	48.596747000000001	48.575434000000001	Городская	0103000020E61000000100000005000000BDC282FB01C54440D48041D2A7494840BDC282FB01C54440397EA834624C4840E9B985AE44CA4440397EA834624C4840E9B985AE44CA4440D48041D2A7494840BDC282FB01C54440D48041D2A7494840
55899	56752	41.495294000000001	41.545105999999997	48.564363	48.536720000000003	Центральная	0103000020E61000000100000005000000D8F335CB65BF4440F88DAF3DB3444840D8F335CB65BF44404609FA0B3D4848403B6D8D08C6C544404609FA0B3D4848403B6D8D08C6C54440F88DAF3DB3444840D8F335CB65BF4440F88DAF3DB3444840
55733	56690	41.619405	41.664518999999999	48.625839999999997	48.600881999999999	пер. Культурный	0103000020E610000001000000050000004CFDBCA948CF4440A6608DB3E94C48404CFDBCA948CF4440AA436E861B5048400A4966F50ED54440AA436E861B5048400A4966F50ED54440A6608DB3E94C48404CFDBCA948CF4440A6608DB3E94C4840
55486	594	41.705849999999998	41.757475999999997	48.868243999999997	48.827395000000003	Титова	0103000020E61000000100000005000000D8F0F44A59DA4440DDEF5014E8694840D8F0F44A59DA44405F79909E226F4840A0C03BF9F4E044405F79909E226F4840A0C03BF9F4E04440DDEF5014E8694840D8F0F44A59DA4440DDEF5014E8694840
55971	594	41.705849999999998	41.757475999999997	48.868243999999997	48.827395000000003	Песчаная	0103000020E61000000100000005000000D8F0F44A59DA4440DDEF5014E8694840D8F0F44A59DA44405F79909E226F4840A0C03BF9F4E044405F79909E226F4840A0C03BF9F4E04440DDEF5014E8694840D8F0F44A59DA4440DDEF5014E8694840
56557	57009	41.784992000000003	41.882710000000003	48.835763	48.786963999999998	Школьная	0103000020E6100000010000000500000092CF2B9E7AE444408E90813CBB64484092CF2B9E7AE444407A1A3048FA6A484014ED2AA4FCF044407A1A3048FA6A484014ED2AA4FCF044408E90813CBB64484092CF2B9E7AE444408E90813CBB644840
56038	26088	41.780276000000001	41.795977999999998	48.557124999999999	48.546503000000001	Западная	0103000020E6100000010000000500000046ED7E15E0E344403C1570CFF345484046ED7E15E0E344405A643BDF4F474840F12A6B9BE2E544405A643BDF4F474840F12A6B9BE2E544403C1570CFF345484046ED7E15E0E344403C1570CFF3454840
56385	56859	41.594566999999998	41.630651999999998	48.793878999999997	48.767187	Центральная	0103000020E61000000100000005000000F2237EC51ACC44404B75012F33624840F2237EC51ACC444097FDBAD39D65484018946934B9D0444097FDBAD39D65484018946934B9D044404B75012F33624840F2237EC51ACC44404B75012F33624840
56517	56975	41.520958999999998	41.550989999999999	48.756652000000003	48.742922999999998	3-я Пионерская	0103000020E6100000010000000500000047C7D5C8AEC244401D39D219185F484047C7D5C8AEC24440FC3905F9D960484026361FD786C64440FC3905F9D960484026361FD786C644401D39D219185F484047C7D5C8AEC244401D39D219185F4840
56484	56945	41.854782	41.894486999999998	48.657581999999998	48.644826999999999	Центральная	0103000020E61000000100000005000000D09A1F7F69ED4440F549EEB089524840D09A1F7F69ED44401938A0A52B5448403CD9CD8C7EF244401938A0A52B5448403CD9CD8C7EF24440F549EEB089524840D09A1F7F69ED4440F549EEB089524840
56550	57002	41.688628999999999	41.691898999999999	48.615155000000001	48.610073999999997	Студенческая	0103000020E61000000100000005000000E109BDFE24D84440E811A3E7164E4840E109BDFE24D84440467C2766BD4E48404B917C2590D84440467C2766BD4E48404B917C2590D84440E811A3E7164E4840E109BDFE24D84440E811A3E7164E4840
56310	56843	41.759622999999998	41.801017999999999	48.946734999999997	48.897765999999997	Новодмитриевская	0103000020E610000001000000050000000B2593533BE14440F9BA0CFFE97248400B2593533BE14440417DCB9C2E794840F0C000C287E64440417DCB9C2E794840F0C000C287E64440F9BA0CFFE97248400B2593533BE14440F9BA0CFFE9724840
55568	56672	41.397458	41.433534999999999	48.687336000000002	48.668436999999997	переулок Школьный	0103000020E610000001000000050000004CC45BE7DFB24440DA37F7578F5548404CC45BE7DFB2444086AE44A0FA574840EF552B137EB7444086AE44A0FA574840EF552B137EB74440DA37F7578F5548404CC45BE7DFB24440DA37F7578F554840
56488	56948	41.515982000000001	41.563898000000002	48.747033999999999	48.727218000000001	Ермака	0103000020E610000001000000050000008FA9BBB20BC244400188BB7A155D48408FA9BBB20BC24440028063CF9E5F4840D12346CF2DC84440028063CF9E5F4840D12346CF2DC844400188BB7A155D48408FA9BBB20BC244400188BB7A155D4840
40040	519	41.653405999999997	41.695861000000001	48.637802000000001	48.618878000000002	Красноармейская	0103000020E610000001000000050000004D81CCCEA2D34440611BF164374F48404D81CCCEA2D3444065A9F57EA3514840EBC726F911D9444065A9F57EA3514840EBC726F911D94440611BF164374F48404D81CCCEA2D34440611BF164374F4840
40083	519	41.653405999999997	41.695861000000001	48.637802000000001	48.618878000000002	Комсомольская	0103000020E610000001000000050000004D81CCCEA2D34440611BF164374F48404D81CCCEA2D3444065A9F57EA3514840EBC726F911D9444065A9F57EA3514840EBC726F911D94440611BF164374F48404D81CCCEA2D34440611BF164374F4840
55617	25701	41.538440000000001	41.578792	48.786245999999998	48.752898000000002	Проходной	0103000020E61000000100000005000000DB6D179AEBC44440A69C2FF65E604840DB6D179AEBC444402F4E7CB5A3644840DD9733DB15CA44402F4E7CB5A3644840DD9733DB15CA4440A69C2FF65E604840DB6D179AEBC44440A69C2FF65E604840
56431	56901	41.860737999999998	41.888081999999997	48.920775999999996	48.891067	Центральная	0103000020E610000001000000050000005436ACA92CEE4440BDC5C37B0E7248405436ACA92CEE44408978EBFCDB7548404815C5ABACF144408978EBFCDB7548404815C5ABACF14440BDC5C37B0E7248405436ACA92CEE4440BDC5C37B0E724840
56181	26011	41.897739000000001	41.921957999999997	48.722076999999999	48.704897000000003	Солнечная	0103000020E6100000010000000500000000AC8E1CE9F2444036069D103A5A484000AC8E1CE9F24440CE18E6046D5C48408D2441B802F64440CE18E6046D5C48408D2441B802F6444036069D103A5A484000AC8E1CE9F2444036069D103A5A4840
56114	636	41.793695999999997	41.818184000000002	48.961956999999998	48.949615999999999	Вячеслав	0103000020E61000000100000005000000A67B9DD497E5444011E15F048D794840A67B9DD497E5444042942F68217B4840240ED940BAE8444042942F68217B4840240ED940BAE8444011E15F048D794840A67B9DD497E5444011E15F048D794840
56541	56995	41.820357999999999	41.858212999999999	48.894941000000003	48.866905000000003	Мира	0103000020E610000001000000050000008881AE7D01E9444094DE37BEF66E48408881AE7D01E94440BE6C3B6D8D724840430070ECD9ED4440BE6C3B6D8D724840430070ECD9ED444094DE37BEF66E48408881AE7D01E9444094DE37BEF66E4840
56505	56964	41.331755999999999	41.370311000000001	48.645493999999999	48.629038000000001	Сельская	0103000020E610000001000000050000003A2009FB76AA44407BF83251845048403A2009FB76AA4440D2E1218C9F524840AE2CD15966AF4440D2E1218C9F524840AE2CD15966AF44407BF83251845048403A2009FB76AA44407BF8325184504840
56180	26405	41.425082000000003	41.449317999999998	48.594386999999998	48.581972999999998	Строительная	0103000020E61000000100000005000000240F441669B64440D7135D177E4A4840240F441669B6444072158BDF144C484087C0914083B9444072158BDF144C484087C0914083B94440D7135D177E4A4840240F441669B64440D7135D177E4A4840
56271	16236	40.801380999999999	40.824522000000002	49.023086999999997	49.010088000000003	Молодежная	0103000020E61000000100000005000000615111A793664440810A47904A814840615111A7936644403BFBCA83F4824840906AD8EF896944403BFBCA83F4824840906AD8EF89694440810A47904A814840615111A793664440810A47904A814840
55839	56699	40.776507000000002	40.815206000000003	49.133299000000001	49.111189000000003	Ленина	0103000020E61000000100000005000000BB0ED594646344406556EF703B8E4840BB0ED5946463444075CB0EF10F91484062C092AB5868444075CB0EF10F91484062C092AB586844406556EF703B8E4840BB0ED594646344406556EF703B8E4840
56482	56941	40.571125000000002	40.601883999999998	49.032319999999999	49.008310000000002	Станиславского	0103000020E61000000100000005000000C976BE9F1A494440691D554D10814840C976BE9F1A494440DC80CF0F238448402AFEEF880A4D4440DC80CF0F238448402AFEEF880A4D4440691D554D10814840C976BE9F1A494440691D554D10814840
55939	56788	40.372695999999998	40.383215999999997	48.858778999999998	48.844431999999998	Российская	0103000020E61000000100000005000000CDACA580B42F444012D90759166C4840CDACA580B42F4440ECBE6378EC6D4840E7A6CD380D314440ECBE6378EC6D4840E7A6CD380D31444012D90759166C4840CDACA580B42F444012D90759166C4840
55985	56800	40.338901999999997	40.376747999999999	48.988562000000002	48.963045000000001	пер. Школьный	0103000020E6100000010000000500000045460724612B4440C5C9FD0E457B484045460724612B4440C0081A33897E4840AD6A494739304440C0081A33897E4840AD6A494739304440C5C9FD0E457B484045460724612B4440C5C9FD0E457B4840
56168	17558	39.717007000000002	39.763567000000002	49.002606	48.979349999999997	Ленина	0103000020E610000001000000050000006500A8E2C6DB434036AB3E575B7D48406500A8E2C6DB4340FE62B6645580484005A73E90BCE14340FE62B6645580484005A73E90BCE1434036AB3E575B7D48406500A8E2C6DB434036AB3E575B7D4840
55880	26822	40.325857999999997	40.354765999999998	48.934514999999998	48.925032999999999	 Школьная	0103000020E61000000100000005000000EA9106B7B5294440425C397B67764840EA9106B7B52944408B4F01309E774840CADDE7F8682D44408B4F01309E774840CADDE7F8682D4440425C397B67764840EA9106B7B5294440425C397B67764840
55838	16544	40.653537	40.670721	49.108358000000003	49.090414000000003	Школьная	0103000020E61000000100000005000000ECDCB419A7534440DF8C9AAF928B4840ECDCB419A75344404721C9ACDE8D4840C6DE8B2FDA5544404721C9ACDE8D4840C6DE8B2FDA554440DF8C9AAF928B4840ECDCB419A7534440DF8C9AAF928B4840
55905	56758	40.090257000000001	40.171716000000004	48.916857	48.904156	Северная	0103000020E61000000100000005000000179E978A8D0B4440B83D4162BB734840179E978A8D0B4440E90DF7915B754840981936CAFA154440E90DF7915B754840981936CAFA154440B83D4162BB734840179E978A8D0B4440B83D4162BB734840
56026	17759	40.045099	40.074016	48.946415000000002	48.918100000000003	Дружбы	0103000020E61000000100000005000000890AD5CDC5054440933A014D84754840890AD5CDC5054440D0B8702024794840BCB0355B79094440D0B8702024794840BCB0355B79094440933A014D84754840890AD5CDC5054440933A014D84754840
56021	17005	40.463444000000003	40.482622999999997	49.052269000000003	49.039265999999998	Садовая	0103000020E6100000010000000500000083C30B22523B444020EC14AB0685484083C30B22523B44401DCC26C0B086484011A62897C63D44401DCC26C0B086484011A62897C63D444020EC14AB0685484083C30B22523B444020EC14AB06854840
55725	16391	40.899504	40.932850000000002	48.868789	48.842618000000002	Советская	0103000020E61000000100000005000000834F73F222734440AE8218E8DA6B4840834F73F222734440F10F5B7A346F48406C09F9A067774440F10F5B7A346F48406C09F9A067774440AE8218E8DA6B4840834F73F222734440AE8218E8DA6B4840
55540	16497	40.664631	40.708325000000002	49.034824999999998	49.000566999999997	Вокзальная	0103000020E610000001000000050000003274ECA012554440793A5794128048403274ECA012554440A60A46257584484038F8C264AA5A4440A60A46257584484038F8C264AA5A4440793A5794128048403274ECA012554440793A579412804840
55861	56718	40.444454	40.470998999999999	48.915916000000003	48.907744999999998	Центральная	0103000020E61000000100000005000000C74961DEE3384440C30DF8FC30744840C74961DEE33844400BF148BC3C7548406FB9FAB1493C44400BF148BC3C7548406FB9FAB1493C4440C30DF8FC30744840C74961DEE3384440C30DF8FC30744840
56298	56841	40.068292999999997	40.093716000000001	49.070103000000003	49.059595999999999	Милькевича	0103000020E61000000100000005000000DAC534D3BD084440787C7BD7A0874840DAC534D3BD084440FE2C9622F9884840548EC9E2FE0B4440FE2C9622F9884840548EC9E2FE0B4440787C7BD7A0874840DAC534D3BD084440787C7BD7A0874840
55835	16169	40.666814000000002	40.687196999999998	48.976216000000001	48.945729	Школьная	0103000020E61000000100000005000000EA4141295A5544407CF0DAA50D794840EA4141295A5544407DEA58A5F47C484064744012F65744407DEA58A5F47C484064744012F65744407CF0DAA50D794840EA4141295A5544407CF0DAA50D794840
55757	17494	39.943579999999997	39.964412000000003	49.018579000000003	48.972667999999999	Российская	0103000020E610000001000000050000007094BC3AC7F84340D0EE9062807C48407094BC3AC7F843403AB2F2CB608248405BEF37DA71FB43403AB2F2CB608248405BEF37DA71FB4340D0EE9062807C48407094BC3AC7F84340D0EE9062807C4840
56022	17699	39.839798000000002	39.856820999999997	49.008771000000003	48.989508000000001	Центральная	0103000020E61000000100000005000000849F38807EEB4340B090B932A87E4840849F38807EEB43409D137B681F81484054C37E4FACED43409D137B681F81484054C37E4FACED4340B090B932A87E4840849F38807EEB4340B090B932A87E4840
41142	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	квартал имени маршала Ефимова	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55608	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	квартал ДСХТ	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55436	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Энгельса	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
40516	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Осоавиахима	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55320	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Нахимова	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55360	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Менделеева	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55289	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Криничная	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55262	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Заводская	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55283	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Жуковского	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
41138	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Донецкая	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
55312	54851	40.357577999999997	40.433008999999998	48.953355000000002	48.892690000000002	Артиллерийская	0103000020E6100000010000000500000071E2AB1DC52D4440AEBB79AA4372484071E2AB1DC52D4440323D6189077A4840D4EFC2D66C374440323D6189077A4840D4EFC2D66C374440AEBB79AA4372484071E2AB1DC52D4440AEBB79AA43724840
56020	17598	39.775272000000001	39.802517999999999	48.964506	48.935515000000002	пер. Школьный	0103000020E6100000010000000500000094C0E61C3CE343406FF59CF4BE77484094C0E61C3CE34340DC65BFEE747B4840C539EAE8B8E64340DC65BFEE747B4840C539EAE8B8E643406FF59CF4BE77484094C0E61C3CE343406FF59CF4BE774840
55560	17349	40.197443999999997	40.226908999999999	48.999384999999997	48.9666	Школьная	0103000020E610000001000000050000004D6551D84519444024287E8CB97B48404D6551D845194440758E01D9EB7F48408315A75A0B1D4440758E01D9EB7F48408315A75A0B1D444024287E8CB97B48404D6551D84519444024287E8CB97B4840
40078	16936	40.320504	40.389989	49.085239999999999	49.038339000000001	Голдобина	0103000020E610000001000000050000005C1E6B4606294440A794D74AE88448405C1E6B4606294440D027F224E98A48405E66D828EB314440D027F224E98A48405E66D828EB314440A794D74AE88448405C1E6B4606294440A794D74AE8844840
55934	56783	40.465456000000003	40.503464000000001	48.953136999999998	48.941220000000001	Мира	0103000020E610000001000000050000000EDDEC0F943B4440AA2B9FE5797848400EDDEC0F943B4440C4CDA964007A48404F5B238271404440C4CDA964007A48404F5B238271404440AA2B9FE5797848400EDDEC0F943B4440AA2B9FE579784840
55753	16921	40.476083000000003	40.509537000000002	49.220408999999997	49.197119999999998	 Победы	0103000020E610000001000000050000003E97A949F03C44409AB1683A3B9948403E97A949F03C44403D5FB35C369C48400D8D2782384144403D5FB35C369C48400D8D2782384144409AB1683A3B9948403E97A949F03C44409AB1683A3B994840
56411	56883	40.883577000000002	40.896324	48.908253999999999	48.888643999999999	Речная	0103000020E61000000100000005000000B83F170D19714440B0E42A16BF714840B83F170D19714440083BC5AA41744840594FADBEBA724440083BC5AA41744840594FADBEBA724440B0E42A16BF714840B83F170D19714440B0E42A16BF714840
40523	16310	40.733198999999999	40.781717	48.865108999999997	48.839208999999997	Ленина	0103000020E61000000100000005000000DE3AFF76D95D444022C154336B6B4840DE3AFF76D95D4440D53C47E4BB6E484016DD7A4D0F644440D53C47E4BB6E484016DD7A4D0F64444022C154336B6B4840DE3AFF76D95D444022C154336B6B4840
40524	16864	40.417495000000002	40.460299999999997	49.174290999999997	49.136369999999999	Советская	0103000020E610000001000000050000002C9FE57970354440E8137992749148402C9FE579703544405A7EE02A4F964840A52C431CEB3A44405A7EE02A4F964840A52C431CEB3A4440E8137992749148402C9FE57970354440E813799274914840
55945	56794	40.594203	40.615780000000001	48.898749000000002	48.879828000000003	Почтовая	0103000020E61000000100000005000000B1170AD80E4C4440740D33349E704840B1170AD80E4C444007280D350A734840F4C308E1D14E444007280D350A734840F4C308E1D14E4440740D33349E704840B1170AD80E4C4440740D33349E704840
56510	56969	40.472005000000003	40.496799000000003	48.987166000000002	48.978309000000003	Фабричная	0103000020E610000001000000050000003546EBA86A3C4440F530B43A397D48403546EBA86A3C444090DC9A745B7E4840BFD7101C973F444090DC9A745B7E4840BFD7101C973F4440F530B43A397D48403546EBA86A3C4440F530B43A397D4840
56539	56993	40.375022999999999	40.403714999999998	49.026944999999998	49.012085999999996	Школьная	0103000020E61000000100000005000000B81FF0C000304440A65EB7088C814840B81FF0C00030444036E50AEF72834840CBF3E0EEAC33444036E50AEF72834840CBF3E0EEAC334440A65EB7088C814840B81FF0C000304440A65EB7088C814840
56545	56998	40.073908000000003	40.096015000000001	48.926600999999998	48.917549999999999	Свободы	0103000020E61000000100000005000000D6743DD175094440EF38454772754840D6743DD1750944406FB88FDC9A764840757632384A0C44406FB88FDC9A764840757632384A0C4440EF38454772754840D6743DD175094440EF38454772754840
56410	56882	40.828636000000003	40.863599000000001	49.152369999999998	49.144609000000003	Центральная	0103000020E61000000100000005000000E62494BE106A444088DA368C82924840E62494BE106A44401D7233DC80934840DDED7A698A6E44401D7233DC80934840DDED7A698A6E444088DA368C82924840E62494BE106A444088DA368C82924840
56401	56873	40.733586000000003	40.759070999999999	48.832638000000003	48.820076	Юбилейная	0103000020E61000000100000005000000D8666325E65D4440041E1840F8684840D8666325E65D444014B4C9E1936A4840C72B103D2961444014B4C9E1936A4840C72B103D29614440041E1840F8684840D8666325E65D4440041E1840F8684840
55605	17285	40.254252999999999	40.304558999999998	48.943066000000002	48.919468000000002	Советская	0103000020E6100000010000000500000077F4BF5C8B204440F9DB9E20B175484077F4BF5C8B2044401AFCFD62B6784840EA5910CAFB2644401AFCFD62B6784840EA5910CAFB264440F9DB9E20B175484077F4BF5C8B204440F9DB9E20B1754840
41146	16774	40.650787999999999	40.685391000000003	49.177689000000001	49.1492	Российская	0103000020E610000001000000050000008B506C054D534440174850FC189348408B506C054D534440F2ED5D83BE96484083FC6CE4BA574440F2ED5D83BE96484083FC6CE4BA574440174850FC189348408B506C054D534440174850FC18934840
56270	56837	40.442081999999999	40.487878000000002	48.847658000000003	48.838034	Станичная	0103000020E610000001000000050000003C139A2496384440D177B7B2446B48403C139A2496384440AD18AE0E806C48400D384BC9723E4440AD18AE0E806C48400D384BC9723E4440D177B7B2446B48403C139A2496384440D177B7B2446B4840
55759	17254	40.191766999999999	40.251271000000003	48.912931999999998	48.889420000000001	Центральная	0103000020E61000000100000005000000DCB930D28B1844404434BA83D8714840DCB930D28B18444066BCADF4DA74484074B7EBA52920444066BCADF4DA74484074B7EBA5292044404434BA83D8714840DCB930D28B1844404434BA83D8714840
56451	56918	40.589055999999999	40.637762000000002	49.174779999999998	49.154798	Московская	0103000020E610000001000000050000009CC1DF2F664B44403CBEBD6BD09348409CC1DF2F664B444058FFE7305F964840D7506A2FA251444058FFE7305F964840D7506A2FA25144403CBEBD6BD09348409CC1DF2F664B44403CBEBD6BD0934840
56019	56802	40.262957999999998	40.288021000000001	49.060068000000001	49.050680999999997	Гетмановская	0103000020E610000001000000050000005C1C959BA8214440A8C30AB77C8648405C1C959BA8214440A0C4E74EB0874840D6C743DFDD244440A0C4E74EB0874840D6C743DFDD244440A8C30AB77C8648405C1C959BA8214440A8C30AB77C864840
56568	57019	40.149869000000002	40.167521000000001	49.111566000000003	49.098377999999997	Восточная	0103000020E6100000010000000500000095D74AE82E134440AC527AA6978C484095D74AE82E1344403BAC70CB478E484055320054711544403BAC70CB478E48405532005471154440AC527AA6978C484095D74AE82E134440AC527AA6978C4840
41147	17657	39.918149	39.948943	48.932585000000003	48.906750000000002	Ленина	0103000020E6100000010000000500000074ED0BE885F54340F2D24D621074484074ED0BE885F54340BEDEFDF15E7748405262D7F676F94340BEDEFDF15E7748405262D7F676F94340F2D24D621074484074ED0BE885F54340F2D24D6210744840
55886	56739	40.336556999999999	40.377682	48.834297999999997	48.800057000000002	Центральная	0103000020E61000000100000005000000B41EBE4C142B4440CBF78C4468664840B41EBE4C142B4440218FE046CA6A4840D9243FE257304440218FE046CA6A4840D9243FE257304440CBF78C4468664840B41EBE4C142B4440CBF78C4468664840
55921	56773	40.199941000000003	40.220962	49.088448999999997	49.054305999999997	Молодежная	0103000020E610000001000000050000009510ACAA9719444000FDBE7FF38648409510ACAA97194440942EFD4B528B484052D4997B481C4440942EFD4B528B484052D4997B481C444000FDBE7FF38648409510ACAA9719444000FDBE7FF3864840
56556	57008	40.142933999999997	40.176217000000001	49.056165999999997	49.042957000000001	Школьная	0103000020E6100000010000000500000044BE4BA94B12444030116F9D7F85484044BE4BA94B124440D5928E7230874840E7FF55478E164440D5928E7230874840E7FF55478E16444030116F9D7F85484044BE4BA94B12444030116F9D7F854840
56504	56963	40.071105000000003	40.114035000000001	48.999681000000002	48.958407999999999	Калинина	0103000020E6100000010000000500000082CAF8F719094440C51C041DAD7A484082CAF8F7190944405FB7088CF57F4840B8CCE9B2980E44405FB7088CF57F4840B8CCE9B2980E4440C51C041DAD7A484082CAF8F719094440C51C041DAD7A4840
56394	56866	38.803815999999998	38.809232999999999	47.589528000000001	47.582107000000001	Примиусская	0103000020E6100000010000000500000032005471E3664340E7E26F7B82CA474032005471E3664340C4094CA775CB474007EC6AF294674340C4094CA775CB474007EC6AF294674340E7E26F7B82CA474032005471E3664340E7E26F7B82CA4740
56245	25614	38.861531999999997	38.870128999999999	47.537194999999997	47.531816999999997	Парковая	0103000020E610000001000000050000008E3A3AAE466E4340793A579412C447408E3A3AAE466E4340904946CEC2C447408D261763606F4340904946CEC2C447408D261763606F4340793A579412C447408E3A3AAE466E4340793A579412C44740
55815	56698	38.853240999999997	38.882292	47.606413000000003	47.598545000000001	проспект Дружбы	0103000020E610000001000000050000009C4D4700376D43409817601F9DCC47409C4D4700376D4340446FF1F09ECD4740DFC2BAF1EE704340446FF1F09ECD4740DFC2BAF1EE7043409817601F9DCC47409C4D4700376D43409817601F9DCC4740
39754	2798	38.906627999999998	38.923012999999997	47.497706000000001	47.470284999999997	Таганрогская	0103000020E61000000100000005000000A6D1E4620C7443405166834C32BC4740A6D1E4620C744340F18288D4B4BF474034643C4A25764340F18288D4B4BF474034643C4A257643405166834C32BC4740A6D1E4620C7443405166834C32BC4740
41347	2724	38.844357000000002	38.894815000000001	47.524948000000002	47.496988000000002	Ленина	0103000020E610000001000000050000000893E2E3136C43409240834D9DBF47400893E2E3136C4340E10CFE7E31C34740317C444C89724340E10CFE7E31C34740317C444C897243409240834D9DBF47400893E2E3136C43409240834D9DBF4740
55786	2923	39.053116000000003	39.082293	47.534798000000002	47.516075999999998	Азарова	0103000020E610000001000000050000007A724D81CC864340102043C70EC247407A724D81CC864340ADFBC74274C4474049D8B793888A4340ADFBC74274C4474049D8B793888A4340102043C70EC247407A724D81CC864340102043C70EC24740
55588	3483	38.672733000000001	38.690403000000003	47.627374000000003	47.607743999999997	Ленина	0103000020E6100000010000000500000051F86C1D1C5643408C2B2E8ECACD474051F86C1D1C5643402C2E8ECA4DD04740B80721205F5843402C2E8ECA4DD04740B80721205F5843408C2B2E8ECACD474051F86C1D1C5643408C2B2E8ECACD4740
55790	3028	39.030200000000001	39.046756000000002	47.578667000000003	47.568387000000001	50 лет Победы	0103000020E610000001000000050000006B2BF697DD8343405C3CBCE7C0C847406B2BF697DD8343402123A0C211CA47402672C119FC8543402123A0C211CA47402672C119FC8543405C3CBCE7C0C847406B2BF697DD8343405C3CBCE7C0C84740
55585	3204	38.830981000000001	38.849747000000001	47.648654999999998	47.641437000000003	Первомайская	0103000020E61000000100000005000000774CDD955D6A4340E1B88C9B1AD24740774CDD955D6A434085B1852007D34740E36F7B82C46C434085B1852007D34740E36F7B82C46C4340E1B88C9B1AD24740774CDD955D6A4340E1B88C9B1AD24740
39753	2342	38.842846999999999	38.884582999999999	47.597602999999999	47.552036000000001	Славы	0103000020E610000001000000050000000F441669E26B43407A1B9B1DA9C647400F441669E26B4340E97E4E417ECC47407DCC07043A714340E97E4E417ECC47407DCC07043A7143407A1B9B1DA9C647400F441669E26B43407A1B9B1DA9C64740
39791	2342	38.842846999999999	38.884582999999999	47.597602999999999	47.552036000000001	Донецкая	0103000020E610000001000000050000000F441669E26B43407A1B9B1DA9C647400F441669E26B4340E97E4E417ECC47407DCC07043A714340E97E4E417ECC47407DCC07043A7143407A1B9B1DA9C647400F441669E26B43407A1B9B1DA9C64740
39750	2342	38.842846999999999	38.884582999999999	47.597602999999999	47.552036000000001	1-я Пятилетка	0103000020E610000001000000050000000F441669E26B43407A1B9B1DA9C647400F441669E26B4340E97E4E417ECC47407DCC07043A714340E97E4E417ECC47407DCC07043A7143407A1B9B1DA9C647400F441669E26B43407A1B9B1DA9C64740
41345	2342	38.842846999999999	38.884582999999999	47.597602999999999	47.552036000000001	1-я Мая	0103000020E610000001000000050000000F441669E26B43407A1B9B1DA9C647400F441669E26B4340E97E4E417ECC47407DCC07043A714340E97E4E417ECC47407DCC07043A7143407A1B9B1DA9C647400F441669E26B43407A1B9B1DA9C64740
55480	2966	39.129832	39.143872999999999	47.599601999999997	47.584307000000003	Парамонова	0103000020E61000000100000005000000B5FCC0559E90434075E95F92CACA4740B5FCC0559E904340DF4E22C2BFCC474082E3326E6A924340DF4E22C2BFCC474082E3326E6A92434075E95F92CACA4740B5FCC0559E90434075E95F92CACA4740
41350	3606	38.509402000000001	38.539135999999999	47.606413000000003	47.585273000000001	Центральная	0103000020E610000001000000050000002D42B11534414340AC1DC539EACA47402D42B11534414340446FF1F09ECD4740520C906802454340446FF1F09ECD4740520C906802454340AC1DC539EACA47402D42B11534414340AC1DC539EACA4740
55812	3885	38.508315000000003	38.536549000000001	47.482326	47.457034999999998	Аникиенко	0103000020E610000001000000050000007B884677104143404D10751F80BA47407B884677104143405801BEDBBCBD4740CBD93BA3AD4443405801BEDBBCBD4740CBD93BA3AD4443404D10751F80BA47407B884677104143404D10751F80BA4740
56493	56953	38.336719000000002	38.354460000000003	47.503428	47.500287	Центральная	0103000020E610000001000000050000008E78B29B192B434096CE876709C047408E78B29B192B434002F2255470C04740BEDEFDF15E2D434002F2255470C04740BEDEFDF15E2D434096CE876709C047408E78B29B192B434096CE876709C04740
55500	3533	38.631591	38.665348999999999	47.569864000000003	47.561225	Центральная	0103000020E6100000010000000500000056B950F9D75043404B598638D6C7474056B950F9D75043407995B54DF1C8474091B6F1272A5543407995B54DF1C8474091B6F1272A5543404B598638D6C7474056B950F9D75043404B598638D6C74740
40154	3934	38.620263000000001	38.647050999999998	47.483987999999997	47.471716999999998	Ленина	0103000020E610000001000000050000009DF529C7644F4340CEFBFF3861BC47409DF529C7644F434006D49B51F3BD47400BEC3191D252434006D49B51F3BD47400BEC3191D2524340CEFBFF3861BC47409DF529C7644F4340CEFBFF3861BC4740
55575	3158	38.910840999999998	38.942146999999999	47.693384999999999	47.684486999999997	Таганрогская	0103000020E610000001000000050000008F6D197096744340C1C41F459DD747408F6D197096744340BB44F5D6C0D847402383DC4598784340BB44F5D6C0D847402383DC4598784340C1C41F459DD747408F6D197096744340C1C41F459DD74740
55587	3385	38.795470000000002	38.804201999999997	47.622073	47.604244000000001	Светлая	0103000020E610000001000000050000007D7901F6D1654340F1660DDE57CD47407D7901F6D1654340C05C8B16A0CF47405BB05417F0664340C05C8B16A0CF47405BB05417F0664340F1660DDE57CD47407D7901F6D1654340F1660DDE57CD4740
56115	2629	38.795084000000003	38.804040000000001	47.575816000000003	47.572502999999998	Заречная	0103000020E6100000010000000500000054C90050C565434052EE3EC747C9474054C90050C5654340BC41B456B4C94740825660C8EA664340BC41B456B4C94740825660C8EA66434052EE3EC747C9474054C90050C565434052EE3EC747C94740
56073	4038	38.680233999999999	38.692362000000003	47.433458000000002	47.418613000000001	Школьная	0103000020E610000001000000050000004AD05FE81157434019575C1C95B547404AD05FE81157434044183F8D7BB74740207F69519F58434044183F8D7BB74740207F69519F58434019575C1C95B547404AD05FE81157434019575C1C95B54740
55930	56780	38.878376000000003	38.889353	47.546227999999999	47.535832999999997	Таганрогская	0103000020E61000000100000005000000B0CBF09F6E7043400C8FFD2C96C44740B0CBF09F6E7043406A1492CCEAC54740BCCCB051D67143406A1492CCEAC54740BCCCB051D67143400C8FFD2C96C44740B0CBF09F6E7043400C8FFD2C96C44740
55572	2856	38.979095000000001	39.042309000000003	47.514366000000003	47.497602000000001	Центральная	0103000020E61000000100000005000000AC5626FC527D43404C361E6CB1BF4740AC5626FC527D43405116BEBED6C14740CAA99D616A8543405116BEBED6C14740CAA99D616A8543404C361E6CB1BF4740AC5626FC527D43404C361E6CB1BF4740
40155	3695	38.379973	38.393869000000002	47.554098000000003	47.525683999999998	переулок Школьный	0103000020E61000000100000005000000772E8CF4A2304340E603029D49C34740772E8CF4A2304340B763EAAEECC6474041F4A44C6A324340B763EAAEECC6474041F4A44C6A324340E603029D49C34740772E8CF4A2304340E603029D49C34740
55502	3801	38.380322999999997	38.394776999999998	47.456597000000002	47.432817999999997	Кирова	0103000020E6100000010000000500000053758F6CAE304340608F899466B7474053758F6CAE304340D2393FC571BA4740431B800D88324340D2393FC571BA4740431B800D88324340608F899466B7474053758F6CAE304340608F899466B74740
55511	3830	38.502825999999999	38.517226000000001	47.435146000000003	47.423375	Мира	0103000020E610000001000000050000000CCA349A5C404340D578E92631B647400CCA349A5C4043401C7E37DDB2B7474009522976344243401C7E37DDB2B747400952297634424340D578E92631B647400CCA349A5C404340D578E92631B64740
55787	3082	38.882013999999998	38.909205999999998	47.666874999999997	47.645285999999999	Советская	0103000020E610000001000000050000009C4EB2D5E570434088484DBB98D247409C4EB2D5E57043408FC2F5285CD54740DAA9B9DC607443408FC2F5285CD54740DAA9B9DC6074434088484DBB98D247409C4EB2D5E570434088484DBB98D24740
40766	3644	38.512627000000002	38.532964999999997	47.578667000000003	47.547243999999999	Ленина	0103000020E61000000100000005000000F705F4C29D414340537765170CC64740F705F4C29D4143402123A0C211CA4740D1747632384443402123A0C211CA4740D174763238444340537765170CC64740F705F4C29D414340537765170CC64740
55789	3268	38.813769000000001	38.825626999999997	47.643476999999997	47.627367999999997	Гагарина	0103000020E61000000100000005000000D3BF249529684340494739984DD04740D3BF249529684340355D4F745DD24740E8D84125AE694340355D4F745DD24740E8D84125AE694340494739984DD04740D3BF249529684340494739984DD04740
55696	30759	38.784734999999998	38.803151	47.644666999999998	47.624684000000002	Московская	0103000020E6100000010000000500000066834C3272644340D02A33A5F5CF474066834C3272644340BCE7C07284D24740F65FE7A6CD664340BCE7C07284D24740F65FE7A6CD664340D02A33A5F5CF474066834C3272644340D02A33A5F5CF4740
56544	56997	38.736190000000001	38.749583999999999	47.681362999999997	47.672572000000002	Победы	0103000020E6100000010000000500000035D252793B5E4340481ADCD616D6474035D252793B5E43402BDA1CE736D747406CCD565EF25F43402BDA1CE736D747406CCD565EF25F4340481ADCD616D6474035D252793B5E4340481ADCD616D64740
40309	3430	38.670074	38.684384999999999	47.699103999999998	47.681975999999999	Ленина	0103000020E6100000010000000500000030F31DFCC4554340155454FD4AD7474030F31DFCC45543405B40683D7CD94740BD6F7CED995743405B40683D7CD94740BD6F7CED99574340155454FD4AD7474030F31DFCC4554340155454FD4AD74740
40456	4100	41.853344999999997	41.877814999999998	47.345007000000003	47.333905000000001	переулок Клубный	0103000020E61000000100000005000000419AB1683AED4440467C2766BDAA4740419AB1683AED44400FF27A3029AC47401878EE3D5CF044400FF27A3029AC47401878EE3D5CF04440467C2766BDAA4740419AB1683AED4440467C2766BDAA4740
40052	4100	41.853344999999997	41.877814999999998	47.345007000000003	47.333905000000001	Административный переулок	0103000020E61000000100000005000000419AB1683AED4440467C2766BDAA4740419AB1683AED44400FF27A3029AC47401878EE3D5CF044400FF27A3029AC47401878EE3D5CF04440467C2766BDAA4740419AB1683AED4440467C2766BDAA4740
55667	2273	41.221029000000001	41.235878999999997	47.443441	47.432166000000002	Ленина	0103000020E61000000100000005000000DA3BA3AD4A9C4440B9382A3751B74740DA3BA3AD4A9C44404F5AB8ACC2B8474016687748319E44404F5AB8ACC2B8474016687748319E4440B9382A3751B74740DA3BA3AD4A9C4440B9382A3751B74740
55586	4214	41.848717999999998	41.855491000000001	47.372028999999998	47.362264000000003	Ленина	0103000020E6100000010000000500000065C39ACAA2EC44405342B0AA5EAE474065C39ACAA2EC4440F01472A59EAF4740DC82A5BA80ED4440F01472A59EAF4740DC82A5BA80ED44405342B0AA5EAE474065C39ACAA2EC44405342B0AA5EAE4740
56262	2506	41.701546999999998	41.710099	47.161161999999997	47.151240999999999	Краснопартизанская	0103000020E61000000100000005000000AFCDC64ACCD944403C6876DD5B934740AFCDC64ACCD94440D1ADD7F4A09447400EF62686E4DA4440D1ADD7F4A09447400EF62686E4DA44403C6876DD5B934740AFCDC64ACCD944403C6876DD5B934740
56274	2630	41.882387000000001	41.897137000000001	47.157331999999997	47.145730999999998	Широкая	0103000020E6100000010000000500000031B5A50EF2F04440B6813B50A792474031B5A50EF2F04440A04E7974239447400A849D62D5F24440A04E7974239447400A849D62D5F24440B6813B50A792474031B5A50EF2F04440B6813B50A7924740
55515	2926	41.342616	41.365164	47.320224000000003	47.304864999999999	Центральная	0103000020E610000001000000050000000D8B51D7DAAB4440F758FAD005A747400D8B51D7DAAB444079B29B19FDA8474099D6A6B1BDAE444079B29B19FDA8474099D6A6B1BDAE4440F758FAD005A747400D8B51D7DAAB4440F758FAD005A74740
56414	56884	41.836877999999999	41.851394999999997	47.315550999999999	47.306153999999999	Юбилейная	0103000020E61000000100000005000000F65E7CD11EEB444011C5E40D30A74740F65E7CD11EEB44402C9CA4F963A847402C7DE882FAEC44402C9CA4F963A847402C7DE882FAEC444011C5E40D30A74740F65E7CD11EEB444011C5E40D30A74740
56148	3698	41.694755999999998	41.700702999999997	47.287624999999998	47.283132000000002	Северная	0103000020E610000001000000050000009259BDC3EDD84440BD395CAB3DA447409259BDC3EDD84440894160E5D0A44740C39ACAA2B0D94440894160E5D0A44740C39ACAA2B0D94440BD395CAB3DA447409259BDC3EDD84440BD395CAB3DA44740
55520	56669	41.469692000000002	41.492626000000001	47.278804000000001	47.262515	Кировская	0103000020E61000000100000005000000AF9811DE1EBC4440CFDA6D179AA14740AF9811DE1EBC44403BFF76D9AFA347406494675E0EBF44403BFF76D9AFA347406494675E0EBF4440CFDA6D179AA14740AF9811DE1EBC4440CFDA6D179AA14740
55310	56645	41.290936000000002	41.313161000000001	47.208263000000002	47.187666999999998	Центральная	0103000020E61000000100000005000000529D0E643DA54440EBC4E57805984740529D0E643DA54440C2FBAA5CA89A4740FBB0DEA815A84440C2FBAA5CA89A4740FBB0DEA815A84440EBC4E57805984740529D0E643DA54440EBC4E57805984740
56584	57028	41.806749000000003	41.819899999999997	47.261512000000003	47.254131000000001	Школьная	0103000020E61000000100000005000000558A1D8D43E744402CF3565D87A04740558A1D8D43E744407BC1A73979A14740C5FEB27BF2E844407BC1A73979A14740C5FEB27BF2E844402CF3565D87A04740558A1D8D43E744402CF3565D87A04740
56009	3798	41.707835000000003	41.716422999999999	47.278723999999997	47.272970999999998	Думенко	0103000020E610000001000000050000006AFB57569ADA4440D2E0B6B6F0A247406AFB57569ADA44401E4E603AADA34740158DB5BFB3DB44401E4E603AADA34740158DB5BFB3DB4440D2E0B6B6F0A247406AFB57569ADA4440D2E0B6B6F0A24740
55516	3428	41.624758999999997	41.631227000000003	47.238520000000001	47.233980000000003	Центральная	0103000020E61000000100000005000000DA70581AF8CF444084F57F0EF39D4740DA70581AF8CF444091B8C7D2879E474015ADDC0BCCD0444091B8C7D2879E474015ADDC0BCCD0444084F57F0EF39D4740DA70581AF8CF444084F57F0EF39D4740
56264	56836	41.471803000000001	41.490271999999997	47.288314999999997	47.279366000000003	Несмеяновская	0103000020E61000000100000005000000CD936B0A64BC4440A3CEDC43C2A34740CD936B0A64BC44401EF98381E7A447407F129F3BC1BE44401EF98381E7A447407F129F3BC1BE4440A3CEDC43C2A34740CD936B0A64BC4440A3CEDC43C2A34740
56443	56910	41.593164999999999	41.604591999999997	47.168984999999999	47.155132000000002	Московская	0103000020E61000000100000005000000E010AAD4ECCB44401348895DDB934740E010AAD4ECCB4440DD41EC4CA19547402CB6494563CD4440DD41EC4CA19547402CB6494563CD44401348895DDB934740E010AAD4ECCB44401348895DDB934740
55317	56648	41.378576000000002	41.404268000000002	47.297671999999999	47.282905999999997	Новая	0103000020E610000001000000050000007786A92D75B04440CCEB884336A447407786A92D75B04440AB77B81D1AA64740E068C70DBFB34440AB77B81D1AA64740E068C70DBFB34440CCEB884336A447407786A92D75B04440CCEB884336A44740
55698	56682	41.821759999999998	41.844405999999999	47.339773999999998	47.322856999999999	Административная	0103000020E610000001000000050000009A94826E2FE944407024D06053A947409A94826E2FE94440FB03E5B67DAB4740E945ED7E15EC4440FB03E5B67DAB4740E945ED7E15EC44407024D06053A947409A94826E2FE944407024D06053A94740
55670	2348	41.326914000000002	41.341197000000001	47.430154000000002	47.420205000000003	Садовая	0103000020E61000000100000005000000624D6551D8A94440CF4E0647C9B54740624D6551D8A944402E1F49490FB74740253FE257ACAB44402E1F49490FB74740253FE257ACAB4440CF4E0647C9B54740624D6551D8A94440CF4E0647C9B54740
55911	56763	41.443973	41.458947999999999	47.347423999999997	47.335456000000001	Центральная	0103000020E610000001000000050000004CA7751BD4B844409D9FE238F0AA47404CA7751BD4B8444039ECBE6378AC47404548DDCEBEBA444039ECBE6378AC47404548DDCEBEBA44409D9FE238F0AA47404CA7751BD4B844409D9FE238F0AA4740
56259	2793	41.483283999999998	41.502346000000003	47.372621000000002	47.363106999999999	Широкая	0103000020E610000001000000050000000C570740DCBD44406EF9484A7AAE47400C570740DCBD4440C366800BB2AF474062A3ACDF4CC04440C366800BB2AF474062A3ACDF4CC044406EF9484A7AAE47400C570740DCBD44406EF9484A7AAE4740
55530	2167	41.204993999999999	41.226894999999999	47.349744000000001	47.340012000000002	Мира	0103000020E6100000010000000500000028F04E3E3D9A4440B01F628385AB474028F04E3E3D9A444072FC5069C4AC47401E5036E50A9D444072FC5069C4AC47401E5036E50A9D4440B01F628385AB474028F04E3E3D9A4440B01F628385AB4740
55898	56751	41.740354000000004	41.751798999999998	47.251035999999999	47.241351999999999	Молодежная	0103000020E610000001000000050000003DBB7CEBC3DE44407F69519FE49E47403DBB7CEBC3DE4440300F99F221A047402F151BF33AE04440300F99F221A047402F151BF33AE044407F69519FE49E47403DBB7CEBC3DE44407F69519FE49E4740
56481	56943	41.421002999999999	41.433598000000003	47.256203999999997	47.243524000000001	Красноармейская	0103000020E610000001000000050000004A42226DE3B5444043E55FCB2B9F47404A42226DE3B544405C8DEC4ACBA0474036CEA62380B744405C8DEC4ACBA0474036CEA62380B7444043E55FCB2B9F47404A42226DE3B5444043E55FCB2B9F4740
40218	54884	41.251446000000001	41.274776000000003	47.280974000000001	47.269962999999997	Никифорова	0103000020E61000000100000005000000E25AED612FA04440A510C8258EA24740E25AED612FA044405E83BEF4F6A34740E4DC26DC2BA344405E83BEF4F6A34740E4DC26DC2BA34440A510C8258EA24740E25AED612FA04440A510C8258EA24740
55864	56721	41.928722	41.950839000000002	47.316564999999997	47.304315000000003	пер. Пионерский	0103000020E61000000100000005000000B189CC5CE0F6444054573ECBF3A64740B189CC5CE0F644407407B13385A847407461A417B5F944407407B13385A847407461A417B5F9444054573ECBF3A64740B189CC5CE0F6444054573ECBF3A64740
41076	2231	41.198104000000001	41.214596999999998	47.421424000000002	47.405912000000001	Строительный	0103000020E61000000100000005000000789ACC785B994440E886A6ECF4B34740789ACC785B994440F0DFBC38F1B54740EC681CEA779B4440F0DFBC38F1B54740EC681CEA779B4440E886A6ECF4B34740789ACC785B994440E886A6ECF4B34740
56405	56877	41.749993000000003	41.762067000000002	47.309691999999998	47.298931000000003	Ленина	0103000020E610000001000000050000004E9D47C5FFDF44405B61FA5E43A647404E9D47C5FFDF44409AEAC9FCA3A74740302E55698BE144409AEAC9FCA3A74740302E55698BE144405B61FA5E43A647404E9D47C5FFDF44405B61FA5E43A64740
55913	56765	41.334054999999999	41.349102000000002	47.263340999999997	47.254137	Школьная	0103000020E610000001000000050000005B087250C2AA44400EDAAB8F87A047405B087250C2AA444014596B28B5A14740EE7BD45FAFAC444014596B28B5A14740EE7BD45FAFAC44400EDAAB8F87A047405B087250C2AA44400EDAAB8F87A04740
55916	56768	41.429223	41.449399	47.375464999999998	47.364102000000003	Школьная	0103000020E6100000010000000500000073D87DC7F0B644404034F3E49AAE474073D87DC7F0B6444075E5B33C0FB0474074ED0BE885B9444075E5B33C0FB0474074ED0BE885B944404034F3E49AAE474073D87DC7F0B644404034F3E49AAE4740
56011	3380	41.553029000000002	41.567914000000002	47.211502000000003	47.202734999999997	Центральная	0103000020E61000000100000005000000AB5E7EA7C9C6444095607138F3994740AB5E7EA7C9C64440F1845E7F129B47406478EC67B1C84440F1845E7F129B47406478EC67B1C8444095607138F3994740AB5E7EA7C9C6444095607138F3994740
55522	4312	41.846086	41.855410999999997	47.414302999999997	47.404953999999996	переулок Экскаваторный	0103000020E610000001000000050000003ECDC98B4CEC444033315D88D5B347403ECDC98B4CEC44403DD175E107B54740BFD18E1B7EED44403DD175E107B54740BFD18E1B7EED444033315D88D5B347403ECDC98B4CEC444033315D88D5B34740
56500	56959	42.057414999999999	42.075228000000003	47.295484999999999	47.281951999999997	Кирова	0103000020E6100000010000000500000061A6ED5F590745405985CD0017A4474061A6ED5F59074540B2BAD573D2A547402BDF3312A1094540B2BAD573D2A547402BDF3312A10945405985CD0017A4474061A6ED5F590745405985CD0017A44740
55388	56641	41.255516	41.299928000000001	47.338265	47.316803	Советская	0103000020E6100000010000000500000068CD8FBFB4A0444029232E008DA8474068CD8FBFB4A04440D3307C444CAB4740CD936B0A64A64440D3307C444CAB4740CD936B0A64A6444029232E008DA8474068CD8FBFB4A0444029232E008DA84740
55295	56641	41.255516	41.299928000000001	47.338265	47.316803	Октябрьская	0103000020E6100000010000000500000068CD8FBFB4A0444029232E008DA8474068CD8FBFB4A04440D3307C444CAB4740CD936B0A64A64440D3307C444CAB4740CD936B0A64A6444029232E008DA8474068CD8FBFB4A0444029232E008DA84740
40452	3161	41.652076999999998	41.682853000000001	47.293742999999999	47.258816000000003	переулок Зыгина	0103000020E61000000100000005000000A5BC564277D344403DD7F7E120A14740A5BC564277D34440E736E15E99A54740DD7C23BA67D74440E736E15E99A54740DD7C23BA67D744403DD7F7E120A14740A5BC564277D344403DD7F7E120A14740
40220	3161	41.652076999999998	41.682853000000001	47.293742999999999	47.258816000000003	Ленина	0103000020E61000000100000005000000A5BC564277D344403DD7F7E120A14740A5BC564277D34440E736E15E99A54740DD7C23BA67D74440E736E15E99A54740DD7C23BA67D744403DD7F7E120A14740A5BC564277D344403DD7F7E120A14740
55307	3161	41.652076999999998	41.682853000000001	47.293742999999999	47.258816000000003	Ковалева	0103000020E61000000100000005000000A5BC564277D344403DD7F7E120A14740A5BC564277D34440E736E15E99A54740DD7C23BA67D74440E736E15E99A54740DD7C23BA67D744403DD7F7E120A14740A5BC564277D344403DD7F7E120A14740
55865	56722	41.663629	41.678154999999997	47.246245999999999	47.231563000000001	Школьная	0103000020E61000000100000005000000AED689CBF1D4444059FB3BDBA39D4740AED689CBF1D44440AA622AFD849F4740374F75C8CDD64440AA622AFD849F4740374F75C8CDD6444059FB3BDBA39D4740AED689CBF1D4444059FB3BDBA39D4740
56257	2398	41.250844000000001	41.265334000000003	47.409272000000001	47.400092999999998	Школьная	0103000020E61000000100000005000000EC32FCA71BA04440E42D573F36B34740EC32FCA71BA0444092955F0663B447402942EA76F6A1444092955F0663B447402942EA76F6A14440E42D573F36B34740EC32FCA71BA04440E42D573F36B34740
56376	20417	38.818997000000003	38.840178999999999	47.787756000000002	47.783718	Победы	0103000020E61000000100000005000000D542C9E4D4684340ADA415DF50E44740D542C9E4D4684340289D4830D5E447409BE447FC8A6B4340289D4830D5E447409BE447FC8A6B4340ADA415DF50E44740D542C9E4D4684340ADA415DF50E44740
55984	20237	38.932760000000002	38.949361000000003	47.750286000000003	47.740113000000001	Красноармейская	0103000020E610000001000000050000002C82FFAD64774340172CD505BCDE47402C82FFAD64774340C652245F09E04740878C47A984794340C652245F09E04740878C47A984794340172CD505BCDE47402C82FFAD64774340172CD505BCDE4740
56379	20698	39.253162000000003	39.278593000000001	47.751958000000002	47.742972999999999	 Социалистическая	0103000020E61000000100000005000000844BC79C67A04340CF6740BD19DF4740844BC79C67A0434098FBE42840E0474080F277EFA8A3434098FBE42840E0474080F277EFA8A34340CF6740BD19DF4740844BC79C67A04340CF6740BD19DF4740
56110	28961	38.855710999999999	38.867075	47.809485000000002	47.802743	Центральная	0103000020E61000000100000005000000EAE923F0876D4340E50B5A48C0E64740EAE923F0876D434021CD58349DE74740F0164850FC6E434021CD58349DE74740F0164850FC6E4340E50B5A48C0E64740EAE923F0876D4340E50B5A48C0E64740
56242	29068	39.067345000000003	39.090862999999999	47.709546000000003	47.701554000000002	Победы	0103000020E610000001000000050000004A46CEC29E88434062307F85CCD947404A46CEC29E884340FA804067D2DA47404EB51666A18B4340FA804067D2DA47404EB51666A18B434062307F85CCD947404A46CEC29E88434062307F85CCD94740
56364	336	38.874414000000002	38.880378999999998	47.787126000000001	47.770105000000001	Широкая	0103000020E61000000100000005000000109546CCEC6F434038BEF6CC92E24740109546CCEC6F434068EA758BC0E44740E78A5242B070434068EA758BC0E44740E78A5242B070434038BEF6CC92E24740109546CCEC6F434038BEF6CC92E24740
9937	20341	39.067560999999998	39.089748999999998	47.746093999999999	47.739586000000003	Победы	0103000020E6100000010000000500000016BEBED6A58843402C4A09C1AADE474016BEBED6A5884340F4DE180280DF4740A2EC2DE57C8B4340F4DE180280DF4740A2EC2DE57C8B43402C4A09C1AADE474016BEBED6A58843402C4A09C1AADE4740
55227	20453	39.056151999999997	39.080587000000001	47.854826000000003	47.837465000000002	Юбилейная	0103000020E6100000010000000500000070CD1DFD2F874340B745990D32EB474070CD1DFD2F874340A0E238F06AED4740CBBDC0AC508A4340A0E238F06AED4740CBBDC0AC508A4340B745990D32EB474070CD1DFD2F874340B745990D32EB4740
55706	20527	39.240684000000002	39.261012999999998	47.833927000000003	47.816673000000002	Школьная	0103000020E61000000100000005000000D255BABBCE9E43405B43A9BD88E84740D255BABBCE9E43402E20B41EBEEA4740596ABDDF68A143402E20B41EBEEA4740596ABDDF68A143405B43A9BD88E84740D255BABBCE9E43405B43A9BD88E84740
40184	20714	39.190522000000001	39.217453999999996	47.712116999999999	47.692148000000003	Кушнарёва	0103000020E6100000010000000500000092955F0663984340F4FE3F4E98D8474092955F06639843407BF65CA626DB474033315D88D59B43407BF65CA626DB474033315D88D59B4340F4FE3F4E98D8474092955F0663984340F4FE3F4E98D84740
40938	20120	38.890431	38.932364999999997	47.827364000000003	47.796315	Театральная	0103000020E610000001000000050000001B2C9CA4F9714340392861A6EDE547401B2C9CA4F9714340A2F14410E7E94740AF777FBC57774340A2F14410E7E94740AF777FBC57774340392861A6EDE547401B2C9CA4F9714340392861A6EDE54740
41220	20120	38.890431	38.932364999999997	47.827364000000003	47.796315	Пролетарская	0103000020E610000001000000050000001B2C9CA4F9714340392861A6EDE547401B2C9CA4F9714340A2F14410E7E94740AF777FBC57774340A2F14410E7E94740AF777FBC57774340392861A6EDE547401B2C9CA4F9714340392861A6EDE54740
55862	56719	39.225924999999997	39.236310000000003	47.672207999999998	47.651992999999997	Молодежная	0103000020E61000000100000005000000A52C431CEB9C4340471CB28174D34740A52C431CEB9C4340060E68E90AD64740E0DBF4673F9E4340060E68E90AD64740E0DBF4673F9E4340471CB28174D34740A52C431CEB9C4340471CB28174D34740
55894	56747	39.207473999999998	39.237791999999999	47.754956999999997	47.744414999999996	Октябрьская	0103000020E6100000010000000500000099620E828E9A43406FD39FFD48DF474099620E828E9A43407171546EA2E047400EA0DFF76F9E43407171546EA2E047400EA0DFF76F9E43406FD39FFD48DF474099620E828E9A43406FD39FFD48DF4740
56362	29017	39.135007000000002	39.147035000000002	47.764097	47.758507000000002	Калинина	0103000020E6100000010000000500000094DDCCE847914340BF64E3C116E1474094DDCCE84791434061FC34EECDE14740062FFA0AD292434061FC34EECDE14740062FFA0AD2924340BF64E3C116E1474094DDCCE847914340BF64E3C116E14740
56277	8332	39.155174000000002	39.163823999999998	47.823008000000002	47.817297000000003	Социалистическая	0103000020E610000001000000050000004298DBBDDC934340390F27309DE847404298DBBDDC934340562C7E5358E947406326512FF8944340562C7E5358E947406326512FF8944340390F27309DE847404298DBBDDC934340390F27309DE84740
56055	26269	39.356476999999998	39.367158000000003	47.725914000000003	47.720973999999998	Советская	0103000020E610000001000000050000005A63D009A1AD434016A243E048DC47405A63D009A1AD4340B2DAFCBFEADC47407E3B8908FFAE4340B2DAFCBFEADC47407E3B8908FFAE434016A243E048DC47405A63D009A1AD434016A243E048DC4740
56121	16829	40.050165	40.076791	48.125106000000002	48.108455999999997	Пионерская	0103000020E61000000100000005000000B13385CE6B0644400987DEE2E10D4840B13385CE6B064440464431790310484046D09849D4094440464431790310484046D09849D40944400987DEE2E10D4840B13385CE6B0644400987DEE2E10D4840
56156	16887	40.015920999999999	40.025613999999997	48.076546999999998	48.070635000000003	Гуковская	0103000020E61000000100000005000000E92807B309024440FB7953910A094840E92807B309024440AFCDC64ACC094840ED28CE5147034440AFCDC64ACC094840ED28CE5147034440FB7953910A094840E92807B309024440FB7953910A094840
56241	56831	39.785414000000003	39.801979000000003	47.779612	47.772007000000002	Школьный	0103000020E6100000010000000500000008E9297288E443403CA41820D1E2474008E9297288E44340DAC87553CAE34740168A743FA7E64340DAC87553CAE34740168A743FA7E643403CA41820D1E2474008E9297288E443403CA41820D1E24740
55487	18632	40.137796000000002	40.162103999999999	48.142327999999999	48.130988000000002	Горького	0103000020E6100000010000000500000083C2A04CA31144409015FC36C410484083C2A04CA31144400DA7CCCD371248408046E9D2BF1444400DA7CCCD371248408046E9D2BF1444409015FC36C410484083C2A04CA31144409015FC36C4104840
56562	57014	39.767124000000003	39.786715999999998	47.830437000000003	47.815494000000001	Советская	0103000020E6100000010000000500000005FD851E31E24340C80A7E1B62E8474005FD851E31E24340B63176C24BEA4740B69E211CB3E44340B63176C24BEA4740B69E211CB3E44340C80A7E1B62E8474005FD851E31E24340C80A7E1B62E84740
56516	56974	40.468933	40.483134999999997	48.116425999999997	48.108257000000002	Щаденко	0103000020E61000000100000005000000F1811DFF053C44401348895DDB0D4840F1811DFF053C4440B933130CE70E4840C746205ED73D4440B933130CE70E4840C746205ED73D44401348895DDB0D4840F1811DFF053C44401348895DDB0D4840
56537	56991	40.534796999999998	40.557965000000003	48.124443999999997	48.113756000000002	Мира	0103000020E61000000100000005000000DC7F643A74444440A5DC7D8E8F0E4840DC7F643A744444407A17EFC7ED0F484005A8A9656B4744407A17EFC7ED0F484005A8A9656B474440A5DC7D8E8F0E4840DC7F643A74444440A5DC7D8E8F0E4840
55964	56796	39.857405	39.868884999999999	47.976667999999997	47.960915999999997	Ворошилова	0103000020E61000000100000005000000A4367172BFED4340001AA54BFFFA4740A4367172BFED43405D86FF7403FD4740137EA99F37EF43405D86FF7403FD4740137EA99F37EF4340001AA54BFFFA4740A4367172BFED4340001AA54BFFFA4740
40868	16781	40.053184000000002	40.082962999999999	48.152102999999997	48.139220000000002	Восточная	0103000020E61000000100000005000000D255BABBCE0644407D7901F6D1114840D255BABBCE064440CE4F711C7813484097E315889E0A4440CE4F711C7813484097E315889E0A44407D7901F6D1114840D255BABBCE0644407D7901F6D1114840
39833	18368	40.373764999999999	40.394309999999997	48.089483000000001	48.081417000000002	Советская	0103000020E61000000100000005000000D9B11188D72F4440522B4CDF6B0A4840D9B11188D72F44402446CF2D740B48402D3E05C0783244402446CF2D740B48402D3E05C078324440522B4CDF6B0A4840D9B11188D72F4440522B4CDF6B0A4840
55811	19979	40.271707999999997	40.288991000000003	47.809987	47.794536000000001	Ленина	0103000020E61000000100000005000000E107E753C722444051BF0B5BB3E54740E107E753C7224440B3976DA7ADE747404FEB36A8FD244440B3976DA7ADE747404FEB36A8FD24444051BF0B5BB3E54740E107E753C722444051BF0B5BB3E54740
55405	56663	40.458863000000001	40.474080000000001	47.902434999999997	47.895215999999998	Советская	0103000020E61000000100000005000000172CD505BC3A44408F6D197096F24740172CD505BC3A444004E275FD82F3474006D847A7AE3C444004E275FD82F3474006D847A7AE3C44408F6D197096F24740172CD505BC3A44408F6D197096F24740
55982	19993	40.206516999999998	40.215212999999999	47.795867000000001	47.792344	Школьная	0103000020E61000000100000005000000B58828266F1A4440469737876BE54740B58828266F1A44409A7B48F8DEE5474047567E198C1B44409A7B48F8DEE5474047567E198C1B4440469737876BE54740B58828266F1A4440469737876BE54740
56575	57024	40.179918000000001	40.194074999999998	47.995773	47.986668000000002	Новая	0103000020E610000001000000050000001AFB928D071744403F0114234BFE47401AFB928D07174440B29E5A7D75FF474050FC1873D7184440B29E5A7D75FF474050FC1873D71844403F0114234BFE47401AFB928D071744403F0114234BFE4740
40183	18585	40.114852999999997	40.135711999999998	48.120227999999997	48.113112000000001	Советская	0103000020E610000001000000050000007A6CCB80B30E444080643A747A0E48407A6CCB80B30E4440200890A1630F48405ED6C4025F114440200890A1630F48405ED6C4025F11444080643A747A0E48407A6CCB80B30E444080643A747A0E4840
56122	19356	40.263829999999999	40.294075999999997	47.890734000000002	47.875264000000001	Центральная	0103000020E6100000010000000500000012DA722EC5214440DEAE97A608F0474012DA722EC5214440B7B75B9203F24740ED444948A4254440B7B75B9203F24740ED444948A4254440DEAE97A608F0474012DA722EC5214440DEAE97A608F04740
55341	56655	40.183736000000003	40.211790000000001	47.887633999999998	47.880715000000002	Советская	0103000020E61000000100000005000000878C47A9841744405F0CE544BBF04740878C47A984174440A968ACFD9DF1474057CF49EF1B1B4440A968ACFD9DF1474057CF49EF1B1B44405F0CE544BBF04740878C47A9841744405F0CE544BBF04740
39857	19852	40.038775000000001	40.060217000000002	47.936197	47.918258999999999	Ленина	0103000020E6100000010000000500000082734694F6044440FB20CB8289F5474082734694F604444081CEA44DD5F74740E5D4CE30B507444081CEA44DD5F74740E5D4CE30B5074440FB20CB8289F5474082734694F6044440FB20CB8289F54740
55313	56646	39.902724999999997	39.924211999999997	48.075372999999999	48.050196999999997	Советская	0103000020E610000001000000050000000B24287E8CF34340BCADF4DA6C0648400B24287E8CF343402E008DD2A50948400E492D944CF643402E008DD2A50948400E492D944CF64340BCADF4DA6C0648400B24287E8CF34340BCADF4DA6C064840
55743	14336	40.085056000000002	40.099204	48.042456000000001	48.025008	Карла Маркса	0103000020E610000001000000050000000F2A711DE30A4440B6114F76330348400F2A711DE30A44406EC2BD326F054840F2D077B7B20C44406EC2BD326F054840F2D077B7B20C4440B6114F76330348400F2A711DE30A4440B6114F7633034840
56108	19511	39.811591	39.843767999999997	47.936776000000002	47.924326999999998	Саломатина	0103000020E610000001000000050000002D5DC136E2E74340A7E7DD5850F647402D5DC136E2E74340BFD6A546E8F74740A6B4FE9600EC4340BFD6A546E8F74740A6B4FE9600EC4340A7E7DD5850F647402D5DC136E2E74340A7E7DD5850F64740
55577	56673	39.796481	39.821660999999999	48.018751999999999	48.003104	Карьерная	0103000020E610000001000000050000005471E316F3E543404F3E3DB6650048405471E316F3E54340075E2D776602484007B309302CE94340075E2D776602484007B309302CE943404F3E3DB6650048405471E316F3E543404F3E3DB665004840
56388	56861	39.933275999999999	39.976188999999998	48.131120000000003	48.109453999999999	Мичурина	0103000020E610000001000000050000002312859675F743404C35B396020E48402312859675F74340FFEC478AC810484083DBDAC2F3FC4340FFEC478AC810484083DBDAC2F3FC43404C35B396020E48402312859675F743404C35B396020E4840
56240	25026	40.260551	40.271887	48.050347000000002	48.045444000000003	Степная	0103000020E6100000010000000500000055F833BC5921444054E6E61BD105484055F833BC59214440D2393FC571064840919A7631CD224440D2393FC571064840919A7631CD22444054E6E61BD105484055F833BC5921444054E6E61BD1054840
56357	56848	40.079791999999998	40.086573999999999	48.039082999999998	48.030847000000001	Придорожная	0103000020E61000000100000005000000C03DCF9F360A4440011764CBF2034840C03DCF9F360A44402F6AF7AB000548408A5759DB140B44402F6AF7AB000548408A5759DB140B4440011764CBF2034840C03DCF9F360A4440011764CBF2034840
55215	14780	40.203004999999997	40.216973000000003	48.041758000000002	48.019916000000002	Ленина	0103000020E6100000010000000500000055F65D11FC1944406555849B8C02484055F65D11FC194440562C7E5358054840B98E71C5C51B4440562C7E5358054840B98E71C5C51B44406555849B8C02484055F65D11FC1944406555849B8C024840
55793	56696	39.903703999999998	39.918373000000003	48.040035000000003	48.028604999999999	Первомайская	0103000020E61000000100000005000000D7A19A92ACF3434044C02154A9034840D7A19A92ACF3434002D9EBDD1F054840C443183F8DF5434002D9EBDD1F054840C443183F8DF5434044C02154A9034840D7A19A92ACF3434044C02154A9034840
55277	56632	40.179487000000002	40.218086999999997	48.134583999999997	48.114452999999997	Ленина	0103000020E610000001000000050000005187156EF9164440ECF65965A60E48405187156EF91644404D486B0C3A11484064575A46EA1B44404D486B0C3A11484064575A46EA1B4440ECF65965A60E48405187156EF9164440ECF65965A60E4840
39788	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	инени Героя Советского Союза Алексеева А.И	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
39851	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Шоссейная	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
39830	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Чкалова	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
40180	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Центральная	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
39849	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Фондовый	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
40869	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Строителей	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
39856	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Свободы	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
55222	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Революционный	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
39831	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Первомайская	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
55219	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Московская	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
55510	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Металлургов	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
55225	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Ленина	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
55226	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Культуры	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
41218	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Кронштадтская	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
40937	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Краснопартизанская	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
40182	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Интернациональная	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
40181	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Гагарина	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
40935	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Вокзальная	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
40931	16973	39.992026000000003	40.138658	47.916677	47.850557999999999	Вербенская	0103000020E610000001000000050000000F643DB5FAFE4340F3ACA415DFEC47400F643DB5FAFE434069FF03AC55F5474015AA9B8BBF11444069FF03AC55F5474015AA9B8BBF114440F3ACA415DFEC47400F643DB5FAFE4340F3ACA415DFEC4740
56123	56813	39.848430999999998	39.860477000000003	48.006504	48.000753000000003	Щербатых	0103000020E61000000100000005000000CFF4126399EC4340DC2F9FAC18004840CFF4126399EC434087A5811FD5004840E8FA3E1C24EE434087A5811FD5004840E8FA3E1C24EE4340DC2F9FAC18004840CFF4126399EC4340DC2F9FAC18004840
55687	19518	39.875093	39.893248	47.894002	47.876472999999997	Мичурина	0103000020E61000000100000005000000B1FA230C03F04340DB696B4430F04740B1FA230C03F04340804754A86EF24740D49B51F355F24340804754A86EF24740D49B51F355F24340DB696B4430F04740B1FA230C03F04340DB696B4430F04740
56465	56930	40.499395	40.515897000000002	47.994362000000002	47.984876	Советская	0103000020E610000001000000050000009964E42CEC3F4440C24EB16A10FE47409964E42CEC3F44404D31074147FF4740618DB3E9084244404D31074147FF4740618DB3E908424440C24EB16A10FE47409964E42CEC3F4440C24EB16A10FE4740
56436	56905	40.540035000000003	40.549196999999999	47.898375999999999	47.891796999999997	Набережная	0103000020E6100000010000000500000002D9EBDD1F454440E0D5726726F2474002D9EBDD1F45444072C119FCFDF24740D90759164C46444072C119FCFDF24740D90759164C464440E0D5726726F2474002D9EBDD1F454440E0D5726726F24740
56492	56952	40.040166999999997	40.060612999999996	48.009264999999999	47.986704000000003	Малиновского	0103000020E6100000010000000500000070B03731240544408C6A11514CFE474070B0373124054440ACFF73982F014840315BB22AC2074440ACFF73982F014840315BB22AC20744408C6A11514CFE474070B03731240544408C6A11514CFE4740
55686	56681	39.930213000000002	39.960720000000002	47.993505999999996	47.972053000000002	Краснопартизанская	0103000020E6100000010000000500000033A8363811F74340467D923B6CFC474033A8363811F743409C3061342BFF47407B4E7ADFF8FA43409C3061342BFF47407B4E7ADFF8FA4340467D923B6CFC474033A8363811F74340467D923B6CFC4740
56460	56926	40.334752000000002	40.349725999999997	47.849663	47.836564000000003	Победы	0103000020E61000000100000005000000A3224E27D92A44406781768714EB4740A3224E27D92A444085CFD6C1C1EC4740CB4752D2C32C444085CFD6C1C1EC4740CB4752D2C32C44406781768714EB4740A3224E27D92A44406781768714EB4740
39853	17410	39.711841999999997	40.609977000000001	48.190980000000003	47.727884000000003	Соцтруда	0103000020E61000000100000005000000A9F57EA31DDB43400EA48B4D2BDD4740A9F57EA31DDB434055185B0872184840F627F1B9134E444055185B0872184840F627F1B9134E44400EA48B4D2BDD4740A9F57EA31DDB43400EA48B4D2BDD4740
55592	18482	40.287571999999997	40.308017999999997	47.939751999999999	47.930062999999997	Ленина	0103000020E61000000100000005000000669FC728CF2444401D1CEC4D0CF74740669FC728CF244440E02C25CB49F84740274A42226D274440E02C25CB49F84740274A42226D2744401D1CEC4D0CF74740669FC728CF2444401D1CEC4D0CF74740
55920	56772	40.353248000000001	40.372957	47.981426999999996	47.969465	Октябрьская	0103000020E610000001000000050000004FB0FF3A372D4440EECEDA6D17FC47404FB0FF3A372D4440A83462669FFD47403AE8120EBD2F4440A83462669FFD47403AE8120EBD2F4440EECEDA6D17FC47404FB0FF3A372D4440EECEDA6D17FC4740
56130	27658	41.292616000000002	41.303908	47.792223	47.780957000000001	Западная	0103000020E61000000100000005000000A724EB7074A54440884A2366F6E34740A724EB7074A54440CB11329067E54740137F1475E6A64440CB11329067E54740137F1475E6A64440884A2366F6E34740A724EB7074A54440884A2366F6E34740
56324	19164	41.216143000000002	41.240900000000003	47.646025999999999	47.635572000000003	Спортивная	0103000020E610000001000000050000003221E692AA9B44406D205D6C5AD147403221E692AA9B4440CF2EDFFAB0D247409FCDAACFD59E4440CF2EDFFAB0D247409FCDAACFD59E44406D205D6C5AD147403221E692AA9B44406D205D6C5AD14740
55987	27441	41.278477000000002	41.294476000000003	47.878062	47.865043	Степная	0103000020E6100000010000000500000017D86322A5A344401E51A1BAB9EE474017D86322A5A3444020EEEA5564F047407CBABA63B1A5444020EEEA5564F047407CBABA63B1A544401E51A1BAB9EE474017D86322A5A344401E51A1BAB9EE4740
56375	27616	41.690345000000001	41.708069000000002	47.818482000000003	47.810895000000002	Центральная	0103000020E6100000010000000500000083FA96395DD84440B6BE4868CBE7474083FA96395DD84440AE2EA704C4E84740DD274701A2DA4440AE2EA704C4E84740DD274701A2DA4440B6BE4868CBE7474083FA96395DD84440B6BE4868CBE74740
56326	19593	41.511518000000002	41.530768000000002	47.893614999999997	47.875433000000001	Центральная	0103000020E610000001000000050000005DA8FC6B79C144406A6B44300EF047405DA8FC6B79C14440861BF0F961F24740B5E1B034F0C34440861BF0F961F24740B5E1B034F0C344406A6B44300EF047405DA8FC6B79C144406A6B44300EF04740
56013	56801	41.456980999999999	41.476464999999997	47.600501999999999	47.596066	Школьная	0103000020E610000001000000050000005AF2785A7EBA4440F72004E44BCC47405AF2785A7EBA44405F97E13FDDCC474025581CCEFCBC44405F97E13FDDCC474025581CCEFCBC4440F72004E44BCC47405AF2785A7EBA4440F72004E44BCC4740
55996	19536	41.422566000000003	41.437865000000002	47.711182999999998	47.699995999999999	Фестивальная	0103000020E61000000100000005000000663387A416B6444058AA0B7899D94740663387A416B644404F3C670B08DB47401288D7F50BB844404F3C670B08DB47401288D7F50BB8444058AA0B7899D94740663387A416B6444058AA0B7899D94740
55993	27541	41.754143999999997	41.770932999999999	47.620773	47.612870999999998	Центральная	0103000020E61000000100000005000000C03C64CA87E044405AD5928E72CE4740C03C64CA87E04440B29E5A7D75CF47401E34BBEEADE24440B29E5A7D75CF47401E34BBEEADE244405AD5928E72CE4740C03C64CA87E044405AD5928E72CE4740
55986	18881	41.039363000000002	41.057617	47.844074999999997	47.833624	Центральная	0103000020E6100000010000000500000013D6C6D8098544409294F430B4EA474013D6C6D809854440832F4CA60AEC4740C9586DFE5F874440832F4CA60AEC4740C9586DFE5F8744409294F430B4EA474013D6C6D8098544409294F430B4EA4740
40109	19247	41.480499000000002	41.553154999999997	47.624203999999999	47.588835000000003	Центральная	0103000020E610000001000000050000005F61C1FD80BD4440BEDEFDF15ECB47405F61C1FD80BD44402504ABEAE5CF4740374F75C8CDC644402504ABEAE5CF4740374F75C8CDC64440BEDEFDF15ECB47405F61C1FD80BD4440BEDEFDF15ECB4740
56079	18916	41.016258000000001	41.047016999999997	47.909623000000003	47.894866	Набережная	0103000020E610000001000000050000003126FDBD14824440B32616F88AF247403126FDBD148244403F58C6866EF4474092AD2EA7048644403F58C6866EF4474092AD2EA704864440B32616F88AF247403126FDBD14824440B32616F88AF24740
56170	18644	41.058110999999997	41.084215999999998	47.728914000000003	47.710534000000003	Мира	0103000020E61000000100000005000000D844662E70874440195932C7F2DA4740D844662E708744405CCCCF0D4DDD474064E60297C78A44405CCCCF0D4DDD474064E60297C78A4440195932C7F2DA4740D844662E70874440195932C7F2DA4740
55960	18813	40.958820000000003	40.970615000000002	47.676813000000003	47.666055	Березовая	0103000020E6100000010000000500000018601F9DBA7A44402C2B4D4A41D5474018601F9DBA7A4440FB40F2CEA1D64740E700C11C3D7C4440FB40F2CEA1D64740E700C11C3D7C44402C2B4D4A41D5474018601F9DBA7A44402C2B4D4A41D54740
55750	19321	41.694324999999999	41.722279999999998	47.607823000000003	47.600282999999997	Зеленая	0103000020E61000000100000005000000C9E53FA4DFD8444021ACC612D6CC4740C9E53FA4DFD84440D960E124CDCD47400647C9AB73DC4440D960E124CDCD47400647C9AB73DC444021ACC612D6CC4740C9E53FA4DFD8444021ACC612D6CC4740
55981	19427	41.306657000000001	41.314481000000001	47.757865000000002	47.750104999999998	Центральная	0103000020E61000000100000005000000740B5D8940A7444075C8CD7003E04740740B5D8940A744403BE466B801E14740501BD5E940A844403BE466B801E14740501BD5E940A8444075C8CD7003E04740740B5D8940A7444075C8CD7003E04740
55990	18975	41.272376999999999	41.290137000000001	47.842393999999999	47.830593999999998	пер. Клубный	0103000020E610000001000000050000005F97E13FDDA244407D2079E750EA47405F97E13FDDA244405E2C0C91D3EB4740062E8F3523A544405E2C0C91D3EB4740062E8F3523A544407D2079E750EA47405F97E13FDDA244407D2079E750EA4740
55988	27518	41.102434000000002	41.136606	47.831175000000002	47.809303	Московская	0103000020E61000000100000005000000CEFFAB8E1C8D444000C79E3D97E74740CEFFAB8E1C8D44405C2041F163EA4740FC372F4E7C9144405C2041F163EA4740FC372F4E7C91444000C79E3D97E74740CEFFAB8E1C8D444000C79E3D97E74740
56316	18724	40.891905000000001	40.901184000000001	47.629955000000002	47.622630999999998	 Казачья	0103000020E61000000100000005000000C7116BF129724440E63C635FB2CF4740C7116BF129724440D1798D5DA2D04740D8D64FFF59734440D1798D5DA2D04740D8D64FFF59734440E63C635FB2CF4740C7116BF129724440E63C635FB2CF4740
40433	18084	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	Рылеева	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
40431	18084	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	Комсомольская	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
40432	18084	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	Калинина	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
40043	18084	41.071119000000003	41.127352999999999	47.593234000000002	47.567912999999997	25 Октября	0103000020E61000000100000005000000E78F696D1A89444093FC885FB1C84740E78F696D1A89444009707A17EFCB47401406651A4D90444009707A17EFCB47401406651A4D90444093FC885FB1C84740E78F696D1A89444093FC885FB1C84740
56366	25535	41.262981000000003	41.295265999999998	47.638936000000001	47.625844000000001	Центральная	0103000020E61000000100000005000000153C855CA9A14440EC32FCA71BD04740153C855CA9A14440581EA4A7C8D1474074CFBA46CBA54440581EA4A7C8D1474074CFBA46CBA54440EC32FCA71BD04740153C855CA9A14440EC32FCA71BD04740
56101	19093	41.182949999999998	41.199002999999998	47.633975	47.618755999999998	Центральная	0103000020E61000000100000005000000CF66D5E76A974440151A886533CF4740CF66D5E76A974440A5BDC11726D14740276728EE78994440A5BDC11726D14740276728EE78994440151A886533CF4740CF66D5E76A974440151A886533CF4740
56325	19677	41.469054	41.481836999999999	47.782705999999997	47.772920999999997	Степная	0103000020E610000001000000050000006C0723F609BC444020B24813EFE247406C0723F609BC44400531D0B52FE447405A80B6D5ACBD44400531D0B52FE447405A80B6D5ACBD444020B24813EFE247406C0723F609BC444020B24813EFE24740
55628	19379	41.413097999999998	41.439346999999998	47.724114	47.709522	Центральная	0103000020E6100000010000000500000081053065E0B4444071E5EC9DD1DA474081053065E0B44440B2497EC4AFDC4740404CC2853CB84440B2497EC4AFDC4740404CC2853CB8444071E5EC9DD1DA474081053065E0B4444071E5EC9DD1DA4740
55992	19768	41.501204999999999	41.513027000000001	47.901311999999997	47.890625	Октябрьская	0103000020E61000000100000005000000BCCB457C27C044400000000000F24740BCCB457C27C0444005BF0D315EF34740857B65DEAAC1444005BF0D315EF34740857B65DEAAC144400000000000F24740BCCB457C27C044400000000000F24740
56253	27293	41.039937999999999	41.059243000000002	47.893495000000001	47.878812000000003	Береговая	0103000020E610000001000000050000000FEF39B01C8544408BAA5FE97CF047400FEF39B01C854440DC114E0B5EF247402BC24D4695874440DC114E0B5EF247402BC24D46958744408BAA5FE97CF047400FEF39B01C8544408BAA5FE97CF04740
39654	18630	41.141447999999997	41.155911000000003	47.585965999999999	47.576380999999998	Лесная	0103000020E61000000100000005000000D40AD3F71A924440948444DAC6C94740D40AD3F71A924440B24813EF00CB4740180B43E4F4934440B24813EF00CB4740180B43E4F4934440948444DAC6C94740D40AD3F71A924440948444DAC6C94740
55630	19017	41.32076	41.359127000000001	47.659896000000003	47.638286000000001	Парковая	0103000020E61000000100000005000000B7EEE6A90EA9444051BF0B5BB3D14740B7EEE6A90EA944407061DD7877D44740280EA0DFF7AD44407061DD7877D44740280EA0DFF7AD444051BF0B5BB3D14740B7EEE6A90EA9444051BF0B5BB3D14740
56213	19478	41.546084999999998	41.570663000000003	47.762396000000003	47.748722999999998	Широкая	0103000020E6100000010000000500000007EBFF1CE6C54440AA61BF27D6DF474007EBFF1CE6C54440F54C2F3196E14740C504357C0BC94440F54C2F3196E14740C504357C0BC94440AA61BF27D6DF474007EBFF1CE6C54440AA61BF27D6DF4740
55991	27686	41.670788999999999	41.686005999999999	47.809116000000003	47.801563000000002	Лазоревая	0103000020E610000001000000050000001EC2F869DCD544408257CB9D99E647401EC2F869DCD54440CE55F31C91E747400D6E6B0BCFD74440CE55F31C91E747400D6E6B0BCFD744408257CB9D99E647401EC2F869DCD544408257CB9D99E64740
55989	27365	41.059215999999999	41.072259000000003	47.818185999999997	47.810495000000003	Пушкина	0103000020E6100000010000000500000031B3CF63948744402849D74CBEE7474031B3CF6394874440C405A051BAE84740BCEB6CC83F894440C405A051BAE84740BCEB6CC83F8944402849D74CBEE7474031B3CF63948744402849D74CBEE74740
56128	27273	41.035240000000002	41.055326000000001	47.702682000000003	47.686653	Молодежная	0103000020E610000001000000050000006AC18BBE82844440A359D93EE4D747406AC18BBE8284444073BED87BF1D947402B4F20EC1487444073BED87BF1D947402B4F20EC14874440A359D93EE4D747406AC18BBE82844440A359D93EE4D74740
56195	24374	41.297978999999998	41.360698999999997	49.136369999999999	49.108463999999998	Заречная	0103000020E6100000010000000500000088F2052D24A644408C65FA25E28D484088F2052D24A64440E813799274914840965984622BAE4440E813799274914840965984622BAE44408C65FA25E28D484088F2052D24A644408C65FA25E28D4840
56036	25022	41.266160999999997	41.307375	48.801048000000002	48.783307000000001	Молодежная	0103000020E610000001000000050000003E3C4B9011A244402BDD5D67436448403E3C4B9011A244405B43A9BD88664840D34D621058A744405B43A9BD88664840D34D621058A744402BDD5D67436448403E3C4B9011A244402BDD5D6743644840
56164	24573	41.142831000000001	41.158721999999997	48.975434999999997	48.960867999999998	Центральная	0103000020E6100000010000000500000070ED444948924440EFE2FDB8FD7A484070ED444948924440D72FD80DDB7C4840EE93A30051944440D72FD80DDB7C4840EE93A30051944440EFE2FDB8FD7A484070ED444948924440EFE2FDB8FD7A4840
56165	25498	41.210025000000002	41.234997999999997	49.100648999999997	49.083044999999998	Заветная	0103000020E61000000100000005000000D42B6519E29A4440548CF337A18A4840D42B6519E29A444003B00111E28C48400D501A6A149E444003B00111E28C48400D501A6A149E4440548CF337A18A4840D42B6519E29A4440548CF337A18A4840
56039	25339	41.699157999999997	41.737425999999999	48.983749000000003	48.970993999999997	Школьная	0103000020E610000001000000050000004E5E64027ED944405D4E0988497C48404E5E64027ED94440823CBB7CEB7D48402C9CA4F963DE4440823CBB7CEB7D48402C9CA4F963DE44405D4E0988497C48404E5E64027ED944405D4E0988497C4840
55729	24590	41.258614999999999	41.312496000000003	49.021166999999998	49.004964999999999	Центральная	0103000020E61000000100000005000000A5A0DB4B1AA14440F44F70B1A2804840A5A0DB4B1AA144409160AA99B5824840BF1072DEFFA744409160AA99B5824840BF1072DEFFA74440F44F70B1A2804840A5A0DB4B1AA14440F44F70B1A2804840
56315	24774	41.145580000000002	41.169339999999998	48.862476999999998	48.832697000000003	Сергеевская	0103000020E61000000100000005000000D1798D5DA2924440193DB7D0956A4840D1798D5DA2924440AE4676A5656E4840CBF3E0EEAC954440AE4676A5656E4840CBF3E0EEAC954440193DB7D0956A4840D1798D5DA2924440193DB7D0956A4840
56306	24848	41.130065999999999	41.150575000000003	48.832917000000002	48.801077999999997	Школьная	0103000020E610000001000000050000002829B000A6904440C5C551B9896648402829B000A690444027A435069D6A4840304CA60A4693444027A435069D6A4840304CA60A46934440C5C551B9896648402829B000A6904440C5C551B989664840
56187	56819	41.014839000000002	41.063167999999997	49.239646999999998	49.178190000000001	Тихомировская	0103000020E6100000010000000500000049DA8D3EE6814440B43C0FEECE96484049DA8D3EE6814440D1CABDC0AC9E4840AD1397E315884440D1CABDC0AC9E4840AD1397E315884440B43C0FEECE96484049DA8D3EE6814440B43C0FEECE964840
32953	24257	41.20026	41.259486000000003	49.255578	49.230800000000002	Большая Садовая	0103000020E610000001000000050000003659A31EA29944405AF5B9DA8A9D48403659A31EA2994440DEC9A7C7B6A048408BE255D636A14440DEC9A7C7B6A048408BE255D636A144405AF5B9DA8A9D48403659A31EA29944405AF5B9DA8A9D4840
55673	25403	41.467841	41.508795999999997	49.066313999999998	49.048721	Центральная	0103000020E610000001000000050000002D5DC136E2BB444070D05E7D3C8648402D5DC136E2BB44402BA226FA7C884840F52A323A20C144402BA226FA7C884840F52A323A20C1444070D05E7D3C8648402D5DC136E2BB444070D05E7D3C864840
40256	24948	41.215423999999999	41.246811000000001	48.834831999999999	48.818277999999999	Мира	0103000020E6100000010000000500000002637D03939B4440A5846055BD68484002637D03939B4440BFD364C6DB6A484083A5BA80979F4440BFD364C6DB6A484083A5BA80979F4440A5846055BD68484002637D03939B4440A5846055BD684840
56193	24153	40.976238000000002	41.009053999999999	49.321032000000002	49.290793000000001	Лесная	0103000020E61000000100000005000000658EE55DF57C4440EF737CB438A54840658EE55DF57C4440187C9A9317A94840F1F274AE28814440187C9A9317A94840F1F274AE28814440EF737CB438A54840658EE55DF57C4440EF737CB438A54840
56342	23983	41.100879999999997	41.159754999999997	49.187846999999998	49.150148999999999	Набережная	0103000020E610000001000000050000000569C6A2E98C444078431A15389348400569C6A2E98C44406BD3D85E0B984840AD2F12DA729444406BD3D85E0B984840AD2F12DA7294444078431A15389348400569C6A2E98C444078431A1538934840
55609	23809	41.019699000000003	41.054572	49.125157000000002	49.094019000000003	Октябрьская	0103000020E61000000100000005000000C861307F85824440F01989D0088C4840C861307F85824440C8EE0225059048407FA31D37FC864440C8EE0225059048407FA31D37FC864440F01989D0088C4840C861307F85824440F01989D0088C4840
56304	52874	41.374173999999996	41.445042000000001	49.17548	49.154432	пер. Школьный	0103000020E61000000100000005000000BA8102EFE4AF44405ABA826DC4934840BA8102EFE4AF4440118DEE207696484058ACE122F7B84440118DEE207696484058ACE122F7B844405ABA826DC4934840BA8102EFE4AF44405ABA826DC4934840
56313	24958	41.443936999999998	41.461570999999999	48.967320999999998	48.959727000000001	Юбилейная	0103000020E61000000100000005000000FF3D78EDD2B844404A0B9755D87A4840FF3D78EDD2B84440F4DDAD2CD17B484019E42EC214BB4440F4DDAD2CD17B484019E42EC214BB44404A0B9755D87A4840FF3D78EDD2B844404A0B9755D87A4840
56161	23860	40.932850000000002	40.957652000000003	48.962229000000001	48.949888000000001	Школьная	0103000020E610000001000000050000006C09F9A067774440726E13EE957948406C09F9A067774440A321E3512A7B484079793A57947A4440A321E3512A7B484079793A57947A4440726E13EE957948406C09F9A067774440726E13EE95794840
56197	24700	41.093091000000001	41.130946000000002	48.938763999999999	48.930016999999999	Песчаная	0103000020E61000000100000005000000A646E867EA8B4440ADDC0BCC0A774840A646E867EA8B4440C154336B2978484061C5A9D6C2904440C154336B2978484061C5A9D6C2904440ADDC0BCC0A774840A646E867EA8B4440ADDC0BCC0A774840
55947	25408	41.122340000000001	41.141644999999997	49.054436000000003	49.043483000000002	Пушкинская	0103000020E610000001000000050000000F7F4DD6A88F44404B77D7D9908548400F7F4DD6A88F4440CFDC43C2F78648402A52616C21924440CFDC43C2F78648402A52616C219244404B77D7D9908548400F7F4DD6A88F44404B77D7D990854840
56341	25200	41.232618000000002	41.260052000000002	48.873471000000002	48.862377000000002	Центральная	0103000020E61000000100000005000000003B376DC69D44404BE9995E626E4840003B376DC69D44409180D1E5CD6F484034A1496249A144409180D1E5CD6F484034A1496249A144404BE9995E626E4840003B376DC69D44404BE9995E626E4840
39765	23589	40.970229000000003	41.052694000000002	49.071477999999999	49.016345999999999	Ленина	0103000020E61000000100000005000000BE50C076307C4440D0B52FA017824840BE50C076307C44401631EC302689484004594FADBE8644401631EC302689484004594FADBE864440D0B52FA017824840BE50C076307C4440D0B52FA017824840
40530	23589	40.970229000000003	41.052694000000002	49.071477999999999	49.016345999999999	Комсомольская	0103000020E61000000100000005000000BE50C076307C4440D0B52FA017824840BE50C076307C44401631EC302689484004594FADBE8644401631EC302689484004594FADBE864440D0B52FA017824840BE50C076307C4440D0B52FA017824840
41165	23589	40.970229000000003	41.052694000000002	49.071477999999999	49.016345999999999	Андреевская	0103000020E61000000100000005000000BE50C076307C4440D0B52FA017824840BE50C076307C44401631EC302689484004594FADBE8644401631EC302689484004594FADBE864440D0B52FA017824840BE50C076307C4440D0B52FA017824840
55610	23589	40.970229000000003	41.052694000000002	49.071477999999999	49.016345999999999	Адмиральская	0103000020E61000000100000005000000BE50C076307C4440D0B52FA017824840BE50C076307C44401631EC302689484004594FADBE8644401631EC302689484004594FADBE864440D0B52FA017824840BE50C076307C4440D0B52FA017824840
55616	24297	41.308731999999999	41.328333000000001	49.275883999999998	49.259687999999997	Центральная	0103000020E61000000100000005000000459DB98784A74440F294D5743DA14840459DB98784A74440ADBEBA2A50A348404A99D4D006AA4440ADBEBA2A50A348404A99D4D006AA4440F294D5743DA14840459DB98784A74440F294D5743DA14840
56037	25255	41.40813	41.444808999999999	48.971809999999998	48.957147999999997	Подтелковская	0103000020E610000001000000050000001C42959A3DB4444045B75ED3837A48401C42959A3DB444407FF62345647C4840B5FB5580EFB844407FF62345647C4840B5FB5580EFB8444045B75ED3837A48401C42959A3DB4444045B75ED3837A4840
55619	25054	41.156799999999997	41.194304000000002	48.738318999999997	48.711936000000001	Советская	0103000020E61000000100000005000000A301BC05129444402B6C06B8205B4840A301BC0512944440F981AB3C815E4840B2BD16F4DE984440F981AB3C815E4840B2BD16F4DE9844402B6C06B8205B4840A301BC05129444402B6C06B8205B4840
55614	24204	41.167427000000004	41.202264	49.218220000000002	49.199168999999998	Центральная	0103000020E61000000100000005000000D4BB783F6E95444042B0AA5E7E994840D4BB783F6E954440A4AA09A2EE9B48403E9468C9E3994440A4AA09A2EE9B48403E9468C9E399444042B0AA5E7E994840D4BB783F6E95444042B0AA5E7E994840
55669	24122	41.014659000000002	41.086227999999998	49.292473000000001	49.239888000000001	Центральная	0103000020E61000000100000005000000C9CB9A58E0814440F75965A6B49E4840C9CB9A58E081444044FB58C16FA54840EFFFE384098B444044FB58C16FA54840EFFFE384098B4440F75965A6B49E4840C9CB9A58E0814440F75965A6B49E4840
32960	24514	41.143047000000003	41.181125999999999	49.065269000000001	49.045827000000003	Победы	0103000020E610000001000000050000003D65355D4F9244400C23BDA8DD8548403D65355D4F924440A8380EBC5A884840473A03232F974440A8380EBC5A884840473A03232F9744400C23BDA8DD8548403D65355D4F9244400C23BDA8DD854840
56034	24679	41.133192000000001	41.146281000000002	48.912357	48.900543999999996	Молодежная	0103000020E610000001000000050000005F0B7A6F0C914440F44D9A06457348405F0B7A6F0C9144406AA33A1DC87448405A83F755B99244406AA33A1DC87448405A83F755B9924440F44D9A06457348405F0B7A6F0C914440F44D9A0645734840
55767	25283	41.555436	41.596066999999998	48.991416999999998	48.976098	Ленина	0103000020E61000000100000005000000B282DF8618C7444073D87DC7F07C4840B282DF8618C7444066D993C0E67E4840C79C67EC4BCC444066D993C0E67E4840C79C67EC4BCC444073D87DC7F07C4840B282DF8618C7444073D87DC7F07C4840
55615	23967	41.058219000000001	41.092480000000002	49.191409	49.153384000000003	Октябрьская	0103000020E61000000100000005000000BF805EB87387444066DD3F16A2934840BF805EB8738744407D941117809848405DC47762D68B44407D941117809848405DC47762D68B444066DD3F16A2934840BF805EB87387444066DD3F16A2934840
56033	23903	40.948534000000002	40.973695999999997	49.010466999999998	48.979787999999999	Центральная	0103000020E610000001000000050000007192E68F69794440B28174B1697D48407192E68F69794440F7578FFB568148407D1F0E12A27C4440F7578FFB568148407D1F0E12A27C4440B28174B1697D48407192E68F69794440B28174B1697D4840
56163	24389	41.345939999999999	41.391286999999998	49.153973000000001	49.138545000000001	Береговая	0103000020E610000001000000050000006A300DC347AC44401D03B2D7BB9148406A300DC347AC4440C7BB2363B5934840CB2C42B115B24440C7BB2363B5934840CB2C42B115B244401D03B2D7BB9148406A300DC347AC44401D03B2D7BB914840
56179	19591	40.480243000000002	40.496592	48.189737000000001	48.184505000000001	Железнодорожная	0103000020E610000001000000050000000491459A783D444068791EDC9D1748400491459A783D4440ABEB504D4918484045BA9F53903F4440ABEB504D4918484045BA9F53903F444068791EDC9D1748400491459A783D444068791EDC9D174840
41157	21571	40.420189999999998	40.441192999999998	48.267896	48.249654	Ленина	0103000020E61000000100000005000000990D32C9C835444065A88AA9F41F4840990D32C9C8354440575D876A4A224840B01C210379384440575D876A4A224840B01C21037938444065A88AA9F41F4840990D32C9C835444065A88AA9F41F4840
56506	56965	40.197938000000001	40.238542000000002	48.366045999999997	48.352407999999997	Набережная	0103000020E610000001000000050000005D514A0856194440A46C91B41B2D48405D514A0856194440726A6798DA2E4840795C548B881E4440726A6798DA2E4840795C548B881E4440A46C91B41B2D48405D514A0856194440A46C91B41B2D4840
55884	56737	40.228606999999997	40.257389000000003	48.564864	48.552348000000002	Российская	0103000020E610000001000000050000007E5182FE421D44406901DA56B34648407E5182FE421D44400858AB764D484840D2AC6C1FF22044400858AB764D484840D2AC6C1FF22044406901DA56B34648407E5182FE421D44406901DA56B3464840
56214	56823	39.941298000000003	39.986860999999998	48.471173999999998	48.462237000000002	Лесная	0103000020E6100000010000000500000026E5EE737CF843402600FF942A3B484026E5EE737CF84340DD5CFC6D4F3C48405359147651FE4340DD5CFC6D4F3C48405359147651FE43402600FF942A3B484026E5EE737CF843402600FF942A3B4840
55304	56630	40.271977	40.332253999999999	48.358611000000003	48.313588000000003	Садовая	0103000020E61000000100000005000000D1217024D02244408335CEA623284840D1217024D0224440317E1AF7E62D48408BFB8F4C872A4440317E1AF7E62D48408BFB8F4C872A44408335CEA623284840D1217024D02244408335CEA623284840
55274	56630	40.271977	40.332253999999999	48.358611000000003	48.313588000000003	 Театральная	0103000020E61000000100000005000000D1217024D02244408335CEA623284840D1217024D0224440317E1AF7E62D48408BFB8F4C872A4440317E1AF7E62D48408BFB8F4C872A44408335CEA623284840D1217024D02244408335CEA623284840
56454	56921	40.304999000000002	40.323962999999999	48.607078000000001	48.589863999999999	Степная	0103000020E6100000010000000500000007280D350A2744403B8BDEA9804B484007280D350A274440800F5EBBB44D4840990E9D9E77294440800F5EBBB44D4840990E9D9E772944403B8BDEA9804B484007280D350A2744403B8BDEA9804B4840
56502	56961	40.062463000000001	40.076666000000003	48.171424999999999	48.154573999999997	Центральная	0103000020E61000000100000005000000E31A9FC9FE074440EC67B114C9134840E31A9FC9FE074440C05B2041F11548408A5B0531D0094440C05B2041F11548408A5B0531D0094440EC67B114C9134840E31A9FC9FE074440EC67B114C9134840
55545	56671	40.575284000000003	40.615430000000003	48.420667000000002	48.392454999999998	Колхозная	0103000020E61000000100000005000000BFF4F6E7A24944406A1327F73B324840BFF4F6E7A2494440D3C08F6AD8354840187D0569C64E4440D3C08F6AD8354840187D0569C64E44406A1327F73B324840BFF4F6E7A24944406A1327F73B324840
56035	56804	40.280799000000002	40.305025999999998	48.245874999999998	48.239376	Народная	0103000020E61000000100000005000000F0DFBC38F123444041B96DDFA31E4840F0DFBC38F1234440B6F3FDD4781F484000378B170B274440B6F3FDD4781F484000378B170B27444041B96DDFA31E4840F0DFBC38F123444041B96DDFA31E4840
55896	56749	40.543897000000001	40.569544	48.566397000000002	48.527042999999999	Московская	0103000020E610000001000000050000003EB2B96A9E454440F94A2025764348403EB2B96A9E454440B9C667B27F48484007D15AD1E6484440B9C667B27F48484007D15AD1E6484440F94A2025764348403EB2B96A9E454440F94A202576434840
56162	56818	40.564315999999998	40.583342000000002	48.263463999999999	48.255420000000001	Платова	0103000020E61000000100000005000000054EB6813B484440465F419AB1204840054EB6813B48444030D63730B92148400E315EF3AA4A444030D63730B92148400E315EF3AA4A4440465F419AB1204840054EB6813B484440465F419AB1204840
56563	57015	40.481707	40.507452999999998	48.403587000000002	48.373013	Молодежная	0103000020E610000001000000050000008CA03193A83D4440CEFDD5E3BE2F48408CA03193A83D44409E0B23BDA8334840E8A04B38F44044409E0B23BDA8334840E8A04B38F4404440CEFDD5E3BE2F48408CA03193A83D4440CEFDD5E3BE2F4840
56555	57007	40.331194000000004	40.350983999999997	48.291232999999998	48.279476000000003	Щаденко	0103000020E61000000100000005000000D350A390642A44402A029CDEC5234840D350A390642A44400B42791F47254840AAB5300BED2C44400B42791F47254840AAB5300BED2C44402A029CDEC5234840D350A390642A44402A029CDEC5234840
56031	21497	40.302717999999999	40.309922	48.455689	48.451076	Достоевского	0103000020E610000001000000050000008CF4A276BF2644405801BEDBBC3948408CF4A276BF264440CF126404543A4840CC272B86AB274440CF126404543A4840CC272B86AB2744405801BEDBBC3948408CF4A276BF2644405801BEDBBC394840
56518	56976	39.986879000000002	40.016784000000001	48.382348999999998	48.371223000000001	Донская	0103000020E61000000100000005000000FA0D130D52FE4340F2423A3C842F4840FA0D130D52FE43404354E1CFF03048404C8C65FA250244404354E1CFF03048404C8C65FA25024440F2423A3C842F4840FA0D130D52FE4340F2423A3C842F4840
55293	56640	40.245683999999997	40.279046999999998	48.422724000000002	48.399275000000003	Советская	0103000020E610000001000000050000004293C492721F4440228E75711B3348404293C492721F4440FE9DEDD11B3648400186E5CFB7234440FE9DEDD11B3648400186E5CFB7234440228E75711B3348404293C492721F4440228E75711B334840
55286	56637	40.136439000000003	40.182127999999999	48.336683000000001	48.314864999999998	Карла Маркса площадь	0103000020E61000000100000005000000117349D576114440D8D30E7F4D284840117349D576114440410FB56D182B4840CBD765F84F174440410FB56D182B4840CBD765F84F174440D8D30E7F4D284840117349D576114440D8D30E7F4D284840
55929	23420	40.318187000000002	40.328733	48.320022999999999	48.313870000000001	Королева	0103000020E610000001000000050000009581035ABA284440079964E42C2848409581035ABA284440E17B7F83F6284840D80E46EC132A4440E17B7F83F6284840D80E46EC132A4440079964E42C2848409581035ABA284440079964E42C284840
55552	56659	40.243068999999998	40.266911	48.38476	48.362119	Профильная	0103000020E61000000100000005000000F1D58EE21C1F44404F2157EA592E4840F1D58EE21C1F44408C67D0D03F314840A9F8BF232A2244408C67D0D03F314840A9F8BF232A2244404F2157EA592E4840F1D58EE21C1F44404F2157EA592E4840
55363	56659	40.243068999999998	40.266911	48.38476	48.362119	Октябрьская	0103000020E61000000100000005000000F1D58EE21C1F44404F2157EA592E4840F1D58EE21C1F44408C67D0D03F314840A9F8BF232A2244408C67D0D03F314840A9F8BF232A2244404F2157EA592E4840F1D58EE21C1F44404F2157EA592E4840
55932	56659	40.243068999999998	40.266911	48.38476	48.362119	Матросова	0103000020E61000000100000005000000F1D58EE21C1F44404F2157EA592E4840F1D58EE21C1F44408C67D0D03F314840A9F8BF232A2244408C67D0D03F314840A9F8BF232A2244404F2157EA592E4840F1D58EE21C1F44404F2157EA592E4840
56571	57021	40.130015999999998	40.15128	48.490715999999999	48.481363999999999	Победы	0103000020E6100000010000000500000076FA415DA410444062BCE6559D3D484076FA415DA4104440DDCF29C8CF3E4840FA449E245D134440DDCF29C8CF3E4840FA449E245D13444062BCE6559D3D484076FA415DA410444062BCE6559D3D4840
55728	22166	40.346043000000002	40.386459000000002	48.537166999999997	48.514833000000003	Спортивная	0103000020E610000001000000050000003F0114234B2C444067F3380CE64148403F0114234B2C4440C6BE64E3C1444840581F0F7D77314440C6BE64E3C1444840581F0F7D7731444067F3380CE64148403F0114234B2C444067F3380CE6414840
40129	22499	40.521062000000001	40.540106000000002	48.297682999999999	48.281395000000003	Калинина	0103000020E610000001000000050000001C98DC28B2424440042159C0042448401C98DC28B24244409FC9FE791A264840CB2F8331224544409FC9FE791A264840CB2F833122454440042159C0042448401C98DC28B2424440042159C004244840
56413	56885	40.351433	40.395397000000003	48.303353000000001	48.293126999999998	Левитана переулок	0103000020E610000001000000050000001ADEACC1FB2C44408C497F2F852548401ADEACC1FB2C44405E126745D4264840E0F76F5E9C3244405E126745D4264840E0F76F5E9C3244408C497F2F852548401ADEACC1FB2C44408C497F2F85254840
56347	56846	40.805235000000003	40.824091000000003	48.503253000000001	48.490673999999999	Школьный	0103000020E610000001000000050000001B4CC3F011674440AE7FD767CE3E48401B4CC3F011674440944E24986A404840C7F65AD07B694440944E24986A404840C7F65AD07B694440AE7FD767CE3E48401B4CC3F011674440AE7FD767CE3E4840
55923	56775	40.483566000000003	40.516984000000001	48.454326000000002	48.430706000000001	Центральная	0103000020E6100000010000000500000091BA9D7DE53D44407218CC5F2137484091BA9D7DE53D44407BDCB75A273A484013471E882C4244407BDCB75A273A484013471E882C4244407218CC5F2137484091BA9D7DE53D44407218CC5F21374840
55883	56736	40.640492999999999	40.705531000000001	48.494596999999999	48.447662999999999	Школьная	0103000020E610000001000000050000009128B4ACFB5144408B506C054D3948409128B4ACFB51444090D959F44E3F484037A8FDD64E5A444090D959F44E3F484037A8FDD64E5A44408B506C054D3948409128B4ACFB5144408B506C054D394840
40082	21884	39.845771999999997	40.861460999999998	48.639951000000003	48.097757000000001	Юбилейная	0103000020E61000000100000005000000AEEFC34142EC434040FA264D830C4840AEEFC34142EC4340710514EAE9514840C5E3A25A446E4440710514EAE9514840C5E3A25A446E444040FA264D830C4840AEEFC34142EC434040FA264D830C4840
41162	21884	39.845771999999997	40.861460999999998	48.639951000000003	48.097757000000001	Фрунзе	0103000020E61000000100000005000000AEEFC34142EC434040FA264D830C4840AEEFC34142EC4340710514EAE9514840C5E3A25A446E4440710514EAE9514840C5E3A25A446E444040FA264D830C4840AEEFC34142EC434040FA264D830C4840
40254	21884	39.845771999999997	40.861460999999998	48.639951000000003	48.097757000000001	Ленина	0103000020E61000000100000005000000AEEFC34142EC434040FA264D830C4840AEEFC34142EC4340710514EAE9514840C5E3A25A446E4440710514EAE9514840C5E3A25A446E444040FA264D830C4840AEEFC34142EC434040FA264D830C4840
41159	21884	39.845771999999997	40.861460999999998	48.639951000000003	48.097757000000001	К.Маркса	0103000020E61000000100000005000000AEEFC34142EC434040FA264D830C4840AEEFC34142EC4340710514EAE9514840C5E3A25A446E4440710514EAE9514840C5E3A25A446E444040FA264D830C4840AEEFC34142EC434040FA264D830C4840
40081	21884	39.845771999999997	40.861460999999998	48.639951000000003	48.097757000000001	Вокзальная	0103000020E61000000100000005000000AEEFC34142EC434040FA264D830C4840AEEFC34142EC4340710514EAE9514840C5E3A25A446E4440710514EAE9514840C5E3A25A446E444040FA264D830C4840AEEFC34142EC434040FA264D830C4840
55887	56740	40.110621999999999	40.133628000000002	48.266084999999997	48.221136000000001	Молодежная	0103000020E61000000100000005000000EB1B98DC280E4440F0FB372F4E1C4840EB1B98DC280E4440637AC2120F2248403AEAE8B81A114440637AC2120F2248403AEAE8B81A114440F0FB372F4E1C4840EB1B98DC280E4440F0FB372F4E1C4840
55867	56724	40.064591999999998	40.095098999999998	48.402146000000002	48.370193999999998	Набережная	0103000020E61000000100000005000000A7CAF78C4408444074965984622F4840A7CAF78C44084440CE1B278579334840EF703B342C0C4440CE1B278579334840EF703B342C0C444074965984622F4840A7CAF78C4408444074965984622F4840
55300	56644	40.308852999999999	40.334401	48.573884	48.546765000000001	Центральная	0103000020E61000000100000005000000C022BF7E8827444079CC4065FC454840C022BF7E882744404DD9E90775494840F65FE7A6CD2A44404DD9E90775494840F65FE7A6CD2A444079CC4065FC454840C022BF7E8827444079CC4065FC454840
56519	56977	39.966047000000003	40.013074000000003	48.510666999999998	48.490786999999997	Молодежная	0103000020E6100000010000000500000010B3976DA7FB4340A626C11BD23E484010B3976DA7FB4340BE1248895D414840C636A968AC014440BE1248895D414840C636A968AC014440A626C11BD23E484010B3976DA7FB4340A626C11BD23E4840
56542	56992	40.546214999999997	40.559545999999997	48.224606000000001	48.204642999999997	Центральная	0103000020E61000000100000005000000D5CA845FEA4544407B2DE8BD311A4840D5CA845FEA454440213EB0E3BF1C4840C64D0D349F474440213EB0E3BF1C4840C64D0D349F4744407B2DE8BD311A4840D5CA845FEA4544407B2DE8BD311A4840
56171	22876	40.554057	40.5717	48.187694999999998	48.176291999999997	Школьная	0103000020E61000000100000005000000588FFB56EB464440F1457BBC90164840588FFB56EB464440B54FC76306184840C58F31772D494440B54FC76306184840C58F31772D494440F1457BBC90164840588FFB56EB464440F1457BBC90164840
56191	56820	40.119165000000002	40.156086000000002	48.224317999999997	48.192776000000002	Станичная	0103000020E61000000100000005000000F7E978CC400F444013BA4BE2AC184840F7E978CC400F4440BAF3C473B61C484086AE44A0FA134440BAF3C473B61C484086AE44A0FA13444013BA4BE2AC184840F7E978CC400F444013BA4BE2AC184840
56522	56980	40.270657	40.309697999999997	48.476598000000003	48.446086000000001	Советская	0103000020E610000001000000050000007CB779E3A42244400B9A9658193948407CB779E3A422444065ABCB29013D48407CD11E2FA427444065ABCB29013D48407CD11E2FA42744400B9A9658193948407CB779E3A42244400B9A965819394840
56397	56869	39.970466999999999	39.996689000000003	48.184294000000001	48.158473999999998	Мира	0103000020E61000000100000005000000726C3D4338FC434016A243E048144840726C3D4338FC4340AD6C1FF29617484038A4518193FF4340AD6C1FF29617484038A4518193FF434016A243E048144840726C3D4338FC434016A243E048144840
56523	56981	40.324663000000001	40.349843	48.302388000000001	48.292017999999999	Набережная	0103000020E61000000100000005000000529CA38E8E294440F2EB87D860254840529CA38E8E294440F75965A6B426484005DEC9A7C72C4440F75965A6B426484005DEC9A7C72C4440F2EB87D860254840529CA38E8E294440F2EB87D860254840
55741	10344	40.056103	40.076512999999998	47.051552000000001	47.038871999999998	Школьная	0103000020E610000001000000050000008F1A13622E074440745DF8C1F98447408F1A13622E0744408E05854199864740035C902DCB0944408E05854199864740035C902DCB094440745DF8C1F98447408F1A13622E074440745DF8C1F9844740
56380	56854	39.994810999999999	40.018706000000002	46.878098000000001	46.872326000000001	Солнечная	0103000020E61000000100000005000000BC5983F755FF4340AAB9DC60A86F4740BC5983F755FF43406D57E88365704740971E4DF5640244406D57E88365704740971E4DF564024440AAB9DC60A86F4740BC5983F755FF4340AAB9DC60A86F4740
56120	9584	40.138865000000003	40.153013000000001	46.808256	46.802087	Парковая	0103000020E610000001000000050000008FC70C54C6114440FCC56CC9AA6647408FC70C54C6114440DC65BFEE74674740726E13EE95134440DC65BFEE74674740726E13EE95134440FCC56CC9AA6647408FC70C54C6114440FCC56CC9AA664740
56503	56962	40.197139	40.243977000000001	46.971257000000001	46.947603000000001	Школьная	0103000020E6100000010000000500000011E2CAD93B194440B64B1B0E4B79474011E2CAD93B1944406B813D26527C4740F4FC69A33A1F44406B813D26527C4740F4FC69A33A1F4440B64B1B0E4B79474011E2CAD93B194440B64B1B0E4B794740
56430	56900	40.349195999999999	40.380133999999998	47.007807	46.997987000000002	Школьная	0103000020E610000001000000050000006FF25B74B22C4440A56ABB09BE7F47406FF25B74B22C444006D7DCD1FF804740800C1D3BA830444006D7DCD1FF804740800C1D3BA8304440A56ABB09BE7F47406FF25B74B22C4440A56ABB09BE7F4740
56468	56931	40.132074000000003	40.173836000000001	47.108902999999998	47.094126000000003	Степная	0103000020E61000000100000005000000725303CDE710444006DA1D520C8C4740725303CDE7104440D8B79388F08D4740096F0F4240164440D8B79388F08D4740096F0F424016444006DA1D520C8C4740725303CDE710444006DA1D520C8C4740
55983	10104	39.914565000000003	39.932423	46.969363000000001	46.965384999999998	Климова	0103000020E610000001000000050000007B88467710F54340448655BC917B47407B88467710F54340EA793716147C4740E48409A359F74340EA793716147C4740E48409A359F74340448655BC917B47407B88467710F54340448655BC917B4740
56207	30647	39.958618000000001	39.976764000000003	47.121473999999999	47.115416000000003	Садовая	0103000020E61000000100000005000000B0AD9FFEB3FA4340B3B794F3C58E4740B0AD9FFEB3FA43403BA8C4758C8F474080F44D9A06FD43403BA8C4758C8F474080F44D9A06FD4340B3B794F3C58E4740B0AD9FFEB3FA4340B3B794F3C58E4740
39871	9888	39.761465000000001	39.807116999999998	46.908445	46.883955999999998	Ленина	0103000020E610000001000000050000003A0664AF77E143402E8D5F78257147403A0664AF77E143407C9BFEEC47744740D7851F9C4FE743407C9BFEEC47744740D7851F9C4FE743402E8D5F78257147403A0664AF77E143402E8D5F7825714740
55819	9888	39.761465000000001	39.807116999999998	46.908445	46.883955999999998	Красная	0103000020E610000001000000050000003A0664AF77E143402E8D5F78257147403A0664AF77E143407C9BFEEC47744740D7851F9C4FE743407C9BFEEC47744740D7851F9C4FE743402E8D5F78257147403A0664AF77E143402E8D5F7825714740
55845	56703	39.985999	40.031928999999998	46.968933	46.962173999999997	Луговая	0103000020E61000000100000005000000C171193735FE4340DF878384287B4740C171193735FE4340F1811DFF057C4740A165DD3F16044440F1811DFF057C4740A165DD3F16044440DF878384287B4740C171193735FE4340DF878384287B4740
40321	10195	39.834192000000002	39.853352999999998	47.046799999999998	47.039209999999997	40 Лет Победы	0103000020E61000000100000005000000DC4AAFCDC6EA43408CD651D504854740DC4AAFCDC6EA4340F5B9DA8AFD854740C478CDAB3AED4340F5B9DA8AFD854740C478CDAB3AED43408CD651D504854740DC4AAFCDC6EA43408CD651D504854740
56378	30763	39.839016000000001	39.856740000000002	46.995528	46.991176000000003	Светлая	0103000020E610000001000000050000000E6954E064EB4340414AECDADE7E47400E6954E064EB43404B2025766D7F4740689604A8A9ED43404B2025766D7F4740689604A8A9ED4340414AECDADE7E47400E6954E064EB4340414AECDADE7E4740
56302	9404	40.177537000000001	40.186646000000003	46.907386000000002	46.901463	Юбилейная	0103000020E610000001000000050000003C6A4C88B9164440EBC6BB23637347403C6A4C88B9164440946C753925744740F1F62004E4174440946C753925744740F1F62004E4174440EBC6BB23637347403C6A4C88B9164440EBC6BB2363734740
56243	10677	40.175865999999999	40.198774	46.952702000000002	46.940823000000002	Пионерская	0103000020E610000001000000050000003A3DEFC6821644408D2958E36C7847403A3DEFC682164440BA6A9E23F2794740C6A52A6D71194440BA6A9E23F2794740C6A52A6D711944408D2958E36C7847403A3DEFC6821644408D2958E36C784740
56371	9579	39.985190000000003	39.990642999999999	46.812758000000002	46.809465000000003	Школьная	0103000020E61000000100000005000000522CB7B41AFE4340DA20938C9C674740522CB7B41AFE4340FCC74274086847407381CB63CDFE4340FCC74274086847407381CB63CDFE4340DA20938C9C674740522CB7B41AFE4340DA20938C9C674740
55338	52110	40.027653000000001	40.076251999999997	46.992744000000002	46.965895000000003	Школьная	0103000020E6100000010000000500000072512D228A0344405A2F8672A27B474072512D228A0344406EA6423C127F4740962023A0C20944406EA6423C127F4740962023A0C20944405A2F8672A27B474072512D228A0344405A2F8672A27B4740
55318	52110	40.027653000000001	40.076251999999997	46.992744000000002	46.965895000000003	Московская	0103000020E6100000010000000500000072512D228A0344405A2F8672A27B474072512D228A0344406EA6423C127F4740962023A0C20944406EA6423C127F4740962023A0C20944405A2F8672A27B474072512D228A0344405A2F8672A27B4740
55844	52110	40.027653000000001	40.076251999999997	46.992744000000002	46.965895000000003	Ленина	0103000020E6100000010000000500000072512D228A0344405A2F8672A27B474072512D228A0344406EA6423C127F4740962023A0C20944406EA6423C127F4740962023A0C20944405A2F8672A27B474072512D228A0344405A2F8672A27B4740
55276	52110	40.027653000000001	40.076251999999997	46.992744000000002	46.965895000000003	Гагарина	0103000020E6100000010000000500000072512D228A0344405A2F8672A27B474072512D228A0344406EA6423C127F4740962023A0C20944406EA6423C127F4740962023A0C20944405A2F8672A27B474072512D228A0344405A2F8672A27B4740
56246	56832	40.258125	40.270862999999999	47.049022000000001	47.028744000000003	Казачья	0103000020E61000000100000005000000D7A3703D0A21444066FA25E2AD834740D7A3703D0A2144406B64575A46864740255987A3AB2244406B64575A46864740255987A3AB22444066FA25E2AD834740D7A3703D0A21444066FA25E2AD834740
56551	57003	40.201585000000001	40.214709999999997	46.929611999999999	46.919333999999999	Трудовая	0103000020E610000001000000050000009D2E8B89CD194440E90C8CBCAC7547409D2E8B89CD1944400DFCA886FD764740E40F069E7B1B44400DFCA886FD764740E40F069E7B1B4440E90C8CBCAC7547409D2E8B89CD194440E90C8CBCAC754740
55791	9217	40.134472000000002	40.183914999999999	46.904522999999998	46.869824999999999	пер. Комсомольский	0103000020E61000000100000005000000261DE56036114440211FF46C566F4740261DE560361144406ABDDF68C7734740361FD7868A1744406ABDDF68C7734740361FD7868A174440211FF46C566F4740261DE56036114440211FF46C566F4740
55509	9217	40.134472000000002	40.183914999999999	46.904522999999998	46.869824999999999	Привокзальная	0103000020E61000000100000005000000261DE56036114440211FF46C566F4740261DE560361144406ABDDF68C7734740361FD7868A1744406ABDDF68C7734740361FD7868A174440211FF46C566F4740261DE56036114440211FF46C566F4740
55508	9217	40.134472000000002	40.183914999999999	46.904522999999998	46.869824999999999	Почтовая	0103000020E61000000100000005000000261DE56036114440211FF46C566F4740261DE560361144406ABDDF68C7734740361FD7868A1744406ABDDF68C7734740361FD7868A174440211FF46C566F4740261DE56036114440211FF46C566F4740
39804	9217	40.134472000000002	40.183914999999999	46.904522999999998	46.869824999999999	Кольцовский переулок	0103000020E61000000100000005000000261DE56036114440211FF46C566F4740261DE560361144406ABDDF68C7734740361FD7868A1744406ABDDF68C7734740361FD7868A174440211FF46C566F4740261DE56036114440211FF46C566F4740
40149	9217	40.134472000000002	40.183914999999999	46.904522999999998	46.869824999999999	Калинина	0103000020E61000000100000005000000261DE56036114440211FF46C566F4740261DE560361144406ABDDF68C7734740361FD7868A1744406ABDDF68C7734740361FD7868A174440211FF46C566F4740261DE56036114440211FF46C566F4740
55485	9217	40.134472000000002	40.183914999999999	46.904522999999998	46.869824999999999	Горького	0103000020E61000000100000005000000261DE56036114440211FF46C566F4740261DE560361144406ABDDF68C7734740361FD7868A1744406ABDDF68C7734740361FD7868A174440211FF46C566F4740261DE56036114440211FF46C566F4740
56374	9725	39.908850999999999	39.920952	46.883124000000002	46.870914999999997	Красноармейская	0103000020E61000000100000005000000ECF7C43A55F44340444C89247A6F4740ECF7C43A55F4434007280D350A714740C89750C1E1F5434007280D350A714740C89750C1E1F54340444C89247A6F4740ECF7C43A55F44340444C89247A6F4740
56572	57018	40.213281000000002	40.250382000000002	47.110455000000002	47.083696000000003	Школьная	0103000020E61000000100000005000000D9EDB3CA4C1B44402C67EF8CB68A4740D9EDB3CA4C1B44400057B263238E4740E8C072840C2044400057B263238E4740E8C072840C2044402C67EF8CB68A4740D9EDB3CA4C1B44402C67EF8CB68A4740
55860	56717	40.289656000000001	40.338892999999999	47.004575000000003	46.993543000000003	Ленина	0103000020E610000001000000050000008B8BA37213254440BA15C26A2C7F47408B8BA372132544408AB0E1E995804740F2EB87D8602B44408AB0E1E995804740F2EB87D8602B4440BA15C26A2C7F47408B8BA37213254440BA15C26A2C7F4740
55806	9485	40.048234000000001	40.067259999999997	46.856676	46.842396000000001	Советская	0103000020E6100000010000000500000013471E882C064440FF23D3A1D36B474013471E882C06444051A2258FA76D47401B2AC6F99B08444051A2258FA76D47401B2AC6F99B084440FF23D3A1D36B474013471E882C064440FF23D3A1D36B4740
55739	9485	40.048234000000001	40.067259999999997	46.856676	46.842396000000001	Первомайская	0103000020E6100000010000000500000013471E882C064440FF23D3A1D36B474013471E882C06444051A2258FA76D47401B2AC6F99B08444051A2258FA76D47401B2AC6F99B084440FF23D3A1D36B474013471E882C064440FF23D3A1D36B4740
56132	30774	40.142611000000002	40.151944	46.970807999999998	46.963391999999999	Кленовая	0103000020E610000001000000050000006286C61341124440309DD66D507B47406286C61341124440FB58C16F437C47406669A7E672134440FB58C16F437C47406669A7E672134440309DD66D507B47406286C61341124440309DD66D507B4740
55596	10254	39.767403000000002	39.782961	46.951723999999999	46.946384999999999	Школьная	0103000020E6100000010000000500000018EDF1423AE243406536C8242379474018EDF1423AE24340BE688F17D27947409085E81038E44340BE688F17D27947409085E81038E443406536C8242379474018EDF1423AE243406536C82423794740
40014	9742	39.952770000000001	39.965544000000001	46.872571999999998	46.863897999999999	Жукова	0103000020E61000000100000005000000124E0B5EF4F94340378AAC35946E4740124E0B5EF4F94340E1B37570B06F4740AD6C1FF296FB4340E1B37570B06F4740AD6C1FF296FB4340378AAC35946E4740124E0B5EF4F94340378AAC35946E4740
55980	12209	39.974392000000002	39.984003999999999	47.036956000000004	47.031213000000001	Бирюкова	0103000020E61000000100000005000000F5BD86E0B8FC4340E31A9FC9FE834740F5BD86E0B8FC43400CB265F9BA8447400C91D3D7F3FD43400CB265F9BA8447400C91D3D7F3FD4340E31A9FC9FE834740F5BD86E0B8FC4340E31A9FC9FE834740
55918	56770	42.970283000000002	42.999324999999999	46.877833000000003	46.843536	Стадионная	0103000020E61000000100000005000000B16EBC3B327C4540D47FD6FCF86B4740B16EBC3B327C4540BF2CEDD45C704740A089B0E1E97F4540BF2CEDD45C704740A089B0E1E97F4540D47FD6FCF86B4740B16EBC3B327C4540D47FD6FCF86B4740
56448	56915	42.088163999999999	42.103966	47.146245999999998	47.118445000000001	Клубный переулок	0103000020E610000001000000050000009F573CF5480B4540F7AFAC34298F47409F573CF5480B4540DD955D30B8924740AEF204C24E0D4540DD955D30B8924740AEF204C24E0D4540F7AFAC34298F47409F573CF5480B4540F7AFAC34298F4740
55514	1923	42.780647999999999	42.817712999999998	46.764902999999997	46.750123000000002	Кирова	0103000020E610000001000000050000000AD80E46EC6345401C7DCC07046047400AD80E46EC6345405FCE6C57E8614740CC41D0D1AA6845405FCE6C57E8614740CC41D0D1AA6845401C7DCC07046047400AD80E46EC6345401C7DCC0704604740
56543	56996	42.599854000000001	42.619374000000001	46.936940999999997	46.929144000000001	Зелёный	0103000020E61000000100000005000000F92F1004C84C454027A3CA30EE764740F92F1004C84C454009A4C4AEED77474011FFB0A5474F454009A4C4AEED77474011FFB0A5474F454027A3CA30EE764740F92F1004C84C454027A3CA30EE764740
55888	56741	42.838921999999997	42.858415999999998	47.050846	47.029161999999999	Мира	0103000020E610000001000000050000008CF2CCCB616B45409A249694BB8347408CF2CCCB616B4540F390291F828647407B2E5393E06D4540F390291F828647407B2E5393E06D45409A249694BB8347408CF2CCCB616B45409A249694BB834740
56576	57020	42.448388999999999	42.474943000000003	47.059643999999999	47.041463	Школьная	0103000020E610000001000000050000006D718DCF643945403D7FDAA84E8547406D718DCF6439454089B3226AA2874740693BA6EECA3C454089B3226AA2874740693BA6EECA3C45403D7FDAA84E8547406D718DCF643945403D7FDAA84E854740
55582	1860	42.739711999999997	42.774306000000003	46.888444999999997	46.872011999999998	Центральная	0103000020E61000000100000005000000B83A00E2AE5E45401ADCD6169E6F4740B83A00E2AE5E4540B9A5D590B87147405D8C81751C634540B9A5D590B87147405D8C81751C6345401ADCD6169E6F4740B83A00E2AE5E45401ADCD6169E6F4740
56498	56958	42.597563000000001	42.606527999999997	47.077345000000001	47.063032	Победы	0103000020E610000001000000050000005B26C3F17C4C4540FD4CBD6E118847405B26C3F17C4C45402BC1E270E6894740DC0DA2B5A24D45402BC1E270E6894740DC0DA2B5A24D4540FD4CBD6E118847405B26C3F17C4C4540FD4CBD6E11884740
56398	56870	42.484276000000001	42.505944	47.239871999999998	47.225444000000003	Центральный	0103000020E610000001000000050000006D1E87C1FC3D45402B8A5759DB9C47406D1E87C1FC3D4540F19C2D20B49E4740C0CDE2C5C2404540F19C2D20B49E4740C0CDE2C5C24045402B8A5759DB9C47406D1E87C1FC3D45402B8A5759DB9C4740
56474	56937	42.450553999999997	42.468628000000002	47.109448999999998	47.086322000000003	Мира	0103000020E610000001000000050000007E8AE3C0AB39454071766B990C8B47407E8AE3C0AB3945403ACAC16C028E4740B5FE9600FC3B45403ACAC16C028E4740B5FE9600FC3B454071766B990C8B47407E8AE3C0AB39454071766B990C8B4740
56281	56839	42.366345000000003	42.384473	47.135703999999997	47.125877000000003	Макарчука	0103000020E61000000100000005000000CD069964E42E4540C828CFBC1C904740CD069964E42E4540DBF7A8BF5E914740F698486936314540DBF7A8BF5E914740F698486936314540C828CFBC1C904740CD069964E42E4540C828CFBC1C904740
40213	1112	42.122300000000003	42.144236999999997	47.247273999999997	47.227530999999999	Школьный	0103000020E610000001000000050000008126C286A70F4540C0E95DBC1F9D47408126C286A70F45405793A7ACA69F4740C3EFA65B761245405793A7ACA69F4740C3EFA65B76124540C0E95DBC1F9D47408126C286A70F4540C0E95DBC1F9D4740
55823	1692	43.088312000000002	43.113940999999997	46.753852000000002	46.742935000000003	Школьная	0103000020E6100000010000000500000014ECBFCE4D8B4540E2067C7E185F474014ECBFCE4D8B45401903EB387E6047403656629E958E45401903EB387E6047403656629E958E4540E2067C7E185F474014ECBFCE4D8B4540E2067C7E185F4740
55339	56653	42.503248999999997	42.535156999999998	46.900145000000002	46.877623999999997	Мира	0103000020E61000000100000005000000525F96766A404540A417B5FB55704740525F96766A40454037548CF337734740DC9C4A068044454037548CF337734740DC9C4A0680444540A417B5FB55704740525F96766A404540A417B5FB55704740
14469	42353	42.678958999999999	42.705117999999999	47.145755999999999	47.132283000000001	Лодянова	0103000020E610000001000000050000009529E620E85645408C683BA6EE9047409529E620E85645400F99F221A892474014E97E4E415A45400F99F221A892474014E97E4E415A45408C683BA6EE9047409529E620E85645408C683BA6EE904740
40045	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Сиреневая	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
41064	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Пушкина	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
40047	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Малый	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
55820	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Магистральная	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
39927	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Круглякова	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
41058	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Игнатовский	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
40048	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Дружбы	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
40127	81	42.432164999999998	42.494706000000001	47.181351999999997	47.120590999999997	Дзержинского	0103000020E61000000100000005000000E8BCC62E513745409198A0866F8F4740E8BCC62E513745403788D68A369747404791B586523F45403788D68A369747404791B586523F45409198A0866F8F4740E8BCC62E513745409198A0866F8F4740
55940	56789	42.773327000000002	42.815575000000003	47.020432999999997	46.997753000000003	Садовая	0103000020E61000000100000005000000910E0F61FC624540323ECC5EB67F4740910E0F61FC6245402C616D8C9D824740B537F8C2646845402C616D8C9D824740B537F8C264684540323ECC5EB67F4740910E0F61FC624540323ECC5EB67F4740
39952	54835	42.592694000000002	42.614190999999998	47.288913999999998	47.273980000000002	Деревенского	0103000020E610000001000000050000008944A165DD4B454009E1D1C611A347408944A165DD4B4540A3AD4A22FBA44740AF3F89CF9D4E4540A3AD4A22FBA44740AF3F89CF9D4E454009E1D1C611A347408944A165DD4B454009E1D1C611A34740
56476	56939	42.398155000000003	42.420900000000003	47.374701999999999	47.359730999999996	Школьная	0103000020E6100000010000000500000094DE37BEF6324540BE2D58AA0BAE474094DE37BEF632454076DF313CF6AF474076711B0DE035454076DF313CF6AF474076711B0DE0354540BE2D58AA0BAE474094DE37BEF6324540BE2D58AA0BAE4740
55364	56660	42.213254999999997	42.266579	47.336573999999999	47.322405000000003	Мира	0103000020E61000000100000005000000AF5A99F04B1B45409088299144A94740AF5A99F04B1B45408A5759DB14AB47407366BB421F2245408A5759DB14AB47407366BB421F2245409088299144A94740AF5A99F04B1B45409088299144A94740
55578	1462	42.954022999999999	42.974550000000001	47.140644000000002	47.117151	Парковая	0103000020E61000000100000005000000DF50F86C1D7A4540CBD8D0CDFE8E4740DF50F86C1D7A45407730629F009247408D28ED0DBE7C45407730629F009247408D28ED0DBE7C4540CBD8D0CDFE8E4740DF50F86C1D7A4540CBD8D0CDFE8E4740
55748	16854	40.289396000000004	40.307281000000003	46.814262999999997	46.804831999999998	Шоссейная	0103000020E61000000100000005000000EFCB99ED0A2544401B6327BC04674740EFCB99ED0A254440E2AB1DC53968474052D7DAFB54274440E2AB1DC53968474052D7DAFB542744401B6327BC04674740EFCB99ED0A2544401B6327BC04674740
56220	16937	40.338811999999997	40.349628000000003	46.803666999999997	46.796455000000002	Пугачева	0103000020E6100000010000000500000005BF0D315E2B44402BDEC83CF265474005BF0D315E2B4440EDEF6C8FDE66474009E23C9CC02C4440EDEF6C8FDE66474009E23C9CC02C44402BDEC83CF265474005BF0D315E2B44402BDEC83CF2654740
55280	56634	40.710292000000003	40.737475000000003	46.884183	46.866652000000002	Центральная	0103000020E61000000100000005000000234E27D9EA5A4440AA81E673EE6E4740234E27D9EA5A4440EF5696E82C7147400E4FAF94655E4440EF5696E82C7147400E4FAF94655E4440AA81E673EE6E4740234E27D9EA5A4440AA81E673EE6E4740
56420	56891	40.476497000000002	40.480331999999997	46.959954000000003	46.950592999999998	Заречная	0103000020E6100000010000000500000031D28BDAFD3C44403C670B08AD79474031D28BDAFD3C44400BD5CDC5DF7A4740739CDB847B3D44400BD5CDC5DF7A4740739CDB847B3D44403C670B08AD79474031D28BDAFD3C44403C670B08AD794740
40410	16493	40.390878000000001	40.420513999999997	47.054174000000003	47.032294	Центральная	0103000020E61000000100000005000000EA5C514A08324440B3EDB43522844740EA5C514A083244409225732CEF8647404CC11A67D33544409225732CEF8647404CC11A67D3354440B3EDB43522844740EA5C514A08324440B3EDB43522844740
55749	15844	40.327807999999997	40.368259000000002	46.617465000000003	46.597845999999997	Специалистов	0103000020E61000000100000005000000FFAECF9CF5294440AF05BD37864C4740FFAECF9CF52944405BB6D617094F474095BA641C232F44405BB6D617094F474095BA641C232F4440AF05BD37864C4740FFAECF9CF5294440AF05BD37864C4740
56392	56865	40.249079000000002	40.281778000000003	46.736265000000003	46.724936999999997	Магистральная	0103000020E61000000100000005000000698F17D2E11F4440865451BCCA5C4740698F17D2E11F4440401878EE3D5E4740BC5D2F4D11244440401878EE3D5E4740BC5D2F4D11244440865451BCCA5C4740698F17D2E11F4440865451BCCA5C4740
56438	56906	40.285837999999998	40.335999999999999	46.899664999999999	46.894696000000003	Заречная	0103000020E610000001000000050000001EFAEE569624444057EE0566857247401EFAEE56962444408C2D0439287347405EBA490C022B44408C2D0439287347405EBA490C022B444057EE0566857247401EFAEE569624444057EE056685724740
55265	56625	40.998624	41.056314	46.946914	46.920264000000003	Ленина	0103000020E61000000100000005000000178046E9D27F4440D4D7F335CB754740178046E9D27F4440F10F5B7A347947404A27124C35874440F10F5B7A347947404A27124C35874440D4D7F335CB754740178046E9D27F4440D4D7F335CB754740
56078	56809	40.228543999999999	40.241712999999997	46.799657000000003	46.790106999999999	Платова	0103000020E6100000010000000500000038D906EE401D44409BABE6392265474038D906EE401D44403D821B295B6647404F029B73F01E44403D821B295B6647404F029B73F01E44409BABE6392265474038D906EE401D44409BABE63922654740
56531	56985	40.614998999999997	40.673461000000003	46.919992999999998	46.906923999999997	40 лет Победы	0103000020E610000001000000050000004E098849B84E44408FFAEB15167447404E098849B84E444043C6A354C2754740D41055F83356444043C6A354C2754740D41055F8335644408FFAEB15167447404E098849B84E44408FFAEB1516744740
56536	56990	40.594374000000002	40.618304999999999	46.795597999999998	46.782653000000003	Мира площадь	0103000020E61000000100000005000000DECB7D72144C4440E38E37F92D644740DECB7D72144C4440AA61BF27D665474005FA449E244F4440AA61BF27D665474005FA449E244F4440E38E37F92D644740DECB7D72144C4440E38E37F92D644740
56333	16240	40.385848000000003	40.395091000000001	47.126525999999998	47.123215999999999	Майская	0103000020E610000001000000050000000F9D9E7763314440062CB98AC58F47400F9D9E7763314440FE0B040132904740D3F8855792324440FE0B040132904740D3F8855792324440062CB98AC58F47400F9D9E7763314440062CB98AC58F4740
56323	14519	40.354928000000001	40.370719999999999	47.056941999999999	47.048696999999997	пер. Казачий	0103000020E61000000100000005000000A437DC476E2D4440E7340BB43B864740A437DC476E2D444069E21DE0498747408FFCC1C0732F444069E21DE0498747408FFCC1C0732F4440E7340BB43B864740A437DC476E2D4440E7340BB43B864740
56076	15895	40.505378	40.562286	46.922651999999999	46.908315999999999	Специалистов	0103000020E61000000100000005000000170FEF39B04044407E37DDB243744740170FEF39B040444064CBF27519764740D47FD6FCF847444064CBF27519764740D47FD6FCF84744407E37DDB243744740170FEF39B04044407E37DDB243744740
56072	12193	40.262203999999997	40.311332	46.529924999999999	46.515675999999999	Школьная	0103000020E61000000100000005000000B07092E68F21444082AAD1AB01424740B07092E68F214440992A1895D443474061191BBAD9274440992A1895D443474061191BBAD927444082AAD1AB01424740B07092E68F21444082AAD1AB01424740
56221	56825	40.199007000000002	40.229981000000002	46.582909000000001	46.578423999999998	Бородинская	0103000020E610000001000000050000006956B60F791944405A9C31CC094A47406956B60F79194440A4C519C39C4A4740C7D97404701D4440A4C519C39C4A4740C7D97404701D44405A9C31CC094A47406956B60F791944405A9C31CC094A4740
55946	15437	40.067951999999998	40.087032000000001	46.541666999999997	46.536658000000003	Мира	0103000020E6100000010000000500000051D9B0A6B208444082919735B144474051D9B0A6B208444045292158554547404DDA54DD230B444045292158554547404DDA54DD230B444082919735B144474051D9B0A6B208444082919735B1444740
40408	54860	40.438218999999997	40.491273999999997	46.791538000000003	46.755654999999997	Токарева	0103000020E610000001000000050000002FBE688F173844408907944DB96047402FBE688F1738444048C5FF1D5165474003B00111E23E444048C5FF1D5165474003B00111E23E44408907944DB96047402FBE688F173844408907944DB9604740
40107	54860	40.438218999999997	40.491273999999997	46.791538000000003	46.755654999999997	Победы	0103000020E610000001000000050000002FBE688F173844408907944DB96047402FBE688F1738444048C5FF1D5165474003B00111E23E444048C5FF1D5165474003B00111E23E44408907944DB96047402FBE688F173844408907944DB9604740
40106	54860	40.438218999999997	40.491273999999997	46.791538000000003	46.755654999999997	Ленина	0103000020E610000001000000050000002FBE688F173844408907944DB96047402FBE688F1738444048C5FF1D5165474003B00111E23E444048C5FF1D5165474003B00111E23E44408907944DB96047402FBE688F173844408907944DB9604740
55948	16180	40.314889999999998	40.326739000000003	47.099347000000002	47.089654000000003	Ростовская	0103000020E6100000010000000500000031EBC5504E28444051FA42C8798B474031EBC5504E28444055FA0967B78C4740F4A96395D229444055FA0967B78C4740F4A96395D229444051FA42C8798B474031EBC5504E28444051FA42C8798B4740
56075	16301	40.463866000000003	40.477117	47.087015000000001	47.082407000000003	Молодежная	0103000020E61000000100000005000000F9DC09F65F3B444012FB04508C8A4740F9DC09F65F3B444077A1B94E238B4740CDAE7B2B123D444077A1B94E238B4740CDAE7B2B123D444012FB04508C8A4740F9DC09F65F3B444012FB04508C8A4740
56320	15767	40.841436999999999	40.848633	46.887551999999999	46.882693000000003	Майская	0103000020E610000001000000050000007A522635B46B44403EB48F15FC7047407A522635B46B4440ECBFCE4D9B71474037A79201A06C4440ECBFCE4D9B71474037A79201A06C44403EB48F15FC7047407A522635B46B44403EB48F15FC704740
56211	15343	40.320962000000002	40.351092000000001	46.520383000000002	46.510776999999997	Парковая	0103000020E610000001000000050000001FA166481529444045460724614147401FA16648152944407B32FFE89B42474091F12895F02C44407B32FFE89B42474091F12895F02C444045460724614147401FA16648152944404546072461414740
56499	56940	40.894384000000002	40.917534000000003	46.886524000000001	46.878042999999998	Молодежная	0103000020E610000001000000050000006808C72C7B724440A9BD88B6637047406808C72C7B7244403F8F519E79714740EA7B0DC1717544403F8F519E79714740EA7B0DC171754440A9BD88B6637047406808C72C7B724440A9BD88B663704740
56421	56892	40.600068999999998	40.618107000000002	46.705295	46.701524999999997	Заречная	0103000020E61000000100000005000000F52B9D0FCF4C4440C7293A92CB594740F52B9D0FCF4C44402384471B475A4740DF3653211E4F44402384471B475A4740DF3653211E4F4440C7293A92CB594740F52B9D0FCF4C4440C7293A92CB594740
55656	16701	40.365672000000004	40.380187999999997	46.928437000000002	46.921832999999999	Тургенева	0103000020E610000001000000050000000E881057CE2E4440D1AFAD9FFE7547400E881057CE2E4440BCB20B06D7764740732A1900AA304440BCB20B06D7764740732A1900AA304440D1AFAD9FFE7547400E881057CE2E4440D1AFAD9FFE754740
55924	56776	40.636387999999997	40.651758000000001	46.738475999999999	46.725802000000002	 Садовая	0103000020E610000001000000050000008EC87729755144408AAF7614E75C47408EC8772975514440C170AE61865E474004745FCE6C534440C170AE61865E474004745FCE6C5344408AAF7614E75C47408EC87729755144408AAF7614E75C4740
55652	16804	40.363866000000002	40.372858000000001	46.859923000000002	46.846784999999997	Куйбышева	0103000020E610000001000000050000002C103D29932E444026DF6C73636C47402C103D29932E4440030AF5F4116E4740A7069ACFB92F4440030AF5F4116E4740A7069ACFB92F444026DF6C73636C47402C103D29932E444026DF6C73636C4740
40427	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Шукшина	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
55602	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Специалистов	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
9752	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Социалистическая	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
40423	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Советская	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
41039	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Научный Городок	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
39649	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Мира	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
9807	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Ленина	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
39651	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Еремина	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
40108	17061	40.284346999999997	40.338084000000002	46.865856999999998	46.831547	Гагарина	0103000020E610000001000000050000009CDB847B65244440200BD121706A47409CDB847B652444409F01F566D46E474083A62556462B44409F01F566D46E474083A62556462B4440200BD121706A47409CDB847B65244440200BD121706A4740
56212	17008	40.238388999999998	40.250238000000003	46.837268000000002	46.833143	Разина	0103000020E61000000100000005000000F25CDF87831E444017F2086EA46A4740F25CDF87831E444061FE0A992B6B4740B51B7DCC0720444061FE0A992B6B4740B51B7DCC0720444017F2086EA46A4740F25CDF87831E444017F2086EA46A4740
55847	56705	40.808855000000001	40.839227000000001	46.988447000000001	46.980566000000003	Степная	0103000020E61000000100000005000000611A868F88674440E7C8CA2F837D4740611A868F88674440276A696E857E4740C97553CA6B6B4440276A696E857E4740C97553CA6B6B4440E7C8CA2F837D4740611A868F88674440E7C8CA2F837D4740
56254	30288	40.080545999999998	40.113343999999998	46.589813999999997	46.578175999999999	Школьная	0103000020E610000001000000050000006CE9D1544F0A444082AAD1AB014A47406CE9D1544F0A4440895C70067F4B47405299620E820E4440895C70067F4B47405299620E820E444082AAD1AB014A47406CE9D1544F0A444082AAD1AB014A4740
40409	15948	40.540779999999998	40.558306000000002	46.857236999999998	46.840676000000002	Цветной Бульвар	0103000020E610000001000000050000005A2A6F47384544401C446B459B6B47405A2A6F4738454440E8F527F1B96D47408E942D9276474440E8F527F1B96D47408E942D92764744401C446B459B6B47405A2A6F47384544401C446B459B6B4740
39944	54831	40.196384000000002	40.228104000000002	46.632052999999999	46.623358000000003	50 лет ВЛКСМ	0103000020E6100000010000000500000095BA641C2319444099D9E731CA4F474095BA641C231944405A2BDA1CE75047401C0B0A83321D44405A2BDA1CE75047401C0B0A83321D444099D9E731CA4F474095BA641C2319444099D9E731CA4F4740
56540	56994	40.786262999999998	40.815916000000001	46.907823	46.902786999999996	Школьная	0103000020E6100000010000000500000005871744A4644440812040868E73474005871744A46444403FC7478B337447403E247CEF6F6844403FC7478B337447403E247CEF6F684440812040868E73474005871744A4644440812040868E734740
56470	56934	40.456347000000001	40.467469000000001	47.012433999999999	46.998176999999998	Школьная	0103000020E6100000010000000500000059501894693A4440484F9143C47F474059501894693A4440E2ADF36F9781474069723106D63B4440E2ADF36F9781474069723106D63B4440484F9143C47F474059501894693A4440484F9143C47F4740
56483	56944	40.509715999999997	40.539054999999998	47.030237	47.021317000000003	Центральная	0103000020E61000000100000005000000BC1FB75F3E414440A7ECF483BA824740BC1FB75F3E414440881057CEDE83474065DF15C1FF444440881057CEDE83474065DF15C1FF444440A7ECF483BA824740BC1FB75F3E414440A7ECF483BA824740
56548	57000	40.131732	40.165078000000001	46.632826000000001	46.627133000000001	Родниковая	0103000020E6100000010000000500000018EB1B98DC104440069FE6E44550474018EB1B98DC1044407D073F710051474001A5A146211544407D073F710051474001A5A14621154440069FE6E44550474018EB1B98DC104440069FE6E445504740
55855	56712	40.609375	40.632201999999999	46.991373000000003	46.967654000000003	Ленина	0103000020E6100000010000000500000000000000004E4440FBEB1516DC7B474000000000004E444097917A4FE57E47409F3BC1FEEB50444097917A4FE57E47409F3BC1FEEB504440FBEB1516DC7B474000000000004E4440FBEB1516DC7B4740
56416	56887	40.233682000000002	40.269722000000002	46.630375999999998	46.620133000000003	 Звездная	0103000020E61000000100000005000000FAD4B14AE91D4440CF15A584604F4740FAD4B14AE91D444076172829B0504740808120408622444076172829B05047408081204086224440CF15A584604F4740FAD4B14AE91D4440CF15A584604F4740
56561	57013	40.179423999999997	40.211592000000003	46.697921999999998	46.690424999999998	Мира	0103000020E610000001000000050000000A0F9A5DF71644409FABADD85F5847400A0F9A5DF71644405794128255594740310C5872151B44405794128255594740310C5872151B44409FABADD85F5847400A0F9A5DF71644409FABADD85F584740
56580	56715	40.252671999999997	40.417262000000001	46.692816999999998	46.673076999999999	Садовая	0103000020E61000000100000005000000B54E5C8E572044404B581B6327564740B54E5C8E57204440718E3A3AAE58474089EE59D768354440718E3A3AAE58474089EE59D7683544404B581B6327564740B54E5C8E572044404B581B6327564740
55858	56715	40.252671999999997	40.417262000000001	46.692816999999998	46.673076999999999	Заречная	0103000020E61000000100000005000000B54E5C8E572044404B581B6327564740B54E5C8E57204440718E3A3AAE58474089EE59D768354440718E3A3AAE58474089EE59D7683544404B581B6327564740B54E5C8E572044404B581B6327564740
55664	32241	43.601402999999998	43.630985000000003	47.369630999999998	47.357064000000001	Гагарина	0103000020E61000000100000005000000AF5B04C6FACC45401B4AED45B4AD4740AF5B04C6FACC45403C4B901150AF47401FA2D11DC4D045403C4B901150AF47401FA2D11DC4D045401B4AED45B4AD4740AF5B04C6FACC45401B4AED45B4AD4740
55646	32329	43.636428000000002	43.682521000000001	46.967063000000003	46.952733000000002	Центральная	0103000020E610000001000000050000001D21037976D14540F568AA27F37947401D21037976D14540F9156BB8C87B4740A7EA1ED95CD74540F9156BB8C87B4740A7EA1ED95CD74540F568AA27F37947401D21037976D14540F568AA27F3794740
55771	32475	43.981121000000002	44.023980000000002	46.887442	46.858635999999997	Центральная	0103000020E610000001000000050000009C35785F95FD45408995D1C8E76D47409C35785F95FD4540658C0FB39771474009E1D1C611034640658C0FB39771474009E1D1C6110346408995D1C8E76D47409C35785F95FD45408995D1C8E76D4740
55768	32418	43.656955000000004	43.676825999999998	46.833593	46.810414000000002	Школьная	0103000020E61000000100000005000000CBF8F71917D445403B1C5DA5BB674740CBF8F71917D445405796E82CB36A47408F8AFF3BA2D645405796E82CB36A47408F8AFF3BA2D645403B1C5DA5BB674740CBF8F71917D445403B1C5DA5BB674740
55648	32387	43.463099	43.494252000000003	46.792309000000003	46.775388999999997	Центральная	0103000020E61000000100000005000000B8E7F9D346BB4540CD565EF23F634740B8E7F9D346BB4540CAA99D616A654740C6FD47A643BF4540CAA99D616A654740C6FD47A643BF4540CD565EF23F634740B8E7F9D346BB4540CD565EF23F634740
55965	25203	43.555356000000003	43.570267999999999	47.257305000000002	47.250821999999999	Зеленая	0103000020E6100000010000000500000096D1C8E715C74540048F6FEF1AA0474096D1C8E715C74540740CC85EEFA0474048FAB48AFEC84540740CC85EEFA0474048FAB48AFEC84540048F6FEF1AA0474096D1C8E715C74540048F6FEF1AA04740
56008	25249	43.692106000000003	43.712668999999998	47.249322999999997	47.23554	Школьная	0103000020E61000000100000005000000C5AEEDED96D845402E73BA2C269E4740C5AEEDED96D84540FF91E9D0E99F4740BFEFDFBC38DB4540FF91E9D0E99F4740BFEFDFBC38DB45402E73BA2C269E4740C5AEEDED96D845402E73BA2C269E4740
55764	32168	44.014898000000002	44.067619999999998	47.086561000000003	47.062154	Школьная	0103000020E610000001000000050000004E637B2DE801464065A88AA9F48747404E637B2DE8014640F60D4C6E148B47401B47ACC5A7084640F60D4C6E148B47401B47ACC5A708464065A88AA9F48747404E637B2DE801464065A88AA9F4874740
55766	32234	44.119138	44.193131999999999	47.319490999999999	47.287422999999997	Новый	0103000020E61000000100000005000000FDDAFAE93F0F4640218FE046CAA44740FDDAFAE93F0F4640E42EC214E5A84740D1E7A38CB8184640E42EC214E5A84740D1E7A38CB8184640218FE046CAA44740FDDAFAE93F0F4640218FE046CAA44740
41241	32093	43.858680999999997	43.940328999999998	47.137732999999997	47.097892999999999	Ломоносова	0103000020E6100000010000000500000029594E42E9ED4540F0C000C2878C474029594E42E9ED45403C4A253CA19147407D3D5FB35CF845403C4A253CA19147407D3D5FB35CF84540F0C000C2878C474029594E42E9ED4540F0C000C2878C4740
39683	32093	43.858680999999997	43.940328999999998	47.137732999999997	47.097892999999999	Горького	0103000020E6100000010000000500000029594E42E9ED4540F0C000C2878C474029594E42E9ED45403C4A253CA19147407D3D5FB35CF845403C4A253CA19147407D3D5FB35CF84540F0C000C2878C474029594E42E9ED4540F0C000C2878C4740
56363	25128	44.139853000000002	44.160612999999998	47.061264000000001	47.047142999999998	Центральная	0103000020E61000000100000005000000AE9FFEB3E61146401F9E25C808864740AE9FFEB3E61146400936AE7FD7874740FE277FF78E1446400936AE7FD7874740FE277FF78E1446401F9E25C808864740AE9FFEB3E61146401F9E25C808864740
39940	14644	40.499763000000002	40.582721999999997	46.382508000000001	46.356552999999998	Шаумяна	0103000020E610000001000000050000001C60E63BF83F444035255987A32D47401C60E63BF83F4440AC3AAB05F630474071546EA2964A4440AC3AAB05F630474071546EA2964A444035255987A32D47401C60E63BF83F444035255987A32D4740
56206	14185	40.815009000000003	40.846359999999997	46.582487	46.560724	пер. Школьный	0103000020E610000001000000050000000C79043752684440890AD5CDC54747400C790437526844402EAC1BEF8E4A47403F524486556C44402EAC1BEF8E4A47403F524486556C4440890AD5CDC54747400C79043752684440890AD5CDC5474740
55503	14237	40.683566999999996	40.701101999999999	46.678857999999998	46.661296	Специалистов	0103000020E61000000100000005000000FACF9A1F7F574440E17CEA58A5544740FACF9A1F7F5744406150A6D1E45647408194D8B5BD5944406150A6D1E45647408194D8B5BD594440E17CEA58A5544740FACF9A1F7F574440E17CEA58A5544740
56318	13642	40.478284000000002	40.492297999999998	46.399695000000001	46.393093999999998	Мира	0103000020E610000001000000050000009C19FD68383D44407D2079E7503247409C19FD68383D4440F7AFAC34293347406FF1F09E033F4440F7AFAC34293347406FF1F09E033F44407D2079E7503247409C19FD68383D44407D2079E750324740
55123	14851	40.605691999999998	40.642209000000001	46.435262999999999	46.421815000000002	пер. Победы	0103000020E6100000010000000500000073B9C150874D44402BFBAE08FE35474073B9C150874D44405514AFB2B637474033198EE7335244405514AFB2B637474033198EE7335244402BFBAE08FE35474073B9C150874D44402BFBAE08FE354740
40402	14381	40.413103	40.475706000000002	46.625196000000003	46.599865000000001	Зеленая	0103000020E610000001000000050000009370218FE0344440ED815660C84C47409370218FE034444086CB2A6C06504740684128EFE33C444086CB2A6C06504740684128EFE33C4440ED815660C84C47409370218FE0344440ED815660C84C4740
40404	14777	40.647005999999998	40.701641000000002	46.344223999999997	46.329003999999998	Школьная	0103000020E610000001000000050000006B28B517D1524440682096CD1C2A47406B28B517D1524440C83F33880F2C474031444E5FCF594440C83F33880F2C474031444E5FCF594440682096CD1C2A47406B28B517D1524440682096CD1C2A4740
41032	14572	40.412582	40.426558999999997	46.408456999999999	46.395952999999999	Почтовая	0103000020E610000001000000050000008A75AA7CCF34444065E08096AE3247408A75AA7CCF3444404069A8514834474040683D7C993644404069A8514834474040683D7C9936444065E08096AE3247408A75AA7CCF34444065E08096AE324740
41030	14458	40.447212	40.548012	46.469678000000002	46.454127999999997	Октябрьская	0103000020E610000001000000050000007B30293E3E3944405419C6DD203A47407B30293E3E3944404AD3A0681E3C474064E8D841254644404AD3A0681E3C474064E8D841254644405419C6DD203A47407B30293E3E3944405419C6DD203A4740
41034	14711	40.324644999999997	40.506914000000002	46.351464999999997	46.337716	Ленина	0103000020E61000000100000005000000ABE7A4F78D29444000AB23473A2B4740ABE7A4F78D29444025581CCEFC2C474039F1D58EE240444025581CCEFC2C474039F1D58EE240444000AB23473A2B4740ABE7A4F78D29444000AB23473A2B4740
56322	14426	40.473038000000003	40.539324999999998	46.535995	46.503737000000001	Парковая	0103000020E61000000100000005000000F4E159828C3C444080643A747A404740F4E159828C3C4440E6E8F17B9B4447402575029A08454440E6E8F17B9B4447402575029A0845444080643A747A404740F4E159828C3C444080643A747A404740
55640	14016	40.553285000000002	40.582965000000002	46.664568000000003	46.659187000000003	Ростовская	0103000020E61000000100000005000000062FFA0AD24644406479573D60544740062FFA0AD2464440ECFB70901055474038DBDC989E4A4440ECFB70901055474038DBDC989E4A44406479573D60544740062FFA0AD24644406479573D60544740
41028	13475	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	переулок Тергенева	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
40103	13475	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	переулок Первомайский	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
41026	13475	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	Ростовская	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
40272	13475	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	Мичурина	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
41029	13475	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	Малькова	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
40972	13475	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	Ленина	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
39647	13475	40.634079	40.694975999999997	46.585844000000002	46.549847999999997	Грицика	0103000020E610000001000000050000004A0A2C8029514440B0E2546B614647404A0A2C80295144406747AAEFFC4A4740A0C03BF9F45844406747AAEFFC4A4740A0C03BF9F4584440B0E2546B614647404A0A2C8029514440B0E2546B61464740
55499	14106	40.764325999999997	40.810194000000003	46.509566999999997	46.499276999999999	Садовая	0103000020E61000000100000005000000C2BD326FD56144408F52094FE83F4740C2BD326FD5614440770FD07D394147402DB5DE6FB4674440770FD07D394147402DB5DE6FB46744408F52094FE83F4740C2BD326FD56144408F52094FE83F4740
55653	14618	40.295836000000001	40.405681999999999	46.419038	46.395493000000002	Школьная	0103000020E610000001000000050000005F7D3CF4DD2544400266BE839F3247405F7D3CF4DD25444000E48409A3354740B6494563ED33444000E48409A3354740B6494563ED3344400266BE839F3247405F7D3CF4DD2544400266BE839F324740
56032	31893	42.992804	43.026724000000002	47.306232999999999	47.289171000000003	Молодежная	0103000020E6100000010000000500000043AB9333147F4540CFF9298E03A5474043AB9333147F45405DFA97A432A74740580229B16B8345405DFA97A432A74740580229B16B834540CFF9298E03A5474043AB9333147F4540CFF9298E03A54740
55660	31503	42.622644000000001	42.654344999999999	47.404874999999997	47.395513000000001	Садовая	0103000020E610000001000000050000007B8670CCB24F45404912842BA0B247407B8670CCB24F4540E7FBA9F1D2B347408BA6B393C1534540E7FBA9F1D2B347408BA6B393C15345404912842BA0B247407B8670CCB24F45404912842BA0B24740
55555	31792	42.978510999999997	43.007697999999998	47.494425	47.479841	Ленина	0103000020E610000001000000050000005CE333D93F7D4540D5230D6E6BBD47405CE333D93F7D454093A9825149BF47404F1F813FFC80454093A9825149BF47404F1F813FFC804540D5230D6E6BBD47405CE333D93F7D4540D5230D6E6BBD4740
55881	56735	42.733243999999999	42.758693999999998	47.367361000000002	47.352772000000002	Молодежная	0103000020E610000001000000050000007EFE7BF0DA5D4540E67805A227AD47407EFE7BF0DA5D4540B6696CAF05AF4740F1D58EE21C614540B6696CAF05AF4740F1D58EE21C614540E67805A227AD47407EFE7BF0DA5D4540E67805A227AD4740
55561	32017	43.240676000000001	43.273643999999997	47.066482000000001	47.046812000000003	Центральная	0103000020E610000001000000050000004F779E78CE9E4540BA8784EFFD8547404F779E78CE9E4540E7E26F7B82884740915F3FC406A34540E7E26F7B82884740915F3FC406A34540BA8784EFFD8547404F779E78CE9E4540BA8784EFFD854740
56054	39345	42.372174999999999	42.384770000000003	47.571103999999998	47.557411999999999	пер. Солнечный	0103000020E61000000100000005000000C4B12E6EA32F4540F032C34659C74740C4B12E6EA32F4540B14E95EF19C94740B03DB32440314540B14E95EF19C94740B03DB32440314540F032C34659C74740C4B12E6EA32F4540F032C34659C74740
56004	31361	42.798479999999998	42.820703999999999	47.246436000000003	47.231324000000001	Центральная	0103000020E610000001000000050000004A41B79734664540D4635B069C9D47404A41B797346645404E4700378B9F474023D923D40C6945404E4700378B9F474023D923D40C694540D4635B069C9D47404A41B79734664540D4635B069C9D4740
56089	32046	43.192830999999998	43.220221000000002	46.915733000000003	46.901240999999999	Центральная	0103000020E61000000100000005000000D653ABAFAE9845403C6876DD5B734740D653ABAFAE9845401A6F2BBD367547403B72A433309C45401A6F2BBD367547403B72A433309C45403C6876DD5B734740D653ABAFAE9845403C6876DD5B734740
56006	31690	42.664217999999998	42.682327999999998	47.737496	47.72775	Приморская	0103000020E610000001000000050000000FB56D1805554540FED478E926DD47400FB56D18055545402577D84466DE474092921E86565745402577D84466DE474092921E8656574540FED478E926DD47400FB56D1805554540FED478E926DD4740
55875	56730	42.341202000000003	42.362222000000003	47.488481999999998	47.479945000000001	Лесная	0103000020E6100000010000000500000037AAD381AC2B45407A7077D66EBD474037AAD381AC2B4540A357039486BE474024F25D4A5D2E4540A357039486BE474024F25D4A5D2E45407A7077D66EBD474037AAD381AC2B45407A7077D66EBD4740
40126	31648	42.490475000000004	42.518484000000001	47.633465000000001	47.611060000000002	Центральная площадь	0103000020E61000000100000005000000B84082E2C73E454067F2CD3637CE4740B84082E2C73E45409014916115D14740E8BF07AF5D4245409014916115D14740E8BF07AF5D42454067F2CD3637CE4740B84082E2C73E454067F2CD3637CE4740
55645	31472	42.727665999999999	42.743000000000002	47.416662000000002	47.403863000000001	Школьный	0103000020E61000000100000005000000A034D428245D4540408864C8B1B34740A034D428245D454034BE2F2E55B54740C976BE9F1A5F454034BE2F2E55B54740C976BE9F1A5F4540408864C8B1B34740A034D428245D4540408864C8B1B34740
55126	25057	42.747563	42.784224000000002	47.425576	47.394072999999999	пл. Павших Борцов 2	0103000020E610000001000000050000008E59F624B05F4540499EEBFB70B247408E59F624B05F454033FB3C4679B64740815EB8736164454033FB3C4679B64740815EB87361644540499EEBFB70B247408E59F624B05F4540499EEBFB70B24740
40298	25057	42.747563	42.784224000000002	47.425576	47.394072999999999	переулок Герцена	0103000020E610000001000000050000008E59F624B05F4540499EEBFB70B247408E59F624B05F454033FB3C4679B64740815EB8736164454033FB3C4679B64740815EB87361644540499EEBFB70B247408E59F624B05F4540499EEBFB70B24740
55234	25057	42.747563	42.784224000000002	47.425576	47.394072999999999	Первомайская	0103000020E610000001000000050000008E59F624B05F4540499EEBFB70B247408E59F624B05F454033FB3C4679B64740815EB8736164454033FB3C4679B64740815EB87361644540499EEBFB70B247408E59F624B05F4540499EEBFB70B24740
40194	25057	42.747563	42.784224000000002	47.425576	47.394072999999999	Ленина	0103000020E610000001000000050000008E59F624B05F4540499EEBFB70B247408E59F624B05F454033FB3C4679B64740815EB8736164454033FB3C4679B64740815EB87361644540499EEBFB70B247408E59F624B05F4540499EEBFB70B24740
55668	31815	43.246335000000002	43.275773000000001	47.348163	47.333813999999997	Школьная	0103000020E610000001000000050000001A6EC0E7879F45403579CA6ABAAA47401A6EC0E7879F4540B056ED9A90AC4740560F98874CA34540B056ED9A90AC4740560F98874CA345403579CA6ABAAA47401A6EC0E7879F45403579CA6ABAAA4740
55907	56760	42.844608000000001	42.876409000000002	47.388655999999997	47.378821000000002	Октябрьская	0103000020E6100000010000000500000051F86C1D1C6C4540DE04DF347DB0474051F86C1D1C6C454074B2D47ABFB14740C5758C2B2E70454074B2D47ABFB14740C5758C2B2E704540DE04DF347DB0474051F86C1D1C6C4540DE04DF347DB04740
55671	31568	42.585355	42.610183999999997	47.535893000000002	47.518923999999998	Административная	0103000020E6100000010000000500000069C6A2E9EC4A4540048E041A6CC2474069C6A2E9EC4A4540E2934E2498C447406F4562821A4E4540E2934E2498C447406F4562821A4E4540048E041A6CC2474069C6A2E9EC4A4540048E041A6CC24740
55773	31876	43.021945000000002	43.054293000000001	47.373621999999997	47.353273000000002	Центральная	0103000020E61000000100000005000000C6A70018CF824540A8C7B60C38AD4740C6A70018CF82454076887FD8D2AF47406CB3B112F386454076887FD8D2AF47406CB3B112F3864540A8C7B60C38AD4740C6A70018CF824540A8C7B60C38AD4740
56087	2860	42.610858	42.633899999999997	47.670532999999999	47.654730999999998	Школьная	0103000020E61000000100000005000000FF3F4E98304E4540B456B439CED34740FF3F4E98304E4540C3F17C06D4D547409A779CA223514540C3F17C06D4D547409A779CA223514540B456B439CED34740FF3F4E98304E4540B456B439CED34740
55761	30150	41.82441	41.852338000000003	47.499355999999999	47.488866000000002	Победы	0103000020E61000000100000005000000683F524486E944402C103D2993BE4740683F524486E94440DB87BCE5EABF4740AC915D6919ED4440DB87BCE5EABF4740AC915D6919ED44402C103D2993BE4740683F524486E944402C103D2993BE4740
56082	30063	41.713396000000003	41.740777000000001	47.510500999999998	47.499015	Центральная	0103000020E61000000100000005000000728C648F50DB4440529B38B9DFBF4740728C648F50DB4440A3C9C51858C147408350DEC7D1DE4440A3C9C51858C147408350DEC7D1DE4440529B38B9DFBF4740728C648F50DB4440529B38B9DFBF4740
56227	30511	42.217063000000003	42.228929999999998	47.461696000000003	47.451661000000001	Центральная	0103000020E61000000100000005000000F9156BB8C81B454078F01307D0B94740F9156BB8C81B4540D658C2DA18BB4740618907944D1D4540D658C2DA18BB4740618907944D1D454078F01307D0B94740F9156BB8C81B454078F01307D0B94740
56002	30199	41.882449999999999	41.906812000000002	47.474755999999999	47.468263	Комсомольская	0103000020E61000000100000005000000772D211FF4F04440A376BF0AF0BB4740772D211FF4F0444036CAFACDC4BC474068CF656A12F4444036CAFACDC4BC474068CF656A12F44440A376BF0AF0BB4740772D211FF4F04440A376BF0AF0BB4740
55760	30461	42.315078999999997	42.325004999999997	47.500810999999999	47.494272000000002	Прудовая	0103000020E6100000010000000500000004543882542845400DAA0D4E44BF47400454388254284540103D29931AC04740AB048BC399294540103D29931AC04740AB048BC3992945400DAA0D4E44BF474004543882542845400DAA0D4E44BF4740
55994	28072	42.027329999999999	42.034768	47.429147999999998	47.423240999999997	 Надежды	0103000020E610000001000000050000008F19A88C7F034540C5A9D6C22CB647408F19A88C7F03454068925852EEB6474042791F477304454068925852EEB6474042791F4773044540C5A9D6C22CB647408F19A88C7F034540C5A9D6C22CB64740
56222	31010	42.082208000000001	42.097498000000002	47.349836000000003	47.337563000000003	Центральная	0103000020E610000001000000050000001BBCAFCA850A45407AABAE4335AB47401BBCAFCA850A4540537B116DC7AC474074B680D07A0C4540537B116DC7AC474074B680D07A0C45407AABAE4335AB47401BBCAFCA850A45407AABAE4335AB4740
56337	30582	42.249178000000001	42.258412999999997	47.411009999999997	47.401667000000003	Молодежная	0103000020E61000000100000005000000FC709010E51F4540F47002D369B34740FC709010E51F45401B2AC6F99BB447403DEE5BAD132145401B2AC6F99BB447403DEE5BAD13214540F47002D369B34740FC709010E51F4540F47002D369B34740
56003	30294	41.861258999999997	41.866531999999999	47.360945999999998	47.357216000000001	Степная	0103000020E610000001000000050000005D3123BC3DEE4440D1CDFE40B9AD47405D3123BC3DEE44409ECF807A33AE4740FF774485EAEE44409ECF807A33AE4740FF774485EAEE4440D1CDFE40B9AD47405D3123BC3DEE4440D1CDFE40B9AD4740
40628	30093	41.767789	41.789563999999999	47.523336	47.497596000000001	Театральная	0103000020E61000000100000005000000419DF2E846E244406A4FC939B1BF4740419DF2E846E24440E4688EACFCC24740AA0CE36E10E54440E4688EACFCC24740AA0CE36E10E544406A4FC939B1BF4740419DF2E846E244406A4FC939B1BF4740
39840	27914	42.010809999999999	42.054549000000002	47.550333000000002	47.530211000000001	переулок Союзный	0103000020E61000000100000005000000213CDA38620145405F7D3CF4DDC34740213CDA38620145406D74CE4F71C64740C7832D76FB0645406D74CE4F71C64740C7832D76FB0645405F7D3CF4DDC34740213CDA38620145405F7D3CF4DDC34740
55243	27914	42.010809999999999	42.054549000000002	47.550333000000002	47.530211000000001	Юбилейная	0103000020E61000000100000005000000213CDA38620145405F7D3CF4DDC34740213CDA38620145406D74CE4F71C64740C7832D76FB0645406D74CE4F71C64740C7832D76FB0645405F7D3CF4DDC34740213CDA38620145405F7D3CF4DDC34740
39715	27914	42.010809999999999	42.054549000000002	47.550333000000002	47.530211000000001	Тюхова	0103000020E61000000100000005000000213CDA38620145405F7D3CF4DDC34740213CDA38620145406D74CE4F71C64740C7832D76FB0645406D74CE4F71C64740C7832D76FB0645405F7D3CF4DDC34740213CDA38620145405F7D3CF4DDC34740
40343	27914	42.010809999999999	42.054549000000002	47.550333000000002	47.530211000000001	Мелиораторов	0103000020E61000000100000005000000213CDA38620145405F7D3CF4DDC34740213CDA38620145406D74CE4F71C64740C7832D76FB0645406D74CE4F71C64740C7832D76FB0645405F7D3CF4DDC34740213CDA38620145405F7D3CF4DDC34740
55557	30646	41.784883999999998	41.794694	47.427947000000003	47.421168000000002	Ленина	0103000020E61000000100000005000000AB93331477E44440950F41D5E8B54740AB93331477E44440EEB5A0F7C6B64740E9297288B8E54440EEB5A0F7C6B64740E9297288B8E54440950F41D5E8B54740AB93331477E44440950F41D5E8B54740
40964	99	41.926026999999998	41.961008	47.478805999999999	47.463414	Садовая	0103000020E61000000100000005000000431B800D88F644401841632651BB4740431B800D88F644407590D78349BD4740E198654F02FB44407590D78349BD4740E198654F02FB44401841632651BB4740431B800D88F644401841632651BB4740
55666	99	41.926026999999998	41.961008	47.478805999999999	47.463414	Комсомольская	0103000020E61000000100000005000000431B800D88F644401841632651BB4740431B800D88F644407590D78349BD4740E198654F02FB44407590D78349BD4740E198654F02FB44401841632651BB4740431B800D88F644401841632651BB4740
56086	31100	42.073926	42.086053	47.551318999999999	47.545431000000001	Комсомольская	0103000020E610000001000000050000007C293C6876094540BF9CD9AED0C547407C293C6876094540EB54F99E91C64740815CE2C8030B4540EB54F99E91C64740815CE2C8030B4540BF9CD9AED0C547407C293C6876094540BF9CD9AED0C54740
55822	30766	41.645358000000002	41.662757999999997	47.424892999999997	47.416516000000001	Кооперативная	0103000020E61000000100000005000000221B48179BD244406021736550B54740221B48179BD2444050A6D1E462B64740C8940F41D5D4444050A6D1E462B64740C8940F41D5D444406021736550B54740221B48179BD244406021736550B54740
55642	29850	41.416753999999997	41.440398000000002	47.526822000000003	47.517214000000003	Центральная	0103000020E61000000100000005000000143DF03158B5444045847F1134C24740143DF03158B544401B683EE76EC34740A69C2FF65EB844401B683EE76EC34740A69C2FF65EB8444045847F1134C24740143DF03158B5444045847F1134C24740
55758	29942	41.568075999999998	41.595429000000003	47.525872999999997	47.513745	Школьная	0103000020E610000001000000050000003DD2E0B6B6C84440E4BD6A65C2C147403DD2E0B6B6C84440B96C74CE4FC34740850B790437CC4440B96C74CE4FC34740850B790437CC4440E4BD6A65C2C147403DD2E0B6B6C84440E4BD6A65C2C14740
56084	30367	42.298738	42.323144999999997	47.503293999999997	47.486941999999999	Центральная	0103000020E610000001000000050000004609FA0B3D26454040868E1D54BE47404609FA0B3D264540F22213F06BC04740D66EBBD05C294540F22213F06BC04740D66EBBD05C29454040868E1D54BE47404609FA0B3D26454040868E1D54BE4740
55762	30781	41.591988999999998	41.600954000000002	47.424118999999997	47.416876000000002	Ленина	0103000020E61000000100000005000000BE4BA94BC6CB4440603E59315CB54740BE4BA94BC6CB44405D4E098849B647404033880FECCC44405D4E098849B647404033880FECCC4440603E59315CB54740BE4BA94BC6CB4440603E59315CB54740
40293	31048	42.056139000000002	42.074967999999998	47.531750000000002	47.516046000000003	переулок Юбилейный	0103000020E61000000100000005000000DC8310902F074540A69D9ACB0DC24740DC8310902F074540F2D24D6210C447408E1F2A8D98094540F2D24D6210C447408E1F2A8D98094540A69D9ACB0DC24740DC8310902F074540A69D9ACB0DC24740
55644	30964	41.420976000000003	41.436356000000004	47.443531999999998	47.432574000000002	Мира	0103000020E610000001000000050000005133A48AE2B54440CA8CB7955EB747405133A48AE2B544405F5D15A8C5B84740EAB46E83DAB744405F5D15A8C5B84740EAB46E83DAB74440CA8CB7955EB747405133A48AE2B54440CA8CB7955EB74740
56338	30362	41.874822999999999	41.884704999999997	47.336573999999999	47.332495000000002	Школьная	0103000020E61000000100000005000000F1643733FAEF4440B18A37328FAA4740F1643733FAEF44408A5759DB14AB4740C8CD70033EF144408A5759DB14AB4740C8CD70033EF14440B18A37328FAA4740F1643733FAEF4440B18A37328FAA4740
55647	29911	41.464193999999999	41.511490999999999	47.534481999999997	47.513263999999999	переулок Совхозный	0103000020E61000000100000005000000ED7F80B56ABB4440691B7FA2B2C14740ED7F80B56ABB44407C26FBE769C4474063997E8978C144407C26FBE769C4474063997E8978C14440691B7FA2B2C14740ED7F80B56ABB4440691B7FA2B2C14740
55643	30877	41.507914999999997	41.523311999999997	47.417442999999999	47.407125000000001	Гайдара	0103000020E61000000100000005000000EC12D55B03C14440273108AC1CB44740EC12D55B03C14440D978B0C56EB547405BCD3AE3FBC24440D978B0C56EB547405BCD3AE3FBC24440273108AC1CB44740EC12D55B03C14440273108AC1CB44740
9964	40369	41.713405000000002	41.722918	47.426070000000003	47.419564999999999	Дружбы	0103000020E61000000100000005000000C5E6E3DA50DB4440EBC5504EB4B54740C5E6E3DA50DB444043E7357689B6474049D8B79388DC444043E7357689B6474049D8B79388DC4440EBC5504EB4B54740C5E6E3DA50DB4440EBC5504EB4B54740
55818	30003	41.642510000000001	41.669620999999999	47.520999000000003	47.509892000000001	Школьная	0103000020E610000001000000050000002EAD86C43DD24440FB3E1C2444C147402EAD86C43DD24440D61F6118B0C247407FDB1324B6D54440D61F6118B0C247407FDB1324B6D54440FB3E1C2444C147402EAD86C43DD24440FB3E1C2444C14740
55927	56779	40.816167999999998	40.835419000000002	47.278792000000003	47.271864999999998	Школьная	0103000020E6100000010000000500000057056A3178684440A9F6E978CCA2474057056A31786844407731CD74AFA3474080BA8102EF6A44407731CD74AFA3474080BA8102EF6A4440A9F6E978CCA2474057056A3178684440A9F6E978CCA24740
55662	29332	40.667774999999999	40.6937	47.235931999999998	47.217126999999998	Ленина	0103000020E610000001000000050000000F0BB5A6795544400F0A4AD1CA9B47400F0BB5A679554440390A1005339E47401B9E5E29CB584440390A1005339E47401B9E5E29CB5844400F0A4AD1CA9B47400F0BB5A6795544400F0A4AD1CA9B4740
56486	56946	40.749782000000003	40.769131999999999	47.139284000000004	47.123694	Центральная	0103000020E61000000100000005000000939048DBF85F4440105B7A34D58F4740939048DBF85F4440946DE00ED49147404E27D9EA72624440946DE00ED49147404E27D9EA72624440105B7A34D58F4740939048DBF85F4440105B7A34D58F4740
56396	56868	40.635947999999999	40.673515000000002	47.190280999999999	47.175454000000002	Производственная	0103000020E6100000010000000500000072FA7ABE66514440E8F9D3467596474072FA7ABE665144406C06B8205B984740C72E51BD355644406C06B8205B984740C72E51BD35564440E8F9D3467596474072FA7ABE66514440E8F9D34675964740
56001	29518	40.982337999999999	40.993485999999997	47.290771999999997	47.282991000000003	Механическая	0103000020E610000001000000050000001CCF6740BD7D4440FB07910C39A447401CCF6740BD7D4440D74B530438A5474055849B8C2A7F4440D74B530438A5474055849B8C2A7F4440FB07910C39A447401CCF6740BD7D4440FB07910C39A44740
56424	56895	40.682022000000003	40.703187	47.020198999999998	47.010092999999998	Верхняя	0103000020E610000001000000050000008693347F4C574440927538BA4A8147408693347F4C574440B9347EE19582474076FC1708025A4440B9347EE19582474076FC1708025A4440927538BA4A8147408693347F4C574440927538BA4A814740
55900	56753	40.606842	40.629004000000002	47.099665999999999	47.071686	Центральная	0103000020E610000001000000050000006CEBA7FFAC4D444060CAC0012D8947406CEBA7FFAC4D4440F64201DBC18C4740CF86FC3383504440F64201DBC18C4740CF86FC338350444060CAC0012D8947406CEBA7FFAC4D444060CAC0012D894740
55943	56792	\N	\N	\N	\N	Дружбы	\N
55922	56774	40.768304999999998	40.813822999999999	47.242685999999999	47.218564999999998	Садовая	0103000020E61000000100000005000000382D78D1576244406E861BF0F99B4740382D78D1576244403999B855109F4740C6DD205A2B6844403999B855109F4740C6DD205A2B6844406E861BF0F99B4740382D78D1576244406E861BF0F99B4740
56425	56894	40.741697000000002	40.755476999999999	47.166516000000001	47.152644000000002	Солнечная	0103000020E610000001000000050000004A4563EDEF5E44401FF7ADD6899347404A4563EDEF5E44406021736550954740AAF06778B36044406021736550954740AAF06778B36044401FF7ADD6899347404A4563EDEF5E44401FF7ADD689934740
55871	56727	40.549053999999998	40.581752000000002	47.170743000000002	47.162723999999997	40-летия Победы проспект	0103000020E6100000010000000500000076DEC666474644401C23D923D494474076DEC66647464440AE8218E8DA954740F9307BD9764A4440AE8218E8DA954740F9307BD9764A44401C23D923D494474076DEC666474644401C23D923D4944740
55843	56702	40.880783000000001	40.906959999999998	47.181842000000003	47.172066999999998	Вишневая	0103000020E61000000100000005000000B7EF517FBD70444044DC9C4A06964740B7EF517FBD7044400685419946974740DC63E943177444400685419946974740DC63E9431774444044DC9C4A06964740B7EF517FBD70444044DC9C4A06964740
55641	56679	40.974828000000002	41.009593000000002	47.037894999999999	47.016544000000003	Школьная	0103000020E61000000100000005000000D09CF529C77C4440F778211D1E824740D09CF529C77C444049D74CBED9844740A1A2EA573A81444049D74CBED9844740A1A2EA573A814440F778211D1E824740D09CF529C77C4440F778211D1E824740
55756	46289	41.097475000000003	41.151113000000002	46.991501999999997	46.974215000000001	Центральная	0103000020E61000000100000005000000BC96900F7A8C4440E622BE13B37C4740BC96900F7A8C444094F59B89E97E47400F80B8AB5793444094F59B89E97E47400F80B8AB57934440E622BE13B37C4740BC96900F7A8C4440E622BE13B37C4740
56143	29273	40.655135999999999	40.680557999999998	47.108252999999998	47.095353000000003	Школьная	0103000020E610000001000000050000005437177FDB534440AA49F086348C47405437177FDB534440D158FB3BDB8D4740FD8348861C574440D158FB3BDB8D4740FD8348861C574440AA49F086348C47405437177FDB534440AA49F086348C4740
55601	28419	40.529659000000002	40.546151999999999	47.115293000000001	47.091861999999999	Центральная	0103000020E610000001000000050000001B84B9DDCB43444061DF4E22C28B47401B84B9DDCB434440973AC8EBC18E47408F52094FE8454440973AC8EBC18E47408F52094FE845444061DF4E22C28B47401B84B9DDCB43444061DF4E22C28B4740
56225	56827	40.825958999999997	40.859349999999999	47.072975	47.058275000000002	Старая	0103000020E610000001000000050000001E6B4606B96944405396218E758747401E6B4606B96944407A36AB3E57894740A7E8482EFF6D44407A36AB3E57894740A7E8482EFF6D44405396218E758747401E6B4606B96944405396218E75874740
56471	56935	40.898102999999999	40.921396000000001	47.061036999999999	47.042157000000003	Школьная	0103000020E6100000010000000500000041B8020AF572444014268C666585474041B8020AF5724440486C770FD08747402655DB4DF0754440486C770FD08747402655DB4DF075444014268C666585474041B8020AF572444014268C6665854740
40125	28782	40.722617	40.796503999999999	47.102173999999998	47.073625999999997	переулок Комсомольский	0103000020E610000001000000050000004E44BFB67E5C44405111A7936C8947404E44BFB67E5C44403140A209148D47400C91D3D7F36544403140A209148D47400C91D3D7F36544405111A7936C8947404E44BFB67E5C44405111A7936C894740
55125	28782	40.722617	40.796503999999999	47.102173999999998	47.073625999999997	пер. Комсомольский	0103000020E610000001000000050000004E44BFB67E5C44405111A7936C8947404E44BFB67E5C44403140A209148D47400C91D3D7F36544403140A209148D47400C91D3D7F36544405111A7936C8947404E44BFB67E5C44405111A7936C894740
40291	28782	40.722617	40.796503999999999	47.102173999999998	47.073625999999997	Октябрьская	0103000020E610000001000000050000004E44BFB67E5C44405111A7936C8947404E44BFB67E5C44403140A209148D47400C91D3D7F36544403140A209148D47400C91D3D7F36544405111A7936C8947404E44BFB67E5C44405111A7936C894740
40627	28782	40.722617	40.796503999999999	47.102173999999998	47.073625999999997	Думенко	0103000020E610000001000000050000004E44BFB67E5C44405111A7936C8947404E44BFB67E5C44403140A209148D47400C91D3D7F36544403140A209148D47400C91D3D7F36544405111A7936C8947404E44BFB67E5C44405111A7936C894740
56343	29069	40.736604	40.779812999999997	46.983277000000001	46.970512999999997	пер. Школьный	0103000020E61000000100000005000000280D350A495E4440E2AB1DC5397C4740280D350A495E44405AF44E05DC7D474071FF91E9D06344405AF44E05DC7D474071FF91E9D0634440E2AB1DC5397C4740280D350A495E4440E2AB1DC5397C4740
55401	56661	40.812916000000001	40.828932999999999	47.248294999999999	47.224691	Центральная	0103000020E610000001000000050000009432A9A10D6844404F5AB8ACC29C47409432A9A10D68444052616C21C89F47409FC9FE791A6A444052616C21C89F47409FC9FE791A6A44404F5AB8ACC29C47409432A9A10D6844404F5AB8ACC29C4740
55559	21338	41.415146	41.465164999999999	49.990591999999999	49.931981	Ленина	0103000020E6100000010000000500000059880E8123B5444027BF45274BF7484059880E8123B54440F1D6F9B7CBFE4840361FD7868ABB4440F1D6F9B7CBFE4840361FD7868ABB444027BF45274BF7484059880E8123B5444027BF45274BF74840
56300	56842	41.127470000000002	41.161479999999997	49.788041999999997	49.769910000000003	Тубянская	0103000020E610000001000000050000004E9CDCEF50904440836E2F698CE248404E9CDCEF50904440EDEF6C8FDEE44840A27A6B60AB944440EDEF6C8FDEE44840A27A6B60AB944440836E2F698CE248404E9CDCEF50904440836E2F698CE24840
55765	20106	41.002837999999997	41.019798000000002	49.616948000000001	49.609440999999997	Клубная	0103000020E61000000100000005000000D097DEFE5C804440B7EBA52902CE4840D097DEFE5C80444093AAED26F8CE48405B43A9BD8882444093AAED26F8CE48405B43A9BD88824440B7EBA52902CE4840D097DEFE5C804440B7EBA52902CE4840
56157	20962	41.081710000000001	41.112827000000003	49.803150000000002	49.795229999999997	Суровская	0103000020E61000000100000005000000CAE02879758A44402766BD18CAE54840CAE02879758A444026E4839ECDE648408B8D791D718E444026E4839ECDE648408B8D791D718E44402766BD18CAE54840CAE02879758A44402766BD18CAE54840
56030	21214	41.177030000000002	41.211255999999999	49.747062999999997	49.728019000000003	Стоговская	0103000020E61000000100000005000000983446EBA8964440EEEE01BA2FDD4840983446EBA89644409C86A8C29FDF4840B98AC56F0A9B44409C86A8C29FDF4840B98AC56F0A9B4440EEEE01BA2FDD4840983446EBA8964440EEEE01BA2FDD4840
56028	21052	41.305121	41.323841999999999	49.822808999999999	49.784460000000003	Солонцовская	0103000020E61000000100000005000000522976340EA7444095826E2F69E44840522976340EA744405FED28CE51E948401E8997A773A944405FED28CE51E948401E8997A773A9444095826E2F69E44840522976340EA7444095826E2F69E44840
56305	21374	41.398698000000003	41.425324000000003	49.930253	49.909917999999998	Свидовская	0103000020E61000000100000005000000857D3B8908B3444057056A3178F44840857D3B8908B34440C100C28712F748401A1A4F0471B64440C100C28712F748401A1A4F0471B6444057056A3178F44840857D3B8908B3444057056A3178F44840
56158	20795	41.511383000000002	41.528064999999998	50.076680000000003	50.061844000000001	Раскольная	0103000020E610000001000000050000007D5D86FF74C1444017BA1281EA0749407D5D86FF74C14440EF2076A6D0094940C49448A297C34440EF2076A6D0094940C49448A297C3444017BA1281EA0749407D5D86FF74C1444017BA1281EA074940
56042	20603	41.108460999999998	41.118541	49.717028999999997	49.708938000000003	Придонская	0103000020E610000001000000050000001BF2CF0CE28D44402272FA7ABEDA48401BF2CF0CE28D44404CA4349BC7DB4840191EFB592C8F44404CA4349BC7DB4840191EFB592C8F44402272FA7ABEDA48401BF2CF0CE28D44402272FA7ABEDA4840
55607	19846	41.073436000000001	41.113663000000003	49.823988999999997	49.811177999999998	Петровского	0103000020E61000000100000005000000AE2CD159668944400A9E42AED4E74840AE2CD15966894440C2A1B77878E94840F4E159828C8E4440C2A1B77878E94840F4E159828C8E44400A9E42AED4E74840AE2CD159668944400A9E42AED4E74840
56296	19435	40.734375999999997	40.767147000000001	49.627305999999997	49.602967	Лесная	0103000020E61000000100000005000000D07B6308005E44409BC8CC052ECD4840D07B6308005E4440D34A21904BD04840BD1C76DF31624440D34A21904BD04840BD1C76DF316244409BC8CC052ECD4840D07B6308005E44409BC8CC052ECD4840
56041	21423	41.316052999999997	41.349469999999997	49.989671000000001	49.976551999999998	 Песковатсколопатинская	0103000020E61000000100000005000000BE66B96C74A84440F46BEBA7FFFC4840BE66B96C74A844405A66118AADFE48407077D66EBBAC44405A66118AADFE48407077D66EBBAC4440F46BEBA7FFFC4840BE66B96C74A84440F46BEBA7FFFC4840
56159	20996	41.368712000000002	41.40372	50.163103	50.151474	Парижская	0103000020E6100000010000000500000046D26EF431AF4440DF1802806313494046D26EF431AF44409370218FE0144940DD5ED218ADB344409370218FE0144940DD5ED218ADB34440DF1802806313494046D26EF431AF4440DF18028063134940
56178	19387	40.762070999999999	40.779381999999998	49.600591000000001	49.581139	Павловская	0103000020E61000000100000005000000711DE38A8B6144400FB743C362CA4840711DE38A8B614440CFA2772AE0CC4840A88B14CAC2634440CFA2772AE0CC4840A88B14CAC26344400FB743C362CA4840711DE38A8B6144400FB743C362CA4840
55763	20849	41.467382999999998	41.490837999999997	50.066839999999999	50.053480999999998	Центральная	0103000020E610000001000000050000006ADAC534D3BB44408BFA2477D80649406ADAC534D3BB444046088F368E08494028D192C7D3BE444046088F368E08494028D192C7D3BE44408BFA2477D80649406ADAC534D3BB44408BFA2477D8064940
56152	20249	41.224604999999997	41.264606999999998	49.567259	49.553964999999998	Ермака	0103000020E6100000010000000500000050C24CDBBF9C444077103B53E8C6484050C24CDBBF9C44404BAE62F19BC8484076A565A4DEA144404BAE62F19BC8484076A565A4DEA1444077103B53E8C6484050C24CDBBF9C444077103B53E8C64840
56301	20001	40.912692	40.955730000000003	49.563308999999997	49.536510999999997	Назаровская	0103000020E6100000010000000500000011A96917D3744440DD787764ACC4484011A96917D37444406F4562821AC848402EE7525C557A44406F4562821AC848402EE7525C557A4440DD787764ACC4484011A96917D3744440DD787764ACC44840
56154	20124	41.142032	41.210160000000002	49.626080999999999	49.593390999999997	Мрыховская	0103000020E61000000100000005000000247EC51A2E924440D05E7D3CF4CB4840247EC51A2E924440D0D2156C23D04840B476DB85E69A4440D0D2156C23D04840B476DB85E69A4440D05E7D3CF4CB4840247EC51A2E924440D05E7D3CF4CB4840
56160	19241	40.853448	40.872393000000002	49.653751	49.647258999999998	Степная	0103000020E61000000100000005000000166BB8C83D6D444055850662D9D24840166BB8C83D6D4440185DDE1CAED348403221E692AA6F4440185DDE1CAED348403221E692AA6F444055850662D9D24840166BB8C83D6D444055850662D9D24840
41155	20452	41.248949000000003	41.269582999999997	49.709071999999999	49.679440999999997	Карла Маркса	0103000020E610000001000000050000009BAF928FDD9F4440E04735ECF7D648409BAF928FDD9F444031410DDFC2DA48405E471CB281A2444031410DDFC2DA48405E471CB281A24440E04735ECF7D648409BAF928FDD9F4440E04735ECF7D64840
55727	20213	41.189382000000002	41.251752000000003	49.594330999999997	49.556798999999998	Плешакова	0103000020E61000000100000005000000BD395CAB3D98444006B98B3045C74840BD395CAB3D984440DEFFC70913CC4840EF59D76839A04440DEFFC70913CC4840EF59D76839A0444006B98B3045C74840BD395CAB3D98444006B98B3045C74840
41153	19981	40.935310999999999	41.034979	49.554577999999999	49.516378000000003	Победы	0103000020E61000000100000005000000664B5645B8774440DC2F9FAC18C24840664B5645B8774440618A7269FCC64840FD851E317A844440618A7269FCC64840FD851E317A844440DC2F9FAC18C24840664B5645B8774440DC2F9FAC18C24840
56297	19904	41.029696999999999	41.065055000000001	49.528202999999998	49.507919999999999	Меловатская	0103000020E6100000010000000500000008E57D1CCD834440FE7DC68503C1484008E57D1CCD8344401553E9279CC348407CB8E4B8538844401553E9279CC348407CB8E4B853884440FE7DC68503C1484008E57D1CCD834440FE7DC68503C14840
56176	19161	40.879598000000001	40.901166000000003	49.683323000000001	49.66816	Макаровская	0103000020E6100000010000000500000042D0D1AA96704440683F524486D5484042D0D1AA9670444064CDC82077D74840322251685973444064CDC82077D748403222516859734440683F524486D5484042D0D1AA96704440683F524486D54840
55544	19814	41.109495000000003	41.146343000000002	49.828673000000002	49.798428000000001	Школьная	0103000020E61000000100000005000000AB09A2EE038E4440F81A82E332E64840AB09A2EE038E4440030AF5F411EA4840D07F0F5EBB924440030AF5F411EA4840D07F0F5EBB924440F81A82E332E64840AB09A2EE038E4440F81A82E332E64840
56155	20519	41.099460000000001	41.146577000000001	49.649697000000003	49.622228999999997	Центральная	0103000020E610000001000000050000004DA1F31ABB8C4440B7CF2A33A5CF48404DA1F31ABB8C444098A7734529D3484043ACFE08C392444098A7734529D3484043ACFE08C3924440B7CF2A33A5CF48404DA1F31ABB8C4440B7CF2A33A5CF4840
56151	19773	41.145077000000001	41.169322000000001	49.976962999999998	49.952823000000002	Колодезная	0103000020E610000001000000050000006E3315E29192444035F0A31AF6F948406E3315E2919244407633A31F0DFD4840253FE257AC9544407633A31F0DFD4840253FE257AC95444035F0A31AF6F948406E3315E29192444035F0A31AF6F94840
56140	56817	41.346093000000003	41.361984	50.024124999999998	50.021022000000002	Семиренко	0103000020E61000000100000005000000F12F82C64CAC44408E3F51D9B0024940F12F82C64CAC44400C022B87160349406FD6E07D55AE44400C022B87160349406FD6E07D55AE44408E3F51D9B0024940F12F82C64CAC44408E3F51D9B0024940
56294	19675	41.228701000000001	41.259099999999997	49.944828999999999	49.919170000000001	Лопатинская	0103000020E6100000010000000500000000C80913469D44406FBBD05CA7F5484000C80913469D4440FCA71B28F0F84840613255302AA14440FCA71B28F0F84840613255302AA144406FBBD05CA7F5484000C80913469D44406FBBD05CA7F54840
40250	19483	41.129795999999999	41.172341000000003	49.802439999999997	49.780800999999997	Матросова	0103000020E610000001000000050000006893C3279D90444090D78349F1E348406893C3279D90444049809A5AB6E64840466117450F96444049809A5AB6E64840466117450F96444090D78349F1E348406893C3279D90444090D78349F1E34840
41150	19483	41.129795999999999	41.172341000000003	49.802439999999997	49.780800999999997	Коммунальная	0103000020E610000001000000050000006893C3279D90444090D78349F1E348406893C3279D90444049809A5AB6E64840466117450F96444049809A5AB6E64840466117450F96444090D78349F1E348406893C3279D90444090D78349F1E34840
56182	21096	41.196820000000002	41.215288999999999	49.776600999999999	49.763609000000002	Заикинская	0103000020E610000001000000050000007099D3653199444034F790F0BDE148407099D365319944403C855CA967E34840221807978E9B44403C855CA967E34840221807978E9B444034F790F0BDE148407099D3653199444034F790F0BDE14840
56190	20719	41.389023000000002	41.422764000000001	49.763528000000001	49.748448000000003	Дубровская	0103000020E6100000010000000500000027327381CBB14440D960E124CDDF484027327381CBB1444047CA1649BBE148408CF678211DB6444047CA1649BBE148408CF678211DB64440D960E124CDDF484027327381CBB14440D960E124CDDF4840
56029	21212	41.161372	41.173751000000003	49.771982000000001	49.758831000000001	Гормиловская	0103000020E61000000100000005000000BC3E73D6A79444407218CC5F21E14840BC3E73D6A7944440E38C614ED0E24840DB5207793D964440E38C614ED0E24840DB5207793D9644407218CC5F21E14840BC3E73D6A79444407218CC5F21E14840
56292	19300	40.760247999999997	40.891697999999998	49.591143000000002	49.570442999999997	Мира	0103000020E61000000100000005000000B96C74CE4F614440B69DB64604C94840B96C74CE4F6144403221E692AACB48404DF4F928237244403221E692AACB48404DF4F92823724440B69DB64604C94840B96C74CE4F614440B69DB64604C94840
55726	19300	40.760247999999997	40.891697999999998	49.591143000000002	49.570442999999997	Административная	0103000020E61000000100000005000000B96C74CE4F614440B69DB64604C94840B96C74CE4F6144403221E692AACB48404DF4F928237244403221E692AACB48404DF4F92823724440B69DB64604C94840B96C74CE4F614440B69DB64604C94840
56100	20682	41.443568999999997	41.518892999999998	49.897728000000001	49.862551000000003	Быковская	0103000020E610000001000000050000007C4276DEC6B84440E910381268EE48407C4276DEC6B844400C5A48C0E8F24840C98FF8156BC244400C5A48C0E8F24840C98FF8156BC24440E910381268EE48407C4276DEC6B84440E910381268EE4840
56153	20354	41.123804999999997	41.177137999999999	49.546559999999999	49.525255999999999	Бирюковская	0103000020E61000000100000005000000670A9DD7D88F44408E03AF963BC34840670A9DD7D88F4440A0A696ADF5C548407E703E75AC964440A0A696ADF5C548407E703E75AC9644408E03AF963BC34840670A9DD7D88F44408E03AF963BC34840
56025	20424	41.124217999999999	41.154328999999997	49.472498999999999	49.437666999999998	Центральная	0103000020E610000001000000050000008AC91B60E68F4440EBC4E57805B848408AC91B60E68F44404432E4D87ABC484085E97B0DC19344404432E4D87ABC484085E97B0DC1934440EBC4E57805B848408AC91B60E68F4440EBC4E57805B84840
56291	18555	41.385367000000002	41.427596999999999	49.287350000000004	49.264915000000002	Казачья	0103000020E6100000010000000500000094FAB2B453B14440249C16BCE8A1484094FAB2B453B14440B84082E2C7A44840116F9D7FBBB64440B84082E2C7A44840116F9D7FBBB64440249C16BCE8A1484094FAB2B453B14440249C16BCE8A14840
56255	31367	41.902509000000002	41.922353000000001	49.179625999999999	49.165779000000001	Луговая	0103000020E610000001000000050000003FAC376A85F344408AAE0B3F389548403FAC376A85F3444072C119FCFD9648400A2FC1A90FF6444072C119FCFD9648400A2FC1A90FF644408AAE0B3F389548403FAC376A85F344408AAE0B3F38954840
56147	18801	41.772315999999996	41.816693000000001	49.303659000000003	49.278399	Школьная	0103000020E61000000100000005000000B9162D40DBE244409B1E1494A2A34840B9162D40DBE244406B11514CDEA64840A2EF6E6589E844406B11514CDEA64840A2EF6E6589E844409B1E1494A2A34840B9162D40DBE244409B1E1494A2A34840
56172	18383	41.704754000000001	41.723978000000002	49.203265999999999	49.178814000000003	Школьная	0103000020E61000000100000005000000D3DC0A6135DA444092088D60E3964840D3DC0A6135DA4440C231CB9E049A48400283A44FABDC4440C231CB9E049A48400283A44FABDC444092088D60E3964840D3DC0A6135DA444092088D60E3964840
56173	18343	41.707493999999997	41.755087000000003	49.147638000000001	49.127426999999997	Центральная	0103000020E61000000100000005000000E00ED4298FDA44404ED026874F904840E00ED4298FDA4440CCD24ECDE59248404051D9B0A6E04440CCD24ECDE59248404051D9B0A6E044404ED026874F904840E00ED4298FDA44404ED026874F904840
56175	18983	41.575082000000002	41.607979	49.389482999999998	49.364607999999997	 Школьная	0103000020E61000000100000005000000574277499CC9444013EE9579ABAE4840574277499CC944408AAC3594DAB14840D0D38041D2CD44408AAC3594DAB14840D0D38041D2CD444013EE9579ABAE4840574277499CC9444013EE9579ABAE4840
56145	18650	41.690426000000002	41.728434	49.350952999999997	49.325237000000001	Кривошлыкова	0103000020E61000000100000005000000702711E15FD844407E39B35DA1A94840702711E15FD844406FB72407ECAC4840B1A547533DDD44406FB72407ECAC4840B1A547533DDD44407E39B35DA1A94840702711E15FD844407E39B35DA1A94840
56287	17926	41.940157999999997	41.969290000000001	49.161625999999998	49.145104000000003	Лазоревая	0103000020E610000001000000050000005089EB1857F84440684293C4929248405089EB1857F8444076172829B0944840802BD9B111FC444076172829B0944840802BD9B111FC4440684293C4929248405089EB1857F84440684293C492924840
56174	18484	41.524434999999997	41.556406000000003	49.277565000000003	49.257694999999998	Школьная	0103000020E610000001000000050000005AF0A2AF20C34440DEAB5626FCA048405AF0A2AF20C34440D3C1FA3F87A348402BA6D24F38C74440D3C1FA3F87A348402BA6D24F38C74440DEAB5626FCA048405AF0A2AF20C34440DEAB5626FCA04840
56293	18778	41.796993000000001	41.84393	49.272486000000001	49.253515	Коньковская	0103000020E610000001000000050000000A12DBDD03E64440D105F52D73A048400A12DBDD03E64440164F3DD2E0A24840800EF3E505EC4440164F3DD2E0A24840800EF3E505EC4440D105F52D73A048400A12DBDD03E64440D105F52D73A04840
56295	18715	41.496668	41.569082000000002	49.351891999999999	49.318795000000001	Школьная	0103000020E61000000100000005000000207C28D192BF44406D904946CEA84840207C28D192BF4440ADDC0BCC0AAD4840035FD1ADD7C84440ADDC0BCC0AAD4840035FD1ADD7C844406D904946CEA84840207C28D192BF44406D904946CEA84840
55543	18627	41.610072000000002	41.690480000000001	49.363024000000003	49.338510999999997	Советская	0103000020E61000000100000005000000481ADCD616CE44400A2B155454AB4840481ADCD616CE4440E1D4079277AE484063450DA661D84440E1D4079277AE484063450DA661D844400A2B155454AB4840481ADCD616CE44400A2B155454AB4840
56166	18061	42.023566000000002	42.035998999999997	49.188187999999997	49.170068000000001	Песчаная	0103000020E6100000010000000500000016A6EF35040345404E0CC9C9C495484016A6EF3504034540F4BF5C8B1698484027D87F9D9B044540F4BF5C8B1698484027D87F9D9B0445404E0CC9C9C495484016A6EF35040345404E0CC9C9C4954840
56142	18011	41.990571000000003	42.009759000000003	49.141657000000002	49.132114000000001	Магрицкого	0103000020E61000000100000005000000DAAED007CBFE444000AC8E1CE9904840DAAED007CBFE4440EF1F0BD121924840BCEB6CC83F014540EF1F0BD121924840BCEB6CC83F01454000AC8E1CE9904840DAAED007CBFE444000AC8E1CE9904840
55541	18449	41.810530999999997	41.854422	49.217702000000003	49.190537999999997	Школьная	0103000020E6100000010000000500000074B2D47ABFE744409752978C6398484074B2D47ABFE744400C23BDA8DD9B4840D07D39B35DED44400C23BDA8DD9B4840D07D39B35DED44409752978C6398484074B2D47ABFE744409752978C63984840
56288	18203	41.865228999999999	41.910181000000001	49.237575999999997	49.223103999999999	Песчаная	0103000020E610000001000000050000008046E9D2BFEE4440ABCDFFAB8E9C48408046E9D2BFEE44404128EFE3689E484065389ECF80F444404128EFE3689E484065389ECF80F44440ABCDFFAB8E9C48408046E9D2BFEE4440ABCDFFAB8E9C4840
56150	18883	41.751618999999998	41.781011999999997	49.385519000000002	49.340788000000003	Грушинская	0103000020E61000000100000005000000AF06280D35E04440446FF1F09EAB4840AF06280D35E044404A7EC4AF58B148404BE48233F8E344404A7EC4AF58B148404BE48233F8E34440446FF1F09EAB4840AF06280D35E04440446FF1F09EAB4840
55751	19024	41.511122	41.554583000000001	49.424238000000003	49.399357000000002	Школьная	0103000020E61000000100000005000000102219726CC14440DF3653211EB34840102219726CC1444038DC476E4DB6484073F56393FCC6444038DC476E4DB6484073F56393FCC64440DF3653211EB34840102219726CC14440DF3653211EB34840
56124	31466	42.012597999999997	42.034013999999999	49.358035999999998	49.340916999999997	Луговая	0103000020E610000001000000050000005CFFAECF9C01454041D3122BA3AB48405CFFAECF9C0145403465A71FD4AD484096CD1C925A0445403465A71FD4AD484096CD1C925A04454041D3122BA3AB48405CFFAECF9C01454041D3122BA3AB4840
56027	19156	41.277119999999996	41.346192000000002	49.423335999999999	49.397821	Мира	0103000020E61000000100000005000000A4880CAB78A34440BD546CCCEBB24840A4880CAB78A34440179CC1DF2FB648408411FB0450AC4440179CC1DF2FB648408411FB0450AC4440BD546CCCEBB24840A4880CAB78A34440BD546CCCEBB24840
55968	31383	41.745384999999999	41.766171999999997	49.167264000000003	49.152788000000001	Кристальная	0103000020E61000000100000005000000E8F692C668DF4440529CA38E8E934840E8F692C668DF44402AE620E868954840328E91EC11E244402AE620E868954840328E91EC11E24440529CA38E8E934840E8F692C668DF4440529CA38E8E934840
56149	19077	41.400432000000002	41.454510999999997	49.449950000000001	49.432535000000001	Школьная	0103000020E61000000100000005000000CD22145B41B344400CB08F4E5DB74840CD22145B41B34440E86A2BF697B948400C569C6A2DBA4440E86A2BF697B948400C569C6A2DBA44400CB08F4E5DB74840CD22145B41B344400CB08F4E5DB74840
40080	18253	41.814698999999997	41.848934	49.242482000000003	49.211405999999997	Теличенко переулок	0103000020E61000000100000005000000BD8A8C0E48E84440CE16105A0F9B4840BD8A8C0E48E8444031EF71A6099F4840323B8BDEA9EC444031EF71A6099F4840323B8BDEA9EC4440CE16105A0F9B4840BD8A8C0E48E84440CE16105A0F9B4840
40243	18253	41.814698999999997	41.848934	49.242482000000003	49.211405999999997	Октябрьская	0103000020E61000000100000005000000BD8A8C0E48E84440CE16105A0F9B4840BD8A8C0E48E8444031EF71A6099F4840323B8BDEA9EC444031EF71A6099F4840323B8BDEA9EC4440CE16105A0F9B4840BD8A8C0E48E84440CE16105A0F9B4840
56024	18085	41.977321000000003	42.013621999999998	49.315593999999997	49.284199999999998	Центральная	0103000020E61000000100000005000000D658C2DA18FD4440F8C264AA60A44840D658C2DA18FD44402B685A6265A84840C8409E5DBE0145402B685A6265A84840C8409E5DBE014540F8C264AA60A44840D658C2DA18FD4440F8C264AA60A44840
55893	56746	40.704048999999998	40.715052999999997	48.249276000000002	48.236358000000003	Старцева	0103000020E6100000010000000500000008E412471E5A4440F1129CFA401E484008E412471E5A4440BFD6A546E81F48400EF450DB865B4440BFD6A546E81F48400EF450DB865B4440F1129CFA401E484008E412471E5A4440F1129CFA401E4840
39635	54809	40.633226000000001	40.831583000000002	48.363872999999998	48.136080999999997	Космонавтов	0103000020E610000001000000050000000B7DB08C0D514440B14D2A1A6B1148400B7DB08C0D514440DE72F563932E48406D74CE4F716A4440DE72F563932E48406D74CE4F716A4440B14D2A1A6B1148400B7DB08C0D514440B14D2A1A6B114840
55744	6745	40.743009000000001	40.778177999999997	48.034979999999997	48.020083999999997	Строителей	0103000020E610000001000000050000001CD13DEB1A5F44402096CD1C920248401CD13DEB1A5F4440CD0182397A044840BC3B32569B634440CD0182397A044840BC3B32569B6344402096CD1C920248401CD13DEB1A5F44402096CD1C92024840
40369	7392	41.028672999999998	41.064757999999998	48.290975000000003	48.270535000000002	Пушкина	0103000020E610000001000000050000009CA38E8EAB83444031B610E4A02248409CA38E8EAB834440107A36AB3E254840C2137AFD49884440107A36AB3E254840C2137AFD4988444031B610E4A02248409CA38E8EAB83444031B610E4A0224840
40091	7392	41.028672999999998	41.064757999999998	48.290975000000003	48.270535000000002	Октябрьская	0103000020E610000001000000050000009CA38E8EAB83444031B610E4A02248409CA38E8EAB834440107A36AB3E254840C2137AFD49884440107A36AB3E254840C2137AFD4988444031B610E4A02248409CA38E8EAB83444031B610E4A0224840
40367	7392	41.028672999999998	41.064757999999998	48.290975000000003	48.270535000000002	Максима Горького	0103000020E610000001000000050000009CA38E8EAB83444031B610E4A02248409CA38E8EAB834440107A36AB3E254840C2137AFD49884440107A36AB3E254840C2137AFD4988444031B610E4A02248409CA38E8EAB83444031B610E4A0224840
39888	7392	41.028672999999998	41.064757999999998	48.290975000000003	48.270535000000002	Железнодорожная	0103000020E610000001000000050000009CA38E8EAB83444031B610E4A02248409CA38E8EAB834440107A36AB3E254840C2137AFD49884440107A36AB3E254840C2137AFD4988444031B610E4A02248409CA38E8EAB83444031B610E4A0224840
56447	56914	40.731878999999999	40.748092999999997	47.920378999999997	47.900272999999999	Центральная	0103000020E6100000010000000500000089D00836AE5D4440643C4A253CF3474089D00836AE5D44406C76A4FACEF54740EAAEEC82C15F44406C76A4FACEF54740EAAEEC82C15F4440643C4A253CF3474089D00836AE5D4440643C4A253CF34740
55769	56694	40.764837999999997	40.788715000000003	48.058677000000003	48.037016000000001	пер. Школьный	0103000020E61000000100000005000000785E2A36E6614440E1B6B6F0BC044840785E2A36E661444082035ABA82074840AD6EF59CF464444082035ABA82074840AD6EF59CF4644440E1B6B6F0BC044840785E2A36E6614440E1B6B6F0BC044840
56574	57023	40.956440000000001	40.979678999999997	47.979472000000001	47.972794999999998	Верхняя	0103000020E610000001000000050000000A4B3CA06C7A44402D5BEB8B84FC47400A4B3CA06C7A444082ACA7565FFD4740FBC9181F667D444082ACA7565FFD4740FBC9181F667D44402D5BEB8B84FC47400A4B3CA06C7A44402D5BEB8B84FC4740
55651	6493	40.878402999999999	40.891131999999999	47.994875	47.983936	Бурденко	0103000020E61000000100000005000000A9DA6E826F704440B4AD669DF1FD4740A9DA6E826F704440D34D621058FF4740A435069D10724440D34D621058FF4740A435069D10724440B4AD669DF1FD4740A9DA6E826F704440B4AD669DF1FD4740
41024	12799	40.838365000000003	40.846027999999997	48.181705000000001	48.176803	Пролетарская	0103000020E61000000100000005000000378E588B4F6B4440D76A0F7BA1164840378E588B4F6B44408542041C4217484009C03FA54A6C44408542041C4217484009C03FA54A6C4440D76A0F7BA1164840378E588B4F6B4440D76A0F7BA1164840
41226	6501	40.810094999999997	40.889183000000003	48.022646000000002	47.995730999999999	микрорайон Юбилейный	0103000020E6100000010000000500000099D36531B1674440834E081D74FF474099D36531B16744404FB16A10E60248406094A0BFD07144404FB16A10E60248406094A0BFD0714440834E081D74FF474099D36531B1674440834E081D74FF4740
39636	6501	40.810094999999997	40.889183000000003	48.022646000000002	47.995730999999999	Маяковского	0103000020E6100000010000000500000099D36531B1674440834E081D74FF474099D36531B16744404FB16A10E60248406094A0BFD07144404FB16A10E60248406094A0BFD0714440834E081D74FF474099D36531B1674440834E081D74FF4740
40387	6501	40.810094999999997	40.889183000000003	48.022646000000002	47.995730999999999	Горького	0103000020E6100000010000000500000099D36531B1674440834E081D74FF474099D36531B16744404FB16A10E60248406094A0BFD07144404FB16A10E60248406094A0BFD0714440834E081D74FF474099D36531B1674440834E081D74FF4740
55649	6501	40.810094999999997	40.889183000000003	48.022646000000002	47.995730999999999	Белинского	0103000020E6100000010000000500000099D36531B1674440834E081D74FF474099D36531B16744404FB16A10E60248406094A0BFD07144404FB16A10E60248406094A0BFD0714440834E081D74FF474099D36531B1674440834E081D74FF4740
56303	6751	40.588687	40.601658999999998	48.237395999999997	48.225932	Почтовая	0103000020E61000000100000005000000494A7A185A4B4440588FFB56EB1C4840494A7A185A4B4440C119FCFD621E48400A2C8029034D4440C119FCFD621E48400A2C8029034D4440588FFB56EB1C4840494A7A185A4B4440588FFB56EB1C4840
56515	56973	40.891806000000003	40.916581000000001	48.293984000000002	48.274163000000001	Школьная	0103000020E610000001000000050000003430F2B226724440FA62EFC5172348403430F2B2267244400DC68844A12548404791B586527544400DC68844A12548404791B58652754440FA62EFC5172348403430F2B226724440FA62EFC517234840
56480	56942	40.556815	40.565322000000002	48.176760999999999	48.174188999999998	Вокзальная	0103000020E610000001000000050000000C76C3B64547444056293DD34B1648400C76C3B645474440A81ABD1AA0164840CBDAA6785C484440A81ABD1AA0164840CBDAA6785C48444056293DD34B1648400C76C3B64547444056293DD34B164840
56321	56844	40.872681	40.894537	48.225451999999997	48.205274000000003	Ефремовой	0103000020E61000000100000005000000986BD102B46F44400C5C1E6B461A4840986BD102B46F4440AD68739CDB1C4840EE073C3080724440AD68739CDB1C4840EE073C30807244400C5C1E6B461A4840986BD102B46F44400C5C1E6B461A4840
56426	56896	41.022995999999999	41.051355999999998	47.986576999999997	47.964705000000002	Центральная	0103000020E610000001000000050000002BF86D88F1824440D3A414747BFB47402BF86D88F18244402EFEB62748FE4740083A5AD5928644402EFEB62748FE4740083A5AD592864440D3A414747BFB47402BF86D88F1824440D3A414747BFB4740
55908	56755	40.867057000000003	40.879722999999998	48.172818999999997	48.164382000000003	Молодежная	0103000020E610000001000000050000004A6249B9FB6E44408A0629780A1548404A6249B9FB6E44404F90D8EE1E164840FE4465C39A7044404F90D8EE1E164840FE4465C39A7044408A0629780A1548404A6249B9FB6E44408A0629780A154840
56429	56899	41.016609000000003	41.039444000000003	48.038136999999999	48.025796999999997	Центральная	0103000020E61000000100000005000000DEE8633E20824440DEAAEB504D034840DEE8633E208244403FE257ACE1044840000341800C8544403FE257ACE1044840000341800C854440DEAAEB504D034840DEE8633E20824440DEAAEB504D034840
56330	56845	40.630727999999998	40.648873999999999	48.072526000000003	48.057411999999999	Шляхтная	0103000020E61000000100000005000000F355F2B1BB504440F032C34659074840F355F2B1BB5044400B0E2F8848094840C39CA04D0E5344400B0E2F8848094840C39CA04D0E534440F032C34659074840F355F2B1BB504440F032C34659074840
56135	31244	40.901642000000002	40.917093000000001	48.019277000000002	48.001223000000003	Береговая	0103000020E610000001000000050000009B594B016973444063804413280048409B594B0169734440524832AB77024840FD31AD4D63754440524832AB77024840FD31AD4D6375444063804413280048409B594B01697344406380441328004840
55942	56791	41.216420999999997	41.240459999999999	48.579607000000003	48.567774	Центральная	0103000020E610000001000000050000007495EEAEB39B444072C284D1AC4848407495EEAEB39B44402FC4EA8F304A484082FFAD64C79E44402FC4EA8F304A484082FFAD64C79E444072C284D1AC4848407495EEAEB39B444072C284D1AC484840
41022	12480	40.869123000000002	40.903672999999998	48.405614999999997	48.378956000000002	Школьная	0103000020E61000000100000005000000C899266C3F6F4440BE4F55A181304840C899266C3F6F44402EE23B31EB3348409CA38E8EAB7344402EE23B31EB3348409CA38E8EAB734440BE4F55A181304840C899266C3F6F4440BE4F55A181304840
55336	56652	40.869715999999997	40.895344999999999	48.311526999999998	48.286833000000001	Ленина	0103000020E610000001000000050000006A6798DA526F4440F03499F1B62448406A6798DA526F44401669E21DE02748408DD13AAA9A7244401669E21DE02748408DD13AAA9A724440F03499F1B62448406A6798DA526F4440F03499F1B6244840
55906	56759	40.884368000000002	40.903700000000001	48.254705999999999	48.237504000000001	Центральная	0103000020E6100000010000000500000081D07AF832714440A855F487661E484081D07AF832714440280CCA349A20484096B20C71AC734440280CCA349A20484096B20C71AC734440A855F487661E484081D07AF832714440A855F487661E4840
55746	13003	40.890934000000001	40.927855000000001	48.032552000000003	48.018161999999997	Центральная	0103000020E610000001000000050000007E7214200A724440D503E621530248407E7214200A724440AFB5F7A92A0448400D37E0F3C3764440AFB5F7A92A0448400D37E0F3C3764440D503E621530248407E7214200A724440D503E62153024840
55870	56726	40.921145000000003	40.950789	48.430137999999999	48.413097	Центральная	0103000020E61000000100000005000000DDEF5014E8754440B189CC5CE0344840DDEF5014E8754440286211C30E374840C2323674B3794440286211C30E374840C2323674B3794440B189CC5CE0344840DDEF5014E8754440B189CC5CE0344840
9823	6801	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	Щаденко	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
55718	6801	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	Чехов	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
55738	6801	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	Тургенева	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
55625	6801	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	Отечественная	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
40208	6801	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	К. Маркса	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
56307	6801	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	Дзержинского	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
39638	6801	40.592775000000003	40.736288999999999	48.224330000000002	48.183520000000001	Горноспасательная	0103000020E6100000010000000500000076711B0DE04B4440BA1457957D17484076711B0DE04B44407FC16ED8B61C4840C8B3CBB73E5E44407FC16ED8B61C4840C8B3CBB73E5E4440BA1457957D17484076711B0DE04B4440BA1457957D174840
56509	56968	40.733981	40.758387999999997	48.142904999999999	48.129195000000003	Центральная	0103000020E610000001000000050000005471E316F35D444043E73576891048405471E316F35D4440AAB706B64A124840E4D6A4DB12614440AAB706B64A124840E4D6A4DB1261444043E73576891048405471E316F35D444043E7357689104840
55904	56757	41.076076999999998	41.104903999999998	48.554667999999999	48.525784000000002	Школьная	0103000020E61000000100000005000000287D21E4BC8944404A61DEE34C434840287D21E4BC894440A1116C5CFF4648401B9C887E6D8D4440A1116C5CFF4648401B9C887E6D8D44404A61DEE34C434840287D21E4BC8944404A61DEE34C434840
56458	56924	41.161704999999998	41.172359	48.564726999999998	48.560327000000001	Садовая	0103000020E61000000100000005000000C24CDBBFB29444406C088ECBB8474840C24CDBBFB294444087156EF948484840EC1516DC0F96444087156EF948484840EC1516DC0F9644406C088ECBB8474840C24CDBBFB29444406C088ECBB8474840
56127	56815	40.818880999999998	40.839810999999997	48.153016999999998	48.146752999999997	Терновой	0103000020E610000001000000050000006B28B517D168444081CB63CDC81248406B28B517D1684440B35DA10F9613484018E945ED7E6B4440B35DA10F9613484018E945ED7E6B444081CB63CDC81248406B28B517D168444081CB63CDC8124840
56560	57012	41.028035000000003	41.046433	48.465367999999998	48.452725000000001	Центральная	0103000020E610000001000000050000005A12A0A696834440728A8EE4F23948405A12A0A6968344406E4DBA2D913B4840433A3C84F18544406E4DBA2D913B4840433A3C84F1854440728A8EE4F23948405A12A0A696834440728A8EE4F2394840
55915	56767	40.650005999999998	40.679516	47.927630000000001	47.916176	Центральная	0103000020E61000000100000005000000151A886533534440A7B0524145F54740151A886533534440ED647094BCF64740EB8D5A61FA564440ED647094BCF64740EB8D5A61FA564440A7B0524145F54740151A886533534440A7B0524145F54740
41000	7246	40.911003000000001	40.992731999999997	48.302933000000003	48.278235000000002	Театральная	0103000020E6100000010000000500000069C70DBF9B74444021CD58349D23484069C70DBF9B74444089F02F82C6264840A9D898D7117F444089F02F82C6264840A9D898D7117F444021CD58349D23484069C70DBF9B74444021CD58349D234840
40376	7246	40.911003000000001	40.992731999999997	48.302933000000003	48.278235000000002	Майская	0103000020E6100000010000000500000069C70DBF9B74444021CD58349D23484069C70DBF9B74444089F02F82C6264840A9D898D7117F444089F02F82C6264840A9D898D7117F444021CD58349D23484069C70DBF9B74444021CD58349D234840
39891	7246	40.911003000000001	40.992731999999997	48.302933000000003	48.278235000000002	Дзержинского	0103000020E6100000010000000500000069C70DBF9B74444021CD58349D23484069C70DBF9B74444089F02F82C6264840A9D898D7117F444089F02F82C6264840A9D898D7117F444021CD58349D23484069C70DBF9B74444021CD58349D234840
55846	56704	40.767614000000002	40.784089000000002	47.875450999999998	47.861584999999998	Центральная	0103000020E61000000100000005000000D3F9F02C41624440B1DCD26A48EE4740D3F9F02C41624440102043C70EF04740A11342075D644440102043C70EF04740A11342075D644440B1DCD26A48EE4740D3F9F02C41624440B1DCD26A48EE4740
56547	56999	41.011381	41.034854000000003	48.498703999999996	48.482396999999999	Школьная	0103000020E61000000100000005000000DC65BFEE748144402158552FBF3D4840DC65BFEE7481444033315D88D53F484041118B187684444033315D88D53F484041118B18768444402158552FBF3D4840DC65BFEE748144402158552FBF3D4840
55501	6396	40.906978000000002	40.919375000000002	47.999504999999999	47.992221000000001	Матросова	0103000020E610000001000000050000008318E8DA17744440C4B3041901FF47408318E8DA177444402098A3C7EFFF474048E17A14AE7544402098A3C7EFFF474048E17A14AE754440C4B3041901FF47408318E8DA17744440C4B3041901FF4740
55434	56636	40.666688000000001	40.735481	48.161864000000001	48.137807000000002	Центральная	0103000020E610000001000000050000005D514A08565544407714E7A8A31148405D514A08565544402B33A5F5B714484029EACC3D245E44402B33A5F5B714484029EACC3D245E44407714E7A8A31148405D514A08565544407714E7A8A3114840
55284	56636	40.666688000000001	40.735481	48.161864000000001	48.137807000000002	Заречная	0103000020E610000001000000050000005D514A08565544407714E7A8A31148405D514A08565544402B33A5F5B714484029EACC3D245E44402B33A5F5B714484029EACC3D245E44407714E7A8A31148405D514A08565544407714E7A8A3114840
56205	56822	40.778770999999999	40.805568000000001	48.102752000000002	48.091475000000003	Станкевского	0103000020E610000001000000050000005F09A4C4AE63444068B3EA73B50B48405F09A4C4AE6344409FCC3FFA260D4840215A2BDA1C6744409FCC3FFA260D4840215A2BDA1C67444068B3EA73B50B48405F09A4C4AE63444068B3EA73B50B4840
55897	56750	41.078457999999998	41.104194	48.154074999999999	48.128076999999998	Шоссейная	0103000020E61000000100000005000000060E68E90A8A4440552FBFD364104840060E68E90A8A4440CB10C7BAB81348403F389F3A568D4440CB10C7BAB81348403F389F3A568D4440552FBFD364104840060E68E90A8A4440552FBFD364104840
56069	11522	40.149203999999997	40.158700000000003	47.145173999999997	47.138818000000001	Центральная	0103000020E610000001000000050000005837DE1D191344404E0CC9C9C49147405837DE1D19134440601DC70F9592474007F0164850144440601DC70F9592474007F01648501444404E0CC9C9C49147405837DE1D191344404E0CC9C9C4914740
55512	56667	40.281453999999997	40.312725	47.163294	47.141435000000001	Братская	0103000020E6100000010000000500000008AA46AF0624444040C1C58A1A92474008AA46AF0624444007D15AD1E694474020D26F5F0728444007D15AD1E694474020D26F5F0728444040C1C58A1A92474008AA46AF0624444040C1C58A1A924740
56533	56987	40.456733999999997	40.474978999999998	47.210743000000001	47.199165999999998	Береговая	0103000020E61000000100000005000000527C7C42763A4440D13C80457E994740527C7C42763A4440336E6AA0F99A4740B5A4A31CCC3C4440336E6AA0F99A4740B5A4A31CCC3C4440D13C80457E994740527C7C42763A4440D13C80457E994740
55627	11838	40.388013000000001	40.397544000000003	47.150033999999998	47.143175999999997	Гагарина	0103000020E6100000010000000500000020B6F468AA3144403AC956975392474020B6F468AA314440DFA46950349347404B5CC7B8E2324440DFA46950349347404B5CC7B8E23244403AC956975392474020B6F468AA3144403AC9569753924740
56383	56857	40.226171999999998	40.262445999999997	47.187654000000002	47.179673999999999	Ленина	0103000020E61000000100000005000000ADA23F34F31C444083F8C08EFF964740ADA23F34F31C4440577BD80B05984740A67B9DD497214440577BD80B05984740A67B9DD49721444083F8C08EFF964740ADA23F34F31C444083F8C08EFF964740
55745	11224	40.669527000000002	40.680028	47.339205999999997	47.327584000000002	Школьная	0103000020E61000000100000005000000FE648C0FB3554440B058C345EEA94740FE648C0FB3554440B14D2A1A6BAB4740A12E52280B574440B14D2A1A6BAB4740A12E52280B574440B058C345EEA94740FE648C0FB3554440B058C345EEA94740
55742	11690	40.289988000000001	40.303167000000002	47.220663999999999	47.208747000000002	Школьная	0103000020E61000000100000005000000C11DA8531E254440AE11C138B89A4740C11DA8531E254440C8B3CBB73E9C4740FC1C1F2DCE264440C8B3CBB73E9C4740FC1C1F2DCE264440AE11C138B89A4740C11DA8531E254440AE11C138B89A4740
55736	11893	40.453454999999998	40.472741999999997	47.130726000000003	47.121394000000002	Первомайская	0103000020E61000000100000005000000959A3DD00A3A44401FF7ADD6898F4740959A3DD00A3A4440535E2BA1BB9047400AB952CF823C4440535E2BA1BB9047400AB952CF823C44401FF7ADD6898F4740959A3DD00A3A44401FF7ADD6898F4740
55624	10808	40.221124000000003	40.271124	47.240372999999998	47.216532999999998	Почтовая	0103000020E610000001000000050000002C2E8ECA4D1C44409CC0745AB79B47402C2E8ECA4D1C4440B3EBDE8AC49E47409294F430B4224440B3EBDE8AC49E47409294F430B42244409CC0745AB79B47402C2E8ECA4D1C44409CC0745AB79B4740
56057	10808	40.221124000000003	40.271124	47.240372999999998	47.216532999999998	Поповкина	0103000020E610000001000000050000002C2E8ECA4D1C44409CC0745AB79B47402C2E8ECA4D1C4440B3EBDE8AC49E47409294F430B4224440B3EBDE8AC49E47409294F430B42244409CC0745AB79B47402C2E8ECA4D1C44409CC0745AB79B4740
55853	56710	40.536675000000002	40.560434999999998	47.343004000000001	47.325555999999999	Школьная	0103000020E6100000010000000500000058CA32C4B14444401F82AAD1ABA9474058CA32C4B1444440D732198EE7AB474052448655BC474440D732198EE7AB474052448655BC4744401F82AAD1ABA9474058CA32C4B14444401F82AAD1ABA94740
55321	56649	40.342458999999998	40.367603000000003	47.220236	47.187618000000001	Центральная	0103000020E61000000100000005000000459C4EB2D52B44400A12DBDD03984740459C4EB2D52B444070B378B1309C4740AC74779D0D2F444070B378B1309C4740AC74779D0D2F44400A12DBDD03984740459C4EB2D52B44400A12DBDD03984740
56489	56949	40.573802000000001	40.595883000000001	47.412143999999998	47.397281999999997	Зеленая	0103000020E6100000010000000500000090300C58724944400DA5F622DAB2474090300C58724944400E9F7422C1B44740069FE6E4454C44400E9F7422C1B44740069FE6E4454C44400DA5F622DAB2474090300C58724944400DA5F622DAB24740
55292	56639	40.482559999999999	40.513804	47.324787000000001	47.300685000000001	Советская	0103000020E61000000100000005000000CB2DAD86C43D4440EAB298D87CA64740CB2DAD86C43D44403E95D39E92A94740E9465854C44144403E95D39E92A94740E9465854C4414440EAB298D87CA64740CB2DAD86C43D4440EAB298D87CA64740
56068	11036	40.442109000000002	40.451765999999999	47.257182999999998	47.245823999999999	Центральная	0103000020E61000000100000005000000362218079738444034492C29779F47403622180797384440280B5F5FEBA04740EDB8E177D3394440280B5F5FEBA04740EDB8E177D339444034492C29779F4740362218079738444034492C29779F4740
55901	56754	40.330637000000003	40.352826	47.303165999999997	47.290985999999997	Октябрьская	0103000020E610000001000000050000007DEC2E50522A444003CC7C073FA547407DEC2E50522A44402BA1BB24CEA64740D9960167292D44402BA1BB24CEA64740D9960167292D444003CC7C073FA547407DEC2E50522A444003CC7C073FA54740
39646	10661	40.359886000000003	40.412779	47.336793999999998	47.296602999999998	Фрунзе	0103000020E61000000100000005000000E62494BE102E44409F724C16F7A54740E62494BE102E444098BED7101CAB4740E0BC38F1D534444098BED7101CAB4740E0BC38F1D53444409F724C16F7A54740E62494BE102E44409F724C16F7A54740
39903	10661	40.359886000000003	40.412779	47.336793999999998	47.296602999999998	Спартака	0103000020E61000000100000005000000E62494BE102E44409F724C16F7A54740E62494BE102E444098BED7101CAB4740E0BC38F1D534444098BED7101CAB4740E0BC38F1D53444409F724C16F7A54740E62494BE102E44409F724C16F7A54740
41019	10661	40.359886000000003	40.412779	47.336793999999998	47.296602999999998	Красноармейская	0103000020E61000000100000005000000E62494BE102E44409F724C16F7A54740E62494BE102E444098BED7101CAB4740E0BC38F1D534444098BED7101CAB4740E0BC38F1D53444409F724C16F7A54740E62494BE102E44409F724C16F7A54740
41020	10661	40.359886000000003	40.412779	47.336793999999998	47.296602999999998	Ермаковский	0103000020E61000000100000005000000E62494BE102E44409F724C16F7A54740E62494BE102E444098BED7101CAB4740E0BC38F1D534444098BED7101CAB4740E0BC38F1D53444409F724C16F7A54740E62494BE102E44409F724C16F7A54740
55297	56642	40.159157999999998	40.200659999999999	47.242643000000001	47.215173999999998	Советская	0103000020E61000000100000005000000C972124A5F144440897956D28A9B4740C972124A5F1444403ACD02ED0E9F4740C4CE143AAF1944403ACD02ED0E9F4740C4CE143AAF194440897956D28A9B4740C972124A5F144440897956D28A9B4740
55747	56692	40.560723000000003	40.576785000000001	47.375233000000001	47.356264000000003	Заярного	0103000020E61000000100000005000000B98E71C5C5474440FF5E0A0F9AAD4740B98E71C5C5474440A3B08BA207B0474064E94317D4494440A3B08BA207B0474064E94317D4494440FF5E0A0F9AAD4740B98E71C5C5474440FF5E0A0F9AAD4740
55959	16304	39.721544000000002	39.729125000000003	47.442672999999999	47.438144999999999	Центральная	0103000020E610000001000000050000000150C58D5BDC4340F5F3A62215B847400150C58D5BDC43403EE94482A9B8474017D9CEF753DD43403EE94482A9B8474017D9CEF753DD4340F5F3A62215B847400150C58D5BDC4340F5F3A62215B84740
55490	16101	39.781668000000003	39.808005999999999	47.387027000000003	47.373078999999997	Строителей	0103000020E61000000100000005000000352A70B20DE4434085E97B0DC1AF4740352A70B20DE44340A2D5C9198AB14740637C98BD6CE74340A2D5C9198AB14740637C98BD6CE7434085E97B0DC1AF4740352A70B20DE4434085E97B0DC1AF4740
55859	56716	40.085577000000001	40.109355000000001	47.200482000000001	47.187525999999998	Центральная	0103000020E610000001000000050000001825E82FF40A444029931ADA009847401825E82FF40A4440E5B7E864A9994740B9533A58FF0D4440E5B7E864A9994740B9533A58FF0D444029931ADA009847401825E82FF40A444029931ADA00984740
56023	56803	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Парковый переулок	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
55248	30087	39.870601000000001	39.880285000000001	47.352125000000001	47.344847999999999	Центральная	0103000020E61000000100000005000000B56E83DA6FEF4340A60BB1FA23AC4740B56E83DA6FEF4340508D976E12AD47406614CB2DADF04340508D976E12AD47406614CB2DADF04340A60BB1FA23AC4740B56E83DA6FEF4340A60BB1FA23AC4740
40302	17146	40.026234000000002	40.058698999999997	47.267346000000003	47.232872999999998	Гагарина	0103000020E610000001000000050000008A05BEA25B0344408A8F4FC8CE9D47408A05BEA25B034440B45BCB6438A2474069A7E67283074440B45BCB6438A2474069A7E672830744408A8F4FC8CE9D47408A05BEA25B0344408A8F4FC8CE9D4740
56049	56805	40.071195000000003	40.079154000000003	47.145933999999997	47.139192000000001	Славянская	0103000020E61000000100000005000000C251F2EA1C094440B3EE1F0BD1914740C251F2EA1C094440EEAF1EF7AD9247407EACE0B7210A4440EEAF1EF7AD9247407EACE0B7210A4440B3EE1F0BD1914740C251F2EA1C094440B3EE1F0BD1914740
55972	17255	40.013074000000003	40.033645	47.236984	47.230663999999997	Береговая	0103000020E61000000100000005000000C636A968AC014440A92EE065869D4740C636A968AC0144406FD6E07D559E47404356B77A4E0444406FD6E07D559E47404356B77A4E044440A92EE065869D4740C636A968AC014440A92EE065869D4740
55693	15572	39.881695000000001	39.896732999999998	47.296377	47.285649999999997	Молодежная	0103000020E61000000100000005000000FB05BB61DBF043401B0DE02D90A44740FB05BB61DBF04340AF2479AEEFA547403A1F9E25C8F24340AF2479AEEFA547403A1F9E25C8F243401B0DE02D90A44740FB05BB61DBF043401B0DE02D90A44740
39997	15484	39.934632999999998	39.951385999999999	47.308653	47.300764999999998	Гагарина	0103000020E610000001000000050000009561DC0DA2F743400664AF777FA647409561DC0DA2F74340F96706F181A74740A6EF3504C7F94340F96706F181A74740A6EF3504C7F943400664AF777FA647409561DC0DA2F743400664AF777FA64740
40141	15843	39.865192999999998	39.895682000000001	47.365260999999997	47.357044999999999	Экспериментальная	0103000020E6100000010000000500000033DDEBA4BEEE4340A4198BA6B3AD474033DDEBA4BEEE43408BC058DFC0AE4740D5CE30B5A5F243408BC058DFC0AE4740D5CE30B5A5F24340A4198BA6B3AD474033DDEBA4BEEE4340A4198BA6B3AD4740
40670	15843	39.865192999999998	39.895682000000001	47.365260999999997	47.357044999999999	Комсомольская	0103000020E6100000010000000500000033DDEBA4BEEE4340A4198BA6B3AD474033DDEBA4BEEE43408BC058DFC0AE4740D5CE30B5A5F243408BC058DFC0AE4740D5CE30B5A5F24340A4198BA6B3AD474033DDEBA4BEEE4340A4198BA6B3AD4740
56527	56979	39.947434000000001	39.966101000000002	47.304358000000001	47.295355999999998	Пионерский	0103000020E610000001000000050000002A8F6E8445F94340B456B439CEA547402A8F6E8445F943405323F433F5A6474003D19332A9FB43405323F433F5A6474003D19332A9FB4340B456B439CEA547402A8F6E8445F94340B456B439CEA54740
55863	56720	39.927391999999998	39.940885000000002	47.118493999999998	47.108896999999999	Кирова	0103000020E610000001000000050000003849F3C7B4F64340F6D03E56F08D47403849F3C7B4F64340D862B7CF2A8F4740032670EB6EF84340D862B7CF2A8F4740032670EB6EF84340F6D03E56F08D47403849F3C7B4F64340F6D03E56F08D4740
56103	15790	39.971634999999999	39.984310000000001	47.340806000000001	47.314207000000003	Центральная	0103000020E61000000100000005000000115322895EFC43404F965AEF37A84740115322895EFC4340EA23F0879FAB47401990BDDEFDFD4340EA23F0879FAB47401990BDDEFDFD43404F965AEF37A84740115322895EFC43404F965AEF37A84740
41269	16940	39.926493999999998	39.968823	47.201217	47.173395999999997	Ленина	0103000020E6100000010000000500000059F8FA5A97F64340ECA012D73196474059F8FA5A97F643401A33897AC19947406A4E5E6402FC43401A33897AC19947406A4E5E6402FC4340ECA012D73196474059F8FA5A97F64340ECA012D731964740
40143	16940	39.926493999999998	39.968823	47.201217	47.173395999999997	5-ый	0103000020E6100000010000000500000059F8FA5A97F64340ECA012D73196474059F8FA5A97F643401A33897AC19947406A4E5E6402FC43401A33897AC19947406A4E5E6402FC4340ECA012D73196474059F8FA5A97F64340ECA012D731964740
40301	16018	39.825335000000003	39.843328	47.407277999999998	47.391235999999999	Советская	0103000020E61000000100000005000000419FC893A4E943404982700514B24740419FC893A4E94340AD307DAF21B447408AE6012CF2EB4340AD307DAF21B447408AE6012CF2EB43404982700514B24740419FC893A4E943404982700514B24740
55889	56742	40.001691999999998	40.018346999999999	47.197322999999997	47.190288000000002	Центральная	0103000020E6100000010000000500000019558671370044401F69705B5B9847401955867137004440D2DF4BE141994740677DCA3159024440D2DF4BE141994740677DCA31590244401F69705B5B98474019558671370044401F69705B5B984740
39731	105	40.031875999999997	40.057414999999999	47.368465	47.355257000000002	Просвещения	0103000020E610000001000000050000007EC34483140444406956B60F79AD47407EC34483140444403E5C72DC29AF474061A6ED5F590744403E5C72DC29AF474061A6ED5F590744406956B60F79AD47407EC34483140444406956B60F79AD4740
56427	56897	40.065994000000003	40.076988999999998	47.385002	47.377240999999998	Восточная	0103000020E61000000100000005000000BADDCB7D72084440ECDADE6E49B04740BADDCB7D720844408272DBBE47B147406C938AC6DA0944408272DBBE47B147406C938AC6DA094440ECDADE6E49B04740BADDCB7D72084440ECDADE6E49B04740
40002	14534	39.842187000000003	39.863370000000003	47.121726000000002	47.104444000000001	Онучкина	0103000020E61000000100000005000000E50E9BC8CCEB4340B821C66B5E8D4740E50E9BC8CCEB43405589B2B7948F47407C2C7DE882EE43405589B2B7948F47407C2C7DE882EE4340B821C66B5E8D4740E50E9BC8CCEB4340B821C66B5E8D4740
55694	15954	39.941747999999997	39.954009999999997	47.407339	47.397184000000003	Зеленая	0103000020E610000001000000050000006589CE328BF843404B3FE1ECD6B247406589CE328BF8434053B131AF23B447404A07EBFF1CFA434053B131AF23B447404A07EBFF1CFA43404B3FE1ECD6B247406589CE328BF843404B3FE1ECD6B24740
55580	16177	39.873125000000002	39.890059000000001	47.393317000000003	47.386361999999998	Толстого	0103000020E61000000100000005000000F6285C8FC2EF434065355D4F74B14740F6285C8FC2EF4340FDFA213658B2474057410C74EDF14340FDFA213658B2474057410C74EDF1434065355D4F74B14740F6285C8FC2EF434065355D4F74B14740
56464	56929	40.073306000000002	40.078308999999997	47.293474000000003	47.285938000000002	Центральная	0103000020E61000000100000005000000E04C4C17620944408257CB9D99A44740E04C4C1762094440F81C588E90A54740C1FD8007060A4440F81C588E90A54740C1FD8007060A44408257CB9D99A44740E04C4C17620944408257CB9D99A44740
40142	16006	39.829566	39.842187000000003	47.342955000000003	47.336953000000001	Центральная	0103000020E61000000100000005000000D0EFFB372FEA434001A5A14621AB4740D0EFFB372FEA4340F67F0EF3E5AB4740E50E9BC8CCEB4340F67F0EF3E5AB4740E50E9BC8CCEB434001A5A14621AB4740D0EFFB372FEA434001A5A14621AB4740
56389	56862	40.003264000000001	40.018777999999998	47.390633000000001	47.385136000000003	50-летия Октября	0103000020E6100000010000000500000088A06AF46A0044409241EE224CB1474088A06AF46A00444083DE1B4300B2474030F147516702444083DE1B4300B2474030F14751670244409241EE224CB1474088A06AF46A0044409241EE224CB14740
56437	56903	39.87724	39.910072999999997	47.443525999999999	47.434584999999998	Подтелкова	0103000020E610000001000000050000001C5F7B6649F04340842A357BA0B747401C5F7B6649F043407D76C075C5B847407EFCA5457DF443407D76C075C5B847407EFCA5457DF44340842A357BA0B747401C5F7B6649F04340842A357BA0B74740
55785	56695	39.854979	39.874895000000002	47.088236000000002	47.071275	Истомина	0103000020E6100000010000000500000026E2ADF36FED4340DE02098A1F89474026E2ADF36FED4340392A37514B8B47408B37328FFCEF4340392A37514B8B47408B37328FFCEF4340DE02098A1F89474026E2ADF36FED4340DE02098A1F894740
55781	16916	39.875577999999997	39.888603000000003	47.140735999999997	47.129272999999998	Центральная	0103000020E610000001000000050000006D8C9DF012F04340BEA085048C9047406D8C9DF012F0434057AF22A30392474052103CBEBDF1434057AF22A30392474052103CBEBDF14340BEA085048C9047406D8C9DF012F04340BEA085048C904740
55784	16770	39.987876	40.012652000000003	47.138474000000002	47.131093999999997	 Ленина	0103000020E610000001000000050000006C4084B872FE4340D5592DB0C79047406C4084B872FE434054AC1A84B9914740501DAB949E01444054AC1A84B9914740501DAB949E014440D5592DB0C79047406C4084B872FE4340D5592DB0C7904740
41265	13066	39.923009	40.038621999999997	47.449711999999998	47.420302	Школьная	0103000020E61000000100000005000000F374AE2825F64340C138B874CCB54740F374AE2825F64340334FAE2990B94740FB73D190F1044440334FAE2990B94740FB73D190F1044440C138B874CCB54740F374AE2825F64340C138B874CCB54740
55679	13066	39.923009	40.038621999999997	47.449711999999998	47.420302	Советская	0103000020E61000000100000005000000F374AE2825F64340C138B874CCB54740F374AE2825F64340334FAE2990B94740FB73D190F1044440334FAE2990B94740FB73D190F1044440C138B874CCB54740F374AE2825F64340C138B874CCB54740
55957	16238	39.750262999999997	39.757764000000002	47.431708	47.426184999999997	Школьная	0103000020E610000001000000050000000D33349E08E04340DB85E63A8DB647400D33349E08E04340F6B52E3542B74740070B2769FEE04340F6B52E3542B74740070B2769FEE04340DB85E63A8DB647400D33349E08E04340DB85E63A8DB64740
55196	15519	39.826844000000001	39.837085000000002	47.305824000000001	47.300201999999999	Совхозная	0103000020E6100000010000000500000069723106D6E94340CE18E6046DA6474069723106D6E943407C2AA73D25A74740707CED9925EB43407C2AA73D25A74740707CED9925EB4340CE18E6046DA6474069723106D6E94340CE18E6046DA64740
55326	56651	40.044533000000001	40.077573000000001	47.193282000000004	47.185523000000003	Школьная	0103000020E61000000100000005000000E04BE141B3054440F2D3B837BF974740E04BE141B3054440E773EE76BD984740BC067DE9ED094440E773EE76BD984740BC067DE9ED094440F2D3B837BF974740E04BE141B3054440F2D3B837BF974740
55325	56650	39.905096	39.923521000000001	47.330325999999999	47.283645	Советская	0103000020E61000000100000005000000C6DE8B2FDAF343404356B77A4EA44740C6DE8B2FDAF343405E82531F48AA4740A915A6EF35F643405E82531F48AA4740A915A6EF35F643404356B77A4EA44740C6DE8B2FDAF343404356B77A4EA44740
56381	56855	39.905096	39.923521000000001	47.330325999999999	47.283645	Фадеева	0103000020E61000000100000005000000C6DE8B2FDAF343404356B77A4EA44740C6DE8B2FDAF343405E82531F48AA4740A915A6EF35F643405E82531F48AA4740A915A6EF35F643404356B77A4EA44740C6DE8B2FDAF343404356B77A4EA44740
56573	57022	40.094147	40.113002000000002	47.236164000000002	47.222396000000003	Луговая	0103000020E610000001000000050000001D0247020D0C44407061DD78779C47401D0247020D0C44400C3F389F3A9E4740F9307BD9760E44400C3F389F3A9E4740F9307BD9760E44407061DD78779C47401D0247020D0C44407061DD78779C4740
55272	56628	39.992628000000003	40.010379	47.332604000000003	47.323143999999999	 Студенческая	0103000020E61000000100000005000000058C2E6F0EFF434006F357C85CA94740058C2E6F0EFF4340684293C492AA474058C85C1954014440684293C492AA474058C85C195401444006F357C85CA94740058C2E6F0EFF434006F357C85CA94740
40140	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Чапаева	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
40665	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Толпинского	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
40300	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Садовая	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
39721	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Мира	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
41199	54816	39.832503000000003	39.845726999999997	47.114305999999999	47.106358	Маяковского	0103000020E61000000100000005000000346953758FEA434080D591239D8D4740346953758FEA434048DE3994A18E47400E2C47C840EC434048DE3994A18E47400E2C47C840EC434080D591239D8D4740346953758FEA434080D591239D8D4740
40139	54816	39.842187000000003	39.863370000000003	47.121726000000002	47.104444000000001	Ленина	0103000020E61000000100000005000000E50E9BC8CCEB4340B821C66B5E8D4740E50E9BC8CCEB43405589B2B7948F47407C2C7DE882EE43405589B2B7948F47407C2C7DE882EE4340B821C66B5E8D4740E50E9BC8CCEB4340B821C66B5E8D4740
40838	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Кирова	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
40667	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Гулаева	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
41148	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Вартанова	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
40004	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Буденного	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
41262	54816	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	Бондарчука	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
56387	6344	38.961021000000002	38.994681	46.659452999999999	46.647119000000004	Гагарина	0103000020E6100000010000000500000076E272BC027B434064CF9ECBD452474076E272BC027B4340E21FB6F468544740EE79FEB4517F4340E21FB6F468544740EE79FEB4517F434064CF9ECBD452474076E272BC027B434064CF9ECBD4524740
56382	56856	38.890000000000001	38.923389999999998	46.95635	46.950716	Центральная	0103000020E6100000010000000500000052B81E85EB71434058E4D70FB179474052B81E85EB714340CAC342AD697A47400ABABDA431764340CAC342AD697A47400ABABDA43176434058E4D70FB179474052B81E85EB71434058E4D70FB1794740
56495	56955	39.034233999999998	39.062144000000004	46.758395999999998	46.745367999999999	Школьная	0103000020E61000000100000005000000A4349BC76184434012BEF737685F4740A4349BC76184434067B5C01E1361474042D2A755F487434067B5C01E1361474042D2A755F487434012BEF737685F4740A4349BC76184434012BEF737685F4740
56497	56957	39.205694999999999	39.245311000000001	46.804703000000003	46.790495	Центральная	0103000020E61000000100000005000000B1F9B836549A43406553AEF02E654740B1F9B836549A43401EFF058200674740AE2CD159669F43401EFF058200674740AE2CD159669F43406553AEF02E654740B1F9B836549A43406553AEF02E654740
56409	56881	39.562173000000001	39.578423999999998	47.149213000000003	47.137095000000002	Степная	0103000020E61000000100000005000000DCD8EC48F5C74340FAB836548C914740DCD8EC48F5C74340AC915D69199347405A9C31CC09CA4340AC915D69199347405A9C31CC09CA4340FAB836548C914740DCD8EC48F5C74340FAB836548C914740
55979	56799	39.320391999999998	39.352372000000003	47.121946000000001	47.113644000000001	Платова	0103000020E6100000010000000500000034F3E49A02A943407DB1F7E28B8E474034F3E49A02A9434063F030ED9B8F4740580394861AAD434063F030ED9B8F4740580394861AAD43407DB1F7E28B8E474034F3E49A02A943407DB1F7E28B8E4740
56355	7635	39.608203000000003	39.612397999999999	47.055892999999998	47.050643000000001	Кольцевая	0103000020E61000000100000005000000202A8D98D9CD4340BB6246787B864740202A8D98D9CD4340A4897780278747406211C30E63CE4340A4897780278747406211C30E63CE4340BB6246787B864740202A8D98D9CD4340BB6246787B864740
55507	9054	39.694774000000002	39.712947	47.005287000000003	47.000923999999998	Зеленая	0103000020E61000000100000005000000390EBC5AEED8434008E412471E804740390EBC5AEED84340070C923EAD8047400264E8D841DB4340070C923EAD8047400264E8D841DB434008E412471E804740390EBC5AEED8434008E412471E804740
41367	7223	39.159171000000001	39.203287000000003	47.034137000000001	47.022644	Мира	0103000020E610000001000000050000005EBC1FB75F944340AEB9A3FFE58247405EBC1FB75F944340B24AE9995E844740DA59F44E059A4340B24AE9995E844740DA59F44E059A4340AEB9A3FFE58247405EBC1FB75F944340AEB9A3FFE5824740
56444	56911	39.675522999999998	39.683698	46.817222999999998	46.811728000000002	Социалистическая	0103000020E610000001000000050000001059A48977D64340AE9FFEB3E66747401059A48977D64340FE4465C39A684740992B836A83D74340FE4465C39A684740992B836A83D74340AE9FFEB3E66747401059A48977D64340AE9FFEB3E6674740
56134	24839	39.446057000000003	39.460214999999998	46.873533000000002	46.868346000000003	Школьная	0103000020E610000001000000050000007193516518B9434064CE33F6256F47407193516518B94340077DE9EDCF6F474077103B53E8BA4340077DE9EDCF6F474077103B53E8BA434064CE33F6256F47407193516518B9434064CE33F6256F4740
56252	8263	39.149847000000001	39.166753	46.631445999999997	46.614747999999999	пер.Береговой	0103000020E61000000100000005000000AD33BE2F2E93434005A4FD0FB04E4740AD33BE2F2E9343405298F738D350474044C18C29589543405298F738D350474044C18C295895434005A4FD0FB04E4740AD33BE2F2E93434005A4FD0FB04E4740
40169	9057	39.024532000000001	39.063113999999999	47.017816000000003	46.994292999999999	Ленина	0103000020E610000001000000050000004DDA54DD2383434024D236FE447F47404DDA54DD238343403BAC70CB47824740BAF59A1E148843403BAC70CB47824740BAF59A1E1488434024D236FE447F47404DDA54DD2383434024D236FE447F4740
40320	8656	39.665219	39.705131000000002	46.956294999999997	46.926135000000002	переулок Промышленный	0103000020E61000000100000005000000C3D66CE525D543402A5778978B764740C3D66CE525D54340062AE3DF677A4740A9328CBB41DA4340062AE3DF677A4740A9328CBB41DA43402A5778978B764740C3D66CE525D543402A5778978B764740
39802	8656	39.665219	39.705131000000002	46.956294999999997	46.926135000000002	Переездная	0103000020E61000000100000005000000C3D66CE525D543402A5778978B764740C3D66CE525D54340062AE3DF677A4740A9328CBB41DA4340062AE3DF677A4740A9328CBB41DA43402A5778978B764740C3D66CE525D543402A5778978B764740
40013	8656	39.665219	39.705131000000002	46.956294999999997	46.926135000000002	Московская	0103000020E61000000100000005000000C3D66CE525D543402A5778978B764740C3D66CE525D54340062AE3DF677A4740A9328CBB41DA4340062AE3DF677A4740A9328CBB41DA43402A5778978B764740C3D66CE525D543402A5778978B764740
40167	8656	39.665219	39.705131000000002	46.956294999999997	46.926135000000002	Мира	0103000020E61000000100000005000000C3D66CE525D543402A5778978B764740C3D66CE525D54340062AE3DF677A4740A9328CBB41DA4340062AE3DF677A4740A9328CBB41DA43402A5778978B764740C3D66CE525D543402A5778978B764740
40316	8656	39.665219	39.705131000000002	46.956294999999997	46.926135000000002	Ленина	0103000020E61000000100000005000000C3D66CE525D543402A5778978B764740C3D66CE525D54340062AE3DF677A4740A9328CBB41DA4340062AE3DF677A4740A9328CBB41DA43402A5778978B764740C3D66CE525D543402A5778978B764740
55705	56683	39.338231999999998	39.355004000000001	47.185437	47.160156999999998	пер.Школьный	0103000020E61000000100000005000000F73AA92F4BAB4340DC9C4A0680944740F73AA92F4BAB4340F33B4D66BC9747407FF964C570AD4340F33B4D66BC9747407FF964C570AD4340DC9C4A0680944740F73AA92F4BAB4340DC9C4A0680944740
56117	7899	38.917039000000003	38.938195	46.866646000000003	46.852473000000003	Центральная	0103000020E610000001000000050000000A14B188617543408CDCD3D51D6D47400A14B18861754340C89A9141EE6E4740A72215C616784340C89A9141EE6E4740A72215C6167843408CDCD3D51D6D47400A14B188617543408CDCD3D51D6D4740
39933	7906	38.736559	38.772041999999999	46.883764999999997	46.869936000000003	Социалистическая	0103000020E610000001000000050000008849B890475E434079CE16105A6F47408849B890475E4340BA2C26361F714740B891B245D2624340BA2C26361F714740B891B245D262434079CE16105A6F47408849B890475E434079CE16105A6F4740
56106	7373	39.156198000000003	39.184305999999999	46.814343000000001	46.809057000000003	Молодежная	0103000020E61000000100000005000000AED9CA4BFE934340C9CC052E8F674740AED9CA4BFE934340FF5C34643C684740713AC95697974340FF5C34643C684740713AC95697974340C9CC052E8F674740AED9CA4BFE934340C9CC052E8F674740
56339	7328	39.200915999999999	39.248491000000001	46.850377999999999	46.837496000000002	Южная	0103000020E610000001000000050000001F9F909DB7994340F243A511336B47401F9F909DB7994340739EB12FD96C4740D82C978DCE9F4340739EB12FD96C4740D82C978DCE9F4340F243A511336B47401F9F909DB7994340F243A511336B4740
40165	54868	39.623573	39.648240999999999	46.950654	46.933753000000003	Филипченко	0103000020E6100000010000000500000095D5743DD1CF43405DC5E2378577474095D5743DD1CF4340E2E7BF07AF7947409276A38FF9D24340E2E7BF07AF7947409276A38FF9D243405DC5E2378577474095D5743DD1CF43405DC5E23785774740
56370	8056	39.467256999999996	39.482492999999998	46.997605	46.984667000000002	Калинина	0103000020E61000000100000005000000DDE9CE13CFBB4340A8397991097E4740DDE9CE13CFBB4340BDA94885B17F474043C6A354C2BD4340BDA94885B17F474043C6A354C2BD4340A8397991097E4740DDE9CE13CFBB4340A8397991097E4740
40822	8323	39.364553000000001	39.411884999999998	47.028075000000001	47.008887999999999	переулок Октябрьский	0103000020E61000000100000005000000505436ACA9AE4340D6A9F23D23814740505436ACA9AE4340E86A2BF697834740425BCEA5B8B44340E86A2BF697834740425BCEA5B8B44340D6A9F23D23814740505436ACA9AE4340D6A9F23D23814740
55104	8323	39.364553000000001	39.411884999999998	47.028075000000001	47.008887999999999	пер.Октябрьский	0103000020E61000000100000005000000505436ACA9AE4340D6A9F23D23814740505436ACA9AE4340E86A2BF697834740425BCEA5B8B44340E86A2BF697834740425BCEA5B8B44340D6A9F23D23814740505436ACA9AE4340D6A9F23D23814740
55909	56761	39.589562999999998	39.606406	46.961872999999997	46.953907999999998	Комсомольская	0103000020E6100000010000000500000040F7E5CC76CB434046B247A8197A474040F7E5CC76CB4340E4F38AA71E7B4740910C39B69ECD4340E4F38AA71E7B4740910C39B69ECD434046B247A8197A474040F7E5CC76CB434046B247A8197A4740
55890	56743	39.439455000000002	39.452139000000003	47.028467999999997	47.014485999999998	Ростовский переулок	0103000020E610000001000000050000002788BA0F40B84340FB1F60ADDA8147402788BA0F40B84340C37DE4D6A4834740821FD5B0DFB94340C37DE4D6A4834740821FD5B0DFB94340FB1F60ADDA8147402788BA0F40B84340FB1F60ADDA814740
56459	56925	39.069474	39.088186	47.027631999999997	47.017477999999997	Победы	0103000020E610000001000000050000000EF62686E4884340223317B83C8247400EF62686E48843405A2904728983474087FBC8AD498B43405A2904728983474087FBC8AD498B4340223317B83C8247400EF62686E4884340223317B83C824740
55792	8206	39.079787000000003	39.109637999999997	46.666386000000003	46.659725000000002	Курышко	0103000020E61000000100000005000000AFD2DD75368A434043AD69DE71544740AFD2DD75368A43409241EE224C5547400D33349E088E43409241EE224C5547400D33349E088E434043AD69DE71544740AFD2DD75368A434043AD69DE71544740
55703	8271	39.183543	39.261076000000003	46.742645000000003	46.720446000000003	Победы	0103000020E61000000100000005000000723447567E9743405B441493375C4740723447567E974340DBC4C9FD0E5F4740A0E238F06AA14340DBC4C9FD0E5F4740A0E238F06AA143405B441493375C4740723447567E9743405B441493375C4740
40820	7686	39.639401999999997	39.651142999999998	47.110515999999997	47.099235999999998	переулок Комсомольский	0103000020E610000001000000050000009D7FBBECD7D14340FD4AE7C3B38C47409D7FBBECD7D14340A5D76663258E4740790261A758D34340A5D76663258E4740790261A758D34340FD4AE7C3B38C47409D7FBBECD7D14340FD4AE7C3B38C4740
55263	56622	39.422835999999997	39.442221000000004	47.164555999999997	47.155714000000003	Заводская	0103000020E6100000010000000500000025C9737D1FB64340C2C3B46FEE93474025C9737D1FB64340272EC72B109547405E4D9EB29AB84340272EC72B109547405E4D9EB29AB84340C2C3B46FEE93474025C9737D1FB64340C2C3B46FEE934740
41366	6694	39.663297	39.686931000000001	46.908014000000001	46.898077000000001	Школьная	0103000020E61000000100000005000000784485EAE6D443401825E82FF4724740784485EAE6D44340B32781CD39744740E6CDE15AEDD74340B32781CD39744740E6CDE15AEDD743401825E82FF4724740784485EAE6D443401825E82FF4724740
40315	8589	39.132230999999997	39.148741999999999	46.882367000000002	46.870145000000001	переулок Школьный	0103000020E61000000100000005000000394206F2EC90434093E34EE9606F4740394206F2EC904340EA08E066F170474054C554FA09934340EA08E066F170474054C554FA0993434093E34EE9606F4740394206F2EC90434093E34EE9606F4740
55702	8956	39.589050999999998	39.627561999999998	46.985526999999998	46.971024	пер.Школьный	0103000020E610000001000000050000008A56EE0566CB4340C8D0B1834A7C47408A56EE0566CB43409929ADBF257E47402E1B9DF353D043409929ADBF257E47402E1B9DF353D04340C8D0B1834A7C47408A56EE0566CB4340C8D0B1834A7C4740
40314	7064	39.398437000000001	39.429079000000002	46.842803000000004	46.824888000000001	Московская	0103000020E610000001000000050000001842CEFBFFB24340726E13EE956947401842CEFBFFB2434040FCFCF7E06B47404033880FECB6434040FCFCF7E06B47404033880FECB64340726E13EE956947401842CEFBFFB24340726E13EE95694740
56372	7963	38.815727000000003	38.845902000000002	46.90701	46.892491	Ленина	0103000020E610000001000000050000006BBB09BE69684340B77C24253D7247406BBB09BE696843408E9257E7187447407DCF4884466C43408E9257E7187447407DCF4884466C4340B77C24253D7247406BBB09BE69684340B77C24253D724740
55269	56626	39.506199000000002	39.515605000000001	47.086218000000002	47.071446999999999	улица Ленина	0103000020E610000001000000050000004B22FB20CBC04340DB32E02C258947404B22FB20CBC04340CC290131098B4740B9533A58FFC14340CC290131098B4740B9533A58FFC14340DB32E02C258947404B22FB20CBC04340DB32E02C25894740
55976	5729	38.948363999999998	38.975358	46.852392999999999	46.835726000000001	Мира	0103000020E61000000100000005000000145AD6FD637943405D35CF11F96A4740145AD6FD637943406F2BBD361B6D47402CF2EB87D87C43406F2BBD361B6D47402CF2EB87D87C43405D35CF11F96A4740145AD6FD637943405D35CF11F96A4740
55590	7765	38.861721000000003	38.887224000000003	46.943142999999999	46.914563999999999	Луговая	0103000020E6100000010000000500000062A3ACDF4C6E4340AA0CE36E1075474062A3ACDF4C6E4340C539EAE8B8784740F81C588E90714340C539EAE8B8784740F81C588E90714340AA0CE36E1075474062A3ACDF4C6E4340AA0CE36E10754740
56105	5961	39.130937000000003	39.142902999999997	46.761606	46.752234000000001	пл.Домошевского	0103000020E610000001000000050000000E6B2A8BC29043403A782634496047400E6B2A8BC2904340FC372F4E7C61474009C03FA54A924340FC372F4E7C61474009C03FA54A9243403A782634496047400E6B2A8BC29043403A78263449604740
56467	56932	39.623483	39.639923000000003	46.961103999999999	46.950937000000003	Школьная	0103000020E61000000100000005000000554E7B4ACECF434037C7B94DB8794740554E7B4ACECF43400307B474057B4740A77A32FFE8D143400307B474057B4740A77A32FFE8D1434037C7B94DB8794740554E7B4ACECF434037C7B94DB8794740
40166	7498	39.533562000000003	39.578415	47.086525000000002	47.071288000000003	площадь Гагарина	0103000020E61000000100000005000000B63176C24BC44340734C16F71F894740B63176C24BC44340A9A44E40138B47400742B28009CA4340A9A44E40138B47400742B28009CA4340734C16F71F894740B63176C24BC44340734C16F71F894740
41371	7498	39.533562000000003	39.578415	47.086525000000002	47.071288000000003	Первомайская	0103000020E61000000100000005000000B63176C24BC44340734C16F71F894740B63176C24BC44340A9A44E40138B47400742B28009CA4340A9A44E40138B47400742B28009CA4340734C16F71F894740B63176C24BC44340734C16F71F894740
40196	7498	39.533562000000003	39.578415	47.086525000000002	47.071288000000003	Матросова	0103000020E61000000100000005000000B63176C24BC44340734C16F71F894740B63176C24BC44340A9A44E40138B47400742B28009CA4340A9A44E40138B47400742B28009CA4340734C16F71F894740B63176C24BC44340734C16F71F894740
39801	7498	39.533562000000003	39.578415	47.086525000000002	47.071288000000003	Ленина	0103000020E61000000100000005000000B63176C24BC44340734C16F71F894740B63176C24BC44340A9A44E40138B47400742B28009CA4340A9A44E40138B47400742B28009CA4340734C16F71F894740B63176C24BC44340734C16F71F894740
40817	7498	39.533562000000003	39.578415	47.086525000000002	47.071288000000003	Кулагина	0103000020E61000000100000005000000B63176C24BC44340734C16F71F894740B63176C24BC44340A9A44E40138B47400742B28009CA4340A9A44E40138B47400742B28009CA4340734C16F71F894740B63176C24BC44340734C16F71F894740
39795	7225	39.301966999999998	39.334207999999997	46.892885999999997	46.870663	Ленина	0103000020E6100000010000000500000051BCCADAA6A643402B6B9BE2716F474051BCCADAA6A643403387A4164A724740E107E753C7AA43403387A4164A724740E107E753C7AA43402B6B9BE2716F474051BCCADAA6A643402B6B9BE2716F4740
40814	7138	39.212926000000003	39.260680999999998	47.025556000000002	47.005034999999999	Мира	0103000020E61000000100000005000000EB3BBF28419B4340ED2AA4FCA4804740EB3BBF28419B4340B91B446B4583474023D8B8FE5DA14340B91B446B4583474023D8B8FE5DA14340ED2AA4FCA4804740EB3BBF28419B4340ED2AA4FCA4804740
55275	56631	39.719774000000001	39.729018000000003	47.102756999999997	47.099511999999997	Заводская	0103000020E610000001000000050000006C41EF8D21DC43409FC728CFBC8C47406C41EF8D21DC4340B0373124278D474001193A7650DD4340B0373124278D474001193A7650DD43409FC728CFBC8C47406C41EF8D21DC43409FC728CFBC8C4740
55854	56711	39.628163999999998	39.652687999999998	46.978968000000002	46.970243000000004	Луговая	0103000020E6100000010000000500000024438EAD67D04340231631EC307C474024438EAD67D043404FEACBD24E7D4740EE3EC7478BD343404FEACBD24E7D4740EE3EC7478BD34340231631EC307C474024438EAD67D04340231631EC307C4740
55850	56708	39.539167999999997	39.555489999999999	47.166074999999999	47.142679000000001	Ленина	0103000020E610000001000000050000005D86FF7403C54340BA69334E439247405D86FF7403C5434073D712F241954740A5A0DB4B1AC7434073D712F241954740A5A0DB4B1AC74340BA69334E439247405D86FF7403C54340BA69334E43924740
55685	6748	39.672620999999999	39.691198	46.890003999999998	46.864773	Ленина	0103000020E6100000010000000500000029CDE67118D643405EBBB4E1B06E474029CDE67118D6434093A7ACA6EB714740C287122D79D8434093A7ACA6EB714740C287122D79D843405EBBB4E1B06E474029CDE67118D643405EBBB4E1B06E4740
56552	57004	39.462136999999998	39.485070999999998	46.842205	46.837138000000003	Октябрьская	0103000020E61000000100000005000000C2A2224E27BB4340931E8656276B4740C2A2224E27BB43408BC3995FCD6B4740779E78CE16BE43408BC3995FCD6B4740779E78CE16BE4340931E8656276B4740C2A2224E27BB4340931E8656276B4740
40774	6753	39.304625999999999	39.342652000000001	47.088985000000001	47.065027000000001	Тельмана	0103000020E6100000010000000500000072C119FCFDA64340B22D03CE5288474072C119FCFDA64340D36A48DC638B47405AF44E05DCAB4340D36A48DC638B47405AF44E05DCAB4340B22D03CE5288474072C119FCFDA64340B22D03CE52884740
40777	6753	39.304625999999999	39.342652000000001	47.088985000000001	47.065027000000001	Советская	0103000020E6100000010000000500000072C119FCFDA64340B22D03CE5288474072C119FCFDA64340D36A48DC638B47405AF44E05DCAB4340D36A48DC638B47405AF44E05DCAB4340B22D03CE5288474072C119FCFDA64340B22D03CE52884740
40778	6753	39.304625999999999	39.342652000000001	47.088985000000001	47.065027000000001	Ленина	0103000020E6100000010000000500000072C119FCFDA64340B22D03CE5288474072C119FCFDA64340D36A48DC638B47405AF44E05DCAB4340D36A48DC638B47405AF44E05DCAB4340B22D03CE5288474072C119FCFDA64340B22D03CE52884740
39793	6753	39.304625999999999	39.342652000000001	47.088985000000001	47.065027000000001	Волгодонская	0103000020E6100000010000000500000072C119FCFDA64340B22D03CE5288474072C119FCFDA64340D36A48DC638B47405AF44E05DCAB4340D36A48DC638B47405AF44E05DCAB4340B22D03CE5288474072C119FCFDA64340B22D03CE52884740
56136	32246	39.371631999999998	39.384343000000001	47.052804000000002	47.047517999999997	Центральная	0103000020E61000000100000005000000D3122BA391AF434054FCDF1115864740D3122BA391AF43408B8C0E48C286474028B9C32632B143408B8C0E48C286474028B9C32632B1434054FCDF1115864740D3122BA391AF434054FCDF1115864740
40826	8435	39.290908999999999	39.332348000000003	47.027467000000001	47.011136999999998	переулок Октябрьский	0103000020E61000000100000005000000588E90813CA543404563EDEF6C814740588E90813CA54340105CE509848347400D7217618AAA4340105CE509848347400D7217618AAA43404563EDEF6C814740588E90813CA543404563EDEF6C814740
55857	56714	39.651673000000002	39.668435000000002	46.935673000000001	46.924123000000002	Ленина	0103000020E61000000100000005000000D65757056AD343409F3D97A949764740D65757056AD3434007600322C47747403A4030478FD5434007600322C47747403A4030478FD543409F3D97A949764740D65757056AD343409F3D97A949764740
56369	56851	39.534531999999999	39.577641999999997	46.973796999999998	46.960428	Ворошиловская	0103000020E610000001000000050000002E55698B6BC44340D314014EEF7A47402E55698B6BC44340B1F84D61A57C4740E4654D2CF0C94340B1F84D61A57C4740E4654D2CF0C94340D314014EEF7A47402E55698B6BC44340D314014EEF7A4740
56407	56879	39.712857	39.731811	46.871721999999998	46.866244999999999	Юбилейная	0103000020E61000000100000005000000C2DCEEE53EDB434069A9BC1DE16E4740C2DCEEE53EDB4340139A2496946F474031ED9BFBABDD4340139A2496946F474031ED9BFBABDD434069A9BC1DE16E4740C2DCEEE53EDB434069A9BC1DE16E4740
32957	6286	38.871673999999999	38.929679	46.672854000000001	46.648077999999998	Дзержинского	0103000020E6100000010000000500000002637D03936F4340E8A04B38F452474002637D03936F4340CC7D7214205647409563B2B8FF764340CC7D7214205647409563B2B8FF764340E8A04B38F452474002637D03936F4340E8A04B38F4524740
56119	5970	39.469026999999997	39.482303999999999	47.142874999999997	47.128132999999998	пл.Павших Борцов	0103000020E6100000010000000500000072F8A41309BC4340E94482A96690474072F8A41309BC43403F355EBA49924740705D3123BCBD43403F355EBA49924740705D3123BCBD4340E94482A96690474072F8A41309BC4340E94482A966904740
56529	56986	39.411130999999997	39.425027999999998	47.166786000000002	47.161375999999997	Мало-Свердлова	0103000020E6100000010000000500000096AFCBF09FB44340FD2D01F8A794474096AFCBF09FB4434020B75F3E5995474030F1475167B6434020B75F3E5995474030F1475167B64340FD2D01F8A794474096AFCBF09FB44340FD2D01F8A7944740
56386	56860	39.309567000000001	39.330362999999998	47.130076000000003	47.120995999999998	Бакланова	0103000020E61000000100000005000000DE7536E49FA74340317903CC7C8F4740DE7536E49FA743404CFF9254A69047407B67B45549AA43404CFF9254A69047407B67B45549AA4340317903CC7C8F4740DE7536E49FA74340317903CC7C8F4740
55484	7074	39.525989000000003	39.550711	46.831738000000001	46.821373000000001	Кирова	0103000020E610000001000000050000002387889B53C34340A1681EC0226947402387889B53C34340946B0A64766A47401346B3B27DC64340946B0A64766A47401346B3B27DC64340A1681EC0226947402387889B53C34340A1681EC022694740
56406	56878	39.053573999999998	39.067174999999999	46.666398000000001	46.658394999999999	Центральная	0103000020E610000001000000050000003CF54883DB864340CA6C9049465447403CF54883DB864340560F98874C554740ED0DBE3099884340560F98874C554740ED0DBE3099884340CA6C9049465447403CF54883DB864340CA6C904946544740
41208	8374	39.332177999999999	39.364688000000001	47.030163000000002	47.010123	переулок Октябрьский	0103000020E61000000100000005000000B03907CF84AA4340FDF7E0B54B814740B03907CF84AA43404E469561DC834740309FAC18AEAE43404E469561DC834740309FAC18AEAE4340FDF7E0B54B814740B03907CF84AA4340FDF7E0B54B814740
55482	7367	39.547916999999998	39.572729000000002	47.010092999999998	46.990524999999998	Горького	0103000020E6100000010000000500000012F6ED2422C64340696FF085C97E474012F6ED2422C64340927538BA4A814740433C122F4FC94340927538BA4A814740433C122F4FC94340696FF085C97E474012F6ED2422C64340696FF085C97E4740
56368	6390	39.490605000000002	39.515631999999997	46.972394999999999	46.962826	 Азовская	0103000020E6100000010000000500000086200725CCBE434087DEE2E13D7B474086200725CCBE43409FE57970777C4740B262B83A00C243409FE57970777C4740B262B83A00C2434087DEE2E13D7B474086200725CCBE434087DEE2E13D7B4740
32955	24585	39.466566	39.471857	46.931477000000001	46.927815000000002	Строителей 	0103000020E6100000010000000500000078B6476FB8BB43407FDE54A4C276474078B6476FB8BB4340F4FC69A33A774740C0B167CF65BC4340F4FC69A33A774740C0B167CF65BC43407FDE54A4C276474078B6476FB8BB43407FDE54A4C2764740
56532	56983	39.621265000000001	39.638306	46.819406000000001	46.808613000000001	Октябрьская	0103000020E6100000010000000500000021938C9C85CF43406B0F7BA18067474021938C9C85CF4340B612BA4BE2684740986BD102B4D14340B612BA4BE2684740986BD102B4D143406B0F7BA18067474021938C9C85CF43406B0F7BA180674740
56404	56876	39.315451000000003	39.334504000000003	47.047517999999997	47.037545000000001	Ленина	0103000020E61000000100000005000000C93EC8B260A843406D904946CE844740C93EC8B260A8434054FCDF1115864740CB30EE06D1AA434054FCDF1115864740CB30EE06D1AA43406D904946CE844740C93EC8B260A843406D904946CE844740
56256	5490	38.968046000000001	39.024433000000002	46.800896999999999	46.760686	переулок Победы	0103000020E6100000010000000500000006836BEEE87B43403543AA285E61474006836BEEE87B4340753BFBCA83664740BAF8DB9E20834340753BFBCA83664740BAF8DB9E208343403543AA285E61474006836BEEE87B43403543AA285E614740
40162	5490	38.968046000000001	39.024433000000002	46.800896999999999	46.760686	Советская	0103000020E6100000010000000500000006836BEEE87B43403543AA285E61474006836BEEE87B4340753BFBCA83664740BAF8DB9E20834340753BFBCA83664740BAF8DB9E208343403543AA285E61474006836BEEE87B43403543AA285E614740
55701	5490	38.968046000000001	39.024433000000002	46.800896999999999	46.760686	Октябрьская	0103000020E6100000010000000500000006836BEEE87B43403543AA285E61474006836BEEE87B4340753BFBCA83664740BAF8DB9E20834340753BFBCA83664740BAF8DB9E208343403543AA285E61474006836BEEE87B43403543AA285E614740
55804	5490	38.968046000000001	39.024433000000002	46.800896999999999	46.760686	Калинина	0103000020E6100000010000000500000006836BEEE87B43403543AA285E61474006836BEEE87B4340753BFBCA83664740BAF8DB9E20834340753BFBCA83664740BAF8DB9E208343403543AA285E61474006836BEEE87B43403543AA285E614740
23456	50720	39.444656000000002	39.483139999999999	43.817355999999997	43.776648999999999	улица Центральная	0103000020E610000001000000050000002FFCE07CEAB843404DBC033C69E345402FFCE07CEAB843403D98141F9FE84540D9B11188D7BD43403D98141F9FE84540D9B11188D7BD43404DBC033C69E345402FFCE07CEAB843404DBC033C69E34540
21563	50389	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	Коншиных	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
20882	50296	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	Карпенко	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
23059	50625	39.971563000000003	39.991622	43.55348	43.541974000000003	Батайская	0103000020E610000001000000050000007880272D5CFC434023A46E675FC545407880272D5CFC4340BB7EC16ED8C645403FFF3D78EDFE4340BB7EC16ED8C645403FFF3D78EDFE434023A46E675FC545407880272D5CFC434023A46E675FC54540
21120	50331	39.186498	39.195678999999998	45.076895	45.072121000000003	Центральная	0103000020E610000001000000050000007C629D2ADF9743406B2DCC423B8946407C629D2ADF974340EB1C03B2D7894640CAC16C020C994340EB1C03B2D7894640CAC16C020C9943406B2DCC423B8946407C629D2ADF9743406B2DCC423B894640
20689	50277	37.792456000000001	37.846463	44.73798	44.711601000000002	Сухумийское шоссе	0103000020E610000001000000050000006EC2BD326FE542408466D7BD155B46406EC2BD326FE54240118DEE20765E464014234BE658EC4240118DEE20765E464014234BE658EC42408466D7BD155B46406EC2BD326FE542408466D7BD155B4640
21139	50332	37.305031	37.331629999999997	44.897398000000003	44.870044	Ленина	0103000020E6100000010000000500000012A27C410BA742405F0A0F9A5D6F464012A27C410BA7424077BF0AF0DD724640AD2F12DA72AA424077BF0AF0DD724640AD2F12DA72AA42405F0A0F9A5D6F464012A27C410BA742405F0A0F9A5D6F4640
6275	23618	37.719665999999997	37.731560000000002	44.757108000000002	44.751860000000001	улица Школьная	0103000020E610000001000000050000008505F7031EDC4240D595CFF23C6046408505F7031EDC42401EC539EAE8604640E88711C2A3DD42401EC539EAE8604640E88711C2A3DD4240D595CFF23C6046408505F7031EDC4240D595CFF23C604640
22329	50490	39.510682000000003	39.552418000000003	44.466236000000002	44.384737999999999	Ленина	0103000020E61000000100000005000000F4531C075EC14340A4C343183F314640F4531C075EC14340E31B0A9FAD3B464062DC0DA2B5C64340E31B0A9FAD3B464062DC0DA2B5C64340A4C343183F314640F4531C075EC14340A4C343183F314640
21111	50327	39.099640000000001	39.121029	44.520389000000002	44.506903999999999	Подгорная	0103000020E61000000100000005000000CDAFE600C18C4340151BF33AE2404640CDAFE600C18C43405D19541B9C4246400D6FD6E07D8F43405D19541B9C4246400D6FD6E07D8F4340151BF33AE2404640CDAFE600C18C4340151BF33AE2404640
22538	50459	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Строительная	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
22056	50459	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Площадь Революции	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
22337	50459	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Пионерская	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
22408	50459	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Коммунистическая	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
23424	50702	39.80621	39.843598	45.954732999999997	45.930267000000001	Школьная	0103000020E61000000100000005000000A5DAA7E331E7434026C632FD12F74640A5DAA7E331E74340BBB4E1B034FA46404A7CEE04FBEB4340BBB4E1B034FA46404A7CEE04FBEB434026C632FD12F74640A5DAA7E331E7434026C632FD12F74640
7856	100	39.098661	39.105614000000003	44.104405	44.098171999999998	улица Пушкина	0103000020E61000000100000005000000013274ECA08C434003B16CE6900C4640013274ECA08C4340FA449E245D0D4640F8FF71C2848D4340FA449E245D0D4640F8FF71C2848D434003B16CE6900C4640013274ECA08C434003B16CE6900C4640
18	100	39.082445999999997	39.087234000000002	44.117026000000003	44.106411999999999	улица Новицкого	0103000020E61000000100000005000000CFD72C978D8A434073F38DE89E0D4640CFD72C978D8A43400F643DB5FA0E4640B58CD47B2A8B43400F643DB5FA0E4640B58CD47B2A8B434073F38DE89E0D4640CFD72C978D8A434073F38DE89E0D4640
8152	100	39.073633999999998	39.075097999999997	44.103110999999998	44.098657000000003	улица Коммунистическая	0103000020E61000000100000005000000D4EFC2D66C894340C042E6CAA00C4640D4EFC2D66C894340CE6DC2BD320D46405CFFAECF9C894340CE6DC2BD320D46405CFFAECF9C894340C042E6CAA00C4640D4EFC2D66C894340C042E6CAA00C4640
8072	100	39.061947000000004	39.071486999999998	44.098999999999997	44.095568999999998	улица Горького	0103000020E61000000100000005000000EC8A19E1ED87434076C1E09A3B0C4640EC8A19E1ED874340E9263108AC0C4640698B6B7C26894340E9263108AC0C4640698B6B7C2689434076C1E09A3B0C4640EC8A19E1ED87434076C1E09A3B0C4640
21089	100	39.030909999999999	39.129302000000003	44.132393999999998	44.066648999999998	площадь Октябрьской Революции	0103000020E61000000100000005000000478FDFDBF4834340D2A755F487084640478FDFDBF4834340E3175E49F210464059A7CAF78C904340E3175E49F210464059A7CAF78C904340D2A755F487084640478FDFDBF4834340D2A755F487084640
23830	100	39.078772000000001	39.082391999999999	44.106574000000002	44.100268999999997	Шаумяна	0103000020E6100000010000000500000096EB6D33158A4340BCE6559DD50C464096EB6D33158A43404D4D8237A40D4640DCB930D28B8A43404D4D8237A40D4640DCB930D28B8A4340BCE6559DD50C464096EB6D33158A4340BCE6559DD50C4640
22890	100	39.056584000000001	39.063034000000002	44.113343999999998	44.098295	Фрунзе	0103000020E610000001000000050000000ABDFE243E8743401F2E39EE940C46400ABDFE243E8743405299620E820E46409E44847F118843405299620E820E46409E44847F118843401F2E39EE940C46400ABDFE243E8743401F2E39EE940C4640
23588	100	39.059601999999998	39.059674000000001	44.106166000000002	44.105001000000001	Таманская	0103000020E610000001000000050000005A63D009A18743400E863AAC700D46405A63D009A18743403CF9F4D8960D4640F435CB65A38743403CF9F4D8960D4640F435CB65A38743400E863AAC700D46405A63D009A18743400E863AAC700D4640
23827	100	39.086381000000003	39.120677999999998	44.105032999999999	44.089891000000001	Сочинская	0103000020E6100000010000000500000076FF58880E8B4340359A5C8C810B464076FF58880E8B43401900AAB8710D464060AC6F60728F43401900AAB8710D464060AC6F60728F4340359A5C8C810B464076FF58880E8B4340359A5C8C810B4640
23644	100	39.065171999999997	39.071072999999998	44.106405000000002	44.096074000000002	Полетаева	0103000020E61000000100000005000000B54E5C8E578843407AFF1F274C0C4640B54E5C8E57884340C190D5AD9E0D4640765089EB18894340C190D5AD9E0D4640765089EB188943407AFF1F274C0C4640B54E5C8E578843407AFF1F274C0C4640
23765	100	39.072439000000003	39.074137	44.103098000000003	44.098139000000003	Ленина	0103000020E610000001000000050000003CFA5FAE4589434028BB99D18F0C46403CFA5FAE458943403A24B550320D464037363B527D8943403A24B550320D464037363B527D89434028BB99D18F0C46403CFA5FAE4589434028BB99D18F0C4640
23711	100	39.078673000000002	39.079625	44.103214000000001	44.101311000000003	Кондратьева	0103000020E61000000100000005000000030AF5F4118A4340CFDC43C2F70C4640030AF5F4118A4340A33EC91D360D4640D578E926318A4340A33EC91D360D4640D578E926318A4340CFDC43C2F70C4640030AF5F4118A4340CFDC43C2F70C4640
23764	100	39.082931000000002	39.094141999999998	44.126908	44.110613000000001	Киевская	0103000020E610000001000000050000008C69A67B9D8A434098C11891280E46408C69A67B9D8A4340E6CC76853E1046400B9755D80C8C4340E6CC76853E1046400B9755D80C8C434098C11891280E46408C69A67B9D8A434098C11891280E4640
23714	100	39.073327999999997	39.083308000000002	44.106088	44.095958000000003	Карла Маркса	0103000020E61000000100000005000000C7F0D8CF6289434011E50B5A480C4640C7F0D8CF62894340C03FA54A940D464062BF27D6A98A4340C03FA54A940D464062BF27D6A98A434011E50B5A480C4640C7F0D8CF6289434011E50B5A480C4640
23450	100	39.117066999999999	39.118288999999997	44.096093000000003	44.094973000000003	Камо	0103000020E610000001000000050000006D382C0DFC8E434063804413280C46406D382C0DFC8E4340F12F82C64C0C4640FF3C0D18248F4340F12F82C64C0C4640FF3C0D18248F434063804413280C46406D382C0DFC8E434063804413280C4640
23602	100	39.065297000000001	39.079436999999999	44.132362000000001	44.115161999999998	Калараша	0103000020E6100000010000000500000072C3EFA65B884340F8DEDFA0BD0E464072C3EFA65B884340D89DEE3CF1104640D28BDAFD2A8A4340D89DEE3CF1104640D28BDAFD2A8A4340F8DEDFA0BD0E464072C3EFA65B884340F8DEDFA0BD0E4640
23650	100	39.085850999999998	39.107410000000002	44.091963	44.085487999999998	Звездная	0103000020E6100000010000000500000019AA622AFD8A4340A8195245F10A464019AA622AFD8A434095B88E71C50B4640B6A1629CBF8D434095B88E71C50B4640B6A1629CBF8D4340A8195245F10A464019AA622AFD8A4340A8195245F10A4640
23063	100	39.052971999999997	39.054580000000001	44.118884000000001	44.117939	Дружбы переулок	0103000020E6100000010000000500000046CD57C9C786434023F609A0180F464046CD57C9C786434043024697370F46400282397AFC86434043024697370F46400282397AFC86434023F609A0180F464046CD57C9C786434023F609A0180F4640
22870	100	39.061947000000004	39.071486999999998	44.098999999999997	44.095568999999998	Горького	0103000020E61000000100000005000000EC8A19E1ED87434076C1E09A3B0C4640EC8A19E1ED874340E9263108AC0C4640698B6B7C26894340E9263108AC0C4640698B6B7C2689434076C1E09A3B0C4640EC8A19E1ED87434076C1E09A3B0C4640
23651	100	39.083343999999997	39.102756999999997	44.115116999999998	44.101025999999997	Богдана Хмельницкого	0103000020E61000000100000005000000AE282504AB8A4340D905836BEE0C4640AE282504AB8A4340581B6327BC0E4640B0373124278D4340581B6327BC0E4640B0373124278D4340D905836BEE0C4640AE282504AB8A4340D905836BEE0C4640
22051	50396	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Федосеева	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
22033	50396	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Парковая	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21666	50396	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Красноармейская	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21887	50396	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Калинина	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
22494	50512	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Меньшикова	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
22736	50425	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Степанова	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
22232	50425	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Рабочая	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21750	50425	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Пионерская	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
22637	50425	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Ленина	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
22180	50425	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Колхозная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
22915	50589	39.840111999999998	39.847980999999997	44.627029	44.613273999999997	Спортивная	0103000020E61000000100000005000000137D3ECA88EB434059BE2EC37F4E4640137D3ECA88EB434061527C7C425046408F5033A48AEC434061527C7C425046408F5033A48AEC434059BE2EC37F4E4640137D3ECA88EB434059BE2EC37F4E4640
22536	50516	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	27 Сентября	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
20552	50259	39.354815000000002	39.386526000000003	44.777650999999999	44.752096000000002	Красная	0103000020E61000000100000005000000AC90F2936AAD4340E9B985AE44604640AC90F2936AAD4340D15966118A634640E08618AF79B14340D15966118A634640E08618AF79B14340E9B985AE44604640AC90F2936AAD4340E9B985AE44604640
22666	50535	39.304482999999998	39.313195999999998	45.069001999999998	45.039439000000002	Шевченко	0103000020E610000001000000050000000F98874CF9A64340EE974F560C8546400F98874CF9A64340E6ADBA0ED5884640779E78CE16A84340E6ADBA0ED5884640779E78CE16A84340EE974F560C8546400F98874CF9A64340EE974F560C854640
22837	50535	39.294654999999999	39.315809999999999	45.053901000000003	45.050252	Красная	0103000020E610000001000000050000002B4D4A41B7A54340804754A86E8646402B4D4A41B7A54340611C5C3AE6864640F8DF4A766CA84340611C5C3AE6864640F8DF4A766CA84340804754A86E8646402B4D4A41B7A54340804754A86E864640
23468	50727	40.439413999999999	40.485156000000003	44.640256000000001	44.585278000000002	Энгельса	0103000020E61000000100000005000000C8B3CBB73E384440BE88B663EA4A4640C8B3CBB73E384440AD889AE8F3514640A6BA8097193E4440AD889AE8F3514640A6BA8097193E4440BE88B663EA4A4640C8B3CBB73E384440BE88B663EA4A4640
21819	50262	39.719037	39.730967	43.640650999999998	43.626258	улица Тимирязева	0103000020E6100000010000000500000096CE876709DC4340DF6DDE3829D0454096CE876709DC434029931ADA00D2454045BA9F5390DD434029931ADA00D2454045BA9F5390DD4340DF6DDE3829D0454096CE876709DC4340DF6DDE3829D04540
4607	50262	39.718220000000002	39.726537999999998	43.589390000000002	43.582469000000003	улица Советская	0103000020E61000000100000005000000A4AA09A2EEDB434088F71C588ECA4540A4AA09A2EEDB4340734BAB2171CB45408FA67A32FFDC4340734BAB2171CB45408FA67A32FFDC434088F71C588ECA4540A4AA09A2EEDB434088F71C588ECA4540
22195	50262	39.886527999999998	39.939141999999997	43.494284	43.421517000000001	улица Ленина	0103000020E61000000100000005000000807EDFBF79F14340A1DAE044F4B54540807EDFBF79F14340D177B7B244BF4540672618CE35F84340D177B7B244BF4540672618CE35F84340A1DAE044F4B54540807EDFBF79F14340A1DAE044F4B54540
4174	50262	39.716512999999999	39.734318000000002	43.627935000000001	43.607571999999998	улица Донская	0103000020E610000001000000050000005514AFB2B6DB43408FFB56EBC4CD45405514AFB2B6DB4340C381902C60D045409C6ED921FEDD4340C381902C60D045409C6ED921FEDD43408FFB56EBC4CD45405514AFB2B6DB43408FFB56EBC4CD4540
4078	50262	39.717627	39.735970000000002	43.622563999999997	43.593034000000003	улица Гагарина	0103000020E6100000010000000500000001DD9733DBDB434042B5C189E8CB454001DD9733DBDB43405ED5592DB0CF4540276BD44334DE43405ED5592DB0CF4540276BD44334DE434042B5C189E8CB454001DD9733DBDB434042B5C189E8CB4540
2638	50262	39.697477999999997	39.722549999999998	43.640689999999999	43.58764	улица Виноградная	0103000020E61000000100000005000000F9D687F546D9434025E99AC937CB4540F9D687F546D94340E76F422102D24540C6DCB5847CDC4340E76F422102D24540C6DCB5847CDC434025E99AC937CB4540F9D687F546D9434025E99AC937CB4540
23597	50262	39.742393	39.756101999999998	43.585844999999999	43.565801	Яна Фабрициуса	0103000020E61000000100000005000000C1E3DBBB06DF4340A585CB2A6CC84540C1E3DBBB06DF434037C30DF8FCCA4540583849F3C7E0434037C30DF8FCCA4540583849F3C7E04340A585CB2A6CC84540C1E3DBBB06DF4340A585CB2A6CC84540
22224	50262	39.852006000000003	39.869981000000003	43.525222999999997	43.513907000000003	Шоссейная	0103000020E6100000010000000500000076FF58880EED4340BE175FB4C7C1454076FF58880EED4340B20DDC813AC34540199293895BEF4340B20DDC813AC34540199293895BEF4340BE175FB4C7C1454076FF58880EED4340BE175FB4C7C14540
4190	50262	39.724148999999997	39.726134000000002	43.621115000000003	43.619418000000003	Чехова переулок	0103000020E610000001000000050000002E3718EAB0DC4340E146CA1649CF45402E3718EAB0DC43400C0742B280CF4540C0417BF5F1DC43400C0742B280CF4540C0417BF5F1DC4340E146CA1649CF45402E3718EAB0DC4340E146CA1649CF4540
24010	50262	39.721912000000003	39.727122000000001	43.625036999999999	43.617924000000002	Чехова	0103000020E61000000100000005000000844BC79C67DC4340EEB4352218CF4540844BC79C67DC43401DE5603601D04540DF196D5512DD43401DE5603601D04540DF196D5512DD4340EEB4352218CF4540844BC79C67DC4340EEB4352218CF4540
23973	50262	39.721912000000003	39.727122000000001	43.625036999999999	43.617924000000002	Чехова	0103000020E61000000100000005000000844BC79C67DC4340EEB4352218CF4540844BC79C67DC43401DE5603601D04540DF196D5512DD43401DE5603601D04540DF196D5512DD4340EEB4352218CF4540844BC79C67DC4340EEB4352218CF4540
21790	50262	39.792717000000003	39.805796999999998	43.587888	43.563423	Чекменева	0103000020E61000000100000005000000DBFD2AC077E543403868AF3E1EC84540DBFD2AC077E54340FDDAFAE93FCB4540821B295B24E74340FDDAFAE93FCB4540821B295B24E743403868AF3E1EC84540DBFD2AC077E543403868AF3E1EC84540
23892	50262	39.733707000000003	39.736617000000003	43.598139000000003	43.595233999999998	Чебрикова	0103000020E6100000010000000500000053EC681CEADD4340CFBBB1A030CC454053EC681CEADD434028BB99D18FCC4540BD56427749DE434028BB99D18FCC4540BD56427749DE4340CFBBB1A030CC454053EC681CEADD4340CFBBB1A030CC4540
23968	50262	39.716234	39.730319999999999	43.609738999999998	43.588352	Чайковского	0103000020E610000001000000050000004224438EADDB4340A2444B1E4FCB45404224438EADDB4340410C74ED0BCE4540AFCE31207BDD4340410C74ED0BCE4540AFCE31207BDD4340A2444B1E4FCB45404224438EADDB4340A2444B1E4FCB4540
20916	50262	39.716234	39.730319999999999	43.609738999999998	43.588352	Чайковского	0103000020E610000001000000050000004224438EADDB4340A2444B1E4FCB45404224438EADDB4340410C74ED0BCE4540AFCE31207BDD4340410C74ED0BCE4540AFCE31207BDD4340A2444B1E4FCB45404224438EADDB4340A2444B1E4FCB4540
4136	50262	39.722172	39.727823000000001	43.602936999999997	43.596468000000002	Цветной бульвар	0103000020E61000000100000005000000200BD12170DC4340268E3C1059CC4540200BD12170DC43403046240A2DCD45406823D74D29DD43403046240A2DCD45406823D74D29DD4340268E3C1059CC4540200BD12170DC4340268E3C1059CC4540
23364	50262	39.993068000000001	39.995620000000002	43.518039000000002	43.517451000000001	Форелевая	0103000020E61000000100000005000000215A2BDA1CFF4340292499D53BC24540215A2BDA1CFF4340BA86191A4FC245402C9FE57970FF4340BA86191A4FC245402C9FE57970FF4340292499D53BC24540215A2BDA1CFF4340292499D53BC24540
23876	50262	39.735188999999998	39.740659999999998	43.579346999999999	43.572352000000002	Учительская	0103000020E6100000010000000500000081B053AC1ADE43406DE690D442C9454081B053AC1ADE43409204E10A28CA454049BA66F2CDDE43409204E10A28CA454049BA66F2CDDE43406DE690D442C9454081B053AC1ADE43406DE690D442C94540
23661	50262	39.735107999999997	39.741827000000001	43.595579999999998	43.592002000000001	Туапсинская	0103000020E610000001000000050000009483D90418DE43405395B6B8C6CB45409483D90418DE43406A1327F73BCC45401825E82FF4DE43406A1327F73BCC45401825E82FF4DE43405395B6B8C6CB45409483D90418DE43405395B6B8C6CB4540
4563	50262	39.731586999999998	39.735107999999997	43.595233999999998	43.593601999999997	Трунова переулок	0103000020E61000000100000005000000E1968FA4A4DD43408B6B7C26FBCB4540E1968FA4A4DD4340CFBBB1A030CC45409483D90418DE4340CFBBB1A030CC45409483D90418DE43408B6B7C26FBCB4540E1968FA4A4DD43408B6B7C26FBCB4540
23840	50262	39.743633000000003	39.751933999999999	43.640839999999997	43.634687999999997	Труда	0103000020E61000000100000005000000FA9CBB5D2FDF4340F294D5743DD14540FA9CBB5D2FDF4340FCFB8C0B07D245400F60915F3FE04340FCFB8C0B07D245400F60915F3FE04340F294D5743DD14540FA9CBB5D2FDF4340F294D5743DD14540
22315	50262	39.728209	39.733240000000002	43.5899	43.584558000000001	Тоннельная	0103000020E6100000010000000500000091D3D7F335DD4340BE4EEACBD2CA454091D3D7F335DD434088F4DBD781CB45403D0FEECEDADD434088F4DBD781CB45403D0FEECEDADD4340BE4EEACBD2CA454091D3D7F335DD4340BE4EEACBD2CA4540
23924	50262	39.719037	39.730967	43.640650999999998	43.626258	Тимирязева	0103000020E6100000010000000500000096CE876709DC4340DF6DDE3829D0454096CE876709DC434029931ADA00D2454045BA9F5390DD434029931ADA00D2454045BA9F5390DD4340DF6DDE3829D0454096CE876709DC4340DF6DDE3829D04540
23931	50262	39.729565000000001	39.732225	43.576166999999998	43.571353000000002	Театральная	0103000020E6100000010000000500000033A7CB6262DD43405ABC581822C9454033A7CB6262DD434068041BD7BFC9454024287E8CB9DD434068041BD7BFC9454024287E8CB9DD43405ABC581822C9454033A7CB6262DD43405ABC581822C94540
20658	50262	39.868993000000003	39.890391000000001	43.517732000000002	43.491425999999997	Сухумское шоссе	0103000020E61000000100000005000000FAB9A1293BEF4340B933130CE7BE4540FAB9A1293BEF4340DD0BCC0A45C245408DD31055F8F14340DD0BCC0A45C245408DD31055F8F14340B933130CE7BE4540FAB9A1293BEF4340B933130CE7BE4540
22413	50262	39.927948999999998	39.933016000000002	43.423599000000003	43.420468999999997	Станиславского	0103000020E610000001000000050000008EAD6708C7F64340ACFD9DEDD1B545408EAD6708C7F6434025CFF57D38B6454087527B116DF7434025CFF57D38B6454087527B116DF74340ACFD9DEDD1B545408EAD6708C7F64340ACFD9DEDD1B54540
23935	50262	39.718220000000002	39.726537999999998	43.589390000000002	43.582469000000003	Советская	0103000020E61000000100000005000000A4AA09A2EEDB434088F71C588ECA4540A4AA09A2EEDB4340734BAB2171CB45408FA67A32FFDC4340734BAB2171CB45408FA67A32FFDC434088F71C588ECA4540A4AA09A2EEDB434088F71C588ECA4540
23920	50262	39.702454000000003	39.717914	43.625005000000002	43.619340000000001	Санаторная	0103000020E61000000100000005000000E2783E03EAD94340658D7A8846CF4540E2783E03EAD94340126BF12900D0454097AB1F9BE4DB4340126BF12900D0454097AB1F9BE4DB4340658D7A8846CF4540E2783E03EAD94340658D7A8846CF4540
22366	50262	39.891953999999998	39.893318999999998	43.497227000000002	43.494453999999998	Ростовская	0103000020E61000000100000005000000A8C4758C2BF243402DB0C7444ABF4540A8C4758C2BF2434017D86322A5BF45409DF2E84658F2434017D86322A5BF45409DF2E84658F243402DB0C7444ABF4540A8C4758C2BF243402DB0C7444ABF4540
23072	50262	39.707835000000003	39.780876999999997	43.656854000000003	43.546933000000003	Ровная	0103000020E610000001000000050000006AFB57569ADA4340350D8AE601C645406AFB57569ADA4340971FB8CA13D445406B990CC7F3E34340971FB8CA13D445406B990CC7F3E34340350D8AE601C645406AFB57569ADA4340350D8AE601C64540
24005	50262	39.704645999999997	39.718525	43.614635	43.609968000000002	Политехническая	0103000020E61000000100000005000000ECA012D731DA4340A3CD716E13CE4540ECA012D731DA43400DFD135CACCE4540E02D90A0F8DB43400DFD135CACCE4540E02D90A0F8DB4340A3CD716E13CE4540ECA012D731DA4340A3CD716E13CE4540
22355	50262	39.287801000000002	39.339885000000002	43.950814999999999	43.902309000000002	Победы	0103000020E61000000100000005000000C860C5A9D6A4434078F17EDC7EF34540C860C5A9D6A44340EBC5504EB4F9454053B3075A81AB4340EBC5504EB4F9454053B3075A81AB434078F17EDC7EF34540C860C5A9D6A4434078F17EDC7EF34540
23710	50262	39.698186999999997	39.710737000000002	43.630628999999999	43.624775999999997	Плеханова	0103000020E6100000010000000500000005BF0D315ED94340B0A9F3A8F8CF454005BF0D315ED9434060747973B8D045405187156EF9DA434060747973B8D045405187156EF9DA4340B0A9F3A8F8CF454005BF0D315ED94340B0A9F3A8F8CF4540
23649	50262	39.706155000000003	39.718992	43.608499000000002	43.603838000000003	Пирогова	0103000020E6100000010000000500000015747B4963DA4340810A47904ACD454015747B4963DA43400953944BE3CD4540F60A0BEE07DC43400953944BE3CD4540F60A0BEE07DC4340810A47904ACD454015747B4963DA4340810A47904ACD4540
24015	50262	40.006534000000002	40.009309999999999	43.428876000000002	43.426282999999998	Петропавловская	0103000020E61000000100000005000000F2272A1BD60044409EEBFB7090B64540F2272A1BD60044400805A568E5B645404CC3F011310144400805A568E5B645404CC3F011310144409EEBFB7090B64540F2272A1BD60044409EEBFB7090B64540
23900	50262	39.920510999999998	39.925891999999997	43.478430000000003	43.454155	Петрозаводская	0103000020E61000000100000005000000DB4DF04DD3F543404E2844C021BA4540DB4DF04DD3F5434070B6B9313DBD454063D009A183F6434070B6B9313DBD454063D009A183F643404E2844C021BA4540DB4DF04DD3F543404E2844C021BA4540
23716	50262	39.725118999999999	39.732135	43.627412999999997	43.615490000000001	Пасечная	0103000020E61000000100000005000000A75A0BB3D0DC4340ED815660C8CE4540A75A0BB3D0DC4340E90AB6114FD04540E4A08499B6DD4340E90AB6114FD04540E4A08499B6DD4340ED815660C8CE4540A75A0BB3D0DC4340ED815660C8CE4540
23982	50262	39.717222999999997	39.723798000000002	43.588208000000002	43.583624	Парковая	0103000020E61000000100000005000000317898F6CDDB43409294F430B4CA4540317898F6CDDB43406F9F55664ACB45408274B169A5DC43406F9F55664ACB45408274B169A5DC43409294F430B4CA4540317898F6CDDB43409294F430B4CA4540
23754	50262	39.336975000000002	39.341287000000001	43.919733000000001	43.914110000000001	Павлова переулок	0103000020E61000000100000005000000E9482EFF21AB43402979758E01F54540E9482EFF21AB4340A7069ACFB9F5454065C6DB4AAFAB4340A7069ACFB9F5454065C6DB4AAFAB43402979758E01F54540E9482EFF21AB43402979758E01F54540
23938	50262	39.722478000000002	39.731129000000003	43.579653999999998	43.573397	Орджоникидзе	0103000020E610000001000000050000002D0ABB287ADC4340F04FA91265C945402D0ABB287ADC43406F7F2E1A32CA45401F1494A295DD43406F7F2E1A32CA45401F1494A295DD4340F04FA91265C945402D0ABB287ADC4340F04FA91265C94540
22644	50262	39.867358000000003	39.868839999999999	43.516745	43.511324999999999	Октября	0103000020E6100000010000000500000045F6419605EF43404850FC1873C1454045F6419605EF43408EAF3DB324C2454073BA2C2636EF43408EAF3DB324C2454073BA2C2636EF43404850FC1873C1454045F6419605EF43404850FC1873C14540
75540	50262	39.707835000000003	39.780876999999997	43.656854000000003	43.546933000000003	Микрорайон Мирный	0103000020E610000001000000050000006AFB57569ADA4340350D8AE601C645406AFB57569ADA4340971FB8CA13D445406B990CC7F3E34340971FB8CA13D445406B990CC7F3E34340350D8AE601C645406AFB57569ADA4340350D8AE601C64540
22527	50262	39.466268999999997	39.480597000000003	43.790042999999997	43.785350999999999	Медицинская	0103000020E61000000100000005000000BE11DDB3AEBB4340C170AE6186E44540BE11DDB3AEBB434084B7072120E5454022C7D63384BD434084B7072120E5454022C7D63384BD4340C170AE6186E44540BE11DDB3AEBB4340C170AE6186E44540
22601	50262	39.707835000000003	39.780876999999997	43.656854000000003	43.546933000000003	Мацестинская	0103000020E610000001000000050000006AFB57569ADA4340350D8AE601C645406AFB57569ADA4340971FB8CA13D445406B990CC7F3E34340971FB8CA13D445406B990CC7F3E34340350D8AE601C645406AFB57569ADA4340350D8AE601C64540
21435	50262	39.737470999999999	39.749291999999997	43.620998	43.609386999999998	Макаренко	0103000020E61000000100000005000000CC5F217365DE4340C4CDA96400CE4540CC5F217365DE4340D270CADC7CCF4540C493DDCCE8DF4340D270CADC7CCF4540C493DDCCE8DF4340C4CDA96400CE4540CC5F217365DE4340C4CDA96400CE4540
23720	50262	39.737803	39.746471999999997	43.585551000000002	43.578139	Лысая Гора	0103000020E6100000010000000500000002F2255470DE434065C5707500CA454002F2255470DE4340EF91CD55F3CA45409AB0FD648CDF4340EF91CD55F3CA45409AB0FD648CDF434065C5707500CA454002F2255470DE434065C5707500CA4540
21880	50262	39.765300000000003	39.771121999999998	43.565997000000003	43.560862999999998	Лесная	0103000020E610000001000000050000007DD0B359F5E14340AA44D95BCAC745407DD0B359F5E143402B51F69672C84540F19C2D20B4E243402B51F69672C84540F19C2D20B4E24340AA44D95BCAC745407DD0B359F5E14340AA44D95BCAC74540
22161	50262	39.886527999999998	39.939141999999997	43.494284	43.421517000000001	Ленина	0103000020E61000000100000005000000807EDFBF79F14340A1DAE044F4B54540807EDFBF79F14340D177B7B244BF4540672618CE35F84340D177B7B244BF4540672618CE35F84340A1DAE044F4B54540807EDFBF79F14340A1DAE044F4B54540
23921	50262	39.666468000000002	39.697620999999998	43.648414000000002	43.631771000000001	Ландышевая	0103000020E610000001000000050000004FEACBD24ED54340D6C743DFDDD045404FEACBD24ED543406022DE3AFFD245405C001AA54BD943406022DE3AFFD245405C001AA54BD94340D6C743DFDDD045404FEACBD24ED54340D6C743DFDDD04540
21924	50262	39.707835000000003	39.780876999999997	43.656854000000003	43.546933000000003	Курортный проспект	0103000020E610000001000000050000006AFB57569ADA4340350D8AE601C645406AFB57569ADA4340971FB8CA13D445406B990CC7F3E34340971FB8CA13D445406B990CC7F3E34340350D8AE601C645406AFB57569ADA4340350D8AE601C64540
22212	50262	39.715344999999999	39.803559999999997	43.58764	43.538412000000001	Курортный проспект	0103000020E61000000100000005000000B62DCA6C90DB434011E335AFEAC44540B62DCA6C90DB434025E99AC937CB4540D72FD80DDBE6434025E99AC937CB4540D72FD80DDBE6434011E335AFEAC44540B62DCA6C90DB434011E335AFEAC44540
20580	50262	39.717654000000003	39.724598	43.607095999999999	43.593595000000001	Красноармейская	0103000020E61000000100000005000000FBEB1516DCDB4340D908C4EBFACB4540FBEB1516DCDB434026C45C52B5CD45409E5F94A0BFDC434026C45C52B5CD45409E5F94A0BFDC4340D908C4EBFACB4540FBEB1516DCDB4340D908C4EBFACB4540
20584	50262	39.717654000000003	39.724598	43.607095999999999	43.593595000000001	Красноармейская	0103000020E61000000100000005000000FBEB1516DCDB4340D908C4EBFACB4540FBEB1516DCDB434026C45C52B5CD45409E5F94A0BFDC434026C45C52B5CD45409E5F94A0BFDC4340D908C4EBFACB4540FBEB1516DCDB4340D908C4EBFACB4540
23854	50262	39.716189999999997	39.741782999999998	43.620097000000001	43.586981000000002	Конституции СССР	0103000020E6100000010000000500000072DC291DACDB4340CB2F833122CB454072DC291DACDB434082ACA7565FCF454048DDCEBEF2DE434082ACA7565FCF454048DDCEBEF2DE4340CB2F833122CB454072DC291DACDB4340CB2F833122CB4540
20736	50262	39.716189999999997	39.741782999999998	43.620097000000001	43.586981000000002	Конституции СССР	0103000020E6100000010000000500000072DC291DACDB4340CB2F833122CB454072DC291DACDB434082ACA7565FCF454048DDCEBEF2DE434082ACA7565FCF454048DDCEBEF2DE4340CB2F833122CB454072DC291DACDB4340CB2F833122CB4540
22826	50262	39.975506000000003	39.979055000000002	43.427069000000003	43.426015	Коммунаров	0103000020E61000000100000005000000A1866F61DDFC43407F4DD6A887B64540A1866F61DDFC434056116E32AAB645401EFE9AAC51FD434056116E32AAB645401EFE9AAC51FD43407F4DD6A887B64540A1866F61DDFC43407F4DD6A887B64540
22932	50262	39.756362000000003	39.763342000000002	43.574260000000002	43.569432999999997	Коммунальная	0103000020E61000000100000005000000F5F75278D0E04340AF21382EE3C84540F5F75278D0E0434053B3075A81C94540E5D4CE30B5E1434053B3075A81C94540E5D4CE30B5E14340AF21382EE3C84540F5F75278D0E04340AF21382EE3C84540
21715	50262	39.742339999999999	39.748249999999999	43.634765999999999	43.630231000000002	Кипарисовая	0103000020E610000001000000050000009E4143FF04DF434073F6CE68ABD045409E4143FF04DF43406E4E250340D14540B29DEFA7C6DF43406E4E250340D14540B29DEFA7C6DF434073F6CE68ABD045409E4143FF04DF434073F6CE68ABD04540
23051	50262	39.327902000000002	39.349722	43.923558	43.903672999999998	Калараш	0103000020E61000000100000005000000812557B1F8A943409CA38E8EABF34540812557B1F8A94340C6FA062637F645408A58C4B0C3AC4340C6FA062637F645408A58C4B0C3AC43409CA38E8EABF34540812557B1F8A943409CA38E8EABF34540
23724	50262	39.804214999999999	39.831713000000001	43.63579	43.587888	Измайловская	0103000020E61000000100000005000000F0F96184F0E64340FDDAFAE93FCB4540F0F96184F0E64340DA8F149161D145403B54539275EA4340DA8F149161D145403B54539275EA4340FDDAFAE93FCB4540F0F96184F0E64340FDDAFAE93FCB4540
23618	50262	39.96752	39.989007999999998	43.493814	43.462839000000002	Ивановская	0103000020E61000000100000005000000EB1C03B2D7FB43401C28F04E3EBB4540EB1C03B2D7FB43404A27124C35BF4540BEBD6BD097FE43404A27124C35BF4540BEBD6BD097FE43401C28F04E3EBB4540EB1C03B2D7FB43401C28F04E3EBB4540
23490	50262	39.684334999999997	39.695394	43.725009999999997	43.703305999999998	Золотая	0103000020E610000001000000050000000B410E4A98D74340508A56EE05DA45400B410E4A98D74340F0A2AF20CDDC4540D5EAABAB02D94340F0A2AF20CDDC4540D5EAABAB02D94340508A56EE05DA45400B410E4A98D74340508A56EE05DA4540
20626	50262	39.836877999999999	39.841504999999998	43.531661	43.525942000000001	Звездная	0103000020E61000000100000005000000F65E7CD11EEB4340E2CB441152C34540F65E7CD11EEB434082C7B7770DC44540D235936FB6EB434082C7B7770DC44540D235936FB6EB4340E2CB441152C34540F65E7CD11EEB4340E2CB441152C34540
23718	50262	39.716512999999999	39.734318000000002	43.627935000000001	43.607571999999998	Донская	0103000020E610000001000000050000005514AFB2B6DB43408FFB56EBC4CD45405514AFB2B6DB4340C381902C60D045409C6ED921FEDD4340C381902C60D045409C6ED921FEDD43408FFB56EBC4CD45405514AFB2B6DB43408FFB56EBC4CD4540
23613	50262	39.716512999999999	39.734318000000002	43.627935000000001	43.607571999999998	Донская	0103000020E610000001000000050000005514AFB2B6DB43408FFB56EBC4CD45405514AFB2B6DB4340C381902C60D045409C6ED921FEDD4340C381902C60D045409C6ED921FEDD43408FFB56EBC4CD45405514AFB2B6DB43408FFB56EBC4CD4540
23909	50262	39.73659	39.744343000000001	43.577212000000003	43.567062	Депутатская	0103000020E61000000100000005000000C347C49448DE4340F566D47C95C84540C347C49448DE4340EC6D3315E2C94540D600A5A146DF4340EC6D3315E2C94540D600A5A146DF4340F566D47C95C84540C347C49448DE4340F566D47C95C84540
22436	50262	39.734425000000002	39.743633000000003	43.602232000000001	43.594541999999997	Дагомысская	0103000020E61000000100000005000000B22E6EA301DE4340990CC7F319CC4540B22E6EA301DE4340664D2CF015CD4540FA9CBB5D2FDF4340664D2CF015CD4540FA9CBB5D2FDF4340990CC7F319CC4540B22E6EA301DE4340990CC7F319CC4540
23929	50262	39.720753000000002	39.725577000000001	43.629024000000001	43.626688000000001	Гранатная	0103000020E6100000010000000500000038BF61A241DC4340D865F84F37D0454038BF61A241DC43401633C2DB83D045406ADD06B5DFDC43401633C2DB83D045406ADD06B5DFDC4340D865F84F37D0454038BF61A241DC4340D865F84F37D04540
22067	50262	39.903497000000002	39.910665999999999	43.457512000000001	43.449803000000003	Голубые Дали	0103000020E610000001000000050000005E8429CAA5F3434044520B2593B945405E8429CAA5F3434087C3D2C08FBA454021CA17B490F4434087C3D2C08FBA454021CA17B490F4434044520B2593B945405E8429CAA5F3434044520B2593B94540
23828	50262	39.717627	39.735970000000002	43.622563999999997	43.593034000000003	Гагарина	0103000020E6100000010000000500000001DD9733DBDB434042B5C189E8CB454001DD9733DBDB43405ED5592DB0CF4540276BD44334DE43405ED5592DB0CF4540276BD44334DE434042B5C189E8CB454001DD9733DBDB434042B5C189E8CB4540
23311	50262	39.717762	39.725101000000002	43.593086	43.583128000000002	Воровского	0103000020E61000000100000005000000E1270EA0DFDB4340E2B034F0A3CA4540E1270EA0DFDB434094DBF63DEACB454001A60C1CD0DC434094DBF63DEACB454001A60C1CD0DC4340E2B034F0A3CA4540E1270EA0DFDB4340E2B034F0A3CA4540
23822	50262	39.696418000000001	39.702086000000001	43.636391000000003	43.625017999999997	Волжская	0103000020E61000000100000005000000412C9B3924D94340A6B4FE9600D04540412C9B3924D94340003CA24275D145405F7D3CF4DDD94340003CA24275D145405F7D3CF4DDD94340A6B4FE9600D04540412C9B3924D94340A6B4FE9600D04540
20605	50262	39.761006999999999	39.765425999999998	43.566381999999997	43.561521999999997	Возрождения	0103000020E61000000100000005000000778368AD68E1434004FEF0F3DFC74540778368AD68E14340838593347FC8454009C1AA7AF9E14340838593347FC8454009C1AA7AF9E1434004FEF0F3DFC74540778368AD68E1434004FEF0F3DFC74540
21593	50262	39.748224	39.765597	43.628704999999997	43.613173000000003	Вишневая	0103000020E61000000100000005000000890AD5CDC5DF434026E5EE737CCE4540890AD5CDC5DF434074EACA6779D0454036751E15FFE1434074EACA6779D0454036751E15FFE1434026E5EE737CCE4540890AD5CDC5DF434026E5EE737CCE4540
22215	50262	39.697477999999997	39.722549999999998	43.640689999999999	43.58764	Виноградная	0103000020E61000000100000005000000F9D687F546D9434025E99AC937CB4540F9D687F546D94340E76F422102D24540C6DCB5847CDC4340E76F422102D24540C6DCB5847CDC434025E99AC937CB4540F9D687F546D9434025E99AC937CB4540
20628	50262	39.750335	39.78951	43.573645999999997	43.546287	Бытха	0103000020E61000000100000005000000A7052FFA0AE043406F9D7FBBECC54540A7052FFA0AE0434098BD6C3B6DC94540B7EEE6A90EE5434098BD6C3B6DC94540B7EEE6A90EE543406F9D7FBBECC54540A7052FFA0AE043406F9D7FBBECC54540
20568	50262	39.915768	39.918346	43.427160999999998	43.424961000000003	Богдана Хмельницкого	0103000020E61000000100000005000000965CC5E237F54340A9893E1F65B64540965CC5E237F5434036902E36ADB64540CA349A5C8CF5434036902E36ADB64540CA349A5C8CF54340A9893E1F65B64540965CC5E237F54340A9893E1F65B64540
22116	50262	39.968750999999997	39.975228000000001	43.422269999999997	43.415740999999997	Бакинская	0103000020E61000000100000005000000D07B630800FC43409C4D470037B54540D07B630800FC43407C0A80F10CB645405E126745D4FC43407C0A80F10CB645405E126745D4FC43409C4D470037B54540D07B630800FC43409C4D470037B54540
24054	50262	39.707835000000003	39.780876999999997	43.656854000000003	43.546933000000003	Астраханская	0103000020E610000001000000050000006AFB57569ADA4340350D8AE601C645406AFB57569ADA4340971FB8CA13D445406B990CC7F3E34340971FB8CA13D445406B990CC7F3E34340350D8AE601C645406AFB57569ADA4340350D8AE601C64540
22280	50262	39.740507000000001	39.747568000000001	43.619425	43.612023999999998	Абрикосовая	0103000020E61000000100000005000000C3BAF1EEC8DE4340FD2E6CCD56CE4540C3BAF1EEC8DE434093A9825149CF4540A0C4E74EB0DF434093A9825149CF4540A0C4E74EB0DF4340FD2E6CCD56CE4540C3BAF1EEC8DE4340FD2E6CCD56CE4540
22715	50262	39.758895000000003	39.783006	43.639738000000001	43.613256999999997	Абовяна	0103000020E61000000100000005000000890CAB7823E14340838593347FCE4540890CAB7823E1434015014EEFE2D145403049658A39E4434015014EEFE2D145403049658A39E44340838593347FCE4540890CAB7823E14340838593347FCE4540
23722	50262	39.707835000000003	39.780876999999997	43.656854000000003	43.546933000000003	60 Лет ВЛКСМ	0103000020E610000001000000050000006AFB57569ADA4340350D8AE601C645406AFB57569ADA4340971FB8CA13D445406B990CC7F3E34340971FB8CA13D445406B990CC7F3E34340350D8AE601C645406AFB57569ADA4340350D8AE601C64540
23662	50262	39.599426999999999	39.607070999999998	43.729238000000002	43.717108000000003	 Лооская	0103000020E6100000010000000500000071AB2006BACC434099D9E731CADB454071AB2006BACC43400F80B8AB57DD4540CDACA580B4CD43400F80B8AB57DD4540CDACA580B4CD434099D9E731CADB454071AB2006BACC434099D9E731CADB4540
21613	50262	39.919325999999998	39.930428999999997	43.432921999999998	43.421196000000002	 Кирова	0103000020E61000000100000005000000662E7079ACF543405F9A22C0E9B54540662E7079ACF5434005DCF3FC69B74540FF1F274C18F7434005DCF3FC69B74540FF1F274C18F743405F9A22C0E9B54540662E7079ACF543405F9A22C0E9B54540
23636	50262	39.721975	39.730831999999999	43.599719	43.582397	 Горького	0103000020E61000000100000005000000CAC342AD69DC4340EE2422FC8BCA4540CAC342AD69DC434019E59997C3CC4540656F29E78BDD434019E59997C3CC4540656F29E78BDD4340EE2422FC8BCA4540CAC342AD69DC4340EE2422FC8BCA4540
23484	50262	39.721975	39.730831999999999	43.599719	43.582397	 Горького	0103000020E61000000100000005000000CAC342AD69DC4340EE2422FC8BCA4540CAC342AD69DC434019E59997C3CC4540656F29E78BDD434019E59997C3CC4540656F29E78BDD4340EE2422FC8BCA4540CAC342AD69DC4340EE2422FC8BCA4540
22622	50410	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Строителей	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
22563	50410	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Пролетарская	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
22603	50410	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Победы	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21692	50410	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Отдельская	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
22282	50410	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Набережная	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
23346	50675	38.955342999999999	39.011003000000002	45.038063000000001	45.030616999999999	улица Буденного	0103000020E6100000010000000500000034BBEEAD487A4340CFD90242EB83464034BBEEAD487A43400518963FDF8446403694DA8B688143400518963FDF8446403694DA8B68814340CFD90242EB83464034BBEEAD487A4340CFD90242EB834640
21339	50270	39.191699	39.238762000000001	44.729559999999999	44.694828999999999	Школьная	0103000020E6100000010000000500000084D6C39789984340FCA71B28F058464084D6C39789984340213CDA38625D464087C3D2C08F9E4340213CDA38625D464087C3D2C08F9E4340FCA71B28F058464084D6C39789984340FCA71B28F0584640
22061	50270	39.191699	39.238762000000001	44.729559999999999	44.694828999999999	Табачная	0103000020E6100000010000000500000084D6C39789984340FCA71B28F058464084D6C39789984340213CDA38625D464087C3D2C08F9E4340213CDA38625D464087C3D2C08F9E4340FCA71B28F058464084D6C39789984340FCA71B28F0584640
20674	50270	39.886527999999998	39.939141999999997	43.494284	43.421517000000001	Ленина	0103000020E61000000100000005000000807EDFBF79F14340A1DAE044F4B54540807EDFBF79F14340D177B7B244BF4540672618CE35F84340D177B7B244BF4540672618CE35F84340A1DAE044F4B54540807EDFBF79F14340A1DAE044F4B54540
22904	50586	41.450944	41.505014000000003	44.139057999999999	44.095880000000001	Ленина	0103000020E61000000100000005000000E9297288B8B94440952BBCCB450C4640E9297288B8B94440A31F0DA7CC114640D6027B4CA4C04440A31F0DA7CC114640D6027B4CA4C04440952BBCCB450C4640E9297288B8B94440952BBCCB450C4640
22931	50592	38.961533000000003	38.971297999999997	45.040700000000001	45.013255999999998	Октябрьская	0103000020E610000001000000050000002C836A83137B4340E63C635FB28146402C836A83137B43403E7958A835854640C9552C7E537C43403E7958A835854640C9552C7E537C4340E63C635FB28146402C836A83137B4340E63C635FB2814640
23355	50300	39.068468000000003	39.106557000000002	45.195735999999997	45.170456999999999	Советская	0103000020E610000001000000050000004969368FC3884340E82FF488D19546404969368FC38843402E5393E00D9946407714E7A8A38D43402E5393E00D9946407714E7A8A38D4340E82FF488D19546404969368FC3884340E82FF488D1954640
21674	50300	39.068468000000003	39.106557000000002	45.195735999999997	45.170456999999999	Пушкина	0103000020E610000001000000050000004969368FC3884340E82FF488D19546404969368FC38843402E5393E00D9946407714E7A8A38D43402E5393E00D9946407714E7A8A38D4340E82FF488D19546404969368FC3884340E82FF488D1954640
20918	50300	39.068468000000003	39.106557000000002	45.195735999999997	45.170456999999999	Мира	0103000020E610000001000000050000004969368FC3884340E82FF488D19546404969368FC38843402E5393E00D9946407714E7A8A38D43402E5393E00D9946407714E7A8A38D4340E82FF488D19546404969368FC3884340E82FF488D1954640
23362	50300	39.068468000000003	39.106557000000002	45.195735999999997	45.170456999999999	Красная	0103000020E610000001000000050000004969368FC3884340E82FF488D19546404969368FC38843402E5393E00D9946407714E7A8A38D43402E5393E00D9946407714E7A8A38D4340E82FF488D19546404969368FC3884340E82FF488D1954640
6412	6023	37.780715000000001	37.789833000000002	44.720376000000002	44.695777	улица набережная Адмирала Серебрякова	0103000020E61000000100000005000000923F1878EEE342408D2782380F594640923F1878EEE342406269E047355C46409A266C3F19E542406269E047355C46409A266C3F19E542408D2782380F594640923F1878EEE342408D2782380F594640
1942	6023	37.780113999999998	37.786312000000002	44.676667000000002	44.675597000000003	улица Южная	0103000020E610000001000000050000006C938AC6DAE342404B2366F6795646406C938AC6DAE3424027A435069D564640E73922DFA5E4424027A435069D564640E73922DFA5E442404B2366F6795646406C938AC6DAE342404B2366F679564640
6436	6023	37.769207999999999	37.784533000000003	44.719633000000002	44.706623999999998	улица Энгельса	0103000020E6100000010000000500000029E9616875E24240CB48BDA7725A464029E9616875E24240AA0F24EF1C5C4640FFD0CC936BE44240AA0F24EF1C5C4640FFD0CC936BE44240CB48BDA7725A464029E9616875E24240CB48BDA7725A4640
20534	6023	37.751215000000002	37.768265	44.750919000000003	44.742269999999998	улица Мефодиевская	0103000020E61000000100000005000000E0A128D027E04240A5660FB4025F4640E0A128D027E04240F778211D1E604640AAD4EC8156E24240F778211D1E604640AAD4EC8156E24240A5660FB4025F4640E0A128D027E04240A5660FB4025F4640
21020	6023	37.762884	37.782252	44.743364999999997	44.735636999999997	улица Жуковского	0103000020E610000001000000050000002252D32EA6E14240205D6C5A295E46402252D32EA6E14240DAFE9595265F4640849D62D520E44240DAFE9595265F4640849D62D520E44240205D6C5A295E46402252D32EA6E14240205D6C5A295E4640
6451	6023	37.763700999999998	37.776187999999998	44.716372999999997	44.703453000000003	улица Грибоедова	0103000020E61000000100000005000000147651F4C0E14240F5A276BF0A5A4640147651F4C0E14240635E471CB25B464019C6DD205AE34240635E471CB25B464019C6DD205AE34240F5A276BF0A5A4640147651F4C0E14240F5A276BF0A5A4640
1750	6023	37.768256000000001	37.792816000000002	44.688876	44.686857000000003	улица Героев Десантников	0103000020E61000000100000005000000577A6D3656E24240AC0320EEEA574640577A6D3656E24240E97FB9162D5846406EDFA3FE7AE54240E97FB9162D5846406EDFA3FE7AE54240AC0320EEEA574640577A6D3656E24240AC0320EEEA574640
6126	6023	37.723267999999997	37.768372999999997	44.743735999999998	44.719133999999997	улица Видова	0103000020E61000000100000005000000251FBB0B94DC424088B839950C5C4640251FBB0B94DC4240CE6DC2BD325F46409010E50B5AE24240CE6DC2BD325F46409010E50B5AE2424088B839950C5C4640251FBB0B94DC424088B839950C5C4640
23520	6023	37.780715000000001	37.789833000000002	44.720376000000002	44.695777	набережная Адмирала Серебрякова	0103000020E61000000100000005000000923F1878EEE342408D2782380F594640923F1878EEE342406269E047355C46409A266C3F19E542406269E047355C46409A266C3F19E542408D2782380F594640923F1878EEE342408D2782380F594640
24026	6023	37.780113999999998	37.786312000000002	44.676667000000002	44.675597000000003	Южная	0103000020E610000001000000050000006C938AC6DAE342404B2366F6795646406C938AC6DAE3424027A435069D564640E73922DFA5E4424027A435069D564640E73922DFA5E442404B2366F6795646406C938AC6DAE342404B2366F679564640
22848	6023	37.758868	37.759174000000002	44.688479000000001	44.686281000000001	Шоссейная	0103000020E610000001000000050000008FFD2C9622E14240DF6E490ED85746408FFD2C9622E14240CC7D7214205846409CFC169D2CE14240CC7D7214205846409CFC169D2CE14240DF6E490ED85746408FFD2C9622E14240DF6E490ED8574640
22431	6023	37.768650999999998	37.775784000000002	44.743063999999997	44.738985	Шаумяна	0103000020E61000000100000005000000D384ED2763E24240069E7B0F975E4640D384ED2763E24240DF6A9DB81C5F46404A61DEE34CE34240DF6A9DB81C5F46404A61DEE34CE34240069E7B0F975E4640D384ED2763E24240069E7B0F975E4640
22996	6023	37.753504999999997	37.764465000000001	44.723193999999999	44.714438999999999	Чайковского	0103000020E61000000100000005000000AD2F12DA72E0424054FEB5BC725B4640AD2F12DA72E04240EB54F99E915C4640E4F736FDD9E14240EB54F99E915C4640E4F736FDD9E1424054FEB5BC725B4640AD2F12DA72E0424054FEB5BC725B4640
23308	6023	37.770636000000003	37.784165000000002	44.715873999999999	44.706950999999997	Цедрика	0103000020E61000000100000005000000658F5033A4E24240EF6FD05E7D5A4640658F5033A4E2424042075DC2A15B46407CD5CA845FE4424042075DC2A15B46407CD5CA845FE44240EF6FD05E7D5A4640658F5033A4E24240EF6FD05E7D5A4640
22699	6023	37.714706999999997	37.720232000000003	44.744607000000002	44.741987999999999	Фрунзе	0103000020E61000000100000005000000739CDB847BDB424021037976F95E4640739CDB847BDB4240B4AF3C484F5F46402FC4EA8F30DC4240B4AF3C484F5F46402FC4EA8F30DC424021037976F95E4640739CDB847BDB424021037976F95E4640
23430	6023	37.778461	37.784129	44.713701999999998	44.710377999999999	Толстого	0103000020E61000000100000005000000111B2C9CA4E3424021E692AAED5A4640111B2C9CA4E342407E8B4E965A5B46402F6CCD565EE442407E8B4E965A5B46402F6CCD565EE4424021E692AAED5A4640111B2C9CA4E3424021E692AAED5A4640
21202	6023	37.695798000000003	37.844738	44.767693999999999	44.663186000000003	Тобольского 	0103000020E61000000100000005000000A54FABE80FD9424021956247E3544640A54FABE80FD94240EFAA07CC436246401FD8F15F20EC4240EFAA07CC436246401FD8F15F20EC424021956247E3544640A54FABE80FD9424021956247E3544640
23111	6023	37.785611000000003	37.789940999999999	44.705579999999998	44.693150000000003	Суворовская	0103000020E610000001000000050000005E30B8E68EE44240789CA223B95846405E30B8E68EE44240185B0872505A4640806264C91CE54240185B0872505A4640806264C91CE54240789CA223B95846405E30B8E68EE44240789CA223B9584640
23742	6023	37.713161999999997	37.724265000000003	44.744216000000002	44.740701000000001	Спортивная	0103000020E61000000100000005000000FE5F75E448DB4240A88E554ACF5E4640FE5F75E448DB424079944A78425F464098512CB7B4DC424079944A78425F464098512CB7B4DC4240A88E554ACF5E4640FE5F75E448DB4240A88E554ACF5E4640
23097	6023	37.764294	37.783141000000001	44.725577000000001	44.713151000000003	Советов	0103000020E61000000100000005000000B743C362D4E142400B0E2F88485B4640B743C362D4E142406ADD06B5DF5C46401094DBF63DE442406ADD06B5DF5C46401094DBF63DE442400B0E2F88485B4640B743C362D4E142400B0E2F88485B4640
22382	6023	37.695798000000003	37.844738	44.767693999999999	44.663186000000003	Севрюкова	0103000020E61000000100000005000000A54FABE80FD9424021956247E3544640A54FABE80FD94240EFAA07CC436246401FD8F15F20EC4240EFAA07CC436246401FD8F15F20EC424021956247E3544640A54FABE80FD9424021956247E3544640
22689	6023	37.742491999999999	37.756937000000001	44.703293000000002	44.699857999999999	Садовая	0103000020E6100000010000000500000054C554FA09DF424007EC6AF29459464054C554FA09DF4240BC404981055A4640F110C64FE3E04240BC404981055A4640F110C64FE3E0424007EC6AF29459464054C554FA09DF424007EC6AF294594640
21095	6023	37.758374000000003	37.777275000000003	44.721625000000003	44.709198999999998	Рубина	0103000020E610000001000000050000008011346612E142408EAD6708C75A46408011346612E14240EE7C3F355E5C4640CC7F48BF7DE34240EE7C3F355E5C4640CC7F48BF7DE342408EAD6708C75A46408011346612E142408EAD6708C75A4640
23081	6023	37.764986	37.782404	44.719051	44.704138	Революции 1905 Года	0103000020E61000000100000005000000EDF2AD0FEBE1424078EFA831215A4640EDF2AD0FEBE14240FB93F8DC095C46403A2174D025E44240FB93F8DC095C46403A2174D025E4424078EFA831215A4640EDF2AD0FEBE1424078EFA831215A4640
23460	6023	37.776403000000002	37.778281	44.700685	44.692976999999999	Прямая	0103000020E6100000010000000500000016C26A2C61E34240AAF06778B358464016C26A2C61E342401DE6CB0BB0594640910C39B69EE342401DE6CB0BB0594640910C39B69EE34240AAF06778B358464016C26A2C61E34240AAF06778B3584640
23549	6023	37.742941000000002	37.747774	44.724027	44.719563000000001	Промышленная	0103000020E61000000100000005000000C4EDD0B018DF4240B134F0A31A5C4640C4EDD0B018DF4240E335AFEAAC5C46404966F50EB7DF4240E335AFEAAC5C46404966F50EB7DF4240B134F0A31A5C4640C4EDD0B018DF4240B134F0A31A5C4640
23518	6023	37.714832999999999	37.719208000000002	44.762568000000002	44.759067000000002	Полевая	0103000020E61000000100000005000000008DD2A57FDB4240863C821B29614640008DD2A57FDB4240F27C06D49B614640C382FB010FDC4240F27C06D49B614640C382FB010FDC4240863C821B29614640008DD2A57FDB4240863C821B29614640
23633	6023	37.767923000000003	37.771948000000002	44.721240999999999	44.718556999999997	Победы	0103000020E61000000100000005000000516C054D4BE24240EBA7FFACF95B4640516C054D4BE2424065C405A0515C4640371B2B31CFE2424065C405A0515C4640371B2B31CFE24240EBA7FFACF95B4640516C054D4BE24240EBA7FFACF95B4640
21586	6023	37.718507000000002	37.726286000000002	44.749453000000003	44.742820000000002	Первомайская	0103000020E610000001000000050000003A799109F8DB42404968CBB9145F46403A799109F8DB4240CE716E13EE5F464076C58CF0F6DC4240CE716E13EE5F464076C58CF0F6DC42404968CBB9145F46403A799109F8DB42404968CBB9145F4640
23010	6023	37.773240999999999	37.783284999999999	44.712440000000001	44.704656999999997	Пархоменко	0103000020E610000001000000050000009276A38FF9E24240E0F25833325A46409276A38FF9E242405E2EE23B315B46404339D1AE42E442405E2EE23B315B46404339D1AE42E44240E0F25833325A46409276A38FF9E24240E0F25833325A4640
1965	6023	37.759174000000002	37.770636000000003	44.708578000000003	44.688479000000001	Мысхакское шоссе	0103000020E610000001000000050000009CFC169D2CE14240CC7D7214205846409CFC169D2CE14240225514AFB25A4640658F5033A4E24240225514AFB25A4640658F5033A4E24240CC7D7214205846409CFC169D2CE14240CC7D721420584640
23511	6023	37.766548999999998	37.784210000000002	44.728900000000003	44.715873999999999	Мира	0103000020E6100000010000000500000008E412471EE2424042075DC2A15B464008E412471EE24240F7065F984C5D46401C9947FE60E44240F7065F984C5D46401C9947FE60E4424042075DC2A15B464008E412471EE2424042075DC2A15B4640
22368	6023	37.751215000000002	37.768265	44.750919000000003	44.742269999999998	Мефодиевская	0103000020E61000000100000005000000E0A128D027E04240A5660FB4025F4640E0A128D027E04240F778211D1E604640AAD4EC8156E24240F778211D1E604640AAD4EC8156E24240A5660FB4025F4640E0A128D027E04240A5660FB4025F4640
21266	6023	37.768166000000001	37.777985000000001	44.750464000000001	44.739952000000002	Менжинского	0103000020E6100000010000000500000017F3734353E242400E4E44BFB65E464017F3734353E24240A56950340F604640A8E3310395E34240A56950340F604640A8E3310395E342400E4E44BFB65E464017F3734353E242400E4E44BFB65E4640
20539	6023	37.760520999999997	37.763314999999999	44.744152	44.743274999999997	Межевая	0103000020E61000000100000005000000EA758BC058E142409A779CA2235F4640EA758BC058E1424062A06B5F405F4640EBC5504EB4E1424062A06B5F405F4640EBC5504EB4E142409A779CA2235F4640EA758BC058E142409A779CA2235F4640
23627	6023	37.767617999999999	37.768704999999997	44.691760000000002	44.685555999999998	Малоземельская	0103000020E6100000010000000500000014E97E4E41E24240CDC98B4CC057464014E97E4E41E242402A5778978B584640C6A2E9EC64E242402A5778978B584640C6A2E9EC64E24240CDC98B4CC057464014E97E4E41E24240CDC98B4CC0574640
23941	6023	37.737685999999997	37.747729	44.733407999999997	44.722591999999999	Луначарского	0103000020E61000000100000005000000C85BAE7E6CDE4240F52C08E57D5C4640C85BAE7E6CDE4240F84F3750E05D4640A9A27895B5DF4240F84F3750E05D4640A9A27895B5DF4240F52C08E57D5C4640C85BAE7E6CDE4240F52C08E57D5C4640
1745	6023	37.783833000000001	37.794936	44.705342999999999	44.673243999999997	Ленина проспект	0103000020E610000001000000050000004643C6A354E44240361D01DC2C5646404643C6A354E4424034BBEEAD485A4640DF347D76C0E5424034BBEEAD485A4640DF347D76C0E54240361D01DC2C5646404643C6A354E44240361D01DC2C564640
22596	6023	37.783833000000001	37.794936	44.705342999999999	44.673243999999997	Ленина	0103000020E610000001000000050000004643C6A354E44240361D01DC2C5646404643C6A354E4424034BBEEAD485A4640DF347D76C0E5424034BBEEAD485A4640DF347D76C0E54240361D01DC2C5646404643C6A354E44240361D01DC2C564640
23990	6023	37.774507999999997	37.784354	44.713791999999998	44.705342999999999	Лейтенанта Шмидта	0103000020E61000000100000005000000C43E011423E3424034BBEEAD485A4640C43E011423E34240BE1248895D5B46404F3E3DB665E44240BE1248895D5B46404F3E3DB665E4424034BBEEAD485A4640C43E011423E3424034BBEEAD485A4640
23691	6023	37.761248999999999	37.787542999999999	44.694291	44.691651	Куникова	0103000020E610000001000000050000006D8E739B70E14240739F1C05885846406D8E739B70E142401D740987DE584640CC988235CEE442401D740987DE584640CC988235CEE44240739F1C05885846406D8E739B70E14240739F1C0588584640
6052	6023	37.749679	37.752966000000001	44.716923999999999	44.714720999999997	Краснознаменный переулок	0103000020E61000000100000005000000BEBF417BF5DF4240D8614CFA7B5B4640BEBF417BF5DF4240D7DB662AC45B4640FE7F9C3061E04240D7DB662AC45B4640FE7F9C3061E04240D8614CFA7B5B4640BEBF417BF5DF4240D8614CFA7B5B4640
21995	6023	37.748483999999998	37.764105999999998	44.756839999999997	44.744439999999997	Краснодарская	0103000020E6100000010000000500000025CADE52CEDF4240C8EA56CF495F464025CADE52CEDF4240FE261422E0604640B456B439CEE14240FE261422E0604640B456B439CEE14240C8EA56CF495F464025CADE52CEDF4240C8EA56CF495F4640
20485	6023	37.774552999999997	37.779476000000003	44.741655000000002	44.738159000000003	Красная	0103000020E6100000010000000500000064027E8D24E34240C11F7EFE7B5E464064027E8D24E342401BF5108DEE5E46402A029CDEC5E342401BF5108DEE5E46402A029CDEC5E34240C11F7EFE7B5E464064027E8D24E34240C11F7EFE7B5E4640
23671	6023	37.750909	37.764465000000001	44.729906	44.723193999999999	Козлова	0103000020E61000000100000005000000D3A23EC91DE04240EB54F99E915C4640D3A23EC91DE04240BC934F8F6D5D4640E4F736FDD9E14240BC934F8F6D5D4640E4F736FDD9E14240EB54F99E915C4640D3A23EC91DE04240EB54F99E915C4640
21808	6023	37.773349000000003	37.781596	44.750079999999997	44.74042	Кирова	0103000020E6100000010000000500000079B29B19FDE24240F4A62215C65E464079B29B19FDE242401CB1169F026046409B5775560BE442401CB1169F026046409B5775560BE44240F4A62215C65E464079B29B19FDE24240F4A62215C65E4640
23377	6023	37.781416	37.782808000000003	44.701434999999996	44.696328000000001	Карамзина	0103000020E610000001000000050000001B49827005E4424001A5A146215946401B49827005E4424087A2409FC85946400A86730D33E4424087A2409FC85946400A86730D33E4424001A5A146215946401B49827005E4424001A5A14621594640
23753	6023	37.776718000000002	37.788288000000001	44.708815000000001	44.703144999999999	Исаева	0103000020E61000000100000005000000761BD47E6BE3424047ACC5A7005A4640761BD47E6BE3424006F52D73BA5A464025EA059FE6E4424006F52D73BA5A464025EA059FE6E4424047ACC5A7005A4640761BD47E6BE3424047ACC5A7005A4640
23768	6023	37.759900999999999	37.768219999999999	44.690894	44.688408000000003	Золотаревского	0103000020E610000001000000050000004E999B6F44E142400327DBC01D5846404E999B6F44E142405680EF366F5846400A11700855E242405680EF366F5846400A11700855E242400327DBC01D5846404E999B6F44E142400327DBC01D584640
21627	6023	37.695798000000003	37.844738	44.767693999999999	44.663186000000003	Дружбы	0103000020E61000000100000005000000A54FABE80FD9424021956247E3544640A54FABE80FD94240EFAA07CC436246401FD8F15F20EC4240EFAA07CC436246401FD8F15F20EC424021956247E3544640A54FABE80FD9424021956247E3544640
1790	6023	37.768759000000003	37.780329000000002	44.707796000000002	44.676243999999997	Дзержинского проспект	0103000020E61000000100000005000000BAC0E5B166E24240E00ED4298F564640BAC0E5B166E24240AC1E300F995A4640698F17D2E1E34240AC1E300F995A4640698F17D2E1E34240E00ED4298F564640BAC0E5B166E24240E00ED4298F564640
23682	6023	37.700127999999999	37.726393999999999	44.748339000000001	44.743262000000001	Горького	0103000020E61000000100000005000000C78157CB9DD94240062E8F35235F4640C78157CB9DD9424022A98592C95F46405C01857AFADC424022A98592C95F46405C01857AFADC4240062E8F35235F4640C78157CB9DD94240062E8F35235F4640
23857	6023	37.726447999999998	37.740775999999997	44.735419	44.729284999999997	Герцена	0103000020E610000001000000050000004F1F813FFCDC42404F3BFC35595D46404F1F813FFCDC4240B3EDB435225E4640B2D47ABFD1DE4240B3EDB435225E4640B2D47ABFD1DE42404F3BFC35595D46404F1F813FFCDC42404F3BFC35595D4640
20424	6023	37.768256000000001	37.792816000000002	44.688876	44.686857000000003	Героев Десантников	0103000020E61000000100000005000000577A6D3656E24240AC0320EEEA574640577A6D3656E24240E97FB9162D5846406EDFA3FE7AE54240E97FB9162D5846406EDFA3FE7AE54240AC0320EEEA574640577A6D3656E24240AC0320EEEA574640
23925	6023	37.759174000000002	37.780175999999997	44.688479000000001	44.684249000000001	Волгоградская	0103000020E610000001000000050000009CFC169D2CE142400DA9A278955746409CFC169D2CE14240CC7D721420584640E28FA2CEDCE34240CC7D721420584640E28FA2CEDCE342400DA9A278955746409CFC169D2CE142400DA9A27895574640
22994	6023	37.748466000000001	37.752625000000002	44.701402999999999	44.699179000000001	Виноградная	0103000020E610000001000000050000007F15E0BBCDDF424066868DB27E5946407F15E0BBCDDF42407C28D192C75946407593180456E042407C28D192C75946407593180456E0424066868DB27E5946407F15E0BBCDDF424066868DB27E594640
23372	6023	37.723267999999997	37.768372999999997	44.743735999999998	44.719133999999997	Видова	0103000020E61000000100000005000000251FBB0B94DC424088B839950C5C4640251FBB0B94DC4240CE6DC2BD325F46409010E50B5AE24240CE6DC2BD325F46409010E50B5AE2424088B839950C5C4640251FBB0B94DC424088B839950C5C4640
6085	6023	37.727849999999997	37.763781999999999	44.742654000000002	44.725788000000001	Анапское шоссе	0103000020E61000000100000005000000613255302ADD424025EA059FE65C4640613255302ADD42402E1F49490F5F464001A3CB9BC3E142402E1F49490F5F464001A3CB9BC3E1424025EA059FE65C4640613255302ADD424025EA059FE65C4640
20479	6023	37.695798000000003	37.844738	44.767693999999999	44.663186000000003	50 лет Октября	0103000020E61000000100000005000000A54FABE80FD9424021956247E3544640A54FABE80FD94240EFAA07CC436246401FD8F15F20EC4240EFAA07CC436246401FD8F15F20EC424021956247E3544640A54FABE80FD9424021956247E3544640
21684	6023	37.695798000000003	37.844738	44.767693999999999	44.663186000000003	40 лет Октября	0103000020E61000000100000005000000A54FABE80FD9424021956247E3544640A54FABE80FD94240EFAA07CC436246401FD8F15F20EC4240EFAA07CC436246401FD8F15F20EC424021956247E3544640A54FABE80FD9424021956247E3544640
23864	6023	37.762273	37.766486	44.716348000000004	44.713171000000003	 Яковлева	0103000020E61000000100000005000000D9CF622992E1424052BAF42F495B4640D9CF622992E142400B47904AB15B4640C26B97361CE242400B47904AB15B4640C26B97361CE2424052BAF42F495B4640D9CF622992E1424052BAF42F495B4640
23855	6023	37.743335999999999	37.750891000000003	44.725659999999998	44.721938999999999	 Чкалова	0103000020E6100000010000000500000040F850A225DF42407D5A457F685C464040F850A225DF4240F701486DE25C46402DEE3F321DE04240F701486DE25C46402DEE3F321DE042407D5A457F685C464040F850A225DF42407D5A457F685C4640
23799	6023	37.785611000000003	37.789940999999999	44.705579999999998	44.693150000000003	 Суворовская	0103000020E610000001000000050000005E30B8E68EE44240789CA223B95846405E30B8E68EE44240185B0872505A4640806264C91CE54240185B0872505A4640806264C91CE54240789CA223B95846405E30B8E68EE44240789CA223B9584640
23604	6023	37.750909	37.764465000000001	44.729906	44.723193999999999	 Козлова	0103000020E61000000100000005000000D3A23EC91DE04240EB54F99E915C4640D3A23EC91DE04240BC934F8F6D5D4640E4F736FDD9E14240BC934F8F6D5D4640E4F736FDD9E14240EB54F99E915C4640D3A23EC91DE04240EB54F99E915C4640
23865	6023	37.762408000000001	37.765245999999998	44.720908000000001	44.718102999999999	 Гладкова	0103000020E61000000100000005000000B91AD99596E142406A1492CCEA5B4640B91AD99596E142405FB69DB6465C464089B2B794F3E142405FB69DB6465C464089B2B794F3E142406A1492CCEA5B4640B91AD99596E142406A1492CCEA5B4640
21600	50394	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Чапаева	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
22665	50394	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Победы	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
22008	50394	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Первомайская	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
21951	50394	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Красная	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
21747	50394	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Кооперативная	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
22175	50394	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	К.Маркса	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
21147	5827	37.784165000000002	37.785575000000001	44.745420000000003	44.736834000000002	Сакко и Ванцетти	0103000020E610000001000000050000007CD5CA845FE442405A4A9693505E46407CD5CA845FE4424065E42CEC695F464011C7BAB88DE4424065E42CEC695F464011C7BAB88DE442405A4A9693505E46407CD5CA845FE442405A4A9693505E4640
22082	50462	40.931286999999998	40.945129999999999	45.035127000000003	45.027603999999997	Восточная	0103000020E610000001000000050000005018946934774440909E2287888346405018946934774440721AA20A7F844640F73B1405FA784440721AA20A7F844640F73B1405FA784440909E2287888346405018946934774440909E228788834640
20463	50248	39.424992000000003	39.453252999999997	44.773823999999998	44.747672999999999	Красная	0103000020E61000000100000005000000E4874A2366B64340158DB5BFB35F4640E4874A2366B64340116E32AA0C6346402DE8BD3104BA4340116E32AA0C6346402DE8BD3104BA4340158DB5BFB35F4640E4874A2366B64340158DB5BFB35F4640
23587	50783	39.956471000000001	39.969568000000002	43.415695999999997	43.412827	улица Казачья	0103000020E61000000100000005000000454948A46DFA4340F1F3DF83D7B44540454948A46DFA4340FC89CA8635B54540C39FE1CD1AFC4340FC89CA8635B54540C39FE1CD1AFC4340F1F3DF83D7B44540454948A46DFA4340F1F3DF83D7B44540
23886	50856	39.127783999999998	39.128655000000002	45.163124000000003	45.150666999999999	Октябрьская	0103000020E61000000100000005000000DD79E2395B90434010CB660E49934640DD79E2395B904340AB984A3FE1944640C3BB5CC477904340AB984A3FE1944640C3BB5CC47790434010CB660E49934640DD79E2395B90434010CB660E49934640
21673	50405	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Халтурина	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21709	50405	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Турчанинова	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21825	50405	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Победы	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21945	50405	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Константинова	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21795	50405	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Ватутина	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
22182	50392	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Мира	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
22261	50392	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Ленина	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
21588	50392	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Крупской	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20908	50299	39.326860000000003	39.346891999999997	44.493557000000003	44.482971999999997	Октябрьская	0103000020E610000001000000050000006F2F698CD6A943401D71C806D23D46406F2F698CD6A943401FDB32E02C3F46403C9F01F566AC43401FDB32E02C3F46403C9F01F566AC43401D71C806D23D46406F2F698CD6A943401D71C806D23D4640
20779	50286	38.881267999999999	38.888033	45.067678000000001	45.056612999999999	Центральная	0103000020E610000001000000050000007381CB63CD704340A4C343183F8746407381CB63CD704340505436ACA98846406762BA10AB714340505436ACA98846406762BA10AB714340A4C343183F8746407381CB63CD704340A4C343183F874640
21942	50444	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Темченко	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21927	50444	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Свердлова	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
22269	50444	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Ленина	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
22352	50444	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Жукова	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21966	50444	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Авиационная	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
23395	50476	40.49926	40.616059	45.469239999999999	45.410882000000001	Черноморская	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
22227	50476	40.49926	40.616059	45.469239999999999	45.410882000000001	С.Целых	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
22882	50476	40.49926	40.616059	45.469239999999999	45.410882000000001	Пушкина	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23304	50476	40.49926	40.616059	45.469239999999999	45.410882000000001	Мира	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23506	50476	40.49926	40.616059	45.469239999999999	45.410882000000001	Линейная	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
22767	50476	40.49926	40.616059	45.469239999999999	45.410882000000001	Красная	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
20429	50242	39.191834	39.191896999999997	45.075297999999997	45.073101999999999	Сербская	0103000020E6100000010000000500000064213A048E984340D7A205685B89464064213A048E98434023BA675DA3894640AA99B5149098434023BA675DA3894640AA99B51490984340D7A205685B89464064213A048E984340D7A205685B894640
5237	242	38.931528999999998	38.967489	45.057282000000001	45.051569999999998	улица космонавта Гагарина	0103000020E6100000010000000500000046239F573C77434034BA83D89986464046239F573C77434022533E0455874640B01EF7ADD67B434022533E0455874640B01EF7ADD67B434034BA83D89986464046239F573C77434034BA83D899864640
4749	242	38.941231000000002	38.949010000000001	45.054378	45.039712000000002	улица Энгельса	0103000020E610000001000000050000009E7DE5417A7843401FA16648158546409E7DE5417A7843409ACFB9DBF5864640DAC9E028797943409ACFB9DBF5864640DAC9E028797943401FA16648158546409E7DE5417A7843401FA1664815854640
15429	242	38.772941000000003	38.819823999999997	45.051347	45.049028999999997	улица Широкая	0103000020E61000000100000005000000685E0EBBEF6243401DC70F9546864640685E0EBBEF624340B5DFDA8992864640EA3C2AFEEF684340B5DFDA8992864640EA3C2AFEEF6843401DC70F9546864640685E0EBBEF6243401DC70F9546864640
16525	242	39.064399000000002	39.071584999999999	45.022074000000003	45.02008	улица Центральная	0103000020E610000001000000050000009372F7393E884340DFA63FFB918246409372F7393E884340C40B2252D38246402CF180B229894340C40B2252D38246402CF180B229894340DFA63FFB918246409372F7393E884340DFA63FFB91824640
5135	242	38.973193000000002	38.984834999999997	45.068868999999999	45.068753999999998	улица Федора Лузана	0103000020E610000001000000050000001BD99596917C43400EBC5AEECC8846401BD99596917C4340A75A0BB3D0884640637AC2120F7E4340A75A0BB3D0884640637AC2120F7E43400EBC5AEECC8846401BD99596917C43400EBC5AEECC884640
5320	242	38.932319999999997	38.938707000000001	45.073056999999999	45.039610000000003	улица Урицкого	0103000020E610000001000000050000000FB40243567743401B4CC3F0118546400FB402435677434037DF88EE598946405DC30C8D2778434037DF88EE598946405DC30C8D277843401B4CC3F0118546400FB40243567743401B4CC3F011854640
6165	242	39.062781999999999	39.081018	45.006323000000002	45.005628000000002	улица Трудовой Славы	0103000020E610000001000000050000008463963D0988434090F8156BB88046408463963D09884340371B2B31CF80464094313ECC5E8A4340371B2B31CF80464094313ECC5E8A434090F8156BB88046408463963D0988434090F8156BB8804640
16089	242	38.936272000000002	38.943629000000001	45.055314000000003	45.039509000000002	улица Труда	0103000020E610000001000000050000008C14CAC2D7774340E77283A10E8546408C14CAC2D777434067817687148746405247C7D5C878434067817687148746405247C7D5C8784340E77283A10E8546408C14CAC2D7774340E77283A10E854640
6452	242	39.012360000000001	39.026544000000001	45.111401000000001	45.106904	улица Тепличная	0103000020E61000000100000005000000A8E3310395814340E2E7BF07AF8D4640A8E3310395814340F0DE5163428E4640D8F335CB65834340F0DE5163428E4640D8F335CB65834340E2E7BF07AF8D4640A8E3310395814340E2E7BF07AF8D4640
6821	242	38.918764000000003	38.938051000000002	45.065679000000003	45.058140999999999	улица Темрюкская	0103000020E61000000100000005000000FF5E0A0F9A75434043C70E2A71874640FF5E0A0F9A7543405A84622B68884640747D1F0E127843405A84622B68884640747D1F0E1278434043C70E2A71874640FF5E0A0F9A75434043C70E2A71874640
2543	242	39.014111	39.019024999999999	45.024659999999997	45.007655	улица Таманская	0103000020E61000000100000005000000C6C1A563CE8143405053CBD6FA804640C6C1A563CE8143407AC2120F28834640386744696F8243407AC2120F28834640386744696F8243405053CBD6FA804640C6C1A563CE8143405053CBD6FA804640
20446	242	39.007418999999999	39.026327999999999	45.014128999999997	45.012619000000001	улица Степная	0103000020E610000001000000050000003C2F151BF38043407427D87F9D8146403C2F151BF38043406C76A4FACE8146400B7C45B75E8343406C76A4FACE8146400B7C45B75E8343407427D87F9D8146403C2F151BF38043407427D87F9D814640
5589	242	38.973605999999997	39.046683999999999	45.021520000000002	45.012949999999996	улица Ставропольская	0103000020E610000001000000050000003D98141F9F7C4340D93D7958A88146403D98141F9F7C4340DF1AD82AC18246408C9FC6BDF9854340DF1AD82AC18246408C9FC6BDF9854340D93D7958A88146403D98141F9F7C4340D93D7958A8814640
5778	242	39.047538000000003	39.114156999999999	45.043762999999998	45.021832000000003	улица Сормовская	0103000020E610000001000000050000009CA8A5B915864340CE001764CB8246409CA8A5B9158643402EE3A6069A85464003CE52B29C8E43402EE3A6069A85464003CE52B29C8E4340CE001764CB8246409CA8A5B915864340CE001764CB824640
6798	242	38.923507000000001	38.938347	45.068429000000002	45.062401000000001	улица Славянская	0103000020E610000001000000050000004450357A357643406D1E87C1FC8746404450357A357643408B8C0E48C28846405DA626C11B7843408B8C0E48C28846405DA626C11B7843406D1E87C1FC8746404450357A357643406D1E87C1FC874640
15672	242	38.986460999999998	38.997663000000003	45.052467999999998	45.023902	улица Садовая	0103000020E61000000100000005000000C5E3A25A447E43408D2782380F834640C5E3A25A447E4340130B7C45B7864640F2B6D26BB37F4340130B7C45B7864640F2B6D26BB37F43408D2782380F834640C5E3A25A447E43408D2782380F834640
5042	242	38.964973000000001	38.977110000000003	45.068677999999998	45.015192999999996	улица Рашпилевская	0103000020E61000000100000005000000F2423A3C847B434066101FD8F1814640F2423A3C847B434033FAD170CA8846401B4CC3F0117D434033FAD170CA8846401B4CC3F0117D434066101FD8F1814640F2423A3C847B434066101FD8F1814640
15932	242	39.021180999999999	39.022537	45.018766999999997	45.008923000000003	улица Пугачева	0103000020E61000000100000005000000F6251B0FB682434053978C6324814640F6251B0FB68243403C9F01F56682464098F90E7EE28243403C9F01F56682464098F90E7EE282434053978C6324814640F6251B0FB682434053978C6324814640
16247	242	39.009287	39.017974000000002	45.047406000000002	45.045814	улица Первомайская	0103000020E6100000010000000500000094A300513081434077D9AF3BDD85464094A30051308143402DD1596611864640D316D7F84C8243402DD1596611864640D316D7F84C82434077D9AF3BDD85464094A300513081434077D9AF3BDD854640
15449	242	38.961533000000003	38.971297999999997	45.040700000000001	45.013255999999998	улица Октябрьская	0103000020E610000001000000050000002C836A83137B4340E63C635FB28146402C836A83137B43403E7958A835854640C9552C7E537C43403E7958A835854640C9552C7E537C4340E63C635FB28146402C836A83137B4340E63C635FB2814640
4189	242	38.994151000000002	39.005757000000003	45.104816999999997	45.047673000000003	улица Московская	0103000020E6100000010000000500000092240857407F43407CF31B261A86464092240857407F43404C88B9A46A8D46408E5C37A5BC8043404C88B9A46A8D46408E5C37A5BC8043407CF31B261A86464092240857407F43407CF31B261A864640
23502	242	39.064174000000001	39.074029000000003	45.029221999999997	45.026406000000001	улица Молодежная	0103000020E6100000010000000500000073A087DA36884340873595456183464073A087DA368843406F29E78BBD83464051FA42C8798943406F29E78BBD83464051FA42C879894340873595456183464073A087DA368843408735954561834640
15891	242	38.959862000000001	38.987853999999999	45.022067999999997	45.018014999999998	улица Мира	0103000020E610000001000000050000002A560DC2DC7A434031EBC5504E8246402A560DC2DC7A4340E124CD1FD3824640849CF7FF717E4340E124CD1FD3824640849CF7FF717E434031EBC5504E8246402A560DC2DC7A434031EBC5504E824640
15379	242	38.961713000000003	38.985221000000003	45.025207999999999	45.019008999999997	улица Ленина	0103000020E61000000100000005000000AC915D69197B434032AA0CE36E824640AC915D69197B43407DCC07043A8346408D2AC3B81B7E43407DCC07043A8346408D2AC3B81B7E434032AA0CE36E824640AC915D69197B434032AA0CE36E824640
23389	242	38.961713000000003	38.985221000000003	45.025207999999999	45.019008999999997	улица Ленина	0103000020E61000000100000005000000AC915D69197B434032AA0CE36E824640AC915D69197B43407DCC07043A8346408D2AC3B81B7E43407DCC07043A8346408D2AC3B81B7E434032AA0CE36E824640AC915D69197B434032AA0CE36E824640
67	242	38.967146999999997	38.983901000000003	45.059095999999997	45.014823	улица Красная	0103000020E6100000010000000500000056B60F79CB7B4340431D56B8E581464056B60F79CB7B434086A92D759087464038C0CC77F07D434086A92D759087464038C0CC77F07D4340431D56B8E581464056B60F79CB7B4340431D56B8E5814640
6495	242	39.001418000000001	39.007669999999997	45.065246000000002	45.062578999999999	улица Карякина	0103000020E6100000010000000500000018D00B772E8043404C35B3960288464018D00B772E804340F0181EFB5988464085949F54FB804340F0181EFB5988464085949F54FB8043404C35B3960288464018D00B772E8043404C35B39602884640
4826	242	38.959826	38.963833000000001	45.013522999999999	44.998846999999998	улица Индустриальная	0103000020E61000000100000005000000DDEC0F94DB7A4340965AEF37DA7F4640DDEC0F94DB7A4340355F251FBB8146401DE736E15E7B4340355F251FBB8146401DE736E15E7B4340965AEF37DA7F4640DDEC0F94DB7A4340965AEF37DA7F4640
23410	242	39.068468000000003	39.079374000000001	45.192585000000001	45.184415999999999	улица Заречная	0103000020E610000001000000050000004969368FC3884340F86D88F19A9746404969368FC38843409F5912A0A69846408C135FED288A43409F5912A0A69846408C135FED288A4340F86D88F19A9746404969368FC3884340F86D88F19A974640
15368	242	39.106171000000003	39.113841999999998	45.101146	45.094268999999997	улица Дорожная	0103000020E610000001000000050000004E64E602978D43406803B001118C46404E64E602978D4340840F255AF28C4640A374E95F928E4340840F255AF28C4640A374E95F928E43406803B001118C46404E64E602978D43406803B001118C4640
2601	242	38.957517000000003	39.004688000000002	45.037286000000002	45.030259999999998	улица Длинная	0103000020E61000000100000005000000992EC4EA8F7A43404030478FDF834640992EC4EA8F7A4340A14CA3C9C58446408257CB9D99804340A14CA3C9C58446408257CB9D998043404030478FDF834640992EC4EA8F7A43404030478FDF834640
7205	242	39.012180000000001	39.029724000000002	45.011350999999998	44.994494000000003	улица Воронежская	0103000020E6100000010000000500000028D53E1D8F814340BC0853944B7F464028D53E1D8F81434071E316F37381464002F4FBFECD83434071E316F37381464002F4FBFECD834340BC0853944B7F464028D53E1D8F814340BC0853944B7F4640
7748	242	39.003646000000003	39.007077000000002	45.039025000000002	45.026425000000003	улица Володарского	0103000020E610000001000000050000007061DD7877804340FE65F7E4618346407061DD7877804340FB5C6DC5FE844640E3C62DE6E7804340FB5C6DC5FE844640E3C62DE6E7804340FE65F7E4618346407061DD7877804340FE65F7E461834640
4087	242	39.026570999999997	39.040889999999997	45.014702	45.010069999999999	улица Бургасская	0103000020E61000000100000005000000D102B4AD66834340DA5548F949814640D102B4AD66834340C89750C1E1814640E15D2EE23B854340C89750C1E1814640E15D2EE23B854340DA5548F949814640D102B4AD66834340DA5548F949814640
6693	242	38.941769999999998	38.960921999999997	45.059536000000001	45.059089999999998	улица Атарбекова	0103000020E610000001000000050000004D2D5BEB8B784340A4C2D842908746404D2D5BEB8B784340A3772AE09E874640E200FA7DFF7A4340A3772AE09E874640E200FA7DFF7A4340A4C2D842908746404D2D5BEB8B784340A4C2D84290874640
21113	242	39.129382999999997	39.135815000000001	45.065953	45.065896000000002	улица Андреевская	0103000020E6100000010000000500000045D4449F8F904340F777B6476F88464045D4449F8F9043405B09DD257188464033A7CB62629143405B09DD257188464033A7CB6262914340F777B6476F88464045D4449F8F904340F777B6476F884640
5371	242	38.901390999999997	38.917884000000001	45.039050000000003	45.026564999999998	улица 70-летия Октября	0103000020E6100000010000000500000051F4C0C760734340EF1B5F7B6683464051F4C0C76073434054742497FF844640C6C210397D75434054742497FF844640C6C210397D754340EF1B5F7B6683464051F4C0C760734340EF1B5F7B66834640
15702	242	39.016554999999997	39.023975	45.125661000000001	45.042482999999997	улица 1-го Мая	0103000020E61000000100000005000000EACA67791E82434067D13B1570854640EACA67791E824340FBB0DEA815904640F775E09C11834340FBB0DEA815904640F775E09C1183434067D13B1570854640EACA67791E82434067D13B1570854640
23955	242	38.901390999999997	38.917884000000001	45.039050000000003	45.026564999999998	им. 70-летия Октября	0103000020E6100000010000000500000051F4C0C760734340EF1B5F7B6683464051F4C0C76073434054742497FF844640C6C210397D75434054742497FF844640C6C210397D754340EF1B5F7B6683464051F4C0C760734340EF1B5F7B66834640
23727	242	38.943224999999998	38.961199999999998	45.064278999999999	45.063591000000002	Яна Полуяна	0103000020E6100000010000000500000082E2C798BB784340F4A8F8BF2388464082E2C798BB784340E868554B3A8846402575029A087B4340E868554B3A8846402575029A087B4340F4A8F8BF2388464082E2C798BB784340F4A8F8BF23884640
23381	242	38.962817000000001	38.964784999999999	45.009337000000002	45.003492999999999	Южная	0103000020E61000000100000005000000348463963D7B4340E961687572804640348463963D7B434046D26EF431814640EF552B137E7B434046D26EF431814640EF552B137E7B4340E961687572804640348463963D7B4340E961687572804640
23901	242	38.941231000000002	38.949010000000001	45.054378	45.039712000000002	Энгельса	0103000020E610000001000000050000009E7DE5417A7843401FA16648158546409E7DE5417A7843409ACFB9DBF5864640DAC9E028797943409ACFB9DBF5864640DAC9E028797943401FA16648158546409E7DE5417A7843401FA1664815854640
23375	242	39.017426	39.027405999999999	45.039133	45.034362000000002	Школьная	0103000020E61000000100000005000000D00CE2033B824340D21C59F965844640D00CE2033B824340E198654F028546406ADB300A82834340E198654F028546406ADB300A82834340D21C59F965844640D00CE2033B824340D21C59F965844640
23839	242	39.007742	39.011460999999997	45.025852	45.011324999999999	Шевченко	0103000020E610000001000000050000001F679AB0FD8043404850FC18738146401F679AB0FD804340A2444B1E4F834640F816D68D77814340A2444B1E4F834640F816D68D778143404850FC18738146401F679AB0FD8043404850FC1873814640
23667	242	38.960590000000003	38.965063000000001	45.041738000000002	45.028590999999999	Чкалова	0103000020E61000000100000005000000AD6EF59CF47A4340DFFAB0DEA8834640AD6EF59CF47A43400F80B8AB5785464032CA332F877B43400F80B8AB5785464032CA332F877B4340DFFAB0DEA8834640AD6EF59CF47A4340DFFAB0DEA8834640
5350	242	38.901390999999997	38.923318999999999	45.034934999999997	45.024800999999997	Чекистов проспект	0103000020E6100000010000000500000051F4C0C7607343403CF4DDAD2C83464051F4C0C7607343402D3E05C078844640416326512F7643402D3E05C078844640416326512F7643403CF4DDAD2C83464051F4C0C7607343403CF4DDAD2C834640
23585	242	38.958928	38.988194999999997	45.031897000000001	45.026960000000003	Чапаева	0103000020E61000000100000005000000FE9B1727BE7A43406C26DF6C73834640FE9B1727BE7A434096EB6D33158446400D897B2C7D7E434096EB6D33158446400D897B2C7D7E43406C26DF6C73834640FE9B1727BE7A43406C26DF6C73834640
23905	242	38.974262000000003	38.982759999999999	45.042667999999999	45.041195999999999	Хакурате	0103000020E6100000010000000500000027DE019EB47C4340EE5C18E94585464027DE019EB47C4340F94A20257685464092E86514CB7D4340F94A20257685464092E86514CB7D4340EE5C18E94585464027DE019EB47C4340EE5C18E945854640
22011	242	39.008470000000003	39.024675000000002	45.036490000000001	45.033324	Филатова	0103000020E61000000100000005000000A27F828B158143400116F9F543844640A27F828B15814340C6504EB4AB844640B003E78C28834340C6504EB4AB844640B003E78C288343400116F9F543844640A27F828B158143400116F9F543844640
23253	242	38.973193000000002	38.984834999999997	45.068868999999999	45.068753999999998	Федора Лузана	0103000020E610000001000000050000001BD99596917C43400EBC5AEECC8846401BD99596917C4340A75A0BB3D0884640637AC2120F7E4340A75A0BB3D0884640637AC2120F7E43400EBC5AEECC8846401BD99596917C43400EBC5AEECC884640
24000	242	39.073759000000003	39.138753000000001	45.034509	45.012732999999997	Фадеева	0103000020E61000000100000005000000916456EF708943403C4A253CA1814640916456EF70894340763579CA6A844640679C86A8C2914340763579CA6A844640679C86A8C29143403C4A253CA1814640916456EF708943403C4A253CA1814640
23655	242	39.015557999999999	39.021054999999997	45.075271999999998	45.075011000000003	Уссурийская	0103000020E610000001000000050000007898F6CDFD8143408EEBDFF5998946407898F6CDFD814340FA264D83A2894640693524EEB1824340FA264D83A2894640693524EEB18243408EEBDFF5998946407898F6CDFD8143408EEBDFF599894640
23670	242	39.028196999999999	39.134261000000002	45.043897000000001	45.030507999999998	Уральская	0103000020E61000000100000005000000336C94F59B8343401822A7AFE7834640336C94F59B8343403EB2B96A9E8546406B10E6762F9143403EB2B96A9E8546406B10E6762F9143401822A7AFE7834640336C94F59B8343401822A7AFE7834640
23621	242	38.953842999999999	38.970264	45.071643999999999	45.036375	Тургенева	0103000020E610000001000000050000005F420587177A43402DB29DEFA78446405F420587177A4340317A6EA12B8946403A3E5A9C317C4340317A6EA12B8946403A3E5A9C317C43402DB29DEFA78446405F420587177A43402DB29DEFA7844640
23884	242	39.062781999999999	39.081018	45.006323000000002	45.005628000000002	Трудовой Славы	0103000020E610000001000000050000008463963D0988434090F8156BB88046408463963D09884340371B2B31CF80464094313ECC5E8A4340371B2B31CF80464094313ECC5E8A434090F8156BB88046408463963D0988434090F8156BB8804640
23778	242	39.012360000000001	39.026544000000001	45.111401000000001	45.106904	Тепличная	0103000020E61000000100000005000000A8E3310395814340E2E7BF07AF8D4640A8E3310395814340F0DE5163428E4640D8F335CB65834340F0DE5163428E4640D8F335CB65834340E2E7BF07AF8D4640A8E3310395814340E2E7BF07AF8D4640
23852	242	38.918764000000003	38.938051000000002	45.065679000000003	45.058140999999999	Темрюкская	0103000020E61000000100000005000000FF5E0A0F9A75434043C70E2A71874640FF5E0A0F9A7543405A84622B68884640747D1F0E127843405A84622B68884640747D1F0E1278434043C70E2A71874640FF5E0A0F9A75434043C70E2A71874640
23795	242	39.014111	39.019024999999999	45.024659999999997	45.007655	Таманская	0103000020E61000000100000005000000C6C1A563CE8143405053CBD6FA804640C6C1A563CE8143407AC2120F28834640386744696F8243407AC2120F28834640386744696F8243405053CBD6FA804640C6C1A563CE8143405053CBD6FA804640
5123	242	39.012889999999999	39.015827000000002	45.125971999999997	45.112488999999997	Строителей бульвар	0103000020E6100000010000000500000004392861A68143407214200A668E464004392861A6814340191BBAD91F90464068B27F9E06824340191BBAD91F90464068B27F9E068243407214200A668E464004392861A68143407214200A668E4640
23721	242	39.007418999999999	39.026327999999999	45.014128999999997	45.012619000000001	Степная	0103000020E610000001000000050000003C2F151BF38043407427D87F9D8146403C2F151BF38043406C76A4FACE8146400B7C45B75E8343406C76A4FACE8146400B7C45B75E8343407427D87F9D8146403C2F151BF38043407427D87F9D814640
23861	242	39.024397	39.026454000000001	45.020193999999996	45.012388999999999	Степана Разина	0103000020E610000001000000050000006D8FDE701F83434042EA76F6958146406D8FDE701F834340A7C98CB795824640986C3CD862834340A7C98CB795824640986C3CD86283434042EA76F6958146406D8FDE701F83434042EA76F695814640
23875	242	39.023336999999998	39.043683999999999	45.032012000000002	45.001148000000001	Стасова	0103000020E61000000100000005000000B4E4F1B4FC824340583A1F9E25804640B4E4F1B4FC8243402F8A1EF818844640E2ADF36F978543402F8A1EF818844640E2ADF36F97854340583A1F9E25804640B4E4F1B4FC824340583A1F9E25804640
23645	242	39.031637000000003	39.050224	45.032719	45.003002000000002	Старокубанская	0103000020E61000000100000005000000FA2B64AE0C8443404BE9995E62804640FA2B64AE0C8443409A7ADD2230844640B6BC72BD6D8643409A7ADD2230844640B6BC72BD6D8643404BE9995E62804640FA2B64AE0C8443404BE9995E62804640
23757	242	38.973605999999997	39.046683999999999	45.021520000000002	45.012949999999996	Ставропольская	0103000020E610000001000000050000003D98141F9F7C4340D93D7958A88146403D98141F9F7C4340DF1AD82AC18246408C9FC6BDF9854340DF1AD82AC18246408C9FC6BDF9854340D93D7958A88146403D98141F9F7C4340D93D7958A8814640
23594	242	39.047538000000003	39.114156999999999	45.043762999999998	45.021832000000003	Сормовская	0103000020E610000001000000050000009CA8A5B915864340CE001764CB8246409CA8A5B9158643402EE3A6069A85464003CE52B29C8E43402EE3A6069A85464003CE52B29C8E4340CE001764CB8246409CA8A5B915864340CE001764CB824640
23829	242	38.959772000000001	38.974567	45.019461999999997	45.016607	Советская	0103000020E61000000100000005000000EACE13CFD97A43403DF19C2D20824640EACE13CFD97A4340E3C116BB7D8246406361889CBE7C4340E3C116BB7D8246406361889CBE7C43403DF19C2D20824640EACE13CFD97A43403DF19C2D20824640
23663	242	38.923507000000001	38.938347	45.068429000000002	45.062401000000001	Славянская	0103000020E610000001000000050000004450357A357643406D1E87C1FC8746404450357A357643408B8C0E48C28846405DA626C11B7843408B8C0E48C28846405DA626C11B7843406D1E87C1FC8746404450357A357643406D1E87C1FC874640
23872	242	39.015422999999998	39.055729999999997	45.028838999999998	45.013044999999998	Селезнева	0103000020E61000000100000005000000984D8061F98143402B306475AB814640984D8061F9814340B7EC10FFB0834640FAB31F2922874340B7EC10FFB0834640FAB31F29228743402B306475AB814640984D8061F98143402B306475AB814640
23809	242	38.931161000000003	39.028143	45.047207999999998	45.031024000000002	Северная	0103000020E61000000100000005000000C4279D483077434010B22C98F8834640C4279D4830774340060E68E90A864640404E98309A834340060E68E90A864640404E98309A83434010B22C98F8834640C4279D483077434010B22C98F8834640
23789	242	39.024622000000001	39.036318000000001	45.010095	45.006469000000003	Свободная	0103000020E610000001000000050000008D614ED0268343400BB8E7F9D38046408D614ED026834340336DFFCA4A814640C9207711A6844340336DFFCA4A814640C9207711A68443400BB8E7F9D38046408D614ED0268343400BB8E7F9D3804640
23759	242	38.986460999999998	38.997663000000003	45.052467999999998	45.023902	Садовая	0103000020E61000000100000005000000C5E3A25A447E43408D2782380F834640C5E3A25A447E4340130B7C45B7864640F2B6D26BB37F4340130B7C45B7864640F2B6D26BB37F43408D2782380F834640C5E3A25A447E43408D2782380F834640
23683	242	38.932571000000003	38.969025000000002	45.05171	45.045940999999999	Рылеева	0103000020E6100000010000000500000059198D7C5E774340D4450A65E185464059198D7C5E7743402670EB6E9E864640D200DE02097C43402670EB6E9E864640D200DE02097C4340D4450A65E185464059198D7C5E774340D4450A65E1854640
23339	242	39.009925000000003	39.018172	45.127288999999998	45.045788000000002	Российская	0103000020E61000000100000005000000D734EF38458143404E469561DC854640D734EF3845814340FD1186014B904640F9D9C87553824340FD1186014B904640F9D9C875538243404E469561DC854640D734EF38458143404E469561DC854640
7053	242	38.973013000000002	38.976911999999999	45.075640999999997	45.072172000000002	Репина проезд	0103000020E610000001000000050000009BCAA2B08B7C4340EDD79DEE3C8946409BCAA2B08B7C43404D9EB29AAE894640F488D1730B7D43404D9EB29AAE894640F488D1730B7D4340EDD79DEE3C8946409BCAA2B08B7C4340EDD79DEE3C894640
23688	242	38.964973000000001	38.977110000000003	45.068677999999998	45.015192999999996	Рашпилевская	0103000020E61000000100000005000000F2423A3C847B434066101FD8F1814640F2423A3C847B434033FAD170CA8846401B4CC3F0117D434033FAD170CA8846401B4CC3F0117D434066101FD8F1814640F2423A3C847B434066101FD8F1814640
21623	242	38.648533	39.383265000000002	45.220457000000003	44.968698000000003	Псурцева	0103000020E610000001000000050000003AB01C2103534340AED9CA4BFE7B46403AB01C21035343404F965AEF379C4640C959D8D30EB143404F965AEF379C4640C959D8D30EB14340AED9CA4BFE7B46403AB01C2103534340AED9CA4BFE7B4640
5397	242	38.907760000000003	38.914155999999998	45.034469999999999	45.027329999999999	Платановый бульвар	0103000020E61000000100000005000000F94ECC7A317443408F19A88C7F834640F94ECC7A31744340B85851836984464099B8551003754340B85851836984464099B85510037543408F19A88C7F834640F94ECC7A317443408F19A88C7F834640
23793	242	39.017730999999998	39.019097000000002	45.018492999999999	45.008699999999997	Пионерская	0103000020E610000001000000050000000C90680245824340D3BCE3141D8146400C906802458243403B1A87FA5D824640D2393FC5718243403B1A87FA5D824640D2393FC571824340D3BCE3141D8146400C90680245824340D3BCE3141D814640
23675	242	38.960365000000003	38.965701000000003	45.007680000000001	45.006801000000003	Песчаная	0103000020E610000001000000050000008D9C853DED7A4340414AECDADE8046408D9C853DED7A4340A96A82A8FB804640755B22179C7B4340A96A82A8FB804640755B22179C7B4340414AECDADE8046408D9C853DED7A4340414AECDADE804640
24024	242	38.962691999999997	38.991374999999998	45.034649000000002	45.029826999999997	Пашковская	0103000020E61000000100000005000000770FD07D397B4340D6C4025FD1834640770FD07D397B434068EBE0606F84464037894160E57E434068EBE0606F84464037894160E57E4340D6C4025FD1834640770FD07D397B4340D6C4025FD1834640
23895	242	38.961533000000003	38.971297999999997	45.040700000000001	45.013255999999998	Октябрьская	0103000020E610000001000000050000002C836A83137B4340E63C635FB28146402C836A83137B43403E7958A835854640C9552C7E537C43403E7958A835854640C9552C7E537C4340E63C635FB28146402C836A83137B4340E63C635FB2814640
23740	242	38.970705000000002	38.986488000000001	45.051048000000002	45.048762000000004	Одесская	0103000020E610000001000000050000002788BA0F407C4340CFA44DD53D8646402788BA0F407C43405B43A9BD88864640BFF2203D457E43405B43A9BD88864640BFF2203D457E4340CFA44DD53D8646402788BA0F407C4340CFA44DD53D864640
23696	242	39.027963	39.040405	45.033974000000001	45.032668000000001	Новгородская	0103000020E61000000100000005000000C03FA54A9483434018D00B772E844640C03FA54A94834340087591425984464025CCB4FD2B854340087591425984464025CCB4FD2B85434018D00B772E844640C03FA54A9483434018D00B772E844640
20541	242	38.994151000000002	39.005757000000003	45.104816999999997	45.047673000000003	Московская	0103000020E6100000010000000500000092240857407F43407CF31B261A86464092240857407F43404C88B9A46A8D46408E5C37A5BC8043404C88B9A46A8D46408E5C37A5BC8043407CF31B261A86464092240857407F43407CF31B261A864640
23699	242	38.973605999999997	38.983434000000003	45.043005000000001	45.013720999999997	Митрофана Седина	0103000020E610000001000000050000003D98141F9F7C43405B22179CC18146403D98141F9F7C4340414816308185464022E3512AE17D4340414816308185464022E3512AE17D43405B22179CC18146403D98141F9F7C43405B22179CC1814640
23689	242	38.959862000000001	38.987853999999999	45.022067999999997	45.018014999999998	Мира	0103000020E610000001000000050000002A560DC2DC7A434031EBC5504E8246402A560DC2DC7A4340E124CD1FD3824640849CF7FF717E4340E124CD1FD3824640849CF7FF717E434031EBC5504E8246402A560DC2DC7A434031EBC5504E824640
20550	242	38.959862000000001	38.987853999999999	45.022067999999997	45.018014999999998	Мира	0103000020E610000001000000050000002A560DC2DC7A434031EBC5504E8246402A560DC2DC7A4340E124CD1FD3824640849CF7FF717E4340E124CD1FD3824640849CF7FF717E434031EBC5504E8246402A560DC2DC7A434031EBC5504E824640
23715	242	38.923183999999999	38.935338000000002	45.040050000000001	45.032445000000003	Минская	0103000020E610000001000000050000006118B0E42A76434099F56228278446406118B0E42A764340371AC05B20854640605AD427B9774340371AC05B20854640605AD427B977434099F56228278446406118B0E42A76434099F5622827844640
23620	242	38.991725000000002	38.993808999999999	45.054544	45.048729999999999	Механическая	0103000020E6100000010000000500000014D044D8F07E4340C32ADEC83C86464014D044D8F07E4340B5183C4CFB86464038BC2022357F4340B5183C4CFB86464038BC2022357F4340C32ADEC83C86464014D044D8F07E4340C32ADEC83C864640
23790	242	39.010778999999999	39.025556000000002	45.012300000000003	45.011242000000003	Майкопская	0103000020E61000000100000005000000E63DCE3461814340BB2BBB6070814640E63DCE3461814340D3DEE00B93814640B91B446B45834340D3DEE00B93814640B91B446B45834340BB2BBB6070814640E63DCE3461814340BB2BBB6070814640
23717	242	38.930757	38.944636000000003	45.154919	45.14855	Лунная	0103000020E61000000100000005000000F4C29D0B2377434010E9B7AF03934640F4C29D0B23774340B743C362D4934640E84F1BD5E9784340B743C362D4934640E84F1BD5E978434010E9B7AF03934640F4C29D0B2377434010E9B7AF03934640
22693	242	39.188654	39.227739999999997	45.028151000000001	45.011274	Ленина	0103000020E610000001000000050000003A2174D025984340C6A52A6D718146403A2174D025984340C32CB4739A834640DAFE9595269D4340C32CB4739A834640DAFE9595269D4340C6A52A6D718146403A2174D025984340C6A52A6D71814640
23761	242	38.980496000000002	38.988393000000002	45.043126000000001	45.022036	Леваневского	0103000020E61000000100000005000000EEED96E4807D4340D6AA5D13D2824640EEED96E4807D4340BCCD1B2785854640344C6DA9837E4340BCCD1B2785854640344C6DA9837E4340D6AA5D13D2824640EEED96E4807D4340D6AA5D13D2824640
24004	242	38.804246999999997	38.820677000000003	45.038082000000003	45.035853000000003	Курганная	0103000020E61000000100000005000000FB73D190F1664340543BC3D496844640FB73D190F16643407C48F8DEDF8446402ACAA5F10B6943407C48F8DEDF8446402ACAA5F10B694340543BC3D496844640FB73D190F1664340543BC3D496844640
23758	242	38.975062000000001	39.012827000000001	45.037069000000002	45.031075000000001	Кузнечная	0103000020E6100000010000000500000043C9E4D4CE7C4340925CFE43FA83464043C9E4D4CE7C434004594FADBE844640BEC0AC50A481434004594FADBE844640BEC0AC50A4814340925CFE43FA83464043C9E4D4CE7C4340925CFE43FA834640
22234	242	38.894581000000002	38.976193000000002	45.077716000000002	45.048202000000003	Красных Партизан	0103000020E61000000100000005000000BE4F55A18172434008CDAE7B2B864640BE4F55A1817243401F300F99F2894640C5CA68E4F37C43401F300F99F2894640C5CA68E4F37C434008CDAE7B2B864640BE4F55A18172434008CDAE7B2B864640
23690	242	38.969321000000001	38.978285999999997	45.041922	45.014479000000001	Красноармейская	0103000020E61000000100000005000000BB29E5B5127C434049BDA772DA814640BB29E5B5127C4340D07D39B35D8546403C11C479387D4340D07D39B35D8546403C11C479387D434049BDA772DA814640BB29E5B5127C434049BDA772DA814640
22696	242	38.967146999999997	38.983901000000003	45.059095999999997	45.014823	Красная	0103000020E6100000010000000500000056B60F79CB7B4340431D56B8E581464056B60F79CB7B434086A92D759087464038C0CC77F07D434086A92D759087464038C0CC77F07D4340431D56B8E581464056B60F79CB7B4340431D56B8E5814640
23747	242	38.959358999999999	38.965547999999998	45.055523999999998	45.037762999999998	Котовского	0103000020E61000000100000005000000C70F9546CC7A4340DAFF006BD5844640C70F9546CC7A4340511212691B874640EE5BAD13977B4340511212691B874640EE5BAD13977B4340DAFF006BD5844640C70F9546CC7A4340DAFF006BD5844640
23725	242	38.960140000000003	38.990926000000002	45.102775000000001	45.096170999999998	Кореновская	0103000020E610000001000000050000006DCA15DEE57A43406CE9D1544F8C46406DCA15DEE57A434057EC2FBB278D4640C860C5A9D67E434057EC2FBB278D4640C860C5A9D67E43406CE9D1544F8C46406DCA15DEE57A43406CE9D1544F8C4640
23019	242	39.099235999999998	39.111983000000002	45.027718	45.011026000000001	Комсомольская	0103000020E61000000100000005000000FD4AE7C3B38C4340EEB3CA4C69814640FD4AE7C3B38C434059C16F438C8346409F5A7D75558E434059C16F438C8346409F5A7D75558E4340EEB3CA4C69814640FD4AE7C3B38C4340EEB3CA4C69814640
21979	242	38.971325	38.986012000000002	45.059255999999998	45.014141000000002	Коммунаров	0103000020E61000000100000005000000C364AA60547C434031444E5FCF814640C364AA60547C4340BF0B5BB39587464056BB26A4357E4340BF0B5BB39587464056BB26A4357E434031444E5FCF814640C364AA60547C434031444E5FCF814640
23692	242	38.987485	38.997933000000003	45.059536000000001	45.043680000000002	Колхозная	0103000020E61000000100000005000000312592E8657E4340A1BE654E97854640312592E8657E4340A3772AE09E874640B24CBF44BC7F4340A3772AE09E874640B24CBF44BC7F4340A1BE654E97854640312592E8657E4340A1BE654E97854640
23949	242	38.936973000000002	38.948453000000001	45.039821000000003	45.038324000000003	Кожевенная	0103000020E61000000100000005000000151E34BBEE774340725303CDE7844640151E34BBEE774340D658C2DA1885464084656CE866794340D658C2DA1885464084656CE866794340725303CDE7844640151E34BBEE774340725303CDE7844640
23586	242	38.949117999999999	38.949854999999999	45.070740000000001	45.059356999999999	Ковалева	0103000020E61000000100000005000000C005D9B27C794340F3E49A0299874640C005D9B27C794340704221020E894640967840D994794340704221020E894640967840D994794340F3E49A0299874640C005D9B27C794340F3E49A0299874640
23046	242	38.962215999999998	38.969213000000003	45.041055999999998	45.020378999999998	Кирова	0103000020E610000001000000050000000ED8D5E4297B4340394371C79B8246400ED8D5E4297B4340FCA6B05241854640D5EDEC2B0F7C4340FCA6B05241854640D5EDEC2B0F7C4340394371C79B8246400ED8D5E4297B4340394371C79B824640
23769	242	39.001418000000001	39.007669999999997	45.065246000000002	45.062578999999999	Карякина	0103000020E6100000010000000500000018D00B772E8043404C35B3960288464018D00B772E804340F0181EFB5988464085949F54FB804340F0181EFB5988464085949F54FB8043404C35B3960288464018D00B772E8043404C35B39602884640
23739	242	38.846980000000002	38.975062000000001	45.059714	45.037069000000002	Калинина	0103000020E61000000100000005000000DC2E34D7696C434004594FADBE844640DC2E34D7696C4340828E56B5A487464043C9E4D4CE7C4340828E56B5A487464043C9E4D4CE7C434004594FADBE844640DC2E34D7696C434004594FADBE844640
23810	242	38.991509999999998	38.998130000000003	45.030368000000003	45.030163999999999	Казачья	0103000020E6100000010000000500000017D4B7CCE97E43401EC2F869DC83464017D4B7CCE97E4340276C3F19E383464008944DB9C27F4340276C3F19E383464008944DB9C27F43401EC2F869DC83464017D4B7CCE97E43401EC2F869DC834640
23794	242	38.993853999999999	39.027495999999999	45.019238999999999	45.017187	КИМ	0103000020E61000000100000005000000D87F9D9B367F43404B75012F33824640D87F9D9B367F434064E76D6C76824640AA622AFD8483434064E76D6C76824640AA622AFD848343404B75012F33824640D87F9D9B367F43404B75012F33824640
23915	242	39.069178000000001	39.072349000000003	45.012517000000003	45.005692000000003	Игнатова	0103000020E6100000010000000500000025CD1FD3DA884340A7ECF483BA80464025CD1FD3DA88434070D234289A814640FC7266BB4289434070D234289A814640FC7266BB42894340A7ECF483BA80464025CD1FD3DA884340A7ECF483BA804640
23356	242	38.648533	39.383265000000002	45.220457000000003	44.968698000000003	Зеленского	0103000020E610000001000000050000003AB01C2103534340AED9CA4BFE7B46403AB01C21035343404F965AEF379C4640C959D8D30EB143404F965AEF379C4640C959D8D30EB14340AED9CA4BFE7B46403AB01C2103534340AED9CA4BFE7B4640
24014	242	39.078242000000003	39.082213000000003	45.033017999999998	45.027005000000003	Звездная	0103000020E610000001000000050000003A9677D5038A43400CEA5BE6748346403A9677D5038A4340F4160FEF398446402D27A1F4858A4340F4160FEF398446402D27A1F4858A43400CEA5BE6748346403A9677D5038A43400CEA5BE674834640
23898	242	38.957374000000002	38.975538	45.014339	44.995545	Захарова	0103000020E610000001000000050000003605323B8B7A43402159C0046E7F46403605323B8B7A4340570740DCD5814640AC00DF6DDE7C4340570740DCD5814640AC00DF6DDE7C43402159C0046E7F46403605323B8B7A43402159C0046E7F4640
23991	242	38.985230000000001	38.994599999999998	45.024374000000002	45.02064	Железнодорожная	0103000020E61000000100000005000000E08442041C7E4340A67EDE54A4824640E08442041C7E4340B56FEEAF1E834640014D840D4F7F4340B56FEEAF1E834640014D840D4F7F4340A67EDE54A4824640E08442041C7E4340A67EDE54A4824640
16518	242	38.997447999999999	38.999594000000002	45.197215999999997	45.128718999999997	Ейское шоссе	0103000020E61000000100000005000000F5BA4560AC7F4340D9AF3BDD79904640F5BA4560AC7F4340BC1FB75F3E99464090A339B2F27F4340BC1FB75F3E99464090A339B2F27F4340D9AF3BDD79904640F5BA4560AC7F4340D9AF3BDD79904640
23700	242	39.065710000000003	39.139434999999999	45.044578000000001	45.012810000000002	Евдокии Бершанской	0103000020E6100000010000000500000095826E2F69884340E88711C2A381464095826E2F69884340800F5EBBB485464079758E01D9914340800F5EBBB485464079758E01D9914340E88711C2A381464095826E2F69884340E88711C2A3814640
23755	242	38.913563000000003	38.921233999999998	45.039050000000003	45.033878000000001	Думенко	0103000020E61000000100000005000000F7EAE3A1EF744340E606431D56844640F7EAE3A1EF74434054742497FF8446404CFBE6FEEA75434054742497FF8446404CFBE6FEEA754340E606431D56844640F7EAE3A1EF744340E606431D56844640
23237	242	39.106171000000003	39.113841999999998	45.101146	45.094268999999997	Дорожная	0103000020E610000001000000050000004E64E602978D43406803B001118C46404E64E602978D4340840F255AF28C4640A374E95F928E4340840F255AF28C4640A374E95F928E43406803B001118C46404E64E602978D43406803B001118C4640
23996	242	38.990305999999997	38.991616999999998	45.028520999999998	45.023240000000001	Дмитриевская Дамба	0103000020E610000001000000050000002B84D558C27E4340C2FA3F87F98246402B84D558C27E4340E61F7D93A68346402D944C4EED7E4340E61F7D93A68346402D944C4EED7E4340C2FA3F87F98246402B84D558C27E4340C2FA3F87F9824640
23808	242	39.021343000000002	39.029311	45.025317000000001	45.002467000000003	Димитрова	0103000020E61000000100000005000000D07F0F5EBB824340DD28B2D650804640D07F0F5EBB824340348463963D834640DF347D76C0834340348463963D834640DF347D76C0834340DD28B2D650804640D07F0F5EBB824340DD28B2D650804640
23151	242	38.972771000000002	38.996530999999997	45.126958000000002	45.054167999999997	Дзержинского	0103000020E61000000100000005000000A5BF97C2837C4340AF3E1EFAEE864640A5BF97C2837C434098FBE428409046409F39EB538E7F434098FBE428409046409F39EB538E7F4340AF3E1EFAEE864640A5BF97C2837C4340AF3E1EFAEE864640
23869	242	38.958649000000001	38.990378	45.033821000000003	45.028061999999998	Горького	0103000020E61000000100000005000000EBABAB02B57A434053211E8997834640EBABAB02B57A434082751C3F54844640C556D0B4C47E434082751C3F54844640C556D0B4C47E434053211E8997834640EBABAB02B57A434053211E8997834640
23288	242	38.959341000000002	38.990495000000003	45.028762999999998	45.019162000000001	Гоголя	0103000020E61000000100000005000000215B96AFCB7A4340B9A981E673824640215B96AFCB7A4340DC2A8881AE834640FFEC478AC87E4340DC2A8881AE834640FFEC478AC87E4340B9A981E673824640215B96AFCB7A4340B9A981E673824640
24002	242	39.070103000000003	39.081377000000003	45.003326999999999	45.002403000000001	Гидростроителей	0103000020E61000000100000005000000FE2C9622F9884340C634D3BD4E804640FE2C9622F9884340CE18E6046D804640C4D2C08F6A8A4340CE18E6046D804640C4D2C08F6A8A4340C634D3BD4E804640FE2C9622F9884340C634D3BD4E804640
24008	242	38.974558000000002	38.986811000000003	45.079262999999997	45.077919999999999	Гастелло	0103000020E6100000010000000500000010070951BE7C434027DA5548F989464010070951BE7C434034643C4A258A4640A22AA6D24F7E434034643C4A258A4640A22AA6D24F7E434027DA5548F989464010070951BE7C434027DA5548F9894640
23657	242	38.951202000000002	38.957203	45.059159999999999	45.040208999999997	Воровского	0103000020E61000000100000005000000E5F1B4FCC07943409F008A9125854640E5F1B4FCC07943409D9D0C8E928746400951BEA0857A43409D9D0C8E928746400951BEA0857A43409F008A9125854640E5F1B4FCC07943409F008A9125854640
23264	242	39.036461000000003	39.038626000000001	45.035783000000002	45.024616000000002	Волжская	0103000020E610000001000000050000002C4A09C1AA844340AB7AF99D268346402C4A09C1AA8443405B608F89948446403D635FB2F18443405B608F89948446403D635FB2F1844340AB7AF99D268346402C4A09C1AA844340AB7AF99D26834640
23591	242	38.989147000000003	39.000914999999999	45.023513999999999	45.009304999999998	Вишняковой	0103000020E61000000100000005000000E0F76F5E9C7E43403A58FFE730814640E0F76F5E9C7E4340C37FBA8102834640B58993FB1D804340C37FBA8102834640B58993FB1D8043403A58FFE730814640E0F76F5E9C7E43403A58FFE730814640
20647	242	39.075448000000002	39.097043999999997	45.015785000000001	45.012937000000001	Василия Мачуги	0103000020E610000001000000050000003946B247A889434045F46BEBA78146403946B247A889434039622D3E05824640F22213F06B8C434039622D3E05824640F22213F06B8C434045F46BEBA78146403946B247A889434045F46BEBA7814640
23787	242	38.889263	38.894671000000002	45.056021000000001	45.054321000000002	Вавилова	0103000020E610000001000000050000007C45B75ED3714340363E93FDF38646407C45B75ED3714340D27135B22B874640FED64E9484724340D27135B22B874640FED64E9484724340363E93FDF38646407C45B75ED3714340363E93FDF3864640
23745	242	39.026570999999997	39.040889999999997	45.014702	45.010069999999999	Бургасская	0103000020E61000000100000005000000D102B4AD66834340DA5548F949814640D102B4AD66834340C89750C1E1814640E15D2EE23B854340C89750C1E1814640E15D2EE23B854340DA5548F949814640D102B4AD66834340DA5548F949814640
23802	242	38.905279999999998	38.915664999999997	45.035611000000003	45.028922000000001	Бульварное Кольцо	0103000020E6100000010000000500000087DC0C37E0734340451152B7B383464087DC0C37E07343405E30B8E68E844640C18BBE82347543405E30B8E68E844640C18BBE8234754340451152B7B383464087DC0C37E0734340451152B7B3834640
23118	242	39.005532000000002	39.008280999999997	45.108386000000003	45.108258999999997	Буковая	0103000020E610000001000000050000006E8AC745B5804340B33F506EDB8D46406E8AC745B580434011ACAA97DF8D4640CE16105A0F81434011ACAA97DF8D4640CE16105A0F814340B33F506EDB8D46406E8AC745B5804340B33F506EDB8D4640
23527	242	38.955342999999999	39.011003000000002	45.038063000000001	45.030616999999999	Буденного	0103000020E6100000010000000500000034BBEEAD487A4340CFD90242EB83464034BBEEAD487A43400518963FDF8446403694DA8B688143400518963FDF8446403694DA8B68814340CFD90242EB83464034BBEEAD487A4340CFD90242EB834640
23712	242	39.079355999999997	39.081682999999998	45.013433999999997	45.003326999999999	Благоева	0103000020E61000000100000005000000E55E6056288A4340CE18E6046D804640E55E6056288A4340C5538F34B8814640D0D1AA96748A4340C5538F34B8814640D0D1AA96748A4340CE18E6046D804640E55E6056288A4340CE18E6046D804640
23986	242	38.933056000000001	38.978538	45.054741	45.046272000000002	Бабушкина	0103000020E6100000010000000500000015AB06616E7743403A5CAB3DEC85464015AB06616E7743400B60CAC00187464056F2B1BB407D43400B60CAC00187464056F2B1BB407D43403A5CAB3DEC85464015AB06616E7743403A5CAB3DEC854640
23318	242	38.941769999999998	38.960921999999997	45.059536000000001	45.059089999999998	Атарбекова	0103000020E610000001000000050000004D2D5BEB8B784340A4C2D842908746404D2D5BEB8B784340A3772AE09E874640E200FA7DFF7A4340A3772AE09E874640E200FA7DFF7A4340A4C2D842908746404D2D5BEB8B784340A4C2D84290874640
24020	242	38.917884000000001	38.944510000000001	45.042628999999998	45.039050000000003	Алма-Атинская	0103000020E61000000100000005000000C6C210397D75434054742497FF844640C6C210397D7543403B6EF8DD748546405B5F24B4E57843403B6EF8DD748546405B5F24B4E578434054742497FF844640C6C210397D75434054742497FF844640
24017	242	39.046872999999998	39.047016999999997	45.069110000000002	45.063215999999997	Алексеевская	0103000020E610000001000000050000005F0839EFFF854340BE4A3E76178846405F0839EFFF854340CDE9B298D888464092AD2EA704864340CDE9B298D888464092AD2EA704864340BE4A3E76178846405F0839EFFF854340BE4A3E7617884640
23695	242	38.901390999999997	38.917884000000001	45.039050000000003	45.026564999999998	70-летия Октября	0103000020E6100000010000000500000051F4C0C760734340EF1B5F7B6683464051F4C0C76073434054742497FF844640C6C210397D75434054742497FF844640C6C210397D754340EF1B5F7B6683464051F4C0C760734340EF1B5F7B66834640
23701	242	38.989730999999999	39.313538000000001	45.060935999999998	45.054409999999997	40-летия Победы	0103000020E610000001000000050000002F6B6281AF7E4340A54929E8F68646402F6B6281AF7E4340149337C0CC874640D106600322A84340149337C0CC874640D106600322A84340A54929E8F68646402F6B6281AF7E4340A54929E8F6864640
23819	242	39.101796	39.103889000000002	45.042062999999999	45.037477000000003	30-й Иркутской Дивизии	0103000020E610000001000000050000008B6EBDA6078D434015ADDC0BCC8446408B6EBDA6078D434092AF04526285464003B5183C4C8D434092AF04526285464003B5183C4C8D434015ADDC0BCC8446408B6EBDA6078D434015ADDC0BCC844640
23672	242	38.929355000000001	38.938392	45.070002000000002	45.038393999999997	2-я Линия	0103000020E61000000100000005000000E2AFC91AF57643406A2E3718EA844640E2AFC91AF5764340CA5356D3F5884640FD69A33A1D784340CA5356D3F5884640FD69A33A1D7843406A2E3718EA844640E2AFC91AF57643406A2E3718EA844640
7213	242	39.030828999999997	39.039965000000002	45.011184999999998	45.003487	2-й Стасова проезд	0103000020E610000001000000050000005A626534F2834340077B1343728046405A626534F2834340569A94826E81464009FEB7921D854340569A94826E81464009FEB7921D854340077B1343728046405A626534F2834340077B134372804640
20578	242	38.648533	39.383265000000002	45.220457000000003	44.968698000000003	2-й Пятилетки	0103000020E610000001000000050000003AB01C2103534340AED9CA4BFE7B46403AB01C21035343404F965AEF379C4640C959D8D30EB143404F965AEF379C4640C959D8D30EB14340AED9CA4BFE7B46403AB01C2103534340AED9CA4BFE7B4640
5034	242	38.971648000000002	38.972546000000001	45.050513000000002	45.047272	2-й Гаражный проезд	0103000020E61000000100000005000000A69C2FF65E7C43401D0247020D864640A69C2FF65E7C4340ED82C1357786464085ED27637C7C4340ED82C1357786464085ED27637C7C43401D0247020D864640A69C2FF65E7C43401D0247020D864640
23252	242	39.016554999999997	39.023975	45.125661000000001	45.042482999999997	1-го Мая	0103000020E61000000100000005000000EACA67791E82434067D13B1570854640EACA67791E824340FBB0DEA815904640F775E09C11834340FBB0DEA815904640F775E09C1183434067D13B1570854640EACA67791E82434067D13B1570854640
21240	242	39.017426	39.027405999999999	45.039133	45.034362000000002	 Школьная	0103000020E61000000100000005000000D00CE2033B824340D21C59F965844640D00CE2033B824340E198654F028546406ADB300A82834340E198654F028546406ADB300A82834340D21C59F965844640D00CE2033B824340D21C59F965844640
23654	242	38.953842999999999	38.970264	45.071643999999999	45.036375	 Тургенева	0103000020E610000001000000050000005F420587177A43402DB29DEFA78446405F420587177A4340317A6EA12B8946403A3E5A9C317C4340317A6EA12B8946403A3E5A9C317C43402DB29DEFA78446405F420587177A43402DB29DEFA7844640
23606	242	39.031637000000003	39.050224	45.032719	45.003002000000002	 Старокубанская	0103000020E61000000100000005000000FA2B64AE0C8443404BE9995E62804640FA2B64AE0C8443409A7ADD2230844640B6BC72BD6D8643409A7ADD2230844640B6BC72BD6D8643404BE9995E62804640FA2B64AE0C8443404BE9995E62804640
23964	242	39.047538000000003	39.114156999999999	45.043762999999998	45.021832000000003	 Сормовская	0103000020E610000001000000050000009CA8A5B915864340CE001764CB8246409CA8A5B9158643402EE3A6069A85464003CE52B29C8E43402EE3A6069A85464003CE52B29C8E4340CE001764CB8246409CA8A5B915864340CE001764CB824640
23614	242	38.973605999999997	38.983434000000003	45.043005000000001	45.013720999999997	 Седина	0103000020E610000001000000050000003D98141F9F7C43405B22179CC18146403D98141F9F7C4340414816308185464022E3512AE17D4340414816308185464022E3512AE17D43405B22179CC18146403D98141F9F7C43405B22179CC1814640
23669	242	38.931161000000003	39.028143	45.047207999999998	45.031024000000002	 Северная	0103000020E61000000100000005000000C4279D483077434010B22C98F8834640C4279D4830774340060E68E90A864640404E98309A834340060E68E90A864640404E98309A83434010B22C98F8834640C4279D483077434010B22C98F8834640
23919	242	39.117831000000002	39.121442000000002	45.089821000000001	45.085875000000001	 Рязанская	0103000020E610000001000000050000003DBA1116158F4340A245B6F3FD8A46403DBA1116158F43403CBF28417F8B4640302E55698B8F43403CBF28417F8B4640302E55698B8F4340A245B6F3FD8A46403DBA1116158F4340A245B6F3FD8A4640
23762	242	39.005235999999996	39.005631000000001	45.055154999999999	45.051507000000001	 Ростовская	0103000020E610000001000000050000008461C092AB804340EE4108C8978646408461C092AB804340FE9AAC510F874640016C4084B8804340FE9AAC510F874640016C4084B8804340EE4108C8978646408461C092AB804340EE4108C897864640
23806	242	38.969321000000001	38.978285999999997	45.041922	45.014479000000001	 Красноармейская	0103000020E61000000100000005000000BB29E5B5127C434049BDA772DA814640BB29E5B5127C4340D07D39B35D8546403C11C479387D4340D07D39B35D8546403C11C479387D434049BDA772DA814640BB29E5B5127C434049BDA772DA814640
23642	242	38.967146999999997	38.983901000000003	45.059095999999997	45.014823	 Красная	0103000020E6100000010000000500000056B60F79CB7B4340431D56B8E581464056B60F79CB7B434086A92D759087464038C0CC77F07D434086A92D759087464038C0CC77F07D4340431D56B8E581464056B60F79CB7B4340431D56B8E5814640
23749	242	38.959358999999999	38.965547999999998	45.055523999999998	45.037762999999998	 Котовского	0103000020E61000000100000005000000C70F9546CC7A4340DAFF006BD5844640C70F9546CC7A4340511212691B874640EE5BAD13977B4340511212691B874640EE5BAD13977B4340DAFF006BD5844640C70F9546CC7A4340DAFF006BD5844640
23678	242	38.985759999999999	39.007669999999997	45.062578999999999	45.061433000000001	 Зиповская	0103000020E610000001000000050000003CDA38622D7E434095F25A09DD8746403CDA38622D7E43404C35B3960288464085949F54FB8043404C35B3960288464085949F54FB80434095F25A09DD8746403CDA38622D7E434095F25A09DD874640
23952	242	39.078242000000003	39.082213000000003	45.033017999999998	45.027005000000003	 Звездная	0103000020E610000001000000050000003A9677D5038A43400CEA5BE6748346403A9677D5038A4340F4160FEF398446402D27A1F4858A4340F4160FEF398446402D27A1F4858A43400CEA5BE6748346403A9677D5038A43400CEA5BE674834640
23943	242	39.024369999999998	39.028035000000003	45.072190999999997	45.035260000000001	 Восточно-Кругликовская	0103000020E610000001000000050000007380608E1E834340B16D5166838446407380608E1E8343406308008E3D8946405A12A0A6968343406308008E3D8946405A12A0A696834340B16D5166838446407380608E1E834340B16D516683844640
23871	242	38.905279999999998	38.915664999999997	45.035611000000003	45.028922000000001	 Бульварное Кольцо	0103000020E6100000010000000500000087DC0C37E0734340451152B7B383464087DC0C37E07343405E30B8E68E844640C18BBE82347543405E30B8E68E844640C18BBE8234754340451152B7B383464087DC0C37E0734340451152B7B3834640
23811	242	38.955342999999999	39.011003000000002	45.038063000000001	45.030616999999999	 Буденного	0103000020E6100000010000000500000034BBEEAD487A4340CFD90242EB83464034BBEEAD487A43400518963FDF8446403694DA8B688143400518963FDF8446403694DA8B68814340CFD90242EB83464034BBEEAD487A4340CFD90242EB834640
23677	242	38.974325	38.977998999999997	45.061357000000001	45.053589000000002	 Брянская	0103000020E610000001000000050000006D567DAEB67C434072361D01DC8646406D567DAEB67C4340BA30D28BDA874640A6423C122F7D4340BA30D28BDA874640A6423C122F7D434072361D01DC8646406D567DAEB67C434072361D01DC864640
23779	242	38.978681999999999	38.979894000000002	45.060929999999999	45.059153999999999	 Бакинская	0103000020E610000001000000050000008997A773457D4340BBB6B75B928746408997A773457D434032ACE28DCC874640F8C5A52A6D7D434032ACE28DCC874640F8C5A52A6D7D4340BBB6B75B928746408997A773457D4340BBB6B75B92874640
23656	242	38.941769999999998	38.960921999999997	45.059536000000001	45.059089999999998	 Атарбекова	0103000020E610000001000000050000004D2D5BEB8B784340A4C2D842908746404D2D5BEB8B784340A3772AE09E874640E200FA7DFF7A4340A3772AE09E874640E200FA7DFF7A4340A4C2D842908746404D2D5BEB8B784340A4C2D84290874640
23731	242	38.989730999999999	39.313538000000001	45.060935999999998	45.054409999999997	 40-летия Победы	0103000020E610000001000000050000002F6B6281AF7E4340A54929E8F68646402F6B6281AF7E4340149337C0CC874640D106600322A84340149337C0CC874640D106600322A84340A54929E8F68646402F6B6281AF7E4340A54929E8F6864640
21675	50406	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Выселковская	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
22053	50457	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Матросова	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
23583	50782	37.7714	37.774965999999999	44.746585000000003	44.745080000000002	Школьная	0103000020E610000001000000050000003411363CBDE24240AC730CC85E5F46403411363CBDE242409357E718905F464087C1FC1532E342409357E718905F464087C1FC1532E34240AC730CC85E5F46403411363CBDE24240AC730CC85E5F4640
23881	50854	39.101778000000003	39.110779000000001	45.094988000000001	45.090736999999997	Степная	0103000020E61000000100000005000000E5B9BE0F078D4340C1C41F459D8B4640E5B9BE0F078D434098C11891288C4640B30A9B012E8E434098C11891288C4640B30A9B012E8E4340C1C41F459D8B4640E5B9BE0F078D4340C1C41F459D8B4640
22142	50468	39.407474999999998	39.445770000000003	44.697046	44.674211999999997	Ленина	0103000020E6100000010000000500000003780B2428B443400E492D944C56464003780B2428B4434060E7A6CD38594640DBC4C9FD0EB9434060E7A6CD38594640DBC4C9FD0EB943400E492D944C56464003780B2428B443400E492D944C564640
22953	50598	38.961713000000003	38.985221000000003	45.025207999999999	45.019008999999997	Ленина	0103000020E61000000100000005000000AC915D69197B434032AA0CE36E824640AC915D69197B43407DCC07043A8346408D2AC3B81B7E43407DCC07043A8346408D2AC3B81B7E434032AA0CE36E824640AC915D69197B434032AA0CE36E824640
21766	50422	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Рабочая	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
22586	50422	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Одесская	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21741	50422	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Коммунистическая	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21873	50422	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Калинина	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
22358	50496	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Гражданская площадь	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
23983	50496	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Братская	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
23916	50863	37.855778999999998	37.865012999999998	44.755457	44.750157000000002	Речная	0103000020E6100000010000000500000042CD902A8AED4240C8EE02250560464042CD902A8AED42406344A2D0B2604640B3CEF8BEB8EE42406344A2D0B2604640B3CEF8BEB8EE4240C8EE02250560464042CD902A8AED4240C8EE022505604640
21464	50377	39.291285999999999	39.323993999999999	44.699846000000001	44.683083000000003	 Школьная	0103000020E610000001000000050000002EE411DC48A543400FBA84436F5746402EE411DC48A54340431EC18D94594640D40CA9A278A94340431EC18D94594640D40CA9A278A943400FBA84436F5746402EE411DC48A543400FBA84436F574640
20645	27694	39.191699	39.238762000000001	44.729559999999999	44.694828999999999	станица Саратовская	0103000020E6100000010000000500000084D6C39789984340FCA71B28F058464084D6C39789984340213CDA38625D464087C3D2C08F9E4340213CDA38625D464087C3D2C08F9E4340FCA71B28F058464084D6C39789984340FCA71B28F0584640
23342	27694	39.346972999999998	39.357672000000001	44.507295999999997	44.501888999999998	поселок Веселый	0103000020E6100000010000000500000029CC7B9C69AC43406F9C14E63D40464029CC7B9C69AC434020B24813EF404640F3583332C8AD434020B24813EF404640F3583332C8AD43406F9C14E63D40464029CC7B9C69AC43406F9C14E63D404640
21512	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Ярославского	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
22079	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Школьная	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
20416	27694	39.415703000000001	39.547504000000004	44.486921000000002	44.392493000000002	Хадыженская	0103000020E61000000100000005000000AFEC82C135B543405874EB353D324640AFEC82C135B54340295E656D533E4640F0366F9C14C64340295E656D533E4640F0366F9C14C643405874EB353D324640AFEC82C135B543405874EB353D324640
20872	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Советская	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
20487	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Псекупская	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
22085	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Парковая	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
20461	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Ленина	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
20880	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Ленина	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
20761	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Кучерявого	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
21492	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Космонавтов	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
21353	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Кондратьева	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
9831	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Заводская	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
20772	27694	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	Вокзальная	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
23465	25997	38.074941000000003	38.092987999999998	44.571640000000002	44.554236000000003	улица Кирова	0103000020E610000001000000050000009510ACAA9709434008228B34F14646409510ACAA97094340F08AE07F2B494640D175E107E70B4340F08AE07F2B494640D175E107E70B434008228B34F14646409510ACAA9709434008228B34F1464640
23392	25997	38.079765000000002	38.090733	44.550561999999999	44.549585999999998	улица Калинина	0103000020E61000000100000005000000C72E51BD350A4340732B84D558464640C72E51BD350A4340CE35CCD07846464080D591239D0B4340CE35CCD07846464080D591239D0B4340732B84D558464640C72E51BD350A4340732B84D558464640
23584	25997	38.066262999999999	38.066307999999999	44.553035000000001	44.552019999999999	Черноморская	0103000020E61000000100000005000000A9F7544E7B084340745E6397A8464640A9F7544E7B0843408D45D3D9C946464049BBD1C77C0843408D45D3D9C946464049BBD1C77C084340745E6397A8464640A9F7544E7B084340745E6397A8464640
23760	25997	38.026234000000002	38.050137999999997	44.590913999999998	44.583364000000003	Туристическая	0103000020E610000001000000050000008A05BEA25B034340F6D4EAABAB4A46408A05BEA25B034340D05FE811A34B4640B72407EC6A064340D05FE811A34B4640B72407EC6A064340F6D4EAABAB4A46408A05BEA25B034340F6D4EAABAB4A4640
22714	25997	38.080708000000001	38.097712999999999	44.565559	44.558289000000002	Толстого	0103000020E610000001000000050000004643C6A3540A4340B85B9203764746404643C6A3540A4340AF7AC03C6448464070B20DDC810C4340AF7AC03C6448464070B20DDC810C4340B85B9203764746404643C6A3540A4340B85B920376474640
24001	25997	37.988441999999999	38.023026999999999	44.58287	44.572924999999998	Солнечная	0103000020E6100000010000000500000015FF774485FE4240C8073D9B5549464015FF774485FE4240E6E8F17B9B4A464066F6798CF2024340E6E8F17B9B4A464066F6798CF2024340C8073D9B5549464015FF774485FE4240C8073D9B55494640
23824	25997	38.061582999999999	38.073988	44.551994000000001	44.550851000000002	Полевая	0103000020E61000000100000005000000AA7EA5F3E107434005FC1A4982464640AA7EA5F3E10743404BCB48BDA7464640F2255470780943404BCB48BDA7464640F22554707809434005FC1A4982464640AA7EA5F3E107434005FC1A4982464640
23868	25997	37.972442999999998	38.134273999999998	44.638184000000003	44.532760000000003	Подгорная	0103000020E61000000100000005000000B01C210379FC4240F94ECC7A31444640B01C210379FC42404D6A6803B0514640FF59F3E32F1143404D6A6803B0514640FF59F3E32F114340F94ECC7A31444640B01C210379FC4240F94ECC7A31444640
23397	25997	38.077221999999999	38.088056000000002	44.561146999999998	44.556221000000001	Первомайская улица	0103000020E610000001000000050000000F441669E2094340992CEE3F324746400F441669E2094340CF9F36AAD3474640B91B446B450B4340CF9F36AAD3474640B91B446B450B4340992CEE3F324746400F441669E2094340992CEE3F32474640
23394	25997	38.077221999999999	38.088056000000002	44.561146999999998	44.556221000000001	Первомайская	0103000020E610000001000000050000000F441669E2094340992CEE3F324746400F441669E2094340CF9F36AAD3474640B91B446B450B4340CF9F36AAD3474640B91B446B450B4340992CEE3F324746400F441669E2094340992CEE3F32474640
22591	25997	37.972442999999998	38.134273999999998	44.638184000000003	44.532760000000003	Парус	0103000020E61000000100000005000000B01C210379FC4240F94ECC7A31444640B01C210379FC42404D6A6803B0514640FF59F3E32F1143404D6A6803B0514640FF59F3E32F114340F94ECC7A31444640B01C210379FC4240F94ECC7A31444640
22973	25997	38.076979999999999	38.112175999999998	44.563042000000003	44.552534000000001	Островского	0103000020E6100000010000000500000019390B7BDA094340CBF6216FB946464019390B7BDA0943402123A0C211484640B3B27DC85B0E43402123A0C211484640B3B27DC85B0E4340CBF6216FB946464019390B7BDA094340CBF6216FB9464640
23705	25997	38.087113000000002	38.091217999999998	44.555123000000002	44.553021999999999	Нахимова	0103000020E610000001000000050000003A07CF84260B4340F8FBC56CC94646403A07CF84260B4340F3203D450E4746403C670B08AD0B4340F3203D450E4746403C670B08AD0B4340F8FBC56CC94646403A07CF84260B4340F8FBC56CC9464640
23816	25997	38.068283999999998	38.080528000000001	44.579819999999998	44.573836	Маячная	0103000020E61000000100000005000000876BB587BD0843403CA2427573494640876BB587BD0843408AC8B08A374A4640C634D3BD4E0A43408AC8B08A374A4640C634D3BD4E0A43403CA2427573494640876BB587BD0843403CA2427573494640
23492	25997	38.030383999999998	38.101287999999997	44.610303000000002	44.558005999999999	Луначарского	0103000020E610000001000000050000002C29779FE3034340637C98BD6C4746402C29779FE30343404AD3A0681E4E464016BD5301F70C43404AD3A0681E4E464016BD5301F70C4340637C98BD6C4746402C29779FE3034340637C98BD6C474640
24029	25997	38.077221999999999	38.082450999999999	44.567948000000001	44.561146999999998	Ленина	0103000020E610000001000000050000000F441669E2094340CF9F36AAD34746400F441669E209434010EA2285B2484640E1421EC18D0A434010EA2285B2484640E1421EC18D0A4340CF9F36AAD34746400F441669E2094340CF9F36AAD3474640
23408	25997	38.077221999999999	38.082450999999999	44.567948000000001	44.561146999999998	Ленина	0103000020E610000001000000050000000F441669E2094340CF9F36AAD34746400F441669E209434010EA2285B2484640E1421EC18D0A434010EA2285B2484640E1421EC18D0A4340CF9F36AAD34746400F441669E2094340CF9F36AAD3474640
23877	25997	38.074339000000002	38.081237999999999	44.556041	44.548160000000003	Курзальная	0103000020E610000001000000050000009FE8BAF083094340D97C5C1B2A4646409FE8BAF083094340191EFB592C474640A298BC01660A4340191EFB592C474640A298BC01660A4340D97C5C1B2A4646409FE8BAF083094340D97C5C1B2A464640
6744	25997	38.061591999999997	38.065328999999998	44.555007000000003	44.550620000000002	Крымская улица	0103000020E61000000100000005000000FDD8243FE2074340034356B77A464640FDD8243FE20743408A0629780A4746407D3D5FB35C0843408A0629780A4746407D3D5FB35C084340034356B77A464640FDD8243FE2074340034356B77A464640
23463	25997	38.060468999999998	38.074941000000003	44.554333	44.552996999999998	Красногвардейская	0103000020E61000000100000005000000FEB5BC72BD0743409FE40E9BC8464640FEB5BC72BD074340FA0B3D62F44646409510ACAA97094340FA0B3D62F44646409510ACAA970943409FE40E9BC8464640FEB5BC72BD0743409FE40E9BC8464640
20498	25997	37.972442999999998	38.134273999999998	44.638184000000003	44.532760000000003	Взлетная	0103000020E61000000100000005000000B01C210379FC4240F94ECC7A31444640B01C210379FC42404D6A6803B0514640FF59F3E32F1143404D6A6803B0514640FF59F3E32F114340F94ECC7A31444640B01C210379FC4240F94ECC7A31444640
21490	25997	37.972442999999998	38.134273999999998	44.638184000000003	44.532760000000003	 мкр. Северный	0103000020E61000000100000005000000B01C210379FC4240F94ECC7A31444640B01C210379FC42404D6A6803B0514640FF59F3E32F1143404D6A6803B0514640FF59F3E32F114340F94ECC7A31444640B01C210379FC4240F94ECC7A31444640
20544	50256	39.884210000000003	39.905222000000002	45.313465000000001	45.301198999999997	Батохина	0103000020E61000000100000005000000E96514CB2DF14340404B57B08DA64640E96514CB2DF1434067B8019F1FA8464053CF8250DEF3434067B8019F1FA8464053CF8250DEF34340404B57B08DA64640E96514CB2DF14340404B57B08DA64640
20934	50301	39.805284	39.850299	46.230344000000002	46.221060000000001	Северная	0103000020E61000000100000005000000FCFECD8B13E74340153AAFB14B1C4740FCFECD8B13E74340386A85E97B1D47402769FE98D6EC4340386A85E97B1D47402769FE98D6EC4340153AAFB14B1C4740FCFECD8B13E74340153AAFB14B1C4740
23785	50388	38.994528000000003	39.000869999999999	45.157296000000002	45.146222999999999	Целиноградская	0103000020E61000000100000005000000687A89B14C7F434025766D6FB7924640687A89B14C7F434054E57B462294464015C616821C80434054E57B462294464015C616821C80434025766D6FB7924640687A89B14C7F434025766D6FB7924640
23413	50696	39.554026	39.660207	46.299531000000002	46.288017000000004	Горького	0103000020E610000001000000050000001D91EF52EAC6434095D8B5BDDD2447401D91EF52EAC64340B0912408572647408ECBB8A981D44340B0912408572647408ECBB8A981D4434095D8B5BDDD2447401D91EF52EAC6434095D8B5BDDD244740
22660	50428	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	переулок Коммунальный	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
22237	50428	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Толстого	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
22219	50428	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Мостовая	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
22247	50428	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Мира	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
21781	50428	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Калинина	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
22264	50428	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Аэродромная	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20458	50246	39.120731999999997	39.133668	44.55836	44.543591999999997	Таманская	0103000020E6100000010000000500000053CA6B25748F4340012F336C9445464053CA6B25748F434081B2295778474640C84274081C91434081B2295778474640C84274081C914340012F336C9445464053CA6B25748F4340012F336C94454640
21338	50356	39.265585999999999	39.298644000000003	44.786696999999997	44.745880999999997	Горбунова	0103000020E610000001000000050000004223D8B8FEA1434098DA5207795F46404223D8B8FEA143403F6EBF7CB2644640C59272F739A643403F6EBF7CB2644640C59272F739A6434098DA5207795F46404223D8B8FEA1434098DA5207795F4640
21472	50379	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Мичурина	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20935	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	пос.Мясокомбинат	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21357	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Шоссейная	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21236	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Шмидта	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21643	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Чехова	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21244	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Черноморская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21200	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Центральная	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21269	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Урупская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21438	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Урицкого	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21319	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Ставропольская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
22565	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Совецкая	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20846	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Советской Армии	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20603	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Свердлова	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20825	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	С.Армии	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20545	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Розы Люксембург	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21598	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Р.Люксембург	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21256	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Пушкина	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20590	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Песчаная	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20596	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Островского	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
22013	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Октябрьская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20830	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Новороссийская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
22223	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Мира	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20816	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Матвеева	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
22540	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Маркова	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20796	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Луначарского	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21822	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Лермонтова	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
22558	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Ленинградская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20536	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Ленина	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20793	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Лавриненко	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20445	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Кропоткина	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21432	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Кочубея	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21433	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Комсомольская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21461	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Комсомольская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20569	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Кирова	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21234	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Калинина	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
22031	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	К.Маркса	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20776	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	К.Либкнехта	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20454	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Ефремова	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21792	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Донская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21440	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Гоголя	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21668	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Володарского	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20495	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Академическая	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
20835	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	Азовская	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
21238	8849	40.889425000000003	41.269817000000003	45.065131999999998	44.775801000000001	30 лет Победы	0103000020E61000000100000005000000569FABADD8714440209A79724D634640569FABADD871444027F6D03E56884640D2730B5D89A2444027F6D03E56884640D2730B5D89A24440209A79724D634640569FABADD8714440209A79724D634640
22339	50361	39.673026	39.795762000000003	44.487043	44.420718000000001	Репина	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21590	50361	39.673026	39.795762000000003	44.487043	44.420718000000001	Лесозаводская	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21393	50361	39.673026	39.795762000000003	44.487043	44.420718000000001	Ленина	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
22900	9001	37.385770999999998	37.388869999999997	44.904018000000001	44.888610999999997	Кавказская	0103000020E61000000100000005000000635FB2F160B14240D4EE5701BE714640635FB2F160B14240677FA0DCB6734640A032FE7DC6B14240677FA0DCB6734640A032FE7DC6B14240D4EE5701BE714640635FB2F160B14240D4EE5701BE714640
16167	7955	37.311605999999998	37.322673000000002	44.884766999999997	44.879255000000001	улица Некрасова	0103000020E61000000100000005000000629E95B4E2A7424018EC866D8B704640629E95B4E2A742403ECA880B40714640AF264F594DA942403ECA880B40714640AF264F594DA9424018EC866D8B704640629E95B4E2A7424018EC866D8B704640
21274	7955	37.305031	37.331629999999997	44.897398000000003	44.870044	улица Ленина	0103000020E6100000010000000500000012A27C410BA742405F0A0F9A5D6F464012A27C410BA7424077BF0AF0DD724640AD2F12DA72AA424077BF0AF0DD724640AD2F12DA72AA42405F0A0F9A5D6F464012A27C410BA742405F0A0F9A5D6F4640
22986	7955	37.374003000000002	37.381028000000001	44.905805999999998	44.900270999999996	Школьная	0103000020E610000001000000050000008ECD8E54DFAF4240C34483143C7346408ECD8E54DFAF4240A2427573F17346401E6E8786C5B04240A2427573F17346401E6E8786C5B04240C34483143C7346408ECD8E54DFAF4240C34483143C734640
23750	7955	37.302568999999998	37.312719999999999	44.895099000000002	44.884670999999997	Черноморская	0103000020E6100000010000000500000047E4BB94BAA642401C5C3AE63C71464047E4BB94BAA6424056D7A19A927246400E677E3507A8424056D7A19A927246400E677E3507A842401C5C3AE63C71464047E4BB94BAA642401C5C3AE63C714640
23263	7955	37.267885	37.272070999999997	44.984606999999997	44.981253000000002	Центральная	0103000020E61000000100000005000000630B410E4AA242400B0DC4B2997D4640630B410E4AA24240D234289A077E46405298F738D3A24240D234289A077E46405298F738D3A242400B0DC4B2997D4640630B410E4AA242400B0DC4B2997D4640
22796	7955	37.304779000000003	37.337648000000002	44.898445000000002	44.883189000000002	Тургенева	0103000020E61000000100000005000000F9C08EFF02A74240EE974F560C714640F9C08EFF02A742409B20EA3E00734640A8C7B60C38AB42409B20EA3E00734640A8C7B60C38AB4240EE974F560C714640F9C08EFF02A74240EE974F560C714640
23910	7955	37.302776000000001	37.334809999999997	44.903035000000003	44.888297999999999	Терская	0103000020E61000000100000005000000C1012D5DC1A64240158DB5BFB3714640C1012D5DC1A642405A12A0A696734640D72FD80DDBAA42405A12A0A696734640D72FD80DDBAA4240158DB5BFB3714640C1012D5DC1A64240158DB5BFB3714640
21607	7955	37.298400999999998	37.313141999999999	44.892673000000002	44.877555999999998	Таманская	0103000020E61000000100000005000000FE0B040132A642404C3448C153704640FE0B040132A64240D882DE1B4372464084807C0915A84240D882DE1B4372464084807C0915A842404C3448C153704640FE0B040132A642404C3448C153704640
23348	7955	37.345032000000003	37.346479000000002	44.906368000000001	44.899275000000003	Спортивная	0103000020E61000000100000005000000680932022AAC4240228E75711B734640680932022AAC42400A12DBDD037446401AE0826C59AC42400A12DBDD037446401AE0826C59AC4240228E75711B734640680932022AAC4240228E75711B734640
22957	7955	37.363357999999998	37.369169999999997	44.907434000000002	44.899517000000003	Солнечная	0103000020E61000000100000005000000B75ED38382AE42401899805F23734640B75ED38382AE4240A5A31CCC2674464008556AF640AF4240A5A31CCC2674464008556AF640AF42401899805F23734640B75ED38382AE42401899805F23734640
23057	7955	37.276096000000003	37.278619999999997	44.995857999999998	44.993448000000001	Свободы	0103000020E6100000010000000500000039471D1D57A342406823D74D297F464039471D1D57A34240E0BA6246787F46407901F6D1A9A34240E0BA6246787F46407901F6D1A9A342406823D74D297F464039471D1D57A342406823D74D297F4640
23813	7955	37.306018999999999	37.336849000000001	44.900404999999999	44.885008999999997	Самбурова	0103000020E61000000100000005000000317A6EA12BA7424034D593F947714640317A6EA12BA74240D3139678407346405C5837DE1DAB4240D3139678407346405C5837DE1DAB424034D593F947714640317A6EA12BA7424034D593F947714640
2457	7955	37.267831000000001	37.322780999999999	44.975839999999998	44.904912000000003	Пионерский проспект	0103000020E6100000010000000500000070ED444948A2424005E10A28D473464070ED444948A2424077103B53E87C4640956247E350A9424077103B53E87C4640956247E350A9424005E10A28D473464070ED444948A2424005E10A28D4734640
23783	7955	37.326481999999999	37.343685000000001	44.899293999999998	44.886235999999997	Парковая	0103000020E61000000100000005000000C85D8429CAA94240D844662E70714640C85D8429CAA9424098BED7101C7346401990BDDEFDAB424098BED7101C7346401990BDDEFDAB4240D844662E70714640C85D8429CAA94240D844662E70714640
22804	7955	37.327990999999997	37.333911000000001	44.877761	44.874029999999998	Омелькова	0103000020E61000000100000005000000F030ED9BFBA9424087DC0C37E06F4640F030ED9BFBA94240255AF2785A70464028637C98BDAA4240255AF2785A70464028637C98BDAA424087DC0C37E06F4640F030ED9BFBA9424087DC0C37E06F4640
23017	7955	37.305785	37.319268999999998	44.905110000000001	44.896541999999997	Набережная	0103000020E61000000100000005000000BE4D7FF623A74240C6BE64E3C1724640BE4D7FF623A742402BA4FCA4DA73464035D07CCEDDA842402BA4FCA4DA73464035D07CCEDDA84240C6BE64E3C1724640BE4D7FF623A74240C6BE64E3C1724640
23095	7955	37.254294000000002	37.286256000000002	45.003563	44.989955000000002	Мира	0103000020E61000000100000005000000D6C8AEB48CA042407FC16ED8B67E4640D6C8AEB48CA04240E23C9CC07480464053245F09A4A44240E23C9CC07480464053245F09A4A442407FC16ED8B67E4640D6C8AEB48CA042407FC16ED8B67E4640
22706	7955	37.272862000000003	37.280155999999998	45.000995000000003	44.994199999999999	Лиманная	0103000020E610000001000000050000001C295B24EDA2424073D712F2417F46401C295B24EDA24240D23AAA9A208046409BE3DC26DCA34240D23AAA9A208046409BE3DC26DCA3424073D712F2417F46401C295B24EDA2424073D712F2417F4640
23814	7955	37.334702	37.350180000000002	44.908071999999997	44.903168999999998	Ленинградская	0103000020E61000000100000005000000F1F3DF83D7AA424069E1B20A9B734640F1F3DF83D7AA4240E7340BB43B7446404DDBBFB2D2AC4240E7340BB43B7446404DDBBFB2D2AC424069E1B20A9B734640F1F3DF83D7AA424069E1B20A9B734640
22677	7955	37.305031	37.331629999999997	44.897398000000003	44.870044	Ленина	0103000020E6100000010000000500000012A27C410BA742405F0A0F9A5D6F464012A27C410BA7424077BF0AF0DD724640AD2F12DA72AA424077BF0AF0DD724640AD2F12DA72AA42405F0A0F9A5D6F464012A27C410BA742405F0A0F9A5D6F4640
23702	7955	37.305031	37.331629999999997	44.897398000000003	44.870044	Ленина	0103000020E6100000010000000500000012A27C410BA742405F0A0F9A5D6F464012A27C410BA7424077BF0AF0DD724640AD2F12DA72AA424077BF0AF0DD724640AD2F12DA72AA42405F0A0F9A5D6F464012A27C410BA742405F0A0F9A5D6F4640
23961	7955	37.303565999999996	37.336058000000001	44.901738999999999	44.887481000000001	Крымская	0103000020E61000000100000005000000B9162D40DBA64240236937FA98714640B9162D40DBA642408D43FD2E6C73464093C7D3F203AB42408D43FD2E6C73464093C7D3F203AB4240236937FA98714640B9162D40DBA64240236937FA98714640
23911	7955	37.316628000000001	37.323113999999997	44.879644999999996	44.876164000000003	Крылова	0103000020E61000000100000005000000BB7F2C4487A842405EF7562426704640BB7F2C4487A84240828B1535987046409B70AFCC5BA94240828B1535987046409B70AFCC5BA942405EF7562426704640BB7F2C4487A842405EF7562426704640
22704	7955	37.275143999999997	37.282339	45.002237999999998	44.995716999999999	Комсомольская	0103000020E6100000010000000500000066D828EB37A342401E8997A7737F464066D828EB37A342407B67B4554980464053B131AF23A442407B67B4554980464053B131AF23A442401E8997A7737F464066D828EB37A342401E8997A7737F4640
23320	7955	37.241627000000001	37.377740000000003	44.998229000000002	44.856231999999999	Коммунаров	0103000020E61000000100000005000000516A2FA2ED9E4240F3E49A02996D4640516A2FA2ED9E42409B75C6F7C57F46400E32C9C859B042409B75C6F7C57F46400E32C9C859B04240F3E49A02996D4640516A2FA2ED9E4240F3E49A02996D4640
22814	7955	37.305857000000003	37.315944999999999	44.949219999999997	44.943229000000002	Дружбы	0103000020E6100000010000000500000058207A5226A74240C4D155BABB78464058207A5226A74240C45A7C0A80794640D82AC1E270A84240C45A7C0A80794640D82AC1E270A84240C4D155BABB78464058207A5226A74240C4D155BABB784640
20618	7955	37.317239000000001	37.331594000000003	44.899932	44.885514000000001	Гребенская	0103000020E6100000010000000500000004029D499BA842403813D3855871464004029D499BA84240DB4FC6F83073464061C614AC71AA4240DB4FC6F83073464061C614AC71AA42403813D3855871464004029D499BA842403813D38558714640
16163	7955	37.311211	37.337558999999999	44.894767000000002	44.879567999999999	Астраханская улица	0103000020E61000000100000005000000E69315C3D5A74240D74D29AF95704640E69315C3D5A7424020459DB98772464038BC202235AB424020459DB98772464038BC202235AB4240D74D29AF95704640E69315C3D5A74240D74D29AF95704640
23867	7955	37.311211	37.337558999999999	44.894767000000002	44.879567999999999	Астраханская	0103000020E61000000100000005000000E69315C3D5A74240D74D29AF95704640E69315C3D5A7424020459DB98772464038BC202235AB424020459DB98772464038BC202235AB4240D74D29AF95704640E69315C3D5A74240D74D29AF95704640
23558	50767	38.093778	38.123916999999999	44.615704999999998	44.587935000000002	Октябрьская	0103000020E61000000100000005000000CA8AE1EA000C43403E963E74414B4640CA8AE1EA000C4340E97DE36BCF4E46408F352383DC0F4340E97DE36BCF4E46408F352383DC0F43403E963E74414B4640CA8AE1EA000C43403E963E74414B4640
75507	50438	40.229261999999999	40.284410000000001	43.691496000000001	43.67868	2-ая бригада	0103000020E61000000100000005000000971B0C75581D444082397AFCDED64540971B0C75581D44404CA8E0F082D84540E353008C672444404CA8E0F082D84540E353008C6724444082397AFCDED64540971B0C75581D444082397AFCDED64540
20567	50263	39.257868999999999	39.266222999999997	44.051906000000002	44.046410999999999	Зыхы	0103000020E610000001000000050000007CD3F4D901A143405B96AFCBF00546407CD3F4D901A14340AC3B16DBA4064640B438639813A24340AC3B16DBA4064640B438639813A243405B96AFCBF00546407CD3F4D901A143405B96AFCBF0054640
21424	46911	40.188488	40.222794	43.691405000000003	43.671038000000003	Турчинского	0103000020E610000001000000050000001FD8F15F20184440C72FBC92E4D545401FD8F15F201844403CA583F57FD845405DDF8783841C44403CA583F57FD845405DDF8783841C4440C72FBC92E4D545401FD8F15F20184440C72FBC92E4D54540
75539	46911	40.188488	40.222794	43.691405000000003	43.671038000000003	Пикет № 397	0103000020E610000001000000050000001FD8F15F20184440C72FBC92E4D545401FD8F15F201844403CA583F57FD845405DDF8783841C44403CA583F57FD845405DDF8783841C4440C72FBC92E4D545401FD8F15F20184440C72FBC92E4D54540
22679	46911	40.188488	40.222794	43.691405000000003	43.671038000000003	Защитников Кавказа	0103000020E610000001000000050000001FD8F15F20184440C72FBC92E4D545401FD8F15F201844403CA583F57FD845405DDF8783841C44403CA583F57FD845405DDF8783841C4440C72FBC92E4D545401FD8F15F20184440C72FBC92E4D54540
75536	46911	40.188488	40.222794	43.691405000000003	43.671038000000003	12-й км дороги Адлер - Красная Поляна	0103000020E610000001000000050000001FD8F15F20184440C72FBC92E4D545401FD8F15F201844403CA583F57FD845405DDF8783841C44403CA583F57FD845405DDF8783841C4440C72FBC92E4D545401FD8F15F20184440C72FBC92E4D54540
23457	50721	39.876520999999997	39.887804000000003	43.626531999999997	43.611241	Центральная	0103000020E61000000100000005000000ECA012D731F04340B77C24253DCE4540ECA012D731F04340E0F2583332D0454006A1BC8FA3F14340E0F2583332D0454006A1BC8FA3F14340B77C24253DCE4540ECA012D731F04340B77C24253DCE4540
21649	50400	39.344835000000003	39.363897000000001	44.012605000000001	44.004396999999997	Адыгахабль	0103000020E6100000010000000500000012C2A38D23AC4340AA99B5149000464012C2A38D23AC43400F62670A9D014640670E492D94AE43400F62670A9D014640670E492D94AE4340AA99B5149000464012C2A38D23AC4340AA99B51490004640
20668	49189	39.693129999999996	39.704448999999997	43.696541000000003	43.690753000000001	Калинина	0103000020E6100000010000000500000030F0DC7BB8D84340944E24986AD8454030F0DC7BB8D843405DA9674128D94540965984622BDA43405DA9674128D94540965984622BDA4340944E24986AD8454030F0DC7BB8D84340944E24986AD84540
21328	6355	39.998548	40.013145999999999	43.516261	43.507303999999998	Кропоткинская	0103000020E610000001000000050000003CBEBD6BD0FF4340A3906456EFC045403CBEBD6BD0FF4340A29927D714C245405F09A4C4AE014440A29927D714C245405F09A4C4AE014440A3906456EFC045403CBEBD6BD0FF4340A3906456EFC04540
20436	28335	37.686114000000003	37.689312000000001	44.672552000000003	44.666519999999998	Красная	0103000020E61000000100000005000000F4A96395D2D74240A110018750554640F4A96395D2D74240016E162F16564640C45E28603BD84240016E162F16564640C45E28603BD84240A110018750554640F4A96395D2D74240A110018750554640
20970	50250	37.534531999999999	37.592041999999999	44.849395000000001	44.816544999999998	Нижняя	0103000020E610000001000000050000002E55698B6BC442402D5BEB8B846846402E55698B6BC442406631B1F9B86C4640E1ED4108C8CB42406631B1F9B86C4640E1ED4108C8CB42402D5BEB8B846846402E55698B6BC442402D5BEB8B84684640
22577	50250	37.534531999999999	37.592041999999999	44.849395000000001	44.816544999999998	Ленина	0103000020E610000001000000050000002E55698B6BC442402D5BEB8B846846402E55698B6BC442406631B1F9B86C4640E1ED4108C8CB42406631B1F9B86C4640E1ED4108C8CB42402D5BEB8B846846402E55698B6BC442402D5BEB8B84684640
20477	50250	37.534531999999999	37.592041999999999	44.849395000000001	44.816544999999998	Красная	0103000020E610000001000000050000002E55698B6BC442402D5BEB8B846846402E55698B6BC442406631B1F9B86C4640E1ED4108C8CB42406631B1F9B86C4640E1ED4108C8CB42402D5BEB8B846846402E55698B6BC442402D5BEB8B84684640
22058	45533	37.636060000000001	37.647036999999997	44.713689000000002	44.703671	Чехова	0103000020E610000001000000050000009A25016A6AD1424062122EE4115A46409A25016A6AD14240EA4141295A5B4640A626C11BD2D24240EA4141295A5B4640A626C11BD2D2424062122EE4115A46409A25016A6AD1424062122EE4115A4640
20464	50249	37.685566000000001	37.716665999999996	44.795991999999998	44.775717999999998	Гагарина	0103000020E61000000100000005000000F19F6EA0C0D74240927538BA4A634640F19F6EA0C0D7424056F0DB10E3654640DB1324B6BBDB424056F0DB10E3654640DB1324B6BBDB4240927538BA4A634640F19F6EA0C0D74240927538BA4A634640
21683	50321	37.641162000000001	37.684190999999998	44.85266	44.830233	Титан	0103000020E610000001000000050000000FB8AE9811D24240AD872F13456A46400FB8AE9811D24240BE4D7FF6236D4640D89B189293D74240BE4D7FF6236D4640D89B189293D74240AD872F13456A46400FB8AE9811D24240AD872F13456A4640
21051	50321	37.641162000000001	37.684190999999998	44.85266	44.830233	Орловская	0103000020E610000001000000050000000FB8AE9811D24240AD872F13456A46400FB8AE9811D24240BE4D7FF6236D4640D89B189293D74240BE4D7FF6236D4640D89B189293D74240AD872F13456A46400FB8AE9811D24240AD872F13456A4640
22313	50487	37.592824	37.609479	44.751623000000002	44.739741000000002	Солнечная	0103000020E61000000100000005000000572426A8E1CB4240534145D5AF5E4640572426A8E1CB4240F1F5B52E35604640A54C6A6803CE4240F1F5B52E35604640A54C6A6803CE4240534145D5AF5E4640572426A8E1CB4240534145D5AF5E4640
20986	50308	37.583525999999999	37.606245000000001	44.724212999999999	44.693381000000002	Островского	0103000020E61000000100000005000000CF2EDFFAB0CA42407A5567B5C0584640CF2EDFFAB0CA4240452BF702B35C4640882EA86F99CD4240452BF702B35C4640882EA86F99CD42407A5567B5C0584640CF2EDFFAB0CA42407A5567B5C0584640
21082	27612	38.582219000000002	38.601084	44.375388999999998	44.369545000000002	Ленина	0103000020E610000001000000050000000F0EF626864A43403EB324404D2F46400F0EF626864A43409A232BBF0C3046400E130D52F04C43409A232BBF0C3046400E130D52F04C43403EB324404D2F46400F0EF626864A43403EB324404D2F4640
20640	27317	38.387419999999999	38.418097000000003	44.481653999999999	44.463534000000003	Советская	0103000020E610000001000000050000007DE882FA96314340C34A0515553B46407DE882FA9631434069FE98D6A63D464022C7D6338435434069FE98D6A63D464022C7D63384354340C34A0515553B46407DE882FA96314340C34A0515553B4640
20838	25873	38.213317000000004	38.224663	44.481383999999998	44.467947000000002	Морская	0103000020E610000001000000050000002657B1F84D1B434073A1F2AFE53B46402657B1F84D1B4340A968ACFD9D3D464085CFD6C1C11C4340A968ACFD9D3D464085CFD6C1C11C434073A1F2AFE53B46402657B1F84D1B434073A1F2AFE53B4640
24041	50903	38.287346999999997	38.333584000000002	44.526435999999997	44.502436000000003	Школьная	0103000020E6100000010000000500000046CD57C9C7244340A22AA6D24F40464046CD57C9C7244340F1B73D4162434640043C69E1B22A4340F1B73D4162434640043C69E1B22A4340A22AA6D24F40464046CD57C9C7244340A22AA6D24F404640
20608	46814	37.917098000000003	37.921759999999999	44.669629	44.666533000000001	Революционная	0103000020E610000001000000050000000F9D9E7763F54240365A0EF4505546400F9D9E7763F5424002BA2F67B655464067614F3BFCF5424002BA2F67B655464067614F3BFCF54240365A0EF4505546400F9D9E7763F54240365A0EF450554640
20863	46814	37.917098000000003	37.921759999999999	44.669629	44.666533000000001	Партизанская	0103000020E610000001000000050000000F9D9E7763F54240365A0EF4505546400F9D9E7763F5424002BA2F67B655464067614F3BFCF5424002BA2F67B655464067614F3BFCF54240365A0EF4505546400F9D9E7763F54240365A0EF450554640
21506	27126	38.117789999999999	38.152869000000003	44.536203999999998	44.492052000000001	Кирова	0103000020E61000000100000005000000DEE522BE130F434038F7578FFB3E4640DEE522BE130F434000FE2955A24446403FC91D369113434000FE2955A24446403FC91D369113434038F7578FFB3E4640DEE522BE130F434038F7578FFB3E4640
21619	27126	38.117789999999999	38.152869000000003	44.536203999999998	44.492052000000001	Горная	0103000020E61000000100000005000000DEE522BE130F434038F7578FFB3E4640DEE522BE130F434000FE2955A24446403FC91D369113434000FE2955A24446403FC91D369113434038F7578FFB3E4640DEE522BE130F434038F7578FFB3E4640
22244	50480	38.354550000000003	38.372408999999998	44.430824999999999	44.410299999999999	Мира	0103000020E61000000100000005000000FE65F7E4612D43403FC6DCB584344640FE65F7E4612D43404CA60A462537464037DE1D19AB2F43404CA60A462537464037DE1D19AB2F43403FC6DCB584344640FE65F7E4612D43403FC6DCB584344640
21296	27504	38.516463000000002	38.550975999999999	44.393388999999999	44.356721	Рабочая	0103000020E610000001000000050000000A4CA7751B424340F165A208A92D46400A4CA7751B42434096CD1C925A324640C170AE618646434096CD1C925A324640C170AE6186464340F165A208A92D46400A4CA7751B424340F165A208A92D4640
20791	27504	38.516463000000002	38.550975999999999	44.393388999999999	44.356721	Ленина	0103000020E610000001000000050000000A4CA7751B424340F165A208A92D46400A4CA7751B42434096CD1C925A324640C170AE618646434096CD1C925A324640C170AE6186464340F165A208A92D46400A4CA7751B424340F165A208A92D4640
22187	27504	38.516463000000002	38.550975999999999	44.393388999999999	44.356721	Красных партизан	0103000020E610000001000000050000000A4CA7751B424340F165A208A92D46400A4CA7751B42434096CD1C925A324640C170AE618646434096CD1C925A324640C170AE6186464340F165A208A92D46400A4CA7751B424340F165A208A92D4640
21237	5937	38.492612000000001	38.518096999999997	46.639156	46.626631000000003	К. Маркса	0103000020E61000000100000005000000FFCEF6E80D3F434074D4D17135504740FFCEF6E80D3F4340668522DDCF514740EE93A30051424340668522DDCF514740EE93A3005142434074D4D17135504740FFCEF6E80D3F434074D4D17135504740
21288	5987	38.451469000000003	38.490968000000002	46.861592999999999	46.842100000000002	Ленина	0103000020E61000000100000005000000341477BCC939434016FBCBEEC96B4740341477BCC939434034BBEEAD486E4740F7B0170AD83E434034BBEEAD486E4740F7B0170AD83E434016FBCBEEC96B4740341477BCC939434016FBCBEEC96B4740
21065	5481	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	Шевченко	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
21487	5481	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	Тельмана	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
22605	5481	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	Ленина	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
20610	5481	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	Красноармейская	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
21477	5481	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	Красная	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
22105	50466	38.624915999999999	38.709510999999999	46.646098000000002	46.612642999999998	Первомайская	0103000020E61000000100000005000000A25F5B3FFD4F4340C98FF8156B4E4740A25F5B3FFD4F43406901DA56B35247407D93A641D15A43406901DA56B35247407D93A641D15A4340C98FF8156B4E4740A25F5B3FFD4F4340C98FF8156B4E4740
20862	5812	38.619993000000001	38.679893	46.488035000000004	46.460293	Советов	0103000020E61000000100000005000000DD5F3DEE5B4F4340F3C98AE1EA3A4740DD5F3DEE5B4F4340D5264EEE773E4740C1E3DBBB06574340D5264EEE773E4740C1E3DBBB06574340F3C98AE1EA3A4740DD5F3DEE5B4F4340F3C98AE1EA3A4740
21493	5812	38.619993000000001	38.679893	46.488035000000004	46.460293	Мира	0103000020E61000000100000005000000DD5F3DEE5B4F4340F3C98AE1EA3A4740DD5F3DEE5B4F4340D5264EEE773E4740C1E3DBBB06574340D5264EEE773E4740C1E3DBBB06574340F3C98AE1EA3A4740DD5F3DEE5B4F4340F3C98AE1EA3A4740
21997	49293	38.555188999999999	38.587403000000002	46.739082000000003	46.724733000000001	2-я Пятилетка	0103000020E61000000100000005000000AA0CE36E104743407EAA0A0DC45C4740AA0CE36E10474340F9872D3D9A5E474041498105304B4340F9872D3D9A5E474041498105304B43407EAA0A0DC45C4740AA0CE36E104743407EAA0A0DC45C4740
20612	6311	38.752817999999998	38.804723000000003	46.822038999999997	46.806584000000001	Мира	0103000020E6100000010000000500000089EB18575C6043400ABDFE243E67474089EB18575C604340AD84EE923869474065ABCB2901674340AD84EE923869474065ABCB29016743400ABDFE243E67474089EB18575C6043400ABDFE243E674740
22172	6363	38.831969000000001	38.861181999999999	46.677745000000002	46.669440999999999	переулок Бригадный	0103000020E610000001000000050000009624CFF57D6A4340FFCC203EB05547409624CFF57D6A434086032159C0564740B2F336363B6E434086032159C0564740B2F336363B6E4340FFCC203EB05547409624CFF57D6A4340FFCC203EB0554740
21021	49302	38.724944000000001	38.788257000000002	46.702934999999997	46.681775999999999	пер. Советов	0103000020E6100000010000000500000039B709F7CA5C43404E999B6F4457474039B709F7CA5C43405C1B2AC6F9594740EAEBF99AE56443405C1B2AC6F9594740EAEBF99AE56443404E999B6F4457474039B709F7CA5C43404E999B6F44574740
21520	49302	38.724944000000001	38.788257000000002	46.702934999999997	46.681775999999999	Крестьянская	0103000020E6100000010000000500000039B709F7CA5C43404E999B6F4457474039B709F7CA5C43405C1B2AC6F9594740EAEBF99AE56443405C1B2AC6F9594740EAEBF99AE56443404E999B6F4457474039B709F7CA5C43404E999B6F44574740
23782	50828	38.594526000000002	38.630800000000001	46.717726999999996	46.695036000000002	Советов	0103000020E61000000100000005000000944F8F6D194C434076C58CF0F6584740944F8F6D194C4340643A747ADE5B47408D28ED0DBE504340643A747ADE5B47408D28ED0DBE50434076C58CF0F6584740944F8F6D194C434076C58CF0F6584740
22467	49260	38.397373000000002	38.421996	46.772044000000001	46.75526	Первомайская	0103000020E610000001000000050000001EA8531EDD3243400DFD135CAC6047401EA8531EDD32434059897956D26247407B8505F70336434059897956D26247407B8505F7033643400DFD135CAC6047401EA8531EDD3243400DFD135CAC604740
21523	45493	39.822890999999998	39.849670000000003	45.369404000000003	45.350056000000002	Школьная	0103000020E610000001000000050000001C96067E54E9434061E28FA2CEAC46401C96067E54E943407C8159A148AF464038328FFCC1EC43407C8159A148AF464038328FFCC1EC434061E28FA2CEAC46401C96067E54E9434061E28FA2CEAC4640
20709	45493	39.822890999999998	39.849670000000003	45.369404000000003	45.350056000000002	Советская	0103000020E610000001000000050000001C96067E54E9434061E28FA2CEAC46401C96067E54E943407C8159A148AF464038328FFCC1EC43407C8159A148AF464038328FFCC1EC434061E28FA2CEAC46401C96067E54E9434061E28FA2CEAC4640
21099	45493	39.822890999999998	39.849670000000003	45.369404000000003	45.350056000000002	Кирова	0103000020E610000001000000050000001C96067E54E9434061E28FA2CEAC46401C96067E54E943407C8159A148AF464038328FFCC1EC43407C8159A148AF464038328FFCC1EC434061E28FA2CEAC46401C96067E54E9434061E28FA2CEAC4640
21521	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Энгельса	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20506	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Советская	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20490	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Рубина	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
21148	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Пролетарская	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20742	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Позиционная	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20456	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Островского	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20743	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Октябрьская	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
21571	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Ободовского	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
21385	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Ленина	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20500	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Куйбышева	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
21057	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Комсомольская	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
21156	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Кавказская	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20513	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Демьяна Бедного	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20940	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Воронежская	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
20496	2261	39.640622999999998	39.730446000000001	45.236955000000002	45.200391000000003	Вокзальная	0103000020E610000001000000050000005F0839EFFFD14340D5B48B69A69946405F0839EFFFD14340D5CF9B8A549E46403CBF28417FDD4340D5CF9B8A549E46403CBF28417FDD4340D5B48B69A69946405F0839EFFFD14340D5B48B69A6994640
23385	50684	39.992035000000001	40.049680000000002	45.106293000000001	45.091475000000003	Мира	0103000020E6100000010000000500000062BEBC00FBFE434068B3EA73B58B464062BEBC00FBFE434099654F029B8D4640F5A10BEA5B06444099654F029B8D4640F5A10BEA5B06444068B3EA73B58B464062BEBC00FBFE434068B3EA73B58B4640
20841	5068	39.410744000000001	39.516162000000001	45.297553999999998	45.269080000000002	Чапаева	0103000020E610000001000000050000009D83674293B44340FC00A43671A246409D83674293B44340A165DD3F16A646400FB8AE9811C24340A165DD3F16A646400FB8AE9811C24340FC00A43671A246409D83674293B44340FC00A43671A24640
20745	5068	39.410744000000001	39.516162000000001	45.297553999999998	45.269080000000002	Ленина	0103000020E610000001000000050000009D83674293B44340FC00A43671A246409D83674293B44340A165DD3F16A646400FB8AE9811C24340A165DD3F16A646400FB8AE9811C24340FC00A43671A246409D83674293B44340FC00A43671A24640
23652	50803	39.967790000000001	39.985818999999999	45.240997	45.228043	Советская	0103000020E61000000100000005000000ABB2EF8AE0FB4340768A5583309D4640ABB2EF8AE0FB434091B75CFDD89E4640416326512FFE434091B75CFDD89E4640416326512FFE4340768A5583309D4640ABB2EF8AE0FB4340768A5583309D4640
23350	50676	39.964682000000003	40.013972000000003	45.221573999999997	45.199914999999997	Мира	0103000020E610000001000000050000001B8524B37AFB43406B7D91D0969946401B8524B37AFB43406BD26D895C9C4640A587A1D5C90144406BD26D895C9C4640A587A1D5C90144406B7D91D0969946401B8524B37AFB43406B7D91D096994640
21250	4970	39.862983	39.939978000000004	45.129629000000001	45.098123999999999	Красноармейская	0103000020E610000001000000050000008200193A76EE4340F279C5538F8C46408200193A76EE43407DCEDDAE97904640D17AF83251F843407DCEDDAE97904640D17AF83251F84340F279C5538F8C46408200193A76EE4340F279C5538F8C4640
20747	4970	39.862983	39.939978000000004	45.129629000000001	45.098123999999999	Калинина	0103000020E610000001000000050000008200193A76EE4340F279C5538F8C46408200193A76EE43407DCEDDAE97904640D17AF83251F843407DCEDDAE97904640D17AF83251F84340F279C5538F8C46408200193A76EE4340F279C5538F8C4640
23751	50774	39.723547000000003	39.789807000000003	45.159610000000001	45.134245	Советская	0103000020E61000000100000005000000390F27309DDC43406553AEF02E914640390F27309DDC4340AA0EB9196E9446407193516518E54340AA0EB9196E9446407193516518E543406553AEF02E914640390F27309DDC43406553AEF02E914640
23571	50774	39.723547000000003	39.789807000000003	45.159610000000001	45.134245	Ленина	0103000020E61000000100000005000000390F27309DDC43406553AEF02E914640390F27309DDC4340AA0EB9196E9446407193516518E54340AA0EB9196E9446407193516518E543406553AEF02E914640390F27309DDC43406553AEF02E914640
23781	50283	39.891863999999998	39.975487999999999	45.332141	45.280408000000001	Школьная	0103000020E61000000100000005000000683D7C9928F24340B5C4CA68E4A34640683D7C9928F243409354A69883AA4640FAD170CADCFC43409354A69883AA4640FAD170CADCFC4340B5C4CA68E4A34640683D7C9928F24340B5C4CA68E4A34640
23612	50283	39.891863999999998	39.975487999999999	45.332141	45.280408000000001	Красная	0103000020E61000000100000005000000683D7C9928F24340B5C4CA68E4A34640683D7C9928F243409354A69883AA4640FAD170CADCFC43409354A69883AA4640FAD170CADCFC4340B5C4CA68E4A34640683D7C9928F24340B5C4CA68E4A34640
20746	50283	39.891863999999998	39.975487999999999	45.332141	45.280408000000001	Коншиных	0103000020E61000000100000005000000683D7C9928F24340B5C4CA68E4A34640683D7C9928F243409354A69883AA4640FAD170CADCFC43409354A69883AA4640FAD170CADCFC4340B5C4CA68E4A34640683D7C9928F24340B5C4CA68E4A34640
21413	50283	39.891863999999998	39.975487999999999	45.332141	45.280408000000001	Комсомольская	0103000020E61000000100000005000000683D7C9928F24340B5C4CA68E4A34640683D7C9928F243409354A69883AA4640FAD170CADCFC43409354A69883AA4640FAD170CADCFC4340B5C4CA68E4A34640683D7C9928F24340B5C4CA68E4A34640
23455	50708	39.633563000000002	39.750917999999999	45.393523000000002	45.361576999999997	Советская	0103000020E61000000100000005000000537AA69718D143402EFEB62748AE4640537AA69718D14340A69C2FF65EB2464026FDBD141EE04340A69C2FF65EB2464026FDBD141EE043402EFEB62748AE4640537AA69718D143402EFEB62748AE4640
23575	50708	39.633563000000002	39.750917999999999	45.393523000000002	45.361576999999997	Красная	0103000020E61000000100000005000000537AA69718D143402EFEB62748AE4640537AA69718D14340A69C2FF65EB2464026FDBD141EE04340A69C2FF65EB2464026FDBD141EE043402EFEB62748AE4640537AA69718D143402EFEB62748AE4640
23440	50708	39.633563000000002	39.750917999999999	45.393523000000002	45.361576999999997	Кирпильская	0103000020E61000000100000005000000537AA69718D143402EFEB62748AE4640537AA69718D14340A69C2FF65EB2464026FDBD141EE04340A69C2FF65EB2464026FDBD141EE043402EFEB62748AE4640537AA69718D143402EFEB62748AE4640
23833	50838	39.787515999999997	39.822432999999997	45.196434000000004	45.181035999999999	Степная	0103000020E61000000100000005000000D2890453CDE4434007B309302C974640D2890453CDE4434047E9D2BF2499464059130B7C45E9434047E9D2BF2499464059130B7C45E9434007B309302C974640D2890453CDE4434007B309302C974640
23567	50771	39.537424999999999	39.571784999999998	45.305084999999998	45.288080999999998	Ленина	0103000020E61000000100000005000000C286A757CAC44340ABCC94D6DFA44640C286A757CAC4434005C078060DA74640F3AB394030C9434005C078060DA74640F3AB394030C94340ABCC94D6DFA44640C286A757CAC44340ABCC94D6DFA44640
20503	3433	39.782611000000003	39.819423999999998	45.303607999999997	45.237366999999999	Пионерская	0103000020E61000000100000005000000B43EE5982CE443402713B70A629E4640B43EE5982CE44340E8667FA0DCA646405CC7B8E2E2E84340E8667FA0DCA646405CC7B8E2E2E843402713B70A629E4640B43EE5982CE443402713B70A629E4640
24019	50899	39.747171999999999	39.805644000000001	45.382300999999998	45.354756000000002	Школьная	0103000020E61000000100000005000000533E0455A3DF4340A70705A568AD4640533E0455A3DF4340321D3A3DEFB04640FC1BB4571FE74340321D3A3DEFB04640FC1BB4571FE74340A70705A568AD4640533E0455A3DF4340A70705A568AD4640
23665	50294	39.538789999999999	39.590649999999997	45.223002000000001	45.197597000000002	Ленина	0103000020E61000000100000005000000B7B41A12F7C44340D464C6DB4A994640B7B41A12F7C44340A7785C548B9C4640F2B0506B9ACB4340A7785C548B9C4640F2B0506B9ACB4340D464C6DB4A994640B7B41A12F7C44340D464C6DB4A994640
22497	50294	39.538789999999999	39.590649999999997	45.223002000000001	45.197597000000002	Красная	0103000020E61000000100000005000000B7B41A12F7C44340D464C6DB4A994640B7B41A12F7C44340A7785C548B9C4640F2B0506B9ACB4340A7785C548B9C4640F2B0506B9ACB4340D464C6DB4A994640B7B41A12F7C44340D464C6DB4A994640
23987	50294	39.538789999999999	39.590649999999997	45.223002000000001	45.197597000000002	Заводская	0103000020E61000000100000005000000B7B41A12F7C44340D464C6DB4A994640B7B41A12F7C44340A7785C548B9C4640F2B0506B9ACB4340A7785C548B9C4640F2B0506B9ACB4340D464C6DB4A994640B7B41A12F7C44340D464C6DB4A994640
23680	50703	39.850560000000002	39.925002999999997	45.242876000000003	45.220818999999999	Советская	0103000020E6100000010000000500000094A46B26DFEC4340EFAA07CC439C464094A46B26DFEC4340DD7D8E8F169F4640D7D9907F66F64340DD7D8E8F169F4640D7D9907F66F64340EFAA07CC439C464094A46B26DFEC4340EFAA07CC439C4640
23426	50703	39.850560000000002	39.925002999999997	45.242876000000003	45.220818999999999	Красная	0103000020E6100000010000000500000094A46B26DFEC4340EFAA07CC439C464094A46B26DFEC4340DD7D8E8F169F4640D7D9907F66F64340DD7D8E8F169F4640D7D9907F66F64340EFAA07CC439C464094A46B26DFEC4340EFAA07CC439C4640
23899	50859	39.963487000000001	40.026279000000002	45.445273	45.411002000000003	Красная	0103000020E61000000100000005000000828FC18A53FB4340994BAAB69BB44640828FC18A53FB43405A65A6B4FEB846402AC93A1C5D0344405A65A6B4FEB846402AC93A1C5D034440994BAAB69BB44640828FC18A53FB4340994BAAB69BB44640
23557	50766	40.033177999999999	40.076206999999997	45.260300000000001	45.245522000000001	Красная	0103000020E610000001000000050000002D793C2D3F0444406939D0436D9F46402D793C2D3F0444400C93A98251A14640F65CA626C10944400C93A98251A14640F65CA626C10944406939D0436D9F46402D793C2D3F0444406939D0436D9F4640
22003	1036	41.362433000000003	41.432493000000001	44.846136000000001	44.821776	Молодежная	0103000020E61000000100000005000000DFFE5C3464AE4440A051BAF42F694640DFFE5C3464AE4440F0FB372F4E6C4640DD5F3DEE5BB74440F0FB372F4E6C4640DD5F3DEE5BB74440A051BAF42F694640DFFE5C3464AE4440A051BAF42F694640
20542	1036	41.362433000000003	41.432493000000001	44.846136000000001	44.821776	Ленина 	0103000020E61000000100000005000000DFFE5C3464AE4440A051BAF42F694640DFFE5C3464AE4440F0FB372F4E6C4640DD5F3DEE5BB74440F0FB372F4E6C4640DD5F3DEE5BB74440A051BAF42F694640DFFE5C3464AE4440A051BAF42F694640
22246	1036	41.362433000000003	41.432493000000001	44.846136000000001	44.821776	Калинина	0103000020E61000000100000005000000DFFE5C3464AE4440A051BAF42F694640DFFE5C3464AE4440F0FB372F4E6C4640DD5F3DEE5BB74440F0FB372F4E6C4640DD5F3DEE5BB74440A051BAF42F694640DFFE5C3464AE4440A051BAF42F694640
21759	50427	41.362433000000003	41.432493000000001	44.846136000000001	44.821776	Школьная	0103000020E61000000100000005000000DFFE5C3464AE4440A051BAF42F694640DFFE5C3464AE4440F0FB372F4E6C4640DD5F3DEE5BB74440F0FB372F4E6C4640DD5F3DEE5BB74440A051BAF42F694640DFFE5C3464AE4440A051BAF42F694640
22978	32332	41.264040999999999	41.311399999999999	44.932305999999997	44.894626000000002	Почтовая	0103000020E61000000100000005000000CDE67118CCA144405E13D21A83724640CDE67118CCA14440AAEE91CD55774640B9FC87F4DBA74440AAEE91CD55774640B9FC87F4DBA744405E13D21A83724640CDE67118CCA144405E13D21A83724640
20716	1928	41.293298999999998	41.319699999999997	44.694046999999998	44.660986999999999	Мира	0103000020E61000000100000005000000897956D28AA54440630AD6389B544640897956D28AA5444086713788D6584640FE43FAEDEBA8444086713788D6584640FE43FAEDEBA84440630AD6389B544640897956D28AA54440630AD6389B544640
21368	2034	41.332717000000002	41.358445000000003	44.652907999999996	44.628453	Ленина	0103000020E6100000010000000500000060E97C7896AA44405B09DD257150464060E97C7896AA4440FCA5457D9253464016359886E1AD4440FCA5457D9253464016359886E1AD44405B09DD257150464060E97C7896AA44405B09DD2571504640
21527	47840	41.194718000000002	41.212153999999998	44.994002999999999	44.975808000000001	Ленина	0103000020E61000000100000005000000A5F8F884EC9844406C96CB46E77C4640A5F8F884EC9844401D90847D3B7F464098DBBDDC279B44401D90847D3B7F464098DBBDDC279B44406C96CB46E77C4640A5F8F884EC9844406C96CB46E77C4640
23338	50671	41.550351999999997	41.596777000000003	44.871493999999998	44.852812999999998	улица Красная	0103000020E61000000100000005000000E3A430EF71C64440444DF4F9286D4640E3A430EF71C6444082548A1D8D6F4640A400513063CC444082548A1D8D6F4640A400513063CC4440444DF4F9286D4640E3A430EF71C64440444DF4F9286D4640
21110	47710	41.469107999999999	41.491584000000003	44.788500999999997	44.774861000000001	Ленина	0103000020E610000001000000050000005F251FBB0BBC444012F92EA52E6346405F251FBB0BBC444080EECB99ED644640529E7939ECBE444080EECB99ED644640529E7939ECBE444012F92EA52E6346405F251FBB0BBC444012F92EA52E634640
21161	50336	41.246802000000002	41.281396000000001	44.911378999999997	44.891643999999999	Центральная	0103000020E61000000100000005000000304B3B35979F44405AD6FD6321724640304B3B35979F44406EA12B11A8744640D49CBCC804A444406EA12B11A8744640D49CBCC804A444405AD6FD6321724640304B3B35979F44405AD6FD6321724640
22636	1543	41.501834000000002	41.532305000000001	44.836247999999998	44.821295999999997	Ленина	0103000020E61000000100000005000000AC02B5183CC04440F52A323A20694640AC02B5183CC0444036ACA92C0A6B4640A73FFB9122C4444036ACA92C0A6B4640A73FFB9122C44440F52A323A20694640AC02B5183CC04440F52A323A20694640
20631	1488	41.306468000000002	41.343218	44.879657000000002	44.842830999999997	Калинина	0103000020E61000000100000005000000A1A2EA573AA744400987DEE2E16B4640A1A2EA573AA744404759BF999870464003B34291EEAB44404759BF999870464003B34291EEAB44400987DEE2E16B4640A1A2EA573AA744400987DEE2E16B4640
21630	1488	41.306468000000002	41.343218	44.879657000000002	44.842830999999997	Донская	0103000020E61000000100000005000000A1A2EA573AA744400987DEE2E16B4640A1A2EA573AA744404759BF999870464003B34291EEAB44404759BF999870464003B34291EEAB44400987DEE2E16B4640A1A2EA573AA744400987DEE2E16B4640
20632	1691	41.419997000000002	41.435799000000003	44.861010999999998	44.846423000000001	Советская	0103000020E6100000010000000500000085B53176C2B5444086CABF96576C464085B53176C2B54440853FC39B356E46409450FA42C8B74440853FC39B356E46409450FA42C8B7444086CABF96576C464085B53176C2B5444086CABF96576C4640
20833	30302	39.134188999999999	39.165415000000003	44.05245	44.025460000000002	Сочинская	0103000020E61000000100000005000000D13DEB1A2D91434097ADF54542034640D13DEB1A2D9143406D567DAEB606464049A297512C9543406D567DAEB606464049A297512C95434097ADF54542034640D13DEB1A2D91434097ADF54542034640
22590	31347	39.282752000000002	39.301760999999999	44.33334	44.309311000000001	Шаумяна	0103000020E610000001000000050000007670B03731A4434083A5BA80972746407670B03731A443406D3997E2AA2A4640A81ABD1AA0A643406D3997E2AA2A4640A81ABD1AA0A6434083A5BA80972746407670B03731A4434083A5BA8097274640
20822	31791	39.168450999999997	39.181333000000002	44.166733000000001	44.152596000000003	Центральная	0103000020E610000001000000050000003FFD67CD8F9543400EC00644881346403FFD67CD8F954340FD14C78157154640C15774EB35974340FD14C78157154640C15774EB359743400EC00644881346403FFD67CD8F9543400EC0064488134640
20566	29551	38.776784999999997	38.794707000000002	44.333972000000003	44.319997999999998	Шаумяна	0103000020E61000000100000005000000FD82DDB06D6343408864C8B1F5284640FD82DDB06D634340CEE33098BF2A46407E737FF5B8654340CEE33098BF2A46407E737FF5B86543408864C8B1F5284640FD82DDB06D6343408864C8B1F5284640
21183	50338	39.163052	39.177236000000001	44.391533000000003	44.383268999999999	Баграмяна	0103000020E6100000010000000500000011C64FE3DE9443400A4966F50E31464011C64FE3DE9443400327DBC01D32464041D653ABAF9643400327DBC01D32464041D653ABAF9643400A4966F50E31464011C64FE3DE9443400A4966F50E314640
23576	50777	38.944806	38.962601999999997	44.293564000000003	44.280605999999999	Мира	0103000020E6100000010000000500000044882B67EF784340DB87BCE5EA23464044882B67EF78434038A45181932546403788D68A367B434038A45181932546403788D68A367B4340DB87BCE5EA23464044882B67EF784340DB87BCE5EA234640
21844	50436	38.692594999999997	38.716562000000003	44.345402	44.301841000000003	Новороссийское шоссе	0103000020E61000000100000005000000C22FF5F3A6584340C5CBD3B9A2264640C22FF5F3A65843408BFCFA21362C464037C7B94DB85B43408BFCFA21362C464037C7B94DB85B4340C5CBD3B9A2264640C22FF5F3A6584340C5CBD3B9A2264640
23184	50436	38.692594999999997	38.716562000000003	44.345402	44.301841000000003	Колхозная	0103000020E61000000100000005000000C22FF5F3A6584340C5CBD3B9A2264640C22FF5F3A65843408BFCFA21362C464037C7B94DB85B43408BFCFA21362C464037C7B94DB85B4340C5CBD3B9A2264640C22FF5F3A6584340C5CBD3B9A2264640
20951	50302	38.827207999999999	38.838597999999998	44.276276000000003	44.268343000000002	Дорога Орлят	0103000020E61000000100000005000000AA7EA5F3E1694340268E3C1059224640AA7EA5F3E1694340B95510035D234640D93EE42D576B4340B95510035D234640D93EE42D576B4340268E3C1059224640AA7EA5F3E1694340268E3C1059224640
23294	50664	39.288268000000002	39.297924999999999	44.28069	44.273049	Центральная	0103000020E61000000100000005000000DE3D40F7E5A443404E9A0645F3224640DE3D40F7E5A44340392861A6ED23464095D4096822A64340392861A6ED23464095D4096822A643404E9A0645F3224640DE3D40F7E5A443404E9A0645F3224640
22510	29917	38.884205999999999	38.896459	44.215144000000002	44.201911000000003	переулок Ореховый	0103000020E61000000100000005000000A77686A92D714340F1D93A38D8194640A77686A92D7143401FF7ADD6891B4640399A232BBF7243401FF7ADD6891B4640399A232BBF724340F1D93A38D8194640A77686A92D714340F1D93A38D8194640
21235	46103	38.826264999999999	38.886353	44.270466999999996	44.243338000000001	Юности	0103000020E610000001000000050000002B6A300DC3694340E1EF17B3251F46402B6A300DC3694340D8D2A3A99E22464012DBDD0374714340D8D2A3A99E22464012DBDD0374714340E1EF17B3251F46402B6A300DC3694340E1EF17B3251F4640
20819	46103	38.826264999999999	38.886353	44.270466999999996	44.243338000000001	1 Микрорайон	0103000020E610000001000000050000002B6A300DC3694340E1EF17B3251F46402B6A300DC3694340D8D2A3A99E22464012DBDD0374714340D8D2A3A99E22464012DBDD0374714340E1EF17B3251F46402B6A300DC3694340E1EF17B3251F4640
20828	30018	38.994177999999998	39.009557000000001	44.179456999999999	44.161987000000003	переулок Фонтанный	0103000020E610000001000000050000008B338639417F434047B071FDBB1446408B338639417F4340E6046D72F81646405439ED2939814340E6046D72F81646405439ED293981434047B071FDBB1446408B338639417F434047B071FDBB144640
21264	31218	39.328989	39.367570999999998	44.379558000000003	44.365943000000001	Центральная	0103000020E6100000010000000500000033DFC14F1CAA43409E996038D72E464033DFC14F1CAA4340B477465B95304640A0FA07910CAF4340B477465B95304640A0FA07910CAF43409E996038D72E464033DFC14F1CAA43409E996038D72E4640
21038	32963	38.866491000000003	38.889972999999998	44.474232000000001	44.462518000000003	Центральная	0103000020E61000000100000005000000A1A3552DE96E4340DAE731CA333B4640A1A3552DE96E4340BC5B59A2B33C464058A9A0A2EA714340BC5B59A2B33C464058A9A0A2EA714340DAE731CA333B4640A1A3552DE96E4340DAE731CA333B4640
21895	31712	39.111902000000001	39.127775	44.143495999999999	44.137194999999998	Шаумяна	0103000020E61000000100000005000000B22D03CE528E43405D16139B8F114640B22D03CE528E4340AC8DB1135E1246408A1F63EE5A904340AC8DB1135E1246408A1F63EE5A9043405D16139B8F114640B22D03CE528E43405D16139B8F114640
21702	31011	39.293883000000001	39.311731999999999	44.122281000000001	44.108942999999996	Тхагушева	0103000020E61000000100000005000000D9EC48F59DA5434066101FD8F10D4640D9EC48F59DA543400AF65FE7A60F4640EF8E8CD5E6A743400AF65FE7A60F4640EF8E8CD5E6A7434066101FD8F10D4640D9EC48F59DA5434066101FD8F10D4640
21228	50346	38.740501999999999	38.769230999999998	44.312910000000002	44.298189999999998	Ленина	0103000020E61000000100000005000000B14F00C5C85E434043FF04172B264640B14F00C5C85E4340B24B546F0D284640E108522976624340B24B546F0D284640E10852297662434043FF04172B264640B14F00C5C85E434043FF04172B264640
21056	30782	39.226993999999998	39.242849	44.204160000000002	44.176333999999997	Спорная	0103000020E61000000100000005000000B131AF230E9D43402096CD1C92164640B131AF230E9D4340609335EA211A4640E36E10AD159F4340609335EA211A4640E36E10AD159F43402096CD1C92164640B131AF230E9D43402096CD1C92164640
21372	32982	39.190361000000003	39.215845999999999	44.172811000000003	44.161921999999997	Майкопская	0103000020E6100000010000000500000089B7CEBF5D9843405F402FDCB914464089B7CEBF5D984340CDB1BCAB1E164640787C7BD7A09B4340CDB1BCAB1E164640787C7BD7A09B43405F402FDCB914464089B7CEBF5D9843405F402FDCB9144640
22455	23288	39.23366	39.259010000000004	44.259892999999998	44.206389000000001	Майкопская	0103000020E6100000010000000500000012312592E89D434088A06AF46A1A464012312592E89D4340CBBA7F2C4421464022AB5B3D27A14340CBBA7F2C4421464022AB5B3D27A1434088A06AF46A1A464012312592E89D434088A06AF46A1A4640
23117	29361	38.692594999999997	38.716562000000003	44.345402	44.301841000000003	Черноморская	0103000020E61000000100000005000000C22FF5F3A6584340C5CBD3B9A2264640C22FF5F3A65843408BFCFA21362C464037C7B94DB85B43408BFCFA21362C464037C7B94DB85B4340C5CBD3B9A2264640C22FF5F3A6584340C5CBD3B9A2264640
20947	29361	38.692594999999997	38.716562000000003	44.345402	44.301841000000003	Советская	0103000020E61000000100000005000000C22FF5F3A6584340C5CBD3B9A2264640C22FF5F3A65843408BFCFA21362C464037C7B94DB85B43408BFCFA21362C464037C7B94DB85B4340C5CBD3B9A2264640C22FF5F3A6584340C5CBD3B9A2264640
21010	18863	38.766247999999997	38.799737	44.438541999999998	44.422049999999999	Школьная	0103000020E610000001000000050000000D501A6A146243406EA301BC053646400D501A6A1462434012F6ED2422384640593332C85D66434012F6ED2422384640593332C85D6643406EA301BC053646400D501A6A146243406EA301BC05364640
21455	30442	39.124594999999999	39.135474000000002	44.057800999999998	44.051147	Клубная	0103000020E61000000100000005000000601F9DBAF28F4340EE2422FC8B064640601F9DBAF28F43408A56EE0566074640AABA4736579143408A56EE0566074640AABA473657914340EE2422FC8B064640601F9DBAF28F4340EE2422FC8B064640
23541	50755	39.428944000000001	39.449767000000001	44.280948000000002	44.269717999999997	Школьная	0103000020E6100000010000000500000060E811A3E7B643403E92921E8622464060E811A3E7B6434035F0A31AF6234640F7E80DF791B9434035F0A31AF6234640F7E80DF791B943403E92921E8622464060E811A3E7B643403E92921E86224640
20802	47394	38.725087000000002	38.737411999999999	44.391263000000002	44.383881000000002	Центральная	0103000020E610000001000000050000009CE09BA6CF5C434024473A03233146409CE09BA6CF5C43404391EEE714324640C7D63384635E43404391EEE714324640C7D63384635E434024473A03233146409CE09BA6CF5C434024473A0323314640
21693	31096	39.266241000000001	39.290208	44.296906	44.269227999999998	Глебова	0103000020E610000001000000050000005BED612F14A2434070952710762246405BED612F14A243403BFE0B0401264640CF84268925A543403BFE0B0401264640CF84268925A5434070952710762246405BED612F14A243407095271076224640
22075	46669	39.241734999999998	39.265082999999997	44.170166000000002	44.155306000000003	Советская	0103000020E6100000010000000500000037A6272CF19E4340B16F2711E113464037A6272CF19E43401172DEFFC7154640DFDC5F3DEEA143401172DEFFC7154640DFDC5F3DEEA14340B16F2711E113464037A6272CF19E4340B16F2711E1134640
23136	50634	39.333139000000003	39.351995000000002	44.079931999999999	44.072141999999999	Центральная	0103000020E61000000100000005000000D6027B4CA4AA43408255F5F23B094640D6027B4CA4AA4340B2F336363B0A464082AD122C0EAD4340B2F336363B0A464082AD122C0EAD43408255F5F23B094640D6027B4CA4AA43408255F5F23B094640
21060	3297	38.660615	38.671691000000003	44.361657999999998	44.352466999999997	Черноморская	0103000020E610000001000000050000009F1F46088F544340A9F57EA31D2D46409F1F46088F5443401B2B31CF4A2E46403F027FF8F95543401B2B31CF4A2E46403F027FF8F9554340A9F57EA31D2D46409F1F46088F544340A9F57EA31D2D4640
20594	46678	39.275368	39.288142000000001	44.174788999999997	44.163823000000001	Центральная	0103000020E61000000100000005000000B62E35423FA3434093AAED26F8144640B62E35423FA34340AB59677C5F164640514D49D6E1A44340AB59677C5F164640514D49D6E1A4434093AAED26F8144640B62E35423FA3434093AAED26F8144640
23148	50635	39.061947000000004	39.075718000000002	44.193845000000003	44.170166000000002	Шапсугская	0103000020E61000000100000005000000EC8A19E1ED8743401172DEFFC7154640EC8A19E1ED8743401FBFB7E9CF184640F9DB9E20B18943401FBFB7E9CF184640F9DB9E20B18943401172DEFFC7154640EC8A19E1ED8743401172DEFFC7154640
22529	30148	39.024540999999999	39.046415000000003	44.153261999999998	44.141387000000002	Горная	0103000020E61000000100000005000000A034D428248343402F8A1EF818124640A034D428248343401ADCD6169E1346409D853DEDF08543401ADCD6169E1346409D853DEDF08543402F8A1EF818124640A034D428248343402F8A1EF818124640
23545	50759	39.080038999999999	39.246065000000002	44.256878	44.087327000000002	Московских Строителей	0103000020E61000000100000005000000C8B3CBB73E8A43406687F8872D0B4640C8B3CBB73E8A4340EC87D860E12046405AD8D30E7F9F4340EC87D860E12046405AD8D30E7F9F43406687F8872D0B4640C8B3CBB73E8A43406687F8872D0B4640
20508	47442	40.107773999999999	40.114485000000002	45.984881999999999	45.983235000000001	Цветочная	0103000020E61000000100000005000000F7ADD689CB0D44402BA4FCA4DAFD4640F7ADD689CB0D4440A435069D10FE4640F870C971A70E4440A435069D10FE4640F870C971A70E44402BA4FCA4DAFD4640F7ADD689CB0D44402BA4FCA4DAFD4640
22420	27723	40.213569	40.281688000000003	45.766492999999997	45.748389000000003	Северная	0103000020E610000001000000050000003F389F3A561B4440D4D7F335CBDF46403F389F3A561B444074CE4F711CE246407CD6355A0E24444074CE4F711CE246407CD6355A0E244440D4D7F335CBDF46403F389F3A561B4440D4D7F335CBDF4640
23402	50691	40.13926	40.150776999999998	45.787154000000001	45.780492000000002	Магистральная	0103000020E610000001000000050000000BD28C45D311444013656F29E7E346400BD28C45D311444032755776C1E4464097FE25A94C13444032755776C1E4464097FE25A94C13444013656F29E7E346400BD28C45D311444013656F29E7E34640
23090	27542	40.396132999999999	40.444336999999997	45.652189	45.640721999999997	Школьная	0103000020E61000000100000005000000E5EE737CB4324440F2E9B12D03D24640E5EE737CB4324440CDE7DCED7AD346408DB3E908E0384440CDE7DCED7AD346408DB3E908E0384440F2E9B12D03D24640E5EE737CB4324440F2E9B12D03D24640
21414	50367	40.117862000000002	40.201442	45.931958999999999	45.895327999999999	Ленина	0103000020E6100000010000000500000078B81D1A160F4440B7989F1B9AF2464078B81D1A160F44403F1BB96E4AF746403A05F9D9C81944403F1BB96E4AF746403A05F9D9C8194440B7989F1B9AF2464078B81D1A160F4440B7989F1B9AF24640
21919	27259	40.117862000000002	40.201442	45.931958999999999	45.895327999999999	Ленина	0103000020E6100000010000000500000078B81D1A160F4440B7989F1B9AF2464078B81D1A160F44403F1BB96E4AF746403A05F9D9C81944403F1BB96E4AF746403A05F9D9C8194440B7989F1B9AF2464078B81D1A160F4440B7989F1B9AF24640
20757	27259	40.117862000000002	40.201442	45.931958999999999	45.895327999999999	Азина	0103000020E6100000010000000500000078B81D1A160F4440B7989F1B9AF2464078B81D1A160F44403F1BB96E4AF746403A05F9D9C81944403F1BB96E4AF746403A05F9D9C8194440B7989F1B9AF2464078B81D1A160F4440B7989F1B9AF24640
23359	50452	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Юго-Восточный бульвар	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
22016	50452	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Парковая	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
22292	50452	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Октябрьская	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21145	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Юго-Восточный бульвар	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21203	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Энгельса	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21653	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Чапаева	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21628	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Федосеева	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21539	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Ударников	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
20804	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Подвойского	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21965	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Передовая	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21347	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Октябрьская	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
20786	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Новорождественское шоссе	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21633	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Набережная	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21026	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Меньшикова	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
20699	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Ляпидевского	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21499	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Ленинградская	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21016	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Ленина	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
20939	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Кирова	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
20644	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Калинина/Майская	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21033	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Калинина	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
21648	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Гражданская	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
20543	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Гвардейская	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
20765	14835	40.066586000000001	40.156229000000003	45.876902999999999	45.832003	Ачкасова	0103000020E610000001000000050000008C2FDAE385084440429605137FEA46408C2FDAE385084440D461855B3EF04640E9D7D64FFF134440D461855B3EF04640E9D7D64FFF134440429605137FEA46408C2FDAE385084440429605137FEA4640
23203	50278	40.378588999999998	40.443294999999999	45.872115000000001	45.834162999999997	Суворова	0103000020E610000001000000050000000BD0B69A7530444041446ADAC5EA46400BD0B69A75304440EFACDD76A1EF46407BBDFBE3BD384440EFACDD76A1EF46407BBDFBE3BD38444041446ADAC5EA46400BD0B69A7530444041446ADAC5EA4640
23945	50278	40.378588999999998	40.443294999999999	45.872115000000001	45.834162999999997	Пионерская	0103000020E610000001000000050000000BD0B69A7530444041446ADAC5EA46400BD0B69A75304440EFACDD76A1EF46407BBDFBE3BD384440EFACDD76A1EF46407BBDFBE3BD38444041446ADAC5EA46400BD0B69A7530444041446ADAC5EA4640
20694	50278	40.378588999999998	40.443294999999999	45.872115000000001	45.834162999999997	Малиновского	0103000020E610000001000000050000000BD0B69A7530444041446ADAC5EA46400BD0B69A75304440EFACDD76A1EF46407BBDFBE3BD384440EFACDD76A1EF46407BBDFBE3BD38444041446ADAC5EA46400BD0B69A7530444041446ADAC5EA4640
20788	26957	40.227528999999997	40.234220999999998	45.837183000000003	45.833917999999997	Титова	0103000020E610000001000000050000001FF296AB1F1D4440DAC534D3BDEA46401FF296AB1F1D444033E202D028EB4640A98427F4FA1D444033E202D028EB4640A98427F4FA1D4440DAC534D3BDEA46401FF296AB1F1D4440DAC534D3BDEA4640
20909	26957	40.227528999999997	40.234220999999998	45.837183000000003	45.833917999999997	Советская	0103000020E610000001000000050000001FF296AB1F1D4440DAC534D3BDEA46401FF296AB1F1D444033E202D028EB4640A98427F4FA1D444033E202D028EB4640A98427F4FA1D4440DAC534D3BDEA46401FF296AB1F1D4440DAC534D3BDEA4640
22995	50616	40.383718999999999	40.401702999999998	45.712674	45.704718999999997	Первомайская	0103000020E610000001000000050000004AED45B41D31444056EF703B34DA46404AED45B41D314440D15AD1E638DB464040DAFF006B334440D15AD1E638DB464040DAFF006B33444056EF703B34DA46404AED45B41D31444056EF703B34DA4640
21712	26987	40.257407000000001	40.269677999999999	45.806362999999997	45.800162	Пионерская	0103000020E6100000010000000500000078616BB6F220444040C05AB56BE6464078616BB6F22044402BDA1CE736E74640B03907CF842244402BDA1CE736E74640B03907CF8422444040C05AB56BE6464078616BB6F220444040C05AB56BE64640
21013	13198	40.146977	40.160981	45.841377000000001	45.833139000000003	Дружбы	0103000020E61000000100000005000000D1217024D0124440D6027B4CA4EA4640D1217024D0124440A54DD53DB2EB4640812381069B144440A54DD53DB2EB4640812381069B144440D6027B4CA4EA4640D1217024D0124440D6027B4CA4EA4640
21199	13198	40.146977	40.160981	45.841377000000001	45.833139000000003	Гагарина 	0103000020E61000000100000005000000D1217024D0124440D6027B4CA4EA4640D1217024D0124440A54DD53DB2EB4640812381069B144440A54DD53DB2EB4640812381069B144440D6027B4CA4EA4640D1217024D0124440D6027B4CA4EA4640
20540	13198	40.146977	40.160981	45.841377000000001	45.833139000000003	Гагарина	0103000020E61000000100000005000000D1217024D0124440D6027B4CA4EA4640D1217024D0124440A54DD53DB2EB4640812381069B144440A54DD53DB2EB4640812381069B144440D6027B4CA4EA4640D1217024D0124440D6027B4CA4EA4640
23741	50818	39.815911999999997	40.565761999999999	46.090192999999999	45.566361000000001	Ленина	0103000020E61000000100000005000000FC34EECD6FE843406C5D6A847EC84640FC34EECD6FE8434000AAB8718B0B4740E7A8A3E36A48444000AAB8718B0B4740E7A8A3E36A4844406C5D6A847EC84640FC34EECD6FE843406C5D6A847EC84640
23958	50343	40.074230999999997	40.180349	45.616148000000003	45.604256999999997	Северная	0103000020E61000000100000005000000B8ACC2668009444085B01A4B58CD4640B8ACC2668009444077BF0AF0DDCE4640E36E10AD1517444077BF0AF0DDCE4640E36E10AD1517444085B01A4B58CD4640B8ACC2668009444085B01A4B58CD4640
24022	50343	40.074230999999997	40.180349	45.616148000000003	45.604256999999997	Первомайская	0103000020E61000000100000005000000B8ACC2668009444085B01A4B58CD4640B8ACC2668009444077BF0AF0DDCE4640E36E10AD1517444077BF0AF0DDCE4640E36E10AD1517444085B01A4B58CD4640B8ACC2668009444085B01A4B58CD4640
23626	50343	40.074230999999997	40.180349	45.616148000000003	45.604256999999997	Красная	0103000020E61000000100000005000000B8ACC2668009444085B01A4B58CD4640B8ACC2668009444077BF0AF0DDCE4640E36E10AD1517444077BF0AF0DDCE4640E36E10AD1517444085B01A4B58CD4640B8ACC2668009444085B01A4B58CD4640
21902	27043	40.331418999999997	40.362141000000001	45.940088000000003	45.932366000000002	Набережная	0103000020E61000000100000005000000F22213F06B2A444080F3E2C457F74640F22213F06B2A444058AEB7CD54F8464037C5E3A25A2E444058AEB7CD54F8464037C5E3A25A2E444080F3E2C457F74640F22213F06B2A444080F3E2C457F74640
20978	9005	39.908456000000001	39.995933999999998	45.897284999999997	45.833188999999997	Красная	0103000020E6100000010000000500000070ED444948F443408731E9EFA5EA464070ED444948F443407E18213CDAF24640BB7CEBC37AFF43407E18213CDAF24640BB7CEBC37AFF43408731E9EFA5EA464070ED444948F443408731E9EFA5EA4640
20514	9005	39.908456000000001	39.995933999999998	45.897284999999997	45.833188999999997	Кирпичная	0103000020E6100000010000000500000070ED444948F443408731E9EFA5EA464070ED444948F443407E18213CDAF24640BB7CEBC37AFF43407E18213CDAF24640BB7CEBC37AFF43408731E9EFA5EA464070ED444948F443408731E9EFA5EA4640
21604	9005	39.908456000000001	39.995933999999998	45.897284999999997	45.833188999999997	Горького	0103000020E6100000010000000500000070ED444948F443408731E9EFA5EA464070ED444948F443407E18213CDAF24640BB7CEBC37AFF43407E18213CDAF24640BB7CEBC37AFF43408731E9EFA5EA464070ED444948F443408731E9EFA5EA4640
21827	26333	40.098010000000002	40.114753999999998	46.003484	45.994574999999998	Мира	0103000020E610000001000000050000002A5778978B0C4440A835CD3B4EFF46402A5778978B0C44409607E92972004740E78A5242B00E44409607E92972004740E78A5242B00E4440A835CD3B4EFF46402A5778978B0C4440A835CD3B4EFF4640
21242	26060	40.263146999999996	40.290284999999997	45.715833000000003	45.700488999999997	Мичурина	0103000020E610000001000000050000002F8507CDAE214440971AA19FA9D946402F8507CDAE214440E4326E6AA0DB46407AC2120F28254440E4326E6AA0DB46407AC2120F28254440971AA19FA9D946402F8507CDAE214440971AA19FA9D94640
21592	27309	40.141424999999998	40.187581000000002	45.980153000000001	45.968378000000001	Северная	0103000020E610000001000000050000001CEBE2361A1244403C1570CFF3FB46401CEBE2361A124440C4094CA775FD4640ED2C7AA702184440C4094CA775FD4640ED2C7AA7021844403C1570CFF3FB46401CEBE2361A1244403C1570CFF3FB4640
23637	50797	40.4315	40.444867000000002	45.601683999999999	45.591374000000002	Советская	0103000020E61000000100000005000000AC1C5A643B37444034DAAA24B2CB4640AC1C5A643B374440634337FB03CD4640EA08E066F1384440634337FB03CD4640EA08E066F138444034DAAA24B2CB4640AC1C5A643B37444034DAAA24B2CB4640
21618	26806	40.225848999999997	40.238334999999999	45.876550999999999	45.868738999999998	Новая	0103000020E61000000100000005000000CA6ABA9EE81C44403FE1ECD632EF4640CA6ABA9EE81C44405723BBD232F04640FF3EE3C2811E44405723BBD232F04640FF3EE3C2811E44403FE1ECD632EF4640CA6ABA9EE81C44403FE1ECD632EF4640
23639	50796	40.339243000000003	40.366695999999997	45.623497999999998	45.611078999999997	Красная	0103000020E61000000100000005000000CF328B506C2B4440DD2230D637CE4640CF328B506C2B44408A8F4FC8CECF464079C9FFE4EF2E44408A8F4FC8CECF464079C9FFE4EF2E4440DD2230D637CE4640CF328B506C2B4440DD2230D637CE4640
21388	25983	40.044308000000001	40.129424	45.822526000000003	45.786639000000001	Мира	0103000020E61000000100000005000000C07971E2AB0544400B613596B0E44640C07971E2AB0544400B0E2F8848E94640A4A833F7901044400B0E2F8848E94640A4A833F7901044400B613596B0E44640C07971E2AB0544400B613596B0E44640
22301	45758	40.026054000000002	40.049950000000003	45.871305	45.860830999999997	Ленина	0103000020E610000001000000050000000AF7CABC550344400531D0B52FEE46400AF7CABC55034440AFEB17EC86EF4640B537F8C264064440AFEB17EC86EF4640B537F8C2640644400531D0B52FEE46400AF7CABC550344400531D0B52FEE4640
20714	27701	40.363129000000001	40.406922000000002	45.717582999999998	45.714838999999998	Октябрьская	0103000020E61000000100000005000000569DD5027B2E4440E27327D87FDB4640569DD5027B2E444031957EC2D9DB4640EF0225051634444031957EC2D9DB4640EF02250516344440E27327D87FDB4640569DD5027B2E4440E27327D87FDB4640
21207	26873	40.296509999999998	40.309123	45.839179999999999	45.828423000000001	переулок Степной	0103000020E61000000100000005000000EE77280AF42544408A20CEC309EA4640EE77280AF425444088BA0F406AEB464080B8AB579127444088BA0F406AEB464080B8AB57912744408A20CEC309EA4640EE77280AF42544408A20CEC309EA4640
23324	50667	39.815911999999997	40.565761999999999	46.090192999999999	45.566361000000001	улица Центральная	0103000020E61000000100000005000000FC34EECD6FE843406C5D6A847EC84640FC34EECD6FE8434000AAB8718B0B4740E7A8A3E36A48444000AAB8718B0B4740E7A8A3E36A4844406C5D6A847EC84640FC34EECD6FE843406C5D6A847EC84640
21843	26412	40.447947999999997	40.550545	45.715966000000002	45.705694999999999	Школьная	0103000020E6100000010000000500000080272D5C56394440B1F9B83654DA464080272D5C5639444023861DC6A4DB4640F8FC30427846444023861DC6A4DB4640F8FC304278464440B1F9B83654DA464080272D5C56394440B1F9B83654DA4640
21395	40468	40.143014999999998	40.164969999999997	45.833019999999998	45.827688000000002	Свободная	0103000020E6100000010000000500000031EBC5504E12444055A52DAEF1E9464031EBC5504E124440FB743C66A0EA46401A69A9BC1D154440FB743C66A0EA46401A69A9BC1D15444055A52DAEF1E9464031EBC5504E12444055A52DAEF1E94640
20744	26303	40.097273000000001	40.124115000000003	46.038666999999997	46.029876000000002	Школьная	0103000020E6100000010000000500000054E41071730C4440B8770DFAD203474054E41071730C44409B374E0AF3044740B6F81400E30F44409B374E0AF3044740B6F81400E30F4440B8770DFAD203474054E41071730C4440B8770DFAD2034740
20922	26082	40.237796000000003	40.299914999999999	45.699992000000002	45.657896999999998	Садовая	0103000020E61000000100000005000000508F6D19701E4440799109F835D44640508F6D19701E444017BB7D5699D94640384A5E9D6326444017BB7D5699D94640384A5E9D63264440799109F835D44640508F6D19701E4440799109F835D44640
20941	26082	40.237796000000003	40.299914999999999	45.699992000000002	45.657896999999998	Первомайская	0103000020E61000000100000005000000508F6D19701E4440799109F835D44640508F6D19701E444017BB7D5699D94640384A5E9D6326444017BB7D5699D94640384A5E9D63264440799109F835D44640508F6D19701E4440799109F835D44640
20677	26082	40.237796000000003	40.299914999999999	45.699992000000002	45.657896999999998	Ленина	0103000020E61000000100000005000000508F6D19701E4440799109F835D44640508F6D19701E444017BB7D5699D94640384A5E9D6326444017BB7D5699D94640384A5E9D63264440799109F835D44640508F6D19701E4440799109F835D44640
21891	26082	40.237796000000003	40.299914999999999	45.699992000000002	45.657896999999998	Буденного	0103000020E61000000100000005000000508F6D19701E4440799109F835D44640508F6D19701E444017BB7D5699D94640384A5E9D6326444017BB7D5699D94640384A5E9D63264440799109F835D44640508F6D19701E4440799109F835D44640
21168	25804	40.138793	40.172272999999997	45.780749999999998	45.758394000000003	Ленина	0103000020E61000000100000005000000F5F411F8C3114440C7BDF90D13E14640F5F411F8C31144400E2DB29DEFE34640ED7DAA0A0D1644400E2DB29DEFE34640ED7DAA0A0D164440C7BDF90D13E14640F5F411F8C3114440C7BDF90D13E14640
22141	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	мкр.Сахарного завода	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21489	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	мкр.Индустриальный,	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21276	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	мкр.Индустриальный	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20624	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	мкр. Сахарного завода	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
22007	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Шереметова	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
22163	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Степанова	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21186	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Советская	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20933	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Профильная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21662	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Набережная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20620	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Ленина	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21078	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Красная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20422	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Котляра	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20591	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Коммунальная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21519	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Комарова	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
21073	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Западная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20974	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Гибридная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20497	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Выборная	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20902	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	Братьев Степановых	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
22217	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	70 лет Октября	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20896	23047	38.906125000000003	39.018253000000001	45.638057000000003	45.557628000000001	50 лет Октября	0103000020E61000000100000005000000448B6CE7FB734340BDAAB35A60C74640448B6CE7FB734340F0FD0DDAABD14640E606431D56824340F0FD0DDAABD14640E606431D56824340BDAAB35A60C74640448B6CE7FB734340BDAAB35A60C74640
20630	24723	38.909286999999999	38.936075000000002	45.550136999999999	45.517578	Школьная	0103000020E61000000100000005000000C7D63384637443408690F3FE3FC24640C7D6338463744340E7A8A3E36AC6464036CD3B4ED1774340E7A8A3E36AC6464036CD3B4ED17743408690F3FE3FC24640C7D63384637443408690F3FE3FC24640
20489	25386	39.177424999999999	39.256010000000003	45.724843999999997	45.713014000000001	Красная	0103000020E61000000100000005000000143FC6DCB59643408ACBF10A44DB4640143FC6DCB5964340D5592DB0C7DC464078B988EFC4A04340D5592DB0C7DC464078B988EFC4A043408ACBF10A44DB4640143FC6DCB59643408ACBF10A44DB4640
22645	50534	38.775644	38.792928000000003	45.548079000000001	45.529279000000002	 Ленина	0103000020E6100000010000000500000058AB764D48634340D4BA0D6ABFC3464058AB764D48634340EC4FE27327C64640960A2AAA7E654340EC4FE27327C64640960A2AAA7E654340D4BA0D6ABFC3464058AB764D48634340D4BA0D6ABFC34640
20878	50295	38.916742999999997	38.950536999999997	45.525579	45.507947000000001	Комсомольская	0103000020E6100000010000000500000020EBA9D557754340F88C446804C1464020EBA9D557754340713B342C46C34640A8514832AB794340713B342C46C34640A8514832AB794340F88C446804C1464020EBA9D557754340F88C446804C14640
23548	48647	38.706726000000003	38.764541000000001	45.753602999999998	45.705002	Свободная	0103000020E61000000100000005000000D09D60FF755A4340ABCE6A813DDA4640D09D60FF755A43407095271076E04640BFB9BF7ADC6143407095271076E04640BFB9BF7ADC614340ABCE6A813DDA4640D09D60FF755A4340ABCE6A813DDA4640
20683	48647	38.706726000000003	38.764541000000001	45.753602999999998	45.705002	Ленина	0103000020E61000000100000005000000D09D60FF755A4340ABCE6A813DDA4640D09D60FF755A43407095271076E04640BFB9BF7ADC6143407095271076E04640BFB9BF7ADC614340ABCE6A813DDA4640D09D60FF755A4340ABCE6A813DDA4640
22017	48647	38.706726000000003	38.764541000000001	45.753602999999998	45.705002	Коммунаров	0103000020E61000000100000005000000D09D60FF755A4340ABCE6A813DDA4640D09D60FF755A43407095271076E04640BFB9BF7ADC6143407095271076E04640BFB9BF7ADC614340ABCE6A813DDA4640D09D60FF755A4340ABCE6A813DDA4640
22281	48647	38.706726000000003	38.764541000000001	45.753602999999998	45.705002	Гоголя	0103000020E61000000100000005000000D09D60FF755A4340ABCE6A813DDA4640D09D60FF755A43407095271076E04640BFB9BF7ADC6143407095271076E04640BFB9BF7ADC614340ABCE6A813DDA4640D09D60FF755A4340ABCE6A813DDA4640
20681	50274	38.560048999999999	39.396946	45.773119000000001	45.363337999999999	Степанова	0103000020E61000000100000005000000299485AFAF47434070B20DDC81AE4640299485AFAF47434047753A90F5E2464096236420CFB2434047753A90F5E2464096236420CFB2434070B20DDC81AE4640299485AFAF47434070B20DDC81AE4640
20721	25236	39.114201999999999	39.173904	45.655634999999997	45.625445999999997	Пионерская	0103000020E61000000100000005000000A391CF2B9E8E4340FEB4519D0ED04640A391CF2B9E8E4340758E01D9EBD3464061527C7C42964340758E01D9EBD3464061527C7C42964340FEB4519D0ED04640A391CF2B9E8E4340FEB4519D0ED04640
21093	25236	39.114201999999999	39.173904	45.655634999999997	45.625445999999997	Красная	0103000020E61000000100000005000000A391CF2B9E8E4340FEB4519D0ED04640A391CF2B9E8E4340758E01D9EBD3464061527C7C42964340758E01D9EBD3464061527C7C42964340FEB4519D0ED04640A391CF2B9E8E4340FEB4519D0ED04640
20906	25324	39.257815000000001	39.379663000000001	45.725121000000001	45.700754000000003	Школьная	0103000020E6100000010000000500000089B5F81400A1434046459C4EB2D9464089B5F81400A143404852D2C3D0DC4640294014CC98B043404852D2C3D0DC4640294014CC98B0434046459C4EB2D9464089B5F81400A1434046459C4EB2D94640
21926	14961	38.992381000000002	39.060769999999998	45.476298999999997	45.418264999999998	Школьная	0103000020E61000000100000005000000FD153257067F4340DD0720B589B54640FD153257067F43400A0F9A5DF7BC4640F949B54FC78743400A0F9A5DF7BC4640F949B54FC7874340DD0720B589B54640FD153257067F4340DD0720B589B54640
20435	14961	38.992381000000002	39.060769999999998	45.476298999999997	45.418264999999998	Пушкина	0103000020E61000000100000005000000FD153257067F4340DD0720B589B54640FD153257067F43400A0F9A5DF7BC4640F949B54FC78743400A0F9A5DF7BC4640F949B54FC7874340DD0720B589B54640FD153257067F4340DD0720B589B54640
20912	14961	38.992381000000002	39.060769999999998	45.476298999999997	45.418264999999998	Мира	0103000020E61000000100000005000000FD153257067F4340DD0720B589B54640FD153257067F43400A0F9A5DF7BC4640F949B54FC78743400A0F9A5DF7BC4640F949B54FC7874340DD0720B589B54640FD153257067F4340DD0720B589B54640
20666	14961	38.992381000000002	39.060769999999998	45.476298999999997	45.418264999999998	Ленина	0103000020E61000000100000005000000FD153257067F4340DD0720B589B54640FD153257067F43400A0F9A5DF7BC4640F949B54FC78743400A0F9A5DF7BC4640F949B54FC7874340DD0720B589B54640FD153257067F4340DD0720B589B54640
22748	16997	38.834429999999998	38.851641999999998	45.662602	45.649298000000002	улица Народная	0103000020E6100000010000000500000090662C9ACE6A4340DAAD65321CD3464090662C9ACE6A4340D1217024D0D4464034F3E49A026D4340D1217024D0D4464034F3E49A026D4340DAAD65321CD3464090662C9ACE6A4340DAAD65321CD34640
20937	48609	38.866993999999998	38.880468999999998	45.672541000000002	45.666620999999999	 Победы	0103000020E6100000010000000500000003EACDA8F96E4340D5E940D653D5464003EACDA8F96E43400D1CD0D215D6464027124C35B37043400D1CD0D215D6464027124C35B3704340D5E940D653D5464003EACDA8F96E4340D5E940D653D54640
21707	24873	38.796700999999999	38.819445999999999	45.636651000000001	45.609130999999998	Ленина	0103000020E6100000010000000500000062D8614CFA65434069FD2D01F8CD464062D8614CFA6543409CFBABC77DD14640446B459BE36843409CFBABC77DD14640446B459BE368434069FD2D01F8CD464062D8614CFA65434069FD2D01F8CD4640
20675	24738	38.963580999999998	39.011057000000001	45.535138000000003	45.506709000000001	Юбилейный	0103000020E610000001000000050000000306499F567B434060CB2BD7DBC046400306499F567B4340666CE8667FC4464029B2D6506A814340666CE8667FC4464029B2D6506A81434060CB2BD7DBC046400306499F567B434060CB2BD7DBC04640
22095	50463	36.686289000000002	36.744247999999999	45.222411999999998	45.195653	Карла Маркса	0103000020E61000000100000005000000624D6551D8574240A12E52280B994640624D6551D8574240751E15FF779C4640840EBA84435F4240751E15FF779C4640840EBA84435F4240A12E52280B994640624D6551D8574240A12E52280B994640
21018	50313	36.976984000000002	36.993153	45.335169	45.325468000000001	Ленина	0103000020E610000001000000050000008E5BCCCF0D7D424080F277EFA8A946408E5BCCCF0D7D424007D15AD1E6AA46404F7633A31F7F424007D15AD1E6AA46404F7633A31F7F424080F277EFA8A946408E5BCCCF0D7D424080F277EFA8A94640
22084	22417	36.925024999999998	36.946494999999999	45.367674999999998	45.358669999999996	Ленина	0103000020E61000000100000005000000BF7D1D3867764240350708E6E8AD4640BF7D1D3867764240454772F90FAF4640EC6987BF26794240454772F90FAF4640EC6987BF26794240350708E6E8AD4640BF7D1D3867764240350708E6E8AD4640
21243	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	площадь Терлецкого	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21658	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	пер. имени Дуси Виноградовой	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21041	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Шопена	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
20811	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Таманская	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21441	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Свердлова	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21267	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Полетаева	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21232	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Октябрьская	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21042	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Морская	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21047	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Молодежная	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
20575	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Мира	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21246	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Ленина	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21045	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Карла Маркса	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21437	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Гагарина	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
20812	20427	37.341008000000002	37.517141000000002	45.299861	45.231610000000003	Бувина	0103000020E6100000010000000500000052D66F26A6AB42409AB67F65A59D464052D66F26A6AB4240452C62D861A64640DB3521AD31C24240452C62D861A64640DB3521AD31C242409AB67F65A59D464052D66F26A6AB42409AB67F65A59D4640
21703	50413	36.686289000000002	36.744247999999999	45.222411999999998	45.195653	Некрасова	0103000020E61000000100000005000000624D6551D8574240A12E52280B994640624D6551D8574240751E15FF779C4640840EBA84435F4240751E15FF779C4640840EBA84435F4240A12E52280B994640624D6551D8574240A12E52280B994640
22606	50531	36.686289000000002	36.744247999999999	45.222411999999998	45.195653	Карла Маркса	0103000020E61000000100000005000000624D6551D8574240A12E52280B994640624D6551D8574240751E15FF779C4640840EBA84435F4240751E15FF779C4640840EBA84435F4240A12E52280B994640624D6551D8574240A12E52280B994640
20634	22866	36.779229000000001	36.795963999999998	45.150412000000003	45.141086000000001	Ленина	0103000020E61000000100000005000000228C9FC6BD63424034F6251B0F924640228C9FC6BD63424086764EB3409346408C65FA25E265424086764EB3409346408C65FA25E265424034F6251B0F924640228C9FC6BD63424034F6251B0F924640
20843	47422	37.256117000000003	37.324990999999997	45.215161999999999	45.18927	Ленина	0103000020E610000001000000050000008E791D71C8A04240950ED6FF399846408E791D71C8A04240C5ABAC6D8A9B4640463F1A4E99A94240C5ABAC6D8A9B4640463F1A4E99A94240950ED6FF399846408E791D71C8A04240950ED6FF39984640
21697	22046	37.124423999999998	37.203611000000002	45.240260999999997	45.192649000000003	пер. Горького	0103000020E61000000100000005000000336B2920ED8F4240B64DF1B8A8984640336B2920ED8F42408BC058DFC09E46408D0DDDEC0F9A42408BC058DFC09E46408D0DDDEC0F9A4240B64DF1B8A8984640336B2920ED8F4240B64DF1B8A8984640
21255	22046	37.124423999999998	37.203611000000002	45.240260999999997	45.192649000000003	Садовая	0103000020E61000000100000005000000336B2920ED8F4240B64DF1B8A8984640336B2920ED8F42408BC058DFC09E46408D0DDDEC0F9A42408BC058DFC09E46408D0DDDEC0F9A4240B64DF1B8A8984640336B2920ED8F4240B64DF1B8A8984640
22568	22046	37.124423999999998	37.203611000000002	45.240260999999997	45.192649000000003	Переулок Ильича	0103000020E61000000100000005000000336B2920ED8F4240B64DF1B8A8984640336B2920ED8F42408BC058DFC09E46408D0DDDEC0F9A42408BC058DFC09E46408D0DDDEC0F9A4240B64DF1B8A8984640336B2920ED8F4240B64DF1B8A8984640
21286	22046	37.124423999999998	37.203611000000002	45.240260999999997	45.192649000000003	Ленина	0103000020E61000000100000005000000336B2920ED8F4240B64DF1B8A8984640336B2920ED8F42408BC058DFC09E46408D0DDDEC0F9A42408BC058DFC09E46408D0DDDEC0F9A4240B64DF1B8A8984640336B2920ED8F4240B64DF1B8A8984640
20589	47351	36.983434000000003	37.008488	45.318129999999996	45.278447999999997	Мира	0103000020E6100000010000000500000022E3512AE17D42407CD11E2FA4A3464022E3512AE17D424030F0DC7BB8A84640483481221681424030F0DC7BB8A8464048348122168142407CD11E2FA4A3464022E3512AE17D42407CD11E2FA4A34640
21456	47351	36.983434000000003	37.008488	45.318129999999996	45.278447999999997	Кулакова	0103000020E6100000010000000500000022E3512AE17D42407CD11E2FA4A3464022E3512AE17D424030F0DC7BB8A84640483481221681424030F0DC7BB8A8464048348122168142407CD11E2FA4A3464022E3512AE17D42407CD11E2FA4A34640
22542	47218	37.646202000000002	37.672548999999997	45.212406000000001	45.199711999999998	Широкая	0103000020E610000001000000050000000E4E44BFB6D24240334FAE29909946400E4E44BFB6D24240B2BCAB1E309B46408FFAEB1516D64240B2BCAB1E309B46408FFAEB1516D64240334FAE29909946400E4E44BFB6D24240334FAE2990994640
22220	47386	36.901587999999997	36.925735000000003	45.271534000000003	45.258270000000003	Ленина	0103000020E61000000100000005000000A73B4F3C67734240DBC4C9FD0EA14640A73B4F3C6773424044E048A0C1A246409CE1067C7E76424044E048A0C1A246409CE1067C7E764240DBC4C9FD0EA14640A73B4F3C67734240DBC4C9FD0EA14640
22153	47386	36.901587999999997	36.925735000000003	45.271534000000003	45.258270000000003	Красная	0103000020E61000000100000005000000A73B4F3C67734240DBC4C9FD0EA14640A73B4F3C6773424044E048A0C1A246409CE1067C7E76424044E048A0C1A246409CE1067C7E764240DBC4C9FD0EA14640A73B4F3C67734240DBC4C9FD0EA14640
21052	47306	37.120193	37.203000000000003	45.350676999999997	45.334820999999998	Бондаревой	0103000020E61000000100000005000000A41AF67B628F4240CB811E6ADBAA4640A41AF67B628F4240CD3AE3FBE2AC4640448B6CE7FB994240CD3AE3FBE2AC4640448B6CE7FB994240CB811E6ADBAA4640A41AF67B628F4240CB811E6ADBAA4640
20597	47616	36.942371999999999	36.979382000000001	45.414292000000003	45.395947	Ленина	0103000020E6100000010000000500000043554CA59F78424083F92B64AEB2464043554CA59F7842404A7F2F8507B546404225AE635C7D42404A7F2F8507B546404225AE635C7D424083F92B64AEB2464043554CA59F78424083F92B64AEB24640
20831	21335	37.535646	37.604897000000001	45.235652999999999	45.212628000000002	Чапаева	0103000020E61000000100000005000000DA1D520C90C44240611BF164379B4640DA1D520C90C44240261AA4E0299E46406939D0436DCD4240261AA4E0299E46406939D0436DCD4240611BF164379B4640DA1D520C90C44240611BF164379B4640
20829	21335	37.535646	37.604897000000001	45.235652999999999	45.212628000000002	Красная	0103000020E61000000100000005000000DA1D520C90C44240611BF164379B4640DA1D520C90C44240261AA4E0299E46406939D0436DCD4240261AA4E0299E46406939D0436DCD4240611BF164379B4640DA1D520C90C44240611BF164379B4640
22160	47233	37.640515000000001	37.676771000000002	45.203344000000001	45.183799999999998	Школьная	0103000020E6100000010000000500000079CC4065FCD142409D8026C28697464079CC4065FCD142403EEB1A2D079A4640CCF09F6EA0D642403EEB1A2D079A4640CCF09F6EA0D642409D8026C28697464079CC4065FCD142409D8026C286974640
20926	47327	36.860823000000003	36.876336000000002	45.399732	45.390219000000002	Постовая	0103000020E610000001000000050000008352B4722F6E424090A339B2F2B146408352B4722F6E424014950D6B2AB346405B272EC72B70424014950D6B2AB346405B272EC72B70424090A339B2F2B146408352B4722F6E424090A339B2F2B14640
21185	47327	36.860823000000003	36.876336000000002	45.399732	45.390219000000002	Первомайский	0103000020E610000001000000050000008352B4722F6E424090A339B2F2B146408352B4722F6E424014950D6B2AB346405B272EC72B70424014950D6B2AB346405B272EC72B70424090A339B2F2B146408352B4722F6E424090A339B2F2B14640
22231	50478	36.765880000000003	36.782246999999998	45.429253000000003	45.417859999999997	Ленина	0103000020E610000001000000050000008B54185B086242403D27BD6F7CB546408B54185B08624240DE5A26C3F1B64640723271AB20644240DE5A26C3F1B64640723271AB206442403D27BD6F7CB546408B54185B086242403D27BD6F7CB54640
21475	22486	36.858173000000001	36.878070000000001	45.386516999999998	45.369124999999997	Ленина	0103000020E61000000100000005000000B5A7E49CD86D42406891ED7C3FAF4640B5A7E49CD86D42408C2C996379B14640A3CC0699647042408C2C996379B14640A3CC0699647042406891ED7C3FAF4640B5A7E49CD86D42406891ED7C3FAF4640
21450	21558	37.253278999999999	37.299030000000002	45.330638999999998	45.315316000000003	Советская	0103000020E61000000100000005000000BDE13E726BA04240E9F351465CA84640BDE13E726BA042401DE4F56052AA4640EE42739D46A642401DE4F56052AA4640EE42739D46A64240E9F351465CA84640BDE13E726BA04240E9F351465CA84640
20958	21558	37.253278999999999	37.299030000000002	45.330638999999998	45.315316000000003	Красная	0103000020E61000000100000005000000BDE13E726BA04240E9F351465CA84640BDE13E726BA042401DE4F56052AA4640EE42739D46A642401DE4F56052AA4640EE42739D46A64240E9F351465CA84640BDE13E726BA04240E9F351465CA84640
21480	22583	36.835633999999999	36.866652999999999	45.323650000000001	45.315373000000001	Ленина	0103000020E610000001000000050000007CB60E0EF66A42404D8578245EA846407CB60E0EF66A4240DAACFA5C6DA946407AFD497CEE6E4240DAACFA5C6DA946407AFD497CEE6E42404D8578245EA846407CB60E0EF66A42404D8578245EA84640
21263	22222	36.978205000000003	37.028905999999999	45.203432999999997	45.185946999999999	Ленина	0103000020E6100000010000000500000050E449D2357D424008E57D1CCD97464050E449D2357D4240ADF6B0170A9A46403F541A31B3834240ADF6B0170A9A46403F541A31B383424008E57D1CCD97464050E449D2357D424008E57D1CCD974640
21229	47714	36.703743000000003	36.714325000000002	45.130411000000002	45.122207000000003	Приморская	0103000020E61000000100000005000000FCE42840145A4240D02B9E7AA48F4640FCE42840145A4240F304C24EB19046408CDB68006F5B4240F304C24EB19046408CDB68006F5B4240D02B9E7AA48F4640FCE42840145A4240D02B9E7AA48F4640
22226	4879	36.892415999999997	36.905926999999998	45.197692000000004	45.188862999999998	площадь Ленина	0103000020E61000000100000005000000AC36FFAF3A7242405436ACA92C984640AC36FFAF3A7242402657B1F84D9946401DC87A6AF57342402657B1F84D9946401DC87A6AF57342405436ACA92C984640AC36FFAF3A7242405436ACA92C984640
20474	4879	36.892415999999997	36.905926999999998	45.197692000000004	45.188862999999998	Молодежная	0103000020E61000000100000005000000AC36FFAF3A7242405436ACA92C984640AC36FFAF3A7242402657B1F84D9946401DC87A6AF57342402657B1F84D9946401DC87A6AF57342405436ACA92C984640AC36FFAF3A7242405436ACA92C984640
21277	47818	36.899163000000001	36.913805000000004	45.132745	45.124313000000001	Гвардейская	0103000020E61000000100000005000000FA62EFC517734240DCBB067DE98F4640FA62EFC51773424090DAC4C9FD904640EDF5EE8FF774424090DAC4C9FD904640EDF5EE8FF7744240DCBB067DE98F4640FA62EFC517734240DCBB067DE98F4640
23617	50688	37.257778999999999	37.282446999999998	45.174028	45.163333999999999	Садовый переулок	0103000020E610000001000000050000003C4CFBE6FEA042409529E620E89446403C4CFBE6FEA042404D4BAC8C4696464039ED293927A442404D4BAC8C4696464039ED293927A442409529E620E89446403C4CFBE6FEA042409529E620E8944640
21271	22620	36.821745999999997	36.832157000000002	45.396954000000001	45.387794999999997	Степная	0103000020E6100000010000000500000035CF11F92E694240B2463D44A3B1464035CF11F92E69424019028063CFB246409911DE1E846A424019028063CFB246409911DE1E846A4240B2463D44A3B1464035CF11F92E694240B2463D44A3B14640
21677	21676	37.079732999999997	37.127191000000003	45.336759000000001	45.299937	переулок Северный	0103000020E61000000100000005000000BBB4E1B0348A424020EEEA5564A64640BBB4E1B0348A42401CD13DEB1AAB46403BAC70CB479042401CD13DEB1AAB46403BAC70CB4790424020EEEA5564A64640BBB4E1B0348A424020EEEA5564A64640
21967	19326	40.186332	40.215186000000003	45.331119999999999	45.321899999999999	Колхозная	0103000020E6100000010000000500000061191BBAD91744408C4AEA0434A9464061191BBAD91744409886E12362AA46404E4700378B1B44409886E12362AA46404E4700378B1B44408C4AEA0434A9464061191BBAD91744408C4AEA0434A94640
23846	50843	40.240976000000003	40.267279000000002	45.331905999999996	45.318173999999999	Длинная	0103000020E610000001000000050000007A8F334DD81E44400038F6ECB9A846407A8F334DD81E44404FAC53E57BAA46402CF4C132362244404FAC53E57BAA46402CF4C132362244400038F6ECB9A846407A8F334DD81E44400038F6ECB9A84640
21027	20008	40.097254999999997	40.108249999999998	45.551133999999998	45.546393999999999	Степная	0103000020E61000000100000005000000AD2F12DA720C4440855D143DF0C54640AD2F12DA720C444059DB148F8BC6464060E5D022DB0D444059DB148F8BC6464060E5D022DB0D4440855D143DF0C54640AD2F12DA720C4440855D143DF0C54640
20904	19836	40.093060000000001	40.127572999999998	45.327952000000003	45.320670999999997	Прикубанская	0103000020E610000001000000050000006B48DC63E90B444047E350BF0BA946406B48DC63E90B44403354C554FAA94640226DE34F541044403354C554FAA94640226DE34F5410444047E350BF0BA946406B48DC63E90B444047E350BF0BA94640
20771	18756	40.010846000000001	40.025452999999999	45.464790000000001	45.454946999999997	Центральная	0103000020E610000001000000050000006EA5D76663014440E7340BB43BBA46406EA5D7666301444001C11C3D7EBB4640E44A3D0B4203444001C11C3D7EBB4640E44A3D0B42034440E7340BB43BBA46406EA5D76663014440E7340BB43BBA4640
21538	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	переулок Средний	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
21922	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Элеваторная	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
21908	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Толстого	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
22383	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Первомайская	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
20524	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Октябрьская	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
21411	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Новая	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
20711	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Набережная	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
20759	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Красная	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
20562	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Водопроводная	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
21606	18001	40.15419	40.247301	45.376001000000002	45.347827000000002	Базарная	0103000020E6100000010000000500000064AF777FBC13444039D55A9885AC464064AF777FBC134440B421FFCC20B0464051A2258FA71F4440B421FFCC20B0464051A2258FA71F444039D55A9885AC464064AF777FBC13444039D55A9885AC4640
23451	50716	40.126244	40.140895	45.205877999999998	45.194529000000003	Коммунаров	0103000020E610000001000000050000007AA86DC328104440D28F8653E69846407AA86DC328104440A27BD6355A9A4640C095ECD808124440A27BD6355A9A4640C095ECD808124440D28F8653E69846407AA86DC328104440D28F8653E6984640
21624	19198	40.266542000000001	40.304971999999999	45.332577999999998	45.325006000000002	Якубина	0103000020E6100000010000000500000056815A0C1E2244407C80EECB99A9464056815A0C1E2244403EAF78EA91AA46400D198F52092744403EAF78EA91AA46400D198F52092744407C80EECB99A9464056815A0C1E2244407C80EECB99A94640
21000	18648	40.202466000000001	40.221564000000001	45.354362999999999	45.340732000000003	Ленина	0103000020E61000000100000005000000A646E867EA194440B0592E1B9DAB4640A646E867EA194440CBF44BC45BAD464048FC8A355C1C4440CBF44BC45BAD464048FC8A355C1C4440B0592E1B9DAB4640A646E867EA194440B0592E1B9DAB4640
21479	50380	40.347327999999997	40.394103000000001	45.269232000000002	45.246093000000002	Октябрьская	0103000020E61000000100000005000000177E703E752C44402463B5F97F9F4640177E703E752C4440B284B53176A24640B42094F771324440B284B53176A24640B42094F7713244402463B5F97F9F4640177E703E752C44402463B5F97F9F4640
21425	19115	40.319040000000001	40.335892000000001	45.343392000000001	45.335245	 Волкова	0103000020E61000000100000005000000D40E7F4DD6284440E292E34EE9AA4640D40E7F4DD6284440A1DAE044F4AB4640787E5182FE2A4440A1DAE044F4AB4640787E5182FE2A4440E292E34EE9AA4640D40E7F4DD6284440E292E34EE9AA4640
21442	19933	40.081130000000002	40.168230999999999	45.554504000000001	45.539141000000001	Ленина	0103000020E61000000100000005000000BC5CC477620A44406477819202C54640BC5CC477620A444027C0B0FCF9C646403196E9978815444027C0B0FCF9C646403196E997881544406477819202C54640BC5CC477620A44406477819202C54640
21644	20061	40.134121999999998	40.188937000000003	45.559780000000003	45.553916999999998	Садовая	0103000020E6100000010000000500000049D6E1E82A11444066D993C0E6C6464049D6E1E82A1144403A7AFCDEA6C746408F006E162F1844403A7AFCDEA6C746408F006E162F18444066D993C0E6C6464049D6E1E82A11444066D993C0E6C64640
20573	50265	40.119793999999999	40.145180000000003	45.285094000000001	45.275308000000003	Мамеева	0103000020E61000000100000005000000E620E868550F4440E129E44A3DA34640E620E868550F44409624CFF57DA4464043041C42951244409624CFF57DA4464043041C4295124440E129E44A3DA34640E620E868550F4440E129E44A3DA34640
21635	19634	40.201352	40.278041000000002	45.533774999999999	45.504353000000002	переулок Школьный	0103000020E61000000100000005000000FA7DFFE6C5194440DB519CA38EC04640FA7DFFE6C519444011363CBD52C446403CF9F4D89623444011363CBD52C446403CF9F4D896234440DB519CA38EC04640FA7DFFE6C5194440DB519CA38EC04640
22899	19634	40.201352	40.278041000000002	45.533774999999999	45.504353000000002	Школьный переулок	0103000020E61000000100000005000000FA7DFFE6C5194440DB519CA38EC04640FA7DFFE6C519444011363CBD52C446403CF9F4D89623444011363CBD52C446403CF9F4D896234440DB519CA38EC04640FA7DFFE6C5194440DB519CA38EC04640
21007	19038	40.332101000000002	40.350751000000002	45.285094000000001	45.268577999999998	Магазинная	0103000020E6100000010000000500000005FC1A49822A444069368FC360A2464005FC1A49822A44409624CFF57DA446400805A568E52C44409624CFF57DA446400805A568E52C444069368FC360A2464005FC1A49822A444069368FC360A24640
21036	20401	40.070512000000001	40.082864000000001	45.263154999999998	45.258091999999998	Зеленчукская	0103000020E61000000100000005000000DFFC868906094440FBAD9D2809A14640DFFC868906094440B2632310AFA1464004029D499B0A4440B2632310AFA1464004029D499B0A4440FBAD9D2809A14640DFFC868906094440FBAD9D2809A14640
21999	19803	40.170845	40.185999000000002	45.286375	45.277248999999998	Верхняя	0103000020E61000000100000005000000B2D7BB3FDE154440A2EC2DE57CA34640B2D7BB3FDE1544402DB29DEFA7A446405B0BB3D0CE1744402DB29DEFA7A446405B0BB3D0CE174440A2EC2DE57CA34640B2D7BB3FDE154440A2EC2DE57CA34640
22487	19914	40.025246000000003	40.075730999999998	45.548842999999998	45.538932000000003	Светлая	0103000020E610000001000000050000006B2DCC423B0344404A6249B9FBC446406B2DCC423B034440BBD1C77C40C646408D25AC8DB1094440BBD1C77C40C646408D25AC8DB10944404A6249B9FBC446406B2DCC423B0344404A6249B9FBC44640
21231	20294	40.157890999999999	40.176639000000002	45.348612000000003	45.338273999999998	Колхозная	0103000020E6100000010000000500000097AAB4C535144440268BFB8F4CAB464097AAB4C535144440207F69519FAC46405D19541B9C164440207F69519FAC46405D19541B9C164440268BFB8F4CAB464097AAB4C535144440268BFB8F4CAB4640
21969	19397	40.183771999999998	40.220872	45.275537	45.257299000000003	Октябрьская	0103000020E61000000100000005000000D3F544D7851744409225732CEFA04640D3F544D78517444042EBE1CB44A34640124DA088451C444042EBE1CB44A34640124DA088451C44409225732CEFA04640D3F544D7851744409225732CEFA04640
23459	50723	40.280898000000001	40.304146000000003	45.270006000000002	45.254601999999998	Красная	0103000020E6100000010000000500000083C13577F423444083BF5FCC96A0464083C13577F4234440A5DC7D8E8FA24640C89A9141EE264440A5DC7D8E8FA24640C89A9141EE26444083BF5FCC96A0464083C13577F423444083BF5FCC96A04640
23800	50832	40.343311999999997	40.368473999999999	45.227465000000002	45.208691000000002	Красная	0103000020E610000001000000050000008429CAA5F12B44401AFCFD62B69A46408429CAA5F12B444009FEB7921D9D464091B6F1272A2F444009FEB7921D9D464091B6F1272A2F44401AFCFD62B69A46408429CAA5F12B44401AFCFD62B69A4640
21009	19298	40.212885999999997	40.241577999999997	45.331265999999999	45.316856000000001	Ленина	0103000020E610000001000000050000005CE333D93F1B44404CC5C6BC8EA846405CE333D93F1B44406C239EEC66AA46406FB72407EC1E44406C239EEC66AA46406FB72407EC1E44404CC5C6BC8EA846405CE333D93F1B44404CC5C6BC8EA84640
21650	19519	40.166856000000003	40.194991999999999	45.214888999999999	45.201940999999998	Октябрьская	0103000020E61000000100000005000000199293895B1544405B5CE333D9994640199293895B15444094A2957B819B4640A67D737FF518444094A2957B819B4640A67D737FF51844405B5CE333D9994640199293895B1544405B5CE333D9994640
21987	50448	40.166856000000003	40.194991999999999	45.214888999999999	45.201940999999998	переулок Ушинского	0103000020E61000000100000005000000199293895B1544405B5CE333D9994640199293895B15444094A2957B819B4640A67D737FF518444094A2957B819B4640A67D737FF51844405B5CE333D9994640199293895B1544405B5CE333D9994640
21003	17640	38.830953999999998	38.866149999999998	46.513157999999997	46.495635	Южная	0103000020E610000001000000050000007D3D5FB35C6A434061E0B9F7703F47407D3D5FB35C6A434023D74D29AF41474017B7D100DE6E434023D74D29AF41474017B7D100DE6E434061E0B9F7703F47407D3D5FB35C6A434061E0B9F7703F4740
22297	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Трудовая	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
21189	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Петренко	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
21197	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Орджоникидзе	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
21894	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Новощербиновская	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
22322	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Ленина	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
20515	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Краснознаменная	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
21831	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Красная	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
20703	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Кольцовская	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
21144	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Кирова	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
20732	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Калинина	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
20523	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Железнодорожная	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
21542	16957	39.019007000000002	39.099908999999997	46.565792000000002	46.509138999999998	Большая Садовая	0103000020E6100000010000000500000092B245D26E8243401F0F7D772B41474092B245D26E824340522B4CDF6B484740BCC96FD1C98C4340522B4CDF6B484740BCC96FD1C98C43401F0F7D772B41474092B245D26E8243401F0F7D772B414740
21072	50322	39.086182999999998	39.105181999999999	46.428331	46.413583000000003	Мира	0103000020E610000001000000050000004F3C670B088B43403E97A949F03447404F3C670B088B4340766EDA8CD33647405E10919A768D4340766EDA8CD33647405E10919A768D43403E97A949F03447404F3C670B088B43403E97A949F0344740
22218	49448	39.058964000000003	39.073183999999998	46.457151000000003	46.444690000000001	Комарова	0103000020E6100000010000000500000018D2E1218C874340DB6D179AEB38474018D2E1218C874340B72A89EC833A4740944BE3175E894340B72A89EC833A4740944BE3175E894340DB6D179AEB38474018D2E1218C874340DB6D179AEB384740
20529	17604	38.777396000000003	38.800043000000002	46.494996	46.476579999999998	Мира	0103000020E6100000010000000500000047054EB681634340BEF6CC92003D474047054EB6816343404ED367075C3F474066321CCF676643404ED367075C3F474066321CCF67664340BEF6CC92003D474047054EB681634340BEF6CC92003D4740
20993	17895	39.145615999999997	39.224775000000001	46.605634999999999	46.574731999999997	Пионерская	0103000020E610000001000000050000001DE38A8BA39243407AFB73D1904947401DE38A8BA39243400F289B72854D4740ADFA5C6DC59C43400F289B72854D4740ADFA5C6DC59C43407AFB73D1904947401DE38A8BA39243407AFB73D190494740
20894	50297	39.045202000000003	39.052971999999997	46.402323000000003	46.391801000000001	Красноармейская	0103000020E610000001000000050000005EDBDB2DC985434022C50089263247405EDBDB2DC9854340DDB6EF517F33474046CD57C9C7864340DDB6EF517F33474046CD57C9C786434022C50089263247405EDBDB2DC985434022C5008926324740
21929	17535	38.857481	38.887027000000003	46.409680999999999	46.399931000000002	Северная	0103000020E610000001000000050000007FF8F9EFC16D43400BD462F0303347407FF8F9EFC16D43407365506D70344740A2D5C9198A7143407365506D70344740A2D5C9198A7143400BD462F0303347407FF8F9EFC16D43400BD462F030334740
20773	48880	39.188079000000002	39.200018	46.478211999999999	46.467461999999998	Школьная	0103000020E610000001000000050000003E0801F912984340B60F79CBD53B47403E0801F9129843400247020D363D4740404E98309A9943400247020D363D4740404E98309A994340B60F79CBD53B47403E0801F912984340B60F79CBD53B4740
23976	50885	37.729483999999999	37.741109000000002	45.595447999999998	45.580758000000003	 Мира	0103000020E61000000100000005000000467A51BB5FDD4240F871344756CA4640467A51BB5FDD4240FB3BDBA337CC4640B9E2E2A8DCDE4240FB3BDBA337CC4640B9E2E2A8DCDE4240F871344756CA4640467A51BB5FDD4240F871344756CA4640
21138	5046	37.748134	37.784596000000001	45.455680000000001	45.419795999999998	Комсомольская	0103000020E610000001000000050000004983DBDAC2DF4240ED7E15E0BBB546404983DBDAC2DF42407CB8E4B853BA4640454948A46DE442407CB8E4B853BA4640454948A46DE44240ED7E15E0BBB546404983DBDAC2DF4240ED7E15E0BBB54640
21823	50432	37.748134	37.784596000000001	45.455680000000001	45.419795999999998	Красная	0103000020E610000001000000050000004983DBDAC2DF4240ED7E15E0BBB546404983DBDAC2DF42407CB8E4B853BA4640454948A46DE442407CB8E4B853BA4640454948A46DE44240ED7E15E0BBB546404983DBDAC2DF4240ED7E15E0BBB54640
20457	5773	37.948726999999998	37.969217999999998	45.565415000000002	45.551164999999997	Красная	0103000020E6100000010000000500000085EAE6E26FF9424094D920938CC6464085EAE6E26FF942407CD5CA845FC84640E658DE550FFC42407CD5CA845FC84640E658DE550FFC424094D920938CC6464085EAE6E26FF9424094D920938CC64640
22766	50555	37.841360999999999	37.935819000000002	45.178139000000002	45.153888999999999	Ленина	0103000020E610000001000000050000009F909DB7B1EB4240691B7FA2B29346409F909DB7B1EB424032923D42CD964640DBFCBFEAC8F7424032923D42CD964640DBFCBFEAC8F74240691B7FA2B29346409F909DB7B1EB4240691B7FA2B2934640
21090	5421	38.097354000000003	38.121464000000003	45.309389000000003	45.281618999999999	Школьная	0103000020E6100000010000000500000041118B18760C4340537765170CA4464041118B18760C4340FF5E0A0F9AA7464018D2E1218C0F4340FF5E0A0F9AA7464018D2E1218C0F4340537765170CA4464041118B18760C4340537765170CA44640
21444	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Ярмарочная	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21247	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Школьная	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21054	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Стаханова	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21265	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Совхозная	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21699	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Проточная	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
20839	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Отдельская	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21473	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Крупской	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
20845	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Красная	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21469	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Запорожская	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
21686	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Западная	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
20867	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Донская	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
20860	2858	38.088137000000003	38.162742000000001	45.2851	45.190038000000001	Дзержинского	0103000020E61000000100000005000000A648BE12480B4340A67F492A53984640A648BE12480B4340780B24287EA44640C3D7D7BAD4144340780B24287EA44640C3D7D7BAD4144340A67F492A53984640A648BE12480B4340A67F492A53984640
23509	50741	38.193913000000002	38.206256000000003	45.183405999999998	45.173850999999999	Пионерская	0103000020E6100000010000000500000077A22424D21843403EB0E3BF4096464077A22424D2184340F1F109D979974640494DBB98661A4340F1F109D979974640494DBB98661A43403EB0E3BF4096464077A22424D21843403EB0E3BF40964640
23443	50710	37.956498000000003	37.987668999999997	45.310231999999999	45.288766000000003	улица Пионерская	0103000020E610000001000000050000003F58C6866EFA42402F19C748F6A446403F58C6866EFA42401A16A3AEB5A74640F22213F06BFE42401A16A3AEB5A74640F22213F06BFE42402F19C748F6A446403F58C6866EFA42402F19C748F6A44640
21746	5495	38.036565000000003	38.075865999999998	45.328377000000003	45.306593999999997	Виноградная	0103000020E61000000100000005000000D1967329AE0443402D93E1783EA74640D1967329AE0443401AE1ED4108AA46406D7022FAB50943401AE1ED4108AA46406D7022FAB50943402D93E1783EA74640D1967329AE0443402D93E1783EA74640
21796	5717	37.892671999999997	37.919666999999997	45.299874000000003	45.288848000000002	Октябрьская	0103000020E6100000010000000500000007077B1343F24240ECC1A4F8F8A4464007077B1343F24240DA756F4562A64640EF1AF4A5B7F54240DA756F4562A64640EF1AF4A5B7F54240ECC1A4F8F8A4464007077B1343F24240ECC1A4F8F8A44640
24009	50895	37.657232999999998	37.713144	45.561836999999997	45.516188999999997	Западная	0103000020E610000001000000050000000D6D003620D4424008C72C7B12C246400D6D003620D4424064575A46EAC7464058AB764D48DB424064575A46EAC7464058AB764D48DB424008C72C7B12C246400D6D003620D4424008C72C7B12C24640
22501	19419	38.031516000000003	38.115248000000001	45.169625000000003	45.147951999999997	Школьная	0103000020E610000001000000050000007FA65EB7080443405BB05417F09246407FA65EB708044340C1CAA145B6954640F7764B72C00E4340C1CAA145B6954640F7764B72C00E43405BB05417F09246407FA65EB7080443405BB05417F0924640
23481	19419	38.031516000000003	38.115248000000001	45.169625000000003	45.147951999999997	Победы	0103000020E610000001000000050000007FA65EB7080443405BB05417F09246407FA65EB708044340C1CAA145B6954640F7764B72C00E4340C1CAA145B6954640F7764B72C00E43405BB05417F09246407FA65EB7080443405BB05417F0924640
23467	19419	38.031516000000003	38.115248000000001	45.169625000000003	45.147951999999997	Веселая	0103000020E610000001000000050000007FA65EB7080443405BB05417F09246407FA65EB708044340C1CAA145B6954640F7764B72C00E4340C1CAA145B6954640F7764B72C00E43405BB05417F09246407FA65EB7080443405BB05417F0924640
21514	5474	38.079127	38.101657000000003	45.308971	45.299309999999998	Советская	0103000020E61000000100000005000000849D62D5200A4340D1AE42CA4FA64640849D62D5200A4340CA349A5C8CA746406A34B918030D4340CA349A5C8CA746406A34B918030D4340D1AE42CA4FA64640849D62D5200A4340D1AE42CA4FA64640
23165	50638	37.890579000000002	38.001818	45.464941000000003	45.397644	Чапаева	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
21501	50324	37.890579000000002	38.001818	45.464941000000003	45.397644	Черноерковская	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
23347	50324	37.890579000000002	38.001818	45.464941000000003	45.397644	Мелиораторов	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
21091	50324	37.890579000000002	38.001818	45.464941000000003	45.397644	Красная	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
21511	50324	37.890579000000002	38.001818	45.464941000000003	45.397644	Инкубаторская	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
23850	50324	37.890579000000002	38.001818	45.464941000000003	45.397644	Гагарина	0103000020E6100000010000000500000090C01F7EFEF14240AEB9A3FFE5B2464090C01F7EFEF14240E7C8CA2F83BB4640A6457D923B004340E7C8CA2F83BB4640A6457D923B004340AEB9A3FFE5B2464090C01F7EFEF14240AEB9A3FFE5B24640
22982	50612	38.001351	38.056372000000003	45.411008000000002	45.368048999999999	Безымянная	0103000020E61000000100000005000000906802452C004340AA29C93A1CAF4640906802452C0043407B32FFE89BB446407F349C32370743407B32FFE89BB446407F349C3237074340AA29C93A1CAF4640906802452C004340AA29C93A1CAF4640
23922	50864	38.152124000000001	38.175272999999997	45.175490000000003	45.164006999999998	Мира	0103000020E61000000100000005000000E6779ACC7813434054A86E2EFE944640E6779ACC781343403563D17476964640976F7D586F1643403563D17476964640976F7D586F16434054A86E2EFE944640E6779ACC7813434054A86E2EFE944640
23763	50823	38.061610000000002	38.074931999999997	45.546722000000003	45.504238999999998	 Красноармейская	0103000020E61000000100000005000000A48D23D6E2074340122F4FE78AC04640A48D23D6E20743407A008BFCFAC5464041B62C5F970943407A008BFCFAC5464041B62C5F97094340122F4FE78AC04640A48D23D6E2074340122F4FE78AC04640
23353	50670	37.704152000000001	37.734299	45.203147000000001	45.187058999999998	улица Октябрьская	0103000020E61000000100000005000000DDB419A721DA424013B69F8CF1974640DDB419A721DA4240E8A38CB8009A4640253E7782FDDD4240E8A38CB8009A4640253E7782FDDD424013B69F8CF1974640DDB419A721DA424013B69F8CF1974640
23337	50670	37.704152000000001	37.734299	45.203147000000001	45.187058999999998	Октябрьская	0103000020E61000000100000005000000DDB419A721DA424013B69F8CF1974640DDB419A721DA4240E8A38CB8009A4640253E7782FDDD4240E8A38CB8009A4640253E7782FDDD424013B69F8CF1974640DDB419A721DA424013B69F8CF1974640
22365	4420	38.068095	38.106012999999997	45.588774999999998	45.555942999999999	Красная	0103000020E61000000100000005000000B4024356B708434056B8E52329C74640B4024356B7084340E8D9ACFA5CCB4640B5F97FD5910D4340E8D9ACFA5CCB4640B5F97FD5910D434056B8E52329C74640B4024356B708434056B8E52329C74640
23396	50689	38.068697	38.109031999999999	45.665815000000002	45.645730999999998	Школьная	0103000020E61000000100000005000000AA2A3410CB084340B6813B50A7D24640AA2A3410CB084340D717096D39D54640D61BB5C2F40D4340D717096D39D54640D61BB5C2F40D4340B6813B50A7D24640AA2A3410CB084340B6813B50A7D24640
21134	5817	37.843111999999998	37.863351000000002	45.669511999999997	45.657342999999997	Школьная	0103000020E61000000100000005000000BD6E1118EBEB424094A0BFD023D44640BD6E1118EBEB4240C823B891B2D5464005FC1A4982EE4240C823B891B2D5464005FC1A4982EE424094A0BFD023D44640BD6E1118EBEB424094A0BFD023D44640
23999	50891	38.038927000000001	38.066837999999997	45.492583000000003	45.460554000000002	Мира	0103000020E6100000010000000500000038F7578FFB0443406005F86EF3BA464038F7578FFB04434065C8B1F50CBF4640A510C8258E08434065C8B1F50CBF4640A510C8258E0843406005F86EF3BA464038F7578FFB0443406005F86EF3BA4640
23608	50789	38.044128000000001	38.065742	45.456749000000002	45.412824000000001	Кубанская	0103000020E61000000100000005000000406B7EFCA50543408080B56AD7B44640406B7EFCA505434088BD50C076BA4640A0FCDD3B6A08434088BD50C076BA4640A0FCDD3B6A0843408080B56AD7B44640406B7EFCA50543408080B56AD7B44640
23555	50764	37.718085000000002	37.757179999999998	45.497928000000002	45.456344000000001	Рабочая	0103000020E61000000100000005000000C45F9335EADB4240E8DCED7A69BA4640C45F9335EADB4240A0E1CD1ABCBF4640B7973446EBE04240A0E1CD1ABCBF4640B7973446EBE04240E8DCED7A69BA4640C45F9335EADB4240E8DCED7A69BA4640
21096	50325	37.950496999999999	37.996876999999998	45.508578	45.468254000000002	пер. Гвардейский	0103000020E610000001000000050000001AF9BCE2A9F94240501C40BFEFBB46401AF9BCE2A9F9424088BB7A1519C146403A9160AA99FF424088BB7A1519C146403A9160AA99FF4240501C40BFEFBB46401AF9BCE2A9F94240501C40BFEFBB4640
23969	50881	38.000785	38.049689000000001	45.379344000000003	45.325367	Советов	0103000020E61000000100000005000000E7A90EB9190043404C1938A0A5A94640E7A90EB91900434088F71C588EB0464048FC8A355C06434088F71C588EB0464048FC8A355C0643404C1938A0A5A94640E7A90EB9190043404C1938A0A5A94640
21536	6152	37.766835999999998	37.780355999999998	45.726636999999997	45.706740000000003	Ленина	0103000020E610000001000000050000009EB29AAE27E242403563D17476DA46409EB29AAE27E242402288F37002DD4640629E95B4E2E342402288F37002DD4640629E95B4E2E342403563D17476DA46409EB29AAE27E242403563D17476DA4640
20607	4070	37.852096000000003	37.927337999999999	45.236896999999999	45.197889000000004	Красная	0103000020E61000000100000005000000B686527B11ED42407C9E3F6D54994640B686527B11ED4240A0C211A4529E4640452BF702B3F64240A0C211A4529E4640452BF702B3F642407C9E3F6D54994640B686527B11ED42407C9E3F6D54994640
9758	40302	38.627656000000002	38.759456999999998	44.917762000000003	44.824038999999999	Ленина	0103000020E61000000100000005000000B09124085750434074D0251C7A694640B0912408575043407BC1A73979754640F0DB10E3356143407BC1A73979754640F0DB10E33561434074D0251C7A694640B09124085750434074D0251C7A694640
20447	40302	38.627656000000002	38.759456999999998	44.917762000000003	44.824038999999999	Казачья	0103000020E61000000100000005000000B09124085750434074D0251C7A694640B0912408575043407BC1A73979754640F0DB10E3356143407BC1A73979754640F0DB10E33561434074D0251C7A694640B09124085750434074D0251C7A694640
21660	50402	38.627656000000002	38.759456999999998	44.917762000000003	44.824038999999999	Ленина	0103000020E61000000100000005000000B09124085750434074D0251C7A694640B0912408575043407BC1A73979754640F0DB10E3356143407BC1A73979754640F0DB10E33561434074D0251C7A694640B09124085750434074D0251C7A694640
21115	2709	38.797302999999999	38.823847999999998	44.573836	44.561841000000001	Кирова	0103000020E61000000100000005000000580053060E664340A646E867EA474640580053060E6643403CA24275734946400070ECD9736943403CA24275734946400070ECD973694340A646E867EA474640580053060E664340A646E867EA474640
20824	2281	38.483314999999997	38.504758000000002	44.861324000000003	44.835538999999997	Тельмана	0103000020E6100000010000000500000047551344DD3D43402AC423F1F26A464047551344DD3D434045A165DD3F6E46407B32FFE89B40434045A165DD3F6E46407B32FFE89B4043402AC423F1F26A464047551344DD3D43402AC423F1F26A4640
20599	2281	38.483314999999997	38.504758000000002	44.861324000000003	44.835538999999997	Октябрьская	0103000020E6100000010000000500000047551344DD3D43402AC423F1F26A464047551344DD3D434045A165DD3F6E46407B32FFE89B40434045A165DD3F6E46407B32FFE89B4043402AC423F1F26A464047551344DD3D43402AC423F1F26A4640
23482	50733	38.532344999999999	38.554927999999997	44.749189999999999	44.721356	Центральная	0103000020E61000000100000005000000359886E123444340FE62B664555C4640359886E123444340C03E3A75E55F46403DD175E107474340C03E3A75E55F46403DD175E107474340FE62B664555C4640359886E123444340FE62B664555C4640
21053	2730	38.844526999999999	38.870722000000001	44.608364999999999	44.597389999999997	Школьная	0103000020E6100000010000000500000064CBF275196C43408D7A8846774C464064CBF275196C4340F98381E7DE4D464030F488D1736F4340F98381E7DE4D464030F488D1736F43408D7A8846774C464064CBF275196C43408D7A8846774C4640
20548	747	38.655926000000001	38.688049999999997	45.069270000000003	45.050550999999999	Соболя	0103000020E610000001000000050000004D4C1762F5534340DAE38574788646404D4C1762F5534340064CE0D6DD884640A301BC0512584340064CE0D6DD884640A301BC0512584340DAE38574788646404D4C1762F5534340DAE3857478864640
21669	50404	38.817838000000002	38.837403999999999	44.728183000000001	44.704869000000002	50-Лет ВЛКСМ	0103000020E6100000010000000500000089B663EAAE6843406C7BBB25395A464089B663EAAE6843406840BD19355D464011C5E40D306B43406840BD19355D464011C5E40D306B43406C7BBB25395A464089B663EAAE6843406C7BBB25395A4640
22991	50614	38.772481999999997	38.833244000000001	44.807957999999999	44.762376000000003	Почтовая	0103000020E61000000100000005000000D45FAFB0E0624340AEA0698995614640D45FAFB0E06243405245F12A6B6746404BCB48BDA76A43405245F12A6B6746404BCB48BDA76A4340AEA0698995614640D45FAFB0E0624340AEA0698995614640
23486	50614	38.772481999999997	38.833244000000001	44.807957999999999	44.762376000000003	Мира	0103000020E61000000100000005000000D45FAFB0E0624340AEA0698995614640D45FAFB0E06243405245F12A6B6746404BCB48BDA76A43405245F12A6B6746404BCB48BDA76A4340AEA0698995614640D45FAFB0E0624340AEA0698995614640
21098	40276	38.656796999999997	38.705880999999998	44.871456000000002	44.832113	Орджоникидзе	0103000020E61000000100000005000000328E91EC11544340C9C9C4AD826A4640328E91EC1154434095F3C5DE8B6F464013EF004F5A5A434095F3C5DE8B6F464013EF004F5A5A4340C9C9C4AD826A4640328E91EC11544340C9C9C4AD826A4640
22159	40276	38.656796999999997	38.705880999999998	44.871456000000002	44.832113	Октябрьская	0103000020E61000000100000005000000328E91EC11544340C9C9C4AD826A4640328E91EC1154434095F3C5DE8B6F464013EF004F5A5A434095F3C5DE8B6F464013EF004F5A5A4340C9C9C4AD826A4640328E91EC11544340C9C9C4AD826A4640
9696	40276	38.656796999999997	38.705880999999998	44.871456000000002	44.832113	Ленина	0103000020E61000000100000005000000328E91EC11544340C9C9C4AD826A4640328E91EC1154434095F3C5DE8B6F464013EF004F5A5A434095F3C5DE8B6F464013EF004F5A5A4340C9C9C4AD826A4640328E91EC11544340C9C9C4AD826A4640
20486	40276	38.656796999999997	38.705880999999998	44.871456000000002	44.832113	Комсомольская	0103000020E61000000100000005000000328E91EC11544340C9C9C4AD826A4640328E91EC1154434095F3C5DE8B6F464013EF004F5A5A434095F3C5DE8B6F464013EF004F5A5A4340C9C9C4AD826A4640328E91EC11544340C9C9C4AD826A4640
20818	40283	38.656796999999997	38.705880999999998	44.871456000000002	44.832113	Орджоникидзе	0103000020E61000000100000005000000328E91EC11544340C9C9C4AD826A4640328E91EC1154434095F3C5DE8B6F464013EF004F5A5A434095F3C5DE8B6F464013EF004F5A5A4340C9C9C4AD826A4640328E91EC11544340C9C9C4AD826A4640
24027	50900	38.710183999999998	38.723668000000004	44.830098999999997	44.818297000000001	Ленина	0103000020E610000001000000050000003C122F4FE75A43401CB5C2F4BD6846403C122F4FE75A43409DB81CAF406A4640B4942C27A15C43409DB81CAF406A4640B4942C27A15C43401CB5C2F4BD6846403C122F4FE75A43401CB5C2F4BD684640
21025	50314	38.542478000000003	38.566426999999997	44.967455000000001	44.957371999999999	Широкова	0103000020E6100000010000000500000056664AEB6F454340950D6B2A8B7A464056664AEB6F45434004ADC090D57B4640234910AE8048434004ADC090D57B4640234910AE80484340950D6B2A8B7A464056664AEB6F454340950D6B2A8B7A4640
20563	1034	38.860956999999999	38.899819000000001	44.854219000000001	44.810758999999997	Мичурина	0103000020E610000001000000050000009221C7D6336E434005F86EF3C66746409221C7D6336E4340984F560C576D4640E3A8DC442D734340984F560C576D4640E3A8DC442D73434005F86EF3C66746409221C7D6336E434005F86EF3C6674640
20794	1034	38.860956999999999	38.899819000000001	44.854219000000001	44.810758999999997	Красная	0103000020E610000001000000050000009221C7D6336E434005F86EF3C66746409221C7D6336E4340984F560C576D4640E3A8DC442D734340984F560C576D4640E3A8DC442D73434005F86EF3C66746409221C7D6336E434005F86EF3C6674640
20553	48207	38.488030999999999	38.523316999999999	45.020117999999997	44.998674999999999	 Кооперативная	0103000020E610000001000000050000009337C0CC773E4340992A1895D47F46409337C0CC773E4340CC07043A938246406D382C0DFC424340CC07043A938246406D382C0DFC424340992A1895D47F46409337C0CC773E4340992A1895D47F4640
20792	33113	38.580432000000002	38.682983	45.015281999999999	44.972504999999998	Советская	0103000020E61000000100000005000000A4C684984B4A43402619390B7B7C4640A4C684984B4A4340D61BB5C2F4814640AB5CA8FC6B574340D61BB5C2F4814640AB5CA8FC6B5743402619390B7B7C4640A4C684984B4A43402619390B7B7C4640
20782	33113	38.580432000000002	38.682983	45.015281999999999	44.972504999999998	Северная	0103000020E61000000100000005000000A4C684984B4A43402619390B7B7C4640A4C684984B4A4340D61BB5C2F4814640AB5CA8FC6B574340D61BB5C2F4814640AB5CA8FC6B5743402619390B7B7C4640A4C684984B4A43402619390B7B7C4640
21636	33113	38.580432000000002	38.682983	45.015281999999999	44.972504999999998	Октябрьская	0103000020E61000000100000005000000A4C684984B4A43402619390B7B7C4640A4C684984B4A4340D61BB5C2F4814640AB5CA8FC6B574340D61BB5C2F4814640AB5CA8FC6B5743402619390B7B7C4640A4C684984B4A43402619390B7B7C4640
20555	33113	38.580432000000002	38.682983	45.015281999999999	44.972504999999998	Ворошилова	0103000020E61000000100000005000000A4C684984B4A43402619390B7B7C4640A4C684984B4A4340D61BB5C2F4814640AB5CA8FC6B574340D61BB5C2F4814640AB5CA8FC6B5743402619390B7B7C4640A4C684984B4A43402619390B7B7C4640
23195	50641	38.662438999999999	38.698703999999999	44.720415000000003	44.700653000000003	Клубная	0103000020E61000000100000005000000274C18CDCA544340126C5CFFAE594640274C18CDCA5443402046088F365C4640CDCAF6216F5943402046088F365C4640CDCAF6216F594340126C5CFFAE594640274C18CDCA544340126C5CFFAE594640
23374	50681	38.561926	38.576676999999997	44.952357999999997	44.936625999999997	Ленина	0103000020E61000000100000005000000D462F030ED474340A94A5B5CE3774640D462F030ED474340BF0AF0DDE67946407DAD4B8DD0494340BF0AF0DDE67946407DAD4B8DD0494340A94A5B5CE3774640D462F030ED474340A94A5B5CE3774640
22992	50615	38.750087000000001	38.758747	44.950488999999997	44.927002999999999	Пролетарская	0103000020E61000000100000005000000CF13CFD9026043409E25C808A8764640CF13CFD902604340971AA19FA97946401478279F1E614340971AA19FA97946401478279F1E6143409E25C808A8764640CF13CFD9026043409E25C808A8764640
22966	50609	38.501533000000002	38.519300999999999	44.840632999999997	44.813329000000003	Восточная	0103000020E61000000100000005000000B16EBC3B32404340B7F1272A1B684640B16EBC3B324043401C78B5DC996B4640DAE38574784243401C78B5DC996B4640DAE3857478424340B7F1272A1B684640B16EBC3B32404340B7F1272A1B684640
20780	50287	38.954230000000003	38.997402999999998	44.779505999999998	44.744945999999999	Красная	0103000020E61000000100000005000000596E6935247A43409CA4F9635A5F4640596E6935247A4340948444DAC663464055F7C8E6AA7F4340948444DAC663464055F7C8E6AA7F43409CA4F9635A5F4640596E6935247A43409CA4F9635A5F4640
22456	102	38.538184000000001	38.598075000000001	44.868127999999999	44.815471000000002	Пионерская	0103000020E61000000100000005000000809D9B36E344434010EB8D5A61684640809D9B36E3444340F65E7CD11E6F464011C7BAB88D4C4340F65E7CD11E6F464011C7BAB88D4C434010EB8D5A61684640809D9B36E344434010EB8D5A61684640
20795	102	38.538184000000001	38.598075000000001	44.868127999999999	44.815471000000002	Первомайская	0103000020E61000000100000005000000809D9B36E344434010EB8D5A61684640809D9B36E3444340F65E7CD11E6F464011C7BAB88D4C4340F65E7CD11E6F464011C7BAB88D4C434010EB8D5A61684640809D9B36E344434010EB8D5A61684640
21223	102	38.538184000000001	38.598075000000001	44.868127999999999	44.815471000000002	Партизанская	0103000020E61000000100000005000000809D9B36E344434010EB8D5A61684640809D9B36E3444340F65E7CD11E6F464011C7BAB88D4C4340F65E7CD11E6F464011C7BAB88D4C434010EB8D5A61684640809D9B36E344434010EB8D5A61684640
21933	102	38.538184000000001	38.598075000000001	44.868127999999999	44.815471000000002	Мира	0103000020E61000000100000005000000809D9B36E344434010EB8D5A61684640809D9B36E3444340F65E7CD11E6F464011C7BAB88D4C4340F65E7CD11E6F464011C7BAB88D4C434010EB8D5A61684640809D9B36E344434010EB8D5A61684640
21206	102	38.538184000000001	38.598075000000001	44.868127999999999	44.815471000000002	Длинная	0103000020E61000000100000005000000809D9B36E344434010EB8D5A61684640809D9B36E3444340F65E7CD11E6F464011C7BAB88D4C4340F65E7CD11E6F464011C7BAB88D4C434010EB8D5A61684640809D9B36E344434010EB8D5A61684640
21645	102	38.538184000000001	38.598075000000001	44.868127999999999	44.815471000000002	50-Лет Октября	0103000020E61000000100000005000000809D9B36E344434010EB8D5A61684640809D9B36E3444340F65E7CD11E6F464011C7BAB88D4C4340F65E7CD11E6F464011C7BAB88D4C434010EB8D5A61684640809D9B36E344434010EB8D5A61684640
23489	50736	38.487051999999998	38.513660000000002	44.777030000000003	44.755386999999999	Калинина	0103000020E61000000100000005000000C7B94DB8573E43406A696E85B0604640C7B94DB8573E4340650113B875634640B6A1629CBF414340650113B875634640B6A1629CBF4143406A696E85B0604640C7B94DB8573E43406A696E85B0604640
23378	50682	38.829560999999998	38.853546000000001	44.779927999999998	44.761397000000002	Ленина	0103000020E61000000100000005000000BE840A0E2F6A4340E222F77475614640BE840A0E2F6A43400A9E42AED4634640D9D0CDFE406D43400A9E42AED4634640D9D0CDFE406D4340E222F77475614640BE840A0E2F6A4340E222F77475614640
21667	46541	38.490025000000003	38.496887999999998	44.874037000000001	44.869118	Веселая	0103000020E61000000100000005000000789CA223B93E4340B62E35423F6F4640789CA223B93E43403A3FC571E06F46402EE3A6069A3F43403A3FC571E06F46402EE3A6069A3F4340B62E35423F6F4640789CA223B93E4340B62E35423F6F4640
21410	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	Школьная	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
21194	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	Пушкина	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
21404	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	Привокзальная	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
20847	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	Победы	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
20953	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	Ленина	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
20790	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	Комсомольская	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
21416	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	Калинина	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
22010	31543	38.821153000000002	38.863149	44.916262000000003	44.889868999999997	50-лет Октября	0103000020E610000001000000050000009301A08A1B694340B35C363AE77146409301A08A1B694340A648BE12487546409D499BAA7B6E4340A648BE12487546409D499BAA7B6E4340B35C363AE77146409301A08A1B694340B35C363AE7714640
23950	50873	38.539935999999997	38.561118	45.015824000000002	45.006852000000002	Центральная	0103000020E610000001000000050000006EF7729F1C454340C3F4BD86E08046406EF7729F1C454340F73E5585068246403599F1B6D2474340F73E5585068246403599F1B6D2474340C3F4BD86E08046406EF7729F1C454340C3F4BD86E0804640
23838	50840	38.589548999999998	38.648910000000001	44.805571999999998	44.777203	Советская	0103000020E61000000100000005000000DB317557764B434032AD4D637B634640DB317557764B43406249B9FB1C67464010069E7B0F5343406249B9FB1C67464010069E7B0F53434032AD4D637B634640DB317557764B434032AD4D637B634640
23564	30914	38.395325	38.409787999999999	46.069600999999999	46.061183999999997	Школьная	0103000020E61000000100000005000000462575029A324340EC8497E0D4074740462575029A3243406B6281AFE80847408925E5EE733443406B6281AFE80847408925E5EE73344340EC8497E0D4074740462575029A324340EC8497E0D4074740
21403	31371	38.41966	38.460757999999998	45.767423000000001	45.742842000000003	Ленина	0103000020E610000001000000050000003DB83B6BB7354340310C587215DF46403DB83B6BB73543405F99B7EA3AE2464068AF3E1EFA3A43405F99B7EA3AE2464068AF3E1EFA3A4340310C587215DF46403DB83B6BB7354340310C587215DF4640
23401	50692	38.353651999999997	38.379190999999999	45.951011000000001	45.93394	Центральная	0103000020E610000001000000050000001E15FF77442D43408F368E588BF746401E15FF77442D434071917BBABAF9464001F8A7548930434071917BBABAF9464001F8A754893043408F368E588BF746401E15FF77442D43408F368E588BF74640
22346	50494	38.099339000000001	38.112400000000001	45.953297999999997	45.933275000000002	Чапаева	0103000020E61000000100000005000000D21BEE23B70C43405396218E75F74640D21BEE23B70C4340CDAB3AAB05FA464003098A1F630E4340CDAB3AAB05FA464003098A1F630E43405396218E75F74640D21BEE23B70C43405396218E75F74640
21569	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	ул.Ленина	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21570	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	ул. Зеленая	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21166	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Фестивальная	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21365	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Строителей	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
22354	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Свободная	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21863	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Ростовская	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
20499	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Московская	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21869	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Мира	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
20439	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Ленина	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21583	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Космонавтов	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21015	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	Казачья	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
21391	9539	38.150227999999998	38.199043000000003	46.064298000000001	46.028162000000002	50 лет Октября	0103000020E61000000100000005000000C478CDAB3A134340B77EFACF9A034740C478CDAB3A1343405F99B7EA3A084740B6BFB33D7A1943405F99B7EA3A084740B6BFB33D7A194340B77EFACF9A034740C478CDAB3A134340B77EFACF9A034740
20613	32571	38.611072999999998	38.617766000000003	45.767347999999998	45.763035000000002	Майкопская	0103000020E61000000100000005000000FB3BDBA3374E4340085A8121ABE14640FB3BDBA3374E43405453927538E24640564ACFF4124F43405453927538E24640564ACFF4124F4340085A8121ABE14640FB3BDBA3374E4340085A8121ABE14640
21213	31222	38.596943000000003	38.624575	45.854297000000003	45.837063999999998	Ленина	0103000020E61000000100000005000000BF49D3A0684C43405854C4E924EB4640BF49D3A0684C43401409A69A59ED46401973D712F24F43401409A69A59ED46401973D712F24F43405854C4E924EB4640BF49D3A0684C43405854C4E924EB4640
23513	50310	38.529048000000003	38.577575000000003	45.957946999999997	45.929326000000003	Ленина	0103000020E61000000100000005000000D20149D8B743434048A98427F4F64640D20149D8B74343409126DE019EFA46405DFE43FAED4943409126DE019EFA46405DFE43FAED49434048A98427F4F64640D20149D8B743434048A98427F4F64640
21005	50310	38.529048000000003	38.577575000000003	45.957946999999997	45.929326000000003	Ленина	0103000020E61000000100000005000000D20149D8B743434048A98427F4F64640D20149D8B74343409126DE019EFA46405DFE43FAED4943409126DE019EFA46405DFE43FAED49434048A98427F4F64640D20149D8B743434048A98427F4F64640
23297	50310	38.529048000000003	38.577575000000003	45.957946999999997	45.929326000000003	Краснодарская	0103000020E61000000100000005000000D20149D8B743434048A98427F4F64640D20149D8B74343409126DE019EFA46405DFE43FAED4943409126DE019EFA46405DFE43FAED49434048A98427F4F64640D20149D8B743434048A98427F4F64640
21208	31196	38.468834000000001	38.487402000000003	45.960960999999998	45.953048000000003	Ленина	0103000020E610000001000000050000005EA0A4C0023C434055C2137AFDF946405EA0A4C0023C4340A0DD21C500FB4640A4005130633E4340A0DD21C500FB4640A4005130633E434055C2137AFDF946405EA0A4C0023C434055C2137AFDF94640
21547	30607	38.173287999999999	38.181804	45.953687000000002	45.946894	Центральная	0103000020E6100000010000000500000006651A4D2E164340AA6395D233F9464006651A4D2E16434068CF656A12FA464018247D5A4517434068CF656A12FA464018247D5A45174340AA6395D233F9464006651A4D2E164340AA6395D233F94640
20522	47345	38.264215999999998	38.276415	45.878884999999997	45.868085999999998	Степная	0103000020E610000001000000050000003B8A73D4D1214340C70E2A711DEF46403B8A73D4D1214340F4F8BD4D7FF04640DA8F149161234340F4F8BD4D7FF04640DA8F149161234340C70E2A711DEF46403B8A73D4D1214340C70E2A711DEF4640
23495	50739	38.342359999999999	38.353983999999997	45.837226999999999	45.825986	Бригадная	0103000020E61000000100000005000000B2BAD573D22B4340187AC4E8B9E94640B2BAD573D22B4340022A1C412AEB464054A703594F2D4340022A1C412AEB464054A703594F2D4340187AC4E8B9E94640B2BAD573D22B4340187AC4E8B9E94640
21398	50363	38.225884999999998	38.239637999999999	46.149037999999997	46.140228	ул.Пионера - ул.Тельмана	0103000020E6100000010000000500000017D4B7CCE91C4340E3FDB8FDF211474017D4B7CCE91C43403DEE5BAD131347407E703E75AC1E43403DEE5BAD131347407E703E75AC1E4340E3FDB8FDF211474017D4B7CCE91C4340E3FDB8FDF2114740
75498	31480	38.555458000000002	38.566561999999998	45.788373	45.777310999999997	Центральная	0103000020E610000001000000050000009A266C3F1947434018E945ED7EE346409A266C3F1947434053060E68E9E446400394861A8548434053060E68E9E446400394861A8548434018E945ED7EE346409A266C3F1947434018E945ED7EE34640
20671	31480	38.555458000000002	38.566561999999998	45.788373	45.777310999999997	Ленина	0103000020E610000001000000050000009A266C3F1947434018E945ED7EE346409A266C3F1947434053060E68E9E446400394861A8548434053060E68E9E446400394861A8548434018E945ED7EE346409A266C3F1947434018E945ED7EE34640
23284	9689	38.349780000000003	38.377853000000002	45.982145000000003	45.958523999999997	Красная	0103000020E61000000100000005000000BF654E97C52C43402E3718EAB0FA4640BF654E97C52C4340087767EDB6FD464006D9B27C5D304340087767EDB6FD464006D9B27C5D3043402E3718EAB0FA4640BF654E97C52C43402E3718EAB0FA4640
20977	47288	38.682211000000002	38.703384	45.969467999999999	45.958637000000003	Школьная	0103000020E6100000010000000500000059FCA6B05257434027DE019EB4FA464059FCA6B0525743405F42058717FC4640CC43A67C085A43405F42058717FC4640CC43A67C085A434027DE019EB4FA464059FCA6B05257434027DE019EB4FA4640
21187	30780	38.548793000000003	38.608305999999999	46.046661	46.018988	Красная	0103000020E610000001000000050000000AA359D93E4643401B82E3326E0247400AA359D93E464340D47FD6FCF8054740F4FA93F8DC4D4340D47FD6FCF8054740F4FA93F8DC4D43401B82E3326E0247400AA359D93E4643401B82E3326E024740
20976	47209	38.243447000000003	38.266866	46.110320999999999	46.095218000000003	Ленина	0103000020E6100000010000000500000098A77345291F4340CAFE791A300C474098A77345291F4340F0879FFF1E0E4740093543AA28224340F0879FFF1E0E4740093543AA28224340CAFE791A300C474098A77345291F4340CAFE791A300C4740
20984	30632	38.336494000000002	38.359355999999998	46.014225000000003	46.000309999999999	Горького	0103000020E610000001000000050000006EA6423C122B43404EEE77280A0047406EA6423C122B43408FE4F21FD201474089CF9D60FF2D43408FE4F21FD201474089CF9D60FF2D43404EEE77280A0047406EA6423C122B43404EEE77280A004740
23610	9614	38.290393000000002	38.307532000000002	45.973990999999998	45.963379000000003	Гагарина	0103000020E6100000010000000500000061FE0A992B2543409C53C90050FB464061FE0A992B25434096CCB1BCABFC46409B3C65355D27434096CCB1BCABFC46409B3C65355D2743409C53C90050FB464061FE0A992B2543409C53C90050FB4640
21984	9528	39.956398999999998	40.011960000000002	46.147415000000002	46.137155999999997	 Ленина	0103000020E61000000100000005000000AB764D486BFA43409F39EB538E114740AB764D486BFA43404DF8A57EDE1247401A6EC0E7870144404DF8A57EDE1247401A6EC0E7870144409F39EB538E114740AB764D486BFA43409F39EB538E114740
21377	29696	39.734110999999999	39.789006999999998	46.012397	45.965308999999998	Красная	0103000020E6100000010000000500000022516859F7DD434069C4CC3E8FFB464022516859F7DD4340C5C892399601474054A86E2EFEE44340C5C892399601474054A86E2EFEE4434069C4CC3E8FFB464022516859F7DD434069C4CC3E8FFB4640
22511	29696	39.734110999999999	39.789006999999998	46.012397	45.965308999999998	Жлобы	0103000020E6100000010000000500000022516859F7DD434069C4CC3E8FFB464022516859F7DD4340C5C892399601474054A86E2EFEE44340C5C892399601474054A86E2EFEE4434069C4CC3E8FFB464022516859F7DD434069C4CC3E8FFB4640
22123	32677	39.516646999999999	39.569108	45.966191999999999	45.934742	Молодежная	0103000020E61000000100000005000000CB49287D21C243404C1938A0A5F74640CB49287D21C2434013D4F02DACFB46402CF2EB87D8C8434013D4F02DACFB46402CF2EB87D8C843404C1938A0A5F74640CB49287D21C243404C1938A0A5F74640
23551	50762	39.816262000000002	39.835979999999999	46.052253	46.045723000000002	Южная	0103000020E61000000100000005000000D97BF1457BE8434067D65240DA054740D97BF1457BE84340170FEF39B0064740170E846401EB4340170FEF39B0064740170E846401EB434067D65240DA054740D97BF1457BE8434067D65240DA054740
21135	47698	39.849975999999998	39.928559999999997	46.016109	45.996372000000001	Бендуса	0103000020E6100000010000000500000044317903CCEC43403753211E89FF464044317903CCEC4340EC1516DC0F024740D72FD80DDBF64340EC1516DC0F024740D72FD80DDBF643403753211E89FF464044317903CCEC43403753211E89FF4640
20928	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	переулок Вокзальный	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
20440	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Шевченко	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
21375	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Чкалова	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
20444	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Спартаковская	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
23776	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Советская	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
22092	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Промышленная	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
21859	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Преградная	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
21106	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Ленина	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
21362	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Крупская	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
21817	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Комсомольская	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
20448	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Заводская	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
21326	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Гражданская	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
20431	46255	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Горького	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
22245	50434	39.749499	39.835934999999999	46.160744000000001	46.116812000000003	Горького	0103000020E610000001000000050000003EB14E95EFDF4340E3E313B2F30E47403EB14E95EFDF43409D83674293144740774A07EBFFEA43409D83674293144740774A07EBFFEA4340E3E313B2F30E47403EB14E95EFDF4340E3E313B2F30E4740
21308	28339	39.620887000000003	39.647711000000001	46.068688000000002	46.056331	Заречная	0103000020E610000001000000050000007BC1A73979CF43402060ADDA350747407BC1A73979CF434057D0B4C4CA0847403621AD31E8D2434057D0B4C4CA0847403621AD31E8D243402060ADDA350747407BC1A73979CF43402060ADDA35074740
23162	50637	\N	\N	\N	\N	Колхозная	\N
21305	28223	39.594476999999998	39.619773000000002	46.071702000000002	46.051890999999998	Кооперативная	0103000020E61000000100000005000000B29C84D217CC434076FA415DA4064740B29C84D217CC43406687F8872D094740CFF8BEB854CF43406687F8872D094740CFF8BEB854CF434076FA415DA4064740B29C84D217CC434076FA415DA4064740
21312	28433	39.920853000000001	39.957504	46.222000999999999	46.203772999999998	Ленина	0103000020E6100000010000000500000035B6D782DEF543406667D13B151A474035B6D782DEF54340F3565D876A1C474004E5B67D8FFA4340F3565D876A1C474004E5B67D8FFA43406667D13B151A474035B6D782DEF543406667D13B151A4740
21355	28034	39.943643000000002	40.017395	46.018380999999998	45.980542	Ленина	0103000020E61000000100000005000000B70C384BC9F843405E2D776682FD4640B70C384BC9F8434013EF004F5A024740950ED6FF3902444013EF004F5A024740950ED6FF390244405E2D776682FD4640B70C384BC9F843405E2D776682FD4640
21302	28034	39.943643000000002	40.017395	46.018380999999998	45.980542	Красная	0103000020E61000000100000005000000B70C384BC9F843405E2D776682FD4640B70C384BC9F8434013EF004F5A024740950ED6FF3902444013EF004F5A024740950ED6FF390244405E2D776682FD4640B70C384BC9F843405E2D776682FD4640
21358	28034	39.943643000000002	40.017395	46.018380999999998	45.980542	Жлобы	0103000020E61000000100000005000000B70C384BC9F843405E2D776682FD4640B70C384BC9F8434013EF004F5A024740950ED6FF3902444013EF004F5A024740950ED6FF390244405E2D776682FD4640B70C384BC9F843405E2D776682FD4640
20660	28392	40.238532999999997	40.320199000000002	46.183635000000002	46.142426	Ленина	0103000020E610000001000000050000002502D53F881E4440D00CE2033B1247402502D53F881E444053B3075A81174740209BE447FC28444053B3075A81174740209BE447FC284440D00CE2033B1247402502D53F881E4440D00CE2033B124740
21578	46773	39.648905999999997	39.659379999999999	46.035007	46.031621999999999	Красноармейская	0103000020E61000000100000005000000CE16105A0FD34340C4EA8F300C044740CE16105A0FD34340C710001C7B04474078D1579066D44340C710001C7B04474078D1579066D44340C4EA8F300C044740CE16105A0FD34340C4EA8F300C044740
20900	46127	39.594630000000002	39.693049000000002	46.111058	46.086785999999996	Ленина	0103000020E61000000100000005000000399CF9D51CCC434015E0BBCD1B0B4740399CF9D51CCC4340C6FA0626370E474044C362D4B5D84340C6FA0626370E474044C362D4B5D8434015E0BBCD1B0B4740399CF9D51CCC434015E0BBCD1B0B4740
20483	29439	39.542312000000003	39.600926999999999	45.983559999999997	45.978281000000003	Мира	0103000020E610000001000000050000003B1DC87A6AC543402BA6D24F38FD46403B1DC87A6AC54340AED3484BE5FD464046240A2DEBCC4340AED3484BE5FD464046240A2DEBCC43402BA6D24F38FD46403B1DC87A6AC543402BA6D24F38FD4640
21126	29262	39.763612000000002	39.790157000000001	46.079659999999997	46.069913	Советская	0103000020E61000000100000005000000A56ABB09BEE143405A48C0E8F2084740A56ABB09BEE143405166834C320A47404DDA54DD23E543405166834C320A47404DDA54DD23E543405A48C0E8F2084740A56ABB09BEE143405A48C0E8F2084740
22190	45921	40.071572000000003	40.121644000000003	46.180047000000002	46.157117	Ленина	0103000020E6100000010000000500000098A7734529094440A452EC681C14474098A7734529094440185FB4C70B17474098E0D407920F4440185FB4C70B17474098E0D407920F4440A452EC681C14474098A7734529094440A452EC681C144740
21554	29548	39.520896	39.549030999999999	45.899925000000003	45.886156999999997	Степная	0103000020E61000000100000005000000014F5AB8ACC243408C0FB3976DF14640014F5AB8ACC2434029ED0DBE30F34640BEBED6A546C6434029ED0DBE30F34640BEBED6A546C643408C0FB3976DF14640014F5AB8ACC243408C0FB3976DF14640
20657	28306	39.529879000000001	39.550567000000001	46.093949000000002	46.087049	Школьная	0103000020E6100000010000000500000029EB3713D3C343402313F06B240B474029EB3713D3C34340F73E5585060C4740E0A0BDFA78C64340F73E5585060C4740E0A0BDFA78C643402313F06B240B474029EB3713D3C343402313F06B240B4740
21992	50450	39.611105000000002	39.683391999999998	46.187640999999999	46.163178000000002	Ленина	0103000020E6100000010000000500000007B64AB038CE43409EB64604E314474007B64AB038CE4340C231CB9E041847408C2C996379D74340C231CB9E041847408C2C996379D743409EB64604E314474007B64AB038CE43409EB64604E3144740
23918	50648	41.579349000000001	41.604151999999999	44.518050000000002	44.498257000000002	Советская	0103000020E6100000010000000500000033FCA71B28CA44406500A8E2C63F464033FCA71B28CA4440AED85F764F42464010E84CDA54CD4440AED85F764F42464010E84CDA54CD44406500A8E2C63F464033FCA71B28CA44406500A8E2C63F4640
23997	50890	41.281171999999998	41.304546000000002	44.505218999999997	44.477460000000001	Южная	0103000020E610000001000000050000008446B071FDA34440F792C6681D3D46408446B071FDA34440AE282504AB4046405610035DFBA64440AE282504AB4046405610035DFBA64440F792C6681D3D46408446B071FDA34440F792C6681D3D4640
23240	50649	41.575665999999998	41.586382999999998	44.297221999999998	44.285175000000002	Полевая	0103000020E61000000100000005000000A6B5696CAFC944408351499D80244640A6B5696CAFC944406BD3D85E0B26464016F71F990ECB44406BD3D85E0B26464016F71F990ECB44408351499D80244640A6B5696CAFC944408351499D80244640
21344	9998	41.564014999999998	41.583418999999999	44.458019999999998	44.448754999999998	Шовгенова	0103000020E610000001000000050000000ABABDA431C844404F75C8CD703946400ABABDA431C84440FB743C66A03A4640B96E4A79ADCA4440FB743C66A03A4640B96E4A79ADCA44404F75C8CD703946400ABABDA431C844404F75C8CD70394640
20706	9998	41.564014999999998	41.583418999999999	44.458019999999998	44.448754999999998	Центральная	0103000020E610000001000000050000000ABABDA431C844404F75C8CD703946400ABABDA431C84440FB743C66A03A4640B96E4A79ADCA4440FB743C66A03A4640B96E4A79ADCA44404F75C8CD703946400ABABDA431C844404F75C8CD70394640
21143	50333	41.528647999999997	41.591673999999998	44.252119999999998	44.17539	Международная	0103000020E61000000100000005000000438CD7BCAAC34440D105F52D73164640438CD7BCAAC344407155D977452046405EF23FF9BBCB44407155D977452046405EF23FF9BBCB4440D105F52D73164640438CD7BCAAC34440D105F52D73164640
22942	50333	41.528647999999997	41.591673999999998	44.252119999999998	44.17539	Ленина	0103000020E61000000100000005000000438CD7BCAAC34440D105F52D73164640438CD7BCAAC344407155D977452046405EF23FF9BBCB44407155D977452046405EF23FF9BBCB4440D105F52D73164640438CD7BCAAC34440D105F52D73164640
23507	50333	41.528647999999997	41.591673999999998	44.252119999999998	44.17539	Кооперативная	0103000020E61000000100000005000000438CD7BCAAC34440D105F52D73164640438CD7BCAAC344407155D977452046405EF23FF9BBCB44407155D977452046405EF23FF9BBCB4440D105F52D73164640438CD7BCAAC34440D105F52D73164640
22783	50563	41.528647999999997	41.591673999999998	44.252119999999998	44.17539	Восточная	0103000020E61000000100000005000000438CD7BCAAC34440D105F52D73164640438CD7BCAAC344407155D977452046405EF23FF9BBCB44407155D977452046405EF23FF9BBCB4440D105F52D73164640438CD7BCAAC34440D105F52D73164640
20837	26055	41.229410999999999	41.266762999999997	44.412374	44.356844000000002	Казачья	0103000020E61000000100000005000000DC2BF3565D9D44400DE36E10AD2D4640DC2BF3565D9D444040DCD5ABC834464034643C4A25A2444040DCD5ABC834464034643C4A25A244400DE36E10AD2D4640DC2BF3565D9D44400DE36E10AD2D4640
23427	50643	41.343460999999998	41.436166999999998	44.284064999999998	44.231105999999997	Тихая	0103000020E61000000100000005000000C939B187F6AB444066F4A3E1941D4640C939B187F6AB44401878EE3D5C244640164CFC51D4B744401878EE3D5C244640164CFC51D4B7444066F4A3E1941D4640C939B187F6AB444066F4A3E1941D4640
23887	50643	41.343460999999998	41.436166999999998	44.284064999999998	44.231105999999997	Ленина	0103000020E61000000100000005000000C939B187F6AB444066F4A3E1941D4640C939B187F6AB44401878EE3D5C244640164CFC51D4B744401878EE3D5C244640164CFC51D4B7444066F4A3E1941D4640C939B187F6AB444066F4A3E1941D4640
23213	50643	41.343460999999998	41.436166999999998	44.284064999999998	44.231105999999997	Ленина	0103000020E61000000100000005000000C939B187F6AB444066F4A3E1941D4640C939B187F6AB44401878EE3D5C244640164CFC51D4B744401878EE3D5C244640164CFC51D4B7444066F4A3E1941D4640C939B187F6AB444066F4A3E1941D4640
23083	50630	41.266950999999999	41.299999999999997	44.366213999999999	44.340187	Шоссейная	0103000020E6100000010000000500000037514B732BA244401EC3633F8B2B464037514B732BA244402EABB019E02E46406666666666A644402EABB019E02E46406666666666A644401EC3633F8B2B464037514B732BA244401EC3633F8B2B4640
21402	46866	41.520339	41.536059999999999	44.477164999999999	44.468860999999997	 Садовая	0103000020E61000000100000005000000ABEAE5779AC2444057AF22A3033C4640ABEAE5779AC24440DEE522BE133D4640CD58349D9DC44440DEE522BE133D4640CD58349D9DC4444057AF22A3033C4640ABEAE5779AC2444057AF22A3033C4640
21252	26239	41.200493999999999	41.238232000000004	44.474649999999997	44.442886000000001	Ленина	0103000020E61000000100000005000000A98592C9A99944409AED0A7DB0384640A98592C9A9994440F085C954C13C46402B6EDC627E9E4440F085C954C13C46402B6EDC627E9E44409AED0A7DB0384640A98592C9A99944409AED0A7DB0384640
23418	50700	41.534666999999999	41.557098000000003	44.223336000000003	44.214511000000002	Центральная	0103000020E610000001000000050000000EA0DFF76FC44440EED0B018751B46400EA0DFF76FC444407E022846961C46406155BDFC4EC744407E022846961C46406155BDFC4EC74440EED0B018751B46400EA0DFF76FC44440EED0B018751B4640
21685	9857	41.377524999999999	41.463233000000002	44.541317999999997	44.489075	Степная	0103000020E6100000010000000500000011363CBD52B04440462575029A3E464011363CBD52B04440395E81E849454640C8B60C384BBB4440395E81E849454640C8B60C384BBB4440462575029A3E464011363CBD52B04440462575029A3E4640
20417	9857	41.377524999999999	41.463233000000002	44.541317999999997	44.489075	Мащенко	0103000020E6100000010000000500000011363CBD52B04440462575029A3E464011363CBD52B04440395E81E849454640C8B60C384BBB4440395E81E849454640C8B60C384BBB4440462575029A3E464011363CBD52B04440462575029A3E4640
20836	9857	41.377524999999999	41.463233000000002	44.541317999999997	44.489075	Ленина	0103000020E6100000010000000500000011363CBD52B04440462575029A3E464011363CBD52B04440395E81E849454640C8B60C384BBB4440395E81E849454640C8B60C384BBB4440462575029A3E464011363CBD52B04440462575029A3E4640
20840	9857	41.377524999999999	41.463233000000002	44.541317999999997	44.489075	Кирова	0103000020E6100000010000000500000011363CBD52B04440462575029A3E464011363CBD52B04440395E81E849454640C8B60C384BBB4440395E81E849454640C8B60C384BBB4440462575029A3E464011363CBD52B04440462575029A3E4640
21678	9832	41.196154999999997	41.227946000000003	44.398457000000001	44.353608000000001	Ленина	0103000020E6100000010000000500000033F9669B1B9944404FCDE506432D464033F9669B1B9944405FEE93A30033464084A0A3552D9D44405FEE93A30033464084A0A3552D9D44404FCDE506432D464033F9669B1B9944404FCDE506432D4640
23176	50596	41.249623	41.320419000000001	44.235221000000003	44.193140999999997	Шаумяна	0103000020E610000001000000050000002AAA7EA5F39F4440244223D8B81846402AAA7EA5F39F44408D2AC3B81B1E46402E02637D03A944408D2AC3B81B1E46402E02637D03A94440244223D8B81846402AAA7EA5F39F4440244223D8B8184640
22951	50596	41.249623	41.320419000000001	44.235221000000003	44.193140999999997	Комсомольская	0103000020E610000001000000050000002AAA7EA5F39F4440244223D8B81846402AAA7EA5F39F44408D2AC3B81B1E46402E02637D03A944408D2AC3B81B1E46402E02637D03A94440244223D8B81846402AAA7EA5F39F4440244223D8B8184640
21272	8939	41.505085999999999	41.535888999999997	44.574716000000002	44.565251000000004	Красная	0103000020E610000001000000050000006FD575A8A6C0444002840F255A4846406FD575A8A6C04440753E3C4B90494640A0A4C00298C44440753E3C4B90494640A0A4C00298C4444002840F255A4846406FD575A8A6C0444002840F255A484640
20725	50281	41.643371999999999	41.688279000000001	44.483691999999998	44.469819000000001	Ленина	0103000020E61000000100000005000000C09481035AD244400C056C07233C4640C09481035AD244401DAB949EE93D464005C3B98619D844401DAB949EE93D464005C3B98619D844400C056C07233C4640C09481035AD244400C056C07233C4640
23254	50654	41.435817	41.472817999999997	44.308576000000002	44.287000999999997	улица Буденного	0103000020E610000001000000050000003A05F9D9C8B74440AB75E272BC2446403A05F9D9C8B744404E2A1A6B7F274640E57ADB4C85BC44404E2A1A6B7F274640E57ADB4C85BC4440AB75E272BC2446403A05F9D9C8B74440AB75E272BC244640
22847	50577	41.301096000000001	41.361013999999997	44.392325999999997	44.363598000000003	Первомайская	0103000020E610000001000000050000006C7A50508AA644400D7217618A2E46406C7A50508AA644406CAF05BD37324640F6B2EDB435AE44406CAF05BD37324640F6B2EDB435AE44400D7217618A2E46406C7A50508AA644400D7217618A2E4640
21218	50345	41.484226999999997	41.543101999999998	44.438284000000003	44.353955999999997	Урупская	0103000020E610000001000000050000008B6B7C26FBBD44408A1C226E4E2D46408B6B7C26FBBD4440172EABB0193846403332C85D84C54440172EABB0193846403332C85D84C544408A1C226E4E2D46408B6B7C26FBBD44408A1C226E4E2D4640
23387	50345	41.484226999999997	41.543101999999998	44.438284000000003	44.353955999999997	Овражная	0103000020E610000001000000050000008B6B7C26FBBD44408A1C226E4E2D46408B6B7C26FBBD4440172EABB0193846403332C85D84C54440172EABB0193846403332C85D84C544408A1C226E4E2D46408B6B7C26FBBD44408A1C226E4E2D4640
21220	50345	41.484226999999997	41.543101999999998	44.438284000000003	44.353955999999997	Кизилова	0103000020E610000001000000050000008B6B7C26FBBD44408A1C226E4E2D46408B6B7C26FBBD4440172EABB0193846403332C85D84C54440172EABB0193846403332C85D84C544408A1C226E4E2D46408B6B7C26FBBD44408A1C226E4E2D4640
22954	50599	41.357132999999997	41.470041999999999	44.228568000000003	44.174227000000002	Трактовая	0103000020E6100000010000000500000043A9BD88B6AD4440448A01124D16464043A9BD88B6AD4440C1745AB7411D46408BDF14562ABC4440C1745AB7411D46408BDF14562ABC4440448A01124D16464043A9BD88B6AD4440448A01124D164640
23349	50599	41.357132999999997	41.470041999999999	44.228568000000003	44.174227000000002	Лесная	0103000020E6100000010000000500000043A9BD88B6AD4440448A01124D16464043A9BD88B6AD4440C1745AB7411D46408BDF14562ABC4440C1745AB7411D46408BDF14562ABC4440448A01124D16464043A9BD88B6AD4440448A01124D164640
23368	49443	41.309361000000003	41.333309999999997	44.326549999999997	44.310214000000002	Красная	0103000020E6100000010000000500000035D4282499A744407461A417B527464035D4282499A744402041F163CC29464002B7EEE6A9AA44402041F163CC29464002B7EEE6A9AA44407461A417B527464035D4282499A744407461A417B5274640
21349	10080	41.495652999999997	41.558022999999999	44.297821999999996	44.262740000000001	пер. Советский	0103000020E610000001000000050000000795B88E71BF4440EFACDD76A12146400795B88E71BF4440C00303081F26464039B5334C6DC74440C00303081F26464039B5334C6DC74440EFACDD76A12146400795B88E71BF4440EFACDD76A1214640
23565	47670	41.354931999999998	41.377066999999997	44.091354000000003	44.062911999999997	Ленина	0103000020E61000000100000005000000E5266A696EAD444052431B800D084640E5266A696EAD4440ED2DE57CB10B46404EB340BB43B04440ED2DE57CB10B46404EB340BB43B0444052431B800D084640E5266A696EAD444052431B800D084640
20615	49576	41.207751999999999	41.226590000000002	44.510156000000002	44.474798	Ленина	0103000020E61000000100000005000000DCD6169E979A4440651A4D2EC63C4640DCD6169E979A4440D9EDB3CA4C414640E2CCAFE6009D4440D9EDB3CA4C414640E2CCAFE6009D4440651A4D2EC63C4640DCD6169E979A4440651A4D2EC63C4640
22705	50541	41.714751999999997	41.736114000000001	44.272165000000001	44.238979	Набережная	0103000020E61000000100000005000000136058FE7CDB444024B726DD961E4640136058FE7CDB4440D40E7F4DD62246405A10CAFB38DE4440D40E7F4DD62246405A10CAFB38DE444024B726DD961E4640136058FE7CDB444024B726DD961E4640
21260	26410	41.379069999999999	41.432592	44.618085999999998	44.572687000000002	Красная	0103000020E610000001000000050000008672A25D85B0444014ECBFCE4D4946408672A25D85B04440C70E2A711D4F46407041B62C5FB74440C70E2A711D4F46407041B62C5FB7444014ECBFCE4D4946408672A25D85B0444014ECBFCE4D494640
21087	32572	41.526716999999998	41.565748999999997	44.510779999999997	44.481955999999997	Октябрьская	0103000020E61000000100000005000000A59F70766BC34440340EF5BBB03D4640A59F70766BC34440B6B9313D61414640525F96766AC84440B6B9313D61414640525F96766AC84440340EF5BBB03D4640A59F70766BC34440340EF5BBB03D4640
21797	32572	41.526716999999998	41.565748999999997	44.510779999999997	44.481955999999997	Коммунаров	0103000020E61000000100000005000000A59F70766BC34440340EF5BBB03D4640A59F70766BC34440B6B9313D61414640525F96766AC84440B6B9313D61414640525F96766AC84440340EF5BBB03D4640A59F70766BC34440340EF5BBB03D4640
20414	27719	41.123023000000003	41.166339999999998	44.269002	44.234884999999998	Красная	0103000020E61000000100000005000000F2D3B837BF8F444015A930B6101E4640F2D3B837BF8F4440804754A86E22464021020EA14A954440804754A86E22464021020EA14A95444015A930B6101E4640F2D3B837BF8F444015A930B6101E4640
23023	50618	40.615591999999999	40.642901000000002	46.051071	46.043501999999997	Пролетарская	0103000020E61000000100000005000000F1D6F9B7CB4E4440C1A7397991054740F1D6F9B7CB4E44401363997E8906474069C878944A5244401363997E8906474069C878944A524440C1A7397991054740F1D6F9B7CB4E4440C1A7397991054740
23376	46117	40.782336999999998	40.791967	45.823957999999998	45.817149000000001	Советов	0103000020E61000000100000005000000B2B96A9E23644440C47AA35698E84640B2B96A9E2364444087A3AB7477E946407041B62C5F65444087A3AB7477E946407041B62C5F654440C47AA35698E84640B2B96A9E23644440C47AA35698E84640
21467	46117	40.782336999999998	40.791967	45.823957999999998	45.817149000000001	Мира	0103000020E61000000100000005000000B2B96A9E23644440C47AA35698E84640B2B96A9E2364444087A3AB7477E946407041B62C5F65444087A3AB7477E946407041B62C5F654440C47AA35698E84640B2B96A9E23644440C47AA35698E84640
21094	13978	40.566077	40.577359999999999	46.028399	46.021903999999999	Юбилейная	0103000020E6100000010000000500000047020D367548444067D311C0CD02474047020D36754844409B1E1494A20347406002B7EEE64944409B1E1494A20347406002B7EEE649444067D311C0CD02474047020D367548444067D311C0CD024740
23719	50812	40.597365000000003	40.648936999999997	46.231409999999997	46.217979999999997	Красная	0103000020E610000001000000050000003563D174764C44404E97C5C4E61B47403563D174764C4440D2FBC6D79E1D474009151C5E10534440D2FBC6D79E1D474009151C5E105344404E97C5C4E61B47403563D174764C44404E97C5C4E61B4740
23989	14264	40.763446000000002	40.777540000000002	45.844723999999999	45.831544000000001	Центральная	0103000020E610000001000000050000008A213999B8614440AF97A60870EA46408A213999B8614440BA1281EA1FEC46407AAA436E86634440BA1281EA1FEC46407AAA436E86634440AF97A60870EA46408A213999B8614440AF97A60870EA4640
21434	14264	40.763446000000002	40.777540000000002	45.844723999999999	45.831544000000001	Ленина	0103000020E610000001000000050000008A213999B8614440AF97A60870EA46408A213999B8614440BA1281EA1FEC46407AAA436E86634440BA1281EA1FEC46407AAA436E86634440AF97A60870EA46408A213999B8614440AF97A60870EA4640
21564	20617	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	ул. Первенцева	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
21517	20617	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	Черняховского	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
21836	20617	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	Почтовая	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
20428	20617	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	Первомайская	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
21101	20617	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	Ленина	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
21105	20617	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	Калинина	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
21551	20617	40.641444999999997	40.743206000000001	45.982258000000002	45.922756	Григорьева	0103000020E610000001000000050000006397A8DE1A52444009185DDE1CF646406397A8DE1A524440001E51A1BAFD46407218CC5F215F4440001E51A1BAFD46407218CC5F215F444009185DDE1CF646406397A8DE1A52444009185DDE1CF64640
23229	10454	40.467207999999999	40.510317999999998	46.182187999999996	46.165388	Красная	0103000020E61000000100000005000000FC36C478CD3B44404F93196F2B154740FC36C478CD3B4440A0DCB6EF51174740B247A81952414440A0DCB6EF51174740B247A819524144404F93196F2B154740FC36C478CD3B44404F93196F2B154740
21023	14085	40.372686999999999	40.389494999999997	46.127769000000001	46.114238	Красная	0103000020E610000001000000050000007A522635B42F4440F0FACC599F0E47407A522635B42F4440A8380EBC5A1047404E7ADFF8DA314440A8380EBC5A1047404E7ADFF8DA314440F0FACC599F0E47407A522635B42F4440F0FACC599F0E4740
22213	49072	40.740735999999998	40.753582000000002	45.820748000000002	45.817318999999998	Шоссейная	0103000020E61000000100000005000000247CEF6FD05E444020B3B3E89DE84640247CEF6FD05E4440F3203D450EE94640596DFE5F75604440F3203D450EE94640596DFE5F7560444020B3B3E89DE84640247CEF6FD05E444020B3B3E89DE84640
20813	10927	40.559806000000002	40.577368999999997	45.991444000000001	45.982809000000003	Светлая	0103000020E61000000100000005000000630D17B9A7474440749B70AFCCFD4640630D17B9A747444060E811A3E7FE4640B35C363AE749444060E811A3E7FE4640B35C363AE7494440749B70AFCCFD4640630D17B9A7474440749B70AFCCFD4640
20853	10914	40.558611999999997	40.590107000000003	45.939073	45.919446000000001	Школьная	0103000020E610000001000000050000009A9317998047444011381268B0F546409A931799804744403FC7478B33F8464002124DA0884B44403FC7478B33F8464002124DA0884B444011381268B0F546409A9317998047444011381268B0F54640
20800	10914	40.558611999999997	40.590107000000003	45.939073	45.919446000000001	Советская	0103000020E610000001000000050000009A9317998047444011381268B0F546409A931799804744403FC7478B33F8464002124DA0884B44403FC7478B33F8464002124DA0884B444011381268B0F546409A9317998047444011381268B0F54640
21417	10914	40.558611999999997	40.590107000000003	45.939073	45.919446000000001	Молодежная	0103000020E610000001000000050000009A9317998047444011381268B0F546409A931799804744403FC7478B33F8464002124DA0884B44403FC7478B33F8464002124DA0884B444011381268B0F546409A9317998047444011381268B0F54640
23863	10994	40.412474000000003	40.463282	46.018568000000002	45.991518999999997	Фрунзе	0103000020E61000000100000005000000A439B2F2CB3444406A2E3718EAFE4640A439B2F2CB3444404660AC6F60024740A96917D34C3B44404660AC6F60024740A96917D34C3B44406A2E3718EAFE4640A439B2F2CB3444406A2E3718EAFE4640
21447	10994	40.412474000000003	40.463282	46.018568000000002	45.991518999999997	Красная 	0103000020E61000000100000005000000A439B2F2CB3444406A2E3718EAFE4640A439B2F2CB3444404660AC6F60024740A96917D34C3B44404660AC6F60024740A96917D34C3B44406A2E3718EAFE4640A439B2F2CB3444406A2E3718EAFE4640
23616	10994	40.412474000000003	40.463282	46.018568000000002	45.991518999999997	 Октябрьская	0103000020E61000000100000005000000A439B2F2CB3444406A2E3718EAFE4640A439B2F2CB3444404660AC6F60024740A96917D34C3B44404660AC6F60024740A96917D34C3B44406A2E3718EAFE4640A439B2F2CB3444406A2E3718EAFE4640
23932	50619	40.683414999999997	40.762484000000001	45.749521000000001	45.703366000000003	Ленина	0103000020E61000000100000005000000444C89247A574440268FA7E507DA4640444C89247A5744402655DB4DF0DF464094DC6113996144402655DB4DF0DF464094DC611399614440268FA7E507DA4640444C89247A574440268FA7E507DA4640
23027	50619	40.683414999999997	40.762484000000001	45.749521000000001	45.703366000000003	Крылова	0103000020E61000000100000005000000444C89247A574440268FA7E507DA4640444C89247A5744402655DB4DF0DF464094DC6113996144402655DB4DF0DF464094DC611399614440268FA7E507DA4640444C89247A574440268FA7E507DA4640
20960	10607	40.690466000000001	40.700842000000002	45.817847	45.812883999999997	Центральная	0103000020E61000000100000005000000FE7F9C306158444088B839950CE84640FE7F9C3061584440DC10E335AFE84640E5D4CE30B5594440DC10E335AFE84640E5D4CE30B559444088B839950CE84640FE7F9C306158444088B839950CE84640
22513	14166	40.667470000000002	40.71199	46.109065000000001	46.067780999999997	Советская 	0103000020E61000000100000005000000D3872EA86F55444024253D0CAD084740D3872EA86F554440B21188D7F50D47401E8A027D225B4440B21188D7F50D47401E8A027D225B444024253D0CAD084740D3872EA86F55444024253D0CAD084740
23470	11044	40.265490999999997	40.285308000000001	45.987122999999997	45.977516999999999	Клубный переулок	0103000020E61000000100000005000000F030ED9BFB2144405B24ED461FFD4640F030ED9BFB2144409010E50B5AFE4640C2A4F8F8842444409010E50B5AFE4640C2A4F8F8842444405B24ED461FFD4640F030ED9BFB2144405B24ED461FFD4640
23962	50879	41.147035000000002	41.161794	44.677334000000002	44.671115999999998	Пролетарская	0103000020E61000000100000005000000062FFA0AD292444042E90B21E7554640062FFA0AD2924440043C69E1B2564640325871AAB5944440043C69E1B2564640325871AAB594444042E90B21E7554640062FFA0AD292444042E90B21E7554640
23537	50756	40.844051	40.853797999999998	45.129266000000001	45.122182000000002	Урожайная	0103000020E61000000100000005000000FB93F8DC096C44407714E7A8A38F4640FB93F8DC096C44400C3ECDC98B904640F2B1BB40496D44400C3ECDC98B904640F2B1BB40496D44407714E7A8A38F4640FB93F8DC096C44407714E7A8A38F4640
23257	50655	41.134656	41.145876000000001	45.035553	45.028292	Свободы	0103000020E61000000100000005000000E71A66683C914440855E7F129F834640E71A66683C91444029232E008D844640BAA29410AC92444029232E008D844640BAA29410AC924440855E7F129F834640E71A66683C914440855E7F129F834640
23848	50845	40.947519	40.961362000000001	45.102691999999998	45.093606999999999	Широкая	0103000020E6100000010000000500000058AB764D487944409DD66D50FB8B464058AB764D48794440C9C7EE02258D4640FFCEF6E80D7B4440C9C7EE02258D4640FFCEF6E80D7B44409DD66D50FB8B464058AB764D487944409DD66D50FB8B4640
21841	50435	41.214418000000002	41.224469999999997	45.161275000000003	45.151220000000002	Школьная	0103000020E610000001000000050000003DD68C0C729B444025404D2D5B9346403DD68C0C729B4440CA54C1A8A49446407077D66EBB9C4440CA54C1A8A49446407077D66EBB9C444025404D2D5B9346403DD68C0C729B444025404D2D5B934640
23407	50695	41.135573000000001	41.152515000000001	44.910760000000003	44.888661999999997	улица Ленина	0103000020E610000001000000050000003D9CC0745A914440569929ADBF7146403D9CC0745A914440A3409FC89374464021938C9C85934440A3409FC89374464021938C9C85934440569929ADBF7146403D9CC0745A914440569929ADBF714640
23076	50593	41.142445000000002	41.216330999999997	44.814621000000002	44.737827000000003	улица Октябрьская	0103000020E61000000100000005000000473D44A33B9244408B8D791D715E4640473D44A33B92444042D13C8045684640340EF5BBB09B444042D13C8045684640340EF5BBB09B44408B8D791D715E4640473D44A33B9244408B8D791D715E4640
23534	50593	41.142445000000002	41.216330999999997	44.814621000000002	44.737827000000003	Энгельса	0103000020E61000000100000005000000473D44A33B9244408B8D791D715E4640473D44A33B92444042D13C8045684640340EF5BBB09B444042D13C8045684640340EF5BBB09B44408B8D791D715E4640473D44A33B9244408B8D791D715E4640
22934	50593	41.142445000000002	41.216330999999997	44.814621000000002	44.737827000000003	Ленина	0103000020E61000000100000005000000473D44A33B9244408B8D791D715E4640473D44A33B92444042D13C8045684640340EF5BBB09B444042D13C8045684640340EF5BBB09B44408B8D791D715E4640473D44A33B9244408B8D791D715E4640
23825	50836	40.862772	40.883721000000001	45.151372000000002	45.134951000000001	Садовая	0103000020E61000000100000005000000C7F319506F6E444000C8091346914640C7F319506F6E4440DBC35E2860934640EBE40CC51D714440DBC35E2860934640EBE40CC51D71444000C8091346914640C7F319506F6E444000C8091346914640
23512	50742	41.231431999999998	41.256971	44.729534000000001	44.707231999999998	Мира	0103000020E61000000100000005000000BA9F53909F9D4440A3570394865A4640BA9F53909F9D4440F8A8BF5E615D46409D82FC6CE4A04440F8A8BF5E615D46409D82FC6CE4A04440A3570394865A4640BA9F53909F9D4440A3570394865A4640
21422	23141	41.027980999999997	41.047888	44.814729999999997	44.804031000000002	Западная	0103000020E6100000010000000500000066F4A3E1948344402FFCE07CEA66464066F4A3E194834440F88898124968464078EFA83121864440F88898124968464078EFA831218644402FFCE07CEA66464066F4A3E1948344402FFCE07CEA664640
20442	32712	41.131494000000004	41.142274	44.884511000000003	44.866365000000002	Школьная	0103000020E6100000010000000500000064CF9ECBD490444014B35E0CE56E464064CF9ECBD4904440E4F90CA8377146401A89D00836924440E4F90CA8377146401A89D0083692444014B35E0CE56E464064CF9ECBD490444014B35E0CE56E4640
22988	50613	41.104689	41.134045999999998	45.082025000000002	45.042126000000003	Ленина	0103000020E610000001000000050000001FA0FB72668D4440D9278062648546401FA0FB72668D44402A3A92CB7F8A46406E14596B289144402A3A92CB7F8A46406E14596B28914440D9278062648546401FA0FB72668D4440D927806264854640
21043	50320	40.968224999999997	40.987026999999998	45.207287999999998	45.185896	Ленина	0103000020E61000000100000005000000B515FBCBEE7B4440863AAC70CB974640B515FBCBEE7B4440376DC669889A46406EA296E6567E4440376DC669889A46406EA296E6567E4440863AAC70CB974640B515FBCBEE7B4440863AAC70CB974640
22314	50320	40.968224999999997	40.987026999999998	45.207287999999998	45.185896	Красноармейская,	0103000020E61000000100000005000000B515FBCBEE7B4440863AAC70CB974640B515FBCBEE7B4440376DC669889A46406EA296E6567E4440376DC669889A46406EA296E6567E4440863AAC70CB974640B515FBCBEE7B4440863AAC70CB974640
20663	47127	41.258111999999997	41.275233999999998	45.072884999999999	45.056058999999998	Школьная	0103000020E61000000100000005000000425A63D009A14440BFD2F9F02C874640425A63D009A144403AAFB14B54894640A65F22DE3AA344403AAFB14B54894640A65F22DE3AA34440BFD2F9F02C874640425A63D009A14440BFD2F9F02C874640
20433	32676	41.013429000000002	41.036138000000001	44.901693999999999	44.882519000000002	Ленина	0103000020E61000000100000005000000B4E89D0AB8814440A08CF161F6704640B4E89D0AB8814440ED7F80B56A7346404912842BA0844440ED7F80B56A7346404912842BA0844440A08CF161F6704640B4E89D0AB8814440A08CF161F6704640
21900	50393	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Ленина	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
21292	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Щорса	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
20943	15931	40.763347000000003	40.844222000000002	44.187964000000001	44.083914999999998	Красный	0103000020E61000000100000005000000F73FC05AB561444069520ABABD0A4640F73FC05AB5614440A56950340F18464028486C770F6C4440A56950340F18464028486C770F6C444069520ABABD0A4640F73FC05AB561444069520ABABD0A4640
21510	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Тимирязева	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
20893	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Суворова	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
21083	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Пушкина	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
20652	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Первомайская	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
20655	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Обороны	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
21088	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Новаторов	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
21300	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Лермонтова	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
20525	13546	40.947654	41.098275000000001	45.149369999999998	45.061400999999996	Красная	0103000020E6100000010000000500000038F6ECB94C7944408978EBFCDB87464038F6ECB94C7944407380608E1E934640D8817346948C44407380608E1E934640D8817346948C44408978EBFCDB87464038F6ECB94C7944408978EBFCDB874640
20781	50288	40.886380000000003	40.899611999999998	45.061636999999997	45.052836999999997	Мира	0103000020E610000001000000050000000CEA5BE6747144406682E15CC38646400CEA5BE6747144409D9CA1B8E3874640698B6B7C267344409D9CA1B8E3874640698B6B7C267344406682E15CC38646400CEA5BE6747144406682E15CC3864640
23472	50728	41.103952	41.132941000000002	45.161712999999999	45.149121999999998	Школьная	0103000020E61000000100000005000000492D944C4E8D44409B8E006E16934640492D944C4E8D4440452BF702B394464016A6EF3504914440452BF702B394464016A6EF35049144409B8E006E16934640492D944C4E8D44409B8E006E16934640
20913	19718	41.387352	41.409253	45.030374999999999	45.011535000000002	Ленина	0103000020E61000000100000005000000250516C094B1444033E197FA79814640250516C094B14440D9CEF753E38346401B65FD6662B44440D9CEF753E38346401B65FD6662B4444033E197FA79814640250516C094B1444033E197FA79814640
23360	46881	40.865170999999997	40.875366999999997	45.217103999999999	45.207839999999997	Школьная	0103000020E610000001000000050000004B395FECBD6E44407B6649809A9A46404B395FECBD6E444057EA5910CA9B4640B27F9E060C70444057EA5910CA9B4640B27F9E060C7044407B6649809A9A46404B395FECBD6E44407B6649809A9A4640
21351	46881	40.865170999999997	40.875366999999997	45.217103999999999	45.207839999999997	Комсомольская	0103000020E610000001000000050000004B395FECBD6E44407B6649809A9A46404B395FECBD6E444057EA5910CA9B4640B27F9E060C70444057EA5910CA9B4640B27F9E060C7044407B6649809A9A46404B395FECBD6E44407B6649809A9A4640
21062	17692	40.983038999999998	41.013787999999998	45.180236000000001	45.149236000000002	Мичурина	0103000020E61000000100000005000000A5D8D138D47D444064B14D2A1A934640A5D8D138D47D4440EBC726F911974640E38920CEC3814440EBC726F911974640E38920CEC381444064B14D2A1A934640A5D8D138D47D444064B14D2A1A934640
23660	50804	40.888626000000002	40.917245999999999	45.175522000000001	45.151614000000002	Мира	0103000020E610000001000000050000000A302C7FBE714440D1CE6916689346400A302C7FBE71444040DD408177964640833122516875444040DD4081779646408331225168754440D1CE6916689346400A302C7FBE714440D1CE691668934640
21307	46999	41.292571000000002	41.346722	45.224513000000002	45.186754000000001	Коммунаров	0103000020E6100000010000000500000007616EF772A54440D732198EE797464007616EF772A5444070438CD7BC9C4640E066F16261AC444070438CD7BC9C4640E066F16261AC4440D732198EE797464007616EF772A54440D732198EE7974640
23399	50690	40.911208999999999	40.927379000000002	45.004219999999997	44.994430000000001	Механизаторов	0103000020E6100000010000000500000012691B7FA2744440A514747B497F464012691B7FA27444409BFEEC478A804640A4FFE55AB47644409BFEEC478A804640A4FFE55AB4764440A514747B497F464012691B7FA2744440A514747B497F4640
21289	18154	40.799242999999997	40.810938999999998	45.003582000000002	44.998586000000003	Пионерская	0103000020E61000000100000005000000494739984D6644402A1F82AAD17F4640494739984D664440596DFE5F75804640850662D9CC674440596DFE5F75804640850662D9CC6744402A1F82AAD17F4640494739984D6644402A1F82AAD17F4640
23885	47835	41.328612	41.352066999999998	45.109059999999999	45.092201000000003	Красноармейская	0103000020E610000001000000050000005D8940F50FAA44404AD40B3ECD8B46405D8940F50FAA4440A0A696ADF58D46401B800D8810AD4440A0A696ADF58D46401B800D8810AD44404AD40B3ECD8B46405D8940F50FAA44404AD40B3ECD8B4640
21112	47215	41.005549999999999	41.029463999999997	44.955024000000002	44.934054000000003	Школьная	0103000020E61000000100000005000000143FC6DCB58044405859DB148F774640143FC6DCB58044409372F7393E7A46406534F279C58344409372F7393E7A46406534F279C58344405859DB148F774640143FC6DCB58044405859DB148F774640
21160	46351	40.962674	40.985239999999997	45.240585000000003	45.207942000000003	Зеленая	0103000020E61000000100000005000000D15AD1E6387B444080BBECD79D9A4640D15AD1E6387B44403F74417DCB9E4640035B25581C7E44403F74417DCB9E4640035B25581C7E444080BBECD79D9A4640D15AD1E6387B444080BBECD79D9A4640
21034	46351	40.962674	40.985239999999997	45.240585000000003	45.207942000000003	Гагарина	0103000020E61000000100000005000000D15AD1E6387B444080BBECD79D9A4640D15AD1E6387B44403F74417DCB9E4640035B25581C7E44403F74417DCB9E4640035B25581C7E444080BBECD79D9A4640D15AD1E6387B444080BBECD79D9A4640
23874	50851	40.911721	40.928780000000003	45.123790999999997	45.117182999999997	Большевистская	0103000020E61000000100000005000000C8091346B3744440D65240DAFF8E4640C8091346B374444002452C62D88F4640E6965643E276444002452C62D88F4640E6965643E2764440D65240DAFF8E4640C8091346B3744440D65240DAFF8E4640
20684	20432	41.274954999999999	41.351616999999997	44.674185999999999	44.612388000000003	Московская	0103000020E61000000100000005000000936FB6B931A344403F3BE0BA624E4640936FB6B931A34440E5B512BA4B564640DBDB2DC901AD4440E5B512BA4B564640DBDB2DC901AD44403F3BE0BA624E4640936FB6B931A344403F3BE0BA624E4640
20686	20432	41.274954999999999	41.351616999999997	44.674185999999999	44.612388000000003	Ленина	0103000020E61000000100000005000000936FB6B931A344403F3BE0BA624E4640936FB6B931A34440E5B512BA4B564640DBDB2DC901AD4440E5B512BA4B564640DBDB2DC901AD44403F3BE0BA624E4640936FB6B931A344403F3BE0BA624E4640
23888	20432	41.274954999999999	41.351616999999997	44.674185999999999	44.612388000000003	Ленина	0103000020E61000000100000005000000936FB6B931A344403F3BE0BA624E4640936FB6B931A34440E5B512BA4B564640DBDB2DC901AD4440E5B512BA4B564640DBDB2DC901AD44403F3BE0BA624E4640936FB6B931A344403F3BE0BA624E4640
23292	50663	40.439413999999999	40.485156000000003	44.640256000000001	44.585278000000002	Школьная	0103000020E61000000100000005000000C8B3CBB73E384440BE88B663EA4A4640C8B3CBB73E384440AD889AE8F3514640A6BA8097193E4440AD889AE8F3514640A6BA8097193E4440BE88B663EA4A4640C8B3CBB73E384440BE88B663EA4A4640
24030	50663	40.439413999999999	40.485156000000003	44.640256000000001	44.585278000000002	Первомайская	0103000020E61000000100000005000000C8B3CBB73E384440BE88B663EA4A4640C8B3CBB73E384440AD889AE8F3514640A6BA8097193E4440AD889AE8F3514640A6BA8097193E4440BE88B663EA4A4640C8B3CBB73E384440BE88B663EA4A4640
9927	16433	40.818629000000001	40.878610000000002	44.264806	44.204431	Ленина	0103000020E610000001000000050000005247C7D5C8684440F0A485CB2A1A46405247C7D5C86844406DE4BA29E521464023F8DF4A767044406DE4BA29E521464023F8DF4A76704440F0A485CB2A1A46405247C7D5C8684440F0A485CB2A1A4640
23462	50724	40.480547999999999	40.525562999999998	44.375441000000002	44.343384999999998	улица Красная	0103000020E610000001000000050000004014CC98823D4440EE77280AF42B46404014CC98823D4440ED4960730E3046406B7EFCA545434440ED4960730E3046406B7EFCA545434440EE77280AF42B46404014CC98823D4440EE77280AF42B4640
22579	17382	40.492342999999998	40.526389000000002	44.756027000000003	44.728893999999997	Ленина	0103000020E610000001000000050000000FB56D18053F444014200A664C5D46400FB56D18053F44404EF2237EC5604640B1FCF9B6604344404EF2237EC5604640B1FCF9B66043444014200A664C5D46400FB56D18053F444014200A664C5D4640
20588	16768	40.589207999999999	40.602764000000001	44.147731999999998	44.127702999999997	Клубная	0103000020E610000001000000050000005245F12A6B4B4440F04C6892581046405245F12A6B4B44404D49D6E1E8124640639AE95E274D44404D49D6E1E8124640639AE95E274D4440F04C6892581046405245F12A6B4B4440F04C689258104640
22528	16397	40.854453999999997	40.893763999999997	44.061869000000002	44.024481000000002	Калинина	0103000020E61000000100000005000000DBF7A8BF5E6D4440CB2F833122034640DBF7A8BF5E6D444070D1C952EB074640CB2BD7DB6672444070D1C952EB074640CB2BD7DB66724440CB2F833122034640DBF7A8BF5E6D4440CB2F833122034640
22791	50565	40.501766000000003	40.530054	44.713869000000003	44.659948	Дубовая	0103000020E61000000100000005000000541F48DE39404440C287122D79544640541F48DE394044406A50340F605B4640978E39CFD84344406A50340F605B4640978E39CFD8434440C287122D79544640541F48DE39404440C287122D79544640
23566	50770	40.532128999999998	40.582093999999998	44.638157999999997	44.627068000000001	Комарова	0103000020E61000000100000005000000682096CD1C4444401F2FA4C343504640682096CD1C44444023D74D29AF5146405299620E824A444023D74D29AF5146405299620E824A44401F2FA4C343504640682096CD1C4444401F2FA4C343504640
23694	50809	40.871926000000002	40.888984999999998	44.300725	44.285252999999997	Коммунаров	0103000020E610000001000000050000001C446B459B6F4440FE0A992B832446401C446B459B6F4440780B24287E26464039D1AE42CA714440780B24287E26464039D1AE42CA714440FE0A992B832446401C446B459B6F4440FE0A992B83244640
22046	15931	40.763347000000003	40.844222000000002	44.187964000000001	44.083914999999998	Советская	0103000020E61000000100000005000000F73FC05AB561444069520ABABD0A4640F73FC05AB5614440A56950340F18464028486C770F6C4440A56950340F18464028486C770F6C444069520ABABD0A4640F73FC05AB561444069520ABABD0A4640
20467	15931	40.763347000000003	40.844222000000002	44.187964000000001	44.083914999999998	Мостовая	0103000020E61000000100000005000000F73FC05AB561444069520ABABD0A4640F73FC05AB5614440A56950340F18464028486C770F6C4440A56950340F18464028486C770F6C444069520ABABD0A4640F73FC05AB561444069520ABABD0A4640
21239	15931	40.763347000000003	40.844222000000002	44.187964000000001	44.083914999999998	Маяковского	0103000020E61000000100000005000000F73FC05AB561444069520ABABD0A4640F73FC05AB5614440A56950340F18464028486C770F6C4440A56950340F18464028486C770F6C444069520ABABD0A4640F73FC05AB561444069520ABABD0A4640
22037	15931	40.763347000000003	40.844222000000002	44.187964000000001	44.083914999999998	Ленина	0103000020E61000000100000005000000F73FC05AB561444069520ABABD0A4640F73FC05AB5614440A56950340F18464028486C770F6C4440A56950340F18464028486C770F6C444069520ABABD0A4640F73FC05AB561444069520ABABD0A4640
21448	15931	40.763347000000003	40.844222000000002	44.187964000000001	44.083914999999998	Главная	0103000020E61000000100000005000000F73FC05AB561444069520ABABD0A4640F73FC05AB5614440A56950340F18464028486C770F6C4440A56950340F18464028486C770F6C444069520ABABD0A4640F73FC05AB561444069520ABABD0A4640
23363	45348	40.699970999999998	40.714666999999999	44.364421999999998	44.351022999999998	Школьная	0103000020E61000000100000005000000FF9254A69859444068925852EE2C4640FF9254A698594440B1F84D61A52E4640E54350357A5B4440B1F84D61A52E4640E54350357A5B444068925852EE2C4640FF9254A69859444068925852EE2C4640
20471	45348	40.699970999999998	40.714666999999999	44.364421999999998	44.351022999999998	Центральная	0103000020E61000000100000005000000FF9254A69859444068925852EE2C4640FF9254A698594440B1F84D61A52E4640E54350357A5B4440B1F84D61A52E4640E54350357A5B444068925852EE2C4640FF9254A69859444068925852EE2C4640
23570	50773	40.751227999999998	40.790331999999999	44.354638999999999	44.315173999999999	Красная	0103000020E6100000010000000500000074EB353D286044405646239F5728464074EB353D286044406D718DCF642D4640BB7D5699296544406D718DCF642D4640BB7D5699296544405646239F5728464074EB353D286044405646239F57284640
21048	16288	40.743754000000003	40.771808999999998	44.061176000000003	44.040294000000003	Садовая	0103000020E610000001000000050000007522C154335F4440CE1C925A280546407522C154335F44406AA67B9DD407464015E126A3CA6244406AA67B9DD407464015E126A3CA624440CE1C925A280546407522C154335F4440CE1C925A28054640
23559	50341	40.735776999999999	40.743071999999998	44.388654000000002	44.376491000000001	Мостовая	0103000020E610000001000000050000001213D4F02D5E4440821E6ADB303046401213D4F02D5E4440D4BA0D6ABF3146406249B9FB1C5F4440D4BA0D6ABF3146406249B9FB1C5F4440821E6ADB303046401213D4F02D5E4440821E6ADB30304640
21214	50341	40.735776999999999	40.743071999999998	44.388654000000002	44.376491000000001	Комсомольская	0103000020E610000001000000050000001213D4F02D5E4440821E6ADB303046401213D4F02D5E4440D4BA0D6ABF3146406249B9FB1C5F4440D4BA0D6ABF3146406249B9FB1C5F4440821E6ADB303046401213D4F02D5E4440821E6ADB30304640
21227	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	мкр. Энергетиков	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
20692	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Советская	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
21348	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Садовая	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
21449	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Мичурина	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
21535	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Ленина	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
21037	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Красная	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
20460	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Комарова	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
21140	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Горького	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
21803	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Буденного	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
21663	15327	40.767245000000003	40.817821000000002	44.429724	44.387520000000002	Боженко	0103000020E6100000010000000500000080828B1535624440E1455F419A31464080828B153562444035272F3201374640B37DC85BAE68444035272F3201374640B37DC85BAE684440E1455F419A31464080828B1535624440E1455F419A314640
24003	50892	40.424565000000001	40.462823999999998	44.572243999999998	44.535117999999997	Советская	0103000020E610000001000000050000005C035B25583644401EC022BF7E4446405C035B255836444086AA984A3F494640E6E61BD13D3B444086AA984A3F494640E6E61BD13D3B44401EC022BF7E4446405C035B25583644401EC022BF7E444640
23599	50787	40.563454	40.584088000000001	44.623756999999998	44.583596	Советская	0103000020E610000001000000050000007366BB421F484440C8091346B34A46407366BB421F48444056D3F544D74F464037FE4465C34A444056D3F544D74F464037FE4465C34A4440C8091346B34A46407366BB421F484440C8091346B34A4640
23879	50852	40.565007999999999	40.606994999999998	44.545532000000001	44.492341000000003	Ленина	0103000020E610000001000000050000003BFDA02E524844406FBDA607053F46403BFDA02E52484440F37519FED3454640F2EA1C03B24D4440F37519FED3454640F2EA1C03B24D44406FBDA607053F46403BFDA02E524844406FBDA607053F4640
23812	50833	40.590088999999999	40.666338000000003	44.327485000000003	44.302925000000002	Мира	0103000020E610000001000000050000005B5D4E09884B44400612143FC62646405B5D4E09884B44401D774A07EB294640810A47904A5544401D774A07EB294640810A47904A5544400612143FC62646405B5D4E09884B44400612143FC6264640
23373	47071	40.736739	40.744069000000003	44.374268000000001	44.368017999999999	Кузнечная	0103000020E610000001000000050000000858AB764D5E44406F2BBD361B2F46400858AB764D5E44403CF88903E82F4640D57B2AA73D5F44403CF88903E82F4640D57B2AA73D5F44406F2BBD361B2F46400858AB764D5E44406F2BBD361B2F4640
20842	17007	40.60183	40.630215999999997	44.601742000000002	44.579473999999998	Ленина	0103000020E6100000010000000500000037E0F3C3084D4440EF703B342C4A464037E0F3C3084D44409850C1E1054D46403DB5FAEAAA5044409850C1E1054D46403DB5FAEAAA504440EF703B342C4A464037E0F3C3084D4440EF703B342C4A4640
23382	50683	40.681635999999997	40.753762000000002	44.248362	44.214866000000001	Первомайская	0103000020E610000001000000050000005CE333D93F574440DC82A5BA801B46405CE333D93F574440DAC87553CA1F4640D97BF1457B604440DAC87553CA1F4640D97BF1457B604440DC82A5BA801B46405CE333D93F574440DC82A5BA801B4640
21055	16654	40.657076000000004	40.698830000000001	44.435105	44.405965999999999	Красная	0103000020E61000000100000005000000467EFD101B544440DBA4A2B1F6334640467EFD101B544440BDA94885B13746405ABBED4273594440BDA94885B13746405ABBED4273594440DBA4A2B1F6334640467EFD101B544440DBA4A2B1F6334640
23529	50752	40.495927000000002	40.549565999999999	44.301130999999998	44.278509	Школьная	0103000020E61000000100000005000000091A33897A3F44402252D32EA6234640091A33897A3F4440E867EA758B2646402C7FBE2D58464440E867EA758B2646402C7FBE2D584644402252D32EA6234640091A33897A3F44402252D32EA6234640
23775	50826	40.576873999999997	40.625625999999997	44.192985999999998	44.153494999999999	 Клубная	0103000020E61000000100000005000000D3F4D901D7494440BD8C62B9A5134640D3F4D901D7494440FD4AE7C3B31846407EC3448314504440FD4AE7C3B31846407EC3448314504440BD8C62B9A5134640D3F4D901D7494440BD8C62B9A5134640
23628	50794	40.812151999999998	40.846916999999998	44.143948000000002	44.111493000000003	Советская улица	0103000020E61000000100000005000000C4B0C398F4674440D15D1267450E4640C4B0C398F46744408D2958E36C12464095B6B8C6676C44408D2958E36C12464095B6B8C6676C4440D15D1267450E4640C4B0C398F4674440D15D1267450E4640
21371	14667	39.259118000000001	39.274281000000002	46.241332999999997	46.230026000000002	Школьная	0103000020E6100000010000000500000008E753C72AA14340679DF17D711D474008E753C72AA143400839EFFFE31E47400475CAA31BA343400839EFFFE31E47400475CAA31BA34340679DF17D711D474008E753C72AA14340679DF17D711D4740
21032	15176	39.537703	39.567186	46.113357999999998	46.100599000000003	Школьная	0103000020E6100000010000000500000005FBAF73D3C443405281936DE00C474005FBAF73D3C44340B75ED383820E4740E15F048D99C84340B75ED383820E4740E15F048D99C843405281936DE00C474005FBAF73D3C443405281936DE00C4740
21219	14966	39.398553999999997	39.439211999999998	46.117525000000001	46.091436999999999	Советов	0103000020E6100000010000000500000051D845D103B343407A522635B40B474051D845D103B3434030BB270F0B0F474060014C1938B8434030BB270F0B0F474060014C1938B843407A522635B40B474051D845D103B343407A522635B40B4740
22001	14966	39.398553999999997	39.439211999999998	46.117525000000001	46.091436999999999	Ленина	0103000020E6100000010000000500000051D845D103B343407A522635B40B474051D845D103B3434030BB270F0B0F474060014C1938B8434030BB270F0B0F474060014C1938B843407A522635B40B474051D845D103B343407A522635B40B4740
23352	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	улица Западная	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
23803	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Энергетиков	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
22977	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Школьная	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
20530	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Шевченко 	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
22987	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Чернышевского	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
23756	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Терновая	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
23209	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Пролетарская	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
20695	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Красная	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
20763	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Кооперации	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
23788	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	Заводская	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
23993	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	20-й Горнострелковой Дивизии	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
23425	49148	39.347816999999999	39.433948000000001	46.346767999999997	46.291485999999999	 Школьная	0103000020E6100000010000000500000015FF774485AC4340F59ECA694F25474015FF774485AC434050A6D1E4622C47401215AA9B8BB7434050A6D1E4622C47401215AA9B8BB74340F59ECA694F25474015FF774485AC4340F59ECA694F254740
23841	50841	39.523555000000002	39.590102000000002	46.346899000000001	46.334958999999998	Красная	0103000020E610000001000000050000002254A9D903C343401C40BFEFDF2A47402254A9D903C34340EF01BA2F672C4740F0A65B7688CB4340EF01BA2F672C4740F0A65B7688CB43401C40BFEFDF2A47402254A9D903C343401C40BFEFDF2A4740
20493	50252	39.278261000000001	39.335006999999997	46.127825000000001	46.089892999999996	Шевченко	0103000020E610000001000000050000004A60730E9EA34340D591239D810B47404A60730E9EA343403C4ED1915C1047402D776682E1AA43403C4ED1915C1047402D776682E1AA4340D591239D810B47404A60730E9EA34340D591239D810B4740
23285	50661	39.487217999999999	39.494619999999998	46.178455999999997	46.169857	Дружная	0103000020E61000000100000005000000E202D0285DBE434093FFC9DFBD154740E202D0285DBE434032E36DA5D716474048F949B54FBF434032E36DA5D716474048F949B54FBF434093FFC9DFBD154740E202D0285DBE434093FFC9DFBD154740
23737	50817	39.190818999999998	39.301248999999999	46.055931000000001	46.007702999999999	Ленина	0103000020E610000001000000050000004B3ACAC16C984340618A7269FC0047404B3ACAC16C98434092EA3BBF28074740F279C5538FA6434092EA3BBF28074740F279C5538FA64340618A7269FC0047404B3ACAC16C984340618A7269FC004740
21634	14761	39.357771	39.378495000000001	46.197273000000003	46.184297000000001	Механическая	0103000020E61000000100000005000000863AAC70CBAD43401EE0490B97174740863AAC70CBAD434021B1DD3D401947408A592F8672B0434021B1DD3D401947408A592F8672B043401EE0490B97174740863AAC70CBAD43401EE0490B97174740
21494	46545	39.284818999999999	39.329194999999999	46.406374999999997	46.384124	Центральная	0103000020E61000000100000005000000C423F1F274A44340EACDA8F92A314740C423F1F274A44340BC74931804344740DC80CF0F23AA4340BC74931804344740DC80CF0F23AA4340EACDA8F92A314740C423F1F274A44340EACDA8F92A314740
20501	21044	39.571193000000001	39.581685	46.125594999999997	46.120984999999997	Центральная	0103000020E61000000100000005000000215A2BDA1CC943403D27BD6F7C0F4740215A2BDA1CC9434043C5387F1310474071C971A774CA434043C5387F1310474071C971A774CA43403D27BD6F7C0F4740215A2BDA1CC943403D27BD6F7C0F4740
23746	50821	39.519593	39.530920999999999	46.274737999999999	46.264415	Юбилейная	0103000020E61000000100000005000000821DFF0582C2434032C9C859D8214740821DFF0582C24340F67B629D2A2347403BE12538F5C34340F67B629D2A2347403BE12538F5C3434032C9C859D8214740821DFF0582C2434032C9C859D8214740
21028	15108	39.557887999999998	39.621723000000003	46.251005999999997	46.238197999999997	Красная	0103000020E61000000100000005000000596ABDDF68C743407EFCA5457D1E4740596ABDDF68C74340C58CF0F620204740E415889E94CF4340C58CF0F620204740E415889E94CF43407EFCA5457D1E4740596ABDDF68C743407EFCA5457D1E4740
21471	50378	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	Убыхская	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
23904	50861	39.255820999999997	39.287855	43.967056999999997	43.949866999999998	Туристская	0103000020E61000000100000005000000A45016BEBEA043405A46EA3D95F94540A45016BEBEA04340162F1686C8FB4540BB7EC16ED8A44340162F1686C8FB4540BB7EC16ED8A443405A46EA3D95F94540A45016BEBEA043405A46EA3D95F94540
22409	50502	40.703527999999999	40.835329000000002	44.609045000000002	44.514817000000001	Телефонная	0103000020E61000000100000005000000FFE89B340D5A444061360186E5414640FFE89B340D5A44406B65C22FF54D46404033880FEC6A44406B65C22FF54D46404033880FEC6A444061360186E5414640FFE89B340D5A444061360186E5414640
23889	50857	40.940755000000003	40.970759000000001	44.24689	44.226469000000002	Советская	0103000020E610000001000000050000003546EBA86A7844406747AAEFFC1C46403546EBA86A784440CFDA6D179A1F46401AA6B6D4417C4440CFDA6D179A1F46401AA6B6D4417C44406747AAEFFC1C46403546EBA86A7844406747AAEFFC1C4640
20549	12231	40.840386000000002	40.902092000000003	44.733108000000001	44.687601000000001	Центральная	0103000020E610000001000000050000001502B9C4916B444034D93F4F035846401502B9C4916B4440CE37A27BD65D4640DBFD2AC077734440CE37A27BD65D4640DBFD2AC07773444034D93F4F035846401502B9C4916B444034D93F4F03584640
21901	12231	40.840386000000002	40.902092000000003	44.733108000000001	44.687601000000001	Ленина	0103000020E610000001000000050000001502B9C4916B444034D93F4F035846401502B9C4916B4440CE37A27BD65D4640DBFD2AC077734440CE37A27BD65D4640DBFD2AC07773444034D93F4F035846401502B9C4916B444034D93F4F03584640
20557	12231	40.840386000000002	40.902092000000003	44.733108000000001	44.687601000000001	Кооперативная	0103000020E610000001000000050000001502B9C4916B444034D93F4F035846401502B9C4916B4440CE37A27BD65D4640DBFD2AC077734440CE37A27BD65D4640DBFD2AC07773444034D93F4F035846401502B9C4916B444034D93F4F03584640
23866	50849	41.138654000000002	41.156098999999998	44.494579000000002	44.457138999999998	Советская	0103000020E61000000100000005000000D4BA0D6ABF914440F25CDF87833A4640D4BA0D6ABF914440EA245B5D4E3F46401AF8510DFB934440EA245B5D4E3F46401AF8510DFB934440F25CDF87833A4640D4BA0D6ABF914440F25CDF87833A4640
21921	13471	40.999378999999998	41.046666000000002	44.431306999999997	44.355013	Ленина	0103000020E6100000010000000500000093A7ACA6EB7F4440D253E410712D464093A7ACA6EB7F444097C4591135374640E6EAC726F985444097C4591135374640E6EAC726F9854440D253E410712D464093A7ACA6EB7F4440D253E410712D4640
22964	13471	40.999378999999998	41.046666000000002	44.431306999999997	44.355013	 Набережная	0103000020E6100000010000000500000093A7ACA6EB7F4440D253E410712D464093A7ACA6EB7F444097C4591135374640E6EAC726F985444097C4591135374640E6EAC726F9854440D253E410712D464093A7ACA6EB7F4440D253E410712D4640
21011	50311	40.936262999999997	40.960428	44.654209999999999	44.639921999999999	Школьная	0103000020E6100000010000000500000038BA4A77D7774440D6FECEF6E851464038BA4A77D7774440AB5B3D27BD534640D314014EEF7A4440AB5B3D27BD534640D314014EEF7A4440D6FECEF6E851464038BA4A77D7774440D6FECEF6E8514640
22763	50554	41.023122000000001	41.044500999999997	44.475845999999997	44.448787000000003	Ленина	0103000020E61000000100000005000000B8E864A9F58244405BEF37DA71394640B8E864A9F582444059F78F85E83C4640D4D17135B285444059F78F85E83C4640D4D17135B28544405BEF37DA71394640B8E864A9F58244405BEF37DA71394640
22620	13410	41.023822000000003	41.043145000000003	44.497942000000002	44.474502000000001	Парковая	0103000020E6100000010000000500000071766B990C8344407CF1457BBC3C464071766B990C83444005A73E90BC3F464033FE7DC68585444005A73E90BC3F464033FE7DC6858544407CF1457BBC3C464071766B990C8344407CF1457BBC3C4640
21897	50442	41.037486000000001	41.049064999999999	44.717711999999999	44.700544000000001	Садовая	0103000020E6100000010000000500000068075C57CC8444405BB4006DAB59464068075C57CC8444402FF99FFCDD5B46406A300DC3478644402FF99FFCDD5B46406A300DC3478644405BB4006DAB59464068075C57CC8444405BB4006DAB594640
23516	50745	41.057409999999997	41.110275999999999	44.665557999999997	44.627952999999998	Мира	0103000020E610000001000000050000004F3BFC355987444069368FC3605046404F3BFC3559874440ABCB29013155464050C422861D8E4440ABCB29013155464050C422861D8E444069368FC3605046404F3BFC355987444069368FC360504640
20517	49013	41.008434000000001	41.081225000000003	44.260978000000001	44.221390999999997	Ленина	0103000020E610000001000000050000005516855D148144407A50508A561C46405516855D14814440DD7C23BA672146400E4FAF94658A4440DD7C23BA672146400E4FAF94658A44407A50508A561C46405516855D148144407A50508A561C4640
23562	50769	41.002954000000003	41.015019000000002	44.330142000000002	44.309117000000001	Первомайская	0103000020E610000001000000050000003AB2F2CB608044409ED15625912746403AB2F2CB608044409D84D217422A4640C9E88024EC8144409D84D217422A4640C9E88024EC8144409ED15625912746403AB2F2CB608044409ED1562591274640
21824	50385	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Школьная	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21872	50385	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Центральная	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21550	50385	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Леонтьева	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21529	50385	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Калинина	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21603	50385	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Воровского	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21789	50385	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Армавирское шоссе	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21376	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Селиверстова	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21119	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Победы	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
20502	8663	40.771152999999998	40.785876000000002	44.584308	44.572615999999996	Мира	0103000020E610000001000000050000002C9B3924B56244404A95287B4B4946402C9B3924B56244404565C39ACA4A46400C5BB395976444404565C39ACA4A46400C5BB395976444404A95287B4B4946402C9B3924B56244404A95287B4B494640
21378	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Международная	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
20919	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Маркса	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
20734	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Красная	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
9930	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Коммунаров	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21370	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Делегатская	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
20932	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Д.Бедного	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
20955	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Военная	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21278	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	Владимирская	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21315	8663	40.672150000000002	40.774144	44.699204999999999	44.583429000000002	40 лет Октября	0103000020E61000000100000005000000D200DE0209564440DD442DCDAD4A4640D200DE02095644408F19A88C7F59464083328D26176344408F19A88C7F59464083328D2617634440DD442DCDAD4A4640D200DE0209564440DD442DCDAD4A4640
21429	12981	40.880586000000001	40.932931000000004	44.323093999999998	44.287652999999999	Ленина	0103000020E6100000010000000500000061A8C30AB770444053CC41D0D124464061A8C30AB770444054C4E9245B294640593673486A77444054C4E9245B294640593673486A77444053CC41D0D124464061A8C30AB770444053CC41D0D1244640
20770	12955	40.795974000000001	40.833739000000001	44.453265999999999	44.411279	Советская	0103000020E61000000100000005000000B03BDD79E26544400B444FCAA4344640B03BDD79E2654440C231CB9E043A46402B33A5F5B76A4440C231CB9E043A46402B33A5F5B76A44400B444FCAA4344640B03BDD79E26544400B444FCAA4344640
21938	48885	40.987170999999996	41.019500999999998	44.611015000000002	44.580880000000001	Ленина	0103000020E61000000100000005000000A1478C9E5B7E444043739D465A4A4640A1478C9E5B7E4440C72E51BD354E4640A19E3E027F824440C72E51BD354E4640A19E3E027F82444043739D465A4A4640A1478C9E5B7E444043739D465A4A4640
22370	49033	40.952711999999998	40.995291999999999	44.272190000000002	44.229937	Ленина	0103000020E61000000100000005000000DD408177F2794440F7915B936E1D4640DD408177F27944402D26361FD722464037FC6EBA657F44402D26361FD722464037FC6EBA657F4440F7915B936E1D4640DD408177F2794440F7915B936E1D4640
21458	48795	41.002433000000003	41.060859999999998	44.583069000000002	44.512341999999997	Мира	0103000020E6100000010000000500000031B77BB94F804440012F336C9441464031B77BB94F804440DD274701A24A464039D1AE42CA874440DD274701A24A464039D1AE42CA874440012F336C9441464031B77BB94F804440012F336C94414640
21282	48795	41.002433000000003	41.060859999999998	44.583069000000002	44.512341999999997	Калмыкова	0103000020E6100000010000000500000031B77BB94F804440012F336C9441464031B77BB94F804440DD274701A24A464039D1AE42CA874440DD274701A24A464039D1AE42CA874440012F336C9441464031B77BB94F804440012F336C94414640
20798	48795	41.002433000000003	41.060859999999998	44.583069000000002	44.512341999999997	50 лет Октября	0103000020E6100000010000000500000031B77BB94F804440012F336C9441464031B77BB94F804440DD274701A24A464039D1AE42CA874440DD274701A24A464039D1AE42CA874440012F336C9441464031B77BB94F804440012F336C94414640
20478	50251	40.768880000000003	40.847239999999999	44.574227999999998	44.521867	Чапаева	0103000020E610000001000000050000003546EBA86A6244404AEEB089CC4246403546EBA86A6244404739984D8049464078EE3D5C726C44404739984D8049464078EE3D5C726C44404AEEB089CC4246403546EBA86A6244404AEEB089CC424640
20962	50251	40.768880000000003	40.847239999999999	44.574227999999998	44.521867	Телефонная	0103000020E610000001000000050000003546EBA86A6244404AEEB089CC4246403546EBA86A6244404739984D8049464078EE3D5C726C44404739984D8049464078EE3D5C726C44404AEEB089CC4246403546EBA86A6244404AEEB089CC424640
21575	50251	40.768880000000003	40.847239999999999	44.574227999999998	44.521867	Гагарина	0103000020E610000001000000050000003546EBA86A6244404AEEB089CC4246403546EBA86A6244404739984D8049464078EE3D5C726C44404739984D8049464078EE3D5C726C44404AEEB089CC4246403546EBA86A6244404AEEB089CC424640
23390	50686	40.898623999999998	40.924163	44.484521999999998	44.469748000000003	Почтовая	0103000020E610000001000000050000004AB3791C0673444043AED4B3203C46404AB3791C06734440A41820D1043E46402D9622F94A764440A41820D1043E46402D9622F94A76444043AED4B3203C46404AB3791C0673444043AED4B3203C4640
21006	12373	41.036821000000003	41.066932000000001	44.178953	44.120869999999996	Краснопартизанская	0103000020E610000001000000050000002C67EF8CB6844440A4880CAB780F46402C67EF8CB6844440B34291EEE716464027874F3A91884440B34291EEE716464027874F3A91884440A4880CAB780F46402C67EF8CB6844440A4880CAB780F4640
20643	11046	39.329815000000004	39.392634000000001	46.610754999999997	46.563326000000004	Ленина	0103000020E61000000100000005000000795DBF6037AA4340467EFD101B484740795DBF6037AA43402A6F47382D4E47401AA6B6D441B243402A6F47382D4E47401AA6B6D441B24340467EFD101B484740795DBF6037AA4340467EFD101B484740
21337	11003	39.484146000000003	39.545077999999997	46.766125000000002	46.751086000000001	Комсомольская	0103000020E610000001000000050000009F3E027FF8BD4340E23D0796236047409F3E027FF8BD4340F2D24D621062474071E2AB1DC5C54340F2D24D621062474071E2AB1DC5C54340E23D0796236047409F3E027FF8BD4340E23D079623604740
20646	9478	39.662255000000002	39.691099999999999	46.658425999999999	46.642057999999999	Школьная	0103000020E61000000100000005000000664E97C5C4D443404D11E0F42E524740664E97C5C4D44340056B9C4D47544740FF21FDF675D84340056B9C4D47544740FF21FDF675D843404D11E0F42E524740664E97C5C4D443404D11E0F42E524740
21772	10777	39.289876	39.502265000000001	46.753203999999997	46.721421999999997	Красная	0103000020E6100000010000000500000099F221A81AA54340B54E5C8E575C474099F221A81AA54340B29B19FD68604740757632384AC04340B29B19FD68604740757632384AC04340B54E5C8E575C474099F221A81AA54340B54E5C8E575C4740
21705	50414	39.289876	39.502265000000001	46.753203999999997	46.721421999999997	Октябрьская	0103000020E6100000010000000500000099F221A81AA54340B54E5C8E575C474099F221A81AA54340B29B19FD68604740757632384AC04340B29B19FD68604740757632384AC04340B54E5C8E575C474099F221A81AA54340B54E5C8E575C4740
21723	9427	39.552292000000001	39.590327000000002	46.681628000000003	46.670355999999998	 Школьная	0103000020E61000000100000005000000D5EB1681B1C64340B456B439CE554740D5EB1681B1C64340DA0418963F5747401079CBD58FCB4340DA0418963F5747401079CBD58FCB4340B456B439CE554740D5EB1681B1C64340B456B439CE554740
20648	9529	39.722513999999997	39.744746999999997	46.626396	46.617353999999999	Мира	0103000020E610000001000000050000007973B8567BDC43400307B474054F47407973B8567BDC4340302C7FBE2D504740A565A4DE53DF4340302C7FBE2D504740A565A4DE53DF43400307B474054F47407973B8567BDC43400307B474054F4740
22200	9688	39.998485000000002	40.011538000000002	46.613033000000001	46.606631999999998	Центральная	0103000020E61000000100000005000000F645425BCEFF4340815A0C1EA64D4740F645425BCEFF4340342F87DD774E4740A454C2137A014440342F87DD774E4740A454C2137A014440815A0C1EA64D4740F645425BCEFF4340815A0C1EA64D4740
21100	10461	39.650621999999998	39.676574000000002	46.714848000000003	46.703200000000002	Красная	0103000020E610000001000000050000007007EA9447D343400B462575025A47407007EA9447D3434036CEA623805B474076A911FA99D6434036CEA623805B474076A911FA99D643400B462575025A47407007EA9447D343400B462575025A4740
23826	50765	39.528441999999998	39.548259000000002	46.394449000000002	46.387929	Школьная	0103000020E610000001000000050000009AEAC9FCA3C34340C21550A8A73147409AEAC9FCA3C343404F78094E7D3247406C5ED5592DC643404F78094E7D3247406C5ED5592DC64340C21550A8A73147409AEAC9FCA3C34340C21550A8A7314740
23556	50765	39.528441999999998	39.548259000000002	46.394449000000002	46.387929	Центральная	0103000020E610000001000000050000009AEAC9FCA3C34340C21550A8A73147409AEAC9FCA3C343404F78094E7D3247406C5ED5592DC643404F78094E7D3247406C5ED5592DC64340C21550A8A73147409AEAC9FCA3C34340C21550A8A7314740
22630	10440	40.003658999999999	40.038927000000001	46.733170999999999	46.726716000000003	Трудовая	0103000020E6100000010000000500000004ABEAE5770044406FBDA607055D474004ABEAE57700444014B01D8CD85D474038F7578FFB04444014B01D8CD85D474038F7578FFB0444406FBDA607055D474004ABEAE5770044406FBDA607055D4740
21313	10274	39.562569000000003	39.582089000000003	46.482128000000003	46.471775999999998	Советская	0103000020E61000000100000005000000295FD04202C84340D384ED27633C4740295FD04202C84340323ECC5EB63D4740412E71E481CA4340323ECC5EB63D4740412E71E481CA4340D384ED27633C4740295FD04202C84340D384ED27633C4740
23607	10274	39.562569000000003	39.582089000000003	46.482128000000003	46.471775999999998	Первомайская	0103000020E61000000100000005000000295FD04202C84340D384ED27633C4740295FD04202C84340323ECC5EB63D4740412E71E481CA4340323ECC5EB63D4740412E71E481CA4340D384ED27633C4740295FD04202C84340D384ED27633C4740
21067	10138	39.756765999999999	39.861043000000002	46.563412999999997	46.532913999999998	Школьная	0103000020E61000000100000005000000C45C52B5DDE043404FCAA48636444740C45C52B5DDE043401492CCEA1D48474091B932A836EE43401492CCEA1D48474091B932A836EE43404FCAA48636444740C45C52B5DDE043404FCAA48636444740
21084	9610	39.664949999999997	39.678199999999997	46.542757999999999	46.533887	Парковая	0103000020E61000000100000005000000D3BCE3141DD543403961C26856444740D3BCE3141DD5434039D2191879454740D712F241CFD6434039D2191879454740D712F241CFD643403961C26856444740D3BCE3141DD543403961C26856444740
21124	10931	39.429825000000001	39.453792	46.781714999999998	46.778697000000001	Центральная	0103000020E6100000010000000500000069006F8104B74340253FE257AC63474069006F8104B7434075E5B33C0F644740DD9733DB15BA434075E5B33C0F644740DD9733DB15BA4340253FE257AC63474069006F8104B74340253FE257AC634740
21297	9534	39.835908000000003	39.844900000000003	46.622298999999998	46.608271999999999	Мира	0103000020E610000001000000050000007E3B8908FFEA434048895DDBDB4D47407E3B8908FFEA4340B0AA5E7EA74F4740F931E6AE25EC4340B0AA5E7EA74F4740F931E6AE25EC434048895DDBDB4D47407E3B8908FFEA434048895DDBDB4D4740
20890	8781	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	переулок Школьный	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
20637	8781	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	переулок Кавказский	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
21478	8781	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	переулок Б.Е. Москвича	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
21071	8781	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	Элеваторная	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
21423	8781	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	Ленинградская	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
20879	8781	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	Ленина	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
21287	8781	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	Красногвардейская	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
21764	50419	39.593614000000002	39.668624000000001	46.583429000000002	46.536707999999997	Ейская	0103000020E610000001000000050000005039268BFBCB434033C005D9B24447405039268BFBCB4340DD442DCDAD4A47400DA9A27895D54340DD442DCDAD4A47400DA9A27895D5434033C005D9B24447405039268BFBCB434033C005D9B2444740
21609	50395	39.277667999999998	39.311830999999998	46.776266	46.758384	Советская	0103000020E61000000100000005000000A79201A08AA34340A3E716BA12614740A79201A08AA34340957F2DAF5C63474082700514EAA74340957F2DAF5C63474082700514EAA74340A3E716BA12614740A79201A08AA34340A3E716BA12614740
23771	50395	39.277667999999998	39.311830999999998	46.776266	46.758384	Длинная	0103000020E61000000100000005000000A79201A08AA34340A3E716BA12614740A79201A08AA34340957F2DAF5C63474082700514EAA74340957F2DAF5C63474082700514EAA74340A3E716BA12614740A79201A08AA34340A3E716BA12614740
21483	10001	39.506936000000003	39.577615000000002	46.745497999999998	46.727345999999997	переулок Советов	0103000020E6100000010000000500000021956247E3C043402E7079AC195D474021956247E3C04340E09D7C7A6C5F4740EB56CF49EFC94340E09D7C7A6C5F4740EB56CF49EFC943402E7079AC195D474021956247E3C043402E7079AC195D4740
24032	10001	39.506936000000003	39.577615000000002	46.745497999999998	46.727345999999997	Клубный переулок	0103000020E6100000010000000500000021956247E3C043402E7079AC195D474021956247E3C04340E09D7C7A6C5F4740EB56CF49EFC94340E09D7C7A6C5F4740EB56CF49EFC943402E7079AC195D474021956247E3C043402E7079AC195D4740
23448	50714	39.323338	39.403109000000001	46.666052000000001	46.651288000000001	Мира	0103000020E61000000100000005000000EBC6BB2363A943407D23BA675D534740EBC6BB2363A94340BBB722314155474094DC611399B34340BBB722314155474094DC611399B343407D23BA675D534740EBC6BB2363A943407D23BA675D534740
21488	10290	39.376105000000003	39.399982999999999	46.504815999999998	46.492266000000001	Центральная	0103000020E61000000100000005000000596E693524B0434064778192023F4740596E693524B04340AF3F89CF9D4047405DFA97A432B34340AF3F89CF9D4047405DFA97A432B3434064778192023F4740596E693524B0434064778192023F4740
20623	10238	39.939044000000003	39.950057000000001	46.534841999999998	46.525770999999999	Мира	0103000020E61000000100000005000000A5C0029832F84340B517D1764C434740A5C0029832F843407C43E1B375444740FE2AC0779BF943407C43E1B375444740FE2AC0779BF94340B517D1764C434740A5C0029832F84340B517D1764C434740
20898	9831	39.643300000000004	39.705086000000001	46.461906999999997	46.407307000000003	Красная	0103000020E6100000010000000500000027C286A757D243404837C2A22234474027C286A757D243409065C1C41F3B4740096F0F4240DA43409065C1C41F3B4740096F0F4240DA43404837C2A22234474027C286A757D243404837C2A222344740
22628	9916	39.598483000000002	39.614294000000001	46.396014999999998	46.387531000000003	Восточная	0103000020E61000000100000005000000221B48179BCC4340D597A59D9A314740221B48179BCC4340DBDC989EB03247408410902FA1CE4340DBDC989EB03247408410902FA1CE4340D597A59D9A314740221B48179BCC4340D597A59D9A314740
23554	50763	39.497629000000003	39.539059999999999	46.717998999999999	46.699838	Садовая	0103000020E6100000010000000500000046459C4EB2BF4340C03FA54A9459474046459C4EB2BF4340C5C72764E75B4740774A07EBFFC44340C5C72764E75B4740774A07EBFFC44340C03FA54A9459474046459C4EB2BF4340C03FA54A94594740
21507	9771	39.826934000000001	39.869469000000002	46.678524000000003	46.652030000000003	переулок Школьный	0103000020E61000000100000005000000A9F92AF9D8E94340650113B875534740A9F92AF9D8E943408BC6DADFD956474063F19BC24AEF43408BC6DADFD956474063F19BC24AEF4340650113B875534740A9F92AF9D8E94340650113B875534740
22149	10671	39.743651	39.760593	46.665823000000003	46.651572999999999	Нижняя	0103000020E61000000100000005000000A051BAF42FDF434072FA7ABE66534740A051BAF42FDF43405AF624B0395547408448861C5BE143405AF624B0395547408448861C5BE1434072FA7ABE66534740A051BAF42FDF434072FA7ABE66534740
23640	50799	39.782674	39.829413000000002	46.77205	46.756889999999999	улица Целинная	0103000020E61000000100000005000000FAB660A92EE44340B05582C5E1604740FAB660A92EE443403B70CE88D26247404AF086342AEA43403B70CE88D26247404AF086342AEA4340B05582C5E1604740FAB660A92EE44340B05582C5E1604740
21279	10690	39.743912000000002	39.760224999999998	46.660572000000002	46.648466999999997	Ленина	0103000020E610000001000000050000000D8D278238DF434082C476F7005347400D8D278238DF4340A053909F8D544740014D840D4FE14340A053909F8D544740014D840D4FE1434082C476F7005347400D8D278238DF434082C476F700534740
20895	9666	39.970350000000003	40.016199999999998	46.648876000000001	46.636755000000001	Братская	0103000020E6100000010000000500000039D6C56D34FC4340414816308151474039D6C56D34FC43406494675E0E534740FC1873D7120244406494675E0E534740FC1873D712024440414816308151474039D6C56D34FC43404148163081514740
20877	10533	39.580283000000001	39.692293999999997	46.736432000000001	46.720556999999999	Красная	0103000020E610000001000000050000005FB69DB646CA4340B2F336363B5C47405FB69DB646CA43402BDD5D67435E4740C79BFC169DD843402BDD5D67435E4740C79BFC169DD84340B2F336363B5C47405FB69DB646CA4340B2F336363B5C4740
20481	9373	39.553963000000003	39.603423999999997	46.646456999999998	46.640177000000001	Большелопатинская	0103000020E61000000100000005000000D7187442E8C643406153E751F1514740D7187442E8C6434098A25C1ABF5247408DCF64FF3CCD434098A25C1ABF5247408DCF64FF3CCD43406153E751F1514740D7187442E8C643406153E751F1514740
20437	10594	39.705482000000003	39.718615	46.762358999999996	46.746220000000001	Школьная	0103000020E6100000010000000500000056F5F23B4DDA434081CF0F23845F474056F5F23B4DDA4340D767CEFA9461474020B58993FBDB4340D767CEFA9461474020B58993FBDB434081CF0F23845F474056F5F23B4DDA434081CF0F23845F4740
21531	8089	40.834950999999997	40.850887999999998	44.931342999999998	44.923161	Заводская	0103000020E610000001000000050000009961A3ACDF6A4440A9F8BF232A7646409961A3ACDF6A4440E42D573F367746408847E2E5E96C4440E42D573F367746408847E2E5E96C4440A9F8BF232A7646409961A3ACDF6A4440A9F8BF232A764640
21691	8253	40.850825	40.868952999999998	44.863241000000002	44.842185999999998	Магистральная	0103000020E6100000010000000500000042CF66D5E76C4440149337C0CC6B464042CF66D5E76C44407EC85BAE7E6E46406B6116DA396F44407EC85BAE7E6E46406B6116DA396F4440149337C0CC6B464042CF66D5E76C4440149337C0CC6B4640
21524	7458	40.243447000000003	40.325839999999999	45.127930999999997	45.08522	Школьная	0103000020E6100000010000000500000098A77345291F4440897B2C7DE88A464098A77345291F44408192020B6090464044DD0720B52944408192020B6090464044DD0720B5294440897B2C7DE88A464098A77345291F4440897B2C7DE88A4640
20917	7458	40.243447000000003	40.325839999999999	45.127930999999997	45.08522	Прогонная	0103000020E6100000010000000500000098A77345291F4440897B2C7DE88A464098A77345291F44408192020B6090464044DD0720B52944408192020B6090464044DD0720B5294440897B2C7DE88A464098A77345291F4440897B2C7DE88A4640
22066	7458	40.243447000000003	40.325839999999999	45.127930999999997	45.08522	Мира	0103000020E6100000010000000500000098A77345291F4440897B2C7DE88A464098A77345291F44408192020B6090464044DD0720B52944408192020B6090464044DD0720B5294440897B2C7DE88A464098A77345291F4440897B2C7DE88A4640
20676	7458	40.243447000000003	40.325839999999999	45.127930999999997	45.08522	Ленина	0103000020E6100000010000000500000098A77345291F4440897B2C7DE88A464098A77345291F44408192020B6090464044DD0720B52944408192020B6090464044DD0720B5294440897B2C7DE88A464098A77345291F4440897B2C7DE88A4640
20678	7737	40.189188999999999	40.228192999999997	45.133431000000002	45.118029	Красная	0103000020E61000000100000005000000A8E15B5837184440637D03931B8F4640A8E15B5837184440E4A25A44149146408B16A06D351D4440E4A25A44149146408B16A06D351D4440637D03931B8F4640A8E15B5837184440637D03931B8F4640
20844	33091	40.726551999999998	40.758909000000003	44.964858999999997	44.950476000000002	Центральная	0103000020E61000000100000005000000F46BEBA7FF5C444003D19332A9794640F46BEBA7FF5C44402920ED7F807B4640EED11BEE236144402920ED7F807B4640EED11BEE2361444003D19332A9794640F46BEBA7FF5C444003D19332A9794640
21470	8486	40.641112999999997	40.686459999999997	44.787222	44.725929000000001	Первомайская	0103000020E610000001000000050000002D05A4FD0F524440E71BD13DEB5C46402D05A4FD0F5244408A58C4B0C36446408E01D9EBDD5744408A58C4B0C36446408E01D9EBDD574440E71BD13DEB5C46402D05A4FD0F524440E71BD13DEB5C4640
20911	8486	40.641112999999997	40.686459999999997	44.787222	44.725929000000001	Курганинская	0103000020E610000001000000050000002D05A4FD0F524440E71BD13DEB5C46402D05A4FD0F5244408A58C4B0C36446408E01D9EBDD5744408A58C4B0C36446408E01D9EBDD574440E71BD13DEB5C46402D05A4FD0F524440E71BD13DEB5C4640
21275	8486	40.641112999999997	40.686459999999997	44.787222	44.725929000000001	Кирова	0103000020E610000001000000050000002D05A4FD0F524440E71BD13DEB5C46402D05A4FD0F5244408A58C4B0C36446408E01D9EBDD5744408A58C4B0C36446408E01D9EBDD574440E71BD13DEB5C46402D05A4FD0F524440E71BD13DEB5C4640
23433	40310	40.413587999999997	40.495218000000001	45.101743999999997	45.059458999999997	Энгельса	0103000020E610000001000000050000004F029B73F0344440F7393E5A9C8746404F029B73F0344440384888F2058D4640FD31AD4D633F4440384888F2058D4640FD31AD4D633F4440F7393E5A9C8746404F029B73F0344440F7393E5A9C874640
23998	40310	40.413587999999997	40.495218000000001	45.101743999999997	45.059458999999997	Пролетарская	0103000020E610000001000000050000004F029B73F0344440F7393E5A9C8746404F029B73F0344440384888F2058D4640FD31AD4D633F4440384888F2058D4640FD31AD4D633F4440F7393E5A9C8746404F029B73F0344440F7393E5A9C874640
22073	40310	40.413587999999997	40.495218000000001	45.101743999999997	45.059458999999997	Победы	0103000020E610000001000000050000004F029B73F0344440F7393E5A9C8746404F029B73F0344440384888F2058D4640FD31AD4D633F4440384888F2058D4640FD31AD4D633F4440F7393E5A9C8746404F029B73F0344440F7393E5A9C874640
9782	40310	40.413587999999997	40.495218000000001	45.101743999999997	45.059458999999997	КИМ	0103000020E610000001000000050000004F029B73F0344440F7393E5A9C8746404F029B73F0344440384888F2058D4640FD31AD4D633F4440384888F2058D4640FD31AD4D633F4440F7393E5A9C8746404F029B73F0344440F7393E5A9C874640
20826	40310	40.413587999999997	40.495218000000001	45.101743999999997	45.059458999999997	Гагарина	0103000020E610000001000000050000004F029B73F0344440F7393E5A9C8746404F029B73F0344440384888F2058D4640FD31AD4D633F4440384888F2058D4640FD31AD4D633F4440F7393E5A9C8746404F029B73F0344440F7393E5A9C874640
22574	8281	40.866339000000004	40.947259000000003	44.843080999999998	44.805540000000001	50 лет ВЛКСМ	0103000020E61000000100000005000000EB1F4432E46E444057CF49EF1B674640EB1F4432E46E444082700514EA6B4640BCEB6CC83F79444082700514EA6B4640BCEB6CC83F79444057CF49EF1B674640EB1F4432E46E444057CF49EF1B674640
21233	46418	40.563884999999999	40.647337999999998	45.022385999999997	44.972174000000003	Революционная	0103000020E610000001000000050000003CDA38622D484440C1029832707C46403CDA38622D484440B2F1608BDD824640A1BAB9F8DB524440B2F1608BDD824640A1BAB9F8DB524440C1029832707C46403CDA38622D484440C1029832707C4640
20950	46418	40.563884999999999	40.647337999999998	45.022385999999997	44.972174000000003	Острецова	0103000020E610000001000000050000003CDA38622D484440C1029832707C46403CDA38622D484440B2F1608BDD824640A1BAB9F8DB524440B2F1608BDD824640A1BAB9F8DB524440C1029832707C46403CDA38622D484440C1029832707C4640
21664	46418	40.563884999999999	40.647337999999998	45.022385999999997	44.972174000000003	Октябрьская	0103000020E610000001000000050000003CDA38622D484440C1029832707C46403CDA38622D484440B2F1608BDD824640A1BAB9F8DB524440B2F1608BDD824640A1BAB9F8DB524440C1029832707C46403CDA38622D484440C1029832707C4640
21445	46418	40.563884999999999	40.647337999999998	45.022385999999997	44.972174000000003	Ленина	0103000020E610000001000000050000003CDA38622D484440C1029832707C46403CDA38622D484440B2F1608BDD824640A1BAB9F8DB524440B2F1608BDD824640A1BAB9F8DB524440C1029832707C46403CDA38622D484440C1029832707C4640
22113	46141	40.704901999999997	40.721592999999999	45.034444999999998	45.022888999999999	Мира	0103000020E6100000010000000500000047718E3A3A5A44401538D906EE82464047718E3A3A5A44405F419AB168844640E202D0285D5C44405F419AB168844640E202D0285D5C44401538D906EE82464047718E3A3A5A44401538D906EE824640
21468	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Чапаева	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20854	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Серикова	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
21273	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Розы Люксембург	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
21070	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Пушкина	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20886	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Первомайская	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20752	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Партизанская	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20473	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Луговая	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
21504	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Ленина	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20990	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Коммунистическая	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
21081	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Калинина	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20991	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Заводская	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20518	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Демьяна Бедного	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20423	5900	40.541615999999998	40.626623000000002	44.920997999999997	44.852634000000002	Бедного	0103000020E61000000100000005000000C37E4FAC5345444095BA641C236D4640C37E4FAC5345444038D73043E3754640F1F5B52E3550444038D73043E3754640F1F5B52E3550444095BA641C236D4640C37E4FAC5345444095BA641C236D4640
20593	50266	40.556697999999997	40.569203000000002	45.042712000000002	45.033425999999999	Синюхинская	0103000020E61000000100000005000000D2DF4BE141474440056B9C4D47844640D2DF4BE141474440C9923996778546407EE4D6A4DB484440C9923996778546407EE4D6A4DB484440056B9C4D47844640D2DF4BE141474440056B9C4D47844640
22310	46377	40.677377999999997	40.697940000000003	44.918788999999997	44.888030000000001	Кочубея	0103000020E61000000100000005000000D3838252B4564440F6EE8FF7AA714640D3838252B45644405776C1E09A754640FE481119565944405776C1E09A754640FE48111956594440F6EE8FF7AA714640D3838252B4564440F6EE8FF7AA714640
23473	50729	40.511459000000002	40.536073000000002	45.016098	45.000535999999997	Коммунаров	0103000020E61000000100000005000000581F0F7D774144403E3C4B9011804640581F0F7D77414440F8C3CF7F0F82464062A2410A9E444440F8C3CF7F0F82464062A2410A9E4444403E3C4B9011804640581F0F7D774144403E3C4B9011804640
21261	8110	40.782831000000002	40.795470000000002	44.941276999999999	44.934814000000003	Северная	0103000020E61000000100000005000000C2A563CE33644440E6EB32FCA7774640C2A563CE336444400EBDC5C37B7846407D7901F6D16544400EBDC5C37B7846407D7901F6D1654440E6EB32FCA7774640C2A563CE33644440E6EB32FCA7774640
20858	47115	40.713417999999997	40.740583000000001	44.858173999999998	44.814480000000003	Кирова	0103000020E610000001000000050000005930F147515B4440809F71E1406846405930F147515B4440852348A5D86D46409E7C7A6CCB5E4440852348A5D86D46409E7C7A6CCB5E4440809F71E1406846405930F147515B4440809F71E140684640
23815	47115	40.713417999999997	40.740583000000001	44.858173999999998	44.814480000000003	Калинина	0103000020E610000001000000050000005930F147515B4440809F71E1406846405930F147515B4440852348A5D86D46409E7C7A6CCB5E4440852348A5D86D46409E7C7A6CCB5E4440809F71E1406846405930F147515B4440809F71E140684640
20930	7678	40.125660000000003	40.162588999999997	45.135891999999998	45.119453999999998	Советская	0103000020E610000001000000050000002B357BA0151044402DB0C7444A8F46402B357BA015104440DEE4B7E8649146403CD862B7CF144440DEE4B7E8649146403CD862B7CF1444402DB0C7444A8F46402B357BA0151044402DB0C7444A8F4640
23930	50867	40.836784000000002	40.852432999999998	44.955547000000003	44.946783000000003	Элеваторная	0103000020E6100000010000000500000075E8F4BC1B6B444053B4722F3079464075E8F4BC1B6B44403D65355D4F7A4640FD8348861C6D44403D65355D4F7A4640FD8348861C6D444053B4722F3079464075E8F4BC1B6B444053B4722F30794640
20852	45633	38.072901000000002	38.090975999999998	45.042068999999998	45.019728999999998	Садовая	0103000020E61000000100000005000000406CE9D15409434032E4D87A86824640406CE9D1540943407496598462854640465C001AA50B43407496598462854640465C001AA50B434032E4D87A86824640406CE9D15409434032E4D87A86824640
22396	3535	37.927680000000002	37.959516000000001	45.001454000000003	44.981814	Почтовая	0103000020E610000001000000050000009F93DE37BEF64240A260C614AC7D46409F93DE37BEF64240653909A52F8046408FFE976BD1FA4240653909A52F8046408FFE976BD1FA4240A260C614AC7D46409F93DE37BEF64240A260C614AC7D4640
21452	2395	38.021687999999997	38.039456999999999	45.004564000000002	44.991134000000002	Суворова	0103000020E610000001000000050000009A5B21ACC602434012FA997ADD7E46409A5B21ACC6024340965E9B8D95804640944C4EED0C054340965E9B8D95804640944C4EED0C05434012FA997ADD7E46409A5B21ACC602434012FA997ADD7E4640
23801	2395	38.021687999999997	38.039456999999999	45.004564000000002	44.991134000000002	Ленина	0103000020E610000001000000050000009A5B21ACC602434012FA997ADD7E46409A5B21ACC6024340965E9B8D95804640944C4EED0C054340965E9B8D95804640944C4EED0C05434012FA997ADD7E46409A5B21ACC602434012FA997ADD7E4640
20821	2395	38.021687999999997	38.039456999999999	45.004564000000002	44.991134000000002	Кирова	0103000020E610000001000000050000009A5B21ACC602434012FA997ADD7E46409A5B21ACC6024340965E9B8D95804640944C4EED0C054340965E9B8D95804640944C4EED0C05434012FA997ADD7E46409A5B21ACC602434012FA997ADD7E4640
20595	2395	38.021687999999997	38.039456999999999	45.004564000000002	44.991134000000002	Гоголя	0103000020E610000001000000050000009A5B21ACC602434012FA997ADD7E46409A5B21ACC6024340965E9B8D95804640944C4EED0C054340965E9B8D95804640944C4EED0C05434012FA997ADD7E46409A5B21ACC602434012FA997ADD7E4640
20865	45504	37.545447000000003	37.561472999999999	45.075915000000002	45.059044999999998	Школьная	0103000020E61000000100000005000000C5591135D1C5424004FF5BC98E874640C5591135D1C542404F232D95B7894640234BE658DEC742404F232D95B7894640234BE658DEC7424004FF5BC98E874640C5591135D1C5424004FF5BC98E874640
21294	45726	38.094738999999997	38.151693000000002	45.153075999999999	45.119039999999998	Советская	0103000020E61000000100000005000000EF535568200C43403A75E5B33C8F4640EF535568200C4340B8E68EFE979346401D041DAD6A134340B8E68EFE979346401D041DAD6A1343403A75E5B33C8F4640EF535568200C43403A75E5B33C8F4640
20708	45726	38.094738999999997	38.151693000000002	45.153075999999999	45.119039999999998	Пестеля	0103000020E61000000100000005000000EF535568200C43403A75E5B33C8F4640EF535568200C4340B8E68EFE979346401D041DAD6A134340B8E68EFE979346401D041DAD6A1343403A75E5B33C8F4640EF535568200C43403A75E5B33C8F4640
23403	50693	37.879620000000003	37.894936000000001	44.907331999999997	44.897205999999997	улица Школьная	0103000020E610000001000000050000002A745E6397F0424032E36DA5D77246402A745E6397F04240A04E797423744640AC014A438DF24240A04E797423744640AC014A438DF2424032E36DA5D77246402A745E6397F0424032E36DA5D7724640
20768	45601	37.82891	37.849293000000003	44.965108000000001	44.953263999999997	Высоцкой	0103000020E61000000100000005000000E7A90EB919EA4240213A048E047A4640E7A90EB919EA4240D28DB0A8887B464062DC0DA2B5EC4240D28DB0A8887B464062DC0DA2B5EC4240213A048E047A4640E7A90EB919EA4240213A048E047A4640
22152	48674	37.790928999999998	37.804834999999997	44.982534999999999	44.973972000000003	Коммунистическая	0103000020E610000001000000050000009F3A56293DE54240209C4F1DAB7C46409F3A56293DE542407216F6B4C37D46408CD651D504E742407216F6B4C37D46408CD651D504E74240209C4F1DAB7C46409F3A56293DE54240209C4F1DAB7C4640
20722	45950	37.754547000000002	37.760809000000002	45.052252000000003	45.047393	Зеленая	0103000020E61000000100000005000000C02500FF94E0424098874CF910864640C02500FF94E0424047938B31B086464051C0763062E1424047938B31B086464051C0763062E1424098874CF910864640C02500FF94E0424098874CF910864640
23578	50779	37.921965999999998	37.944631000000001	45.042126000000003	45.026597000000002	Широкая	0103000020E6100000010000000500000010035DFB02F64240FB95CE876783464010035DFB02F64240D927806264854640D6E429ABE9F84240D927806264854640D6E429ABE9F84240FB95CE876783464010035DFB02F64240FB95CE8767834640
20715	4961	38.028407999999999	38.071948999999996	44.905926999999998	44.884715999999997	Комарова	0103000020E61000000100000005000000EE7893DFA2034340BC1FB75F3E714640EE7893DFA20343401DC87A6AF57346406DFDF49F350943401DC87A6AF57346406DFDF49F35094340BC1FB75F3E714640EE7893DFA2034340BC1FB75F3E714640
23354	4961	38.028407999999999	38.071948999999996	44.905926999999998	44.884715999999997	Кирова	0103000020E61000000100000005000000EE7893DFA2034340BC1FB75F3E714640EE7893DFA20343401DC87A6AF57346406DFDF49F350943401DC87A6AF57346406DFDF49F35094340BC1FB75F3E714640EE7893DFA2034340BC1FB75F3E714640
23988	50887	38.000425	38.037489999999998	45.046526999999998	45.022092999999998	Шоссейная	0103000020E61000000100000005000000E78C28ED0D0043403A3C84F1D3824640E78C28ED0D004340C4B0C398F4854640A9F6E978CC044340C4B0C398F4854640A9F6E978CC0443403A3C84F1D3824640E78C28ED0D0043403A3C84F1D3824640
20938	45397	37.643991999999997	37.662846999999999	45.053665000000002	45.030183999999998	Новопокровская	0103000020E610000001000000050000005C7171546ED24240656EBE11DD8346405C7171546ED242404DF8A57EDE86464038A0A52BD8D442404DF8A57EDE86464038A0A52BD8D44240656EBE11DD8346405C7171546ED24240656EBE11DD834640
23928	50865	37.68862	37.694648000000001	45.043303999999999	45.038514999999997	Мира	0103000020E610000001000000050000008EAF3DB324D84240E5B33C0FEE8446408EAF3DB324D842409BE447FC8A854640AC1DC539EAD842409BE447FC8A854640AC1DC539EAD84240E5B33C0FEE8446408EAF3DB324D84240E5B33C0FEE844640
21543	4715	37.788485999999999	37.804332000000002	44.942431999999997	44.926938999999997	 Фроловой	0103000020E610000001000000050000004BADF71BEDE442408731E9EFA57646404BADF71BEDE44240185A9D9CA17846402A90D959F4E64240185A9D9CA17846402A90D959F4E642408731E9EFA57646404BADF71BEDE442408731E9EFA5764640
22020	50453	37.837587999999997	37.893543999999999	44.877333	44.856915999999998	Горького	0103000020E61000000100000005000000D2C2651536EB4240A6B5696CAF6D4640D2C2651536EB4240CD599F724C704640BDC458A65FF24240CD599F724C704640BDC458A65FF24240A6B5696CAF6D4640D2C2651536EB4240A6B5696CAF6D4640
21270	5599	37.837587999999997	37.893543999999999	44.877333	44.856915999999998	Октябрьская	0103000020E61000000100000005000000D2C2651536EB4240A6B5696CAF6D4640D2C2651536EB4240CD599F724C704640BDC458A65FF24240CD599F724C704640BDC458A65FF24240A6B5696CAF6D4640D2C2651536EB4240A6B5696CAF6D4640
23844	4224	37.733176999999998	37.742519000000001	45.056007999999999	45.051321999999999	Кубанская	0103000020E61000000100000005000000F69672BED8DD42405CC823B891864640F69672BED8DD42403D2828452B8746404ED4D2DC0ADF42403D2828452B8746404ED4D2DC0ADF42405CC823B891864640F69672BED8DD42405CC823B891864640
20856	5706	37.879548	37.911977	44.83869	44.814346	Ленина	0103000020E6100000010000000500000090A1630795F0424070D05E7D3C68464090A1630795F04240BABDA4315A6B464023DA8EA9BBF44240BABDA4315A6B464023DA8EA9BBF4424070D05E7D3C68464090A1630795F0424070D05E7D3C684640
20944	4819	37.855877	37.886699	44.954315999999999	44.935701000000002	Ленина	0103000020E610000001000000050000000533A6608DED4240D1EAE40CC57746400533A6608DED42405706D506277A4640AD32535A7FF142405706D506277A4640AD32535A7FF14240D1EAE40CC57746400533A6608DED4240D1EAE40CC5774640
20945	5252	38.189081000000002	38.214925000000001	45.162697999999999	45.145860999999996	Пролетарская	0103000020E61000000100000005000000C2A563CE331843408461C092AB924640C2A563CE33184340F38FBE49D3944640E10B93A9821B4340F38FBE49D3944640E10B93A9821B43408461C092AB924640C2A563CE331843408461C092AB924640
21459	5079	38.121400999999999	38.137768999999999	44.960095000000003	44.942157999999999	Мира	0103000020E61000000100000005000000D15966118A0F434017D522A298784640D15966118A0F4340CD069964E47A464089B3226AA2114340CD069964E47A464089B3226AA211434017D522A298784640D15966118A0F434017D522A298784640
23577	50778	37.891199	37.897820000000003	44.920563999999999	44.912450999999997	 Кирова	0103000020E610000001000000050000002C9D0FCF12F24240EB19C231CB7446402C9D0FCF12F24240FEEF880AD5754640EDD808C4EBF24240FEEF880AD5754640EDD808C4EBF24240EB19C231CB7446402C9D0FCF12F24240EB19C231CB744640
20688	5316	38.173063999999997	38.199123999999998	45.080477999999999	45.053199999999997	Зеленая	0103000020E61000000100000005000000B60E0EF626164340D712F241CF864640B60E0EF6261643401406651A4D8A4640A2EC2DE57C1943401406651A4D8A4640A2EC2DE57C194340D712F241CF864640B60E0EF626164340D712F241CF864640
21595	4110	37.665604999999999	37.683455000000002	45.097253000000002	45.070995000000003	Жукова	0103000020E61000000100000005000000EC866D8B32D54240FB96395D16894640EC866D8B32D542400D384BC9728C4640D3A414747BD742400D384BC9728C4640D3A414747BD74240FB96395D16894640EC866D8B32D54240FB96395D16894640
20452	2380	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Фурманова	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
20482	2380	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Фадеева	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21259	2380	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Свердлова	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21157	2380	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Родниковая	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21174	2380	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Луначарского	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21581	2380	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Ленина	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21176	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Энергетиков	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21850	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Привокзальная	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21184	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Луначарского	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21899	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Либкнехта	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
20989	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Ленина	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21809	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Крупской	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
20509	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Гречко	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
21359	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	Горная	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
20635	50253	37.946660999999999	38.046545000000002	44.957371999999999	44.878647999999998	50 лет Октября	0103000020E6100000010000000500000007B309302CF942401059A4897770464007B309302CF94240950D6B2A8B7A46406B65C22FF5054340950D6B2A8B7A46406B65C22FF50543401059A4897770464007B309302CF942401059A48977704640
20803	50291	38.038899999999998	38.056462000000003	44.994736000000003	44.964661999999997	Школьная	0103000020E610000001000000050000003EE8D9ACFA044340D3D85E0B7A7B46403EE8D9ACFA044340B2135E82537F4640BFBB95253A074340B2135E82537F4640BFBB95253A074340D3D85E0B7A7B46403EE8D9ACFA044340D3D85E0B7A7B4640
20787	3823	37.773484000000003	37.806192000000003	45.120319000000002	45.081108999999998	Комсомольская	0103000020E6100000010000000500000059FD118601E34240A4349BC7618A464059FD118601E34240310BED9C668F4640FF25A94C31E74240310BED9C668F4640FF25A94C31E74240A4349BC7618A464059FD118601E34240A4349BC7618A4640
21936	49498	37.867896999999999	37.908662	45.063859000000001	45.010688000000002	Красная	0103000020E61000000100000005000000F4A5B73F17EF4240D63A71395E814640F4A5B73F17EF424013471E882C884640198F52094FF4424013471E882C884640198F52094FF44240D63A71395E814640F4A5B73F17EF4240D63A71395E814640
21201	49498	37.867896999999999	37.908662	45.063859000000001	45.010688000000002	Горького	0103000020E61000000100000005000000F4A5B73F17EF4240D63A71395E814640F4A5B73F17EF424013471E882C884640198F52094FF4424013471E882C884640198F52094FF44240D63A71395E814640F4A5B73F17EF4240D63A71395E814640
21205	3741	37.807315000000003	37.838881000000001	45.076348000000003	45.050545	Гастелло	0103000020E61000000100000005000000FE48111956E74240F8FC304278864640FE48111956E74240B98E71C5C58946402E1EDE7360EB4240B98E71C5C58946402E1EDE7360EB4240F8FC304278864640FE48111956E74240F8FC304278864640
23959	50878	38.054206999999998	38.064134000000003	45.152782999999999	45.144316000000003	Светлая	0103000020E610000001000000050000006D1B4641F006434010255AF2789246406D1B4641F00643404031B2648E934640E547FC8A350843404031B2648E934640E547FC8A3508434010255AF2789246406D1B4641F006434010255AF278924640
23365	50678	38.126072999999998	38.177573000000002	45.057746999999999	45.033636000000001	Школьная	0103000020E610000001000000050000004DF4F92823104340F0FB372F4E8446404DF4F928231043409738F2406487464089D349B6BA1643409738F2406487464089D349B6BA164340F0FB372F4E8446404DF4F92823104340F0FB372F4E844640
20834	4663	37.777338	37.799832000000002	44.977555000000002	44.962040000000002	Молодежная	0103000020E6100000010000000500000012F8C3CF7FE34240D0B87020247B464012F8C3CF7FE342404985B185207D4640AB251DE560E642404985B185207D4640AB251DE560E64240D0B87020247B464012F8C3CF7FE34240D0B87020247B4640
20995	3998	37.717967999999999	37.735008999999998	44.992046000000002	44.978071999999997	Центральная	0103000020E610000001000000050000008AC91B60E6DB424010919A76317D46408AC91B60E6DB42405610035DFB7E464001A260C614DE42405610035DFB7E464001A260C614DE424010919A76317D46408AC91B60E6DB424010919A76317D4640
20998	49466	37.867780000000003	37.880868999999997	45.129978999999999	45.125413000000002	Колобова	0103000020E61000000100000005000000BB0F406A13EF424023BF7E880D904640BB0F406A13EF42405915E126A3904640B587BD50C0F042405915E126A3904640B587BD50C0F0424023BF7E880D904640BB0F406A13EF424023BF7E880D904640
20696	4280	37.603478000000003	37.671641999999999	45.137590000000003	45.098481	Пушкина	0103000020E6100000010000000500000081ED60C43ECD4240812381069B8C464081ED60C43ECD4240DA20938C9C9146405D4F745DF8D54240DA20938C9C9146405D4F745DF8D54240812381069B8C464081ED60C43ECD4240812381069B8C4640
21717	4280	37.603478000000003	37.671641999999999	45.137590000000003	45.098481	Красная	0103000020E6100000010000000500000081ED60C43ECD4240812381069B8C464081ED60C43ECD4240DA20938C9C9146405D4F745DF8D54240DA20938C9C9146405D4F745DF8D54240812381069B8C464081ED60C43ECD4240812381069B8C4640
21050	4280	37.603478000000003	37.671641999999999	45.137590000000003	45.098481	Железнодорожная	0103000020E6100000010000000500000081ED60C43ECD4240812381069B8C464081ED60C43ECD4240DA20938C9C9146405D4F745DF8D54240DA20938C9C9146405D4F745DF8D54240812381069B8C464081ED60C43ECD4240812381069B8C4640
21801	50421	37.603478000000003	37.671641999999999	45.137590000000003	45.098481	Чапаева	0103000020E6100000010000000500000081ED60C43ECD4240812381069B8C464081ED60C43ECD4240DA20938C9C9146405D4F745DF8D54240DA20938C9C9146405D4F745DF8D54240812381069B8C464081ED60C43ECD4240812381069B8C4640
22296	50421	37.603478000000003	37.671641999999999	45.137590000000003	45.098481	Советская	0103000020E6100000010000000500000081ED60C43ECD4240812381069B8C464081ED60C43ECD4240DA20938C9C9146405D4F745DF8D54240DA20938C9C9146405D4F745DF8D54240812381069B8C464081ED60C43ECD4240812381069B8C4640
20713	45687	37.984363000000002	38.003712999999998	44.868633000000003	44.849567	Миронова	0103000020E610000001000000050000003C32569BFFFD42406361889CBE6C46403C32569BFFFD4240FA9CBB5D2F6F4640F7C8E6AA79004340FA9CBB5D2F6F4640F7C8E6AA790043406361889CBE6C46403C32569BFFFD42406361889CBE6C4640
21293	4075	37.693201999999999	37.774768999999999	45.133977999999999	45.074393999999998	Ленина	0103000020E61000000100000005000000CAC2D7D7BAD8424062821ABE85894640CAC2D7D7BAD842401631EC3026914640317A6EA12BE342401631EC3026914640317A6EA12BE3424062821ABE85894640CAC2D7D7BAD8424062821ABE85894640
21546	50387	39.674650999999997	40.434195000000003	46.595480000000002	46.207191000000002	Пушкина	0103000020E610000001000000050000005A9BC6F65AD643404583143C851A47405A9BC6F65AD6434007B64AB0384C47401A8BA6B39337444007B64AB0384C47401A8BA6B3933744404583143C851A47405A9BC6F65AD643404583143C851A4740
20453	50245	39.674650999999997	40.434195000000003	46.595480000000002	46.207191000000002	Центральная	0103000020E610000001000000050000005A9BC6F65AD643404583143C851A47405A9BC6F65AD6434007B64AB0384C47401A8BA6B39337444007B64AB0384C47401A8BA6B3933744404583143C851A47405A9BC6F65AD643404583143C851A4740
20672	748	40.218474000000001	40.317055000000003	46.298023999999998	46.280966999999997	Свердликова	0103000020E610000001000000050000005E83BEF4F61B4440AB2006BAF62347405E83BEF4F61B444028B682A62526474043041C429528444028B682A62526474043041C4295284440AB2006BAF62347405E83BEF4F61B4440AB2006BAF6234740
21778	48855	39.846131	39.855787999999997	46.257860999999998	46.250433000000001	переулок Парковый	0103000020E61000000100000005000000DE9046054EEC43406A6B44300E204740DE9046054EEC4340F9F4D89601214740952710768AED4340F9F4D89601214740952710768AED43406A6B44300E204740DE9046054EEC43406A6B44300E204740
21029	50316	40.232621999999999	40.283296	46.420827000000003	46.409066000000003	Первомайская	0103000020E61000000100000005000000412AC58EC61D4440E9F351465C344740412AC58EC61D44400C23BDA8DD354740378B170B432444400C23BDA8DD354740378B170B43244440E9F351465C344740412AC58EC61D4440E9F351465C344740
81126	62089	40.214548000000001	40.232379999999999	46.486707000000003	46.469672000000003	Ленина	0103000020E610000001000000050000000BB6114F761B444068EC4B361E3C47400BB6114F761B4440FDDD3B6A4C3E47404B1FBAA0BE1D4440FDDD3B6A4C3E47404B1FBAA0BE1D444068EC4B361E3C47400BB6114F761B444068EC4B361E3C4740
20682	50275	39.755220999999999	39.787748999999998	46.247728000000002	46.241190000000003	 Хлеборобная	0103000020E610000001000000050000004F20EC14ABE04340A60F5D50DF1E47404F20EC14ABE04340D926158DB51F4740753A90F5D4E44340D926158DB51F4740753A90F5D4E44340A60F5D50DF1E47404F20EC14ABE04340A60F5D50DF1E4740
21125	1428	40.147623000000003	40.159122000000004	46.248787999999998	46.241307999999997	Суворова	0103000020E6100000010000000500000097917A4FE5124440AF21382EE31E474097917A4FE512444091D10149D81F47407D09151C5E14444091D10149D81F47407D09151C5E144440AF21382EE31E474097917A4FE5124440AF21382EE31E4740
22468	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Юбилейная	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
23523	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Чкалова	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
23412	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Центральная	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
22074	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Трудовая	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
20968	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Первомайская	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
22475	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Ленина	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
20983	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Красная	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
20905	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Кооперативная	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
21137	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Кондратюка	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
21522	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Комсомольская	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
20659	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Кирова	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
23630	126	39.698214	39.825245000000002	46.300570999999998	46.259087999999998	Зеленый переулок	0103000020E61000000100000005000000FFCD8B135FD943409D64ABCB29214740FFCD8B135FD9434021904B1C792647400118CFA0A1E9434021904B1C792647400118CFA0A1E943409D64ABCB29214740FFCD8B135FD943409D64ABCB29214740
20927	1234	39.923780999999998	39.935566999999999	46.251710000000003	46.246144999999999	Лермонтова	0103000020E6100000010000000500000045D5AF743EF643407689EAAD811F474045D5AF743EF64340C009850838204740C11BD2A8C0F74340C009850838204740C11BD2A8C0F743407689EAAD811F474045D5AF743EF643407689EAAD811F4740
21153	50335	39.936698999999997	39.958286000000001	46.479551999999998	46.460715	Школьная	0103000020E610000001000000050000001399B9C0E5F7434069E388B5F83A47401399B9C0E5F743409E5DBEF5613D47407A1B9B1DA9FA43409E5DBEF5613D47407A1B9B1DA9FA434069E388B5F83A47401399B9C0E5F7434069E388B5F83A4740
21794	50335	39.936698999999997	39.958286000000001	46.479551999999998	46.460715	Красная	0103000020E610000001000000050000001399B9C0E5F7434069E388B5F83A47401399B9C0E5F743409E5DBEF5613D47407A1B9B1DA9FA43409E5DBEF5613D47407A1B9B1DA9FA434069E388B5F83A47401399B9C0E5F7434069E388B5F83A4740
23015	1484	40.059148	40.103389999999997	46.416733000000001	46.402236000000002	Первомайская	0103000020E61000000100000005000000D9CF6229920744400EA320787C334740D9CF622992074440FD14C78157354740E15D2EE23B0D4440FD14C78157354740E15D2EE23B0D44400EA320787C334740D9CF6229920744400EA320787C334740
22253	2056	40.081732000000002	40.110604000000002	46.538882999999998	46.525846000000001	Ленина	0103000020E61000000100000005000000B284B531760A4440C05DF6EB4E434740B284B531760A444068AF3E1EFA44474045679945280E444068AF3E1EFA44474045679945280E4440C05DF6EB4E434740B284B531760A4440C05DF6EB4E434740
22165	50471	39.924912999999997	40.008159999999997	46.345405999999997	46.290233999999998	Энгельса	0103000020E610000001000000050000009752978C63F64340F8174163262547409752978C63F64340CCEB8843362C474053910A630B014440CCEB8843362C474053910A630B014440F8174163262547409752978C63F64340F817416326254740
22709	50471	39.924912999999997	40.008159999999997	46.345405999999997	46.290233999999998	Халтурина	0103000020E610000001000000050000009752978C63F64340F8174163262547409752978C63F64340CCEB8843362C474053910A630B014440CCEB8843362C474053910A630B014440F8174163262547409752978C63F64340F817416326254740
22341	50471	39.924912999999997	40.008159999999997	46.345405999999997	46.290233999999998	Орджоникидзе	0103000020E610000001000000050000009752978C63F64340F8174163262547409752978C63F64340CCEB8843362C474053910A630B014440CCEB8843362C474053910A630B014440F8174163262547409752978C63F64340F817416326254740
21784	48908	40.086447999999997	40.094614	46.252426999999997	46.242187000000001	Фермерская	0103000020E61000000100000005000000FD6662BA100B44401842CEFBFF1E4740FD6662BA100B44404ED026874F20474033DFC14F1C0C44404ED026874F20474033DFC14F1C0C44401842CEFBFF1E4740FD6662BA100B44401842CEFBFF1E4740
21833	49064	39.882610999999997	39.896175999999997	46.486694999999997	46.473762000000001	Черемушки	0103000020E61000000100000005000000800BB265F9F04340350BB43BA43C4740800BB265F9F04340381092054C3E4740E4BA29E5B5F24340381092054C3E4740E4BA29E5B5F24340350BB43BA43C4740800BB265F9F04340350BB43BA43C4740
20973	50307	40.163451999999999	40.207172999999997	46.536087999999999	46.527607000000003	пер. Школьный	0103000020E610000001000000050000009F3BC1FEEB14444002124DA0884347409F3BC1FEEB14444097E315889E4447409ECE15A5841A444097E315889E4447409ECE15A5841A444002124DA0884347409F3BC1FEEB14444002124DA088434740
22340	50307	40.163451999999999	40.207172999999997	46.536087999999999	46.527607000000003	Калинина	0103000020E610000001000000050000009F3BC1FEEB14444002124DA0884347409F3BC1FEEB14444097E315889E4447409ECE15A5841A444097E315889E4447409ECE15A5841A444002124DA0884347409F3BC1FEEB14444002124DA088434740
20964	49122	39.998933999999998	40.015158	46.543495	46.536082	Мира	0103000020E61000000100000005000000656EBE11DDFF4340B5FCC0559E444740656EBE11DDFF43400F45813E91454740EA2285B2F00144400F45813E91454740EA2285B2F0014440B5FCC0559E444740656EBE11DDFF4340B5FCC0559E444740
21122	48888	39.998475999999997	40.005555000000001	46.255423999999998	46.243882999999997	Советская	0103000020E61000000100000005000000A2EBC20FCEFF43407286E28E371F4740A2EBC20FCEFF4340874ECFBBB120474026AAB706B6004440874ECFBBB120474026AAB706B60044407286E28E371F4740A2EBC20FCEFF43407286E28E371F4740
22326	48983	40.192117000000003	40.200812999999997	46.412297000000002	46.407525	Трудовая	0103000020E61000000100000005000000B900344A97184440B5A679C729344740B900344A97184440959EE925C63447404ACE893DB4194440959EE925C63447404ACE893DB4194440B5A679C729344740B900344A97184440B5A679C729344740
21439	1922	40.018805	40.027591000000001	46.474984999999997	46.468586000000002	Центральная	0103000020E610000001000000050000002A00C6336802444086AE44A0FA3B47402A00C63368024440978BF84ECC3C4740FC54151A88034440978BF84ECC3C4740FC54151A8803444086AE44A0FA3B47402A00C6336802444086AE44A0FA3B4740
20963	32734	38.117485000000002	38.144641	45.345799999999997	45.328401999999997	Садовая	0103000020E61000000100000005000000A2629CBF090F434072F8A41309AA4640A2629CBF090F4340787AA52C43AC46409354A69883124340787AA52C43AC46409354A6988312434072F8A41309AA4640A2629CBF090F434072F8A41309AA4640
22818	15828	38.165005999999998	38.175417000000003	45.243364999999997	45.234149000000002	Центральная	0103000020E6100000010000000500000067D2A6EA1E15434010B22C98F89D464067D2A6EA1E154340DAFE9595269F4640CB14731074164340DAFE9595269F4640CB1473107416434010B22C98F89D464067D2A6EA1E15434010B22C98F89D4640
21577	16519	38.077500999999998	38.141362000000001	45.574348999999998	45.542985000000002	ул.Школьная	0103000020E610000001000000050000002234828DEB094340FA9B508880C546402234828DEB094340C2BE9D4484C94640D672672618124340C2BE9D4484C94640D672672618124340FA9B508880C546402234828DEB094340FA9B508880C54640
20881	15589	38.116461000000001	38.174284999999998	45.313198999999997	45.25235	Школьная	0103000020E610000001000000050000003621AD31E80E4340A3923A014DA046403621AD31E80E4340E811A3E716A8464078978BF84E164340E811A3E716A8464078978BF84E164340A3923A014DA046403621AD31E80E4340A3923A014DA04640
21561	15589	38.116461000000001	38.174284999999998	45.313198999999997	45.25235	Садовая	0103000020E610000001000000050000003621AD31E80E4340A3923A014DA046403621AD31E80E4340E811A3E716A8464078978BF84E164340E811A3E716A8464078978BF84E164340A3923A014DA046403621AD31E80E4340A3923A014DA04640
21549	15589	38.116461000000001	38.174284999999998	45.313198999999997	45.25235	Набережная	0103000020E610000001000000050000003621AD31E80E4340A3923A014DA046403621AD31E80E4340E811A3E716A8464078978BF84E164340E811A3E716A8464078978BF84E164340A3923A014DA046403621AD31E80E4340A3923A014DA04640
22643	15589	38.116461000000001	38.174284999999998	45.313198999999997	45.25235	Мазуренко	0103000020E610000001000000050000003621AD31E80E4340A3923A014DA046403621AD31E80E4340E811A3E716A8464078978BF84E164340E811A3E716A8464078978BF84E164340A3923A014DA046403621AD31E80E4340A3923A014DA04640
23004	15901	38.208393999999998	38.233502000000001	45.199171999999997	45.185482999999998	Школьная	0103000020E61000000100000005000000605793A7AC1A4340637B2DE8BD974640605793A7AC1A4340B323D5777E9946407AC6BE64E31D4340B323D5777E9946407AC6BE64E31D4340637B2DE8BD974640605793A7AC1A4340637B2DE8BD974640
20697	17060	38.407164999999999	38.468609000000001	45.412736000000002	45.359189000000001	Северная	0103000020E61000000100000005000000B58993FB1D3443409E0AB8E7F9AD4640B58993FB1D344340E1F08288D4B446403ECE3461FB3B4340E1F08288D4B446403ECE3461FB3B43409E0AB8E7F9AD4640B58993FB1D3443409E0AB8E7F9AD4640
21196	17060	38.407164999999999	38.468609000000001	45.412736000000002	45.359189000000001	Мира	0103000020E61000000100000005000000B58993FB1D3443409E0AB8E7F9AD4640B58993FB1D344340E1F08288D4B446403ECE3461FB3B4340E1F08288D4B446403ECE3461FB3B43409E0AB8E7F9AD4640B58993FB1D3443409E0AB8E7F9AD4640
20758	17060	38.407164999999999	38.468609000000001	45.412736000000002	45.359189000000001	Батарейная	0103000020E61000000100000005000000B58993FB1D3443409E0AB8E7F9AD4640B58993FB1D344340E1F08288D4B446403ECE3461FB3B4340E1F08288D4B446403ECE3461FB3B43409E0AB8E7F9AD4640B58993FB1D3443409E0AB8E7F9AD4640
20739	16649	38.265616999999999	38.313901000000001	45.485872999999998	45.446626000000002	Красная	0103000020E610000001000000050000007D21E4BCFF2143408BC56F0A2BB946407D21E4BCFF2143403481221631BE4640429770E82D2843403481221631BE4640429770E82D2843408BC56F0A2BB946407D21E4BCFF2143408BC56F0A2BB94640
22906	16649	38.265616999999999	38.313901000000001	45.485872999999998	45.446626000000002	Дружбы	0103000020E610000001000000050000007D21E4BCFF2143408BC56F0A2BB946407D21E4BCFF2143403481221631BE4640429770E82D2843403481221631BE4640429770E82D2843408BC56F0A2BB946407D21E4BCFF2143408BC56F0A2BB94640
20949	15385	38.301253000000003	38.319766999999999	45.236117	45.219295000000002	Мира	0103000020E61000000100000005000000346953758F2643409296CADB119C4640346953758F264340CB83F414399E464086AB0320EE284340CB83F414399E464086AB0320EE2843409296CADB119C4640346953758F2643409296CADB119C4640
21181	16597	38.073	38.087535000000003	45.543061000000002	45.504151	Набережная	0103000020E61000000100000005000000D34D621058094340739F1C0588C04640D34D621058094340D55DD90583C54640B020CD58340B4340D55DD90583C54640B020CD58340B4340739F1C0588C04640D34D621058094340739F1C0588C04640
21810	16763	38.062094999999999	38.085002000000003	45.393003999999998	45.360754	Красная	0103000020E61000000100000005000000601F9DBAF20743405AF3E32F2DAE4640601F9DBAF20743403D997FF44DB246401C0C7558E10A43403D997FF44DB246401C0C7558E10A43405AF3E32F2DAE4640601F9DBAF20743405AF3E32F2DAE4640
23189	50640	38.452528999999998	38.516696000000003	45.121532999999999	45.096839000000003	Центральная	0103000020E61000000100000005000000ECBE6378EC3943401AFD6838658C4640ECBE6378EC3943404031B2648E8F4640ADFC3218234243404031B2648E8F4640ADFC3218234243401AFD6838658C4640ECBE6378EC3943401AFD6838658C4640
23510	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Элеваторная	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
20420	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Школьная	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
20903	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Шевченко	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
23979	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Центральная	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
21086	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Таманская	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
21301	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Просвещения	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
23471	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Народная	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
23733	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Ленина	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
20425	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Красная	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
21415	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Комсомольская	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
20475	14023	38.172533999999999	38.249572999999998	45.394965999999997	45.337792	Жлобы	0103000020E610000001000000050000005AB9179815164340DB6CACC43CAB46405AB91798151643401684F23E8EB24640787B1002F21F43401684F23E8EB24640787B1002F21F4340DB6CACC43CAB46405AB9179815164340DB6CACC43CAB4640
20687	46110	38.328480999999996	38.340743000000003	45.206462000000002	45.196357999999996	Кольцевая	0103000020E61000000100000005000000BE2D58AA0B2A43406B274A4222994640BE2D58AA0B2A4340F2EEC8586D9A4640A4AB74779D2B4340F2EEC8586D9A4640A4AB74779D2B43406B274A4222994640BE2D58AA0B2A43406B274A4222994640
21369	47108	38.298279999999998	38.318258	45.184047999999997	45.171906	Мира	0103000020E610000001000000050000008386FE092E2643403BFE0B04019646408386FE092E264340757286E28E9746405ED89AADBC284340757286E28E9746405ED89AADBC2843403BFE0B04019646408386FE092E2643403BFE0B0401964640
21462	50376	38.281858999999997	38.306868000000001	45.241283000000003	45.227345	Октябрьская	0103000020E61000000100000005000000A88AA9F4132443405EF415A4199D4640A88AA9F413244340570A815CE29E46402F185C7347274340570A815CE29E46402F185C73472743405EF415A4199D4640A88AA9F4132443405EF415A4199D4640
20469	14725	38.541947999999998	38.610408	45.217606000000004	45.178851000000002	Красная	0103000020E61000000100000005000000F910548D5E454340AFEDED96E4964640F910548D5E454340EAB46E83DA9B4640BF9B6ED9214E4340EAB46E83DA9B4640BF9B6ED9214E4340AFEDED96E4964640F910548D5E454340AFEDED96E4964640
21316	14725	38.541947999999998	38.610408	45.217606000000004	45.178851000000002	Гагарина	0103000020E61000000100000005000000F910548D5E454340AFEDED96E4964640F910548D5E454340EAB46E83DA9B4640BF9B6ED9214E4340EAB46E83DA9B4640BF9B6ED9214E4340AFEDED96E4964640F910548D5E454340AFEDED96E4964640
23445	45742	38.321626999999999	38.332496999999996	45.255172999999999	45.244259	Космонавтов	0103000020E610000001000000050000005B41D3122B294340786000E1439F46405B41D3122B2943403EE94482A9A046405182FE428F2A43403EE94482A9A046405182FE428F2A4340786000E1439F46405B41D3122B294340786000E1439F4640
20598	45742	38.321626999999999	38.332496999999996	45.255172999999999	45.244259	Клубная	0103000020E610000001000000050000005B41D3122B294340786000E1439F46405B41D3122B2943403EE94482A9A046405182FE428F2A43403EE94482A9A046405182FE428F2A4340786000E1439F46405B41D3122B294340786000E1439F4640
20511	16281	38.602746000000003	38.677584000000003	45.120776999999997	45.089159000000002	Шевченко	0103000020E61000000100000005000000BDE5EAC7264D43407192E68F698B4640BDE5EAC7264D4340F38DE89E758F46407D259012BB564340F38DE89E758F46407D259012BB5643407192E68F698B4640BDE5EAC7264D43407192E68F698B4640
20504	16281	38.602746000000003	38.677584000000003	45.120776999999997	45.089159000000002	Соболя	0103000020E61000000100000005000000BDE5EAC7264D43407192E68F698B4640BDE5EAC7264D4340F38DE89E758F46407D259012BB564340F38DE89E758F46407D259012BB5643407192E68F698B4640BDE5EAC7264D43407192E68F698B4640
20994	16281	38.602746000000003	38.677584000000003	45.120776999999997	45.089159000000002	Пионерская	0103000020E61000000100000005000000BDE5EAC7264D43407192E68F698B4640BDE5EAC7264D4340F38DE89E758F46407D259012BB564340F38DE89E758F46407D259012BB5643407192E68F698B4640BDE5EAC7264D43407192E68F698B4640
20980	16281	38.602746000000003	38.677584000000003	45.120776999999997	45.089159000000002	Ленина	0103000020E61000000100000005000000BDE5EAC7264D43407192E68F698B4640BDE5EAC7264D4340F38DE89E758F46407D259012BB564340F38DE89E758F46407D259012BB5643407192E68F698B4640BDE5EAC7264D43407192E68F698B4640
21173	16281	38.602746000000003	38.677584000000003	45.120776999999997	45.089159000000002	Красная	0103000020E61000000100000005000000BDE5EAC7264D43407192E68F698B4640BDE5EAC7264D4340F38DE89E758F46407D259012BB564340F38DE89E758F46407D259012BB5643407192E68F698B4640BDE5EAC7264D43407192E68F698B4640
21994	15924	38.198971	38.230026000000002	45.271186	45.257120999999998	Молодежная	0103000020E610000001000000050000001CEDB8E177194340B20E4757E9A046401CEDB8E17719434008910C39B6A24640679DF17D711D434008910C39B6A24640679DF17D711D4340B20E4757E9A046401CEDB8E177194340B20E4757E9A04640
20931	15524	38.401333999999999	38.412069000000002	45.185242000000002	45.175719000000001	Октябрьская	0103000020E61000000100000005000000ED629AE95E3343409624CFF57D964640ED629AE95E3343403EEC8502B697464004594FADBE3443403EEC8502B697464004594FADBE3443409624CFF57D964640ED629AE95E3343409624CFF57D964640
20925	15087	38.309922	38.319471	45.288384999999998	45.279234000000002	Центральная	0103000020E61000000100000005000000CC272B86AB27434034F790F0BDA34640CC272B86AB27434017D4B7CCE9A446409D82FC6CE428434017D4B7CCE9A446409D82FC6CE428434034F790F0BDA34640CC272B86AB27434034F790F0BDA34640
20455	46052	38.340653000000003	38.353337000000003	45.15558	45.142707999999999	Первомайская	0103000020E6100000010000000500000064247B849A2B4340547078414492464064247B849A2B4340B2F4A10BEA934640BFBB95253A2D4340B2F4A10BEA934640BFBB95253A2D4340547078414492464064247B849A2B43405470784144924640
21152	16838	38.086959999999998	38.10286	45.416671000000001	45.410001999999999	Рисовая	0103000020E61000000100000005000000B3075A81210B4340B5A50EF27AB44640B3075A81210B43408718AF7955B54640850838842A0D43408718AF7955B54640850838842A0D4340B5A50EF27AB44640B3075A81210B4340B5A50EF27AB44640
21710	50416	38.425113000000003	38.496977999999999	45.295645	45.249271999999998	Пионерская	0103000020E610000001000000050000005F0D501A6A3643407DE71725E89F46405F0D501A6A364340EB1C03B2D7A546406E6AA0F99C3F4340EB1C03B2D7A546406E6AA0F99C3F43407DE71725E89F46405F0D501A6A3643407DE71725E89F4640
21382	46321	38.425113000000003	38.496977999999999	45.295645	45.249271999999998	Черноморская	0103000020E610000001000000050000005F0D501A6A3643407DE71725E89F46405F0D501A6A364340EB1C03B2D7A546406E6AA0F99C3F4340EB1C03B2D7A546406E6AA0F99C3F43407DE71725E89F46405F0D501A6A3643407DE71725E89F4640
22259	46321	38.425113000000003	38.496977999999999	45.295645	45.249271999999998	Советская	0103000020E610000001000000050000005F0D501A6A3643407DE71725E89F46405F0D501A6A364340EB1C03B2D7A546406E6AA0F99C3F4340EB1C03B2D7A546406E6AA0F99C3F43407DE71725E89F46405F0D501A6A3643407DE71725E89F4640
21847	46321	38.425113000000003	38.496977999999999	45.295645	45.249271999999998	Ленина	0103000020E610000001000000050000005F0D501A6A3643407DE71725E89F46405F0D501A6A364340EB1C03B2D7A546406E6AA0F99C3F4340EB1C03B2D7A546406E6AA0F99C3F43407DE71725E89F46405F0D501A6A3643407DE71725E89F4640
20441	46321	38.425113000000003	38.496977999999999	45.295645	45.249271999999998	Красная	0103000020E610000001000000050000005F0D501A6A3643407DE71725E89F46405F0D501A6A364340EB1C03B2D7A546406E6AA0F99C3F4340EB1C03B2D7A546406E6AA0F99C3F43407DE71725E89F46405F0D501A6A3643407DE71725E89F4640
21545	16814	38.052087	38.078507000000002	45.354179999999999	45.31709	Кирова	0103000020E61000000100000005000000FCC56CC9AA064340BFF1B56796A84640FCC56CC9AA064340DA722EC555AD4640E8C072840C0A4340DA722EC555AD4640E8C072840C0A4340BFF1B56796A84640FCC56CC9AA064340BFF1B56796A84640
20526	40471	38.465052	38.483916999999998	45.356465999999998	45.347675000000002	Пролетарская	0103000020E610000001000000050000003E78EDD2863B43408351499D80AC46403E78EDD2863B434066118AADA0AD46403D7D04FEF03D434066118AADA0AD46403D7D04FEF03D43408351499D80AC46403E78EDD2863B43408351499D80AC4640
20737	40471	38.465052	38.483916999999998	45.356465999999998	45.347675000000002	Матросова	0103000020E610000001000000050000003E78EDD2863B43408351499D80AC46403E78EDD2863B434066118AADA0AD46403D7D04FEF03D434066118AADA0AD46403D7D04FEF03D43408351499D80AC46403E78EDD2863B43408351499D80AC4640
21380	45847	38.350758999999996	38.363030000000002	45.284605999999997	45.276380000000003	Новая	0103000020E610000001000000050000008AE3C0ABE52C43405EA27A6B60A346408AE3C0ABE52C4340681F2BF86DA44640C3BB5CC4772E4340681F2BF86DA44640C3BB5CC4772E43405EA27A6B60A346408AE3C0ABE52C43405EA27A6B60A34640
23595	50785	40.369103000000003	40.398828000000002	44.943286999999998	44.933289000000002	улица Шоссейная	0103000020E6100000010000000500000081ED60C43E2F4440B85B92037677464081ED60C43E2F4440F8DEDFA0BD784640535DC0CB0C334440F8DEDFA0BD784640535DC0CB0C334440B85B92037677464081ED60C43E2F4440B85B920376774640
23369	46308	40.418411999999996	40.425606999999999	44.905582000000003	44.899856	Центральная	0103000020E61000000100000005000000812040868E354440008E3D7B2E734640812040868E35444053EC681CEA7346406EF9484A7A36444053EC681CEA7346406EF9484A7A364440008E3D7B2E734640812040868E354440008E3D7B2E734640
21617	46308	40.418411999999996	40.425606999999999	44.905582000000003	44.899856	Кирова	0103000020E61000000100000005000000812040868E354440008E3D7B2E734640812040868E35444053EC681CEA7346406EF9484A7A36444053EC681CEA7346406EF9484A7A364440008E3D7B2E734640812040868E354440008E3D7B2E734640
21596	46308	40.418411999999996	40.425606999999999	44.905582000000003	44.899856	Азовская	0103000020E61000000100000005000000812040868E354440008E3D7B2E734640812040868E35444053EC681CEA7346406EF9484A7A36444053EC681CEA7346406EF9484A7A364440008E3D7B2E734640812040868E354440008E3D7B2E734640
20735	46573	40.677207000000003	40.726326999999998	44.639851999999998	44.596556	Школьная	0103000020E61000000100000005000000A7CF0EB8AE564440C51D6FF25B4C4640A7CF0EB8AE564440DD239BABE6514640D4997B48F85C4440DD239BABE6514640D4997B48F85C4440C51D6FF25B4C4640A7CF0EB8AE564440C51D6FF25B4C4640
23858	49337	39.179788000000002	39.220013999999999	45.436191999999998	45.413696999999999	Красная	0103000020E610000001000000050000004C1B0E4B0397434006BAF605F4B446404C1B0E4B039743406F63B323D5B74640C154336B299C43406F63B323D5B74640C154336B299C434006BAF605F4B446404C1B0E4B0397434006BAF605F4B44640
20753	49337	39.179788000000002	39.220013999999999	45.436191999999998	45.413696999999999	Айвазяна	0103000020E610000001000000050000004C1B0E4B0397434006BAF605F4B446404C1B0E4B039743406F63B323D5B74640C154336B299C43406F63B323D5B74640C154336B299C434006BAF605F4B446404C1B0E4B0397434006BAF605F4B44640
23488	49211	39.515442999999998	39.619593999999999	45.389960000000002	45.362735999999998	Фрунзе	0103000020E61000000100000005000000DFF94509FAC143407A8A1C226EAE4640DFF94509FAC14340C45F9335EAB146401F662FDB4ECF4340C45F9335EAB146401F662FDB4ECF43407A8A1C226EAE4640DFF94509FAC143407A8A1C226EAE4640
22071	49211	39.515442999999998	39.619593999999999	45.389960000000002	45.362735999999998	Фрунзе	0103000020E61000000100000005000000DFF94509FAC143407A8A1C226EAE4640DFF94509FAC14340C45F9335EAB146401F662FDB4ECF4340C45F9335EAB146401F662FDB4ECF43407A8A1C226EAE4640DFF94509FAC143407A8A1C226EAE4640
20849	12571	39.349138000000004	39.417509000000003	45.410305999999999	45.375368000000002	Третьякова	0103000020E610000001000000050000003BE5D18DB0AC434083FB010F0CB046403BE5D18DB0AC434021AD31E884B44640916456EF70B5434021AD31E884B44640916456EF70B5434083FB010F0CB046403BE5D18DB0AC434083FB010F0CB04640
21058	12571	39.349138000000004	39.417509000000003	45.410305999999999	45.375368000000002	Пролетарская	0103000020E610000001000000050000003BE5D18DB0AC434083FB010F0CB046403BE5D18DB0AC434021AD31E884B44640916456EF70B5434021AD31E884B44640916456EF70B5434083FB010F0CB046403BE5D18DB0AC434083FB010F0CB04640
21262	12571	39.349138000000004	39.417509000000003	45.410305999999999	45.375368000000002	Красная	0103000020E610000001000000050000003BE5D18DB0AC434083FB010F0CB046403BE5D18DB0AC434021AD31E884B44640916456EF70B5434021AD31E884B44640916456EF70B5434083FB010F0CB046403BE5D18DB0AC434083FB010F0CB04640
22103	50465	39.349138000000004	39.417509000000003	45.410305999999999	45.375368000000002	Красная	0103000020E610000001000000050000003BE5D18DB0AC434083FB010F0CB046403BE5D18DB0AC434021AD31E884B44640916456EF70B5434021AD31E884B44640916456EF70B5434083FB010F0CB046403BE5D18DB0AC434083FB010F0CB04640
21068	13330	39.443102000000003	39.461956999999998	45.702767999999999	45.687710000000003	Пионерская	0103000020E610000001000000050000006765FB90B7B84340EB909BE106D846406765FB90B7B843407156444DF4D9464042942F6821BB43407156444DF4D9464042942F6821BB4340EB909BE106D846406765FB90B7B84340EB909BE106D84640
24039	50904	39.196981000000001	39.248005999999997	45.412761000000003	45.387624000000002	Северная	0103000020E61000000100000005000000797764AC369943408692C9A99DB14640797764AC369943403A083A5AD5B446401B9B1DA9BE9F43403A083A5AD5B446401B9B1DA9BE9F43408692C9A99DB14640797764AC369943408692C9A99DB14640
21374	47524	39.545949999999998	39.559244999999997	45.498812999999998	45.489077000000002	Партизанская	0103000020E6100000010000000500000027A089B0E1C54340E71C3C139ABE464027A089B0E1C54340EAE8B81AD9BF4640CBB9145795C74340EAE8B81AD9BF4640CBB9145795C74340E71C3C139ABE464027A089B0E1C54340E71C3C139ABE4640
23391	50687	39.257230999999997	39.273966999999999	45.404111	45.394764000000002	Центральная	0103000020E61000000100000005000000394206F2ECA04340AFD172A087B24640394206F2ECA04340187AC4E8B9B346407497C45911A34340187AC4E8B9B346407497C45911A34340AFD172A087B24640394206F2ECA04340AFD172A087B24640
21195	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Школьная	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
20611	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Фрунзе	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
20583	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Маяковского	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
20936	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Матросова	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
20891	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Маркса	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
21345	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Красная	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
20832	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Коммунаров	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
20582	11444	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Заводская	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
21253	50348	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Октябрьская	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
22539	50348	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Лиманский переулок	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
21251	50348	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Красная	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
21465	50348	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Клубная	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
21257	50348	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Запорожская	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
21481	50348	39.401249	39.507348999999998	45.488931000000001	45.435229999999997	Выселковская	0103000020E61000000100000005000000BF4692205CB34340791EDC9DB5B74640BF4692205CB3434013807F4A95BE46404354E1CFF0C0434013807F4A95BE46404354E1CFF0C04340791EDC9DB5B74640BF4692205CB34340791EDC9DB5B74640
20907	50298	39.404626999999998	39.465981999999997	45.396763999999997	45.372214999999997	Казачья	0103000020E610000001000000050000000F0A4AD1CAB34340520ABABDA4AF46400F0A4AD1CAB34340751DAA29C9B246402843554CA5BB4340751DAA29C9B246402843554CA5BB4340520ABABDA4AF46400F0A4AD1CAB34340520ABABDA4AF4640
22221	50474	39.115566999999999	39.669226000000002	45.814667999999998	45.306694999999998	Золотарева	0103000020E6100000010000000500000098BF42E6CA8E4340616C21C841A7464098BF42E6CA8E4340828C800A47E8464003D19332A9D54340828C800A47E8464003D19332A9D54340616C21C841A7464098BF42E6CA8E4340616C21C841A74640
20888	13551	39.525576000000001	39.573132999999999	45.536116999999997	45.527169999999998	Лунева	0103000020E6100000010000000500000000C8091346C3434056B77A4E7AC3464000C8091346C3434031EA5A7B9FC4464012A1116C5CC9434031EA5A7B9FC4464012A1116C5CC9434056B77A4E7AC3464000C8091346C3434056B77A4E7AC34640
23054	50622	39.294386000000003	39.373832999999998	45.59384	45.579970000000003	Южная	0103000020E610000001000000050000003C33C170AEA54340A054FB743CCA46403C33C170AEA543404087F9F202CC464031957EC2D9AF43404087F9F202CC464031957EC2D9AF4340A054FB743CCA46403C33C170AEA54340A054FB743CCA4640
21496	13523	39.480345999999997	39.640794	45.588509999999999	45.567106000000003	Северная	0103000020E61000000100000005000000D8614CFA7BBD4340C5AEEDED96C84640D8614CFA7BBD43403AAFB14B54CB46408CBCAC8905D243403AAFB14B54CB46408CBCAC8905D24340C5AEEDED96C84640D8614CFA7BBD4340C5AEEDED96C84640
22883	50583	39.164749999999998	39.214112	45.568922999999998	45.534115999999997	Пролетарская	0103000020E610000001000000050000000C022B87169543409A22C0E95DC446400C022B87169543409A780778D2C8464030D7A205689B43409A780778D2C8464030D7A205689B43409A22C0E95DC446400C022B87169543409A22C0E95DC44640
20602	12907	39.164749999999998	39.214112	45.568922999999998	45.534115999999997	Советская	0103000020E610000001000000050000000C022B87169543409A22C0E95DC446400C022B87169543409A780778D2C8464030D7A205689B43409A780778D2C8464030D7A205689B43409A22C0E95DC446400C022B87169543409A22C0E95DC44640
20606	12907	39.164749999999998	39.214112	45.568922999999998	45.534115999999997	Ленина	0103000020E610000001000000050000000C022B87169543409A22C0E95DC446400C022B87169543409A780778D2C8464030D7A205689B43409A780778D2C8464030D7A205689B43409A22C0E95DC446400C022B87169543409A22C0E95DC44640
22070	12383	39.558427000000002	39.657924999999999	45.471204999999998	45.449154999999998	Гагарина	0103000020E61000000100000005000000091A33897AC74340DDEA39E97DB94640091A33897AC74340185B087250BC4640431CEBE236D44340185B087250BC4640431CEBE236D44340DDEA39E97DB94640091A33897AC74340DDEA39E97DB94640
22625	13245	39.269862000000003	39.403190000000002	45.645631000000002	45.631520999999999	Школьная	0103000020E61000000100000005000000723788D68AA243405DDE1CAED5D04640723788D68AA2434053245F09A4D246408109DCBA9BB3434053245F09A4D246408109DCBA9BB343405DDE1CAED5D04640723788D68AA243405DDE1CAED5D04640
20617	13245	39.269862000000003	39.403190000000002	45.645631000000002	45.631520999999999	Центральная	0103000020E61000000100000005000000723788D68AA243405DDE1CAED5D04640723788D68AA2434053245F09A4D246408109DCBA9BB3434053245F09A4D246408109DCBA9BB343405DDE1CAED5D04640723788D68AA243405DDE1CAED5D04640
23896	13047	39.308416999999999	39.370482000000003	45.557381999999997	45.541122999999999	Мира	0103000020E61000000100000005000000E54350357AA74340840EBA8443C54640E54350357AA7434085B01A4B58C74640DBE044F46BAF434085B01A4B58C74640DBE044F46BAF4340840EBA8443C54640E54350357AA74340840EBA8443C54640
20507	13367	39.470581000000003	39.510278	45.786790000000003	45.775677000000002	Партизанская	0103000020E610000001000000050000003B8F8AFF3BBC434034A1496249E346403B8F8AFF3BBC4340F168E388B5E4464024EF1CCA50C14340F168E388B5E4464024EF1CCA50C1434034A1496249E346403B8F8AFF3BBC434034A1496249E34640
20572	39762	31.586822999999999	31.588529000000001	59.865541999999998	59.864700999999997	Новая	0103000020E61000000100000005000000658A39083A963F40C4E8B985AEEE4D40658A39083A963F403FA88B14CAEE4D4062BF27D6A9963F403FA88B14CAEE4D4062BF27D6A9963F40C4E8B985AEEE4D40658A39083A963F40C4E8B985AEEE4D40
22867	50580	39.064399000000002	39.071584999999999	45.022074000000003	45.02008	Центральная	0103000020E610000001000000050000009372F7393E884340DFA63FFB918246409372F7393E884340C40B2252D38246402CF180B229894340C40B2252D38246402CF180B229894340DFA63FFB918246409372F7393E884340DFA63FFB91824640
10085	40520	39.333407999999999	39.410637000000001	45.996552999999999	45.959702	Красная	0103000020E61000000100000005000000C51C041DADAA4340F1F3DF83D7FA4640C51C041DADAA434087DD770C8FFF464087C3D2C08FB4434087DD770C8FFF464087C3D2C08FB44340F1F3DF83D7FA4640C51C041DADAA4340F1F3DF83D7FA4640
20415	50241	38.910859000000002	39.042659999999998	46.040168000000001	45.948304	Красная	0103000020E6100000010000000500000036221807977443403F55850662F946403622180797744340412C9B3924054740766C04E275854340412C9B3924054740766C04E2758543403F55850662F9464036221807977443403F55850662F94640
22498	10778	39.333407999999999	39.410637000000001	45.996552999999999	45.959702	переулок Гоголя	0103000020E61000000100000005000000C51C041DADAA4340F1F3DF83D7FA4640C51C041DADAA434087DD770C8FFF464087C3D2C08FB4434087DD770C8FFF464087C3D2C08FB44340F1F3DF83D7FA4640C51C041DADAA4340F1F3DF83D7FA4640
20806	10778	39.333407999999999	39.410637000000001	45.996552999999999	45.959702	Партизанская	0103000020E61000000100000005000000C51C041DADAA4340F1F3DF83D7FA4640C51C041DADAA434087DD770C8FFF464087C3D2C08FB4434087DD770C8FFF464087C3D2C08FB44340F1F3DF83D7FA4640C51C041DADAA4340F1F3DF83D7FA4640
9706	10778	39.333407999999999	39.410637000000001	45.996552999999999	45.959702	Красная	0103000020E61000000100000005000000C51C041DADAA4340F1F3DF83D7FA4640C51C041DADAA434087DD770C8FFF464087C3D2C08FB4434087DD770C8FFF464087C3D2C08FB44340F1F3DF83D7FA4640C51C041DADAA4340F1F3DF83D7FA4640
23461	50722	38.994222999999998	39.020381999999998	46.207652000000003	46.196461999999997	Алтайская	0103000020E610000001000000050000002BF702B3427F43401074B4AA251947402BF702B3427F434079793A57941A4740AAB69BE09B82434079793A57941A4740AAB69BE09B8243401074B4AA251947402BF702B3427F43401074B4AA25194740
23522	50748	38.517082000000002	38.543655000000001	46.168615000000003	46.142595	Длинная	0103000020E61000000100000005000000D6AC33BE2F4243405CC98E8D40124740D6AC33BE2F424340BA4E232D9515474048A7AE7C96454340BA4E232D9515474048A7AE7C964543405CC98E8D40124740D6AC33BE2F4243405CC98E8D40124740
23686	50807	39.140934999999999	39.211094000000003	45.984512000000002	45.967796	Северная	0103000020E610000001000000050000004EEE77280A9243408D9944BDE0FB46404EEE77280A92434081423D7D04FE4640E030D120059B434081423D7D04FE4640E030D120059B43408D9944BDE0FB46404EEE77280A9243408D9944BDE0FB4640
20574	11040	39.151805000000003	39.164183999999999	45.944387999999996	45.938904000000001	Широкая	0103000020E61000000100000005000000452FA3586E934340B30A9B012EF84640452FA3586E9343400F5EBBB4E1F84640634337FB039543400F5EBBB4E1F84640634337FB03954340B30A9B012EF84640452FA3586E934340B30A9B012EF84640
21793	10437	38.939990999999999	38.990125999999997	46.162959999999998	46.103223	Лиманская	0103000020E6100000010000000500000065C405A051784340F6984869360D474065C405A05178434030478FDFDB144740AB75E272BC7E434030478FDFDB144740AB75E272BC7E4340F6984869360D474065C405A051784340F6984869360D4740
20556	10437	38.939990999999999	38.990125999999997	46.162959999999998	46.103223	Красная	0103000020E6100000010000000500000065C405A051784340F6984869360D474065C405A05178434030478FDFDB144740AB75E272BC7E434030478FDFDB144740AB75E272BC7E4340F6984869360D474065C405A051784340F6984869360D4740
20491	10437	38.939990999999999	38.990125999999997	46.162959999999998	46.103223	Коммунаров	0103000020E6100000010000000500000065C405A051784340F6984869360D474065C405A05178434030478FDFDB144740AB75E272BC7E434030478FDFDB144740AB75E272BC7E4340F6984869360D474065C405A051784340F6984869360D4740
22492	10437	38.939990999999999	38.990125999999997	46.162959999999998	46.103223	Кирова	0103000020E6100000010000000500000065C405A051784340F6984869360D474065C405A05178434030478FDFDB144740AB75E272BC7E434030478FDFDB144740AB75E272BC7E4340F6984869360D474065C405A051784340F6984869360D4740
23454	50719	38.508324000000002	39.522091000000003	46.395363000000003	45.880440999999998	Центральная	0103000020E61000000100000005000000CEE2C5C2104143405D876A4AB2F04640CEE2C5C210414340348639419B3247409A44BDE0D3C24340348639419B3247409A44BDE0D3C243405D876A4AB2F04640CEE2C5C2104143405D876A4AB2F04640
23539	50758	38.770361999999999	38.822356999999997	46.189999	46.174106999999999	Широкая	0103000020E61000000100000005000000630AD6389B62434099805F2349164740630AD6389B624340E8A221E3511847407E5182FE42694340E8A221E3511847407E5182FE4269434099805F2349164740630AD6389B62434099805F2349164740
21972	50446	38.595109999999998	38.632111999999999	46.303316000000002	46.286292000000003	Труда	0103000020E61000000100000005000000E3C281902C4C4340A08D5C37A5244740E3C281902C4C4340412D060FD32647405FB4C70BE9504340412D060FD32647405FB4C70BE9504340A08D5C37A5244740E3C281902C4C4340A08D5C37A5244740
23207	50446	38.595109999999998	38.632111999999999	46.303316000000002	46.286292000000003	Светлая	0103000020E61000000100000005000000E3C281902C4C4340A08D5C37A5244740E3C281902C4C4340412D060FD32647405FB4C70BE9504340412D060FD32647405FB4C70BE9504340A08D5C37A5244740E3C281902C4C4340A08D5C37A5244740
20961	50304	38.707498000000001	38.722912999999998	46.205537999999997	46.192594999999997	Кондруцкого	0103000020E6100000010000000500000022FE614B8F5A4340C22FF5F3A618474022FE614B8F5A4340E90AB6114F1A4740376DC669885C4340E90AB6114F1A4740376DC669885C4340C22FF5F3A618474022FE614B8F5A4340C22FF5F3A6184740
21743	50423	38.675077999999999	38.719940000000001	46.153128000000002	46.125594999999997	Мира	0103000020E61000000100000005000000E21FB6F46856434043C5387F13104740E21FB6F4685643400B0DC4B299134740878A71FE265C43400B0DC4B299134740878A71FE265C434043C5387F13104740E21FB6F46856434043C5387F13104740
20546	10142	38.675077999999999	38.719940000000001	46.153128000000002	46.125594999999997	Мира	0103000020E61000000100000005000000E21FB6F46856434043C5387F13104740E21FB6F4685643400B0DC4B299134740878A71FE265C43400B0DC4B299134740878A71FE265C434043C5387F13104740E21FB6F46856434043C5387F13104740
21210	10363	39.020677999999997	39.037953000000002	45.936391	45.927213999999999	Красноармейская	0103000020E6100000010000000500000093DFA293A58243405932C7F2AEF6464093DFA293A582434066A208A9DBF746407EE4D6A4DB84434066A208A9DBF746407EE4D6A4DB8443405932C7F2AEF6464093DFA293A58243405932C7F2AEF64640
23333	50668	38.770119999999999	38.786541	46.129468000000003	46.123615000000001	Светлая	0103000020E610000001000000050000006DFFCA4A93624340C425C79DD20F47406DFFCA4A9362434074F04C689210474048FB1F60AD64434074F04C689210474048FB1F60AD644340C425C79DD20F47406DFFCA4A93624340C425C79DD20F4740
20774	9984	38.928258999999997	38.996952999999998	46.333105000000003	46.294916999999998	пер. Вольный	0103000020E61000000100000005000000DC9BDF30D176434068041BD7BF254740DC9BDF30D17643402A91442FA32A47401553E9279C7F43402A91442FA32A47401553E9279C7F434068041BD7BF254740DC9BDF30D176434068041BD7BF254740
20576	9984	38.928258999999997	38.996952999999998	46.333105000000003	46.294916999999998	Ленина	0103000020E61000000100000005000000DC9BDF30D176434068041BD7BF254740DC9BDF30D17643402A91442FA32A47401553E9279C7F43402A91442FA32A47401553E9279C7F434068041BD7BF254740DC9BDF30D176434068041BD7BF254740
21430	9984	38.928258999999997	38.996952999999998	46.333105000000003	46.294916999999998	Дружбы	0103000020E61000000100000005000000DC9BDF30D176434068041BD7BF254740DC9BDF30D17643402A91442FA32A47401553E9279C7F43402A91442FA32A47401553E9279C7F434068041BD7BF254740DC9BDF30D176434068041BD7BF254740
20480	9683	38.711782999999997	38.780208000000002	46.336888000000002	46.302345000000003	Мира	0103000020E61000000100000005000000A46C91B41B5B4340F88DAF3DB3264740A46C91B41B5B43401A355F251F2B4740EE0912DBDD6343401A355F251F2B4740EE0912DBDD634340F88DAF3DB3264740A46C91B41B5B4340F88DAF3DB3264740
23807	9683	38.711782999999997	38.780208000000002	46.336888000000002	46.302345000000003	Восточная	0103000020E61000000100000005000000A46C91B41B5B4340F88DAF3DB3264740A46C91B41B5B43401A355F251F2B4740EE0912DBDD6343401A355F251F2B4740EE0912DBDD634340F88DAF3DB3264740A46C91B41B5B4340F88DAF3DB3264740
23515	50744	39.103206	39.147412000000003	46.163091000000001	46.148238999999997	Охотничья	0103000020E610000001000000050000002060ADDA358D4340F17EDC7EF91247402060ADDA358D4340CFA2772AE0144740DC847B65DE924340CFA2772AE0144740DC847B65DE924340F17EDC7EF91247402060ADDA358D4340F17EDC7EF9124740
21024	9670	39.211804000000001	39.242158000000003	45.969467999999999	45.953386000000002	Центральная	0103000020E61000000100000005000000BC94BA641C9B43406D3B6D8D08FA4640BC94BA641C9B43405F42058717FC46407E3B8908FF9E43405F42058717FC46407E3B8908FF9E43406D3B6D8D08FA4640BC94BA641C9B43406D3B6D8D08FA4640
20587	9535	39.146289000000003	39.205587000000001	46.167036000000003	46.145722999999997	Красная	0103000020E61000000100000005000000DD611399B992434033A31F0DA7124740DD611399B992434099A0866F61154740CBBDC0AC509A434099A0866F61154740CBBDC0AC509A434033A31F0DA7124740DD611399B992434033A31F0DA7124740
23596	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	улица Широкая	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
22027	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Элеваторная	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
20468	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Чипигинская	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
21923	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Чигиринская	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
22398	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Таманская	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
20807	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Северная	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
21612	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Октябрьская	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
20476	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Горького	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
20997	9000	38.934618999999998	39.003591999999998	46.115307000000001	46.052709999999998	Герцена	0103000020E61000000100000005000000309C6B98A177434009168733BF064740309C6B98A1774340FCFF3861C20E47407C43E1B375804340FCFF3861C20E47407C43E1B37580434009168733BF064740309C6B98A177434009168733BF064740
22779	50561	39.142857999999997	39.177829000000003	46.111421	46.098579999999998	Полтавская	0103000020E6100000010000000500000069FCC22B499243401405FA449E0C474069FCC22B49924340378B170B430E4740E4A3C519C3964340378B170B430E4740E4A3C519C39643401405FA449E0C474069FCC22B499243401405FA449E0C4740
23624	50792	39.048839999999998	39.085059999999999	46.229433	46.205232000000002	Советская	0103000020E610000001000000050000004A5E9D6340864340DD0BCC0A451A47404A5E9D6340864340C4CF7F0F5E1D47405019FF3EE38A4340C4CF7F0F5E1D47405019FF3EE38A4340DD0BCC0A451A47404A5E9D6340864340DD0BCC0A451A4740
22849	50579	38.583378000000003	38.627116999999998	46.263157	46.247172999999997	Светлая	0103000020E610000001000000050000005B9A5B21AC4A434023BA675DA31F47405B9A5B21AC4A4340535BEA20AF21474000E2AE5E45504340535BEA20AF21474000E2AE5E4550434023BA675DA31F47405B9A5B21AC4A434023BA675DA31F4740
21597	8182	38.66057	38.748911	45.473474000000003	45.384408999999998	Школьная	0103000020E61000000100000005000000FF5BC98E8D544340DFA4695034B14640FF5BC98E8D544340CFC0C8CB9ABC4640AD4ECE50DC5F4340CFC0C8CB9ABC4640AD4ECE50DC5F4340DFA4695034B14640FF5BC98E8D544340DFA4695034B14640
21621	8182	38.66057	38.748911	45.473474000000003	45.384408999999998	Северная	0103000020E61000000100000005000000FF5BC98E8D544340DFA4695034B14640FF5BC98E8D544340CFC0C8CB9ABC4640AD4ECE50DC5F4340CFC0C8CB9ABC4640AD4ECE50DC5F4340DFA4695034B14640FF5BC98E8D544340DFA4695034B14640
20764	8182	38.66057	38.748911	45.473474000000003	45.384408999999998	Красная	0103000020E61000000100000005000000FF5BC98E8D544340DFA4695034B14640FF5BC98E8D544340CFC0C8CB9ABC4640AD4ECE50DC5F4340CFC0C8CB9ABC4640AD4ECE50DC5F4340DFA4695034B14640FF5BC98E8D544340DFA4695034B14640
20564	8637	38.601182999999999	38.625680000000003	45.644339000000002	45.631470999999998	Солнечная	0103000020E61000000100000005000000A1F48590F34C4340ABAFAE0AD4D04640A1F48590F34C4340C8444AB379D2464072E1404816504340C8444AB379D2464072E1404816504340ABAFAE0AD4D04640A1F48590F34C4340ABAFAE0AD4D04640
23530	50753	38.506788	38.537438000000002	45.729267	45.712699999999998	Центральная	0103000020E61000000100000005000000AC00DF6DDE404340FAEDEBC039DB4640AC00DF6DDE404340A986FD9E58DD464057D0B4C4CA444340A986FD9E58DD464057D0B4C4CA444340FAEDEBC039DB4640AC00DF6DDE404340FAEDEBC039DB4640
23371	50680	38.070332000000001	38.085144999999997	45.761676000000001	45.753507999999997	Центральная	0103000020E610000001000000050000005FEE93A3000943401EA33CF372E046405FEE93A300094340F51263997EE146407E350708E60A4340F51263997EE146407E350708E60A43401EA33CF372E046405FEE93A3000943401EA33CF372E04640
21687	50408	38.584726000000003	38.616292000000001	45.397751	45.367435	Гайдара	0103000020E610000001000000050000007A8F334DD84A4340F0332E1C08AF46407A8F334DD84A4340C4793881E9B24640AA6400A8E24E4340C4793881E9B24640AA6400A8E24E4340F0332E1C08AF46407A8F334DD84A4340F0332E1C08AF4640
21222	8669	38.343967999999997	38.397894000000001	45.600991	45.560594000000002	Ленина	0103000020E610000001000000050000006D6FB724072C4340BB2A508BC1C746406D6FB724072C43405D18E945EDCC464027A3CA30EE3243405D18E945EDCC464027A3CA30EE324340BB2A508BC1C746406D6FB724072C4340BB2A508BC1C74640
23953	50875	38.419319000000002	38.472372999999997	45.713315999999999	45.689397	Ленина	0103000020E61000000100000005000000B4CBB73EAC354340F27A30293ED84640B4CBB73EAC35434055DB4DF04DDB4640B741EDB7763C434055DB4DF04DDB4640B741EDB7763C4340F27A30293ED84640B4CBB73EAC354340F27A30293ED84640
21397	47491	38.626389000000003	38.696295999999997	45.500765000000001	45.468051000000003	Фадеева	0103000020E610000001000000050000007EC9C6832D50434018EE5C18E9BB46407EC9C6832D504340A0FD481119C04640F52A323A20594340A0FD481119C04640F52A323A2059434018EE5C18E9BB46407EC9C6832D50434018EE5C18E9BB4640
21281	47491	38.626389000000003	38.696295999999997	45.500765000000001	45.468051000000003	Ленина	0103000020E610000001000000050000007EC9C6832D50434018EE5C18E9BB46407EC9C6832D504340A0FD481119C04640F52A323A20594340A0FD481119C04640F52A323A2059434018EE5C18E9BB46407EC9C6832D50434018EE5C18E9BB4640
21399	47491	38.626389000000003	38.696295999999997	45.500765000000001	45.468051000000003	Коваля	0103000020E610000001000000050000007EC9C6832D50434018EE5C18E9BB46407EC9C6832D504340A0FD481119C04640F52A323A20594340A0FD481119C04640F52A323A2059434018EE5C18E9BB46407EC9C6832D50434018EE5C18E9BB4640
21400	47491	38.626389000000003	38.696295999999997	45.500765000000001	45.468051000000003	Заречная	0103000020E610000001000000050000007EC9C6832D50434018EE5C18E9BB46407EC9C6832D504340A0FD481119C04640F52A323A20594340A0FD481119C04640F52A323A2059434018EE5C18E9BB46407EC9C6832D50434018EE5C18E9BB4640
23538	50757	38.582811999999997	38.609780000000001	45.464846999999999	45.444583000000002	Молодежная	0103000020E61000000100000005000000B1DB6795994A4340C5AD8218E8B84640B1DB6795994A43406552431B80BB4640A0E062450D4E43406552431B80BB4640A0E062450D4E4340C5AD8218E8B84640B1DB6795994A4340C5AD8218E8B84640
21158	6733	40.633665999999998	40.709204999999997	45.461236999999997	45.427191000000001	Ленина	0103000020E61000000100000005000000274BADF71B514440A112D731AEB64640274BADF71B514440425A63D009BB46407094BC3AC75A4440425A63D009BB46407094BC3AC75A4440A112D731AEB64640274BADF71B514440A112D731AEB64640
21436	8785	38.128174999999999	38.209786999999999	45.669449	45.626939	Советская	0103000020E610000001000000050000001895D4096810434021CB82893FD046401895D4096810434082AB3C81B0D546401F10E84CDA1A434082AB3C81B0D546401F10E84CDA1A434021CB82893FD046401895D4096810434021CB82893FD04640
21412	8785	38.128174999999999	38.209786999999999	45.669449	45.626939	Мира	0103000020E610000001000000050000001895D4096810434021CB82893FD046401895D4096810434082AB3C81B0D546401F10E84CDA1A434082AB3C81B0D546401F10E84CDA1A434021CB82893FD046401895D4096810434021CB82893FD04640
23748	50822	38.554721999999998	38.587546000000003	45.674121999999997	45.653235000000002	Советская	0103000020E61000000100000005000000942F68210147434021CD58349DD34640942F682101474340CEC133A149D64640A47213B5344B4340CEC133A149D64640A47213B5344B434021CD58349DD34640942F68210147434021CD58349DD34640
23862	50848	38.511594000000002	38.530763999999998	45.676546000000002	45.656680999999999	Мира	0103000020E61000000100000005000000386A85E97B414340C9737D1F0ED44640386A85E97B414340AC1E300F99D6464073F22213F0434340AC1E300F99D6464073F22213F0434340C9737D1F0ED44640386A85E97B414340C9737D1F0ED44640
20750	50285	38.748632000000001	38.777639000000001	45.377716999999997	45.335270999999999	улица Бойко-Павлова	0103000020E610000001000000050000009A5E622CD35F43400B26FE28EAAA46409A5E622CD35F43405512D90759B046400D8CBCAC896343405512D90759B046400D8CBCAC896343400B26FE28EAAA46409A5E622CD35F43400B26FE28EAAA4640
23452	50717	38.652476	38.685121000000002	45.330804000000001	45.304160000000003	Красная	0103000020E6100000010000000500000063B66455845343402D6002B7EEA6464063B664558453434068B114C957AA4640C366800BB257434068B114C957AA4640C366800BB25743402D6002B7EEA6464063B66455845343402D6002B7EEA64640
23791	50830	38.392575999999998	38.427835000000002	45.558985	45.520262000000002	Центральная	0103000020E61000000100000005000000E5982CEE3F32434000ADF9F197C24640E5982CEE3F3243402FFA0AD28CC74640C68A1A4CC33643402FFA0AD28CC74640C68A1A4CC336434000ADF9F197C24640E5982CEE3F32434000ADF9F197C24640
20426	6939	40.779741000000001	40.804166000000002	45.544947999999998	45.539608000000001	Красноармейская	0103000020E61000000100000005000000D82C978DCE6344407A54FCDF11C54640D82C978DCE634440A30227DBC0C546400F4757E9EE664440A30227DBC0C546400F4757E9EE6644407A54FCDF11C54640D82C978DCE6344407A54FCDF11C54640
21574	50391	40.81765	40.883451000000001	45.457512999999999	45.428538000000003	Вокзальная	0103000020E6100000010000000500000086C954C1A8684440F08B4B55DAB6464086C954C1A8684440573F36C98FBA46402B4F20EC14714440573F36C98FBA46402B4F20EC14714440F08B4B55DAB6464086C954C1A8684440F08B4B55DAB64640
21495	6848	40.81765	40.883451000000001	45.457512999999999	45.428538000000003	Трактовая	0103000020E6100000010000000500000086C954C1A8684440F08B4B55DAB6464086C954C1A8684440573F36C98FBA46402B4F20EC14714440573F36C98FBA46402B4F20EC14714440F08B4B55DAB6464086C954C1A8684440F08B4B55DAB64640
21035	50319	40.524825999999997	40.620820000000002	45.609560000000002	45.591133999999997	Ленина	0103000020E61000000100000005000000950B957F2D434440DEC66647AACB4640950B957F2D4344409279E40F06CE4640F3599E07774F44409279E40F06CE4640F3599E07774F4440DEC66647AACB4640950B957F2D434440DEC66647AACB4640
22068	7533	40.261448999999999	40.277655000000003	45.564940999999997	45.552301	Школьная	0103000020E6100000010000000500000034492C2977214440284696CCB1C6464034492C2977214440B39597FC4FC846401349F4328A234440B39597FC4FC846401349F4328A234440284696CCB1C6464034492C2977214440284696CCB1C64640
20726	47140	40.728105999999997	40.743125999999997	45.536842999999998	45.523975	Первомайская	0103000020E61000000100000005000000BC02D193325D4440F775E09C11C34640BC02D193325D4440130B7C45B7C446405567B5C01E5F4440130B7C45B7C446405567B5C01E5F4440F775E09C11C34640BC02D193325D4440F775E09C11C34640
23367	47395	40.384770000000003	40.418177999999997	45.558681999999997	45.527619000000001	Ленина	0103000020E61000000100000005000000B03DB32440314440C6DFF60489C34640B03DB32440314440936E4BE482C746400EF450DB86354440936E4BE482C746400EF450DB86354440C6DFF60489C34640B03DB32440314440C6DFF60489C34640
21989	47208	40.582112000000002	40.610273999999997	45.559105000000002	45.545231999999999	Мира	0103000020E61000000100000005000000F94D61A5824A4440C85D8429CAC54640F94D61A5824A4440DA03ADC090C74640AFCC5B751D4E4440DA03ADC090C74640AFCC5B751D4E4440C85D8429CAC54640F94D61A5824A4440C85D8429CAC54640
23503	50328	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	переулок Белинского	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
21280	50328	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	Целых	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
21230	50328	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	С.Целых	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
21114	50328	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	Микрорайон-1	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
23823	50328	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	Красноармейская	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
23298	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	улица Мира	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23409	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	пер.Белинского	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23084	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Шоссейная	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23500	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Шаумяна	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23442	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Черноморская	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
22486	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Целых	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
22846	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Пушкина	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
20629	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Микрорайон-1	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
20718	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Микрорайон №1	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23880	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Красноармейская	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
22759	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Красная	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23074	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Комсомольская	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23542	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	Гоголя	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
23831	32672	40.49926	40.616059	45.469239999999999	45.410882000000001	1 проезд	0103000020E61000000100000005000000B9196EC0E73F4440EE4108C897B44640B9196EC0E73F4440CEFC6A0E10BC464007B47405DB4E4440CEFC6A0E10BC464007B47405DB4E4440EE4108C897B44640B9196EC0E73F4440EE4108C897B44640
24011	50893	40.464289000000001	40.481662	45.572808999999999	45.567332999999998	Мира	0103000020E610000001000000050000003F726BD26D3B44408578245E9EC846403F726BD26D3B44405FED28CE51C94640ECDCB419A73D44405FED28CE51C94640ECDCB419A73D44408578245E9EC846403F726BD26D3B44408578245E9EC84640
23405	50591	40.389746000000002	40.483144000000003	45.429101000000003	45.396985000000001	Ленина	0103000020E6100000010000000500000098DF6932E331444054008C67D0B2464098DF6932E331444028D714C8ECB646401BA19FA9D73D444028D714C8ECB646401BA19FA9D73D444054008C67D0B2464098DF6932E331444054008C67D0B24640
22929	50591	40.389746000000002	40.483144000000003	45.429101000000003	45.396985000000001	Красная	0103000020E6100000010000000500000098DF6932E331444054008C67D0B2464098DF6932E331444028D714C8ECB646401BA19FA9D73D444028D714C8ECB646401BA19FA9D73D444054008C67D0B2464098DF6932E331444054008C67D0B24640
22955	50600	40.464289000000001	40.481662	45.572808999999999	45.567332999999998	Красная	0103000020E610000001000000050000003F726BD26D3B44408578245E9EC846403F726BD26D3B44405FED28CE51C94640ECDCB419A73D44405FED28CE51C94640ECDCB419A73D44408578245E9EC846403F726BD26D3B44408578245E9EC84640
22277	50484	40.633665999999998	40.709204999999997	45.461236999999997	45.427191000000001	Ленина	0103000020E61000000100000005000000274BADF71B514440A112D731AEB64640274BADF71B514440425A63D009BB46407094BC3AC75A4440425A63D009BB46407094BC3AC75A4440A112D731AEB64640274BADF71B514440A112D731AEB64640
20982	6733	40.633665999999998	40.709204999999997	45.461236999999997	45.427191000000001	Первомайский	0103000020E61000000100000005000000274BADF71B514440A112D731AEB64640274BADF71B514440425A63D009BB46407094BC3AC75A4440425A63D009BB46407094BC3AC75A4440A112D731AEB64640274BADF71B514440A112D731AEB64640
20959	6733	40.633665999999998	40.709204999999997	45.461236999999997	45.427191000000001	Калинина	0103000020E61000000100000005000000274BADF71B514440A112D731AEB64640274BADF71B514440425A63D009BB46407094BC3AC75A4440425A63D009BB46407094BC3AC75A4440A112D731AEB64640274BADF71B514440A112D731AEB64640
20729	47206	40.722779000000003	40.797797000000003	45.674128000000003	45.639519	Фрунзе	0103000020E61000000100000005000000289EB305845C4440D71533C2DBD14640289EB305845C4440B1A888D349D6464068EC4B361E664440B1A888D349D6464068EC4B361E664440D71533C2DBD14640289EB305845C4440D71533C2DBD14640
22133	7404	40.495010999999998	40.519688000000002	45.470497000000002	45.461939000000001	Молодежная	0103000020E6100000010000000500000083143C855C3F44409CDF30D120BB464083143C855C3F4440DDEEE53E39BC4640D40FEA2285424440DDEEE53E39BC4640D40FEA22854244409CDF30D120BB464083143C855C3F44409CDF30D120BB4640
21077	46882	40.447992999999997	40.463444000000003	45.522195000000004	45.507555000000004	Таманская	0103000020E6100000010000000500000020EBA9D557394440EDF5EE8FF7C0464020EBA9D5573944403F912749D7C2464083C30B22523B44403F912749D7C2464083C30B22523B4440EDF5EE8FF7C0464020EBA9D557394440EDF5EE8FF7C04640
21066	45882	38.315958999999999	38.326208000000001	46.448751000000001	46.431499000000002	Центральная	0103000020E610000001000000050000003DF0315871284340DCA0F65B3B3747403DF03158712843400E863AAC70394740C7D8092FC12943400E863AAC70394740C7D8092FC1294340DCA0F65B3B3747403DF0315871284340DCA0F65B3B374740
20472	4271	38.286934000000002	38.302430000000001	46.263112999999997	46.246993000000003	Кирова	0103000020E61000000100000005000000240ED940BA244340A4AB74779D1F4740240ED940BA2443408313D1AFAD21474026AAB706B62643408313D1AFAD21474026AAB706B6264340A4AB74779D1F4740240ED940BA244340A4AB74779D1F4740
23707	50811	38.251674999999999	38.285846999999997	46.369812000000003	46.348728000000001	Ленина	0103000020E61000000100000005000000431CEBE23620434089997D1EA32C4740431CEBE2362043408DD5E6FF552F474071546EA2962443408DD5E6FF552F474071546EA29624434089997D1EA32C4740431CEBE23620434089997D1EA32C4740
20762	6025	38.317405000000001	38.344965000000002	46.665601000000002	46.650942000000001	Косиора	0103000020E610000001000000050000001F4B1FBAA0284340E2CB4411525347401F4B1FBAA0284340AB97DF6932554740E0A128D0272C4340AB97DF6932554740E0A128D0272C4340E2CB4411525347401F4B1FBAA0284340E2CB441152534740
20616	45824	38.128408	38.145583999999999	46.520859999999999	46.511718999999999	Ленина	0103000020E61000000100000005000000BB4560AC6F104340F4DE180280414740BB4560AC6F104340B4E55C8AAB42474012691B7FA2124340B4E55C8AAB42474012691B7FA2124340F4DE180280414740BB4560AC6F104340F4DE180280414740
21646	6198	38.186484	38.209356	46.697291999999997	46.687550000000002	Центральная	0103000020E61000000100000005000000179D2CB5DE174340B22E6EA301584740179D2CB5DE17434097E13FDD40594740569C6A2DCC1A434097E13FDD40594740569C6A2DCC1A4340B22E6EA301584740179D2CB5DE174340B22E6EA301584740
23625	50791	38.051962000000003	38.067655000000002	46.555097000000004	46.538760000000003	Шоссейная	0103000020E610000001000000050000004051D9B0A60643404D327216F64447404051D9B0A6064340CA8D226B0D474740983446EBA8084340CA8D226B0D474740983446EBA80843404D327216F64447404051D9B0A60643404D327216F6444740
21146	50334	38.002186000000002	38.017493000000002	46.565308999999999	46.551937000000002	Светлая	0103000020E6100000010000000500000029417FA147004340E73922DFA546474029417FA1470043403691990B5C4847405874EB353D0243403691990B5C4847405874EB353D024340E73922DFA546474029417FA147004340E73922DFA5464740
21063	3424	38.132531999999998	38.160173	46.633470000000003	46.617390999999998	Советов	0103000020E6100000010000000500000034D6FECEF610434020EC14AB064F474034D6FECEF6104340A27F828B15514740E259828C80144340A27F828B15514740E259828C8014434020EC14AB064F474034D6FECEF610434020EC14AB064F4740
21579	6155	38.255367	38.269326999999997	46.654387	46.645733	Комсомольская	0103000020E6100000010000000500000023BDA8DDAF20434057790261A752474023BDA8DDAF204340BAF605F4C25347400377A04E79224340BAF605F4C25347400377A04E7922434057790261A752474023BDA8DDAF20434057790261A7524740
21364	50357	38.459544999999999	38.504550999999999	46.288615	46.267960000000002	Мешкова	0103000020E610000001000000050000002905DD5ED23A43406E5166834C2247402905DD5ED23A434049111956F124474001158E209540434049111956F124474001158E20954043406E5166834C2247402905DD5ED23A43406E5166834C224740
20604	3720	38.251001000000002	38.270755000000001	46.584252999999997	46.574601999999999	Школьная	0103000020E61000000100000005000000B421FFCC20204340AC1BEF8E8C494740B421FFCC2020434081CB63CDC84A47403F1D8F19A822434081CB63CDC84A47403F1D8F19A8224340AC1BEF8E8C494740B421FFCC20204340AC1BEF8E8C494740
23305	50646	37.926521000000001	37.985657000000003	46.420124999999999	46.399296999999997	Победы	0103000020E610000001000000050000005307793D98F642400932022A1C3347405307793D98F64240B29DEFA7C6354740680932022AFE4240B29DEFA7C6354740680932022AFE42400932022A1C3347405307793D98F642400932022A1C334740
23499	50646	37.926521000000001	37.985657000000003	46.420124999999999	46.399296999999997	Азовская	0103000020E610000001000000050000005307793D98F642400932022A1C3347405307793D98F64240B29DEFA7C6354740680932022AFE4240B29DEFA7C6354740680932022AFE42400932022A1C3347405307793D98F642400932022A1C334740
23227	50647	37.926521000000001	37.985657000000003	46.420124999999999	46.399296999999997	Советская	0103000020E610000001000000050000005307793D98F642400932022A1C3347405307793D98F64240B29DEFA7C6354740680932022AFE4240B29DEFA7C6354740680932022AFE42400932022A1C3347405307793D98F642400932022A1C334740
22216	50473	38.457309000000002	38.465392999999999	46.430833999999997	46.421691000000003	Мира	0103000020E610000001000000050000004F95EF19893A43403F027FF8F93547404F95EF19893A43409F008A9125374740C76471FF913B43409F008A9125374740C76471FF913B43403F027FF8F93547404F95EF19893A43403F027FF8F9354740
21733	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	угол ул.К.Маркса и ул.Гоголя	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21498	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Ясенская	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21735	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Янышева	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20778	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Юности переулок 	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21102	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Театральная площадь	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20661	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Пушкина	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21509	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Портовая аллея	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21254	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Первомайская	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20897	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Красная	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20432	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Коммунистическая	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21343	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Кирпичная	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20600	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	К. Либкнехта	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21136	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Герцена	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20861	50243	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Баррикадная	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21311	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Харьковская	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21682	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Таманская	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20419	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Свердлова	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
21154	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Романа	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20418	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Первомайская	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20427	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Коммунистическая	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
20809	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Коммунаров	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
22551	1328	38.239879999999999	38.314960999999997	46.728161999999998	46.668241000000002	Бердянская	0103000020E61000000100000005000000747B4963B41E4340556CCCEB88554740747B4963B41E434050189469345D4740FA415DA45028434050189469345D4740FA415DA450284340556CCCEB88554740747B4963B41E4340556CCCEB88554740
22775	50560	37.779682000000001	37.819603000000001	46.648634000000001	46.609392999999997	Октябрьская	0103000020E61000000100000005000000D3A3A99ECCE34240A6B4FE96004E4740D3A3A99ECCE342406E895C70065347400C5A48C0E8E842406E895C70065347400C5A48C0E8E84240A6B4FE96004E4740D3A3A99ECCE34240A6B4FE96004E4740
23937	50560	37.779682000000001	37.819603000000001	46.648634000000001	46.609392999999997	Ленина	0103000020E61000000100000005000000D3A3A99ECCE34240A6B4FE96004E4740D3A3A99ECCE342406E895C70065347400C5A48C0E8E842406E895C70065347400C5A48C0E8E84240A6B4FE96004E4740D3A3A99ECCE34240A6B4FE96004E4740
22802	50567	37.779682000000001	37.819603000000001	46.648634000000001	46.609392999999997	Октябрьская	0103000020E61000000100000005000000D3A3A99ECCE34240A6B4FE96004E4740D3A3A99ECCE342406E895C70065347400C5A48C0E8E842406E895C70065347400C5A48C0E8E84240A6B4FE96004E4740D3A3A99ECCE34240A6B4FE96004E4740
20719	45686	38.064844000000001	38.094029999999997	46.661178999999997	46.642949000000002	Мира	0103000020E61000000100000005000000C1ABE5CE4C0843407AFF1F274C524740C1ABE5CE4C084340A7E67283A1544740E36BCF2C090C4340A7E67283A1544740E36BCF2C090C43407AFF1F274C524740C1ABE5CE4C0843407AFF1F274C524740
23370	45831	38.227761999999998	38.238208999999998	46.519831000000003	46.511192000000001	Парковая	0103000020E61000000100000005000000C2A2224E271D434009FD4CBD6E414740C2A2224E271D434037397CD289424740724EECA17D1E434037397CD289424740724EECA17D1E434009FD4CBD6E414740C2A2224E271D434009FD4CBD6E414740
21396	46070	38.391705000000002	38.409391999999997	46.654901000000002	46.635702999999999	Советская	0103000020E610000001000000050000000057B263233243400B7C45B75E5147400057B26323324340118FC4CBD35347403C9F01F566344340118FC4CBD35347403C9F01F5663443400B7C45B75E5147400057B263233243400B7C45B75E514740
22360	50497	39.312271000000003	39.444071999999998	45.160054000000002	45.06673	Западная	0103000020E610000001000000050000009F3E027FF8A74340BFD4CF9B8A8846409F3E027FF8A7434008CC43A67C944640DF88EE59D7B8434008CC43A67C944640DF88EE59D7B84340BFD4CF9B8A8846409F3E027FF8A74340BFD4CF9B8A884640
22499	32718	39.241025999999998	39.250960999999997	45.135942999999997	45.125584000000003	Садовая	0103000020E610000001000000050000002BBEA1F0D99E43405073F222139046402BBEA1F0D99E4340608F89946691464025C9737D1FA04340608F89946691464025C9737D1FA043405073F222139046402BBEA1F0D99E43405073F22213904640
23501	1227	39.336184000000003	39.37509	45.259557999999998	45.245345	Украинская	0103000020E6100000010000000500000020B8CA1308AB43405A9E0777679F464020B8CA1308AB434024B5503239A146404087F9F202B0434024B5503239A146404087F9F202B043405A9E0777679F464020B8CA1308AB43405A9E0777679F4640
20808	1227	39.336184000000003	39.37509	45.259557999999998	45.245345	Советов	0103000020E6100000010000000500000020B8CA1308AB43405A9E0777679F464020B8CA1308AB434024B5503239A146404087F9F202B0434024B5503239A146404087F9F202B043405A9E0777679F464020B8CA1308AB43405A9E0777679F4640
21049	2045	39.048400000000001	39.122124999999997	45.360658999999998	45.326830999999999	Советская	0103000020E610000001000000050000002E90A0F831864340D4282499D5A946402E90A0F8318643400801F9122AAE46401283C0CAA18F43400801F9122AAE46401283C0CAA18F4340D4282499D5A946402E90A0F831864340D4282499D5A94640
22516	2045	39.048400000000001	39.122124999999997	45.360658999999998	45.326830999999999	Красная	0103000020E610000001000000050000002E90A0F831864340D4282499D5A946402E90A0F8318643400801F9122AAE46401283C0CAA18F43400801F9122AAE46401283C0CAA18F4340D4282499D5A946402E90A0F831864340D4282499D5A94640
21217	50344	39.378368999999999	39.388807999999997	45.118983	45.109741	Луначарского	0103000020E61000000100000005000000FD6838656EB04340E2033BFE0B8E4640FD6838656EB04340D6E3BED53A8F46402A36E675C4B14340D6E3BED53A8F46402A36E675C4B14340E2033BFE0B8E4640FD6838656EB04340E2033BFE0B8E4640
22963	50606	38.848570000000002	38.868763999999999	45.220500999999999	45.183793999999999	улица Новотитаровская	0103000020E61000000100000005000000F12E17F19D6C4340BB99D18F86974640F12E17F19D6C43401EDE7360399C464098F8A3A8336F43401EDE7360399C464098F8A3A8336F4340BB99D18F86974640F12E17F19D6C4340BB99D18F86974640
20815	1795	39.221254000000002	39.315289	45.308368999999999	45.281047999999998	Мира	0103000020E61000000100000005000000FA0D130D529C4340984D8061F9A34640FA0D130D529C4340D40CA9A278A74640EFE4D3635BA84340D40CA9A278A74640EFE4D3635BA84340984D8061F9A34640FA0D130D529C4340984D8061F9A34640
20585	1795	39.221254000000002	39.315289	45.308368999999999	45.281047999999998	Красная	0103000020E61000000100000005000000FA0D130D529C4340984D8061F9A34640FA0D130D529C4340D40CA9A278A74640EFE4D3635BA84340D40CA9A278A74640EFE4D3635BA84340984D8061F9A34640FA0D130D529C4340984D8061F9A34640
21044	1795	39.221254000000002	39.315289	45.308368999999999	45.281047999999998	Базарная	0103000020E61000000100000005000000FA0D130D529C4340984D8061F9A34640FA0D130D529C4340D40CA9A278A74640EFE4D3635BA84340D40CA9A278A74640EFE4D3635BA84340984D8061F9A34640FA0D130D529C4340984D8061F9A34640
22035	1688	39.260455999999998	39.362333999999997	45.172516000000002	45.149351000000003	Ленина	0103000020E610000001000000050000000306499F56A14340FD4FFEEE1D9346400306499F56A14340B4041901159646404B1DE4F560AE4340B4041901159646404B1DE4F560AE4340FD4FFEEE1D9346400306499F56A14340FD4FFEEE1D934640
24035	50584	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Южная	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
23906	50584	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Широкая	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
23435	50584	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Степная	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
23016	50584	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Советская	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
22972	50584	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Октябрьская	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
23417	50584	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Новотитаровская	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
22891	50584	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Луначарского	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
22962	50605	38.899208000000002	39.033532999999998	45.258923000000003	45.223827999999997	Крайняя	0103000020E610000001000000050000009A266C3F19734340ECF65965A69C46409A266C3F1973434053978C6324A146401B2B31CF4A84434053978C6324A146401B2B31CF4A844340ECF65965A69C46409A266C3F19734340ECF65965A69C4640
23703	50658	38.820093	38.876364000000002	45.306575000000002	45.255153999999997	Свердлова	0103000020E61000000100000005000000DA56B3CEF8684340C7B8E2E2A8A04640DA56B3CEF8684340B7627FD93DA7464025B20FB22C704340B7627FD93DA7464025B20FB22C704340C7B8E2E2A8A04640DA56B3CEF8684340C7B8E2E2A8A04640
23275	50658	38.820093	38.876364000000002	45.306575000000002	45.255153999999997	Красная	0103000020E61000000100000005000000DA56B3CEF8684340C7B8E2E2A8A04640DA56B3CEF8684340B7627FD93DA7464025B20FB22C704340B7627FD93DA7464025B20FB22C704340C7B8E2E2A8A04640DA56B3CEF8684340C7B8E2E2A8A04640
21460	3065	38.809249999999999	38.833604000000001	45.332470000000001	45.324472999999998	Школьная 	0103000020E61000000100000005000000DD24068195674340AEB7CD5488A94640DD24068195674340587380608EAA46404BE82E89B36A4340587380608EAA46404BE82E89B36A4340AEB7CD5488A94640DD24068195674340AEB7CD5488A94640
20579	49526	39.149298999999999	39.18383	45.315956	45.264201	Кирова	0103000020E61000000100000005000000AA29C93A1C93434006499F56D1A14640AA29C93A1C934340CC7C073F71A846400803CFBD87974340CC7C073F71A846400803CFBD8797434006499F56D1A14640AA29C93A1C93434006499F56D1A14640
21661	1375	39.223868000000003	39.242894	45.164763999999998	45.151595	Центральная	0103000020E610000001000000050000007B4FE5B4A79C43405A9E0777679346407B4FE5B4A79C434071C79BFC1695464083328D26179F434071C79BFC1695464083328D26179F43405A9E0777679346407B4FE5B4A79C43405A9E077767934640
21654	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	переулокТельмана	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
21334	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Тельмана	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
23684	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Мира	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
21226	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Луначарского	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
20799	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Краснодарская	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
20560	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Красная	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
21652	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Комарова	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
20785	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Кирова	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
21642	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Калинина	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
9844	554	39.201697000000003	39.257860000000001	45.250084999999999	45.178373999999998	Гоголя	0103000020E61000000100000005000000C5591135D1994340753A90F5D4964640C5591135D19943402E1C08C902A046402979758E01A143402E1C08C902A046402979758E01A14340753A90F5D4964640C5591135D1994340753A90F5D4964640
20642	49685	38.847949999999997	38.854472000000001	45.406838999999998	45.401890000000002	Центральная	0103000020E61000000100000005000000545227A0896C4340734BAB2171B34640545227A0896C434061DEE34C13B4464082ACA7565F6D434061DEE34C13B4464082ACA7565F6D4340734BAB2171B34640545227A0896C4340734BAB2171B34640
23573	50775	38.727494999999998	38.749926000000002	45.227218000000001	45.211573999999999	 Красная	0103000020E610000001000000050000007380608E1E5D43408A5759DB149B46407380608E1E5D43400188BB7A159D4640C6353E93FD5F43400188BB7A159D4640C6353E93FD5F43408A5759DB149B46407380608E1E5D43408A5759DB149B4640
22032	50455	39.394117000000001	39.449731	45.131956000000002	45.099085000000002	Луначарского	0103000020E6100000010000000500000019E6046D72B24340184339D1AE8C464019E6046D72B24340684128EFE3904640AA7F10C990B94340684128EFE3904640AA7F10C990B94340184339D1AE8C464019E6046D72B24340184339D1AE8C4640
22493	50455	39.394117000000001	39.449731	45.131956000000002	45.099085000000002	Интернациональная	0103000020E6100000010000000500000019E6046D72B24340184339D1AE8C464019E6046D72B24340684128EFE3904640AA7F10C990B94340684128EFE3904640AA7F10C990B94340184339D1AE8C464019E6046D72B24340184339D1AE8C4640
21040	1243	39.180416000000001	39.222017000000001	45.151417000000002	45.129826000000001	Почтовая	0103000020E610000001000000050000006BD619DF17974340D3156C239E9046406BD619DF179743407B87DBA161934640F913950D6B9C43407B87DBA161934640F913950D6B9C4340D3156C239E9046406BD619DF17974340D3156C239E904640
22819	50571	40.718763000000003	40.736721000000003	45.422092999999997	45.409008999999998	Северная	0103000020E6100000010000000500000095490D6D005C444084622B685AB4464095490D6D005C44406D6FB72407B6464062A3ACDF4C5E44406D6FB72407B6464062A3ACDF4C5E444084622B685AB4464095490D6D005C444084622B685AB44640
23970	50882	40.743763000000001	40.769033	45.120986000000002	45.104633	Советская	0103000020E61000000100000005000000C87C40A0335F44408B8A389D648D4640C87C40A0335F44400EA320787C8F4640BB4560AC6F6244400EA320787C8F4640BB4560AC6F6244408B8A389D648D4640C87C40A0335F44408B8A389D648D4640
20783	50289	40.465527999999999	40.480089999999997	45.351120999999999	45.340598999999997	Ветеранов	0103000020E61000000100000005000000A7AFE76B963B444070067FBF98AB4640A7AFE76B963B44402BF86D88F1AC46407D91D096733D44402BF86D88F1AC46407D91D096733D444070067FBF98AB4640A7AFE76B963B444070067FBF98AB4640
23321	50665	40.758011000000003	40.781942000000001	45.188735999999999	45.172998999999997	Красная	0103000020E610000001000000050000000F81238106614440CF9ECBD4249646400F81238106614440F7C951802898464036AFEAAC16644440F7C951802898464036AFEAAC16644440CF9ECBD4249646400F81238106614440CF9ECBD424964640
21427	50369	40.620505999999999	40.637124	45.368245000000002	45.352944999999998	Шукшина	0103000020E61000000100000005000000637C98BD6C4F4440B324404D2DAD4640637C98BD6C4F444030F5F3A622AF464094BF7B478D51444030F5F3A622AF464094BF7B478D514440B324404D2DAD4640637C98BD6C4F4440B324404D2DAD4640
21431	49010	40.601973000000001	40.686711000000003	45.266008999999997	45.246943999999999	Ленина 	0103000020E610000001000000050000009A0986730D4D4440C2F869DC9B9F46409A0986730D4D444088B839950CA24640D8666325E657444088B839950CA24640D8666325E6574440C2F869DC9B9F46409A0986730D4D4440C2F869DC9B9F4640
21212	49010	40.601973000000001	40.686711000000003	45.266008999999997	45.246943999999999	Кирова	0103000020E610000001000000050000009A0986730D4D4440C2F869DC9B9F46409A0986730D4D444088B839950CA24640D8666325E657444088B839950CA24640D8666325E6574440C2F869DC9B9F46409A0986730D4D4440C2F869DC9B9F4640
21014	50312	40.434950000000001	40.452826000000002	45.367649999999998	45.358638999999997	Садовая	0103000020E6100000010000000500000096B20C71AC374440FA08FCE1E7AD464096B20C71AC374440EC2FBB270FAF4640A663CE33F6394440EC2FBB270FAF4640A663CE33F6394440FA08FCE1E7AD464096B20C71AC374440FA08FCE1E7AD4640
23531	50312	40.434950000000001	40.452826000000002	45.367649999999998	45.358638999999997	Буденного	0103000020E6100000010000000500000096B20C71AC374440FA08FCE1E7AD464096B20C71AC374440EC2FBB270FAF4640A663CE33F6394440EC2FBB270FAF4640A663CE33F6394440FA08FCE1E7AD464096B20C71AC374440FA08FCE1E7AD4640
23282	50660	40.397219999999997	40.436278999999999	45.204157000000002	45.189872999999999	Октябрьская	0103000020E6100000010000000500000097A8DE1AD83244405BB22AC24D98464097A8DE1AD8324440EF1F0BD1219A46403E7782FDD7374440EF1F0BD1219A46403E7782FDD73744405BB22AC24D98464097A8DE1AD83244405BB22AC24D984640
24016	50898	40.592379000000001	40.617308000000001	45.370113000000003	45.364553000000001	Красная	0103000020E6100000010000000500000029EB3713D34B4440505436ACA9AE464029EB3713D34B44408869DFDC5FAF464093C7D3F2034F44408869DFDC5FAF464093C7D3F2034F4440505436ACA9AE464029EB3713D34B4440505436ACA9AE4640
21949	48947	40.574539000000001	40.640340000000002	45.182256000000002	45.169834999999999	Советская	0103000020E6100000010000000500000066A3737E8A494440AB5B3D27BD95464066A3737E8A494440F9BF232A549746400B293FA9F6514440F9BF232A549746400B293FA9F6514440AB5B3D27BD95464066A3737E8A494440AB5B3D27BD954640
21420	32140	40.914866000000004	40.960760000000001	45.325189000000002	45.287688000000003	Красная	0103000020E61000000100000005000000761C3F541A754440D0B9DBF5D2A44640761C3F541A7544406D020CCB9FA9464009A7052FFA7A44406D020CCB9FA9464009A7052FFA7A4440D0B9DBF5D2A44640761C3F541A754440D0B9DBF5D2A44640
23603	11374	40.816473000000002	40.852352000000003	45.257660999999999	45.232607000000002	Ленина	0103000020E610000001000000050000009488F02F826844400CE9F010C69D46409488F02F82684440323A2009FBA046401157CEDE196D4440323A2009FBA046401157CEDE196D44400CE9F010C69D46409488F02F826844400CE9F010C69D4640
20999	11374	40.816473000000002	40.852352000000003	45.257660999999999	45.232607000000002	Ленина	0103000020E610000001000000050000009488F02F826844400CE9F010C69D46409488F02F82684440323A2009FBA046401157CEDE196D4440323A2009FBA046401157CEDE196D44400CE9F010C69D46409488F02F826844400CE9F010C69D4640
23078	50627	40.480835999999996	40.491570000000003	45.248187000000001	45.244069000000003	Октябрьская	0103000020E61000000100000005000000A65EB7088C3D4440D57B2AA73D9F4640A65EB7088C3D44406C257497C49F4640EDD808C4EB3E44406C257497C49F4640EDD808C4EB3E4440D57B2AA73D9F4640A65EB7088C3D4440D57B2AA73D9F4640
20954	30791	40.479398000000003	40.556752000000003	45.389718999999999	45.369227000000002	Красная	0103000020E6100000010000000500000048E2E5E95C3D44406DE690D442AF464048E2E5E95C3D44409ED0EB4FE2B14640C6FD47A6434744409ED0EB4FE2B14640C6FD47A6434744406DE690D442AF464048E2E5E95C3D44406DE690D442AF4640
23985	50888	40.687007999999999	40.728735	45.253872999999999	45.240533999999997	Восточная	0103000020E61000000100000005000000910BCEE0EF574440BCC96FD1C99E4640910BCEE0EF574440302B14E97EA04640AC394030475D4440302B14E97EA04640AC394030475D4440BCC96FD1C99E4640910BCEE0EF574440BCC96FD1C99E4640
20512	33131	40.993476999999999	41.023355000000002	45.299253	45.277889999999999	Октябрьская	0103000020E61000000100000005000000022A1C412A7F444056F146E691A34640022A1C412A7F44406D1D1CEC4DA646405B99F04BFD8244406D1D1CEC4DA646405B99F04BFD82444056F146E691A34640022A1C412A7F444056F146E691A34640
23902	50860	40.654552000000002	40.687969000000002	45.162863000000002	45.139713	Красная	0103000020E6100000010000000500000005C4245CC8534440BCE9961DE291464005C4245CC85344403E5DDDB1D8944640B7D4415E0F5844403E5DDDB1D8944640B7D4415E0F584440BCE9961DE291464005C4245CC8534440BCE9961DE2914640
21172	31785	40.515591000000001	40.586387999999999	45.251010999999998	45.234403	Октябрьская	0103000020E61000000100000005000000548EC9E2FE414440CA8AE1EA009E4640548EC9E2FE414440D7F7E12021A04640286211C30E4B4440D7F7E12021A04640286211C30E4B4440CA8AE1EA009E4640548EC9E2FE414440CA8AE1EA009E4640
21611	31785	40.515591000000001	40.586387999999999	45.251010999999998	45.234403	Заречная	0103000020E61000000100000005000000548EC9E2FE414440CA8AE1EA009E4640548EC9E2FE414440D7F7E12021A04640286211C30E4B4440D7F7E12021A04640286211C30E4B4440CA8AE1EA009E4640548EC9E2FE414440CA8AE1EA009E4640
22430	50503	40.300148	40.320289000000002	45.348985999999996	45.337349000000003	Красная,	0103000020E61000000100000005000000DBFAE93F6B2644404E2B85402EAB4640DBFAE93F6B2644408461C092ABAC46406022DE3AFF2844408461C092ABAC46406022DE3AFF2844404E2B85402EAB4640DBFAE93F6B2644404E2B85402EAB4640
23214	50644	40.689191000000001	40.707445	45.287909999999997	45.279431000000002	Первомайская	0103000020E6100000010000000500000049D92269375844408A3E1F65C4A3464049D92269375844407E18213CDAA44640FF5BC98E8D5A44407E18213CDAA44640FF5BC98E8D5A44408A3E1F65C4A3464049D92269375844408A3E1F65C4A34640
20470	30178	40.729875	40.779992999999997	45.407395000000001	45.381148000000003	Кирова	0103000020E610000001000000050000008195438B6C5D4440C9772975C9B046408195438B6C5D4440E7C6F48425B44640F10D85CFD6634440E7C6F48425B44640F10D85CFD6634440C9772975C9B046408195438B6C5D4440C9772975C9B04640
21361	30178	40.729875	40.779992999999997	45.407395000000001	45.381148000000003	Базарная	0103000020E610000001000000050000008195438B6C5D4440C9772975C9B046408195438B6C5D4440E7C6F48425B44640F10D85CFD6634440E7C6F48425B44640F10D85CFD6634440C9772975C9B046408195438B6C5D4440C9772975C9B04640
21188	31086	40.933298999999998	40.945076	45.372253000000001	45.364305999999999	Рабочая	0103000020E61000000100000005000000DB3175577677444048DE3994A1AE4640DB31755776774440406B7EFCA5AF4640041E1840F8784440406B7EFCA5AF4640041E1840F878444048DE3994A1AE4640DB3175577677444048DE3994A1AE4640
21004	50309	40.400570999999999	40.421492999999998	45.360298	45.350467999999999	Школьная	0103000020E61000000100000005000000EE5C18E945334440B325AB22DCAC4640EE5C18E9453344403868AF3E1EAE4640183F8D7BF33544403868AF3E1EAE4640183F8D7BF3354440B325AB22DCAC4640EE5C18E945334440B325AB22DCAC4640
24031	50902	40.759501999999998	40.785257000000001	45.348377999999997	45.340409000000001	Мира	0103000020E61000000100000005000000909F8D5C37614440CD21A98592AB4640909F8D5C37614440AC527AA697AC464040FA264D83644440AC527AA697AC464040FA264D83644440CD21A98592AB4640909F8D5C37614440CD21A98592AB4640
20751	30608	40.569589000000001	40.618789999999997	45.40258	45.380724000000001	Школьная	0103000020E61000000100000005000000A794D74AE8484440B2666490BBB04640A794D74AE84844400803CFBD87B34640C18BBE82344F44400803CFBD87B34640C18BBE82344F4440B2666490BBB04640A794D74AE8484440B2666490BBB04640
21401	30608	40.569589000000001	40.618789999999997	45.40258	45.380724000000001	Строителей	0103000020E61000000100000005000000A794D74AE8484440B2666490BBB04640A794D74AE84844400803CFBD87B34640C18BBE82344F44400803CFBD87B34640C18BBE82344F4440B2666490BBB04640A794D74AE8484440B2666490BBB04640
20748	30608	40.569589000000001	40.618789999999997	45.40258	45.380724000000001	Промышленная	0103000020E61000000100000005000000A794D74AE8484440B2666490BBB04640A794D74AE84844400803CFBD87B34640C18BBE82344F44400803CFBD87B34640C18BBE82344F4440B2666490BBB04640A794D74AE8484440B2666490BBB04640
21601	30608	40.569589000000001	40.618789999999997	45.40258	45.380724000000001	Почтовая	0103000020E61000000100000005000000A794D74AE8484440B2666490BBB04640A794D74AE84844400803CFBD87B34640C18BBE82344F44400803CFBD87B34640C18BBE82344F4440B2666490BBB04640A794D74AE8484440B2666490BBB04640
23358	46580	40.856565000000003	40.870570000000001	45.362608999999999	45.350892999999999	Турчинского	0103000020E61000000100000005000000FAF202ECA36D44409AB2D30FEAAC4640FAF202ECA36D44401D1EC2F869AE46407A7077D66E6F44401D1EC2F869AE46407A7077D66E6F44409AB2D30FEAAC4640FAF202ECA36D44409AB2D30FEAAC4640
23851	50846	40.406661999999997	40.434420000000003	45.244748000000001	45.237824000000003	Красная	0103000020E6100000010000000500000052431B800D3444401A1A4F04719E464052431B800D34444076E107E7539F46403A5D16139B37444076E107E7539F46403A5D16139B3744401A1A4F04719E464052431B800D3444401A1A4F04719E4640
23647	50801	40.909160999999997	40.923713999999997	45.423926999999999	45.413083999999998	Юбилейная	0103000020E610000001000000050000003AE63C635F7444401C40BFEFDFB446403AE63C635F74444019726C3D43B64640BD6DA6423C76444019726C3D43B64640BD6DA6423C7644401C40BFEFDFB446403AE63C635F7444401C40BFEFDFB44640
22394	48646	40.515492999999999	40.527180000000001	45.308222999999998	45.301578999999997	Ленина	0103000020E610000001000000050000009128B4ACFB414440871403249AA646409128B4ACFB4144400070ECD973A746407A8D5DA27A4344400070ECD973A746407A8D5DA27A434440871403249AA646409128B4ACFB414440871403249AA64640
21107	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Энергетиков	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
21866	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Чехова	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
20988	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Тимирязева	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
20969	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Советская	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
21103	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Пионерская	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
21129	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Нагорная	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
21446	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Ленина	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
20740	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Короткова	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
21585	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Комсомольская	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
21167	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Кирова	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
20823	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Западный микрорайон	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
20727	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	Волго-Донская	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
21155	29398	40.645918999999999	40.738031999999997	45.381242999999998	45.346299999999999	50 лет ВЛКСМ	0103000020E61000000100000005000000B96E4A79AD5244406A4DF38E53AC4640B96E4A79AD5244401A6A1492CCB0464063B323D5775E44401A6A1492CCB0464063B323D5775E44406A4DF38E53AC4640B96E4A79AD5244406A4DF38E53AC4640
22364	30321	40.641067999999997	40.691795999999997	45.416361000000002	45.395238999999997	Шевченко	0103000020E610000001000000050000008D4127840E524440478D093197B246408D4127840E524440392A37514BB5464076C075C58C584440392A37514BB5464076C075C58C584440478D093197B246408D4127840E524440478D093197B24640
22345	30321	40.641067999999997	40.691795999999997	45.416361000000002	45.395238999999997	Степная	0103000020E610000001000000050000008D4127840E524440478D093197B246408D4127840E524440392A37514BB5464076C075C58C584440392A37514BB5464076C075C58C584440478D093197B246408D4127840E524440478D093197B24640
21367	30321	40.641067999999997	40.691795999999997	45.416361000000002	45.395238999999997	Почтовая	0103000020E610000001000000050000008D4127840E524440478D093197B246408D4127840E524440392A37514BB5464076C075C58C584440392A37514BB5464076C075C58C584440478D093197B246408D4127840E524440478D093197B24640
21565	30321	40.641067999999997	40.691795999999997	45.416361000000002	45.395238999999997	Красная	0103000020E610000001000000050000008D4127840E524440478D093197B246408D4127840E524440392A37514BB5464076C075C58C584440392A37514BB5464076C075C58C584440478D093197B246408D4127840E524440478D093197B24640
21209	50339	40.798560999999999	40.816688999999997	45.179029	45.166167999999999	Свободный Труд	0103000020E61000000100000005000000376E313F3766444024D236FE44954640376E313F376644408E041A6CEA9646406000E143896844408E041A6CEA9646406000E1438968444024D236FE44954640376E313F3766444024D236FE44954640
21001	30748	40.819653000000002	40.843324000000003	45.382503	45.366751000000001	Советская 	0103000020E61000000100000005000000BE88B663EA6844403D635FB2F1AE4640BE88B663EA6844409ACFB9DBF5B0464049F7730AF26B44409ACFB9DBF5B0464049F7730AF26B44403D635FB2F1AE4640BE88B663EA6844403D635FB2F1AE4640
21192	30748	40.819653000000002	40.843324000000003	45.382503	45.366751000000001	Советская	0103000020E61000000100000005000000BE88B663EA6844403D635FB2F1AE4640BE88B663EA6844409ACFB9DBF5B0464049F7730AF26B44409ACFB9DBF5B0464049F7730AF26B44403D635FB2F1AE4640BE88B663EA6844403D635FB2F1AE4640
23322	50666	40.48442	40.538983000000002	45.194172999999999	45.186219999999999	Школьная	0103000020E61000000100000005000000A0C37C79013E444039EE940ED6974640A0C37C79013E444013622EA9DA984640CC0C1B65FD44444013622EA9DA984640CC0C1B65FD44444039EE940ED6974640A0C37C79013E444039EE940ED6974640
21608	12269	40.788580000000003	40.801946999999998	45.220030999999999	45.210284999999999	Центральная	0103000020E61000000100000005000000CD237F30F064444070EB6E9EEA9A4640CD237F30F0644440978DCEF9299C46400A100533A6664440978DCEF9299C46400A100533A666444070EB6E9EEA9A4640CD237F30F064444070EB6E9EEA9A4640
22971	50602	40.606904999999998	40.627315000000003	45.233280000000001	45.224195999999999	улица Ленина	0103000020E61000000100000005000000B2632310AF4D44406FF25B74B29C4640B2632310AF4D4440CB67791EDC9D464027A5A0DB4B504440CB67791EDC9D464027A5A0DB4B5044406FF25B74B29C4640B2632310AF4D44406FF25B74B29C4640
21314	50349	39.273589999999999	39.317239000000001	44.537790999999999	44.510509999999996	Ленина	0103000020E610000001000000050000009E4143FF04A34340F6234564584146409E4143FF04A34340A48AE255D644464004029D499BA84340A48AE255D644464004029D499BA84340F6234564584146409E4143FF04A34340F623456458414640
22098	50464	39.548015999999997	39.618893	45.724730999999998	45.691827000000004	Новобазарная	0103000020E61000000100000005000000A5D7666325C64340B2BE81C98DD84640A5D7666325C64340DDB243FCC3DC4640965CC5E237CF4340DDB243FCC3DC4640965CC5E237CF4340B2BE81C98DD84640A5D7666325C64340B2BE81C98DD84640
21046	25147	39.999267000000003	40.014412	45.756193000000003	45.747836	Красная	0103000020E610000001000000050000006C7C26FBE7FF4340BF620D17B9DF46406C7C26FBE7FF4340693BA6EECAE04640C1559E40D8014440693BA6EECAE04640C1559E40D8014440BF620D17B9DF46406C7C26FBE7FF4340BF620D17B9DF4640
21354	25009	39.680031999999997	39.745223000000003	45.671028999999997	45.645598999999997	Комарова	0103000020E61000000100000005000000E21DE0490BD7434047AAEFFCA2D24640E21DE0490BD7434073D53C47E4D546400F9D9E7763DF434073D53C47E4D546400F9D9E7763DF434047AAEFFCA2D24640E21DE0490BD7434047AAEFFCA2D24640
23980	25583	40.115544999999997	40.123736999999998	45.708477000000002	45.702402999999997	Школьная	0103000020E61000000100000005000000B01BB62DCA0E44405FCE6C57E8D94640B01BB62DCA0E4440EE7BD45FAFDA46400F27309DD60F4440EE7BD45FAFDA46400F27309DD60F44405FCE6C57E8D94640B01BB62DCA0E44405FCE6C57E8D94640
21615	25583	40.115544999999997	40.123736999999998	45.708477000000002	45.702402999999997	Молодежная	0103000020E61000000100000005000000B01BB62DCA0E44405FCE6C57E8D94640B01BB62DCA0E4440EE7BD45FAFDA46400F27309DD60F4440EE7BD45FAFDA46400F27309DD60F44405FCE6C57E8D94640B01BB62DCA0E44405FCE6C57E8D94640
21360	25583	40.115544999999997	40.123736999999998	45.708477000000002	45.702402999999997	Дорожная	0103000020E61000000100000005000000B01BB62DCA0E44405FCE6C57E8D94640B01BB62DCA0E4440EE7BD45FAFDA46400F27309DD60F4440EE7BD45FAFDA46400F27309DD60F44405FCE6C57E8D94640B01BB62DCA0E44405FCE6C57E8D94640
23966	25513	39.515407000000003	39.556306999999997	45.890836	45.877485999999998	Красная	0103000020E61000000100000005000000939048DBF8C143405359147651F04640939048DBF8C14340BB0CFFE906F2464097C4591135C74340BB0CFFE906F2464097C4591135C743405359147651F04640939048DBF8C143405359147651F04640
20710	25171	39.989179	39.997532999999997	45.808442999999997	45.801771000000002	Советская	0103000020E61000000100000005000000EB71DF6A9DFE4340CCF09F6EA0E64640EB71DF6A9DFE43400ED76A0F7BE7464023D74D29AFFF43400ED76A0F7BE7464023D74D29AFFF4340CCF09F6EA0E64640EB71DF6A9DFE4340CCF09F6EA0E64640
22543	25709	39.83766	39.956919999999997	45.652831999999997	45.610852000000001	Украинская	0103000020E610000001000000050000006C95607138EB43401D59F96530CE46406C95607138EB434021E4BCFF8FD34640B471C45A7CFA434021E4BCFF8FD34640B471C45A7CFA43401D59F96530CE46406C95607138EB43401D59F96530CE4640
22547	25709	39.83766	39.956919999999997	45.652831999999997	45.610852000000001	Почтовая	0103000020E610000001000000050000006C95607138EB43401D59F96530CE46406C95607138EB434021E4BCFF8FD34640B471C45A7CFA434021E4BCFF8FD34640B471C45A7CFA43401D59F96530CE46406C95607138EB43401D59F96530CE4640
21681	25709	39.83766	39.956919999999997	45.652831999999997	45.610852000000001	Красная	0103000020E610000001000000050000006C95607138EB43401D59F96530CE46406C95607138EB434021E4BCFF8FD34640B471C45A7CFA434021E4BCFF8FD34640B471C45A7CFA43401D59F96530CE46406C95607138EB43401D59F96530CE4640
23981	24155	39.755930999999997	39.849580000000003	45.714499000000004	45.688768000000003	Советская	0103000020E610000001000000050000002B84D558C2E043400344C18C29D846402B84D558C2E043402A0307B474DB4640F8AA9509BFEC43402A0307B474DB4640F8AA9509BFEC43400344C18C29D846402B84D558C2E043400344C18C29D84640
23300	24155	39.755930999999997	39.849580000000003	45.714499000000004	45.688768000000003	Комсомольская	0103000020E610000001000000050000002B84D558C2E043400344C18C29D846402B84D558C2E043402A0307B474DB4640F8AA9509BFEC43402A0307B474DB4640F8AA9509BFEC43400344C18C29D846402B84D558C2E043400344C18C29D84640
23447	50713	39.515407000000003	39.556306999999997	45.890836	45.877485999999998	Ленина	0103000020E61000000100000005000000939048DBF8C143405359147651F04640939048DBF8C14340BB0CFFE906F2464097C4591135C74340BB0CFFE906F2464097C4591135C743405359147651F04640939048DBF8C143405359147651F04640
21245	25622	39.782431000000003	39.971823000000001	45.481355000000001	45.447871999999997	Ленина	0103000020E610000001000000050000003430F2B226E44340A565A4DE53B946403430F2B226E443400F62670A9DBD4640144031B264FC43400F62670A9DBD4640144031B264FC4340A565A4DE53B946403430F2B226E44340A565A4DE53B94640
21813	25622	39.782431000000003	39.971823000000001	45.481355000000001	45.447871999999997	Горького	0103000020E610000001000000050000003430F2B226E44340A565A4DE53B946403430F2B226E443400F62670A9DBD4640144031B264FC43400F62670A9DBD4640144031B264FC4340A565A4DE53B946403430F2B226E44340A565A4DE53B94640
23994	50889	39.934696000000002	39.99765	45.705846000000001	45.689152	Ленина	0103000020E61000000100000005000000DCD9571EA4F743408BFCFA2136D84640DCD9571EA4F743409701672959DA46405D6DC5FEB2FF43409701672959DA46405D6DC5FEB2FF43408BFCFA2136D84640DCD9571EA4F743408BFCFA2136D84640
22054	25390	39.617176999999998	39.693615000000001	45.868783000000001	45.836925999999998	Красная	0103000020E61000000100000005000000F46BEBA7FFCE43400796236420EB4640F46BEBA7FFCE43400F29064834EF4640ED815660C8D843400F29064834EF4640ED815660C8D843400796236420EB4640F46BEBA7FFCE43400796236420EB4640
22057	25390	39.617176999999998	39.693615000000001	45.868783000000001	45.836925999999998	Кооперативная	0103000020E61000000100000005000000F46BEBA7FFCE43400796236420EB4640F46BEBA7FFCE43400F29064834EF4640ED815660C8D843400F29064834EF4640ED815660C8D843400796236420EB4640F46BEBA7FFCE43400796236420EB4640
22841	50576	39.595725000000002	39.665371999999998	45.550325999999998	45.537140000000001	Южная	0103000020E610000001000000050000006E3480B740CC4340CDAFE600C1C446406E3480B740CC4340BA11161571C6464049D6E1E82AD54340BA11161571C6464049D6E1E82AD54340CDAFE600C1C446406E3480B740CC4340CDAFE600C1C44640
21647	24383	39.616835999999999	39.672882000000001	45.682924999999997	45.636688999999997	Школьная	0103000020E610000001000000050000006B7F677BF4CE4340895C70067FD146406B7F677BF4CE4340764F1E166AD74640960854FF20D64340764F1E166AD74640960854FF20D64340895C70067FD146406B7F677BF4CE4340895C70067FD14640
21657	24451	39.608975999999998	39.657449	45.741829000000003	45.730978	Школьная	0103000020E610000001000000050000004206F2ECF2CD4340390CE6AF90DD46404206F2ECF2CD4340B91CAF40F4DE4640DAE4F04927D44340B91CAF40F4DE4640DAE4F04927D44340390CE6AF90DD46404206F2ECF2CD4340390CE6AF90DD4640
21350	24451	39.608975999999998	39.657449	45.741829000000003	45.730978	Садовая	0103000020E610000001000000050000004206F2ECF2CD4340390CE6AF90DD46404206F2ECF2CD4340B91CAF40F4DE4640DAE4F04927D44340B91CAF40F4DE4640DAE4F04927D44340390CE6AF90DD46404206F2ECF2CD4340390CE6AF90DD4640
21812	25229	39.861007000000001	39.882809000000002	45.792672000000003	45.773589999999999	переулок Школьный	0103000020E610000001000000050000004450357A35EE43409E4143FF04E346404450357A35EE43403B3AAE4676E54640A7CEA3E2FFF043403B3AAE4676E54640A7CEA3E2FFF043409E4143FF04E346404450357A35EE43409E4143FF04E34640
21672	25229	39.861007000000001	39.882809000000002	45.792672000000003	45.773589999999999	Мира	0103000020E610000001000000050000004450357A35EE43409E4143FF04E346404450357A35EE43403B3AAE4676E54640A7CEA3E2FFF043403B3AAE4676E54640A7CEA3E2FFF043409E4143FF04E346404450357A35EE43409E4143FF04E34640
22038	25088	39.923214999999999	39.953398999999997	45.767643	45.741798000000003	Шевченко	0103000020E610000001000000050000009C16BCE82BF643407E1EA33CF3DE46409C16BCE82BF643406D00362042E2464001857AFA08FA43406D00362042E2464001857AFA08FA43407E1EA33CF3DE46409C16BCE82BF643407E1EA33CF3DE4640
21811	24645	39.592519000000003	39.690731	45.611274999999999	45.563478000000003	переулок Полевой	0103000020E610000001000000050000001BA19FA9D7CB4340FC010F0C20C846401BA19FA9D7CB434063EE5A423ECE4640ACAA97DF69D8434063EE5A423ECE4640ACAA97DF69D84340FC010F0C20C846401BA19FA9D7CB4340FC010F0C20C84640
20571	24645	39.592519000000003	39.690731	45.611274999999999	45.563478000000003	пер.Якименко	0103000020E610000001000000050000001BA19FA9D7CB4340FC010F0C20C846401BA19FA9D7CB434063EE5A423ECE4640ACAA97DF69D8434063EE5A423ECE4640ACAA97DF69D84340FC010F0C20C846401BA19FA9D7CB4340FC010F0C20C84640
20814	24645	39.592519000000003	39.690731	45.611274999999999	45.563478000000003	пер.Первомайский	0103000020E610000001000000050000001BA19FA9D7CB4340FC010F0C20C846401BA19FA9D7CB434063EE5A423ECE4640ACAA97DF69D8434063EE5A423ECE4640ACAA97DF69D84340FC010F0C20C846401BA19FA9D7CB4340FC010F0C20C84640
22503	24645	39.592519000000003	39.690731	45.611274999999999	45.563478000000003	Свободы	0103000020E610000001000000050000001BA19FA9D7CB4340FC010F0C20C846401BA19FA9D7CB434063EE5A423ECE4640ACAA97DF69D8434063EE5A423ECE4640ACAA97DF69D84340FC010F0C20C846401BA19FA9D7CB4340FC010F0C20C84640
22022	24645	39.592519000000003	39.690731	45.611274999999999	45.563478000000003	Ленина	0103000020E610000001000000050000001BA19FA9D7CB4340FC010F0C20C846401BA19FA9D7CB434063EE5A423ECE4640ACAA97DF69D8434063EE5A423ECE4640ACAA97DF69D84340FC010F0C20C846401BA19FA9D7CB4340FC010F0C20C84640
20810	24645	39.592519000000003	39.690731	45.611274999999999	45.563478000000003	Дзержинского	0103000020E610000001000000050000001BA19FA9D7CB4340FC010F0C20C846401BA19FA9D7CB434063EE5A423ECE4640ACAA97DF69D8434063EE5A423ECE4640ACAA97DF69D84340FC010F0C20C846401BA19FA9D7CB4340FC010F0C20C84640
21651	24488	39.763603000000003	39.812443999999999	45.650374999999997	45.577005	Октябрьская	0103000020E6100000010000000500000052103CBEBDE143407250C24CDBC9464052103CBEBDE143406891ED7C3FD346406CEA3C2AFEE743406891ED7C3FD346406CEA3C2AFEE743407250C24CDBC9464052103CBEBDE143407250C24CDBC94640
20705	24488	39.763603000000003	39.812443999999999	45.650374999999997	45.577005	Мира	0103000020E6100000010000000500000052103CBEBDE143407250C24CDBC9464052103CBEBDE143406891ED7C3FD346406CEA3C2AFEE743406891ED7C3FD346406CEA3C2AFEE743407250C24CDBC9464052103CBEBDE143407250C24CDBC94640
21225	24278	39.548015999999997	39.618893	45.724730999999998	45.691827000000004	Красноармейская	0103000020E61000000100000005000000A5D7666325C64340B2BE81C98DD84640A5D7666325C64340DDB243FCC3DC4640965CC5E237CF4340DDB243FCC3DC4640965CC5E237CF4340B2BE81C98DD84640A5D7666325C64340B2BE81C98DD84640
20702	24008	39.839509999999997	39.869675999999998	45.693759999999997	45.685538000000001	Ленина	0103000020E610000001000000050000001D554D1075EB434027158DB5BFD746401D554D1075EB4340F0A2AF20CDD84640DC0E0D8B51EF4340F0A2AF20CDD84640DC0E0D8B51EF434027158DB5BFD746401D554D1075EB434027158DB5BFD74640
21221	24008	39.839509999999997	39.869675999999998	45.693759999999997	45.685538000000001	Кочубея	0103000020E610000001000000050000001D554D1075EB434027158DB5BFD746401D554D1075EB4340F0A2AF20CDD84640DC0E0D8B51EF4340F0A2AF20CDD84640DC0E0D8B51EF434027158DB5BFD746401D554D1075EB434027158DB5BFD74640
23380	25312	39.699669999999998	39.763486	45.814919000000003	45.793539000000003	Красная	0103000020E6100000010000000500000004FF5BC98ED94340DF8C9AAF92E5464004FF5BC98ED94340CCF10A444FE84640187AC4E8B9E14340CCF10A444FE84640187AC4E8B9E14340DF8C9AAF92E5464004FF5BC98ED94340DF8C9AAF92E54640
23580	50780	39.852176999999998	39.909416999999998	45.702081999999997	45.682282999999998	Чапаева	0103000020E61000000100000005000000A2B3CC2214ED4340F2CEA10C55D74640A2B3CC2214ED43401D8EAED2DDD9464095B6B8C667F443401D8EAED2DDD9464095B6B8C667F44340F2CEA10C55D74640A2B3CC2214ED4340F2CEA10C55D74640
23485	50735	39.669172000000003	39.764429	45.497821000000002	45.469921999999997	Октябрьская	0103000020E6100000010000000500000010B3976DA7D54340E0D5726726BC464010B3976DA7D543408A213999B8BF4640978E39CFD8E143408A213999B8BF4640978E39CFD8E14340E0D5726726BC464010B3976DA7D54340E0D5726726BC4640
21418	23118	38.857607000000002	38.888680000000001	45.940382999999997	45.921039	Красная	0103000020E610000001000000050000000CE9F010C66D434097AB1F9BE4F546400CE9F010C66D4340705B5B785EF84640FD4D2844C0714340705B5B785EF84640FD4D2844C071434097AB1F9BE4F546400CE9F010C66D434097AB1F9BE4F54640
23679	23014	38.611207999999998	38.646377000000001	45.859017000000001	45.846418999999997	Матросова	0103000020E61000000100000005000000DB8651103C4E434044DB317557EC4640DB8651103C4E4340A1DAE044F4ED46407CF1457BBC524340A1DAE044F4ED46407CF1457BBC52434044DB317557EC4640DB8651103C4E434044DB317557EC4640
20533	32644	39.140037	39.278297000000002	45.892460999999997	45.868343000000003	Ленина	0103000020E610000001000000050000006F9D7FBBEC914340F35A09DD25EF46406F9D7FBBEC9143404CFA7B293CF2464097C9703C9FA343404CFA7B293CF2464097C9703C9FA34340F35A09DD25EF46406F9D7FBBEC914340F35A09DD25EF4640
21131	32644	39.140037	39.278297000000002	45.892460999999997	45.868343000000003	50 лет Победы	0103000020E610000001000000050000006F9D7FBBEC914340F35A09DD25EF46406F9D7FBBEC9143404CFA7B293CF2464097C9703C9FA343404CFA7B293CF2464097C9703C9FA34340F35A09DD25EF46406F9D7FBBEC914340F35A09DD25EF4640
21532	50386	39.280552	39.322125999999997	45.804453000000002	45.788724999999999	Суворова	0103000020E61000000100000005000000E869C020E9A34340D044D8F0F4E44640E869C020E9A34340A515DF50F8E646407C98BD6C3BA94340A515DF50F8E646407C98BD6C3BA94340D044D8F0F4E44640E869C020E9A34340D044D8F0F4E44640
23419	49602	39.152856	39.170848999999997	45.812399999999997	45.800426000000002	улица Мира	0103000020E61000000100000005000000AA7F10C9909343401E6FF25B74E64640AA7F10C9909343409CA223B9FCE74640F3C64961DE9543409CA223B9FCE74640F3C64961DE9543401E6FF25B74E64640AA7F10C9909343401E6FF25B74E64640
20649	49602	39.152856	39.170848999999997	45.812399999999997	45.800426000000002	 Партизанская	0103000020E61000000100000005000000AA7F10C9909343401E6FF25B74E64640AA7F10C9909343409CA223B9FCE74640F3C64961DE9543409CA223B9FCE74640F3C64961DE9543401E6FF25B74E64640AA7F10C9909343401E6FF25B74E64640
20421	15123	39.434351999999997	39.461723999999997	45.799553000000003	45.783690999999997	Солнечная	0103000020E61000000100000005000000E179A9D898B74340B39597FC4FE44640E179A9D898B743409835B1C057E646409FE3A3C519BB43409835B1C057E646409FE3A3C519BB4340B39597FC4FE44640E179A9D898B74340B39597FC4FE44640
22087	15123	39.434351999999997	39.461723999999997	45.799553000000003	45.783690999999997	Набережная,	0103000020E61000000100000005000000E179A9D898B74340B39597FC4FE44640E179A9D898B743409835B1C057E646409FE3A3C519BB43409835B1C057E646409FE3A3C519BB4340B39597FC4FE44640E179A9D898B74340B39597FC4FE44640
21632	23322	39.005074	39.048571000000003	45.860196999999999	45.824384999999999	Толстого	0103000020E61000000100000005000000AB07CC43A68043400F289B7285E94640AB07CC43A6804340048F6FEF1AEE46405B44149337864340048F6FEF1AEE46405B441493378643400F289B7285E94640AB07CC43A68043400F289B7285E94640
20531	23322	39.005074	39.048571000000003	45.860196999999999	45.824384999999999	Красная	0103000020E61000000100000005000000AB07CC43A68043400F289B7285E94640AB07CC43A6804340048F6FEF1AEE46405B44149337864340048F6FEF1AEE46405B441493378643400F289B7285E94640AB07CC43A68043400F289B7285E94640
21118	50330	\N	\N	\N	\N	Советская	\N
23907	50330	\N	\N	\N	\N	Красная	\N
20767	22929	38.635696000000003	38.692416000000001	45.786437999999997	45.759526000000001	Красная	0103000020E6100000010000000500000059198D7C5E514340193BE12538E1464059198D7C5E514340732A1900AAE44640139D6516A1584340732A1900AAE44640139D6516A1584340193BE12538E1464059198D7C5E514340193BE12538E14640
21198	23220	38.934520999999997	38.943441	45.867646999999998	45.860097000000003	Красная	0103000020E610000001000000050000006D3656629E774340A13193A817EE46406D3656629E7743407BBC900E0FEF46404F5AB8ACC27843407BBC900E0FEF46404F5AB8ACC2784340A13193A817EE46406D3656629E774340A13193A817EE4640
20769	23286	38.908082999999998	38.918008999999998	45.888415000000002	45.881483000000003	Гагарина	0103000020E61000000100000005000000DB8651103C744340707D586FD4F04640DB8651103C7443404F232D95B7F146408237A451817543404F232D95B7F146408237A45181754340707D586FD4F04640DB8651103C744340707D586FD4F04640
23951	50874	39.021217	39.029615999999997	45.776525999999997	45.761142	Советская	0103000020E61000000100000005000000438F183DB782434057CEDE196DE14640438F183DB7824340313F373465E346401BB80375CA834340313F373465E346401BB80375CA83434057CEDE196DE14640438F183DB782434057CEDE196DE14640
22403	49360	38.999791999999999	39.033712999999999	45.758890999999998	45.730645000000003	Длинная	0103000020E61000000100000005000000B6662B2FF97F434033FE7DC685DD4640B6662B2FF97F4340471D1D5723E146409B3924B550844340471D1D5723E146409B3924B55084434033FE7DC685DD4640B6662B2FF97F434033FE7DC685DD4640
21002	23235	38.917327	38.945031	45.912354999999998	45.904980000000002	Гоголя	0103000020E61000000100000005000000705E9CF86A7543405DC47762D6F34640705E9CF86A754340C9AB730CC8F44640645A9BC6F6784340C9AB730CC8F44640645A9BC6F67843405DC47762D6F34640705E9CF86A7543405DC47762D6F34640
21204	48464	39.314579999999999	39.335510999999997	45.788781999999998	45.775708999999999	Восточная	0103000020E61000000100000005000000E3FC4D2844A843403F1BB96E4AE34640E3FC4D2844A8434034D6FECEF6E4464060394206F2AA434034D6FECEF6E4464060394206F2AA43403F1BB96E4AE34640E3FC4D2844A843403F1BB96E4AE34640
20996	22874	38.799216000000001	38.834905999999997	45.868493999999998	45.844239999999999	Центральная	0103000020E610000001000000050000005038BBB54C664340CEFC6A0E10EC46405038BBB54C664340D862B7CF2AEF4640F99D2633DE6A4340D862B7CF2AEF4640F99D2633DE6A4340CEFC6A0E10EC46405038BBB54C664340CEFC6A0E10EC4640
20755	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Энгельса	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
21903	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Тимофеева	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
20754	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Ростовская	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
20519	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Ленина	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
20884	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Красная	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
21408	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Кошевого Олега	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
20756	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Димитрова	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
21193	11582	38.977541000000002	39.016258000000001	45.830959999999997	45.780486000000003	Выгонная	0103000020E61000000100000005000000E4BF4010207D4340317E1AF7E6E34640E4BF4010207D43405F24B4E55CEA46403126FDBD148243405F24B4E55CEA46403126FDBD14824340317E1AF7E6E34640E4BF4010207D4340317E1AF7E6E34640
21079	50323	39.154373999999997	39.262521999999997	45.810943000000002	45.775588999999997	Деркача	0103000020E6100000010000000500000025ADF886C29343409411178046E3464025ADF886C2934340C7F5EFFACCE74640813D26529AA14340C7F5EFFACCE74640813D26529AA143409411178046E3464025ADF886C29343409411178046E34640
21533	23684	39.154373999999997	39.262521999999997	45.810943000000002	45.775588999999997	 Деркача	0103000020E6100000010000000500000025ADF886C29343409411178046E3464025ADF886C2934340C7F5EFFACCE74640813D26529AA14340C7F5EFFACCE74640813D26529AA143409411178046E3464025ADF886C29343409411178046E34640
20527	23045	38.692262999999997	38.708486000000001	45.895597000000002	45.873947000000001	Ленина	0103000020E610000001000000050000008C9DF0129C584340FAB7CB7EDDEF46408C9DF0129C584340A7B228ECA2F2464041D653ABAF5A4340A7B228ECA2F2464041D653ABAF5A4340FAB7CB7EDDEF46408C9DF0129C584340FAB7CB7EDDEF4640
21012	23767	39.340254000000002	39.409683999999999	45.808354999999999	45.778354999999998	Красная	0103000020E61000000100000005000000A62A6D718DAB4340CBD6FA22A1E34640A62A6D718DAB43406F47382D78E74640E4D87A8670B443406F47382D78E74640E4D87A8670B44340CBD6FA22A1E34640A62A6D718DAB4340CBD6FA22A1E34640
23449	50715	39.649939000000003	39.660511999999997	43.686515999999997	43.679931000000003	улица Кооперативная	0103000020E610000001000000050000008EB27E3331D34340AF44A0FA07D745408EB27E3331D3434022179CC1DFD74540CA4E3FA88BD4434022179CC1DFD74540CA4E3FA88BD44340AF44A0FA07D745408EB27E3331D34340AF44A0FA07D74540
20641	13823	39.705993999999997	39.722369999999998	43.648394000000003	43.630524999999999	Целинная	0103000020E610000001000000050000000B96EA025EDA4340BB270F0BB5D045400B96EA025EDA434019761893FED2454046CEC29E76DC434019761893FED2454046CEC29E76DC4340BB270F0BB5D045400B96EA025EDA4340BB270F0BB5D04540
21689	12377	39.759011999999998	39.773574000000004	43.693862000000003	43.656613	Леселидзе	0103000020E61000000100000005000000C2A2224E27E14340719010E50BD44540C2A2224E27E14340F5F75278D0D8454099840B7904E34340F5F75278D0D8454099840B7904E34340719010E50BD44540C2A2224E27E14340719010E50BD44540
23658	15416	39.743633000000003	39.751933999999999	43.640839999999997	43.634687999999997	 Труда	0103000020E61000000100000005000000FA9CBB5D2FDF4340F294D5743DD14540FA9CBB5D2FDF4340FCFB8C0B07D245400F60915F3FE04340FCFB8C0B07D245400F60915F3FE04340F294D5743DD14540FA9CBB5D2FDF4340F294D5743DD14540
4401	15668	39.740507000000001	39.747568000000001	43.619425	43.612023999999998	улица Абрикосовая	0103000020E61000000100000005000000C3BAF1EEC8DE4340FD2E6CCD56CE4540C3BAF1EEC8DE434093A9825149CF4540A0C4E74EB0DF434093A9825149CF4540A0C4E74EB0DF4340FD2E6CCD56CE4540C3BAF1EEC8DE4340FD2E6CCD56CE4540
4430	15668	39.738261000000001	39.744855000000001	43.619425	43.610849000000002	улица 60 Лет ВЛКСМ	0103000020E61000000100000005000000C57421567FDE4340ACE5CE4C30CE4540C57421567FDE434093A9825149CF45408CA19C6857DF434093A9825149CF45408CA19C6857DF4340ACE5CE4C30CE4540C57421567FDE4340ACE5CE4C30CE4540
21500	10695	39.693587999999998	39.699174999999997	43.638902999999999	43.626387999999999	Крымская	0103000020E61000000100000005000000F372D87DC7D84340AD4D637B2DD04540F372D87DC7D843407C28D192C7D145402497FF907ED943407C28D192C7D145402497FF907ED94340AD4D637B2DD04540F372D87DC7D84340AD4D637B2DD04540
23738	9466	39.731110999999999	39.750981000000003	43.653044999999999	43.640801000000003	Армянская	0103000020E61000000100000005000000785F950B95DD43403F1F65C405D24540785F950B95DD43407DE882FA96D345406D75392520E043407DE882FA96D345406D75392520E043403F1F65C405D24540785F950B95DD43403F1F65C405D24540
21426	13693	39.869173000000004	39.872416000000001	43.515861999999998	43.507494000000001	улица Ялтинская	0103000020E610000001000000050000007AC8940F41EF434047753A90F5C045407AC8940F41EF4340E49F19C407C24540EA40D653ABEF4340E49F19C407C24540EA40D653ABEF434047753A90F5C045407AC8940F41EF434047753A90F5C04540
21162	13693	39.871265999999999	39.877186000000002	43.510905999999999	43.507134000000001	улица Краснополянская	0103000020E61000000100000005000000F10EF0A485EF4340475854C4E9C04540F10EF0A485EF434043AA285E65C1454029417FA147F0434043AA285E65C1454029417FA147F04340475854C4E9C04540F10EF0A485EF4340475854C4E9C04540
20633	13693	39.869002000000002	39.872047000000002	43.515104000000001	43.514626999999997	Ушинского	0103000020E610000001000000050000004D1421753BEF4340BD512B4CDFC145404D1421753BEF4340F70489EDEEC1454097C9703C9FEF4340F70489EDEEC1454097C9703C9FEF4340BD512B4CDFC145404D1421753BEF4340BD512B4CDFC14540
2434	8792	39.881416999999999	39.890211000000001	43.568055000000001	43.55086	улица Центральная	0103000020E61000000100000005000000B891B245D2F0434058569A9482C64540B891B245D2F0434026AAB706B6C845400DC51D6FF2F1434026AAB706B6C845400DC51D6FF2F1434058569A9482C64540B891B245D2F0434058569A9482C64540
23622	12468	39.765624000000003	39.775208999999997	43.594332999999999	43.588731000000003	Буковая	0103000020E6100000010000000500000030849CF7FFE14340199293895BCB454030849CF7FFE143407FF78E1A13CC45404D486B0C3AE343407FF78E1A13CC45404D486B0C3AE34340199293895BCB454030849CF7FFE14340199293895BCB4540
23687	12593	39.823718	39.829512000000001	43.595135999999997	43.588743999999998	улица Карчикяна	0103000020E61000000100000005000000329067976FE94340ADDBA0F65BCB4540329067976FE943400C569C6A2DCC4540DDD1FF722DEA43400C569C6A2DCC4540DDD1FF722DEA4340ADDBA0F65BCB4540329067976FE94340ADDBA0F65BCB4540
23632	12593	39.813603000000001	39.832306000000003	43.609315000000002	43.579732	Юбилейная	0103000020E61000000100000005000000B876A22424E84340EB387EA834CA4540B876A22424E843402BFBAE08FECD4540DE21C50089EA43402BFBAE08FECD4540DE21C50089EA4340EB387EA834CA4540B876A22424E84340EB387EA834CA4540
20570	50264	39.737470999999999	39.749291999999997	43.620998	43.609386999999998	Макаренко	0103000020E61000000100000005000000CC5F217365DE4340C4CDA96400CE4540CC5F217365DE4340D270CADC7CCF4540C493DDCCE8DF4340D270CADC7CCF4540C493DDCCE8DF4340C4CDA96400CE4540CC5F217365DE4340C4CDA96400CE4540
21340	50264	39.748224	39.765597	43.628704999999997	43.613173000000003	Вишневая	0103000020E61000000100000005000000890AD5CDC5DF434026E5EE737CCE4540890AD5CDC5DF434074EACA6779D0454036751E15FFE1434074EACA6779D0454036751E15FFE1434026E5EE737CCE4540890AD5CDC5DF434026E5EE737CCE4540
21791	9842	39.809704000000004	39.824086000000001	43.545482999999997	43.535961999999998	Большой Ахун дорога	0103000020E610000001000000050000005FB87361A4E743400AF31E679AC445405FB87361A4E7434011C30E63D2C54540B58B69A67BE9434011C30E63D2C54540B58B69A67BE943400AF31E679AC445405FB87361A4E743400AF31E679AC44540
22429	30712	39.888432999999999	39.893723999999999	43.506538999999997	43.494422	улица Дарвина	0103000020E61000000100000005000000F5D72B2CB8F143402236583849BF4540F5D72B2CB8F1434003931B45D6C045403DD34B8C65F2434003931B45D6C045403DD34B8C65F243402236583849BF4540F5D72B2CB8F143402236583849BF4540
20889	30712	39.892637000000001	39.899275000000003	43.502197000000002	43.494715999999997	Апшеронская	0103000020E610000001000000050000008B19E1ED41F243406A6798DA52BF45408B19E1ED41F243401D93C5FD47C04540228E75711BF343401D93C5FD47C04540228E75711BF343406A6798DA52BF45408B19E1ED41F243406A6798DA52BF4540
23415	50698	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	улица Шаумяна	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
109	382	39.904781999999997	39.931156000000001	43.560053000000003	43.549312	улица Володи Ульянова	0103000020E61000000100000005000000360186E5CFF3434072A609DB4FC64540360186E5CFF343406B8313D1AFC74540B2BCAB1E30F743406B8313D1AFC74540B2BCAB1E30F7434072A609DB4FC64540360186E5CFF3434072A609DB4FC64540
23777	382	39.918624999999999	39.926763999999999	43.565657000000002	43.560020000000002	Школьная	0103000020E61000000100000005000000DD24068195F543408F8D40BCAEC74540DD24068195F5434072E0D57267C84540198EE733A0F6434072E0D57267C84540198EE733A0F643408F8D40BCAEC74540DD24068195F543408F8D40BCAEC74540
21249	48184	39.818210999999998	39.839205	43.635900999999997	43.622140000000002	Калиновая	0103000020E610000001000000050000001D1D5723BBE8434048C49448A2CF45401D1D5723BBE84340313F373465D14540E1D1C6116BEB4340313F373465D14540E1D1C6116BEB434048C49448A2CF45401D1D5723BBE8434048C49448A2CF4540
20987	8095	39.890749999999997	39.910027999999997	43.519634000000003	43.508245000000002	Пробковая	0103000020E61000000100000005000000BC74931804F2434082AD122C0EC14540BC74931804F24340E1F1ED5D83C24540DE3829CC7BF44340E1F1ED5D83C24540DE3829CC7BF4434082AD122C0EC14540BC74931804F2434082AD122C0EC14540
21474	40381	39.762658999999999	39.769334000000001	43.566304000000002	43.557786	улица Ворошиловская	0103000020E61000000100000005000000028063CF9EE1434055151A8865C74540028063CF9EE1434008CC43A67CC84540B6D9588979E2434008CC43A67CC84540B6D9588979E2434055151A8865C74540028063CF9EE1434055151A8865C74540
20625	40381	39.753523999999999	39.772460000000002	43.568094000000002	43.560915000000001	улица Бытха	0103000020E610000001000000050000002460747973E04340FD6A0E10CCC745402460747973E04340E486DF4DB7C84540EDBB22F8DFE24340E486DF4DB7C84540EDBB22F8DFE24340FD6A0E10CCC745402460747973E04340FD6A0E10CCC74540
21163	40381	39.765300000000003	39.771121999999998	43.565997000000003	43.560862999999998	Лесная	0103000020E610000001000000050000007DD0B359F5E14340AA44D95BCAC745407DD0B359F5E143402B51F69672C84540F19C2D20B4E243402B51F69672C84540F19C2D20B4E24340AA44D95BCAC745407DD0B359F5E14340AA44D95BCAC74540
20601	40381	39.715344999999999	39.803559999999997	43.58764	43.538412000000001	Курортный проспект	0103000020E61000000100000005000000B62DCA6C90DB434011E335AFEAC44540B62DCA6C90DB434025E99AC937CB4540D72FD80DDBE6434025E99AC937CB4540D72FD80DDBE6434011E335AFEAC44540B62DCA6C90DB434011E335AFEAC44540
21059	40381	39.761006999999999	39.765425999999998	43.566381999999997	43.561521999999997	Возрождения	0103000020E61000000100000005000000778368AD68E1434004FEF0F3DFC74540778368AD68E14340838593347FC8454009C1AA7AF9E14340838593347FC8454009C1AA7AF9E1434004FEF0F3DFC74540778368AD68E1434004FEF0F3DFC74540
21421	50368	39.489158000000003	39.517491	43.781146999999997	43.75779	Череповецкая	0103000020E61000000100000005000000D449B6BA9CBE4340309E4143FFE04540D449B6BA9CBE43402B2FF99FFCE34540B77C24253DC243402B2FF99FFCE34540B77C24253DC24340309E4143FFE04540D449B6BA9CBE4340309E4143FFE04540
20749	50284	39.637794	39.701627999999999	43.666617000000002	43.640689999999999	Батумское шоссе	0103000020E61000000100000005000000E2CAD93BA3D14340E76F422102D24540E2CAD93BA3D1434094FAB2B453D545409CFA40F2CED9434094FAB2B453D545409CFA40F2CED94340E76F422102D24540E2CAD93BA3D14340E76F422102D24540
23446	50712	39.444656000000002	39.483139999999999	43.817355999999997	43.776648999999999	улица Центральная	0103000020E610000001000000050000002FFCE07CEAB843404DBC033C69E345402FFCE07CEAB843403D98141F9FE84540D9B11188D7BD43403D98141F9FE84540D9B11188D7BD43404DBC033C69E345402FFCE07CEAB843404DBC033C69E34540
3138	11043	39.482672999999998	39.528216999999998	43.778719000000002	43.747729	улица Главная	0103000020E61000000100000005000000C3D4963AC8BD4340A9A27895B5DF4540C3D4963AC8BD43400DE36E10ADE345407A185A9D9CC343400DE36E10ADE345407A185A9D9CC34340A9A27895B5DF4540C3D4963AC8BD4340A9A27895B5DF4540
2696	9524	39.444656000000002	39.483139999999999	43.817355999999997	43.776648999999999	улица Центральная	0103000020E610000001000000050000002FFCE07CEAB843404DBC033C69E345402FFCE07CEAB843403D98141F9FE84540D9B11188D7BD43403D98141F9FE84540D9B11188D7BD43404DBC033C69E345402FFCE07CEAB843404DBC033C69E34540
20850	50293	39.882243000000003	40.043723999999997	43.565396	43.385041000000001	Лучевая	0103000020E61000000100000005000000FE0FB056EDF04340404F030649B14540FE0FB056EDF0434005A568E55EC8454070067FBF9805444005A568E55EC8454070067FBF98054440404F030649B14540FE0FB056EDF04340404F030649B14540
23752	10779	39.364238999999998	39.392491	43.898893000000001	43.883580000000002	 Солоники	0103000020E61000000100000005000000C07630629FAE434029B3412619F14540C07630629FAE43403ACD02ED0EF34540B77C24253DB243403ACD02ED0EF34540B77C24253DB2434029B3412619F14540C07630629FAE434029B3412619F14540
16261	9976	39.210805999999998	39.216132999999999	43.999831999999998	43.994404000000003	улица Кольцевая	0103000020E6100000010000000500000079E6E5B0FB9A43407C8159A148FF454079E6E5B0FB9A434044BFB67EFAFF45400E4B033FAA9B434044BFB67EFAFF45400E4B033FAA9B43407C8159A148FF454079E6E5B0FB9A43407C8159A148FF4540
23820	9976	39.214210999999999	39.240406	44.000241000000003	43.978389999999997	Сибирская	0103000020E61000000100000005000000C3B81B446B9B4340E15D2EE23BFD4540C3B81B446B9B4340268FA7E5070046408FE1B19FC59E4340268FA7E5070046408FE1B19FC59E4340E15D2EE23BFD4540C3B81B446B9B4340E15D2EE23BFD4540
22052	11935	39.691558000000001	39.719900000000003	43.688862999999998	43.648349000000003	Славы	0103000020E61000000100000005000000C2A4F8F884D8434079B29B19FDD24540C2A4F8F884D843405436ACA92CD84540F931E6AE25DC43405436ACA92CD84540F931E6AE25DC434079B29B19FDD24540C2A4F8F884D8434079B29B19FDD24540
75557	12323	39.5274	39.537909999999997	43.762588000000001	43.752795999999996	Рязанская	0103000020E6100000010000000500000088F4DBD781C34340A1478C9E5BE0454088F4DBD781C343403929CC7B9CE145407E18213CDAC443403929CC7B9CE145407E18213CDAC44340A1478C9E5BE0454088F4DBD781C34340A1478C9E5BE04540
3428	12177	39.312181000000002	39.312505000000002	43.952100000000002	43.951327999999997	улица Верхняя	0103000020E610000001000000050000005FB7088CF5A7434071E2AB1DC5F945405FB7088CF5A74340C442AD69DEF94540126BF12900A84340C442AD69DEF94540126BF12900A8434071E2AB1DC5F945405FB7088CF5A7434071E2AB1DC5F94540
20650	9843	39.191349000000002	39.200206000000001	44.006394	44.000377	Свободы	0103000020E61000000100000005000000A88FC01F7E984340D655815A0C004640A88FC01F7E9843400072C284D1004640433BA759A09943400072C284D1004640433BA759A0994340D655815A0C004640A88FC01F7E984340D655815A0C004640
20430	9843	39.175708999999998	39.202658999999997	44.018808999999997	44.003599999999999	Майкопская	0103000020E61000000100000005000000724EECA17D964340FF21FDF675004640724EECA17D9643406BEF535568024640BA9EE8BAF09943406BEF535568024640BA9EE8BAF0994340FF21FDF675004640724EECA17D964340FF21FDF675004640
23944	9837	39.156216000000001	39.174621999999999	44.031298999999997	44.016131999999999	Магринская	0103000020E61000000100000005000000548EC9E2FE934340A435069D10024640548EC9E2FE934340E1B20A9B01044640C09481035A964340E1B20A9B01044640C09481035A964340A435069D10024640548EC9E2FE934340A435069D10024640
23609	10081	39.587828999999999	39.591611	43.701227000000003	43.699272000000001	Весенняя	0103000020E61000000100000005000000F8510DFB3DCB43401781B1BE81D94540F8510DFB3DCB43403E096CCEC1D94540187AC4E8B9CB43403E096CCEC1D94540187AC4E8B9CB43401781B1BE81D94540F8510DFB3DCB43401781B1BE81D94540
8224	10702	39.287801000000002	39.339885000000002	43.950814999999999	43.902309000000002	улица Победы	0103000020E61000000100000005000000C860C5A9D6A4434078F17EDC7EF34540C860C5A9D6A44340EBC5504EB4F9454053B3075A81AB4340EBC5504EB4F9454053B3075A81AB434078F17EDC7EF34540C860C5A9D6A4434078F17EDC7EF34540
3033	10702	39.339885000000002	39.364238999999998	43.902309000000002	43.886381	Сочинское шоссе	0103000020E6100000010000000500000053B3075A81AB4340DC65BFEE74F1454053B3075A81AB434078F17EDC7EF34540C07630629FAE434078F17EDC7EF34540C07630629FAE4340DC65BFEE74F1454053B3075A81AB4340DC65BFEE74F14540
20728	10702	39.287801000000002	39.339885000000002	43.950814999999999	43.902309000000002	Победы	0103000020E61000000100000005000000C860C5A9D6A4434078F17EDC7EF34540C860C5A9D6A44340EBC5504EB4F9454053B3075A81AB4340EBC5504EB4F9454053B3075A81AB434078F17EDC7EF34540C860C5A9D6A4434078F17EDC7EF34540
23890	10702	39.325583999999999	39.334729000000003	43.917758999999997	43.910271999999999	Партизанская	0103000020E61000000100000005000000E90C8CBCACA94340753BFBCA83F44540E90C8CBCACA94340094E7D2079F54540EB025E66D8AA4340094E7D2079F54540EB025E66D8AA4340753BFBCA83F44540E90C8CBCACA94340753BFBCA83F44540
20952	10702	39.326276	39.343792999999998	43.918765999999998	43.905855000000003	Павлова	0103000020E610000001000000050000001FBC7669C3A9434084F57F0EF3F345401FBC7669C3A943409F56D11F9AF54540FFCBB56801AC43409F56D11F9AF54540FFCBB56801AC434084F57F0EF3F345401FBC7669C3A9434084F57F0EF3F34540
21443	10702	39.324497000000001	39.327272999999998	43.910530999999999	43.90746	Нахимова	0103000020E610000001000000050000003753211E89A94340CE3637A627F445403753211E89A94340417FA1478CF4454091EEE714E4A94340417FA1478CF4454091EEE714E4A94340CE3637A627F445403753211E89A94340CE3637A627F44540
3253	11491	39.628836999999997	39.636437000000001	43.679971000000002	43.669238	улица Чайная	0103000020E61000000100000005000000E3C116BB7DD04340C79E3D97A9D54540E3C116BB7DD043403D9D2B4A09D74540707B82C476D143403D9D2B4A09D74540707B82C476D14340C79E3D97A9D54540E3C116BB7DD04340C79E3D97A9D54540
75537	11491	39.618398999999997	39.651860999999997	43.681260999999999	43.658889000000002	Образцовая	0103000020E610000001000000050000008670CCB227CF4340DA58897956D445408670CCB227CF43402785798F33D74540D844662E70D343402785798F33D74540D844662E70D34340DA58897956D445408670CCB227CF4340DA58897956D44540
3075	10856	39.392491	39.446514999999998	43.884867	43.814799000000001	улица Магистральная	0103000020E61000000100000005000000B77C24253DB2434021E868554BE84540B77C24253DB24340A227655243F1454033164D6727B94340A227655243F1454033164D6727B9434021E868554BE84540B77C24253DB2434021E868554BE84540
16059	11544	39.650297999999999	39.651439000000003	43.658921999999997	43.653782	улица Фестивальная	0103000020E61000000100000005000000BD5301F73CD34340535BEA20AFD34540BD5301F73CD34340B54E5C8E57D44540632B685A62D34340B54E5C8E57D44540632B685A62D34340535BEA20AFD34540BD5301F73CD34340535BEA20AFD34540
3296	11544	39.666162	39.690137999999997	43.703305999999998	43.664490999999998	Барановское шоссе	0103000020E6100000010000000500000042EBE1CB44D5434040BE840A0ED5454042EBE1CB44D54340508A56EE05DA454009DD257156D84340508A56EE05DA454009DD257156D8434040BE840A0ED5454042EBE1CB44D5434040BE840A0ED54540
20494	11544	39.647477000000002	39.656298999999997	43.679873000000001	43.651943000000003	Армавирская	0103000020E61000000100000005000000C3F4BD86E0D2434096ED43DE72D34540C3F4BD86E0D243407A37161406D74540E1B20A9B01D443407A37161406D74540E1B20A9B01D4434096ED43DE72D34540C3F4BD86E0D2434096ED43DE72D34540
3275	11583	39.637794	39.701627999999999	43.666617000000002	43.640689999999999	Батумское шоссе	0103000020E61000000100000005000000E2CAD93BA3D14340E76F422102D24540E2CAD93BA3D1434094FAB2B453D545409CFA40F2CED9434094FAB2B453D545409CFA40F2CED94340E76F422102D24540E2CAD93BA3D14340E76F422102D24540
2844	10008	39.240406	39.255820999999997	43.981070000000003	43.967056999999997	улица Авроры	0103000020E610000001000000050000008FE1B19FC59E4340162F1686C8FB45408FE1B19FC59E43401A8BA6B393FD4540A45016BEBEA043401A8BA6B393FD4540A45016BEBEA04340162F1686C8FB45408FE1B19FC59E4340162F1686C8FB4540
3410	10369	39.656855999999998	39.665992000000003	43.705919000000002	43.686281000000001	улица Космическая	0103000020E6100000010000000500000037177FDB13D44340DF6E490ED8D7454037177FDB13D443400150C58D5BDA4540E6B2D1393FD543400150C58D5BDA4540E6B2D1393FD54340DF6E490ED8D7454037177FDB13D44340DF6E490ED8D74540
23878	10369	39.649939000000003	39.660511999999997	43.686515999999997	43.679931000000003	 Надежная	0103000020E610000001000000050000008EB27E3331D34340AF44A0FA07D745408EB27E3331D3434022179CC1DFD74540CA4E3FA88BD4434022179CC1DFD74540CA4E3FA88BD44340AF44A0FA07D745408EB27E3331D34340AF44A0FA07D74540
3225	11371	39.549247000000001	39.566063	43.76294	43.750985	улица Октемберянская	0103000020E610000001000000050000008B36C7B94DC64340AE64C74620E045408B36C7B94DC64340B6679604A8E14540E23C9CC074C84340B6679604A8E14540E23C9CC074C84340AE64C74620E045408B36C7B94DC64340AE64C74620E04540
3198	11241	39.616278999999999	39.629519999999999	43.74024	43.733908999999997	улица Краснооктябрьская	0103000020E61000000100000005000000151BF33AE2CE4340BA9EE8BAF0DD4540151BF33AE2CE434074982F2FC0DE4540C616821C94D0434074982F2FC0DE4540C616821C94D04340BA9EE8BAF0DD4540151BF33AE2CE4340BA9EE8BAF0DD4540
3189	11208	39.524228999999998	39.569206999999999	43.754117000000001	43.726436999999997	улица Львовская	0103000020E61000000100000005000000B14E95EF19C343405BCD3AE3FBDC4540B14E95EF19C34340C72DE6E786E04540BFD364C6DBC84340C72DE6E786E04540BFD364C6DBC843405BCD3AE3FBDC4540B14E95EF19C343405BCD3AE3FBDC4540
23805	11208	39.547755000000002	39.554861000000002	43.739237000000003	43.727916	 Молодежная	0103000020E61000000100000005000000399CF9D51CC64340191EFB592CDD4540399CF9D51CC64340207F69519FDE4540B6696CAF05C74340207F69519FDE4540B6696CAF05C74340191EFB592CDD4540399CF9D51CC64340191EFB592CDD4540
3091	10913	39.475971000000001	39.519565999999998	43.838765000000002	43.811312999999998	улица Ачмизова	0103000020E61000000100000005000000166C239EECBC4340EAE8B81AD9E74540166C239EECBC4340C503CAA65CEB4540880E812381C24340C503CAA65CEB4540880E812381C24340EAE8B81AD9E74540166C239EECBC4340EAE8B81AD9E74540
20981	11129	39.517330000000001	39.530382000000003	43.775047999999998	43.760283000000001	Араратская	0103000020E61000000100000005000000AE9E93DE37C24340365A0EF450E14540AE9E93DE37C24340446ADAC534E345408C31B08EE3C34340446ADAC534E345408C31B08EE3C34340365A0EF450E14540AE9E93DE37C24340365A0EF450E14540
21407	50365	39.955419999999997	39.990094999999997	43.500647000000001	43.458329999999997	Пензенская	0103000020E61000000100000005000000DFF8DA334BFA43404963B48EAABA4540DFF8DA334BFA434096EB6D3315C045407077D66EBBFE434096EB6D3315C045407077D66EBBFE43404963B48EAABA4540DFF8DA334BFA43404963B48EAABA4540
21030	50317	39.981318000000002	40.015185000000002	43.434899000000001	43.391461	Худякова	0103000020E61000000100000005000000F27C06D49BFD43406954E0641BB24540F27C06D49BFD434014083BC5AAB74540E4310395F101444014083BC5AAB74540E4310395F10144406954E0641BB24540F27C06D49BFD43406954E0641BB24540
1778	6574	39.972181999999997	39.990381999999997	43.458559999999999	43.430303000000002	улица Владимировская	0103000020E6100000010000000500000043E1B37570FC4340732F302B14B7454043E1B37570FC43407BA01518B2BA454006465ED6C4FE43407BA01518B2BA454006465ED6C4FE4340732F302B14B7454043E1B37570FC4340732F302B14B74540
15699	7182	39.920510999999998	39.925891999999997	43.478430000000003	43.454155	улица Петрозаводская	0103000020E61000000100000005000000DB4DF04DD3F543404E2844C021BA4540DB4DF04DD3F5434070B6B9313DBD454063D009A183F6434070B6B9313DBD454063D009A183F643404E2844C021BA4540DB4DF04DD3F543404E2844C021BA4540
23428	50704	39.996859000000001	40.010029000000003	43.433374000000001	43.405681999999999	Мира	0103000020E6100000010000000500000094DC611399FF4340B6494563EDB3454094DC611399FF4340E6779ACC78B745407C8159A148014440E6779ACC78B745407C8159A148014440B6494563EDB3454094DC611399FF4340B6494563EDB34540
21123	6456	40.009346000000001	40.032873000000002	43.476937999999997	43.428364999999999	улица Светогорская	0103000020E61000000100000005000000992CEE3F3201444022E010AAD4B64540992CEE3F320144401D1CEC4D0CBD4540F1F5B52E350444401D1CEC4D0CBD4540F1F5B52E3504444022E010AAD4B64540992CEE3F3201444022E010AAD4B64540
1772	6456	39.993139999999997	39.99933	43.474007	43.471358000000002	улица Грушевая	0103000020E61000000100000005000000BA2C26361FFF43409F5A7D7555BC4540BA2C26361FFF43409C89E942ACBC4540B2F4A10BEAFF43409C89E942ACBC4540B2F4A10BEAFF43409F5A7D7555BC4540BA2C26361FFF43409F5A7D7555BC4540
21190	6456	40.009346000000001	40.032873000000002	43.476937999999997	43.428364999999999	Светогорская	0103000020E61000000100000005000000992CEE3F3201444022E010AAD4B64540992CEE3F320144401D1CEC4D0CBD4540F1F5B52E350444401D1CEC4D0CBD4540F1F5B52E3504444022E010AAD4B64540992CEE3F3201444022E010AAD4B64540
21515	50280	39.944738999999998	39.977967999999997	43.404077999999998	43.392640999999998	улица Нижнеимеретинская	0103000020E61000000100000005000000BC202235EDF84340CC086F0F42B24540BC202235EDF843403C84F1D3B8B345406B44300E2EFD43403C84F1D3B8B345406B44300E2EFD4340CC086F0F42B24540BC202235EDF84340CC086F0F42B24540
75603	50280	39.926341000000001	39.995952000000003	43.417830000000002	43.385814000000003	микрорайон Мирный	0103000020E61000000100000005000000D3F8855792F64340632B685A62B14540D3F8855792F64340D3A414747BB545406231EA5A7BFF4340D3A414747BB545406231EA5A7BFF4340632B685A62B14540D3F8855792F64340632B685A62B14540
20942	50280	39.980195000000002	39.983536999999998	43.394606000000003	43.391638	Полевая	0103000020E61000000100000005000000F3599E0777FD434078EFA83121B24540F3599E0777FD434017670C7382B24540F6B3588AE4FD434017670C7382B24540F6B3588AE4FD434078EFA83121B24540F3599E0777FD434078EFA83121B24540
23676	8335	39.947605000000003	39.953560000000003	43.457827000000002	43.452067999999997	 Пчеловодов	0103000020E610000001000000050000005743E21E4BF94340B8C83D5DDDB945405743E21E4BF94340E71C3C139ABA45400B630B410EFA4340E71C3C139ABA45400B630B410EFA4340B8C83D5DDDB945405743E21E4BF94340B8C83D5DDDB94540
140	504	39.996859000000001	40.010029000000003	43.433374000000001	43.405681999999999	улица Мира	0103000020E6100000010000000500000094DC611399FF4340B6494563EDB3454094DC611399FF4340E6779ACC78B745407C8159A148014440E6779ACC78B745407C8159A148014440B6494563EDB3454094DC611399FF4340B6494563EDB34540
23593	504	40.002096000000002	40.004288000000003	43.413567	43.409984999999999	Мира переулок	0103000020E61000000100000005000000E9B985AE44004440DF6C73637AB44540E9B985AE4400444038DA71C3EFB44540F4E159828C00444038DA71C3EFB44540F4E159828C004440DF6C73637AB44540E9B985AE44004440DF6C73637AB44540
23730	8028	39.917520000000003	39.936591	43.52355	43.498567999999999	Мостовая	0103000020E6100000010000000500000085B69C4B71F54340836A8313D1BF454085B69C4B71F5434010E9B7AF03C345402D5DC136E2F7434010E9B7AF03C345402D5DC136E2F74340836A8313D1BF454085B69C4B71F54340836A8313D1BF4540
20698	13104	39.916640000000001	39.928038999999998	43.433793000000001	43.423814999999998	улица Ульянова	0103000020E610000001000000050000004C1AA37554F54340F146E6913FB645404C1AA37554F54340EB1D6E8786B74540CE3461FBC9F64340EB1D6E8786B74540CE3461FBC9F64340F146E6913FB645404C1AA37554F54340F146E6913FB64540
20975	13104	39.910837000000001	39.921509	43.437027	43.431325000000001	улица Ромашек	0103000020E610000001000000050000004E7E8B4E96F443403E7958A835B745404E7E8B4E96F44340083C3080F0B745401EFCC401F4F54340083C3080F0B745401EFCC401F4F543403E7958A835B745404E7E8B4E96F443403E7958A835B74540
20438	13104	39.920088999999997	39.924095999999999	43.435690999999998	43.432797999999998	улица Революции	0103000020E610000001000000050000006534F279C5F5434019E3C3EC65B745406534F279C5F54340AD1402B9C4B74540A52E19C748F64340AD1402B9C4B74540A52E19C748F6434019E3C3EC65B745406534F279C5F5434019E3C3EC65B74540
20801	13104	39.886527999999998	39.939141999999997	43.494284	43.421517000000001	улица Ленина	0103000020E61000000100000005000000807EDFBF79F14340A1DAE044F4B54540807EDFBF79F14340D177B7B244BF4540672618CE35F84340D177B7B244BF4540672618CE35F84340A1DAE044F4B54540807EDFBF79F14340A1DAE044F4B54540
20738	13104	39.912965999999997	39.922209000000002	43.438662999999998	43.428607999999997	улица Куйбышева	0103000020E61000000100000005000000122EE411DCF44340E8667FA0DCB64540122EE411DCF443408D7BF31B26B84540D789CBF10AF643408D7BF31B26B84540D789CBF10AF64340E8667FA0DCB64540122EE411DCF44340E8667FA0DCB64540
20691	13104	39.909139000000003	39.917062000000001	43.448146999999999	43.43994	улица Кирпичная	0103000020E610000001000000050000005342B0AA5EF44340E31934F44FB845405342B0AA5EF44340776682E15CB94540C233A14962F54340776682E15CB94540C233A14962F54340E31934F44FB845405342B0AA5EF44340E31934F44FB84540
20662	13104	39.916640000000001	39.928038999999998	43.433793000000001	43.423814999999998	Ульянова	0103000020E610000001000000050000004C1AA37554F54340F146E6913FB645404C1AA37554F54340EB1D6E8786B74540CE3461FBC9F64340EB1D6E8786B74540CE3461FBC9F64340F146E6913FB645404C1AA37554F54340F146E6913FB64540
20965	13104	39.914923999999999	39.926270000000002	43.434970999999997	43.425589000000002	Свердлова	0103000020E61000000100000005000000AA29C93A1CF54340C8444AB379B64540AA29C93A1CF54340ADDA3521ADB745400AA2EE0390F64340ADDA3521ADB745400AA2EE0390F64340C8444AB379B64540AA29C93A1CF54340C8444AB379B64540
21104	13104	39.923090000000002	39.929251999999998	43.433249000000004	43.426603999999998	Садовая	0103000020E61000000100000005000000E0A128D027F64340E02BBAF59AB64540E0A128D027F643402A0307B474B745400DDFC2BAF1F643402A0307B474B745400DDFC2BAF1F64340E02BBAF59AB64540E0A128D027F64340E02BBAF59AB64540
21537	13104	39.888001000000003	39.921311000000003	43.487488999999997	43.418438999999999	Просвещения	0103000020E610000001000000050000005CE84A04AAF143407B2FBE688FB545405CE84A04AAF143407214200A66BE4540F838D384EDF543407214200A66BE4540F838D384EDF543407B2FBE688FB545405CE84A04AAF143407B2FBE688FB54540
21109	13104	39.919784	39.928192000000003	43.435513999999998	43.428502999999999	Молокова	0103000020E6100000010000000500000029B16B7BBBF54340739EB12FD9B6454029B16B7BBBF543409E7939ECBEB745405534D6FECEF643409E7939ECBEB745405534D6FECEF64340739EB12FD9B6454029B16B7BBBF54340739EB12FD9B64540
21116	13104	39.916764999999998	39.922775000000001	43.443218999999999	43.440731999999997	Котовского	0103000020E61000000100000005000000088F368E58F543407C26FBE769B84540088F368E58F54340A0FB7266BBB845408048BF7D1DF64340A0FB7266BBB845408048BF7D1DF643407C26FBE769B84540088F368E58F543407C26FBE769B84540
21625	13104	39.942430000000002	39.967556000000002	43.462839000000002	43.450549000000002	Костромская	0103000020E610000001000000050000007862D68BA1F843406D1FF296ABB945407862D68BA1F843401C28F04E3EBB4540388600E0D8FB43401C28F04E3EBB4540388600E0D8FB43406D1FF296ABB945407862D68BA1F843406D1FF296ABB94540
20690	13104	39.909139000000003	39.917062000000001	43.448146999999999	43.43994	Кирпичная	0103000020E610000001000000050000005342B0AA5EF44340E31934F44FB845405342B0AA5EF44340776682E15CB94540C233A14962F54340776682E15CB94540C233A14962F54340E31934F44FB845405342B0AA5EF44340E31934F44FB84540
21039	13104	39.920907	39.931246000000002	43.432313000000001	43.420535000000001	Демократическая	0103000020E6100000010000000500000028D4D347E0F5434064E94317D4B5454028D4D347E0F543405D514A0856B74540F243A51133F743405D514A0856B74540F243A51133F7434064E94317D4B5454028D4D347E0F5434064E94317D4B54540
21179	13104	39.903497000000002	39.910665999999999	43.457512000000001	43.449803000000003	Голубые Дали	0103000020E610000001000000050000005E8429CAA5F3434044520B2593B945405E8429CAA5F3434087C3D2C08FBA454021CA17B490F4434087C3D2C08FBA454021CA17B490F4434044520B2593B945405E8429CAA5F3434044520B2593B94540
21182	13104	39.909336000000003	39.921509	43.454155	43.443919000000001	Гастелло	0103000020E61000000100000005000000A9893E1F65F4434059897956D2B84540A9893E1F65F443404E2844C021BA45401EFCC401F4F543404E2844C021BA45401EFCC401F4F5434059897956D2B84540A9893E1F65F4434059897956D2B84540
22937	13104	39.886178000000001	39.967556000000002	43.494284	43.414648	8 Марта	0103000020E61000000100000005000000A437DC476EF1434008AD872F13B54540A437DC476EF14340D177B7B244BF4540388600E0D8FB4340D177B7B244BF4540388600E0D8FB434008AD872F13B54540A437DC476EF1434008AD872F13B54540
21392	13104	39.903497000000002	39.910665999999999	43.457512000000001	43.449803000000003	 Голубые Дали	0103000020E610000001000000050000005E8429CAA5F3434044520B2593B945405E8429CAA5F3434087C3D2C08FBA454021CA17B490F4434087C3D2C08FBA454021CA17B490F4434044520B2593B945405E8429CAA5F3434044520B2593B94540
22343	47651	39.844056000000002	39.886958999999997	44.737653999999999	44.717506999999998	Шоссейная	0103000020E610000001000000050000000DFFE9060AEC434056D3F544D75B46400DFFE9060AEC4340BDE13E726B5E464049F25CDF87F14340BDE13E726B5E464049F25CDF87F1434056D3F544D75B46400DFFE9060AEC434056D3F544D75B4640
21127	47651	39.844056000000002	39.886958999999997	44.737653999999999	44.717506999999998	Школьная	0103000020E610000001000000050000000DFFE9060AEC434056D3F544D75B46400DFFE9060AEC4340BDE13E726B5E464049F25CDF87F14340BDE13E726B5E464049F25CDF87F1434056D3F544D75B46400DFFE9060AEC434056D3F544D75B4640
20693	47651	39.844056000000002	39.886958999999997	44.737653999999999	44.717506999999998	Центральная	0103000020E610000001000000050000000DFFE9060AEC434056D3F544D75B46400DFFE9060AEC4340BDE13E726B5E464049F25CDF87F14340BDE13E726B5E464049F25CDF87F1434056D3F544D75B46400DFFE9060AEC434056D3F544D75B4640
23345	47651	39.844056000000002	39.886958999999997	44.737653999999999	44.717506999999998	Краснооктябрьская	0103000020E610000001000000050000000DFFE9060AEC434056D3F544D75B46400DFFE9060AEC4340BDE13E726B5E464049F25CDF87F14340BDE13E726B5E464049F25CDF87F1434056D3F544D75B46400DFFE9060AEC434056D3F544D75B4640
20484	20418	39.835225000000001	39.864590999999997	44.921968	44.889901000000002	Советская	0103000020E610000001000000050000009BE61DA7E8EA4340BFD6A546E87146409BE61DA7E8EA4340B1FA230C037646403DB5FAEAAAEE4340B1FA230C037646403DB5FAEAAAEE4340BFD6A546E87146409BE61DA7E8EA4340BFD6A546E8714640
23893	21652	39.655498999999999	39.687677000000001	44.718564000000001	44.683852000000002	Красная	0103000020E61000000100000005000000C5C72764E7D34340F0A65B7688574640C5C72764E7D343409E0AB8E7F95B46400F9BC8CC05D843409E0AB8E7F95B46400F9BC8CC05D84340F0A65B7688574640C5C72764E7D34340F0A65B7688574640
20510	21189	39.514598999999997	39.524299999999997	45.018965000000001	45.009954999999998	Школьная	0103000020E61000000100000005000000F3C64961DEC1434041B7973446814640F3C64961DEC143406362F3716D8246407AA52C431CC343406362F3716D8246407AA52C431CC3434041B7973446814640F3C64961DEC1434041B7973446814640
21976	22148	39.856200999999999	39.879018000000002	44.647162999999999	44.635528999999998	Мира	0103000020E61000000100000005000000B8E68EFE97ED43406D54A70359514640B8E68EFE97ED43403317B83CD6524640344C6DA983F043403317B83CD6524640344C6DA983F043406D54A70359514640B8E68EFE97ED43406D54A70359514640
20609	46907	39.588476	39.606766	45.043469999999999	45.025807	Красная	0103000020E610000001000000050000008E3D7B2E53CB43400281CEA44D8346408E3D7B2E53CB4340B62DCA6C9085464091291F82AACD4340B62DCA6C9085464091291F82AACD43400281CEA44D8346408E3D7B2E53CB43400281CEA44D834640
21133	48541	39.814807000000002	39.823591999999998	44.790753000000002	44.782333999999999	Комарова	0103000020E61000000100000005000000A4C684984BE843404146408523644640A4C684984BE84340611BF16437654640A59F70766BE94340611BF16437654640A59F70766BE943404146408523644640A4C684984BE843404146408523644640
21121	21215	39.555732999999996	39.606459999999998	44.977708	44.940384000000002	Победы	0103000020E610000001000000050000006B274A4222C7434041D7BE805E7846406B274A4222C74340CF842689257D4640842A357BA0CD4340CF842689257D4640842A357BA0CD434041D7BE805E7846406B274A4222C7434041D7BE805E784640
21525	21215	39.555732999999996	39.606459999999998	44.977708	44.940384000000002	Первомайская	0103000020E610000001000000050000006B274A4222C7434041D7BE805E7846406B274A4222C74340CF842689257D4640842A357BA0CD4340CF842689257D4640842A357BA0CD434041D7BE805E7846406B274A4222C7434041D7BE805E784640
22359	21215	39.555732999999996	39.606459999999998	44.977708	44.940384000000002	Кубанская	0103000020E610000001000000050000006B274A4222C7434041D7BE805E7846406B274A4222C74340CF842689257D4640842A357BA0CD4340CF842689257D4640842A357BA0CD434041D7BE805E7846406B274A4222C7434041D7BE805E784640
22126	48469	39.908698999999999	39.920341000000001	44.744836999999997	44.732191999999998	Центральная	0103000020E610000001000000050000003674B33F50F443404832AB77B85D46403674B33F50F44340E5EC9DD1565F46407F15E0BBCDF54340E5EC9DD1565F46407F15E0BBCDF543404832AB77B85D46403674B33F50F443404832AB77B85D4640
20680	48469	39.908698999999999	39.920341000000001	44.744836999999997	44.732191999999998	Норильская	0103000020E610000001000000050000003674B33F50F443404832AB77B85D46403674B33F50F44340E5EC9DD1565F46407F15E0BBCDF54340E5EC9DD1565F46407F15E0BBCDF543404832AB77B85D46403674B33F50F443404832AB77B85D4640
20848	22165	39.776484000000004	39.821849	44.716341	44.676051999999999	Мира	0103000020E6100000010000000500000003EFE4D363E343409C3237DF8856464003EFE4D363E3434058E4D70FB15B46400AA0185932E9434058E4D70FB15B46400AA0185932E943409C3237DF8856464003EFE4D363E343409C3237DF88564640
21637	22165	39.776484000000004	39.821849	44.716341	44.676051999999999	Крестьянская	0103000020E6100000010000000500000003EFE4D363E343409C3237DF8856464003EFE4D363E3434058E4D70FB15B46400AA0185932E9434058E4D70FB15B46400AA0185932E943409C3237DF8856464003EFE4D363E343409C3237DF88564640
23248	22165	39.776484000000004	39.821849	44.716341	44.676051999999999	 Заречная	0103000020E6100000010000000500000003EFE4D363E343409C3237DF8856464003EFE4D363E3434058E4D70FB15B46400AA0185932E9434058E4D70FB15B46400AA0185932E943409C3237DF8856464003EFE4D363E343409C3237DF88564640
20817	48759	39.759452000000003	39.778452000000001	44.874248000000001	44.852404	Мира	0103000020E61000000100000005000000DF701FB935E14340637D03931B6D4640DF701FB935E14340F54BC45BE76F4640BEC0AC50A4E34340F54BC45BE76F4640BEC0AC50A4E34340637D03931B6D4640DF701FB935E14340637D03931B6D4640
20614	50267	39.726951	39.753585999999999	44.905008000000002	44.885603000000003	Центральная	0103000020E61000000100000005000000B265F9BA0CDD4340A81E69705B714640B265F9BA0CDD4340274F594DD77346409A5C8C8175E04340274F594DD77346409A5C8C8175E04340A81E69705B714640B265F9BA0CDD4340A81E69705B714640
21390	50360	39.605814000000002	39.63288	44.860582999999998	44.843234000000002	Привокзальная	0103000020E61000000100000005000000BFBA2A508BCD434009707A17EF6B4640BFBA2A508BCD43402D3F7095276E464070253B3602D143402D3F7095276E464070253B3602D1434009707A17EF6B4640BFBA2A508BCD434009707A17EF6B4640
22127	21577	39.646867	39.661355999999998	44.787593000000001	44.774624000000003	Школьная	0103000020E610000001000000050000004AEEB089CCD243402E5915E1266346404AEEB089CCD243407EC7F0D8CF644640B6813B50A7D443407EC7F0D8CF644640B6813B50A7D443402E5915E1266346404AEEB089CCD243402E5915E126634640
21656	32941	39.851512	39.873583000000004	44.963659999999997	44.946112999999997	Красная	0103000020E6100000010000000500000066136058FEEC434004A9143B1A79464066136058FEEC43404F3BFC35597B4640B9AB5791D1EF43404F3BFC35597B4640B9AB5791D1EF434004A9143B1A79464066136058FEEC434004A9143B1A794640
21785	21351	39.646399000000002	39.663764	44.888317000000001	44.868957999999999	Клубная	0103000020E610000001000000050000006495D233BDD243407DCC07043A6F46406495D233BDD243408CBD175FB47146408E210038F6D443408CBD175FB47146408E210038F6D443407DCC07043A6F46406495D233BDD243407DCC07043A6F4640
20883	48813	39.666189000000003	39.690049000000002	44.685901999999999	44.670397999999999	Ленина	0103000020E610000001000000050000003CFA5FAE45D54340E3A6069ACF5546403CFA5FAE45D54340682101A3CB5746409AD18F8653D84340682101A3CB5746409AD18F8653D84340E3A6069ACF5546403CFA5FAE45D54340E3A6069ACF554640
21562	48643	39.770071000000002	39.787227999999999	44.904848000000001	44.894658	Клубная	0103000020E610000001000000050000008C4CC0AF91E24340698D4127847246408C4CC0AF91E24340EEEC2B0FD27346406C3F19E3C3E44340EEEC2B0FD27346406C3F19E3C3E44340698D4127847246408C4CC0AF91E24340698D412784724640
21557	20569	39.911160000000002	39.934058	44.919944999999998	44.904381999999998	Мира	0103000020E6100000010000000500000031B610E4A0F44340A88B14CAC273464031B610E4A0F44340328FFCC1C0754640994869368FF74340328FFCC1C0754640994869368FF74340A88B14CAC273464031B610E4A0F44340A88B14CAC2734640
23517	50746	39.815416999999997	39.842385	44.770772000000001	44.740361999999998	Центральная	0103000020E610000001000000050000001CCD91955FE84340BF99982EC45E46401CCD91955FE8434015562AA8A86246400BD28C45D3EB434015562AA8A86246400BD28C45D3EB4340BF99982EC45E46401CCD91955FE84340BF99982EC45E4640
21075	21831	39.759963999999997	39.787075999999999	44.749338000000002	44.713375999999997	Химплощадка	0103000020E610000001000000050000009411178046E143402AE09EE74F5B46409411178046E1434035D3BD4EEA5F4640B6BB07E8BEE4434035D3BD4EEA5F4640B6BB07E8BEE443402AE09EE74F5B46409411178046E143402AE09EE74F5B4640
21386	21831	39.759963999999997	39.787075999999999	44.749338000000002	44.713375999999997	Советская	0103000020E610000001000000050000009411178046E143402AE09EE74F5B46409411178046E1434035D3BD4EEA5F4640B6BB07E8BEE4434035D3BD4EEA5F4640B6BB07E8BEE443402AE09EE74F5B46409411178046E143402AE09EE74F5B4640
22399	21831	39.759963999999997	39.787075999999999	44.749338000000002	44.713375999999997	Заводская	0103000020E610000001000000050000009411178046E143402AE09EE74F5B46409411178046E1434035D3BD4EEA5F4640B6BB07E8BEE4434035D3BD4EEA5F4640B6BB07E8BEE443402AE09EE74F5B46409411178046E143402AE09EE74F5B4640
21920	21924	39.771391000000001	39.799266000000003	44.827184000000003	44.787413999999998	Луценко	0103000020E61000000100000005000000E1B6B6F0BCE24340CE3461FBC9644640E1B6B6F0BCE2434022E3512AE1694640026729594EE6434022E3512AE1694640026729594EE64340CE3461FBC9644640E1B6B6F0BCE24340CE3461FBC9644640
23211	21924	39.771391000000001	39.799266000000003	44.827184000000003	44.787413999999998	Голенева	0103000020E61000000100000005000000E1B6B6F0BCE24340CE3461FBC9644640E1B6B6F0BCE2434022E3512AE1694640026729594EE6434022E3512AE1694640026729594EE64340CE3461FBC9644640E1B6B6F0BCE24340CE3461FBC9644640
21387	21740	39.603262000000001	39.625388000000001	44.675474999999999	44.638088000000003	Школьная	0103000020E61000000100000005000000B47570B037CD43402BFC19DEAC514640B47570B037CD4340FF21FDF675564640CAA7C7B60CD04340FF21FDF675564640CAA7C7B60CD043402BFC19DEAC514640B47570B037CD43402BFC19DEAC514640
22025	21129	39.669719999999998	39.686976000000001	44.909668000000003	44.900436999999997	Солнечная	0103000020E6100000010000000500000012BD8C62B9D54340DE8D05854173464012BD8C62B9D54340DF1B43007074464086915ED4EED74340DF1B43007074464086915ED4EED74340DE8D05854173464012BD8C62B9D54340DE8D058541734640
21379	20856	39.770806999999998	39.793875999999997	44.839987000000001	44.828736999999997	Гагарина	0103000020E610000001000000050000009143C4CDA9E2434019FED30D146A46409143C4CDA9E243405708ABB1846B4640268A90BA9DE543405708ABB1846B4640268A90BA9DE5434019FED30D146A46409143C4CDA9E2434019FED30D146A4640
21320	20721	39.717564000000003	39.785333000000001	44.958998000000001	44.910069999999997	Советская	0103000020E61000000100000005000000BB641C23D9DB43400D897B2C7D744640BB641C23D9DB4340F7764B72C07A46401BBCAFCA85E44340F7764B72C07A46401BBCAFCA85E443400D897B2C7D744640BB641C23D9DB43400D897B2C7D744640
20915	20721	39.717564000000003	39.785333000000001	44.958998000000001	44.910069999999997	Почтовая	0103000020E61000000100000005000000BB641C23D9DB43400D897B2C7D744640BB641C23D9DB4340F7764B72C07A46401BBCAFCA85E44340F7764B72C07A46401BBCAFCA85E443400D897B2C7D744640BB641C23D9DB43400D897B2C7D744640
22335	20721	39.717564000000003	39.785333000000001	44.958998000000001	44.910069999999997	Ленина	0103000020E61000000100000005000000BB641C23D9DB43400D897B2C7D744640BB641C23D9DB4340F7764B72C07A46401BBCAFCA85E44340F7764B72C07A46401BBCAFCA85E443400D897B2C7D744640BB641C23D9DB43400D897B2C7D744640
23772	21439	39.663207	39.700451000000001	44.857120000000002	44.823687	Красная	0103000020E6100000010000000500000038BD8BF7E3D44340F7915B936E69464038BD8BF7E3D44340AF5FB01BB66D4640AAB9DC60A8D94340AF5FB01BB66D4640AAB9DC60A8D94340F7915B936E69464038BD8BF7E3D44340F7915B936E694640
23849	21439	39.663207	39.700451000000001	44.857120000000002	44.823687	Комсомольская	0103000020E6100000010000000500000038BD8BF7E3D44340F7915B936E69464038BD8BF7E3D44340AF5FB01BB66D4640AAB9DC60A8D94340AF5FB01BB66D4640AAB9DC60A8D94340F7915B936E69464038BD8BF7E3D44340F7915B936E694640
22633	11745	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Совхозная	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
9877	11745	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Ленина	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
21317	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Шалимова	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
21327	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Свердлова	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20673	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Пролетарская	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20914	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Победы	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20876	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Мира	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20873	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Луначарского	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
10084	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Ленина	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20901	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Красная	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
21069	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Интернациональная	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20923	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Железнодорожная	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20670	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Деповская	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20656	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	Гоголя	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
21485	40522	39.836069999999999	39.917763000000001	44.803806999999999	44.735886000000001	40 лет Октября	0103000020E6100000010000000500000057957D5704EB4340C9CA2F83315E464057957D5704EB4340DFA5D425E36646404B3D0B4279F54340DFA5D425E36646404B3D0B4279F54340C9CA2F83315E464057957D5704EB4340C9CA2F83315E4640
20724	32947	39.843947999999997	39.862301000000002	45.015613000000002	44.995654000000002	Первомайская	0103000020E6100000010000000500000026C3F17C06EC4340D8101C97717F464026C3F17C06EC43403C32569BFF814640702711E15FEE43403C32569BFF814640702711E15FEE4340D8101C97717F464026C3F17C06EC4340D8101C97717F4640
21132	18051	40.834609999999998	40.857472000000001	46.204796000000002	46.192576000000003	Советская	0103000020E6100000010000000500000010751F80D46A44404CFF9254A618474010751F80D46A4440022D5DC1361A47402C9E7AA4C16D4440022D5DC1361A47402C9E7AA4C16D44404CFF9254A618474010751F80D46A44404CFF9254A6184740
21482	18377	41.023201999999998	41.097690999999998	45.791024999999998	45.745955000000002	Советская	0103000020E61000000100000005000000D4997B48F8824440D3A414747BDF4640D4997B48F8824440C1A8A44E40E54640880E8123818C4440C1A8A44E40E54640880E8123818C4440D3A414747BDF4640D4997B48F8824440D3A414747BDF4640
20868	18377	41.023201999999998	41.097690999999998	45.791024999999998	45.745955000000002	Краснопартизанская	0103000020E61000000100000005000000D4997B48F8824440D3A414747BDF4640D4997B48F8824440C1A8A44E40E54640880E8123818C4440C1A8A44E40E54640880E8123818C4440D3A414747BDF4640D4997B48F8824440D3A414747BDF4640
22434	18472	40.948551999999999	40.961855999999997	45.744363999999997	45.723925000000001	Алексенко	0103000020E610000001000000050000001747E5266A794440DFE00B93A9DC46401747E5266A794440ED28CE5147DF46400EBBEF181E7B4440ED28CE5147DF46400EBBEF181E7B4440DFE00B93A9DC46401747E5266A794440DFE00B93A9DC4640
21291	17991	40.698695000000001	40.721611000000003	46.189725000000003	46.182712000000002	переулок Почтовый	0103000020E610000001000000050000007A7077D66E5944401B4B581B631747407A7077D66E594440E71DA7E84818474089B7CEBF5D5C4440E71DA7E84818474089B7CEBF5D5C44401B4B581B631747407A7077D66E5944401B4B581B63174740
20639	18074	40.905954000000001	40.926102999999998	46.202638	46.198994999999996	Садовая	0103000020E6100000010000000500000017D7F84CF6734440A4880CAB7819474017D7F84CF6734440A376BF0AF01947401EDD088B8A764440A376BF0AF01947401EDD088B8A764440A4880CAB7819474017D7F84CF6734440A4880CAB78194740
20892	18186	40.921810000000001	41.012072000000003	46.002043999999998	45.961154999999998	Соболя	0103000020E610000001000000050000001990BDDEFD75444085B1852007FB46401990BDDEFD754440969350FA42004740429946938B814440969350FA42004740429946938B81444085B1852007FB46401990BDDEFD75444085B1852007FB4640
23883	18315	41.198563	41.230694999999997	45.811942000000002	45.791226999999999	Красная	0103000020E610000001000000050000000B992B836A994440295B24ED46E546400B992B836A994440DA1F28B7EDE74640E42CEC69879D4440DA1F28B7EDE74640E42CEC69879D4440295B24ED46E546400B992B836A994440295B24ED46E54640
20866	18285	40.963203999999998	41.014983000000001	45.899737000000002	45.879173999999999	60 лет СССР	0103000020E610000001000000050000002DB0C7444A7B44402BBF0CC688F046402DB0C7444A7B44402600FF942AF346407C7F83F6EA8144402600FF942AF346407C7F83F6EA8144402BBF0CC688F046402DB0C7444A7B44402BBF0CC688F04640
22661	18158	40.959789999999998	40.981332000000002	46.278257000000004	46.268813999999999	Новая	0103000020E6100000010000000500000090831266DA7A44407D5A457F6822474090831266DA7A44400971E5EC9D234740574277499C7D44400971E5EC9D234740574277499C7D44407D5A457F6822474090831266DA7A44407D5A457F68224740
20622	18220	41.062610999999997	41.126778000000002	45.969135999999999	45.951687999999997	Мира	0103000020E6100000010000000500000057AF22A30388444071FF91E9D0F9464057AF22A30388444029B000A60CFC464018EDF1423A90444029B000A60CFC464018EDF1423A90444071FF91E9D0F9464057AF22A30388444071FF91E9D0F94640
21290	17927	40.594921999999997	40.611424	46.179310999999998	46.171754	Степная	0103000020E61000000100000005000000E0D57267264C4440857AFA08FC154740E0D57267264C44401268B0A9F3164740A8FE4124434E44401268B0A9F3164740A8FE4124434E4440857AFA08FC154740E0D57267264C4440857AFA08FC154740
21298	17464	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	Толстого	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
21726	17464	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	Первомайская	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
22093	17464	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	Крестьянская	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
22648	17464	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	Красная,	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
21476	17464	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	Красная	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
20979	17464	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	Колхозная	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
20887	17464	40.823453000000001	41.042417	46.103523000000003	46.060628000000001	Капитана Молчанова	0103000020E6100000010000000500000084656CE866694440679C86A8C207474084656CE86669444021B1DD3D400D4740B0E595EB6D85444021B1DD3D400D4740B0E595EB6D854440679C86A8C207474084656CE866694440679C86A8C2074740
22367	12901	39.797396999999997	39.820008000000001	44.389504000000002	44.367148	Советская	0103000020E61000000100000005000000D976DA1A11E643405A65A6B4FE2E4640D976DA1A11E64340A2D45E44DB314640AC3AAB05F6E84340A2D45E44DB314640AC3AAB05F6E843405A65A6B4FE2E4640D976DA1A11E643405A65A6B4FE2E4640
20466	45660	39.748384999999999	39.775191	44.263804999999998	44.241484999999997	Шоссейная	0103000020E6100000010000000500000092E86514CBDF4340BEBC00FBE81E464092E86514CBDF4340B9C2BB5CC4214640A7936C7539E34340B9C2BB5CC4214640A7936C7539E34340BEBC00FBE81E464092E86514CBDF4340BEBC00FBE81E4640
23784	50827	39.784559999999999	39.794288999999999	44.413507000000003	44.404877999999997	Полевая	0103000020E61000000100000005000000F8DF4A766CE44340586FD40AD3334640F8DF4A766CE4434063D520CCED34464049490F43ABE5434063D520CCED34464049490F43ABE54340586FD40AD3334640F8DF4A766CE44340586FD40AD3334640
20741	12074	39.510682000000003	39.552418000000003	44.466236000000002	44.384737999999999	Промысловая	0103000020E61000000100000005000000F4531C075EC14340A4C343183F314640F4531C075EC14340E31B0A9FAD3B464062DC0DA2B5C64340E31B0A9FAD3B464062DC0DA2B5C64340A4C343183F314640F4531C075EC14340A4C343183F314640
21552	12074	39.510682000000003	39.552418000000003	44.466236000000002	44.384737999999999	Первомайская	0103000020E61000000100000005000000F4531C075EC14340A4C343183F314640F4531C075EC14340E31B0A9FAD3B464062DC0DA2B5C64340E31B0A9FAD3B464062DC0DA2B5C64340A4C343183F314640F4531C075EC14340A4C343183F314640
20985	12074	39.510682000000003	39.552418000000003	44.466236000000002	44.384737999999999	Кирова	0103000020E61000000100000005000000F4531C075EC14340A4C343183F314640F4531C075EC14340E31B0A9FAD3B464062DC0DA2B5C64340E31B0A9FAD3B464062DC0DA2B5C64340A4C343183F314640F4531C075EC14340A4C343183F314640
20592	12074	39.510682000000003	39.552418000000003	44.466236000000002	44.384737999999999	Аэродромная	0103000020E61000000100000005000000F4531C075EC14340A4C343183F314640F4531C075EC14340E31B0A9FAD3B464062DC0DA2B5C64340E31B0A9FAD3B464062DC0DA2B5C64340A4C343183F314640F4531C075EC14340A4C343183F314640
21191	13244	39.682071999999998	39.692841999999999	44.118566999999999	44.105842000000003	Клубная	0103000020E6100000010000000500000037C2A2224ED7434089450C3B8C0D464037C2A2224ED7434042B115342D0F4640CAA5F10BAFD8434042B115342D0F4640CAA5F10BAFD8434089450C3B8C0D464037C2A2224ED7434089450C3B8C0D4640
24013	50897	39.525432000000002	39.553145000000001	44.376767999999998	44.360833	Чкалова	0103000020E61000000100000005000000CD22145B41C34340A62897C62F2E4640CD22145B41C34340F4160FEF3930464014799274CDC64340F4160FEF3930464014799274CDC64340A62897C62F2E4640CD22145B41C34340A62897C62F2E4640
21541	13794	39.597396000000003	39.628568000000001	44.621262000000002	44.585714000000003	Советская	0103000020E610000001000000050000007061DD7877CC4340996725ADF84A46407061DD7877CC4340B01F6283854F4640F4A78DEA74D04340B01F6283854F4640F4A78DEA74D04340996725ADF84A46407061DD7877CC4340996725ADF84A4640
21558	45837	39.462622000000003	39.490461000000003	44.442917999999999	44.430329	Привокзальная	0103000020E610000001000000050000007F349C3237BB43409CC24A05153746407F349C3237BB4340A5677A89B1384640537B116DC7BE4340A5677A89B1384640537B116DC7BE43409CC24A05153746407F349C3237BB43409CC24A0515374640
20966	50305	39.652794999999998	39.671973999999999	44.445594999999997	44.435600999999998	Хадыженское шоссе	0103000020E6100000010000000500000004FF5BC98ED343406D8D08C6C137464004FF5BC98ED343406C21C8410939464093E1783E03D643406C21C8410939464093E1783E03D643406D8D08C6C137464004FF5BC98ED343406D8D08C6C1374640
22490	50513	39.816234999999999	39.840902999999997	44.286878999999999	44.265368000000002	Ленина	0103000020E61000000100000005000000DF6C73637AE84340D5B32094F7214640DF6C73637AE8434060747973B8244640DC0DA2B5A2EB434060747973B8244640DC0DA2B5A2EB4340D5B32094F7214640DF6C73637AE84340D5B32094F7214640
20707	13271	39.677005000000001	39.689473999999997	44.192281000000001	44.181105000000002	Железнодорожная	0103000020E610000001000000050000003F1D8F19A8D643403012DA722E1746403F1D8F19A8D643403352EFA99C1846409DB81CAF40D843403352EFA99C1846409DB81CAF40D843403012DA722E1746403F1D8F19A8D643403012DA722E174640
20704	45713	39.697792	39.711024000000002	44.073664000000001	44.060637999999997	Клубная	0103000020E6100000010000000500000089B48D3F51D943408A7269FCC207464089B48D3F51D943403F726BD26D094640E7559DD502DB43403F726BD26D094640E7559DD502DB43408A7269FCC207464089B48D3F51D943408A7269FCC2074640
21638	12821	39.814160000000001	39.838476999999997	44.312064999999997	44.289833999999999	Советская	0103000020E610000001000000050000000EDB166536E843406AA2CF47192546400EDB166536E84340F59CF4BEF12746405EB9DE3653EB4340F59CF4BEF12746405EB9DE3653EB43406AA2CF47192546400EDB166536E843406AA2CF4719254640
23946	50871	39.670205000000003	39.679574000000002	44.414717000000003	44.400286000000001	 Дружбы	0103000020E61000000100000005000000CF4E0647C9D54340F98557923C334640CF4E0647C9D54340310C587215354640209BE447FCD64340310C587215354640209BE447FCD64340F98557923C334640CF4E0647C9D54340F98557923C334640
21640	45619	39.913127000000003	39.928398999999999	44.291538000000003	44.254935000000003	Центральная	0103000020E610000001000000050000001C0C7558E1F443408ACDC7B5A12046401C0C7558E1F4434048C5FF1D51254640CE5147C7D5F6434048C5FF1D51254640CE5147C7D5F643408ACDC7B5A12046401C0C7558E1F443408ACDC7B5A1204640
23525	50747	39.624274	39.666423000000002	44.389118000000003	44.361167999999999	Красная	0103000020E610000001000000050000001EDFDE35E8CF43404D2EC6C03A2E46401EDFDE35E8CF434079245E9ECE314640AF264F594DD5434079245E9ECE314640AF264F594DD543404D2EC6C03A2E46401EDFDE35E8CF43404D2EC6C03A2E4640
20760	9757	39.681424999999997	39.750236000000001	44.406623000000003	44.343693999999999	Школьная	0103000020E61000000100000005000000A1D634EF38D743406CEA3C2AFE2B4640A1D634EF38D743409566F3380C3446401424B6BB07E043409566F3380C3446401424B6BB07E043406CEA3C2AFE2B4640A1D634EF38D743406CEA3C2AFE2B4640
20451	9757	39.681424999999997	39.750236000000001	44.406623000000003	44.343693999999999	Советская	0103000020E61000000100000005000000A1D634EF38D743406CEA3C2AFE2B4640A1D634EF38D743409566F3380C3446401424B6BB07E043409566F3380C3446401424B6BB07E043406CEA3C2AFE2B4640A1D634EF38D743406CEA3C2AFE2B4640
21406	13125	39.945089000000003	39.968885999999998	44.208508000000002	44.191640999999997	Железнодорожная	0103000020E61000000100000005000000996725ADF8F843404FC939B187184640996725ADF8F84340297AE063B01A4640B0C6D97404FC4340297AE063B01A4640B0C6D97404FC43404FC939B187184640996725ADF8F843404FC939B187184640
23847	50844	39.678325999999998	39.692338999999997	44.469073000000002	44.461019	Ленина	0103000020E610000001000000050000006403E962D3D64340D5EAABAB023B46406403E962D3D64340E33785950A3C4640675F79909ED84340E33785950A3C4640675F79909ED84340D5EAABAB023B46406403E962D3D64340D5EAABAB023B4640
23974	50884	39.479897000000001	39.498707000000003	44.598481	44.586536000000002	Школьная	0103000020E610000001000000050000006939D0436DBD43409DF6949C134B46406939D0436DBD4340812381069B4C4640A5A487A1D5BF4340812381069B4C4640A5A487A1D5BF43409DF6949C134B46406939D0436DBD43409DF6949C134B4640
24012	50896	39.526069999999997	39.550361000000002	44.551782000000003	44.539563999999999	Центральная	0103000020E610000001000000050000000FB4024356C34340AA0CE36E104546400FB4024356C34340C042E6CAA046464037FFAF3A72C64340C042E6CAA046464037FFAF3A72C64340AA0CE36E104546400FB4024356C34340AA0CE36E10454640
23736	50651	39.401212999999998	39.442194000000001	44.424670999999996	44.395893999999998	Новицкого	0103000020E6100000010000000500000072DD94F25AB34340605793A7AC32464072DD94F25AB34340A1478C9E5B364640643E20D099B84340A1478C9E5B364640643E20D099B84340605793A7AC32464072DD94F25AB34340605793A7AC324640
23251	50653	39.401212999999998	39.442194000000001	44.424670999999996	44.395893999999998	Железнодорожная	0103000020E6100000010000000500000072DD94F25AB34340605793A7AC32464072DD94F25AB34340A1478C9E5B364640643E20D099B84340A1478C9E5B364640643E20D099B84340605793A7AC32464072DD94F25AB34340605793A7AC324640
23845	13329	39.477767999999998	39.509405999999998	44.521211999999998	44.478456999999999	Ленина	0103000020E61000000100000005000000A489778027BD434069C537143E3D4640A489778027BD434031242713B74246406E313F3734C1434031242713B74246406E313F3734C1434069C537143E3D4640A489778027BD434069C537143E3D4640
21540	13329	39.477767999999998	39.509405999999998	44.521211999999998	44.478456999999999	Клубная	0103000020E61000000100000005000000A489778027BD434069C537143E3D4640A489778027BD434031242713B74246406E313F3734C1434031242713B74246406E313F3734C1434069C537143E3D4640A489778027BD434069C537143E3D4640
23942	50868	39.727966000000002	39.737622999999999	44.602249	44.594534000000003	Советская	0103000020E61000000100000005000000CB4C69FD2DDD4340172EABB0194C4640CB4C69FD2DDD43403C86C77E164D464082E3326E6ADE43403C86C77E164D464082E3326E6ADE4340172EABB0194C4640CB4C69FD2DDD4340172EABB0194C4640
20551	50258	39.814402000000001	39.845070999999997	44.449714	44.430231999999997	Угольная	0103000020E6100000010000000500000004E621533EE84340A9D898D71137464004E621533EE84340D446753A9039464025E659492BEC4340D446753A9039464025E659492BEC4340A9D898D71137464004E621533EE84340A9D898D711374640
21224	13606	39.686149999999998	39.712353999999998	44.595368000000001	44.572405000000003	Школьная	0103000020E61000000100000005000000401361C3D3D743409088299144494640401361C3D3D74340DF8AC404354C46405F96766A2EDB4340DF8AC404354C46405F96766A2EDB43409088299144494640401361C3D3D743409088299144494640
20520	12989	39.897424999999998	39.906336000000003	44.239547999999999	44.224783000000002	Клубная	0103000020E6100000010000000500000070CE88D2DEF2434030D978B0C51C464070CE88D2DEF243403EE94482A91E4640FF976BD102F443403EE94482A91E4640FF976BD102F4434030D978B0C51C464070CE88D2DEF2434030D978B0C51C4640
21381	32682	39.697127000000002	39.713683000000003	44.569592	44.527065999999998	Кимовская	0103000020E610000001000000050000004D1421753BD94340B16A10E6764346404D1421753BD9434018080264E8484640085BECF659DB434018080264E8484640085BECF659DB4340B16A10E6764346404D1421753BD94340B16A10E676434640
20971	10038	39.673026	39.795762000000003	44.487043	44.420718000000001	Пролетарская	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21169	10038	39.673026	39.795762000000003	44.487043	44.420718000000001	Ленина	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
20731	10038	39.673026	39.795762000000003	44.487043	44.420718000000001	Краснознаменная	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
20492	10038	39.673026	39.795762000000003	44.487043	44.420718000000001	Красноармейская	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21573	10038	39.673026	39.795762000000003	44.487043	44.420718000000001	Коммунистическая	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21566	10038	39.673026	39.795762000000003	44.487043	44.420718000000001	Исполкомовская	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21097	50326	39.673026	39.795762000000003	44.487043	44.420718000000001	Пролетарская	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21178	50326	39.673026	39.795762000000003	44.487043	44.420718000000001	Ленина	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21180	50326	39.673026	39.795762000000003	44.487043	44.420718000000001	Королева	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
21165	50326	39.673026	39.795762000000003	44.487043	44.420718000000001	Комарова	0103000020E61000000100000005000000C9AD49B725D64340556B6116DA354640C9AD49B725D64340745FCE6C573E464025B37A87DBE54340745FCE6C573E464025B37A87DBE54340556B6116DA354640C9AD49B725D64340556B6116DA354640
20685	50276	37.264471999999998	37.396272000000003	45.082304999999998	44.988852000000001	Советская	0103000020E61000000100000005000000965AEF37DAA14240C74ACCB3927E4640965AEF37DAA142400DA661F8888A46400729780AB9B242400DA661F8888A46400729780AB9B24240C74ACCB3927E4640965AEF37DAA14240C74ACCB3927E4640
20665	32915	37.392077	37.439275000000002	45.119422	45.108144000000003	Садовая	0103000020E61000000100000005000000C44142942FB242401BA19FA9D78D4640C44142942FB2424022365838498F4640A779C7293AB8424022365838498F4640A779C7293AB842401BA19FA9D78D4640C44142942FB242401BA19FA9D78D4640
23478	50732	37.370238999999998	37.388160999999997	45.088554000000002	45.083112999999997	Свободы	0103000020E61000000100000005000000145AD6FD63AF4240AC6F6072A38A4640145AD6FD63AF42400AF7CABC558B4640944A7842AFB142400AF7CABC558B4640944A7842AFB14240AC6F6072A38A4640145AD6FD63AF4240AC6F6072A38A4640
20720	10545	37.321038000000001	37.369017999999997	44.986308999999999	44.974437000000002	Совхозная	0103000020E61000000100000005000000FA62EFC517A942409581035ABA7C4640FA62EFC517A942400F60915F3F7E464052D158FB3BAF42400F60915F3F7E464052D158FB3BAF42409581035ABA7C4640FA62EFC517A942409581035ABA7C4640
20921	10545	37.321038000000001	37.369017999999997	44.986308999999999	44.974437000000002	Садовая	0103000020E61000000100000005000000FA62EFC517A942409581035ABA7C4640FA62EFC517A942400F60915F3F7E464052D158FB3BAF42400F60915F3F7E464052D158FB3BAF42409581035ABA7C4640FA62EFC517A942409581035ABA7C4640
21299	32786	37.417230000000004	37.437218000000001	44.898871999999997	44.889467000000003	Чехова	0103000020E610000001000000050000007E74EACA67B5424085EFFD0DDA7146407E74EACA67B5424022A5D93C0E7346407C9C69C2F6B7424022A5D93C0E7346407C9C69C2F6B7424085EFFD0DDA7146407E74EACA67B5424085EFFD0DDA714640
21061	10845	37.349479000000002	37.382708000000001	44.871699	44.855854999999998	Фрунзе	0103000020E61000000100000005000000C4D155BABBAC42401D8F19A88C6D4640C4D155BABBAC42405B7A34D5936F464073F56393FCB042405B7A34D5936F464073F56393FCB042401D8F19A88C6D4640C4D155BABBAC42401D8F19A88C6D4640
21373	10845	37.349479000000002	37.382708000000001	44.871699	44.855854999999998	Советская	0103000020E61000000100000005000000C4D155BABBAC42401D8F19A88C6D4640C4D155BABBAC42405B7A34D5936F464073F56393FCB042405B7A34D5936F464073F56393FCB042401D8F19A88C6D4640C4D155BABBAC42401D8F19A88C6D4640
23422	10845	37.349479000000002	37.382708000000001	44.871699	44.855854999999998	Парковый проезд	0103000020E61000000100000005000000C4D155BABBAC42401D8F19A88C6D4640C4D155BABBAC42405B7A34D5936F464073F56393FCB042405B7A34D5936F464073F56393FCB042401D8F19A88C6D4640C4D155BABBAC42401D8F19A88C6D4640
21341	10940	37.404842000000002	37.442886000000001	44.803244999999997	44.791936	Советская	0103000020E610000001000000050000000C06D7DCD1B342403543AA285E6546400C06D7DCD1B3424077D66EBBD06646409AED0A7DB0B8424077D66EBBD06646409AED0A7DB0B842403543AA285E6546400C06D7DCD1B342403543AA285E654640
21896	32832	37.261256000000003	37.286552	45.077677999999999	45.058905000000003	Пушкина	0103000020E6100000010000000500000020F12BD670A142401349F4328A87464020F12BD670A1424031CF4A5AF18946403C4D66BCADA4424031CF4A5AF18946403C4D66BCADA442401349F4328A87464020F12BD670A142401349F4328A874640
23837	10699	37.295383000000001	37.319313999999999	44.982503000000001	44.966338999999998	Солнечная	0103000020E61000000100000005000000AE65321CCFA54240B7EC10FFB07B4640AE65321CCFA54240679C86A8C27D4640D593F947DFA84240679C86A8C27D4640D593F947DFA84240B7EC10FFB07B4640AE65321CCFA54240B7EC10FFB07B4640
21149	10985	37.372816999999998	37.386032	44.962493000000002	44.927481999999998	Школьная	0103000020E610000001000000050000004832AB77B8AF424078D0ECBAB77646404832AB77B8AF424081D07AF8327B4640D09A1F7F69B1424081D07AF8327B4640D09A1F7F69B1424078D0ECBAB77646404832AB77B8AF424078D0ECBAB7764640
21366	32978	37.335276999999998	37.369636999999997	45.043508000000003	45.033617	Гремахова	0103000020E61000000100000005000000ED0C535BEAAA424079CBD58F4D844640ED0C535BEAAA4240A48E8EAB918546401E32E54350AF4240A48E8EAB918546401E32E54350AF424079CBD58F4D844640ED0C535BEAAA424079CBD58F4D844640
21335	50355	37.326329999999999	37.358300999999997	45.018709999999999	45.010592000000003	Свободы	0103000020E6100000010000000500000012DA722EC5A94240B4CC22145B81464012DA722EC5A94240D80DDB1665824640E28FA2CEDCAD4240D80DDB1665824640E28FA2CEDCAD4240B4CC22145B81464012DA722EC5A94240B4CC22145B814640
22372	50498	37.451025000000001	37.461984000000001	45.134315000000001	45.128847	Красногорская	0103000020E61000000100000005000000D656EC2FBBB942400798F90E7E904640D656EC2FBBB942405E2EE23B319146403CA3AD4A22BB42405E2EE23B319146403CA3AD4A22BB42400798F90E7E904640D656EC2FBBB942400798F90E7E904640
23835	50839	37.437809999999999	37.467436999999997	45.119745999999999	45.104722000000002	Солнечная	0103000020E610000001000000050000004EEE77280AB84240FB95CE87678D46404EEE77280AB84240D5E940D6538F46405DF8C1F9D4BB4240D5E940D6538F46405DF8C1F9D4BB4240FB95CE87678D46404EEE77280AB84240FB95CE87678D4640
20855	9950	37.324533000000002	37.360509999999998	45.142243999999998	45.125304999999997	Центральная	0103000020E6100000010000000500000084BC1E4C8AA942403C8386FE0990464084BC1E4C8AA94240AF06280D35924640C3F0113125AE4240AF06280D35924640C3F0113125AE42403C8386FE0990464084BC1E4C8AA942403C8386FE09904640
21092	9950	37.324533000000002	37.360509999999998	45.142243999999998	45.125304999999997	Октябрьская	0103000020E6100000010000000500000084BC1E4C8AA942403C8386FE0990464084BC1E4C8AA94240AF06280D35924640C3F0113125AE4240AF06280D35924640C3F0113125AE42403C8386FE0990464084BC1E4C8AA942403C8386FE09904640
20664	50272	37.464570999999999	37.546883999999999	45.037305000000003	45.001899999999999	Новороссийская	0103000020E61000000100000005000000C3D5011077BB424063EE5A423E804640C3D5011077BB4240187D0569C6844640535A7F4B00C64240187D0569C6844640535A7F4B00C6424063EE5A423E804640C3D5011077BB424063EE5A423E804640
20784	50272	37.464570999999999	37.546883999999999	45.037305000000003	45.001899999999999	Мира	0103000020E61000000100000005000000C3D5011077BB424063EE5A423E804640C3D5011077BB4240187D0569C6844640535A7F4B00C64240187D0569C6844640535A7F4B00C6424063EE5A423E804640C3D5011077BB424063EE5A423E804640
23480	50734	37.315289	37.341799000000002	44.971944000000001	44.960158999999997	улица Мира	0103000020E61000000100000005000000EFE4D3635BA84240E3FA777DE67A4640EFE4D3635BA842408FC536A9687C46401B67D311C0AB42408FC536A9687C46401B67D311C0AB4240E3FA777DE67A4640EFE4D3635BA84240E3FA777DE67A4640
23281	50657	37.444476000000002	37.465119000000001	45.105122999999999	45.094459000000001	Центральная	0103000020E61000000100000005000000AFEDED96E4B842400CE8853B178C4640AFEDED96E4B842405987A3AB748D4640C6DFF60489BB42405987A3AB748D4640C6DFF60489BB42400CE8853B178C4640AFEDED96E4B842400CE8853B178C4640
22240	32919	37.451096999999997	37.479788999999997	45.151314999999997	45.137264999999999	Южная	0103000020E610000001000000050000006F29E78BBDB9424056F146E6919146406F29E78BBDB942407632384A5E93464082FDD7B969BD42407632384A5E93464082FDD7B969BD424056F146E6919146406F29E78BBDB9424056F146E691914640
23505	50740	37.113878	37.144627	45.060281000000003	45.050066999999999	Лобача	0103000020E61000000100000005000000F0DDE68D938E4240EECD6F9868864640F0DDE68D938E4240FCC8AD49B78746402E8F352383924240FCC8AD49B78746402E8F352383924240EECD6F9868864640F0DDE68D938E4240EECD6F9868864640
21641	40434	38.167907	38.199356999999999	44.732959999999999	44.717616	Ленина	0103000020E610000001000000050000007EE200FA7D1543400D8B51D7DA5B46407EE200FA7D15434059A31EA2D15D4640459DB9878419434059A31EA2D15D4640459DB987841943400D8B51D7DA5B46407EE200FA7D1543400D8B51D7DA5B4640
24007	50894	38.066999000000003	38.084786000000001	44.765281000000002	44.738179000000002	Красная	0103000020E61000000100000005000000AFEE586C9308434008CC43A67C5E4640AFEE586C9308434006A051BAF46146404F948444DA0A434006A051BAF46146404F948444DA0A434008CC43A67C5E4640AFEE586C9308434008CC43A67C5E4640
23514	50743	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	Каменеческая	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
23971	50559	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	Холмская	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
22773	50559	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	Толстого	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
23343	50559	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	Рудничная	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
22950	50559	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	Мира	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
22990	50559	38.365276000000001	38.417153999999996	44.872357000000001	44.813200999999999	Ленина	0103000020E61000000100000005000000C1012D5DC12E434089096AF816684640C1012D5DC12E4340E5B7E864A96F4640A2B2614D65354340E5B7E864A96F4640A2B2614D6535434089096AF816684640C1012D5DC12E434089096AF816684640
22976	48041	38.435830000000003	38.490366999999999	45.091405000000002	45.065660000000001	Первомайская	0103000020E61000000100000005000000CF4E0647C9374340E353008C67884640CF4E0647C93743406FD8B628B38B4640D1048A58C43E43406FD8B628B38B4640D1048A58C43E4340E353008C67884640CF4E0647C9374340E353008C67884640
22549	48041	38.435830000000003	38.490366999999999	45.091405000000002	45.065660000000001	Красная	0103000020E61000000100000005000000CF4E0647C9374340E353008C67884640CF4E0647C93743406FD8B628B38B4640D1048A58C43E43406FD8B628B38B4640D1048A58C43E4340E353008C67884640CF4E0647C9374340E353008C67884640
20586	7464	38.327348999999998	38.354604000000002	44.787849000000001	44.759784000000003	Лесная	0103000020E610000001000000050000006CB07092E62943401503249A406146406CB07092E6294340D9976C3CD8644640F183F3A9632D4340D9976C3CD8644640F183F3A9632D43401503249A406146406CB07092E62943401503249A40614640
20820	6909	38.211547000000003	38.221024999999997	44.839502000000003	44.831581999999997	Центральная	0103000020E610000001000000050000009148DBF8131B43409CF86A47716A46409148DBF8131B43409B7631CD746B4640984C158C4A1C43409B7631CD746B4640984C158C4A1C43409CF86A47716A46409148DBF8131B43409CF86A47716A4640
21019	45897	38.436709999999998	38.457667999999998	44.937773999999997	44.926627000000003	Мира	0103000020E6100000010000000500000007EBFF1CE6374340994BAAB69B76464007EBFF1CE637434001857AFA087846407E3672DD943A434001857AFA087846407E3672DD943A4340994BAAB69B76464007EBFF1CE6374340994BAAB69B764640
23804	50831	38.339342000000002	38.384168000000003	45.136946999999999	45.111356999999998	Первомайская	0103000020E610000001000000050000006214048F6F2B4340209738F2408E46406214048F6F2B43408524B37A87914640BA15C26A2C3143408524B37A87914640BA15C26A2C314340209738F2408E46406214048F6F2B4340209738F2408E4640
20700	48164	\N	\N	\N	\N	Есенина	\N
24038	48164	\N	\N	\N	\N	 Офицерская	\N
22176	50472	38.307254	38.362769999999998	45.037329999999997	44.987034999999999	Советская	0103000020E6100000010000000500000058C85C1954274340F180B229577E464058C85C19542743407094BC3AC784464026FC523F6F2E43407094BC3AC784464026FC523F6F2E4340F180B229577E464058C85C1954274340F180B229577E4640
20559	7675	38.307254	38.362769999999998	45.037329999999997	44.987034999999999	Мельничная	0103000020E6100000010000000500000058C85C1954274340F180B229577E464058C85C19542743407094BC3AC784464026FC523F6F2E43407094BC3AC784464026FC523F6F2E4340F180B229577E464058C85C1954274340F180B229577E4640
23860	50544	38.222434999999997	38.254154999999997	45.180470999999997	45.161369999999998	 Красная	0103000020E610000001000000050000002D3E05C0781C43401B47ACC5A79446402D3E05C0781C43402E7079AC19974640B48EAA26882043402E7079AC19974640B48EAA26882043401B47ACC5A79446402D3E05C0781C43401B47ACC5A7944640
23287	50662	38.362293999999999	38.381220999999996	44.939025000000001	44.921042	Пионерская	0103000020E61000000100000005000000BDC458A65F2E4340081F4AB4E4754640BDC458A65F2E43402E90A0F83178464032C687D9CB3043402E90A0F83178464032C687D9CB304340081F4AB4E4754640BDC458A65F2E4340081F4AB4E4754640
23436	50707	38.481679999999997	38.500732999999997	45.099384000000001	45.078315000000003	Суворова	0103000020E610000001000000050000009291B3B0A73D4340A4E4D539068A46409291B3B0A73D434072DF6A9DB88C46409483D9041840434072DF6A9DB88C46409483D90418404340A4E4D539068A46409291B3B0A73D4340A4E4D539068A4640
21466	5327	38.178686999999996	38.210326000000002	44.996685999999997	44.989235000000001	Красная	0103000020E61000000100000005000000349C3237DF1643407F87A2409F7E4640349C3237DF164340C6302768937F4640CFBF5DF6EB1A4340C6302768937F4640CFBF5DF6EB1A43407F87A2409F7E4640349C3237DF1643407F87A2409F7E4640
22146	6623	38.271239999999999	38.346456000000003	44.873998	44.818393	Школьная	0103000020E61000000100000005000000FBAE08FEB72243403E23111AC1684640FBAE08FEB72243407C629D2ADF6F464062C092AB582C43407C629D2ADF6F464062C092AB582C43403E23111AC1684640FBAE08FEB72243403E23111AC1684640
21336	6623	38.271239999999999	38.346456000000003	44.873998	44.818393	Свободы	0103000020E61000000100000005000000FBAE08FEB72243403E23111AC1684640FBAE08FEB72243407C629D2ADF6F464062C092AB582C43407C629D2ADF6F464062C092AB582C43403E23111AC1684640FBAE08FEB72243403E23111AC1684640
21486	6623	38.271239999999999	38.346456000000003	44.873998	44.818393	Мира	0103000020E61000000100000005000000FBAE08FEB72243403E23111AC1684640FBAE08FEB72243407C629D2ADF6F464062C092AB582C43407C629D2ADF6F464062C092AB582C43403E23111AC1684640FBAE08FEB72243403E23111AC1684640
20521	6623	38.271239999999999	38.346456000000003	44.873998	44.818393	Красная	0103000020E61000000100000005000000FBAE08FEB72243403E23111AC1684640FBAE08FEB72243407C629D2ADF6F464062C092AB582C43407C629D2ADF6F464062C092AB582C43403E23111AC1684640FBAE08FEB72243403E23111AC1684640
21491	6623	38.271239999999999	38.346456000000003	44.873998	44.818393	Колхозная	0103000020E61000000100000005000000FBAE08FEB72243403E23111AC1684640FBAE08FEB72243407C629D2ADF6F464062C092AB582C43407C629D2ADF6F464062C092AB582C43403E23111AC1684640FBAE08FEB72243403E23111AC1684640
20651	6114	38.132280000000002	38.186987000000002	44.893037	44.842371	Советов	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21303	6114	38.132280000000002	38.186987000000002	44.893037	44.842371	Набережная	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21295	6114	38.132280000000002	38.186987000000002	44.893037	44.842371	Мира	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21074	6114	38.132280000000002	38.186987000000002	44.893037	44.842371	Интернациональная	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21076	6114	38.132280000000002	38.186987000000002	44.893037	44.842371	Володарского	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
20465	6114	38.132280000000002	38.186987000000002	44.893037	44.842371	Вокзальная	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21622	50350	38.132280000000002	38.186987000000002	44.893037	44.842371	Тищенко	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21503	50350	38.132280000000002	38.186987000000002	44.893037	44.842371	Советов	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21497	50350	38.132280000000002	38.186987000000002	44.893037	44.842371	Пролетарская	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
21318	50350	38.132280000000002	38.186987000000002	44.893037	44.842371	Набережная	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
22369	50350	38.132280000000002	38.186987000000002	44.893037	44.842371	Володарского	0103000020E610000001000000050000001BF5108DEE104340A60C1CD0D26B46401BF5108DEE104340198F52094F7246407AE3A430EF174340198F52094F7246407AE3A430EF174340A60C1CD0D26B46401BF5108DEE104340A60C1CD0D26B4640
27822	51748	44.771242999999998	44.779418	48.771160000000002	48.761978999999997	Первомайская	0103000020E610000001000000050000006C223317B8624640909E2287886148406C223317B8624640DFFDF15EB5624840F5F411F8C3634640DFFDF15EB5624840F5F411F8C3634640909E2287886148406C223317B8624640909E228788614840
27041	51447	43.003709000000001	43.022995999999999	49.965091000000001	49.948238000000003	Левинская	0103000020E61000000100000005000000B6D95889798045408869DFDC5FF94840B6D9588979804540FC54151A88FB48402BF86D88F1824540FC54151A88FB48402BF86D88F18245408869DFDC5FF94840B6D95889798045408869DFDC5FF94840
26809	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Чапаева	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27047	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Фроловская	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
26459	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Строителей	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27224	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Свердлова	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
26661	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Революционная	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27157	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Рабочая	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27251	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Пролетарская	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
26888	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Орджоникидзе	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
26784	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Народная	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
26969	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Московская	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27165	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Красноармейская	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27100	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Зеленая	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
26414	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Заречный квартал	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
26522	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Донская	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27070	16895	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	Гагарина	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27208	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	пр. Ленина	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26773	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Чапаева	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
27260	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Советская	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26478	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Разливаева	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
27261	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Пушкина	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26906	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Островского	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26897	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Октябрьская	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26943	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Московская	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26477	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Мичурина	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
27093	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	М. Горького	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26968	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Льва Толстого	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26560	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Красноармейская	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26675	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Гагарина	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26823	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Волгоградская	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
27117	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Весенняя	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
27094	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	Большая Мушкетовская	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
26783	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	50-лет Победы	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
27180	7479	41.979612000000003	42.062337999999997	50.814843000000003	50.758147999999998	 Гастелло	0103000020E6100000010000000500000074620FED63FD44408FC360FE0A61494074620FED63FD4440F12F82C64C68494026A60BB1FA074540F12F82C64C68494026A60BB1FA0745408FC360FE0A61494074620FED63FD44408FC360FE0A614940
27311	51603	44.705460000000002	44.720559999999999	48.756864999999998	48.745055999999998	Тракторная	0103000020E610000001000000050000006E5166834C5A464023D8B8FE5D5F48406E5166834C5A4640573ECBF3E06048402367614F3B5C4640573ECBF3E06048402367614F3B5C464023D8B8FE5D5F48406E5166834C5A464023D8B8FE5D5F4840
27217	51547	44.706439000000003	44.729714000000001	48.700460999999997	48.690685000000002	Центральная	0103000020E610000001000000050000003ACFD8976C5A46403C6BB75D685848403ACFD8976C5A4640CD8FBFB4A859484078B7B244675D4640CD8FBFB4A859484078B7B244675D46403C6BB75D685848403ACFD8976C5A46403C6BB75D68584840
27059	51456	42.802270999999998	42.920292000000003	48.627524999999999	48.584100999999997	Орджоникидзе	0103000020E61000000100000005000000BDC3EDD0B0664540CB4752D2C34A4840BDC3EDD0B066454011363CBD525048409E62D520CC75454011363CBD525048409E62D520CC754540CB4752D2C34A4840BDC3EDD0B0664540CB4752D2C34A4840
27457	51659	44.646171000000002	44.665717999999998	48.753580999999997	48.742424	Центральная	0103000020E61000000100000005000000D34F38BBB5524640FCE1E7BF075F4840D34F38BBB552464088F19A5775604840E42D573F3655464088F19A5775604840E42D573F36554640FCE1E7BF075F4840D34F38BBB5524640FCE1E7BF075F4840
27296	51417	44.851624000000001	44.864874999999998	48.717542000000002	48.705925999999998	Октябрьская	0103000020E610000001000000050000008E3EE603026D4640B3B27DC85B5A48408E3EE603026D4640D3C08F6AD85B484062105839B46E4640D3C08F6AD85B484062105839B46E4640B3B27DC85B5A48408E3EE603026D4640B3B27DC85B5A4840
27115	51417	44.837476000000002	44.906582999999998	48.728746000000001	48.695667999999998	Ленина	0103000020E61000000100000005000000AB97DF69326B4640D66F26A60B594840AB97DF69326B4640A08B868C475D4840060E68E90A744640A08B868C475D4840060E68E90A744640D66F26A60B594840AB97DF69326B4640D66F26A60B594840
27006	51417	44.863095999999999	44.866616999999998	48.716828999999997	48.713524	Гагарина	0103000020E610000001000000050000007AA702EE796E46409F7422C1545B48407AA702EE796E464085E97B0DC15B48402D944C4EED6E464085E97B0DC15B48402D944C4EED6E46409F7422C1545B48407AA702EE796E46409F7422C1545B4840
27109	51490	42.708047000000001	42.758361000000001	49.591715000000001	49.559604	Пролетарская	0103000020E61000000100000005000000F583BA48A15A4540FB5A971AA1C74840F583BA48A15A4540BDC62E51BDCB4840EBC726F911614540BDC62E51BDCB4840EBC726F911614540FB5A971AA1C74840F583BA48A15A4540FB5A971AA1C74840
27220	51548	44.723739999999999	44.743315000000003	48.707025999999999	48.701447999999999	Центральная	0103000020E610000001000000050000004D672783A35C46401CEC4D0CC95948404D672783A35C4640FAB5F5D37F5A484029D027F2245F4640FAB5F5D37F5A484029D027F2245F46401CEC4D0CC95948404D672783A35C46401CEC4D0CC9594840
27071	51468	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	переулок Карла Маркса	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
27045	51449	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Пугачева	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
27333	51573	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Ленина	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27344	51612	44.743665	44.761612999999997	48.715069	48.703113000000002	 Центральная	0103000020E6100000010000000500000005172B6A305F46403C32569BFF59484005172B6A305F464014B18861875B4840AE9AE7887C61464014B18861875B4840AE9AE7887C6146403C32569BFF59484005172B6A305F46403C32569BFF594840
26745	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	площадь Конституции	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27140	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Ясный	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27201	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Южная	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26570	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Энгельса	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26590	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Стройная	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27298	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Смехова	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26832	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Свободы	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26609	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Республиканская	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26608	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Пирогова	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26844	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Новороссийская	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27197	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Мичурина	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27023	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Мира	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27019	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Магистральная	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26597	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Ленина	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26839	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Кубанский	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27129	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Крупской	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27210	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Карельская	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26837	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Гоголя	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26577	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Байкальская	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26630	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	Александра Невского	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
26864	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	2 Краснознаменская	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27133	14060	43.191384999999997	43.300530000000002	50.100290000000001	50.035564999999998	 2 Краснознаменская	0103000020E61000000100000005000000F4F8BD4D7F984540EDF0D7648D044940F4F8BD4D7F984540D40E7F4DD60C4940C3BB5CC477A64540D40E7F4DD60C4940C3BB5CC477A64540EDF0D7648D044940F4F8BD4D7F984540EDF0D7648D044940
27114	51379	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	Крупской	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
27480	51669	44.690618999999998	44.712699999999998	48.774116999999997	48.763582999999997	Павших Борцов	0103000020E61000000100000005000000847F1134665846400A647616BD614840847F11346658464089230F4416634840FAEDEBC0395B464089230F4416634840FAEDEBC0395B46400A647616BD614840847F1134665846400A647616BD614840
27121	51495	44.694464000000004	44.712412999999998	48.730231000000003	48.719230000000003	Шоссейная	0103000020E61000000100000005000000EB1F4432E4584640AB2688BA0F5C4840EB1F4432E458464040C39B35785D4840641F6459305B464040C39B35785D4840641F6459305B4640AB2688BA0F5C4840EB1F4432E4584640AB2688BA0F5C4840
27293	51593	44.571708999999998	44.576264000000002	48.707483000000003	48.706139999999998	улица Космонавтов	0103000020E6100000010000000500000018EAB0C22D494640DF32A7CB625A484018EAB0C22D494640EDBC8DCD8E5A48405BEECC04C3494640EDBC8DCD8E5A48405BEECC04C3494640DF32A7CB625A484018EAB0C22D494640DF32A7CB625A4840
27542	51593	44.550409999999999	44.565888000000001	48.681727000000002	48.680180999999997	улица Горького	0103000020E6100000010000000500000018B2BAD573464640272EC72B1057484018B2BAD5734646406DE690D44257484074999A046F4846406DE690D44257484074999A046F484640272EC72B1057484018B2BAD573464640272EC72B10574840
27292	51593	44.559303999999997	44.602387	48.708976	48.704065	Ленина	0103000020E61000000100000005000000D0420246974746400EA14ACD1E5A4840D0420246974746400FD3BEB9BF5A48408D4468041B4D46400FD3BEB9BF5A48408D4468041B4D46400EA14ACD1E5A4840D0420246974746400EA14ACD1E5A4840
27127	51496	44.732131000000003	44.823946999999997	48.809693000000003	48.738824000000001	Ленина	0103000020E61000000100000005000000A3B1F677B65D4640FDBFEAC8915E4840A3B1F677B65D46406B662D05A467484093516518776946406B662D05A46748409351651877694640FDBFEAC8915E4840A3B1F677B65D4640FDBFEAC8915E4840
26776	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Южный городок	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26868	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Феоктистова	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27566	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Титова	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26717	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Советская	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27391	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Серафимовича	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27496	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Республиканская 	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27497	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Пролетарская	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27319	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Набережная	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27703	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Мира	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
9783	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Ленина	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27392	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Кубанская	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27662	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Короленко	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27368	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Королева	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27330	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Казанская улица	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26496	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Давыдова	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27466	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Волгоградская	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27278	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Воинов интернационалистов	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27419	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Буденного	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26979	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	5 микрорайон	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26966	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	4 микрорайон	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26930	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	333 Стрелковой дивизии	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26988	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	3 микрорайон	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27517	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	 Металлургов	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27721	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	 Короленко	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27135	12417	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	 5 микрорайон	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
27152	51507	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	Ломоносова	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
27156	51453	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Северная	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
27051	51453	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Московская	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
27547	51701	44.613534999999999	44.646493999999997	48.711317999999999	48.693562999999997	переулок Школьный	0103000020E61000000100000005000000C6F99B50884E46409A5B21ACC6584840C6F99B50884E46402F87DD770C5B4840B587BD50C05246402F87DD770C5B4840B587BD50C05246409A5B21ACC6584840C6F99B50884E46409A5B21ACC6584840
27678	51723	44.309446000000001	44.326630999999999	48.691415999999997	48.688585000000003	 Валентины Терешковой	0103000020E6100000010000000500000063F030ED9B27464012C2A38D2358484063F030ED9B2746402FF7C951805848400D6E6B0BCF2946402FF7C951805848400D6E6B0BCF29464012C2A38D2358484063F030ED9B27464012C2A38D23584840
27312	51270	44.754696000000003	44.809987999999997	48.799385999999998	48.751817000000003	улица имени генерала Карбышева	0103000020E610000001000000050000000536E7E099604640D6C9198A3B6048400536E7E099604640AC70CB47526648408313D1AFAD674640AC70CB47526648408313D1AFAD674640D6C9198A3B6048400536E7E099604640D6C9198A3B604840
27320	51270	44.744419999999998	44.842758000000003	48.803570000000001	48.750902000000004	улица Пушкина	0103000020E61000000100000005000000813E9127495F46402140868E1D604840813E9127495F4640FB05BB61DB664840A038807EDF6B4640FB05BB61DB664840A038807EDF6B46402140868E1D604840813E9127495F46402140868E1D604840
27339	51270	44.784627999999998	44.826993000000002	48.781686000000001	48.750872000000001	улица Мира	0103000020E6100000010000000500000050C3B7B06E644640B6BDDD921C60484050C3B7B06E644640DBDE6E490E644840AE8218E8DA694640DBDE6E490E644840AE8218E8DA694640B6BDDD921C60484050C3B7B06E644640B6BDDD921C604840
27306	51270	44.779040999999999	44.812530000000002	48.779198999999998	48.753599000000001	улица Дружбы	0103000020E610000001000000050000001F9F909DB76346402FA699EE756048401F9F909DB7634640B709F7CABC6348406B82A8FB00684640B709F7CABC6348406B82A8FB006846402FA699EE756048401F9F909DB76346402FA699EE75604840
27272	51270	44.734501999999999	44.761065000000002	48.810726000000003	48.802567000000003	улица 19 Партсъезда	0103000020E610000001000000050000005D6C5A29045E4640A7ECF483BA6648405D6C5A29045E46402A029CDEC5674840AC90F2936A6146402A029CDEC5674840AC90F2936A614640A7ECF483BA6648405D6C5A29045E4640A7ECF483BA664840
27421	51270	44.754696000000003	44.809987999999997	48.799385999999998	48.751817000000003	имени генерала Карбышева	0103000020E610000001000000050000000536E7E099604640D6C9198A3B6048400536E7E099604640AC70CB47526648408313D1AFAD674640AC70CB47526648408313D1AFAD674640D6C9198A3B6048400536E7E099604640D6C9198A3B604840
27581	51270	44.742632	44.755972	48.796501999999997	48.793605999999997	имени Космонавтов	0103000020E61000000100000005000000467BBC900E5F464066F4A3E194654840467BBC900E5F46406B990CC7F36548408A58C4B0C36046406B990CC7F36548408A58C4B0C360464066F4A3E194654840467BBC900E5F464066F4A3E194654840
27443	51270	44.733989999999999	44.759870999999997	48.808703000000001	48.800828000000003	имени Карла Маркса	0103000020E61000000100000005000000A7CB6262F35D46404DDC2A8881664840A7CB6262F35D4640AB96749483674840E316F37343614640AB96749483674840E316F373436146404DDC2A8881664840A7CB6262F35D46404DDC2A8881664840
27334	51270	44.739092999999997	44.743000000000002	48.800151999999997	48.798271	имени Аркадия Гайдара	0103000020E61000000100000005000000ECD973999A5E4640302C7FBE2D664840ECD973999A5E46401CEA77616B664840C976BE9F1A5F46401CEA77616B664840C976BE9F1A5F4640302C7FBE2D664840ECD973999A5E4640302C7FBE2D664840
26733	51270	44.753394	44.767811999999999	48.873950999999998	48.868859999999998	Чапаева	0103000020E610000001000000050000005680EF366F604640BA66F2CD366F48405680EF366F6046403BA759A0DD6F4840F9BCE2A9476246403BA759A0DD6F4840F9BCE2A947624640BA66F2CD366F48405680EF366F604640BA66F2CD366F4840
26439	51270	44.780189999999997	44.782966000000002	48.791611000000003	48.782938999999999	Химиков 	0103000020E6100000010000000500000047551344DD634640A8E15B583764484047551344DD634640B2135E8253654840A2F0D93A38644640B2135E8253654840A2F0D93A38644640A8E15B583764484047551344DD634640A8E15B5837644840
27571	51270	44.753672000000002	44.758828999999999	48.793005999999998	48.779710000000001	Советская улица	0103000020E6100000010000000500000099F4F752786046409D2E8B89CD63484099F4F7527860464011C4793881654840D120054F2161464011C4793881654840D120054F216146409D2E8B89CD63484099F4F752786046409D2E8B89CD634840
27636	51270	44.753672000000002	44.758828999999999	48.793005999999998	48.779710000000001	Советская	0103000020E6100000010000000500000099F4F752786046409D2E8B89CD63484099F4F7527860464011C4793881654840D120054F2161464011C4793881654840D120054F216146409D2E8B89CD63484099F4F752786046409D2E8B89CD634840
27409	51270	44.744419999999998	44.842758000000003	48.803570000000001	48.750902000000004	Пушкина	0103000020E61000000100000005000000813E9127495F46402140868E1D604840813E9127495F4640FB05BB61DB664840A038807EDF6B4640FB05BB61DB664840A038807EDF6B46402140868E1D604840813E9127495F46402140868E1D604840
26870	51270	44.768908000000003	44.776175000000002	48.774383999999998	48.764080999999997	Прибрежная	0103000020E61000000100000005000000FFD0CC936B6246405B3FFD67CD614840FFD0CC936B624640D845D1031F634840857CD0B359634640D845D1031F634840857CD0B3596346405B3FFD67CD614840FFD0CC936B6246405B3FFD67CD614840
27426	51270	44.780388000000002	44.795552000000001	48.784928000000001	48.771213000000003	Пионерская	0103000020E610000001000000050000006E1805C1E363464002A08A1BB76248406E1805C1E36346407BDB4C85786448403A22DFA5D46546407BDB4C85786448403A22DFA5D465464002A08A1BB76248406E1805C1E363464002A08A1BB7624840
27435	51270	44.729084999999998	44.745497999999998	48.807521999999999	48.784655000000001	Набережная	0103000020E61000000100000005000000888043A8525D46404AD235936F644840888043A8525D4640776682E15C674840E09D7C7A6C5F4640776682E15C674840E09D7C7A6C5F46404AD235936F644840888043A8525D46404AD235936F644840
27380	51270	44.784627999999998	44.826993000000002	48.781686000000001	48.750872000000001	Мира	0103000020E6100000010000000500000050C3B7B06E644640B6BDDD921C60484050C3B7B06E644640DBDE6E490E644840AE8218E8DA694640DBDE6E490E644840AE8218E8DA694640B6BDDD921C60484050C3B7B06E644640B6BDDD921C604840
27052	51270	44.769105000000003	44.778860999999999	48.789878000000002	48.778723999999997	Машиностроителей	0103000020E6100000010000000500000055185B08726246401E4E603AAD63484055185B08726246403AEAE8B81A6548409F909DB7B16346403AEAE8B81A6548409F909DB7B16346401E4E603AAD63484055185B08726246401E4E603AAD634840
27494	51270	44.737251000000001	44.747895999999997	48.808743999999997	48.799670999999996	Комсомольская	0103000020E61000000100000005000000BEF8A23D5E5E4640A1478C9E5B664840BEF8A23D5E5E4640096B63EC8467484094675E0EBB5F4640096B63EC8467484094675E0EBB5F4640A1478C9E5B664840BEF8A23D5E5E4640A1478C9E5B664840
27388	51270	44.804929999999999	44.813167999999997	48.774110999999998	48.770572000000001	Клавы Нечаевой	0103000020E61000000100000005000000DEC83CF2076746404E9B711AA2624840DEC83CF207674640A73CBA1116634840AD1397E315684640A73CBA1116634840AD1397E3156846404E9B711AA2624840DEC83CF2076746404E9B711AA2624840
27712	51270	44.736856000000003	44.759484	48.814065999999997	48.807059000000002	Кирова	0103000020E6100000010000000500000042EE224C515E4640A37895B54D67484042EE224C515E46408C648F5033684840EAEA8EC5366146408C648F5033684840EAEA8EC536614640A37895B54D67484042EE224C515E4640A37895B54D674840
26875	51270	44.648721999999999	44.885382999999997	48.938906000000003	48.724156999999998	Зеленый Гидростроевская	0103000020E610000001000000050000000D198F5209534640B115342DB15C48400D198F5209534640540262122E78484099B7EA3A54714640540262122E78484099B7EA3A54714640B115342DB15C48400D198F5209534640B115342DB15C4840
27313	51270	44.779040999999999	44.812530000000002	48.779198999999998	48.753599000000001	Дружбы	0103000020E610000001000000050000001F9F909DB76346402FA699EE756048401F9F909DB7634640B709F7CABC6348406B82A8FB00684640B709F7CABC6348406B82A8FB006846402FA699EE756048401F9F909DB76346402FA699EE75604840
27448	51270	44.757660999999999	44.767318000000003	48.780296999999997	48.773296999999999	Академика Королева	0103000020E61000000100000005000000323A2009FB604640268C6665FB624840323A2009FB6046405D15A8C5E0634840EAD0E979376246405D15A8C5E0634840EAD0E97937624640268C6665FB624840323A2009FB604640268C6665FB624840
27271	51270	44.648721999999999	44.885382999999997	48.938906000000003	48.724156999999998	7 Автодорога	0103000020E610000001000000050000000D198F5209534640B115342DB15C48400D198F5209534640540262122E78484099B7EA3A54714640540262122E78484099B7EA3A54714640B115342DB15C48400D198F5209534640B115342DB15C4840
27294	51270	44.648721999999999	44.885382999999997	48.938906000000003	48.724156999999998	40 лет Победы	0103000020E610000001000000050000000D198F5209534640B115342DB15C48400D198F5209534640540262122E78484099B7EA3A54714640540262122E78484099B7EA3A54714640B115342DB15C48400D198F5209534640B115342DB15C4840
26436	51270	44.648721999999999	44.885382999999997	48.938906000000003	48.724156999999998	40 Лет Победы	0103000020E610000001000000050000000D198F5209534640B115342DB15C48400D198F5209534640540262122E78484099B7EA3A54714640540262122E78484099B7EA3A54714640B115342DB15C48400D198F5209534640B115342DB15C4840
27375	51270	44.744419999999998	44.842758000000003	48.803570000000001	48.750902000000004	 Пушкина	0103000020E61000000100000005000000813E9127495F46402140868E1D604840813E9127495F4640FB05BB61DB664840A038807EDF6B4640FB05BB61DB664840A038807EDF6B46402140868E1D604840813E9127495F46402140868E1D604840
27411	51270	44.730513999999999	44.741536000000004	48.848049000000003	48.846406999999999	 Плеханова	0103000020E6100000010000000500000094A2957B815D4640800D8810576C484094A2957B815D4640E833A0DE8C6C48404167D2A6EA5E4640E833A0DE8C6C48404167D2A6EA5E4640800D8810576C484094A2957B815D4640800D8810576C4840
27273	51270	44.793342000000003	44.803133000000003	48.784405	48.774562000000003	 Наримана Нариманова	0103000020E6100000010000000500000089450C3B8C654640B85CFDD82463484089450C3B8C654640D1E80E626764484050ABE80FCD664640D1E80E626764484050ABE80FCD664640B85CFDD82463484089450C3B8C654640B85CFDD824634840
27440	51270	44.804929999999999	44.813167999999997	48.774110999999998	48.770572000000001	 Клавы Нечаевой	0103000020E61000000100000005000000DEC83CF2076746404E9B711AA2624840DEC83CF207674640A73CBA1116634840AD1397E315684640A73CBA1116634840AD1397E3156846404E9B711AA2624840DEC83CF2076746404E9B711AA2624840
26444	51270	44.648721999999999	44.885382999999997	48.938906000000003	48.724156999999998	 40 Лет Победы	0103000020E610000001000000050000000D198F5209534640B115342DB15C48400D198F5209534640540262122E78484099B7EA3A54714640540262122E78484099B7EA3A54714640B115342DB15C48400D198F5209534640B115342DB15C4840
3646	416	44.449952000000003	44.452466999999999	48.651499999999999	48.650333000000003	улица Текстильная	0103000020E610000001000000050000008962F206983946403A419B1C3E5348408962F2069839464008AC1C5A6453484076C24B70EA39464008AC1C5A6453484076C24B70EA3946403A419B1C3E5348408962F206983946403A419B1C3E534840
26806	416	44.552017999999997	44.581958999999998	48.788685000000001	48.763672	улица Таращенцев	0103000020E61000000100000005000000D3669C86A84646407A6F0C01C0614840D3669C86A846464042EC4CA1F3644840724EECA17D4A464042EC4CA1F3644840724EECA17D4A46407A6F0C01C0614840D3669C86A84646407A6F0C01C0614840
4517	416	44.455809000000002	44.478051000000001	48.702649999999998	48.693165	улица Саши Филиппова	0103000020E610000001000000050000007A1C06F3573A4640ADDD76A1B95848407A1C06F3573A46406744696FF0594840F96871C6303D46406744696FF0594840F96871C6303D4640ADDD76A1B95848407A1C06F3573A4640ADDD76A1B9584840
5068	416	44.488678	44.489037000000003	48.772359000000002	48.767958999999998	улица Савкина	0103000020E6100000010000000500000029232E008D3E46409DD5027B4C62484029232E008D3E4640B9E2E2A8DC62484059C4B0C3983E4640B9E2E2A8DC62484059C4B0C3983E46409DD5027B4C62484029232E008D3E46409DD5027B4C624840
6508	416	44.538229000000001	44.548909999999999	48.767437000000001	48.754857999999999	улица Репина	0103000020E61000000100000005000000206118B0E4444640DE8FDB2F9F604840206118B0E4444640C45E28603B6248404339D1AE42464640C45E28603B6248404339D1AE42464640DE8FDB2F9F604840206118B0E4444640DE8FDB2F9F604840
27279	416	44.426693999999998	44.438578999999997	48.586205	48.574212000000003	улица Писемского	0103000020E6100000010000000500000020B3B3E89D364640427C60C77F49484020B3B3E89D36464037E0F3C3084B48402FDB4E5B2338464037E0F3C3084B48402FDB4E5B23384640427C60C77F49484020B3B3E89D364640427C60C77F494840
5524	416	44.442056000000001	44.445037999999997	48.575327000000001	48.571345000000001	улица Первой Пятилетки	0103000020E6100000010000000500000013807F4A95384640D7DD3CD52149484013807F4A95384640BEC0AC50A449484016BD5301F7384640BEC0AC50A449484016BD5301F7384640D7DD3CD52149484013807F4A95384640D7DD3CD521494840
6244	416	44.569913	44.579155999999998	48.786999000000002	48.781270999999997	улица Пельше	0103000020E610000001000000050000005A48C0E8F2484640172829B0006448405A48C0E8F24846400B7E1B62BC6448401EA4A7C8214A46400B7E1B62BC6448401EA4A7C8214A4640172829B0006448405A48C0E8F2484640172829B000644840
3619	416	44.459257999999998	44.462834000000001	48.659612000000003	48.658254999999997	улица Некрасова	0103000020E61000000100000005000000933655F7C83A4640D8B628B341544840933655F7C83A46404B06802A6E5448400ABDFE243E3B46404B06802A6E5448400ABDFE243E3B4640D8B628B341544840933655F7C83A4640D8B628B341544840
6722	416	44.452781000000002	44.458638999999998	48.658166000000001	48.652273999999998	улица Крепильная	0103000020E6100000010000000500000006A051BAF4394640FB03E5B67D53484006A051BAF439464069AB92C83E544840C7D5C8AEB43A464069AB92C83E544840C7D5C8AEB43A4640FB03E5B67D53484006A051BAF4394640FB03E5B67D534840
4912	416	44.493529000000002	44.510840000000002	48.756425999999998	48.751288000000002	улица Константина Симонова	0103000020E61000000100000005000000555051F52B3F46404AF086342A604840555051F52B3F46400BEC3191D26048408CBE8234634146400BEC3191D26048408CBE8234634146404AF086342A604840555051F52B3F46404AF086342A604840
5967	416	44.5717	44.583818999999998	48.504029000000003	48.491981000000003	улица Командира Рудь	0103000020E61000000100000005000000C58F31772D4946406FA0C03BF93E4840C58F31772D494640289EB3058440484047E4BB94BA4A4640289EB3058440484047E4BB94BA4A46406FA0C03BF93E4840C58F31772D4946406FA0C03BF93E4840
5302	416	44.424709	44.429352999999999	48.62079	48.586205	улица Кирова	0103000020E610000001000000050000008FA850DD5C36464037E0F3C3084B48408FA850DD5C36464088D7F50B764F484041B8020AF536464088D7F50B764F484041B8020AF536464037E0F3C3084B48408FA850DD5C36464037E0F3C3084B4840
4290	416	44.498945999999997	44.506348000000003	48.700063	48.694806	улица КИМ	0103000020E61000000100000005000000293C6876DD3F464044882B67EF584840293C6876DD3F4640E01115AA9B5948409032E202D0404640E01115AA9B5948409032E202D040464044882B67EF584840293C6876DD3F464044882B67EF584840
4458	416	44.463569999999997	44.489063999999999	48.710633999999999	48.698428	улица Елецкая	0103000020E610000001000000050000000FB40243563B46402B4EB516665948400FB40243563B46407CB60E0EF65A484052D32EA6993E46407CB60E0EF65A484052D32EA6993E46402B4EB516665948400FB40243563B46402B4EB51666594840
27316	416	44.320909	44.321303999999998	48.692487	48.684255	улица Голубятникова	0103000020E61000000100000005000000FCFECD8B13294640EF8FF7AA95574840FCFECD8B13294640DCF3FC69A358484078094E7D20294640DCF3FC69A358484078094E7D20294640EF8FF7AA95574840FCFECD8B13294640EF8FF7AA95574840
6320	416	44.547598999999998	44.566679000000001	48.779471999999998	48.770744000000001	улица Генерала Штеменко	0103000020E6100000010000000500000041295AB9174646404BCB48BDA762484041295AB917464640E8120EBDC56348403D2AFEEF88484640E8120EBDC56348403D2AFEEF884846404BCB48BDA762484041295AB9174646404BCB48BDA7624840
7190	416	44.522041999999999	44.529784999999997	48.715069	48.710948999999999	улица Гагарина	0103000020E61000000100000005000000B891B245D2424640DC0F7860005B4840B891B245D242464014B18861875B4840A774B0FECF43464014B18861875B4840A774B0FECF434640DC0F7860005B4840B891B245D2424640DC0F7860005B4840
6489	416	44.543906999999997	44.553697999999997	48.769325000000002	48.765684999999998	улица Вершинина	0103000020E6100000010000000500000061889CBE9E454640D50451F70162484061889CBE9E454640637FD93D7962484028EE7893DF464640637FD93D7962484028EE7893DF464640D50451F70162484061889CBE9E454640D50451F701624840
27626	416	44.466472000000003	44.473056	48.675849999999997	48.673565000000004	улака	0103000020E61000000100000005000000F73FC05AB53B4640795DBF6037564840F73FC05AB53B46403480B740825648409A9658198D3C46403480B740825648409A9658198D3C4640795DBF6037564840F73FC05AB53B4640795DBF6037564840
5986	416	44.564782999999998	44.583351999999998	48.516348999999998	48.504446999999999	проспект Столетова	0103000020E610000001000000050000001B2B31CF4A4846405CC823B8914048401B2B31CF4A48464041295AB91742484031074147AB4A464041295AB91742484031074147AB4A46405CC823B8914048401B2B31CF4A4846405CC823B891404840
4669	416	44.482156000000003	44.506546	48.753723000000001	48.719076000000001	проспект Маршала Советского Союза Г. К. Жукова	0103000020E61000000100000005000000FCC8AD49B73D464054ABAFAE0A5C4840FCC8AD49B73D46401B9FC9FE79604840B6F5D37FD64046401B9FC9FE79604840B6F5D37FD640464054ABAFAE0A5C4840FCC8AD49B73D464054ABAFAE0A5C4840
5756	416	44.509473999999997	44.566929999999999	48.517387999999997	48.51352	проспект Героев Сталинграда	0103000020E61000000100000005000000C614AC7136414640C4EBFA05BB414840C614AC7136414640E2AB1DC539424840868F882991484640E2AB1DC539424840868F882991484640C4EBFA05BB414840C614AC7136414640C4EBFA05BB414840
3745	416	44.505637999999998	44.611711	48.808916000000004	48.700491	проспект В. И. Ленина	0103000020E61000000100000005000000B3CEF8BEB8404640381268B0A9594840B3CEF8BEB8404640079B3A8F8A6748403ECDC98B4C4E4640079B3A8F8A6748403ECDC98B4C4E4640381268B0A9594840B3CEF8BEB8404640381268B0A9594840
27258	416	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	поселок имени XIX Партсъезда	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
27291	416	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	поселок Веселая Балка	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
26841	416	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	пос. Сорок домиков	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
26949	416	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	пос. Металлургов	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
27363	416	44.513112	44.516984000000001	48.709432999999997	48.707042999999999	площадь Павших Борцов	0103000020E61000000100000005000000B3976DA7AD414640D0EE9062805A4840B3976DA7AD41464001DA56B3CE5A484013471E882C42464001DA56B3CE5A484013471E882C424640D0EE9062805A4840B3976DA7AD414640D0EE9062805A4840
3805	416	44.575023999999999	44.576757999999998	48.777341	48.776170999999998	площадь Германа Титова	0103000020E610000001000000050000002235ED629A494640438D4292596348402235ED629A494640836BEEE87F6348406ADAC534D3494640836BEEE87F6348406ADAC534D3494640438D4292596348402235ED629A494640438D429259634840
5401	416	44.410794000000003	44.422139999999999	48.608645000000003	48.608150000000002	переулок Школьный	0103000020E610000001000000050000004FB2D5E594344640FD87F4DBD74D48404FB2D5E594344640DDEF5014E84D4840AE2AFBAE08364640DDEF5014E84D4840AE2AFBAE08364640FD87F4DBD74D48404FB2D5E594344640FD87F4DBD74D4840
5705	416	44.531860000000002	44.533486000000003	48.513317000000001	48.513072999999999	переулок Обводный	0103000020E6100000010000000500000079060DFD13444640F5BA4560AC41484079060DFD134446408CBD175FB4414840DB6FED44494446408CBD175FB4414840DB6FED4449444640F5BA4560AC41484079060DFD13444640F5BA4560AC414840
27513	416	44.531860000000002	44.533486000000003	48.513317000000001	48.513072999999999	переулок Обводной	0103000020E6100000010000000500000079060DFD13444640F5BA4560AC41484079060DFD134446408CBD175FB4414840DB6FED44494446408CBD175FB4414840DB6FED4449444640F5BA4560AC41484079060DFD13444640F5BA4560AC414840
26894	416	44.296052000000003	44.298369999999998	48.638992999999999	48.631692999999999	переулок Лейтенанта Мостового	0103000020E610000001000000050000002CF52C08E52546405A0EF450DB5048402CF52C08E5254640BCAFCA85CA514840C30DF8FC30264640BCAFCA85CA514840C30DF8FC302646405A0EF450DB5048402CF52C08E52546405A0EF450DB504840
27621	416	44.426864999999999	44.433512999999998	48.566187999999997	48.564900000000002	п. имени Саши Чекалина	0103000020E610000001000000050000004D672783A336464055C1A8A44E4848404D672783A33646409EB12FD97848484007B29E5A7D3746409EB12FD97848484007B29E5A7D37464055C1A8A44E4848404D672783A336464055C1A8A44E484840
26393	416	44.166794000000003	44.447526000000003	48.738211999999997	48.434669	п. Аэропорт	0103000020E61000000100000005000000A3957B8159154640E2CAD93BA3374840A3957B8159154640E3C116BB7D5E48400B0E2F8848394640E3C116BB7D5E48400B0E2F8848394640E2CAD93BA3374840A3957B8159154640E2CAD93BA3374840
27696	416	44.522759999999998	44.535542999999997	48.769069999999999	48.762869999999999	им. Асланова	0103000020E6100000010000000500000017D4B7CCE9424640BD8C62B9A561484017D4B7CCE9424640D82AC1E270624840054D4BAC8C444640D82AC1E270624840054D4BAC8C444640BD8C62B9A561484017D4B7CCE9424640BD8C62B9A5614840
5736	416	44.540258999999999	44.545262999999998	48.518825999999997	48.509002000000002	бульвар Энгельса	0103000020E61000000100000005000000512FF834274546409FCC3FFA26414840512FF834274546404128EFE368424840035C902DCB4546404128EFE368424840035C902DCB4546409FCC3FFA26414840512FF834274546409FCC3FFA26414840
4853	416	44.492586000000003	44.505305999999997	48.756610000000002	48.740802000000002	бульвар 30-летия Победы	0103000020E61000000100000005000000D63BDC0E0D3F4640DC679599D25E4840D63BDC0E0D3F4640CDE9B298D86048407D3CF4DDAD404640CDE9B298D86048407D3CF4DDAD404640DC679599D25E4840D63BDC0E0D3F4640DC679599D25E4840
6674	416	44.458404999999999	44.459609	48.675088000000002	48.673606999999997	Юрьевская улица	0103000020E6100000010000000500000054A9D903AD3A4640A7AD11C13856484054A9D903AD3A464006F698486956484040F9BB77D43A464006F698486956484040F9BB77D43A4640A7AD11C13856484054A9D903AD3A4640A7AD11C138564840
27142	416	44.562987	44.563149000000003	48.792793000000003	48.791795	Южный	0103000020E610000001000000050000005D8940F50F4846407311DF89596548405D8940F50F484640B6BFB33D7A65484037E3344415484640B6BFB33D7A65484037E33444154846407311DF89596548405D8940F50F4846407311DF8959654840
27559	416	44.480637999999999	44.486828000000003	48.751750999999999	48.741925000000002	Эльбрусская	0103000020E61000000100000005000000809BC58B853D4640DB8AFD65F75E4840809BC58B853D46401EDE73603960484078634161503E46401EDE73603960484078634161503E4640DB8AFD65F75E4840809BC58B853D4640DB8AFD65F75E4840
6687	416	44.439315999999998	44.461970999999998	48.674790999999999	48.645237999999999	Электролесовская улица	0103000020E61000000100000005000000054EB6813B3846407711A62897524840054EB6813B3846404C512E8D5F564840A759A0DD213B46404C512E8D5F564840A759A0DD213B46407711A62897524840054EB6813B3846407711A62897524840
27555	416	44.439315999999998	44.461970999999998	48.674790999999999	48.645237999999999	Электролесовская	0103000020E61000000100000005000000054EB6813B3846407711A62897524840054EB6813B3846404C512E8D5F564840A759A0DD213B46404C512E8D5F564840A759A0DD213B46407711A62897524840054EB6813B3846407711A62897524840
27638	416	44.531599999999997	44.531959000000001	48.725352000000001	48.723770999999999	Школьная	0103000020E61000000100000005000000DC4603780B44464088653387A45C4840DC4603780B4446404A0B9755D85C48400CE8853B174446404A0B9755D85C48400CE8853B1744464088653387A45C4840DC4603780B44464088653387A45C4840
27658	416	44.480468000000002	44.512653999999998	48.766243000000003	48.756723000000001	Шекснинская	0103000020E610000001000000050000002463B5F97F3D4640C5909C4CDC6048402463B5F97F3D4640FCE4284014624840F01472A59E414640FCE4284014624840F01472A59E414640C5909C4CDC6048402463B5F97F3D4640C5909C4CDC604840
27612	416	44.443663999999998	44.456887000000002	48.673969999999997	48.668965999999998	Чебышева	0103000020E61000000100000005000000CE3461FBC938464066118AADA0554840CE3461FBC9384640183E22A644564840D97BF1457B3A4640183E22A644564840D97BF1457B3A464066118AADA0554840CE3461FBC938464066118AADA0554840
27605	416	44.473928000000001	44.490141999999999	48.741883999999999	48.729899000000003	Хорошева	0103000020E61000000100000005000000505436ACA93C46400A3197546D5D4840505436ACA93C46407CB60E0EF65E4840B1321AF9BC3E46407CB60E0EF65E4840B1321AF9BC3E46400A3197546D5D4840505436ACA93C46400A3197546D5D4840
27587	416	44.543582999999998	44.570945999999999	48.793183999999997	48.775868000000003	Хользунова	0103000020E61000000100000005000000AED4B32094454640A80183A44F634840AED4B32094454640F0DAA50D8765484019E42EC214494640F0DAA50D8765484019E42EC214494640A80183A44F634840AED4B32094454640A80183A44F634840
27673	416	44.521070999999999	44.529381000000001	48.728538	48.724068000000003	Хиросимы	0103000020E610000001000000050000006FF25B74B2424640420A9E42AE5C48406FF25B74B242464056F2B1BB405D4840D80FB1C1C243464056F2B1BB405D4840D80FB1C1C2434640420A9E42AE5C48406FF25B74B2424640420A9E42AE5C4840
27591	416	44.547212000000002	44.552799999999998	48.506746	48.497838999999999	Хабаровская	0103000020E6100000010000000500000048FDF50A0B46464030D63730B93F484048FDF50A0B4646407DB08C0DDD404840499D8026C24646407DB08C0DDD404840499D8026C246464030D63730B93F484048FDF50A0B46464030D63730B93F4840
27695	416	44.450904000000001	44.455809000000002	48.702649999999998	48.691827000000004	Феодосийская	0103000020E610000001000000050000005BD1E638B7394640B2BE81C98D5848405BD1E638B73946406744696FF05948407A1C06F3573A46406744696FF05948407A1C06F3573A4640B2BE81C98D5848405BD1E638B7394640B2BE81C98D584840
27551	416	44.439216999999999	44.447418999999996	48.663051000000003	48.661105999999997	Ухтомского	0103000020E61000000100000005000000726C3D43383846403D98141F9F544840726C3D4338384640414AECDADE544840F44D9A0645394640414AECDADE544840F44D9A06453946403D98141F9F544840726C3D43383846403D98141F9F544840
6639	416	44.429560000000002	44.454884	48.687330000000003	48.634419999999999	Университетский проспект	0103000020E61000000100000005000000BBD573D2FB364640D3F6AFAC34514840BBD573D2FB364640A4C7EF6DFA574840A1BC8FA3393A4640A4C7EF6DFA574840A1BC8FA3393A4640D3F6AFAC34514840BBD573D2FB364640D3F6AFAC34514840
27692	416	44.559133000000003	44.590853000000003	48.528199999999998	48.497551999999999	Удмуртская	0103000020E61000000100000005000000A48E8EAB914746409A07B0C8AF3F4840A48E8EAB91474640A4DFBE0E9C4348402BDF3312A14B4640A4DFBE0E9C4348402BDF3312A14B46409A07B0C8AF3F4840A48E8EAB914746409A07B0C8AF3F4840
26529	416	44.559133000000003	44.590853000000003	48.528199999999998	48.497551999999999	Удмурская	0103000020E61000000100000005000000A48E8EAB914746409A07B0C8AF3F4840A48E8EAB91474640A4DFBE0E9C4348402BDF3312A14B4640A4DFBE0E9C4348402BDF3312A14B46409A07B0C8AF3F4840A48E8EAB914746409A07B0C8AF3F4840
27719	416	44.470101	44.474898000000003	48.679031999999999	48.673738	Туркменская	0103000020E61000000100000005000000906802452C3C46404609FA0B3D564840906802452C3C4640FF774485EA564840C9772975C93C4640FF774485EA564840C9772975C93C46404609FA0B3D564840906802452C3C46404609FA0B3D564840
27590	416	44.416418	44.420603999999997	48.623136000000002	48.597146000000002	Турбинная	0103000020E610000001000000050000009DBB5D2F4D354640F777B6476F4C48409DBB5D2F4D354640EA7AA2EBC24F48408C48145AD6354640EA7AA2EBC24F48408C48145AD6354640F777B6476F4C48409DBB5D2F4D354640F777B6476F4C4840
27550	416	44.466472000000003	44.473056	48.675849999999997	48.673565000000004	Тулака	0103000020E61000000100000005000000F73FC05AB53B4640795DBF6037564840F73FC05AB53B46403480B740825648409A9658198D3C46403480B740825648409A9658198D3C4640795DBF6037564840F73FC05AB53B4640795DBF6037564840
27608	416	44.504821	44.521278000000002	48.731175999999998	48.719099	Ткачева	0103000020E61000000100000005000000C1AA7AF99D4046400CCB9F6F0B5C4840C1AA7AF99D4046405FCFD72C975D4840E90FCD3CB94246405FCFD72C975D4840E90FCD3CB94246400CCB9F6F0B5C4840C1AA7AF99D4046400CCB9F6F0B5C4840
27637	416	44.384194999999998	44.389738000000001	48.782915000000003	48.777904999999997	Строителей	0103000020E61000000100000005000000B324404D2D3146408B321B6492634840B324404D2D3146402046088F3664484015014EEFE23146402046088F3664484015014EEFE23146408B321B6492634840B324404D2D3146408B321B6492634840
27467	416	44.468223999999999	44.475265999999998	48.701324	48.697066	Ставропольская	0103000020E61000000100000005000000E59997C3EE3B4640A7936C7539594840E59997C3EE3B464030F31DFCC45948404B732B84D53C464030F31DFCC45948404B732B84D53C4640A7936C7539594840E59997C3EE3B4640A7936C7539594840
4428	416	44.487473999999999	44.499673999999999	48.702387999999999	48.695104000000001	Социалистическая улица	0103000020E610000001000000050000003DD34B8C653E4640CEA8F92AF95848403DD34B8C653E46402A8D98D9E7594840AC545051F53F46402A8D98D9E7594840AC545051F53F4640CEA8F92AF95848403DD34B8C653E4640CEA8F92AF9584840
6362	416	44.541947999999998	44.548065999999999	48.782060000000001	48.777762000000003	Созидательская улица	0103000020E61000000100000005000000F910548D5E454640290989B48D634840F910548D5E45464040C1C58A1A6448405706D5062746464040C1C58A1A6448405706D50627464640290989B48D634840F910548D5E454640290989B48D634840
3344	416	44.512897000000002	44.537303999999999	48.721482999999999	48.702364000000003	Советская улица	0103000020E61000000100000005000000B79BE09BA6414640A2F14410E7594840B79BE09BA64146405BCF108E595C48404701A260C64446405BCF108E595C48404701A260C6444640A2F14410E7594840B79BE09BA6414640A2F14410E7594840
27594	416	44.512897000000002	44.537303999999999	48.721482999999999	48.702364000000003	Советская	0103000020E61000000100000005000000B79BE09BA6414640A2F14410E7594840B79BE09BA64146405BCF108E595C48404701A260C64446405BCF108E595C48404701A260C6444640A2F14410E7594840B79BE09BA6414640A2F14410E7594840
27602	416	44.455809000000002	44.478051000000001	48.702649999999998	48.693165	Саши Филиппова	0103000020E610000001000000050000007A1C06F3573A4640ADDD76A1B95848407A1C06F3573A46406744696FF0594840F96871C6303D46406744696FF0594840F96871C6303D4640ADDD76A1B95848407A1C06F3573A4640ADDD76A1B9584840
27567	416	44.579704	44.589540999999997	48.523843999999997	48.519081999999997	Саушинская	0103000020E6100000010000000500000021AE9CBD334A46409CF86A477142484021AE9CBD334A4640581AF8510D43484058535914764B4640581AF8510D43484058535914764B46409CF86A477142484021AE9CBD334A46409CF86A4771424840
4435	416	44.484769999999997	44.492235000000001	48.706235	48.702067	Ростовская улица	0103000020E610000001000000050000007C0A80F10C3E4640E84CDA54DD5948407C0A80F10C3E4640312592E8655A48402979758E013F4640312592E8655A48402979758E013F4640E84CDA54DD5948407C0A80F10C3E4640E84CDA54DD594840
27645	416	44.565511000000001	44.567037999999997	48.521791999999998	48.518211000000001	Российская	0103000020E610000001000000050000009E4319AA62484640B7B6F0BC544248409E4319AA624846403FA88B14CA4248406CCB80B3944846403FA88B14CA4248406CCB80B394484640B7B6F0BC544248409E4319AA62484640B7B6F0BC54424840
27644	416	44.487582000000003	44.530728000000003	48.751911999999997	48.707572999999996	Рокоссовского	0103000020E61000000100000005000000240F4416693E46402C4487C0915A4840240F4416693E464027BC04A73E604840278925E5EE43464027BC04A73E604840278925E5EE4346402C4487C0915A4840240F4416693E46402C4487C0915A4840
27553	416	44.418680999999999	44.433531000000002	48.656802999999996	48.654665999999999	Родниковая	0103000020E61000000100000005000000713AC95697354640CDE67118CC534840713AC956973546401475E61E12544840AE669DF17D3746401475E61E12544840AE669DF17D374640CDE67118CC534840713AC95697354640CDE67118CC534840
4808	416	44.485470999999997	44.489899999999999	48.740017999999999	48.734414999999998	Рионская улица	0103000020E610000001000000050000000514EAE9233E46408E588B4F015E48400514EAE9233E4640C539EAE8B85E4840BB270F0BB53E4640C539EAE8B85E4840BB270F0BB53E46408E588B4F015E48400514EAE9233E46408E588B4F015E4840
27554	416	44.467621999999999	44.474727000000001	48.729559999999999	48.723961000000003	Римского-Корсакова	0103000020E61000000100000005000000EF71A609DB3B46402C4A09C1AA5C4840EF71A609DB3B4640213CDA38625D48409CC3B5DAC33C4640213CDA38625D48409CC3B5DAC33C46402C4A09C1AA5C4840EF71A609DB3B46402C4A09C1AA5C4840
27614	416	44.477791000000003	44.488804000000002	48.770465000000002	48.770060999999998	Республиканская	0103000020E610000001000000050000005DA96741283D46406876DD5B916248405DA96741283D464038DBDC989E624840B6132521913E464038DBDC989E624840B6132521913E46406876DD5B916248405DA96741283D46406876DD5B91624840
27548	416	44.538229000000001	44.548909999999999	48.767437000000001	48.754857999999999	Репина	0103000020E61000000100000005000000206118B0E4444640DE8FDB2F9F604840206118B0E4444640C45E28603B6248404339D1AE42464640C45E28603B6248404339D1AE42464640DE8FDB2F9F604840206118B0E4444640DE8FDB2F9F604840
27476	416	44.473407000000002	44.505637999999998	48.700491	48.681125999999999	Рабоче-Крестьянская	0103000020E610000001000000050000004759BF99983C4640473A03232F5748404759BF99983C4640381268B0A9594840B3CEF8BEB8404640381268B0A9594840B3CEF8BEB8404640473A03232F5748404759BF99983C4640473A03232F574840
27686	416	44.482641000000001	44.492280000000001	48.760393000000001	48.760055000000001	Пятиизбянская	0103000020E61000000100000005000000B85A272EC73D4640A514747B49614840B85A272EC73D4640BD8DCD8E54614840C93CF207033F4640BD8DCD8E54614840C93CF207033F4640A514747B49614840B85A272EC73D4640A514747B49614840
27677	416	44.510795000000002	44.514172000000002	48.706960000000002	48.704630000000002	Пушкина	0103000020E61000000100000005000000ECFA05BB61414640E7E3DA50315A4840ECFA05BB6141464043CA4FAA7D5A48406C425A63D041464043CA4FAA7D5A48406C425A63D0414640E7E3DA50315A4840ECFA05BB61414640E7E3DA50315A4840
27685	416	44.532184000000001	44.534941000000003	48.518873999999997	48.510219999999997	Пролетарская	0103000020E610000001000000050000002CBAF59A1E444640EFE192E34E4148402CBAF59A1E444640525F96766A42484010255AF278444640525F96766A42484010255AF278444640EFE192E34E4148402CBAF59A1E444640EFE192E34E414840
16501	416	44.513480999999999	44.515107	48.712311	48.711323999999998	Привокзальная площадь	0103000020E61000000100000005000000060FD3BEB9414640116E32AA0C5B4840060FD3BEB941464060CAC0012D5B48406878B306EF41464060CAC0012D5B48406878B306EF414640116E32AA0C5B4840060FD3BEB9414640116E32AA0C5B4840
6284	416	44.583855	44.588140000000003	48.775922000000001	48.772917	Прибалтийская улица	0103000020E61000000100000005000000944DB9C2BB4A4640DFC2BAF1EE624840944DB9C2BB4A46409B1F7F695163484017BCE82B484B46409B1F7F695163484017BCE82B484B4640DFC2BAF1EE624840944DB9C2BB4A4640DFC2BAF1EE624840
27596	416	44.542811	44.550635	48.781609000000003	48.771112000000002	Поддубного	0103000020E610000001000000050000005C74B2D47A454640CEC64ACCB36248405C74B2D47A45464030A182C30B64484038842A357B46464030A182C30B64484038842A357B464640CEC64ACCB36248405C74B2D47A454640CEC64ACCB3624840
27710	416	44.507461999999997	44.527171000000003	48.723801000000002	48.712536999999998	Пархоменко	0103000020E610000001000000050000003BFBCA83F440464050189469345B48403BFBCA83F4404640F3E7DB82A55C48402733DE567A434640F3E7DB82A55C48402733DE567A43464050189469345B48403BFBCA83F440464050189469345B4840
4634	416	44.518134000000003	44.524799000000002	48.736685000000001	48.732613999999998	Охотская улица	0103000020E610000001000000050000000C79043752424640BE4BA94BC65D48400C79043752424640153AAFB14B5E48409CFC169D2C434640153AAFB14B5E48409CFC169D2C434640BE4BA94BC65D48400C79043752424640BE4BA94BC65D4840
27613	416	44.333754999999996	44.335200999999998	48.657743000000004	48.655880000000003	Ольховская	0103000020E6100000010000000500000030F0DC7BB82A4640DD0C37E0F353484030F0DC7BB82A4640231631EC30544840124BCADDE72A4640231631EC30544840124BCADDE72A4640DD0C37E0F353484030F0DC7BB82A4640DD0C37E0F3534840
27715	416	44.571286999999998	44.581052	48.516063000000003	48.509419999999999	Олимпийская	0103000020E61000000100000005000000A2D0B2EE1F494640D3F6AFAC34414840A2D0B2EE1F4946407CD6355A0E42484040A374E95F4A46407CD6355A0E42484040A374E95F4A4640D3F6AFAC34414840A2D0B2EE1F494640D3F6AFAC34414840
27627	416	44.486828000000003	44.49485	48.726095000000001	48.714593999999998	Новорядская	0103000020E6100000010000000500000078634161503E46407BF5F1D0775B484078634161503E4640026553AEF05C48407A36AB3E573F4640026553AEF05C48407A36AB3E573F46407BF5F1D0775B484078634161503E46407BF5F1D0775B4840
7044	416	44.503357000000001	44.518932999999997	48.720086000000002	48.710948999999999	Новороссийская улица	0103000020E61000000100000005000000399B8E006E404640DC0F7860005B4840399B8E006E4046405B272EC72B5C484057E883656C4246405B272EC72B5C484057E883656C424640DC0F7860005B4840399B8E006E404640DC0F7860005B4840
27632	416	44.503357000000001	44.518932999999997	48.720086000000002	48.710948999999999	Новороссийская	0103000020E61000000100000005000000399B8E006E404640DC0F7860005B4840399B8E006E4046405B272EC72B5C484057E883656C4246405B272EC72B5C484057E883656C424640DC0F7860005B4840399B8E006E404640DC0F7860005B4840
27653	416	44.493448000000001	44.503599000000001	48.739555000000003	48.728538	Новодвинская	0103000020E610000001000000050000006823D74D293F464056F2B1BB405D48406823D74D293F4640F14BFDBCA95E48402FA699EE75404640F14BFDBCA95E48402FA699EE7540464056F2B1BB405D48406823D74D293F464056F2B1BB405D4840
27665	416	44.567594999999997	44.573542000000003	48.791640999999998	48.791463	Никопольская	0103000020E61000000100000005000000C22FF5F3A64846403D7FDAA84E654840C22FF5F3A64846401C96067E54654840F47002D3694946401C96067E54654840F47002D3694946403D7FDAA84E654840C22FF5F3A64846403D7FDAA84E654840
6106	416	44.590125	44.598497000000002	48.526273000000003	48.518802000000001	Николаевская улица	0103000020E61000000100000005000000A8C64B37894B4640B98C9B1A68424840A8C64B37894B464048E2E5E95C43484087E0B88C9B4C464048E2E5E95C43484087E0B88C9B4C4640B98C9B1A68424840A8C64B37894B4640B98C9B1A68424840
27552	416	44.533189999999998	44.534860999999999	48.758713	48.756669000000002	Нестерова	0103000020E61000000100000005000000F146E6913F444640D272A087DA604840F146E6913F4446406806F1811D614840F3734353764446406806F1811D614840F373435376444640D272A087DA604840F146E6913F444640D272A087DA604840
27629	416	44.506303000000003	44.512222999999999	48.719217999999998	48.714837000000003	Невская	0103000020E61000000100000005000000F06E6589CE404640427C60C77F5B4840F06E6589CE404640E658DE550F5C484027A1F48590414640E658DE550F5C484027A1F48590414640427C60C77F5B4840F06E6589CE404640427C60C77F5B4840
27657	416	44.509338999999997	44.523757000000003	48.713940000000001	48.705319000000003	Мира	0103000020E61000000100000005000000E6C9350532414640AC1F9BE4475A4840E6C935053241464033A7CB62625B48408A0629780A43464033A7CB62625B48408A0629780A434640AC1F9BE4475A4840E6C9350532414640AC1F9BE4475A4840
27669	416	44.470281	44.495901000000003	48.707680000000003	48.687413999999997	Милиционера Буханцева	0103000020E610000001000000050000001077F52A323C46400168942EFD5748401077F52A323C464043041C42955A4840E08618AF793F464043041C42955A4840E08618AF793F46400168942EFD5748401077F52A323C46400168942EFD574840
27720	416	44.513956999999998	44.555100000000003	48.739167999999999	48.701478000000002	Маршала Чуйкова	0103000020E610000001000000050000006F46CD57C9414640876EF607CA5948406F46CD57C9414640F71F990E9D5E48403B014D840D474640F71F990E9D5E48403B014D840D474640876EF607CA5948406F46CD57C9414640876EF607CA594840
27564	416	44.533045999999999	44.578949999999999	48.789681999999999	48.759217	Маршала Еременко	0103000020E61000000100000005000000BEA1F0D93A4446409BC8CC052E614840BEA1F0D93A444640B41EBE4C1465484075029A081B4A4640B41EBE4C1465484075029A081B4A46409BC8CC052E614840BEA1F0D93A4446409BC8CC052E614840
27654	416	44.435983	44.444687999999999	48.683458000000002	48.681251000000003	Мамина-Сибиряка	0103000020E61000000100000005000000554E7B4ACE37464004AF963B33574840554E7B4ACE37464044183F8D7B5748403A765089EB38464044183F8D7B5748403A765089EB38464004AF963B33574840554E7B4ACE37464004AF963B33574840
27631	416	44.430458000000002	44.521690999999997	48.569699	48.510488000000002	Лазоревая	0103000020E610000001000000050000009A266C3F193746400F80B8AB574148409A266C3F193746402EC896E5EB4848400BCF4BC5C64246402EC896E5EB4848400BCF4BC5C64246400F80B8AB574148409A266C3F193746400F80B8AB57414840
27656	416	44.492289	44.492702999999999	48.772489999999998	48.767525999999997	Кутузовская	0103000020E610000001000000050000001C977153033F4640336ABE4A3E6248401C977153033F4640573ECBF3E06248400FD253E4103F4640573ECBF3E06248400FD253E4103F4640336ABE4A3E6248401C977153033F4640336ABE4A3E624840
27674	416	44.422023000000003	44.428150000000002	48.604444999999998	48.604247999999998	Курчатова	0103000020E61000000100000005000000759483D90436464032569BFF574D4840759483D904364640889D29745E4D484026E4839ECD364640889D29745E4D484026E4839ECD36464032569BFF574D4840759483D90436464032569BFF574D4840
6555	416	44.528860000000002	44.548774999999999	48.752029999999998	48.750551000000002	Кубинская улица	0103000020E61000000100000005000000CF143AAFB1434640747D1F0E12604840CF143AAFB143464031CEDF844260484063EE5A423E46464031CEDF844260484063EE5A423E464640747D1F0E12604840CF143AAFB1434640747D1F0E12604840
27691	416	44.494939000000002	44.508862999999998	48.721465000000002	48.711657000000002	Кубанская	0103000020E61000000100000005000000EA4141295A3F4640187C9A93175B4840EA4141295A3F4640B51A12F7585C48407D923B6C22414640B51A12F7585C48407D923B6C22414640187C9A93175B4840EA4141295A3F4640187C9A93175B4840
6640	416	44.431446999999999	44.435290999999999	48.668388999999998	48.657237000000002	Криворожская улица	0103000020E61000000100000005000000897AC1A7393746404F5C8E5720544840897AC1A739374640C90050C58D5548401F9F909DB7374640C90050C58D5548401F9F909DB73746404F5C8E5720544840897AC1A7393746404F5C8E5720544840
27709	416	44.431446999999999	44.435290999999999	48.668388999999998	48.657237000000002	Криворожская	0103000020E61000000100000005000000897AC1A7393746404F5C8E5720544840897AC1A739374640C90050C58D5548401F9F909DB7374640C90050C58D5548401F9F909DB73746404F5C8E5720544840897AC1A7393746404F5C8E5720544840
27562	416	44.477502999999999	44.494993000000001	48.784008	48.759371999999999	Краснополянская	0103000020E61000000100000005000000F65E7CD11E3D4640C2BF081A33614840F65E7CD11E3D4640B4E6C75F5A644840DD5F3DEE5B3F4640B4E6C75F5A644840DD5F3DEE5B3F4640C2BF081A33614840F65E7CD11E3D4640C2BF081A33614840
6590	416	44.464972000000003	44.469301999999999	48.680965999999998	48.677931999999998	Красноволжская улица	0103000020E6100000010000000500000022C7D633843B4640B874CC79C656484022C7D633843B46400ED8D5E42957484044F98216123C46400ED8D5E42957484044F98216123C4640B874CC79C656484022C7D633843B4640B874CC79C6564840
27697	416	44.493529000000002	44.510840000000002	48.756425999999998	48.751288000000002	Константина Симонова	0103000020E61000000100000005000000555051F52B3F46404AF086342A604840555051F52B3F46400BEC3191D26048408CBE8234634146400BEC3191D26048408CBE8234634146404AF086342A604840555051F52B3F46404AF086342A604840
7151	416	44.507139000000002	44.531824	48.723574999999997	48.707216000000003	Коммунистическая улица	0103000020E6100000010000000500000059C345EEE94046409E9ACB0D865A484059C345EEE9404640029A081B9E5C48402C9D0FCF12444640029A081B9E5C48402C9D0FCF124446409E9ACB0D865A484059C345EEE94046409E9ACB0D865A4840
27546	416	44.507139000000002	44.531824	48.723574999999997	48.707216000000003	Коммунистическая	0103000020E6100000010000000500000059C345EEE94046409E9ACB0D865A484059C345EEE9404640029A081B9E5C48402C9D0FCF12444640029A081B9E5C48402C9D0FCF124446409E9ACB0D865A484059C345EEE94046409E9ACB0D865A4840
27624	416	44.542864999999999	44.549754999999998	48.789248999999998	48.784447	Коммунаров	0103000020E610000001000000050000004F92AE997C454640003961C2686448404F92AE997C4546404AB3791C06654840FFE7305F5E4646404AB3791C06654840FFE7305F5E464640003961C2686448404F92AE997C454640003961C268644840
27694	416	44.467405999999997	44.483215999999999	48.695816999999998	48.686473999999997	Комитетская	0103000020E6100000010000000500000022FAB5F5D33B4640F3C64961DE57484022FAB5F5D33B46401B800D8810594840B4739A05DA3D46401B800D8810594840B4739A05DA3D4640F3C64961DE57484022FAB5F5D33B4640F3C64961DE574840
27660	416	44.474871	44.501882999999999	48.518926999999998	48.500304	Колесная	0103000020E61000000100000005000000CF68AB92C83C46406C0723F609404840CF68AB92C83C464075012F336C4248408DB5BFB33D40464075012F336C4248408DB5BFB33D4046406C0723F609404840CF68AB92C83C46406C0723F609404840
27599	416	44.474116000000002	44.503177000000001	48.702739000000001	48.684297000000001	Козловская	0103000020E61000000100000005000000534145D5AF3C46401EE0490B97574840534145D5AF3C4640D74FFF59F3594840B98C9B1A68404640D74FFF59F3594840B98C9B1A684046401EE0490B97574840534145D5AF3C46401EE0490B97574840
4400	416	44.491661000000001	44.504658999999997	48.701193000000004	48.693688000000002	Ковровская улица	0103000020E61000000100000005000000FDDB65BFEE3E464057D0B4C4CA584840FDDB65BFEE3E4640929735B1C0594840E75086AA98404640929735B1C0594840E75086AA9840464057D0B4C4CA584840FDDB65BFEE3E464057D0B4C4CA584840
27371	416	44.471502000000001	44.480521000000003	48.695413000000002	48.688788000000002	Клубная	0103000020E61000000100000005000000D2FF722D5A3C46404AF086342A584840D2FF722D5A3C46404C1B0E4B0359484047054EB6813D46404C1B0E4B0359484047054EB6813D46404AF086342A584840D2FF722D5A3C46404AF086342A584840
27641	416	44.424709	44.429352999999999	48.62079	48.586205	Кирова	0103000020E610000001000000050000008FA850DD5C36464037E0F3C3084B48408FA850DD5C36464088D7F50B764F484041B8020AF536464088D7F50B764F484041B8020AF536464037E0F3C3084B48408FA850DD5C36464037E0F3C3084B4840
26652	416	44.424709	44.429352999999999	48.62079	48.586205	Кирова	0103000020E610000001000000050000008FA850DD5C36464037E0F3C3084B48408FA850DD5C36464088D7F50B764F484041B8020AF536464088D7F50B764F484041B8020AF536464037E0F3C3084B48408FA850DD5C36464037E0F3C3084B4840
27647	416	44.619104999999998	44.621637999999997	48.538747999999998	48.536791999999998	Кедроградская	0103000020E6100000010000000500000021E527D53E4F46409160AA99B544484021E527D53E4F46408864C8B1F5444840B5F97FD5914F46408864C8B1F5444840B5F97FD5914F46409160AA99B544484021E527D53E4F46409160AA99B5444840
27579	416	44.494841000000001	44.529497999999997	48.738757999999997	48.729987999999999	Качинцев	0103000020E6100000010000000500000027DC2BF3563F4640793C2D3F705D484027DC2BF3563F464045D4449F8F5E484011A62897C643464045D4449F8F5E484011A62897C6434640793C2D3F705D484027DC2BF3563F4640793C2D3F705D4840
27508	416	44.535542999999997	44.542622000000001	48.777762000000003	48.769069999999999	Качалова	0103000020E61000000100000005000000054D4BAC8C444640D82AC1E270624840054D4BAC8C444640290989B48D634840890B40A374454640290989B48D634840890B40A374454640D82AC1E270624840054D4BAC8C444640D82AC1E270624840
6599	416	44.412329999999997	44.460129999999999	48.680441999999999	48.675379999999997	Казахская улица	0103000020E610000001000000050000007094BC3AC7344640AD2F12DA725648407094BC3AC7344640946934B91857484049F4328AE53A4640946934B91857484049F4328AE53A4640AD2F12DA725648407094BC3AC7344640AD2F12DA72564840
27604	416	44.412329999999997	44.460129999999999	48.680441999999999	48.675379999999997	Казахская	0103000020E610000001000000050000007094BC3AC7344640AD2F12DA725648407094BC3AC7344640946934B91857484049F4328AE53A4640946934B91857484049F4328AE53A4640AD2F12DA725648407094BC3AC7344640AD2F12DA72564840
27573	416	44.498945999999997	44.506348000000003	48.700063	48.694806	КИМ	0103000020E61000000100000005000000293C6876DD3F464044882B67EF584840293C6876DD3F4640E01115AA9B5948409032E202D0404640E01115AA9B5948409032E202D040464044882B67EF584840293C6876DD3F464044882B67EF584840
27672	416	44.499979000000003	44.510902000000002	48.732787000000002	48.726458000000001	Иртышская	0103000020E61000000100000005000000E9D7D64FFF3F464073F56393FC5C4840E9D7D64FFF3F46408CF7E3F6CB5D484002BB9A3C654146408CF7E3F6CB5D484002BB9A3C6541464073F56393FC5C4840E9D7D64FFF3F464073F56393FC5C4840
27598	416	44.485982999999997	44.491804000000002	48.691974999999999	48.687128000000001	Иркутская	0103000020E61000000100000005000000BBB4E1B0343E46403C1570CFF3574840BBB4E1B0343E4640265305A3925848406005F86EF33E4640265305A3925848406005F86EF33E46403C1570CFF3574840BBB4E1B0343E46403C1570CFF3574840
27643	416	44.547553999999998	44.552233999999999	48.514820999999998	48.506746	Изобильная	0103000020E61000000100000005000000A165DD3F164646407DB08C0DDD404840A165DD3F16464640A2258FA7E5414840A0DE8C9AAF464640A2258FA7E5414840A0DE8C9AAF4646407DB08C0DDD404840A165DD3F164646407DB08C0DDD404840
27583	416	44.469768999999999	44.473801999999999	48.720923999999997	48.719135000000001	Жирновская	0103000020E610000001000000050000005AD6FD63213C464059349D9D0C5C48405AD6FD63213C46406473D53C475C4840C3633F8BA53C46406473D53C475C4840C3633F8BA53C464059349D9D0C5C48405AD6FD63213C464059349D9D0C5C4840
27549	416	44.459482999999999	44.483629999999998	48.702198000000003	48.687348	Ельшанская	0103000020E61000000100000005000000B308C556D03A46404A7CEE04FB574840B308C556D03A464087A8C29FE1594840A7AE7C96E73D464087A8C29FE1594840A7AE7C96E73D46404A7CEE04FB574840B308C556D03A46404A7CEE04FB574840
27707	416	44.463569999999997	44.489063999999999	48.710633999999999	48.698428	Елецкая	0103000020E610000001000000050000000FB40243563B46402B4EB516665948400FB40243563B46407CB60E0EF65A484052D32EA6993E46407CB60E0EF65A484052D32EA6993E46402B4EB516665948400FB40243563B46402B4EB51666594840
27711	416	44.499448999999998	44.517406000000001	48.731924999999997	48.717280000000002	Двинская	0103000020E610000001000000050000008C82E0F1ED3F46409609BFD4CF5B48408C82E0F1ED3F4640F90FE9B7AF5D484089601C5C3A424640F90FE9B7AF5D484089601C5C3A4246409609BFD4CF5B48408C82E0F1ED3F46409609BFD4CF5B4840
27502	416	44.437770999999998	44.445694000000003	48.659951	48.657212999999999	Даугавская 	0103000020E61000000100000005000000901150E108384640C6C03A8E1F544840901150E10838464033FB3C4679544840000341800C39464033FB3C4679544840000341800C394640C6C03A8E1F544840901150E108384640C6C03A8E1F544840
27680	416	44.421799	44.427520999999999	48.601751999999998	48.601585	Губкина	0103000020E61000000100000005000000253E7782FD354640D061BEBC004D4840253E7782FD354640BB26A435064D484036AD1402B9364640BB26A435064D484036AD1402B9364640D061BEBC004D4840253E7782FD354640D061BEBC004D4840
27329	416	44.532462000000002	44.547868000000001	48.510685000000002	48.506835000000002	Гражданская улица	0103000020E610000001000000050000006F2EFEB627444640EDBB22F8DF4048406F2EFEB62744464065C746205E4148403143E3892046464065C746205E4148403143E38920464640EDBB22F8DF4048406F2EFEB627444640EDBB22F8DF404840
27683	416	44.517532000000003	44.537016999999999	48.510178000000003	48.503815000000003	Героев Малой Земли	0103000020E610000001000000050000001651137D3E424640FC1D8A027D4048401651137D3E424640C19140834D414840B1321AF9BC444640C19140834D414840B1321AF9BC444640FC1D8A027D4048401651137D3E424640FC1D8A027D404840
5583	416	44.462392999999999	44.466974999999998	48.533427000000003	48.530199000000003	Георгиевская улица	0103000020E610000001000000050000001D739EB12F3B46409BAF928FDD4348401D739EB12F3B4640D6E6FF5547444840598638D6C53B4640D6E6FF5547444840598638D6C53B46409BAF928FDD4348401D739EB12F3B46409BAF928FDD434840
27501	416	44.462392999999999	44.466974999999998	48.533427000000003	48.530199000000003	Георгиевская	0103000020E610000001000000050000001D739EB12F3B46409BAF928FDD4348401D739EB12F3B4640D6E6FF5547444840598638D6C53B4640D6E6FF5547444840598638D6C53B46409BAF928FDD4348401D739EB12F3B46409BAF928FDD434840
27600	416	44.547598999999998	44.566679000000001	48.779471999999998	48.770744000000001	Генерала Штеменко	0103000020E6100000010000000500000041295AB9174646404BCB48BDA762484041295AB917464640E8120EBDC56348403D2AFEEF88484640E8120EBDC56348403D2AFEEF884846404BCB48BDA762484041295AB9174646404BCB48BDA7624840
27563	416	44.482219000000001	44.483018999999999	48.765946	48.757452999999998	Гейне	0103000020E610000001000000050000004241295AB93D4640E8A04B38F46048404241295AB93D46404240BE840A6248405E2C0C91D33D46404240BE840A6248405E2C0C91D33D4640E8A04B38F46048404241295AB93D4640E8A04B38F4604840
27620	416	44.555925999999999	44.569994000000001	48.524686000000003	48.519936000000001	Вучетича	0103000020E61000000100000005000000807F4A9528474640AC014A438D424840807F4A9528474640A4552DE92843484047753A90F5484640A4552DE92843484047753A90F5484640AC014A438D424840807F4A9528474640AC014A438D424840
16277	416	44.384815000000003	44.395415	48.630628000000002	48.628418000000003	Волгоградская улица	0103000020E610000001000000050000005001309E41314640DF1B4300705048405001309E4131464090F8156BB850484086AC6EF59C32464090F8156BB850484086AC6EF59C324640DF1B4300705048405001309E41314640DF1B430070504840
27633	416	44.384815000000003	44.395415	48.630628000000002	48.628418000000003	Волгоградская	0103000020E610000001000000050000005001309E41314640DF1B4300705048405001309E4131464090F8156BB850484086AC6EF59C32464090F8156BB850484086AC6EF59C324640DF1B4300705048405001309E41314640DF1B430070504840
27405	416	44.384815000000003	44.395415	48.630628000000002	48.628418000000003	Волгоградская	0103000020E610000001000000050000005001309E41314640DF1B4300705048405001309E4131464090F8156BB850484086AC6EF59C32464090F8156BB850484086AC6EF59C324640DF1B4300705048405001309E41314640DF1B430070504840
27586	416	44.505637999999998	44.611711	48.808916000000004	48.700491	В. И. Ленина	0103000020E61000000100000005000000B3CEF8BEB8404640381268B0A9594840B3CEF8BEB8404640079B3A8F8A6748403ECDC98B4C4E4640079B3A8F8A6748403ECDC98B4C4E4640381268B0A9594840B3CEF8BEB8404640381268B0A9594840
27336	416	44.540258999999999	44.545262999999998	48.518825999999997	48.509002000000002	Бульвар Энгельса	0103000020E61000000100000005000000512FF834274546409FCC3FFA26414840512FF834274546404128EFE368424840035C902DCB4546404128EFE368424840035C902DCB4546409FCC3FFA26414840512FF834274546409FCC3FFA26414840
27565	416	44.566184999999997	44.592756999999999	48.512749999999997	48.497456999999997	Брестская	0103000020E610000001000000050000002D3E05C0784846404815C5ABAC3F48402D3E05C0784846401283C0CAA1414840CFBC1C76DF4B46401283C0CAA1414840CFBC1C76DF4B46404815C5ABAC3F48402D3E05C0784846404815C5ABAC3F4840
27580	416	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	Большая	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
6388	416	44.532597000000003	44.564388000000001	48.778196000000001	48.768292000000002	Богунская улица	0103000020E610000001000000050000004F7974232C444640A4E36A64576248404F7974232C44464063F030ED9B6348409F20B1DD3D48464063F030ED9B6348409F20B1DD3D484640A4E36A64576248404F7974232C444640A4E36A6457624840
27593	416	44.532597000000003	44.564388000000001	48.778196000000001	48.768292000000002	Богунская	0103000020E610000001000000050000004F7974232C444640A4E36A64576248404F7974232C44464063F030ED9B6348409F20B1DD3D48464063F030ED9B6348409F20B1DD3D484640A4E36A64576248404F7974232C444640A4E36A6457624840
27716	416	44.560588000000003	44.575384	48.527937999999999	48.520992	Бахтурова	0103000020E61000000100000005000000D943FB58C147464023BDA8DDAF424840D943FB58C14746406728EE78934348402252D32EA64946406728EE78934348402252D32EA649464023BDA8DDAF424840D943FB58C147464023BDA8DDAF424840
27655	416	44.487608999999999	44.497886000000001	48.696584000000001	48.689191999999998	Баррикадная	0103000020E610000001000000050000001D1EC2F8693E464019558671375848401D1EC2F8693E46405C751DAA2959484071917BBABA3F46405C751DAA2959484071917BBABA3F464019558671375848401D1EC2F8693E46401955867137584840
4717	416	44.446061999999998	44.497445999999997	48.757899000000002	48.713827000000002	Ангарская улица	0103000020E6100000010000000500000082FE428F183946403B00E2AE5E5B484082FE428F18394640E7559DD50261484054C37E4FAC3F4640E7559DD50261484054C37E4FAC3F46403B00E2AE5E5B484082FE428F183946403B00E2AE5E5B4840
27592	416	44.446061999999998	44.497445999999997	48.757899000000002	48.713827000000002	Ангарская	0103000020E6100000010000000500000082FE428F183946403B00E2AE5E5B484082FE428F18394640E7559DD50261484054C37E4FAC3F4640E7559DD50261484054C37E4FAC3F46403B00E2AE5E5B484082FE428F183946403B00E2AE5E5B4840
27681	416	44.416786000000002	44.418402999999998	48.589953000000001	48.582062999999998	Алычевая	0103000020E6100000010000000500000020B75F3E59354640179B560A814A484020B75F3E59354640AB967494834B48402EC6C03A8E354640AB967494834B48402EC6C03A8E354640179B560A814A484020B75F3E59354640179B560A814A4840
27609	416	44.395783000000002	44.415537	48.688484000000003	48.684522999999999	Алишера Навои	0103000020E6100000010000000500000009A87004A93246400E2E1D739E57484009A87004A9324640DEE8633E2058484094A3005130354640DEE8633E2058484094A30051303546400E2E1D739E57484009A87004A93246400E2E1D739E574840
27618	416	44.501488000000002	44.507964999999999	48.515948999999999	48.510285000000003	Алданская	0103000020E6100000010000000500000011AB3FC230404640D751D5045141484011AB3FC230404640B3B3E89D0A4248409E4143FF04414640B3B3E89D0A4248409E4143FF04414640D751D5045141484011AB3FC230404640D751D50451414840
27652	416	44.490484000000002	44.499296000000001	48.700127999999999	48.693824999999997	Академическая	0103000020E610000001000000050000000B9B012EC83E4640D712F241CF5848400B9B012EC83E4640C78157CB9D59484006836BEEE83F4640C78157CB9D59484006836BEEE83F4640D712F241CF5848400B9B012EC83E4640D712F241CF584840
27575	416	44.422293000000003	44.454155999999998	48.694937000000003	48.686771	Автотранспортная	0103000020E61000000100000005000000352A70B20D364640AD6BB41CE8574840352A70B20D364640E3E313B2F35848401EA4A7C8213A4640E3E313B2F35848401EA4A7C8213A4640AD6BB41CE8574840352A70B20D364640AD6BB41CE8574840
26781	416	44.387708000000003	44.416533999999999	48.591943999999998	48.589970999999998	Абганеровская	0103000020E61000000100000005000000E4326E6AA0314640514B732B844B4840E4326E6AA03146401E882CD2C44B484006D671FC503546401E882CD2C44B484006D671FC50354640514B732B844B4840E4326E6AA0314640514B732B844B4840
4861	416	44.499251000000001	44.506528000000003	48.759014999999998	48.748204999999999	8-й Воздушной Армии улица	0103000020E6100000010000000500000066BFEE74E73F464012DA722EC55F484066BFEE74E73F464033164D67276148401041D5E8D540464033164D67276148401041D5E8D540464012DA722EC55F484066BFEE74E73F464012DA722EC55F4840
27526	416	44.499251000000001	44.506528000000003	48.759014999999998	48.748204999999999	8-й Воздушной Армии	0103000020E6100000010000000500000066BFEE74E73F464012DA722EC55F484066BFEE74E73F464033164D67276148401041D5E8D540464033164D67276148401041D5E8D540464012DA722EC55F484066BFEE74E73F464012DA722EC55F4840
5346	416	44.421348999999999	44.430008999999998	48.636254000000001	48.598612000000003	64-й Армии улица	0103000020E61000000100000005000000E59997C3EE354640207F69519F4C4840E59997C3EE3546407FF964C5705148402AFEEF880A3746407FF964C5705148402AFEEF880A374640207F69519F4C4840E59997C3EE354640207F69519F4C4840
27589	416	44.421348999999999	44.430008999999998	48.636254000000001	48.598612000000003	64-й Армии	0103000020E61000000100000005000000E59997C3EE354640207F69519F4C4840E59997C3EE3546407FF964C5705148402AFEEF880A3746407FF964C5705148402AFEEF880A374640207F69519F4C4840E59997C3EE354640207F69519F4C4840
27588	416	44.473461	44.507883999999997	48.768897000000003	48.766824999999997	51-й Гвардейской Дивизии	0103000020E610000001000000050000003A77BB5E9A3C4640AA605452276248403A77BB5E9A3C46400B7F86376B624840B114C957024146400B7F86376B624840B114C95702414640AA605452276248403A77BB5E9A3C4640AA60545227624840
27705	416	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	50 Лет Октября	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
27533	416	44.596691999999997	44.603833000000002	48.524231999999998	48.520561999999998	2-я Штурманская	0103000020E6100000010000000500000075E44867604C46402AC58EC6A142484075E44867604C464022C2BF081A4348406F9F55664A4D464022C2BF081A4348406F9F55664A4D46402AC58EC6A142484075E44867604C46402AC58EC6A1424840
27687	416	44.574584000000002	44.584285999999999	48.518062	48.511485	2-я Динамовская	0103000020E610000001000000050000000667F0F78B49464081B22957784148400667F0F78B49464072A609DB4F4248405DC136E2C94A464072A609DB4F4248405DC136E2C94A464081B22957784148400667F0F78B49464081B2295778414840
27556	416	44.473928000000001	44.490141999999999	48.741883999999999	48.729899000000003	 Хорошева	0103000020E61000000100000005000000505436ACA93C46400A3197546D5D4840505436ACA93C46407CB60E0EF65E4840B1321AF9BC3E46407CB60E0EF65E4840B1321AF9BC3E46400A3197546D5D4840505436ACA93C46400A3197546D5D4840
27607	416	44.487582000000003	44.530728000000003	48.751911999999997	48.707572999999996	 Рокоссовского	0103000020E61000000100000005000000240F4416693E46402C4487C0915A4840240F4416693E464027BC04A73E604840278925E5EE43464027BC04A73E604840278925E5EE4346402C4487C0915A4840240F4416693E46402C4487C0915A4840
27574	416	44.538229000000001	44.548909999999999	48.767437000000001	48.754857999999999	 Репина	0103000020E61000000100000005000000206118B0E4444640DE8FDB2F9F604840206118B0E4444640C45E28603B6248404339D1AE42464640C45E28603B6248404339D1AE42464640DE8FDB2F9F604840206118B0E4444640DE8FDB2F9F604840
27640	416	44.426693999999998	44.438578999999997	48.586205	48.574212000000003	 Писемского	0103000020E6100000010000000500000020B3B3E89D364640427C60C77F49484020B3B3E89D36464037E0F3C3084B48402FDB4E5B2338464037E0F3C3084B48402FDB4E5B23384640427C60C77F49484020B3B3E89D364640427C60C77F494840
27622	416	44.569913	44.579155999999998	48.786999000000002	48.781270999999997	 Пельше	0103000020E610000001000000050000005A48C0E8F2484640172829B0006448405A48C0E8F24846400B7E1B62BC6448401EA4A7C8214A46400B7E1B62BC6448401EA4A7C8214A4640172829B0006448405A48C0E8F2484640172829B000644840
27557	416	44.507461999999997	44.527171000000003	48.723801000000002	48.712536999999998	 Пархоменко	0103000020E610000001000000050000003BFBCA83F440464050189469345B48403BFBCA83F4404640F3E7DB82A55C48402733DE567A434640F3E7DB82A55C48402733DE567A43464050189469345B48403BFBCA83F440464050189469345B4840
27693	416	44.484447000000003	44.486747000000001	48.698892000000001	48.697279999999999	 Липецкая	0103000020E610000001000000050000009AD2FA5B023E4640D3139678405948409AD2FA5B023E4640D0B7054B755948408B36C7B94D3E4640D0B7054B755948408B36C7B94D3E4640D3139678405948409AD2FA5B023E4640D313967840594840
27628	416	44.424709	44.429352999999999	48.62079	48.586205	 Кирова	0103000020E610000001000000050000008FA850DD5C36464037E0F3C3084B48408FA850DD5C36464088D7F50B764F484041B8020AF536464088D7F50B764F484041B8020AF536464037E0F3C3084B48408FA850DD5C36464037E0F3C3084B4840
27650	416	44.469265999999998	44.526857	48.765287000000001	48.744753000000003	 Землячки	0103000020E61000000100000005000000F78F85E8103C4640884CF910545F4840F78F85E8103C4640E886A6ECF46148409755D80C70434640E886A6ECF46148409755D80C70434640884CF910545F4840F78F85E8103C4640884CF910545F4840
27577	416	44.463569999999997	44.489063999999999	48.710633999999999	48.698428	 Елецкая	0103000020E610000001000000050000000FB40243563B46402B4EB516665948400FB40243563B46407CB60E0EF65A484052D32EA6993E46407CB60E0EF65A484052D32EA6993E46402B4EB516665948400FB40243563B46402B4EB51666594840
27682	416	44.506203999999997	44.524709999999999	48.523594000000003	48.516629999999999	 Арсеньева	0103000020E610000001000000050000005C8DEC4ACB404640F5108DEE204248405C8DEC4ACB404640E030D120054348402CF180B229434640E030D120054348402CF180B229434640F5108DEE204248405C8DEC4ACB404640F5108DEE20424840
27532	416	44.435443999999997	44.441858000000003	48.651029999999999	48.650041999999999	 Академика Королева	0103000020E61000000100000005000000A59E05A1BC3746406283859334534840A59E05A1BC374640815B77F354534840EDBC8DCD8E384640815B77F354534840EDBC8DCD8E3846406283859334534840A59E05A1BC3746406283859334534840
27570	416	44.266883999999997	44.718026999999999	48.888952000000003	48.450364	 40 Лет ВЛКСМ	0103000020E61000000100000005000000AFE9414129224640DBA50D87A5394840AFE94141292246405EDBDB2DC97148408F52094FE85B46405EDBDB2DC97148408F52094FE85B4640DBA50D87A5394840AFE9414129224640DBA50D87A5394840
27442	51656	44.647284999999997	44.670873999999998	48.713166999999999	48.698481000000001	Школьная	0103000020E610000001000000050000007E18213CDA5246404EF04DD3675948407E18213CDA52464010CB660E495B48404CDE0033DF55464010CB660E495B48404CDE0033DF5546404EF04DD3675948407E18213CDA5246404EF04DD367594840
26435	11109	42.205852	42.261512000000003	48.438262000000002	48.404305000000001	Цимлянская	0103000020E6100000010000000500000079E8BB5B591A4540FD4D2844C033484079E8BB5B591A45402F8A1EF8183848407BC1A739792145402F8A1EF8183848407BC1A73979214540FD4D2844C033484079E8BB5B591A4540FD4D2844C0334840
27062	11109	42.205852	42.261512000000003	48.438262000000002	48.404305000000001	Советская	0103000020E6100000010000000500000079E8BB5B591A4540FD4D2844C033484079E8BB5B591A45402F8A1EF8183848407BC1A739792145402F8A1EF8183848407BC1A73979214540FD4D2844C033484079E8BB5B591A4540FD4D2844C0334840
26645	11109	42.205852	42.261512000000003	48.438262000000002	48.404305000000001	Ленина	0103000020E6100000010000000500000079E8BB5B591A4540FD4D2844C033484079E8BB5B591A45402F8A1EF8183848407BC1A739792145402F8A1EF8183848407BC1A73979214540FD4D2844C033484079E8BB5B591A4540FD4D2844C0334840
26903	11109	42.205852	42.261512000000003	48.438262000000002	48.404305000000001	2-я Гвардейская	0103000020E6100000010000000500000079E8BB5B591A4540FD4D2844C033484079E8BB5B591A45402F8A1EF8183848407BC1A739792145402F8A1EF8183848407BC1A73979214540FD4D2844C033484079E8BB5B591A4540FD4D2844C0334840
27675	51722	42.656680999999999	42.719059999999999	48.186331000000003	48.161310999999998	Октябрьская	0103000020E61000000100000005000000C9737D1F0E54454016BEBED6A5144840C9737D1F0E544540919DB7B1D91748404EEE77280A5C4540919DB7B1D91748404EEE77280A5C454016BEBED6A5144840C9737D1F0E54454016BEBED6A5144840
27659	51719	42.272525000000002	42.297238	48.152614	48.137151000000003	Советская	0103000020E61000000100000005000000D42B6519E22245408ECEF9298E114840D42B6519E2224540B47405DB88134840719010E50B264540B47405DB88134840719010E50B2645408ECEF9298E114840D42B6519E22245408ECEF9298E114840
27372	51627	42.130690000000001	42.144101999999997	48.148429999999998	48.141810999999997	Гагарина	0103000020E6100000010000000500000006F52D73BA104540459BE3DC2612484006F52D73BA10454065DF15C1FF124840E3A430EF7112454065DF15C1FF124840E3A430EF71124540459BE3DC2612484006F52D73BA104540459BE3DC26124840
27521	51689	42.124347999999998	42.897708000000002	48.502752000000001	47.898296999999999	Ленина	0103000020E6100000010000000500000058A9A0A2EA0F4540268C6665FBF2474058A9A0A2EA0F4540D2FF722D5A404840C5AD8218E8724540D2FF722D5A404840C5AD8218E8724540268C6665FBF2474058A9A0A2EA0F4540268C6665FBF24740
26964	11483	42.271286000000003	42.304532000000002	48.411267000000002	48.392969000000001	Советская	0103000020E610000001000000050000006CEEE87FB9224540C1ABE5CE4C3248406CEEE87FB92245404776A565A4344840F14A92E7FA2645404776A565A4344840F14A92E7FA264540C1ABE5CE4C3248406CEEE87FB9224540C1ABE5CE4C324840
27518	51687	42.348818999999999	42.364998	48.314469000000003	48.300620000000002	Школьная	0103000020E61000000100000005000000999CDA19A62C4540034356B77A264840999CDA19A62C45408C4D2B85402848407E8D2441B82E45408C4D2B85402848407E8D2441B82E4540034356B77A264840999CDA19A62C4540034356B77A264840
27483	51671	42.234338000000001	42.262903999999999	48.256278000000002	48.230386000000003	Октябрьская	0103000020E61000000100000005000000E31A9FC9FE1D454067BAD7497D1D4840E31A9FC9FE1D45409757AEB7CD20484069FE98D6A62145409757AEB7CD20484069FE98D6A621454067BAD7497D1D4840E31A9FC9FE1D454067BAD7497D1D4840
26800	51357	42.432093000000002	42.469391000000002	48.492387000000001	48.481239000000002	Горбункова	0103000020E610000001000000050000004FEACBD24E374540A647533D993D48404FEACBD24E374540DFFC8689063F4840B4041901153C4540DFFC8689063F4840B4041901153C4540A647533D993D48404FEACBD24E374540A647533D993D4840
26910	11785	42.249070000000003	42.301963000000001	48.177264999999998	48.153480000000002	пл. Центральная	0103000020E6100000010000000500000016359886E11F4540884B8E3BA513484016359886E11F4540DBDC989EB016484010CD3CB9A6264540DBDC989EB016484010CD3CB9A6264540884B8E3BA513484016359886E11F4540884B8E3BA5134840
27561	51704	42.620820000000002	42.673641000000003	48.259523000000002	48.226832999999999	Октябрьская	0103000020E61000000100000005000000F3599E07774F4540A8531EDD081D4840F3599E07774F4540A8C7B60C38214840541F48DE39564540A8C7B60C38214840541F48DE39564540A8531EDD081D4840F3599E07774F4540A8531EDD081D4840
26959	51397	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	40 Лет Октября	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27389	51633	43.717564000000003	43.731856999999998	50.07564	50.061092000000002	Центральная	0103000020E61000000100000005000000BB641C23D9DB45400C06D7DCD1074940BB641C23D9DB45407D224F92AE094940A12C7C7DADDD45407D224F92AE094940A12C7C7DADDD45400C06D7DCD1074940BB641C23D9DB45400C06D7DCD1074940
27141	51501	43.758132000000003	43.781156000000003	49.758603999999998	49.744059	Калиновский переулок	0103000020E610000001000000050000008A0629780AE14540B1A547533DDF48408A0629780AE14540B14E95EF19E148407F8978EBFCE34540B14E95EF19E148407F8978EBFCE34540B1A547533DDF48408A0629780AE14540B1A547533DDF4840
27064	51462	43.580041000000001	43.687947000000001	49.804358999999998	49.735059	40 Лет Октября	0103000020E6100000010000000500000069AB92C83ECA4540B3D0CE6916DE484069AB92C83ECA4540239F573CF5E64840CF30B5A50ED84540239F573CF5E64840CF30B5A50ED84540B3D0CE6916DE484069AB92C83ECA4540B3D0CE6916DE4840
27386	51634	42.035010999999997	42.064233000000002	50.840077000000001	50.825347999999998	Школьная	0103000020E6100000010000000500000008008E3D7B044540D5E8D500A569494008008E3D7B044540978FA4A4876B4940782975C938084540978FA4A4876B4940782975C938084540D5E8D500A569494008008E3D7B044540D5E8D500A5694940
27378	51623	41.941657999999997	41.996930999999996	50.761612999999997	50.744916000000003	Ленина	0103000020E610000001000000050000002502D53F88F8444032225168595F49402502D53F88F84440AE9AE7887C6149402DAF5C6F9BFF4440AE9AE7887C6149402DAF5C6F9BFF444032225168595F49402502D53F88F8444032225168595F4940
27401	51642	41.994919000000003	42.076045999999998	50.826093	50.807479000000001	Комарова	0103000020E61000000100000005000000A3957B8159FF4440789ACC785B674940A3957B8159FF44402E3A596ABD694940ED7E15E0BB0945402E3A596ABD694940ED7E15E0BB094540789ACC785B674940A3957B8159FF4440789ACC785B674940
27468	51666	41.884605999999998	41.917574000000002	50.973087	50.948630000000001	Октябрьская	0103000020E6100000010000000500000035ECF7C43AF14440930035B56C79494035ECF7C43AF14440D594641D8E7C494078D4981073F54440D594641D8E7C494078D4981073F54440930035B56C79494035ECF7C43AF14440930035B56C794940
27304	51598	42.073557999999998	42.102097000000001	50.848362999999999	50.834974000000003	Центральная	0103000020E61000000100000005000000F92D3A596A0945405281936DE06A4940F92D3A596A0945407711A628976C49408602B683110D45407711A628976C49408602B683110D45405281936DE06A4940F92D3A596A0945405281936DE06A4940
26771	51337	42.068527000000003	42.096896000000001	50.770699999999998	50.756450000000001	Юбилейная	0103000020E610000001000000050000004EF2237EC50845409487855AD36049404EF2237EC50845407B832F4CA66249407E8E8F16670C45407B832F4CA66249407E8E8F16670C45409487855AD36049404EF2237EC50845409487855AD3604940
26385	51261	41.820349	41.862202000000003	50.834474	50.799855999999998	Красноармейская	0103000020E6100000010000000500000035272F3201E9444033C170AE6166494035272F3201E9444060AE450BD06A4940DD4598A25CEE444060AE450BD06A4940DD4598A25CEE444033C170AE6166494035272F3201E9444033C170AE61664940
26871	7598	42.802270999999998	42.920292000000003	48.627524999999999	48.584100999999997	Шоссейная	0103000020E61000000100000005000000BDC3EDD0B0664540CB4752D2C34A4840BDC3EDD0B066454011363CBD525048409E62D520CC75454011363CBD525048409E62D520CC754540CB4752D2C34A4840BDC3EDD0B0664540CB4752D2C34A4840
27061	7598	42.802270999999998	42.920292000000003	48.627524999999999	48.584100999999997	Советская	0103000020E61000000100000005000000BDC3EDD0B0664540CB4752D2C34A4840BDC3EDD0B066454011363CBD525048409E62D520CC75454011363CBD525048409E62D520CC754540CB4752D2C34A4840BDC3EDD0B0664540CB4752D2C34A4840
26631	7598	42.802270999999998	42.920292000000003	48.627524999999999	48.584100999999997	Ленина	0103000020E61000000100000005000000BDC3EDD0B0664540CB4752D2C34A4840BDC3EDD0B066454011363CBD525048409E62D520CC75454011363CBD525048409E62D520CC754540CB4752D2C34A4840BDC3EDD0B0664540CB4752D2C34A4840
27444	7598	42.802270999999998	42.920292000000003	48.627524999999999	48.584100999999997	Звездина	0103000020E61000000100000005000000BDC3EDD0B0664540CB4752D2C34A4840BDC3EDD0B066454011363CBD525048409E62D520CC75454011363CBD525048409E62D520CC754540CB4752D2C34A4840BDC3EDD0B0664540CB4752D2C34A4840
27194	9183	43.497225999999998	43.519198000000003	48.636069999999997	48.621504000000002	Центральная	0103000020E61000000100000005000000465C001AA5BF4540A62A6D718D4F4840465C001AA5BF4540BDFBE3BD6A51484006137F1475C24540BDFBE3BD6A51484006137F1475C24540A62A6D718D4F4840465C001AA5BF4540A62A6D718D4F4840
27463	8007	42.908226999999997	42.933765999999999	48.654744000000001	48.635843000000001	Раздольная	0103000020E610000001000000050000000E2C47C840744540FD31AD4D635148400E2C47C84074454049A0C1A6CE534840F10EF0A48577454049A0C1A6CE534840F10EF0A485774540FD31AD4D635148400E2C47C840744540FD31AD4D63514840
27186	51529	44.602522	44.628869000000002	48.654046999999998	48.645059000000003	Базовский переулок	0103000020E610000001000000050000006D8FDE701F4D4640C87E164B915248406D8FDE701F4D46400186E5CFB7534840EF3B86C77E5046400186E5CFB7534840EF3B86C77E504640C87E164B915248406D8FDE701F4D4640C87E164B91524840
26588	51302	44.842632000000002	44.857534999999999	48.591914000000003	48.582890999999996	Придорожная	0103000020E610000001000000050000001348895DDB6B4640FD101B2C9C4A48401348895DDB6B4640B40584D6C34B48407216F6B4C36D4640B40584D6C34B48407216F6B4C36D4640FD101B2C9C4A48401348895DDB6B4640FD101B2C9C4A4840
27523	51691	44.609268	44.628779000000002	48.632646000000001	48.620593	Центральная	0103000020E61000000100000005000000EA3F6B7EFC4D4640329067976F4F4840EA3F6B7EFC4D4640FDF84B8BFA504840AFB48CD47B504640FDF84B8BFA504840AFB48CD47B504640329067976F4F4840EA3F6B7EFC4D4640329067976F4F4840
27541	51699	44.875708000000003	44.918019000000001	48.623821	48.610551000000001	Советская	0103000020E610000001000000050000003C6C22331770464022C50089264E48403C6C2233177046406DC7D45DD94F4840A60D87A5817546406DC7D45DD94F4840A60D87A58175464022C50089264E48403C6C22331770464022C50089264E4840
27540	51699	44.875708000000003	44.918019000000001	48.623821	48.610551000000001	Молодежная	0103000020E610000001000000050000003C6C22331770464022C50089264E48403C6C2233177046406DC7D45DD94F4840A60D87A5817546406DC7D45DD94F4840A60D87A58175464022C50089264E48403C6C22331770464022C50089264E4840
26937	5600	44.933883000000002	44.946154	48.724449	48.716894000000003	Совхозная	0103000020E610000001000000050000002BA5677A897746406D59BE2EC35B48402BA5677A89774640594FADBEBA5C4840637D03931B794640594FADBEBA5C4840637D03931B7946406D59BE2EC35B48402BA5677A897746406D59BE2EC35B4840
26546	4067	44.852074000000002	44.862834999999997	48.722529000000002	48.712465000000002	микрорайон	0103000020E61000000100000005000000CEE2C5C2106D4640B745990D325B4840CEE2C5C2106D4640AFB48CD47B5C48400D6C9560716E4640AFB48CD47B5C48400D6C9560716E4640B745990D325B4840CEE2C5C2106D4640B745990D325B4840
26972	4067	44.548236000000003	45.581280999999997	49.231023	48.486888	Садовая	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
26816	4067	44.548236000000003	45.581280999999997	49.231023	48.486888	Партизанская	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
26735	4067	44.863095999999999	44.866616999999998	48.716828999999997	48.713524	Гагарина	0103000020E610000001000000050000007AA702EE796E46409F7422C1545B48407AA702EE796E464085E97B0DC15B48402D944C4EED6E464085E97B0DC15B48402D944C4EED6E46409F7422C1545B48407AA702EE796E46409F7422C1545B4840
26736	4067	44.548236000000003	45.581280999999997	49.231023	48.486888	Воровкого	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
27670	51721	44.770829999999997	44.802280000000003	48.559038999999999	48.548549000000001	Новостройка	0103000020E610000001000000050000004963B48EAA62464073A087DA364648404963B48EAA624640221807978E474840111E6D1CB1664640221807978E474840111E6D1CB166464073A087DA364648404963B48EAA62464073A087DA36464840
27305	6014	44.910949000000002	44.932831999999998	49.029874999999997	49.003664000000001	Советская	0103000020E6100000010000000500000076A911FA997446401616DC0F7880484076A911FA99744640E7FBA9F1D2834840C554FA0967774640E7FBA9F1D2834840C554FA09677746401616DC0F7880484076A911FA997446401616DC0F78804840
26433	45891	44.548236000000003	45.581280999999997	49.231023	48.486888	Приканальная	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
27128	5374	44.719149999999999	44.725124000000001	48.578218	48.570307999999997	Новая	0103000020E610000001000000050000008E75711B0D5C4640D65240DAFF4848408E75711B0D5C4640B1FA230C034A4840B9C5FCDCD05C4640B1FA230C034A4840B9C5FCDCD05C4640D65240DAFF4848408E75711B0D5C4640D65240DAFF484840
27024	51434	44.548236000000003	45.581280999999997	49.231023	48.486888	Солнечная	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
27530	51695	45.142167000000001	45.164247000000003	48.954267000000002	48.938971000000002	Школьная	0103000020E6100000010000000500000004C93B87329246403B72A4333078484004C93B87329246407653CA6B257A4840AABBB20B069546407653CA6B257A4840AABBB20B069546403B72A4333078484004C93B87329246403B72A43330784840
26821	47815	44.839568999999997	44.866492000000001	48.686849000000002	48.672142999999998	Турусова	0103000020E6100000010000000500000022DE3AFF766B46401F9E25C80856484022DE3AFF766B4640292504ABEA574840711FB935E96E4640292504ABEA574840711FB935E96E46401F9E25C80856484022DE3AFF766B46401F9E25C808564840
26680	48202	44.883380000000002	44.902298000000002	48.688865	48.672029999999999	Школьная	0103000020E6100000010000000500000062F888981271464027F73B140556484062F8889812714640F52D73BA2C584840849F38807E734640F52D73BA2C584840849F38807E73464027F73B140556484062F888981271464027F73B1405564840
27206	51430	45.291628000000003	45.322153	49.092367000000003	49.070971	Рыжовой	0103000020E61000000100000005000000884CF91054A5464072FBE59315894840884CF91054A54640651D8EAED28B484076A73B4F3CA94640651D8EAED28B484076A73B4F3CA9464072FBE59315894840884CF91054A5464072FBE59315894840
26990	47533	44.548236000000003	45.581280999999997	49.231023	48.486888	Шестакова	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
26919	47533	44.548236000000003	45.581280999999997	49.231023	48.486888	Тимирязева	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
26718	47533	44.548236000000003	45.581280999999997	49.231023	48.486888	Свердлова	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
26812	47533	44.559303999999997	44.602387	48.708976	48.704065	Ленина	0103000020E61000000100000005000000D0420246974746400EA14ACD1E5A4840D0420246974746400FD3BEB9BF5A48408D4468041B4D46400FD3BEB9BF5A48408D4468041B4D46400EA14ACD1E5A4840D0420246974746400EA14ACD1E5A4840
26834	47533	44.505637999999998	44.611711	48.808916000000004	48.700491	В. И. Ленина	0103000020E61000000100000005000000B3CEF8BEB8404640381268B0A9594840B3CEF8BEB8404640079B3A8F8A6748403ECDC98B4C4E4640079B3A8F8A6748403ECDC98B4C4E4640381268B0A9594840B3CEF8BEB8404640381268B0A9594840
27355	51620	44.853591999999999	44.865251999999998	48.646892999999999	48.638058000000001	улица Центральная	0103000020E610000001000000050000004910AE80426D4640C07971E2AB5148404910AE80426D46407381CB63CD5248403866D993C06E46407381CB63CD5248403866D993C06E4640C07971E2AB5148404910AE80426D4640C07971E2AB514840
26740	4570	44.548236000000003	45.581280999999997	49.231023	48.486888	Центральная	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
27113	4570	44.548236000000003	45.581280999999997	49.231023	48.486888	Веселая	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
27649	51718	44.679408000000002	44.728717000000003	48.604171000000001	48.590620999999999	Советская	0103000020E61000000100000005000000055262D7F656464058AA0B78994B4840055262D7F65646408718AF79554D484006854199465D46408718AF79554D484006854199465D464058AA0B78994B4840055262D7F656464058AA0B78994B4840
26562	4648	44.548236000000003	45.581280999999997	49.231023	48.486888	 Тракторозаводская	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
27110	51491	44.926426999999997	44.956530000000001	48.676284000000003	48.664800999999997	Калинина	0103000020E61000000100000005000000D190F128957646408EACFC3218554840D190F128957646406F675F79905648404AD235936F7A46406F675F79905648404AD235936F7A46408EACFC3218554840D190F128957646408EACFC3218554840
27119	47990	44.917012999999997	44.930594999999997	48.820283000000003	48.810102999999998	Школьная	0103000020E61000000100000005000000E08096AE607546401CB28174B1674840E08096AE607546407E3B8908FF6848401A69A9BC1D7746407E3B8908FF6848401A69A9BC1D7746401CB28174B1674840E08096AE607546401CB28174B1674840
27331	51608	44.658720000000002	44.675257999999999	48.688014000000003	48.667687000000001	Ленина	0103000020E610000001000000050000004E9CDCEF50544640707B82C4765548404E9CDCEF505446405798BED710584840622EA9DA6E5646405798BED710584840622EA9DA6E564640707B82C4765548404E9CDCEF50544640707B82C476554840
26721	47688	44.548236000000003	44.566175999999999	48.674452000000002	48.658206999999997	Молодежная	0103000020E61000000100000005000000B43EE5982C464640C77F812040544840B43EE5982C464640645C717154564840DAE3857478484640645C717154564840DAE3857478484640C77F812040544840B43EE5982C464640C77F812040544840
26743	4766	44.548236000000003	45.581280999999997	49.231023	48.486888	Центральная	0103000020E61000000100000005000000B43EE5982C4646404D689258523E4840B43EE5982C464640D9CF6229929D4840A164726A67CA4640D9CF6229929D4840A164726A67CA46404D689258523E4840B43EE5982C4646404D689258523E4840
26468	5913	44.700743000000003	44.738239	48.665788999999997	48.641368	Школьная	0103000020E6100000010000000500000052F355F2B1594640B859BC581852484052F355F2B1594640AD84EE9238554840DDD0949D7E5E4640AD84EE9238554840DDD0949D7E5E4640B859BC581852484052F355F2B1594640B859BC5818524840
27227	3360	42.708047000000001	42.758361000000001	49.591715000000001	49.559604	Подтелкова	0103000020E61000000100000005000000F583BA48A15A4540FB5A971AA1C74840F583BA48A15A4540BDC62E51BDCB4840EBC726F911614540BDC62E51BDCB4840EBC726F911614540FB5A971AA1C74840F583BA48A15A4540FB5A971AA1C74840
26549	3360	42.708047000000001	42.758361000000001	49.591715000000001	49.559604	Октябрьская	0103000020E61000000100000005000000F583BA48A15A4540FB5A971AA1C74840F583BA48A15A4540BDC62E51BDCB4840EBC726F911614540BDC62E51BDCB4840EBC726F911614540FB5A971AA1C74840F583BA48A15A4540FB5A971AA1C74840
26716	3360	42.708047000000001	42.758361000000001	49.591715000000001	49.559604	68-Гвардейская	0103000020E61000000100000005000000F583BA48A15A4540FB5A971AA1C74840F583BA48A15A4540BDC62E51BDCB4840EBC726F911614540BDC62E51BDCB4840EBC726F911614540FB5A971AA1C74840F583BA48A15A4540FB5A971AA1C74840
27470	51665	42.353284000000002	42.391840000000002	49.454225000000001	49.433537000000001	 Центральная	0103000020E610000001000000050000009C19FD68382D4540904DF2237EB748409C19FD68382D45404703780B24BA4840E0A128D0273245404703780B24BA4840E0A128D027324540904DF2237EB748409C19FD68382D4540904DF2237EB74840
27379	51628	\N	\N	\N	\N	Ленина	\N
27284	970	44.353454999999997	44.387805999999998	48.452432000000002	48.432307999999999	Клубная	0103000020E61000000100000005000000C8CD70033E2D46404BE658DE55374840C8CD70033E2D4640FAD4B14AE9394840A69883A0A3314640FAD4B14AE9394840A69883A0A33146404BE658DE55374840C8CD70033E2D46404BE658DE55374840
26857	8982	44.662385	44.697105000000001	48.211032000000003	48.181201000000001	18 ГМП	0103000020E61000000100000005000000342E1C08C95446405280289831174840342E1C08C95446406A34B918031B4840657094BC3A5946406A34B918031B4840657094BC3A5946405280289831174840342E1C08C95446405280289831174840
26805	51362	44.087491	44.122695999999998	48.144865000000003	48.127006000000002	Сердюкова	0103000020E61000000100000005000000E0D8B3E7320B4640A9328CBB41104840E0D8B3E7320B4640E3AAB2EF8A124840CDACA580B40F4640E3AAB2EF8A124840CDACA580B40F4640A9328CBB41104840E0D8B3E7320B4640A9328CBB41104840
27049	51451	44.042431000000001	44.081059000000003	48.330573000000001	48.309663	Школьная	0103000020E6100000010000000500000015AB06616E05464000E48409A327484015AB06616E05464066F84F37502A4840F3052D24600A464066F84F37502A4840F3052D24600A464000E48409A327484015AB06616E05464000E48409A3274840
26688	32203	44.728473999999999	44.804220000000001	48.487096999999999	48.453477999999997	Сидорова	0103000020E610000001000000050000003FFED2A23E5D46404DBA2D910B3A48403FFED2A23E5D4640677DCA31593E4840026553AEF0664640677DCA31593E4840026553AEF06646404DBA2D910B3A48403FFED2A23E5D46404DBA2D910B3A4840
26798	32203	44.728473999999999	44.804220000000001	48.487096999999999	48.453477999999997	Переулок Зеленый	0103000020E610000001000000050000003FFED2A23E5D46404DBA2D910B3A48403FFED2A23E5D4640677DCA31593E4840026553AEF0664640677DCA31593E4840026553AEF06646404DBA2D910B3A48403FFED2A23E5D46404DBA2D910B3A4840
26983	32203	44.728473999999999	44.804220000000001	48.487096999999999	48.453477999999997	Мелиоративная	0103000020E610000001000000050000003FFED2A23E5D46404DBA2D910B3A48403FFED2A23E5D4640677DCA31593E4840026553AEF0664640677DCA31593E4840026553AEF06646404DBA2D910B3A48403FFED2A23E5D46404DBA2D910B3A4840
27267	32203	44.728473999999999	44.804220000000001	48.487096999999999	48.453477999999997	1 микрорайон	0103000020E610000001000000050000003FFED2A23E5D46404DBA2D910B3A48403FFED2A23E5D4640677DCA31593E4840026553AEF0664640677DCA31593E4840026553AEF06646404DBA2D910B3A48403FFED2A23E5D46404DBA2D910B3A4840
27262	173	44.881044000000003	44.945678000000001	48.429696	48.413803000000001	Советская	0103000020E61000000100000005000000242BBF0CC67046404CFE277FF7344840242BBF0CC67046406B9C4D4700374840FA4509FA0B7946406B9C4D4700374840FA4509FA0B7946404CFE277FF7344840242BBF0CC67046404CFE277FF7344840
26899	46559	44.273217000000002	44.287258000000001	48.322132000000003	48.308998000000003	Набережная	0103000020E610000001000000050000000ADB4FC6F8224640C443183F8D2748400ADB4FC6F82246405F7F129F3B294840D7C1C1DEC42446405F7F129F3B294840D7C1C1DEC4244640C443183F8D2748400ADB4FC6F8224640C443183F8D274840
27035	45700	44.073441000000003	44.192818000000003	48.240425999999999	48.148496000000002	переулок Школьный	0103000020E61000000100000005000000C097C283660946401DCBBBEA01134840C097C28366094640D68D7747C61E4840420A9E42AE184640D68D7747C61E4840420A9E42AE1846401DCBBBEA01134840C097C283660946401DCBBBEA01134840
26689	46462	44.560516	44.589872999999997	48.245472999999997	48.230181999999999	Школьная	0103000020E610000001000000050000003F7100FDBE4746405E10919A761D48403F7100FDBE4746408786C5A86B1F48408EE55DF5804B46408786C5A86B1F48408EE55DF5804B46405E10919A761D48403F7100FDBE4746405E10919A761D4840
26977	46555	44.191353999999997	44.218671999999998	48.485621999999999	48.472321000000001	Дружбы	0103000020E61000000100000005000000B9FAB1497E184640651BB803753C4840B9FAB1497E184640EB1B98DC283E48408446B071FD1B4640EB1B98DC283E48408446B071FD1B4640651BB803753C4840B9FAB1497E184640651BB803753C4840
26684	403	44.571323	44.580773000000001	48.458945	48.440061	Школьная	0103000020E61000000100000005000000EF39B01C214946405E9F39EB53384840EF39B01C21494640D4D4B2B5BE3A48402DB308C5564A4640D4D4B2B5BE3A48402DB308C5564A46405E9F39EB53384840EF39B01C214946405E9F39EB53384840
27090	46480	44.474395000000001	44.510184000000002	48.224966000000002	48.215792999999998	Красных Зорь	0103000020E610000001000000050000006631B1F9B83C464055DAE21A9F1B48406631B1F9B83C4640215B96AFCB1C4840A37895B54D414640215B96AFCB1C4840A37895B54D41464055DAE21A9F1B48406631B1F9B83C464055DAE21A9F1B4840
27092	46508	44.245108999999999	44.265293999999997	48.174970000000002	48.162038000000003	Чапаева	0103000020E61000000100000005000000467A51BB5F1F4640C95A43A9BD144840467A51BB5F1F4640FCE3BD6A651648409AE95E27F5214640FCE3BD6A651648409AE95E27F5214640C95A43A9BD144840467A51BB5F1F4640C95A43A9BD144840
26763	46658	43.926189000000001	45.073948999999999	48.584589999999999	48.054220000000001	Школьная	0103000020E610000001000000050000001D75745C8DF64540026553AEF00648401D75745C8DF64540C9C859D8D34A484034492C2977894640C9C859D8D34A484034492C2977894640026553AEF00648401D75745C8DF64540026553AEF0064840
27230	51550	43.926189000000001	45.073948999999999	48.584589999999999	48.054220000000001	Кирова	0103000020E610000001000000050000001D75745C8DF64540026553AEF00648401D75745C8DF64540C9C859D8D34A484034492C2977894640C9C859D8D34A484034492C2977894640026553AEF00648401D75745C8DF64540026553AEF0064840
27248	51565	44.378644000000001	44.388103000000001	48.430627999999999	48.417205000000003	Привокзальная	0103000020E61000000100000005000000CF69166877304640255D33F966354840CF69166877304640F65E7CD11E374840603DEE5BAD314640F65E7CD11E374840603DEE5BAD314640255D33F966354840CF69166877304640255D33F966354840
27177	489	44.605665999999999	44.636361000000001	48.349043000000002	48.312707000000003	Октябрьская	0103000020E610000001000000050000004A26A776864D46407A1D71C8062848404A26A776864D4640E9F2E670AD2C484095B9F94674514640E9F2E670AD2C484095B9F946745146407A1D71C8062848404A26A776864D46407A1D71C806284840
26842	305	44.565061999999998	44.596108000000001	48.438769999999998	48.400854000000002	Ильина	0103000020E610000001000000050000002E1B9DF353484640433C122F4F3348402E1B9DF353484640A33B889D29384840267156444D4C4640A33B889D29384840267156444D4C4640433C122F4F3348402E1B9DF353484640433C122F4F334840
26673	31945	44.460479999999997	44.510247	50.652484000000001	50.637028000000001	Советская	0103000020E61000000100000005000000253B3602F13A464072512D228A514940253B3602F13A4640E694809884534940E9F010C64F414640E694809884534940E9F010C64F41464072512D228A514940253B3602F13A464072512D228A514940
26976	32170	44.253301999999998	44.291552000000003	50.805281000000001	50.786732000000001	Мирная	0103000020E6100000010000000500000075012F336C204640BC5B59A2B364494075012F336C2046408B8BA37213674940AD8A7093512546408B8BA37213674940AD8A709351254640BC5B59A2B364494075012F336C204640BC5B59A2B3644940
26779	31540	44.571376999999998	44.583882000000003	50.872503999999999	50.866393000000002	Новая	0103000020E61000000100000005000000E257ACE122494640DE3D40F7E56E4940E257ACE12249464089D00836AE6F49408E5C37A5BC4A464089D00836AE6F49408E5C37A5BC4A4640DE3D40F7E56E4940E257ACE122494640DE3D40F7E56E4940
27252	51569	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	Строителей	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
27255	51569	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	Советская	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
75600	51569	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	Горная	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
26632	31297	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	Октябрьская 	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
26425	31297	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	Комсомольская	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
26463	31297	44.500635000000003	44.598210000000002	50.834223000000001	50.786385000000003	Володарского	0103000020E61000000100000005000000D21DC4CE1440464051888043A8644940D21DC4CE144046401749BBD1C76A4940F1113125924C46401749BBD1C76A4940F1113125924C464051888043A8644940D21DC4CE1440464051888043A8644940
26974	32095	44.545262999999998	44.576515000000001	50.893013000000003	50.878079	Полевая	0103000020E61000000100000005000000035C902DCB454640F62686E464704940035C902DCB45464091F3FE3F4E724940A453573ECB49464091F3FE3F4E724940A453573ECB494640F62686E464704940035C902DCB454640F62686E464704940
26975	32034	44.494373000000003	44.521700000000003	50.959721999999999	50.940486	Мирная	0103000020E6100000010000000500000041834D9D473F4640452C62D86178494041834D9D473F464038A0A52BD87A49405F29CB10C742464038A0A52BD87A49405F29CB10C7424640452C62D86178494041834D9D473F4640452C62D861784940
26682	31715	44.389198999999998	44.415734999999998	50.544925999999997	50.530551000000003	Пролетарская	0103000020E610000001000000050000006551D845D131464018EE5C18E94349406551D845D1314640BB5E9A22C0454940BA66F2CD36354640BB5E9A22C0454940BA66F2CD3635464018EE5C18E94349406551D845D131464018EE5C18E9434940
27086	32013	44.173997999999997	44.246825000000001	50.860947000000003	50.812755000000003	Московская 	0103000020E61000000100000005000000E2C80391451646408B54185B08684940E2C80391451646406F4BE482336E4940E86A2BF6971F46406F4BE482336E4940E86A2BF6971F46408B54185B08684940E2C80391451646408B54185B08684940
27008	31924	44.432785000000003	44.503743	50.635210999999998	50.615451	Молодёжная	0103000020E610000001000000050000008599B67F653746402FA52E19C74E49408599B67F653746409C8713984E514940624B8FA67A4046409C8713984E514940624B8FA67A4046402FA52E19C74E49408599B67F653746402FA52E19C74E4940
26840	31854	44.462159999999997	44.489809999999999	51.029831000000001	50.996215999999997	Кирова	0103000020E610000001000000050000007AC2120F283B46403FE08101847F49407AC2120F283B464018B49080D18349407BA01518B23E464018B49080D18349407BA01518B23E46403FE08101847F49407AC2120F283B46403FE08101847F4940
27160	31826	44.345370000000003	44.371879	51.009258000000003	50.986612000000001	Майская	0103000020E6100000010000000500000080828B15352C4640ABEB504D497E494080828B15352C4640FA9CBB5D2F814940DB8827BB992F4640FA9CBB5D2F814940DB8827BB992F4640ABEB504D497E494080828B15352C4640ABEB504D497E4940
26685	31781	44.361234000000003	44.417180999999999	50.850746000000001	50.823214	Мира 	0103000020E61000000100000005000000051A6CEA3C2E4640FFCD8B135F694940051A6CEA3C2E4640F699B33EE56C49409CC1DF2F66354640F699B33EE56C49409CC1DF2F66354640FFCD8B135F694940051A6CEA3C2E4640FFCD8B135F694940
26958	31697	44.430584000000003	44.465617999999999	50.595837000000003	50.579481000000001	Молодежная	0103000020E61000000100000005000000271763601D374640A2D3F36E2C4A4940271763601D374640965F0663444C4940E736E15E993B4640965F0663444C4940E736E15E993B4640A2D3F36E2C4A4940271763601D374640A2D3F36E2C4A4940
27081	31649	44.045817999999997	44.124070000000003	50.845092999999999	50.813825000000001	Школьная	0103000020E61000000100000005000000B8C83D5DDD05464067D5E76A2B684940B8C83D5DDD0546400D8AE6012C6C494016359886E10F46400D8AE6012C6C494016359886E10F464067D5E76A2B684940B8C83D5DDD05464067D5E76A2B684940
26896	32122	44.570281000000001	44.598129	50.901631000000002	50.887774	Центральная	0103000020E61000000100000005000000DD43C2F7FE4846409B1E1494A2714940DD43C2F7FE484640A70705A56873494004E5B67D8F4C4640A70705A56873494004E5B67D8F4C46409B1E1494A2714940DD43C2F7FE4846409B1E1494A2714940
26638	30556	46.828915000000002	46.864730999999999	49.140023999999997	49.114285000000002	Калинина	0103000020E61000000100000005000000F91400E3196A474031B610E4A08E4840F91400E3196A4740DA53724EEC9148402F6B6281AF6E4740DA53724EEC9148402F6B6281AF6E474031B610E4A08E4840F91400E3196A474031B610E4A08E4840
26962	30556	46.828915000000002	46.864730999999999	49.140023999999997	49.114285000000002	Вокзальная	0103000020E61000000100000005000000F91400E3196A474031B610E4A08E4840F91400E3196A4740DA53724EEC9148402F6B6281AF6E4740DA53724EEC9148402F6B6281AF6E474031B610E4A08E4840F91400E3196A474031B610E4A08E4840
26535	26585	46.697986	46.722679999999997	50.048859	50.026190999999997	Центральная	0103000020E610000001000000050000006E88F19A575947408A39083A5A0349406E88F19A57594740C18EFF024106494094BC3AC7805C4740C18EFF024106494094BC3AC7805C47408A39083A5A0349406E88F19A575947408A39083A5A034940
27487	51675	46.682265000000001	46.69388	49.992247999999996	49.983623999999999	Школьная	0103000020E610000001000000050000004C1AA37554574740C5C72764E7FD48404C1AA37554574740BDC282FB01FF48409BAC510FD1584740BDC282FB01FF48409BAC510FD1584740C5C72764E7FD48404C1AA37554574740C5C72764E7FD4840
27361	51621	47.155219000000002	47.168892	50.116154000000002	50.107708000000002	Береговая	0103000020E61000000100000005000000E25B5837DE93474040C23060C90D4940E25B5837DE93474059A65F22DE0E49402C47C8409E95474059A65F22DE0E49402C47C8409E95474040C23060C90D4940E25B5837DE93474040C23060C90D4940
27063	51461	47.023805000000003	47.046675999999998	49.941989	49.931784	улица Карпенко	0103000020E610000001000000050000009B3DD00A0C834740D177B7B244F748409B3DD00A0C8347408B18761893F8484009C1AA7AF98547408B18761893F8484009C1AA7AF9854740D177B7B244F748409B3DD00A0C834740D177B7B244F74840
27221	49370	47.071074000000003	47.126545	50.091603999999997	50.056558000000003	Чапаева	0103000020E6100000010000000500000047CCECF318894740E129E44A3D07494047CCECF31889474065170CAEB90B4940753C66A03290474065170CAEB90B4940753C66A032904740E129E44A3D07494047CCECF318894740E129E44A3D074940
27225	49370	47.071074000000003	47.126545	50.091603999999997	50.056558000000003	Гагарина	0103000020E6100000010000000500000047CCECF318894740E129E44A3D07494047CCECF31889474065170CAEB90B4940753C66A03290474065170CAEB90B4940753C66A032904740E129E44A3D07494047CCECF318894740E129E44A3D074940
26565	48783	46.659762000000001	46.684933000000001	50.210040999999997	50.184697999999997	А.Уриха	0103000020E610000001000000050000006092CA14735447407CD11E2FA41749406092CA1473544740D9E89C9FE21A4940C07971E2AB574740D9E89C9FE21A4940C07971E2AB5747407CD11E2FA41749406092CA14735447407CD11E2FA4174940
26641	51312	46.288561000000001	46.321511000000001	49.656556000000002	49.644319000000003	Прудентовская	0103000020E6100000010000000500000056F31C91EF2447408198840B79D2484056F31C91EF2447400DFFE9060AD44840F226BF45272947400DFFE9060AD44840F226BF45272947408198840B79D2484056F31C91EF2447408198840B79D24840
27032	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	площадь Ленина	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
26574	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Юбилейная	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
26849	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Ушакова	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
26948	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Советская	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
26604	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Остравская	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
26848	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Новая	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
27040	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Мира	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
26946	6484	46.862279000000001	46.915090999999997	50.058546999999997	50.035286999999997	Красноармейская	0103000020E61000000100000005000000888384285F6E4740AA7CCF4884044940888384285F6E4740B323D5777E07494095EEAEB321754740B323D5777E07494095EEAEB321754740AA7CCF4884044940888384285F6E4740AA7CCF4884044940
26984	23656	46.773012999999999	46.812395000000002	50.034778000000003	50.022984000000001	Школьная	0103000020E6100000010000000500000001310917F2624740672AC423F102494001310917F2624740664F029B730449408B37328FFC674740664F029B730449408B37328FFC674740672AC423F102494001310917F2624740672AC423F1024940
26485	49408	47.037377999999997	47.067022999999999	50.034303999999999	50.020629	Школьная	0103000020E6100000010000000500000081CB63CDC8844740B22C98F8A302494081CB63CDC88447409D0FCF1264044940378AAC35948847409D0FCF1264044940378AAC3594884740B22C98F8A302494081CB63CDC8844740B22C98F8A3024940
27046	51450	47.191941999999997	47.212595	50.191405000000003	50.174666000000002	Центральная	0103000020E610000001000000050000004A5D328E9198474090DC9A745B1649404A5D328E919847403CA583F57F18494085251E50369B47403CA583F57F18494085251E50369B474090DC9A745B1649404A5D328E9198474090DC9A745B164940
27219	29457	47.310062000000002	47.325763999999999	50.115859999999998	50.109290999999999	Школьная	0103000020E61000000100000005000000BEDD921CB0A74740A25F5B3FFD0D4940BEDD921CB0A7474010751F80D40E4940691B7FA2B2A9474010751F80D40E4940691B7FA2B2A94740A25F5B3FFD0D4940BEDD921CB0A74740A25F5B3FFD0D4940
27214	51546	46.518664000000001	46.552674000000003	49.995525999999998	49.974663	Цветочная	0103000020E6100000010000000500000068CEFA946342474085CFD6C1C1FC484068CEFA9463424740AA285E656DFF4840BDAC8905BE464740AA285E656DFF4840BDAC8905BE46474085CFD6C1C1FC484068CEFA946342474085CFD6C1C1FC4840
26879	45382	46.740583999999998	46.772644999999997	49.548704999999998	49.533956000000003	Мирная	0103000020E610000001000000050000006EF8DD74CB5E474062C092AB58C448406EF8DD74CB5E47406A1327F73BC648407E350708E66247406A1327F73BC648407E350708E662474062C092AB58C448406EF8DD74CB5E474062C092AB58C44840
26764	48208	46.926526000000003	46.947951000000003	49.125239999999998	49.113788999999997	улица Калинина	0103000020E6100000010000000500000065726A679876474080D250A3908E484065726A6798764740551344DD07904840F29A577556794740551344DD07904840F29A57755679474080D250A3908E484065726A679876474080D250A3908E4840
27240	30266	46.835768999999999	46.861407	49.752277999999997	49.732467999999997	Советская	0103000020E610000001000000050000005C01857AFA6A4740EAAEEC82C1DD48405C01857AFA6A474009C03FA54AE04840D2C5A695426E474009C03FA54AE04840D2C5A695426E4740EAAEEC82C1DD48405C01857AFA6A4740EAAEEC82C1DD4840
26863	29985	46.436647999999998	46.464692999999997	49.774047000000003	49.754629999999999	Комсомольская	0103000020E6100000010000000500000091EEE714E43747404D4A41B797E0484091EEE714E43747409148DBF813E348400ED76A0F7B3B47409148DBF813E348400ED76A0F7B3B47404D4A41B797E0484091EEE714E43747404D4A41B797E04840
26859	49391	47.032266999999997	47.047359	50.043444999999998	50.032902999999997	переулок Гоголя	0103000020E61000000100000005000000B9DE3653218447405B785E2A36044940B9DE3653218447405D16139B8F054940EC1516DC0F8647405D16139B8F054940EC1516DC0F8647405B785E2A36044940B9DE3653218447405B785E2A36044940
27158	45398	46.76041	46.785760000000003	49.43844	49.413108999999999	Мира	0103000020E6100000010000000500000093C6681D55614740755776C1E0B4484093C6681D556147400EA14ACD1EB84840A3409FC8936447400EA14ACD1EB84840A3409FC893644740755776C1E0B4484093C6681D55614740755776C1E0B44840
26960	30510	46.805208999999998	46.820058000000003	49.289417999999998	49.276189000000002	Ветеринаров	0103000020E61000000100000005000000F1B8A81611674740EA4141295AA34840F1B8A81611674740D66F26A60BA548405E6919A9F7684740D66F26A60BA548405E6919A9F7684740EA4141295AA34840F1B8A81611674740EA4141295AA34840
27606	51709	44.722537000000003	44.775500999999998	49.771877000000003	49.747342000000003	Советская	0103000020E610000001000000050000003293A8177C5C4640B07614E7A8DF48403293A8177C5C46406EC493DDCCE24840F581E49D436346406EC493DDCCE24840F581E49D43634640B07614E7A8DF48403293A8177C5C4640B07614E7A8DF4840
26803	51361	44.267791000000003	44.310389999999998	49.673389999999998	49.631349999999998	Краснопартизанская	0103000020E61000000100000005000000E294B9F946224640302AA913D0D04840E294B9F9462246400ABABDA431D64840B28009DCBA2746400ABABDA431D64840B28009DCBA274640302AA913D0D04840E294B9F946224640302AA913D0D04840
27458	51361	44.267791000000003	44.310389999999998	49.673389999999998	49.631349999999998	Кирова	0103000020E61000000100000005000000E294B9F946224640302AA913D0D04840E294B9F9462246400ABABDA431D64840B28009DCBA2746400ABABDA431D64840B28009DCBA274640302AA913D0D04840E294B9F946224640302AA913D0D04840
27398	51641	44.749181	44.793880999999999	50.005775	49.981852000000003	Центральная	0103000020E610000001000000050000006DE4BA29E55F464090C18A53ADFD48406DE4BA29E55F46403411363CBD00494038F581E49D6546403411363CBD00494038F581E49D65464090C18A53ADFD48406DE4BA29E55F464090C18A53ADFD4840
27184	51524	45.081978999999997	45.104033000000001	49.776612999999998	49.749490000000002	Ценральная	0103000020E61000000100000005000000B9FAB1497E8A4640EB56CF49EFDF4840B9FAB1497E8A46400053060E68E34840365A0EF4508D46400053060E68E34840365A0EF4508D4640EB56CF49EFDF4840B9FAB1497E8A4640EB56CF49EFDF4840
27718	51729	44.262914000000002	44.286045000000001	49.917883000000003	49.905306000000003	Новая	0103000020E610000001000000050000008DD47B2AA7214640B16F2711E1F348408DD47B2AA7214640F646AD307DF548409817601F9D244640F646AD307DF548409817601F9D244640B16F2711E1F348408DD47B2AA7214640B16F2711E1F34840
27535	51697	44.535767999999997	44.580539999999999	49.873136000000002	49.844006	улица Восточная	0103000020E61000000100000005000000251FBB0B944446405BD07B6308EC4840251FBB0B94444640EA7AA2EBC2EF48408A027D224F4A4640EA7AA2EBC2EF48408A027D224F4A46405BD07B6308EC4840251FBB0B944446405BD07B6308EC4840
27702	51697	44.535767999999997	44.580539999999999	49.873136000000002	49.844006	Советская	0103000020E61000000100000005000000251FBB0B944446405BD07B6308EC4840251FBB0B94444640EA7AA2EBC2EF48408A027D224F4A4640EA7AA2EBC2EF48408A027D224F4A46405BD07B6308EC4840251FBB0B944446405BD07B6308EC4840
26693	51321	44.535767999999997	44.580539999999999	49.873136000000002	49.844006	Базарная	0103000020E61000000100000005000000251FBB0B944446405BD07B6308EC4840251FBB0B94444640EA7AA2EBC2EF48408A027D224F4A4640EA7AA2EBC2EF48408A027D224F4A46405BD07B6308EC4840251FBB0B944446405BD07B6308EC4840
26981	51403	44.316175000000001	44.337077999999998	49.974772999999999	49.963456999999998	Почтовая	0103000020E610000001000000050000000A68226C78284640170D198F52FB48400A68226C782846400C03965CC5FC4840BD19355F252B46400C03965CC5FC4840BD19355F252B4640170D198F52FB48400A68226C78284640170D198F52FB4840
27328	51607	44.902828	44.961264	49.794764999999998	49.748972000000002	Ленина	0103000020E61000000100000005000000E0F42EDE8F73464053CF8250DEDF4840E0F42EDE8F734640B28009DCBAE548403C69E1B20A7B4640B28009DCBAE548403C69E1B20A7B464053CF8250DEDF4840E0F42EDE8F73464053CF8250DEDF4840
27170	51517	44.512968999999998	44.540241000000002	49.897421000000001	49.881599999999999	Даниловка	0103000020E61000000100000005000000506EDBF7A8414640A913D044D8F04840506EDBF7A84146402FDFFAB0DEF24840AB7AF99D264546402FDFFAB0DEF24840AB7AF99D26454640A913D044D8F04840506EDBF7A8414640A913D044D8F04840
27345	51611	44.461593999999998	44.511539999999997	50.029316000000001	50.003059999999998	 Кооперативная	0103000020E61000000100000005000000D1031F83153B46407FF6234564004940D1031F83153B4640F19F6EA0C0034940444C89247A414640F19F6EA0C0034940444C89247A4146407FF6234564004940D1031F83153B46407FF6234564004940
26678	28480	44.460714000000003	44.505170999999997	49.832078000000003	49.80733	Верхняя	0103000020E61000000100000005000000996725ADF83A4640338AE59656E74840996725ADF83A46404DDC2A8881EA48409DF17D71A94046404DDC2A8881EA48409DF17D71A9404640338AE59656E74840996725ADF83A4640338AE59656E74840
26967	51400	44.516005	44.562969000000002	49.816316999999998	49.788989999999998	Элеваторная	0103000020E6100000010000000500000047C9AB730C4246407E6FD39FFDE4484047C9AB730C4246409C1551137DE84840B7D4415E0F4846409C1551137DE84840B7D4415E0F4846407E6FD39FFDE4484047C9AB730C4246407E6FD39FFDE44840
27704	51400	44.516005	44.562969000000002	49.816316999999998	49.788989999999998	Октябрьская	0103000020E6100000010000000500000047C9AB730C4246407E6FD39FFDE4484047C9AB730C4246409C1551137DE84840B7D4415E0F4846409C1551137DE84840B7D4415E0F4846407E6FD39FFDE4484047C9AB730C4246407E6FD39FFDE44840
27572	51705	44.349879000000001	44.406455000000001	49.715544000000001	49.699401000000002	Московская 	0103000020E610000001000000050000005247C7D5C82C464015E5D2F885D948405247C7D5C82C4640AD6C1FF296DB4840D925AAB706344640AD6C1FF296DB4840D925AAB70634464015E5D2F885D948405247C7D5C82C464015E5D2F885D94840
26695	51322	44.671126000000001	44.697023999999999	49.917419000000002	49.900519000000003	Почтовая	0103000020E6100000010000000500000066BFEE74E75546409C36E33444F3484066BFEE74E755464051DD5CFC6DF5484078431A153859464051DD5CFC6DF5484078431A15385946409C36E33444F3484066BFEE74E75546409C36E33444F34840
27338	51609	44.400382999999998	44.424709	50.081426	50.043855999999998	Центральная	0103000020E61000000100000005000000EB6F09C03F334640DFDDCA129D054940EB6F09C03F334640A585CB2A6C0A49408FA850DD5C364640A585CB2A6C0A49408FA850DD5C364640DFDDCA129D054940EB6F09C03F334640DFDDCA129D054940
26572	27854	44.039574000000002	44.071339000000002	47.998522000000001	47.972596000000003	Сердюкова	0103000020E61000000100000005000000CEE2C5C210054640371C96067EFC4740CEE2C5C210054640132BA391CFFF4740F5F6E7A221094640132BA391CFFF4740F5F6E7A221094640371C96067EFC4740CEE2C5C210054640371C96067EFC4740
27519	51688	43.334989999999998	43.380310000000001	48.284883999999998	48.262245999999998	 Центральная	0103000020E61000000100000005000000573ECBF3E0AA4540DFC0E44691214840573ECBF3E0AA4540AB93331477244840BF2B82FFADB04540AB93331477244840BF2B82FFADB04540DFC0E44691214840573ECBF3E0AA4540DFC0E44691214840
27341	12440	43.502364	43.522765	48.102654999999999	48.08719	Рабочая	0103000020E610000001000000050000000858AB764DC04540E544BB0A290B48400858AB764DC04540ACE28DCC230D4840293FA9F6E9C24540ACE28DCC230D4840293FA9F6E9C24540E544BB0A290B48400858AB764DC04540E544BB0A290B4840
26547	26961	43.735477000000003	43.761878000000003	47.840803000000001	47.815837999999999	Дуенко	0103000020E61000000100000005000000E8FA3E1C24DE4540C26A2C616DE84740E8FA3E1C24DE454079B0C56E9FEB47405DC5E23785E1454079B0C56E9FEB47405DC5E23785E14540C26A2C616DE84740E8FA3E1C24DE4540C26A2C616DE84740
26926	27590	43.965733	43.997911000000002	47.911085	47.885924000000003	Центральная	0103000020E6100000010000000500000080D591239DFB4540EA5E27F565F1474080D591239DFB45402670EB6E9EF44740CAA8328CBBFF45402670EB6E9EF44740CAA8328CBBFF4540EA5E27F565F1474080D591239DFB4540EA5E27F565F14740
26749	27400	43.629475999999997	43.680858999999998	47.979249000000003	47.95478	Небыкова	0103000020E61000000100000005000000F6CE68AB92D04540FC6F253B36FA4740F6CE68AB92D0454003D2FE0758FD4740F817416326D7454003D2FE0758FD4740F817416326D74540FC6F253B36FA4740F6CE68AB92D04540FC6F253B36FA4740
27584	51425	43.629475999999997	43.680858999999998	47.979249000000003	47.95478	переулок Рабочий	0103000020E61000000100000005000000F6CE68AB92D04540FC6F253B36FA4740F6CE68AB92D0454003D2FE0758FD4740F817416326D7454003D2FE0758FD4740F817416326D74540FC6F253B36FA4740F6CE68AB92D04540FC6F253B36FA4740
27014	51425	43.629475999999997	43.680858999999998	47.979249000000003	47.95478	Октябрьская	0103000020E61000000100000005000000F6CE68AB92D04540FC6F253B36FA4740F6CE68AB92D0454003D2FE0758FD4740F817416326D7454003D2FE0758FD4740F817416326D74540FC6F253B36FA4740F6CE68AB92D04540FC6F253B36FA4740
27016	51425	43.629475999999997	43.680858999999998	47.979249000000003	47.95478	Ленина	0103000020E61000000100000005000000F6CE68AB92D04540FC6F253B36FA4740F6CE68AB92D0454003D2FE0758FD4740F817416326D7454003D2FE0758FD4740F817416326D74540FC6F253B36FA4740F6CE68AB92D04540FC6F253B36FA4740
27499	51682	43.247188000000001	43.286372999999998	48.016733000000002	47.997943999999997	Центральная	0103000020E6100000010000000500000059FB3BDBA39F4540A59E05A1BCFF474059FB3BDBA39F4540CAE1934E240248408CBAD6DEA7A44540CAE1934E240248408CBAD6DEA7A44540A59E05A1BCFF474059FB3BDBA39F4540A59E05A1BCFF4740
27400	51640	43.476725999999999	43.493219000000003	48.222073000000002	48.210563999999998	Центральная	0103000020E610000001000000050000009293895B05BD454083DBDAC2F31A48409293895B05BD45408D2958E36C1C48400762D9CC21BF45408D2958E36C1C48400762D9CC21BF454083DBDAC2F31A48409293895B05BD454083DBDAC2F31A4840
26732	27100	43.122492999999999	43.142282999999999	48.204745000000003	48.192506000000002	Тихий переулок	0103000020E61000000100000005000000957EC2D9AD8F454053245F09A4184840957EC2D9AD8F454080828B15351A48406DE34F543692454080828B15351A48406DE34F543692454053245F09A4184840957EC2D9AD8F454053245F09A4184840
26738	27316	43.796185000000001	43.828460999999997	47.950670000000002	47.929440999999997	Продольная	0103000020E610000001000000050000006B48DC63E9E54540E04735ECF7F647406B48DC63E9E54540E8A4F78DAFF94740778192020BEA4540E8A4F78DAFF94740778192020BEA4540E04735ECF7F647406B48DC63E9E54540E04735ECF7F64740
27200	27268	43.798512000000002	43.819451000000001	47.996417999999998	47.976444999999998	Школьная	0103000020E6100000010000000500000056BB26A435E64540DEAB5626FCFC474056BB26A435E64540A79201A08AFF474056D636C5E3E84540A79201A08AFF474056D636C5E3E84540DEAB5626FCFC474056BB26A435E64540DEAB5626FCFC4740
27449	51657	43.126069000000001	43.145372999999999	48.233356999999998	48.221136000000001	Школьная	0103000020E610000001000000050000000C056C0723904540F0FB372F4E1C48400C056C072390454076A565A4DE1D4840575C1C959B92454076A565A4DE1D4840575C1C959B924540F0FB372F4E1C48400C056C0723904540F0FB372F4E1C4840
27190	26841	43.681047999999997	43.707566	48.197161000000001	48.17595	Центральная	0103000020E61000000100000005000000CB80B3942CD7454098DD938785164840CB80B3942CD74540F98557923C1948407AE1CE8591DA4540F98557923C1948407AE1CE8591DA454098DD938785164840CB80B3942CD7454098DD938785164840
26851	51372	43.445743	43.480561999999999	47.985612000000003	47.969791000000001	Юбилейная	0103000020E61000000100000005000000E1B54B1B0EB94540427A8A1C22FC4740E1B54B1B0EB94540C845B58828FE4740A5D93C0E83BD4540C845B58828FE4740A5D93C0E83BD4540427A8A1C22FC4740E1B54B1B0EB94540427A8A1C22FC4740
26589	26925	43.748573999999998	43.778551	47.958044000000001	47.945601000000003	им. Ю.М. Носачева	0103000020E610000001000000050000006551D845D1DF45404F081D7409F947406551D845D1DF45408410902FA1FA474051A2258FA7E345408410902FA1FA474051A2258FA7E345404F081D7409F947406551D845D1DF45404F081D7409F94740
26818	27197	43.748573999999998	43.778551	47.958044000000001	47.945601000000003	Центральная	0103000020E610000001000000050000006551D845D1DF45404F081D7409F947406551D845D1DF45408410902FA1FA474051A2258FA7E345408410902FA1FA474051A2258FA7E345404F081D7409F947406551D845D1DF45404F081D7409F94740
26922	26823	43.597045999999999	43.643867	48.206780999999999	48.190398000000002	Административная	0103000020E61000000100000005000000931ADA006CCC4540A69C2FF65E184840931ADA006CCC45409337C0CC771A4840A0FCDD3B6AD245409337C0CC771A4840A0FCDD3B6AD24540A69C2FF65E184840931ADA006CCC4540A69C2FF65E184840
27528	51693	44.064413000000002	44.085540999999999	48.019578000000003	48.008566000000002	Молодежная	0103000020E61000000100000005000000F83768AF3E084640C4EDD0B018014840F83768AF3E0846404DDC2A8881024840CBBBEA01F30A46404DDC2A8881024840CBBBEA01F30A4640C4EDD0B018014840F83768AF3E084640C4EDD0B018014840
27349	51615	43.390281000000002	43.423248999999998	47.987541999999998	47.967776000000001	улица Дружбы	0103000020E6100000010000000500000006A051BAF4B1454046ED7E15E0FB474006A051BAF4B1454095B6B8C667FE47404888F2052DB6454095B6B8C667FE47404888F2052DB6454046ED7E15E0FB474006A051BAF4B1454046ED7E15E0FB4740
27123	27952	43.964537999999997	43.991227000000002	48.026682999999998	48.011538000000002	Центральная	0103000020E61000000100000005000000E7DF2EFB75FB4540A454C2137A014840E7DF2EFB75FB4540F92D3A596A034840C3F4BD86E0FE4540F92D3A596A034840C3F4BD86E0FE4540A454C2137A014840E7DF2EFB75FB4540A454C2137A014840
27420	51649	43.155605000000001	43.165595000000003	48.273173999999997	48.251598000000001	Центральная	0103000020E610000001000000050000000B0C59DDEA93454098DEFE5C342048400B0C59DDEA9345400A0F9A5DF7224840C9B08A37329545400A0F9A5DF7224840C9B08A373295454098DEFE5C342048400B0C59DDEA93454098DEFE5C34204840
26902	51381	43.431719999999999	43.452660000000002	48.097600999999997	48.084114	Виноградная	0103000020E61000000100000005000000BA83D89942B7454060915F3FC40A4840BA83D89942B74540488787307E0C48408B1A4CC3F0B94540488787307E0C48408B1A4CC3F0B9454060915F3FC40A4840BA83D89942B7454060915F3FC40A4840
27295	26757	43.805168000000002	43.829324	48.141703	48.130867000000002	Центральная	0103000020E6100000010000000500000093E4B9BE0FE745401590F63FC010484093E4B9BE0FE745405F5FEB5223124840DAE4F04927EA45405F5FEB5223124840DAE4F04927EA45401590F63FC010484093E4B9BE0FE745401590F63FC0104840
27099	51480	43.580202999999997	43.654161000000002	47.994723999999998	47.965085000000002	Татаренко	0103000020E610000001000000050000004205871744CA45401A6EC0E787FB47404205871744CA4540ED45B41D53FF4740CAA8328CBBD34540ED45B41D53FF4740CAA8328CBBD345401A6EC0E787FB47404205871744CA45401A6EC0E787FB4740
26992	26676	43.925848000000002	44.009974999999997	47.976390000000002	47.938254999999998	Октябрьская	0103000020E610000001000000050000009488F02F82F645407C2766BD18F847409488F02F82F645401B12F758FAFC474088635DDC460146401B12F758FAFC474088635DDC460146407C2766BD18F847409488F02F82F645407C2766BD18F84740
26814	51367	44.165275999999999	44.207504999999998	48.103605999999999	48.055911999999999	Гордиенко	0103000020E61000000100000005000000276893C3271546401BBAD91F28074840276893C327154640AED51EF6420D4840D4601A868F1A4640AED51EF6420D4840D4601A868F1A46401BBAD91F28074840276893C3271546401BBAD91F28074840
27195	26485	42.777737999999999	42.805990000000001	51.017333000000001	50.993619000000002	Советская	0103000020E61000000100000005000000A06D35EB8C63454095D74AE82E7F4940A06D35EB8C6345401F12BEF737824940977329AE2A6745401F12BEF737824940977329AE2A67454095D74AE82E7F4940A06D35EB8C63454095D74AE82E7F4940
27323	51606	42.282263	42.304864999999999	51.045808000000001	51.023921999999999	улица Центральная	0103000020E6100000010000000500000078EFA83121244540D4D347E00F83494078EFA8312124454095F25A09DD854940F758FAD00527454095F25A09DD854940F758FAD005274540D4D347E00F83494078EFA83121244540D4D347E00F834940
26510	26388	42.475104000000002	42.505772999999998	50.862726000000002	50.842955000000003	Центральная	0103000020E6100000010000000500000072193735D03C4540F67F0EF3E56B494072193735D03C454057B439CE6D6E494093196F2BBD40454057B439CE6D6E494093196F2BBD404540F67F0EF3E56B494072193735D03C4540F67F0EF3E56B4940
26912	51386	42.370702000000001	42.393214	51.036859999999997	51.010731	Центральная	0103000020E61000000100000005000000E947C329732F4540D50627A25F814940E947C329732F4540E94317D4B7844940282A1BD654324540E94317D4B7844940282A1BD654324540D50627A25F814940E947C329732F4540D50627A25F814940
26940	25387	42.325642999999999	42.403841	50.996521999999999	50.947591000000003	Усадьба СХ	0103000020E61000000100000005000000EE9579ABAE294540F27D71A94A794940EE9579ABAE2945404CDF6B088E7F494058E4D70FB13345404CDF6B088E7F494058E4D70FB1334540F27D71A94A794940EE9579ABAE294540F27D71A94A794940
26399	25387	42.325642999999999	42.403841	50.996521999999999	50.947591000000003	Первомайская	0103000020E61000000100000005000000EE9579ABAE294540F27D71A94A794940EE9579ABAE2945404CDF6B088E7F494058E4D70FB13345404CDF6B088E7F494058E4D70FB1334540F27D71A94A794940EE9579ABAE294540F27D71A94A794940
26703	25387	42.325642999999999	42.403841	50.996521999999999	50.947591000000003	Народная	0103000020E61000000100000005000000EE9579ABAE294540F27D71A94A794940EE9579ABAE2945404CDF6B088E7F494058E4D70FB13345404CDF6B088E7F494058E4D70FB1334540F27D71A94A794940EE9579ABAE294540F27D71A94A794940
27495	51680	42.727935000000002	42.746647000000003	50.890723000000001	50.871492000000003	 Центральная	0103000020E61000000100000005000000904E5DF92C5D4540E25CC30C8D6F4940904E5DF92C5D4540C3651536037249400954FF20925F4540C3651536037249400954FF20925F4540E25CC30C8D6F4940904E5DF92C5D4540E25CC30C8D6F4940
26987	26276	42.802836999999997	42.834853000000003	51.190530000000003	51.177584000000003	Народная	0103000020E610000001000000050000006682E15CC36645407D259012BB9649406682E15CC366454015747B4963984940D7FB8D76DC6A454015747B4963984940D7FB8D76DC6A45407D259012BB9649406682E15CC36645407D259012BB964940
26431	26350	42.894339000000002	42.928879000000002	51.117279000000003	51.105738000000002	Школьная	0103000020E61000000100000005000000C8444AB379724540E4F8A1D2888D4940C8444AB379724540F9C08EFF028F49407978CF81E5764540F9C08EFF028F49407978CF81E5764540E4F8A1D2888D4940C8444AB379724540E4F8A1D2888D4940
27543	51700	42.522517999999998	42.569023000000001	50.850313999999997	50.826241000000003	Советская	0103000020E6100000010000000500000021C9ACDEE1424540A3CEDC43C269494021C9ACDEE14245405CAAD216D76C4940FED5E3BED54845405CAAD216D76C4940FED5E3BED5484540A3CEDC43C269494021C9ACDEE1424540A3CEDC43C2694940
27387	51631	42.751561000000002	42.783082999999998	50.902346999999999	50.873572000000003	Центральная	0103000020E610000001000000050000007BF99D2633604540C5591135D16F49407BF99D26336045406552431B80734940DB8651103C6445406552431B80734940DB8651103C644540C5591135D16F49407BF99D2633604540C5591135D16F4940
26914	51388	42.278525999999999	42.349294999999998	50.954259	50.930978000000003	Центральная	0103000020E61000000100000005000000F88A6EBDA6234540D3A57F492A774940F88A6EBDA6234540F374AE28257A494002D4D4B2B52C4540F374AE28257A494002D4D4B2B52C4540D3A57F492A774940F88A6EBDA6234540D3A57F492A774940
27268	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	поселок Казачий	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27454	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Советская улица	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27364	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Рабочая	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
26426	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Подтелкова	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27615	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Пионерская	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27162	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Народная	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27377	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Ленина	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27318	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	Калинина	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
27327	51269	42.645783999999999	42.701084999999999	50.547885999999998	50.502049999999997	 Киквидзе	0103000020E61000000100000005000000D923D40CA9524540787AA52C43404940D923D40CA9524540D7F7E12021464940AB5B3D27BD594540D7F7E12021464940AB5B3D27BD594540787AA52C43404940D923D40CA9524540787AA52C43404940
26810	22351	45.426546000000002	45.506101000000001	50.053423000000002	50.002510000000001	Чайковского	0103000020E61000000100000005000000AC1E300F99B64640DCF4673F52004940AC1E300F99B6464057ED9A90D606494088BCE5EAC7C0464057ED9A90D606494088BCE5EAC7C04640DCF4673F52004940AC1E300F99B64640DCF4673F52004940
27250	22351	45.426546000000002	45.506101000000001	50.053423000000002	50.002510000000001	Свердлова	0103000020E61000000100000005000000AC1E300F99B64640DCF4673F52004940AC1E300F99B6464057ED9A90D606494088BCE5EAC7C0464057ED9A90D606494088BCE5EAC7C04640DCF4673F52004940AC1E300F99B64640DCF4673F52004940
26886	22351	45.426546000000002	45.506101000000001	50.053423000000002	50.002510000000001	Республиканская	0103000020E61000000100000005000000AC1E300F99B64640DCF4673F52004940AC1E300F99B6464057ED9A90D606494088BCE5EAC7C0464057ED9A90D606494088BCE5EAC7C04640DCF4673F52004940AC1E300F99B64640DCF4673F52004940
26579	22351	45.426546000000002	45.506101000000001	50.053423000000002	50.002510000000001	Октябрьская	0103000020E61000000100000005000000AC1E300F99B64640DCF4673F52004940AC1E300F99B6464057ED9A90D606494088BCE5EAC7C0464057ED9A90D606494088BCE5EAC7C04640DCF4673F52004940AC1E300F99B64640DCF4673F52004940
26995	22351	45.426546000000002	45.506101000000001	50.053423000000002	50.002510000000001	Калинина	0103000020E61000000100000005000000AC1E300F99B64640DCF4673F52004940AC1E300F99B6464057ED9A90D606494088BCE5EAC7C0464057ED9A90D606494088BCE5EAC7C04640DCF4673F52004940AC1E300F99B64640DCF4673F52004940
26622	21130	41.719881999999998	41.780616999999999	50.428668999999999	50.394497000000001	Ленина	0103000020E61000000100000005000000527DE71725DC444060AFB0E07E324940527DE71725DC44408EE733A0DE364940CFD90242EBE344408EE733A0DE364940CFD90242EBE3444060AFB0E07E324940527DE71725DC444060AFB0E07E324940
26643	21130	41.719881999999998	41.780616999999999	50.428668999999999	50.394497000000001	Коммунистическая	0103000020E61000000100000005000000527DE71725DC444060AFB0E07E324940527DE71725DC44408EE733A0DE364940CFD90242EBE344408EE733A0DE364940CFD90242EBE3444060AFB0E07E324940527DE71725DC444060AFB0E07E324940
26422	20429	43.532097999999998	43.553038000000001	50.046909999999997	50.034146999999997	Советская	0103000020E610000001000000050000002D228AC91BC44540D520CCED5E0449402D228AC91BC445407CED992501064940FEB8FDF2C9C645407CED992501064940FEB8FDF2C9C64540D520CCED5E0449402D228AC91BC44540D520CCED5E044940
27611	51710	43.016222999999997	43.072017000000002	50.245787	50.225292000000003	Советская	0103000020E61000000100000005000000B4386398138245407506465ED61C4940B4386398138245401764CBF2751F4940C6E061DA378945401764CBF2751F4940C6E061DA378945407506465ED61C4940B4386398138245407506465ED61C4940
26762	20414	43.453415	43.497477000000003	50.004303999999998	49.987226999999997	Мира	0103000020E610000001000000050000000742B28009BA4540355D4F745DFE48400742B28009BA4540F99E91088D00494090C18A53ADBF4540F99E91088D00494090C18A53ADBF4540355D4F745DFE48400742B28009BA4540355D4F745DFE4840
26681	19496	43.399200999999998	43.435429999999997	49.924447999999998	49.906838	Садовая	0103000020E61000000100000005000000E7C3B30419B345409162804413F44840E7C3B30419B34540226DE34F54F6484040D9942BBCB74540226DE34F54F6484040D9942BBCB745409162804413F44840E7C3B30419B345409162804413F44840
26428	20544	43.602373	43.621696	50.154007999999997	50.133347000000001	Юрия Прищепного	0103000020E61000000100000005000000287FF78E1ACD45408602B68311114940287FF78E1ACD454043A9BD88B6134940EA060ABC93CF454043A9BD88B6134940EA060ABC93CF45408602B68311114940287FF78E1ACD45408602B68311114940
26380	13835	42.976894000000001	42.998553000000001	50.312975999999999	50.294508	Школьная	0103000020E610000001000000050000004ED4D2DC0A7D454087342A70B22549404ED4D2DC0A7D45406937FA980F2849404E29AF95D07F45406937FA980F2849404E29AF95D07F454087342A70B22549404ED4D2DC0A7D454087342A70B2254940
26585	45373	43.205246000000002	43.269286999999998	50.017184999999998	49.945658000000002	Центральная	0103000020E6100000010000000500000042D13C80459A4540B39943520BF9484042D13C80459A4540AA7D3A1E33024940751E15FF77A24540AA7D3A1E33024940751E15FF77A24540B39943520BF9484042D13C80459A4540B39943520BF94840
26954	45801	43.310195999999998	43.350673999999998	50.133792	50.106813000000002	Ленина	0103000020E61000000100000005000000CDACA580B4A74540D2E4620CAC0D4940CDACA580B4A74540B43BA418201149405CC7B8E2E2AC4540B43BA418201149405CC7B8E2E2AC4540D2E4620CAC0D4940CDACA580B4A74540D2E4620CAC0D4940
26854	20629	43.601205999999998	43.644100000000002	50.275727000000003	50.245344000000003	Ленина	0103000020E6100000010000000500000059147651F4CC45408A22A46E671F494059147651F4CC4540E6CFB7054B23494043AD69DE71D24540E6CFB7054B23494043AD69DE71D245408A22A46E671F494059147651F4CC45408A22A46E671F4940
26639	19919	42.878914999999999	42.909916000000003	50.052531999999999	50.034911000000001	Центральная	0103000020E610000001000000050000005F7B664980704540A5A2B1F6770449405F7B6649807045402AFF5A5EB9064940B70DA320787445402AFF5A5EB9064940B70DA32078744540A5A2B1F6770449405F7B664980704540A5A2B1F677044940
26961	20200	43.603110000000001	43.643408000000001	50.514459000000002	50.490189000000001	Первомайский	0103000020E61000000100000005000000FEF15EB532CD4540F2ED5D83BE3E4940FEF15EB532CD45400211E2CAD94149400DFE7E315BD245400211E2CAD94149400DFE7E315BD24540F2ED5D83BE3E4940FEF15EB532CD4540F2ED5D83BE3E4940
27226	21103	42.981915999999998	43.025897000000001	50.183238000000003	50.158268	Первомайский	0103000020E61000000100000005000000A6B5696CAF7D45406D00362042144940A6B5696CAF7D454036B1C057741749404208C8975083454036B1C057741749404208C897508345406D00362042144940A6B5696CAF7D45406D00362042144940
27229	20864	43.059134999999998	43.084971000000003	50.27731	50.248080000000002	Парковый	0103000020E61000000100000005000000448655BC918745405665DF15C11F4940448655BC91874540486DE2E47E234940E10D6954E08A4540486DE2E47E234940E10D6954E08A45405665DF15C11F4940448655BC918745405665DF15C11F4940
26383	20524	43.642015999999998	43.661914000000003	50.213661000000002	50.197830000000003	Мира	0103000020E610000001000000050000001EC18D942DD245407715527E521949401EC18D942DD2454020B75F3E591B4940DD611399B9D4454020B75F3E591B4940DD611399B9D445407715527E521949401EC18D942DD245407715527E52194940
26876	20024	43.548340000000003	43.579853	50.415624999999999	50.396214000000001	Школьная	0103000020E61000000100000005000000598B4F0130C64540D21BEE23B7324940598B4F0130C64540333333333335494066BE839F38CA4540333333333335494066BE839F38CA4540D21BEE23B7324940598B4F0130C64540D21BEE23B7324940
27161	19936	43.106261000000003	43.131844999999998	50.059207000000001	50.031751999999997	Украинская 	0103000020E610000001000000050000008EEBDFF5998D454092CA1473100449408EEBDFF5998D4540DE585018940749401092054CE0904540DE585018940749401092054CE090454092CA1473100449408EEBDFF5998D454092CA147310044940
26423	45661	43.161543000000002	43.184756	50.024147999999997	50.007998000000001	Чекунова	0103000020E61000000100000005000000E9F2E670AD9445407A37161406014940E9F2E670AD944540C4211B4817034940B1DEA815A6974540C4211B4817034940B1DEA815A69745407A37161406014940E9F2E670AD9445407A37161406014940
27044	45789	43.696705000000001	43.741801000000002	50.232610999999999	50.212277999999998	Лесная	0103000020E61000000100000005000000D7FA22A12DD9454084D4EDEC2B1B4940D7FA22A12DD945404DD87E32C61D4940EF91CD55F3DE45404DD87E32C61D4940EF91CD55F3DE454084D4EDEC2B1B4940D7FA22A12DD9454084D4EDEC2B1B4940
26419	19606	43.396676999999997	43.433616000000001	50.202218000000002	50.181888999999998	Маршала Жукова	0103000020E61000000100000005000000A609DB4FC6B245404640852348174940A609DB4FC6B24540CE548847E2194940DC82A5BA80B74540CE548847E2194940DC82A5BA80B745404640852348174940A609DB4FC6B245404640852348174940
27244	20084	43.522728999999998	43.542932	50.368718000000001	50.355231000000003	Заречная	0103000020E61000000100000005000000DCD5ABC8E8C2454040C39B35782D4940DCD5ABC8E8C2454028B9C326322F4940D7F9B7CB7EC5454028B9C326322F4940D7F9B7CB7EC5454040C39B35782D4940DCD5ABC8E8C2454040C39B35782D4940
27031	51439	42.650294000000002	43.754798999999998	50.588797999999997	49.820798000000003	Свободы	0103000020E610000001000000050000007C6473D53C534540A54FABE80FE948407C6473D53C534540A0F99CBB5D4B4940D906EE409DE04540A0F99CBB5D4B4940D906EE409DE04540A54FABE80FE948407C6473D53C534540A54FABE80FE94840
27402	51643	42.855361000000002	42.875906000000001	50.236316000000002	50.216757000000001	Центральная	0103000020E610000001000000050000000EA320787C6D4540EC1681B1BE1B49400EA320787C6D4540C2C2499A3F1E4940622F14B01D704540C2C2499A3F1E4940622F14B01D704540EC1681B1BE1B49400EA320787C6D4540EC1681B1BE1B4940
26596	19863	42.999567999999996	43.011586999999999	50.095816999999997	50.085565000000003	Советская	0103000020E6100000010000000500000066101FD8F17F454054573ECBF30A494066101FD8F17F45404EB340BB430C49408507CDAE7B8145404EB340BB430C49408507CDAE7B81454054573ECBF30A494066101FD8F17F454054573ECBF30A4940
27144	19762	42.876480999999998	42.913921999999999	50.170431999999998	50.150089000000001	Центральная	0103000020E610000001000000050000005E48878730704540A33EC91D361349405E488787307045408F183DB7D0154940268C6665FB7445408F183DB7D0154940268C6665FB744540A33EC91D361349405E48878730704540A33EC91D36134940
26963	19694	43.548743999999999	43.564445999999997	50.238736000000003	50.223269999999999	Центральная	0103000020E6100000010000000500000028F04E3E3DC64540C616821C941C494028F04E3E3DC645405E30B8E68E1E4940D32D3BC43FC845405E30B8E68E1E4940D32D3BC43FC84540C616821C941C494028F04E3E3DC64540C616821C941C4940
26939	19269	43.101913000000003	43.138762	49.981574000000002	49.937826000000001	Центральная	0103000020E61000000100000005000000C504357C0B8D454054ABAFAE0AF84840C504357C0B8D45404D4D8237A4FD4840BAF605F4C29145404D4D8237A4FD4840BAF605F4C291454054ABAFAE0AF84840C504357C0B8D454054ABAFAE0AF84840
26759	19660	43.526870000000002	43.568883999999997	50.197736999999996	50.168978000000003	Красная	0103000020E610000001000000050000002C9FE57970C345402BDF3312A11549402C9FE57970C34540C51A2E724F194940DC9BDF30D1C84540C51A2E724F194940DC9BDF30D1C845402BDF3312A11549402C9FE57970C345402BDF3312A1154940
27150	20842	43.377175000000001	43.393093	50.164257999999997	50.146988999999998	Ольховая	0103000020E6100000010000000500000035EF384547B0454095EF1989D012494035EF384547B045409D0DF96706154940ADA415DF50B245409D0DF96706154940ADA415DF50B2454095EF1989D012494035EF384547B0454095EF1989D0124940
27034	20999	43.145238999999997	43.174883000000001	50.238746999999996	50.221673000000003	Зеленая	0103000020E61000000100000005000000478D093197924540FFB3E6C75F1C4940478D0931979245405182FE428F1E49402DD0EE90629645405182FE428F1E49402DD0EE9062964540FFB3E6C75F1C4940478D093197924540FFB3E6C75F1C4940
27446	51618	43.225261000000003	43.315739000000001	49.918596000000001	49.895569999999999	Центральная	0103000020E610000001000000050000003A083A5AD59C4540ADA3AA09A2F248403A083A5AD59C4540431EC18D94F548402F89B3226AA84540431EC18D94F548402F89B3226AA84540ADA3AA09A2F248403A083A5AD59C4540ADA3AA09A2F24840
27352	51618	43.225261000000003	43.315739000000001	49.918596000000001	49.895569999999999	Советская улица	0103000020E610000001000000050000003A083A5AD59C4540ADA3AA09A2F248403A083A5AD59C4540431EC18D94F548402F89B3226AA84540431EC18D94F548402F89B3226AA84540ADA3AA09A2F248403A083A5AD59C4540ADA3AA09A2F24840
27130	19174	43.089444	43.132959	49.909163999999997	49.882308000000002	Ленина	0103000020E610000001000000050000006669A7E6728B4540E57FF277EFF048406669A7E6728B4540AB59677C5FF44840BC5AEECC04914540AB59677C5FF44840BC5AEECC04914540E57FF277EFF048406669A7E6728B4540E57FF277EFF04840
26929	18539	45.357644999999998	45.387416000000002	48.673648999999997	48.659112	Бегичева	0103000020E61000000100000005000000F949B54FC7AD4640593332C85D544840F949B54FC7AD4640D6FD63213A5648403CF9F4D896B14640D6FD63213A5648403CF9F4D896B14640593332C85D544840F949B54FC7AD4640593332C85D544840
27302	19009	45.560960999999999	45.575729000000003	49.059430999999996	49.048278000000003	Ленина	0103000020E610000001000000050000006DAAEE91CDC74640E38E37F92D8648406DAAEE91CDC746402DAF5C6F9B874840ED2DE57CB1C946402DAF5C6F9B874840ED2DE57CB1C94640E38E37F92D8648406DAAEE91CDC74640E38E37F92D864840
26581	51295	45.587263999999998	45.608293000000003	48.935687000000001	48.922783000000003	Добровольского	0103000020E610000001000000050000001F0F7D772BCB46400327DBC01D7648401F0F7D772BCB46406C257497C477484060B1868BDCCD46406C257497C477484060B1868BDCCD46400327DBC01D7648401F0F7D772BCB46400327DBC01D764840
27202	51541	45.069465999999998	45.09196	48.513083999999999	48.498137	Центральная	0103000020E610000001000000050000008B170B43E4884640BAF605F4C23F48408B170B43E4884640E90C8CBCAC41484024456458C58B4640E90C8CBCAC41484024456458C58B4640BAF605F4C23F48408B170B43E4884640BAF605F4C23F4840
26934	49382	45.366214999999997	45.416080999999998	48.686943999999997	48.667163000000002	Павших борцов	0103000020E61000000100000005000000FE261422E0AE4640F60CE19865554840FE261422E0AE46407A17EFC7ED57484055BE672442B546407A17EFC7ED57484055BE672442B54640F60CE19865554840FE261422E0AE4640F60CE19865554840
27027	49530	45.460214999999998	45.479951	49.114297000000001	49.097392999999997	Школьная	0103000020E6100000010000000500000077103B53E8BA4640FEEDB25F778C484077103B53E8BA4640F583BA48A18E48405C57CC086FBD4640F583BA48A18E48405C57CC086FBD4640FEEDB25F778C484077103B53E8BA4640FEEDB25F778C4840
26777	30424	45.545015999999997	45.576143000000002	48.977068000000003	48.963583	Переулок Клубный	0103000020E61000000100000005000000FBE59315C3C54640A4FD0FB0567B4840FBE59315C3C54640ECFB7090107D4840E068C70DBFC94640ECFB7090107D4840E068C70DBFC94640A4FD0FB0567B4840FBE59315C3C54640A4FD0FB0567B4840
27026	30424	45.545015999999997	45.576143000000002	48.977068000000003	48.963583	Барышнева	0103000020E61000000100000005000000FBE59315C3C54640A4FD0FB0567B4840FBE59315C3C54640ECFB7090107D4840E068C70DBFC94640ECFB7090107D4840E068C70DBFC94640A4FD0FB0567B4840FBE59315C3C54640A4FD0FB0567B4840
26566	49425	45.015270999999998	45.060968000000003	48.489868000000001	48.471957000000003	Речная	0103000020E61000000100000005000000E2C96E66F4814640240F4416693C4840E2C96E66F4814640B0AD9FFEB33E4840200DA7CCCD874640B0AD9FFEB33E4840200DA7CCCD874640240F4416693C4840E2C96E66F4814640240F4416693C4840
27149	49472	45.312119000000003	45.331980999999999	48.678556999999998	48.673082999999998	Школьная	0103000020E61000000100000005000000E9BAF083F3A746402D3F709527564840E9BAF083F3A7464066BCADF4DA5648405AF2785A7EAA464066BCADF4DA5648405AF2785A7EAA46402D3F709527564840E9BAF083F3A746402D3F709527564840
26936	19113	45.629835	45.661366000000001	49.241511000000003	49.227282000000002	Ленина	0103000020E610000001000000050000002670EB6E9ED04640187C9A93179D48402670EB6E9ED04640E84F1BD5E99E4840DA571EA4A7D44640E84F1BD5E99E4840DA571EA4A7D44640187C9A93179D48402670EB6E9ED04640187C9A93179D4840
27198	18454	45.273778999999998	45.295274999999997	48.690809999999999	48.675367999999999	Советская	0103000020E6100000010000000500000071AAB5300BA34640E96168757256484071AAB5300BA34640F8DF4A766C584840C7293A92CBA54640F8DF4A766C584840C7293A92CBA54640E96168757256484071AAB5300BA34640E961687572564840
27122	18786	44.937396	44.952317000000001	48.505056000000003	48.499127999999999	Павших Борцов	0103000020E610000001000000050000005BB39597FC7746404A42226DE33F48405BB39597FC7746400553CDACA540484061360186E57946400553CDACA540484061360186E57946404A42226DE33F48405BB39597FC7746404A42226DE33F4840
26820	10821	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	Ястребова	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
26554	10821	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	Чернышевского	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
26885	10821	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	Ленина	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
26925	10821	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	Битюцкого	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
27351	10821	45.174218000000003	45.249550999999997	48.719914000000003	48.686159000000004	 Ленина	0103000020E61000000100000005000000F12F82C64C964640946DE00ED4574840F12F82C64C9646405EF75624265C484090D78349F19F46405EF75624265C484090D78349F19F4640946DE00ED4574840F12F82C64C964640946DE00ED4574840
26741	49342	45.290128000000003	45.322035999999997	48.884135999999998	48.867621999999997	Школьная	0103000020E61000000100000005000000B3D30FEA22A5464022A5D93C0E6F4840B3D30FEA22A54640AE9B525E2B7148403C11C47938A94640AE9B525E2B7148403C11C47938A9464022A5D93C0E6F4840B3D30FEA22A5464022A5D93C0E6F4840
27301	18641	45.439275000000002	45.472135999999999	48.664014999999999	48.647660999999999	Гагарина	0103000020E61000000100000005000000A779C7293AB8464084F23E8EE6524840A779C7293AB84640D7868A71FE544840D3A1D3F36EBC4640D7868A71FE544840D3A1D3F36EBC464084F23E8EE6524840A779C7293AB8464084F23E8EE6524840
26828	18882	45.296182999999999	45.332681000000001	48.463175	48.450220999999999	Заречная	0103000020E61000000100000005000000CA501553E9A54640787C7BD7A0394840CA501553E9A5464093A98251493B484013807F4A95AA464093A98251493B484013807F4A95AA4640787C7BD7A0394840CA501553E9A54640787C7BD7A0394840
27199	49361	44.984242999999999	45.045445000000001	48.718451000000002	48.691308999999997	Совхозная	0103000020E610000001000000050000009128B4ACFB7D4640193735D07C5848409128B4ACFB7D4640A663CE33F65B484024624A24D1854640A663CE33F65B484024624A24D1854640193735D07C5848409128B4ACFB7D4640193735D07C584840
27060	18338	45.122044000000002	45.148139999999998	48.718291000000001	48.708762	Карла Маркса	0103000020E61000000100000005000000265646239F8F4640E35295B6B85A4840265646239F8F46406D01A1F5F05B48405E9D6340F69246406D01A1F5F05B48405E9D6340F6924640E35295B6B85A4840265646239F8F4640E35295B6B85A4840
27005	20334	42.529291000000001	42.535696000000002	49.887479999999996	49.884061000000003	Центральная	0103000020E610000001000000050000009888B7CEBF434540A4552DE928F148409888B7CEBF43454052EDD3F198F148408C4CC0AF9144454052EDD3F198F148408C4CC0AF91444540A4552DE928F148409888B7CEBF434540A4552DE928F14840
27105	16682	44.755189999999999	44.851391	50.351754	50.287222	Чапаева	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
26513	16682	44.755189999999999	44.851391	50.351754	50.287222	Синельникова	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
27108	16682	44.755189999999999	44.851391	50.351754	50.287222	Мира	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
27104	16682	44.755189999999999	44.851391	50.351754	50.287222	Ленина	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
26722	16682	44.755189999999999	44.851391	50.351754	50.287222	Зеленая	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
27290	16682	44.755189999999999	44.851391	50.351754	50.287222	Губкина	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
27107	16682	44.755189999999999	44.851391	50.351754	50.287222	 Ленина	0103000020E610000001000000050000001422E010AA6046408A58C4B0C32449401422E010AA6046405C1E6B46062D4940EB8D5A61FA6C46405C1E6B46062D4940EB8D5A61FA6C46408A58C4B0C32449401422E010AA6046408A58C4B0C3244940
26999	51412	44.678905	44.722158999999998	50.320270000000001	50.298690999999998	Зеленая	0103000020E61000000100000005000000A20BEA5BE6564640054EB6813B264940A20BEA5BE6564640E9F17B9BFE2849408BC1C3B46F5C4640E9F17B9BFE2849408BC1C3B46F5C4640054EB6813B264940A20BEA5BE6564640054EB6813B264940
26731	49231	44.691139999999997	44.710185000000003	50.272962999999997	50.258924999999998	Мира	0103000020E610000001000000050000008D7A884677584640F38E5374242149408D7A8846775846404F029B73F02249400D8E9257E75A46404F029B73F02249400D8E9257E75A4640F38E5374242149408D7A884677584640F38E537424214940
27525	51539	43.099361999999999	43.118828000000001	47.692318	47.679222000000003	Центральная	0103000020E610000001000000050000008A3BDEE4B78C4540A35C1ABFF0D647408A3BDEE4B78C4540503750E09DD84740AFEC82C1358F4540503750E09DD84740AFEC82C1358F4540A35C1ABFF0D647408A3BDEE4B78C4540A35C1ABFF0D64740
27370	51428	42.970489000000001	42.998049999999999	47.846929000000003	47.820540000000001	 Садовая	0103000020E610000001000000050000005A10CAFB387C4540A987687407E947405A10CAFB387C45405A84622B68EC4740EBE2361AC07F45405A84622B68EC4740EBE2361AC07F4540A987687407E947405A10CAFB387C4540A987687407E94740
27484	51392	42.963239999999999	42.998291999999999	49.175192000000003	49.161090000000002	Пролетарская	0103000020E610000001000000050000007A19C5724B7B454038DBDC989E9448407A19C5724B7B4540AB4203B16C964840E1ED4108C87F4540AB4203B16C964840E1ED4108C87F454038DBDC989E9448407A19C5724B7B454038DBDC989E944840
26951	51392	42.963239999999999	42.998291999999999	49.175192000000003	49.161090000000002	Придорожная	0103000020E610000001000000050000007A19C5724B7B454038DBDC989E9448407A19C5724B7B4540AB4203B16C964840E1ED4108C87F4540AB4203B16C964840E1ED4108C87F454038DBDC989E9448407A19C5724B7B454038DBDC989E944840
27101	15186	43.336103999999999	43.354052000000003	49.419691	49.396678000000001	Казачья	0103000020E610000001000000050000000307B47405AB454077853E58C6B248400307B47405AB454078B6476FB8B54840AD8A709351AD454078B6476FB8B54840AD8A709351AD454077853E58C6B248400307B47405AB454077853E58C6B24840
27491	51677	43.319799000000003	43.348104999999997	49.379958999999999	49.347766999999997	Центральная	0103000020E610000001000000050000009225732CEFA8454063D009A183AC48409225732CEFA8454012691B7FA2B048407B4963B48EAC454012691B7FA2B048407B4963B48EAC454063D009A183AC48409225732CEFA8454063D009A183AC4840
27437	51655	43.199156000000002	43.223014999999997	49.239899999999999	49.227851999999999	Донская	0103000020E61000000100000005000000AE669DF17D994540022A1C412A9D4840AE669DF17D994540BB270F0BB59E48403BC269C18B9C4540BB270F0BB59E48403BC269C18B9C4540022A1C412A9D4840AE669DF17D994540022A1C412A9D4840
27459	51662	42.566327999999999	42.601973999999998	49.192922000000003	49.172063999999999	Молодежная	0103000020E610000001000000050000009067976F7D484540D3687231069648409067976F7D484540E75608ABB19848406A85E97B0D4D4540E75608ABB19848406A85E97B0D4D4540D3687231069648409067976F7D484540D368723106964840
26505	51287	43.115153999999997	43.134369	49.304200000000002	49.296427999999999	Сухорукова	0103000020E610000001000000050000007500C45DBD8E454031CF4A5AF1A548407500C45DBD8E4540BBB88D06F0A64840514CDE0033914540BBB88D06F0A64840514CDE003391454031CF4A5AF1A548407500C45DBD8E454031CF4A5AF1A54840
26526	15432	42.876220000000004	42.936388999999998	49.017119999999998	49.001046000000002	Атамана Макарова	0103000020E61000000100000005000000F20C1AFA2770454054E57B4622804840F20C1AFA27704540C30DF8FC30824840C5AA4198DB774540C30DF8FC30824840C5AA4198DB77454054E57B4622804840F20C1AFA2770454054E57B4622804840
27490	51674	42.430529999999997	42.443114999999999	49.097493	49.080418999999999	Центральная	0103000020E6100000010000000500000033F9669B1B3745400F7D772B4B8A484033F9669B1B374540624B8FA67A8C4840FBAE08FEB7384540624B8FA67A8C4840FBAE08FEB73845400F7D772B4B8A484033F9669B1B3745400F7D772B4B8A4840
27489	51676	42.630603000000001	42.647024000000002	49.112333	49.096513999999999	Центральная	0103000020E6100000010000000500000037E15E99B750454096CD1C925A8C484037E15E99B75045407BA180ED608E484012DDB3AED15245407BA180ED608E484012DDB3AED152454096CD1C925A8C484037E15E99B750454096CD1C925A8C4840
26518	51289	43.000152	43.019528000000001	49.054011000000003	49.042076999999999	Келина	0103000020E61000000100000005000000B68311FB04804540F77475C762854840B68311FB04804540E84F1BD5E98648409BADBCE47F824540E84F1BD5E98648409BADBCE47F824540F77475C762854840B68311FB04804540F77475C762854840
27642	51716	43.259036999999999	43.273319999999998	49.332998000000003	49.319676000000001	Молодежная	0103000020E610000001000000050000001BBAD91F28A1454076A8A624EBA848401BBAD91F28A1454014D1AFAD9FAA4840DEAB5626FCA2454014D1AFAD9FAA4840DEAB5626FCA2454076A8A624EBA848401BBAD91F28A1454076A8A624EBA84840
27471	51667	42.522212000000003	42.543259999999997	49.080413	49.058120000000002	Молодежная	0103000020E6100000010000000500000015CAC2D7D74245402C9FE5797087484015CAC2D7D74245402D9622F94A8A4840CB9C2E8B894545402D9622F94A8A4840CB9C2E8B894545402C9FE5797087484015CAC2D7D74245402C9FE57970874840
26687	15129	43.445715999999997	43.469459000000001	49.484527	49.472299999999997	Ленина	0103000020E61000000100000005000000E7A6CD380DB945404DF38E5374BC4840E7A6CD380DB94540B68311FB04BE48400CE8853B17BC4540B68311FB04BE48400CE8853B17BC45404DF38E5374BC4840E7A6CD380DB945404DF38E5374BC4840
26434	15199	43.040225999999997	43.078502999999998	49.322183000000003	49.290581000000003	Ленина	0103000020E61000000100000005000000753925202685454064EB19C231A548407539252026854540E129E44A3DA94840A6D1E4620C8A4540E129E44A3DA94840A6D1E4620C8A454064EB19C231A54840753925202685454064EB19C231A54840
27477	51668	43.017732000000002	43.032617000000002	49.342396000000001	49.329492999999999	переулок Школьный	0103000020E61000000100000005000000DD0BCC0A4582454066A19DD32CAA4840DD0BCC0A45824540FF23D3A1D3AB484096253ACB2C844540FF23D3A1D3AB484096253ACB2C84454066A19DD32CAA4840DD0BCC0A4582454066A19DD32CAA4840
27503	23437	42.893908000000003	42.904293000000003	49.144739000000001	49.133222000000004	Центральная	0103000020E61000000100000005000000FFD0CC936B724540CA8D226B0D914840FFD0CC936B72454056BABBCE8692484039807EDFBF73454056BABBCE8692484039807EDFBF734540CA8D226B0D914840FFD0CC936B724540CA8D226B0D914840
27309	51600	42.711387999999999	42.748793999999997	49.057447000000003	49.039265999999998	Центральная	0103000020E61000000100000005000000286211C30E5B454020EC14AB06854840286211C30E5B45406D205D6C5A87484073B8567BD85F45406D205D6C5A87484073B8567BD85F454020EC14AB06854840286211C30E5B454020EC14AB06854840
27434	51650	42.862476000000001	42.886111	49.193876000000003	49.182901000000001	Московский переулок	0103000020E61000000100000005000000DECA129D656E4540EEB3CA4C69974840DECA129D656E45405ABDC3EDD09848401CD0D2156C7145405ABDC3EDD09848401CD0D2156C714540EEB3CA4C69974840DECA129D656E4540EEB3CA4C69974840
27091	14524	43.196137	43.241098000000001	49.074494000000001	49.041834999999999	Центральная	0103000020E610000001000000050000008D4468041B994540016A6AD95A8548408D4468041B994540C6DFF60489894840C5909C4CDC9E4540C6DFF60489894840C5909C4CDC9E4540016A6AD95A8548408D4468041B994540016A6AD95A854840
27433	51635	42.657175000000002	42.688777999999999	49.226092999999999	49.202559000000001	переулок Больничный	0103000020E61000000100000005000000D95F764F1E54454057410C74ED994840D95F764F1E544540616D8C9DF09C4840261AA4E029584540616D8C9DF09C4840261AA4E02958454057410C74ED994840D95F764F1E54454057410C74ED994840
27390	51635	42.657175000000002	42.688777999999999	49.226092999999999	49.202559000000001	Центральная	0103000020E61000000100000005000000D95F764F1E54454057410C74ED994840D95F764F1E544540616D8C9DF09C4840261AA4E029584540616D8C9DF09C4840261AA4E02958454057410C74ED994840D95F764F1E54454057410C74ED994840
27456	51661	43.303998	43.314517000000002	49.185302999999998	49.175367999999999	Пролетарская	0103000020E6100000010000000500000053060E68E9A64540E96168757296484053060E68E9A64540E36C3A02B89748409D84D21742A84540E36C3A02B89748409D84D21742A84540E96168757296484053060E68E9A64540E961687572964840
26664	51317	42.920076000000002	42.938302999999998	48.892553999999997	48.880670000000002	улица Чижова	0103000020E61000000100000005000000D1EAE40CC5754540BF4868CBB9704840D1EAE40CC5754540FDF49F353F7248408D5E0D501A784540FDF49F353F7248408D5E0D501A784540BF4868CBB9704840D1EAE40CC5754540BF4868CBB9704840
26785	37535	45.763261999999997	45.786205000000002	50.625841000000001	50.607649000000002	Центральная	0103000020E61000000100000005000000C823B891B2E146403B394371C74D4940C823B891B2E146407BBFD18E1B504940D1798D5DA2E446407BBFD18E1B504940D1798D5DA2E446403B394371C74D4940C823B891B2E146403B394371C74D4940
27015	51427	42.977801999999997	43.023345999999997	50.737926999999999	50.715046000000001	Ширяевский проезд	0103000020E6100000010000000500000050FBAD9D287D45405C9198A0865B494050FBAD9D287D4540EEEA5564745E4940073F7100FD824540EEEA5564745E4940073F7100FD8245405C9198A0865B494050FBAD9D287D45405C9198A0865B4940
27018	47878	43.149451999999997	43.181728	50.808183999999997	50.789141000000001	Центральная	0103000020E6100000010000000500000030293E3E21934540647781920265494030293E3E219345404293C492726749403D62F4DC429745404293C492726749403D62F4DC42974540647781920265494030293E3E219345406477819202654940
26792	51356	42.984171000000003	43.012782000000001	50.568761000000002	50.539282	Калачевский переулок	0103000020E61000000100000005000000F855B950F97D454026A94C3107454940F855B950F97D4540C11E1329CD4849401EFD2FD7A2814540C11E1329CD4849401EFD2FD7A281454026A94C3107454940F855B950F97D454026A94C3107454940
26699	46971	45.674356000000003	45.692932999999996	50.494062999999997	50.485255000000002	Мира	0103000020E6100000010000000500000042EE224C51D64640399CF9D51C3E494042EE224C51D64640F294D5743D3F4940DAA84E07B2D84640F294D5743D3F4940DAA84E07B2D84640399CF9D51C3E494042EE224C51D64640399CF9D51C3E4940
27057	46998	45.753919000000003	45.767429999999997	50.513857000000002	50.507361000000003	Центральная	0103000020E61000000100000005000000A16AF46A80E0464008228B34F1404940A16AF46A80E046400CE9F010C641494011FC6F253BE246400CE9F010C641494011FC6F253BE2464008228B34F1404940A16AF46A80E0464008228B34F1404940
26458	12937	45.083390000000001	45.119402999999998	49.871597999999999	49.853659999999998	Советская	0103000020E610000001000000050000001F680586AC8A4640A1F31ABB44ED48401F680586AC8A464027A1F48590EF4840AB05F698488F464027A1F48590EF4840AB05F698488F4640A1F31ABB44ED48401F680586AC8A4640A1F31ABB44ED4840
26766	11647	45.416530000000002	45.432600999999998	50.485083000000003	50.470156000000003	Школьная	0103000020E61000000100000005000000C5E6E3DA50B54640540262122E3C4940C5E6E3DA50B546403C6C2233173E4940C39B35785FB746403C6C2233173E4940C39B35785FB74640540262122E3C4940C5E6E3DA50B54640540262122E3C4940
27143	46470	45.321066000000002	45.355732000000003	50.301211000000002	50.279296000000002	60 лет Октября	0103000020E61000000100000005000000C4EDD0B018A94640AAF3A8F8BF234940C4EDD0B018A94640051901158E26494002124DA088AD4640051901158E26494002124DA088AD4640AAF3A8F8BF234940C4EDD0B018A94640AAF3A8F8BF234940
26918	51389	45.483696999999999	45.511158999999999	50.21452	50.199415000000002	Центральная	0103000020E610000001000000050000002F1686C8E9BD46407AAA436E861949402F1686C8E9BD4640412B3064751B49402D077AA86DC14640412B3064751B49402D077AA86DC146407AAA436E861949402F1686C8E9BD46407AAA436E86194940
26904	51382	45.018900000000002	45.050106999999997	49.990482	49.961157	Молодежная	0103000020E610000001000000050000007CF2B0506B82464026A94C3107FB48407CF2B0506B8246406AA33A1DC8FE48407C26FBE7698646406AA33A1DC8FE48407C26FBE76986464026A94C3107FB48407CF2B0506B82464026A94C3107FB4840
27080	13403	45.269987999999998	45.292419000000002	50.126325000000001	50.111058999999997	Центральная	0103000020E61000000100000005000000FE277FF78EA2464096766A2E370E4940FE277FF78EA2464067D5E76A2B10494051DD5CFC6DA5464067D5E76A2B10494051DD5CFC6DA5464096766A2E370E4940FE277FF78EA2464096766A2E370E4940
27004	51416	45.307321999999999	45.333579999999998	50.496132000000003	50.481397000000001	Советская	0103000020E61000000100000005000000B0ABC95356A746403EB2B96A9E3D4940B0ABC95356A74640E23FDD40813F4940C24CDBBFB2AA4640E23FDD40813F4940C24CDBBFB2AA46403EB2B96A9E3D4940B0ABC95356A746403EB2B96A9E3D4940
26676	13116	44.825924000000001	44.872304	50.024344999999997	50.001339999999999	Советская	0103000020E61000000100000005000000A27DACE0B76946409C16BCE82B004940A27DACE0B76946401A69A9BC1D034940C21550A8A76F46401A69A9BC1D034940C21550A8A76F46409C16BCE82B004940A27DACE0B76946409C16BCE82B004940
26412	12450	45.057788000000002	45.093423999999999	50.119348000000002	50.090800999999999	Школьная	0103000020E61000000100000005000000F60CE19865874640D8B8FE5D9F0B4940F60CE19865874640E86B96CB460F4940AC545051F58B4640E86B96CB460F4940AC545051F58B4640D8B8FE5D9F0B4940F60CE19865874640D8B8FE5D9F0B4940
27164	12508	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	Школьная	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
26679	12508	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	Рихарда Зорге	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
26654	12508	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	Пионерская	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
26453	12508	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	Ленина	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
27223	12508	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	Коммунистическая	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
27067	12508	45.176544999999997	45.231862999999997	50.156905000000002	50.121606999999997	30 лет Победы	0103000020E61000000100000005000000DBA2CC06999646407AFB73D1900F4940DBA2CC069996464019CA8976151449408313D1AFAD9D464019CA8976151449408313D1AFAD9D46407AFB73D1900F4940DBA2CC06999646407AFB73D1900F4940
27231	46846	45.397665000000003	45.408974999999998	50.594928000000003	50.580362000000001	Центральная	0103000020E61000000100000005000000C6E1CCAFE6B24640ABEB504D494A4940C6E1CCAFE6B24640C3BCC799264C4940D8F0F44A59B44640C3BCC799264C4940D8F0F44A59B44640ABEB504D494A4940C6E1CCAFE6B24640ABEB504D494A4940
26874	12244	45.691594000000002	45.709874999999997	50.320517000000002	50.305078000000002	Ленина	0103000020E610000001000000050000000F0EF62686D84640535DC0CB0C2749400F0EF62686D84640F16778B306294940BE9F1A2FDDDA4640F16778B306294940BE9F1A2FDDDA4640535DC0CB0C2749400F0EF62686D84640535DC0CB0C274940
27394	51638	44.787196999999999	45.896293	50.612558999999997	49.751992999999999	Совхозная	0103000020E6100000010000000500000031410DDFC264464014E97E4E41E0484031410DDFC26446406BEF5355684E49401E51A1BAB9F246406BEF5355684E49401E51A1BAB9F2464014E97E4E41E0484031410DDFC264464014E97E4E41E04840
26724	47599	45.193621999999998	45.222161999999997	50.191284000000003	50.164862999999997	Советская	0103000020E610000001000000050000009FE40E9BC898464004A9143B1A1549409FE40E9BC8984640C11F7EFE7B184940FC34EECD6F9C4640C11F7EFE7B184940FC34EECD6F9C464004A9143B1A1549409FE40E9BC898464004A9143B1A154940
27168	13196	44.928583000000003	44.975968999999999	50.077004000000002	50.054805000000002	Центральная	0103000020E61000000100000005000000904FC8CEDB7646402254A9D903074940904FC8CEDB764640A2D45E44DB09494075745C8DEC7C4640A2D45E44DB09494075745C8DEC7C46402254A9D903074940904FC8CEDB7646402254A9D903074940
26957	13390	45.378441000000002	45.401384	50.171643000000003	50.157615	Центральная	0103000020E61000000100000005000000973B33C170B04640F52D73BA2C144940973B33C170B046402ECBD765F81549409F91088D60B346402ECBD765F81549409F91088D60B34640F52D73BA2C144940973B33C170B04640F52D73BA2C144940
27234	47072	45.550953999999997	45.570554999999999	50.243062000000002	50.228306000000003	Центральная	0103000020E61000000100000005000000D9CC21A985C6464084BD8921391D4940D9CC21A985C646403F73D6A71C1F4940DEC83CF207C946403F73D6A71C1F4940DEC83CF207C9464084BD8921391D4940D9CC21A985C6464084BD8921391D4940
27053	13288	45.276420000000002	45.293253999999997	50.251691000000001	50.236770999999997	Советская	0103000020E61000000100000005000000ECFA05BB61A3464013D21A834E1E4940ECFA05BB61A3464049D9226937204940E9B5D95889A5464049D9226937204940E9B5D95889A5464013D21A834E1E4940ECFA05BB61A3464013D21A834E1E4940
26889	13288	45.276420000000002	45.293253999999997	50.251691000000001	50.236770999999997	Микрорайон	0103000020E61000000100000005000000ECFA05BB61A3464013D21A834E1E4940ECFA05BB61A3464049D9226937204940E9B5D95889A5464049D9226937204940E9B5D95889A5464013D21A834E1E4940ECFA05BB61A3464013D21A834E1E4940
26955	11862	45.128951999999998	45.179032999999997	50.469892000000002	50.447108999999998	Центральная	0103000020E610000001000000050000007C60C77F81904640A65F22DE3A3949407C60C77F819046407653CA6B253C4940CFF3A78DEA9646407653CA6B253C4940CFF3A78DEA964640A65F22DE3A3949407C60C77F81904640A65F22DE3A394940
27072	13098	45.121046999999997	45.132320999999997	50.037861999999997	50.021664999999999	Почтовая	0103000020E61000000100000005000000B323D5777E8F4640E23B31EBC5024940B323D5777E8F46406DE179A9D804494079C9FFE4EF9046406DE179A9D804494079C9FFE4EF904640E23B31EBC5024940B323D5777E8F4640E23B31EBC5024940
26633	12119	45.790273999999997	45.80489	50.384165000000003	50.372292000000002	Цветочный бульвар	0103000020E610000001000000050000008670CCB227E54640FE47A643A72F49408670CCB227E5464049A297512C3149405070B1A206E7464049A297512C3149405070B1A206E74640FE47A643A72F49408670CCB227E54640FE47A643A72F4940
26403	11924	45.622622	45.644936000000001	50.548966999999998	50.531002999999998	Советская	0103000020E6100000010000000500000093E2E313B2CF4640F88903E8F743494093E2E313B2CF4640A7CAF78C44464940AC014A438DD24640A7CAF78C44464940AC014A438DD24640F88903E8F743494093E2E313B2CF4640F88903E8F7434940
27714	51728	45.277273000000001	45.317768999999998	50.013035000000002	50.003354999999999	Мира	0103000020E610000001000000050000002B8881AE7DA3464098A3C7EF6D0049402B8881AE7DA34640085A8121AB014940605793A7ACA84640085A8121AB014940605793A7ACA8464098A3C7EF6D0049402B8881AE7DA3464098A3C7EF6D004940
26408	12358	45.447296999999999	45.47475	50.186815000000003	50.169024	Школьная	0103000020E61000000100000005000000A94C310741B946409B1E1494A2154940A94C310741B946407DB3CD8DE917494054E3A59BC4BC46407DB3CD8DE917494054E3A59BC4BC46409B1E1494A2154940A94C310741B946409B1E1494A2154940
26623	11978	45.692897000000002	45.705294000000002	50.421944000000003	50.413851000000001	Школьная	0103000020E610000001000000050000008E3F51D9B0D846405D35CF11F93449408E3F51D9B0D84640295FD042023649405308E41247DA4640295FD042023649405308E41247DA46405D35CF11F93449408E3F51D9B0D846405D35CF11F9344940
26620	11684	45.453172000000002	45.479664	50.486550000000001	50.471795999999998	Песчаная	0103000020E6100000010000000500000041BB438A01BA46401A31B3CF633C494041BB438A01BA464035EF3845473E4940C68844A165BD464035EF3845473E4940C68844A165BD46401A31B3CF633C494041BB438A01BA46401A31B3CF633C4940
26855	8914	45.172969999999999	45.191637	49.966244000000003	49.953488999999998	Новая	0103000020E61000000100000005000000359886E123964640410C74ED0BFA4840359886E12396464066FA25E2ADFB48400EDAAB8F8798464066FA25E2ADFB48400EDAAB8F87984640410C74ED0BFA4840359886E123964640410C74ED0BFA4840
27192	47146	45.148248000000002	45.168604000000002	50.146752999999997	50.124985000000002	Саратовская	0103000020E6100000010000000500000045D95BCAF9924640CBBE2B82FF0F494045D95BCAF992464081CB63CDC8124940C6FCDCD09495464081CB63CDC8124940C6FCDCD094954640CBBE2B82FF0F494045D95BCAF9924640CBBE2B82FF0F4940
27249	12931	45.295886000000003	45.330624	49.839928	49.816026000000001	Дружбы	0103000020E6100000010000000500000011ACAA97DFA54640C5573B8A73E8484011ACAA97DFA54640527FBDC282EB4840E8A221E351AA4640527FBDC282EB4840E8A221E351AA4640C5573B8A73E8484011ACAA97DFA54640C5573B8A73E84840
9777	40309	45.331522	45.471417000000002	50.136985000000003	50.053798999999998	Ленина	0103000020E61000000100000005000000C7F319506FAA46405CC7B8E2E2064940C7F319506FAA4640738577B988114940A4E36A6457BC4640738577B988114940A4E36A6457BC46405CC7B8E2E2064940C7F319506FAA46405CC7B8E2E2064940
26869	40309	45.331432999999997	45.471040000000002	50.143768000000001	50.053747000000001	Краснодонская	0103000020E6100000010000000500000057E883656CAA46400AA1832EE106494057E883656CAA46400D1B65FD66124940CE8DE9094BBC46400D1B65FD66124940CE8DE9094BBC46400AA1832EE106494057E883656CAA46400AA1832EE1064940
27125	10203	43.903947000000002	43.913110000000003	48.435751000000003	48.425505000000001	Пушкина	0103000020E610000001000000050000009E280989B4F345406AA4A5F2763648409E280989B4F34540831953B0C637484046D3D9C9E0F44540831953B0C637484046D3D9C9E0F445406AA4A5F2763648409E280989B4F345406AA4A5F276364840
27030	51436	43.659433999999997	43.684604999999998	48.544105000000002	48.533665999999997	Суворова	0103000020E610000001000000050000006BEF535568D445405A7EE02A4F4448406BEF535568D44540884B8E3BA5454840CBD6FA22A1D74540884B8E3BA5454840CBD6FA22A1D745405A7EE02A4F4448406BEF535568D445405A7EE02A4F444840
26833	10171	43.926547999999997	43.948692000000001	48.396994999999997	48.382750000000001	Верхне-Царицынская	0103000020E610000001000000050000004C16F71F99F64540A245B6F3FD3048404C16F71F99F6454077D66EBBD032484009FD4CBD6EF9454077D66EBBD032484009FD4CBD6EF94540A245B6F3FD3048404C16F71F99F64540A245B6F3FD304840
26825	9251	43.306548999999997	43.338088999999997	48.703778999999997	48.691195999999998	Школьная	0103000020E610000001000000050000008DCF64FF3CA7454021904B1C795848408DCF64FF3CA74540484E266E155A48409411178046AB4540484E266E155A48409411178046AB454021904B1C795848408DCF64FF3CA7454021904B1C79584840
26429	9432	43.586779	43.605293000000003	48.814796000000001	48.804727	Центральная	0103000020E61000000100000005000000637D03931BCB4540A69A594B01674840637D03931BCB4540B0743E3C4B684840B6BFB33D7ACD4540B0743E3C4B684840B6BFB33D7ACD4540A69A594B01674840637D03931BCB4540A69A594B01674840
27481	51670	43.588664999999999	43.621768000000003	48.653863000000001	48.639481000000004	Волгоградская	0103000020E6100000010000000500000061A6ED5F59CB4540EAB46E83DA51484061A6ED5F59CB4540408864C8B153484084D9041896CF4540408864C8B153484084D9041896CF4540EAB46E83DA51484061A6ED5F59CB4540EAB46E83DA514840
26927	9179	43.4251	43.463602000000002	48.597926000000001	48.583880999999998	Центральная	0103000020E61000000100000005000000CAC342AD69B64540BDE0D39CBC4A4840CAC342AD69B64540CCB6D3D6884C48401B2E724F57BB4540CCB6D3D6884C48401B2E724F57BB4540BDE0D39CBC4A4840CAC342AD69B64540BDE0D39CBC4A4840
27021	9652	43.877392999999998	43.926763999999999	48.700800000000001	48.680062	Молодежная	0103000020E61000000100000005000000A25EF0694EF045404DA088450C574840A25EF0694EF04540B6847CD0B3594840198EE733A0F64540B6847CD0B3594840198EE733A0F645404DA088450C574840A25EF0694EF045404DA088450C574840
26600	51305	43.534353000000003	43.551690000000001	48.573497000000003	48.559443999999999	Победы	0103000020E610000001000000050000007FC2D9AD65C44540C2F869DC9B4748407FC2D9AD65C4454054AD855968494840DFC325C79DC6454054AD855968494840DFC325C79DC64540C2F869DC9B4748407FC2D9AD65C44540C2F869DC9B474840
27010	51423	43.341898	43.360978000000003	48.398353	48.386572999999999	Первомайская	0103000020E61000000100000005000000AE484C50C3AB454020425C397B314840AE484C50C3AB4540BAA1293BFD324840AA49F08634AE4540BAA1293BFD324840AA49F08634AE454020425C397B314840AE484C50C3AB454020425C397B314840
27465	51596	43.800057000000002	43.809004000000002	48.658231000000001	48.646695999999999	Школьная	0103000020E61000000100000005000000CBF78C4468E645401D3A3DEFC6524840CBF78C4468E64540501BD5E940544840A62A6D718DE74540501BD5E940544840A62A6D718DE745401D3A3DEFC6524840CBF78C4468E645401D3A3DEFC6524840
26947	46434	43.755598999999997	43.780662	48.330142000000002	48.318950999999998	Мира	0103000020E61000000100000005000000F5F1D077B7E045406403E962D3284840F5F1D077B7E045409D84D217422A48406F9D7FBBECE345409D84D217422A48406F9D7FBBECE345406403E962D3284840F5F1D077B7E045406403E962D3284840
26757	10323	43.551887999999998	43.578567999999997	48.497062999999997	48.483638999999997	Молодежная	0103000020E6100000010000000500000005871744A4C64540FA08FCE1E73D484005871744A4C645409C86A8C29F3F48408D4127840ECA45409C86A8C29F3F48408D4127840ECA4540FA08FCE1E73D484005871744A4C64540FA08FCE1E73D4840
26882	9540	43.820959999999999	43.852939999999997	48.695008000000001	48.679836000000002	Набережная	0103000020E610000001000000050000007EA99F3715E945405D52B5DD045748407EA99F3715E94540AC3AAB05F6584840A1B94E232DED4540AC3AAB05F6584840A1B94E232DED45405D52B5DD045748407EA99F3715E945405D52B5DD04574840
27116	9277	43.576878999999998	43.612039000000003	48.906672999999998	48.892837999999998	Подгорная	0103000020E61000000100000005000000E55FCB2BD7C945402250FD8348724840E55FCB2BD7C94540469561DC0D7448403370404B57CE4540469561DC0D7448403370404B57CE45402250FD8348724840E55FCB2BD7C945402250FD8348724840
27213	10725	43.675351999999997	43.693129999999996	48.367854000000001	48.351073	Свободная	0103000020E61000000100000005000000E3A430EF71D645401AC1C6F5EF2C4840E3A430EF71D64540F5D901D7152F484030F0DC7BB8D84540F5D901D7152F484030F0DC7BB8D845401AC1C6F5EF2C4840E3A430EF71D645401AC1C6F5EF2C4840
26447	51271	43.857126999999998	43.877958999999997	48.663967999999997	48.650637000000003	Шлюзовая	0103000020E6100000010000000500000061C26856B6ED4540A648BE124853484061C26856B6ED454096CB46E7FC5448404B1DE4F560F0454096CB46E7FC5448404B1DE4F560F04540A648BE124853484061C26856B6ED4540A648BE1248534840
27303	10044	43.590488999999998	43.619503999999999	48.613571	48.597039000000002	Клубная	0103000020E61000000100000005000000E9D2BF2495CB4540E1B721C66B4C4840E9D2BF2495CB45401363997E894E4840DFDE35E84BCF45401363997E894E4840DFDE35E84BCF4540E1B721C66B4C4840E9D2BF2495CB4540E1B721C66B4C4840
26742	9357	43.488790000000002	43.514617000000001	48.745750999999998	48.728133	Донская	0103000020E61000000100000005000000514EB4AB90BE4540B6114F76335D4840514EB4AB90BE4540CAFACDC4745F48409A7B48F8DEC14540CAFACDC4745F48409A7B48F8DEC14540B6114F76335D4840514EB4AB90BE4540B6114F76335D4840
26612	11110	43.481451	43.571866999999997	48.713565000000003	48.655856999999997	пер.Озёрный	0103000020E6100000010000000500000031D0B52FA0BD454024ED461FF353484031D0B52FA0BD4540FE481119565B4840B05417F032C94540FE481119565B4840B05417F032C9454024ED461FF353484031D0B52FA0BD454024ED461FF3534840
27154	11110	43.481451	43.571866999999997	48.713565000000003	48.655856999999997	Советская	0103000020E6100000010000000500000031D0B52FA0BD454024ED461FF353484031D0B52FA0BD4540FE481119565B4840B05417F032C94540FE481119565B4840B05417F032C9454024ED461FF353484031D0B52FA0BD454024ED461FF3534840
26852	11110	43.481451	43.571866999999997	48.713565000000003	48.655856999999997	Революционная	0103000020E6100000010000000500000031D0B52FA0BD454024ED461FF353484031D0B52FA0BD4540FE481119565B4840B05417F032C94540FE481119565B4840B05417F032C9454024ED461FF353484031D0B52FA0BD454024ED461FF3534840
26389	11110	43.481451	43.571866999999997	48.713565000000003	48.655856999999997	Октябрьская	0103000020E6100000010000000500000031D0B52FA0BD454024ED461FF353484031D0B52FA0BD4540FE481119565B4840B05417F032C94540FE481119565B4840B05417F032C9454024ED461FF353484031D0B52FA0BD454024ED461FF3534840
26953	11110	43.481451	43.571866999999997	48.713565000000003	48.655856999999997	Краснознаменская	0103000020E6100000010000000500000031D0B52FA0BD454024ED461FF353484031D0B52FA0BD4540FE481119565B4840B05417F032C94540FE481119565B4840B05417F032C9454024ED461FF353484031D0B52FA0BD454024ED461FF3534840
27033	11110	43.481451	43.571866999999997	48.713565000000003	48.655856999999997	Дубинец	0103000020E6100000010000000500000031D0B52FA0BD454024ED461FF353484031D0B52FA0BD4540FE481119565B4840B05417F032C94540FE481119565B4840B05417F032C9454024ED461FF353484031D0B52FA0BD454024ED461FF3534840
26932	9439	43.620690000000003	43.649984000000003	48.654369000000003	48.643940000000001	пер.Советский	0103000020E61000000100000005000000257A19C572CF45400A4B3CA06C524840257A19C572CF45401442075DC25348402E76FBAC32D345401442075DC25348402E76FBAC32D345400A4B3CA06C524840257A19C572CF45400A4B3CA06C524840
26938	9328	43.540812000000003	43.593947	48.858494	48.841597999999998	пер.Клубный	0103000020E6100000010000000500000066A4DE5339C545408330B77BB96B484066A4DE5339C54540F7E7A221E36D484056478E7406CC4540F7E7A221E36D484056478E7406CC45408330B77BB96B484066A4DE5339C545408330B77BB96B4840
27028	9901	43.709910999999998	43.738970999999999	48.64472	48.629334999999998	Советская	0103000020E610000001000000050000000B09185DDEDA4540349D9D0C8E5048400B09185DDEDA4540DF89592F86524840A1D80A9A96DE4540DF89592F86524840A1D80A9A96DE4540349D9D0C8E5048400B09185DDEDA4540349D9D0C8E504840
26765	10286	43.567070000000001	43.598744000000003	48.523850000000003	48.509645999999996	Донская	0103000020E610000001000000050000007845F0BF95C84540C34483143C4148407845F0BF95C845403B014D840D4348408F56B5A4A3CC45403B014D840D4348408F56B5A4A3CC4540C34483143C4148407845F0BF95C84540C34483143C414840
26750	10132	43.881219000000002	43.912328000000002	48.510798000000001	48.488881999999997	Центральная	0103000020E6100000010000000500000092CEC0C8CBF0454031CD74AF933E484092CEC0C8CBF045405D6E30D461414840D09CF529C7F445405D6E30D461414840D09CF529C7F4454031CD74AF933E484092CEC0C8CBF0454031CD74AF933E4840
26591	51303	43.616638999999999	43.630930999999997	48.413772999999999	48.399023	переулок Мирный	0103000020E610000001000000050000001538D906EECE454008AD872F133348401538D906EECE4540E17B7F83F63448402B84D558C2D04540E17B7F83F63448402B84D558C2D0454008AD872F133348401538D906EECE454008AD872F13334840
27218	10903	44.034785999999997	44.079433000000002	48.636802000000003	48.602538000000003	Школьная	0103000020E61000000100000005000000E82D1EDE73044640734C16F71F4D4840E82D1EDE7304464082035ABA82514840919C4CDC2A0A464082035ABA82514840919C4CDC2A0A4640734C16F71F4D4840E82D1EDE73044640734C16F71F4D4840
27039	10903	44.034785999999997	44.079433000000002	48.636802000000003	48.602538000000003	Ленина	0103000020E61000000100000005000000E82D1EDE73044640734C16F71F4D4840E82D1EDE7304464082035ABA82514840919C4CDC2A0A464082035ABA82514840919C4CDC2A0A4640734C16F71F4D4840E82D1EDE73044640734C16F71F4D4840
26847	10903	44.034785999999997	44.079433000000002	48.636802000000003	48.602538000000003	Волгоградская	0103000020E61000000100000005000000E82D1EDE73044640734C16F71F4D4840E82D1EDE7304464082035ABA82514840919C4CDC2A0A464082035ABA82514840919C4CDC2A0A4640734C16F71F4D4840E82D1EDE73044640734C16F71F4D4840
27307	10636	43.644117999999999	43.664347999999997	48.388578000000003	48.377237999999998	Трудовой переулок	0103000020E61000000100000005000000E961687572D245407B67B45549304840E961687572D24540F9F884ECBC314840DD94F25A09D54540F9F884ECBC314840DD94F25A09D545407B67B45549304840E961687572D245407B67B45549304840
27232	51552	43.590299999999999	43.611249000000001	49.475320000000004	49.460034	Каменский проезд	0103000020E61000000100000005000000166A4DF38ECB45402786E464E2BA4840166A4DF38ECB45403F912749D7BC48403A5B40683DCE45403F912749D7BC48403A5B40683DCE45402786E464E2BA4840166A4DF38ECB45402786E464E2BA4840
27151	7291	43.967421999999999	44.012974999999997	49.333086000000002	49.284435000000002	площадь Ленина	0103000020E6100000010000000500000028B7ED7BD4FB45403C6BB75D68A4484028B7ED7BD4FB4540B360E28FA2AA48403255302AA9014640B360E28FA2AA48403255302AA90146403C6BB75D68A4484028B7ED7BD4FB45403C6BB75D68A44840
27077	51471	43.394395000000003	44.520496000000001	49.659198000000004	48.936101000000001	площадь Павших Борцов	0103000020E610000001000000050000005C5A0D897BB245405F605628D27748405C5A0D897BB2454058CB9D9960D4484073D9E89C9F42464058CB9D9960D4484073D9E89C9F4246405F605628D27748405C5A0D897BB245405F605628D2774840
26761	48757	44.643754000000001	44.661586	50.666410999999997	50.659770999999999	Победы	0103000020E61000000100000005000000A855F48766524640B3EC496073544940A855F48766524640EA58A5F44C554940E8BE9CD9AE544640EA58A5F44C554940E8BE9CD9AE544640B3EC496073544940A855F48766524640B3EC496073544940
27211	6323	45.119691000000003	45.147350000000003	50.673450000000003	50.652706999999999	Молодежная	0103000020E610000001000000050000001250E108528F4640656F29E78B5349401250E108528F4640E0BE0E9C335649406688635DDC924640E0BE0E9C335649406688635DDC924640656F29E78B5349401250E108528F4640656F29E78B534940
26392	7047	44.532228000000003	44.562680999999998	50.954497000000003	50.936706000000001	Молодежная	0103000020E61000000100000005000000FC010F0C20444640C6FB71FBE5774940FC010F0C20444640A8902BF52C7A4940508A56EE05484640A8902BF52C7A4940508A56EE05484640C6FB71FBE5774940FC010F0C20444640C6FB71FBE5774940
26807	49305	44.274816000000001	44.293078999999999	51.105680999999997	51.090200000000003	Степная	0103000020E610000001000000050000007235B22B2D234640B30C71AC8B8B49407235B22B2D2346407F677BF4868D49407B12D89C832546407F677BF4868D49407B12D89C83254640B30C71AC8B8B49407235B22B2D234640B30C71AC8B8B4940
27159	6537	45.213070999999999	45.233822000000004	50.883671999999997	50.869990999999999	Центральная	0103000020E61000000100000005000000EE5C18E9459B46403C6876DD5B6F4940EE5C18E9459B46400932022A1C714940EC8A19E1ED9D46400932022A1C714940EC8A19E1ED9D46403C6876DD5B6F4940EE5C18E9459B46403C6876DD5B6F4940
26611	6679	44.952595000000002	44.979446000000003	51.077491999999999	51.056820999999999	Эльтонская	0103000020E61000000100000005000000A4AA09A2EE794640EE5C18E945874940A4AA09A2EE794640CFD90242EB89494059198D7C5E7D4640CFD90242EB89494059198D7C5E7D4640EE5C18E945874940A4AA09A2EE794640EE5C18E945874940
27246	49106	45.127882999999997	45.144376000000001	51.025843000000002	51.012363000000001	Молодежная	0103000020E61000000100000005000000705B5B785E90464019575C1C95814940705B5B785E9046404FEACBD24E834940E529ABE97A9246404FEACBD24E834940E529ABE97A92464019575C1C95814940705B5B785E90464019575C1C95814940
27145	6983	44.750447000000001	44.776418	51.099499999999999	51.091009	Зеленая	0103000020E61000000100000005000000CF30B5A50E6046402252D32EA68B4940CF30B5A50E604640DBF97E6ABC8C49404B033FAA61634640DBF97E6ABC8C49404B033FAA616346402252D32EA68B4940CF30B5A50E6046402252D32EA68B4940
27256	4282	44.720075000000001	44.751696000000003	50.853760000000001	50.822315000000003	Центральная	0103000020E6100000010000000500000067D5E76A2B5C46405001309E4169494067D5E76A2B5C46400551F701486D49405B441493376046400551F701486D49405B441493376046405001309E4169494067D5E76A2B5C46405001309E41694940
27384	51632	44.884970000000003	44.907615999999997	50.661878000000002	50.650410999999998	улица Центральная	0103000020E6100000010000000500000077F86BB246714640B5FAEAAA4053494077F86BB24671464090F8156BB8544940C5A9D6C22C74464090F8156BB8544940C5A9D6C22C744640B5FAEAAA4053494077F86BB246714640B5FAEAAA40534940
27137	2780	44.680280000000003	44.693916000000002	50.823658000000002	50.815936000000001	 Ленина	0103000020E61000000100000005000000BB0F406A1357464085D0419770684940BB0F406A135746405D8B16A06D694940E8154F3DD25846405D8B16A06D694940E8154F3DD258464085D0419770684940BB0F406A1357464085D0419770684940
26482	6997	44.681671999999999	44.709772000000001	50.888734999999997	50.869849000000002	Центральная	0103000020E61000000100000005000000A94C310741574640AABA4736576F4940A94C310741574640C0E78711C2714940EACE13CFD95A4640C0E78711C2714940EACE13CFD95A4640AABA4736576F4940A94C310741574640AABA4736576F4940
27288	30181	44.692658999999999	44.725797	50.792158999999998	50.770386000000002	Фрунзе	0103000020E61000000100000005000000D923D40CA9584640ECA529029C624940D923D40CA9584640B41D537765654940784485EAE65C4640B41D537765654940784485EAE65C4640ECA529029C624940D923D40CA9584640ECA529029C624940
27038	45450	44.802036999999999	44.847437999999997	50.914330999999997	50.858462000000003	Нефтяников	0103000020E610000001000000050000004A97FE25A9664640EC6D3315E26D49404A97FE25A9664640075C57CC087549409EB12FD9786C4640075C57CC087549409EB12FD9786C4640EC6D3315E26D49404A97FE25A9664640EC6D3315E26D4940
26697	45450	44.802036999999999	44.847437999999997	50.914330999999997	50.858462000000003	Ленина	0103000020E610000001000000050000004A97FE25A9664640EC6D3315E26D49404A97FE25A9664640075C57CC087549409EB12FD9786C4640075C57CC087549409EB12FD9786C4640EC6D3315E26D49404A97FE25A9664640EC6D3315E26D4940
26375	45450	44.802036999999999	44.847437999999997	50.914330999999997	50.858462000000003	Карла Маркса	0103000020E610000001000000050000004A97FE25A9664640EC6D3315E26D49404A97FE25A9664640075C57CC087549409EB12FD9786C4640075C57CC087549409EB12FD9786C4640EC6D3315E26D49404A97FE25A9664640EC6D3315E26D4940
26996	48739	44.698155999999997	44.762197	50.723981999999999	50.671435000000002	Новая	0103000020E61000000100000005000000CAC0012D5D594640E4310395F1554940CAC0012D5D59464043723271AB5C4940FE0DDAAB8F61464043723271AB5C4940FE0DDAAB8F614640E4310395F1554940CAC0012D5D594640E4310395F1554940
27001	48739	44.698155999999997	44.762197	50.723981999999999	50.671435000000002	Ленина	0103000020E61000000100000005000000CAC0012D5D594640E4310395F1554940CAC0012D5D59464043723271AB5C4940FE0DDAAB8F61464043723271AB5C4940FE0DDAAB8F614640E4310395F1554940CAC0012D5D594640E4310395F1554940
27079	48739	44.698155999999997	44.762197	50.723981999999999	50.671435000000002	Камышинская	0103000020E61000000100000005000000CAC0012D5D594640E4310395F1554940CAC0012D5D59464043723271AB5C4940FE0DDAAB8F61464043723271AB5C4940FE0DDAAB8F614640E4310395F1554940CAC0012D5D594640E4310395F1554940
26394	7101	44.454622999999998	44.497768999999998	51.143448999999997	51.125295999999999	Продольная	0103000020E6100000010000000500000034812216313A4640E92807B30990494034812216313A46406BD26D895C92494037FB03E5B63F46406BD26D895C92494037FB03E5B63F4640E92807B30990494034812216313A4640E92807B309904940
26440	5911	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	Строителей	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
26900	5911	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	Советская	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
26945	5911	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	Мира	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
26808	5911	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	Матросова	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
9848	5911	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	Ленина	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
26986	5911	44.750473999999997	44.832410000000003	50.996834	50.960261000000003	35 лет Победы	0103000020E61000000100000005000000C83F33880F604640E84F1BD5E97A4940C83F33880F6046403BC5AA41987F4940836E2F698C6A46403BC5AA41987F4940836E2F698C6A4640E84F1BD5E97A4940C83F33880F604640E84F1BD5E97A4940
27276	49292	44.306266000000001	44.331141000000002	51.158585000000002	51.144568	Школьная	0103000020E6100000010000000500000039F06AB933274640290648348192494039F06AB9332746406E5166834C944940B0AE0AD4622A46406E5166834C944940B0AE0AD4622A4640290648348192494039F06AB9332746402906483481924940
27178	6711	44.795318000000002	44.815610999999997	51.155484000000001	51.139837999999997	Верхняя	0103000020E61000000100000005000000C7F5EFFACC654640785E2A36E6914940C7F5EFFACC654640908653E6E693494001A1F5F065684640908653E6E693494001A1F5F065684640785E2A36E6914940C7F5EFFACC654640785E2A36E6914940
26599	49071	45.239840000000001	45.271020999999998	50.766306999999998	50.754626999999999	Мира	0103000020E61000000100000005000000E622BE13B39E4640DCD6169E97604940E622BE13B39E464012D9075916624940BDC3EDD0B0A2464012D9075916624940BDC3EDD0B0A24640DCD6169E97604940E622BE13B39E4640DCD6169E97604940
27017	6357	45.033731000000003	45.077362000000001	50.791088000000002	50.768791	Центральная	0103000020E6100000010000000500000042EE224C51844640C53A55BE6762494042EE224C518446400821205F4265494001FA7DFFE68946400821205F4265494001FA7DFFE6894640C53A55BE6762494042EE224C51844640C53A55BE67624940
27239	6357	45.033731000000003	45.077362000000001	50.791088000000002	50.768791	 Рабочая	0103000020E6100000010000000500000042EE224C51844640C53A55BE6762494042EE224C518446400821205F4265494001FA7DFFE68946400821205F4265494001FA7DFFE6894640C53A55BE6762494042EE224C51844640C53A55BE67624940
26980	7141	44.478096000000001	44.504911	51.071005999999997	51.053027999999998	Центральная	0103000020E61000000100000005000000992CEE3F323D4640DAE21A9FC9864940992CEE3F323D4640EEE87FB916894940013274ECA0404640EEE87FB916894940013274ECA0404640DAE21A9FC9864940992CEE3F323D4640DAE21A9FC9864940
26843	6239	44.947223000000001	44.979140000000001	50.661661000000002	50.649799999999999	Лиманская	0103000020E610000001000000050000006F826F9A3E7946406C787AA52C5349406F826F9A3E794640F304C24EB15449404C1AA375547D4640F304C24EB15449404C1AA375547D46406C787AA52C5349406F826F9A3E7946406C787AA52C534940
27043	6918	44.736640000000001	44.762323000000002	51.140324	51.125391999999998	Мира	0103000020E61000000100000005000000757632384A5E46400B9755D80C904940757632384A5E4640056C0723F69149408BFED0CC93614640056C0723F69149408BFED0CC936146400B9755D80C904940757632384A5E46400B9755D80C904940
26701	49178	44.687448000000003	44.706538000000002	50.991737000000001	50.971975	Мира	0103000020E61000000100000005000000AED9CA4BFE574640CAC342AD697C4940AED9CA4BFE574640D89DEE3CF17E4940CDB051D66F5A4640D89DEE3CF17E4940CDB051D66F5A4640CAC342AD697C4940AED9CA4BFE574640CAC342AD697C4940
27037	6476	45.158920000000002	45.183982999999998	50.911757999999999	50.890557999999999	 Центральная	0103000020E610000001000000050000001557957D579446407898F6CDFD7149401557957D57944640E5EE737CB47449408E0244C18C974640E5EE737CB47449408E0244C18C9746407898F6CDFD7149401557957D579446407898F6CDFD714940
27427	51652	44.736631000000003	44.788482000000002	51.046477000000003	51.011032	улица Центральная	0103000020E61000000100000005000000221CB3EC495E4640D09A1F7F69814940221CB3EC495E4640138255F5F28549400ABE69FAEC644640138255F5F28549400ABE69FAEC644640D09A1F7F69814940221CB3EC495E4640D09A1F7F69814940
27204	5521	43.438386000000001	43.478414999999998	50.834195000000001	50.808497000000003	 Советская	0103000020E610000001000000050000001B834E081DB8454002F566D47C6749401B834E081DB845404DBED9E6C66A49403A75E5B33CBD45404DBED9E6C66A49403A75E5B33CBD454002F566D47C6749401B834E081DB8454002F566D47C674940
26901	5783	43.513629000000002	43.542994999999998	51.041997000000002	51.026001999999998	Боевая	0103000020E610000001000000050000007BA35698BEC14540B7D09508548349407BA35698BEC14540DBC35E28608549401D7233DC80C54540DBC35E28608549401D7233DC80C54540B7D09508548349407BA35698BEC14540B7D0950854834940
26982	5184	43.764870000000002	43.840336999999998	50.909742000000001	50.870764000000001	Красная	0103000020E6100000010000000500000084D89942E7E145405F44DB31756F494084D89942E7E1454019E6046D72744940334FAE2990EB454019E6046D72744940334FAE2990EB45405F44DB31756F494084D89942E7E145405F44DB31756F4940
26469	4476	43.682189000000001	43.731695000000002	51.060330999999998	51.022914	Ленина	0103000020E6100000010000000500000071581AF851D745406E4F90D8EE82494071581AF851D74540ADF71BEDB8874940C8D2872EA8DD4540ADF71BEDB8874940C8D2872EA8DD45406E4F90D8EE82494071581AF851D745406E4F90D8EE824940
27172	5370	43.552453999999997	43.575899999999997	50.618772	50.596299999999999	Центральная	0103000020E61000000100000005000000AE450BD0B6C645406A4DF38E534C4940AE450BD0B6C645401BD7BFEB334F494019E25817B7C945401BD7BFEB334F494019E25817B7C945406A4DF38E534C4940AE450BD0B6C645406A4DF38E534C4940
26795	5822	43.383670000000002	43.398752000000002	50.917738	50.900483000000001	Ленинская	0103000020E61000000100000005000000693A3B191CB145404FCDE50643734940693A3B191CB14540F225547078754940789B374E0AB34540F225547078754940789B374E0AB345404FCDE50643734940693A3B191CB145404FCDE50643734940
26965	46233	43.823600999999996	43.842286000000001	50.683450000000001	50.671247000000001	Солнечная	0103000020E61000000100000005000000F8F9EFC16BE94540E144F46BEB554940F8F9EFC16BE94540C139234A7B57494078F01307D0EB4540C139234A7B57494078F01307D0EB4540E144F46BEB554940F8F9EFC16BE94540E144F46BEB554940
27085	4405	43.736590999999997	43.761609	50.984048999999999	50.970551999999998	Пролетарская	0103000020E6100000010000000500000093C3279D48DE4540A088450C3B7C494093C3279D48DE4540AC545051F57D49406DAB59677CE14540AC545051F57D49406DAB59677CE14540A088450C3B7C494093C3279D48DE4540A088450C3B7C4940
26472	4629	43.969163999999999	44.072955999999998	51.037042	51.001334	Московская	0103000020E61000000100000005000000F33AE2900DFC4540BA2F67B62B804940F33AE2900DFC45400A4AD1CABD8449400306499F560946400A4AD1CABD8449400306499F56094640BA2F67B62B804940F33AE2900DFC4540BA2F67B62B804940
27412	51646	43.500540000000001	43.549570000000003	50.794840999999998	50.750433000000001	Центральная	0103000020E61000000100000005000000802BD9B111C045406A6B44300E604940802BD9B111C045408D429259BD6549406E6E4C4F58C645408D429259BD6549406E6E4C4F58C645406A6B44300E604940802BD9B111C045406A6B44300E604940
26796	5017	43.904567	43.957397	50.864693000000003	50.815776999999997	Центральная	0103000020E610000001000000050000003A05F9D9C8F345401CEA77616B6849403A05F9D9C8F34540420A9E42AE6E4940EE2422FC8BFA4540420A9E42AE6E4940EE2422FC8BFA45401CEA77616B6849403A05F9D9C8F345401CEA77616B684940
27175	5579	43.63138	43.674742000000002	50.830173000000002	50.806955000000002	Мира	0103000020E610000001000000050000009BAC510FD1D04540FE2B2B4D4A6749409BAC510FD1D04540D882DE1B436A49406B9E23F25DD64540D882DE1B436A49406B9E23F25DD64540FE2B2B4D4A6749409BAC510FD1D04540FE2B2B4D4A674940
27274	5163	43.840184000000001	43.87247	50.863852000000001	50.846071000000002	Новосельская	0103000020E61000000100000005000000AD4F39268BEB4540098CF50D4C6C4940AD4F39268BEB4540C74ACCB3926E4940DD5ED218ADEF4540C74ACCB3926E4940DD5ED218ADEF4540098CF50D4C6C4940AD4F39268BEB4540098CF50D4C6C4940
27529	5163	43.840184000000001	43.87247	50.863852000000001	50.846071000000002	 Сорокина	0103000020E61000000100000005000000AD4F39268BEB4540098CF50D4C6C4940AD4F39268BEB4540C74ACCB3926E4940DD5ED218ADEF4540C74ACCB3926E4940DD5ED218ADEF4540098CF50D4C6C4940AD4F39268BEB4540098CF50D4C6C4940
26970	3785	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Школьная	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
27054	3785	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Первомайская	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
26466	3785	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Мира	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
27073	3785	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Ленинская	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
26956	3785	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Красная	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
27166	3785	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Гоголя	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
27003	51415	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Новоселовская	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
27088	51415	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	Вокзальная	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
27112	51415	43.705967000000001	43.809561000000002	50.976036000000001	50.916477	 Большая Казанская	0103000020E6100000010000000500000012876C205DDA4540A2444B1E4F75494012876C205DDA4540FDDB65BFEE7C4940FC8EE1B19FE74540FDDB65BFEE7C4940FC8EE1B19FE74540A2444B1E4F75494012876C205DDA4540A2444B1E4F754940
26793	5613	43.595033999999998	43.634605000000001	50.975616000000002	50.954593000000003	Советская	0103000020E610000001000000050000000801F9122ACC4540CAFE791A307A49400801F9122ACC454028BA2EFCE07C4940657094BC3AD1454028BA2EFCE07C4940657094BC3AD14540CAFE791A307A49400801F9122ACC4540CAFE791A307A4940
27300	5048	43.895511999999997	43.991703000000001	50.906942000000001	50.864942999999997	Усадьба школы	0103000020E6100000010000000500000078962023A0F24540BAF3C473B66E494078962023A0F2454036AFEAAC167449402C2CB81FF0FE454036AFEAAC167449402C2CB81FF0FE4540BAF3C473B66E494078962023A0F24540BAF3C473B66E4940
27183	5048	43.895511999999997	43.991703000000001	50.906942000000001	50.864942999999997	Мельничная	0103000020E6100000010000000500000078962023A0F24540BAF3C473B66E494078962023A0F2454036AFEAAC167449402C2CB81FF0FE454036AFEAAC167449402C2CB81FF0FE4540BAF3C473B66E494078962023A0F24540BAF3C473B66E4940
27263	5690	43.566037000000001	43.602480999999997	51.000275000000002	50.984099999999998	Новая	0103000020E61000000100000005000000B9A981E673C845402EFF21FDF67D4940B9A981E673C84540D200DE02098049400EBBEF181ECD4540D200DE02098049400EBBEF181ECD45402EFF21FDF67D4940B9A981E673C845402EFF21FDF67D4940
27065	4582	43.852652999999997	43.886043000000001	51.051828	51.036158	Центральная	0103000020E610000001000000050000000BEBC6BB23ED454090BE49D3A08449400BEBC6BB23ED45403082C64CA2864940C4EC65DB69F145403082C64CA2864940C4EC65DB69F1454090BE49D3A08449400BEBC6BB23ED454090BE49D3A0844940
26978	4929	43.810585000000003	43.889465999999999	50.934901000000004	50.906902000000002	Советская	0103000020E6100000010000000500000068D0D03FC1E74540A8565F5D1574494068D0D03FC1E74540B5FF01D6AA774940B4739A05DAF14540B5FF01D6AA774940B4739A05DAF14540A8565F5D1574494068D0D03FC1E74540A8565F5D15744940
27171	5291	43.743893999999997	43.778371	50.649102999999997	50.636319	Микрорайон-1	0103000020E6100000010000000500000066D828EB37DF45406669A7E67251494066D828EB37DF4540245E9ECE15534940D19332A9A1E34540245E9ECE15534940D19332A9A1E345406669A7E67251494066D828EB37DF45406669A7E672514940
26892	4486	43.911034000000001	44.016945999999997	51.103012	50.850068999999998	Молодежная	0103000020E61000000100000005000000A4C519C39CF44540F52B9D0FCF6C4940A4C519C39CF445403B8C497F2F8D494025E659492B0246403B8C497F2F8D494025E659492B024640F52B9D0FCF6C4940A4C519C39CF44540F52B9D0FCF6C4940
27259	4486	43.911034000000001	44.016945999999997	51.103012	50.850068999999998	Ленина	0103000020E61000000100000005000000A4C519C39CF44540F52B9D0FCF6C4940A4C519C39CF445403B8C497F2F8D494025E659492B0246403B8C497F2F8D494025E659492B024640F52B9D0FCF6C4940A4C519C39CF44540F52B9D0FCF6C4940
27264	5744	43.543551999999998	43.574032000000003	51.027973000000003	51.006402000000001	Веселая	0103000020E6100000010000000500000073D6A71C93C545408350DEC7D180494073D6A71C93C54540E415889E94834940C26D6DE179C94540E415889E94834940C26D6DE179C945408350DEC7D180494073D6A71C93C545408350DEC7D1804940
27493	51679	43.723305000000003	43.748807999999997	50.768352999999998	50.746248999999999	Степная	0103000020E6100000010000000500000043041C4295DC45401BD65416855F494043041C4295DC454049641F6459624940D87DC7F0D8DF454049641F6459624940D87DC7F0D8DF45401BD65416855F494043041C4295DC45401BD65416855F4940
27506	51684	44.644221000000002	44.663660999999998	49.048738	49.036673	Центральная	0103000020E61000000100000005000000BE326FD575524640B7D26BB3B1844840BE326FD5755246404609FA0B3D864840B950F9D7F25446404609FA0B3D864840B950F9D7F2544640B7D26BB3B1844840BE326FD575524640B7D26BB3B1844840
26873	3015	44.603932	44.624647000000003	49.488278999999999	49.465263	Кленовая	0103000020E610000001000000050000000281CEA44D4D4640F984ECBC8DBB48400281CEA44D4D46406B2920ED7FBE4840B345D26EF44F46406B2920ED7FBE4840B345D26EF44F4640F984ECBC8DBB48400281CEA44D4D4640F984ECBC8DBB4840
27237	2903	44.933208999999998	44.955784000000001	49.321496000000003	49.297055999999998	 Советская	0103000020E610000001000000050000009BAA7B6473774640508A56EE05A648409BAA7B6473774640BDE5EAC726A9484021054F21577A4640BDE5EAC726A9484021054F21577A4640508A56EE05A648409BAA7B6473774640508A56EE05A64840
26456	48065	44.404246000000001	44.433576000000002	49.193916999999999	49.177748000000001	Центральная	0103000020E61000000100000005000000F8C43A55BE334640F7764B72C0964840F8C43A55BE334640B891B245D29848404E2A1A6B7F374640B891B245D29848404E2A1A6B7F374640F7764B72C0964840F8C43A55BE334640F7764B72C0964840
27068	48095	44.905703000000003	44.927945000000001	49.314971999999997	49.302508000000003	Мира	0103000020E61000000100000005000000CE716E13EE734640A2630795B8A64840CE716E13EE734640EE93A30051A848404DBED9E6C6764640EE93A30051A848404DBED9E6C6764640A2630795B8A64840CE716E13EE734640A2630795B8A64840
26985	29901	44.705495999999997	44.737349999999999	49.240282000000001	49.222262999999998	Мира	0103000020E61000000100000005000000BABA63B14D5A4640300E2E1D739C4840BABA63B14D5A4640A3E8818FC19E484051DA1B7C615E4640A3E8818FC19E484051DA1B7C615E4640300E2E1D739C4840BABA63B14D5A4640300E2E1D739C4840
26653	3366	44.901077000000001	44.923786	49.641368	49.626629999999999	Комсомольская	0103000020E61000000100000005000000C216BB7D56734640A3586E6935D04840C216BB7D56734640B859BC5818D248405740A19E3E764640B859BC5818D248405740A19E3E764640A3586E6935D04840C216BB7D56734640A3586E6935D04840
26838	2592	44.694895000000002	44.724727999999999	48.997033000000002	48.976877999999999	Степная	0103000020E61000000100000005000000B493C151F258464048179B560A7D4840B493C151F2584640320400C79E7F48406C3F19E3C35C4640320400C79E7F48406C3F19E3C35C464048179B560A7D4840B493C151F258464048179B560A7D4840
26787	2592	44.694895000000002	44.724727999999999	48.997033000000002	48.976877999999999	Песчанная	0103000020E61000000100000005000000B493C151F258464048179B560A7D4840B493C151F2584640320400C79E7F48406C3F19E3C35C4640320400C79E7F48406C3F19E3C35C464048179B560A7D4840B493C151F258464048179B560A7D4840
27247	48118	44.517280999999997	44.532184000000001	49.451115000000001	49.443922999999998	Большая	0103000020E61000000100000005000000CCEB8843364246409A780778D2B84840CCEB88433642464016DEE522BEB948402CBAF59A1E44464016DEE522BEB948402CBAF59A1E4446409A780778D2B84840CCEB8843364246409A780778D2B84840
26407	51267	44.841760999999998	44.872644999999999	49.124008000000003	49.102742999999997	Московская	0103000020E610000001000000050000002D060FD3BE6B46404B72C0AE268D48402D060FD3BE6B4640A038807EDF8F48404B02D4D4B26F4640A038807EDF8F48404B02D4D4B26F46404B72C0AE268D48402D060FD3BE6B46404B72C0AE268D4840
26752	47806	44.860517999999999	44.884681999999998	49.188299999999998	49.170302999999997	Центральная	0103000020E6100000010000000500000046CF2D74256E464091B41B7DCC95484046CF2D74256E46401CEBE2361A98484010AE80423D7146401CEBE2361A98484010AE80423D71464091B41B7DCC95484046CF2D74256E464091B41B7DCC954840
27136	19499	44.512852000000002	44.545326000000003	49.367494000000001	49.346269999999997	Центральная	0103000020E6100000010000000500000017D86322A5414640FFCA4A9352AC484017D86322A5414640F5BC1B0B0AAF48404AD40B3ECD454640F5BC1B0B0AAF48404AD40B3ECD454640FFCA4A9352AC484017D86322A5414640FFCA4A9352AC4840
26952	1739	44.407614000000002	44.443339999999999	49.297508999999998	49.278264	Гагарина	0103000020E6100000010000000500000025B20FB22C344640BBD39D279EA3484025B20FB22C34464001A260C614A648401B81785DBF38464001A260C614A648401B81785DBF384640BBD39D279EA3484025B20FB22C344640BBD39D279EA34840
26872	3230	45.212783000000002	45.238591999999997	49.730260999999999	49.720413000000001	Центральная	0103000020E6100000010000000500000088122D793C9B46407F4E417E36DC484088122D793C9B4640AA45443179DD48402A8BC22E8A9E4640AA45443179DD48402A8BC22E8A9E46407F4E417E36DC484088122D793C9B46407F4E417E36DC4840
26616	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Юбилейная	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
26836	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Шевченко	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
26769	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Советская	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
26950	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Пугачева	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
26941	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Почтовая	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
26617	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Магистральная	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
26625	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	Гагарина	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
27228	1882	44.780594999999998	44.852010999999997	49.070315000000001	49.034547000000003	30 лет Победы,	0103000020E61000000100000005000000E7357689EA63464064963D096C844840E7357689EA63464089B5F81400894840876A4AB20E6D464089B5F81400894840876A4AB20E6D464064963D096C844840E7357689EA63464064963D096C844840
26541	46252	44.629534	44.655943999999998	49.308024000000003	49.288395999999999	Школьная	0103000020E610000001000000050000002BDCF291945046400B26FE28EAA448402BDCF291945046400A3197546DA74840F30016F9F55346400A3197546DA74840F30016F9F55346400B26FE28EAA448402BDCF291945046400B26FE28EAA44840
26390	3128	45.037675	45.106279000000001	49.567334000000002	49.541362999999997	Пушкина	0103000020E610000001000000050000003B70CE88D2844640D921FE614BC548403B70CE88D284464056F487669EC8484034A0DE8C9A8D464056F487669EC8484034A0DE8C9A8D4640D921FE614BC548403B70CE88D2844640D921FE614BC54840
26944	3128	45.037675	45.106279000000001	49.567334000000002	49.541362999999997	Крестьянская	0103000020E610000001000000050000003B70CE88D2844640D921FE614BC548403B70CE88D284464056F487669EC8484034A0DE8C9A8D464056F487669EC8484034A0DE8C9A8D4640D921FE614BC548403B70CE88D2844640D921FE614BC54840
26942	2797	44.913797000000002	44.951678999999999	49.262605000000001	49.247599000000001	Школьный переулок	0103000020E610000001000000050000006A17D34CF7744640DBC2F352B19F48406A17D34CF77446400F62670A9DA148401EA5129ED07946400F62670A9DA148401EA5129ED0794640DBC2F352B19F48406A17D34CF7744640DBC2F352B19F4840
27236	2937	44.956708999999996	44.993594000000002	49.391395000000003	49.372222000000001	Школьная	0103000020E61000000100000005000000F964C570757A4640056D72F8A4AF4840F964C570757A4640B2683A3B19B248403CC093162E7F4640B2683A3B19B248403CC093162E7F4640056D72F8A4AF4840F964C570757A4640056D72F8A4AF4840
26398	3384	45.059207000000001	45.080264	49.693848000000003	49.678887000000003	Центральная	0103000020E61000000100000005000000DE58501894874640FC56EBC4E5D64840DE585018948746409032E202D0D84840E8853B17468A46409032E202D0D84840E8853B17468A4640FC56EBC4E5D64840DE58501894874640FC56EBC4E5D64840
27058	51452	44.574530000000003	44.5854	49.223244999999999	49.212135000000004	Конторская	0103000020E610000001000000050000001349F4328A49464022AB5B3D279B48401349F4328A4946406DFFCA4A939C4840098A1F63EE4A46406DFFCA4A939C4840098A1F63EE4A464022AB5B3D279B48401349F4328A49464022AB5B3D279B4840
27527	51692	44.093733999999998	44.13944	50.373556000000001	50.345821999999998	Комсомольская	0103000020E61000000100000005000000FA42C879FF0B4640601E32E5432C4940FA42C879FF0B4640BF9CD9AED02F49408BE07F2BD9114640BF9CD9AED02F49408BE07F2BD9114640601E32E5432C4940FA42C879FF0B4640601E32E5432C4940
26754	28213	44.093733999999998	44.13944	50.373556000000001	50.345821999999998	Федорцова	0103000020E61000000100000005000000FA42C879FF0B4640601E32E5432C4940FA42C879FF0B4640BF9CD9AED02F49408BE07F2BD9114640BF9CD9AED02F49408BE07F2BD9114640601E32E5432C4940FA42C879FF0B4640601E32E5432C4940
27648	51717	44.599260999999998	44.605549000000003	48.545805000000001	48.544702000000001	Центральная	0103000020E6100000010000000500000056629E95B44C46406C088ECBB845484056629E95B44C4640247F30F0DC45484011902FA1824D4640247F30F0DC45484011902FA1824D46406C088ECBB845484056629E95B44C46406C088ECBB8454840
27324	31935	44.204092000000003	44.233241999999997	48.858606999999999	48.842771999999997	улица Центральная	0103000020E6100000010000000500000008B0C8AF1F1A464004FEF0F3DF6B484008B0C8AF1F1A4640EF8E8CD5E66D4840DD06B5DFDA1D4640EF8E8CD5E66D4840DD06B5DFDA1D464004FEF0F3DF6B484008B0C8AF1F1A464004FEF0F3DF6B4840
27118	31935	44.204092000000003	44.233241999999997	48.858606999999999	48.842771999999997	Центральная	0103000020E6100000010000000500000008B0C8AF1F1A464004FEF0F3DF6B484008B0C8AF1F1A4640EF8E8CD5E66D4840DD06B5DFDA1D4640EF8E8CD5E66D4840DD06B5DFDA1D464004FEF0F3DF6B484008B0C8AF1F1A464004FEF0F3DF6B4840
26935	32368	44.200526000000004	44.229469000000002	48.961975000000002	48.936421000000003	Советская	0103000020E61000000100000005000000B5FF01D6AA194640D124B1A4DC774840B5FF01D6AA194640E9482EFF217B484011397D3D5F1D4640E9482EFF217B484011397D3D5F1D4640D124B1A4DC774840B5FF01D6AA194640D124B1A4DC774840
27203	5	44.001998	44.040624999999999	49.060605000000002	49.041007999999998	Специалистов	0103000020E610000001000000050000002654707841004640EB6F09C03F8548402654707841004640AF7C96E7C18748403333333333054640AF7C96E7C18748403333333333054640EB6F09C03F8548402654707841004640EB6F09C03F854840
26563	32007	44.135567999999999	44.158709000000002	48.833877000000001	48.822952000000001	Рабочая	0103000020E610000001000000050000002B31CF4A5A114640C216BB7D566948402B31CF4A5A1146407CF1457BBC6A48405A4A9693501446407CF1457BBC6A48405A4A969350144640C216BB7D566948402B31CF4A5A114640C216BB7D56694840
26830	51369	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	2-я Продольная	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26782	306	43.796975000000003	43.828048000000003	48.920527999999997	48.894111000000002	Спортивная	0103000020E61000000100000005000000645DDC4603E6454037FFAF3A72724840645DDC4603E64540B1868BDCD375484055C2137AFDE94540B1868BDCD375484055C2137AFDE9454037FFAF3A72724840645DDC4603E6454037FFAF3A72724840
27131	166	44.007863999999998	44.138820000000003	49.046635999999999	49.018343000000002	переулок Советский	0103000020E610000001000000050000006A6803B001014640268E3C10598248406A6803B0010146407B681F2BF8854840EF0390DAC41146407B681F2BF8854840EF0390DAC4114640268E3C10598248406A6803B001014640268E3C1059824840
27193	31539	44.521645999999997	44.579597	48.858173999999998	48.837328999999997	Советская	0103000020E610000001000000050000006B0BCF4BC5424640067FBF982D6B48406B0BCF4BC5424640852348A5D86D48400BEE073C304A4640852348A5D86D48400BEE073C304A4640067FBF982D6B48406B0BCF4BC5424640067FBF982D6B4840
27359	51622	44.372373000000003	44.392549000000002	48.889626999999997	48.878833	улица Молодежная	0103000020E61000000100000005000000EB7420EBA92F4640A2D288997D704840EB7420EBA92F4640BD512B4CDF714840EC89AE0B3F324640BD512B4CDF714840EC89AE0B3F324640A2D288997D704840EB7420EBA92F4640A2D288997D704840
26826	31777	44.044424999999997	44.073135000000001	48.691000000000003	48.659154000000001	Озерная	0103000020E61000000100000005000000F90FE9B7AF054640888384285F544840F90FE9B7AF0546409CC420B072584840B398D87C5C0946409CC420B072584840B398D87C5C094640888384285F544840F90FE9B7AF054640888384285F544840
26744	31777	44.044424999999997	44.073135000000001	48.691000000000003	48.659154000000001	Ленина	0103000020E61000000100000005000000F90FE9B7AF054640888384285F544840F90FE9B7AF0546409CC420B072584840B398D87C5C0946409CC420B072584840B398D87C5C094640888384285F544840F90FE9B7AF054640888384285F544840
26564	32023	44.292943999999999	44.309553999999999	48.844580999999998	48.835413000000003	Центральная	0103000020E610000001000000050000009BC761307F2546409ED32CD0EE6A48409BC761307F25464057E9EE3A1B6C4840492C29779F27464057E9EE3A1B6C4840492C29779F2746409ED32CD0EE6A48409BC761307F2546409ED32CD0EE6A4840
26580	32282	44.348415000000003	44.385308999999999	48.953828999999999	48.893211000000001	Нефтянников	0103000020E61000000100000005000000CA37DBDC982C4640B7B6F0BC54724840CA37DBDC982C4640FA7C9411177A48405FED28CE51314640FA7C9411177A48405FED28CE51314640B7B6F0BC54724840CA37DBDC982C4640B7B6F0BC54724840
27625	51713	44.224815999999997	44.239477000000001	48.805599000000001	48.795873	Новосельская	0103000020E610000001000000050000000BCF4BC5C61C46407C629D2ADF6548400BCF4BC5C61C46405C5837DE1D6748407592AD2EA71E46405C5837DE1D6748407592AD2EA71E46407C629D2ADF6548400BCF4BC5C61C46407C629D2ADF654840
27029	32436	44.218411000000003	44.243051999999999	49.036638000000004	49.008049999999997	Шлихтера	0103000020E61000000100000005000000180B43E4F41B4640CC5D4BC807814840180B43E4F41B46403BE5D18DB08448401B9DF3531C1F46403BE5D18DB08448401B9DF3531C1F4640CC5D4BC807814840180B43E4F41B4640CC5D4BC807814840
26561	31917	43.967106999999999	43.997776000000002	48.715646	48.696072999999998	51 Гвардейской дивизии	0103000020E61000000100000005000000C85D8429CAFB4540765089EB18594840C85D8429CAFB4540B1C1C2499A5B4840EA5DBC1FB7FF4540B1C1C2499A5B4840EA5DBC1FB7FF4540765089EB18594840C85D8429CAFB4540765089EB18594840
26822	31717	44.548352999999999	44.577889999999996	48.991079999999997	48.973100000000002	Ленина	0103000020E61000000100000005000000EDD45C6E304646406ADE718A8E7C4840EDD45C6E304646401EDC9DB5DB7E4840BC57AD4CF84946401EDC9DB5DB7E4840BC57AD4CF84946406ADE718A8E7C4840EDD45C6E304646406ADE718A8E7C4840
27297	31580	44.622069000000003	44.667676	48.948776000000002	48.924469999999999	Школьная	0103000020E610000001000000050000007F6DFDF49F4F46400A117008557648407F6DFDF49F4F4640679DF17D717948407C293C6876554640679DF17D717948407C293C68765546400A117008557648407F6DFDF49F4F46400A11700855764840
26734	31580	44.622069000000003	44.667676	48.948776000000002	48.924469999999999	Молодежная, 4 квартал	0103000020E610000001000000050000007F6DFDF49F4F46400A117008557648407F6DFDF49F4F4640679DF17D717948407C293C6876554640679DF17D717948407C293C68765546400A117008557648407F6DFDF49F4F46400A11700855764840
27138	51499	44.622069000000003	44.667676	48.948776000000002	48.924469999999999	Мелиоративная	0103000020E610000001000000050000007F6DFDF49F4F46400A117008557648407F6DFDF49F4F4640679DF17D717948407C293C6876554640679DF17D717948407C293C68765546400A117008557648407F6DFDF49F4F46400A11700855764840
27479	51617	43.959291999999998	43.974643999999998	49.000030000000002	48.992486999999997	Центральная	0103000020E610000001000000050000003FA88B14CAFA4540425A63D0097F48403FA88B14CAFA45406B82A8FB008048400E9F7422C1FC45406B82A8FB008048400E9F7422C1FC4540425A63D0097F48403FA88B14CAFA4540425A63D0097F4840
27382	51630	44.294120999999997	44.313740000000003	48.965955000000001	48.947243999999998	Ленина	0103000020E610000001000000050000008D08C6C1A525464086AA984A3F7948408D08C6C1A52546402F34D769A47B484039B9DFA1282846402F34D769A47B484039B9DFA12828464086AA984A3F7948408D08C6C1A525464086AA984A3F794840
27560	51703	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	Баррикадная	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
26991	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	проспект Ленина	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26989	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	площадь 40-лет Сталинградской битвы	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26780	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	площадь 40 лет Сталинградской битвы	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26994	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Чуйкова	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
27111	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Центральная	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
27076	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Промышленная	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26813	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Пархоменко	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26993	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Октябрьская	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26924	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Новоселовская	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26817	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Краснознаменская	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
27216	30858	43.796975000000003	44.667676	49.073189999999997	48.659154000000001	Демократическая	0103000020E61000000100000005000000645DDC4603E64540888384285F544840645DDC4603E645407632384A5E8948407C293C68765546407632384A5E8948407C293C6876554640888384285F544840645DDC4603E64540888384285F544840
26748	195	43.874698000000002	43.928578999999999	48.953082999999999	48.933141999999997	 Мира	0103000020E6100000010000000500000035F0A31AF6EF4540134372327177484035F0A31AF6EF4540D1AFAD9FFE7948404E603AADDBF64540D1AFAD9FFE7948404E603AADDBF64540134372327177484035F0A31AF6EF45401343723271774840
27505	51683	44.314773000000002	44.338112000000002	49.031433999999997	49.022070999999997	Центральная	0103000020E61000000100000005000000F8544E7B4A2846405298F738D3824840F8544E7B4A284640C1FD8007068448404D310741472B4640C1FD8007068448404D310741472B46405298F738D3824840F8544E7B4A2846405298F738D3824840
26883	30725	44.743270000000003	44.778393999999999	48.881517000000002	48.859875000000002	Калинина	0103000020E61000000100000005000000890CAB78235F4640F2D24D62106E4840890CAB78235F46401CEF8E8CD570484089B3226AA26346401CEF8E8CD570484089B3226AA2634640F2D24D62106E4840890CAB78235F4640F2D24D62106E4840
27314	32172	44.355117	44.372787000000002	48.718237000000002	48.712482999999999	Заречная	0103000020E6100000010000000500000077A04E79742D46405DFA97A4325B484077A04E79742D46407AE3A430EF5B4840DEAF027CB72F46407AE3A430EF5B4840DEAF027CB72F46405DFA97A4325B484077A04E79742D46405DFA97A4325B4840
27181	51522	44.176630000000003	44.187939999999998	48.553147000000003	48.540573999999999	Лундышева	0103000020E610000001000000050000000ABFD4CF9B164640B1886187314548400ABFD4CF9B164640B5705985CD4648401CCEFC6A0E184640B5705985CD4648401CCEFC6A0E184640B1886187314548400ABFD4CF9B164640B188618731454840
27087	51474	44.230817000000002	44.246834	48.589303999999998	48.575249999999997	Семушкина	0103000020E61000000100000005000000302E55698B1D46401283C0CAA1494840302E55698B1D464074B33F506E4B48403BC5AA41981F464074B33F506E4B48403BC5AA41981F46401283C0CAA1494840302E55698B1D46401283C0CAA1494840
26657	46646	45.370330000000003	45.393084000000002	49.747238000000003	49.740822999999999	Центральная	0103000020E61000000100000005000000255D33F966AF4640F38FBE49D3DE4840255D33F966AF46400B2AAA7EA5DF48405A4A969350B246400B2AAA7EA5DF48405A4A969350B24640F38FBE49D3DE4840255D33F966AF4640F38FBE49D3DE4840
27317	51604	45.489455	45.533931000000003	49.542813000000002	49.516922000000001	Мира	0103000020E610000001000000050000008DEE2076A6BE46409D4A06802AC248408DEE2076A6BE4640FD6B79E57AC5484009A9DBD957C44640FD6B79E57AC5484009A9DBD957C446409D4A06802AC248408DEE2076A6BE46409D4A06802AC24840
27416	51647	45.915678999999997	45.933663000000003	49.683188999999999	49.673121999999999	Садовая	0103000020E6100000010000000500000026512FF834F54640EB1B98DC28D6484026512FF834F5464054FEB5BC72D748401D3EE94482F7464054FEB5BC72D748401D3EE94482F74640EB1B98DC28D6484026512FF834F54640EB1B98DC28D64840
26835	48570	45.444971000000002	45.466081000000003	49.772779	49.759652000000003	Центральная	0103000020E610000001000000050000008F554ACFF4B84640A62BD8463CE148408F554ACFF4B846408E041A6CEAE24840BC24CE8AA8BB46408E041A6CEAE24840BC24CE8AA8BB4640A62BD8463CE148408F554ACFF4B84640A62BD8463CE14840
27812	51673	45.012531000000003	45.049964000000003	49.281737999999997	49.242640999999999	Пионерская	0103000020E61000000100000005000000D597A59D9A81464099D53BDC0E9F4840D597A59D9A8146402D05A4FD0FA448401AFD6838658646402D05A4FD0FA448401AFD68386586464099D53BDC0E9F4840D597A59D9A81464099D53BDC0E9F4840
27485	51673	45.012531000000003	45.049964000000003	49.281737999999997	49.242640999999999	Горького	0103000020E61000000100000005000000D597A59D9A81464099D53BDC0E9F4840D597A59D9A8146402D05A4FD0FA448401AFD6838658646402D05A4FD0FA448401AFD68386586464099D53BDC0E9F4840D597A59D9A81464099D53BDC0E9F4840
27453	51660	45.453415	45.468649999999997	49.656450999999997	49.643864000000001	Центральная	0103000020E610000001000000050000000742B28009BA46402F89B3226AD248400742B28009BA464097361C9606D448409CA223B9FCBB464097361C9606D448409CA223B9FCBB46402F89B3226AD248400742B28009BA46402F89B3226AD24840
27431	51653	44.989642000000003	45.029096000000003	49.208004000000003	49.183095000000002	Шурухина	0103000020E61000000100000005000000C05FCC96AC7E4640D3872EA86F974840C05FCC96AC7E4640F6B704E09F9A4840E338F06AB9834640F6B704E09F9A4840E338F06AB9834640D3872EA86F974840C05FCC96AC7E4640D3872EA86F974840
27353	51619	45.064435000000003	45.083516000000003	49.357033000000001	49.341545000000004	Советская	0103000020E61000000100000005000000E0DBF4673F884640618E1EBFB7AB4840E0DBF4673F884640E04BE141B3AD4840AC58FCA6B08A4640E04BE141B3AD4840AC58FCA6B08A4640618E1EBFB7AB4840E0DBF4673F884640618E1EBFB7AB4840
27346	51613	45.728749000000001	45.758132000000003	49.672626000000001	49.654648999999999	переулок Центральный	0103000020E6100000010000000500000011FFB0A547DD4640F7ADD689CBD3484011FFB0A547DD46403B38D89B18D648408A0629780AE146403B38D89B18D648408A0629780AE14640F7ADD689CBD3484011FFB0A547DD4640F7ADD689CBD34840
27103	51486	45.369126000000001	45.400548999999998	49.909762000000001	49.877763000000002	Советская	0103000020E61000000100000005000000390D51853FAF4640C651B9895AF04840390D51853FAF46406092CA1473F4484006B98B3045B346406092CA1473F4484006B98B3045B34640C651B9895AF04840390D51853FAF4640C651B9895AF04840
27537	51486	45.369126000000001	45.400548999999998	49.909762000000001	49.877763000000002	Песчаная	0103000020E61000000100000005000000390D51853FAF4640C651B9895AF04840390D51853FAF46406092CA1473F4484006B98B3045B346406092CA1473F4484006B98B3045B34640C651B9895AF04840390D51853FAF4640C651B9895AF04840
27012	51424	45.528613	45.573231999999997	49.396279	49.373624	Шмарова	0103000020E61000000100000005000000C79E3D97A9C34640178046E9D2AF4840C79E3D97A9C34640B98B3045B9B24840A5828AAA5FC94640B98B3045B9B24840A5828AAA5FC94640178046E9D2AF4840C79E3D97A9C34640178046E9D2AF4840
27083	51473	45.342948999999997	45.355435999999997	49.620455	49.608226999999999	Сиреневая	0103000020E610000001000000050000001399B9C0E5AB4640A8C5E061DACD48401399B9C0E5AB4640E1D1C6116BCF484018E945ED7EAD4640E1D1C6116BCF484018E945ED7EAD4640A8C5E061DACD48401399B9C0E5AB4640A8C5E061DACD4840
26768	49438	45.462631999999999	45.482968999999997	49.916066999999998	49.909413999999998	Совхозная	0103000020E61000000100000005000000A20A7F8637BB464024438EAD67F44840A20A7F8637BB4640F0F8F6AE41F54840ACFD9DEDD1BD4640F0F8F6AE41F54840ACFD9DEDD1BD464024438EAD67F44840A20A7F8637BB464024438EAD67F44840
27515	51686	45.357098000000001	45.379689999999997	49.2318	49.219043999999997	Советская	0103000020E61000000100000005000000C7BB2363B5AD4640483140A2099C4840C7BB2363B5AD46403D9B559FAB9D4840224F92AE99B046403D9B559FAB9D4840224F92AE99B04640483140A2099C4840C7BB2363B5AD4640483140A2099C4840
27635	51715	45.158946999999998	45.192813999999998	49.552498	49.522933999999999	Советская	0103000020E610000001000000050000000E66136058944640B5FB5580EFC248400E661360589446407E8D2441B8C64840001B1021AE9846407E8D2441B8C64840001B1021AE984640B5FB5580EFC248400E66136058944640B5FB5580EFC24840
27504	51470	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	переулок Набережный	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
27075	51470	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	Загодзерновская	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
27507	51470	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	Дзержинского	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
27315	51470	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	Волжская	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
27422	51470	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	 Мира	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
27603	51708	45.369207000000003	45.411921999999997	49.784813999999997	49.745252999999998	Строителей	0103000020E61000000100000005000000263ACB2C42AF4640791F477364DF4840263ACB2C42AF4640B2B8FFC874E448405F402FDCB9B44640B2B8FFC874E448405F402FDCB9B44640791F477364DF4840263ACB2C42AF4640791F477364DF4840
9651	40257	45.632188999999997	45.653326	49.803806999999999	49.789600999999998	Центральная	0103000020E610000001000000050000000AF2B391EBD04640C7F143A511E548400AF2B391EBD04640DFA5D425E3E6484031D0B52FA0D34640DFA5D425E3E6484031D0B52FA0D34640C7F143A511E548400AF2B391EBD04640C7F143A511E54840
27191	12512	42.203327999999999	42.353158000000001	50.343471000000001	50.177995000000003	 Веселый	0103000020E61000000100000005000000382EE3A6061A4540FFEC478AC8164940382EE3A6061A4540ED0F94DBF62B49400F290648342D4540ED0F94DBF62B49400F290648342D4540FFEC478AC8164940382EE3A6061A4540FFEC478AC8164940
26827	13837	42.114376999999998	42.184930999999999	50.199230999999997	50.173985999999999	Хоперская	0103000020E610000001000000050000001135D1E7A30E45401EFB592C451649401135D1E7A30E4540B8ACC266801949401F82AAD1AB174540B8ACC266801949401F82AAD1AB1745401EFB592C451649401135D1E7A30E45401EFB592C45164940
26802	47387	42.171537000000001	42.204352	50.31335	50.280096	Ленина	0103000020E61000000100000005000000E886A6ECF4154540C6DE8B2FDA234940E886A6ECF4154540CE1951DA1B284940A46FD234281A4540CE1951DA1B284940A46FD234281A4540C6DE8B2FDA234940E886A6ECF4154540C6DE8B2FDA234940
56867	57104	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Советская	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56928	57104	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Перовской	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56927	57104	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Ленина	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56869	57104	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Интернациональная	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
57127	57104	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Б.Хмельницкого	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
57062	57122	45.871777999999999	45.882576	48.521152999999998	48.509455000000003	Советская	0103000020E61000000100000005000000A7AFE76B96EF464050E449D235414840A7AFE76B96EF46402C9B3924B5424840041E1840F8F046402C9B3924B5424840041E1840F8F0464050E449D235414840A7AFE76B96EF464050E449D235414840
57169	57134	46.519122000000003	46.557903000000003	47.926482999999998	47.898412	Калинина	0103000020E610000001000000050000002B51F69672424740BF2A172AFFF247402B51F6967242474065A6B4FE96F647408FAB915D6947474065A6B4FE96F647408FAB915D69474740BF2A172AFFF247402B51F69672424740BF2A172AFFF24740
57179	57136	47.982199000000001	48.011457	45.984862999999997	45.935651	Восточная	0103000020E61000000100000005000000FB9463B2B8FD47401FBC7669C3F74640FB9463B2B8FD47402D05A4FD0FFE4640B727486C770148402D05A4FD0FFE4640B727486C770148401FBC7669C3F74640FB9463B2B8FD47401FBC7669C3F74640
56924	57113	47.841945000000003	47.862535000000001	46.699393000000001	46.684088000000003	Центральная	0103000020E61000000100000005000000EF0390DAC4EB474004CB113290574740EF0390DAC4EB47409206B7B585594740E353008C67EE47409206B7B585594740E353008C67EE474004CB113290574740EF0390DAC4EB474004CB113290574740
56923	57113	47.841945000000003	47.862535000000001	46.699393000000001	46.684088000000003	Волжская	0103000020E61000000100000005000000EF0390DAC4EB474004CB113290574740EF0390DAC4EB47409206B7B585594740E353008C67EE47409206B7B585594740E353008C67EE474004CB113290574740EF0390DAC4EB474004CB113290574740
56950	57113	47.841945000000003	47.862535000000001	46.699393000000001	46.684088000000003	Астраханская	0103000020E61000000100000005000000EF0390DAC4EB474004CB113290574740EF0390DAC4EB47409206B7B585594740E353008C67EE47409206B7B585594740E353008C67EE474004CB113290574740EF0390DAC4EB474004CB113290574740
57157	57131	47.645941999999998	47.684272999999997	45.787852000000001	45.763078999999998	Ленина	0103000020E61000000100000005000000718E3A3AAED24740D7A19A92ACE14640718E3A3AAED247404A0B9755D8E446409544F64196D747404A0B9755D8E446409544F64196D74740D7A19A92ACE14640718E3A3AAED24740D7A19A92ACE14640
57165	57133	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Карла Маркса	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
57187	57109	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Молодежная	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
56903	57109	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Горького	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
57119	57109	48.015689000000002	48.020935000000001	46.347296999999998	46.344728000000003	А.П. Гужвина	0103000020E6100000010000000500000017F4DE1802024840FC010F0C202C474017F4DE1802024840DC7F643A742C4740BF2B82FFAD024840DC7F643A742C4740BF2B82FFAD024840FC010F0C202C474017F4DE1802024840FC010F0C202C4740
56893	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	пл.Ленина	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56844	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Шоссе авиаторов	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56941	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Финогенова	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56938	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Суворова	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56849	15786	46.138182999999998	46.227052999999998	48.318693000000003	48.227961000000001	Ст.Лаврентьева	0103000020E610000001000000050000007CEE04FBAF114740B9E177D32D1D48407CEE04FBAF114740693BA6EECA284840B6BA9C12101D4740693BA6EECA284840B6BA9C12101D4740B9E177D32D1D48407CEE04FBAF114740B9E177D32D1D4840
57152	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	П.О.Сухого	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56936	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Октябрьская	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56958	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Нестерова	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56898	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Мира	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56889	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Микрорайон	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56937	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Котовского	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56841	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Конструкторская	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
57142	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	К.Маркса	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56895	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Иванова	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
57138	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Заводская	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56888	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Добролюбова	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56890	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Волгоградская	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56967	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Величко	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
56899	15786	46.138227999999998	46.225758999999996	48.318686999999997	48.227756999999997	Андреева	0103000020E610000001000000050000001CB28174B1114740B0373124271D48401CB28174B1114740865451BCCA2848408AE3C0ABE51C4740865451BCCA2848408AE3C0ABE51C4740B0373124271D48401CB28174B1114740B0373124271D4840
15652	3394	47.949941000000003	47.950794000000002	46.298236000000003	46.295627000000003	улица Шоссейная	0103000020E610000001000000050000009510ACAA97F947404568041BD72547409510ACAA97F94740B43EE5982C264740D49D279EB3F94740B43EE5982C264740D49D279EB3F947404568041BD72547409510ACAA97F947404568041BD7254740
1339	3394	48.023926000000003	48.049276999999996	46.345325000000003	46.342506999999998	улица Челюскинцев	0103000020E6100000010000000500000016C3D5011003484056D3F544D72B474016C3D50110034840E0BE0E9C332C4740F5B86FB54E064840E0BE0E9C332C4740F5B86FB54E06484056D3F544D72B474016C3D5011003484056D3F544D72B4740
4781	3394	48.08511	48.089081	46.401553	46.397114999999999	улица Туркменская	0103000020E6100000010000000500000002486DE2E40A484022E010AAD432474002486DE2E40A48402B4EB51666334740F5D89601670B48402B4EB51666334740F5D89601670B484022E010AAD432474002486DE2E40A484022E010AAD4324740
4978	3394	48.049393000000002	48.052528000000002	46.379877999999998	46.361814000000003	улица Татищева	0103000020E610000001000000050000005FD3838252064840139ED0EB4F2E47405FD3838252064840253CA1D79F304740E90FCD3CB9064840253CA1D79F304740E90FCD3CB9064840139ED0EB4F2E47405FD3838252064840139ED0EB4F2E4740
16363	3394	47.929099999999998	47.947775999999998	46.282387	46.278070999999997	улица Таганская	0103000020E61000000100000005000000575BB1BFECF64740A67B9DD497234740575BB1BFECF6474064E8D8412524474083F755B950F9474064E8D8412524474083F755B950F94740A67B9DD497234740575BB1BFECF64740A67B9DD497234740
57301	57143	47.938504999999999	47.945763999999997	46.283334000000004	46.282966000000002	Парковая	0103000020E61000000100000005000000F5108DEE20F84740A2F0D93A38244740F5108DEE20F8474025ECDB4944244740F8DD74CB0EF9474025ECDB4944244740F8DD74CB0EF94740A2F0D93A38244740F5108DEE20F84740A2F0D93A38244740
5846	3394	47.999231000000002	48.013469999999998	46.403554	46.401012000000001	улица Староастраханская	0103000020E610000001000000050000001F1329CDE6FF4740DBA6785C543347401F1329CDE6FF4740C21550A8A733474012BD8C62B9014840C21550A8A733474012BD8C62B9014840DBA6785C543347401F1329CDE6FF4740DBA6785C54334740
4475	3394	48.008197000000003	48.016713000000003	46.345804000000001	46.3384	улица Сен-Симона	0103000020E6100000010000000500000071766B990C014840B37BF2B0502B474071766B990C014840BA69334E432C47408335CEA623024840BA69334E432C47408335CEA623024840B37BF2B0502B474071766B990C014840B37BF2B0502B4740
16858	3394	48.040554	48.048018999999996	46.365215999999997	46.364694	улица Полякова	0103000020E610000001000000050000006ADC9BDF300548401286014BAE2E47406ADC9BDF30054840EBFCDB65BF2E4740164B917C25064840EBFCDB65BF2E4740164B917C250648401286014BAE2E47406ADC9BDF300548401286014BAE2E4740
56983	3394	48.005088000000001	48.018833000000001	46.388947999999999	46.387593000000003	улица Пионерская	0103000020E6100000010000000500000010CD3CB9A60048404B94BDA59C31474010CD3CB9A60048401CEC4D0CC9314740F48AA71E690248401CEC4D0CC9314740F48AA71E690248404B94BDA59C31474010CD3CB9A60048404B94BDA59C314740
57035	3394	48.005088000000001	48.018833000000001	46.388947999999999	46.387593000000003	улица Пионерская	0103000020E6100000010000000500000010CD3CB9A60048404B94BDA59C31474010CD3CB9A60048401CEC4D0CC9314740F48AA71E690248401CEC4D0CC9314740F48AA71E690248404B94BDA59C31474010CD3CB9A60048404B94BDA59C314740
5517	3394	47.960433000000002	47.964170000000003	46.278444	46.265555999999997	улица Панфилова	0103000020E61000000100000005000000E57FF277EFFA4740D7A02FBDFD214740E57FF277EFFA47403BE2900DA423474065E42CEC69FB47403BE2900DA423474065E42CEC69FB4740D7A02FBDFD214740E57FF277EFFA4740D7A02FBDFD214740
5712	3394	47.974266999999998	47.981005000000003	46.350855000000003	46.350662	улица Лепехинская	0103000020E610000001000000050000003849F3C7B4FC474098F90E7EE22C47403849F3C7B4FC4740AD510FD1E82C4740331B649291FD4740AD510FD1E82C4740331B649291FD474098F90E7EE22C47403849F3C7B4FC474098F90E7EE22C4740
4542	3394	48.06382	48.084364999999998	46.356228999999999	46.353928000000003	улица Куликова	0103000020E61000000100000005000000556AF6402B084840C19140834D2D4740556AF6402B084840827170E9982D4740A9F6E978CC0A4840827170E9982D4740A9F6E978CC0A4840C19140834D2D4740556AF6402B084840C19140834D2D4740
4490	3394	48.015481999999999	48.020378000000001	46.346114999999998	46.344316999999997	улица Костина	0103000020E610000001000000050000009DD66D50FB014840793A5794122C47409DD66D50FB014840D8D30E7F4D2C474069C70DBF9B024840D8D30E7F4D2C474069C70DBF9B024840793A5794122C47409DD66D50FB014840793A5794122C4740
5079	3394	48.040804999999999	48.059930999999999	46.335047000000003	46.323191999999999	улица Звездная	0103000020E61000000100000005000000B341261939054840172AFF5A5E294740B341261939054840BCCFF1D1E22A47401F82AAD1AB074840BCCFF1D1E22A47401F82AAD1AB074840172AFF5A5E294740B341261939054840172AFF5A5E294740
5648	3394	47.978318999999999	47.989080000000001	46.340533999999998	46.333703	улица Заводская Площадь	0103000020E610000001000000050000001807978E39FD4740DEC9A7C7B62A47401807978E39FD474089963C9E962B47405890662C9AFE474089963C9E962B47405890662C9AFE4740DEC9A7C7B62A47401807978E39FD4740DEC9A7C7B62A4740
5281	3394	48.020116999999999	48.024070000000002	46.341928000000003	46.309890000000003	улица Боевая	0103000020E61000000100000005000000FC8BA03193024840C1ADBB79AA274740FC8BA0319302484019CBF44BC42B47404968CBB91403484019CBF44BC42B47404968CBB914034840C1ADBB79AA274740FC8BA03193024840C1ADBB79AA274740
5381	3394	48.006571000000001	48.037509	46.336607999999998	46.323546999999998	улица Богдана Хмельницкого	0103000020E610000001000000050000000F0D8B51D700484005DCF3FC692947400F0D8B51D700484036C98FF8152B474020274C18CD04484036C98FF8152B474020274C18CD04484005DCF3FC692947400F0D8B51D700484005DCF3FC69294740
5483	3394	47.986251000000003	48.004091000000003	46.315044999999998	46.296418000000003	улица Безжонова	0103000020E61000000100000005000000DB5207793DFE47400EF96706F1254740DB5207793DFE474058E20165532847409E9ACB0D8600484058E20165532847409E9ACB0D860048400EF96706F1254740DB5207793DFE47400EF96706F1254740
5300	3394	48.031373000000002	48.039287000000002	46.326036000000002	46.325482000000001	улица 3-я Рыбацкая	0103000020E610000001000000050000001C7DCC0704044840E5B7E864A92947401C7DCC0704044840CAA8328CBB29474038143E5B07054840CAA8328CBB29474038143E5B07054840E5B7E864A92947401C7DCC0704044840E5B7E864A9294740
57075	3394	48.057729999999999	48.084913	46.377366000000002	46.358542999999997	Яблочкова	0103000020E61000000100000005000000C1FF56B263074840D89AADBCE42D4740C1FF56B263074840A94F72874D304740AC00DF6DDE0A4840A94F72874D304740AC00DF6DDE0A4840D89AADBCE42D4740C1FF56B263074840D89AADBCE42D4740
57046	3394	48.083942999999998	48.129567999999999	46.415863000000002	46.407953999999997	Энергетическая	0103000020E6100000010000000500000033DDEBA4BE0A4840DD2230D63734474033DDEBA4BE0A4840E84EB0FF3A354740D74D29AF95104840E84EB0FF3A354740D74D29AF95104840DD2230D63734474033DDEBA4BE0A4840DD2230D637344740
57022	3394	48.101612000000003	48.127645999999999	46.368848	46.367007000000001	Щукина	0103000020E61000000100000005000000CA703C9F010D48409833DB15FA2E4740CA703C9F010D4840F6984869362F47408CBB41B456104840F6984869362F47408CBB41B4561048409833DB15FA2E4740CA703C9F010D48409833DB15FA2E4740
57302	3394	47.962238999999997	47.974609000000001	46.269449000000002	46.265014000000001	Школьная	0103000020E61000000100000005000000C6F7C5A52AFB4740B77D8FFAEB214740C6F7C5A52AFB47404F78094E7D22474092B1DAFCBFFC47404F78094E7D22474092B1DAFCBFFC4740B77D8FFAEB214740C6F7C5A52AFB4740B77D8FFAEB214740
57240	3394	47.962238999999997	47.974609000000001	46.269449000000002	46.265014000000001	Школьная	0103000020E61000000100000005000000C6F7C5A52AFB4740B77D8FFAEB214740C6F7C5A52AFB47404F78094E7D22474092B1DAFCBFFC47404F78094E7D22474092B1DAFCBFFC4740B77D8FFAEB214740C6F7C5A52AFB4740B77D8FFAEB214740
57202	3394	47.962238999999997	47.974609000000001	46.269449000000002	46.265014000000001	Школьная	0103000020E61000000100000005000000C6F7C5A52AFB4740B77D8FFAEB214740C6F7C5A52AFB47404F78094E7D22474092B1DAFCBFFC47404F78094E7D22474092B1DAFCBFFC4740B77D8FFAEB214740C6F7C5A52AFB4740B77D8FFAEB214740
56879	3394	47.877643999999997	48.230853000000003	46.559125000000002	46.233547999999999	Шелгунова	0103000020E61000000100000005000000EBC37AA356F04740EA059FE6E41D4740EBC37AA356F0474021B07268914747407D9752978C1D484021B07268914747407D9752978C1D4840EA059FE6E41D4740EBC37AA356F04740EA059FE6E41D4740
16270	3394	48.024006999999997	48.028795000000002	46.345554999999997	46.345188	Шаумяна площадь	0103000020E6100000010000000500000002F04FA9120348405F7CD11E2F2C474002F04FA91203484011FC6F253B2C4740E8A4F78DAF03484011FC6F253B2C4740E8A4F78DAF0348405F7CD11E2F2C474002F04FA9120348405F7CD11E2F2C4740
56976	3394	48.024006999999997	48.028795000000002	46.345554999999997	46.345188	Шаумяна	0103000020E6100000010000000500000002F04FA9120348405F7CD11E2F2C474002F04FA91203484011FC6F253B2C4740E8A4F78DAF03484011FC6F253B2C4740E8A4F78DAF0348405F7CD11E2F2C474002F04FA9120348405F7CD11E2F2C4740
57072	3394	47.952582	47.962786999999999	46.318966000000003	46.301273999999999	Чкалова	0103000020E610000001000000050000000F61FC34EEF947404B917C25902647400F61FC34EEF947409A44BDE0D3284740C901BB9A3CFB47409A44BDE0D3284740C901BB9A3CFB47404B917C25902647400F61FC34EEF947404B917C2590264740
57080	3394	47.952582	47.962786999999999	46.318966000000003	46.301273999999999	Чкалова	0103000020E610000001000000050000000F61FC34EEF947404B917C25902647400F61FC34EEF947409A44BDE0D3284740C901BB9A3CFB47409A44BDE0D3284740C901BB9A3CFB47404B917C25902647400F61FC34EEF947404B917C2590264740
56990	3394	47.995305999999999	47.998603000000003	46.320726999999998	46.319426	Чигорина	0103000020E610000001000000050000009CC1DF2F66FF4740FDBE7FF3E22847409CC1DF2F66FF4740DBF813950D29474000581D39D2FF4740DBF813950D29474000581D39D2FF4740FDBE7FF3E22847409CC1DF2F66FF4740FDBE7FF3E2284740
56985	3394	48.048513	48.054307000000001	46.348877000000002	46.345841	Чалабяна	0103000020E6100000010000000500000026378AAC35064840D74E9484442C474026378AAC35064840CEA96400A82C4740D1782288F3064840CEA96400A82C4740D1782288F3064840D74E9484442C474026378AAC35064840D74E9484442C4740
57025	3394	47.979702000000003	47.983179	46.412291000000003	46.409345000000002	Химиков	0103000020E61000000100000005000000B4E908E066FD4740FCE3BD6A65344740B4E908E066FD4740B3B794F3C5344740978E39CFD8FD4740B3B794F3C5344740978E39CFD8FD4740FCE3BD6A65344740B4E908E066FD4740FCE3BD6A65344740
56973	3394	48.033133999999997	48.040804999999999	46.320503000000002	46.307282000000001	Фунтовское шоссе	0103000020E610000001000000050000005D3123BC3D04484022533E04552747405D3123BC3D0448408CA2073E06294740B3412619390548408CA2073E06294740B34126193905484022533E04552747405D3123BC3D04484022533E0455274740
57054	3394	47.979692999999997	47.993141000000001	46.419018999999999	46.414434	Тренева	0103000020E61000000100000005000000608F899466FD4740DC2C5E2C0C354740608F899466FD474089B3226AA23547408BA8893E1FFF474089B3226AA23547408BA8893E1FFF4740DC2C5E2C0C354740608F899466FD4740DC2C5E2C0C354740
56935	3394	48.005825000000002	48.011088999999998	46.365614000000001	46.355035000000001	Толстого	0103000020E61000000100000005000000E63FA4DFBE004840BAF770C9712D4740E63FA4DFBE004840D97A8670CC2E4740342C465D6B014840D97A8670CC2E4740342C465D6B014840BAF770C9712D4740E63FA4DFBE004840BAF770C9712D4740
57063	3394	48.049393000000002	48.052528000000002	46.379877999999998	46.361814000000003	Татищева	0103000020E610000001000000050000005FD3838252064840139ED0EB4F2E47405FD3838252064840253CA1D79F304740E90FCD3CB9064840253CA1D79F304740E90FCD3CB9064840139ED0EB4F2E47405FD3838252064840139ED0EB4F2E4740
57073	3394	47.929099999999998	47.947775999999998	46.282387	46.278070999999997	Таганская	0103000020E61000000100000005000000575BB1BFECF64740A67B9DD497234740575BB1BFECF6474064E8D8412524474083F755B950F9474064E8D8412524474083F755B950F94740A67B9DD497234740575BB1BFECF64740A67B9DD497234740
57037	3394	47.929099999999998	47.947775999999998	46.282387	46.278070999999997	Таганская	0103000020E61000000100000005000000575BB1BFECF64740A67B9DD497234740575BB1BFECF6474064E8D8412524474083F755B950F9474064E8D8412524474083F755B950F94740A67B9DD497234740575BB1BFECF64740A67B9DD497234740
56874	3394	47.877643999999997	48.230853000000003	46.559125000000002	46.233547999999999	Студенческая	0103000020E61000000100000005000000EBC37AA356F04740EA059FE6E41D4740EBC37AA356F0474021B07268914747407D9752978C1D484021B07268914747407D9752978C1D4840EA059FE6E41D4740EBC37AA356F04740EA059FE6E41D4740
5775	3394	48.007002	48.009408999999998	46.367497999999998	46.367001000000002	Спортивный переулок	0103000020E61000000100000005000000D8800871E5004840B64C86E3F92E4740D8800871E500484036ACA92C0A2F4740DFA469503401484036ACA92C0A2F4740DFA4695034014840B64C86E3F92E4740D8800871E5004840B64C86E3F92E4740
57056	3394	48.056544000000002	48.090806000000001	46.35004	46.346339	Софьи Перовской	0103000020E610000001000000050000007C6473D53C074840282A1BD6542C47407C6473D53C0748405B25581CCE2C4740EA23F0879F0B48405B25581CCE2C4740EA23F0879F0B4840282A1BD6542C47407C6473D53C074840282A1BD6542C4740
57019	3394	48.094965000000002	48.101090999999997	46.387518	46.381121	Соликамская	0103000020E61000000100000005000000E0A128D0270C4840CF68AB92C8304740E0A128D0270C4840404E98309A314740C075C58CF00C4840404E98309A314740C075C58CF00C4840CF68AB92C8304740E0A128D0270C4840CF68AB92C8304740
57307	3394	48.033942000000003	48.048440999999997	46.349604999999997	46.348627999999998	Советская	0103000020E61000000100000005000000FDFA213658044840253CA1D79F2C4740FDFA21365804484050C24CDBBF2C47408C648F503306484050C24CDBBF2C47408C648F5033064840253CA1D79F2C4740FDFA213658044840253CA1D79F2C4740
57201	3394	48.033942000000003	48.048440999999997	46.349604999999997	46.348627999999998	Советская	0103000020E61000000100000005000000FDFA213658044840253CA1D79F2C4740FDFA21365804484050C24CDBBF2C47408C648F503306484050C24CDBBF2C47408C648F5033064840253CA1D79F2C4740FDFA213658044840253CA1D79F2C4740
57001	3394	48.033942000000003	48.048440999999997	46.349604999999997	46.348627999999998	Советская	0103000020E61000000100000005000000FDFA213658044840253CA1D79F2C4740FDFA21365804484050C24CDBBF2C47408C648F503306484050C24CDBBF2C47408C648F5033064840253CA1D79F2C4740FDFA213658044840253CA1D79F2C4740
57086	3394	47.961897	47.969954999999999	46.462018999999998	46.461559000000001	Силикатная	0103000020E610000001000000050000006D8FDE701FFB47405516855D143B47406D8FDE701FFB4740B8904770233B4740BCCB457C27FC4740B8904770233B4740BCCB457C27FC47405516855D143B47406D8FDE701FFB47405516855D143B4740
56972	3394	48.041201000000001	48.048414000000001	46.367629000000001	46.367094000000002	Селенского	0103000020E6100000010000000500000000C80913460548406747AAEFFC2E474000C8091346054840D50792770E2F47409355116E32064840D50792770E2F47409355116E320648406747AAEFFC2E474000C80913460548406747AAEFFC2E4740
57061	3394	48.125148000000003	48.146214000000001	46.368282000000001	46.361652999999997	Садовских	0103000020E61000000100000005000000759483D90410484009C03FA54A2E4740759483D9041048404DDA54DD232F4740D21BEE23B71248404DDA54DD232F4740D21BEE23B712484009C03FA54A2E4740759483D90410484009C03FA54A2E4740
57049	3394	48.038666999999997	48.070630000000001	46.319763000000002	46.309809000000001	Рождественского	0103000020E610000001000000050000009B374E0AF3044840D48041D2A72747409B374E0AF304484045BC75FEED284740E90E62670A09484045BC75FEED284740E90E62670A094840D48041D2A72747409B374E0AF3044840D48041D2A7274740
56993	3394	47.997534000000002	48.010002	46.375948999999999	46.359886000000003	Пушкина	0103000020E61000000100000005000000F452B131AFFF4740E62494BE102E4740F452B131AFFF474061FBC9181F3047408272DBBE4701484061FBC9181F3047408272DBBE47014840E62494BE102E4740F452B131AFFF4740E62494BE102E4740
57032	3394	47.964807999999998	47.974159	46.441901999999999	46.439455000000002	Промышленная	0103000020E61000000100000005000000A7751BD47EFB47402788BA0F40384740A7751BD47EFB4740BC04A73E90384740520DFB3DB1FC4740BC04A73E90384740520DFB3DB1FC47402788BA0F40384740A7751BD47EFB47402788BA0F40384740
57078	3394	48.049276999999996	48.057307999999999	46.358181999999999	46.345269000000002	Победы	0103000020E61000000100000005000000F5B86FB54E0648404CA94BC6312C4740F5B86FB54E064840080264E8D82D47404BE658DE55074840080264E8D82D47404BE658DE550748404CA94BC6312C4740F5B86FB54E0648404CA94BC6312C4740
57021	3394	47.983682000000002	48.010810999999997	46.358674000000001	46.327598000000002	Пирогова	0103000020E61000000100000005000000FAD4B14AE9FD4740151E34BBEE294740FAD4B14AE9FD474077F69507E92D4740F1B73D416201484077F69507E92D4740F1B73D4162014840151E34BBEE294740FAD4B14AE9FD4740151E34BBEE294740
57071	3394	47.963127999999998	47.966352999999998	46.282947999999998	46.278213999999998	Немова	0103000020E6100000010000000500000052EE3EC747FB474009A52F849C23474052EE3EC747FB4740FB3BDBA3372447401CB28174B1FB4740FB3BDBA3372447401CB28174B1FB474009A52F849C23474052EE3EC747FB474009A52F849C234740
4728	3394	48.091973000000003	48.172265000000003	46.358362999999997	46.337324000000002	Началовское шоссе	0103000020E61000000100000005000000B98E71C5C50B4840F513CE6E2D2B4740B98E71C5C50B4840588CBAD6DE2D47406B9F8EC70C164840588CBAD6DE2D47406B9F8EC70C164840F513CE6E2D2B4740B98E71C5C50B4840F513CE6E2D2B4740
56978	3394	48.013559999999998	48.017592999999998	46.401752000000002	46.395772999999998	Нанайская	0103000020E6100000010000000500000052448655BC014840E5D18DB0A832474052448655BC014840228D0A9C6C334740BBD1C77C40024840228D0A9C6C334740BBD1C77C40024840E5D18DB0A832474052448655BC014840E5D18DB0A8324740
56932	3394	48.002662999999998	48.023251999999999	46.345294000000003	46.326962999999999	Набережная Приволжского Затона	0103000020E6100000010000000500000062F4DC4257004840430070ECD929474062F4DC4257004840A5C00298322C474086C8E9EBF9024840A5C00298322C474086C8E9EBF9024840430070ECD929474062F4DC4257004840430070ECD9294740
57064	3394	48.011493000000002	48.069730999999997	46.343440000000001	46.327672999999997	Н. Островского	0103000020E610000001000000050000000491459A780148401F645930F12947400491459A78014840B21188D7F52B4740394206F2EC084840B21188D7F52B4740394206F2EC0848401F645930F12947400491459A780148401F645930F1294740
56880	3394	48.039906999999999	48.048738	46.350357000000002	46.349685999999998	Молодой Гвардии	0103000020E61000000100000005000000D4F02DAC1B0548403DEFC682C22C4740D4F02DAC1B0548405C76887FD82C47404609FA0B3D0648405C76887FD82C47404609FA0B3D0648403DEFC682C22C4740D4F02DAC1B0548403DEFC682C22C4740
3183	3394	48.011510999999999	48.014521000000002	46.332483000000003	46.329321999999998	Мирный переулок	0103000020E61000000100000005000000AA4544317901484039ED2939272A4740AA45443179014840EDBC8DCD8E2A4740780DFAD2DB014840EDBC8DCD8E2A4740780DFAD2DB01484039ED2939272A4740AA4544317901484039ED2939272A4740
56998	3394	47.995368999999997	48.003470999999998	46.368293999999999	46.357385999999998	Минина	0103000020E61000000100000005000000E2395B4068FF47402D060FD3BE2D4740E2395B4068FF474011A8FE41242F474001BEDBBC7100484011A8FE41242F474001BEDBBC710048402D060FD3BE2D4740E2395B4068FF47402D060FD3BE2D4740
57083	3394	47.961987000000001	47.965257000000001	46.464421000000002	46.456332000000003	Мелиоративная	0103000020E61000000100000005000000AD16D86322FB4740240F4416693A4740AD16D86322FB4740AE49B725723B4740179E978A8DFB4740AE49B725723B4740179E978A8DFB4740240F4416693A4740AD16D86322FB4740240F4416693A4740
56982	3394	47.983179	48.013289999999998	46.412291000000003	46.371651999999997	Магистральная	0103000020E61000000100000005000000978E39CFD8FD47401ABFF04A922F4740978E39CFD8FD4740B3B794F3C534474092AE997CB3014840B3B794F3C534474092AE997CB30148401ABFF04A922F4740978E39CFD8FD47401ABFF04A922F4740
56878	3394	48.038882999999998	48.049187000000003	46.330342000000002	46.328400999999999	М.Луконина	0103000020E6100000010000000500000068AF3E1EFA044840A27C410B092A474068AF3E1EFA044840643F8BA5482A4740B63176C24B064840643F8BA5482A4740B63176C24B064840A27C410B092A474068AF3E1EFA044840A27C410B092A4740
57058	3394	48.049393000000002	48.049850999999997	46.361814000000003	46.358032999999999	Ляхова	0103000020E610000001000000050000005FD3838252064840C3F17C06D42D47405FD3838252064840139ED0EB4F2E474021567F8461064840139ED0EB4F2E474021567F8461064840C3F17C06D42D47405FD3838252064840C3F17C06D42D4740
56876	3394	48.038882999999998	48.049187000000003	46.330342000000002	46.328400999999999	Луконина	0103000020E6100000010000000500000068AF3E1EFA044840A27C410B092A474068AF3E1EFA044840643F8BA5482A4740B63176C24B064840643F8BA5482A4740B63176C24B064840A27C410B092A474068AF3E1EFA044840A27C410B092A4740
5802	3394	47.983663999999997	48.001818999999998	46.364887000000003	46.360912999999996	Ленинградский переулок	0103000020E610000001000000050000005320B3B3E8FD4740C2D9AD65322E47405320B3B3E8FD474027DE019EB42E474076C1E09A3B00484027DE019EB42E474076C1E09A3B004840C2D9AD65322E47405320B3B3E8FD4740C2D9AD65322E4740
16332	3394	48.025516000000003	48.033619000000002	46.347420999999997	46.347098000000003	Ленина площадь	0103000020E610000001000000050000002BC3B81B44034840E6400FB56D2C47402BC3B81B44034840C878944A782C47401AC39CA04D044840C878944A782C47401AC39CA04D044840E6400FB56D2C47402BC3B81B44034840E6400FB56D2C4740
57051	3394	48.033619000000002	48.045665	46.348129999999998	46.347403	Ленина	0103000020E610000001000000050000001AC39CA04D04484022C495B3772C47401AC39CA04D044840D4601A868F2C474032C9C859D8054840D4601A868F2C474032C9C859D805484022C495B3772C47401AC39CA04D04484022C495B3772C4740
57204	3394	48.033619000000002	48.045665	46.348129999999998	46.347403	Ленина	0103000020E610000001000000050000001AC39CA04D04484022C495B3772C47401AC39CA04D044840D4601A868F2C474032C9C859D8054840D4601A868F2C474032C9C859D805484022C495B3772C47401AC39CA04D04484022C495B3772C4740
56981	3394	48.033619000000002	48.045665	46.348129999999998	46.347403	Ленина	0103000020E610000001000000050000001AC39CA04D04484022C495B3772C47401AC39CA04D044840D4601A868F2C474032C9C859D8054840D4601A868F2C474032C9C859D805484022C495B3772C47401AC39CA04D04484022C495B3772C4740
57052	3394	48.033619000000002	48.045665	46.348129999999998	46.347403	Ленина	0103000020E610000001000000050000001AC39CA04D04484022C495B3772C47401AC39CA04D044840D4601A868F2C474032C9C859D8054840D4601A868F2C474032C9C859D805484022C495B3772C47401AC39CA04D04484022C495B3772C4740
56975	3394	48.057712000000002	48.071841999999997	46.348609000000003	46.347563999999998	Курская	0103000020E610000001000000050000001B4B581B630748402BA226FA7C2C47401B4B581B63074840AF0B3F389F2C4740573D601E32094840AF0B3F389F2C4740573D601E320948402BA226FA7C2C47401B4B581B630748402BA226FA7C2C4740
57043	3394	48.06382	48.084364999999998	46.356228999999999	46.353928000000003	Куликова	0103000020E61000000100000005000000556AF6402B084840C19140834D2D4740556AF6402B084840827170E9982D4740A9F6E978CC0A4840827170E9982D4740A9F6E978CC0A4840C19140834D2D4740556AF6402B084840C19140834D2D4740
57079	3394	48.032908999999997	48.036870999999998	46.330945999999997	46.321300000000001	Краснодарская	0103000020E610000001000000050000003D5FB35C36044840371AC05B202947403D5FB35C36044840FA5E43705C2A4740DD955D30B8044840FA5E43705C2A4740DD955D30B8044840371AC05B202947403D5FB35C36044840371AC05B20294740
56896	3394	48.032397000000003	48.069730999999997	46.355676000000003	46.339564000000003	Красная набережная	0103000020E6100000010000000500000088BEBB9525044840117349D5762B474088BEBB95250448406EFC89CA862D4740394206F2EC0848406EFC89CA862D4740394206F2EC084840117349D5762B474088BEBB9525044840117349D5762B4740
57095	3394	48.021725000000004	48.023440999999998	46.343725999999997	46.342748999999998	Котовского	0103000020E61000000100000005000000B84082E2C70248404CDE0033DF2B4740B84082E2C70248407764AC36FF2B474059315C1D000348407764AC36FF2B474059315C1D000348404CDE0033DF2B4740B84082E2C70248404CDE0033DF2B4740
57077	3394	48.049078999999999	48.058835000000002	46.333199	46.330342000000002	Космонавтов	0103000020E61000000100000005000000CFF57D3848064840643F8BA5482A4740CFF57D3848064840AB07CC43A62A47401A6EC0E787074840AB07CC43A62A47401A6EC0E787074840643F8BA5482A4740CFF57D3848064840643F8BA5482A4740
57010	3394	48.094974000000001	48.147525000000002	46.359997999999997	46.354723999999997	Космонавта В. Комарова	0103000020E6100000010000000500000033FCA71B280C48409B8D9598672D474033FCA71B280C48400D501A6A142E4740D42B6519E21248400D501A6A142E4740D42B6519E21248409B8D9598672D474033FCA71B280C48409B8D9598672D4740
56957	3394	48.042881000000001	48.050220000000003	46.379280999999999	46.371180000000003	Комсомольская Набережная	0103000020E61000000100000005000000554FE61F7D054840F37684D3822F4740554FE61F7D054840417FA1478C30474075CDE49B6D064840417FA1478C30474075CDE49B6D064840F37684D3822F4740554FE61F7D054840F37684D3822F4740
57200	3394	47.987490000000001	48.004261999999997	46.357261999999999	46.343440000000001	Комсомольская	0103000020E610000001000000050000004390831266FE4740B21188D7F52B47404390831266FE4740410DDFC2BA2D4740CA4E3FA88B004840410DDFC2BA2D4740CA4E3FA88B004840B21188D7F52B47404390831266FE4740B21188D7F52B4740
57068	3394	47.987490000000001	48.004261999999997	46.357261999999999	46.343440000000001	Комсомольская	0103000020E610000001000000050000004390831266FE4740B21188D7F52B47404390831266FE4740410DDFC2BA2D4740CA4E3FA88B004840410DDFC2BA2D4740CA4E3FA88B004840B21188D7F52B47404390831266FE4740B21188D7F52B4740
57038	3394	48.042071999999997	48.045611000000001	46.361964	46.347844000000002	Коммунистическая	0103000020E61000000100000005000000E509849D620548400F0EF626862C4740E509849D62054840282A1BD6542E47403FABCC94D6054840282A1BD6542E47403FABCC94D60548400F0EF626862C4740E509849D620548400F0EF626862C4740
57009	3394	48.036825999999998	48.038882999999998	46.354289000000001	46.334474	Кирова	0103000020E610000001000000050000003DD2E0B6B604484060AE450BD02A47403DD2E0B6B6044840912A8A57592D474068AF3E1EFA044840912A8A57592D474068AF3E1EFA04484060AE450BD02A47403DD2E0B6B604484060AE450BD02A4740
57085	3394	47.957495999999999	47.970162000000002	46.315038000000001	46.298149000000002	Капитана Краснова	0103000020E6100000010000000500000081069B3A8FFA4740E52A16BF2926474081069B3A8FFA4740A67F492A5328474036E9B6442EFC4740A67F492A5328474036E9B6442EFC4740E52A16BF2926474081069B3A8FFA4740E52A16BF29264740
57060	3394	48.040804999999999	48.059930999999999	46.335047000000003	46.323191999999999	Звездная	0103000020E61000000100000005000000B341261939054840172AFF5A5E294740B341261939054840BCCFF1D1E22A47401F82AAD1AB074840BCCFF1D1E22A47401F82AAD1AB074840172AFF5A5E294740B341261939054840172AFF5A5E294740
57040	3394	47.978318999999999	47.989080000000001	46.340533999999998	46.333703	Заводская Площадь	0103000020E610000001000000050000001807978E39FD4740DEC9A7C7B62A47401807978E39FD474089963C9E962B47405890662C9AFE474089963C9E962B47405890662C9AFE4740DEC9A7C7B62A47401807978E39FD4740DEC9A7C7B62A4740
57047	3394	48.091048000000001	48.091425999999998	46.408351000000003	46.399656999999998	Жилая	0103000020E61000000100000005000000E02EFB75A70B4840094FE8F527334740E02EFB75A70B4840FB2477D8443447408600E0D8B30B4840FB2477D8443447408600E0D8B30B4840094FE8F527334740E02EFB75A70B4840094FE8F527334740
57124	3394	47.989592000000002	47.992314	46.257922999999998	46.253504999999997	Есенина	0103000020E610000001000000050000000E315EF3AAFE4740AD2F12DA722047400E315EF3AAFE47406FF1F09E0321474075AE282504FF47406FF1F09E0321474075AE282504FF4740AD2F12DA722047400E315EF3AAFE4740AD2F12DA72204740
57027	3394	48.024645	48.038361999999999	46.332607000000003	46.330989000000002	Дубровинского	0103000020E6100000010000000500000045813E9127034840FA2AF9D85D2A474045813E9127034840D9B5BDDD922A47405FB4C70BE9044840D9B5BDDD922A47405FB4C70BE9044840FA2AF9D85D2A474045813E9127034840FA2AF9D85D2A4740
56984	3394	47.945799999999998	47.948180000000001	46.291074999999999	46.289368000000003	Докучаева	0103000020E61000000100000005000000454772F90FF947402541B8020A254740454772F90FF9474073D712F241254740535C55F65DF9474073D712F241254740535C55F65DF947402541B8020A254740454772F90FF947402541B8020A254740
57050	3394	47.99006	48.005825000000002	46.355035000000001	46.340839000000003	Дзержинского	0103000020E61000000100000005000000F4893C49BAFE4740C619C39CA02B4740F4893C49BAFE4740BAF770C9712D4740E63FA4DFBE004840BAF770C9712D4740E63FA4DFBE004840C619C39CA02B4740F4893C49BAFE4740C619C39CA02B4740
56964	3394	48.042315000000002	48.060738999999998	46.338132999999999	46.335526000000002	Джона Рида	0103000020E61000000100000005000000AC90F2936A054840967A1684F22A4740AC90F2936A054840645930F1472B4740BE4BA94BC6074840645930F1472B4740BE4BA94BC6074840967A1684F22A4740AC90F2936A054840967A1684F22A4740
56951	3394	47.976522000000003	47.977088000000002	46.351801000000002	46.345238000000002	Депутатский переулок	0103000020E610000001000000050000008AE942ACFEFC474011AB3FC2302C47408AE942ACFEFC47409DD9AED0072D474033A8363811FD47409DD9AED0072D474033A8363811FD474011AB3FC2302C47408AE942ACFEFC474011AB3FC2302C4740
56991	3394	48.095764000000003	48.107495999999998	46.382264999999997	46.373672999999997	Дальняя	0103000020E610000001000000050000002C11A8FE410C4840F8325184D42F47402C11A8FE410C4840E5B33C0FEE304740B439CE6DC20D4840E5B33C0FEE304740B439CE6DC20D4840F8325184D42F47402C11A8FE410C4840F8325184D42F4740
5822	3394	47.989978999999998	47.999133	46.361745999999997	46.359164999999997	Грановский переулок	0103000020E61000000100000005000000075DC2A1B7FE4740156F641EF92D4740075DC2A1B7FE4740BABA63B14D2E47405CAD1397E3FF4740BABA63B14D2E47405CAD1397E3FF4740156F641EF92D4740075DC2A1B7FE4740156F641EF92D4740
57002	3394	48.009723999999999	48.011907000000001	46.384255000000003	46.379286999999998	Гагарина	0103000020E610000001000000050000003FFED2A23E0148402366F6798C3047403FFED2A23E014840892991442F314740F7CB272B86014840892991442F314740F7CB272B860148402366F6798C3047403FFED2A23E0148402366F6798C304740
56979	3394	48.009723999999999	48.011907000000001	46.384255000000003	46.379286999999998	Гагарина	0103000020E610000001000000050000003FFED2A23E0148402366F6798C3047403FFED2A23E014840892991442F314740F7CB272B86014840892991442F314740F7CB272B860148402366F6798C3047403FFED2A23E0148402366F6798C304740
5173	3394	48.049187000000003	48.051414999999999	46.330342000000002	46.327267999999997	Воробьева проезд	0103000020E61000000100000005000000B63176C24B0648407F83F6EAE3294740B63176C24B064840643F8BA5482A47400DC347C494064840643F8BA5482A47400DC347C4940648407F83F6EAE3294740B63176C24B0648407F83F6EAE3294740
57074	3394	47.960703000000002	47.965409999999999	46.313090000000003	46.305844	Водников	0103000020E61000000100000005000000A515DF50F8FA4740C3D66CE525274740A515DF50F8FA4740325A4755132847409D9D0C8E92FB4740325A4755132847409D9D0C8E92FB4740C3D66CE525274740A515DF50F8FA4740C3D66CE525274740
57066	3394	48.029864000000003	48.032980999999999	46.343980999999999	46.330945999999997	Бэра	0103000020E61000000100000005000000F4A96395D2034840FA5E43705C2A4740F4A96395D203484002B9C491072C4740D731AEB83804484002B9C491072C4740D731AEB838044840FA5E43705C2A4740F4A96395D2034840FA5E43705C2A4740
5904	3394	47.976351000000001	47.991397999999997	46.420304999999999	46.416857	Бумажников проспект	0103000020E610000001000000050000005D35CF11F9FC4740E90DF7915B3547405D35CF11F9FC474032ACE28DCC354740EFA83121E6FE474032ACE28DCC354740EFA83121E6FE4740E90DF7915B3547405D35CF11F9FC4740E90DF7915B354740
57036	3394	48.062275	48.068275999999997	46.378397999999997	46.362043999999997	Ботвина	0103000020E61000000100000005000000E02D90A0F807484044DB3175572E4740E02D90A0F8074840976F7D586F304740048D9944BD084840976F7D586F304740048D9944BD08484044DB3175572E4740E02D90A0F807484044DB3175572E4740
57028	3394	48.060389000000001	48.075130000000001	46.367952000000002	46.349032000000001	Бориса Алексеева	0103000020E61000000100000005000000E204A6D3BA074840F5A0A014AD2C4740E204A6D3BA074840B83F170D192F474068791EDC9D094840B83F170D192F474068791EDC9D094840F5A0A014AD2C4740E204A6D3BA074840F5A0A014AD2C4740
57041	3394	48.020116999999999	48.024070000000002	46.341928000000003	46.309890000000003	Боевая	0103000020E61000000100000005000000FC8BA03193024840C1ADBB79AA274740FC8BA0319302484019CBF44BC42B47404968CBB91403484019CBF44BC42B47404968CBB914034840C1ADBB79AA274740FC8BA03193024840C1ADBB79AA274740
57030	3394	48.006571000000001	48.037509	46.336607999999998	46.323546999999998	Богдана Хмельницкого	0103000020E610000001000000050000000F0D8B51D700484005DCF3FC692947400F0D8B51D700484036C98FF8152B474020274C18CD04484036C98FF8152B474020274C18CD04484005DCF3FC692947400F0D8B51D700484005DCF3FC69294740
57018	3394	47.986251000000003	48.004091000000003	46.315044999999998	46.296418000000003	Безжонова	0103000020E61000000100000005000000DB5207793DFE47400EF96706F1254740DB5207793DFE474058E20165532847409E9ACB0D8600484058E20165532847409E9ACB0D860048400EF96706F1254740DB5207793DFE47400EF96706F1254740
56914	3394	48.065401000000001	48.065572000000003	46.351191	46.350563000000001	Барсовой	0103000020E6100000010000000500000017105A0F5F0848400518963FDF2C474017105A0F5F08484024D3A1D3F32C474044C4CDA96408484024D3A1D3F32C474044C4CDA9640848400518963FDF2C474017105A0F5F0848400518963FDF2C4740
57069	3394	48.016758000000003	48.052914999999999	46.343290000000003	46.339309	Бакинская	0103000020E6100000010000000500000023F94A2025024840861E317A6E2B474023F94A20250248409D853DEDF02B4740E23B31EBC50648409D853DEDF02B4740E23B31EBC5064840861E317A6E2B474023F94A2025024840861E317A6E2B4740
57065	3394	48.016758000000003	48.052914999999999	46.343290000000003	46.339309	Бакинская	0103000020E6100000010000000500000023F94A2025024840861E317A6E2B474023F94A20250248409D853DEDF02B4740E23B31EBC50648409D853DEDF02B4740E23B31EBC5064840861E317A6E2B474023F94A2025024840861E317A6E2B4740
57082	3394	48.017592999999998	48.048163000000002	46.340684000000003	46.335999000000001	Ахшарумова	0103000020E61000000100000005000000BBD1C77C400248408E3EE603022B4740BBD1C77C400248409F2287889B2B47404AF086342A0648409F2287889B2B47404AF086342A0648408E3EE603022B4740BBD1C77C400248408E3EE603022B4740
56987	3394	48.070664999999998	48.079891000000003	46.369270999999998	46.363630000000001	Ахтубинская	0103000020E6100000010000000500000065FCFB8C0B09484018EC866D8B2E474065FCFB8C0B0948403C2EAA45442F4740541F48DE390A48403C2EAA45442F4740541F48DE390A484018EC866D8B2E474065FCFB8C0B09484018EC866D8B2E4740
57014	3394	47.974697999999997	47.977753	46.326583999999997	46.323141999999997	Артема Сергеева площадь	0103000020E6100000010000000500000001BD70E7C2FC474065FB90B75C29474001BD70E7C2FC4740CCB22781CD2947406F48A30227FD4740CCB22781CD2947406F48A30227FD474065FB90B75C29474001BD70E7C2FC474065FB90B75C294740
57005	3394	48.001558000000003	48.005752999999999	46.322992999999997	46.317534000000002	Артезианская	0103000020E610000001000000050000000A86730D330048401DAF40F4A42847400A86730D3300484020EBA9D5572947404C6DA983BC00484020EBA9D5572947404C6DA983BC0048401DAF40F4A42847400A86730D330048401DAF40F4A4284740
57011	3394	48.021698000000001	48.026665999999999	46.351863000000002	46.347490000000001	Анатолия Сергеева	0103000020E61000000100000005000000BE310400C7024840F1D7648D7A2C4740BE310400C702484013D6C6D8092D474023F59ECA6903484013D6C6D8092D474023F59ECA69034840F1D7648D7A2C4740BE310400C7024840F1D7648D7A2C4740
57084	3394	47.990822999999999	47.999896	46.318978000000001	46.315910000000002	Александрова	0103000020E61000000100000005000000F38FBE49D3FE47405C3D27BD6F284740F38FBE49D3FE47405E126745D42847405BB39597FCFF47405E126745D42847405BB39597FCFF47405C3D27BD6F284740F38FBE49D3FE47405C3D27BD6F284740
57016	3394	48.037391999999997	48.056508000000001	46.358741999999999	46.357728000000002	Академика Королева	0103000020E61000000100000005000000E690D442C9044840876EF607CA2D4740E690D442C9044840CFD90242EB2D47402FFB75A73B074840CFD90242EB2D47402FFB75A73B074840876EF607CA2D4740E690D442C9044840876EF607CA2D4740
57042	3394	48.020800000000001	48.045583999999998	46.364097000000001	46.343122000000001	Адмиралтейская	0103000020E61000000100000005000000DFE00B93A9024840E144F46BEB2B4740DFE00B93A90248402EC901BB9A2E4740459C4EB2D50548402EC901BB9A2E4740459C4EB2D5054840E144F46BEB2B4740DFE00B93A9024840E144F46BEB2B4740
56997	3394	47.969119999999997	48.006714000000002	46.323621000000003	46.277771999999999	Адмирала Нахимова	0103000020E6100000010000000500000023F3C81F0CFC47404CDF6B088E23474023F3C81F0CFC474040A6B5696C29474072361D01DC00484040A6B5696C29474072361D01DC0048404CDF6B088E23474023F3C81F0CFC47404CDF6B088E234740
57048	3394	48.078677999999996	48.083717999999998	46.388998000000001	46.381692999999999	Агрономическая	0103000020E610000001000000050000001475E61E120A48405A0EF450DB3047401475E61E120A4840CE1ABCAFCA314740130B7C45B70A4840CE1ABCAFCA314740130B7C45B70A48405A0EF450DB3047401475E61E120A48405A0EF450DB304740
57076	3394	48.067422999999998	48.081194000000004	46.377279000000001	46.373213	Авиационная	0103000020E61000000100000005000000C5FF1D51A108484095B88E71C52F4740C5FF1D51A1084840DA3BA3AD4A304740D350A390640A4840DA3BA3AD4A304740D350A390640A484095B88E71C52F4740C5FF1D51A108484095B88E71C52F4740
57045	3394	48.082037999999997	48.083978000000002	46.414788000000001	46.408512999999999	8-я Железнодорожная	0103000020E61000000100000005000000BE839F38800A4840D47E6B274A344740BE839F38800A4840FA62EFC517354740B0CA85CABF0A4840FA62EFC517354740B0CA85CABF0A4840D47E6B274A344740BE839F38800A4840D47E6B274A344740
56992	3394	47.941648999999998	47.985917999999998	46.346761999999998	46.343564000000001	5-я Керченская	0103000020E61000000100000005000000D2A755F487F847409E0AB8E7F92B4740D2A755F487F847406EBF7CB2622C4740D4449F8F32FE47406EBF7CB2622C4740D4449F8F32FE47409E0AB8E7F92B4740D2A755F487F847409E0AB8E7F92B4740
57044	3394	48.074860999999999	48.085127999999997	46.359681000000002	46.351981000000002	11-й Красной Армии	0103000020E61000000100000005000000785F950B950948401DE8A1B60D2D4740785F950B950948400DFFE9060A2E4740A8FC6B79E50A48400DFFE9060A2E4740A8FC6B79E50A48401DE8A1B60D2D4740785F950B950948401DE8A1B60D2D4740
57059	3394	48.062823000000002	48.072839000000002	46.378672000000002	46.361037000000003	1-я Перевозная	0103000020E61000000100000005000000E33785950A084840AFD2DD75362E4740E33785950A08484099F4F75278304740CA6FD1C95209484099F4F75278304740CA6FD1C952094840AFD2DD75362E4740E33785950A084840AFD2DD75362E4740
57070	3394	48.074922999999998	48.077618000000001	46.416452999999997	46.402448	1-я Железнодорожная	0103000020E61000000100000005000000EE5BAD1397094840992B836A83334740EE5BAD139709484019A9F7544E3547405CCAF962EF09484019A9F7544E3547405CCAF962EF094840992B836A83334740EE5BAD1397094840992B836A83334740
56966	15153	46.084257000000001	46.123359999999998	48.080641	48.043444000000001	пл.Ленина	0103000020E61000000100000005000000C3BAF1EEC80A47408D9AAF928F054840C3BAF1EEC80A4740BEDBBC71520A484039D1AE42CA0F4740BEDBBC71520A484039D1AE42CA0F47408D9AAF928F054840C3BAF1EEC80A47408D9AAF928F054840
56929	15153	46.084257000000001	46.123359999999998	48.080641	48.043444000000001	пл. Ленина	0103000020E61000000100000005000000C3BAF1EEC80A47408D9AAF928F054840C3BAF1EEC80A4740BEDBBC71520A484039D1AE42CA0F4740BEDBBC71520A484039D1AE42CA0F47408D9AAF928F054840C3BAF1EEC80A47408D9AAF928F054840
56840	15153	46.084257000000001	46.123359999999998	48.080641	48.043444000000001	Комиссара Савельева	0103000020E61000000100000005000000C3BAF1EEC80A47408D9AAF928F054840C3BAF1EEC80A4740BEDBBC71520A484039D1AE42CA0F4740BEDBBC71520A484039D1AE42CA0F47408D9AAF928F054840C3BAF1EEC80A47408D9AAF928F054840
56970	15849	45.098939999999999	45.133884000000002	48.438536999999997	48.417701999999998	Школьная	0103000020E610000001000000050000001422E010AA8C4640A5BC5642773548401422E010AA8C4640008BFCFA2138484095BA641C23914640008BFCFA2138484095BA641C23914640A5BC5642773548401422E010AA8C4640A5BC564277354840
57247	15609	45.781516000000003	45.795287000000002	48.310417999999999	48.299823000000004	1-го Мая	0103000020E610000001000000050000007FA65EB708E4464058CB9D99602648407FA65EB708E446407C0BEBC6BB2748408CF7E3F6CBE546407C0BEBC6BB2748408CF7E3F6CBE5464058CB9D99602648407FA65EB708E4464058CB9D9960264840
57160	15410	45.913226999999999	45.967852999999998	48.234316999999997	48.205088000000003	пл. Мира	0103000020E610000001000000050000007F69519FE4F44640AA66D652401A48407F69519FE4F44640CBF27519FE1D4840F12A6B9BE2FB4640CBF27519FE1D4840F12A6B9BE2FB4640AA66D652401A48407F69519FE4F44640AA66D652401A4840
56971	15733	45.258569999999999	45.321263999999999	48.418156000000003	48.399459999999998	пер. Кооперативный	0103000020E6100000010000000500000005DD5ED218A14640B3075A812133484005DD5ED218A146402750C42286354840EAB0C22D1FA946402750C42286354840EAB0C22D1FA94640B3075A812133484005DD5ED218A14640B3075A8121334840
56965	15120	46.125839999999997	46.143725000000003	47.928812999999998	47.906168000000001	Победы	0103000020E61000000100000005000000AA436E861B10474043572250FDF34740AA436E861B104740C18C2958E3F647400E4FAF9465124740C18C2958E3F647400E4FAF946512474043572250FDF34740AA436E861B10474043572250FDF34740
57106	15512	45.876080999999999	45.901952999999999	48.261214000000002	48.247357000000001	1-го Мая	0103000020E61000000100000005000000D0D2156C23F04640E5B7E864A91F4840D0D2156C23F04640F1A0D9756F214840B9C3263273F34640F1A0D9756F214840B9C3263273F34640E5B7E864A91F4840D0D2156C23F04640E5B7E864A91F4840
57109	15696	45.551690999999998	45.578200000000002	48.450347000000001	48.434161000000003	Советская	0103000020E61000000100000005000000AF3F89CF9DC646406E19709692374840AF3F89CF9DC64640056D72F8A43948400B46257502CA4640056D72F8A43948400B46257502CA46406E19709692374840AF3F89CF9DC646406E19709692374840
57105	15353	46.023513000000001	46.052160000000001	48.153756000000001	48.132033999999997	Комсомольская	0103000020E61000000100000005000000F303577902034740E3FA777DE6104840F3035779020347402AC8CF46AE1348406614CB2DAD0647402AC8CF46AE1348406614CB2DAD064740E3FA777DE6104840F303577902034740E3FA777DE6104840
57158	15637	45.590929000000003	45.619512999999998	48.325133999999998	48.310209	Ленина	0103000020E6100000010000000500000006A1BC8FA3CB464062F6B2EDB427484006A1BC8FA3CB4640A968ACFD9D2948403239B5334CCF4640A968ACFD9D2948403239B5334CCF464062F6B2EDB427484006A1BC8FA3CB464062F6B2EDB4274840
57224	14033	47.114193	47.135941000000003	47.538088999999999	47.527078000000003	Железнодорожная	0103000020E61000000100000005000000503750E09D8E47407638BA4A77C34740503750E09D8E47402EABB019E0C44740C097C283669147402EABB019E0C44740C097C283669147407638BA4A77C34740503750E09D8E47407638BA4A77C34740
56864	14918	47.799095999999999	47.828048000000003	47.046149	47.023885	Советская	0103000020E61000000100000005000000A52E19C748E64740B7EEE6A90E834740A52E19C748E647401EDFDE35E885474055C2137AFDE947401EDFDE35E885474055C2137AFDE94740B7EEE6A90E834740A52E19C748E64740B7EEE6A90E834740
56959	14090	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Терешковой	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56834	14090	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Советская	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56861	14090	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Лесхозная	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56963	14090	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Ленина	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56961	14090	47.226509999999998	47.291215000000001	47.421747000000003	47.390242000000001	Гагарина	0103000020E61000000100000005000000C51B9947FE9C474048C32973F3B14740C51B9947FE9C4740D31742CEFBB54740658D7A8846A54740D31742CEFBB54740658D7A8846A5474048C32973F3B14740C51B9947FE9C474048C32973F3B14740
56930	14549	47.356622000000002	47.392294	47.323504	47.304419000000003	Октябрьская	0103000020E610000001000000050000005E8429CAA5AD4740F9A3A833F7A647405E8429CAA5AD474006103E9468A94740613596B036B2474006103E9468A94740613596B036B24740F9A3A833F7A647405E8429CAA5AD4740F9A3A833F7A64740
57311	57149	47.692537999999999	47.708069000000002	47.154673000000003	47.139558999999998	Светлая	0103000020E610000001000000050000005E9ECE15A5D84740656EBE11DD9147405E9ECE15A5D8474080492A53CC934740DD274701A2DA474080492A53CC934740DD274701A2DA4740656EBE11DD9147405E9ECE15A5D84740656EBE11DD914740
56836	14641	47.435780999999999	47.478504999999998	47.178412000000002	47.155940999999999	Советская	0103000020E61000000100000005000000ED9BFBABC7B74740828DEBDFF5934740ED9BFBABC7B74740639B5434D69647407AFCDEA63FBD4740639B5434D69647407AFCDEA63FBD4740828DEBDFF5934740ED9BFBABC7B74740828DEBDFF5934740
56934	13948	46.974550000000001	47.016312999999997	47.555453999999997	47.541240000000002	Ленина	0103000020E610000001000000050000008D28ED0DBE7C4740BEA4315A47C547408D28ED0DBE7C47405837DE1D19C74740F4BF5C8B168247405837DE1D19C74740F4BF5C8B16824740BEA4315A47C547408D28ED0DBE7C4740BEA4315A47C54740
57087	15070	47.612695000000002	47.624248000000001	46.935777999999999	46.925334999999997	Школьная	0103000020E610000001000000050000001CB62DCA6CCE47400D6C9560717647401CB62DCA6CCE47407C28D192C7774740F54BC45BE7CF47407C28D192C7774740F54BC45BE7CF47400D6C9560717647401CB62DCA6CCE47400D6C956071764740
57107	13819	46.864471000000002	46.873966000000003	47.655380000000001	47.638553000000002	Ленина	0103000020E6100000010000000500000093AB58FCA66E4740A0E1CD1ABCD1474093AB58FCA66E4740EB39E97DE3D3474071E82D1EDE6F4740EB39E97DE3D3474071E82D1EDE6F4740A0E1CD1ABCD1474093AB58FCA66E4740A0E1CD1ABCD14740
57193	14991	47.826529999999998	47.836196000000001	46.954419000000001	46.948593000000002	Советская	0103000020E61000000100000005000000D9942BBCCBE94740761BD47E6B794740D9942BBCCBE947402CD7DB662A7A4740E485747808EB47402CD7DB662A7A4740E485747808EB4740761BD47E6B794740D9942BBCCBE94740761BD47E6B794740
56926	13969	47.017885	47.047699999999999	47.551951000000003	47.535606999999999	Почтовая	0103000020E61000000100000005000000630B410E4A8247401C412AC58EC44740630B410E4A8247404CFF9254A6C6474075029A081B8647404CFF9254A6C6474075029A081B8647401C412AC58EC44740630B410E4A8247401C412AC58EC44740
56870	15029	47.604151999999999	47.628819999999997	46.990808000000001	46.963563999999998	Набережная	0103000020E6100000010000000500000010E84CDA54CD47402DCDAD10567B474010E84CDA54CD4740BE4EEACBD27E47400D897B2C7DD04740BE4EEACBD27E47400D897B2C7DD047402DCDAD10567B474010E84CDA54CD47402DCDAD10567B4740
56839	14740	47.626340999999996	47.662174999999998	47.148287000000003	47.130296999999999	Советская	0103000020E610000001000000050000006C921FF12BD047402AE27492AD9047406C921FF12BD0474003B68311FB924740499D8026C2D4474003B68311FB924740499D8026C2D447402AE27492AD9047406C921FF12BD047402AE27492AD904740
57244	13881	46.910086999999997	46.932580999999999	47.567115999999999	47.549590999999999	Школьная	0103000020E61000000100000005000000E3C116BB7D744740859675FF58C64740E3C116BB7D744740E884D04197C847407CEF6FD05E774740E884D04197C847407CEF6FD05E774740859675FF58C64740E3C116BB7D744740859675FF58C64740
57231	14586	47.389284000000004	47.403936000000002	47.322068999999999	47.309837999999999	Привокзальная	0103000020E61000000100000005000000946DE00ED4B147406E8786C5A8A74740946DE00ED4B147401807978E39A94740AAD6C22CB4B347401807978E39A94740AAD6C22CB4B347406E8786C5A8A74740946DE00ED4B147406E8786C5A8A74740
57306	57146	47.773305000000001	47.780914000000003	47.075209000000001	47.068550000000002	Школьная	0103000020E61000000100000005000000A96A82A8FBE247400612143FC6884740A96A82A8FBE24740B4AED172A0894740897E6DFDF4E34740B4AED172A0894740897E6DFDF4E347400612143FC6884740A96A82A8FBE247400612143FC6884740
57295	57141	47.945152999999998	47.950597000000002	46.343930999999998	46.343401999999998	Центральная	0103000020E61000000100000005000000AF5B04C6FAF84740C4B0C398F42B4740AF5B04C6FAF84740508A56EE052C47407E569929ADF94740508A56EE052C47407E569929ADF94740C4B0C398F42B4740AF5B04C6FAF84740C4B0C398F42B4740
56974	57115	48.032622000000003	48.036969999999997	46.505740000000003	46.504382	50-летия Победы	0103000020E61000000100000005000000A8902BF52C0448407558E1968F404740A8902BF52C044840B8239C16BC4047407077D66EBB044840B8239C16BC4047407077D66EBB0448407558E1968F404740A8902BF52C0448407558E1968F404740
56862	13389	48.000560999999998	48.027645	46.251555000000003	46.234575999999997	Юность	0103000020E61000000100000005000000975302621200484097361C96061E47409753026212004840991249F432204740EF7211DF89034840991249F432204740EF7211DF8903484097361C96061E4740975302621200484097361C96061E4740
56868	13389	48.000560999999998	48.027645	46.251555000000003	46.234575999999997	Школьная	0103000020E61000000100000005000000975302621200484097361C96061E47409753026212004840991249F432204740EF7211DF89034840991249F432204740EF7211DF8903484097361C96061E4740975302621200484097361C96061E4740
56922	13114	48.096581999999998	48.111665000000002	46.236147000000003	46.223860000000002	Чехова	0103000020E61000000100000005000000EEB089CC5C0C4840F870C971A71C4740EEB089CC5C0C484036069D103A1E4740CE8DE9094B0E484036069D103A1E4740CE8DE9094B0E4840F870C971A71C4740EEB089CC5C0C4840F870C971A71C4740
56955	13520	48.033619000000002	48.045665	46.348129999999998	46.347403	Ленина	0103000020E610000001000000050000001AC39CA04D04484022C495B3772C47401AC39CA04D044840D4601A868F2C474032C9C859D8054840D4601A868F2C474032C9C859D805484022C495B3772C47401AC39CA04D04484022C495B3772C4740
57298	57142	48.033619000000002	48.045665	46.348129999999998	46.347403	Ленина	0103000020E610000001000000050000001AC39CA04D04484022C495B3772C47401AC39CA04D044840D4601A868F2C474032C9C859D8054840D4601A868F2C474032C9C859D805484022C495B3772C47401AC39CA04D04484022C495B3772C4740
56921	13670	48.182792999999997	48.198684	46.463546000000001	46.455264	Советская	0103000020E610000001000000050000000778D2C265174840E8853B17463A47400778D2C2651748408718AF79553B4740861E317A6E1948408718AF79553B4740861E317A6E194840E8853B17463A47400778D2C265174840E8853B17463A4740
57130	12694	48.218843	48.230744999999999	46.294960000000003	46.287936000000002	Советская	0103000020E61000000100000005000000B1FA230C031C4840A8AB3B16DB244740B1FA230C031C484068D0D03FC1254740965B5A0D891D484068D0D03FC1254740965B5A0D891D4840A8AB3B16DB244740B1FA230C031C4840A8AB3B16DB244740
57004	12694	48.218843	48.230744999999999	46.294960000000003	46.287936000000002	Ленина	0103000020E61000000100000005000000B1FA230C031C4840A8AB3B16DB244740B1FA230C031C484068D0D03FC1254740965B5A0D891D484068D0D03FC1254740965B5A0D891D4840A8AB3B16DB244740B1FA230C031C4840A8AB3B16DB244740
56887	57106	47.951467999999998	48.456949999999999	46.464438999999999	46.122253000000001	Клубная	0103000020E61000000100000005000000639813B4C9F94740406B7EFCA50F4740639813B4C9F9474054FEB5BC723B47401FF46C567D3A484054FEB5BC723B47401FF46C567D3A4840406B7EFCA50F4740639813B4C9F94740406B7EFCA50F4740
56863	12675	48.230035999999998	48.258791000000002	46.299525000000003	46.284180999999997	Ленина	0103000020E610000001000000050000008A73D4D1711D48408192020B602447408A73D4D1711D4840CEAACFD556264740E4BF401020214840CEAACFD556264740E4BF4010202148408192020B602447408A73D4D1711D48408192020B60244740
56954	13270	48.186225	48.201532	46.240031000000002	46.232306999999999	Ленина	0103000020E610000001000000050000004B598638D6174840E1D05B3CBC1D47404B598638D61748405A83F755B91E47407A8CF2CCCB1948405A83F755B91E47407A8CF2CCCB194840E1D05B3CBC1D47404B598638D6174840E1D05B3CBC1D4740
57103	13235	48.164971000000001	48.176873000000001	46.245727000000002	46.236172000000003	Молодежная	0103000020E61000000100000005000000EBE40CC51D1548408F1D54E23A1E4740EBE40CC51D154840425F7AFB731F4740D04543C6A3164840425F7AFB731F4740D04543C6A31648408F1D54E23A1E4740EBE40CC51D1548408F1D54E23A1E4740
57254	13184	48.201774999999998	48.207326000000002	46.194378999999998	46.188895000000002	Садовая	0103000020E61000000100000005000000401361C3D319484060B01BB62D184740401361C3D3194840BC033C69E118474025CE8AA8891A4840BC033C69E118474025CE8AA8891A484060B01BB62D184740401361C3D319484060B01BB62D184740
57273	12773	48.260057000000003	48.268006999999997	46.325251999999999	46.318648000000003	Школьная	0103000020E61000000100000005000000460C3B8C49214840C9772975C9284740460C3B8C49214840B37A87DBA1294740AE0CAA0D4E224840B37A87DBA1294740AE0CAA0D4E224840C9772975C9284740460C3B8C49214840C9772975C9284740
56838	12638	48.310308999999997	48.327188	46.324629999999999	46.312044	Юбилейная	0103000020E61000000100000005000000C5538F34B8274840DE74CB0EF1274740C5538F34B827484076A6D0798D29474063D2DF4BE129484076A6D0798D29474063D2DF4BE1294840DE74CB0EF1274740C5538F34B8274840DE74CB0EF1274740
57192	13458	48.018141	48.028328000000002	46.197504000000002	46.185307999999999	Фрунзе	0103000020E61000000100000005000000BEDBBC7152024840F5D72B2CB8174740BEDBBC7152024840236AA2CF47194740D2C77C40A0034840236AA2CF47194740D2C77C40A0034840F5D72B2CB8174740BEDBBC7152024840F5D72B2CB8174740
57249	11751	47.632162000000001	47.661752	46.256914000000002	46.252021999999997	М.Джалиля	0103000020E6100000010000000500000011E335AFEAD04740AEEFC3414220474011E335AFEAD0474039F1D58EE220474003081F4AB4D4474039F1D58EE220474003081F4AB4D44740AEEFC3414220474011E335AFEAD04740AEEFC34142204740
57274	11837	47.454143000000002	47.466971000000001	46.252862999999998	46.249279999999999	Советская	0103000020E610000001000000050000008A5A9A5B21BA474000C63368E81F47408A5A9A5B21BA474029AF95D05D2047401897AAB4C5BB474029AF95D05D2047401897AAB4C5BB474000C63368E81F47408A5A9A5B21BA474000C63368E81F4740
57163	57132	48.050964999999998	48.058304999999997	46.541269999999997	46.534816999999997	Вересаева	0103000020E61000000100000005000000CD1E680586064840232C2AE274444740CD1E6805860648402827DA5548454740BD18CA89760748402827DA5548454740BD18CA8976074840232C2AE274444740CD1E680586064840232C2AE274444740
57146	11446	47.966030000000003	47.967053999999997	46.472763	46.469399000000003	Санаторная	0103000020E610000001000000050000003A7AFCDEA6FB474037E33444153C47403A7AFCDEA6FB474022E17B7F833C4740A5BBEB6CC8FB474022E17B7F833C4740A5BBEB6CC8FB474037E33444153C47403A7AFCDEA6FB474037E33444153C4740
57245	11410	47.939816999999998	47.974868999999998	46.339787999999999	46.337915000000002	Советская	0103000020E61000000100000005000000C79C67EC4BF84740F7E978CC402B4740C79C67EC4BF8474060C9552C7E2B47402E71E481C8FC474060C9552C7E2B47402E71E481C8FC4740F7E978CC402B4740C79C67EC4BF84740F7E978CC402B4740
56953	11486	47.899078000000003	47.924616999999998	46.652000000000001	46.623536999999999	Горького	0103000020E61000000100000005000000CC46E7FC14F34740486C770FD04F4740CC46E7FC14F34740FA7E6ABC74534740AE2990D959F64740FA7E6ABC74534740AE2990D959F64740486C770FD04F4740CC46E7FC14F34740486C770FD04F4740
56919	12208	47.170140000000004	47.200547999999998	46.227307000000003	46.220092999999999	Ленина	0103000020E61000000100000005000000E8DEC325C79547400D8AE6012C1C4740E8DEC325C795474071935165181D47409CA38E8EAB99474071935165181D47409CA38E8EAB9947400D8AE6012C1C4740E8DEC325C79547400D8AE6012C1C4740
57243	11626	47.770232999999998	47.790840000000003	46.841453000000001	46.818950000000001	Набережная	0103000020E6100000010000000500000065A6B4FE96E247409487855AD368474065A6B4FE96E24740800F5EBBB46B4740302FC03E3AE54740800F5EBBB46B4740302FC03E3AE547409487855AD368474065A6B4FE96E247409487855AD3684740
57271	12046	47.867179	47.892853000000002	46.293534000000001	46.285674999999998	Кирова	0103000020E610000001000000050000009563B2B8FFEE4740742497FF902447409563B2B8FFEE4740CD21A985922547405891D10149F24740CD21A985922547405891D10149F24740742497FF902447409563B2B8FFEE4740742497FF90244740
56952	12538	47.707881	47.740507999999998	46.334268999999999	46.330461	Советская	0103000020E61000000100000005000000DA3A38D89BDA47403ECDC98B4C2A4740DA3A38D89BDA474087889B53C92A4740933655F7C8DE474087889B53C92A4740933655F7C8DE47403ECDC98B4C2A4740DA3A38D89BDA47403ECDC98B4C2A4740
57269	11535	47.879845000000003	47.896490999999997	46.702514000000001	46.684156000000002	Гагарина	0103000020E610000001000000050000004A46CEC29EF047405CAE7E6C925747404A46CEC29EF04740B77D8FFAEB59474044149337C0F24740B77D8FFAEB59474044149337C0F247405CAE7E6C925747404A46CEC29EF047405CAE7E6C92574740
56881	12292	47.841945000000003	47.862535000000001	46.699393000000001	46.684088000000003	Школьная	0103000020E61000000100000005000000EF0390DAC4EB474004CB113290574740EF0390DAC4EB47409206B7B585594740E353008C67EE47409206B7B585594740E353008C67EE474004CB113290574740EF0390DAC4EB474004CB113290574740
56857	11792	47.401699000000001	47.450369999999999	46.261699	46.251030999999998	Ленина	0103000020E61000000100000005000000FFEA71DF6AB347401EA4A7C821204740FFEA71DF6AB34740AD32535A7F214740BD8C62B9A5B94740AD32535A7F214740BD8C62B9A5B947401EA4A7C821204740FFEA71DF6AB347401EA4A7C821204740
57242	11693	47.517007	47.554332000000002	46.234695000000002	46.231484000000002	Ленина	0103000020E61000000100000005000000CB660E492DC247400DC68844A11D4740CB660E492DC2474072C45A7C0A1E47402A90D959F4C6474072C45A7C0A1E47402A90D959F4C647400DC68844A11D4740CB660E492DC247400DC68844A11D4740
56858	11297	47.848593000000001	47.886825000000002	46.677553000000003	46.633772999999998	Почтовая	0103000020E61000000100000005000000A94E07B29EEC47403D0B42791F514740A94E07B29EEC47404227840EBA5647403A234A7B83F147404227840EBA5647403A234A7B83F147403D0B42791F514740A94E07B29EEC47403D0B42791F514740
57241	11355	47.799401000000003	47.816631000000001	46.759217	46.746782000000003	Школьная	0103000020E61000000100000005000000E2B19FC552E64740E99E758D965F4740E2B19FC552E647409BC8CC052E6147402CF3565D87E847409BC8CC052E6147402CF3565D87E84740E99E758D965F4740E2B19FC552E64740E99E758D965F4740
56860	12186	47.231701999999999	47.272153000000003	46.192906999999998	46.182156999999997	Коммунистическая	0103000020E610000001000000050000007A354069A89D474065DEAAEB501747407A354069A89D4740B115342DB11847401041D5E8D5A24740B115342DB11847401041D5E8D5A2474065DEAAEB501747407A354069A89D474065DEAAEB50174740
57125	11584	47.778111000000003	47.794612999999998	46.797910999999999	46.780653000000001	Пионерская	0103000020E6100000010000000500000035D4282499E347401C430070EC63474035D4282499E34740300F99F221664740FCFCF7E0B5E54740300F99F221664740FCFCF7E0B5E547401C430070EC63474035D4282499E347401C430070EC634740
57221	10828	47.488430999999999	47.512928000000002	45.960678999999999	45.956719	Иванова	0103000020E6100000010000000500000021AD31E884BE47401D3BA8C475FA464021AD31E884BE47401C7A8B87F7FA4640F299EC9FA7C147401C7A8B87F7FA4640F299EC9FA7C147401D3BA8C475FA464021AD31E884BE47401D3BA8C475FA4640
56856	9966	47.093505	47.140801000000003	45.778467999999997	45.759934999999999	Кирова	0103000020E610000001000000050000009981CAF8F78B4740FA0AD28C45E146409981CAF8F78B4740C37DE4D6A4E346403F1F65C405924740C37DE4D6A4E346403F1F65C405924740FA0AD28C45E146409981CAF8F78B4740FA0AD28C45E14640
57270	11000	47.549688000000003	47.566198999999997	45.861528	45.854717999999998	Полевая	0103000020E610000001000000050000007880272D5CC64740B9A6406667ED46407880272D5CC647404D4BAC8C46EE46409203763579C847404D4BAC8C46EE46409203763579C84740B9A6406667ED46407880272D5CC64740B9A6406667ED4640
57067	57118	46.911856999999998	47.686959000000002	46.172795999999998	45.414918	Советская	0103000020E6100000010000000500000078D0ECBAB7744740C84274081CB5464078D0ECBAB77447409770E82D1E164740B058C345EED747409770E82D1E164740B058C345EED74740C84274081CB5464078D0ECBAB7744740C84274081CB54640
57212	57140	46.911856999999998	47.686959000000002	46.172795999999998	45.414918	Школьная	0103000020E6100000010000000500000078D0ECBAB7744740C84274081CB5464078D0ECBAB77447409770E82D1E164740B058C345EED747409770E82D1E164740B058C345EED74740C84274081CB5464078D0ECBAB7744740C84274081CB54640
57217	10279	47.558734000000001	47.570528000000003	45.648578999999998	45.638509999999997	Мира	0103000020E61000000100000005000000E694809884C74740A01518B2BAD14640E694809884C74740AAEFFCA204D34640E5B9BE0F07C94740AAEFFCA204D34640E5B9BE0F07C94740A01518B2BAD14640E694809884C74740A01518B2BAD14640
57102	10882	47.292211999999999	47.308939000000002	45.893388999999999	45.889180000000003	Октябрьская	0103000020E61000000100000005000000D7BFEB3367A54740EF2076A6D0F14640D7BFEB3367A5474096CD1C925AF24640BFBA2A508BA7474096CD1C925AF24640BFBA2A508BA74740EF2076A6D0F14640D7BFEB3367A54740EF2076A6D0F14640
56962	10444	47.152920000000002	47.182437999999998	45.729097000000003	45.715972000000001	Ленина	0103000020E61000000100000005000000C173EFE192934740056D72F8A4DB4640C173EFE1929347404D4EED0C53DD464019C6DD205A9747404D4EED0C53DD464019C6DD205A974740056D72F8A4DB4640C173EFE192934740056D72F8A4DB4640
57292	9905	47.320113999999997	47.334944999999998	45.811025000000001	45.804251999999998	Молодежная	0103000020E61000000100000005000000F17EDC7EF9A847400DDFC2BAF1E64640F17EDC7EF9A84740849ECDAACFE74640B77A4E7ADFAA4740849ECDAACFE74640B77A4E7ADFAA47400DDFC2BAF1E64640F17EDC7EF9A847400DDFC2BAF1E64640
56910	10055	47.520322	47.548330999999997	45.792853999999998	45.780982000000002	Советская	0103000020E61000000100000005000000D5B14AE999C24740E161DA37F7E34640D5B14AE999C247405B40683D7CE546400531D0B52FC647405B40683D7CE546400531D0B52FC64740E161DA37F7E34640D5B14AE999C24740E161DA37F7E34640
57123	10577	47.109872000000003	47.137611999999997	45.935412999999997	45.919677999999998	Кооперативная	0103000020E61000000100000005000000815F2349108E4740E36C3A02B8F54640815F2349108E47406AA0F99CBBF74640C1C41F459D9147406AA0F99CBBF74640C1C41F459D914740E36C3A02B8F54640815F2349108E4740E36C3A02B8F54640
56999	57112	47.19903	47.263278	45.795304999999999	45.775481999999997	Победы	0103000020E610000001000000050000002176A6D0799947407E5182FE42E346402176A6D07999474032ACE28DCCE54640CEE0EF17B3A1474032ACE28DCCE54640CEE0EF17B3A147407E5182FE42E346402176A6D0799947407E5182FE42E34640
56977	57112	47.19903	47.263278	45.795304999999999	45.775481999999997	Космонавтов	0103000020E610000001000000050000002176A6D0799947407E5182FE42E346402176A6D07999474032ACE28DCCE54640CEE0EF17B3A1474032ACE28DCCE54640CEE0EF17B3A147407E5182FE42E346402176A6D0799947407E5182FE42E34640
56912	57111	47.19903	47.263278	45.795304999999999	45.775481999999997	Ленина	0103000020E610000001000000050000002176A6D0799947407E5182FE42E346402176A6D07999474032ACE28DCCE54640CEE0EF17B3A1474032ACE28DCCE54640CEE0EF17B3A147407E5182FE42E346402176A6D0799947407E5182FE42E34640
56859	10112	47.515183	47.534137999999999	45.783150999999997	45.77469	Свердлова	0103000020E61000000100000005000000433A3C84F1C14740E544BB0A29E34640433A3C84F1C14740336ABE4A3EE4464082C64CA25EC44740336ABE4A3EE4464082C64CA25EC44740E544BB0A29E34640433A3C84F1C14740E544BB0A29E34640
57104	10943	47.511598999999997	47.538359999999997	45.860849999999999	45.849688999999998	Колхозная	0103000020E6100000010000000500000049D576137CC14740AE62F19BC2EC464049D576137CC147407C61325530EE4640BEBC00FBE8C447407C61325530EE4640BEBC00FBE8C44740AE62F19BC2EC464049D576137CC14740AE62F19BC2EC4640
56913	10658	47.123679000000003	47.169052999999998	45.992896999999999	45.977792000000001	Советская	0103000020E61000000100000005000000DB19A6B6D48F47402D25CB4928FD4640DB19A6B6D48F4740F4A5B73F17FF464035255987A3954740F4A5B73F17FF464035255987A39547402D25CB4928FD4640DB19A6B6D48F47402D25CB4928FD4640
57194	10750	47.433275000000002	47.468066999999998	45.952233	45.944305999999997	Советская	0103000020E610000001000000050000005396218E75B7474052B5DD04DFF846405396218E75B7474003965CC5E2F946401DAB949EE9BB474003965CC5E2F946401DAB949EE9BB474052B5DD04DFF846405396218E75B7474052B5DD04DFF84640
56916	10853	47.424596999999999	47.485098999999998	45.881883999999999	45.875064000000002	Советская	0103000020E61000000100000005000000677DCA3159B6474017F4DE1802F04640677DCA3159B64740CE6E2D93E1F0464041295AB917BE4740CE6E2D93E1F0464041295AB917BE474017F4DE1802F04640677DCA3159B6474017F4DE1802F04640
57238	10200	47.525433	47.540067000000001	45.730085000000003	45.720905000000002	Горького	0103000020E610000001000000050000009D9E776341C34740EE42739D46DC46409D9E776341C347406C26DF6C73DD46400D535BEA20C547406C26DF6C73DD46400D535BEA20C54740EE42739D46DC46409D9E776341C34740EE42739D46DC4640
57218	10302	47.639124000000002	47.646858000000002	45.620983000000003	45.602106999999997	Октябрьская	0103000020E610000001000000050000005B0BB3D0CED14740A9D898D711CD46405B0BB3D0CED147409D2FF65E7CCF4640F793313ECCD247409D2FF65E7CCF4640F793313ECCD24740A9D898D711CD46405B0BB3D0CED14740A9D898D711CD4640
57220	10536	47.519494999999999	47.538980000000002	45.616759000000002	45.611899000000001	Южная	0103000020E61000000100000005000000BFB7E9CF7EC2474041BAD8B452CE4640BFB7E9CF7EC24740C0417BF5F1CE46405B99F04BFDC44740C0417BF5F1CE46405B99F04BFDC4474041BAD8B452CE4640BFB7E9CF7EC2474041BAD8B452CE4640
57101	10456	47.399425999999998	47.416547999999999	45.703259000000003	45.697316999999998	Мира	0103000020E610000001000000050000000796236420B34740F0F8F6AE41D946400796236420B3474010CF126404DA46406B9BE27151B5474010CF126404DA46406B9BE27151B54740F0F8F6AE41D946400796236420B34740F0F8F6AE41D94640
57100	10163	47.568040000000003	47.605527000000002	45.729675999999998	45.713096	Советская	0103000020E61000000100000005000000F168E388B5C847404774CFBA46DB4640F168E388B5C847408A56EE0566DD464029ECA2E881CD47408A56EE0566DD464029ECA2E881CD47404774CFBA46DB4640F168E388B5C847404774CFBA46DB4640
57098	57125	48.04421	48.067008999999999	46.691859000000001	46.67662	Ленина	0103000020E61000000100000005000000FD135CACA8054840E6E8F17B9B564740FD135CACA8054840BD38F1D58E584740D2C43BC093084840BD38F1D58E584740D2C43BC093084840E6E8F17B9B564740FD135CACA8054840E6E8F17B9B564740
57308	57147	47.811096999999997	49.014012999999998	47.519995000000002	46.405698000000001	Набережная	0103000020E610000001000000050000001D71C806D2E74740BC067DE9ED3347401D71C806D2E74740B18A37328FC24740035C902DCB814840B18A37328FC24740035C902DCB814840BC067DE9ED3347401D71C806D2E74740BC067DE9ED334740
57219	9596	48.114072	48.133403999999999	46.677368000000001	46.658617999999997	Набережная	0103000020E61000000100000005000000D5B14AE9990E4840494739984D544740D5B14AE9990E4840B0AD9FFEB3564740EA93DC6113114840B0AD9FFEB3564740EA93DC6113114840494739984D544740D5B14AE9990E4840494739984D544740
57222	9498	48.209589999999999	48.224448000000002	46.604216999999998	46.598427999999998	Мира	0103000020E61000000100000005000000C9C859D8D31A48405E81E849994C4740C9C859D8D31A4840F7578FFB564D474089D349B6BA1C4840F7578FFB564D474089D349B6BA1C48405E81E849994C4740C9C859D8D31A48405E81E849994C4740
57162	9091	48.358755000000002	48.384393000000003	46.512526000000001	46.489635999999997	Елизарова	0103000020E61000000100000005000000642310AFEB2D4840DD787764AC3E4740642310AFEB2D4840C32CB4739A414740DAE731CA33314840C32CB4739A414740DAE731CA33314840DD787764AC3E4740642310AFEB2D4840DD787764AC3E4740
57272	9297	48.050021999999998	48.060352999999999	46.649512999999999	46.629193999999998	Школьная	0103000020E610000001000000050000004E0AF31E67064840726BD26D895047404E0AF31E67064840D6A9F23D23534740959BA8A5B9074840D6A9F23D23534740959BA8A5B9074840726BD26D895047404E0AF31E67064840726BD26D89504740
57268	8662	48.041021000000001	48.071348	46.729118999999997	46.723861999999997	Юбилейная	0103000020E6100000010000000500000080B9162D4005484098689082A75C474080B9162D4005484034F279C5535D4740485167EE2109484034F279C5535D4740485167EE2109484098689082A75C474080B9162D4005484098689082A75C4740
57300	9036	48.458396	48.475644000000003	46.665768	46.662346999999997	Набережная	0103000020E61000000100000005000000014F5AB8AC3A484046CD57C9C7544740014F5AB8AC3A4840965CC5E237554740F24410E7E13C4840965CC5E237554740F24410E7E13C484046CD57C9C7544740014F5AB8AC3A484046CD57C9C7544740
57128	8522	48.525517999999998	48.541418999999998	46.519750000000002	46.513269999999999	Советская	0103000020E61000000100000005000000CBBA7F2C444348404B02D4D4B2414740CBBA7F2C444348404A0C022B874247406D37C1374D4548404A0C022B874247406D37C1374D4548404B02D4D4B2414740CBBA7F2C444348404B02D4D4B2414740
56906	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Советская	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
56855	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Мордовцева	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
56908	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Леонова	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
56853	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Ленинская	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
57174	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	З.Ананьевой	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
57099	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Братская	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
57267	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Береговая	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
56948	8058	48.316758999999998	48.362771000000002	46.551043999999997	46.518374000000001	Ахтубинская	0103000020E6100000010000000500000059DB148F8B284840618C48145A42474059DB148F8B28484019541B9C88464740F777B6476F2E484019541B9C88464740F777B6476F2E4840618C48145A42474059DB148F8B284840618C48145A424740
57216	9426	48.718369000000003	48.742066000000001	46.532418	46.529100999999997	Заречная	0103000020E61000000100000005000000E9BAF083F35B4840F4A3E194B9434740E9BAF083F35B48409FE6E445264447409DBCC804FC5E48409FE6E445264447409DBCC804FC5E4840F4A3E194B9434740E9BAF083F35B4840F4A3E194B9434740
57097	8843	47.931885000000001	47.942583999999997	46.863238000000003	46.847352000000001	Степная	0103000020E610000001000000050000000551F70148F74740A019C407766C47400551F70148F747400D5531957E6E4740CEDDAE97A6F847400D5531957E6E4740CEDDAE97A6F84740A019C407766C47400551F70148F74740A019C407766C4740
57290	8969	48.622501	48.646683000000003	46.547561000000002	46.523997999999999	Центральная	0103000020E61000000100000005000000185DDE1CAE4F4840AF95D05D12434740185DDE1CAE4F484054C8957A1646474089F02F82C652484054C8957A1646474089F02F82C6524840AF95D05D12434740185DDE1CAE4F4840AF95D05D12434740
56854	9674	48.300293000000003	48.313983	46.527185000000003	46.519731999999998	Советская	0103000020E61000000100000005000000DF1B430070264840A357039486424740DF1B4300702648408CF84ECC7A434740FF3F4E98302848408CF84ECC7A434740FF3F4E9830284840A357039486424740DF1B430070264840A357039486424740
57096	8885	47.889510999999999	47.924374999999998	46.919992999999998	46.894418999999999	Привокзальная	0103000020E610000001000000050000005437177FDBF14740E4F560527C7247405437177FDBF1474043C6A354C2754740B81E85EB51F6474043C6A354C2754740B81E85EB51F64740E4F560527C7247405437177FDBF14740E4F560527C724740
57150	7974	48.214072999999999	48.226953999999999	46.635505000000002	46.617725	Мира	0103000020E6100000010000000500000072FA7ABE661B4840F775E09C114F474072FA7ABE661B4840E5B8533A5851474023D923D40C1D4840E5B8533A5851474023D923D40C1D4840F775E09C114F474072FA7ABE661B4840F775E09C114F4740
57239	8803	47.930753000000003	47.944316999999998	46.828555999999999	46.817388999999999	Центральная	0103000020E61000000100000005000000B3D30FEA22F74740198EE733A0684740B3D30FEA22F74740C9737D1F0E6A474046072461DFF84740C9737D1F0E6A474046072461DFF84740198EE733A0684740B3D30FEA22F74740198EE733A0684740
56949	9469	48.148648000000001	48.181049999999999	46.628673999999997	46.611063999999999	Ленина	0103000020E61000000100000005000000D34ECDE506134840A8E15B58374E4740D34ECDE50613484039ECBE63785047406C787AA52C17484039ECBE63785047406C787AA52C174840A8E15B58374E4740D34ECDE506134840A8E15B58374E4740
56909	9353	48.383575999999998	48.393098000000002	46.558883999999999	46.549885000000003	Гагарина	0103000020E61000000100000005000000E7C3B30419314840CEC7B5A162464740E7C3B30419314840FB20CB8289474740BF0F070951324840FB20CB8289474740BF0F070951324840CEC7B5A162464740E7C3B30419314840CEC7B5A162464740
57129	8736	48.024016000000003	48.043742999999999	46.728273000000002	46.711962999999997	Волгоградская	0103000020E61000000100000005000000564ACFF412034840247B849A215B4740564ACFF412034840A8C7B60C385D4740E736E15E99054840A8C7B60C385D4740E736E15E99054840247B849A215B4740564ACFF412034840247B849A215B4740
57126	9212	47.967728000000001	47.985891000000002	46.715131999999997	46.706462999999999	Советская	0103000020E6100000010000000500000035B6D782DEFB4740C26A2C616D5A474035B6D782DEFB47405A290472895B4740DB3521AD31FE47405A290472895B4740DB3521AD31FE4740C26A2C616D5A474035B6D782DEFB4740C26A2C616D5A4740
57291	8740	47.937444999999997	47.962983999999999	46.813436000000003	46.804535999999999	Заречная	0103000020E610000001000000050000003C66A032FEF74740323A2009FB6647403C66A032FEF74740CDB1BCAB1E6847401F49490F43FB4740CDB1BCAB1E6847401F49490F43FB4740323A2009FB6647403C66A032FEF74740323A2009FB664740
57288	8586	48.674683999999999	48.714272000000001	46.479317000000002	46.471986999999999	Иришева	0103000020E610000001000000050000003691990B5C5648408E91EC116A3C47403691990B5C5648405BB56B425A3D47406939D0436D5B48405BB56B425A3D47406939D0436D5B48408E91EC116A3C47403691990B5C5648408E91EC116A3C4740
57121	9175	48.450060000000001	48.463102999999997	46.656582999999998	46.648677999999997	Советская	0103000020E610000001000000050000006F9EEA909B3948403DD175E1075347406F9EEA909B394840060E68E90A544740F9D687F5463B4840060E68E90A544740F9D687F5463B48403DD175E1075347406F9EEA909B3948403DD175E107534740
57191	8610	48.325418999999997	48.339827999999997	46.582183999999998	46.576058000000003	Октябрьская	0103000020E610000001000000050000009E3F6D54A7294840B24CBF44BC4947409E3F6D54A729484092205C01854A4740EE21E17B7F2B484092205C01854A4740EE21E17B7F2B4840B24CBF44BC4947409E3F6D54A7294840B24CBF44BC494740
57225	9345	47.999203999999999	48.022067	46.653613999999997	46.648443	Школьная	0103000020E610000001000000050000002504ABEAE5FF4740FA28232E005347402504ABEAE5FF4740971AA19FA953474011A96917D3024840971AA19FA953474011A96917D3024840FA28232E005347402504ABEAE5FF4740FA28232E00534740
57122	9103	48.006391000000001	48.013801999999998	46.797781999999998	46.787182000000001	Набережная	0103000020E610000001000000050000008FFE976BD1004840FCFF3861C26447408FFE976BD100484032AB77B81D664740484F9143C401484032AB77B81D664740484F9143C4014840FCFF3861C26447408FFE976BD1004840FCFF3861C2644740
57320	57151	47.759892999999998	48.613211999999997	46.210895000000001	45.413229000000001	улица Молодежная	0103000020E61000000100000005000000CBBA7F2C44E14740206118B0E4B44640CBBA7F2C44E14740E9F17B9BFE1A4740E3C116BB7D4E4840E9F17B9BFE1A4740E3C116BB7D4E4840206118B0E4B44640CBBA7F2C44E14740206118B0E4B44640
57235	6999	48.259860000000003	48.281159000000002	45.980905	45.972982000000002	Восточная	0103000020E61000000100000005000000F0C4AC174321484060CC96AC8AFC4640F0C4AC1743214840CFBD874B8EFD4640F0FCA204FD234840CFBD874B8EFD4640F0FCA204FD23484060CC96AC8AFC4640F0C4AC174321484060CC96AC8AFC4640
56837	8016	47.945126000000002	47.983708999999998	46.180584000000003	46.166929000000003	Школьная	0103000020E61000000100000005000000B64C86E3F9F8474083E0F1ED5D154740B64C86E3F9F84740271763601D174740F3E32F2DEAFD4740271763601D174740F3E32F2DEAFD474083E0F1ED5D154740B64C86E3F9F8474083E0F1ED5D154740
57263	7307	47.900713000000003	47.92398	46.098461	46.081079000000003	Ленина	0103000020E61000000100000005000000810A47904AF347403AB2F2CB600A4740810A47904AF347403A77BB5E9A0C47403C1405FA44F647403A77BB5E9A0C47403C1405FA44F647403AB2F2CB600A4740810A47904AF347403AB2F2CB600A4740
57286	7976	48.036259999999999	48.044848000000002	46.076583999999997	46.068331000000001	Дорожная	0103000020E610000001000000050000009413ED2AA4044840C826F911BF0847409413ED2AA4044840CCB22781CD09474040A54A94BD054840CCB22781CD09474040A54A94BD054840C826F911BF0847409413ED2AA4044840C826F911BF084740
57108	7938	48.031903	48.044550999999998	46.057419000000003	46.034675	Ксенофонтова	0103000020E6100000010000000500000078D2C26515044840917EFB3A7004474078D2C26515044840A3957B81590747408600E0D8B3054840A3957B81590747408600E0D8B3054840917EFB3A7004474078D2C26515044840917EFB3A70044740
57090	6507	48.315995000000001	48.349736	46.157598	46.122528000000003	Школьная	0103000020E610000001000000050000008A592F8672284840126C5CFFAE0F47408A592F86722848401FF5D72B2C144740EF1D3526C42C48401FF5D72B2C144740EF1D3526C42C4840126C5CFFAE0F47408A592F8672284840126C5CFFAE0F4740
57185	6507	48.315995000000001	48.349736	46.157598	46.122528000000003	Ленина	0103000020E610000001000000050000008A592F8672284840126C5CFFAE0F47408A592F86722848401FF5D72B2C144740EF1D3526C42C48401FF5D72B2C144740EF1D3526C42C4840126C5CFFAE0F47408A592F8672284840126C5CFFAE0F4740
57262	6659	48.345585999999997	48.365268	46.163041	46.150443000000003	Джамбула	0103000020E610000001000000050000004CFA7B293C2C4840C1745AB7411347404CFA7B293C2C48401D740987DE1447403E23111AC12E48401D740987DE1447403E23111AC12E4840C1745AB7411347404CFA7B293C2C4840C1745AB741134740
57234	6442	48.106462999999998	48.116677000000003	45.827047999999998	45.811382999999999	Советская	0103000020E61000000100000005000000F59D5F94A00D4840E3C3EC65DBE74640F59D5F94A00D4840711C78B5DCE9464003999D45EF0E4840711C78B5DCE9464003999D45EF0E4840E3C3EC65DBE74640F59D5F94A00D4840E3C3EC65DBE74640
57289	6665	48.387985999999998	48.404443000000001	46.102885999999998	46.082504999999998	Маяковского	0103000020E6100000010000000500000026A77686A9314840D4601A868F0A474026A77686A9314840AE9B525E2B0D47404E0CC9C9C4334840AE9B525E2B0D47404E0CC9C9C4334840D4601A868F0A474026A77686A9314840D4601A868F0A4740
56851	6915	48.228606999999997	48.273218	46.184452999999998	46.157952999999999	Курманова	0103000020E610000001000000050000007E5182FE421D48400DA7CCCD371447407E5182FE421D48401553E9279C174740DA56B3CEF82248401553E9279C174740DA56B3CEF82248400DA7CCCD371447407E5182FE421D48400DA7CCCD37144740
56947	7771	47.835234999999997	47.850496999999997	46.045879999999997	46.010275	Советская	0103000020E61000000100000005000000BEBC00FBE8EA4740B37BF2B050014740BEBC00FBE8EA47402EC55565DF0547404D2CF015DDEC47402EC55565DF0547404D2CF015DDEC4740B37BF2B050014740BEBC00FBE8EA4740B37BF2B050014740
56833	6734	48.215833000000003	48.234572	46.083486000000001	46.057243999999997	Степная	0103000020E61000000100000005000000E4326E6AA01B484034F279C553074740E4326E6AA01B484041D653ABAF0A474056478E74061E484041D653ABAF0A474056478E74061E484034F279C553074740E4326E6AA01B484034F279C553074740
57154	7735	47.942700000000002	47.966937000000001	45.870176000000001	45.837560000000003	Братьев Фоминых	0103000020E6100000010000000500000038F8C264AAF847400938842A35EB464038F8C264AAF84740CEE15AED61EF46406C257497C4FB4740CEE15AED61EF46406C257497C4FB47400938842A35EB464038F8C264AAF847400938842A35EB4640
57278	6217	48.235345000000002	48.244318999999997	45.946913000000002	45.936221000000003	Джамбула	0103000020E610000001000000050000007923F3C81F1E48400A6AF816D6F746407923F3C81F1E48402194F77134F946404D6551D8451F48402194F77134F946404D6551D8451F48400A6AF816D6F746407923F3C81F1E48400A6AF816D6F74640
57237	7444	48.101261999999998	48.110263000000003	45.871782000000003	45.851484999999997	Рыбацкая	0103000020E61000000100000005000000ED293927F60C48406C04E275FDEC4640ED293927F60C4840E99E758D96EF4640BC7A15191D0E4840E99E758D96EF4640BC7A15191D0E48406C04E275FDEC4640ED293927F60C48406C04E275FDEC4640
57236	6332	48.139009000000001	48.152645999999997	45.837584999999997	45.827713000000003	Садовая	0103000020E61000000100000005000000C26C020CCB114840AEBCE47FF2E94640C26C020CCB114840614F3BFC35EB4640BFEE74E789134840614F3BFC35EB4640BFEE74E789134840AEBCE47FF2E94640C26C020CCB114840AEBCE47FF2E94640
56850	7582	47.982199000000001	48.011457	45.984862999999997	45.935651	Хлебникова	0103000020E61000000100000005000000FB9463B2B8FD47401FBC7669C3F74640FB9463B2B8FD47402D05A4FD0FFE4640B727486C770148402D05A4FD0FFE4640B727486C770148401FBC7669C3F74640FB9463B2B8FD47401FBC7669C3F74640
57161	7490	47.909472000000001	47.930869999999999	46.168745999999999	46.133564999999997	Мира	0103000020E610000001000000050000005950189469F44740F3716DA8181147405950189469F4474058AA0B7899154740EC6987BF26F7474058AA0B7899154740EC6987BF26F74740F3716DA8181147405950189469F44740F3716DA818114740
57299	7697	47.981535000000001	47.995035999999999	45.925753	45.895378000000001	Комсомольская	0103000020E610000001000000050000008F705AF0A2FD474069C70DBF9BF246408F705AF0A2FD4740429605137FF64640DC2BF3565DFF4740429605137FF64640DC2BF3565DFF474069C70DBF9BF246408F705AF0A2FD474069C70DBF9BF24640
57214	7210	48.171222999999998	48.186475999999999	45.983879999999999	45.976728000000001	Джамбула	0103000020E6100000010000000500000058A9A0A2EA154840338B506C05FD464058A9A0A2EA1548402098A3C7EFFD464094BE1072DE1748402098A3C7EFFD464094BE1072DE174840338B506C05FD464058A9A0A2EA154840338B506C05FD4640
57094	7365	48.113632000000003	48.128912	45.926147999999998	45.897585999999997	Степная	0103000020E61000000100000005000000B9E34D7E8B0E484079AC1919E4F24640B9E34D7E8B0E4840BEA085048CF64640EE073C3080104840BEA085048CF64640EE073C308010484079AC1919E4F24640B9E34D7E8B0E484079AC1919E4F24640
9677	7518	47.871437	47.889654999999998	46.166055999999998	46.149175999999997	Мира	0103000020E610000001000000050000001EC3633F8BEF47408EACFC32181347401EC3633F8BEF4740FCA6B0524115474087DC0C37E0F14740FCA6B0524115474087DC0C37E0F147408EACFC32181347401EC3633F8BEF47408EACFC3218134740
57293	7849	47.962338000000003	47.966487999999998	46.005724999999998	46.000991999999997	Садовая	0103000020E610000001000000050000005AD93EE42DFB474060C77F81200047405AD93EE42DFB474082E2C798BB004740FCFCF7E0B5FB474082E2C798BB004740FCFCF7E0B5FB474060C77F81200047405AD93EE42DFB474060C77F8120004740
57260	6854	48.356464000000003	48.367604	46.060158000000001	46.042726999999999	Придорожная	0103000020E61000000100000005000000C619C39CA02D4840FED30D1478054740C619C39CA02D4840E04BE141B30747407CF0DAA50D2F4840E04BE141B30747407CF0DAA50D2F4840FED30D1478054740C619C39CA02D4840FED30D1478054740
57120	6255	48.124563999999999	48.136090000000003	45.881068999999997	45.870477000000001	Молодежная	0103000020E61000000100000005000000252191B6F10F4840C97553CA6BEF4640252191B6F10F48407C4276DEC6F0464005A8A9656B1148407C4276DEC6F0464005A8A9656B114840C97553CA6BEF4640252191B6F10F4840C97553CA6BEF4640
57093	6143	48.289396000000004	48.313353999999997	45.935004999999997	45.907632999999997	Ленина	0103000020E61000000100000005000000EFCB99ED0A2548409BE271512DF44640EFCB99ED0A254840594C6C3EAEF746400F09DFFB1B284840594C6C3EAEF746400F09DFFB1B2848409BE271512DF44640EFCB99ED0A2548409BE271512DF44640
56787	5539	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Ульянова	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
57188	5539	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Тараканова	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
56831	5539	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Пушкина	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
56902	5539	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Максима Горького	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
56848	5539	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Любича	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
57092	5539	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Курмангазы	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
56830	5539	48.065427999999997	48.100346000000002	46.124552000000001	46.083005	Горького	0103000020E61000000100000005000000101FD8F15F084840C63368E89F0A4740101FD8F15F0848406153E751F10F474068244223D80C48406153E751F10F474068244223D80C4840C63368E89F0A4740101FD8F15F084840C63368E89F0A4740
56946	7237	47.964440000000003	47.989341000000003	46.082991999999997	46.056462000000003	Васильева	0103000020E61000000100000005000000257A19C572FB4740BFBB95253A074740257A19C572FB474031EA5A7B9F0A4740C5CBD3B9A2FE474031EA5A7B9F0A4740C5CBD3B9A2FE4740BFBB95253A074740257A19C572FB4740BFBB95253A074740
57155	57130	48.142144000000002	48.167118000000002	45.923202000000003	45.896926999999998	Абая	0103000020E610000001000000050000004CA94BC6311248401FF30181CEF246404CA94BC63112484008CDAE7B2BF646405649641F6415484008CDAE7B2BF646405649641F641548401FF30181CEF246404CA94BC6311248401FF30181CEF24640
57223	6794	48.196007000000002	48.204892000000001	46.111457999999999	46.085042000000001	Степная	0103000020E61000000100000005000000BF64E3C116194840AA6400A8E20A4740BF64E3C11619484054707841440E4740249BABE6391A484054707841440E4740249BABE6391A4840AA6400A8E20A4740BF64E3C116194840AA6400A8E20A4740
57198	57138	47.759892999999998	48.613211999999997	46.210895000000001	45.413229000000001	Школьная	0103000020E61000000100000005000000CBBA7F2C44E14740206118B0E4B44640CBBA7F2C44E14740E9F17B9BFE1A4740E3C116BB7D4E4840E9F17B9BFE1A4740E3C116BB7D4E4840206118B0E4B44640CBBA7F2C44E14740206118B0E4B44640
57303	57144	48.467253999999997	48.491301999999997	46.107903	46.086505000000002	Степная	0103000020E610000001000000050000006C76A4FACE3B484062F88898120B47406C76A4FACE3B4840F511F8C3CF0D4740CD3AE3FBE23E4840F511F8C3CF0D4740CD3AE3FBE23E484062F88898120B47406C76A4FACE3B484062F88898120B4740
57266	7657	47.995809000000001	48.006794999999997	45.858898000000003	45.841365000000003	Молодежная	0103000020E61000000100000005000000FF0758AB76FF4740E17F2BD9B1EB4640FF0758AB76FF4740C74CA25EF0ED46405E6397A8DE004840C74CA25EF0ED46405E6397A8DE004840E17F2BD9B1EB4640FF0758AB76FF4740E17F2BD9B1EB4640
56904	7083	47.901603000000001	47.934804	46.208537999999997	46.193530000000003	Ленина	0103000020E61000000100000005000000DD7C23BA67F34740BF654E97C5184740DD7C23BA67F3474093FC885FB11A4740C21550A8A7F7474093FC885FB11A4740C21550A8A7F74740BF654E97C5184740DD7C23BA67F34740BF654E97C5184740
56832	7060	48.105313000000002	48.145783000000002	46.031658999999998	46.002519999999997	Набережная	0103000020E61000000100000005000000FD6B79E57A0D4840FFCA4A9352004740FD6B79E57A0D4840E1CFF0660D04474009A87004A9124840E1CFF0660D04474009A87004A9124840FFCA4A9352004740FD6B79E57A0D4840FFCA4A9352004740
57232	6961	48.217162999999999	48.230601999999998	46.121048000000002	46.105966000000002	Степная	0103000020E610000001000000050000005C7347FFCB1B4840753E3C4B900D47405C7347FFCB1B4840849F38807E0F47403332C85D841D4840849F38807E0F47403332C85D841D4840753E3C4B900D47405C7347FFCB1B4840753E3C4B900D4740
57264	7861	47.868428000000002	47.878883999999999	45.959307000000003	45.933732999999997	Набережная	0103000020E61000000100000005000000217711A628EF474015191D9084F74640217711A628EF474075E95F92CAFA4640247D5A457FF0474075E95F92CAFA4640247D5A457FF0474015191D9084F74640217711A628EF474015191D9084F74640
57259	4370	47.693210999999998	47.713602999999999	45.993034000000002	45.981343000000003	Школьная	0103000020E610000001000000050000001D1D5723BBD847404B94BDA59CFD46401D1D5723BBD8474075E8F4BC1BFF4640EBA9D55757DB474075E8F4BC1BFF4640EBA9D55757DB47404B94BDA59CFD46401D1D5723BBD847404B94BDA59CFD4640
57116	5132	47.697828999999999	47.721975	45.908504999999998	45.882016	Ленина	0103000020E61000000100000005000000A699EE7552D947403D4679E6E5F04640A699EE7552D9474051A04FE449F44640CAC342AD69DC474051A04FE449F44640CAC342AD69DC47403D4679E6E5F04640A699EE7552D947403D4679E6E5F04640
57215	4791	47.563035999999997	47.582844000000001	45.835821000000003	45.826456999999998	Мичурина	0103000020E610000001000000050000003E3C4B9011C847406F46CD57C9E946403E3C4B9011C84740AF27BA2EFCEA4640BD55D7A19ACA4740AF27BA2EFCEA4640BD55D7A19ACA47406F46CD57C9E946403E3C4B9011C847406F46CD57C9E94640
57159	4735	47.623564999999999	47.645159999999997	45.868474999999997	45.850681000000002	Пионерская	0103000020E6100000010000000500000012F758FAD0CF47400F2A711DE3EC464012F758FAD0CF4740613255302AEF4640FB57569A94D24740613255302AEF4640FB57569A94D247400F2A711DE3EC464012F758FAD0CF47400F2A711DE3EC4640
56945	4537	47.656416	47.681227999999997	45.947037999999999	45.920718999999998	Ленина	0103000020E610000001000000050000001B49827005D4474025E7C41EDAF546401B49827005D44740DD088B8A38F946404B8FA67A32D74740DD088B8A38F946404B8FA67A32D7474025E7C41EDAF546401B49827005D4474025E7C41EDAF54640
57213	4453	47.634146999999999	47.653497000000002	45.984662	45.978743999999999	Гагарина	0103000020E61000000100000005000000A2ED98BA2BD14740FF93BF7B47FD4640A2ED98BA2BD1474096CE876709FE46405E8429CAA5D3474096CE876709FE46405E8429CAA5D34740FF93BF7B47FD4640A2ED98BA2BD14740FF93BF7B47FD4640
57183	5295	47.640292000000002	47.656784999999999	45.786526000000002	45.764701000000002	Пионерский переулок	0103000020E61000000100000005000000FAF19716F5D14740F81BEDB8E1E14640FAF19716F5D1474013BA4BE2ACE446406EC0E78711D4474013BA4BE2ACE446406EC0E78711D44740F81BEDB8E1E14640FAF19716F5D14740F81BEDB8E1E14640
57305	57145	47.681936999999998	47.705680000000001	45.872523000000001	45.851868000000003	Пушкина	0103000020E6100000010000000500000057772CB649D747402541B8020AED464057772CB649D7474000016BD5AEEF46407CB8E4B853DA474000016BD5AEEF46407CB8E4B853DA47402541B8020AED464057772CB649D747402541B8020AED4640
57285	4130	47.611733999999998	47.621130999999998	46.080773000000001	46.077278	Садовая	0103000020E61000000100000005000000F6ECB94C4DCE4740A359D93EE4094740F6ECB94C4DCE47402DB308C5560A474011C4793881CF47402DB308C5560A474011C4793881CF4740A359D93EE4094740F6ECB94C4DCE4740A359D93EE4094740
57233	4507	47.612721999999998	47.629997000000003	45.970846000000002	45.965815999999997	Советская	0103000020E6100000010000000500000015C5ABAC6DCE47400DFAD2DB9FFB464015C5ABAC6DCE4740E9B985AE44FC464000CADFBDA3D04740E9B985AE44FC464000CADFBDA3D047400DFAD2DB9FFB464015C5ABAC6DCE47400DFAD2DB9FFB4640
57189	5084	47.643839999999997	47.678209000000003	45.823298000000001	45.810346000000003	Советская	0103000020E61000000100000005000000A6ED5F5969D24740E338F06AB9E74640A6ED5F5969D247405D6E30D461E946402B6D718DCFD647405D6E30D461E946402B6D718DCFD64740E338F06AB9E74640A6ED5F5969D24740E338F06AB9E74640
57257	4609	47.609695000000002	47.627994000000001	45.897303000000001	45.885052999999999	Колхозная	0103000020E6100000010000000500000072C45A7C0ACE4740041DAD6A49F1464072C45A7C0ACE474025CD1FD3DAF24640C80A7E1B62D0474025CD1FD3DAF24640C80A7E1B62D04740041DAD6A49F1464072C45A7C0ACE4740041DAD6A49F14640
57186	4816	47.532476000000003	47.586995000000002	45.856858000000003	45.837797999999999	Первомайская	0103000020E61000000100000005000000D4F36E2C28C44740BD5301F73CEB4640D4F36E2C28C4474072A8DF85ADED464030F5F3A622CB474072A8DF85ADED464030F5F3A622CB4740BD5301F73CEB4640D4F36E2C28C44740BD5301F73CEB4640
56852	4816	47.532476000000003	47.586995000000002	45.856858000000003	45.837797999999999	Кирова	0103000020E61000000100000005000000D4F36E2C28C44740BD5301F73CEB4640D4F36E2C28C4474072A8DF85ADED464030F5F3A622CB474072A8DF85ADED464030F5F3A622CB4740BD5301F73CEB4640D4F36E2C28C44740BD5301F73CEB4640
57284	4183	47.464194999999997	47.484614000000001	46.081316999999999	46.075552999999999	Степная	0103000020E61000000100000005000000BDFBE3BD6ABB4740AE0E80B8AB094740BDFBE3BD6ABB4740EECD6F98680A47408597E0D407BE4740EECD6F98680A47408597E0D407BE4740AE0E80B8AB094740BDFBE3BD6ABB4740AE0E80B8AB094740
57314	57150	47.196739000000001	47.886457	46.256303000000003	45.336942999999998	Тукая	0103000020E61000000100000005000000836C59BE2E994740DDCEBEF220AB4640836C59BE2E994740F06E6589CE204740B727486C77F14740F06E6589CE204740B727486C77F14740DDCEBEF220AB4640836C59BE2E994740DDCEBEF220AB4640
57148	4651	47.598601000000002	47.626170000000002	45.873728	45.863472999999999	Советская	0103000020E610000001000000050000002C2D23F59ECC474050FD834886EE46402C2D23F59ECC4740BCCCB051D6EF464040DEAB5626D04740BCCCB051D6EF464040DEAB5626D0474050FD834886EE46402C2D23F59ECC474050FD834886EE4640
56901	5377	47.645941999999998	47.684272999999997	45.787852000000001	45.763078999999998	Крупской	0103000020E61000000100000005000000718E3A3AAED24740D7A19A92ACE14640718E3A3AAED247404A0B9755D8E446409544F64196D747404A0B9755D8E446409544F64196D74740D7A19A92ACE14640718E3A3AAED24740D7A19A92ACE14640
57190	4349	47.709246	47.725335000000001	46.038997999999999	46.021754000000001	70 лет Октября	0103000020E61000000100000005000000CF68AB92C8DA47405247C7D5C8024740CF68AB92C8DA4740014EEFE2FD04474074D2FBC6D7DC4740014EEFE2FD04474074D2FBC6D7DC47405247C7D5C8024740CF68AB92C8DA47405247C7D5C8024740
56847	3511	47.834569999999999	47.886457	46.211401000000002	46.196854999999999	Мира	0103000020E61000000100000005000000821C9430D3EA4740EC866D8B32194740821C9430D3EA4740BDAB1E300F1B4740B727486C77F14740BDAB1E300F1B4740B727486C77F14740EC866D8B32194740821C9430D3EA4740EC866D8B32194740
57296	4219	47.556657999999999	47.585647000000002	46.059527000000003	46.053373000000001	Зеленая	0103000020E610000001000000050000004487C09140C74740A5BE2CEDD40647404487C09140C74740501DAB949E07474011001C7BF6CA4740501DAB949E07474011001C7BF6CA4740A5BE2CEDD40647404487C09140C74740A5BE2CEDD4064740
56828	3764	47.688386999999999	47.751835	46.112695000000002	46.065266999999999	Пионерская	0103000020E61000000100000005000000EBFEB1101DD84740074147AB5A084740EBFEB1101DD847401CB62DCA6C0E47407C7E18213CE047401CB62DCA6C0E47407C7E18213CE04740074147AB5A084740EBFEB1101DD84740074147AB5A084740
56843	3764	47.688386999999999	47.751835	46.112695000000002	46.065266999999999	О.Кошевого	0103000020E61000000100000005000000EBFEB1101DD84740074147AB5A084740EBFEB1101DD847401CB62DCA6C0E47407C7E18213CE047401CB62DCA6C0E47407C7E18213CE04740074147AB5A084740EBFEB1101DD84740074147AB5A084740
56835	3764	47.688386999999999	47.751835	46.112695000000002	46.065266999999999	Молодежная	0103000020E61000000100000005000000EBFEB1101DD84740074147AB5A084740EBFEB1101DD847401CB62DCA6C0E47407C7E18213CE047401CB62DCA6C0E47407C7E18213CE04740074147AB5A084740EBFEB1101DD84740074147AB5A084740
56944	3764	47.688386999999999	47.751835	46.112695000000002	46.065266999999999	Гастелло	0103000020E61000000100000005000000EBFEB1101DD84740074147AB5A084740EBFEB1101DD847401CB62DCA6C0E47407C7E18213CE047401CB62DCA6C0E47407C7E18213CE04740074147AB5A084740EBFEB1101DD84740074147AB5A084740
56865	3764	47.688386999999999	47.751835	46.112695000000002	46.065266999999999	1-го Мая	0103000020E61000000100000005000000EBFEB1101DD84740074147AB5A084740EBFEB1101DD847401CB62DCA6C0E47407C7E18213CE047401CB62DCA6C0E47407C7E18213CE04740074147AB5A084740EBFEB1101DD84740074147AB5A084740
57256	5450	47.655679999999997	47.673133999999997	45.757306	45.745955000000002	Советская	0103000020E6100000010000000500000015527E52EDD34740D3A414747BDF464015527E52EDD3474044882B67EFE04640AFE9414129D6474044882B67EFE04640AFE9414129D64740D3A414747BDF464015527E52EDD34740D3A414747BDF4640
56829	5238	47.680725000000002	47.704386	45.813205000000004	45.794846	Пушкина	0103000020E61000000100000005000000E9482EFF21D747409FAD8383BDE54640E9482EFF21D74740CBF8F71917E8464050E1085229DA4740CBF8F71917E8464050E1085229DA47409FAD8383BDE54640E9482EFF21D747409FAD8383BDE54640
57117	4057	47.663207999999997	47.677957999999997	46.127406999999998	46.119760999999997	Школьная	0103000020E610000001000000050000000839EFFFE3D447400A2B1554540F47400839EFFFE3D44740072461DF4E104740E107E753C7D64740072461DF4E104740E107E753C7D647400A2B1554540F47400839EFFFE3D447400A2B1554540F4740
57210	5035	47.552489999999999	47.584370999999997	45.830257000000003	45.821603000000003	Волжская	0103000020E61000000100000005000000FBAE08FEB7C64740D3A57F492AE94640FBAE08FEB7C64740362383DC45EA46408BDD3EABCCCA4740362383DC45EA46408BDD3EABCCCA4740D3A57F492AE94640FBAE08FEB7C64740D3A57F492AE94640
57294	4000	47.638621000000001	47.644792000000002	46.060352000000002	46.051009000000001	Ленина	0103000020E61000000100000005000000F8C43A55BED147409D66817687064740F8C43A55BED14740C51F459DB9074740795C548B88D24740C51F459DB9074740795C548B88D247409D66817687064740F8C43A55BED147409D66817687064740
57261	4301	47.746049999999997	47.773763000000002	46.101505000000003	46.091430000000003	Степная	0103000020E610000001000000050000002497FF907EDF4740C8EF6DFAB30B47402497FF907EDF4740B4B0A71DFE0C47406CED7DAA0AE34740B4B0A71DFE0C47406CED7DAA0AE34740C8EF6DFAB30B47402497FF907EDF4740C8EF6DFAB30B4740
56900	3608	47.803282000000003	47.822560000000003	46.177252000000003	46.151324000000002	Калинина	0103000020E6100000010000000500000095BBCFF1D1E64740CA8CB7955E13474095BBCFF1D1E6474047938B31B0164740B77F65A549E9474047938B31B0164740B77F65A549E94740CA8CB7955E13474095BBCFF1D1E64740CA8CB7955E134740
57211	3673	47.792358	47.809274000000002	46.147047000000001	46.131791	Садовая	0103000020E61000000100000005000000AB5CA8FC6BE547401D740987DE104740AB5CA8FC6BE54740CAFCA36FD212474066C0594A96E74740CAFCA36FD212474066C0594A96E747401D740987DE104740AB5CA8FC6BE547401D740987DE104740
57282	3564	47.834803999999998	47.848773000000001	46.197659999999999	46.183436	Победы	0103000020E61000000100000005000000F54883DBDAEA47405C74B2D47A174740F54883DBDAEA47401ADD41EC4C194740295DFA97A4EC47401ADD41EC4C194740295DFA97A4EC47405C74B2D47A174740F54883DBDAEA47405C74B2D47A174740
57178	2881	46.948247000000002	46.960411000000001	47.341965999999999	47.334369000000002	Ленина/Садовая	0103000020E61000000100000005000000DBC35E2860794740EBE5779ACCAA4740DBC35E2860794740062CB98AC5AB4740FDDB65BFEE7A4740062CB98AC5AB4740FDDB65BFEE7A4740EBE5779ACCAA4740DBC35E2860794740EBE5779ACCAA4740
57253	2421	47.323841999999999	47.337513999999999	47.055672000000001	47.041113000000003	Зеленая	0103000020E610000001000000050000001E8997A773A947406138D730438547401E8997A773A94740C6A695422087474098F8A3A833AB4740C6A695422087474098F8A3A833AB47406138D730438547401E8997A773A947406138D73043854740
57208	2308	47.475783	47.490200999999999	47.011910999999998	47.002195999999998	Колхозная	0103000020E61000000100000005000000137F1475E6BC47404C1762F547804740137F1475E6BC474038BBB54C86814740B6BB07E8BEBE474038BBB54C86814740B6BB07E8BEBE47404C1762F547804740137F1475E6BC47404C1762F547804740
57151	3104	46.463588000000001	46.503005999999999	47.685305999999997	47.671455999999999	Мира	0103000020E61000000100000005000000B66801DA563B4740FB592C45F2D54740B66801DA563B474054E0641BB8D747408CD827806240474054E0641BB8D747408CD8278062404740FB592C45F2D54740B66801DA563B4740FB592C45F2D54740
57207	2199	47.587685999999998	47.598447999999998	46.890669000000003	46.878622	Колхозная	0103000020E6100000010000000500000095287B4B39CB4740E7C589AF7670474095287B4B39CB4740D047197101724740A52DAEF199CC4740D047197101724740A52DAEF199CC4740E7C589AF7670474095287B4B39CB4740E7C589AF76704740
56803	3179	46.389918000000002	46.415430000000001	47.771244000000003	47.746783999999998	Московская	0103000020E61000000100000005000000950F41D5E831474089963C9E96DF4740950F41D5E83147403D9E961FB8E247407EE36BCF2C3547403D9E961FB8E247407EE36BCF2C35474089963C9E96DF4740950F41D5E831474089963C9E96DF4740
57304	2940	46.843755000000002	46.853242000000002	47.384587000000003	47.376502000000002	Олега Кошевого	0103000020E61000000100000005000000126BF129006C47407670B03731B04740126BF129006C4740BFBB95253AB147406DC9AA08376D4740BFBB95253AB147406DC9AA08376D47407670B03731B04740126BF129006C47407670B03731B04740
57176	2357	47.327021999999999	47.345024000000002	47.018312999999999	47.007831000000003	Набережная	0103000020E6100000010000000500000048895DDBDBA947408F72309B0081474048895DDBDBA94740BB0B941458824740E52A16BF29AC4740BB0B941458824740E52A16BF29AC47408F72309B0081474048895DDBDBA947408F72309B00814740
57258	2485	47.206226000000001	47.225054	47.097873999999997	47.092685000000003	1 Мая	0103000020E61000000100000005000000DECA129D659A474036EA211ADD8B4740DECA129D659A474079909E22878C4740C0EAC891CE9C474079909E22878C4740C0EAC891CE9C474036EA211ADD8B4740DECA129D659A474036EA211ADD8B4740
57147	2983	46.800735000000003	46.830514000000001	47.469968000000001	47.454268999999996	Ленина	0103000020E610000001000000050000009CE1067C7E664740164B917C25BA47409CE1067C7E664740511553E927BC4740616F62484E6A4740511553E927BC4740616F62484E6A4740164B917C25BA47409CE1067C7E664740164B917C25BA4740
57177	2813	47.013545999999998	47.034261000000001	47.303452999999998	47.291665000000002	Ленина	0103000020E61000000100000005000000ED7E15E0BB814740A5315A4755A54740ED7E15E0BB814740C16F438CD7A647409E4319AA62844740C16F438CD7A647409E4319AA62844740A5315A4755A54740ED7E15E0BB814740A5315A4755A54740
56897	2128	47.621642999999999	47.647585999999997	46.831632999999997	46.820287999999998	Зверобоева	0103000020E61000000100000005000000C76471FF91CF47408FA67A32FF684740C76471FF91CF47401EA33CF3726A474079AC1919E4D247401EA33CF3726A474079AC1919E4D247408FA67A32FF684740C76471FF91CF47408FA67A32FF684740
56800	2643	47.015127	47.042462999999998	47.266024999999999	47.231409999999997	Чернышевского	0103000020E61000000100000005000000AF2479AEEF814740D2FBC6D79E9D4740AF2479AEEF8147408E75711B0DA247402025766D6F8547408E75711B0DA247402025766D6F854740D2FBC6D79E9D4740AF2479AEEF814740D2FBC6D79E9D4740
56797	2643	47.015127	47.042462999999998	47.266024999999999	47.231409999999997	Мусаева	0103000020E61000000100000005000000AF2479AEEF814740D2FBC6D79E9D4740AF2479AEEF8147408E75711B0DA247402025766D6F8547408E75711B0DA247402025766D6F854740D2FBC6D79E9D4740AF2479AEEF814740D2FBC6D79E9D4740
57184	3293	46.268672000000002	46.283647000000002	47.801828999999998	47.789074999999997	Советская	0103000020E61000000100000005000000EBAC16D863224740AC8BDB6800E54740EBAC16D86322474000FE2955A2E64740E44D7E8B4E24474000FE2955A2E64740E44D7E8B4E244740AC8BDB6800E54740EBAC16D863224740AC8BDB6800E54740
57175	2526	47.104393000000002	47.126787999999998	47.125563999999997	47.118524999999998	Октябрьская	0103000020E610000001000000050000003677F4BF5C8D47401361C3D32B8F47403677F4BF5C8D474008C72C7B129047403BC3D4963A90474008C72C7B129047403BC3D4963A9047401361C3D32B8F47403677F4BF5C8D47401361C3D32B8F4740
56846	2236	47.540543	47.558670999999997	46.976644	46.962623000000001	Ленина	0103000020E61000000100000005000000768A558330C547404FB0FF3A377B4740768A558330C54740D5EAABAB027D47409F1C058882C74740D5EAABAB027D47409F1C058882C747404FB0FF3A377B4740768A558330C547404FB0FF3A377B4740
57181	2587	47.029895000000003	47.047367999999999	47.179881999999999	47.169310000000003	А.Кенжиева	0103000020E610000001000000050000002FA86F99D3834740617138F3AB9547402FA86F99D3834740CD91955F069747403F70952710864740CD91955F069747403F70952710864740617138F3AB9547402FA86F99D3834740617138F3AB954740
57227	3051	46.618476000000001	46.638435999999999	47.639918999999999	47.630186000000002	Кирова	0103000020E6100000010000000500000032AEB8382A4F4740D33252EFA9D0474032AEB8382A4F4740658BA4DDE8D14740664B5645B8514740658BA4DDE8D14740664B5645B8514740D33252EFA9D0474032AEB8382A4F4740D33252EFA9D04740
57209	1546	48.704625	48.710850000000001	46.326073000000001	46.322476000000002	Новоямнинская	0103000020E61000000100000005000000D578E926315A484059DFC0E446294740D578E926315A4840E78D93C2BC294740492EFF21FD5A4840E78D93C2BC294740492EFF21FD5A484059DFC0E446294740D578E926315A484059DFC0E446294740
57279	2089	48.378805999999997	48.391525999999999	46.248849999999997	46.213078000000003	Школьная	0103000020E61000000100000005000000A8C30AB77C304840A1BFD023461B4740A8C30AB77C30484007CE1951DA1F474050C422861D32484007CE1951DA1F474050C422861D324840A1BFD023461B4740A8C30AB77C304840A1BFD023461B4740
57113	273	48.720219	48.729795000000003	46.197266999999997	46.186473999999997	Молодежная	0103000020E610000001000000050000009A7ADD22305C4840F3C64961DE1747409A7ADD22305C48403ECA880B4019474065E42CEC695D48403ECA880B4019474065E42CEC695D4840F3C64961DE1747409A7ADD22305C4840F3C64961DE174740
57228	1371	48.619419000000001	48.632463000000001	46.451706999999999	46.429063999999997	Набережная	0103000020E61000000100000005000000B1C22D1F494F48400AF2B391EB364740B1C22D1F494F4840E82FF488D13947400C772E8CF4504840E82FF488D13947400C772E8CF45048400AF2B391EB364740B1C22D1F494F48400AF2B391EB364740
56795	1832	48.468592000000001	48.525472999999998	46.254669999999997	46.214967999999999	Боевая	0103000020E61000000100000005000000689599D2FA3B4840E0D74812841B4740689599D2FA3B4840DBA2CC06992047402BF702B342434840DBA2CC06992047402BF702B342434840E0D74812841B4740689599D2FA3B4840E0D74812841B4740
57144	1658	48.450806	48.459015999999998	46.350681000000002	46.344870999999998	Молодежная	0103000020E61000000100000005000000986BD102B43948405E2BA1BB242C4740986BD102B43948400F2A711DE32C47409D2B4A09C13A48400F2A711DE32C47409D2B4A09C13A48405E2BA1BB242C4740986BD102B43948405E2BA1BB242C4740
57143	1152	48.536935999999997	48.549880999999999	46.388818000000001	46.381456999999997	Комсомольская	0103000020E61000000100000005000000C405A051BA44484046EA3D95D3304740C405A051BA4448404E0CC9C9C43147408CD82780624648404E0CC9C9C43147408CD827806246484046EA3D95D3304740C405A051BA44484046EA3D95D3304740
56942	1781	48.596539	48.627620999999998	46.024056999999999	46.008046999999998	Советская	0103000020E61000000100000005000000EFE4D3635B4C48405BEA20AF07014740EFE4D3635B4C4840B41EBE4C1403474033A48AE255504840B41EBE4C1403474033A48AE2555048405BEA20AF07014740EFE4D3635B4C48405BEA20AF07014740
57170	436	48.705675999999997	48.715736999999997	46.262590000000003	46.242474000000001	И.Алтынсарина	0103000020E610000001000000050000003AC95697535A4840AE105663091F47403AC95697535A4840DA20938C9C214740C1C41F459D5B4840DA20938C9C214740C1C41F459D5B4840AE105663091F47403AC95697535A4840AE105663091F4740
56872	1895	48.498263999999999	48.512771000000001	46.218060999999999	46.205931	Нариманова	0103000020E610000001000000050000001763601DC73F4840C51D6FF25B1A47401763601DC73F48403BC43F6CE91B47402AABE97AA24148403BC43F6CE91B47402AABE97AA2414840C51D6FF25B1A47401763601DC73F4840C51D6FF25B1A4740
57255	2015	48.450302000000001	48.465860999999997	46.246195	46.236134999999997	Заречная	0103000020E6100000010000000500000065A9F57EA33948407138F3AB391E474065A9F57EA339484028B85851831F4740ADBD4F55A13B484028B85851831F4740ADBD4F55A13B48407138F3AB391E474065A9F57EA33948407138F3AB391E4740
57246	1426	48.677782999999998	48.704318999999998	46.474817000000002	46.462217000000003	Заводская	0103000020E610000001000000050000007364E597C1564840DF5339ED293B47407364E597C1564840DC4AAFCDC63C4740C879FF1F275A4840DC4AAFCDC63C4740C879FF1F275A4840DF5339ED293B47407364E597C1564840DF5339ED293B4740
57230	1489	48.589595000000003	48.611038000000001	46.396163999999999	46.383907000000001	Д.Нурпеисовой	0103000020E610000001000000050000004C7155D9774B48404DDA54DD233147404C7155D9774B484020ED7F80B53247407F4E417E364E484020ED7F80B53247407F4E417E364E48404DDA54DD233147404C7155D9774B48404DDA54DD23314740
57145	779	48.359724999999997	48.377170999999997	46.379013999999998	46.364823999999999	Центральная	0103000020E61000000100000005000000DC4603780B2E4840E065868DB22E4740DC4603780B2E4840F25CDF8783304740F3FFAA2347304840F25CDF8783304740F3FFAA2347304840E065868DB22E4740DC4603780B2E4840E065868DB22E4740
57206	1263	48.832535999999998	48.839821000000001	46.447006000000002	46.441789999999997	Советская	0103000020E610000001000000050000000F5F268A906A484094D920938C3847400F5F268A906A4840D28E1B7E373947403CBF28417F6B4840D28E1B7E373947403CBF28417F6B484094D920938C3847400F5F268A906A484094D920938C384740
57226	944	48.803052999999998	48.825304000000003	46.282660999999997	46.270957000000003	Жукова	0103000020E6100000010000000500000033FAD170CA664840A7CF0EB8AE22474033FAD170CA664840656D533C2E24474006A1BC8FA3694840656D533C2E24474006A1BC8FA3694840A7CF0EB8AE22474033FAD170CA664840A7CF0EB8AE224740
57172	21449	48.536378999999997	48.567253999999998	46.284866000000001	46.279833000000004	Центральная	0103000020E610000001000000050000006EA12B11A8444840B9AB5791D12347406EA12B11A844484005DF347D76244740394371C79B48484005DF347D76244740394371C79B484840B9AB5791D12347406EA12B11A8444840B9AB5791D1234740
57229	1713	48.459851999999998	48.464019999999998	46.281987999999998	46.278924000000004	Школьная	0103000020E6100000010000000500000006802A6EDC3A4840E60819C8B323474006802A6EDC3A4840A6EECA2E182447404F58E201653B4840A6EECA2E182447404F58E201653B4840E60819C8B323474006802A6EDC3A4840E60819C8B3234740
57140	848	48.766626000000002	48.787987999999999	46.332047000000003	46.314577999999997	Центральная	0103000020E61000000100000005000000B421FFCC206248404205871744284740B421FFCC2062484012DE1E84802A4740FAD170CADC64484012DE1E84802A4740FAD170CADC6448404205871744284740B421FFCC206248404205871744284740
56842	32438	48.706763000000002	48.731726999999999	46.419572000000002	46.390782000000002	Проходная	0103000020E61000000100000005000000ED82C135775A4840C8EE022505324740ED82C135775A48409E280989B4354740D34CF73AA95D48409E280989B4354740D34CF73AA95D4840C8EE022505324740ED82C135775A4840C8EE022505324740
56940	32438	48.706763000000002	48.731726999999999	46.419572000000002	46.390782000000002	Победы	0103000020E61000000100000005000000ED82C135775A4840C8EE022505324740ED82C135775A48409E280989B4354740D34CF73AA95D48409E280989B4354740D34CF73AA95D4840C8EE022505324740ED82C135775A4840C8EE022505324740
57153	729	48.640394999999998	48.656699000000003	46.176709000000002	46.158884	Мыльникова	0103000020E61000000100000005000000CEC29E76F8514840C8ED974F56144740CEC29E76F851484056F487669E16474070287CB60E54484056F487669E16474070287CB60E544840C8ED974F56144740CEC29E76F8514840C8ED974F56144740
57280	1080	48.728996000000002	48.755487000000002	46.383949999999999	46.377982000000003	Бакушина	0103000020E610000001000000050000001975ADBD4F5D4840043DD4B6613047401975ADBD4F5D48404CA60A4625314740CEC64ACCB36048404CA60A4625314740CEC64ACCB3604840043DD4B6613047401975ADBD4F5D4840043DD4B661304740
57110	26437	48.633110000000002	48.643853	46.270234000000002	46.261418999999997	Школьная	0103000020E61000000100000005000000A2629CBF09514840C9C6832D76214740A2629CBF0951484036221807972247403B376DC66952484036221807972247403B376DC669524840C9C6832D76214740A2629CBF09514840C9C6832D76214740
57250	1199	48.427135	48.443447999999997	46.434294000000001	46.429803	Набережная	0103000020E610000001000000050000000DFD135CAC364840815CE2C8033747400DFD135CAC364840AD6C1FF29637474001BD70E7C2384840AD6C1FF29637474001BD70E7C2384840815CE2C8033747400DFD135CAC364840815CE2C803374740
57283	656	48.579479999999997	48.591957999999998	46.313811999999999	46.308228	Юрия Суюнчалиева	0103000020E61000000100000005000000D15790662C4A484012DBDD0374274740D15790662C4A4840D28BDAFD2A284740834D9D47C54B4840D28BDAFD2A284740834D9D47C54B484012DBDD0374274740D15790662C4A484012DBDD0374274740
56877	1314	48.553600000000003	48.577800000000003	46.421902000000003	46.415514999999999	30 лет Победы	0103000020E610000001000000050000006688635DDC464840ACFF73982F3547406688635DDC464840FA0E7EE2003647407DD0B359F5494840FA0E7EE2003647407DD0B359F5494840ACFF73982F3547406688635DDC464840ACFF73982F354740
57205	562	48.548299999999998	48.566473000000002	46.278033000000001	46.272826000000002	Гагарина	0103000020E61000000100000005000000CA32C4B12E464840CFBF5DF6EB224740CA32C4B12E464840B91AD995962347409488F02F82484840B91AD995962347409488F02F82484840CFBF5DF6EB224740CA32C4B12E464840CFBF5DF6EB224740
57180	1045	48.865197999999999	48.888779	46.347278000000003	46.337175000000002	Ленина	0103000020E610000001000000050000004548DDCEBE6E4840B003E78C282B47404548DDCEBE6E4840664F029B732C4740902FA182C3714840664F029B732C4740902FA182C3714840B003E78C282B47404548DDCEBE6E4840B003E78C282B4740
57251	599	48.658405999999999	48.662565000000001	46.230286999999997	46.222549999999998	Школьная	0103000020E61000000100000005000000BEBED6A546544840C6DCB5847C1C4740BEBED6A546544840D3D85E0B7A1D4740B43C0FEECE544840D3D85E0B7A1D4740B43C0FEECE544840C6DCB5847C1C4740BEBED6A546544840C6DCB5847C1C4740
64919	57121	48.625779000000001	48.640205999999999	46.367001000000002	46.362690999999998	Пионерская	0103000020E6100000010000000500000005C3B98619504840DAC69FA86C2E474005C3B98619504840B64C86E3F92E4740FB592C45F2514840B64C86E3F92E4740FB592C45F2514840DAC69FA86C2E474005C3B98619504840DAC69FA86C2E4740
57039	57121	48.625779000000001	48.640205999999999	46.367001000000002	46.362690999999998	Ленина	0103000020E6100000010000000500000005C3B98619504840DAC69FA86C2E474005C3B98619504840B64C86E3F92E4740FB592C45F2514840B64C86E3F92E4740FB592C45F2514840DAC69FA86C2E474005C3B98619504840DAC69FA86C2E4740
56792	218	48.597959000000003	48.639631000000001	46.182499999999997	46.171267	Советская	0103000020E61000000100000005000000A8ACA6EB894C484028F1B913EC154740A8ACA6EB894C48408FC2F5285C174740FF40B96DDF5148408FC2F5285C174740FF40B96DDF51484028F1B913EC154740A8ACA6EB894C484028F1B913EC154740
56791	20953	48.524360000000001	48.550465000000003	46.420366999999999	46.379112999999997	Чехова	0103000020E6100000010000000500000050AA7D3A1E434840853E58C68630474050AA7D3A1E434840A8A8FA95CE354740DC4B1AA375464840A8A8FA95CE354740DC4B1AA375464840853E58C68630474050AA7D3A1E434840853E58C686304740
56788	20953	48.524360000000001	48.550465000000003	46.420366999999999	46.379112999999997	Суворова	0103000020E6100000010000000500000050AA7D3A1E434840853E58C68630474050AA7D3A1E434840A8A8FA95CE354740DC4B1AA375464840A8A8FA95CE354740DC4B1AA375464840853E58C68630474050AA7D3A1E434840853E58C686304740
56873	20953	48.524360000000001	48.550465000000003	46.420366999999999	46.379112999999997	Победы	0103000020E6100000010000000500000050AA7D3A1E434840853E58C68630474050AA7D3A1E434840A8A8FA95CE354740DC4B1AA375464840A8A8FA95CE354740DC4B1AA375464840853E58C68630474050AA7D3A1E434840853E58C686304740
56790	20953	48.524360000000001	48.550465000000003	46.420366999999999	46.379112999999997	Маяковского	0103000020E6100000010000000500000050AA7D3A1E434840853E58C68630474050AA7D3A1E434840A8A8FA95CE354740DC4B1AA375464840A8A8FA95CE354740DC4B1AA375464840853E58C68630474050AA7D3A1E434840853E58C686304740
56939	20953	48.524360000000001	48.550465000000003	46.420366999999999	46.379112999999997	Алешина	0103000020E6100000010000000500000050AA7D3A1E434840853E58C68630474050AA7D3A1E434840A8A8FA95CE354740DC4B1AA375464840A8A8FA95CE354740DC4B1AA375464840853E58C68630474050AA7D3A1E434840853E58C686304740
57118	1598	48.270207999999997	48.290753000000002	46.477603999999999	46.466977999999997	Лати Каримова	0103000020E610000001000000050000000C8FFD2C96224840CAF962EFC53B47400C8FFD2C962248402A38BC20223D4740611BF164372548402A38BC20223D4740611BF16437254840CAF962EFC53B47400C8FFD2C96224840CAF962EFC53B4740
57089	73	48.646206999999997	48.660426999999999	46.324362000000001	46.300066000000001	Советская	0103000020E610000001000000050000001FB935E9B65248401E520C90682647401FB935E9B65248405708ABB1842947409C3237DF885448405708ABB1842947409C3237DF885448401E520C90682647401FB935E9B65248401E520C9068264740
57252	136	48.563687999999999	48.581752999999999	46.356800999999997	46.345294000000003	Молодежный	0103000020E61000000100000005000000E692AAED26484840A5C00298322C4740E692AAED264848400D17B9A7AB2D4740C9ACDEE1764A48400D17B9A7AB2D4740C9ACDEE1764A4840A5C00298322C4740E692AAED26484840A5C00298322C4740
57277	927	48.872214	48.886704000000002	46.266495999999997	46.258913999999997	Абая	0103000020E61000000100000005000000828E56B5A46F4840FF3C0D1824214740828E56B5A46F4840E5417A8A1C224740BF9D44847F714840E5417A8A1C224740BF9D44847F714840FF3C0D1824214740828E56B5A46F4840FF3C0D1824214740
57276	1942	48.338192999999997	48.351559999999999	46.290508000000003	46.273747999999998	Набережная	0103000020E61000000100000005000000395E81E8492B484036ACA92C0A234740395E81E8492B4840FA9CBB5D2F254740774A07EBFF2C4840FA9CBB5D2F254740774A07EBFF2C484036ACA92C0A234740395E81E8492B484036ACA92C0A234740
56794	457	48.499512000000003	48.510184000000002	46.281489999999998	46.269848000000003	Центральная	0103000020E61000000100000005000000D3FA5B02F03F48400D7217618A224740D3FA5B02F03F4840551344DD07244740A37895B54D414840551344DD07244740A37895B54D4148400D7217618A224740D3FA5B02F03F48400D7217618A224740
57265	346	48.688310999999999	48.696091000000003	46.183292000000002	46.179335999999999	Г.Жукова	0103000020E61000000100000005000000103D29931A5848406B7F677BF4164740103D29931A58484029CFBC1C761747401D0588821959484029CFBC1C761747401D058882195948406B7F677BF4164740103D29931A5848406B7F677BF4164740
57134	30330	46.225858000000002	46.246349000000002	48.212994999999999	48.195754999999998	Школьная	0103000020E610000001000000050000001EC539EAE81C4740A583F57F0E1948401EC539EAE81C4740139B8F6B431B48407F33315D881F4740139B8F6B431B48407F33315D881F4740A583F57F0E1948401EC539EAE81C4740A583F57F0E194840
57091	30734	46.787593000000001	46.809646000000001	47.754883999999997	47.737786	пер.Коммунальный	0103000020E610000001000000050000007EC7F0D8CF6447402CB98AC56FDE47407EC7F0D8CF6447400723F609A0E047402AABE97AA26747400723F609A0E047402AABE97AA26747402CB98AC56FDE47407EC7F0D8CF6447402CB98AC56FDE4740
57275	31214	46.781672999999998	46.799467999999997	48.212743000000003	48.203214000000003	Космонавтов	0103000020E61000000100000005000000469561DC0D644740700B96EA021A4840469561DC0D644740FAB9A1293B1B48406919A9F754664740FAB9A1293B1B48406919A9F754664740700B96EA021A4840469561DC0D644740700B96EA021A4840
64916	11162	45.871777999999999	45.882576	48.521152999999998	48.509455000000003	Ленина	0103000020E61000000100000005000000A7AFE76B96EF464050E449D235414840A7AFE76B96EF46402C9B3924B5424840041E1840F8F046402C9B3924B5424840041E1840F8F0464050E449D235414840A7AFE76B96EF464050E449D235414840
56925	11162	45.871777999999999	45.882576	48.521152999999998	48.509455000000003	Геологическая	0103000020E61000000100000005000000A7AFE76B96EF464050E449D235414840A7AFE76B96EF46402C9B3924B5424840041E1840F8F046402C9B3924B5424840041E1840F8F0464050E449D235414840A7AFE76B96EF464050E449D235414840
57309	57148	45.203772999999998	47.210375999999997	48.863928999999999	47.663894999999997	Набережная	0103000020E610000001000000050000006667D13B159A46402C7DE882FAD447406667D13B159A46407288B839956E484080EECB99ED9A47407288B839956E484080EECB99ED9A47402C7DE882FAD447406667D13B159A46402C7DE882FAD44740
57248	30196	45.901359999999997	45.970359000000002	48.494011999999998	48.4602	Братская	0103000020E6100000010000000500000016F6B4C35FF3464042CF66D5E73A484016F6B4C35FF3464070EA03C93B3F48408C3045B934FC464070EA03C93B3F48408C3045B934FC464042CF66D5E73A484016F6B4C35FF3464042CF66D5E73A4840
57141	30196	45.901359999999997	45.970359000000002	48.494011999999998	48.4602	60 лет СССР	0103000020E6100000010000000500000016F6B4C35FF3464042CF66D5E73A484016F6B4C35FF3464070EA03C93B3F48408C3045B934FC464070EA03C93B3F48408C3045B934FC464042CF66D5E73A484016F6B4C35FF3464042CF66D5E73A4840
57199	57139	46.068330000000003	46.090662000000002	48.370247999999997	48.358604999999997	Почтовая	0103000020E61000000100000005000000F8AA9509BF0847404E97C5C4E62D4840F8AA9509BF08474067B45549642F4840B77EFACF9A0B474067B45549642F4840B77EFACF9A0B47404E97C5C4E62D4840F8AA9509BF0847404E97C5C4E62D4840
57112	30618	46.632184000000002	46.643126000000002	47.884244000000002	47.867038000000001	Ленина	0103000020E61000000100000005000000F986C267EB504740D331E719FBEE4740F986C267EB50474095D74AE82EF14740899AE8F35152474095D74AE82EF14740899AE8F351524740D331E719FBEE4740F986C267EB504740D331E719FBEE4740
57111	30423	46.354343999999998	46.382829999999998	48.068624	48.040227999999999	Молодежная	0103000020E6100000010000000500000054C4E9245B2D47401631EC302605484054C4E9245B2D474040DCD5ABC8084840BEF6CC920031474040DCD5ABC8084840BEF6CC92003147401631EC302605484054C4E9245B2D47401631EC3026054840
56885	31131	46.818773	46.839911000000001	48.232852999999999	48.20758	М.Горького	0103000020E6100000010000000500000085ECBC8DCD684740DFA63FFB911A484085ECBC8DCD68474043E38920CE1D48407C462234826B474043E38920CE1D48407C462234826B4740DFA63FFB911A484085ECBC8DCD684740DFA63FFB911A4840
57166	29009	45.695357999999999	45.707619999999999	48.404328999999997	48.399825	Советская	0103000020E610000001000000050000008881AE7D01D94640C58F31772D3348408881AE7D01D9464085E97B0DC13348406DFFCA4A93DA464085E97B0DC13348406DFFCA4A93DA4640C58F31772D3348408881AE7D01D94640C58F31772D334840
57131	29009	45.695357999999999	45.707619999999999	48.404328999999997	48.399825	Октябрьская	0103000020E610000001000000050000008881AE7D01D94640C58F31772D3348408881AE7D01D9464085E97B0DC13348406DFFCA4A93DA464085E97B0DC13348406DFFCA4A93DA4640C58F31772D3348408881AE7D01D94640C58F31772D334840
57136	29009	45.695357999999999	45.707619999999999	48.404328999999997	48.399825	Московская	0103000020E610000001000000050000008881AE7D01D94640C58F31772D3348408881AE7D01D9464085E97B0DC13348406DFFCA4A93DA464085E97B0DC13348406DFFCA4A93DA4640C58F31772D3348408881AE7D01D94640C58F31772D334840
57171	29009	45.695357999999999	45.707619999999999	48.404328999999997	48.399825	Лесная	0103000020E610000001000000050000008881AE7D01D94640C58F31772D3348408881AE7D01D9464085E97B0DC13348406DFFCA4A93DA464085E97B0DC13348406DFFCA4A93DA4640C58F31772D3348408881AE7D01D94640C58F31772D334840
57132	29009	45.695357999999999	45.707619999999999	48.404328999999997	48.399825	Кирова	0103000020E610000001000000050000008881AE7D01D94640C58F31772D3348408881AE7D01D9464085E97B0DC13348406DFFCA4A93DA464085E97B0DC13348406DFFCA4A93DA4640C58F31772D3348408881AE7D01D94640C58F31772D334840
56883	30696	46.711576999999998	46.734493000000001	47.814760999999997	47.800885000000001	Ленина	0103000020E61000000100000005000000FBCA83F4145B4740B16D516683E64740FBCA83F4145B47403387A4164AE847400A12DBDD035E47403387A4164AE847400A12DBDD035E4740B16D516683E64740FBCA83F4145B4740B16D516683E64740
57026	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	улица Волгоградская	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
56891	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	проспект 9 Мая	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
56996	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	Янгеля	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
57034	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	Пионерская	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
56980	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	Ленина	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
57013	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	Волгоградская	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
57057	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	Ватутина	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
56988	57108	45.707439999999998	45.761169000000002	48.597943999999998	48.572918999999999	Академика Янгеля	0103000020E61000000100000005000000EDF0D7648DDA4640E620E86855494840EDF0D7648DDA4640726BD26D894C484051DD5CFC6DE14640726BD26D894C484051DD5CFC6DE14640E620E86855494840EDF0D7648DDA4640E620E86855494840
56884	30808	46.708173000000002	46.734986999999997	48.238625999999996	48.214683000000001	Степная	0103000020E610000001000000050000008274B169A55A4740EB0088BB7A1B48408274B169A55A4740D6FCF84B8B1E484019FED30D145E4740D6FCF84B8B1E484019FED30D145E4740EB0088BB7A1B48408274B169A55A4740EB0088BB7A1B4840
57167	30808	46.708173000000002	46.734986999999997	48.238625999999996	48.214683000000001	Советская	0103000020E610000001000000050000008274B169A55A4740EB0088BB7A1B48408274B169A55A4740D6FCF84B8B1E484019FED30D145E4740D6FCF84B8B1E484019FED30D145E4740EB0088BB7A1B48408274B169A55A4740EB0088BB7A1B4840
56785	30808	46.708173000000002	46.734986999999997	48.238625999999996	48.214683000000001	Рабочая	0103000020E610000001000000050000008274B169A55A4740EB0088BB7A1B48408274B169A55A4740D6FCF84B8B1E484019FED30D145E4740D6FCF84B8B1E484019FED30D145E4740EB0088BB7A1B48408274B169A55A4740EB0088BB7A1B4840
57137	30808	46.708173000000002	46.734986999999997	48.238625999999996	48.214683000000001	Джамбула	0103000020E610000001000000050000008274B169A55A4740EB0088BB7A1B48408274B169A55A4740D6FCF84B8B1E484019FED30D145E4740D6FCF84B8B1E484019FED30D145E4740EB0088BB7A1B48408274B169A55A4740EB0088BB7A1B4840
57114	30808	46.708173000000002	46.734986999999997	48.238625999999996	48.214683000000001	Абаева	0103000020E610000001000000050000008274B169A55A4740EB0088BB7A1B48408274B169A55A4740D6FCF84B8B1E484019FED30D145E4740D6FCF84B8B1E484019FED30D145E4740EB0088BB7A1B48408274B169A55A4740EB0088BB7A1B4840
57281	11592	46.871530999999997	46.884943	47.730350999999999	47.720556000000002	Школьная	0103000020E610000001000000050000009F39EB538E6F4740E277D32D3BDC47409F39EB538E6F4740EACC3D247CDD47407DE9EDCF45714740EACC3D247CDD47407DE9EDCF45714740E277D32D3BDC47409F39EB538E6F4740E277D32D3BDC4740
56933	30487	46.409339000000003	46.431572000000003	47.998589000000003	47.982042	Школьная	0103000020E610000001000000050000001AFD68386534474033A6608DB3FD47401AFD6838653447409B92ACC3D1FF474046EF54C03D3747409B92ACC3D1FF474046EF54C03D37474033A6608DB3FD47401AFD68386534474033A6608DB3FD4740
57287	30400	46.283960999999998	46.300373	48.152151000000003	48.129140999999997	Школьная	0103000020E61000000100000005000000732B84D5582447404FC939B187104840732B84D558244740E08618AF79134840FBCC599F72264740E08618AF79134840FBCC599F722647404FC939B187104840732B84D5582447404FC939B187104840
23168	50639	38.698200999999997	38.707867	57.484355000000001	57.482008999999998	Школьная	0103000020E610000001000000050000006A847EA65E59434057B08D78B2BD4C406A847EA65E594340B9533A58FFBD4C407575C7629B5A4340B9533A58FFBD4C407575C7629B5A434057B08D78B2BD4C406A847EA65E59434057B08D78B2BD4C40
2071	2085	39.815686999999997	39.815930000000002	57.642848999999998	57.638021999999999	улица Юности	0103000020E61000000100000005000000DC627E6E68E84340731074B4AAD14C40DC627E6E68E8434016A243E048D24C40A3E9EC6470E8434016A243E048D24C40A3E9EC6470E84340731074B4AAD14C40DC627E6E68E84340731074B4AAD14C40
2431	2085	39.934551999999996	39.946382999999997	57.553846	57.550871999999998	улица Щепкина	0103000020E61000000100000005000000A83462669FF743401C2444F982C64C40A83462669FF743409D82FC6CE4C64C40C43E011423F943409D82FC6CE4C64C40C43E011423F943401C2444F982C64C40A83462669FF743401C2444F982C64C40
2027	2085	39.809407999999998	39.857548000000001	57.638046000000003	57.636861000000003	улица Чкалова	0103000020E61000000100000005000000758F6CAE9AE74340878C47A984D14C40758F6CAE9AE74340FCABC77DABD14C4007600322C4ED4340FCABC77DABD14C4007600322C4ED4340878C47A984D14C40758F6CAE9AE74340878C47A984D14C40
7220	2085	39.786203999999998	39.809156000000002	57.689202000000002	57.675012000000002	улица Урицкого	0103000020E6100000010000000500000000FE2955A2E443402B3410CB66D64C4000FE2955A2E443403D2B69C537D84C405CAE7E6C92E743403D2B69C537D84C405CAE7E6C92E743402B3410CB66D64C4000FE2955A2E443402B3410CB66D64C40
1994	2085	39.843957000000003	39.852868000000001	57.635888000000001	57.629899000000002	улица Тургенева	0103000020E610000001000000050000007A1D71C806EC43403D64CA87A0D04C407A1D71C806EC43409DF529C764D14C4008E753C72AED43409DF529C764D14C4008E753C72AED43403D64CA87A0D04C407A1D71C806EC43403D64CA87A0D04C40
725	2085	39.759155999999997	39.767671999999997	57.691915999999999	57.686931999999999	улица Туманова	0103000020E61000000100000005000000F54718062CE14340B6494563EDD74C40F54718062CE1434021CA17B490D84C4007077B1343E2434021CA17B490D84C4007077B1343E24340B6494563EDD74C40F54718062CE14340B6494563EDD74C40
646	2085	39.757350000000002	39.786203999999998	57.690939	57.678314	улица Труфанова	0103000020E6100000010000000500000014D044D8F0E04340A0353FFED2D64C4014D044D8F0E04340F6436CB070D84C4000FE2955A2E44340F6436CB070D84C4000FE2955A2E44340A0353FFED2D64C4014D044D8F0E04340A0353FFED2D64C40
1856	2085	39.827202999999997	39.841621000000004	57.613987999999999	57.604128000000003	улица Стачек	0103000020E610000001000000050000009813B4C9E1E94340884CF91054CD4C409813B4C9E1E943407711A62897CE4C403C50A73CBAEB43407711A62897CE4C403C50A73CBAEB4340884CF91054CD4C409813B4C9E1E94340884CF91054CD4C40
1457	2085	39.881228	39.883096999999999	57.631383	57.622124999999997	улица Собинова	0103000020E61000000100000005000000E5284014CCF043401283C0CAA1CF4C40E5284014CCF043400C207C28D1D04C400D198F5209F143400C207C28D1D04C400D198F5209F143401283C0CAA1CF4C40E5284014CCF043401283C0CAA1CF4C40
2623	2085	39.852141000000003	39.884121	57.581491	57.577644999999997	улица Слепнева	0103000020E61000000100000005000000564ACFF412ED434055D97745F0C94C40564ACFF412ED43408CF50D4C6ECA4C40795A7EE02AF143408CF50D4C6ECA4C40795A7EE02AF1434055D97745F0C94C40564ACFF412ED434055D97745F0C94C40
1987	2085	39.844676	39.885190000000001	57.637487	57.628824000000002	улица Свердлова	0103000020E61000000100000005000000A9DBD9571EEC43404F78094E7DD04C40A9DBD9571EEC434005508C2C99D14C40855FEAE74DF1434005508C2C99D14C40855FEAE74DF143404F78094E7DD04C40A9DBD9571EEC43404F78094E7DD04C40
1090	2085	39.943302000000003	39.953263999999997	57.646600999999997	57.642955000000001	улица Саукова	0103000020E610000001000000050000002E20B41EBEF843405CE674594CD24C402E20B41EBEF84340CB4752D2C3D24C40213A048E04FA4340CB4752D2C3D24C40213A048E04FA43405CE674594CD24C402E20B41EBEF843405CE674594CD24C40
1534	2085	39.843921000000002	39.877068999999999	57.623508000000001	57.622751999999998	улица Салтыкова-Щедрина	0103000020E610000001000000050000002DB4739A05EC434061C26856B6CF4C402DB4739A05EC4340AE65321CCFCF4C40EFAA07CC43F04340AE65321CCFCF4C40EFAA07CC43F0434061C26856B6CF4C402DB4739A05EC434061C26856B6CF4C40
1727	2085	39.832808999999997	39.843409000000001	57.582720999999999	57.578485000000001	улица Рыкачева	0103000020E6100000010000000500000040683D7C99EA4340001DE6CB0BCA4C4040683D7C99EA4340A1D80A9A96CA4C4077137CD3F4EB4340A1D80A9A96CA4C4077137CD3F4EB4340001DE6CB0BCA4C4040683D7C99EA4340001DE6CB0BCA4C40
1516	2085	39.867725999999998	39.888503999999998	57.639009999999999	57.621324999999999	улица Победы	0103000020E61000000100000005000000C7F143A511EF4340F697DD9387CF4C40C7F143A511EF434092E86514CBD14C40BE2EC37FBAF1434092E86514CBD14C40BE2EC37FBAF14340F697DD9387CF4C40C7F143A511EF4340F697DD9387CF4C40
1642	2085	39.828119999999998	39.835718999999997	57.630896	57.626939999999998	улица Павлика Морозова	0103000020E61000000100000005000000EE940ED6FFE94340F146E6913FD04C40EE940ED6FFE94340AF963B33C1D04C40AAD216D7F8EA4340AF963B33C1D04C40AAD216D7F8EA4340F146E6913FD04C40EE940ED6FFE94340F146E6913FD04C40
1868	2085	39.814833999999998	39.835844999999999	57.606231000000001	57.598004000000003	улица Маланова	0103000020E610000001000000050000009DD5027B4CE84340487023658BCC4C409DD5027B4CE84340236937FA98CD4C4037C30DF8FCEA4340236937FA98CD4C4037C30DF8FCEA4340487023658BCC4C409DD5027B4CE84340487023658BCC4C40
1714	2085	39.843409000000001	39.849023000000003	57.582514000000003	57.578485000000001	улица Курчатова	0103000020E6100000010000000500000077137CD3F4EB4340001DE6CB0BCA4C4077137CD3F4EB434028BB99D18FCA4C40A24621C9ACEC434028BB99D18FCA4C40A24621C9ACEC4340001DE6CB0BCA4C4077137CD3F4EB4340001DE6CB0BCA4C40
2041	2085	39.834533999999998	39.851044999999999	57.637661000000001	57.631421000000003	улица Кудрявцева	0103000020E6100000010000000500000035B39602D2EA4340FA804067D2D04C4035B39602D2EA4340A3772AE09ED14C405036E50AEFEC4340A3772AE09ED14C405036E50AEFEC4340FA804067D2D04C4035B39602D2EA4340FA804067D2D04C40
2518	2085	39.855589999999999	39.877688999999997	57.584978999999997	57.582726000000001	улица Кривова	0103000020E610000001000000050000006F641EF983ED4340B343FCC396CA4C406F641EF983ED434063EC8497E0CA4C408B87F71C58F0434063EC8497E0CA4C408B87F71C58F04340B343FCC396CA4C406F641EF983ED4340B343FCC396CA4C40
1273	2085	39.81964	39.824778000000002	57.729711000000002	57.726346999999997	улица Комарова	0103000020E61000000100000005000000293FA9F6E9E843401B4641F0F8DC4C40293FA9F6E9E843400744882B67DD4C40EB3A545392E943400744882B67DD4C40EB3A545392E943401B4641F0F8DC4C40293FA9F6E9E843401B4641F0F8DC4C40
2746	2085	39.844047000000003	39.861088000000002	57.575550999999997	57.569840999999997	улица Калинина	0103000020E61000000100000005000000BAA46ABB09EC4340C075C58CF0C84C40BAA46ABB09EC43400D17B9A7ABC94C40317DAF2138EE43400D17B9A7ABC94C40317DAF2138EE4340C075C58CF0C84C40BAA46ABB09EC4340C075C58CF0C84C40
2101	2085	39.826278000000002	39.830311999999999	57.642626999999997	57.632939	улица Жукова	0103000020E61000000100000005000000C0B33D7AC3E9434075AE282504D14C40C0B33D7AC3E943406743FE9941D24C40F9BCE2A947EA43406743FE9941D24C40F9BCE2A947EA434075AE282504D14C40C0B33D7AC3E9434075AE282504D14C40
632	2085	39.779341000000002	39.815696000000003	57.685603999999998	57.671267999999998	улица Елены Колесовой	0103000020E610000001000000050000004AB72572C1E34340F86C1D1CECD54C404AB72572C1E34340DE0033DFC1D74C4030BDFDB968E84340DE0033DFC1D74C4030BDFDB968E84340F86C1D1CECD54C404AB72572C1E34340F86C1D1CECD54C40
687	2085	39.753874000000003	39.779341000000002	57.686464999999998	57.671267999999998	улица Громова	0103000020E6100000010000000500000001A777F17EE04340F86C1D1CECD54C4001A777F17EE04340A06CCA15DED74C404AB72572C1E34340A06CCA15DED74C404AB72572C1E34340F86C1D1CECD54C4001A777F17EE04340F86C1D1CECD54C40
2571	2085	39.863567000000003	39.887937999999998	57.592770000000002	57.590801999999996	улица Гоголя	0103000020E61000000100000005000000D2730B5D89EE4340A83462669FCB4C40D2730B5D89EE434064062AE3DFCB4C401570CFF3A7F1434064062AE3DFCB4C401570CFF3A7F14340A83462669FCB4C40D2730B5D89EE4340A83462669FCB4C40
1902	2085	39.813118000000003	39.822712000000003	57.612875000000003	57.607619	улица Бахвалова	0103000020E61000000100000005000000FCE4284014E84340D0B69A75C6CD4C40FCE4284014E843409CC420B072CE4C406D0377A04EE943409CC420B072CE4C406D0377A04EE94340D0B69A75C6CD4C40FCE4284014E84340D0B69A75C6CD4C40
556	2085	39.773519999999998	39.779988000000003	57.715124000000003	57.713729000000001	улица 1905-го года	0103000020E61000000100000005000000A5660FB402E34340789ACC785BDB4C40A5660FB402E34340D84AE82E89DB4C40E0A293A5D6E34340D84AE82E89DB4C40E0A293A5D6E34340789ACC785BDB4C40A5660FB402E34340789ACC785BDB4C40
2394	2085	39.873520999999997	39.972721	57.599218999999998	57.541317999999997	проспект Фрунзе	0103000020E6100000010000000500000042AF3F89CFEF4340395E81E849C54C4042AF3F89CFEF434027124C35B3CC4C40F390291F82FC434027124C35B3CC4C40F390291F82FC4340395E81E849C54C4042AF3F89CFEF4340395E81E849C54C40
1968	2085	39.843822000000003	39.882458999999997	57.643090000000001	57.627175999999999	проспект Ленина	0103000020E610000001000000050000009AD2FA5B02EC4340056B9C4D47D04C409AD2FA5B02EC43403C31EBC550D24C40CA87A06AF4F043403C31EBC550D24C40CA87A06AF4F04340056B9C4D47D04C409AD2FA5B02EC4340056B9C4D47D04C40
753	2085	39.773564999999998	39.799823000000004	57.695546999999998	57.674607999999999	проспект Дзержинского	0103000020E61000000100000005000000452A8C2D04E343405BCF108E59D64C40452A8C2D04E343405BEA20AF07D94C4058CB9D9960E643405BEA20AF07D94C4058CB9D9960E643405BCF108E59D64C40452A8C2D04E343405BCF108E59D64C40
963	2085	39.903191999999997	39.954898999999997	57.658856999999998	57.636268000000001	проспект Авиаторов	0103000020E610000001000000050000002101A3CB9BF34340E4BED53A71D14C402101A3CB9BF34340CEDE196D55D44C40D6FD63213AFA4340CEDE196D55D44C40D6FD63213AFA4340E4BED53A71D14C402101A3CB9BF34340E4BED53A71D14C40
2704	2085	39.849850000000004	39.86054	57.578609999999998	57.573557000000001	проезд Ушакова	0103000020E61000000100000005000000B84082E2C7EC434029B2D6506AC94C40B84082E2C7EC4340BC9179E40FCA4C402E73BA2C26EE4340BC9179E40FCA4C402E73BA2C26EE434029B2D6506AC94C40B84082E2C7EC434029B2D6506AC94C40
2655	2085	39.846176	39.85727	57.579787000000003	57.574821999999998	проезд Подвойского	0103000020E610000001000000050000007E54C37E4FEC4340BA826DC493C94C407E54C37E4FEC4340AFD2DD7536CA4C40C4EBFA05BBED4340AFD2DD7536CA4C40C4EBFA05BBED4340BA826DC493C94C407E54C37E4FEC4340BA826DC493C94C40
858	2085	39.759236999999999	39.767932999999999	57.704224000000004	57.702185	проезд Моторостроителей	0103000020E61000000100000005000000E27492AD2EE14340F25EB532E1D94C40E27492AD2EE143407787140324DA4C407442E8A04BE243407787140324DA4C407442E8A04BE24340F25EB532E1D94C40E27492AD2EE14340F25EB532E1D94C40
2722	2085	39.853577999999999	39.864339999999999	57.576390000000004	57.572277999999997	проезд Матросова	0103000020E61000000100000005000000E44A3D0B42ED4340321CCF6740C94C40E44A3D0B42ED4340E8DEC325C7C94C40F44F70B1A2EE4340E8DEC325C7C94C40F44F70B1A2EE4340321CCF6740C94C40E44A3D0B42ED4340321CCF6740C94C40
1145	2085	39.945259999999998	39.957504	57.656362999999999	57.652641000000003	проезд  Доброхотова	0103000020E61000000100000005000000C51B9947FEF84340AE8383BD89D34C40C51B9947FEF84340F8A6E9B303D44C4004E5B67D8FFA4340F8A6E9B303D44C4004E5B67D8FFA4340AE8383BD89D34C40C51B9947FEF84340AE8383BD89D34C40
22947	2085	39.919010999999998	39.924939999999999	57.578325	57.561408	Ярославская	0103000020E6100000010000000500000006D50627A2F543403CDBA337DCC74C4006D50627A2F54340C7BAB88D06CA4C409161156F64F64340C7BAB88D06CA4C409161156F64F643403CDBA337DCC74C4006D50627A2F543403CDBA337DCC74C40
1180	2085	39.954351000000003	39.959417000000002	57.652043999999997	57.645797000000002	Школьный проезд	0103000020E61000000100000005000000D4F36E2C28FA43406E6DE179A9D24C40D4F36E2C28FA4340C9C6832D76D34C40FC1C1F2DCEFA4340C9C6832D76D34C40FC1C1F2DCEFA43406E6DE179A9D24C40D4F36E2C28FA43406E6DE179A9D24C40
24133	2085	39.870646000000001	39.876099000000004	57.633834999999998	57.619107999999997	Чайковского	0103000020E610000001000000050000005532005471EF4340925852EE3ECF4C405532005471EF4340B3075A8121D14C407787140324F04340B3075A8121D14C407787140324F04340925852EE3ECF4C405532005471EF4340925852EE3ECF4C40
5966	2085	39.824176000000001	39.938226	57.678823999999999	57.648710999999999	Центральная улица	0103000020E61000000100000005000000F51263997EE9434019C748F608D34C40F51263997EE94340B5DE6FB4E3D64C40E22021CA17F84340B5DE6FB4E3D64C40E22021CA17F8434019C748F608D34C40F51263997EE9434019C748F608D34C40
1547	2085	39.809407999999998	39.862848999999997	57.636861000000003	57.627406999999998	Угличская улица	0103000020E61000000100000005000000758F6CAE9AE74340072461DF4ED04C40758F6CAE9AE74340878C47A984D14C40723106D671EE4340878C47A984D14C40723106D671EE4340072461DF4ED04C40758F6CAE9AE74340072461DF4ED04C40
24090	2085	39.809407999999998	39.862848999999997	57.636861000000003	57.627406999999998	Угличская	0103000020E61000000100000005000000758F6CAE9AE74340072461DF4ED04C40758F6CAE9AE74340878C47A984D14C40723106D671EE4340878C47A984D14C40723106D671EE4340072461DF4ED04C40758F6CAE9AE74340072461DF4ED04C40
568	2085	39.740741	39.842348999999999	57.729922000000002	57.666319999999999	Тутаевское шоссе	0103000020E6100000010000000500000036E7E099D0DE4340DA5548F949D54C4036E7E099D0DE4340C25087156EDD4C40BE688F17D2EB4340C25087156EDD4C40BE688F17D2EB4340DA5548F949D54C4036E7E099D0DE4340DA5548F949D54C40
24117	2085	39.888522000000002	39.895448000000002	57.611583000000003	57.605671000000001	Туговская	0103000020E6100000010000000500000065E3C116BBF143405C9198A086CD4C4065E3C116BBF1434011E50B5A48CE4C4062A2410A9EF2434011E50B5A48CE4C4062A2410A9EF243405C9198A086CD4C4065E3C116BBF143405C9198A086CD4C40
24104	2085	39.757350000000002	39.786203999999998	57.690939	57.678314	Труфанова	0103000020E6100000010000000500000014D044D8F0E04340A0353FFED2D64C4014D044D8F0E04340F6436CB070D84C4000FE2955A2E44340F6436CB070D84C4000FE2955A2E44340A0353FFED2D64C4014D044D8F0E04340A0353FFED2D64C40
24118	2085	39.923090000000002	39.927050999999999	57.576487	57.574975999999999	Театральная	0103000020E61000000100000005000000E0A128D027F6434011FE45D098C94C40E0A128D027F64340DAC87553CAC94C40AF5C6F9BA9F64340DAC87553CAC94C40AF5C6F9BA9F6434011FE45D098C94C40E0A128D027F6434011FE45D098C94C40
944	2085	39.898440000000001	39.930149999999998	57.644106000000001	57.606482	Тверицкая набережная	0103000020E6100000010000000500000089B5F81400F343406CCEC133A1CD4C4089B5F81400F343402594BE1072D24C40EC2FBB270FF743402594BE1072D24C40EC2FBB270FF743406CCEC133A1CD4C4089B5F81400F343406CCEC133A1CD4C40
2529	2085	39.867583000000003	39.87856	57.601861999999997	57.576897000000002	Суздальское шоссе	0103000020E6100000010000000500000065C8B1F50CEF43408C14CAC2D7C94C4065C8B1F50CEF4340425A63D009CD4C4071C971A774F04340425A63D009CD4C4071C971A774F043408C14CAC2D7C94C4065C8B1F50CEF43408C14CAC2D7C94C40
24096	2085	39.900514999999999	39.90692	57.641168	57.638942	Станция Урочь	0103000020E610000001000000050000005A47551344F343403A05F9D9C8D14C405A47551344F34340F19E03CB11D24C404E0B5EF415F44340F19E03CB11D24C404E0B5EF415F443403A05F9D9C8D14C405A47551344F343403A05F9D9C8D14C40
24123	2085	39.920853000000001	39.930950000000003	57.572924999999998	57.570062999999998	Спортивная	0103000020E6100000010000000500000035B6D782DEF543406FD40AD3F7C84C4035B6D782DEF54340C8073D9B55C94C40091B9E5E29F74340C8073D9B55C94C40091B9E5E29F743406FD40AD3F7C84C4035B6D782DEF543406FD40AD3F7C84C40
1258	2085	39.806848000000002	39.828847000000003	57.733055	57.716546000000001	Спартаковская улица	0103000020E61000000100000005000000E86B96CB46E74340310A82C7B7DB4C40E86B96CB46E74340AB9509BFD4DD4C40A13193A817EA4340AB9509BFD4DD4C40A13193A817EA4340310A82C7B7DB4C40E86B96CB46E74340310A82C7B7DB4C40
24140	2085	39.914150999999997	39.927132	57.641388999999997	57.622124999999997	Союзная	0103000020E61000000100000005000000874D64E602F543401283C0CAA1CF4C40874D64E602F54340CF81E50819D24C409C89E942ACF64340CF81E50819D24C409C89E942ACF643401283C0CAA1CF4C40874D64E602F543401283C0CAA1CF4C40
1390	2085	39.873933999999998	39.893588999999999	57.643493999999997	57.627499	Советская улица	0103000020E61000000100000005000000656EBE11DDEF4340E8A221E351D04C40656EBE11DDEF43400B96EA025ED24C405D88D51F61F243400B96EA025ED24C405D88D51F61F24340E8A221E351D04C40656EBE11DDEF4340E8A221E351D04C40
24128	2085	39.873933999999998	39.893588999999999	57.643493999999997	57.627499	Советская	0103000020E61000000100000005000000656EBE11DDEF4340E8A221E351D04C40656EBE11DDEF43400B96EA025ED24C405D88D51F61F243400B96EA025ED24C405D88D51F61F24340E8A221E351D04C40656EBE11DDEF4340E8A221E351D04C40
23226	2085	39.852141000000003	39.884121	57.581491	57.577644999999997	Слепнева	0103000020E61000000100000005000000564ACFF412ED434055D97745F0C94C40564ACFF412ED43408CF50D4C6ECA4C40795A7EE02AF143408CF50D4C6ECA4C40795A7EE02AF1434055D97745F0C94C40564ACFF412ED434055D97745F0C94C40
24102	2085	39.837615	39.883842000000001	57.627175999999999	57.625166	Свободы	0103000020E61000000100000005000000CCD1E3F736EB43401B49827005D04C40CCD1E3F736EB4340056B9C4D47D04C40666A12BC21F14340056B9C4D47D04C40666A12BC21F143401B49827005D04C40CCD1E3F736EB43401B49827005D04C40
2381	2085	39.923512000000002	39.933824000000001	57.570034	57.565573999999998	Светлая улица	0103000020E6100000010000000500000056BB26A435F64340E4BB94BA64C84C4056BB26A435F64340D5CDC5DFF6C84C40261C7A8B87F74340D5CDC5DFF6C84C40261C7A8B87F74340E4BB94BA64C84C4056BB26A435F64340E4BB94BA64C84C40
15729	2085	39.766244	39.770806999999998	57.740141999999999	57.732416000000001	Садовая улица	0103000020E61000000100000005000000CC608C4814E243409888B7CEBFDD4C40CC608C4814E24340B1321AF9BCDE4C409143C4CDA9E24340B1321AF9BCDE4C409143C4CDA9E243409888B7CEBFDD4C40CC608C4814E243409888B7CEBFDD4C40
1611	2085	39.843992999999998	39.867950999999998	57.624993000000003	57.624805000000002	Рыбинская улица	0103000020E61000000100000005000000C6866EF607EC43404BB0389CF9CF4C40C6866EF607EC43404E9D47C5FFCF4C40E7C3B30419EF43404E9D47C5FFCF4C40E7C3B30419EF43404BB0389CF9CF4C40C6866EF607EC43404BB0389CF9CF4C40
1443	2085	39.876978999999999	39.883501000000003	57.646273999999998	57.619473999999997	Республиканская улица	0103000020E61000000100000005000000AF230ED940F04340745C8DEC4ACF4C40AF230ED940F04340A7203F1BB9D24C40DD7D8E8F16F14340A7203F1BB9D24C40DD7D8E8F16F14340745C8DEC4ACF4C40AF230ED940F04340745C8DEC4ACF4C40
1361	2085	39.891181000000003	39.900101999999997	57.625942000000002	57.621994999999998	Революционная улица	0103000020E6100000010000000500000086E8103812F2434044A33B889DCF4C4086E8103812F24340AF9811DE1ED04C403788D68A36F34340AF9811DE1ED04C403788D68A36F3434044A33B889DCF4C4086E8103812F2434044A33B889DCF4C40
22569	2085	39.730688000000001	40.002923000000003	57.775405999999997	57.530433000000002	Привокзальная площадь	0103000020E6100000010000000500000032CA332F87DD43400EDC813AE5C34C4032CA332F87DD4340A38FF98040E34C40FFB3E6C75F004440A38FF98040E34C40FFB3E6C75F0044400EDC813AE5C34C4032CA332F87DD43400EDC813AE5C34C40
24139	2085	39.828847000000003	39.837156999999998	57.723747000000003	57.716546000000001	Панфилова	0103000020E61000000100000005000000A13193A817EA4340310A82C7B7DB4C40A13193A817EA434000CADFBDA3DC4C40094FE8F527EB434000CADFBDA3DC4C40094FE8F527EB4340310A82C7B7DB4C40A13193A817EA4340310A82C7B7DB4C40
24127	2085	39.831929000000002	39.852141000000003	57.589283000000002	57.581414000000002	Павлова	0103000020E6100000010000000500000008CC43A67CEA4340E1B721C66BCA4C4008CC43A67CEA43405D8B16A06DCB4C40564ACFF412ED43405D8B16A06DCB4C40564ACFF412ED4340E1B721C66BCA4C4008CC43A67CEA4340E1B721C66BCA4C40
24136	2085	39.823197	39.845160999999997	57.58522	57.576332000000001	Нефтяников	0103000020E610000001000000050000002995F0845EE94340B3D1393FC5C94C402995F0845EE94340897B2C7DE8CA4C40656D533C2EEC4340897B2C7DE8CA4C40656D533C2EEC4340B3D1393FC5C94C402995F0845EE94340B3D1393FC5C94C40
1702	2085	39.828515000000003	39.883958999999997	57.615121000000002	57.564073	Московский проспект	0103000020E610000001000000050000006B9F8EC70CEA43403FC7478B33C84C406B9F8EC70CEA43409A0AF148BCCE4C409F008A9125F143409A0AF148BCCE4C409F008A9125F143403FC7478B33C84C406B9F8EC70CEA43403FC7478B33C84C40
15557	2085	39.860638999999999	39.886690000000002	57.612628999999998	57.609774999999999	Малая Пролетарская улица	0103000020E61000000100000005000000C154336B29EE43408E75711B0DCE4C40C154336B29EE434064CA87A06ACE4C405AD8D30E7FF1434064CA87A06ACE4C405AD8D30E7FF143408E75711B0DCE4C40C154336B29EE43408E75711B0DCE4C40
24143	2085	39.814833999999998	39.835844999999999	57.606231000000001	57.598004000000003	Маланова	0103000020E610000001000000050000009DD5027B4CE84340487023658BCC4C409DD5027B4CE84340236937FA98CD4C4037C30DF8FCEA4340236937FA98CD4C4037C30DF8FCEA4340487023658BCC4C409DD5027B4CE84340487023658BCC4C40
24126	2085	39.777428	39.841459999999998	57.64282	57.615530999999997	Магистральная	0103000020E61000000100000005000000527FBDC282E343404B5645B8C9CE4C40527FBDC282E343407C9BFEEC47D24C40327216F6B4EB43407C9BFEEC47D24C40327216F6B4EB43404B5645B8C9CE4C40527FBDC282E343404B5645B8C9CE4C40
1831	2085	39.837677999999997	39.841621000000004	57.604128000000003	57.598525000000002	Лесная улица	0103000020E61000000100000005000000124A5F0839EB4340516B9A779CCC4C40124A5F0839EB4340884CF91054CD4C403C50A73CBAEB4340884CF91054CD4C403C50A73CBAEB4340516B9A779CCC4C40124A5F0839EB4340516B9A779CCC4C40
690	2085	39.740741	39.842177999999997	57.729922000000002	57.666204	Ленинградский проспект	0103000020E6100000010000000500000036E7E099D0DE4340713B342C46D54C4036E7E099D0DE4340C25087156EDD4C4091B41B7DCCEB4340C25087156EDD4C4091B41B7DCCEB4340713B342C46D54C4036E7E099D0DE4340713B342C46D54C40
533	2085	39.750073999999998	39.774194000000001	57.733041	57.723266000000002	Красноперевальский переулок	0103000020E610000001000000050000003ACAC16C02E043408527F4FA93DC4C403ACAC16C02E0434046D09849D4DD4C403561FBC918E3434046D09849D4DD4C403561FBC918E343408527F4FA93DC4C403ACAC16C02E043408527F4FA93DC4C40
22945	2085	39.796202999999998	39.816451000000001	57.764111	57.732194999999997	Колышкина	0103000020E6100000010000000500000011FDDAFAE9E54340B9A5D590B8DD4C4011FDDAFAE9E54340C6C1A563CEE14C40ACE4637781E84340C6C1A563CEE14C40ACE4637781E84340B9A5D590B8DD4C4011FDDAFAE9E54340B9A5D590B8DD4C40
1041	2085	39.944667000000003	39.984310000000001	57.608936	57.606988000000001	Клубная улица	0103000020E61000000100000005000000234E27D9EAF84340408864C8B1CD4C40234E27D9EAF84340B4AD669DF1CD4C401990BDDEFDFD4340B4AD669DF1CD4C401990BDDEFDFD4340408864C8B1CD4C40234E27D9EAF84340408864C8B1CD4C40
2473	2085	39.935513	39.938163000000003	57.553140999999997	57.549297000000003	Индустриальный переулок	0103000020E61000000100000005000000CEFDD5E3BEF743403D65355D4FC64C40CEFDD5E3BEF74340D2890453CDC64C409CA8A5B915F84340D2890453CDC64C409CA8A5B915F843403D65355D4FC64C40CEFDD5E3BEF743403D65355D4FC64C40
24144	2085	39.919784	39.924149999999997	57.579942000000003	57.578677999999996	Ильинская	0103000020E6100000010000000500000029B16B7BBBF543401475E61E12CA4C4029B16B7BBBF54340D6C9198A3BCA4C40984C158C4AF64340D6C9198A3BCA4C40984C158C4AF643401475E61E12CA4C4029B16B7BBBF543401475E61E12CA4C40
2500	2085	39.923602000000002	39.935361	57.555599000000001	57.546346	Звездная улица	0103000020E610000001000000050000009642209738F6434074266DAAEEC54C409642209738F643405C5837DE1DC74C40187AC4E8B9F743405C5837DE1DC74C40187AC4E8B9F7434074266DAAEEC54C409642209738F6434074266DAAEEC54C40
24113	2085	39.779341000000002	39.815696000000003	57.685603999999998	57.671267999999998	Елены Колесовой	0103000020E610000001000000050000004AB72572C1E34340F86C1D1CECD54C404AB72572C1E34340DE0033DFC1D74C4030BDFDB968E84340DE0033DFC1D74C4030BDFDB968E84340F86C1D1CECD54C404AB72572C1E34340F86C1D1CECD54C40
22949	2085	39.902338	39.907055	57.648300999999996	57.645031000000003	Дачная	0103000020E6100000010000000500000012F8C3CF7FF34340FEF3346090D24C4012F8C3CF7FF34340677BF486FBD24C402E56D4601AF44340677BF486FBD24C402E56D4601AF44340FEF3346090D24C4012F8C3CF7FF34340FEF3346090D24C40
24115	2085	39.753874000000003	39.779341000000002	57.686464999999998	57.671267999999998	Громова	0103000020E6100000010000000500000001A777F17EE04340F86C1D1CECD54C4001A777F17EE04340A06CCA15DED74C404AB72572C1E34340A06CCA15DED74C404AB72572C1E34340F86C1D1CECD54C4001A777F17EE04340F86C1D1CECD54C40
24130	2085	39.357052000000003	40.411709999999999	57.907905999999997	57.342103999999999	Волкова	0103000020E61000000100000005000000577C43E1B3AD434057EA5910CAAB4C40577C43E1B3AD4340CCEB884336F44C40D4B7CCE9B2344440CCEB884336F44C40D4B7CCE9B234444057EA5910CAAB4C40577C43E1B3AD434057EA5910CAAB4C40
16352	2085	39.884031	39.903883999999998	57.643479999999997	57.621499	Волжская набережная	0103000020E6100000010000000500000039D384ED27F1434094BF7B478DCF4C4039D384ED27F14340A6D0798D5DD24C4057B08D78B2F34340A6D0798D5DD24C4057B08D78B2F3434094BF7B478DCF4C4039D384ED27F1434094BF7B478DCF4C40
24109	2085	39.881174000000001	39.890481000000001	57.604349999999997	57.603825000000001	Верхняя	0103000020E61000000100000005000000F20A444FCAF04340ECC039234ACD4C40F20A444FCAF0434036AB3E575BCD4C40CD5A0A48FBF1434036AB3E575BCD4C40CD5A0A48FBF14340ECC039234ACD4C40F20A444FCAF04340ECC039234ACD4C40
1821	2085	39.84375	39.886285999999998	57.610773000000002	57.607128000000003	Большая Федоровская улица	0103000020E610000001000000050000000000000000EC4340323ECC5EB6CD4C400000000000EC4340D12346CF2DCE4C408A73D4D171F14340D12346CF2DCE4C408A73D4D171F14340323ECC5EB6CD4C400000000000EC4340323ECC5EB6CD4C40
1495	2085	39.848286999999999	39.886384	57.622419000000001	57.620182999999997	Большая Октябрьская улица	0103000020E610000001000000050000009C4F1DAB94EC43408044132862CF4C409C4F1DAB94EC43405BB4006DABCF4C404DD9E90775F143405BB4006DABCF4C404DD9E90775F143408044132862CF4C409C4F1DAB94EC43408044132862CF4C40
543	2085	39.771948000000002	39.777777999999998	57.727760000000004	57.717945	Большая Любимская улица	0103000020E61000000100000005000000371B2B31CFE24340D2A92B9FE5DB4C40371B2B31CFE2434022AB5B3D27DD4C402EC6C03A8EE3434022AB5B3D27DD4C402EC6C03A8EE34340D2A92B9FE5DB4C40371B2B31CFE24340D2A92B9FE5DB4C40
24132	2085	39.792707999999998	39.81062	57.692535999999997	57.683107	Блюхера	0103000020E6100000010000000500000087A3AB7477E543409755D80C70D74C4087A3AB7477E54340BDA60705A5D84C40E4BD6A65C2E74340BDA60705A5D84C40E4BD6A65C2E743409755D80C70D74C4087A3AB7477E543409755D80C70D74C40
808	2085	39.768282999999997	39.775083000000002	57.681432000000001	57.678319000000002	Архангельский проезд	0103000020E610000001000000050000005089EB1857E24340B2A03028D3D64C405089EB1857E243405439ED2939D74C40C15774EB35E343405439ED2939D74C40C15774EB35E34340B2A03028D3D64C405089EB1857E24340B2A03028D3D64C40
1211	2085	39.924247999999999	39.931066999999999	57.659416	57.65343	Алмазная улица	0103000020E610000001000000050000005BB22AC24DF64340D61C2098A3D34C405BB22AC24DF64340C53A55BE67D44C4042B115342DF74340C53A55BE67D44C4042B115342DF74340D61C2098A3D34C405BB22AC24DF64340D61C2098A3D34C40
24146	2085	39.80762	39.851826000000003	57.642921000000001	57.636861000000003	Автозаводская	0103000020E610000001000000050000003ACC971760E74340878C47A984D14C403ACC971760E74340B0743E3C4BD24C40F6F065A208ED4340B0743E3C4BD24C40F6F065A208ED4340878C47A984D14C403ACC971760E74340878C47A984D14C40
2322	2085	39.908591000000001	39.912660000000002	57.598115	57.597245999999998	2-я Портовая улица	0103000020E610000001000000050000005038BBB54CF443405AD5928E72CC4C405038BBB54CF443409F1F46088FCC4C40062FFA0AD2F443409F1F46088FCC4C40062FFA0AD2F443405AD5928E72CC4C405038BBB54CF443405AD5928E72CC4C40
24100	2085	39.8934	39.897263000000002	57.608203000000003	57.605415999999998	2-я Полянская	0103000020E610000001000000050000008A1F63EE5AF24340D13C80457ECD4C408A1F63EE5AF24340202A8D98D9CD4C4097749483D9F24340202A8D98D9CD4C4097749483D9F24340D13C80457ECD4C408A1F63EE5AF24340D13C80457ECD4C40
24125	2085	39.848925000000001	39.858716000000001	57.637242000000001	57.633251999999999	 Щапова	0103000020E61000000100000005000000DFE00B93A9EC43403410CB660ED14C40DFE00B93A9EC43409ED1562591D14C40A646E867EAED43409ED1562591D14C40A646E867EAED43403410CB660ED14C40DFE00B93A9EC43403410CB660ED14C40
24134	2085	39.759155999999997	39.767671999999997	57.691915999999999	57.686931999999999	 Туманова	0103000020E61000000100000005000000F54718062CE14340B6494563EDD74C40F54718062CE1434021CA17B490D84C4007077B1343E2434021CA17B490D84C4007077B1343E24340B6494563EDD74C40F54718062CE14340B6494563EDD74C40
24137	2085	39.887732	39.887929	57.638865000000003	57.632057000000003	 Терешковой	0103000020E610000001000000050000006CCEC133A1F143409C1A683EE7D04C406CCEC133A1F143408FC70C54C6D14C40C21550A8A7F143408FC70C54C6D14C40C21550A8A7F143409C1A683EE7D04C406CCEC133A1F143409C1A683EE7D04C40
24082	2085	39.852141000000003	39.884121	57.581491	57.577644999999997	 Слепнева	0103000020E61000000100000005000000564ACFF412ED434055D97745F0C94C40564ACFF412ED43408CF50D4C6ECA4C40795A7EE02AF143408CF50D4C6ECA4C40795A7EE02AF1434055D97745F0C94C40564ACFF412ED434055D97745F0C94C40
24099	2085	39.939726	39.963405999999999	57.653758000000003	57.647030000000001	 Серго Орджоникидзе	0103000020E61000000100000005000000B7990AF148F84340F4C308E1D1D24C40B7990AF148F84340CBBF9657AED34C40956247E350FB4340CBBF9657AED34C40956247E350FB4340F4C308E1D1D24C40B7990AF148F84340F4C308E1D1D24C40
24145	2085	39.837615	39.883842000000001	57.627175999999999	57.625166	 Свободы	0103000020E61000000100000005000000CCD1E3F736EB43401B49827005D04C40CCD1E3F736EB4340056B9C4D47D04C40666A12BC21F14340056B9C4D47D04C40666A12BC21F143401B49827005D04C40CCD1E3F736EB43401B49827005D04C40
24105	2085	39.843921000000002	39.877068999999999	57.623508000000001	57.622751999999998	 Салтыкова-Щедрина	0103000020E610000001000000050000002DB4739A05EC434061C26856B6CF4C402DB4739A05EC4340AE65321CCFCF4C40EFAA07CC43F04340AE65321CCFCF4C40EFAA07CC43F0434061C26856B6CF4C402DB4739A05EC434061C26856B6CF4C40
24089	2085	39.926611000000001	39.945790000000002	57.557535000000001	57.542853999999998	 Пирогова	0103000020E61000000100000005000000938E72309BF643405B40683D7CC54C40938E72309BF643400CB08F4E5DC74C4022718FA50FF943400CB08F4E5DC74C4022718FA50FF943405B40683D7CC54C40938E72309BF643405B40683D7CC54C40
24098	2085	39.945449000000004	39.964222999999997	57.647468000000003	57.641235000000002	 Папанина	0103000020E6100000010000000500000099840B7904F9434079060DFD13D24C4099840B7904F94340709A3E3BE0D24C408786C5A86BFB4340709A3E3BE0D24C408786C5A86BFB434079060DFD13D24C4099840B7904F9434079060DFD13D24C40
24121	2085	39.831929000000002	39.852141000000003	57.589283000000002	57.581414000000002	 Павлова	0103000020E6100000010000000500000008CC43A67CEA4340E1B721C66BCA4C4008CC43A67CEA43405D8B16A06DCB4C40564ACFF412ED43405D8B16A06DCB4C40564ACFF412ED4340E1B721C66BCA4C4008CC43A67CEA4340E1B721C66BCA4C40
24120	2085	39.915840000000003	39.941343000000003	57.642493000000002	57.625610000000002	 Маяковского	0103000020E61000000100000005000000302FC03E3AF5434079060DFD13D04C40302FC03E3AF543405874EB353DD24C40C6A86BED7DF843405874EB353DD24C40C6A86BED7DF8434079060DFD13D04C40302FC03E3AF5434079060DFD13D04C40
24091	2085	39.828783999999999	39.837066999999998	57.728682999999997	57.723627	 Лебедева	0103000020E610000001000000050000005AB9179815EA434055C03DCF9FDC4C405AB9179815EA434059130B7C45DD4C40C9C7EE0225EB434059130B7C45DD4C40C9C7EE0225EB434055C03DCF9FDC4C405AB9179815EA434055C03DCF9FDC4C40
24106	2085	39.838549	39.844217	57.584448999999999	57.580399999999997	 Зелинского	0103000020E61000000100000005000000F88BD99255EB4340984C158C4ACA4C40F88BD99255EB434007978E39CFCA4C4016DD7A4D0FEC434007978E39CFCA4C4016DD7A4D0FEC4340984C158C4ACA4C40F88BD99255EB4340984C158C4ACA4C40
24093	2085	39.792707999999998	39.81062	57.692535999999997	57.683107	 Блюхера	0103000020E6100000010000000500000087A3AB7477E543409755D80C70D74C4087A3AB7477E54340BDA60705A5D84C40E4BD6A65C2E74340BDA60705A5D84C40E4BD6A65C2E743409755D80C70D74C4087A3AB7477E543409755D80C70D74C40
24141	2085	39.813118000000003	39.822712000000003	57.612875000000003	57.607619	 Бахвалова	0103000020E61000000100000005000000FCE4284014E84340D0B69A75C6CD4C40FCE4284014E843409CC420B072CE4C406D0377A04EE943409CC420B072CE4C406D0377A04EE94340D0B69A75C6CD4C40FCE4284014E84340D0B69A75C6CD4C40
22437	50506	39.728226999999997	39.733328999999998	57.731585000000003	57.727514999999997	Звездная	0103000020E610000001000000050000003788D68A36DD4340BA2C26361FDD4C403788D68A36DD4340419FC893A4DD4C40AC1A84B9DDDD4340419FC893A4DD4C40AC1A84B9DDDD4340BA2C26361FDD4C403788D68A36DD4340BA2C26361FDD4C40
22390	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	микрорайон Мирный	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22784	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Ярославское шоссе	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22459	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Ярославская	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22393	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Студенческий городок	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22534	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Старостина	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22815	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Рыбинское шоссе	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22405	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Опарина	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22613	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Ленинское шоссе	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22910	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Красноармейский бульвар	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22782	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Кирова	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22712	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Зины Золотовой	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22556	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Волжская	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22479	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	Вокзальная	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22895	165	38.256678999999998	38.355618999999997	57.550741000000002	57.501638	1 линия Камышевского шоссе	0103000020E61000000100000005000000F54883DBDA20434026378AAC35C04C40F54883DBDA2043407EC85BAE7EC64C40096B63EC842D43407EC85BAE7EC64C40096B63EC842D434026378AAC35C04C40F54883DBDA20434026378AAC35C04C40
22515	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	проспект Мира	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22562	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	проспект Ленина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22598	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	проспект 50 лет Октября	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22672	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	набережная Космонавтов	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22926	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Ярославский тракт	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22688	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Щепкина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22449	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Чкалова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22476	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Чехова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22864	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Черняховского	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22380	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Черепанова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22896	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Фроловская	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22517	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Федорова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22716	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Труда	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22576	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Солнечная	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22836	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Серова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22522	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Свободы	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22785	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Свердлова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22894	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Рокоссовского	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22690	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Расплетина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22465	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Радищева	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22866	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Пятилетки	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22684	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Пушкина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22470	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Полиграфская	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22811	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Пархинская	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22844	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Ошанина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22572	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Моховая	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22523	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Моторостроителей	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22887	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Молодежная	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22446	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Механизации	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22685	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Ломоносова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22943	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Куйбышева	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22925	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Кораблестроителей	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22474	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Карякинская	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22928	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Инженерная	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22727	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Гончарова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22639	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Глеба Успенского	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22481	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Гастелло	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22734	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Гагарина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22746	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Ворошилова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22938	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Волочаевская	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22608	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Волжская Набережная	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22869	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Вихарева	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22780	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Бурлацкая	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22616	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Бориса Рукавицына	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22561	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Бабушкина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22442	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Академика Павлова	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22395	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	Академика Губкина	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22512	3130	38.734051999999998	38.958416	58.080674999999999	58.010984000000001	9 мая	0103000020E610000001000000050000001DC87A6AF55D4340BF6378EC67014D401DC87A6AF55D43406A4DF38E530A4D4048FB1F60AD7A43406A4DF38E530A4D4048FB1F60AD7A4340BF6378EC67014D401DC87A6AF55D4340BF6378EC67014D40
22930	28001	39.371837999999997	39.464796	57.211801000000001	57.172649	Октябрьская	0103000020E610000001000000050000007CB4386398AF4340F357C85C19964C407CB4386398AF43404B21904B1C9B4C40E3A7716F7EBB43404B21904B1C9B4C40E3A7716F7EBB4340F357C85C19964C407CB4386398AF4340F357C85C19964C40
22519	28001	39.371837999999997	39.464796	57.211801000000001	57.172649	1-Й МКР	0103000020E610000001000000050000007CB4386398AF4340F357C85C19964C407CB4386398AF43404B21904B1C9B4C40E3A7716F7EBB43404B21904B1C9B4C40E3A7716F7EBB4340F357C85C19964C407CB4386398AF4340F357C85C19964C40
22385	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	площадь Народная	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22824	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	площадь Менделеева	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22694	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	переулок Берендеевский	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22615	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	микрорайон Чкаловский	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22391	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	Строителей	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22821	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	Советская	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22614	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	Свободы	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22618	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	Плещеевская	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22695	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	Октябрьская	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22621	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	Менделеева	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22755	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	Кардовского	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
22825	12457	38.824027999999998	38.904345999999997	56.766044999999998	56.722375	50 лет Комсомола	0103000020E61000000100000005000000807EDFBF796943405839B4C8765C4C40807EDFBF79694340D52137C30D624C405B22179CC1734340D52137C30D624C405B22179CC17343405839B4C8765C4C40807EDFBF796943405839B4C8765C4C40
24048	50909	39.833041999999999	39.842466000000002	57.563637999999997	57.557839999999999	Школьная	0103000020E61000000100000005000000E318C91EA1EA43404833164D67C74C40E318C91EA1EA434034643C4A25C84C40F8FE06EDD5EB434034643C4A25C84C40F8FE06EDD5EB43404833164D67C74C40E318C91EA1EA43404833164D67C74C40
22838	4288	39.765461999999999	39.778424999999999	57.651542999999997	57.641274000000003	Школьная	0103000020E61000000100000005000000562AA8A8FAE1434037E3344415D24C40562AA8A8FAE143400778D2C265D34C40C4B12E6EA3E343400778D2C265D34C40C4B12E6EA3E3434037E3344415D24C40562AA8A8FAE1434037E3344415D24C40
22629	4225	39.786473999999998	39.800119000000002	57.620877	57.613737999999998	Луговая	0103000020E61000000100000005000000C093162EABE44340FE277FF78ECE4C40C093162EABE4434057EBC4E578CF4C4041F4A44C6AE6434057EBC4E578CF4C4041F4A44C6AE64340FE277FF78ECE4C40C093162EABE44340FE277FF78ECE4C40
23044	3953	40.003318	40.010882000000002	57.710196000000003	57.701842999999997	Клубная	0103000020E610000001000000050000007BBE66B96C00444098F6CDFDD5D94C407BBE66B96C00444001E0D8B3E7DA4C40BB0ED5946401444001E0D8B3E7DA4C40BB0ED5946401444098F6CDFDD5D94C407BBE66B96C00444098F6CDFDD5D94C40
23109	47161	39.722020000000001	39.726996	57.685021999999996	57.682004999999997	Садовая	0103000020E610000001000000050000006A87BF266BDC4340AF5A99F04BD74C406A87BF266BDC43402F8507CDAED74C40522976340EDD43402F8507CDAED74C40522976340EDD4340AF5A99F04BD74C406A87BF266BDC4340AF5A99F04BD74C40
22935	5299	39.327893000000003	39.340271999999999	57.559306999999997	57.548355999999998	Мира	0103000020E610000001000000050000002ECBD765F8A943405E48878730C64C402ECBD765F8A9434041B62C5F97C74C404CDF6B088EAB434041B62C5F97C74C404CDF6B088EAB43405E48878730C64C402ECBD765F8A943405E48878730C64C40
22788	3666	40.111232999999999	40.132334	57.548108999999997	57.535690000000002	Юбилейная	0103000020E61000000100000005000000349E08E23C0E4440AA656B7D91C44C40349E08E23C0E444056D28A6F28C64C400E130D52F010444056D28A6F28C64C400E130D52F0104440AA656B7D91C44C40349E08E23C0E4440AA656B7D91C44C40
22889	3666	40.111232999999999	40.132334	57.548108999999997	57.535690000000002	Туношна -городок-26	0103000020E61000000100000005000000349E08E23C0E4440AA656B7D91C44C40349E08E23C0E444056D28A6F28C64C400E130D52F010444056D28A6F28C64C400E130D52F0104440AA656B7D91C44C40349E08E23C0E4440AA656B7D91C44C40
22440	4980	40.032440999999999	40.059094000000002	57.857965	57.846480999999997	Социалистическая	0103000020E610000001000000050000005706D50627044440BAD7497D59EC4C405706D506270444406B0E10CCD1ED4C40E6B16664900744406B0E10CCD1ED4C40E6B1666490074440BAD7497D59EC4C405706D50627044440BAD7497D59EC4C40
22480	46172	40.144990999999997	40.157685000000001	57.576799999999999	57.572037000000002	Набережная	0103000020E610000001000000050000006F9BA9108F1244400D8D278238C94C406F9BA9108F124440992A1895D4C94C40EE08A7052F144440992A1895D4C94C40EE08A7052F1444400D8D278238C94C406F9BA9108F1244400D8D278238C94C40
22611	5367	39.443398000000002	39.455786000000003	57.617773	57.612918000000001	Советская 	0103000020E61000000100000005000000508E0244C1B843409B90D61874CE4C40508E0244C1B8434008AD872F13CF4C40C2FC153257BA434008AD872F13CF4C40C2FC153257BA43409B90D61874CE4C40508E0244C1B843409B90D61874CE4C40
22520	47457	39.725245000000001	39.751125000000002	57.790846999999999	57.777017999999998	Школьная	0103000020E61000000100000005000000344B02D4D4DC4340A033695375E34C40344B02D4D4DC4340E29178793AE54C40A01A2FDD24E04340E29178793AE54C40A01A2FDD24E04340A033695375E34C40344B02D4D4DC4340A033695375E34C40
22798	47376	39.486293000000003	39.520806	57.568755000000003	57.553488999999999	Школьная	0103000020E610000001000000050000000AA359D93EBE43400ED940BAD8C64C400AA359D93EBE4340DF37BEF6CCC84C40C1C760C5A9C24340DF37BEF6CCC84C40C1C760C5A9C243400ED940BAD8C64C400AA359D93EBE43400ED940BAD8C64C40
22861	47226	39.878442999999997	39.931649999999998	57.811349	57.700851999999998	Центральная	0103000020E610000001000000050000003733FAD170F0434008ABB184B5D94C403733FAD170F043403752B648DAE74C40C1A8A44E40F743403752B648DAE74C40C1A8A44E40F7434008ABB184B5D94C403733FAD170F0434008ABB184B5D94C40
22406	4344	39.741477000000003	39.766100000000002	57.499544	57.472427000000003	Пушкина	0103000020E610000001000000050000003CDEE4B7E8DE4340AB5FE97C78BC4C403CDEE4B7E8DE4340DE74CB0EF1BF4C4099BB96900FE24340DE74CB0EF1BF4C4099BB96900FE24340AB5FE97C78BC4C403CDEE4B7E8DE4340AB5FE97C78BC4C40
24051	50910	40.351953999999999	40.364503999999997	57.595191999999997	57.587705	Школьная	0103000020E6100000010000000500000023D923D40C2D44400C59DDEA39CB4C4023D923D40C2D4440A06B5F402FCC4C406EA12B11A82E4440A06B5F402FCC4C406EA12B11A82E44400C59DDEA39CB4C4023D923D40C2D44400C59DDEA39CB4C40
24053	50912	39.716261000000003	39.736294000000001	57.479177999999997	57.467644999999997	Лесная	0103000020E610000001000000050000003C33C170AEDB4340A79196CADBBB4C403C33C170AEDB4340397B67B455BD4C40DA1EBDE13EDE4340397B67B455BD4C40DA1EBDE13EDE4340A79196CADBBB4C403C33C170AEDB4340A79196CADBBB4C40
22649	5140	39.672217000000003	39.680922000000002	57.534323000000001	57.529480999999997	Центральная	0103000020E610000001000000050000005A68E7340BD643403B6D8D08C6C34C405A68E7340BD64340144031B264C44C403F90BC7328D74340144031B264C44C403F90BC7328D743403B6D8D08C6C34C405A68E7340BD643403B6D8D08C6C34C40
22438	4512	39.759228	39.775559000000001	57.516829000000001	57.504185999999997	Школьная	0103000020E610000001000000050000008F1A13622EE14340EF8CB62A89C04C408F1A13622EE14340EC4FE27327C24C402A8F6E8445E34340EC4FE27327C24C402A8F6E8445E34340EF8CB62A89C04C408F1A13622EE14340EF8CB62A89C04C40
23060	47078	39.721606000000001	39.754322999999999	57.536932	57.523251999999999	Некрасова	0103000020E61000000100000005000000774CDD955DDC434086C8E9EBF9C24C40774CDD955DDC434083161230BAC44C4070CFF3A78DE0434083161230BAC44C4070CFF3A78DE0434086C8E9EBF9C24C40774CDD955DDC434086C8E9EBF9C24C40
22609	5042	39.944262999999999	39.962822000000003	57.801898000000001	57.790089000000002	Олимпийская	0103000020E6100000010000000500000053E9279CDDF84340F5F6E7A221E54C4053E9279CDDF84340295DFA97A4E64C4046EF54C03DFB4340295DFA97A4E64C4046EF54C03DFB4340F5F6E7A221E54C4053E9279CDDF84340F5F6E7A221E54C40
22526	4939	39.978577999999999	39.991892	57.864113000000003	57.856400000000001	Ярославская	0103000020E61000000100000005000000E44A3D0B42FD4340AF25E4839EED4C40E44A3D0B42FD4340348639419BEE4C40FF942A51F6FE4340348639419BEE4C40FF942A51F6FE4340AF25E4839EED4C40E44A3D0B42FD4340AF25E4839EED4C40
22897	15292	38.022623000000003	38.040571	58.665070999999998	58.659861999999997	Центральная	0103000020E6100000010000000500000097917A4FE5024340C3EFA65B76544D4097917A4FE50243404E42E90B21554D404015376E310543404E42E90B21554D404015376E31054340C3EFA65B76544D4097917A4FE5024340C3EFA65B76544D40
22564	50520	39.500647999999998	39.515165000000003	57.932031000000002	57.925106999999997	Школьный переулок	0103000020E610000001000000050000006667D13B15C043407C26FBE769F64C406667D13B15C04340D9EDB3CA4CF74C409D853DEDF0C14340D9EDB3CA4CF74C409D853DEDF0C143407C26FBE769F64C406667D13B15C043407C26FBE769F64C40
22567	836	39.525162999999999	39.555723999999998	57.765920999999999	57.747962000000001	Школьная	0103000020E61000000100000005000000DD088B8A38C343404C530438BDDF4C40DD088B8A38C34340E92807B309E24C4018CDCAF621C74340E92807B309E24C4018CDCAF621C743404C530438BDDF4C40DD088B8A38C343404C530438BDDF4C40
22646	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	проспект 50-летия Победы	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22624	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	проспект 50 лет Победы	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22757	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	Ярославская	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22823	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	Ушакова	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22389	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	Розы Люксембург	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22878	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	П.Шитова	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22417	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	Моторостроителей	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22877	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	Ленина	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22578	31124	39.494773000000002	39.570760999999997	57.902039000000002	57.837532000000003	Комсомольская	0103000020E61000000100000005000000CFF8BEB854BF43403FADA23F34EB4C40CFF8BEB854BF4340B85B920376F34C40876A4AB20EC94340B85B920376F34C40876A4AB20EC943403FADA23F34EB4C40CFF8BEB854BF43403FADA23F34EB4C40
22835	50575	39.275089999999999	39.293971999999997	57.889124000000002	57.882100000000001	Центральная	0103000020E6100000010000000500000073BA2C2636A343409BE61DA7E8F04C4073BA2C2636A343405B0BB3D0CEF14C4048F8DEDFA0A543405B0BB3D0CEF14C4048F8DEDFA0A543409BE61DA7E8F04C4073BA2C2636A343409BE61DA7E8F04C40
22632	50533	39.363565000000001	39.376725	57.944629999999997	57.936461000000001	Новая	0103000020E61000000100000005000000317C444C89AE43405F7D3CF4DDF74C40317C444C89AE43400569C6A2E9F84C40F54A598638B043400569C6A2E9F84C40F54A598638B043405F7D3CF4DDF74C40317C444C89AE43405F7D3CF4DDF74C40
24068	50924	39.324829999999999	39.337325	57.921636999999997	57.913429000000001	Молодежная	0103000020E610000001000000050000003D61890794A94340E71BD13DEBF44C403D61890794A943404BE48233F8F54C40C58F31772DAB43404BE48233F8F54C40C58F31772DAB4340E71BD13DEBF44C403D61890794A94340E71BD13DEBF44C40
22460	681	39.627256000000003	39.649183999999998	57.850073000000002	57.840420999999999	Школьная	0103000020E61000000100000005000000221CB3EC49D0434091EF52EA92EB4C40221CB3EC49D04340371B2B31CFEC4C40118B187618D34340371B2B31CFEC4C40118B187618D3434091EF52EA92EB4C40221CB3EC49D0434091EF52EA92EB4C40
23129	49056	39.346325999999998	39.359549000000001	58.063434999999998	58.059306999999997	Центральная	0103000020E6100000010000000500000093E00D6954AC434041B62C5F97074D4093E00D6954AC4340FC3559A31E084D409E279EB305AE4340FC3559A31E084D409E279EB305AE434041B62C5F97074D4093E00D6954AC434041B62C5F97074D40
22710	50543	39.467266000000002	39.476770999999999	58.110897999999999	58.103352000000001	Молодёжная	0103000020E6100000010000000500000031444E5FCFBB4340F4FC69A33A0D4D4031444E5FCFBB43408D98D9E7310E4D40325706D506BD43408D98D9E7310E4D40325706D506BD4340F4FC69A33A0D4D4031444E5FCFBB4340F4FC69A33A0D4D40
22473	50511	39.597225999999999	39.656461	57.950122999999998	57.771056999999999	Школьная	0103000020E610000001000000050000001329CDE671CC43400A2DEBFEB1E24C401329CDE671CC4340B51666A19DF94C40BB0CFFE906D44340B51666A19DF94C40BB0CFFE906D443400A2DEBFEB1E24C401329CDE671CC43400A2DEBFEB1E24C40
22641	777	39.464418999999999	39.481855000000003	57.686556000000003	57.678789999999999	Центральная	0103000020E610000001000000050000000D52F01472BB4340096D3997E2D64C400D52F01472BB4340B16F2711E1D74C400135B56CADBD4340B16F2711E1D74C400135B56CADBD4340096D3997E2D64C400D52F01472BB4340096D3997E2D64C40
22560	50519	39.756343999999999	39.774363999999998	58.008490000000002	57.998584999999999	Центральная	0103000020E610000001000000050000004E4354E1CFE0434059A31EA2D1FF4C404E4354E1CFE04340E92B483316014D4091990B5C1EE34340E92B483316014D4091990B5C1EE3434059A31EA2D1FF4C404E4354E1CFE0434059A31EA2D1FF4C40
24058	50519	39.756343999999999	39.774363999999998	58.008490000000002	57.998584999999999	 Школьная	0103000020E610000001000000050000004E4354E1CFE0434059A31EA2D1FF4C404E4354E1CFE04340E92B483316014D4091990B5C1EE34340E92B483316014D4091990B5C1EE3434059A31EA2D1FF4C404E4354E1CFE0434059A31EA2D1FF4C40
23131	49107	39.827894999999998	39.853264000000003	57.985567000000003	57.978591000000002	Заречная	0103000020E61000000100000005000000CEC29E76F8E9434079944A7842FD4C40CEC29E76F8E943402882380F27FE4C40556D37C137ED43402882380F27FE4C40556D37C137ED434079944A7842FD4C40CEC29E76F8E9434079944A7842FD4C40
22880	414	39.623735000000003	39.643245999999998	57.801414000000001	57.793514000000002	Советская	0103000020E610000001000000050000006F2F698CD6CF43408675E3DD91E54C406F2F698CD6CF43403D47E4BB94E64C4033A48AE255D243403D47E4BB94E64C4033A48AE255D243408675E3DD91E54C406F2F698CD6CF43408675E3DD91E54C40
22463	290	39.566288	39.622441000000002	57.840420999999999	57.810946999999999	Садовая	0103000020E61000000100000005000000020F0C207CC8434008E57D1CCDE74C40020F0C207CC8434091EF52EA92EB4C4043588D25ACCF434091EF52EA92EB4C4043588D25ACCF434008E57D1CCDE74C40020F0C207CC8434008E57D1CCDE74C40
22735	47392	39.410420999999999	39.420473000000001	57.695937000000001	57.691082999999999	Молодежная	0103000020E61000000100000005000000BA4BE2AC88B4434029E9616875D84C40BA4BE2AC88B44340C689AF7614D94C40EEEC2B0FD2B54340C689AF7614D94C40EEEC2B0FD2B5434029E9616875D84C40BA4BE2AC88B4434029E9616875D84C40
22772	50558	39.394404000000002	39.408562000000003	57.906863999999999	57.897700999999998	Центральная	0103000020E61000000100000005000000AFB48CD47BB24340124BCADDE7F24C40AFB48CD47BB24340BAF59A1E14F44C40B63176C24BB44340BAF59A1E14F44C40B63176C24BB44340124BCADDE7F24C40AFB48CD47BB24340124BCADDE7F24C40
22871	579	39.457321999999998	39.489849999999997	57.944606	57.938754000000003	Анненская	0103000020E61000000100000005000000E3DEFC8689BA43409E7E501729F84C40E3DEFC8689BA43407DCD72D9E8F84C4009F9A067B3BE43407DCD72D9E8F84C4009F9A067B3BE43409E7E501729F84C40E3DEFC8689BA43409E7E501729F84C40
22708	50542	39.791108999999999	39.802607999999999	57.949468000000003	57.945681	Центральная	0103000020E610000001000000050000001F49490F43E543406BB933130CF94C401F49490F43E543409D4CDC2A88F94C4005C1E3DBBBE643409D4CDC2A88F94C4005C1E3DBBBE643406BB933130CF94C401F49490F43E543406BB933130CF94C40
22832	32383	39.607224000000002	39.638378000000003	58.09901	58.088402000000002	Солнечная	0103000020E6100000010000000500000054AC1A84B9CD43405473B9C1500B4D4054AC1A84B9CD43400DFD135CAC0C4D40323ECC5EB6D143400DFD135CAC0C4D40323ECC5EB6D143405473B9C1500B4D4054AC1A84B9CD43405473B9C1500B4D40
22544	49273	38.602969999999999	38.62771	58.002377000000003	57.982804000000002	Тугаринова	0103000020E610000001000000050000000C3CF71E2E4D434062307F85CCFD4C400C3CF71E2E4D43409DA1B8E34D004D40A3AF20CD585043409DA1B8E34D004D40A3AF20CD5850434062307F85CCFD4C400C3CF71E2E4D434062307F85CCFD4C40
22822	30911	38.630997999999998	38.650661999999997	58.119630999999998	58.107236999999998	Водников	0103000020E61000000100000005000000B3EBDE8AC4504340E8F527F1B90D4D40B3EBDE8AC45043403C4B9011500F4D40FE5F75E4485343403C4B9011500F4D40FE5F75E448534340E8F527F1B90D4D40B3EBDE8AC4504340E8F527F1B90D4D40
24056	46562	38.966068999999997	38.976534999999998	58.033766999999997	58.025298999999997	Центральная	0103000020E61000000100000005000000F7562426A87B43408DCF64FF3C034D40F7562426A87B43408E57207A52044D401E335019FF7C43408E57207A52044D401E335019FF7C43408DCF64FF3C034D40F7562426A87B43408DCF64FF3C034D40
22691	30520	38.861353000000001	38.879255999999998	58.303384000000001	58.282575999999999	Приморская	0103000020E61000000100000005000000DFA7AAD0406E434037514B732B244D40DFA7AAD0406E434099107349D5264D40E867EA758B70434099107349D5264D40E867EA758B70434037514B732B244D40DFA7AAD0406E434037514B732B244D40
24060	49188	38.833055999999999	38.866419	57.999910999999997	57.982785	Центральная	0103000020E6100000010000000500000048DE3994A16A4340EBFF1CE6CBFD4C4048DE3994A16A434090F46915FDFF4C4007D15AD1E66E434090F46915FDFF4C4007D15AD1E66E4340EBFF1CE6CBFD4C4048DE3994A16A4340EBFF1CE6CBFD4C40
22381	30814	38.760472	38.779713999999998	58.021771999999999	58.007922999999998	Молодежная	0103000020E6100000010000000500000009C38025576143406FF1F09E03014D4009C3802557614340F8FBC56CC9024D40DE1D19ABCD634340F8FBC56CC9024D40DE1D19ABCD6343406FF1F09E03014D4009C38025576143406FF1F09E03014D40
22737	27955	39.282482999999999	39.302309000000001	57.156582999999998	57.148482999999999	Квартал В	0103000020E610000001000000050000008656276728A443408881AE7D01934C408656276728A44340060E68E90A944C40AB24B20FB2A64340060E68E90A944C40AB24B20FB2A643408881AE7D01934C408656276728A443408881AE7D01934C40
22524	29232	39.284747000000003	39.302802999999997	56.943770999999998	56.935305999999997	Заводская	0103000020E610000001000000050000002B51F69672A4434054E0641BB8774C402B51F69672A44340E4F4F57CCD784C40BA10AB3FC2A64340E4F4F57CCD784C40BA10AB3FC2A6434054E0641BB8774C402B51F69672A4434054E0641BB8774C40
22610	29434	39.494225	39.523977000000002	57.170917000000003	57.155836000000001	Прудная	0103000020E61000000100000005000000CCEEC9C342BF43400DC51D6FF2934C40CCEEC9C342BF43404CAAB69BE0954C40986DA7AD11C343404CAAB69BE0954C40986DA7AD11C343400DC51D6FF2934C40CCEEC9C342BF43400DC51D6FF2934C40
22530	29757	39.514454999999998	39.548627000000003	57.312939999999998	57.295518999999999	Окружная	0103000020E61000000100000005000000C02154A9D9C143405E2C0C91D3A54C40C02154A9D9C143401CCEFC6A0EA84C40EF59D76839C643401CCEFC6A0EA84C40EF59D76839C643405E2C0C91D3A54C40C02154A9D9C143405E2C0C91D3A54C40
22812	29757	39.514454999999998	39.548627000000003	57.312939999999998	57.295518999999999	Мира	0103000020E61000000100000005000000C02154A9D9C143405E2C0C91D3A54C40C02154A9D9C143401CCEFC6A0EA84C40EF59D76839C643401CCEFC6A0EA84C40EF59D76839C643405E2C0C91D3A54C40C02154A9D9C143405E2C0C91D3A54C40
22750	29757	39.514454999999998	39.548627000000003	57.312939999999998	57.295518999999999	Ленинская	0103000020E61000000100000005000000C02154A9D9C143405E2C0C91D3A54C40C02154A9D9C143401CCEFC6A0EA84C40EF59D76839C643401CCEFC6A0EA84C40EF59D76839C643405E2C0C91D3A54C40C02154A9D9C143405E2C0C91D3A54C40
22602	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	Спартаковская	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22594	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	Революции	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22674	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	Пролетарская	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22805	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	Московская	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22675	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	Моравского	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22744	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	Ленинская	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22803	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	Каменный мост	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22670	50525	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	1-Й МКР	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
22683	29182	39.419646999999998	39.430821999999999	56.974445000000003	56.966546000000001	39	0103000020E61000000100000005000000A86E2EFEB6B54340310A82C7B77B4C40A86E2EFEB6B5434018601F9DBA7C4C40DB32E02C25B7434018601F9DBA7C4C40DB32E02C25B74340310A82C7B77B4C40A86E2EFEB6B54340310A82C7B77B4C40
23220	46677	39.306736999999998	39.317543999999998	56.822558000000001	56.816459000000002	Советская	0103000020E6100000010000000500000090BC732843A743402FC37FBA81684C4090BC732843A7434016889E9449694C4040852348A5A8434016889E9449694C4040852348A5A843402FC37FBA81684C4090BC732843A743402FC37FBA81684C40
23073	46677	39.306736999999998	39.317543999999998	56.822558000000001	56.816459000000002	Любимская	0103000020E6100000010000000500000090BC732843A743402FC37FBA81684C4090BC732843A7434016889E9449694C4040852348A5A8434016889E9449694C4040852348A5A843402FC37FBA81684C4090BC732843A743402FC37FBA81684C40
22751	29958	39.365271999999997	39.404204999999997	57.105846999999997	57.086269000000001	Центральная	0103000020E610000001000000050000007F129F3BC1AE43404ED4D2DC0A8B4C407F129F3BC1AE43409AB0FD648C8D4C4099F04BFDBCB343409AB0FD648C8D4C4099F04BFDBCB343404ED4D2DC0A8B4C407F129F3BC1AE43404ED4D2DC0A8B4C40
22809	29249	39.241933000000003	39.300781999999998	57.020578999999998	56.993102	Советская	0103000020E610000001000000050000005E6919A9F79E4340CDCB61F71D7F4C405E6919A9F79E434000FE2955A2824C40DC9C4A0680A6434000FE2955A2824C40DC9C4A0680A64340CDCB61F71D7F4C405E6919A9F79E4340CDCB61F71D7F4C40
22920	29249	39.241933000000003	39.300781999999998	57.020578999999998	56.993102	Пролетарская	0103000020E610000001000000050000005E6919A9F79E4340CDCB61F71D7F4C405E6919A9F79E434000FE2955A2824C40DC9C4A0680A6434000FE2955A2824C40DC9C4A0680A64340CDCB61F71D7F4C405E6919A9F79E4340CDCB61F71D7F4C40
22810	29612	39.534272000000001	39.548914000000003	57.268586999999997	57.261408000000003	Центральная	0103000020E6100000010000000500000092955F0663C44340D6743DD175A14C4092955F0663C44340BC900E0F61A24C4085285FD042C64340BC900E0F61A24C4085285FD042C64340D6743DD175A14C4092955F0663C44340D6743DD175A14C40
22441	29337	39.726610000000001	39.748421	57.115026	57.106067000000003	Труда	0103000020E610000001000000050000002979758E01DD4340A9177C9A938D4C402979758E01DD43404818062CB98E4C40DF516342CCDF43404818062CB98E4C40DF516342CCDF4340A9177C9A938D4C402979758E01DD4340A9177C9A938D4C40
22834	29388	39.574084999999997	39.594531000000003	57.096215999999998	57.083646999999999	Центральная	0103000020E61000000100000005000000E40F069E7BC943404AB4E4F1B48A4C40E40F069E7BC943400CAD4ECE508C4C40A6BA809719CC43400CAD4ECE508C4C40A6BA809719CC43404AB4E4F1B48A4C40E40F069E7BC943404AB4E4F1B48A4C40
22680	28863	39.183785	39.195247999999999	56.959018	56.949843999999999	Заводская	0103000020E61000000100000005000000683F524486974340A226FA7C94794C40683F5244869743403E23111AC17A4C40014EEFE2FD9843403E23111AC17A4C40014EEFE2FD984340A226FA7C94794C40683F524486974340A226FA7C94794C40
22940	30017	39.383822000000002	39.394727000000003	57.077835999999998	57.065627999999997	Нагорная	0103000020E610000001000000050000001FBE4C1421B14340D7D9907F66884C401FBE4C1421B14340C939B187F6894C4092EC116A86B24340C939B187F6894C4092EC116A86B24340D7D9907F66884C401FBE4C1421B14340D7D9907F66884C40
22933	29089	39.380443999999997	39.406970999999999	56.914994	56.897364000000003	Сосновая	0103000020E61000000100000005000000CEFA9463B2B04340CB4DD4D2DC724C40CEFA9463B2B04340A304FD851E754C40D0B52FA017B44340A304FD851E754C40D0B52FA017B44340CB4DD4D2DC724C40CEFA9463B2B04340CB4DD4D2DC724C40
22862	27829	39.327533000000003	39.348374	57.198307	57.190762999999997	Школьная	0103000020E610000001000000050000002EAEF199ECA94340B72407EC6A984C402EAEF199ECA94340B0C8AF1F62994C406B63EC8497AC4340B0C8AF1F62994C406B63EC8497AC4340B72407EC6A984C402EAEF199ECA94340B72407EC6A984C40
22808	28953	39.274757000000001	39.300288000000002	56.866706000000001	56.851061999999999	Березовая	0103000020E610000001000000050000006DACC43C2BA34340266F8099EF6C4C406DACC43C2BA343409D9FE238F06E4C40CDB051D66FA643409D9FE238F06E4C40CDB051D66FA64340266F8099EF6C4C406DACC43C2BA34340266F8099EF6C4C40
22682	29130	39.316609999999997	39.338259000000001	56.879151	56.869273999999997	Центральная	0103000020E6100000010000000500000014CB2DAD86A84340ADA1D45E446F4C4014CB2DAD86A84340739F1C0588704C40F14927124CAB4340739F1C0588704C40F14927124CAB4340ADA1D45E446F4C4014CB2DAD86A84340ADA1D45E446F4C40
22747	28738	39.132662000000003	39.152155	57.102601	57.094704999999998	Кузьмина	0103000020E6100000010000000500000003B68311FB90434043E21E4B1F8C4C4003B68311FB904340B9C49107228D4C402176A6D079934340B9C49107228D4C402176A6D07993434043E21E4B1F8C4C4003B68311FB90434043E21E4B1F8C4C40
22687	29659	39.581828999999999	39.594746000000001	57.303761999999999	57.298374000000003	квартал В	0103000020E61000000100000005000000A46E675F79CA434005FD851E31A64C40A46E675F79CA43403FE257ACE1A64C40A2B60DA320CC43403FE257ACE1A64C40A2B60DA320CC434005FD851E31A64C40A46E675F79CA434005FD851E31A64C40
22749	28999	39.241044000000002	39.246568000000003	56.809511999999998	56.804298000000003	Школьная	0103000020E61000000100000005000000D272A087DA9E43407E1EA33CF3664C40D272A087DA9E43401ADCD6169E674C40BD1E4C8A8F9F43401ADCD6169E674C40BD1E4C8A8F9F43407E1EA33CF3664C40D272A087DA9E43407E1EA33CF3664C40
22731	27353	39.078448999999999	39.094572999999997	58.492054000000003	58.477502999999999	Рыбинская	0103000020E61000000100000005000000B3B3E89D0A8A4340F65E7CD11E3D4D40B3B3E89D0A8A4340D9EE1EA0FB3E4D40D40AD3F71A8C4340D9EE1EA0FB3E4D40D40AD3F71A8C4340F65E7CD11E3D4D40B3B3E89D0A8A4340F65E7CD11E3D4D40
22919	27302	39.190998999999998	39.205793999999997	58.500946999999996	58.494311000000003	Административная	0103000020E61000000100000005000000CB48BDA772984340CB863595453F4D40CB48BDA772984340C00303081F404D4044DB3175579A4340C00303081F404D4044DB3175579A4340CB863595453F4D40CB48BDA772984340CB863595453F4D40
22668	27727	39.290495999999997	39.310510000000001	58.712466999999997	58.703301000000003	Центральная	0103000020E6100000010000000500000035CF11F92EA543403F1F65C4055A4D4035CF11F92EA54340573D601E325B4D405D8AABCABEA74340573D601E325B4D405D8AABCABEA743403F1F65C4055A4D4035CF11F92EA543403F1F65C4055A4D40
22587	27089	39.378386999999996	39.389760000000003	58.739680999999997	58.731209	Калининская	0103000020E61000000100000005000000A31D37FC6EB043403BC5AA41985D4D40A31D37FC6EB043407D3CF4DDAD5E4D40FDA4DAA7E3B143407D3CF4DDAD5E4D40FDA4DAA7E3B143403BC5AA41985D4D40A31D37FC6EB043403BC5AA41985D4D40
22839	26542	39.092407999999999	39.152307999999998	58.506495000000001	58.489792000000001	Строителей	0103000020E61000000100000005000000C3F17C06D48B4340D5EB1681B13E4D40C3F17C06D48B4340344B02D4D4404D40A7751BD47E934340344B02D4D4404D40A7751BD47E934340D5EB1681B13E4D40C3F17C06D48B4340D5EB1681B13E4D40
22469	26542	39.092407999999999	39.152307999999998	58.506495000000001	58.489792000000001	Советская	0103000020E61000000100000005000000C3F17C06D48B4340D5EB1681B13E4D40C3F17C06D48B4340344B02D4D4404D40A7751BD47E934340344B02D4D4404D40A7751BD47E934340D5EB1681B13E4D40C3F17C06D48B4340D5EB1681B13E4D40
22553	26542	39.092407999999999	39.152307999999998	58.506495000000001	58.489792000000001	Преображенского	0103000020E61000000100000005000000C3F17C06D48B4340D5EB1681B13E4D40C3F17C06D48B4340344B02D4D4404D40A7751BD47E934340344B02D4D4404D40A7751BD47E934340D5EB1681B13E4D40C3F17C06D48B4340D5EB1681B13E4D40
22789	26542	39.092407999999999	39.152307999999998	58.506495000000001	58.489792000000001	Заречная	0103000020E61000000100000005000000C3F17C06D48B4340D5EB1681B13E4D40C3F17C06D48B4340344B02D4D4404D40A7751BD47E934340344B02D4D4404D40A7751BD47E934340D5EB1681B13E4D40C3F17C06D48B4340D5EB1681B13E4D40
22733	27481	39.616737000000001	39.646704999999997	58.309095999999997	58.297958999999999	Мирная	0103000020E61000000100000005000000D89DEE3CF1CE43404146408523264D40D89DEE3CF1CE434086A92D7590274D407094BC3AC7D2434086A92D7590274D407094BC3AC7D243404146408523264D40D89DEE3CF1CE43404146408523264D40
22423	27392	38.960850000000001	39.007257000000003	58.433244999999999	58.418821000000001	Школьная	0103000020E61000000100000005000000492EFF21FD7A434063F030ED9B354D40492EFF21FD7A4340E813799274374D4063D520CCED804340E813799274374D4063D520CCED80434063F030ED9B354D40492EFF21FD7A434063F030ED9B354D40
22918	27258	39.158237	39.172277999999999	58.790883000000001	58.783776000000003	Центральная	0103000020E6100000010000000500000032022A1C41944340E2B19FC552644D4032022A1C419443402FFB75A73B654D40FFE89B340D9643402FFB75A73B654D40FFE89B340D964340E2B19FC552644D4032022A1C41944340E2B19FC552644D40
22794	27173	39.069887999999999	39.095210999999999	58.517138000000003	58.511375000000001	Ветеранская	0103000020E6100000010000000500000001310917F2884340FA7E6ABC74414D4001310917F28843406AC2F69331424D40179CC1DF2F8C43406AC2F69331424D40179CC1DF2F8C4340FA7E6ABC74414D4001310917F2884340FA7E6ABC74414D40
22756	27117	39.342067999999998	39.355175000000003	58.629596999999997	58.620980000000003	Огурцова	0103000020E610000001000000050000000A815CE2C8AB43402CBCCB457C4F4D400A815CE2C8AB434071546EA296504D40ACADD85F76AD434071546EA296504D40ACADD85F76AD43402CBCCB457C4F4D400A815CE2C8AB43402CBCCB457C4F4D40
22916	27036	38.686585999999998	38.694760000000002	58.620896000000002	58.613303999999999	Ильинская	0103000020E610000001000000050000001BF2CF0CE2574340C440D7BE804E4D401BF2CF0CE2574340CE1B2785794F4D40D4484BE5ED584340CE1B2785794F4D40D4484BE5ED584340C440D7BE804E4D401BF2CF0CE2574340C440D7BE804E4D40
22922	27551	39.284880999999999	39.30097	58.415126000000001	58.406131000000002	Школьная	0103000020E610000001000000050000003A2009FB76A443402672C119FC334D403A2009FB76A4434012DC48D922354D40DF89592F86A6434012DC48D922354D40DF89592F86A643402672C119FC334D403A2009FB76A443402672C119FC334D40
22427	27004	38.509149999999998	38.523989999999998	58.700687000000002	58.693004999999999	Молодежная	0103000020E610000001000000050000001361C3D32B414340747B4963B4584D401361C3D32B414340BEDD921CB0594D402CB7B41A12434340BEDD921CB0594D402CB7B41A12434340747B4963B4584D401361C3D32B414340747B4963B4584D40
22509	26954	39.096038	39.107644000000001	58.325657999999997	58.319575999999998	Школьная	0103000020E610000001000000050000002D9622F94A8C4340124BCADDE7284D402D9622F94A8C434023D74D29AF294D4029CE5147C78D434023D74D29AF294D4029CE5147C78D4340124BCADDE7284D402D9622F94A8C4340124BCADDE7284D40
22820	26904	39.466566	39.502355000000001	58.813977000000001	58.806702000000001	Пошехонская	0103000020E6100000010000000500000078B6476FB8BB434014CFD90242674D4078B6476FB8BB43401D59F96530684D40B5FD2B2B4DC043401D59F96530684D40B5FD2B2B4DC0434014CFD90242674D4078B6476FB8BB434014CFD90242674D40
22504	26805	39.206566000000002	39.215235	58.8414	58.835104000000001	Солнечная	0103000020E61000000100000005000000973B33C1709A4340206118B0E46A4D40973B33C1709A43405D6DC5FEB26B4D402FFA0AD28C9B43405D6DC5FEB26B4D402FFA0AD28C9B4340206118B0E46A4D40973B33C1709A4340206118B0E46A4D40
22853	26764	39.378073000000001	39.405453000000001	58.385789000000003	58.376399999999997	Федоровская	0103000020E61000000100000005000000144031B264B04340711B0DE02D304D40144031B264B043400A14B18861314D40558847E2E5B343400A14B18861314D40558847E2E5B34340711B0DE02D304D40144031B264B04340711B0DE02D304D40
22505	26848	39.285303999999996	39.299864999999997	58.823709999999998	58.817121999999998	Центральная	0103000020E6100000010000000500000080B56AD784A44340CA6B257497684D4080B56AD784A44340AFB14B546F694D40861BF0F961A64340AFB14B546F694D40861BF0F961A64340CA6B257497684D4080B56AD784A44340CA6B257497684D40
22485	26006	38.270018999999998	38.292261000000003	56.905455000000003	56.888415999999999	Мичуринская	0103000020E6100000010000000500000039268BFB8F2243401F9F909DB7714C4039268BFB8F224340F67F0EF3E5734C40B972F6CE68254340F67F0EF3E5734C40B972F6CE682543401F9F909DB7714C4039268BFB8F2243401F9F909DB7714C40
22851	26251	39.091582000000002	39.110275999999999	56.786172999999998	56.769996999999996	Овражная	0103000020E610000001000000050000007E737FF5B88B43405182FE428F624C407E737FF5B88B4340C5FF1D51A1644C4050C422861D8E4340C5FF1D51A1644C4050C422861D8E43405182FE428F624C407E737FF5B88B43405182FE428F624C40
22901	25179	38.885221000000001	38.894661999999997	56.77628	56.772497000000001	Троицкая	0103000020E61000000100000005000000C05DF6EB4E7143400AA1832EE1624C40C05DF6EB4E714340FA449E245D634C40AA7CCF4884724340FA449E245D634C40AA7CCF48847243400AA1832EE1624C40C05DF6EB4E7143400AA1832EE1624C40
22584	26438	39.156198000000003	39.181987999999997	56.642108999999998	56.624678000000003	Центральная	0103000020E61000000100000005000000AED9CA4BFE934340EE43DE72F54F4C40AED9CA4BFE934340CFBBB1A030524C40D921FE614B974340CFBBB1A030524C40D921FE614B974340EE43DE72F54F4C40AED9CA4BFE934340EE43DE72F54F4C40
22502	26282	39.187702000000002	39.196604000000001	56.716704999999997	56.712505999999998	Республиканская	0103000020E6100000010000000500000068B27F9E06984340151A8865335B4C4068B27F9E0698434099F04BFDBC5B4C40A321E3512A99434099F04BFDBC5B4C40A321E3512A994340151A8865335B4C4068B27F9E06984340151A8865335B4C40
22726	26282	39.187702000000002	39.196604000000001	56.716704999999997	56.712505999999998	Большая Октябрьская	0103000020E6100000010000000500000068B27F9E06984340151A8865335B4C4068B27F9E0698434099F04BFDBC5B4C40A321E3512A99434099F04BFDBC5B4C40A321E3512A994340151A8865335B4C4068B27F9E06984340151A8865335B4C40
22484	25867	38.635247	38.651451999999999	57.038899000000001	57.026663999999997	Центральная	0103000020E61000000100000005000000E9F010C64F51434082FDD7B969834C40E9F010C64F5143406E6C76A4FA844C40F77475C7625343406E6C76A4FA844C40F77475C76253434082FDD7B969834C40E9F010C64F51434082FDD7B969834C40
22790	50564	38.704076000000001	38.721071999999999	56.719071	56.707926	Моисеева	0103000020E6100000010000000500000002F390291F5A43407AFEB4519D5A4C4002F390291F5A43404240BE840A5C4C40D90759164C5C43404240BE840A5C4C40D90759164C5C43407AFEB4519D5A4C4002F390291F5A43407AFEB4519D5A4C40
22421	25970	38.248458999999997	38.283546999999999	56.926096999999999	56.910806999999998	Адмирала Спиридова	0103000020E61000000100000005000000CCB22781CD1F4340E3FBE25295744C40CCB22781CD1F43403CF6B3588A764C4080F0A1444B2443403CF6B3588A764C4080F0A1444B244340E3FBE25295744C40CCB22781CD1F4340E3FBE25295744C40
22415	25428	38.801974000000001	38.823345000000003	56.960937000000001	56.952509999999997	Школьная	0103000020E61000000100000005000000041F8315A7664340758E01D9EB794C40041F8315A76643401842CEFBFF7A4C409E29745E636943401842CEFBFF7A4C409E29745E63694340758E01D9EB794C40041F8315A7664340758E01D9EB794C40
22658	25572	38.635165999999998	38.701622999999998	56.829911000000003	56.805840000000003	Депутатская	0103000020E61000000100000005000000FCC3961E4D51434082E7DEC325674C40FCC3961E4D5143409BCB0D863A6A4C408A8F4FC8CE5943409BCB0D863A6A4C408A8F4FC8CE59434082E7DEC325674C40FCC3961E4D51434082E7DEC325674C40
22402	50501	38.338954999999999	38.368949999999998	56.739100000000001	56.708132999999997	Петрова	0103000020E6100000010000000500000068E89FE0622B4340F31B261AA45A4C4068E89FE0622B43409F3C2CD49A5E4C40FAEDEBC0392F43409F3C2CD49A5E4C40FAEDEBC0392F4340F31B261AA45A4C4068E89FE0622B4340F31B261AA45A4C40
22902	25271	38.870713000000002	38.883074000000001	56.797328999999998	56.789067000000003	Совхозная	0103000020E61000000100000005000000DD990986736F43402AADBF2500654C40DD990986736F434081936DE00E664C4055F99E910871434081936DE00E664C4055F99E91087143402AADBF2500654C40DD990986736F43402AADBF2500654C40
22659	25663	38.460830000000001	38.487051999999998	56.886488999999997	56.874099999999999	Центральная	0103000020E610000001000000050000000282397AFC3A434080B74082E26F4C400282397AFC3A4340C2A1B77878714C40C7B94DB8573E4340C2A1B77878714C40C7B94DB8573E434080B74082E26F4C400282397AFC3A434080B74082E26F4C40
22720	25144	38.946235000000001	38.962862000000001	56.685225000000003	56.673713999999997	Школьная	0103000020E6100000010000000500000050AA7D3A1E794340BD6DA6423C564C4050AA7D3A1E79434068B3EA73B5574C40D447E00F3F7B434068B3EA73B5574C40D447E00F3F7B4340BD6DA6423C564C4050AA7D3A1E794340BD6DA6423C564C40
22845	25327	38.994168999999999	39.014336	56.815646000000001	56.804875000000003	прспект Мира	0103000020E6100000010000000500000038D906EE407F43401B2FDD2406674C4038D906EE407F43407E8E8F1667684C40E69315C3D58143407E8E8F1667684C40E69315C3D58143401B2FDD2406674C4038D906EE407F43401B2FDD2406674C40
22411	25327	38.994168999999999	39.014336	56.815646000000001	56.804875000000003	проспект Мира	0103000020E6100000010000000500000038D906EE407F43401B2FDD2406674C4038D906EE407F43407E8E8F1667684C40E69315C3D58143407E8E8F1667684C40E69315C3D58143401B2FDD2406674C4038D906EE407F43401B2FDD2406674C40
22721	25732	38.345100000000002	38.358305000000001	57.033791000000001	57.022475	Центральная	0103000020E61000000100000005000000C0EC9E3C2C2C434022FDF675E0824C40C0EC9E3C2C2C434017F3734353844C40247F30F0DC2D434017F3734353844C40247F30F0DC2D434022FDF675E0824C40C0EC9E3C2C2C434022FDF675E0824C40
22723	25782	38.963940000000001	38.984394999999999	56.639539999999997	56.629618999999998	Октябрьская	0103000020E6100000010000000500000033A7CB62627B434059F8FA5A97504C4033A7CB62627B4340EE3D5C72DC514C4047ACC5A7007E4340EE3D5C72DC514C4047ACC5A7007E434059F8FA5A97504C4033A7CB62627B434059F8FA5A97504C40
22653	26201	39.161462	39.178485000000002	56.774687	56.766238000000001	Крутец	0103000020E61000000100000005000000FCC56CC9AA944340EA79371614624C40FCC56CC9AA94434074D190F128634C40CDE9B298D896434074D190F128634C40CDE9B298D8964340EA79371614624C40FCC56CC9AA944340EA79371614624C40
24081	50933	39.125456999999997	39.147295	56.713726000000001	56.701838000000002	Клубная	0103000020E61000000100000005000000F20698F90E904340878BDCD3D5594C40F20698F90E9043400727A25F5B5B4C40A2EE0390DA9243400727A25F5B5B4C40A2EE0390DA924340878BDCD3D5594C40F20698F90E904340878BDCD3D5594C40
22483	25817	38.514674999999997	38.531869	57.060098000000004	57.050606999999999	Школьная	0103000020E61000000100000005000000CE88D2DEE04143406EF9484A7A864C40CE88D2DEE04143400B47904AB1874C40CC608C48144443400B47904AB1874C40CC608C48144443406EF9484A7A864C40CE88D2DEE04143406EF9484A7A864C40
22654	26391	39.274999999999999	39.293298999999998	56.661388000000002	56.651522	Центральная	0103000020E610000001000000050000003333333333A34340F04FA91265534C403333333333A34340C2FBAA5CA8544C40897956D28AA54340C2FBAA5CA8544C40897956D28AA54340F04FA91265534C403333333333A34340F04FA91265534C40
24062	47634	38.688445000000002	38.712933	56.666533000000001	56.648221999999997	Центральная	0103000020E61000000100000005000000200C3CF71E5843401B4641F0F8524C40200C3CF71E584340365A0EF450554C409D9E7763415B4340365A0EF450554C409D9E7763415B43401B4641F0F8524C40200C3CF71E5843401B4641F0F8524C40
22852	25524	38.890979000000002	38.923678000000002	56.751612999999999	56.729748000000001	Советская	0103000020E610000001000000050000001E3691990B7243402429E961685D4C401E3691990B724340CD1FD3DA34604C407104A9143B764340CD1FD3DA34604C407104A9143B7643402429E961685D4C401E3691990B7243402429E961685D4C40
24071	50927	38.990107999999999	39.061641000000002	56.605960000000003	56.591678999999999	Центральная	0103000020E6100000010000000500000005C1E3DBBB7E4340705D3123BC4B4C4005C1E3DBBB7E43409357E718904D4C40DF8B2FDAE38743409357E718904D4C40DF8B2FDAE3874340705D3123BC4B4C4005C1E3DBBB7E4340705D3123BC4B4C40
22908	26473	39.221119000000002	39.244582999999999	56.579895999999998	56.563744999999997	Центральная	0103000020E610000001000000050000001AC39CA04D9C43404A24D1CB28484C401AC39CA04D9C4340658A39083A4A4C402B14E97E4E9F4340658A39083A4A4C402B14E97E4E9F43404A24D1CB28484C401AC39CA04D9C43404A24D1CB28484C40
22868	26043	38.262912999999998	38.280897000000003	56.871344999999998	56.860894999999999	Садовая	0103000020E61000000100000005000000BC581822A72143401C25AFCE316E4C40BC581822A72143403D44A33B886F4C40B345D26EF42343403D44A33B886F4C40B345D26EF42343401C25AFCE316E4C40BC581822A72143401C25AFCE316E4C40
24084	50935	40.199708000000001	40.222911000000003	58.549467999999997	58.526823	Первомайская	0103000020E61000000100000005000000F25F200890194440EBE3A1EF6E434D40F25F2008901944406919A9F754464D409775FF58881C44406919A9F754464D409775FF58881C4440EBE3A1EF6E434D40F25F200890194440EBE3A1EF6E434D40
23085	46222	40.361818	40.372444999999999	58.434753000000001	58.429721000000001	Маслова	0103000020E61000000100000005000000548D5E0D502E4440C4B3041901374D40548D5E0D502E4440406B7EFCA5374D4084471B47AC2F4440406B7EFCA5374D4084471B47AC2F4440C4B3041901374D40548D5E0D502E4440C4B3041901374D40
24083	50934	39.510170000000002	39.520842000000002	58.654366000000003	58.650415000000002	Молодежная	0103000020E610000001000000050000003EB324404DC14340F7E978CC40534D403EB324404DC14340A3CEDC43C2534D400E315EF3AAC24340A3CEDC43C2534D400E315EF3AAC24340F7E978CC40534D403EB324404DC14340F7E978CC40534D40
22607	24041	39.510969000000003	39.521650000000001	58.684787999999998	58.680301999999998	Луговая	0103000020E610000001000000050000008A22A46E67C14340A2B3CC2214574D408A22A46E67C14340BC581822A7574D40ADFA5C6DC5C24340BC581822A7574D40ADFA5C6DC5C24340A2B3CC2214574D408A22A46E67C14340A2B3CC2214574D40
22676	19330	39.888289	39.922029999999999	58.705165999999998	58.688234999999999	Школьная	0103000020E61000000100000005000000C2323674B3F14340357BA01518584D40C2323674B3F14340252026E1425A4D4027F73B1405F64340252026E1425A4D4027F73B1405F64340357BA01518584D40C2323674B3F14340357BA01518584D40
22617	19330	39.888289	39.922029999999999	58.705165999999998	58.688234999999999	Советская	0103000020E61000000100000005000000C2323674B3F14340357BA01518584D40C2323674B3F14340252026E1425A4D4027F73B1405F64340252026E1425A4D4027F73B1405F64340357BA01518584D40C2323674B3F14340357BA01518584D40
22642	24394	39.911771000000002	39.936464999999998	58.458959	58.450296000000002	Заречная	0103000020E610000001000000050000007A3881E9B4F4434083C2A04CA3394D407A3881E9B4F44340399A232BBF3A4D40A06CCA15DEF74340399A232BBF3A4D40A06CCA15DEF7434083C2A04CA3394D407A3881E9B4F4434083C2A04CA3394D40
22719	24337	39.754708999999998	39.765704999999997	58.579841000000002	58.571756000000001	Центральная	0103000020E61000000100000005000000997FF44D9AE0434059A5F44C2F494D40997FF44D9AE04340A2F0D93A384A4D401CB1169F02E24340A2F0D93A384A4D401CB1169F02E2434059A5F44C2F494D40997FF44D9AE0434059A5F44C2F494D40
23238	47468	40.205770999999999	40.222830000000002	58.383577000000002	58.378712	Мира	0103000020E610000001000000050000008CBB41B4561A4440274D83A279304D408CBB41B4561A4440B83F170D19314D40AA4885B1851C4440B83F170D19314D40AA4885B1851C4440274D83A279304D408CBB41B4561A4440274D83A279304D40
22718	46548	39.727293000000003	39.748978000000001	58.644692999999997	58.639859999999999	Центральная	0103000020E610000001000000050000000CCEE0EF17DD43406002B7EEE6514D400CCEE0EF17DD4340E57ADB4C85524D4035B6D782DEDF4340E57ADB4C85524D4035B6D782DEDF43406002B7EEE6514D400CCEE0EF17DD43406002B7EEE6514D40
24073	50929	40.438048999999999	40.448245	57.760773999999998	57.757326999999997	Комсомольская	0103000020E61000000100000005000000D38558FD113844405BB05417F0E04C40D38558FD11384440D4D2DC0A61E14C403ACC971760394440D4D2DC0A61E14C403ACC9717603944405BB05417F0E04C40D38558FD113844405BB05417F0E04C40
22776	23149	40.534886999999998	40.555008999999998	57.740074999999997	57.724775000000001	Школьная	0103000020E610000001000000050000001C075E2D77444440ADFA5C6DC5DC4C401C075E2D7744444029CB10C7BADE4C402AFEEF880A47444029CB10C7BADE4C402AFEEF880A474440ADFA5C6DC5DC4C401C075E2D77444440ADFA5C6DC5DC4C40
23234	49294	40.567667	40.595810999999998	57.681162999999998	57.670256999999999	Заводская	0103000020E610000001000000050000005C02F04FA948444021753BFBCAD54C405C02F04FA9484440641F645930D74C406CCCEB88434C4440641F645930D74C406CCCEB88434C444021753BFBCAD54C405C02F04FA948444021753BFBCAD54C40
22387	22791	40.343375000000002	40.385326999999997	57.692203999999997	57.660801999999997	Строителей	0103000020E61000000100000005000000CBA145B6F32B4440D190F12895D44C40CBA145B6F32B4440871403249AD84C4005A2276552314440871403249AD84C4005A2276552314440D190F12895D44C40CBA145B6F32B4440D190F12895D44C40
22827	22791	40.343375000000002	40.385326999999997	57.692203999999997	57.660801999999997	Пролетарская	0103000020E61000000100000005000000CBA145B6F32B4440D190F12895D44C40CBA145B6F32B4440871403249AD84C4005A2276552314440871403249AD84C4005A2276552314440D190F12895D44C40CBA145B6F32B4440D190F12895D44C40
23120	49177	40.388345000000001	40.395198999999998	57.384107	57.381419000000001	Пионерская	0103000020E610000001000000050000005648F949B531444059897956D2B04C405648F949B531444014950D6B2AB14C40B9347EE19532444014950D6B2AB14C40B9347EE19532444059897956D2B04C405648F949B531444059897956D2B04C40
22830	46033	40.515421000000003	40.539468999999997	57.649366000000001	57.638233999999997	Молодежная	0103000020E61000000100000005000000F855B950F9414440FE98D6A6B1D14C40F855B950F94144403291D26C1ED34C40581AF8510D4544403291D26C1ED34C40581AF8510D454440FE98D6A6B1D14C40F855B950F9414440FE98D6A6B1D14C40
24114	50922	40.419921000000002	40.448585999999999	57.760683	57.740175999999998	Центральная	0103000020E61000000100000005000000AAF3A8F8BF3544405DA45016BEDE4C40AAF3A8F8BF354440C4CF7F0F5EE14C40C3B81B446B394440C4CF7F0F5EE14C40C3B81B446B3944405DA45016BEDE4C40AAF3A8F8BF3544405DA45016BEDE4C40
24064	50922	40.419921000000002	40.448585999999999	57.760683	57.740175999999998	Набережная	0103000020E61000000100000005000000AAF3A8F8BF3544405DA45016BEDE4C40AAF3A8F8BF354440C4CF7F0F5EE14C40C3B81B446B394440C4CF7F0F5EE14C40C3B81B446B3944405DA45016BEDE4C40AAF3A8F8BF3544405DA45016BEDE4C40
9969	23529	40.183205999999998	40.203076000000003	57.644722999999999	57.633561	Ярославская	0103000020E610000001000000050000002A37514B73174440B282DF8618D14C402A37514B7317444050FD834886D24C401F4DF564FE19444050FD834886D24C401F4DF564FE194440B282DF8618D14C402A37514B73174440B282DF8618D14C40
24074	22631	40.262113999999997	40.271042999999999	57.501342999999999	57.497042999999998	Молодежная	0103000020E6100000010000000500000070E998F38C21444055DAE21A9FBF4C4070E998F38C2144400D8AE6012CC04C40A5677A89B12244400D8AE6012CC04C40A5677A89B122444055DAE21A9FBF4C4070E998F38C21444055DAE21A9FBF4C40
22454	50508	40.255403000000001	40.272561000000003	57.874164999999998	57.859243999999997	Давыдковская	0103000020E610000001000000050000007026A60BB120444061A417B5FBED4C407026A60BB1204440672783A3E4EF4C4021956247E3224440672783A3E4EF4C4021956247E322444061A417B5FBED4C407026A60BB120444061A417B5FBED4C40
24095	50940	40.294857	40.328139999999998	57.444535000000002	57.425136999999999	Центральная	0103000020E6100000010000000500000093FFC9DFBD254440E7A8A3E36AB64C4093FFC9DFBD254440B476DB85E6B84C403541D47D002A4440B476DB85E6B84C403541D47D002A4440E7A8A3E36AB64C4093FFC9DFBD254440E7A8A3E36AB64C40
22876	22314	38.219965000000002	38.287095999999998	57.940240000000003	57.924757999999997	переулок Клубный	0103000020E61000000100000005000000E0A128D0271C4340705B5B785EF64C40E0A128D0271C43400E32C9C859F84C40FD67CD8FBF2443400E32C9C859F84C40FD67CD8FBF244340705B5B785EF64C40E0A128D0271C4340705B5B785EF64C40
22457	22474	37.378998000000003	37.398518000000003	57.832419999999999	57.821100000000001	Ленина	0103000020E61000000100000005000000ED9FA70183B04240705F07CE19E94C40ED9FA70183B04240A64412BD8CEA4C40056F48A302B34240A64412BD8CEA4C40056F48A302B34240705F07CE19E94C40ED9FA70183B04240705F07CE19E94C40
22444	21301	38.034319000000004	38.086824999999997	57.914690999999998	57.888952000000003	Советская	0103000020E61000000100000005000000D350A390640443405EDBDB2DC9F14C40D350A3906404434007793D9814F54C40D3BCE3141D0B434007793D9814F54C40D3BCE3141D0B43405EDBDB2DC9F14C40D350A390640443405EDBDB2DC9F14C40
24135	50948	37.330983000000003	38.431545	58.210996000000002	57.690699000000002	Центральная	0103000020E610000001000000050000001844A4A65DAA4240A13028D368D84C401844A4A65DAA42401DCBBBEA011B4D404CE0D6DD3C3743401DCBBBEA011B4D404CE0D6DD3C374340A13028D368D84C401844A4A65DAA4240A13028D368D84C40
23080	49224	38.286898000000001	38.297687000000003	57.913936	57.910708	Мира	0103000020E61000000100000005000000D7A4DB12B9244340501A6A1492F44C40D7A4DB12B92443408B51D7DAFBF44C40E1B88C9B1A2643408B51D7DAFBF44C40E1B88C9B1A264340501A6A1492F44C40D7A4DB12B9244340501A6A1492F44C40
22778	21519	37.98413	38.005761	57.918582000000001	57.906883000000001	Советская	0103000020E610000001000000050000009981CAF8F7FD42403126FDBD14F44C409981CAF8F7FD4240DE58501894F54C40CF4BC5C6BC004340DE58501894F54C40CF4BC5C6BC0043403126FDBD14F44C409981CAF8F7FD42403126FDBD14F44C40
24101	50942	37.330983000000003	38.431545	58.210996000000002	57.690699000000002	3-я Вокзальная	0103000020E610000001000000050000001844A4A65DAA4240A13028D368D84C401844A4A65DAA42401DCBBBEA011B4D404CE0D6DD3C3743401DCBBBEA011B4D404CE0D6DD3C374340A13028D368D84C401844A4A65DAA4240A13028D368D84C40
22874	22143	38.18882	38.211880000000001	58.013415999999999	58.004460999999999	Центральная	0103000020E61000000100000005000000556AF6402B184340C18D942D92004D40556AF6402B1843401F9F909DB7014D40975643E21E1B43401F9F909DB7014D40975643E21E1B4340C18D942D92004D40556AF6402B184340C18D942D92004D40
22464	22007	38.112059000000002	38.135720999999997	58.083458999999998	58.064759000000002	Центральная	0103000020E610000001000000050000007A1C06F3570E4340938FDD054A084D407A1C06F3570E434047C7D5C8AE0A4D40B130444E5F11434047C7D5C8AE0A4D40B130444E5F114340938FDD054A084D407A1C06F3570E4340938FDD054A084D40
22386	5867	38.035207999999997	38.057298000000003	58.120728999999997	58.110326999999998	Центральная	0103000020E610000001000000050000005E471CB281044340D26EF4311F0E4D405E471CB281044340E256410C740F4D402810768A55074340E256410C740F4D402810768A55074340D26EF4311F0E4D405E471CB281044340D26EF4311F0E4D40
24076	50923	38.361376999999997	38.421698999999997	57.964123000000001	57.936872000000001	Линейная улица	0103000020E610000001000000050000006743FE99412E4340E144F46BEBF74C406743FE99412E43402429E96168FB4C40C1E09A3BFA3543402429E96168FB4C40C1E09A3BFA354340E144F46BEBF74C406743FE99412E4340E144F46BEBF74C40
24066	50923	38.361376999999997	38.421698999999997	57.964123000000001	57.936872000000001	Линейная	0103000020E610000001000000050000006743FE99412E4340E144F46BEBF74C406743FE99412E43402429E96168FB4C40C1E09A3BFA3543402429E96168FB4C40C1E09A3BFA354340E144F46BEBF74C406743FE99412E4340E144F46BEBF74C40
23077	21046	37.927967000000002	37.950201	57.732785999999997	57.721127000000003	Центральная	0103000020E610000001000000050000003562669FC7F642409DA1B8E34DDC4C403562669FC7F64240BB7B80EECBDD4C4031D0B52FA0F94240BB7B80EECBDD4C4031D0B52FA0F942409DA1B8E34DDC4C403562669FC7F642409DA1B8E34DDC4C40
23182	21218	38.430233000000001	38.481006000000001	57.802022999999998	57.773822000000003	Угличская улица	0103000020E610000001000000050000007A54FCDF1137434071766B990CE34C407A54FCDF11374340E5D18DB0A8E64C400397C79A913D4340E5D18DB0A8E64C400397C79A913D434071766B990CE34C407A54FCDF1137434071766B990CE34C40
22813	21218	38.430233000000001	38.481006000000001	57.802022999999998	57.773822000000003	К.Либкнехта	0103000020E610000001000000050000007A54FCDF1137434071766B990CE34C407A54FCDF11374340E5D18DB0A8E64C400397C79A913D4340E5D18DB0A8E64C400397C79A913D434071766B990CE34C407A54FCDF1137434071766B990CE34C40
22532	21218	38.430233000000001	38.481006000000001	57.802022999999998	57.773822000000003	Загородная	0103000020E610000001000000050000007A54FCDF1137434071766B990CE34C407A54FCDF11374340E5D18DB0A8E64C400397C79A913D4340E5D18DB0A8E64C400397C79A913D434071766B990CE34C407A54FCDF1137434071766B990CE34C40
23250	21218	38.430233000000001	38.481006000000001	57.802022999999998	57.773822000000003	 Карла Либкнехта	0103000020E610000001000000050000007A54FCDF1137434071766B990CE34C407A54FCDF11374340E5D18DB0A8E64C400397C79A913D4340E5D18DB0A8E64C400397C79A913D434071766B990CE34C407A54FCDF1137434071766B990CE34C40
23106	49124	40.526415999999998	40.533575999999996	58.293320000000001	58.290982999999997	Юбилейная	0103000020E61000000100000005000000AA0B789961434440925852EE3E254D40AA0B789961434440A1A17F828B254D401AF7E6374C444440A1A17F828B254D401AF7E6374C444440925852EE3E254D40AA0B789961434440925852EE3E254D40
22807	5841	40.785184999999998	40.797393	58.344759000000003	58.337744999999998	Молодежная	0103000020E61000000100000005000000A6272CF1806444409AB1683A3B2B4D40A6272CF18064444037001B10212C4D4098874CF91066444037001B10212C4D4098874CF9106644409AB1683A3B2B4D40A6272CF1806444409AB1683A3B2B4D40
22892	17881	40.662537999999998	40.716256999999999	58.370806999999999	58.331031000000003	Трефолева	0103000020E61000000100000005000000BA2D910BCE544440297B4B395F2A4D40BA2D910BCE5444405E10919A762F4D40FA43334FAE5B44405E10919A762F4D40FA43334FAE5B4440297B4B395F2A4D40BA2D910BCE544440297B4B395F2A4D40
22545	17881	40.662537999999998	40.716256999999999	58.370806999999999	58.331031000000003	Советская	0103000020E61000000100000005000000BA2D910BCE544440297B4B395F2A4D40BA2D910BCE5444405E10919A762F4D40FA43334FAE5B44405E10919A762F4D40FA43334FAE5B4440297B4B395F2A4D40BA2D910BCE544440297B4B395F2A4D40
22801	17881	40.662537999999998	40.716256999999999	58.370806999999999	58.331031000000003	Октябрьская	0103000020E61000000100000005000000BA2D910BCE544440297B4B395F2A4D40BA2D910BCE5444405E10919A762F4D40FA43334FAE5B44405E10919A762F4D40FA43334FAE5B4440297B4B395F2A4D40BA2D910BCE544440297B4B395F2A4D40
22927	17881	40.662537999999998	40.716256999999999	58.370806999999999	58.331031000000003	Набережная реки Обноры	0103000020E61000000100000005000000BA2D910BCE544440297B4B395F2A4D40BA2D910BCE5444405E10919A762F4D40FA43334FAE5B44405E10919A762F4D40FA43334FAE5B4440297B4B395F2A4D40BA2D910BCE544440297B4B395F2A4D40
22422	18087	39.604143000000001	39.630319999999998	58.204954999999998	58.195076999999998	Нагорная	0103000020E61000000100000005000000BD8DCD8E54CD4340D4997B48F8184D40BD8DCD8E54CD43406A1327F73B1A4D40E2016553AED043406A1327F73B1A4D40E2016553AED04340D4997B48F8184D40BD8DCD8E54CD4340D4997B48F8184D40
22518	18865	40.400965999999997	40.548029999999997	57.993377000000002	57.976171000000001	Старая	0103000020E610000001000000050000006A6798DA52334440DD26DC2BF3FC4C406A6798DA523344409FCC3FFA26FF4C400A9DD7D8254644409FCC3FFA26FF4C400A9DD7D825464440DD26DC2BF3FC4C406A6798DA52334440DD26DC2BF3FC4C40
22588	17993	39.974114	40.017116000000001	58.305408	58.296796000000001	Школьная	0103000020E61000000100000005000000B2497EC4AFFC4340B4CA4C69FD254D40B2497EC4AFFC4340E8F7FD9B17274D40821E6ADB30024440E8F7FD9B17274D40821E6ADB30024440B4CA4C69FD254D40B2497EC4AFFC4340B4CA4C69FD254D40
22740	19012	40.440922999999998	40.459887000000002	58.050736000000001	58.041038	Покровская	0103000020E61000000100000005000000F086342A7038444056F2B1BB40054D40F086342A703844406C5D6A847E064D40836DC493DD3A44406C5D6A847E064D40836DC493DD3A444056F2B1BB40054D40F086342A7038444056F2B1BB40054D40
24103	50943	39.515093	40.692191000000001	58.393996999999999	57.872998000000003	Набережная	0103000020E6100000010000000500000003B34291EEC1434099BC0166BEEF4C4003B34291EEC143406EDC627E6E324D40F3CAF5B6995844406EDC627E6E324D40F3CAF5B69958444099BC0166BEEF4C4003B34291EEC1434099BC0166BEEF4C40
22424	18271	39.947127999999999	39.964053	58.139403999999999	58.125933000000003	Рабочая	0103000020E610000001000000050000001D90847D3BF943405C3E92921E104D401D90847D3BF943403E7782FDD7114D402B4EB51666FB43403E7782FDD7114D402B4EB51666FB43405C3E92921E104D401D90847D3BF943405C3E92921E104D40
22593	50524	40.195673999999997	40.206149000000003	57.916578999999999	57.912100000000002	Мира	0103000020E61000000100000005000000B8567BD80B1944403F575BB1BFF44C40B8567BD80B194440A699EE7552F54C40338D2617631A4440A699EE7552F54C40338D2617631A44403F575BB1BFF44C40B8567BD80B1944403F575BB1BFF44C40
22857	18171	39.884714000000002	39.904854	58.214452000000001	58.204951000000001	Школьная	0103000020E610000001000000050000001C28F04E3EF14340292499D53B1A4D401C28F04E3EF14340E947C329731B4D40D0D38041D2F34340E947C329731B4D40D0D38041D2F34340292499D53B1A4D401C28F04E3EF14340292499D53B1A4D40
22921	18375	40.004243000000002	40.030383999999998	58.004474999999999	57.996344000000001	Центральная	0103000020E61000000100000005000000541EDD088B0044406DC83F3388FF4C40541EDD088B004440265305A392004D402C29779FE3034440265305A392004D402C29779FE30344406DC83F3388FF4C40541EDD088B0044406DC83F3388FF4C40
22669	18909	40.428203000000003	40.456885999999997	58.012127999999997	57.998604999999998	Ленина	0103000020E6100000010000000500000049861C5BCF364440A04FE449D2FF4C4049861C5BCF364440D5AE09698D014D4008008E3D7B3A4440D5AE09698D014D4008008E3D7B3A4440A04FE449D2FF4C4049861C5BCF364440A04FE449D2FF4C40
22673	19075	40.353040999999997	40.372354999999999	58.087484000000003	58.081389000000001	Школьная	0103000020E61000000100000005000000D5928E72302D444088A06AF46A0A4D40D5928E72302D44402E76FBAC320B4D4044C02154A92F44402E76FBAC320B4D4044C02154A92F444088A06AF46A0A4D40D5928E72302D444088A06AF46A0A4D40
22508	18331	39.891658	39.914008000000003	58.040114000000003	58.030937000000002	Почтовая	0103000020E61000000100000005000000BF9B6ED921F24340419E5DBEF5034D40BF9B6ED921F243404E0E9F7422054D402524D236FEF443404E0E9F7422054D402524D236FEF44340419E5DBEF5034D40BF9B6ED921F24340419E5DBEF5034D40
22854	17947	40.191083999999996	40.203687000000002	58.267195000000001	58.261088000000001	Центральная	0103000020E61000000100000005000000F964C5707518444064B0E2546B214D40F964C57075184440CE531D7233224D4068CF656A121A4440CE531D7233224D4068CF656A121A444064B0E2546B214D40F964C5707518444064B0E2546B214D40
22875	17785	40.278382000000001	40.305314000000003	58.255132000000003	58.243642000000001	Центральная	0103000020E61000000100000005000000C5E57805A22344404DF73AA92F1F4D40C5E57805A2234440E014562AA8204D406781768714274440E014562AA8204D4067817687142744404DF73AA92F1F4D40C5E57805A22344404DF73AA92F1F4D40
22507	18232	39.841135999999999	39.866253	58.135798000000001	58.127321000000002	Молодежная	0103000020E610000001000000050000007FBE2D58AAEB4340098CF50D4C104D407FBE2D58AAEB43405D6E30D461114D40EC87D860E1EE43405D6E30D461114D40EC87D860E1EE4340098CF50D4C104D407FBE2D58AAEB4340098CF50D4C104D40
22914	17749	40.280053000000002	40.294587999999997	58.163120999999997	58.157342999999997	Молодёжная	0103000020E61000000100000005000000C712D6C6D823444094A0BFD023144D40C712D6C6D823444039252026E1144D40A3E5400FB525444039252026E1144D40A3E5400FB525444094A0BFD023144D40C712D6C6D823444094A0BFD023144D40
22656	17844	40.191370999999997	40.22813	58.317155999999997	58.303832999999997	Вологодская	0103000020E610000001000000050000008F334DD87E1844400839EFFFE3264D408F334DD87E18444076DD5B9198284D40459E245D331D444076DD5B9198284D40459E245D331D44400839EFFFE3264D408F334DD87E1844400839EFFFE3264D40
22795	18802	40.388883999999997	40.399349000000001	57.963206999999997	57.958174	Центральная	0103000020E6100000010000000500000005F86EF3C631444052F01472A5FA4C4005F86EF3C63144409E23F25D4AFB4C405C5837DE1D3344409E23F25D4AFB4C405C5837DE1D33444052F01472A5FA4C4005F86EF3C631444052F01472A5FA4C40
22589	18545	40.124293999999999	40.254818999999998	58.140093	58.110351000000001	Ярославская	0103000020E61000000100000005000000658BA4DDE80F44405B0A48FB1F0E4D40658BA4DDE80F444003B34291EE114D4020B3B3E89D20444003B34291EE114D4020B3B3E89D2044405B0A48FB1F0E4D40658BA4DDE80F44405B0A48FB1F0E4D40
22732	18441	40.007494999999999	40.027644000000002	57.970205	57.957166999999998	Центральная	0103000020E6100000010000000500000017F19D98F5004440BCE7C07284FA4C4017F19D98F500444035B56CAD2FFC4C401FF7ADD68903444035B56CAD2FFC4C401FF7ADD689034440BCE7C07284FA4C4017F19D98F5004440BCE7C07284FA4C40
24057	47745	40.363146999999998	40.373873000000003	57.914642999999998	57.906619999999997	Советская	0103000020E61000000100000005000000FC51D4997B2E444023F3C81F0CF44C40FC51D4997B2E4440F641960513F54C40C0ED0912DB2F4440F641960513F54C40C0ED0912DB2F444023F3C81F0CF44C40FC51D4997B2E444023F3C81F0CF44C40
22799	18970	40.344444000000003	40.369560999999997	58.038297999999998	58.029859999999999	Южная	0103000020E61000000100000005000000D7A6B1BD162C4440B2BAD573D2034D40D7A6B1BD162C444048C0E8F2E6044D4043705CC64D2F444048C0E8F2E6044D4043705CC64D2F4440B2BAD573D2034D40D7A6B1BD162C4440B2BAD573D2034D40
22855	18044	39.803066000000001	39.821148999999998	58.290647	58.286138999999999	Молодежная	0103000020E61000000100000005000000C843DFDDCAE64340198EE733A0244D40C843DFDDCAE643401BD7BFEB33254D40511212691BE943401BD7BFEB33254D40511212691BE94340198EE733A0244D40C843DFDDCAE64340198EE733A0244D40
22397	18658	40.165292999999998	40.182819000000002	57.999935000000001	57.990304999999999	Южная	0103000020E61000000100000005000000FDA02E52281544405B087250C2FE4C40FDA02E52281544401990BDDEFDFF4C40310BED9C661744401990BDDEFDFF4C40310BED9C661744405B087250C2FE4C40FDA02E52281544405B087250C2FE4C40
22729	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	площадь Советская	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22717	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	площадь Соборная	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22692	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	Ярославская	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22793	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	Урицкого	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22907	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	Заводская	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22923	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	Гражданская	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22911	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	Вятская	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22585	17191	40.137886000000002	40.211530000000003	58.210939000000003	58.162964000000002	Володарского	0103000020E61000000100000005000000C3499A3FA611444072361D01DC144D40C3499A3FA6114440B939950C001B4D40BB0F406A131B4440B939950C001B4D40BB0F406A131B444072361D01DC144D40C3499A3FA611444072361D01DC144D40
22655	17679	40.130915000000002	40.158501999999999	58.193986000000002	58.175333999999999	Гагарина	0103000020E6100000010000000500000026C79DD2C11044403DF0315871164D4026C79DD2C1104440E1F08288D4184D40E02C25CB49144440E1F08288D4184D40E02C25CB491444403DF0315871164D4026C79DD2C11044403DF0315871164D40
22730	18150	39.758913	39.774265999999997	58.182290999999999	58.172786000000002	Центральная	0103000020E610000001000000050000002FC1A90F24E14340749A05DA1D164D402FC1A90F24E1434075ADBD4F55174D40CE33F6251BE3434075ADBD4F55174D40CE33F6251BE34340749A05DA1D164D402FC1A90F24E14340749A05DA1D164D40
24052	47121	40.151549000000003	40.162768999999997	58.094718999999998	58.090766000000002	Лапшина	0103000020E61000000100000005000000EA5E27F5651344405CCB64389E0B4D40EA5E27F565134440A8A78FC01F0C4D40BCE6559DD5144440A8A78FC01F0C4D40BCE6559DD51444405CCB64389E0B4D40EA5E27F5651344405CCB64389E0B4D40
22843	18481	40.088146000000002	40.107460000000003	58.090623999999998	58.080722000000002	Лесная	0103000020E61000000100000005000000F9A23D5E480B4440AB083719550A4D40F9A23D5E480B4440C91D3691990B4D4068D0D03FC10D4440C91D3691990B4D4068D0D03FC10D4440AB083719550A4D40F9A23D5E480B4440AB083719550A4D40
22583	17026	39.636418999999997	39.657744999999998	57.428243000000002	57.416384000000001	Центральная	0103000020E61000000100000005000000C9C6832D76D14340F14927124CB54C40C9C6832D76D14340D7DEA7AAD0B64C40C30DF8FC30D44340D7DEA7AAD0B64C40C30DF8FC30D44340F14927124CB54C40C9C6832D76D14340F14927124CB54C40
22713	17089	39.587021	39.599983999999999	57.364716000000001	57.357531000000002	Центральная	0103000020E6100000010000000500000059880E8123CB434031276893C3AD4C4059880E8123CB4340FA298E03AFAE4C40C70F9546CCCC4340FA298E03AFAE4C40C70F9546CCCC434031276893C3AD4C4059880E8123CB434031276893C3AD4C40
22581	16807	40.109921	40.122613999999999	57.229773000000002	57.223911999999999	Центральная	0103000020E6100000010000000500000062122EE4110E44404A97FE25A99C4C4062122EE4110E44407D40A033699D4C401004C8D0B10F44407D40A033699D4C401004C8D0B10F44404A97FE25A99C4C4062122EE4110E44404A97FE25A99C4C40
22414	16743	40.043284	40.068446000000002	57.240367999999997	57.229801999999999	Центральная	0103000020E61000000100000005000000543882548A0544401747E5266A9D4C40543882548A054440A180ED60C49E4C4061C5A9D6C2084440A180ED60C49E4C4061C5A9D6C20844401747E5266A9D4C40543882548A0544401747E5266A9D4C40
22724	16877	39.931192000000003	39.950775999999998	57.310426999999997	57.303809999999999	Школьная	0103000020E61000000100000005000000FF25A94C31F743405019FF3EE3A64C40FF25A94C31F74340CF656A12BCA74C402DE92807B3F94340CF656A12BCA74C402DE92807B3F943405019FF3EE3A64C40FF25A94C31F743405019FF3EE3A64C40
22580	16714	40.161600999999997	40.187112999999997	57.303790999999997	57.289755999999997	Центральная	0103000020E610000001000000050000001D007157AF144440EEE87FB916A54C401D007157AF144440D9E89C9FE2A64C4006D49B51F3174440D9E89C9FE2A64C4006D49B51F3174440EEE87FB916A54C401D007157AF144440EEE87FB916A54C40
22500	16954	39.990436000000003	40.005823999999997	57.378498	57.373845000000003	Школьная	0103000020E61000000100000005000000FA635A9BC6FE4340F6622827DAAF4C40FA635A9BC6FE4340FBCC599F72B04C4015C440D7BE004440FBCC599F72B04C4015C440D7BE004440F6622827DAAF4C40FA635A9BC6FE4340F6622827DAAF4C40
22859	16389	39.767994999999999	39.781066000000003	57.401077999999998	57.38205	Клубная	0103000020E61000000100000005000000EA3E00A94DE24340E9B7AF03E7B04C40EA3E00A94DE2434092921E8656B34C403F027FF8F9E3434092921E8656B34C403F027FF8F9E34340E9B7AF03E7B04C40EA3E00A94DE24340E9B7AF03E7B04C40
22856	16271	39.812902000000001	39.823529000000001	57.335467999999999	57.328229	Молодежная	0103000020E610000001000000050000002F6D382C0DE84340A54C6A6803AA4C402F6D382C0DE84340616D8C9DF0AA4C405F27F56569E94340616D8C9DF0AA4C405F27F56569E94340A54C6A6803AA4C402F6D382C0DE84340A54C6A6803AA4C40
22418	16214	39.716898999999998	39.740848	57.329118000000001	57.319623	Центральная	0103000020E610000001000000050000007EC4AF58C3DB434053060E68E9A84C407EC4AF58C3DB43403143E38920AA4C404CA7751BD4DE43403143E38920AA4C404CA7751BD4DE434053060E68E9A84C407EC4AF58C3DB434053060E68E9A84C40
22792	50566	40.353732999999998	40.370548999999997	57.303538000000003	57.293438000000002	Школьная	0103000020E610000001000000050000000B42791F472D4440ABB35A608FA54C400B42791F472D4440F08B4B55DAA64C4062484E266E2F4440F08B4B55DAA64C4062484E266E2F4440ABB35A608FA54C400B42791F472D4440ABB35A608FA54C40
22652	16857	40.189880000000002	40.208672999999997	57.238736000000003	57.228565000000003	Центральная	0103000020E610000001000000050000000E15E3FC4D1844405001309E419D4C400E15E3FC4D1844405E30B8E68E9E4C407347FFCBB51A44405E30B8E68E9E4C407347FFCBB51A44405001309E419D4C400E15E3FC4D1844405001309E419D4C40
22850	16630	40.255510999999998	40.273603000000001	57.340122000000001	57.335904999999997	Колхозная	0103000020E6100000010000000500000056629E95B42044400CC85EEFFEAA4C4056629E95B42044403753211E89AB4C40338B506C052344403753211E89AB4C40338B506C052344400CC85EEFFEAA4C4056629E95B42044400CC85EEFFEAA4C40
22858	16313	39.743813000000003	39.756371000000001	57.273603999999999	57.264074999999998	Урицкого	0103000020E610000001000000050000007AABAE4335DF43407958A835CDA14C407AABAE4335DF43400307B47405A34C404852D2C3D0E043400307B47405A34C404852D2C3D0E043407958A835CDA14C407AABAE4335DF43407958A835CDA14C40
22663	17129	39.417077999999997	39.438709000000003	57.423091999999997	57.413378999999999	Тенистая	0103000020E61000000100000005000000C7F0D8CF62B5434035ED629AE9B44C40C7F0D8CF62B543408099EFE027B64C40FEBAD39D27B843408099EFE027B64C40FEBAD39D27B8434035ED629AE9B44C40C7F0D8CF62B5434035ED629AE9B44C40
22416	17001	39.907305999999998	39.920341000000001	57.414712000000002	57.403595000000003	Центральная	0103000020E6100000010000000500000077BB5E9A22F4434021EA3E00A9B34C4077BB5E9A22F443401FA1664815B54C407F15E0BBCDF543401FA1664815B54C407F15E0BBCDF5434021EA3E00A9B34C4077BB5E9A22F4434021EA3E00A9B34C40
22478	15842	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	Юбилейный проезд	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
22448	15842	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	Чернышевского	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
22407	15842	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	Спортивная	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
22905	15842	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	Советская	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
22582	15842	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	Клубная	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
22445	15842	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	Кирова	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
22754	15842	39.808329999999998	39.885916999999999	57.331684000000003	57.287211999999997	Калинина	0103000020E610000001000000050000001630815B77E743406682E15CC3A44C401630815B77E74340A14D0E9F74AA4C4037FC6EBA65F14340A14D0E9F74AA4C4037FC6EBA65F143406682E15CC3A44C401630815B77E743406682E15CC3A44C40
22410	16470	39.759425	39.788989000000001	57.359423999999997	57.342005999999998	Розы Люксембург	0103000020E61000000100000005000000E561A1D634E14340948444DAC6AB4C40E561A1D634E14340E1B20A9B01AE4C40AEF36F97FDE44340E1B20A9B01AE4C40AEF36F97FDE44340948444DAC6AB4C40E561A1D634E14340948444DAC6AB4C40
22903	16470	39.759425	39.788989000000001	57.359423999999997	57.342005999999998	Некрасовская	0103000020E61000000100000005000000E561A1D634E14340948444DAC6AB4C40E561A1D634E14340E1B20A9B01AE4C40AEF36F97FDE44340E1B20A9B01AE4C40AEF36F97FDE44340948444DAC6AB4C40E561A1D634E14340948444DAC6AB4C40
22662	14284	37.529933	37.556676000000003	58.345761000000003	58.337504000000003	Молодёжная	0103000020E610000001000000050000001C0934D8D4C342407522C154332B4D401C0934D8D4C34240BB9D7DE5412C4D40EB3BBF2841C74240BB9D7DE5412C4D40EB3BBF2841C742407522C154332B4D401C0934D8D4C342407522C154332B4D40
22816	47668	37.63738	37.678486999999997	58.405602999999999	58.382666	Михайловская	0103000020E61000000100000005000000EF8FF7AA95D1424044A51133FB304D40EF8FF7AA95D142406A1492CCEA334D406DE179A9D8D642406A1492CCEA334D406DE179A9D8D6424044A51133FB304D40EF8FF7AA95D1424044A51133FB304D40
22612	15757	37.841397000000001	37.887273999999998	58.311870999999996	58.282953999999997	Республиканская	0103000020E61000000100000005000000ECF99AE5B2EB4240DD2230D637244D40ECF99AE5B2EB424010C99063EB274D40A94BC63192F1424010C99063EB274D40A94BC63192F14240DD2230D637244D40ECF99AE5B2EB4240DD2230D637244D40
22626	14077	39.293604000000002	39.307913999999997	57.360585	57.350588000000002	Центральная	0103000020E61000000100000005000000C6FCDCD094A543405E2F4D11E0AC4C40C6FCDCD094A54340CE3637A627AE4C4082FDD7B969A74340CE3637A627AE4C4082FDD7B969A743405E2F4D11E0AC4C40C6FCDCD094A543405E2F4D11E0AC4C40
22840	14508	39.070894000000003	39.086559999999999	57.423295000000003	57.411977999999998	Транспортная	0103000020E61000000100000005000000C7BDF90D13894340F355F2B1BBB44C40C7BDF90D13894340B9C7D2872EB64C402592E865148B4340B9C7D2872EB64C402592E865148B4340F355F2B1BBB44C40C7BDF90D13894340F355F2B1BBB44C40
22404	15014	38.810580000000002	38.822833000000003	57.170707	57.164490000000001	Транспортная	0103000020E610000001000000050000005665DF15C1674340704221020E954C405665DF15C167434061191BBAD9954C40E8887C975269434061191BBAD9954C40E8887C9752694340704221020E954C405665DF15C1674340704221020E954C40
22640	14895	39.092058000000002	39.099981	57.198003999999997	57.190806000000002	Центральная	0103000020E61000000100000005000000E7AA798EC88B4340B7F0BC546C984C40E7AA798EC88B4340143DF03158994C40569C6A2DCC8C4340143DF03158994C40569C6A2DCC8C4340B7F0BC546C984C40E7AA798EC88B4340B7F0BC546C984C40
24122	50946	39.100107000000001	39.107787999999999	57.462184999999998	57.455537999999997	Лесная	0103000020E61000000100000005000000E38C614ED08C4340E90AB6114FBA4C40E38C614ED08C4340D3D9C9E028BB4C405C7347FFCB8D4340D3D9C9E028BB4C405C7347FFCB8D4340E90AB6114FBA4C40E38C614ED08C4340E90AB6114FBA4C40
22703	14305	\N	\N	\N	\N	Верхняя	\N
22477	14920	38.975565000000003	38.991104999999997	57.152090999999999	57.145954000000003	Клубная	0103000020E61000000100000005000000A60F5D50DF7C4340365CE49EAE924C40A60F5D50DF7C43400A82C7B777934C4077F35487DC7E43400A82C7B777934C4077F35487DC7E4340365CE49EAE924C40A60F5D50DF7C4340365CE49EAE924C40
22627	14443	38.9529	38.974837000000001	57.466227000000003	57.455813999999997	Школьная	0103000020E61000000100000005000000E02D90A0F87943408B87F71C58BA4C40E02D90A0F879434090C18A53ADBB4C4023F77475C77C434090C18A53ADBB4C4023F77475C77C43408B87F71C58BA4C40E02D90A0F87943408B87F71C58BA4C40
22833	14224	39.004947999999999	39.015279	57.331114999999997	57.318350000000002	Советская	0103000020E610000001000000050000001E17D522A28043403F575BB1BFA84C401E17D522A2804340861BF0F961AA4C4065A88AA9F4814340861BF0F961AA4C4065A88AA9F48143403F575BB1BFA84C401E17D522A28043403F575BB1BFA84C40
22886	5557	39.183363	39.201248	57.230918000000003	57.223571	переулок Луговой	0103000020E61000000100000005000000F225547078974340C1AA7AF99D9C4C40F225547078974340640795B88E9D4C405531957EC2994340640795B88E9D4C405531957EC2994340C1AA7AF99D9C4C40F225547078974340C1AA7AF99D9C4C40
22842	14654	38.774216000000003	38.784457000000003	57.217548000000001	57.208516000000003	Красная	0103000020E610000001000000050000001D05888219634340AC58FCA6B09A4C401D05888219634340B5A7E49CD89B4C40240F441669644340B5A7E49CD89B4C40240F441669644340AC58FCA6B09A4C401D05888219634340AC58FCA6B09A4C40
24086	50936	38.960976000000002	38.973274000000004	57.201309999999999	57.195945999999999	Новая	0103000020E61000000100000005000000D61EF642017B434019E42EC214994C40D61EF642017B4340CB2DAD86C4994C400806103E947C4340CB2DAD86C4994C400806103E947C434019E42EC214994C40D61EF642017B434019E42EC214994C40
22777	13992	38.752746000000002	38.769266000000002	57.120894999999997	57.113731000000001	Центральная	0103000020E61000000100000005000000F0181EFB596043404CC5C6BC8E8E4C40F0181EFB59604340FD9FC37C798F4C405EF6EB4E77624340FD9FC37C798F4C405EF6EB4E776243404CC5C6BC8E8E4C40F0181EFB596043404CC5C6BC8E8E4C40
22739	14594	38.740924999999997	38.758189999999999	57.243791999999999	57.232832999999999	Липовая	0103000020E61000000100000005000000F7E461A1D65E4340FC36C478CD9D4C40F7E461A1D65E434062838593349F4C40BE13B35E0C61434062838593349F4C40BE13B35E0C614340FC36C478CD9D4C40F7E461A1D65E4340FC36C478CD9D4C40
22888	14428	39.130119999999998	39.151651999999999	57.373038999999999	57.351666000000002	Советская	0103000020E610000001000000050000001B47ACC5A7904340BD8E386403AD4C401B47ACC5A7904340F790F0BDBFAF4C40BE2F2E5569934340F790F0BDBFAF4C40BE2F2E5569934340BD8E386403AD4C401B47ACC5A7904340BD8E386403AD4C40
23123	46369	39.233417000000003	39.242409000000002	57.362512000000002	57.359983	Советская	0103000020E610000001000000050000004CAAB69BE09D4340D80E46EC13AE4C404CAAB69BE09D43402B3410CB66AE4C40C7A01342079F43402B3410CB66AE4C40C7A01342079F4340D80E46EC13AE4C404CAAB69BE09D4340D80E46EC13AE4C40
24061	46369	39.233417000000003	39.242409000000002	57.362512000000002	57.359983	Заречная	0103000020E610000001000000050000004CAAB69BE09D4340D80E46EC13AE4C404CAAB69BE09D43402B3410CB66AE4C40C7A01342079F43402B3410CB66AE4C40C7A01342079F4340D80E46EC13AE4C404CAAB69BE09D4340D80E46EC13AE4C40
23088	46369	39.233417000000003	39.242409000000002	57.362512000000002	57.359983	 Ленина	0103000020E610000001000000050000004CAAB69BE09D4340D80E46EC13AE4C404CAAB69BE09D43402B3410CB66AE4C40C7A01342079F43402B3410CB66AE4C40C7A01342079F4340D80E46EC13AE4C404CAAB69BE09D4340D80E46EC13AE4C40
22831	14143	39.120553000000001	39.176679	57.274850000000001	57.248710000000003	Победы	0103000020E61000000100000005000000A437DC476E8F43401618B2BAD59F4C40A437DC476E8F43401EA7E8482EA34C40EB71DF6A9D9643401EA7E8482EA34C40EB71DF6A9D9643401618B2BAD59F4C40A437DC476E8F43401618B2BAD59F4C40
22702	14143	39.120553000000001	39.176679	57.274850000000001	57.248710000000003	Первомайская	0103000020E61000000100000005000000A437DC476E8F43401618B2BAD59F4C40A437DC476E8F43401EA7E8482EA34C40EB71DF6A9D9643401EA7E8482EA34C40EB71DF6A9D9643401618B2BAD59F4C40A437DC476E8F43401618B2BAD59F4C40
22893	14984	38.890413000000002	38.944788000000003	57.230347999999999	57.150905000000002	Транспортная	0103000020E6100000010000000500000075779D0DF9714340C5E6E3DA50934C4075779D0DF97143407959130B7C9D4C409ED32CD0EE7843407959130B7C9D4C409ED32CD0EE784340C5E6E3DA50934C4075779D0DF9714340C5E6E3DA50934C40
22461	14022	39.020569999999999	39.247394999999997	57.313265999999999	57.196649000000001	Крестьянская	0103000020E61000000100000005000000ADA3AA09A282434043E55FCB2B994C40ADA3AA09A28243407079AC1919A84C40D218ADA3AA9F43407079AC1919A84C40D218ADA3AA9F434043E55FCB2B994C40ADA3AA09A282434043E55FCB2B994C40
22546	13305	39.316133999999998	39.337316000000001	57.771920999999999	57.764567	Мира	0103000020E61000000100000005000000AB93331477A84340E84CDA54DDE14C40AB93331477A843403D0CAD4ECEE24C407235B22B2DAB43403D0CAD4ECEE24C407235B22B2DAB4340E84CDA54DDE14C40AB93331477A84340E84CDA54DDE14C40
22634	13933	39.164102999999997	39.172826000000001	57.675170999999999	57.671581000000003	Школьная	0103000020E610000001000000050000007616BD5301954340B8CEBF5DF6D54C407616BD5301954340931ADA006CD64C4002F390291F964340931ADA006CD64C4002F390291F964340B8CEBF5DF6D54C407616BD5301954340B8CEBF5DF6D54C40
22433	47329	38.662951	38.668025999999998	57.719493	57.716800999999997	Центральная	0103000020E61000000100000005000000DDEC0F94DB544340BB5E9A22C0DB4C40DDEC0F94DB544340B859BC5818DC4C4058703FE081554340B859BC5818DC4C4058703FE081554340BB5E9A22C0DB4C40DDEC0F94DB544340BB5E9A22C0DB4C40
22458	13577	38.981771999999999	38.997807000000002	57.814033999999999	57.794440000000002	Зеленая	0103000020E61000000100000005000000731074B4AA7D43402F51BD35B0E54C40731074B4AA7D434081EA1F4432E84C40255CC823B87F434081EA1F4432E84C40255CC823B87F43402F51BD35B0E54C40731074B4AA7D43402F51BD35B0E54C40
22885	13874	\N	\N	\N	\N	Октябрьская	\N
22884	13723	39.127325999999996	39.141789000000003	57.700040000000001	57.690905000000001	Мира	0103000020E610000001000000050000001AF7E6374C9043404AD235936FD84C401AF7E6374C90434028F224E99AD94C405EF756242692434028F224E99AD94C405EF75624269243404AD235936FD84C401AF7E6374C9043404AD235936FD84C40
22700	13432	38.918152999999997	38.943486	57.764135000000003	57.750560999999998	Рабочая	0103000020E61000000100000005000000B5DC9909867543409753026212E04C40B5DC9909867543404F5DF92CCFE14C40EF1D3526C47843404F5DF92CCFE14C40EF1D3526C47843409753026212E04C40B5DC9909867543409753026212E04C40
22774	13651	38.900419999999997	38.914864999999999	57.611215999999999	57.603341999999998	А.В.Романова	0103000020E6100000010000000500000008556AF640734340D026874F3ACD4C4008556AF6407343405E656D533CCE4C40A5A0DB4B1A7543405E656D533CCE4C40A5A0DB4B1A754340D026874F3ACD4C4008556AF640734340D026874F3ACD4C40
22752	13452	39.272395000000003	39.301859999999998	57.787229000000004	57.764850000000003	Мира	0103000020E61000000100000005000000064CE0D6DDA243403D2CD49AE6E14C40064CE0D6DDA243403DBB7CEBC3E44C403BFC3559A3A643403DBB7CEBC3E44C403BFC3559A3A643403D2CD49AE6E14C40064CE0D6DDA243403D2CD49AE6E14C40
22879	13510	39.074649000000001	39.093764999999998	57.822572000000001	57.811584000000003	Молодежная	0103000020E61000000100000005000000EDD632198E8943407BFA08FCE1E74C40EDD632198E8943407B4D0F0A4AE94C403541D47D008C43407B4D0F0A4AE94C403541D47D008C43407BFA08FCE1E74C40EDD632198E8943407BFA08FCE1E74C40
22760	13378	38.776767	38.783810000000003	57.596643999999998	57.59252	Челюскинцев	0103000020E6100000010000000500000057CEDE196D634340EB1C03B2D7CB4C4057CEDE196D63434064ADA1D45ECC4C408E23D6E25364434064ADA1D45ECC4C408E23D6E253644340EB1C03B2D7CB4C4057CEDE196D634340EB1C03B2D7CB4C40
22828	13378	38.776767	38.783810000000003	57.596643999999998	57.59252	Заречная	0103000020E6100000010000000500000057CEDE196D634340EB1C03B2D7CB4C4057CEDE196D63434064ADA1D45ECC4C408E23D6E25364434064ADA1D45ECC4C408E23D6E253644340EB1C03B2D7CB4C4057CEDE196D634340EB1C03B2D7CB4C40
23094	48967	39.116762000000001	39.126086000000001	57.715983999999999	57.712575999999999	Советская	0103000020E6100000010000000500000031B5A50EF28E43400EF5BBB035DB4C4031B5A50EF28E4340C93A1C5DA5DB4C40E23D079623904340C93A1C5DA5DB4C40E23D0796239043400EF5BBB035DB4C4031B5A50EF28E43400EF5BBB035DB4C40
75441	60607	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	Интернациональная улица	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
75277	60512	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	П.Смидовича	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
75112	60512	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	Машиностроителей	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
75108	60511	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Учебная	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
75110	60511	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Советская	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
75084	51156	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	квартал им. 50-летия Октября	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25298	51156	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Завенягина	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
15364	12984	37.581972	37.586733000000002	54.112990000000003	54.112267000000003	улица Садовая	0103000020E610000001000000050000000798F90E7ECA4240C4B5DAC35E0E4B400798F90E7ECA42403563D174760E4B40F33D23111ACB42403563D174760E4B40F33D23111ACB4240C4B5DAC35E0E4B400798F90E7ECA4240C4B5DAC35E0E4B40
3910	12984	37.586787000000001	37.614716000000001	54.207264000000002	54.203966999999999	улица Дрейера	0103000020E61000000100000005000000E65B1FD61BCB42404B3B35971B1A4B40E65B1FD61BCB4240AFD172A0871A4B40FA298E03AFCE4240AFD172A0871A4B40FA298E03AFCE42404B3B35971B1A4B40E65B1FD61BCB42404B3B35971B1A4B40
4723	12984	37.709299000000001	37.712164999999999	54.187131999999998	54.183402000000001	улица Дачная	0103000020E61000000100000005000000F20A444FCADA4240B0027CB779174B40F20A444FCADA42407D04FEF0F3174B408C2D043928DB42407D04FEF0F3174B408C2D043928DB4240B0027CB779174B40F20A444FCADA4240B0027CB779174B40
3687	12984	37.614716000000001	37.627256000000003	54.216735999999997	54.202471000000003	улица Галкина	0103000020E61000000100000005000000FA298E03AFCE4240B8B1D991EA194B40FA298E03AFCE4240D4EE5701BE1B4B40221CB3EC49D04240D4EE5701BE1B4B40221CB3EC49D04240B8B1D991EA194B40FA298E03AFCE4240B8B1D991EA194B40
75150	12984	37.619764000000004	37.637532999999998	54.121760999999999	54.116773999999999	микрорайон Скуратовский	0103000020E610000001000000050000007C9E3F6D54CF4240F5824F73F20E4B407C9E3F6D54CF4240D1764CDD950F4B40758F6CAE9AD14240D1764CDD950F4B40758F6CAE9AD14240F5824F73F20E4B407C9E3F6D54CF4240F5824F73F20E4B40
75179	12984	37.569234000000002	37.584595	54.154221999999997	54.146296999999997	генерала Маргелова	0103000020E61000000100000005000000B9E2E2A8DCC842405F402FDCB9124B40B9E2E2A8DCC842406F29E78BBD134B40DB334B02D4CA42406F29E78BBD134B40DB334B02D4CA42405F402FDCB9124B40B9E2E2A8DCC842405F402FDCB9124B40
75219	12984	37.694341999999999	37.697575999999998	54.207137000000003	54.202607999999998	Юлиуса Фучика	0103000020E610000001000000050000009F1EDB32E0D8424038F4160FEF194B409F1EDB32E0D8424052651877831A4B40BC3C9D2B4AD9424052651877831A4B40BC3C9D2B4AD9424038F4160FEF194B409F1EDB32E0D8424038F4160FEF194B40
75115	12984	37.676340000000003	37.711824	54.221105999999999	54.216673	Щегловская Засека	0103000020E61000000100000005000000037D224F92D642408E76DCF0BB1B4B40037D224F92D6424085798F334D1C4B400341800C1DDB424085798F334D1C4B400341800C1DDB42408E76DCF0BB1B4B40037D224F92D642408E76DCF0BB1B4B40
75455	12984	37.585188000000002	37.591403999999997	54.129970999999998	54.126879000000002	Школьная	0103000020E610000001000000050000007E01BD70E7CA42404CC631923D104B407E01BD70E7CA4240D636C5E3A2104B409E5C5320B3CB4240D636C5E3A2104B409E5C5320B3CB42404CC631923D104B407E01BD70E7CA42404CC631923D104B40
75141	12984	37.590524000000002	37.617887000000003	54.168557	54.164535000000001	Шевченко	0103000020E6100000010000000500000066C0594A96CB424010069E7B0F154B4066C0594A96CB42408541994693154B40D1CFD4EB16CF42408541994693154B40D1CFD4EB16CF424010069E7B0F154B4066C0594A96CB424010069E7B0F154B40
75257	12984	37.594746000000001	37.596704000000003	54.197735999999999	54.188381	Халтурина	0103000020E61000000100000005000000A2B60DA320CC424009185DDE1C184B40A2B60DA320CC4240F59ECA694F194B403AB2F2CB60CC4240F59ECA694F194B403AB2F2CB60CC424009185DDE1C184B40A2B60DA320CC424009185DDE1C184B40
75165	12984	37.590074999999999	37.592770000000002	54.203313999999999	54.185651999999997	Фрунзе	0103000020E61000000100000005000000F697DD9387CB4240EF37DA71C3174B40F697DD9387CB4240D3687231061A4B4064062AE3DFCB4240D3687231061A4B4064062AE3DFCB4240EF37DA71C3174B40F697DD9387CB4240EF37DA71C3174B40
75206	12984	37.593317999999996	37.613520999999999	54.193291000000002	54.174517000000002	Фридриха Энгельса	0103000020E6100000010000000500000066101FD8F1CB42404BCCB39256164B4066101FD8F1CB42403ACE6DC2BD184B4061342BDB87CE42403ACE6DC2BD184B4061342BDB87CE42404BCCB39256164B4066101FD8F1CB42404BCCB39256164B40
75218	12984	37.605750999999998	37.633032	54.184614000000003	54.170274999999997	Тимирязева	0103000020E610000001000000050000007842AF3F89CD4240C7293A92CB154B407842AF3F89CD42401F317A6EA1174B4026A94C3107D142401F317A6EA1174B4026A94C3107D14240C7293A92CB154B407842AF3F89CD4240C7293A92CB154B40
75207	12984	37.565668000000002	37.574686999999997	54.163992	54.161572	Сурикова	0103000020E6100000010000000500000066321CCF67C8424083F92B64AE144B4066321CCF67C842401F679AB0FD144B40DA37F7578FC942401F679AB0FD144B40DA37F7578FC9424083F92B64AE144B4066321CCF67C8424083F92B64AE144B40
75181	12984	37.624831	37.630642999999999	54.190499000000003	54.176893999999997	Староникитская	0103000020E6100000010000000500000074435376FACF4240E76D6C76A4164B4074435376FACF4240DA756F4562184B40C539EAE8B8D04240DA756F4562184B40C539EAE8B8D04240E76D6C76A4164B4074435376FACF4240E76D6C76A4164B40
75221	12984	37.594872000000002	37.601430000000001	54.191130999999999	54.184787999999998	Софьи Перовской	0103000020E610000001000000050000002FA704C424CC4240BC581822A7174B402FA704C424CC42403A2009FB76184B40A96A82A8FBCC42403A2009FB76184B40A96A82A8FBCC4240BC581822A7174B402FA704C424CC4240BC581822A7174B40
75201	12984	37.584837999999998	37.611311000000001	54.200107000000003	54.198126000000002	Сойфера	0103000020E61000000100000005000000A1BAB9F8DBCA4240603E59315C194B40A1BAB9F8DBCA4240B0592E1B9D194B40B05758703FCE4240B0592E1B9D194B40B05758703FCE4240603E59315C194B40A1BAB9F8DBCA4240603E59315C194B40
75122	12984	37.56803	37.571489	54.18768	54.174902000000003	Серебровская	0103000020E61000000100000005000000CD920035B5C84240A400513063164B40CD920035B5C84240800EF3E505184B400A83328D26C94240800EF3E505184B400A83328D26C94240A400513063164B40CD920035B5C84240A400513063164B40
75224	12984	37.565379999999998	37.581792	54.175772000000002	54.163711999999997	Седова	0103000020E61000000100000005000000FFE7305F5EC842403BFBCA83F4144B40FFE7305F5EC84240B9C667B27F164B408789062978CA4240B9C667B27F164B408789062978CA42403BFBCA83F4144B40FFE7305F5EC842403BFBCA83F4144B40
75211	12984	37.579017	37.632404000000001	54.167929000000001	54.155524999999997	Рязанская	0103000020E61000000100000005000000FD69A33A1DCA4240EE5A423EE8134B40FD69A33A1DCA424066868DB27E154B4007EE409DF2D0424066868DB27E154B4007EE409DF2D04240EE5A423EE8134B40FD69A33A1DCA4240EE5A423EE8134B40
75154	12984	37.553072999999998	37.565344000000003	54.200633000000003	54.195687	Рогова	0103000020E610000001000000050000007AA69718CBC642404DA088450C194B407AA69718CBC64240CBBF9657AE194B40B37E33315DC84240CBBF9657AE194B40B37E33315DC842404DA088450C194B407AA69718CBC642404DA088450C194B40
75191	12984	37.664599000000003	37.677086000000003	54.208770000000001	54.202682000000003	Рихарда Зорге	0103000020E6100000010000000500000027FA7C9411D5424073BED87BF1194B4027FA7C9411D542406631B1F9B81A4B402C4A09C1AAD642406631B1F9B81A4B402C4A09C1AAD6424073BED87BF1194B4027FA7C9411D5424073BED87BF1194B40
75143	12984	37.584029000000001	37.615695000000002	54.194940000000003	54.19229	Революции	0103000020E6100000010000000500000032755776C1CA424086AC6EF59C184B4032755776C1CA424054573ECBF3184B40C6A70018CFCE424054573ECBF3184B40C6A70018CFCE424086AC6EF59C184B4032755776C1CA424086AC6EF59C184B40
75190	12984	37.540810999999998	37.556972000000002	54.120310000000003	54.116625999999997	Пушкина	0103000020E6100000010000000500000095287B4B39C5424080EECB99ED0E4B4095287B4B39C54240DEB06D51660F4B40D464C6DB4AC74240DEB06D51660F4B40D464C6DB4AC7424080EECB99ED0E4B4095287B4B39C5424080EECB99ED0E4B40
75149	12984	37.540810999999998	37.556972000000002	54.120310000000003	54.116625999999997	Пушкина	0103000020E6100000010000000500000095287B4B39C5424080EECB99ED0E4B4095287B4B39C54240DEB06D51660F4B40D464C6DB4AC74240DEB06D51660F4B40D464C6DB4AC7424080EECB99ED0E4B4095287B4B39C5424080EECB99ED0E4B40
75145	12984	37.601438999999999	37.624623999999997	54.221316000000002	54.217993999999997	Пузакова	0103000020E61000000100000005000000FCC401F4FBCC4240B35C363AE71B4B40FCC401F4FBCC4240700A2B15541C4B40FA25E2ADF3CF4240700A2B15541C4B40FA25E2ADF3CF4240B35C363AE71B4B40FCC401F4FBCC4240B35C363AE71B4B40
75212	12984	37.662469999999999	37.687658999999996	54.195976999999999	54.189096999999997	Приупская	0103000020E61000000100000005000000624A24D1CBD44240C7629B5434184B40624A24D1CBD4424054E23AC615194B4068E6C93505D8424054E23AC615194B4068E6C93505D84240C7629B5434184B40624A24D1CBD44240C7629B5434184B40
75226	12984	37.566960999999999	37.581342999999997	54.205210000000001	54.194713	Привокзальная	0103000020E61000000100000005000000C18D942D92C84240938D075BEC184B40C18D942D92C84240F5673F52441A4B4017618A7269CA4240F5673F52441A4B4017618A7269CA4240938D075BEC184B40C18D942D92C84240938D075BEC184B40
75222	12984	37.620348	37.622666000000002	54.175556	54.166569000000003	Перекопская	0103000020E61000000100000005000000CB11329067CF424083C30B2252154B40CB11329067CF4240EC4E779E78164B40632AFD84B3CF4240EC4E779E78164B40632AFD84B3CF424083C30B2252154B40CB11329067CF424083C30B2252154B40
75113	12984	37.581288999999998	37.606586	54.189782000000001	54.180472000000002	Первомайская	0103000020E6100000010000000500000024438EAD67CA4240FFEBDCB419174B4024438EAD67CA42404BAFCDC64A184B40111B2C9CA4CD42404BAFCDC64A184B40111B2C9CA4CD4240FFEBDCB419174B4024438EAD67CA4240FFEBDCB419174B40
75072	12984	37.483750000000001	37.862453000000002	54.272525000000002	54.029412999999998	Павшинский мост	0103000020E6100000010000000500000052B81E85EBBD4240E38920CEC3034B4052B81E85EBBD4240D42B6519E2224B4026AB22DC64EE4240D42B6519E2224B4026AB22DC64EE4240E38920CEC3034B4052B81E85EBBD4240E38920CEC3034B40
75184	12984	37.574686999999997	37.593317999999996	54.174517000000002	54.161572	Оружейная	0103000020E61000000100000005000000DA37F7578FC9424083F92B64AE144B40DA37F7578FC942404BCCB39256164B4066101FD8F1CB42404BCCB39256164B4066101FD8F1CB424083F92B64AE144B40DA37F7578FC9424083F92B64AE144B40
75138	12984	37.618012999999998	37.628711000000003	54.241694000000003	54.205098999999997	Октябрьская	0103000020E610000001000000050000005DC0CB0C1BCF42409DB81CAF401A4B405DC0CB0C1BCF4240D9D138D4EF1E4B4057D11F9A79D04240D9D138D4EF1E4B4057D11F9A79D042409DB81CAF401A4B405DC0CB0C1BCF42409DB81CAF401A4B40
75192	12984	37.513026000000004	37.568604999999998	54.195540000000001	54.183053999999998	Одоевское шоссе	0103000020E61000000100000005000000B5FF01D6AAC1424074B33F506E174B40B5FF01D6AAC14240A987687407194B40C9AB730CC8C84240A987687407194B40C9AB730CC8C8424074B33F506E174B40B5FF01D6AAC1424074B33F506E174B40
75135	12984	37.513026000000004	37.568604999999998	54.195540000000001	54.183053999999998	Одоевское шоссе	0103000020E61000000100000005000000B5FF01D6AAC1424074B33F506E174B40B5FF01D6AAC14240A987687407194B40C9AB730CC8C84240A987687407194B40C9AB730CC8C8424074B33F506E174B40B5FF01D6AAC1424074B33F506E174B40
15928	12984	37.513026000000004	37.568604999999998	54.195540000000001	54.183053999999998	Одоевское шоссе	0103000020E61000000100000005000000B5FF01D6AAC1424074B33F506E174B40B5FF01D6AAC14240A987687407194B40C9AB730CC8C84240A987687407194B40C9AB730CC8C8424074B33F506E174B40B5FF01D6AAC1424074B33F506E174B40
75215	12984	37.636068999999999	37.641809000000002	54.182406	54.172835999999997	Новомосковская	0103000020E61000000100000005000000ED7F80B56AD1424025C9737D1F164B40ED7F80B56AD142400E4C6E1459174B40A5A31CCC26D242400E4C6E1459174B40A5A31CCC26D2424025C9737D1F164B40ED7F80B56AD1424025C9737D1F164B40
75116	12984	37.597827000000002	37.601914999999998	54.167760999999999	54.166200000000003	Николая Руднева	0103000020E6100000010000000500000039D55A9885CC4240304CA60A46154B4039D55A9885CC4240AA45443179154B4065FCFB8C0BCD4240AA45443179154B4065FCFB8C0BCD4240304CA60A46154B4039D55A9885CC4240304CA60A46154B40
75170	12984	37.658994	37.671830999999997	54.210776000000003	54.202886999999997	Немцова	0103000020E610000001000000050000004F2157EA59D442404BE48233F8194B404F2157EA59D442400F643DB5FA1A4B4030B8E68EFED542400F643DB5FA1A4B4030B8E68EFED542404BE48233F8194B404F2157EA59D442404BE48233F8194B40
75427	12984	37.528927000000003	37.533696999999997	54.125275000000002	54.118737000000003	Мира	0103000020E61000000100000005000000577C43E1B3C342409FE925C6320F4B40577C43E1B3C34240D200DE0209104B40957CEC2E50C44240D200DE0209104B40957CEC2E50C442409FE925C6320F4B40577C43E1B3C342409FE925C6320F4B40
75174	12984	37.664231000000001	37.709837999999998	54.196266999999999	54.177979999999998	Металлургов	0103000020E61000000100000005000000A4FE7A8505D54240C9AB730CC8164B40A4FE7A8505D542405B24ED461F194B40A1BAB9F8DBDA42405B24ED461F194B40A1BAB9F8DBDA4240C9AB730CC8164B40A4FE7A8505D54240C9AB730CC8164B40
75216	12984	37.614294000000001	37.617851000000002	54.200564999999997	54.195303000000003	Металлистов	0103000020E610000001000000050000008410902FA1CE4240C5E74EB0FF184B408410902FA1CE424072DC291DAC194B408466D7BD15CF424072DC291DAC194B408466D7BD15CF4240C5E74EB0FF184B408410902FA1CE4240C5E74EB0FF184B40
75178	12984	37.616773000000002	37.626159999999999	54.195303000000003	54.190731	Менделеевская	0103000020E610000001000000050000002507EC6AF2CE4240ACAA97DF69184B402507EC6AF2CE4240C5E74EB0FF184B401C08C90226D04240C5E74EB0FF184B401C08C90226D04240ACAA97DF69184B402507EC6AF2CE4240ACAA97DF69184B40
25317	12984	37.616773000000002	37.626159999999999	54.195303000000003	54.190731	Менделеевская	0103000020E610000001000000050000002507EC6AF2CE4240ACAA97DF69184B402507EC6AF2CE4240C5E74EB0FF184B401C08C90226D04240C5E74EB0FF184B401C08C90226D04240ACAA97DF69184B402507EC6AF2CE4240ACAA97DF69184B40
75205	12984	37.665703999999998	37.670824000000003	54.205962999999997	54.202387000000002	Маяковского	0103000020E610000001000000050000007F68E6C935D542405A1135D1E7194B407F68E6C935D54240D097DEFE5C1A4B409BAF928FDDD54240D097DEFE5C1A4B409BAF928FDDD542405A1135D1E7194B407F68E6C935D542405A1135D1E7194B40
75132	12984	37.665703999999998	37.670824000000003	54.205962999999997	54.202387000000002	Маяковского	0103000020E610000001000000050000007F68E6C935D542405A1135D1E7194B407F68E6C935D54240D097DEFE5C1A4B409BAF928FDDD54240D097DEFE5C1A4B409BAF928FDDD542405A1135D1E7194B407F68E6C935D542405A1135D1E7194B40
75153	12984	37.628011000000001	37.631227000000003	54.218846999999997	54.212192000000002	Максимовского	0103000020E610000001000000050000009E4319AA62D04240863C821B291B4B409E4319AA62D04240F2E9B12D031C4B4015ADDC0BCCD04240F2E9B12D031C4B4015ADDC0BCCD04240863C821B291B4B409E4319AA62D04240863C821B291B4B40
75158	12984	37.594054	37.622351000000002	54.217905000000002	54.213061000000003	Максима Горького	0103000020E610000001000000050000006C0723F609CC4240CB863595451B4B406C0723F609CC42404451A04FE41B4B4003D19332A9CF42404451A04FE41B4B4003D19332A9CF4240CB863595451B4B406C0723F609CC4240CB863595451B4B40
75156	12984	37.594054	37.622351000000002	54.217905000000002	54.213061000000003	Максима Горького	0103000020E610000001000000050000006C0723F609CC4240CB863595451B4B406C0723F609CC42404451A04FE41B4B4003D19332A9CF42404451A04FE41B4B4003D19332A9CF4240CB863595451B4B406C0723F609CC4240CB863595451B4B40
75157	12984	37.558929999999997	37.575378000000001	54.171782	54.163881000000003	Макаренко	0103000020E610000001000000050000006B60AB048BC74240C8B7770DFA144B406B60AB048BC742404F05DCF3FC154B40406B7EFCA5C942404F05DCF3FC154B40406B7EFCA5C94240C8B7770DFA144B406B60AB048BC74240C8B7770DFA144B40
75194	12984	37.689087000000001	37.694341999999999	54.214319000000003	54.210591999999998	Майская	0103000020E61000000100000005000000A48CB80034D842404D66BCADF41A4B40A48CB80034D84240AAF413CE6E1B4B409F1EDB32E0D84240AAF413CE6E1B4B409F1EDB32E0D842404D66BCADF41A4B40A48CB80034D842404D66BCADF41A4B40
26756	12984	37.696309999999997	37.705212000000003	54.184472	54.179122999999997	М. Мазая	0103000020E610000001000000050000005AF0A2AF20D942400F7BA180ED164B405AF0A2AF20D942408C834BC79C174B40965F066344DA42408C834BC79C174B40965F066344DA42400F7BA180ED164B405AF0A2AF20D942400F7BA180ED164B40
75130	12984	37.591728000000003	37.621766999999998	54.210628	54.205536000000002	Луначарского	0103000020E6100000010000000500000052103CBEBDCB42404913EF004F1A4B4052103CBEBDCB42409ACFB9DBF51A4B40B35DA10F96CF42409ACFB9DBF51A4B40B35DA10F96CF42404913EF004F1A4B4052103CBEBDCB42404913EF004F1A4B40
75168	12984	37.634639999999997	37.660449	54.204698999999998	54.196688000000002	Ложевая	0103000020E61000000100000005000000E15D2EE23BD1424001C287122D194B40E15D2EE23BD142400F43AB93331A4B4084D6C39789D442400F43AB93331A4B4084D6C39789D4424001C287122D194B40E15D2EE23BD1424001C287122D194B40
75210	12984	37.592984999999999	37.620078999999997	54.213208999999999	54.208412000000003	Литейная	0103000020E610000001000000050000006002B7EEE6CB4240070C923EAD1A4B406002B7EEE6CB42403F1BB96E4A1B4B40DBF7A8BF5ECF42403F1BB96E4A1B4B40DBF7A8BF5ECF4240070C923EAD1A4B406002B7EEE6CB4240070C923EAD1A4B40
4792	12984	37.579250000000002	37.616405	54.192399999999999	54.134250000000002	Ленина проспект	0103000020E61000000100000005000000A01A2FDD24CA424077BE9F1A2F114B40A01A2FDD24CA42400DE02D90A0184B40A20BEA5BE6CE42400DE02D90A0184B40A20BEA5BE6CE424077BE9F1A2F114B40A01A2FDD24CA424077BE9F1A2F114B40
75225	12984	37.579250000000002	37.616405	54.192399999999999	54.134250000000002	Ленина	0103000020E61000000100000005000000A01A2FDD24CA424077BE9F1A2F114B40A01A2FDD24CA42400DE02D90A0184B40A20BEA5BE6CE42400DE02D90A0184B40A20BEA5BE6CE424077BE9F1A2F114B40A01A2FDD24CA424077BE9F1A2F114B40
75183	12984	37.579250000000002	37.616405	54.192399999999999	54.134250000000002	Ленина	0103000020E61000000100000005000000A01A2FDD24CA424077BE9F1A2F114B40A01A2FDD24CA42400DE02D90A0184B40A20BEA5BE6CE42400DE02D90A0184B40A20BEA5BE6CE424077BE9F1A2F114B40A01A2FDD24CA424077BE9F1A2F114B40
75185	12984	37.579250000000002	37.616405	54.192399999999999	54.134250000000002	Ленина	0103000020E61000000100000005000000A01A2FDD24CA424077BE9F1A2F114B40A01A2FDD24CA42400DE02D90A0184B40A20BEA5BE6CE42400DE02D90A0184B40A20BEA5BE6CE424077BE9F1A2F114B40A01A2FDD24CA424077BE9F1A2F114B40
75220	12984	37.663665000000002	37.711581000000002	54.213960999999998	54.179001999999997	Кутузова	0103000020E61000000100000005000000FB3F87F9F2D4424094F59B89E9164B40FB3F87F9F2D442404ACFF412631B4B403DBA111615DB42404ACFF412631B4B403DBA111615DB424094F59B89E9164B40FB3F87F9F2D4424094F59B89E9164B40
75139	12984	37.591538999999997	37.610844	54.201523000000002	54.199568999999997	Коминтерна	0103000020E610000001000000050000007EA7C98CB7CB4240D0251C7A8B194B407EA7C98CB7CB424027327381CB194B409A7ADD2230CE424027327381CB194B409A7ADD2230CE4240D0251C7A8B194B407EA7C98CB7CB4240D0251C7A8B194B40
75166	12984	37.643740000000001	37.676340000000003	54.217905000000002	54.194571000000003	Кирова	0103000020E610000001000000050000004390831266D2424001E0D8B3E7184B404390831266D242404451A04FE41B4B40037D224F92D642404451A04FE41B4B40037D224F92D6424001E0D8B3E7184B404390831266D2424001E0D8B3E7184B40
75351	12984	37.568578000000002	37.602966000000002	54.118690000000001	54.106292000000003	Киреевская	0103000020E61000000100000005000000D09CF529C7C84240C9E9EBF99A0D4B40D09CF529C7C842405E2EE23B310F4B40CB4C69FD2DCD42405E2EE23B310F4B40CB4C69FD2DCD4240C9E9EBF99A0D4B40D09CF529C7C84240C9E9EBF99A0D4B40
75223	12984	37.614401000000001	37.638117000000001	54.181468000000002	54.175556	Кауля	0103000020E610000001000000050000009AD024B1A4CE4240EC4E779E78164B409AD024B1A4CE4240A1A2EA573A174B40C5025FD1ADD14240A1A2EA573A174B40C5025FD1ADD14240EC4E779E78164B409AD024B1A4CE4240EC4E779E78164B40
75144	12984	37.526375000000002	37.543568999999998	54.185130000000001	54.179613000000003	Карбышева	0103000020E610000001000000050000004C37894160C34240DE770C8FFD164B404C37894160C3424016C1FF56B2174B40490F43AB93C5424016C1FF56B2174B40490F43AB93C54240DE770C8FFD164B404C37894160C34240DE770C8FFD164B40
3988	12984	37.553063999999999	37.579017	54.157786999999999	54.156716000000003	Калужское шоссе	0103000020E61000000100000005000000274C18CDCAC64240466117450F144B40274C18CDCAC64240F25D4A5D32144B40FD69A33A1DCA4240F25D4A5D32144B40FD69A33A1DCA4240466117450F144B40274C18CDCAC64240466117450F144B40
75147	12984	37.650621000000001	37.659416	54.204230000000003	54.194434000000001	Калинина	0103000020E61000000100000005000000A08B868C47D34240809D9B36E3184B40A08B868C47D34240596E6935241A4B40C53A55BE67D44240596E6935241A4B40C53A55BE67D44240809D9B36E3184B40A08B868C47D34240809D9B36E3184B40
75213	12984	37.638143999999997	37.656398000000003	54.207211000000001	54.200949000000001	Замочная	0103000020E61000000100000005000000BE11DDB3AED14240FB9463B2B8194B40BE11DDB3AED142408C2FDAE3851A4B40759483D904D442408C2FDAE3851A4B40759483D904D44240FB9463B2B8194B40BE11DDB3AED14240FB9463B2B8194B40
75202	12984	37.611167000000002	37.620195000000002	54.190767000000001	54.182110999999999	Жуковского	0103000020E610000001000000050000007DB262B83ACE4240F59ECA694F174B407DB262B83ACE4240F913950D6B184B404512BD8C62CF4240F913950D6B184B404512BD8C62CF4240F59ECA694F174B407DB262B83ACE4240F59ECA694F174B40
75198	12984	37.635305000000002	37.655230000000003	54.199243000000003	54.193480000000001	Епифанская	0103000020E610000001000000050000001EFE9AAC51D142400D37E0F3C3184B401EFE9AAC51D142407D7A6CCB80194B40D6AD9E93DED342407D7A6CCB80194B40D6AD9E93DED342400D37E0F3C3184B401EFE9AAC51D142400D37E0F3C3184B40
75164	12984	37.537028999999997	37.540165000000002	54.200175000000002	54.197409999999998	Дружбы	0103000020E610000001000000050000007500C45DBDC44240A1F31ABB44194B407500C45DBDC44240083D9B559F194B40D0B8702024C54240083D9B559F194B40D0B8702024C54240A1F31ABB44194B407500C45DBDC44240A1F31ABB44194B40
75137	12984	37.570383999999997	37.612685999999997	54.193617000000003	54.190714999999997	Демонстрации	0103000020E61000000100000005000000B114C95702C94240A6ED5F5969184B40B114C95702C942408E791D71C8184B40C85BAE7E6CCE42408E791D71C8184B40C85BAE7E6CCE4240A6ED5F5969184B40B114C95702C94240A6ED5F5969184B40
75193	12984	37.618219000000003	37.635413	54.205157	54.199122000000003	Демидовская Плотина	0103000020E610000001000000050000000762D9CC21CF424002F566D47C194B400762D9CC21CF4240D2C5A695421A4B40043A933655D14240D2C5A695421A4B40043A933655D1424002F566D47C194B400762D9CC21CF424002F566D47C194B40
75176	12984	37.596704000000003	37.618758	54.190299000000003	54.182063999999997	Гоголевская	0103000020E610000001000000050000003AB2F2CB60CC4240B4E386DF4D174B403AB2F2CB60CC424013BBB6B75B184B40B6114F7633CF424013BBB6B75B184B40B6114F7633CF4240B4E386DF4D174B403AB2F2CB60CC4240B4E386DF4D174B40
75209	12984	37.613655999999999	37.623159999999999	54.228169000000001	54.213287000000001	Герцена	0103000020E61000000100000005000000417FA1478CCE4240BBD408FD4C1B4B40417FA1478CCE4240037B4CA4341D4B407216F6B4C3CF4240037B4CA4341D4B407216F6B4C3CF4240BBD408FD4C1B4B40417FA1478CCE4240BBD408FD4C1B4B40
75124	12984	37.636850000000003	37.659874000000002	54.205751999999997	54.198478999999999	Гармонная	0103000020E61000000100000005000000933A014D84D14240ADF886C267194B40933A014D84D14240158BDF14561A4B4088BD50C076D44240158BDF14561A4B4088BD50C076D44240ADF886C267194B40933A014D84D14240ADF886C267194B40
75204	12984	37.614716000000001	37.627256000000003	54.216735999999997	54.202471000000003	Галкина	0103000020E61000000100000005000000FA298E03AFCE4240B8B1D991EA194B40FA298E03AFCE4240D4EE5701BE1B4B40221CB3EC49D04240D4EE5701BE1B4B40221CB3EC49D04240B8B1D991EA194B40FA298E03AFCE4240B8B1D991EA194B40
26877	12984	37.590093000000003	37.592500000000001	54.108666999999997	54.107405999999997	Гагарина	0103000020E610000001000000050000009D4CDC2A88CB424074B2D47ABF0D4B409D4CDC2A88CB4240C493DDCCE80D4B40A4703D0AD7CB4240C493DDCCE80D4B40A4703D0AD7CB424074B2D47ABF0D4B409D4CDC2A88CB424074B2D47ABF0D4B40
75128	12984	37.591503000000003	37.592581000000003	54.155397999999998	54.151159	Волоховская	0103000020E61000000100000005000000323ECC5EB6CB42407FBF982D59134B40323ECC5EB6CB424091EEE714E4134B40919DB7B1D9CB424091EEE714E4134B40919DB7B1D9CB42407FBF982D59134B40323ECC5EB6CB42407FBF982D59134B40
75172	12984	37.680472000000002	37.698573000000003	54.212713999999998	54.202255000000001	Вильямса	0103000020E61000000100000005000000FFEBDCB419D74240EB39E97DE3194B40FFEBDCB419D742405FB35C363A1B4B402F6F0ED76AD942405FB35C363A1B4B402F6F0ED76AD94240EB39E97DE3194B40FFEBDCB419D74240EB39E97DE3194B40
75200	12984	37.580309999999997	37.588735999999997	54.198416000000002	54.185546000000002	Вересаева	0103000020E6100000010000000500000058C51B9947CA4240AAF3A8F8BF174B4058C51B9947CA424067800BB265194B402AFD84B35BCB424067800BB265194B402AFD84B35BCB4240AAF3A8F8BF174B4058C51B9947CA4240AAF3A8F8BF174B40
75214	12984	37.597099999999998	37.605291999999999	54.191820999999997	54.183960999999996	Бундурина	0103000020E610000001000000050000008638D6C56DCC4240A65EB7088C174B408638D6C56DCC4240CFD72C978D184B40E54350357ACD4240CFD72C978D184B40E54350357ACD4240A65EB7088C174B408638D6C56DCC4240A65EB7088C174B40
75125	12984	37.570383999999997	37.588709000000001	54.191426	54.166606000000002	Болдина	0103000020E61000000100000005000000B114C95702C94240A0A86C5853154B40B114C95702C9424053CDACA580184B4031EE06D15ACB424053CDACA580184B4031EE06D15ACB4240A0A86C5853154B40B114C95702C94240A0A86C5853154B40
75117	12984	37.608229999999999	37.615209999999998	54.291580000000003	54.287711999999999	Березовская	0103000020E6100000010000000500000019390B7BDACD424058552FBFD3244B4019390B7BDACD42407715527E52254B4009168733BFCE42407715527E52254B4009168733BFCE424058552FBFD3244B4019390B7BDACD424058552FBFD3244B40
75217	12984	37.665120000000002	37.681263000000001	54.216330999999997	54.207000000000001	Баженова	0103000020E6100000010000000500000030F5F3A622D54240D122DBF97E1A4B4030F5F3A622D54240340EF5BBB01B4B40C87C40A033D74240340EF5BBB01B4B40C87C40A033D74240D122DBF97E1A4B4030F5F3A622D54240D122DBF97E1A4B40
15970	12984	37.537730000000003	37.545014999999999	54.205041000000001	54.202123999999998	6-й Полюсный проезд	0103000020E61000000100000005000000FF092E56D4C442404CDE0033DF194B40FF092E56D4C4424069AB92C83E1A4B402B6A300DC3C5424069AB92C83E1A4B402B6A300DC3C542404CDE0033DF194B40FF092E56D4C442404CDE0033DF194B40
25635	12984	37.532519999999998	37.552157000000001	54.206041999999997	54.198532	18-й проезд	0103000020E61000000100000005000000A33B889D29C44240D09A1F7F69194B40A33B889D29C442401CCD91955F1A4B40F5A0A014ADC642401CCD91955F1A4B40F5A0A014ADC64240D09A1F7F69194B40A33B889D29C44240D09A1F7F69194B40
4627	12984	37.675514	37.676825000000001	54.196171999999997	54.191974000000002	1-й Металлургов проезд	0103000020E61000000100000005000000BDFE243E77D6424056D7A19A92184B40BDFE243E77D642400932022A1C194B40BF0E9C33A2D642400932022A1C194B40BF0E9C33A2D6424056D7A19A92184B40BDFE243E77D6424056D7A19A92184B40
75426	12984	37.585188000000002	37.591403999999997	54.129970999999998	54.126879000000002	 Школьная	0103000020E610000001000000050000007E01BD70E7CA42404CC631923D104B407E01BD70E7CA4240D636C5E3A2104B409E5C5320B3CB4240D636C5E3A2104B409E5C5320B3CB42404CC631923D104B407E01BD70E7CA42404CC631923D104B40
75292	12984	37.605741999999999	37.610458000000001	54.142004	54.134044000000003	 Центральная	0103000020E6100000010000000500000025E82FF488CD4240CE1C925A28114B4025E82FF488CD42405AF3E32F2D124B4071CADC7C23CE42405AF3E32F2D124B4071CADC7C23CE4240CE1C925A28114B4025E82FF488CD4240CE1C925A28114B40
75103	60507	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	Тульская	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
26587	51300	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	Парковая	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
25337	20502	37.540622999999997	37.590739999999997	54.259900000000002	54.231180000000002	Ленина 	0103000020E61000000100000005000000923B6C2233C54240A1BE654E971D4B40923B6C2233C542407E1D386744214B4032384A5E9DCB42407E1D386744214B4032384A5E9DCB4240A1BE654E971D4B40923B6C2233C54240A1BE654E971D4B40
26330	20502	37.540622999999997	37.590739999999997	54.259900000000002	54.231180000000002	Заводская	0103000020E61000000100000005000000923B6C2233C54240A1BE654E971D4B40923B6C2233C542407E1D386744214B4032384A5E9DCB42407E1D386744214B4032384A5E9DCB4240A1BE654E971D4B40923B6C2233C54240A1BE654E971D4B40
75099	60504	37.266950999999999	37.325448999999999	53.725104999999999	53.682718999999999	Победы	0103000020E6100000010000000500000037514B732BA24240CDAD105663D74A4037514B732BA2424042959A3DD0DC4A4009C21550A8A9424042959A3DD0DC4A4009C21550A8A94240CDAD105663D74A4037514B732BA24240CDAD105663D74A40
75086	60498	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Чехова	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
75081	60496	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Островского	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
75076	60494	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Мира	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
75079	60494	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Дачная	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25365	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Школьная	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25646	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Тургенева	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25513	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Стахановская	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25880	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Советская	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25330	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Свердлова	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
26112	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Первомайская	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25921	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Октябрьская	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25536	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Новая	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
26091	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Ленина	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
26815	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Кирпичная	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25958	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Кирова	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25331	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Индустриальная	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25838	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Заводская	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
26774	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Горького	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
26573	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	Вахрушева	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
26569	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	328 Стрелковой дивизии	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
25882	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	30 лет Победы	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
26895	14206	38.253444999999999	38.372785999999998	53.983058	53.950657999999997	10 Армии	0103000020E61000000100000005000000D82AC1E27020434023D74D29AFF94A40D82AC1E2702043401C0934D8D4FD4A400D349F73B72F43401C0934D8D4FD4A400D349F73B72F434023D74D29AFF94A40D82AC1E27020434023D74D29AFF94A40
75075	60492	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Шахтная	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
75100	60492	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Западный МКР	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
25621	51186	38.253427000000002	38.43291	54.012078000000002	53.915686999999998	Заводская	0103000020E610000001000000050000003276C24B70204340A92F4B3B35F54A403276C24B7020434024809BC58B014B40410E4A986937434024809BC58B014B40410E4A9869374340A92F4B3B35F54A403276C24B70204340A92F4B3B35F54A40
25676	51189	38.253427000000002	38.43291	54.012078000000002	53.915686999999998	Советская	0103000020E610000001000000050000003276C24B70204340A92F4B3B35F54A403276C24B7020434024809BC58B014B40410E4A986937434024809BC58B014B40410E4A9869374340A92F4B3B35F54A403276C24B70204340A92F4B3B35F54A40
26862	12660	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	Южная	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
25350	12660	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	Л.Толстого	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
26656	12660	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	Комсомольская	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
26340	12660	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	Карбышева	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
25754	12660	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	Горького	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
25351	12660	37.661212999999996	37.728774999999999	54.494053000000001	54.462235999999997	Гайдара	0103000020E610000001000000050000005358A9A0A2D4424055849B8C2A3B4B405358A9A0A2D44240CFBEF2203D3F4B403A92CB7F48DD4240CFBEF2203D3F4B403A92CB7F48DD424055849B8C2A3B4B405358A9A0A2D4424055849B8C2A3B4B40
26649	12550	37.723888000000002	37.755400999999999	54.549486000000002	54.536741999999997	Школьная	0103000020E61000000100000005000000C2FBAA5CA8DC4240DF313CF6B3444B40C2FBAA5CA8DC424010CEA78E55464B40CF2EDFFAB0E0424010CEA78E55464B40CF2EDFFAB0E04240DF313CF6B3444B40C2FBAA5CA8DC4240DF313CF6B3444B40
75408	11946	37.691594000000002	37.708500000000001	54.373122000000002	54.364147000000003	Учительская	0103000020E610000001000000050000000F0EF62686D84240E0F76F5E9C2E4B400F0EF62686D8424085B53176C22F4B40A69BC420B0DA424085B53176C22F4B40A69BC420B0DA4240E0F76F5E9C2E4B400F0EF62686D84240E0F76F5E9C2E4B40
26729	11760	37.639679999999998	37.655751000000002	54.505789999999998	54.492316000000002	Садовая	0103000020E61000000100000005000000E0F3C308E1D1424016A6EF35043F4B40E0F3C308E1D1424069520ABABD404B40DFA815A6EFD3424069520ABABD404B40DFA815A6EFD3424016A6EF35043F4B40E0F3C308E1D1424016A6EF35043F4B40
26142	46488	37.890121000000001	37.913558000000002	54.546373000000003	54.533408999999999	Мира	0103000020E61000000100000005000000CD3D247CEFF142402F3201BF46444B40CD3D247CEFF142406E35EB8CEF454B40E57FF277EFF442406E35EB8CEF454B40E57FF277EFF442402F3201BF46444B40CD3D247CEFF142402F3201BF46444B40
75272	18517	37.745879000000002	37.771614999999997	54.680681	54.670763999999998	Экспериментальная	0103000020E61000000100000005000000F8E28BF678DF4240C5AA4198DB554B40F8E28BF678DF42401901158E20574B40300DC347C4E242401901158E20574B40300DC347C4E24240C5AA4198DB554B40F8E28BF678DF4240C5AA4198DB554B40
25903	12453	38.008446999999997	38.023251999999999	54.590817999999999	54.583993999999997	Центральная	0103000020E61000000100000005000000E95F92CA14014340B587BD50C04A4B40E95F92CA14014340AEF199EC9F4B4B4086C8E9EBF9024340AEF199EC9F4B4B4086C8E9EBF9024340B587BD50C04A4B40E95F92CA14014340B587BD50C04A4B40
25344	12436	37.713926000000001	37.739195000000002	54.531205	54.515194000000001	Зеленая	0103000020E61000000100000005000000CEE15AED61DB4240378C82E0F1414B40CEE15AED61DB4240603C8386FE434B40F12E17F19DDE4240603C8386FE434B40F12E17F19DDE4240378C82E0F1414B40CEE15AED61DB4240378C82E0F1414B40
75471	46530	37.630319	37.682043999999998	54.377490000000002	54.356476999999998	Центральная	0103000020E610000001000000050000001286014BAED042405A63D009A12D4B401286014BAED042409548A29751304B406D37C1374DD742409548A29751304B406D37C1374DD742405A63D009A12D4B401286014BAED042405A63D009A12D4B40
26147	46530	37.630319	37.682043999999998	54.377490000000002	54.356476999999998	Советская	0103000020E610000001000000050000001286014BAED042405A63D009A12D4B401286014BAED042409548A29751304B406D37C1374DD742409548A29751304B406D37C1374DD742405A63D009A12D4B401286014BAED042405A63D009A12D4B40
75393	46657	37.972039000000002	37.983204999999998	54.632348	54.625494000000003	Новая	0103000020E61000000100000005000000E1B721C66BFC424010ECF82F10504B40E1B721C66BFC424073D87DC7F0504B40C02154A9D9FD424073D87DC7F0504B40C02154A9D9FD424010ECF82F10504B40E1B721C66BFC424010ECF82F10504B40
25340	33153	37.805114000000003	37.82723	54.818863999999998	54.801608000000002	Центральная	0103000020E61000000100000005000000A0C6BDF90DE74240221B48179B664B40A0C6BDF90DE7424095EF1989D0684B40922232ACE2E9424095EF1989D0684B40922232ACE2E94240221B48179B664B40A0C6BDF90DE74240221B48179B664B40
75452	46170	37.837848000000001	37.871751000000003	54.465685000000001	54.453622000000003	Центральная	0103000020E610000001000000050000006F826F9A3EEB4240815F2349103A4B406F826F9A3EEB42406F9EEA909B3B4B40AEA0698995EF42406F9EEA909B3B4B40AEA0698995EF4240815F2349103A4B406F826F9A3EEB4240815F2349103A4B40
75335	46170	37.837848000000001	37.871751000000003	54.465685000000001	54.453622000000003	Советская	0103000020E610000001000000050000006F826F9A3EEB4240815F2349103A4B406F826F9A3EEB42406F9EEA909B3B4B40AEA0698995EF42406F9EEA909B3B4B40AEA0698995EF4240815F2349103A4B406F826F9A3EEB4240815F2349103A4B40
25336	46295	37.962004	37.978479999999998	54.829528000000003	54.812477999999999	Центральная	0103000020E61000000100000005000000834F73F222FB4240185C7347FF674B40834F73F222FB4240E38E37F92D6A4B4021E527D53EFD4240E38E37F92D6A4B4021E527D53EFD4240185C7347FF674B40834F73F222FB4240185C7347FF674B40
25342	12266	37.755741999999998	37.763117000000001	54.500943999999997	54.487824000000003	Мира	0103000020E61000000100000005000000581B6327BCE042401A1A4F04713E4B40581B6327BCE042404F90D8EE1E404B40C5025FD1ADE142404F90D8EE1E404B40C5025FD1ADE142401A1A4F04713E4B40581B6327BCE042401A1A4F04713E4B40
25358	11863	37.901341000000002	37.917088999999997	54.434238999999998	54.420605999999999	Молодежная	0103000020E61000000100000005000000A0C552245FF342402D40DB6AD6354B40A0C552245FF34240E9D2BF2495374B40BB421F2C63F54240E9D2BF2495374B40BB421F2C63F542402D40DB6AD6354B40A0C552245FF342402D40DB6AD6354B40
75262	11836	37.724957000000003	37.741306000000002	54.460593000000003	54.447963000000001	Школьная	0103000020E61000000100000005000000CE001764CBDC4240B66801DA56394B40CE001764CBDC42401EE21FB6F43A4B400F2A711DE3DE42401EE21FB6F43A4B400F2A711DE3DE4240B66801DA56394B40CE001764CBDC4240B66801DA56394B40
26615	12036	37.987426999999997	38.009399999999999	54.781145000000002	54.763883	Студенческая	0103000020E61000000100000005000000FC17080264FE4240357C0BEBC6614B40FC17080264FE42408B37328FFC634B408C4AEA04340143408B37328FFC634B408C4AEA0434014340357C0BEBC6614B40FC17080264FE4240357C0BEBC6614B40
67861	47016	37.604700000000001	37.627237999999998	54.465214000000003	54.448684999999998	Тихомирова	0103000020E6100000010000000500000013F241CF66CD4240569A94826E394B4013F241CF66CD424018D2E1218C3B4B407B67B45549D0424018D2E1218C3B4B407B67B45549D04240569A94826E394B4013F241CF66CD4240569A94826E394B40
26553	49181	37.517743000000003	37.552480000000003	54.087800999999999	54.057259000000002	Школьная	0103000020E61000000100000005000000D15D126745C242406A334E4354074B40D15D126745C242402EC72B103D0B4B40D8D825AAB7C642402EC72B103D0B4B40D8D825AAB7C642406A334E4354074B40D15D126745C242406A334E4354074B40
26465	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Юбилейная	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
25449	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Стволовая	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
25792	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Спортивная	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
26536	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Свободы	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
26595	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Пролетарская	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
25767	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Пионерская	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
25461	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Мира	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
25320	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Лукашина	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
25542	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Лизы Шамшиковой	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
26097	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Ленина	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
26051	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Комсомольская	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
25348	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Коммунальная	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
26799	9304	37.473607999999999	37.555138999999997	54.026541000000002	53.979689999999998	Болдина	0103000020E61000000100000005000000DE8FDB2F9FBC4240EF1B5F7B66FD4A40DE8FDB2F9FBC424067800BB265034B40F8DD74CB0EC7424067800BB265034B40F8DD74CB0EC74240EF1B5F7B66FD4A40DE8FDB2F9FBC4240EF1B5F7B66FD4A40
75287	60559	37.488556000000003	37.505004	53.982025	53.973404000000002	Центральная	0103000020E61000000100000005000000DE21C50089BE4240D6E5948098FC4A40DE21C50089BE42405D6DC5FEB2FD4A40B22C98F8A3C042405D6DC5FEB2FD4A40B22C98F8A3C04240D6E5948098FC4A40DE21C50089BE4240D6E5948098FC4A40
75241	40974	37.505004	37.519764000000002	53.857173000000003	53.851787000000002	Ленина	0103000020E61000000100000005000000B22C98F8A3C0424038143E5B07ED4A40B22C98F8A3C04240D20149D8B7ED4A40AFD172A087C24240D20149D8B7ED4A40AFD172A087C2424038143E5B07ED4A40B22C98F8A3C0424038143E5B07ED4A40
26928	45996	37.604331000000002	37.619863000000002	53.976253999999997	53.967632000000002	Трудовая	0103000020E61000000100000005000000C07ADCB75ACD42401348895DDBFB4A40C07ADCB75ACD42406A4B1DE4F5FC4A400F80B8AB57CF42406A4B1DE4F5FC4A400F80B8AB57CF42401348895DDBFB4A40C07ADCB75ACD42401348895DDBFB4A40
26286	45596	37.617015000000002	37.654510999999999	53.954504999999997	53.927024000000003	Энергетиков	0103000020E610000001000000050000001B12F758FACE4240B64DF1B8A8F64A401B12F758FACE42402A6F47382DFA4A40A6EF3504C7D342402A6F47382DFA4A40A6EF3504C7D34240B64DF1B8A8F64A401B12F758FACE4240B64DF1B8A8F64A40
26470	45596	37.617015000000002	37.654510999999999	53.954504999999997	53.927024000000003	Школьная	0103000020E610000001000000050000001B12F758FACE4240B64DF1B8A8F64A401B12F758FACE42402A6F47382DFA4A40A6EF3504C7D342402A6F47382DFA4A40A6EF3504C7D34240B64DF1B8A8F64A401B12F758FACE4240B64DF1B8A8F64A40
26317	49235	37.235850999999997	37.274262999999998	53.996917000000003	53.986176	Советская	0103000020E610000001000000050000004CDD955D309E4240D00CE2033BFE4A404CDD955D309E4240C9E9EBF99AFF4A405DC0CB0C1BA34240C9E9EBF99AFF4A405DC0CB0C1BA34240D00CE2033BFE4A404CDD955D309E4240D00CE2033BFE4A40
26376	10933	37.302309000000001	37.329393000000003	53.932718000000001	53.920147	 А.Н.Козаченко	0103000020E61000000100000005000000AB24B20FB2A642409A417C60C7F54A40AB24B20FB2A64240FD31AD4D63F74A400344C18C29AA4240FD31AD4D63F74A400344C18C29AA42409A417C60C7F54A40AB24B20FB2A642409A417C60C7F54A40
75233	10645	37.548824000000003	37.582017	53.952903999999997	53.912495	Шахтёрская	0103000020E6100000010000000500000045A165DD3FC64240BB61DBA2CCF44A4045A165DD3FC64240211D1EC2F8F94A40A75B76887FCA4240211D1EC2F8F94A40A75B76887FCA4240BB61DBA2CCF44A4045A165DD3FC64240BB61DBA2CCF44A40
67900	10645	37.548824000000003	37.582017	53.952903999999997	53.912495	Клубная	0103000020E6100000010000000500000045A165DD3FC64240BB61DBA2CCF44A4045A165DD3FC64240211D1EC2F8F94A40A75B76887FCA4240211D1EC2F8F94A40A75B76887FCA4240BB61DBA2CCF44A4045A165DD3FC64240BB61DBA2CCF44A40
26804	10766	37.166806999999999	37.18206	54.055926999999997	54.044060000000002	Речная	0103000020E6100000010000000500000037DF88EE59954240E88711C2A3054B4037DF88EE5995424050FBAD9D28074B4073F4F8BD4D97424050FBAD9D28074B4073F4F8BD4D974240E88711C2A3054B4037DF88EE59954240E88711C2A3054B40
75414	45839	37.383597000000002	37.405157000000003	53.816536999999997	53.808093999999997	Куприянова	0103000020E61000000100000005000000FFEBDCB419B14240020CCB9F6FE74A40FFEBDCB419B14240AA7CCF4884E84A406C5F402FDCB34240AA7CCF4884E84A406C5F402FDCB34240020CCB9F6FE74A40FFEBDCB419B14240020CCB9F6FE74A40
26258	11488	37.650370000000002	37.674453999999997	53.993465999999998	53.976587000000002	Центральная	0103000020E610000001000000050000005726FC523FD34240715985CD00FD4A405726FC523FD342400ED8D5E429FF4A400454388254D642400ED8D5E429FF4A400454388254D64240715985CD00FD4A405726FC523FD34240715985CD00FD4A40
75328	60575	37.661608000000001	37.690874999999998	54.019955000000003	54.006459	Центральная	0103000020E61000000100000005000000D0622992AFD44240E7E104A6D3004B40D0622992AFD442402332ACE28D024B40DF4F8D976ED842402332ACE28D024B40DF4F8D976ED84240E7E104A6D3004B40D0622992AFD44240E7E104A6D3004B40
26099	45865	37.492581000000001	37.516205999999997	53.730341000000003	53.719206999999997	Школьная	0103000020E61000000100000005000000C4D0EAE40CBF4240F20698F90EDC4A40C4D0EAE40CBF4240C7F65AD07BDD4A40DEFFC70913C24240C7F65AD07BDD4A40DEFFC70913C24240F20698F90EDC4A40C4D0EAE40CBF4240F20698F90EDC4A40
26093	45807	37.476751999999998	37.49559	53.857534000000001	53.845137000000001	Тульская	0103000020E61000000100000005000000BB26A43506BD4240DDD1FF722DEC4A40BB26A43506BD4240A29A92ACC3ED4A40C11C3D7E6FBF4240A29A92ACC3ED4A40C11C3D7E6FBF4240DDD1FF722DEC4A40BB26A43506BD4240DDD1FF722DEC4A40
25884	10917	37.142741000000001	37.170661000000003	53.949418000000001	53.930374	Коммунаров	0103000020E6100000010000000500000030664B56459242403C86C77E16F74A4030664B5645924240EB1D6E8786F94A40F1D93A38D8954240EB1D6E8786F94A40F1D93A38D89542403C86C77E16F74A4030664B56459242403C86C77E16F74A40
25932	12235	37.156261000000001	37.167867000000001	54.039095000000003	54.030920000000002	Центральная	0103000020E61000000100000005000000F451465C009442406B65C22FF5034B40F451465C00944240F437A11001054B40F08975AA7C954240F437A11001054B40F08975AA7C9542406B65C22FF5034B40F451465C009442406B65C22FF5034B40
75105	11008	37.447521000000002	37.468856000000002	53.914112000000003	53.895789999999998	Школьная	0103000020E61000000100000005000000F9A23D5E48B94240BB0A293FA9F24A40F9A23D5E48B94240CA703C9F01F54A404644317903BC4240CA703C9F01F54A404644317903BC4240BB0A293FA9F24A40F9A23D5E48B94240BB0A293FA9F24A40
25783	11175	37.388322000000002	37.405003999999998	53.756354999999999	53.745398000000002	Молодежная	0103000020E610000001000000050000009E280989B4B142407D40A03369DF4A409E280989B4B1424042959A3DD0E04A40E55FCB2BD7B3424042959A3DD0E04A40E55FCB2BD7B342407D40A03369DF4A409E280989B4B142407D40A03369DF4A40
26907	49282	37.587488	37.612451999999998	53.933857000000003	53.925592000000002	Центральная	0103000020E610000001000000050000006F6589CE32CB424039B874CC79F64A406F6589CE32CB424002124DA088F74A40552FBFD364CE424002124DA088F74A40552FBFD364CE424039B874CC79F64A406F6589CE32CB424039B874CC79F64A40
25704	29098	37.407744000000001	37.438574000000003	54.045386999999998	54.035319999999999	Шахтерская	0103000020E61000000100000005000000F39194F430B442408672A25D85044B40F39194F430B44240EF54C03DCF054B401E705D3123B84240EF54C03DCF054B401E705D3123B842408672A25D85044B40F39194F430B442408672A25D85044B40
26382	29136	37.468505999999998	37.486804999999997	54.015220999999997	54.009469000000003	Агрохимиков	0103000020E6100000010000000500000069FD2D01F8BB4240B5A9BA4736014B4069FD2D01F8BB4240309B00C3F2014B40BF4351A04FBE4240309B00C3F2014B40BF4351A04FBE4240B5A9BA4736014B4069FD2D01F8BB4240B5A9BA4736014B40
75253	46072	37.071190000000001	37.096674999999998	53.860778000000003	53.846204999999998	Бритикова	0103000020E61000000100000005000000B0E600C11C894240185B087250EC4A40B0E600C11C894240E38E37F92DEE4A409FABADD85F8C4240E38E37F92DEE4A409FABADD85F8C4240185B087250EC4A40B0E600C11C894240185B087250EC4A40
25775	10810	37.109737000000003	37.121738000000001	53.946736999999999	53.931525000000001	Комсомольская	0103000020E61000000100000005000000A114ADDC0B8E4240053411363CF74A40A114ADDC0B8E4240E27492AD2EF94A4019575C1C958F4240E27492AD2EF94A4019575C1C958F4240053411363CF74A40A114ADDC0B8E4240053411363CF74A40
26262	7658	36.859807000000004	36.933819999999997	53.465927999999998	53.442355999999997	Производственная	0103000020E610000001000000050000009AEFE0270E6E42403D98141F9FB84A409AEFE0270E6E424035255987A3BB4A40E42CEC698777424035255987A3BB4A40E42CEC69877742403D98141F9FB84A409AEFE0270E6E42403D98141F9FB84A40
25993	7658	36.859807000000004	36.933819999999997	53.465927999999998	53.442355999999997	Космонавтов	0103000020E610000001000000050000009AEFE0270E6E42403D98141F9FB84A409AEFE0270E6E424035255987A3BB4A40E42CEC698777424035255987A3BB4A40E42CEC69877742403D98141F9FB84A409AEFE0270E6E42403D98141F9FB84A40
25988	7658	36.859807000000004	36.933819999999997	53.465927999999998	53.442355999999997	К.Маркса	0103000020E610000001000000050000009AEFE0270E6E42403D98141F9FB84A409AEFE0270E6E424035255987A3BB4A40E42CEC698777424035255987A3BB4A40E42CEC69877742403D98141F9FB84A409AEFE0270E6E42403D98141F9FB84A40
26512	9046	37.281719000000002	37.307842000000001	53.383558999999998	53.374358000000001	Школьная	0103000020E61000000100000005000000B7D4415E0FA442407C7F83F6EAAF4A40B7D4415E0FA44240118B187618B14A40E92ADD5D67A74240118B187618B14A40E92ADD5D67A742407C7F83F6EAAF4A40B7D4415E0FA442407C7F83F6EAAF4A40
75434	51217	36.459150000000001	36.485776000000001	53.441277999999997	53.429155000000002	Центральная	0103000020E61000000100000005000000ADFA5C6DC53A42401BF5108DEEB64A40ADFA5C6DC53A4240DE3829CC7BB84A40429770E82D3E4240DE3829CC7BB84A40429770E82D3E42401BF5108DEEB64A40ADFA5C6DC53A42401BF5108DEEB64A40
26055	8322	37.019429000000002	37.034215000000003	53.597129000000002	53.590801999999996	Школьная	0103000020E6100000010000000500000008CC43A67C824240A83462669FCB4A4008CC43A67C824240213F1BB96ECC4A402E04392861844240213F1BB96ECC4A402E04392861844240A83462669FCB4A4008CC43A67C824240A83462669FCB4A40
26401	51263	36.380502	37.504600000000003	53.650495999999997	53.256169	Перронная	0103000020E6100000010000000500000003081F4AB4304240E09F5225CAA04A4003081F4AB4304240E316F37343D34A40E3C798BB96C04240E316F37343D34A40E3C798BB96C04240E09F5225CAA04A4003081F4AB4304240E09F5225CAA04A40
25492	9137	37.131898	37.151130999999999	53.448604000000003	53.434209000000003	Центральная	0103000020E6100000010000000500000033349E08E29042407F50172994B74A4033349E08E29042406A6D1ADB6BB94A40B534B742589342406A6D1ADB6BB94A40B534B742589342407F50172994B74A4033349E08E29042407F50172994B74A40
26001	7806	36.833891000000001	37.045399000000003	53.567583999999997	53.433205000000001	А.Скуратова	0103000020E61000000100000005000000E1B6B6F0BC6A42405ABBED4273B74A40E1B6B6F0BC6A4240CEDDAE97A6C84A40B4226AA2CF854240CEDDAE97A6C84A40B4226AA2CF8542405ABBED4273B74A40E1B6B6F0BC6A42405ABBED4273B74A40
75348	8496	36.760328000000001	36.774360000000001	53.555304	53.545338000000001	Центральная	0103000020E61000000100000005000000D61D8B6D526142400EA2B5A2CDC54A40D61D8B6D5261424043AB933314C74A4050AA7D3A1E63424043AB933314C74A4050AA7D3A1E6342400EA2B5A2CDC54A40D61D8B6D526142400EA2B5A2CDC54A40
25949	9073	37.079256999999998	37.093693000000002	53.535037000000003	53.525863000000001	Школьная	0103000020E61000000100000005000000527DE717258A42409696917A4FC34A40527DE717258A42403293A8177CC44A409C6ED921FE8B42403293A8177CC44A409C6ED921FE8B42409696917A4FC34A40527DE717258A42409696917A4FC34A40
75352	8981	36.601452000000002	36.624754000000003	53.484889000000003	53.468077000000001	Молодежная	0103000020E61000000100000005000000910E0F61FC4C4240418177F2E9BB4A40910E0F61FC4C42405798BED710BE4A40C90567F0F74F42405798BED710BE4A40C90567F0F74F4240418177F2E9BB4A40910E0F61FC4C4240418177F2E9BB4A40
26017	9238	37.036749	37.050628000000003	53.506321	53.497140999999999	Центральная	0103000020E610000001000000050000009294F430B48442401840F850A2BF4A409294F430B484424096236420CFC04A40862172FA7A86424096236420CFC04A40862172FA7A8642401840F850A2BF4A409294F430B48442401840F850A2BF4A40
75375	46463	37.049810000000001	37.060042000000003	53.348978000000002	53.340538000000002	Школьная	0103000020E61000000100000005000000C381902C60864240CB85CABF96AB4A40C381902C608642400283A44FABAC4A407731CD74AF8742400283A44FABAC4A407731CD74AF874240CB85CABF96AB4A40C381902C60864240CB85CABF96AB4A40
26416	7981	36.8127	36.822330000000001	53.313932999999999	53.307271999999998	В.С.Усова	0103000020E61000000100000005000000C7BAB88D06684240FE7C5BB054A74A40C7BAB88D066842404D11E0F42EA84A408542041C426942404D11E0F42EA84A408542041C42694240FE7C5BB054A74A40C7BAB88D06684240FE7C5BB054A74A40
25726	8309	36.982984000000002	37.016528000000001	53.565862000000003	53.548985999999999	Совхозная	0103000020E61000000100000005000000E23E726BD27D42401EFB592C45C64A40E23E726BD27D42404B06802A6EC84A40F1BBE9961D8242404B06802A6EC84A40F1BBE9961D8242401EFB592C45C64A40E23E726BD27D42401EFB592C45C64A40
26492	8593	37.235787999999999	37.285384000000001	53.376629999999999	53.359597999999998	Школьная	0103000020E6100000010000000500000006651A4D2E9E42407FDAA84E07AE4A4006651A4D2E9E4240A3586E6935B04A409D66817687A44240A3586E6935B04A409D66817687A442407FDAA84E07AE4A4006651A4D2E9E42407FDAA84E07AE4A40
26495	8689	37.415784000000002	37.421487999999997	53.332537000000002	53.328223999999999	Свободная	0103000020E610000001000000050000009C19FD6838B5424093E1783E03AA4A409C19FD6838B54240E0DA899290AA4A4006D49B51F3B54240E0DA899290AA4A4006D49B51F3B5424093E1783E03AA4A409C19FD6838B5424093E1783E03AA4A40
75411	8429	36.866644000000001	36.884053000000002	53.512591	53.492378000000002	Центральная	0103000020E6100000010000000500000027A3CA30EE6E42408CA2073E06BF4A4027A3CA30EE6E4240AA9CF6949CC14A40217711A628714240AA9CF6949CC14A40217711A6287142408CA2073E06BF4A4027A3CA30EE6E42408CA2073E06BF4A40
75406	8763	37.324533000000002	37.339264999999997	53.337784999999997	53.328826999999997	Центральная	0103000020E6100000010000000500000084BC1E4C8AA942405985CD0017AA4A4084BC1E4C8AA94240280AF4893CAB4A40B6D617096DAB4240280AF4893CAB4A40B6D617096DAB42405985CD0017AA4A4084BC1E4C8AA942405985CD0017AA4A40
75298	60564	36.986811000000003	37.005721000000001	53.398632999999997	53.390175999999997	Луговая	0103000020E61000000100000005000000A22AA6D24F7E424090D78349F1B14A40A22AA6D24F7E42409D0DF96706B34A4041F33977BB8042409D0DF96706B34A4041F33977BB80424090D78349F1B14A40A22AA6D24F7E424090D78349F1B14A40
26503	8874	36.583863000000001	36.599943000000003	53.440592000000002	53.427095000000001	Советская	0103000020E61000000100000005000000172CD505BC4A42407FA4880CABB64A40172CD505BC4A42408B70935165B84A40693BA6EECA4C42408B70935165B84A40693BA6EECA4C42407FA4880CABB64A40172CD505BC4A42407FA4880CABB64A40
25293	8123	36.884466000000003	36.919986000000002	53.333365000000001	53.323614999999997	Центральная	0103000020E610000001000000050000004436902E367142405DBF60376CA94A404436902E36714240C6504EB4ABAA4A409163EB19C2754240C6504EB4ABAA4A409163EB19C27542405DBF60376CA94A404436902E367142405DBF60376CA94A40
26406	8954	36.628123000000002	36.652216000000003	53.519396	53.50609	Центральная	0103000020E61000000100000005000000C66E9F5566504240946A9F8EC7C04A40C66E9F55665042402CD670917BC24A40C7F65AD07B5342402CD670917BC24A40C7F65AD07B534240946A9F8EC7C04A40C66E9F5566504240946A9F8EC7C04A40
26917	7935	36.752315000000003	36.768386	53.402518999999998	53.387608999999998	Юбилейная	0103000020E6100000010000000500000027A5A0DB4B6042405051F52B9DB14A4027A5A0DB4B60424062821ABE85B34A40255AF2785A62424062821ABE85B34A40255AF2785A6242405051F52B9DB14A4027A5A0DB4B6042405051F52B9DB14A40
25308	7896	36.783163000000002	36.802126999999999	53.435389000000001	53.426321999999999	Грушелевского	0103000020E61000000100000005000000F83768AF3E6442405CC823B891B64A40F83768AF3E644240E204A6D3BAB74A408A1EF818AC664240E204A6D3BAB74A408A1EF818AC6642405CC823B891B64A40F83768AF3E6442405CC823B891B64A40
26519	9153	36.937691000000001	36.958010999999999	53.477912000000003	53.462179999999996	Победы	0103000020E610000001000000050000007460394206784240C16ED8B628BB4A407460394206784240D82E6D382CBD4A40A81ABD1AA07A4240D82E6D382CBD4A40A81ABD1AA07A4240C16ED8B628BB4A407460394206784240C16ED8B628BB4A40
26613	7808	36.866050999999999	36.884070999999999	53.386218	53.376952000000003	Садовая	0103000020E6100000010000000500000084D558C2DA6E4240B61490F63FB04A4084D558C2DA6E4240329067976FB14A40C72B103D29714240329067976FB14A40C72B103D29714240B61490F63FB04A4084D558C2DA6E4240B61490F63FB04A40
26913	8000	37.113168000000002	37.124890999999998	53.333188	53.323179000000003	Л.Н.Толстого	0103000020E61000000100000005000000147AFD497C8E424083E0F1ED5DA94A40147AFD497C8E4240B7B585E7A5AA4A404948A46DFC8F4240B7B585E7A5AA4A404948A46DFC8F424083E0F1ED5DA94A40147AFD497C8E424083E0F1ED5DA94A40
75445	28594	38.069074999999998	38.093446	54.038260000000001	54.030042000000002	Школьная	0103000020E6100000010000000500000050FC1873D7084340D3C08F6AD8034B4050FC1873D70843405B5F24B4E5044B4094F8DC09F60B43405B5F24B4E5044B4094F8DC09F60B4340D3C08F6AD8034B4050FC1873D7084340D3C08F6AD8034B40
25682	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	квартал им. 50-летия Октября	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
26172	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Чехова	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
26201	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Центральная	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25363	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Тульская	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
26891	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Трудовые резервы	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25361	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Смоленского	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
26867	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Октябрьская	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25357	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Мира	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25924	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Кирова	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25324	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Заводская	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25291	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Завенягина	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
26881	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Горняцкая	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25659	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Генерала Васильева	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25353	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Гагарина	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
26276	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Володарского	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25731	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	Беклемищева	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25832	5644	38.115490999999999	38.199689999999997	54.000055000000003	53.944277999999997	14 Декабря	0103000020E61000000100000005000000BDFDB968C80E4340882AFC19DEF84A40BDFDB968C80E4340C4995FCD01004B404BAB21718F194340C4995FCD01004B404BAB21718F194340882AFC19DEF84A40BDFDB968C80E4340882AFC19DEF84A40
25375	48606	38.089421000000002	38.109256000000002	53.955209000000004	53.939306000000002	Льва Толстого	0103000020E61000000100000005000000AE49B725720B4340E277D32D3BF84A40AE49B725720B434025ECDB4944FA4A402672C119FC0D434025ECDB4944FA4A402672C119FC0D4340E277D32D3BF84A40AE49B725720B4340E277D32D3BF84A40
75203	48680	38.199223000000003	38.222012999999997	53.966884999999998	53.957555999999997	переулок Клубный	0103000020E6100000010000000500000036CEA62380194340560BEC3191FA4A4036CEA6238019434019FF3EE3C2FB4A40B72407EC6A1C434019FF3EE3C2FB4A40B72407EC6A1C4340560BEC3191FA4A4036CEA62380194340560BEC3191FA4A40
26893	6066	38.204487	38.237068999999998	54.018506000000002	53.993147999999998	Центральная	0103000020E6100000010000000500000084BA48A12C1A43403D0B42791FFF4A4084BA48A12C1A4340D06394675E024B409DF2E846581E4340D06394675E024B409DF2E846581E43403D0B42791FFF4A4084BA48A12C1A43403D0B42791FFF4A40
75231	45578	38.019074000000003	38.043733000000003	53.953026000000001	53.935267000000003	Центральная	0103000020E610000001000000050000001A1A4F047102434097033DD4B6F74A401A1A4F04710243406D1E87C1FCF94A40C460FE0A990543406D1E87C1FCF94A40C460FE0A9905434097033DD4B6F74A401A1A4F047102434097033DD4B6F74A40
75446	47756	38.228929999999998	38.248297000000001	53.874077999999997	53.858628000000003	Советская	0103000020E61000000100000005000000618907944D1D434007B7B585E7ED4A40618907944D1D43409813B4C9E1EF4A40F3583332C81F43409813B4C9E1EF4A40F3583332C81F434007B7B585E7ED4A40618907944D1D434007B7B585E7ED4A40
75101	48549	38.083599999999997	38.139834999999998	53.934313000000003	53.913401	Театральная	0103000020E6100000010000000500000009F9A067B30A43401D91EF52EAF44A4009F9A067B30A4340249D819197F74A4007EBFF1CE6114340249D819197F74A4007EBFF1CE61143401D91EF52EAF44A4009F9A067B30A43401D91EF52EAF44A40
75182	48549	38.083599999999997	38.139834999999998	53.934313000000003	53.913401	Советская	0103000020E6100000010000000500000009F9A067B30A43401D91EF52EAF44A4009F9A067B30A4340249D819197F74A4007EBFF1CE6114340249D819197F74A4007EBFF1CE61143401D91EF52EAF44A4009F9A067B30A43401D91EF52EAF44A40
67858	48549	38.083599999999997	38.139834999999998	53.934313000000003	53.913401	Пионерская	0103000020E6100000010000000500000009F9A067B30A43401D91EF52EAF44A4009F9A067B30A4340249D819197F74A4007EBFF1CE6114340249D819197F74A4007EBFF1CE61143401D91EF52EAF44A4009F9A067B30A43401D91EF52EAF44A40
75161	48549	38.083599999999997	38.139834999999998	53.934313000000003	53.913401	Комсомольская	0103000020E6100000010000000500000009F9A067B30A43401D91EF52EAF44A4009F9A067B30A4340249D819197F74A4007EBFF1CE6114340249D819197F74A4007EBFF1CE61143401D91EF52EAF44A4009F9A067B30A43401D91EF52EAF44A40
75097	28780	38.077905000000001	38.103768000000002	54.009050999999999	53.988325000000003	Советская	0103000020E61000000100000005000000F29881CAF8094340DC68006F81FE4A40F29881CAF8094340807F4A9528014B40882F1345480D4340807F4A9528014B40882F1345480D4340DC68006F81FE4A40F29881CAF8094340DC68006F81FE4A40
25678	28780	38.077905000000001	38.103768000000002	54.009050999999999	53.988325000000003	Пугачёва	0103000020E61000000100000005000000F29881CAF8094340DC68006F81FE4A40F29881CAF8094340807F4A9528014B40882F1345480D4340807F4A9528014B40882F1345480D4340DC68006F81FE4A40F29881CAF8094340DC68006F81FE4A40
75107	60510	37.483750000000001	37.532601	54.058157000000001	54.029412999999998	Школьная	0103000020E6100000010000000500000052B81E85EBBD4240E38920CEC3034B4052B81E85EBBD4240498446B071074B40906802452CC44240498446B071074B40906802452CC44240E38920CEC3034B4052B81E85EBBD4240E38920CEC3034B40
75230	60545	37.604833999999997	37.620778999999999	53.442473999999997	53.430244000000002	Центральная	0103000020E6100000010000000500000022C154336BCD42406EA6423C12B74A4022C154336BCD424047AAEFFCA2B84A409485AFAF75CF424047AAEFFCA2B84A409485AFAF75CF42406EA6423C12B74A4022C154336BCD42406EA6423C12B74A40
75290	60561	37.485070999999998	37.497737000000001	53.562733000000001	53.549793999999999	Школьная	0103000020E61000000100000005000000779E78CE16BE4240BDC458A65FC64A40779E78CE16BE4240A3B08BA207C84A402C8194D8B5BF4240A3B08BA207C84A402C8194D8B5BF4240BDC458A65FC64A40779E78CE16BE4240BDC458A65FC64A40
75363	48221	37.759990999999999	37.774535	53.671492000000001	53.662860000000002	Успенская	0103000020E610000001000000050000008E20956247E14240CDE9B298D8D44A408E20956247E1424048C32973F3D54A40BE4D7FF623E3424048C32973F3D54A40BE4D7FF623E34240CDE9B298D8D44A408E20956247E14240CDE9B298D8D44A40
26794	5384	37.553936	37.610700000000001	53.635998000000001	53.599518000000003	Сельхозтехниковская,	0103000020E61000000100000005000000DD09F65FE7C6424082AE7D01BDCC4A40DD09F65FE7C642402429E96168D14A4067D5E76A2BCE42402429E96168D14A4067D5E76A2BCE424082AE7D01BDCC4A40DD09F65FE7C6424082AE7D01BDCC4A40
75377	48929	37.735143999999998	37.754556000000001	53.722909999999999	53.713377000000001	Прудная	0103000020E61000000100000005000000E1ECD63219DE4240FB5B02F04FDB4A40E1ECD63219DE4240C6F99B5088DC4A4013807F4A95E04240C6F99B5088DC4A4013807F4A95E04240FB5B02F04FDB4A40E1ECD63219DE4240FB5B02F04FDB4A40
26686	5204	37.672243999999999	37.681119000000002	53.616661999999998	53.609926000000002	Центральная	0103000020E61000000100000005000000537765170CD64240747D1F0E12CE4A40537765170CD64240CD57C9C7EECE4A4095D74AE82ED74240CD57C9C7EECE4A4095D74AE82ED74240747D1F0E12CE4A40537765170CD64240747D1F0E12CE4A40
25929	5145	37.828119000000001	37.845348999999999	53.638838	53.626798000000001	Школьная	0103000020E610000001000000050000001E19ABCDFFE942405F99B7EA3AD04A401E19ABCDFFE9424095B88E71C5D14A40685A626534EC424095B88E71C5D14A40685A626534EC42405F99B7EA3AD04A401E19ABCDFFE942405F99B7EA3AD04A40
26846	4869	37.508561999999998	37.530228999999999	53.450443999999997	53.442179000000003	Центральная	0103000020E6100000010000000500000082FE428F18C142402FFD4B5299B84A4082FE428F18C14240F7562426A8B94A4005323B8BDEC34240F7562426A8B94A4005323B8BDEC342402FFD4B5299B84A4082FE428F18C142402FFD4B5299B84A40
26289	48854	37.491709	37.508893999999998	53.542431999999998	53.535246000000001	Центральная	0103000020E610000001000000050000000E130D52F0BE42404CA8E0F082C44A400E130D52F0BE4240E5266A696EC54A40B890477023C14240E5266A696EC54A40B890477023C142404CA8E0F082C44A400E130D52F0BE42404CA8E0F082C44A40
75372	28417	37.622898999999997	37.660943000000003	53.556133000000003	53.534041000000002	Колоскова	0103000020E6100000010000000500000005DB8827BBCF424090DC9A745BC44A4005DB8827BBCF4240FA9CBB5D2FC74A4094C2BCC799D44240FA9CBB5D2FC74A4094C2BCC799D4424090DC9A745BC44A4005DB8827BBCF424090DC9A745BC44A40
26691	5223	37.753514000000003	37.774822	53.398524999999999	53.388629000000002	Молодежная	0103000020E61000000100000005000000018A912573E042407BA35698BEB14A40018A912573E04240B7D100DE02B34A40541C075E2DE34240B7D100DE02B34A40541C075E2DE342407BA35698BEB14A40018A912573E042407BA35698BEB14A40
26850	28337	37.704664000000001	37.746327999999998	53.561241000000003	53.544331999999997	Базарная	0103000020E610000001000000050000009355116E32DA42404815C5ABACC54A409355116E32DA42405116BEBED6C74A40670B08AD87DF42405116BEBED6C74A40670B08AD87DF42404815C5ABACC54A409355116E32DA42404815C5ABACC54A40
25356	4355	36.363407000000002	36.398890999999999	54.126668000000002	54.111533000000001	Молодежная	0103000020E610000001000000050000009911DE1E842E42405FB69DB6460E4B409911DE1E842E424091B932A836104B4099D53BDC0E33424091B932A836104B4099D53BDC0E3342405FB69DB6460E4B409911DE1E842E42405FB69DB6460E4B40
26140	3110	36.227789000000001	36.256894000000003	54.103937000000002	54.086528000000001	Чекалина	0103000020E61000000100000005000000BCB1A030281D42401A187959130B4B40BCB1A030281D424014ECBFCE4D0D4B40F24410E7E120424014ECBFCE4D0D4B40F24410E7E12042401A187959130B4B40BCB1A030281D42401A187959130B4B40
75098	60503	35.968525999999997	36.856996000000002	54.310682999999997	53.933799	Машиностроителей	0103000020E61000000100000005000000B0A9F3A8F8FB4140CD04C3B986F74A40B0A9F3A8F8FB41402A36E675C4274B40C366800BB26D42402A36E675C4274B40C366800BB26D4240CD04C3B986F74A40B0A9F3A8F8FB4140CD04C3B986F74A40
75443	3860	36.591732	36.636755999999998	54.230826999999998	54.197758	Молодежная	0103000020E6100000010000000500000093FFC9DFBD4B4240DD42572250194B4093FFC9DFBD4B4240530438BD8B1D4B4011C4793881514240530438BD8B1D4B4011C4793881514240DD42572250194B4093FFC9DFBD4B4240DD42572250194B40
25359	3860	36.591732	36.636755999999998	54.230826999999998	54.197758	Заводская	0103000020E6100000010000000500000093FFC9DFBD4B4240DD42572250194B4093FFC9DFBD4B4240530438BD8B1D4B4011C4793881514240530438BD8B1D4B4011C4793881514240DD42572250194B4093FFC9DFBD4B4240DD42572250194B40
25343	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	пл. Победы	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
25795	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	Суворова	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
9687	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	Проспект Мира	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
25895	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	Пионерская	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
25329	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	Октябрьская	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
25549	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	Ленинского Юбилея	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
26111	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	Белинского	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
26647	2477	36.457596000000002	36.523001999999998	54.133420999999998	54.097861000000002	 Тульская	0103000020E61000000100000005000000E5637781923A4240E54691B5860C4B40E5637781923A4240C0CC77F013114B400DDFC2BAF1424240C0CC77F013114B400DDFC2BAF1424240E54691B5860C4B40E5637781923A4240E54691B5860C4B40
26659	3677	36.094496999999997	36.123215999999999	54.180830999999998	54.159463000000002	Ленина	0103000020E61000000100000005000000F9484A7A180C424006F6984869144B40F9484A7A180C42402E8D5F7825174B40062CB98AC50F42402E8D5F7825174B40062CB98AC50F424006F6984869144B40F9484A7A180C424006F6984869144B40
26163	4378	36.337186000000003	36.356428000000001	54.109206	54.093561999999999	За мир	0103000020E61000000100000005000000A4552DE9282B4240FD12F1D6F90B4B40A4552DE9282B424074435376FA0D4B4079B0C56E9F2D424074435376FA0D4B4079B0C56E9F2D4240FD12F1D6F90B4B40A4552DE9282B4240FD12F1D6F90B4B40
26166	4674	36.427619	36.436484999999998	54.124943000000002	54.120446999999999	60 лет СССР	0103000020E61000000100000005000000F9122A38BC3642405EF3AACE6A0F4B40F9122A38BC3642409C6ED921FE0F4B40E71890BDDE3742409C6ED921FE0F4B40E71890BDDE3742405EF3AACE6A0F4B40F9122A38BC3642405EF3AACE6A0F4B40
25326	47479	36.336610999999998	36.381805	54.030707999999997	54.002585000000003	40 лет Победы	0103000020E61000000100000005000000A73CBA11162B4240E73A8DB454004B40A73CBA11162B4240DFDC5F3DEE034B4082397AFCDE304240DFDC5F3DEE034B4082397AFCDE304240E73A8DB454004B40A73CBA11162B4240E73A8DB454004B40
26845	4748	36.418312	36.436072000000003	54.185651999999997	54.178643999999998	Полевая	0103000020E610000001000000050000001EC3633F8B35424035D07CCEDD164B401EC3633F8B354240EF37DA71C3174B40C5591135D1374240EF37DA71C3174B40C5591135D137424035D07CCEDD164B401EC3633F8B35424035D07CCEDD164B40
25560	3508	36.521510999999997	36.546322000000004	54.178665000000002	54.169342	Глубокая	0103000020E610000001000000050000008BC058DFC04242406CEBA7FFAC154B408BC058DFC04242404DF8A57EDE164B40EC8A19E1ED4542404DF8A57EDE164B40EC8A19E1ED4542406CEBA7FFAC154B408BC058DFC04242406CEBA7FFAC154B40
75320	49469	36.512931999999999	36.523657999999998	54.193043000000003	54.185678000000003	Южная	0103000020E6100000010000000500000033897AC1A741424019CBF44BC4174B4033897AC1A741424062DC0DA2B5184B40F624B0390743424062DC0DA2B5184B40F624B0390743424019CBF44BC4174B4033897AC1A741424019CBF44BC4174B40
75456	60615	36.381687999999997	36.438443999999997	54.053458999999997	54.036515000000001	Романова	0103000020E6100000010000000500000048A30227DB3042401F680586AC044B4048A30227DB304240A35698BED7064B404F90D8EE1E384240A35698BED7064B404F90D8EE1E3842401F680586AC044B4048A30227DB3042401F680586AC044B40
75442	60608	36.450966000000001	36.482596000000001	54.168072000000002	54.144356000000002	улица Комсомольская	0103000020E61000000100000005000000D1CDFE40B93942409E7DE5417A124B40D1CDFE40B9394240C9AF1F6283154B401897AAB4C53D4240C9AF1F6283154B401897AAB4C53D42409E7DE5417A124B40D1CDFE40B93942409E7DE5417A124B40
26176	51240	37.590093000000003	37.592500000000001	54.108666999999997	54.107405999999997	Гагарина	0103000020E610000001000000050000009D4CDC2A88CB424074B2D47ABF0D4B409D4CDC2A88CB4240C493DDCCE80D4B40A4703D0AD7CB4240C493DDCCE80D4B40A4703D0AD7CB424074B2D47ABF0D4B409D4CDC2A88CB424074B2D47ABF0D4B40
26297	47056	37.010769000000003	37.024352	53.697366000000002	53.689982000000001	Школьная	0103000020E61000000100000005000000C367EBE060814240126A865451D84A40C367EBE060814240D2AB014A43D94A40CDCB61F71D834240D2AB014A43D94A40CDCB61F71D834240126A865451D84A40C367EBE060814240126A865451D84A40
75420	60599	37.351869000000001	37.366304999999997	53.426788999999999	53.419415999999998	Центральная	0103000020E61000000100000005000000F5BC1B0B0AAD4240A6B5696CAFB54A40F5BC1B0B0AAD424072A59E05A1B64A403EAE0D15E3AE424072A59E05A1B64A403EAE0D15E3AE4240A6B5696CAFB54A40F5BC1B0B0AAD4240A6B5696CAFB54A40
75447	1459	37.102567999999998	37.455677999999999	53.812741000000003	53.664583	Школьная	0103000020E61000000100000005000000DDCEBEF2208D4240213D450E11D54A40DDCEBEF2208D4240268FA7E507E84A40DBC01DA853BA4240268FA7E507E84A40DBC01DA853BA4240213D450E11D54A40DDCEBEF2208D4240213D450E11D54A40
75467	1459	37.102567999999998	37.455677999999999	53.812741000000003	53.664583	Центральная	0103000020E61000000100000005000000DDCEBEF2208D4240213D450E11D54A40DDCEBEF2208D4240268FA7E507E84A40DBC01DA853BA4240268FA7E507E84A40DBC01DA853BA4240213D450E11D54A40DDCEBEF2208D4240213D450E11D54A40
75297	60563	37.13232	37.146819000000001	53.6008	53.592170000000003	Почтовая	0103000020E61000000100000005000000A94D9CDCEF9042400FD6FF39CCCB4A40A94D9CDCEF904240E9B7AF03E7CC4A4039B709F7CA924240E9B7AF03E7CC4A4039B709F7CA9242400FD6FF39CCCB4A40A94D9CDCEF9042400FD6FF39CCCB4A40
25551	1828	37.175609999999999	37.201903999999999	53.587974000000003	53.577925	Центральная	0103000020E61000000100000005000000DF6C73637A96424039454772F9C94A40DF6C73637A964240FC7266BB42CB4A403E7782FDD7994240FC7266BB42CB4A403E7782FDD799424039454772F9C94A40DF6C73637A96424039454772F9C94A40
26746	801	37.266950999999999	37.325448999999999	53.725104999999999	53.682718999999999	Тимофеева	0103000020E6100000010000000500000037514B732BA24240CDAD105663D74A4037514B732BA2424042959A3DD0DC4A4009C21550A8A9424042959A3DD0DC4A4009C21550A8A94240CDAD105663D74A4037514B732BA24240CDAD105663D74A40
26575	801	37.266950999999999	37.325448999999999	53.725104999999999	53.682718999999999	Орлова	0103000020E6100000010000000500000037514B732BA24240CDAD105663D74A4037514B732BA2424042959A3DD0DC4A4009C21550A8A9424042959A3DD0DC4A4009C21550A8A94240CDAD105663D74A4037514B732BA24240CDAD105663D74A40
26710	801	37.266950999999999	37.325448999999999	53.725104999999999	53.682718999999999	Ленина	0103000020E6100000010000000500000037514B732BA24240CDAD105663D74A4037514B732BA2424042959A3DD0DC4A4009C21550A8A9424042959A3DD0DC4A4009C21550A8A94240CDAD105663D74A4037514B732BA24240CDAD105663D74A40
25514	801	37.266950999999999	37.325448999999999	53.725104999999999	53.682718999999999	Коммунаров	0103000020E6100000010000000500000037514B732BA24240CDAD105663D74A4037514B732BA2424042959A3DD0DC4A4009C21550A8A9424042959A3DD0DC4A4009C21550A8A94240CDAD105663D74A4037514B732BA24240CDAD105663D74A40
75373	46922	37.197465999999999	37.205829999999999	53.492068000000003	53.480736	Школьная	0103000020E610000001000000050000003509DE90469942404301DBC188BD4A403509DE90469942403EB48F15FCBE4A4091442FA3589A42403EB48F15FCBE4A4091442FA3589A42404301DBC188BD4A403509DE90469942404301DBC188BD4A40
25864	1729	37.225709000000002	37.244070999999998	53.658714000000003	53.646877000000003	Парковая	0103000020E61000000100000005000000D9B45208E49C42406EC493DDCCD24A40D9B45208E49C42406CB587BD50D44A407573F1B73D9F42406CB587BD50D44A407573F1B73D9F42406EC493DDCCD24A40D9B45208E49C42406EC493DDCCD24A40
26259	46735	37.375126000000002	37.392319999999998	53.621704000000001	53.596980000000002	Центральная	0103000020E610000001000000050000008DF0F62004B04240DC2E34D769CC4A408DF0F62004B042406DE525FF93CF4A408AC8B08A37B242406DE525FF93CF4A408AC8B08A37B24240DC2E34D769CC4A408DF0F62004B04240DC2E34D769CC4A40
25545	2200	37.253045	37.265109000000002	53.781506	53.767479999999999	Шоссейная	0103000020E610000001000000050000004AB54FC763A04240C32ADEC83CE24A404AB54FC763A042405BD07B6308E44A4009707A17EFA142405BD07B6308E44A4009707A17EFA14240C32ADEC83CE24A404AB54FC763A04240C32ADEC83CE24A40
26310	47026	37.092874999999999	37.107382999999999	53.749077	53.738484999999997	Центральная	0103000020E61000000100000005000000D9CEF753E38B424014CB2DAD86DE4A40D9CEF753E38B4240C89750C1E1DF4A40BC92E4B9BE8D4240C89750C1E1DF4A40BC92E4B9BE8D424014CB2DAD86DE4A40D9CEF753E38B424014CB2DAD86DE4A40
25960	46706	37.307752000000001	37.337693000000002	53.679188000000003	53.665714000000001	Парковая	0103000020E61000000100000005000000A9A3E36A64A74240A33EC91D36D54A40A9A3E36A64A74240F7EAE3A1EFD64A40488B338639AB4240F7EAE3A1EFD64A40488B338639AB4240A33EC91D36D54A40A9A3E36A64A74240A33EC91D36D54A40
25459	1676	37.458508000000002	37.465792999999998	53.572696000000001	53.567214999999997	Центральная	0103000020E61000000100000005000000297AE063B0BA42407B6649809AC84A40297AE063B0BA424067463F1A4EC94A4055DAE21A9FBB424067463F1A4EC94A4055DAE21A9FBB42407B6649809AC84A40297AE063B0BA42407B6649809AC84A40
26296	1588	37.392769000000001	37.405444000000003	53.552619	53.541302999999999	Школьная	0103000020E61000000100000005000000FAF02C4146B24240041DAD6A49C54A40FAF02C4146B24240F9122A38BCC64A40022EC896E5B34240F9122A38BCC64A40022EC896E5B34240041DAD6A49C54A40FAF02C4146B24240041DAD6A49C54A40
75339	46925	37.267023000000002	37.289157000000003	53.463836999999998	53.451622999999998	Молодежная	0103000020E61000000100000005000000D12346CF2DA242408A8F4FC8CEB94A40D12346CF2DA242405ED6C4025FBB4A406A34B91803A542405ED6C4025FBB4A406A34B91803A542408A8F4FC8CEB94A40D12346CF2DA242408A8F4FC8CEB94A40
75260	60553	37.107823000000003	37.145265000000002	53.605753	53.599832999999997	Школьная	0103000020E61000000100000005000000D960E124CD8D4240E107E753C7CC4A40D960E124CD8D4240193A765089CD4A407120240B98924240193A765089CD4A407120240B98924240E107E753C7CC4A40D960E124CD8D4240E107E753C7CC4A40
75312	46857	37.168289000000001	37.196370000000002	53.561208999999998	53.545909999999999	Школьная	0103000020E6100000010000000500000066A3737E8A9542409947FE60E0C54A4066A3737E8A954240459C4EB2D5C74A4030F5F3A622994240459C4EB2D5C74A4030F5F3A6229942409947FE60E0C54A4066A3737E8A9542409947FE60E0C54A40
75383	226	36.993763999999999	37.015673999999997	53.927273	53.915899000000003	Школьная	0103000020E6100000010000000500000098F8A3A8337F424035B8AD2D3CF54A4098F8A3A8337F42405EBBB4E1B0F64A40E1B20A9B018242405EBBB4E1B0F64A40E1B20A9B0182424035B8AD2D3CF54A4098F8A3A8337F424035B8AD2D3CF54A40
26880	674	36.630746000000002	36.650661999999997	53.794763000000003	53.781294000000003	площадь Стрелецкая	0103000020E610000001000000050000009A0AF148BC504240D047197101E44A409A0AF148BC504240128942CBBAE54A40FE5F75E448534240128942CBBAE54A40FE5F75E448534240D047197101E44A409A0AF148BC504240D047197101E44A40
25834	46302	36.795577999999999	36.808962999999999	53.891008999999997	53.883839999999999	Центральная	0103000020E6100000010000000500000063B5F97FD5654240C5724BAB21F14A4063B5F97FD565424088B839950CF24A4047567E198C67424088B839950CF24A4047567E198C674240C5724BAB21F14A4063B5F97FD5654240C5724BAB21F14A40
75402	46409	36.509284999999998	36.797122999999999	53.894241000000001	53.856647000000002	Шарова	0103000020E61000000100000005000000F3AB394030414240B79BE09BA6ED4A40F3AB39403041424005DF347D76F24A40D8F15F200866424005DF347D76F24A40D8F15F2008664240B79BE09BA6ED4A40F3AB394030414240B79BE09BA6ED4A40
26357	47	36.568213999999998	36.582875000000001	54.055964000000003	54.047702000000001	Центральная	0103000020E610000001000000050000008E90813CBB48424016FA60191B064B408E90813CBB4842406EE00ED429074B40F853E3A59B4A42406EE00ED429074B40F853E3A59B4A424016FA60191B064B408E90813CBB48424016FA60191B064B40
26544	46337	36.821854000000002	36.846009000000002	53.857214999999997	53.844383000000001	Центральная	0103000020E610000001000000050000001C0B0A83326942403126FDBD14EC4A401C0B0A833269424000529B38B9ED4A40938FDD054A6C424000529B38B9ED4A40938FDD054A6C42403126FDBD14EC4A401C0B0A83326942403126FDBD14EC4A40
25508	32223	36.660732000000003	36.712214000000003	53.952776999999998	53.912340999999998	Победы	0103000020E61000000100000005000000D9B5BDDD9254424064E60297C7F44A40D9B5BDDD92544240C4B0C398F4F94A406EE00ED4295B4240C4B0C398F4F94A406EE00ED4295B424064E60297C7F44A40D9B5BDDD9254424064E60297C7F44A40
75271	32223	36.660732000000003	36.712214000000003	53.952776999999998	53.912340999999998	Ленина	0103000020E61000000100000005000000D9B5BDDD9254424064E60297C7F44A40D9B5BDDD92544240C4B0C398F4F94A406EE00ED4295B4240C4B0C398F4F94A406EE00ED4295B424064E60297C7F44A40D9B5BDDD9254424064E60297C7F44A40
26548	32223	36.660732000000003	36.712214000000003	53.952776999999998	53.912340999999998	Карла Маркса	0103000020E61000000100000005000000D9B5BDDD9254424064E60297C7F44A40D9B5BDDD92544240C4B0C398F4F94A406EE00ED4295B4240C4B0C398F4F94A406EE00ED4295B424064E60297C7F44A40D9B5BDDD9254424064E60297C7F44A40
25829	32223	36.660732000000003	36.712214000000003	53.952776999999998	53.912340999999998	50 лет Октября	0103000020E61000000100000005000000D9B5BDDD9254424064E60297C7F44A40D9B5BDDD92544240C4B0C398F4F94A406EE00ED4295B4240C4B0C398F4F94A406EE00ED4295B424064E60297C7F44A40D9B5BDDD9254424064E60297C7F44A40
25843	612	36.643034999999998	36.662672000000001	53.963897000000003	53.943694999999998	Молодежная	0103000020E6100000010000000500000078978BF84E52424009336DFFCAF84A4078978BF84E52424034DB15FA60FB4A40CAFCA36FD254424034DB15FA60FB4A40CAFCA36FD254424009336DFFCAF84A4078978BF84E52424009336DFFCAF84A40
11712	8491	36.787860999999999	36.804488999999997	53.964480000000002	53.958827999999997	Бунина	0103000020E610000001000000050000009D6516A1D86442409A3E3BE0BAFA4A409D6516A1D8644240B3D2A41474FB4A40F17EDC7EF9664240B3D2A41474FB4A40F17EDC7EF96642409A3E3BE0BAFA4A409D6516A1D86442409A3E3BE0BAFA4A40
25876	150	36.795183000000002	36.828968000000003	53.944457999999997	53.935378999999998	Школьная	0103000020E61000000100000005000000E7AA798EC8654240BE2EC37FBAF74A40E7AA798EC86542400839EFFFE3F84A401CB7989F1B6A42400839EFFFE3F84A401CB7989F1B6A4240BE2EC37FBAF74A40E7AA798EC8654240BE2EC37FBAF74A40
67859	48484	36.999710999999998	37.010302000000003	53.809429000000002	53.805441000000002	Дружбы	0103000020E61000000100000005000000C939B187F67F4240C4EDD0B018E74A40C939B187F67F42408DB7955E9BE74A40AD8A7093518142408DB7955E9BE74A40AD8A709351814240C4EDD0B018E74A40C939B187F67F4240C4EDD0B018E74A40
9870	487	36.979131000000002	36.995992000000001	53.805664	53.795161	Луговая	0103000020E61000000100000005000000F9BF232A547D4240FF06EDD5C7E54A40F9BF232A547D424043C879FF1FE74A40F08975AA7C7F424043C879FF1FE74A40F08975AA7C7F4240FF06EDD5C7E54A40F9BF232A547D4240FF06EDD5C7E54A40
26598	46207	36.689279999999997	36.714128000000002	53.988537000000001	53.972197000000001	Центральная	0103000020E61000000100000005000000B8E4B8533A584240792288F370FC4A40B8E4B8533A58424067F1626188FE4A403694DA8B685B424067F1626188FE4A403694DA8B685B4240792288F370FC4A40B8E4B8533A584240792288F370FC4A40
26020	45879	38.537419999999997	38.553994000000003	54.247070999999998	54.228512000000002	Центральная	0103000020E61000000100000005000000B01BB62DCA4443402D5F97E13F1D4B40B01BB62DCA4443401F65C405A01F4B4012178046E94643401F65C405A01F4B4012178046E94643402D5F97E13F1D4B40B01BB62DCA4443402D5F97E13F1D4B40
25318	31513	38.34881	38.396977999999997	54.077153000000003	54.0608	Зеленая	0103000020E6100000010000000500000046425BCEA52C434064CC5D4BC8074B4046425BCEA52C4340E7E44526E0094B40A19DD32CD0324340E7E44526E0094B40A19DD32CD032434064CC5D4BC8074B4046425BCEA52C434064CC5D4BC8074B40
75376	31856	38.468744000000001	38.486530999999999	54.189523999999999	54.175687000000003	Гукова	0103000020E610000001000000050000001E19ABCDFF3B43408BAA5FE97C164B401E19ABCDFF3B43404FE78A5242184B40BEBED6A5463E43404FE78A5242184B40BEBED6A5463E43408BAA5FE97C164B401E19ABCDFF3B43408BAA5FE97C164B40
25321	51160	38.530315000000002	38.560076000000002	54.157896999999998	54.143881	Школьная	0103000020E6100000010000000500000004CAA65CE143434005C24EB16A124B4004CAA65CE1434340799109F835144B4023A30392B0474340799109F835144B4023A30392B047434005C24EB16A124B4004CAA65CE143434005C24EB16A124B40
26786	46000	38.232486999999999	38.244731000000002	54.201639	54.194186000000002	Молодежная	0103000020E6100000010000000500000061DF4E22C21D4340A8AB3B16DB184B4061DF4E22C21D4340904C874ECF194B40A0A86C58531F4340904C874ECF194B40A0A86C58531F4340A8AB3B16DB184B4061DF4E22C21D4340A8AB3B16DB184B40
75340	45528	38.593457000000001	38.614899999999999	54.198827000000001	54.186605	Советская	0103000020E61000000100000005000000884A2366F64B4340922232ACE2174B40884A2366F64B4340E947C32973194B40BB270F0BB54E4340E947C32973194B40BB270F0BB54E4340922232ACE2174B40884A2366F64B4340922232ACE2174B40
75436	45528	38.593457000000001	38.614899999999999	54.198827000000001	54.186605	Пролетарская	0103000020E61000000100000005000000884A2366F64B4340922232ACE2174B40884A2366F64B4340E947C32973194B40BB270F0BB54E4340E947C32973194B40BB270F0BB54E4340922232ACE2174B40884A2366F64B4340922232ACE2174B40
75398	45796	38.418976999999998	38.442225999999998	54.110450999999998	54.099665999999999	Победы	0103000020E610000001000000050000005A63D009A1354340F64201DBC10C4B405A63D009A1354340BE672442230E4B406FB88FDC9A384340BE672442230E4B406FB88FDC9A384340F64201DBC10C4B405A63D009A1354340F64201DBC10C4B40
25312	51159	38.441256000000003	38.460228000000001	54.145494999999997	54.135610999999997	Центральная	0103000020E61000000100000005000000F7949C137B3843402AFD84B35B114B40F7949C137B384340A25D85949F124B400C5A48C0E83A4340A25D85949F124B400C5A48C0E83A43402AFD84B35B114B40F7949C137B3843402AFD84B35B114B40
25303	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	проспект Победы	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26648	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Школьная	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26887	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Шахтерская	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25721	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Центральная	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25300	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Трудовые резервы	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26391	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Солнечная	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25302	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Свердлова	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26021	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Рудничная	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25322	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Пушкина 	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25434	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Присягина	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26462	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Орджоникидзе	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25412	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Октябрьская	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25716	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Московская	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25762	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Молодежная	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25956	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Мира	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26388	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Маяковского	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26396	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Маклец	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25472	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Ленина	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25964	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Кукунина	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25980	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Куйбышева	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26216	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Клинский проезд	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26222	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Калинина	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26767	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Дружбы	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26884	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Донская	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25748	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Демкина	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25974	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Березовая	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25430	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Бережного	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25808	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	Аварийная	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
25464	27080	38.167476000000001	38.34872	54.10154	53.976953000000002	1-ая Транспортная	0103000020E61000000100000005000000B56E83DA6F154340535DC0CB0CFD4A40B56E83DA6F154340309E4143FF0C4B4006BB61DBA22C4340309E4143FF0C4B4006BB61DBA22C4340535DC0CB0CFD4A40B56E83DA6F154340535DC0CB0CFD4A40
26788	45719	38.364134999999997	38.389485999999998	54.049135	54.04177	Толстого	0103000020E610000001000000050000001B2AC6F99B2E43401AFA27B858054B401B2AC6F99B2E4340630B410E4A064B40FB1F60ADDA314340630B410E4A064B40FB1F60ADDA3143401AFA27B858054B401B2AC6F99B2E43401AFA27B858054B40
75229	60536	38.485632000000003	38.501837999999999	54.127665999999998	54.118051000000001	Центральная	0103000020E610000001000000050000000FF27A30293E43404B21904B1C0F4B400FF27A30293E4340D367075C57104B40EDF1423A3C404340D367075C57104B40EDF1423A3C4043404B21904B1C0F4B400FF27A30293E43404B21904B1C0F4B40
25452	31902	38.718843999999997	38.743045000000002	54.151749000000002	54.143479999999997	Школьная	0103000020E6100000010000000500000081768714035C4340A6D0798D5D124B4081768714035C4340B119E0826C134B40693A3B191C5F4340B119E0826C134B40693A3B191C5F4340A6D0798D5D124B4081768714035C4340A6D0798D5D124B40
25736	31334	38.217494000000002	38.239674000000001	54.037731000000001	54.026446	Новая	0103000020E61000000100000005000000C289E8D7D61B4340158E209562034B40C289E8D7D61B4340CF85915ED4044B40CBD93BA3AD1E4340CF85915ED4044B40CBD93BA3AD1E4340158E209562034B40C289E8D7D61B4340158E209562034B40
26260	31994	38.344265	38.363857000000003	54.230943000000003	54.220346999999997	Садовая	0103000020E61000000100000005000000271422E0102C4340C7629B54341C4B40271422E0102C4340BD1E4C8A8F1D4B40D9B5BDDD922E4340BD1E4C8A8F1D4B40D9B5BDDD922E4340C7629B54341C4B40271422E0102C4340C7629B54341C4B40
26865	31235	38.157809999999998	38.175201999999999	54.119143999999999	54.108086999999998	Центральная	0103000020E61000000100000005000000AA7D3A1E33144340B60F79CBD50D4B40AA7D3A1E33144340DFC14F1C400F4B40CE18E6046D164340DFC14F1C400F4B40CE18E6046D164340B60F79CBD50D4B40AA7D3A1E33144340B60F79CBD50D4B40
26072	31702	38.650770000000001	38.670425000000002	54.135162000000001	54.126711	Новики	0103000020E61000000100000005000000E59B6D6E4C5343409085E81038104B40E59B6D6E4C534340BBD408FD4C114B40DDB5847CD0554340BBD408FD4C114B40DDB5847CD05543409085E81038104B40E59B6D6E4C5343409085E81038104B40
26878	20702	37.832422000000001	37.863000999999997	54.137473	54.120525999999998	Садовая	0103000020E61000000100000005000000473CD9CD8CEA4240AA285E656D0F4B40473CD9CD8CEA4240A08A1BB798114B4028B517D176EE4240A08A1BB798114B4028B517D176EE4240AA285E656D0F4B40473CD9CD8CEA4240AA285E656D0F4B40
26185	20702	37.832422000000001	37.863000999999997	54.137473	54.120525999999998	Ленина	0103000020E61000000100000005000000473CD9CD8CEA4240AA285E656D0F4B40473CD9CD8CEA4240A08A1BB798114B4028B517D176EE4240A08A1BB798114B4028B517D176EE4240AA285E656D0F4B40473CD9CD8CEA4240AA285E656D0F4B40
25931	20800	37.775244999999998	37.793346	54.182532999999999	54.172103999999997	Совхозная	0103000020E610000001000000050000009AB1683A3BE3424061C1FD8007164B409AB1683A3BE342406BB8C83D5D174B40CA349A5C8CE542406BB8C83D5D174B40CA349A5C8CE5424061C1FD8007164B409AB1683A3BE3424061C1FD8007164B40
75077	60495	37.169798	38.028030999999999	54.409027000000002	54.039316999999997	Центральная	0103000020E610000001000000050000008E76DCF0BB954240A296E65608054B408E76DCF0BB9542402B172AFF5A344B4018231285960343402B172AFF5A344B401823128596034340A296E65608054B408E76DCF0BB954240A296E65608054B40
75197	60495	37.169798	38.028030999999999	54.409027000000002	54.039316999999997	Совхозная	0103000020E610000001000000050000008E76DCF0BB954240A296E65608054B408E76DCF0BB9542402B172AFF5A344B4018231285960343402B172AFF5A344B401823128596034340A296E65608054B408E76DCF0BB954240A296E65608054B40
75261	27227	37.761887000000002	37.796363999999997	54.304679	54.289825	Центральная	0103000020E61000000100000005000000B01F628385E14240174850FC18254B40B01F628385E142409563B2B8FF264B401ADB6B41EFE542409563B2B8FF264B401ADB6B41EFE54240174850FC18254B40B01F628385E14240174850FC18254B40
75279	48114	37.829726999999998	37.849696999999999	54.331704000000002	54.320540999999999	Советское	0103000020E61000000100000005000000D9CD8C7E34EA42407903CC7C07294B40D9CD8C7E34EA4240E8F9D346752A4B4031410DDFC2EC4240E8F9D346752A4B4031410DDFC2EC42407903CC7C07294B40D9CD8C7E34EA42407903CC7C07294B40
26366	48114	37.829726999999998	37.849696999999999	54.331704000000002	54.320540999999999	Советская	0103000020E61000000100000005000000D9CD8C7E34EA42407903CC7C07294B40D9CD8C7E34EA4240E8F9D346752A4B4031410DDFC2EC4240E8F9D346752A4B4031410DDFC2EC42407903CC7C07294B40D9CD8C7E34EA42407903CC7C07294B40
25906	26690	37.733212000000002	37.746048999999999	54.109844000000002	54.101407999999999	Центральная	0103000020E6100000010000000500000073840CE4D9DD4240C1C6F5EFFA0C4B4073840CE4D9DD4240B7D4415E0F0E4B40541B9C887EDF4240B7D4415E0F0E4B40541B9C887EDF4240C1C6F5EFFA0C4B4073840CE4D9DD4240C1C6F5EFFA0C4B40
25916	27250	37.563485	37.576994999999997	54.300328999999998	54.289361999999997	Московская	0103000020E61000000100000005000000AE64C74620C84240425A63D009254B40AE64C74620C842402B85402E71264B404E7ADFF8DAC942402B85402E71264B404E7ADFF8DAC94240425A63D009254B40AE64C74620C84240425A63D009254B40
25347	20469	37.395778	37.408382000000003	54.300119000000002	54.290596999999998	Школьная	0103000020E61000000100000005000000F73C7FDAA8B2424069A8514832254B40F73C7FDAA8B2424041F4A44C6A264B40362383DC45B4424041F4A44C6A264B40362383DC45B4424069A8514832254B40F73C7FDAA8B2424069A8514832254B40
75285	60558	37.169798	38.028030999999999	54.409027000000002	54.039316999999997	Центральная	0103000020E610000001000000050000008E76DCF0BB954240A296E65608054B408E76DCF0BB9542402B172AFF5A344B4018231285960343402B172AFF5A344B401823128596034340A296E65608054B408E76DCF0BB954240A296E65608054B40
75078	27134	37.702750999999999	37.719028000000002	54.261904000000001	54.255060999999998	Центральная	0103000020E610000001000000050000009B1DA9BEF3D9424016BEBED6A5204B409B1DA9BEF3D942408658FD1186214B404374081C09DC42408658FD1186214B404374081C09DC424016BEBED6A5204B409B1DA9BEF3D9424016BEBED6A5204B40
26146	25905	37.436318999999997	37.470734	54.309317	54.267277999999997	Центральная	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
75270	25905	37.436318999999997	37.470734	54.309317	54.267277999999997	Свердлова	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
26127	25905	37.436318999999997	37.470734	54.309317	54.267277999999997	Механизаторов	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
26861	25905	37.436318999999997	37.470734	54.309317	54.267277999999997	Ленина	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
25339	25905	37.436318999999997	37.470734	54.309317	54.267277999999997	Гагарина 	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
75167	25905	37.436318999999997	37.470734	54.309317	54.267277999999997	Гагарина	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
75245	25905	37.436318999999997	37.470734	54.309317	54.267277999999997	Буденого	0103000020E61000000100000005000000CCCF0D4DD9B742405B785E2A36224B40CCCF0D4DD9B74240658C0FB397274B40C18EFF0241BC4240658C0FB397274B40C18EFF0241BC42405B785E2A36224B40CCCF0D4DD9B742405B785E2A36224B40
11990	40984	37.244501999999997	37.254913000000002	54.079994999999997	54.073349	Игоревская	0103000020E610000001000000050000003EE76ED74B9F4240DF18028063094B403EE76ED74B9F4240F86BB2463D0A4B40A2293BFDA0A04240F86BB2463D0A4B40A2293BFDA0A04240DF18028063094B403EE76ED74B9F4240DF18028063094B40
26149	26332	37.669359999999998	37.717689999999997	54.145321000000003	54.105446999999998	Центральная	0103000020E6100000010000000500000012A0A696ADD542400C3B8C497F0D4B4012A0A696ADD542400536E7E099124B4047551344DDDB42400536E7E099124B4047551344DDDB42400C3B8C497F0D4B4012A0A696ADD542400C3B8C497F0D4B40
26159	26886	37.366179000000002	37.388528999999998	54.154476000000003	54.139113000000002	Школьная	0103000020E61000000100000005000000B2BD16F4DEAE424067B96C74CE114B40B2BD16F4DEAE42402A029CDEC5134B4017467A51BBB142402A029CDEC5134B4017467A51BBB1424067B96C74CE114B40B2BD16F4DEAE424067B96C74CE114B40
26669	26886	37.366179000000002	37.388528999999998	54.154476000000003	54.139113000000002	Новая	0103000020E61000000100000005000000B2BD16F4DEAE424067B96C74CE114B40B2BD16F4DEAE42402A029CDEC5134B4017467A51BBB142402A029CDEC5134B4017467A51BBB1424067B96C74CE114B40B2BD16F4DEAE424067B96C74CE114B40
26856	19609	37.477193	37.503289000000002	54.283996000000002	54.250757999999998	Советская	0103000020E61000000100000005000000A87004A914BD4240ED9A90D618204B40A87004A914BD4240F0181EFB59244B40E1B721C66BC04240F0181EFB59244B40E1B721C66BC04240ED9A90D618204B40A87004A914BD4240ED9A90D618204B40
26651	19609	37.477193	37.503289000000002	54.283996000000002	54.250757999999998	Пушкина	0103000020E61000000100000005000000A87004A914BD4240ED9A90D618204B40A87004A914BD4240F0181EFB59244B40E1B721C66BC04240F0181EFB59244B40E1B721C66BC04240ED9A90D618204B40A87004A914BD4240ED9A90D618204B40
25613	19609	37.477193	37.503289000000002	54.283996000000002	54.250757999999998	Клубная	0103000020E61000000100000005000000A87004A914BD4240ED9A90D618204B40A87004A914BD4240F0181EFB59244B40E1B721C66BC04240F0181EFB59244B40E1B721C66BC04240ED9A90D618204B40A87004A914BD4240ED9A90D618204B40
26349	27418	37.650872999999997	37.668812000000003	54.297905999999998	54.282819000000003	Центральная	0103000020E61000000100000005000000B96C74CE4FD34240FED7B96933244B40B96C74CE4FD342401EA4A7C821264B401096B1A19BD542401EA4A7C821264B401096B1A19BD54240FED7B96933244B40B96C74CE4FD34240FED7B96933244B40
26683	27559	37.248041000000001	37.271073999999999	54.252310000000001	54.225521999999998	Центральная	0103000020E610000001000000050000009888B7CEBF9F4240A643A7E7DD1C4B409888B7CEBF9F4240153AAFB14B204B40E065868DB2A24240153AAFB14B204B40E065868DB2A24240A643A7E7DD1C4B409888B7CEBF9F4240A643A7E7DD1C4B40
26115	47918	38.471744000000001	38.487088	53.415970999999999	53.406986000000003	Молодежная	0103000020E61000000100000005000000C80A7E1B623C434006F7031E18B44A40C80A7E1B623C4340CE8AA8893EB54A4014234BE6583E4340CE8AA8893EB54A4014234BE6583E434006F7031E18B44A40C80A7E1B623C434006F7031E18B44A40
75251	47792	38.542109000000004	38.659132999999997	53.420012	53.393681999999998	Центральная	0103000020E6100000010000000500000003EFE4D3634543400E83F92B64B24A4003EFE4D363454340BAF605F4C2B54A40705B5B785E544340BAF605F4C2B54A40705B5B785E5443400E83F92B64B24A4003EFE4D3634543400E83F92B64B24A40
26629	47792	38.542109000000004	38.659132999999997	53.420012	53.393681999999998	Запрудная	0103000020E6100000010000000500000003EFE4D3634543400E83F92B64B24A4003EFE4D363454340BAF605F4C2B54A40705B5B785E544340BAF605F4C2B54A40705B5B785E5443400E83F92B64B24A4003EFE4D3634543400E83F92B64B24A40
25522	25027	38.410299999999999	38.432577999999999	53.460158999999997	53.452067999999997	Центральная	0103000020E610000001000000050000003FC6DCB584344340B8C83D5DDDB94A403FC6DCB584344340E3FA777DE6BA4A400B7C45B75E374340E3FA777DE6BA4A400B7C45B75E374340B8C83D5DDDB94A403FC6DCB584344340B8C83D5DDDB94A40
75349	47690	38.461081	38.477080000000001	53.562787	53.548766999999998	Центральная	0103000020E610000001000000050000004BE7C3B3043B4340E00F3FFF3DC64A404BE7C3B3043B434096CE876709C84A40B0C91AF5103D434096CE876709C84A40B0C91AF5103D4340E00F3FFF3DC64A404BE7C3B3043B4340E00F3FFF3DC64A40
75451	60613	38.379477999999999	38.698740000000001	53.403587999999999	53.379987	Школьная	0103000020E6100000010000000500000097C62FBC92304340DCF3FC69A3B04A4097C62FBC923043406E8786C5A8B34A401A34F44F705943406E8786C5A8B34A401A34F44F70594340DCF3FC69A3B04A4097C62FBC92304340DCF3FC69A3B04A40
26379	25543	38.64423	38.684789000000002	53.452154	53.414977999999998	Школьная	0103000020E61000000100000005000000118DEE20765243409D47C5FF1DB54A40118DEE2076524340B760A92EE0B94A408DD47B2AA7574340B760A92EE0B94A408DD47B2AA75743409D47C5FF1DB54A40118DEE20765243409D47C5FF1DB54A40
26819	25543	38.64423	38.684789000000002	53.452154	53.414977999999998	Парковая	0103000020E61000000100000005000000118DEE20765243409D47C5FF1DB54A40118DEE2076524340B760A92EE0B94A408DD47B2AA7574340B760A92EE0B94A408DD47B2AA75743409D47C5FF1DB54A40118DEE20765243409D47C5FF1DB54A40
26831	25543	38.64423	38.684789000000002	53.452154	53.414977999999998	Октябрьская	0103000020E61000000100000005000000118DEE20765243409D47C5FF1DB54A40118DEE2076524340B760A92EE0B94A408DD47B2AA7574340B760A92EE0B94A408DD47B2AA75743409D47C5FF1DB54A40118DEE20765243409D47C5FF1DB54A40
26626	25543	38.64423	38.684789000000002	53.452154	53.414977999999998	1-ая Привокзальная	0103000020E61000000100000005000000118DEE20765243409D47C5FF1DB54A40118DEE2076524340B760A92EE0B94A408DD47B2AA7574340B760A92EE0B94A408DD47B2AA75743409D47C5FF1DB54A40118DEE20765243409D47C5FF1DB54A40
75392	60593	38.589531999999998	38.612735000000001	53.508479000000001	53.495168999999997	Садовая	0103000020E6100000010000000500000005F9D9C8754B43401B7FA2B261BF4A4005F9D9C8754B4340F5D901D715C14A40AA0EB9196E4E4340F5D901D715C14A40AA0EB9196E4E43401B7FA2B261BF4A4005F9D9C8754B43401B7FA2B261BF4A40
75444	60609	38.857131000000003	38.879165999999998	53.573059000000001	53.565615999999999	Центральная	0103000020E61000000100000005000000A3B1F677B66D4340130CE71A66C84A40A3B1F677B66D4340D8D64FFF59C94A40A8E0F08288704340D8D64FFF59C94A40A8E0F08288704340130CE71A66C84A40A3B1F677B66D4340130CE71A66C84A40
26898	47694	38.477682000000001	38.490861000000002	53.568888999999999	53.553260999999999	Дорожная	0103000020E61000000100000005000000A6F10BAF243D43407D93A641D1C64A40A6F10BAF243D4340EE06D15AD1C84A40E1F08288D43E4340EE06D15AD1C84A40E1F08288D43E43407D93A641D1C64A40A6F10BAF243D43407D93A641D1C64A40
75430	60602	38.689819	38.716687999999998	53.499780999999999	53.483763000000003	Центральная	0103000020E6100000010000000500000068942EFD4B584340E7012CF2EBBD4A4068942EFD4B584340C214E5D2F8BF4A40C3B7B06EBC5B4340C214E5D2F8BF4A40C3B7B06EBC5B4340E7012CF2EBBD4A4068942EFD4B584340E7012CF2EBBD4A40
11717	39105	34.509590000000003	34.526001999999998	56.922525999999998	56.919105999999999	Школьная	0103000020E61000000100000005000000302FC03E3A41414058C7F143A5754C40302FC03E3A414140D7DAFB5415764C40B7D0950854434140D7DAFB5415764C40B7D095085443414058C7F143A5754C40302FC03E3A41414058C7F143A5754C40
26829	21284	37.978875000000002	38.012884999999997	54.10389	54.081595	Советская	0103000020E610000001000000050000009EEFA7C64BFD4240314278B4710A4B409EEFA7C64BFD4240D3307C444C0D4B40F2CD3637A6014340D3307C444C0D4B40F2CD3637A6014340314278B4710A4B409EEFA7C64BFD4240314278B4710A4B40
26198	21284	37.978875000000002	38.012884999999997	54.10389	54.081595	Первомайская	0103000020E610000001000000050000009EEFA7C64BFD4240314278B4710A4B409EEFA7C64BFD4240D3307C444C0D4B40F2CD3637A6014340D3307C444C0D4B40F2CD3637A6014340314278B4710A4B409EEFA7C64BFD4240314278B4710A4B40
25364	21284	37.978875000000002	38.012884999999997	54.10389	54.081595	Ленина	0103000020E610000001000000050000009EEFA7C64BFD4240314278B4710A4B409EEFA7C64BFD4240D3307C444C0D4B40F2CD3637A6014340D3307C444C0D4B40F2CD3637A6014340314278B4710A4B409EEFA7C64BFD4240314278B4710A4B40
25700	47425	38.017152000000003	38.047344000000002	53.906947000000002	53.893439000000001	Молодежная	0103000020E61000000100000005000000CF8767093202434048FC8A355CF24A40CF87670932024340481ADCD616F44A40B7D4415E0F064340481ADCD616F44A40B7D4415E0F06434048FC8A355CF24A40CF8767093202434048FC8A355CF24A40
26502	22498	37.802427999999999	37.819792	53.892612	53.885066000000002	Ленина	0103000020E6100000010000000500000085B2F0F5B5E642409966BAD749F14A4085B2F0F5B5E6424032022A1C41F24A40DFC2BAF1EEE8424032022A1C41F24A40DFC2BAF1EEE842409966BAD749F14A4085B2F0F5B5E642409966BAD749F14A40
25505	23969	37.749966000000001	37.761347999999998	54.111792000000001	54.105690000000003	Центральная	0103000020E61000000100000005000000548EC9E2FEDF4240D3C1FA3F870D4B40548EC9E2FEDF42402BFA43334F0E4B400070ECD973E142402BFA43334F0E4B400070ECD973E14240D3C1FA3F870D4B40548EC9E2FEDF4240D3C1FA3F870D4B40
26284	47280	37.848906999999997	37.866253	53.88964	53.879030999999998	Молодежная	0103000020E61000000100000005000000382C0DFCA8EC4240C8957A1684F04A40382C0DFCA8EC4240529B38B9DFF14A40EC87D860E1EE4240529B38B9DFF14A40EC87D860E1EE4240C8957A1684F04A40382C0DFCA8EC4240C8957A1684F04A40
75114	22405	37.721623999999998	37.745969000000002	53.913241999999997	53.902617999999997	Клубная	0103000020E610000001000000050000001D01DC2C5EDC4240F56393FC88F34A401D01DC2C5EDC4240B4AA251DE5F44A40386A85E97BDF4240B4AA251DE5F44A40386A85E97BDF4240F56393FC88F34A401D01DC2C5EDC4240F56393FC88F34A40
26143	23025	37.792313	37.801780999999998	54.034987000000001	54.029767	Ленина	0103000020E610000001000000050000000B992B836AE5424001C0B167CF034B400B992B836AE5424080643A747A044B40EFC682C2A0E6424080643A747A044B40EFC682C2A0E6424001C0B167CF034B400B992B836AE5424001C0B167CF034B40
25861	24866	37.971338000000003	37.993068000000001	54.078426	54.066395999999997	Комсомольская	0103000020E6100000010000000500000058AEB7CD54FC4240E84A04AA7F084B4058AEB7CD54FC4240FB93F8DC090A4B40215A2BDA1CFF4240FB93F8DC090A4B40215A2BDA1CFF4240E84A04AA7F084B4058AEB7CD54FC4240E84A04AA7F084B40
75435	60604	\N	\N	\N	\N	Центральная	\N
75423	47909	38.004576	38.013145000000002	54.088988999999998	54.085731000000003	Центральная	0103000020E610000001000000050000005A2C45F2950043406FA0C03BF90A4B405A2C45F295004340145AD6FD630B4B408F8D40BCAE014340145AD6FD630B4B408F8D40BCAE0143406FA0C03BF90A4B405A2C45F2950043406FA0C03BF90A4B40
25851	47319	37.902563000000001	37.918318999999997	53.848877000000002	53.832124999999998	Зеленая	0103000020E6100000010000000500000032CA332F87F342408D976E1283EA4A4032CA332F87F34240CEA96400A8EC4A40D0251C7A8BF54240CEA96400A8EC4A40D0251C7A8BF542408D976E1283EA4A4032CA332F87F342408D976E1283EA4A40
75450	47350	37.802804999999999	37.823816999999998	53.862578999999997	53.850571000000002	Центральная	0103000020E610000001000000050000005B087250C2E6424088F6B182DFEC4A405B087250C2E64240B29B19FD68EE4A40C571E0D572E94240B29B19FD68EE4A40C571E0D572E9424088F6B182DFEC4A405B087250C2E6424088F6B182DFEC4A40
25465	23076	37.684308000000001	37.714483000000001	53.950986	53.934128000000001	Советская	0103000020E610000001000000050000001232906797D7424092239D8191F74A401232906797D74240187AC4E8B9F94A402446CF2D74DB4240187AC4E8B9F94A402446CF2D74DB424092239D8191F74A401232906797D7424092239D8191F74A40
75088	23076	37.684308000000001	37.714483000000001	53.950986	53.934128000000001	Лермонтова	0103000020E610000001000000050000001232906797D7424092239D8191F74A401232906797D74240187AC4E8B9F94A402446CF2D74DB4240187AC4E8B9F94A402446CF2D74DB424092239D8191F74A401232906797D7424092239D8191F74A40
25909	23076	37.684308000000001	37.714483000000001	53.950986	53.934128000000001	Комсомольская	0103000020E610000001000000050000001232906797D7424092239D8191F74A401232906797D74240187AC4E8B9F94A402446CF2D74DB4240187AC4E8B9F94A402446CF2D74DB424092239D8191F74A401232906797D7424092239D8191F74A40
75382	24183	37.873367999999999	37.885503999999997	53.834223999999999	53.826141	Центральная	0103000020E61000000100000005000000BCAFCA85CAEF42403F7100FDBEE94A40BCAFCA85CAEF4240E7C41EDAC7EA4A40143DF03158F14240E7C41EDAC7EA4A40143DF03158F142403F7100FDBEE94A40BCAFCA85CAEF42403F7100FDBEE94A40
26291	24626	37.880643999999997	37.892816000000003	54.179392	54.168239999999997	Школьная	0103000020E6100000010000000500000095B54DF1B8F0424084F068E388154B4095B54DF1B8F04240FF942A51F6164B403BAC70CB47F24240FF942A51F6164B403BAC70CB47F2424084F068E388154B4095B54DF1B8F0424084F068E388154B40
75227	24626	37.880643999999997	37.892816000000003	54.179392	54.168239999999997	Советская	0103000020E6100000010000000500000095B54DF1B8F0424084F068E388154B4095B54DF1B8F04240FF942A51F6164B403BAC70CB47F24240FF942A51F6164B403BAC70CB47F2424084F068E388154B4095B54DF1B8F0424084F068E388154B40
26921	40469	37.750675999999999	37.763908000000001	54.080168999999998	54.062026000000003	Красногвардейская	0103000020E6100000010000000500000030F2B22616E0424038C0CC77F0074B4030F2B22616E04240969350FA420A4B408E93C2BCC7E14240969350FA420A4B408E93C2BCC7E1424038C0CC77F0074B4030F2B22616E0424038C0CC77F0074B40
26281	23258	37.662424999999999	37.678297999999998	53.959510999999999	53.945315999999998	Школьная	0103000020E61000000100000005000000C286A757CAD4424059315C1D00F94A40C286A757CAD442407D93A641D1FA4A409A780778D2D642407D93A641D1FA4A409A780778D2D6424059315C1D00F94A40C286A757CAD4424059315C1D00F94A40
25319	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Чехова	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
26508	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Толстого	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
25411	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Тесакова	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
26274	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Октябрьская	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
25976	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Мира	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
25362	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Ленина	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
25417	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	Комарова	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
26789	22107	37.894739000000001	37.946148999999998	53.951590000000003	53.913184000000001	 Торговая	0103000020E6100000010000000500000056BABBCE86F24240809D9B36E3F44A4056BABBCE86F24240AF997CB3CDF94A40511212691BF94240AF997CB3CDF94A40511212691BF94240809D9B36E3F44A4056BABBCE86F24240809D9B36E3F44A40
25307	21433	37.910629999999998	37.967170000000003	54.008887000000001	53.952396	Советская	0103000020E61000000100000005000000D4601A868FF44240AD6BB41CE8F94A40D4601A868FF44240062E8F3523014B400FD6FF39CCFB4240062E8F3523014B400FD6FF39CCFB4240AD6BB41CE8F94A40D4601A868FF44240AD6BB41CE8F94A40
26770	21433	37.910629999999998	37.967170000000003	54.008887000000001	53.952396	Грецова	0103000020E61000000100000005000000D4601A868FF44240AD6BB41CE8F94A40D4601A868FF44240062E8F3523014B400FD6FF39CCFB4240062E8F3523014B400FD6FF39CCFB4240AD6BB41CE8F94A40D4601A868FF44240AD6BB41CE8F94A40
25316	22424	37.747981000000003	37.771157000000002	53.945708000000003	53.934731999999997	Победы	0103000020E61000000100000005000000C38366D7BDDF42402843554CA5F74A40C38366D7BDDF424065C8B1F50CF94A406E8AC745B5E2424065C8B1F50CF94A406E8AC745B5E242402843554CA5F74A40C38366D7BDDF42402843554CA5F74A40
75091	21244	37.802455000000002	37.837066999999998	54.005982000000003	53.987096999999999	Пионерская	0103000020E610000001000000050000007FC16ED8B6E64240677DCA3159FE4A407FC16ED8B6E64240AE2EA704C4004B40C9C7EE0225EB4240AE2EA704C4004B40C9C7EE0225EB4240677DCA3159FE4A407FC16ED8B6E64240677DCA3159FE4A40
25519	21244	37.802455000000002	37.837066999999998	54.005982000000003	53.987096999999999	Комсомольская	0103000020E610000001000000050000007FC16ED8B6E64240677DCA3159FE4A407FC16ED8B6E64240AE2EA704C4004B40C9C7EE0225EB4240AE2EA704C4004B40C9C7EE0225EB4240677DCA3159FE4A407FC16ED8B6E64240677DCA3159FE4A40
26797	23867	37.814115000000001	37.835638000000003	54.056482000000003	54.042442000000001	Центральная	0103000020E610000001000000050000006E179AEB34E8424009FD4CBD6E054B406E179AEB34E8424006685BCD3A074B40BEA59C2FF6EA424006685BCD3A074B40BEA59C2FF6EA424009FD4CBD6E054B406E179AEB34E8424009FD4CBD6E054B40
26378	23289	37.806972999999999	37.848457000000003	54.099608000000003	54.064355999999997	Советская	0103000020E61000000100000005000000A4E029E44AE7424093A641D13C084B40A4E029E44AE74240C23577F4BF0C4B40F9872D3D9AEC4240C23577F4BF0C4B40F9872D3D9AEC424093A641D13C084B40A4E029E44AE7424093A641D13C084B40
75083	23289	37.806972999999999	37.848457000000003	54.099608000000003	54.064355999999997	Первомайская	0103000020E61000000100000005000000A4E029E44AE7424093A641D13C084B40A4E029E44AE74240C23577F4BF0C4B40F9872D3D9AEC4240C23577F4BF0C4B40F9872D3D9AEC424093A641D13C084B40A4E029E44AE7424093A641D13C084B40
25323	23289	37.806972999999999	37.848457000000003	54.099608000000003	54.064355999999997	Мира	0103000020E61000000100000005000000A4E029E44AE7424093A641D13C084B40A4E029E44AE74240C23577F4BF0C4B40F9872D3D9AEC4240C23577F4BF0C4B40F9872D3D9AEC424093A641D13C084B40A4E029E44AE7424093A641D13C084B40
75237	51158	38.591543999999999	38.602826999999998	54.018071999999997	54.012141	Шахтная	0103000020E610000001000000050000009012BBB6B74B43406AF816D68D014B409012BBB6B74B4340957CEC2E50024B40A912656F294D4340957CEC2E50024B40A912656F294D43406AF816D68D014B409012BBB6B74B43406AF816D68D014B40
25773	20345	38.521375999999997	38.531661999999997	54.040818999999999	54.029788000000003	Центральная	0103000020E61000000100000005000000AB75E272BC42434019E8DA17D0034B40AB75E272BC4243401807978E39054B4052431B800D4443401807978E39054B4052431B800D44434019E8DA17D0034B40AB75E272BC42434019E8DA17D0034B40
26708	22009	38.775492	38.804138999999999	53.932527	53.917473999999999	Школьная	0103000020E61000000100000005000000A2276552436343401477BCC96FF54A40A22765524363434089D1730B5DF74A401538D906EE66434089D1730B5DF74A401538D906EE6643401477BCC96FF54A40A2276552436343401477BCC96FF54A40
75394	60594	38.780433000000002	38.784888000000002	53.917335999999999	53.914090999999999	Центральная	0103000020E610000001000000050000000EDC813AE5634340B24813EF00F54A400EDC813AE5634340C3B81B446BF54A40ED82C13577644340C3B81B446BF54A40ED82C13577644340B24813EF00F54A400EDC813AE5634340B24813EF00F54A40
75259	60552	38.580134999999999	38.598416	53.970100000000002	53.961471000000003	Кимовская	0103000020E61000000100000005000000EA211ADD414A4340B686527B11FB4A40EA211ADD414A4340C0EC9E3C2CFC4A409AB33EE5984C4340C0EC9E3C2CFC4A409AB33EE5984C4340B686527B11FB4A40EA211ADD414A4340B686527B11FB4A40
25998	21761	38.503957999999997	38.533135000000001	53.867171999999997	53.858649	Молодежная	0103000020E610000001000000050000005E471CB2814043401EDFDE35E8ED4A405E471CB281404340E200FA7DFFEE4A402EAD86C43D444340E200FA7DFFEE4A402EAD86C43D4443401EDFDE35E8ED4A405E471CB2814043401EDFDE35E8ED4A40
26384	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Шевченко	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
25512	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Толстого	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
25710	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Павлова	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
26244	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Октябрьская	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
26243	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Маяковского	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
25310	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Ленина	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
26920	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Крылова	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
25447	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Коммунистическая	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
26908	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Кирова	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
25371	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Больничная	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
26775	19534	38.466740999999999	38.565204999999999	53.985525000000003	53.945115000000001	Бессолова	0103000020E61000000100000005000000E659492BBE3B4340C2FA3F87F9F84A40E659492BBE3B4340F931E6AE25FE4A4091442FA358484340F931E6AE25FE4A4091442FA358484340C2FA3F87F9F84A40E659492BBE3B4340C2FA3F87F9F84A40
75410	46275	38.549430999999998	38.589450999999997	53.768692999999999	53.749088	Центральная	0103000020E610000001000000050000004C3448C153464340BCE9961DE2DF4A404C3448C15346434002D53F8864E24A4018CC5F21734B434002D53F8864E24A4018CC5F21734B4340BCE9961DE2DF4A404C3448C153464340BCE9961DE2DF4A40
25313	22052	38.532192000000002	38.581411000000003	53.837688999999997	53.816504999999999	50 лет Октября	0103000020E61000000100000005000000AF9811DE1E4443409F02603C83E84A40AF9811DE1E444340069CA56439EB4A407044F7AC6B4A4340069CA56439EB4A407044F7AC6B4A43409F02603C83E84A40AF9811DE1E4443409F02603C83E84A40
75371	45642	38.592208999999997	38.606465	53.774237999999997	53.765073999999998	Центральная	0103000020E61000000100000005000000CCB22781CD4B43408C82E0F1EDE14A40CCB22781CD4B434004A9143B1AE34A40969526A5A04D434004A9143B1AE34A40969526A5A04D43408C82E0F1EDE14A40CCB22781CD4B43408C82E0F1EDE14A40
26227	21428	38.701138	38.718521000000003	54.036985000000001	54.025827	Больничная	0103000020E61000000100000005000000CEFDD5E3BE594340492D944C4E034B40CEFDD5E3BE594340A6B8AAECBB044B409F3E027FF85B4340A6B8AAECBB044B409F3E027FF85B4340492D944C4E034B40CEFDD5E3BE594340492D944C4E034B40
75405	46575	37.824634000000003	37.835107999999998	53.303710000000002	53.298512000000002	Центральная	0103000020E61000000100000005000000B8955E9B8DE9424056BB26A435A64A40B8955E9B8DE94240EDBB22F8DFA64A406150A6D1E4EA4240EDBB22F8DFA64A406150A6D1E4EA424056BB26A435A64A40B8955E9B8DE9424056BB26A435A64A40
75082	60497	37.690111000000002	37.713126000000003	53.269677999999999	53.251891999999998	Тихомирова	0103000020E6100000010000000500000010CEA78E55D84240E00F3FFF3DA04A4010CEA78E55D84240B03907CF84A24A40B2F677B647DB4240B03907CF84A24A40B2F677B647DB4240E00F3FFF3DA04A4010CEA78E55D84240E00F3FFF3DA04A40
75265	49444	37.577660000000002	37.587837999999998	53.222211999999999	53.212328999999997	Октябрьская	0103000020E610000001000000050000008B1A4CC3F0C94240067FBF982D9B4A408B1A4CC3F0C94240AE635C71719C4A404BAC8C463ECB4240AE635C71719C4A404BAC8C463ECB4240067FBF982D9B4A408B1A4CC3F0C94240067FBF982D9B4A40
75369	17825	37.443469999999998	37.460197000000001	54.63646	54.627479999999998	Молодежная	0103000020E61000000100000005000000E960FD9FC3B842407172BF4351504B40E960FD9FC3B84240289B728577514B40D15B3CBCE7BA4240289B728577514B40D15B3CBCE7BA42407172BF4351504B40E960FD9FC3B842407172BF4351504B40
75123	60518	37.150897999999998	37.772119000000004	54.833843000000002	54.450355000000002	микрорайон В	0103000020E6100000010000000500000012842BA050934240884B8E3BA5394B4012842BA050934240D07F0F5EBB6A4B4064CF9ECBD4E24240D07F0F5EBB6A4B4064CF9ECBD4E24240884B8E3BA5394B4012842BA050934240884B8E3BA5394B40
26481	49312	37.394539000000002	37.425125999999999	54.538884000000003	54.523623000000001	238 Стрелковой дивизии	0103000020E610000001000000050000008FFF024180B242407A37161406434B408FFF024180B24240392BA226FA444B40F3565D876AB64240392BA226FA444B40F3565D876AB642407A37161406434B408FFF024180B242407A37161406434B40
75258	18401	37.524937999999999	37.533318999999999	54.70635	54.697906000000003	Болотова	0103000020E61000000100000005000000BD361B2B31C3424052D7DAFB54594B40BD361B2B31C34240CAC342AD695A4B40EFAA07CC43C44240CAC342AD695A4B40EFAA07CC43C4424052D7DAFB54594B40BD361B2B31C3424052D7DAFB54594B40
75163	49246	37.525844999999997	37.566412999999997	54.638440000000003	54.622095999999999	.Школьная	0103000020E61000000100000005000000EFE192E34EC34240787C7BD7A04F4B40EFE192E34EC34240A83AE466B8514B40BE839F3880C84240A83AE466B8514B40BE839F3880C84240787C7BD7A04F4B40EFE192E34EC34240787C7BD7A04F4B40
25599	18129	37.453459000000002	37.477578999999999	54.587598999999997	54.569814999999998	Кирова	0103000020E61000000100000005000000D789CBF10ABA424097E2AAB2EF484B40D789CBF10ABA4240C614AC71364B4B40D120054F21BD4240C614AC71364B4B40D120054F21BD424097E2AAB2EF484B40D789CBF10ABA424097E2AAB2EF484B40
25354	17940	37.696776999999997	37.713818000000003	54.637219999999999	54.626432999999999	Мира	0103000020E6100000010000000500000070CD1DFD2FD942404D11E0F42E504B4070CD1DFD2FD94240B62DCA6C90514B40E8A562635EDB4240B62DCA6C90514B40E8A562635EDB42404D11E0F42E504B4070CD1DFD2FD942404D11E0F42E504B40
75274	60556	37.435214000000002	37.457887999999997	54.755571000000003	54.741014999999997	Мира	0103000020E610000001000000050000007461A417B5B74240376C5B94D95E4B407461A417B5B742402C67EF8CB6604B408C9DF0129CBA42402C67EF8CB6604B408C9DF0129CBA4240376C5B94D95E4B407461A417B5B74240376C5B94D95E4B40
25732	49207	37.259431999999997	37.274371000000002	54.833640000000003	54.827308000000002	Школьная	0103000020E6100000010000000500000097C4591135A142400EDC813AE5694B4097C4591135A1424098512CB7B46A4B4044FCC3961EA3424098512CB7B46A4B4044FCC3961EA342400EDC813AE5694B4097C4591135A142400EDC813AE5694B40
26179	18613	37.373967	37.426878000000002	54.751939	54.717827999999997	Северная	0103000020E6100000010000000500000041649126DEAF42409813B4C9E15B4B4041649126DEAF424021CB82893F604B40E2B034F0A3B6424021CB82893F604B40E2B034F0A3B642409813B4C9E15B4B4041649126DEAF42409813B4C9E15B4B40
26355	18613	37.373967	37.426878000000002	54.751939	54.717827999999997	Поленова	0103000020E6100000010000000500000041649126DEAF42409813B4C9E15B4B4041649126DEAF424021CB82893F604B40E2B034F0A3B6424021CB82893F604B40E2B034F0A3B642409813B4C9E15B4B4041649126DEAF42409813B4C9E15B4B40
26183	18613	37.373967	37.426878000000002	54.751939	54.717827999999997	Гагарина	0103000020E6100000010000000500000041649126DEAF42409813B4C9E15B4B4041649126DEAF424021CB82893F604B40E2B034F0A3B6424021CB82893F604B40E2B034F0A3B642409813B4C9E15B4B4041649126DEAF42409813B4C9E15B4B40
26256	49167	37.613225	37.649138999999998	54.677504999999996	54.660671999999998	Школьная	0103000020E61000000100000005000000780B24287ECE424003B16CE690544B40780B24287ECE424030F0DC7BB8564B4071C79BFC16D3424030F0DC7BB8564B4071C79BFC16D3424003B16CE690544B40780B24287ECE424003B16CE690544B40
26674	17805	37.362577000000002	37.385599999999997	54.710219000000002	54.702489999999997	Новая	0103000020E6100000010000000500000012A452EC68AE42402EE23B31EB594B4012A452EC68AE4240B9FFC874E85A4B4036AB3E575BB14240B9FFC874E85A4B4036AB3E575BB142402EE23B31EB594B4012A452EC68AE42402EE23B31EB594B40
25730	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Тургенева	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25557	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Тульское шоссе	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25493	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Строителей	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25334	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Словацкого восстания	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25977	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Свердлова	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25435	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Пионерская	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25333	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Московская застава 	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25349	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Молодежная	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
26138	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Мира	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25299	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Ломоносова	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25345	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Ленинградская	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
26224	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Ленина	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
26129	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Красноармейская	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25338	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Комсомольская	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25301	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Карла Маркса	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
26145	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Интернациональная	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25346	16197	38.029027999999997	38.136142999999997	53.171017999999997	53.127310999999999	Дружбы	0103000020E610000001000000050000008A558330B7034340E5B512BA4B904A408A558330B70343407F83F6EAE3954A40274A42226D1143407F83F6EAE3954A40274A42226D114340E5B512BA4B904A408A558330B7034340E5B512BA4B904A40
25332	16026	36.963464000000002	37.006943	54.185141000000002	54.167977	Дружбы	0103000020E61000000100000005000000CA6FD1C9527B424077BD344580154B40CA6FD1C9527B42400A1346B3B2174B40D3F71A82E38042400A1346B3B2174B40D3F71A82E380424077BD344580154B40CA6FD1C9527B424077BD344580154B40
75431	60603	37.053905999999998	37.074792000000002	54.188665	54.180993999999998	Мира	0103000020E6100000010000000500000072874D64E6864240D862B7CF2A174B4072874D64E68642402E73BA2C26184B405000C5C8928942402E73BA2C26184B405000C5C892894240D862B7CF2A174B4072874D64E6864240D862B7CF2A174B40
67871	40670	37.103754000000002	37.126688000000001	54.114134999999997	54.097079000000001	проспект Улитина	0103000020E61000000100000005000000236AA2CF478D42406F10AD156D0C4B40236AA2CF478D42401B2AC6F99B0E4B40D865F84F379042401B2AC6F99B0E4B40D865F84F379042406F10AD156D0C4B40236AA2CF478D42406F10AD156D0C4B40
75296	40670	37.103754000000002	37.126688000000001	54.114134999999997	54.097079000000001	Школьная	0103000020E61000000100000005000000236AA2CF478D42406F10AD156D0C4B40236AA2CF478D42401B2AC6F99B0E4B40D865F84F379042401B2AC6F99B0E4B40D865F84F379042406F10AD156D0C4B40236AA2CF478D42406F10AD156D0C4B40
75188	40670	37.103754000000002	37.126688000000001	54.114134999999997	54.097079000000001	Улитина	0103000020E61000000100000005000000236AA2CF478D42406F10AD156D0C4B40236AA2CF478D42401B2AC6F99B0E4B40D865F84F379042401B2AC6F99B0E4B40D865F84F379042406F10AD156D0C4B40236AA2CF478D42406F10AD156D0C4B40
25533	16106	37.108092999999997	37.151643	54.263508000000002	54.251078999999997	Центральная	0103000020E6100000010000000500000098F6CDFDD58D42402FDB4E5B23204B4098F6CDFDD58D4240001E51A1BA214B406BD5AE0969934240001E51A1BA214B406BD5AE09699342402FDB4E5B23204B4098F6CDFDD58D42402FDB4E5B23204B40
75323	60572	36.846971000000003	36.863948999999998	54.210459999999998	54.191789	Дружбы	0103000020E6100000010000000500000089D4B48B696C4240C45DBD8A8C184B4089D4B48B696C4240DE8E705AF01A4B40B9347EE1956E4240DE8E705AF01A4B40B9347EE1956E4240C45DBD8A8C184B4089D4B48B696C4240C45DBD8A8C184B40
26182	48502	37.053296000000003	37.087198000000001	54.087231000000003	54.073064000000002	Чирикова А.И	0103000020E61000000100000005000000FA804067D2864240EA4141295A094B40FA804067D28642404419AA622A0B4B406823D74D298B42404419AA622A0B4B406823D74D298B4240EA4141295A094B40FA804067D2864240EA4141295A094B40
26148	30558	36.843009000000002	36.868161999999998	54.255740000000003	54.237969	Центральная	0103000020E61000000100000005000000E99D0AB8E76B42401D3BA8C4751E4B40E99D0AB8E76B4240B8239C16BC204B40A2D0B2EE1F6F4240B8239C16BC204B40A2D0B2EE1F6F42401D3BA8C4751E4B40E99D0AB8E76B42401D3BA8C4751E4B40
75111	15723	36.930990000000001	36.989389000000003	54.168118999999997	54.143237999999997	Фрунзе	0103000020E61000000100000005000000977329AE2A774240B0C56E9F55124B40977329AE2A774240096B63EC84154B40D6027B4CA47E4240096B63EC84154B40D6027B4CA47E4240B0C56E9F55124B40977329AE2A774240B0C56E9F55124B40
26601	15723	36.930990000000001	36.989389000000003	54.168118999999997	54.143237999999997	Красноармейская	0103000020E61000000100000005000000977329AE2A774240B0C56E9F55124B40977329AE2A774240096B63EC84154B40D6027B4CA47E4240096B63EC84154B40D6027B4CA47E4240B0C56E9F55124B40977329AE2A774240B0C56E9F55124B40
26723	16007	36.934286999999998	36.956637000000001	54.128261999999999	54.111775999999999	Молодежная	0103000020E61000000100000005000000FA0967B796774240253D0CAD4E0E4B40FA0967B796774240E7A8A3E36A104B406092CA14737A4240E7A8A3E36A104B406092CA14737A4240253D0CAD4E0E4B40FA0967B796774240253D0CAD4E0E4B40
75345	16007	36.934286999999998	36.956637000000001	54.128261999999999	54.111775999999999	Ленина	0103000020E61000000100000005000000FA0967B796774240253D0CAD4E0E4B40FA0967B796774240E7A8A3E36A104B406092CA14737A4240E7A8A3E36A104B406092CA14737A4240253D0CAD4E0E4B40FA0967B796774240253D0CAD4E0E4B40
26801	46787	37.121262000000002	37.143082	54.227184999999999	54.214782999999997	Дружбы	0103000020E61000000100000005000000B01F6283858F42404E5E64027E1B4B40B01F6283858F42402592E865141D4B40B952CF82509242402592E865141D4B40B952CF82509242404E5E64027E1B4B40B01F6283858F42404E5E64027E1B4B40
25823	13355	38.026161999999999	38.046706999999998	53.485247999999999	53.470987000000001	Школьная	0103000020E61000000100000005000000F032C34659034340ABEB504D49BC4A40F032C346590343408639419B1CBE4A4044BFB67EFA0543408639419B1CBE4A4044BFB67EFA054340ABEB504D49BC4A40F032C34659034340ABEB504D49BC4A40
75254	13903	37.983258999999997	38.237400999999998	53.459708999999997	53.353395999999996	Центральная	0103000020E61000000100000005000000B33F506EDBFD4240C34483143CAD4A40B33F506EDBFD4240A35698BED7BA4A40D384ED27631E4340A35698BED7BA4A40D384ED27631E4340C34483143CAD4A40B33F506EDBFD4240C34483143CAD4A40
26279	13903	37.983258999999997	38.237400999999998	53.459708999999997	53.353395999999996	Железнодорожная	0103000020E61000000100000005000000B33F506EDBFD4240C34483143CAD4A40B33F506EDBFD4240A35698BED7BA4A40D384ED27631E4340A35698BED7BA4A40D384ED27631E4340C34483143CAD4A40B33F506EDBFD4240C34483143CAD4A40
75173	60526	37.982548999999999	37.995241999999998	53.545113000000001	53.535508	Садовская	0103000020E61000000100000005000000D7DB662AC4FD4240895FB1868BC44A40D7DB662AC4FD4240EECF4543C6C54A4085CD001764FF4240EECF4543C6C54A4085CD001764FF4240895FB1868BC44A40D7DB662AC4FD4240895FB1868BC44A40
75355	60580	37.900398000000003	37.917923999999999	53.569808000000002	53.558652000000002	Центральная	0103000020E6100000010000000500000021B1DD3D40F3424029ECA2E881C74A4021B1DD3D40F34240E57FF277EFC84A40541B9C887EF54240E57FF277EFC84A40541B9C887EF5424029ECA2E881C74A4021B1DD3D40F3424029ECA2E881C74A40
26747	47473	37.831730999999998	37.853856	53.492533999999999	53.476196999999999	Административная	0103000020E61000000100000005000000E108522976EA424006BAF605F4BC4A40E108522976EA42408315A75A0BBF4A4027BF45274BED42408315A75A0BBF4A4027BF45274BED424006BAF605F4BC4A40E108522976EA424006BAF605F4BC4A40
26533	47721	38.122596000000001	38.199806000000002	53.551473999999999	53.535524000000002	Антонова	0103000020E610000001000000050000006A4FC939B10F43408F1CE90C8CC44A406A4FC939B10F4340124C35B396C64A40B5C5353E93194340124C35B396C64A40B5C5353E931943408F1CE90C8CC44A406A4FC939B10F43408F1CE90C8CC44A40
75418	13998	38.233592000000002	38.321410999999998	53.551265000000001	53.537643000000003	 Главная	0103000020E61000000100000005000000BA4DB857E61D434030F65E7CD1C44A40BA4DB857E61D4340F836FDD98FC64A408EC9E2FE23294340F836FDD98FC64A408EC9E2FE2329434030F65E7CD1C44A40BA4DB857E61D434030F65E7CD1C44A40
75367	47752	38.111080000000001	38.141263000000002	53.590342	53.572391000000003	Центральная	0103000020E61000000100000005000000AE9E93DE370E43402BC3B81B44C94A40AE9E93DE370E434045BA9F5390CB4A404391EEE71412434045BA9F5390CB4A404391EEE7141243402BC3B81B44C94A40AE9E93DE370E43402BC3B81B44C94A40
26351	14198	37.886159999999997	37.909641999999998	53.400007000000002	53.383966999999998	Школьная	0103000020E61000000100000005000000FD82DDB06DF1424022DFA5D425B14A40FD82DDB06DF14240E695EB6D33B34A40B58828266FF44240E695EB6D33B34A40B58828266FF4424022DFA5D425B14A40FD82DDB06DF1424022DFA5D425B14A40
26078	14105	38.056578999999999	38.080043000000003	53.368834999999997	53.358620000000002	Молодежная	0103000020E61000000100000005000000F8510DFB3D07434084D89942E7AD4A40F8510DFB3D074340614F3BFC35AF4A400AA359D93E0A4340614F3BFC35AF4A400AA359D93E0A434084D89942E7AD4A40F8510DFB3D07434084D89942E7AD4A40
75366	13347	37.846975	37.869424000000002	53.549467999999997	53.523614999999999	Школьная	0103000020E61000000100000005000000CAC342AD69EC4240F758FAD005C34A40CAC342AD69EC42406919A9F754C64A40C32D1F4949EF42406919A9F754C64A40C32D1F4949EF4240F758FAD005C34A40CAC342AD69EC4240F758FAD005C34A40
26791	47587	38.079127	38.092979	53.398992	53.388323	Весенняя	0103000020E61000000100000005000000849D62D5200A43406EA46C91B4B14A40849D62D5200A4340CDAE7B2B12B34A407E1B62BCE60B4340CDAE7B2B12B34A407E1B62BCE60B43406EA46C91B4B14A40849D62D5200A43406EA46C91B4B14A40
26538	47640	37.980294000000001	38.021166999999998	53.574342999999999	53.547257999999999	имени Хрунова	0103000020E61000000100000005000000863B17467AFD4240B83CD68C0CC64A40863B17467AFD4240E0D7481284C94A409160AA99B5024340E0D7481284C94A409160AA99B5024340B83CD68C0CC64A40863B17467AFD4240B83CD68C0CC64A40
25828	47640	37.980294000000001	38.021166999999998	53.574342999999999	53.547257999999999	Ленина	0103000020E61000000100000005000000863B17467AFD4240B83CD68C0CC64A40863B17467AFD4240E0D7481284C94A409160AA99B5024340E0D7481284C94A409160AA99B5024340B83CD68C0CC64A40863B17467AFD4240B83CD68C0CC64A40
25498	13640	37.899912999999998	37.943373000000001	53.616368000000001	53.595751	Школьная	0103000020E61000000100000005000000641F645930F3424097C79A9141CC4A40641F645930F3424085268925E5CE4A40F7764B72C0F8424085268925E5CE4A40F7764B72C0F8424097C79A9141CC4A40641F645930F3424097C79A9141CC4A40
26504	13252	37.907772999999999	37.933608999999997	53.480296000000003	53.467095999999998	Школьная	0103000020E610000001000000050000008D98D9E731F44240D40B3ECDC9BB4A408D98D9E731F442402733DE567ABD4A402920ED7F80F742402733DE567ABD4A402920ED7F80F74240D40B3ECDC9BB4A408D98D9E731F44240D40B3ECDC9BB4A40
75316	47995	38.088369999999998	38.106183999999999	53.599677999999997	53.587611000000003	4	0103000020E6100000010000000500000048F949B54F0B43408BE255D636CB4A4048F949B54F0B4340BA10AB3FC2CC4A40E2ADF36F970D4340BA10AB3FC2CC4A40E2ADF36F970D43408BE255D636CB4A4048F949B54F0B43408BE255D636CB4A40
25672	12541	38.285621999999996	38.301388000000003	54.465857999999997	54.455798999999999	Молодежная	0103000020E610000001000000050000005182FE428F2443405646239F573A4B405182FE428F2443403C4A253CA13B4B4014B4C9E1932643403C4A253CA13B4B4014B4C9E1932643405646239F573A4B405182FE428F2443405646239F573A4B40
26361	5483	38.476649000000002	38.490178	54.293204000000003	54.286192999999997	Школьная	0103000020E61000000100000005000000E7559DD5023D43400CACE3F8A1244B40E7559DD5023D434038876BB587254B40FE9B1727BE3E434038876BB587254B40FE9B1727BE3E43400CACE3F8A1244B40E7559DD5023D43400CACE3F8A1244B40
26188	5483	38.476649000000002	38.490178	54.293204000000003	54.286192999999997	Привокзальная	0103000020E61000000100000005000000E7559DD5023D43400CACE3F8A1244B40E7559DD5023D434038876BB587254B40FE9B1727BE3E434038876BB587254B40FE9B1727BE3E43400CACE3F8A1244B40E7559DD5023D43400CACE3F8A1244B40
26283	5483	38.476649000000002	38.490178	54.293204000000003	54.286192999999997	Комсомольская	0103000020E61000000100000005000000E7559DD5023D43400CACE3F8A1244B40E7559DD5023D434038876BB587254B40FE9B1727BE3E434038876BB587254B40FE9B1727BE3E43400CACE3F8A1244B40E7559DD5023D43400CACE3F8A1244B40
25311	12518	38.103057999999997	38.12088	54.443491999999999	54.435062000000002	Центральная	0103000020E61000000100000005000000ABCB2901310D4340BEDD921CB0374B40ABCB2901310D4340D1048A58C4384B40C85EEFFE780F4340D1048A58C4384B40C85EEFFE780F4340BEDD921CB0374B40ABCB2901310D4340BEDD921CB0374B40
26161	12822	38.165823000000003	38.186259999999997	54.674793000000001	54.663046999999999	Библиотечная	0103000020E610000001000000050000005AF624B039154340FF5A5EB9DE544B405AF624B039154340ED48F59D5F564B40C746205ED7174340ED48F59D5F564B40C746205ED7174340FF5A5EB9DE544B405AF624B039154340FF5A5EB9DE544B40
75453	45745	38.137445	38.154018999999998	54.31082	54.301464000000003	Центральная	0103000020E61000000100000005000000D6FF39CC97114340EF75525F96264B40D6FF39CC97114340AB7823F3C8274B4037FB03E5B6134340AB7823F3C8274B4037FB03E5B6134340EF75525F96264B40D6FF39CC97114340EF75525F96264B40
25315	47353	38.419328	38.444884999999999	54.399551000000002	54.390205000000002	Молодежная	0103000020E610000001000000050000000726378AAC3543402BDEC83CF2314B400726378AAC354340C40AB77C24334B4090BDDEFDF1384340C40AB77C24334B4090BDDEFDF13843402BDEC83CF2314B400726378AAC3543402BDEC83CF2314B40
26778	12963	38.354892	38.383018	54.335887999999997	54.322961999999997	Центральная	0103000020E6100000010000000500000057CEDE196D2D4340E5EC9DD156294B4057CEDE196D2D4340368FC360FE2A4B40C1E3DBBB06314340368FC360FE2A4B40C1E3DBBB06314340E5EC9DD156294B4057CEDE196D2D4340E5EC9DD156294B40
75302	60565	38.466489000000003	38.48742	54.271453000000001	54.262472000000002	Клубная	0103000020E61000000100000005000000CD785BE9B53B4340D00EB8AE98214B40CD785BE9B53B434057B3CEF8BE224B404AB54FC7633E434057B3CEF8BE224B404AB54FC7633E4340D00EB8AE98214B40CD785BE9B53B4340D00EB8AE98214B40
25583	12790	38.090535000000003	38.114995999999998	54.577486999999998	54.569381999999997	Дорожная	0103000020E610000001000000050000005A12A0A6960B43402D776682E1484B405A12A0A6960B4340BD6E1118EB494B40DD955D30B80E4340BD6E1118EB494B40DD955D30B80E43402D776682E1484B405A12A0A6960B43402D776682E1484B40
75282	60557	38.274428999999998	38.286169999999998	54.372041000000003	54.361629000000001	Новая	0103000020E6100000010000000500000078094E7D202343408124ECDB492E4B4078094E7D20234340B5E21B0A9F2F4B40548CF337A1244340B5E21B0A9F2F4B40548CF337A12443408124ECDB492E4B4078094E7D202343408124ECDB492E4B40
26344	12742	38.198476999999997	38.231166999999999	54.588590000000003	54.566307999999999	Советская	0103000020E610000001000000050000000C01C0B16719434049BBD1C77C484B400C01C0B1671943405760C8EA564B4B400C7558E1961D43405760C8EA564B4B400C7558E1961D434049BBD1C77C484B400C01C0B16719434049BBD1C77C484B40
26420	12435	38.188326000000004	38.212338000000003	54.412039999999998	54.400269999999999	Горная	0103000020E61000000100000005000000467EFD101B184340F3C81F0C3C334B40467EFD101B18434069520ABABD344B405AD93EE42D1B434069520ABABD344B405AD93EE42D1B4340F3C81F0C3C334B40467EFD101B184340F3C81F0C3C334B40
75474	60621	38.355997000000002	38.379855999999997	54.625509999999998	54.613849000000002	Липовая	0103000020E61000000100000005000000B03C484F912D434056D7A19A924E4B40B03C484F912D434015A930B610504B403D98141F9F30434015A930B610504B403D98141F9F30434056D7A19A924E4B40B03C484F912D434056D7A19A924E4B40
26056	47181	38.302475000000001	38.340159	54.570295000000002	54.552357999999998	Барская слобода	0103000020E61000000100000005000000C66D3480B72643408CD7BCAAB3464B40C66D3480B72643404209336DFF484B40543882548A2B43404209336DFF484B40543882548A2B43408CD7BCAAB3464B40C66D3480B72643408CD7BCAAB3464B40
26410	12170	38.138838	38.171357	54.152546000000001	54.126843000000001	Школьная	0103000020E6100000010000000500000095B88E71C5114340FF5C34643C104B4095B88E71C51143405C9198A086134B406878B306EF1543405C9198A086134B406878B306EF154340FF5C34643C104B4095B88E71C5114340FF5C34643C104B40
25984	12170	38.138838	38.171357	54.152546000000001	54.126843000000001	Первомайская	0103000020E6100000010000000500000095B88E71C5114340FF5C34643C104B4095B88E71C51143405C9198A086134B406878B306EF1543405C9198A086134B406878B306EF154340FF5C34643C104B4095B88E71C5114340FF5C34643C104B40
26488	12883	38.286557000000002	38.317233999999999	54.302892999999997	54.274622999999998	Воронковка	0103000020E610000001000000050000004EB857E6AD2443405DDDB1D826234B404EB857E6AD244340FA97A432C5264B40F296AB1F9B284340FA97A432C5264B40F296AB1F9B2843405DDDB1D826234B404EB857E6AD2443405DDDB1D826234B40
25306	11854	38.236708999999998	38.282532000000003	54.367545999999997	54.338780999999997	микрорайон Южный	0103000020E610000001000000050000009DD5027B4C1E4340CAC0012D5D2B4B409DD5027B4C1E434047E350BF0B2F4B40680932022A24434047E350BF0B2F4B40680932022A244340CAC0012D5D2B4B409DD5027B4C1E4340CAC0012D5D2B4B40
25739	11854	38.236708999999998	38.282532000000003	54.367545999999997	54.338780999999997	Л. Толстого	0103000020E610000001000000050000009DD5027B4C1E4340CAC0012D5D2B4B409DD5027B4C1E434047E350BF0B2F4B40680932022A24434047E350BF0B2F4B40680932022A244340CAC0012D5D2B4B409DD5027B4C1E4340CAC0012D5D2B4B40
26299	11854	38.236708999999998	38.282532000000003	54.367545999999997	54.338780999999997	Бундурина	0103000020E610000001000000050000009DD5027B4C1E4340CAC0012D5D2B4B409DD5027B4C1E434047E350BF0B2F4B40680932022A24434047E350BF0B2F4B40680932022A244340CAC0012D5D2B4B409DD5027B4C1E4340CAC0012D5D2B4B40
26405	13068	38.076782000000001	38.095117000000002	54.181641999999997	54.168703999999998	Дружбы	0103000020E61000000100000005000000F37519FED3094340295AB91798154B40F37519FED30943403ECA880B40174B4096253ACB2C0C43403ECA880B40174B4096253ACB2C0C4340295AB91798154B40F37519FED3094340295AB91798154B40
25989	12332	37.933194999999998	37.963324999999998	54.320394	54.307600000000001	Новая	0103000020E6100000010000000500000036E50AEF72F74240F31FD26F5F274B4036E50AEF72F74240D5EAABAB02294B40A835CD3B4EFB4240D5EAABAB02294B40A835CD3B4EFB4240F31FD26F5F274B4036E50AEF72F74240F31FD26F5F274B40
25760	47153	38.334831999999999	38.356724	54.509250999999999	54.500165000000003	Центральная	0103000020E61000000100000005000000BFD364C6DB2A43404BCD1E6805404B40BFD364C6DB2A4340473A03232F414B4062D9CC21A92D4340473A03232F414B4062D9CC21A92D43404BCD1E6805404B40BFD364C6DB2A43404BCD1E6805404B40
75422	60601	38.160577000000004	38.175139000000001	53.775632000000002	53.769502000000003	Шахтерский переулок	0103000020E61000000100000005000000B2BE81C98D144340721AA20A7FE24A40B2BE81C98D14434094DDCCE847E34A4088A06AF46A16434094DDCCE847E34A4088A06AF46A164340721AA20A7FE24A40B2BE81C98D144340721AA20A7FE24A40
25328	40444	38.139744999999998	38.152555	53.799086000000003	53.789028999999999	Липки	0103000020E61000000100000005000000C763062AE31143403C4CFBE6FEE44A40C763062AE31143408258367348E64A40AFEB17EC861343408258367348E64A40AFEB17EC861343403C4CFBE6FEE44A40C763062AE31143403C4CFBE6FEE44A40
25587	10733	38.155222999999999	38.241219000000001	53.700153999999998	53.665778000000003	Трудовая	0103000020E61000000100000005000000234BE658DE134340BA32A83638D54A40234BE658DE134340F01472A59ED94A404016A243E01E4340F01472A59ED94A404016A243E01E4340BA32A83638D54A40234BE658DE134340BA32A83638D54A40
26377	10733	38.155222999999999	38.241219000000001	53.700153999999998	53.665778000000003	Советская	0103000020E61000000100000005000000234BE658DE134340BA32A83638D54A40234BE658DE134340F01472A59ED94A404016A243E01E4340F01472A59ED94A404016A243E01E4340BA32A83638D54A40234BE658DE134340BA32A83638D54A40
25697	10733	38.155222999999999	38.241219000000001	53.700153999999998	53.665778000000003	Кирова	0103000020E61000000100000005000000234BE658DE134340BA32A83638D54A40234BE658DE134340F01472A59ED94A404016A243E01E4340F01472A59ED94A404016A243E01E4340BA32A83638D54A40234BE658DE134340BA32A83638D54A40
25289	10733	38.155222999999999	38.241219000000001	53.700153999999998	53.665778000000003	Воровского	0103000020E61000000100000005000000234BE658DE134340BA32A83638D54A40234BE658DE134340F01472A59ED94A404016A243E01E4340F01472A59ED94A404016A243E01E4340BA32A83638D54A40234BE658DE134340BA32A83638D54A40
26084	46776	38.122318	38.169514999999997	53.723942999999998	53.687342000000001	слоб.1-ое общество	0103000020E6100000010000000500000027DBC01DA80F4340689599D2FAD74A4027DBC01DA80F434085950A2AAADC4A403997E2AAB215434085950A2AAADC4A403997E2AAB2154340689599D2FAD74A4027DBC01DA80F4340689599D2FAD74A40
75196	60531	38.257810999999997	38.277132999999999	53.749513999999998	53.743662	Центральная	0103000020E6100000010000000500000047C66AF3FF20434094A3005130DF4A4047C66AF3FF20434073F22213F0DF4A4039D219187923434073F22213F0DF4A4039D219187923434094A3005130DF4A4047C66AF3FF20434094A3005130DF4A40
25943	11377	38.317441000000002	38.335290000000001	53.844059000000001	53.828994999999999	Школьная	0103000020E610000001000000050000006CB41CE8A128434015C616821CEA4A406CB41CE8A12843407E7214200AEC4A40825660C8EA2A43407E7214200AEC4A40825660C8EA2A434015C616821CEA4A406CB41CE8A128434015C616821CEA4A40
75307	60567	38.094326000000002	38.123413999999997	53.764467000000003	53.748261999999997	Садовая	0103000020E61000000100000005000000CD94D6DF120C4340766B990CC7DF4A40CD94D6DF120C434085EFFD0DDAE14A402CEFAA07CC0F434085EFFD0DDAE14A402CEFAA07CC0F4340766B990CC7DF4A40CD94D6DF120C4340766B990CC7DF4A40
26082	46494	38.328544000000001	38.364288000000002	53.645335000000003	53.6175	Центральная	0103000020E6100000010000000500000005A6D3BA0D2A4340D7A3703D0ACF4A4005A6D3BA0D2A43406AFB57569AD24A40A2293BFDA02E43406AFB57569AD24A40A2293BFDA02E4340D7A3703D0ACF4A4005A6D3BA0D2A4340D7A3703D0ACF4A40
75249	46717	38.029727999999999	38.085495999999999	53.802219000000001	53.787018000000003	Восточная	0103000020E6100000010000000500000043E38920CE03434082AE7D01BDE44A4043E38920CE0343406B9DB81CAFE64A402BF86D88F10A43406B9DB81CAFE64A402BF86D88F10A434082AE7D01BDE44A4043E38920CE03434082AE7D01BDE44A40
25295	51155	38.120511999999998	38.327222999999996	53.622734000000001	53.5959	слоб.Бригада 3	0103000020E610000001000000050000004563EDEF6C0F4340DCD7817346CC4A404563EDEF6C0F4340BB0D6ABFB5CF4A40DFBF7971E2294340BB0D6ABFB5CF4A40DFBF7971E2294340DCD7817346CC4A404563EDEF6C0F4340DCD7817346CC4A40
75432	60596	38.061132999999998	38.083303999999998	53.725749	53.679380000000002	слобода Церковенка	0103000020E610000001000000050000006ADAC534D30743403BC780ECF5D64A406ADAC534D3074340670DDE57E5DC4A4020D099B4A90A4340670DDE57E5DC4A4020D099B4A90A43403BC780ECF5D64A406ADAC534D30743403BC780ECF5D64A40
25290	10929	38.520567999999997	38.546582999999998	53.644182000000001	53.628906999999998	Лесная	0103000020E610000001000000050000000CACE3F8A1424340DC9C4A0680D04A400CACE3F8A14243400056478E74D24A4058C6866EF64543400056478E74D24A4058C6866EF6454340DC9C4A0680D04A400CACE3F8A1424340DC9C4A0680D04A40
25327	46684	37.967781000000002	38.037965999999997	53.773418999999997	53.746718000000001	слоб.Бодаево	0103000020E610000001000000050000005858703FE0FB4240D2AA967494DF4A405858703FE0FB4240718DCF64FFE24A40122EE411DC044340718DCF64FFE24A40122EE411DC044340D2AA967494DF4A405858703FE0FB4240D2AA967494DF4A40
26550	46465	38.376154999999997	38.396726000000001	53.713845999999997	53.700543000000003	Школьная	0103000020E610000001000000050000000A9DD7D8253043408B389D64ABD94A400A9DD7D825304340B130444E5FDB4A4088BCE5EAC7324340B130444E5FDB4A4088BCE5EAC73243408B389D64ABD94A400A9DD7D8253043408B389D64ABD94A40
25457	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	переулок Школьный	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26824	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Центральная	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26702	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Ф.Энгельса	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
25937	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Урицкого	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26386	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Пролетарская	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26197	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Макаренко	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
75250	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	МКР Лесной	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26474	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Ленина	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26314	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Л.Толстого	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
25751	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Коммунаров	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
25954	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Клубная	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26277	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Кирпичная	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26705	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Западный МКР	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
25942	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Воронежская	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26199	9692	38.088092000000003	38.158124999999998	53.792752	53.753335999999997	Вересаева	0103000020E6100000010000000500000006854199460B4340217365506DE04A4006854199460B434057EBC4E578E54A400AD7A3703D14434057EBC4E578E54A400AD7A3703D144340217365506DE04A4006854199460B4340217365506DE04A40
26514	11118	38.228057999999997	38.277897000000003	53.804383000000001	53.789481000000002	Победы	0103000020E61000000100000005000000ABCB2901311D43401DE8A1B60DE54A40ABCB2901311D4340AC3AAB05F6E64A400954FF2092234340AC3AAB05F6E64A400954FF20922343401DE8A1B60DE54A40ABCB2901311D43401DE8A1B60DE54A40
26238	11118	38.228057999999997	38.277897000000003	53.804383000000001	53.789481000000002	Луговая	0103000020E61000000100000005000000ABCB2901311D43401DE8A1B60DE54A40ABCB2901311D4340AC3AAB05F6E64A400954FF2092234340AC3AAB05F6E64A400954FF20922343401DE8A1B60DE54A40ABCB2901311D43401DE8A1B60DE54A40
25849	46415	38.399241000000004	38.435875000000003	53.675423000000002	53.664817999999997	Центральная	0103000020E61000000100000005000000761C3F541A33434064E597C118D54A40761C3F541A334340ADFBC74274D64A406F1283C0CA374340ADFBC74274D64A406F1283C0CA37434064E597C118D54A40761C3F541A33434064E597C118D54A40
11651	5958	36.180241000000002	36.196330000000003	53.741159000000003	53.729621999999999	Ленина	0103000020E61000000100000005000000FD321823121742409738F24064DD4A40FD321823121742406B11514CDEDE4A40A29C6857211942406B11514CDEDE4A40A29C6857211942409738F24064DD4A40FD321823121742409738F24064DD4A40
11390	40915	36.168877000000002	36.189278000000002	53.697702	53.686601000000003	Центральная	0103000020E61000000100000005000000F705F4C29D1542405133A48AE2D74A40F705F4C29D154240492D944C4ED94A4018EDF1423A184240492D944C4ED94A4018EDF1423A1842405133A48AE2D74A40F705F4C29D1542405133A48AE2D74A40
75482	60629	35.973269000000002	36.100515000000001	53.880761	53.679758999999997	Садовая	0103000020E61000000100000005000000F69A1E1494FC4140B114C95702D74A40F69A1E1494FC4140CF4BC5C6BCF04A40F4E0EEACDD0C4240CF4BC5C6BCF04A40F4E0EEACDD0C4240B114C95702D74A40F69A1E1494FC4140B114C95702D74A40
25309	8950	36.033231999999998	36.054540000000003	53.782767	53.768889999999999	Школьный переулок	0103000020E61000000100000005000000209738F240044240581CCEFC6AE24A40209738F240044240ABB184B531E44A407429AE2AFB064240ABB184B531E44A407429AE2AFB064240581CCEFC6AE24A40209738F240044240581CCEFC6AE24A40
25420	9241	36.235495999999998	36.258682	53.712955999999998	53.704977999999997	Центральная	0103000020E610000001000000050000005E2BA1BB241E4240223317B83CDA4A405E2BA1BB241E424055BE672442DB4A402D08E57D1C21424055BE672442DB4A402D08E57D1C214240223317B83CDA4A405E2BA1BB241E4240223317B83CDA4A40
75289	45942	36.057099999999998	36.065049999999999	53.907105999999999	53.901122000000001	Центральная	0103000020E61000000100000005000000014D840D4F07424062DA37F757F34A40014D840D4F074240B000A60C1CF44A406A4DF38E53084240B000A60C1CF44A406A4DF38E5308424062DA37F757F34A40014D840D4F07424062DA37F757F34A40
75242	60550	36.161242000000001	36.182163000000003	53.838059999999999	53.825110000000002	Школьный переулок	0103000020E61000000100000005000000EE5EEE93A314424021CD58349DE94A40EE5EEE93A3144240FA0AD28C45EB4A4048C5FF1D51174240FA0AD28C45EB4A4048C5FF1D5117424021CD58349DE94A40EE5EEE93A314424021CD58349DE94A40
26046	48431	35.927768999999998	35.945762999999999	53.781629000000002	53.771838000000002	Первомайская	0103000020E610000001000000050000000E9F7422C1F64140B0E76B96CBE24A400E9F7422C1F64140774D486B0CE44A40286211C30EF94140774D486B0CE44A40286211C30EF94140B0E76B96CBE24A400E9F7422C1F64140B0E76B96CBE24A40
25341	9321	36.292727999999997	36.322533999999997	53.582613000000002	53.562444999999997	Центральная	0103000020E61000000100000005000000CE4F711C782542403C66A032FEC74A40CE4F711C78254240BB9C121093CA4A408DEC4ACB48294240BB9C121093CA4A408DEC4ACB482942403C66A032FEC74A40CE4F711C782542403C66A032FEC74A40
75485	60631	36.295988999999999	36.334508999999997	53.809769000000003	53.795965000000002	Рабочая	0103000020E61000000100000005000000E57CB1F7E22542405DE15D2EE2E54A40E57CB1F7E22542404628B682A6E74A40DC9BDF30D12A42404628B682A6E74A40DC9BDF30D12A42405DE15D2EE2E54A40E57CB1F7E22542405DE15D2EE2E54A40
11335	40913	36.169029999999999	36.183726	53.670082999999998	53.661622000000001	Садовая	0103000020E610000001000000050000007D0569C6A215424035289A07B0D44A407D0569C6A2154240834D9D47C5D54A4063B6645584174240834D9D47C5D54A4063B664558417424035289A07B0D44A407D0569C6A215424035289A07B0D44A40
26713	49679	36.248449999999998	36.271895999999998	53.648643999999997	53.638278	Садовая	0103000020E610000001000000050000007958A835CD1F4240CEE0EF17B3D14A407958A835CD1F4240915F3FC406D34A40E4F4F57CCD224240915F3FC406D34A40E4F4F57CCD224240CEE0EF17B3D14A407958A835CD1F4240CEE0EF17B3D14A40
26539	9387	36.102555000000002	36.168931000000001	53.828527999999999	53.788857999999998	Фрунзе	0103000020E610000001000000050000004985B185200D42400F98874CF9E44A404985B185200D4240FFE89B340DEA4A40EA23F0879F154240FFE89B340DEA4A40EA23F0879F1542400F98874CF9E44A404985B185200D42400F98874CF9E44A40
25546	9387	36.102555000000002	36.168931000000001	53.828527999999999	53.788857999999998	Советская	0103000020E610000001000000050000004985B185200D42400F98874CF9E44A404985B185200D4240FFE89B340DEA4A40EA23F0879F154240FFE89B340DEA4A40EA23F0879F1542400F98874CF9E44A404985B185200D42400F98874CF9E44A40
25926	9387	36.102555000000002	36.168931000000001	53.828527999999999	53.788857999999998	Пушкина	0103000020E610000001000000050000004985B185200D42400F98874CF9E44A404985B185200D4240FFE89B340DEA4A40EA23F0879F154240FFE89B340DEA4A40EA23F0879F1542400F98874CF9E44A404985B185200D42400F98874CF9E44A40
25781	9387	36.102555000000002	36.168931000000001	53.828527999999999	53.788857999999998	Карла Маркса	0103000020E610000001000000050000004985B185200D42400F98874CF9E44A404985B185200D4240FFE89B340DEA4A40EA23F0879F154240FFE89B340DEA4A40EA23F0879F1542400F98874CF9E44A404985B185200D42400F98874CF9E44A40
75362	49126	36.151971000000003	36.164368000000003	53.764679999999998	53.755609999999997	Школьная	0103000020E61000000100000005000000607825C973134240E94317D4B7E04A40607825C973134240E0F3C308E1E14A402541B8020A154240E0F3C308E1E14A402541B8020A154240E94317D4B7E04A40607825C973134240E94317D4B7E04A40
75175	47380	36.417234000000001	36.436673999999996	53.768777999999998	53.755949999999999	Ленина	0103000020E61000000100000005000000BF6378EC67354240A2B437F8C2E04A40BF6378EC6735424030F1475167E24A40BA8102EFE437424030F1475167E24A40BA8102EFE4374240A2B437F8C2E04A40BF6378EC67354240A2B437F8C2E04A40
75310	47691	36.888517999999998	36.915126000000001	53.696576999999998	53.683374999999998	Школьная	0103000020E6100000010000000500000023F433F5BA714240B6F3FDD478D74A4023F433F5BA714240A912656F29D94A4012DC48D922754240A912656F29D94A4012DC48D922754240B6F3FDD478D74A4023F433F5BA714240B6F3FDD478D74A40
75142	60506	36.627485	36.694985000000003	53.745462000000003	53.725515000000001	Халтурина	0103000020E6100000010000000500000083DDB06D51504240F4E0EEACDDDC4A4083DDB06D5150424094347F4C6BDF4A40F41ABB44F558424094347F4C6BDF4A40F41ABB44F5584240F4E0EEACDDDC4A4083DDB06D51504240F4E0EEACDDDC4A40
75102	60506	36.627485	36.694985000000003	53.745462000000003	53.725515000000001	Папанина	0103000020E6100000010000000500000083DDB06D51504240F4E0EEACDDDC4A4083DDB06D5150424094347F4C6BDF4A40F41ABB44F558424094347F4C6BDF4A40F41ABB44F5584240F4E0EEACDDDC4A4083DDB06D51504240F4E0EEACDDDC4A40
25355	51163	37.263969000000003	37.285600000000002	54.570666000000003	54.561870999999996	Дорожная	0103000020E61000000100000005000000341477BCC9A1424010C99063EB474B40341477BCC9A1424036785F950B494B406ADE718A8EA4424036785F950B494B406ADE718A8EA4424010C99063EB474B40341477BCC9A1424010C99063EB474B40
75437	60605	37.339975000000003	37.363053000000001	54.444471	54.433914999999999	Садовая	0103000020E61000000100000005000000933A014D84AB4240361FD7868A374B40933A014D84AB42409D82FC6CE4384B407BDB4C8578AE42409D82FC6CE4384B407BDB4C8578AE4240361FD7868A374B40933A014D84AB4240361FD7868A374B40
26010	8497	37.214067	37.231656000000001	54.412820000000004	54.402957999999998	Юбилейная	0103000020E610000001000000050000009013268C669B4240AED4B32094334B409013268C669B42403F912749D7344B400AF65FE7A69D42403F912749D7344B400AF65FE7A69D4240AED4B32094334B409013268C669B4240AED4B32094334B40
25554	49462	37.039560000000002	37.057715000000002	54.432794000000001	54.424681	Садовая	0103000020E61000000100000005000000691D554D10854240C51D6FF25B364B40691D554D10854240D8F335CB65374B408CBE823463874240D8F335CB65374B408CBE823463874240C51D6FF25B364B40691D554D10854240C51D6FF25B364B40
75358	49491	37.159602	37.190584999999999	54.347855000000003	54.330753999999999	Победы	0103000020E6100000010000000500000027309DD66D944240B682A625562A4B4027309DD66D94424003603C83862C4B40D80DDB166598424003603C83862C4B40D80DDB1665984240B682A625562A4B4027309DD66D944240B682A625562A4B40
9796	8616	37.328099000000002	37.349048000000003	54.475023999999998	54.458849999999998	Школьная	0103000020E61000000100000005000000D76CE525FFA9424082E2C798BB3A4B40D76CE525FFA9424055682096CD3C4B40FB5DD89AADAC424055682096CD3C4B40FB5DD89AADAC424082E2C798BB3A4B40D76CE525FFA9424082E2C798BB3A4B40
25352	8325	36.916778999999998	36.939307999999997	54.458692999999997	54.445962999999999	Центральная	0103000020E610000001000000050000006D54A70359754240EF1CCA5015394B406D54A70359754240BAF3C473B63A4B40826F9A3E3B784240BAF3C473B63A4B40826F9A3E3B784240EF1CCA5015394B406D54A70359754240EF1CCA5015394B40
25905	8119	37.142471	37.159008999999998	54.591031999999998	54.56317	Приокская	0103000020E6100000010000000500000070D05E7D3C9242404E0B5EF415484B4070D05E7D3C924240DA71C3EFA64B4B4084622B685A944240DA71C3EFA64B4B4084622B685A9442404E0B5EF415484B4070D05E7D3C9242404E0B5EF415484B40
25500	8227	37.195839999999997	37.210087999999999	54.543202999999998	54.531356000000002	Центральная	0103000020E61000000100000005000000D39FFD48119942404644317903444B40D39FFD4811994240670B08AD87454B401AA4E029E49A4240670B08AD87454B401AA4E029E49A42404644317903444B40D39FFD48119942404644317903444B40
26760	8433	37.152470000000001	37.167893999999997	54.485784000000002	54.477693000000002	Новая	0103000020E6100000010000000500000081CF0F23849342409A43520B253D4B4081CF0F2384934240C5758C2B2E3E4B40E998F38C7D954240C5758C2B2E3E4B40E998F38C7D9542409A43520B253D4B4081CF0F23849342409A43520B253D4B40
25997	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	площадь Победы	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26905	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Южная	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26811	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Энгельса	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25750	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Школьная	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25596	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Центральная	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25981	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Трудовые резервы	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26911	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Сосновая	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26272	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Советская	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26758	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Серафимовича	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25305	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Северная	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26606	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Октябрьская	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26273	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Некрасова	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25455	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Мира	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26415	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Металлистов	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25743	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Ленина	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25296	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Дубравная	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25965	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Болотова	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25418	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	Баумана	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
26220	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	50 лет Октября	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
25812	2910	36.97278	37.130020999999999	54.543945000000001	54.479680000000002	50 лет ВЛКСМ	0103000020E61000000100000005000000F819170E847C4240CC457C27663D4B40F819170E847C42404FE960FD9F454B4088653387A49042404FE960FD9F454B4088653387A4904240CC457C27663D4B40F819170E847C4240CC457C27663D4B40
75421	60600	37.436363999999998	37.450549000000002	54.458060000000003	54.452852	Полякова	0103000020E610000001000000050000006C938AC6DAB74240CFF6E80DF7394B406C938AC6DAB742408ACDC7B5A13A4B406D1FF296ABB942408ACDC7B5A13A4B406D1FF296ABB94240CFF6E80DF7394B406C938AC6DAB74240CFF6E80DF7394B40
26381	51260	37.630257	37.636392000000001	54.197809999999997	54.195766999999996	Ступинская	0103000020E610000001000000050000009C89E942ACD0424069519FE40E194B409C89E942ACD042402F698CD651194B40D0B7054B75D142402F698CD651194B40D0B7054B75D1424069519FE40E194B409C89E942ACD0424069519FE40E194B40
18152	29318	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	проспект Энергетиков	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
17933	29318	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	проспект Курчатова	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
18240	29318	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	переулок Автодорожный	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
18042	29318	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	Пионерская	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
18206	29318	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	Левитана	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
18087	29318	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	Автодорожный переулок	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
17944	29318	34.980873000000003	35.045847999999999	57.898251000000002	57.859450000000002	1-й Красноармейский переулок	0103000020E61000000100000005000000C443183F8D7D41400B46257502EE4C40C443183F8D7D4140B64C86E3F9F24C40234BE658DE854140B64C86E3F9F24C40234BE658DE8541400B46257502EE4C40C443183F8D7D41400B46257502EE4C40
12289	26786	34.899109000000003	35.034790000000001	57.090474999999998	57.008749999999999	Мира	0103000020E610000001000000050000000745F3001673414085EB51B81E814C400745F30016734140840D4FAF948B4C402A1DACFF73844140840D4FAF948B4C402A1DACFF7384414085EB51B81E814C400745F3001673414085EB51B81E814C40
12288	26786	34.899109000000003	35.034790000000001	57.090474999999998	57.008749999999999	Ленинградское шоссе	0103000020E610000001000000050000000745F3001673414085EB51B81E814C400745F30016734140840D4FAF948B4C402A1DACFF73844140840D4FAF948B4C402A1DACFF7384414085EB51B81E814C400745F3001673414085EB51B81E814C40
12290	26786	34.899109000000003	35.034790000000001	57.090474999999998	57.008749999999999	Калининское шоссе	0103000020E610000001000000050000000745F3001673414085EB51B81E814C400745F30016734140840D4FAF948B4C402A1DACFF73844140840D4FAF948B4C402A1DACFF7384414085EB51B81E814C400745F3001673414085EB51B81E814C40
12291	26786	34.899109000000003	35.034790000000001	57.090474999999998	57.008749999999999	Гоголя	0103000020E610000001000000050000000745F3001673414085EB51B81E814C400745F30016734140840D4FAF948B4C402A1DACFF73844140840D4FAF948B4C402A1DACFF7384414085EB51B81E814C400745F3001673414085EB51B81E814C40
6023	1465	35.823430000000002	35.851844	56.852395999999999	56.842438000000001	улица маршала Конева	0103000020E61000000100000005000000CC457C2766E941402E742502D56B4C40CC457C2766E94140E09EE74F1B6D4C409CA5643909ED4140E09EE74F1B6D4C409CA5643909ED41402E742502D56B4C40CC457C2766E941402E742502D56B4C40
390	1465	35.835782000000002	35.839618000000002	56.846651999999999	56.841836999999998	улица Ткача	0103000020E61000000100000005000000F14A92E7FAEA414008C89750C16B4C40F14A92E7FAEA4140E78BBD175F6C4C400491459A78EB4140E78BBD175F6C4C400491459A78EB414008C89750C16B4C40F14A92E7FAEA414008C89750C16B4C40
5789	1465	35.901753999999997	35.945070999999999	56.843618999999997	56.831211000000003	улица Склизкова	0103000020E61000000100000005000000C284D1AC6CF34140A9893E1F656A4C40C284D1AC6CF3414061A417B5FB6B4C40F2B22616F8F8414061A417B5FB6B4C40F2B22616F8F84140A9893E1F656A4C40C284D1AC6CF34140A9893E1F656A4C40
18396	1465	35.893912	35.906945999999998	56.854965	56.837277999999998	проспект Чайковского	0103000020E6100000010000000500000040C05AB56BF2414084D4EDEC2B6B4C4040C05AB56BF24140C11C3D7E6F6D4C40779E78CE16F44140C11C3D7E6F6D4C40779E78CE16F4414084D4EDEC2B6B4C4040C05AB56BF2414084D4EDEC2B6B4C40
18390	1465	35.906838999999998	35.946013999999998	56.847956000000003	56.832703000000002	проспект Победы	0103000020E6100000010000000500000061DEE34C13F44140FB230C03966A4C4061DEE34C13F4414037397CD2896C4C4071C79BFC16F9414037397CD2896C4C4071C79BFC16F94140FB230C03966A4C4061DEE34C13F44140FB230C03966A4C40
18382	1465	35.886609	35.906981999999999	56.835594	56.819029999999998	проспект Октябрьский	0103000020E610000001000000050000006DAB59677CF14140B0389CF9D5684C406DAB59677CF14140EE5D83BEF46A4C40C40776FC17F44140EE5D83BEF46A4C40C40776FC17F44140B0389CF9D5684C406DAB59677CF14140B0389CF9D5684C40
18502	1465	35.821570999999999	35.870618999999998	56.855251000000003	56.847926999999999	проспект Ленина	0103000020E61000000100000005000000C72B103D29E941409C3237DF886C4C40C72B103D29E94140876F61DD786D4C405B23827170EF4140876F61DD786D4C405B23827170EF41409C3237DF886C4C40C72B103D29E941409C3237DF886C4C40
18527	1465	35.909506999999998	35.914977	56.873435999999998	56.861288999999999	проспект Комсомольский	0103000020E61000000100000005000000D53DB2B96AF44140C8B3CBB73E6E4C40D53DB2B96AF44140149337C0CC6F4C40CDCB61F71DF54140149337C0CC6F4C40CDCB61F71DF54140C8B3CBB73E6E4C40D53DB2B96AF44140C8B3CBB73E6E4C40
18714	1465	35.851224000000002	35.879781000000001	56.856112000000003	56.852352000000003	проспект Калинина	0103000020E6100000010000000500000000C974E8F4EC41401157CEDE196D4C4000C974E8F4EC414049DBF813956D4C403352EFA99CF0414049DBF813956D4C403352EFA99CF041401157CEDE196D4C4000C974E8F4EC41401157CEDE196D4C40
18505	1465	35.906821000000001	35.922334999999997	56.848345000000002	56.835574000000001	проспект Волоколамский	0103000020E61000000100000005000000BB29E5B512F44140A7B1BD16F46A4C40BB29E5B512F44140D15CA791966C4C40637AC2120FF64140D15CA791966C4C40637AC2120FF64140A7B1BD16F46A4C40BB29E5B512F44140A7B1BD16F46A4C40
18370	1465	35.792169000000001	35.821570999999999	56.847960999999998	56.844230000000003	проспект 50 лет Октября	0103000020E61000000100000005000000D8F335CB65E54140AB2688BA0F6C4C40D8F335CB65E5414048A46DFC896C4C40C72B103D29E9414048A46DFC896C4C40C72B103D29E94140AB2688BA0F6C4C40D8F335CB65E54140AB2688BA0F6C4C40
18734	1465	35.892178000000001	35.905149999999999	56.849142000000001	56.848073999999997	проезд Дарвина	0103000020E61000000100000005000000F81A82E332F24140404B57B08D6C4C40F81A82E332F241407CD45FAFB06C4C40B9FC87F4DBF341407CD45FAFB06C4C40B9FC87F4DBF34140404B57B08D6C4C40F81A82E332F24140404B57B08D6C4C40
18260	1465	36.024203999999997	36.034283000000002	56.801133999999998	56.799621000000002	поселок Химинститута	0103000020E610000001000000050000005837DE1D19034240F0181EFB59664C405837DE1D1903424059DB148F8B664C4086E7A5626304424059DB148F8B664C4086E7A56263044240F0181EFB59664C405837DE1D19034240F0181EFB59664C40
18855	1465	35.943652	35.944172999999999	56.848483000000002	56.848300999999999	площадь Гагарина	0103000020E610000001000000050000000A67B796C9F8414001158E20956C4C400A67B796C9F84140221B48179B6C4C4013622EA9DAF84140221B48179B6C4C4013622EA9DAF8414001158E20956C4C400A67B796C9F8414001158E20956C4C40
19062	1465	35.918723	35.920340000000003	56.854413999999998	56.853119	пл.Славы	0103000020E61000000100000005000000A08A1BB798F54140514CDE00336D4C40A08A1BB798F541404D9F1D705D6D4C40AF997CB3CDF541404D9F1D705D6D4C40AF997CB3CDF54140514CDE00336D4C40A08A1BB798F54140514CDE00336D4C40
18365	1465	35.835926000000001	35.841917000000002	56.883178999999998	56.881065	бульвар Молодежный	0103000020E6100000010000000500000024F0879FFFEA41403B53E8BCC6704C4024F0879FFFEA4140CAC16C020C714C402579AEEFC3EB4140CAC16C020C714C402579AEEFC3EB41403B53E8BCC6704C4024F0879FFFEA41403B53E8BCC6704C40
18495	1465	35.886609	35.907018000000001	56.826600999999997	56.817636	бульвар Гусева	0103000020E610000001000000050000006DAB59677CF141402104E44BA8684C406DAB59677CF14140A2EBC20FCE694C401171732A19F44140A2EBC20FCE694C401171732A19F441402104E44BA8684C406DAB59677CF141402104E44BA8684C40
5351	1465	35.890515999999998	35.914042999999999	56.875182000000002	56.871758	Шмидта бульвар	0103000020E610000001000000050000004948A46DFCF14140600322C4956F4C404948A46DFCF141402106BAF605704C40A1116C5CFFF441402106BAF605704C40A1116C5CFFF44140600322C4956F4C404948A46DFCF14140600322C4956F4C40
6411	1465	35.893912	35.906945999999998	56.854965	56.837277999999998	Чайковского проспект	0103000020E6100000010000000500000040C05AB56BF2414084D4EDEC2B6B4C4040C05AB56BF24140C11C3D7E6F6D4C40779E78CE16F44140C11C3D7E6F6D4C40779E78CE16F4414084D4EDEC2B6B4C4040C05AB56BF2414084D4EDEC2B6B4C40
18709	1465	36.002051000000002	36.005797000000001	56.805396999999999	56.797758000000002	Центральная	0103000020E6100000010000000500000049F6083543004240AA0F24EF1C664C4049F6083543004240F4A5B73F17674C401CB5C2F4BD004240F4A5B73F17674C401CB5C2F4BD004240AA0F24EF1C664C4049F6083543004240AA0F24EF1C664C40
5804	1465	35.906174	35.920268999999998	56.835495000000002	56.829970000000003	Цанова бульвар	0103000020E61000000100000005000000253E7782FDF34140A054FB743C6A4C40253E7782FDF341405B7C0A80F16A4C40E542E55FCBF541405B7C0A80F16A4C40E542E55FCBF54140A054FB743C6A4C40253E7782FDF34140A054FB743C6A4C40
18692	1465	35.900883	35.922173000000001	56.839759000000001	56.831595	Фадеева	0103000020E61000000100000005000000DD42572250F34140314278B4716A4C40DD42572250F34140C6C210397D6B4C408A20CEC309F64140C6C210397D6B4C408A20CEC309F64140314278B4716A4C40DD42572250F34140314278B4716A4C40
18764	1465	35.878515	35.889043000000001	56.861440999999999	56.856914000000003	Учительская	0103000020E61000000100000005000000D105F52D73F0414006BEA25BAF6D4C40D105F52D73F041407E37DDB2436E4C406EDE3829CCF141407E37DDB2436E4C406EDE3829CCF1414006BEA25BAF6D4C40D105F52D73F0414006BEA25BAF6D4C40
8130	1465	35.925289999999997	35.939771	56.875064000000002	56.874307000000002	Третьяковский переулок	0103000020E610000001000000050000006DA818E76FF64140FAD4B14AE96F4C406DA818E76FF6414017F4DE1802704C40575D876A4AF8414017F4DE1802704C40575D876A4AF84140FAD4B14AE96F4C406DA818E76FF64140FAD4B14AE96F4C40
18386	1465	35.844701999999998	35.862264000000003	56.842452000000002	56.832216000000003	Тракторная	0103000020E61000000100000005000000D26EF4311FEC41409E9ACB0D866A4C40D26EF4311FEC414093399677D56B4C405342B0AA5EEE414093399677D56B4C405342B0AA5EEE41409E9ACB0D866A4C40D26EF4311FEC41409E9ACB0D866A4C40
19070	1465	35.911582000000003	35.925595999999999	56.847788999999999	56.835642999999997	Терещенко	0103000020E61000000100000005000000A7CF0EB8AEF44140CF108E59F66A4C40A7CF0EB8AEF441404B749659846C4C407AA702EE79F641404B749659846C4C407AA702EE79F64140CF108E59F66A4C40A7CF0EB8AEF44140CF108E59F66A4C40
18862	1465	35.916496000000002	35.930149999999998	56.843027999999997	56.837805000000003	Тамары Ильиной	0103000020E610000001000000050000001975ADBD4FF5414070B6B9313D6B4C401975ADBD4FF541405FCE6C57E86B4C40EC2FBB270FF741405FCE6C57E86B4C40EC2FBB270FF7414070B6B9313D6B4C401975ADBD4FF5414070B6B9313D6B4C40
6315	1465	35.911887	35.914887999999998	56.858986000000002	56.852918000000003	Студенческий переулок	0103000020E61000000100000005000000E35295B6B8F44140BA15C26A2C6D4C40E35295B6B8F4414066DCD440F36D4C405DC0CB0C1BF5414066DCD440F36D4C405DC0CB0C1BF54140BA15C26A2C6D4C40E35295B6B8F44140BA15C26A2C6D4C40
6386	1465	35.893562000000003	35.903694999999999	56.840867000000003	56.837026999999999	Спортивный переулок	0103000020E610000001000000050000006479573D60F241403B6F63B3236B4C406479573D60F2414090A4A487A16B4C4084471B47ACF3414090A4A487A16B4C4084471B47ACF341403B6F63B3236B4C406479573D60F241403B6F63B3236B4C40
18493	1465	35.876080000000002	35.892195999999998	56.855727999999999	56.849102999999999	Спартака	0103000020E610000001000000050000000057B26323F04140BEF73768AF6C4C400057B26323F04140C022BF7E886D4C409ECF807A33F24140C022BF7E886D4C409ECF807A33F24140BEF73768AF6C4C400057B26323F04140BEF73768AF6C4C40
18780	1465	35.884613999999999	35.901556999999997	56.887807000000002	56.884487	Соминка	0103000020E61000000100000005000000B8CA13083BF141405B5EB9DE36714C40B8CA13083BF141407714E7A8A3714C406C3D433866F341407714E7A8A3714C406C3D433866F341405B5EB9DE36714C40B8CA13083BF141405B5EB9DE36714C40
18783	1465	35.853811	35.872836999999997	56.832850999999998	56.827399	Солнечная	0103000020E6100000010000000500000087FBC8AD49ED41401EDFDE35E8694C4087FBC8AD49ED41406FB88FDC9A6A4C408FDE701FB9EF41406FB88FDC9A6A4C408FDE701FB9EF41401EDFDE35E8694C4087FBC8AD49ED41401EDFDE35E8694C40
18374	1465	35.898583000000002	35.927536000000003	56.861299000000002	56.855452	Советская	0103000020E61000000100000005000000ECDE8AC404F341401EA67D737F6D4C40ECDE8AC404F34140EC89AE0B3F6E4C406CEEE87FB9F64140EC89AE0B3F6E4C406CEEE87FB9F641401EA67D737F6D4C40ECDE8AC404F341401EA67D737F6D4C40
18529	1465	35.901753999999997	35.945070999999999	56.843618999999997	56.831211000000003	Склизкова	0103000020E61000000100000005000000C284D1AC6CF34140A9893E1F656A4C40C284D1AC6CF3414061A417B5FB6B4C40F2B22616F8F8414061A417B5FB6B4C40F2B22616F8F84140A9893E1F656A4C40C284D1AC6CF34140A9893E1F656A4C40
6313	1465	35.903964000000002	35.907153000000001	56.862124999999999	56.855378000000002	Свободный переулок	0103000020E610000001000000050000007461A417B5F34140E4DBBB067D6D4C407461A417B5F341403108AC1C5A6E4C40F1BBE9961DF441403108AC1C5A6E4C40F1BBE9961DF44140E4DBBB067D6D4C407461A417B5F34140E4DBBB067D6D4C40
5489	1465	35.962983000000001	36.024876999999996	56.887064000000002	56.863095000000001	Сахаровское шоссе	0103000020E610000001000000050000004FCDE50643FB4140AA2B9FE5796E4C404FCDE50643FB4140BFBA2A508B714C4017B6662B2F034240BFBA2A508B714C4017B6662B2F034240AA2B9FE5796E4C404FCDE50643FB4140AA2B9FE5796E4C40
18491	1465	35.924491000000003	35.950425000000003	56.866022000000001	56.865205000000003	Розы Люксембург	0103000020E61000000100000005000000223999B855F64140F8AA9509BF6E4C40223999B855F64140EACE13CFD96E4C408126C286A7F94140EACE13CFD96E4C408126C286A7F94140F8AA9509BF6E4C40223999B855F64140F8AA9509BF6E4C40
18695	1465	35.844656999999998	35.848357999999998	56.857933000000003	56.850180999999999	Ржевская	0103000020E6100000010000000500000032AB77B81DEC41401D5723BBD26C4C4032AB77B81DEC41406094A0BFD06D4C4065A6B4FE96EC41406094A0BFD06D4C4065A6B4FE96EC41401D5723BBD26C4C4032AB77B81DEC41401D5723BBD26C4C40
6051	1465	35.840974000000003	35.841997999999997	56.854557	56.851799999999997	Ремесленный проезд	0103000020E61000000100000005000000A6643909A5EB4140CC5D4BC8076D4C40A6643909A5EB4140B0C8AF1F626D4C4011A62897C6EB4140B0C8AF1F626D4C4011A62897C6EB4140CC5D4BC8076D4C40A6643909A5EB4140CC5D4BC8076D4C40
5779	1465	35.906838999999998	35.946013999999998	56.847956000000003	56.832703000000002	Победы проспект	0103000020E6100000010000000500000061DEE34C13F44140FB230C03966A4C4061DEE34C13F4414037397CD2896C4C4071C79BFC16F9414037397CD2896C4C4071C79BFC16F94140FB230C03966A4C4061DEE34C13F44140FB230C03966A4C40
684	1465	35.775837000000003	35.879565999999997	56.885196000000001	56.869318	Петербургское шоссе	0103000020E610000001000000050000006D0377A04EE341407DE9EDCF456F4C406D0377A04EE3414067463F1A4E714C403656629E95F0414067463F1A4E714C403656629E95F041407DE9EDCF456F4C406D0377A04EE341407DE9EDCF456F4C40
18743	1465	35.821238000000001	35.851241999999999	56.901169000000003	56.873756	Паши Савельевой	0103000020E61000000100000005000000C11DA8531EE941408657923CD76F4C40C11DA8531EE94140A3957B8159734C40A67D737FF5EC4140A3957B8159734C40A67D737FF5EC41408657923CD76F4C40C11DA8531EE941408657923CD76F4C40
18388	1465	35.920124999999999	35.944020000000002	56.848399000000001	56.830142000000002	Орджоникидзе	0103000020E61000000100000005000000B29DEFA7C6F541409D84D217426A4C40B29DEFA7C6F54140C47AA356986C4C408D62B9A5D5F84140C47AA356986C4C408D62B9A5D5F841409D84D217426A4C40B29DEFA7C6F541409D84D217426A4C40
5826	1465	35.886609	35.906981999999999	56.835594	56.819029999999998	Октябрьский проспект	0103000020E610000001000000050000006DAB59677CF14140B0389CF9D5684C406DAB59677CF14140EE5D83BEF46A4C40C40776FC17F44140EE5D83BEF46A4C40C40776FC17F44140B0389CF9D5684C406DAB59677CF14140B0389CF9D5684C40
18398	1465	35.919963000000003	35.942869999999999	56.845736000000002	56.836623000000003	Озерная	0103000020E61000000100000005000000D943FB58C1F541406C0A6476166B4C40D943FB58C1F541406286C613416C4C409430D3F6AFF841406286C613416C4C409430D3F6AFF841406C0A6476166B4C40D943FB58C1F541406C0A6476166B4C40
18706	1465	35.925190999999998	35.929755	56.881453	56.867311000000001	Новая Заря	0103000020E61000000100000005000000DAC69FA86CF64140043BFE0B046F4C40DAC69FA86CF6414005FBAF73D3704C4070253B3602F7414005FBAF73D3704C4070253B3602F74140043BFE0B046F4C40DAC69FA86CF64140043BFE0B046F4C40
19040	1465	35.728442000000001	36.056049000000002	56.927669000000002	56.783239000000002	Новая	0103000020E61000000100000005000000348463963DDD4140D3F9F02C41644C40348463963DDD4140AB4198DBBD764C409CFC169D2C074240AB4198DBBD764C409CFC169D2C074240D3F9F02C41644C40348463963DDD4140D3F9F02C41644C40
6166	1465	35.884264000000002	35.884712999999998	56.872728000000002	56.871856999999999	Никитина переулок	0103000020E61000000100000005000000DC8310902FF14140F3E49A02996F4C40DC8310902FF14140D926158DB56F4C404BAC8C463EF14140D926158DB56F4C404BAC8C463EF14140F3E49A02996F4C40DC8310902FF14140F3E49A02996F4C40
18848	1465	35.900371	35.904701000000003	56.877681000000003	56.867690000000003	Мусоргского	0103000020E6100000010000000500000027A25F5B3FF341407B884677106F4C4027A25F5B3FF3414009A9DBD957704C404AD40B3ECDF3414009A9DBD957704C404AD40B3ECDF341407B884677106F4C4027A25F5B3FF341407B884677106F4C40
5576	1465	35.728712000000002	36.099707000000002	56.848163	56.782465000000002	Московское шоссе	0103000020E61000000100000005000000F419506F46DD4140E0A128D027644C40F419506F46DD4140B056ED9A906C4C405517F032C30C4240B056ED9A906C4C405517F032C30C4240E0A128D027644C40F419506F46DD4140E0A128D027644C40
5213	1465	35.835926000000001	35.841917000000002	56.883178999999998	56.881065	Молодежный бульвар	0103000020E6100000010000000500000024F0879FFFEA41403B53E8BCC6704C4024F0879FFFEA4140CAC16C020C714C402579AEEFC3EB4140CAC16C020C714C402579AEEFC3EB41403B53E8BCC6704C4024F0879FFFEA41403B53E8BCC6704C40
18519	1465	35.883356999999997	35.920285999999997	56.826926	56.814492999999999	Можайского	0103000020E61000000100000005000000A9D898D711F1414014E97E4E41684C40A9D898D711F14140261B0FB6D8694C40BB7B80EECBF54140261B0FB6D8694C40BB7B80EECBF5414014E97E4E41684C40A9D898D711F1414014E97E4E41684C40
18394	1465	35.823430000000002	35.851844	56.852395999999999	56.842438000000001	Маршала Конева	0103000020E61000000100000005000000CC457C2766E941402E742502D56B4C40CC457C2766E94140E09EE74F1B6D4C409CA5643909ED4140E09EE74F1B6D4C409CA5643909ED41402E742502D56B4C40CC457C2766E941402E742502D56B4C40
18535	1465	35.913863999999997	35.938566999999999	56.823075000000003	56.813536999999997	Линейная	0103000020E61000000100000005000000F17EDC7EF9F44140008BFCFA21684C40F17EDC7EF9F44140DE9387855A694C406B0DA5F622F84140DE9387855A694C406B0DA5F622F84140008BFCFA21684C40F17EDC7EF9F44140008BFCFA21684C40
6047	1465	35.821570999999999	35.870618999999998	56.855251000000003	56.847926999999999	Ленина проспект	0103000020E61000000100000005000000C72B103D29E941409C3237DF886C4C40C72B103D29E94140876F61DD786D4C405B23827170EF4140876F61DD786D4C405B23827170EF41409C3237DF886C4C40C72B103D29E941409C3237DF886C4C40
18498	1465	35.904826	35.914437999999997	56.823507999999997	56.816178000000001	Левитана	0103000020E6100000010000000500000006499F56D1F341407BDB4C8578684C4006499F56D1F3414047FFCBB568694C401D1CEC4D0CF5414047FFCBB568694C401D1CEC4D0CF541407BDB4C8578684C4006499F56D1F341407BDB4C8578684C40
18798	1465	35.893436000000001	35.925353000000001	56.879432000000001	56.874822999999999	Красина	0103000020E61000000100000005000000D788601C5CF24140F1643733FA6F4C40D788601C5CF2414027874F3A91704C40B42094F771F6414027874F3A91704C40B42094F771F64140F1643733FA6F4C40D788601C5CF24140F1643733FA6F4C40
67833	1465	35.899940000000001	35.903388999999997	56.845593000000001	56.844800999999997	Коробкова	0103000020E610000001000000050000005E2EE23B31F3414065506D70226C4C405E2EE23B31F34140FF5C34643C6C4C4077483140A2F34140FF5C34643C6C4C4077483140A2F3414065506D70226C4C405E2EE23B31F3414065506D70226C4C40
18392	1465	35.850811	35.861007000000001	56.847271999999997	56.839976	Константина Заслонова	0103000020E61000000100000005000000DD09F65FE7EC414063B66455846B4C40DD09F65FE7EC41408368AD68736C4C404450357A35EE41408368AD68736C4C404450357A35EE414063B66455846B4C40DD09F65FE7EC414063B66455846B4C40
4531	1465	35.909506999999998	35.914977	56.873435999999998	56.861288999999999	Комсомольский проспект	0103000020E61000000100000005000000D53DB2B96AF44140C8B3CBB73E6E4C40D53DB2B96AF44140149337C0CC6F4C40CDCB61F71DF54140149337C0CC6F4C40CDCB61F71DF54140C8B3CBB73E6E4C40D53DB2B96AF44140C8B3CBB73E6E4C40
19045	1465	35.867843000000001	35.875495999999998	56.836559000000001	56.830782999999997	Карбышева	0103000020E610000001000000050000000188BB7A15EF41405089EB18576A4C400188BB7A15EF41405516855D146B4C40B0E3BF4010F041405516855D146B4C40B0E3BF4010F041405089EB18576A4C400188BB7A15EF41405089EB18576A4C40
18510	1465	35.909101999999997	35.918849000000002	56.839548000000001	56.835746	Ипподромная	0103000020E61000000100000005000000355D4F745DF44140A4E194B9F96A4C40355D4F745DF441400BB6114F766B4C402D7B12D89CF541400BB6114F766B4C402D7B12D89CF54140A4E194B9F96A4C40355D4F745DF44140A4E194B9F96A4C40
18735	1465	35.846975	35.848771999999997	56.830620000000003	56.826310999999997	Ильи Касьянова	0103000020E61000000100000005000000CAC342AD69EC41409BA9108FC4694C40CAC342AD69EC4140A7B393C1516A4C4058E1968FA4EC4140A7B393C1516A4C4058E1968FA4EC41409BA9108FC4694C40CAC342AD69EC41409BA9108FC4694C40
18385	1465	35.905293999999998	35.910530999999999	56.880488999999997	56.867123999999997	Зинаиды Коноплянниковой	0103000020E61000000100000005000000ECA17DACE0F34140D1C952EBFD6E4C40ECA17DACE0F341406EBE11DDB3704C40417FA1478CF441406EBE11DDB3704C40417FA1478CF44140D1C952EBFD6E4C40ECA17DACE0F34140D1C952EBFD6E4C40
18383	1465	35.903964000000002	35.925317	56.855378000000002	56.852213999999996	Желябова	0103000020E610000001000000050000007461A417B5F34140BF982D59156D4C407461A417B5F34140E4DBBB067D6D4C4067B796C970F64140E4DBBB067D6D4C4067B796C970F64140BF982D59156D4C407461A417B5F34140BF982D59156D4C40
18699	1465	35.880679999999998	35.895412	56.837879000000001	56.832265	Железнодорожников	0103000020E61000000100000005000000E21E4B1FBAF041407F4DD6A8876A4C40E21E4B1FBAF04140AA807B9E3F6B4C40153944DC9CF24140AA807B9E3F6B4C40153944DC9CF241407F4DD6A8876A4C40E21E4B1FBAF041407F4DD6A8876A4C40
18253	1465	35.901485000000001	35.913153999999999	56.870165	56.868689000000003	Екатерины Фарафоновой	0103000020E61000000100000005000000D36A48DC63F341408EB27E33316F4C40D36A48DC63F34140DA8F1491616F4C40151BF33AE2F44140DA8F1491616F4C40151BF33AE2F441408EB27E33316F4C40D36A48DC63F341408EB27E33316F4C40
18377	1465	35.886311999999997	35.896140000000003	56.858356000000001	56.854211999999997	Достоевского	0103000020E61000000100000005000000B306EFAB72F14140E5EC9DD1566D4C40B306EFAB72F14140A629029CDE6D4C4098512CB7B4F24140A629029CDE6D4C4098512CB7B4F24140E5EC9DD1566D4C40B306EFAB72F14140E5EC9DD1566D4C40
18778	1465	35.887506999999999	35.904421999999997	56.893068	56.890554999999999	Дачная	0103000020E610000001000000050000004CFC51D499F141400725CCB4FD714C404CFC51D499F14140548D5E0D50724C4036E49F19C4F34140548D5E0D50724C4036E49F19C4F341400725CCB4FD714C404CFC51D499F141400725CCB4FD714C40
5848	1465	35.886609	35.907018000000001	56.826600999999997	56.817636	Гусева бульвар	0103000020E610000001000000050000006DAB59677CF141402104E44BA8684C406DAB59677CF14140A2EBC20FCE694C401171732A19F44140A2EBC20FCE694C401171732A19F441402104E44BA8684C406DAB59677CF141402104E44BA8684C40
18748	1465	35.752552999999999	35.792169000000001	56.844230000000003	56.839823000000003	Громова	0103000020E61000000100000005000000DBC01DA853E04140DDB6EF517F6B4C40DBC01DA853E04140AB2688BA0F6C4C40D8F335CB65E54140AB2688BA0F6C4C40D8F335CB65E54140DDB6EF517F6B4C40DBC01DA853E04140DDB6EF517F6B4C40
19076	1465	35.894568	35.904116999999999	56.881827000000001	56.880484000000003	Грибоедова	0103000020E610000001000000050000002906483481F241405D5320B3B3704C402906483481F241406ADD06B5DF704C40FA60191BBAF341406ADD06B5DF704C40FA60191BBAF341405D5320B3B3704C402906483481F241405D5320B3B3704C40
18256	1465	35.880994000000001	35.917968999999999	56.870567999999999	56.865623999999997	Горького	0103000020E6100000010000000500000072FC5069C4F04140FC5069C4CC6E4C4072FC5069C4F04140D978B0C56E6F4C40F4DE180280F54140D978B0C56E6F4C40F4DE180280F54140FC5069C4CC6E4C4072FC5069C4F04140FC5069C4CC6E4C40
18702	1465	35.847819000000001	35.864142000000001	56.828729000000003	56.824542999999998	Георгиевская	0103000020E61000000100000005000000B6F63E5585EC4140A79201A08A694C40B6F63E5585EC4140971FB8CA136A4C40CE8C7E349CEE4140971FB8CA136A4C40CE8C7E349CEE4140A79201A08A694C40B6F63E5585EC4140A79201A08A694C40
5766	1465	35.906821000000001	35.922334999999997	56.848345000000002	56.835574000000001	Волоколамский проспект	0103000020E61000000100000005000000BB29E5B512F44140A7B1BD16F46A4C40BB29E5B512F44140D15CA791966C4C40637AC2120FF64140D15CA791966C4C40637AC2120FF64140A7B1BD16F46A4C40BB29E5B512F44140A7B1BD16F46A4C40
18384	1465	35.913989000000001	35.918678	56.860751999999998	56.851278999999998	Володарского	0103000020E61000000100000005000000AEF36F97FDF44140C362D4B5F66C4C40AEF36F97FDF44140B9FB1C1F2D6E4C4000C79E3D97F54140B9FB1C1F2D6E4C4000C79E3D97F54140C362D4B5F66C4C40AEF36F97FDF44140C362D4B5F66C4C40
18500	1465	35.859929000000001	35.869981000000003	56.857027000000002	56.855786999999999	Виноградова	0103000020E61000000100000005000000E5F0492712EE4140C5ABAC6D8A6D4C40E5F0492712EE4140FE648C0FB36D4C40199293895BEF4140FE648C0FB36D4C40199293895BEF4140C5ABAC6D8A6D4C40E5F0492712EE4140C5ABAC6D8A6D4C40
18864	1465	35.853057	35.871876	56.877696	56.874720000000003	Веселова	0103000020E61000000100000005000000DB4FC6F830ED41401D9430D3F66F4C40DB4FC6F830ED41403EEAAF5758704C406A15FDA199EF41403EEAAF5758704C406A15FDA199EF41401D9430D3F66F4C40DB4FC6F830ED41401D9430D3F66F4C40
18528	1465	35.926611000000001	35.944513999999998	56.855452	56.848163	Вагжанова	0103000020E61000000100000005000000938E72309BF64140B056ED9A906C4C40938E72309BF641401EA67D737F6D4C409C4EB2D5E5F841401EA67D737F6D4C409C4EB2D5E5F84140B056ED9A906C4C40938E72309BF64140B056ED9A906C4C40
5088	1465	35.914681000000002	35.922407	56.829225999999998	56.787154000000001	Бурашевское шоссе	0103000020E61000000100000005000000E4A25A4414F5414032755776C1644C40E4A25A4414F54140177FDB13246A4C40FD4CBD6E11F64140177FDB13246A4C40FD4CBD6E11F6414032755776C1644C40E4A25A4414F5414032755776C1644C40
18489	1465	35.814402000000001	35.831865000000001	56.840556999999997	56.830117999999999	Борихино Поле	0103000020E6100000010000000500000004E621533EE8414014E97E4E416A4C4004E621533EE8414041B62C5F976B4C40F1D7648D7AEA414041B62C5F976B4C40F1D7648D7AEA414014E97E4E416A4C4004E621533EE8414014E97E4E416A4C40
18532	1465	35.839329999999997	35.844388000000002	56.847607000000004	56.841496999999997	Бориса Полевого	0103000020E610000001000000050000009D465A2A6FEB41404F57772CB66B4C409D465A2A6FEB41402B6EDC627E6C4C404391EEE714EC41402B6EDC627E6C4C404391EEE714EC41404F57772CB66B4C409D465A2A6FEB41404F57772CB66B4C40
18366	1465	35.892834000000001	35.899903999999999	56.881055000000003	56.868535999999999	Благоева	0103000020E61000000100000005000000E1606F6248F2414007B309302C6F4C40E1606F6248F24140187D0569C6704C4011C5E40D30F34140187D0569C6704C4011C5E40D30F3414007B309302C6F4C40E1606F6248F2414007B309302C6F4C40
18694	1465	35.869126999999999	35.872360999999998	56.851874000000002	56.846680999999997	Баррикадная	0103000020E610000001000000050000000989B48D3FEF41408192020B606C4C400989B48D3FEF414007280D350A6D4C4026A77686A9EF414007280D350A6D4C4026A77686A9EF41408192020B606C4C400989B48D3FEF41408192020B606C4C40
18696	1465	35.900191	35.906632000000002	56.839351000000001	56.834125999999998	Александра Завидова	0103000020E61000000100000005000000A7936C7539F34140245F09A4C46A4C40A7936C7539F34140B56E83DA6F6B4C40E8C072840CF44140B56E83DA6F6B4C40E8C072840CF44140245F09A4C46A4C40A7936C7539F34140245F09A4C46A4C40
18722	1465	35.821309999999997	35.847478000000002	56.850707999999997	56.844225000000002	Академическая	0103000020E610000001000000050000005AF0A2AF20E9414099BB96900F6C4C405AF0A2AF20E941400839EFFFE36C4C402D0ABB287AEC41400839EFFFE36C4C402D0ABB287AEC414099BB96900F6C4C405AF0A2AF20E9414099BB96900F6C4C40
18395	1465	35.911949999999997	35.963037	56.867434000000003	56.863055000000003	Академика Туполева	0103000020E6100000010000000500000029CB10C7BAF441401CD31396786E4C4029CB10C7BAF4414020B8CA13086F4C4042EBE1CB44FB414020B8CA13086F4C4042EBE1CB44FB41401CD31396786E4C4029CB10C7BAF441401CD31396786E4C40
6101	1465	35.790785	35.798996000000002	56.846913000000001	56.842413000000001	50 Лет Октября проспект	0103000020E610000001000000050000006C95607138E54140D55C6E30D46B4C406C95607138E5414054C72AA5676C4C4042D13C8045E6414054C72AA5676C4C4042D13C8045E64140D55C6E30D46B4C406C95607138E54140D55C6E30D46B4C40
18369	1465	35.728442000000001	36.056049000000002	56.927669000000002	56.783239000000002	15 лет Октября	0103000020E61000000100000005000000348463963DDD4140D3F9F02C41644C40348463963DDD4140AB4198DBBD764C409CFC169D2C074240AB4198DBBD764C409CFC169D2C074240D3F9F02C41644C40348463963DDD4140D3F9F02C41644C40
18700	1465	35.887946999999997	35.900855999999997	56.846105000000001	56.842787000000001	1-я Суворова	0103000020E6100000010000000500000068CA4E3FA8F141403A3FC571E06B4C4068CA4E3FA8F14140B5FD2B2B4D6C4C40E333D93F4FF34140B5FD2B2B4D6C4C40E333D93F4FF341403A3FC571E06B4C4068CA4E3FA8F141403A3FC571E06B4C40
4680	1465	35.850191000000002	35.861096000000003	56.889783000000001	56.885899000000002	1-й Вагонников переулок	0103000020E61000000100000005000000412D060FD3EC41409147702365714C40412D060FD3EC4140B5C4CA68E4714C40B45BCB6438EE4140B5C4CA68E4714C40B45BCB6438EE41409147702365714C40412D060FD3EC41409147702365714C40
12210	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Чернышевского	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12218	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Челюскинцев	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
18181	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Чайковского	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12216	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Центральная	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12202	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Урицкого	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12201	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Трудовая	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12209	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Торопецкий тракт	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12219	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Тертия Филиппова	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12217	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Селижаровский проезд	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
17973	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Пионерская	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12205	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Партизанская	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12215	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Никиты Головни	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12211	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Московское шоссе	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12207	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Марата	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12200	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Ленинградское шоссе	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12208	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Кривощапова	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12214	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Краностроителей	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12204	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Карла Маркса	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12212	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Зубцовское шоссе	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12203	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Волосковская Горка	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12213	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Валентина Степанченко	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12206	12814	34.261296000000002	34.385227	56.288725999999997	56.230812	Большая Спасская	0103000020E61000000100000005000000AE49B725722141401EC3633F8B1D4C40AE49B72572214140A0C03BF9F4244C40A2444B1E4F314140A0C03BF9F4244C40A2444B1E4F3141401EC3633F8B1D4C40AE49B725722141401EC3633F8B1D4C40
12123	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	пр. Ленина	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12109	5955	32.751066000000002	32.803787999999997	56.243724999999998	56.202381000000003	Чайковского	0103000020E610000001000000050000009B9141EE22604040782AE09EE7194C409B9141EE22604040DA1B7C61321F4C4068757286E2664040DA1B7C61321F4C4068757286E2664040782AE09EE7194C409B9141EE22604040782AE09EE7194C40
12138	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Торопецкий тракт	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12113	5955	32.751066000000002	32.803787999999997	56.243724999999998	56.202381000000003	Советская	0103000020E610000001000000050000009B9141EE22604040782AE09EE7194C409B9141EE22604040DA1B7C61321F4C4068757286E2664040DA1B7C61321F4C4068757286E2664040782AE09EE7194C409B9141EE22604040782AE09EE7194C40
12133	5955	32.751066000000002	32.803787999999997	56.243724999999998	56.202381000000003	Пушкина	0103000020E610000001000000050000009B9141EE22604040782AE09EE7194C409B9141EE22604040DA1B7C61321F4C4068757286E2664040DA1B7C61321F4C4068757286E2664040782AE09EE7194C409B9141EE22604040782AE09EE7194C40
12118	5955	32.751066000000002	32.803787999999997	56.243724999999998	56.202381000000003	Правды	0103000020E610000001000000050000009B9141EE22604040782AE09EE7194C409B9141EE22604040DA1B7C61321F4C4068757286E2664040DA1B7C61321F4C4068757286E2664040782AE09EE7194C409B9141EE22604040782AE09EE7194C40
12136	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Пионерская	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12114	5955	32.751066000000002	32.803787999999997	56.243724999999998	56.202381000000003	Мира	0103000020E610000001000000050000009B9141EE22604040782AE09EE7194C409B9141EE22604040DA1B7C61321F4C4068757286E2664040DA1B7C61321F4C4068757286E2664040782AE09EE7194C409B9141EE22604040782AE09EE7194C40
12112	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Матросова	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12128	5955	32.751066000000002	32.803787999999997	56.243724999999998	56.202381000000003	Лесная	0103000020E610000001000000050000009B9141EE22604040782AE09EE7194C409B9141EE22604040DA1B7C61321F4C4068757286E2664040DA1B7C61321F4C4068757286E2664040782AE09EE7194C409B9141EE22604040782AE09EE7194C40
12115	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Ленина	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12121	5955	32.751066000000002	32.803787999999997	56.243724999999998	56.202381000000003	Кирова	0103000020E610000001000000050000009B9141EE22604040782AE09EE7194C409B9141EE22604040DA1B7C61321F4C4068757286E2664040DA1B7C61321F4C4068757286E2664040782AE09EE7194C409B9141EE22604040782AE09EE7194C40
12134	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Карбышева	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12120	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Казанская	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12127	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Заводская	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12126	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Больничная	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12107	5955	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	А. Невского	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
12047	40997	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	Горячева	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
11997	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	проспект Ленина	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11996	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Энергетиков	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11986	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Строителей	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11987	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Свободы	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11991	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Первомайская	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
12088	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Набережная Волги	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11985	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Маяковского	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11983	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Комсомольская	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
12000	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Горького	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11993	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Гагарина	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11999	28509	36.746808000000001	36.810706000000003	56.760593999999998	56.670771000000002	Баскакова	0103000020E6100000010000000500000012329067975F4240780DFAD2DB554C4012329067975F424054C4E9245B614C40E355D636C567424054C4E9245B614C40E355D636C5674240780DFAD2DB554C4012329067975F4240780DFAD2DB554C40
11965	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	проезд Титова	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11979	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	проезд Савеловский	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11972	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Южная	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11966	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Шевченко	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11971	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Троицкая	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11974	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Русакова	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11968	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Ленина	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11981	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Кропоткина	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11976	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Коммунистическая	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11978	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Кириллова	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11969	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Звиргздыня	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11967	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	Володарского	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11980	27735	37.308236999999998	37.397520999999998	56.902952999999997	56.840439000000003	60 лет Октября	0103000020E6100000010000000500000065355D4F74A7424038A45181936B4C4065355D4F74A742409C69C2F693734C40923CD7F7E1B242409C69C2F693734C40923CD7F7E1B2424038A45181936B4C4065355D4F74A7424038A45181936B4C40
11933	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Чистопрудная	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
10802	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Республиканская	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
11932	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Максима Горького	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
11929	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Льва Толстого	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
11934	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Ленина	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
8253	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Кашинская	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
10595	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Карла Маркса	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
11931	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Инны Константиновой	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
11930	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Гражданская	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
11928	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	Анатолия Луначарского	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
10885	1349	37.565595999999999	37.657916	57.373136000000002	57.344988000000001	25 Октября	0103000020E61000000100000005000000CC5F217365C8424098C1189128AC4C40CC5F217365C84240EA7AA2EBC2AF4C40F0C16B9736D44240EA7AA2EBC2AF4C40F0C16B9736D4424098C1189128AC4C40CC5F217365C8424098C1189128AC4C40
11210	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Ямская	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11810	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Шмидта	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11809	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Узкоколейная	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11811	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Советская	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11817	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Сиверсова	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11056	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Северная	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11824	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Ржевский тракт	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11825	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Осташковская	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11823	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Московское шоссе	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11061	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Мира	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11814	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Марины Расковой	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11830	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Магистральная	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11831	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Льва Толстого	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11829	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Ленинградское шоссе	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11818	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Красный Городок	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11827	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Коммунаров	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11819	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Карла Маркса	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11812	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Казанский проспект	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11820	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Екатерининская	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11815	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Демьяна Бедного	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11821	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Венецианова	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11813	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Вагжанова	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11816	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Большая Садовая	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11826	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	Бейшлотская набережная	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
11822	8097	34.448307	34.629237000000003	57.627740000000003	57.541182999999997	3-я Пролетарская	0103000020E61000000100000005000000B0C8AF1F6239414059130B7C45C54C40B0C8AF1F623941400E32C9C859D04C40723788D68A5041400E32C9C859D04C40723788D68A50414059130B7C45C54C40B0C8AF1F6239414059130B7C45C54C40
17335	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	переулок Первомайский	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
11867	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	переулок Молодежный	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
11732	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Школьная	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
18241	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Чудова	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
18083	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Чехова	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
18103	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Спасская	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
18071	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Советская	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
11731	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	М.И. Кузнецова	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
18099	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Красноармейская	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
11725	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Клубная	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
18118	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Кашинская	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
11728	1361	36.665008	36.732129999999998	57.816943999999999	57.753773000000002	Большая	0103000020E6100000010000000500000008CA6DFB1E554240CDCD37A27BE04C4008CA6DFB1E554240EB54F99E91E84C40D235936FB65D4240EB54F99E91E84C40D235936FB65D4240CDCD37A27BE04C4008CA6DFB1E554240CDCD37A27BE04C40
17948	31018	33.678306999999997	33.730013999999997	57.495075	57.464818999999999	Советская	0103000020E61000000100000005000000EDD286C3D2D640409BC761307FBB4C40EDD286C3D2D640409A081B9E5EBF4C40A2CF471971DD40409A081B9E5EBF4C40A2CF471971DD40409BC761307FBB4C40EDD286C3D2D640409BC761307FBB4C40
18122	31409	33.952671000000002	33.976529999999997	57.614927999999999	57.605029999999999	Толстова	0103000020E610000001000000050000007F6C921FF1F94040A88C7F9F71CD4C407F6C921FF1F9404085B2F0F5B5CE4C400CC85EEFFEFC404085B2F0F5B5CE4C400CC85EEFFEFC4040A88C7F9F71CD4C407F6C921FF1F94040A88C7F9F71CD4C40
18082	31111	33.901538000000002	33.930590000000002	57.454689999999999	57.438645000000001	Школьная	0103000020E61000000100000005000000F60CE19865F34040E7C6F48425B84C40F60CE19865F34040BCE82B4833BA4C4009FEB7921DF74040BCE82B4833BA4C4009FEB7921DF74040E7C6F48425B84C40F60CE19865F34040E7C6F48425B84C40
17905	31342	33.778478	33.815058000000001	57.611780000000003	57.593204	Юбилейная	0103000020E61000000100000005000000E753C72AA5E340409EEDD11BEECB4C40E753C72AA5E34040672C9ACE4ECE4C40ED2B0FD253E84040672C9ACE4ECE4C40ED2B0FD253E840409EEDD11BEECB4C40E753C72AA5E340409EEDD11BEECB4C40
18033	31508	33.859309000000003	33.894047	57.662536000000003	57.64978	Центральная	0103000020E6100000010000000500000049145AD6FDED404025CCB4FD2BD34C4049145AD6FDED40401A36CAFACDD44C40200BD12170F240401A36CAFACDD44C40200BD12170F2404025CCB4FD2BD34C4049145AD6FDED404025CCB4FD2BD34C40
18225	31191	33.819217000000002	33.849750999999998	57.417459999999998	57.396079	Новая	0103000020E61000000100000005000000E3A9471ADCE84040F2D077B7B2B24C40E3A9471ADCE84040AFB14B546FB54C40245F09A4C4EC4040AFB14B546FB54C40245F09A4C4EC4040F2D077B7B2B24C40E3A9471ADCE84040F2D077B7B2B24C40
18031	31051	33.800361000000002	33.829790000000003	57.444361000000001	57.425006000000003	Профсоюзная	0103000020E6100000010000000500000037FFAF3A72E64040494DBB9866B64C4037FFAF3A72E64040164F3DD2E0B84C402046088F36EA4040164F3DD2E0B84C402046088F36EA4040494DBB9866B64C4037FFAF3A72E64040494DBB9866B64C40
75060	30680	35.062764000000001	35.073669000000002	57.940114999999999	57.927554000000001	Городок монтажников 	0103000020E61000000100000005000000DEAE97A60888414012A3E716BAF64C40DEAE97A60888414051BD35B055F84C4051DD5CFC6D89414051BD35B055F84C4051DD5CFC6D89414012A3E716BAF64C40DEAE97A60888414012A3E716BAF64C40
18215	30508	34.570137000000003	34.574708999999999	58.041595000000001	58.033582000000003	Центральная	0103000020E61000000100000005000000AA9ECC3FFA484140FDDD3B6A4C044D40AA9ECC3FFA484140AC5626FC52054D40C2DB831090494140AC5626FC52054D40C2DB831090494140FDDD3B6A4C044D40AA9ECC3FFA484140FDDD3B6A4C044D40
18069	30441	34.512725000000003	34.528922000000001	57.922392000000002	57.906233	Почтовая	0103000020E61000000100000005000000BA6B09F9A04141402AC76471FFF34C40BA6B09F9A0414140C80BE9F010F64C40451152B7B3434140C80BE9F010F64C40451152B7B34341402AC76471FFF34C40BA6B09F9A04141402AC76471FFF34C40
17975	30189	34.849961999999998	34.858226000000002	58.071294999999999	58.066706000000003	Маслово	0103000020E61000000100000005000000DF6B088ECB6C414037397CD289084D40DF6B088ECB6C414025AFCE3120094D40D8497D59DA6D414025AFCE3120094D40D8497D59DA6D414037397CD289084D40DF6B088ECB6C414037397CD289084D40
12284	25860	34.722301999999999	34.739460000000001	56.988536000000003	56.977235999999998	Центральная	0103000020E61000000100000005000000EEEA5564745C4140A73CBA11167D4C40EEEA5564745C41409775FF58887E4C409F5912A0A65E41409775FF58887E4C409F5912A0A65E4140A73CBA11167D4C40EEEA5564745C4140A73CBA11167D4C40
12283	25829	34.628158999999997	34.658450000000002	57.042357000000003	57.030327999999997	Совхозная	0103000020E6100000010000000500000012D89C83675041409813B4C9E1834C4012D89C8367504140DBE044F46B854C408E06F01648544140DBE044F46B854C408E06F016485441409813B4C9E1834C4012D89C83675041409813B4C9E1834C40
12286	26085	34.618186999999999	34.640008000000002	57.211362000000001	57.200042000000003	Молодежная	0103000020E61000000100000005000000FBE769C0204F4140C9E9EBF99A994C40FBE769C0204F4140FFCEF6E80D9B4C40D5963AC8EB514140FFCEF6E80D9B4C40D5963AC8EB514140C9E9EBF99A994C40FBE769C0204F4140C9E9EBF99A994C40
12285	25998	35.145659999999999	35.168576000000002	57.008941	56.998866999999997	Советская	0103000020E61000000100000005000000ED2AA4FCA4924140DD06B5DFDA7F4C40ED2AA4FCA4924140F94B8BFA24814C40FC71FBE593954140F94B8BFA24814C40FC71FBE593954140DD06B5DFDA7F4C40ED2AA4FCA4924140DD06B5DFDA7F4C40
12282	25765	34.643188000000002	34.663246999999998	57.009126999999999	56.995117	Черемушки	0103000020E61000000100000005000000FF9600FC53524140C9586DFE5F7F4C40FF9600FC535241405B41D3122B814C40C6151747E55441405B41D3122B814C40C6151747E5544140C9586DFE5F7F4C40FF9600FC53524140C9586DFE5F7F4C40
12280	25429	35.031250999999997	35.066465000000001	56.945500000000003	56.927771999999997	Центральная	0103000020E61000000100000005000000D07B6308008441407F129F3BC1764C40D07B6308008441401B2FDD2406794C4011AAD4EC818841401B2FDD2406794C4011AAD4EC818841407F129F3BC1764C40D07B6308008441407F129F3BC1764C40
75063	60471	34.796323000000001	34.815862000000003	57.187178000000003	57.177137999999999	Центральная	0103000020E61000000100000005000000BC067DE9ED6541407E703E75AC964C40BC067DE9ED654140EE43DE72F5974C404B06802A6E684140EE43DE72F5974C404B06802A6E6841407E703E75AC964C40BC067DE9ED6541407E703E75AC964C40
12272	41036	34.641184000000003	34.913328999999997	56.544341000000003	56.439850999999997	Иваноцва	0103000020E61000000100000005000000F75B3B5112524140730E9E094D384C40F75B3B51125241409C6F44F7AC454C4083BEF4F6E77441409C6F44F7AC454C4083BEF4F6E7744140730E9E094D384C40F75B3B5112524140730E9E094D384C40
12271	17393	34.992291000000002	35.006906000000001	57.420296	57.408599000000002	Центральная	0103000020E61000000100000005000000BD8E3864037F4140D316D7F84CB44C40BD8E3864037F4140DF516342CCB54C40B612BA4BE2804140DF516342CCB54C40B612BA4BE2804140D316D7F84CB44C40BD8E3864037F4140D316D7F84CB44C40
12269	17393	34.992291000000002	35.006906000000001	57.420296	57.408599000000002	Советов	0103000020E61000000100000005000000BD8E3864037F4140D316D7F84CB44C40BD8E3864037F4140DF516342CCB54C40B612BA4BE2804140DF516342CCB54C40B612BA4BE2804140D316D7F84CB44C40BD8E3864037F4140D316D7F84CB44C40
12270	17497	35.073436000000001	35.086829999999999	57.366486999999999	57.354636999999997	Лесная	0103000020E61000000100000005000000AE2CD15966894140CC79C6BE64AD4C40AE2CD159668941405FB4C70BE9AE4C40E527D53E1D8B41405FB4C70BE9AE4C40E527D53E1D8B4140CC79C6BE64AD4C40AE2CD15966894140CC79C6BE64AD4C40
12251	17002	35.490434	35.507779999999997	57.513289999999998	57.502571000000003	Центральная	0103000020E61000000100000005000000596C938AC6BE414082751C3F54C04C40596C938AC6BE414092AE997CB3C14C400CC85EEFFEC0414092AE997CB3C14C400CC85EEFFEC0414082751C3F54C04C40596C938AC6BE414082751C3F54C04C40
12265	17199	35.110635000000002	35.12932	57.433247999999999	57.422601999999998	Климово	0103000020E610000001000000050000008065A549298E4140B29C84D217B64C408065A549298E41405987A3AB74B74C40FF5BC98E8D9041405987A3AB74B74C40FF5BC98E8D904140B29C84D217B64C408065A549298E4140B29C84D217B64C40
12266	17222	35.191536999999997	35.221828000000002	57.434885999999999	57.425063999999999	Советская	0103000020E61000000100000005000000AA7CCF48849841407D5A457F68B64C40AA7CCF48849841407FBE2D58AAB74C4026AB22DC649C41407FBE2D58AAB74C4026AB22DC649C41407D5A457F68B64C40AA7CCF48849841407D5A457F68B64C40
12252	17100	35.465989999999998	35.482743999999997	57.578870999999999	57.555168999999999	Культурная	0103000020E61000000100000005000000AB21718FA5BB414063601DC70FC74C40AB21718FA5BB414029CDE67118CA4C408C2B2E8ECABD414029CDE67118CA4C408C2B2E8ECABD414063601DC70FC74C40AB21718FA5BB414063601DC70FC74C40
12250	16930	34.727736999999998	34.752260999999997	57.316668	57.307841000000003	Новая	0103000020E61000000100000005000000698B6B7C265D414019AF795567A74C40698B6B7C265D414049D8B79388A84C403387A4164A60414049D8B79388A84C403387A4164A60414019AF795567A74C40698B6B7C265D414019AF795567A74C40
12267	17317	35.130648999999998	35.412011	57.528925999999998	57.489677	Центральная	0103000020E61000000100000005000000A7203F1BB99041403C4D66BCADBE4C40A7203F1BB99041408600E0D8B3C34C40CF4BC5C6BCB441408600E0D8B3C34C40CF4BC5C6BCB441403C4D66BCADBE4C40A7203F1BB99041403C4D66BCADBE4C40
12249	16907	34.829129999999999	34.863669999999999	57.374806	57.354657000000003	Новая	0103000020E61000000100000005000000F5108DEE206A414014268C6665AD4C40F5108DEE206A41401B2C9CA4F9AF4C40A64412BD8C6E41401B2C9CA4F9AF4C40A64412BD8C6E414014268C6665AD4C40F5108DEE206A414014268C6665AD4C40
12268	17302	35.280408000000001	35.299694000000002	57.376184000000002	57.366667	Центральная	0103000020E61000000100000005000000B5C4CA68E4A34140DFC2BAF1EEAE4C40B5C4CA68E4A34140A5A31CCC26B04C405A677C5F5CA64140A5A31CCC26B04C405A677C5F5CA64140DFC2BAF1EEAE4C40B5C4CA68E4A34140DFC2BAF1EEAE4C40
12247	15923	37.130048000000002	37.188536999999997	57.792501999999999	57.768892999999998	Широкая	0103000020E610000001000000050000008274B169A5904240C98FF8156BE24C408274B169A5904240DE019EB470E54C40008BFCFA21984240DE019EB470E54C40008BFCFA21984240C98FF8156BE24C408274B169A5904240C98FF8156BE24C40
12248	15923	37.130048000000002	37.188536999999997	57.792501999999999	57.768892999999998	Новопромышленная	0103000020E610000001000000050000008274B169A5904240C98FF8156BE24C408274B169A5904240DE019EB470E54C40008BFCFA21984240DE019EB470E54C40008BFCFA21984240C98FF8156BE24C408274B169A5904240C98FF8156BE24C40
12246	15814	33.036963999999998	33.060957999999999	56.855034000000003	56.844323000000003	Новая	0103000020E610000001000000050000008E90813CBB8440405C21ACC6126C4C408E90813CBB844040EA7B0DC1716D4C40FC36C478CD874040EA7B0DC1716D4C40FC36C478CD8740405C21ACC6126C4C408E90813CBB8440405C21ACC6126C4C40
12244	15734	33.287818000000001	33.299945999999998	56.907401	56.901366000000003	Центральная	0103000020E610000001000000050000009E996038D7A44040F9DC09F65F734C409E996038D7A44040C9AD49B725744C4073486AA164A64040C9AD49B725744C4073486AA164A64040F9DC09F65F734C409E996038D7A44040F9DC09F65F734C40
12234	15146	33.373157999999997	33.381540000000001	56.797324000000003	56.788628000000003	Центральная	0103000020E61000000100000005000000D11E2FA4C3AF4040DE5A26C3F1644C40D11E2FA4C3AF404070287CB60E664C40D40E7F4DD6B0404070287CB60E664C40D40E7F4DD6B04040DE5A26C3F1644C40D11E2FA4C3AF4040DE5A26C3F1644C40
12242	15635	\N	\N	\N	\N	Почтовая	\N
12228	14116	33.424379999999999	33.485987000000002	56.87077	56.832979000000002	Энгельса	0103000020E61000000100000005000000CA89761552B640409DA04D0E9F6A4C40CA89761552B64040412B3064756F4C40FDA36FD234BE4040412B3064756F4C40FDA36FD234BE40409DA04D0E9F6A4C40CA89761552B640409DA04D0E9F6A4C40
12226	14116	33.424379999999999	33.485987000000002	56.87077	56.832979000000002	Пушкина	0103000020E61000000100000005000000CA89761552B640409DA04D0E9F6A4C40CA89761552B64040412B3064756F4C40FDA36FD234BE4040412B3064756F4C40FDA36FD234BE40409DA04D0E9F6A4C40CA89761552B640409DA04D0E9F6A4C40
12227	14116	33.424379999999999	33.485987000000002	56.87077	56.832979000000002	Победы	0103000020E61000000100000005000000CA89761552B640409DA04D0E9F6A4C40CA89761552B64040412B3064756F4C40FDA36FD234BE4040412B3064756F4C40FDA36FD234BE40409DA04D0E9F6A4C40CA89761552B640409DA04D0E9F6A4C40
12230	14116	33.424379999999999	33.485987000000002	56.87077	56.832979000000002	Микрорайон	0103000020E61000000100000005000000CA89761552B640409DA04D0E9F6A4C40CA89761552B64040412B3064756F4C40FDA36FD234BE4040412B3064756F4C40FDA36FD234BE40409DA04D0E9F6A4C40CA89761552B640409DA04D0E9F6A4C40
12225	14116	33.424379999999999	33.485987000000002	56.87077	56.832979000000002	Ленина	0103000020E61000000100000005000000CA89761552B640409DA04D0E9F6A4C40CA89761552B64040412B3064756F4C40FDA36FD234BE4040412B3064756F4C40FDA36FD234BE40409DA04D0E9F6A4C40CA89761552B640409DA04D0E9F6A4C40
12223	14116	33.424379999999999	33.485987000000002	56.87077	56.832979000000002	Зеленая	0103000020E61000000100000005000000CA89761552B640409DA04D0E9F6A4C40CA89761552B64040412B3064756F4C40FDA36FD234BE4040412B3064756F4C40FDA36FD234BE40409DA04D0E9F6A4C40CA89761552B640409DA04D0E9F6A4C40
12245	15805	33.531199000000001	33.541618999999997	56.832191000000002	56.827882000000002	Дружная	0103000020E610000001000000050000007E552E54FEC340403A799109F8694C407E552E54FEC340404583143C856A4C4034F279C553C540404583143C856A4C4034F279C553C540403A799109F8694C407E552E54FEC340403A799109F8694C40
12241	15628	33.579608999999998	33.592841	56.719580000000001	56.708252000000002	Центральная	0103000020E61000000100000005000000CFBBB1A030CA4040CEA96400A85A4C40CFBBB1A030CA4040876D8B321B5C4C402D5DC136E2CB4040876D8B321B5C4C402D5DC136E2CB4040CEA96400A85A4C40CFBBB1A030CA4040CEA96400A85A4C40
12238	15448	33.468981999999997	33.496254999999998	56.659627	56.641669	Советская	0103000020E61000000100000005000000D234289A07BC4040B3EDB43522524C40D234289A07BC4040804754A86E544C40FDBCA94885BF4040804754A86E544C40FDBCA94885BF4040B3EDB43522524C40D234289A07BC4040B3EDB43522524C40
12240	15548	33.612506000000003	33.634236000000001	56.609096000000001	56.599578000000001	Центральная	0103000020E61000000100000005000000494DBB9866CE404057B3CEF8BE4C4C40494DBB9866CE4040ED0F94DBF64D4C4012F92EA52ED14040ED0F94DBF64D4C4012F92EA52ED1404057B3CEF8BE4C4C40494DBB9866CE404057B3CEF8BE4C4C40
12237	15348	33.257598999999999	33.273580000000003	56.650784999999999	56.645589000000001	Новая	0103000020E61000000100000005000000BC3D0801F9A0404024D40CA9A2524C40BC3D0801F9A040401ADD41EC4C534C407B6B60AB04A340401ADD41EC4C534C407B6B60AB04A3404024D40CA9A2524C40BC3D0801F9A0404024D40CA9A2524C40
12232	15044	33.787658999999998	33.809497	56.759942000000002	56.751306999999997	Центральная	0103000020E6100000010000000500000035B39602D2E44040C020E9D32A604C4035B39602D2E44040AD6D8AC745614C40E59A02999DE74040AD6D8AC745614C40E59A02999DE74040C020E9D32A604C4035B39602D2E44040C020E9D32A604C40
12236	15246	33.486210999999997	33.496470000000002	56.834347999999999	56.826985999999998	Молодежная	0103000020E610000001000000050000004CFA7B293CBE4040FB1F60ADDA694C404CFA7B293CBE4040D3BD4EEACB6A4C40FAB836548CBF4040D3BD4EEACB6A4C40FAB836548CBF4040FB1F60ADDA694C404CFA7B293CBE4040FB1F60ADDA694C40
12235	15234	33.833984999999998	33.85859	56.670732000000001	56.655707999999997	Школьный	0103000020E61000000100000005000000622D3E05C0EA4040DFDC5F3DEE534C40622D3E05C0EA4040BA30D28BDA554C401956F146E6ED4040BA30D28BDA554C401956F146E6ED4040DFDC5F3DEE534C40622D3E05C0EA4040DFDC5F3DEE534C40
12243	15713	33.198920999999999	33.217255999999999	56.822823	56.814197	Северная	0103000020E610000001000000050000006ABE4A3E769940402BC0779B37684C406ABE4A3E76994040C4B2994352694C400D6E6B0BCF9B4040C4B2994352694C400D6E6B0BCF9B40402BC0779B37684C406ABE4A3E769940402BC0779B37684C40
12239	15534	33.491359000000003	33.501842000000003	56.551322999999996	56.545397999999999	Школьная	0103000020E6100000010000000500000032CC09DAE4BE4040E3A6069ACF454C4032CC09DAE4BE40402C4487C091464C402FE1D05B3CC040402C4487C091464C402FE1D05B3CC04040E3A6069ACF454C4032CC09DAE4BE4040E3A6069ACF454C40
12233	15053	33.218494999999997	33.228619000000002	56.703181999999998	56.695329000000001	Зеленая	0103000020E6100000010000000500000075ABE7A4F79B4040EE7A698A00594C4075ABE7A4F79B4040649126DE015A4C40431F2C63439D4040649126DE015A4C40431F2C63439D4040EE7A698A00594C4075ABE7A4F79B4040EE7A698A00594C40
12231	14969	33.706083	33.731191000000003	56.744110999999997	56.733718000000003	Центральная	0103000020E610000001000000050000007BA180ED60DA4040473EAF78EA5D4C407BA180ED60DA404003CC7C073F5F4C409510ACAA97DD404003CC7C073F5F4C409510ACAA97DD4040473EAF78EA5D4C407BA180ED60DA4040473EAF78EA5D4C40
12222	13926	36.393258000000003	36.438462000000001	58.472392999999997	58.447263	Школьная	0103000020E61000000100000005000000F871344756324240FDDAFAE93F394D40F871344756324240FEEDB25F773C4D40F644D7851F384240FEEDB25F773C4D40F644D7851F384240FDDAFAE93F394D40F871344756324240FDDAFAE93F394D40
12221	13926	36.393258000000003	36.438462000000001	58.472392999999997	58.447263	Советская	0103000020E61000000100000005000000F871344756324240FDDAFAE93F394D40F871344756324240FEEDB25F773C4D40F644D7851F384240FEEDB25F773C4D40F644D7851F384240FDDAFAE93F394D40F871344756324240FDDAFAE93F394D40
12199	12710	33.859155999999999	33.874670000000002	56.251156999999999	56.244864999999997	Школьная	0103000020E61000000100000005000000C214E5D2F8ED4040AF777FBC571F4C40C214E5D2F8ED4040AB949EE925204C406B65C22FF5EF4040AB949EE925204C406B65C22FF5EF4040AF777FBC571F4C40C214E5D2F8ED4040AF777FBC571F4C40
12279	11665	33.813234000000001	33.842509999999997	56.475230000000003	56.459482000000001	Центральная	0103000020E6100000010000000500000065FF3C0D18E84040E38C614ED03A4C4065FF3C0D18E84040FF092E56D43C4C40C746205ED7EB4040FF092E56D43C4C40C746205ED7EB4040E38C614ED03A4C4065FF3C0D18E84040E38C614ED03A4C40
12190	11548	34.256382000000002	34.275120999999999	56.337710999999999	56.324077000000003	Школьная	0103000020E610000001000000050000003CA41820D12041406231EA5A7B294C403CA41820D1204140EE3F321D3A2B4C40AEB8382A37234140EE3F321D3A2B4C40AEB8382A372341406231EA5A7B294C403CA41820D12041406231EA5A7B294C40
12278	11643	33.913082000000003	33.944172999999999	56.407570999999997	56.393588999999999	Новая	0103000020E610000001000000050000007C48F8DEDFF440405D88D51F61324C407C48F8DEDFF4404025E659492B344C4013622EA9DAF8404025E659492B344C4013622EA9DAF840405D88D51F61324C407C48F8DEDFF440405D88D51F61324C40
12197	12543	34.320495000000001	34.334895000000003	56.036994999999997	56.025120000000001	Привокзальная	0103000020E6100000010000000500000009C4EBFA05294140DE3CD52137034C4009C4EBFA05294140C98E8D40BC044C40064CE0D6DD2A4140C98E8D40BC044C40064CE0D6DD2A4140DE3CD52137034C4009C4EBFA05294140DE3CD52137034C40
12194	12169	34.716301000000001	34.741481	56.315255999999998	56.305554000000001	Центральная	0103000020E61000000100000005000000CA8B4CC0AF5B4140BC94BA641C274C40CA8B4CC0AF5B414013EF004F5A284C407DCD72D9E85E414013EF004F5A284C407DCD72D9E85E4140BC94BA641C274C40CA8B4CC0AF5B4140BC94BA641C274C40
12196	12336	34.040705000000003	34.072020999999999	56.309323999999997	56.301574000000002	Банная	0103000020E6100000010000000500000050E449D23505414076A911FA99264C4050E449D23505414017EFC7ED97274C4007D0EFFB3709414017EFC7ED97274C4007D0EFFB3709414076A911FA99264C4050E449D23505414076A911FA99264C40
12192	11948	34.119945999999999	34.154288000000001	56.500129999999999	56.491146000000001	Центральная	0103000020E610000001000000050000009CA4F9635A0F4140D6C743DFDD3E4C409CA4F9635A0F4140CEDF844204404C4027158DB5BF134140CEDF844204404C4027158DB5BF134140D6C743DFDD3E4C409CA4F9635A0F4140D6C743DFDD3E4C40
12198	12658	33.936950000000003	33.943174999999997	56.206577000000003	56.201363999999998	Центральная	0103000020E610000001000000050000005DFE43FAEDF74040BE4BA94BC6194C405DFE43FAEDF740408B8D791D711A4C40D0B359F5B9F840408B8D791D711A4C40D0B359F5B9F84040BE4BA94BC6194C405DFE43FAEDF74040BE4BA94BC6194C40
12195	12260	34.095143	34.111601	56.293871000000003	56.289265	Заводское шоссе	0103000020E61000000100000005000000BFB854A52D0C41405070B1A206254C40BFB854A52D0C4140151F9F909D254C40B7990AF1480E4140151F9F909D254C40B7990AF1480E41405070B1A206254C40BFB854A52D0C41405070B1A206254C40
12193	12064	34.429603999999998	34.448037999999997	56.370429000000001	56.359110000000001	Молодежная	0103000020E610000001000000050000008A1D8D43FD36414052D50451F72D4C408A1D8D43FD364140B83EAC376A2F4C40C0AE264F59394140B83EAC376A2F4C40C0AE264F5939414052D50451F72D4C408A1D8D43FD36414052D50451F72D4C40
12191	11575	34.039698999999999	34.053893000000002	56.368011000000003	56.355798999999998	Приволжская	0103000020E610000001000000050000008A5759DB14054140897956D28A2D4C408A5759DB14054140BDC804FC1A2F4C40DE3D40F7E5064140BDC804FC1A2F4C40DE3D40F7E5064140897956D28A2D4C408A5759DB14054140897956D28A2D4C40
12187	11282	36.024571999999999	36.066037999999999	57.352592999999999	57.331007999999997	Советская	0103000020E61000000100000005000000DB32E02C25034240705B5B785EAA4C40DB32E02C2503424036E675C421AD4C408925E5EE7308424036E675C421AD4C408925E5EE73084240705B5B785EAA4C40DB32E02C25034240705B5B785EAA4C40
12188	11282	36.024571999999999	36.066037999999999	57.352592999999999	57.331007999999997	Пионерская	0103000020E61000000100000005000000DB32E02C25034240705B5B785EAA4C40DB32E02C2503424036E675C421AD4C408925E5EE7308424036E675C421AD4C408925E5EE73084240705B5B785EAA4C40DB32E02C25034240705B5B785EAA4C40
12186	11267	35.889617999999999	35.912174999999998	57.247985	57.238838999999999	Центральная	0103000020E610000001000000050000006AF7AB00DFF141403201BF46929E4C406AF7AB00DFF141400473F4F8BD9F4C40499D8026C2F441400473F4F8BD9F4C40499D8026C2F441403201BF46929E4C406AF7AB00DFF141403201BF46929E4C40
12182	11099	36.057549000000002	36.088236000000002	57.144224999999999	57.113124999999997	Пушкина	0103000020E61000000100000005000000717500C45D07424014AE47E17A8E4C40717500C45D074240FF21FDF675924C40392A37514B0B4240FF21FDF675924C40392A37514B0B424014AE47E17A8E4C40717500C45D07424014AE47E17A8E4C40
12184	11099	36.057549000000002	36.088236000000002	57.144224999999999	57.113124999999997	Колхозная	0103000020E61000000100000005000000717500C45D07424014AE47E17A8E4C40717500C45D074240FF21FDF675924C40392A37514B0B4240FF21FDF675924C40392A37514B0B424014AE47E17A8E4C40717500C45D07424014AE47E17A8E4C40
12181	11078	36.573900999999999	36.613785999999998	57.371147000000001	57.351776999999998	Комсомольская	0103000020E610000001000000050000002312859675494240143E5B0707AD4C4023128596754942401781B1BE81AF4C400F5F268A904E42401781B1BE81AF4C400F5F268A904E4240143E5B0707AD4C402312859675494240143E5B0707AD4C40
12179	11002	36.066029	36.089556000000002	57.213887	57.204172	Школьная	0103000020E6100000010000000500000036CB65A3730842402461DF4E229A4C4036CB65A373084240100533A6609B4C408E942D92760B4240100533A6609B4C408E942D92760B42402461DF4E229A4C4036CB65A3730842402461DF4E229A4C40
12178	10909	35.991325000000003	36.004953	57.324041000000001	57.318038999999999	Центральная	0103000020E61000000100000005000000865AD3BCE3FE414020ED7F80B5A84C40865AD3BCE3FE414015C8EC2C7AA94C403082C64CA200424015C8EC2C7AA94C403082C64CA200424020ED7F80B5A84C40865AD3BCE3FE414020ED7F80B5A84C40
12176	10832	36.156804000000001	36.179108999999997	57.137642	57.125805999999997	Советская	0103000020E61000000100000005000000E5F0492712144240FED137691A904C40E5F04927121442402C47C8409E914C40AAB5300BED1642402C47C8409E914C40AAB5300BED164240FED137691A904C40E5F0492712144240FED137691A904C40
12171	10642	32.589934999999997	32.592557999999997	56.865392	56.863723999999998	Первомайская	0103000020E6100000010000000500000004E275FD824B404099620E828E6E4C4004E275FD824B40402A1C412AC56E4C40D87DC7F0D84B40402A1C412AC56E4C40D87DC7F0D84B404099620E828E6E4C4004E275FD824B404099620E828E6E4C40
12173	10720	32.320943999999997	32.332227000000003	57.067673999999997	57.061557000000001	Советская	0103000020E6100000010000000500000078EC67B11429404081EB8A19E1874C4078EC67B1142940400E65A88AA9884C4092EC116A862A40400E65A88AA9884C4092EC116A862A404081EB8A19E1874C4078EC67B11429404081EB8A19E1874C40
12164	10292	32.701335	32.765788999999998	56.953035	56.903032000000003	Лесная	0103000020E6100000010000000500000024456458C5594040E99E758D96734C4024456458C5594040C078060DFD794C407A51BB5F05624040C078060DFD794C407A51BB5F05624040E99E758D96734C4024456458C5594040E99E758D96734C40
12165	10292	32.701335	32.765788999999998	56.953035	56.903032000000003	Восточная	0103000020E6100000010000000500000024456458C5594040E99E758D96734C4024456458C5594040C078060DFD794C407A51BB5F05624040C078060DFD794C407A51BB5F05624040E99E758D96734C4024456458C5594040E99E758D96734C40
12180	10292	32.701335	32.765788999999998	56.953035	56.903032000000003	249-й Стрелковой Дивизии	0103000020E6100000010000000500000024456458C5594040E99E758D96734C4024456458C5594040C078060DFD794C407A51BB5F05624040C078060DFD794C407A51BB5F05624040E99E758D96734C4024456458C5594040E99E758D96734C40
12170	10620	32.417341999999998	32.457245	56.783278000000003	56.763159000000002	Советская	0103000020E61000000100000005000000A59F70766B354040F452B131AF614C40A59F70766B35404091D6187442644C4038A11001873A404091D6187442644C4038A11001873A4040F452B131AF614C40A59F70766B354040F452B131AF614C40
12169	10568	32.840133999999999	32.856807000000003	56.648206999999999	56.638342000000002	Центральная	0103000020E61000000100000005000000FB20CB82896B4040E5D4CE30B5514C40FB20CB82896B4040E6046D72F8524C40F0FD0DDAAB6D4040E6046D72F8524C40F0FD0DDAAB6D4040E5D4CE30B5514C40FB20CB82896B4040E5D4CE30B5514C40
12168	10541	32.746583000000001	32.766167000000003	57.003588000000001	56.999073000000003	Центральная	0103000020E61000000100000005000000F25F2008905F404087A8C29FE17F4C40F25F2008905F40403B54539275804C402123A0C2116240403B54539275804C402123A0C21162404087A8C29FE17F4C40F25F2008905F404087A8C29FE17F4C40
12105	5200	32.619193000000003	32.630395	56.996068000000001	56.991031999999997	Центральная	0103000020E61000000100000005000000C1745AB7414F40400DA5F622DA7E4C40C1745AB7414F4040CB4BFE277F7F4C40ED478AC8B0504040CB4BFE277F7F4C40ED478AC8B05040400DA5F622DA7E4C40C1745AB7414F40400DA5F622DA7E4C40
12174	10760	32.778644	32.794409999999999	56.891675999999997	56.879947999999999	Набережная	0103000020E61000000100000005000000029D499BAA6340401E17D522A2704C40029D499BAA63404065506D7022724C40C4CE143AAF65404065506D7022724C40C4CE143AAF6540401E17D522A2704C40029D499BAA6340401E17D522A2704C40
12161	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	переулок Литвиенко	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12156	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	Шевчука	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12155	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	Осташковский переулок	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12157	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	Микрорайон	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12158	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	Заслонова	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12159	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	Загородная	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12152	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	Горького	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12153	8934	33.078825000000002	33.166877999999997	57.169156000000001	57.129480000000001	Володарского	0103000020E61000000100000005000000B98D06F0168A404038BEF6CC92904C40B98D06F0168A40400AF65FE7A6954C40003620425C9540400AF65FE7A6954C40003620425C95404038BEF6CC92904C40B98D06F0168A404038BEF6CC92904C40
12149	8761	33.342785999999997	33.372377	56.350971000000001	56.341636999999999	Советская	0103000020E6100000010000000500000069C36169E0AB4040410DDFC2BA2B4C4069C36169E0AB4040166C239EEC2C4C402C64AE0CAAAF4040166C239EEC2C4C402C64AE0CAAAF4040410DDFC2BA2B4C4069C36169E0AB4040410DDFC2BA2B4C40
12146	8576	33.339480999999999	33.375557000000001	56.174750000000003	56.156095000000001	Школьная	0103000020E61000000100000005000000834E081D74AB4040D908C4EBFA134C40834E081D74AB4040EE7C3F355E164C405664744012B04040EE7C3F355E164C405664744012B04040D908C4EBFA134C40834E081D74AB4040D908C4EBFA134C40
12147	8603	33.215046000000001	33.245652	56.079898999999997	56.059393	Центральная	0103000020E610000001000000050000005C9198A0869B4040404E98309A074C405C9198A0869B4040D6FD63213A0A4C4037195586719F4040D6FD63213A0A4C4037195586719F4040404E98309A074C405C9198A0869B4040404E98309A074C40
12150	7795	33.465325999999997	33.518003	56.218141000000003	56.198019000000002	Чехова	0103000020E610000001000000050000003FFD67CD8FBB40404A7EC4AF58194C403FFD67CD8FBB40405875560BEC1B4C406D1D1CEC4DC240405875560BEC1B4C406D1D1CEC4DC240404A7EC4AF58194C403FFD67CD8FBB40404A7EC4AF58194C40
12141	7795	33.465325999999997	33.518003	56.218141000000003	56.198019000000002	Октябрьская	0103000020E610000001000000050000003FFD67CD8FBB40404A7EC4AF58194C403FFD67CD8FBB40405875560BEC1B4C406D1D1CEC4DC240405875560BEC1B4C406D1D1CEC4DC240404A7EC4AF58194C403FFD67CD8FBB40404A7EC4AF58194C40
12143	7916	33.162818000000001	33.190880999999997	56.237336999999997	56.228641000000003	Юбилейная	0103000020E610000001000000050000009E996038D79440402BC3B81B441D4C409E996038D7944040BC900E0F611E4C40C136E2C96E984040BC900E0F611E4C40C136E2C96E9840402BC3B81B441D4C409E996038D79440402BC3B81B441D4C40
12144	8004	33.329770000000003	33.341951000000002	56.258167999999998	56.252696999999998	Центральная	0103000020E61000000100000005000000D99942E735AA40400E66136058204C40D99942E735AA4040D66F26A60B214C40D1EAE40CC5AB4040D66F26A60B214C40D1EAE40CC5AB40400E66136058204C40D99942E735AA40400E66136058204C40
12145	8088	33.505201999999997	33.537855999999998	56.225503000000003	56.211317999999999	Центральная	0103000020E61000000100000005000000D8EF8975AAC040402F87DD770C1B4C40D8EF8975AAC0404030134548DD1C4C408BFA2477D8C4404030134548DD1C4C408BFA2477D8C440402F87DD770C1B4C40D8EF8975AAC040402F87DD770C1B4C40
12148	8687	33.411867000000001	33.427875	55.956536999999997	55.944929000000002	Советская	0103000020E610000001000000050000009CA6CF0EB8B440406005F86EF3F84B409CA6CF0EB8B44040FC34EECD6FFA4B4054E3A59BC4B64040FC34EECD6FFA4B4054E3A59BC4B640406005F86EF3F84B409CA6CF0EB8B440406005F86EF3F84B40
12151	8851	33.315728999999997	33.331646999999997	56.413791000000003	56.402839999999998	Центральная	0103000020E610000001000000050000000BB3D0CE69A84040A4C2D84290334C400BB3D0CE69A8404088307E1AF7344C408368AD6873AA404088307E1AF7344C408368AD6873AA4040A4C2D84290334C400BB3D0CE69A84040A4C2D84290334C40
12135	6958	32.781717	32.803230999999997	56.203637999999998	56.188848999999998	Бельское шоссе	0103000020E6100000010000000500000016DD7A4D0F644040EF703B342C184C4016DD7A4D0F644040861C5BCF101A4C401211FE45D0664040861C5BCF101A4C401211FE45D0664040EF703B342C184C4016DD7A4D0F644040EF703B342C184C40
12108	5697	32.811791999999997	32.828923000000003	56.275719000000002	56.254117000000001	Советская	0103000020E61000000100000005000000C493DDCCE8674040C72DE6E786204C40C493DDCCE867404063F19BC24A234C407CF31B261A6A404063F19BC24A234C407CF31B261A6A4040C72DE6E786204C40C493DDCCE8674040C72DE6E786204C40
25967	51213	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	Южная	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
12276	4860	36.746737000000003	36.778779	58.174000999999997	58.153728999999998	пл.Корнилова	0103000020E6100000010000000500000049DBF813955F424030B95164AD134D4049DBF813955F4240533C2EAA45164D40E2E7BF07AF634240533C2EAA45164D40E2E7BF07AF63424030B95164AD134D4049DBF813955F424030B95164AD134D40
12106	4860	36.746737000000003	36.778779	58.174000999999997	58.153728999999998	Ленина	0103000020E6100000010000000500000049DBF813955F424030B95164AD134D4049DBF813955F4240533C2EAA45164D40E2E7BF07AF634240533C2EAA45164D40E2E7BF07AF63424030B95164AD134D4049DBF813955F424030B95164AD134D40
12096	3351	35.835611	35.925747999999999	57.806468000000002	57.779946000000002	Пролетарская	0103000020E61000000100000005000000C4961E4DF5EA4140B1524145D5E34C40C4961E4DF5EA4140A1A2EA573AE74C40302B14E97EF64140A1A2EA573AE74C40302B14E97EF64140B1524145D5E34C40C4961E4DF5EA4140B1524145D5E34C40
12097	3351	35.835611	35.925747999999999	57.806468000000002	57.779946000000002	Парковская	0103000020E61000000100000005000000C4961E4DF5EA4140B1524145D5E34C40C4961E4DF5EA4140A1A2EA573AE74C40302B14E97EF64140A1A2EA573AE74C40302B14E97EF64140B1524145D5E34C40C4961E4DF5EA4140B1524145D5E34C40
12094	3351	35.835611	35.925747999999999	57.806468000000002	57.779946000000002	Красноармейская	0103000020E61000000100000005000000C4961E4DF5EA4140B1524145D5E34C40C4961E4DF5EA4140A1A2EA573AE74C40302B14E97EF64140A1A2EA573AE74C40302B14E97EF64140B1524145D5E34C40C4961E4DF5EA4140B1524145D5E34C40
12095	3351	35.835611	35.925747999999999	57.806468000000002	57.779946000000002	Кранослободская	0103000020E61000000100000005000000C4961E4DF5EA4140B1524145D5E34C40C4961E4DF5EA4140A1A2EA573AE74C40302B14E97EF64140A1A2EA573AE74C40302B14E97EF64140B1524145D5E34C40C4961E4DF5EA4140B1524145D5E34C40
12076	2026	35.671543	35.705086000000001	57.443373000000001	57.418202000000001	1-я Больничная	0103000020E61000000100000005000000CA6DFB1EF5D54140978FA4A487B54C40CA6DFB1EF5D54140F7764B72C0B84C40096F0F4240DA4140F7764B72C0B84C40096F0F4240DA4140978FA4A487B54C40CA6DFB1EF5D54140978FA4A487B54C40
12091	3003	35.660584	35.683337999999999	57.134022999999999	57.120719000000001	Севастьянова	0103000020E6100000010000000500000064213A048ED44140BF805EB8738F4C4064213A048ED44140B6F468AA27914C40990E9D9E77D74140B6F468AA27914C40990E9D9E77D74140BF805EB8738F4C4064213A048ED44140BF805EB8738F4C40
12082	2088	35.432096999999999	35.496479000000001	57.137372999999997	57.109909000000002	Первомайская	0103000020E6100000010000000500000090D959F44EB741409E44847F118E4C4090D959F44EB741403C2D3F7095914C404D13B69F8CBF41403C2D3F7095914C404D13B69F8CBF41409E44847F118E4C4090D959F44EB741409E44847F118E4C40
12077	2088	35.432096999999999	35.496479000000001	57.137372999999997	57.109909000000002	Лихославская	0103000020E6100000010000000500000090D959F44EB741409E44847F118E4C4090D959F44EB741403C2D3F7095914C404D13B69F8CBF41403C2D3F7095914C404D13B69F8CBF41409E44847F118E4C4090D959F44EB741409E44847F118E4C40
12083	2088	35.432096999999999	35.496479000000001	57.137372999999997	57.109909000000002	Комсомольская	0103000020E6100000010000000500000090D959F44EB741409E44847F118E4C4090D959F44EB741403C2D3F7095914C404D13B69F8CBF41403C2D3F7095914C404D13B69F8CBF41409E44847F118E4C4090D959F44EB741409E44847F118E4C40
12080	2088	35.432096999999999	35.496479000000001	57.137372999999997	57.109909000000002	Гагарина	0103000020E6100000010000000500000090D959F44EB741409E44847F118E4C4090D959F44EB741403C2D3F7095914C404D13B69F8CBF41403C2D3F7095914C404D13B69F8CBF41409E44847F118E4C4090D959F44EB741409E44847F118E4C40
12078	2088	35.432096999999999	35.496479000000001	57.137372999999997	57.109909000000002	Бежецкая	0103000020E6100000010000000500000090D959F44EB741409E44847F118E4C4090D959F44EB741403C2D3F7095914C404D13B69F8CBF41403C2D3F7095914C404D13B69F8CBF41409E44847F118E4C4090D959F44EB741409E44847F118E4C40
12081	2088	35.432096999999999	35.496479000000001	57.137372999999997	57.109909000000002	Афанасьева	0103000020E6100000010000000500000090D959F44EB741409E44847F118E4C4090D959F44EB741403C2D3F7095914C404D13B69F8CBF41403C2D3F7095914C404D13B69F8CBF41409E44847F118E4C4090D959F44EB741409E44847F118E4C40
12090	2825	35.527444000000003	35.535348999999997	57.060524000000001	57.057474999999997	Комсомольская	0103000020E61000000100000005000000583CF54883C3414036AB3E575B874C40583CF54883C34140C24F1C40BF874C402079E75086C44140C24F1C40BF874C402079E75086C4414036AB3E575B874C40583CF54883C3414036AB3E575B874C40
12084	2483	35.210042000000001	35.247574	57.293841999999998	57.269779	Ленина	0103000020E61000000100000005000000AA6400A8E29A4140E412471E88A24C40AA6400A8E29A41407A185A9D9CA54C4082AB3C81B09F41407A185A9D9CA54C4082AB3C81B09F4140E412471E88A24C40AA6400A8E29A4140E412471E88A24C40
12086	2654	35.359271	35.373437000000003	57.097287000000001	57.086514000000001	Молодежная	0103000020E610000001000000050000005BB39597FCAD4140B55208E4128B4C405BB39597FCAD4140B9A981E6738C4C40E50E9BC8CCAF4140B9A981E6738C4C40E50E9BC8CCAF4140B55208E4128B4C405BB39597FCAD4140B55208E4128B4C40
12087	2704	35.443730000000002	35.472737000000002	57.073456999999998	57.062325000000001	Центральная	0103000020E6100000010000000500000086200725CCB84140925CFE43FA874C4086200725CCB84140C554FA0967894C40F94D61A582BC4140C554FA0967894C40F94D61A582BC4140925CFE43FA874C4086200725CCB84140925CFE43FA874C40
12074	1455	35.676493000000001	35.692473999999997	58.055979000000001	58.042915000000001	Центральная	0103000020E61000000100000005000000897C975297D6414001C11C3D7E054D40897C975297D64140A321E3512A074D4047AAEFFCA2D84140A321E3512A074D4047AAEFFCA2D8414001C11C3D7E054D40897C975297D6414001C11C3D7E054D40
12072	1342	35.649102999999997	35.666072	58.406399	58.394969000000003	Центральная	0103000020E61000000100000005000000245E9ECE15D3414088F71C588E324D40245E9ECE15D341404510E7E104344D400264E8D841D541404510E7E104344D400264E8D841D5414088F71C588E324D40245E9ECE15D3414088F71C588E324D40
12071	1253	35.478765000000003	35.490532000000002	58.174551000000001	58.164392999999997	Речная	0103000020E6100000010000000500000017BCE82B48BD41407D586FD40A154D4017BCE82B48BD4140F73DEAAF57164D401CD2A8C0C9BE4140F73DEAAF57164D401CD2A8C0C9BE41407D586FD40A154D4017BCE82B48BD41407D586FD40A154D40
12069	1230	35.479599999999998	35.499084000000003	58.385840999999999	58.372298999999998	Советская	0103000020E61000000100000005000000AF94658863BD4140B0AA5E7EA72F4D40AF94658863BD41405C3AE63C63314D407BFA08FCE1BF41405C3AE63C63314D407BFA08FCE1BF4140B0AA5E7EA72F4D40AF94658863BD4140B0AA5E7EA72F4D40
12068	1128	35.560187999999997	35.583454000000003	58.251443000000002	58.235934999999998	Новая	0103000020E610000001000000050000004ACE893DB4C74140AA7D3A1E331E4D404ACE893DB4C7414071E7C2482F204D40365CE49EAECA414071E7C2482F204D40365CE49EAECA4140AA7D3A1E331E4D404ACE893DB4C74140AA7D3A1E331E4D40
12067	1108	35.506557999999998	35.545338999999998	58.293793000000001	58.278931999999998	Советская	0103000020E610000001000000050000007AC37DE4D6C0414068E7340BB4234D407AC37DE4D6C0414099654F029B254D40DE1D19ABCDC5414099654F029B254D40DE1D19ABCDC5414068E7340BB4234D407AC37DE4D6C0414068E7340BB4234D40
12073	1108	35.506557999999998	35.545338999999998	58.293793000000001	58.278931999999998	Речная	0103000020E610000001000000050000007AC37DE4D6C0414068E7340BB4234D407AC37DE4D6C0414099654F029B254D40DE1D19ABCDC5414099654F029B254D40DE1D19ABCDC5414068E7340BB4234D407AC37DE4D6C0414068E7340BB4234D40
12066	1004	35.433391	35.448366	58.119169999999997	58.111716000000001	Ленина	0103000020E61000000100000005000000BCB0355B79B741405038BBB54C0E4D40BCB0355B79B7414008556AF6400F4D40B5519D0E64B9414008556AF6400F4D40B5519D0E64B941405038BBB54C0E4D40BCB0355B79B741405038BBB54C0E4D40
12065	989	35.468263	35.480786000000002	58.326542000000003	58.323815000000003	Речная	0103000020E61000000100000005000000A376BF0AF0BB4140257A19C572294D40A376BF0AF0BB41409E62D520CC294D40F52F49658ABD41409E62D520CC294D40F52F49658ABD4140257A19C572294D40A376BF0AF0BB4140257A19C572294D40
12064	913	35.511391000000003	35.534182000000001	58.256656999999997	58.246409	Центральная	0103000020E61000000100000005000000003CA24275C14140543882548A1F4D40003CA24275C141400DA5F622DA204D40520E661360C441400DA5F622DA204D40520E661360C44140543882548A1F4D40003CA24275C14140543882548A1F4D40
12062	802	35.934372000000003	35.950190999999997	58.263148000000001	58.251756	Береговая	0103000020E6100000010000000500000029266F8099F741403049658A39204D4029266F8099F7414000016BD5AE214D400DFAD2DB9FF9414000016BD5AE214D400DFAD2DB9FF941403049658A39204D4029266F8099F741403049658A39204D40
12063	864	35.290081999999998	35.303063000000002	58.215746000000003	58.205756999999998	Центральная	0103000020E6100000010000000500000042942F6821A5414027F6D03E561A4D4042942F6821A54140151F9F909D1B4D4057D0B4C4CAA64140151F9F909D1B4D4057D0B4C4CAA6414027F6D03E561A4D4042942F6821A5414027F6D03E561A4D40
12075	1571	35.421056999999998	35.439687999999997	58.165807999999998	58.157632999999997	Центральная	0103000020E610000001000000050000003D601E32E5B541409BE271512D144D403D601E32E5B5414024B5503239154D40C93846B247B8414024B5503239154D40C93846B247B841409BE271512D144D403D601E32E5B541409BE271512D144D40
12060	163	34.027752	34.058995000000003	56.951503000000002	56.927782000000001	Трудовая	0103000020E610000001000000050000000533A6608D034140A3E8818FC1764C400533A6608D034140E085ADD9CA794C4053D0ED258D074140E085ADD9CA794C4053D0ED258D074140A3E8818FC1764C400533A6608D034140A3E8818FC1764C40
12041	731	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	Степана Разина	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
12042	731	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	Советская	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
12050	731	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	Пионерский бульвар	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
12061	731	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	Октябрьская	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
12043	731	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	Карла Маркса	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
12048	731	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	Бумажников	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
12046	731	34.098162000000002	34.232495999999998	57.055408999999997	56.999195999999998	8 Марта	0103000020E61000000100000005000000E0DA8992900C4140A2258FA7E57F4C40E0DA8992900C4140B87361A417874C40B439CE6DC21D4140B87361A417874C40B439CE6DC21D4140A2258FA7E57F4C40E0DA8992900C4140A2258FA7E57F4C40
12040	31023	37.098229000000003	37.141528000000001	58.077272000000001	58.045582000000003	Пионерская	0103000020E61000000100000005000000684293C4928C4240A5A487A1D5054D40684293C4928C4240C172840CE4094D40F1BBE9961D924240C172840CE4094D40F1BBE9961D924240A5A487A1D5054D40684293C4928C4240A5A487A1D5054D40
12037	31023	37.098229000000003	37.141528000000001	58.077272000000001	58.045582000000003	Октябрьская	0103000020E61000000100000005000000684293C4928C4240A5A487A1D5054D40684293C4928C4240C172840CE4094D40F1BBE9961D924240C172840CE4094D40F1BBE9961D924240A5A487A1D5054D40684293C4928C4240A5A487A1D5054D40
12039	31023	37.098229000000003	37.141528000000001	58.077272000000001	58.045582000000003	Мясникова	0103000020E61000000100000005000000684293C4928C4240A5A487A1D5054D40684293C4928C4240C172840CE4094D40F1BBE9961D924240C172840CE4094D40F1BBE9961D924240A5A487A1D5054D40684293C4928C4240A5A487A1D5054D40
12038	31023	37.098229000000003	37.141528000000001	58.077272000000001	58.045582000000003	Калинина	0103000020E61000000100000005000000684293C4928C4240A5A487A1D5054D40684293C4928C4240C172840CE4094D40F1BBE9961D924240C172840CE4094D40F1BBE9961D924240A5A487A1D5054D40684293C4928C4240A5A487A1D5054D40
12021	30023	36.634850999999998	36.663220000000003	56.708351	56.696855999999997	Центральная	0103000020E610000001000000050000009C6A2DCC42514240BC02D19332594C409C6A2DCC42514240618BDD3EAB5A4C40CD069964E4544240618BDD3EAB5A4C40CD069964E4544240BC02D19332594C409C6A2DCC42514240BC02D19332594C40
12026	30256	36.422803999999999	36.433934000000001	56.669530000000002	56.663223000000002	Парковая	0103000020E610000001000000050000001A4F04711E3642403E7AC37DE4544C401A4F04711E3642406FD8B628B3554C40AD4F39268B3742406FD8B628B3554C40AD4F39268B3742403E7AC37DE4544C401A4F04711E3642403E7AC37DE4544C40
12019	29906	36.800339000000001	36.817945999999999	56.666493000000003	56.657034000000003	Новая	0103000020E610000001000000050000004F5B238271664240172EABB019544C404F5B238271664240A80183A44F554C406FF25B74B2684240A80183A44F554C406FF25B74B2684240172EABB019544C404F5B238271664240172EABB019544C40
12033	30361	36.272748999999997	36.318105000000003	56.674143999999998	56.629486	проспект Химиков	0103000020E6100000010000000500000023827170E92242401AA54BFF92504C4023827170E9224240B665C0594A564C40D8D825AAB7284240B665C0594A564C40D8D825AAB72842401AA54BFF92504C4023827170E92242401AA54BFF92504C40
12028	30361	36.272748999999997	36.318105000000003	56.674143999999998	56.629486	Фадеева	0103000020E6100000010000000500000023827170E92242401AA54BFF92504C4023827170E9224240B665C0594A564C40D8D825AAB7284240B665C0594A564C40D8D825AAB72842401AA54BFF92504C4023827170E92242401AA54BFF92504C40
12030	30361	36.272748999999997	36.318105000000003	56.674143999999998	56.629486	Правды	0103000020E6100000010000000500000023827170E92242401AA54BFF92504C4023827170E9224240B665C0594A564C40D8D825AAB7284240B665C0594A564C40D8D825AAB72842401AA54BFF92504C4023827170E92242401AA54BFF92504C40
12031	30361	36.272748999999997	36.318105000000003	56.674143999999998	56.629486	Погрузочная	0103000020E6100000010000000500000023827170E92242401AA54BFF92504C4023827170E9224240B665C0594A564C40D8D825AAB7284240B665C0594A564C40D8D825AAB72842401AA54BFF92504C4023827170E92242401AA54BFF92504C40
12029	30361	36.272748999999997	36.318105000000003	56.674143999999998	56.629486	Калинина	0103000020E6100000010000000500000023827170E92242401AA54BFF92504C4023827170E9224240B665C0594A564C40D8D825AAB7284240B665C0594A564C40D8D825AAB72842401AA54BFF92504C4023827170E92242401AA54BFF92504C40
12032	30361	36.272748999999997	36.318105000000003	56.674143999999998	56.629486	Диева	0103000020E6100000010000000500000023827170E92242401AA54BFF92504C4023827170E9224240B665C0594A564C40D8D825AAB7284240B665C0594A564C40D8D825AAB72842401AA54BFF92504C4023827170E92242401AA54BFF92504C40
12020	29973	36.691049999999997	36.712690000000002	56.856560000000002	56.848073999999997	Школьная	0103000020E610000001000000050000004DF38E5374584240404B57B08D6C4C404DF38E5374584240E88711C2A36D4C40D717096D395B4240E88711C2A36D4C40D717096D395B4240404B57B08D6C4C404DF38E5374584240404B57B08D6C4C40
12035	30694	36.200417000000002	36.22972	56.650838999999998	56.637569999999997	Школьная	0103000020E61000000100000005000000FE47A643A71942409274CDE49B514C40FE47A643A71942400DFB3DB14E534C405A9E0777671D42400DFB3DB14E534C405A9E0777671D42409274CDE49B514C40FE47A643A71942409274CDE49B514C40
12009	29461	36.407218	36.456338000000002	56.572026999999999	56.534157	Фабричная	0103000020E61000000100000005000000D82B2CB81F344240F9F6AE415F444C40D82B2CB81F344240E9B6442E38494C4006F69848693A4240E9B6442E38494C4006F69848693A4240F9F6AE415F444C40D82B2CB81F344240F9F6AE415F444C40
12012	29461	36.407218	36.456338000000002	56.572026999999999	56.534157	Советская	0103000020E61000000100000005000000D82B2CB81F344240F9F6AE415F444C40D82B2CB81F344240E9B6442E38494C4006F69848693A4240E9B6442E38494C4006F69848693A4240F9F6AE415F444C40D82B2CB81F344240F9F6AE415F444C40
12011	29461	36.407218	36.456338000000002	56.572026999999999	56.534157	Парковая	0103000020E61000000100000005000000D82B2CB81F344240F9F6AE415F444C40D82B2CB81F344240E9B6442E38494C4006F69848693A4240E9B6442E38494C4006F69848693A4240F9F6AE415F444C40D82B2CB81F344240F9F6AE415F444C40
12008	29461	36.407218	36.456338000000002	56.572026999999999	56.534157	Моховая	0103000020E61000000100000005000000D82B2CB81F344240F9F6AE415F444C40D82B2CB81F344240E9B6442E38494C4006F69848693A4240E9B6442E38494C4006F69848693A4240F9F6AE415F444C40D82B2CB81F344240F9F6AE415F444C40
12010	29461	36.407218	36.456338000000002	56.572026999999999	56.534157	Ленинская	0103000020E61000000100000005000000D82B2CB81F344240F9F6AE415F444C40D82B2CB81F344240E9B6442E38494C4006F69848693A4240E9B6442E38494C4006F69848693A4240F9F6AE415F444C40D82B2CB81F344240F9F6AE415F444C40
12024	30157	36.489773	36.52196	56.594329999999999	56.576841999999999	Школьная	0103000020E610000001000000050000005EBBB4E1B03E4240C87A6AF5D5494C405EBBB4E1B03E42400E846401134C4C40FBE8D495CF4242400E846401134C4C40FBE8D495CF424240C87A6AF5D5494C405EBBB4E1B03E4240C87A6AF5D5494C40
12017	29882	36.959322999999998	36.985804999999999	56.597110000000001	56.586562999999998	Гаранина	0103000020E610000001000000050000007AA69718CB7A42409605137F144B4C407AA69718CB7A4240AA0EB9196E4C4C40DC9DB5DB2E7E4240AA0EB9196E4C4C40DC9DB5DB2E7E42409605137F144B4C407AA69718CB7A42409605137F144B4C40
12013	29730	36.243375	36.296078999999999	56.517995999999997	56.498703999999996	Дм. Обушева	0103000020E61000000100000005000000FED478E9261F424033315D88D53F4C40FED478E9261F4240BABA63B14D424C402504ABEAE5254240BABA63B14D424C402504ABEAE525424033315D88D53F4C40FED478E9261F424033315D88D53F4C40
12014	29730	36.243375	36.296078999999999	56.517995999999997	56.498703999999996	Дачный переулок	0103000020E61000000100000005000000FED478E9261F424033315D88D53F4C40FED478E9261F4240BABA63B14D424C402504ABEAE5254240BABA63B14D424C402504ABEAE525424033315D88D53F4C40FED478E9261F424033315D88D53F4C40
12034	30666	36.190122000000002	36.232505000000003	56.630327000000001	56.619759999999999	Пионерская	0103000020E610000001000000050000000420EEEA551842403AAFB14B544F4C400420EEEA5518424095641D8EAE504C4008944DB9C21D424095641D8EAE504C4008944DB9C21D42403AAFB14B544F4C400420EEEA551842403AAFB14B544F4C40
12023	30121	36.507362000000001	36.547013999999997	56.544232000000001	56.506484	Школьная	0103000020E61000000100000005000000D89DEE3CF140424040F9BB77D4404C40D89DEE3CF1404240E5B7E864A9454C40213A048E04464240E5B7E864A9454C40213A048E0446424040F9BB77D4404C40D89DEE3CF140424040F9BB77D4404C40
12015	29829	36.963168000000003	36.989327000000003	56.671993000000001	56.652749	Центральная	0103000020E61000000100000005000000E146CA16497B424094BF7B478D534C40E146CA16497B42400A12DBDD03564C4060066344A27E42400A12DBDD03564C4060066344A27E424094BF7B478D534C40E146CA16497B424094BF7B478D534C40
12036	30765	36.309885999999999	36.342962	56.721397000000003	56.696466000000001	Советская	0103000020E610000001000000050000007FBE2D58AA274240526342CC25594C407FBE2D58AA2742405D37A5BC565C4C40A8E2C62DE62B42405D37A5BC565C4C40A8E2C62DE62B4240526342CC25594C407FBE2D58AA274240526342CC25594C40
12027	30285	36.347920000000002	36.373486999999997	56.550598999999998	56.541235	Советская	0103000020E61000000100000005000000EACF7EA4882C4240AC39403047454C40EACF7EA4882C4240EB1A2D077A464C40963D096CCE2F4240EB1A2D077A464C40963D096CCE2F4240AC39403047454C40EACF7EA4882C4240AC39403047454C40
12022	30062	36.614316000000002	36.635570000000001	56.616371999999998	56.601109000000001	Большая	0103000020E610000001000000050000006CB41CE8A14E4240672AC423F14C4C406CB41CE8A14E4240C6151747E54E4C40CC28965B5A514240C6151747E54E4C40CC28965B5A514240672AC423F14C4C406CB41CE8A14E4240672AC423F14C4C40
12275	41044	36.623542	37.674930000000003	57.322763000000002	56.769064	пр-д Абрамовский	0103000020E610000001000000050000005AD76839D04F4240F6436CB070624C405AD76839D04F4240EFAD484C50A94C406E8B321B64D64240EFAD484C50A94C406E8B321B64D64240F6436CB070624C405AD76839D04F4240F6436CB070624C40
11961	27621	37.225610000000003	37.242328000000001	56.821832999999998	56.815035000000002	Центральная	0103000020E6100000010000000500000046D3D9C9E09C4240350C1F1153684C4046D3D9C9E09C424004E3E0D231694C40DA73999A049F424004E3E0D231694C40DA73999A049F4240350C1F1153684C4046D3D9C9E09C4240350C1F1153684C40
11959	27561	37.309531	37.331629999999997	57.085281000000002	57.075620000000001	Солнечная	0103000020E61000000100000005000000910C39B69EA74240367689EAAD894C40910C39B69EA742402FFCE07CEA8A4C40AD2F12DA72AA42402FFCE07CEA8A4C40AD2F12DA72AA4240367689EAAD894C40910C39B69EA74240367689EAAD894C40
11958	27515	37.422117	37.445078000000002	56.868152000000002	56.860436999999997	Центральная	0103000020E61000000100000005000000F60A0BEE07B6424059A2B3CC226E4C40F60A0BEE07B642407FFACF9A1F6F4C40A515DF50F8B842407FFACF9A1F6F4C40A515DF50F8B8424059A2B3CC226E4C40F60A0BEE07B6424059A2B3CC226E4C40
11957	27471	36.807758999999997	36.838858999999999	57.011268999999999	56.980944000000001	Школьная	0103000020E610000001000000050000005B069CA5646742408D9AAF928F7D4C405B069CA564674240B43A394371814C40467A51BB5F6B4240B43A394371814C40467A51BB5F6B42408D9AAF928F7D4C405B069CA5646742408D9AAF928F7D4C40
11954	27421	37.540146999999997	37.558005000000001	56.962228000000003	56.953231000000002	Заводская	0103000020E610000001000000050000002904728923C5424046443179037A4C402904728923C54240D3A57F492A7B4C40930035B56CC74240D3A57F492A7B4C40930035B56CC7424046443179037A4C402904728923C5424046443179037A4C40
11953	27350	37.074119000000003	37.086838999999998	57.092210999999999	57.087691999999997	Володарского	0103000020E6100000010000000500000091813CBB7C894240770FD07D398B4C4091813CBB7C8942406DAAEE91CD8B4C403882548A1D8B42406DAAEE91CD8B4C403882548A1D8B4240770FD07D398B4C4091813CBB7C894240770FD07D398B4C40
11952	27230	37.062575000000002	37.069482999999998	56.993400999999999	56.989624999999997	Советская	0103000020E610000001000000050000000B46257502884240E9263108AC7E4C400B46257502884240276893C3277F4C406150A6D1E4884240276893C3277F4C406150A6D1E4884240E9263108AC7E4C400B46257502884240E9263108AC7E4C40
11950	27145	37.051983999999997	37.067335999999997	56.925502000000002	56.914458000000003	Молодежная	0103000020E6100000010000000500000027F56569A786424065C8B1F50C754C4027F56569A7864240F9307BD976764C40F6EB4E779E884240F9307BD976764C40F6EB4E779E88424065C8B1F50C754C4027F56569A786424065C8B1F50C754C40
12070	27192	36.864856000000003	36.893143999999999	57.292265999999998	57.281894999999999	Лесная	0103000020E61000000100000005000000ECDFF599B36E4240F5F3A62215A44C40ECDFF599B36E4240CADDE7F868A54C402F4FE78A52724240CADDE7F868A54C402F4FE78A52724240F5F3A62215A44C40ECDFF599B36E4240F5F3A62215A44C40
11948	27066	36.743287000000002	36.766804999999998	57.091155000000001	57.082512999999999	Школьная	0103000020E610000001000000050000005F454607245F4240573F36C98F8A4C405F454607245F4240F6EE8FF7AA8B4C4063B48EAA26624240F6EE8FF7AA8B4C4063B48EAA26624240573F36C98F8A4C405F454607245F4240573F36C98F8A4C40
11949	27086	37.162216000000001	37.192031	56.970078999999998	56.953310000000002	Центральная	0103000020E61000000100000005000000A8716F7EC39442409279E40F067A4C40A8716F7EC3944240A8C4758C2B7C4C40BA68C87894984240A8C4758C2B7C4C40BA68C878949842409279E40F067A4C40A8716F7EC39442409279E40F067A4C40
11947	27006	36.703392999999998	36.750644000000001	57.170537000000003	57.138041999999999	Садовый переулок	0103000020E610000001000000050000001F9E25C8085A4240BABC395CAB914C401F9E25C8085A424005E10A28D4954C402578431A1560424005E10A28D4954C402578431A15604240BABC395CAB914C401F9E25C8085A4240BABC395CAB914C40
11962	40978	37.494906999999998	37.537630999999998	56.97392	56.958286999999999	Заводская	0103000020E61000000100000005000000DEC7D11C59BF42404A97FE25A97A4C40DEC7D11C59BF4240CD751A69A97C4C406B28B517D1C44240CD751A69A97C4C406B28B517D1C442404A97FE25A97A4C40DEC7D11C59BF42404A97FE25A97A4C40
11941	26140	37.274864999999998	37.320912999999997	57.596725999999997	57.572467000000003	Советская	0103000020E6100000010000000500000053E8BCC62EA342400685419946C94C4053E8BCC62EA3424021567F8461CC4C403DEE5BAD13A9424021567F8461CC4C403DEE5BAD13A942400685419946C94C4053E8BCC62EA342400685419946C94C40
11942	26140	37.274864999999998	37.320912999999997	57.596725999999997	57.572467000000003	Ленинградская	0103000020E6100000010000000500000053E8BCC62EA342400685419946C94C4053E8BCC62EA3424021567F8461CC4C403DEE5BAD13A9424021567F8461CC4C403DEE5BAD13A942400685419946C94C4053E8BCC62EA342400685419946C94C40
11940	26140	37.274864999999998	37.320912999999997	57.596725999999997	57.572467000000003	Кооперативная	0103000020E6100000010000000500000053E8BCC62EA342400685419946C94C4053E8BCC62EA3424021567F8461CC4C403DEE5BAD13A9424021567F8461CC4C403DEE5BAD13A942400685419946C94C4053E8BCC62EA342400685419946C94C40
11938	25777	37.242291999999999	37.261327000000001	57.460858999999999	57.452055999999999	Центральная	0103000020E610000001000000050000008D0A9C6C039F4240F4FA93F8DCB94C408D0A9C6C039F42409C887E6DFDBA4C40E947C32973A142409C887E6DFDBA4C40E947C32973A14240F4FA93F8DCB94C408D0A9C6C039F4240F4FA93F8DCB94C40
11936	25065	37.605049999999999	37.616827000000001	57.179806999999997	57.168174999999998	Центральная	0103000020E61000000100000005000000EF38454772CD42409D8026C286954C40EF38454772CD4240C24B70EA03974C401825E82FF4CE4240C24B70EA03974C401825E82FF4CE42409D8026C286954C40EF38454772CD42409D8026C286954C40
11937	25194	37.133361999999998	37.150314000000002	57.261567999999997	57.249381999999997	Молодежная	0103000020E61000000100000005000000BB438A0112914240041BD7BFEB9F4C40BB438A01129142400ED76A0F7BA14C40C310397D3D9342400ED76A0F7BA14C40C310397D3D934240041BD7BFEB9F4C40BB438A0112914240041BD7BFEB9F4C40
11935	24973	37.559074000000003	37.577624	57.242505999999999	57.230333000000002	Слободка	0103000020E610000001000000050000009F05A1BC8FC7424044183F8D7B9D4C409F05A1BC8FC74240B98AC56F0A9F4C403EB14E95EFC94240B98AC56F0A9F4C403EB14E95EFC9424044183F8D7B9D4C409F05A1BC8FC7424044183F8D7B9D4C40
11915	24022	38.094271999999997	38.107126999999998	56.937407999999998	56.923394999999999	Центральная	0103000020E61000000100000005000000D976DA1A110C43401C25AFCE31764C40D976DA1A110C43401F813FFCFC774C4061C26856B60D43401F813FFCFC774C4061C26856B60D43401C25AFCE31764C40D976DA1A110C43401C25AFCE31764C40
11907	23695	37.902867999999998	37.912452999999999	57.263564000000002	57.260292999999997	Чигиревская	0103000020E610000001000000050000006E4DBA2D91F342405930F14751A14C406E4DBA2D91F3424094331477BCA14C408C118942CBF4424094331477BCA14C408C118942CBF442405930F14751A14C406E4DBA2D91F342405930F14751A14C40
11926	24528	38.031094000000003	38.045026999999997	57.121814000000001	57.113022999999998	Молодежная	0103000020E61000000100000005000000098D60E3FA0343401059A489778E4C40098D60E3FA034340F418E599978F4C40EF37DA71C3054340F418E599978F4C40EF37DA71C30543401059A489778E4C40098D60E3FA0343401059A489778E4C40
11925	24467	38.167870999999998	38.183717999999999	57.116287	57.104976999999998	Широкая	0103000020E61000000100000005000000317903CC7C15434085EAE6E26F8D4C40317903CC7C15434098F90E7EE28E4C40E0D748128417434098F90E7EE28E4C40E0D748128417434085EAE6E26F8D4C40317903CC7C15434085EAE6E26F8D4C40
11906	23632	37.859507000000001	37.874661000000003	57.109557000000002	57.102347000000002	Центральная	0103000020E610000001000000050000006FD74B5304EE4240FFEBDCB4198D4C406FD74B5304EE42402106BAF6058E4C40180B43E4F4EF42402106BAF6058E4C40180B43E4F4EF4240FFEBDCB4198D4C406FD74B5304EE4240FFEBDCB4198D4C40
11918	24173	38.208215000000003	38.230125000000001	57.311773000000002	57.298126000000003	Речная	0103000020E61000000100000005000000B1C403CAA61A43402D0B26FE28A64C40B1C403CAA61A43404E637B2DE8A74C40FA7E6ABC741D43404E637B2DE8A74C40FA7E6ABC741D43402D0B26FE28A64C40B1C403CAA61A43402D0B26FE28A64C40
11913	23974	37.912795000000003	37.93289	57.091189	57.081290000000003	Школьная	0103000020E61000000100000005000000E6797077D6F44240F5BEF1B5678A4C40E6797077D6F44240A260C614AC8B4C40FA6184F068F74240A260C614AC8B4C40FA6184F068F74240F5BEF1B5678A4C40E6797077D6F44240F5BEF1B5678A4C40
11924	24425	38.081696000000001	38.092458000000001	57.172629999999998	57.166330000000002	Школьная	0103000020E61000000100000005000000651BB803750A4340FE2B2B4D4A954C40651BB803750A43407C2766BD18964C407520EBA9D50B43407C2766BD18964C407520EBA9D50B4340FE2B2B4D4A954C40651BB803750A4340FE2B2B4D4A954C40
11923	24361	38.056741000000002	38.075119999999998	57.054582000000003	57.045200999999999	Школьная	0103000020E61000000100000005000000D2AB014A430743408D5F7825C9854C40D2AB014A43074340A379008BFC864C4044A33B889D094340A379008BFC864C4044A33B889D0943408D5F7825C9854C40D2AB014A430743408D5F7825C9854C40
11912	23898	37.981929000000001	38.009076	57.054675000000003	57.026311	Ленинская	0103000020E610000001000000050000003BFF76D9AFFD42403543AA285E834C403BFF76D9AFFD424054742497FF864C40D99601672901434054742497FF864C40D9960167290143403543AA285E834C403BFF76D9AFFD42403543AA285E834C40
11917	24112	38.046526999999998	38.061779999999999	57.265296999999997	57.259946999999997	Новая	0103000020E61000000100000005000000C4B0C398F4054340BED87BF145A14C40C4B0C398F40543400B5D8940F5A14C4000C63368E80743400B5D8940F5A14C4000C63368E8074340BED87BF145A14C40C4B0C398F4054340BED87BF145A14C40
11921	24322	37.972614	37.988531999999999	57.207945000000002	57.202539000000002	Центральная	0103000020E61000000100000005000000DDD0949D7EFC4240109546CCEC994C40DDD0949D7EFC4240F12E17F19D9A4C405586713788FE4240F12E17F19D9A4C405586713788FE4240109546CCEC994C40DDD0949D7EFC4240109546CCEC994C40
11909	23821	37.788395999999999	37.804557000000003	57.093522	57.085638000000003	Советская	0103000020E610000001000000050000000B26FE28EAE44240BEA59C2FF68A4C400B26FE28EAE442406FBA6587F88B4C404A6249B9FBE642406FBA6587F88B4C404A6249B9FBE64240BEA59C2FF68A4C400B26FE28EAE44240BEA59C2FF68A4C40
11896	766	37.803334999999997	37.861474000000001	57.249527999999998	57.228341	улица Коминтерна	0103000020E61000000100000005000000B75D68AED3E6424000AB23473A9D4C40B75D68AED3E64240D8B79388F09F4C405A2DB0C744EE4240D8B79388F09F4C405A2DB0C744EE424000AB23473A9D4C40B75D68AED3E6424000AB23473A9D4C40
11895	766	37.803334999999997	37.861474000000001	57.249527999999998	57.228341	Тверская	0103000020E61000000100000005000000B75D68AED3E6424000AB23473A9D4C40B75D68AED3E64240D8B79388F09F4C405A2DB0C744EE4240D8B79388F09F4C405A2DB0C744EE424000AB23473A9D4C40B75D68AED3E6424000AB23473A9D4C40
11897	766	37.803334999999997	37.861474000000001	57.249527999999998	57.228341	Студенческая	0103000020E61000000100000005000000B75D68AED3E6424000AB23473A9D4C40B75D68AED3E64240D8B79388F09F4C405A2DB0C744EE4240D8B79388F09F4C405A2DB0C744EE424000AB23473A9D4C40B75D68AED3E6424000AB23473A9D4C40
11894	766	37.803334999999997	37.861474000000001	57.249527999999998	57.228341	Коминтерна	0103000020E61000000100000005000000B75D68AED3E6424000AB23473A9D4C40B75D68AED3E64240D8B79388F09F4C405A2DB0C744EE4240D8B79388F09F4C405A2DB0C744EE424000AB23473A9D4C40B75D68AED3E6424000AB23473A9D4C40
11769	766	37.803334999999997	37.861474000000001	57.249527999999998	57.228341	К. Маркса	0103000020E61000000100000005000000B75D68AED3E6424000AB23473A9D4C40B75D68AED3E64240D8B79388F09F4C405A2DB0C744EE4240D8B79388F09F4C405A2DB0C744EE424000AB23473A9D4C40B75D68AED3E6424000AB23473A9D4C40
11920	24269	38.045081000000003	38.053362999999997	57.195644000000001	57.190094000000002	Школьная	0103000020E61000000100000005000000E355D636C50543403A950C0055984C40E355D636C50543404ED4D2DC0A994C4081E84999D40643404ED4D2DC0A994C4081E84999D40643403A950C0055984C40E355D636C50543403A950C0055984C40
11905	23606	37.754089	37.776618999999997	57.234411000000001	57.227020000000003	Молодежная	0103000020E61000000100000005000000FDA204FD85E04240DBC4C9FD0E9D4C40FDA204FD85E042404D69FD2D019E4C40E2395B4068E342404D69FD2D019E4C40E2395B4068E34240DBC4C9FD0E9D4C40FDA204FD85E04240DBC4C9FD0E9D4C40
11908	23776	37.941074	37.953595999999997	56.946618999999998	56.936248999999997	Центральная	0103000020E61000000100000005000000D68EE21C75F84240D3F4D901D7774C40D68EE21C75F84240D862B7CF2A794C4057CC086F0FFA4240D862B7CF2A794C4057CC086F0FFA4240D3F4D901D7774C40D68EE21C75F84240D3F4D901D7774C40
11904	23546	37.907746000000003	37.920636999999999	57.147306	57.139366000000003	Советская	0103000020E6100000010000000500000094895B0531F442405116BEBED6914C4094895B0531F4424096404AECDA924C40683EE76ED7F5424096404AECDA924C40683EE76ED7F542405116BEBED6914C4094895B0531F442405116BEBED6914C40
11916	24065	38.148046000000001	38.160290000000003	57.251835999999997	57.244649000000003	Цветочная	0103000020E61000000100000005000000DD26DC2BF3124340E3FF8EA8509F4C40DD26DC2BF31243404CFA7B293CA04C401CF0F961841443404CFA7B293CA04C401CF0F96184144340E3FF8EA8509F4C40DD26DC2BF3124340E3FF8EA8509F4C40
11919	24200	38.146419999999999	38.156660000000002	57.028609000000003	57.021960999999997	Центральная	0103000020E610000001000000050000007BBDFBE3BD124340CB64389ECF824C407BBDFBE3BD12434086AFAF75A9834C40B24B546F0D14434086AFAF75A9834C40B24B546F0D144340CB64389ECF824C407BBDFBE3BD124340CB64389ECF824C40
11903	23484	37.849490000000003	37.862434999999998	57.205117999999999	57.198107	Центральная	0103000020E61000000100000005000000B8239C16BCEC4240E90DF7915B994C40B8239C16BCEC424014E97E4E419A4C407FF6234564EE424014E97E4E419A4C407FF6234564EE4240E90DF7915B994C40B8239C16BCEC4240E90DF7915B994C40
11890	40971	36.032027999999997	36.060675000000003	56.768112000000002	56.749614000000001	3-я Мира	0103000020E610000001000000050000003447567E19044240D74FFF59F35F4C403447567E1904424024D5777E51624C40A857CA32C407424024D5777E51624C40A857CA32C4074240D74FFF59F35F4C403447567E19044240D74FFF59F35F4C40
11888	22681	35.949590000000001	36.006318	56.522257000000003	56.492840000000001	Кирова	0103000020E61000000100000005000000E84D452A8CF9414090149161153F4C40E84D452A8CF94140B58D3F51D9424C4025B03907CF004240B58D3F51D9424C4025B03907CF00424090149161153F4C40E84D452A8CF9414090149161153F4C40
11893	23260	35.553432000000001	35.571137999999998	56.631253000000001	56.620845000000003	проспект Калинина	0103000020E61000000100000005000000AA471ADCD6C641404C7155D9774F4C40AA471ADCD6C641403E40F7E5CC504C405DC0CB0C1BC941403E40F7E5CC504C405DC0CB0C1BC941404C7155D9774F4C40AA471ADCD6C641404C7155D9774F4C40
11882	22132	35.607726999999997	35.625774	56.920816000000002	56.910542	Центральная	0103000020E61000000100000005000000B6F292FFC9CD414035D1E7A38C744C40B6F292FFC9CD414018D1764CDD754C40F357C85C19D0414018D1764CDD754C40F357C85C19D0414035D1E7A38C744C40B6F292FFC9CD414035D1E7A38C744C40
11868	21525	35.759667999999998	35.763269999999999	56.725752999999997	56.723239999999997	Слободская	0103000020E61000000100000005000000ABE80FCD3CE141405B94D920935C4C40ABE80FCD3CE14140A8FC6B79E55C4C404B02D4D4B2E14140A8FC6B79E55C4C404B02D4D4B2E141405B94D920935C4C40ABE80FCD3CE141405B94D920935C4C40
11870	21606	36.540376000000002	36.564289000000002	56.870406000000003	56.850954000000002	Советская	0103000020E610000001000000050000008BC56F0A2B4542404033880FEC6C4C408BC56F0A2B454240001FBC76696F4C400C3F389F3A484240001FBC76696F4C400C3F389F3A4842404033880FEC6C4C408BC56F0A2B4542404033880FEC6C4C40
11861	21245	35.581397000000003	35.595410999999999	56.556522000000001	56.549700999999999	Беговая	0103000020E610000001000000050000000B7F86376BCA41400CCA349A5C464C400B7F86376BCA414094C0E61C3C474C40DE567A6D36CC414094C0E61C3C474C40DE567A6D36CC41400CCA349A5C464C400B7F86376BCA41400CCA349A5C464C40
11859	21186	35.693964999999999	35.718848000000001	56.669593999999996	56.657978999999997	Егорова	0103000020E61000000100000005000000C9C859D8D3D84140363AE7A738544C40C9C859D8D3D8414085CC9541B5554C40C365153603DC414085CC9541B5554C40C365153603DC4140363AE7A738544C40C9C859D8D3D84140363AE7A738544C40
11873	21809	35.746948000000003	35.765667999999998	56.970319000000003	56.966796000000002	Береговая	0103000020E6100000010000000500000004E8F7FD9BDF4140AAF3A8F8BF7B4C4004E8F7FD9BDF4140FED7B969337C4C40FFCBB56801E24140FED7B969337C4C40FFCBB56801E24140AAF3A8F8BF7B4C4004E8F7FD9BDF4140AAF3A8F8BF7B4C40
11892	23215	36.218266999999997	36.237651999999997	56.919100999999998	56.907784999999997	Привокзальная	0103000020E61000000100000005000000E4654D2CF01B42405166834C32744C40E4654D2CF01B4240465C001AA5754C401CEA77616B1E4240465C001AA5754C401CEA77616B1E42405166834C32744C40E4654D2CF01B42405166834C32744C40
11884	22374	35.823718	35.844298000000002	56.812117999999998	56.799748999999998	Школьная	0103000020E61000000100000005000000329067976FE941401D01DC2C5E664C40329067976FE94140183F8D7BF3674C40030AF5F411EC4140183F8D7BF3674C40030AF5F411EC41401D01DC2C5E664C40329067976FE941401D01DC2C5E664C40
11858	21156	35.479968	35.506045999999998	56.469352999999998	56.459293000000002	Молодежная	0103000020E61000000100000005000000329067976FBD41401024EF1CCA3A4C40329067976FBD4140C6A354C2133C4C40C422861DC6C04140C6A354C2133C4C40C422861DC6C041401024EF1CCA3A4C40329067976FBD41401024EF1CCA3A4C40
11883	22278	35.878838000000002	35.904125999999998	56.978138999999999	56.967973999999998	Центральная	0103000020E61000000100000005000000B43D7AC37DF041406CB07092E67B4C40B43D7AC37DF0414098F8A3A8337D4C404DBB9866BAF3414098F8A3A8337D4C404DBB9866BAF341406CB07092E67B4C40B43D7AC37DF041406CB07092E67B4C40
11857	21110	35.707709000000001	35.717779	56.507491999999999	56.493675000000003	Центральная	0103000020E61000000100000005000000DD0A613596DA414029ED0DBE303F4C40DD0A613596DA4140A67D737FF5404C40B760A92EE0DB4140A67D737FF5404C40B760A92EE0DB414029ED0DBE303F4C40DD0A613596DA414029ED0DBE303F4C40
11881	22051	35.444898000000002	35.519430999999997	56.938616000000003	56.917785000000002	Тверская	0103000020E610000001000000050000002507EC6AF2B8414033E197FA79754C402507EC6AF2B841404DC0AF9124784C40A8C30AB77CC241404DC0AF9124784C40A8C30AB77CC2414033E197FA79754C402507EC6AF2B8414033E197FA79754C40
11880	22051	35.444898000000002	35.519430999999997	56.938616000000003	56.917785000000002	Советская	0103000020E610000001000000050000002507EC6AF2B8414033E197FA79754C402507EC6AF2B841404DC0AF9124784C40A8C30AB77CC241404DC0AF9124784C40A8C30AB77CC2414033E197FA79754C402507EC6AF2B8414033E197FA79754C40
11879	22008	35.387954000000001	35.411903000000002	56.862268	56.842343999999997	Школьная	0103000020E610000001000000050000001B2D077AA8B14140ACFD9DEDD16B4C401B2D077AA8B1414094313ECC5E6E4C40E90FCD3CB9B4414094313ECC5E6E4C40E90FCD3CB9B44140ACFD9DEDD16B4C401B2D077AA8B14140ACFD9DEDD16B4C40
11871	21708	35.667122999999997	35.694710999999998	56.983559	56.972217999999998	Титова	0103000020E6100000010000000500000067B4554964D54140904AB1A3717C4C4067B4554964D54140DE57E542E57D4C40F295404AECD84140DE57E542E57D4C40F295404AECD84140904AB1A3717C4C4067B4554964D54140904AB1A3717C4C40
11874	21845	35.597028000000002	35.617905	56.722583	56.713405000000002	Зеленая	0103000020E61000000100000005000000ED65DB696BCC4140C5E6E3DA505B4C40ED65DB696BCC4140A2D288997D5C4C407784D38217CF4140A2D288997D5C4C407784D38217CF4140C5E6E3DA505B4C40ED65DB696BCC4140C5E6E3DA505B4C40
11877	21916	35.497098999999999	35.518487999999998	56.683118999999998	56.673060999999997	Зеленая	0103000020E61000000100000005000000E9EFA5F0A0BF4140459BE3DC26564C40E9EFA5F0A0BF41405B23827170574C4029AF95D05DC241405B23827170574C4029AF95D05DC24140459BE3DC26564C40E9EFA5F0A0BF4140459BE3DC26564C40
11869	21565	36.199860000000001	36.223252000000002	56.839725000000001	56.83126	Школьная	0103000020E61000000100000005000000A8E33103951942408A3C49BA666A4C40A8E33103951942401A51DA1B7C6B4C4020628385931C42401A51DA1B7C6B4C4020628385931C42408A3C49BA666A4C40A8E33103951942408A3C49BA666A4C40
11866	40970	35.740614000000001	35.755696999999998	56.861628000000003	56.855403000000003	Заводская	0103000020E61000000100000005000000D97A8670CCDE41403DF372D87D6D4C40D97A8670CCDE4140B1A888D3496E4C40B857E6ADBAE04140B1A888D3496E4C40B857E6ADBAE041403DF372D87D6D4C40D97A8670CCDE41403DF372D87D6D4C40
11891	23166	35.908366000000001	35.935082000000001	57.022283999999999	57.000332999999998	Парковая	0103000020E6100000010000000500000030664B5645F44140060E68E90A804C4030664B5645F44140AE9CBD33DA824C40058A58C4B0F74140AE9CBD33DA824C40058A58C4B0F74140060E68E90A804C4030664B5645F44140060E68E90A804C40
12016	21367	35.574444	35.599606000000001	56.832462	56.821522999999999	переулок Административный	0103000020E6100000010000000500000014B1886187C94140B6F468AA27694C4014B1886187C94140D594641D8E6A4C40213EB0E3BFCC4140D594641D8E6A4C40213EB0E3BFCC4140B6F468AA27694C4014B1886187C94140B6F468AA27694C40
11856	20913	35.874094999999997	35.905715999999998	56.684275999999997	56.675286999999997	Центральная	0103000020E610000001000000050000006E4C4F58E2EF4140FC34EECD6F564C406E4C4F58E2EF414006B8205B96574C4062BB7B80EEF3414006B8205B96574C4062BB7B80EEF34140FC34EECD6F564C406E4C4F58E2EF4140FC34EECD6F564C40
9739	19301	34.548074	34.606383999999998	56.183442999999997	56.159103000000002	Советская	0103000020E61000000100000005000000DAE4F0492746414006D9B27C5D144C40DAE4F049274641400ED76A0F7B174C40A968ACFD9D4D41400ED76A0F7B174C40A968ACFD9D4D414006D9B27C5D144C40DAE4F0492746414006D9B27C5D144C40
11848	19301	34.548074	34.606383999999998	56.183442999999997	56.159103000000002	Ржевская	0103000020E61000000100000005000000DAE4F0492746414006D9B27C5D144C40DAE4F049274641400ED76A0F7B174C40A968ACFD9D4D41400ED76A0F7B174C40A968ACFD9D4D414006D9B27C5D144C40DAE4F0492746414006D9B27C5D144C40
11849	19301	34.548074	34.606383999999998	56.183442999999997	56.159103000000002	Октябрьская	0103000020E61000000100000005000000DAE4F0492746414006D9B27C5D144C40DAE4F049274641400ED76A0F7B174C40A968ACFD9D4D41400ED76A0F7B174C40A968ACFD9D4D414006D9B27C5D144C40DAE4F0492746414006D9B27C5D144C40
11850	19301	34.548074	34.606383999999998	56.183442999999997	56.159103000000002	Декабристов	0103000020E61000000100000005000000DAE4F0492746414006D9B27C5D144C40DAE4F049274641400ED76A0F7B174C40A968ACFD9D4D41400ED76A0F7B174C40A968ACFD9D4D414006D9B27C5D144C40DAE4F0492746414006D9B27C5D144C40
11842	17809	31.643982000000001	31.695114	56.288321000000003	56.264676999999999	Кирова	0103000020E6100000010000000500000072361D01DCA43F406F8099EFE0214C4072361D01DCA43F4001E0D8B3E7244C40E3FDB8FDF2B13F4001E0D8B3E7244C40E3FDB8FDF2B13F406F8099EFE0214C4072361D01DCA43F406F8099EFE0214C40
11839	17512	32.048825999999998	32.118059000000002	56.277113	56.233364000000002	Школьная	0103000020E61000000100000005000000E5982CEE3F06404029081EDFDE1D4C40E5982CEE3F064040F225547078234C40CEFFAB8E1C0F4040F225547078234C40CEFFAB8E1C0F404029081EDFDE1D4C40E5982CEE3F06404029081EDFDE1D4C40
11837	17512	32.048825999999998	32.118059000000002	56.277113	56.233364000000002	Первомайская	0103000020E61000000100000005000000E5982CEE3F06404029081EDFDE1D4C40E5982CEE3F064040F225547078234C40CEFFAB8E1C0F4040F225547078234C40CEFFAB8E1C0F404029081EDFDE1D4C40E5982CEE3F06404029081EDFDE1D4C40
11836	17512	32.048825999999998	32.118059000000002	56.277113	56.233364000000002	Молодежная	0103000020E61000000100000005000000E5982CEE3F06404029081EDFDE1D4C40E5982CEE3F064040F225547078234C40CEFFAB8E1C0F4040F225547078234C40CEFFAB8E1C0F404029081EDFDE1D4C40E5982CEE3F06404029081EDFDE1D4C40
11840	17512	32.048825999999998	32.118059000000002	56.277113	56.233364000000002	Мира	0103000020E61000000100000005000000E5982CEE3F06404029081EDFDE1D4C40E5982CEE3F064040F225547078234C40CEFFAB8E1C0F4040F225547078234C40CEFFAB8E1C0F404029081EDFDE1D4C40E5982CEE3F06404029081EDFDE1D4C40
11841	17512	32.048825999999998	32.118059000000002	56.277113	56.233364000000002	Льнозаводская	0103000020E61000000100000005000000E5982CEE3F06404029081EDFDE1D4C40E5982CEE3F064040F225547078234C40CEFFAB8E1C0F4040F225547078234C40CEFFAB8E1C0F404029081EDFDE1D4C40E5982CEE3F06404029081EDFDE1D4C40
11838	17512	32.048825999999998	32.118059000000002	56.277113	56.233364000000002	Кирова	0103000020E61000000100000005000000E5982CEE3F06404029081EDFDE1D4C40E5982CEE3F064040F225547078234C40CEFFAB8E1C0F4040F225547078234C40CEFFAB8E1C0F404029081EDFDE1D4C40E5982CEE3F06404029081EDFDE1D4C40
11834	16918	32.261862000000001	32.299850999999997	55.817678999999998	55.808548000000002	Октябрьская	0103000020E610000001000000050000005708ABB184214040849F38807EE74B405708ABB18421404020D099B4A9E84B4021567F846126404020D099B4A9E84B4021567F8461264040849F38807EE74B405708ABB184214040849F38807EE74B40
11833	16749	32.223108000000003	32.314250999999999	55.866596000000001	55.833798999999999	Советская	0103000020E61000000100000005000000EDBC8DCD8E1C40400038F6ECB9EA4B40EDBC8DCD8E1C4040166C239EECEE4B401EDE736039284040166C239EECEE4B401EDE7360392840400038F6ECB9EA4B40EDBC8DCD8E1C40400038F6ECB9EA4B40
11802	15048	34.715727000000001	34.785165999999997	57.573112999999999	57.552900000000001	Рабочая	0103000020E610000001000000050000009EEE3CF19C5B4140ADFA5C6DC5C64C409EEE3CF19C5B4140CBF44BC45BC94C402FF7C95180644140CBF44BC45BC94C402FF7C95180644140ADFA5C6DC5C64C409EEE3CF19C5B4140ADFA5C6DC5C64C40
11801	14891	34.606976000000003	34.628698	57.637915999999997	57.621214000000002	Бежецкая	0103000020E610000001000000050000007CBABA63B14D41409FE8BAF083CF4C407CBABA63B14D41402DCC423BA7D14C40C287122D795041402DCC423BA7D14C40C287122D795041409FE8BAF083CF4C407CBABA63B14D41409FE8BAF083CF4C40
11800	14773	34.427134000000002	34.467351000000001	57.674419999999998	57.660417000000002	Центральная	0103000020E610000001000000050000003D81B053AC364140795C548B88D44C403D81B053AC36414058E2016553D64C405F605628D23B414058E2016553D64C405F605628D23B4140795C548B88D44C403D81B053AC364140795C548B88D44C40
11799	14688	34.482075000000002	34.499529000000003	57.747328000000003	57.730969999999999	Центральная	0103000020E610000001000000050000000F9C33A2B43D4140B62DCA6C90DD4C400F9C33A2B43D41404BB1A371A8DF4C40A933F790F03F41404BB1A371A8DF4C40A933F790F03F4140B62DCA6C90DD4C400F9C33A2B43D4140B62DCA6C90DD4C40
11788	13910	34.945075000000003	34.961829000000002	57.643416999999999	57.634422999999998	Почтовая	0103000020E6100000010000000500000034A2B437F8784140446ADAC534D14C4034A2B437F87841406058FE7C5BD24C4015AC71361D7B41406058FE7C5BD24C4015AC71361D7B4140446ADAC534D14C4034A2B437F8784140446ADAC534D14C40
11803	15065	34.790385999999998	34.821018000000002	57.550693000000003	57.53396	Карла Маркса	0103000020E61000000100000005000000AE9B525E2B654140A3AF20CD58C44C40AE9B525E2B6541406D91B41B7DC64C40B3B6291E176941406D91B41B7DC64C40B3B6291E17694140A3AF20CD58C44C40AE9B525E2B654140A3AF20CD58C44C40
11798	14595	34.998804	35.018754999999999	57.730932000000003	57.709378000000001	Заводская	0103000020E61000000100000005000000978E39CFD87F41403E40F7E5CCDA4C40978E39CFD87F4140C9CC052E8FDD4C4078D1579066824140C9CC052E8FDD4C4078D15790668241403E40F7E5CCDA4C40978E39CFD87F41403E40F7E5CCDA4C40
11796	14480	34.120530000000002	34.149850999999998	57.409742999999999	57.398125	Солнечная	0103000020E61000000100000005000000EC17EC866D0F4140295C8FC2F5B24C40EC17EC866D0F4140E961687572B44C40EE224C512E134140E961687572B44C40EE224C512E134140295C8FC2F5B24C40EC17EC866D0F4140295C8FC2F5B24C40
11806	15242	34.385398000000002	34.444614999999999	57.634003999999997	57.607239	Кирова	0103000020E61000000100000005000000CFF8BEB85431414089EDEE01BACD4C40CFF8BEB8543141403FC4060B27D14C40D027F224E93841403FC4060B27D14C40D027F224E938414089EDEE01BACD4C40CFF8BEB85431414089EDEE01BACD4C40
11807	15242	34.385398000000002	34.444614999999999	57.634003999999997	57.607239	Боровая	0103000020E61000000100000005000000CFF8BEB85431414089EDEE01BACD4C40CFF8BEB8543141403FC4060B27D14C40D027F224E93841403FC4060B27D14C40D027F224E938414089EDEE01BACD4C40CFF8BEB85431414089EDEE01BACD4C40
11805	15242	34.385398000000002	34.444614999999999	57.634003999999997	57.607239	1 Мая	0103000020E61000000100000005000000CFF8BEB85431414089EDEE01BACD4C40CFF8BEB8543141403FC4060B27D14C40D027F224E93841403FC4060B27D14C40D027F224E938414089EDEE01BACD4C40CFF8BEB85431414089EDEE01BACD4C40
11797	14499	34.060665999999998	34.087561999999998	57.474837000000001	57.458737999999997	Школьная 	0103000020E6100000010000000500000054FD4AE7C30741405AB741EDB7BA4C4054FD4AE7C307414023F77475C7BC4C40A92F4B3B350B414023F77475C7BC4C40A92F4B3B350B41405AB741EDB7BA4C4054FD4AE7C30741405AB741EDB7BA4C40
11792	14102	34.544535000000003	34.576236000000002	57.511718999999999	57.501493000000004	Микробиологов	0103000020E610000001000000050000008143A852B3454140231631EC30C04C408143A852B3454140F4DE180280C14C409163EB19C2494140F4DE180280C14C409163EB19C2494140231631EC30C04C408143A852B3454140231631EC30C04C40
11790	14009	34.190077000000002	34.241819999999997	57.285679999999999	57.272052000000002	Первомайская	0103000020E61000000100000005000000645C717154184140DC679599D2A24C40645C717154184140868F882991A44C4065C22FF5F31E4140868F882991A44C4065C22FF5F31E4140DC679599D2A24C40645C717154184140DC679599D2A24C40
11789	13932	34.768188000000002	34.796719000000003	57.712007999999997	57.703214000000003	Школьная	0103000020E61000000100000005000000FF9600FC53624140700B96EA02DA4C40FF9600FC53624140C43E011423DB4C40098D60E3FA654140C43E011423DB4C40098D60E3FA654140700B96EA02DA4C40FF9600FC53624140700B96EA02DA4C40
11795	14405	34.391191999999997	34.417808999999998	57.650863999999999	57.639029000000001	Некрасовский переулок	0103000020E61000000100000005000000793A5794123241400919C8B3CBD14C40793A5794123241406612F5824FD34C40BB7CEBC37A3541406612F5824FD34C40BB7CEBC37A3541400919C8B3CBD14C40793A5794123241400919C8B3CBD14C40
11785	13829	34.631886999999999	34.646223999999997	57.582774000000001	57.573244000000003	Центральная	0103000020E610000001000000050000003FE257ACE15041406A50340F60C94C403FE257ACE1504140C47AA35698CA4C40F5F1D077B7524140C47AA35698CA4C40F5F1D077B75241406A50340F60C94C403FE257ACE15041406A50340F60C94C40
11791	14028	34.412761000000003	34.433799	57.365371000000003	57.354778000000003	Советская	0103000020E610000001000000050000003A083A5AD53441408FAB915D69AD4C403A083A5AD534414013F4177AC4AE4C40CD04C3B98637414013F4177AC4AE4C40CD04C3B9863741408FAB915D69AD4C403A083A5AD53441408FAB915D69AD4C40
11783	13727	34.145386000000002	34.169856000000003	57.667031999999999	57.656179999999999	Октябрьская	0103000020E61000000100000005000000ECA529029C1241400725CCB4FDD34C40ECA529029C12414057B1F84D61D54C40C38366D7BD15414057B1F84D61D54C40C38366D7BD1541400725CCB4FDD34C40ECA529029C1241400725CCB4FDD34C40
11794	14391	34.234211999999999	34.250678000000001	57.751016999999997	57.741515999999997	Фабричная	0103000020E61000000100000005000000562AA8A8FA1D4140F9BA0CFFE9DE4C40562AA8A8FA1D4140B9DE365321E04C40D1E9793716204140B9DE365321E04C40D1E9793716204140F9BA0CFFE9DE4C40562AA8A8FA1D4140F9BA0CFFE9DE4C40
11784	13812	34.665501999999996	34.698900999999999	57.556849999999997	57.539172999999998	Советская	0103000020E6100000010000000500000017B6662B2F5541406FF1F09E03C54C4017B6662B2F55414088635DDC46C74C40231285967559414088635DDC46C74C4023128596755941406FF1F09E03C54C4017B6662B2F5541406FF1F09E03C54C40
11804	15164	34.710813000000002	34.740475000000004	57.476497000000002	57.465389999999999	Мира	0103000020E610000001000000050000002C499EEBFB5A414056F146E691BB4C402C499EEBFB5A414031D28BDAFDBC4C40B84082E2C75E414031D28BDAFDBC4C40B84082E2C75E414056F146E691BB4C402C499EEBFB5A414056F146E691BB4C40
11793	14310	34.307299	34.335137000000003	57.718305999999998	57.705545999999998	Октябрьская	0103000020E61000000100000005000000F88BD992552741406CE9D1544FDA4C40F88BD99255274140A2427573F1DB4C40FC56EBC4E52A4140A2427573F1DB4C40FC56EBC4E52A41406CE9D1544FDA4C40F88BD992552741406CE9D1544FDA4C40
11779	12795	37.235348000000002	37.283254999999997	58.682729999999999	58.634608999999998	Южная	0103000020E61000000100000005000000EA961DE21F9E4240A65F22DE3A514D40EA961DE21F9E4240C1FF56B263574D40D8B628B341A44240C1FF56B263574D40D8B628B341A44240A65F22DE3A514D40EA961DE21F9E4240A65F22DE3A514D40
11777	12795	37.235348000000002	37.283254999999997	58.682729999999999	58.634608999999998	Тихонова	0103000020E61000000100000005000000EA961DE21F9E4240A65F22DE3A514D40EA961DE21F9E4240C1FF56B263574D40D8B628B341A44240C1FF56B263574D40D8B628B341A44240A65F22DE3A514D40EA961DE21F9E4240A65F22DE3A514D40
11778	12795	37.235348000000002	37.283254999999997	58.682729999999999	58.634608999999998	Панфилова	0103000020E61000000100000005000000EA961DE21F9E4240A65F22DE3A514D40EA961DE21F9E4240C1FF56B263574D40D8B628B341A44240C1FF56B263574D40D8B628B341A44240A65F22DE3A514D40EA961DE21F9E4240A65F22DE3A514D40
11192	40537	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	м/р-н Заозерный	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11773	12442	34.056255	34.142187999999997	57.732219000000001	57.711070999999997	Центральная	0103000020E61000000100000005000000459E245D330741402711E15F04DB4C40459E245D330741404241295AB9DD4C401BF16437331241404241295AB9DD4C401BF16437331241402711E15F04DB4C40459E245D330741402711E15F04DB4C40
11770	12335	34.241909999999997	34.267933999999997	57.998829000000001	57.992722999999998	Центральная	0103000020E61000000100000005000000A54929E8F61E4140567E198C11FF4C40A54929E8F61E4140F0A5F0A0D9FF4C4044BE4BA94B224140F0A5F0A0D9FF4C4044BE4BA94B224140567E198C11FF4C40A54929E8F61E4140567E198C11FF4C40
11771	12335	34.241909999999997	34.267933999999997	57.998829000000001	57.992722999999998	Озерная	0103000020E61000000100000005000000A54929E8F61E4140567E198C11FF4C40A54929E8F61E4140F0A5F0A0D9FF4C4044BE4BA94B224140F0A5F0A0D9FF4C4044BE4BA94B224140567E198C11FF4C40A54929E8F61E4140567E198C11FF4C40
11763	11832	33.759101999999999	33.771382000000003	58.116222999999998	58.112195999999997	Первомайская	0103000020E61000000100000005000000022A1C412AE14040FA5E43705C0E4D40022A1C412AE1404081053065E00E4D408E5C37A5BCE2404081053065E00E4D408E5C37A5BCE24040FA5E43705C0E4D40022A1C412AE14040FA5E43705C0E4D40
11767	12071	33.944819000000003	33.995950999999998	57.733421	57.718806000000001	Советская	0103000020E61000000100000005000000D9D138D4EFF840409415C3D501DC4C40D9D138D4EFF840408D9944BDE0DD4C4091B586527BFF40408D9944BDE0DD4C4091B586527BFF40409415C3D501DC4C40D9D138D4EFF840409415C3D501DC4C40
11774	12071	33.944819000000003	33.995950999999998	57.733421	57.718806000000001	Полевая	0103000020E61000000100000005000000D9D138D4EFF840409415C3D501DC4C40D9D138D4EFF840408D9944BDE0DD4C4091B586527BFF40408D9944BDE0DD4C4091B586527BFF40409415C3D501DC4C40D9D138D4EFF840409415C3D501DC4C40
11764	11860	33.762354000000002	33.79419	58.049816	58.032542999999997	Советская	0103000020E61000000100000005000000C6FCDCD094E140405B5B785E2A044D40C6FCDCD094E14040A568E55E60064D40B6679604A8E54040A568E55E60064D40B6679604A8E540405B5B785E2A044D40C6FCDCD094E140405B5B785E2A044D40
10819	26375	34.235649000000002	34.257361000000003	58.077353000000002	58.069262000000002	Центральная	0103000020E61000000100000005000000E52A16BF291E4140836DC493DD084D40E52A16BF291E4140AE9FFEB3E6094D4008228B34F1204140AE9FFEB3E6094D4008228B34F1204140836DC493DD084D40E52A16BF291E4140836DC493DD084D40
11772	12439	34.292943000000001	34.311762999999999	57.943798999999999	57.926563999999999	Ленина	0103000020E61000000100000005000000CB4BFE277F25414052D32EA699F64C40CB4BFE277F254140AE7FD767CEF84C402A8D98D9E7274140AE7FD767CEF84C402A8D98D9E727414052D32EA699F64C40CB4BFE277F25414052D32EA699F64C40
11766	12033	33.711931	33.731226999999997	57.817289000000002	57.802861999999998	Зеленая	0103000020E610000001000000050000001901158E20DB4040BF99982EC4E64C401901158E20DB4040B6300BED9CE84C40E179A9D898DD4040B6300BED9CE84C40E179A9D898DD4040BF99982EC4E64C401901158E20DB4040BF99982EC4E64C40
11775	12548	34.027859999999997	34.039538	58.100783999999997	58.093150000000001	Лесная	0103000020E61000000100000005000000EB6E9EEA90034140ABCFD556EC0B4D40EB6E9EEA90034140E3FA777DE60C4D408179C8940F054140E3FA777DE60C4D408179C8940F054140ABCFD556EC0B4D40EB6E9EEA90034140ABCFD556EC0B4D40
11762	11775	33.866458999999999	33.900289999999998	57.909880999999999	57.900379000000001	Новая	0103000020E610000001000000050000009529E620E8EE4040AA807B9E3FF34C409529E620E8EE40403A2009FB76F44C403A75E5B33CF340403A2009FB76F44C403A75E5B33CF34040AA807B9E3FF34C409529E620E8EE4040AA807B9E3FF34C40
11765	11962	33.679223	33.712533000000001	57.885727000000003	57.861125999999999	Октябрьская	0103000020E6100000010000000500000073D87DC7F0D640401EDE736039EE4C4073D87DC7F0D64040941799805FF14C400F29064834DB4040941799805FF14C400F29064834DB40401EDE736039EE4C4073D87DC7F0D640401EDE736039EE4C40
18158	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Школьный переулок	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11758	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Студенческая	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
12256	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Олега Кошевого	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11759	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Народная	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11757	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Мира	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11776	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Линейная	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11753	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Кирова	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
10049	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Заозерный м/р-н	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11754	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Заводской микрорайон	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11755	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Дзержинского	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
10365	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Главная	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11756	4965	33.939950000000003	34.193401000000001	57.919266	57.822887999999999	Гагарина	0103000020E6100000010000000500000007F0164850F84040AB22DC6454E94C4007F0164850F8404091291F82AAF54C40C1012D5DC118414091291F82AAF54C40C1012D5DC1184140AB22DC6454E94C4007F0164850F84040AB22DC6454E94C40
11768	12246	34.468347999999999	34.484158999999998	58.104579000000001	58.095419	Новая	0103000020E61000000100000005000000D192C7D3F23B4140613596B0360C4D40D192C7D3F23B4140986C3CD8620D4D4033880FECF83D4140986C3CD8620D4D4033880FECF83D4140613596B0360C4D40D192C7D3F23B4140613596B0360C4D40
11760	11676	33.881928000000002	33.924166999999997	57.997675000000001	57.972205000000002	Победы	0103000020E610000001000000050000009EB64604E3F04040FC00A43671FC4C409EB64604E3F04040B6847CD0B3FF4C406E85B01A4BF64040B6847CD0B3FF4C406E85B01A4BF64040FC00A43671FC4C409EB64604E3F04040FC00A43671FC4C40
11761	11676	33.881928000000002	33.924166999999997	57.997675000000001	57.972205000000002	Крестьянская	0103000020E610000001000000050000009EB64604E3F04040FC00A43671FC4C409EB64604E3F04040B6847CD0B3FF4C406E85B01A4BF64040B6847CD0B3FF4C406E85B01A4BF64040FC00A43671FC4C409EB64604E3F04040FC00A43671FC4C40
11750	11112	33.042102	33.058038000000003	55.819934000000003	55.814208999999998	Центральная	0103000020E61000000100000005000000508C2C9963854040EF8D210038E84B40508C2C99638540407270E998F3E84B406FF607CA6D8740407270E998F3E84B406FF607CA6D874040EF8D210038E84B40508C2C9963854040EF8D210038E84B40
18775	49954	32.570613000000002	32.598263000000003	55.756067000000002	55.747252000000003	Школьная	0103000020E6100000010000000500000013D6C6D80949404070EF1AF4A5DF4B4013D6C6D809494040DC4AAFCDC6E04B4014B4C9E1934C4040DC4AAFCDC6E04B4014B4C9E1934C404070EF1AF4A5DF4B4013D6C6D80949404070EF1AF4A5DF4B40
11752	11192	33.020228000000003	33.037205999999998	55.941510999999998	55.929268	Зеленая	0103000020E61000000100000005000000543BC3D496824040139CFA40F2F64B40543BC3D49682404081E9B46E83F84B40849B8C2AC384404081E9B46E83F84B40849B8C2AC3844040139CFA40F2F64B40543BC3D496824040139CFA40F2F64B40
11749	11085	33.166052000000001	33.195067000000002	55.722259000000001	55.707937999999999	Советская	0103000020E61000000100000005000000BBB72231419540403ECC5EB69DDA4B40BBB7223141954040EF1EA0FB72DC4B40B1C398F4F7984040EF1EA0FB72DC4B40B1C398F4F79840403ECC5EB69DDA4B40BBB72231419540403ECC5EB69DDA4B40
11748	11023	33.082455000000003	33.135939999999998	55.802132999999998	55.773864000000003	Центральная	0103000020E610000001000000050000002332ACE28D8A4040A0C6BDF90DE34B402332ACE28D8A40406C054D4BACE64B40EF1B5F7B669140406C054D4BACE64B40EF1B5F7B66914040A0C6BDF90DE34B402332ACE28D8A4040A0C6BDF90DE34B40
11746	10904	32.753483000000003	32.784708000000002	55.724159999999998	55.711635000000001	Центральная	0103000020E61000000100000005000000C68B85217260404030D80DDB16DB4B40C68B85217260404022895E46B1DC4B406D74CE4F7164404022895E46B1DC4B406D74CE4F7164404030D80DDB16DB4B40C68B85217260404030D80DDB16DB4B40
11745	10839	33.252299000000001	33.277560000000001	55.875349	55.862388000000003	Зеленая	0103000020E6100000010000000500000021E868554BA040403F3BE0BA62EE4B4021E868554BA040400CCB9F6F0BF04B40C156091687A340400CCB9F6F0BF04B40C156091687A340403F3BE0BA62EE4B4021E868554BA040403F3BE0BA62EE4B40
11744	10809	33.376455	33.410671999999998	55.921661999999998	55.907819000000003	Центральная	0103000020E6100000010000000500000035B56CAD2FB04040FED7B96933F44B4035B56CAD2FB04040A4FB3905F9F54B4003B16CE690B44040A4FB3905F9F54B4003B16CE690B44040FED7B96933F44B4035B56CAD2FB04040FED7B96933F44B40
11747	11012	32.874917000000003	32.910848999999999	55.807223	55.790641000000001	Школьная	0103000020E6100000010000000500000073DBBE47FD6F404039F06AB933E54B4073DBBE47FD6F40401DCA501553E74B40124C35B3967440401DCA501553E74B40124C35B39674404039F06AB933E54B4073DBBE47FD6F404039F06AB933E54B40
11742	10727	32.908433000000002	32.971252	55.863079999999997	55.815483	Ленина	0103000020E61000000100000005000000B8CD548847744040D4B837BF61E84B40B8CD54884774404074EACA6779EE4B4059164CFC517C404074EACA6779EE4B4059164CFC517C4040D4B837BF61E84B40B8CD548847744040D4B837BF61E84B40
11743	10727	32.908433000000002	32.971252	55.863079999999997	55.815483	Кирова	0103000020E61000000100000005000000B8CD548847744040D4B837BF61E84B40B8CD54884774404074EACA6779EE4B4059164CFC517C404074EACA6779EE4B4059164CFC517C4040D4B837BF61E84B40B8CD548847744040D4B837BF61E84B40
11751	10727	32.908433000000002	32.971252	55.863079999999997	55.815483	1 Мая	0103000020E61000000100000005000000B8CD548847744040D4B837BF61E84B40B8CD54884774404074EACA6779EE4B4059164CFC517C404074EACA6779EE4B4059164CFC517C4040D4B837BF61E84B40B8CD548847744040D4B837BF61E84B40
11738	10269	36.411054	36.422310000000003	57.539037999999998	57.531143999999998	Центральная	0103000020E61000000100000005000000EB71DF6A9D344240BABBCE86FCC34C40EB71DF6A9D3442408FA67A32FFC44C400B630B410E3642408FA67A32FFC44C400B630B410E364240BABBCE86FCC34C40EB71DF6A9D344240BABBCE86FCC34C40
11740	40948	36.512383999999997	36.537931999999998	57.799720999999998	57.790376999999999	Большая	0103000020E61000000100000005000000307F85CC954142405B41D3122BE54C40307F85CC954142405376FA415DE64C4066BCADF4DA4442405376FA415DE64C4066BCADF4DA4442405B41D3122BE54C40307F85CC954142405B41D3122BE54C40
11734	10100	36.426658000000003	36.446753000000001	57.674584000000003	57.66722	Косарева	0103000020E61000000100000005000000D449B6BA9C3642405A9E077767D54C40D449B6BA9C364240D333BDC458D64C40E831CA332F394240D333BDC458D64C40E831CA332F3942405A9E077767D54C40D449B6BA9C3642405A9E077767D54C40
11741	10626	36.537303000000001	36.552135	57.893591999999998	57.884616999999999	Молодежная	0103000020E6100000010000000500000077853E58C6444240293E3E213BF14C4077853E58C6444240CEFBFF3861F24C400DFD135CAC464240CEFBFF3861F24C400DFD135CAC464240293E3E213BF14C4077853E58C6444240293E3E213BF14C40
11159	13257	36.861227	36.892856999999999	57.806176000000001	57.798267000000003	Центральная	0103000020E6100000010000000500000052B7B3AF3C6E4240EF3CF19C2DE64C4052B7B3AF3C6E4240F96871C630E74C4099805F2349724240F96871C630E74C4099805F2349724240EF3CF19C2DE64C4052B7B3AF3C6E4240EF3CF19C2DE64C40
11737	10379	36.835993000000002	36.867407	57.618067000000003	57.608916000000001	Челябинская	0103000020E61000000100000005000000AC5791D1016B42406D01A1F5F0CD4C40AC5791D1016B424051DEC7D11CCF4C4026A94C31076F424051DEC7D11CCF4C4026A94C31076F42406D01A1F5F0CD4C40AC5791D1016B42406D01A1F5F0CD4C40
11735	10213	36.285020000000003	36.318375000000003	57.561976999999999	57.542782000000003	Восточная	0103000020E610000001000000050000005C5A0D897B244240C26D6DE179C54C405C5A0D897B244240560DC2DCEEC74C40986E1283C0284240560DC2DCEEC74C40986E1283C0284240C26D6DE179C54C405C5A0D897B244240C26D6DE179C54C40
11733	10088	36.496960000000001	36.521295000000002	57.726126000000001	57.711590000000001	Молодежная	0103000020E61000000100000005000000C8B5A1629C3F42409014916115DB4C40C8B5A1629C3F42403D635FB2F1DC4C40BF4868CBB94242403D635FB2F1DC4C40BF4868CBB94242409014916115DB4C40C8B5A1629C3F42409014916115DB4C40
11723	9316	36.708477000000002	36.722921999999997	57.740487999999999	57.731138000000001	Солнечная	0103000020E61000000100000005000000EE7BD45FAF5A4240726E13EE95DD4C40EE7BD45FAF5A42404C8A8F4FC8DE4C408AC745B5885C42404C8A8F4FC8DE4C408AC745B5885C4240726E13EE95DD4C40EE7BD45FAF5A4240726E13EE95DD4C40
11254	17944	36.506922000000003	36.530583999999998	57.467272999999999	57.455606000000003	Школьная	0103000020E61000000100000005000000BCCFF1D1E240424042EE224C51BA4C40BCCFF1D1E2404240E3A6069ACFBB4C40F3E32F2DEA434240E3A6069ACFBB4C40F3E32F2DEA43424042EE224C51BA4C40BCCFF1D1E240424042EE224C51BA4C40
11027	5476	36.751838999999997	36.771701	57.797845000000002	57.788322999999998	Центральная	0103000020E61000000100000005000000BD6DA6423C604240A1D79FC4E7E44C40BD6DA6423C6042407923F3C81FE64C402FA52E19C76242407923F3C81FE64C402FA52E19C7624240A1D79FC4E7E44C40BD6DA6423C604240A1D79FC4E7E44C40
11019	3717	36.691625000000002	36.701335999999998	57.6554	57.646600999999997	Центральная	0103000020E610000001000000050000004A0C022B87584240CB4752D2C3D24C404A0C022B8758424032E6AE25E4D34C40F4C0C760C559424032E6AE25E4D34C40F4C0C760C5594240CB4752D2C3D24C404A0C022B87584240CB4752D2C3D24C40
11713	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	Парковая	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
17923	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	Октябрьская	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
18234	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	Новгородская	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
18237	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	Кленовая	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
18117	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	Авиаторов	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
11716	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	8 Марта	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
11715	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	50 лет Октября	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
11714	8508	32.245961000000001	32.294479000000003	56.672986999999999	56.621558	1-ый Измайловский переулок	0103000020E61000000100000005000000B58B69A67B1F4040994869368F4F4C40B58B69A67B1F40400BD1217024564C40ED2DE57CB12540400BD1217024564C40ED2DE57CB1254040994869368F4F4C40B58B69A67B1F4040994869368F4F4C40
25695	127	41.449596999999997	41.451096999999997	52.743957999999999	52.742966000000003	площадь Комсомольская	0103000020E610000001000000050000009AB0FD648CB944401D058882195F4A409AB0FD648CB944407DCC07043A5F4A406F29E78BBDB944407DCC07043A5F4A406F29E78BBDB944401D058882195F4A409AB0FD648CB944401D058882195F4A40
25699	127	41.327336000000003	41.52881	52.788285000000002	52.670479	пл.Л.Толстого	0103000020E61000000100000005000000D8666325E6A94440D0D38041D2554A40D8666325E6A94440B476DB85E6644A401DE6CB0BB0C34440B476DB85E6644A401DE6CB0BB0C34440D0D38041D2554A40D8666325E6A94440D0D38041D2554A40
26040	127	41.508175999999999	41.512551000000002	52.715535000000003	52.703805000000003	им. маршала Малиновского	0103000020E61000000100000005000000594E42E90BC1444072E14048165A4A40594E42E90BC144405A12A0A6965B4A401C446B459BC144405A12A0A6965B4A401C446B459BC1444072E14048165A4A40594E42E90BC1444072E14048165A4A40
25471	127	41.417096000000001	41.447054000000001	52.758195999999998	52.749839999999999	бульвар Энтузиастов	0103000020E610000001000000050000006EA5D76663B54440C79DD2C1FA5F4A406EA5D76663B54440A0FA07910C614A40E3C5C21039B94440A0FA07910C614A40E3C5C21039B94440C79DD2C1FA5F4A406EA5D76663B54440C79DD2C1FA5F4A40
25992	127	41.450449999999996	41.476374999999997	52.694850000000002	52.692594999999997	Южная	0103000020E61000000100000005000000D93D7958A8B94440C22FF5F3A6584A40D93D7958A8B9444014D044D8F0584A40E5D022DBF9BC444014D044D8F0584A40E5D022DBF9BC4440C22FF5F3A6584A40D93D7958A8B94440C22FF5F3A6584A40
26261	127	41.415461000000001	41.436912999999997	52.745043000000003	52.735098999999998	Широкая	0103000020E61000000100000005000000B9E177D32DB5444041295AB9175E4A40B9E177D32DB544408F8EAB915D5F4A403F19E3C3ECB744408F8EAB915D5F4A403F19E3C3ECB7444041295AB9175E4A40B9E177D32DB5444041295AB9175E4A40
25692	127	41.441628999999999	41.469242999999999	52.745381000000002	52.736178000000002	Чичканова	0103000020E610000001000000050000008BFB8F4C87B844407104A9143B5E4A408BFB8F4C87B84440A70705A5685F4A403F70952710BC4440A70705A5685F4A403F70952710BC44407104A9143B5E4A408BFB8F4C87B844407104A9143B5E4A40
25588	127	41.396667999999998	41.411149000000002	52.771884	52.765078000000003	Чичерина	0103000020E6100000010000000500000053AF5B04C6B24440CE716E13EE614A4053AF5B04C6B2444020274C18CD624A403D64CA87A0B4444020274C18CD624A403D64CA87A0B44440CE716E13EE614A4053AF5B04C6B24440CE716E13EE614A40
25714	127	41.327336000000003	41.52881	52.788285000000002	52.670479	Цветочная/М.Н.Мордасовой	0103000020E61000000100000005000000D8666325E6A94440D0D38041D2554A40D8666325E6A94440B476DB85E6644A401DE6CB0BB0C34440B476DB85E6644A401DE6CB0BB0C34440D0D38041D2554A40D8666325E6A94440D0D38041D2554A40
26320	127	41.449793999999997	41.472279	52.710816000000001	52.700842000000002	Фридриха Энгельса	0103000020E61000000100000005000000F0F78BD992B94440E5D4CE30B5594A40F0F78BD992B944409DBCC804FC5A4A4036CB65A373BC44409DBCC804FC5A4A4036CB65A373BC4440E5D4CE30B5594A40F0F78BD992B94440E5D4CE30B5594A40
26170	127	41.408059000000002	41.408983999999997	52.710597999999997	52.709418999999997	Ударная	0103000020E6100000010000000500000053EBFD463BB444409C14E63DCE5A4A4053EBFD463BB444402F4D11E0F45A4A402B4B749659B444402F4D11E0F45A4A402B4B749659B444409C14E63DCE5A4A4053EBFD463BB444409C14E63DCE5A4A40
26321	127	41.43526	41.460628	52.730583000000003	52.728003999999999	Студенецкая набережная	0103000020E61000000100000005000000E4A08499B6B74440B8AD2D3C2F5D4A40E4A08499B6B74440BD0166BE835D4A409ACFB9DBF5BA4440BD0166BE835D4A409ACFB9DBF5BA4440B8AD2D3C2F5D4A40E4A08499B6B74440B8AD2D3C2F5D4A40
25907	127	41.454807000000002	41.462254000000001	52.728653000000001	52.727589000000002	Степана Разина	0103000020E61000000100000005000000F67EA31D37BA4440F5F6E7A2215D4A40F67EA31D37BA4440EF906280445D4A40FC389A232BBB4440EF906280445D4A40FC389A232BBB4440F5F6E7A2215D4A40F67EA31D37BA4440F5F6E7A2215D4A40
25578	127	41.412927000000003	41.427247000000001	52.765852000000002	52.754418999999999	Социалистическая	0103000020E610000001000000050000005551BCCADAB44440923D42CD90604A405551BCCADAB44440C1C9367007624A4035289A07B0B64440C1C9367007624A4035289A07B0B64440923D42CD90604A405551BCCADAB44440923D42CD90604A40
75036	127	41.405543000000002	41.407393999999996	52.714548000000001	52.711978000000002	Солнечная	0103000020E61000000100000005000000950F41D5E8B344405ABC5818225B4A40950F41D5E8B344400BB6114F765B4A40164B917C25B444400BB6114F765B4A40164B917C25B444405ABC5818225B4A40950F41D5E8B344405ABC5818225B4A40
25483	127	41.443066000000002	41.476635999999999	52.763558000000003	52.761426999999998	Совхозная	0103000020E610000001000000050000001AFCFD62B6B844404CA59F7076614A401AFCFD62B6B84440B24CBF44BC614A40520C906802BD4440B24CBF44BC614A40520C906802BD44404CA59F7076614A401AFCFD62B6B844404CA59F7076614A40
26028	127	41.431415000000001	41.472476999999998	52.766058999999998	52.701022000000002	Советская	0103000020E610000001000000050000007E00529B38B7444065E3C116BB594A407E00529B38B744403AE7A7380E624A405C8E57207ABC44403AE7A7380E624A405C8E57207ABC444065E3C116BB594A407E00529B38B7444065E3C116BB594A40
25504	127	41.431415000000001	41.472476999999998	52.766058999999998	52.701022000000002	Советская	0103000020E610000001000000050000007E00529B38B7444065E3C116BB594A407E00529B38B744403AE7A7380E624A405C8E57207ABC44403AE7A7380E624A405C8E57207ABC444065E3C116BB594A407E00529B38B7444065E3C116BB594A40
26042	127	41.416744999999999	41.421722000000003	52.707411999999998	52.704290999999998	Серпуховская	0103000020E61000000100000005000000C1E270E657B54440FEEE1D35265A4A40C1E270E657B544402366F6798C5A4A407A008BFCFAB544402366F6798C5A4A407A008BFCFAB54440FEEE1D35265A4A40C1E270E657B54440FEEE1D35265A4A40
25991	127	41.464894999999999	41.473320999999999	52.691116000000001	52.690362999999998	Сергея Лазо	0103000020E610000001000000050000007689EAAD81BB444029AF95D05D584A407689EAAD81BB444005DF347D76584A4048C153C895BC444005DF347D76584A4048C153C895BC444029AF95D05D584A407689EAAD81BB444029AF95D05D584A40
26066	127	41.447763999999999	41.470258000000001	52.712344000000002	52.702292999999997	Сергеева-Ценского	0103000020E61000000100000005000000BF29AC5450B94440D89AADBCE4594A40BF29AC5450B944403CC093162E5B4A405857056A31BC44403CC093162E5B4A405857056A31BC4440D89AADBCE4594A40BF29AC5450B94440D89AADBCE4594A40
26347	127	41.396776000000003	41.399830000000001	52.710051999999997	52.703139	Сенько	0103000020E610000001000000050000003AEB538EC9B2444065C57075005A4A403AEB538EC9B24440CD3AE3FBE25A4A40D7FA22A12DB34440CD3AE3FBE25A4A40D7FA22A12DB3444065C57075005A4A403AEB538EC9B2444065C57075005A4A40
25424	127	41.466225000000001	41.470230999999998	52.695461000000002	52.695166	Самарская	0103000020E61000000100000005000000EFC9C342ADBB444044A51133FB584A40EFC9C342ADBB44405D52B5DD04594A405E48878730BC44405D52B5DD04594A405E48878730BC444044A51133FB584A40EFC9C342ADBB444044A51133FB584A40
26083	127	41.390172999999997	41.435879	52.787053999999998	52.750135	Рылеева	0103000020E610000001000000050000001F645930F1B14440E04A766C04604A401F645930F1B14440CE177B2FBE644A40B00111E2CAB74440CE177B2FBE644A40B00111E2CAB74440E04A766C04604A401F645930F1B14440E04A766C04604A40
25582	127	41.390172999999997	41.435879	52.787053999999998	52.750135	Рылеева	0103000020E610000001000000050000001F645930F1B14440E04A766C04604A401F645930F1B14440CE177B2FBE644A40B00111E2CAB74440CE177B2FBE644A40B00111E2CAB74440E04A766C04604A401F645930F1B14440E04A766C04604A40
25973	127	41.433830999999998	41.464320000000001	52.743080999999997	52.701659999999997	Пролетарская	0103000020E61000000100000005000000D87E32C687B74440A774B0FECF594A40D87E32C687B74440B5A338471D5F4A407A7077D66EBB4440B5A338471D5F4A407A7077D66EBB4440A774B0FECF594A40D87E32C687B74440A774B0FECF594A40
26206	127	41.471685999999998	41.474983000000002	52.756200999999997	52.754452000000001	Проезд Энергетиков	0103000020E6100000010000000500000093FDF33460BC44406E3315E291604A4093FDF33460BC4440EB19C231CB604A40F793313ECCBC4440EB19C231CB604A40F793313ECCBC44406E3315E291604A4093FDF33460BC44406E3315E291604A40
26102	127	41.402534000000003	41.410088999999999	52.733609999999999	52.716566	Полынковская	0103000020E6100000010000000500000098C3EE3B86B3444078B6476FB85B4A4098C3EE3B86B344406002B7EEE65D4A4084B9DDCB7DB444406002B7EEE65D4A4084B9DDCB7DB4444078B6476FB85B4A4098C3EE3B86B3444078B6476FB85B4A40
26318	127	41.464643000000002	41.480426999999999	52.704039999999999	52.701856999999997	Пионерская	0103000020E610000001000000050000005DA8FC6B79BB4440FDBB3E73D6594A405DA8FC6B79BB4440B58993FB1D5A4A40C58EC6A17EBD4440B58993FB1D5A4A40C58EC6A17EBD4440FDBB3E73D6594A405DA8FC6B79BB4440FDBB3E73D6594A40
25675	127	41.418443000000003	41.425063999999999	52.715732000000003	52.707051	Петропавловская	0103000020E61000000100000005000000BD1E4C8A8FB5444053CDACA5805A4A40BD1E4C8A8FB54440B0592E1B9D5B4A407D5A457F68B64440B0592E1B9D5B4A407D5A457F68B6444053CDACA5805A4A40BD1E4C8A8FB5444053CDACA5805A4A40
26192	127	41.433993000000001	41.461976	52.734979000000003	52.731827000000003	Пензенская	0103000020E61000000100000005000000B2D826158DB7444037AAD381AC5D4A40B2D826158DB74440971FB8CA135E4A40B9C4910722BB4440971FB8CA135E4A40B9C4910722BB444037AAD381AC5D4A40B2D826158DB7444037AAD381AC5D4A40
26331	127	41.415819999999997	41.430076	52.704241000000003	52.697251000000001	Ново-рубежный переулок	0103000020E61000000100000005000000E882FA9639B54440390D51853F594A40E882FA9639B544404DC0AF91245A4A40B265F9BA0CB744404DC0AF91245A4A40B265F9BA0CB74440390D51853F594A40E882FA9639B54440390D51853F594A40
25853	127	41.386794999999999	41.404636000000004	52.715981999999997	52.714830999999997	Новикова-Прибоя	0103000020E61000000100000005000000CFA0A17F82B144405F950B957F5B4A40CFA0A17F82B144402843554CA55B4A406364C91CCBB344402843554CA55B4A406364C91CCBB344405F950B957F5B4A40CFA0A17F82B144405F950B957F5B4A40
25526	127	41.396532999999998	41.397252000000002	52.720390000000002	52.714410999999998	Нагорная	0103000020E610000001000000050000007364E597C1B244408A73D4D1715B4A407364E597C1B24440C72E51BD355C4A40A3224E27D9B24440C72E51BD355C4A40A3224E27D9B244408A73D4D1715B4A407364E597C1B244408A73D4D1715B4A40
25444	127	41.407304000000003	41.443694999999998	52.763226000000003	52.739699999999999	Н.Вирты	0103000020E61000000100000005000000D7C3978922B44440F46C567DAE5E4A40D7C3978922B444407CBABA63B1614A4009336DFFCAB844407CBABA63B1614A4009336DFFCAB84440F46C567DAE5E4A40D7C3978922B44440F46C567DAE5E4A40
25825	127	41.435098000000004	41.494998000000002	52.738914999999999	52.728625999999998	Московская	0103000020E610000001000000050000000B47904AB1B74440F581E49D435D4A400B47904AB1B744400DC347C4945E4A40EFCA2E185CBF44400DC347C4945E4A40EFCA2E185CBF4440F581E49D435D4A400B47904AB1B74440F581E49D435D4A40
25972	127	41.451079	41.474497999999997	52.758049	52.743239000000003	Моршанское шоссе	0103000020E61000000100000005000000C974E8F4BCB944404E0E9F74225F4A40C974E8F4BCB94440FCE1E7BF07614A403A02B859BCBC4440FCE1E7BF07614A403A02B859BCBC44404E0E9F74225F4A40C974E8F4BCB944404E0E9F74225F4A40
25975	127	41.373553999999999	41.453172000000002	52.782969000000001	52.730578000000001	Мичуринская	0103000020E610000001000000050000001EA5129ED0AF4440AB967494835D4A401EA5129ED0AF44401364045438644A4041BB438A01BA44401364045438644A4041BB438A01BA4440AB967494835D4A401EA5129ED0AF4440AB967494835D4A40
74475	127	41.408462999999998	41.420625999999999	52.720329999999997	52.719746000000001	Мира	0103000020E610000001000000050000002250FD8348B44440A2B60DA3205C4A402250FD8348B44440F12900C6335C4A4074ECA012D7B54440F12900C6335C4A4074ECA012D7B54440A2B60DA3205C4A402250FD8348B44440A2B60DA3205C4A40
26219	127	41.424596999999999	41.426492000000003	52.714477000000002	52.710636000000001	Мастерских	0103000020E61000000100000005000000677DCA3159B644401DAED51EF65A4A40677DCA3159B64440425F7AFB735B4A40B900344A97B64440425F7AFB735B4A40B900344A97B644401DAED51EF65A4A40677DCA3159B644401DAED51EF65A4A40
25605	127	41.391368	41.400818000000001	52.7303	52.729748999999998	Майская	0103000020E61000000100000005000000B859BC5818B24440F4A44C6A685D4A40B859BC5818B2444068226C787A5D4A40F6D214014EB3444068226C787A5D4A40F6D214014EB34440F4A44C6A685D4A40B859BC5818B24440F4A44C6A685D4A40
26094	127	41.413682000000001	41.424650999999997	52.717084	52.714215000000003	Лесная	0103000020E61000000100000005000000D1782288F3B4444005A8A9656B5B4A40D1782288F3B44440103E9468C95B4A405A9BC6F65AB64440103E9468C95B4A405A9BC6F65AB6444005A8A9656B5B4A40D1782288F3B4444005A8A9656B5B4A40
26313	127	41.433391	41.466197999999999	52.715387999999997	52.696748999999997	Лермонтовская	0103000020E61000000100000005000000BCB0355B79B74440A6423C122F594A40BCB0355B79B74440B5F97FD5915B4A40F5BA4560ACBB4440B5F97FD5915B4A40F5BA4560ACBB4440A6423C122F594A40BCB0355B79B74440A6423C122F594A40
25963	127	41.434550000000002	41.462963999999999	52.733463	52.730240000000002	Куйбышева	0103000020E61000000100000005000000083D9B559FB74440931D1B81785D4A40083D9B559FB74440BCE9961DE25D4A40D89C836742BB4440BCE9961DE25D4A40D89C836742BB4440931D1B81785D4A40083D9B559FB74440931D1B81785D4A40
26063	127	41.434846	41.463458000000003	52.715747999999998	52.709921000000001	Кронштадтская	0103000020E61000000100000005000000F165A208A9B744402FDFFAB0DE5A4A40F165A208A9B74440B51666A19D5B4A40E8887C9752BB4440B51666A19D5B4A40E8887C9752BB44402FDFFAB0DE5A4A40F165A208A9B744402FDFFAB0DE5A4A40
25462	127	41.409773999999999	41.466529999999999	52.764358999999999	52.703978999999997	Карла Маркса	0103000020E610000001000000050000002460747973B444400F09DFFB1B5A4A402460747973B444409EB30584D6614A402B4D4A41B7BB44409EB30584D6614A402B4D4A41B7BB44400F09DFFB1B5A4A402460747973B444400F09DFFB1B5A4A40
25718	127	41.420544999999997	41.431576999999997	52.731870000000001	52.726444000000001	Кавалерийская	0103000020E6100000010000000500000087BF266BD4B544400E30F31DFC5C4A4087BF266BD4B54440367689EAAD5D4A40575A46EA3DB74440367689EAAD5D4A40575A46EA3DB744400E30F31DFC5C4A4087BF266BD4B544400E30F31DFC5C4A40
26096	127	41.429349000000002	41.456496000000001	52.721922999999997	52.718840999999998	Интернациональная	0103000020E6100000010000000500000000C974E8F4B6444010035DFB025C4A4000C974E8F4B64440779D0DF9675C4A409E60FF756EBA4440779D0DF9675C4A409E60FF756EBA444010035DFB025C4A4000C974E8F4B6444010035DFB025C4A40
25460	127	41.411211999999999	41.419305999999999	52.704825	52.700111	Ивана Франко	0103000020E6100000010000000500000083DC4598A2B44440F148BC3C9D594A4083DC4598A2B444409C33A2B4375A4A401F82AAD1ABB544409C33A2B4375A4A401F82AAD1ABB54440F148BC3C9D594A4083DC4598A2B44440F148BC3C9D594A40
25440	127	41.439957999999997	41.441170999999997	52.753013000000003	52.747261999999999	Защитная	0103000020E6100000010000000500000089CE328B50B8444093C5FD47A65F4A4089CE328B50B844403F3BE0BA62604A40C878944A78B844403F3BE0BA62604A40C878944A78B8444093C5FD47A65F4A4089CE328B50B8444093C5FD47A65F4A40
26052	127	41.428683999999997	41.453127000000002	52.720652000000001	52.698501	Железнодорожная	0103000020E61000000100000005000000C328081EDFB64440959C137B68594A40C328081EDFB6444004E621533E5C4A40A1F7C61000BA444004E621533E5C4A40A1F7C61000BA4440959C137B68594A40C328081EDFB64440959C137B68594A40
26352	127	41.394027000000001	41.403422999999997	52.724535000000003	52.723880999999999	Делегатская	0103000020E61000000100000005000000D95E0B7A6FB244400F99F221A85C4A40D95E0B7A6FB2444058E71890BD5C4A4023BA675DA3B3444058E71890BD5C4A4023BA675DA3B344400F99F221A85C4A40D95E0B7A6FB244400F99F221A85C4A40
25422	127	41.467725000000002	41.480265000000003	52.705829000000001	52.704039999999999	Гоголя	0103000020E61000000100000005000000C442AD69DEBB4440B58993FB1D5A4A40C442AD69DEBB4440C1C8CB9A585A4A40EC34D25279BD4440C1C8CB9A585A4A40EC34D25279BD4440B58993FB1D5A4A40C442AD69DEBB4440B58993FB1D5A4A40
25915	127	41.396963999999997	41.426088	52.720095000000001	52.710051999999997	Гастелло	0103000020E610000001000000050000003CD862B7CFB24440CD3AE3FBE25A4A403CD862B7CFB24440AE81AD122C5C4A40E99B340D8AB64440AE81AD122C5C4A40E99B340D8AB64440CD3AE3FBE25A4A403CD862B7CFB24440CD3AE3FBE25A4A40
25837	127	41.456243999999998	41.459783999999999	52.740017000000002	52.734717000000003	Володарского	0103000020E61000000100000005000000847F113466BA44405A68E7340B5E4A40847F113466BA4440F5BD86E0B85E4A40AE9CBD33DABA4440F5BD86E0B85E4A40AE9CBD33DABA44405A68E7340B5E4A40847F113466BA44405A68E7340B5E4A40
26200	127	41.368774999999999	41.401797000000002	52.750357999999999	52.733359	Бастионная	0103000020E610000001000000050000008C4AEA0434AF4440179D2CB5DE5D4A408C4AEA0434AF44405F251FBB0B604A40C25087156EB344405F251FBB0B604A40C25087156EB34440179D2CB5DE5D4A408C4AEA0434AF4440179D2CB5DE5D4A40
25594	127	41.461984000000001	41.469656000000001	52.706397000000003	52.674132	Астраханская	0103000020E610000001000000050000003CA3AD4A22BB4440F29716F549564A403CA3AD4A22BB44400B7F86376B5A4A40622F14B01DBC44400B7F86376B5A4A40622F14B01DBC4440F29716F549564A403CA3AD4A22BB4440F29716F549564A40
25429	127	41.327336000000003	41.52881	52.788285000000002	52.670479	А.Бебеля	0103000020E61000000100000005000000D8666325E6A94440D0D38041D2554A40D8666325E6A94440B476DB85E6644A401DE6CB0BB0C34440B476DB85E6644A401DE6CB0BB0C34440D0D38041D2554A40D8666325E6A94440D0D38041D2554A40
25835	127	41.446767000000001	41.455409000000003	52.741504999999997	52.740234999999998	1-я Полковая	0103000020E610000001000000050000004DF73AA92FB94440622D3E05C05E4A404DF73AA92FB944400569C6A2E95E4A40ECA694D74ABA44400569C6A2E95E4A40ECA694D74ABA4440622D3E05C05E4A404DF73AA92FB94440622D3E05C05E4A40
25595	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Тимирязева	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25797	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Тамбовская	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25469	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Спортивная	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25996	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Советская	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
26290	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Пушкина	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25913	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Пролетарская	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25999	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Победы	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
26039	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Некрасова	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25579	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Маяковского	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25655	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Комсомольская	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25468	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Гоголя	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
26350	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Аптекарская	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25717	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Академика Маркова	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
26353	4588	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	60 лет	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
25922	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Южная	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25800	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Фрунзе	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
26092	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Пролетарская	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
26364	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Пионерская	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25928	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Октябрьская площадь	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25600	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Лотикова	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25567	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Ленина	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25784	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Крупской	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25534	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Красноармейская	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
26359	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Красная	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25855	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Кирова	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25966	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Интернациональная	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
26358	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Зеленая	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25723	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Дзержинского	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25575	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Горького	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
26275	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	Гибнера	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25690	2288	41.742088000000003	41.858905	53.470483999999999	53.41677	7-й городок	0103000020E61000000100000005000000856055BDFCDE44401AFA27B858B54A40856055BDFCDE444048A5D8D138BC4A4079AF5A99F0ED444048A5D8D138BC4A4079AF5A99F0ED44401AFA27B858B54A40856055BDFCDE44401AFA27B858B54A40
25715	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Федеративная	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25794	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Турбинная	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25591	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Тамбовская	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25889	2401	41.444476000000002	41.465901000000002	52.761508999999997	52.760593999999998	Средняя	0103000020E61000000100000005000000AFEDED96E4B8444054C4E9245B614A40AFEDED96E4B84440094E7D2079614A403C16DBA4A2BB4440094E7D2079614A403C16DBA4A2BB444054C4E9245B614A40AFEDED96E4B8444054C4E9245B614A40
25735	2401	41.412927000000003	41.427247000000001	52.765852000000002	52.754418999999999	Социалистическая	0103000020E610000001000000050000005551BCCADAB44440923D42CD90604A405551BCCADAB44440C1C9367007624A4035289A07B0B64440C1C9367007624A4035289A07B0B64440923D42CD90604A405551BCCADAB44440923D42CD90604A40
25393	2401	41.431415000000001	41.472476999999998	52.766058999999998	52.701022000000002	Советская	0103000020E610000001000000050000007E00529B38B7444065E3C116BB594A407E00529B38B744403AE7A7380E624A405C8E57207ABC44403AE7A7380E624A405C8E57207ABC444065E3C116BB594A407E00529B38B7444065E3C116BB594A40
25652	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Революционная	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25888	2401	41.442024000000004	41.447144000000002	52.744247000000001	52.740518000000002	Новая	0103000020E610000001000000050000000806103E94B84440B70C384BC95E4A400806103E94B84440B492567C435F4A40234DBC033CB94440B492567C435F4A40234DBC033CB94440B70C384BC95E4A400806103E94B84440B70C384BC95E4A40
25535	2401	41.446641	41.449112	52.733266	52.731740000000002	Мичурина	0103000020E61000000100000005000000C00644882BB94440689604A8A95D4A40C00644882BB9444066A208A9DB5D4A40DE1E84807CB9444066A208A9DB5D4A40DE1E84807CB94440689604A8A95D4A40C00644882BB94440689604A8A95D4A40
25400	2401	41.408462999999998	41.420625999999999	52.720329999999997	52.719746000000001	Мира	0103000020E610000001000000050000002250FD8348B44440A2B60DA3205C4A402250FD8348B44440F12900C6335C4A4074ECA012D7B54440F12900C6335C4A4074ECA012D7B54440A2B60DA3205C4A402250FD8348B44440A2B60DA3205C4A40
25383	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Мартовская	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25541	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Липецкое шоссе	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25803	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Лермонтова	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25791	2401	41.430695999999998	41.431674999999998	52.720903	52.716380999999998	Лаврова	0103000020E610000001000000050000004E42E90B21B74440E63C635FB25B4A404E42E90B21B744404D4BAC8C465C4A401AC05B2041B744404D4BAC8C465C4A401AC05B2041B74440E63C635FB25B4A404E42E90B21B74440E63C635FB25B4A40
25799	2401	41.440792999999999	41.442760999999997	52.7273	52.720308000000003	Красная	0103000020E6100000010000000500000022A7AFE76BB844400A86730D335C4A4022A7AFE76BB84440BE30992A185D4A40DD787764ACB84440BE30992A185D4A40DD787764ACB844400A86730D335C4A4022A7AFE76BB844400A86730D335C4A40
25398	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Кооперативная	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25480	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Киевская	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25654	2401	41.429349000000002	41.456496000000001	52.721922999999997	52.718840999999998	Интернациональная	0103000020E6100000010000000500000000C974E8F4B6444010035DFB025C4A4000C974E8F4B64440779D0DF9675C4A409E60FF756EBA4440779D0DF9675C4A409E60FF756EBA444010035DFB025C4A4000C974E8F4B6444010035DFB025C4A40
25852	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Дзержинского	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25919	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Автозаводская	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25671	2401	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	7 Ноября	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
26164	51231	41.449793999999997	41.472279	52.710816000000001	52.700842000000002	Энгельса	0103000020E61000000100000005000000F0F78BD992B94440E5D4CE30B5594A40F0F78BD992B944409DBCC804FC5A4A4036CB65A373BC44409DBCC804FC5A4A4036CB65A373BC4440E5D4CE30B5594A40F0F78BD992B94440E5D4CE30B5594A40
26368	51231	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Тамбовская	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
26223	51231	41.431415000000001	41.472476999999998	52.766058999999998	52.701022000000002	Советская	0103000020E610000001000000050000007E00529B38B7444065E3C116BB594A407E00529B38B744403AE7A7380E624A405C8E57207ABC44403AE7A7380E624A405C8E57207ABC444065E3C116BB594A407E00529B38B7444065E3C116BB594A40
26311	51231	41.427470999999997	41.429430000000004	52.71913	52.718480999999997	Привокзальная площадь	0103000020E61000000100000005000000847EA65EB7B6444010E6762FF75B4A40847EA65EB7B6444047C9AB730C5C4A40EDF5EE8FF7B6444047C9AB730C5C4A40EDF5EE8FF7B6444010E6762FF75B4A40847EA65EB7B6444010E6762FF75B4A40
26110	51231	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Полтавская	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
26132	51231	41.408462999999998	41.420625999999999	52.720329999999997	52.719746000000001	Мира	0103000020E610000001000000050000002250FD8348B44440A2B60DA3205C4A402250FD8348B44440F12900C6335C4A4074ECA012D7B54440F12900C6335C4A4074ECA012D7B54440A2B60DA3205C4A402250FD8348B44440A2B60DA3205C4A40
26150	51231	41.440792999999999	41.442760999999997	52.7273	52.720308000000003	Красная	0103000020E6100000010000000500000022A7AFE76BB844400A86730D335C4A4022A7AFE76BB84440BE30992A185D4A40DD787764ACB84440BE30992A185D4A40DD787764ACB844400A86730D335C4A4022A7AFE76BB844400A86730D335C4A40
26215	51231	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Дубровского	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
26154	51231	40.431356000000001	40.545783999999998	52.917597999999998	52.860689000000001	Герасимова	0103000020E61000000100000005000000797764AC363744407383A10E2B6E4A40797764AC363744400070ECD973754A400C570740DC4544400070ECD973754A400C570740DC4544407383A10E2B6E4A40797764AC363744407383A10E2B6E4A40
25868	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	Свободы	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
25920	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	Посконкина	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
26004	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	Октябрьская	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
25479	26221	41.491297000000003	41.492967	52.682693	52.680388999999998	Набережная	0103000020E61000000100000005000000BCCFF1D1E2BE444071C79BFC16574A40BCCFF1D1E2BE4440A41AF67B62574A40ED80EB8A19BF4440A41AF67B62574A40ED80EB8A19BF444071C79BFC16574A40BCCFF1D1E2BE444071C79BFC16574A40
26006	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	Лесхозная	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
25603	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	Красногвардейская	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
26363	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	Котовского	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
25401	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	Кирова	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
25738	26221	41.481378999999997	41.532592000000001	52.607754	52.573495000000001	9-й Пятилетки	0103000020E6100000010000000500000097FDBAD39DBD4440B3B5BE4868494A4097FDBAD39DBD4440B00111E2CA4D4A403D0E83F92BC44440B00111E2CA4D4A403D0E83F92BC44440B3B5BE4868494A4097FDBAD39DBD4440B3B5BE4868494A40
75504	60648	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Спортивная	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
75007	60435	41.439247999999999	41.491135	52.661883000000003	52.616197	переулок Березовый	0103000020E61000000100000005000000AD6A494739B844405872158BDF4E4A40AD6A494739B84440A2630795B8544A40E275FD82DDBE4440A2630795B8544A40E275FD82DDBE44405872158BDF4E4A40AD6A494739B844405872158BDF4E4A40
75013	60435	41.439247999999999	41.491135	52.661883000000003	52.616197	Советская	0103000020E61000000100000005000000AD6A494739B844405872158BDF4E4A40AD6A494739B84440A2630795B8544A40E275FD82DDBE4440A2630795B8544A40E275FD82DDBE44405872158BDF4E4A40AD6A494739B844405872158BDF4E4A40
25574	45628	42.941555000000001	42.998866999999997	52.576855999999999	52.549106000000002	Транспортная	0103000020E610000001000000050000005131CEDF84784540C904FC1A49464A405131CEDF847845402D40DB6AD6494A40DD06B5DFDA7F45402D40DB6AD6494A40DD06B5DFDA7F4540C904FC1A49464A405131CEDF84784540C904FC1A49464A40
26210	45628	42.941555000000001	42.998866999999997	52.576855999999999	52.549106000000002	Советская	0103000020E610000001000000050000005131CEDF84784540C904FC1A49464A405131CEDF847845402D40DB6AD6494A40DD06B5DFDA7F45402D40DB6AD6494A40DD06B5DFDA7F4540C904FC1A49464A405131CEDF84784540C904FC1A49464A40
25581	51179	42.998454000000002	43.000475000000002	52.612910999999997	52.610115999999998	Школьная	0103000020E61000000100000005000000BB473657CD7F45401762F547184E4A40BB473657CD7F4540E82D1EDE734E4A4099BB96900F804540E82D1EDE734E4A4099BB96900F8045401762F547184E4A40BB473657CD7F45401762F547184E4A40
26204	51193	43.139758999999998	43.155119999999997	52.671543999999997	52.659686999999998	Центральная	0103000020E610000001000000050000002C29779FE3914540554CA59F70544A402C29779FE39145409AE95E27F5554A404E7ADFF8DA9345409AE95E27F5554A404E7ADFF8DA934540554CA59F70544A402C29779FE3914540554CA59F70544A40
25702	48277	42.860284	42.901643	52.620964999999998	52.592855	Ленина	0103000020E61000000100000005000000D3A23EC91D6E4540922232ACE24B4A40D3A23EC91D6E4540F67AF7C77B4F4A406BD5AE0969734540F67AF7C77B4F4A406BD5AE0969734540922232ACE24B4A40D3A23EC91D6E4540922232ACE24B4A40
25387	4166	42.841599000000002	42.868997999999998	52.480074999999999	52.46951	Коммунальная	0103000020E6100000010000000500000054AC1A84B96B45408E9257E7183C4A4054AC1A84B96B45404850FC18733D4A400B2593533B6F45404850FC18733D4A400B2593533B6F45408E9257E7183C4A4054AC1A84B96B45408E9257E7183C4A40
25842	4166	42.841599000000002	42.868997999999998	52.480074999999999	52.46951	Заречная	0103000020E6100000010000000500000054AC1A84B96B45408E9257E7183C4A4054AC1A84B96B45404850FC18733D4A400B2593533B6F45404850FC18733D4A400B2593533B6F45408E9257E7183C4A4054AC1A84B96B45408E9257E7183C4A40
25707	45358	42.823794999999997	42.837952000000001	52.545771000000002	52.531941000000003	Центральная	0103000020E61000000100000005000000DDCD531D72694540663387A416444A40DDCD531D72694540780DFAD2DB454A4014CFD902426B4540780DFAD2DB454A4014CFD902426B4540663387A416444A40DDCD531D72694540663387A416444A40
25970	46436	42.904336999999998	42.918163	52.721665999999999	52.707259000000001	Молодежная	0103000020E6100000010000000500000008C89750C17345409D668176875A4A4008C89750C17345404C512E8D5F5C4A40D9B27C5D867545404C512E8D5F5C4A40D9B27C5D867545409D668176875A4A4008C89750C17345409D668176875A4A40
25463	51169	43.075088999999998	43.089947000000002	52.781025	52.773702999999998	Центральная	0103000020E6100000010000000500000009A52F849C89454096E82CB308634A4009A52F849C894540E02D90A0F8634A40C9AF1F62838B4540E02D90A0F8634A40C9AF1F62838B454096E82CB308634A4009A52F849C89454096E82CB308634A40
26049	3371	42.924801000000002	42.957121999999998	52.826140000000002	52.807070000000003	Парковая	0103000020E61000000100000005000000702711E15F76454097CADB114E674A40702711E15F7645406FF59CF4BE694A401C2444F9827A45406FF59CF4BE694A401C2444F9827A454097CADB114E674A40702711E15F76454097CADB114E674A40
25448	51168	42.882508000000001	42.905478000000002	52.738424999999999	52.711804000000001	Быковская	0103000020E61000000100000005000000AC3AAB05F6704540BC94BA641C5B4A40AC3AAB05F67045403FC6DCB5845E4A40AE9FFEB3E67345403FC6DCB5845E4A40AE9FFEB3E6734540BC94BA641C5B4A40AC3AAB05F6704540BC94BA641C5B4A40
25982	46432	43.016033999999998	43.033209999999997	52.578786999999998	52.566462000000001	Центральная	0103000020E61000000100000005000000E1CFF0660D824540A036AAD381484A40E1CFF0660D824540CB2C42B1154A4A4038F3AB3940844540CB2C42B1154A4A4038F3AB3940844540A036AAD381484A40E1CFF0660D824540A036AAD381484A40
26336	40452	42.801893999999997	42.836973	52.493367999999997	52.469059999999999	Луговая	0103000020E61000000100000005000000E76D6C76A46645404EEE77280A3C4A40E76D6C76A46645404B72C0AE263F4A40485167EE216B45404B72C0AE263F4A40485167EE216B45404EEE77280A3C4A40E76D6C76A46645404EEE77280A3C4A40
25454	46283	42.908020999999998	42.941312000000003	52.506996999999998	52.490648	Верхняя	0103000020E61000000100000005000000658A39083A74454085ECBC8DCD3E4A40658A39083A744540C6151747E5404A408BAA5FE97C784540C6151747E5404A408BAA5FE97C78454085ECBC8DCD3E4A40658A39083A74454085ECBC8DCD3E4A40
25845	51207	42.994177999999998	43.023094999999998	52.852386000000003	52.834240999999999	Начальная	0103000020E610000001000000050000008B338639417F4540BDFDB968C86A4A408B338639417F4540BDC804FC1A6D4A40BED9E6C6F4824540BDC804FC1A6D4A40BED9E6C6F4824540BDFDB968C86A4A408B338639417F4540BDFDB968C86A4A40
25576	30783	42.773587999999997	42.788885999999998	52.519661999999997	52.512098999999999	Центральная	0103000020E61000000100000005000000FD497CEE046345403BA8C4758C414A40FD497CEE04634540AA7CCF4884424A40D9226937FA644540AA7CCF4884424A40D9226937FA6445403BA8C4758C414A40FD497CEE046345403BA8C4758C414A40
25839	47795	43.063572999999998	43.093496000000002	52.750756000000003	52.738888000000003	Центральная	0103000020E610000001000000050000004DF4F9282388454014B4C9E1935E4A404DF4F928238845404DA3C9C518604A4046274BADF78B45404DA3C9C518604A4046274BADF78B454014B4C9E1935E4A404DF4F9282388454014B4C9E1935E4A40
75384	47795	43.063572999999998	43.093496000000002	52.750756000000003	52.738888000000003	Мира	0103000020E610000001000000050000004DF4F9282388454014B4C9E1935E4A404DF4F928238845404DA3C9C518604A4046274BADF78B45404DA3C9C518604A4046274BADF78B454014B4C9E1935E4A404DF4F9282388454014B4C9E1935E4A40
26203	49233	42.929544	42.945929	52.379435000000001	52.368614999999998	Молодежная	0103000020E61000000100000005000000B5183C4CFB76454053E8BCC62E2F4A40B5183C4CFB76454098FA795391304A4043AB93331479454098FA795391304A4043AB93331479454053E8BCC62E2F4A40B5183C4CFB76454053E8BCC62E2F4A40
25807	26647	41.955132999999996	41.97486	51.846600000000002	51.836016999999998	Школьная	0103000020E61000000100000005000000492A53CC41FA444034F3E49A02EB4940492A53CC41FA4440956588635DEC4940DB166536C8FC4440956588635DEC4940DB166536C8FC444034F3E49A02EB4940492A53CC41FA444034F3E49A02EB4940
25804	26371	42.22222	42.239305999999999	51.888420000000004	51.875855999999999	Школьная	0103000020E61000000100000005000000314278B4711C4540B000A60C1CF04940314278B4711C4540618E1EBFB7F1494048DE3994A11E4540618E1EBFB7F1494048DE3994A11E4540B000A60C1CF04940314278B4711C4540B000A60C1CF04940
26308	27112	42.084220999999999	42.112175999999998	51.865412999999997	51.840591000000003	Попова	0103000020E610000001000000050000007651F4C0C70A4540EE27637C98EB49407651F4C0C70A454041446ADAC5EE4940B3B27DC85B0E454041446ADAC5EE4940B3B27DC85B0E4540EE27637C98EB49407651F4C0C70A4540EE27637C98EB4940
25878	47278	41.970584000000002	41.99747	51.902591999999999	51.874721999999998	Центральная	0103000020E61000000100000005000000AC02B5183CFC4440BD8BF7E3F6EF4940AC02B5183CFC4440CCD0782288F34940DD5ED218ADFF4440CCD0782288F34940DD5ED218ADFF4440BD8BF7E3F6EF4940AC02B5183CFC4440BD8BF7E3F6EF4940
26374	47278	41.970584000000002	41.99747	51.902591999999999	51.874721999999998	Молодежная	0103000020E61000000100000005000000AC02B5183CFC4440BD8BF7E3F6EF4940AC02B5183CFC4440CCD0782288F34940DD5ED218ADFF4440CCD0782288F34940DD5ED218ADFF4440BD8BF7E3F6EF4940AC02B5183CFC4440BD8BF7E3F6EF4940
26316	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	переулок Первомайский	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
25673	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	Шоссейная	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
25674	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	Центральная	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
25644	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	Микрорайон Молодежный	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
26326	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	Дачная	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
25679	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	Гагарина	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
26241	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	Большая Садовая	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
25423	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	4 микрорайон	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
26015	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	2 микрорайон	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
25433	20	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	1 микрорайон	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
25681	47261	41.929468	41.950721999999999	51.925896999999999	51.899514000000003	Молодежная	0103000020E61000000100000005000000DA56B3CEF8F64440A725564623F34940DA56B3CEF8F64440753BFBCA83F649403ACB2C42B1F94440753BFBCA83F649403ACB2C42B1F94440A725564623F34940DA56B3CEF8F64440A725564623F34940
25944	20965	42.060236000000003	42.107261999999999	51.749752000000001	51.716797999999997	Юбилейная	0103000020E610000001000000050000005C0531D0B50745404AEB6F09C0DB49405C0531D0B5074540280EA0DFF7DF4940410DDFC2BA0D4540280EA0DFF7DF4940410DDFC2BA0D45404AEB6F09C0DB49405C0531D0B50745404AEB6F09C0DB4940
25816	20965	42.060236000000003	42.107261999999999	51.749752000000001	51.716797999999997	Центральная	0103000020E610000001000000050000005C0531D0B50745404AEB6F09C0DB49405C0531D0B5074540280EA0DFF7DF4940410DDFC2BA0D4540280EA0DFF7DF4940410DDFC2BA0D45404AEB6F09C0DB49405C0531D0B50745404AEB6F09C0DB4940
25947	26829	42.301881999999999	42.329559000000003	52.046149999999997	52.005009000000001	Центральная	0103000020E6100000010000000500000023A0C211A4264540C4978922A4004A4023A0C211A4264540EE5A423EE8054A401E8D43FD2E2A4540EE5A423EE8054A401E8D43FD2E2A4540C4978922A4004A4023A0C211A4264540C4978922A4004A40
26180	26829	42.301881999999999	42.329559000000003	52.046149999999997	52.005009000000001	Кировская	0103000020E6100000010000000500000023A0C211A4264540C4978922A4004A4023A0C211A4264540EE5A423EE8054A401E8D43FD2E2A4540EE5A423EE8054A401E8D43FD2E2A4540C4978922A4004A4023A0C211A4264540C4978922A4004A40
25827	26278	42.052205000000001	42.118769999999998	51.932994999999998	51.889943000000002	Советская	0103000020E6100000010000000500000006D847A7AE064540EE26F8A6E9F1494006D847A7AE0645406F2A52616CF749407ADFF8DA330F45406F2A52616CF749407ADFF8DA330F4540EE26F8A6E9F1494006D847A7AE064540EE26F8A6E9F14940
25930	26278	42.052205000000001	42.118769999999998	51.932994999999998	51.889943000000002	Молодежная	0103000020E6100000010000000500000006D847A7AE064540EE26F8A6E9F1494006D847A7AE0645406F2A52616CF749407ADFF8DA330F45406F2A52616CF749407ADFF8DA330F4540EE26F8A6E9F1494006D847A7AE064540EE26F8A6E9F14940
26294	47377	42.335245999999998	42.376190999999999	51.940057000000003	51.917743000000002	Центральная	0103000020E61000000100000005000000B20E4757E92A45400491459A78F54940B20E4757E92A45401DB0ABC953F849405706D506273045401DB0ABC953F849405706D506273045400491459A78F54940B20E4757E92A45400491459A78F54940
26169	47430	41.939385000000001	41.963307	51.780386999999997	51.767418999999997	Школьная	0103000020E610000001000000050000002EAD86C43DF844401DAA29C93AE249402EAD86C43DF844409D9CA1B8E3E349400281CEA44DFB44409D9CA1B8E3E349400281CEA44DFB44401DAA29C93AE249402EAD86C43DF844401DAA29C93AE24940
26023	47573	42.353149000000002	42.364252	52.123130000000003	52.115409999999997	4-я Лопатинская	0103000020E61000000100000005000000BCCE86FC332D4540D0D03FC1C50E4A40BCCE86FC332D454008944DB9C20F4A4055C03DCF9F2E454008944DB9C20F4A4055C03DCF9F2E4540D0D03FC1C50E4A40BCCE86FC332D4540D0D03FC1C50E4A40
25810	47557	42.311036000000001	42.363408	52.006528000000003	51.995517	Молодежная	0103000020E6100000010000000500000078F01307D027454057CEDE196DFF494078F01307D02745401041D5E8D5004A40698D4127842E45401041D5E8D5004A40698D4127842E454057CEDE196DFF494078F01307D027454057CEDE196DFF4940
26177	26752	42.107576999999999	42.121833000000002	51.684663999999998	51.671756999999999	Григорьевская	0103000020E61000000100000005000000A1664815C50D4540F6ED2422FCD54940A1664815C50D4540D05FE811A3D749406B494739980F4540D05FE811A3D749406B494739980F4540F6ED2422FCD54940A1664815C50D4540F6ED2422FCD54940
25665	26563	42.229981000000002	42.261673999999999	51.849755000000002	51.831442000000003	Центральная	0103000020E61000000100000005000000C7D97404701D4540AB4203B16CEA4940C7D97404701D4540664E97C5C4EC4940541B9C887E214540664E97C5C4EC4940541B9C887E214540AB4203B16CEA4940C7D97404701D4540AB4203B16CEA4940
25419	27027	42.506625999999997	42.529938000000001	52.039180999999999	52.026426999999998	Куракинский	0103000020E61000000100000005000000D2A6EA1ED94045409E5DBEF561034A40D2A6EA1ED9404540F2CF0CE203054A402E742502D5434540F2CF0CE203054A402E742502D54345409E5DBEF561034A40D2A6EA1ED94045409E5DBEF561034A40
25936	26503	42.338839	42.381490999999997	51.924075000000002	51.889648999999999	Советская	0103000020E61000000100000005000000FFCD8B135F2B4540A5F5B704E0F14940FFCD8B135F2B45408E06F01648F64940F25B74B2D43045408E06F01648F64940F25B74B2D4304540A5F5B704E0F14940FFCD8B135F2B4540A5F5B704E0F14940
75024	60444	42.043168000000001	42.088982000000001	52.010109999999997	51.992511	Советская	0103000020E61000000100000005000000EB1D6E8786054540CBF5B6990AFF4940EB1D6E878605454068AED3484B014A4062F71DC3630B454068AED3484B014A4062F71DC3630B4540CBF5B6990AFF4940EB1D6E8786054540CBF5B6990AFF4940
26202	47591	42.285569000000002	42.308638000000002	52.160055999999997	52.151608000000003	Алаторская	0103000020E610000001000000050000002FE065868D244540EFE714E467134A402FE065868D244540A8C30AB77C144A40C426327381274540A8C30AB77C144A40C426327381274540EFE714E467134A402FE065868D244540EFE714E467134A40
25438	51167	42.201774	42.293762000000001	52.031241999999999	51.931229000000002	переулок Большой Садовый	0103000020E610000001000000050000007097FDBAD31945401C0B0A8332F749407097FDBAD31945407D21E4BCFF034A405E6743FE992545407D21E4BCFF034A405E6743FE992545401C0B0A8332F749407097FDBAD31945401C0B0A8332F74940
26026	46946	40.960625999999998	41.083381000000003	52.131881999999997	52.060138999999999	Школьная	0103000020E61000000100000005000000F9D7F2CAF57A4440691B7FA2B2074A40F9D7F2CAF57A44402D776682E1104A40CC0D863AAC8A44402D776682E1104A40CC0D863AAC8A4440691B7FA2B2074A40F9D7F2CAF57A4440691B7FA2B2074A40
25558	32188	41.335501999999998	41.36891	52.041535000000003	52.027923000000001	Полевая	0103000020E610000001000000050000000DDFC2BAF1AA444032E719FB92034A400DDFC2BAF1AA4440D751D50451054A406C95607138AF4440D751D50451054A406C95607138AF444032E719FB92034A400DDFC2BAF1AA444032E719FB92034A40
26171	3534	41.057113999999999	41.116833999999997	51.985401000000003	51.949395000000003	Центральная	0103000020E610000001000000050000006612F5824F87444033FE7DC685F949406612F5824F8744400D39B69E21FE4940CA87A06AF48E44400D39B69E21FE4940CA87A06AF48E444033FE7DC685F949406612F5824F87444033FE7DC685F94940
25630	24737	41.136209999999998	41.195095000000002	52.008419000000004	51.975527	проспект Революции	0103000020E61000000100000005000000AFB14B546F914440B8AE9811DEFC4940AFB14B546F91444020D5B0DF13014A407B4E7ADFF898444020D5B0DF13014A407B4E7ADFF8984440B8AE9811DEFC4940AFB14B546F914440B8AE9811DEFC4940
25530	24737	41.136209999999998	41.195095000000002	52.008419000000004	51.975527	Чичканова	0103000020E61000000100000005000000AFB14B546F914440B8AE9811DEFC4940AFB14B546F91444020D5B0DF13014A407B4E7ADFF898444020D5B0DF13014A407B4E7ADFF8984440B8AE9811DEFC4940AFB14B546F914440B8AE9811DEFC4940
25914	24737	41.136209999999998	41.195095000000002	52.008419000000004	51.975527	Проспект Революции	0103000020E61000000100000005000000AFB14B546F914440B8AE9811DEFC4940AFB14B546F91444020D5B0DF13014A407B4E7ADFF898444020D5B0DF13014A407B4E7ADFF8984440B8AE9811DEFC4940AFB14B546F914440B8AE9811DEFC4940
26156	24737	41.136209999999998	41.195095000000002	52.008419000000004	51.975527	40 лет Октября	0103000020E61000000100000005000000AFB14B546F914440B8AE9811DEFC4940AFB14B546F91444020D5B0DF13014A407B4E7ADFF898444020D5B0DF13014A407B4E7ADFF8984440B8AE9811DEFC4940AFB14B546F914440B8AE9811DEFC4940
26255	24915	41.106206999999998	41.158155999999998	51.983893000000002	51.963819999999998	Школьная	0103000020E610000001000000050000009ACDE330988D4440889D29745EFB49409ACDE330988D4440B5E1B034F0FD494045D5AF743E944440B5E1B034F0FD494045D5AF743E944440889D29745EFB49409ACDE330988D4440889D29745EFB4940
75022	60441	41.063203999999999	41.108345	51.785173	51.763750999999999	Центральная	0103000020E61000000100000005000000FA7C941117884440C6A4BF97C2E14940FA7C941117884440E259828C80E44940B2D7BB3FDE8D4440E259828C80E44940B2D7BB3FDE8D4440C6A4BF97C2E14940FA7C941117884440C6A4BF97C2E14940
25544	47095	41.071477999999999	41.104554	51.89584	51.876379	Центральная	0103000020E610000001000000050000001631EC30268944405AF3E32F2DF049401631EC30268944406D3997E2AAF249403F558506628D44406D3997E2AAF249403F558506628D44405AF3E32F2DF049401631EC30268944405AF3E32F2DF04940
26174	51239	40.954310999999997	40.992570000000001	51.939785000000001	51.919170999999999	Дружбы	0103000020E61000000100000005000000459BE3DC267A44403F373465A7F54940459BE3DC267A4440BC22F8DF4AF84940D07EA4880C7F4440BC22F8DF4AF84940D07EA4880C7F44403F373465A7F54940459BE3DC267A44403F373465A7F54940
25494	45820	41.264696000000001	41.270985000000003	52.222034000000001	52.217360999999997	Энтузиастов	0103000020E61000000100000005000000E6B0FB8EE1A144408236397CD21B4A40E6B0FB8EE1A14440CF4C309C6B1C4A40715AF0A2AFA24440CF4C309C6B1C4A40715AF0A2AFA244408236397CD21B4A40E6B0FB8EE1A144408236397CD21B4A40
25793	25261	41.379941000000002	41.441018	52.173186999999999	52.156177999999997	Молодежная	0103000020E610000001000000050000006CB41CE8A1B04440662D05A4FD134A406CB41CE8A1B04440D28BDAFD2A164A4042791F4773B84440D28BDAFD2A164A4042791F4773B84440662D05A4FD134A406CB41CE8A1B04440662D05A4FD134A40
25568	49381	40.963887	40.99248	52.024375999999997	52.007271000000003	Центральная	0103000020E61000000100000005000000100533A6607B4440C89A9141EE004A40100533A6607B44405567B5C01E034A4090F7AA95097F44405567B5C01E034A4090F7AA95097F4440C89A9141EE004A40100533A6607B4440C89A9141EE004A40
26165	32110	41.053187999999999	41.182025000000003	52.147767000000002	51.807352999999999	Новая	0103000020E61000000100000005000000134548DDCE864440EBA9D55757E74940134548DDCE864440CA367007EA124A40F7065F984C974440CA367007EA124A40F7065F984C974440EBA9D55757E74940134548DDCE864440EBA9D55757E74940
26114	47348	41.162621000000001	41.177982	51.891615999999999	51.882232999999999	Парковая	0103000020E610000001000000050000004852D2C3D0944440DA39CD02EDF049404852D2C3D0944440904B1C7920F249406AA33A1DC8964440904B1C7920F249406AA33A1DC8964440DA39CD02EDF049404852D2C3D0944440DA39CD02EDF04940
25403	47042	41.004427999999997	41.024514000000003	51.844746999999998	51.823087000000001	Речная	0103000020E61000000100000005000000E597C11891804440A26131EA5AE94940E597C11891804440723271AB20EC4940A725564623834440723271AB20EC4940A725564623834440A26131EA5AE94940E597C11891804440A26131EA5AE94940
25532	24991	41.174973000000001	41.214930000000003	52.155796000000002	52.133817000000001	Центральная	0103000020E610000001000000050000006D57E883659644400D535BEA20114A406D57E883659644407F6C921FF1134A40F37684D3829B44407F6C921FF1134A40F37684D3829B44400D535BEA20114A406D57E883659644400D535BEA20114A40
25881	51190	40.968369000000003	40.992794000000004	51.972963999999997	51.962372000000002	Каменка	0103000020E61000000100000005000000E9BAF083F37B4440064B75012FFB4940E9BAF083F37B4440B91798158AFC494020D5B0DF137F4440B91798158AFC494020D5B0DF137F4440064B75012FFB4940E9BAF083F37B4440064B75012FFB4940
26328	51254	41.263789000000003	41.293784000000002	51.988123999999999	51.967298999999997	Новая	0103000020E61000000100000005000000B40584D6C3A144400C3A2174D0FB4940B40584D6C3A144404432E4D87AFE4940460BD0B69AA544404432E4D87AFE4940460BD0B69AA544400C3A2174D0FB4940B40584D6C3A144400C3A2174D0FB4940
25917	51218	41.188339999999997	41.210312000000002	52.123086000000001	52.100242999999999	Кавказская 	0103000020E61000000100000005000000AA436E861B98444093533BC3D40C4A40AA436E861B984440384C3448C10F4A406AFAEC80EB9A4440384C3448C10F4A406AFAEC80EB9A444093533BC3D40C4A40AA436E861B98444093533BC3D40C4A40
25615	45706	41.291341000000003	41.302489000000001	52.100177000000002	52.077621999999998	Школьная	0103000020E61000000100000005000000F27D71A94AA544409DB98784EF094A40F27D71A94AA54440DC679599D20C4A402B33A5F5B7A64440DC679599D20C4A402B33A5F5B7A644409DB98784EF094A40F27D71A94AA544409DB98784EF094A40
25660	45706	41.291341000000003	41.302489000000001	52.100177000000002	52.077621999999998	Молодежная	0103000020E61000000100000005000000F27D71A94AA544409DB98784EF094A40F27D71A94AA54440DC679599D20C4A402B33A5F5B7A64440DC679599D20C4A402B33A5F5B7A644409DB98784EF094A40F27D71A94AA544409DB98784EF094A40
75487	45706	41.291341000000003	41.302489000000001	52.100177000000002	52.077621999999998	Александровская	0103000020E61000000100000005000000F27D71A94AA544409DB98784EF094A40F27D71A94AA54440DC679599D20C4A402B33A5F5B7A64440DC679599D20C4A402B33A5F5B7A644409DB98784EF094A40F27D71A94AA544409DB98784EF094A40
26045	24636	41.479743999999997	41.510717999999997	53.010527000000003	52.955731	Ленина	0103000020E61000000100000005000000E2395B4068BD4440FE62B664557A4A40E2395B4068BD4440CD5CE0F258814A4040BD19355FC14440CD5CE0F258814A4040BD19355FC14440FE62B664557A4A40E2395B4068BD4440FE62B664557A4A40
26037	1176	40.933793000000001	40.950484000000003	52.637794	52.627015999999998	Совхозная	0103000020E61000000100000005000000EB1D6E8786774440CC086F0F42504A40EB1D6E8786774440E2CAD93BA3514A4086AFAF75A9794440E2CAD93BA3514A4086AFAF75A9794440CC086F0F42504A40EB1D6E8786774440CC086F0F42504A40
75417	47159	41.316718000000002	41.333821999999998	52.590814000000002	52.577188999999997	Школьная	0103000020E61000000100000005000000FB0626378AA84440334E4354E1494A40FB0626378AA844406D020CCB9F4B4A40B857E6ADBAAA44406D020CCB9F4B4A40B857E6ADBAAA4440334E4354E1494A40FB0626378AA84440334E4354E1494A40
25763	51199	41.550162999999998	41.581873999999999	52.820121999999998	52.801560000000002	Советская	0103000020E61000000100000005000000103CBEBD6BC6444011E4A08499664A40103CBEBD6BC64440745DF8C1F9684A404432E4D87ACA4440745DF8C1F9684A404432E4D87ACA444011E4A08499664A40103CBEBD6BC6444011E4A08499664A40
26118	23039	41.510691000000001	41.545636000000002	53.060468	53.037224000000002	Большая	0103000020E6100000010000000500000047AE9B525EC144402B508BC1C3844A4047AE9B525EC144402E3A596ABD874A4098C28366D7C544402E3A596ABD874A4098C28366D7C544402B508BC1C3844A4047AE9B525EC144402B508BC1C3844A40
26024	24133	41.463160999999999	41.482466000000002	52.86842	52.819735000000001	Совхозная	0103000020E610000001000000050000002EE411DC48BB44407B319413ED684A402EE411DC48BB44409E98F562286F4A404AB72572C1BD44409E98F562286F4A404AB72572C1BD44407B319413ED684A402EE411DC48BB44407B319413ED684A40
9898	23877	41.227758000000001	41.311633	52.966465999999997	52.912830999999997	переулок Школьный	0103000020E6100000010000000500000081B3942C279D444032E36DA5D7744A4081B3942C279D444014596B28B57B4A405CAD1397E3A7444014596B28B57B4A405CAD1397E3A7444032E36DA5D7744A4081B3942C279D444032E36DA5D7744A40
25620	46417	41.442760999999997	41.457304000000001	52.651012000000001	52.644570000000002	мкр.Центральный	0103000020E61000000100000005000000DD787764ACB84440CAFD0E4581524A40DD787764ACB84440DBA6785C54534A403D2AFEEF88BA4440DBA6785C54534A403D2AFEEF88BA4440CAFD0E4581524A40DD787764ACB84440CAFD0E4581524A40
25899	46417	41.444673999999999	41.455174999999997	52.659081	52.649755999999996	мкр. Северный	0103000020E61000000100000005000000D5B0DF13EBB844409C3061342B534A40D5B0DF13EBB844401E3526C45C544A40787AA52C43BA44401E3526C45C544A40787AA52C43BA44409C3061342B534A40D5B0DF13EBB844409C3061342B534A40
26032	46417	41.442760999999997	41.457304000000001	52.651012000000001	52.644570000000002	Центральный	0103000020E61000000100000005000000DD787764ACB84440CAFD0E4581524A40DD787764ACB84440DBA6785C54534A403D2AFEEF88BA4440DBA6785C54534A403D2AFEEF88BA4440CAFD0E4581524A40DD787764ACB84440CAFD0E4581524A40
26288	46417	41.444673999999999	41.455174999999997	52.659081	52.649755999999996	Северный	0103000020E61000000100000005000000D5B0DF13EBB844409C3061342B534A40D5B0DF13EBB844401E3526C45C544A40787AA52C43BA44401E3526C45C544A40787AA52C43BA44409C3061342B534A40D5B0DF13EBB844409C3061342B534A40
25629	23738	40.789918999999998	41.839438999999999	53.216535	52.484369000000001	Филимонова	0103000020E6100000010000000500000098BED7101C6544401E19ABCDFF3D4A4098BED7101C6544403DB83B6BB79B4A4054FEB5BC72EB44403DB83B6BB79B4A4054FEB5BC72EB44401E19ABCDFF3D4A4098BED7101C6544401E19ABCDFF3D4A40
25727	23835	41.746059000000002	41.786006999999998	52.803939	52.768168000000003	Чапаева	0103000020E6100000010000000500000078F17EDC7EDF4440B8EA3A5453624A4078F17EDC7EDF44404E7D2079E7664A40AAB69BE09BE444404E7D2079E7664A40AAB69BE09BE44440B8EA3A5453624A4078F17EDC7EDF4440B8EA3A5453624A40
26137	24243	41.420904999999998	41.456595	52.923734000000003	52.892842000000002	Школьная	0103000020E6100000010000000500000087DC0C37E0B54440643F8BA548724A4087DC0C37E0B54440051A6CEA3C764A40314278B471BA4440051A6CEA3C764A40314278B471BA4440643F8BA548724A4087DC0C37E0B54440643F8BA548724A40
26269	46551	41.221254000000002	41.261381999999998	52.830226000000003	52.792335999999999	Центральная	0103000020E61000000100000005000000FA0D130D529C4440C3B81B446B654A40FA0D130D529C4440FB2477D8446A4A40ACE122F774A14440FB2477D8446A4A40ACE122F774A14440C3B81B446B654A40FA0D130D529C4440C3B81B446B654A40
25886	51174	41.132707000000003	41.183875	52.831135000000003	52.810499	2-я Школьная улица	0103000020E61000000100000005000000A379008BFC9044406938656EBE674A40A379008BFC904440CEC7B5A1626A4A40A8C64B3789974440CEC7B5A1626A4A40A8C64B37899744406938656EBE674A40A379008BFC9044406938656EBE674A40
25515	51174	41.132707000000003	41.183875	52.831135000000003	52.810499	2-я Школьная	0103000020E61000000100000005000000A379008BFC9044406938656EBE674A40A379008BFC904440CEC7B5A1626A4A40A8C64B3789974440CEC7B5A1626A4A40A8C64B37899744406938656EBE674A40A379008BFC9044406938656EBE674A40
25634	46158	41.315810999999997	41.340496000000002	52.762430000000002	52.7288	50 лет Октября	0103000020E61000000100000005000000C85BAE7E6CA8444093A98251495D4A40C85BAE7E6CA84440A1BE654E97614A409C35785F95AB4440A1BE654E97614A409C35785F95AB444093A98251495D4A40C85BAE7E6CA8444093A98251495D4A40
25877	51212	40.789918999999998	41.839438999999999	53.216535	52.484369000000001	Дорожная	0103000020E6100000010000000500000098BED7101C6544401E19ABCDFF3D4A4098BED7101C6544403DB83B6BB79B4A4054FEB5BC72EB44403DB83B6BB79B4A4054FEB5BC72EB44401E19ABCDFF3D4A4098BED7101C6544401E19ABCDFF3D4A40
26250	23554	41.412064999999998	41.436399999999999	52.689708000000003	52.668011	Советская	0103000020E61000000100000005000000C269C18BBEB44440232F6B6281554A40C269C18BBEB4444011E50B5A48584A40B9FC87F4DBB7444011E50B5A48584A40B9FC87F4DBB74440232F6B6281554A40C269C18BBEB44440232F6B6281554A40
25501	23554	41.435519999999997	41.446928999999997	52.695520999999999	52.692005999999999	Садовая	0103000020E6100000010000000500000080608E1EBFB74440615111A793584A4080608E1EBFB74440325706D506594A4026512FF834B94440325706D506594A4026512FF834B94440615111A793584A4080608E1EBFB74440615111A793584A40
26247	45979	41.016950000000001	41.038868999999998	52.562406000000003	52.551997	Центральная	0103000020E6100000010000000500000067D5E76A2B824440BC3E73D6A7464A4067D5E76A2B8244407F8978EBFC474A4003EACDA8F98444407F8978EBFC474A4003EACDA8F9844440BC3E73D6A7464A4067D5E76A2B824440BC3E73D6A7464A40
25368	23099	41.627426999999997	41.71857	52.723804000000001	52.701267000000001	Советская	0103000020E610000001000000050000004ED026874FD04440CC61F71DC3594A404ED026874FD04440645B069CA55C4A4080F10C1AFADB4440645B069CA55C4A4080F10C1AFADB4440CC61F71DC3594A404ED026874FD04440CC61F71DC3594A40
25746	23099	41.627426999999997	41.71857	52.723804000000001	52.701267000000001	Малоталинская	0103000020E610000001000000050000004ED026874FD04440CC61F71DC3594A404ED026874FD04440645B069CA55C4A4080F10C1AFADB4440645B069CA55C4A4080F10C1AFADB4440CC61F71DC3594A404ED026874FD04440CC61F71DC3594A40
25873	22990	41.214776999999998	41.244124999999997	52.860574999999997	52.837173999999997	Советская	0103000020E610000001000000050000006C770FD07D9B4440DF878384286B4A406C770FD07D9B4440AA605452276E4A406891ED7C3F9F4440AA605452276E4A406891ED7C3F9F4440DF878384286B4A406C770FD07D9B4440DF878384286B4A40
26131	24178	41.478000999999999	41.510655	52.880637999999998	52.846860999999997	Интернациональная	0103000020E61000000100000005000000473A03232FBD444001A1F5F0656C4A40473A03232FBD4440B3CEF8BEB8704A40FA449E245DC14440B3CEF8BEB8704A40FA449E245DC1444001A1F5F0656C4A40473A03232FBD444001A1F5F0656C4A40
25741	22733	41.462434000000002	41.489527000000002	52.574409000000003	52.526429	Колхозная	0103000020E610000001000000050000007C478D0931BB44403F55850662434A407C478D0931BB444098C3EE3B86494A4027C11BD2A8BE444098C3EE3B86494A4027C11BD2A8BE44403F55850662434A407C478D0931BB44403F55850662434A40
25859	22776	40.789918999999998	41.839438999999999	53.216535	52.484369000000001	Центральная	0103000020E6100000010000000500000098BED7101C6544401E19ABCDFF3D4A4098BED7101C6544403DB83B6BB79B4A4054FEB5BC72EB44403DB83B6BB79B4A4054FEB5BC72EB44401E19ABCDFF3D4A4098BED7101C6544401E19ABCDFF3D4A40
26109	22378	41.008595999999997	41.052739000000003	52.812328000000001	52.781405999999997	Школьная	0103000020E610000001000000050000002E7079AC19814440F7729F1C05644A402E7079AC1981444003D0285DFA674A40A41CCC26C086444003D0285DFA674A40A41CCC26C0864440F7729F1C05644A402E7079AC19814440F7729F1C05644A40
25642	22897	41.299039	41.313206000000001	52.807347	52.796039	Ново-Южная	0103000020E61000000100000005000000419DF2E846A6444097AB1F9BE4654A40419DF2E846A6444009C3802557674A409B745B2217A8444009C3802557674A409B745B2217A8444097AB1F9BE4654A40419DF2E846A6444097AB1F9BE4654A40
25521	440	41.213582000000002	41.250870999999997	52.896003999999998	52.857590000000002	Молодежная	0103000020E61000000100000005000000D481ACA7569B444036B05582C56D4A40D481ACA7569B4440E78A5242B0724A40E5417A8A1CA04440E78A5242B0724A40E5417A8A1CA0444036B05582C56D4A40D481ACA7569B444036B05582C56D4A40
26263	23930	41.385357999999997	41.424182999999999	52.937466999999998	52.922435999999998	Школьная	0103000020E6100000010000000500000040A0336953B144409753026212764A4040A0336953B14440240A2DEBFE774A407442E8A04BB64440240A2DEBFE774A407442E8A04BB644409753026212764A4040A0336953B144409753026212764A40
25771	45374	40.858953999999997	40.884242	52.614502000000002	52.588400999999998	Центральная	0103000020E610000001000000050000005A626534F26D444083F755B9504B4A405A626534F26D4440CEA96400A84E4A40F4DF83D72E714440CEA96400A84E4A40F4DF83D72E71444083F755B9504B4A405A626534F26D444083F755B9504B4A40
25520	45607	41.486122000000002	41.490650000000002	52.775114000000002	52.774270000000001	Школьная	0103000020E61000000100000005000000DDEEE53E39BE4440102384471B634A40DDEEE53E39BE4440FC5580EF36634A4026E4839ECDBE4440FC5580EF36634A4026E4839ECDBE4440102384471B634A40DDEEE53E39BE4440102384471B634A40
26053	45607	41.474497999999997	41.497971	52.789504999999998	52.758049	Советская	0103000020E610000001000000050000003A02B859BCBC4440FCE1E7BF07614A403A02B859BCBC4440A583F57F0E654A409FAD8383BDBF4440A583F57F0E654A409FAD8383BDBF4440FCE1E7BF07614A403A02B859BCBC4440FCE1E7BF07614A40
25380	24027	41.523690000000002	41.538539	52.855485999999999	52.843266	Интернациональная	0103000020E61000000100000005000000029F1F4608C3444014EAE923F06B4A40029F1F4608C34440CA17B490806D4A406E4F90D8EEC44440CA17B490806D4A406E4F90D8EEC4444014EAE923F06B4A40029F1F4608C3444014EAE923F06B4A40
26232	45576	41.473824	41.515442999999998	52.958612000000002	52.909208999999997	переулок Школьный	0103000020E61000000100000005000000AB07CC43A6BC44404B1DE4F560744A40AB07CC43A6BC4440CEC64ACCB37A4A40DFF94509FAC14440CEC64ACCB37A4A40DFF94509FAC144404B1DE4F560744A40AB07CC43A6BC44404B1DE4F560744A40
25709	45576	41.473824	41.515442999999998	52.958612000000002	52.909208999999997	Ленина	0103000020E61000000100000005000000AB07CC43A6BC44404B1DE4F560744A40AB07CC43A6BC4440CEC64ACCB37A4A40DFF94509FAC14440CEC64ACCB37A4A40DFF94509FAC144404B1DE4F560744A40AB07CC43A6BC44404B1DE4F560744A40
26116	45736	41.308624000000002	41.320993999999999	52.616394	52.602493000000003	Центральная 	0103000020E610000001000000050000005F61C1FD80A74440D388997D1E4D4A405F61C1FD80A74440AEB9A3FFE54E4A402A1BD65416A94440AEB9A3FFE54E4A402A1BD65416A94440D388997D1E4D4A405F61C1FD80A74440D388997D1E4D4A40
26253	23824	41.787768	41.839438999999999	52.857520000000001	52.822744999999998	 2-я Советская	0103000020E61000000100000005000000EC6AF294D5E4444048F949B54F694A40EC6AF294D5E444403DD52137C36D4A4054FEB5BC72EB44403DD52137C36D4A4054FEB5BC72EB444048F949B54F694A40EC6AF294D5E4444048F949B54F694A40
26073	45502	41.300987999999997	41.350476999999998	52.566215999999997	52.527940999999998	Советская	0103000020E61000000100000005000000853E58C686A64440D89B189293434A40853E58C686A64440683C11C479484A4006802A6EDCAC4440683C11C479484A4006802A6EDCAC4440D89B189293434A40853E58C686A64440D89B189293434A40
25985	22313	41.098086000000002	41.184441	52.796061000000002	52.777968999999999	Школьная	0103000020E61000000100000005000000051901158E8C4440A226FA7C94634A40051901158E8C44407F4FAC53E5654A4051853FC39B9744407F4FAC53E5654A4051853FC39B974440A226FA7C94634A40051901158E8C4440A226FA7C94634A40
25772	22197	41.036093000000001	41.086489	52.715006000000002	52.685957999999999	Центральная	0103000020E61000000100000005000000A94E07B29E844440FC36C478CD574A40A94E07B29E844440CE380D51855B4A405C3B5112128B4440CE380D51855B4A405C3B5112128B4440FC36C478CD574A40A94E07B29E844440FC36C478CD574A40
26267	45343	40.882624999999997	40.902495999999999	52.647046000000003	52.631149000000001	Молодежная	0103000020E61000000100000005000000E5D022DBF970444099F38C7DC9504A40E5D022DBF9704440FA804067D2524A40AA622AFD84734440FA804067D2524A40AA622AFD8473444099F38C7DC9504A40E5D022DBF970444099F38C7DC9504A40
25737	22652	41.472602999999999	41.474884000000003	52.761814000000001	52.758065000000002	переулок Совхозный	0103000020E61000000100000005000000E97E4E417EBC4440029F1F4608614A40E97E4E417EBC444046D1031F83614A4064B2B8FFC8BC444046D1031F83614A4064B2B8FFC8BC4440029F1F4608614A40E97E4E417EBC4440029F1F4608614A40
26305	17681	40.516013999999998	40.549124999999997	53.453999000000003	53.438811000000001	Молодежная	0103000020E610000001000000050000009A232BBF0C424440021077F52AB84A409A232BBF0C42444057B5A4A31CBA4A403F355EBA4946444057B5A4A31CBA4A403F355EBA49464440021077F52AB84A409A232BBF0C424440021077F52AB84A40
25818	5796	40.661288999999996	40.733567999999998	53.352997999999999	53.297058999999997	Элеваторная	0103000020E610000001000000050000002E1A321EA5544440C1FD800706A64A402E1A321EA5544440D6C6D8092FAD4A4031B2648EE55D4440D6C6D8092FAD4A4031B2648EE55D4440C1FD800706A64A402E1A321EA5544440C1FD800706A64A40
26058	5796	40.661288999999996	40.733567999999998	53.352997999999999	53.297058999999997	Советская	0103000020E610000001000000050000002E1A321EA5544440C1FD800706A64A402E1A321EA5544440D6C6D8092FAD4A4031B2648EE55D4440D6C6D8092FAD4A4031B2648EE55D4440C1FD800706A64A402E1A321EA5544440C1FD800706A64A40
25416	5796	40.661288999999996	40.733567999999998	53.352997999999999	53.297058999999997	Московская	0103000020E610000001000000050000002E1A321EA5544440C1FD800706A64A402E1A321EA5544440D6C6D8092FAD4A4031B2648EE55D4440D6C6D8092FAD4A4031B2648EE55D4440C1FD800706A64A402E1A321EA5544440C1FD800706A64A40
26141	5796	40.661288999999996	40.733567999999998	53.352997999999999	53.297058999999997	Ломоносова	0103000020E610000001000000050000002E1A321EA5544440C1FD800706A64A402E1A321EA5544440D6C6D8092FAD4A4031B2648EE55D4440D6C6D8092FAD4A4031B2648EE55D4440C1FD800706A64A402E1A321EA5544440C1FD800706A64A40
25645	5796	40.661288999999996	40.733567999999998	53.352997999999999	53.297058999999997	Заречная	0103000020E610000001000000050000002E1A321EA5544440C1FD800706A64A402E1A321EA5544440D6C6D8092FAD4A4031B2648EE55D4440D6C6D8092FAD4A4031B2648EE55D4440C1FD800706A64A402E1A321EA5544440C1FD800706A64A40
26278	51251	40.595388999999997	40.616652000000002	53.285291999999998	53.265524999999997	Центральная	0103000020E61000000100000005000000F6B2EDB4354C44409CA223B9FCA14A40F6B2EDB4354C4440BCE7C07284A44A40AA81E673EE4E4440BCE7C07284A44A40AA81E673EE4E44409CA223B9FCA14A40F6B2EDB4354C44409CA223B9FCA14A40
26303	17584	40.441732000000002	40.473298999999997	53.414388000000002	53.398744999999998	Уваркина	0103000020E6100000010000000500000060CC96AC8A384440C5387F130AB34A4060CC96AC8A3844406CED7DAA0AB54A40601DC70F953C44406CED7DAA0AB54A40601DC70F953C4440C5387F130AB34A4060CC96AC8A384440C5387F130AB34A40
26302	17671	40.506680000000003	40.538552000000003	53.398578999999998	53.382581999999999	Центральная	0103000020E61000000100000005000000C6C4E6E3DA404440E6046D72F8B04A40C6C4E6E3DA404440AAEFFCA204B34A4003999D45EF444440AAEFFCA204B34A4003999D45EF444440E6046D72F8B04A40C6C4E6E3DA404440E6046D72F8B04A40
25445	8660	40.726965	40.756672000000002	53.285648000000002	53.270001000000001	Школьная	0103000020E61000000100000005000000172B6A300D5D444093718C648FA24A40172B6A300D5D44407B15191D90A44A4043E6CAA0DA6044407B15191D90A44A4043E6CAA0DA60444093718C648FA24A40172B6A300D5D444093718C648FA24A40
25858	17514	40.817703999999999	40.881835000000002	53.337344000000002	53.319662000000001	Пажа	0103000020E6100000010000000500000079E75086AA68444011E335AFEAA84A4079E75086AA6844403CC093162EAB4A40EDBB22F8DF7044403CC093162EAB4A40EDBB22F8DF70444011E335AFEAA84A4079E75086AA68444011E335AFEAA84A40
25940	17365	40.718521000000003	40.758369999999999	53.276468000000001	53.251519999999999	Центральная	0103000020E610000001000000050000009F3E027FF85B44401C25AFCE31A04A409F3E027FF85B4440FD31AD4D63A34A403E22A64412614440FD31AD4D63A34A403E22A644126144401C25AFCE31A04A409F3E027FF85B44401C25AFCE31A04A40
25688	17365	40.718521000000003	40.758369999999999	53.276468000000001	53.251519999999999	Рабочая	0103000020E610000001000000050000009F3E027FF85B44401C25AFCE31A04A409F3E027FF85B4440FD31AD4D63A34A403E22A64412614440FD31AD4D63A34A403E22A644126144401C25AFCE31A04A409F3E027FF85B44401C25AFCE31A04A40
25935	17217	40.834924000000001	40.928699999999999	53.389048000000003	53.344822999999998	Советская	0103000020E61000000100000005000000A05225CADE6A44404DF4F92823AC4A40A05225CADE6A444080492A53CCB14A40C9E53FA4DF76444080492A53CCB14A40C9E53FA4DF7644404DF4F92823AC4A40A05225CADE6A44404DF4F92823AC4A40
26095	17217	40.834924000000001	40.928699999999999	53.389048000000003	53.344822999999998	Бутырская	0103000020E61000000100000005000000A05225CADE6A44404DF4F92823AC4A40A05225CADE6A444080492A53CCB14A40C9E53FA4DF76444080492A53CCB14A40C9E53FA4DF7644404DF4F92823AC4A40A05225CADE6A44404DF4F92823AC4A40
26193	5722	40.584465000000002	40.609276999999999	53.353805000000001	53.310242000000002	Центральная	0103000020E610000001000000050000000D54C6BFCF4A44403EEC8502B6A74A400D54C6BFCF4A4440A514747B49AD4A403D9AEAC9FC4D4440A514747B49AD4A403D9AEAC9FC4D44403EEC8502B6A74A400D54C6BFCF4A44403EEC8502B6A74A40
25953	17453	40.774566999999998	40.794913999999999	53.218848000000001	53.210608000000001	Школьная	0103000020E61000000100000005000000C9C7EE02256344405323F433F59A4A40C9C7EE0225634440C3651536039C4A40F790F0BDBF654440C3651536039C4A40F790F0BDBF6544405323F433F59A4A40C9C7EE02256344405323F433F59A4A40
25566	17070	40.591929999999998	40.641956999999998	53.503086000000003	53.441262000000002	Кончанка	0103000020E61000000100000005000000B9C2BB5CC44B4440D97BF1457BB84A40B9C2BB5CC44B4440A9893E1F65C04A401938A0A52B524440A9893E1F65C04A401938A0A52B524440D97BF1457BB84A40B9C2BB5CC44B4440D97BF1457BB84A40
26370	17462	40.863211999999997	40.902836999999998	53.300761000000001	53.289276000000001	школьная	0103000020E61000000100000005000000E3C116BB7D6E444044C2F7FE06A54A40E3C116BB7D6E4440C57421567FA64A40334FAE2990734440C57421567FA64A40334FAE299073444044C2F7FE06A54A40E3C116BB7D6E444044C2F7FE06A54A40
26064	16881	40.623649999999998	40.671638000000002	53.414307000000001	53.373283000000001	Школьная	0103000020E61000000100000005000000401361C3D34F44408E93C2BCC7AF4A40401361C3D34F44407FC0030308B54A401C60E63BF85544407FC0030308B54A401C60E63BF85544408E93C2BCC7AF4A40401361C3D34F44408E93C2BCC7AF4A40
25421	16925	40.674889999999998	40.707543000000001	53.235596999999999	53.214761000000003	Центр	0103000020E61000000100000005000000DF32A7CB6256444067BAD7497D9B4A40DF32A7CB625644409204E10A289E4A40C2C1DEC4905A44409204E10A289E4A40C2C1DEC4905A444067BAD7497D9B4A40DF32A7CB6256444067BAD7497D9B4A40
25565	16925	40.674889999999998	40.707543000000001	53.235596999999999	53.214761000000003	Племзавод	0103000020E61000000100000005000000DF32A7CB6256444067BAD7497D9B4A40DF32A7CB625644409204E10A289E4A40C2C1DEC4905A44409204E10A289E4A40C2C1DEC4905A444067BAD7497D9B4A40DF32A7CB6256444067BAD7497D9B4A40
26282	51252	40.659770999999999	40.689675999999999	53.409948999999997	53.376871999999999	Совхозная	0103000020E61000000100000005000000B3EC496073544440996379573DB04A40B3EC4960735444409203763579B44A40056B9C4D475844409203763579B44A40056B9C4D47584440996379573DB04A40B3EC496073544440996379573DB04A40
26293	17161	40.547508999999998	40.573596000000002	53.339092000000001	53.323599000000002	Сельскохозяйственная	0103000020E6100000010000000500000001A260C614464440580229B16BA94A4001A260C614464440E92ADD5D67AB4A40E78EFE976B494440E92ADD5D67AB4A40E78EFE976B494440580229B16BA94A4001A260C614464440580229B16BA94A40
26287	51253	41.162019000000001	41.208103000000001	52.969942000000003	52.950592999999998	Центральная	0103000020E61000000100000005000000522AE109BD9444403C670B08AD794A40522AE109BD9444402882380F277C4A4089997D1EA39A44402882380F277C4A4089997D1EA39A44403C670B08AD794A40522AE109BD9444403C670B08AD794A40
25657	47620	41.273167999999998	41.296793000000001	53.031028999999997	53.009188000000002	Октябрьская	0103000020E610000001000000050000002828452BF7A2444001C287122D814A402828452BF7A24440211D1EC2F8834A4043572250FDA54440211D1EC2F8834A4043572250FDA5444001C287122D814A402828452BF7A2444001C287122D814A40
25860	47762	40.905137000000003	40.931826000000001	53.263209000000003	53.247247000000002	Молодежная	0103000020E6100000010000000500000025B37A87DB7344405E8429CAA59F4A4025B37A87DB734440A6811FD5B0A14A4000C8091346774440A6811FD5B0A14A4000C80913467744405E8429CAA59F4A4025B37A87DB7344405E8429CAA59F4A40
25870	16570	41.361328	41.406692999999997	53.378182000000002	53.342446000000002	Московская	0103000020E610000001000000050000008690F3FE3FAE4440B1524145D5AB4A408690F3FE3FAE4440CBF78C4468B04A408D4127840EB44440CBF78C4468B04A408D4127840EB44440B1524145D5AB4A408690F3FE3FAE4440B1524145D5AB4A40
25788	15585	41.337657999999998	41.371380000000002	53.105741000000002	53.082526000000001	Полевая	0103000020E61000000100000005000000CB9D996038AB4440EC884336908A4A40CB9D996038AB4440556CCCEB888D4A40BA313D6189AF4440556CCCEB888D4A40BA313D6189AF4440EC884336908A4A40CB9D996038AB4440EC884336908A4A40
25396	15403	41.264004999999997	41.318452000000001	53.209448999999999	53.193142999999999	Интернациональная	0103000020E61000000100000005000000807D74EACAA14440C539EAE8B8984A40807D74EACAA1444007978E39CF9A4A4043ACFE08C3A8444007978E39CF9A4A4043ACFE08C3A84440C539EAE8B8984A40807D74EACAA14440C539EAE8B8984A40
25789	47176	41.196936999999998	41.238232000000004	53.137796999999999	53.101010000000002	Советская	0103000020E61000000100000005000000A92F4B3B35994440D4484BE5ED8C4A40A92F4B3B35994440533E0455A3914A402B6EDC627E9E4440533E0455A3914A402B6EDC627E9E4440D4484BE5ED8C4A40A92F4B3B35994440D4484BE5ED8C4A40
26087	16676	41.475530999999997	41.515658999999999	53.261319	53.238624999999999	Ленина	0103000020E61000000100000005000000F99D2633DEBC4440068195438B9E4A40F99D2633DEBC44406669A7E672A14A40AC71361D01C244406669A7E672A14A40AC71361D01C24440068195438B9E4A40F99D2633DEBC4440068195438B9E4A40
26085	45623	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	Прогресс	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
25404	45623	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	Набережная	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
26295	45623	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	Мичурина	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
75018	45623	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	Красноармейская	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
75016	45623	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	Котовского	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
25987	45623	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	Интернациональная	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
26029	45623	41.329464999999999	41.402489000000003	53.260995999999999	53.201093999999998	Высотная	0103000020E610000001000000050000009C16BCE82BAA4440FEB5BC72BD994A409C16BCE82BAA44408331225168A14A40F8FF71C284B344408331225168A14A40F8FF71C284B34440FEB5BC72BD994A409C16BCE82BAA4440FEB5BC72BD994A40
26264	46579	41.196936999999998	41.238232000000004	53.137796999999999	53.101010000000002	Мира	0103000020E61000000100000005000000A92F4B3B35994440D4484BE5ED8C4A40A92F4B3B35994440533E0455A3914A402B6EDC627E9E4440533E0455A3914A402B6EDC627E9E4440D4484BE5ED8C4A40A92F4B3B35994440D4484BE5ED8C4A40
25910	15150	41.555309999999999	41.578648999999999	53.153109000000001	53.132482000000003	Колхозная	0103000020E610000001000000050000002592E86514C7444083A7902BF5904A402592E86514C7444094DC611399934A407A6EA12B11CA444094DC611399934A407A6EA12B11CA444083A7902BF5904A402592E86514C7444083A7902BF5904A40
26153	16620	41.461112999999997	41.512757000000001	53.353051999999998	53.321238000000001	Интернациональная	0103000020E61000000100000005000000566133C005BB4440C11DA8531EA94A40566133C005BB4440C9E4D4CE30AD4A40C5E57805A2C14440C9E4D4CE30AD4A40C5E57805A2C14440C11DA8531EA94A40566133C005BB4440C11DA8531EA94A40
26014	15449	41.252811999999999	41.331262000000002	53.240532999999999	53.207248	Центральная	0103000020E61000000100000005000000A704C4245CA04440A9143B1A879A4A40A704C4245CA04440EC4D0CC9C99E4A402B3410CB66AA4440EC4D0CC9C99E4A402B3410CB66AA4440A9143B1A879A4A40A704C4245CA04440A9143B1A879A4A40
25647	45993	41.217300999999999	41.228090000000002	53.255862	53.250798000000003	Клубная	0103000020E61000000100000005000000AD31E884D09B44407CF31B261AA04A40AD31E884D09B444003250516C0A04A40B745990D329D444003250516C0A04A40B745990D329D44407CF31B261AA04A40AD31E884D09B44407CF31B261AA04A40
26270	16459	41.014569999999999	41.057509000000003	53.418300000000002	53.383425000000003	Пролетарская	0103000020E6100000010000000500000059C0046EDD81444002BC051214B14A4059C0046EDD8144405AF5B9DA8AB54A40E31C75745C8744405AF5B9DA8AB54A40E31C75745C87444002BC051214B14A4059C0046EDD81444002BC051214B14A40
26168	47601	41.215181000000001	41.264454000000001	53.173451999999997	53.140920000000001	Советская бригада №2	0103000020E610000001000000050000003CDC0E0D8B9B444019ADA3AA09924A403CDC0E0D8B9B444080B6D5AC33964A40F0A5F0A0D9A1444080B6D5AC33964A40F0A5F0A0D9A1444019ADA3AA09924A403CDC0E0D8B9B444019ADA3AA09924A40
25911	15285	41.522548999999998	41.572594000000002	53.134464000000001	53.087420999999999	Центральная	0103000020E610000001000000050000005CC7B8E2E2C24440E7FD7F9C308B4A405CC7B8E2E2C24440A33EC91D36914A4063F19BC24AC94440A33EC91D36914A4063F19BC24AC94440E7FD7F9C308B4A405CC7B8E2E2C24440E7FD7F9C308B4A40
25912	15392	41.251842000000003	41.276321000000003	53.192495000000001	53.172722999999998	Пролетарская	0103000020E610000001000000050000002FE1D05B3CA044402D228AC91B964A402FE1D05B3CA044405FD218ADA3984A4059198D7C5EA344405FD218ADA3984A4059198D7C5EA344402D228AC91B964A402FE1D05B3CA044402D228AC91B964A40
25415	16784	41.621946999999999	41.696939	53.249090000000002	53.225467999999999	Захарова	0103000020E61000000100000005000000336C94F59BCF4440B325AB22DC9C4A40336C94F59BCF44405DE15D2EE29F4A404A27124C35D944405DE15D2EE29F4A404A27124C35D94440B325AB22DC9C4A40336C94F59BCF4440B325AB22DC9C4A40
25405	47884	41.191771000000003	41.226886	53.304065000000001	53.276634999999999	Советская	0103000020E610000001000000050000001EA9BEF38B984440E8F692C668A34A401EA9BEF38B984440DB6D179AEBA64A40CBF5B6990A9D4440DB6D179AEBA64A40CBF5B6990A9D4440E8F692C668A34A401EA9BEF38B984440E8F692C668A34A40
26151	16364	41.176374000000003	41.220275000000001	53.440061	53.417403999999998	Слободская	0103000020E61000000100000005000000AFEE586C939644401B9C887E6DB54A40AFEE586C939644405E9F39EB53B84A402E90A0F8319C44405E9F39EB53B84A402E90A0F8319C44401B9C887E6DB54A40AFEE586C939644401B9C887E6DB54A40
25407	16776	41.448276	41.476438000000002	53.250545000000002	53.227004999999998	Молодежная	0103000020E6100000010000000500000075CAA31B61B94440A583F57F0E9D4A4075CAA31B61B944409296CADB11A04A402C499EEBFBBC44409296CADB11A04A402C499EEBFBBC4440A583F57F0E9D4A4075CAA31B61B94440A583F57F0E9D4A40
25918	51219	41.258893	41.290154999999999	53.048457999999997	53.022688000000002	Ленинская	0103000020E61000000100000005000000E814E46723A144407E01BD70E7824A40E814E46723A14440629D2ADF33864A40ACE28DCC23A54440629D2ADF33864A40ACE28DCC23A544407E01BD70E7824A40E814E46723A144407E01BD70E7824A40
26134	16150	40.973039999999997	40.996369999999999	53.162908999999999	53.145414000000002	Молодежная	0103000020E6100000010000000500000094D920938C7C4440B6300BED9C924A4094D920938C7C4440AE9CBD33DA944A40965B5A0D897F4440AE9CBD33DA944A40965B5A0D897F4440B6300BED9C924A4094D920938C7C4440B6300BED9C924A40
25759	16066	40.987126000000004	41.011785000000003	53.203235999999997	53.187834000000002	Молодежная	0103000020E6100000010000000500000002840F255A7E4440D789CBF10A984A4002840F255A7E444057AF22A3039A4A40ACCABE2B8281444057AF22A3039A4A40ACCABE2B82814440D789CBF10A984A4002840F255A7E4440D789CBF10A984A40
25511	15967	41.020336999999998	41.075609999999998	53.257904000000003	53.229813	Половинкина	0103000020E610000001000000050000000AF31E679A8244400B992B836A9D4A400AF31E679A824440F9C08EFF02A14A4012A0A696AD894440F9C08EFF02A14A4012A0A696AD8944400B992B836A9D4A400AF31E679A8244400B992B836A9D4A40
26048	51227	41.493470000000002	41.516773000000001	53.139521000000002	53.119599999999998	Бахмут	0103000020E6100000010000000500000050C763062ABF4440014D840D4F8F4A4050C763062ABF4440780DFAD2DB914A40583A1F9E25C24440780DFAD2DB914A40583A1F9E25C24440014D840D4F8F4A4050C763062ABF4440014D840D4F8F4A40
26031	15016	41.366951999999998	41.379519000000002	53.322350999999998	53.301504000000001	Интернациональная	0103000020E61000000100000005000000D4997B48F8AE44407DCEDDAE97A64A40D4997B48F8AE44409C6A2DCC42A94A40F69A1E1494B044409C6A2DCC42A94A40F69A1E1494B044407DCEDDAE97A64A40D4997B48F8AE44407DCEDDAE97A64A40
25531	47553	41.184108999999999	41.216825	52.997093	52.977837999999998	Центральная	0103000020E610000001000000050000001BF33AE2909744409D64ABCB297D4A401BF33AE290974440070951BEA07F4A4044FAEDEBC09B4440070951BEA07F4A4044FAEDEBC09B44409D64ABCB297D4A401BF33AE2909744409D64ABCB297D4A40
25539	47692	40.917290999999999	40.948903000000001	53.216788000000001	53.193967999999998	Центральная	0103000020E6100000010000000500000023F59ECA697544403A3C84F1D3984A4023F59ECA6975444027158DB5BF9B4A40C4094CA77579444027158DB5BF9B4A40C4094CA7757944403A3C84F1D3984A4023F59ECA697544403A3C84F1D3984A40
25680	49251	41.584209000000001	41.605733000000001	53.111865000000002	53.093462000000002	Новая	0103000020E61000000100000005000000B2834A5CC7CA44409AB51490F68B4A40B2834A5CC7CA44409548A297518E4A40D28DB0A888CD44409548A297518E4A40D28DB0A888CD44409AB51490F68B4A40B2834A5CC7CA44409AB51490F68B4A40
25801	16468	41.284405999999997	41.324255000000001	53.391582	53.358147000000002	Советская	0103000020E61000000100000005000000A164726A67A444408C14CAC2D7AD4A40A164726A67A44440E4D9E55B1FB24A404148163081A94440E4D9E55B1FB24A404148163081A944408C14CAC2D7AD4A40A164726A67A444408C14CAC2D7AD4A40
26280	47551	41.191052999999997	41.227640999999998	53.034115999999997	53.017569000000002	Ленинская	0103000020E61000000100000005000000BE66B96C74984440333674B33F824A40BE66B96C749844409A22C0E95D844A40471D1D57239D44409A22C0E95D844A40471D1D57239D4440333674B33F824A40BE66B96C74984440333674B33F824A40
9931	15959	41.051777999999999	41.086174	53.291471999999999	53.260596999999997	Больничная	0103000020E610000001000000050000007E5358A9A0864440C537143E5BA14A407E5358A9A086444090D959F44EA54A40FCE1E7BF078B444090D959F44EA54A40FCE1E7BF078B4440C537143E5BA14A407E5358A9A0864440C537143E5BA14A40
26034	15091	41.453710999999998	41.498564000000002	53.191071000000001	53.171131000000003	Тамбовская	0103000020E61000000100000005000000F06AB93313BA4440782AE09EE7954A40F06AB93313BA4440651BB80375984A40427BF5F1D0BF4440651BB80375984A40427BF5F1D0BF4440782AE09EE7954A40F06AB93313BA4440782AE09EE7954A40
25389	16309	41.091151000000004	41.148975999999998	53.398105999999999	53.348215000000003	Школьная	0103000020E61000000100000005000000B5FF01D6AA8B4440037D224F92AC4A40B5FF01D6AA8B4440B22B2D23F5B24A40C7F143A511934440B22B2D23F5B24A40C7F143A511934440037D224F92AC4A40B5FF01D6AA8B4440037D224F92AC4A40
25790	51202	41.369484999999997	41.411346000000002	53.147373999999999	53.1158	Школьная	0103000020E6100000010000000500000068AED3484BAF44403B70CE88D28E4A4068AED3484BAF4440EE23B726DD924A4093AB58FCA6B44440EE23B726DD924A4093AB58FCA6B444403B70CE88D28E4A4068AED3484BAF44403B70CE88D28E4A40
25753	13867	41.541153000000001	41.602418	52.352038	52.317264999999999	Советская	0103000020E61000000100000005000000EF90628044C544402D95B7239C284A40EF90628044C544408179C8940F2D4A40C84274081CCD44408179C8940F2D4A40C84274081CCD44402D95B7239C284A40EF90628044C544402D95B7239C284A40
25854	13964	41.647181000000003	41.664158999999998	52.404809	52.396000999999998	Ленина	0103000020E61000000100000005000000DACBB6D3D6D2444076172829B0324A40DACBB6D3D6D24440301004C8D0334A400A2C802903D54440301004C8D0334A400A2C802903D5444076172829B0324A40DACBB6D3D6D2444076172829B0324A40
25506	14352	41.725811	41.812398999999999	52.257829999999998	52.238725000000002	Школьная	0103000020E61000000100000005000000DD09F65FE7DC44406ADE718A8E1E4A40DD09F65FE7DC4440BEF6CC9200214A40CC26C0B0FCE74440BEF6CC9200214A40CC26C0B0FCE744406ADE718A8E1E4A40DD09F65FE7DC44406ADE718A8E1E4A40
25510	5587	41.65249	41.699122000000003	52.387427000000002	52.369070999999998	Олимпийская	0103000020E61000000100000005000000C87BD5CA84D344407573F1B73D2F4A40C87BD5CA84D34440304B3B3597314A4002F566D47CD94440304B3B3597314A4002F566D47CD944407573F1B73D2F4A40C87BD5CA84D344407573F1B73D2F4A40
25490	13860	41.608517999999997	41.640453000000001	52.330497999999999	52.296010000000003	Советская	0103000020E610000001000000050000007F83F6EAE3CD4440FDA4DAA7E3254A407F83F6EAE3CD44405BB22AC24D2A4A4003D0285DFAD144405BB22AC24D2A4A4003D0285DFAD14440FDA4DAA7E3254A407F83F6EAE3CD4440FDA4DAA7E3254A40
25633	14436	41.653486999999998	41.730409999999999	52.259506000000002	52.234637999999997	Придорожная	0103000020E610000001000000050000003AAE4676A5D344400D33349E081E4A403AAE4676A5D34440D28E1B7E37214A40EF552B137EDD4440D28E1B7E37214A40EF552B137EDD44400D33349E081E4A403AAE4676A5D344400D33349E081E4A40
25890	14578	41.642887000000002	41.665489000000001	52.421250000000001	52.404313999999999	Школьная	0103000020E610000001000000050000000403081F4AD2444050A8A78FC0334A400403081F4AD2444052B81E85EB354A40836C59BE2ED5444052B81E85EB354A40836C59BE2ED5444050A8A78FC0334A400403081F4AD2444050A8A78FC0334A40
26252	14533	41.765237999999997	41.781748999999998	52.406599999999997	52.395994999999999	Центральная	0103000020E6100000010000000500000006D49B51F3E144409430D3F6AF324A4006D49B51F3E14440DC4603780B344A402157EA5910E44440DC4603780B344A402157EA5910E444409430D3F6AF324A4006D49B51F3E144409430D3F6AF324A40
25592	14533	41.765237999999997	41.781748999999998	52.406599999999997	52.395994999999999	Рабочая	0103000020E6100000010000000500000006D49B51F3E144409430D3F6AF324A4006D49B51F3E14440DC4603780B344A402157EA5910E44440DC4603780B344A402157EA5910E444409430D3F6AF324A4006D49B51F3E144409430D3F6AF324A40
25503	14252	41.540577999999996	41.591934999999999	52.104348000000002	52.074893000000003	Театральная	0103000020E61000000100000005000000F277EFA831C5444084D9041896094A40F277EFA831C5444096B377465B0D4A40CB2DAD86C4CB444096B377465B0D4A40CB2DAD86C4CB444084D9041896094A40F277EFA831C5444084D9041896094A40
25891	51214	41.720708000000002	41.774428	52.318972000000002	52.291184999999999	Центральная	0103000020E6100000010000000500000098FBE42840DC4440FA0AD28C45254A4098FBE42840DC44407C2B1213D4284A40A88DEA7420E344407C2B1213D4284A40A88DEA7420E34440FA0AD28C45254A4098FBE42840DC4440FA0AD28C45254A40
26125	14444	41.843795	41.884318	52.342399999999998	52.329264999999999	Центральная	0103000020E61000000100000005000000A0C37C7901EC4440D55B035B252A4A40A0C37C7901EC4440401361C3D32B4A40CFA10C5531F14440401361C3D32B4A40CFA10C5531F14440D55B035B252A4A40A0C37C7901EC4440D55B035B252A4A40
25562	4426	41.519053999999997	41.533346999999999	52.209463999999997	52.202665000000003	Садовая	0103000020E61000000100000005000000D26D895C70C244409D853DEDF0194A40D26D895C70C244403CD862B7CF1A4A40B935E9B644C444403CD862B7CF1A4A40B935E9B644C444409D853DEDF0194A40D26D895C70C244409D853DEDF0194A40
25636	4426	41.519053999999997	41.533346999999999	52.209463999999997	52.202665000000003	Кооперативная	0103000020E61000000100000005000000D26D895C70C244409D853DEDF0194A40D26D895C70C244403CD862B7CF1A4A40B935E9B644C444403CD862B7CF1A4A40B935E9B644C444409D853DEDF0194A40D26D895C70C244409D853DEDF0194A40
25777	14078	41.567113999999997	41.901431000000002	52.351978000000003	52.236238	Олимпийская	0103000020E61000000100000005000000478D093197C844404609FA0B3D1E4A40478D093197C84440AC74779D0D2D4A40E04C4C1762F34440AC74779D0D2D4A40E04C4C1762F344404609FA0B3D1E4A40478D093197C844404609FA0B3D1E4A40
26013	14078	41.567113999999997	41.901431000000002	52.351978000000003	52.236238	Гагарина	0103000020E61000000100000005000000478D093197C844404609FA0B3D1E4A40478D093197C84440AC74779D0D2D4A40E04C4C1762F34440AC74779D0D2D4A40E04C4C1762F344404609FA0B3D1E4A40478D093197C844404609FA0B3D1E4A40
25466	14300	41.808616999999998	41.850774999999999	52.264671	52.238526999999998	Центральная	0103000020E61000000100000005000000ACFE08C380E74440431B800D881E4A40ACFE08C380E744408D9944BDE0214A4090A0F831E6EC44408D9944BDE0214A4090A0F831E6EC4440431B800D881E4A40ACFE08C380E74440431B800D881E4A40
26136	14154	41.618991999999999	41.668309999999998	52.221432	52.155476	Школьная	0103000020E61000000100000005000000293E3E213BCF44400DA837A3E6134A40293E3E213BCF4440D9243FE2571C4A407DCB9C2E8BD54440D9243FE2571C4A407DCB9C2E8BD544400DA837A3E6134A40293E3E213BCF44400DA837A3E6134A40
75364	46451	41.706434000000002	41.720267999999997	52.431283000000001	52.423105999999997	Парковая	0103000020E610000001000000050000002864E76D6CDA4440E55E605628364A402864E76D6CDA44400F29064834374A407B2DE8BD31DC44400F29064834374A407B2DE8BD31DC4440E55E605628364A402864E76D6CDA4440E55E605628364A40
25590	4529	41.630571000000003	41.670276999999999	52.141494999999999	52.128177999999998	Школьная	0103000020E610000001000000050000002C67EF8CB6D044408908FF2268104A402C67EF8CB6D0444015C616821C124A40682101A3CBD5444015C616821C124A40682101A3CBD544408908FF2268104A402C67EF8CB6D044408908FF2268104A40
26225	13589	41.944299000000001	41.962912000000003	52.246346000000003	52.222591000000001	Зеленая	0103000020E61000000100000005000000A05225CADEF8444025B1A4DC7D1C4A40A05225CADEF844400EC00644881F4A4086764EB340FB44400EC00644881F4A4086764EB340FB444025B1A4DC7D1C4A40A05225CADEF8444025B1A4DC7D1C4A40
26122	46531	42.016461	42.032451000000002	52.353326000000003	52.337524999999999	Мичуринская	0103000020E610000001000000050000006954E0641B0245408C4AEA04342B4A406954E0641B024540CB694FC9392D4A407BDCB75A27044540CB694FC9392D4A407BDCB75A270445408C4AEA04342B4A406954E0641B0245408C4AEA04342B4A40
26240	46705	41.949975999999999	41.970979	52.197752000000001	52.174776999999999	Основная	0103000020E6100000010000000500000011FE45D098F94440E78BBD175F164A4011FE45D098F94440FB5B02F04F194A40280D350A49FC4440FB5B02F04F194A40280D350A49FC4440E78BBD175F164A4011FE45D098F94440E78BBD175F164A40
25378	46640	41.975408000000002	42.021113999999997	52.037984999999999	52.015802000000001	Школьная	0103000020E61000000100000005000000DE205A2BDAFC44400F9BC8CC05024A40DE205A2BDAFC4440895E46B1DC044A406EBE11DDB3024540895E46B1DC044A406EBE11DDB30245400F9BC8CC05024A40DE205A2BDAFC44400F9BC8CC05024A40
25941	46499	42.095511999999999	42.111916000000001	52.312811000000004	52.299370000000003	Садовая	0103000020E610000001000000050000001230BABC390C4540A7B393C151264A401230BABC390C45401F6ADB300A284A4017F37343530E45401F6ADB300A284A4017F37343530E4540A7B393C151264A401230BABC390C4540A7B393C151264A40
25439	12483	41.988559000000002	42.055618000000003	52.155282999999997	52.122450000000001	Школьная	0103000020E610000001000000050000004F95EF1989FE444096B20C71AC0F4A404F95EF1989FE4440F84F3750E0134A40D388997D1E074540F84F3750E0134A40D388997D1E07454096B20C71AC0F4A404F95EF1989FE444096B20C71AC0F4A40
26103	12483	41.988559000000002	42.055618000000003	52.155282999999997	52.122450000000001	Советская	0103000020E610000001000000050000004F95EF1989FE444096B20C71AC0F4A404F95EF1989FE4440F84F3750E0134A40D388997D1E074540F84F3750E0134A40D388997D1E07454096B20C71AC0F4A404F95EF1989FE444096B20C71AC0F4A40
25524	12483	41.988559000000002	42.055618000000003	52.155282999999997	52.122450000000001	Первомайская	0103000020E610000001000000050000004F95EF1989FE444096B20C71AC0F4A404F95EF1989FE4440F84F3750E0134A40D388997D1E074540F84F3750E0134A40D388997D1E07454096B20C71AC0F4A404F95EF1989FE444096B20C71AC0F4A40
26354	12483	41.988559000000002	42.055618000000003	52.155282999999997	52.122450000000001	Комсомольская	0103000020E610000001000000050000004F95EF1989FE444096B20C71AC0F4A404F95EF1989FE4440F84F3750E0134A40D388997D1E074540F84F3750E0134A40D388997D1E07454096B20C71AC0F4A404F95EF1989FE444096B20C71AC0F4A40
25745	46378	41.643354000000002	41.663682999999999	52.036372	52.025956000000001	Школьная	0103000020E610000001000000050000001AE0826C59D244404791B58652034A401AE0826C59D24440BC3E73D6A7044A40A1F48590F3D44440BC3E73D6A7044A40A1F48590F3D444404791B58652034A401AE0826C59D244404791B58652034A40
25871	46536	41.728586	41.746706000000003	52.143833000000001	52.118872000000003	Юбилейная	0103000020E610000001000000050000006729594E42DD44407F349C32370F4A406729594E42DD4440F48AA71E69124A400EDDEC0F94DF4440F48AA71E69124A400EDDEC0F94DF44407F349C32370F4A406729594E42DD44407F349C32370F4A40
26367	46343	42.253894000000003	42.304091999999997	52.138460000000002	52.119219999999999	Центральная	0103000020E6100000010000000500000048533D997F204540BA83D899420F4A4048533D997F204540EFE6A90EB9114A40D47C957CEC264540EFE6A90EB9114A40D47C957CEC264540BA83D899420F4A4048533D997F204540BA83D899420F4A40
26098	46214	41.883572999999998	41.905293999999998	52.111201000000001	52.101737	Молодежная	0103000020E61000000100000005000000765089EB18F1444086E5CFB7050D4A40765089EB18F14440292499D53B0E4A40ECA17DACE0F34440292499D53B0E4A40ECA17DACE0F3444086E5CFB7050D4A40765089EB18F1444086E5CFB7050D4A40
26009	13580	42.062193999999998	42.100669000000003	52.074528000000001	52.052934	Школьная	0103000020E61000000100000005000000F30016F9F5074540596C938AC6064A40F30016F9F507454072512D228A094A404B5CC7B8E20C454072512D228A094A404B5CC7B8E20C4540596C938AC6064A40F30016F9F5074540596C938AC6064A40
25525	46227	41.885711000000001	41.892699999999998	52.164813000000002	52.162469999999999	Зеленая	0103000020E610000001000000050000008E5A61FA5EF14440624A24D1CB144A408E5A61FA5EF14440537AA69718154A40D1915CFE43F24440537AA69718154A40D1915CFE43F24440624A24D1CB144A408E5A61FA5EF14440624A24D1CB144A40
25366	13506	41.987301000000002	41.997515	52.082321	52.075436000000003	Школьная	0103000020E61000000100000005000000702711E15FFE4440757808E3A7094A40702711E15FFE44401363997E890A4A407D224F92AEFF44401363997E890A4A407D224F92AEFF4440757808E3A7094A40702711E15FFE4440757808E3A7094A40
25482	46574	42.093114	42.112841000000003	52.235593000000001	52.199623000000003	Проезжая	0103000020E610000001000000050000005E66D828EB0B4540C443183F8D194A405E66D828EB0B4540511553E9271E4A40F052EA92710E4540511553E9271E4A40F052EA92710E4540C443183F8D194A405E66D828EB0B4540C443183F8D194A40
25740	51196	41.780554000000002	41.816701999999999	52.085287000000001	52.063184	Советская	0103000020E6100000010000000500000089618731E9E34440B3D0CE6916084A4089618731E9E3444011E335AFEA0A4A40F549EEB089E8444011E335AFEA0A4A40F549EEB089E84440B3D0CE6916084A4089618731E9E34440B3D0CE6916084A40
25537	45440	41.948225000000001	42.200192999999999	52.359783	52.204734999999999	Мира	0103000020E61000000100000005000000F31FD26F5FF944405CACA8C1341A4A40F31FD26F5FF9444011548D5E0D2E4A40AEF199EC9F19454011548D5E0D2E4A40AEF199EC9F1945405CACA8C1341A4A40F31FD26F5FF944405CACA8C1341A4A40
26000	46491	42.042099	42.069237000000001	52.313746999999999	52.294544999999999	Школьная	0103000020E61000000100000005000000DF18028063054540A4198BA6B3254A40DF18028063054540EB1B98DC28284A402A560DC2DC084540EB1B98DC28284A402A560DC2DC084540A4198BA6B3254A40DF18028063054540A4198BA6B3254A40
25747	13677	41.914475000000003	41.932350999999997	52.257201999999999	52.236750999999998	Школьная	0103000020E610000001000000050000003B014D840DF54440CC2555DB4D1E4A403B014D840DF544409F3BC1FEEB204A404AB20E4757F744409F3BC1FEEB204A404AB20E4757F74440CC2555DB4D1E4A403B014D840DF54440CC2555DB4D1E4A40
75582	60699	42.010693000000003	42.028129999999997	52.121383000000002	52.103734000000003	Новая	0103000020E61000000100000005000000E8A562635E014540DCBDDC27470D4A40E8A562635E0145402BA5677A890F4A40AB048BC3990345402BA5677A890F4A40AB048BC399034540DCBDDC27470D4A40E8A562635E014540DCBDDC27470D4A40
25618	51185	41.874203000000001	41.901800000000001	51.975183000000001	51.964945999999998	Вишневая	0103000020E61000000100000005000000558847E2E5EF4440F833BC5983FB4940558847E2E5EF4440BE4EEACBD2FC494033C4B12E6EF34440BE4EEACBD2FC494033C4B12E6EF34440F833BC5983FB4940558847E2E5EF4440F833BC5983FB4940
25663	12735	42.199536999999999	42.254505000000002	52.146563	52.111876000000002	Центральная	0103000020E61000000100000005000000C5ABAC6D8A194540899AE8F3510E4A40C5ABAC6D8A194540DEE68D93C2124A4091D5AD9E93204540DEE68D93C2124A4091D5AD9E93204540899AE8F3510E4A40C5ABAC6D8A194540899AE8F3510E4A40
26362	46273	42.278804999999998	42.299627999999998	52.243600000000001	52.213410000000003	Центральная	0103000020E610000001000000050000000B7BDAE1AF234540D751D504511B4A400B7BDAE1AF2345401EA7E8482E1F4A40A27BD6355A2645401EA7E8482E1F4A40A27BD6355A264540D751D504511B4A400B7BDAE1AF234540D751D504511B4A40
26236	46585	41.823008000000002	41.859991999999998	52.026631999999999	52.015791	Молодежная	0103000020E61000000100000005000000562C7E5358E944401B49827005024A40562C7E5358E94440778368AD68034A402B69C53714EE4440778368AD68034A402B69C53714EE44401B49827005024A40562C7E5358E944401B49827005024A40
26371	13105	42.114449	42.137867999999997	52.151890000000002	52.128908000000003	Центральная	0103000020E61000000100000005000000AB07CC43A60E4540AD18AE0E80104A40AB07CC43A60E4540734BAB2171134A401C959BA8A5114540734BAB2171134A401C959BA8A5114540AD18AE0E80104A40AB07CC43A60E4540AD18AE0E80104A40
75360	45569	41.899644000000002	42.138596	52.183315	52.118408000000002	Центральная	0103000020E610000001000000050000007505DB8827F34440DACA4BFE270F4A407505DB8827F34440E1EEACDD76174A409FAD8383BD114540E1EEACDD76174A409FAD8383BD114540DACA4BFE270F4A407505DB8827F34440DACA4BFE270F4A40
26211	45444	41.856462000000001	41.917178999999997	52.490642999999999	52.458019999999998	Центральная	0103000020E610000001000000050000002522FC8BA0ED4440FB743C66A03A4A402522FC8BA0ED44407381CB63CD3E4A40FBC9181F66F544407381CB63CD3E4A40FBC9181F66F54440FB743C66A03A4A402522FC8BA0ED4440FB743C66A03A4A40
26071	9886	42.001584999999999	42.024374999999999	52.838664000000001	52.828757000000003	Школьная	0103000020E610000001000000050000000395F1EF3300454061AA99B5146A4A400395F1EF33004540912A8A57596B4A4085EB51B81E034540912A8A57596B4A4085EB51B81E03454061AA99B5146A4A400395F1EF3300454061AA99B5146A4A40
25962	9802	41.954666000000003	41.997892	52.806378000000002	52.768337000000002	Октябрьская	0103000020E61000000100000005000000344DD87E32FA444044A7E7DD58624A40344DD87E32FA4440611BF16437674A405378D0ECBAFF4440611BF16437674A405378D0ECBAFF444044A7E7DD58624A40344DD87E32FA444044A7E7DD58624A40
25968	49437	42.167062999999999	42.187769000000003	52.790534000000001	52.759422000000001	Школьная	0103000020E6100000010000000500000092AF04526215454074EE76BD34614A4092AF0452621545402330D63730654A40F01989D0081845402330D63730654A40F01989D00818454074EE76BD34614A4092AF04526215454074EE76BD34614A40
26208	49537	41.941783999999998	41.985253	52.730708999999997	52.704689000000002	Советская	0103000020E61000000100000005000000B2F2CB608CF84440EC6CC83F335A4A40B2F2CB608CF8444049F25CDF875D4A4098A432C51CFE444049F25CDF875D4A4098A432C51CFE4440EC6CC83F335A4A40B2F2CB608CF84440EC6CC83F335A4A40
26337	49537	41.941783999999998	41.985253	52.730708999999997	52.704689000000002	Киевская	0103000020E61000000100000005000000B2F2CB608CF84440EC6CC83F335A4A40B2F2CB608CF8444049F25CDF875D4A4098A432C51CFE444049F25CDF875D4A4098A432C51CFE4440EC6CC83F335A4A40B2F2CB608CF84440EC6CC83F335A4A40
26292	10491	42.028013000000001	42.056876000000003	52.603651999999997	52.578885999999997	Советская	0103000020E61000000100000005000000726E13EE950345405E0EBBEF184A4A40726E13EE950345401E15FF77444D4A40B2F677B6470745401E15FF77444D4A40B2F677B6470745405E0EBBEF184A4A40726E13EE950345405E0EBBEF184A4A40
25604	48518	42.175713999999999	42.206868	52.718125999999998	52.683320999999999	Школьная	0103000020E6100000010000000500000084B9DDCB7D164540C3D5011077574A4084B9DDCB7D1645402234828DEB5B4A40624B8FA67A1A45402234828DEB5B4A40624B8FA67A1A4540C3D5011077574A4084B9DDCB7D164540C3D5011077574A40
25370	45497	41.730184999999999	41.818264999999997	52.656410000000001	52.620455999999997	Коммунальная	0103000020E61000000100000005000000CF83BBB376DD4440B14D2A1A6B4F4A40CF83BBB376DD444039622D3E05544A40103B53E8BCE8444039622D3E05544A40103B53E8BCE84440B14D2A1A6B4F4A40CF83BBB376DD4440B14D2A1A6B4F4A40
25892	46757	42.033942000000003	42.057791999999999	52.698151000000003	52.679456000000002	Школьная	0103000020E61000000100000005000000FDFA2136580445401689096AF8564A40FDFA213658044540B95510035D594A4037FC6EBA65074540B95510035D594A4037FC6EBA650745401689096AF8564A40FDFA2136580445401689096AF8564A40
25865	46757	42.033942000000003	42.057791999999999	52.698151000000003	52.679456000000002	Центральная	0103000020E61000000100000005000000FDFA2136580445401689096AF8564A40FDFA213658044540B95510035D594A4037FC6EBA65074540B95510035D594A4037FC6EBA650745401689096AF8564A40FDFA2136580445401689096AF8564A40
75027	48434	42.014969000000001	42.045746000000001	52.569772999999998	52.543427000000001	Молодёжная	0103000020E6100000010000000500000017BA1281EA014540B76114048F454A4017BA1281EA01454068925852EE484A401FF64201DB05454068925852EE484A401FF64201DB054540B76114048F454A4017BA1281EA014540B76114048F454A40
25774	45621	41.691971000000002	41.754385999999997	52.487198999999997	52.468927999999998	Молодежная	0103000020E61000000100000005000000E563778192D84440DF162CD5053C4A40E563778192D844406BD26D895C3E4A40B6476FB88FE044406BD26D895C3E4A40B6476FB88FE04440DF162CD5053C4A40E563778192D84440DF162CD5053C4A40
75399	9892	42.030214000000001	42.059660999999998	52.821210000000001	52.785066	Молодежная	0103000020E61000000100000005000000D0F0660DDE034540CC99ED0A7D644A40D0F0660DDE034540F792C6681D694A405FECBDF8A2074540F792C6681D694A405FECBDF8A2074540CC99ED0A7D644A40D0F0660DDE034540CC99ED0A7D644A40
25979	51221	42.034804000000001	42.067449000000003	52.450825999999999	52.418602	Больничный проезд	0103000020E610000001000000050000008FE21C7574044540250516C094354A408FE21C7574044540DF1797AAB4394A40EF92382BA2084540DF1797AAB4394A40EF92382BA2084540250516C094354A408FE21C7574044540250516C094354A40
75029	60448	42.044119999999999	42.079872999999999	52.649028999999999	52.620373999999998	Проезжая	0103000020E61000000100000005000000BD8C62B9A5054540F4A44C6A684F4A40BD8C62B9A5054540EA93DC6113534A40AD6A4947390A4540EA93DC6113534A40AD6A4947390A4540F4A44C6A684F4A40BD8C62B9A5054540F4A44C6A684F4A40
26333	46683	42.007621	42.023691999999997	52.719403	52.710565000000003	Центральная	0103000020E61000000100000005000000A4E194B9F900454054573ECBF35A4A40A4E194B9F900454078D2C265155C4A40A296E6560803454078D2C265155C4A40A296E6560803454054573ECBF35A4A40A4E194B9F900454054573ECBF35A4A40
25437	10201	41.994506000000001	42.038936	52.751955000000002	52.722681000000001	Советская	0103000020E6100000010000000500000080D6FCF84BFF444065389ECF805C4A4080D6FCF84BFF44402788BA0F40604A408B51D7DAFB0445402788BA0F40604A408B51D7DAFB04454065389ECF805C4A4080D6FCF84BFF444065389ECF805C4A40
26341	10688	41.847181999999997	41.957154000000003	52.588625999999998	52.559969000000002	Центральная	0103000020E6100000010000000500000043E1B37570EC44400DE36E10AD474A4043E1B37570EC4440A3C9C518584B4A40289EB30584FA4440A3C9C518584B4A40289EB30584FA44400DE36E10AD474A4043E1B37570EC44400DE36E10AD474A40
25900	10688	41.847181999999997	41.957154000000003	52.588625999999998	52.559969000000002	Больничная	0103000020E6100000010000000500000043E1B37570EC44400DE36E10AD474A4043E1B37570EC4440A3C9C518584B4A40289EB30584FA4440A3C9C518584B4A40289EB30584FA44400DE36E10AD474A4043E1B37570EC44400DE36E10AD474A40
25556	45405	42.069128999999997	42.105600000000003	52.515388000000002	52.485658000000001	Советская	0103000020E61000000100000005000000431A1538D90845403885950A2A3E4A40431A1538D90845401C60E63BF8414A40933A014D840D45401C60E63BF8414A40933A014D840D45403885950A2A3E4A40431A1538D90845403885950A2A3E4A40
25580	45405	42.069128999999997	42.105600000000003	52.515388000000002	52.485658000000001	Новое село	0103000020E61000000100000005000000431A1538D90845403885950A2A3E4A40431A1538D90845401C60E63BF8414A40933A014D840D45401C60E63BF8414A40933A014D840D45403885950A2A3E4A40431A1538D90845403885950A2A3E4A40
25456	45573	41.629179000000001	41.687947000000001	52.556108999999999	52.538716999999998	Красная	0103000020E610000001000000050000003D2AFEEF88D044404D66BCADF4444A403D2AFEEF88D04440710168942E474A40CF30B5A50ED84440710168942E474A40CF30B5A50ED844404D66BCADF4444A403D2AFEEF88D044404D66BCADF4444A40
75361	60583	41.956632999999997	41.982512999999997	52.570884999999997	52.559690000000003	Центральная	0103000020E610000001000000050000001EA33CF372FA4440FAF202ECA3474A401EA33CF372FA444073637AC212494A408A7269FCC2FD444073637AC212494A408A7269FCC2FD4440FAF202ECA3474A401EA33CF372FA4440FAF202ECA3474A40
25840	51171	41.825811000000002	41.968814000000002	52.706319999999998	52.626896000000002	Ремесленная	0103000020E61000000100000005000000AAD6C22CB4E9444022FFCC203E504A40AAD6C22CB4E944405F419AB1685A4A4017F4DE1802FC44405F419AB1685A4A4017F4DE1802FC444022FFCC203E504A40AAD6C22CB4E9444022FFCC203E504A40
26254	26643	42.204047000000003	42.238273	53.343392999999999	53.324336000000002	Красная	0103000020E6100000010000000500000068EC4B361E1A45402E7590D783A94A4068EC4B361E1A45407156444DF4AB4A408942CBBA7F1E45407156444DF4AB4A408942CBBA7F1E45402E7590D783A94A4068EC4B361E1A45402E7590D783A94A40
26324	49374	42.34395	42.444544	53.125247000000002	53.085734000000002	Садовая	0103000020E61000000100000005000000C7BAB88D062C4540E013EB54F98A4A40C7BAB88D062C45400876FC1708904A4007D15AD1E63845400876FC1708904A4007D15AD1E6384540E013EB54F98A4A40C7BAB88D062C4540E013EB54F98A4A40
26068	9645	42.233564999999999	42.259813999999999	53.192706000000001	53.176527999999998	Рубцовка	0103000020E61000000100000005000000C03E3A75E51D4540056A317898964A40C03E3A75E51D45401ADF1797AA984A407F85CC95412145401ADF1797AA984A407F85CC9541214540056A317898964A40C03E3A75E51D4540056A317898964A40
25685	49334	42.297058	42.327708999999999	53.328826999999997	53.311957999999997	Заречная	0103000020E61000000100000005000000F1811DFF05264540DFDC5F3DEEA74A40F1811DFF052645405985CD0017AA4A406CCD565EF22945405985CD0017AA4A406CCD565EF2294540DFDC5F3DEEA74A40F1811DFF05264540DFDC5F3DEEA74A40
25563	9489	42.185586000000001	42.216650000000001	53.252107000000002	53.222444000000003	Пролетарская	0103000020E61000000100000005000000384C3448C11745408198840B799C4A40384C3448C1174540DD0BCC0A45A04A40D656EC2FBB1B4540DD0BCC0A45A04A40D656EC2FBB1B45408198840B799C4A40384C3448C11745408198840B799C4A40
25883	45387	42.335084000000002	42.391084999999997	53.223990999999998	53.202841999999997	Молодёжная	0103000020E61000000100000005000000D9B45208E42A4540AB2006BAF6994A40D9B45208E42A454096CCB1BCAB9C4A40637AC2120F32454096CCB1BCAB9C4A40637AC2120F324540AB2006BAF6994A40D9B45208E42A4540AB2006BAF6994A40
26334	9575	42.235684999999997	42.242629000000001	53.307848	53.300480999999998	Школьная	0103000020E61000000100000005000000319413ED2A1E4540E108522976A64A40319413ED2A1E4540CB11329067A74A40D50792770E1F4540CB11329067A74A40D50792770E1F4540E108522976A64A40319413ED2A1E4540E108522976A64A40
25969	49149	41.982486000000002	42.001916999999999	53.270986000000001	53.262180999999998	Новая	0103000020E610000001000000050000009163EB19C2FD4440F850A2258FA14A409163EB19C2FD444041D653ABAFA24A403927F6D03E00454041D653ABAFA24A403927F6D03E004540F850A2258FA14A409163EB19C2FD4440F850A2258FA14A40
75391	45460	42.302466000000003	42.335397999999998	53.232196000000002	53.208300000000001	Молодежная	0103000020E610000001000000050000007313B534B7264540DFE00B93A99A4A407313B534B72645408A213999B89D4A4068925852EE2A45408A213999B89D4A4068925852EE2A4540DFE00B93A99A4A407313B534B7264540DFE00B93A99A4A40
25978	46668	42.061044000000003	42.076476999999997	53.124723000000003	53.103529999999999	Центральная	0103000020E61000000100000005000000FBCE2F4AD0074540D3139678408D4A40FBCE2F4AD00745408E075BECF68F4A40B6F292FFC90945408E075BECF68F4A40B6F292FFC9094540D3139678408D4A40FBCE2F4AD0074540D3139678408D4A40
25446	49232	42.161188000000003	42.182881999999999	53.303021000000001	53.274120000000003	Центральная	0103000020E61000000100000005000000FB40F2CEA1144540FB96395D16A34A40FB40F2CEA114454028806264C9A64A40778368AD6817454028806264C9A64A40778368AD68174540FB96395D16A34A40FB40F2CEA1144540FB96395D16A34A40
25527	9142	42.264512000000003	42.313910999999997	53.175928999999996	53.133372999999999	Новая	0103000020E6100000010000000500000025B37A87DB214540AF95D05D12914A4025B37A87DB21454080B56AD784964A40656D533C2E28454080B56AD784964A40656D533C2E284540AF95D05D12914A4025B37A87DB214540AF95D05D12914A40
26062	8959	42.084148999999996	42.113083000000003	53.255054000000001	53.241427999999999	Садовая	0103000020E61000000100000005000000DC7EF964C50A45405A2BDA1CE79E4A40DC7EF964C50A4540645B069CA5A04A40E65DF580790E4540645B069CA5A04A40E65DF580790E45405A2BDA1CE79E4A40DC7EF964C50A45405A2BDA1CE79E4A40
25431	49362	42.215463999999997	42.235864999999997	53.203797000000002	53.191049999999997	Новая	0103000020E6100000010000000500000090BB0853941B45404DF38E5374984A4090BB0853941B4540EF022505169A4A40B1A206D3301E4540EF022505169A4A40B1A206D3301E45404DF38E5374984A4090BB0853941B45404DF38E5374984A40
26312	9056	42.042789999999997	42.055286000000002	53.188248999999999	53.161656999999998	Центральная	0103000020E61000000100000005000000444C89247A054540B115342DB1944A40444C89247A0545409A40118B18984A409DF6949C130745409A40118B18984A409DF6949C13074540B115342DB1944A40444C89247A054540B115342DB1944A40
25923	40388	\N	\N	\N	\N	Центральная	\N
25948	8872	42.036501999999999	42.082962999999999	53.287816999999997	53.272753000000002	Школьная	0103000020E610000001000000050000008A1EF818AC0445406571FF91E9A24A408A1EF818AC044540CD1DFD2FD7A44A4097E315889E0A4540CD1DFD2FD7A44A4097E315889E0A45406571FF91E9A24A408A1EF818AC0445406571FF91E9A24A40
25780	9393	42.421061999999999	42.451011999999999	53.186210000000003	53.152802000000001	Центральная	0103000020E610000001000000050000004FCB0F5CE5354540B76114048F934A404FCB0F5CE53545401618B2BAD5974A40410DDFC2BA3945401618B2BAD5974A40410DDFC2BA394540B76114048F934A404FCB0F5CE5354540B76114048F934A40
25667	48945	40.429667999999999	40.499709000000003	52.475884000000001	52.443361000000003	Советская	0103000020E61000000100000005000000A1116C5CFF36444033A9A10DC0384A40A1116C5CFF364440475854C4E93C4A402942EA76F63F4440475854C4E93C4A402942EA76F63F444033A9A10DC0384A40A1116C5CFF36444033A9A10DC0384A40
26155	51238	40.433439999999997	40.503832000000003	52.528894999999999	52.503017	Первомайская	0103000020E610000001000000050000009D6340F67A374440802A6EDC62404A409D6340F67A3744404B02D4D4B2434A40D25625917D4044404B02D4D4B2434A40D25625917D404440802A6EDC62404A409D6340F67A374440802A6EDC62404A40
25609	48775	40.393222999999999	40.406256999999997	52.693316000000003	52.678936999999998	Молодежная	0103000020E610000001000000050000007B849A2155324440AD855968E7564A407B849A215532444093E52494BE584A40B262B83A0034444093E52494BE584A40B262B83A00344440AD855968E7564A407B849A2155324440AD855968E7564A40
25705	5652	40.352412000000001	40.377673000000001	52.440978000000001	52.418678999999997	Центральная	0103000020E61000000100000005000000E65B1FD61B2D4440D042024697354A40E65B1FD61B2D4440B42094F771384A4086CABF9657304440B42094F771384A4086CABF9657304440D042024697354A40E65B1FD61B2D4440D042024697354A40
26173	8424	40.449672999999997	40.509115000000001	52.483969000000002	52.460434999999997	Колхозная	0103000020E61000000100000005000000757286E28E3944408577B988EF3A4A40757286E28E39444090A339B2F23D4A40977329AE2A41444090A339B2F23D4A40977329AE2A4144408577B988EF3A4A40757286E28E3944408577B988EF3A4A40
75356	48809	40.192628999999997	40.216569	52.751012000000003	52.736815999999997	Центральная	0103000020E610000001000000050000006EA12B11A8184440B39597FC4F5E4A406EA12B11A8184440A873452921604A40E9297288B81B4440A873452921604A40E9297288B81B4440B39597FC4F5E4A406EA12B11A8184440B39597FC4F5E4A40
25664	48706	40.289296999999998	40.325812999999997	52.541558999999999	52.519443000000003	Центральная	0103000020E610000001000000050000005BEA20AF072544406D91B41B7D424A405BEA20AF072544405FED28CE51454A404ACE893DB42944405FED28CE51454A404ACE893DB42944406D91B41B7D424A405BEA20AF072544406D91B41B7D424A40
25955	7907	40.324969000000003	40.346654000000001	52.752740000000003	52.737105	Центральная	0103000020E610000001000000050000005F9B8D9598294440EA5BE674595E4A405F9B8D95982944400E32C9C859604A40888384285F2C44400E32C9C859604A40888384285F2C4440EA5BE674595E4A405F9B8D9598294440EA5BE674595E4A40
25661	46798	40.257317	40.268554999999999	52.732289999999999	52.711640000000003	Школьная	0103000020E6100000010000000500000038DA71C3EF2044404243FF04175B4A4038DA71C3EF2044400B98C0ADBB5D4A40B1169F02602244400B98C0ADBB5D4A40B1169F02602244404243FF04175B4A4038DA71C3EF2044404243FF04175B4A40
26054	8498	40.376963000000003	40.388075999999998	52.440792000000002	52.428938000000002	Молодежная	0103000020E61000000100000005000000AA66D652403044407E01BD70E7364A40AA66D65240304440522B4CDF6B384A40662E7079AC314440522B4CDF6B384A40662E7079AC3144407E01BD70E7364A40AA66D652403044407E01BD70E7364A40
25658	48619	40.194901999999999	40.225740999999999	52.670310000000001	52.654164000000002	Советская	0103000020E6100000010000000500000066F6798CF21844403B1C5DA5BB534A4066F6798CF21844404417D4B7CC554A40E42EC214E51C44404417D4B7CC554A40E42EC214E51C44403B1C5DA5BB534A4066F6798CF21844403B1C5DA5BB534A40
26057	7824	40.359392	40.384033000000002	52.652427000000003	52.635936000000001	Кооперативная	0103000020E61000000100000005000000D6389B8E002E4440AE2CD15966514A40D6389B8E002E444082035ABA82534A40DACA4BFE2731444082035ABA82534A40DACA4BFE27314440AE2CD15966514A40D6389B8E002E4440AE2CD15966514A40
25896	25453	40.227753	40.266416999999997	52.649614	52.611434000000003	Советская	0103000020E610000001000000050000006F48A302271D4440CCD42478434E4A406F48A302271D44400A83328D26534A40990CC7F3192244400A83328D26534A40990CC7F319224440CCD42478434E4A406F48A302271D4440CCD42478434E4A40
26237	25453	40.227753	40.266416999999997	52.649614	52.611434000000003	Приозерная	0103000020E610000001000000050000006F48A302271D4440CCD42478434E4A406F48A302271D44400A83328D26534A40990CC7F3192244400A83328D26534A40990CC7F319224440CCD42478434E4A406F48A302271D4440CCD42478434E4A40
75015	25453	40.227753	40.266416999999997	52.649614	52.611434000000003	Первомайская	0103000020E610000001000000050000006F48A302271D4440CCD42478434E4A406F48A302271D44400A83328D26534A40990CC7F3192244400A83328D26534A40990CC7F319224440CCD42478434E4A406F48A302271D4440CCD42478434E4A40
25516	25453	40.227753	40.266416999999997	52.649614	52.611434000000003	Моторина	0103000020E610000001000000050000006F48A302271D4440CCD42478434E4A406F48A302271D44400A83328D26534A40990CC7F3192244400A83328D26534A40990CC7F319224440CCD42478434E4A406F48A302271D4440CCD42478434E4A40
25885	25453	40.227753	40.266416999999997	52.649614	52.611434000000003	Молодежная	0103000020E610000001000000050000006F48A302271D4440CCD42478434E4A406F48A302271D44400A83328D26534A40990CC7F3192244400A83328D26534A40990CC7F319224440CCD42478434E4A406F48A302271D4440CCD42478434E4A40
74984	25453	40.227753	40.266416999999997	52.649614	52.611434000000003	Кооперативная	0103000020E610000001000000050000006F48A302271D4440CCD42478434E4A406F48A302271D44400A83328D26534A40990CC7F3192244400A83328D26534A40990CC7F319224440CCD42478434E4A406F48A302271D4440CCD42478434E4A40
25379	49074	40.548461000000003	40.590448000000002	52.648088999999999	52.630214000000002	Центральная	0103000020E61000000100000005000000D41055F8334644409DBD33DAAA504A40D41055F833464440DCF29194F4524A408BFED0CC934B4440DCF29194F4524A408BFED0CC934B44409DBD33DAAA504A40D41055F8334644409DBD33DAAA504A40
75415	60597	40.465501000000003	40.481141000000001	52.588746	52.562860000000001	Советская	0103000020E61000000100000005000000AEA06989953B4440001DE6CB0B484A40AEA06989953B44404ED367075C4B4A40E3E13D07963D44404ED367075C4B4A40E3E13D07963D4440001DE6CB0B484A40AEA06989953B4440001DE6CB0B484A40
25550	8121	40.017358999999999	40.063181999999998	52.673783	52.651159999999997	Садовая	0103000020E6100000010000000500000048A5D8D1380244404F3BFC3559534A4048A5D8D138024440E6CC76853E564A4012D9075916084440E6CC76853E564A4012D90759160844404F3BFC3559534A4048A5D8D1380244404F3BFC3559534A40
26190	8049	40.099212999999999	40.132162999999998	52.796802	52.764986	Гагарина	0103000020E61000000100000005000000452BF702B30C4440EDF2AD0FEB614A40452BF702B30C444096B1A19BFD654A40E15E99B7EA10444096B1A19BFD654A40E15E99B7EA104440EDF2AD0FEB614A40452BF702B30C4440EDF2AD0FEB614A40
25933	8211	40.112651999999997	40.147964999999999	52.688600000000001	52.667323000000003	Школьная	0103000020E610000001000000050000001CEA77616B0E44402F6F0ED76A554A401CEA77616B0E44404703780B24584A40F0F96184F01244404703780B24584A40F0F96184F01244402F6F0ED76A554A401CEA77616B0E44402F6F0ED76A554A40
26160	48650	40.249349000000002	40.275319000000003	52.563205000000004	52.542009	Советская	0103000020E61000000100000005000000292504ABEA1F44409F91088D60454A40292504ABEA1F4440CBF8F71917484A40D57B2AA73D234440CBF8F71917484A40D57B2AA73D2344409F91088D60454A40292504ABEA1F44409F91088D60454A40
75386	60591	40.710076999999998	40.720191999999997	52.456983000000001	52.446116000000004	Центральная	0103000020E6100000010000000500000026529ACDE35A4440761C3F541A394A4026529ACDE35A4440FBE93F6B7E3A4A40A06B5F402F5C4440FBE93F6B7E3A4A40A06B5F402F5C4440761C3F541A394A4026529ACDE35A4440761C3F541A394A40
25650	48690	40.332667000000001	40.365977000000001	52.525229000000003	52.503351000000002	Молодежная	0103000020E61000000100000005000000AEBA0ED5942A444057B439CE6D404A40AEBA0ED5942A444095F430B43A434A404A0B9755D82E444095F430B43A434A404A0B9755D82E444057B439CE6D404A40AEBA0ED5942A444057B439CE6D404A40
25552	47081	40.276639000000003	40.289341999999998	52.527306000000003	52.517420999999999	Школьная	0103000020E610000001000000050000002AE620E868234440BEA1F0D93A424A402AE620E868234440077E54C37E434A40FBAD9D2809254440077E54C37E434A40FBAD9D2809254440BEA1F0D93A424A402AE620E868234440BEA1F0D93A424A40
25766	45988	40.576228	40.610399999999998	52.489123999999997	52.463797999999997	Советская	0103000020E610000001000000050000000E85CFD6C1494440A0F99CBB5D3B4A400E85CFD6C149444027D87F9D9B3E4A403CBD5296214E444027D87F9D9B3E4A403CBD5296214E4440A0F99CBB5D3B4A400E85CFD6C1494440A0F99CBB5D3B4A40
74976	45988	40.576228	40.610399999999998	52.489123999999997	52.463797999999997	Красная площадь	0103000020E610000001000000050000000E85CFD6C1494440A0F99CBB5D3B4A400E85CFD6C149444027D87F9D9B3E4A403CBD5296214E444027D87F9D9B3E4A403CBD5296214E4440A0F99CBB5D3B4A400E85CFD6C1494440A0F99CBB5D3B4A40
25802	48629	40.274124	40.319318000000003	52.613605	52.605342	Центральная	0103000020E610000001000000050000003C86C77E162344409772BED87B4D4A403C86C77E16234440BFD4CF9B8A4E4A4017838769DF284440BFD4CF9B8A4E4A4017838769DF2844409772BED87B4D4A403C86C77E162344409772BED87B4D4A40
25833	48990	40.684024999999998	40.715277999999998	52.502392	52.486041999999998	Советская	0103000020E61000000100000005000000BD5296218E574440C03DCF9F363E4A40BD5296218E574440D2E28C614E404A402EC6C03A8E5B4440D2E28C614E404A402EC6C03A8E5B4440C03DCF9F363E4A40BD5296218E574440C03DCF9F363E4A40
25666	8365	40.370271000000002	40.420118000000002	52.557254	52.528461999999998	Пионерская	0103000020E6100000010000000500000020D4450A652F4440E1968FA4A4434A4020D4450A652F444058C85C1954474A40003B376DC635444058C85C1954474A40003B376DC6354440E1968FA4A4434A4020D4450A652F4440E1968FA4A4434A40
26181	48740	39.985235000000003	40.028129999999997	52.622118	52.601289999999999	Колхозная	0103000020E61000000100000005000000F2EF332E1CFE4340B7B41A12F74C4A40F2EF332E1CFE434060200890A14F4A40AB048BC39903444060200890A14F4A40AB048BC399034440B7B41A12F74C4A40F2EF332E1CFE4340B7B41A12F74C4A40
26178	51241	40.759286000000003	40.770318000000003	52.539363000000002	52.522643000000002	Полевая	0103000020E61000000100000005000000C4279D4830614440DE3D40F7E5424A40C4279D483061444013D6C6D809454A4094C2BCC79962444013D6C6D809454A4094C2BCC799624440DE3D40F7E5424A40C4279D4830614440DE3D40F7E5424A40
26018	48342	40.171016000000002	40.192683000000002	53.163508999999998	53.151224999999997	Новая	0103000020E61000000100000005000000DF8B2FDAE315444036AB3E575B934A40DF8B2FDAE315444003CDE7DCED944A4062BF27D6A918444003CDE7DCED944A4062BF27D6A918444036AB3E575B934A40DF8B2FDAE315444036AB3E575B934A40
26230	5801	40.365689000000003	40.402223999999997	53.088227000000003	53.042687000000001	Лесная	0103000020E61000000100000005000000E4C0ABE5CE2E4440707B82C476854A40E4C0ABE5CE2E4440E6CFB7054B8B4A4049D576137C334440E6CFB7054B8B4A4049D576137C334440707B82C476854A40E4C0ABE5CE2E4440707B82C476854A40
25608	7230	40.471294999999998	40.508710000000001	53.199092999999998	53.172123999999997	Школьная	0103000020E6100000010000000500000058E20165533C4440A86DC32808964A4058E20165533C444067EE21E17B994A40F792C6681D41444067EE21E17B994A40F792C6681D414440A86DC32808964A4058E20165533C4440A86DC32808964A40
26365	7026	40.518267999999999	40.552349999999997	53.196930000000002	53.165483999999999	Интернациональная	0103000020E610000001000000050000001B48179B56424440710168942E954A401B48179B56424440F7CC920035994A4009F9A067B3464440F7CC920035994A4009F9A067B3464440710168942E954A401B48179B56424440710168942E954A40
25734	48350	40.299734999999998	40.314971	53.151646	53.147007000000002	Школьная	0103000020E61000000100000005000000B83B6BB75D2644403CA41820D1924A40B83B6BB75D264440DC48D92269934A401E1840F850284440DC48D92269934A401E1840F8502844403CA41820D1924A40B83B6BB75D2644403CA41820D1924A40
25770	7325	40.383000000000003	40.442261999999999	53.220255000000002	53.182701999999999	Советская	0103000020E610000001000000050000001B2FDD2406314440F77475C762974A401B2FDD2406314440E7E3DA50319C4A40BC218D0A9C384440E7E3DA50319C4A40BC218D0A9C384440F77475C762974A401B2FDD2406314440F77475C762974A40
25733	51195	40.505116999999998	40.537438000000002	53.210580999999998	53.186279999999996	Школьная	0103000020E61000000100000005000000AAD381ACA74044400EF3E505D8974A40AAD381ACA740444059147651F49A4A4057D0B4C4CA44444059147651F49A4A4057D0B4C4CA4444400EF3E505D8974A40AAD381ACA74044400EF3E505D8974A40
25653	6565	40.147120000000001	40.195323999999999	53.221446	53.201666000000003	Пионерская	0103000020E61000000100000005000000344B02D4D41244408A5B0531D0994A40344B02D4D41244403EEAAF57589C4A40DC0F7860001944403EEAAF57589C4A40DC0F7860001944408A5B0531D0994A40344B02D4D41244408A5B0531D0994A40
75012	48122	40.264476000000002	40.309491000000001	53.266134000000001	53.231425000000002	переулок Школьный	0103000020E61000000100000005000000D8497D59DA214440083D9B559F9D4A40D8497D59DA214440452DCDAD10A24A4003B4AD669D274440452DCDAD10A24A4003B4AD669D274440083D9B559F9D4A40D8497D59DA214440083D9B559F9D4A40
75014	48122	40.264476000000002	40.309491000000001	53.266134000000001	53.231425000000002	Э.Тельмана	0103000020E61000000100000005000000D8497D59DA214440083D9B559F9D4A40D8497D59DA214440452DCDAD10A24A4003B4AD669D274440452DCDAD10A24A4003B4AD669D274440083D9B559F9D4A40D8497D59DA214440083D9B559F9D4A40
75387	48122	40.264476000000002	40.309491000000001	53.266134000000001	53.231425000000002	Советская	0103000020E61000000100000005000000D8497D59DA214440083D9B559F9D4A40D8497D59DA214440452DCDAD10A24A4003B4AD669D274440452DCDAD10A24A4003B4AD669D274440083D9B559F9D4A40D8497D59DA214440083D9B559F9D4A40
25651	48122	40.264476000000002	40.309491000000001	53.266134000000001	53.231425000000002	Дружбы	0103000020E61000000100000005000000D8497D59DA214440083D9B559F9D4A40D8497D59DA214440452DCDAD10A24A4003B4AD669D274440452DCDAD10A24A4003B4AD669D274440083D9B559F9D4A40D8497D59DA214440083D9B559F9D4A40
25785	48235	40.276800999999999	40.303238999999998	53.310828999999998	53.295928000000004	Колхозная	0103000020E61000000100000005000000034015376E23444040FCFCF7E0A54A40034015376E234440FED2A23EC9A74A4095EF1989D0264440FED2A23EC9A74A4095EF1989D026444040FCFCF7E0A54A40034015376E23444040FCFCF7E0A54A40
26373	47923	40.106102999999997	40.126801	53.275875999999997	53.266570000000002	Центральная	0103000020E61000000100000005000000F58079C8940D4440200C3CF71EA24A40F58079C8940D44402AE09EE74FA34A40D00CE2033B1044402AE09EE74FA34A40D00CE2033B104440200C3CF71EA24A40F58079C8940D4440200C3CF71EA24A40
26325	48378	40.312095999999997	40.327601000000001	53.133881000000002	53.117891999999998	Набережная	0103000020E61000000100000005000000309B00C3F2274440E23AC615178F4A40309B00C3F227444024473A0323914A4086915ED4EE29444024473A0323914A4086915ED4EE294440E23AC615178F4A40309B00C3F2274440E23AC615178F4A40
26307	7125	40.415106000000002	40.466282999999997	53.342694000000002	53.308154999999999	Школьная	0103000020E61000000100000005000000CB2F833122354440A88C7F9F71A74A40CB2F8331223544408944A165DDAB4A4023D74D29AF3B44408944A165DDAB4A4023D74D29AF3B4440A88C7F9F71A74A40CB2F833122354440A88C7F9F71A74A40
25586	51181	40.494346	40.526981999999997	53.230713000000002	53.211486999999998	Школьная	0103000020E610000001000000050000004774CFBA463F4440BB438A01129B4A404774CFBA463F44408BE1EA00889D4A4053CA6B25744344408BE1EA00889D4A4053CA6B2574434440BB438A01129B4A404774CFBA463F4440BB438A01129B4A40
26157	6502	40.226154000000001	40.250965999999998	53.211924000000003	53.186554999999998	Советская	0103000020E6100000010000000500000007EE409DF21C4440E0F3C308E1974A4007EE409DF21C4440679E5C53209B4A40373465A71F204440679E5C53209B4A40373465A71F204440E0F3C308E1974A4007EE409DF21C4440E0F3C308E1974A40
26033	48227	40.225983999999997	40.267558000000001	53.304516999999997	53.264028000000003	Ленина	0103000020E61000000100000005000000AAB5300BED1C4440399D64ABCBA14A40AAB5300BED1C4440BB09BE69FAA64A403FE42D573F224440BB09BE69FAA64A403FE42D573F224440399D64ABCBA14A40AAB5300BED1C4440399D64ABCBA14A40
26191	6606	40.108044	40.138064999999997	53.225242000000001	53.208052000000002	Центральная Усадьба	0103000020E61000000100000005000000B743C362D40D444007EFAB72A19A4A40B743C362D40D4440C3D7D7BAD49C4A4072DC291DAC114440C3D7D7BAD49C4A4072DC291DAC11444007EFAB72A19A4A40B743C362D40D444007EFAB72A19A4A40
25724	6951	40.346725999999997	40.376190999999999	53.157682999999999	53.122923	Заречная	0103000020E6100000010000000500000021567F84612C44408E76DCF0BB8F4A4021567F84612C44404D11E0F42E944A405706D506273044404D11E0F42E944A405706D506273044408E76DCF0BB8F4A4021567F84612C44408E76DCF0BB8F4A40
26335	6333	40.296590999999999	40.355781	53.226115	53.177705000000003	Школьная	0103000020E61000000100000005000000DBA4A2B1F6254440F8AA9509BF964A40DBA4A2B1F625444049111956F19C4A40E3C4573B8A2D444049111956F19C4A40E3C4573B8A2D4440F8AA9509BF964A40DBA4A2B1F6254440F8AA9509BF964A40
25491	6882	40.339117000000002	40.351092000000001	53.171843000000003	53.157645000000002	Школьная	0103000020E610000001000000050000004242942F682B444060B01BB62D944A404242942F682B4440F58590F3FE954A4091F12895F02C4440F58590F3FE954A4091F12895F02C444060B01BB62D944A404242942F682B444060B01BB62D944A40
25408	48313	40.138263000000002	40.169182999999997	53.271723999999999	53.254821999999997	Совхозная	0103000020E61000000100000005000000999F1B9AB21144409126DE019EA04A40999F1B9AB2114440E7C41EDAC7A24A400305DEC9A7154440E7C41EDAC7A24A400305DEC9A71544409126DE019EA04A40999F1B9AB21144409126DE019EA04A40
25805	47191	40.296959000000001	40.321744000000002	53.107444000000001	53.095954999999996	Заводская	0103000020E610000001000000050000005EA0A4C0022644409F71E140488C4A405EA0A4C002264440621399B9C08D4A4095D74AE82E294440621399B9C08D4A4095D74AE82E2944409F71E140488C4A405EA0A4C0022644409F71E140488C4A40
74990	60421	40.568393999999998	41.118693	53.179696	52.549802	Площадь Ленина	0103000020E610000001000000050000000E9F7422C148444040A374E95F464A400E9F7422C14844406B9C4D4700974A40CFA10C55318F44406B9C4D4700974A40CFA10C55318F444040A374E95F464A400E9F7422C148444040A374E95F464A40
75064	46749	40.812151999999998	40.875807000000002	52.919840999999998	52.897058000000001	Центральная	0103000020E61000000100000005000000C4B0C398F4674440BE4EEACBD2724A40C4B0C398F46744408D429259BD754A40CF4D9B711A7044408D429259BD754A40CF4D9B711A704440BE4EEACBD2724A40C4B0C398F4674440BE4EEACBD2724A40
25874	46749	40.812151999999998	40.875807000000002	52.919840999999998	52.897058000000001	Криворотченко	0103000020E61000000100000005000000C4B0C398F4674440BE4EEACBD2724A40C4B0C398F46744408D429259BD754A40CF4D9B711A7044408D429259BD754A40CF4D9B711A704440BE4EEACBD2724A40C4B0C398F4674440BE4EEACBD2724A40
25764	5917	40.659232000000003	40.716275000000003	52.720750000000002	52.698112999999999	площадь Советов	0103000020E61000000100000005000000043DD4B661544440CBF44BC45B594A40043DD4B661544440C74B3789415C4A40A1F831E6AE5B4440C74B3789415C4A40A1F831E6AE5B4440CBF44BC45B594A40043DD4B661544440CBF44BC45B594A40
25683	47911	40.946359999999999	40.978718000000001	52.877735999999999	52.869774	Молодежная	0103000020E610000001000000050000000C1F1153227944409F7422C1546F4A400C1F115322794440CC423BA759704A40D600A5A1467D4440CC423BA759704A40D600A5A1467D44409F7422C1546F4A400C1F1153227944409F7422C1546F4A40
26005	5984	40.664388000000002	40.712322	52.753290999999997	52.739766000000003	Тамбовская	0103000020E610000001000000050000006CED7DAA0A554440AC58FCA6B05E4A406CED7DAA0A55444081AFE8D66B604A40541C075E2D5B444081AFE8D66B604A40541C075E2D5B4440AC58FCA6B05E4A406CED7DAA0A554440AC58FCA6B05E4A40
25624	47706	40.783810000000003	40.809384999999999	52.951445	52.926127999999999	Школьная	0103000020E610000001000000050000008E23D6E25364444077F4BF5C8B764A408E23D6E253644440AB7823F3C8794A40BD6F7CED99674440AB7823F3C8794A40BD6F7CED9967444077F4BF5C8B764A408E23D6E25364444077F4BF5C8B764A40
26186	51243	40.791454999999999	40.814163999999998	52.988804999999999	52.966346999999999	Новая	0103000020E61000000100000005000000BAA0BE654E6544403ACB2C42B17B4A40BAA0BE654E654440868F8829917E4A404FCAA48636684440868F8829917E4A404FCAA486366844403ACB2C42B17B4A40BAA0BE654E6544403ACB2C42B17B4A40
25632	5431	40.992749000000003	41.020246999999998	52.985850999999997	52.959685999999998	Зеленая	0103000020E6100000010000000500000080113466127F4440EB36A8FDD67A4A4080113466127F44404CDD955D307E4A40CA6B2574978244404CDD955D307E4A40CA6B257497824440EB36A8FDD67A4A4080113466127F4440EB36A8FDD67A4A40
26257	47876	40.970965	41.029518000000003	52.838909000000001	52.816388000000003	Пушкина	0103000020E61000000100000005000000C347C494487C4440666CE8667F684A40C347C494487C4440F8A8BF5E616B4A405952EE3EC7834440F8A8BF5E616B4A405952EE3EC7834440666CE8667F684A40C347C494487C4440666CE8667F684A40
26003	5437	41.002980999999998	41.042012999999997	52.855986000000001	52.831145999999997	Красная	0103000020E6100000010000000500000033C170AE61804440C119FCFD626A4A4033C170AE61804440BCEA01F3906D4A40E08096AE60854440BCEA01F3906D4A40E08096AE60854440C119FCFD626A4A4033C170AE61804440C119FCFD626A4A40
25606	5711	40.810310999999999	40.862178999999998	52.791193	52.768255000000003	Молодежная	0103000020E61000000100000005000000664B5645B867444087FE092E56624A40664B5645B86744407DE9EDCF45654A402426A8E15B6E44407DE9EDCF45654A402426A8E15B6E444087FE092E56624A40664B5645B867444087FE092E56624A40
25518	5921	40.830640000000002	40.854427000000001	52.690182999999998	52.681252000000001	Редькино	0103000020E61000000100000005000000EE5F5969526A4440D42AFA4333574A40EE5F5969526A4440A9A0A2EA57584A40E2E82ADD5D6D4440A9A0A2EA57584A40E2E82ADD5D6D4440D42AFA4333574A40EE5F5969526A4440D42AFA4333574A40
25728	47735	40.819087000000003	40.862188000000003	53.010666999999998	52.966656	Советская	0103000020E6100000010000000500000015CAC2D7D7684440B83D4162BB7B4A4015CAC2D7D7684440BE1248895D814A407880272D5C6E4440BE1248895D814A407880272D5C6E4440B83D4162BB7B4A4015CAC2D7D7684440B83D4162BB7B4A40
75381	48103	40.759089000000003	40.828240999999998	52.899014000000001	52.869436999999998	Центральная	0103000020E610000001000000050000006EE00ED42961444057772CB6496F4A406EE00ED429614440B55208E412734A40691A14CD036A4440B55208E412734A40691A14CD036A444057772CB6496F4A406EE00ED42961444057772CB6496F4A40
26245	48103	40.759089000000003	40.828240999999998	52.899014000000001	52.869436999999998	Победы	0103000020E610000001000000050000006EE00ED42961444057772CB6496F4A406EE00ED429614440B55208E412734A40691A14CD036A4440B55208E412734A40691A14CD036A444057772CB6496F4A406EE00ED42961444057772CB6496F4A40
75488	48103	40.759089000000003	40.828240999999998	52.899014000000001	52.869436999999998	Коммунальная	0103000020E610000001000000050000006EE00ED42961444057772CB6496F4A406EE00ED429614440B55208E412734A40691A14CD036A4440B55208E412734A40691A14CD036A444057772CB6496F4A406EE00ED42961444057772CB6496F4A40
25627	51187	40.759089000000003	40.828240999999998	52.899014000000001	52.869436999999998	Заводская	0103000020E610000001000000050000006EE00ED42961444057772CB6496F4A406EE00ED429614440B55208E412734A40691A14CD036A4440B55208E412734A40691A14CD036A444057772CB6496F4A406EE00ED42961444057772CB6496F4A40
25475	5319	40.880532000000002	40.890422000000001	53.092981000000002	53.081314999999996	Центральная	0103000020E610000001000000050000006E8AC745B57044404DD6A887688A4A406E8AC745B57044401F1329CDE68B4A40C8D11C59F97144401F1329CDE68B4A40C8D11C59F97144404DD6A887688A4A406E8AC745B57044404DD6A887688A4A40
25898	48071	40.645038999999997	40.675995	52.646051	52.631475999999999	Молодежная	0103000020E6100000010000000500000080D250A390524440BD1AA034D4504A4080D250A390524440284696CCB1524A4038A1100187564440284696CCB1524A4038A1100187564440BD1AA034D4504A4080D250A390524440BD1AA034D4504A40
25844	47774	40.920865999999997	40.950240999999998	53.105189000000003	53.082234	Молодежная	0103000020E61000000100000005000000C9FFE4EFDE754440444FCAA4868A4A40C9FFE4EFDE754440117349D5768D4A40BF28417FA1794440117349D5768D4A40BF28417FA1794440444FCAA4868A4A40C9FFE4EFDE754440444FCAA4868A4A40
25729	5671	40.744680000000002	40.765448999999997	52.864570999999998	52.849634999999999	Школьная	0103000020E610000001000000050000001EFE9AAC515F4440BB44F5D6C06C4A401EFE9AAC515F4440F6083543AA6E4A40C1E09A3BFA614440F6083543AA6E4A40C1E09A3BFA614440BB44F5D6C06C4A401EFE9AAC515F4440BB44F5D6C06C4A40
25507	47830	40.958289999999998	40.977370000000001	53.023131999999997	53.011670000000002	Центральная	0103000020E61000000100000005000000BB0A293FA97A4440132C0E677E814A40BB0A293FA97A4440DBBE47FDF5824A40B70BCD751A7D4440DBBE47FDF5824A40B70BCD751A7D4440132C0E677E814A40BB0A293FA97A4440132C0E677E814A40
25622	47568	42.359563000000001	42.426937000000002	51.726678999999997	51.689565999999999	переулок Коммунульный	0103000020E6100000010000000500000003ED0E29062E45407E37DDB243D8494003ED0E29062E454051D845D103DD4940E73922DFA536454051D845D103DD4940E73922DFA53645407E37DDB243D8494003ED0E29062E45407E37DDB243D84940
25540	47568	42.359563000000001	42.426937000000002	51.726678999999997	51.689565999999999	Интернациональная	0103000020E6100000010000000500000003ED0E29062E45407E37DDB243D8494003ED0E29062E454051D845D103DD4940E73922DFA536454051D845D103DD4940E73922DFA53645407E37DDB243D8494003ED0E29062E45407E37DDB243D84940
25410	47250	42.360982	42.413085000000002	51.829214999999998	51.808478000000001	Молодежная	0103000020E61000000100000005000000EB387EA8342E45408BC404357CE74940EB387EA8342E4540232D95B723EA4940EDBB22F8DF344540232D95B723EA4940EDBB22F8DF3445408BC404357CE74940EB387EA8342E45408BC404357CE74940
26128	47475	42.589818999999999	42.608674999999998	51.915705000000003	51.900781000000002	Центральная	0103000020E610000001000000050000009BC761307F4B4540D9EDB3CA4CF349409BC761307F4B454050E449D235F549404772F90FE94D454050E449D235F549404772F90FE94D4540D9EDB3CA4CF349409BC761307F4B4540D9EDB3CA4CF34940
25382	6879	42.484527999999997	42.506760999999997	51.663584999999998	51.649951999999999	Советская	0103000020E6100000010000000500000086FF7403053E454022FC8BA031D3494086FF7403053E4540DE8E705AF0D44940B2F1608BDD404540DE8E705AF0D44940B2F1608BDD40454022FC8BA031D3494086FF7403053E454022FC8BA031D34940
75054	47283	42.30968	42.328814000000001	51.806835	51.790481999999997	Октябрьская	0103000020E61000000100000005000000D61C2098A3274540D009A1832EE54940D61C2098A32745405322895E46E74940C53BC093162A45405322895E46E74940C53BC093162A4540D009A1832EE54940D61C2098A3274540D009A1832EE54940
25612	47326	42.180861	42.193266999999999	51.751759999999997	51.740071999999998	Центральная	0103000020E61000000100000005000000990F087426174540B857E6ADBADE4940990F0874261745407138F3AB39E04940B1321AF9BC1845407138F3AB39E04940B1321AF9BC184540B857E6ADBADE4940990F087426174540B857E6ADBADE4940
25481	4048	42.374330999999998	42.436521999999997	51.912987999999999	51.873871000000001	Советская	0103000020E6100000010000000500000082700514EA2F45401FF64201DBEF494082700514EA2F4540FAD170CADCF4494004FEF0F3DF374540FAD170CADCF4494004FEF0F3DF3745401FF64201DBEF494082700514EA2F45401FF64201DBEF4940
25602	3472	42.413597000000003	42.509070000000001	51.874020999999999	51.829638000000003	Свердлова	0103000020E61000000100000005000000A35C1ABFF03445406AC2F69331EA4940A35C1ABFF034454034828DEBDFEF4940F7AFAC342941454034828DEBDFEF4940F7AFAC34294145406AC2F69331EA4940A35C1ABFF03445406AC2F69331EA4940
26101	3472	42.413597000000003	42.509070000000001	51.874020999999999	51.829638000000003	Красная	0103000020E61000000100000005000000A35C1ABFF03445406AC2F69331EA4940A35C1ABFF034454034828DEBDFEF4940F7AFAC342941454034828DEBDFEF4940F7AFAC34294145406AC2F69331EA4940A35C1ABFF03445406AC2F69331EA4940
25607	3472	42.413597000000003	42.509070000000001	51.874020999999999	51.829638000000003	Заводская	0103000020E61000000100000005000000A35C1ABFF03445406AC2F69331EA4940A35C1ABFF034454034828DEBDFEF4940F7AFAC342941454034828DEBDFEF4940F7AFAC34294145406AC2F69331EA4940A35C1ABFF03445406AC2F69331EA4940
25879	4436	42.337176999999997	42.390286000000003	51.790917	51.771315000000001	Советская	0103000020E6100000010000000500000050FBAD9D282B454006F52D73BAE2494050FBAD9D282B4540DB6CACC43CE54940180B43E4F4314540DB6CACC43CE54940180B43E4F431454006F52D73BAE2494050FBAD9D282B454006F52D73BAE24940
25477	47247	42.403768999999997	42.433647000000001	51.840206999999999	51.825614000000002	Первомайская	0103000020E61000000100000005000000BE11DDB3AE334540548F34B8ADE94940BE11DDB3AE334540656F29E78BEB49401781B1BE81374540656F29E78BEB49401781B1BE81374540548F34B8ADE94940BE11DDB3AE334540548F34B8ADE94940
25486	47445	42.587529000000004	42.606994999999998	51.949294999999999	51.934776999999997	Садовая	0103000020E61000000100000005000000CE397826344B4540C806D2C5A6F74940CE397826344B4540CFA0A17F82F94940F2EA1C03B24D4540CFA0A17F82F94940F2EA1C03B24D4540C806D2C5A6F74940CE397826344B4540C806D2C5A6F74940
26117	47540	42.426892000000002	42.454093	51.741410000000002	51.725402000000003	Клубная	0103000020E610000001000000050000004776A565A4364540FC3905F9D9DC49404776A565A4364540B476DB85E6DE4940D82B2CB81F3A4540B476DB85E6DE4940D82B2CB81F3A4540FC3905F9D9DC49404776A565A4364540FC3905F9D9DC4940
25875	51211	42.418097000000003	42.457200999999998	51.799194	51.784002999999998	Красная	0103000020E6100000010000000500000022C7D63384354540A27BD6355AE4494022C7D6338435454068942EFD4BE649406859F78F853A454068942EFD4BE649406859F78F853A4540A27BD6355AE4494022C7D63384354540A27BD6355AE44940
26113	4091	42.684061999999997	42.702711000000001	52.065919000000001	52.054240999999998	Малиновская	0103000020E61000000100000005000000DA37F7578F574540198D7C5EF1064A40DA37F7578F574540AF97A60870084A400DC51D6FF2594540AF97A60870084A400DC51D6FF2594540198D7C5EF1064A40DA37F7578F574540198D7C5EF1064A40
25478	47304	42.276288999999998	42.307640999999997	51.759146999999999	51.734695000000002	Набережная	0103000020E610000001000000050000004D9F1D705D23454072C45A7C0ADE49404D9F1D705D234540A2ED98BA2BE1494051F4C0C760274540A2ED98BA2BE1494051F4C0C76027454072C45A7C0ADE49404D9F1D705D23454072C45A7C0ADE4940
25821	47764	42.178077000000002	42.187562999999997	51.734845999999997	51.725864999999999	Центральная	0103000020E61000000100000005000000BC95253ACB164540D027F224E9DC4940BC95253ACB16454057CC086F0FDE494046787B100218454057CC086F0FDE494046787B1002184540D027F224E9DC4940BC95253ACB164540D027F224E9DC4940
26213	46287	41.543559999999999	41.577022999999997	53.514015999999998	53.506309999999999	Школьная	0103000020E61000000100000005000000F6B4C35F93C54440A2D11DC4CEC04A40F6B4C35F93C5444074CFBA46CBC14A401805C1E3DBC9444074CFBA46CBC14A401805C1E3DBC94440A2D11DC4CEC04A40F6B4C35F93C54440A2D11DC4CEC04A40
25850	1815	41.805069000000003	41.862876	53.492389000000003	53.461441000000001	Центральная	0103000020E61000000100000005000000000341800CE744404B04AA7F10BB4A40000341800CE7444080F44D9A06BF4A406C4084B872EE444080F44D9A06BF4A406C4084B872EE44404B04AA7F10BB4A40000341800CE744404B04AA7F10BB4A40
25990	1815	41.805069000000003	41.862876	53.492389000000003	53.461441000000001	Рабочая	0103000020E61000000100000005000000000341800CE744404B04AA7F10BB4A40000341800CE7444080F44D9A06BF4A406C4084B872EE444080F44D9A06BF4A406C4084B872EE44404B04AA7F10BB4A40000341800CE744404B04AA7F10BB4A40
26074	1815	41.805069000000003	41.862876	53.492389000000003	53.461441000000001	Октяборьская	0103000020E61000000100000005000000000341800CE744404B04AA7F10BB4A40000341800CE7444080F44D9A06BF4A406C4084B872EE444080F44D9A06BF4A406C4084B872EE44404B04AA7F10BB4A40000341800CE744404B04AA7F10BB4A40
75295	1815	41.805069000000003	41.862876	53.492389000000003	53.461441000000001	МСО	0103000020E61000000100000005000000000341800CE744404B04AA7F10BB4A40000341800CE7444080F44D9A06BF4A406C4084B872EE444080F44D9A06BF4A406C4084B872EE44404B04AA7F10BB4A40000341800CE744404B04AA7F10BB4A40
26080	1697	41.878380999999997	41.906542999999999	53.771875999999999	53.722782000000002	Центральная	0103000020E61000000100000005000000C136E2C96EF044409911DE1E84DC4A40C136E2C96EF044409D4830D5CCE24A4078B5DC9909F444409D4830D5CCE24A4078B5DC9909F444409911DE1E84DC4A40C136E2C96EF044409911DE1E84DC4A40
26079	51228	41.65249	41.668148000000002	53.466875999999999	53.455908000000001	Привокзальная	0103000020E61000000100000005000000C87BD5CA84D344400DFE7E315BBA4A40C87BD5CA84D34440C6A4BF97C2BB4A40A471A8DF85D54440C6A4BF97C2BB4A40A471A8DF85D544400DFE7E315BBA4A40C87BD5CA84D344400DFE7E315BBA4A40
25925	1638	41.810495000000003	41.871985000000002	53.630583999999999	53.607441999999999	Центральная	0103000020E610000001000000050000002849D74CBEE74440C11BD2A8C0CD4A402849D74CBEE74440C0B0FCF9B6D04A4021CD58349DEF4440C0B0FCF9B6D04A4021CD58349DEF4440C11BD2A8C0CD4A402849D74CBEE74440C11BD2A8C0CD4A40
25961	32359	41.773215	41.791063999999999	53.710541999999997	53.676254999999998	Центральная	0103000020E6100000010000000500000069E388B5F8E24440D4601A868FD64A4069E388B5F8E244409B374E0AF3DA4A407F85CC9541E544409B374E0AF3DA4A407F85CC9541E54440D4601A868FD64A4069E388B5F8E24440D4601A868FD64A40
26323	45767	41.667492000000003	41.698627999999999	53.662998999999999	53.641257000000003	Интернациональная	0103000020E61000000100000005000000BB2BBB6070D5444061AA99B514D24A40BB2BBB6070D54440EE23B726DDD44A40F2086EA46CD94440EE23B726DDD44A40F2086EA46CD9444061AA99B514D24A40BB2BBB6070D5444061AA99B514D24A40
25848	1984	41.593362999999997	41.643901999999997	53.583105000000003	53.533029999999997	Центральная	0103000020E6100000010000000500000006D49B51F3CB4440B8E4B8533AC44A4006D49B51F3CB44402A91442FA3CA4A401CEA77616BD244402A91442FA3CA4A401CEA77616BD24440B8E4B8533AC44A4006D49B51F3CB4440B8E4B8533AC44A40
25986	46537	42.041829	42.064915999999997	53.744743	53.720432000000002	Хлебная	0103000020E610000001000000050000001F8315A75A054540F67EA31D37DC4A401F8315A75A054540647616BD53DF4A405A7EE02A4F084540647616BD53DF4A405A7EE02A4F084540F67EA31D37DC4A401F8315A75A054540F67EA31D37DC4A40
25402	45914	41.762058000000003	41.791738000000002	53.414549000000001	53.396597999999997	Новая	0103000020E61000000100000005000000DDD3D51D8BE144405AD427B9C3B24A40DDD3D51D8BE1444075CB0EF10FB54A400F80B8AB57E5444075CB0EF10FB54A400F80B8AB57E544405AD427B9C3B24A40DDD3D51D8BE144405AD427B9C3B24A40
25497	45814	41.438915999999999	41.523223000000002	53.693308999999999	53.536839999999998	Молодежная	0103000020E6100000010000000500000077D844662EB84440A297512CB7C44A4077D844662EB84440E0826C59BED84A40ECC1A4F8F8C24440E0826C59BED84A40ECC1A4F8F8C24440A297512CB7C44A4077D844662EB84440A297512CB7C44A40
25703	694	41.735207000000003	41.780481999999999	53.380260999999997	53.345640000000003	Молодежная	0103000020E61000000100000005000000286552431BDE4440401878EE3DAC4A40286552431BDE4440DD787764ACB04A40EF8E8CD5E6E34440DD787764ACB04A40EF8E8CD5E6E34440401878EE3DAC4A40286552431BDE4440401878EE3DAC4A40
26345	46478	41.783895999999999	41.835675000000002	53.628779000000002	53.608446000000001	Центральная	0103000020E610000001000000050000008CBB41B456E44440E6B0FB8EE1CD4A408CBB41B456E44440AFB48CD47BD04A40DB8AFD65F7EA4440AFB48CD47BD04A40DB8AFD65F7EA4440E6B0FB8EE1CD4A408CBB41B456E44440E6B0FB8EE1CD4A40
26329	262	41.243639999999999	41.287145000000002	53.511285000000001	53.45091	Мира	0103000020E61000000100000005000000ACFF73982F9F44403DB83B6BB7B94A40ACFF73982F9F4440BAF770C971C14A40DF1AD82AC1A44440BAF770C971C14A40DF1AD82AC1A444403DB83B6BB7B94A40ACFF73982F9F44403DB83B6BB7B94A40
26196	1298	41.777912999999998	41.814959999999999	53.802090999999997	53.783969999999997	Центральная	0103000020E610000001000000050000000E1137A792E34440C685032159E44A400E1137A792E344403DB5FAEAAAE64A402AC6F99B50E844403DB5FAEAAAE64A402AC6F99B50E84440C685032159E44A400E1137A792E34440C685032159E44A40
25450	1248	41.766612000000002	41.811546	53.785943000000003	53.766430999999997	Школьная	0103000020E610000001000000050000004F5C8E5720E24440FED137691AE24A404F5C8E5720E2444094C2BCC799E44A408D9944BDE0E7444094C2BCC799E44A408D9944BDE0E74440FED137691AE24A404F5C8E5720E24440FED137691AE24A40
25786	45973	41.492607999999997	41.536400999999998	53.517811999999999	53.494638999999999	1-ая Заводская	0103000020E61000000100000005000000BDDF68C70DBF4440BF29AC5450BF4A40BDDF68C70DBF4440F9BCE2A947C24A405645B8C9A8C44440F9BCE2A947C24A405645B8C9A8C44440BF29AC5450BF4A40BDDF68C70DBF4440BF29AC5450BF4A40
25687	32492	41.846580000000003	41.869540999999998	53.561101999999998	53.544561999999999	Лоскутовка	0103000020E610000001000000050000004EB9C2BB5CEC44407A522635B4C54A404EB9C2BB5CEC44402FDCB930D2C74A40FCC3961E4DEF44402FDCB930D2C74A40FCC3961E4DEF44407A522635B4C54A404EB9C2BB5CEC44407A522635B4C54A40
26209	1002	41.491996999999998	41.571193000000001	53.468049999999998	53.438226	Ольховка	0103000020E61000000100000005000000745DF8C1F9BE4440E22021CA17B84A40745DF8C1F9BE44404772F90FE9BB4A40215A2BDA1CC944404772F90FE9BB4A40215A2BDA1CC94440E22021CA17B84A40745DF8C1F9BE4440E22021CA17B84A40
25570	392	42.233286999999997	42.265158999999997	53.448920999999999	53.435581999999997	Школьная	0103000020E610000001000000050000007DCA3159DC1D4540F65CA626C1B74A407DCA3159DC1D45406ABE4A3E76B94A40BA9EE8BAF02145406ABE4A3E76B94A40BA9EE8BAF0214540F65CA626C1B74A407DCA3159DC1D4540F65CA626C1B74A40
25712	46329	41.749274999999997	41.784641000000001	53.299044000000002	53.279089999999997	Центральная	0103000020E61000000100000005000000EE5A423EE8DF444000529B38B9A34A40EE5A423EE8DF44405308E41247A64A40E50CC51D6FE444405308E41247A64A40E50CC51D6FE4444000529B38B9A34A40EE5A423EE8DF444000529B38B9A34A40
26076	46194	41.740929000000001	41.793219999999998	53.401473000000003	53.379708000000001	60 лет СССР	0103000020E6100000010000000500000039D4EFC2D6DE4440C90391459AB04A4039D4EFC2D6DE44400F9D9E7763B34A403D44A33B88E544400F9D9E7763B34A403D44A33B88E54440C90391459AB04A4039D4EFC2D6DE4440C90391459AB04A40
26107	49479	41.780895000000001	41.806443000000002	53.759895	53.742345999999998	Центральная	0103000020E61000000100000005000000124E0B5EF4E344408028983105DF4A40124E0B5EF4E344406CB2463D44E14A40488B338639E744406CB2463D44E14A40488B338639E744408028983105DF4A40124E0B5EF4E344408028983105DF4A40
26214	1133	41.713459	41.759956000000003	53.287945999999998	53.259951000000001	Тамбовская	0103000020E61000000100000005000000B804E09F52DB444000C8091346A14A40B804E09F52DB4440CB811E6ADBA44A401233FB3C46E14440CB811E6ADBA44A401233FB3C46E1444000C8091346A14A40B804E09F52DB444000C8091346A14A40
25523	774	41.824553999999999	41.880203999999999	53.519674999999999	53.489618999999998	Новая	0103000020E610000001000000050000009BE447FC8AE944400740DCD5ABBE4A409BE447FC8AE944403FC6DCB584C24A4079E75086AAF044403FC6DCB584C24A4079E75086AAF044400740DCD5ABBE4A409BE447FC8AE944400740DCD5ABBE4A40
25399	653	41.746634	41.795250000000003	53.347988999999998	53.304952999999998	Ламзина	0103000020E61000000100000005000000740AF2B391DF444096E82CB308A74A40740AF2B391DF4440122F4FE78AAC4A406F1283C0CAE54440122F4FE78AAC4A406F1283C0CAE5444096E82CB308A74A40740AF2B391DF444096E82CB308A74A40
25585	51180	41.854619999999997	41.884228999999998	53.684286999999998	53.671652000000002	Колхозна	0103000020E61000000100000005000000F6402B3064ED4440812557B1F8D54A40F6402B3064ED4440FA0967B796D74A405F96766A2EF14440FA0967B796D74A405F96766A2EF14440812557B1F8D54A40F6402B3064ED4440812557B1F8D54A40
25752	51197	41.452364000000003	41.481746999999999	53.724625000000003	53.713425000000001	Зеленая	0103000020E61000000100000005000000A2F14410E7B944400C93A98251DB4A40A2F14410E7B94440986E1283C0DC4A401AF9BCE2A9BD4440986E1283C0DC4A401AF9BCE2A9BD44400C93A98251DB4A40A2F14410E7B944400C93A98251DB4A40
26162	46437	41.739249000000001	41.781928000000001	53.641246000000002	53.620944999999999	1-ая Лимасово	0103000020E61000000100000005000000E44C13B69FDE4440AFCE31207BCF4A40E44C13B69FDE44406D58535914D24A40D1E9793716E444406D58535914D24A40D1E9793716E44440AFCE31207BCF4A40E44C13B69FDE4440AFCE31207BCF4A40
26194	46006	42.041721000000003	42.063577000000002	53.418370000000003	53.403615000000002	Школьная	0103000020E6100000010000000500000039471D1D57054540689604A8A9B34A4039471D1D5705454053D0ED258DB54A408FE3874A2308454053D0ED258DB54A408FE3874A23084540689604A8A9B34A4039471D1D57054540689604A8A9B34A40
25649	46006	42.041721000000003	42.063577000000002	53.418370000000003	53.403615000000002	Центральная	0103000020E6100000010000000500000039471D1D57054540689604A8A9B34A4039471D1D5705454053D0ED258DB54A408FE3874A2308454053D0ED258DB54A408FE3874A23084540689604A8A9B34A4039471D1D57054540689604A8A9B34A40
25373	45952	41.411706000000002	41.493685999999997	53.492384000000001	53.459296000000002	Школьная	0103000020E6100000010000000500000093C83EC8B2B4444081971936CABA4A4093C83EC8B2B444406E895C7006BF4A401C3F541A31BF44406E895C7006BF4A401C3F541A31BF444081971936CABA4A4093C83EC8B2B4444081971936CABA4A40
25830	45926	41.594208000000002	41.625737999999998	53.780904999999997	53.745344000000003	Советская	0103000020E61000000100000005000000C382FB010FCC44408A22A46E67DF4A40C382FB010FCC44403524EEB1F4E34A40A6EECA2E18D044403524EEB1F4E34A40A6EECA2E18D044408A22A46E67DF4A40C382FB010FCC44408A22A46E67DF4A40
25577	46236	41.501322000000002	41.538907000000002	53.407522999999998	53.373578999999999	Заря	0103000020E61000000100000005000000F661BD512BC0444077BCC96FD1AF4A40F661BD512BC0444014AFB2B629B44A40F14A92E7FAC4444014AFB2B629B44A40F14A92E7FAC4444077BCC96FD1AF4A40F661BD512BC0444077BCC96FD1AF4A40
25372	32451	41.831524000000002	41.858823999999998	53.610145000000003	53.587519999999998	Центральная	0103000020E6100000010000000500000068EBE0606FEA44407ADFF8DA33CB4A4068EBE0606FEA4440B2683A3B19CE4A408C82E0F1EDED4440B2683A3B19CE4A408C82E0F1EDED44407ADFF8DA33CB4A4068EBE0606FEA44407ADFF8DA33CB4A40
25496	32361	41.841369999999998	41.871184999999997	53.586435000000002	53.568621	Новая	0103000020E61000000100000005000000F2EA1C03B2EB4440CF68AB92C8C84A40F2EA1C03B2EB4440691D554D10CB4A4004E275FD82EF4440691D554D10CB4A4004E275FD82EF4440CF68AB92C8C84A40F2EA1C03B2EB4440CF68AB92C8C84A40
25428	32108	41.633662000000001	41.724229999999999	53.700986	53.663905999999997	Ильинка	0103000020E61000000100000005000000E65B1FD61BD1444020CF2EDFFAD44A40E65B1FD61BD14440187AC4E8B9D94A401B649291B3DC4440187AC4E8B9D94A401B649291B3DC444020CF2EDFFAD44A40E65B1FD61BD1444020CF2EDFFAD44A40
25436	32108	41.633662000000001	41.724229999999999	53.700986	53.663905999999997	Гоголя	0103000020E61000000100000005000000E65B1FD61BD1444020CF2EDFFAD44A40E65B1FD61BD14440187AC4E8B9D94A401B649291B3DC4440187AC4E8B9D94A401B649291B3DC444020CF2EDFFAD44A40E65B1FD61BD1444020CF2EDFFAD44A40
26187	1758	40.613553000000003	40.647644	52.035142	52.020929000000002	Центральная	0103000020E610000001000000050000006DAE9AE7884E4440DD442DCDAD024A406DAE9AE7884E4440A75B76887F044A40AEB9A3FFE5524440A75B76887F044A40AEB9A3FFE5524440DD442DCDAD024A406DAE9AE7884E4440DD442DCDAD024A40
26301	1059	40.838876999999997	40.854202000000001	52.194676999999999	52.184359000000001	Луговая 	0103000020E61000000100000005000000EC2E5052606B444094DC611399174A40EC2E5052606B444046240A2DEB184A40C216BB7D566D444046240A2DEB184A40C216BB7D566D444094DC611399174A40EC2E5052606B444094DC611399174A40
26081	45577	40.843530000000001	40.922133000000002	52.166139000000001	52.120122000000002	Школьная	0103000020E61000000100000005000000F29881CAF86B4440DBC35E28600F4A40F29881CAF86B44408ACBF10A44154A40FCC74274087644408ACBF10A44154A40FCC7427408764440DBC35E28600F4A40F29881CAF86B4440DBC35E28600F4A40
75468	45577	40.843530000000001	40.922133000000002	52.166139000000001	52.120122000000002	Техническая	0103000020E61000000100000005000000F29881CAF86B4440DBC35E28600F4A40F29881CAF86B44408ACBF10A44154A40FCC74274087644408ACBF10A44154A40FCC7427408764440DBC35E28600F4A40F29881CAF86B4440DBC35E28600F4A40
25571	45577	40.843530000000001	40.922133000000002	52.166139000000001	52.120122000000002	Революционная	0103000020E61000000100000005000000F29881CAF86B4440DBC35E28600F4A40F29881CAF86B44408ACBF10A44154A40FCC74274087644408ACBF10A44154A40FCC7427408764440DBC35E28600F4A40F29881CAF86B4440DBC35E28600F4A40
25701	45577	40.843530000000001	40.922133000000002	52.166139000000001	52.120122000000002	Кирпичная	0103000020E61000000100000005000000F29881CAF86B4440DBC35E28600F4A40F29881CAF86B44408ACBF10A44154A40FCC74274087644408ACBF10A44154A40FCC7427408764440DBC35E28600F4A40F29881CAF86B4440DBC35E28600F4A40
25814	1250	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	Школьная	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
25811	1250	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	Техническая	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
25538	1250	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	Пятилетка	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
25559	1250	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	Интернациональная	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
26060	1250	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	70 лет Октября	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
26233	1250	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	2-я Революционная	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
25643	1250	40.733576999999997	40.831708999999996	52.131556000000003	52.06644	1-я Революционная	0103000020E61000000100000005000000840CE4D9E55D4440B8921D1B81084A40840CE4D9E55D4440DACBB6D3D6104A40F964C570756A4440DACBB6D3D6104A40F964C570756A4440B8921D1B81084A40840CE4D9E55D4440B8921D1B81084A40
26139	3585	40.545307999999999	40.575572000000001	52.010947000000002	51.985030000000002	Школьная	0103000020E61000000100000005000000A31F0DA7CC45444019CA897615FE4940A31F0DA7CC454440A27E17B666014A40253FE257AC494440A27E17B666014A40253FE257AC49444019CA897615FE4940A31F0DA7CC45444019CA897615FE4940
25869	3013	40.791536000000001	40.833820000000003	52.030327999999997	52.018811999999997	Центральная	0103000020E61000000100000005000000A7CD380D51654440DC627E6E68024A40A7CD380D516544409813B4C9E1034A4018601F9DBA6A44409813B4C9E1034A4018601F9DBA6A4440DC627E6E68024A40A7CD380D51654440DC627E6E68024A40
25495	48438	40.084812999999997	40.143391999999999	52.871149000000003	52.853538999999998	Советская	0103000020E6100000010000000500000048A30227DB0A4440266E15C4406D4A4048A30227DB0A4440B87878CF816F4A40074147AB5A124440B87878CF816F4A40074147AB5A124440266E15C4406D4A4048A30227DB0A4440266E15C4406D4A40
26135	48803	40.530638000000003	40.541938999999999	52.938682999999997	52.929161999999998	Горького	0103000020E61000000100000005000000E7012CF2EB434440CD57C9C7EE764A40E7012CF2EB434440D427B9C326784A40A6B6D4415E454440D427B9C326784A40A6B6D4415E454440CD57C9C7EE764A40E7012CF2EB434440CD57C9C7EE764A40
25488	48332	40.426991000000001	40.488731999999999	52.838048999999998	52.812350000000002	Советская	0103000020E61000000100000005000000DA571EA4A7364440EB73B515FB674A40DA571EA4A736444006B98B30456B4A401C412AC58E3E444006B98B30456B4A401C412AC58E3E4440EB73B515FB674A40DA571EA4A7364440EB73B515FB674A40
25637	28510	40.536594000000001	40.563085000000001	52.956301000000003	52.936169999999997	Исакова	0103000020E610000001000000050000006B9DB81CAF44444087BF266BD4774A406B9DB81CAF444440E9103812687A4A4020EF552B13484440E9103812687A4A4020EF552B1348444087BF266BD4774A406B9DB81CAF44444087BF266BD4774A40
26104	48255	40.621512000000003	40.656187000000003	52.788916	52.772390000000001	Поперечная	0103000020E61000000100000005000000290989B48D4F4440F4E0EEACDD624A40290989B48D4F444044A51133FB644A40BA8784EFFD53444044A51133FB644A40BA8784EFFD534440F4E0EEACDD624A40290989B48D4F4440F4E0EEACDD624A40
26124	48556	40.352817000000002	40.379029000000003	53.012839999999997	53.001151999999998	Советская	0103000020E61000000100000005000000863C821B292D44409929ADBF25804A40863C821B292D4440520ABABDA4814A40289EB30584304440520ABABDA4814A40289EB305843044409929ADBF25804A40863C821B292D44409929ADBF25804A40
25367	27279	40.501190999999999	40.542703000000003	52.806781000000001	52.781613	Белаховой	0103000020E610000001000000050000005706D50627404440719010E50B644A405706D5062740444060048D9944674A407638BA4A7745444060048D9944674A407638BA4A77454440719010E50B644A405706D50627404440719010E50B644A40
26119	27575	40.304307999999999	40.333727000000003	52.876708999999998	52.847605999999999	Советская	0103000020E61000000100000005000000A1F48590F32644405AF2785A7E6C4A40A1F48590F3264440EF8D210038704A406765FB90B72A4440EF8D210038704A406765FB90B72A44405AF2785A7E6C4A40A1F48590F32644405AF2785A7E6C4A40
26121	27670	40.147210000000001	40.175120999999997	52.865572	52.849226999999999	Рахманинова	0103000020E6100000010000000500000074D2FBC6D7124440AAF06778B36C4A4074D2FBC6D7124440AA2A3410CB6E4A40E1EB6B5D6A164440AA2A3410CB6E4A40E1EB6B5D6A164440AAF06778B36C4A4074D2FBC6D7124440AAF06778B36C4A40
25822	46966	40.407093000000003	40.429371000000003	52.862456000000002	52.835863000000003	Красноармейская	0103000020E610000001000000050000001CB7989F1B344440DE770C8FFD6A4A401CB7989F1B344440971E4DF5646E4A40E86C01A1F5364440971E4DF5646E4A40E86C01A1F5364440DE770C8FFD6A4A401CB7989F1B344440DE770C8FFD6A4A40
26248	48491	40.377088999999998	40.400615999999999	52.961275000000001	52.949236999999997	Центральная	0103000020E610000001000000050000003657CD73443044409A93179980794A403657CD734430444030BB270F0B7B4A408E2095624733444030BB270F0B7B4A408E209562473344409A93179980794A403657CD73443044409A93179980794A40
25894	51215	40.690359000000001	40.713974999999998	53.138365	53.130639000000002	Центральная	0103000020E61000000100000005000000E8BF07AF5D584440844A5CC7B8904A40E8BF07AF5D5844409DF4BEF1B5914A40AF946588635B44409DF4BEF1B5914A40AF946588635B4440844A5CC7B8904A40E8BF07AF5D584440844A5CC7B8904A40
26012	27849	40.232298999999998	40.277600999999997	52.983486999999997	52.964334000000001	Революционная	0103000020E610000001000000050000005EF23FF9BB1D4440DF35E84B6F7B4A405EF23FF9BB1D44404485EAE6E27D4A401F2BF86D882344404485EAE6E27D4A401F2BF86D88234440DF35E84B6F7B4A405EF23FF9BB1D4440DF35E84B6F7B4A40
26008	48110	40.549332	40.584699000000001	52.904173999999998	52.882432000000001	Луговая	0103000020E61000000100000005000000B952CF8250464440D1782288F3704A40B952CF82504644405EF23FF9BB734A408080B56AD74A44405EF23FF9BB734A408080B56AD74A4440D1782288F3704A40B952CF8250464440D1782288F3704A40
25385	28650	40.510120999999998	40.526802000000004	52.977502000000001	52.969057999999997	Спортивная	0103000020E610000001000000050000005C001AA54B414440ADF6B0170A7C4A405C001AA54B41444026E318C91E7D4A40D4BB783F6E43444026E318C91E7D4A40D4BB783F6E434440ADF6B0170A7C4A405C001AA54B414440ADF6B0170A7C4A40
25631	27987	40.373631000000003	40.401918999999999	53.031900999999998	53.010337	Коммунистическая	0103000020E61000000100000005000000CAE2FE23D32F444029780AB952814A40CAE2FE23D32F4440D7DAFB5415844A400D52F01472334440D7DAFB5415844A400D52F0147233444029780AB952814A40CAE2FE23D32F444029780AB952814A40
25451	45526	40.378014	40.430584000000003	52.837972999999998	52.812474999999999	Советская	0103000020E610000001000000050000000FB743C362304440A7E8482EFF674A400FB743C3623044402BF702B3426B4A40271763601D3744402BF702B3426B4A40271763601D374440A7E8482EFF674A400FB743C362304440A7E8482EFF674A40
25867	45526	40.378014	40.430584000000003	52.837972999999998	52.812474999999999	Максима Горького	0103000020E610000001000000050000000FB743C362304440A7E8482EFF674A400FB743C3623044402BF702B3426B4A40271763601D3744402BF702B3426B4A40271763601D374440A7E8482EFF674A400FB743C362304440A7E8482EFF674A40
26011	27282	40.476298999999997	40.500822999999997	52.788094000000001	52.771546000000001	Замостье	0103000020E610000001000000050000000A0F9A5DF73C444008AEF204C2624A400A0F9A5DF73C44404016A243E0644A40D40AD3F71A4044404016A243E0644A40D40AD3F71A40444008AEF204C2624A400A0F9A5DF73C444008AEF204C2624A40
25623	27716	40.219552	40.286026999999997	52.845723999999997	52.833447	Центральная	0103000020E61000000100000005000000BDE2A9471A1C444083F92B64AE6A4A40BDE2A9471A1C44409DB81CAF406C4A40F16261889C2444409DB81CAF406C4A40F16261889C24444083F92B64AE6A4A40BDE2A9471A1C444083F92B64AE6A4A40
25626	27933	40.192306000000002	40.211663999999999	53.000999999999998	52.988605	Лесная	0103000020E610000001000000050000008C69A67B9D184440BFD4CF9B8A7E4A408C69A67B9D184440E3A59BC420804A40CADE52CE171B4440E3A59BC420804A40CADE52CE171B4440BFD4CF9B8A7E4A408C69A67B9D184440BFD4CF9B8A7E4A40
26251	51249	40.306176000000001	40.328724000000001	52.932429999999997	52.90419	Липовская	0103000020E61000000100000005000000F96871C63027444064AF777FBC734A40F96871C63027444096E7C1DD59774A4085B4C6A0132A444096E7C1DD59774A4085B4C6A0132A444064AF777FBC734A40F96871C63027444064AF777FBC734A40
25749	48281	40.546826000000003	40.608728999999997	52.770640999999998	52.755710999999998	Леонова	0103000020E610000001000000050000001F4DF564FE4544401D1D5723BB604A401F4DF564FE45444076FA415DA4624A403A90F5D4EA4D444076FA415DA4624A403A90F5D4EA4D44401D1D5723BB604A401F4DF564FE4544401D1D5723BB604A40
25742	46727	40.583359999999999	40.623299000000003	52.995603000000003	52.967593999999998	Центральная	0103000020E61000000100000005000000B4E55C8AAB4A444025E7C41EDA7B4A40B4E55C8AAB4A444056664AEB6F7F4A409450FA42C84F444056664AEB6F7F4A409450FA42C84F444025E7C41EDA7B4A40B4E55C8AAB4A444025E7C41EDA7B4A40
26022	48702	40.585282999999997	40.630935000000001	53.058140999999999	53.026707000000002	Коммунальная	0103000020E61000000100000005000000CFF3A78DEA4A444082C98D226B834A40CFF3A78DEA4A444043C70E2A71874A406D73637AC250444043C70E2A71874A406D73637AC250444082C98D226B834A40CFF3A78DEA4A444082C98D226B834A40
25836	46977	40.471142999999998	40.537582	53.059640000000002	52.947132000000003	Центральная	0103000020E61000000100000005000000A25EF0694E3C44405F7F129F3B794A40A25EF0694E3C444048C49448A2874A408A75AA7CCF44444048C49448A2874A408A75AA7CCF4444405F7F129F3B794A40A25EF0694E3C44405F7F129F3B794A40
25442	46977	40.471142999999998	40.537582	53.059640000000002	52.947132000000003	Мира	0103000020E61000000100000005000000A25EF0694E3C44405F7F129F3B794A40A25EF0694E3C444048C49448A2874A408A75AA7CCF44444048C49448A2874A408A75AA7CCF4444405F7F129F3B794A40A25EF0694E3C44405F7F129F3B794A40
25831	48134	40.579363000000001	40.595118999999997	52.910451999999999	52.900024000000002	Парковая	0103000020E6100000010000000500000098C11891284A4440BCCE86FC33734A4098C11891284A4440F549EEB089744A40361D01DC2C4C4440F549EEB089744A40361D01DC2C4C4440BCCE86FC33734A4098C11891284A4440BCCE86FC33734A40
75327	48240	40.663274000000001	40.690314000000001	52.855203000000003	52.841166000000001	микрорайон Южный	0103000020E61000000100000005000000C0249529E6544440EA40D653AB6B4A40C0249529E65444407638BA4A776D4A4048FC8A355C5844407638BA4A776D4A4048FC8A355C584440EA40D653AB6B4A40C0249529E6544440EA40D653AB6B4A40
25862	48240	40.663274000000001	40.690314000000001	52.855203000000003	52.841166000000001	Школьная	0103000020E61000000100000005000000C0249529E6544440EA40D653AB6B4A40C0249529E65444407638BA4A776D4A4048FC8A355C5844407638BA4A776D4A4048FC8A355C584440EA40D653AB6B4A40C0249529E6544440EA40D653AB6B4A40
26030	48836	40.555351000000002	40.595846999999999	52.985211	52.957889999999999	Ворошилова	0103000020E610000001000000050000008466D7BD154744402D95B7239C7A4A408466D7BD154744406954E0641B7E4A40B935E9B6444C44406954E0641B7E4A40B935E9B6444C44402D95B7239C7A4A408466D7BD154744402D95B7239C7A4A40
25778	26945	40.530315000000002	40.572184999999998	52.888908999999998	52.869126999999999	Строителей	0103000020E6100000010000000500000004CAA65CE14344400989B48D3F6F4A4004CAA65CE14344405E0F26C5C7714A408121AB5B3D4944405E0F26C5C7714A408121AB5B3D4944400989B48D3F6F4A4004CAA65CE14344400989B48D3F6F4A40
25377	26945	40.530315000000002	40.572184999999998	52.888908999999998	52.869126999999999	Советская	0103000020E6100000010000000500000004CAA65CE14344400989B48D3F6F4A4004CAA65CE14344405E0F26C5C7714A408121AB5B3D4944405E0F26C5C7714A408121AB5B3D4944400989B48D3F6F4A4004CAA65CE14344400989B48D3F6F4A40
25386	48515	40.309643999999999	40.347659999999998	52.963174000000002	52.931339000000001	Советская	0103000020E6100000010000000500000089B3226AA2274440A33EC91D36774A4089B3226AA2274440C32D1F49497B4A404D10751F802C4440C32D1F49497B4A404D10751F802C4440A33EC91D36774A4089B3226AA2274440A33EC91D36774A40
25755	28105	40.504479000000003	40.525931	53.019379000000001	53.004106	Заречная	0103000020E61000000100000005000000684293C492404440D3DB9F8B86804A40684293C492404440569DD5027B824A40EE79FEB451434440569DD5027B824A40EE79FEB451434440D3DB9F8B86804A40684293C492404440D3DB9F8B86804A40
25994	48413	40.642837999999998	40.667001999999997	53.143988	53.118653999999999	Школьная	0103000020E610000001000000050000002250FD834852444011C5E40D308F4A402250FD83485244401B82E3326E924A40EC2E5052605544401B82E3326E924A40EC2E50526055444011C5E40D308F4A402250FD834852444011C5E40D308F4A40
25761	28371	40.677368999999999	40.723399000000001	53.125393000000003	53.082115000000002	Пушкина	0103000020E6100000010000000500000080290307B45644406AC18BBE828A4A4080290307B4564440DC12B9E00C904A40C47AA356985C4440DC12B9E00C904A40C47AA356985C44406AC18BBE828A4A4080290307B45644406AC18BBE828A4A40
25369	48357	40.483970999999997	40.522858999999997	52.856029999999997	52.833556000000002	Центральная	0103000020E61000000100000005000000309B00C3F23D44403AB187F6B16A4A40309B00C3F23D44408B321B64926D4A40AAB5300BED4244408B321B64926D4A40AAB5300BED4244403AB187F6B16A4A40309B00C3F23D44403AB187F6B16A4A40
25616	51184	40.382505999999999	40.396996000000001	52.722610000000003	52.715961	Ленина	0103000020E610000001000000050000000B43E4F4F5304440111B2C9CA45B4A400B43E4F4F53044409CE1067C7E5C4A404852D2C3D03244409CE1067C7E5C4A404852D2C3D0324440111B2C9CA45B4A400B43E4F4F5304440111B2C9CA45B4A40
25765	47996	40.528401000000002	40.553176999999998	53.121448000000001	53.109048999999999	Советская	0103000020E610000001000000050000003C16DBA4A2434440AC545051F58D4A403C16DBA4A24344401215AA9B8B8F4A401FF30181CE4644401215AA9B8B8F4A401FF30181CE464440AC545051F58D4A403C16DBA4A2434440AC545051F58D4A40
25374	48618	40.458880999999998	40.478572	53.009849000000003	52.988469000000002	Молодежная	0103000020E61000000100000005000000BDE0D39CBC3A44400F0EF626867E4A40BDE0D39CBC3A4440FC7266BB42814A400264E8D8413D4440FC7266BB42814A400264E8D8413D44400F0EF626867E4A40BDE0D39CBC3A44400F0EF626867E4A40
75433	48770	41.475315000000002	41.487766000000001	52.611778999999999	52.600994	Лесная	0103000020E610000001000000050000002D26361FD7BC4440CE8B135FED4C4A402D26361FD7BC444096B036C64E4E4A40E50CC51D6FBE444096B036C64E4E4A40E50CC51D6FBE4440CE8B135FED4C4A402D26361FD7BC4440CE8B135FED4C4A40
26346	2172	42.724485999999999	42.778492	52.608853000000003	52.593522	Октябрьская	0103000020E6100000010000000500000076340EF5BB5C45406FBA6587F84B4A4076340EF5BB5C4540278925E5EE4D4A404C1938A0A5634540278925E5EE4D4A404C1938A0A56345406FBA6587F84B4A4076340EF5BB5C45406FBA6587F84B4A40
75378	46786	42.463057999999997	42.478096000000001	52.597351000000003	52.592680000000001	Центральная	0103000020E6100000010000000500000059130B7C453B4540247F30F0DC4B4A4059130B7C453B4540D09D60FF754C4A40992CEE3F323D4540D09D60FF754C4A40992CEE3F323D4540247F30F0DC4B4A4059130B7C453B4540247F30F0DC4B4A40
26226	2737	42.753051999999997	42.774621000000003	52.649428	52.641520999999997	Кирова	0103000020E61000000100000005000000FC170802646045403E59315C1D524A40FC17080264604540A88DEA7420534A40BDE5EAC726634540A88DEA7420534A40BDE5EAC7266345403E59315C1D524A40FC170802646045403E59315C1D524A40
25983	47164	42.510848000000003	42.535974000000003	52.692563	52.680700999999999	Заброд	0103000020E610000001000000050000000F9D9E776341454060ADDA3521574A400F9D9E7763414540B7B585E7A5584A40CFC0C8CB9A444540B7B585E7A5584A40CFC0C8CB9A44454060ADDA3521574A400F9D9E776341454060ADDA3521574A40
26086	46153	42.412725000000002	42.450059000000003	52.817214999999997	52.798712999999999	Центральная	0103000020E61000000100000005000000ED9E3C2CD4344540EDF1423A3C664A40ED9E3C2CD43445407B6649809A684A409F2287889B3945407B6649809A684A409F2287889B394540EDF1423A3C664A40ED9E3C2CD4344540EDF1423A3C664A40
25601	51182	42.383988000000002	42.393475000000002	52.799725000000002	52.793076999999997	Зеленая	0103000020E610000001000000050000003A07CF8426314540DA1A118C83654A403A07CF8426314540956588635D664A40956588635D324540956588635D664A40956588635D324540DA1A118C83654A403A07CF8426314540DA1A118C83654A40
25995	25548	42.837511999999997	42.849297999999997	52.646914000000002	52.638815999999998	Строителей	0103000020E61000000100000005000000F700DD97336B4540AD1402B9C4514A40F700DD97336B45408BA9F413CE524A407347FFCBB56C45408BA9F413CE524A407347FFCBB56C4540AD1402B9C4514A40F700DD97336B4540AD1402B9C4514A40
25725	2557	42.480899000000001	42.496609999999997	52.821916999999999	52.814908000000003	Набережная	0103000020E61000000100000005000000EDD632198E3D4540D89FC4E74E684A40EDD632198E3D45406283859334694A40EB6E9EEA903F45406283859334694A40EB6E9EEA903F4540D89FC4E74E684A40EDD632198E3D4540D89FC4E74E684A40
25458	46086	42.268303000000003	42.295828	52.830269999999999	52.811549999999997	Советская	0103000020E610000001000000050000009835B1C057224540CE88D2DEE0674A409835B1C057224540CA6C9049466A4A40DC9E20B1DD254540CA6C9049466A4A40DC9E20B1DD254540CE88D2DEE0674A409835B1C057224540CE88D2DEE0674A40
75379	60589	42.285271999999999	42.294130000000003	52.631011999999998	52.627065000000002	Юбилейная	0103000020E61000000100000005000000753BFBCA83244540AEBB79AA43504A40753BFBCA8324454018B14F00C5504A40E162450DA625454018B14F00C5504A40E162450DA6254540AEBB79AA43504A40753BFBCA83244540AEBB79AA43504A40
25757	46007	42.390250000000002	42.436368999999999	52.676665999999997	52.668627999999998	Полякова	0103000020E61000000100000005000000CBA145B6F33145404E98309A95554A40CBA145B6F33145405628D2FD9C564A407EFE7BF0DA3745405628D2FD9C564A407EFE7BF0DA3745404E98309A95554A40CBA145B6F33145404E98309A95554A40
25779	51201	42.237509000000003	42.245854000000001	52.808430000000001	52.799093999999997	Садовая 	0103000020E61000000100000005000000BAC0E5B1661E4540043752B648664A40BAC0E5B1661E45407A8D5DA27A674A409FCBD424781F45407A8D5DA27A674A409FCBD424781F4540043752B648664A40BAC0E5B1661E4540043752B648664A40
26212	24434	42.715197000000003	42.742964000000001	52.642482999999999	52.629885999999999	Рабочая	0103000020E61000000100000005000000429946938B5B4540A81ABD1AA0504A40429946938B5B4540349E08E23C524A407C0DC171195F4540349E08E23C524A407C0DC171195F4540A81ABD1AA0504A40429946938B5B4540A81ABD1AA0504A40
75389	60592	42.318268000000003	42.342289000000001	52.781644999999997	52.770532000000003	Центральная	0103000020E6100000010000000500000082AE7D01BD284540C042E6CAA0624A4082AE7D01BD2845407C0A80F10C644A40E9633E20D02B45407C0A80F10C644A40E9633E20D02B4540C042E6CAA0624A4082AE7D01BD284540C042E6CAA0624A40
25589	51170	42.363137999999999	42.376137	52.661102	52.650683999999998	Мирная	0103000020E61000000100000005000000A9F7544E7B2E4540E603029D49534A40A9F7544E7B2E4540FCA886FD9E544A4064E8D84125304540FCA886FD9E544A4064E8D84125304540E603029D49534A40A9F7544E7B2E4540E603029D49534A40
26348	47379	42.678223000000003	42.730710999999999	52.552489999999999	52.534565000000001	Дорожная	0103000020E610000001000000050000009032E202D05645400A4B3CA06C444A409032E202D0564540FBAE08FEB7464A40EAE923F0875D4540FBAE08FEB7464A40EAE923F0875D45400A4B3CA06C444A409032E202D05645400A4B3CA06C444A40
25711	46733	42.814442999999997	42.842011999999997	52.769879000000003	52.762599000000002	Новая	0103000020E6100000010000000500000062BA10AB3F6845402D7B12D89C614A4062BA10AB3F684540487023658B624A40766B990CC76B4540487023658B624A40766B990CC76B45402D7B12D89C614A4062BA10AB3F6845402D7B12D89C614A40
26077	4952	42.365240999999997	42.396583	52.649062000000001	52.631509000000001	Железнодорожная	0103000020E6100000010000000500000044149337C02E454099107349D5504A4044149337C02E4540C689AF7614534A402593533BC3324540C689AF7614534A402593533BC332454099107349D5504A4044149337C02E454099107349D5504A40
26221	25367	42.760643000000002	42.770676999999999	52.683736000000003	52.676191000000003	Газопроводская	0103000020E610000001000000050000003677F4BF5C614540BE6C3B6D8D564A403677F4BF5C614540878C47A984574A40C3633F8BA5624540878C47A984574A40C3633F8BA5624540BE6C3B6D8D564A403677F4BF5C614540BE6C3B6D8D564A40
26342	47132	42.553742999999997	42.598649999999999	52.718775000000001	52.683889000000001	Гордеевка	0103000020E61000000100000005000000C8B1F50CE14645400D8CBCAC89574A40C8B1F50CE14645405917B7D1005C4A400DE02D90A04C45405917B7D1005C4A400DE02D90A04C45400D8CBCAC89574A40C8B1F50CE14645400D8CBCAC89574A40
25720	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Школьная	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25467	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Спортивная	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25593	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Советская	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25597	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Рабоче-Крестьянская	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25662	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Пушкинская	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25473	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Моршанский тракт	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
26002	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Микрорайон №1	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25856	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Интернациональная	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25598	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	Заводской	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
25768	3087	42.696376999999998	42.753070000000001	52.670527999999997	52.637231999999997	50 лет Победы	0103000020E61000000100000005000000E257ACE1225945407AFB73D190514A40E257ACE122594540B1868BDCD3554A40A3CC069964604540B1868BDCD3554A40A3CC0699646045407AFB73D190514A40E257ACE1225945407AFB73D190514A40
26338	24327	42.598542000000002	42.661020000000001	52.635783000000004	52.604325000000003	Подвячка	0103000020E6100000010000000500000027A435069D4C4540DE9387855A4D4A4027A435069D4C4540282D5C5661514A403F00A94D9C544540282D5C5661514A403F00A94D9C544540DE9387855A4D4A4027A435069D4C4540DE9387855A4D4A40
26207	24129	42.468663999999997	42.530898999999998	52.594298999999999	52.530177000000002	Верхняя Луговка	0103000020E610000001000000050000000168942EFD3B4540B30B06D7DC434A400168942EFD3B4540D38558FD114C4A40533D997FF4434540D38558FD114C4A40533D997FF4434540B30B06D7DC434A400168942EFD3B4540B30B06D7DC434A40
25698	24123	42.533549000000001	42.595461	52.556224	52.528554999999997	Площадь	0103000020E6100000010000000500000021E868554B4445409291B3B0A7434A4021E868554B4445400AA0185932474A409085E810384C45400AA0185932474A409085E810384C45409291B3B0A7434A4021E868554B4445409291B3B0A7434A40
25971	24031	42.699153000000003	42.734861000000002	52.686732999999997	52.666454000000002	Приовражная	0103000020E610000001000000050000003DF372D87D594540EA245B5D4E554A403DF372D87D594540BF0AF0DDE6574A408D0DDDEC0F5E4540BF0AF0DDE6574A408D0DDDEC0F5E4540EA245B5D4E554A403DF372D87D594540EA245B5D4E554A40
26339	3936	42.562511000000001	42.594374000000002	52.603816000000002	52.586748999999998	Городок	0103000020E61000000100000005000000F451465C00484540F8FA5A971A4B4A40F451465C004845409966BAD7494D4A40DECB7D72144C45409966BAD7494D4A40DECB7D72144C4540F8FA5A971A4B4A40F451465C00484540F8FA5A971A4B4A40
25826	23607	42.736432999999998	42.763418999999999	52.281185999999998	52.265436999999999	Центральная	0103000020E61000000100000005000000FB58C16F435E4540FD12F1D6F9214A40FB58C16F435E4540E90B21E7FD234A409012BBB6B7614540E90B21E7FD234A409012BBB6B7614540FD12F1D6F9214A40FB58C16F435E4540FD12F1D6F9214A40
26189	23271	42.402943	42.474530000000001	52.184843999999998	52.153083000000002	Чапаевская	0103000020E610000001000000050000007993DFA2933345406B49473998134A407993DFA293334540506EDBF7A8174A40467C2766BD3C4540506EDBF7A8174A40467C2766BD3C45406B49473998134A407993DFA2933345406B49473998134A40
26319	23177	42.444336999999997	42.474789999999999	52.250630000000001	52.212178999999999	Набережная	0103000020E610000001000000050000008DB3E908E0384540F1F274AE281B4A408DB3E908E0384540C0B2D2A414204A40E23B31EBC53C4540C0B2D2A414204A40E23B31EBC53C4540F1F274AE281B4A408DB3E908E0384540F1F274AE281B4A40
26322	23449	42.565134	42.591185000000003	52.187742999999998	52.171574	Молодежная	0103000020E61000000100000005000000C8ED974F56484540056C0723F6154A40C8ED974F56484540C6866EF607184A40617138F3AB4B4540C6866EF607184A40617138F3AB4B4540056C0723F6154A40C8ED974F56484540056C0723F6154A40
26184	22896	42.266516000000003	42.283503000000003	52.340781999999997	52.335737000000002	Соболевка	0103000020E610000001000000050000002DEE3F321D2245405187156EF92A4A402DEE3F321D22454061889CBE9E2B4A40B1A888D34924454061889CBE9E2B4A40B1A888D3492445405187156EF92A4A402DEE3F321D2245405187156EF92A4A40
25388	22453	42.485866000000001	42.497311000000003	52.373156000000002	52.366514000000002	Центральная	0103000020E61000000100000005000000821E6ADB303E454059C345EEE92E4A40821E6ADB303E454031276893C32F4A40757808E3A73F454031276893C32F4A40757808E3A73F454059C345EEE92E4A40821E6ADB303E454059C345EEE92E4A40
26041	23318	42.602691999999998	42.616723999999998	52.112611999999999	52.098959999999998	Центральная	0103000020E61000000100000005000000C9C7EE02254D45405BCEA5B8AA0C4A40C9C7EE02254D45408E91EC116A0E4A404354E1CFF04E45408E91EC116A0E4A404354E1CFF04E45405BCEA5B8AA0C4A40C9C7EE02254D45405BCEA5B8AA0C4A40
25820	23100	42.580531000000001	42.593133999999999	52.276502999999998	52.269492999999997	Садовая	0103000020E6100000010000000500000037A8FDD64E4A45401EC022BF7E224A4037A8FDD64E4A4540791F477364234A40A5129ED0EB4B4540791F477364234A40A5129ED0EB4B45401EC022BF7E224A4037A8FDD64E4A45401EC022BF7E224A40
25815	22573	42.549951999999998	42.591974999999998	52.447350999999998	52.413581999999998	Центральная	0103000020E61000000100000005000000552FBFD3644645406D1B4641F0344A40552FBFD3644645409C6A2DCC42394A40598638D6C54B45409C6A2DCC42394A40598638D6C54B45406D1B4641F0344A40552FBFD3644645406D1B4641F0344A40
26332	23838	42.772374999999997	42.816409999999998	52.411439999999999	52.392209000000001	Центральная	0103000020E61000000100000005000000BE9F1A2FDD62454033198EE733324A40BE9F1A2FDD6245401422E010AA344A404D10751F806845401422E010AA344A404D10751F8068454033198EE733324A40BE9F1A2FDD62454033198EE733324A40
25670	22517	42.507893000000003	42.552602	52.462085999999999	52.436580999999997	Краснофлотская	0103000020E61000000100000005000000056F48A3024145400987DEE2E1374A40056F48A30241454040F850A2253B4A4023DA8EA9BB46454040F850A2253B4A4023DA8EA9BB4645400987DEE2E1374A40056F48A3024145400987DEE2E1374A40
75419	46030	42.762484999999998	42.773372000000002	52.176262999999999	52.159022999999998	Молодежная	0103000020E610000001000000050000006458C51B99614540E9279CDD5A144A406458C51B99614540573F36C98F164A4031D28BDAFD624540573F36C98F164A4031D28BDAFD624540E9279CDD5A144A406458C51B99614540E9279CDD5A144A40
26152	23552	42.747123000000002	42.788041999999997	52.193319000000002	52.181128000000001	Школьная	0103000020E61000000100000005000000728BF9B9A15F4540E831CA332F174A40728BF9B9A15F454004594FADBE184A40EDEF6C8FDE64454004594FADBE184A40EDEF6C8FDE644540E831CA332F174A40728BF9B9A15F4540E831CA332F174A40
26044	22467	42.428823000000001	42.459994999999999	52.438892000000003	52.421294000000003	Молодежная	0103000020E61000000100000005000000E5620CACE3364540220038F6EC354A40E5620CACE3364540EF3CF19C2D384A4069A9BC1DE13A4540EF3CF19C2D384A4069A9BC1DE13A4540220038F6EC354A40E5620CACE3364540220038F6EC354A40
25528	23875	42.814343999999998	42.827539999999999	52.361438	52.355130000000003	Петровка	0103000020E61000000100000005000000CFD8976C3C6845400CEA5BE6742D4A40CFD8976C3C6845400DC4B299432E4A40E010AAD4EC6945400DC4B299432E4A40E010AAD4EC6945400CEA5BE6742D4A40CFD8976C3C6845400CEA5BE6742D4A40
25819	22904	42.389899	42.411341999999998	52.37077	52.356934000000003	Богачевская	0103000020E610000001000000050000001EDFDE35E83145404D6A6803B02D4A401EDFDE35E8314540412B3064752F4A4051BCCADAA6344540412B3064752F4A4051BCCADAA63445404D6A6803B02D4A401EDFDE35E83145404D6A6803B02D4A40
25686	23376	42.702404999999999	42.725681000000002	52.126446999999999	52.103225000000002	Центральная	0103000020E6100000010000000500000000C63368E859454097900F7A360D4A4000C63368E8594540B2D6506A2F104A400F2A711DE35C4540B2D6506A2F104A400F2A711DE35C454097900F7A360D4A4000C63368E859454097900F7A360D4A40
25569	23932	42.841203999999998	42.893889999999999	52.344116999999997	52.326557000000001	Калиновка	0103000020E61000000100000005000000D7A19A92AC6B4540D3A3A99ECC294A40D7A19A92AC6B4540B27F9E060C2C4A40581CCEFC6A724540B27F9E060C2C4A40581CCEFC6A724540D3A3A99ECC294A40D7A19A92AC6B4540D3A3A99ECC294A40
25391	22778	42.218096000000003	42.236736999999998	52.386310999999999	52.360458999999999	Якова Синева	0103000020E61000000100000005000000B8B1D991EA1B454041464085232E4A40B8B1D991EA1B4540E38A8BA372314A406760E4654D1E4540E38A8BA372314A406760E4654D1E454041464085232E4A40B8B1D991EA1B454041464085232E4A40
25817	22732	42.229325000000003	42.260299000000003	52.519125000000003	52.495998999999998	Курдюковская	0103000020E61000000100000005000000DE9387855A1D4540A2EC2DE57C3F4A40DE9387855A1D45409CC420B072424A403C17467A512145409CC420B072424A403C17467A51214540A2EC2DE57C3F4A40DE9387855A1D4540A2EC2DE57C3F4A40
9642	23455	42.634636	42.652225000000001	52.246445000000001	52.221100999999997	Кирова	0103000020E61000000100000005000000A06EA0C03B514540730E9E094D1C4A40A06EA0C03B514540A1A17F828B1F4A401A51DA1B7C534540A1A17F828B1F4A401A51DA1B7C534540730E9E094D1C4A40A06EA0C03B514540730E9E094D1C4A40
25684	23038	42.477412999999999	42.521044000000003	52.268424000000003	52.247762999999999	Советская	0103000020E61000000100000005000000B6D782DE1B3D45405514AFB2B61F4A40B6D782DE1B3D454013BBB6B75B224A4076E3DD91B142454013BBB6B75B224A4076E3DD91B14245405514AFB2B61F4A40B6D782DE1B3D45405514AFB2B61F4A40
26065	22992	42.378813999999998	42.395262000000002	52.346328	52.335731000000003	Поселковая	0103000020E610000001000000050000002BA226FA7C3045406FA0C03BF92A4A402BA226FA7C30454034D8D479542C4A4000ADF9F19732454034D8D479542C4A4000ADF9F1973245406FA0C03BF92A4A402BA226FA7C3045406FA0C03BF92A4A40
25564	23262	42.343392999999999	42.371771000000003	52.249985000000002	52.231102999999997	Садовая	0103000020E610000001000000050000007156444DF42B4540F58079C8941D4A407156444DF42B4540CBBE2B82FF1F4A40F54C2F31962F4540CBBE2B82FF1F4A40F54C2F31962F4540F58079C8941D4A407156444DF42B4540F58079C8941D4A40
25677	23004	42.411206999999997	42.426416000000003	52.298212999999997	52.271621000000003	Карандеевская	0103000020E610000001000000050000007171546EA234454013F4177AC4224A407171546EA2344540FB1EF5D72B264A40DE3EABCC94364540FB1EF5D72B264A40DE3EABCC9436454013F4177AC4224A407171546EA234454013F4177AC4224A40
26195	23739	42.606223	42.645029999999998	52.380155000000002	52.348709999999997	пер. Школьный	0103000020E61000000100000005000000A08A1BB7984D4540E2E47E87A22C4A40A08A1BB7984D4540983446EBA8304A402D78D15790524540983446EBA8304A402D78D15790524540E2E47E87A22C4A40A08A1BB7984D4540E2E47E87A22C4A40
25689	23739	42.606223	42.645029999999998	52.380155000000002	52.348709999999997	Высотная	0103000020E61000000100000005000000A08A1BB7984D4540E2E47E87A22C4A40A08A1BB7984D4540983446EBA8304A402D78D15790524540983446EBA8304A402D78D15790524540E2E47E87A22C4A40A08A1BB7984D4540E2E47E87A22C4A40
26327	23825	42.617469	42.653329999999997	52.409962	52.387706999999999	Центральная	0103000020E610000001000000050000009CA56439094F454013B70A62A0314A409CA56439094F4540274D83A279344A4072BF4351A0534540274D83A279344A4072BF4351A053454013B70A62A0314A409CA56439094F454013B70A62A0314A40
25950	22744	42.186979000000001	42.221347999999999	52.432298000000003	52.412505000000003	Школьная	0103000020E61000000100000005000000F70489EDEE174540DF37BEF6CC344A40F70489EDEE1745402810768A55374A407B849A21551C45402810768A55374A407B849A21551C4540DF37BEF6CC344A40F70489EDEE174540DF37BEF6CC344A40
26309	22827	42.274923999999999	42.308135	52.425072	52.388784999999999	Школьная	0103000020E610000001000000050000005871AAB5302345407216F6B4C3314A405871AAB530234540003961C268364A4061E0B9F770274540003961C268364A4061E0B9F7702745407216F6B4C3314A405871AAB5302345407216F6B4C3314A40
25669	3143	42.451577999999998	42.502889000000003	52.362560000000002	52.289439000000002	Техническая	0103000020E61000000100000005000000EACBD24ECD394540EE974F560C254A40EACBD24ECD3945403C6BB75D682E4A405342B0AA5E4045403C6BB75D682E4A405342B0AA5E404540EE974F560C254A40EACBD24ECD394540EE974F560C254A40
25414	3143	42.451577999999998	42.502889000000003	52.362560000000002	52.289439000000002	Советская	0103000020E61000000100000005000000EACBD24ECD394540EE974F560C254A40EACBD24ECD3945403C6BB75D682E4A405342B0AA5E4045403C6BB75D682E4A405342B0AA5E404540EE974F560C254A40EACBD24ECD394540EE974F560C254A40
25806	3143	42.451577999999998	42.502889000000003	52.362560000000002	52.289439000000002	Рылеева	0103000020E61000000100000005000000EACBD24ECD394540EE974F560C254A40EACBD24ECD3945403C6BB75D682E4A405342B0AA5E4045403C6BB75D682E4A405342B0AA5E404540EE974F560C254A40EACBD24ECD394540EE974F560C254A40
25548	3143	42.451577999999998	42.502889000000003	52.362560000000002	52.289439000000002	Лунина	0103000020E61000000100000005000000EACBD24ECD394540EE974F560C254A40EACBD24ECD3945403C6BB75D682E4A405342B0AA5E4045403C6BB75D682E4A405342B0AA5E404540EE974F560C254A40EACBD24ECD394540EE974F560C254A40
25813	3143	42.451577999999998	42.502889000000003	52.362560000000002	52.289439000000002	Карла Маркса	0103000020E61000000100000005000000EACBD24ECD394540EE974F560C254A40EACBD24ECD3945403C6BB75D682E4A405342B0AA5E4045403C6BB75D682E4A405342B0AA5E404540EE974F560C254A40EACBD24ECD394540EE974F560C254A40
25553	3143	42.451577999999998	42.502889000000003	52.362560000000002	52.289439000000002	Белинского	0103000020E61000000100000005000000EACBD24ECD394540EE974F560C254A40EACBD24ECD3945403C6BB75D682E4A405342B0AA5E4045403C6BB75D682E4A405342B0AA5E404540EE974F560C254A40EACBD24ECD394540EE974F560C254A40
26059	22656	42.337707000000002	42.355080999999998	52.516807	52.503148000000003	Молодежная	0103000020E61000000100000005000000AD50A4FB392B45401F86562767404A40AD50A4FB392B454004AC55BB26424A402A37514B732D454004AC55BB26424A402A37514B732D45401F86562767404A40AD50A4FB392B45401F86562767404A40
26061	22653	42.374654999999997	42.395837	52.469751000000002	52.456462000000002	Школьная	0103000020E610000001000000050000003524EEB1F42F4540F2EEC8586D3A4A403524EEB1F42F4540B421FFCC203C4A40FCC56CC9AA324540B421FFCC203C4A40FCC56CC9AA324540F2EEC8586D3A4A403524EEB1F42F4540F2EEC8586D3A4A40
25432	23566	42.802343	42.832517000000003	52.275565999999998	52.248932000000003	Школьная	0103000020E610000001000000050000005796E82CB3664540C576F700DD1F4A405796E82CB3664540DCF126BF45234A40992EC4EA8F6A4540DCF126BF45234A40992EC4EA8F6A4540C576F700DD1F4A405796E82CB3664540C576F700DD1F4A40
25957	23180	42.295172000000001	42.313084000000003	52.300659000000003	52.277048000000001	Центральная	0103000020E61000000100000005000000F3583332C82545400BB6114F76234A40F3583332C8254540C11F7EFE7B264A405073F22213284540C11F7EFE7B264A405073F222132845400BB6114F76234A40F3583332C82545400BB6114F76234A40
25904	23664	42.546880000000002	42.617353000000001	52.350883000000003	52.291592999999999	Центральная	0103000020E61000000100000005000000126BF129004645400B5F5FEB52254A40126BF1290046454077DCF0BBE92C4A40338B506C054F454077DCF0BBE92C4A40338B506C054F45400B5F5FEB52254A40126BF129004645400B5F5FEB52254A40
25453	45484	42.465581999999998	42.480566000000003	52.414472000000004	52.406210000000002	Школьная	0103000020E610000001000000050000009ACDE330983B454072A774B0FE334A409ACDE330983B4540CA8D226B0D354A40E7C8CA2F833D4540CA8D226B0D354A40E7C8CA2F833D454072A774B0FE334A409ACDE330983B454072A774B0FE334A40
75032	45484	42.465581999999998	42.480566000000003	52.414472000000004	52.406210000000002	Советская	0103000020E610000001000000050000009ACDE330983B454072A774B0FE334A409ACDE330983B4540CA8D226B0D354A40E7C8CA2F833D4540CA8D226B0D354A40E7C8CA2F833D454072A774B0FE334A409ACDE330983B454072A774B0FE334A40
25951	45946	41.557555999999998	41.650595000000003	52.525142000000002	52.499420999999998	Суренка	0103000020E6100000010000000500000023D8B8FE5DC74440C2F7FE06ED3F4A4023D8B8FE5DC74440C6E061DA37434A4077F86BB246D34440C6E061DA37434A4077F86BB246D34440C2F7FE06ED3F4A4023D8B8FE5DC74440C2F7FE06ED3F4A40
25611	45946	41.557555999999998	41.650595000000003	52.525142000000002	52.499420999999998	Молодежная	0103000020E6100000010000000500000023D8B8FE5DC74440C2F7FE06ED3F4A4023D8B8FE5DC74440C6E061DA37434A4077F86BB246D34440C6E061DA37434A4077F86BB246D34440C2F7FE06ED3F4A4023D8B8FE5DC74440C2F7FE06ED3F4A40
25426	45832	41.226472999999999	41.257689999999997	52.422842000000003	52.407241999999997	Школьная	0103000020E61000000100000005000000A8363811FD9C444060C77F8120344A40A8363811FD9C444008B0C8AF1F364A40CC4065FCFBA0444008B0C8AF1F364A40CC4065FCFBA0444060C77F8120344A40A8363811FD9C444060C77F8120344A40
25427	21736	41.014597000000002	41.042434999999998	52.421272000000002	52.393521999999997	Дзержинского	0103000020E6100000010000000500000053CF8250DE814440D520CCED5E324A4053CF8250DE8144403A5CAB3DEC354A40569A94826E8544403A5CAB3DEC354A40569A94826E854440D520CCED5E324A4053CF8250DE814440D520CCED5E324A40
79322	45784	41.466880000000003	41.479232000000003	52.452939000000001	52.445945999999999	Школьная	0103000020E6100000010000000500000008944DB9C2BB444019E42EC214394A4008944DB9C2BB44409E0AB8E7F9394A402D99637957BD44409E0AB8E7F9394A402D99637957BD444019E42EC214394A4008944DB9C2BB444019E42EC214394A40
26069	21823	41.081843999999997	41.116151000000002	52.366656999999996	52.352594000000003	Центральная	0103000020E61000000100000005000000D9AF3BDD798A44400762D9CC212D4A40D9AF3BDD798A4440BBECD79DEE2E4A40E8323509DE8E4440BBECD79DEE2E4A40E8323509DE8E44400762D9CC212D4A40D9AF3BDD798A44400762D9CC212D4A40
25561	45850	41.308920999999998	41.347394999999999	52.471814000000002	52.456226000000001	Центральная	0103000020E6100000010000000500000018062CB98AA74440DECA129D653A4A4018062CB98AA74440C1E5B166643C4A409FE5797077AC4440C1E5B166643C4A409FE5797077AC4440DECA129D653A4A4018062CB98AA74440DECA129D653A4A40
26108	21621	41.198481999999998	41.260438000000001	52.279874999999997	52.256920999999998	Московская	0103000020E610000001000000050000001E6CB1DB67994440EB538EC9E2204A401E6CB1DB67994440E7FBA9F1D2234A405D514A0856A14440E7FBA9F1D2234A405D514A0856A14440EB538EC9E2204A401E6CB1DB67994440EB538EC9E2204A40
25641	45727	41.380965000000003	41.418622999999997	52.353181999999997	52.307195	Победы	0103000020E61000000100000005000000D8F50B76C3B04440533F6F2A52274A40D8F50B76C3B0444097C45911352D4A403C2D3F7095B5444097C45911352D4A403C2D3F7095B54440533F6F2A52274A40D8F50B76C3B04440533F6F2A52274A40
26175	51203	41.413088999999999	41.461894999999998	52.437618999999998	52.401017000000003	Гагарина	0103000020E610000001000000050000002EABB019E0B44440ED116A8654334A402EABB019E0B44440DA8D3EE603384A40CC9717601FBB4440DA8D3EE603384A40CC9717601FBB4440ED116A8654334A402EABB019E0B44440ED116A8654334A40
25555	51176	41.20035	41.243819999999999	52.392110000000002	52.364100000000001	Гагарина	0103000020E6100000010000000500000076E09C11A59944409F3C2CD49A2E4A4076E09C11A5994440A03715A930324A402C0E677E359F4440A03715A930324A402C0E677E359F44409F3C2CD49A2E4A4076E09C11A59944409F3C2CD49A2E4A40
25934	45771	41.371110999999999	41.409379000000001	52.526747	52.516834000000003	Школьная	0103000020E61000000100000005000000CA17B49080AF4440FEBAD39D27424A40CA17B49080AF4440102219726C434A40A855F48766B44440102219726C434A40A855F48766B44440FEBAD39D27424A40CA17B49080AF4440FEBAD39D27424A40
25543	45753	41.404519000000001	41.428325000000001	52.469104000000002	52.439473999999997	Сергеева	0103000020E6100000010000000500000029CE5147C7B344409DB81CAF40384A4029CE5147C7B344401E3691990B3C4A409487855AD3B644401E3691990B3C4A409487855AD3B644409DB81CAF40384A4029CE5147C7B344409DB81CAF40384A40
75374	46833	41.318694000000001	41.379995000000001	52.301687999999999	52.259202999999999	Зеленая	0103000020E6100000010000000500000039B709F7CAA8444036035C902D214A4039B709F7CAA844403ECC5EB69D264A405FD218ADA3B044403ECC5EB69D264A405FD218ADA3B0444036035C902D214A4039B709F7CAA8444036035C902D214A40
26218	11384	41.855410999999997	41.887588000000001	51.752021999999997	51.739742999999997	Школьная	0103000020E61000000100000005000000BFD18E1B7EED4440F3380CE6AFDE4940BFD18E1B7EED4440AEEFC34142E049403929CC7B9CF14440AEEFC34142E049403929CC7B9CF14440F3380CE6AFDE4940BFD18E1B7EED4440F3380CE6AFDE4940
25893	20807	41.569817999999998	41.606416000000003	51.935426999999997	51.915759999999999	Центральная	0103000020E610000001000000050000000856D5CBEFC84440137EA99F37F549400856D5CBEFC84440CF656A12BCF74940B5E21B0A9FCD4440CF656A12BCF74940B5E21B0A9FCD4440137EA99F37F549400856D5CBEFC84440137EA99F37F54940
25529	20285	41.290253999999997	41.317517000000002	51.856447000000003	51.844240999999997	Центральная	0103000020E610000001000000050000003FC4060B27A544409E78CE1610EC49403FC4060B27A54440F0E0270EA0ED49404776A565A4A84440F0E0270EA0ED49404776A565A4A844409E78CE1610EC49403FC4060B27A544409E78CE1610EC4940
25939	20647	41.622334000000002	41.701574000000001	51.961545000000001	51.923476000000001	Фиолетова	0103000020E610000001000000050000002D98F8A3A8CF44400952297634F649402D98F8A3A8CF4440F05014E813FB4940A9DC442DCDD94440F05014E813FB4940A9DC442DCDD944400952297634F649402D98F8A3A8CF44400952297634F64940
26217	45433	41.542312000000003	41.603200000000001	51.810727	51.772106000000001	Международная	0103000020E610000001000000050000003B1DC87A6AC54440CF85915ED4E249403B1DC87A6AC54440FA7DFFE6C5E749403E7958A835CD4440FA7DFFE6C5E749403E7958A835CD4440CF85915ED4E249403B1DC87A6AC54440CF85915ED4E24940
25841	51206	41.767752999999999	41.797263000000001	51.873437000000003	51.855490000000003	Трудовая	0103000020E61000000100000005000000F433F5BA45E244400C0742B280ED4940F433F5BA45E24440E50E9BC8CCEF4940CAA7C7B60CE64440E50E9BC8CCEF4940CAA7C7B60CE644400C0742B280ED4940F433F5BA45E244400C0742B280ED4940
75028	51206	41.767752999999999	41.797263000000001	51.873437000000003	51.855490000000003	 Школьная	0103000020E61000000100000005000000F433F5BA45E244400C0742B280ED4940F433F5BA45E24440E50E9BC8CCEF4940CAA7C7B60CE64440E50E9BC8CCEF4940CAA7C7B60CE644400C0742B280ED4940F433F5BA45E244400C0742B280ED4940
26158	46797	41.372126000000002	41.388950999999999	51.836590000000001	51.828336	Вишневая	0103000020E61000000100000005000000E3FE23D3A1AF4440BB0CFFE906EA4940E3FE23D3A1AF44409014916115EB49408D5F7825C9B144409014916115EB49408D5F7825C9B14440BB0CFFE906EA4940E3FE23D3A1AF4440BB0CFFE906EA4940
25656	20057	41.306835999999997	41.325440999999998	51.920986999999997	51.911648999999997	Трудовая	0103000020E61000000100000005000000239EEC6646A744402E3718EAB0F44940239EEC6646A744404485EAE6E2F5494086E3F90CA8A944404485EAE6E2F5494086E3F90CA8A944402E3718EAB0F44940239EEC6646A744402E3718EAB0F44940
25901	9479	41.21078	41.243558999999998	51.805615000000003	51.778503000000001	Центральная	0103000020E610000001000000050000005053CBD6FA9A4440406B7EFCA5E349405053CBD6FA9A444062156F641EE74940BFD2F9F02C9F444062156F641EE74940BFD2F9F02C9F4440406B7EFCA5E349405053CBD6FA9A4440406B7EFCA5E34940
75020	9479	41.21078	41.243558999999998	51.805615000000003	51.778503000000001	Ленинская	0103000020E610000001000000050000005053CBD6FA9A4440406B7EFCA5E349405053CBD6FA9A444062156F641EE74940BFD2F9F02C9F444062156F641EE74940BFD2F9F02C9F4440406B7EFCA5E349405053CBD6FA9A4440406B7EFCA5E34940
26036	51226	41.208722000000002	41.235078999999999	51.760708000000001	51.744522000000003	Кировская	0103000020E6100000010000000500000055FA0967B79A44408693347F4CDF494055FA0967B79A44401DE736E15EE14940FA7C9411179E44401DE736E15EE14940FA7C9411179E44408693347F4CDF494055FA0967B79A44408693347F4CDF4940
26126	51234	41.736320999999997	41.762157000000002	51.931201000000001	51.914138000000001	Кропоткина	0103000020E61000000100000005000000D32D3BC43FDE4440F303577902F54940D32D3BC43FDE44405280289831F7494070B54E5C8EE144405280289831F7494070B54E5C8EE14440F303577902F54940D32D3BC43FDE4440F303577902F54940
75395	45540	41.582870999999997	41.628478000000001	52.042405000000002	52.024360000000001	Центральная	0103000020E61000000100000005000000B66455849BCA444050AA7D3A1E034A40B66455849BCA4440EC17EC866D054A40B42094F771D04440EC17EC866D054A40B42094F771D0444050AA7D3A1E034A40B66455849BCA444050AA7D3A1E034A40
25648	21071	41.822487000000002	41.850712000000001	51.879904000000003	51.85895	Луговая	0103000020E610000001000000050000004D31074147E944401973D712F2ED49404D31074147E944404FCFBBB1A0F049404A287D21E4EC44404FCFBBB1A0F049404A287D21E4EC44401973D712F2ED49404D31074147E944401973D712F2ED4940
26047	20181	41.422063000000001	41.454807000000002	51.798175000000001	51.781467999999997	Центральная	0103000020E6100000010000000500000003ED0E2906B644406D6FB72407E4494003ED0E2906B644400EBE30992AE64940F67EA31D37BA44400EBE30992AE64940F67EA31D37BA44406D6FB72407E4494003ED0E2906B644406D6FB72407E44940
26038	45585	41.87379	41.912768	51.895440000000001	51.869093999999997	Мира	0103000020E6100000010000000500000032C9C859D8EF44402D93E1783EEF494032C9C859D8EF4440DFC325C79DF24940EC6AF294D5F44440DFC325C79DF24940EC6AF294D5F444402D93E1783EEF494032C9C859D8EF44402D93E1783EEF4940
25798	45495	41.728073999999999	41.750487	51.863298999999998	51.846077000000001	Зеленая	0103000020E61000000100000005000000B188618731DD4440EB724A404CEC4940B188618731DD4440B2D5E59480EE49405D8940F50FE04440B2D5E59480EE49405D8940F50FE04440EB724A404CEC4940B188618731DD4440EB724A404CEC4940
25572	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Энгельса	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
25787	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Чкалова	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
26027	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Тухачевского	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
26266	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Серова	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
25517	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Семашко	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
25638	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Первомайская	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
25897	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Нагорная	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
25384	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Кировская	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
25392	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Интернациональная	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
26265	10689	41.431280000000001	41.516835999999998	51.861075	51.796748999999998	Заводская	0103000020E610000001000000050000009EB5DB2E34B74440730F09DFFBE549409EB5DB2E34B744409C33A2B437EE49409EB29AAE27C244409C33A2B437EE49409EB29AAE27C24440730F09DFFBE549409EB5DB2E34B74440730F09DFFBE54940
26043	21123	41.817520000000002	41.845959999999998	51.831453000000003	51.819752000000001	Мира	0103000020E61000000100000005000000B8E9CF7EA4E84440516A2FA2EDE84940B8E9CF7EA4E844409F94490D6DEA4940B1DCD26A48EC44409F94490D6DEA4940B1DCD26A48EC4440516A2FA2EDE84940B8E9CF7EA4E84440516A2FA2EDE84940
26090	51230	41.948816999999998	41.973439999999997	51.684345	51.664439999999999	Северный микрарайон	0103000020E61000000100000005000000C571E0D572F94440BE13B35E0CD54940C571E0D572F944402F17F19D98D74940224F92AE99FC44402F17F19D98D74940224F92AE99FC4440BE13B35E0CD54940C571E0D572F94440BE13B35E0CD54940
26285	45538	41.514876999999998	41.532251000000002	51.922704000000003	51.901142	Жукова	0103000020E61000000100000005000000363B527DE7C14440A986FD9E58F34940363B527DE7C14440B7F1272A1BF64940B421FFCC20C44440B7F1272A1BF64940B421FFCC20C44440A986FD9E58F34940363B527DE7C14440A986FD9E58F34940
25782	49523	41.421371999999998	41.506433000000001	51.894678999999996	51.846884000000003	Свободы	0103000020E610000001000000050000009DB98784EFB54440BAC0E5B166EC49409DB98784EFB5444080B56AD784F24940BE4EEACBD2C0444080B56AD784F24940BE4EEACBD2C04440BAC0E5B166EC49409DB98784EFB54440BAC0E5B166EC4940
25394	49523	41.421371999999998	41.506433000000001	51.894678999999996	51.846884000000003	Колхозная	0103000020E610000001000000050000009DB98784EFB54440BAC0E5B166EC49409DB98784EFB5444080B56AD784F24940BE4EEACBD2C0444080B56AD784F24940BE4EEACBD2C04440BAC0E5B166EC49409DB98784EFB54440BAC0E5B166EC4940
25502	49219	41.871400999999999	41.886744	51.687193000000001	51.676399000000004	Торговая	0103000020E61000000100000005000000D15966118AEF44400806103E94D64940D15966118AEF44402385B2F0F5D749404DF6CFD380F144402385B2F0F5D749404DF6CFD380F144400806103E94D64940D15966118AEF44400806103E94D64940
25376	525	42.619912999999997	42.649251999999997	52.797575000000002	52.782091999999999	Заречная	0103000020E61000000100000005000000C0AE264F594F45404B3B35971B644A40C0AE264F594F4540B98D06F016664A40696E85B01A534540B98D06F016664A40696E85B01A5345404B3B35971B644A40C0AE264F594F45404B3B35971B644A40
26133	51236	42.678024999999998	42.710517000000003	53.040239999999997	53.034489000000001	Центральная	0103000020E61000000100000005000000696FF085C95645402F89B3226A844A40696FF085C9564540DAFE959526854A4043209738F25A4540DAFE959526854A4043209738F25A45402F89B3226A844A40696FF085C95645402F89B3226A844A40
25872	51210	42.877890999999998	42.955703	52.933222999999998	52.884317000000003	Поповка	0103000020E61000000100000005000000F33977BB5E704540FF25A94C31714A40F33977BB5E7045400070ECD973774A4034D8D479547A45400070ECD973774A4034D8D479547A4540FF25A94C31714A40F33977BB5E704540FF25A94C31714A40
25409	45428	42.877890999999998	42.955703	52.933222999999998	52.884317000000003	Гагарина	0103000020E61000000100000005000000F33977BB5E704540FF25A94C31714A40F33977BB5E7045400070ECD973774A4034D8D479547A45400070ECD973774A4034D8D479547A4540FF25A94C31714A40F33977BB5E704540FF25A94C31714A40
25381	575	42.390402000000002	42.431275999999997	53.043005999999998	53.016252999999999	Центральная	0103000020E61000000100000005000000812557B1F83145401FBB0B9414824A40812557B1F831454011C4793881854A405CC64D0D3437454011C4793881854A405CC64D0D343745401FBB0B9414824A40812557B1F83145401FBB0B9414824A40
75403	46637	42.536450000000002	42.651426000000001	53.050434000000003	52.825558000000001	Новая	0103000020E6100000010000000500000038F8C264AA444540C07971E2AB694A4038F8C264AA444540A14D0E9F74864A40CEE15AED61534540A14D0E9F74864A40CEE15AED61534540C07971E2AB694A4038F8C264AA444540C07971E2AB694A40
25509	19114	42.517963000000002	42.534869	52.835203999999997	52.81832	Бурчановка	0103000020E61000000100000005000000DFC4909C4C424540D4D4B2B5BE684A40DFC4909C4C42454083BEF4F6E76A4A4076525F967644454083BEF4F6E76A4A4076525F9676444540D4D4B2B5BE684A40DFC4909C4C424540D4D4B2B5BE684A40
25397	51166	42.472786999999997	42.503706999999999	52.928983000000002	52.911386	Прудная	0103000020E61000000100000005000000AA7CCF48843C45402104E44BA8744A40AA7CCF48843C45401EC539EAE8764A4015E29178794045401EC539EAE8764A4015E29178794045402104E44BA8744A40AA7CCF48843C45402104E44BA8744A40
25406	45520	42.5732	42.610174999999998	53.123171999999997	53.083992000000002	Молодежная	0103000020E610000001000000050000009A081B9E5E4945401590F63FC08A4A409A081B9E5E49454036E49F19C48F4A401CEBE2361A4E454036E49F19C48F4A401CEBE2361A4E45401590F63FC08A4A409A081B9E5E4945401590F63FC08A4A40
25499	18682	42.734169999999999	42.791662000000002	52.890197000000001	52.855131999999998	Школьная	0103000020E6100000010000000500000027DA5548F95D4540ACE122F7746D4A4027DA5548F95D4540A8FFACF9F1714A4034BE2F2E55654540A8FFACF9F1714A4034BE2F2E55654540ACE122F7746D4A4027DA5548F95D4540ACE122F7746D4A40
26298	12809	42.793647	42.825150999999998	52.861744000000002	52.832794	Гагарина	0103000020E61000000100000005000000C5C89239966545400B2769FE986A4A40C5C89239966545401AC39CA04D6E4A407FA1478C9E6945401AC39CA04D6E4A407FA1478C9E6945400B2769FE986A4A40C5C89239966545400B2769FE986A4A40
26130	49333	42.545082999999998	42.570388999999999	53.026170999999998	53.005682	Новая	0103000020E61000000100000005000000834D9D47C545454083161230BA804A40834D9D47C5454540438D429259834A40C37FBA8102494540438D429259834A40C37FBA810249454083161230BA804A40834D9D47C545454083161230BA804A40
26268	3658	42.184904000000003	42.200606000000001	53.079275000000003	53.058427999999999	Школьная 	0103000020E6100000010000000500000026732CEFAA174540D99596917A874A4026732CEFAA174540F931E6AE258A4A40D1B01875AD194540F931E6AE258A4A40D1B01875AD194540D99596917A874A4026732CEFAA174540D99596917A874A40
25484	48917	42.062347000000003	42.070611	52.929623999999997	52.922431000000003	Молодежная	0103000020E610000001000000050000007A008BFCFA07454086E8103812764A407A008BFCFA074540D1C952EBFD764A4072DEFFC709094540D1C952EBFD764A4072DEFFC70909454086E8103812764A407A008BFCFA07454086E8103812764A40
26019	51223	42.035325	42.048727999999997	52.949845000000003	52.945309000000002	Совхозная	0103000020E6100000010000000500000098DD938785044540A7CEA3E2FF784A4098DD93878504454073A25D8594794A40223317B83C06454073A25D8594794A40223317B83C064540A7CEA3E2FF784A4098DD938785044540A7CEA3E2FF784A40
26249	49171	42.060459999999999	42.071832999999998	52.909871000000003	52.888843999999999	Центральная	0103000020E61000000100000005000000AB5B3D27BD074540779FE3A3C5714A40AB5B3D27BD074540174A26A776744A4004E3E0D231094540174A26A776744A4004E3E0D231094540779FE3A3C5714A40AB5B3D27BD074540779FE3A3C5714A40
26271	18416	41.879781999999999	41.932656999999999	52.995370000000001	52.95176	Октябрьская	0103000020E6100000010000000500000003CE52B29CF044400BD28C45D3794A4003CE52B29CF04440B3B5BE48687F4A4057B1F84D61F74440B3B5BE48687F4A4057B1F84D61F744400BD28C45D3794A4003CE52B29CF044400BD28C45D3794A40
25425	47049	41.923180000000002	41.938451000000001	52.915790000000001	52.908909999999999	Молодежная	0103000020E61000000100000005000000202922C32AF64440F180B22957744A40202922C32AF644407E00529B38754A4002F390291FF844407E00529B38754A4002F390291FF84440F180B22957744A40202922C32AF64440F180B22957744A40
75397	47049	41.923180000000002	41.938451000000001	52.915790000000001	52.908909999999999	Ильменовка	0103000020E61000000100000005000000202922C32AF64440F180B22957744A40202922C32AF644407E00529B38754A4002F390291FF844407E00529B38754A4002F390291FF84440F180B22957744A40202922C32AF64440F180B22957744A40
25693	49109	42.160955000000001	42.175776999999997	52.861842000000003	52.854109999999999	Совхозная	0103000020E610000001000000050000005890662C9A144540E197FA79536D4A405890662C9A144540DD28B2D6506E4A40CA3159DC7F164540DD28B2D6506E4A40CA3159DC7F164540E197FA79536D4A405890662C9A144540E197FA79536D4A40
26242	49059	42.043221000000003	42.059885000000001	53.020288999999998	52.978976000000003	Школьная	0103000020E610000001000000050000000EC0064488054540D2C8E7154F7D4A400EC0064488054540F9BB77D498824A40AF42CA4FAA074540F9BB77D498824A40AF42CA4FAA074540D2C8E7154F7D4A400EC0064488054540D2C8E7154F7D4A40
25619	18120	42.035918000000002	42.047246000000001	53.067487	53.045031000000002	Молодежная	0103000020E610000001000000050000003BAB05F69804454031276893C3854A403BAB05F698044540DCF3FC69A3884A40F46E2C280C064540DCF3FC69A3884A40F46E2C280C06454031276893C3854A403BAB05F69804454031276893C3854A40
75472	60620	42.170126000000003	42.199708000000001	52.975923999999999	52.952069000000002	Максимовка	0103000020E61000000100000005000000831953B0C61545408944A165DD794A40831953B0C6154540D5B0DF13EB7C4A40F25F200890194540D5B0DF13EB7C4A40F25F2008901945408944A165DD794A40831953B0C61545408944A165DD794A40
26239	48997	42.417855000000003	42.430934000000001	52.899475000000002	52.887979999999999	Центральная	0103000020E610000001000000050000002CBCCB457C35454044C02154A9714A402CBCCB457C354540E9482EFF21734A40035E66D828374540E9482EFF21734A40035E66D82837454044C02154A9714A402CBCCB457C35454044C02154A9714A40
25487	17966	41.889285999999998	41.912139000000003	53.059618999999998	53.037153000000004	Советская	0103000020E610000001000000050000003465A71FD4F1444062F9F36DC1844A403465A71FD4F14440309C6B98A1874A40FD3383F8C0F44440309C6B98A1874A40FD3383F8C0F4444062F9F36DC1844A403465A71FD4F1444062F9F36DC1844A40
75424	49086	42.089106999999998	42.107747000000003	53.046320000000001	53.008229	Центральная	0103000020E610000001000000050000001E6CB1DB670B45407CF0DAA50D814A401E6CB1DB670B45404B9352D0ED854A40FE9E58A7CA0D45404B9352D0ED854A40FE9E58A7CA0D45407CF0DAA50D814A401E6CB1DB670B45407CF0DAA50D814A40
25485	17871	41.870196999999997	41.903658999999998	52.897247999999998	52.871403999999998	Школьная	0103000020E61000000100000005000000E509849D62EF444042CD902A8A6F4A40E509849D62EF44406133C005D9724A4037DE1D19ABF344406133C005D9724A4037DE1D19ABF3444042CD902A8A6F4A40E509849D62EF444042CD902A8A6F4A40
26067	48925	42.271349000000001	42.298181	52.963921999999997	52.941656999999999	Центральная	0103000020E61000000100000005000000B2666490BB2245405586713788784A40B2666490BB2245408CF2CCCB617B4A40F0A485CB2A2645408CF2CCCB617B4A40F0A485CB2A2645405586713788784A40B2666490BB2245405586713788784A40
25617	48979	41.905994999999997	41.921211999999997	53.025001000000003	53.012135999999998	Набережная	0103000020E6100000010000000500000075ABE7A4F7F34440588D25AC8D814A4075ABE7A4F7F3444004AF963B33834A4064575A46EAF5444004AF963B33834A4064575A46EAF54440588D25AC8D814A4075ABE7A4F7F34440588D25AC8D814A40
26007	46360	42.406078000000001	42.423873999999998	52.863363999999997	52.850777000000001	Советская	0103000020E6100000010000000500000003D0285DFA3345403198BF42E66C4A4003D0285DFA334540994528B6826E4A40F6CFD38041364540994528B6826E4A40F6CFD380413645403198BF42E66C4A4003D0285DFA3345403198BF42E66C4A40
25625	18351	42.094371000000002	42.109805000000001	52.878013000000003	52.855905	Кольцевая	0103000020E610000001000000050000006D585359140C4540CFBD874B8E6D4A406D585359140C45403F3BE0BA62704A40F9F719170E0E45403F3BE0BA62704A40F9F719170E0E4540CFBD874B8E6D4A406D585359140C4540CFBD874B8E6D4A40
26246	18574	42.085424000000003	42.093437000000002	52.93421	52.901159	Центральная	0103000020E610000001000000050000009225732CEF0A45407FBF982D59734A409225732CEF0A45404FCC7A3194774A40419E5DBEF50B45404FCC7A3194774A40419E5DBEF50B45407FBF982D59734A409225732CEF0A45407FBF982D59734A40
26372	895	42.034399999999998	42.077869	52.964964000000002	52.941141000000002	Советская	0103000020E61000000100000005000000BF7D1D38670445405EF6EB4E77784A40BF7D1D38670445409FE8BAF0837B4A40A52F849CF70945409FE8BAF0837B4A40A52F849CF70945405EF6EB4E77784A40BF7D1D38670445405EF6EB4E77784A40
25614	895	42.034399999999998	42.077869	52.964964000000002	52.941141000000002	Октябрьская	0103000020E61000000100000005000000BF7D1D38670445405EF6EB4E77784A40BF7D1D38670445409FE8BAF0837B4A40A52F849CF70945409FE8BAF0837B4A40A52F849CF70945405EF6EB4E77784A40BF7D1D38670445405EF6EB4E77784A40
25639	40435	41.822082999999999	41.827150000000003	52.988506999999998	52.985622999999997	Совхозная	0103000020E610000001000000050000007DCC07043AE94440BB97FBE4287E4A407DCC07043AE94440FC6EBA65877E4A4076711B0DE0E94440FC6EBA65877E4A4076711B0DE0E94440BB97FBE4287E4A407DCC07043AE94440BB97FBE4287E4A40
39781	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	пр-кт Металлургов	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39780	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Энтузиастов	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
40017	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Энгельса	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
40000	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Шоссейная	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39782	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Школьный переулок	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39601	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Школьная	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
40159	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Центральная	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
40217	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Тургенева	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39716	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Старозавопье	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39593	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Советская	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39675	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Пугачева	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39597	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Победы	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39777	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Ольховская	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39603	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Октябрьская	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39595	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Металлургов проспект	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
40001	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Макаренко	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39772	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Лесная	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39999	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Кузнецова	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39870	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Интернациональная	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39951	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Дачная	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39678	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Гагарина	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39596	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Автозаводская	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39872	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	30 лет Победы	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39676	54805	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	1-я Рабочая	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39860	54804	34.252681000000003	34.313172999999999	55.853763999999998	55.813324000000001	Станционное шоссе	0103000020E6100000010000000500000009A9DBD957204140A58636001BE84B4009A9DBD9572041404640852348ED4B40BF7E880D162841404640852348ED4B40BF7E880D16284140A58636001BE84B4009A9DBD957204140A58636001BE84B40
39590	54804	34.252681000000003	34.313172999999999	55.853763999999998	55.813324000000001	Проспект Коммунистов	0103000020E6100000010000000500000009A9DBD957204140A58636001BE84B4009A9DBD9572041404640852348ED4B40BF7E880D162841404640852348ED4B40BF7E880D16284140A58636001BE84B4009A9DBD957204140A58636001BE84B40
39648	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	Минская	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39592	54804	34.252681000000003	34.313172999999999	55.853763999999998	55.813324000000001	Большая Пролетарская	0103000020E6100000010000000500000009A9DBD957204140A58636001BE84B4009A9DBD9572041404640852348ED4B40BF7E880D162841404640852348ED4B40BF7E880D16284140A58636001BE84B4009A9DBD957204140A58636001BE84B40
1263	6	32.050604999999997	32.100318000000001	54.801763000000001	54.790308000000003	улица Соболева	0103000020E61000000100000005000000CD0182397A06404033E202D028654B40CD0182397A0640404912842BA0664B409E996038D70C40404912842BA0664B409E996038D70C404033E202D028654B40CD0182397A06404033E202D028654B40
1221	6	32.070951999999998	32.075138000000003	54.773226000000001	54.768656	улица Румянцева	0103000020E61000000100000005000000FBCA83F414094040E5EFDE5163624B40FBCA83F4140940405D35CF11F9624B40EB573A1F9E0940405D35CF11F9624B40EB573A1F9E094040E5EFDE5163624B40FBCA83F414094040E5EFDE5163624B40
75034	6	31.996877000000001	32.002023999999999	54.806859000000003	54.805447999999998	улица Белинского	0103000020E610000001000000050000007522C15433FF3F40765089EB18674B407522C15433FF3F40DCBDDC2747674B404FE78A5242004040DCBDDC2747674B404FE78A5242004040765089EB18674B407522C15433FF3F40765089EB18674B40
39770	6	32.044801999999997	32.050991000000003	54.778185000000001	54.754173000000002	проспект Гагарина	0103000020E61000000100000005000000CF656A12BC0540405B43A9BD88604B40CF656A12BC0540406F9EEA909B634B40F7B182DF860640406F9EEA909B634B40F7B182DF860640405B43A9BD88604B40CF656A12BC0540405B43A9BD88604B40
39790	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	мкр. Южный	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39909	6	32.055824000000001	32.062210999999998	54.784540999999997	54.778736000000002	маршала Жукова	0103000020E610000001000000050000007C2AA73D25074040E31B0A9FAD634B407C2AA73D2507404081AFE8D66B644B40C939B187F607404081AFE8D66B644B40C939B187F6074040E31B0A9FAD634B407C2AA73D25074040E31B0A9FAD634B40
39578	6	32.001575000000003	32.010404999999999	54.812151	54.807046	генерала Городнянского	0103000020E61000000100000005000000E0BE0E9C330040400E2F88484D674B40E0BE0E9C33004040F4346090F4674B40815B77F354014040F4346090F4674B40815B77F3540140400E2F88484D674B40E0BE0E9C330040400E2F88484D674B40
39886	6	32.026620000000001	32.033769999999997	54.766064	54.762979000000001	Энергетический проезд	0103000020E61000000100000005000000B3B5BE48680340407444BE4BA9614B40B3B5BE48680340404C5299620E624B40FFCA4A93520440404C5299620E624B40FFCA4A93520440407444BE4BA9614B40B3B5BE48680340407444BE4BA9614B40
39541	6	32.026620000000001	32.033769999999997	54.766064	54.762979000000001	Энергетический проезд	0103000020E61000000100000005000000B3B5BE48680340407444BE4BA9614B40B3B5BE48680340404C5299620E624B40FFCA4A93520440404C5299620E624B40FFCA4A93520440407444BE4BA9614B40B3B5BE48680340407444BE4BA9614B40
39631	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	Щорса	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39915	6	32.059838999999997	32.088845999999997	54.784494000000002	54.769590999999998	Шевченко	0103000020E610000001000000050000003E03EACDA8074040E12538F581624B403E03EACDA807404041F4A44C6A644B40B130444E5F0B404041F4A44C6A644B40B130444E5F0B4040E12538F581624B403E03EACDA8074040E12538F581624B40
39756	6	32.040148000000002	32.045898000000001	54.814979000000001	54.814371999999999	Чкалова	0103000020E61000000100000005000000FA7FD59123054040996379573D684B40FA7FD59123054040A1F65B3B51684B40D57954FCDF054040A1F65B3B51684B40D57954FCDF054040996379573D684B40FA7FD59123054040996379573D684B40
39582	6	32.118059000000002	32.125677000000003	54.812618000000001	54.811824999999999	Центральная	0103000020E61000000100000005000000CEFFAB8E1C0F4040A089B0E1E9674B40CEFFAB8E1C0F40400A12DBDD03684B40016E162F161040400A12DBDD03684B40016E162F16104040A089B0E1E9674B40CEFFAB8E1C0F4040A089B0E1E9674B40
39634	6	32.038530999999999	32.044451000000002	54.818303999999998	54.804980999999998	Фрунзе	0103000020E61000000100000005000000EB707495EE04404060730E9E09674B40EB707495EE044040CE177B2FBE684B4023A30392B0054040CE177B2FBE684B4023A30392B005404060730E9E09674B40EB707495EE04404060730E9E09674B40
39964	6	32.022883	32.025559999999999	54.805971999999997	54.798181999999997	Ударников	0103000020E61000000100000005000000335184D4ED024040C020E9D32A664B40335184D4ED024040F0BE2A172A674B40FA0AD28C45034040F0BE2A172A674B40FA0AD28C45034040C020E9D32A664B40335184D4ED024040C020E9D32A664B40
39897	6	32.056308999999999	32.068202999999997	54.779265000000002	54.773403000000002	Твардовского	0103000020E6100000010000000500000038BC2022350740406CD097DEFE624B4038BC2022350740406FF59CF4BE634B409A3E3BE0BA0840406FF59CF4BE634B409A3E3BE0BA0840406CD097DEFE624B4038BC2022350740406CD097DEFE624B40
1550	6	32.072048000000002	32.099508999999998	54.769534	54.756433000000001	Строителей проспект	0103000020E6100000010000000500000001DF6DDE38094040BE4EEACBD2604B4001DF6DDE380940407D94111780624B402E54FEB5BC0C40407D94111780624B402E54FEB5BC0C4040BE4EEACBD2604B4001DF6DDE38094040BE4EEACBD2604B40
39689	6	32.074140999999997	32.083573000000001	54.768281999999999	54.761015	Соколовского	0103000020E610000001000000050000007825C9737D094040FA6184F068614B407825C9737D094040800D881057624B4010EA2285B20A4040800D881057624B4010EA2285B20A4040FA6184F068614B407825C9737D094040FA6184F068614B40
39901	6	32.050604999999997	32.100318000000001	54.801763000000001	54.790308000000003	Соболева	0103000020E61000000100000005000000CD0182397A06404033E202D028654B40CD0182397A0640404912842BA0664B409E996038D70C40404912842BA0664B409E996038D70C404033E202D028654B40CD0182397A06404033E202D028654B40
39583	6	32.119326000000001	32.127932000000001	54.819533999999997	54.810237000000001	Седова	0103000020E6100000010000000500000000C80913460F40402C8194D8B5674B4000C80913460F4040E3FA777DE6684B40520E661360104040E3FA777DE6684B40520E6613601040402C8194D8B5674B4000C80913460F40402C8194D8B5674B40
39893	6	32.070951999999998	32.075138000000003	54.773226000000001	54.768656	Румянцева	0103000020E61000000100000005000000FBCA83F414094040E5EFDE5163624B40FBCA83F4140940405D35CF11F9624B40EB573A1F9E0940405D35CF11F9624B40EB573A1F9E094040E5EFDE5163624B40FBCA83F414094040E5EFDE5163624B40
39679	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	Революционная	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39919	6	32.046922000000002	32.052833	54.771523000000002	54.771362000000003	Раевского	0103000020E6100000010000000500000041BB438A0106404047B071FDBB624B4041BB438A01064040508E0244C1624B402593533BC3064040508E0244C1624B402593533BC306404047B071FDBB624B4041BB438A0106404047B071FDBB624B40
39622	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	Рабочая	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39900	6	32.037318999999997	32.049886000000001	54.785169000000003	54.784027000000002	Пржевальского	0103000020E610000001000000050000007C4276DEC60440402B172AFF5A644B407C4276DEC6044040A16AF46A80644B409E4319AA62064040A16AF46A80644B409E4319AA620640402B172AFF5A644B407C4276DEC60440402B172AFF5A644B40
39887	6	32.079602000000001	32.112938999999997	54.777225000000001	54.752786	Попова	0103000020E610000001000000050000001D59F965300A40407E71A94A5B604B401D59F965300A40401A51DA1B7C634B40B2B8FFC8740E40401A51DA1B7C634B40B2B8FFC8740E40407E71A94A5B604B401D59F965300A40407E71A94A5B604B40
39926	6	32.101439999999997	32.107486000000002	54.765611999999997	54.760905999999999	Петра Алексеева	0103000020E61000000100000005000000CC4065FCFB0C404043AA285E65614B40CC4065FCFB0C40406BB6F292FF614B409163EB19C20D40406BB6F292FF614B409163EB19C20D404043AA285E65614B40CC4065FCFB0C404043AA285E65614B40
39762	6	32.016415000000002	32.024230000000003	54.791564999999999	54.787613999999998	Парковая	0103000020E61000000100000005000000F91400E31902404095EF1989D0644B40F91400E31902404041D47D0052654B4082CAF8F71903404041D47D0052654B4082CAF8F71903404095EF1989D0644B40F91400E31902404095EF1989D0644B40
39752	6	32.047055999999998	32.051692000000003	54.812271000000003	54.810521999999999	Островского	0103000020E61000000100000005000000508A56EE050640402158552FBF674B40508A56EE050640409F3E027FF8674B4080BBECD79D0640409F3E027FF8674B4080BBECD79D0640402158552FBF674B40508A56EE050640402158552FBF674B40
39639	6	32.042842999999998	32.044316999999999	54.784027000000002	54.768931000000002	Октябрьской Революции	0103000020E6100000010000000500000067EE21E17B054040B7F0BC546C624B4067EE21E17B0540402B172AFF5A644B4013D4F02DAC0540402B172AFF5A644B4013D4F02DAC054040B7F0BC546C624B4067EE21E17B054040B7F0BC546C624B40
39922	6	32.016827999999997	32.023654999999998	54.781078000000001	54.770406000000001	Нормандия-Неман	0103000020E610000001000000050000001BD47E6B270240403352EFA99C624B401BD47E6B2702404003D0285DFA634B4085B185200703404003D0285DFA634B4085B18520070340403352EFA99C624B401BD47E6B270240403352EFA99C624B40
39991	6	32.049230000000001	32.077105000000003	54.799619999999997	54.794310000000003	Новомосковская	0103000020E61000000100000005000000B5FD2B2B4D064040617138F3AB654B40B5FD2B2B4D0640401F9DBAF259664B40D6AD9E93DE0940401F9DBAF259664B40D6AD9E93DE094040617138F3AB654B40B5FD2B2B4D064040617138F3AB654B40
39670	6	32.011581999999997	32.016559000000001	54.787432000000003	54.786602000000002	Новокраснофлотская	0103000020E61000000100000005000000739CDB847B014040EE7BD45FAF644B40739CDB847B01404075E95F92CA644B402CBAF59A1E02404075E95F92CA644B402CBAF59A1E024040EE7BD45FAF644B40739CDB847B014040EE7BD45FAF644B40
39657	6	31.989699000000002	32.047443000000001	54.774317000000003	54.767907999999998	Николаева	0103000020E6100000010000000500000048E2E5E95CFD3F401B2B31CF4A624B4048E2E5E95CFD3F4051DEC7D11C634B404AB6BA9C1206404051DEC7D11C634B404AB6BA9C120640401B2B31CF4A624B4048E2E5E95CFD3F401B2B31CF4A624B40
39699	6	32.043166999999997	32.046913000000004	54.771585000000002	54.771439999999998	Неверовского	0103000020E610000001000000050000001AA20A7F86054040C269C18BBE624B401AA20A7F86054040C68A1A4CC3624B40EE60C43E01064040C68A1A4CC3624B40EE60C43E01064040C269C18BBE624B401AA20A7F86054040C269C18BBE624B40
39579	6	32.005068999999999	32.036392999999997	54.781742000000001	54.780776000000003	Нахимова	0103000020E61000000100000005000000999CDA19A600404038C0CC77F0634B40999CDA19A60040406FF4311F10644B40D3669C86A80440406FF4311F10644B40D3669C86A804404038C0CC77F0634B40999CDA19A600404038C0CC77F0634B40
39667	6	32.023564999999998	32.029431000000002	54.778818999999999	54.776829999999997	Нарвская	0103000020E61000000100000005000000452A8C2D040340409D465A2A6F634B40452A8C2D0403404070404B57B0634B408A3E1F65C403404070404B57B0634B408A3E1F65C40340409D465A2A6F634B40452A8C2D040340409D465A2A6F634B40
40038	6	32.138396999999998	32.154215999999998	54.803927000000002	54.803372000000003	Московский Большак	0103000020E61000000100000005000000A86E2EFEB6114040D542C9E4D4664B40A86E2EFEB61140408AAF7614E7664B408D429259BD1340408AAF7614E7664B408D429259BD134040D542C9E4D4664B40A86E2EFEB6114040D542C9E4D4664B40
39587	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	Маршала Соколовского	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39585	6	32.005015	32.021284000000001	54.772120000000001	54.769804000000001	Марины Расковой	0103000020E61000000100000005000000A67EDE54A40040403D2AFEEF88624B40A67EDE54A4004040344B02D4D4624B40CBF6216FB9024040344B02D4D4624B40CBF6216FB90240403D2AFEEF88624B40A67EDE54A40040403D2AFEEF88624B40
39928	6	32.044308000000001	32.061976999999999	54.783752	54.782443000000001	Ленина	0103000020E61000000100000005000000C07971E2AB054040F8FD9B1727644B40C07971E2AB05404059164CFC51644B40560DC2DCEE07404059164CFC51644B40560DC2DCEE074040F8FD9B1727644B40C07971E2AB054040F8FD9B1727644B40
39884	6	32.044308000000001	32.061976999999999	54.783752	54.782443000000001	Ленина	0103000020E61000000100000005000000C07971E2AB054040F8FD9B1727644B40C07971E2AB05404059164CFC51644B40560DC2DCEE07404059164CFC51644B40560DC2DCEE074040F8FD9B1727644B40C07971E2AB054040F8FD9B1727644B40
39894	6	32.050991000000003	32.072048000000002	54.778154000000001	54.756459	Крупской	0103000020E61000000100000005000000F7B182DF86064040E7E104A6D3604B40F7B182DF8606404034A0DE8C9A634B4001DF6DDE3809404034A0DE8C9A634B4001DF6DDE38094040E7E104A6D3604B40F7B182DF86064040E7E104A6D3604B40
39913	6	32.044299000000002	32.057763999999999	54.780673	54.779815999999997	Коммунистическая	0103000020E610000001000000050000006D1FF296AB054040E272BC02D1634B406D1FF296AB05404063EFC517ED634B406D718DCF6407404063EFC517ED634B406D718DCF64074040E272BC02D1634B406D1FF296AB054040E272BC02D1634B40
39917	6	32.050514999999997	32.052957999999997	54.772494000000002	54.772379999999998	Коммунальная	0103000020E610000001000000050000008D7A884677064040D00A0C59DD624B408D7A884677064040992D5915E1624B40E107E753C7064040992D5915E1624B40E107E753C7064040D00A0C59DD624B408D7A884677064040D00A0C59DD624B40
39686	6	32.000163999999998	32.012067000000002	54.778300000000002	54.771684	Кловская	0103000020E610000001000000050000007A51BB5F05004040596C938AC6624B407A51BB5F05004040083D9B559F634B40302E55698B014040083D9B559F634B40302E55698B014040596C938AC6624B407A51BB5F05004040596C938AC6624B40
39537	6	32.023466999999997	32.059911	54.770453000000003	54.768811999999997	Кирова	0103000020E6100000010000000500000082C476F700034040DC627E6E68624B4082C476F700034040740D33349E624B40D8D5E429AB074040740D33349E624B40D8D5E429AB074040DC627E6E68624B4082C476F700034040DC627E6E68624B40
39850	6	32.032781999999997	32.050991000000003	54.795431999999998	54.778154000000001	Дзержинского	0103000020E61000000100000005000000E0F258333204404034A0DE8C9A634B40E0F25833320440408F183DB7D0654B40F7B182DF860640408F183DB7D0654B40F7B182DF8606404034A0DE8C9A634B40E0F258333204404034A0DE8C9A634B40
39575	6	32.042709000000002	32.064906000000001	54.824871000000002	54.810813000000003	Губенко	0103000020E61000000100000005000000581F0F7D77054040F9156BB8C8674B40581F0F7D770540409C35785F95694B4037A8FDD64E0840409C35785F95694B4037A8FDD64E084040F9156BB8C8674B40581F0F7D77054040F9156BB8C8674B40
39653	6	32.047559	32.062767999999998	54.816052999999997	54.810547999999997	Генерала Лукина	0103000020E61000000100000005000000B3D0CE69160640404AEB6F09C0674B40B3D0CE6916064040BE66B96C74684B401F9E25C808084040BE66B96C74684B401F9E25C8080840404AEB6F09C0674B40B3D0CE69160640404AEB6F09C0674B40
39569	6	32.062021999999999	32.070601000000003	54.80538	54.804254	Гастелло	0103000020E61000000100000005000000F6D03E56F0074040AED689CBF1664B40F6D03E56F00740401E6D1CB116674B404F081D74090940401E6D1CB116674B404F081D7409094040AED689CBF1664B40F6D03E56F0074040AED689CBF1664B40
39907	6	32.000684999999997	32.012183999999998	54.774394999999998	54.771658000000002	Гарабурды	0103000020E61000000100000005000000834C32721600404030D978B0C5624B40834C327216004040CC9717601F634B4069C4CC3E8F014040CC9717601F634B4069C4CC3E8F01404030D978B0C5624B40834C32721600404030D978B0C5624B40
39846	6	32.000684999999997	32.012183999999998	54.774394999999998	54.771658000000002	Гарабурды	0103000020E61000000100000005000000834C32721600404030D978B0C5624B40834C327216004040CC9717601F634B4069C4CC3E8F014040CC9717601F634B4069C4CC3E8F01404030D978B0C5624B40834C32721600404030D978B0C5624B40
39588	6	32.044801999999997	32.050991000000003	54.778185000000001	54.754173000000002	Гагарина проспект	0103000020E61000000100000005000000CF656A12BC0540405B43A9BD88604B40CF656A12BC0540406F9EEA909B634B40F7B182DF860640406F9EEA909B634B40F7B182DF860640405B43A9BD88604B40CF656A12BC0540405B43A9BD88604B40
1437	6	32.044801999999997	32.050991000000003	54.778185000000001	54.754173000000002	Гагарина проспект	0103000020E61000000100000005000000CF656A12BC0540405B43A9BD88604B40CF656A12BC0540406F9EEA909B634B40F7B182DF860640406F9EEA909B634B40F7B182DF860640405B43A9BD88604B40CF656A12BC0540405B43A9BD88604B40
39637	6	31.802112999999999	32.048979000000003	54.800009000000003	54.778637000000003	Витебское шоссе	0103000020E610000001000000050000004AB20E4757CD3F40503A9160AA634B404AB20E4757CD3F40BAC0E5B166664B406C98A1F144064040BAC0E5B166664B406C98A1F144064040503A9160AA634B404AB20E4757CD3F40503A9160AA634B40
39574	6	32.025145999999999	32.027473000000001	54.812472999999997	54.807569999999998	Валентины Гризодубовой	0103000020E6100000010000000500000007D0EFFB37034040889D29745E674B4007D0EFFB3703404006F1811DFF674B40F2423A3C8403404006F1811DFF674B40F2423A3C84034040889D29745E674B4007D0EFFB37034040889D29745E674B40
39873	6	32.038891	32.039752999999997	54.788777000000003	54.784790000000001	Бакунина	0103000020E61000000100000005000000EB8D5A61FA0440402A1DACFF73644B40EB8D5A61FA044040236B0DA5F6644B407D7555A016054040236B0DA5F6644B407D7555A0160540402A1DACFF73644B40EB8D5A61FA0440402A1DACFF73644B40
39662	6	32.019863999999998	32.030580999999998	54.789690999999998	54.772021000000002	Багратиона	0103000020E61000000100000005000000122F4FE78A024040A1698995D1624B40122F4FE78A02404007793D9814654B4082700514EA03404007793D9814654B4082700514EA034040A1698995D1624B40122F4FE78A024040A1698995D1624B40
39761	6	32.005203999999999	32.023564999999998	54.777073999999999	54.776725999999996	Академика Петрова	0103000020E6100000010000000500000079E75086AA004040F8F9EFC16B634B4079E75086AA00404034492C2977634B40452A8C2D0403404034492C2977634B40452A8C2D04034040F8F9EFC16B634B4079E75086AA004040F8F9EFC16B634B40
39644	6	32.050263000000001	32.069245000000002	54.822277999999997	54.817551999999999	Автозаводская	0103000020E6100000010000000500000074999A046F064040C3633F8BA5684B4074999A046F064040321CCF6740694B40AD342905DD084040321CCF6740694B40AD342905DD084040C3633F8BA5684B4074999A046F064040C3633F8BA5684B40
39906	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	25 Сентября	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39889	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	12 Лет Октября	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39835	6	31.788288000000001	32.209902999999997	54.850167999999996	54.709308999999998	12 Лет Октября	0103000020E610000001000000050000004AD40B3ECDC93F4015E126A3CA5A4B404AD40B3ECDC93F40880D164ED26C4B40882AFC19DE1A4040880D164ED26C4B40882AFC19DE1A404015E126A3CA5A4B404AD40B3ECDC93F4015E126A3CA5A4B40
39581	6	31.995825	32.004835999999997	54.805608999999997	54.801639000000002	 Радищева	0103000020E61000000100000005000000098A1F63EEFE3F405D19541B9C664B40098A1F63EEFE3F407F2E1A321E674B40F6EB4E779E0040407F2E1A321E674B40F6EB4E779E0040405D19541B9C664B40098A1F63EEFE3F405D19541B9C664B40
39632	6	32.127932000000001	32.139259000000003	54.815731	54.810237000000001	 Папанина	0103000020E61000000100000005000000520E6613601040402C8194D8B5674B40520E661360104040ACAA97DF69684B403B56293DD3114040ACAA97DF69684B403B56293DD31140402C8194D8B5674B40520E6613601040402C8194D8B5674B40
39567	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	микрорайон-2	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39623	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	микрорайон-1	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39805	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Энгельса	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39546	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Строителей	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39722	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Советская	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39983	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Районная подстанция	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
40012	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Пушкина	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39823	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Октябрьская	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39803	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Ленина	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39746	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Кутузова	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39629	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Куйбышева	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
40123	45598	33.787478999999998	33.795959000000003	55.293360999999997	55.287086000000002	Ковалева	0103000020E61000000100000005000000B5A4A31CCCE44040DA91EA3BBFA44B40B5A4A31CCCE44040FF756EDA8CA54B407BFA08FCE1E54040FF756EDA8CA54B407BFA08FCE1E54040DA91EA3BBFA44B40B5A4A31CCCE44040DA91EA3BBFA44B40
39820	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Красногвардейская	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39720	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Комсомольская	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39941	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Коммунистическая	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39573	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Ковалева	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
40273	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Горняцкая	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39832	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Вахрушева	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39822	54800	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	40 лет Октября	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39624	54806	31.023651000000001	31.115459000000001	54.957949999999997	54.932994999999998	Молкомбината	0103000020E610000001000000050000008884EFFD0D063F406F2A52616C774B408884EFFD0D063F40029A081B9E7A4B40640795B88E1D3F40029A081B9E7A4B40640795B88E1D3F406F2A52616C774B408884EFFD0D063F406F2A52616C774B40
39978	54806	31.023651000000001	31.115459000000001	54.957949999999997	54.932994999999998	Мелиораторов	0103000020E610000001000000050000008884EFFD0D063F406F2A52616C774B408884EFFD0D063F40029A081B9E7A4B40640795B88E1D3F40029A081B9E7A4B40640795B88E1D3F406F2A52616C774B408884EFFD0D063F406F2A52616C774B40
39719	54806	31.023651000000001	31.115459000000001	54.957949999999997	54.932994999999998	Красноярская	0103000020E610000001000000050000008884EFFD0D063F406F2A52616C774B408884EFFD0D063F40029A081B9E7A4B40640795B88E1D3F40029A081B9E7A4B40640795B88E1D3F406F2A52616C774B408884EFFD0D063F406F2A52616C774B40
39743	54806	31.023651000000001	31.115459000000001	54.957949999999997	54.932994999999998	Киреева	0103000020E610000001000000050000008884EFFD0D063F406F2A52616C774B408884EFFD0D063F40029A081B9E7A4B40640795B88E1D3F40029A081B9E7A4B40640795B88E1D3F406F2A52616C774B408884EFFD0D063F406F2A52616C774B40
39800	54806	31.023651000000001	31.115459000000001	54.957949999999997	54.932994999999998	Западная	0103000020E610000001000000050000008884EFFD0D063F406F2A52616C774B408884EFFD0D063F40029A081B9E7A4B40640795B88E1D3F40029A081B9E7A4B40640795B88E1D3F406F2A52616C774B408884EFFD0D063F406F2A52616C774B40
39594	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	площадь Бернандоса	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39621	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	пер.1-й Братский	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39797	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Энергетиков	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39561	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Советская	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39741	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Пушкина	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39562	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Пролетарская	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39794	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Мичурина	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39620	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Ленина	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39740	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Красноармейская	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39615	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Красина	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39877	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Каляева	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39975	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	К.Маркса	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39876	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Заслонова	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39619	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Горького	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39530	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	34 микрорайон	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39618	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	2-я Дачная  	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39565	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	17 микрорайон	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39742	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	16 микрорайон	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39798	54794	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	15 микрорайон	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39616	54803	32.415751999999998	32.473100000000002	54.425702000000001	54.391337999999998	Толстого	0103000020E61000000100000005000000909F8D5C373540404DD7135D17324B40909F8D5C37354040C0EB33677D364B406ADE718A8E3C4040C0EB33677D364B406ADE718A8E3C40404DD7135D17324B40909F8D5C373540404DD7135D17324B40
39564	54803	32.415751999999998	32.473100000000002	54.425702000000001	54.391337999999998	Красноармейская	0103000020E61000000100000005000000909F8D5C373540404DD7135D17324B40909F8D5C37354040C0EB33677D364B406ADE718A8E3C4040C0EB33677D364B406ADE718A8E3C40404DD7135D17324B40909F8D5C373540404DD7135D17324B40
39738	54803	32.415751999999998	32.473100000000002	54.425702000000001	54.391337999999998	Кирова	0103000020E61000000100000005000000909F8D5C373540404DD7135D17324B40909F8D5C37354040C0EB33677D364B406ADE718A8E3C4040C0EB33677D364B406ADE718A8E3C40404DD7135D17324B40909F8D5C373540404DD7135D17324B40
39706	7627	31.831443	31.874507999999999	54.792354000000003	54.783814	Северная	0103000020E61000000100000005000000F67CCD72D9D43F40CF12640454644B40F67CCD72D9D43F406A6D1ADB6B654B4022179CC1DFDF3F406A6D1ADB6B654B4022179CC1DFDF3F40CF12640454644B40F67CCD72D9D43F40CF12640454644B40
39534	45893	31.947945000000001	31.970637	54.761789	54.750151000000002	Молодёжная	0103000020E610000001000000050000001F680586ACF23F40E607AEF204604B401F680586ACF23F40EDB94C4D82614B409D499BAA7BF83F40EDB94C4D82614B409D499BAA7BF83F40E607AEF204604B401F680586ACF23F40E607AEF204604B40
39890	54828	31.905653000000001	31.906846999999999	54.805515	54.803713999999999	Станционный переулок	0103000020E61000000100000005000000388600E0D8E73F402EABB019E0664B40388600E0D8E73F40FEB7921D1B674B40C879FF1F27E83F40FEB7921D1B674B40C879FF1F27E83F402EABB019E0664B40388600E0D8E73F402EABB019E0664B40
39611	54797	33.15193	33.210760999999998	54.592832000000001	54.561107999999997	микрорайон Кутузовский	0103000020E6100000010000000500000001A436717293404011C30E63D2474B4001A4367172934040DA0242EBE14B4B40D9226937FA9A4040DA0242EBE14B4B40D9226937FA9A404011C30E63D2474B4001A436717293404011C30E63D2474B40
39607	54797	33.15193	33.210760999999998	54.592832000000001	54.561107999999997	Смоленский большак	0103000020E6100000010000000500000001A436717293404011C30E63D2474B4001A4367172934040DA0242EBE14B4B40D9226937FA9A4040DA0242EBE14B4B40D9226937FA9A404011C30E63D2474B4001A436717293404011C30E63D2474B40
39655	54797	33.15193	33.210760999999998	54.592832000000001	54.561107999999997	Пролетарская	0103000020E6100000010000000500000001A436717293404011C30E63D2474B4001A4367172934040DA0242EBE14B4B40D9226937FA9A4040DA0242EBE14B4B40D9226937FA9A404011C30E63D2474B4001A436717293404011C30E63D2474B40
39874	54797	33.15193	33.210760999999998	54.592832000000001	54.561107999999997	Ленина	0103000020E6100000010000000500000001A436717293404011C30E63D2474B4001A4367172934040DA0242EBE14B4B40D9226937FA9A4040DA0242EBE14B4B40D9226937FA9A404011C30E63D2474B4001A436717293404011C30E63D2474B40
39535	54797	33.15193	33.210760999999998	54.592832000000001	54.561107999999997	Кировская	0103000020E6100000010000000500000001A436717293404011C30E63D2474B4001A4367172934040DA0242EBE14B4B40D9226937FA9A4040DA0242EBE14B4B40D9226937FA9A404011C30E63D2474B4001A436717293404011C30E63D2474B40
39732	54802	32.377214000000002	32.429011000000003	55.208348000000001	55.182479999999998	Смоленская	0103000020E61000000100000005000000F3CB608C48304040481630815B974B40F3CB608C48304040F017B325AB9A4B40E84F1BD5E9364040F017B325AB9A4B40E84F1BD5E9364040481630815B974B40F3CB608C48304040481630815B974B40
39538	54798	33.256799999999998	33.376553999999999	54.936776000000002	54.887393000000003	Седова	0103000020E6100000010000000500000070CE88D2DEA0404084D9041896714B4070CE88D2DEA04040BFD6A546E8774B40C896E5EB32B04040BFD6A546E8774B40C896E5EB32B0404084D9041896714B4070CE88D2DEA0404084D9041896714B40
39735	54798	33.256799999999998	33.376553999999999	54.936776000000002	54.887393000000003	Пушкина	0103000020E6100000010000000500000070CE88D2DEA0404084D9041896714B4070CE88D2DEA04040BFD6A546E8774B40C896E5EB32B04040BFD6A546E8774B40C896E5EB32B0404084D9041896714B4070CE88D2DEA0404084D9041896714B40
39698	54798	33.256799999999998	33.376553999999999	54.936776000000002	54.887393000000003	Путенкова	0103000020E6100000010000000500000070CE88D2DEA0404084D9041896714B4070CE88D2DEA04040BFD6A546E8774B40C896E5EB32B04040BFD6A546E8774B40C896E5EB32B0404084D9041896714B4070CE88D2DEA0404084D9041896714B40
39554	54795	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	4 микрорайон	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
39532	54795	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	3 микрорайон	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
39729	54795	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	2 микрорайон	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
39786	54795	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	1 микрорайон	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
39787	54795	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	 1 микрорайон	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
39669	54796	31.476869000000001	31.578458999999999	55.292028000000002	55.240820999999997	Суворовский проезд	0103000020E61000000100000005000000EA793716147A3F405298F738D39E4B40EA793716147A3F4016C26A2C61A54B40AD1397E315943F4016C26A2C61A54B40AD1397E315943F405298F738D39E4B40EA793716147A3F405298F738D39E4B40
39533	54796	31.476869000000001	31.578458999999999	55.292028000000002	55.240820999999997	Советская	0103000020E61000000100000005000000EA793716147A3F405298F738D39E4B40EA793716147A3F4016C26A2C61A54B40AD1397E315943F4016C26A2C61A54B40AD1397E315943F405298F738D39E4B40EA793716147A3F405298F738D39E4B40
39727	54796	31.476869000000001	31.578458999999999	55.292028000000002	55.240820999999997	Октябрьская	0103000020E61000000100000005000000EA793716147A3F405298F738D39E4B40EA793716147A3F4016C26A2C61A54B40AD1397E315943F4016C26A2C61A54B40AD1397E315943F405298F738D39E4B40EA793716147A3F405298F738D39E4B40
39728	54796	31.476869000000001	31.578458999999999	55.292028000000002	55.240820999999997	Вакарина	0103000020E61000000100000005000000EA793716147A3F405298F738D39E4B40EA793716147A3F4016C26A2C61A54B40AD1397E315943F4016C26A2C61A54B40AD1397E315943F405298F738D39E4B40EA793716147A3F405298F738D39E4B40
39725	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	Строителей	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
39827	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	Советская	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
39880	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	Первомайский проезд	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
39550	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	П.Алексеева	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
40009	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	Молодежная	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
39818	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	Ленина	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
39665	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	Гагарина	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
39710	54801	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	Бахтина	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
39666	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Юбилейная	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39659	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Строителей	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39783	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Пушкина	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39544	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Ползунова	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39806	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Покровского	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39553	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Плотникова	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39528	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Московская	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39545	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Ленина	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39875	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Заслонова	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39811	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Загородный переулок	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39625	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Докучаева	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39810	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	25 Октября	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
40247	54793	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	 Ленина	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39703	54799	31.135608000000001	31.230784	55.627763000000002	55.590353	Советская	0103000020E610000001000000050000007313B534B7223F40390CE6AF90CB4B407313B534B7223F40C651B9895AD04B40A87004A9143B3F40C651B9895AD04B40A87004A9143B3F40390CE6AF90CB4B407313B534B7223F40390CE6AF90CB4B40
39539	54799	31.135608000000001	31.230784	55.627763000000002	55.590353	Недоговорова	0103000020E610000001000000050000007313B534B7223F40390CE6AF90CB4B407313B534B7223F40C651B9895AD04B40A87004A9143B3F40C651B9895AD04B40A87004A9143B3F40390CE6AF90CB4B407313B534B7223F40390CE6AF90CB4B40
39885	13395	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Чайковского	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39878	13395	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Советская	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
39869	13395	32.593969000000001	32.789468999999997	55.091009999999997	55.018628999999997	Ленинская	0103000020E610000001000000050000003EEB1A2D074C4040EBE0606F62824B403EEB1A2D074C4040F2CD3637A68B4B40581AF8510D654040F2CD3637A68B4B40581AF8510D654040EBE0606F62824B403EEB1A2D074C4040EBE0606F62824B40
9766	15281	32.888472	32.920155999999999	55.103538	55.085033000000003	Магистральная	0103000020E61000000100000005000000B3B45373B9714040570A815CE28A4B40B3B45373B971404056F2B1BB408D4B40ED9BFBABC775404056F2B1BB408D4B40ED9BFBABC7754040570A815CE28A4B40B3B45373B9714040570A815CE28A4B40
40221	40398	32.866166999999997	32.887574000000001	55.412252000000002	55.399299999999997	Центральный переулок	0103000020E61000000100000005000000EDEF6C8FDE6E40407AA52C431CB34B40EDEF6C8FDE6E4040F5DA6CACC4B44B40D4635B069C714040F5DA6CACC4B44B40D4635B069C7140407AA52C431CB34B40EDEF6C8FDE6E40407AA52C431CB34B40
40019	15152	32.607506000000001	32.633108	54.999046	54.983581999999998	переулок Центральный	0103000020E61000000100000005000000D80FB1C1C24D40409677D503E67D4B40D80FB1C1C24D40408D9944BDE07F4B40016BD5AE095140408D9944BDE07F4B40016BD5AE095140409677D503E67D4B40D80FB1C1C24D40409677D503E67D4B40
75055	54879	32.832723000000001	32.870559999999998	55.032031000000003	55.011118000000003	Парковая	0103000020E6100000010000000500000042D0D1AA966A4040CF328B506C814B4042D0D1AA966A4040A6BA809719844B40569A94826E6F4040A6BA809719844B40569A94826E6F4040CF328B506C814B4042D0D1AA966A4040CF328B506C814B40
40219	49055	32.776550999999998	32.794696999999999	55.049436	55.035947	Школьная	0103000020E610000001000000050000008A56EE0566634040D5B14AE999844B408A56EE05666340405E9F39EB53864B405A9D9CA1B86540405E9F39EB53864B405A9D9CA1B8654040D5B14AE999844B408A56EE0566634040D5B14AE999844B40
40033	15015	32.499053000000004	32.522219999999997	55.063766999999999	55.056043000000003	Школьная	0103000020E6100000010000000500000040FCFCF7E03F4040BA15C26A2C874B4040FCFCF7E03F404032C85D8429884B4097A8DE1AD842404032C85D8429884B4097A8DE1AD8424040BA15C26A2C874B4040FCFCF7E03F4040BA15C26A2C874B40
39701	54813	32.661926000000001	32.688552000000001	55.098691000000002	55.080348999999998	Советская	0103000020E61000000100000005000000A12FBDFDB954404016A243E0488A4B40A12FBDFDB95440406CB41CE8A18C4B4036CCD078225840406CB41CE8A18C4B4036CCD0782258404016A243E0488A4B40A12FBDFDB954404016A243E0488A4B40
40101	14927	32.923884000000001	32.965108000000001	55.402526000000002	55.383025000000004	Победы	0103000020E610000001000000050000001AA6B6D441764040744694F606B14B401AA6B6D44176404015E5D2F885B34B40D28DB0A8887B404015E5D2F885B34B40D28DB0A8887B4040744694F606B14B401AA6B6D441764040744694F606B14B40
75021	48958	32.735416999999998	32.763229000000003	55.420265000000001	55.407181999999999	Школьная	0103000020E6100000010000000500000012F6ED24225E40408BC22E8A1EB44B4012F6ED24225E4040A453573ECBB54B40ED2DE57CB1614040A453573ECBB54B40ED2DE57CB16140408BC22E8A1EB44B4012F6ED24225E40408BC22E8A1EB44B40
40104	48953	32.641939000000001	32.672499000000002	55.295062999999999	55.286450000000002	Школьная	0103000020E610000001000000050000007383A10E2B52404038F8C264AAA44B407383A10E2B5240403CA1D79FC4A54B40DECB7D72145640403CA1D79FC4A54B40DECB7D721456404038F8C264AAA44B407383A10E2B52404038F8C264AAA44B40
39687	14822	32.852145	32.876632999999998	55.243761999999997	55.204002000000003	Школьная	0103000020E6100000010000000500000097395D16136D4040C828CFBC1C9A4B4097395D16136D4040F700DD97339F4B4014CC988235704040F700DD97339F4B4014CC988235704040C828CFBC1C9A4B4097395D16136D4040C828CFBC1C9A4B40
39769	12734	32.405808	32.447031000000003	53.877496999999998	53.836970999999998	Советская	0103000020E61000000100000005000000433A3C84F1334040A759A0DD21EB4A40433A3C84F133404047AB5AD251F04A402BA6D24F3839404047AB5AD251F04A402BA6D24F38394040A759A0DD21EB4A40433A3C84F1334040A759A0DD21EB4A40
40283	48229	32.357999	32.391514999999998	53.938723000000003	53.924612000000003	Молодежная	0103000020E61000000100000005000000178046E9D22D40409DBE9EAF59F64A40178046E9D22D40406380441328F84A405C72DC291D3240406380441328F84A405C72DC291D3240409DBE9EAF59F64A40178046E9D22D40409DBE9EAF59F64A40
40086	54852	32.381417999999996	32.402681000000001	53.848599999999998	53.839010999999999	Руссковская	0103000020E61000000100000005000000880D164ED2304040FCFD62B664EB4A40880D164ED23040405BB1BFEC9EEC4A403CDC0E0D8B3340405BB1BFEC9EEC4A403CDC0E0D8B334040FCFD62B664EB4A40880D164ED2304040FCFD62B664EB4A40
39949	54834	32.432380000000002	32.472597	53.817323000000002	53.796889999999998	Первомайская	0103000020E61000000100000005000000E5B8533A583740403541D47D00E64A40E5B8533A5837404062A2410A9EE84A400798F90E7E3C404062A2410A9EE84A400798F90E7E3C40403541D47D00E64A40E5B8533A583740403541D47D00E64A40
75090	48477	33.314444999999999	33.319510999999999	55.637402999999999	55.631503000000002	Школьная	0103000020E6100000010000000500000003B2D7BB3FA84040B7291E17D5D04B4003B2D7BB3FA84040A7AFE76B96D14B402BDB87BCE5A84040A7AFE76B96D14B402BDB87BCE5A84040B7291E17D5D04B4003B2D7BB3FA84040B7291E17D5D04B40
39864	12603	33.462532000000003	33.503998000000003	55.525446000000002	55.494909999999997	Старшины Сорокина	0103000020E610000001000000050000003FADA23F34BB40404F3BFC3559BF4B403FADA23F34BB404032E884D041C34B40ED9FA70183C0404032E884D041C34B40ED9FA70183C040404F3BFC3559BF4B403FADA23F34BB40404F3BFC3559BF4B40
39865	12603	33.462532000000003	33.503998000000003	55.525446000000002	55.494909999999997	Советская	0103000020E610000001000000050000003FADA23F34BB40404F3BFC3559BF4B403FADA23F34BB404032E884D041C34B40ED9FA70183C0404032E884D041C34B40ED9FA70183C040404F3BFC3559BF4B403FADA23F34BB40404F3BFC3559BF4B40
39591	12603	33.462532000000003	33.503998000000003	55.525446000000002	55.494909999999997	Нахимовская	0103000020E610000001000000050000003FADA23F34BB40404F3BFC3559BF4B403FADA23F34BB404032E884D041C34B40ED9FA70183C0404032E884D041C34B40ED9FA70183C040404F3BFC3559BF4B403FADA23F34BB40404F3BFC3559BF4B40
40215	48013	33.563699999999997	33.579528000000003	55.457169	55.436861999999998	Центральная	0103000020E61000000100000005000000AA60545227C84040BD6E1118EBB74B40AA60545227C840405DDF878384BA4B40E38E37F92DCA40405DDF878384BA4B40E38E37F92DCA4040BD6E1118EBB74B40AA60545227C84040BD6E1118EBB74B40
40185	12400	33.726080000000003	33.754196999999998	55.438434999999998	55.425863999999997	Грибоедова	0103000020E61000000100000005000000CD237F30F0DC4040994528B682B64B40CD237F30F0DC4040FC3559A31EB84B40E3DEFC8689E04040FC3559A31EB84B40E3DEFC8689E04040994528B682B64B40CD237F30F0DC4040994528B682B64B40
40100	12353	33.379465000000003	33.406844999999997	55.638027999999998	55.626533000000002	Школьная	0103000020E61000000100000005000000037D224F92B04040B16EBC3B32D04B40037D224F92B0404055F7C8E6AAD14B4043C5387F13B4404055F7C8E6AAD14B4043C5387F13B44040B16EBC3B32D04B40037D224F92B04040B16EBC3B32D04B40
40156	54864	33.293306999999999	33.313285999999998	55.612772	55.600928000000003	Базарная	0103000020E610000001000000050000000C5872158BA5404017A06D35EBCC4B400C5872158BA54040C7F319506FCE4B40B72572C119A84040C7F319506FCE4B40B72572C119A8404017A06D35EBCC4B400C5872158BA5404017A06D35EBCC4B40
40282	12256	33.38993	33.401975999999998	55.551088999999997	55.543011999999997	Центральный переулок	0103000020E6100000010000000500000059DDEA39E9B14040F3AACE6A81C54B4059DDEA39E9B14040B91798158AC64B4071E316F373B34040B91798158AC64B4071E316F373B34040F3AACE6A81C54B4059DDEA39E9B14040F3AACE6A81C54B40
40216	54882	33.250996999999998	33.269044000000001	55.524849000000003	55.517856999999999	Железнодорожная	0103000020E61000000100000005000000723271AB20A0404099805F2349C24B40723271AB20A040404E2B85402EC34B40AF97A60870A240404E2B85402EC34B40AF97A60870A2404099805F2349C24B40723271AB20A0404099805F2349C24B40
39866	54825	33.266331000000001	33.308632000000003	55.472648	55.436371999999999	Южная	0103000020E610000001000000050000009B745B2217A24040EF71A609DBB74B409B745B2217A240408942CBBA7FBC4B40E23FDD4081A740408942CBBA7FBC4B40E23FDD4081A74040EF71A609DBB74B409B745B2217A24040EF71A609DBB74B40
75070	48920	33.711167000000003	33.720348000000001	55.594585000000002	55.589385999999998	Центральная	0103000020E610000001000000050000004A7F2F8507DB4040315C1D0071CB4B404A7F2F8507DB404099D87C5C1BCC4B4098DEFE5C34DC404099D87C5C1BCC4B4098DEFE5C34DC4040315C1D0071CB4B404A7F2F8507DB4040315C1D0071CB4B40
40071	54849	33.316538000000001	33.318361000000003	55.695990999999999	55.694794000000002	Железнодорожная	0103000020E610000001000000050000007BF8325184A8404080BA8102EFD84B407BF8325184A84040B9A7AB3B16D94B4033A9A10DC0A84040B9A7AB3B16D94B4033A9A10DC0A8404080BA8102EFD84B407BF8325184A8404080BA8102EFD84B40
75186	60530	33.023282999999999	33.038167999999999	55.507126999999997	55.495638999999997	Новая	0103000020E61000000100000005000000C1C6F5EFFA824040A2CF471971BF4B40C1C6F5EFFA82404094F59B89E9C04B407AE063B0E284404094F59B89E9C04B407AE063B0E2844040A2CF471971BF4B40C1C6F5EFFA824040A2CF471971BF4B40
39948	47823	32.936703000000001	32.975949999999997	55.510455999999998	55.495154999999997	Центральная	0103000020E61000000100000005000000558847E2E5774040B6B9313D61BF4B40558847E2E57740400306499F56C14B40FE43FAEDEB7C40400306499F56C14B40FE43FAEDEB7C4040B6B9313D61BF4B40558847E2E5774040B6B9313D61BF4B40
40677	47802	32.783900000000003	32.818018000000002	55.631737000000001	55.554546999999999	Лесная	0103000020E61000000100000005000000CEAACFD556644040268C6665FBC64B40CEAACFD5566440402A560DC2DCD04B4009C556D0B46840402A560DC2DCD04B4009C556D0B4684040268C6665FBC64B40CEAACFD556644040268C6665FBC64B40
40214	11896	33.503979999999999	33.526401999999997	55.415686000000001	55.404116000000002	Черемушки	0103000020E6100000010000000500000046EBA86A82C040402AE5B512BAB34B4046EBA86A82C04040D9B3E73235B54B404546072461C34040D9B3E73235B54B404546072461C340402AE5B512BAB34B4046EBA86A82C040402AE5B512BAB34B40
39767	10876	32.132351	32.183563999999997	54.218336000000001	54.172730999999999	Советская	0103000020E61000000100000005000000E44BA8E0F0104040B000A60C1C164B40E44BA8E0F01040400DC51D6FF21B4B40895C70067F1740400DC51D6FF21B4B40895C70067F174040B000A60C1C164B40E44BA8E0F0104040B000A60C1C164B40
40322	10876	32.132351	32.183563999999997	54.218336000000001	54.172730999999999	Северная	0103000020E61000000100000005000000E44BA8E0F0104040B000A60C1C164B40E44BA8E0F01040400DC51D6FF21B4B40895C70067F1740400DC51D6FF21B4B40895C70067F174040B000A60C1C164B40E44BA8E0F0104040B000A60C1C164B40
39674	10876	32.132351	32.183563999999997	54.218336000000001	54.172730999999999	Пушкина переулок	0103000020E61000000100000005000000E44BA8E0F0104040B000A60C1C164B40E44BA8E0F01040400DC51D6FF21B4B40895C70067F1740400DC51D6FF21B4B40895C70067F174040B000A60C1C164B40E44BA8E0F0104040B000A60C1C164B40
40152	10876	32.132351	32.183563999999997	54.218336000000001	54.172730999999999	Берестнева	0103000020E61000000100000005000000E44BA8E0F0104040B000A60C1C164B40E44BA8E0F01040400DC51D6FF21B4B40895C70067F1740400DC51D6FF21B4B40895C70067F174040B000A60C1C164B40E44BA8E0F0104040B000A60C1C164B40
39847	6702	32.254747000000002	32.267189000000002	54.159089000000002	54.146982000000001	Школьная	0103000020E6100000010000000500000087E0B88C9B204040E38C614ED0124B4087E0B88C9B204040A11342075D144B40EC6CC83F33224040A11342075D144B40EC6CC83F33224040E38C614ED0124B4087E0B88C9B204040E38C614ED0124B40
75177	47822	32.236016999999997	32.251989000000002	54.209907000000001	54.204915	Октябрьская	0103000020E61000000100000005000000672618CE351E4040DCBA9BA73A1A4B40672618CE351E4040CA198A3BDE1A4B40D3F9F02C41204040CA198A3BDE1A4B40D3F9F02C41204040DCBA9BA73A1A4B40672618CE351E4040DCBA9BA73A1A4B40
39673	47370	34.299339000000003	34.364215999999999	54.792155999999999	54.763809999999999	Советская	0103000020E610000001000000050000006CB587BD50264140CB2DAD86C4614B406CB587BD5026414043AA285E65654B40085740A19E2E414043AA285E65654B40085740A19E2E4140CB2DAD86C4614B406CB587BD50264140CB2DAD86C4614B40
39859	47370	34.299339000000003	34.364215999999999	54.792155999999999	54.763809999999999	Мира	0103000020E610000001000000050000006CB587BD50264140CB2DAD86C4614B406CB587BD5026414043AA285E65654B40085740A19E2E414043AA285E65654B40085740A19E2E4140CB2DAD86C4614B406CB587BD50264140CB2DAD86C4614B40
40242	9809	34.864829	34.893261000000003	55.125869999999999	55.108457000000001	Центральная	0103000020E61000000100000005000000F2D077B7B26E4140DA0242EBE18D4B40F2D077B7B26E414015C616821C904B4069E55E605672414015C616821C904B4069E55E6056724140DA0242EBE18D4B40F2D077B7B26E4140DA0242EBE18D4B40
75056	49129	34.813957000000002	34.821475999999997	54.996366000000002	54.992575000000002	Центральная	0103000020E61000000100000005000000D6AC33BE2F684140E2E995B20C7F4B40D6AC33BE2F684140556CCCEB887F4B407539252026694140556CCCEB887F4B407539252026694140E2E995B20C7F4B40D6AC33BE2F684140E2E995B20C7F4B40
40120	9361	34.792892000000002	34.814272000000003	55.232263000000003	55.221322000000001	Возрождения	0103000020E6100000010000000500000049A12C7C7D65414052F17F47549C4B4049A12C7C7D654140128942CBBA9D4B4036069D103A684140128942CBBA9D4B4036069D103A68414052F17F47549C4B4049A12C7C7D65414052F17F47549C4B40
40277	9732	34.923974000000001	34.948371999999999	55.061951999999998	55.049337999999999	Центральная	0103000020E610000001000000050000005A2DB0C7447641409B3924B550864B405A2DB0C744764140FDF50A0BEE874B409738F24064794140FDF50A0BEE874B409738F240647941409B3924B550864B405A2DB0C7447641409B3924B550864B40
40278	9476	35.117398999999999	35.130586000000001	55.192435000000003	55.184514999999998	Молодежная	0103000020E61000000100000005000000A3CA30EE068F41408B4F01309E974B40A3CA30EE068F41408ACDC7B5A1984B4061A8C30AB79041408ACDC7B5A1984B4061A8C30AB79041408B4F01309E974B40A3CA30EE068F41408B4F01309E974B40
39998	9743	35.074782999999996	35.095830999999997	55.088481000000002	55.080772000000003	Липовая Аллея	0103000020E61000000100000005000000FCA5457D928941405D37A5BC568A4B40FCA5457D92894140A0A86C58538B4B40B378B130448C4140A0A86C58538B4B40B378B130448C41405D37A5BC568A4B40FCA5457D928941405D37A5BC568A4B40
40234	7565	31.722287999999999	31.740632000000002	54.755425000000002	54.745921000000003	Смоленская	0103000020E61000000100000005000000124BCADDE7B83F402733DE567A5F4B40124BCADDE7B83F4058CA32C4B1604B40FF5E0A0F9ABD3F4058CA32C4B1604B40FF5E0A0F9ABD3F402733DE567A5F4B40124BCADDE7B83F402733DE567A5F4B40
40029	54843	31.815712999999999	31.848258999999999	54.706516000000001	54.694986999999998	Мира	0103000020E610000001000000050000000BEC3191D2D03F4094128255F5584B400BEC3191D2D03F40E50CC51D6F5A4B40A489778027D93F40E50CC51D6F5A4B40A489778027D93F4094128255F5584B400BEC3191D2D03F4094128255F5584B40
39855	7321	32.170862	32.196662000000003	54.662447999999998	54.644119000000003	Ленина	0103000020E61000000100000005000000881057CEDE154040BADDCB7D72524B40881057CEDE1540407AA69718CB544B40D82E6D382C1940407AA69718CB544B40D82E6D382C194040BADDCB7D72524B40881057CEDE154040BADDCB7D72524B40
39963	46102	31.625503999999999	31.655328000000001	54.788978999999998	54.776741999999999	Озерная	0103000020E610000001000000050000006684B70721A03F40FEB627486C634B406684B70721A03F408A1D8D43FD644B4031276893C3A73F408A1D8D43FD644B4031276893C3A73F40FEB627486C634B406684B70721A03F40FEB627486C634B40
75104	60508	31.880759999999999	31.904575000000001	54.551876999999998	54.538753	Центральная	0103000020E61000000100000005000000FD9FC37C79E13F409ACFB9DBF5444B40FD9FC37C79E13F401135D1E7A3464B407AC7293A92E73F401135D1E7A3464B407AC7293A92E73F409ACFB9DBF5444B40FD9FC37C79E13F409ACFB9DBF5444B40
39990	45823	31.941009999999999	31.961402	54.63523	54.618138999999999	Центральная	0103000020E610000001000000050000007E350708E6F03F40EAB0C22D1F4F4B407E350708E6F03F4013B875374F514B401A4F04711EF63F4013B875374F514B401A4F04711EF63F40EAB0C22D1F4F4B407E350708E6F03F40EAB0C22D1F4F4B40
40095	45653	32.153803000000003	32.298675000000003	54.849317999999997	54.763207000000001	Центральная	0103000020E610000001000000050000006B8313D1AF134040058A58C4B0614B406B8313D1AF134040BAF3C473B66C4B4000917EFB3A264040BAF3C473B66C4B4000917EFB3A264040058A58C4B0614B406B8313D1AF134040058A58C4B0614B40
39671	7028	32.134076	32.170735999999998	54.697526000000003	54.677447999999998	Спортивная	0103000020E61000000100000005000000D996016729114040CC5EB69DB6564B40D9960167291140400B0E2F8848594B40FB1F60ADDA1540400B0E2F8848594B40FB1F60ADDA154040CC5EB69DB6564B40D996016729114040CC5EB69DB6564B40
40202	46126	31.555292000000001	31.576733999999998	54.807907	54.796759999999999	Витебское шоссе	0103000020E61000000100000005000000FEBAD39D278E3F4067614F3BFC654B40FEBAD39D278E3F40D09A1F7F69674B40C37DE4D6A4933F40D09A1F7F69674B40C37DE4D6A4933F4067614F3BFC654B40FEBAD39D278E3F4067614F3BFC654B40
39599	3690	32.020808000000002	32.041882000000001	54.859138999999999	54.845455999999999	Автодорожная	0103000020E6100000010000000500000062BF27D6A90240407E1AF7E6376C4B4062BF27D6A9024040ECDB4944F86D4B404225AE635C054040ECDB4944F86D4B404225AE635C0540407E1AF7E6376C4B4062BF27D6A90240407E1AF7E6376C4B40
40249	48429	31.842357	31.854870999999999	54.851433	54.840656000000003	Садовый переулок	0103000020E61000000100000005000000828E56B5A4D73F40D597A59D9A6B4B40828E56B5A4D73F401ADEACC1FB6C4B407F4C6BD3D8DA3F401ADEACC1FB6C4B407F4C6BD3D8DA3F40D597A59D9A6B4B40828E56B5A4D73F40D597A59D9A6B4B40
40207	7634	31.685314000000002	31.714248999999999	54.817281999999999	54.803978999999998	Парковая	0103000020E61000000100000005000000AF7D01BD70AF3F40DCD5ABC8E8664B40AF7D01BD70AF3F4003CE52B29C684B406133C005D9B63F4003CE52B29C684B406133C005D9B63F40DCD5ABC8E8664B40AF7D01BD70AF3F40DCD5ABC8E8664B40
40035	45998	31.789176999999999	31.809388999999999	54.810974000000002	54.805027000000003	Мира	0103000020E6100000010000000500000061C1FD8007CA3F40D1B2EE1F0B674B4061C1FD8007CA3F4002F4FBFECD674B40FDBD141E34CF3F4002F4FBFECD674B40FDBD141E34CF3F40D1B2EE1F0B674B4061C1FD8007CA3F40D1B2EE1F0B674B40
40031	6147	32.057001	32.076638000000003	54.964720999999997	54.953034000000002	Лесная	0103000020E610000001000000050000006E6B0BCF4B074040F0FCA204FD794B406E6B0BCF4B074040D8614CFA7B7B4B40C0D02346CF094040D8614CFA7B7B4B40C0D02346CF094040F0FCA204FD794B406E6B0BCF4B074040F0FCA204FD794B40
40209	7229	32.011259000000003	32.025829000000002	54.602485999999999	54.593097999999998	Школьная	0103000020E61000000100000005000000916456EF7001404058A9A0A2EA4B4B40916456EF700140402026E1421E4D4B40EA245B5D4E0340402026E1421E4D4B40EA245B5D4E03404058A9A0A2EA4B4B40916456EF7001404058A9A0A2EA4B4B40
40203	6690	32.071589000000003	32.092528999999999	55.031787999999999	55.016874000000001	Мира	0103000020E610000001000000050000006EE00ED4290940408C135FED28824B406EE00ED429094040DF3312A111844B403E7782FDD70B4040DF3312A111844B403E7782FDD70B40408C135FED28824B406EE00ED4290940408C135FED28824B40
39852	6876	32.094504999999998	32.113900000000001	54.831347999999998	54.819527999999998	Садовая	0103000020E610000001000000050000007C2766BD180C40400114234BE6684B407C2766BD180C404029CC7B9C696A4B40D8817346940E404029CC7B9C696A4B40D8817346940E40400114234BE6684B407C2766BD180C40400114234BE6684B40
39961	7506	31.877257	31.895330999999999	54.722695999999999	54.710650999999999	Садовая	0103000020E61000000100000005000000E42F2DEA93E03F4052EFA99CF65A4B40E42F2DEA93E03F409A79724D815C4B405018946934E53F409A79724D815C4B405018946934E53F4052EFA99CF65A4B40E42F2DEA93E03F4052EFA99CF65A4B40
40237	46318	31.465819	31.486148	55.043407000000002	55.025219	Колхозный переулок	0103000020E61000000100000005000000FDDAFAE93F773F40711E4E603A834B40FDDAFAE93F773F4070B54E5C8E854B400C040132747C3F4070B54E5C8E854B400C040132747C3F40711E4E603A834B40FDDAFAE93F773F40711E4E603A834B40
39672	7215	32.173412999999996	32.194415999999997	54.603873	54.591298000000002	Дружбы	0103000020E61000000100000005000000C2D9AD6532164040591822A7AF4B4B40C2D9AD6532164040FDF7E0B54B4D4B40D9E89C9FE2184040FDF7E0B54B4D4B40D9E89C9FE2184040591822A7AF4B4B40C2D9AD6532164040591822A7AF4B4B40
39652	7759	31.673932000000001	31.738593000000002	54.781903	54.758313999999999	Витебское шоссе	0103000020E6100000010000000500000056BABBCE86AC3F40AA0CE36E10614B4056BABBCE86AC3F4078D2C26515644B40F60D4C6E14BD3F4078D2C26515644B40F60D4C6E14BD3F40AA0CE36E10614B4056BABBCE86AC3F40AA0CE36E10614B40
75017	8219	31.605822	31.648627000000001	54.999521000000001	54.977248000000003	Советская	0103000020E6100000010000000500000083328D26179B3F406C0A6476167D4B4083328D26179B3F402655DB4DF07F4B40774D486B0CA63F402655DB4DF07F4B40774D486B0CA63F406C0A6476167D4B4083328D26179B3F406C0A6476167D4B40
40292	54896	31.501483	31.535420999999999	54.862886000000003	54.853361	Молодёжная	0103000020E61000000100000005000000FE7F9C3061803F404757E9EE3A6D4B40FE7F9C3061803F409016670C736E4B407497C45911893F409016670C736E4B407497C45911893F404757E9EE3A6D4B40FE7F9C3061803F404757E9EE3A6D4B40
39774	49303	32.006974	32.039115000000002	54.919061999999997	54.881194000000001	Мира	0103000020E610000001000000050000000EF62686E400404039B709F7CA704B400EF62686E4004040887FD8D2A3754B403BE466B801054040887FD8D2A3754B403BE466B80105404039B709F7CA704B400EF62686E400404039B709F7CA704B40
40044	2561	31.970196999999999	31.984452999999998	54.863394	54.854579000000001	Мичурина	0103000020E6100000010000000500000064ADA1D45EF83F40986C3CD8626D4B4064ADA1D45EF83F4004C8D0B1836E4B40F7729F1C05FC3F4004C8D0B1836E4B40F7729F1C05FC3F40986C3CD8626D4B4064ADA1D45EF83F40986C3CD8626D4B40
40079	8044	31.921032	31.948906000000001	55.054166000000002	55.043303999999999	Мира	0103000020E61000000100000005000000C991CEC0C8EB3F409BE447FC8A854B40C991CEC0C8EB3F400F4757E9EE864B406AFAEC80EBF23F400F4757E9EE864B406AFAEC80EBF23F409BE447FC8A854B40C991CEC0C8EB3F409BE447FC8A854B40
40069	8305	31.552938000000001	31.577245999999999	54.925044	54.913893000000002	Центральная	0103000020E6100000010000000500000035B742588D8D3F408C852172FA744B4035B742588D8D3F4036AE7FD767764B402FBFD364C6933F4036AE7FD767764B402FBFD364C6933F408C852172FA744B4035B742588D8D3F408C852172FA744B40
75096	60502	31.742842	31.770258999999999	54.918297000000003	54.903939999999999	.Речная	0103000020E610000001000000050000006118B0E42ABE3F40EBC5504EB4734B406118B0E42ABE3F40E9818FC18A754B401D739EB12FC53F40E9818FC18A754B401D739EB12FC53F40EBC5504EB4734B406118B0E42ABE3F40EBC5504EB4734B40
75085	45688	32.235433	32.256517000000002	54.709750999999997	54.696084999999997	Почтовая	0103000020E6100000010000000500000018B325AB221E40403A1E335019594B4018B325AB221E4040D2A6EA1ED95A4B401CEF8E8CD5204040D2A6EA1ED95A4B401CEF8E8CD52040403A1E335019594B4018B325AB221E40403A1E335019594B40
40075	8428	31.546578	31.579474000000001	55.123600000000003	55.113106999999999	Молодежная	0103000020E610000001000000050000008DB62A89EC8B3F406EF9484A7A8E4B408DB62A89EC8B3F408FE4F21FD28F4B40DFE1766858943F408FE4F21FD28F4B40DFE1766858943F406EF9484A7A8E4B408DB62A89EC8B3F406EF9484A7A8E4B40
40163	8039	31.856954999999999	31.886465000000001	55.065648000000003	55.050597000000003	Ефимова	0103000020E61000000100000005000000C824236761DB3F404B2366F679864B40C824236761DB3F401F86562767884B40740CC85EEFE23F401F86562767884B40740CC85EEFE23F404B2366F679864B40C824236761DB3F404B2366F679864B40
75062	60470	33.041086999999997	33.053331	55.098547000000003	55.095388999999997	Центральная	0103000020E6100000010000000500000037A5BC5642854040F6B2EDB4358C4B4037A5BC5642854040390F27309D8C4B40766EDA8CD3864040390F27309D8C4B40766EDA8CD3864040F6B2EDB4358C4B4037A5BC5642854040F6B2EDB4358C4B40
39947	16147	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	Калинина	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39628	16147	33.184502999999999	33.277909999999999	55.163013999999997	55.081338000000002	 микрорайон ГМП	0103000020E61000000100000005000000C78157CB9D97404006F69848698A4B40C78157CB9D97404023658BA4DD944B409D9D0C8E92A3404023658BA4DD944B409D9D0C8E92A3404006F69848698A4B40C78157CB9D97404006F69848698A4B40
39612	22902	33.463726999999999	33.476258000000001	55.090912000000003	55.088217999999998	Революционная	0103000020E61000000100000005000000D7A205685BBB4040927538BA4A8B4B40D7A205685BBB404030682101A38B4B40AC3AAB05F6BC404030682101A38B4B40AC3AAB05F6BC4040927538BA4A8B4B40D7A205685BBB4040927538BA4A8B4B40
39609	22902	33.463726999999999	33.476258000000001	55.090912000000003	55.088217999999998	1-я Краснинская	0103000020E61000000100000005000000D7A205685BBB4040927538BA4A8B4B40D7A205685BBB404030682101A38B4B40AC3AAB05F6BC404030682101A38B4B40AC3AAB05F6BC4040927538BA4A8B4B40D7A205685BBB4040927538BA4A8B4B40
75080	49508	31.031987000000001	31.065773	55.043097000000003	55.029637000000001	Молодежная	0103000020E61000000100000005000000ACE5CE4C30083F4033E02C25CB834B40ACE5CE4C30083F4022C7D63384854B40B6F5D37FD6103F4022C7D63384854B40B6F5D37FD6103F4033E02C25CB834B40ACE5CE4C30083F4033E02C25CB834B40
75133	48056	30.968081000000002	30.983872999999999	54.807341999999998	54.799385999999998	Школьная	0103000020E6100000010000000500000005E10A28D4F73E40AC70CB4752664B4005E10A28D4F73E40F7578FFB56674B40DB6AD619DFFB3E40F7578FFB56674B40DB6AD619DFFB3E40AC70CB4752664B4005E10A28D4F73E40AC70CB4752664B40
39980	28566	31.347978000000001	31.451975999999998	54.874875000000003	54.842734999999998	Ленина	0103000020E610000001000000050000003DBA111615593F40E71890BDDE6B4B403DBA111615593F40448B6CE7FB6F4B40AF93FAB2B4733F40448B6CE7FB6F4B40AF93FAB2B4733F40E71890BDDE6B4B403DBA111615593F40E71890BDDE6B4B40
75169	47482	30.899692000000002	30.931996000000002	54.786524	54.770313000000002	 Гореленкова	0103000020E610000001000000050000000C79043752E63E408257CB9D99624B400C79043752E63E4072C284D1AC644B40B900344A97EE3E4072C284D1AC644B40B900344A97EE3E408257CB9D99624B400C79043752E63E408257CB9D99624B40
39792	16009	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	переулок Димитрова	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
9743	16009	32.777773000000003	32.915250999999998	53.973447	53.920639999999999	Первомайская	0103000020E610000001000000050000001D5BCF108E634040D9B11188D7F54A401D5BCF108E634040D5B14AE999FC4A40CE50DCF126754040D5B14AE999FC4A40CE50DCF126754040D9B11188D7F54A401D5BCF108E634040D9B11188D7F54A40
39744	28019	32.790260000000004	32.815106999999998	54.028672	54.002659000000001	Советская	0103000020E6100000010000000500000022AB5B3D2765404021054F2157004B4022AB5B3D27654040CC272B86AB034B40CEDE196D55684040CC272B86AB034B40CEDE196D5568404021054F2157004B4022AB5B3D2765404021054F2157004B40
39799	27533	32.877181	32.922077999999999	53.990358000000001	53.968828999999999	Совхозная	0103000020E6100000010000000500000017D68D77477040404C35B39602FC4A4017D68D77477040407EAA0A0DC4FE4A40382EE3A6067640407EAA0A0DC4FE4A40382EE3A6067640404C35B39602FC4A4017D68D77477040404C35B39602FC4A40
39739	41362	33.082777999999998	33.097465	54.057929999999999	54.048240999999997	Советская	0103000020E61000000100000005000000056A3178988A4040C5A9D6C22C064B40056A3178988A404088BA0F406A074B4098C0ADBB798C404088BA0F406A074B4098C0ADBB798C4040C5A9D6C22C064B40056A3178988A4040C5A9D6C22C064B40
39630	54807	32.806446999999999	32.813462999999999	54.002521000000002	54.000362000000003	Мира	0103000020E61000000100000005000000897AC1A739674040A114ADDC0B004B40897AC1A739674040D046AE9B52004B40C6C03A8E1F684040D046AE9B52004B40C6C03A8E1F684040A114ADDC0B004B40897AC1A739674040A114ADDC0B004B40
39568	27286	33.260607999999998	33.318559	54.124268000000001	54.099983000000002	Комсомольская	0103000020E61000000100000005000000B9895A9A5BA14040F793313ECC0C4B40B9895A9A5BA140403CF88903E80F4B40596C938AC6A840403CF88903E80F4B40596C938AC6A84040F793313ECC0C4B40B9895A9A5BA14040F793313ECC0C4B40
39650	15391	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	2 микрорайон	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
39551	15391	33.257841999999997	33.313231999999999	54.161065999999998	54.141624	1 микрорайон	0103000020E6100000010000000500000082C476F700A14040132A38BC20124B4082C476F700A14040AF3F89CF9D144B40C40776FC17A84040AF3F89CF9D144B40C40776FC17A84040132A38BC20124B4082C476F700A14040132A38BC20124B40
40443	45501	33.145516000000001	33.168944000000003	54.256497000000003	54.227817000000002	им.колхоза Быстрые волны	0103000020E61000000100000005000000BA85AE44A0924040863C821B291D4B40BA85AE44A0924040D542C9E4D4204B407F6DFDF49F954040D542C9E4D4204B407F6DFDF49F954040863C821B291D4B40BA85AE44A0924040863C821B291D4B40
39558	24779	32.626434000000003	32.670847000000002	54.205551999999997	54.162379000000001	Ленина	0103000020E610000001000000050000001E8D43FD2E5040405247C7D5C8144B401E8D43FD2E5040404ED026874F1A4B4053CF8250DE5540404ED026874F1A4B4053CF8250DE5540405247C7D5C8144B401E8D43FD2E5040405247C7D5C8144B40
39946	54832	32.299582000000001	32.325857999999997	54.501021999999999	54.477677	Центральная	0103000020E61000000100000005000000323CF6B35826404094861A85243D4B40323CF6B358264040CB49287D21404B40EA9106B7B5294040CB49287D21404B40EA9106B7B529404094861A85243D4B40323CF6B35826404094861A85243D4B40
39971	24242	32.472498999999999	32.499205000000003	54.420144999999998	54.402717000000003	имени С.И.Бизунова	0103000020E610000001000000050000004432E4D87A3C404089450C3B8C334B404432E4D87A3C4040F949B54FC7354B40F67F0EF3E53F4040F949B54FC7354B40F67F0EF3E53F404089450C3B8C334B404432E4D87A3C404089450C3B8C334B40
75146	46008	33.857349999999997	33.863396000000002	55.658383000000001	55.654964999999997	Центральная	0103000020E61000000100000005000000E09C11A5BDED40402783A3E4D5D34B40E09C11A5BDED4040069FE6E445D44B40A5BF97C283EE4040069FE6E445D44B40A5BF97C283EE40402783A3E4D5D34B40E09C11A5BDED40402783A3E4D5D34B40
40018	23443	34.263675999999997	34.326082	55.643616999999999	55.587809	Чкалова	0103000020E61000000100000005000000BB5E9A22C0214140B1A547533DCB4B40BB5E9A22C02141402713B70A62D24B403AE8120EBD2941402713B70A62D24B403AE8120EBD294140B1A547533DCB4B40BB5E9A22C0214140B1A547533DCB4B40
39968	23443	34.263675999999997	34.326082	55.643616999999999	55.587809	Советская	0103000020E61000000100000005000000BB5E9A22C0214140B1A547533DCB4B40BB5E9A22C02141402713B70A62D24B403AE8120EBD2941402713B70A62D24B403AE8120EBD294140B1A547533DCB4B40BB5E9A22C0214140B1A547533DCB4B40
39969	23443	34.263675999999997	34.326082	55.643616999999999	55.587809	Горького	0103000020E61000000100000005000000BB5E9A22C0214140B1A547533DCB4B40BB5E9A22C02141402713B70A62D24B403AE8120EBD2941402713B70A62D24B403AE8120EBD294140B1A547533DCB4B40BB5E9A22C0214140B1A547533DCB4B40
39708	48243	\N	\N	\N	\N	Центральная	\N
40137	20974	31.764562999999999	31.789625999999998	54.602888	54.589368	Центральная	0103000020E610000001000000050000004DBB9866BAC33F408BA71E69704B4B404DBB9866BAC33F404F93196F2B4D4B404012F6ED24CA3F404F93196F2B4D4B404012F6ED24CA3F408BA71E69704B4B404DBB9866BAC33F408BA71E69704B4B40
39943	47767	31.576491999999998	31.594457999999999	54.609603999999997	54.595053999999998	Парковая	0103000020E61000000100000005000000D767CEFA94933F404FADBEBA2A4C4B40D767CEFA94933F4061C1FD80074E4B4077D844662E983F4061C1FD80074E4B4077D844662E983F404FADBEBA2A4C4B40D767CEFA94933F404FADBEBA2A4C4B40
40193	21072	31.221737999999998	31.245623999999999	54.622960999999997	54.611528	Мира	0103000020E61000000100000005000000CB4752D2C3383F404D4BAC8C464E4B40CB4752D2C3383F407BD7A02FBD4F4B40DA1CE736E13E3F407BD7A02FBD4F4B40DA1CE736E13E3F404D4BAC8C464E4B40CB4752D2C3383F404D4BAC8C464E4B40
39563	47589	31.342544	31.414929999999998	54.733317	54.703508999999997	Советская	0103000020E61000000100000005000000E770ADF6B0573F4088B839950C5A4B40E770ADF6B0573F40E84CDA54DD5D4B4018213CDA386A3F40E84CDA54DD5D4B4018213CDA386A3F4088B839950C5A4B40E770ADF6B0573F4088B839950C5A4B40
39958	47589	31.342544	31.414929999999998	54.733317	54.703508999999997	Молодежная	0103000020E61000000100000005000000E770ADF6B0573F4088B839950C5A4B40E770ADF6B0573F40E84CDA54DD5D4B4018213CDA386A3F40E84CDA54DD5D4B4018213CDA386A3F4088B839950C5A4B40E770ADF6B0573F4088B839950C5A4B40
40192	20645	32.489477000000001	32.511502999999998	54.714157	54.698478000000001	Молодежная	0103000020E610000001000000050000007592AD2EA73E4040DD7C23BA67594B407592AD2EA73E4040D09A1F7F695B4B40276728EE78414040D09A1F7F695B4B40276728EE78414040DD7C23BA67594B407592AD2EA73E4040DD7C23BA67594B40
40133	47388	32.409112999999998	32.436304999999997	54.982869000000001	54.968355000000003	Молодежнвя	0103000020E6100000010000000500000029AF95D05D34404084F57F0EF37B4B4029AF95D05D34404049A0C1A6CE7D4B40670A9DD7D837404049A0C1A6CE7D4B40670A9DD7D837404084F57F0EF37B4B4029AF95D05D34404084F57F0EF37B4B40
40135	47420	32.509993999999999	32.532470000000004	54.970995000000002	54.958311999999999	Школьная	0103000020E61000000100000005000000FF93BF7B47414040A3AEB5F7A97A4B40FF93BF7B474140402ECA6C90497C4B40F20C1AFA274440402ECA6C90497C4B40F20C1AFA27444040A3AEB5F7A97A4B40FF93BF7B47414040A3AEB5F7A97A4B40
39957	47346	32.466138000000001	32.481831999999997	54.787810999999998	54.778829000000002	Приозёрная	0103000020E6100000010000000500000020B6F468AA3B404094162EABB0634B4020B6F468AA3B4040EB36A8FDD6644B404815C5ABAC3D4040EB36A8FDD6644B404815C5ABAC3D404094162EABB0634B4020B6F468AA3B404094162EABB0634B40
40190	20431	32.580323	32.601163999999997	54.841858000000002	54.821733000000002	Центральная	0103000020E61000000100000005000000ED0E2906484A4040A185048C2E694B40ED0E2906484A404020F0C000C26B4B402AC423F1F24C404020F0C000C26B4B402AC423F1F24C4040A185048C2E694B40ED0E2906484A4040A185048C2E694B40
40188	20112	32.435102000000001	32.450400000000002	54.949497000000001	54.932068999999998	Зеленая	0103000020E610000001000000050000004C361E6CB1374040C64E78094E774B404C361E6CB13740403753211E89794B40280F0BB5A63940403753211E89794B40280F0BB5A6394040C64E78094E774B404C361E6CB1374040C64E78094E774B40
40266	47315	32.699368	32.723407000000002	54.938177000000003	54.921121999999997	Школьная	0103000020E6100000010000000500000039EFFFE38459404024D06053E7754B4039EFFFE384594040016E162F16784B404759BF99985C4040016E162F16784B404759BF99985C404024D06053E7754B4039EFFFE38459404024D06053E7754B40
40138	20290	32.342387000000002	32.367530000000002	54.716320000000003	54.701314000000004	Школьная	0103000020E61000000100000005000000ACC95356D32B40400D1D3BA8C4594B40ACC95356D32B404041BCAE5FB05B4B40422619390B2F404041BCAE5FB05B4B40422619390B2F40400D1D3BA8C4594B40ACC95356D32B40400D1D3BA8C4594B40
40023	47240	32.379145999999999	32.400345999999999	54.872999	54.859456000000002	Административная	0103000020E6100000010000000500000061342BDB87304040ED2C7AA7026E4B4061342BDB873040406938656EBE6F4B40CE8AA8893E3340406938656EBE6F4B40CE8AA8893E334040ED2C7AA7026E4B4061342BDB87304040ED2C7AA7026E4B40
39613	19927	32.399987000000003	32.479441999999999	54.902237	54.876372000000003	Школьная	0103000020E610000001000000050000009FE925C632334040A8902BF52C704B409FE925C632334040DE1E84807C734B40172AFF5A5E3D4040DE1E84807C734B40172AFF5A5E3D4040A8902BF52C704B409FE925C632334040A8902BF52C704B40
39737	19927	32.399987000000003	32.479441999999999	54.902237	54.876372000000003	Ленина	0103000020E610000001000000050000009FE925C632334040A8902BF52C704B409FE925C632334040DE1E84807C734B40172AFF5A5E3D4040DE1E84807C734B40172AFF5A5E3D4040A8902BF52C704B409FE925C632334040A8902BF52C704B40
75053	47221	32.297083999999998	32.319884000000002	55.030203999999998	55.009543000000001	Центральная	0103000020E610000001000000050000001A1538D906264040EF737CB438814B401A1538D906264040AC1A84B9DD834B40C0417BF5F1284040AC1A84B9DD834B40C0417BF5F1284040EF737CB438814B401A1538D906264040EF737CB438814B40
40187	20040	32.371133	32.394542999999999	54.943344000000003	54.929327000000001	Центральная	0103000020E61000000100000005000000B2BB4049812F40401825E82FF4764B40B2BB4049812F40405D70067FBF784B40D0EE9062803240405D70067FBF784B40D0EE9062803240401825E82FF4764B40B2BB4049812F40401825E82FF4764B40
39540	48278	32.853411000000001	32.866481999999998	53.550114999999998	53.540489999999998	Никольская	0103000020E61000000100000005000000F98557923C6D404053E8BCC62EC54A40F98557923C6D4040FF04172B6AC64A404D49D6E1E86E4040FF04172B6AC64A404D49D6E1E86E404053E8BCC62EC54A40F98557923C6D404053E8BCC62EC54A40
39734	19208	32.734959000000003	32.775391999999997	53.691800000000001	53.654082000000002	Понятовская	0103000020E610000001000000050000005073F222135E40407E737FF5B8D34A405073F222135E4040B8AF03E78CD84A403ECA880B40634040B8AF03E78CD84A403ECA880B406340407E737FF5B8D34A405073F222135E40407E737FF5B8D34A40
39937	19416	32.733387	32.783082	53.770082000000002	53.735258000000002	Ленина	0103000020E61000000100000005000000E1270EA0DF5D4040AA0F24EF1CDE4A40E1270EA0DF5D4040809E060C92E24A400B0BEE073C644040809E060C92E24A400B0BEE073C644040AA0F24EF1CDE4A40E1270EA0DF5D4040AA0F24EF1CDE4A40
39589	45681	33.283946999999998	33.304454999999997	54.665160999999998	54.650520999999998	Викторова	0103000020E610000001000000050000000E66136058A440403C2EAA4544534B400E66136058A440408EC9E2FE23554B40450DA661F8A640408EC9E2FE23554B40450DA661F8A640403C2EAA4544534B400E66136058A440403C2EAA4544534B40
40089	54854	32.457946	32.492145000000001	55.165801000000002	55.145149000000004	Московская	0103000020E61000000100000005000000C1AA7AF99D3A40400806103E94924B40C1AA7AF99D3A4040725298F738954B40E9F17B9BFE3E4040725298F738954B40E9F17B9BFE3E40400806103E94924B40C1AA7AF99D3A40400806103E94924B40
40084	17972	32.474744000000001	32.494633	55.339145000000002	55.320124999999997	Центральная	0103000020E6100000010000000500000072FC5069C43C4040E5D022DBF9A84B4072FC5069C43C40400CCD751A69AB4B40DD425722503F40400CCD751A69AB4B40DD425722503F4040E5D022DBF9A84B4072FC5069C43C4040E5D022DBF9A84B40
39935	46240	32.335918999999997	32.388433999999997	55.521780999999997	55.495699999999999	Б. Советская	0103000020E61000000100000005000000718DCF64FF2A40404850FC1873BF4B40718DCF64FF2A40404B5645B8C9C24B40C5538F34B83140404B5645B8C9C24B40C5538F34B83140404850FC1873BF4B40718DCF64FF2A40404850FC1873BF4B40
75067	46025	32.010548999999997	32.042852000000003	55.136899999999997	55.123928999999997	Центральная	0103000020E61000000100000005000000B4006DAB590140405303CDE7DC8F4B40B4006DAB5901404044696FF085914B40BB48A12C7C05404044696FF085914B40BB48A12C7C0540405303CDE7DC8F4B40B4006DAB590140405303CDE7DC8F4B40
39606	45951	32.402807000000003	32.437069000000001	55.615938999999997	55.572299000000001	Парковая	0103000020E61000000100000005000000C9CC052E8F3340404A44F81741C94B40C9CC052E8F3340405CAAD216D7CE4B40378C82E0F13740405CAAD216D7CE4B40378C82E0F13740404A44F81741C94B40C9CC052E8F3340404A44F81741C94B40
39751	45951	32.402807000000003	32.437069000000001	55.615938999999997	55.572299000000001	 Строителей	0103000020E61000000100000005000000C9CC052E8F3340404A44F81741C94B40C9CC052E8F3340405CAAD216D7CE4B40378C82E0F13740405CAAD216D7CE4B40378C82E0F13740404A44F81741C94B40C9CC052E8F3340404A44F81741C94B40
40253	46078	32.357064999999999	32.376612000000002	55.284292000000001	55.272435999999999	Центральная	0103000020E61000000100000005000000EBC5504EB42D40406420CF2EDFA24B40EBC5504EB42D4040D94125AE63A44B40FDA36FD234304040D94125AE63A44B40FDA36FD2343040406420CF2EDFA24B40EBC5504EB42D40406420CF2EDFA24B40
40171	17519	32.384014000000001	32.405394000000001	55.228634	55.211208999999997	Центральная	0103000020E61000000100000005000000639AE95E2731404078CF81E5089B4B40639AE95E27314040786000E1439D4B4050FF59F3E3334040786000E1439D4B4050FF59F3E333404078CF81E5089B4B40639AE95E2731404078CF81E5089B4B40
40128	17468	32.231462999999998	32.253453	55.255184999999997	55.242063000000002	Центральная	0103000020E61000000100000005000000F59D5F94A01D40402C499EEBFB9E4B40F59D5F94A01D404002B7EEE6A9A04B405B09DD257120404002B7EEE6A9A04B405B09DD25712040402C499EEBFB9E4B40F59D5F94A01D40402C499EEBFB9E4B40
39560	16976	32.377214000000002	32.429011000000003	55.208348000000001	55.182479999999998	Бугаева	0103000020E61000000100000005000000F3CB608C48304040481630815B974B40F3CB608C48304040F017B325AB9A4B40E84F1BD5E9364040F017B325AB9A4B40E84F1BD5E9364040481630815B974B40F3CB608C48304040481630815B974B40
75061	54944	32.428131	32.440500999999998	55.620981999999998	55.606791999999999	Школьная	0103000020E61000000100000005000000AFB321FFCC364040BABC395CABCD4B40AFB321FFCC364040CCB392567CCF4B407A6D365662384040CCB392567CCF4B407A6D365662384040BABC395CABCD4B40AFB321FFCC364040BABC395CABCD4B40
40264	54890	32.510641	32.537914000000001	55.587769000000002	55.578065000000002	Школьная	0103000020E61000000100000005000000957F2DAF5C4140402BFBAE08FEC94B40957F2DAF5C414040234DBC033CCB4B40C007AF5DDA444040234DBC033CCB4B40C007AF5DDA4440402BFBAE08FEC94B40957F2DAF5C4140402BFBAE08FEC94B40
40255	17581	32.206229	32.220233999999998	55.663953999999997	55.645634000000001	Центральная	0103000020E610000001000000050000004F3E3DB6651A4040C4978922A4D24B404F3E3DB6651A40403106D671FCD44B40CFBBB1A0301C40403106D671FCD44B40CFBBB1A0301C4040C4978922A4D24B404F3E3DB6651A4040C4978922A4D24B40
40124	17359	32.308475000000001	32.324536999999999	55.359318000000002	55.349066000000001	Лесная	0103000020E610000001000000050000001A51DA1B7C274040A112D731AEAC4B401A51DA1B7C2740409C6ED921FEAD4B40C5ABAC6D8A2940409C6ED921FEAD4B40C5ABAC6D8A294040A112D731AEAC4B401A51DA1B7C274040A112D731AEAC4B40
40231	45984	32.378867	32.400517000000001	55.170918	55.158745000000003	Солнечная	0103000020E610000001000000050000004E44BFB67E304040A7B393C151944B404E44BFB67E3040401C261AA4E0954B40FB3E1C24443340401C261AA4E0954B40FB3E1C2444334040A7B393C151944B404E44BFB67E304040A7B393C151944B40
39656	1355	33.256799999999998	33.376553999999999	54.936776000000002	54.887393000000003	Лермонтова	0103000020E6100000010000000500000070CE88D2DEA0404084D9041896714B4070CE88D2DEA04040BFD6A546E8774B40C896E5EB32B04040BFD6A546E8774B40C896E5EB32B0404084D9041896714B4070CE88D2DEA0404084D9041896714B40
39953	1355	33.256799999999998	33.376553999999999	54.936776000000002	54.887393000000003	Карла Маркса 	0103000020E6100000010000000500000070CE88D2DEA0404084D9041896714B4070CE88D2DEA04040BFD6A546E8774B40C896E5EB32B04040BFD6A546E8774B40C896E5EB32B0404084D9041896714B4070CE88D2DEA0404084D9041896714B40
39602	16780	33.329545000000003	33.379761000000002	54.993974999999999	54.971192000000002	Советская	0103000020E61000000100000005000000B9C7D2872EAA40408411FB04507C4B40B9C7D2872EAA40405305A3923A7F4B40ECA529029CB040405305A3923A7F4B40ECA529029CB040408411FB04507C4B40B9C7D2872EAA40408411FB04507C4B40
39733	16780	33.329545000000003	33.379761000000002	54.993974999999999	54.971192000000002	Молодежная	0103000020E61000000100000005000000B9C7D2872EAA40408411FB04507C4B40B9C7D2872EAA40405305A3923A7F4B40ECA529029CB040405305A3923A7F4B40ECA529029CB040408411FB04507C4B40B9C7D2872EAA40408411FB04507C4B40
39555	16780	33.329545000000003	33.379761000000002	54.993974999999999	54.971192000000002	Комсомольская	0103000020E61000000100000005000000B9C7D2872EAA40408411FB04507C4B40B9C7D2872EAA40405305A3923A7F4B40ECA529029CB040405305A3923A7F4B40ECA529029CB040408411FB04507C4B40B9C7D2872EAA40408411FB04507C4B40
40223	14877	31.806721	31.829654999999999	55.330081	55.320529000000001	Боровая	0103000020E6100000010000000500000015FF774485CE3F40B535221807A94B4015FF774485CE3F40F7031E1840AA4B407FF6234564D43F40F7031E1840AA4B407FF6234564D43F40B535221807A94B4015FF774485CE3F40B535221807A94B40
40306	54899	31.171396999999999	32.147298999999997	55.787385999999998	55.035699000000001	Дорожная	0103000020E61000000100000005000000ECA17DACE02B3F40FDBFEAC891844B40ECA17DACE02B3F4004AA7F10C9E44B40E3DD91B1DA12404004AA7F10C9E44B40E3DD91B1DA124040FDBFEAC891844B40ECA17DACE02B3F40FDBFEAC891844B40
75095	46340	31.489041	31.496632000000002	55.407034000000003	55.402909000000001	Школьная	0103000020E6100000010000000500000034677DCA317D3F40CD21A98592B34B4034677DCA317D3F40172EABB019B44B40A7255646237F3F40172EABB019B44B40A7255646237F3F40CD21A98592B34B4034677DCA317D3F40CD21A98592B34B40
40059	14821	31.480982999999998	31.496596	55.248016	55.234189000000001	Центральная	0103000020E6100000010000000500000095EEAEB3217B3F409E0AB8E7F99D4B4095EEAEB3217B3F403F7100FDBE9F4B400D535BEA207F3F403F7100FDBE9F4B400D535BEA207F3F409E0AB8E7F99D4B4095EEAEB3217B3F409E0AB8E7F99D4B40
39526	14926	31.823969000000002	31.909192000000001	55.514890999999999	55.486891999999997	Советская	0103000020E61000000100000005000000F7EAE3A1EFD23F408E57207A52BE4B40F7EAE3A1EFD23F409B00C3F2E7C14B40EBC891CEC0E83F409B00C3F2E7C14B40EBC891CEC0E83F408E57207A52BE4B40F7EAE3A1EFD23F408E57207A52BE4B40
40056	14926	31.823969000000002	31.909192000000001	55.514890999999999	55.486891999999997	Курортная	0103000020E61000000100000005000000F7EAE3A1EFD23F408E57207A52BE4B40F7EAE3A1EFD23F409B00C3F2E7C14B40EBC891CEC0E83F409B00C3F2E7C14B40EBC891CEC0E83F408E57207A52BE4B40F7EAE3A1EFD23F408E57207A52BE4B40
40063	14926	31.823969000000002	31.909192000000001	55.514890999999999	55.486891999999997	1 Мая	0103000020E61000000100000005000000F7EAE3A1EFD23F408E57207A52BE4B40F7EAE3A1EFD23F409B00C3F2E7C14B40EBC891CEC0E83F409B00C3F2E7C14B40EBC891CEC0E83F408E57207A52BE4B40F7EAE3A1EFD23F408E57207A52BE4B40
40168	49534	31.883177	31.897387999999999	55.687710000000003	55.672504000000004	Лесная	0103000020E6100000010000000500000053944BE317E23F40F0366F9C14D64B4053944BE317E23F40EB909BE106D84B40A6D24F38BBE53F40EB909BE106D84B40A6D24F38BBE53F40F0366F9C14D64B4053944BE317E23F40F0366F9C14D64B40
40050	15092	31.914518999999999	31.936941000000001	55.372171000000002	55.365540000000003	Ямская	0103000020E610000001000000050000001492CCEA1DEA3F409FB0C403CAAE4B401492CCEA1DEA3F4083C2A04CA3AF4B401348895DDBEF3F4083C2A04CA3AF4B401348895DDBEF3F409FB0C403CAAE4B401492CCEA1DEA3F409FB0C403CAAE4B40
40164	15290	31.385940999999999	31.405173999999999	55.374288	55.360894000000002	Центральная	0103000020E610000001000000050000007F2F8507CD623F404CA94BC631AE4B407F2F8507CD623F4083A44FABE8AF4B408330B77BB9673F4083A44FABE8AF4B408330B77BB9673F404CA94BC631AE4B407F2F8507CD623F404CA94BC631AE4B40
40222	14722	31.267714000000002	31.303718	55.114913999999999	55.098156000000003	Егорова	0103000020E610000001000000050000006DAE9AE788443F40FEF33460908C4B406DAE9AE788443F4020ED7F80B58E4B40DF347D76C04D3F4020ED7F80B58E4B40DF347D76C04D3F40FEF33460908C4B406DAE9AE788443F40FEF33460908C4B40
40608	54941	31.344179	31.368342999999999	55.189371999999999	55.177970999999999	Парковая	0103000020E6100000010000000500000051F86C1D1C583F407651F4C0C7964B4051F86C1D1C583F40996379573D984B40E5B512BA4B5E3F40996379573D984B40E5B512BA4B5E3F407651F4C0C7964B4051F86C1D1C583F407651F4C0C7964B40
40297	54898	31.518380000000001	31.547063000000001	55.349736999999998	55.334643999999997	Парковая	0103000020E6100000010000000500000086E63A8DB4843F40BCE6559DD5AA4B4086E63A8DB4843F40BF99982EC4AC4B4006DA1D520C8C3F40BF99982EC4AC4B4006DA1D520C8C3F40BCE6559DD5AA4B4086E63A8DB4843F40BCE6559DD5AA4B40
40105	14580	31.297152000000001	31.316780000000001	55.339514000000001	55.323106000000003	Верхняя	0103000020E61000000100000005000000E5F04927124C3F40199293895BA94B40E5F04927124C3F405F44DB3175AB4B40E2067C7E18513F405F44DB3175AB4B40E2067C7E18513F40199293895BA94B40E5F04927124C3F40199293895BA94B40
40296	54897	31.643802999999998	31.684937000000001	55.515946	55.505719999999997	Центральная	0103000020E610000001000000050000001211FE45D0A43F407077D66EBBC04B401211FE45D0A43F404240BE840AC24B4003D2FE0758AF3F404240BE840AC24B4003D2FE0758AF3F407077D66EBBC04B401211FE45D0A43F407077D66EBBC04B40
39668	49147	32.856816000000002	32.893566	54.654766000000002	54.622044000000002	Ленина	0103000020E6100000010000000500000043588D25AC6D4040265646239F4F4B4043588D25AC6D404031444E5FCF534B40A568E55E6072404031444E5FCF534B40A568E55E60724040265646239F4F4B4043588D25AC6D4040265646239F4F4B40
75059	49322	35.027495999999999	35.059286999999998	55.370865999999999	55.354328000000002	Центральная	0103000020E61000000100000005000000AA622AFD848341404F07B29E5AAD4B40AA622AFD8483414063997E8978AF4B40FA0967B79687414063997E8978AF4B40FA0967B7968741404F07B29E5AAD4B40AA622AFD848341404F07B29E5AAD4B40
40022	12155	34.967021000000003	35.023319000000001	55.570287999999998	55.531641999999998	микрорайон Лесной	0103000020E61000000100000005000000CAC51858C77B41400B9755D80CC44B40CAC51858C77B41408FA67A32FFC84B400E30F31DFC8241408FA67A32FFC84B400E30F31DFC8241400B9755D80CC44B40CAC51858C77B41400B9755D80CC44B40
40248	12060	34.514755000000001	34.534680000000002	55.487167999999997	55.473939000000001	Новоселов	0103000020E61000000100000005000000EB39E97DE341414044A67C08AABC4B40EB39E97DE341414030D461855BBE4B40A3E9EC647044414030D461855BBE4B40A3E9EC647044414044A67C08AABC4B40EB39E97DE341414044A67C08AABC4B40
40051	48292	33.984273000000002	34.001367999999999	55.198431999999997	55.185482	Окружная	0103000020E61000000100000005000000FCAA5CA8FCFD404093FFC9DFBD974B40FCAA5CA8FCFD40406C3D433866994B4066A19DD32C0041406C3D433866994B4066A19DD32C00414093FFC9DFBD974B40FCAA5CA8FCFD404093FFC9DFBD974B40
39942	48325	34.265635000000003	34.296104999999997	55.183759999999999	55.162205999999998	Школьная	0103000020E6100000010000000500000024D6E25300224140849B8C2AC3944B4024D6E253002241400F289B7285974B404E97C5C4E62541400F289B7285974B404E97C5C4E6254140849B8C2AC3944B4024D6E25300224140849B8C2AC3944B40
40111	11993	33.876807999999997	33.901457999999998	55.412370000000003	55.395681000000003	Центральная	0103000020E61000000100000005000000826F9A3E3BF040400553CDACA5B24B40826F9A3E3BF04040FFEC478AC8B44B40D95BCAF962F34040FFEC478AC8B44B40D95BCAF962F340400553CDACA5B24B40826F9A3E3BF040400553CDACA5B24B40
39977	48028	34.658431999999998	34.679550999999996	55.352905	55.338689000000002	Успенская	0103000020E61000000100000005000000E751F17F47544140EA4141295AAB4B40E751F17F4754414025CCB4FD2BAD4B40677BF486FB56414025CCB4FD2BAD4B40677BF486FB564140EA4141295AAB4B40E751F17F47544140EA4141295AAB4B40
39681	48405	34.635030999999998	34.661855000000003	55.430871000000003	55.410203000000003	Почтовая	0103000020E610000001000000050000001C7920B2485141404DDC2A8881B44B401C7920B248514140BDE5EAC726B74B40D8D825AAB7544140BDE5EAC726B74B40D8D825AAB75441404DDC2A8881B44B401C7920B2485141404DDC2A8881B44B40
40027	11777	33.947775	34.012084999999999	55.155628	55.037520999999998	Советская	0103000020E61000000100000005000000B37BF2B050F94040E4F4F57CCD844B40B37BF2B050F94040C32B499EEB934B40D6E253008C014140C32B499EEB934B40D6E253008C014140E4F4F57CCD844B40B37BF2B050F94040E4F4F57CCD844B40
40010	11777	33.947775	34.012084999999999	55.155628	55.037520999999998	Ленина	0103000020E61000000100000005000000B37BF2B050F94040E4F4F57CCD844B40B37BF2B050F94040C32B499EEB934B40D6E253008C014140C32B499EEB934B40D6E253008C014140E4F4F57CCD844B40B37BF2B050F94040E4F4F57CCD844B40
40252	11661	34.040984000000002	34.060243999999997	55.087527000000001	55.071226000000003	Гагарина	0103000020E6100000010000000500000063D4B5F63E054140FD4FFEEE1D894B4063D4B5F63E0541402D42B115348B4B40DEE34C13B60741402D42B115348B4B40DEE34C13B6074140FD4FFEEE1D894B4063D4B5F63E054140FD4FFEEE1D894B40
40003	11568	34.129693000000003	34.158321999999998	55.223334999999999	55.206992	Школьная	0103000020E6100000010000000500000094C2BCC7991041404E44BFB67E9A4B4094C2BCC799104140AD86C43D969C4B40601E32E543144140AD86C43D969C4B40601E32E5431441404E44BFB67E9A4B4094C2BCC7991041404E44BFB67E9A4B40
40049	54846	\N	\N	\N	\N	Рабочая	\N
40110	11323	33.858409999999999	33.883966999999998	54.959563000000003	54.948928000000002	Молодёжная	0103000020E610000001000000050000009947FE60E0ED40401D21037976794B409947FE60E0ED4040D0B9DBF5D27A4B4022DFA5D425F14040D0B9DBF5D27A4B4022DFA5D425F140401D21037976794B409947FE60E0ED40401D21037976794B40
39945	11341	34.305456999999997	34.341541999999997	55.406931999999998	55.391381000000003	Ленина	0103000020E61000000100000005000000C9AA0837192741404DA3C9C518B24B40C9AA08371927414012D9075916B44B40EF1AF4A5B72B414012D9075916B44B40EF1AF4A5B72B41404DA3C9C518B24B40C9AA0837192741404DA3C9C518B24B40
39815	11236	34.284498999999997	34.318662000000003	55.113019000000001	55.096666999999997	Парковая	0103000020E61000000100000005000000525F96766A2441401CCD91955F8C4B40525F96766A244140CF691668778E4B402E3D9AEAC9284140CF691668778E4B402E3D9AEAC92841401CCD91955F8C4B40525F96766A2441401CCD91955F8C4B40
40201	54878	34.637824999999999	34.672994000000003	55.186725000000003	55.169657999999998	Школьная	0103000020E610000001000000050000001DC9E53FA45141409CC0745AB7954B401DC9E53FA45141403D2CD49AE6974B40BE33DAAA245641403D2CD49AE6974B40BE33DAAA245641409CC0745AB7954B401DC9E53FA45141409CC0745AB7954B40
39549	10964	34.350076000000001	34.388075000000001	55.177067000000001	55.154783999999999	Авиационная	0103000020E61000000100000005000000A88E554ACF2C4140D7F84CF6CF934B40A88E554ACF2C4140B519A721AA964B4096B20C71AC314140B519A721AA964B4096B20C71AC314140D7F84CF6CF934B40A88E554ACF2C4140D7F84CF6CF934B40
39661	10964	34.350076000000001	34.388075000000001	55.177067000000001	55.154783999999999	50 лет Победы	0103000020E61000000100000005000000A88E554ACF2C4140D7F84CF6CF934B40A88E554ACF2C4140B519A721AA964B4096B20C71AC314140B519A721AA964B4096B20C71AC314140D7F84CF6CF934B40A88E554ACF2C4140D7F84CF6CF934B40
39714	1259	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Песочная	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39543	1259	34.249733999999997	34.338856	55.244737000000001	55.132066999999999	Кашена	0103000020E610000001000000050000008159A148F71F4140BFF04A92E7904B408159A148F71F4140828FC18A539F4B40D50627A25F2B4140828FC18A539F4B40D50627A25F2B4140BFF04A92E7904B408159A148F71F4140BFF04A92E7904B40
39548	47987	34.242341000000003	34.270997999999999	55.244079999999997	55.228592999999996	Ленина	0103000020E610000001000000050000006FBDA607051F4140198C1189429D4B406FBDA607051F4140C8CD70033E9F4B4005A4FD0FB0224140C8CD70033E9F4B4005A4FD0FB0224140198C1189429D4B406FBDA607051F4140198C1189429D4B40
39702	9728	31.135608000000001	31.230784	55.627763000000002	55.590353	Володарского	0103000020E610000001000000050000007313B534B7223F40390CE6AF90CB4B407313B534B7223F40C651B9895AD04B40A87004A9143B3F40C651B9895AD04B40A87004A9143B3F40390CE6AF90CB4B407313B534B7223F40390CE6AF90CB4B40
38278	54631	41.675010999999998	41.770519999999998	54.042203999999998	54.016188999999997	Цюрупы	0103000020E610000001000000050000005AB8ACC266D6444008C72C7B12024B405AB8ACC266D6444054E1CFF066054B40FB743C66A0E2444054E1CFF066054B40FB743C66A0E2444008C72C7B12024B405AB8ACC266D6444008C72C7B12024B40
38533	54626	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	Набережная	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
38260	54626	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	Ломоносова	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
38208	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	мкр.Октябрьский	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38788	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	мкр.Комсомольский	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38544	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	мкр.Коготково	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38273	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	мкр.Заречный	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38527	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Пушкина	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38268	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Поташная	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38053	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Площадь Ленина	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38279	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Орджоникидзе	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38512	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Октябрьская	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38076	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Мира	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38046	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Ленина	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38083	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Карла Маркса	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38221	7320	39.532457000000001	39.602435999999997	53.850284000000002	53.800863	Автозаводской микрорайон	0103000020E610000001000000050000005DC30C8D27C44340C9C9C4AD82E64A405DC30C8D27C44340F2272A1BD6EC4A406EF7729F1CCD4340F2272A1BD6EC4A406EF7729F1CCD4340C9C9C4AD82E64A405DC30C8D27C44340C9C9C4AD82E64A40
38131	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	микрорайон Южный	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38267	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	микрорайон Северный	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38246	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Типанова	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
37985	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Свободы проспект	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38035	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Пушкина	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38210	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Островитянова	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38104	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Ново-Елатомская	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38206	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Ленина	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38288	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Киевская	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
38105	4031	41.875731000000002	41.974077999999999	54.374149000000003	54.323681000000001	Вокзальная	0103000020E61000000100000005000000F48B12F417F0444015AB06616E294B40F48B12F417F04440626A4B1DE42F4B4065E08096AEFC4440626A4B1DE42F4B4065E08096AEFC444015AB06616E294B40F48B12F417F0444015AB06616E294B40
15395	1114	39.785279000000003	39.828991000000002	54.614035999999999	54.599356999999998	улица Новоселов	0103000020E61000000100000005000000289EB30584E4434078D0ECBAB74C4B40289EB30584E4434088484DBB984E4B40D4D688601CEA434088484DBB984E4B40D4D688601CEA434078D0ECBAB74C4B40289EB30584E4434078D0ECBAB74C4B40
6827	1114	39.756523999999999	39.761077999999998	54.631008999999999	54.628428999999997	проезд Щедрина	0103000020E61000000100000005000000CE5147C7D5E04340D26D895C70504B40CE5147C7D5E04340A73D25E7C4504B4040DAFF006BE14340A73D25E7C4504B4040DAFF006BE14340D26D895C70504B40CE5147C7D5E04340D26D895C70504B40
15923	1114	39.663179999999997	39.67042	54.659562999999999	54.646427000000003	проезд Шабулина	0103000020E610000001000000050000003EAE0D15E3D443402E20B41EBE524B403EAE0D15E3D443406953758F6C544B40CB4A9352D0D543406953758F6C544B40CB4A9352D0D543402E20B41EBE524B403EAE0D15E3D443402E20B41EBE524B40
5794	1114	39.706012000000001	39.706155000000003	54.605834000000002	54.602663	проезд Гоголя	0103000020E61000000100000005000000B24AE9995EDA43402FC1A90F244D4B40B24AE9995EDA43400667F0F78B4D4B4015747B4963DA43400667F0F78B4D4B4015747B4963DA43402FC1A90F244D4B40B24AE9995EDA43402FC1A90F244D4B40
38334	1114	39.639446999999997	39.647773999999998	54.649239999999999	54.636386999999999	Юбилейная 	0103000020E610000001000000050000003D433866D9D14340BE4C142175514B403D433866D9D14340A5A0DB4B1A534B407C992842EAD24340A5A0DB4B1A534B407C992842EAD24340BE4C142175514B403D433866D9D14340BE4C142175514B40
38439	1114	39.757888999999999	39.779566000000003	54.621481000000003	54.618009000000001	Электрозаводская	0103000020E61000000100000005000000C37FBA8102E143401CD13DEB1A4F4B40C37FBA8102E14340EE0A7DB08C4F4B406A8995D1C8E34340EE0A7DB08C4F4B406A8995D1C8E343401CD13DEB1A4F4B40C37FBA8102E143401CD13DEB1A4F4B40
38369	1114	39.697316000000001	39.711761000000003	54.597067000000003	54.595267999999997	Щорса	0103000020E61000000100000005000000207D93A641D943407B2DE8BD314C4B40207D93A641D94340AB4203B16C4C4B40BDC804FC1ADB4340AB4203B16C4C4B40BDC804FC1ADB43407B2DE8BD314C4B40207D93A641D943407B2DE8BD314C4B40
38367	1114	39.711761000000003	39.712857	54.609614999999998	54.595267999999997	Черновицкая	0103000020E61000000100000005000000BDC804FC1ADB43407B2DE8BD314C4B40BDC804FC1ADB4340551344DD074E4B40C2DCEEE53EDB4340551344DD074E4B40C2DCEEE53EDB43407B2DE8BD314C4B40BDC804FC1ADB43407B2DE8BD314C4B40
38347	1114	39.754187999999999	39.764285000000001	54.603931000000003	54.602429000000001	Трудовая	0103000020E6100000010000000500000090847D3B89E04340BC94BA641C4D4B4090847D3B89E0434032056B9C4D4D4B4064E94317D4E1434032056B9C4D4D4B4064E94317D4E14340BC94BA641C4D4B4090847D3B89E04340BC94BA641C4D4B40
38364	1114	39.719441000000003	39.725523000000003	54.605521000000003	54.602893000000002	Толстого	0103000020E61000000100000005000000663387A416DC434061FE0A992B4D4B40663387A416DC434047054EB6814D4B4077BF0AF0DDDC434047054EB6814D4B4077BF0AF0DDDC434061FE0A992B4D4B40663387A416DC434061FE0A992B4D4B40
38447	1114	39.780033000000003	39.791468000000002	54.619370000000004	54.609901999999998	Тимуровцев	0103000020E610000001000000050000008066101FD8E34340EBE1CB44114E4B408066101FD8E34340D00F2384474F4B404FEACBD24EE54340D00F2384474F4B404FEACBD24EE54340EBE1CB44114E4B408066101FD8E34340EBE1CB44114E4B40
38418	1114	39.795321999999999	39.809893000000002	54.616216000000001	54.605052000000001	Тимакова	0103000020E6100000010000000500000008E57D1CCDE5434090300C58724D4B4008E57D1CCDE54340CFA2772AE04E4B403221E692AAE74340CFA2772AE04E4B403221E692AAE7434090300C58724D4B4008E57D1CCDE5434090300C58724D4B40
38445	1114	39.698321999999997	39.714976999999998	54.614671999999999	54.603909999999999	Стройкова	0103000020E61000000100000005000000E509849D62D943401ADD41EC4C4D4B40E509849D62D943402AE27492AD4E4B403332C85D84DB43402AE27492AD4E4B403332C85D84DB43401ADD41EC4C4D4B40E509849D62D943401ADD41EC4C4D4B40
38362	1114	39.722873	39.737453000000002	54.638617000000004	54.637053999999999	Солнечная	0103000020E61000000100000005000000A9143B1A87DC43409BE447FC8A514B40A9143B1A87DC4340B7D5AC33BE514B4026AB22DC64DE4340B7D5AC33BE514B4026AB22DC64DE43409BE447FC8A514B40A9143B1A87DC43409BE447FC8A514B40
38436	1114	39.788288000000001	39.797046999999999	54.618780000000001	54.605677999999997	Советской Армии	0103000020E6100000010000000500000025EA059FE6E443400EF450DB864D4B4025EA059FE6E443409EB5DB2E344F4B40FD2FD7A205E643409EB5DB2E344F4B40FD2FD7A205E643400EF450DB864D4B4025EA059FE6E443400EF450DB864D4B40
38417	1114	39.788288000000001	39.797046999999999	54.618780000000001	54.605677999999997	Советской Армии	0103000020E6100000010000000500000025EA059FE6E443400EF450DB864D4B4025EA059FE6E443409EB5DB2E344F4B40FD2FD7A205E643409EB5DB2E344F4B40FD2FD7A205E643400EF450DB864D4B4025EA059FE6E443400EF450DB864D4B40
38302	1114	39.743085000000001	39.743597000000001	54.633187	54.632989000000002	Соборная площадь	0103000020E61000000100000005000000F792C6681DDF434027DD96C805514B40F792C6681DDF43404DA088450C514B40AD33BE2F2EDF43404DA088450C514B40AD33BE2F2EDF434027DD96C805514B40F792C6681DDF434027DD96C805514B40
38178	1114	39.716665999999996	39.740085000000001	54.633937000000003	54.631560999999998	Семинарская	0103000020E61000000100000005000000DB1324B6BBDB4340EB36A8FDD6504B40DB1324B6BBDB4340B85CFDD824514B404DA1F31ABBDE4340B85CFDD824514B404DA1F31ABBDE4340EB36A8FDD6504B40DB1324B6BBDB4340EB36A8FDD6504B40
38177	1114	39.716665999999996	39.740085000000001	54.633937000000003	54.631560999999998	Семинарская	0103000020E61000000100000005000000DB1324B6BBDB4340EB36A8FDD6504B40DB1324B6BBDB4340B85CFDD824514B404DA1F31ABBDE4340B85CFDD824514B404DA1F31ABBDE4340EB36A8FDD6504B40DB1324B6BBDB4340EB36A8FDD6504B40
38319	1114	39.727733000000001	39.734695000000002	54.618071	54.613039999999998	Семашко	0103000020E61000000100000005000000289CDD5A26DD4340E6913F18784E4B40289CDD5A26DD434092CD55F31C4F4B4072C45A7C0ADE434092CD55F31C4F4B4072C45A7C0ADE4340E6913F18784E4B40289CDD5A26DD4340E6913F18784E4B40
38402	1114	39.624777000000002	39.629519999999999	54.690345000000001	54.686597999999996	Сельских Строителей	0103000020E61000000100000005000000812557B1F8CF4340DFBF7971E2574B40812557B1F8CF434083FA96395D584B40C616821C94D0434083FA96395D584B40C616821C94D04340DFBF7971E2574B40812557B1F8CF4340DFBF7971E2574B40
38384	1114	39.791397000000003	39.796768	54.585163000000001	54.582622000000001	Связи	0103000020E610000001000000050000008693347F4CE543400EF7915B934A4B408693347F4CE5434025EA059FE64A4B40EA3F6B7EFCE5434025EA059FE64A4B40EA3F6B7EFCE543400EF7915B934A4B408693347F4CE543400EF7915B934A4B40
38379	1114	39.791397000000003	39.796768	54.585163000000001	54.582622000000001	Связи	0103000020E610000001000000050000008693347F4CE543400EF7915B934A4B408693347F4CE5434025EA059FE64A4B40EA3F6B7EFCE5434025EA059FE64A4B40EA3F6B7EFCE543400EF7915B934A4B408693347F4CE543400EF7915B934A4B40
38443	1114	39.739240000000002	39.764159999999997	54.635312999999996	54.619427000000002	Свободы	0103000020E6100000010000000500000091F2936A9FDE434034A14962494F4B4091F2936A9FDE4340A0DCB6EF51514B40A774B0FECFE14340A0DCB6EF51514B40A774B0FECFE1434034A14962494F4B4091F2936A9FDE434034A14962494F4B40
38304	1114	39.780186	39.780634999999997	54.537970000000001	54.533017000000001	Предзаводская	0103000020E6100000010000000500000006668522DDE34340249BABE639444B4006668522DDE34340541D7233DC444B40758E01D9EBE34340541D7233DC444B40758E01D9EBE34340249BABE639444B4006668522DDE34340249BABE639444B40
38372	1114	39.716594000000001	39.727561999999999	54.610413000000001	54.603540000000002	Полетаева	0103000020E610000001000000050000004241295AB9DB4340F7E978CC404D4B404241295AB9DB4340D1066003224E4B40FBE769C020DD4340D1066003224E4B40FBE769C020DD4340F7E978CC404D4B404241295AB9DB4340F7E978CC404D4B40
38406	1114	39.795707999999998	39.797953999999997	54.597636000000001	54.594099	Полевая	0103000020E6100000010000000500000031957EC2D9E543400CCB9F6F0B4C4B4031957EC2D9E54340C57421567F4C4B402FDB4E5B23E64340C57421567F4C4B402FDB4E5B23E643400CCB9F6F0B4C4B4031957EC2D9E543400CCB9F6F0B4C4B40
6012	1114	39.704745000000003	39.735872000000001	54.630961999999997	54.628928999999999	Первомайский проспект	0103000020E6100000010000000500000080828B1535DA4340C440D7BE80504B4080828B1535DA43406682E15CC3504B406405BF0D31DE43406682E15CC3504B406405BF0D31DE4340C440D7BE80504B4080828B1535DA4340C440D7BE80504B40
38428	1114	39.688961999999997	39.725073999999999	54.617868000000001	54.605521000000003	Островского	0103000020E61000000100000005000000E71725E82FD8434047054EB6814D4B40E71725E82FD843405A9F724C164F4B4007978E39CFDC43405A9F724C164F4B4007978E39CFDC434047054EB6814D4B40E71725E82FD8434047054EB6814D4B40
38438	1114	39.655355999999998	39.684479000000003	54.614708999999998	54.600875000000002	Октябрьский Городок	0103000020E61000000100000005000000629E95B4E2D34340F4FDD478E94C4B40629E95B4E2D3434047C7D5C8AE4E4B403FE603029DD7434047C7D5C8AE4E4B403FE603029DD74340F4FDD478E94C4B40629E95B4E2D34340F4FDD478E94C4B40
16177	1114	39.637982000000001	39.663018000000001	54.665317000000002	54.648453000000003	Октябрьская улица	0103000020E61000000100000005000000E5B7E864A9D143401EFF058200534B40E5B7E864A9D14340863C821B29554B40655419C6DDD44340863C821B29554B40655419C6DDD443401EFF058200534B40E5B7E864A9D143401EFF058200534B40
38401	1114	39.637982000000001	39.669756	54.665317000000002	54.646197000000001	Октябрьская 	0103000020E61000000100000005000000E5B7E864A9D14340FCE25295B6524B40E5B7E864A9D14340863C821B29554B405F268A90BAD54340863C821B29554B405F268A90BAD54340FCE25295B6524B40E5B7E864A9D14340FCE25295B6524B40
38441	1114	39.637982000000001	39.669756	54.665317000000002	54.646197000000001	Октябрьская	0103000020E61000000100000005000000E5B7E864A9D14340FCE25295B6524B40E5B7E864A9D14340863C821B29554B405F268A90BAD54340863C821B29554B405F268A90BAD54340FCE25295B6524B40E5B7E864A9D14340FCE25295B6524B40
38424	1114	39.785279000000003	39.828991000000002	54.614035999999999	54.599356999999998	Новоселов	0103000020E61000000100000005000000289EB30584E4434078D0ECBAB74C4B40289EB30584E4434088484DBB984E4B40D4D688601CEA434088484DBB984E4B40D4D688601CEA434078D0ECBAB74C4B40289EB30584E4434078D0ECBAB74C4B40
38426	1114	39.785279000000003	39.828991000000002	54.614035999999999	54.599356999999998	Новоселов	0103000020E61000000100000005000000289EB30584E4434078D0ECBAB74C4B40289EB30584E4434088484DBB984E4B40D4D688601CEA434088484DBB984E4B40D4D688601CEA434078D0ECBAB74C4B40289EB30584E4434078D0ECBAB74C4B40
38348	1114	39.639662000000001	39.654753999999997	54.638658	54.632576999999998	Новаторов	0103000020E610000001000000050000003A3FC571E0D14340D4997B48F8504B403A3FC571E0D1434015AA9B8BBF514B406C76A4FACED3434015AA9B8BBF514B406C76A4FACED34340D4997B48F8504B403A3FC571E0D14340D4997B48F8504B40
38349	1114	39.744945000000001	39.749822999999999	54.629966000000003	54.628684	Николодворянская 	0103000020E61000000100000005000000CC28965B5ADF43405DC2A1B778504B40CC28965B5ADF4340C5CBD3B9A2504B40F1643733FADF4340C5CBD3B9A2504B40F1643733FADF43405DC2A1B778504B40CC28965B5ADF43405DC2A1B778504B40
38394	1114	39.701932999999997	39.706712000000003	54.598548000000001	54.589702000000003	Нахимова	0103000020E61000000100000005000000D87DC7F0D8D943406231EA5A7B4B4B40D87DC7F0D8D94340098B8A389D4C4B406BD8EF8975DA4340098B8A389D4C4B406BD8EF8975DA43406231EA5A7B4B4B40D87DC7F0D8D943406231EA5A7B4B4B40
6347	1114	39.597630000000002	39.704790000000003	54.666753999999997	54.630805000000002	Московское шоссе	0103000020E61000000100000005000000E38DCC237FCC43409F93DE37BE504B40E38DCC237FCC4340143DF03158554B402046088F36DA4340143DF03158554B402046088F36DA43409F93DE37BE504B40E38DCC237FCC43409F93DE37BE504B40
15472	1114	39.659056999999997	39.703128	54.631456999999997	54.618060999999997	Михайловское шоссе	0103000020E610000001000000050000009599D2FA5BD443406EF7729F1C4F4B409599D2FA5BD4434046EA3D95D3504B4071732A1900DA434046EA3D95D3504B4071732A1900DA43406EF7729F1C4F4B409599D2FA5BD443406EF7729F1C4F4B40
38398	1114	39.755985000000003	39.761698000000003	54.639284000000004	54.635765999999997	Лесопарковая	0103000020E610000001000000050000001FA2D11DC4E0434051F4C0C760514B401FA2D11DC4E04340946DE00ED4514B40DDB6EF517FE14340946DE00ED4514B40DDB6EF517FE1434051F4C0C760514B401FA2D11DC4E0434051F4C0C760514B40
38396	1114	39.763531	39.774220999999997	54.623497999999998	54.618029999999997	Лермонтова	0103000020E61000000100000005000000B83D4162BBE1434033F9669B1B4F4B40B83D4162BBE143408A8F4FC8CE4F4B402E7079AC19E343408A8F4FC8CE4F4B402E7079AC19E3434033F9669B1B4F4B40B83D4162BBE1434033F9669B1B4F4B40
38410	1114	39.696165999999998	39.726106999999999	54.623393999999998	54.606986999999997	Ленинского Комсомола	0103000020E61000000100000005000000274BADF71BD943406F0C01C0B14D4B40274BADF71BD94340E542E55FCB4F4B40C632FD12F1DC4340E542E55FCB4F4B40C632FD12F1DC43406F0C01C0B14D4B40274BADF71BD943406F0C01C0B14D4B40
38358	1114	39.740085000000001	39.755958	54.631560999999998	54.621918999999998	Ленина	0103000020E610000001000000050000004DA1F31ABBDE434069E1B20A9B4F4B404DA1F31ABBDE4340EB36A8FDD6504B402593533BC3E04340EB36A8FDD6504B402593533BC3E0434069E1B20A9B4F4B404DA1F31ABBDE434069E1B20A9B4F4B40
398	1114	39.761626	39.773465999999999	54.609813000000003	54.583764000000002	Куйбышевское шоссе	0103000020E6100000010000000500000043E4F4F57CE14340844A5CC7B84A4B4043E4F4F57CE143407CD6355A0E4E4B40B24813EF00E343407CD6355A0E4E4B40B24813EF00E34340844A5CC7B84A4B4043E4F4F57CE14340844A5CC7B84A4B40
38405	1114	39.727553	39.739958999999999	54.627439000000003	54.626275999999997	Кудрявцева	0103000020E61000000100000005000000A88DEA7420DD43408522DDCF29504B40A88DEA7420DD4340139ED0EB4F504B40C0B0FCF9B6DE4340139ED0EB4F504B40C0B0FCF9B6DE43408522DDCF29504B40A88DEA7420DD43408522DDCF29504B40
38399	1114	39.641396	39.664231000000001	54.640185000000002	54.636172999999999	Крупской	0103000020E6100000010000000500000082E49D4319D2434092CCEA1D6E514B4082E49D4319D24340E4310395F1514B40A4FE7A8505D54340E4310395F1514B40A4FE7A8505D5434092CCEA1D6E514B4082E49D4319D2434092CCEA1D6E514B40
38375	1114	39.640911000000003	39.648681000000003	54.670436000000002	54.664186999999998	Космонавтов	0103000020E61000000100000005000000C652245F09D24340D4B6611404554B40C652245F09D24340D107CBD8D0554B40AF44A0FA07D34340D107CBD8D0554B40AF44A0FA07D34340D4B6611404554B40C652245F09D24340D4B6611404554B40
38346	1114	39.667411000000001	39.672854999999998	54.607017999999997	54.605145999999998	Керамзавода	0103000020E61000000100000005000000CEFE40B96DD5434011A7936C754D4B40CEFE40B96DD54340AA0A0DC4B24D4B409CF9D51C20D64340AA0A0DC4B24D4B409CF9D51C20D6434011A7936C754D4B40CEFE40B96DD5434011A7936C754D4B40
1277	1114	39.771130999999997	39.819432999999997	54.625864	54.614562999999997	Касимовское шоссе	0103000020E6100000010000000500000044F7AC6BB4E24340732A1900AA4E4B4044F7AC6BB4E2434033DFC14F1C504B40AF21382EE3E8434033DFC14F1C504B40AF21382EE3E84340732A1900AA4E4B4044F7AC6BB4E24340732A1900AA4E4B40
38354	1114	39.779718000000003	39.82414	54.609802000000002	54.596608000000003	Зубковой	0103000020E61000000100000005000000200DA7CCCDE343401844A4A65D4C4B40200DA7CCCDE343408884EFFD0D4E4B40A8A9656B7DE943408884EFFD0D4E4B40A8A9656B7DE943401844A4A65D4C4B40200DA7CCCDE343401844A4A65D4C4B40
38313	1114	39.574741000000003	39.591791000000001	54.662286999999999	54.658296999999997	Забайкальская	0103000020E61000000100000005000000CE55F31C91C9434007077B1343544B40CE55F31C91C9434071C806D2C5544B409888B7CEBFCB434071C806D2C5544B409888B7CEBFCB434007077B1343544B40CE55F31C91C9434007077B1343544B40
38377	1114	39.742798000000001	39.772064999999998	54.630774000000002	54.614646	Есенина	0103000020E6100000010000000500000061C43E0114DF4340014F5AB8AC4E4B4061C43E0114DF43406495D233BD504B4070B1A206D3E243406495D233BD504B4070B1A206D3E24340014F5AB8AC4E4B4061C43E0114DF4340014F5AB8AC4E4B40
38459	1114	39.742798000000001	39.772064999999998	54.630774000000002	54.614646	Есенина	0103000020E6100000010000000500000061C43E0114DF4340014F5AB8AC4E4B4061C43E0114DF43406495D233BD504B4070B1A206D3E243406495D233BD504B4070B1A206D3E24340014F5AB8AC4E4B4061C43E0114DF4340014F5AB8AC4E4B40
38403	1114	39.716234	39.729250999999998	54.629142999999999	54.617289	Дзержинского	0103000020E610000001000000050000004224438EADDB43401C977153034F4B404224438EADDB4340F0C000C287504B40A3C9C51858DD4340F0C000C287504B40A3C9C51858DD43401C977153034F4B404224438EADDB43401C977153034F4B40
38386	1114	39.716234	39.729250999999998	54.629142999999999	54.617289	Дзержинского	0103000020E610000001000000050000004224438EADDB43401C977153034F4B404224438EADDB4340F0C000C287504B40A3C9C51858DD4340F0C000C287504B40A3C9C51858DD43401C977153034F4B404224438EADDB43401C977153034F4B40
38392	1114	39.645806999999998	39.656829000000002	54.662927000000003	54.654724999999999	Дачная	0103000020E610000001000000050000009143C4CDA9D24340D26F5F07CE534B409143C4CDA9D243405551BCCADA544B403E0801F912D443405551BCCADA544B403E0801F912D44340D26F5F07CE534B409143C4CDA9D24340D26F5F07CE534B40
38450	1114	39.737335999999999	39.760539000000001	54.629970999999998	54.609672000000003	Горького	0103000020E61000000100000005000000EC14AB0661DE4340BAA46ABB094E4B40EC14AB0661DE4340D636C5E3A2504B40912A8A5759E14340D636C5E3A2504B40912A8A5759E14340BAA46ABB094E4B40EC14AB0661DE4340BAA46ABB094E4B40
38381	1114	39.752580000000002	39.765569999999997	54.631207000000003	54.624029999999998	Вознесенская	0103000020E61000000100000005000000D5CF9B8A54E0434087DC0C37E04F4B40D5CF9B8A54E04340CE001764CB504B403C66A032FEE14340CE001764CB504B403C66A032FEE1434087DC0C37E04F4B40D5CF9B8A54E0434087DC0C37E04F4B40
38062	1114	39.666432	39.674633999999998	54.638559000000001	54.635928	Вишневая	0103000020E610000001000000050000000281CEA44DD543402B4EB51666514B400281CEA44DD5434082C8224DBC514B4084622B685AD6434082C8224DBC514B4084622B685AD643402B4EB51666514B400281CEA44DD543402B4EB51666514B40
38435	1114	39.670636000000002	39.678567999999999	54.669176	54.665416	Весенняя	0103000020E6100000010000000500000098C28366D7D54340191EFB592C554B4098C28366D7D5434051A2258FA7554B405A0EF450DBD6434051A2258FA7554B405A0EF450DBD64340191EFB592C554B4098C28366D7D54340191EFB592C554B40
38390	1114	39.644925999999998	39.654826	54.643873999999997	54.641201000000002	Великанова	0103000020E61000000100000005000000882B67EF8CD24340CD94D6DF12524B40882B67EF8CD24340525F96766A524B4006499F56D1D34340525F96766A524B4006499F56D1D34340CD94D6DF12524B40882B67EF8CD24340CD94D6DF12524B40
38204	1114	39.738728000000002	39.752580000000002	54.624029999999998	54.616987000000002	Введенская	0103000020E61000000100000005000000DB519CA38EDE43405187156EF94E4B40DB519CA38EDE434087DC0C37E04F4B40D5CF9B8A54E0434087DC0C37E04F4B40D5CF9B8A54E043405187156EF94E4B40DB519CA38EDE43405187156EF94E4B40
38361	1114	39.641576000000001	39.679645999999998	54.676433000000003	54.660131	Бирюзова	0103000020E6100000010000000500000002F390291FD24340B309302C7F544B4002F390291FD24340B477465B95564B40B96DDFA3FED64340B477465B95564B40B96DDFA3FED64340B309302C7F544B4002F390291FD24340B309302C7F544B40
38299	1114	39.575288999999998	39.594540000000002	54.658937999999999	54.654026999999999	Белякова	0103000020E61000000100000005000000D05FE811A3C94340BAD91F28B7534B40D05FE811A3C94340BB0B941458544B40F91400E319CC4340BB0B941458544B40F91400E319CC4340BAD91F28B7534B40D05FE811A3C94340BAD91F28B7534B40
38315	1114	39.575288999999998	39.594540000000002	54.658937999999999	54.654026999999999	Белякова	0103000020E61000000100000005000000D05FE811A3C94340BAD91F28B7534B40D05FE811A3C94340BB0B941458544B40F91400E319CC4340BB0B941458544B40F91400E319CC4340BAD91F28B7534B40D05FE811A3C94340BAD91F28B7534B40
38503	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Широкая	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38176	1114	39.663916999999998	39.671264999999998	54.633682	54.631332	Бахмачевская	0103000020E610000001000000050000001421753BFBD443408A75AA7CCF504B401421753BFBD443402D08E57D1C514B4087F9F202ECD543402D08E57D1C514B4087F9F202ECD543408A75AA7CCF504B401421753BFBD443408A75AA7CCF504B40
38385	1114	39.731191000000003	39.740533999999997	54.609358999999998	54.600630000000002	Баженова	0103000020E610000001000000050000009510ACAA97DD43408D7F9F71E14C4B409510ACAA97DD4340FA42C879FF4D4B40BCC96FD1C9DE4340FA42C879FF4D4B40BCC96FD1C9DE43408D7F9F71E14C4B409510ACAA97DD43408D7F9F71E14C4B40
38414	1114	39.615155999999999	39.630481000000003	54.645634999999999	54.642139	Аллейная	0103000020E6100000010000000500000016F88A6EBDCE43403A3E5A9C31524B4016F88A6EBDCE43409413ED2AA4524B40ECDFF599B3D043409413ED2AA4524B40ECDFF599B3D043403A3E5A9C31524B4016F88A6EBDCE43403A3E5A9C31524B40
38432	1114	39.693705000000001	39.707045000000001	54.615693999999998	54.612644000000003	9-я линия	0103000020E610000001000000050000002D095053CBD843409A0B5C1E6B4E4B402D095053CBD84340F52B9D0FCF4E4B4071E6577380DA4340F52B9D0FCF4E4B4071E6577380DA43409A0B5C1E6B4E4B402D095053CBD843409A0B5C1E6B4E4B40
38216	1114	39.537227000000001	39.853074999999997	54.705835	54.528880000000001	9-й район	0103000020E610000001000000050000009CC3B5DAC3C4434016C1FF56B2434B409CC3B5DAC3C44340A3AF20CD585A4B408104C58F31ED4340A3AF20CD585A4B408104C58F31ED434016C1FF56B2434B409CC3B5DAC3C4434016C1FF56B2434B40
38298	1114	39.709057000000001	39.712273000000003	54.611299000000002	54.609729000000002	50-летия Октября площадь	0103000020E61000000100000005000000FCFF3861C2DA43401E3691990B4E4B40FCFF3861C2DA4340EC89AE0B3F4E4B407369FCC22BDB4340EC89AE0B3F4E4B407369FCC22BDB43401E3691990B4E4B40FCFF3861C2DA43401E3691990B4E4B40
38430	1114	39.711481999999997	39.720987000000001	54.619964000000003	54.614094000000001	2-я линия	0103000020E61000000100000005000000A9D898D711DB4340BD55D7A19A4E4B40A9D898D711DB43404359F8FA5A4F4B40ABEB504D49DC43404359F8FA5A4F4B40ABEB504D49DC4340BD55D7A19A4E4B40A9D898D711DB4340BD55D7A19A4E4B40
38388	1114	39.711481999999997	39.720987000000001	54.619964000000003	54.614094000000001	2-я Линия	0103000020E61000000100000005000000A9D898D711DB4340BD55D7A19A4E4B40A9D898D711DB43404359F8FA5A4F4B40ABEB504D49DC43404359F8FA5A4F4B40ABEB504D49DC4340BD55D7A19A4E4B40A9D898D711DB4340BD55D7A19A4E4B40
38382	1114	39.696129999999997	39.701555999999997	54.613233000000001	54.609563000000001	12-я линия	0103000020E61000000100000005000000DAE1AFC91AD9434003ED0E29064E4B40DAE1AFC91AD94340FBE93F6B7E4E4B4002284696CCD94340FBE93F6B7E4E4B4002284696CCD9434003ED0E29064E4B40DAE1AFC91AD9434003ED0E29064E4B40
38350	1114	39.795932999999998	39.801439999999999	54.590170999999998	54.586210999999999	1-я Механизаторов	0103000020E610000001000000050000005167EE21E1E5434019C748F6084B4B405167EE21E1E5434018062CB98A4B4B4066DAFE9595E6434018062CB98A4B4B4066DAFE9595E6434019C748F6084B4B405167EE21E1E5434019C748F6084B4B40
38359	1114	39.670780000000001	39.685017999999999	54.645905999999997	54.643675999999999	1-я Красная	0103000020E61000000100000005000000CB67791EDCD543402C9CA4F963524B40CB67791EDCD5434024253D0CAD524B40EE9579ABAED7434024253D0CAD524B40EE9579ABAED743402C9CA4F963524B40CB67791EDCD543402C9CA4F963524B40
38510	1114	39.706856000000002	39.773116000000002	54.595267999999997	54.543731000000001	 Южный промузел	0103000020E610000001000000050000009E7DE5417ADA4340236937FA98454B409E7DE5417ADA43407B2DE8BD314C4B40D6011077F5E243407B2DE8BD314C4B40D6011077F5E24340236937FA98454B409E7DE5417ADA4340236937FA98454B40
38370	1114	39.676555999999998	39.710000000000001	54.629336000000002	54.613066000000003	 Чкалова	0103000020E61000000100000005000000CFF4126399D6434010255AF2784E4B40CFF4126399D64340051901158E504B407B14AE47E1DA4340051901158E504B407B14AE47E1DA434010255AF2784E4B40CFF4126399D6434010255AF2784E4B40
38451	1114	39.755958	39.761626	54.621918999999998	54.609813000000003	 Циолковского	0103000020E610000001000000050000002593533BC3E043407CD6355A0E4E4B402593533BC3E0434069E1B20A9B4F4B4043E4F4F57CE1434069E1B20A9B4F4B4043E4F4F57CE143407CD6355A0E4E4B402593533BC3E043407CD6355A0E4E4B40
38397	1114	39.752561999999998	39.762245999999998	54.626021000000001	54.614697999999997	 Урицкого	0103000020E610000001000000050000002E1B9DF353E0434053758F6CAE4E4B402E1B9DF353E04340FBCDC47421504B40DFC0E44691E14340FBCDC47421504B40DFC0E44691E1434053758F6CAE4E4B402E1B9DF353E0434053758F6CAE4E4B40
38408	1114	39.624777000000002	39.629519999999999	54.690345000000001	54.686597999999996	 Сельских Строителей	0103000020E61000000100000005000000812557B1F8CF4340DFBF7971E2574B40812557B1F8CF434083FA96395D584B40C616821C94D0434083FA96395D584B40C616821C94D04340DFBF7971E2574B40812557B1F8CF4340DFBF7971E2574B40
38440	1114	39.656846999999999	39.662902000000003	54.653860000000002	54.651167000000001	 Пирогова	0103000020E61000000100000005000000E4BCFF8F13D44340029EB47059534B40E4BCFF8F13D44340CF143AAFB1534B40FC3905F9D9D44340CF143AAFB1534B40FC3905F9D9D44340029EB47059534B40E4BCFF8F13D44340029EB47059534B40
38380	1114	39.785279000000003	39.828991000000002	54.614035999999999	54.599356999999998	 Новоселов	0103000020E61000000100000005000000289EB30584E4434078D0ECBAB74C4B40289EB30584E4434088484DBB984E4B40D4D688601CEA434088484DBB984E4B40D4D688601CEA434078D0ECBAB74C4B40289EB30584E4434078D0ECBAB74C4B40
38404	1114	39.785279000000003	39.828991000000002	54.614035999999999	54.599356999999998	 Новоселов	0103000020E61000000100000005000000289EB30584E4434078D0ECBAB74C4B40289EB30584E4434088484DBB984E4B40D4D688601CEA434088484DBB984E4B40D4D688601CEA434078D0ECBAB74C4B40289EB30584E4434078D0ECBAB74C4B40
38393	1114	39.650765	39.655014000000001	54.637976000000002	54.630606999999998	 Костычева	0103000020E61000000100000005000000D3307C444CD3434078D0ECBAB7504B40D3307C444CD3434003D19332A9514B400936AE7FD7D3434003D19332A9514B400936AE7FD7D3434078D0ECBAB7504B40D3307C444CD3434078D0ECBAB7504B40
38374	1114	39.633167	39.640892999999998	54.663141000000003	54.659308000000003	 Карла Маркса	0103000020E6100000010000000500000006F4C29D0BD14340DFFE5C3464544B4006F4C29D0BD1434081D1E5CDE1544B401F9E25C808D2434081D1E5CDE1544B401F9E25C808D24340DFFE5C3464544B4006F4C29D0BD14340DFFE5C3464544B40
38368	1114	39.637776000000002	39.668129999999998	54.68206	54.660260999999998	 Интернациональная	0103000020E610000001000000050000003C16DBA4A2D1434081E9B46E83544B403C16DBA4A2D1434073F4F8BD4D574B40FDBCA94885D5434073F4F8BD4D574B40FDBCA94885D5434081E9B46E83544B403C16DBA4A2D1434081E9B46E83544B40
38411	1114	39.637776000000002	39.668129999999998	54.68206	54.660260999999998	 Интернациональная	0103000020E610000001000000050000003C16DBA4A2D1434081E9B46E83544B403C16DBA4A2D1434073F4F8BD4D574B40FDBCA94885D5434073F4F8BD4D574B40FDBCA94885D5434081E9B46E83544B403C16DBA4A2D1434081E9B46E83544B40
38400	1114	39.707045000000001	39.732754999999997	54.619104	54.609541999999998	 Гагарина	0103000020E6100000010000000500000071E6577380DA4340EBC4E578054E4B4071E6577380DA43405169C4CC3E4F4B40807D74EACADD43405169C4CC3E4F4B40807D74EACADD4340EBC4E578054E4B4071E6577380DA4340EBC4E578054E4B40
38373	1114	39.641576000000001	39.679645999999998	54.676433000000003	54.660131	 Бирюзова	0103000020E6100000010000000500000002F390291FD24340B309302C7F544B4002F390291FD24340B477465B95564B40B96DDFA3FED64340B477465B95564B40B96DDFA3FED64340B309302C7F544B4002F390291FD24340B309302C7F544B40
38220	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Строителей	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38577	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Пожалостина	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38496	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Новоряжская	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38244	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Мичуринская	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38080	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Лермонтова	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38266	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Кольцова	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38247	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Горького	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38283	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Гагарина	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38241	54596	40.019083999999999	40.165374	53.731876	53.686233000000001	Волгоградская	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38285	54589	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Набережный переулок	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38222	54589	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Мира	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38499	54589	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Куйбышева	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38054	54591	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	Воеводина	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38256	54625	39.991568000000001	40.068823000000002	53.945242	53.899371000000002	Коминтерна	0103000020E610000001000000050000004CE141B3EBFE434044FCC3961EF34A404CE141B3EBFE43401F679AB0FDF84A40371B2B31CF0844401F679AB0FDF84A40371B2B31CF08444044FCC3961EF34A404CE141B3EBFE434044FCC3961EF34A40
38462	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	академика В.Ф. Уткина	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38099	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Татарская	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38089	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Советская	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38224	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Северная	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38235	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Приоский	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38223	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Приокский	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38228	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Московская	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38227	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Ленина	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38281	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	К. Либкнехта	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38225	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Затонная	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38097	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Гагарина	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38193	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	Большакова	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38240	8703	41.342697000000001	41.440955000000002	54.962912000000003	54.918509	 50 лет ВЛКСМ	0103000020E61000000100000005000000FAB7CB7EDDAB4440740AF2B391754B40FAB7CB7EDDAB444086764EB3407B4B40FC00A43671B8444086764EB3407B4B40FC00A43671B84440740AF2B391754B40FAB7CB7EDDAB4440740AF2B391754B40
38543	17361	42.074249000000002	42.099375000000002	54.131653999999997	54.112631	Центральная	0103000020E610000001000000050000005F61C1FD8009454005C24EB16A0E4B405F61C1FD800945409C31CC09DA104B401F85EB51B80C45409C31CC09DA104B401F85EB51B80C454005C24EB16A0E4B405F61C1FD8009454005C24EB16A0E4B40
38671	16841	41.575063999999998	41.598312999999997	54.104512999999997	54.096271000000002	Центральная	0103000020E61000000100000005000000B08D78B29BC94440D046AE9B520C4B40B08D78B29BC94440E08096AE600D4B40C5E2378595CC4440E08096AE600D4B40C5E2378595CC4440D046AE9B520C4B40B08D78B29BC94440D046AE9B520C4B40
38107	17113	41.675010999999998	41.770519999999998	54.042203999999998	54.016188999999997	Энгельса	0103000020E610000001000000050000005AB8ACC266D6444008C72C7B12024B405AB8ACC266D6444054E1CFF066054B40FB743C66A0E2444054E1CFF066054B40FB743C66A0E2444008C72C7B12024B405AB8ACC266D6444008C72C7B12024B40
38203	17113	41.675010999999998	41.770519999999998	54.042203999999998	54.016188999999997	Тараскина	0103000020E610000001000000050000005AB8ACC266D6444008C72C7B12024B405AB8ACC266D6444054E1CFF066054B40FB743C66A0E2444054E1CFF066054B40FB743C66A0E2444008C72C7B12024B405AB8ACC266D6444008C72C7B12024B40
74891	17113	41.675010999999998	41.770519999999998	54.042203999999998	54.016188999999997	Республиканская площадь	0103000020E610000001000000050000005AB8ACC266D6444008C72C7B12024B405AB8ACC266D6444054E1CFF066054B40FB743C66A0E2444054E1CFF066054B40FB743C66A0E2444008C72C7B12024B405AB8ACC266D6444008C72C7B12024B40
38697	15099	42.090679000000002	42.124428999999999	53.893428999999998	53.886085000000001	Центральная	0103000020E610000001000000050000008DB7955E9B0B4540F33CB83B6BF14A408DB7955E9B0B45402426A8E15BF24A4045D61A4AED0F45402426A8E15BF24A4045D61A4AED0F4540F33CB83B6BF14A408DB7955E9B0B4540F33CB83B6BF14A40
38125	54604	41.712471000000001	41.762524999999997	54.022055000000002	54.006807999999999	Морина	0103000020E61000000100000005000000992CEE3F32DB4440F3ACA415DF004B40992CEE3F32DB44404DDBBFB2D2024B40F2B0506B9AE144404DDBBFB2D2024B40F2B0506B9AE14440F3ACA415DF004B40992CEE3F32DB4440F3ACA415DF004B40
38326	54604	41.712471000000001	41.762524999999997	54.022055000000002	54.006807999999999	Базарная	0103000020E61000000100000005000000992CEE3F32DB4440F3ACA415DF004B40992CEE3F32DB44404DDBBFB2D2024B40F2B0506B9AE144404DDBBFB2D2024B40F2B0506B9AE14440F3ACA415DF004B40992CEE3F32DB4440F3ACA415DF004B40
38666	14619	41.632224000000001	41.660260999999998	54.195529000000001	54.182754000000003	Центральная	0103000020E6100000010000000500000087DF4DB7ECD044404A9BAA7B64174B4087DF4DB7ECD04440B535221807194B4081E9B46E83D44440B535221807194B4081E9B46E83D444404A9BAA7B64174B4087DF4DB7ECD044404A9BAA7B64174B40
38668	16210	41.390065	41.413519999999998	53.967737	53.953726000000003	Центральная	0103000020E61000000100000005000000392861A6EDB1444026AC8DB113FA4A40392861A6EDB14440881057CEDEFB4A40F71E2E39EEB44440881057CEDEFB4A40F71E2E39EEB4444026AC8DB113FA4A40392861A6EDB1444026AC8DB113FA4A40
38615	15498	41.945979000000001	41.966380000000001	54.068646999999999	54.052638999999999	Центральная	0103000020E61000000100000005000000F5D901D715F9444040BFEFDFBC064B40F5D901D715F94440F8FBC56CC9084B4016C1FF56B2FB4440F8FBC56CC9084B4016C1FF56B2FB444040BFEFDFBC064B40F5D901D715F9444040BFEFDFBC064B40
38700	16775	41.577705000000002	41.616432000000003	53.960343000000002	53.934641999999997	Центральная	0103000020E610000001000000050000002BDEC83CF2C94440E8BB5B59A2F74A402BDEC83CF2C94440A5F8F884ECFA4A409C1A683EE7CE4440A5F8F884ECFA4A409C1A683EE7CE4440E8BB5B59A2F74A402BDEC83CF2C94440E8BB5B59A2F74A40
38694	16153	41.924993999999998	41.951126000000002	53.906024000000002	53.886414000000002	Центральная	0103000020E61000000100000005000000847F113466F64440B85B920376F14A40847F113466F6444010B22C98F8F34A400A302C7FBEF9444010B22C98F8F34A400A302C7FBEF94440B85B920376F14A40847F113466F64440B85B920376F14A40
38792	15930	41.841613000000002	41.869883000000002	53.864660000000001	53.848823000000003	Центральная	0103000020E61000000100000005000000B9718BF9B9EB4440DB8B683BA6EC4A40B9718BF9B9EB44406614CB2DADEE4A40562C7E5358EF44406614CB2DADEE4A40562C7E5358EF4440DB8B683BA6EC4A40B9718BF9B9EB4440DB8B683BA6EC4A40
38672	15598	41.842475	41.878641000000002	54.110055000000003	54.094867000000001	Центральная	0103000020E610000001000000050000004B598638D6EB44401D3C139A240C4B404B598638D6EB444072E14048160E4B405EF6EB4E77F0444072E14048160E4B405EF6EB4E77F044401D3C139A240C4B404B598638D6EB44401D3C139A240C4B40
38704	54669	41.262692999999999	42.445981000000003	54.241294000000003	53.772956000000001	Центральная	0103000020E61000000100000005000000AEF199EC9FA144409D9FE238F0E24A40AEF199EC9FA144404B5CC7B8E21E4B4096D1C8E7153945404B5CC7B8E21E4B4096D1C8E7153945409D9FE238F0E24A40AEF199EC9FA144409D9FE238F0E24A40
38667	15866	41.604664	41.629897999999997	53.901594000000003	53.886690000000002	Центральная	0103000020E61000000100000005000000C68844A165CD44405AD8D30E7FF14A40C68844A165CD44408A22A46E67F34A406CE8667FA0D044408A22A46E67F34A406CE8667FA0D044405AD8D30E7FF14A40C68844A165CD44405AD8D30E7FF14A40
38720	16518	41.840400000000002	41.871419000000003	54.006855000000002	53.972169999999998	Центральная	0103000020E610000001000000050000007AC7293A92EB44407F130A1170FC4A407AC7293A92EB44403468E89FE0004B40780E65A88AEF44403468E89FE0004B40780E65A88AEF44407F130A1170FC4A407AC7293A92EB44407F130A1170FC4A40
38618	16518	41.840400000000002	41.871419000000003	54.006855000000002	53.972169999999998	Набережная	0103000020E610000001000000050000007AC7293A92EB44407F130A1170FC4A407AC7293A92EB44403468E89FE0004B40780E65A88AEF44403468E89FE0004B40780E65A88AEF44407F130A1170FC4A407AC7293A92EB44407F130A1170FC4A40
38542	15686	41.896678999999999	41.931651000000002	54.064615000000003	54.039946	Центральная	0103000020E610000001000000050000004701A260C6F2444092CD55F31C054B404701A260C6F2444060EAE74D45084B409224085740F7444060EAE74D45084B409224085740F7444092CD55F31C054B404701A260C6F2444092CD55F31C054B40
38669	16463	41.752104000000003	41.788181000000002	53.838144999999997	53.807164	Центральная	0103000020E610000001000000050000006C98A1F144E044401841632651E74A406C98A1F144E044402827DA5548EB4A400F2A711DE3E444402827DA5548EB4A400F2A711DE3E444401841632651E74A406C98A1F144E044401841632651E74A40
38613	16065	41.873251000000003	41.903101999999997	53.872587000000003	53.860793999999999	Центральная	0103000020E61000000100000005000000831953B0C6EF4440E84B6F7F2EEE4A40831953B0C6EF444017F549EEB0EF4A40E179A9D898F3444017F549EEB0EF4A40E179A9D898F34440E84B6F7F2EEE4A40831953B0C6EF4440E84B6F7F2EEE4A40
38695	16163	41.451644999999999	41.532556	53.893051999999997	53.868074	Центральная	0103000020E610000001000000050000007233DC80CFB944400341800C1DEF4A407233DC80CFB944404ED026874FF24A40F0A485CB2AC444404ED026874FF24A40F0A485CB2AC444400341800C1DEF4A407233DC80CFB944400341800C1DEF4A40
38612	15976	41.792115000000003	41.829906999999999	53.904119000000001	53.866917000000001	Центральная	0103000020E61000000100000005000000E5D5390664E5444058ACE122F7EE4A40E5D5390664E544409B58E02BBAF34A4059DC7F643AEA44409B58E02BBAF34A4059DC7F643AEA444058ACE122F7EE4A40E5D5390664E5444058ACE122F7EE4A40
38691	14732	41.712983000000001	41.750478000000001	53.923121999999999	53.899652000000003	Центральная	0103000020E610000001000000050000004FCDE50643DB4440F8E3F6CB27F34A404FCDE50643DB4440EB1B98DC28F64A400A2FC1A90FE04440EB1B98DC28F64A400A2FC1A90FE04440F8E3F6CB27F34A404FCDE50643DB4440F8E3F6CB27F34A40
38696	15345	42.065615999999999	42.108367000000001	54.077036	54.067827999999999	Центральная	0103000020E61000000100000005000000130CE71A6608454065E08096AE084B40130CE71A66084540AD4ECE50DC094B409A7B48F8DE0D4540AD4ECE50DC094B409A7B48F8DE0D454065E08096AE084B40130CE71A6608454065E08096AE084B40
38705	15587	41.905141	41.934516000000002	54.050587999999998	54.025848000000003	Центральная	0103000020E6100000010000000500000066A208A9DBF344406155BDFC4E034B4066A208A9DBF34440F7C8E6AA79064B405CCB64389EF74440F7C8E6AA79064B405CCB64389EF744406155BDFC4E034B4066A208A9DBF344406155BDFC4E034B40
38614	16677	41.888280000000002	41.920268999999998	54.010976999999997	53.994159000000003	Центральная	0103000020E610000001000000050000006FD8B628B3F144401503249A40FF4A406FD8B628B3F144400C01C0B167014B40E542E55FCBF544400C01C0B167014B40E542E55FCBF544401503249A40FF4A406FD8B628B3F144401503249A40FF4A40
38611	15772	41.654431000000002	41.678756999999997	53.874741999999998	53.859323000000003	Центральная	0103000020E610000001000000050000008A3E1F65C4D34440AED9CA4BFEED4A408A3E1F65C4D344400438BD8BF7EF4A402D776682E1D644400438BD8BF7EF4A402D776682E1D64440AED9CA4BFEED4A408A3E1F65C4D34440AED9CA4BFEED4A40
38609	15490	41.977257999999999	42.002302999999998	54.106988999999999	54.093815999999997	Центральная	0103000020E610000001000000050000008FE046CA16FD4440B7EBA529020C4B408FE046CA16FD44401004C8D0B10D4B4062D7F6764B0045401004C8D0B10D4B4062D7F6764B004540B7EBA529020C4B408FE046CA16FD4440B7EBA529020C4B40
38702	15201	42.066811000000001	42.117755000000002	54.049658000000001	54.040073	Центральная	0103000020E61000000100000005000000AC014A438D084540EF39B01C21054B40AC014A438D0845400DFE7E315B064B4062F88898120F45400DFE7E315B064B4062F88898120F4540EF39B01C21054B40AC014A438D084540EF39B01C21054B40
38698	16679	41.505822000000002	41.539625999999998	53.950515000000003	53.930587000000003	Центральная	0103000020E6100000010000000500000075CC79C6BEC04440988A8D791DF74A4075CC79C6BEC04440C1ADBB79AAF94A402009FB7612C54440C1ADBB79AAF94A402009FB7612C54440988A8D791DF74A4075CC79C6BEC04440988A8D791DF74A40
38689	14343	41.571461999999997	41.607961000000003	53.883488999999997	53.869990999999999	Центральная	0103000020E610000001000000050000001074B4AA25C944403C6876DD5BEF4A401074B4AA25C9444018B0E42A16F14A402A1F82AAD1CD444018B0E42A16F14A402A1F82AAD1CD44403C6876DD5BEF4A401074B4AA25C944403C6876DD5BEF4A40
38699	17417	42.179701999999999	42.213918999999997	54.093899999999998	54.083069000000002	Центральная	0103000020E610000001000000050000004D83A27900174540DD274701A20A4B404D83A27900174540158C4AEA040C4B401B7FA2B2611B4540158C4AEA040C4B401B7FA2B2611B4540DD274701A20A4B404D83A27900174540DD274701A20A4B40
38621	15054	42.065814000000003	42.095008999999997	53.864288000000002	53.842559999999999	Центральная	0103000020E610000001000000050000003ACFD8976C08454079758E01D9EB4A403ACFD8976C084540A2293BFDA0EE4A40AFE94141290C4540A2293BFDA0EE4A40AFE94141290C454079758E01D9EB4A403ACFD8976C08454079758E01D9EB4A40
38790	14630	41.727831999999999	41.751340999999996	54.091931000000002	54.082006999999997	Центральная	0103000020E61000000100000005000000BB7D569929DD4440838593347F0A4B40BB7D569929DD44408A3E1F65C40B4B406C921FF12BE044408A3E1F65C40B4B406C921FF12BE04440838593347F0A4B40BB7D569929DD4440838593347F0A4B40
38310	54633	41.685602000000003	41.719298000000002	54.021203999999997	53.991422	Центральная	0103000020E610000001000000050000003E096CCEC1D74440784485EAE6FE4A403E096CCEC1D74440AE450BD0B6024B40030AF5F411DC4440AE450BD0B6024B40030AF5F411DC4440784485EAE6FE4A403E096CCEC1D74440784485EAE6FE4A40
38337	54633	41.685602000000003	41.719298000000002	54.021203999999997	53.991422	Ленина	0103000020E610000001000000050000003E096CCEC1D74440784485EAE6FE4A403E096CCEC1D74440AE450BD0B6024B40030AF5F411DC4440AE450BD0B6024B40030AF5F411DC4440784485EAE6FE4A403E096CCEC1D74440784485EAE6FE4A40
38616	16885	41.540559999999999	41.555984000000002	54.019759999999998	54.005215	Центральная	0103000020E610000001000000050000004CC3F01131C544406D3997E2AA004B404CC3F01131C544406DE2E47E87024B40B58CD47B2AC744406DE2E47E87024B40B58CD47B2AC744406D3997E2AA004B404CC3F01131C544406D3997E2AA004B40
38540	14921	41.755274999999997	41.789743999999999	54.174280000000003	54.151074000000001	Центральная	0103000020E61000000100000005000000423EE8D9ACE0444051A3906456134B40423EE8D9ACE04440672C9ACE4E164B402A1BD65416E54440672C9ACE4E164B402A1BD65416E5444051A3906456134B40423EE8D9ACE0444051A3906456134B40
38665	14778	42.046905000000002	42.076908000000003	53.971535000000003	53.954901999999997	Центральная	0103000020E610000001000000050000006B82A8FB0006454047718E3A3AFA4A406B82A8FB00064540AEF545425BFC4A408066101FD8094540AEF545425BFC4A408066101FD809454047718E3A3AFA4A406B82A8FB0006454047718E3A3AFA4A40
38610	14914	42.069325999999997	42.106903000000003	53.954754000000001	53.935823999999997	Плетнева	0103000020E610000001000000050000009961A3ACDF084540EC67B114C9F74A409961A3ACDF084540D3DC0A6135FA4A40126C5CFFAE0D4540D3DC0A6135FA4A40126C5CFFAE0D4540EC67B114C9F74A409961A3ACDF084540EC67B114C9F74A40
38692	15282	42.099249	42.112796000000003	54.035632	54.021262	Центральная	0103000020E610000001000000050000009294F430B40C4540E35295B6B8024B409294F430B40C45407558E1968F044B40508F6D19700E45407558E1968F044B40508F6D19700E4540E35295B6B8024B409294F430B40C4540E35295B6B8024B40
38617	16480	41.777158	41.812804	53.867266999999998	53.852260000000001	Центральная	0103000020E6100000010000000500000092E9D0E979E3444030D80DDB16ED4A4092E9D0E979E3444034F3E49A02EF4A406C0723F609E8444034F3E49A02EF4A406C0723F609E8444030D80DDB16ED4A4092E9D0E979E3444030D80DDB16ED4A40
38664	14445	41.710808999999998	41.733652999999997	53.952596999999997	53.939141999999997	Центральная	0103000020E61000000100000005000000EA5910CAFBDA4440672618CE35F84A40EA5910CAFBDA444044A2D0B2EEF94A405FCE6C57E8DD444044A2D0B2EEF94A405FCE6C57E8DD4440672618CE35F84A40EA5910CAFBDA4440672618CE35F84A40
38794	15296	42.091074999999996	42.104306999999999	54.031644	54.016919000000001	Центральная	0103000020E61000000100000005000000D93D7958A80B45402CD7DB662A024B40D93D7958A80B4540AC8E1CE90C044B4037DF88EE590D4540AC8E1CE90C044B4037DF88EE590D45402CD7DB662A024B40D93D7958A80B45402CD7DB662A024B40
38690	14720	41.802095999999999	41.853982000000002	53.965629	53.931376	Центральная	0103000020E610000001000000050000004F20EC14ABE64440C0232A5437F74A404F20EC14ABE64440DB8827BB99FB4A40B4AF3C484FED4440DB8827BB99FB4A40B4AF3C484FED4440C0232A5437F74A404F20EC14ABE64440C0232A5437F74A40
38791	14535	41.710287999999998	41.758878000000003	54.134318	54.112752999999998	Центральная	0103000020E61000000100000005000000E15E99B7EADA444050C3B7B06E0E4B40E15E99B7EADA4440CFA10C5531114B40B3D30FEA22E14440CFA10C5531114B40B3D30FEA22E1444050C3B7B06E0E4B40E15E99B7EADA444050C3B7B06E0E4B40
38787	14334	41.477822000000003	41.529107000000003	53.818137	53.802160000000001	Центральная	0103000020E6100000010000000500000098A7734529BD44406614CB2DADE64A4098A7734529BD4440E35295B6B8E84A40D78A36C7B9C34440E35295B6B8E84A40D78A36C7B9C344406614CB2DADE64A4098A7734529BD44406614CB2DADE64A40
38608	14145	41.421928999999999	41.498690000000003	54.286681999999999	54.244487999999997	Сосновая	0103000020E61000000100000005000000F31DFCC401B64440D921FE614B1F4B40F31DFCC401B644400A2DEBFEB1244B40CF6BEC12D5BF44400A2DEBFEB1244B40CF6BEC12D5BF4440D921FE614B1F4B40F31DFCC401B64440D921FE614B1F4B40
38687	13030	40.366103000000003	40.391928999999998	53.830801999999998	53.812655999999997	Однодворцы	0103000020E61000000100000005000000D7FB8D76DC2E4440F7729F1C05E84A40D7FB8D76DC2E4440C7B94DB857EA4A404FADBEBA2A324440C7B94DB857EA4A404FADBEBA2A324440F7729F1C05E84A40D7FB8D76DC2E4440F7729F1C05E84A40
38623	13016	40.406697999999999	40.432174000000003	53.732168999999999	53.712978	Молодежная	0103000020E610000001000000050000009FAC18AE0E3444403D62F4DC42DB4A409FAC18AE0E3444409012BBB6B7DD4A403C17467A513744409012BBB6B7DD4A403C17467A513744403D62F4DC42DB4A409FAC18AE0E3444403D62F4DC42DB4A40
38058	13067	40.448118999999998	40.512177999999999	53.819879999999998	53.779820000000001	Совхозная	0103000020E61000000100000005000000ADDBA0F65B39444024624A24D1E34A40ADDBA0F65B3944407E52EDD3F1E84A4087DD770C8F4144407E52EDD3F1E84A4087DD770C8F41444024624A24D1E34A40ADDBA0F65B39444024624A24D1E34A40
38094	13067	40.448118999999998	40.512177999999999	53.819879999999998	53.779820000000001	Советская	0103000020E61000000100000005000000ADDBA0F65B39444024624A24D1E34A40ADDBA0F65B3944407E52EDD3F1E84A4087DD770C8F4144407E52EDD3F1E84A4087DD770C8F41444024624A24D1E34A40ADDBA0F65B39444024624A24D1E34A40
38789	13067	40.448118999999998	40.512177999999999	53.819879999999998	53.779820000000001	Гагарина	0103000020E61000000100000005000000ADDBA0F65B39444024624A24D1E34A40ADDBA0F65B3944407E52EDD3F1E84A4087DD770C8F4144407E52EDD3F1E84A4087DD770C8F41444024624A24D1E34A40ADDBA0F65B39444024624A24D1E34A40
38685	12856	40.491219999999998	40.507947000000001	53.880251999999999	53.860841999999998	Юбилейная	0103000020E610000001000000050000001092054CE03E4440F982161230EE4A401092054CE03E44408A1EF818ACF04A40F88C4468044144408A1EF818ACF04A40F88C446804414440F982161230EE4A401092054CE03E4440F982161230EE4A40
38661	12813	40.500948999999999	40.567253000000001	53.706336999999998	53.685113000000001	Молодежная	0103000020E6100000010000000500000061FBC9181F404440408864C8B1D74A4061FBC9181F404440357A354069DA4A4069C70DBF9B484440357A354069DA4A4069C70DBF9B484440408864C8B1D74A4061FBC9181F404440408864C8B1D74A40
38793	12808	40.406939999999999	40.460946999999997	53.920667000000002	53.869635000000002	Центральная	0103000020E6100000010000000500000095B7239C163444407E3A1E3350EF4A4095B7239C16344440D3C08F6AD8F54A403B18B14F003B4440D3C08F6AD8F54A403B18B14F003B44407E3A1E3350EF4A4095B7239C163444407E3A1E3350EF4A40
38683	12481	40.444839999999999	40.483656000000003	53.782874	53.770476000000002	Правобережная	0103000020E61000000100000005000000F0F96184F03844402C2D23F59EE24A40F0F96184F0384440C171193735E44A40D1419770E83D4440C171193735E44A40D1419770E83D44402C2D23F59EE24A40F0F96184F03844402C2D23F59EE24A40
38786	12651	40.414064000000003	40.453572000000001	53.84646	53.815382999999997	Центральная	0103000020E61000000100000005000000B939950C00354440705B5B785EE84A40B939950C00354440A3AF20CD58EC4A40CF30B5A50E3A4440A3AF20CD58EC4A40CF30B5A50E3A4440705B5B785EE84A40B939950C00354440705B5B785EE84A40
38607	12250	40.535201999999998	40.572499999999998	53.765425	53.750306999999999	Школьная	0103000020E610000001000000050000007C60C77F81444440DD7A4D0F0AE04A407C60C77F8144444039454772F9E14A40E17A14AE4749444039454772F9E14A40E17A14AE47494440DD7A4D0F0AE04A407C60C77F81444440DD7A4D0F0AE04A40
38670	12587	40.393428999999998	40.418376000000002	53.662129	53.641278	Центральная	0103000020E610000001000000050000002426A8E15B32444078D2C26515D24A402426A8E15B324440D95DA0A4C0D44A4035B742588D354440D95DA0A4C0D44A4035B742588D35444078D2C26515D24A402426A8E15B32444078D2C26515D24A40
38663	12106	40.677028	40.702072999999999	53.818440000000002	53.801712999999999	Центральная	0103000020E61000000100000005000000F73C7FDAA856444097E315889EE64A40F73C7FDAA85644407FDE54A4C2E84A40CA332F87DD5944407FDE54A4C2E84A40CA332F87DD59444097E315889EE64A40F73C7FDAA856444097E315889EE64A40
38605	12342	40.605781999999998	40.632722999999999	53.621639000000002	53.599741999999999	Школьный переулок	0103000020E61000000100000005000000B340BB438A4D4440D1048A58C4CC4A40B340BB438A4D44408675E3DD91CF4A40A8363811FD5044408675E3DD91CF4A40A8363811FD504440D1048A58C4CC4A40B340BB438A4D4440D1048A58C4CC4A40
38784	12583	40.447400000000002	40.46799	53.666097999999998	53.64723	Центральная	0103000020E610000001000000050000007E1D386744394440BB7EC16ED8D24A407E1D3867443944402BF702B342D54A40726DA818E73B44402BF702B342D54A40726DA818E73B4440BB7EC16ED8D24A407E1D386744394440BB7EC16ED8D24A40
38606	8776	40.366605999999997	40.391776999999998	53.777633000000002	53.757680999999998	Аничкова	0103000020E61000000100000005000000394206F2EC2E444079E6E5B0FBE04A40394206F2EC2E44402BA5677A89E34A409929ADBF253244402BA5677A89E34A409929ADBF2532444079E6E5B0FBE04A40394206F2EC2E444079E6E5B0FBE04A40
38785	12096	40.647382999999998	40.677098999999998	53.759911000000002	53.742842000000003	Новоселов	0103000020E61000000100000005000000417E3672DD524440310C587215DF4A40417E3672DD524440726F7EC344E14A40C093162EAB564440726F7EC344E14A40C093162EAB564440310C587215DF4A40417E3672DD524440310C587215DF4A40
38783	12013	40.714128000000002	40.744346999999998	53.797507000000003	53.760539000000001	Центральная	0103000020E610000001000000050000003694DA8B685B4440912A8A5759E14A403694DA8B685B444061AA99B514E64A4017F032C3465F444061AA99B514E64A4017F032C3465F4440912A8A5759E14A403694DA8B685B4440912A8A5759E14A40
38681	11988	40.527538999999997	40.545074	53.628005000000002	53.604641999999998	Центральная	0103000020E61000000100000005000000A92EE06586434440DEE4B7E864CD4A40A92EE06586434440BC5CC47762D04A4030F31DFCC4454440BC5CC47762D04A4030F31DFCC4454440DEE4B7E864CD4A40A92EE06586434440DEE4B7E864CD4A40
38679	11899	40.568942	40.592055999999999	53.560476000000001	53.541195999999999	Солнечная	0103000020E6100000010000000500000011A96917D3484440EE5C18E945C54A4011A96917D3484440B11875ADBDC74A4046B3B27DC84B4440B11875ADBDC74A4046B3B27DC84B4440EE5C18E945C54A4011A96917D3484440EE5C18E945C54A40
38721	11337	39.953498000000003	39.972416000000003	54.312075	54.292819999999999	Колхозная	0103000020E610000001000000050000009566F3380CFA4340AFCE31207B254B409566F3380CFA43401973D712F2274B40B70DA32078FC43401973D712F2274B40B70DA32078FC4340AFCE31207B254B409566F3380CFA4340AFCE31207B254B40
38202	10978	39.882432000000001	39.928452	54.247948999999998	54.212729000000003	Школьная	0103000020E61000000100000005000000D1782288F3F0434095F430B43A1B4B40D1782288F3F04340B709F7CABC1F4B40F1F3DF83D7F64340B709F7CABC1F4B40F1F3DF83D7F6434095F430B43A1B4B40D1782288F3F0434095F430B43A1B4B40
38275	10978	39.882432000000001	39.928452	54.247948999999998	54.212729000000003	Советская	0103000020E61000000100000005000000D1782288F3F0434095F430B43A1B4B40D1782288F3F04340B709F7CABC1F4B40F1F3DF83D7F64340B709F7CABC1F4B40F1F3DF83D7F6434095F430B43A1B4B40D1782288F3F0434095F430B43A1B4B40
38061	10978	39.882432000000001	39.928452	54.247948999999998	54.212729000000003	Денисова	0103000020E61000000100000005000000D1782288F3F0434095F430B43A1B4B40D1782288F3F04340B709F7CABC1F4B40F1F3DF83D7F64340B709F7CABC1F4B40F1F3DF83D7F6434095F430B43A1B4B40D1782288F3F0434095F430B43A1B4B40
38674	11219	39.801844000000003	39.837318000000003	54.155735999999997	54.139882999999998	Новая	0103000020E61000000100000005000000363FFED2A2E643401822A7AFE7114B40363FFED2A2E64340A9674128EF134B40132D793C2DEB4340A9674128EF134B40132D793C2DEB43401822A7AFE7114B40363FFED2A2E643401822A7AFE7114B40
38323	9578	39.978937999999999	39.997272000000002	54.171512999999997	54.159948	Советская	0103000020E61000000100000005000000E46723D74DFD4340C287122D79144B40E46723D74DFD43405FEB5223F4154B40B79BE09BA6FF43405FEB5223F4154B40B79BE09BA6FF4340C287122D79144B40E46723D74DFD4340C287122D79144B40
38088	6746	39.954019000000002	39.968086	54.269697000000001	54.258184999999997	Весенняя	0103000020E610000001000000050000009E616A4B1DFA4340ACA8C1340C214B409E616A4B1DFA4340276A696E85224B4094DBF63DEAFB4340276A696E85224B4094DBF63DEAFB4340ACA8C1340C214B409E616A4B1DFA4340ACA8C1340C214B40
38795	11102	39.740524999999998	39.766872999999997	54.243188000000004	54.230569000000003	Молодежная	0103000020E61000000100000005000000696FF085C9DE4340583CF548831D4B40696FF085C9DE4340CC63CDC8201F4B40BB97FBE428E24340CC63CDC8201F4B40BB97FBE428E24340583CF548831D4B40696FF085C9DE4340583CF548831D4B40
38458	11682	40.181283000000001	40.208556000000002	54.165246000000003	54.149608999999998	Речная	0103000020E610000001000000050000000F29064834174440F817416326134B400F29064834174440BDE5EAC726154B403AB187F6B11A4440BDE5EAC726154B403AB187F6B11A4440F817416326134B400F29064834174440F817416326134B40
38277	11470	40.092745000000001	40.127392999999998	54.305719000000003	54.289315000000002	Центральная	0103000020E610000001000000050000000BEF7211DF0B4440029F1F4608254B400BEF7211DF0B44400762D9CC21274B40A25EF0694E1044400762D9CC21274B40A25EF0694E104440029F1F4608254B400BEF7211DF0B4440029F1F4608254B40
38539	11732	40.191972999999997	40.208438999999998	54.225631999999997	54.211255000000001	Молодежная	0103000020E61000000100000005000000855B3E9292184440E90E62670A1B4B40855B3E92921844402D776682E11C4B40001B1021AE1A44402D776682E11C4B40001B1021AE1A4440E90E62670A1B4B40855B3E9292184440E90E62670A1B4B40
38604	11567	39.931883999999997	39.972622999999999	54.181657999999999	54.166606000000002	Колхозная	0103000020E6100000010000000500000034D593F947F74340A0A86C5853154B4034D593F947F743404487C09140174B40302B14E97EFC43404487C09140174B40302B14E97EFC4340A0A86C5853154B4034D593F947F74340A0A86C5853154B40
38629	11653	40.203246999999998	40.218096000000003	54.152683000000003	54.139018	Центральная	0103000020E610000001000000050000004B0169FF031A444015C78157CB114B404B0169FF031A4440DDD3D51D8B134B40B8B1D991EA1B4440DDD3D51D8B134B40B8B1D991EA1B444015C78157CB114B404B0169FF031A444015C78157CB114B40
38782	10930	40.309247999999997	40.354118999999997	54.566009999999999	54.548943000000001	Школьная	0103000020E610000001000000050000003C2D3F70952744401F2FA4C343464B403C2D3F7095274440BF9A030473484B4034F279C5532D4440BF9A030473484B4034F279C5532D44401F2FA4C343464B403C2D3F70952744401F2FA4C343464B40
38749	257	40.247686999999999	40.283268999999997	54.216940999999998	54.202950999999999	Школьная	0103000020E610000001000000050000007A522635B41F444062D8614CFA194B407A522635B41F4440AD1402B9C41B4B403D7C992842244440AD1402B9C41B4B403D7C99284224444062D8614CFA194B407A522635B41F444062D8614CFA194B40
38546	9740	40.471080000000001	40.502521000000002	54.444670000000002	54.434066999999999	Кооперативная	0103000020E610000001000000050000005CE674594C3C4440ECA2E8818F374B405CE674594C3C444094C151F2EA384B40D046AE9B5240444094C151F2EA384B40D046AE9B52404440ECA2E8818F374B405CE674594C3C4440ECA2E8818F374B40
38457	10743	40.211143	40.242207000000001	54.407029999999999	54.388150000000003	Школьная	0103000020E61000000100000005000000C1E3DBBB061B4440A1F831E6AE314B40C1E3DBBB061B4440D53E1D8F19344B405FEE93A3001F4440D53E1D8F19344B405FEE93A3001F4440A1F831E6AE314B40C1E3DBBB061B4440A1F831E6AE314B40
38535	9354	40.356751000000003	40.392504000000002	54.291207	54.269928	Административная	0103000020E610000001000000050000005CE84A04AA2D444029232E008D224B405CE84A04AA2D4440E2AE5E4546254B404CC631923D324440E2AE5E4546254B404CC631923D32444029232E008D224B405CE84A04AA2D444029232E008D224B40
38813	54692	40.559339000000001	40.587133000000001	54.496557000000003	54.473471000000004	Школьная	0103000020E610000001000000050000004D309C6B984744405E4D9EB29A3C4B404D309C6B98474440C9CC052E8F3F4B4081B3942C274B4440C9CC052E8F3F4B4081B3942C274B44405E4D9EB29A3C4B404D309C6B984744405E4D9EB29A3C4B40
38552	10187	40.527323000000003	40.544930000000001	54.557291999999997	54.537526	Федина	0103000020E61000000100000005000000DDB6EF517F434440F65FE7A6CD444B40DDB6EF517F4344404529215855474B40FD4D2844C04544404529215855474B40FD4D2844C0454440F65FE7A6CD444B40DDB6EF517F434440F65FE7A6CD444B40
38106	8266	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	Советская	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
38286	8266	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	Рязанское шоссе	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
38534	8266	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	Луначарского	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
38545	8266	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	Ленина	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
37969	8266	40.353076999999999	40.401766000000002	54.426403999999998	54.398555999999999	Войкова	0103000020E6100000010000000500000022FC8BA0312D4440F2CF0CE203334B4022FC8BA0312D44401971016894364B4087527B116D3344401971016894364B4087527B116D334440F2CF0CE203334B4022FC8BA0312D4440F2CF0CE203334B40
38541	10499	40.119290999999997	40.137588999999998	54.414974000000001	54.394153000000003	Центральная	0103000020E6100000010000000500000083DA6FED440F4440664F029B73324B4083DA6FED440F44405C5837DE1D354B4009A52F849C1144405C5837DE1D354B4009A52F849C114440664F029B73324B4083DA6FED440F4440664F029B73324B40
38549	9405	40.437887000000003	40.456643999999997	54.347278000000003	54.336129999999997	Почтовая	0103000020E61000000100000005000000FA2B64AE0C3844402C9ACE4E062B4B40FA2B64AE0C384440664F029B732C4B4012F5824F733A4440664F029B732C4B4012F5824F733A44402C9ACE4E062B4B40FA2B64AE0C3844402C9ACE4E062B4B40
38781	10560	40.189664999999998	40.220692	54.474496000000002	54.441837	Назина	0103000020E61000000100000005000000111956F146184440D594641D8E384B40111956F1461844409A0AF148BC3C4B40923EADA23F1C44409A0AF148BC3C4B40923EADA23F1C4440D594641D8E384B40111956F146184440D594641D8E384B40
38603	10402	40.219110999999998	40.254029000000003	54.338937999999999	54.308666000000002	Школьная	0103000020E61000000100000005000000D09849D40B1C44408EB1135E82274B40D09849D40B1C444092AF0452622B4B40289EB3058420444092AF0452622B4B40289EB305842044408EB1135E82274B40D09849D40B1C44408EB1135E82274B40
38513	10101	40.261215	40.288991000000003	54.474286999999997	54.449674999999999	Рязанская	0103000020E61000000100000005000000C11C3D7E6F214440166A4DF38E394B40C11C3D7E6F2144407FF5B86FB53C4B404FEB36A8FD2444407FF5B86FB53C4B404FEB36A8FD244440166A4DF38E394B40C11C3D7E6F214440166A4DF38E394B40
38538	10341	40.168716000000003	40.203741000000001	54.357877999999999	54.335200999999998	Мартынова	0103000020E61000000100000005000000EE27637C98154440124BCADDE72A4B40EE27637C981544409CFA40F2CE2D4B405BED612F141A44409CFA40F2CE2D4B405BED612F141A4440124BCADDE72A4B40EE27637C98154440124BCADDE72A4B40
38551	54651	40.559311999999998	40.599691999999997	54.474282000000002	54.460813000000002	Центральная	0103000020E6100000010000000500000053211E89974744402C499EEBFB3A4B4053211E89974744406E8AC745B53C4B401FD61BB5C24C44406E8AC745B53C4B401FD61BB5C24C44402C499EEBFB3A4B4053211E89974744402C499EEBFB3A4B40
38673	10191	40.225687000000001	40.255394000000003	54.589596999999998	54.563541000000001	Школьная	0103000020E61000000100000005000000F110C64FE31C4440427A8A1C22484B40F110C64FE31C4440EC681CEA774B4B401DCC26C0B0204440EC681CEA774B4B401DCC26C0B0204440427A8A1C22484B40F110C64FE31C4440427A8A1C22484B40
38547	10048	40.416713999999999	40.435550999999997	54.526732000000003	54.507866	Центральная	0103000020E6100000010000000500000086E464E2563544400B60CAC001414B4086E464E256354440DBE044F46B434B40BB5E9A22C0374440DBE044F46B434B40BB5E9A22C03744400B60CAC001414B4086E464E2563544400B60CAC001414B40
38485	9939	40.873175000000003	40.899971000000001	54.679161000000001	54.666775000000001	Молодежная	0103000020E61000000100000005000000A857CA32C46F44402C6519E258554B40A857CA32C46F4440FDDB65BFEE564B40992CEE3F32734440FDDB65BFEE564B40992CEE3F327344402C6519E258554B40A857CA32C46F44402C6519E258554B40
38537	9724	40.491112000000001	40.521628	54.439816	54.413584999999998	Центральная	0103000020E610000001000000050000002A560DC2DC3E4440DE8E705AF0344B402A560DC2DC3E4440F72004E44B384B40C556D0B4C4424440F72004E44B384B40C556D0B4C4424440DE8E705AF0344B402A560DC2DC3E4440DE8E705AF0344B40
38660	10687	40.215589999999999	40.231597999999998	54.433940999999997	54.408423999999997	Центральная	0103000020E610000001000000050000001DACFF73981B44406473D53C47344B401DACFF73981B44405FB2F1608B374B40D5E8D500A51D44405FB2F1608B374B40D5E8D500A51D44406473D53C47344B401DACFF73981B44406473D53C47344B40
38454	9267	40.334122999999998	40.387770000000003	54.333347000000003	54.281393999999999	Интернатская	0103000020E61000000100000005000000B3EBDE8AC42A444033A5F5B704244B40B3EBDE8AC42A4440209C4F1DAB2A4B405A2F8672A2314440209C4F1DAB2A4B405A2F8672A231444033A5F5B704244B40B3EBDE8AC42A444033A5F5B704244B40
38750	9220	40.517432999999997	40.549017999999997	54.418432000000003	54.399934000000002	Василия Игонина	0103000020E61000000100000005000000826F9A3E3B4244407C478D0931334B40826F9A3E3B424440C9CC052E8F354B402975C93846464440C9CC052E8F354B402975C938464644407C478D0931334B40826F9A3E3B4244407C478D0931334B40
38532	8964	40.844213000000003	40.887467000000001	54.576954999999998	54.525624999999998	Советская	0103000020E61000000100000005000000D5EDEC2B0F6C4440E17A14AE47434B40D5EDEC2B0F6C4440C02154A9D9494B40BEA3C68498714440C02154A9D9494B40BEA3C68498714440E17A14AE47434B40D5EDEC2B0F6C4440E17A14AE47434B40
38531	8964	40.844213000000003	40.887467000000001	54.576954999999998	54.525624999999998	Красная	0103000020E61000000100000005000000D5EDEC2B0F6C4440E17A14AE47434B40D5EDEC2B0F6C4440C02154A9D9494B40BEA3C68498714440C02154A9D9494B40BEA3C68498714440E17A14AE47434B40D5EDEC2B0F6C4440E17A14AE47434B40
38536	8964	40.844213000000003	40.887467000000001	54.576954999999998	54.525624999999998	Банникова	0103000020E61000000100000005000000D5EDEC2B0F6C4440E17A14AE47434B40D5EDEC2B0F6C4440C02154A9D9494B40BEA3C68498714440C02154A9D9494B40BEA3C68498714440E17A14AE47434B40D5EDEC2B0F6C4440E17A14AE47434B40
38658	8704	40.827567000000002	40.849235	54.512721999999997	54.499448999999998	Молодежная	0103000020E61000000100000005000000DA1F28B7ED6944408C82E0F1ED3F4B40DA1F28B7ED69444048F8DEDFA0414B402DCF83BBB36C444048F8DEDFA0414B402DCF83BBB36C44408C82E0F1ED3F4B40DA1F28B7ED6944408C82E0F1ED3F4B40
38599	8825	40.221375000000002	40.235137000000002	54.304226999999997	54.290543999999997	Дачная	0103000020E6100000010000000500000075931804561C44404606B98B30254B4075931804561C4440B4C70BE9F0264B402F8A1EF8181E4440B4C70BE9F0264B402F8A1EF8181E44404606B98B30254B4075931804561C44404606B98B30254B40
38548	10002	40.421402999999998	40.442379000000003	54.486130000000003	54.470132999999997	Магистральная	0103000020E61000000100000005000000D8B79388F03544409BE271512D3C4B40D8B79388F035444060CD0182393E4B40F6B704E09F38444060CD0182393E4B40F6B704E09F3844409BE271512D3C4B40D8B79388F03544409BE271512D3C4B40
38778	10498	40.126396	40.147075000000001	54.446288000000003	54.437103999999998	Молодежная	0103000020E61000000100000005000000302C7FBE2D104440B3791C06F3374B40302C7FBE2D104440734C16F71F394B409487855AD3124440734C16F71F394B409487855AD3124440B3791C06F3374B40302C7FBE2D104440B3791C06F3374B40
38715	9577	40.667001999999997	40.715834999999998	54.510579	54.491751999999998	Перышкина	0103000020E61000000100000005000000EC2E5052605544400DDFC2BAF13E4B40EC2E5052605544401F8315A75A414B40842A357BA05B44401F8315A75A414B40842A357BA05B44400DDFC2BAF13E4B40EC2E5052605544400DDFC2BAF13E4B40
38657	8649	40.635364000000003	40.669257000000002	54.448506999999999	54.430211999999997	Школьная	0103000020E610000001000000050000002387889B53514440622CD32F11374B402387889B53514440778368AD68394B403ECF9F36AA554440778368AD68394B403ECF9F36AA554440622CD32F11374B402387889B53514440622CD32F11374B40
38043	8778	40.078040000000001	40.39705	54.460577000000001	54.419955999999999	Центральная	0103000020E61000000100000005000000D2E3F736FD09444026E1421EC1354B40D2E3F736FD0944401825E82FF43A4B403B70CE88D23244401825E82FF43A4B403B70CE88D232444026E1421EC1354B40D2E3F736FD09444026E1421EC1354B40
38716	8598	40.756582000000002	40.791077999999999	54.463676	54.447465999999999	Школьная	0103000020E61000000100000005000000035FD1ADD76044403509DE9046394B40035FD1ADD760444055F833BC593B4B40E44A3D0B4265444055F833BC593B4B40E44A3D0B426544403509DE9046394B40035FD1ADD76044403509DE9046394B40
38779	10926	40.465474	40.501730000000002	54.669570999999998	54.648744999999998	Масловка	0103000020E61000000100000005000000B491EBA6943B4440C5387F130A534B40B491EBA6943B4440CDACA580B4554B4007B64AB038404440CDACA580B4554B4007B64AB038404440C5387F130A534B40B491EBA6943B4440C5387F130A534B40
38601	9144	40.512374999999999	40.531474000000003	54.425083999999998	54.408937999999999	Центральная	0103000020E61000000100000005000000DD24068195414440BB0B941458344B40DD24068195414440C4060B2769364B4050560C5707444440C4060B2769364B4050560C5707444440BB0B941458344B40DD24068195414440BB0B941458344B40
38776	7023	39.811006999999996	39.847371000000003	53.705542999999999	53.696725999999998	Октябрьская	0103000020E61000000100000005000000DDE9CE13CFE74340EE224C512ED94A40DDE9CE13CFE74340FB75A73B4FDA4A40174A26A776EC4340FB75A73B4FDA4A40174A26A776EC4340EE224C512ED94A40DDE9CE13CFE74340EE224C512ED94A40
38218	5435	39.556415000000001	39.593389999999999	53.752702999999997	53.729872999999998	Большак	0103000020E610000001000000050000007E00529B38C74340E09D7C7A6CDD4A407E00529B38C74340F04C689258E04A4000E31934F4CB4340F04C689258E04A4000E31934F4CB4340E09D7C7A6CDD4A407E00529B38C74340E09D7C7A6CDD4A40
38461	6747	39.798986999999997	39.816873000000001	53.758611999999999	53.751770999999998	Школьная	0103000020E61000000100000005000000EE76BD3445E64340658A39083AE04A40EE76BD3445E64340342DB1321AE14A4022FE614B8FE84340342DB1321AE14A4022FE614B8FE84340658A39083AE04A40EE76BD3445E64340658A39083AE04A40
38526	6747	39.798986999999997	39.816873000000001	53.758611999999999	53.751770999999998	Гагарина	0103000020E61000000100000005000000EE76BD3445E64340658A39083AE04A40EE76BD3445E64340342DB1321AE14A4022FE614B8FE84340342DB1321AE14A4022FE614B8FE84340658A39083AE04A40EE76BD3445E64340658A39083AE04A40
38808	54587	39.661949	39.697584999999997	53.931212000000002	53.913252999999997	Мичурина	0103000020E61000000100000005000000594FADBEBAD44340A8FC6B79E5F44A40594FADBEBAD4434046D26EF431F74A400F971C774AD9434046D26EF431F74A400F971C774AD94340A8FC6B79E5F44A40594FADBEBAD44340A8FC6B79E5F44A40
38091	5428	39.479115	39.556711999999997	53.754151	53.734927999999996	Школьная	0103000020E61000000100000005000000F302ECA353BD43401475E61E12DE4A40F302ECA353BD4340739F1C0588E04A4037A5BC5642C74340739F1C0588E04A4037A5BC5642C743401475E61E12DE4A40F302ECA353BD43401475E61E12DE4A40
38525	6696	39.586095999999998	39.623367000000002	53.744599000000001	53.730389000000002	Клубная	0103000020E610000001000000050000008028983105CB4340D82D02637DDD4A408028983105CB434031D120054FDF4A40EC33677DCACF434031D120054FDF4A40EC33677DCACF4340D82D02637DDD4A408028983105CB4340D82D02637DDD4A40
38772	5960	38.956907000000001	38.993684000000002	53.817701	53.798119	Школьная	0103000020E610000001000000050000002028B7ED7B7A43407AA86DC328E64A402028B7ED7B7A43400874266DAAE84A407C478D09317F43400874266DAAE84A407C478D09317F43407AA86DC328E64A402028B7ED7B7A43407AA86DC328E64A40
38654	7232	39.608364999999999	39.641207000000001	53.918705000000003	53.897658	Карла Маркса	0103000020E61000000100000005000000F98381E7DECD4340137F1475E6F24A40F98381E7DECD4340FAD51C2098F54A40AF7B2B1213D24340FAD51C2098F54A40AF7B2B1213D24340137F1475E6F24A40F98381E7DECD4340137F1475E6F24A40
38652	6345	39.455129999999997	39.478397000000001	53.785411000000003	53.767798999999997	Первомайская	0103000020E61000000100000005000000D8B628B341BA43406473D53C47E24A40D8B628B341BA43409775FF5888E44A4094C0E61C3CBD43409775FF5888E44A4094C0E61C3CBD43406473D53C47E24A40D8B628B341BA43406473D53C47E24A40
38598	6557	39.647145000000002	39.672243999999999	53.692968	53.671939999999999	40 лет Победы	0103000020E610000001000000050000008D62B9A5D5D24340E76F422102D64A408D62B9A5D5D243405796E82CB3D84A40537765170CD643405796E82CB3D84A40537765170CD64340E76F422102D64A408D62B9A5D5D24340E76F422102D64A40
38038	5282	39.552444999999999	39.573025000000001	53.718561999999999	53.709209999999999	Горняцкая	0103000020E610000001000000050000005BEB8B84B6C6434082FFAD64C7DA4A405BEB8B84B6C64340FD12F1D6F9DB4A402C6519E258C94340FD12F1D6F9DB4A402C6519E258C9434082FFAD64C7DA4A405BEB8B84B6C6434082FFAD64C7DA4A40
38773	6496	38.971890000000002	39.407860999999997	53.910283	53.745829000000001	Набережная	0103000020E610000001000000050000009CA73AE4667C434046B41D5377DF4A409CA73AE4667C4340698D412784F44A402C280CCA34B44340698D412784F44A402C280CCA34B4434046B41D5377DF4A409CA73AE4667C434046B41D5377DF4A40
38746	5055	39.237172000000001	39.302236999999998	53.846066999999998	53.832858999999999	Центральная	0103000020E6100000010000000500000072C3EFA65B9E4340F296AB1F9BEA4A4072C3EFA65B9E4340C79C67EC4BEC4A401152B7B3AFA64340C79C67EC4BEC4A401152B7B3AFA64340F296AB1F9BEA4A4072C3EFA65B9E4340F296AB1F9BEA4A40
38190	5055	39.237172000000001	39.302236999999998	53.846066999999998	53.832858999999999	Первомайская	0103000020E6100000010000000500000072C3EFA65B9E4340F296AB1F9BEA4A4072C3EFA65B9E4340C79C67EC4BEC4A401152B7B3AFA64340C79C67EC4BEC4A401152B7B3AFA64340F296AB1F9BEA4A4072C3EFA65B9E4340F296AB1F9BEA4A40
38748	6500	39.387729999999998	39.446919999999999	53.810200000000002	53.795836999999999	Центральная	0103000020E61000000100000005000000CBD6FA22A1B143402FF99FFCDDE54A40CBD6FA22A1B143400F9C33A2B4E74A40D3F6AFAC34B943400F9C33A2B4E74A40D3F6AFAC34B943402FF99FFCDDE54A40CBD6FA22A1B143402FF99FFCDDE54A40
38815	54693	\N	\N	\N	\N	Рабочая	\N
38600	6075	38.894689	38.941068999999999	53.856732000000001	53.832880000000003	Молодежная	0103000020E61000000100000005000000A48B4D2B857243400ABFD4CF9BEA4A40A48B4D2B85724340E5B7E864A9ED4A40C423F1F274784340E5B7E864A9ED4A40C423F1F2747843400ABFD4CF9BEA4A40A48B4D2B857243400ABFD4CF9BEA4A40
38777	7220	39.586545000000001	39.612442999999999	53.960045999999998	53.949613999999997	Советская	0103000020E61000000100000005000000F05014E813CB434070E998F38CF94A40F05014E813CB4340EB538EC9E2FA4A4002D53F8864CE4340EB538EC9E2FA4A4002D53F8864CE434070E998F38CF94A40F05014E813CB434070E998F38CF94A40
38528	7139	39.433174999999999	39.486975000000001	53.854405999999997	53.834834999999998	Советская	0103000020E61000000100000005000000EF38454772B7434030478FDFDBEA4A40EF38454772B74340CAC0012D5DED4A401C7C613255BE4340CAC0012D5DED4A401C7C613255BE434030478FDFDBEA4A40EF38454772B7434030478FDFDBEA4A40
9916	5114	39.187719999999999	39.311551999999999	53.838208999999999	53.786161	Молодежная	0103000020E610000001000000050000000E677E3507984340013274ECA0E44A400E677E35079843403F1BB96E4AEB4A406F8099EFE0A743403F1BB96E4AEB4A406F8099EFE0A74340013274ECA0E44A400E677E3507984340013274ECA0E44A40
38189	6288	39.476078999999999	39.523994999999999	53.785240999999999	53.766010999999999	Мира	0103000020E61000000100000005000000FCA71B28F0BC434029B000A60CE24A40FCA71B28F0BC43403A3DEFC682E44A403E22A64412C343403A3DEFC682E44A403E22A64412C3434029B000A60CE24A40FCA71B28F0BC434029B000A60CE24A40
38653	6393	39.355462000000003	39.386957000000002	53.750146999999998	53.728434	Центральная	0103000020E61000000100000005000000427C60C77FAD4340B1A547533DDD4A40427C60C77FAD4340A41820D104E04A40A9FA95CE87B14340A41820D104E04A40A9FA95CE87B14340B1A547533DDD4A40427C60C77FAD4340B1A547533DDD4A40
38524	5971	38.847582000000003	38.894249000000002	53.897095	53.871392	Школьная	0103000020E61000000100000005000000D25625917D6C43407EFFE6C589EF4A40D25625917D6C4340DB334B02D4F24A4088BD50C076724340DB334B02D4F24A4088BD50C0767243407EFFE6C589EF4A40D25625917D6C43407EFFE6C589EF4A40
38747	5919	39.154041999999997	39.213816000000001	53.940043000000003	53.921213000000002	Советская	0103000020E61000000100000005000000EF1AF4A5B793434035D3BD4EEAF54A40EF1AF4A5B7934340B8EA3A5453F84A4047AE9B525E9B4340B8EA3A5453F84A4047AE9B525E9B434035D3BD4EEAF54A40EF1AF4A5B793434035D3BD4EEAF54A40
38650	6186	39.367364999999999	39.430641999999999	53.914042999999999	53.889237000000001	Школьная	0103000020E61000000100000005000000F758FAD005AF434053B29C84D2F14A40F758FAD005AF4340A1116C5CFFF44A405B24ED461FB74340A1116C5CFFF44A405B24ED461FB7434053B29C84D2F14A40F758FAD005AF434053B29C84D2F14A40
38522	6140	39.423321000000001	39.473239999999997	53.930242	53.911921999999997	Попова	0103000020E61000000100000005000000E25AED612FB643405F402FDCB9F44A40E25AED612FB64340CDAE7B2B12F74A405B94D92093BC4340CDAE7B2B12F74A405B94D92093BC43405F402FDCB9F44A40E25AED612FB643405F402FDCB9F44A40
38712	5728	39.056663999999998	39.089381000000003	53.773694999999996	53.753028	Казинка	0103000020E61000000100000005000000266E15C440874340747CB43863E04A40266E15C440874340130A117008E34A4020F12BD6708B4340130A117008E34A4020F12BD6708B4340747CB43863E04A40266E15C440874340747CB43863E04A40
38502	6615	39.627004999999997	39.662785	53.742393999999997	53.728360000000002	Церковная	0103000020E61000000100000005000000D8B628B341D0434077DB85E63ADD4A40D8B628B341D04340915F3FC406DF4A40C2A38D23D6D44340915F3FC406DF4A40C2A38D23D6D4434077DB85E63ADD4A40D8B628B341D0434077DB85E63ADD4A40
38744	4974	39.163500999999997	39.192624000000002	53.797767999999998	53.780506000000003	Советская	0103000020E6100000010000000500000080EECB99ED944340782AE09EE7E34A4080EECB99ED944340CDE506431DE64A405D363AE7A7984340CDE506431DE64A405D363AE7A7984340782AE09EE7E34A4080EECB99ED944340782AE09EE7E34A40
38659	7079	39.489994000000003	39.540219	53.933131000000003	53.908867000000001	Молодежна	0103000020E610000001000000050000003D9E961FB8BE4340F2B4FCC055F44A403D9E961FB8BE434020F12BD670F74A40C3D66CE525C5434020F12BD670F74A40C3D66CE525C54340F2B4FCC055F44A403D9E961FB8BE4340F2B4FCC055F44A40
38656	6881	39.748727000000002	39.787506999999998	53.721145999999997	53.706235999999997	Гагарина	0103000020E61000000100000005000000EC504D49D6DF434001A1F5F065DA4A40EC504D49D6DF434013D21A834EDC4A407F2F8507CDE4434013D21A834EDC4A407F2F8507CDE4434001A1F5F065DA4A40EC504D49D6DF434001A1F5F065DA4A40
38523	5810	39.017696000000001	39.060482	53.848658999999998	53.819381	Базарная	0103000020E6100000010000000500000090A2CEDC438243405DFB027AE1E84A4090A2CEDC43824340603AADDBA0EC4A4093FFC9DFBD874340603AADDBA0EC4A4093FFC9DFBD8743405DFB027AE1E84A4090A2CEDC438243405DFB027AE1E84A40
38075	5491	39.585079999999998	39.643076000000001	53.848452000000002	53.824334	Школьная	0103000020E6100000010000000500000097C5C4E6E3CA43408D7DC9C683E94A4097C5C4E6E3CA4340E71C3C139AEC4A40D76B7A5050D24340E71C3C139AEC4A40D76B7A5050D243408D7DC9C683E94A4097C5C4E6E3CA43408D7DC9C683E94A40
38460	5593	39.635027000000001	39.666691999999998	53.886132000000003	53.871228000000002	Центральная	0103000020E61000000100000005000000DB89929048D1434004AE2B6684EF4A40DB89929048D1434034F8FBC56CF14A409E40D82956D5434034F8FBC56CF14A409E40D82956D5434004AE2B6684EF4A40DB89929048D1434004AE2B6684EF4A40
38775	5654	39.046360999999997	39.071559000000001	53.912219	53.891008999999997	Запрудная	0103000020E61000000100000005000000A9674128EF85434088B839950CF24A40A9674128EF85434019E59997C3F44A40035E66D82889434019E59997C3F44A40035E66D82889434088B839950CF24A40A9674128EF85434088B839950CF24A40
38774	6283	39.292552999999998	39.320256999999998	53.895249	53.875999999999998	Ленина	0103000020E6100000010000000500000060AC6F6072A54340E3A59BC420F04A4060AC6F6072A543406B63EC8497F24A4054A86E2EFEA843406B63EC8497F24A4054A86E2EFEA84340E3A59BC420F04A4060AC6F6072A54340E3A59BC420F04A40
38087	3740	41.780455000000003	41.829206999999997	54.293824000000001	54.262971	Больничная	0103000020E61000000100000005000000F67F0EF3E5E34440F165A208A9214B40F67F0EF3E5E34440D4635B069C254B40A04E797423EA4440D4635B069C254B40A04E797423EA4440F165A208A9214B40F67F0EF3E5E34440F165A208A9214B40
38199	881	40.950071000000001	41.039937999999999	53.759799000000001	53.698948999999999	Ленина	0103000020E6100000010000000500000063F030ED9B79444034492C2977D94A4063F030ED9B7944404A44F81741E14A400FEF39B01C8544404A44F81741E14A400FEF39B01C85444034492C2977D94A4063F030ED9B79444034492C2977D94A40
38265	881	40.950071000000001	41.039937999999999	53.759799000000001	53.698948999999999	Казинка	0103000020E6100000010000000500000063F030ED9B79444034492C2977D94A4063F030ED9B7944404A44F81741E14A400FEF39B01C8544404A44F81741E14A400FEF39B01C85444034492C2977D94A4063F030ED9B79444034492C2977D94A40
38519	881	40.950071000000001	41.039937999999999	53.759799000000001	53.698948999999999	1 Мая	0103000020E6100000010000000500000063F030ED9B79444034492C2977D94A4063F030ED9B7944404A44F81741E14A400FEF39B01C8544404A44F81741E14A400FEF39B01C85444034492C2977D94A4063F030ED9B79444034492C2977D94A40
75045	9314	40.850447000000003	40.868017999999999	53.499862	53.487825000000001	Курская	0103000020E610000001000000050000009CFD8172DB6C4440EA95B20C71BE4A409CFD8172DB6C4440AF415F7AFBBF4A406F2BBD361B6F4440AF415F7AFBBF4A406F2BBD361B6F4440EA95B20C71BE4A409CFD8172DB6C4440EA95B20C71BE4A40
38245	30086	40.653213000000001	40.716876999999997	53.966836999999998	53.931811000000003	Советская	0103000020E610000001000000050000003929CC7B9C534440CB86359545F74A403929CC7B9C53444008C89750C1FB4A40962023A0C25B444008C89750C1FB4A40962023A0C25B4440CB86359545F74A403929CC7B9C534440CB86359545F74A40
38516	30086	40.653213000000001	40.716876999999997	53.966836999999998	53.931811000000003	Свободы	0103000020E610000001000000050000003929CC7B9C534440CB86359545F74A403929CC7B9C53444008C89750C1FB4A40962023A0C25B444008C89750C1FB4A40962023A0C25B4440CB86359545F74A403929CC7B9C534440CB86359545F74A40
38518	30086	40.653213000000001	40.716876999999997	53.966836999999998	53.931811000000003	Пролетарская	0103000020E610000001000000050000003929CC7B9C534440CB86359545F74A403929CC7B9C53444008C89750C1FB4A40962023A0C25B444008C89750C1FB4A40962023A0C25B4440CB86359545F74A403929CC7B9C534440CB86359545F74A40
38743	30086	40.653213000000001	40.716876999999997	53.966836999999998	53.931811000000003	Гусева	0103000020E610000001000000050000003929CC7B9C534440CB86359545F74A403929CC7B9C53444008C89750C1FB4A40962023A0C25B444008C89750C1FB4A40962023A0C25B4440CB86359545F74A403929CC7B9C534440CB86359545F74A40
38517	30086	40.665968999999997	40.686701999999997	53.939878999999998	53.924298999999998	Большая Дорога	0103000020E610000001000000050000002D93E1783E554440DD5CFC6D4FF64A402D93E1783E5544403D997FF44DF84A40840CE4D9E55744403D997FF44DF84A40840CE4D9E5574440DD5CFC6D4FF64A402D93E1783E554440DD5CFC6D4FF64A40
38806	54686	40.520136999999998	40.529586999999999	53.932527	53.929288	Центральная	0103000020E61000000100000005000000433866D9934244405A48C0E8F2F64A40433866D99342444089D1730B5DF74A4081B1BE81C943444089D1730B5DF74A4081B1BE81C94344405A48C0E8F2F64A40433866D9934244405A48C0E8F2F64A40
37968	14339	40.008636000000003	40.075839000000002	54.614896000000002	54.595857000000002	Лесная	0103000020E61000000100000005000000BDC804FC1A014440DD0BCC0A454C4B40BDC804FC1A0144407A3881E9B44E4B407461A417B50944407A3881E9B44E4B407461A417B5094440DD0BCC0A454C4B40BDC804FC1A014440DD0BCC0A454C4B40
38646	27976	39.956488999999998	39.996032999999997	54.630279000000002	54.614735000000003	Центральная	0103000020E61000000100000005000000EBFD463B6EFA4340715AF0A2AF4E4B40EBFD463B6EFA4340842D76FBAC504B404E5E64027EFF4340842D76FBAC504B404E5E64027EFF4340715AF0A2AF4E4B40EBFD463B6EFA4340715AF0A2AF4E4B40
38802	54682	40.058788999999997	40.09995	53.585659999999997	53.558444000000001	Центральная	0103000020E61000000100000005000000A92EE06586074440DF52CE177BC74A40A92EE06586074440A54929E8F6CA4A401B9E5E29CB0C4440A54929E8F6CA4A401B9E5E29CB0C4440DF52CE177BC74A40A92EE06586074440DF52CE177BC74A40
38771	27054	39.944837999999997	39.951872000000002	53.791778999999998	53.781533000000003	Есенина	0103000020E610000001000000050000004F029B73F0F8434055DFF94509E44A404F029B73F0F843406D54A70359E54A4033FD12F1D6F943406D54A70359E54A4033FD12F1D6F9434055DFF94509E44A404F029B73F0F8434055DFF94509E44A40
38739	26407	40.279558999999999	40.313442999999999	53.655704	53.643317000000003	Совхозная	0103000020E61000000100000005000000B726DD96C8234440FDFA213658D24A40B726DD96C82344409EEDD11BEED34A407F1475E61E2844409EEDD11BEED34A407F1475E61E284440FDFA213658D24A40B726DD96C8234440FDFA213658D24A40
38770	26421	40.092008999999997	40.112338000000001	53.687049000000002	53.672483999999997	Дорожная	0103000020E6100000010000000500000005F86EF3C60B4440A88AA9F413D64A4005F86EF3C60B4440F0DFBC38F1D74A408D0C7217610E4440F0DFBC38F1D74A408D0C7217610E4440A88AA9F413D64A4005F86EF3C60B4440A88AA9F413D64A40
38740	26888	39.906866000000001	39.948934000000001	53.597620999999997	53.567402000000001	Поповка	0103000020E610000001000000050000005BED612F14F44340AED7F4A0A0C84A405BED612F14F443408F334DD87ECC4A40FF0758AB76F943408F334DD87ECC4A40FF0758AB76F94340AED7F4A0A0C84A405BED612F14F44340AED7F4A0A0C84A40
38030	5337	40.019083999999999	40.165374	53.731876	53.686233000000001	площадь Свободы	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38048	5337	40.019083999999999	40.165374	53.731876	53.686233000000001	Совхозная	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38070	5337	40.019083999999999	40.165374	53.731876	53.686233000000001	Свободы	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38032	5337	40.019083999999999	40.165374	53.731876	53.686233000000001	Максима Горького	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38188	5337	40.019083999999999	40.165374	53.731876	53.686233000000001	Лермонтова	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38184	5337	40.019083999999999	40.165374	53.731876	53.686233000000001	Ленина	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38093	5337	40.019083999999999	40.165374	53.731876	53.686233000000001	Красной Армии	0103000020E610000001000000050000003DF0315871024440CE37A27BD6D74A403DF0315871024440185DDE1CAEDD4A40EACDA8F92A154440185DDE1CAEDD4A40EACDA8F92A154440CE37A27BD6D74A403DF0315871024440CE37A27BD6D74A40
38643	26347	40.148485999999998	40.169974000000003	53.597402000000002	53.581384	Центральная	0103000020E61000000100000005000000F9F4D89601134440763579CA6ACA4A40F9F4D89601134440524832AB77CC4A40CD9541B5C1154440524832AB77CC4A40CD9541B5C1154440763579CA6ACA4A40F9F4D89601134440763579CA6ACA4A40
38647	26968	40.076718999999997	40.099986000000001	53.811433000000001	53.775260000000003	Большая Дорога	0103000020E61000000100000005000000ACFD9DEDD1094440D0F23CB83BE34A40ACFD9DEDD109444095F25A09DDE74A4068075C57CC0C444095F25A09DDE74A4068075C57CC0C4440D0F23CB83BE34A40ACFD9DEDD1094440D0F23CB83BE34A40
38581	14257	40.074509999999997	40.105924000000002	53.838486000000003	53.805925000000002	Новая	0103000020E61000000100000005000000CB9C2E8B89094440B003E78C28E74A40CB9C2E8B89094440B2135E8253EB4A4046EEE9EA8E0D4440B2135E8253EB4A4046EEE9EA8E0D4440B003E78C28E74A40CB9C2E8B89094440B003E78C28E74A40
38495	26895	40.123818	40.186430999999999	53.771726999999998	53.747304	Новая	0103000020E61000000100000005000000FC53AA44D90F4440C21550A8A7DF4A40FC53AA44D90F4440583849F3C7E24A40F4FA93F8DC174440583849F3C7E24A40F4FA93F8DC174440C21550A8A7DF4A40FC53AA44D90F4440C21550A8A7DF4A40
38493	10501	40.287303000000001	40.335433999999999	53.751164000000003	53.722329000000002	Школьная	0103000020E6100000010000000500000077853E58C6244440E8F9D34675DC4A4077853E58C62444405EF7562426E04A40B5FB5580EF2A44405EF7562426E04A40B5FB5580EF2A4440E8F9D34675DC4A4077853E58C6244440E8F9D34675DC4A40
38741	13917	40.173827000000003	40.208942	53.643264000000002	53.610208999999998	Новая	0103000020E61000000100000005000000B61490F63F164440C85C19541BCE4A40B61490F63F164440DA58897956D24A406361889CBE1A4440DA58897956D24A406361889CBE1A4440C85C19541BCE4A40B61490F63F164440C85C19541BCE4A40
38645	10561	39.915705000000003	39.974544999999999	53.650485000000003	53.622056000000001	Центральная	0103000020E6100000010000000500000050E449D235F54340EA23F0879FCF4A4050E449D235F54340F0C4AC1743D34A407BBDFBE3BDFC4340F0C4AC1743D34A407BBDFBE3BDFC4340EA23F0879FCF4A4050E449D235F54340EA23F0879FCF4A40
38497	26682	40.181103999999998	40.227384999999998	53.739764000000001	53.708489999999998	Советской Армии	0103000020E610000001000000050000005F96766A2E17444082C5E1CCAFDA4A405F96766A2E1744400B613596B0DE4A40EC4CA1F31A1D44400B613596B0DE4A40EC4CA1F31A1D444082C5E1CCAFDA4A405F96766A2E17444082C5E1CCAFDA4A40
38644	26524	40.043176000000003	40.072183000000003	53.671854000000003	53.655262	Солнечная	0103000020E610000001000000050000006EFC89CA86054440E1270EA0DFD34A406EFC89CA86054440E9D7D64FFFD54A40E129E44A3D094440E9D7D64FFFD54A40E129E44A3D094440E1270EA0DFD34A406EFC89CA86054440E1270EA0DFD34A40
38597	26263	40.114457999999999	40.147165000000001	53.646706000000002	53.635389000000004	Гагарина	0103000020E61000000100000005000000FE614B8FA60E44407C9E3F6D54D14A40FE614B8FA60E444041102043C7D24A40D40E7F4DD612444041102043C7D24A40D40E7F4DD61244407C9E3F6D54D14A40FE614B8FA60E44407C9E3F6D54D14A40
37972	4913	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Электротяговая	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38051	4913	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Театральная	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38047	4913	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Почтовая	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
37977	4913	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Новосельская	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38271	4913	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Макаренко	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38068	4913	39.475917000000003	39.543291000000004	54.741208	54.709043999999999	Заготовительная	0103000020E61000000100000005000000234E27D9EABC434067B62BF4C15A4B40234E27D9EABC43404CC45BE7DF5E4B40079B3A8F8AC543404CC45BE7DF5E4B40079B3A8F8AC5434067B62BF4C15A4B40234E27D9EABC434067B62BF4C15A4B40
38641	6498	41.088788000000001	41.122053000000001	54.044266	54.023240000000001	Молодежная	0103000020E610000001000000050000007D23BA675D8B4440C2FA3F87F9024B407D23BA675D8B444091291F82AA054B4079B0C56E9F8F444091291F82AA054B4079B0C56E9F8F4440C2FA3F87F9024B407D23BA675D8B4440C2FA3F87F9024B40
9850	22657	41.192373000000003	41.228791000000001	54.197293999999999	54.176968000000002	Новая	0103000020E6100000010000000500000014D1AFAD9F98444022382EE3A6164B4014D1AFAD9F98444038D906EE40194B40404F0306499D444038D906EE40194B40404F0306499D444022382EE3A6164B4014D1AFAD9F98444022382EE3A6164B40
38711	23359	41.275440000000003	41.305003999999997	54.080840000000002	54.047623000000002	Сельская	0103000020E610000001000000050000005001309E41A34440CAC4AD8218064B405001309E41A34440B51A12F7580A4B401893FE5E0AA74440B51A12F7580A4B401893FE5E0AA74440CAC4AD8218064B405001309E41A34440CAC4AD8218064B40
38217	23178	41.094096999999998	41.135007000000002	54.173479	54.134630000000001	Ленинский проспект	0103000020E610000001000000050000006BD3D85E0B8C4440BE874B8E3B114B406BD3D85E0B8C44407AC5538F34164B4094DDCCE8479144407AC5538F34164B4094DDCCE847914440BE874B8E3B114B406BD3D85E0B8C4440BE874B8E3B114B40
38253	23178	41.094096999999998	41.135007000000002	54.173479	54.134630000000001	Ворошилова	0103000020E610000001000000050000006BD3D85E0B8C4440BE874B8E3B114B406BD3D85E0B8C44407AC5538F34164B4094DDCCE8479144407AC5538F34164B4094DDCCE847914440BE874B8E3B114B406BD3D85E0B8C4440BE874B8E3B114B40
38498	23094	40.796683000000002	40.856340000000003	54.121006999999999	54.097639000000001	Революции	0103000020E61000000100000005000000BC2363B5F965444036E84B6F7F0C4B40BC2363B5F965444025CB49287D0F4B40DA20938C9C6D444025CB49287D0F4B40DA20938C9C6D444036E84B6F7F0C4B40BC2363B5F965444036E84B6F7F0C4B40
38765	22382	40.924000999999997	40.95158	54.134476999999997	54.119888000000003	Поселковая	0103000020E61000000100000005000000533C2EAA4576444068976F7D580F4B40533C2EAA457644403788D68A36114B408BC3995FCD7944403788D68A36114B408BC3995FCD79444068976F7D580F4B40533C2EAA4576444068976F7D580F4B40
38745	54675	\N	\N	\N	\N	Черемушки	\N
38738	22819	41.205722000000002	41.225943000000001	54.128810999999999	54.103689000000003	Центральная	0103000020E61000000100000005000000AB083719559A44403CFA5FAE450D4B40AB083719559A4440BA2EFCE07C104B404CE141B3EB9C4440BA2EFCE07C104B404CE141B3EB9C44403CFA5FAE450D4B40AB083719559A44403CFA5FAE450D4B40
38769	22898	40.882517	40.911254	54.177363	54.159548000000001	Школьная	0103000020E61000000100000005000000FF942A51F67044403412A1116C144B40FF942A51F67044409E42AED4B3164B40B22C98F8A37444409E42AED4B3164B40B22C98F8A37444403412A1116C144B40FF942A51F67044403412A1116C144B40
38648	23275	41.377336	41.393883000000002	54.093541000000002	54.075045000000003	Центральная	0103000020E610000001000000050000003ECDC98B4CB044403A5D16139B094B403ECDC98B4CB04440E6EAC726F90B4B40A6B915C26AB24440E6EAC726F90B4B40A6B915C26AB244403A5D16139B094B403ECDC98B4CB044403A5D16139B094B40
38595	3203	41.245193999999998	41.273283999999997	54.126589000000003	54.104539000000003	Луговая	0103000020E6100000010000000500000074965984629F44400A14B188610D4B4074965984629F444045847F1134104B40914259F8FAA2444045847F1134104B40914259F8FAA244400A14B188610D4B4074965984629F44400A14B188610D4B40
38640	22745	41.034970000000001	41.058002999999999	54.223927000000003	54.201628999999997	Солнечный переулок	0103000020E61000000100000005000000AA2B9FE5798444406C76A4FACE194B40AA2B9FE57984444080D8D2A3A91C4B40F2086EA46C87444080D8D2A3A91C4B40F2086EA46C8744406C76A4FACE194B40AA2B9FE5798444406C76A4FACE194B40
38596	23228	41.157643999999998	41.183165000000002	54.150115	54.118822000000002	Молодежная	0103000020E610000001000000050000008F34B8AD2D944440CD052E8F350F4B408F34B8AD2D944440CCD1E3F736134B40CC6262F371974440CCD1E3F736134B40CC6262F371974440CD052E8F350F4B408F34B8AD2D944440CD052E8F350F4B40
38593	3086	41.114148	41.143180999999998	54.221668999999999	54.192737999999999	Центральная	0103000020E61000000100000005000000B073D3669C8E4440255987A3AB184B40B073D3669C8E4440BDC458A65F1C4B404C3448C153924440BDC458A65F1C4B404C3448C153924440255987A3AB184B40B073D3669C8E4440255987A3AB184B40
38768	22476	41.398240000000001	41.411983999999997	54.041110000000003	54.029243000000001	Центальная	0103000020E61000000100000005000000C2FA3F87F9B244408751103CBE034B40C2FA3F87F9B24440F0C4AC1743054B40D53C47E4BBB44440F0C4AC1743054B40D53C47E4BBB444408751103CBE034B40C2FA3F87F9B244408751103CBE034B40
38767	22375	40.930056	40.940072000000001	54.182074	54.169848000000002	Центральная	0103000020E610000001000000050000006BB933130C77444040A54A94BD154B406BB933130C774440D8B969334E174B4052F17F4754784440D8B969334E174B4052F17F475478444040A54A94BD154B406BB933130C77444040A54A94BD154B40
38764	2223	39.497287999999998	39.511651999999998	54.089818000000001	54.080115999999997	Центральная	0103000020E61000000100000005000000BC581822A7BF434073F1B73D410A4B40BC581822A7BF4340CB4BFE277F0B4B406C770FD07DC14340CB4BFE277F0B4B406C770FD07DC1434073F1B73D410A4B40BC581822A7BF434073F1B73D410A4B40
38642	2499	39.700190999999997	39.726771999999997	54.087822000000003	54.077216	Садовая	0103000020E610000001000000050000000DFAD2DB9FD943402D5DC136E2094B400DFAD2DB9FD9434046EF54C03D0B4B4002D369DD06DD434046EF54C03D0B4B4002D369DD06DD43402D5DC136E2094B400DFAD2DB9FD943402D5DC136E2094B40
38736	2460	39.478988999999999	39.513142999999999	53.995488000000002	53.984158999999998	Центральная	0103000020E610000001000000050000006612F5824FBD434033880FECF8FD4A406612F5824FBD4340BDC799266CFF4A40EE9579ABAEC14340BDC799266CFF4A40EE9579ABAEC1434033880FECF8FD4A406612F5824FBD434033880FECF8FD4A40
38737	2335	39.398473000000003	39.440254000000003	54.012528000000003	53.996001	Степановка	0103000020E6100000010000000500000065ABCB2901B3434043E4F4F57CFF4A4065ABCB2901B3434064247B849A014B4073F7393E5AB8434064247B849A014B4073F7393E5AB8434043E4F4F57CFF4A4065ABCB2901B3434043E4F4F57CFF4A40
38102	2627	39.561490999999997	39.641961999999999	54.132719999999999	54.080613	Первомайская	0103000020E61000000100000005000000C9FFE4EFDEC74340F450DB86510A4B40C9FFE4EFDEC7434037C30DF8FC104B402BA391CF2BD2434037C30DF8FC104B402BA391CF2BD24340F450DB86510A4B40C9FFE4EFDEC74340F450DB86510A4B40
38492	2627	39.561490999999997	39.641961999999999	54.132719999999999	54.080613	Верхне-Архангельская	0103000020E61000000100000005000000C9FFE4EFDEC74340F450DB86510A4B40C9FFE4EFDEC7434037C30DF8FC104B402BA391CF2BD2434037C30DF8FC104B402BA391CF2BD24340F450DB86510A4B40C9FFE4EFDEC74340F450DB86510A4B40
38488	2270	39.398608000000003	39.454214	54.079292000000002	54.056745999999997	Большая	0103000020E6100000010000000500000045F6419605B34340E316F37343074B4045F6419605B34340CF6A813D260A4B4053B131AF23BA4340CF6A813D260A4B4053B131AF23BA4340E316F37343074B4045F6419605B34340E316F37343074B40
38064	2792	39.730849999999997	39.757063000000002	54.051307000000001	54.026144000000002	проспект Энергетиков 	0103000020E610000001000000050000000B24287E8CDD43404A7EC4AF58034B400B24287E8CDD434027874F3A91064B407E01BD70E7E0434027874F3A91064B407E01BD70E7E043404A7EC4AF58034B400B24287E8CDD43404A7EC4AF58034B40
38063	2792	39.730849999999997	39.757063000000002	54.051307000000001	54.026144000000002	пр. Энергетиков	0103000020E610000001000000050000000B24287E8CDD43404A7EC4AF58034B400B24287E8CDD434027874F3A91064B407E01BD70E7E0434027874F3A91064B407E01BD70E7E043404A7EC4AF58034B400B24287E8CDD43404A7EC4AF58034B40
38200	2792	39.730849999999997	39.757063000000002	54.051307000000001	54.026144000000002	пр. Смирягина	0103000020E610000001000000050000000B24287E8CDD43404A7EC4AF58034B400B24287E8CDD434027874F3A91064B407E01BD70E7E0434027874F3A91064B407E01BD70E7E043404A7EC4AF58034B400B24287E8CDD43404A7EC4AF58034B40
38066	2792	39.730849999999997	39.757063000000002	54.051307000000001	54.026144000000002	Строителей	0103000020E610000001000000050000000B24287E8CDD43404A7EC4AF58034B400B24287E8CDD434027874F3A91064B407E01BD70E7E0434027874F3A91064B407E01BD70E7E043404A7EC4AF58034B400B24287E8CDD43404A7EC4AF58034B40
38103	2792	39.730849999999997	39.757063000000002	54.051307000000001	54.026144000000002	Комсомольская	0103000020E610000001000000050000000B24287E8CDD43404A7EC4AF58034B400B24287E8CDD434027874F3A91064B407E01BD70E7E0434027874F3A91064B407E01BD70E7E043404A7EC4AF58034B400B24287E8CDD43404A7EC4AF58034B40
38489	19209	39.588045000000001	39.620348	54.367021000000001	54.356057	Школьная	0103000020E61000000100000005000000C5C9FD0E45CB434085419946932D4B40C5C9FD0E45CB4340FDF84B8BFA2E4B40CB11329067CF4340FDF84B8BFA2E4B40CB11329067CF434085419946932D4B40C5C9FD0E45CB434085419946932D4B40
38762	21078	39.591907999999997	39.609056000000002	54.178001000000002	54.165419999999997	Октябрьская	0103000020E61000000100000005000000D11E2FA4C3CB43405A0D897B2C154B40D11E2FA4C3CB4340E1D39CBCC8164B405FB7088CF5CD4340E1D39CBCC8164B405FB7088CF5CD43405A0D897B2C154B40D11E2FA4C3CB43405A0D897B2C154B40
38717	2396	39.346021	39.363421000000002	53.999346000000003	53.990544	Молодежная	0103000020E61000000100000005000000575D876A4AAC4340E09F5225CAFE4A40575D876A4AAC4340B8B1D991EAFF4A40FED64E9484AE4340B8B1D991EAFF4A40FED64E9484AE4340E09F5225CAFE4A40575D876A4AAC4340E09F5225CAFE4A40
38594	21165	39.434216999999997	39.462389000000002	54.169041	54.155208000000002	Советская	0103000020E61000000100000005000000012F336C94B74340EE0912DBDD134B40012F336C94B743407157AF22A3154B40DC8310902FBB43407157AF22A3154B40DC8310902FBB4340EE0912DBDD134B40012F336C94B74340EE0912DBDD134B40
38638	21019	39.517499999999998	39.548133	54.192053000000001	54.179476000000001	Почтовая	0103000020E610000001000000050000000AD7A3703DC243405D35CF11F9164B400AD7A3703DC24340A20C553195184B40DF6DDE3829C64340A20C553195184B40DF6DDE3829C643405D35CF11F9164B400AD7A3703DC243405D35CF11F9164B40
38801	20287	41.954486000000003	41.970430999999998	54.556415000000001	54.535023000000002	им. Дмитрия Кокорева	0103000020E61000000100000005000000B43EE5982CFA4440CDCD37A27B444B40B43EE5982CFA44407E00529B38474B402503401537FC44407E00529B38474B402503401537FC4440CDCD37A27B444B40B43EE5982CFA4440CDCD37A27B444B40
38733	19021	41.839942000000001	41.875138	54.629038999999999	54.611007000000001	Школьная	0103000020E61000000100000005000000B7442E3883EB44404450357A354E4B40B7442E3883EB44404B74965984504B4051BEA08504F044404B74965984504B4051BEA08504F044404450357A354E4B40B7442E3883EB44404450357A354E4B40
38639	19107	41.737003999999999	41.765498000000001	54.613655999999999	54.595362000000002	Первомайская	0103000020E61000000100000005000000B682A62556DE4440FDA36FD2344C4B40B682A62556DE4440417FA1478C4E4B40A393A5D6FBE14440417FA1478C4E4B40A393A5D6FBE14440FDA36FD2344C4B40B682A62556DE4440FDA36FD2344C4B40
38763	19102	41.910162999999997	41.922443000000001	54.509898999999997	54.496786999999998	Школьная	0103000020E61000000100000005000000BE839F3880F44440FA0967B7963F4B40BE839F3880F44440ADA1D45E44414B404AB6BA9C12F64440ADA1D45E44414B404AB6BA9C12F64440FA0967B7963F4B40BE839F3880F44440FA0967B7963F4B40
38491	19205	41.784847999999997	41.838000999999998	54.593781	54.568871000000001	Павлова	0103000020E610000001000000050000005E2A36E675E444404852D2C3D0484B405E2A36E675E444403BFE0B04014C4B40F581E49D43EB44403BFE0B04014C4B40F581E49D43EB44404852D2C3D0484B405E2A36E675E444404852D2C3D0484B40
38514	19205	41.784847999999997	41.838000999999998	54.593781	54.568871000000001	Красная	0103000020E610000001000000050000005E2A36E675E444404852D2C3D0484B405E2A36E675E444403BFE0B04014C4B40F581E49D43EB44403BFE0B04014C4B40F581E49D43EB44404852D2C3D0484B405E2A36E675E444404852D2C3D0484B40
38490	19205	41.784847999999997	41.838000999999998	54.593781	54.568871000000001	Горького	0103000020E610000001000000050000005E2A36E675E444404852D2C3D0484B405E2A36E675E444403BFE0B04014C4B40F581E49D43EB44403BFE0B04014C4B40F581E49D43EB44404852D2C3D0484B405E2A36E675E444404852D2C3D0484B40
38731	20533	41.654853000000003	41.697226000000001	54.631973000000002	54.620282000000003	Николаевка	0103000020E6100000010000000500000000581D39D2D3444014268C66654F4B4000581D39D2D344403E7AC37DE4504B40E0F599B33ED944403E7AC37DE4504B40E0F599B33ED9444014268C66654F4B4000581D39D2D3444014268C66654F4B40
38761	20365	41.837192999999999	41.872146000000001	54.606198999999997	54.590254999999999	Заречная	0103000020E6100000010000000500000056B8E52329EB444076A6D0798D4B4B4056B8E52329EB444017EFC7ED974D4B402AABE97AA2EF444017EFC7ED974D4B402AABE97AA2EF444076A6D0798D4B4B4056B8E52329EB444076A6D0798D4B4B40
38591	20065	41.569360000000003	41.604556000000002	54.487113000000001	54.466104000000001	Молодежная	0103000020E6100000010000000500000046D3D9C9E0C844407444BE4BA93B4B4046D3D9C9E0C844406D3A02B8593E4B40E04C4C1762CD44406D3A02B8593E4B40E04C4C1762CD44407444BE4BA93B4B4046D3D9C9E0C844407444BE4BA93B4B40
38487	18902	41.800074000000002	41.823214999999998	54.528545000000001	54.501420000000003	Молодежная	0103000020E61000000100000005000000A13028D368E64440B9C7D2872E404B40A13028D368E644406FBBD05CA7434B40CF49EF1B5FE944406FBBD05CA7434B40CF49EF1B5FE94440B9C7D2872E404B40A13028D368E64440B9C7D2872E404B40
38636	18891	41.745241	41.755752000000001	54.720453999999997	54.713012999999997	Есенина	0103000020E61000000100000005000000B5519D0E64DF4440B94F8E02445B4B40B5519D0E64DF4440DD2230D6375C4B407CF1457BBCE04440DD2230D6375C4B407CF1457BBCE04440B94F8E02445B4B40B5519D0E64DF4440B94F8E02445B4B40
38766	19938	41.742421	41.770142999999997	54.708565	54.692224000000003	Николаевка	0103000020E610000001000000050000008B6EBDA607DF4440CFC0C8CB9A584B408B6EBDA607DF44408D0B0742B25A4B40251FBB0B94E244408D0B0742B25A4B40251FBB0B94E24440CFC0C8CB9A584B408B6EBDA607DF4440CFC0C8CB9A584B40
38573	18945	41.607278000000001	41.650495999999997	54.565389000000003	54.537886	Крупской	0103000020E6100000010000000500000047CA1649BBCD4440F67CCD72D9444B4047CA1649BBCD44405342B0AA5E484B40E316F37343D344405342B0AA5E484B40E316F37343D34440F67CCD72D9444B4047CA1649BBCD4440F67CCD72D9444B40
38732	19825	41.733832999999997	41.759273	54.746887999999998	54.728160000000003	Центральная	0103000020E61000000100000005000000DFDC5F3DEEDD4440B020CD58345D4B40DFDC5F3DEEDD44402EE3A6069A5F4B402FDE8FDB2FE144402EE3A6069A5F4B402FDE8FDB2FE14440B020CD58345D4B40DFDC5F3DEEDD4440B020CD58345D4B40
38592	20539	41.585700000000003	41.611958000000001	54.596671000000001	54.572775	Колхозная	0103000020E6100000010000000500000034A2B437F8CA4440B37BF2B050494B4034A2B437F8CA44405EBC1FB75F4C4B404643C6A354CE44405EBC1FB75F4C4B404643C6A354CE4440B37BF2B050494B4034A2B437F8CA4440B37BF2B050494B40
38728	18697	40.359499999999997	40.392944	53.451709000000001	53.429622000000002	Молодежная	0103000020E61000000100000005000000BC749318042E444031D28BDAFDB64A40BC749318042E44408927BB99D1B94A4068942EFD4B3244408927BB99D1B94A4068942EFD4B32444031D28BDAFDB64A40BC749318042E444031D28BDAFDB64A40
38729	18788	40.473838000000001	40.518430000000002	53.498832999999998	53.477628000000003	Центральная	0103000020E6100000010000000500000010CD3CB9A63C4440B3D30FEA22BD4A4010CD3CB9A63C444031957EC2D9BF4A40F5A10BEA5B42444031957EC2D9BF4A40F5A10BEA5B424440B3D30FEA22BD4A4010CD3CB9A63C4440B3D30FEA22BD4A40
38718	18587	40.220396000000001	40.272497999999999	53.511375999999998	53.494579999999999	Центральная	0103000020E61000000100000005000000A915A6EF351C4440BAA0BE654EBF4A40A915A6EF351C4440CAFACDC474C14A40DA1CE736E1224440CAFACDC474C14A40DA1CE736E1224440BAA0BE654EBF4A40A915A6EF351C4440BAA0BE654EBF4A40
38726	18785	40.331257000000001	40.361134999999997	53.369231999999997	53.354475999999998	Центральная	0103000020E6100000010000000500000019C91EA1662A4440C39B35785FAD4A4019C91EA1662A44407E5182FE42AF4A407138F3AB392E44407E5182FE42AF4A407138F3AB392E4440C39B35785FAD4A4019C91EA1662A4440C39B35785FAD4A40
38582	18470	40.222012999999997	40.244551999999999	53.453623	53.438023000000001	Крутякова	0103000020E61000000100000005000000B72407EC6A1C4440AAF23D2311B84A40B72407EC6A1C444051DB865110BA4A40F015DD7A4D1F444051DB865110BA4A40F015DD7A4D1F4440AAF23D2311B84A40B72407EC6A1C4440AAF23D2311B84A40
38809	54688	40.103273999999999	40.133088999999998	53.498421	53.476331000000002	Вишневая	0103000020E6100000010000000500000078431A15380D44401689096AF8BC4A4078431A15380D4440DF516342CCBF4A408A3A730F09114440DF516342CCBF4A408A3A730F091144401689096AF8BC4A4078431A15380D44401689096AF8BC4A40
38760	18636	40.164745000000003	40.175615000000001	53.490343000000003	53.481153999999997	Молодежная	0103000020E61000000100000005000000FB96395D16154440772B4B7496BD4A40FB96395D161544404969368FC3BE4A40F1D7648D7A1644404969368FC3BE4A40F1D7648D7A164440772B4B7496BD4A40FB96395D16154440772B4B7496BD4A40
38735	19822	40.488283000000003	40.508800000000001	53.568359000000001	53.548954000000002	Центральная	0103000020E61000000100000005000000AD18AE0E803E44401381EA1F44C64A40AD18AE0E803E444092B1DAFCBFC84A40371AC05B2041444092B1DAFCBFC84A40371AC05B204144401381EA1F44C64A40AD18AE0E803E44401381EA1F44C64A40
38486	19307	40.009228999999998	40.056660000000001	53.437635999999998	53.414135000000002	Центральная	0103000020E610000001000000050000005F96766A2E01444082902C6002B54A405F96766A2E014440B0C6D97404B84A40E57E87A240074440B0C6D97404B84A40E57E87A24007444082902C6002B54A405F96766A2E01444082902C6002B54A40
38589	19510	40.021931000000002	40.059939	53.484459999999999	53.477837000000001	Почтовая	0103000020E6100000010000000500000061E28FA2CE024440CDE847C329BD4A4061E28FA2CE0244402E1C08C902BE4A40A260C614AC0744402E1C08C902BE4A40A260C614AC074440CDE847C329BD4A4061E28FA2CE024440CDE847C329BD4A40
38590	19618	40.102015999999999	40.131822	53.541168999999996	53.508296999999999	Молодежная	0103000020E6100000010000000500000099D53BDC0E0D4440D4D347E00FC14A4099D53BDC0E0D4440F44D9A0645C54A405872158BDF104440F44D9A0645C54A405872158BDF104440D4D347E00FC14A4099D53BDC0E0D4440D4D347E00FC14A40
38727	18467	40.183385000000001	40.222425999999999	53.376002	53.357093999999996	Заречная	0103000020E61000000100000005000000DAC9E0287917444085CC9541B5AD4A40DAC9E02879174440849D62D520B04A40DAE38574781C4440849D62D520B04A40DAE38574781C444085CC9541B5AD4A40DAC9E0287917444085CC9541B5AD4A40
38730	18469	40.219884	40.270404999999997	53.586488000000003	53.570813999999999	Молодежная	0103000020E61000000100000005000000F374AE28251C4440AA0CE36E10C94A40F374AE28251C44408CBFED0912CB4A4062D68BA19C2244408CBFED0912CB4A4062D68BA19C224440AA0CE36E10C94A40F374AE28251C4440AA0CE36E10C94A40
38734	18789	40.163972999999999	40.182011000000003	53.449001000000003	53.424019999999999	Зеленая	0103000020E61000000100000005000000A8363811FD144440CA6C904946B64A40A8363811FD144440876F61DD78B94A409241EE224C174440876F61DD78B94A409241EE224C174440CA6C904946B64A40A8363811FD144440CA6C904946B64A40
38725	18465	40.263291000000002	40.289521000000001	53.426761999999997	53.401446	Центральная	0103000020E61000000100000005000000632AFD84B3214440158E209562B34A40632AFD84B321444078962023A0B64A40AB402D060F25444078962023A0B64A40AB402D060F254440158E209562B34A40632AFD84B3214440158E209562B34A40
38635	18582	40.244534000000002	40.267341999999999	53.405177000000002	53.392038999999997	Мичурина	0103000020E610000001000000050000004A61DEE34C1F4440D6E07D552EB24A404A61DEE34C1F4440B30B06D7DCB34A40726C3D4338224440B30B06D7DCB34A40726C3D4338224440D6E07D552EB24A404A61DEE34C1F4440D6E07D552EB24A40
38092	18263	40.18891	40.222695999999999	53.490085999999998	53.46255	Советская	0103000020E6100000010000000500000095F1EF332E184440E561A1D634BB4A4095F1EF332E1844401D1D5723BBBE4A409A79724D811C44401D1D5723BBBE4A409A79724D811C4440E561A1D634BB4A4095F1EF332E184440E561A1D634BB4A40
38481	18263	40.18891	40.222695999999999	53.490085999999998	53.46255	Весенняя 	0103000020E6100000010000000500000095F1EF332E184440E561A1D634BB4A4095F1EF332E1844401D1D5723BBBE4A409A79724D811C44401D1D5723BBBE4A409A79724D811C4440E561A1D634BB4A4095F1EF332E184440E561A1D634BB4A40
38759	15491	39.223005999999998	39.256782000000001	53.986192000000003	53.949401999999999	Верховка	0103000020E61000000100000005000000E867EA758B9C4340E560360186F94A40E867EA758B9C4340D6C9198A3BFE4A40CA198A3BDEA04340D6C9198A3BFE4A40CA198A3BDEA04340E560360186F94A40E867EA758B9C4340E560360186F94A40
38626	17364	39.031404000000002	39.049604000000002	54.326312000000001	54.305131000000003	Кадушная	0103000020E61000000100000005000000577BD80B0584434076FF58880E274B40577BD80B058443406C257497C4294B401AE0826C598643406C257497C4294B401AE0826C5986434076FF58880E274B40577BD80B0584434076FF58880E274B40
38804	54684	39.149371000000002	39.160679999999999	54.066136999999998	54.059690000000003	Центральная	0103000020E6100000010000000500000044FCC3961E934340FAF202ECA3074B4044FCC3961E9343401C075E2D77084B40868F8829919443401C075E2D77084B40868F882991944340FAF202ECA3074B4044FCC3961E934340FAF202ECA3074B40
38632	17471	39.166024999999998	39.184629000000001	54.295132000000002	54.272646000000002	Поярковская 	0103000020E61000000100000005000000C1A8A44E409543404FB16A10E6224B40C1A8A44E409543406500A8E2C6254B4054724EECA19743406500A8E2C6254B4054724EECA19743404FB16A10E6224B40C1A8A44E409543404FB16A10E6224B40
38506	15591	38.958038000000002	38.978968999999999	54.224159	54.217747000000003	Почтовая	0103000020E61000000100000005000000A2293BFDA07A4340ACE63922DF1B4B40A2293BFDA07A4340520DFB3DB11C4B401F662FDB4E7D4340520DFB3DB11C4B401F662FDB4E7D4340ACE63922DF1B4B40A2293BFDA07A4340ACE63922DF1B4B40
38758	16358	39.131439999999998	39.162944000000003	54.090747999999998	54.076714000000003	Лесная	0103000020E6100000010000000500000070B1A206D39043409B92ACC3D1094B4070B1A206D3904340B51666A19D0B4B402B8A5759DB944340B51666A19D0B4B402B8A5759DB9443409B92ACC3D1094B4070B1A206D39043409B92ACC3D1094B40
38805	54685	39.104337999999998	39.110159000000003	53.980829	53.977767999999998	Луговая	0103000020E6100000010000000500000072DD94F25A8D4340A489778027FD4A4072DD94F25A8D4340F4FBFECD8BFD4A40172EABB0198E4340F4FBFECD8BFD4A40172EABB0198E4340A489778027FD4A4072DD94F25A8D4340A489778027FD4A40
38480	15769	38.875078999999999	38.910473000000003	54.249470000000002	54.218525999999997	Цементников	0103000020E610000001000000050000004C35B39602704340B0A9F3A8F81B4B404C35B39602704340A4AA09A2EE1F4B400D7217618A744340A4AA09A2EE1F4B400D7217618A744340B0A9F3A8F81B4B404C35B39602704340B0A9F3A8F81B4B40
38477	15769	38.875078999999999	38.910473000000003	54.249470000000002	54.218525999999997	Кочубина	0103000020E610000001000000050000004C35B39602704340B0A9F3A8F81B4B404C35B39602704340A4AA09A2EE1F4B400D7217618A744340A4AA09A2EE1F4B400D7217618A744340B0A9F3A8F81B4B404C35B39602704340B0A9F3A8F81B4B40
38483	15769	38.875078999999999	38.910473000000003	54.249470000000002	54.218525999999997	Клубная	0103000020E610000001000000050000004C35B39602704340B0A9F3A8F81B4B404C35B39602704340A4AA09A2EE1F4B400D7217618A744340A4AA09A2EE1F4B400D7217618A744340B0A9F3A8F81B4B404C35B39602704340B0A9F3A8F81B4B40
38633	15769	38.875078999999999	38.910473000000003	54.249470000000002	54.218525999999997	Больничная	0103000020E610000001000000050000004C35B39602704340B0A9F3A8F81B4B404C35B39602704340A4AA09A2EE1F4B400D7217618A744340A4AA09A2EE1F4B400D7217618A744340B0A9F3A8F81B4B404C35B39602704340B0A9F3A8F81B4B40
38478	15769	38.875078999999999	38.910473000000003	54.249470000000002	54.218525999999997	3-й Строительный переулок	0103000020E610000001000000050000004C35B39602704340B0A9F3A8F81B4B404C35B39602704340A4AA09A2EE1F4B400D7217618A744340A4AA09A2EE1F4B400D7217618A744340B0A9F3A8F81B4B404C35B39602704340B0A9F3A8F81B4B40
38714	17266	38.982221000000003	39.073399999999999	54.372382000000002	54.327083999999999	Слобода	0103000020E61000000100000005000000E338F06AB97D4340BE8575E3DD294B40E338F06AB97D43403ECF9F36AA2F4B4061C3D32B658943403ECF9F36AA2F4B4061C3D32B65894340BE8575E3DD294B40E338F06AB97D4340BE8575E3DD294B40
38724	17730	38.897114999999999	38.923121000000002	54.196119000000003	54.187027	Новая	0103000020E6100000010000000500000022E010AAD4724340083C3080F0174B4022E010AAD4724340E78F696D1A194B401BA034D428764340E78F696D1A194B401BA034D428764340083C3080F0174B4022E010AAD4724340083C3080F0174B40
38198	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	ст. Михайлов	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38257	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	Школьная	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38468	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	Октябрьская	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38211	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	Новая	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38186	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	Нагорная	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38471	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	Карла Маркса	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38637	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	Зеленая	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38505	15018	38.998849	39.045102999999997	54.246881000000002	54.213771999999999	23 Партсъезда	0103000020E610000001000000050000003752B648DA7F4340776682E15C1B4B403752B648DA7F43407C80EECB991F4B40CAF962EFC58543407C80EECB991F4B40CAF962EFC5854340776682E15C1B4B403752B648DA7F4340776682E15C1B4B40
38572	16516	38.973084999999998	39.004652	54.091513999999997	54.067104	Кулькова	0103000020E61000000100000005000000349D9D0C8E7C434024B726DD96084B40349D9D0C8E7C4340259012BBB60B4B4035EECD6F98804340259012BBB60B4B4035EECD6F9880434024B726DD96084B40349D9D0C8E7C434024B726DD96084B40
38810	54689	39.174883000000001	39.194125	54.089575000000004	54.080148000000001	Центральная	0103000020E610000001000000050000002DD0EE90629643407F6B274A420A4B402DD0EE906296434005C58F31770B4B40022B8716D998434005C58F31770B4B40022B8716D99843407F6B274A420A4B402DD0EE90629643407F6B274A420A4B40
38474	15640	39.000996000000001	39.024163000000001	54.258448000000001	54.235464	Лещенка	0103000020E61000000100000005000000A2B60DA32080434053B131AF231E4B40A2B60DA320804340BADBF5D214214B40FA62EFC517834340BADBF5D214214B40FA62EFC51783434053B131AF231E4B40A2B60DA32080434053B131AF231E4B40
38475	16579	38.803277000000001	38.822231000000002	54.102786000000002	54.096414000000003	Центральная	0103000020E610000001000000050000008350DEC7D16643403370404B570C4B408350DEC7D16643404B3E7617280D4B40F2608BDD3E6943404B3E7617280D4B40F2608BDD3E6943403370404B570C4B408350DEC7D16643403370404B570C4B40
38511	16832	39.094006999999998	39.132752000000004	54.049467999999997	54.032950999999997	Центральная	0103000020E610000001000000050000002B4CDF6B088C43406CAF05BD37044B402B4CDF6B088C43406919A9F754064B40433D7D04FE9043406919A9F754064B40433D7D04FE9043406CAF05BD37044B402B4CDF6B088C43406CAF05BD37044B40
38757	15858	38.852513000000002	38.86544	54.251925999999997	54.246865999999997	Школьная	0103000020E610000001000000050000001A355F251F6D4340463F1A4E991F4B401A355F251F6D43408C81751C3F204B403B53E8BCC66E43408C81751C3F204B403B53E8BCC66E4340463F1A4E991F4B401A355F251F6D4340463F1A4E991F4B40
38479	16269	39.073697000000003	39.104194	54.128456999999997	54.106023	Школьная	0103000020E610000001000000050000001B683EE76E894340D9CF6229920D4B401B683EE76E8943409CF86A4771104B403F389F3A568D43409CF86A4771104B403F389F3A568D4340D9CF6229920D4B401B683EE76E894340D9CF6229920D4B40
38754	14333	39.440308000000002	39.462622000000003	53.551617999999998	53.537964000000002	Центральная	0103000020E61000000100000005000000661536035CB8434072361D01DCC44A40661536035CB8434045F12A6B9BC64A407F349C3237BB434045F12A6B9BC64A407F349C3237BB434072361D01DCC44A40661536035CB8434072361D01DCC44A40
38473	14734	39.115952999999998	39.168837000000003	53.628518	53.595061000000001	Ленина	0103000020E61000000100000005000000C16F438CD78E4340021077F52ACC4A40C16F438CD78E434042791F4773D04A4069AD68739C95434042791F4773D04A4069AD68739C954340021077F52ACC4A40C16F438CD78E4340021077F52ACC4A40
38469	15008	39.619567000000004	39.636212999999998	53.682932000000001	53.670526000000002	Мира	0103000020E610000001000000050000002657B1F84DCF4340118FC4CBD3D54A402657B1F84DCF434029B2D6506AD74A402025766D6FD1434029B2D6506AD74A402025766D6FD14340118FC4CBD3D54A402657B1F84DCF4340118FC4CBD3D54A40
38803	54683	39.325727999999998	39.353019000000003	53.748289	53.734267000000003	Центральная	0103000020E610000001000000050000001CB28174B1A943401AC40776FCDD4A401CB28174B1A94340707A17EFC7DF4A40EEEE01BA2FAD4340707A17EFC7DF4A40EEEE01BA2FAD43401AC40776FCDD4A401CB28174B1A943401AC40776FCDD4A40
38567	13316	39.356082000000001	39.387836999999998	53.654184000000001	53.636558999999998	Новая	0103000020E61000000100000005000000DE58501894AD4340BB7CEBC37AD14A40DE58501894AD434082C8224DBCD34A40E1968FA4A4B1434082C8224DBCD34A40E1968FA4A4B14340BB7CEBC37AD14A40DE58501894AD4340BB7CEBC37AD14A40
38571	54652	39.234521999999998	39.256602000000001	53.695489000000002	53.686121	Центральная	0103000020E61000000100000005000000A41820D1049E4340A60C1CD0D2D74A40A41820D1049E434027DD96C805D94A404A0B9755D8A0434027DD96C805D94A404A0B9755D8A04340A60C1CD0D2D74A40A41820D1049E4340A60C1CD0D2D74A40
38580	13859	39.552705000000003	39.573276999999997	53.684238999999998	53.673811999999998	Луговая	0103000020E61000000100000005000000F8AA9509BFC6434080D3BB783FD64A40F8AA9509BFC64340E9D2BF2495D74A404546072461C94340E9D2BF2495D74A404546072461C9434080D3BB783FD64A40F8AA9509BFC6434080D3BB783FD64A40
38753	14431	39.312019999999997	39.333148000000001	53.565331999999998	53.555978000000003	Новоселов	0103000020E6100000010000000500000055D97745F0A74340D3A57F492AC74A4055D97745F0A74340EEB089CC5CC84A40295DFA97A4AA4340EEB089CC5CC84A40295DFA97A4AA4340D3A57F492AC74A4055D97745F0A74340D3A57F492AC74A40
38722	14782	39.100628	39.117812999999998	53.542197000000002	53.534823000000003	Центральная	0103000020E61000000100000005000000EC87D860E18C434006137F1475C44A40EC87D860E18C4340A27E17B666C54A409605137F148F4340A27E17B666C54A409605137F148F434006137F1475C44A40EC87D860E18C434006137F1475C44A40
38520	5341	39.534838000000001	39.551788999999999	53.689273	53.678308000000001	Центральная	0103000020E610000001000000050000003B54539275C44340BE4EEACBD2D64A403B54539275C44340068200193AD84A4072A59E05A1C64340068200193AD84A4072A59E05A1C64340BE4EEACBD2D64A403B54539275C44340BE4EEACBD2D64A40
38814	54691	39.176383000000001	39.213366999999998	53.745471999999999	53.724497	Центральная	0103000020E610000001000000050000000249D8B7939643406A865451BCDC4A400249D8B793964340B70A62A06BDF4A40D7851F9C4F9B4340B70A62A06BDF4A40D7851F9C4F9B43406A865451BCDC4A400249D8B7939643406A865451BCDC4A40
38570	13915	39.489139999999999	39.497908000000002	53.663404	53.654957000000003	Центральная	0103000020E610000001000000050000002D95B7239CBE4340A5A487A1D5D34A402D95B7239CBE43408E041A6CEAD44A4059350873BBBF43408E041A6CEAD44A4059350873BBBF4340A5A487A1D5D34A402D95B7239CBE4340A5A487A1D5D34A40
38252	14911	39.408848999999996	39.467742999999999	53.591518000000001	53.569578	Центральная	0103000020E610000001000000050000004B00FE2955B44340B34291EEE7C84A404B00FE2955B44340677FA0DCB6CB4A406AF7AB00DFBB4340677FA0DCB6CB4A406AF7AB00DFBB4340B34291EEE7C84A404B00FE2955B44340B34291EEE7C84A40
38569	14157	39.031224000000002	39.056682000000002	53.714267	53.682644000000003	Поповка	0103000020E61000000100000005000000D76CE525FF834340C367EBE060D74A40D76CE525FF83434057CEDE196DDB4A40CD22145B4187434057CEDE196DDB4A40CD22145B41874340C367EBE060D74A40D76CE525FF834340C367EBE060D74A40
38752	13972	39.348967000000002	39.386876000000001	53.446786000000003	53.436343999999998	Зеленая	0103000020E610000001000000050000000E315EF3AAAC434025E7C41EDAB74A400E315EF3AAAC4340C4279D4830B94A40BCCD1B2785B14340C4279D4830B94A40BCCD1B2785B1434025E7C41EDAB74A400E315EF3AAAC434025E7C41EDAB74A40
38678	13679	39.465856000000002	39.481288999999997	53.642735000000002	53.624518000000002	Московская	0103000020E610000001000000050000009C525E2BA1BB4340B5E1B034F0CF4A409C525E2BA1BB43404E7FF62345D24A405776C1E09ABD43404E7FF62345D24A405776C1E09ABD4340B5E1B034F0CF4A409C525E2BA1BB4340B5E1B034F0CF4A40
38755	14829	39.214677999999999	39.240639000000002	53.548253000000003	53.533185000000003	Центральная	0103000020E61000000100000005000000D99596917A9B4340E0DBF4673FC44A40D99596917A9B43408A7780272DC64A4032923D42CD9E43408A7780272DC64A4032923D42CD9E4340E0DBF4673FC44A40D99596917A9B4340E0DBF4673FC44A40
38713	13772	39.588099	39.602598	53.676138000000002	53.663367000000001	Вишневая	0103000020E61000000100000005000000B8E7F9D346CB4340711FB935E9D44A40B8E7F9D346CB43409BCAA2B08BD64A40485167EE21CD43409BCAA2B08BD64A40485167EE21CD4340711FB935E9D44A40B8E7F9D346CB4340711FB935E9D44A40
38576	13493	39.557977999999999	39.588773000000003	53.568862000000003	53.559161000000003	Центральная	0103000020E6100000010000000500000099F1B6D26BC743406E19709692C74A4099F1B6D26BC74340F5F75278D0C84A4048E2E5E95CCB4340F5F75278D0C84A4048E2E5E95CCB43406E19709692C74A4099F1B6D26BC743406E19709692C74A40
38751	13582	39.481001999999997	39.496074999999998	53.607522000000003	53.600197000000001	Ленина	0103000020E61000000100000005000000C1A7397991BD434023145B41D3CC4A40C1A7397991BD4340DECCE847C3CD4A407DAEB6627FBF4340DECCE847C3CD4A407DAEB6627FBF434023145B41D3CC4A40C1A7397991BD434023145B41D3CC4A40
38677	13354	39.316206000000001	39.341278000000003	53.646402000000002	53.633628000000002	Центральная	0103000020E6100000010000000500000045662E7079A843403AEAE8B81AD14A4045662E7079A84340D508FD4CBDD24A40126C5CFFAEAB4340D508FD4CBDD24A40126C5CFFAEAB43403AEAE8B81AD14A4045662E7079A843403AEAE8B81AD14A40
38628	14055	39.151750999999997	39.189785999999998	53.451425	53.433109000000002	Центральная	0103000020E610000001000000050000005111A7936C934340384D9F1D70B74A405111A7936C93434064CC5D4BC8B94A408C9E5BE84A98434064CC5D4BC8B94A408C9E5BE84A984340384D9F1D70B74A405111A7936C934340384D9F1D70B74A40
38620	14255	39.049433000000001	39.065899000000002	53.673347999999997	53.658825999999998	Молодежная	0103000020E61000000100000005000000ED2B0FD25386434093E00D6954D44A40ED2B0FD253864340DB696B4430D64A4068EBE0606F884340DB696B4430D64A4068EBE0606F88434093E00D6954D44A40ED2B0FD25386434093E00D6954D44A40
38756	14621	39.130865	39.169583000000003	53.720959999999998	53.701183	Центральная	0103000020E6100000010000000500000074982F2FC09043406EC1525DC0D94A4074982F2FC0904340B1DCD26A48DC4A40927A4FE5B4954340B1DCD26A48DC4A40927A4FE5B49543406EC1525DC0D94A4074982F2FC09043406EC1525DC0D94A40
38723	13486	39.670959000000003	39.683069000000003	53.595526	53.584938000000001	Центральная	0103000020E610000001000000050000007BFA08FCE1D543400518963FDFCA4A407BFA08FCE1D5434077F52A323ACC4A40AAF413CE6ED7434077F52A323ACC4A40AAF413CE6ED743400518963FDFCA4A407BFA08FCE1D543400518963FDFCA4A40
38634	13207	39.191538000000001	39.224756999999997	53.657817999999999	53.638576999999998	Школьная	0103000020E610000001000000050000007BF8325184984340287D21E4BCD14A407BF83251849843402D5C566133D44A4006465ED6C49C43402D5C566133D44A4006465ED6C49C4340287D21E4BCD14A407BF8325184984340287D21E4BCD14A40
75057	60465	39.532691	39.548105999999997	53.645964999999997	53.637338	Центральная	0103000020E61000000100000005000000D0EFFB372FC44340C03FA54A94D14A40D0EFFB372FC4434029AE2AFBAED24A40E55E605628C6434029AE2AFBAED24A40E55E605628C64340C03FA54A94D14A40D0EFFB372FC44340C03FA54A94D14A40
38568	14146	39.271073999999999	39.294592000000002	53.431187999999999	53.416651999999999	Ерзикова	0103000020E61000000100000005000000E065868DB2A2434010E84CDA54B54A40E065868DB2A24340BD361B2B31B74A40E5D4CE30B5A54340BD361B2B31B74A40E5D4CE30B5A5434010E84CDA54B54A40E065868DB2A2434010E84CDA54B54A40
38710	13206	39.754179000000001	39.778433999999997	53.869422999999998	53.854835999999999	Молодежная	0103000020E610000001000000050000003D2AFEEF88E04340C3B81B446BED4A403D2AFEEF88E04340F2B1BB4049EF4A40170CAEB9A3E34340F2B1BB4049EF4A40170CAEB9A3E34340C3B81B446BED4A403D2AFEEF88E04340C3B81B446BED4A40
38719	13022	39.937533999999999	39.954647000000001	54.021230000000003	54.011533	Новая	0103000020E61000000100000005000000AC71361D01F8434092E9D0E979014B40AC71361D01F84340D8D825AAB7024B40BD1C76DF31FA4340D8D825AAB7024B40BD1C76DF31FA434092E9D0E979014B40AC71361D01F8434092E9D0E979014B40
38563	12928	39.732135	39.755696999999998	53.966652000000003	53.947462999999999	Верхняя	0103000020E61000000100000005000000E4A08499B6DD4340C495B37746F94A40E4A08499B6DD4340774EB340BBFB4A40B857E6ADBAE04340774EB340BBFB4A40B857E6ADBAE04340C495B37746F94A40E4A08499B6DD4340C495B37746F94A40
38560	12247	40.197642000000002	40.213695000000001	53.953963999999999	53.939948000000001	Центральная	0103000020E61000000100000005000000742843554C19444066F84F3750F84A40742843554C194440DAC70A7E1BFA4A40CC28965B5A1B4440DAC70A7E1BFA4A40CC28965B5A1B444066F84F3750F84A40742843554C19444066F84F3750F84A40
38561	12812	40.142108	40.168626000000003	54.076180999999998	54.051186000000001	Набережная	0103000020E61000000100000005000000FF3F4E9830124440AC014A438D064B40FF3F4E9830124440CDC98B4CC0094B40AEA0698995154440CDC98B4CC0094B40AEA0698995154440AC014A438D064B40FF3F4E9830124440AC014A438D064B40
38472	12726	40.294713999999999	40.329577	54.066074	54.053184000000002	Школьная	0103000020E6100000010000000500000030D63730B9254440D255BABBCE064B4030D63730B9254440D68EE21C75084B40C44142942F2A4440D68EE21C75084B40C44142942F2A4440D255BABBCE064B4030D63730B9254440D255BABBCE064B40
38255	12589	40.090266	40.115706000000003	53.953169000000003	53.922415999999998	Центральная	0103000020E610000001000000050000006AF816D68D0B444050A73CBA11F64A406AF816D68D0B4440D047197101FA4A40BAF94674CF0E4440D047197101FA4A40BAF94674CF0E444050A73CBA11F64A406AF816D68D0B444050A73CBA11F64A40
38562	12497	40.021428	40.05021	54.089416999999997	54.065703999999997	Новая	0103000020E61000000100000005000000FE9B1727BE024440B29B19FD68084B40FE9B1727BE0244406C5A2904720B4B4051F701486D0644406C5A2904720B4B4051F701486D064440B29B19FD68084B40FE9B1727BE024440B29B19FD68084B40
38476	12479	40.080753000000001	40.128346000000001	54.036203	54.013506	Молодежная	0103000020E61000000100000005000000E606431D560A44405F268A90BA014B40E606431D560A44403082C64CA2044B40454948A46D1044403082C64CA2044B40454948A46D1044405F268A90BA014B40E606431D560A44405F268A90BA014B40
38559	12392	39.835997999999996	39.859588000000002	53.964230999999998	53.941988000000002	Новая 	0103000020E61000000100000005000000BDC282FB01EB4340BB9C121093F84A40BDC282FB01EB43400A65E1EB6BFB4A405C04C6FA06EE43400A65E1EB6BFB4A405C04C6FA06EE4340BB9C121093F84A40BDC282FB01EB4340BB9C121093F84A40
38564	22014	39.913316000000002	39.935566999999999	53.980531999999997	53.968128999999998	Кукуевская	0103000020E61000000100000005000000EF74E789E7F4434093A7ACA6EBFB4A40EF74E789E7F443403A57941282FD4A40C11BD2A8C0F743403A57941282FD4A40C11BD2A8C0F7434093A7ACA6EBFB4A40EF74E789E7F4434093A7ACA6EBFB4A40
38566	12860	40.253382000000002	40.268680000000003	54.026820999999998	54.013537999999997	Лесная	0103000020E6100000010000000500000092B245D26E2044406AA0F99CBB014B4092B245D26E2044404AECDADE6E034B406E8B321B642244404AECDADE6E034B406E8B321B642244406AA0F99CBB014B4092B245D26E2044406AA0F99CBB014B40
38565	12338	40.221474000000001	40.248145000000001	54.101514000000002	54.079265999999997	Цветочная	0103000020E6100000010000000500000008759142591C4440A5D76663250A4B4008759142591C4440070B2769FE0C4B403DD52137C31F4440070B2769FE0C4B403DD52137C31F4440A5D76663250A4B4008759142591C4440A5D76663250A4B40
37921	11153	39.991568000000001	40.068823000000002	53.945242	53.899371000000002	Школьная	0103000020E610000001000000050000004CE141B3EBFE434044FCC3961EF34A404CE141B3EBFE43401F679AB0FDF84A40371B2B31CF0844401F679AB0FDF84A40371B2B31CF08444044FCC3961EF34A404CE141B3EBFE434044FCC3961EF34A40
38197	11153	39.991568000000001	40.068823000000002	53.945242	53.899371000000002	Шахтерская	0103000020E610000001000000050000004CE141B3EBFE434044FCC3961EF34A404CE141B3EBFE43401F679AB0FDF84A40371B2B31CF0844401F679AB0FDF84A40371B2B31CF08444044FCC3961EF34A404CE141B3EBFE434044FCC3961EF34A40
38195	11153	39.991568000000001	40.068823000000002	53.945242	53.899371000000002	Маяковского	0103000020E610000001000000050000004CE141B3EBFE434044FCC3961EF34A404CE141B3EBFE43401F679AB0FDF84A40371B2B31CF0844401F679AB0FDF84A40371B2B31CF08444044FCC3961EF34A404CE141B3EBFE434044FCC3961EF34A40
38504	11153	39.991568000000001	40.068823000000002	53.945242	53.899371000000002	Заводская	0103000020E610000001000000050000004CE141B3EBFE434044FCC3961EF34A404CE141B3EBFE43401F679AB0FDF84A40371B2B31CF0844401F679AB0FDF84A40371B2B31CF08444044FCC3961EF34A404CE141B3EBFE434044FCC3961EF34A40
38555	11338	40.008187	40.033195999999997	53.863917000000001	53.851160999999998	Луговая	0103000020E610000001000000050000004DA088450C014440B950F9D7F2EC4A404DA088450C014440AEBA0ED594EE4A40D32D3BC43F044440AEBA0ED594EE4A40D32D3BC43F044440B950F9D7F2EC4A404DA088450C014440B950F9D7F2EC4A40
38557	12099	40.163325999999998	40.186691000000003	53.901414000000003	53.885787000000001	микрорайон Каменный карьер	0103000020E61000000100000005000000124BCADDE7144440691CEA7761F14A40124BCADDE71444400A14B18861F34A4091BA9D7DE51744400A14B18861F34A4091BA9D7DE5174440691CEA7761F14A40124BCADDE7144440691CEA7761F14A40
38467	12159	40.191192000000001	40.221429000000001	53.988781000000003	53.974463999999998	Школьная	0103000020E61000000100000005000000E0A0BDFA781844408E90813CBBFC4A40E0A0BDFA78184440FEF3346090FE4A4068B114C9571C4440FEF3346090FE4A4068B114C9571C44408E90813CBBFC4A40E0A0BDFA781844408E90813CBBFC4A40
38466	11900	40.125435000000003	40.159508000000002	53.885500999999998	53.865955999999997	Школьная	0103000020E610000001000000050000000B630B410E10444032E36DA5D7EE4A400B630B410E104440A3C9C51858F14A40A6B915C26A144440A3C9C51858F14A40A6B915C26A14444032E36DA5D7EE4A400B630B410E10444032E36DA5D7EE4A40
38558	12011	40.217987999999998	40.248081999999997	53.867792999999999	53.848737999999997	Центральный переулок	0103000020E61000000100000005000000D175E107E71B4440AC6F6072A3EC4A40D175E107E71B44404F594DD713EF4A40F65CA626C11F44404F594DD713EF4A40F65CA626C11F4440AC6F6072A3EC4A40D175E107E71B4440AC6F6072A3EC4A40
38827	54696	40.099787999999997	40.112625000000001	53.918678	53.911645999999998	Центральная	0103000020E6100000010000000500000041446ADAC50C4440BDC3EDD0B0F44A4041446ADAC50C444000C79E3D97F54A4023DBF97E6A0E444000C79E3D97F54A4023DBF97E6A0E4440BDC3EDD0B0F44A4041446ADAC50C4440BDC3EDD0B0F44A40
38556	11672	39.831460999999997	39.870376	53.844583999999998	53.834919999999997	Центральная	0103000020E61000000100000005000000217365506DEA43405E6397A8DEEA4A40217365506DEA4340C85C19541BEC4A40959C137B68EF4340C85C19541BEC4A40959C137B68EF43405E6397A8DEEA4A40217365506DEA43405E6397A8DEEA4A40
38470	11652	39.974302999999999	39.994101000000001	53.934997000000003	53.919139000000001	Братьев Лукьяновых	0103000020E6100000010000000500000085B2F0F5B5FC434034BDC458A6F54A4085B2F0F5B5FC4340D76D50FBADF74A40E0F599B33EFF4340D76D50FBADF74A40E0F599B33EFF434034BDC458A6F54A4085B2F0F5B5FC434034BDC458A6F54A40
38631	13069	39.856444000000003	39.877006000000002	54.043087	54.020446999999997	Полевая	0103000020E610000001000000050000007F6DFDF49FED43409126DE019E024B407F6DFDF49FED4340FEF0F3DF83054B40A9328CBB41F04340FEF0F3DF83054B40A9328CBB41F043409126DE019E024B407F6DFDF49FED43409126DE019E024B40
38554	11571	39.853776000000003	39.877212999999998	53.92774	53.919987999999996	Новая	0103000020E610000001000000050000000B0E2F8848ED4340315BB22AC2F54A400B0E2F8848ED434074982F2FC0F64A402250FD8348F0434074982F2FC0F64A402250FD8348F04340315BB22AC2F54A400B0E2F8848ED4340315BB22AC2F54A40
38847	54687	39.672593999999997	40.438794000000001	54.137298999999999	53.806998999999998	Школьная	0103000020E610000001000000050000002FBE688F17D64340CD7344BE4BE74A402FBE688F17D6434002637D0393114B402CD7DB662A38444002637D0393114B402CD7DB662A384440CD7344BE4BE74A402FBE688F17D64340CD7344BE4BE74A40
38507	9795	40.505502999999997	40.583278999999997	55.161130999999997	55.134003	Советская	0103000020E61000000100000005000000D3838252B44044406F48A30227914B40D3838252B440444096AFCBF09F944B40C7B8E2E2A84A444096AFCBF09F944B40C7B8E2E2A84A44406F48A30227914B40D3838252B44044406F48A30227914B40
38056	9795	40.505502999999997	40.583278999999997	55.161130999999997	55.134003	Ленина	0103000020E61000000100000005000000D3838252B44044406F48A30227914B40D3838252B440444096AFCBF09F944B40C7B8E2E2A84A444096AFCBF09F944B40C7B8E2E2A84A44406F48A30227914B40D3838252B44044406F48A30227914B40
38196	9580	40.164906999999999	40.189628999999996	55.141742000000001	55.126097000000001	Московская	0103000020E61000000100000005000000D4F02DAC1B154440D68F4DF223904B40D4F02DAC1B1544401D3C139A24924B40C4AF58C3451844401D3C139A24924B40C4AF58C345184440D68F4DF223904B40D4F02DAC1B154440D68F4DF223904B40
37935	9580	40.164906999999999	40.189628999999996	55.141742000000001	55.126097000000001	Ленина	0103000020E61000000100000005000000D4F02DAC1B154440D68F4DF223904B40D4F02DAC1B1544401D3C139A24924B40C4AF58C3451844401D3C139A24924B40C4AF58C345184440D68F4DF223904B40D4F02DAC1B154440D68F4DF223904B40
38508	9580	40.164906999999999	40.189628999999996	55.141742000000001	55.126097000000001	Интернациональная	0103000020E61000000100000005000000D4F02DAC1B154440D68F4DF223904B40D4F02DAC1B1544401D3C139A24924B40C4AF58C3451844401D3C139A24924B40C4AF58C345184440D68F4DF223904B40D4F02DAC1B154440D68F4DF223904B40
38055	9580	40.164906999999999	40.189628999999996	55.141742000000001	55.126097000000001	Есенина	0103000020E61000000100000005000000D4F02DAC1B154440D68F4DF223904B40D4F02DAC1B1544401D3C139A24924B40C4AF58C3451844401D3C139A24924B40C4AF58C345184440D68F4DF223904B40D4F02DAC1B154440D68F4DF223904B40
38553	10924	40.558216000000002	40.572966999999998	55.168849999999999	55.165425999999997	9 Дружбы	0103000020E610000001000000050000004E0D349F734744403CF4DDAD2C954B404E0D349F73474440FDF675E09C954B40F7578FFB56494440FDF675E09C954B40F7578FFB564944403CF4DDAD2C954B404E0D349F734744403CF4DDAD2C954B40
38464	10007	39.938504999999999	39.986493000000003	54.967993	54.934345	1 Мая	0103000020E61000000100000005000000F5108DEE20F843402F17F19D98774B40F5108DEE20F84340E3E0D231E77B4B40D15D126745FE4340E3E0D231E77B4B40D15D126745FE43402F17F19D98774B40F5108DEE20F843402F17F19D98774B40
38811	54690	40.173566999999998	40.197049	55.075479000000001	55.063786999999998	улица Центральная	0103000020E6100000010000000500000019558671371644407974232C2A884B4019558671371644407444BE4BA9894B40D15AD1E6381944407444BE4BA9894B40D15AD1E6381944407974232C2A884B4019558671371644407974232C2A884B40
38100	10257	40.195673999999997	40.224043000000002	55.125433000000001	55.097816000000002	Красный Октябрь	0103000020E61000000100000005000000B8567BD80B1944404583143C858C4B40B8567BD80B1944406A6B44300E904B40E9F2E670AD1C44406A6B44300E904B40E9F2E670AD1C44404583143C858C4B40B8567BD80B1944404583143C858C4B40
37966	9944	40.075147000000001	40.095835999999998	55.060254999999998	55.048966999999998	Школьная	0103000020E610000001000000050000003EB2B96A9E094440A7CAF78C44864B403EB2B96A9E094440D235936FB6874B40C5E3A25A440C4440D235936FB6874B40C5E3A25A440C4440A7CAF78C44864B403EB2B96A9E094440A7CAF78C44864B40
38085	8651	41.283337000000003	41.308588	55.011674999999997	54.992637000000002	Советская	0103000020E61000000100000005000000965F066344A4444058E6ADBA0E7F4B40965F066344A444402497FF907E814B4012F8C3CF7FA744402497FF907E814B4012F8C3CF7FA7444058E6ADBA0E7F4B40965F066344A4444058E6ADBA0E7F4B40
38194	8601	41.116627000000001	41.163465000000002	54.948467999999998	54.910162	Академика Уткина	0103000020E61000000100000005000000516A2FA2ED8E4440EE073C3080744B40516A2FA2ED8E4440B9A6406667794B403485CE6BEC944440B9A6406667794B403485CE6BEC944440EE073C3080744B40516A2FA2ED8E4440EE073C3080744B40
38192	7133	41.728928000000003	41.764761999999997	54.980863999999997	54.948715999999997	Янина	0103000020E61000000100000005000000C19140834DDD44409198A0866F794B40C19140834DDD444070E998F38C7D4B409D9CA1B8E3E1444070E998F38C7D4B409D9CA1B8E3E144409198A0866F794B40C19140834DDD44409198A0866F794B40
38182	7133	41.728928000000003	41.764761999999997	54.980863999999997	54.948715999999997	Луначарского	0103000020E61000000100000005000000C19140834DDD44409198A0866F794B40C19140834DDD444070E998F38C7D4B409D9CA1B8E3E1444070E998F38C7D4B409D9CA1B8E3E144409198A0866F794B40C19140834DDD44409198A0866F794B40
38501	7067	41.130308999999997	41.175027	55.072257	55.044649999999997	Центральная	0103000020E61000000100000005000000EEAF1EF7AD90444019E25817B7854B40EEAF1EF7AD9044401BF4A5B73F894B406075E448679644401BF4A5B73F894B406075E4486796444019E25817B7854B40EEAF1EF7AD90444019E25817B7854B40
38234	7067	41.130308999999997	41.175027	55.072257	55.044649999999997	Первомайская	0103000020E61000000100000005000000EEAF1EF7AD90444019E25817B7854B40EEAF1EF7AD9044401BF4A5B73F894B406075E448679644401BF4A5B73F894B406075E4486796444019E25817B7854B40EEAF1EF7AD90444019E25817B7854B40
38585	5268	42.428373999999998	42.452843999999999	54.654110000000003	54.643520000000002	Центральная	0103000020E61000000100000005000000753A90F5D4364540352905DD5E524B40753A90F5D436454048FE60E0B9534B404C18CDCAF639454048FE60E0B9534B404C18CDCAF6394540352905DD5E524B40753A90F5D4364540352905DD5E524B40
38586	5336	42.473253999999997	42.498218000000001	54.435046	54.419243999999999	Школьная	0103000020E61000000100000005000000C0594A96933C4540A98592C9A9354B40C0594A96933C4540B8205B96AF374B40A723809BC53F4540B8205B96AF374B40A723809BC53F4540A98592C9A9354B40C0594A96933C4540A98592C9A9354B40
38799	5109	42.269084999999997	42.293841999999998	54.625708000000003	54.613118999999998	Почтовая	0103000020E610000001000000050000000D6C95607122454032C7F2AE7A4E4B400D6C9560712245403C6C223317504B407A185A9D9C2545403C6C223317504B407A185A9D9C25454032C7F2AE7A4E4B400D6C95607122454032C7F2AE7A4E4B40
38798	5115	42.320118000000001	42.339621000000001	54.629362	54.622179000000003	Молодежная	0103000020E61000000100000005000000336E6AA0F928454006A1BC8FA34F4B40336E6AA0F92845402EAC1BEF8E504B40750470B3782B45402EAC1BEF8E504B40750470B3782B454006A1BC8FA34F4B40336E6AA0F928454006A1BC8FA34F4B40
38707	5496	42.510786000000003	42.525328999999999	54.613394999999997	54.597405999999999	Базарная	0103000020E6100000010000000500000099A0866F614145409337C0CC774C4B4099A0866F61414540D44334BA834E4B40F8510DFB3D434540D44334BA834E4B40F8510DFB3D4345409337C0CC774C4B4099A0866F614145409337C0CC774C4B40
38709	5653	42.568682000000003	42.592855999999998	54.630071000000001	54.611935000000003	Центральная	0103000020E6100000010000000500000075E95F92CA4845408E23D6E2534E4B4075E95F92CA4845403A94A12AA6504B40629E95B4E24B45403A94A12AA6504B40629E95B4E24B45408E23D6E2534E4B4075E95F92CA4845408E23D6E2534E4B40
38622	5424	42.375742000000002	42.424359000000003	54.408230000000003	54.393109000000003	Школьная	0103000020E61000000100000005000000E8DD585018304540B3614D6551324B40E8DD585018304540809F71E140344B40B3614D6551364540809F71E140344B40B3614D6551364540B3614D6551324B40E8DD585018304540B3614D6551324B40
38500	5724	42.43318	42.496592	54.589649000000001	54.539208000000002	Центральная	0103000020E6100000010000000500000001A4367172374540ECDE8AC404454B4001A43671723745403F8F519E794B4B4045BA9F53903F45403F8F519E794B4B4045BA9F53903F4540ECDE8AC404454B4001A4367172374540ECDE8AC404454B40
38452	5724	42.43318	42.496592	54.589649000000001	54.539208000000002	Первомайская	0103000020E6100000010000000500000001A4367172374540ECDE8AC404454B4001A43671723745403F8F519E794B4B4045BA9F53903F45403F8F519E794B4B4045BA9F53903F4540ECDE8AC404454B4001A4367172374540ECDE8AC404454B40
38588	5724	42.43318	42.496592	54.589649000000001	54.539208000000002	Московская	0103000020E6100000010000000500000001A4367172374540ECDE8AC404454B4001A43671723745403F8F519E794B4B4045BA9F53903F45403F8F519E794B4B4045BA9F53903F4540ECDE8AC404454B4001A4367172374540ECDE8AC404454B40
38455	5724	42.43318	42.496592	54.589649000000001	54.539208000000002	Ленина	0103000020E6100000010000000500000001A4367172374540ECDE8AC404454B4001A43671723745403F8F519E794B4B4045BA9F53903F45403F8F519E794B4B4045BA9F53903F4540ECDE8AC404454B4001A4367172374540ECDE8AC404454B40
38484	5724	42.43318	42.496592	54.589649000000001	54.539208000000002	Касимовская	0103000020E6100000010000000500000001A4367172374540ECDE8AC404454B4001A43671723745403F8F519E794B4B4045BA9F53903F45403F8F519E794B4B4045BA9F53903F4540ECDE8AC404454B4001A4367172374540ECDE8AC404454B40
38587	5650	42.569913	42.596331999999997	54.671722000000003	54.658093999999998	Школьная	0103000020E610000001000000050000005A48C0E8F2484540CFD8976C3C544B405A48C0E8F24845407A008BFCFA554B4075C7629B544C45407A008BFCFA554B4075C7629B544C4540CFD8976C3C544B405A48C0E8F2484540CFD8976C3C544B40
38703	5214	42.423388000000003	42.440438	54.668909999999997	54.654468999999999	Центральная	0103000020E610000001000000050000006AC2F69331364540779FE3A3C5534B406AC2F69331364540D2FBC6D79E554B4034F5BA4560384540D2FBC6D79E554B4034F5BA4560384540779FE3A3C5534B406AC2F69331364540779FE3A3C5534B40
38706	5434	42.350211999999999	42.372661000000001	54.398482000000001	54.387694000000003	Почтовая	0103000020E6100000010000000500000058552FBFD32C45407F6DFDF49F314B4058552FBFD32C4540B8054B7501334B4051BF0B5BB32F4540B8054B7501334B4051BF0B5BB32F45407F6DFDF49F314B4058552FBFD32C45407F6DFDF49F314B40
38630	5053	42.097147	42.126873000000003	54.591704999999997	54.562789000000002	Почтовая	0103000020E61000000100000005000000C7F319506F0C454037C64E7809484B40C7F319506F0C454099F04BFDBC4B4B406ADFDC5F3D10454099F04BFDBC4B4B406ADFDC5F3D10454037C64E7809484B40C7F319506F0C454037C64E7809484B40
38237	4419	39.260717	39.299703999999998	54.384118000000001	54.352825000000003	Школьная	0103000020E610000001000000050000007041B62C5FA14340091B9E5E292D4B407041B62C5FA1434008E753C72A314B407D3D5FB35CA6434008E753C72A314B407D3D5FB35CA64340091B9E5E292D4B407041B62C5FA14340091B9E5E292D4B40
38096	4419	39.260717	39.299703999999998	54.384118000000001	54.352825000000003	Центральная	0103000020E610000001000000050000007041B62C5FA14340091B9E5E292D4B407041B62C5FA1434008E753C72A314B407D3D5FB35CA6434008E753C72A314B407D3D5FB35CA64340091B9E5E292D4B407041B62C5FA14340091B9E5E292D4B40
38682	3829	42.205269000000001	42.229827999999998	54.71696	54.696672999999997	Центральная	0103000020E61000000100000005000000FAF02C41461A4540CB80B3942C594B40FAF02C41461A454024456458C55B4B4040DAFF006B1D454024456458C55B4B4040DAFF006B1D4540CB80B3942C594B40FAF02C41461A4540CB80B3942C594B40
38680	2004	42.359400999999998	42.375211999999998	54.722638000000003	54.710957999999998	Центральная	0103000020E6100000010000000500000029931ADA002E45402F6AF7AB005B4B4029931ADA002E4540666CE8667F5C4B408B8862F206304540666CE8667F5C4B408B8862F2063045402F6AF7AB005B4B4029931ADA002E45402F6AF7AB005B4B40
38676	3742	42.089134000000001	42.117502999999999	54.625103000000003	54.605646	Центральная	0103000020E61000000100000005000000187B2FBE680B4540037AE1CE854D4B40187B2FBE680B4540D5D0066003504B4048179B560A0F4540D5D0066003504B4048179B560A0F4540037AE1CE854D4B40187B2FBE680B4540037AE1CE854D4B40
38800	54679	42.228185000000003	42.245423000000002	54.898933999999997	54.876143999999996	Моложежная	0103000020E610000001000000050000000938842A351D4540164B917C25704B400938842A351D454098A1F14410734B40D65757056A1F454098A1F14410734B40D65757056A1F4540164B917C25704B400938842A351D4540164B917C25704B40
38574	3596	42.151316000000001	42.171194999999997	54.833775000000003	54.817402000000001	Свестурская	0103000020E6100000010000000500000047AE9B525E134540AED7F4A0A0684B4047AE9B525E134540789CA223B96A4B408E1EBFB7E9154540789CA223B96A4B408E1EBFB7E9154540AED7F4A0A0684B4047AE9B525E134540AED7F4A0A0684B40
38625	3603	42.150516000000003	42.193860000000001	54.709038999999997	54.698706999999999	Центральная	0103000020E610000001000000050000002BC3B81B441345403E3E213B6F594B402BC3B81B44134540554B3ACAC15A4B4054008C67D0184540554B3ACAC15A4B4054008C67D01845403E3E213B6F594B402BC3B81B441345403E3E213B6F594B40
38624	3539	41.986376	42.022677000000002	54.762380999999998	54.745790999999997	Центральная	0103000020E6100000010000000500000097C79A9141FE444058535914765F4B4097C79A9141FE4440BF0B5BB395614B408AAF7614E7024540BF0B5BB395614B408AAF7614E702454058535914765F4B4097C79A9141FE444058535914765F4B40
38797	3484	42.267395999999998	42.302520000000001	54.752817	54.736514	Центральная	0103000020E61000000100000005000000658A39083A224540E8853B17465E4B40658A39083A224540B96FB54E5C604B406631B1F9B8264540B96FB54E5C604B406631B1F9B8264540E8853B17465E4B40658A39083A224540E8853B17465E4B40
38627	3425	42.281356000000002	42.307181999999997	54.877853000000002	54.855221999999998	Поляна	0103000020E610000001000000050000004644317903244540EC681CEA776D4B40464431790324454006D9B27C5D704B40BEF561BD5127454006D9B27C5D704B40BEF561BD51274540EC681CEA776D4B404644317903244540EC681CEA776D4B40
38583	3378	42.386566999999999	42.397418000000002	54.769891999999999	54.758952999999998	Зеленая	0103000020E610000001000000050000003E5B07077B314540BD19355F25614B403E5B07077B314540DCB930D28B624B40BE6BD097DE324540DCB930D28B624B40BE6BD097DE324540BD19355F25614B403E5B07077B314540BD19355F25614B40
38579	3320	41.933582000000001	41.949168	54.817644999999999	54.808487999999997	Школьная	0103000020E6100000010000000500000030116F9D7FF74440AE9AE7887C674B4030116F9D7FF74440745E6397A8684B40723447567EF94440745E6397A8684B40723447567EF94440AE9AE7887C674B4030116F9D7FF74440AE9AE7887C674B40
38262	3159	42.225022000000003	42.295864000000002	54.783726000000001	54.756745000000002	пл.Ленина	0103000020E61000000100000005000000B5705985CD1C4540AD342905DD604B40B5705985CD1C45403083312251644B4029081EDFDE2545403083312251644B4029081EDFDE254540AD342905DD604B40B5705985CD1C4540AD342905DD604B40
38095	3159	42.225022000000003	42.295864000000002	54.783726000000001	54.756745000000002	Садовая	0103000020E61000000100000005000000B5705985CD1C4540AD342905DD604B40B5705985CD1C45403083312251644B4029081EDFDE2545403083312251644B4029081EDFDE254540AD342905DD604B40B5705985CD1C4540AD342905DD604B40
38259	3159	42.225022000000003	42.295864000000002	54.783726000000001	54.756745000000002	Московская	0103000020E61000000100000005000000B5705985CD1C4540AD342905DD604B40B5705985CD1C45403083312251644B4029081EDFDE2545403083312251644B4029081EDFDE254540AD342905DD604B40B5705985CD1C4540AD342905DD604B40
38708	3089	42.020879999999998	42.044846999999997	54.728783999999997	54.716985999999999	Центральная	0103000020E61000000100000005000000FB912232AC0245404DD87E32C65B4B40FB912232AC0245408DEC4ACB485D4B406F29E78BBD0545408DEC4ACB485D4B406F29E78BBD0545404DD87E32C65B4B40FB912232AC0245404DD87E32C65B4B40
38796	3029	42.149617999999997	42.184714999999997	54.733905	54.721156000000001	Солнечная	0103000020E610000001000000050000004B72C0AE2613454037A8FDD64E5C4B404B72C0AE2613454079AF5A99F05D4B40520ABABDA417454079AF5A99F05D4B40520ABABDA417454037A8FDD64E5C4B404B72C0AE2613454037A8FDD64E5C4B40
38575	2967	42.095854000000003	42.122470999999997	54.655828999999997	54.639648000000001	Молодежная	0103000020E610000001000000050000006C98A1F1440C4540D57954FCDF514B406C98A1F1440C45405A626534F2534B40ADDA3521AD0F45405A626534F2534B40ADDA3521AD0F4540D57954FCDF514B406C98A1F1440C4540D57954FCDF514B40
38465	2918	42.011915000000002	42.045071999999998	54.684157999999996	54.654843999999997	Советская	0103000020E610000001000000050000007AAA436E86014540ACFD9DEDD1534B407AAA436E86014540FCA5457D92574B408FFB56EBC4054540FCA5457D92574B408FFB56EBC4054540ACFD9DEDD1534B407AAA436E86014540ACFD9DEDD1534B40
7969	9161	36.039574000000002	36.054782000000003	52.990138999999999	52.980066000000001	улица Цветаева	0103000020E61000000100000005000000CEE2C5C210054240F5F57CCD727D4A40CEE2C5C21005424040BFEFDFBC7E4A406A34B9180307424040BFEFDFBC7E4A406A34B91803074240F5F57CCD727D4A40CEE2C5C210054240F5F57CCD727D4A40
7824	9161	36.045557000000002	36.062786000000003	52.972990000000003	52.962035	улица Тургенева	0103000020E610000001000000050000004C8DD0CFD4054240BE4D7FF6237B4A404C8DD0CFD4054240E3AAB2EF8A7C4A40C652245F09084240E3AAB2EF8A7C4A40C652245F09084240BE4D7FF6237B4A404C8DD0CFD4054240BE4D7FF6237B4A40
7264	9161	36.101557999999997	36.105187000000001	53.009459	53.002262999999999	улица Силикатная	0103000020E61000000100000005000000D65240DAFF0C4240D47E6B274A804A40D65240DAFF0C424091D3D7F335814A40707B82C4760D424091D3D7F335814A40707B82C4760D4240D47E6B274A804A40D65240DAFF0C4240D47E6B274A804A40
7899	9161	36.082422999999999	36.085872999999999	52.985422999999997	52.977246999999998	улица Пожарная	0103000020E6100000010000000500000017B83CD68C0A42409B8E006E167D4A4017B83CD68C0A4240F4DC4257227E4A40014EEFE2FD0A4240F4DC4257227E4A40014EEFE2FD0A42409B8E006E167D4A4017B83CD68C0A42409B8E006E167D4A40
7956	9161	36.060153999999997	36.061987000000002	52.989938000000002	52.981366999999999	улица Матвеева	0103000020E610000001000000050000009E5C5320B3074240D32F116F9D7D4A409E5C5320B3074240A988D349B67E4A407AE3A430EF074240A988D349B67E4A407AE3A430EF074240D32F116F9D7D4A409E5C5320B3074240D32F116F9D7D4A40
7781	9161	36.057665999999998	36.081893000000001	52.988177	52.965924000000001	улица Максима Горького	0103000020E61000000100000005000000AA0B789961074240F435CB65A37B4A40AA0B78996107424067D47C957C7E4A40BB6246787B0A424067D47C957C7E4A40BB6246787B0A4240F435CB65A37B4A40AA0B789961074240F435CB65A37B4A40
7584	9161	36.034148000000002	36.056345	52.949751999999997	52.937570000000001	улица Латышских Стрелков	0103000020E61000000100000005000000A69C2FF65E044240F9DA334B02784A40A69C2FF65E044240C1A7397991794A4085251E5036074240C1A7397991794A4085251E5036074240F9DA334B02784A40A69C2FF65E044240F9DA334B02784A40
7363	9161	36.125363	36.135207999999999	53.001905000000001	52.998058	улица Дмитрия Блынского	0103000020E61000000100000005000000719010E50B1042406EC1525DC07F4A40719010E50B10424075594C6C3E804A402B14E97E4E11424075594C6C3E804A402B14E97E4E1142406EC1525DC07F4A40719010E50B1042406EC1525DC07F4A40
7376	9161	36.069470000000003	36.076836	52.963422999999999	52.950366000000002	улица Гагарина	0103000020E61000000100000005000000CD069964E40842407C9DD497A5794A40CD069964E40842406B9BE271517B4A40E69315C3D50942406B9BE271517B4A40E69315C3D50942407C9DD497A5794A40CD069964E40842407C9DD497A5794A40
7191	9161	36.118904000000001	36.143329000000001	52.974975000000001	52.967962999999997	переулок Южный	0103000020E610000001000000050000008AAE0B3F380F4240785E2A36E67B4A408AAE0B3F380F424074B515FBCB7C4A40C1C8CB9A5812424074B515FBCB7C4A40C1C8CB9A58124240785E2A36E67B4A408AAE0B3F380F4240785E2A36E67B4A40
7526	9161	36.041694	36.044289999999997	52.950533999999998	52.949308000000002	переулок Циолковского	0103000020E610000001000000050000003F389F3A5605424064EAAEEC82794A403F389F3A5605424037DE1D19AB794A4019C5724BAB05424037DE1D19AB794A4019C5724BAB05424064EAAEEC82794A403F389F3A5605424064EAAEEC82794A40
7479	9161	36.053147000000003	36.061078999999999	52.956567	52.952883	переулок Соляной	0103000020E61000000100000005000000B5705985CD0642400AF5F411F8794A40B5705985CD06424067B796C9707A4A4077BCC96FD107424067B796C9707A4A4077BCC96FD10742400AF5F411F8794A40B5705985CD0642400AF5F411F8794A40
7369	9161	36.108780000000003	36.115338000000001	52.992691999999998	52.989032999999999	переулок Артельный	0103000020E61000000100000005000000BD3AC780EC0D424017D522A2987E4A40BD3AC780EC0D42401B800D88107F4A4037FE4465C30E42401B800D88107F4A4037FE4465C30E424017D522A2987E4A40BD3AC780EC0D424017D522A2987E4A40
7076	9161	36.071033	36.081767999999997	52.974037000000003	52.959598999999997	набережная Дубровинского	0103000020E61000000100000005000000E8F7FD9B170942401C23D923D47A4A40E8F7FD9B17094240070C923EAD7C4A40FEEDB25F770A4240070C923EAD7C4A40FEEDB25F770A42401C23D923D47A4A40E8F7FD9B170942401C23D923D47A4A40
37919	9161	36.033788999999999	36.039574000000002	52.980066000000001	52.962409000000001	генерала Родина	0103000020E6100000010000000500000076FBAC32530442402330D637307B4A4076FBAC3253044240F5F57CCD727D4A40CEE2C5C210054240F5F57CCD727D4A40CEE2C5C2100542402330D637307B4A4076FBAC32530442402330D637307B4A40
37910	9161	36.070646000000004	36.078263999999997	52.965001000000001	52.953491	Черкасская	0103000020E61000000100000005000000EFCB99ED0A094240E2033BFE0B7A4A40EFCB99ED0A094240BCCD1B27857B4A40213A048E040A4240BCCD1B27857B4A40213A048E040A4240E2033BFE0B7A4A40EFCB99ED0A094240E2033BFE0B7A4A40
37999	9161	36.042923999999999	36.061430000000001	52.961216	52.956046000000001	Фридриха Энгельса	0103000020E61000000100000005000000541B9C887E0542405EBC1FB75F7A4A40541B9C887E0542402B323A20097B4A40247F30F0DC0742402B323A20097B4A40247F30F0DC0742405EBC1FB75F7A4A40541B9C887E0542405EBC1FB75F7A4A40
7747	9161	36.088523000000002	36.088757000000001	52.935963000000001	52.930850999999997	Узловая улица	0103000020E61000000100000005000000CFF8BEB8540B42407539252026774A40CFF8BEB8540B42400EA2B5A2CD774A404225AE635C0B42400EA2B5A2CD774A404225AE635C0B42407539252026774A40CFF8BEB8540B42407539252026774A40
37925	9161	36.116774999999997	36.131875999999998	52.986311999999998	52.971986999999999	Тульская	0103000020E61000000100000005000000C5FEB27BF20E42408E91EC116A7C4A40C5FEB27BF20E424080D3BB783F7E4A404B901150E110424080D3BB783F7E4A404B901150E11042408E91EC116A7C4A40C5FEB27BF20E42408E91EC116A7C4A40
37894	9161	36.020035	36.040309999999998	52.966498000000001	52.965049999999998	Трудовых резервов	0103000020E610000001000000050000003FE3C281900242409D8026C2867B4A403FE3C2819002424020D3DA34B67B4A40D3D9C9E02805424020D3DA34B67B4A40D3D9C9E0280542409D8026C2867B4A403FE3C281900242409D8026C2867B4A40
37920	9161	36.020035	36.040309999999998	52.966498000000001	52.965049999999998	Трудовых Резервов	0103000020E610000001000000050000003FE3C281900242409D8026C2867B4A403FE3C2819002424020D3DA34B67B4A40D3D9C9E02805424020D3DA34B67B4A40D3D9C9E0280542409D8026C2867B4A403FE3C281900242409D8026C2867B4A40
37881	9161	36.096383000000003	36.109831	52.964984999999999	52.964443000000003	Студенческая	0103000020E61000000100000005000000F8713447560C424096ED43DE727B4A40F8713447560C4240B610E4A0847B4A40228B34F10E0E4240B610E4A0847B4A40228B34F10E0E424096ED43DE727B4A40F8713447560C424096ED43DE727B4A40
36872	9161	35.973565999999998	36.192557000000001	53.040787000000002	52.895389999999999	Старо-Привокзальная	0103000020E61000000100000005000000AF3F89CF9DFC41402D95B7239C724A40AF3F89CF9DFC41400D8D278238854A40D5CE30B5A51842400D8D278238854A40D5CE30B5A51842402D95B7239C724A40AF3F89CF9DFC41402D95B7239C724A40
2572	9161	36.071508999999999	36.084713999999998	52.973537999999998	52.968477999999998	Советская улица	0103000020E61000000100000005000000512FF834270942409F724C16F77B4A40512FF83427094240E5B4A7E49C7C4A40B5C189E8D70A4240E5B4A7E49C7C4A40B5C189E8D70A42409F724C16F77B4A40512FF834270942409F724C16F77B4A40
37915	9161	36.071508999999999	36.084713999999998	52.973537999999998	52.968477999999998	Советская	0103000020E61000000100000005000000512FF834270942409F724C16F77B4A40512FF83427094240E5B4A7E49C7C4A40B5C189E8D70A4240E5B4A7E49C7C4A40B5C189E8D70A42409F724C16F77B4A40512FF834270942409F724C16F77B4A40
37912	9161	36.101557999999997	36.105187000000001	53.009459	53.002262999999999	Силикатная	0103000020E61000000100000005000000D65240DAFF0C4240D47E6B274A804A40D65240DAFF0C424091D3D7F335814A40707B82C4760D424091D3D7F335814A40707B82C4760D4240D47E6B274A804A40D65240DAFF0C4240D47E6B274A804A40
37930	9161	36.055518999999997	36.069415999999997	52.976835000000001	52.966526000000002	Салтыкова-Щедрина	0103000020E610000001000000050000003FA7203F1B074240EA5DBC1FB77B4A403FA7203F1B074240494BE5ED087D4A40D9E89C9FE2084240494BE5ED087D4A40D9E89C9FE2084240EA5DBC1FB77B4A403FA7203F1B074240EA5DBC1FB77B4A40
7300	9161	36.142817000000001	36.155501000000001	53.022694000000001	53.012081000000002	Рощинская улица	0103000020E610000001000000050000000B28D4D34712424095F3C5DE8B814A400B28D4D34712424060E811A3E7824A4066BFEE74E713424060E811A3E7824A4066BFEE74E713424095F3C5DE8B814A400B28D4D34712424095F3C5DE8B814A40
37874	9161	36.142817000000001	36.155501000000001	53.022694000000001	53.012081000000002	Рощинская	0103000020E610000001000000050000000B28D4D34712424095F3C5DE8B814A400B28D4D34712424060E811A3E7824A4066BFEE74E713424060E811A3E7824A4066BFEE74E713424095F3C5DE8B814A400B28D4D34712424095F3C5DE8B814A40
37927	9161	36.078749000000002	36.082900000000002	52.973998999999999	52.970230000000001	Революции	0103000020E61000000100000005000000DECB7D72140A42408ECC237F307C4A40DECB7D72140A424019ABCDFFAB7C4A40516B9A779C0A424019ABCDFFAB7C4A40516B9A779C0A42408ECC237F307C4A40DECB7D72140A42408ECC237F307C4A40
37906	9161	36.079504	36.107298	52.968798	52.967567000000003	Пушкина	0103000020E610000001000000050000005AF3E32F2D0A42402CD8463CD97B4A405AF3E32F2D0A42401137A792017C4A408E76DCF0BB0D42401137A792017C4A408E76DCF0BB0D42402CD8463CD97B4A405AF3E32F2D0A42402CD8463CD97B4A40
37880	9161	36.063378999999998	36.068446000000002	52.971271000000002	52.969101999999999	Пролетарская гора	0103000020E61000000100000005000000682096CD1C0842407D3ECA880B7C4A40682096CD1C084240D046AE9B527C4A4061C5A9D6C2084240D046AE9B527C4A4061C5A9D6C20842407D3ECA880B7C4A40682096CD1C0842407D3ECA880B7C4A40
7162	9161	36.109202000000003	36.110692999999998	52.979047000000001	52.977952000000002	Привокзальная площадь	0103000020E610000001000000050000003354C554FA0D42406687F8872D7D4A403354C554FA0D42409B1F7F69517D4A40B4722F302B0E42409B1F7F69517D4A40B4722F302B0E42406687F8872D7D4A403354C554FA0D42406687F8872D7D4A40
37911	9161	36.030025000000002	36.061959999999999	52.983417000000003	52.969118000000002	Полесская	0103000020E61000000100000005000000FD87F4DBD703424083FB010F0C7C4A40FD87F4DBD70342404CAAB69BE07D4A4080D4264EEE0742404CAAB69BE07D4A4080D4264EEE07424083FB010F0C7C4A40FD87F4DBD703424083FB010F0C7C4A40
37908	9161	36.072164999999998	36.075676999999999	52.970609000000003	52.967323	Покровская	0103000020E610000001000000050000003A75E5B33C09424095D5743DD17B4A403A75E5B33C094240051A6CEA3C7C4A409A07B0C8AF094240051A6CEA3C7C4A409A07B0C8AF09424095D5743DD17B4A403A75E5B33C09424095D5743DD17B4A40
37917	9161	36.005868999999997	36.023448999999999	52.931669999999997	52.926633000000002	Планерная	0103000020E61000000100000005000000B587BD50C00042407B32FFE89B764A40B587BD50C000424008556AF640774A40DC0F78600003424008556AF640774A40DC0F7860000342407B32FFE89B764A40B587BD50C00042407B32FFE89B764A40
37891	9161	36.056156999999999	36.067053000000001	52.978250000000003	52.972887	Пионерская	0103000020E6100000010000000500000082380F27300742400EDAAB8F877C4A4082380F2730074240F0A7C64B377D4A40A20C553195084240F0A7C64B377D4A40A20C5531950842400EDAAB8F877C4A4082380F27300742400EDAAB8F877C4A40
37883	9161	36.110495999999998	36.125048	52.984994	52.970311000000002	Паровозная	0103000020E610000001000000050000005E2BA1BB240E42407BF99D26337C4A405E2BA1BB240E4240CC608C48147E4A401137A79201104240CC608C48147E4A401137A792011042407BF99D26337C4A405E2BA1BB240E42407BF99D26337C4A40
37870	9161	36.049114000000003	36.063352000000002	52.963830000000002	52.954804000000003	Панчука	0103000020E610000001000000050000004CE3175E49064240850B7904377A4A404CE3175E49064240AC730CC85E7B4A406F1118EB1B084240AC730CC85E7B4A406F1118EB1B084240850B7904377A4A404CE3175E49064240850B7904377A4A40
37901	9161	36.102913999999998	36.108600000000003	52.978769999999997	52.978239000000002	Орджоникидзе	0103000020E61000000100000005000000782634492C0D4240FC5580EF367D4A40782634492C0D42402827DA55487D4A403D2CD49AE60D42402827DA55487D4A403D2CD49AE60D4240FC5580EF367D4A40782634492C0D4240FC5580EF367D4A40
37890	9161	36.052697999999999	36.078102999999999	52.992897999999997	52.967827	Октябрьская	0103000020E610000001000000050000004548DDCEBE064240C89750C1E17B4A404548DDCEBE064240C4211B48177F4A40185C7347FF094240C4211B48177F4A40185C7347FF094240C89750C1E17B4A404548DDCEBE064240C89750C1E17B4A40
7980	9161	36.030501000000001	36.055294000000004	52.99492	52.977398999999998	Наугорское шоссе	0103000020E6100000010000000500000066BFEE74E7034240511212691B7D4A4066BFEE74E70342407311DF89597F4A4020D5B0DF130742407311DF89597F4A4020D5B0DF13074240511212691B7D4A4066BFEE74E7034240511212691B7D4A40
7375	9161	36.107782999999998	36.155501000000001	53.012081000000002	52.983964	Московское шоссе	0103000020E610000001000000050000004A0856D5CB0D42407E384888F27D4A404A0856D5CB0D424095F3C5DE8B814A4066BFEE74E713424095F3C5DE8B814A4066BFEE74E71342407E384888F27D4A404A0856D5CB0D42407E384888F27D4A40
37892	9161	36.072659000000002	36.107837000000004	52.984008000000003	52.966113	Московская	0103000020E610000001000000050000004A61DEE34C094240C79E3D97A97B4A404A61DEE34C0942404E8061F9F37D4A403E26529ACD0D42404E8061F9F37D4A403E26529ACD0D4240C79E3D97A97B4A404A61DEE34C094240C79E3D97A97B4A40
37885	9161	36.135936000000001	36.150309	53.017147000000001	53.008560000000003	Металлургов	0103000020E61000000100000005000000AE2CD15966114240E2067C7E18814A40AE2CD15966114240BD1C76DF31824A40B1A547533D134240BD1C76DF31824A40B1A547533D134240E2067C7E18814A40AE2CD15966114240E2067C7E18814A40
37899	9161	36.059849	36.07009	52.960070999999999	52.944629999999997	Маяковского	0103000020E6100000010000000500000062D9CC21A90742400569C6A2E9784A4062D9CC21A9074240446B459BE37A4A4069E388B5F8084240446B459BE37A4A4069E388B5F80842400569C6A2E9784A4062D9CC21A90742400569C6A2E9784A40
37914	9161	36.008752999999999	36.021248	52.925736999999998	52.923228999999999	Машкарина	0103000020E61000000100000005000000F65E7CD11E01424001DC2C5E2C764A40F65E7CD11E0142403CD9CD8C7E764A407E8D2441B80242403CD9CD8C7E764A407E8D2441B802424001DC2C5E2C764A40F65E7CD11E01424001DC2C5E2C764A40
37932	9161	36.043041000000002	36.051791000000001	52.979447999999998	52.973353000000003	Матросова	0103000020E610000001000000050000008EB1135E82054240543BC3D4967C4A408EB1135E82054240F910548D5E7D4A40139D6516A1064240F910548D5E7D4A40139D6516A1064240543BC3D4967C4A408EB1135E82054240543BC3D4967C4A40
7637	9161	36.049356000000003	36.059310000000004	52.939920000000001	52.935811999999999	Маслозаводской переулок	0103000020E6100000010000000500000042EE224C51064240289A07B0C8774A4042EE224C510642409C6D6E4C4F784A40B3295778970742409C6D6E4C4F784A40B329577897074240289A07B0C8774A4042EE224C51064240289A07B0C8774A40
37887	9161	36.131256	36.145547999999998	53.013246000000002	53.006224000000003	Маринченко	0103000020E61000000100000005000000AFB321FFCC104240A439B2F2CB804A40AFB321FFCC104240C366800BB2814A40C5FF1D51A1124240C366800BB2814A40C5FF1D51A1124240A439B2F2CB804A40AFB321FFCC104240A439B2F2CB804A40
37905	9161	36.057665999999998	36.081893000000001	52.988177	52.965924000000001	Максима Горького	0103000020E61000000100000005000000AA0B789961074240F435CB65A37B4A40AA0B78996107424067D47C957C7E4A40BB6246787B0A424067D47C957C7E4A40BB6246787B0A4240F435CB65A37B4A40AA0B789961074240F435CB65A37B4A40
37886	9161	36.049078000000002	36.068750999999999	52.954124999999998	52.947859000000001	МОПРа	0103000020E61000000100000005000000FF791A3048064240111C977153794A40FF791A3048064240E3A59BC4207A4A409D4830D5CC084240E3A59BC4207A4A409D4830D5CC084240111C977153794A40FF791A3048064240111C977153794A40
37875	9161	36.089215000000003	36.090445000000003	53.001325999999999	52.994729999999997	Льва Толстого	0103000020E6100000010000000500000005A8A9656B0B4240CF2C0950537F4A4005A8A9656B0B424037514B732B804A401A8BA6B3930B424037514B732B804A401A8BA6B3930B4240CF2C0950537F4A4005A8A9656B0B4240CF2C0950537F4A40
37879	9161	36.095647	36.117762999999997	52.958064	52.948608	Ливенская	0103000020E61000000100000005000000F27A30293E0C4240AB5CA8FC6B794A40F27A30293E0C4240CBBC55D7A17A4A40E4D6A4DB120F4240CBBC55D7A17A4A40E4D6A4DB120F4240AB5CA8FC6B794A40F27A30293E0C4240AB5CA8FC6B794A40
37923	9161	36.109642000000001	36.110613000000001	52.972768000000002	52.965012000000002	Лесная	0103000020E610000001000000050000004F22C2BF080E4240B01F6283857B4A404F22C2BF080E4240344C6DA9837C4A4098C11891280E4240344C6DA9837C4A4098C11891280E4240B01F6283857B4A404F22C2BF080E4240B01F6283857B4A40
37896	9161	36.048234000000001	36.060153999999997	52.981366999999999	52.972464000000002	Лескова	0103000020E6100000010000000500000013471E882C064240C8444AB3797C4A4013471E882C064240D32F116F9D7D4A409E5C5320B3074240D32F116F9D7D4A409E5C5320B3074240C8444AB3797C4A4013471E882C064240C8444AB3797C4A40
37888	9161	36.034148000000002	36.056345	52.949751999999997	52.937570000000001	Латышских Стрелков	0103000020E61000000100000005000000A69C2FF65E044240F9DA334B02784A40A69C2FF65E044240C1A7397991794A4085251E5036074240C1A7397991794A4085251E5036074240F9DA334B02784A40A69C2FF65E044240F9DA334B02784A40
7722	9161	35.993436000000003	36.020592000000001	52.924363	52.909649000000002	Кромское шоссе	0103000020E61000000100000005000000A4552DE928FF414068EBE0606F744A40A4552DE928FF4140F450DB8651764A40954737C2A2024240F450DB8651764A40954737C2A202424068EBE0606F744A40A4552DE928FF414068EBE0606F744A40
37904	9161	36.060153999999997	36.071212000000003	52.981366999999999	52.975962000000003	Красноармейская	0103000020E610000001000000050000009E5C5320B3074240C311A452EC7C4A409E5C5320B3074240D32F116F9D7D4A40988A8D791D094240D32F116F9D7D4A40988A8D791D094240C311A452EC7C4A409E5C5320B3074240C311A452EC7C4A40
37876	9161	36.020969999999998	36.067447999999999	52.962131999999997	52.924798000000003	Комсомольская	0103000020E610000001000000050000003B191C25AF024240FFB3E6C75F764A403B191C25AF024240B0373124277B4A401E17D522A2084240B0373124277B4A401E17D522A2084240FFB3E6C75F764A403B191C25AF024240FFB3E6C75F764A40
37922	9161	36.037750000000003	36.044604	52.993921999999998	52.990036000000003	Картукова	0103000020E6100000010000000500000046B6F3FDD40442406CEEE87FB97E4A4046B6F3FDD404424030630AD6387F4A40A9A27895B505424030630AD6387F4A40A9A27895B50542406CEEE87FB97E4A4046B6F3FDD40442406CEEE87FB97E4A40
7573	9161	36.023691999999997	36.049050999999999	52.946973999999997	52.94088	Карачевское шоссе	0103000020E61000000100000005000000A296E65608034240F1BA7EC16E784A40A296E65608034240C614AC7136794A40056B9C4D47064240C614AC7136794A40056B9C4D47064240F1BA7EC16E784A40A296E65608034240F1BA7EC16E784A40
7626	9161	36.046858999999998	36.058931999999999	52.949784999999999	52.942594999999997	Карачевский переулок	0103000020E61000000100000005000000FA42C879FF054240C22FF5F3A6784A40FA42C879FF0542409D9D0C8E92794A400C5872158B0742409D9D0C8E92794A400C5872158B074240C22FF5F3A6784A40FA42C879FF054240C22FF5F3A6784A40
38000	9161	36.045529999999999	36.065787	52.962403000000002	52.949595000000002	Карачевская	0103000020E61000000100000005000000527E52EDD3054240FAB836548C794A40527E52EDD305424041498105307B4A4040C05AB56B08424041498105307B4A4040C05AB56B084240FAB836548C794A40527E52EDD3054240FAB836548C794A40
37903	9161	36.054782000000003	36.076117000000004	52.990388000000003	52.989694	Игнатова	0103000020E610000001000000050000006A34B918030742401286014BAE7E4A406A34B91803074240E92CB308C57E4A40B7D5AC33BE094240E92CB308C57E4A40B7D5AC33BE0942401286014BAE7E4A406A34B918030742401286014BAE7E4A40
37852	9161	36.092556000000002	36.097442999999998	52.973016999999999	52.959789000000001	Емельяна Пугачева	0103000020E61000000100000005000000388600E0D80B4240C007AF5DDA7A4A40388600E0D80B4240DCB930D28B7C4A40B01C2103790C4240DCB930D28B7C4A40B01C2103790C4240C007AF5DDA7A4A40388600E0D80B4240C007AF5DDA7A4A40
37926	9161	36.116236000000001	36.128290999999997	52.984572	52.980331999999997	Деповская	0103000020E61000000100000005000000164F3DD2E00E4240739CDB847B7D4A40164F3DD2E00E424056478E74067E4A4081AFE8D66B10424056478E74067E4A4081AFE8D66B104240739CDB847B7D4A40164F3DD2E00E4240739CDB847B7D4A40
37893	9161	36.092143	36.110657000000003	52.974063999999998	52.972642999999998	Грузовая	0103000020E6100000010000000500000015C78157CB0B424077D7D9907F7C4A4015C78157CB0B4240001B1021AE7C4A40680932022A0E4240001B1021AE7C4A40680932022A0E424077D7D9907F7C4A4015C78157CB0B424077D7D9907F7C4A40
37884	9161	36.059310000000004	36.076889999999999	52.950366000000002	52.935778999999997	Городская	0103000020E61000000100000005000000B3295778970742404CA4349BC7774A40B3295778970742407C9DD497A5794A40D9B11188D70942407C9DD497A5794A40D9B11188D70942404CA4349BC7774A40B3295778970742404CA4349BC7774A40
37916	9161	36.082154000000003	36.085523000000002	52.974443000000001	52.971266	Герцена	0103000020E61000000100000005000000289EB305840A4240BEDBBC71527C4A40289EB305840A42407768588CBA7C4A402507EC6AF20A42407768588CBA7C4A402507EC6AF20A4240BEDBBC71527C4A40289EB305840A4240BEDBBC71527C4A40
7368	9161	36.065480999999998	36.074050999999997	52.963228000000001	52.962024	Воскресенский переулок	0103000020E6100000010000000500000033C170AE61084240CAFB389A237B4A4033C170AE61084240B64B1B0E4B7B4A40389ECF807A094240B64B1B0E4B7B4A40389ECF807A094240CAFB389A237B4A4033C170AE61084240CAFB389A237B4A40
37929	9161	36.030258000000003	36.038728999999996	52.971558000000002	52.970984000000001	Веселая	0103000020E61000000100000005000000A038807EDF0342403A782634497C4A40A038807EDF034240661536035C7C4A4011346612F5044240661536035C7C4A4011346612F50442403A782634497C4A40A038807EDF0342403A782634497C4A40
37918	9161	36.032783000000002	36.062336999999999	52.961199000000001	52.946562	Васильевская	0103000020E61000000100000005000000B16EBC3B3204424074D190F128794A40B16EBC3B3204424055F99E91087B4A40562AA8A8FA07424055F99E91087B4A40562AA8A8FA07424074D190F128794A40B16EBC3B3204424074D190F128794A40
37928	9161	36.028982999999997	36.032594000000003	52.926322999999996	52.925113000000003	Бетонный переулок	0103000020E61000000100000005000000EA9106B7B50342405F0D501A6A764A40EA9106B7B50342402C4487C091764A40DE054A0A2C0442402C4487C091764A40DE054A0A2C0442405F0D501A6A764A40EA9106B7B50342405F0D501A6A764A40
37913	9161	36.023808000000002	36.048780999999998	52.940077000000002	52.925562999999997	Автовокзальная	0103000020E610000001000000050000000CB1FA230C0342409EB12FD978764A400CB1FA230C034240645C717154784A4045D5AF743E064240645C717154784A4045D5AF743E0642409EB12FD978764A400CB1FA230C0342409EB12FD978764A40
37909	9161	36.099761000000001	36.103048999999999	52.956805000000003	52.941879	Абрамова-Соколова	0103000020E610000001000000050000004835ECF7C40C424004E5B67D8F784A404835ECF7C40C42401CD31396787A4A405871AAB5300D42401CD31396787A4A405871AAB5300D424004E5B67D8F784A404835ECF7C40C424004E5B67D8F784A40
37889	9161	36.071958000000002	36.099608000000003	52.934106999999997	52.927061999999999	6-й Орловской дивизии	0103000020E61000000100000005000000C15774EB35094240A3AEB5F7A9764A40C15774EB350942407AFB73D190774A40C23577F4BF0C42407AFB73D190774A40C23577F4BF0C4240A3AEB5F7A9764A40C15774EB35094240A3AEB5F7A9764A40
37924	9161	36.077069000000002	36.078291	52.986956999999997	52.983981	 Полярная	0103000020E610000001000000050000008944A165DD0942405471E316F37D4A408944A165DD09424075C7629B547E4A401B498270050A424075C7629B547E4A401B498270050A42405471E316F37D4A408944A165DD0942405471E316F37D4A40
38175	9161	36.083933000000002	36.089950999999999	52.996313000000001	52.989944000000001	 Молодежная	0103000020E6100000010000000500000010070951BE0A42408B6F287CB67E4A4010070951BE0A424032CA332F877F4A400A9FAD83830B424032CA332F877F4A400A9FAD83830B42408B6F287CB67E4A4010070951BE0A42408B6F287CB67E4A40
37907	9161	35.973565999999998	36.192557000000001	53.040787000000002	52.895389999999999	 5 Августа	0103000020E61000000100000005000000AF3F89CF9DFC41402D95B7239C724A40AF3F89CF9DFC41400D8D278238854A40D5CE30B5A51842400D8D278238854A40D5CE30B5A51842402D95B7239C724A40AF3F89CF9DFC41402D95B7239C724A40
8979	36621	55.840679000000002	55.862931000000003	54.622633	54.613593000000002	улица Школьная	0103000020E610000001000000050000008DB7955E9BEB4B40FB0626378A4E4B408DB7955E9BEB4B4087342A70B24F4B4030DAE38574EE4B4087342A70B24F4B4030DAE38574EE4B40FB0626378A4E4B408DB7955E9BEB4B40FB0626378A4E4B40
36828	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Тургенева	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
37944	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Рева	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
36775	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Мира	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
37862	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Микрорайон Коммаш	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
37851	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Микрорайон 1	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
36915	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Машиностроителей	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
36820	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Ленина	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
36882	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Кузьмина	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
37866	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Катукова	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
36773	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Карла Маркса	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
36877	1325	36.536459000000001	36.613157000000001	53.304512000000003	53.258383000000002	Болховская	0103000020E610000001000000050000008B5242B0AA444240D36BB3B112A14A408B5242B0AA444240AA9ECC3FFAA64A402028B7ED7B4E4240AA9ECC3FFAA64A402028B7ED7B4E4240D36BB3B112A14A408B5242B0AA444240D36BB3B112A14A40
37853	54560	36.472292000000003	36.518259	52.411242000000001	52.389994000000002	Советская	0103000020E61000000100000005000000CB147310743C424070D1C952EB314A40CB147310743C4240EE5EEE93A3344A40C8ED974F56424240EE5EEE93A3344A40C8ED974F5642424070D1C952EB314A40CB147310743C424070D1C952EB314A40
37872	54560	36.472292000000003	36.518259	52.411242000000001	52.389994000000002	Ленина	0103000020E61000000100000005000000CB147310743C424070D1C952EB314A40CB147310743C4240EE5EEE93A3344A40C8ED974F56424240EE5EEE93A3344A40C8ED974F5642424070D1C952EB314A40CB147310743C424070D1C952EB314A40
38130	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Энергетиков	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36901	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Элеваторная	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
37863	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Фрунзе	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36736	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Селитренникова	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36857	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Пушкина	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
37858	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Октябрьская пл.	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36923	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Октябрьская	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36853	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Московская	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
37849	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Мира	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36881	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Максима Горького	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36911	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Ленина	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36759	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Кирова	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36921	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Карла Маркса	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36837	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Дзержинского	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
37854	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Денисова	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
37867	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	Гайдара	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36861	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	 Пухова	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36735	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	 Мира	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36817	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	 Елецкая	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36864	92	37.543532999999996	37.642339	52.442641999999999	52.394950999999999	 Гайдара	0103000020E61000000100000005000000FCA5457D92C54240E1421EC18D324A40FCA5457D92C5424003EB387EA8384A4001F9122A38D2424003EB387EA8384A4001F9122A38D24240E1421EC18D324A40FCA5457D92C54240E1421EC18D324A40
36961	22250	36.055194999999998	36.080024999999999	53.009718999999997	52.992826999999998	Строительная	0103000020E610000001000000050000008CF337A110074240FBCA83F4147F4A408CF337A1100742402D93E1783E814A4063EE5A423E0A42402D93E1783E814A4063EE5A423E0A4240FBCA83F4147F4A408CF337A110074240FBCA83F4147F4A40
36841	27538	35.173974999999999	35.268540999999999	52.885035000000002	52.841557999999999	Советская	0103000020E610000001000000050000002AA913D044964140F5D72B2CB86B4A402AA913D0449641405E68AED348714A404C512E8D5FA241405E68AED348714A404C512E8D5FA24140F5D72B2CB86B4A402AA913D044964140F5D72B2CB86B4A40
36897	27538	35.173974999999999	35.268540999999999	52.885035000000002	52.841557999999999	Ленина	0103000020E610000001000000050000002AA913D044964140F5D72B2CB86B4A402AA913D0449641405E68AED348714A404C512E8D5FA241405E68AED348714A404C512E8D5FA24140F5D72B2CB86B4A402AA913D044964140F5D72B2CB86B4A40
37994	46037	35.365243999999997	35.391402999999997	52.915177	52.901214000000003	Тургенева	0103000020E61000000100000005000000B587BD50C0AE41404359F8FA5A734A40B587BD50C0AE414094861A8524754A403447567E19B2414094861A8524754A403447567E19B241404359F8FA5A734A40B587BD50C0AE41404359F8FA5A734A40
38701	46105	35.167768000000002	35.192084999999999	52.770037000000002	52.761170999999997	Центральная	0103000020E610000001000000050000005DA8FC6B79954140F1D4230D6E614A405DA8FC6B79954140E0DA899290624A40AD86C43D96984140E0DA899290624A40AD86C43D96984140F1D4230D6E614A405DA8FC6B79954140F1D4230D6E614A40
38191	49193	34.926031000000002	34.988455000000002	52.865288999999997	52.843874999999997	Комсомольская	0103000020E61000000100000005000000850A0E2F88764140BC749318046C4A40850A0E2F88764140554B3ACAC16E4A40AA4885B1857E4140554B3ACAC16E4A40AA4885B1857E4140BC749318046C4A40850A0E2F88764140BC749318046C4A40
38077	27913	35.349730999999998	35.364300999999998	52.934019999999997	52.924857000000003	Советская	0103000020E61000000100000005000000DDB243FCC3AC4140043DD4B661764A40DDB243FCC3AC4140ABE7A4F78D774A403673486AA1AE4140ABE7A4F78D774A403673486AA1AE4140043DD4B661764A40DDB243FCC3AC4140043DD4B661764A40
38150	28054	35.224730000000001	35.246172999999999	52.796360999999997	52.787047999999999	пер. Почтовый	0103000020E610000001000000050000000D37E0F3C39C4140EC3026FDBD644A400D37E0F3C39C4140A9674128EF654A404014CC98829F4140A9674128EF654A404014CC98829F4140EC3026FDBD644A400D37E0F3C39C4140EC3026FDBD644A40
38141	28018	35.267975	35.298544999999997	52.876840000000001	52.859357000000003	Садовая	0103000020E61000000100000005000000A3923A014DA241405A4B0169FF6D4A40A3923A014DA241408EE9094B3C704A4031B1F9B836A641408EE9094B3C704A4031B1F9B836A641405A4B0169FF6D4A40A3923A014DA241405A4B0169FF6D4A40
38006	27703	35.027379000000003	35.058864999999997	52.858221	52.845517999999998	Школьный переулок	0103000020E6100000010000000500000071CCB22781834140F4160FEF396C4A4071CCB22781834140C6DE8B2FDA6D4A4084F068E388874140C6DE8B2FDA6D4A4084F068E388874140F4160FEF396C4A4071CCB22781834140F4160FEF396C4A40
38005	46132	35.105901000000003	35.137602000000001	52.808827999999998	52.792810000000003	Медведевка	0103000020E610000001000000050000008ECEF9298E8D41408CF84ECC7A654A408ECEF9298E8D4140670B08AD87674A409EEE3CF19C914140670B08AD87674A409EEE3CF19C9141408CF84ECC7A654A408ECEF9298E8D41408CF84ECC7A654A40
38420	54637	35.092695999999997	35.116689999999998	52.854022999999998	52.841493	пер. Школьный	0103000020E61000000100000005000000293C6876DD8B41400E68E90AB66B4A40293C6876DD8B414012842BA0506D4A4097E2AAB2EF8E414012842BA0506D4A4097E2AAB2EF8E41400E68E90AB66B4A40293C6876DD8B41400E68E90AB66B4A40
37861	27121	35.375081000000002	35.407626999999998	53.144970999999998	53.114075999999997	им. Пушкина	0103000020E61000000100000005000000ED2C7AA702B0414016A1D80A9A8E4A40ED2C7AA702B0414028EFE3688E924A40B9FB1C1F2DB4414028EFE3688E924A40B9FB1C1F2DB4414016A1D80A9A8E4A40ED2C7AA702B0414016A1D80A9A8E4A40
37934	27121	35.375081000000002	35.407626999999998	53.144970999999998	53.114075999999997	Школьная	0103000020E61000000100000005000000ED2C7AA702B0414016A1D80A9A8E4A40ED2C7AA702B0414028EFE3688E924A40B9FB1C1F2DB4414028EFE3688E924A40B9FB1C1F2DB4414016A1D80A9A8E4A40ED2C7AA702B0414016A1D80A9A8E4A40
37933	27121	35.375081000000002	35.407626999999998	53.144970999999998	53.114075999999997	Батова	0103000020E61000000100000005000000ED2C7AA702B0414016A1D80A9A8E4A40ED2C7AA702B0414028EFE3688E924A40B9FB1C1F2DB4414028EFE3688E924A40B9FB1C1F2DB4414016A1D80A9A8E4A40ED2C7AA702B0414016A1D80A9A8E4A40
38002	54578	35.304032999999997	35.325817000000001	53.204535999999997	53.194648000000001	Школьная	0103000020E61000000100000005000000CFF3A78DEAA64140AC1DC539EA984A40CFF3A78DEAA64140656D533C2E9A4A408CBD175FB4A94140656D533C2E9A4A408CBD175FB4A94140AC1DC539EA984A40CFF3A78DEAA64140AC1DC539EA984A40
38016	49390	35.449964999999999	35.478118000000002	53.171061000000002	53.156506	Школьная	0103000020E610000001000000050000001DACFF7398B941405BD07B6308944A401DACFF7398B941407F4FAC53E5954A4081D07AF832BD41407F4FAC53E5954A4081D07AF832BD41405BD07B6308944A401DACFF7398B941405BD07B6308944A40
75031	60451	35.367975000000001	35.388924000000003	53.115687000000001	53.103459000000001	им. Ефимова	0103000020E61000000100000005000000705F07CE19AF41400ABDFE243E8D4A40705F07CE19AF414043C9E4D4CE8E4A409450FA42C8B1414043C9E4D4CE8E4A409450FA42C8B141400ABDFE243E8D4A40705F07CE19AF41400ABDFE243E8D4A40
37975	26921	35.527380999999998	35.556944999999999	53.107444000000001	53.096494999999997	Школьная	0103000020E6100000010000000500000011C4793881C341401F9DBAF2598C4A4011C4793881C34140621399B9C08D4A40DA5548F949C74140621399B9C08D4A40DA5548F949C741401F9DBAF2598C4A4011C4793881C341401F9DBAF2598C4A40
38003	45586	35.322332000000003	35.340235	53.103940999999999	53.092278	им. Алдобаева	0103000020E61000000100000005000000263ACB2C42A94140F511F8C3CF8B4A40263ACB2C42A9414055DB4DF04D8D4A402FFA0AD28CAB414055DB4DF04D8D4A402FFA0AD28CAB4140F511F8C3CF8B4A40263ACB2C42A94140F511F8C3CF8B4A40
38036	27098	35.283076000000001	35.295651999999997	53.260382	53.253734000000001	Школьная	0103000020E61000000100000005000000292499D53BA441400FF10F5B7AA04A40292499D53BA44140C93B873254A14A409D7FBBECD7A54140C93B873254A14A409D7FBBECD7A541400FF10F5B7AA04A40292499D53BA441400FF10F5B7AA04A40
37989	45441	35.349649999999997	35.375045	53.144755000000004	53.137230000000002	Молодежная	0103000020E61000000100000005000000F085C954C1AC4140DA03ADC090914A40F085C954C1AC41405C77F35487924A40A0C37C7901B041405C77F35487924A40A0C37C7901B04140DA03ADC090914A40F085C954C1AC4140DA03ADC090914A40
36754	3545	35.300314	35.310051999999999	53.314647999999998	53.310634999999998	Привокзальная	0103000020E61000000100000005000000F6436CB070A6414019FF3EE3C2A74A40F6436CB070A641403BE0BA6246A84A409A07B0C8AFA741403BE0BA6246A84A409A07B0C8AFA7414019FF3EE3C2A74A40F6436CB070A6414019FF3EE3C2A74A40
38314	49594	35.782144000000002	35.797441999999997	52.905841000000002	52.903055000000002	Центральная	0103000020E610000001000000050000009E616A4B1DE44140A1BE654E97734A409E616A4B1DE441401F300F99F2734A40793A579412E641401F300F99F2734A40793A579412E64140A1BE654E97734A409E616A4B1DE44140A1BE654E97734A40
38018	25734	35.607483999999999	35.621730999999997	53.019188999999997	53.007199999999997	Первомайская	0103000020E61000000100000005000000F06B2409C2CD4140FE43FAEDEB804A40F06B2409C2CD4140B2B8FFC874824A4066F4A3E194CF4140B2B8FFC874824A4066F4A3E194CF4140FE43FAEDEB804A40F06B2409C2CD4140FE43FAEDEB804A40
74977	49123	35.620204000000001	35.641987999999998	53.022227999999998	53.010731999999997	Советская	0103000020E61000000100000005000000986C3CD862CF4140A5828AAA5F814A40986C3CD862CF41401A87FA5DD8824A405436ACA92CD241401A87FA5DD8824A405436ACA92CD24140A5828AAA5F814A40986C3CD862CF4140A5828AAA5F814A40
38020	26355	35.725262000000001	35.773169000000003	52.831189000000002	52.821373000000001	Молодежная	0103000020E610000001000000050000000A849D62D5DC4140A1681EC022694A400A849D62D5DC4140C1E5B166646A4A40F9A3A833F7E24140C1E5B166646A4A40F9A3A833F7E24140A1681EC022694A400A849D62D5DC4140A1681EC022694A40
37954	26374	35.669781999999998	35.681182	53.058275999999999	53.050812999999998	Школьная	0103000020E6100000010000000500000088B9A46ABBD54140179B560A81864A4088B9A46ABBD541402312859675874A40DB4FC6F830D741402312859675874A40DB4FC6F830D74140179B560A81864A4088B9A46ABBD54140179B560A81864A40
38205	49484	35.694225000000003	35.741405	53.169474000000001	53.15211	Д.Давыдова	0103000020E610000001000000050000006688635DDCD8414081B2295778934A406688635DDCD84140DBC2F352B1954A40A20BEA5BE6DE4140DBC2F352B1954A40A20BEA5BE6DE414081B2295778934A406688635DDCD8414081B2295778934A40
38019	26081	35.451994999999997	35.476680000000002	52.941319999999997	52.933016000000002	Микрорайон Школьный	0103000020E610000001000000050000004E7ADFF8DAB9414087527B116D774A404E7ADFF8DAB941400D897B2C7D784A402254A9D903BD41400D897B2C7D784A402254A9D903BD414087527B116D774A404E7ADFF8DAB9414087527B116D774A40
38149	26260	35.808050999999999	35.834426000000001	52.942405000000001	52.936934999999998	Школьная	0103000020E61000000100000005000000034015376EE7414027BD6F7CED774A40034015376EE741401F4B1FBAA0784A404F779E78CEEA41401F4B1FBAA0784A404F779E78CEEA414027BD6F7CED774A40034015376EE7414027BD6F7CED774A40
38693	54668	35.601123999999999	35.608849999999997	52.879606000000003	52.876193000000001	Школьная	0103000020E610000001000000050000009C6B98A1F1CC4140F8FD9B1727704A409C6B98A1F1CC4140C5AEEDED96704A40B515FBCBEECD4140C5AEEDED96704A40B515FBCBEECD4140F8FD9B1727704A409C6B98A1F1CC4140F8FD9B1727704A40
37950	26197	35.786096000000001	35.816701999999999	52.962626	52.951797999999997	Молодежная	0103000020E610000001000000050000001AC231CB9EE44140F8325184D4794A401AC231CB9EE44140C0232A54377B4A40F549EEB089E84140C0232A54377B4A40F549EEB089E84140F8325184D4794A401AC231CB9EE44140F8325184D4794A40
38137	49512	35.549551999999998	35.592590000000001	52.953572000000001	52.942590000000003	Центральная	0103000020E61000000100000005000000C7B94DB857C64140B1C403CAA6784A40C7B94DB857C64140CF30B5A50E7A4A40E4F736FDD9CB4140CF30B5A50E7A4A40E4F736FDD9CB4140B1C403CAA6784A40C7B94DB857C64140B1C403CAA6784A40
38121	25795	35.512757000000001	35.526088000000001	52.986144000000003	52.976959000000001	Центральная	0103000020E61000000100000005000000C5E57805A2C14140354415FE0C7D4A40C5E57805A2C14140C59272F7397E4A40B66801DA56C34140C59272F7397E4A40B66801DA56C34140354415FE0C7D4A40C5E57805A2C14140354415FE0C7D4A40
38148	49470	35.519233999999997	35.649894000000003	53.138790999999998	52.967686	Державина	0103000020E61000000100000005000000527C7C4276C2414006668522DD7B4A40527C7C4276C2414054FD4AE7C3914A40EEEE01BA2FD3414054FD4AE7C3914A40EEEE01BA2FD3414006668522DD7B4A40527C7C4276C2414006668522DD7B4A40
38159	26177	35.811725000000003	35.824814000000003	53.044803999999999	53.025613	Победы	0103000020E610000001000000050000003D2CD49AE6E741401DAD6A4947834A403D2CD49AE6E74140705D3123BC854A4038A4518193E94140705D3123BC854A4038A4518193E941401DAD6A4947834A403D2CD49AE6E741401DAD6A4947834A40
37953	54567	35.759928000000002	35.797936	52.461109999999998	52.432358999999998	Московская	0103000020E6100000010000000500000048A8195245E14140CD902A8A57374A4048A8195245E14140E5ED08A7053B4A40892650C422E64140E5ED08A7053B4A40892650C422E64140CD902A8A57374A4048A8195245E14140CD902A8A57374A40
36965	46399	35.368963000000001	35.398311	52.757978000000001	52.739657000000001	Советская	0103000020E610000001000000050000008F37F92D3AAF4140F5A0A014AD5E4A408F37F92D3AAF4140338B506C05614A408B51D7DAFBB24140338B506C05614A408B51D7DAFBB24140F5A0A014AD5E4A408F37F92D3AAF4140F5A0A014AD5E4A40
38078	46399	35.368963000000001	35.398311	52.757978000000001	52.739657000000001	Ленина	0103000020E610000001000000050000008F37F92D3AAF4140F5A0A014AD5E4A408F37F92D3AAF4140338B506C05614A408B51D7DAFBB24140338B506C05614A408B51D7DAFBB24140F5A0A014AD5E4A408F37F92D3AAF4140F5A0A014AD5E4A40
9737	40293	36.568592000000002	36.614567000000001	52.635258999999998	52.608645000000003	Школьная	0103000020E610000001000000050000003562669FC7484240DDEF5014E84D4A403562669FC7484240ADBEBA2A50514A40B519A721AA4E4240ADBEBA2A50514A40B519A721AA4E4240DDEF5014E84D4A403562669FC7484240DDEF5014E84D4A40
36967	23615	36.355915000000003	36.390419999999999	52.681480999999998	52.656426000000003	Школьная	0103000020E61000000100000005000000F3936A9F8E2D42403F1F65C405544A40F3936A9F8E2D424035ECF7C43A574A4027DA5548F931424035ECF7C43A574A4027DA5548F93142403F1F65C405544A40F3936A9F8E2D42403F1F65C405544A40
37860	23615	36.355915000000003	36.390419999999999	52.681480999999998	52.656426000000003	Чкалова	0103000020E61000000100000005000000F3936A9F8E2D42403F1F65C405544A40F3936A9F8E2D424035ECF7C43A574A4027DA5548F931424035ECF7C43A574A4027DA5548F93142403F1F65C405544A40F3936A9F8E2D42403F1F65C405544A40
36963	23615	36.355915000000003	36.390419999999999	52.681480999999998	52.656426000000003	Садовая	0103000020E61000000100000005000000F3936A9F8E2D42403F1F65C405544A40F3936A9F8E2D424035ECF7C43A574A4027DA5548F931424035ECF7C43A574A4027DA5548F93142403F1F65C405544A40F3936A9F8E2D42403F1F65C405544A40
36744	23615	36.355915000000003	36.390419999999999	52.681480999999998	52.656426000000003	 Ленина	0103000020E61000000100000005000000F3936A9F8E2D42403F1F65C405544A40F3936A9F8E2D424035ECF7C43A574A4027DA5548F931424035ECF7C43A574A4027DA5548F93142403F1F65C405544A40F3936A9F8E2D42403F1F65C405544A40
38157	23255	36.914164999999997	37.179554000000003	52.542430000000003	52.506436999999998	Центральная	0103000020E61000000100000005000000EC12D55B03754240FF3D78EDD2404A40EC12D55B03754240452FA3586E454A40D9EE1EA0FB964240452FA3586E454A40D9EE1EA0FB964240FF3D78EDD2404A40EC12D55B03754240FF3D78EDD2404A40
38179	48359	36.947671999999997	36.959879999999998	52.593653000000003	52.586480999999999	Центральная	0103000020E61000000100000005000000DEAAEB504D794240D95C35CF114B4A40DEAAEB504D7942400E164ED2FC4B4A40D00A0C59DD7A42400E164ED2FC4B4A40D00A0C59DD7A4240D95C35CF114B4A40DEAAEB504D794240D95C35CF114B4A40
38584	54654	36.771116999999997	36.794319999999999	52.533261000000003	52.515300000000003	Центральная	0103000020E61000000100000005000000DF313CF6B36242407DD0B359F5414A40DF313CF6B3624240BB9D7DE541444A4084471B47AC654240BB9D7DE541444A4084471B47AC6542407DD0B359F5414A40DF313CF6B36242407DD0B359F5414A40
38082	49166	36.797815	36.826524999999997	52.713985999999998	52.691983999999998	Овалова	0103000020E610000001000000050000000EA14ACD1E66424079AD84EE92584A400EA14ACD1E664240A3E6ABE4635B4A40C7293A92CB694240A3E6ABE4635B4A40C7293A92CB69424079AD84EE92584A400EA14ACD1E66424079AD84EE92584A40
36888	49166	36.797815	36.826524999999997	52.713985999999998	52.691983999999998	 Мира	0103000020E610000001000000050000000EA14ACD1E66424079AD84EE92584A400EA14ACD1E664240A3E6ABE4635B4A40C7293A92CB694240A3E6ABE4635B4A40C7293A92CB69424079AD84EE92584A400EA14ACD1E66424079AD84EE92584A40
38602	54658	36.844248999999998	36.876130000000003	52.415213000000001	52.391274000000003	Центральная	0103000020E610000001000000050000002157EA59106C424037E3344415324A402157EA59106C4240E1EF17B325354A40B285200725704240E1EF17B325354A40B28520072570424037E3344415324A402157EA59106C424037E3344415324A40
38619	48488	36.683450000000001	36.719391999999999	52.629727000000003	52.609366999999999	Школьная	0103000020E61000000100000005000000C139234A7B5742407D21E4BCFF4D4A40C139234A7B5742404034F3E49A504A4084807C09155C42404034F3E49A504A4084807C09155C42407D21E4BCFF4D4A40C139234A7B5742407D21E4BCFF4D4A40
38116	48329	36.845354	36.870336000000002	52.654536	52.622337000000002	Центральная	0103000020E610000001000000050000007AC5538F346C42409E0B23BDA84F4A407AC5538F346C4240FF06EDD5C7534A400744882B676F4240FF06EDD5C7534A400744882B676F42409E0B23BDA84F4A407AC5538F346C42409E0B23BDA84F4A40
38146	23507	36.940412999999999	36.970506999999998	52.434049999999999	52.416817000000002	Центральная	0103000020E61000000100000005000000DBDD03745F7842405BB56B425A354A40DBDD03745F784240166A4DF38E374A4000C5C892397C4240166A4DF38E374A4000C5C892397C42405BB56B425A354A40DBDD03745F7842405BB56B425A354A40
38169	54617	37.106834999999997	37.135643999999999	52.493285	52.467962999999997	Центральная	0103000020E61000000100000005000000B988EFC4AC8D4240785E2A36E63B4A40B988EFC4AC8D4240BE4D7FF6233F4A4006F357C85C914240BE4D7FF6233F4A4006F357C85C914240785E2A36E63B4A40B988EFC4AC8D4240785E2A36E63B4A40
38427	54640	36.661720000000003	36.936442999999997	52.692601000000003	52.578043000000001	Заречная	0103000020E61000000100000005000000F88DAF3DB354424043572250FD494A40F88DAF3DB3544240A5164A26A7584A40B8C83D5DDD774240A5164A26A7584A40B8C83D5DDD77424043572250FD494A40F88DAF3DB354424043572250FD494A40
37979	54566	36.821620000000003	36.885508000000002	52.616596000000001	52.598008	Советская	0103000020E61000000100000005000000A9DE1AD82A694240895FB1868B4C4A40A9DE1AD82A694240166C239EEC4E4A40562C7E5358714240166C239EEC4E4A40562C7E5358714240895FB1868B4C4A40A9DE1AD82A694240895FB1868B4C4A40
37947	54566	36.821620000000003	36.885508000000002	52.616596000000001	52.598008	50 лет Октября	0103000020E61000000100000005000000A9DE1AD82A694240895FB1868B4C4A40A9DE1AD82A694240166C239EEC4E4A40562C7E5358714240166C239EEC4E4A40562C7E5358714240895FB1868B4C4A40A9DE1AD82A694240895FB1868B4C4A40
38118	48525	36.677045	36.696250999999997	52.683556000000003	52.671484	Центральная	0103000020E61000000100000005000000CD751A69A9564240C5E40D30F3554A40CD751A69A9564240077E54C37E574A405567B5C01E594240077E54C37E574A405567B5C01E594240C5E40D30F3554A40CD751A69A9564240C5E40D30F3554A40
38120	22770	37.023857999999997	37.039192	52.666393999999997	52.655966999999997	Советская	0103000020E61000000100000005000000BDDF68C70D834240AB2006BAF6534A40BDDF68C70D83424014200A664C554A40E621533E0485424014200A664C554A40E621533E04854240AB2006BAF6534A40BDDF68C70D834240AB2006BAF6534A40
38074	48302	36.879508000000001	36.900455999999998	52.560702999999997	52.545634	Центральная	0103000020E610000001000000050000000249D8B793704240F7CABC55D7454A400249D8B79370424071E2AB1DC5474A4055BE67244273424071E2AB1DC5474A4055BE672442734240F7CABC55D7454A400249D8B793704240F7CABC55D7454A40
38117	46567	36.607551999999998	36.628509000000001	52.616525000000003	52.610405999999998	Рабочая	0103000020E61000000100000005000000484F9143C44D42401EA4A7C8214E4A40484F9143C44D42404D158C4AEA4E4A40EF1EA0FB725042404D158C4AEA4E4A40EF1EA0FB725042401EA4A7C8214E4A40484F9143C44D42401EA4A7C8214E4A40
36985	17600	37.060985000000002	37.094016000000003	52.497995000000003	52.479152999999997	Советская	0103000020E61000000100000005000000F645425BCE874240E063B0E2543D4A40F645425BCE8742402849D74CBE3F4A407FA65EB7088C42402849D74CBE3F4A407FA65EB7088C4240E063B0E2543D4A40F645425BCE874240E063B0E2543D4A40
38276	54628	36.767020000000002	36.796854000000003	52.636854	52.624960999999999	Административная	0103000020E6100000010000000500000060B01BB62D6242404223D8B8FE4F4A4060B01BB62D624240D4298F6E84514A40E9D7D64FFF654240D4298F6E84514A40E9D7D64FFF6542404223D8B8FE4F4A4060B01BB62D6242404223D8B8FE4F4A40
38147	40410	37.129527000000003	37.161318000000001	52.444321000000002	52.430843000000003	Школьная	0103000020E6100000010000000500000079793A5794904240F35A09DD25374A4079793A579490424088F6B182DF384A40C9207711A694424088F6B182DF384A40C9207711A6944240F35A09DD25374A4079793A5794904240F35A09DD25374A40
38160	54612	36.786020000000001	36.810768000000003	52.459173	52.439782000000001	Алферьева	0103000020E610000001000000050000003F00A94D9C6442404BAFCDC64A384A403F00A94D9C644240651A4D2EC63A4A405952EE3EC7674240651A4D2EC63A4A405952EE3EC76742404BAFCDC64A384A403F00A94D9C6442404BAFCDC64A384A40
38034	23311	37.060975999999997	37.091222000000002	52.539389999999997	52.530056000000002	Цветочная	0103000020E61000000100000005000000A2EBC20FCE874240388600E0D8434A40A2EBC20FCE8742400CE544BB0A454A407E569929AD8B42400CE544BB0A454A407E569929AD8B4240388600E0D8434A40A2EBC20FCE874240388600E0D8434A40
38297	54632	36.603931000000003	36.646503000000003	52.584265000000002	52.568010999999998	Центральная	0103000020E6100000010000000500000032056B9C4D4D424056629E95B4484A4032056B9C4D4D424046990D32C94A4A4009E23C9CC052424046990D32C94A4A4009E23C9CC052424056629E95B4484A4032056B9C4D4D424056629E95B4484A40
74998	48654	36.148449999999997	36.177636	52.930214999999997	52.908872000000002	переулок Школьный	0103000020E61000000100000005000000AC8BDB68001342400420EEEA55744A40AC8BDB6800134240D39FFD4811774A40CF4BC5C6BC164240D39FFD4811774A40CF4BC5C6BC1642400420EEEA55744A40AC8BDB68001342400420EEEA55744A40
38057	48654	36.148449999999997	36.177636	52.930214999999997	52.908872000000002	Луговая	0103000020E61000000100000005000000AC8BDB68001342400420EEEA55744A40AC8BDB6800134240D39FFD4811774A40CF4BC5C6BC164240D39FFD4811774A40CF4BC5C6BC1642400420EEEA55744A40AC8BDB68001342400420EEEA55744A40
38113	18389	36.926839999999999	36.955855	53.081077000000001	53.065804	Раздольная	0103000020E61000000100000005000000F44F70B1A276424016F9F5436C884A40F44F70B1A276424099BA2BBB608A4A40EA5BE674597A424099BA2BBB608A4A40EA5BE674597A424016F9F5436C884A40F44F70B1A276424016F9F5436C884A40
38174	54619	36.785598	37.315199	53.200597999999999	52.872295999999999	Центральная	0103000020E61000000100000005000000C9E6AA798E6442403F373465A76F4A40C9E6AA798E6442404ED2FC31AD994A40AF5DDA7058A842404ED2FC31AD994A40AF5DDA7058A842403F373465A76F4A40C9E6AA798E6442403F373465A76F4A40
38098	18829	37.100420999999997	37.119807000000002	53.140531000000003	53.131400999999997	Центральная	0103000020E61000000100000005000000726A6798DA8C4240B2D47ABFD1904A40726A6798DA8C42407F8978EBFC914A407B6AF5D5558F42407F8978EBFC914A407B6AF5D5558F4240B2D47ABFD1904A40726A6798DA8C4240B2D47ABFD1904A40
38067	18857	37.124622000000002	37.149783999999997	53.137754000000001	53.121777999999999	Школьная	0103000020E610000001000000050000005A2E1B9DF38F4240A7AFE76B968F4A405A2E1B9DF38F424054724EECA1914A4066BB421F2C93424054724EECA1914A4066BB421F2C934240A7AFE76B968F4A405A2E1B9DF38F4240A7AFE76B968F4A40
38152	18519	37.218809999999998	37.235805999999997	53.040239999999997	53.033244000000003	Садовая	0103000020E61000000100000005000000D50451F7019C4240E564E25641844A40D50451F7019C4240DAFE959526854A40AC1919E42E9E4240DAFE959526854A40AC1919E42E9E4240E564E25641844A40D50451F7019C4240E564E25641844A40
38031	18350	36.879705000000001	36.900312999999997	53.068531	53.053561999999999	Школьная	0103000020E610000001000000050000005890662C9A70424078279F1EDB864A405890662C9A7042408FE1B19FC5884A40F294D5743D7342408FE1B19FC5884A40F294D5743D73424078279F1EDB864A405890662C9A70424078279F1EDB864A40
36894	18127	37.028672999999998	37.060617000000001	52.985059	52.963689000000002	Карла Маркса	0103000020E610000001000000050000009CA38E8EAB834240EA4141295A7B4A409CA38E8EAB834240B3D0CE69167E4A40734A404CC2874240B3D0CE69167E4A40734A404CC2874240EA4141295A7B4A409CA38E8EAB834240EA4141295A7B4A40
38014	18729	37.110948999999998	37.145561999999998	53.036211000000002	53.021827000000002	Победы	0103000020E610000001000000050000000F43AB93338E4240BC95253ACB824A400F43AB93338E4240B360E28FA2844A402AC58EC6A1924240B360E28FA2844A402AC58EC6A1924240BC95253ACB824A400F43AB93338E4240BC95253ACB824A40
37973	18562	37.005899999999997	37.039003000000001	52.971145999999997	52.953023999999999	Центральная	0103000020E61000000100000005000000F085C954C1804240CC26C0B0FC794A40F085C954C180424013D21A834E7C4A4013B9E00CFE84424013D21A834E7C4A4013B9E00CFE844240CC26C0B0FC794A40F085C954C1804240CC26C0B0FC794A40
38164	18290	36.937466999999998	36.997357999999998	52.992463999999998	52.968401999999998	Центральная	0103000020E61000000100000005000000240A2DEBFE774240C4B0C398F47B4A40240A2DEBFE7742408A3A730F097F4A40B5334C6DA97F42408A3A730F097F4A40B5334C6DA97F4240C4B0C398F47B4A40240A2DEBFE774240C4B0C398F47B4A40
38037	18459	37.163778999999998	37.218755999999999	53.065631000000003	53.045431999999998	Центральная	0103000020E61000000100000005000000C362D4B5F69442408F183DB7D0854A40C362D4B5F6944240494DBB9866884A40E2E65432009C4240494DBB9866884A40E2E65432009C42408F183DB7D0854A40C362D4B5F69442408F183DB7D0854A40
38138	18215	36.942093	36.974217000000003	53.031809000000003	53.013635999999998	Лесная	0103000020E610000001000000050000003065E080967842402D060FD3BE814A403065E08096784240F75B3B5112844A40871A8524B37C4240F75B3B5112844A40871A8524B37C42402D060FD3BE814A403065E080967842402D060FD3BE814A40
38115	18737	37.109808999999998	37.140225999999998	52.997368999999999	52.979264000000001	Образцовая	0103000020E610000001000000050000003AE7A7380E8E42403813D385587D4A403AE7A7380E8E4240A98592C9A97F4A404206F2ECF2914240A98592C9A97F4A404206F2ECF29142403813D385587D4A403AE7A7380E8E42403813D385587D4A40
38114	18669	37.063806	37.096963000000002	53.037439999999997	53.026674999999997	Центральная	0103000020E61000000100000005000000F0A485CB2A884240764F1E166A834A40F0A485CB2A884240F7C77BD5CA844A4006F69848698C4240F7C77BD5CA844A4006F69848698C4240764F1E166A834A40F0A485CB2A884240764F1E166A834A40
72345	16981	37.410375999999999	37.466951999999999	52.867854999999999	52.844337000000003	Победы	0103000020E610000001000000050000001A88653387B44240C1E61C3C136C4A401A88653387B44240C55565DF156F4A40A1664815C5BB4240C55565DF156F4A40A1664815C5BB4240C1E61C3C136C4A401A88653387B44240C1E61C3C136C4A40
36892	16981	37.410375999999999	37.466951999999999	52.867854999999999	52.844337000000003	Комсомольская	0103000020E610000001000000050000001A88653387B44240C1E61C3C136C4A401A88653387B44240C55565DF156F4A40A1664815C5BB4240C55565DF156F4A40A1664815C5BB4240C1E61C3C136C4A401A88653387B44240C1E61C3C136C4A40
72129	46197	37.361291999999999	37.386201999999997	52.863343	52.847138000000001	Колхозная	0103000020E610000001000000050000003927F6D03EAE424074999A046F6C4A403927F6D03EAE4240821DFF05826E4A402CD32F116FB14240821DFF05826E4A402CD32F116FB1424074999A046F6C4A403927F6D03EAE424074999A046F6C4A40
74973	60408	37.448222000000001	37.469619999999999	52.894831000000003	52.890338	Школьная	0103000020E6100000010000000500000082ACA7565FB942406A317898F6714A4082ACA7565FB9424037397CD289724A4015C616821CBC424037397CD289724A4015C616821CBC42406A317898F6714A4082ACA7565FB942406A317898F6714A40
38081	45825	36.401747999999998	36.438623	53.427604000000002	53.415284	Школьная	0103000020E61000000100000005000000E09D7C7A6C334240AA46AF0628B54A40E09D7C7A6C334240C4D155BABBB64A40FF2268CC24384240C4D155BABBB64A40FF2268CC24384240AA46AF0628B54A40E09D7C7A6C334240AA46AF0628B54A40
37991	15700	36.831609	36.855460000000001	53.164799000000002	53.152898999999998	Садовая	0103000020E610000001000000050000009607E929726A4240A94BC63192934A409607E929726A4240EEB4352218954A40A18499B67F6D4240EEB4352218954A40A18499B67F6D4240A94BC63192934A409607E929726A4240A94BC63192934A40
38090	16052	36.590124000000003	36.606743000000002	53.177380999999997	53.154746000000003	Мичурина	0103000020E61000000100000005000000D84AE82E894B4240EA9788B7CE934A40D84AE82E894B424044F7AC6BB4964A40D9092FC1A94D424044F7AC6BB4964A40D9092FC1A94D4240EA9788B7CE934A40D84AE82E894B4240EA9788B7CE934A40
38332	54634	36.436387000000003	36.449393999999998	53.343296000000002	53.336452000000001	Центральная	0103000020E6100000010000000500000025B37A87DB3742403F56F0DB10AB4A4025B37A87DB3742407F6C921FF1AB4A4062821ABE853942407F6C921FF1AB4A4062821ABE853942403F56F0DB10AB4A4025B37A87DB3742403F56F0DB10AB4A40
38128	45918	36.483637999999999	36.496932999999999	53.296165000000002	53.285345999999997	Школьная	0103000020E610000001000000050000002A8D98D9E73D4240AF05BD3786A44A402A8D98D9E73D4240249C16BCE8A54A40CEA623809B3F4240249C16BCE8A54A40CEA623809B3F4240AF05BD3786A44A402A8D98D9E73D4240AF05BD3786A44A40
37978	16380	36.31718	36.349870000000003	53.356524	53.340015999999999	Ленина	0103000020E61000000100000005000000FF78AF5A99284240F10EF0A485AB4A40FF78AF5A992842409B1E1494A2AD4A40FFEC478AC82C42409B1E1494A2AD4A40FFEC478AC82C4240F10EF0A485AB4A40FF78AF5A99284240F10EF0A485AB4A40
38040	9082	36.533683000000003	36.557505999999997	53.077478999999997	53.063141999999999	Центральная	0103000020E6100000010000000500000031B77BB94F44424084807C0915884A4031B77BB94F4442403A90F5D4EA894A4071A94A5B5C4742403A90F5D4EA894A4071A94A5B5C47424084807C0915884A4031B77BB94F44424084807C0915884A40
37949	16135	36.611459000000004	36.637528000000003	53.375872999999999	53.364348	Никольская	0103000020E6100000010000000500000025ECDB49444E4240772E8CF4A2AE4A4025ECDB49444E42408639419B1CB04A4064247B849A5142408639419B1CB04A4064247B849A514240772E8CF4A2AE4A4025ECDB49444E4240772E8CF4A2AE4A40
38419	16608	36.485982999999997	36.506231	53.088194999999999	53.069710999999998	Полянская	0103000020E61000000100000005000000BBB4E1B0343E4240F295404AEC884A40BBB4E1B0343E4240DA5548F9498B4A40569C6A2DCC404240DA5548F9498B4A40569C6A2DCC404240F295404AEC884A40BBB4E1B0343E4240F295404AEC884A40
38136	15996	36.660156999999998	36.691634000000001	53.189194000000001	53.164999000000002	Школьная	0103000020E61000000100000005000000DC9C4A0680544240B56FEEAF1E954A40DC9C4A0680544240BA4C4D8237984A409D66817687584240BA4C4D8237984A409D66817687584240B56FEEAF1E954A40DC9C4A0680544240B56FEEAF1E954A40
72291	40392	36.435110999999999	36.447481000000003	53.149085999999997	53.138440000000003	Центральная	0103000020E610000001000000050000009F909DB7B1374240A83AE466B8914A409F909DB7B13742404E25034015934A406B4AB20E473942404E25034015934A406B4AB20E47394240A83AE466B8914A409F909DB7B1374240A83AE466B8914A40
38165	54614	36.323656999999997	36.373531	53.170597000000001	53.152774999999998	Совхозная	0103000020E610000001000000050000008C0FB3976D294240BD5296218E934A408C0FB3976D294240DAE55B1FD6954A40668522DDCF2F4240DAE55B1FD6954A40668522DDCF2F4240BD5296218E934A408C0FB3976D294240BD5296218E934A40
37959	16752	36.462204	36.483234000000003	53.232616	53.220190000000002	Центральная	0103000020E610000001000000050000004A0A2C80293B42400074982F2F9C4A404A0A2C80293B42405F43705CC69D4A405B28999CDA3D42405F43705CC69D4A405B28999CDA3D42400074982F2F9C4A404A0A2C80293B42400074982F2F9C4A40
75025	60445	36.890593000000003	36.904732000000003	53.210560000000001	53.204309000000002	Центральная	0103000020E61000000100000005000000F58590F3FE714240A5A31CCC269A4A40F58590F3FE71424042EC4CA1F39A4A4085D21742CE73424042EC4CA1F39A4A4085D21742CE734240A5A31CCC269A4A40F58590F3FE714240A5A31CCC269A4A40
38029	16194	36.572715000000002	36.627395	53.331052999999997	53.32105	Мира	0103000020E61000000100000005000000DE76A1B94E494240BE30992A18A94A40DE76A1B94E494240101FD8F15FAA4A404356B77A4E504240101FD8F15FAA4A404356B77A4E504240BE30992A18A94A40DE76A1B94E494240BE30992A18A94A40
36752	45394	36.330224000000001	36.335406999999996	53.216233000000003	53.213282999999997	Чапаева	0103000020E610000001000000050000005A2DB0C7442A424079E57ADB4C9B4A405A2DB0C7442A424072A8DF85AD9B4A40BBECD79DEE2A424072A8DF85AD9B4A40BBECD79DEE2A424079E57ADB4C9B4A405A2DB0C7442A424079E57ADB4C9B4A40
36749	45394	36.330224000000001	36.335406999999996	53.216233000000003	53.213282999999997	Ленина	0103000020E610000001000000050000005A2DB0C7442A424079E57ADB4C9B4A405A2DB0C7442A424072A8DF85AD9B4A40BBECD79DEE2A424072A8DF85AD9B4A40BBECD79DEE2A424079E57ADB4C9B4A405A2DB0C7442A424079E57ADB4C9B4A40
38416	15912	36.745801999999998	36.770488	53.096074000000002	53.083370000000002	Квартальная	0103000020E610000001000000050000004CA59F70765F4240D8BB3FDEAB8A4A404CA59F70765F42407AFF1F274C8C4A40F0FACC599F6242407AFF1F274C8C4A40F0FACC599F624240D8BB3FDEAB8A4A404CA59F70765F4240D8BB3FDEAB8A4A40
38153	45608	36.748559999999998	36.774332999999999	53.211227999999998	53.201337000000002	Минаева	0103000020E61000000100000005000000008C67D0D05F4240C53C2B69C5994A40008C67D0D05F4240EFFFE384099B4A40569BFF571D634240EFFFE384099B4A40569BFF571D634240C53C2B69C5994A40008C67D0D05F4240C53C2B69C5994A40
38011	16664	36.500374000000001	36.534806000000003	53.124738999999998	53.109876	Школьный переулок	0103000020E6100000010000000500000065E256410C404240C24EB16A108E4A4065E256410C40424093C49272F78F4A4030DAE3857444424093C49272F78F4A4030DAE38574444240C24EB16A108E4A4065E256410C404240C24EB16A108E4A40
38033	54586	36.474646	36.501567999999999	53.329483000000003	53.314121	Школьная	0103000020E61000000100000005000000AF963B33C13C424050FEEE1D35A84A40AF963B33C13C424043CBBA7F2CAA4A402D5C56613340424043CBBA7F2CAA4A402D5C56613340424050FEEE1D35A84A40AF963B33C13C424050FEEE1D35A84A40
38079	45575	36.874018999999997	36.899908000000003	53.223942999999998	53.210273999999998	Школьная	0103000020E61000000100000005000000938AC6DADF6F42407C992842EA9A4A40938AC6DADF6F424085950A2AAA9C4A4053B4722F3073424085950A2AAA9C4A4053B4722F307342407C992842EA9A4A40938AC6DADF6F42407C992842EA9A4A40
38688	45886	36.717981000000002	36.739351999999997	53.121350999999997	53.109476000000001	Школьная	0103000020E610000001000000050000001F1329CDE65B424034D93F4F038E4A401F1329CDE65B42401F2BF86D888F4A40B81D1A16A35E42401F2BF86D888F4A40B81D1A16A35E424034D93F4F038E4A401F1329CDE65B424034D93F4F038E4A40
38550	46036	36.513309	36.557102	53.267733999999997	53.232523999999998	Центральная	0103000020E6100000010000000500000009DFFB1BB44142407EC4AF58C39D4A4009DFFB1BB44142407D03931B45A24A40A2444B1E4F4742407D03931B45A24A40A2444B1E4F4742407EC4AF58C39D4A4009DFFB1BB44142407EC4AF58C39D4A40
37940	16697	36.395710999999999	36.418312	53.189593000000002	53.174698999999997	Тюленина	0103000020E610000001000000050000006FD575A8A63242406BD26D895C964A406FD575A8A632424078465B9544984A401EC3633F8B35424078465B9544984A401EC3633F8B3542406BD26D895C964A406FD575A8A63242406BD26D895C964A40
37938	14703	36.813616000000003	36.842891999999999	53.275257000000003	53.252980000000001	пл.Центральная	0103000020E610000001000000050000004DC0AF912468424063450DA661A04A404DC0AF91246842405F7F129F3BA34A40AF0793E2E36B42405F7F129F3BA34A40AF0793E2E36B424063450DA661A04A404DC0AF912468424063450DA661A04A40
37981	45880	36.310048000000002	36.338264000000002	53.335833000000001	53.323802999999998	Молодежная	0103000020E61000000100000005000000591822A7AF27424060AC6F6072A94A40591822A7AF27424073F56393FCAA4A4003B5183C4C2B424073F56393FCAA4A4003B5183C4C2B424060AC6F6072A94A40591822A7AF27424060AC6F6072A94A40
38423	54639	36.237850000000002	36.261116000000001	53.172809999999998	53.157310000000003	Школьная	0103000020E6100000010000000500000043AD69DE711E4240B9AAECBB22944A4043AD69DE711E4240FC3559A31E964A402E3BC43F6C214240FC3559A31E964A402E3BC43F6C214240B9AAECBB22944A4043AD69DE711E4240B9AAECBB22944A40
38065	45911	36.395361000000001	36.414216000000003	53.282983000000002	53.271272000000003	Центральная	0103000020E61000000100000005000000938E72309B3242400729780AB9A24A40938E72309B324240782975C938A44A406FBDA60705354240782975C938A44A406FBDA607053542400729780AB9A24A40938E72309B3242400729780AB9A24A40
37995	54575	36.458871000000002	36.473827999999997	52.327311000000002	52.313454999999998	Центральная	0103000020E610000001000000050000009A0AF148BC3A424043E21E4B1F284A409A0AF148BC3A42407F4FAC53E5294A40ECF65965A63C42407F4FAC53E5294A40ECF65965A63C424043E21E4B1F284A409A0AF148BC3A424043E21E4B1F284A40
36835	15516	36.472292000000003	36.518259	52.411242000000001	52.389994000000002	 К.Либкнехта	0103000020E61000000100000005000000CB147310743C424070D1C952EB314A40CB147310743C4240EE5EEE93A3344A40C8ED974F56424240EE5EEE93A3344A40C8ED974F5642424070D1C952EB314A40CB147310743C424070D1C952EB314A40
38154	48062	36.427349999999997	36.441471	52.403281	52.394286000000001	Садовая	0103000020E6100000010000000500000009F9A067B3364240A5A2B1F677324A4009F9A067B3364240910C39B69E334A40F390291F82384240910C39B69E334A40F390291F82384240A5A2B1F677324A4009F9A067B3364240A5A2B1F677324A40
36890	40391	37.579366999999998	37.629942	52.417735	52.393506000000002	Воронежская	0103000020E61000000100000005000000D9B0A6B228CA4240D06394675E324A40D9B0A6B228CA424081B2295778354A403C3080F0A1D0424081B2295778354A403C3080F0A1D04240D06394675E324A40D9B0A6B228CA4240D06394675E324A40
38270	54627	37.583993	37.634127999999997	52.348567000000003	52.321581000000002	Садовая	0103000020E61000000100000005000000E50B5A48C0CA4240EB01F39029294A40E50B5A48C0CA424080BBECD79D2C4A402BBD361B2BD1424080BBECD79D2C4A402BBD361B2BD14240EB01F39029294A40E50B5A48C0CA4240EB01F39029294A40
38135	12794	37.431261999999997	37.47916	52.419035999999998	52.404643999999998	Дружбы Народов	0103000020E61000000100000005000000F700DD9733B74240E542E55FCB334A40F700DD9733B742405FECBDF8A2354A4093C6681D55BD42405FECBDF8A2354A4093C6681D55BD4240E542E55FCB334A40F700DD9733B74240E542E55FCB334A40
74971	47023	37.332805999999998	37.385357999999997	52.347020999999998	52.329825999999997	Центральная	0103000020E61000000100000005000000CFF4126399AA42406CAF05BD372A4A40CFF4126399AA42403A03232F6B2C4A4040A0336953B142403A03232F6B2C4A4040A0336953B142406CAF05BD372A4A40CFF4126399AA42406CAF05BD372A4A40
38001	54577	37.639921999999999	37.666189000000003	52.438557000000003	52.427439	Центральная	0103000020E61000000100000005000000D6FECEF6E8D1424079043752B6364A40D6FECEF6E8D142404837C2A222384A403CFA5FAE45D542404837C2A222384A403CFA5FAE45D5424079043752B6364A40D6FECEF6E8D1424079043752B6364A40
38015	54584	37.670572999999997	37.701447999999999	52.373618	52.338267999999999	Пентюхова	0103000020E61000000100000005000000514A0856D5D5424044A4A65D4C2B4A40514A0856D5D542403599F1B6D22F4A401CEC4D0CC9D942403599F1B6D22F4A401CEC4D0CC9D9424044A4A65D4C2B4A40514A0856D5D5424044A4A65D4C2B4A40
37948	13195	37.514750999999997	37.537154999999998	52.578465000000001	52.567683000000002	Школьная	0103000020E61000000100000005000000A94A5B5CE3C1424062BF27D6A9484A40A94A5B5CE3C14240B97020240B4A4A4002F1BA7EC1C44240B97020240B4A4A4002F1BA7EC1C4424062BF27D6A9484A40A94A5B5CE3C1424062BF27D6A9484A40
38162	14467	37.787227999999999	37.824283999999999	52.297342999999998	52.270986999999998	Центральная	0103000020E610000001000000050000006C3F19E3C3E442401152B7B3AF224A406C3F19E3C3E44240E658DE550F264A40DB4E5B2382E94240E658DE550F264A40DB4E5B2382E942401152B7B3AF224A406C3F19E3C3E442401152B7B3AF224A40
36953	13064	37.510322000000002	37.528846000000001	52.434862000000003	52.424796999999998	Комсомольская	0103000020E61000000100000005000000F436363B52C142402E3883BF5F364A40F436363B52C14240F722DA8EA9374A406A4FC939B1C34240F722DA8EA9374A406A4FC939B1C342402E3883BF5F364A40F436363B52C142402E3883BF5F364A40
37965	13994	37.496541999999998	37.520023999999999	52.343302000000001	52.317684	Ассовиахим	0103000020E61000000100000005000000938B31B08EBF4240323B8BDEA9284A40938B31B08EBF42406153E751F12B4A404B917C2590C242406153E751F12B4A404B917C2590C24240323B8BDEA9284A40938B31B08EBF4240323B8BDEA9284A40
37942	48865	37.367570999999998	37.413097999999998	52.399754000000001	52.381590000000003	Центральная	0103000020E61000000100000005000000A0FA07910CAF4240863DEDF0D7304A40A0FA07910CAF4240FC389A232B334A4081053065E0B44240FC389A232B334A4081053065E0B44240863DEDF0D7304A40A0FA07910CAF4240863DEDF0D7304A40
37936	12849	37.258372000000001	37.282482999999999	52.4373	52.422199999999997	Молодежная	0103000020E61000000100000005000000DF196D5512A14240832F4CA60A364A40DF196D5512A1424039454772F9374A408656276728A4424039454772F9374A408656276728A44240832F4CA60A364A40DF196D5512A14240832F4CA60A364A40
38042	46226	37.630947999999997	37.719217	52.603487999999999	52.558278000000001	Советская	0103000020E6100000010000000500000001BD70E7C2D04240C4094CA775474A4001BD70E7C2D04240A4C343183F4D4A4016DD7A4D0FDC4240A4C343183F4D4A4016DD7A4D0FDC4240C4094CA775474A4001BD70E7C2D04240C4094CA775474A40
38127	13221	37.599651000000001	37.620887000000003	52.558376000000003	52.548437999999997	Орловская	0103000020E61000000100000005000000C1012D5DC1CC42401BF1643733464A40C1012D5DC1CC4240876F61DD78474A407BC1A73979CF4240876F61DD78474A407BC1A73979CF42401BF1643733464A40C1012D5DC1CC42401BF1643733464A40
38027	49400	37.789760999999999	37.817869999999999	52.226756000000002	52.213228000000001	Фрунзе	0103000020E61000000100000005000000005471E316E54240B64B1B0E4B1B4A40005471E316E54240FD153257061D4A409430D3F6AFE84240FD153257061D4A409430D3F6AFE84240B64B1B0E4B1B4A40005471E316E54240B64B1B0E4B1B4A40
38013	14520	37.922362	37.980052000000001	52.292667000000002	52.268672000000002	Центральная	0103000020E610000001000000050000005D8940F50FF64240EBAC16D863224A405D8940F50FF6424029CFBC1C76254A4090300C5872FD424029CFBC1C76254A4090300C5872FD4240EBAC16D863224A405D8940F50FF64240EBAC16D863224A40
37964	48957	37.528557999999997	37.549129999999998	52.423073000000002	52.400709999999997	Школьная	0103000020E610000001000000050000000305DEC9A7C342400F971C774A334A400305DEC9A7C342400A698D4127364A4051A04FE449C642400A698D4127364A4051A04FE449C642400F971C774A334A400305DEC9A7C342400F971C774A334A40
38024	48946	37.507978000000001	37.531298	52.475302999999997	52.454810000000002	Октябрьская	0103000020E61000000100000005000000338B506C05C1424067F2CD36373A4A40338B506C05C1424068588CBAD63C4A401137A79201C4424068588CBAD63C4A401137A79201C4424067F2CD36373A4A40338B506C05C1424067F2CD36373A4A40
38295	54603	37.682377000000002	37.710951999999999	52.451802999999998	52.429701000000001	Центральная	0103000020E610000001000000050000007445292158D742407D073F7100374A407445292158D742400A9E42AED4394A404D83A27900DB42400A9E42AED4394A404D83A27900DB42407D073F7100374A407445292158D742407D073F7100374A40
38122	54603	37.682377000000002	37.710951999999999	52.451802999999998	52.429701000000001	Н.А. Кузьмина	0103000020E610000001000000050000007445292158D742407D073F7100374A407445292158D742400A9E42AED4394A404D83A27900DB42400A9E42AED4394A404D83A27900DB42407D073F7100374A407445292158D742407D073F7100374A40
38119	49180	37.758975999999997	37.795465999999998	52.423879999999997	52.402946	Церковная	0103000020E610000001000000050000007539252026E14240EA060ABC93334A407539252026E14240D8B628B341364A403B8A73D4D1E54240D8B628B341364A403B8A73D4D1E54240EA060ABC93334A407539252026E14240EA060ABC93334A40
37859	54563	37.447206999999999	37.511499000000001	52.455694000000001	52.426780000000001	Комсомольская	0103000020E6100000010000000500000069C537143EB942401F4B1FBAA0364A4069C537143EB94240E17D552E543A4A40E6779ACC78C14240E17D552E543A4A40E6779ACC78C142401F4B1FBAA0364A4069C537143EB942401F4B1FBAA0364A40
38233	54623	37.957369	38.016396999999998	52.335163999999999	52.310273000000002	Круглянская	0103000020E61000000100000005000000249A40118BFA424079EA9106B7274A40249A40118BFA4240F56569A7E62A4A405260014C19024340F56569A7E62A4A405260014C1902434079EA9106B7274A40249A40118BFA424079EA9106B7274A40
36742	49263	37.433129999999998	37.527929	52.385773	52.341399000000003	Молодежная	0103000020E610000001000000050000004F75C8CD70B742408DF161F6B22B4A404F75C8CD70B742400457790261314A4014CE6E2D93C342400457790261314A4014CE6E2D93C342408DF161F6B22B4A404F75C8CD70B742408DF161F6B22B4A40
37937	49153	37.755437000000001	37.794837000000001	52.464796999999997	52.438706000000003	Центральная	0103000020E610000001000000050000001C98DC28B2E042408D47A98427384A401C98DC28B2E04240B323D5777E3B4A404C530438BDE54240B323D5777E3B4A404C530438BDE542408D47A98427384A401C98DC28B2E042408D47A98427384A40
38028	49398	37.725693999999997	37.763728	52.289610000000003	52.259942000000002	М. Горького	0103000020E61000000100000005000000A3737E8AE3DC4240AD6D8AC745214A40A3737E8AE3DC42401B4CC3F011254A400E85CFD6C1E142401B4CC3F011254A400E85CFD6C1E14240AD6D8AC745214A40A3737E8AE3DC4240AD6D8AC745214A40
38161	49000	37.508085999999999	37.527723000000002	52.532456000000003	52.520587999999996	Вишневая	0103000020E6100000010000000500000019C748F608C142405358A9A0A2424A4019C748F608C142408D47A98427444A406B2C616D8CC342408D47A98427444A406B2C616D8CC342405358A9A0A2424A4019C748F608C142405358A9A0A2424A40
37988	13145	37.493819999999999	37.523285000000001	52.527892000000001	52.489677	Центральная	0103000020E610000001000000050000002C0E677E35BF42403C4D66BCAD3E4A402C0E677E35BF4240F7E80DF791434A4062BEBC00FBC24240F7E80DF791434A4062BEBC00FBC242403C4D66BCAD3E4A402C0E677E35BF42403C4D66BCAD3E4A40
38134	49330	37.765318000000001	37.797262000000003	52.350658000000003	52.332979999999999	Воронежская	0103000020E610000001000000050000002385B2F0F5E142406D1CB1169F2A4A402385B2F0F5E14240570A815CE22C4A40FA2B64AE0CE64240570A815CE22C4A40FA2B64AE0CE642406D1CB1169F2A4A402385B2F0F5E142406D1CB1169F2A4A40
38431	49376	37.681083000000001	37.695976999999999	52.259323999999999	52.237566999999999	Центральная	0103000020E61000000100000005000000486E4DBA2DD74240EECD6F98681E4A40486E4DBA2DD74240B188618731214A4054E23AC615D94240B188618731214A4054E23AC615D94240EECD6F98681E4A40486E4DBA2DD74240EECD6F98681E4A40
37958	13281	37.633885999999997	37.649472000000003	52.558627999999999	52.534187000000003	Центральная	0103000020E6100000010000000500000035B22B2D23D142406479573D60444A4035B22B2D23D14240A0504F1F81474A4078D503E621D34240A0504F1F81474A4078D503E621D342406479573D60444A4035B22B2D23D142406479573D60444A40
38163	49252	37.541412999999999	37.562190999999999	52.535682000000001	52.383805000000002	площадь Центральная	0103000020E610000001000000050000008B506C054DC542404985B18520314A408B506C054DC5424027874F3A91444A40828DEBDFF5C7424027874F3A91444A40828DEBDFF5C742404985B18520314A408B506C054DC542404985B18520314A40
38126	14570	37.857728000000002	37.887569999999997	52.310707999999998	52.289417	Центральная	0103000020E61000000100000005000000876EF607CAED424006F4C29D0B254A40876EF607CAED4240834D9D47C5274A409274CDE49BF14240834D9D47C5274A409274CDE49BF1424006F4C29D0B254A40876EF607CAED424006F4C29D0B254A40
38072	13339	37.608401000000001	37.654682000000001	52.520527999999999	52.490718999999999	Школьная	0103000020E6100000010000000500000046ED7E15E0CD42404E4354E1CF3E4A4046ED7E15E0CD42407E5358A9A0424A40D3A3A99ECCD342407E5358A9A0424A40D3A3A99ECCD342404E4354E1CF3E4A4046ED7E15E0CD42404E4354E1CF3E4A40
38112	13632	37.858384000000001	37.879862000000003	52.389961	52.376311999999999	Центральная	0103000020E6100000010000000500000070B4E386DFED4240D28BDAFD2A304A4070B4E386DFED424094DBF63DEA314A40207F69519FF0424094DBF63DEA314A40207F69519FF04240D28BDAFD2A304A4070B4E386DFED4240D28BDAFD2A304A40
38025	49306	37.407780000000002	37.427992000000003	52.286189	52.266604999999998	Ливенская	0103000020E6100000010000000500000040FB912232B442409CF9D51C20224A4040FB912232B44240CBBC55D7A1244A408E791D71C8B64240CBBC55D7A1244A408E791D71C8B642409CF9D51C20224A4040FB912232B442409CF9D51C20224A40
38168	54616	37.442365000000002	37.481918	52.292324999999998	52.264285000000001	Центральная	0103000020E6100000010000000500000091F2936A9FB8424064E94317D4214A4091F2936A9FB84240CF66D5E76A254A4047AD307DAFBD4240CF66D5E76A254A4047AD307DAFBD424064E94317D4214A4091F2936A9FB8424064E94317D4214A40
38012	12684	37.307734000000004	37.322602000000003	52.313918000000001	52.301523000000003	Полевая	0103000020E6100000010000000500000003EFE4D363A74240F4FE3F4E98264A4003EFE4D363A7424018D00B772E284A40E6CFB7054BA9424018D00B772E284A40E6CFB7054BA94240F4FE3F4E98264A4003EFE4D363A74240F4FE3F4E98264A40
38578	54653	37.552624000000002	37.577866999999998	52.382513000000003	52.367635999999997	Карла Маркса	0103000020E610000001000000050000000B7E1B62BCC64240876A4AB20E2F4A400B7E1B62BCC64240BEA59C2FF6304A400438BD8BF7C94240BEA59C2FF6304A400438BD8BF7C94240876A4AB20E2F4A400B7E1B62BCC64240876A4AB20E2F4A40
38529	49318	37.466116	37.511507999999999	52.271301000000001	52.241587000000003	Войнова	0103000020E61000000100000005000000381268B0A9BB4240C311A452EC1E4A40381268B0A9BB4240A12FBDFDB9224A4039D2191879C14240A12FBDFDB9224A4039D2191879C14240C311A452EC1E4A40381268B0A9BB4240C311A452EC1E4A40
38421	54638	35.846364000000001	35.863754999999998	52.765236000000002	52.751721000000003	 Победы	0103000020E610000001000000050000008141D2A755EC4140B45BCB6438604A408141D2A755EC414066DCD440F3614A40D4601A868FEE414066DCD440F3614A40D4601A868FEE4140B45BCB6438604A408141D2A755EC4140B45BCB6438604A40
74985	47343	35.812848000000002	35.860719000000003	52.560194000000003	52.535091000000001	Лесная	0103000020E610000001000000050000003C4F3C670BE8414025B1A4DC7D444A403C4F3C670BE841402DB5DE6FB4474A40DE054A0A2CEE41402DB5DE6FB4474A40DE054A0A2CEE414025B1A4DC7D444A403C4F3C670BE8414025B1A4DC7D444A40
36943	11969	35.735458000000001	35.808903999999998	52.710571000000002	52.676397999999999	пер.Бобкова	0103000020E6100000010000000500000071CADC7C23DE4140378AAC3594564A4071CADC7C23DE4140363E93FDF35A4A4042CD902A8AE74140363E93FDF35A4A4042CD902A8AE74140378AAC3594564A4071CADC7C23DE4140378AAC3594564A40
37869	11969	35.735458000000001	35.808903999999998	52.710571000000002	52.676397999999999	Советская	0103000020E6100000010000000500000071CADC7C23DE4140378AAC3594564A4071CADC7C23DE4140363E93FDF35A4A4042CD902A8AE74140363E93FDF35A4A4042CD902A8AE74140378AAC3594564A4071CADC7C23DE4140378AAC3594564A40
37990	11969	35.735458000000001	35.808903999999998	52.710571000000002	52.676397999999999	Заводской пер.	0103000020E6100000010000000500000071CADC7C23DE4140378AAC3594564A4071CADC7C23DE4140363E93FDF35A4A4042CD902A8AE74140363E93FDF35A4A4042CD902A8AE74140378AAC3594564A4071CADC7C23DE4140378AAC3594564A40
36830	11969	35.735458000000001	35.808903999999998	52.710571000000002	52.676397999999999	 Карла Маркса	0103000020E6100000010000000500000071CADC7C23DE4140378AAC3594564A4071CADC7C23DE4140363E93FDF35A4A4042CD902A8AE74140363E93FDF35A4A4042CD902A8AE74140378AAC3594564A4071CADC7C23DE4140378AAC3594564A40
74983	60416	35.620573	35.635618999999998	52.539203999999998	52.527529999999999	Майская	0103000020E61000000100000005000000EBE3A1EF6ECF414056D4601A86434A40EBE3A1EF6ECF4140AAEFFCA204454A40ADDBA0F65BD14140AAEFFCA204454A40ADDBA0F65BD1414056D4601A86434A40EBE3A1EF6ECF414056D4601A86434A40
38521	54649	37.770690000000002	37.815651000000003	52.767961	52.747256	Школьная	0103000020E6100000010000000500000058AD4CF8A5E24240B1DEA815A65F4A4058AD4CF8A5E242403ECDC98B4C624A4090F9804067E842403ECDC98B4C624A4090F9804067E84240B1DEA815A65F4A4058AD4CF8A5E24240B1DEA815A65F4A40
37945	10611	37.656416	37.682808000000001	52.777695999999999	52.762261000000002	Ленина	0103000020E610000001000000050000001B49827005D442401502B9C491614A401B49827005D44240711DE38A8B634A403DB9A64066D74240711DE38A8B634A403DB9A64066D742401502B9C491614A401B49827005D442401502B9C491614A40
38651	54663	37.553198999999999	37.572702	52.679177000000003	52.669108000000001	Центральная	0103000020E6100000010000000500000007978E39CFC64240F9BEB854A5554A4007978E39CFC6424003999D45EF564A40492D944C4EC9424003999D45EF564A40492D944C4EC94240F9BEB854A5554A4007978E39CFC64240F9BEB854A5554A40
38069	10837	37.777203	37.796444999999999	52.666410999999997	52.655273000000001	Центральная	0103000020E6100000010000000500000032AD4D637BE34240D57954FCDF534A4032AD4D637BE34240EA58A5F44C554A400708E6E8F1E54240EA58A5F44C554A400708E6E8F1E54240D57954FCDF534A4032AD4D637BE34240D57954FCDF534A40
38684	54666	37.423167999999997	37.487793000000003	52.735621999999999	52.700972999999998	Ленина	0103000020E610000001000000050000005B5B785E2AB642408330B77BB9594A405B5B785E2AB64240EB1B98DC285E4A40DF1B430070BE4240EB1B98DC285E4A40DF1B430070BE42408330B77BB9594A405B5B785E2AB642408330B77BB9594A40
38026	10516	37.610340999999998	37.690083999999999	52.847155000000001	52.815496000000003	Школьная	0103000020E61000000100000005000000373465A71FCE42406902452C62684A40373465A71FCE42404AD235936F6C4A4016BF29AC54D842404AD235936F6C4A4016BF29AC54D842406902452C62684A40373465A71FCE42406902452C62684A40
38044	46635	37.633552999999999	37.647136000000003	52.668677000000002	52.654066	Толстовка	0103000020E610000001000000050000002FA4C34318D1424078B6476FB8534A402FA4C34318D14240304B3B3597554A403A083A5AD5D24240304B3B3597554A403A083A5AD5D2424078B6476FB8534A402FA4C34318D1424078B6476FB8534A40
38071	48190	37.836751999999997	37.889437999999998	52.778018000000003	52.751753999999998	Центральная	0103000020E61000000100000005000000696E85B01AEB42408F519E7939604A40696E85B01AEB424084D9041896634A40EAE8B81AD9F1424084D9041896634A40EAE8B81AD9F142408F519E7939604A40696E85B01AEB42408F519E7939604A40
37946	54565	37.656748	37.697189999999999	52.796022999999998	52.778415000000003	Ленина	0103000020E6100000010000000500000051DB865110D44240A1DB4B1AA3634A4051DB865110D4424091EEE714E4654A40938C9C853DD9424091EEE714E4654A40938C9C853DD94240A1DB4B1AA3634A4051DB865110D44240A1DB4B1AA3634A40
38023	10901	37.683481999999998	37.718085000000002	52.664766999999998	52.654552000000002	Молодежная	0103000020E61000000100000005000000CCB392567CD7424005C4245CC8534A40CCB392567CD74240E23AC61517554A40C45F9335EADB4240E23AC61517554A40C45F9335EADB424005C4245CC8534A40CCB392567CD7424005C4245CC8534A40
38009	10590	37.509459999999997	37.557187999999996	52.824921000000003	52.785763000000003	Набережная	0103000020E61000000100000005000000614F3BFC35C1424014B4C9E193644A40614F3BFC35C142404E64E60297694A40A0DCB6EF51C742404E64E60297694A40A0DCB6EF51C7424014B4C9E193644A40614F3BFC35C1424014B4C9E193644A40
38111	10797	37.669494999999998	37.728487000000001	52.733403000000003	52.705818000000001	Школьная	0103000020E61000000100000005000000F2EA1C03B2D54240CD76853E585A4A40F2EA1C03B2D54240E7E44526E05D4A40D447E00F3FDD4240E7E44526E05D4A40D447E00F3FDD4240CD76853E585A4A40F2EA1C03B2D54240CD76853E585A4A40
38129	48098	37.700468999999998	37.741342000000003	52.758926000000002	52.74579	8 Марта	0103000020E61000000100000005000000506EDBF7A8D9424088D7F50B765F4A40506EDBF7A8D94240C40AB77C24614A405C936E4BE4DE4240C40AB77C24614A405C936E4BE4DE424088D7F50B765F4A40506EDBF7A8D9424088D7F50B765F4A40
36786	19251	37.348500000000001	37.369484999999997	53.271352999999998	53.262208000000001	Советская	0103000020E61000000100000005000000F853E3A59BAC4240F25F200890A14A40F853E3A59BAC4240F355F2B1BBA24A4068AED3484BAF4240F355F2B1BBA24A4068AED3484BAF4240F25F200890A14A40F853E3A59BAC4240F25F200890A14A40
75004	60432	37.000295000000001	37.015583999999997	53.218524000000002	53.210456999999998	Школьная	0103000020E6100000010000000500000019ADA3AA098042406D1B4641F09A4A4019ADA3AA0980424010B22C98F89B4A40A12B11A8FE81424010B22C98F89B4A40A12B11A8FE8142406D1B4641F09A4A4019ADA3AA098042406D1B4641F09A4A40
37951	25809	37.203206000000002	37.226500000000001	53.137770000000003	53.130049999999997	Центральная	0103000020E61000000100000005000000ED2C7AA7029A4240226C787AA5904A40ED2C7AA7029A42405A2F8672A2914A40A245B6F3FD9C42405A2F8672A2914A40A245B6F3FD9C4240226C787AA5904A40ED2C7AA7029A4240226C787AA5904A40
36779	54363	36.886972999999998	37.244179000000003	52.161537000000003	52.103281000000003	 Первомайская	0103000020E61000000100000005000000AEB7CD54887142402BA6D24F380D4A40AEB7CD5488714240070C923EAD144A405CAFE941419F4240070C923EAD144A405CAFE941419F42402BA6D24F380D4A40AEB7CD54887142402BA6D24F380D4A40
37856	54561	36.999361	37.063383999999999	52.231721	52.210087999999999	Терешковой	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
37997	54561	36.999361	37.063383999999999	52.231721	52.210087999999999	Советская улица	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
37897	54561	36.999361	37.063383999999999	52.231721	52.210087999999999	Пионерская	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
37902	54561	36.999361	37.063383999999999	52.231721	52.210087999999999	Комсомольская улица	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
74975	54561	36.999361	37.063383999999999	52.231721	52.210087999999999	Карла Маркса	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
37900	54561	36.999361	37.063383999999999	52.231721	52.210087999999999	Железнодорожная	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
37992	54561	36.999361	37.063383999999999	52.231721	52.210087999999999	1-й Октябрьский переулок	0103000020E61000000100000005000000EDF2AD0FEB7F42401AA4E029E41A4A40EDF2AD0FEB7F4240F165A208A91D4A407A8B87F71C884240F165A208A91D4A407A8B87F71C8842401AA4E029E41A4A40EDF2AD0FEB7F42401AA4E029E41A4A40
71993	48395	36.968890000000002	36.980612999999998	52.214806000000003	52.196626000000002	Лесная	0103000020E61000000100000005000000F2B56796047C42408BC56F0A2B194A40F2B56796047C4240077E54C37E1B4A4027840EBA847D4240077E54C37E1B4A4027840EBA847D42408BC56F0A2B194A40F2B56796047C42408BC56F0A2B194A40
38045	11068	35.54983	35.580283000000001	53.340618999999997	53.330381000000003	Садовая	0103000020E610000001000000050000000A2E56D460C64140221CB3EC49AA4A400A2E56D460C64140B7B2446799AB4A405FB69DB646CA4140B7B2446799AB4A405FB69DB646CA4140221CB3EC49AA4A400A2E56D460C64140221CB3EC49AA4A40
38142	26780	35.482007000000003	35.495806000000002	53.306696000000002	53.299151999999999	Школьная	0103000020E61000000100000005000000B7B8C667B2BD41403944DC9C4AA64A40B7B8C667B2BD414032E884D041A74A408E942D9276BF414032E884D041A74A408E942D9276BF41403944DC9C4AA64A40B7B8C667B2BD41403944DC9C4AA64A40
38124	45810	35.772154	35.815488999999999	53.337736999999997	53.325847000000003	1-я Русская	0103000020E61000000100000005000000E0BC38F1D5E24140F73FC05AB5A94A40E0BC38F1D5E2414017D34CF73AAB4A40B69F8CF161E8414017D34CF73AAB4A40B69F8CF161E84140F73FC05AB5A94A40E0BC38F1D5E24140F73FC05AB5A94A40
38140	46026	35.647351	35.674301	53.380358000000001	53.364735000000003	Центральная	0103000020E610000001000000050000003604C765DCD24140715AF0A2AFAE4A403604C765DCD24140D0622992AFB04A407E54C37E4FD64140D0622992AFB04A407E54C37E4FD64140715AF0A2AFAE4A403604C765DCD24140715AF0A2AFAE4A40
37871	45786	35.664338000000001	35.704690999999997	53.287139000000003	53.269516000000003	Совхозная	0103000020E61000000100000005000000BABE0F0709D54140D7DF12807FA24A40BABE0F0709D54140FD3383F8C0A44A408C648F5033DA4140FD3383F8C0A44A408C648F5033DA4140D7DF12807FA24A40BABE0F0709D54140D7DF12807FA24A40
38123	27320	35.617463999999998	35.663072	53.223936999999999	53.205424999999998	Никольская	0103000020E610000001000000050000008A3A730F09CF4140F163CC5D4B9A4A408A3A730F09CF4140A3AEB5F7A99C4A405872158BDFD44140A3AEB5F7A99C4A405872158BDFD44140F163CC5D4B9A4A408A3A730F09CF4140F163CC5D4B9A4A40
38073	45761	35.715803000000001	35.741387000000003	53.300491999999998	53.279688	Молодежная	0103000020E6100000010000000500000079B0C56E9FDB4140B58AFED0CCA34A4079B0C56E9FDB4140D55A988576A64A40FC56EBC4E5DE4140D55A988576A64A40FC56EBC4E5DE4140B58AFED0CCA34A4079B0C56E9FDB4140B58AFED0CCA34A40
77159	61083	36.301999000000002	37.044995	53.078496000000001	52.727497	Лесная	0103000020E610000001000000050000005D363AE7A72642401478279F1E5D4A405D363AE7A7264240F46E2C280C8A4A40E4BD6A65C2854240F46E2C280C8A4A40E4BD6A65C28542401478279F1E5D4A405D363AE7A72642401478279F1E5D4A40
38649	54661	36.837817000000001	36.851247000000001	52.867724000000003	52.860553000000003	Малая Выгонская	0103000020E61000000100000005000000348463963D6B4240C3BCC799266E4A40348463963D6B424027FA7C94116F4A40B8E864A9F56C424027FA7C94116F4A40B8E864A9F56C4240C3BCC799266E4A40348463963D6B4240C3BCC799266E4A40
38007	8451	36.762017	36.792442999999999	52.954549	52.937168	Паршина	0103000020E610000001000000050000007EFFE6C589614240CA6DFB1EF5774A407EFFE6C589614240FAB660A92E7A4A40D978B0C56E654240FAB660A92E7A4A40D978B0C56E654240CA6DFB1EF5774A407EFFE6C589614240CA6DFB1EF5774A40
38022	8881	36.595424000000001	36.629272999999998	52.918678999999997	52.901919999999997	Школьная	0103000020E6100000010000000500000073A087DA364C4240DDCD531D72734A4073A087DA364C4240D042024697754A40BEA085048C504240D042024697754A40BEA085048C504240DDCD531D72734A4073A087DA364C4240DDCD531D72734A40
38662	54664	36.487769999999998	36.513632999999999	52.880023999999999	52.866745999999999	Школьная	0103000020E6100000010000000500000026FC523F6F3E42402BF86D88F16E4A4026FC523F6F3E4240F9D85DA0A4704A40BC92E4B9BE414240F9D85DA0A4704A40BC92E4B9BE4142402BF86D88F16E4A4026FC523F6F3E42402BF86D88F16E4A40
38109	9093	36.644499000000003	36.663291999999998	53.023864000000003	53.012709999999998	Центральная	0103000020E6100000010000000500000001A777F17E524240842A357BA0814A4001A777F17E524240A0C6BDF90D834A4066D993C0E6544240A0C6BDF90D834A4066D993C0E6544240842A357BA0814A4001A777F17E524240842A357BA0814A40
38132	47272	36.768115999999999	36.804991999999999	52.773747	52.764009999999999	Молодежная	0103000020E6100000010000000500000065C405A05162424092E86514CB614A4065C405A051624240663046240A634A4054C554FA09674240663046240A634A4054C554FA0967424092E86514CB614A4065C405A05162424092E86514CB614A40
37962	47434	36.545622000000002	36.587834000000001	52.864407999999997	52.844647000000002	Почтовый переулок	0103000020E6100000010000000500000033FD12F1D64542400FD594641D6C4A4033FD12F1D64542404C33DDEBA46E4A400ABDFE243E4B42404C33DDEBA46E4A400ABDFE243E4B42400FD594641D6C4A4033FD12F1D64542400FD594641D6C4A40
38675	54665	36.721009000000002	36.760696000000003	52.836347000000004	52.810487999999999	Центральная	0103000020E61000000100000005000000938FDD054A5C424075E61E12BE674A40938FDD054A5C4240CA8D226B0D6B4A4059198D7C5E614240CA8D226B0D6B4A4059198D7C5E61424075E61E12BE674A40938FDD054A5C424075E61E12BE674A40
38170	54618	36.803268000000003	36.828375000000001	52.859884999999998	52.845137000000001	Советская	0103000020E6100000010000000500000030F65E7CD1664240DDD1FF722D6C4A4030F65E7CD166424015A930B6106E4A4079E92631086A424015A930B6106E4A4079E92631086A4240DDD1FF722D6C4A4030F65E7CD1664240DDD1FF722D6C4A40
37976	47328	36.837763000000002	36.878214	52.906340999999998	52.887464000000001	Октябрьская	0103000020E61000000100000005000000416667D13B6B42404D309C6B98714A40416667D13B6B424010035DFB02744A40D671FC506970424010035DFB02744A40D671FC50697042404D309C6B98714A40416667D13B6B42404D309C6B98714A40
37984	47494	36.379829000000001	36.409590000000001	52.954906999999999	52.931893000000002	Привокзальная	0103000020E610000001000000050000004489963C9E304240882F134548774A404489963C9E30424059DC7F643A7A4A406362F3716D34424059DC7F643A7A4A406362F3716D344240882F134548774A404489963C9E304240882F134548774A40
36851	8137	36.874513	36.908971999999999	52.919764999999998	52.882697999999998	М. Горького	0103000020E61000000100000005000000A376BF0AF06F42404F1F813FFC704A40A376BF0AF06F4240B28009DCBA754A40677DCA3159744240B28009DCBA754A40677DCA31597442404F1F813FFC704A40A376BF0AF06F42404F1F813FFC704A40
37993	8137	36.874513	36.908971999999999	52.919764999999998	52.882697999999998	Ленина	0103000020E61000000100000005000000A376BF0AF06F42404F1F813FFC704A40A376BF0AF06F4240B28009DCBA754A40677DCA3159744240B28009DCBA754A40677DCA31597442404F1F813FFC704A40A376BF0AF06F42404F1F813FFC704A40
38052	8137	36.874513	36.908971999999999	52.919764999999998	52.882697999999998	Гагарина	0103000020E61000000100000005000000A376BF0AF06F42404F1F813FFC704A40A376BF0AF06F4240B28009DCBA754A40677DCA3159744240B28009DCBA754A40677DCA31597442404F1F813FFC704A40A376BF0AF06F42404F1F813FFC704A40
36972	8137	36.874513	36.908971999999999	52.919764999999998	52.882697999999998	 М.Горького	0103000020E61000000100000005000000A376BF0AF06F42404F1F813FFC704A40A376BF0AF06F4240B28009DCBA754A40677DCA3159744240B28009DCBA754A40677DCA31597442404F1F813FFC704A40A376BF0AF06F42404F1F813FFC704A40
38110	8619	36.855082000000003	36.892972999999998	52.802475000000001	52.768962999999999	Центральная	0103000020E61000000100000005000000FBB2B453736D4240C26A2C616D624A40FBB2B453736D4240C66D3480B7664A40029B73F04C724240C66D3480B7664A40029B73F04C724240C26A2C616D624A40FBB2B453736D4240C26A2C616D624A40
38010	54581	36.673074999999997	36.946880999999998	52.890152999999998	52.790452000000002	Мира	0103000020E61000000100000005000000AA605452275642406687F8872D654A40AA60545227564240D8B79388F0714A40151A886533794240D8B79388F0714A40151A8865337942406687F8872D654A40AA605452275642406687F8872D654A40
74989	47201	36.774279	36.828169000000003	52.898204	52.869861	Школьная	0103000020E61000000100000005000000637D03931B6342406E88F19A576F4A40637D03931B63424075914259F8724A40D0471971016A424075914259F8724A40D0471971016A42406E88F19A576F4A40637D03931B6342406E88F19A576F4A40
38133	47150	36.710093999999998	36.742209000000003	52.926633000000002	52.904505	Привокзальная	0103000020E61000000100000005000000FC8A355CE45A4240C408E1D1C6734A40FC8A355CE45A42407B32FFE89B764A4000E65AB4005F42407B32FFE89B764A4000E65AB4005F4240C408E1D1C6734A40FC8A355CE45A4240C408E1D1C6734A40
38008	7581	37.504204999999999	37.544440999999999	52.068742999999998	52.047922	Луговая	0103000020E6100000010000000500000066BD18CA89C042402461DF4E22064A4066BD18CA89C042401A6A1492CC084A40FFCC203EB0C542401A6A1492CC084A40FFCC203EB0C542402461DF4E22064A4066BD18CA89C042402461DF4E22064A40
36937	7581	37.504204999999999	37.544440999999999	52.068742999999998	52.047922	Ленина	0103000020E6100000010000000500000066BD18CA89C042402461DF4E22064A4066BD18CA89C042401A6A1492CC084A40FFCC203EB0C542401A6A1492CC084A40FFCC203EB0C542402461DF4E22064A4066BD18CA89C042402461DF4E22064A40
36879	6843	35.114632	35.170605999999999	52.518320000000003	52.497281999999998	Социалистическая	0103000020E610000001000000050000009C89E942AC8E4140DA71C3EFA63F4A409C89E942AC8E41406E6E4C4F58424A402D40DB6AD69541406E6E4C4F58424A402D40DB6AD6954140DA71C3EFA63F4A409C89E942AC8E4140DA71C3EFA63F4A40
36871	6843	35.114632	35.170605999999999	52.518320000000003	52.497281999999998	Советская	0103000020E610000001000000050000009C89E942AC8E4140DA71C3EFA63F4A409C89E942AC8E41406E6E4C4F58424A402D40DB6AD69541406E6E4C4F58424A402D40DB6AD6954140DA71C3EFA63F4A409C89E942AC8E4140DA71C3EFA63F4A40
37971	45534	36.262768999999999	36.274205000000002	52.424067000000001	52.408906999999999	Школьная	0103000020E6100000010000000500000089B3226AA2214240800D881057344A4089B3226AA22142400B28D4D347364A4029B34126192342400B28D4D347364A4029B3412619234240800D881057344A4089B3226AA2214240800D881057344A40
72243	48622	36.336126	36.358708999999998	52.550508000000001	52.53875	Школьная	0103000020E61000000100000005000000EBAA402D062B4240295C8FC2F5444A40EBAA402D062B4240DB17D00B77464A40F3E32F2DEA2D4240DB17D00B77464A40F3E32F2DEA2D4240295C8FC2F5444A40EBAA402D062B4240295C8FC2F5444A40
37974	4828	36.29439	36.365321000000002	52.509880000000003	52.485230000000001	Советская	0103000020E610000001000000050000007D224F92AE254240E08442041C3E4A407D224F92AE254240377172BF43414A4061C5A9D6C22E4240377172BF43414A4061C5A9D6C22E4240E08442041C3E4A407D224F92AE254240E08442041C3E4A40
37983	4828	36.29439	36.365321000000002	52.509880000000003	52.485230000000001	Привокзальная	0103000020E610000001000000050000007D224F92AE254240E08442041C3E4A407D224F92AE254240377172BF43414A4061C5A9D6C22E4240377172BF43414A4061C5A9D6C22E4240E08442041C3E4A407D224F92AE254240E08442041C3E4A40
37952	4828	36.29439	36.365321000000002	52.509880000000003	52.485230000000001	Ленина	0103000020E610000001000000050000007D224F92AE254240E08442041C3E4A407D224F92AE254240377172BF43414A4061C5A9D6C22E4240377172BF43414A4061C5A9D6C22E4240E08442041C3E4A407D224F92AE254240E08442041C3E4A40
37943	4545	37.345266000000002	37.382241	52.618592	52.586809000000002	Кооперативная	0103000020E61000000100000005000000DB3521AD31AC4240CEFFAB8E1C4B4A40DB3521AD31AC42409BC8CC052E4F4A405D18E945EDB042409BC8CC052E4F4A405D18E945EDB04240CEFFAB8E1C4B4A40DB3521AD31AC4240CEFFAB8E1C4B4A40
36929	4545	37.345266000000002	37.382241	52.618592	52.586809000000002	Гайтеровой	0103000020E61000000100000005000000DB3521AD31AC4240CEFFAB8E1C4B4A40DB3521AD31AC42409BC8CC052E4F4A405D18E945EDB042409BC8CC052E4F4A405D18E945EDB04240CEFFAB8E1C4B4A40DB3521AD31AC4240CEFFAB8E1C4B4A40
38041	4656	37.461103999999999	37.492060000000002	52.559393999999998	52.542150999999997	Центральная	0103000020E610000001000000050000000307B47405BB4240313F373465454A400307B47405BB424010CAFB389A474A40BBD573D2FBBE424010CAFB389A474A40BBD573D2FBBE4240313F373465454A400307B47405BB4240313F373465454A40
38084	4746	37.309244	37.341987000000003	52.561064000000002	52.545611999999998	Молодежная	0103000020E61000000100000005000000FB3DB14E95A742400F27309DD6454A40FB3DB14E95A74240427BF5F1D0474A401E54E23AC6AB4240427BF5F1D0474A401E54E23AC6AB42400F27309DD6454A40FB3DB14E95A742400F27309DD6454A40
37963	48215	37.080801999999998	37.096541000000002	52.765633999999999	52.756647999999998	Школьная	0103000020E61000000100000005000000C7B94DB8578A4240BA4A77D7D9604A40C7B94DB8578A4240535A7F4B00624A4090DC9A745B8C4240535A7F4B00624A4090DC9A745B8C4240BA4A77D7D9604A40C7B94DB8578A4240BA4A77D7D9604A40
38139	54609	37.200251000000002	37.235760999999997	52.807195	52.789749999999998	Славянская	0103000020E61000000100000005000000E3FE23D3A19942400C022B8716654A40E3FE23D3A1994240533F6F2A52674A400C569C6A2D9E4240533F6F2A52674A400C569C6A2D9E42400C022B8716654A40E3FE23D3A19942400C022B8716654A40
36848	49500	37.199883	37.267167000000001	52.828930999999997	52.799773999999999	Ленина	0103000020E61000000100000005000000600322C495994240761893FE5E664A40600322C495994240FED137691A6A4A4004C93B8732A24240FED137691A6A4A4004C93B8732A24240761893FE5E664A40600322C495994240761893FE5E664A40
36909	49500	37.199883	37.267167000000001	52.828930999999997	52.799773999999999	Коминтерна	0103000020E61000000100000005000000600322C495994240761893FE5E664A40600322C495994240FED137691A6A4A4004C93B8732A24240FED137691A6A4A4004C93B8732A24240761893FE5E664A40600322C495994240761893FE5E664A40
36839	3310	35.977473000000003	36.035774000000004	53.472349000000001	53.420344	переулок Земляной	0103000020E610000001000000050000008CDCD3D51DFD4140F0880AD5CDB54A408CDCD3D51DFD41402FA699EE75BC4A400806103E940442402FA699EE75BC4A400806103E94044240F0880AD5CDB54A408CDCD3D51DFD4140F0880AD5CDB54A40
36843	3310	35.977473000000003	36.035774000000004	53.472349000000001	53.420344	Ленина	0103000020E610000001000000050000008CDCD3D51DFD4140F0880AD5CDB54A408CDCD3D51DFD41402FA699EE75BC4A400806103E940442402FA699EE75BC4A400806103E94044240F0880AD5CDB54A408CDCD3D51DFD4140F0880AD5CDB54A40
36740	3310	35.977473000000003	36.035774000000004	53.472349000000001	53.420344	Василия Ермакова	0103000020E610000001000000050000008CDCD3D51DFD4140F0880AD5CDB54A408CDCD3D51DFD41402FA699EE75BC4A400806103E940442402FA699EE75BC4A400806103E94044240F0880AD5CDB54A408CDCD3D51DFD4140F0880AD5CDB54A40
74967	8948	35.924688000000003	35.958168000000001	53.569572999999998	53.554411000000002	переулок Школьный	0103000020E610000001000000050000007880272D5CF6414076C58CF0F6C64A407880272D5CF64140A1D79FC4E7C84A407009C03FA5FA4140A1D79FC4E7C84A407009C03FA5FA414076C58CF0F6C64A407880272D5CF6414076C58CF0F6C64A40
80876	62013	37.468164999999999	37.481397000000001	56.296339000000003	56.294201000000001	Бусалова	0103000020E61000000100000005000000E010AAD4ECBB4240AAB9DC60A8254C40E010AAD4ECBB4240C2C3B46FEE254C403EB2B96A9EBD4240C2C3B46FEE254C403EB2B96A9EBD4240AAB9DC60A8254C40E010AAD4ECBB4240AAB9DC60A8254C40
80905	62016	37.449291000000002	37.463368000000003	55.966256999999999	55.957197000000001	Школьная	0103000020E610000001000000050000008EB1135E82B94240276A696E85FA4B408EB1135E82B94240FA43334FAEFB4B40A80183A44FBB4240FA43334FAEFB4B40A80183A44FBB4240276A696E85FA4B408EB1135E82B94240276A696E85FA4B40
4186	11204	37.850982000000002	37.853918999999998	55.937154999999997	55.935026999999998	Школьный проезд	0103000020E610000001000000050000000ABE69FAECEC424041F0F8F6AEF74B400ABE69FAECEC42403524EEB1F4F74B406D37C1374DED42403524EEB1F4F74B406D37C1374DED424041F0F8F6AEF74B400ABE69FAECEC424041F0F8F6AEF74B40
71925	11204	37.828111	37.855517999999996	55.937654000000002	55.934659000000003	Тихонравова	0103000020E610000001000000050000009B3A8F8AFFE94240BFF4F6E7A2F74B409B3A8F8AFFE94240577BD80B05F84B40D591239D81ED4240577BD80B05F84B40D591239D81ED4240BFF4F6E7A2F74B409B3A8F8AFFE94240BFF4F6E7A2F74B40
71805	11204	37.812829999999998	37.865462000000001	55.945292000000002	55.925884000000003	М.К.Тихонравова	0103000020E61000000100000005000000959A3DD00AE84240E1F1ED5D83F64B40959A3DD00AE84240D1950854FFF84B4023F77475C7EE4240D1950854FFF84B4023F77475C7EE4240E1F1ED5D83F64B40959A3DD00AE84240E1F1ED5D83F64B40
4172	11204	37.835583999999997	37.850011000000002	55.934885999999999	55.934421999999998	Лесная улица	0103000020E61000000100000005000000CA87A06AF4EA4240DA54DD239BF74B40CA87A06AF4EA42407FBE2D58AAF74B40C11E1329CDEC42407FBE2D58AAF74B40C11E1329CDEC4240DA54DD239BF74B40CA87A06AF4EA4240DA54DD239BF74B40
80566	11204	37.845492999999998	37.851996999999997	55.926428999999999	55.926307999999999	Комитетская	0103000020E610000001000000050000009BFF571D39EC4240F702B34291F64B409BFF571D39EC42407288B83995F64B4022A5D93C0EED42407288B83995F64B4022A5D93C0EED4240F702B34291F64B409BFF571D39EC4240F702B34291F64B40
71863	11204	37.812829999999998	37.865462000000001	55.945292000000002	55.925884000000003	АМ.К.Тихонравова	0103000020E61000000100000005000000959A3DD00AE84240E1F1ED5D83F64B40959A3DD00AE84240D1950854FFF84B4023F77475C7EE4240D1950854FFF84B4023F77475C7EE4240E1F1ED5D83F64B40959A3DD00AE84240E1F1ED5D83F64B40
71862	11204	37.812829999999998	37.865462000000001	55.945292000000002	55.925884000000003	А.И.Соколова	0103000020E61000000100000005000000959A3DD00AE84240E1F1ED5D83F64B40959A3DD00AE84240D1950854FFF84B4023F77475C7EE4240D1950854FFF84B4023F77475C7EE4240E1F1ED5D83F64B40959A3DD00AE84240E1F1ED5D83F64B40
80677	61947	38.208295999999997	38.226792000000003	55.72166	55.719408999999999	Маяковского	0103000020E610000001000000050000009DF17D71A91A43405AB9179815DC4B409DF17D71A91A43406A6AD95A5FDC4B404A7F2F85071D43406A6AD95A5FDC4B404A7F2F85071D43405AB9179815DC4B409DF17D71A91A43405AB9179815DC4B40
3847	13377	38.417935	38.434922	55.769347000000003	55.766942	улица Ялагина	0103000020E61000000100000005000000486DE2E47E354340E4F6CB272BE24B40486DE2E47E3543404B2366F679E24B40CC272B86AB3743404B2366F679E24B40CC272B86AB374340E4F6CB272BE24B40486DE2E47E354340E4F6CB272BE24B40
3955	13377	38.433413000000002	38.454596000000002	55.779940000000003	55.776958	улица Тевосяна	0103000020E61000000100000005000000A454C2137A374340CB2E185C73E34B40A454C2137A374340CF6BEC12D5E34B403B72A433303A4340CF6BEC12D5E34B403B72A433303A4340CB2E185C73E34B40A454C2137A374340CB2E185C73E34B40
4108	13377	38.423037999999998	38.423774000000002	55.811087999999998	55.808725000000003	улица Сталеваров	0103000020E610000001000000050000008D7BF31B26364340933A014D84E74B408D7BF31B26364340CA1649BBD1E74B409372F7393E364340CA1649BBD1E74B409372F7393E364340933A014D84E74B408D7BF31B26364340933A014D84E74B40
3972	13377	38.437626000000002	38.459941000000001	55.787067	55.783842999999997	улица Корешкова	0103000020E610000001000000050000008DF0F620043843406919A9F754E44B408DF0F620043843406361889CBEE44B40768BC058DF3A43406361889CBEE44B40768BC058DF3A43406919A9F754E44B408DF0F620043843406919A9F754E44B40
3985	13377	38.431840999999999	38.445081999999999	55.813808999999999	55.78481	проспект Ленина	0103000020E610000001000000050000003509DE904637434071C971A774E44B403509DE90463743406118B0E42AE84B40E6046D72F83843406118B0E42AE84B40E6046D72F838434071C971A774E44B403509DE904637434071C971A774E44B40
81048	13377	38.433539000000003	38.447158000000002	55.790154999999999	55.788201000000001	проезд Чернышевского	0103000020E610000001000000050000003145B9347E37434056D636C5E3E44B403145B9347E374340ACE28DCC23E54B4088122D793C394340ACE28DCC23E54B4088122D793C39434056D636C5E3E44B403145B9347E37434056D636C5E3E44B40
80564	13377	38.417935	38.434922	55.769347000000003	55.766942	Ялагина	0103000020E61000000100000005000000486DE2E47E354340E4F6CB272BE24B40486DE2E47E3543404B2366F679E24B40CC272B86AB3743404B2366F679E24B40CC272B86AB374340E4F6CB272BE24B40486DE2E47E354340E4F6CB272BE24B40
79829	13377	38.435920000000003	38.449762999999997	55.767705999999997	55.762343000000001	Южный проспект	0103000020E610000001000000050000000FD6FF39CC374340D2AA967494E14B400FD6FF39CC374340B378B13044E24B40B5F97FD591394340B378B13044E24B40B5F97FD591394340D2AA967494E14B400FD6FF39CC374340D2AA967494E14B40
71920	13377	38.430826000000003	38.466147999999997	55.794775999999999	55.789760000000001	Советская улица	0103000020E610000001000000050000001D226E4E2537434030D80DDB16E54B401D226E4E25374340A6D24F38BBE54B40438CD7BCAA3B4340A6D24F38BBE54B40438CD7BCAA3B434030D80DDB16E54B401D226E4E2537434030D80DDB16E54B40
71820	13377	38.432758	38.453139999999998	55.783245000000001	55.780293999999998	Радио	0103000020E610000001000000050000008B8A389D64374340ECA17DACE0E34B408B8A389D64374340B5E0455F41E44B403541D47D003A4340B5E0455F41E44B403541D47D003A4340ECA17DACE0E34B408B8A389D64374340ECA17DACE0E34B40
79836	13377	38.428553000000001	38.438676999999998	55.804667999999999	55.790878999999997	Пушкина	0103000020E6100000010000000500000025CD1FD3DA364340ED0BE8853BE54B4025CD1FD3DA364340A1116C5CFFE64B40F240649126384340A1116C5CFFE64B40F240649126384340ED0BE8853BE54B4025CD1FD3DA364340ED0BE8853BE54B40
71959	13377	38.434905000000001	38.448037999999997	55.771281999999999	55.769280999999999	Победы	0103000020E61000000100000005000000F6EE8FF7AA3743409337C0CC77E24B40F6EE8FF7AA3743402AFF5A5EB9E24B40C0AE264F593943402AFF5A5EB9E24B40C0AE264F593943409337C0CC77E24B40F6EE8FF7AA3743409337C0CC77E24B40
79835	13377	38.436881	38.449241999999998	55.813738000000001	55.785468000000002	Первомайская	0103000020E61000000100000005000000349F73B7EB374340FB0626378AE44B40349F73B7EB37434098C1189128E84B40ACFE08C38039434098C1189128E84B40ACFE08C380394340FB0626378AE44B40349F73B7EB374340FB0626378AE44B40
71802	13377	38.442208000000001	38.449753999999999	55.784435000000002	55.767696000000001	Мира	0103000020E61000000100000005000000C90391459A38434090A2CEDC43E24B40C90391459A3843403C6BB75D68E44B40629F008A913943403C6BB75D68E44B40629F008A9139434090A2CEDC43E24B40C90391459A38434090A2CEDC43E24B40
81058	13377	38.437626000000002	38.459941000000001	55.787067	55.783842999999997	Корешкова	0103000020E610000001000000050000008DF0F620043843406919A9F754E44B408DF0F620043843406361889CBEE44B40768BC058DF3A43406361889CBEE44B40768BC058DF3A43406919A9F754E44B408DF0F620043843406919A9F754E44B40
80580	13377	38.455798999999999	38.479801999999999	55.803767000000001	55.800463000000001	Комсомольская	0103000020E610000001000000050000005646239F573A43403B54539275E64B405646239F573A4340514D49D6E1E64B401747E5266A3D4340514D49D6E1E64B401747E5266A3D43403B54539275E64B405646239F573A43403B54539275E64B40
79920	13377	38.459733999999997	38.470388	55.809327000000003	55.785452999999997	Карла Маркса	0103000020E61000000100000005000000FC6D4F90D83A4340C5C551B989E44B40FC6D4F90D83A43408962F20698E74B4026378AAC353C43408962F20698E74B4026378AAC353C4340C5C551B989E44B40FC6D4F90D83A4340C5C551B989E44B40
79834	13377	38.416794000000003	38.434401000000001	55.771915	55.769483999999999	Западная	0103000020E61000000100000005000000A3957B8159354340CB65A3737EE24B40A3957B81593543405B25581CCEE24B40C32CB4739A3743405B25581CCEE24B40C32CB4739A374340CB65A3737EE24B40A3957B8159354340CB65A3737EE24B40
79828	13377	38.467872999999997	38.471420999999999	55.805568999999998	55.797457999999999	Загонова	0103000020E6100000010000000500000038D73043E33B43407FF78E1A13E64B4038D73043E33B4340F1D58EE21CE74B40E5D2F885573C4340F1D58EE21CE74B40E5D2F885573C43407FF78E1A13E64B4038D73043E33B43407FF78E1A13E64B40
80614	13377	38.416722999999998	38.433674000000003	55.775646000000002	55.766976999999997	Журавлева	0103000020E61000000100000005000000D93EE42D5735434060E4654D2CE24B40D93EE42D57354340F9A23D5E48E34B4011902FA182374340F9A23D5E48E34B4011902FA18237434060E4654D2CE24B40D93EE42D5735434060E4654D2CE24B40
79816	13377	38.449772000000003	38.453975999999997	55.781346999999997	55.780760000000001	1-я Поселковая	0103000020E610000001000000050000000954FF2092394340320395F1EFE34B400954FF2092394340F2E9B12D03E44B409E95B4E21B3A4340F2E9B12D03E44B409E95B4E21B3A4340320395F1EFE34B400954FF2092394340320395F1EFE34B40
71445	13129	38.778869	38.785670000000003	55.884357999999999	55.865136	Советская улица	0103000020E61000000100000005000000226FB9FAB1634340CF4BC5C6BCEE4B40226FB9FAB16343405DFA97A432F14B4063B9A5D5906443405DFA97A432F14B4063B9A5D590644340CF4BC5C6BCEE4B40226FB9FAB1634340CF4BC5C6BCEE4B40
72185	13129	38.778869	38.785670000000003	55.884357999999999	55.865136	Советская	0103000020E61000000100000005000000226FB9FAB1634340CF4BC5C6BCEE4B40226FB9FAB16343405DFA97A432F14B4063B9A5D5906443405DFA97A432F14B4063B9A5D590644340CF4BC5C6BCEE4B40226FB9FAB1634340CF4BC5C6BCEE4B40
71804	13129	38.769778000000002	38.779355000000002	55.897129999999997	55.889361000000001	Ленина	0103000020E610000001000000050000001497E315886243403FABCC94D6F14B401497E315886243405721E527D5F24B40AF7C96E7C16343405721E527D5F24B40AF7C96E7C16343403FABCC94D6F14B401497E315886243403FABCC94D6F14B40
79989	13129	38.772607999999998	38.782435999999997	55.883983999999998	55.875101999999998	Кржижановского	0103000020E610000001000000050000006150A6D1E46243400455A35703F04B406150A6D1E4624340F817416326F14B40459BE3DC26644340F817416326F14B40459BE3DC266443400455A35703F04B406150A6D1E46243400455A35703F04B40
74097	13129	38.774664999999999	38.785167000000001	55.884054999999996	55.882933999999999	Горького	0103000020E610000001000000050000008C2D043928634340634337FB03F14B408C2D043928634340C16ED8B628F14B4000732D5A80644340C16ED8B628F14B4000732D5A80644340634337FB03F14B408C2D043928634340634337FB03F14B40
80036	618	37.56203	37.565479000000003	55.504863	55.499836000000002	Театральная	0103000020E6100000010000000500000079AF5A99F0C7424086AE44A0FABF4B4079AF5A99F0C74240F0FACC599FC04B4093C9A99D61C84240F0FACC599FC04B4093C9A99D61C8424086AE44A0FABF4B4079AF5A99F0C7424086AE44A0FABF4B40
80578	618	37.555588999999998	37.561014	55.508105999999998	55.500003999999997	Новостроевская	0103000020E610000001000000050000003882548A1DC7424041EF8D2100C04B403882548A1DC7424060730E9E09C14B40904C874ECFC7424060730E9E09C14B40904C874ECFC7424041EF8D2100C04B403882548A1DC7424041EF8D2100C04B40
79815	618	37.5334	37.536670000000001	55.513539999999999	55.508268999999999	Молодежная	0103000020E61000000100000005000000DCD7817346C442400A4966F50EC14B40DCD7817346C442400B98C0ADBBC14B40465F419AB1C442400B98C0ADBBC14B40465F419AB1C442400A4966F50EC14B40DCD7817346C442400A4966F50EC14B40
79825	618	37.522818000000001	37.536670000000001	55.514620999999998	55.513458	Авиаторов	0103000020E610000001000000050000004CE141B3EBC242404EEFE2FDB8C14B404CE141B3EBC24240DB6AD619DFC14B40465F419AB1C44240DB6AD619DFC14B40465F419AB1C442404EEFE2FDB8C14B404CE141B3EBC242404EEFE2FDB8C14B40
71799	618	37.505192999999998	37.584802000000003	55.523167999999998	55.486891999999997	40 Лет Октября	0103000020E6100000010000000500000085950A2AAAC042408E57207A52BE4B4085950A2AAAC042402828452BF7C24B405551BCCADACA42402828452BF7C24B405551BCCADACA42408E57207A52BE4B4085950A2AAAC042408E57207A52BE4B40
71800	618	37.505192999999998	37.584802000000003	55.523167999999998	55.486891999999997	 40 Лет Октября	0103000020E6100000010000000500000085950A2AAAC042408E57207A52BE4B4085950A2AAAC042402828452BF7C24B405551BCCADACA42402828452BF7C24B405551BCCADACA42408E57207A52BE4B4085950A2AAAC042408E57207A52BE4B40
81065	60268	37.969217999999998	37.973987999999999	55.943325999999999	55.940486999999997	проспект 60 лет Октября	0103000020E61000000100000005000000E658DE550FFC424015A8C5E061F84B40E658DE550FFC4240B6BB07E8BEF84B40255987A3ABFC4240B6BB07E8BEF84B40255987A3ABFC424015A8C5E061F84B40E658DE550FFC424015A8C5E061F84B40
80543	60268	37.990831	37.992736000000001	55.922964	55.919986999999999	площадь Ленина	0103000020E61000000100000005000000766EDA8CD3FE424061DF4E22C2F54B40766EDA8CD3FE424053B131AF23F64B40EBC726F911FF424053B131AF23F64B40EBC726F911FF424061DF4E22C2F54B40766EDA8CD3FE424061DF4E22C2F54B40
80545	60268	37.939582000000001	37.994083000000003	55.928693000000003	55.913817999999999	Центральная	0103000020E6100000010000000500000084F4143944F84240813FFCFCF7F44B4084F4143944F8424017838769DFF64B403A419B1C3EFF424017838769DFF64B403A419B1C3EFF4240813FFCFCF7F44B4084F4143944F84240813FFCFCF7F44B40
80524	60268	37.981614999999998	38.000020999999997	55.928027	55.925015999999999	Талсинская	0103000020E61000000100000005000000AB21718FA5FD42406C239EEC66F64B40AB21718FA5FD42400A67B796C9F64B40172829B0000043400A67B796C9F64B40172829B0000043406C239EEC66F64B40AB21718FA5FD42406C239EEC66F64B40
80562	60268	37.991954	38.009408999999998	55.919766000000003	55.910321000000003	Советская	0103000020E6100000010000000500000075914259F8FE424057EE056685F44B4075914259F8FE424083FC6CE4BAF54B40DFA469503401434083FC6CE4BAF54B40DFA469503401434057EE056685F44B4075914259F8FE424057EE056685F44B40
80232	60268	37.974077999999999	37.979674000000003	55.924492000000001	55.919401999999998	Пушкина	0103000020E6100000010000000500000065E08096AEFC424041F0F8F6AEF54B4065E08096AEFC4240F2B4FCC055F64B40EA5E27F565FD4240F2B4FCC055F64B40EA5E27F565FD424041F0F8F6AEF54B4065E08096AEFC424041F0F8F6AEF54B40
80536	60268	37.993085999999998	38.001629000000001	55.927447000000001	55.910890999999999	Пролетарский проспект	0103000020E61000000100000005000000C70E2A711DFF4240419C871398F44B40C70E2A711DFF4240FCE25295B6F64B40D3DC0A6135004340FCE25295B6F64B40D3DC0A6135004340419C871398F44B40C70E2A711DFF4240419C871398F44B40
80542	60268	37.978425999999999	37.990893999999997	55.923276000000001	55.920149000000002	Парковая	0103000020E610000001000000050000002EC72B103DFD42403B394371C7F54B402EC72B103DFD4240429770E82DF64B40BCE6559DD5FE4240429770E82DF64B40BCE6559DD5FE42403B394371C7F54B402EC72B103DFD42403B394371C7F54B40
80029	60268	37.978029999999997	37.993248000000001	55.910927000000001	55.894832999999998	Московская	0103000020E61000000100000005000000E140481630FD4240D73043E389F24B40E140481630FD42408E05854199F44B40A1681EC022FF42408E05854199F44B40A1681EC022FF4240D73043E389F24B40E140481630FD4240D73043E389F24B40
80026	60268	37.990786	38.011349000000003	55.916137999999997	55.915396999999999	Краснознаменская	0103000020E61000000100000005000000D6AA5D13D2FE4240A2ED98BA2BF54B40D6AA5D13D2FE4240B94F8E0244F54B40D1EB4FE273014340B94F8E0244F54B40D1EB4FE273014340A2ED98BA2BF54B40D6AA5D13D2FE4240A2ED98BA2BF54B40
80544	60268	37.985548999999999	38.001511999999998	55.931314999999998	55.927447000000001	Комсомольская	0103000020E6100000010000000500000081CD397826FE4240FCE25295B6F64B4081CD397826FE42401AA3755435F74B409946938B310043401AA3755435F74B409946938B31004340FCE25295B6F64B4081CD397826FE4240FCE25295B6F64B40
80550	60268	38.044370999999998	38.065202999999997	55.903913000000003	55.902085999999997	Институтская	0103000020E6100000010000000500000006F2ECF2AD054340F816D68D77F34B4006F2ECF2AD054340F2B6D26BB3F34B40F04C689258084340F2B6D26BB3F34B40F04C689258084340F816D68D77F34B4006F2ECF2AD054340F816D68D77F34B40
79819	60268	38.044370999999998	38.065202999999997	55.903913000000003	55.902085999999997	Институтская	0103000020E6100000010000000500000006F2ECF2AD054340F816D68D77F34B4006F2ECF2AD054340F2B6D26BB3F34B40F04C689258084340F2B6D26BB3F34B40F04C689258084340F816D68D77F34B4006F2ECF2AD054340F816D68D77F34B40
81040	60268	38.057873000000001	38.067349999999998	55.911400999999998	55.903801999999999	Гагарина	0103000020E610000001000000050000002429E961680743409A07B0C8AFF34B402429E961680743405645B8C9A8F44B405BB1BFEC9E0843405645B8C9A8F44B405BB1BFEC9E0843409A07B0C8AFF34B402429E961680743409A07B0C8AFF34B40
79818	60268	37.939331000000003	38.095278	55.955806000000003	55.863965	8 Марта	0103000020E610000001000000050000003B8F8AFF3BF84240BFF1B56796EE4B403B8F8AFF3BF8424009A9DBD957FA4B409F03CB11320C434009A9DBD957FA4B409F03CB11320C4340BFF1B56796EE4B403B8F8AFF3BF84240BFF1B56796EE4B40
80342	60268	37.992044	38.010972000000002	55.920324999999998	55.918953000000002	1-й Советский переулок	0103000020E61000000100000005000000B5183C4CFBFE4240D2C77C40A0F54B40B5183C4CFBFE42407958A835CDF54B40FB95CE87670143407958A835CDF54B40FB95CE8767014340D2C77C40A0F54B40B5183C4CFBFE4240D2C77C40A0F54B40
80521	59533	39.520536999999997	39.521146999999999	55.586511999999999	55.575454000000001	проспект Маршала Борзова	0103000020E61000000100000005000000D1ADD7F4A0C243401B2D077AA8C94B40D1ADD7F4A0C24340145B41D312CB4B404AB4E4F1B4C24340145B41D312CB4B404AB4E4F1B4C243401B2D077AA8C94B40D1ADD7F4A0C243401B2D077AA8C94B40
80517	59533	39.510305000000002	39.550522000000001	55.575836000000002	55.575225000000003	проспект Ильича	0103000020E610000001000000050000001EFE9AAC51C14340BA6B09F9A0C94B401EFE9AAC51C1434003EE79FEB4C94B4040DD408177C6434003EE79FEB4C94B4040DD408177C64340BA6B09F9A0C94B401EFE9AAC51C14340BA6B09F9A0C94B40
71853	59533	39.497000999999997	39.586948999999997	55.615333999999997	55.557388000000003	Первомайская	0103000020E61000000100000005000000268A90BA9DBF434068976F7D58C74B40268A90BA9DBF4340F50EB743C3CE4B40BFB5132521CB4340F50EB743C3CE4B40BFB5132521CB434068976F7D58C74B40268A90BA9DBF434068976F7D58C74B40
80870	59533	39.520859999999999	39.523302999999999	55.57208	55.562953	Вокзальная	0103000020E61000000100000005000000B4E55C8AABC24340B1170AD80EC84B40B4E55C8AABC243400C59DDEA39C94B400873BB97FBC243400C59DDEA39C94B400873BB97FBC24340B1170AD80EC84B40B4E55C8AABC24340B1170AD80EC84B40
79855	61885	37.452129999999997	37.488295999999998	55.148400000000002	55.140996000000001	Чехова	0103000020E610000001000000050000002EC55565DFB94240F46E2C280C924B402EC55565DFB94240FB5C6DC5FE924B404162BB7B80BE4240FB5C6DC5FE924B404162BB7B80BE4240F46E2C280C924B402EC55565DFB94240F46E2C280C924B40
80086	61885	37.457825	37.472225000000002	55.141022	55.130569999999999	Солнышевская	0103000020E61000000100000005000000462575029ABA42405BEB8B84B6904B40462575029ABA42401D0247020D924B4043AD69DE71BC42401D0247020D924B4043AD69DE71BC42405BEB8B84B6904B40462575029ABA42405BEB8B84B6904B40
81066	61885	37.463475000000003	37.487918999999998	55.156630999999997	55.155642999999998	Полиграфистов	0103000020E61000000100000005000000BEC1172653BB4240F86C1D1CEC934B40BEC1172653BB424017450F7C0C944B406B0C3A2174BE424017450F7C0C944B406B0C3A2174BE4240F86C1D1CEC934B40BEC1172653BB4240F86C1D1CEC934B40
80185	61885	37.412235000000003	37.442086000000003	55.175894	55.149763999999998	Гагарина	0103000020E610000001000000050000001FA2D11DC4B442401F0F7D772B934B401FA2D11DC4B4424004C8D0B183964B407E02284696B8424004C8D0B183964B407E02284696B842401F0F7D772B934B401FA2D11DC4B442401F0F7D772B934B40
824	3200	38.384104999999998	38.432245999999999	56.036799000000002	56.012495999999999	проспект Академика Семенова	0103000020E61000000100000005000000739D465A2A31434058AA0B7899014C40739D465A2A31434044C362D4B5044C40D5E940D65337434044C362D4B5044C40D5E940D65337434058AA0B7899014C40739D465A2A31434058AA0B7899014C40
80328	3200	38.375948000000001	38.380097999999997	56.012898999999997	56.010423000000003	проезд Строителей	0103000020E61000000100000005000000917F66101F3043402810768A55014C40917F66101F3043405793A7ACA6014C4033A31F0DA73043405793A7ACA6014C4033A31F0DA73043402810768A55014C40917F66101F3043402810768A55014C40
855	3200	38.370935000000003	38.387321	56.012445999999997	56.004655	Школьный бульвар	0103000020E610000001000000050000008CF84ECC7A2F4340A661F88898004C408CF84ECC7A2F4340A67B9DD497014C40EA060ABC93314340A67B9DD497014C40EA060ABC93314340A661F88898004C408CF84ECC7A2F4340A661F88898004C40
72270	3200	38.367055000000001	38.380853000000002	56.010734999999997	56.002380000000002	Центральная	0103000020E61000000100000005000000A96A82A8FB2E43400E15E3FC4D004C40A96A82A8FB2E434016F6B4C35F014C40B0CA85CABF30434016F6B4C35F014C40B0CA85CABF3043400E15E3FC4D004C40A96A82A8FB2E43400E15E3FC4D004C40
834	3200	38.373370000000001	38.384104999999998	56.012495999999999	56.006925000000003	Институтский проспект	0103000020E610000001000000050000005DA79196CA2F43402D431CEBE2004C405DA79196CA2F434058AA0B7899014C40739D465A2A31434058AA0B7899014C40739D465A2A3143402D431CEBE2004C405DA79196CA2F43402D431CEBE2004C40
79997	96	37.445033000000002	37.451923000000001	55.889961999999997	55.887084000000002	улица Чапаева	0103000020E61000000100000005000000055262D7F6B842400667F0F78BF14B40055262D7F6B8424064575A46EAF14B40B5A7E49CD8B9424064575A46EAF14B40B5A7E49CD8B942400667F0F78BF14B40055262D7F6B842400667F0F78BF14B40
69721	96	37.433813000000001	37.447862999999998	55.896135000000001	55.889997000000001	улица Маяковского	0103000020E6100000010000000500000032CA332F87B74240E144F46BEBF14B4032CA332F87B7424086E63A8DB4F24B40520B259353B9424086E63A8DB4F24B40520B259353B94240E144F46BEBF14B4032CA332F87B74240E144F46BEBF14B40
16461	96	37.433813000000001	37.447862999999998	55.896135000000001	55.889997000000001	улица Маяковского	0103000020E6100000010000000500000032CA332F87B74240E144F46BEBF14B4032CA332F87B7424086E63A8DB4F24B40520B259353B9424086E63A8DB4F24B40520B259353B94240E144F46BEBF14B4032CA332F87B74240E144F46BEBF14B40
71918	96	37.405265	37.411068	55.891632999999999	55.891002	улица Машенцева	0103000020E61000000100000005000000529B38B9DFB34240D655815A0CF24B40529B38B9DFB342406684B70721F24B40503750E09DB442406684B70721F24B40503750E09DB44240D655815A0CF24B40529B38B9DFB34240D655815A0CF24B40
16432	96	37.286012999999997	37.299819999999997	55.955393000000001	55.950296999999999	улица Горького	0103000020E610000001000000050000008C9DF0129CA44240533E0455A3F94B408C9DF0129CA44240E6E95C514AFA4B40E657738060A64240E6E95C514AFA4B40E657738060A64240533E0455A3F94B408C9DF0129CA44240533E0455A3F94B40
71860	96	37.333506999999997	37.334629999999997	55.941279000000002	55.938223999999998	улица Глинки	0103000020E6100000010000000500000058FE7C5BB0AA424041295AB917F84B4058FE7C5BB0AA4240AFB48CD47BF84B405721E527D5AA4240AFB48CD47BF84B405721E527D5AA424041295AB917F84B4058FE7C5BB0AA424041295AB917F84B40
80039	96	37.447305999999998	37.457996000000001	55.90363	55.896095000000003	проспект Мира	0103000020E61000000100000005000000FCA6B05241B94240F88DAF3DB3F24B40FCA6B05241B942409DD7D825AAF34B4073D9E89C9FBA42409DD7D825AAF34B4073D9E89C9FBA4240F88DAF3DB3F24B40FCA6B05241B94240F88DAF3DB3F24B40
331	96	37.402847999999999	37.409081999999998	55.903671000000003	55.898406999999999	проспект Мельникова	0103000020E6100000010000000500000027A1F48590B34240ADBF2500FFF24B4027A1F48590B34240FCABC77DABF34B40EEB089CC5CB44240FCABC77DABF34B40EEB089CC5CB44240ADBF2500FFF24B4027A1F48590B34240ADBF2500FFF24B40
71771	96	37.361911999999997	37.377685999999997	55.924501999999997	55.915604000000002	мкр. Планерная	0103000020E61000000100000005000000D503E62153AE42401C0B0A8332F54B40D503E62153AE4240158BDF1456F64B401A14CD0358B04240158BDF1456F64B401A14CD0358B042401C0B0A8332F54B40D503E62153AE42401C0B0A8332F54B40
80766	96	37.228116999999997	37.507071000000003	55.997613000000001	55.877414999999999	мкр. Новогорск	0103000020E61000000100000005000000B05417F0329D42408A027D224FF04B40B05417F0329D4240408864C8B1FF4B4001E0D8B3E7C04240408864C8B1FF4B4001E0D8B3E7C042408A027D224FF04B40B05417F0329D42408A027D224FF04B40
229	96	37.408957000000001	37.433903000000001	55.898457000000001	55.886583999999999	Юбилейный проспект	0103000020E61000000100000005000000323CF6B358B442401494A2957BF14B40323CF6B358B442405FEE93A300F34B4072512D228AB742405FEE93A300F34B4072512D228AB742401494A2957BF14B40323CF6B358B442401494A2957BF14B40
80557	96	37.295696999999997	37.296353000000003	55.945337000000002	55.941369999999999	Тюкова	0103000020E610000001000000050000003D433866D9A54240BFB7E9CF7EF84B403D433866D9A54240715985CD00F94B40278925E5EEA54240715985CD00F94B40278925E5EEA54240BFB7E9CF7EF84B403D433866D9A54240BFB7E9CF7EF84B40
81043	96	37.337037000000002	37.337819000000003	55.940638999999997	55.938313999999998	Спортивная	0103000020E610000001000000050000005F45460724AB424081B053AC1AF84B405F45460724AB4240CB2BD7DB66F84B40D57B2AA73DAB4240CB2BD7DB66F84B40D57B2AA73DAB424081B053AC1AF84B405F45460724AB424081B053AC1AF84B40
80209	96	37.228116999999997	37.507071000000003	55.997613000000001	55.877414999999999	Соколовская	0103000020E61000000100000005000000B05417F0329D42408A027D224FF04B40B05417F0329D4240408864C8B1FF4B4001E0D8B3E7C04240408864C8B1FF4B4001E0D8B3E7C042408A027D224FF04B40B05417F0329D42408A027D224FF04B40
80298	96	37.473159000000003	37.483643000000001	55.895161000000002	55.891370000000002	Пожарского	0103000020E610000001000000050000006F675F7990BC42405951836918F24B406F675F7990BC4240CCD3B9A294F24B403CF88903E8BD4240CCD3B9A294F24B403CF88903E8BD42405951836918F24B406F675F7990BC42405951836918F24B40
80511	96	37.299819999999997	37.309136000000002	55.962589000000001	55.950296999999999	Первомайская	0103000020E61000000100000005000000E657738060A64240533E0455A3F94B40E657738060A64240A33EC91D36FB4B401502B9C491A74240A33EC91D36FB4B401502B9C491A74240533E0455A3F94B40E657738060A64240533E0455A3F94B40
80515	96	37.415146	37.419134999999997	55.898522999999997	55.894539999999999	Парковая	0103000020E6100000010000000500000059880E8123B542405F7B664980F24B4059880E8123B5424016DA39CD02F34B40F2CD3637A6B5424016DA39CD02F34B40F2CD3637A6B542405F7B664980F24B4059880E8123B542405F7B664980F24B40
80510	96	37.424345000000002	37.431702000000001	55.887144999999997	55.877879	Панфилова	0103000020E610000001000000050000004E9CDCEF50B642402F6CCD565EF04B404E9CDCEF50B64240ABE7A4F78DF14B4014CFD90242B74240ABE7A4F78DF14B4014CFD90242B742402F6CCD565EF04B404E9CDCEF50B642402F6CCD565EF04B40
80908	96	37.326563	37.337819000000003	55.942901999999997	55.940638999999997	Октябрьская	0103000020E61000000100000005000000B58AFED0CCA94240CB2BD7DB66F84B40B58AFED0CCA942409FAA4203B1F84B40D57B2AA73DAB42409FAA4203B1F84B40D57B2AA73DAB4240CB2BD7DB66F84B40B58AFED0CCA94240CB2BD7DB66F84B40
80310	96	37.472062999999999	37.473339000000003	55.892713000000001	55.889527999999999	Нахимова	0103000020E610000001000000050000006953758F6CBC42402A70B20DDCF14B406953758F6CBC424066DB696B44F24B40EF75525F96BC424066DB696B44F24B40EF75525F96BC42402A70B20DDCF14B406953758F6CBC42402A70B20DDCF14B40
80504	96	37.441034999999999	37.450386999999999	55.894095999999998	55.884928000000002	Московская	0103000020E6100000010000000500000018B2BAD573B8424048A8195245F14B4018B2BAD573B8424001BEDBBC71F24B4093C5FD47A6B9424001BEDBBC71F24B4093C5FD47A6B9424048A8195245F14B4018B2BAD573B8424048A8195245F14B40
80229	96	37.399659	37.409126999999998	55.900860000000002	55.897917	Молодежный проезд	0103000020E61000000100000005000000AA46AF0628B34240DFC2BAF1EEF24B40AA46AF0628B34240252367614FF34B408E7406465EB44240252367614FF34B408E7406465EB44240DFC2BAF1EEF24B40AA46AF0628B34240DFC2BAF1EEF24B40
74113	96	37.389848999999998	37.423285	55.904251000000002	55.878202999999999	Молодежная	0103000020E610000001000000050000006CB07092E6B14240E21FB6F468F04B406CB07092E6B142400A302C7FBEF34B4095F1EF332EB642400A302C7FBEF34B4095F1EF332EB64240E21FB6F468F04B406CB07092E6B14240E21FB6F468F04B40
71859	96	37.399309000000002	37.406190000000002	55.90851	55.905977	Марии Рубцовой	0103000020E61000000100000005000000CEFFAB8E1CB34240CFF6E80DF7F34B40CEFFAB8E1CB34240630B410E4AF44B402BFBAE08FEB34240630B410E4AF44B402BFBAE08FEB34240CFF6E80DF7F34B40CEFFAB8E1CB34240CFF6E80DF7F34B40
16	96	37.452632999999999	37.474317999999997	55.917268	55.894944000000002	Ленинский проспект	0103000020E61000000100000005000000910BCEE0EFB942402FE065868DF24B40910BCEE0EFB942406BD5AE0969F54B40BAF3C473B6BC42406BD5AE0969F54B40BAF3C473B6BC42402FE065868DF24B40910BCEE0EFB942402FE065868DF24B40
80073	96	37.429789	37.439895	55.894666999999998	55.886609999999997	Ленинградская	0103000020E610000001000000050000001C97715303B742403D27BD6F7CF14B401C97715303B74240BCE7C07284F24B404356B77A4EB84240BCE7C07284F24B404356B77A4EB842403D27BD6F7CF14B401C97715303B742403D27BD6F7CF14B40
80138	96	37.412945000000001	37.427408	55.892212999999998	55.889330999999999	Лавочкина	0103000020E61000000100000005000000FB05BB61DBB44240D4282499D5F14B40FB05BB61DBB4424074081C0934F24B403E062B4EB5B6424074081C0934F24B403E062B4EB5B64240D4282499D5F14B40FB05BB61DBB44240D4282499D5F14B40
74084	96	37.228116999999997	37.507071000000003	55.997613000000001	55.877414999999999	Куркинское шоссе	0103000020E61000000100000005000000B05417F0329D42408A027D224FF04B40B05417F0329D4240408864C8B1FF4B4001E0D8B3E7C04240408864C8B1FF4B4001E0D8B3E7C042408A027D224FF04B40B05417F0329D42408A027D224FF04B40
74091	96	37.228116999999997	37.507071000000003	55.997613000000001	55.877414999999999	Куркинское шоссе	0103000020E61000000100000005000000B05417F0329D42408A027D224FF04B40B05417F0329D4240408864C8B1FF4B4001E0D8B3E7C04240408864C8B1FF4B4001E0D8B3E7C042408A027D224FF04B40B05417F0329D42408A027D224FF04B40
80056	96	37.451509999999999	37.454214	55.892774000000003	55.882165999999998	Кирова	0103000020E6100000010000000500000092E86514CBB9424052D2C3D0EAF04B4092E86514CBB942400C5C1E6B46F24B4053B131AF23BA42400C5C1E6B46F24B4053B131AF23BA424052D2C3D0EAF04B4092E86514CBB9424052D2C3D0EAF04B40
80785	96	37.228116999999997	37.507071000000003	55.997613000000001	55.877414999999999	Квартал Свистуха	0103000020E61000000100000005000000B05417F0329D42408A027D224FF04B40B05417F0329D4240408864C8B1FF4B4001E0D8B3E7C04240408864C8B1FF4B4001E0D8B3E7C042408A027D224FF04B40B05417F0329D42408A027D224FF04B40
71840	96	37.473168000000001	37.481513999999997	55.889527999999999	55.887326999999999	Зеленая улица	0103000020E61000000100000005000000C2C1DEC490BC4240CCED5EEE93F14B40C2C1DEC490BC42402A70B20DDCF14B4077483140A2BD42402A70B20DDCF14B4077483140A2BD4240CCED5EEE93F14B40C2C1DEC490BC4240CCED5EEE93F14B40
81056	96	37.430633	37.435834	55.888567999999999	55.884504	Горшина	0103000020E6100000010000000500000008CA6DFB1EB742403197546D37F14B4008CA6DFB1EB74240D522A298BCF14B40103E9468C9B74240D522A298BCF14B40103E9468C9B742403197546D37F14B4008CA6DFB1EB742403197546D37F14B40
81017	96	37.305191999999998	37.337397000000003	55.959263	55.956003000000003	Горная	0103000020E610000001000000050000001B800D8810A742405FF0694E5EFA4B401B800D8810A74240A5A14621C9FA4B405F622CD32FAB4240A5A14621C9FA4B405F622CD32FAB42405FF0694E5EFA4B401B800D8810A742405FF0694E5EFA4B40
79807	96	37.452748999999997	37.455983000000003	55.889082999999999	55.886316999999998	Ватутина	0103000020E61000000100000005000000FA25E2ADF3B94240C571E0D572F14B40FA25E2ADF3B94240FC36C478CDF14B401844A4A65DBA4240FC36C478CDF14B401844A4A65DBA4240C571E0D572F14B40FA25E2ADF3B94240C571E0D572F14B40
80513	96	37.450952999999998	37.454653999999998	55.904826	55.901752999999999	Бурденко	0103000020E610000001000000050000003C84F1D3B8B94240F2086EA46CF34B403C84F1D3B8B9424006499F56D1F34B406F7F2E1A32BA424006499F56D1F34B406F7F2E1A32BA4240F2086EA46CF34B403C84F1D3B8B94240F2086EA46CF34B40
401	96	37.469880000000003	37.485340000000001	55.896594999999998	55.891965999999996	Библиотечная улица	0103000020E61000000100000005000000B285200725BC42406C921FF12BF24B40B285200725BC4240E960FD9FC3F24B4067B8019F1FBE4240E960FD9FC3F24B4067B8019F1FBE42406C921FF12BF24B40B285200725BC42406C921FF12BF24B40
79985	96	37.469880000000003	37.485340000000001	55.896594999999998	55.891965999999996	Библиотечная	0103000020E61000000100000005000000B285200725BC42406C921FF12BF24B40B285200725BC4240E960FD9FC3F24B4067B8019F1FBE4240E960FD9FC3F24B4067B8019F1FBE42406C921FF12BF24B40B285200725BC42406C921FF12BF24B40
80520	96	37.445653	37.450952999999998	55.901752999999999	55.899704	Березовая Аллея	0103000020E61000000100000005000000A12E52280BB942404A0A2C8029F34B40A12E52280BB94240F2086EA46CF34B403C84F1D3B8B94240F2086EA46CF34B403C84F1D3B8B942404A0A2C8029F34B40A12E52280BB942404A0A2C8029F34B40
80506	96	37.419466999999997	37.428576	55.883206999999999	55.880217000000002	Бабакина	0103000020E6100000010000000500000028603B18B1B542400E315EF3AAF04B4028603B18B1B54240944C4EED0CF14B40DDEC0F94DBB64240944C4EED0CF14B40DDEC0F94DBB642400E315EF3AAF04B4028603B18B1B542400E315EF3AAF04B40
80079	96	37.228116999999997	37.507071000000003	55.997613000000001	55.877414999999999	9 Мая	0103000020E61000000100000005000000B05417F0329D42408A027D224FF04B40B05417F0329D4240408864C8B1FF4B4001E0D8B3E7C04240408864C8B1FF4B4001E0D8B3E7C042408A027D224FF04B40B05417F0329D42408A027D224FF04B40
16417	96	37.291258999999997	37.295957999999999	55.947277999999997	55.946188999999997	2-й Чапаевский переулок	0103000020E6100000010000000500000034D593F947A54240DF6A9DB81CF94B4034D593F947A54240321CCF6740F94B40AA7EA5F3E1A54240321CCF6740F94B40AA7EA5F3E1A54240DF6A9DB81CF94B4034D593F947A54240DF6A9DB81CF94B40
80022	11769	38.045313999999998	38.066937000000003	55.957439000000001	55.947736999999996	проспект Мира	0103000020E61000000100000005000000850662D9CC054340C51A2E724FF94B40850662D9CC0543401D75745C8DFA4B4039F24064910843401D75745C8DFA4B4039F2406491084340C51A2E724FF94B40850662D9CC054340C51A2E724FF94B40
80481	11769	38.046635000000002	38.054917000000003	55.955897	55.954051999999997	Школьная	0103000020E61000000100000005000000ABECBB22F805434079573D601EFA4B40ABECBB22F805434019AC38D55AFA4B404A7F2F850707434019AC38D55AFA4B404A7F2F850707434079573D601EFA4B40ABECBB22F805434079573D601EFA4B40
81091	11769	38.022497000000001	38.041972000000001	55.961727000000003	55.958708999999999	Попова	0103000020E610000001000000050000000AA1832EE1024340C0B0FCF9B6FA4B400AA1832EE10243401157CEDE19FB4B4082ACA7565F0543401157CEDE19FB4B4082ACA7565F054340C0B0FCF9B6FA4B400AA1832EE1024340C0B0FCF9B6FA4B40
80490	11769	38.051557000000003	38.070359000000003	55.95185	55.944803	Полевая	0103000020E61000000100000005000000A070766B99064340D314014EEFF84B40A070766B990643404B598638D6F94B4059FD1186010943404B598638D6F94B4059FD118601094340D314014EEFF84B40A070766B99064340D314014EEFF84B40
80019	11769	38.026989	38.039008000000003	55.959293000000002	55.956668000000001	Нахимова	0103000020E61000000100000005000000062D2460740343409B90D61874FA4B40062D2460740343401024EF1CCAFA4B402524D236FE0443401024EF1CCAFA4B402524D236FE0443409B90D61874FA4B40062D2460740343409B90D61874FA4B40
80492	11769	38.039619000000002	38.047111000000001	55.952328000000001	55.948960999999997	Луговая	0103000020E610000001000000050000006EA6423C12054340F816D68D77F94B406EA6423C12054340558847E2E5F94B401424B6BB07064340558847E2E5F94B401424B6BB07064340F816D68D77F94B406EA6423C12054340F816D68D77F94B40
80480	11769	38.042349999999999	38.043823000000003	55.960864999999998	55.953336	Комсомольская	0103000020E61000000100000005000000287E8CB96B054340BB0CFFE906FA4B40287E8CB96B0543407E6FD39FFDFA4B4004E8F7FD9B0543407E6FD39FFDFA4B4004E8F7FD9B054340BB0CFFE906FA4B40287E8CB96B054340BB0CFFE906FA4B40
80712	61953	36.438830000000003	36.504900999999997	55.622604000000003	55.571775000000002	Новая	0103000020E610000001000000050000007940D9942B384240D0D556EC2FC94B407940D9942B384240ED2DE57CB1CF4B40DD5B9198A0404240ED2DE57CB1CF4B40DD5B9198A0404240D0D556EC2FC94B407940D9942B384240D0D556EC2FC94B40
74101	31250	37.249901000000001	37.328583999999999	55.509217	55.449812000000001	микрорайон В	0103000020E610000001000000050000006D1E87C1FC9F424097AC8A7093B94B406D1E87C1FC9F42409BC8CC052EC14B4093FE5E0A0FAA42409BC8CC052EC14B4093FE5E0A0FAA424097AC8A7093B94B406D1E87C1FC9F424097AC8A7093B94B40
80053	31250	37.300745999999997	37.306790999999997	55.477791000000003	55.473689	Школьная	0103000020E610000001000000050000008F334DD87EA64240CBBC55D7A1BC4B408F334DD87EA642405DA9674128BD4B4083DA6FED44A742405DA9674128BD4B4083DA6FED44A74240CBBC55D7A1BC4B408F334DD87EA64240CBBC55D7A1BC4B40
7911	31250	37.295149000000002	37.297431000000003	55.474674	55.467860999999999	Сиреневый бульвар	0103000020E610000001000000050000003B394371C7A54240740987DEE2BB4B403B394371C7A5424079211D1EC2BC4B4086E8103812A6424079211D1EC2BC4B4086E8103812A64240740987DEE2BB4B403B394371C7A54240740987DEE2BB4B40
72154	31250	37.249901000000001	37.328583999999999	55.509217	55.449812000000001	Площадь Верещагина	0103000020E610000001000000050000006D1E87C1FC9F424097AC8A7093B94B406D1E87C1FC9F42409BC8CC052EC14B4093FE5E0A0FAA42409BC8CC052EC14B4093FE5E0A0FAA424097AC8A7093B94B406D1E87C1FC9F424097AC8A7093B94B40
16895	31250	37.290702000000003	37.306350999999999	55.484183000000002	55.470968999999997	Октябрьский проспект	0103000020E61000000100000005000000DF701FB935A54240043752B648BC4B40DF701FB935A54240BC2363B5F9BD4B40670C738236A74240BC2363B5F9BD4B40670C738236A74240043752B648BC4B40DF701FB935A54240043752B648BC4B40
74072	31250	37.249901000000001	37.328583999999999	55.509217	55.449812000000001	Микрорайон В	0103000020E610000001000000050000006D1E87C1FC9F424097AC8A7093B94B406D1E87C1FC9F42409BC8CC052EC14B4093FE5E0A0FAA42409BC8CC052EC14B4093FE5E0A0FAA424097AC8A7093B94B406D1E87C1FC9F424097AC8A7093B94B40
71856	31250	37.249901000000001	37.328583999999999	55.509217	55.449812000000001	Микрорайон В	0103000020E610000001000000050000006D1E87C1FC9F424097AC8A7093B94B406D1E87C1FC9F42409BC8CC052EC14B4093FE5E0A0FAA42409BC8CC052EC14B4093FE5E0A0FAA424097AC8A7093B94B406D1E87C1FC9F424097AC8A7093B94B40
80502	31250	37.313617999999998	37.314740999999998	55.493822999999999	55.491697000000002	Комсомольский проезд	0103000020E61000000100000005000000EDB776A224A842404A4563EDEFBE4B40EDB776A224A842409D81919735BF4B40ECDADE6E49A842409D81919735BF4B40ECDADE6E49A842404A4563EDEFBE4B40EDB776A224A842404A4563EDEFBE4B40
79809	61868	37.511634000000001	37.517814000000001	56.727041999999997	56.723016999999999	Шишунова	0103000020E61000000100000005000000C6C210397DC14240DCB930D28B5C4C40C6C210397DC14240C26856B60F5D4C409AB4A9BA47C24240C26856B60F5D4C409AB4A9BA47C24240DCB930D28B5C4C40C6C210397DC14240DCB930D28B5C4C40
79805	61868	37.528154000000001	37.539957999999999	56.742151	56.731397999999999	Победы	0103000020E6100000010000000500000034A0DE8C9AC342400E2E1D739E5D4C4034A0DE8C9AC34240CBD8D0CDFE5E4C40569BFF571DC54240CBD8D0CDFE5E4C40569BFF571DC542400E2E1D739E5D4C4034A0DE8C9AC342400E2E1D739E5D4C40
80849	61868	37.528962999999997	37.533023	56.724637000000001	56.722909000000001	Орлова	0103000020E61000000100000005000000A3E5400FB5C34240F67D3848885C4C40A3E5400FB5C342405C3CBCE7C05C4C40068200193AC442405C3CBCE7C05C4C40068200193AC44240F67D3848885C4C40A3E5400FB5C34240F67D3848885C4C40
79984	59517	38.049509	38.084553	54.885435000000001	54.883130999999999	Чайковского	0103000020E61000000100000005000000C8ED974F56064340B98AC56F0A714B40C8ED974F56064340ECDD1FEF55714B40ACE3F8A1D20A4340ECDD1FEF55714B40ACE3F8A1D20A4340B98AC56F0A714B40C8ED974F56064340B98AC56F0A714B40
80006	59517	38.086637000000003	38.089269000000002	54.897965999999997	54.883602000000003	Тургенева	0103000020E61000000100000005000000D1CFD4EB160B43401157CEDE19714B40D1CFD4EB160B4340C075C58CF0724B40F8C5A52A6D0B4340C075C58CF0724B40F8C5A52A6D0B43401157CEDE19714B40D1CFD4EB160B43401157CEDE19714B40
80688	59517	38.083393999999998	38.087049999999998	54.899545000000003	54.879981999999998	Пушкина	0103000020E61000000100000005000000605793A7AC0A4340CA880B40A3704B40605793A7AC0A4340E223624A24734B40F38E5374240B4340E223624A24734B40F38E5374240B4340CA880B40A3704B40605793A7AC0A4340CA880B40A3704B40
80698	59517	38.070673999999997	38.076072000000003	54.896853	54.879469	Куйбышева	0103000020E61000000100000005000000B8567BD80B094340446CB07092704B40B8567BD80B094340E5284014CC724B40171230BABC094340E5284014CC724B40171230BABC094340446CB07092704B40B8567BD80B094340446CB07092704B40
80445	59517	38.084632999999997	38.113765999999998	54.903509999999997	54.876004000000002	Колхозная 	0103000020E61000000100000005000000C8940F41D50A4340259529E620704B40C8940F41D50A4340F2CD3637A6734B40C8B260E28F0E4340F2CD3637A6734B40C8B260E28F0E4340259529E620704B40C8940F41D50A4340259529E620704B40
80467	59517	38.126091000000002	38.136825999999999	54.867409000000002	54.861249000000001	Есенина	0103000020E61000000100000005000000F4A8F8BF231043403A5B40683D6E4B40F4A8F8BF23104340C7A01342076F4B400A9FAD8383114340C7A01342076F4B400A9FAD83831143403A5B40683D6E4B40F4A8F8BF231043403A5B40683D6E4B40
80452	59517	38.060532000000002	38.094155999999998	54.893104000000001	54.889054999999999	Горького	0103000020E61000000100000005000000452E3883BF07434032ACE28DCC714B40452E3883BF074340A1F65B3B51724B40705CC64D0D0C4340A1F65B3B51724B40705CC64D0D0C434032ACE28DCC714B40452E3883BF07434032ACE28DCC714B40
71815	59517	38.028892999999997	38.167225000000002	54.920506000000003	54.853205000000003	Городищенская	0103000020E61000000100000005000000AA0A0DC4B203434050E449D2356D4B40AA0A0DC4B2034340CAE2FE23D3754B406C09F9A067154340CAE2FE23D3754B406C09F9A06715434050E449D2356D4B40AA0A0DC4B203434050E449D2356D4B40
80493	59517	38.072946000000002	38.092663999999999	54.891722000000001	54.891064	 Тимирязева	0103000020E61000000100000005000000E02F664B560943404C5299620E724B40E02F664B56094340D68F4DF223724B401EC2F869DC0B4340D68F4DF223724B401EC2F869DC0B43404C5299620E724B40E02F664B560943404C5299620E724B40
80662	61948	38.155214000000001	38.197552000000002	55.816246999999997	55.806519999999999	Большая Московская	0103000020E61000000100000005000000D0F0660DDE134340F3C81F0C3CE74B40D0F0660DDE134340A33A1DC87AE84B4034A1496249194340A33A1DC87AE84B4034A1496249194340F3C81F0C3CE74B40D0F0660DDE134340F3C81F0C3CE74B40
79982	61911	36.947932000000002	36.970049000000003	56.183923999999998	56.172555000000003	Обуховская	0103000020E610000001000000050000007B6AF5D55579424072E1404816164C407B6AF5D555794240897956D28A174C403E42CD902A7C4240897956D28A174C403E42CD902A7C424072E1404816164C407B6AF5D55579424072E1404816164C40
80432	61911	36.963554000000002	36.967480000000002	56.203251999999999	56.196061	Вертлинская	0103000020E610000001000000050000000AF7CABC557B4240B282DF8618194C400AF7CABC557B42405D6C5A29041A4C405DC47762D67B42405D6C5A29041A4C405DC47762D67B4240B282DF8618194C400AF7CABC557B4240B282DF8618194C40
80441	61911	36.978295000000003	36.990718999999999	56.190776999999997	56.187210999999998	Банковская	0103000020E61000000100000005000000906B43C5387D4240C939B187F6174C40906B43C5387D42401CEA77616B184C404E4354E1CF7E42401CEA77616B184C404E4354E1CF7E4240C939B187F6174C40906B43C5387D4240C939B187F6174C40
5798	12304	37.412469000000002	37.425044999999997	54.919387999999998	54.900291000000003	улица Чехова	0103000020E6100000010000000500000092CEC0C8CBB442400BF148BC3C734B4092CEC0C8CBB44240DC2A8881AE754B40062AE3DF67B64240DC2A8881AE754B40062AE3DF67B642400BF148BC3C734B4092CEC0C8CBB442400BF148BC3C734B40
5943	12304	37.408427000000003	37.450405000000003	54.939424000000002	54.911977999999998	улица Ворошилова	0103000020E61000000100000005000000D6E6FF5547B44240F355F2B1BB744B40D6E6FF5547B44240EC89AE0B3F784B403A7AFCDEA6B94240EC89AE0B3F784B403A7AFCDEA6B94240F355F2B1BB744B40D6E6FF5547B44240F355F2B1BB744B40
5811	12304	37.413736	37.422924999999999	54.924956000000002	54.917985999999999	проезд Мишина	0103000020E61000000100000005000000C4961E4DF5B44240CA17B49080754B40C4961E4DF5B44240971E4DF564764B4095D4096822B64240971E4DF564764B4095D4096822B64240CA17B49080754B40C4961E4DF5B44240CA17B49080754B40
80410	12304	37.394008999999997	37.403970999999999	54.942790000000002	54.940514999999998	Юбилейная	0103000020E6100000010000000500000032AA0CE36EB24240DF32A7CB62784B4032AA0CE36EB24240787FBC57AD784B4026C45C52B5B34240787FBC57AD784B4026C45C52B5B34240DF32A7CB62784B4032AA0CE36EB24240DF32A7CB62784B40
79999	12304	37.382545999999998	37.397466999999999	54.914234	54.908768999999999	Чернышевского	0103000020E61000000100000005000000999B6F44F7B042402F4FE78A52744B40999B6F44F7B042401572A59E05754B409F1EDB32E0B242401572A59E05754B409F1EDB32E0B242402F4FE78A52744B40999B6F44F7B042402F4FE78A52744B40
71841	12304	37.428835999999997	37.444071999999998	54.922683999999997	54.894502000000003	Центральная улица	0103000020E6100000010000000500000079AC1919E4B64240721AA20A7F724B4079AC1919E4B642406F4562821A764B40DF88EE59D7B842406F4562821A764B40DF88EE59D7B84240721AA20A7F724B4079AC1919E4B64240721AA20A7F724B40
72105	12304	37.428835999999997	37.444071999999998	54.922683999999997	54.894502000000003	Центральная	0103000020E6100000010000000500000079AC1919E4B64240721AA20A7F724B4079AC1919E4B642406F4562821A764B40DF88EE59D7B842406F4562821A764B40DF88EE59D7B84240721AA20A7F724B4079AC1919E4B64240721AA20A7F724B40
80365	12304	37.381422999999998	37.397108000000003	54.937494999999998	54.931494999999998	Химиков	0103000020E610000001000000050000009A780778D2B042409AB1683A3B774B409A780778D2B04240EE940ED6FF774B40707D586FD4B24240EE940ED6FF774B40707D586FD4B242409AB1683A3B774B409A780778D2B042409AB1683A3B774B40
80393	12304	37.440415999999999	37.446838999999997	54.931179	54.925669999999997	Фирсова	0103000020E610000001000000050000004C512E8D5FB84240B471C45A7C764B404C512E8D5FB842406ADC9BDF30774B40E6C9350532B942406ADC9BDF30774B40E6C9350532B94240B471C45A7C764B404C512E8D5FB84240B471C45A7C764B40
80379	12304	37.441780999999999	37.441915999999999	54.938901000000001	54.937283000000001	Тяговая 	0103000020E61000000100000005000000417FA1478CB84240630CACE3F8774B40417FA1478CB84240429770E82D784B4021CA17B490B84240429770E82D784B4021CA17B490B84240630CACE3F8774B40417FA1478CB84240630CACE3F8774B40
80424	12304	37.455202	37.466368000000003	54.937427	54.931463999999998	Текстильная	0103000020E610000001000000050000007289230F44BA42405FB35C363A774B407289230F44BA424096B1A19BFD774B4052F355F2B1BB424096B1A19BFD774B4052F355F2B1BB42405FB35C363A774B407289230F44BA42405FB35C363A774B40
69615	12304	37.408749999999998	37.450296999999999	54.934221000000001	54.913561999999999	Советская улица	0103000020E61000000100000005000000B81E85EB51B44240266F8099EF744B40B81E85EB51B44240431EC18D94774B40533E0455A3B94240431EC18D94774B40533E0455A3B94240266F8099EF744B40B81E85EB51B44240266F8099EF744B40
72094	12304	37.408749999999998	37.450296999999999	54.934221000000001	54.913561999999999	Советская	0103000020E61000000100000005000000B81E85EB51B44240266F8099EF744B40B81E85EB51B44240431EC18D94774B40533E0455A3B94240431EC18D94774B40533E0455A3B94240266F8099EF744B40B81E85EB51B44240266F8099EF744B40
80015	12304	37.408489000000003	37.415028999999997	54.916418	54.909281999999997	Свердлова	0103000020E610000001000000050000004CE3175E49B44240B56B425A63744B404CE3175E49B442409DBB5D2F4D754B401FF296AB1FB542409DBB5D2F4D754B401FF296AB1FB54240B56B425A63744B404CE3175E49B44240B56B425A63744B40
80013	12304	37.389229999999998	37.402785000000002	54.935110000000002	54.924909	Пушкина	0103000020E61000000100000005000000A04FE449D2B142405663096B63764B40A04FE449D2B14240CF143AAFB1774B40E12879758EB34240CF143AAFB1774B40E12879758EB342405663096B63764B40A04FE449D2B142405663096B63764B40
74195	12304	37.365414999999999	37.404231000000003	54.934955000000002	54.908152999999999	Пролетарская	0103000020E61000000100000005000000E23B31EBC5AE4240D461855B3E744B40E23B31EBC5AE4240A81DFE9AAC774B40C38366D7BDB34240A81DFE9AAC774B40C38366D7BDB34240D461855B3E744B40E23B31EBC5AE4240D461855B3E744B40
80010	12304	37.442346999999998	37.450682999999998	54.923780999999998	54.919699000000001	Осенняя	0103000020E61000000100000005000000EA3D95D39EB84240FB9463B2B8754B40EA3D95D39EB8424045D5AF743E764B407CEE04FBAFB9424045D5AF743E764B407CEE04FBAFB94240FB9463B2B8754B40EA3D95D39EB84240FB9463B2B8754B40
79941	12304	37.425485999999999	37.433804000000002	54.915249000000003	54.906699000000003	Новослободская 	0103000020E61000000100000005000000F373435376B6424070287CB60E744B40F373435376B642402E5915E126754B40DF6FB4E386B742402E5915E126754B40DF6FB4E386B7424070287CB60E744B40F373435376B6424070287CB60E744B40
79967	12304	37.402731000000003	37.409773999999999	54.954062	54.924325000000003	Московское шоссе	0103000020E61000000100000005000000EE0A7DB08CB3424007F0164850764B40EE0A7DB08CB342409D2D20B41E7A4B402460747973B442409D2D20B41E7A4B402460747973B4424007F0164850764B40EE0A7DB08CB3424007F0164850764B40
68475	12304	37.380443999999997	37.380471	54.920180000000002	54.920158999999998	Красный Текстильщик	0103000020E61000000100000005000000CEFA9463B2B042405E0F26C5C7754B40CEFA9463B2B0424076374F75C8754B40C8091346B3B0424076374F75C8754B40C8091346B3B042405E0F26C5C7754B40CEFA9463B2B042405E0F26C5C7754B40
80326	12304	37.383867000000002	37.395572000000001	54.918804000000002	54.906103999999999	Космонавтов	0103000020E61000000100000005000000BF81C98D22B142402C634337FB734B40BF81C98D22B142408DB7955E9B754B404E9B711AA2B242408DB7955E9B754B404E9B711AA2B242402C634337FB734B40BF81C98D22B142402C634337FB734B40
80011	12304	37.401932000000002	37.404851000000001	54.906689	54.906021000000003	Клубный переулок	0103000020E61000000100000005000000A29BFD8172B342409F3E027FF8734B40A29BFD8172B342404C5299620E744B405F605628D2B342404C5299620E744B405F605628D2B342409F3E027FF8734B40A29BFD8172B342409F3E027FF8734B40
80012	12304	37.454483000000003	37.456352000000003	54.934494999999998	54.923532999999999	Дзержинского	0103000020E6100000010000000500000043CBBA7F2CBA42406DE34F5436764B4043CBBA7F2CBA424044A33B889D774B406BBB09BE69BA424044A33B889D774B406BBB09BE69BA42406DE34F5436764B4043CBBA7F2CBA42406DE34F5436764B40
80352	12304	37.427624000000002	37.439931000000001	54.927976999999998	54.9178	Джона Рида	0103000020E610000001000000050000000B7E1B62BCB6424068226C787A754B400B7E1B62BCB64240583849F3C7764B4090BFB4A84FB84240583849F3C7764B4090BFB4A84FB8424068226C787A754B400B7E1B62BCB6424068226C787A754B40
71912	12304	37.427902000000003	37.439715	54.935828999999998	54.922564999999999	Горького	0103000020E610000001000000050000004EF2237EC5B6424095B7239C16764B404EF2237EC5B64240FED2A23EC9774B40C347C49448B84240FED2A23EC9774B40C347C49448B8424095B7239C16764B404EF2237EC5B6424095B7239C16764B40
80014	12304	37.454644999999999	37.463591999999998	54.927646000000003	54.924841999999998	Войкова	0103000020E610000001000000050000001C25AFCE31BA4240CEFBFF3861764B401C25AFCE31BA4240F321A81ABD764B40F7578FFB56BB4240F321A81ABD764B40F7578FFB56BB4240CEFBFF3861764B401C25AFCE31BA4240CEFBFF3861764B40
79983	12304	37.426779000000003	37.434379	54.919466	54.916252999999998	Водонапорная	0103000020E610000001000000050000004FCFBBB1A0B6424052EE3EC747754B404FCFBBB1A0B6424058E4D70FB1754B40DB8827BB99B7424058E4D70FB1754B40DB8827BB99B7424052EE3EC747754B404FCFBBB1A0B6424052EE3EC747754B40
71911	12304	37.403925999999998	37.404572999999999	54.903748	54.898555999999999	Большой Ударный переулок	0103000020E610000001000000050000008600E0D8B3B34240F2CF0CE203734B408600E0D8B3B34240A7E9B303AE734B401CEC4D0CC9B34240A7E9B303AE734B401CEC4D0CC9B34240F2CF0CE203734B408600E0D8B3B34240F2CF0CE203734B40
80341	12304	37.367274999999999	37.378594	54.918483000000002	54.913893000000002	1905 года	0103000020E61000000100000005000000B7D100DE02AF42408C852172FA744B40B7D100DE02AF42404B77D7D990754B401D3BA8C475B042404B77D7D990754B401D3BA8C475B042408C852172FA744B40B7D100DE02AF42408C852172FA744B40
80353	12304	37.402731000000003	37.416564999999999	54.924325000000003	54.913685999999998	1-я Московская	0103000020E61000000100000005000000EE0A7DB08CB342401268B0A9F3744B40EE0A7DB08CB3424007F0164850764B4041D47D0052B5424007F0164850764B4041D47D0052B542401268B0A9F3744B40EE0A7DB08CB342401268B0A9F3744B40
71838	59528	38.127096999999999	38.159122000000004	56.334975999999997	56.292437999999997	проспект Красной Армии	0103000020E61000000100000005000000B935E9B644104340C70DBF9B6E254C40B935E9B644104340F2785A7EE02A4C407D09151C5E144340F2785A7EE02A4C407D09151C5E144340C70DBF9B6E254C40B935E9B644104340C70DBF9B6E254C40
80049	59528	38.116604000000002	38.127780000000001	56.295324999999998	56.294676000000003	Хотьковский проезд	0103000020E61000000100000005000000994A3FE1EC0E4340437573F1B7254C40994A3FE1EC0E43407958A835CD254C409C8A54185B1043407958A835CD254C409C8A54185B104340437573F1B7254C40994A3FE1EC0E4340437573F1B7254C40
80244	59528	38.175794000000003	38.177042999999998	56.299585999999998	56.288190999999998	Птицеградская	0103000020E61000000100000005000000A16AF46A8016434032005471E3244C40A16AF46A80164340732B84D558264C402C7E5358A9164340732B84D558264C402C7E5358A916434032005471E3244C40A16AF46A8016434032005471E3244C40
79978	59528	38.175552000000003	38.179935999999998	56.304870000000001	56.299590999999999	Молодежная	0103000020E61000000100000005000000AB5FE97C78164340859675FF58264C40AB5FE97C7816434009C4EBFA05274C40C0AF91240817434009C4EBFA05274C40C0AF912408174340859675FF58264C40AB5FE97C78164340859675FF58264C40
80702	59528	38.116594999999997	38.127096999999999	56.293506999999998	56.292453000000002	Куликова	0103000020E6100000010000000500000045F0BF95EC0E4340FD4E93196F254C4045F0BF95EC0E4340D3122BA391254C40B935E9B644104340D3122BA391254C40B935E9B644104340FD4E93196F254C4045F0BF95EC0E4340FD4E93196F254C40
80172	59528	38.100380999999999	38.125363	56.309344000000003	56.307566000000001	Кирова	0103000020E61000000100000005000000E411DC48D90C434047AE9B525E274C40E411DC48D90C43405F9B8D9598274C40719010E50B1043405F9B8D9598274C40719010E50B10434047AE9B525E274C40E411DC48D90C434047AE9B525E274C40
80157	59528	38.131031	38.143059999999998	56.333039999999997	56.324441	Дружбы	0103000020E610000001000000050000008FE1B19FC5104340A33D5E4887294C408FE1B19FC51043404221020EA12A4C40D1AE42CA4F1243404221020EA12A4C40D1AE42CA4F124340A33D5E4887294C408FE1B19FC5104340A33D5E4887294C40
80235	59528	38.140365000000003	38.144568999999997	56.319884000000002	56.310667000000002	Валовая	0103000020E610000001000000050000006440F67AF71143402579AEEFC3274C406440F67AF7114340C0417BF5F1284C40F981AB3C81124340C0417BF5F1284C40F981AB3C811243402579AEEFC3274C406440F67AF71143402579AEEFC3274C40
80696	61950	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	Ульяновская	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
80701	61950	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	Волоколамское шоссе	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
80122	13222	39.863998000000002	39.882916999999999	55.657814000000002	55.657037000000003	улица Энгельса	0103000020E610000001000000050000009BE7887C97EE434088A1D5C919D44B409BE7887C97EE4340EC6CC83F33D44B408D0A9C6C03F14340EC6CC83F33D44B408D0A9C6C03F1434088A1D5C919D44B409BE7887C97EE434088A1D5C919D44B40
80707	13222	39.863998000000002	39.882916999999999	55.657814000000002	55.657037000000003	Энгельса	0103000020E610000001000000050000009BE7887C97EE434088A1D5C919D44B409BE7887C97EE4340EC6CC83F33D44B408D0A9C6C03F14340EC6CC83F33D44B408D0A9C6C03F1434088A1D5C919D44B409BE7887C97EE434088A1D5C919D44B40
80058	13222	39.863998000000002	39.882916999999999	55.657814000000002	55.657037000000003	Фридриха Энгельса	0103000020E610000001000000050000009BE7887C97EE434088A1D5C919D44B409BE7887C97EE4340EC6CC83F33D44B408D0A9C6C03F14340EC6CC83F33D44B408D0A9C6C03F1434088A1D5C919D44B409BE7887C97EE434088A1D5C919D44B40
71928	13222	39.813952999999998	39.890273999999998	55.663659000000003	55.658423999999997	Советская улица	0103000020E6100000010000000500000094BDA59C2FE843406473D53C47D44B4094BDA59C2FE84340195932C7F2D44B40533D997FF4F14340195932C7F2D44B40533D997FF4F143406473D53C47D44B4094BDA59C2FE843406473D53C47D44B40
80711	13222	39.849913000000001	39.853209999999997	55.671818000000002	55.658723000000002	Свердлова	0103000020E61000000100000005000000FEB8FDF2C9EC4340BF0F070951D44B40FEB8FDF2C9EC43409C6ED921FED54B40614F3BFC35ED43409C6ED921FED54B40614F3BFC35ED4340BF0F070951D44B40FEB8FDF2C9EC4340BF0F070951D44B40
80693	13222	39.863036999999998	39.888136000000003	55.659399000000001	55.65849	Октябрьской Революции	0103000020E61000000100000005000000751E15FF77EE43401C5F7B6649D44B40751E15FF77EE4340EF01BA2F67D44B403C33C170AEF14340EF01BA2F67D44B403C33C170AEF143401C5F7B6649D44B40751E15FF77EE43401C5F7B6649D44B40
80720	13222	39.849319999999999	39.850226999999997	55.671722000000003	55.658687999999998	Карла Маркса	0103000020E610000001000000050000005BEB8B84B6EC434042226DE34FD44B405BEB8B84B6EC43407A008BFCFAD54B408D96033DD4EC43407A008BFCFAD54B408D96033DD4EC434042226DE34FD44B405BEB8B84B6EC434042226DE34FD44B40
61939	52779	37.845914999999998	37.862462000000001	55.768425999999998	55.760190000000001	улица Победы	0103000020E61000000100000005000000111956F146EC4240855FEAE74DE14B40111956F146EC4240B3B27DC85BE24B407905A22765EE4240B3B27DC85BE24B407905A22765EE4240855FEAE74DE14B40111956F146EC4240855FEAE74DE14B40
61942	52779	37.865957000000002	37.868265000000001	55.750160000000001	55.746456000000002	улица Котовского	0103000020E61000000100000005000000035FD1ADD7EE424095F3C5DE8BDF4B40035FD1ADD7EE424039622D3E05E04B4077A1B94E23EF424039622D3E05E04B4077A1B94E23EF424095F3C5DE8BDF4B40035FD1ADD7EE424095F3C5DE8BDF4B40
67004	52779	37.859569999999998	37.864789000000002	55.751275	55.745452999999998	Южная	0103000020E61000000100000005000000B54FC76306EE424040DAFF006BDF4B40B54FC76306EE4240B5A679C729E04B406478EC67B1EE4240B5A679C729E04B406478EC67B1EE424040DAFF006BDF4B40B54FC76306EE424040DAFF006BDF4B40
59437	52779	37.851646000000002	37.877895000000002	55.752459999999999	55.744743	Юбилейный проспект	0103000020E6100000010000000500000076E272BC02ED4240647616BD53DF4B4076E272BC02ED42402AC6F99B50E04B40352905DD5EF042402AC6F99B50E04B40352905DD5EF04240647616BD53DF4B4076E272BC02ED4240647616BD53DF4B40
59466	52779	37.853245000000001	37.864420000000003	55.768090999999998	55.764384	Советская	0103000020E61000000100000005000000DE3CD52137ED4240F7CABC55D7E14B40DE3CD52137ED42400CAD4ECE50E24B4011018750A5EE42400CAD4ECE50E24B4011018750A5EE4240F7CABC55D7E14B40DE3CD52137ED4240F7CABC55D7E14B40
66985	52779	37.845914999999998	37.862462000000001	55.768425999999998	55.760190000000001	Победы	0103000020E61000000100000005000000111956F146EC4240855FEAE74DE14B40111956F146EC4240B3B27DC85BE24B407905A22765EE4240B3B27DC85BE24B407905A22765EE4240855FEAE74DE14B40111956F146EC4240855FEAE74DE14B40
66999	52779	37.842590999999999	37.861842000000003	55.758462999999999	55.755144999999999	Новая	0103000020E61000000100000005000000B4739A05DAEB4240745E6397A8E04B40B4739A05DAEB4240EF1CCA5015E14B40DD28B2D650EE4240EF1CCA5015E14B40DD28B2D650EE4240745E6397A8E04B40B4739A05DAEB4240745E6397A8E04B40
59452	52779	37.846643	37.855392000000002	55.760793	55.759901999999997	Лесная	0103000020E6100000010000000500000094313ECC5EEC42401E15FF7744E14B4094313ECC5EEC42404B033FAA61E14B4049A12C7C7DED42404B033FAA61E14B4049A12C7C7DED42401E15FF7744E14B4094313ECC5EEC42401E15FF7744E14B40
59461	52779	37.846445000000003	37.853496999999997	55.760767999999999	55.750864	Комсомольская улица	0103000020E610000001000000050000006E6E4C4F58EC424033DFC14F1CE04B406E6E4C4F58EC4240F2EB87D860E14B40F71DC3633FED4240F2EB87D860E14B40F71DC3633FED424033DFC14F1CE04B406E6E4C4F58EC424033DFC14F1CE04B40
80747	59541	38.224958999999998	38.272103000000001	55.568838	55.552627000000001	Михалевича	0103000020E610000001000000050000006EF8DD74CB1C43407CF1457BBCC64B406EF8DD74CB1C43406C5CFFAECFC84B405E126745D42243406C5CFFAECFC84B405E126745D42243407CF1457BBCC64B406EF8DD74CB1C43407CF1457BBCC64B40
80687	59541	38.230609999999999	38.274527999999997	55.572156	55.565778000000002	Красноармейская	0103000020E61000000100000005000000B610E4A0841D4340ED65DB696BC84B40B610E4A0841D4340E71A66683CC94B400BEBC6BB23234340E71A66683CC94B400BEBC6BB23234340ED65DB696BC84B40B610E4A0841D4340ED65DB696BC84B40
80676	59541	38.202528000000001	38.209643	55.591670999999998	55.582771999999999	Космонавтов	0103000020E610000001000000050000001C430070EC1943402383DC4598CA4B401C430070EC194340ED7E15E0BBCB4B40EC6AF294D51A4340ED7E15E0BBCB4B40EC6AF294D51A43402383DC4598CA4B401C430070EC1943402383DC4598CA4B40
80700	59541	38.213973000000003	38.230609999999999	55.571474000000002	55.567214	Карла Маркса	0103000020E610000001000000050000000F9D9E77631B4340ABEAE5779AC84B400F9D9E77631B4340D5415E0F26C94B40B610E4A0841D4340D5415E0F26C94B40B610E4A0841D4340ABEAE5779AC84B400F9D9E77631B4340ABEAE5779AC84B40
80094	59541	38.232703000000001	38.238874000000003	55.576385999999999	55.563941	Гурьева	0103000020E610000001000000050000002E573F36C91D4340D0EFFB372FC84B402E573F36C91D4340A6EF3504C7C94B40AFEE586C931E4340A6EF3504C7C94B40AFEE586C931E4340D0EFFB372FC84B402E573F36C91D4340D0EFFB372FC84B40
79959	59541	38.196420000000003	38.229306999999999	55.567310999999997	55.557006000000001	100-й Свирской Дивизии	0103000020E61000000100000005000000E223624A2419434080D6FCF84BC74B40E223624A241943409DD497A59DC84B4037DF88EE591D43409DD497A59DC84B4037DF88EE591D434080D6FCF84BC74B40E223624A2419434080D6FCF84BC74B40
15660	4258	37.602885000000001	37.643300000000004	54.833879000000003	54.831307000000002	проспект Науки	0103000020E61000000100000005000000DE1FEF552BCD4240CBF78C44686A4B40DE1FEF552BCD42401DE90C8CBC6A4B4027C286A757D242401DE90C8CBC6A4B4027C286A757D24240CBF78C44686A4B40DE1FEF552BCD4240CBF78C44686A4B40
71916	4258	37.603613000000003	37.630921000000001	54.836528999999999	54.834325	бульвар Иерусалимского	0103000020E610000001000000050000006138D73043CD42401B9E5E29CB6A4B406138D73043CD4240EA93DC61136B4B4008AEF204C2D04240EA93DC61136B4B4008AEF204C2D042401B9E5E29CB6A4B406138D73043CD42401B9E5E29CB6A4B40
71825	59520	37.772252999999999	37.885055000000001	56.065483999999998	55.961505000000002	мкр. Дзержинец	0103000020E61000000100000005000000739EB12FD9E2424062F8889812FB4B40739EB12FD9E24240A4349BC761084C40A514747B49F14240A4349BC761084C40A514747B49F1424062F8889812FB4B40739EB12FD9E2424062F8889812FB4B40
80841	59520	37.870736000000001	37.871580000000002	56.024918999999997	56.013829000000001	Центральная	0103000020E6100000010000000500000095B9F94674EF4240425E0F26C5014C4095B9F94674EF42404606B98B30034C4081ECF5EE8FEF42404606B98B30034C4081ECF5EE8FEF4240425E0F26C5014C4095B9F94674EF4240425E0F26C5014C40
80498	59520	37.841963	37.856048000000001	56.013311000000002	56.009813999999999	Тургенева	0103000020E6100000010000000500000095B88E71C5EB42407F85CC9541014C4095B88E71C5EB4240AAD6C22CB4014C4032E719FB92ED4240AAD6C22CB4014C4032E719FB92ED42407F85CC9541014C4095B88E71C5EB42407F85CC9541014C40
71915	59520	37.861716000000001	37.873663999999998	56.011253000000004	56.003073999999998	Серебрянка	0103000020E610000001000000050000005038BBB54CEE4240E4BB94BA64004C405038BBB54CEE4240AF7D01BD70014C40A5D8D138D4EF4240AF7D01BD70014C40A5D8D138D4EF4240E4BB94BA64004C405038BBB54CEE4240E4BB94BA64004C40
80906	59520	37.821472	37.826825999999997	55.975938999999997	55.975898999999998	Кольцовская	0103000020E61000000100000005000000344A97FE25E942407C992842EAFC4B40344A97FE25E942400AF2B391EBFC4B40C2BD326FD5E942400AF2B391EBFC4B40C2BD326FD5E942407C992842EAFC4B40344A97FE25E942407C992842EAFC4B40
80639	59520	37.855562999999997	37.863055000000003	56.016978999999999	56.013125000000002	Институтская	0103000020E610000001000000050000007555A01683ED424048E17A14AE014C407555A01683ED424001DC2C5E2C024C401CD3139678EE424001DC2C5E2C024C401CD3139678EE424048E17A14AE014C407555A01683ED424048E17A14AE014C40
80514	59520	37.828488	37.858510000000003	56.049038000000003	56.048701000000001	Горького	0103000020E61000000100000005000000719010E50BEA4240292499D53B064C40719010E50BEA424071218FE046064C40FDA4DAA7E3ED424071218FE046064C40FDA4DAA7E3ED4240292499D53B064C40719010E50BEA4240292499D53B064C40
80644	59520	37.813594000000002	37.815175000000004	55.990569000000001	55.987411999999999	Вокзальная	0103000020E61000000100000005000000651C23D923E84240C7D6338463FE4B40651C23D923E8424039B709F7CAFE4B4027C286A757E8424039B709F7CAFE4B4027C286A757E84240C7D6338463FE4B40651C23D923E84240C7D6338463FE4B40
80640	4116	37.220103999999999	37.227443000000001	54.872751000000001	54.860911999999999	Школьная	0103000020E6100000010000000500000001DC2C5E2C9C4240F25D4A5D326E4B4001DC2C5E2C9C42409146054EB66F4B40215A2BDA1C9D42409146054EB66F4B40215A2BDA1C9D4240F25D4A5D326E4B4001DC2C5E2C9C4240F25D4A5D326E4B40
1115	4116	37.210366	37.219842999999997	54.880360000000003	54.875495999999998	Северный проезд	0103000020E610000001000000050000005D18E945ED9A4240B0E3BF4010704B405D18E945ED9A4240715AF0A2AF704B4094A0BFD0239C4240715AF0A2AF704B4094A0BFD0239C4240B0E3BF4010704B405D18E945ED9A4240B0E3BF4010704B40
1104	4116	37.210411000000001	37.217705000000002	54.879303	54.874077	Лесной бульвар	0103000020E61000000100000005000000FDDB65BFEE9A4240C89750C1E16F4B40FDDB65BFEE9A424029232E008D704B407D96E7C1DD9B424029232E008D704B407D96E7C1DD9B4240C89750C1E16F4B40FDDB65BFEE9A4240C89750C1E16F4B40
80459	4116	37.213177999999999	37.224981999999997	54.881695999999998	54.862242999999999	Ленина	0103000020E61000000100000005000000041DAD6A499B42403B1A87FA5D6E4B40041DAD6A499B4240CB811E6ADB704B402618CE35CC9C4240CB811E6ADB704B402618CE35CC9C42403B1A87FA5D6E4B40041DAD6A499B42403B1A87FA5D6E4B40
80457	4116	37.208156000000002	37.216996000000002	54.873108000000002	54.872050999999999	Дружбы	0103000020E61000000100000005000000AC3B16DBA49A4240D8B8FE5D9F6F4B40AC3B16DBA49A424020F0C000C26F4B4071AE6186C69B424020F0C000C26F4B4071AE6186C69B4240D8B8FE5D9F6F4B40AC3B16DBA49A4240D8B8FE5D9F6F4B40
80465	4116	37.216996000000002	37.230767	54.876531999999997	54.872393000000002	Архитектора Корина	0103000020E6100000010000000500000071AE6186C69B42403221E692AA6F4B4071AE6186C69B4240E0F2583332704B407EFFE6C5899D4240E0F2583332704B407EFFE6C5899D42403221E692AA6F4B4071AE6186C69B42403221E692AA6F4B40
8053	204	37.564670999999997	37.567608	55.442469000000003	55.433608	улица Ульяновых	0103000020E61000000100000005000000F3FFAA2347C8424059A4897780B74B40F3FFAA2347C84240363FFED2A2B84B4057790261A7C84240363FFED2A2B84B4057790261A7C8424059A4897780B74B40F3FFAA2347C8424059A4897780B74B40
8001	204	37.544746000000004	37.556261999999997	55.446283999999999	55.437213999999997	улица Павлика Морозова	0103000020E610000001000000050000003C50A73CBAC542403AADDBA0F6B74B403C50A73CBAC54240315D88D51FB94B40F700DD9733C74240315D88D51FB94B40F700DD9733C742403AADDBA0F6B74B403C50A73CBAC542403AADDBA0F6B74B40
80405	204	37.519809000000002	37.529860999999997	55.421689999999998	55.418635000000002	улица Гайдара	0103000020E610000001000000050000004F95EF1989C2424001FBE8D495B54B404F95EF1989C242406E861BF0F9B54B408236397CD2C342406E861BF0F9B54B408236397CD2C3424001FBE8D495B54B404F95EF1989C2424001FBE8D495B54B40
7750	204	37.558965999999998	37.567481999999998	55.487758999999997	55.460501999999998	проспект Юных Ленинцев	0103000020E61000000100000005000000B8C9A8328CC742400DDFC2BAF1BA4B40B8C9A8328CC7424032AA0CE36EBE4B40CA880B40A3C8424032AA0CE36EBE4B40CA880B40A3C842400DDFC2BAF1BA4B40B8C9A8328CC742400DDFC2BAF1BA4B40
7978	204	37.550702000000001	37.558553000000003	55.461762999999998	55.460552999999997	проезд Авиаторов	0103000020E61000000100000005000000C0EB33677DC642408F899466F3BA4B40C0EB33677DC642405DC0CB0C1BBB4B40960A2AAA7EC742405DC0CB0C1BBB4B40960A2AAA7EC742408F899466F3BA4B40C0EB33677DC642408F899466F3BA4B40
80392	204	37.494737000000001	37.501069999999999	55.431713000000002	55.418608999999996	Юбилейная	0103000020E61000000100000005000000828FC18A53BF4240D767CEFA94B54B40828FC18A53BF42400821205F42B74B40DC80CF0F23C042400821205F42B74B40DC80CF0F23C04240D767CEFA94B54B40828FC18A53BF4240D767CEFA94B54B40
80389	204	37.494737000000001	37.501069999999999	55.431713000000002	55.418608999999996	Юбилейная	0103000020E61000000100000005000000828FC18A53BF4240D767CEFA94B54B40828FC18A53BF42400821205F42B74B40DC80CF0F23C042400821205F42B74B40DC80CF0F23C04240D767CEFA94B54B40828FC18A53BF4240D767CEFA94B54B40
80897	204	37.570968000000001	37.580238000000001	55.441555000000001	55.439385000000001	Халатова	0103000020E610000001000000050000000188BB7A15C942402EAD86C43DB84B400188BB7A15C942405131CEDF84B84B40BFF2203D45CA42405131CEDF84B84B40BFF2203D45CA42402EAD86C43DB84B400188BB7A15C942402EAD86C43DB84B40
80440	204	37.566727999999998	37.578297999999997	55.408026	55.404136000000001	Филиппова	0103000020E610000001000000050000001EDD088B8AC8424071917BBABAB34B401EDD088B8AC8424077F52A323AB44B40CDAB3AAB05CA424077F52A323AB44B40CDAB3AAB05CA424071917BBABAB34B401EDD088B8AC8424071917BBABAB34B40
8043	204	37.539687999999998	37.561579999999999	55.435743000000002	55.427529999999997	Февральская улица	0103000020E610000001000000050000009605137F14C542408907944DB9B64B409605137F14C54240003B376DC6B74B40390B7BDAE1C74240003B376DC6B74B40390B7BDAE1C742408907944DB9B64B409605137F14C542408907944DB9B64B40
80375	204	37.539687999999998	37.561579999999999	55.435743000000002	55.427529999999997	Февральская	0103000020E610000001000000050000009605137F14C542408907944DB9B64B409605137F14C54240003B376DC6B74B40390B7BDAE1C74240003B376DC6B74B40390B7BDAE1C742408907944DB9B64B409605137F14C542408907944DB9B64B40
80372	204	37.564670999999997	37.567608	55.442469000000003	55.433608	Ульяновых	0103000020E61000000100000005000000F3FFAA2347C8424059A4897780B74B40F3FFAA2347C84240363FFED2A2B84B4057790261A7C84240363FFED2A2B84B4057790261A7C8424059A4897780B74B40F3FFAA2347C8424059A4897780B74B40
80471	204	37.561067999999999	37.565694999999998	55.405312000000002	55.397801999999999	Сосновая 	0103000020E61000000100000005000000836A8313D1C7424046240A2DEBB24B40836A8313D1C7424093567C43E1B34B405F419AB168C8424093567C43E1B34B405F419AB168C8424046240A2DEBB24B40836A8313D1C7424046240A2DEBB24B40
80446	204	37.572054999999999	37.584693999999999	55.426447000000003	55.41865	Северная	0103000020E61000000100000005000000B341261939C94240363CBD5296B54B40B341261939C94240193DB7D095B64B406E15C440D7CA4240193DB7D095B64B406E15C440D7CA4240363CBD5296B54B40B341261939C94240363CBD5296B54B40
79995	204	37.529105999999999	37.54374	55.428904000000003	55.414557000000002	Свердлова	0103000020E61000000100000005000000060FD3BEB9C34240F8A92A3410B54B40060FD3BEB9C34240D28F8653E6B64B4076C3B64599C54240D28F8653E6B64B4076C3B64599C54240F8A92A3410B54B40060FD3BEB9C34240F8A92A3410B54B40
8104	204	37.540712999999997	37.564033000000002	55.436709	55.431085000000003	Революционный проспект	0103000020E61000000100000005000000D2C2651536C54240E96514CB2DB74B40D2C2651536C54240376F9C14E6B74B40B16EBC3B32C84240376F9C14E6B74B40B16EBC3B32C84240E96514CB2DB74B40D2C2651536C54240E96514CB2DB74B40
80364	204	37.545850999999999	37.558965999999998	55.465707999999999	55.460512000000001	Профсоюзная	0103000020E6100000010000000500000094BE1072DEC5424031B5A50EF2BA4B4094BE1072DEC5424027BEDA519CBB4B40B8C9A8328CC7424027BEDA519CBB4B40B8C9A8328CC7424031B5A50EF2BA4B4094BE1072DEC5424031B5A50EF2BA4B40
80075	204	37.553018999999999	37.565137999999997	55.412072999999999	55.404862000000001	Правды	0103000020E6100000010000000500000087889B53C9C6424053B29C84D2B34B4087889B53C9C642404548DDCEBEB44B4009DD257156C842404548DDCEBEB44B4009DD257156C8424053B29C84D2B34B4087889B53C9C6424053B29C84D2B34B40
80024	204	37.529097	37.536805000000001	55.416065000000003	55.408675000000002	Победы	0103000020E61000000100000005000000B3B45373B9C34240AED85F764FB44B40B3B45373B9C342405001309E41B54B4026AAB706B6C442405001309E41B54B4026AAB706B6C44240AED85F764FB44B40B3B45373B9C34240AED85F764FB44B40
80369	204	37.567554000000001	37.599587999999997	55.457208999999999	55.450026000000001	Плещеевская	0103000020E61000000100000005000000645B069CA5C84240C32CB4739AB94B40645B069CA5C84240EB3713D385BA4B407A89B14CBFCC4240EB3713D385BA4B407A89B14CBFCC4240C32CB4739AB94B40645B069CA5C84240C32CB4739AB94B40
8134	204	37.498545999999997	37.506791999999997	55.431085000000003	55.430231999999997	Пахринский проезд	0103000020E610000001000000050000009BC6F65AD0BF4240A9D898D711B74B409BC6F65AD0BF4240E96514CB2DB74B40EDEF6C8FDEC04240E96514CB2DB74B40EDEF6C8FDEC04240A9D898D711B74B409BC6F65AD0BF4240A9D898D711B74B40
80406	204	37.517831999999999	37.520994000000002	55.433582999999999	55.422544000000002	Парковая 	0103000020E610000001000000050000004069A85148C242407E8FFAEB15B64B404069A85148C24240008DD2A57FB74B40C4B46FEEAFC24240008DD2A57FB74B40C4B46FEEAFC242407E8FFAEB15B64B404069A85148C242407E8FFAEB15B64B40
79840	204	37.544746000000004	37.556261999999997	55.446283999999999	55.437213999999997	Павлика Морозова	0103000020E610000001000000050000003C50A73CBAC542403AADDBA0F6B74B403C50A73CBAC54240315D88D51FB94B40F700DD9733C74240315D88D51FB94B40F700DD9733C742403AADDBA0F6B74B403C50A73CBAC542403AADDBA0F6B74B40
71843	204	37.505336999999997	37.509981000000003	55.434227	55.420085999999998	Октябрьский проспект	0103000020E61000000100000005000000B83A00E2AEC04240F4C0C760C5B54B40B83A00E2AEC04240250516C094B74B406B4AB20E47C14240250516C094B74B406B4AB20E47C14240F4C0C760C5B54B40B83A00E2AEC04240F4C0C760C5B54B40
80400	204	37.539149000000002	37.539687999999998	55.421328000000003	55.412973000000001	Народная	0103000020E61000000100000005000000E7559DD502C54240C5909C4CDCB44B40E7559DD502C54240CE716E13EEB54B409605137F14C54240CE716E13EEB54B409605137F14C54240C5909C4CDCB44B40E7559DD502C54240C5909C4CDCB44B40
8057	204	37.561832000000003	37.567410000000002	55.443337999999997	55.436805999999997	Мраморная улица	0103000020E6100000010000000500000053EC681CEAC7424029594E42E9B74B4053EC681CEAC742407A89B14CBFB84B4031B610E4A0C842407A89B14CBFB84B4031B610E4A0C8424029594E42E9B74B4053EC681CEAC7424029594E42E9B74B40
79785	204	37.561140000000002	37.572153999999998	55.409508000000002	55.40502	Молодежная	0103000020E610000001000000050000001D3D7E6FD3C74240EB1C03B2D7B34B401D3D7E6FD3C74240A6B915C26AB44B4046239F573CC94240A6B915C26AB44B4046239F573CC94240EB1C03B2D7B34B401D3D7E6FD3C74240EB1C03B2D7B34B40
80425	204	37.570546	37.575369999999999	55.422508000000001	55.419094999999999	Мира	0103000020E610000001000000050000008B6EBDA607C942406475ABE7A4B54B408B6EBDA607C942403126FDBD14B64B40BD8C62B9A5C942403126FDBD14B64B40BD8C62B9A5C942406475ABE7A4B54B408B6EBDA607C942406475ABE7A4B54B40
80374	204	37.520401999999997	37.526564	55.431586000000003	55.42521	Маштакова	0103000020E61000000100000005000000F16261889CC2424051F701486DB64B40F16261889CC24240ABB4C5353EB74B401FA0FB7266C34240ABB4C5353EB74B401FA0FB7266C3424051F701486DB64B40F16261889CC2424051F701486DB64B40
80443	204	37.564490999999997	37.580965999999997	55.414245000000001	55.408026	Машиностроителей	0103000020E6100000010000000500000073F1B73D41C8424077F52A323AB44B4073F1B73D41C8424009C4EBFA05B54B40410B09185DCA424009C4EBFA05B54B40410B09185DCA424077F52A323AB44B4073F1B73D41C8424077F52A323AB44B40
79784	204	37.542554000000003	37.546156000000003	55.424005000000001	55.410846999999997	Литейная	0103000020E610000001000000050000003128D36872C5424071546EA296B44B403128D36872C54240952BBCCB45B64B40D1419770E8C54240952BBCCB45B64B40D1419770E8C5424071546EA296B44B403128D36872C5424071546EA296B44B40
80456	204	37.525244000000001	37.547504000000004	55.412067999999998	55.404702999999998	Лапшенкова	0103000020E61000000100000005000000CA3505323BC34240EACBD24ECDB34B40CA3505323BC3424033DDEBA4BEB44B40F0366F9C14C6424033DDEBA4BEB44B40F0366F9C14C64240EACBD24ECDB34B40CA3505323BC34240EACBD24ECDB34B40
80394	204	37.552283000000003	37.557116000000001	55.434716999999999	55.430779000000001	Красная	0103000020E6100000010000000500000082919735B1C64240DC662AC423B74B4082919735B1C64240F30181CEA4B74B40070ABC934FC74240F30181CEA4B74B40070ABC934FC74240DC662AC423B74B4082919735B1C64240DC662AC423B74B40
6143	204	37.559379	37.561329000000001	55.434838999999997	55.433399000000001	Кооперативный проезд	0103000020E61000000100000005000000DB8827BB99C742403F8F519E79B74B40DB8827BB99C742403E03EACDA8B74B40F0A5F0A0D9C742403E03EACDA8B74B40F0A5F0A0D9C742403F8F519E79B74B40DB8827BB99C742403F8F519E79B74B40
79783	204	37.538449	37.565299000000003	55.434660999999998	55.423765000000003	Комсомольская	0103000020E610000001000000050000002EC896E5EBC44240401878EE3DB64B402EC896E5EBC442405FECBDF8A2B74B4013BBB6B75BC842405FECBDF8A2B74B4013BBB6B75BC84240401878EE3DB64B402EC896E5EBC44240401878EE3DB64B40
79945	204	37.516539000000002	37.523510000000002	55.422074000000002	55.411597999999998	Высотная	0103000020E61000000100000005000000E50D30F31DC24240AC8C463EAFB44B40E50D30F31DC24240F73E558506B64B4082902C6002C34240F73E558506B64B4082902C6002C34240AC8C463EAFB44B40E50D30F31DC24240AC8C463EAFB44B40
80412	204	37.540056999999997	37.548653999999999	55.414510999999997	55.412835000000001	Володи Дубинина	0103000020E61000000100000005000000E97C789620C5424074D2FBC6D7B44B40E97C789620C54240876A4AB20EB54B40E868554B3AC64240876A4AB20EB54B40E868554B3AC6424074D2FBC6D7B44B40E97C789620C5424074D2FBC6D7B44B40
80409	204	37.528503999999998	37.550288999999999	55.414751000000003	55.407668000000001	Ватутина	0103000020E6100000010000000500000010E7E104A6C3424018D00B772EB44B4010E7E104A6C34240DD7D8E8F16B54B409D2CB5DE6FC64240DD7D8E8F16B54B409D2CB5DE6FC6424018D00B772EB44B4010E7E104A6C3424018D00B772EB44B40
80363	204	37.563161000000001	37.584955000000001	55.473652999999999	55.472714000000003	Быковская	0103000020E61000000100000005000000FBB0DEA815C84240412E71E481BC4B40FBB0DEA815C842407E5358A9A0BC4B40DB5031CEDFCA42407E5358A9A0BC4B40DB5031CEDFCA4240412E71E481BC4B40FBB0DEA815C84240412E71E481BC4B40
80455	204	37.553693000000003	37.563907	55.400148999999999	55.399892999999999	Бородинская	0103000020E6100000010000000500000017838769DFC642401D739EB12FB34B4017838769DFC6424078431A1538B34B40247EC51A2EC8424078431A1538B34B40247EC51A2EC842401D739EB12FB34B4017838769DFC642401D739EB12FB34B40
52	204	37.54383	37.551428999999999	55.431356000000001	55.391779	Большая Серпуховская улица	0103000020E61000000100000005000000B64AB0389CC542403A2174D025B24B40B64AB0389CC54240797764AC36B74B407288B83995C64240797764AC36B74B407288B83995C642403A2174D025B24B40B64AB0389CC542403A2174D025B24B40
80414	204	37.54383	37.551428999999999	55.431356000000001	55.391779	Большая Серпуховская 	0103000020E61000000100000005000000B64AB0389CC542403A2174D025B24B40B64AB0389CC54240797764AC36B74B407288B83995C64240797764AC36B74B407288B83995C642403A2174D025B24B40B64AB0389CC542403A2174D025B24B40
79948	204	37.538566000000003	37.54824	55.437122000000002	55.429808000000001	Большая Зеленовская 	0103000020E61000000100000005000000685E0EBBEFC4424093C7D3F203B74B40685E0EBBEFC442405A2E1B9DF3B74B40F52D73BA2CC642405A2E1B9DF3B74B40F52D73BA2CC6424093C7D3F203B74B40685E0EBBEFC4424093C7D3F203B74B40
79839	204	37.538566000000003	37.54824	55.437122000000002	55.429808000000001	Большая Зеленовская	0103000020E61000000100000005000000685E0EBBEFC4424093C7D3F203B74B40685E0EBBEFC442405A2E1B9DF3B74B40F52D73BA2CC642405A2E1B9DF3B74B40F52D73BA2CC6424093C7D3F203B74B40685E0EBBEFC4424093C7D3F203B74B40
80065	204	37.580508000000002	37.585754000000001	55.420357000000003	55.418726999999997	Батырева	0103000020E610000001000000050000007F880D164ECA4240E179A9D898B54B407F880D164ECA424085D21742CEB54B4027C0B0FCF9CA424085D21742CEB54B4027C0B0FCF9CA4240E179A9D898B54B407F880D164ECA4240E179A9D898B54B40
80017	61915	38.150669000000001	38.197695000000003	56.423720000000003	56.406480999999999	Пионерская	0103000020E61000000100000005000000B1C22D1F4913434002B9C49107344C40B1C22D1F49134340A054FB743C364C4097CADB114E194340A054FB743C364C4097CADB114E19434002B9C49107344C40B1C22D1F4913434002B9C49107344C40
80196	61915	38.166811000000003	38.174222	56.416589999999999	56.413881000000003	Мира	0103000020E6100000010000000500000079CE16105A154340C8B7770DFA344C4079CE16105A1543409AEB34D252354C40321F10E84C1643409AEB34D252354C40321F10E84C164340C8B7770DFA344C4079CE16105A154340C8B7770DFA344C40
80356	61875	38.685237999999998	38.704929	55.790928999999998	55.789881000000001	Школьная	0103000020E61000000100000005000000FCFCF7E0B5574340AB5D13D21AE54B40FCFCF7E0B55743409F3A56293DE54B4041800C1D3B5A43409F3A56293DE54B4041800C1D3B5A4340AB5D13D21AE54B40FCFCF7E0B5574340AB5D13D21AE54B40
79841	61875	38.665798000000002	38.667658000000003	55.773307000000003	55.771250999999999	Тимирязева	0103000020E6100000010000000500000001DF6DDE38554340EF004F5AB8E24B4001DF6DDE385543404A6249B9FBE24B40D6743DD1755543404A6249B9FBE24B40D6743DD175554340EF004F5AB8E24B4001DF6DDE38554340EF004F5AB8E24B40
80357	61875	38.647948999999997	38.675446000000001	55.781691000000002	55.778927000000003	Кирова	0103000020E61000000100000005000000EA3C2AFEEF524340577C43E1B3E34B40EA3C2AFEEF524340ED4960730EE44B40651BB80375564340ED4960730EE44B40651BB80375564340577C43E1B3E34B40EA3C2AFEEF524340577C43E1B3E34B40
80509	61875	38.597355999999998	38.614441999999997	55.792679999999997	55.786535999999998	Дружбы	0103000020E61000000100000005000000E1085229764C434036902E36ADE44B40E1085229764C4340BD18CA8976E54B40F8A41309A64E4340BD18CA8976E54B40F8A41309A64E434036902E36ADE44B40E1085229764C434036902E36ADE44B40
79847	61875	38.663291999999998	38.664836999999999	55.782339	55.776764999999997	Выставкина	0103000020E6100000010000000500000066D993C0E6544340B6D617096DE34B4066D993C0E654434053B131AF23E44B40DB15FA601955434053B131AF23E44B40DB15FA6019554340B6D617096DE34B4066D993C0E6544340B6D617096DE34B40
80355	61875	38.651183000000003	38.656492	55.779221	55.765416999999999	Большая Покровская	0103000020E61000000100000005000000085BECF659534340B6662B2FF9E14B40085BECF6595343409FAD8383BDE34B40F60A0BEE075443409FAD8383BDE34B40F60A0BEE07544340B6662B2FF9E14B40085BECF659534340B6662B2FF9E14B40
80913	62020	38.170692000000003	38.191578	55.885893000000003	55.880788000000003	Центральная	0103000020E610000001000000050000002CD8463CD9154340C95A43A9BDF04B402CD8463CD9154340AF601BF164F14B400951BEA085184340AF601BF164F14B400951BEA085184340C95A43A9BDF04B402CD8463CD9154340C95A43A9BDF04B40
70966	18912	38.957310999999997	38.977755999999999	55.808655000000002	55.808011999999998	улица Володарского	0103000020E61000000100000005000000EF8CB62A897A43404563EDEF6CE74B40EF8CB62A897A43409A5FCD0182E74B40E0BBCD1B277D43409A5FCD0182E74B40E0BBCD1B277D43404563EDEF6CE74B40EF8CB62A897A43404563EDEF6CE74B40
6764	18912	38.991815000000003	39.009422000000001	55.804122	55.790691000000002	улица Бугрова	0103000020E6100000010000000500000054573ECBF37E4340EB1ED95C35E54B4054573ECBF37E43403FFF3D78EDE64B4074EE76BD348143403FFF3D78EDE64B4074EE76BD34814340EB1ED95C35E54B4054573ECBF37E4340EB1ED95C35E54B40
6516	18912	38.943001000000002	38.974207999999997	55.813794000000001	55.811756000000003	улица Бирюкова	0103000020E61000000100000005000000338CBB41B4784340782AE09EE7E74B40338CBB41B47843402CD7DB662AE84B4033C005D9B27C43402CD7DB662AE84B4033C005D9B27C4340782AE09EE7E74B40338CBB41B4784340782AE09EE7E74B40
6634	18912	38.987943000000001	38.998094000000002	55.821066999999999	55.819468999999998	проезд Беляцкого	0103000020E61000000100000005000000F4A78DEA747E4340FC8A355CE4E84B40F4A78DEA747E4340946934B918E94B40BB2A508BC17F4340946934B918E94B40BB2A508BC17F4340FC8A355CE4E84B40F4A78DEA747E4340FC8A355CE4E84B40
79826	18912	38.971207999999997	38.973840000000003	55.817101999999998	55.816020000000002	площадь Пушкина	0103000020E6100000010000000500000089CE328B507C4340E370E65773E84B4089CE328B507C434083BF5FCC96E84B40B1C403CAA67C434083BF5FCC96E84B40B1C403CAA67C4340E370E65773E84B4089CE328B507C4340E370E65773E84B40
80869	18912	38.998651000000002	39.046325000000003	55.822878000000003	55.807456000000002	Торфобрикетная	0103000020E61000000100000005000000118FC4CBD37F4340C07ADCB75AE74B40118FC4CBD37F4340884CF91054E94B405DFE43FAED854340884CF91054E94B405DFE43FAED854340C07ADCB75AE74B40118FC4CBD37F4340C07ADCB75AE74B40
79823	18912	38.970632999999999	38.971243999999999	55.816727999999998	55.808022000000001	Пушкина	0103000020E610000001000000050000008DB5BFB33D7C43406939D0436DE74B408DB5BFB33D7C43401EDD088B8AE84B40D63730B9517C43401EDD088B8AE84B40D63730B9517C43406939D0436DE74B408DB5BFB33D7C43406939D0436DE74B40
80125	18912	38.947671999999997	38.964236999999997	55.801546000000002	55.791618	Правды	0103000020E61000000100000005000000DEAAEB504D794340647616BD53E54B40DEAAEB504D794340AC1E300F99E64B40EC4B361E6C7B4340AC1E300F99E64B40EC4B361E6C7B4340647616BD53E54B40DEAAEB504D794340647616BD53E54B40
80184	18912	38.989803000000002	39.008164000000001	55.825051999999999	55.817314000000003	Парковская	0103000020E61000000100000005000000C93D5DDDB17E43400F48C2BE9DE84B40C93D5DDDB17E4340ECBFCE4D9BE94B40958098840B814340ECBFCE4D9BE94B40958098840B8143400F48C2BE9DE84B40C93D5DDDB17E43400F48C2BE9DE84B40
80205	18912	38.989874999999998	39.009898	55.825051999999999	55.814436000000001	Набережная 	0103000020E6100000010000000500000062105839B47E4340B05758703FE84B4062105839B47E4340ECBFCE4D9BE94B40DD25715644814340ECBFCE4D9BE94B40DD25715644814340B05758703FE84B4062105839B47E4340B05758703FE84B40
71880	18912	39.000276999999997	39.006951999999998	55.815109	55.814076999999997	Мира	0103000020E6100000010000000500000072F8A4130980434080B6D5AC33E84B4072F8A413098043406FD6E07D55E84B4026529ACDE38043406FD6E07D55E84B4026529ACDE380434080B6D5AC33E84B4072F8A4130980434080B6D5AC33E84B40
80206	18912	38.968108999999998	38.972977	55.803230999999997	55.793111000000003	Мадонская	0103000020E610000001000000050000004CFBE6FEEA7B4340878C47A984E54B404CFBE6FEEA7B43401211FE45D0E64B404E61A5828A7C43401211FE45D0E64B404E61A5828A7C4340878C47A984E54B404CFBE6FEEA7B4340878C47A984E54B40
80188	18912	38.975475000000003	38.985365000000002	55.815342000000001	55.811866999999999	Лопатина	0103000020E610000001000000050000006688635DDC7C4340CFD90242EBE74B406688635DDC7C434012876C205DE84B40C0CFB870207E434012876C205DE84B40C0CFB870207E4340CFD90242EBE74B406688635DDC7C4340CFD90242EBE74B40
71807	18912	38.972437999999997	39.002747999999997	55.813130999999998	55.795574999999999	Ленина	0103000020E610000001000000050000009EB12FD9787C4340F241CF66D5E54B409EB12FD9787C4340902E36AD14E84B409010E50B5A804340902E36AD14E84B409010E50B5A804340F241CF66D5E54B409EB12FD9787C4340F241CF66D5E54B40
80203	18912	38.999378999999998	39.015045999999998	55.806919000000001	55.799467	Красина	0103000020E6100000010000000500000093A7ACA6EB7F4340999D45EF54E64B4093A7ACA6EB7F4340B1C22D1F49E74B40C2F7FE06ED814340B1C22D1F49E74B40C2F7FE06ED814340999D45EF54E64B4093A7ACA6EB7F4340999D45EF54E64B40
80170	18912	38.951804000000003	38.972977	55.817101999999998	55.814219000000001	Козлова	0103000020E61000000100000005000000DB19A6B6D47943401364045438E84B40DB19A6B6D479434083BF5FCC96E84B404E61A5828A7C434083BF5FCC96E84B404E61A5828A7C43401364045438E84B40DB19A6B6D47943401364045438E84B40
74074	18912	38.951804000000003	38.972977	55.817101999999998	55.814219000000001	Козлова	0103000020E61000000100000005000000DB19A6B6D47943401364045438E84B40DB19A6B6D479434083BF5FCC96E84B404E61A5828A7C434083BF5FCC96E84B404E61A5828A7C43401364045438E84B40DB19A6B6D47943401364045438E84B40
72048	18912	38.996854999999996	39.001131000000001	55.819282000000001	55.812781999999999	Клязьменский проезд	0103000020E6100000010000000500000052EDD3F1987F43408463963D09E84B4052EDD3F1987F4340CA198A3BDEE84B408201840F25804340CA198A3BDEE84B408201840F258043408463963D09E84B4052EDD3F1987F43408463963D09E84B40
80147	18912	38.957301999999999	38.957687999999997	55.814467	55.808112999999999	Иванова	0103000020E610000001000000050000009C3237DF887A4340793C2D3F70E74B409C3237DF887A4340EB55647440E84B40C5E23785957A4340EB55647440E84B40C5E23785957A4340793C2D3F70E74B409C3237DF887A4340793C2D3F70E74B40
71791	18912	39.011111	39.014704000000002	55.799871000000003	55.795737000000003	Зеленая	0103000020E610000001000000050000001CD0D2156C814340CC9BC3B5DAE54B401CD0D2156C8143406902452C62E64B40698F17D2E18143406902452C62E64B40698F17D2E1814340CC9BC3B5DAE54B401CD0D2156C814340CC9BC3B5DAE54B40
79910	18912	38.966464999999999	38.972546000000001	55.795620999999997	55.785983999999999	Егорьевская	0103000020E6100000010000000500000044DD0720B57B4340F296AB1F9BE44B4044DD0720B57B43406281AFE8D6E54B4085ED27637C7C43406281AFE8D6E54B4085ED27637C7C4340F296AB1F9BE44B4044DD0720B57B4340F296AB1F9BE44B40
71905	18912	38.975115000000002	38.985230000000001	55.798803999999997	55.791035000000001	Горького	0103000020E61000000100000005000000666B7D91D07C4340E57E87A240E54B40666B7D91D07C4340FDF49F353FE64B40E08442041C7E4340FDF49F353FE64B40E08442041C7E4340E57E87A240E54B40666B7D91D07C4340E57E87A240E54B40
80182	18912	38.974207999999997	38.988059999999997	55.819311999999996	55.813794000000001	Галочкина	0103000020E6100000010000000500000033C005D9B27C43402CD7DB662AE84B4033C005D9B27C4340349C3237DFE84B402D3E05C0787E4340349C3237DFE84B402D3E05C0787E43402CD7DB662AE84B4033C005D9B27C43402CD7DB662AE84B40
80136	18912	38.943207000000001	38.969994999999997	55.808134000000003	55.792386999999998	Гагарина	0103000020E61000000100000005000000DC2DC901BB7843404563EDEF6CE54B40DC2DC901BB784340916456EF70E74B404A24D1CB287C4340916456EF70E74B404A24D1CB287C43404563EDEF6CE54B40DC2DC901BB7843404563EDEF6CE54B40
79905	18912	38.986497	39.004238999999998	55.811447000000001	55.802568000000001	Волкова	0103000020E61000000100000005000000124DA088457E43407768588CBAE64B40124DA088457E4340FAB7CB7EDDE74B40122F4FE78A804340FAB7CB7EDDE74B40122F4FE78A8043407768588CBAE64B40124DA088457E43407768588CBAE64B40
80189	18912	38.991815000000003	39.009422000000001	55.804122	55.790691000000002	Бугрова	0103000020E6100000010000000500000054573ECBF37E4340EB1ED95C35E54B4054573ECBF37E43403FFF3D78EDE64B4074EE76BD348143403FFF3D78EDE64B4074EE76BD34814340EB1ED95C35E54B4054573ECBF37E4340EB1ED95C35E54B40
80679	18912	38.919590999999997	38.929130999999998	55.793717999999998	55.781174999999998	Бондаренко	0103000020E6100000010000000500000014596B28B5754340F5B9DA8AFDE34B4014596B28B57543408E1F2A8D98E54B409259BDC3ED7643408E1F2A8D98E54B409259BDC3ED764340F5B9DA8AFDE34B4014596B28B5754340F5B9DA8AFDE34B40
6533	18912	38.958343999999997	38.960265999999997	55.817121999999998	55.815691000000001	4-й проезд Козлова	0103000020E61000000100000005000000AE282504AB7A43401E520C9068E84B40AE282504AB7A4340CA6B257497E84B40F9BA0CFFE97A4340CA6B257497E84B40F9BA0CFFE97A43401E520C9068E84B40AE282504AB7A43401E520C9068E84B40
80839	60229	38.472588999999999	38.610982999999997	54.874392999999998	54.844051	площадь Советская	0103000020E6100000010000000500000084B9DDCB7D3C4340FB93F8DC096C4B4084B9DDCB7D3C4340F86C1D1CEC6F4B40BBB4E1B0344E4340F86C1D1CEC6F4B40BBB4E1B0344E4340FB93F8DC096C4B4084B9DDCB7D3C4340FB93F8DC096C4B40
81047	60229	38.472588999999999	38.610982999999997	54.874392999999998	54.844051	микрорайон им. Маршала Катукова	0103000020E6100000010000000500000084B9DDCB7D3C4340FB93F8DC096C4B4084B9DDCB7D3C4340F86C1D1CEC6F4B40BBB4E1B0344E4340F86C1D1CEC6F4B40BBB4E1B0344E4340FB93F8DC096C4B4084B9DDCB7D3C4340FB93F8DC096C4B40
81055	62063	38.266246000000002	38.267862999999998	54.796090999999997	54.790427999999999	Советская	0103000020E610000001000000050000006D58535914224340DDEBA4BE2C654B406D58535914224340E9D1544FE6654B407B67B45549224340E9D1544FE6654B407B67B45549224340DDEBA4BE2C654B406D58535914224340DDEBA4BE2C654B40
80370	61912	37.322978999999997	37.334792	55.697355999999999	55.693382999999997	Чистяковой	0103000020E61000000100000005000000BB25396057A942401A4D2EC6C0D84B40BB25396057A94240AED51EF642D94B40317BD976DAAA4240AED51EF642D94B40317BD976DAAA42401A4D2EC6C0D84B40BB25396057A942401A4D2EC6C0D84B40
80667	61912	37.289614999999998	37.295409999999997	55.687202999999997	55.683508000000003	Чикина	0103000020E610000001000000050000002CB7B41A12A54240F646AD307DD74B402CB7B41A12A54240465B9544F6D74B40A774B0FECFA54240465B9544F6D74B40A774B0FECFA54240F646AD307DD74B402CB7B41A12A54240F646AD307DD74B40
81020	61912	37.316439000000003	37.316986999999997	55.682585000000003	55.680467999999998	Трудовая	0103000020E61000000100000005000000E816BA1281A84240BDFC4E9319D74B40E816BA1281A84240BEDEFDF15ED74B40EA20AF0793A84240BEDEFDF15ED74B40EA20AF0793A84240BDFC4E9319D74B40E816BA1281A84240BDFC4E9319D74B40
79988	61912	37.281332999999997	37.298814	55.673006000000001	55.670015999999997	Союзная	0103000020E610000001000000050000008D2441B802A44240FBE59315C3D54B408D2441B802A442408201840F25D64B4021CB82893FA642408201840F25D64B4021CB82893FA64240FBE59315C3D54B408D2441B802A44240FBE59315C3D54B40
80658	61912	37.245086000000001	37.258983000000001	55.686897999999999	55.677174000000001	Северная	0103000020E610000001000000050000008E5A61FA5E9F4240CBD93BA3ADD64B408E5A61FA5E9F42400AD80E46ECD74B40289CDD5A26A142400AD80E46ECD74B40289CDD5A26A14240CBD93BA3ADD64B408E5A61FA5E9F4240CBD93BA3ADD64B40
80665	61912	37.274217999999998	37.281754999999997	55.685543000000003	55.678915000000003	Ново-Спортивная	0103000020E61000000100000005000000BDFC4E9319A34240C6E1CCAFE6D64B40BDFC4E9319A3424039807EDFBFD74B40033E3F8C10A4424039807EDFBFD74B40033E3F8C10A44240C6E1CCAFE6D64B40BDFC4E9319A34240C6E1CCAFE6D64B40
80083	61912	37.253126000000002	37.274262999999998	55.678975999999999	55.673214000000002	Молодежная	0103000020E6100000010000000500000037E2C96E66A04240CC9A58E02BD64B4037E2C96E66A042406B6281AFE8D64B405DC0CB0C1BA342406B6281AFE8D64B405DC0CB0C1BA34240CC9A58E02BD64B4037E2C96E66A04240CC9A58E02BD64B40
80692	61912	37.250807999999999	37.310636000000002	55.687071000000003	55.666086	Можайское шоссе	0103000020E610000001000000050000009FC9FE791AA042406729594E42D54B409FC9FE791AA04240D88349F1F1D74B40EA7AA2EBC2A74240D88349F1F1D74B40EA7AA2EBC2A742406729594E42D54B409FC9FE791AA042406729594E42D54B40
80681	61912	37.281126	37.295904	55.667375999999997	55.666482000000002	Комсомольская	0103000020E610000001000000050000001407D0EFFBA34240B4AF3C484FD54B401407D0EFFBA342405111A7936CD54B40B760A92EE0A542405111A7936CD54B40B760A92EE0A54240B4AF3C484FD54B401407D0EFFBA34240B4AF3C484FD54B40
80672	61912	37.281019000000001	37.298732999999999	55.679524000000001	55.672640999999999	Вокзальная	0103000020E61000000100000005000000FE463B6EF8A342407079AC1919D64B40FE463B6EF8A342406E6C76A4FAD64B40349E08E23CA642406E6C76A4FAD64B40349E08E23CA642407079AC1919D64B40FE463B6EF8A342407079AC1919D64B40
80318	61912	37.281332999999997	37.289966	55.670381999999996	55.655498000000001	Верхнепролетарская	0103000020E610000001000000050000008D2441B802A44240F54BC45BE7D34B408D2441B802A44240DDE9CE13CFD54B40D9791B9B1DA54240DDE9CE13CFD54B40D9791B9B1DA54240F54BC45BE7D34B408D2441B802A44240F54BC45BE7D34B40
80615	60231	38.395702	38.408915999999998	55.839329999999997	55.834986999999998	Юбилейная	0103000020E610000001000000050000001C7BF65CA6324340E6CAA0DAE0EA4B401C7BF65CA63243409D465A2A6FEB4B40D367075C573443409D465A2A6FEB4B40D367075C57344340E6CAA0DAE0EA4B401C7BF65CA6324340E6CAA0DAE0EA4B40
80630	60231	38.396681000000001	38.452565	55.857557999999997	55.839652999999998	Третьего Интернационала	0103000020E61000000100000005000000E8F86871C6324340807EDFBF79EB4B40E8F86871C63243402A36E675C4ED4B40392861A6ED3943402A36E675C4ED4B40392861A6ED394340807EDFBF79EB4B40E8F86871C6324340807EDFBF79EB4B40
79992	60231	38.447535000000002	38.466695999999999	55.898099000000002	55.876055999999998	Советской Конституции	0103000020E610000001000000050000005E68AED34839434077BB5E9A22F04B405E68AED34839434000C974E8F4F24B404696CCB1BC3B434000C974E8F4F24B404696CCB1BC3B434077BB5E9A22F04B405E68AED34839434077BB5E9A22F04B40
74114	60231	38.431221000000001	38.45252	55.857387000000003	55.851050000000001	Советская	0103000020E61000000100000005000000992CEE3F3237434062A1D634EFEC4B40992CEE3F32374340FE8172DBBEED4B409964E42CEC394340FE8172DBBEED4B409964E42CEC39434062A1D634EFEC4B40992CEE3F3237434062A1D634EFEC4B40
80642	60231	38.494273999999997	38.498334999999997	55.861378000000002	55.850414000000001	Октябрьская	0103000020E61000000100000005000000ADA1D45E443F4340C007AF5DDAEC4B40ADA1D45E443F434038BF61A241EE4B40E0B9F770C93F434038BF61A241EE4B40E0B9F770C93F4340C007AF5DDAEC4B40ADA1D45E443F4340C007AF5DDAEC4B40
74078	60231	38.365141000000001	38.514989	55.900011999999997	55.823656	Набережная 60-летия октября	0103000020E61000000100000005000000E1B6B6F0BC2E4340BC934F8F6DE94B40E1B6B6F0BC2E4340F700DD9733F34B405E66D828EB414340F700DD9733F34B405E66D828EB414340BC934F8F6DE94B40E1B6B6F0BC2E4340BC934F8F6DE94B40
80069	60231	38.464243000000003	38.474817000000002	55.880329000000003	55.876798999999998	Краснослободская	0103000020E61000000100000005000000CF328B506C3B43402F151BF33AF04B40CF328B506C3B4340365CE49EAEF04B40DC4AAFCDC63C4340365CE49EAEF04B40DC4AAFCDC63C43402F151BF33AF04B40CF328B506C3B43402F151BF33AF04B40
79943	60231	38.430889000000001	38.453705999999997	55.857371999999998	55.847684999999998	Комсомольская	0103000020E61000000100000005000000639AE95E27374340A6272CF180EC4B40639AE95E27374340C8409E5DBEED4B40DEFFC709133A4340C8409E5DBEED4B40DEFFC709133A4340A6272CF180EC4B40639AE95E27374340A6272CF180EC4B40
80643	60231	38.474798999999997	38.484805999999999	55.888710000000003	55.880329000000003	Кирова	0103000020E610000001000000050000003596B036C63C4340365CE49EAEF04B403596B036C63C434068D0D03FC1F14B40C9737D1F0E3E434068D0D03FC1F14B40C9737D1F0E3E4340365CE49EAEF04B403596B036C63C4340365CE49EAEF04B40
80651	60231	38.434249000000001	38.447158000000002	55.877899999999997	55.870395000000002	Зенитчиков	0103000020E610000001000000050000000DA9A278953743400CCD751A69EF4B400DA9A278953743404694F6065FF04B4088122D793C3943404694F6065FF04B4088122D793C3943400CCD751A69EF4B400DA9A278953743400CCD751A69EF4B40
80648	60231	38.424402999999998	38.441363000000003	55.890214	55.857765999999998	Декабристов	0103000020E6100000010000000500000082A966D65236434074CFBA46CBED4B4082A966D6523643407E384888F2F14B400D5531957E3843407E384888F2F14B400D5531957E38434074CFBA46CBED4B4082A966D65236434074CFBA46CBED4B40
80652	60231	38.406958000000003	38.408943000000001	55.843459000000003	55.839329999999997	Бабушкина	0103000020E610000001000000050000003C6C2233173443409D465A2A6FEB4B403C6C2233173443402942EA76F6EB4B40CD76853E583443402942EA76F6EB4B40CD76853E583443409D465A2A6FEB4B403C6C2233173443409D465A2A6FEB4B40
80311	61934	37.166178000000002	37.186570000000003	55.840947	55.838824000000002	Институтская	0103000020E6100000010000000500000048A8195245954240CA8CB7955EEB4B4048A8195245954240AC55BB26A4EB4B4016359886E1974240AC55BB26A4EB4B4016359886E1974240CA8CB7955EEB4B4048A8195245954240CA8CB7955EEB4B40
80313	59557	37.129975999999999	37.214229000000003	55.865004999999996	55.827641	11 Саперов	0103000020E61000000100000005000000E8A1B60DA390424014EAE923F0E94B40E8A1B60DA390424030F0DC7BB8EE4B406A6D1ADB6B9B424030F0DC7BB8EE4B406A6D1ADB6B9B424014EAE923F0E94B40E8A1B60DA390424014EAE923F0E94B40
80627	59539	36.71649	36.723066000000003	55.388731999999997	55.386752999999999	Школьная	0103000020E610000001000000050000009DF4BEF1B55B4240A0504F1F81B14B409DF4BEF1B55B42404F745DF8C1B14B40BE6C3B6D8D5C42404F745DF8C1B14B40BE6C3B6D8D5C4240A0504F1F81B14B409DF4BEF1B55B4240A0504F1F81B14B40
80694	59539	36.717334999999999	36.729058000000002	55.416105000000002	55.408071999999997	Шибанкова	0103000020E6100000010000000500000059A31EA2D15B4240E7340BB43BB44B4059A31EA2D15B4240DE59BBED42B54B408F71C5C5515D4240DE59BBED42B54B408F71C5C5515D4240E7340BB43BB44B4059A31EA2D15B4240E7340BB43BB44B40
80105	59539	36.738185000000001	36.755952999999998	55.382503	55.363872000000001	Погодина	0103000020E61000000100000005000000EAB298D87C5E42400EF7915B93AE4B40EAB298D87C5E42409ACFB9DBF5B04B4013286211C36042409ACFB9DBF5B04B4013286211C36042400EF7915B93AE4B40EAB298D87C5E42400EF7915B93AE4B40
71871	59539	36.734617999999998	36.745362	55.393932	55.388742000000001	Парк Воровского	0103000020E61000000100000005000000C6866EF6075E4240734A404CC2B14B40C6866EF6075E4240876C205D6CB24B4030D7A205685F4240876C205D6CB24B4030D7A205685F4240734A404CC2B14B40C6866EF6075E4240734A404CC2B14B40
80899	59539	36.737977999999998	36.770882999999998	55.384441000000002	55.375076	Московская	0103000020E6100000010000000500000070952710765E4240DBC1887D02B04B4070952710765E4240EB1ED95C35B14B406C054D4BAC624240EB1ED95C35B14B406C054D4BAC624240DBC1887D02B04B4070952710765E4240DBC1887D02B04B40
80335	59539	36.725949999999997	36.732058000000002	55.386211000000003	55.373612999999999	Ленина	0103000020E61000000100000005000000FE43FAEDEB5C4240232E008DD2AF4B40FE43FAEDEB5C4240802DAF5C6FB14B4039639813B45D4240802DAF5C6FB14B4039639813B45D4240232E008DD2AF4B40FE43FAEDEB5C4240232E008DD2AF4B40
80616	60249	37.727058999999997	37.739842000000003	55.912410000000001	55.904882000000001	Щербакова	0103000020E6100000010000000500000098A1F14410DD42409A5E622CD3F34B4098A1F14410DD42408D45D3D9C9F44B40871A8524B3DE42408D45D3D9C9F44B40871A8524B3DE42409A5E622CD3F34B4098A1F14410DD42409A5E622CD3F34B40
80055	60249	37.749749999999999	37.755015	55.902822999999998	55.899749	Фрунзе	0103000020E610000001000000050000008716D9CEF7DF4240EACDA8F92AF34B408716D9CEF7DF4240CE893DB48FF34B40A67EDE54A4E04240CE893DB48FF34B40A67EDE54A4E04240EACDA8F92AF34B408716D9CEF7DF4240EACDA8F92AF34B40
80378	60249	37.765866000000003	37.782592999999999	55.949617000000003	55.919559	Силикатная	0103000020E61000000100000005000000268FA7E507E2424009DFFB1BB4F54B40268FA7E507E24240E25CC30C8DF94B400D8AE6012CE44240E25CC30C8DF94B400D8AE6012CE4424009DFFB1BB4F54B40268FA7E507E2424009DFFB1BB4F54B40
80612	60249	37.718705	37.739043000000002	55.900571999999997	55.886901999999999	Семашко	0103000020E61000000100000005000000603C8386FEDB4240E560360186F14B40603C8386FEDB4240BED87BF145F34B403BAB05F698DE4240BED87BF145F34B403BAB05F698DE4240E560360186F14B40603C8386FEDB4240E560360186F14B40
80080	60249	37.740946999999998	37.75506	55.885655	55.885069999999999	Октябрьская	0103000020E61000000100000005000000DF88EE59D7DE4240DA5548F949F14B40DF88EE59D7DE4240FA449E245DF14B4046425BCEA5E04240FA449E245DF14B4046425BCEA5E04240DA5548F949F14B40DF88EE59D7DE4240DA5548F949F14B40
79927	60249	37.719386999999998	37.759030000000003	55.916455999999997	55.898249999999997	Новомытищинский проспект	0103000020E6100000010000000500000072158BDF14DC4240E5D022DBF9F24B4072158BDF14DC42408A1C226E4EF54B40695721E527E142408A1C226E4EF54B40695721E527E14240E5D022DBF9F24B4072158BDF14DC4240E5D022DBF9F24B40
80599	60249	37.711689	37.748367000000002	55.924472000000002	55.911532000000001	Колпакова	0103000020E6100000010000000500000023F609A018DB4240F5A0A014ADF44B4023F609A018DB4240AB08371955F64B40EC33677DCADF4240AB08371955F64B40EC33677DCADF4240F5A0A014ADF44B4023F609A018DB4240F5A0A014ADF44B40
80606	60249	37.758499999999998	37.770870000000002	55.923831	55.923175000000001	Индустриальная	0103000020E610000001000000050000000C022B8716E142400EBE30992AF64B400C022B8716E14240F7031E1840F64B40D8BB3FDEABE24240F7031E1840F64B40D8BB3FDEABE242400EBE30992AF64B400C022B8716E142400EBE30992AF64B40
80076	60249	37.698151000000003	37.726556000000002	55.896518999999998	55.892249	Веры Волошиной	0103000020E61000000100000005000000B95510035DD94240C171193735F24B40B95510035DD942400E9F7422C1F24B40365B79C9FFDC42400E9F7422C1F24B40365B79C9FFDC4240C171193735F24B40B95510035DD94240C171193735F24B40
80618	60249	37.701655000000002	37.706370999999997	55.912596999999998	55.908152000000001	Борисовка	0103000020E610000001000000050000009609BFD4CFD9424004E621533EF44B409609BFD4CFD94240BFB67EFACFF44B40E1EB6B5D6ADA4240BFB67EFACFF44B40E1EB6B5D6ADA424004E621533EF44B409609BFD4CFD9424004E621533EF44B40
80610	60249	37.743166000000002	37.755769000000001	55.924824999999998	55.919134999999997	Белобородова	0103000020E61000000100000005000000E4BF401020DF4240F2CD3637A6F54B40E4BF401020DF4240F8C264AA60F64B40522AE109BDE04240F8C264AA60F64B40522AE109BDE04240F2CD3637A6F54B40E4BF401020DF4240F2CD3637A6F54B40
80525	60249	37.771903000000002	37.783329000000002	55.919795999999998	55.915376999999999	Академика Каргина	0103000020E610000001000000050000009757AEB7CDE242405B41D3122BF54B409757AEB7CDE24240ED7E15E0BBF54B401381EA1F44E44240ED7E15E0BBF54B401381EA1F44E442405B41D3122BF54B409757AEB7CDE242405B41D3122BF54B40
80081	60249	37.754961000000002	37.756802	55.888764999999999	55.881363999999998	4-я Парковая	0103000020E61000000100000005000000B360E28FA2E0424095EF1989D0F04B40B360E28FA2E042402B6A300DC3F14B4011C64FE3DEE042402B6A300DC3F14B4011C64FE3DEE0424095EF1989D0F04B40B360E28FA2E0424095EF1989D0F04B40
80641	60249	37.713126000000003	37.719962000000002	55.897145000000002	55.891486	3-я Крестьянская	0103000020E61000000100000005000000B2F677B647DB4240C26B97361CF24B40B2F677B647DB42408D62B9A5D5F24B406F2EFEB627DC42408D62B9A5D5F24B406F2EFEB627DC4240C26B97361CF24B40B2F677B647DB4240C26B97361CF24B40
80571	61942	38.152895999999998	38.221590999999997	55.854987000000001	55.824860000000001	Авиационная	0103000020E6100000010000000500000038D89B1892134340A8E3310395E94B4038D89B1892134340A9C0C93670ED4B40410B09185D1C4340A9C0C93670ED4B40410B09185D1C4340A8E3310395E94B4038D89B1892134340A8E3310395E94B40
80535	61930	36.028165000000001	36.029432	55.515068999999997	55.504981000000001	Полосухина	0103000020E6100000010000000500000028F224E99A034240FA0CA837A3C04B4028F224E99A0342407A17EFC7EDC14B405ABA826DC40342407A17EFC7EDC14B405ABA826DC4034240FA0CA837A3C04B4028F224E99A034240FA0CA837A3C04B40
80489	61930	36.001871000000001	36.025891999999999	55.508977999999999	55.505485	Московская	0103000020E61000000100000005000000C9E7154F3D0042402DCF83BBB3C04B40C9E7154F3D0042401631EC3026C14B40309DD66D500342401631EC3026C14B40309DD66D500342402DCF83BBB3C04B40C9E7154F3D0042402DCF83BBB3C04B40
80527	61930	36.025891999999999	36.042475000000003	55.505485	55.503711000000003	Мира	0103000020E61000000100000005000000309DD66D5003424057D11F9A79C04B40309DD66D500342402DCF83BBB3C04B40E5F21FD26F0542402DCF83BBB3C04B40E5F21FD26F05424057D11F9A79C04B40309DD66D5003424057D11F9A79C04B40
80179	61930	36.02026	36.023997000000001	55.508344999999998	55.496934000000003	Красноармейская	0103000020E610000001000000050000005FB532E1970242409F2287889BBF4B405FB532E197024240E50AEF7211C14B40DF196D5512034240E50AEF7211C14B40DF196D55120342409F2287889BBF4B405FB532E1970242409F2287889BBF4B40
80715	61954	37.849032000000001	37.872630999999998	56.147004000000003	56.131225000000001	Совхозная	0103000020E61000000100000005000000F5A0A014ADEC424074B515FBCB104C40F5A0A014ADEC4240CB30EE06D1124C40E63C635FB2EF4240CB30EE06D1124C40E63C635FB2EF424074B515FBCB104C40F5A0A014ADEC424074B515FBCB104C40
71788	59512	37.217948	37.246901000000001	56.042703000000003	56.022554	Куйбышево	0103000020E61000000100000005000000431D56B8E59B42406E32AA0CE3024C40431D56B8E59B42407638BA4A77054C40C32CB4739A9F42407638BA4A77054C40C32CB4739A9F42406E32AA0CE3024C40431D56B8E59B42406E32AA0CE3024C40
71868	59538	37.974347000000002	38.010702000000002	55.631869000000002	55.6248	Быковское шоссе	0103000020E6100000010000000500000055FA0967B7FC424039454772F9CF4B4055FA0967B7FC4240992D5915E1D04B403B00E2AE5E014340992D5915E1D04B403B00E2AE5E01434039454772F9CF4B4055FA0967B7FC424039454772F9CF4B40
79892	61892	37.867789000000002	37.882665000000003	55.694104000000003	55.685949000000001	микрорайон поселок Калинина	0103000020E610000001000000050000000E6ABFB513EF4240A9DC442DCDD74B400E6ABFB513EF4240EB025E66D8D84B407429AE2AFBF04240EB025E66D8D84B407429AE2AFBF04240A9DC442DCDD74B400E6ABFB513EF4240A9DC442DCDD74B40
80377	61892	37.914006999999998	37.938136	55.672077000000002	55.66048	Электрификации	0103000020E6100000010000000500000054A86E2EFEF44240BFD4CF9B8AD44B4054A86E2EFEF4424068B27F9E06D64B40A29927D714F8424068B27F9E06D64B40A29927D714F84240BFD4CF9B8AD44B4054A86E2EFEF44240BFD4CF9B8AD44B40
80293	61892	37.864609000000002	37.917619000000002	55.693657000000002	55.658301999999999	Октябрьский проспект	0103000020E61000000100000005000000E469F981ABEE424019726C3D43D44B40E469F981ABEE42401CD2A8C0C9D84B401898158A74F542401CD2A8C0C9D84B401898158A74F5424019726C3D43D44B40E469F981ABEE424019726C3D43D44B40
80383	61892	37.879503	37.890202000000002	55.695006999999997	55.687486999999997	Красногорская	0103000020E61000000100000005000000F0DDE68D93F042406BB6F292FFD74B40F0DDE68D93F04240DBBE47FDF5D84B40BA6A9E23F2F14240DBBE47FDF5D84B40BA6A9E23F2F142406BB6F292FFD74B40F0DDE68D93F042406BB6F292FFD74B40
80384	61892	37.890202000000002	37.911968000000002	55.687528	55.682203999999999	Инициативная	0103000020E61000000100000005000000BA6A9E23F2F14240A699EE7552D74B40BA6A9E23F2F14240CA8AE1EA00D84B40D07F0F5EBBF44240CA8AE1EA00D84B40D07F0F5EBBF44240A699EE7552D74B40BA6A9E23F2F14240A699EE7552D74B40
74109	211	37.896974999999998	37.902473000000001	55.579973000000003	55.578218	проезд Шестакова	0103000020E61000000100000005000000302AA913D0F24240B1FA230C03CA4B40302AA913D0F2424011C8258E3CCA4B40F2423A3C84F3424011C8258E3CCA4B40F2423A3C84F34240B1FA230C03CA4B40302AA913D0F24240B1FA230C03CA4B40
80317	211	37.902768999999999	37.912497999999999	55.587611000000003	55.580604000000001	Спортивная 	0103000020E61000000100000005000000DB6B41EF8DF34240A1F65B3B51CA4B40DB6B41EF8DF342408BE255D636CB4B402CD505BCCCF442408BE255D636CB4B402CD505BCCCF44240A1F65B3B51CA4B40DB6B41EF8DF34240A1F65B3B51CA4B40
80321	211	37.902768999999999	37.912497999999999	55.587611000000003	55.580604000000001	Спортивная	0103000020E61000000100000005000000DB6B41EF8DF34240A1F65B3B51CA4B40DB6B41EF8DF342408BE255D636CB4B402CD505BCCCF442408BE255D636CB4B402CD505BCCCF44240A1F65B3B51CA4B40DB6B41EF8DF34240A1F65B3B51CA4B40
80327	211	37.908679999999997	37.912624000000001	55.573520000000002	55.573388000000001	Сафонова	0103000020E61000000100000005000000BF4351A04FF442409DF529C764C94B40BF4351A04FF442400CCD751A69C94B40B9C5FCDCD0F442400CCD751A69C94B40B9C5FCDCD0F442409DF529C764C94B40BF4351A04FF442409DF529C764C94B40
80333	211	37.905132000000002	37.906165000000001	55.578192000000001	55.574491999999999	Пионерская	0103000020E610000001000000050000001348895DDBF3424025E82FF488C94B401348895DDBF342408867093202CA4B40D2E3F736FDF342408867093202CA4B40D2E3F736FDF3424025E82FF488C94B401348895DDBF3424025E82FF488C94B40
81154	211	37.908797	37.916046999999999	55.592748999999998	55.569194000000003	Парковая улица	0103000020E61000000100000005000000F9D9C87553F442402B8A5759DBC84B40F9D9C87553F442404CDE0033DFCB4B40A94C310741F542404CDE0033DFCB4B40A94C310741F542402B8A5759DBC84B40F9D9C87553F442402B8A5759DBC84B40
80325	211	37.908797	37.916046999999999	55.592748999999998	55.569194000000003	Парковая	0103000020E61000000100000005000000F9D9C87553F442402B8A5759DBC84B40F9D9C87553F442404CDE0033DFCB4B40A94C310741F542404CDE0033DFCB4B40A94C310741F542402B8A5759DBC84B40F9D9C87553F442402B8A5759DBC84B40
80330	211	37.908797	37.916046999999999	55.592748999999998	55.569194000000003	Парковая	0103000020E61000000100000005000000F9D9C87553F442402B8A5759DBC84B40F9D9C87553F442404CDE0033DFCB4B40A94C310741F542404CDE0033DFCB4B40A94C310741F542402B8A5759DBC84B40F9D9C87553F442402B8A5759DBC84B40
71897	211	37.897263000000002	37.911591000000001	55.578218	55.577784999999999	Ленина	0103000020E6100000010000000500000097749483D9F24240478FDFDBF4C94B4097749483D9F24240B1FA230C03CA4B40FA298E03AFF44240B1FA230C03CA4B40FA298E03AFF44240478FDFDBF4C94B4097749483D9F24240478FDFDBF4C94B40
80319	211	37.895915000000002	37.906461999999998	55.584913999999998	55.582349999999998	Комсомольская	0103000020E61000000100000005000000787FBC57ADF24240AD69DE718ACA4B40787FBC57ADF242407C7C4276DECA4B408B8862F206F442407C7C4276DECA4B408B8862F206F44240AD69DE718ACA4B40787FBC57ADF24240AD69DE718ACA4B40
81151	211	37.875649000000003	37.886169000000002	55.59984	55.593639000000003	6 микрорайон	0103000020E6100000010000000500000037E3344415F04240A950DD5CFCCB4B4037E3344415F04240946A9F8EC7CC4B4051DD5CFC6DF14240946A9F8EC7CC4B4051DD5CFC6DF14240A950DD5CFCCB4B4037E3344415F04240A950DD5CFCCB4B40
80622	61945	38.994762000000001	39.041347999999999	54.982506999999998	54.923946999999998	Пушкина	0103000020E61000000100000005000000DBA6785C547F4340601E32E543764B40DBA6785C547F4340A88B14CAC27D4B40A4E029E44A854340A88B14CAC27D4B40A4E029E44A854340601E32E543764B40DBA6785C547F4340601E32E543764B40
80626	61945	39.028402999999997	39.035975999999998	54.975662	54.966205000000002	Первомайская	0103000020E61000000100000005000000DC0DA2B5A2834340A81DFE9AAC7B4B40DC0DA2B5A283434098F90E7EE27C4B406FB88FDC9A84434098F90E7EE27C4B406FB88FDC9A844340A81DFE9AAC7B4B40DC0DA2B5A2834340A81DFE9AAC7B4B40
80620	61945	39.018953000000003	39.039794000000001	54.953194000000003	54.944020999999999	Мира	0103000020E610000001000000050000009F94490D6D8243405DDE1CAED5784B409F94490D6D824340295FD042027A4B40DC4944F817854340295FD042027A4B40DC4944F8178543405DDE1CAED5784B409F94490D6D8243405DDE1CAED5784B40
7501	22625	38.204980999999997	38.206570999999997	55.874637	55.873838999999997	площадь Революции	0103000020E6100000010000000500000093A641D13C1A4340137CD3F4D9EF4B4093A641D13C1A43408F6FEF1AF4EF4B40A8A624EB701A43408F6FEF1AF4EF4B40A8A624EB701A4340137CD3F4D9EF4B4093A641D13C1A4340137CD3F4D9EF4B40
79921	22625	38.186377	38.192583999999997	55.869273	55.864125999999999	Чехова	0103000020E6100000010000000500000001DD9733DB174340C8CF46AE9BEE4B4001DD9733DB174340DD25715644EF4B40CEDDAE97A6184340DD25715644EF4B40CEDDAE97A6184340C8CF46AE9BEE4B4001DD9733DB174340C8CF46AE9BEE4B40
80323	22625	38.189870999999997	38.197363000000003	55.872804000000002	55.869808999999997	Строителей	0103000020E61000000100000005000000BABA63B14D1843401B62BCE655EF4B40BABA63B14D184340B4E89D0AB8EF4B406138D73043194340B4E89D0AB8EF4B406138D730431943401B62BCE655EF4B40BABA63B14D1843401B62BCE655EF4B40
7810	22625	38.193598999999999	38.205331000000001	55.884811999999997	55.875560999999998	Почтовая улица	0103000020E61000000100000005000000E7C41EDAC71843409753026212F04B40E7C41EDAC7184340DE8D058541F14B4070ED4449481A4340DE8D058541F14B4070ED4449481A43409753026212F04B40E7C41EDAC71843409753026212F04B40
79877	22625	38.170341999999998	38.178705000000001	55.884988999999997	55.882832999999998	Октябрьская	0103000020E610000001000000050000004F9143C4CD1543402F6AF7AB00F14B404F9143C4CD154340ED28CE5147F14B40DB5031CEDF164340ED28CE5147F14B40DB5031CEDF1643402F6AF7AB00F14B404F9143C4CD1543402F6AF7AB00F14B40
79907	22625	38.189439999999998	38.205044000000001	55.875172999999997	55.867733000000001	Ленина	0103000020E61000000100000005000000F146E6913F1843407A54FCDF11EF4B40F146E6913F184340CDAB3AAB05F04B40DA1EBDE13E1A4340CDAB3AAB05F04B40DA1EBDE13E1A43407A54FCDF11EF4B40F146E6913F1843407A54FCDF11EF4B40
79911	22625	38.186377	38.192583999999997	55.869273	55.864125999999999	 Чехова	0103000020E6100000010000000500000001DD9733DB174340C8CF46AE9BEE4B4001DD9733DB174340DD25715644EF4B40CEDDAE97A6184340DD25715644EF4B40CEDDAE97A6184340C8CF46AE9BEE4B4001DD9733DB174340C8CF46AE9BEE4B40
80730	29102	37.453989	37.471066	56.007851000000002	56.006048999999997	улица Победы	0103000020E6100000010000000500000033DFC14F1CBA42403596B036C6004C4033DFC14F1CBA4240D61EF64201014C40F72004E44BBC4240D61EF64201014C40F72004E44BBC42403596B036C6004C4033DFC14F1CBA42403596B036C6004C40
28789	29102	37.472279	37.479680999999999	56.019796999999997	56.019475	проезд Шадунца	0103000020E6100000010000000500000036CB65A373BC4240780B24287E024C4036CB65A373BC42408AC745B588024C409CC1DF2F66BD42408AC745B588024C409CC1DF2F66BD4240780B24287E024C4036CB65A373BC4240780B24287E024C40
79926	29102	37.477606000000002	37.482097000000003	56.018991999999997	56.010277000000002	Чехова	0103000020E61000000100000005000000CB2F833122BD42405473B9C150014C40CB2F833122BD42405C7171546E024C40F73FC05AB5BD42405C7171546E024C40F73FC05AB5BD42405473B9C150014C40CB2F833122BD42405473B9C150014C40
80208	29102	37.481990000000003	37.482627000000001	56.005586000000001	56.003019000000002	Фестивальная	0103000020E61000000100000005000000E17F2BD9B1BD4240212235ED62004C40E17F2BD9B1BD424061A8C30AB7004C405395B6B8C6BD424061A8C30AB7004C405395B6B8C6BD4240212235ED62004C40E17F2BD9B1BD4240212235ED62004C40
16868	29102	37.482627000000001	37.487568000000003	56.006663000000003	56.005586000000001	Первая улица	0103000020E610000001000000050000005395B6B8C6BD424061A8C30AB7004C405395B6B8C6BD4240F08B4B55DA004C40BF49D3A068BE4240F08B4B55DA004C40BF49D3A068BE424061A8C30AB7004C405395B6B8C6BD424061A8C30AB7004C40
80386	29102	37.484298000000003	37.488404000000003	56.016098999999997	56.015475000000002	Павлика Морозова	0103000020E6100000010000000500000055C2137AFDBD4240EB73B515FB014C4055C2137AFDBD4240C83F33880F024C40289EB30584BE4240C83F33880F024C40289EB30584BE4240EB73B515FB014C4055C2137AFDBD4240EB73B515FB014C40
80388	29102	37.478783	37.489561999999999	56.049836999999997	56.042306000000004	Научный городок	0103000020E61000000100000005000000BD70E7C248BD4240593673486A054C40BD70E7C248BD4240BC900E0F61064C40A3AEB5F7A9BE4240BC900E0F61064C40A3AEB5F7A9BE4240593673486A054C40BD70E7C248BD4240593673486A054C40
80619	29102	37.452739999999999	37.470734	56.009400999999997	56.007015000000003	Мирная	0103000020E61000000100000005000000A7CB6262F3B942406DCA15DEE5004C40A7CB6262F3B942405CC64D0D34014C40C18EFF0241BC42405CC64D0D34014C40C18EFF0241BC42406DCA15DEE5004C40A7CB6262F3B942406DCA15DEE5004C40
79975	29102	37.437316000000003	37.483246999999999	56.013080000000002	56.007156000000002	Ленина	0103000020E610000001000000050000003F027FF8F9B742402FFCE07CEA004C403F027FF8F9B74240A81DFE9AAC014C40EF71A609DBBD4240A81DFE9AAC014C40EF71A609DBBD42402FFCE07CEA004C403F027FF8F9B742402FFCE07CEA004C40
16890	29102	37.411858000000002	37.454762000000002	56.032021	56.020527000000001	Краснополянская улица	0103000020E61000000100000005000000494C50C3B7B44240AED7F4A0A0024C40494C50C3B7B4424082E49D4319044C4056BB26A435BA424082E49D4319044C4056BB26A435BA4240AED7F4A0A0024C40494C50C3B7B44240AED7F4A0A0024C40
80283	29102	37.478746999999998	37.498643999999999	56.024622000000001	56.023062000000003	Комиссара Агапова	0103000020E610000001000000050000007007EA9447BD4240E3E313B2F3024C407007EA9447BD42408D614ED026034C405E2C0C91D3BF42408D614ED026034C405E2C0C91D3BF4240E3E313B2F3024C407007EA9447BD4240E3E313B2F3024C40
80617	29102	37.466431	37.467590000000001	56.010210999999998	56.007398000000002	Дружбы	0103000020E61000000100000005000000986BD102B4BB42402507EC6AF2004C40986BD102B4BB42409C8713984E014C40E4F736FDD9BB42409C8713984E014C40E4F736FDD9BB42402507EC6AF2004C40986BD102B4BB42402507EC6AF2004C40
80261	29102	37.472270000000002	37.481378999999997	56.026845000000002	56.025818999999998	Деповская	0103000020E61000000100000005000000E370E65773BC4240C64E78094E034C40E370E65773BC4240D3872EA86F034C4097FDBAD39DBD4240D3872EA86F034C4097FDBAD39DBD4240C64E78094E034C40E370E65773BC4240C64E78094E034C40
80439	29102	37.422207	37.427093999999997	56.022272000000001	56.020567	Булычева	0103000020E61000000100000005000000369204E10AB642403C3080F0A1024C40369204E10AB64240EACE13CFD9024C40AE282504ABB64240EACE13CFD9024C40AE282504ABB642403C3080F0A1024C40369204E10AB642403C3080F0A1024C40
28799	29102	37.466979000000002	37.476284999999997	56.024028000000001	56.010356999999999	Букинское шоссе	0103000020E610000001000000050000009B75C6F7C5BB42407024D06053014C409B75C6F7C5BB42401A18795913034C40A54929E8F6BC42401A18795913034C40A54929E8F6BC42407024D06053014C409B75C6F7C5BB42407024D06053014C40
81059	29102	37.409027999999999	37.533363999999999	56.067756000000003	55.999499999999998	Большая	0103000020E61000000100000005000000FB928D075BB442400E2DB29DEFFF4B40FB928D075BB44240CC0D863AAC084C408F6E844545C44240CC0D863AAC084C408F6E844545C442400E2DB29DEFFF4B40FB928D075BB442400E2DB29DEFFF4B40
16886	29102	37.420409999999997	37.422288000000002	56.023676000000002	56.014569000000002	Аэропортовская улица	0103000020E61000000100000005000000A774B0FECFB542408944A165DD014C40A774B0FECFB542409DD9AED007034C4023BF7E880DB642409DD9AED007034C4023BF7E880DB642408944A165DD014C40A774B0FECFB542408944A165DD014C40
80350	29102	37.420409999999997	37.422288000000002	56.023676000000002	56.014569000000002	Аэропортовская	0103000020E61000000100000005000000A774B0FECFB542408944A165DD014C40A774B0FECFB542409DD9AED007034C4023BF7E880DB642409DD9AED007034C4023BF7E880DB642408944A165DD014C40A774B0FECFB542408944A165DD014C40
80703	29102	37.457366999999998	37.467678999999997	56.014679999999998	56.011282999999999	Авиационная	0103000020E6100000010000000500000083A279008BBA42401900AAB871014C4083A279008BBA4240E0F3C308E1014C405303CDE7DCBB4240E0F3C308E1014C405303CDE7DCBB42401900AAB871014C4083A279008BBA42401900AAB871014C40
80661	29102	37.457366999999998	37.467678999999997	56.014679999999998	56.011282999999999	 Авиационная	0103000020E6100000010000000500000083A279008BBA42401900AAB871014C4083A279008BBA4240E0F3C308E1014C405303CDE7DCBB4240E0F3C308E1014C405303CDE7DCBB42401900AAB871014C4083A279008BBA42401900AAB871014C40
79803	61867	38.957822999999998	38.958865000000003	55.720063000000003	55.711995000000002	Октябрьская	0103000020E61000000100000005000000A52DAEF1997A434030F5F3A622DB4B40A52DAEF1997A4340A3073E062BDC4B40B8239C16BC7A4340A3073E062BDC4B40B8239C16BC7A434030F5F3A622DB4B40A52DAEF1997A434030F5F3A622DB4B40
80220	61867	38.959466999999997	38.960976000000002	55.731313	55.729112999999998	Новая	0103000020E61000000100000005000000AD4B8DD0CF7A4340520B259353DD4B40AD4B8DD0CF7A4340E01115AA9BDD4B40D61EF642017B4340E01115AA9BDD4B40D61EF642017B4340520B259353DD4B40AD4B8DD0CF7A4340520B259353DD4B40
80300	61867	38.947636000000003	38.964137999999998	55.710433000000002	55.702348000000001	Коммунистическая	0103000020E610000001000000050000009241EE224C7943409C340D8AE6D94B409241EE224C794340E57FF277EFDA4B40596ABDDF687B4340E57FF277EFDA4B40596ABDDF687B43409C340D8AE6D94B409241EE224C7943409C340D8AE6D94B40
80896	61936	38.934502999999999	38.940278999999997	55.585174000000002	55.579743999999998	Совхозная	0103000020E61000000100000005000000C78157CB9D774340AF06280D35CA4B40C78157CB9D774340193C4CFBE6CA4B40CB0EF10F5B784340193C4CFBE6CA4B40CB0EF10F5B784340AF06280D35CA4B40C78157CB9D774340AF06280D35CA4B40
80338	61936	38.876148000000001	38.888823000000002	55.586241999999999	55.579307	Лесная	0103000020E61000000100000005000000583A1F9E2570434004AC55BB26CA4B40583A1F9E2570434054C554FA09CB4B406077BAF3C471434054C554FA09CB4B406077BAF3C471434004AC55BB26CA4B40583A1F9E2570434004AC55BB26CA4B40
80746	61968	38.121087000000003	38.204746999999998	55.623086999999998	55.571820000000002	Чурилина	0103000020E61000000100000005000000427C60C77F0F43407099D36531C94B40427C60C77F0F434008C89750C1CF4B40207A5226351A434008C89750C1CF4B40207A5226351A43407099D36531C94B40427C60C77F0F43407099D36531C94B40
74117	59506	37.039991999999998	37.042712999999999	55.600216000000003	55.592688000000003	проспект Мира	0103000020E61000000100000005000000020D36751E854240A75D4C33DDCB4B40020D36751E8542409A44BDE0D3CC4B40990E9D9E778542409A44BDE0D3CC4B40990E9D9E77854240A75D4C33DDCB4B40020D36751E854240A75D4C33DDCB4B40
79814	59506	37.035491	37.042712999999999	55.600216000000003	55.600169999999999	Молодежная	0103000020E61000000100000005000000B32616F88A8442402905DD5ED2CC4B40B32616F88A8442409A44BDE0D3CC4B40990E9D9E778542409A44BDE0D3CC4B40990E9D9E778542402905DD5ED2CC4B40B32616F88A8442402905DD5ED2CC4B40
71779	59506	37.024388000000002	37.068001000000002	55.606914000000003	55.580986000000003	Комсомольский бульвар	0103000020E610000001000000050000001A355F251F83424089B7CEBF5DCA4B401A355F251F83424006BEA25BAFCD4B40338CBB41B488424006BEA25BAFCD4B40338CBB41B488424089B7CEBF5DCA4B401A355F251F83424089B7CEBF5DCA4B40
71896	59506	37.024388000000002	37.068001000000002	55.606914000000003	55.580986000000003	Генерала Шлыкова	0103000020E610000001000000050000001A355F251F83424089B7CEBF5DCA4B401A355F251F83424006BEA25BAFCD4B40338CBB41B488424006BEA25BAFCD4B40338CBB41B488424089B7CEBF5DCA4B401A355F251F83424089B7CEBF5DCA4B40
80270	61932	38.229514000000002	38.240689000000003	56.442124999999997	56.433574999999998	Строителей	0103000020E61000000100000005000000B1FCF9B6601D43407DAEB6627F374C40B1FCF9B6601D43403BDF4F8D97384C40E4C0ABE5CE1E43403BDF4F8D97384C40E4C0ABE5CE1E43407DAEB6627F374C40B1FCF9B6601D43407DAEB6627F374C40
80171	5426	38.850186999999998	38.859619000000002	55.069065999999999	55.06371	Лесная	0103000020E61000000100000005000000FF3D78EDD26C4340CE3637A627884B40FF3D78EDD26C4340FDA19927D7884B409702D2FE076E4340FDA19927D7884B409702D2FE076E4340CE3637A627884B40FF3D78EDD26C4340CE3637A627884B40
79817	59550	37.321612999999999	37.327443000000002	55.807859999999998	55.805684999999997	Южный бульвар	0103000020E61000000100000005000000F67B629D2AA942405AF0A2AF20E74B40F67B629D2AA942408FDFDBF467E74B40EE26F8A6E9A942408FDFDBF467E74B40EE26F8A6E9A942405AF0A2AF20E74B40F67B629D2AA942405AF0A2AF20E74B40
80909	59550	37.25168	37.256441000000002	55.838560999999999	55.822296000000001	Чапаева	0103000020E610000001000000050000005587DC0C37A04240D9D0CDFE40E94B405587DC0C37A04240BC5983F755EB4B40412D060FD3A04240BC5983F755EB4B40412D060FD3A04240D9D0CDFE40E94B405587DC0C37A04240D9D0CDFE40E94B40
71917	59550	37.229140999999998	37.394089000000001	55.851278000000001	55.799886999999998	Ткацкой фабрики	0103000020E610000001000000050000001C96067E549D42406EBF7CB262E64B401C96067E549D4240F3E670ADF6EC4B404F5B238271B24240F3E670ADF6EC4B404F5B238271B242406EBF7CB262E64B401C96067E549D42406EBF7CB262E64B40
80119	59550	37.322853000000002	37.341034999999998	55.839213000000001	55.818736000000001	Речная	0103000020E610000001000000050000002F35423F53A9424068075C57CCE84B402F35423F53A9424064B0E2546BEB4B404BE5ED08A7AB424064B0E2546BEB4B404BE5ED08A7AB424068075C57CCE84B402F35423F53A9424068075C57CCE84B40
80454	59550	37.328691999999997	37.334809999999997	55.829723999999999	55.821531999999998	Пионерская	0103000020E61000000100000005000000793A579412AA4240094FE8F527E94B40793A579412AA4240685A626534EA4B40D72FD80DDBAA4240685A626534EA4B40D72FD80DDBAA4240094FE8F527E94B40793A579412AA4240094FE8F527E94B40
79885	59550	37.321074000000003	37.357429000000003	55.817470999999998	55.802689999999998	Ильинское шоссе	0103000020E6100000010000000500000047CCECF318A94240C269C18BBEE64B4047CCECF318A94240D636C5E3A2E84B402DD2C43BC0AD4240D636C5E3A2E84B402DD2C43BC0AD4240C269C18BBEE64B4047CCECF318A94240C269C18BBEE64B40
80894	59550	37.334961999999997	37.351545000000002	55.816369000000002	55.810284000000003	Вокзальная	0103000020E610000001000000050000008DB3E908E0AA42406D3CD862B7E74B408DB3E908E0AA4240EF3B86C77EE84B404209336DFFAC4240EF3B86C77EE84B404209336DFFAC42406D3CD862B7E74B408DB3E908E0AA42406D3CD862B7E74B40
6419	15725	38.125210000000003	38.144559999999998	56.110982	56.101242999999997	улица Академика Янгеля	0103000020E61000000100000005000000EB909BE10610434076F9D687F50C4C40EB909BE106104340EB387EA8340E4C40A6272CF180124340EB387EA8340E4C40A6272CF18012434076F9D687F50C4C40EB909BE10610434076F9D687F50C4C40
80312	15725	38.135010999999999	38.144075000000001	56.121647000000003	56.119695	Спортивная улица	0103000020E61000000100000005000000D5CC5A0A48114340533F6F2A520F4C40D5CC5A0A481143400954FF20920F4C40EA95B20C711243400954FF20920F4C40EA95B20C71124340533F6F2A520F4C40D5CC5A0A48114340533F6F2A520F4C40
80287	15725	38.138973	38.142611000000002	56.123919999999998	56.118645999999998	Комсомольская	0103000020E61000000100000005000000750305DEC91143408EE6C8CA2F0F4C40750305DEC911434000A94D9CDC0F4C406286C6134112434000A94D9CDC0F4C406286C613411243408EE6C8CA2F0F4C40750305DEC91143408EE6C8CA2F0F4C40
72027	15725	38.139924999999998	38.142961	56.123171999999997	56.122529999999998	Горького	0103000020E610000001000000050000004772F90FE9114340B2632310AF0F4C404772F90FE911434036E49F19C40F4C403ECDC98B4C12434036E49F19C40F4C403ECDC98B4C124340B2632310AF0F4C404772F90FE9114340B2632310AF0F4C40
80280	15725	38.125210000000003	38.144559999999998	56.110982	56.101242999999997	Академика Янгеля	0103000020E61000000100000005000000EB909BE10610434076F9D687F50C4C40EB909BE106104340EB387EA8340E4C40A6272CF180124340EB387EA8340E4C40A6272CF18012434076F9D687F50C4C40EB909BE10610434076F9D687F50C4C40
80274	15725	38.136699999999998	38.140203	56.103270999999999	56.101891000000002	 Новая Жизнь	0103000020E610000001000000050000007DAEB6627F114340DD60A8C30A0D4C407DAEB6627F11434007D0EFFB370D4C408AE6012CF211434007D0EFFB370D4C408AE6012CF2114340DD60A8C30A0D4C407DAEB6627F114340DD60A8C30A0D4C40
316	1202	37.868831	37.875335	55.650627	55.650323	Парковая улица	0103000020E610000001000000050000002060ADDA35EF4240166BB8C83DD34B402060ADDA35EF42408272DBBE47D34B40A7052FFA0AF042408272DBBE47D34B40A7052FFA0AF04240166BB8C83DD34B402060ADDA35EF4240166BB8C83DD34B40
81037	1202	37.874706000000003	37.882117000000001	55.653167000000003	55.648381999999998	Малая Колхозная	0103000020E61000000100000005000000B8CEBF5DF6EF424054A86E2EFED24B40B8CEBF5DF6EF4240C9E9EBF99AD34B40711FB935E9F04240C9E9EBF99AD34B40711FB935E9F0424054A86E2EFED24B40B8CEBF5DF6EF424054A86E2EFED24B40
15451	722	37.830230999999998	37.857548000000001	55.925561000000002	55.924864999999997	улица Сакко и Ванцетти	0103000020E610000001000000050000000C90680245EA4240861BF0F961F64B400C90680245EA4240FEB968C878F64B4007600322C4ED4240FEB968C878F64B4007600322C4ED4240861BF0F961F64B400C90680245EA4240861BF0F961F64B40
15609	722	37.873691000000001	37.877068999999999	55.918424000000002	55.906905000000002	улица Победы	0103000020E610000001000000050000009FE74F1BD5EF424019CA897615F44B409FE74F1BD5EF424046EEE9EA8EF54B40EFAA07CC43F0424046EEE9EA8EF54B40EFAA07CC43F0424019CA897615F44B409FE74F1BD5EF424019CA897615F44B40
80116	722	37.856228000000002	37.857557	55.922685999999999	55.910921999999999	улица Дзержинского	0103000020E61000000100000005000000B2F50CE198ED42407C9A931799F44B40B2F50CE198ED4240103D29931AF64B405ABA826DC4ED4240103D29931AF64B405ABA826DC4ED42407C9A931799F44B40B2F50CE198ED42407C9A931799F44B40
15571	722	37.866010000000003	37.869146000000001	55.92145	55.905774999999998	проспект Космонавтов	0103000020E6100000010000000500000026016A6AD9EE42406744696FF0F34B4026016A6AD9EE42401973D712F2F54B4080B9162D40EF42401973D712F2F54B4080B9162D40EF42406744696FF0F34B4026016A6AD9EE42406744696FF0F34B40
15481	722	37.832287999999998	37.855069	55.922383000000004	55.920355999999998	проспект Королева	0103000020E61000000100000005000000376DC66988EA4240B456B439CEF54B40376DC66988EA424075B169A510F64B406669A7E672ED424075B169A510F64B406669A7E672ED4240B456B439CEF54B40376DC66988EA4240B456B439CEF54B40
80282	722	37.862524999999998	37.868794999999999	55.931632999999998	55.926580000000001	Школьная	0103000020E61000000100000005000000BF7D1D3867EE42405890662C9AF64B40BF7D1D3867EE4240EB6F09C03FF74B40D3F6AFAC34EF4240EB6F09C03FF74B40D3F6AFAC34EF42405890662C9AF64B40BF7D1D3867EE42405890662C9AF64B40
80991	722	37.788404999999997	37.947631000000001	55.960099999999997	55.876379999999997	Торфопредприятие	0103000020E610000001000000050000005E807D74EAE442402A6F47382DF04B405E807D74EAE44240DE718A8EE4FA4B4080D6FCF84BF94240DE718A8EE4FA4B4080D6FCF84BF942402A6F47382DF04B405E807D74EAE442402A6F47382DF04B40
80250	722	37.812182999999997	37.813341999999999	55.919009000000003	55.913949000000002	Терешковой	0103000020E61000000100000005000000FFAECF9CF5E74240209BE447FCF44B40FFAECF9CF5E7424066DD3F16A2F54B404B3B35971BE8424066DD3F16A2F54B404B3B35971BE84240209BE447FCF44B40FFAECF9CF5E74240209BE447FCF44B40
80253	722	37.846803999999999	37.856847999999999	55.920077999999997	55.919387	Суворова	0103000020E610000001000000050000009D0FCF1264EC42400CAF2479AEF54B409D0FCF1264EC424071E2AB1DC5F54B404ED2FC31ADED424071E2AB1DC5F54B404ED2FC31ADED42400CAF2479AEF54B409D0FCF1264EC42400CAF2479AEF54B40
80134	722	37.858249000000001	37.862399000000003	55.910049000000001	55.909725999999999	Стадионная	0103000020E6100000010000000500000090696D1ADBED42401329CDE671F44B4090696D1ADBED4240F660527C7CF44B40338D261763EE4240F660527C7CF44B40338D261763EE42401329CDE671F44B4090696D1ADBED42401329CDE671F44B40
15626	722	37.879655999999997	37.902545000000003	55.929979000000003	55.925328999999998	Спартаковская улица	0103000020E6100000010000000500000076DD5B9198F042402B85402E71F64B4076DD5B9198F04240C07B478D09F74B408C15359886F34240C07B478D09F74B408C15359886F342402B85402E71F64B4076DD5B9198F042402B85402E71F64B40
79906	722	37.897289999999998	37.898305000000001	55.915129	55.913490000000003	Солнечная	0103000020E6100000010000000500000090831266DAF242408D9C853DEDF44B4090831266DAF24240834F73F222F54B40A96A82A8FBF24240834F73F222F54B40A96A82A8FBF242408D9C853DEDF44B4090831266DAF242408D9C853DEDF44B40
80271	722	37.861851000000001	37.868983999999998	55.956693000000001	55.938571000000003	Советская 	0103000020E610000001000000050000003083312251EE4240ADFC321823F84B403083312251EE4240F4A78DEA74FA4B40A65F22DE3AEF4240F4A78DEA74FA4B40A65F22DE3AEF4240ADFC321823F84B403083312251EE4240ADFC321823F84B40
80276	722	37.861851000000001	37.868983999999998	55.956693000000001	55.938571000000003	Советская	0103000020E610000001000000050000003083312251EE4240ADFC321823F84B403083312251EE4240F4A78DEA74FA4B40A65F22DE3AEF4240F4A78DEA74FA4B40A65F22DE3AEF4240ADFC321823F84B403083312251EE4240ADFC321823F84B40
80268	722	37.861851000000001	37.868983999999998	55.956693000000001	55.938571000000003	Советская	0103000020E610000001000000050000003083312251EE4240ADFC321823F84B403083312251EE4240F4A78DEA74FA4B40A65F22DE3AEF4240F4A78DEA74FA4B40A65F22DE3AEF4240ADFC321823F84B403083312251EE4240ADFC321823F84B40
79898	722	37.861851000000001	37.868983999999998	55.956693000000001	55.938571000000003	Советская	0103000020E610000001000000050000003083312251EE4240ADFC321823F84B403083312251EE4240F4A78DEA74FA4B40A65F22DE3AEF4240F4A78DEA74FA4B40A65F22DE3AEF4240ADFC321823F84B403083312251EE4240ADFC321823F84B40
80411	722	37.830230999999998	37.857548000000001	55.925561000000002	55.924864999999997	Сакко и Ванцетти	0103000020E610000001000000050000000C90680245EA4240861BF0F961F64B400C90680245EA4240FEB968C878F64B4007600322C4ED4240FEB968C878F64B4007600322C4ED4240861BF0F961F64B400C90680245EA4240861BF0F961F64B40
80503	722	37.873691000000001	37.877068999999999	55.918424000000002	55.906905000000002	Победы	0103000020E610000001000000050000009FE74F1BD5EF424019CA897615F44B409FE74F1BD5EF424046EEE9EA8EF54B40EFAA07CC43F0424046EEE9EA8EF54B40EFAA07CC43F0424019CA897615F44B409FE74F1BD5EF424019CA897615F44B40
80277	722	37.789617999999997	37.837749000000002	55.914296999999998	55.912930000000003	Пионерская	0103000020E610000001000000050000009D2ADF3312E54240C6C4E6E3DAF44B409D2ADF3312E542405BEA20AF07F54B40DCA0F65B3BEB42405BEA20AF07F54B40DCA0F65B3BEB4240C6C4E6E3DAF44B409D2ADF3312E54240C6C4E6E3DAF44B40
79929	722	37.861212999999999	37.868409	55.94567	55.945281999999999	Первомайская улица	0103000020E61000000100000005000000EDF1423A3CEE4240ADBF2500FFF84B40EDF1423A3CEE42407767EDB60BF94B40AA46AF0628EF42407767EDB60BF94B40AA46AF0628EF4240ADBF2500FFF84B40EDF1423A3CEE4240ADBF2500FFF84B40
81026	722	37.892915000000002	37.906821000000001	55.921652000000002	55.918156000000003	Пашенной	0103000020E61000000100000005000000CE8DE9094BF242402750C42286F54B40CE8DE9094BF24240812557B1F8F54B40BB29E5B512F44240812557B1F8F54B40BB29E5B512F442402750C42286F54B40CE8DE9094BF242402750C42286F54B40
15487	722	37.826790000000003	37.845725999999999	55.924092999999999	55.913550000000001	Октябрьский бульвар	0103000020E6100000010000000500000076543541D4E9424062A1D634EFF44B4076543541D4E9424034BBEEAD48F64B403EB0E3BF40EC424034BBEEAD48F64B403EB0E3BF40EC424062A1D634EFF44B4076543541D4E9424062A1D634EFF44B40
80269	722	37.807493999999998	37.830517999999998	55.919638999999997	55.917808000000001	Октябрьская улица	0103000020E61000000100000005000000ADDBA0F65BE74240EB0088BB7AF54B40ADDBA0F65BE74240259012BBB6F54B40A25EF0694EEA4240259012BBB6F54B40A25EF0694EEA4240EB0088BB7AF54B40ADDBA0F65BE74240EB0088BB7AF54B40
80258	722	37.807493999999998	37.830517999999998	55.919638999999997	55.917808000000001	Октябрьская 	0103000020E61000000100000005000000ADDBA0F65BE74240EB0088BB7AF54B40ADDBA0F65BE74240259012BBB6F54B40A25EF0694EEA4240259012BBB6F54B40A25EF0694EEA4240EB0088BB7AF54B40ADDBA0F65BE74240EB0088BB7AF54B40
15678	722	37.835341999999997	37.842142000000003	55.949863999999998	55.945003999999997	Молодежная улица	0103000020E61000000100000005000000D47C957CECEA42406A4B1DE4F5F84B40D47C957CECEA4240E9D2BF2495F94B40454B1E4FCBEB4240E9D2BF2495F94B40454B1E4FCBEB42406A4B1DE4F5F84B40D47C957CECEA42406A4B1DE4F5F84B40
71801	722	37.843255999999997	37.850766	55.907178000000002	55.906623000000003	Мичурина	0103000020E61000000100000005000000F01307D0EFEB42409566F3380CF44B40F01307D0EFEB42404AD3A0681EF44B403D4679E6E5EC42404AD3A0681EF44B403D4679E6E5EC42409566F3380CF44B40F01307D0EFEB42409566F3380CF44B40
72310	722	37.876099000000004	37.887256000000001	55.938355000000001	55.937119000000003	Ленина	0103000020E610000001000000050000007787140324F04240E9BAF083F3F74B407787140324F04240E08442041CF84B400397C79A91F14240E08442041CF84B400397C79A91F14240E9BAF083F3F74B407787140324F04240E9BAF083F3F74B40
81033	722	37.913738000000002	37.917906000000002	55.953673999999999	55.943975999999999	Краснооктябрьская	0103000020E61000000100000005000000658EE55DF5F44240BD1AA034D4F84B40658EE55DF5F44240D38558FD11FA4B40AE669DF17DF54240D38558FD11FA4B40AE669DF17DF54240BD1AA034D4F84B40658EE55DF5F44240BD1AA034D4F84B40
80246	722	37.857458000000001	37.861212999999999	55.94567	55.937820000000002	Комсомольская	0103000020E61000000100000005000000C7D8092FC1ED424072C45A7C0AF84B40C7D8092FC1ED42407767EDB60BF94B40EDF1423A3CEE42407767EDB60BF94B40EDF1423A3CEE424072C45A7C0AF84B40C7D8092FC1ED424072C45A7C0AF84B40
80263	722	37.824266000000001	37.84366	55.937558000000003	55.925874	Комитетский лес	0103000020E61000000100000005000000359A5C8C81E94240BD1B0B0A83F64B40359A5C8C81E94240350D8AE601F84B40C078060DFDEB4240350D8AE601F84B40C078060DFDEB4240BD1B0B0A83F64B40359A5C8C81E94240BD1B0B0A83F64B40
6065	722	37.837749000000002	37.856551000000003	55.913974000000003	55.913252999999997	Калининградская улица	0103000020E61000000100000005000000DCA0F65B3BEB4240A8FC6B79E5F44B40DCA0F65B3BEB424079B29B19FDF44B40952D9276A3ED424079B29B19FDF44B40952D9276A3ED4240A8FC6B79E5F44B40DCA0F65B3BEB4240A8FC6B79E5F44B40
80265	722	37.855806000000001	37.868723000000003	55.924401000000003	55.921818999999999	Исаева	0103000020E610000001000000050000003CDC0E0D8BED42406CEA3C2AFEF54B403CDC0E0D8BED4240E2B19FC552F64B403A24B55032EF4240E2B19FC552F64B403A24B55032EF42406CEA3C2AFEF54B403CDC0E0D8BED42406CEA3C2AFEF54B40
80123	722	37.856228000000002	37.857557	55.922685999999999	55.910921999999999	Дзержинского	0103000020E61000000100000005000000B2F50CE198ED42407C9A931799F44B40B2F50CE198ED4240103D29931AF64B405ABA826DC4ED4240103D29931AF64B405ABA826DC4ED42407C9A931799F44B40B2F50CE198ED42407C9A931799F44B40
80272	722	37.856228000000002	37.857557	55.922685999999999	55.910921999999999	Дзержинского	0103000020E61000000100000005000000B2F50CE198ED42407C9A931799F44B40B2F50CE198ED4240103D29931AF64B405ABA826DC4ED4240103D29931AF64B405ABA826DC4ED42407C9A931799F44B40B2F50CE198ED42407C9A931799F44B40
80257	722	37.856228000000002	37.857557	55.922685999999999	55.910921999999999	Дзержинского	0103000020E61000000100000005000000B2F50CE198ED42407C9A931799F44B40B2F50CE198ED4240103D29931AF64B405ABA826DC4ED4240103D29931AF64B405ABA826DC4ED42407C9A931799F44B40B2F50CE198ED42407C9A931799F44B40
80241	722	37.812058	37.823672999999999	55.927003999999997	55.926630000000003	Грабина	0103000020E61000000100000005000000433A3C84F1E742400ABFD4CF9BF64B40433A3C84F1E742406EA12B11A8F64B4092CCEA1D6EE942406EA12B11A8F64B4092CCEA1D6EE942400ABFD4CF9BF64B40433A3C84F1E742400ABFD4CF9BF64B40
71806	722	37.800415000000001	37.82396	55.917822999999999	55.916164000000002	Гагарина	0103000020E610000001000000050000002A1DACFF73E64240E3E2A8DC44F54B402A1DACFF73E6424020425C397BF54B40289B728577E9424020425C397BF54B40289B728577E94240E3E2A8DC44F54B402A1DACFF73E64240E3E2A8DC44F54B40
5847	722	37.803856000000003	37.828111	55.934659000000003	55.930442999999997	Болшевское шоссе	0103000020E61000000100000005000000C158DFC0E4E6424064E597C118F74B40C158DFC0E4E64240BFF4F6E7A2F74B409B3A8F8AFFE94240BFF4F6E7A2F74B409B3A8F8AFFE9424064E597C118F74B40C158DFC0E4E6424064E597C118F74B40
79860	722	37.788404999999997	37.947631000000001	55.960099999999997	55.876379999999997	 50 Лет ВЛКСМ	0103000020E610000001000000050000005E807D74EAE442402A6F47382DF04B405E807D74EAE44240DE718A8EE4FA4B4080D6FCF84BF94240DE718A8EE4FA4B4080D6FCF84BF942402A6F47382DF04B405E807D74EAE442402A6F47382DF04B40
16517	5426	38.791868000000001	38.806573	55.091289000000003	55.086399	улица Партизан	0103000020E61000000100000005000000DD5F3DEE5B6543401CB4571F0F8B4B40DD5F3DEE5B65434006BEA25BAF8B4B40166BB8C83D67434006BEA25BAF8B4B40166BB8C83D6743401CB4571F0F8B4B40DD5F3DEE5B6543401CB4571F0F8B4B40
16260	5426	38.749647000000003	38.753258000000002	55.106278000000003	55.104100000000003	улица Набережная реки Коломенки	0103000020E61000000100000005000000B345D26EF45F4340BEC11726538D4B40B345D26EF45F434064247B849A8D4B40A6B915C26A60434064247B849A8D4B40A6B915C26A604340BEC11726538D4B40B345D26EF45F4340BEC11726538D4B40
74986	5426	38.722653000000001	38.732498	55.104996	55.103811	улица Менделеева	0103000020E610000001000000050000009BADBCE47F5C434087FBC8AD498D4B409BADBCE47F5C4340FC1A4982708D4B405531957EC25D4340FC1A4982708D4B405531957EC25D434087FBC8AD498D4B409BADBCE47F5C434087FBC8AD498D4B40
16354	5426	38.788347000000002	38.795282	55.086368	55.078885	улица Малышева	0103000020E610000001000000050000002A73F38DE86443408E9257E7188A4B402A73F38DE8644340E1B54B1B0E8B4B407A8CF2CCCB654340E1B54B1B0E8B4B407A8CF2CCCB6543408E9257E7188A4B402A73F38DE86443408E9257E7188A4B40
72300	5426	38.840386000000002	38.847473999999998	55.042766999999998	55.036442000000001	улица Ларцевы Поляны	0103000020E610000001000000050000001502B9C4916B4340B519A721AA844B401502B9C4916B43408C2C996379854B40EB1A2D077A6C43408C2C996379854B40EB1A2D077A6C4340B519A721AA844B401502B9C4916B4340B519A721AA844B40
16343	5426	38.763669999999998	38.808594999999997	55.083615999999999	55.076138	улица Дзержинского	0103000020E61000000100000005000000D97745F0BF614340CEFDD5E3BE894B40D97745F0BF6143400FB6D8EDB38A4B40C45A7C0A806743400FB6D8EDB38A4B40C45A7C0A80674340CEFDD5E3BE894B40D97745F0BF614340CEFDD5E3BE894B40
80207	5426	38.740152000000002	38.768503000000003	55.094081000000003	55.061390000000003	проспект Кирова	0103000020E61000000100000005000000D508FD4CBD5E43409626A5A0DB874B40D508FD4CBD5E43406616A1D80A8C4B405FF0694E5E6243406616A1D80A8C4B405FF0694E5E6243409626A5A0DB874B40D508FD4CBD5E43409626A5A0DB874B40
80576	5426	38.740152000000002	38.768503000000003	55.094081000000003	55.061390000000003	проспект Кирова	0103000020E61000000100000005000000D508FD4CBD5E43409626A5A0DB874B40D508FD4CBD5E43406616A1D80A8C4B405FF0694E5E6243406616A1D80A8C4B405FF0694E5E6243409626A5A0DB874B40D508FD4CBD5E43409626A5A0DB874B40
80243	5426	38.745801999999998	38.753923	55.063926000000002	55.058812000000003	бульвар 800-летия Коломны	0103000020E610000001000000050000004CA59F70765F4340624ED02687874B404CA59F70765F43409BAE27BA2E884B40E259828C806043409BAE27BA2E884B40E259828C80604340624ED02687874B404CA59F70765F4340624ED02687874B40
80254	5426	38.743377000000002	38.750824000000001	55.053046000000002	55.048940999999999	Южная	0103000020E610000001000000050000009FCC3FFA265F43407E37DDB243864B409FCC3FFA265F434081971936CA864B40A58636001B60434081971936CA864B40A58636001B6043407E37DDB243864B409FCC3FFA265F43407E37DDB243864B40
80223	5426	38.761792	38.766579999999998	55.093184000000001	55.088177000000002	Шилова	0103000020E610000001000000050000005E2D77668261434034A14962498B4B405E2D77668261434057410C74ED8B4B4043E21E4B1F62434057410C74ED8B4B4043E21E4B1F62434034A14962498B4B405E2D77668261434034A14962498B4B40
80212	5426	38.807580000000002	38.815952000000003	55.080210000000001	55.077855	Шавырина	0103000020E61000000100000005000000AC730CC85E674340406A1327F7894B40AC730CC85E674340F5673F52448A4B408B8D791D71684340F5673F52448A4B408B8D791D71684340406A1327F7894B40AC730CC85E674340406A1327F7894B40
79870	5426	38.838876999999997	38.844132000000002	55.059260000000002	55.045934000000003	Цементников	0103000020E61000000100000005000000EC2E5052606B434022E3512AE1854B40EC2E5052606B434001FBE8D495874B40E8C072840C6C434001FBE8D495874B40E8C072840C6C434022E3512AE1854B40EC2E5052606B434022E3512AE1854B40
80242	5426	38.772131999999999	38.792254	55.083553999999999	55.077741000000003	Фрунзе	0103000020E61000000100000005000000F818AC38D56243407847C66AF3894B40F818AC38D562434099B9C0E5B18A4B4006103E946865434099B9C0E5B18A4B4006103E94686543407847C66AF3894B40F818AC38D56243407847C66AF3894B40
80230	5426	38.748767000000001	38.757551999999997	55.060884000000001	55.056223000000003	Спирина	0103000020E610000001000000050000007AA9D898D75F43403A24B55032874B407AA9D898D75F4340C26C020CCB874B407B82C476F7604340C26C020CCB874B407B82C476F76043403A24B55032874B407AA9D898D75F43403A24B55032874B40
80366	5426	38.837215	38.863877000000002	55.056516999999999	55.052722000000003	Советская	0103000020E610000001000000050000003E5C72DC296B4340CEE33098BF864B403E5C72DC296B43408255F5F23B874B4020628385936E43408255F5F23B874B4020628385936E4340CEE33098BF864B403E5C72DC296B4340CEE33098BF864B40
80556	5426	38.79945	38.822411000000002	55.055000999999997	55.038176	Свободы	0103000020E61000000100000005000000C364AA6054664340FDBE7FF3E2844B40C364AA6054664340A71FD4450A874B40726F7EC344694340A71FD4450A874B40726F7EC344694340FDBE7FF3E2844B40C364AA6054664340FDBE7FF3E2844B40
79779	5426	38.727485999999999	38.836253999999997	55.130631000000001	55.068081999999997	Октябрьской революции	0103000020E610000001000000050000002026E1421E5D43401FB935E9B6884B402026E1421E5D4340016C4084B8904B401893FE5E0A6B4340016C4084B8904B401893FE5E0A6B43401FB935E9B6884B402026E1421E5D43401FB935E9B6884B40
80851	5426	38.727485999999999	38.836253999999997	55.130631000000001	55.068081999999997	Октябрьской революции	0103000020E610000001000000050000002026E1421E5D43401FB935E9B6884B402026E1421E5D4340016C4084B8904B401893FE5E0A6B4340016C4084B8904B401893FE5E0A6B43401FB935E9B6884B402026E1421E5D43401FB935E9B6884B40
74323	5426	38.727485999999999	38.836253999999997	55.130631000000001	55.068081999999997	Октябрьской Революции	0103000020E610000001000000050000002026E1421E5D43401FB935E9B6884B402026E1421E5D4340016C4084B8904B401893FE5E0A6B4340016C4084B8904B401893FE5E0A6B43401FB935E9B6884B402026E1421E5D43401FB935E9B6884B40
79419	5426	38.837763000000002	38.858550000000001	55.069035	55.059178000000003	Октябрьская	0103000020E61000000100000005000000416667D13B6B434044520B2593874B40416667D13B6B4340C2A38D23D6884B408BFD65F7E46D4340C2A38D23D6884B408BFD65F7E46D434044520B2593874B40416667D13B6B434044520B2593874B40
80214	5426	38.800958999999999	38.803483	55.084125999999998	55.070658999999999	Окский проспект	0103000020E61000000100000005000000EB3713D3856643408315A75A0B894B40EB3713D385664340245F09A4C48A4B402CF2EB87D8664340245F09A4C48A4B402CF2EB87D86643408315A75A0B894B40EB3713D3856643408315A75A0B894B40
16283	5426	38.710723000000002	38.750734000000001	55.097996000000002	55.077106999999998	Озерское шоссе	0103000020E61000000100000005000000ECC1A4F8F85A434076A565A4DE894B40ECC1A4F8F85A4340C59107228B8C4B4065FF3C0D18604340C59107228B8C4B4065FF3C0D1860434076A565A4DE894B40ECC1A4F8F85A434076A565A4DE894B40
16255	5426	38.694364999999998	38.740422000000002	55.112468	55.107987999999999	Малинское шоссе	0103000020E61000000100000005000000573ECBF3E0584340232E008DD28D4B40573ECBF3E05843405BECF659658E4B40959EE925C65E43405BECF659658E4B40959EE925C65E4340232E008DD28D4B40573ECBF3E0584340232E008DD28D4B40
80231	5426	38.753824000000002	38.761792	55.088177000000002	55.08155	Леваневского	0103000020E610000001000000050000004F78094E7D604340917EFB3A708A4B404F78094E7D60434034A14962498B4B405E2D77668261434034A14962498B4B405E2D776682614340917EFB3A708A4B404F78094E7D604340917EFB3A708A4B40
80238	5426	38.753338999999997	38.779139000000001	55.10257	55.092365000000001	Красногвардейская	0103000020E6100000010000000500000092E68F696D604340C425C79DD28B4B4092E68F696D6043407EC68503218D4B40E204A6D3BA6343407EC68503218D4B40E204A6D3BA634340C425C79DD28B4B4092E68F696D604340C425C79DD28B4B40
80163	5426	38.755279999999999	38.767693999999999	55.103734000000003	55.09592	Комсомольская	0103000020E6100000010000000500000054A9D903AD6043402384471B478C4B4054A9D903AD604340DCBDDC27478D4B40EFAA07CC43624340DCBDDC27478D4B40EFAA07CC436243402384471B478C4B4054A9D903AD6043402384471B478C4B40
80867	5426	38.740152000000002	38.768503000000003	55.094081000000003	55.061390000000003	Кирова	0103000020E61000000100000005000000D508FD4CBD5E43409626A5A0DB874B40D508FD4CBD5E43406616A1D80A8C4B405FF0694E5E6243406616A1D80A8C4B405FF0694E5E6243409626A5A0DB874B40D508FD4CBD5E43409626A5A0DB874B40
80145	5426	38.775931999999997	38.788859000000002	55.087893000000001	55.073112999999999	Калинина	0103000020E61000000100000005000000BEF561BD51634340CBF44BC45B894B40BEF561BD516343400F46EC13408B4B40E013EB54F96443400F46EC13408B4B40E013EB54F9644340CBF44BC45B894B40BEF561BD51634340CBF44BC45B894B40
79901	5426	38.762188000000002	38.786783999999997	55.082410000000003	55.073742000000003	Зеленая	0103000020E61000000100000005000000ABB35A608F614340BB2BBB6070894B40ABB35A608F614340836E2F698C8A4B400E828E56B5644340836E2F698C8A4B400E828E56B5644340BB2BBB6070894B40ABB35A608F614340BB2BBB6070894B40
80248	5426	38.762188000000002	38.786783999999997	55.082410000000003	55.073742000000003	Зеленая	0103000020E61000000100000005000000ABB35A608F614340BB2BBB6070894B40ABB35A608F614340836E2F698C8A4B400E828E56B5644340836E2F698C8A4B400E828E56B5644340BB2BBB6070894B40ABB35A608F614340BB2BBB6070894B40
79912	5426	38.755800999999998	38.763814000000004	55.107365000000001	55.100797999999998	Зайцева	0103000020E610000001000000050000005DA45016BE60434048C0E8F2E68C4B405DA45016BE60434016DEE522BE8D4B400D1D3BA8C461434016DEE522BE8D4B400D1D3BA8C461434048C0E8F2E68C4B405DA45016BE60434048C0E8F2E68C4B40
80114	5426	38.763525999999999	38.776784999999997	55.088697000000003	55.073639	Добролюбова	0103000020E61000000100000005000000A6D24F38BB614340E65AB4006D894B40A6D24F38BB6143406D205D6C5A8B4B40FD82DDB06D6343406D205D6C5A8B4B40FD82DDB06D634340E65AB4006D894B40A6D24F38BB614340E65AB4006D894B40
80221	5426	38.763669999999998	38.808594999999997	55.083615999999999	55.076138	Дзержинского	0103000020E61000000100000005000000D97745F0BF614340CEFDD5E3BE894B40D97745F0BF6143400FB6D8EDB38A4B40C45A7C0A806743400FB6D8EDB38A4B40C45A7C0A80674340CEFDD5E3BE894B40D97745F0BF614340CEFDD5E3BE894B40
80322	5426	38.763669999999998	38.808594999999997	55.083615999999999	55.076138	Дзержинского	0103000020E61000000100000005000000D97745F0BF614340CEFDD5E3BE894B40D97745F0BF6143400FB6D8EDB38A4B40C45A7C0A806743400FB6D8EDB38A4B40C45A7C0A80674340CEFDD5E3BE894B40D97745F0BF614340CEFDD5E3BE894B40
80227	5426	38.739477999999998	38.754040000000003	55.061818000000002	55.052169999999997	Девичье Поле	0103000020E61000000100000005000000450E1137A75E434089EAAD81AD864B40450E1137A75E4340EE26F8A6E9874B401CF0F96184604340EE26F8A6E9874B401CF0F9618460434089EAAD81AD864B40450E1137A75E434089EAAD81AD864B40
80237	5426	38.741446000000003	38.761046999999998	55.071829000000001	55.060797000000001	Астахова	0103000020E6100000010000000500000001E0D8B3E75E4340F3583332C8874B4001E0D8B3E75E4340C3F352B131894B4005DCF3FC69614340C3F352B131894B4005DCF3FC69614340F3583332C8874B4001E0D8B3E75E4340F3583332C8874B40
80193	59548	36.757201999999999	36.764954000000003	56.327579999999998	56.323652000000003	Самодеятельная	0103000020E610000001000000050000009F3BC1FEEB6042407BA4C16D6D294C409F3BC1FEEB6042406E693524EE294C40E2783E03EA6142406E693524EE294C40E2783E03EA6142407BA4C16D6D294C409F3BC1FEEB6042407BA4C16D6D294C40
81061	59548	36.735256	36.743862	56.340989	56.335464999999999	Папивина	0103000020E6100000010000000500000009185DDE1C5E4240F0F96184F02A4C4009185DDE1C5E4240DBA50D87A52B4C405B5EB9DE365F4240DBA50D87A52B4C405B5EB9DE365F4240F0F96184F02A4C4009185DDE1C5E4240F0F96184F02A4C40
80572	59548	36.712950999999997	36.732444000000001	56.333305000000003	56.318516000000002	Карла Маркса	0103000020E61000000100000005000000435376FA415B42405AA0DD21C5284C40435376FA415B4240F14BFDBCA92A4C40621399B9C05D4240F14BFDBCA92A4C40621399B9C05D42405AA0DD21C5284C40435376FA415B42405AA0DD21C5284C40
80111	59548	36.671332	36.780566999999998	56.380259000000002	56.311810999999999	50 лет Октября	0103000020E610000001000000050000000F61FC34EE5542403BC43F6CE9274C400F61FC34EE5542403D81B053AC304C401DAB949EE96342403D81B053AC304C401DAB949EE96342403BC43F6CE9274C400F61FC34EE5542403BC43F6CE9274C40
3801	13220	37.536175999999998	37.542042000000002	55.379854000000002	55.359481000000002	проспект 50 лет Октября	0103000020E610000001000000050000003673486AA1C442404644317903AE4B403673486AA1C442409DA04D0E9FB04B407B87DBA161C542409DA04D0E9FB04B407B87DBA161C542404644317903AE4B403673486AA1C442404644317903AE4B40
3869	13220	37.541044999999997	37.541789999999999	55.381453999999998	55.380001999999998	проезд Юности	0103000020E6100000010000000500000008556AF640C542401135D1E7A3B04B4008556AF640C54240D576137CD3B04B4061A6ED5F59C54240D576137CD3B04B4061A6ED5F59C542401135D1E7A3B04B4008556AF640C542401135D1E7A3B04B40
80199	13220	37.492984999999997	37.522458999999998	55.371577000000002	55.364476000000003	Школьная	0103000020E610000001000000050000009335EA211ABF4240A5164A26A7AE4B409335EA211ABF42401079CBD58FAF4B401C40BFEFDFC242401079CBD58FAF4B401C40BFEFDFC24240A5164A26A7AE4B409335EA211ABF4240A5164A26A7AE4B40
80186	13220	37.535007999999998	37.542957999999999	55.375172999999997	55.374048000000002	Театральная	0103000020E61000000100000005000000978C63247BC442402E910BCEE0AF4B40978C63247BC44240CDAB3AAB05B04B40008DD2A57FC54240CDAB3AAB05B04B40008DD2A57FC542402E910BCEE0AF4B40978C63247BC442402E910BCEE0AF4B40
80110	13220	37.531109999999998	37.538637000000001	55.386006000000002	55.357475000000001	Симферопольская	0103000020E610000001000000050000000E4A9869FBC342409D11A5BDC1AD4B400E4A9869FBC34240A70705A568B14B4031B5A50EF2C44240A70705A568B14B4031B5A50EF2C442409D11A5BDC1AD4B400E4A9869FBC342409D11A5BDC1AD4B40
80041	13220	37.531405999999997	37.546146999999998	55.357475000000001	55.349209999999999	Серпуховская	0103000020E61000000100000005000000F7729F1C05C44240D4B7CCE9B2AC4B40F7729F1C05C442409D11A5BDC1AD4B407DE71725E8C542409D11A5BDC1AD4B407DE71725E8C54240D4B7CCE9B2AC4B40F7729F1C05C44240D4B7CCE9B2AC4B40
80102	13220	37.508947999999997	37.510969000000003	55.367171999999997	55.360258999999999	Рощинская	0103000020E61000000100000005000000ABAE433525C142407A8B87F71CAE4B40ABAE433525C14240E200FA7DFFAE4B408A22A46E67C14240E200FA7DFFAE4B408A22A46E67C142407A8B87F71CAE4B40ABAE433525C142407A8B87F71CAE4B40
80183	13220	37.517536	37.521056999999999	55.358472999999996	55.345973999999998	Рожкова	0103000020E610000001000000050000005740A19E3EC2424016A243E048AC4B405740A19E3EC24240DFBF7971E2AD4B400A2DEBFEB1C24240DFBF7971E2AD4B400A2DEBFEB1C2424016A243E048AC4B405740A19E3EC2424016A243E048AC4B40
80194	13220	37.539940000000001	37.542302999999997	55.362608000000002	55.358136000000002	Революции	0103000020E61000000100000005000000B0E600C11CC5424098C28366D7AD4B40B0E600C11CC542404DA25EF069AE4B40E7C2482F6AC542404DA25EF069AE4B40E7C2482F6AC5424098C28366D7AD4B40B0E600C11CC5424098C28366D7AD4B40
80050	13220	37.533571000000002	37.533938999999997	55.366855000000001	55.358094999999999	Первомайская	0103000020E61000000100000005000000098CF50D4CC4424039EE940ED6AD4B40098CF50D4CC44240E2AFC91AF5AE4B408B87F71C58C44240E2AFC91AF5AE4B408B87F71C58C4424039EE940ED6AD4B40098CF50D4CC4424039EE940ED6AD4B40
74300	13220	37.537083000000003	37.549759000000002	55.384701999999997	55.381239999999998	Молодежная	0103000020E61000000100000005000000691EC022BFC44240A9F6E978CCB04B40691EC022BFC44240575A46EA3DB14B4041D7BE805EC64240575A46EA3DB14B4041D7BE805EC64240A9F6E978CCB04B40691EC022BFC44240A9F6E978CCB04B40
71898	13220	37.520986000000001	37.522872	55.364476000000003	55.346983000000002	Ленина	0103000020E6100000010000000500000041D653ABAFC242404DA25EF069AC4B4041D653ABAFC24240A5164A26A7AE4B403FFF3D78EDC24240A5164A26A7AE4B403FFF3D78EDC242404DA25EF069AC4B4041D653ABAFC242404DA25EF069AC4B40
80195	13220	37.535995999999997	37.548267000000003	55.380738000000001	55.378973999999999	Заводская	0103000020E61000000100000005000000B66455849BC442406404543882B04B40B66455849BC44240172CD505BCB04B40EF3CF19C2DC64240172CD505BCB04B40EF3CF19C2DC642406404543882B04B40B66455849BC442406404543882B04B40
80174	61929	38.238784000000003	38.249780000000001	54.848266000000002	54.847810000000003	Металлистов	0103000020E610000001000000050000006F675F79901E4340639CBF09856C4B406F675F79901E43408527F4FA936C4B40F29881CAF81F43408527F4FA936C4B40F29881CAF81F4340639CBF09856C4B406F675F79901E4340639CBF09856C4B40
80236	61929	38.251809999999999	38.253695999999998	54.842646999999999	54.838394999999998	Гвардейская	0103000020E610000001000000050000002367614F3B204340A1100187506B4B402367614F3B20434048895DDBDB6B4B4021904B1C7920434048895DDBDB6B4B4021904B1C79204340A1100187506B4B402367614F3B204340A1100187506B4B40
80109	60277	36.858721000000003	36.873435000000001	55.910513000000002	55.903619999999997	Юбилейная	0103000020E61000000100000005000000B8B1D991EA6D42407901F6D1A9F34B40B8B1D991EA6D42409BCAA2B08BF44B404417D4B7CC6F42409BCAA2B08BF44B404417D4B7CC6F42407901F6D1A9F34B40B8B1D991EA6D42407901F6D1A9F34B40
80077	60277	36.858110000000003	36.864524000000003	55.925006000000003	55.893793000000002	Ленина	0103000020E610000001000000050000006F2F698CD66D424066321CCF67F24B406F2F698CD66D4240494DBB9866F64B40B64DF1B8A86E4240494DBB9866F64B40B64DF1B8A86E424066321CCF67F24B406F2F698CD66D424066321CCF67F24B40
74272	60277	36.817075000000003	36.901139000000001	55.932395	55.890295000000002	9 Гвардейской Дивизии	0103000020E610000001000000050000008AB0E1E9956842406B65C22FF5F14B408AB0E1E9956842401AFA27B858F74B403813D385587342401AFA27B858F74B403813D385587342406B65C22FF5F14B408AB0E1E9956842406B65C22FF5F14B40
79873	61889	37.481090999999999	37.516530000000003	56.187475999999997	56.160516000000001	Сельский дом	0103000020E6100000010000000500000031B3CF6394BD42400C3ECDC98B144C4031B3CF6394BD42407764AC36FF174C4092B3B0A71DC242407764AC36FF174C4092B3B0A71DC242400C3ECDC98B144C4031B3CF6394BD42400C3ECDC98B144C40
2454	7706	37.885323999999997	37.912337000000001	55.969335000000001	55.963264000000002	Центральный проезд	0103000020E61000000100000005000000942EFD4B52F1424003B5183C4CFB4B40942EFD4B52F1424020EF552B13FC4B4023F77475C7F4424020EF552B13FC4B4023F77475C7F4424003B5183C4CFB4B40942EFD4B52F1424003B5183C4CFB4B40
79883	7706	37.924256999999997	37.938442000000002	55.971763000000003	55.971133999999999	Хлебозаводская	0103000020E61000000100000005000000AE0CAA0D4EF642404F04711E4EFC4B40AE0CAA0D4EF642403F3BE0BA62FC4B40AF9811DE1EF842403F3BE0BA62FC4B40AF9811DE1EF842404F04711E4EFC4B40AE0CAA0D4EF642404F04711E4EFC4B40
80148	7706	37.915731999999998	37.918768	55.967143999999998	55.965626999999998	Трубниковская	0103000020E6100000010000000500000049F3C7B436F542403A9160AA99FB4B4049F3C7B436F54240E542E55FCBFB4B40404E98309AF54240E542E55FCBFB4B40404E98309AF542403A9160AA99FB4B4049F3C7B436F542403A9160AA99FB4B40
79886	3929	37.898654999999998	37.929755	55.830376000000001	55.823312000000001	Гагарина	0103000020E6100000010000000500000085B1852007F34240C233A14962E94B4085B1852007F3424010B1C1C249EA4B4070253B3602F7424010B1C1C249EA4B4070253B3602F74240C233A14962E94B4085B1852007F34240C233A14962E94B40
80098	7706	37.904601999999997	37.915022999999998	55.976100000000002	55.961747000000003	Советский проспект	0103000020E61000000100000005000000B6F292FFC9F34240580394861AFB4B40B6F292FFC9F3424014D044D8F0FC4B403D0B42791FF5424014D044D8F0FC4B403D0B42791FF54240580394861AFB4B40B6F292FFC9F34240580394861AFB4B40
80144	7706	37.907234000000003	37.920726999999999	55.964478	55.961993999999997	Смурякова	0103000020E61000000100000005000000DEE8633E20F442405F79909E22FB4B40DEE8633E20F4424012DBDD0374FB4B40A8C5E061DAF5424012DBDD0374FB4B40A8C5E061DAF542405F79909E22FB4B40DEE8633E20F442405F79909E22FB4B40
80165	7706	37.898888999999997	37.916719999999998	55.978693999999997	55.971893999999999	Первомайская улица	0103000020E61000000100000005000000F8DD74CB0EF34240DD96C80567FC4B40F8DD74CB0EF342404D6551D845FD4B4068CBB91457F542404D6551D845FD4B4068CBB91457F54240DD96C80567FC4B40F8DD74CB0EF34240DD96C80567FC4B40
80152	7706	37.898888999999997	37.916719999999998	55.978693999999997	55.971893999999999	Первомайская	0103000020E61000000100000005000000F8DD74CB0EF34240DD96C80567FC4B40F8DD74CB0EF342404D6551D845FD4B4068CBB91457F542404D6551D845FD4B4068CBB91457F54240DD96C80567FC4B40F8DD74CB0EF34240DD96C80567FC4B40
80139	7706	37.895465999999999	37.909525000000002	55.972388000000002	55.969607000000003	Задорожная	0103000020E61000000100000005000000085740A19EF24240817C09151CFC4B40085740A19EF24240ED82C13577FC4B407CF2B0506BF44240ED82C13577FC4B407CF2B0506BF44240817C09151CFC4B40085740A19EF24240817C09151CFC4B40
80097	7706	37.907215999999998	37.912337000000001	55.975914000000003	55.968221999999997	 Дзержинского	0103000020E61000000100000005000000373465A71FF4424044A2D0B2EEFB4B40373465A71FF44240B2DAFCBFEAFC4B4023F77475C7F44240B2DAFCBFEAFC4B4023F77475C7F4424044A2D0B2EEFB4B40373465A71FF4424044A2D0B2EEFB4B40
2365	5833	36.866356000000003	36.866841000000001	55.736437000000002	55.735236	улица Кирова	0103000020E61000000100000005000000C158DFC0E46E4240C26B97361CDE4B40C158DFC0E46E42403D484F9143DE4B407DEA58A5F46E42403D484F9143DE4B407DEA58A5F46E4240C26B97361CDE4B40C158DFC0E46E4240C26B97361CDE4B40
80889	5833	36.851264999999998	36.856141999999998	55.740313999999998	55.736463000000001	Спортивная	0103000020E610000001000000050000005E9D6340F66C424066DB696B44DE4B405E9D6340F66C4240AE62F19BC2DE4B40B35DA10F966D4240AE62F19BC2DE4B40B35DA10F966D424066DB696B44DE4B405E9D6340F66C424066DB696B44DE4B40
68989	5833	36.855846	36.867829	55.736502999999999	55.734450000000002	Советская улица	0103000020E61000000100000005000000CA349A5C8C6D42400B46257502DE4B40CA349A5C8C6D4240F433F5BA45DE4B409CC24A05156F4240F433F5BA45DE4B409CC24A05156F42400B46257502DE4B40CA349A5C8C6D42400B46257502DE4B40
80191	5833	36.858721000000003	36.862934000000003	55.740040999999998	55.729619999999997	Некрасова	0103000020E61000000100000005000000B8B1D991EA6D4240F6402B3064DD4B40B8B1D991EA6D42407D59DAA9B9DE4B40A14D0E9F746E42407D59DAA9B9DE4B40A14D0E9F746E4240F6402B3064DD4B40B8B1D991EA6D4240F6402B3064DD4B40
79880	5833	36.849980000000002	36.876928999999997	55.745472999999997	55.741166	Нахабинское шоссе	0103000020E6100000010000000500000086200725CC6C42401D740987DEDE4B4086200725CC6C42408786C5A86BDF4B40FDF49F353F7042408786C5A86BDF4B40FDF49F353F7042401D740987DEDE4B4086200725CC6C42401D740987DEDE4B40
81052	5833	36.860311000000003	36.86844	55.743887000000001	55.739438	Маяковского	0103000020E61000000100000005000000CDB1BCAB1E6E4240B7B585E7A5DE4B40CDB1BCAB1E6E4240B47570B037DF4B40E544BB0A296F4240B47570B037DF4B40E544BB0A296F4240B7B585E7A5DE4B40CDB1BCAB1E6E4240B7B585E7A5DE4B40
72274	5833	36.860311000000003	36.86844	55.743887000000001	55.739438	Маяковского	0103000020E61000000100000005000000CDB1BCAB1E6E4240B7B585E7A5DE4B40CDB1BCAB1E6E4240B47570B037DF4B40E544BB0A296F4240B47570B037DF4B40E544BB0A296F4240B7B585E7A5DE4B40CDB1BCAB1E6E4240B7B585E7A5DE4B40
80845	5833	36.806851999999999	36.904445000000003	55.748649999999998	55.699142000000002	Звенигородское шоссе	0103000020E61000000100000005000000295B24ED4667424049A12C7C7DD94B40295B24ED46674240401361C3D3DF4B40EF0390DAC4734240401361C3D3DF4B40EF0390DAC473424049A12C7C7DD94B40295B24ED4667424049A12C7C7DD94B40
74136	5833	36.806851999999999	36.904445000000003	55.748649999999998	55.699142000000002	Верхнепосадкое шоссе	0103000020E61000000100000005000000295B24ED4667424049A12C7C7DD94B40295B24ED46674240401361C3D3DF4B40EF0390DAC4734240401361C3D3DF4B40EF0390DAC473424049A12C7C7DD94B40295B24ED4667424049A12C7C7DD94B40
74081	60232	38.879201999999999	38.896844999999999	54.793039	54.765549999999998	Московская	0103000020E61000000100000005000000F549EEB089704340F5B9DA8AFD614B40F549EEB089704340EDB94C4D82654B40624A24D1CB724340EDB94C4D82654B40624A24D1CB724340F5B9DA8AFD614B40F549EEB089704340F5B9DA8AFD614B40
80130	60232	38.886218	38.894967999999999	54.757919000000001	54.752769999999998	Микрорайон-1	0103000020E61000000100000005000000329067976F71434078B471C45A604B40329067976F7143402E02637D03614B40B77BB94F8E7243402E02637D03614B40B77BB94F8E72434078B471C45A604B40329067976F71434078B471C45A604B40
1697	5694	38.089691000000002	38.103299999999997	55.604680999999999	55.598618999999999	улица Дугина	0103000020E610000001000000050000006EDFA3FE7A0B4340D2E1218C9FCC4B406EDFA3FE7A0B43409CC1DF2F66CD4B40A1D634EF380D43409CC1DF2F66CD4B40A1D634EF380D4340D2E1218C9FCC4B406EDFA3FE7A0B4340D2E1218C9FCC4B40
80127	5694	38.113649000000002	38.127814999999998	55.59957	55.595644	Фрунзе	0103000020E610000001000000050000008F1CE90C8C0E4340810706103ECC4B408F1CE90C8C0E4340D4D4B2B5BECC4B401878EE3D5C104340D4D4B2B5BECC4B401878EE3D5C104340810706103ECC4B408F1CE90C8C0E4340810706103ECC4B40
79863	5694	38.068607	38.078687000000002	55.607463000000003	55.602936999999997	Федотова	0103000020E610000001000000050000006AA33A1DC80843403046240A2DCD4B406AA33A1DC8084340D943FB58C1CD4B4068CF656A120A4340D943FB58C1CD4B4068CF656A120A43403046240A2DCD4B406AA33A1DC80843403046240A2DCD4B40
79851	5694	38.121141000000001	38.130105999999998	55.591157000000003	55.588720000000002	Пушкина	0103000020E61000000100000005000000359A5C8C810F434025404D2D5BCB4B40359A5C8C810F434097E65608ABCB4B40B6813B50A710434097E65608ABCB4B40B6813B50A710434025404D2D5BCB4B40359A5C8C810F434025404D2D5BCB4B40
80131	5694	38.134427000000002	38.137867999999997	55.588349000000001	55.587417000000002	Осипенко	0103000020E61000000100000005000000865968E734114340A60EF27A30CB4B40865968E73411434031D120054FCB4B401C959BA8A511434031D120054FCB4B401C959BA8A5114340A60EF27A30CB4B40865968E734114340A60EF27A30CB4B40
74149	5694	38.085963	38.10004	55.606827000000003	55.602113000000003	Молодежная	0103000020E6100000010000000500000041D5E8D5000B43408CBFED0912CD4B4041D5E8D5000B434037AAD381ACCD4B405B25581CCE0C434037AAD381ACCD4B405B25581CCE0C43408CBFED0912CD4B4041D5E8D5000B43408CBFED0912CD4B40
79853	5694	38.10754	38.117269	55.603166000000002	55.598481999999997	Менделеева	0103000020E610000001000000050000008481E7DEC30D4340519FE40E9BCC4B408481E7DEC30D43409207228B34CD4B40D5EAABAB020F43409207228B34CD4B40D5EAABAB020F4340519FE40E9BCC4B408481E7DEC30D4340519FE40E9BCC4B40
71884	5694	38.137374000000001	38.140023999999997	55.586970000000001	55.582644999999999	Лесная	0103000020E610000001000000050000000DA9A27895114340C616821C94CA4B400DA9A27895114340D7DD3CD521CB4B40DA53724EEC114340D7DD3CD521CB4B40DA53724EEC114340C616821C94CA4B400DA9A27895114340C616821C94CA4B40
79862	5694	38.088405999999999	38.091667000000001	55.597999000000002	55.594569999999997	Левченко	0103000020E61000000100000005000000956247E3500B43406397A8DE1ACC4B40956247E3500B43403605323B8BCC4B40AC8F87BEBB0B43403605323B8BCC4B40AC8F87BEBB0B43406397A8DE1ACC4B40956247E3500B43406397A8DE1ACC4B40
80021	5694	38.127411000000002	38.132514	55.589258999999998	55.586039	Комсомольская	0103000020E610000001000000050000004913EF004F1043401C97715303CB4B404913EF004F104340D4EFC2D66CCB4B408E210038F6104340D4EFC2D66CCB4B408E210038F61043401C97715303CB4B404913EF004F1043401C97715303CB4B40
80124	5694	38.127285000000001	38.138694000000001	55.600186000000001	55.594656999999998	Дзержинского	0103000020E61000000100000005000000BC22F8DF4A10434032AB77B81DCC4B40BC22F8DF4A1043402FC214E5D2CC4B40621399B9C01143402FC214E5D2CC4B40621399B9C011434032AB77B81DCC4B40BC22F8DF4A10434032AB77B81DCC4B40
80043	5694	38.087248000000002	38.094641000000003	55.600318000000001	55.595556999999999	Гудкова	0103000020E610000001000000050000001A5245F12A0B4340B2F336363BCC4B401A5245F12A0B43409E996038D7CC4B402DEE3F321D0C43409E996038D7CC4B402DEE3F321D0C4340B2F336363BCC4B401A5245F12A0B4340B2F336363BCC4B40
79843	5694	38.082810000000002	38.090598	55.595832000000001	55.592056999999997	Гризодубовой	0103000020E6100000010000000500000011E4A084990A4340162F1686C8CB4B4011E4A084990A434084F4143944CC4B40A08A1BB7980B434084F4143944CC4B40A08A1BB7980B4340162F1686C8CB4B4011E4A084990A4340162F1686C8CB4B40
72001	5694	38.071266000000001	38.113765999999998	55.611179999999997	55.595644	Гагарина	0103000020E610000001000000050000008BA8893E1F094340810706103ECC4B408BA8893E1F09434011FC6F253BCE4B40C8B260E28F0E434011FC6F253BCE4B40C8B260E28F0E4340810706103ECC4B408BA8893E1F094340810706103ECC4B40
80126	5694	38.069065999999999	38.078687000000002	55.607228999999997	55.604543999999997	Баженова	0103000020E61000000100000005000000FDA19927D70843401B7FA2B261CD4B40FDA19927D708434065170CAEB9CD4B4068CF656A120A434065170CAEB9CD4B4068CF656A120A43401B7FA2B261CD4B40FDA19927D70843401B7FA2B261CD4B40
921	2581	37.942788999999998	37.951988	55.750297000000003	55.750140000000002	улица Юннатов	0103000020E61000000100000005000000A703594FADF84240F2B5679604E04B40A703594FADF84240BAA46ABB09E04B409C1727BEDAF94240BAA46ABB09E04B409C1727BEDAF94240F2B5679604E04B40A703594FADF84240F2B5679604E04B40
881	2581	37.947685	37.959992	55.755378	55.754370000000002	улица Смельчак	0103000020E6100000010000000500000073F4F8BD4DF94240B18A37328FE04B4073F4F8BD4DF94240170FEF39B0E04B40F8359204E1FA4240170FEF39B0E04B40F8359204E1FA4240B18A37328FE04B4073F4F8BD4DF94240B18A37328FE04B40
977	2581	37.965885	37.972344	55.746502	55.745883999999997	улица Свободы	0103000020E610000001000000050000003659A31EA2FB4240094E7D2079DF4B403659A31EA2FB42400533A6608DDF4B401D3BA8C475FC42400533A6608DDF4B401D3BA8C475FC4240094E7D2079DF4B403659A31EA2FB4240094E7D2079DF4B40
1286	2581	38.008347999999998	38.033653999999999	55.74868	55.747540000000001	улица Новая	0103000020E61000000100000005000000567E198C11014340D6390664AFDF4B40567E198C11014340AB9509BFD4DF4B4096B036C64E044340AB9509BFD4DF4B4096B036C64E044340D6390664AFDF4B40567E198C11014340D6390664AFDF4B40
1388	2581	38.017950999999996	38.037643000000003	55.734369000000001	55.726832000000002	улица 1 Мая	0103000020E610000001000000050000001AF7E6374C024340D8D7BAD408DD4B401AF7E6374C0243401E19ABCDFFDD4B4030F65E7CD10443401E19ABCDFFDD4B4030F65E7CD1044340D8D7BAD408DD4B401AF7E6374C024340D8D7BAD408DD4B40
80132	2581	37.959732000000002	37.976906999999997	55.733669999999996	55.724870000000003	микр. Павлино	0103000020E610000001000000050000005C76887FD8FA4240FFEC478AC8DC4B405C76887FD8FA4240350708E6E8DD4B40E21DE0490BFD4240350708E6E8DD4B40E21DE0490BFD4240FFEC478AC8DC4B405C76887FD8FA4240FFEC478AC8DC4B40
80088	2581	37.959732000000002	37.976906999999997	55.733669999999996	55.724870000000003	микр. Павлино	0103000020E610000001000000050000005C76887FD8FA4240FFEC478AC8DC4B405C76887FD8FA4240350708E6E8DD4B40E21DE0490BFD4240350708E6E8DD4B40E21DE0490BFD4240FFEC478AC8DC4B405C76887FD8FA4240FFEC478AC8DC4B40
80118	2581	38.015920999999999	38.022388999999997	55.743335000000002	55.738135	Юбилейная	0103000020E61000000100000005000000E92807B30902434038842A357BDE4B40E92807B309024340707CED9925DF4B4023658BA4DD024340707CED9925DF4B4023658BA4DD02434038842A357BDE4B40E92807B30902434038842A357BDE4B40
80587	2581	38.014161000000001	38.022416	55.747124999999997	55.746532000000002	Школьная	0103000020E6100000010000000500000078F01307D001434070B54E5C8EDF4B4078F01307D00143401283C0CAA1DF4B401D740987DE0243401283C0CAA1DF4B401D740987DE02434070B54E5C8EDF4B4078F01307D001434070B54E5C8EDF4B40
79949	2581	37.946849999999998	37.969802000000001	55.751441999999997	55.749380000000002	Центральная	0103000020E61000000100000005000000DA1B7C6132F94240642310AFEBDF4B40DA1B7C6132F94240A06B5F402FE04B4036CCD07822FC4240A06B5F402FE04B4036CCD07822FC4240642310AFEBDF4B40DA1B7C6132F94240642310AFEBDF4B40
80601	2581	37.947685	37.959992	55.755378	55.754370000000002	Смельчак	0103000020E6100000010000000500000073F4F8BD4DF94240B18A37328FE04B4073F4F8BD4DF94240170FEF39B0E04B40F8359204E1FA4240170FEF39B0E04B40F8359204E1FA4240B18A37328FE04B4073F4F8BD4DF94240B18A37328FE04B40
80588	2581	38.008133000000001	38.008546000000003	55.750819	55.743364999999997	Пролетарская	0103000020E610000001000000050000005A828C800A014340DAFE959526DF4B405A828C800A014340931B45D61AE04B407D410B0918014340931B45D61AE04B407D410B0918014340DAFE959526DF4B405A828C800A014340DAFE959526DF4B40
74143	2581	38.123125999999999	38.140050000000002	55.751908	55.743831	Победы	0103000020E61000000100000005000000C6A4BF97C20F43402060ADDA35DF4B40C6A4BF97C20F4340E6CC76853EE04B4004E78C28ED114340E6CC76853EE04B4004E78C28ED1143402060ADDA35DF4B40C6A4BF97C20F43402060ADDA35DF4B40
80591	2581	38.008546000000003	38.040688000000003	55.743420999999998	55.743335000000002	Пионерская	0103000020E610000001000000050000007D410B0918014340707CED9925DF4B407D410B09180143406E14596B28DF4B407AABAE43350543406E14596B28DF4B407AABAE4335054340707CED9925DF4B407D410B0918014340707CED9925DF4B40
1142	2581	37.986133000000002	38.008133000000001	55.751741000000003	55.750798000000003	Октябрьская улица	0103000020E61000000100000005000000D1402C9B39FE42407CF31B261AE04B40D1402C9B39FE4240FB07910C39E04B405A828C800A014340FB07910C39E04B405A828C800A0143407CF31B261AE04B40D1402C9B39FE42407CF31B261AE04B40
943	2581	37.969802000000001	37.995457999999999	55.751674999999999	55.750377999999998	Носовихинское шоссе	0103000020E6100000010000000500000036CCD07822FC4240A6D1E4620CE04B4036CCD07822FC4240431CEBE236E04B405245F12A6BFF4240431CEBE236E04B405245F12A6BFF4240A6D1E4620CE04B4036CCD07822FC4240A6D1E4620CE04B40
80590	2581	38.008347999999998	38.033653999999999	55.74868	55.747540000000001	Новая	0103000020E61000000100000005000000567E198C11014340D6390664AFDF4B40567E198C11014340AB9509BFD4DF4B4096B036C64E044340AB9509BFD4DF4B4096B036C64E044340D6390664AFDF4B40567E198C11014340D6390664AFDF4B40
80108	2581	37.993239000000003	38.002122999999997	55.750165000000003	55.746972999999997	Некрасова	0103000020E610000001000000050000004E0E9F7422FF42405CFFAECF9CDF4B404E0E9F7422FF42404BCD1E6805E04B40E2C80391450043404BCD1E6805E04B40E2C80391450043405CFFAECF9CDF4B404E0E9F7422FF42405CFFAECF9CDF4B40
74194	2581	38.022101999999997	38.022559999999999	55.748497999999998	55.74335	Колхозная	0103000020E610000001000000050000008D96033DD4024340A5BDC11726DF4B408D96033DD40243408A8F4FC8CEDF4B405019FF3EE30243408A8F4FC8CEDF4B405019FF3EE3024340A5BDC11726DF4B408D96033DD4024340A5BDC11726DF4B40
80594	2581	38.018805	38.034830999999997	55.743395999999997	55.736437000000002	Калинина	0103000020E610000001000000050000002A00C633680243403D484F9143DE4B402A00C6336802434015FDA19927DF4B4088F19A577504434015FDA19927DF4B4088F19A57750443403D484F9143DE4B402A00C633680243403D484F9143DE4B40
80585	2581	37.970762999999998	37.978399000000003	55.749861000000003	55.743482	Заводская	0103000020E610000001000000050000005B9544F641FC424014950D6B2ADF4B405B9544F641FC4240DFC5FB71FBDF4B4035B8AD2D3CFD4240DFC5FB71FBDF4B4035B8AD2D3CFD424014950D6B2ADF4B405B9544F641FC424014950D6B2ADF4B40
79952	2581	37.985988999999996	37.993239000000003	55.750363	55.748660000000001	Жилгородок	0103000020E610000001000000050000009D9B36E334FE424064E94317D4DF4B409D9B36E334FE4240719010E50BE04B404E0E9F7422FF4240719010E50BE04B404E0E9F7422FF424064E94317D4DF4B409D9B36E334FE424064E94317D4DF4B40
1077	2581	37.982010000000002	37.987031000000002	55.751466999999998	55.740679	Граничная улица	0103000020E61000000100000005000000282CF180B2FD4240C0EAC891CEDE4B40282CF180B2FD4240F982161230E04B40B091240857FE4240F982161230E04B40B091240857FE4240C0EAC891CEDE4B40282CF180B2FD4240C0EAC891CEDE4B40
80573	2581	37.982010000000002	37.987031000000002	55.751466999999998	55.740679	Граничная	0103000020E61000000100000005000000282CF180B2FD4240C0EAC891CEDE4B40282CF180B2FD4240F982161230E04B40B091240857FE4240F982161230E04B40B091240857FE4240C0EAC891CEDE4B40282CF180B2FD4240C0EAC891CEDE4B40
80969	2581	37.942932999999996	38.145009000000002	55.766921000000004	55.715743000000003	Гидрогородок	0103000020E61000000100000005000000DAA84E07B2F84240A4AB74779DDB4B40DAA84E07B2F84240CDCEA2772AE24B401650A8A78F124340CDCEA2772AE24B401650A8A78F124340A4AB74779DDB4B40DAA84E07B2F84240A4AB74779DDB4B40
80115	2581	37.942932999999996	38.145009000000002	55.766921000000004	55.715743000000003	1 Мая	0103000020E61000000100000005000000DAA84E07B2F84240A4AB74779DDB4B40DAA84E07B2F84240CDCEA2772AE24B401650A8A78F124340CDCEA2772AE24B401650A8A78F124340A4AB74779DDB4B40DAA84E07B2F84240A4AB74779DDB4B40
80598	61924	39.036811999999998	39.054212	55.388333000000003	55.376646999999998	Софьи Перовской	0103000020E61000000100000005000000D80C7041B6844340799109F835B04B40D80C7041B6844340927A4FE5B4B14B407F86376BF0864340927A4FE5B4B14B407F86376BF0864340799109F835B04B40D80C7041B6844340799109F835B04B40
80091	61924	39.013806000000002	39.054239000000003	55.397382999999998	55.371332000000002	Советская	0103000020E610000001000000050000008A3E1F65C4814340A9FA95CE87AF4B408A3E1F65C4814340417E3672DDB24B407995B54DF1864340417E3672DDB24B407995B54DF1864340A9FA95CE87AF4B408A3E1F65C4814340A9FA95CE87AF4B40
80292	61924	39.02243	39.039650000000002	55.371223999999998	55.366103000000003	Горшкова	0103000020E6100000010000000500000082397AFCDE824340D7FB8D76DCAE4B4082397AFCDE824340C2BE9D4484AF4B40A9A44E4013854340C2BE9D4484AF4B40A9A44E4013854340D7FB8D76DCAE4B4082397AFCDE824340D7FB8D76DCAE4B40
80596	61924	39.058613999999999	39.070193000000003	55.375726	55.369152	1-й микрорайон	0103000020E610000001000000050000003B8BDEA98087434062A06B5F40AF4B403B8BDEA980874340E22021CA17B04B403EB48F15FC884340E22021CA17B04B403EB48F15FC88434062A06B5F40AF4B403B8BDEA98087434062A06B5F40AF4B40
80895	61924	38.992182999999997	39.090989	55.405898999999998	55.355786999999999	1 Мая	0103000020E61000000100000005000000D65240DAFF7E4340C5ABAC6D8AAD4B40D65240DAFF7E4340533D997FF4B34B40DBA50D87A58B4340533D997FF4B34B40DBA50D87A58B4340C5ABAC6D8AAD4B40D65240DAFF7E4340C5ABAC6D8AAD4B40
8056	1343	37.169896999999999	37.187953	56.746583000000001	56.743344999999998	улица Сахарова	0103000020E610000001000000050000002158552FBF9542409352D0ED255F4C402158552FBF954240F25F2008905F4C40B1170AD80E984240F25F2008905F4C40B1170AD80E9842409352D0ED255F4C402158552FBF9542409352D0ED255F4C40
8042	1343	37.164768000000002	37.170408999999999	56.742184999999999	56.734532999999999	улица Понтекорво	0103000020E61000000100000005000000B3B6291E17954240986A662D055E4C40B3B6291E17954240774A07EBFF5E4C40D7F84CF6CF954240774A07EBFF5E4C40D7F84CF6CF954240986A662D055E4C40B3B6291E17954240986A662D055E4C40
7976	1343	37.131117000000003	37.133111	56.757229000000002	56.756577	площадь Космонавтов	0103000020E610000001000000050000008E791D71C8904240F1F3DF83D7604C408E791D71C8904240994A3FE1EC604C4072DEFFC709914240994A3FE1EC604C4072DEFFC709914240F1F3DF83D7604C408E791D71C8904240F1F3DF83D7604C40
71865	1343	37.124236000000003	37.164732000000001	56.763061	56.75488	Центральная	0103000020E61000000100000005000000317E1AF7E68F4240C63368E89F604C40317E1AF7E68F424031ED9BFBAB614C40664D2CF01595424031ED9BFBAB614C40664D2CF015954240C63368E89F604C40317E1AF7E68F4240C63368E89F604C40
80030	1343	37.189866000000002	37.195867	56.749214000000002	56.745531999999997	Флерова	0103000020E61000000100000005000000A94F72874D9842408C0FB3976D5F4C40A94F72874D98424049DA8D3EE65F4C40CDAE7B2B1299424049DA8D3EE65F4C40CDAE7B2B129942408C0FB3976D5F4C40A94F72874D9842408C0FB3976D5F4C40
80880	1343	37.218719999999998	37.232796999999998	56.7453	56.739663	Университетская	0103000020E61000000100000005000000957D5704FF9B4240D787F546AD5E4C40957D5704FF9B4240BADA8AFD655F4C40AFCDC64ACC9D4240BADA8AFD655F4C40AFCDC64ACC9D4240D787F546AD5E4C40957D5704FF9B4240D787F546AD5E4C40
80044	1343	37.119385000000001	37.143405999999999	56.763598000000002	56.758896	Тверская	0103000020E610000001000000050000000551F701488F424059880E8123614C400551F701488F424040A54A94BD614C406C06B8205B92424040A54A94BD614C406C06B8205B92424059880E8123614C400551F701488F424059880E8123614C40
71936	1343	37.153826000000002	37.158757999999999	56.733742999999997	56.730167999999999	Попова	0103000020E6100000010000000500000023A30392B0934240F94A2025765D4C4023A30392B09342409F55664AEB5D4C403BFDA02E529442409F55664AEB5D4C403BFDA02E52944240F94A2025765D4C4023A30392B0934240F94A2025765D4C40
71878	1343	37.1325	37.141061000000001	56.756354999999999	56.742609999999999	Ленина	0103000020E61000000100000005000000295C8FC2F59042405ED72FD80D5F4C40295C8FC2F590424042959A3DD0604C40DBDE6E490E92424042959A3DD0604C40DBDE6E490E9242405ED72FD80D5F4C40295C8FC2F59042405ED72FD80D5F4C40
79938	1343	37.129877	37.157463999999997	56.759014999999998	56.753666000000003	Карла Маркса	0103000020E6100000010000000500000055C03DCF9F904240B70DA32078604C4055C03DCF9F90424033164D6727614C400F26C5C72794424033164D6727614C400F26C5C727944240B70DA32078604C4055C03DCF9F904240B70DA32078604C40
79940	1343	37.176167	37.177253999999998	56.742516000000002	56.741647	Дачный проезд	0103000020E6100000010000000500000035D1E7A38C9642409816F549EE5E4C4035D1E7A38C964240DD60A8C30A5F4C40E78A5242B0964240DD60A8C30A5F4C40E78A5242B09642409816F549EE5E4C4035D1E7A38C9642409816F549EE5E4C40
80558	1343	37.186596999999999	37.199452000000001	56.754998000000001	56.748054000000003	Векслера	0103000020E610000001000000050000000F441669E29742402DD2C43BC05F4C400F441669E2974240D04543C6A3604C40978FA4A487994240D04543C6A3604C40978FA4A4879942402DD2C43BC05F4C400F441669E29742402DD2C43BC05F4C40
80561	1343	37.191941999999997	37.199154999999998	56.751282000000003	56.747802999999998	Блохинцева	0103000020E610000001000000050000004A5D328E91984240E36C3A02B85F4C404A5D328E91984240680932022A604C40DDEA39E97D994240680932022A604C40DDEA39E97D994240E36C3A02B85F4C404A5D328E91984240E36C3A02B85F4C40
71927	1343	37.101832000000002	37.256377999999998	56.783060999999996	56.698245	Алея Высоцкого	0103000020E61000000100000005000000D8D7BAD4088D42403ACC971760594C40D8D7BAD4088D4240F3E2C4573B644C40FAB48AFED0A04240F3E2C4573B644C40FAB48AFED0A042403ACC971760594C40D8D7BAD4088D42403ACC971760594C40
80560	1343	37.202675999999997	37.207814999999997	56.756582000000002	56.752417000000001	Академика Балдина	0103000020E6100000010000000500000090D78349F19942402BFA43334F604C4090D78349F1994240035FD1ADD7604C40224F92AE999A4240035FD1ADD7604C40224F92AE999A42402BFA43334F604C4090D78349F19942402BFA43334F604C40
7478	4639	37.726061999999999	37.732053999999998	55.441049999999997	55.432699	улица Текстильщиков	0103000020E61000000100000005000000266F8099EFDC424086014BAE62B74B40266F8099EFDC42404DF38E5374B84B40F7730AF2B3DD42404DF38E5374B84B40F7730AF2B3DD424086014BAE62B74B40266F8099EFDC424086014BAE62B74B40
7357	4639	37.735216000000001	37.762937999999998	55.451858999999999	55.449317000000001	улица Гагарина	0103000020E610000001000000050000007BBFD18E1BDE4240B7442E3883B94B407BBFD18E1BDE42409EB30584D6B94B401570CFF3A7E142409EB30584D6B94B401570CFF3A7E14240B7442E3883B94B407BBFD18E1BDE4240B7442E3883B94B40
71789	4639	37.508912000000002	38.036223	55.588664000000001	55.288879999999999	пос.ГПЗ Константиново	0103000020E610000001000000050000005F45460724C14240F73B1405FAA44B405F45460724C14240912A8A5759CB4B40772E8CF4A2044340912A8A5759CB4B40772E8CF4A2044340F73B1405FAA44B405F45460724C14240F73B1405FAA44B40
71885	4639	37.636814000000001	38.164124999999999	55.564027000000003	55.264054999999999	пл.Гагарина	0103000020E6100000010000000500000046D1031F83D1424032ACE28DCCA14B4046D1031F83D14240CF87670932C84B405EBA490C02154340CF87670932C84B405EBA490C0215434032ACE28DCCA14B4046D1031F83D1424032ACE28DCCA14B40
80769	4639	37.733840999999998	37.748204999999999	55.444206000000001	55.441989	Южная	0103000020E6100000010000000500000062BB7B80EEDD42408B18761893B84B4062BB7B80EEDD4240EF5701BEDBB84B4012DA722EC5DF4240EF5701BEDBB84B4012DA722EC5DF42408B18761893B84B4062BB7B80EEDD42408B18761893B84B40
67099	4639	37.508912000000002	38.036223	55.588664000000001	55.288879999999999	Ю.Корнеева	0103000020E610000001000000050000005F45460724C14240F73B1405FAA44B405F45460724C14240912A8A5759CB4B40772E8CF4A2044340912A8A5759CB4B40772E8CF4A2044340F73B1405FAA44B405F45460724C14240F73B1405FAA44B40
71766	4639	37.836860000000001	37.844217	55.417189	55.416417000000003	Чкалова	0103000020E6100000010000000500000050AA7D3A1EEB4240CD3FFA264DB54B4050AA7D3A1EEB42401FA0FB7266B54B4016DD7A4D0FEC42401FA0FB7266B54B4016DD7A4D0FEC4240CD3FFA264DB54B4050AA7D3A1EEB4240CD3FFA264DB54B40
16867	4639	37.753172999999997	37.758572000000001	55.452936999999999	55.442315999999998	Центральная улица	0103000020E61000000100000005000000779D0DF967E04240AF3F89CF9DB84B40779D0DF967E04240FD12F1D6F9B94B40A6D425E318E14240FD12F1D6F9B94B40A6D425E318E14240AF3F89CF9DB84B40779D0DF967E04240AF3F89CF9DB84B40
79918	4639	37.765892999999998	37.773484000000003	55.424306000000001	55.418756999999999	Талалихина	0103000020E610000001000000050000001F9E25C808E242404CFC51D499B54B401F9E25C808E2424090BFB4A84FB64B4059FD118601E3424090BFB4A84FB64B4059FD118601E342404CFC51D499B54B401F9E25C808E242404CFC51D499B54B40
7327	4639	37.726134000000002	37.771965999999999	55.445487	55.439165000000003	Советская улица	0103000020E61000000100000005000000C0417BF5F1DC42402046088F36B84B40C0417BF5F1DC424086E5CFB705B94B40DDCF29C8CFE2424086E5CFB705B94B40DDCF29C8CFE242402046088F36B84B40C0417BF5F1DC42402046088F36B84B40
80190	4639	37.726134000000002	37.771965999999999	55.445487	55.439165000000003	Советская	0103000020E61000000100000005000000C0417BF5F1DC42402046088F36B84B40C0417BF5F1DC424086E5CFB705B94B40DDCF29C8CFE2424086E5CFB705B94B40DDCF29C8CFE242402046088F36B84B40C0417BF5F1DC42402046088F36B84B40
80552	4639	37.758563000000002	37.767105999999998	55.441377000000003	55.421475999999998	Рабочая	0103000020E61000000100000005000000537AA69718E142404206F2ECF2B54B40537AA69718E14240721AA20A7FB84B405E48878730E24240721AA20A7FB84B405E48878730E242404206F2ECF2B54B40537AA69718E142404206F2ECF2B54B40
79928	4639	37.749167	37.755795999999997	55.423805999999999	55.423473000000001	Парковая	0103000020E61000000100000005000000081F4AB4E4DF424098DEFE5C34B64B40081F4AB4E4DF42409EEC66463FB64B404B395FECBDE042409EEC66463FB64B404B395FECBDE0424098DEFE5C34B64B40081F4AB4E4DF424098DEFE5C34B64B40
81106	4639	\N	\N	\N	\N	Новая 	\N
71767	4639	37.508912000000002	38.036223	55.588664000000001	55.288879999999999	Луговая	0103000020E610000001000000050000005F45460724C14240F73B1405FAA44B405F45460724C14240912A8A5759CB4B40772E8CF4A2044340912A8A5759CB4B40772E8CF4A2044340F73B1405FAA44B405F45460724C14240F73B1405FAA44B40
80035	4639	37.733994000000003	37.742842000000003	55.453529000000003	55.452012000000003	Ломоносова	0103000020E61000000100000005000000E9BAF083F3DD424025B37A87DBB94B40E9BAF083F3DD4240D064FF3C0DBA4B40310C587215DF4240D064FF3C0DBA4B40310C587215DF424025B37A87DBB94B40E9BAF083F3DD424025B37A87DBB94B40
71809	4639	37.771965999999999	37.780526999999999	55.439165000000003	55.421439999999997	Корнеева	0103000020E61000000100000005000000DDCF29C8CFE24240F59CF4BEF1B54B40DDCF29C8CFE242402046088F36B84B408F52094FE8E342402046088F36B84B408F52094FE8E34240F59CF4BEF1B54B40DDCF29C8CFE24240F59CF4BEF1B54B40
80554	4639	37.755876999999998	37.773834000000001	55.434446000000001	55.430349999999997	Коломийца	0103000020E610000001000000050000003866D993C0E04240B3EA73B515B74B403866D993C0E0424063F030ED9BB74B40354415FE0CE3424063F030ED9BB74B40354415FE0CE34240B3EA73B515B74B403866D993C0E04240B3EA73B515B74B40
7393	4639	37.739069999999998	37.783419000000002	55.476761000000003	55.410299999999999	Каширское шоссе	0103000020E6100000010000000500000034BA83D899DE42403FC6DCB584B44B4034BA83D899DE42400F81238106BD4B405308E41247E442400F81238106BD4B405308E41247E442403FC6DCB584B44B4034BA83D899DE42403FC6DCB584B44B40
74060	4639	37.747469000000002	37.763908000000001	55.373362	55.367597000000004	Заборье	0103000020E610000001000000050000000DE36E10ADDF4240CA8D226B0DAF4B400DE36E10ADDF4240DAC87553CAAF4B408E93C2BCC7E14240DAC87553CAAF4B408E93C2BCC7E14240CA8D226B0DAF4B400DE36E10ADDF4240CA8D226B0DAF4B40
80264	4639	37.831631999999999	37.845475	55.413024	55.412058000000002	Жуковского	0103000020E610000001000000050000004E27D9EA72EA424010070951BEB44B404E27D9EA72EA4240473B6EF8DDB44B40F54A598638EC4240473B6EF8DDB44B40F54A598638EC424010070951BEB44B404E27D9EA72EA424010070951BEB44B40
80074	4639	37.751421000000001	37.771965999999999	55.440416999999997	55.438343000000003	Горького	0103000020E61000000100000005000000894336902EE042401CB7989F1BB84B40894336902EE042401CCD91955FB84B40DDCF29C8CFE242401CCD91955FB84B40DDCF29C8CFE242401CB7989F1BB84B40894336902EE042401CB7989F1BB84B40
4024	4639	37.772064999999998	37.775308000000003	55.434047999999997	55.429701000000001	Восточная улица	0103000020E6100000010000000500000070B1A206D3E242407D073F7100B74B4070B1A206D3E24240757286E28EB74B40E129E44A3DE34240757286E28EB74B40E129E44A3DE342407D073F7100B74B4070B1A206D3E242407D073F7100B74B40
80753	4639	37.508912000000002	38.036223	55.588664000000001	55.288879999999999	Агрохимиков	0103000020E610000001000000050000005F45460724C14240F73B1405FAA44B405F45460724C14240912A8A5759CB4B40772E8CF4A2044340912A8A5759CB4B40772E8CF4A2044340F73B1405FAA44B405F45460724C14240F73B1405FAA44B40
72272	4639	37.508912000000002	38.036223	55.588664000000001	55.288879999999999	Авенариуса	0103000020E610000001000000050000005F45460724C14240F73B1405FAA44B405F45460724C14240912A8A5759CB4B40772E8CF4A2044340912A8A5759CB4B40772E8CF4A2044340F73B1405FAA44B405F45460724C14240F73B1405FAA44B40
7367	4639	37.742241	37.764024999999997	55.449734999999997	55.447678000000003	3-й Московский проезд	0103000020E610000001000000050000000B60CAC001DF4240C19140834DB94B400B60CAC001DF4240EB6E9EEA90B94B40C7293A92CBE14240EB6E9EEA90B94B40C7293A92CBE14240C19140834DB94B400B60CAC001DF4240C19140834DB94B40
7332	4639	37.744045999999997	37.746561	55.450654	55.443413999999997	2-я Коммунистическая улица	0103000020E610000001000000050000001C5C3AE63CDF4240554B3ACAC1B84B401C5C3AE63CDF4240E2E7BF07AFB94B400ABC934F8FDF4240E2E7BF07AFB94B400ABC934F8FDF4240554B3ACAC1B84B401C5C3AE63CDF4240554B3ACAC1B84B40
71992	4639	37.508912000000002	38.036223	55.588664000000001	55.288879999999999	2-ая Московская	0103000020E610000001000000050000005F45460724C14240F73B1405FAA44B405F45460724C14240912A8A5759CB4B40772E8CF4A2044340912A8A5759CB4B40772E8CF4A2044340F73B1405FAA44B405F45460724C14240F73B1405FAA44B40
7341	4639	37.747244000000002	37.749535000000002	55.450997000000001	55.443001000000002	1-я Коммунистическая улица	0103000020E61000000100000005000000ED10FFB0A5DF4240338CBB41B4B84B40ED10FFB0A5DF42400CCC0A45BAB94B408B1A4CC3F0DF42400CCC0A45BAB94B408B1A4CC3F0DF4240338CBB41B4B84B40ED10FFB0A5DF4240338CBB41B4B84B40
80815	4639	37.739285000000002	37.759695000000001	55.446075	55.442740000000001	1-й Московский проезд	0103000020E6100000010000000500000031B610E4A0DE4240C6504EB4ABB84B4031B610E4A0DE4240174850FC18B94B40A5F78DAF3DE14240174850FC18B94B40A5F78DAF3DE14240C6504EB4ABB84B4031B610E4A0DE4240C6504EB4ABB84B40
7215	10881	37.491449000000003	37.506270999999998	55.948906000000001	55.947217000000002	проспект Пацаева	0103000020E61000000100000005000000725303CDE7BE42408D9B1A683EF94B40725303CDE7BE4240357D76C075F94B40E4F4F57CCDC04240357D76C075F94B40E4F4F57CCDC042408D9B1A683EF94B40725303CDE7BE42408D9B1A683EF94B40
6944	10881	37.513528999999998	37.515551000000002	55.933886999999999	55.932864000000002	площадь Собина	0103000020E6100000010000000500000017467A51BBC14240D1CE691668F74B4017467A51BBC142406C94F59B89F74B40C6353E93FDC142406C94F59B89F74B40C6353E93FDC14240D1CE691668F74B4017467A51BBC14240D1CE691668F74B40
16863	10881	37.497818000000002	37.500458999999999	55.975959000000003	55.974907000000002	Южная улица	0103000020E6100000010000000500000019AE0E80B8BF42401CD2A8C0C9FC4B4019AE0E80B8BF4240529E7939ECFC4B4093FE5E0A0FC04240529E7939ECFC4B4093FE5E0A0FC042401CD2A8C0C9FC4B4019AE0E80B8BF42401CD2A8C0C9FC4B40
80202	10881	37.511417999999999	37.516674000000002	55.941223000000001	55.930861999999998	Циолковского	0103000020E61000000100000005000000F94A202576C14240698B6B7C26F74B40F94A202576C142401B9FC9FE79F84B40C558A65F22C242401B9FC9FE79F84B40C558A65F22C24240698B6B7C26F74B40F94A202576C14240698B6B7C26F74B40
80546	10881	37.506397	37.508077	55.960593000000003	55.958714000000001	Флотская 	0103000020E6100000010000000500000071E5EC9DD1C04240D21BEE23B7FA4B4071E5EC9DD1C042401EE21FB6F4FA4B40C66CC9AA08C142401EE21FB6F4FA4B40C66CC9AA08C14240D21BEE23B7FA4B4071E5EC9DD1C04240D21BEE23B7FA4B40
80225	10881	37.498429000000002	37.501043000000003	55.951199000000003	55.938229	Спортивная 	0103000020E6100000010000000500000062307F85CCBF424053944BE317F84B4062307F85CCBF4240747E8AE3C0F94B40E371512D22C04240747E8AE3C0F94B40E371512D22C0424053944BE317F84B4062307F85CCBF424053944BE317F84B40
80037	10881	37.498429000000002	37.501043000000003	55.951199000000003	55.938229	Спортивная	0103000020E6100000010000000500000062307F85CCBF424053944BE317F84B4062307F85CCBF4240747E8AE3C0F94B40E371512D22C04240747E8AE3C0F94B40E371512D22C0424053944BE317F84B4062307F85CCBF424053944BE317F84B40
71955	10881	37.515352999999998	37.519539000000002	55.934134	55.933469000000002	Советская	0103000020E610000001000000050000009F724C16F7C14240386A85E97BF74B409F724C16F7C14240740AF2B391F74B408FFF024180C24240740AF2B391F74B408FFF024180C24240386A85E97BF74B409F724C16F7C14240386A85E97BF74B40
80027	10881	37.515631999999997	37.526150999999999	55.941889000000003	55.920814999999997	Первомайская	0103000020E61000000100000005000000B262B83A00C2424047551344DDF54B40B262B83A00C2424028BB99D18FF84B40FCE07CEA58C3424028BB99D18FF84B40FCE07CEA58C3424047551344DDF54B40B262B83A00C2424047551344DDF54B40
80040	10881	37.511606999999998	37.515774999999998	55.945216000000002	55.937078999999997	Октябрьская	0103000020E61000000100000005000000CCB392567CC142405A626534F2F74B40CCB392567CC14240F6D37FD6FCF84B40158C4AEA04C24240F6D37FD6FCF84B40158C4AEA04C242405A626534F2F74B40CCB392567CC142405A626534F2F74B40
7141	10881	37.491736000000003	37.510753999999999	55.939397999999997	55.937911	Новый бульвар	0103000020E6100000010000000500000008228B34F1BE424082C7B7770DF84B4008228B34F1BE4240C2F693313EF84B408D26176360C14240C2F693313EF84B408D26176360C1424082C7B7770DF84B4008228B34F1BE424082C7B7770DF84B40
5831	10881	37.514921999999999	37.527804000000003	55.945796000000001	55.922908	Московское шоссе	0103000020E61000000100000005000000D6FECEF6E8C14240BF9B6ED921F64B40D6FECEF6E8C142400458E4D70FF94B405859DB148FC342400458E4D70FF94B405859DB148FC34240BF9B6ED921F64B40D6FECEF6E8C14240BF9B6ED921F64B40
74142	10881	37.484658000000003	37.491745000000002	55.946229000000002	55.937981999999998	Молодежная улица	0103000020E6100000010000000500000055DFF94509BE42404B1E4FCB0FF84B4055DFF94509BE42406EC328081EF94B405B7C0A80F1BE42406EC328081EF94B405B7C0A80F1BE42404B1E4FCB0FF84B4055DFF94509BE42404B1E4FCB0FF84B40
7148	10881	37.485340000000001	37.495230999999997	55.953280999999997	55.896594999999998	Лихачевское шоссе	0103000020E6100000010000000500000067B8019F1FBE4240E960FD9FC3F24B4067B8019F1FBE4240F7729F1C05FA4B40917BBABA63BF4240F7729F1C05FA4B40917BBABA63BF4240E960FD9FC3F24B4067B8019F1FBE4240E960FD9FC3F24B40
16864	10881	37.500458999999999	37.504734999999997	55.975409999999997	55.963642	Ленинградская улица	0103000020E6100000010000000500000093FE5E0A0FC04240A986FD9E58FB4B4093FE5E0A0FC042407E18213CDAFC4B40C2120F289BC042407E18213CDAFC4B40C2120F289BC04240A986FD9E58FB4B4093FE5E0A0FC04240A986FD9E58FB4B40
6922	10881	37.516674000000002	37.522306	55.931507000000003	55.930680000000002	Институтский переулок	0103000020E61000000100000005000000C558A65F22C242404985B18520F74B40C558A65F22C242405F7F129F3BF74B4096404AECDAC242405F7F129F3BF74B4096404AECDAC242404985B18520F74B40C558A65F22C242404985B18520F74B40
80204	10881	37.506270999999998	37.513052999999999	55.947217000000002	55.934407	Дирижабельная	0103000020E61000000100000005000000E4F4F57CCDC04240A51309A69AF74B40E4F4F57CCDC042408D9B1A683EF94B40AE0E80B8ABC142408D9B1A683EF94B40AE0E80B8ABC14240A51309A69AF74B40E4F4F57CCDC04240A51309A69AF74B40
74115	10881	37.489032000000002	37.489139999999999	55.949061999999998	55.946260000000002	Гранитная	0103000020E610000001000000050000004759BF9998BE4240A9C1340C1FF94B404759BF9998BE42402CF015DD7AF94B402D95B7239CBE42402CF015DD7AF94B402D95B7239CBE4240A9C1340C1FF94B404759BF9998BE4240A9C1340C1FF94B40
80160	10881	37.503315999999998	37.507618999999998	55.944595999999997	55.938284000000003	Академика Лаврентьева	0103000020E61000000100000005000000DAC69FA86CC04240172EABB019F84B40DAC69FA86CC0424059F78F85E8F84B4003EACDA8F9C0424059F78F85E8F84B4003EACDA8F9C04240172EABB019F84B40DAC69FA86CC04240172EABB019F84B40
80801	10881	37.451447000000002	37.536526000000002	55.996535000000002	55.897058999999999	25 -го съезда	0103000020E610000001000000050000004C70EA03C9B942408ECA4DD4D2F24B404C70EA03C9B94240E12879758EFF4B4013BA4BE2ACC44240E12879758EFF4B4013BA4BE2ACC442408ECA4DD4D2F24B404C70EA03C9B942408ECA4DD4D2F24B40
80854	60253	37.528638999999998	37.541943000000003	56.359439000000002	56.353929000000001	микрорайон Махалина	0103000020E61000000100000005000000F0315871AAC34240910DA48B4D2D4C40F0315871AAC3424017F4DE18022E4C40E8A562635EC5424017F4DE18022E4C40E8A562635EC54240910DA48B4D2D4C40F0315871AAC34240910DA48B4D2D4C40
80843	60253	37.490397999999999	37.504734999999997	56.357385000000001	56.350636999999999	Старо-Рогачевская 	0103000020E610000001000000050000000C03965CC5BE42403FE257ACE12C4C400C03965CC5BE42405D8AABCABE2D4C40C2120F289BC042405D8AABCABE2D4C40C2120F289BC042403FE257ACE12C4C400C03965CC5BE42403FE257ACE12C4C40
74213	60253	37.518300000000004	37.531207999999999	56.381041000000003	56.345913000000003	Профессиональная	0103000020E6100000010000000500000027C286A757C2424071218FE0462C4C4027C286A757C24240B3B794F3C5304C40D1AFAD9FFEC34240B3B794F3C5304C40D1AFAD9FFEC3424071218FE0462C4C4027C286A757C2424071218FE0462C4C40
81022	60253	37.530678000000002	37.533265	56.345624000000001	56.342984000000001	Больничная	0103000020E61000000100000005000000755AB741EDC34240908653E6E62B4C40755AB741EDC342403A5B40683D2C4C40FC8C0B0742C442403A5B40683D2C4C40FC8C0B0742C44240908653E6E62B4C40755AB741EDC34240908653E6E62B4C40
5925	22061	37.852077999999999	37.861410999999997	55.629516000000002	55.625714000000002	улица Лермонтова	0103000020E610000001000000050000000FD253E410ED42401E53776517D04B400FD253E410ED42408527F4FA93D04B4013B534B742EE42408527F4FA93D04B4013B534B742EE42401E53776517D04B400FD253E410ED42401E53776517D04B40
5888	22061	37.843283	37.846167000000001	55.636609999999997	55.635432000000002	проезд Пушкина	0103000020E61000000100000005000000EA2285B2F0EB42407B6AF5D555D14B40EA2285B2F0EB42403D27BD6F7CD14B402BFA43334FEC42403D27BD6F7CD14B402BFA43334FEC42407B6AF5D555D14B40EA2285B2F0EB42407B6AF5D555D14B40
80016	22061	37.841864000000001	37.846867000000003	55.632382	55.630324000000002	Школьная	0103000020E6100000010000000500000002D71533C2EB424024F1F274AED04B4002D71533C2EB42401F4AB4E4F1D04B40E4874A2366EC42401F4AB4E4F1D04B40E4874A2366EC424024F1F274AED04B4002D71533C2EB424024F1F274AED04B40
80529	22061	37.841576000000003	37.866388000000001	55.639552000000002	55.629562	Угрешская	0103000020E610000001000000050000009C8C2AC3B8EB4240F566D47C95D04B409C8C2AC3B8EB4240B30B06D7DCD14B40CCD24ECDE5EE4240B30B06D7DCD14B40CCD24ECDE5EE4240F566D47C95D04B409C8C2AC3B8EB4240F566D47C95D04B40
80533	22061	37.860962000000001	37.867421	55.629368999999997	55.624861000000003	Томилинская	0103000020E61000000100000005000000A48CB80034EE4240DFC5FB71FBCF4B40A48CB80034EE4240E00ED4298FD04B408B6EBDA607EF4240E00ED4298FD04B408B6EBDA607EF4240DFC5FB71FBCF4B40A48CB80034EE4240DFC5FB71FBCF4B40
80033	22061	37.844225999999999	37.852077999999999	55.626750999999999	55.625515999999998	Спортивная	0103000020E610000001000000050000006937FA980FEC4240F78F85E810D04B406937FA980FEC42401EDE736039D04B400FD253E410ED42401EDE736039D04B400FD253E410ED4240F78F85E810D04B406937FA980FEC4240F78F85E810D04B40
79888	22061	37.849221	37.882593	55.630716	55.622100000000003	Лесная	0103000020E61000000100000005000000C8091346B3EC4240BA6B09F9A0CF4B40C8091346B3EC42402F88484DBBD04B40DA56B3CEF8F042402F88484DBBD04B40DA56B3CEF8F04240BA6B09F9A0CF4B40C8091346B3EC4240BA6B09F9A0CF4B40
80540	22061	37.852077999999999	37.861410999999997	55.629516000000002	55.625714000000002	Лермонтова	0103000020E610000001000000050000000FD253E410ED42401E53776517D04B400FD253E410ED42408527F4FA93D04B4013B534B742EE42408527F4FA93D04B4013B534B742EE42401E53776517D04B400FD253E410ED42401E53776517D04B40
80169	61926	37.123148999999998	37.126913000000002	55.854864999999997	55.853318999999999	Ленина	0103000020E610000001000000050000007EC4AF58C38F42401807978E39ED4B407EC4AF58C38F42405DBF60376CED4B40F83768AF3E9042405DBF60376CED4B40F83768AF3E9042401807978E39ED4B407EC4AF58C38F42401807978E39ED4B40
80103	61926	37.111362999999997	37.127065000000002	55.861412999999999	55.856861000000002	Гагарина	0103000020E61000000100000005000000027E8D24418E4240E31B0A9FADED4B40027E8D24418E4240B4ACFBC742EE4B40AEBB79AA43904240B4ACFBC742EE4B40AEBB79AA43904240E31B0A9FADED4B40027E8D24418E4240E31B0A9FADED4B40
80718	61956	38.793314000000002	38.823498000000001	54.966566	54.948090999999998	Центральная	0103000020E61000000100000005000000BFBA2A508B654340E350BF0B5B794B40BFBA2A508B65434078B6476FB87B4B402429E9616869434078B6476FB87B4B402429E96168694340E350BF0B5B794B40BFBA2A508B654340E350BF0B5B794B40
79902	61895	38.672795999999998	38.673838000000003	55.323413000000002	55.322727	площадь Ленина	0103000020E610000001000000050000009770E82D1E564340A2444B1E4FA94B409770E82D1E564340F60CE19865A94B40AA66D65240564340F60CE19865A94B40AA66D65240564340A2444B1E4FA94B409770E82D1E564340A2444B1E4FA94B40
80496	61895	38.753653999999997	38.771053999999999	55.253993999999999	55.251983000000003	Чапаева	0103000020E61000000100000005000000F23FF9BB77604340F1129CFA40A04B40F23FF9BB77604340ABB019E082A04B4099B9C0E5B1624340ABB019E082A04B4099B9C0E5B1624340F1129CFA40A04B40F23FF9BB77604340F1129CFA40A04B40
80396	61895	38.650221999999999	38.657516000000001	55.307808000000001	55.306911999999997	Цесиса	0103000020E61000000100000005000000E29178793A534340FE5F75E448A74B40E29178793A5343403DB9A64066A74B40624CFA7B295443403DB9A64066A74B40624CFA7B29544340FE5F75E448A74B40E29178793A534340FE5F75E448A74B40
80458	61895	38.655737000000002	38.669013999999997	55.326332999999998	55.321266999999999	Менделеева	0103000020E610000001000000050000007AE3A430EF5343405B24ED461FA94B407AE3A430EF534340834D9D47C5A94B4077483140A2554340834D9D47C5A94B4077483140A25543405B24ED461FA94B407AE3A430EF5343405B24ED461FA94B40
80551	61895	38.635804	38.784080000000003	55.360202999999998	55.236519000000001	Маркина	0103000020E610000001000000050000003F55850662514340FAF02C41469E4B403F55850662514340E675C4211BAE4B404EB9C2BB5C644340E675C4211BAE4B404EB9C2BB5C644340FAF02C41469E4B403F55850662514340FAF02C41469E4B40
80484	61895	38.759222999999999	38.765332000000001	55.253137000000002	55.246583999999999	Карла Маркса	0103000020E610000001000000050000007DAF21382E614340C2DB8310909F4B407DAF21382E6143402B3410CB66A04B40884A2366F66143402B3410CB66A04B40884A2366F6614340C2DB8310909F4B407DAF21382E614340C2DB8310909F4B40
80007	61895	38.759222999999999	38.765332000000001	55.253137000000002	55.246583999999999	Карла Маркса	0103000020E610000001000000050000007DAF21382E614340C2DB8310909F4B407DAF21382E6143402B3410CB66A04B40884A2366F66143402B3410CB66A04B40884A2366F6614340C2DB8310909F4B407DAF21382E614340C2DB8310909F4B40
80448	61895	38.646152000000001	38.662547000000004	55.316774000000002	55.310104000000003	Кагана	0103000020E610000001000000050000005C1FD61BB5524340ED2DE57CB1A74B405C1FD61BB55243408F1CE90C8CA84B400E881057CE5443408F1CE90C8CA84B400E881057CE544340ED2DE57CB1A74B405C1FD61BB5524340ED2DE57CB1A74B40
80153	61890	35.945951000000001	35.951000000000001	56.045569	56.041882999999999	Катукова	0103000020E610000001000000050000002B4F20EC14F9414012A1116C5C054C402B4F20EC14F94140105B7A34D5054C407D3F355EBAF94140105B7A34D5054C407D3F355EBAF9414012A1116C5C054C402B4F20EC14F9414012A1116C5C054C40
79874	61890	35.926036000000003	35.936976999999999	56.008051999999999	55.994990000000001	Волоколамская	0103000020E610000001000000050000009775FF5888F641406CEC12D55BFF4B409775FF5888F641406D5512D907014C40560DC2DCEEF741406D5512D907014C40560DC2DCEEF741406CEC12D55BFF4B409775FF5888F641406CEC12D55BFF4B40
74205	60269	37.171827999999998	37.210994999999997	55.693007999999999	55.677447999999998	Спортивная	0103000020E61000000100000005000000BF44BC75FE954240CC5EB69DB6D64B40BF44BC75FE954240E5EE737CB4D84B404C4F58E2019B4240E5EE737CB4D84B404C4F58E2019B4240CC5EB69DB6D64B40BF44BC75FE954240CC5EB69DB6D64B40
80534	60269	37.171827999999998	37.210994999999997	55.693007999999999	55.677447999999998	Лесная	0103000020E61000000100000005000000BF44BC75FE954240CC5EB69DB6D64B40BF44BC75FE954240E5EE737CB4D84B404C4F58E2019B4240E5EE737CB4D84B404C4F58E2019B4240CC5EB69DB6D64B40BF44BC75FE954240CC5EB69DB6D64B40
71947	59566	37.171827999999998	37.210994999999997	55.693007999999999	55.677447999999998	мкр. Школьный	0103000020E61000000100000005000000BF44BC75FE954240CC5EB69DB6D64B40BF44BC75FE954240E5EE737CB4D84B404C4F58E2019B4240E5EE737CB4D84B404C4F58E2019B4240CC5EB69DB6D64B40BF44BC75FE954240CC5EB69DB6D64B40
80512	59566	37.171827999999998	37.210994999999997	55.693007999999999	55.677447999999998	Маршала Жукова	0103000020E61000000100000005000000BF44BC75FE954240CC5EB69DB6D64B40BF44BC75FE954240E5EE737CB4D84B404C4F58E2019B4240E5EE737CB4D84B404C4F58E2019B4240CC5EB69DB6D64B40BF44BC75FE954240CC5EB69DB6D64B40
80324	61935	37.722459999999998	37.722999000000002	55.547387000000001	55.543644	Ольховая 	0103000020E610000001000000050000008655BC9179DC42405455682096C54B408655BC9179DC4240B6A0F7C610C64B403605323B8BDC4240B6A0F7C610C64B403605323B8BDC42405455682096C54B408655BC9179DC42405455682096C54B40
80633	61946	36.184068000000003	36.185164	55.344822999999998	55.342114000000002	Советская площадь	0103000020E61000000100000005000000BD1E4C8A8F1742407BC03C64CAAB4B40BD1E4C8A8F1742404DF4F92823AC4B40C2323674B31742404DF4F92823AC4B40C2323674B31742407BC03C64CAAB4B40BD1E4C8A8F1742407BC03C64CAAB4B40
37279	13981	38.196986000000003	38.304792999999997	55.442678999999998	55.396237999999997	площадь Тимофеева	0103000020E610000001000000050000008BE255D6361943405AB741EDB7B24B408BE255D63619434020D099B4A9B84B405D86FF740327434020D099B4A9B84B405D86FF74032743405AB741EDB7B24B408BE255D6361943405AB741EDB7B24B40
80464	13981	38.283079999999998	38.291514999999997	55.421633999999997	55.416007999999998	Строительная	0103000020E610000001000000050000006A1327F73B244340EB6F09C03FB54B406A1327F73B244340DA70581AF8B54B408FA50F5D50254340DA70581AF8B54B408FA50F5D50254340EB6F09C03FB54B406A1327F73B244340EB6F09C03FB54B40
3952	13981	38.243833000000002	38.285245000000003	55.431361000000003	55.413969000000002	Советская улица	0103000020E61000000100000005000000C15774EB351F43406747AAEFFCB44B40C15774EB351F43408BE255D636B74B407C2C7DE8822443408BE255D636B74B407C2C7DE8822443406747AAEFFCB44B40C15774EB351F43406747AAEFFCB44B40
80438	13981	38.247650999999998	38.273997999999999	55.428632999999998	55.420851999999996	Московская	0103000020E610000001000000050000002DE92807B31F4340643A747ADEB54B402DE92807B31F4340417E3672DDB64B40AF95D05D12234340417E3672DDB64B40AF95D05D12234340643A747ADEB54B402DE92807B31F4340643A747ADEB54B40
74075	13981	38.278219999999997	38.286251	55.422927000000001	55.419452	Москворецкая	0103000020E61000000100000005000000EB8B84B69C234340F31E679AB0B54B40EB8B84B69C23434036CCD07822B64B4041B96DDFA324434036CCD07822B64B4041B96DDFA3244340F31E679AB0B54B40EB8B84B69C234340F31E679AB0B54B40
74133	13981	38.235092000000002	38.283079999999998	55.416007999999998	55.411091999999996	Льва Толстого	0103000020E610000001000000050000008FC6A17E171E4340D8D2A3A99EB44B408FC6A17E171E4340EB6F09C03FB54B406A1327F73B244340EB6F09C03FB54B406A1327F73B244340D8D2A3A99EB44B408FC6A17E171E4340D8D2A3A99EB44B40
4677	13981	38.257666999999998	38.271124	55.425868999999999	55.417214000000001	Комсомольский переулок	0103000020E610000001000000050000001421753BFB20434078B7B24467B54B401421753BFB204340ABB019E082B64B409294F430B4224340ABB019E082B64B409294F430B422434078B7B24467B54B401421753BFB20434078B7B24467B54B40
80038	3929	37.867708	37.985791999999996	55.799011	55.782744000000001	шоссе Энтузиастов	0103000020E61000000100000005000000213D450E11EF4240F39194F430E44B40213D450E11EF4240771211FE45E64B404754A86E2EFE4240771211FE45E64B404754A86E2EFE4240F39194F430E44B40213D450E11EF4240F39194F430E44B40
79879	3929	37.923997	37.984336999999996	55.803894	55.796728999999999	проспект Ленина	0103000020E61000000100000005000000124DA08845F642402C634337FBE54B40124DA08845F64240AEB9A3FFE5E64B40129F3BC1FEFD4240AEB9A3FFE5E64B40129F3BC1FEFD42402C634337FBE54B40124DA08845F642402C634337FBE54B40
79891	3929	37.877087000000003	37.880006000000002	55.785316000000002	55.783847999999999	микрорайон ЦОВБ	0103000020E61000000100000005000000965F066344F042407B849A2155E44B40965F066344F042404583143C85E44B4053245F09A4F042404583143C85E44B4053245F09A4F042407B849A2155E44B40965F066344F042407B849A2155E44B40
71783	3929	37.996122	38.021301999999999	55.797517999999997	55.789774999999999	микрорайон Северный	0103000020E61000000100000005000000BE69FAEC80FF42406519E25817E54B40BE69FAEC80FF424054FCDF1115E64B4071AB2006BA02434054FCDF1115E64B4071AB2006BA0243406519E25817E54B40BE69FAEC80FF42406519E25817E54B40
79882	3929	37.891316000000003	37.904710000000001	55.780966999999997	55.774709999999999	микрорайон Дзержинского	0103000020E61000000100000005000000663387A416F242402CF180B229E34B40663387A416F24240AB2006BAF6E34B409D2E8B89CDF34240AB2006BAF6E34B409D2E8B89CDF342402CF180B229E34B40663387A416F242402CF180B229E34B40
80399	3929	37.936734999999999	37.936771	55.798318000000002	55.798298000000003	микрорайон 1 Мая	0103000020E610000001000000050000006002B7EEE6F742402A3BFDA02EE64B406002B7EEE6F7424071E7C2482FE64B40AD6BB41CE8F7424071E7C2482FE64B40AD6BB41CE8F742402A3BFDA02EE64B406002B7EEE6F742402A3BFDA02EE64B40
80786	3929	37.82741	38.059587999999998	55.846406000000002	55.738104999999997	квартал Абрамцово	0103000020E6100000010000000500000012312592E8E94240CD0182397ADE4B4012312592E8E94240B091240857EC4B40F59D5F94A0074340B091240857EC4B40F59D5F94A0074340CD0182397ADE4B4012312592E8E94240CD0182397ADE4B40
80419	3929	37.956704000000002	37.970430999999998	55.793621999999999	55.792645	Юлиуса Фучика	0103000020E61000000100000005000000E8F9D34675FA4240412B306475E54B40E8F9D34675FA42406CB1DB6795E54B402503401537FC42406CB1DB6795E54B402503401537FC4240412B306475E54B40E8F9D34675FA4240412B306475E54B40
4164	3929	37.843255999999997	37.960064000000003	55.846359999999997	55.814779999999999	Щелковское шоссе	0103000020E61000000100000005000000F01307D0EFEB4240AAB706B64AE84B40F01307D0EFEB42403F52448655EC4B4092088D60E3FA42403F52448655EC4B4092088D60E3FA4240AAB706B64AE84B40F01307D0EFEB4240AAB706B64AE84B40
80417	3929	37.970098	37.982180999999997	55.795589999999997	55.794193999999997	Фадеева	0103000020E610000001000000050000001FF5D72B2CFC4240F7562426A8E54B401FF5D72B2CFC42402783A3E4D5E54B4054E0641BB8FD42402783A3E4D5E54B4054E0641BB8FD4240F7562426A8E54B401FF5D72B2CFC4240F7562426A8E54B40
80422	3929	37.972693999999997	37.985253	55.798848999999997	55.789962000000003	Твардовского	0103000020E61000000100000005000000F981AB3C81FC4240988A8D791DE54B40F981AB3C81FC42409DB81CAF40E64B4098A432C51CFE42409DB81CAF40E64B4098A432C51CFE4240988A8D791DE54B40F981AB3C81FC4240988A8D791DE54B40
80234	3929	37.966468999999996	37.966855000000002	55.818351	55.814309999999999	Спортивная	0103000020E6100000010000000500000085CC9541B5FB42402367614F3BE84B4085CC9541B5FB42400FD3BEB9BFE84B40AF7C96E7C1FB42400FD3BEB9BFE84B40AF7C96E7C1FB42402367614F3BE84B4085CC9541B5FB42402367614F3BE84B40
80142	3929	37.912067	37.924931000000001	55.779828000000002	55.774633999999999	Сосновый бор	0103000020E610000001000000050000006361889CBEF44240512FF83427E34B406361889CBEF44240A7406667D1E34B403E07962364F64240A7406667D1E34B403E07962364F64240512FF83427E34B406361889CBEF44240512FF83427E34B40
71794	3929	37.953192000000001	37.961483000000001	55.829481999999999	55.819898999999999	Солнечная	0103000020E610000001000000050000008867093202FA4240F5824F73F2E84B408867093202FA4240724F57772CEA4B407A54FCDF11FB4240724F57772CEA4B407A54FCDF11FB4240F5824F73F2E84B408867093202FA4240F5824F73F2E84B40
74185	3929	37.934066999999999	37.954773000000003	55.82002	55.794072	Советская улица	0103000020E61000000100000005000000ECA2E8818FF74240AC55BB26A4E54B40ECA2E8818FF742407008556AF6E84B404A0D6D0036FA42407008556AF6E84B404A0D6D0036FA4240AC55BB26A4E54B40ECA2E8818FF74240AC55BB26A4E54B40
74129	3929	37.934066999999999	37.954773000000003	55.82002	55.794072	Советская	0103000020E61000000100000005000000ECA2E8818FF74240AC55BB26A4E54B40ECA2E8818FF742407008556AF6E84B404A0D6D0036FA42407008556AF6E84B404A0D6D0036FA4240AC55BB26A4E54B40ECA2E8818FF74240AC55BB26A4E54B40
80216	3929	37.966693999999997	37.973314000000002	55.835861999999999	55.818331000000001	Свердлова	0103000020E61000000100000005000000A59E05A1BCFB4240C826F911BFE84B40A59E05A1BCFB42400DFCA886FDEA4B40965E9B8D95FC42400DFCA886FDEA4B40965E9B8D95FC4240C826F911BFE84B40A59E05A1BCFB4240C826F911BFE84B40
80466	3929	37.926135000000002	37.950164999999998	55.760601000000001	55.756903000000001	Садовая 	0103000020E610000001000000050000002A5778978BF64240459F8F32E2E04B402A5778978BF642400727A25F5BE14B40E466B8019FF942400727A25F5BE14B40E466B8019FF94240459F8F32E2E04B402A5778978BF64240459F8F32E2E04B40
15378	3929	37.921194	37.931595999999999	55.790194999999997	55.757708000000001	Разинское шоссе	0103000020E61000000100000005000000BEA25BAFE9F5424073F56393FCE04B40BEA25BAFE9F542403A3B191C25E54B40CE8AA8893EF742403A3B191C25E54B40CE8AA8893EF7424073F56393FCE04B40BEA25BAFE9F5424073F56393FCE04B40
80140	3929	37.931488999999999	37.934201999999999	55.794077000000001	55.790194999999997	Разина	0103000020E61000000100000005000000B8CA13083BF742403A3B191C25E54B40B8CA13083BF74240BEC0AC50A4E54B40CCED5EEE93F74240BEC0AC50A4E54B40CCED5EEE93F742403A3B191C25E54B40B8CA13083BF742403A3B191C25E54B40
15945	3929	37.906623000000003	37.940022999999997	55.752754000000003	55.750408	Носовихинское шоссе	0103000020E610000001000000050000009566F3380CF4424011548D5E0DE04B409566F3380CF4424073F7393E5AE04B40703E75AC52F8424073F7393E5AE04B40703E75AC52F8424011548D5E0DE04B409566F3380CF4424011548D5E0DE04B40
71938	3929	37.925811000000003	37.928685999999999	55.769863999999998	55.765301000000001	Новая	0103000020E6100000010000000500000077A38FF980F642404D4C1762F5E14B4077A38FF980F64240122F4FE78AE24B406420CF2EDFF64240122F4FE78AE24B406420CF2EDFF642404D4C1762F5E14B4077A38FF980F642404D4C1762F5E14B40
80415	3929	37.82741	38.059587999999998	55.846406000000002	55.738104999999997	Московский проезд	0103000020E6100000010000000500000012312592E8E94240CD0182397ADE4B4012312592E8E94240B091240857EC4B40F59D5F94A0074340B091240857EC4B40F59D5F94A0074340CD0182397ADE4B4012312592E8E94240CD0182397ADE4B40
80431	3929	37.907836000000003	37.921202999999998	55.757496000000003	55.755291999999997	Московская	0103000020E61000000100000005000000D41055F833F4424018778368ADE04B40D41055F833F44240E86C01A1F5E04B4011FDDAFAE9F54240E86C01A1F5E04B4011FDDAFAE9F5424018778368ADE04B40D41055F833F4424018778368ADE04B40
68803	3929	37.878864999999998	37.882288000000003	55.742235000000001	55.740780999999998	Мирской проезд	0103000020E61000000100000005000000AD4CF8A57EF04240C43F6CE9D1DE4B40AD4CF8A57EF042402979758E01DF4B409ED32CD0EEF042402979758E01DF4B409ED32CD0EEF04240C43F6CE9D1DE4B40AD4CF8A57EF04240C43F6CE9D1DE4B40
80971	3929	37.930914000000001	37.933025000000001	55.745645000000003	55.741961000000003	Лесопарковая улица	0103000020E61000000100000005000000BCB1A03028F7424028F4FA93F8DE4B40BCB1A03028F7424085B69C4B71DF4B40DAACFA5C6DF7424085B69C4B71DF4B40DAACFA5C6DF7424028F4FA93F8DE4B40BCB1A03028F7424028F4FA93F8DE4B40
80224	3929	37.965156999999998	37.974752000000002	55.821826000000001	55.819707000000001	Кудаковского	0103000020E61000000100000005000000B340BB438AFB4240B1A6B228ECE84B40B340BB438AFB42405280289831E94B40F5DA6CACC4FC42405280289831E94B40F5DA6CACC4FC4240B1A6B228ECE84B40B340BB438AFB4240B1A6B228ECE84B40
80499	3929	37.926997	37.934551999999996	55.799982999999997	55.799492000000001	Крупской	0103000020E61000000100000005000000BC3E73D6A7F64240F2B4FCC055E64B40BC3E73D6A7F64240902DCBD765E64B40A83462669FF74240902DCBD765E64B40A83462669FF74240F2B4FCC055E64B40BC3E73D6A7F64240F2B4FCC055E64B40
79845	3929	37.954709999999999	37.966864000000001	55.814315000000001	55.813262999999999	Крупешина	0103000020E610000001000000050000000395F1EF33FA4240FF05820019E84B400395F1EF33FA424035D252793BE84B4002D71533C2FB424035D252793BE84B4002D71533C2FB4240FF05820019E84B400395F1EF33FA4240FF05820019E84B40
72244	3929	37.939017	37.947217999999999	55.809503999999997	55.807915999999999	Зеленая	0103000020E61000000100000005000000ABB184B531F8424023F59ECA69E74B40ABB184B531F8424097FDBAD39DE74B405D177E703EF9424097FDBAD39DE74B405D177E703EF9424023F59ECA69E74B40ABB184B531F8424023F59ECA69E74B40
71933	3929	37.959542999999996	37.971949000000002	55.833728000000001	55.813383999999999	Заречная	0103000020E61000000100000005000000880D164ED2FA42407A8B87F71CE84B40880D164ED2FA424037E15E99B7EA4B40A13028D368FC424037E15E99B7EA4B40A13028D368FC42407A8B87F71CE84B40880D164ED2FA42407A8B87F71CE84B40
16186	3929	37.893830999999999	37.929215999999997	55.780583	55.760013000000001	Вишняковское шоссе	0103000020E610000001000000050000005393E00D69F2424076C4211B48E14B405393E00D69F242402368CC24EAE34B40C075C58CF0F642402368CC24EAE34B40C075C58CF0F6424076C4211B48E14B405393E00D69F2424076C4211B48E14B40
80426	3929	37.963692999999999	37.983455999999997	55.802897000000002	55.800725999999997	Белякова	0103000020E610000001000000050000002B31CF4A5AFB4240488787307EE64B402B31CF4A5AFB42403C873254C5E64B400987DEE2E1FD42403C873254C5E64B400987DEE2E1FD4240488787307EE64B402B31CF4A5AFB4240488787307EE64B40
80866	3929	37.878433999999999	37.883025000000004	55.821663999999998	55.820860000000003	Акуловский проезд	0103000020E61000000100000005000000E4D87A8670F042401B4CC3F011E94B40E4D87A8670F04240782634492CE94B40744694F606F14240782634492CE94B40744694F606F142401B4CC3F011E94B40E4D87A8670F042401B4CC3F011E94B40
80436	3929	37.880985000000003	37.904108000000001	55.775748	55.768552	9-я Линия	0103000020E610000001000000050000001FA2D11DC4F0424040A374E95FE24B401FA2D11DC4F04240FDF7E0B54BE34B40A7069ACFB9F34240FDF7E0B54BE34B40A7069ACFB9F3424040A374E95FE24B401FA2D11DC4F0424040A374E95FE24B40
79896	3929	37.82741	38.059587999999998	55.846406000000002	55.738104999999997	40 лет Победы	0103000020E6100000010000000500000012312592E8E94240CD0182397ADE4B4012312592E8E94240B091240857EC4B40F59D5F94A0074340B091240857EC4B40F59D5F94A0074340CD0182397ADE4B4012312592E8E94240CD0182397ADE4B40
80706	61951	37.918759999999999	37.983609000000001	56.186379000000002	56.148327999999999	Кольцова	0103000020E61000000100000005000000BD6F7CED99F54240618A7269FC124C40BD6F7CED99F54240A2D45E44DB174C40908653E6E6FD4240A2D45E44DB174C40908653E6E6FD4240618A7269FC124C40BD6F7CED99F54240618A7269FC124C40
80608	61944	37.066437999999998	37.093952999999999	55.556944999999999	55.543430000000001	Февральская	0103000020E61000000100000005000000179B560A8188424028D53E1D8FC54B40179B560A81884240DA5548F949C74B40382EE3A6068C4240DA5548F949C74B40382EE3A6068C424028D53E1D8FC54B40179B560A8188424028D53E1D8FC54B40
80631	61944	37.068539999999999	37.073093999999998	55.549083000000003	55.545340000000003	Ленина	0103000020E61000000100000005000000E23B31EBC5884240AF997CB3CDC54B40E23B31EBC588424011E50B5A48C64B4054C4E9245B89424011E50B5A48C64B4054C4E9245B894240AF997CB3CDC54B40E23B31EBC5884240AF997CB3CDC54B40
81121	25140	37.035409999999999	37.052334000000002	55.595892999999997	55.595230999999998	Краснознаменная улица	0103000020E61000000100000005000000C6F99B50888442405E48878730CC4B40C6F99B50888442402975C93846CC4B40043C69E1B28642402975C93846CC4B40043C69E1B28642405E48878730CC4B40C6F99B50888442405E48878730CC4B40
71893	25140	37.024388000000002	37.068001000000002	55.606914000000003	55.580986000000003	Генерала Шлыкова	0103000020E610000001000000050000001A355F251F83424089B7CEBF5DCA4B401A355F251F83424006BEA25BAFCD4B40338CBB41B488424006BEA25BAFCD4B40338CBB41B488424089B7CEBF5DCA4B401A355F251F83424089B7CEBF5DCA4B40
71812	59514	37.604996	38.120728	55.523214000000003	55.124428999999999	Связистов	0103000020E61000000100000005000000FC1A498270CD424045D61A4AED8F4B40FC1A498270CD4240996725ADF8C24B4012DBDD03740F4340996725ADF8C24B4012DBDD03740F434045D61A4AED8F4B40FC1A498270CD424045D61A4AED8F4B40
71997	30955	37.827311000000002	37.855285000000002	55.282640999999998	55.264845000000001	Заря	0103000020E610000001000000050000007F4FAC53E5E942402BC1E270E6A14B407F4FAC53E5E942401EC18D942DA44B4033E197FA79ED42401EC18D942DA44B4033E197FA79ED42402BC1E270E6A14B407F4FAC53E5E942402BC1E270E6A14B40
74181	7280	38.083618000000001	38.08652	55.765690999999997	55.755904999999998	Ленина	0103000020E61000000100000005000000B0AD9FFEB30A434002F1BA7EC1E04B40B0AD9FFEB30A4340B7EBA52902E24B4097395D16130B4340B7EBA52902E24B4097395D16130B434002F1BA7EC1E04B40B0AD9FFEB30A434002F1BA7EC1E04B40
72229	7280	38.040688000000003	38.056578999999999	55.750706999999998	55.742027	Агрогородок	0103000020E610000001000000050000007AABAE4335054340DFDFA0BDFADE4B407AABAE43350543406BF0BE2A17E04B40F8510DFB3D0743406BF0BE2A17E04B40F8510DFB3D074340DFDFA0BDFADE4B407AABAE4335054340DFDFA0BDFADE4B40
71803	16550	38.050092999999997	38.063091999999997	55.758504000000002	55.754198000000002	улица Авиарембаза	0103000020E6100000010000000500000017618A7269064340B45A608F89E04B4017618A72690643404EF1B8A816E14B40D2510E66130843404EF1B8A816E14B40D2510E6613084340B45A608F89E04B4017618A7269064340B45A608F89E04B40
72248	16586	38.034723	38.051935	55.737892000000002	55.721873000000002	Новослободская	0103000020E61000000100000005000000A2B5A2CD71044340C66E9F5566DC4B40A2B5A2CD7104434072FDBB3E73DE4B4046425BCEA506434072FDBB3E73DE4B4046425BCEA5064340C66E9F5566DC4B40A2B5A2CD71044340C66E9F5566DC4B40
80784	15718	38.047344000000002	38.065275	55.713512000000001	55.702022999999997	Парковая	0103000020E61000000100000005000000B7D4415E0F0643401805C1E3DBD94B40B7D4415E0F064340DBA6785C54DB4B408A1F63EE5A084340DBA6785C54DB4B408A1F63EE5A0843401805C1E3DBD94B40B7D4415E0F0643401805C1E3DBD94B40
80034	61919	38.152895999999998	38.221590999999997	55.854987000000001	55.824860000000001	Баранова	0103000020E6100000010000000500000038D89B1892134340A8E3310395E94B4038D89B1892134340A9C0C93670ED4B40410B09185D1C4340A9C0C93670ED4B40410B09185D1C4340A8E3310395E94B4038D89B1892134340A8E3310395E94B40
80579	271	38.058357999999998	38.068212000000003	55.903377999999996	55.903004000000003	улица Супруна	0103000020E61000000100000005000000E0BA6246780743401F1494A295F34B40E0BA62467807434083F6EAE3A1F34B40EE98BA2BBB08434083F6EAE3A1F34B40EE98BA2BBB0843401F1494A295F34B40E0BA6246780743401F1494A295F34B40
79	271	37.974238999999997	37.992052999999999	55.937674000000001	55.931638	улица Свердлова	0103000020E610000001000000050000006EBE11DDB3FC4240FDDAFAE93FF74B406EBE11DDB3FC42409E279EB305F84B400873BB97FBFE42409E279EB305F84B400873BB97FBFE4240FDDAFAE93FF74B406EBE11DDB3FC4240FDDAFAE93FF74B40
2331	271	37.971122000000001	37.980122999999999	55.945796000000001	55.939570000000003	улица Неделина	0103000020E610000001000000050000008B36C7B94DFC4240C0266BD443F84B408B36C7B94DFC42400458E4D70FF94B405987A3AB74FD42400458E4D70FF94B405987A3AB74FD4240C0266BD443F84B408B36C7B94DFC4240C0266BD443F84B40
2317	271	37.969217999999998	37.973987999999999	55.943325999999999	55.940486999999997	проспект 60 лет Октября	0103000020E61000000100000005000000E658DE550FFC424015A8C5E061F84B40E658DE550FFC4240B6BB07E8BEF84B40255987A3ABFC4240B6BB07E8BEF84B40255987A3ABFC424015A8C5E061F84B40E658DE550FFC424015A8C5E061F84B40
2574	271	37.990831	37.992736000000001	55.922964	55.919986999999999	площадь Ленина	0103000020E61000000100000005000000766EDA8CD3FE424061DF4E22C2F54B40766EDA8CD3FE424053B131AF23F64B40EBC726F911FF424053B131AF23F64B40EBC726F911FF424061DF4E22C2F54B40766EDA8CD3FE424061DF4E22C2F54B40
80532	271	37.988647999999998	37.994388999999998	55.940618000000001	55.936489000000002	Школьная	0103000020E61000000100000005000000BEA085048CFE424029081EDFDEF74B40BEA085048CFE4240B403AE2B66F84B404640852348FF4240B403AE2B66F84B404640852348FF424029081EDFDEF74B40BEA085048CFE424029081EDFDEF74B40
80559	271	37.939582000000001	37.994083000000003	55.928693000000003	55.913817999999999	Центральная	0103000020E6100000010000000500000084F4143944F84240813FFCFCF7F44B4084F4143944F8424017838769DFF64B403A419B1C3EFF424017838769DFF64B403A419B1C3EFF4240813FFCFCF7F44B4084F4143944F84240813FFCFCF7F44B40
2485	271	38.001511999999998	38.035055	55.940744000000002	55.927382000000001	Фряновское шоссе	0103000020E610000001000000050000009946938B3100434015731074B4F64B409946938B3100434041F4A44C6AF84B40D847A7AE7C04434041F4A44C6AF84B40D847A7AE7C04434015731074B4F64B409946938B3100434015731074B4F64B40
79871	271	37.989654999999999	37.992807999999997	55.937154999999997	55.935985000000002	Фестивальная	0103000020E6100000010000000500000054A9D903ADFE4240F645425BCEF74B4054A9D903ADFE42403524EEB1F4F74B40849A215514FF42403524EEB1F4F74B40849A215514FF4240F645425BCEF74B4054A9D903ADFE4240F645425BCEF74B40
81069	271	38.010773999999998	38.012884999999997	55.919347000000002	55.910134999999997	Фабричная	0103000020E61000000100000005000000D4D2DC0A61014340F4F8BD4D7FF44B40D4D2DC0A610143407E569929ADF54B40F2CD3637A60143407E569929ADF54B40F2CD3637A6014340F4F8BD4D7FF44B40D4D2DC0A61014340F4F8BD4D7FF44B40
81028	271	37.951422000000001	37.961168999999998	55.945946999999997	55.940365999999997	Урожайная	0103000020E61000000100000005000000F3583332C8F942409A22C0E95DF84B40F3583332C8F94240E95F92CA14F94B40EA76F69507FB4240E95F92CA14F94B40EA76F69507FB42409A22C0E95DF84B40F3583332C8F942409A22C0E95DF84B40
80541	271	37.981614999999998	38.000020999999997	55.928027	55.925015999999999	Талсинская 	0103000020E61000000100000005000000AB21718FA5FD42406C239EEC66F64B40AB21718FA5FD42400A67B796C9F64B40172829B0000043400A67B796C9F64B40172829B0000043406C239EEC66F64B40AB21718FA5FD42406C239EEC66F64B40
80522	271	37.981614999999998	38.000020999999997	55.928027	55.925015999999999	Талсинская	0103000020E61000000100000005000000AB21718FA5FD42406C239EEC66F64B40AB21718FA5FD42400A67B796C9F64B40172829B0000043400A67B796C9F64B40172829B0000043406C239EEC66F64B40AB21718FA5FD42406C239EEC66F64B40
81062	271	38.058357999999998	38.068212000000003	55.903377999999996	55.903004000000003	Супруна	0103000020E61000000100000005000000E0BA6246780743401F1494A295F34B40E0BA62467807434083F6EAE3A1F34B40EE98BA2BBB08434083F6EAE3A1F34B40EE98BA2BBB0843401F1494A295F34B40E0BA6246780743401F1494A295F34B40
74126	271	38.058357999999998	38.068212000000003	55.903377999999996	55.903004000000003	Супруна	0103000020E61000000100000005000000E0BA6246780743401F1494A295F34B40E0BA62467807434083F6EAE3A1F34B40EE98BA2BBB08434083F6EAE3A1F34B40EE98BA2BBB0843401F1494A295F34B40E0BA6246780743401F1494A295F34B40
79813	271	38.058357999999998	38.068212000000003	55.903377999999996	55.903004000000003	Супруна	0103000020E61000000100000005000000E0BA6246780743401F1494A295F34B40E0BA62467807434083F6EAE3A1F34B40EE98BA2BBB08434083F6EAE3A1F34B40EE98BA2BBB0843401F1494A295F34B40E0BA6246780743401F1494A295F34B40
2502	271	37.993085999999998	38.001629000000001	55.927447000000001	55.910890999999999	Пролетарский проспект	0103000020E61000000100000005000000C70E2A711DFF4240419C871398F44B40C70E2A711DFF4240FCE25295B6F64B40D3DC0A6135004340FCE25295B6F64B40D3DC0A6135004340419C871398F44B40C70E2A711DFF4240419C871398F44B40
80032	271	37.992609999999999	38.000048	55.934432000000001	55.933039999999998	Полевая	0103000020E610000001000000050000005ED72FD80DFF42400FEECEDA6DF74B405ED72FD80DFF4240FE2AC0779BF74B401137A79201004340FE2AC0779BF74B401137A792010043400FEECEDA6DF74B405ED72FD80DFF42400FEECEDA6DF74B40
80548	271	37.958447	37.974786999999999	55.926054999999998	55.920245000000001	Пионерская	0103000020E6100000010000000500000083F92B64AEFA42405DA79196CAF54B4083F92B64AEFA42400DA661F888F64B4071C806D2C5FC42400DA661F888F64B4071C806D2C5FC42405DA79196CAF54B4083F92B64AEFA42405DA79196CAF54B40
80538	271	37.978425999999999	37.990893999999997	55.923276000000001	55.920149000000002	Парковая	0103000020E610000001000000050000002EC72B103DFD42403B394371C7F54B402EC72B103DFD4240429770E82DF64B40BCE6559DD5FE4240429770E82DF64B40BCE6559DD5FE42403B394371C7F54B402EC72B103DFD42403B394371C7F54B40
80113	271	37.971122000000001	37.980122999999999	55.945796000000001	55.939570000000003	Неделина	0103000020E610000001000000050000008B36C7B94DFC4240C0266BD443F84B408B36C7B94DFC42400458E4D70FF94B405987A3AB74FD42400458E4D70FF94B405987A3AB74FD4240C0266BD443F84B408B36C7B94DFC4240C0266BD443F84B40
79810	271	37.999096000000002	38.001314999999998	55.921723	55.921636999999997	Малопролетарская	0103000020E610000001000000050000003FC8B260E2FF42404BE48233F8F54B403FC8B260E2FF42404A7CEE04FBF54B4043FF04172B0043404A7CEE04FBF54B4043FF04172B0043404BE48233F8F54B403FC8B260E2FF42404BE48233F8F54B40
80530	271	37.985548999999999	38.001511999999998	55.931314999999998	55.927447000000001	Комсомольская 	0103000020E6100000010000000500000081CD397826FE4240FCE25295B6F64B4081CD397826FE42401AA3755435F74B409946938B310043401AA3755435F74B409946938B31004340FCE25295B6F64B4081CD397826FE4240FCE25295B6F64B40
80537	271	37.985548999999999	38.001511999999998	55.931314999999998	55.927447000000001	Комсомольская	0103000020E6100000010000000500000081CD397826FE4240FCE25295B6F64B4081CD397826FE42401AA3755435F74B409946938B310043401AA3755435F74B409946938B31004340FCE25295B6F64B4081CD397826FE4240FCE25295B6F64B40
74199	271	38.044370999999998	38.065202999999997	55.903913000000003	55.902085999999997	Институтская	0103000020E6100000010000000500000006F2ECF2AD054340F816D68D77F34B4006F2ECF2AD054340F2B6D26BB3F34B40F04C689258084340F2B6D26BB3F34B40F04C689258084340F816D68D77F34B4006F2ECF2AD054340F816D68D77F34B40
81030	271	37.999975999999997	38.020000000000003	55.925077000000002	55.921173000000003	Заречная	0103000020E610000001000000050000007764AC36FFFF4240A77A32FFE8F54B407764AC36FFFF424012A452EC68F64B40C3F5285C8F02434012A452EC68F64B40C3F5285C8F024340A77A32FFE8F54B407764AC36FFFF4240A77A32FFE8F54B40
80549	271	38.057873000000001	38.067349999999998	55.911400999999998	55.903801999999999	Гагарина	0103000020E610000001000000050000002429E961680743409A07B0C8AFF34B402429E961680743405645B8C9A8F44B405BB1BFEC9E0843405645B8C9A8F44B405BB1BFEC9E0843409A07B0C8AFF34B402429E961680743409A07B0C8AFF34B40
74111	271	38.057873000000001	38.067349999999998	55.911400999999998	55.903801999999999	Гагарина	0103000020E610000001000000050000002429E961680743409A07B0C8AFF34B402429E961680743405645B8C9A8F44B405BB1BFEC9E0843405645B8C9A8F44B405BB1BFEC9E0843409A07B0C8AFF34B402429E961680743409A07B0C8AFF34B40
80553	271	38.073296999999997	38.092376999999999	55.888387000000002	55.874091999999997	Беляева	0103000020E610000001000000050000008CF2CCCB61094340FDD8243FE2EF4B408CF2CCCB6109434085984BAAB6F14B4088F37002D30B434085984BAAB6F14B4088F37002D30B4340FDD8243FE2EF4B408CF2CCCB61094340FDD8243FE2EF4B40
80577	61943	38.403202999999998	38.458297000000002	56.146858999999999	56.113360999999998	Механизаторов	0103000020E610000001000000050000001553E9279C33434028D2FD9C820E4C401553E9279C334340C70F9546CC124C406E6DE179A93A4340C70F9546CC124C406E6DE179A93A434028D2FD9C820E4C401553E9279C33434028D2FD9C820E4C40
80565	61941	38.403202999999998	38.458297000000002	56.146858999999999	56.113360999999998	Текстильщиков	0103000020E610000001000000050000001553E9279C33434028D2FD9C820E4C401553E9279C334340C70F9546CC124C406E6DE179A93A4340C70F9546CC124C406E6DE179A93A434028D2FD9C820E4C401553E9279C33434028D2FD9C820E4C40
80583	61941	38.403202999999998	38.458297000000002	56.146858999999999	56.113360999999998	Первомайская	0103000020E610000001000000050000001553E9279C33434028D2FD9C820E4C401553E9279C334340C70F9546CC124C406E6DE179A93A4340C70F9546CC124C406E6DE179A93A434028D2FD9C820E4C401553E9279C33434028D2FD9C820E4C40
80359	61937	38.136817000000001	38.137895	55.903792000000003	55.897872	Набережная	0103000020E61000000100000005000000B7442E38831143403FFF3D78EDF24B40B7442E38831143407731CD74AFF34B4016A4198BA61143407731CD74AFF34B4016A4198BA61143403FFF3D78EDF24B40B7442E38831143403FFF3D78EDF24B40
3267	9552	38.121913999999997	38.131273999999998	55.898412	55.898103999999996	улица Дзержинского	0103000020E610000001000000050000005776C1E09A0F434011346612F5F24B405776C1E09A0F4340BF2A172AFFF24B4055682096CD104340BF2A172AFFF24B4055682096CD10434011346612F5F24B405776C1E09A0F434011346612F5F24B40
2708	9552	38.138649000000001	38.141910000000003	55.905265	55.904902	Советская улица	0103000020E61000000100000005000000C24F1C40BF114340E10A28D4D3F34B40C24F1C40BF114340529B38B9DFF34B40D97C5C1B2A124340529B38B9DFF34B40D97C5C1B2A124340E10A28D4D3F34B40C24F1C40BF114340E10A28D4D3F34B40
8054	31977	38.074213	38.081121000000003	55.969945000000003	55.964785999999997	Окружной проезд	0103000020E6100000010000000500000012F8C3CF7F094340BFD18E1B7EFB4B4012F8C3CF7F09434099F5622827FC4B406902452C620A434099F5622827FC4B406902452C620A4340BFD18E1B7EFB4B4012F8C3CF7F094340BFD18E1B7EFB4B40
79824	61873	38.152895999999998	38.221590999999997	55.854987000000001	55.824860000000001	1-я Дачная	0103000020E6100000010000000500000038D89B1892134340A8E3310395E94B4038D89B1892134340A9C0C93670ED4B40410B09185D1C4340A9C0C93670ED4B40410B09185D1C4340A8E3310395E94B4038D89B1892134340A8E3310395E94B40
80592	11138	37.987363999999999	37.992556	55.868803999999997	55.864646	Юбилейная	0103000020E61000000100000005000000B69F8CF161FE4240014F5AB8ACEE4B40B69F8CF161FE424026512FF834EF4B406BB933130CFF424026512FF834EF4B406BB933130CFF4240014F5AB8ACEE4B40B69F8CF161FE4240014F5AB8ACEE4B40
4586	11138	37.985872999999998	37.989331	55.871758	55.867691999999998	Садовая улица	0103000020E610000001000000050000003481221631FE42401B800D8810EF4B403481221631FE4240600322C495EF4B40A1F5F065A2FE4240600322C495EF4B40A1F5F065A2FE42401B800D8810EF4B403481221631FE42401B800D8810EF4B40
80900	60271	37.910916999999998	37.913352000000003	55.932662000000001	55.926448999999998	Школьная	0103000020E610000001000000050000006A2FA2ED98F44240B9347EE195F64B406A2FA2ED98F44240691CEA7761F74B403CDEE4B7E8F44240691CEA7761F74B403CDEE4B7E8F44240B9347EE195F64B406A2FA2ED98F44240B9347EE195F64B40
80285	60271	37.934488999999999	37.953560000000003	55.907863999999996	55.905427000000003	Сергея Лазо	0103000020E6100000010000000500000062BCE6559DF742402CF52C08E5F34B4062BCE6559DF742409D9B36E334F44B400B630B410EFA42409D9B36E334F44B400B630B410EFA42402CF52C08E5F34B4062BCE6559DF742402CF52C08E5F34B40
80306	60271	37.919199999999996	37.925919	55.926806999999997	55.912486000000001	Комсомольская	0103000020E61000000100000005000000D93D7958A8F5424068075C57CCF44B40D93D7958A8F54240185A9D9CA1F64B405DDF878384F64240185A9D9CA1F64B405DDF878384F6424068075C57CCF44B40D93D7958A8F5424068075C57CCF44B40
74218	60271	37.896957	37.959668999999998	55.935743000000002	55.896175999999997	Димитрова	0103000020E610000001000000050000008A75AA7CCFF24240E4BA29E5B5F24B408A75AA7CCFF24240003B376DC6F74B4015FE0C6FD6FA4240003B376DC6F74B4015FE0C6FD6FA4240E4BA29E5B5F24B408A75AA7CCFF24240E4BA29E5B5F24B40
3500	94	37.938791999999999	37.941459999999999	55.927436999999998	55.921289000000002	улица Текстильщиков	0103000020E610000001000000050000008BDF14562AF84240109546CCECF54B408BDF14562AF84240D80C7041B6F64B40FF3EE3C281F84240D80C7041B6F64B40FF3EE3C281F84240109546CCECF54B408BDF14562AF84240109546CCECF54B40
3025	94	37.934488999999999	37.953560000000003	55.907863999999996	55.905427000000003	улица Сергея Лазо	0103000020E6100000010000000500000062BCE6559DF742402CF52C08E5F34B4062BCE6559DF742409D9B36E334F44B400B630B410EFA42409D9B36E334F44B400B630B410EFA42402CF52C08E5F34B4062BCE6559DF742402CF52C08E5F34B40
15	94	37.919199999999996	37.925919	55.926806999999997	55.912486000000001	Комсомольская улица	0103000020E61000000100000005000000D93D7958A8F5424068075C57CCF44B40D93D7958A8F54240185A9D9CA1F64B405DDF878384F64240185A9D9CA1F64B405DDF878384F6424068075C57CCF44B40D93D7958A8F5424068075C57CCF44B40
80860	94	37.896957	37.959668999999998	55.935743000000002	55.896175999999997	Димитрова	0103000020E610000001000000050000008A75AA7CCFF24240E4BA29E5B5F24B408A75AA7CCFF24240003B376DC6F74B4015FE0C6FD6FA4240003B376DC6F74B4015FE0C6FD6FA4240E4BA29E5B5F24B408A75AA7CCFF24240E4BA29E5B5F24B40
80873	62012	38.104351000000001	38.107469000000002	55.909660000000002	55.909407999999999	Центральная	0103000020E610000001000000050000000727A25F5B0D4340425C397B67F44B400727A25F5B0D43405C3D27BD6FF44B40BB2A508BC10D43405C3D27BD6FF44B40BB2A508BC10D4340425C397B67F44B400727A25F5B0D4340425C397B67F44B40
80850	60263	35.526133000000002	35.527929	56.028157999999998	56.022151999999998	Лесная	0103000020E61000000100000005000000562C7E5358C341403FC571E0D5024C40562C7E5358C34140758F6CAE9A034C4014CE6E2D93C34140758F6CAE9A034C4014CE6E2D93C341403FC571E0D5024C40562C7E5358C341403FC571E0D5024C40
74176	60263	35.497638000000002	35.524686000000003	56.036020000000001	56.027594999999998	1-я Советская улица	0103000020E61000000100000005000000999F1B9AB2BF41403D44A33B88034C40999F1B9AB2BF41403F00A94D9C044C40A4552DE928C341403F00A94D9C044C40A4552DE928C341403D44A33B88034C40999F1B9AB2BF41403D44A33B88034C40
79811	60263	35.510393999999998	35.512388000000001	56.034903	56.031232000000003	1-й Советский переулок	0103000020E610000001000000050000008D09319754C141405A4B0169FF034C408D09319754C1414022C495B377044C40726E13EE95C1414022C495B377044C40726E13EE95C141405A4B0169FF034C408D09319754C141405A4B0169FF034C40
80846	7863	35.502389999999998	35.527929	56.024667000000001	56.023766999999999	Южная	0103000020E6100000010000000500000031EBC5504EC04140ADDC0BCC0A034C4031EBC5504EC041402D25CB4928034C4014CE6E2D93C341402D25CB4928034C4014CE6E2D93C34140ADDC0BCC0A034C4031EBC5504EC04140ADDC0BCC0A034C40
16896	7863	35.500387000000003	35.509900000000002	56.035651999999999	56.030723999999999	Комсомольская улица	0103000020E61000000100000005000000FA2B64AE0CC04140E59997C3EE034C40FA2B64AE0CC04140BC04A73E90044C407E1D386744C14140BC04A73E90044C407E1D386744C14140E59997C3EE034C40FA2B64AE0CC04140E59997C3EE034C40
2149	7863	35.497638000000002	35.524686000000003	56.036020000000001	56.027594999999998	1-я Советская улица	0103000020E61000000100000005000000999F1B9AB2BF41403D44A33B88034C40999F1B9AB2BF41403F00A94D9C044C40A4552DE928C341403F00A94D9C044C40A4552DE928C341403D44A33B88034C40999F1B9AB2BF41403D44A33B88034C40
71926	8163	35.637982000000001	35.657808000000003	56.010542999999998	55.996544999999998	Промышленная	0103000020E61000000100000005000000E5B7E864A9D1414004FF5BC98EFF4B40E5B7E864A9D14140D219187959014C400A86730D33D44140D219187959014C400A86730D33D4414004FF5BC98EFF4B40E5B7E864A9D1414004FF5BC98EFF4B40
71929	8303	35.483165999999997	35.521354000000002	55.907960000000003	55.885671000000002	Школьная	0103000020E6100000010000000500000002452C62D8BD41400002D6AA5DF14B4002452C62D8BD4140C009850838F44B40C4D155BABBC24140C009850838F44B40C4D155BABBC241400002D6AA5DF14B4002452C62D8BD41400002D6AA5DF14B40
67038	7945	35.480300999999997	35.519216	56.158616000000002	56.146025999999999	Центральная	0103000020E61000000100000005000000389ECF807ABD4140CF2EDFFAB0124C40389ECF807ABD4140A94F72874D144C40ACC77DAB75C24140A94F72874D144C40ACC77DAB75C24140CF2EDFFAB0124C40389ECF807ABD4140CF2EDFFAB0124C40
71858	8246	35.355058	35.382204999999999	56.003064000000002	55.987698999999999	Микрорайон	0103000020E610000001000000050000007217618A72AD41405DA5BBEB6CFE4B407217618A72AD4140C1E5B16664004C4010AFEB17ECB04140C1E5B16664004C4010AFEB17ECB041405DA5BBEB6CFE4B407217618A72AD41405DA5BBEB6CFE4B40
71932	7991	35.345283999999999	35.367634000000002	56.227285000000002	56.216459	Новая	0103000020E6100000010000000500000081EA1F4432AC414062F6B2EDB41B4C4081EA1F4432AC414089EFC4AC171D4C40E77283A10EAF414089EFC4AC171D4C40E77283A10EAF414062F6B2EDB41B4C4081EA1F4432AC414062F6B2EDB41B4C40
80767	8317	35.334862999999999	35.354222	55.880096000000002	55.865935	Школьная	0103000020E61000000100000005000000FAD170CADCAA41401BBB44F5D6EE4B40FAD170CADCAA414093AB58FCA6F04B4009C3802557AD414093AB58FCA6F04B4009C3802557AD41401BBB44F5D6EE4B40FAD170CADCAA41401BBB44F5D6EE4B40
80948	62018	35.143180999999998	35.752149000000003	56.243063999999997	55.757485000000003	Микрорайон	0103000020E610000001000000050000004C3448C153924140F41ABB44F5E04B404C3448C153924140DF6A9DB81C1F4C400C5C1E6B46E04140DF6A9DB81C1F4C400C5C1E6B46E04140F41ABB44F5E04B404C3448C153924140F41ABB44F5E04B40
80763	8140	35.648913999999998	35.673437999999997	56.097065999999998	56.084133999999999	Центральная	0103000020E6100000010000000500000051F52B9D0FD34140A73D25E7C40A4C4051F52B9D0FD34140DAC69FA86C0C4C401BF1643733D64140DAC69FA86C0C4C401BF1643733D64140A73D25E7C40A4C4051F52B9D0FD34140A73D25E7C40A4C40
72180	6454	39.400224999999999	39.436526000000001	55.576421000000003	55.552881999999997	Интернациональная	0103000020E610000001000000050000005305A3923AB3434006465ED6C4C64B405305A3923AB3434023DDCF29C8C94B4046ED7E15E0B7434023DDCF29C8C94B4046ED7E15E0B7434006465ED6C4C64B405305A3923AB3434006465ED6C4C64B40
6357	5601	39.554340000000003	39.559272	55.565340999999997	55.564633000000001	улица Дача Винтера	0103000020E61000000100000005000000AD6EF59CF4C64340069FE6E445C84B40AD6EF59CF4C64340410B09185DC84B40C5C8923996C74340410B09185DC84B40C5C8923996C74340069FE6E445C84B40AD6EF59CF4C64340069FE6E445C84B40
1639	5601	39.520536999999997	39.521146999999999	55.586511999999999	55.575454000000001	проспект Маршала Борзова	0103000020E61000000100000005000000D1ADD7F4A0C243401B2D077AA8C94B40D1ADD7F4A0C24340145B41D312CB4B404AB4E4F1B4C24340145B41D312CB4B404AB4E4F1B4C243401B2D077AA8C94B40D1ADD7F4A0C243401B2D077AA8C94B40
1575	5601	39.510305000000002	39.550522000000001	55.575836000000002	55.575225000000003	проспект Ильича	0103000020E610000001000000050000001EFE9AAC51C14340BA6B09F9A0C94B401EFE9AAC51C1434003EE79FEB4C94B4040DD408177C6434003EE79FEB4C94B4040DD408177C64340BA6B09F9A0C94B401EFE9AAC51C14340BA6B09F9A0C94B40
1530	5601	39.543568999999998	39.545447000000003	55.578237999999999	55.577174999999997	площадь Ленина	0103000020E61000000100000005000000490F43AB93C54340CE88D2DEE0C94B40490F43AB93C54340F8A6E9B303CA4B40C5591135D1C54340F8A6E9B303CA4B40C5591135D1C54340CE88D2DEE0C94B40490F43AB93C54340CE88D2DEE0C94B40
79986	5601	39.520913999999998	39.537945999999998	55.582070000000002	55.581398	Спортивная	0103000020E61000000100000005000000A703594FADC24340DBFAE93F6BCA4B40A703594FADC24340CAFD0E4581CA4B40CB811E6ADBC44340CAFD0E4581CA4B40CB811E6ADBC44340DBFAE93F6BCA4B40A703594FADC24340DBFAE93F6BCA4B40
81027	5601	39.502372999999999	39.518030000000003	55.571362000000001	55.570818000000003	Новый Тупик	0103000020E610000001000000050000005BB22AC24DC04340ECFB709010C94B405BB22AC24DC04340AD16D86322C94B40672C9ACE4EC24340AD16D86322C94B40672C9ACE4EC24340ECFB709010C94B405BB22AC24DC04340ECFB709010C94B40
1558	5601	39.544269999999997	39.546075999999999	55.583235000000002	55.578074999999998	Московская улица	0103000020E61000000100000005000000D218ADA3AAC543404ED1915CFEC94B40D218ADA3AAC54340F870C971A7CA4B40B49080D1E5C54340F870C971A7CA4B40B49080D1E5C543404ED1915CFEC94B40D218ADA3AAC543404ED1915CFEC94B40
1679	5601	39.534433	39.539400999999998	55.574375000000003	55.573118000000001	Конный проезд	0103000020E610000001000000050000009B73F04C68C44340DD5F3DEE5BC94B409B73F04C68C44340EC51B81E85C94B4000378B170BC54340EC51B81E85C94B4000378B170BC54340DD5F3DEE5BC94B409B73F04C68C44340DD5F3DEE5BC94B40
80519	5601	39.521057999999996	39.538789999999999	55.577942999999998	55.577215000000002	Жарова	0103000020E61000000100000005000000DAA84E07B2C243405DE15D2EE2C94B40DAA84E07B2C24340DFF94509FAC94B40B7B41A12F7C44340DFF94509FAC94B40B7B41A12F7C443405DE15D2EE2C94B40DAA84E07B2C243405DE15D2EE2C94B40
80759	7586	39.534263000000003	39.555974999999997	55.295724	55.279922999999997	Центральная	0103000020E610000001000000050000003F3BE0BA62C44340F8325184D4A34B403F3BE0BA62C443403752B648DAA54B40613255302AC743403752B648DAA54B40613255302AC74340F8325184D4A34B403F3BE0BA62C44340F8325184D4A34B40
81011	62055	39.972991	40.040266000000003	55.566414999999999	55.529964999999997	Вокзальная	0103000020E61000000100000005000000B32616F88AFC43402783A3E4D5C34B40B32616F88AFC43405F7B664980C84B400492B06F270544405F7B664980C84B400492B06F270544402783A3E4D5C34B40B32616F88AFC43402783A3E4D5C34B40
71852	6872	39.972991	40.040266000000003	55.566414999999999	55.529964999999997	Вокзальная	0103000020E61000000100000005000000B32616F88AFC43402783A3E4D5C34B40B32616F88AFC43405F7B664980C84B400492B06F270544405F7B664980C84B400492B06F270544402783A3E4D5C34B40B32616F88AFC43402783A3E4D5C34B40
71832	7276	39.77599	39.816972	55.569651999999998	55.550051000000003	Горького	0103000020E61000000100000005000000F302ECA353E34340E910381268C64B40F302ECA353E34340ED0C535BEAC84B40B5DFDA8992E84340ED0C535BEAC84B40B5DFDA8992E84340E910381268C64B40F302ECA353E34340E910381268C64B40
74094	7846	39.779888999999997	39.80903	55.137548000000002	55.120980000000003	Клубная	0103000020E610000001000000050000004CC11A67D3E343402CBCCB457C8F4B404CC11A67D3E34340ABD0402C9B914B40CFBD874B8EE74340ABD0402C9B914B40CFBD874B8EE743402CBCCB457C8F4B404CC11A67D3E343402CBCCB457C8F4B40
80768	6955	39.936995000000003	39.954853999999997	55.606389999999998	55.598613999999998	Школьная	0103000020E61000000100000005000000FDC1C073EFF74340C07630629FCC4B40FDC1C073EFF743408B4F01309ECD4B40363AE7A738FA43408B4F01309ECD4B40363AE7A738FA4340C07630629FCC4B40FDC1C073EFF74340C07630629FCC4B40
81010	7012	40.010683999999998	40.046042	55.601858999999997	55.584150999999999	Парковая	0103000020E61000000100000005000000944BE3175E0144407D76C075C5CA4B40944BE3175E014440D1E638B709CD4B40081F4AB4E4054440D1E638B709CD4B40081F4AB4E40544407D76C075C5CA4B40944BE3175E0144407D76C075C5CA4B40
80744	7201	39.651519999999998	39.672953999999997	55.483351999999996	55.472943999999998	Клубная	0103000020E610000001000000050000004F58E20165D34340726BD26D89BC4B404F58E20165D34340643A747ADEBD4B402FDB4E5B23D64340643A747ADEBD4B402FDB4E5B23D64340726BD26D89BC4B404F58E20165D34340726BD26D89BC4B40
71850	6609	39.715722	39.759363	55.726446000000003	55.709986999999998	Советская	0103000020E610000001000000050000008C834BC79CDB4340E6CAA0DAE0DA4B408C834BC79CDB4340AF27BA2EFCDC4B406F6589CE32E14340AF27BA2EFCDC4B406F6589CE32E14340E6CAA0DAE0DA4B408C834BC79CDB4340E6CAA0DAE0DA4B40
72182	6609	39.715722	39.759363	55.726446000000003	55.709986999999998	Луначарского	0103000020E610000001000000050000008C834BC79CDB4340E6CAA0DAE0DA4B408C834BC79CDB4340AF27BA2EFCDC4B406F6589CE32E14340AF27BA2EFCDC4B406F6589CE32E14340E6CAA0DAE0DA4B408C834BC79CDB4340E6CAA0DAE0DA4B40
80761	7037	39.655085999999997	39.702804999999998	55.569997999999998	55.548324000000001	Центральная	0103000020E61000000100000005000000A208A9DBD9D3434053CE177B2FC64B40A208A9DBD9D343408864C8B1F5C84B408E3BA583F5D943408864C8B1F5C84B408E3BA583F5D9434053CE177B2FC64B40A208A9DBD9D3434053CE177B2FC64B40
74093	7285	39.808428999999997	39.841540000000002	55.329358999999997	55.309012000000003	Пролетарская	0103000020E61000000100000005000000A911FA997AE74340290989B48DA74B40A911FA997AE7434056D28A6F28AA4B404F232D95B7EB434056D28A6F28AA4B404F232D95B7EB4340290989B48DA74B40A911FA997AE74340290989B48DA74B40
1073	3514	37.463475000000003	37.487918999999998	55.156630999999997	55.155642999999998	улица Полиграфистов	0103000020E61000000100000005000000BEC1172653BB4240F86C1D1CEC934B40BEC1172653BB424017450F7C0C944B406B0C3A2174BE424017450F7C0C944B406B0C3A2174BE4240F86C1D1CEC934B40BEC1172653BB4240F86C1D1CEC934B40
1162	3514	37.421523999999998	37.442086000000003	55.151091000000001	55.149763999999998	улица Гарнаева	0103000020E61000000100000005000000533D997FF4B542401F0F7D772B934B40533D997FF4B5424027DC2BF356934B407E02284696B8424027DC2BF356934B407E02284696B842401F0F7D772B934B40533D997FF4B542401F0F7D772B934B40
1105	3514	37.412235000000003	37.442086000000003	55.175894	55.149763999999998	улица Гагарина	0103000020E610000001000000050000001FA2D11DC4B442401F0F7D772B934B401FA2D11DC4B4424004C8D0B183964B407E02284696B8424004C8D0B183964B407E02284696B842401F0F7D772B934B401FA2D11DC4B442401F0F7D772B934B40
74125	3514	37.452129999999997	37.488295999999998	55.148400000000002	55.140996000000001	Чехова	0103000020E610000001000000050000002EC55565DFB94240F46E2C280C924B402EC55565DFB94240FB5C6DC5FE924B404162BB7B80BE4240FB5C6DC5FE924B404162BB7B80BE4240F46E2C280C924B402EC55565DFB94240F46E2C280C924B40
1049	3514	37.450971000000003	37.464984999999999	55.156630999999997	55.138840000000002	Московская улица	0103000020E61000000100000005000000E338F06AB9B9424036B05582C5914B40E338F06AB9B9424017450F7C0C944B40B610E4A084BB424017450F7C0C944B40B610E4A084BB424036B05582C5914B40E338F06AB9B9424036B05582C5914B40
1027	3514	37.466825999999998	37.469906999999999	55.155715000000001	55.149841000000002	Молодежная улица	0103000020E61000000100000005000000147651F4C0BB4240CB4C69FD2D934B40147651F4C0BB4240923F1878EE934B40AB949EE925BC4240923F1878EE934B40AB949EE925BC4240CB4C69FD2D934B40147651F4C0BB4240CB4C69FD2D934B40
80284	3514	37.460312999999999	37.478566999999998	55.152597999999998	55.149954000000001	Мира	0103000020E610000001000000050000003A765089EBBA4240C3F352B131934B403A765089EBBA4240AEB7CD5488934B40F0F8F6AE41BD4240AEB7CD5488934B40F0F8F6AE41BD4240C3F352B131934B403A765089EBBA4240C3F352B131934B40
79869	3514	37.455992000000002	37.460700000000003	55.149532000000001	55.144624	Лопасненская	0103000020E610000001000000050000006B9E23F25DBA4240BD1B0B0A83924B406B9E23F25DBA42404DDA54DD23934B4034A2B437F8BA42404DDA54DD23934B4034A2B437F8BA4240BD1B0B0A83924B406B9E23F25DBA4240BD1B0B0A83924B40
1056	3514	37.465738999999999	37.471128999999998	55.173853000000001	55.167045999999999	Земская улица	0103000020E6100000010000000500000062BCE6559DBB4240BC7669C361954B4062BCE6559DBB4240DFA7AAD040964B403D997FF44DBC4240DFA7AAD040964B403D997FF44DBC4240BC7669C361954B4062BCE6559DBB4240BC7669C361954B40
74058	5021	37.475135000000002	37.507268000000003	55.194650000000003	55.173051000000001	Вокзальная	0103000020E61000000100000005000000AD174339D1BC424022C5008926964B40AD174339D1BC42404D158C4AEA984B4057276728EEC042404D158C4AEA984B4057276728EEC0424022C5008926964B40AD174339D1BC424022C5008926964B40
80743	5255	37.137754999999999	37.166213999999997	55.153441999999998	55.136400999999999	Платонова	0103000020E6100000010000000500000024EEB1F4A19142402312859675914B4024EEB1F4A19142409AEAC9FCA3934B4094111780469542409AEAC9FCA3934B4094111780469542402312859675914B4024EEB1F4A19142402312859675914B40
71769	59155	37.592267	37.617688999999999	55.065066000000002	55.054743000000002	Новая	0103000020E6100000010000000500000001C0B167CFCB4240AC5791D101874B4001C0B167CFCB4240700A2B1554884B40AA0CE36E10CF4240700A2B1554884B40AA0CE36E10CF4240AC5791D101874B4001C0B167CFCB4240AC5791D101874B40
80046	61920	37.527894000000003	37.562730000000002	55.256247000000002	55.232351000000001	Заводская	0103000020E6100000010000000500000098E0D40792C34240B11875ADBD9D4B4098E0D40792C342405C59A2B3CCA04B40323D618907C842405C59A2B3CCA04B40323D618907C84240B11875ADBD9D4B4098E0D40792C34240B11875ADBD9D4B40
80749	61972	37.421030000000002	37.438052999999996	55.105161000000003	55.089582999999998	Русское поле	0103000020E610000001000000050000004451A04FE4B5424087A3AB74778B4B404451A04FE4B5424047E867EA758D4B401475E61E12B8424047E867EA758D4B401475E61E12B8424087A3AB74778B4B404451A04FE4B5424087A3AB74778B4B40
81008	30746	37.284970999999999	37.308480000000003	56.647004000000003	56.624054000000001	Шоссейная	0103000020E610000001000000050000007AA702EE79A4424010786000E14F4C407AA702EE79A44240CB30EE06D1524C402CBCCB457CA74240CB30EE06D1524C402CBCCB457CA7424010786000E14F4C407AA702EE79A4424010786000E14F4C40
7488	29255	37.527363999999999	37.529322000000001	56.744244000000002	56.731655000000003	улица Зины Голицыной	0103000020E610000001000000050000003B8BDEA980C342403A7AFCDEA65D4C403B8BDEA980C34240431F2C63435F4C40D386C3D2C0C34240431F2C63435F4C40D386C3D2C0C342403A7AFCDEA65D4C403B8BDEA980C342403A7AFCDEA65D4C40
71847	29255	37.500773000000002	37.562766000000003	56.746070000000003	56.711373999999999	микрорайон Юбилейный	0103000020E6100000010000000500000023DC645419C04240C39CA04D0E5B4C4023DC645419C042406C43C5387F5F4C407FA65EB708C842406C43C5387F5F4C407FA65EB708C84240C39CA04D0E5B4C4023DC645419C04240C39CA04D0E5B4C40
71848	29255	37.500773000000002	37.562766000000003	56.746070000000003	56.711373999999999	микрорайон ПМК-21	0103000020E6100000010000000500000023DC645419C04240C39CA04D0E5B4C4023DC645419C042406C43C5387F5F4C407FA65EB708C842406C43C5387F5F4C407FA65EB708C84240C39CA04D0E5B4C4023DC645419C04240C39CA04D0E5B4C40
72415	29255	37.500773000000002	37.562766000000003	56.746070000000003	56.711373999999999	Микрорайон Юбилейный	0103000020E6100000010000000500000023DC645419C04240C39CA04D0E5B4C4023DC645419C042406C43C5387F5F4C407FA65EB708C842406C43C5387F5F4C407FA65EB708C84240C39CA04D0E5B4C4023DC645419C04240C39CA04D0E5B4C40
74106	60241	37.611759999999997	37.632888999999999	56.733426999999999	56.720933000000002	Клубная	0103000020E610000001000000050000001F80D4264ECE4240B8CD5488475C4C401F80D4264ECE42406F8099EFE05D4C40C37FBA8102D142406F8099EFE05D4C40C37FBA8102D14240B8CD5488475C4C401F80D4264ECE4240B8CD5488475C4C40
80742	30352	37.611148999999997	37.628397	56.557032999999997	56.548166999999999	Садовая	0103000020E61000000100000005000000D6FD63213ACE42408BDF14562A464C40D6FD63213ACE424079E57ADB4C474C40C7F319506FD0424079E57ADB4C474C40C7F319506FD042408BDF14562A464C40D6FD63213ACE42408BDF14562A464C40
71831	29869	37.385159999999999	37.475611999999998	56.580857999999999	56.523488	Пролетарский переулок	0103000020E610000001000000050000001ADD41EC4CB142409AEC9FA701434C401ADD41EC4CB142405BCF108E594A4C40E6CAA0DAE0BC42405BCF108E594A4C40E6CAA0DAE0BC42409AEC9FA701434C401ADD41EC4CB142409AEC9FA701434C40
72416	29869	37.385159999999999	37.475611999999998	56.580857999999999	56.523488	МУ Дворец культуры "Прогресс"	0103000020E610000001000000050000001ADD41EC4CB142409AEC9FA701434C401ADD41EC4CB142405BCF108E594A4C40E6CAA0DAE0BC42405BCF108E594A4C40E6CAA0DAE0BC42409AEC9FA701434C401ADD41EC4CB142409AEC9FA701434C40
71830	29869	37.385159999999999	37.475611999999998	56.580857999999999	56.523488	Ленина	0103000020E610000001000000050000001ADD41EC4CB142409AEC9FA701434C401ADD41EC4CB142405BCF108E594A4C40E6CAA0DAE0BC42405BCF108E594A4C40E6CAA0DAE0BC42409AEC9FA701434C401ADD41EC4CB142409AEC9FA701434C40
72419	29869	37.385159999999999	37.475611999999998	56.580857999999999	56.523488	Карла Маркса	0103000020E610000001000000050000001ADD41EC4CB142409AEC9FA701434C401ADD41EC4CB142405BCF108E594A4C40E6CAA0DAE0BC42405BCF108E594A4C40E6CAA0DAE0BC42409AEC9FA701434C401ADD41EC4CB142409AEC9FA701434C40
71839	29869	37.385159999999999	37.475611999999998	56.580857999999999	56.523488	К.Маркса	0103000020E610000001000000050000001ADD41EC4CB142409AEC9FA701434C401ADD41EC4CB142405BCF108E594A4C40E6CAA0DAE0BC42405BCF108E594A4C40E6CAA0DAE0BC42409AEC9FA701434C401ADD41EC4CB142409AEC9FA701434C40
71875	29625	37.554789	37.630293000000002	56.550821999999997	56.518746	Советская	0103000020E610000001000000050000001C97715303C742402577D84466424C401C97715303C742406AF5D55581464C40E9F2E670ADD042406AF5D55581464C40E9F2E670ADD042402577D84466424C401C97715303C742402577D84466424C40
71829	29625	37.554789	37.630293000000002	56.550821999999997	56.518746	Рубцова	0103000020E610000001000000050000001C97715303C742402577D84466424C401C97715303C742406AF5D55581464C40E9F2E670ADD042406AF5D55581464C40E9F2E670ADD042402577D84466424C401C97715303C742402577D84466424C40
71782	28328	37.974032999999999	38.000416000000001	55.059120999999998	55.044592999999999	Совхозная	0103000020E61000000100000005000000C51C041DADFC4240B5503239B5854B40C51C041DADFC4240DFC0E44691874B409432A9A10D004340DFC0E44691874B409432A9A10D004340B5503239B5854B40C51C041DADFC4240B5503239B5854B40
80740	29241	37.813189000000001	37.844189999999998	55.015082999999997	54.990664000000002	Школьная	0103000020E61000000100000005000000C53BC09316E842408BA9F413CE7E4B40C53BC09316E84240DFDC5F3DEE814B401CCEFC6A0EEC4240DFDC5F3DEE814B401CCEFC6A0EEC42408BA9F413CE7E4B40C53BC09316E842408BA9F413CE7E4B40
72113	28793	37.878632000000003	37.912641999999998	55.148637000000001	55.136164000000001	Пролетарская	0103000020E610000001000000050000000B9C6C0377F042403F726BD26D914B400B9C6C0377F04240DFFC868906934B405F7AFB73D1F44240DFFC868906934B405F7AFB73D1F442403F726BD26D914B400B9C6C0377F042403F726BD26D914B40
72115	28801	37.928614000000003	37.946356000000002	55.221418999999997	55.209519	Ленина	0103000020E61000000100000005000000CB4DD4D2DCF642400072C284D19A4B40CB4DD4D2DCF6424044DB3175579C4B40CB2F833122F9424044DB3175579C4B40CB2F833122F942400072C284D19A4B40CB4DD4D2DCF642400072C284D19A4B40
6950	13685	38.049509	38.084553	54.885435000000001	54.883130999999999	улица Чайковского	0103000020E61000000100000005000000C8ED974F56064340B98AC56F0A714B40C8ED974F56064340ECDD1FEF55714B40ACE3F8A1D20A4340ECDD1FEF55714B40ACE3F8A1D20A4340B98AC56F0A714B40C8ED974F56064340B98AC56F0A714B40
7170	13685	38.063307000000002	38.068913000000002	54.894689	54.879060000000003	улица Калинина	0103000020E61000000100000005000000CF4D9B711A084340639CBF0985704B40CF4D9B711A084340A48B4D2B85724B4077A22424D2084340A48B4D2B85724B4077A22424D2084340639CBF0985704B40CF4D9B711A084340639CBF0985704B40
7126	13685	38.050595999999999	38.094110999999998	54.888770000000001	54.885869999999997	улица Андропова	0103000020E610000001000000050000007AA702EE79064340F6402B3064714B407AA702EE790643403DD52137C3714B40D09849D40B0C43403DD52137C3714B40D09849D40B0C4340F6402B3064714B407AA702EE79064340F6402B3064714B40
7140	13685	38.075893000000001	38.081677999999997	54.904561000000001	54.872678000000001	проспект Победы	0103000020E61000000100000005000000677FA0DCB609434027F8A6E9B36F4B40677FA0DCB6094340581EA4A7C8734B40BE66B96C740A4340581EA4A7C8734B40BE66B96C740A434027F8A6E9B36F4B40677FA0DCB609434027F8A6E9B36F4B40
80453	13685	38.049509	38.084553	54.885435000000001	54.883130999999999	Чайковского	0103000020E61000000100000005000000C8ED974F56064340B98AC56F0A714B40C8ED974F56064340ECDD1FEF55714B40ACE3F8A1D20A4340ECDD1FEF55714B40ACE3F8A1D20A4340B98AC56F0A714B40C8ED974F56064340B98AC56F0A714B40
80450	13685	38.072946000000002	38.092663999999999	54.891722000000001	54.891064	Тимирязева	0103000020E61000000100000005000000E02F664B560943404C5299620E724B40E02F664B56094340D68F4DF223724B401EC2F869DC0B4340D68F4DF223724B401EC2F869DC0B43404C5299620E724B40E02F664B560943404C5299620E724B40
80469	13685	38.059013	38.067323000000002	54.879598999999999	54.879033999999997	Службина	0103000020E61000000100000005000000F984ECBC8D0743403909A52F84704B40F984ECBC8D074340124C35B396704B4062A2410A9E084340124C35B396704B4062A2410A9E0843403909A52F84704B40F984ECBC8D0743403909A52F84704B40
79802	13685	38.070673999999997	38.076072000000003	54.896853	54.879469	Куйбышева	0103000020E61000000100000005000000B8567BD80B094340446CB07092704B40B8567BD80B094340E5284014CC724B40171230BABC094340E5284014CC724B40171230BABC094340446CB07092704B40B8567BD80B094340446CB07092704B40
80463	13685	38.050595999999999	38.094110999999998	54.888770000000001	54.885869999999997	Андропова	0103000020E610000001000000050000007AA702EE79064340F6402B3064714B407AA702EE790643403DD52137C3714B40D09849D40B0C43403DD52137C3714B40D09849D40B0C4340F6402B3064714B407AA702EE79064340F6402B3064714B40
71846	13685	38.028892999999997	38.167225000000002	54.920506000000003	54.853205000000003	Авиаторов	0103000020E61000000100000005000000AA0A0DC4B203434050E449D2356D4B40AA0A0DC4B2034340CAE2FE23D3754B406C09F9A067154340CAE2FE23D3754B406C09F9A06715434050E449D2356D4B40AA0A0DC4B203434050E449D2356D4B40
9928	28219	38.130294999999997	38.153596999999998	54.959784999999997	54.934040000000003	Центральная	0103000020E6100000010000000500000089EAAD81AD104340F3936A9F8E774B4089EAAD81AD1043407E18213CDA7A4B40C1E10511A91343407E18213CDA7A4B40C1E10511A9134340F3936A9F8E774B4089EAAD81AD104340F3936A9F8E774B40
71780	28272	37.949221000000001	37.975776000000003	54.984734000000003	54.964509	Дружбы	0103000020E6100000010000000500000095D6DF1280F942404DD9E907757B4B4095D6DF1280F9424030A182C30B7E4B40611C5C3AE6FC424030A182C30B7E4B40611C5C3AE6FC42404DD9E907757B4B4095D6DF1280F942404DD9E907757B4B40
72117	29187	37.746713999999997	37.784390000000002	55.071061	55.053438	40 лет Победы	0103000020E6100000010000000500000090BB085394DF42408C2E6F0ED7864B4090BB085394DF4240B282DF8618894B409CA73AE466E44240B282DF8618894B409CA73AE466E442408C2E6F0ED7864B4090BB085394DF42408C2E6F0ED7864B40
72265	28599	37.915678	37.995781000000001	55.142890000000001	55.101385000000001	Московская	0103000020E6100000010000000500000056D5CBEF34F5424009A7052FFA8C4B4056D5CBEF34F54240757632384A924B40357D76C075FF4240757632384A924B40357D76C075FF424009A7052FFA8C4B4056D5CBEF34F5424009A7052FFA8C4B40
80738	28975	38.348801000000002	38.371051999999999	55.204037999999997	55.189957999999997	Новая	0103000020E61000000100000005000000F3E7DB82A52C434089CE328B50984B40F3E7DB82A52C43401492CCEA1D9A4B40C58EC6A17E2F43401492CCEA1D9A4B40C58EC6A17E2F434089CE328B50984B40F3E7DB82A52C434089CE328B50984B40
74138	60254	38.143248	38.212283999999997	55.127007999999996	55.089733000000003	Промышленная	0103000020E61000000100000005000000D49B51F3551243409D2FF65E7C8B4B40D49B51F355124340492A53CC41904B4066BB421F2C1B4340492A53CC41904B4066BB421F2C1B43409D2FF65E7C8B4B40D49B51F3551243409D2FF65E7C8B4B40
71913	29110	38.274473999999998	38.294685999999999	55.068525000000001	55.053128999999998	Центральная	0103000020E6100000010000000500000018CDCAF6212343400EBC5AEECC864B4018CDCAF621234340ADFA5C6DC5884B40664B5645B8254340ADFA5C6DC5884B40664B5645B82543400EBC5AEECC864B4018CDCAF6212343400EBC5AEECC864B40
80748	29131	37.824302000000003	37.857745999999999	55.083486999999998	55.070298000000001	Школьная	0103000020E6100000010000000500000082035ABA82E94240B37C5D86FF884B4082035ABA82E942401152B7B3AF8A4B402D23F59ECAED42401152B7B3AF8A4B402D23F59ECAED4240B37C5D86FF884B4082035ABA82E94240B37C5D86FF884B40
72395	28315	38.007252999999999	38.037939000000001	54.991692	54.976664	Комсомольская	0103000020E6100000010000000500000021E692AAED0043401C977153037D4B4021E692AAED00434038DA71C3EF7E4B40191F662FDB04434038DA71C3EF7E4B40191F662FDB0443401C977153037D4B4021E692AAED0043401C977153037D4B40
72420	28529	38.101152999999996	38.131624000000002	55.111685999999999	55.097996000000002	Новые дома	0103000020E610000001000000050000003672DD94F20C4340C59107228B8C4B403672DD94F20C4340E5B512BA4B8E4B4032AF230ED9104340E5B512BA4B8E4B4032AF230ED9104340C59107228B8C4B403672DD94F20C4340C59107228B8C4B40
72399	29063	38.317422999999998	38.346060999999999	55.120942999999997	55.101942000000001	Новоселов	0103000020E61000000100000005000000C5FF1D51A12843405F0B7A6F0C8D4B40C5FF1D51A12843400ED76A0F7B8F4B40E5B512BA4B2C43400ED76A0F7B8F4B40E5B512BA4B2C43405F0B7A6F0C8D4B40C5FF1D51A12843405F0B7A6F0C8D4B40
80736	28880	38.277951000000002	38.297255999999997	55.154860999999997	55.141305000000003	Шоссейная	0103000020E61000000100000005000000FC71FBE59323434072E1404816924B40FC71FBE5932343408236397CD2934B4017450F7C0C2643408236397CD2934B4017450F7C0C26434072E1404816924B40FC71FBE59323434072E1404816924B40
74086	49694	37.157105000000001	37.184728	56.038997000000002	56.024687	микрорайон Новые дома	0103000020E61000000100000005000000E08442041C94424074D190F128034C40E08442041C94424031D28BDAFD044C40E753C72AA597424031D28BDAFD044C40E753C72AA597424074D190F128034C40E08442041C94424074D190F128034C40
6718	11017	36.949773999999998	36.959026000000001	56.174039	56.170530999999997	Школьная улица	0103000020E61000000100000005000000A94BC6319279424022FAB5F5D3154C40A94BC63192794240419DF2E846164C40C1012D5DC17A4240419DF2E846164C40C1012D5DC17A424022FAB5F5D3154C40A94BC6319279424022FAB5F5D3154C40
80871	11017	36.972259000000001	36.976526	56.180202000000001	56.171011999999997	Стеклозаводская	0103000020E61000000100000005000000EF1EA0FB727C42409D9CA1B8E3154C40EF1EA0FB727C42403F56F0DB10174C40CBD8D0CDFE7C42403F56F0DB10174C40CBD8D0CDFE7C42409D9CA1B8E3154C40EF1EA0FB727C42409D9CA1B8E3154C40
80435	11017	36.973641999999998	36.979346	56.186424000000002	56.184285000000003	Советская	0103000020E610000001000000050000008A01124DA07C42405A12A0A696174C408A01124DA07C42404298DBBDDC174C40F5BBB0355B7D42404298DBBDDC174C40F5BBB0355B7D42405A12A0A696174C408A01124DA07C42405A12A0A696174C40
79980	11017	36.972617999999997	36.985221000000003	56.188147000000001	56.179661000000003	Почтовая	0103000020E610000001000000050000001EC022BF7E7C4240EFAEB321FF164C401EC022BF7E7C424096EB6D3315184C408D2AC3B81B7E424096EB6D3315184C408D2AC3B81B7E4240EFAEB321FF164C401EC022BF7E7C4240EFAEB321FF164C40
6702	11017	36.947932000000002	36.970049000000003	56.183923999999998	56.172555000000003	Обуховская улица	0103000020E610000001000000050000007B6AF5D55579424072E1404816164C407B6AF5D555794240897956D28A174C403E42CD902A7C4240897956D28A174C403E42CD902A7C424072E1404816164C407B6AF5D55579424072E1404816164C40
74065	11017	36.993808999999999	37.003475000000002	56.181600000000003	56.177230999999999	Мкр. Рекинцо	0103000020E6100000010000000500000038BC2022357F42402F6B6281AF164C4038BC2022357F4240107A36AB3E174C4043AD69DE71804240107A36AB3E174C4043AD69DE718042402F6B6281AF164C4038BC2022357F42402F6B6281AF164C40
80428	11017	36.957453999999998	36.996755999999998	56.200057000000001	56.175536999999998	Красная	0103000020E6100000010000000500000052B648DA8D7A4240751E15FF77164C4052B648DA8D7A4240FE2AC0779B194C40BF0B5BB3957F4240FE2AC0779B194C40BF0B5BB3957F4240751E15FF77164C4052B648DA8D7A4240751E15FF77164C40
80430	11017	36.978645999999998	36.991114000000003	56.190241	56.182371000000003	Дзержинского	0103000020E610000001000000050000003C2EAA45447D4240925ED4EE57174C403C2EAA45447D4240DEAD2CD159184C40CB4DD4D2DC7E4240DEAD2CD159184C40CB4DD4D2DC7E4240925ED4EE57174C403C2EAA45447D4240925ED4EE57174C40
74087	49692	37.112206999999998	37.156224999999999	56.079718999999997	56.066654999999997	микрорайон Механического завода № 1	0103000020E61000000100000005000000EEB089CC5C8E4240B48EAA2688084C40EEB089CC5C8E424056EF703B340A4C40A7E8482EFF93424056EF703B340A4C40A7E8482EFF934240B48EAA2688084C40EEB089CC5C8E4240B48EAA2688084C40
71924	24931	37.039721999999998	37.083596	56.092801999999999	56.058869999999999	микрорайон Поваровка	0103000020E610000001000000050000004277499C15854240965B5A0D89074C404277499C158542406F8099EFE00B4C40C8091346B38A42406F8099EFE00B4C40C8091346B38A4240965B5A0D89074C404277499C15854240965B5A0D89074C40
71827	24931	37.039721999999998	37.083596	56.092801999999999	56.058869999999999	МКР№2	0103000020E610000001000000050000004277499C15854240965B5A0D89074C404277499C158542406F8099EFE00B4C40C8091346B38A42406F8099EFE00B4C40C8091346B38A4240965B5A0D89074C404277499C15854240965B5A0D89074C40
71814	24931	37.039721999999998	37.083596	56.092801999999999	56.058869999999999	МЕХЛЕСХОЗА	0103000020E610000001000000050000004277499C15854240965B5A0D89074C404277499C158542406F8099EFE00B4C40C8091346B38A42406F8099EFE00B4C40C8091346B38A4240965B5A0D89074C404277499C15854240965B5A0D89074C40
6477	24762	37.232689000000001	37.240513999999997	56.040244000000001	56.037165999999999	улица Куйбышева	0103000020E61000000100000005000000C991CEC0C89D4240F64201DBC1044C40C991CEC0C89D42401CEE23B726054C40751DAA29C99E42401CEE23B726054C40751DAA29C99E4240F64201DBC1044C40C991CEC0C89D4240F64201DBC1044C40
74064	60223	36.709896999999998	37.427757999999997	56.365741999999997	55.884878	Центральная усадьба	0103000020E61000000100000005000000A643A7E7DD5A42409679ABAE43F14B40A643A7E7DD5A4240066344A2D02E4C401A4D2EC6C0B64240066344A2D02E4C401A4D2EC6C0B642409679ABAE43F14B40A643A7E7DD5A42409679ABAE43F14B40
80904	62015	37.224065000000003	37.236784999999998	55.915488000000003	55.907328999999997	Липовая Аллея	0103000020E61000000100000005000000D1967329AE9C42402FDB4E5B23F44B40D1967329AE9C4240B3F0F5B52EF54B4078978BF84E9E4240B3F0F5B52EF54B4078978BF84E9E42402FDB4E5B23F44B40D1967329AE9C42402FDB4E5B23F44B40
2398	341	37.124478000000003	37.125771999999998	56.011394000000003	56.001761000000002	Первомайская улица	0103000020E61000000100000005000000278925E5EE8F424042B456B439004C40278925E5EE8F424071AFCC5B75014C405260014C1990424071AFCC5B75014C405260014C1990424042B456B439004C40278925E5EE8F424042B456B439004C40
80141	341	37.124478000000003	37.125771999999998	56.011394000000003	56.001761000000002	Первомайская	0103000020E61000000100000005000000278925E5EE8F424042B456B439004C40278925E5EE8F424071AFCC5B75014C405260014C1990424071AFCC5B75014C405260014C1990424042B456B439004C40278925E5EE8F424042B456B439004C40
837	3247	37.346578000000001	37.369295999999999	54.904555999999999	54.898851000000001	улица Ленина	0103000020E61000000100000005000000ADC1FBAA5CAC42400B7DB08C0D734B40ADC1FBAA5CAC424046B3B27DC8734B409545611745AF424046B3B27DC8734B409545611745AF42400B7DB08C0D734B40ADC1FBAA5CAC42400B7DB08C0D734B40
80716	48300	38.692298999999998	38.724252	54.443480999999998	54.423020999999999	Запрудная	0103000020E61000000100000005000000D906EE409D584340B742588D25364B40D906EE409D584340DDB243FCC3384B4003081F4AB45C4340DDB243FCC3384B4003081F4AB45C4340B742588D25364B40D906EE409D584340B742588D25364B40
71973	46759	38.596564999999998	38.62912	54.556837999999999	54.527312000000002	Советская	0103000020E610000001000000050000001878EE3D5C4C4340E964A9F57E434B401878EE3D5C4C4340C495B37746474B4038A1100187504340C495B37746474B4038A1100187504340E964A9F57E434B401878EE3D5C4C4340E964A9F57E434B40
80304	59148	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	Школьная	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
79990	59148	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	Центральный	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
71772	59148	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	И.Садофьева	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
81078	59148	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	Большая Луговая	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
80331	61914	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	микрорайон Западный	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
81021	61914	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	Привокзальная	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
80003	61914	38.692326000000001	38.752046	54.500531000000002	54.447937000000003	Первомайская	0103000020E61000000100000005000000D3156C239E5843408DD5E6FF55394B40D3156C239E5843402DD1596611404B40378B170B436043402DD1596611404B40378B170B436043408DD5E6FF55394B40D3156C239E5843408DD5E6FF55394B40
80734	5274	38.550328999999998	38.588048999999998	54.345556999999999	54.310141999999999	микрорайон Юбилейный	0103000020E610000001000000050000002B85402E71464340DA8EA9BBB2274B402B85402E71464340B2F336363B2C4B4006B98B30454B4340B2F336363B2C4B4006B98B30454B4340DA8EA9BBB2274B402B85402E71464340DA8EA9BBB2274B40
80732	5274	38.550328999999998	38.588048999999998	54.345556999999999	54.310141999999999	м-он Юбилейный	0103000020E610000001000000050000002B85402E71464340DA8EA9BBB2274B402B85402E71464340B2F336363B2C4B4006B98B30454B4340B2F336363B2C4B4006B98B30454B4340DA8EA9BBB2274B402B85402E71464340DA8EA9BBB2274B40
80760	3492	38.661828	38.693142999999999	54.340533999999998	54.322510000000001	Школьная	0103000020E61000000100000005000000DEC9A7C7B65443400551F70148294B40DEC9A7C7B654434089963C9E962B4B40C539EAE8B858434089963C9E962B4B40C539EAE8B85843400551F70148294B40DEC9A7C7B65443400551F70148294B40
71902	59547	38.061816	38.099105000000002	56.531922999999999	56.511539999999997	мкр. Новый	0103000020E610000001000000050000004D2F3196E9074340444C89247A414C404D2F3196E9074340BF7E880D16444C405FEFFE78AF0C4340BF7E880D16444C405FEFFE78AF0C4340444C89247A414C404D2F3196E9074340444C89247A414C40
79801	59547	38.061816	38.099105000000002	56.531922999999999	56.511539999999997	Центральная	0103000020E610000001000000050000004D2F3196E9074340444C89247A414C404D2F3196E9074340BF7E880D16444C405FEFFE78AF0C4340BF7E880D16444C405FEFFE78AF0C4340444C89247A414C404D2F3196E9074340444C89247A414C40
80281	3067	37.983725999999997	37.993552999999999	56.247320999999999	56.244720000000001	Седина	0103000020E61000000100000005000000C91CCBBBEAFD4240AC5626FC521F4C40C91CCBBBEAFD4240984EEB36A81F4C40DDEBA4BE2CFF4240984EEB36A81F4C40DDEBA4BE2CFF4240AC5626FC521F4C40C91CCBBBEAFD4240AC5626FC521F4C40
80299	3067	37.983294000000001	37.984741	56.269745999999998	56.269626000000002	Пушкина	0103000020E61000000100000005000000302DEA93DCFD42405E13D21A83224C40302DEA93DCFD4240081D740987224C40E2033BFE0BFE4240081D740987224C40E2033BFE0BFE42405E13D21A83224C40302DEA93DCFD42405E13D21A83224C40
80290	3067	38.004998000000001	38.011277	56.264077	56.259672999999999	Октябрьская	0103000020E61000000100000005000000D04543C6A3004340BD5301F73C214C40D04543C6A30043401A506F46CD214C4037195586710143401A506F46CD214C403719558671014340BD5301F73C214C40D04543C6A3004340BD5301F73C214C40
79924	3067	37.977212999999999	37.985756000000002	56.253596999999999	56.251902000000001	Майолик	0103000020E61000000100000005000000EF1CCA5015FD424004E621533E204C40EF1CCA5015FD42408EAED2DD75204C40FBEAAA402DFE42408EAED2DD75204C40FBEAAA402DFE424004E621533E204C40EF1CCA5015FD424004E621533E204C40
79858	3067	37.977032999999999	37.982180999999997	56.259507999999997	56.244394999999997	 Михеенко	0103000020E610000001000000050000006F0ED76A0FFD42402827DA55481F4C406F0ED76A0FFD42407286E28E37214C4054E0641BB8FD42407286E28E37214C4054E0641BB8FD42402827DA55481F4C406F0ED76A0FFD42402827DA55481F4C40
80777	48407	37.918256	37.929637999999997	56.621523000000003	56.61289	Школьная	0103000020E610000001000000050000008AADA06989F54240D105F52D734E4C408AADA06989F542401D5BCF108E4F4C40368FC360FEF642401D5BCF108E4F4C40368FC360FEF64240D105F52D734E4C408AADA06989F54240D105F52D734E4C40
4637	15436	38.144146999999997	38.144604999999999	56.316113999999999	56.311801000000003	улица Леонида Булавина	0103000020E610000001000000050000008368AD687312434018EE5C18E9274C408368AD687312434064E76D6C76284C4046EBA86A8212434064E76D6C76284C4046EBA86A8212434018EE5C18E9274C408368AD687312434018EE5C18E9274C40
4569	15436	38.156750000000002	38.165635000000002	56.324691000000001	56.318047	улица 40 лет Октября	0103000020E61000000100000005000000F2D24D6210144340A3CB9BC3B5284C40F2D24D62101443401C2785798F294C4057091687331543401C2785798F294C405709168733154340A3CB9BC3B5284C40F2D24D6210144340A3CB9BC3B5284C40
4399	15436	38.127096999999999	38.159122000000004	56.334975999999997	56.292437999999997	проспект Красной Армии	0103000020E61000000100000005000000B935E9B644104340C70DBF9B6E254C40B935E9B644104340F2785A7EE02A4C407D09151C5E144340F2785A7EE02A4C407D09151C5E144340C70DBF9B6E254C40B935E9B644104340C70DBF9B6E254C40
15815	15436	38.177959000000001	38.185361999999998	56.302712	56.301338999999999	бульвар Свободы	0103000020E61000000100000005000000B2834A5CC71643403201BF4692264C40B2834A5CC7164340AA0D4E44BF264C40E8F527F1B9174340AA0D4E44BF264C40E8F527F1B91743403201BF4692264C40B2834A5CC71643403201BF4692264C40
80112	15436	38.177959000000001	38.185361999999998	56.302712	56.301338999999999	бульвар Свободы	0103000020E61000000100000005000000B2834A5CC71643403201BF4692264C40B2834A5CC7164340AA0D4E44BF264C40E8F527F1B9174340AA0D4E44BF264C40E8F527F1B91743403201BF4692264C40B2834A5CC71643403201BF4692264C40
80240	15436	38.180546999999997	38.188991000000001	56.304110999999999	56.302388000000001	Ясная	0103000020E610000001000000050000000932022A1C174340F75965A6B4264C400932022A1C1743404BADF71BED264C40821E6ADB301843404BADF71BED264C40821E6ADB30184340F75965A6B4264C400932022A1C174340F75965A6B4264C40
4621	15436	38.170180000000002	38.200777000000002	56.309159000000001	56.297313000000003	Ярославское шоссе	0103000020E6100000010000000500000076374F75C81543407CD6355A0E264C4076374F75C8154340CD21A98592274C40FE648C0FB3194340CD21A98592274C40FE648C0FB31943407CD6355A0E264C4076374F75C81543407CD6355A0E264C40
80047	15436	38.121285	38.121375	56.295290000000001	56.290244999999999	Школьная	0103000020E61000000100000005000000683F5244860F4340EC6987BF26254C40683F5244860F4340FD6A0E10CC254C40A8C64B37890F4340FD6A0E10CC254C40A8C64B37890F4340EC6987BF26254C40683F5244860F4340EC6987BF26254C40
4332	15436	38.170180000000002	38.200777000000002	56.309159000000001	56.297313000000003	Хотьковский проезд	0103000020E6100000010000000500000076374F75C81543407CD6355A0E264C4076374F75C8154340CD21A98592274C40FE648C0FB3194340CD21A98592274C40FE648C0FB31943407CD6355A0E264C4076374F75C81543407CD6355A0E264C40
74307	15436	38.100479999999997	38.116568999999998	56.312255	56.311231999999997	Советская	0103000020E6100000010000000500000077F35487DC0C4340FDBB3E73D6274C4077F35487DC0C43409981CAF8F7274C401C5DA5BBEB0E43409981CAF8F7274C401C5DA5BBEB0E4340FDBB3E73D6274C4077F35487DC0C4340FDBB3E73D6274C40
4772	15436	38.170180000000002	38.200777000000002	56.309159000000001	56.297313000000003	Скобяное шоссе	0103000020E6100000010000000500000076374F75C81543407CD6355A0E264C4076374F75C8154340CD21A98592274C40FE648C0FB3194340CD21A98592274C40FE648C0FB31943407CD6355A0E264C4076374F75C81543407CD6355A0E264C40
80000	15436	38.162903999999997	38.165202999999998	56.314427000000002	56.306567999999999	Парковая	0103000020E610000001000000050000009C31CC09DA1443400400C79E3D274C409C31CC09DA1443405DFDD8243F284C40BD19355F251543405DFDD8243F284C40BD19355F251543400400C79E3D274C409C31CC09DA1443400400C79E3D274C40
4780	15436	38.170180000000002	38.200777000000002	56.309159000000001	56.297313000000003	Московское шоссе	0103000020E6100000010000000500000076374F75C81543407CD6355A0E264C4076374F75C8154340CD21A98592274C40FE648C0FB3194340CD21A98592274C40FE648C0FB31943407CD6355A0E264C4076374F75C81543407CD6355A0E264C40
80175	15436	38.139744999999998	38.147165000000001	56.326957	56.324561000000003	Матросова	0103000020E61000000100000005000000C763062AE31143404E4700378B294C40C763062AE311434061191BBAD9294C40D40E7F4DD612434061191BBAD9294C40D40E7F4DD61243404E4700378B294C40C763062AE31143404E4700378B294C40
4760	15436	38.170180000000002	38.200777000000002	56.309159000000001	56.297313000000003	Клубная улица	0103000020E6100000010000000500000076374F75C81543407CD6355A0E264C4076374F75C8154340CD21A98592274C40FE648C0FB3194340CD21A98592274C40FE648C0FB31943407CD6355A0E264C4076374F75C81543407CD6355A0E264C40
79968	15436	38.146068999999997	38.146473	56.315980000000003	56.311720999999999	Карла Либкнехта	0103000020E61000000100000005000000CEFA9463B2124340FB3C4679E6274C40CEFA9463B212434055185B0872284C409E5F94A0BF12434055185B0872284C409E5F94A0BF124340FB3C4679E6274C40CEFA9463B2124340FB3C4679E6274C40
80213	15436	38.048817999999997	38.067484999999998	56.289490000000001	56.283515000000001	Институтская	0103000020E6100000010000000500000062BA10AB3F064340757632384A244C4062BA10AB3F064340704221020E254C403BFC3559A3084340704221020E254C403BFC3559A3084340757632384A244C4062BA10AB3F064340757632384A244C40
4675	15436	38.145440000000001	38.155672000000003	56.304690000000001	56.296548999999999	Железнодорожная улица	0103000020E61000000100000005000000DFC325C79D124340AC545051F5254C40DFC325C79D12434089B5F81400274C409373620FED13434089B5F81400274C409373620FED134340AC545051F5254C40DFC325C79D124340AC545051F5254C40
79969	15436	38.142879999999998	38.156750000000002	56.328643999999997	56.324516000000003	Глинки	0103000020E6100000010000000500000051A04FE449124340AE8383BD89294C4051A04FE4491243406803B001112A4C40F2D24D62101443406803B001112A4C40F2D24D6210144340AE8383BD89294C4051A04FE449124340AE8383BD89294C40
4414	15436	38.170180000000002	38.200777000000002	56.309159000000001	56.297313000000003	Вознесенская улица	0103000020E6100000010000000500000076374F75C81543407CD6355A0E264C4076374F75C8154340CD21A98592274C40FE648C0FB3194340CD21A98592274C40FE648C0FB31943407CD6355A0E264C4076374F75C81543407CD6355A0E264C40
81044	15436	38.128489000000002	38.134867	56.309724000000003	56.293261999999999	Вознесенская	0103000020E61000000100000005000000A872DA53721043406C94F59B89254C40A872DA5372104340A6643909A5274C40A227655243114340A6643909A5274C40A2276552431143406C94F59B89254C40A872DA53721043406C94F59B89254C40
80133	15436	38.131309999999999	38.134050000000002	56.324671000000002	56.313567999999997	1-й Ударной Армии	0103000020E61000000100000005000000A2D11DC4CE1043403B8908FF22284C40A2D11DC4CE104340D57ABFD18E294C40B003E78C28114340D57ABFD18E294C40B003E78C281143403B8908FF22284C40A2D11DC4CE1043403B8908FF22284C40
80295	17824	38.082512999999999	38.099096000000003	56.451568000000002	56.449553000000002	Институтская	0103000020E61000000100000005000000573F36C98F0A4340CB68E4F38A394C40573F36C98F0A4340C7F5EFFACC394C400C957F2DAF0C4340C7F5EFFACC394C400C957F2DAF0C4340CB68E4F38A394C40573F36C98F0A4340CB68E4F38A394C40
71834	30164	37.891505000000002	37.900666999999999	56.334032999999998	56.330165999999998	8 Марта	0103000020E61000000100000005000000399CF9D51CF24240252026E1422A4C40399CF9D51CF242407364E597C12A4C4010CB660E49F342407364E597C12A4C4010CB660E49F34240252026E1422A4C40399CF9D51CF24240252026E1422A4C40
80005	61913	38.171751999999998	38.173116999999998	56.415913000000003	56.409210000000002	Строителей	0103000020E61000000100000005000000E48233F8FB1543401C9947FE60344C40E48233F8FB1543409A7D1EA33C354C40D9B0A6B2281643409A7D1EA33C354C40D9B0A6B2281643401C9947FE60344C40E48233F8FB1543401C9947FE60344C40
80004	61913	38.172704000000003	38.178488999999999	56.420099999999998	56.415180999999997	Советская улица	0103000020E61000000100000005000000B7F1272A1B164340D575A8A624354C40B7F1272A1B164340598638D6C5354C400ED940BAD8164340598638D6C5354C400ED940BAD8164340D575A8A624354C40B7F1272A1B164340D575A8A624354C40
4989	16736	38.232908999999999	38.253686999999999	56.445464000000001	56.437835999999997	улица 1 Мая	0103000020E61000000100000005000000D7F84CF6CF1D4340778192020B384C40D7F84CF6CF1D4340CEC5DFF604394C40CE35CCD078204340CEC5DFF604394C40CE35CCD078204340778192020B384C40D7F84CF6CF1D4340778192020B384C40
80267	16736	38.243769999999998	38.245396	56.440601999999998	56.438347999999998	Трудовые Резервы	0103000020E610000001000000050000007ADFF8DA331F43402D228AC91B384C407ADFF8DA331F4340AE4676A565384C40DC48D922691F4340AE4676A565384C40DC48D922691F43402D228AC91B384C407ADFF8DA331F43402D228AC91B384C40
80722	16736	38.243760999999999	38.244875	56.438347999999998	56.435402000000003	Новая	0103000020E610000001000000050000002785798F331F4340774EB340BB374C402785798F331F43402D228AC91B384C40D34D6210581F43402D228AC91B384C40D34D6210581F4340774EB340BB374C402785798F331F4340774EB340BB374C40
80255	16736	38.210990000000002	38.232908999999999	56.445464000000001	56.433520999999999	Горького	0103000020E610000001000000050000003BE466B8011B43408A90BA9D7D374C403BE466B8011B4340CEC5DFF604394C40D7F84CF6CF1D4340CEC5DFF604394C40D7F84CF6CF1D43408A90BA9D7D374C403BE466B8011B43408A90BA9D7D374C40
80731	20012	38.004890000000003	38.050426000000002	56.558571000000001	56.543776000000001	Октябрьская	0103000020E61000000100000005000000EA094B3CA0004340C32CB4739A454C40EA094B3CA00043403CBF28417F474C401E6FF25B740643403CBF28417F474C401E6FF25B74064340C32CB4739A454C40EA094B3CA0004340C32CB4739A454C40
72082	19148	38.285280999999998	38.315285000000003	56.399248	56.385581000000002	Полевая	0103000020E61000000100000005000000C8957A1684244340C07ADCB75A314C40C8957A1684244340287FF78E1A334C40AEF545425B284340287FF78E1A334C40AEF545425B284340C07ADCB75A314C40C8957A1684244340C07ADCB75A314C40
80775	17897	38.371276999999999	38.383557000000003	56.272295	56.267676999999999	микрорайон	0103000020E61000000100000005000000E5603601862F434019726C3D43224C40E5603601862F4340A2EE0390DA224C407193516518314340A2EE0390DA224C40719351651831434019726C3D43224C40E5603601862F434019726C3D43224C40
80920	45676	36.438830000000003	36.504900999999997	55.622604000000003	55.571775000000002	Студенческая	0103000020E610000001000000050000007940D9942B384240D0D556EC2FC94B407940D9942B384240ED2DE57CB1CF4B40DD5B9198A0404240ED2DE57CB1CF4B40DD5B9198A0404240D0D556EC2FC94B407940D9942B384240D0D556EC2FC94B40
81035	45676	36.438830000000003	36.504900999999997	55.622604000000003	55.571775000000002	Привокзальная	0103000020E610000001000000050000007940D9942B384240D0D556EC2FC94B407940D9942B384240ED2DE57CB1CF4B40DD5B9198A0404240ED2DE57CB1CF4B40DD5B9198A0404240D0D556EC2FC94B407940D9942B384240D0D556EC2FC94B40
72065	45676	36.438830000000003	36.504900999999997	55.622604000000003	55.571775000000002	Восточный микрорайон	0103000020E610000001000000050000007940D9942B384240D0D556EC2FC94B407940D9942B384240ED2DE57CB1CF4B40DD5B9198A0404240ED2DE57CB1CF4B40DD5B9198A0404240D0D556EC2FC94B407940D9942B384240D0D556EC2FC94B40
71776	45676	36.438830000000003	36.504900999999997	55.622604000000003	55.571775000000002	Восточный микрорайон	0103000020E610000001000000050000007940D9942B384240D0D556EC2FC94B407940D9942B384240ED2DE57CB1CF4B40DD5B9198A0404240ED2DE57CB1CF4B40DD5B9198A0404240D0D556EC2FC94B407940D9942B384240D0D556EC2FC94B40
71770	48542	36.216343999999999	36.234687999999998	55.967899000000003	55.953764999999997	Нерудная	0103000020E61000000100000005000000C9570229B11B4240E388B5F814FA4B40C9570229B11B4240626A4B1DE4FB4B40BF61A2410A1E4240626A4B1DE4FB4B40BF61A2410A1E4240E388B5F814FA4B40C9570229B11B4240E388B5F814FA4B40
81083	13943	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	ул. Федеративная	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
81032	13943	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	Щербакова	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
79799	13943	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	Социалистическая	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
79964	13943	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	Микрорайон	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
80048	13943	36.156795000000002	36.226602999999997	55.717466999999999	55.685563999999999	Волоколамское шоссе	0103000020E610000001000000050000009296CADB1114424050A8A78FC0D74B409296CADB11144240C87A6AF5D5DB4B407616BD53011D4240C87A6AF5D5DB4B407616BD53011D424050A8A78FC0D74B409296CADB1114424050A8A78FC0D74B40
71910	15268	36.511046	36.546914999999998	55.678057000000003	55.656128000000002	Красная Горка	0103000020E61000000100000005000000356090F469414240B5FE9600FCD34B40356090F46941424075E95F92CAD64B408E588B4F0146424075E95F92CAD64B408E588B4F01464240B5FE9600FCD34B40356090F469414240B5FE9600FCD34B40
72346	14842	36.351083000000003	36.397112	55.568548	55.535488000000001	Невкипелого	0103000020E610000001000000050000003E97A949F02C424042B3EBDE8AC44B403E97A949F02C4240651A4D2EC6C84B40B16CE690D4324240651A4D2EC6C84B40B16CE690D432424042B3EBDE8AC44B403E97A949F02C424042B3EBDE8AC44B40
80727	14522	36.433359000000003	36.443277000000002	55.912666999999999	55.903039999999997	Центральная	0103000020E61000000100000005000000B136C64E783742406B7D91D096F34B40B136C64E78374240B891B245D2F44B40D508FD4CBD384240B891B245D2F44B40D508FD4CBD3842406B7D91D096F34B40B136C64E783742406B7D91D096F34B40
71824	12029	38.363335999999997	38.385362000000001	55.513688000000002	55.494522000000003	Мира	0103000020E61000000100000005000000CFBA46CB812E43408693347F4CBF4B40CFBA46CB812E4340802C4487C0C14B40828FC18A53314340802C4487C0C14B40828FC18A533143408693347F4CBF4B40CFBA46CB812E43408693347F4CBF4B40
80999	9244	38.136924	38.179909000000002	55.643337000000002	55.611840999999998	Школьная	0103000020E61000000100000005000000CD04C3B9861143400CAD4ECE50CE4B40CD04C3B98611434044A7E7DD58D24B40C7A013420717434044A7E7DD58D24B40C7A01342071743400CAD4ECE50CE4B40CD04C3B9861143400CAD4ECE50CE4B40
67078	9807	38.016460000000002	38.06673	55.646213000000003	55.621789999999997	Солнцева	0103000020E6100000010000000500000099D87C5C1B0243406B7D91D096CF4B4099D87C5C1B02434002A08A1BB7D24B40BFD4CF9B8A08434002A08A1BB7D24B40BFD4CF9B8A0843406B7D91D096CF4B4099D87C5C1B0243406B7D91D096CF4B40
79790	9807	38.049644000000001	38.054720000000003	55.642950999999996	55.633555999999999	Первомайская	0103000020E61000000100000005000000A8380EBC5A064340A017EE5C18D14B40A8380EBC5A0643401AF7E6374CD24B40F437A110010743401AF7E6374CD24B40F437A11001074340A017EE5C18D14B40A8380EBC5A064340A017EE5C18D14B40
80128	9807	38.047057000000002	38.050192000000003	55.637759000000003	55.634293	Октябрьская 	0103000020E610000001000000050000002106BAF605064340768A558330D14B402106BAF60506434066DD3F16A2D14B40AB4203B16C06434066DD3F16A2D14B40AB4203B16C064340768A558330D14B402106BAF605064340768A558330D14B40
80695	9807	38.032674999999998	38.044119000000002	55.634247000000002	55.623502999999999	Горячева	0103000020E61000000100000005000000CA32C4B12E0443409CFA40F2CECF4B40CA32C4B12E044340064B75012FD14B40ED10FFB0A5054340064B75012FD14B40ED10FFB0A50543409CFA40F2CECF4B40CA32C4B12E0443409CFA40F2CECF4B40
80957	11828	38.223889999999997	38.243977000000001	55.486632	55.473643000000003	Садовая	0103000020E6100000010000000500000062F3716DA81C43405B7D7555A0BC4B4062F3716DA81C4340F29716F549BE4B40F4FC69A33A1F4340F29716F549BE4B40F4FC69A33A1F43405B7D7555A0BC4B4062F3716DA81C43405B7D7555A0BC4B40
72061	9648	38.041936999999997	38.100228000000001	55.656773000000001	55.643942000000003	Трудовая	0103000020E6100000010000000500000005BF0D315E054340AB4203B16CD24B4005BF0D315E054340AAF23D2311D44B405E126745D40C4340AAF23D2311D44B405E126745D40C4340AB4203B16CD24B4005BF0D315E054340AB4203B16CD24B40
79981	61910	37.517698000000003	38.180959999999999	56.742446999999999	55.649484000000001	Центральная	0103000020E61000000100000005000000319A95ED43C242403CA3AD4A22D34B40319A95ED43C24240B401D880085F4C402CF180B229174340B401D880085F4C402CF180B2291743403CA3AD4A22D34B40319A95ED43C242403CA3AD4A22D34B40
72064	12365	38.437778999999999	38.489108999999999	55.607416999999998	55.590311999999997	Центральная	0103000020E6100000010000000500000013F06B2409384340DA37F7578FCB4B4013F06B240938434068041BD7BFCD4B40F296AB1F9B3E434068041BD7BFCD4B40F296AB1F9B3E4340DA37F7578FCB4B4013F06B2409384340DA37F7578FCB4B40
2422	8168	38.232703000000001	38.238874000000003	55.576385999999999	55.563941	улица Гурьева	0103000020E610000001000000050000002E573F36C91D4340D0EFFB372FC84B402E573F36C91D4340A6EF3504C7C94B40AFEE586C931E4340A6EF3504C7C94B40AFEE586C931E4340D0EFFB372FC84B402E573F36C91D4340D0EFFB372FC84B40
71887	8168	38.163891999999997	38.288882999999998	55.596584999999997	55.542797999999998	поселок Красный Октябрь	0103000020E61000000100000005000000BB09BE69FA144340C72AA5677AC54B40BB09BE69FA1443405F24B4E55CCC4B4068AF3E1EFA2443405F24B4E55CCC4B4068AF3E1EFA244340C72AA5677AC54B40BB09BE69FA144340C72AA5677AC54B40
80059	8168	38.197865999999998	38.216174000000002	55.583244999999998	55.571953000000001	Чугунова	0103000020E61000000100000005000000C37E4FAC53194340AFEC82C135C94B40C37E4FAC531943401B47ACC5A7CA4B406D1FF296AB1B43401B47ACC5A7CA4B406D1FF296AB1B4340AFEC82C135C94B40C37E4FAC53194340AFEC82C135C94B40
79953	8168	38.197488999999997	38.202213999999998	55.568089000000001	55.560988000000002	Серова	0103000020E61000000100000005000000ED28CE514719434067B96C74CEC74B40ED28CE5147194340D21BEE23B7C84B408C65FA25E2194340D21BEE23B7C84B408C65FA25E219434067B96C74CEC74B40ED28CE514719434067B96C74CEC74B40
80683	8168	38.224958999999998	38.272103000000001	55.568838	55.552627000000001	Михалевича	0103000020E610000001000000050000006EF8DD74CB1C43407CF1457BBCC64B406EF8DD74CB1C43406C5CFFAECFC84B405E126745D42243406C5CFFAECFC84B405E126745D42243407CF1457BBCC64B406EF8DD74CB1C43407CF1457BBCC64B40
80686	8168	38.230609999999999	38.274527999999997	55.572156	55.565778000000002	Красноармейская	0103000020E61000000100000005000000B610E4A0841D4340ED65DB696BC84B40B610E4A0841D4340E71A66683CC94B400BEBC6BB23234340E71A66683CC94B400BEBC6BB23234340ED65DB696BC84B40B610E4A0841D4340ED65DB696BC84B40
2235	8168	38.203975	38.211970000000001	55.593456000000003	55.582827999999999	Коммунистическая улица	0103000020E61000000100000005000000CE1951DA1B1A4340B7989F1B9ACA4B40CE1951DA1B1A4340B8CEBF5DF6CB4B40D7DD3CD5211B4340B8CEBF5DF6CB4B40D7DD3CD5211B4340B7989F1B9ACA4B40CE1951DA1B1A4340B7989F1B9ACA4B40
80090	8168	38.203975	38.211970000000001	55.593456000000003	55.582827999999999	Коммунистическая	0103000020E61000000100000005000000CE1951DA1B1A4340B7989F1B9ACA4B40CE1951DA1B1A4340B8CEBF5DF6CB4B40D7DD3CD5211B4340B8CEBF5DF6CB4B40D7DD3CD5211B4340B7989F1B9ACA4B40CE1951DA1B1A4340B7989F1B9ACA4B40
80690	8168	38.240563000000002	38.246653999999999	55.570552999999997	55.563605000000003	Коминтерна	0103000020E6100000010000000500000057D0B4C4CA1E4340596E693524C84B4057D0B4C4CA1E43403DD175E107C94B40BBB6B75B921F43403DD175E107C94B40BBB6B75B921F4340596E693524C84B4057D0B4C4CA1E4340596E693524C84B40
79950	8168	38.244183	38.245961999999999	55.576909999999998	55.573388000000001	Интернациональная 	0103000020E610000001000000050000009D9E7763411F43409DF529C764C94B409D9E7763411F4340205ED72FD8C94B408507CDAE7B1F4340205ED72FD8C94B408507CDAE7B1F43409DF529C764C94B409D9E7763411F43409DF529C764C94B40
80684	8168	38.206983999999999	38.214897999999998	55.575454000000001	55.570909	Воровского	0103000020E61000000100000005000000CB65A3737E1A4340FCFECD8B13C94B40CB65A3737E1A43401B2D077AA8C94B40E7FC14C7811B43401B2D077AA8C94B40E7FC14C7811B4340FCFECD8B13C94B40CB65A3737E1A4340FCFECD8B13C94B40
80985	48034	38.109561999999997	38.141272000000001	55.372374999999998	55.361773999999997	Советская	0103000020E610000001000000050000003271AB20060E43408445459C4EAE4B403271AB20060E43408B6CE7FBA9AF4B4096EB6D33151243408B6CE7FBA9AF4B4096EB6D33151243408445459C4EAE4B403271AB20060E43408445459C4EAE4B40
80960	12067	38.411000000000001	38.443860999999998	55.546154000000001	55.533791999999998	Центральная	0103000020E61000000100000005000000F853E3A59B344340E76ED74B53C44B40F853E3A59B344340304AD05FE8C54B40247CEF6FD0384340304AD05FE8C54B40247CEF6FD0384340E76ED74B53C44B40F853E3A59B344340E76ED74B53C44B40
2997	10584	37.982377999999997	38.012849000000003	55.600872000000003	55.583159000000002	Центральная улица	0103000020E61000000100000005000000AA27F38FBEFD42401DAF40F4A4CA4B40AA27F38FBEFD4240838AAA5FE9CC4B40A6643909A5014340838AAA5FE9CC4B40A6643909A50143401DAF40F4A4CA4B40AA27F38FBEFD42401DAF40F4A4CA4B40
3015	10584	37.977240000000002	37.983851000000001	55.601059999999997	55.596727000000001	Подмосковная улица	0103000020E61000000100000005000000E92B483316FD4240F2D1E28C61CC4B40E92B483316FD42408577B988EFCC4B4086915ED4EEFD42408577B988EFCC4B4086915ED4EEFD4240F2D1E28C61CC4B40E92B483316FD4240F2D1E28C61CC4B40
74102	11666	\N	\N	\N	\N	Ленинская	\N
80726	11137	38.141506	38.173917000000003	55.289397999999998	55.275021000000002	Центральная	0103000020E6100000010000000500000009185DDE1C1243404B5B5CE333A34B4009185DDE1C1243408FC360FE0AA54B40F69B89E9421643408FC360FE0AA54B40F69B89E9421643404B5B5CE333A34B4009185DDE1C1243404B5B5CE333A34B40
71876	11598	37.517698000000003	38.180959999999999	56.742446999999999	55.649484000000001	Центральная	0103000020E61000000100000005000000319A95ED43C242403CA3AD4A22D34B40319A95ED43C24240B401D880085F4C402CF180B229174340B401D880085F4C402CF180B2291743403CA3AD4A22D34B40319A95ED43C242403CA3AD4A22D34B40
72057	9286	38.121087000000003	38.204746999999998	55.623086999999998	55.571820000000002	Мира	0103000020E61000000100000005000000427C60C77F0F43407099D36531C94B40427C60C77F0F434008C89750C1CF4B40207A5226351A434008C89750C1CF4B40207A5226351A43407099D36531C94B40427C60C77F0F43407099D36531C94B40
80853	9286	38.157378999999999	38.170448999999998	55.592596	55.587142999999998	Карла Маркса	0103000020E61000000100000005000000E109BDFE24144340A489778027CB4B40E109BDFE24144340C6DE8B2FDACB4B406551D845D1154340C6DE8B2FDACB4B406551D845D1154340A489778027CB4B40E109BDFE24144340A489778027CB4B40
79962	61905	38.142170999999998	38.157378999999999	55.592596	55.584730999999998	Центральная	0103000020E6100000010000000500000045B8C9A8321243408BFA2477D8CA4B4045B8C9A832124340C6DE8B2FDACB4B40E109BDFE24144340C6DE8B2FDACB4B40E109BDFE241443408BFA2477D8CA4B4045B8C9A8321243408BFA2477D8CA4B40
79796	11203	38.247093999999997	38.253526000000001	55.552520000000001	55.550285000000002	Школьная	0103000020E61000000100000005000000D784B4C6A01F43405C3D27BD6FC64B40D784B4C6A01F43406631B1F9B8C64B40C5573B8A732043406631B1F9B8C64B40C5573B8A732043405C3D27BD6FC64B40D784B4C6A01F43405C3D27BD6FC64B40
80697	61872	38.094569	38.114879999999999	55.628616999999998	55.619117000000003	Первомайская	0103000020E61000000100000005000000931B45D61A0C4340E6B2D1393FCF4B40931B45D61A0C4340D55A988576D04B40747B4963B40E4340D55A988576D04B40747B4963B40E4340E6B2D1393FCF4B40931B45D61A0C4340E6B2D1393FCF4B40
79822	61872	38.101709999999997	38.131129999999999	55.630009000000001	55.616193000000003	Октябрьская	0103000020E610000001000000050000008CD651D5040D434017838769DFCE4B408CD651D5040D4340C4978922A4D04B4022C32ADEC8104340C4978922A4D04B4022C32ADEC810434017838769DFCE4B408CD651D5040D434017838769DFCE4B40
2916	9407	38.094650000000001	38.100489000000003	55.615969999999997	55.610762999999999	улица Опаленной Юности	0103000020E610000001000000050000008048BF7D1D0C4340AD4D637B2DCE4B408048BF7D1D0C434097A8DE1AD8CE4B40CB4DD4D2DC0C434097A8DE1AD8CE4B40CB4DD4D2DC0C4340AD4D637B2DCE4B408048BF7D1D0C4340AD4D637B2DCE4B40
80685	9407	38.087445000000002	38.117376999999998	55.623477999999999	55.610925999999999	Ленинская	0103000020E610000001000000050000007099D365310B43405723BBD232CE4B407099D365310B434043E38920CECF4B40BB26A435060F434043E38920CECF4B40BB26A435060F43405723BBD232CE4B407099D365310B43405723BBD232CE4B40
79842	61876	38.059857999999998	38.060406	55.644775000000003	55.639446	Кирова	0103000020E61000000100000005000000B5334C6DA90743406DC7D45DD9D14B40B5334C6DA9074340A323B9FC87D24B40B83D4162BB074340A323B9FC87D24B40B83D4162BB0743406DC7D45DD9D14B40B5334C6DA90743406DC7D45DD9D14B40
80729	11852	38.310172999999999	38.321834000000003	55.544320999999997	55.539171000000003	Спортивная 	0103000020E61000000100000005000000158DB5BFB3274340CFF9298E03C54B40158DB5BFB327434054C37E4FACC54B40D55E44DB3129434054C37E4FACC54B40D55E44DB31294340CFF9298E03C54B40158DB5BFB3274340CFF9298E03C54B40
71835	11649	38.323405999999999	38.34545	55.514288999999998	55.504067999999997	Ленина	0103000020E6100000010000000500000043AA285E65294340E57ADB4C85C04B4043AA285E65294340A5D8D138D4C14B409C33A2B4372C4340A5D8D138D4C14B409C33A2B4372C4340E57ADB4C85C04B4043AA285E65294340E57ADB4C85C04B40
74197	9127	38.247211	38.254828000000003	55.581102999999999	55.578313999999999	Октябрьская	0103000020E61000000100000005000000111B2C9CA41F4340D368723106CA4B40111B2C9CA41F4340C24D469561CA4B40740D33349E204340C24D469561CA4B40740D33349E204340D368723106CA4B40111B2C9CA41F4340D368723106CA4B40
72384	9763	38.071328999999999	38.101297000000002	55.658484000000001	55.649779000000002	Кооперативная	0103000020E61000000100000005000000D120054F21094340555051F52BD34B40D120054F210943403A78263449D44B406A17D34CF70C43403A78263449D44B406A17D34CF70C4340555051F52BD34B40D120054F21094340555051F52BD34B40
81016	10504	37.966855000000002	37.992718000000004	55.553305000000002	55.542324000000001	Центральная	0103000020E61000000100000005000000AF7C96E7C1FB4240FFEA71DF6AC54B40AF7C96E7C1FB42404DDBBFB2D2C64B404513286211FF42404DDBBFB2D2C64B404513286211FF4240FFEA71DF6AC54B40AF7C96E7C1FB4240FFEA71DF6AC54B40
635	2489	38.075811999999999	38.076107999999998	55.642372000000002	55.628342000000004	Школьная улица	0103000020E610000001000000050000007A522635B4094340045ABA826DD04B407A522635B4094340DDEEE53E39D24B40637B2DE8BD094340DDEEE53E39D24B40637B2DE8BD094340045ABA826DD04B407A522635B4094340045ABA826DD04B40
79956	2489	38.083412000000003	38.088200000000001	55.644201000000002	55.642885	Чапаева	0103000020E61000000100000005000000070C923EAD0A4340630B410E4AD24B40070C923EAD0A43407786A92D75D24B40ECC039234A0B43407786A92D75D24B40ECC039234A0B4340630B410E4AD24B40070C923EAD0A4340630B410E4AD24B40
79791	2489	38.069659000000001	38.073386999999997	55.631253999999998	55.627443	Станционная	0103000020E61000000100000005000000A06F0B96EA084340548D5E0D50D04B40A06F0B96EA0843400EBC5AEECCD04B40CC79C6BE640943400EBC5AEECCD04B40CC79C6BE64094340548D5E0D50D04B40A06F0B96EA084340548D5E0D50D04B40
79831	61874	38.075533	38.084975	55.623421999999998	55.620362	Чкалова	0103000020E610000001000000050000006762BA10AB09434030D7A20568CF4B406762BA10AB094340AFCDC64ACCCF4B4022FDF675E00A4340AFCDC64ACCCF4B4022FDF675E00A434030D7A20568CF4B406762BA10AB09434030D7A20568CF4B40
79830	61874	38.065615999999999	38.069837999999997	55.626131000000001	55.621673000000001	Советская	0103000020E61000000100000005000000130CE71A6608434032E719FB92CF4B40130CE71A660843408201840F25D04B404F029B73F00843408201840F25D04B404F029B73F008434032E719FB92CF4B40130CE71A6608434032E719FB92CF4B40
71808	10368	38.079701999999997	38.087372999999999	55.616844	55.613366999999997	Колхозная	0103000020E6100000010000000500000080B6D5AC330A43400AB952CF82CE4B4080B6D5AC330A4340EE5D83BEF4CE4B40D6C6D8092F0B4340EE5D83BEF4CE4B40D6C6D8092F0B43400AB952CF82CE4B4080B6D5AC330A43400AB952CF82CE4B40
80937	11529	38.287581000000003	38.324322000000002	55.462420999999999	55.447851	Центральная	0103000020E61000000100000005000000BAF94674CF2443408E3D7B2E53B94B40BAF94674CF244340E7FD7F9C30BB4B40C9AF1F6283294340E7FD7F9C30BB4B40C9AF1F62832943408E3D7B2E53B94B40BAF94674CF2443408E3D7B2E53B94B40
80682	61949	37.790238000000002	37.801465999999998	55.971653000000003	55.955882000000003	Главная	0103000020E610000001000000050000003A07CF8426E54240E46A64575AFA4B403A07CF8426E54240B80721205FFC4B408F6D197096E64240B80721205FFC4B408F6D197096E64240E46A64575AFA4B403A07CF8426E54240E46A64575AFA4B40
79954	61901	37.959910999999998	37.977787999999997	56.155092000000003	56.150759999999998	Школьная	0103000020E610000001000000050000000B09185DDEFA4240C1C58A1A4C134C400B09185DDEFA424085EFFD0DDA134C40EB353D2828FD424085EFFD0DDA134C40EB353D2828FD4240C1C58A1A4C134C400B09185DDEFA4240C1C58A1A4C134C40
71507	59472	37.689267000000001	38.187525999999998	56.230736999999998	55.942810999999999	Степаньковское шоссе	0103000020E61000000100000005000000249BABE639D842408FA7E507AEF84B40249BABE639D84240137D3ECA881D4C4029931ADA00184340137D3ECA881D4C4029931ADA001843408FA7E507AEF84B40249BABE639D842408FA7E507AEF84B40
80990	1881	37.805554000000001	37.809632000000001	55.968232	55.966845999999997	Школьная 	0103000020E61000000100000005000000BC94BA641CE742405B22179CC1FB4B40BC94BA641CE742406878B306EFFB4B40C5E57805A2E742406878B306EFFB4B40C5E57805A2E742405B22179CC1FB4B40BC94BA641CE742405B22179CC1FB4B40
679	1881	37.794657000000001	37.797271000000002	55.968392999999999	55.966282	Речная улица	0103000020E61000000100000005000000CC441152B7E54240535BEA20AFFB4B40CC441152B7E542407156444DF4FB4B404D86E3F90CE642407156444DF4FB4B404D86E3F90CE64240535BEA20AFFB4B40CC441152B7E54240535BEA20AFFB4B40
74282	60276	37.805903999999998	37.843319000000001	55.971476000000003	55.953997000000001	Большая Тарасовская	0103000020E6100000010000000500000098DBBDDC27E74240B6BDDD921CFA4B4098DBBDDC27E74240A96C585359FC4B40378C82E0F1EB4240A96C585359FC4B40378C82E0F1EB4240B6BDDD921CFA4B4098DBBDDC27E74240B6BDDD921CFA4B40
71768	59138	37.893704999999997	37.965310000000002	56.152540000000002	56.126382999999997	Тютчева	0103000020E61000000100000005000000C6A2E9EC64F242409BE271512D104C40C6A2E9EC64F242407AAA436E86134C403A4030478FFB42407AAA436E86134C403A4030478FFB42409BE271512D104C40C6A2E9EC64F242409BE271512D104C40
78635	59138	37.893704999999997	37.965310000000002	56.152540000000002	56.126382999999997	Крайняя	0103000020E61000000100000005000000C6A2E9EC64F242409BE271512D104C40C6A2E9EC64F242407AAA436E86134C403A4030478FFB42407AAA436E86134C403A4030478FFB42409BE271512D104C40C6A2E9EC64F242409BE271512D104C40
80992	61906	37.950614000000002	37.976179999999999	56.130040999999999	56.112161	Талицы	0103000020E61000000100000005000000548F34B8ADF942407E71A94A5B0E4C40548F34B8ADF94240CF11F92EA5104C4030815B77F3FC4240CF11F92EA5104C4030815B77F3FC42407E71A94A5B0E4C40548F34B8ADF942407E71A94A5B0E4C40
79963	61906	37.893704999999997	37.965310000000002	56.152540000000002	56.126382999999997	Полевая	0103000020E61000000100000005000000C6A2E9EC64F242409BE271512D104C40C6A2E9EC64F242407AAA436E86134C403A4030478FFB42407AAA436E86134C403A4030478FFB42409BE271512D104C40C6A2E9EC64F242409BE271512D104C40
80998	61906	37.893704999999997	37.965310000000002	56.152540000000002	56.126382999999997	Дальняя	0103000020E61000000100000005000000C6A2E9EC64F242409BE271512D104C40C6A2E9EC64F242407AAA436E86134C403A4030478FFB42407AAA436E86134C403A4030478FFB42409BE271512D104C40C6A2E9EC64F242409BE271512D104C40
15594	4327	37.830418999999999	37.855150000000002	56.045105999999997	56.044995999999998	улица Коминтерна	0103000020E610000001000000050000000F7D772B4BEA4240B439CE6DC2054C400F7D772B4BEA42403B6D8D08C6054C405396218E75ED42403B6D8D08C6054C405396218E75ED4240B439CE6DC2054C400F7D772B4BEA4240B439CE6DC2054C40
1371	4327	37.860593999999999	37.866981000000003	55.996066999999996	55.992331	улица Инессы Арманд	0103000020E610000001000000050000002191B6F127EE42404BE7C3B304FF4B402191B6F127EE4240FACF9A1F7FFF4B406FA0C03BF9EE4240FACF9A1F7FFF4B406FA0C03BF9EE42404BE7C3B304FF4B402191B6F127EE42404BE7C3B304FF4B40
80898	4327	37.857844999999998	37.858375000000002	56.037393000000002	56.036029999999997	пр.Дзержинского	0103000020E61000000100000005000000C0046EDDCDED424062D68BA19C044C40C0046EDDCDED4240B70C384BC9044C401D5A643BDFED4240B70C384BC9044C401D5A643BDFED424062D68BA19C044C40C0046EDDCDED424062D68BA19C044C40
1405	4327	37.838639000000001	37.877975999999997	56.012481000000001	55.964131000000002	Ярославское шоссе	0103000020E610000001000000050000003813D38558EB4240A70705A568FB4B403813D38558EB4240236937FA98014C4021567F8461F04240236937FA98014C4021567F8461F04240A70705A568FB4B403813D38558EB4240A70705A568FB4B40
79976	4327	37.808509000000001	37.813720000000004	56.005893	56.001981999999998	Школьная	0103000020E61000000100000005000000C6C210397DE74240209738F240004C40C6C210397DE742403E23111AC1004C40F20C1AFA27E842403E23111AC1004C40F20C1AFA27E84240209738F240004C40C6C210397DE74240209738F240004C40
80505	4327	37.844999000000001	37.852904000000002	56.008741999999998	56.003380999999997	Чехова	0103000020E610000001000000050000008C135FED28EC4240C136E2C96E004C408C135FED28EC4240020D36751E014C40555051F52BED4240020D36751E014C40555051F52BED4240C136E2C96E004C408C135FED28EC4240C136E2C96E004C40
15735	4327	37.846265000000002	37.852266	55.985987000000002	55.985095999999999	Фабричная улица	0103000020E61000000100000005000000EE5F596952EC4240D0B52FA017FE4B40EE5F596952EC4240FDA36FD234FE4B4012BF620D17ED4240FDA36FD234FE4B4012BF620D17ED4240D0B52FA017FE4B40EE5F596952EC4240D0B52FA017FE4B40
80666	4327	37.826988	37.831848000000001	55.975425999999999	55.971626999999998	Сологубовская	0103000020E610000001000000050000009C1727BEDAE942408E7406465EFC4B409C1727BEDAE9424084D558C2DAFC4B401B9FC9FE79EA424084D558C2DAFC4B401B9FC9FE79EA42408E7406465EFC4B409C1727BEDAE942408E7406465EFC4B40
15826	4327	37.852051000000003	37.858105000000002	56.033831999999997	56.030335999999998	Советская улица	0103000020E6100000010000000500000016C3D50110ED42401BF2CF0CE2034C4016C3D50110ED424075C7629B54044C405DC47762D6ED424075C7629B54044C405DC47762D6ED42401BF2CF0CE2034C4016C3D50110ED42401BF2CF0CE2034C40
15885	4327	37.852051000000003	37.858105000000002	56.033831999999997	56.030335999999998	Советская улица	0103000020E6100000010000000500000016C3D50110ED42401BF2CF0CE2034C4016C3D50110ED424075C7629B54044C405DC47762D6ED424075C7629B54044C405DC47762D6ED42401BF2CF0CE2034C4016C3D50110ED42401BF2CF0CE2034C40
15799	4327	37.844675000000002	37.850541	55.983438999999997	55.982658000000001	Рабочая улица	0103000020E61000000100000005000000D95F764F1EEC42408E93C2BCC7FD4B40D95F764F1EEC4240334E4354E1FD4B401D740987DEEC4240334E4354E1FD4B401D740987DEEC42408E93C2BCC7FD4B40D95F764F1EEC42408E93C2BCC7FD4B40
1284	4327	37.842618000000002	37.845044000000001	56.010775000000002	56.007851000000002	Писаревский проезд	0103000020E61000000100000005000000AE8218E8DAEB4240D61EF64201014C40AE8218E8DAEB4240A54E401361014C402CD7DB662AEC4240A54E401361014C402CD7DB662AEC4240D61EF64201014C40AE8218E8DAEB4240D61EF64201014C40
80724	4327	37.829825999999997	37.866782999999998	55.994577	55.985574	Октябрьская	0103000020E610000001000000050000006CAF05BD37EA4240DAE4F04927FE4B406CAF05BD37EA4240492D944C4EFF4B4048DDCEBEF2EE4240492D944C4EFF4B4048DDCEBEF2EE4240DAE4F04927FE4B406CAF05BD37EA4240DAE4F04927FE4B40
80500	4327	37.839024999999999	37.839339000000002	56.060448999999998	56.050767	Некрасова	0103000020E6100000010000000500000061C3D32B65EB4240A75B76887F064C4061C3D32B65EB4240B709F7CABC074C40F1A0D9756FEB4240B709F7CABC074C40F1A0D9756FEB4240A75B76887F064C4061C3D32B65EB4240A75B76887F064C40
15811	4327	37.836024999999999	37.838962000000002	55.987754000000002	55.972242000000001	Лермонтовская улица	0103000020E61000000100000005000000B7D100DE02EB424019E6046D72FC4B40B7D100DE02EB4240213F1BB96EFE4B401B4B581B63EB4240213F1BB96EFE4B401B4B581B63EB424019E6046D72FC4B40B7D100DE02EB424019E6046D72FC4B40
80689	4327	37.813720000000004	37.826448999999997	56.001981999999998	55.995840999999999	Кузнецкий Мост	0103000020E61000000100000005000000F20C1AFA27E842400A82C7B777FF4B40F20C1AFA27E84240209738F240004C40EC67B114C9E94240209738F240004C40EC67B114C9E942400A82C7B777FF4B40F20C1AFA27E842400A82C7B777FF4B40
80883	4327	37.830418999999999	37.855150000000002	56.045105999999997	56.044995999999998	Коминтерна	0103000020E610000001000000050000000F7D772B4BEA4240B439CE6DC2054C400F7D772B4BEA42403B6D8D08C6054C405396218E75ED42403B6D8D08C6054C405396218E75ED4240B439CE6DC2054C400F7D772B4BEA4240B439CE6DC2054C40
79955	4327	37.858006000000003	37.859820999999997	56.051335000000002	56.048088	Железнодорожная	0103000020E61000000100000005000000CAE2FE23D3ED42403FAA61BF27064C40CAE2FE23D3ED4240F111312592064C40FEB4519D0EEE4240F111312592064C40FEB4519D0EEE42403FAA61BF27064C40CAE2FE23D3ED42403FAA61BF27064C40
79947	4327	37.833851000000003	37.837479999999999	56.010156000000002	56.003115000000001	Боголюбская	0103000020E61000000100000005000000535E2BA1BBEA42404390831266004C40535E2BA1BBEA4240D9EDB3CA4C014C40EC866D8B32EB4240D9EDB3CA4C014C40EC866D8B32EB42404390831266004C40535E2BA1BBEA42404390831266004C40
1227	4327	37.830742999999998	37.838287999999999	56.018856	56.010413	Авиационная улица	0103000020E61000000100000005000000C23060C955EA4240043A933655014C40C23060C955EA4240ACAA97DF69024C408B506C054DEB4240ACAA97DF69024C408B506C054DEB4240043A933655014C40C23060C955EA4240043A933655014C40
1159	4327	37.831470000000003	37.834381	56.010356999999999	56.004342999999999	2-я Домбровская улица	0103000020E6100000010000000500000075CDE49B6DEA4240B77BB94F8E004C4075CDE49B6DEA42407024D06053014C40AFB321FFCCEA42407024D06053014C40AFB321FFCCEA4240B77BB94F8E004C4075CDE49B6DEA4240B77BB94F8E004C40
1340	4327	37.852383000000003	37.856309000000003	56.002510999999998	56.001660000000001	2-й Надсоновский проезд	0103000020E610000001000000050000004C55DAE21AED42400EDB166536004C404C55DAE21AED4240AC70CB4752004C409F2287889BED4240AC70CB4752004C409F2287889BED42400EDB166536004C404C55DAE21AED42400EDB166536004C40
1358	4327	37.860162000000003	37.866325000000003	56.003245999999997	56.001378000000003	1-й Фабричный проезд	0103000020E6100000010000000500000088A1D5C919EE42408A7780272D004C4088A1D5C919EE4240E1EB6B5D6A004C40865AD3BCE3EE4240E1EB6B5D6A004C40865AD3BCE3EE42408A7780272D004C4088A1D5C919EE42408A7780272D004C40
1195	4327	37.824615999999999	37.835009999999997	56.012797999999997	56.011569999999999	1-й Добролюбовский проезд	0103000020E6100000010000000500000011E15F048DE94240AFCE31207B014C4011E15F048DE9424023BA675DA3014C409EEA909BE1EA424023BA675DA3014C409EEA909BE1EA4240AFCE31207B014C4011E15F048DE94240AFCE31207B014C40
79979	61861	37.845258999999999	37.886994999999999	56.079918999999997	56.050823000000001	Ленина	0103000020E6100000010000000500000028D3687231EC42403B71395E81064C4028D3687231EC42401DAA29C93A0A4C40965B5A0D89F142401DAA29C93A0A4C40965B5A0D89F142403B71395E81064C4028D3687231EC42403B71395E81064C40
80757	61861	37.845258999999999	37.886994999999999	56.079918999999997	56.050823000000001	Зеленый городок	0103000020E6100000010000000500000028D3687231EC42403B71395E81064C4028D3687231EC42401DAA29C93A0A4C40965B5A0D89F142401DAA29C93A0A4C40965B5A0D89F142403B71395E81064C4028D3687231EC42403B71395E81064C40
79820	61870	37.863683999999999	37.863836999999997	56.075172000000002	56.061357999999998	Лесная	0103000020E610000001000000050000000B0A83328DEE42408AAC3594DA074C400B0A83328DEE424097C9703C9F094C409109F83592EE424097C9703C9F094C409109F83592EE42408AAC3594DA074C400B0A83328DEE42408AAC3594DA074C40
80725	2890	37.855949000000003	37.857171000000001	55.958351	55.955241999999998	Новая	0103000020E610000001000000050000009F05A1BC8FED424000E2AE5E45FA4B409F05A1BC8FED4240618BDD3EABFA4B40310A82C7B7ED4240618BDD3EABFA4B40310A82C7B7ED424000E2AE5E45FA4B409F05A1BC8FED424000E2AE5E45FA4B40
79788	2890	37.846822000000003	37.862220000000001	55.960039000000002	55.956693000000001	Ленина	0103000020E6100000010000000500000044C4CDA964EC4240F4A78DEA74FA4B4044C4CDA964EC424039F1D58EE2FA4B4083FA96395DEE424039F1D58EE2FA4B4083FA96395DEE4240F4A78DEA74FA4B4044C4CDA964EC4240F4A78DEA74FA4B40
74214	6433	37.923780999999998	37.932288	56.077055999999999	56.076976000000002	Титова	0103000020E6100000010000000500000045D5AF743EF64240D8497D59DA094C4045D5AF743EF64240F4FA93F8DC094C40043A933655F74240F4FA93F8DC094C40043A933655F74240D8497D59DA094C4045D5AF743EF64240D8497D59DA094C40
80671	6433	37.927464000000001	37.927500000000002	56.081004999999998	56.077055999999999	Гагарина	0103000020E61000000100000005000000D21BEE23B7F64240F4FA93F8DC094C40D21BEE23B7F64240FFE7305F5E0A4C401F85EB51B8F64240FFE7305F5E0A4C401F85EB51B8F64240F4FA93F8DC094C40D21BEE23B7F64240F4FA93F8DC094C40
79808	61869	37.923780999999998	37.932288	56.077055999999999	56.076976000000002	Титова	0103000020E6100000010000000500000045D5AF743EF64240D8497D59DA094C4045D5AF743EF64240F4FA93F8DC094C40043A933655F74240F4FA93F8DC094C40043A933655F74240D8497D59DA094C4045D5AF743EF64240D8497D59DA094C40
71892	59545	37.878478999999999	37.937812999999998	56.129348	56.080367000000003	Школьная	0103000020E61000000100000005000000849CF7FF71F04240BD564277490A4C40849CF7FF71F04240C9E6AA798E104C40BF61A2410AF84240C9E6AA798E104C40BF61A2410AF84240BD564277490A4C40849CF7FF71F04240BD564277490A4C40
80093	61925	37.968311	37.985900000000001	56.047483999999997	56.039428999999998	Школьная 	0103000020E61000000100000005000000B4AD669DF1FB4240CAC16C020C054C40B4AD669DF1FB4240A88AA9F413064C402E90A0F831FE4240A88AA9F413064C402E90A0F831FE4240CAC16C020C054C40B4AD669DF1FB4240CAC16C020C054C40
80713	6744	37.867581999999999	37.89349	56.060167	56.042712999999999	Огородная	0103000020E61000000100000005000000944C4EED0CEF4240990E9D9E77054C40944C4EED0CEF424033A6608DB3074C40CAA65CE15DF2424033A6608DB3074C40CAA65CE15DF24240990E9D9E77054C40944C4EED0CEF4240990E9D9E77054C40
81000	7551	37.739249000000001	37.760269999999998	56.154535000000003	56.140239000000001	Парковая	0103000020E61000000100000005000000E44C13B69FDE4240D74FFF59F3114C40E44C13B69FDE42402F8B89CDC7134C40A110018750E142402F8B89CDC7134C40A110018750E14240D74FFF59F3114C40E44C13B69FDE4240D74FFF59F3114C40
80495	61940	37.847945000000003	37.852563000000004	56.015056999999999	56.013955000000003	2-й Некрасовский проезд	0103000020E6100000010000000500000043E7357689EC4240CF4E0647C9014C4043E7357689EC4240B6494563ED014C40CC63CDC820ED4240B6494563ED014C40CC63CDC820ED4240CF4E0647C9014C4043E7357689EC4240CF4E0647C9014C40
71828	59521	37.506782999999999	37.537694000000002	55.332667999999998	55.304656999999999	Строителей	0103000020E610000001000000050000009A95ED43DEC04240ADBF2500FFA64B409A95ED43DEC042407E3672DD94AA4B40B2A03028D3C442407E3672DD94AA4B40B2A03028D3C44240ADBF2500FFA64B409A95ED43DEC04240ADBF2500FFA64B40
71826	59521	37.506782999999999	37.537694000000002	55.332667999999998	55.304656999999999	Московская	0103000020E610000001000000050000009A95ED43DEC04240ADBF2500FFA64B409A95ED43DEC042407E3672DD94AA4B40B2A03028D3C442407E3672DD94AA4B40B2A03028D3C44240ADBF2500FFA64B409A95ED43DEC04240ADBF2500FFA64B40
74077	45757	37.201554000000002	37.212037000000002	55.330449999999999	55.323709999999998	Мира	0103000020E6100000010000000500000062307F85CC994240AFB14B546FA94B4062307F85CC9942404A7B832F4CAA4B405F454607249B42404A7B832F4CAA4B405F454607249B4240AFB14B546FA94B4062307F85CC994240AFB14B546FA94B40
71844	1945	37.506782999999999	37.537694000000002	55.332667999999998	55.304656999999999	Горького	0103000020E610000001000000050000009A95ED43DEC04240ADBF2500FFA64B409A95ED43DEC042407E3672DD94AA4B40B2A03028D3C442407E3672DD94AA4B40B2A03028D3C44240ADBF2500FFA64B409A95ED43DEC04240ADBF2500FFA64B40
71842	46031	37.364265000000003	37.389175999999999	55.379767000000001	55.367565999999997	Центральная	0103000020E61000000100000005000000EA094B3CA0AE42408E8F16670CAF4B40EA094B3CA0AE4240CE8C7E349CB04B40AD31E884D0B14240CE8C7E349CB04B40AD31E884D0B142408E8F16670CAF4B40EA094B3CA0AE42408E8F16670CAF4B40
81031	62059	37.511139999999997	37.511462999999999	55.363334999999999	55.361998999999997	Новая улица	0103000020E61000000100000005000000B6D617096DC14240A417B5FB55AE4B40B6D617096DC14240FF3EE3C281AE4B40990E9D9E77C14240FF3EE3C281AE4B40990E9D9E77C14240A417B5FB55AE4B40B6D617096DC14240A417B5FB55AE4B40
71845	45544	37.335438000000003	37.373195000000003	55.328488999999998	55.315294000000002	Центральная	0103000020E61000000100000005000000F7EAE3A1EFAA42400150C58D5BA84B40F7EAE3A1EFAA4240410C74ED0BAA4B40EF0390DAC4AF4240410C74ED0BAA4B40EF0390DAC4AF42400150C58D5BA84B40F7EAE3A1EFAA42400150C58D5BA84B40
74201	2834	37.538654999999999	37.543999999999997	55.391860999999999	55.386547999999998	Большая Серпуховская	0103000020E61000000100000005000000D769A4A5F2C44240C72AA5677AB14B40D769A4A5F2C44240F7C9518028B24B401283C0CAA1C54240F7C9518028B24B401283C0CAA1C54240C72AA5677AB14B40D769A4A5F2C44240C72AA5677AB14B40
923	3569	37.521937999999999	37.522477000000002	55.449955000000003	55.447234000000002	Высокая улица	0103000020E61000000100000005000000134548DDCEC2424063D4B5F63EB94B40134548DDCEC24240FAD51C2098B94B40C3F4BD86E0C24240FAD51C2098B94B40C3F4BD86E0C2424063D4B5F63EB94B40134548DDCEC2424063D4B5F63EB94B40
80737	45896	37.031646000000002	37.045938	55.223509	55.217080000000003	Центральная	0103000020E610000001000000050000004D86E3F90C844240CF4E0647C99B4B404D86E3F90C8442404BAE62F19B9C4B4063D2DF4BE18542404BAE62F19B9C4B4063D2DF4BE1854240CF4E0647C99B4B404D86E3F90C844240CF4E0647C99B4B40
81006	45975	37.607044000000002	37.624732000000002	55.418446000000003	55.406227000000001	Центральная	0103000020E61000000100000005000000D49D279EB3CD424048E00F3FFFB34B40D49D279EB3CD42402E9276A38FB54B40E161DA37F7CF42402E9276A38FB54B40E161DA37F7CF424048E00F3FFFB34B40D49D279EB3CD424048E00F3FFFB34B40
1093	1147	38.626021000000001	38.640807000000002	55.786738	55.784196999999999	улица Гагарина	0103000020E61000000100000005000000FBCDC47421504340874F3A9160E44B40FBCDC474215043409E42AED4B3E44B402106BAF6055243409E42AED4B3E44B402106BAF605524340874F3A9160E44B40FBCDC47421504340874F3A9160E44B40
7581	1147	38.600957999999999	38.649906999999999	55.783777000000001	55.779215999999998	улица 1 Мая	0103000020E6100000010000000500000081221631EC4C43408D429259BDE34B4081221631EC4C4340B22D03CE52E44B4082380F2730534340B22D03CE52E44B4082380F27305343408D429259BDE34B4081221631EC4C43408D429259BDE34B40
7622	1147	38.650410000000001	38.652126000000003	55.781275999999998	55.779175000000002	площадь Революции	0103000020E61000000100000005000000E57E87A2405343402F6EA301BCE34B40E57E87A24053434029931ADA00E44B40876F61DD7853434029931ADA00E44B40876F61DD785343402F6EA301BCE34B40E57E87A2405343402F6EA301BCE34B40
68850	1147	38.670380000000002	38.674574999999997	55.784759000000001	55.781944000000003	переулок Герцена	0103000020E610000001000000050000003DF20703CF554340D7A6B1BD16E44B403DF20703CF554340EF1EA0FB72E44B407FD93D7958564340EF1EA0FB72E44B407FD93D7958564340D7A6B1BD16E44B403DF20703CF554340D7A6B1BD16E44B40
80354	1147	38.656492	38.669499999999999	55.766061000000001	55.765416999999999	Южная	0103000020E61000000100000005000000F60A0BEE07544340B6662B2FF9E14B40F60A0BEE07544340DBDE6E490EE24B4004560E2DB2554340DBDE6E490EE24B4004560E2DB2554340B6662B2FF9E14B40F60A0BEE07544340B6662B2FF9E14B40
80358	1147	38.633926000000002	38.645271999999999	55.779620999999999	55.776623999999998	Сенная	0103000020E61000000100000005000000C40AB77C24514340F4A44C6A68E34B40C40AB77C245143402D23F59ECAE34B402383DC45985243402D23F59ECAE34B402383DC4598524340F4A44C6A68E34B40C40AB77C24514340F4A44C6A68E34B40
79837	1147	38.644570999999999	38.649853	55.79392	55.783589999999997	Мира	0103000020E610000001000000050000009A79724D815243407FBC57AD4CE44B409A79724D81524340F6D1A92B9FE54B408F1A13622E534340F6D1A92B9FE54B408F1A13622E5343407FBC57AD4CE44B409A79724D815243407FBC57AD4CE44B40
80362	1147	38.665601000000002	38.678500999999997	55.772587999999999	55.763204000000002	Кузьмина	0103000020E61000000100000005000000AB97DF693255434094162EABB0E14B40AB97DF69325543401AA4E029E4E24B40D2A6EA1ED95643401AA4E029E4E24B40D2A6EA1ED956434094162EABB0E14B40AB97DF693255434094162EABB0E14B40
7735	1147	38.413353999999998	38.940665000000003	55.924497000000002	55.627290000000002	Корнево-Юдинский переулок	0103000020E61000000100000005000000DCD5ABC8E8344340CE8DE9094BD04B40DCD5ABC8E83443400420EEEA55F64B40F5BEF1B5677843400420EEEA55F64B40F5BEF1B567784340CE8DE9094BD04B40DCD5ABC8E8344340CE8DE9094BD04B40
80345	1147	38.647948999999997	38.675446000000001	55.781691000000002	55.778927000000003	Кирова	0103000020E61000000100000005000000EA3C2AFEEF524340577C43E1B3E34B40EA3C2AFEEF524340ED4960730EE44B40651BB80375564340ED4960730EE44B40651BB80375564340577C43E1B3E34B40EA3C2AFEEF524340577C43E1B3E34B40
80346	1147	38.673757999999999	38.676910999999997	55.787000999999997	55.776502000000001	Каляева	0103000020E610000001000000050000008DB5BFB33D564340A9A3E36A64E34B408DB5BFB33D564340AB75E272BCE44B40BDA60705A5564340AB75E272BCE44B40BDA60705A5564340A9A3E36A64E34B408DB5BFB33D564340A9A3E36A64E34B40
80380	1147	38.666274999999999	38.672195000000002	55.784612000000003	55.776634000000001	Герцена	0103000020E610000001000000050000003A92CB7F48554340187B2FBE68E34B403A92CB7F485543404B06802A6EE44B4072C45A7C0A5643404B06802A6EE44B4072C45A7C0A564340187B2FBE68E34B403A92CB7F48554340187B2FBE68E34B40
7730	1147	38.651183000000003	38.656492	55.779221	55.765416999999999	Большая Покровская улица	0103000020E61000000100000005000000085BECF659534340B6662B2FF9E14B40085BECF6595343409FAD8383BDE34B40F60A0BEE075443409FAD8383BDE34B40F60A0BEE07544340B6662B2FF9E14B40085BECF659534340B6662B2FF9E14B40
80376	1147	38.695478999999999	38.704766999999997	55.786946	55.786647000000002	Белинского	0103000020E610000001000000050000000307B474055943408E3F51D9B0E44B400307B47405594340E8DB82A5BAE44B40672618CE355A4340E8DB82A5BAE44B40672618CE355A43408E3F51D9B0E44B400307B474055943408E3F51D9B0E44B40
7599	1147	38.413353999999998	38.940665000000003	55.924497000000002	55.627290000000002	1-й переулок 1 Мая	0103000020E61000000100000005000000DCD5ABC8E8344340CE8DE9094BD04B40DCD5ABC8E83443400420EEEA55F64B40F5BEF1B5677843400420EEEA55F64B40F5BEF1B567784340CE8DE9094BD04B40DCD5ABC8E8344340CE8DE9094BD04B40
74092	60235	38.652360000000002	38.676245999999999	55.855289999999997	55.842666000000001	Новая	0103000020E61000000100000005000000FA9B508880534340BFB9BF7ADCEB4B40FA9B508880534340444C89247AED4B4081069B3A8F564340444C89247AED4B4081069B3A8F564340BFB9BF7ADCEB4B40FA9B508880534340BFB9BF7ADCEB4B40
80813	31054	38.721969999999999	38.748156000000002	55.636341000000002	55.625064000000002	Школьная	0103000020E61000000100000005000000B8585183695C434017F4DE1802D04B40B8585183695C43404E0D349F73D14B4031276893C35F43404E0D349F73D14B4031276893C35F434017F4DE1802D04B40B8585183695C434017F4DE1802D04B40
80361	21386	38.643555999999997	38.646790000000003	55.815918000000003	55.806029000000002	Спортивная	0103000020E610000001000000050000008192020B60524340555051F52BE74B408192020B60524340DF1B430070E84B409FB0C403CA524340DF1B430070E84B409FB0C403CA524340555051F52BE74B408192020B60524340555051F52BE74B40
80705	27892	39.152937000000001	39.166564000000001	55.775782999999997	55.768526999999999	Центральная	0103000020E6100000010000000500000097AC8A7093934340E78BBD175FE24B4097AC8A709393434079E57ADB4CE34B4071581AF85195434079E57ADB4CE34B4071581AF851954340E78BBD175FE24B4097AC8A7093934340E78BBD175FE24B40
80914	29103	38.841554000000002	38.872087999999998	55.516196000000001	55.497613000000001	Советская	0103000020E61000000100000005000000B4E89D0AB86B4340408864C8B1BF4B40B4E89D0AB86B4340BB29E5B512C24B40F59D5F94A06F4340BB29E5B512C24B40F59D5F94A06F4340408864C8B1BF4B40B4E89D0AB86B4340408864C8B1BF4B40
81019	27982	38.824306	38.838113	55.743031000000002	55.738413999999999	Слободка	0103000020E61000000100000005000000C3F2E7DB826943404B74965984DE4B40C3F2E7DB826943400475CAA31BDF4B401DAD6A49476B43400475CAA31BDF4B401DAD6A49476B43404B74965984DE4B40C3F2E7DB826943404B74965984DE4B40
80912	62011	\N	\N	\N	\N	Дружбы	\N
80865	62011	\N	\N	\N	\N	Дружбы	\N
6960	5501	38.948103000000003	38.954588999999999	55.717633999999997	55.714545999999999	улица Степана Морозкина	0103000020E61000000100000005000000A81E69705B7943406ABE4A3E76DB4B40A81E69705B794340B33F506EDBDB4B40880FECF82F7A4340B33F506EDBDB4B40880FECF82F7A43406ABE4A3E76DB4B40A81E69705B7943406ABE4A3E76DB4B40
6988	5501	38.943089999999998	38.952216999999997	55.739229999999999	55.73218	улица Калинина	0103000020E61000000100000005000000A297512CB778434084640113B8DD4B40A297512CB77843406D1CB1169FDE4B40FDD8243FE27943406D1CB1169FDE4B40FDD8243FE279434084640113B8DD4B40A297512CB778434084640113B8DD4B40
6976	5501	38.957535	38.959232999999998	55.729061999999999	55.720063000000003	Советская улица	0103000020E610000001000000050000003FE3C281907A4340A3073E062BDC4B403FE3C281907A4340D06053E751DD4B403A1F9E25C87A4340D06053E751DD4B403A1F9E25C87A4340A3073E062BDC4B403FE3C281907A4340A3073E062BDC4B40
80340	5501	38.951417999999997	38.958029000000003	55.707912	55.692937000000001	Ленина	0103000020E61000000100000005000000B169A510C87943401C98DC28B2D84B40B169A510C8794340153944DC9CDA4B404FCFBBB1A07A4340153944DC9CDA4B404FCFBBB1A07A43401C98DC28B2D84B40B169A510C87943401C98DC28B2D84B40
79833	5501	38.957723999999999	38.957822999999998	55.711995000000002	55.707841000000002	Кирова	0103000020E61000000100000005000000124C35B3967A43404CE2AC889ADA4B40124C35B3967A434030F5F3A622DB4B40A52DAEF1997A434030F5F3A622DB4B40A52DAEF1997A43404CE2AC889ADA4B40124C35B3967A43404CE2AC889ADA4B40
80343	5501	38.943089999999998	38.952216999999997	55.739229999999999	55.73218	Калинина	0103000020E61000000100000005000000A297512CB778434084640113B8DD4B40A297512CB77843406D1CB1169FDE4B40FDD8243FE27943406D1CB1169FDE4B40FDD8243FE279434084640113B8DD4B40A297512CB778434084640113B8DD4B40
80332	22533	38.912205999999998	38.921970999999999	55.574559000000001	55.574075000000001	Школьная	0103000020E61000000100000005000000849B8C2AC3744340C139234A7BC94B40849B8C2AC3744340AD4F39268BC94B40226E4E2503764340AD4F39268BC94B40226E4E2503764340C139234A7BC94B40849B8C2AC3744340C139234A7BC94B40
6902	22533	38.894851000000003	38.937359000000001	55.580776999999998	55.577475	Советская улица	0103000020E610000001000000050000007EE5417A8A724340F9A067B3EAC94B407EE5417A8A7243406EA296E656CA4B403ECE3461FB7743406EA296E656CA4B403ECE3461FB774340F9A067B3EAC94B407EE5417A8A724340F9A067B3EAC94B40
80339	22533	38.894851000000003	38.937359000000001	55.580776999999998	55.577475	Советская	0103000020E610000001000000050000007EE5417A8A724340F9A067B3EAC94B407EE5417A8A7243406EA296E656CA4B403ECE3461FB7743406EA296E656CA4B403ECE3461FB774340F9A067B3EAC94B407EE5417A8A724340F9A067B3EAC94B40
6861	22533	38.920031000000002	38.922735000000003	55.591904999999997	55.579124	Новинское шоссе	0103000020E6100000010000000500000031276893C3754340132A38BC20CA4B4031276893C375434060AB048BC3CB4B40F2EF332E1C76434060AB048BC3CB4B40F2EF332E1C764340132A38BC20CA4B4031276893C3754340132A38BC20CA4B40
6666	22533	38.898308999999998	38.915323999999998	55.586145999999999	55.58352	Набережная улица	0103000020E61000000100000005000000EA5910CAFB724340ED478AC8B0CA4B40EA5910CAFB724340325706D506CB4B40389F3A5629754340325706D506CB4B40389F3A5629754340ED478AC8B0CA4B40EA5910CAFB724340ED478AC8B0CA4B40
6920	22533	38.910823000000001	38.922735000000003	55.591904999999997	55.583530000000003	Коммунистическая улица	0103000020E61000000100000005000000E9B81AD995744340111E6D1CB1CA4B40E9B81AD99574434060AB048BC3CB4B40F2EF332E1C76434060AB048BC3CB4B40F2EF332E1C764340111E6D1CB1CA4B40E9B81AD995744340111E6D1CB1CA4B40
6870	22533	38.922088000000002	38.923273999999999	55.579225000000001	55.574106	Вокзальная улица	0103000020E610000001000000050000005C04C6FA06764340FC372F4E7CC94B405C04C6FA067643404703780B24CA4B40A19FA9D72D7643404703780B24CA4B40A19FA9D72D764340FC372F4E7CC94B405C04C6FA06764340FC372F4E7CC94B40
80334	22533	38.922088000000002	38.923273999999999	55.579225000000001	55.574106	Вокзальная 	0103000020E610000001000000050000005C04C6FA06764340FC372F4E7CC94B405C04C6FA067643404703780B24CA4B40A19FA9D72D7643404703780B24CA4B40A19FA9D72D764340FC372F4E7CC94B405C04C6FA06764340FC372F4E7CC94B40
71907	29129	38.895066999999997	38.925528	55.486938000000002	55.468862000000001	Совхозная	0103000020E610000001000000050000004A5D328E91724340282B86AB03BC4B404A5D328E91724340FF9600FC53BE4B4022C495B377764340FF9600FC53BE4B4022C495B377764340282B86AB03BC4B404A5D328E91724340282B86AB03BC4B40
80836	29423	38.937359000000001	38.95467	55.581570999999997	55.579326999999999	Школьная	0103000020E610000001000000050000003ECE3461FB7743404B581B6327CA4B403ECE3461FB774340A8A624EB70CA4B40753C66A0327A4340A8A624EB70CA4B40753C66A0327A43404B581B6327CA4B403ECE3461FB7743404B581B6327CA4B40
6845	21773	38.847797	38.85351	55.742863	55.738596000000001	Центральная улица	0103000020E61000000100000005000000CE52B29C846C43406C7A50508ADE4B40CE52B29C846C43404834812216DF4B408C67D0D03F6D43404834812216DF4B408C67D0D03F6D43406C7A50508ADE4B40CE52B29C846C43406C7A50508ADE4B40
81023	21773	38.852800999999999	38.855756	55.747551000000001	55.742919000000001	Советская	0103000020E61000000100000005000000807F4A95286D4340DC4944F817DF4B40807F4A95286D4340CA8B4CC0AFDF4B408AADA069896D4340CA8B4CC0AFDF4B408AADA069896D4340DC4944F817DF4B40807F4A95286D4340DC4944F817DF4B40
80222	21773	38.841490999999998	38.845604999999999	55.744064000000002	55.741459999999996	Коммунистическая	0103000020E610000001000000050000006D7022FAB56B434065A54929E8DE4B406D7022FAB56B4340C310397D3DDF4B40C32ADEC83C6C4340C310397D3DDF4B40C32ADEC83C6C434065A54929E8DE4B406D7022FAB56B434065A54929E8DE4B40
80215	21773	38.839936999999999	38.849468000000002	55.747774	55.742027	Зимина	0103000020E61000000100000005000000A5D93C0E836B4340DFDFA0BDFADE4B40A5D93C0E836B43404966F50EB7DF4B40D07F0F5EBB6C43404966F50EB7DF4B40D07F0F5EBB6C4340DFDFA0BDFADE4B40A5D93C0E836B4340DFDFA0BDFADE4B40
80351	28293	38.876831000000003	38.889541999999999	55.799810999999998	55.792133999999997	Заводская 	0103000020E610000001000000050000003B8F8AFF3B7043405B069CA564E54B403B8F8AFF3B70434093FDF33460E64B408F352383DC71434093FDF33460E64B408F352383DC7143405B069CA564E54B403B8F8AFF3B7043405B069CA564E54B40
72049	28133	38.839596	38.877361000000001	55.617967999999998	55.598847999999997	2-й микрорайон	0103000020E610000001000000050000001CEDB8E1776B434033A31F0DA7CC4B401CEDB8E1776B4340BDFC4E9319CF4B4097E4805D4D704340BDFC4E9319CF4B4097E4805D4D70434033A31F0DA7CC4B401CEDB8E1776B434033A31F0DA7CC4B40
72366	27560	39.093629999999997	39.147269000000001	55.708317999999998	55.685386000000001	Ленинская-2	0103000020E6100000010000000500000055F65D11FC8B434071917BBABAD74B4055F65D11FC8B434085950A2AAADA4B40795BE9B5D992434085950A2AAADA4B40795BE9B5D992434071917BBABAD74B4055F65D11FC8B434071917BBABAD74B40
80916	27792	39.051158000000001	39.068809999999999	55.852742999999997	55.835194999999999	Новая	0103000020E61000000100000005000000E27668588C864340306475ABE7EA4B40E27668588C8643404B72C0AE26ED4B40A2D11DC4CE8843404B72C0AE26ED4B40A2D11DC4CE884340306475ABE7EA4B40E27668588C864340306475ABE7EA4B40
72369	27644	39.090729000000003	39.105415999999998	55.777839	55.766815000000001	Школьная	0103000020E610000001000000050000003FE603029D8B4340878A71FE26E24B403FE603029D8B4340D446753A90E34B40D13C80457E8D4340D446753A90E34B40D13C80457E8D4340878A71FE26E24B403FE603029D8B4340878A71FE26E24B40
80828	62004	38.591427000000003	38.622050999999999	54.908214999999998	54.88138	Багратиона	0103000020E61000000100000005000000577C43E1B34B43409BAC510FD1704B40577C43E1B34B43404A5E9D6340744B40D8B8FE5D9F4F43404A5E9D6340744B40D8B8FE5D9F4F43409BAC510FD1704B40577C43E1B34B43409BAC510FD1704B40
80776	23214	38.393061000000003	38.420279999999998	54.877428000000002	54.868383000000001	Набережная	0103000020E61000000100000005000000A22AA6D24F32434081B3942C276F4B40A22AA6D24F3243401F4C8A8F4F704B40D9942BBCCB3543401F4C8A8F4F704B40D9942BBCCB35434081B3942C276F4B40A22AA6D24F32434081B3942C276F4B40
80961	24271	38.654587999999997	38.712851999999998	54.907381999999998	54.890163000000001	Советская	0103000020E61000000100000005000000512D228AC9534340FC8D76DCF0714B40512D228AC9534340527DE71725744B40B071FDBB3E5B4340527DE71725744B40B071FDBB3E5B4340FC8D76DCF0714B40512D228AC9534340FC8D76DCF0714B40
80835	16867	38.568807	38.578294	54.854916000000003	54.852708	площадь Карла Маркса	0103000020E61000000100000005000000315EF3AACE484340CF842689256D4B40315EF3AACE484340E06932E36D6D4B408CBCAC89054A4340E06932E36D6D4B408CBCAC89054A4340CF842689256D4B40315EF3AACE484340CF842689256D4B40
80826	16867	38.568807	38.578294	54.854916000000003	54.852708	пл. Карла Маркса	0103000020E61000000100000005000000315EF3AACE484340CF842689256D4B40315EF3AACE484340E06932E36D6D4B408CBCAC89054A4340E06932E36D6D4B408CBCAC89054A4340CF842689256D4B40315EF3AACE484340CF842689256D4B40
74079	16867	38.472588999999999	38.610982999999997	54.874392999999998	54.844051	микрорайон 1	0103000020E6100000010000000500000084B9DDCB7D3C4340FB93F8DC096C4B4084B9DDCB7D3C4340F86C1D1CEC6F4B40BBB4E1B0344E4340F86C1D1CEC6F4B40BBB4E1B0344E4340FB93F8DC096C4B4084B9DDCB7D3C4340FB93F8DC096C4B40
71888	16867	38.568807	38.578294	54.854916000000003	54.852708	Микр.им.маршала Катукова	0103000020E61000000100000005000000315EF3AACE484340CF842689256D4B40315EF3AACE484340E06932E36D6D4B408CBCAC89054A4340E06932E36D6D4B408CBCAC89054A4340CF842689256D4B40315EF3AACE484340CF842689256D4B40
81004	16867	38.568807	38.578294	54.854916000000003	54.852708	Микр. им.Маршала Катукова	0103000020E61000000100000005000000315EF3AACE484340CF842689256D4B40315EF3AACE484340E06932E36D6D4B408CBCAC89054A4340E06932E36D6D4B408CBCAC89054A4340CF842689256D4B40315EF3AACE484340CF842689256D4B40
74157	16867	38.472337000000003	38.568339999999999	54.859729999999999	54.850696999999997	Ленина	0103000020E610000001000000050000006BD8EF89753C434014E7A8A3E36C4B406BD8EF89753C4340EEB1F4A10B6E4B401B81785DBF484340EEB1F4A10B6E4B401B81785DBF48434014E7A8A3E36C4B406BD8EF89753C434014E7A8A3E36C4B40
72356	16867	38.568807	38.578294	54.854916000000003	54.852708	Болотный переулок	0103000020E61000000100000005000000315EF3AACE484340CF842689256D4B40315EF3AACE484340E06932E36D6D4B408CBCAC89054A4340E06932E36D6D4B408CBCAC89054A4340CF842689256D4B40315EF3AACE484340CF842689256D4B40
80856	16867	38.541445000000003	38.551316999999997	54.861803000000002	54.858418999999998	2-я Высокополянская	0103000020E6100000010000000500000097CADB114E454340ECA17DACE06D4B4097CADB114E4543401F4C8A8F4F6E4B404A5D328E914643401F4C8A8F4F6E4B404A5D328E91464340ECA17DACE06D4B4097CADB114E454340ECA17DACE06D4B40
71890	24142	38.504505999999999	38.535713000000001	54.962043999999999	54.949703999999997	Школьная	0103000020E61000000100000005000000615111A793404340B07092E68F794B40615111A79340434011A8FE41247B4B4062855B3E9244434011A8FE41247B4B4062855B3E92444340B07092E68F794B40615111A793404340B07092E68F794B40
80830	62006	37.311785999999998	37.325952000000001	55.729671000000003	55.721649999999997	Советская	0103000020E61000000100000005000000E2AC889AE8A742404694F6065FDC4B40E2AC889AE8A7424079EBFCDB65DD4B406C088ECBB8A9424079EBFCDB65DD4B406C088ECBB8A942404694F6065FDC4B40E2AC889AE8A742404694F6065FDC4B40
70909	59420	37.169547000000001	37.192174999999999	55.667085999999998	55.653528000000001	1-е Успенское шоссе	0103000020E61000000100000005000000451152B7B3954240998235CEA6D34B40451152B7B39542404ACFF41263D54B40ED0DBE30999842404ACFF41263D54B40ED0DBE3099984240998235CEA6D34B40451152B7B3954240998235CEA6D34B40
71811	22630	36.959907000000001	36.971854	55.667442000000001	55.658529999999999	Заводская 	0103000020E61000000100000005000000CA198A3BDE7A4240AAB706B64AD44B40CA198A3BDE7A424009FD4CBD6ED54B404F3E3DB6657C424009FD4CBD6ED54B404F3E3DB6657C4240AAB706B64AD44B40CA198A3BDE7A4240AAB706B64AD44B40
29899	53053	36.686981000000003	36.691760000000002	55.599091999999999	55.595323	Школьная улица	0103000020E6100000010000000500000098FC4FFEEE5742403FC7478B33CC4B4098FC4FFEEE574240CAA5F10BAFCC4B402A5778978B584240CAA5F10BAFCC4B402A5778978B5842403FC7478B33CC4B4098FC4FFEEE5742403FC7478B33CC4B40
79937	61897	36.784421000000002	36.814109999999999	55.731347999999997	55.718800999999999	Юбилейная	0103000020E61000000100000005000000D7A546E86764424082AAD1AB01DC4B40D7A546E8676442405CFFAECF9CDD4B405CACA8C1346842405CFFAECF9CDD4B405CACA8C13468424082AAD1AB01DC4B40D7A546E86764424082AAD1AB01DC4B40
5122	1096	37.25141	37.271559000000003	55.682487999999999	55.674686999999999	улица Маршала Жукова	0103000020E6100000010000000500000095F1EF332EA04240A704C4245CD64B4095F1EF332EA04240CBF44BC45BD74B409DF7FF71C2A24240CBF44BC45BD74B409DF7FF71C2A24240A704C4245CD64B4095F1EF332EA04240A704C4245CD64B40
16370	1096	37.226616999999997	37.229894999999999	55.660921999999999	55.659343	улица Дениса Давыдова	0103000020E61000000100000005000000DBDB2DC9019D42405BECF65965D44B40DBDB2DC9019D42407C9A931799D44B40C84109336D9D42407C9A931799D44B40C84109336D9D42405BECF65965D44B40DBDB2DC9019D42405BECF65965D44B40
5287	1096	37.290981000000002	37.304222000000003	55.688217999999999	55.685665	бульвар Маршала Крылова	0103000020E61000000100000005000000F2608BDD3EA542408481E7DEC3D74B40F2608BDD3EA542405F42058717D84B40A35C1ABFF0A642405F42058717D84B40A35C1ABFF0A642408481E7DEC3D74B40F2608BDD3EA542408481E7DEC3D74B40
5182	1096	37.253467000000001	37.260663000000001	55.683432000000003	55.674579999999999	бульвар Любы Новоселовой	0103000020E61000000100000005000000C0CE4D9B71A0424091442FA358D64B40C0CE4D9B71A042401B8524B37AD74B407D23BA675DA142401B8524B37AD74B407D23BA675DA1424091442FA358D64B40C0CE4D9B71A0424091442FA358D64B40
80669	1096	37.286669000000003	37.288448000000002	55.671503999999999	55.665512	Солнечная	0103000020E6100000010000000500000076E3DD91B1A442403B8C497F2FD54B4076E3DD91B1A442400C91D3D7F3D54B405E4C33DDEBA442400C91D3D7F3D54B405E4C33DDEBA442403B8C497F2FD54B4076E3DD91B1A442403B8C497F2FD54B40
5139	1096	37.245086000000001	37.258983000000001	55.686897999999999	55.677174000000001	Северная улица	0103000020E610000001000000050000008E5A61FA5E9F4240CBD93BA3ADD64B408E5A61FA5E9F42400AD80E46ECD74B40289CDD5A26A142400AD80E46ECD74B40289CDD5A26A14240CBD93BA3ADD64B408E5A61FA5E9F4240CBD93BA3ADD64B40
80670	1096	37.274217999999998	37.281754999999997	55.685543000000003	55.678915000000003	Ново-Спортивная	0103000020E61000000100000005000000BDFC4E9319A34240C6E1CCAFE6D64B40BDFC4E9319A3424039807EDFBFD74B40033E3F8C10A4424039807EDFBFD74B40033E3F8C10A44240C6E1CCAFE6D64B40BDFC4E9319A34240C6E1CCAFE6D64B40
283	1096	37.253126000000002	37.274262999999998	55.678975999999999	55.673214000000002	Молодежная улица	0103000020E6100000010000000500000037E2C96E66A04240CC9A58E02BD64B4037E2C96E66A042406B6281AFE8D64B405DC0CB0C1BA342406B6281AFE8D64B405DC0CB0C1BA34240CC9A58E02BD64B4037E2C96E66A04240CC9A58E02BD64B40
5258	1096	37.250807999999999	37.310636000000002	55.687071000000003	55.666086	Можайское шоссе	0103000020E610000001000000050000009FC9FE791AA042406729594E42D54B409FC9FE791AA04240D88349F1F1D74B40EA7AA2EBC2A74240D88349F1F1D74B40EA7AA2EBC2A742406729594E42D54B409FC9FE791AA042406729594E42D54B40
80660	1096	37.25141	37.271559000000003	55.682487999999999	55.674686999999999	Маршала Жукова	0103000020E6100000010000000500000095F1EF332EA04240A704C4245CD64B4095F1EF332EA04240CBF44BC45BD74B409DF7FF71C2A24240CBF44BC45BD74B409DF7FF71C2A24240A704C4245CD64B4095F1EF332EA04240A704C4245CD64B40
80555	1096	37.212018999999998	37.212603000000001	55.660887000000002	55.654198000000001	Липовая 	0103000020E61000000100000005000000B8904770239B4240E78D93C2BCD34B40B8904770239B424000ADF9F197D44B4008043A93369B424000ADF9F197D44B4008043A93369B4240E78D93C2BCD34B40B8904770239B4240E78D93C2BCD34B40
80675	1096	37.281126	37.295904	55.667375999999997	55.666482000000002	Комсомольская	0103000020E610000001000000050000001407D0EFFBA34240B4AF3C484FD54B401407D0EFFBA342405111A7936CD54B40B760A92EE0A542405111A7936CD54B40B760A92EE0A54240B4AF3C484FD54B401407D0EFFBA34240B4AF3C484FD54B40
79936	1096	37.195436000000001	37.205596	55.658468999999997	55.658448999999997	Дружбы	0103000020E61000000100000005000000043BFE0B04994240BD8A8C0E48D44B40043BFE0B04994240043752B648D44B401E1840F8509A4240043752B648D44B401E1840F8509A4240BD8A8C0E48D44B40043BFE0B04994240BD8A8C0E48D44B40
79996	1096	37.281019000000001	37.298732999999999	55.679524000000001	55.672640999999999	Вокзальная	0103000020E61000000100000005000000FE463B6EF8A342407079AC1919D64B40FE463B6EF8A342406E6C76A4FAD64B40349E08E23CA642406E6C76A4FAD64B40349E08E23CA642407079AC1919D64B40FE463B6EF8A342407079AC1919D64B40
79899	61893	37.356019000000003	37.367274999999999	55.705188999999997	55.703946000000002	Агрохимиков	0103000020E6100000010000000500000098E0D40792AD424034130CE71ADA4B4098E0D40792AD4240DD3F16A243DA4B40B7D100DE02AF4240DD3F16A243DA4B40B7D100DE02AF424034130CE71ADA4B4098E0D40792AD424034130CE71ADA4B40
80678	21669	37.356019000000003	37.367274999999999	55.705188999999997	55.703946000000002	Агрохимиков	0103000020E6100000010000000500000098E0D40792AD424034130CE71ADA4B4098E0D40792AD4240DD3F16A243DA4B40B7D100DE02AF4240DD3F16A243DA4B40B7D100DE02AF424034130CE71ADA4B4098E0D40792AD424034130CE71ADA4B40
2439	1576	37.352066000000001	37.372171000000002	55.729478	55.715255999999997	Советский проспект	0103000020E610000001000000050000004B04AA7F10AD4240462234828DDB4B404B04AA7F10AD42406493FC885FDD4B4083C2A04CA3AF42406493FC885FDD4B4083C2A04CA3AF4240462234828DDB4B404B04AA7F10AD4240462234828DDB4B40
74082	40459	37.032167000000001	37.046064000000001	55.676488999999997	55.672001000000002	микрорайон Фирсановка	0103000020E6100000010000000500000056815A0C1E8442408DF0F62004D64B4056815A0C1E844240478D093197D64B40F0C2D66CE5854240478D093197D64B40F0C2D66CE58542408DF0F62004D64B4056815A0C1E8442408DF0F62004D64B40
5500	20282	37.020732000000002	37.025258999999998	55.627665999999998	55.626944000000002	Петровское шоссе	0103000020E6100000010000000500000087FD9E58A7824240333674B33FD04B4087FD9E58A7824240D367075C57D04B40FF76D9AF3B834240D367075C57D04B40FF76D9AF3B834240333674B33FD04B4087FD9E58A7824240333674B33FD04B40
72207	22571	36.951445	36.979104	55.643886000000002	55.629598000000001	Зеленая	0103000020E61000000100000005000000AB7823F3C879424042D0D1AA96D04B40AB7823F3C8794240172D40DB6AD24B40FFB0A547537D4240172D40DB6AD24B40FFB0A547537D424042D0D1AA96D04B40AB7823F3C879424042D0D1AA96D04B40
5746	21381	37.209494999999997	37.219565000000003	55.638150000000003	55.633820999999998	Фасадная улица	0103000020E6100000010000000500000077D66EBBD09A42404E42E90B21D14B4077D66EBBD09A4240A1F831E6AED14B40522CB7B41A9C4240A1F831E6AED14B40522CB7B41A9C42404E42E90B21D14B4077D66EBBD09A42404E42E90B21D14B40
80470	61938	37.209494999999997	37.219565000000003	55.638150000000003	55.633820999999998	Фасадная	0103000020E6100000010000000500000077D66EBBD09A42404E42E90B21D14B4077D66EBBD09A4240A1F831E6AED14B40522CB7B41A9C4240A1F831E6AED14B40522CB7B41A9C42404E42E90B21D14B4077D66EBBD09A42404E42E90B21D14B40
81014	61938	37.214264999999997	37.216627000000003	55.632438	55.630802000000003	Осоргино	0103000020E61000000100000005000000B6D617096D9B42402E20B41EBED04B40B6D617096D9B4240B35F77BAF3D04B401E37FC6EBA9B4240B35F77BAF3D04B401E37FC6EBA9B42402E20B41EBED04B40B6D617096D9B42402E20B41EBED04B40
79960	61904	37.379733999999999	37.409827999999997	55.697341000000002	55.678438	Лучистая	0103000020E61000000100000005000000F296AB1F9BB042408C2E6F0ED7D64B40F296AB1F9BB0424079944A7842D94B40177E703E75B4424079944A7842D94B40177E703E75B442408C2E6F0ED7D64B40F296AB1F9BB042408C2E6F0ED7D64B40
80420	61904	37.394305000000003	37.400117000000002	55.689309000000002	55.685817	Заречная	0103000020E610000001000000050000001CD3139678B242403A05F9D9C8D74B401CD3139678B2424053EBFD463BD84B406DC9AA0837B3424053EBFD463BD84B406DC9AA0837B342403A05F9D9C8D74B401CD3139678B242403A05F9D9C8D74B40
5960	22339	37.100906000000002	37.104804999999999	55.649478999999999	55.643352999999998	Лесная улица	0103000020E610000001000000050000002FFCE07CEA8C424049641F6459D24B402FFCE07CEA8C42402A38BC2022D34B4088BA0F406A8D42402A38BC2022D34B4088BA0F406A8D424049641F6459D24B402FFCE07CEA8C424049641F6459D24B40
79800	22339	37.056431000000003	37.131340999999999	55.658290999999998	55.631853999999997	30 Лет Октября	0103000020E6100000010000000500000084BD89213987424063EC8497E0D04B4084BD892139874240252026E142D44B40DDCF29C8CF904240252026E142D44B40DDCF29C8CF90424063EC8497E0D04B4084BD89213987424063EC8497E0D04B40
5961	152	36.968494999999997	36.998238000000001	55.611994000000003	55.610183999999997	проспект Луначарского	0103000020E6100000010000000500000075ABE7A4F77B42406F4562821ACE4B4075ABE7A4F77B424093ACC3D155CE4B40EECF4543C67F424093ACC3D155CE4B40EECF4543C67F42406F4562821ACE4B4075ABE7A4F77B42406F4562821ACE4B40
5547	152	36.965179999999997	36.970317999999999	55.611561999999999	55.610706999999998	проспект Керамиков	0103000020E610000001000000050000006B60AB048B7B42401938A0A52BCE4B406B60AB048B7B4240F9BCE2A947CE4B402D5C5661337C4240F9BCE2A947CE4B402D5C5661337C42401938A0A52BCE4B406B60AB048B7B42401938A0A52BCE4B40
5528	152	36.983209000000002	36.986711999999997	55.629886999999997	55.616300000000003	Советская улица	0103000020E610000001000000050000000211E2CAD97D42402D431CEBE2CE4B400211E2CAD97D424078962023A0D04B400E492D944C7E424078962023A0D04B400E492D944C7E42402D431CEBE2CE4B400211E2CAD97D42402D431CEBE2CE4B40
5540	152	36.968710000000002	36.997259	55.610849999999999	55.608958000000001	Пролетарский проспект	0103000020E6100000010000000500000072A774B0FE7B42409C51F355F2CD4B4072A774B0FE7B42407C61325530CE4B402252D32EA67F42407C61325530CE4B402252D32EA67F42409C51F355F2CD4B4072A774B0FE7B42409C51F355F2CD4B40
388	152	36.976255999999999	36.984188000000003	55.622298999999998	55.620347000000002	Молодежный проезд	0103000020E610000001000000050000000B43E4F4F57C4240FB95CE8767CF4B400B43E4F4F57C4240B0AA5E7EA7CF4B40CE8E54DFF97D4240B0AA5E7EA7CF4B40CE8E54DFF97D4240FB95CE8767CF4B400B43E4F4F57C4240FB95CE8767CF4B40
71786	152	36.953574000000003	37.008515000000003	55.635497999999998	55.601278999999998	Минское шоссе	0103000020E6100000010000000500000070287CB60E7A4240C362D4B5F6CC4B4070287CB60E7A424032569BFF57D14B404243FF041781424032569BFF57D14B404243FF0417814240C362D4B5F6CC4B4070287CB60E7A4240C362D4B5F6CC4B40
81057	62064	37.195436000000001	37.205596	55.658468999999997	55.658448999999997	улица Дружбы	0103000020E61000000100000005000000043BFE0B04994240BD8A8C0E48D44B40043BFE0B04994240043752B648D44B401E1840F8509A4240043752B648D44B401E1840F8509A4240BD8A8C0E48D44B40043BFE0B04994240BD8A8C0E48D44B40
80367	20319	36.975295000000003	37.012251999999997	55.630074999999998	55.629755000000003	Можайское шоссе	0103000020E61000000100000005000000E6797077D67C42400ABFD4CF9BD04B40E6797077D67C42407B832F4CA6D04B40C1A73979918142407B832F4CA6D04B40C1A73979918142400ABFD4CF9BD04B40E6797077D67C42400ABFD4CF9BD04B40
4709	16961	38.332003	38.340231000000003	55.726948	55.722436000000002	улица Сергеева	0103000020E61000000100000005000000429605137F2A4340FEB968C878DC4B40429605137F2A434041F2CEA10CDD4B40EE0A7DB08C2B434041F2CEA10CDD4B40EE0A7DB08C2B4340FEB968C878DC4B40429605137F2A4340FEB968C878DC4B40
71903	18299	38.385147000000003	38.421393999999999	55.940784999999998	55.914175999999998	Центральная усадьба	0103000020E610000001000000050000008693347F4C314340E0641BB803F54B408693347F4C3143409FC893A46BF84B40855D143DF03543409FC893A46BF84B40855D143DF0354340E0641BB803F54B408693347F4C314340E0641BB803F54B40
80855	18299	38.385147000000003	38.421393999999999	55.940784999999998	55.914175999999998	Московская	0103000020E610000001000000050000008693347F4C314340E0641BB803F54B408693347F4C3143409FC893A46BF84B40855D143DF03543409FC893A46BF84B40855D143DF0354340E0641BB803F54B408693347F4C314340E0641BB803F54B40
74062	15982	38.143400999999997	38.155420999999997	55.746592999999997	55.741044000000002	микрорайон Светлый	0103000020E610000001000000050000005A9BC6F65A124340D272A087DADE4B405A9BC6F65A1243401536035C90DF4B40490ED8D5E41343401536035C90DF4B40490ED8D5E4134340D272A087DADE4B405A9BC6F65A124340D272A087DADE4B40
80653	15982	38.209490000000002	38.231938999999997	55.718598	55.715611000000003	Школьная	0103000020E61000000100000005000000666B7D91D01A434035D4282499DB4B40666B7D91D01A43404A7CEE04FBDB4B405ED5592DB01D43404A7CEE04FBDB4B405ED5592DB01D434035D4282499DB4B40666B7D91D01A434035D4282499DB4B40
4566	15982	38.218186000000003	38.220844999999997	55.719586999999997	55.713577999999998	Советская улица	0103000020E61000000100000005000000F838D384ED1B434092921E8656DB4B40F838D384ED1B434039D0436D1BDC4B40183E22A6441C434039D0436D1BDC4B40183E22A6441C434092921E8656DB4B40F838D384ED1B434092921E8656DB4B40
4529	15982	38.210549999999998	38.227780000000003	55.714525999999999	55.713577999999998	Парковая улица	0103000020E610000001000000050000001E166A4DF31A434092921E8656DB4B401E166A4DF31A43402312859675DB4B40695721E5271D43402312859675DB4B40695721E5271D434092921E8656DB4B401E166A4DF31A434092921E8656DB4B40
72343	15982	38.209426999999998	38.211835000000001	55.715631000000002	55.711478	Октябрьская	0103000020E610000001000000050000001FF30181CE1A434068E90AB611DB4B401FF30181CE1A43407C80EECB99DB4B40F792C6681D1B43407C80EECB99DB4B40F792C6681D1B434068E90AB611DB4B401FF30181CE1A434068E90AB611DB4B40
80656	15982	38.208295999999997	38.226792000000003	55.72166	55.719408999999999	Маяковского	0103000020E610000001000000050000009DF17D71A91A43405AB9179815DC4B409DF17D71A91A43406A6AD95A5FDC4B404A7F2F85071D43406A6AD95A5FDC4B404A7F2F85071D43405AB9179815DC4B409DF17D71A91A43405AB9179815DC4B40
80025	61916	38.146599000000002	38.163173	55.813930999999997	55.812069000000001	Полевая	0103000020E610000001000000050000002B508BC1C3124340378C82E0F1E74B402B508BC1C3124340AC1919E42EE84B408C4B55DAE2144340AC1919E42EE84B408C4B55DAE2144340378C82E0F1E74B402B508BC1C3124340378C82E0F1E74B40
80822	17999	38.458297000000002	38.477879999999999	55.739037000000003	55.728966	Железнодорожная	0103000020E610000001000000050000006E6DE179A93A4340AEF204C24EDD4B406E6DE179A93A434059C4B0C398DE4B40CCB4FD2B2B3D434059C4B0C398DE4B40CCB4FD2B2B3D4340AEF204C24EDD4B406E6DE179A93A4340AEF204C24EDD4B40
80827	47555	38.255231999999999	38.300049000000001	55.778725000000001	55.764268000000001	Совхозная	0103000020E6100000010000000500000043723271AB2043408EB0A888D3E14B4043723271AB204340EFC9C342ADE34B404819710168264340EFC9C342ADE34B4048197101682643408EB0A888D3E14B4043723271AB2043408EB0A888D3E14B40
80926	62024	38.605477	38.638418000000001	55.937669	55.926231999999999	Школьная	0103000020E6100000010000000500000077BD3445804D43401C412AC58EF64B4077BD3445804D43408CBCAC8905F84B40C09657AEB75143408CBCAC8905F84B40C09657AEB75143401C412AC58EF64B4077BD3445804D43401C412AC58EF64B40
80930	17900	38.470792000000003	38.492908999999997	56.048772	56.035677999999997	Большая Стромынка	0103000020E61000000100000005000000F69B89E9423C4340E597C11891044C40F69B89E9423C4340F27A30293E064C40B87361A4173F4340F27A30293E064C40B87361A4173F4340E597C11891044C40F69B89E9423C4340E597C11891044C40
4600	402	38.183627999999999	38.185487000000002	55.810516	55.809033999999997	Школьный проезд	0103000020E61000000100000005000000A0504F1F8117434010AD156D8EE74B40A0504F1F811743403F7100FDBEE74B40A56ABB09BE1743403F7100FDBEE74B40A56ABB09BE17434010AD156D8EE74B40A0504F1F8117434010AD156D8EE74B40
5700	402	38.183627999999999	38.185487000000002	55.810516	55.809033999999997	Октябрьская улица	0103000020E61000000100000005000000A0504F1F8117434010AD156D8EE74B40A0504F1F811743403F7100FDBEE74B40A56ABB09BE1743403F7100FDBEE74B40A56ABB09BE17434010AD156D8EE74B40A0504F1F8117434010AD156D8EE74B40
71923	402	38.155214000000001	38.197552000000002	55.816246999999997	55.806519999999999	Большая Московская	0103000020E61000000100000005000000D0F0660DDE134340F3C81F0C3CE74B40D0F0660DDE134340A33A1DC87AE84B4034A1496249194340A33A1DC87AE84B4034A1496249194340F3C81F0C3CE74B40D0F0660DDE134340F3C81F0C3CE74B40
80817	48099	38.237319999999997	38.245458999999997	55.916168999999996	55.902914000000003	Береговая	0103000020E61000000100000005000000E6577380601E4340DF8C9AAF92F34B40E6577380601E4340F44D9A0645F54B4022C154336B1F4340F44D9A0645F54B4022C154336B1F4340DF8C9AAF92F34B40E6577380601E4340DF8C9AAF92F34B40
80790	48099	38.237319999999997	38.245458999999997	55.916168999999996	55.902914000000003	Береговая	0103000020E61000000100000005000000E6577380601E4340DF8C9AAF92F34B40E6577380601E4340F44D9A0645F54B4022C154336B1F4340F44D9A0645F54B4022C154336B1F4340DF8C9AAF92F34B40E6577380601E4340DF8C9AAF92F34B40
80911	21126	38.392423000000001	38.410927999999998	55.855355000000003	55.852789000000001	Лесная	0103000020E610000001000000050000005F99B7EA3A324340BCB1A03028ED4B405F99B7EA3A3243402CBCCB457CED4B405E81E849993443402CBCCB457CED4B405E81E84999344340BCB1A03028ED4B405F99B7EA3A324340BCB1A03028ED4B40
5404	16719	38.280681999999999	38.285721000000002	55.829850999999998	55.829593000000003	улица Калинина	0103000020E61000000100000005000000B6494563ED234340CAFE791A30EA4B40B6494563ED234340C5C6BC8E38EA4B40E563778192244340C5C6BC8E38EA4B40E563778192244340CAFE791A30EA4B40B6494563ED234340CAFE791A30EA4B40
4655	16719	38.267125999999998	38.275705000000002	55.834558000000001	55.831584999999997	Советская улица	0103000020E61000000100000005000000A5F44C2F312243400D6C956071EA4B40A5F44C2F31224340BE4EEACBD2EA4B40FE2B2B4D4A234340BE4EEACBD2EA4B40FE2B2B4D4A2343400D6C956071EA4B40A5F44C2F312243400D6C956071EA4B40
80663	16719	38.267125999999998	38.275705000000002	55.834558000000001	55.831584999999997	Советская	0103000020E61000000100000005000000A5F44C2F312243400D6C956071EA4B40A5F44C2F31224340BE4EEACBD2EA4B40FE2B2B4D4A234340BE4EEACBD2EA4B40FE2B2B4D4A2343400D6C956071EA4B40A5F44C2F312243400D6C956071EA4B40
80659	16719	38.257531999999998	38.260874000000001	55.836660999999999	55.834350000000001	Московская	0103000020E6100000010000000500000034D6FECEF620434074B515FBCBEA4B4034D6FECEF6204340596B28B517EB4B403830B95164214340596B28B517EB4B403830B9516421434074B515FBCBEA4B4034D6FECEF620434074B515FBCBEA4B40
4674	16719	38.260407000000001	38.263370999999999	55.828409999999998	55.818624	Кудиновское шоссе	0103000020E6100000010000000500000022533E045521434040DCD5ABC8E84B4022533E0455214340F5D6C05609EA4B407FDB1324B6214340F5D6C05609EA4B407FDB1324B621434040DCD5ABC8E84B4022533E045521434040DCD5ABC8E84B40
4050	3079	38.453068000000002	38.525849999999998	55.858705	55.856861000000002	шоссе Энтузиастов	0103000020E610000001000000050000009C6ED921FE394340E31B0A9FADED4B409C6ED921FE394340B2F4A10BEAED4B40014D840D4F434340B2F4A10BEAED4B40014D840D4F434340E31B0A9FADED4B409C6ED921FE394340E31B0A9FADED4B40
2367	3079	38.396681000000001	38.452565	55.857557999999997	55.839652999999998	улица Третьего Интернационала	0103000020E61000000100000005000000E8F86871C6324340807EDFBF79EB4B40E8F86871C63243402A36E675C4ED4B40392861A6ED3943402A36E675C4ED4B40392861A6ED394340807EDFBF79EB4B40E8F86871C6324340807EDFBF79EB4B40
4334	3079	38.428804999999997	38.451514000000003	55.883873000000001	55.880237999999999	улица Текстилей	0103000020E610000001000000050000003EAE0D15E3364340255987A3ABF04B403EAE0D15E3364340A1681EC022F14B40D4D7F335CB394340A1681EC022F14B40D4D7F335CB394340255987A3ABF04B403EAE0D15E3364340255987A3ABF04B40
874	3079	38.428624999999997	38.447040999999999	55.867576	55.862166000000002	улица 28 Июня 1906 Года	0103000020E61000000100000005000000BE9F1A2FDD36434090DC9A745BEE4B40BE9F1A2FDD364340B265F9BA0CEF4B404E7CB5A338394340B265F9BA0CEF4B404E7CB5A33839434090DC9A745BEE4B40BE9F1A2FDD36434090DC9A745BEE4B40
80609	3079	38.395702	38.408915999999998	55.839329999999997	55.834986999999998	Юбилейная	0103000020E610000001000000050000001C7BF65CA6324340E6CAA0DAE0EA4B401C7BF65CA63243409D465A2A6FEB4B40D367075C573443409D465A2A6FEB4B40D367075C57344340E6CAA0DAE0EA4B401C7BF65CA6324340E6CAA0DAE0EA4B40
4299	3079	38.426802000000002	38.430889000000001	55.847684999999998	55.832293	Электростальское шоссе	0103000020E6100000010000000500000007EFAB72A136434049D8B79388EA4B4007EFAB72A1364340A6272CF180EC4B40639AE95E27374340A6272CF180EC4B40639AE95E2737434049D8B79388EA4B4007EFAB72A136434049D8B79388EA4B40
80575	3079	38.478454999999997	38.485515999999997	55.832403999999997	55.831347000000001	Центральная	0103000020E61000000100000005000000C8CD70033E3D43405950189469EA4B40C8CD70033E3D4340A087DA368CEA4B40A5D76663253E4340A087DA368CEA4B40A5D76663253E43405950189469EA4B40C8CD70033E3D43405950189469EA4B40
80603	3079	38.396681000000001	38.452565	55.857557999999997	55.839652999999998	Третьего Интернационала	0103000020E61000000100000005000000E8F86871C6324340807EDFBF79EB4B40E8F86871C63243402A36E675C4ED4B40392861A6ED3943402A36E675C4ED4B40392861A6ED394340807EDFBF79EB4B40E8F86871C6324340807EDFBF79EB4B40
79944	3079	38.447535000000002	38.466695999999999	55.898099000000002	55.876055999999998	Советской Конституции	0103000020E610000001000000050000005E68AED34839434077BB5E9A22F04B405E68AED34839434000C974E8F4F24B404696CCB1BC3B434000C974E8F4F24B404696CCB1BC3B434077BB5E9A22F04B405E68AED34839434077BB5E9A22F04B40
80291	3079	38.431221000000001	38.45252	55.857387000000003	55.851050000000001	Советская	0103000020E61000000100000005000000992CEE3F3237434062A1D634EFEC4B40992CEE3F32374340FE8172DBBEED4B409964E42CEC394340FE8172DBBEED4B409964E42CEC39434062A1D634EFEC4B40992CEE3F3237434062A1D634EFEC4B40
4358	3079	38.468555000000002	38.479542000000002	55.879252999999999	55.878186999999997	Ремесленная улица	0103000020E610000001000000050000004BB0389CF93B4340DC627E6E68F04B404BB0389CF93B434077F4BF5C8BF04B407B87DBA1613D434077F4BF5C8BF04B407B87DBA1613D4340DC627E6E68F04B404BB0389CF93B4340DC627E6E68F04B40
80649	3079	38.431150000000002	38.436351000000002	55.878819	55.876930000000002	Новая 	0103000020E61000000100000005000000D0D556EC2F374340CE70033E3FF04B40D0D556EC2F3743403D0D18247DF04B40D8497D59DA3743403D0D18247DF04B40D8497D59DA374340CE70033E3FF04B40D0D556EC2F374340CE70033E3FF04B40
4107	3079	38.440078999999997	38.450040999999999	55.851363999999997	55.848261000000001	Нижегородская улица	0103000020E61000000100000005000000045438825438434073BC02D193EC4B400454388254384340F17EDC7EF9EC4B40F86D88F19A394340F17EDC7EF9EC4B40F86D88F19A39434073BC02D193EC4B40045438825438434073BC02D193EC4B40
4142	3079	38.430889000000001	38.453705999999997	55.857371999999998	55.847684999999998	Комсомольская улица	0103000020E61000000100000005000000639AE95E27374340A6272CF180EC4B40639AE95E27374340C8409E5DBEED4B40DEFFC709133A4340C8409E5DBEED4B40DEFFC709133A4340A6272CF180EC4B40639AE95E27374340A6272CF180EC4B40
80752	3079	38.452997000000003	38.467046000000003	55.876016	55.857588999999997	Климова	0103000020E61000000100000005000000D31742CEFB3943406534F279C5ED4B40D31742CEFB394340E962D34A21F04B4023DDCF29C83B4340E962D34A21F04B4023DDCF29C83B43406534F279C5ED4B40D31742CEFB3943406534F279C5ED4B40
80023	3079	38.440159999999999	38.448703000000002	55.867545999999997	55.860726	Белякова	0103000020E61000000100000005000000F180B22957384340906802452CEE4B40F180B2295738434047E350BF0BEF4B40FD4E93196F39434047E350BF0BEF4B40FD4E93196F394340906802452CEE4B40F180B22957384340906802452CEE4B40
80638	3079	38.435965000000003	38.443052000000002	55.842326999999997	55.839689	Аэроклубная	0103000020E61000000100000005000000AF997CB3CD374340CDE7DCED7AEB4B40AF997CB3CD374340D6C4025FD1EB4B40B5368DEDB5384340D6C4025FD1EB4B40B5368DEDB5384340CDE7DCED7AEB4B40AF997CB3CD374340CDE7DCED7AEB4B40
4130	3079	38.475104000000002	38.486710000000002	55.859755999999997	55.859226	Автобазовая улица	0103000020E6100000010000000500000072193735D03C4340BBEF181EFBED4B4072193735D03C434017450F7C0CEE4B406E5166834C3E434017450F7C0CEE4B406E5166834C3E4340BBEF181EFBED4B4072193735D03C4340BBEF181EFBED4B40
80249	3079	38.428804999999997	38.451514000000003	55.883873000000001	55.880237999999999	 Текстилей	0103000020E610000001000000050000003EAE0D15E3364340255987A3ABF04B403EAE0D15E3364340A1681EC022F14B40D4D7F335CB394340A1681EC022F14B40D4D7F335CB394340255987A3ABF04B403EAE0D15E3364340255987A3ABF04B40
80668	3079	38.452997000000003	38.467046000000003	55.876016	55.857588999999997	 Климова	0103000020E61000000100000005000000D31742CEFB3943406534F279C5ED4B40D31742CEFB394340E962D34A21F04B4023DDCF29C83B4340E962D34A21F04B4023DDCF29C83B43406534F279C5ED4B40D31742CEFB3943406534F279C5ED4B40
80095	15914	38.372418000000003	38.410192000000002	55.893782999999999	55.887048999999998	Советская	0103000020E610000001000000050000008B389D64AB2F4340897956D28AF14B408B389D64AB2F4340425C397B67F24B40598AE42B81344340425C397B67F24B40598AE42B81344340897956D28AF14B408B389D64AB2F4340897956D28AF14B40
81053	17660	38.544023000000003	38.567414999999997	55.956556999999997	55.942312000000001	Горького	0103000020E61000000100000005000000CBA2B08BA24543406E50FBAD9DF84B40CBA2B08BA245434043E1B37570FA4B404221020EA148434043E1B37570FA4B404221020EA14843406E50FBAD9DF84B40CBA2B08BA24543406E50FBAD9DF84B40
71886	17013	38.196851000000002	38.238855999999998	55.775272000000001	55.751199	Центральная	0103000020E61000000100000005000000AB97DF6932194340DAE4F04927E04B40AB97DF693219434094C0E61C3CE34B40083A5AD5921E434094C0E61C3CE34B40083A5AD5921E4340DAE4F04927E04B40AB97DF6932194340DAE4F04927E04B40
80825	17013	38.196851000000002	38.238855999999998	55.775272000000001	55.751199	Напрудная	0103000020E61000000100000005000000AB97DF6932194340DAE4F04927E04B40AB97DF693219434094C0E61C3CE34B40083A5AD5921E434094C0E61C3CE34B40083A5AD5921E4340DAE4F04927E04B40AB97DF6932194340DAE4F04927E04B40
71891	59544	38.573155	38.605998	55.869905000000003	55.857286000000002	Спортивная	0103000020E61000000100000005000000FA449E245D494340CAA8328CBBED4B40FA449E245D4943403ED00A0C59EF4B4080B8AB57914D43403ED00A0C59EF4B4080B8AB57914D4340CAA8328CBBED4B40FA449E245D494340CAA8328CBBED4B40
80823	47906	38.502332000000003	38.513300000000001	55.731627000000003	55.723506	Центральная	0103000020E61000000100000005000000FDDD3B6A4C404340DA3A38D89BDC4B40FDDD3B6A4C40434070EF1AF4A5DD4B40B6847CD0B341434070EF1AF4A5DD4B40B6847CD0B3414340DA3A38D89BDC4B40FDDD3B6A4C404340DA3A38D89BDC4B40
80778	16279	38.151046000000001	38.184876000000003	55.749085999999998	55.736007000000001	Школьная	0103000020E610000001000000050000008718AF79551343404450357A35DE4B408718AF79551343401BF2CF0CE2DF4B405CE84A04AA1743401BF2CF0CE2DF4B405CE84A04AA1743404450357A35DE4B408718AF79551343404450357A35DE4B40
80940	17801	38.532029999999999	38.549799	55.998764999999999	55.984647000000002	Поселок Фабрики	0103000020E61000000100000005000000D53E1D8F19444340618DB3E908FE4B40D53E1D8F19444340D9B11188D7FF4B40CF2F4AD05F464340D9B11188D7FF4B40CF2F4AD05F464340618DB3E908FE4B40D53E1D8F19444340618DB3E908FE4B40
72344	17446	38.590626999999998	38.632947000000001	55.856043	55.840477	мкр.Фабрики	0103000020E610000001000000050000003A9160AA994B4340250516C094EB4B403A9160AA994B4340207C28D192ED4B40F88C446804514340207C28D192ED4B40F88C446804514340250516C094EB4B403A9160AA994B4340250516C094EB4B40
80824	17446	38.590626999999998	38.632947000000001	55.856043	55.840477	Демонстрационная	0103000020E610000001000000050000003A9160AA994B4340250516C094EB4B403A9160AA994B4340207C28D192ED4B40F88C446804514340207C28D192ED4B40F88C446804514340250516C094EB4B403A9160AA994B4340250516C094EB4B40
80756	49696	37.094915	37.098184000000003	55.592478999999997	55.589168000000001	Садовая	0103000020E610000001000000050000002E73BA2C268C4240C4EC65DB69CB4B402E73BA2C268C42408C48145AD6CB4B40C87E164B918C42408C48145AD6CB4B40C87E164B918C4240C4EC65DB69CB4B402E73BA2C268C4240C4EC65DB69CB4B40
71785	14268	36.645145999999997	36.684798000000001	55.434196	55.415706999999998	Центральная	0103000020E610000001000000050000009692E52494524240F0DB10E335B54B409692E52494524240EA060ABC93B74B40E02EFB75A7574240EA060ABC93B74B40E02EFB75A7574240F0DB10E335B54B409692E52494524240F0DB10E335B54B40
80983	12454	36.296151000000002	36.325651000000001	55.390588000000001	55.379404000000001	Нарская	0103000020E61000000100000005000000BFD6A546E82542405DFC6D4F90B04B40BFD6A546E8254240E31A9FC9FEB14B40717495EEAE294240E31A9FC9FEB14B40717495EEAE2942405DFC6D4F90B04B40BFD6A546E82542405DFC6D4F90B04B40
80981	12509	36.163811000000003	36.179594000000002	55.385029000000003	55.373899999999999	Школьная	0103000020E61000000100000005000000CFDC43C2F7144240B9FC87F4DBAF4B40CFDC43C2F71442407C8159A148B14B406747AAEFFC1642407C8159A148B14B406747AAEFFC164240B9FC87F4DBAF4B40CFDC43C2F7144240B9FC87F4DBAF4B40
80989	62042	36.911163999999999	36.935814000000001	55.485264999999998	55.475250000000003	Майская	0103000020E6100000010000000500000072A59E05A174424046B6F3FDD4BC4B4072A59E05A17442405C72DC291DBE4B40C991CEC0C87742405C72DC291DBE4B40C991CEC0C877424046B6F3FDD4BC4B4072A59E05A174424046B6F3FDD4BC4B40
81013	12582	36.157800999999999	36.157980999999999	55.335438000000003	55.33531	Центральная	0103000020E610000001000000050000005723BBD232144240C9022670EBAA4B405723BBD232144240F7EAE3A1EFAA4B40D731AEB838144240F7EAE3A1EFAA4B40D731AEB838144240C9022670EBAA4B405723BBD232144240C9022670EBAA4B40
72038	14104	37.151823	37.180461000000001	55.543627999999998	55.531131999999999	Центральная	0103000020E61000000100000005000000EBE3A1EF6E934240F6ED2422FCC34B40EBE3A1EF6E9342404E98309A95C54B400B9A9658199742404E98309A95C54B400B9A965819974240F6ED2422FCC34B40EBE3A1EF6E934240F6ED2422FCC34B40
71901	13518	36.633315000000003	36.656294000000003	55.315668000000002	55.291863999999997	Школьная	0103000020E610000001000000050000007B884677105142409B70AFCC5BA54B407B8846771051424066321CCF67A84B40D04719710154424066321CCF67A84B40D0471971015442409B70AFCC5BA54B407B884677105142409B70AFCC5BA54B40
80604	1095	36.717334999999999	36.729058000000002	55.416105000000002	55.408071999999997	Шибанкова	0103000020E6100000010000000500000059A31EA2D15B4240E7340BB43BB44B4059A31EA2D15B4240DE59BBED42B54B408F71C5C5515D4240DE59BBED42B54B408F71C5C5515D4240E7340BB43BB44B4059A31EA2D15B4240E7340BB43BB44B40
81045	1095	36.715941999999998	36.722724999999997	55.373126999999997	55.372928000000002	Чехова	0103000020E610000001000000050000009AEAC9FCA35B4240A0E1CD1ABCAF4B409AEAC9FCA35B4240962023A0C2AF4B403480B740825C4240962023A0C2AF4B403480B740825C4240A0E1CD1ABCAF4B409AEAC9FCA35B4240A0E1CD1ABCAF4B40
2866	1095	36.734340000000003	36.741742000000002	55.38015	55.366287	Профсоюзная улица	0103000020E61000000100000005000000841266DAFE5D424098F90E7EE2AE4B40841266DAFE5D424086C954C1A8B04B40EA08E066F15E424086C954C1A8B04B40EA08E066F15E424098F90E7EE2AE4B40841266DAFE5D424098F90E7EE2AE4B40
72323	1095	36.700373999999996	36.727890000000002	55.385407999999998	55.379015000000003	Маршала Жукова	0103000020E61000000100000005000000FE7BF0DAA5594240C3D8429083B04B40FE7BF0DAA5594240F2CEA10C55B14B40F08AE07F2B5D4240F2CEA10C55B14B40F08AE07F2B5D4240C3D8429083B04B40FE7BF0DAA5594240C3D8429083B04B40
80344	1095	36.725949999999997	36.732058000000002	55.386211000000003	55.373612999999999	Ленина	0103000020E61000000100000005000000FE43FAEDEB5C4240232E008DD2AF4B40FE43FAEDEB5C4240802DAF5C6FB14B4039639813B45D4240802DAF5C6FB14B4039639813B45D4240232E008DD2AF4B40FE43FAEDEB5C4240232E008DD2AF4B40
3118	1095	36.716796000000002	36.719076999999999	55.387039000000001	55.381991999999997	Комсомольская улица	0103000020E61000000100000005000000AAF3A8F8BF5B4240B4AA251DE5B04B40AAF3A8F8BF5B424066A3737E8AB14B40242713B70A5C424066A3737E8AB14B40242713B70A5C4240B4AA251DE5B04B40AAF3A8F8BF5B4240B4AA251DE5B04B40
80629	1095	36.739891	36.741221000000003	55.388026000000004	55.384844999999999	Генерала Ефремова	0103000020E6100000010000000500000068CD8FBFB45E4240BA83D89942B14B4068CD8FBFB45E4240B5FF01D6AAB14B40E10D6954E05E4240B5FF01D6AAB14B40E10D6954E05E4240BA83D89942B14B4068CD8FBFB45E4240BA83D89942B14B40
3231	1095	36.749198	36.754964999999999	55.390148000000003	55.383633000000003	2-й Володарский переулок	0103000020E61000000100000005000000431D56B8E55F42404C55DAE21AB14B40431D56B8E55F4240C74CA25EF0B14B40F44F70B1A2604240C74CA25EF0B14B40F44F70B1A26042404C55DAE21AB14B40431D56B8E55F42404C55DAE21AB14B40
16892	1095	36.717118999999997	36.720981999999999	55.380191000000003	55.379536000000002	1-й Колхозный переулок	0103000020E610000001000000050000008C2B2E8ECA5B4240CCD3B9A294B04B408C2B2E8ECA5B4240E59D4319AAB04B4099805F23495C4240E59D4319AAB04B4099805F23495C4240CCD3B9A294B04B408C2B2E8ECA5B4240CCD3B9A294B04B40
80634	13891	37.205362000000001	37.207895999999998	55.596183000000003	55.592683000000001	 Липовая аллея	0103000020E61000000100000005000000ABEB504D499A424095F25A09DDCB4B40ABEB504D499A424031B77BB94FCC4B400F7C0C569C9A424031B77BB94FCC4B400F7C0C569C9A424095F25A09DDCB4B40ABEB504D499A424095F25A09DDCB4B40
80646	13041	37.164955999999997	37.170616000000003	55.602815	55.600439999999999	Ленина	0103000020E61000000100000005000000B5A338471D954240E99AC937DBCC4B40B5A338471D954240E544BB0A29CD4B405116BEBED6954240E544BB0A29CD4B405116BEBED6954240E99AC937DBCC4B40B5A338471D954240E99AC937DBCC4B40
80066	61923	37.160131999999997	37.167848999999997	55.598858	55.596156999999998	Дачная	0103000020E61000000100000005000000838593347F944240072461DF4ECC4B40838593347F94424057790261A7CC4B4049D576137C95424057790261A7CC4B4049D576137C954240072461DF4ECC4B40838593347F944240072461DF4ECC4B40
71777	12600	36.963265999999997	36.998156999999999	55.570735999999997	55.521807000000003	мкрн Тарасково	0103000020E61000000100000005000000A3ACDF4C4C7B424075E95F92CAC24B40A3ACDF4C4C7B42402E5393E00DC94B4001A3CB9BC37F42402E5393E00DC94B4001A3CB9BC37F424075E95F92CAC24B40A3ACDF4C4C7B424075E95F92CAC24B40
71774	12600	36.963265999999997	36.998156999999999	55.570735999999997	55.521807000000003	мкрн КЭЧ	0103000020E61000000100000005000000A3ACDF4C4C7B424075E95F92CAC24B40A3ACDF4C4C7B42402E5393E00DC94B4001A3CB9BC37F42402E5393E00DC94B4001A3CB9BC37F424075E95F92CAC24B40A3ACDF4C4C7B424075E95F92CAC24B40
74151	12600	36.966760999999998	36.979517000000001	55.530368000000003	55.523519	Фабричная	0103000020E610000001000000050000002D060FD3BE7B4240D5EAABAB02C34B402D060FD3BE7B4240276C3F19E3C34B40227024D0607D4240276C3F19E3C34B40227024D0607D4240D5EAABAB02C34B402D060FD3BE7B4240D5EAABAB02C34B40
80951	28167	37.188473999999999	37.207580999999998	55.503914999999999	55.497725000000003	Административная	0103000020E61000000100000005000000BA1281EA1F98424068B3EA73B5BF4B40BA1281EA1F9842405F7B664980C04B40AF22A303929A42405F7B664980C04B40AF22A303929A424068B3EA73B5BF4B40BA1281EA1F98424068B3EA73B5BF4B40
79935	12366	36.184697	36.185442000000002	55.343004999999998	55.334603000000001	Первомайская улица	0103000020E61000000100000005000000AC55BB26A41742405E126745D4AA4B40AC55BB26A4174240A7AE7C96E7AB4B4005A73E90BC174240A7AE7C96E7AB4B4005A73E90BC1742405E126745D4AA4B40AC55BB26A41742405E126745D4AA4B40
67047	58932	37.184009000000003	37.187925999999997	55.612273000000002	55.609355000000001	Орджоникидзе	0103000020E61000000100000005000000B8955E9B8D974240B9533A58FFCD4B40B8955E9B8D974240A69C2FF65ECE4B40B7088CF50D984240A69C2FF65ECE4B40B7088CF50D984240B9533A58FFCD4B40B8955E9B8D974240B9533A58FFCD4B40
74146	13409	36.738562000000002	36.767200000000003	55.341341	55.320231999999997	Речная	0103000020E61000000100000005000000C0081A33895E4240FB90B75CFDA84B40C0081A33895E424058E4D70FB1AB4B40E0BE0E9C3362424058E4D70FB1AB4B40E0BE0E9C33624240FB90B75CFDA84B40C0081A33895E4240FB90B75CFDA84B40
79934	2721	37.050196	37.067273	55.538927000000001	55.535845000000002	Школьная	0103000020E61000000100000005000000EC3191D26C864240D15CA79196C44B40EC3191D26C86424038F7578FFBC44B40B073D3669C88424038F7578FFBC44B40B073D3669C884240D15CA79196C44B40EC3191D26C864240D15CA79196C44B40
704	2721	37.044286	37.060760999999999	55.540852000000001	55.531188	Спортивная улица	0103000020E61000000100000005000000D8D5E429AB8542408A03E8F7FDC34B40D8D5E429AB854240F4FC69A33AC54B40A6EF3504C7874240F4FC69A33AC54B40A6EF3504C78742408A03E8F7FDC34B40D8D5E429AB8542408A03E8F7FDC34B40
80632	2721	37.056440000000002	37.064380999999997	55.556384999999999	55.548589	Самохина	0103000020E61000000100000005000000D717096D3987424001F9122A38C64B40D717096D39874240137EA99F37C74B40ECBDF8A23D884240137EA99F37C74B40ECBDF8A23D88424001F9122A38C64B40D717096D3987424001F9122A38C64B40
3418	2721	37.063643999999996	37.073445	55.560428000000002	55.553539000000001	Парковая улица	0103000020E61000000100000005000000164B917C25884240C007AF5DDAC64B40164B917C25884240A0E1CD1ABCC74B40018750A566894240A0E1CD1ABCC74B40018750A566894240C007AF5DDAC64B40164B917C25884240C007AF5DDAC64B40
80832	2721	37.090369000000003	37.099792000000001	55.568268000000003	55.560713	Куйбышева	0103000020E610000001000000050000003FC91D36918B424095B88E71C5C74B403FC91D36918B424082AE7D01BDC84B408333F8FBC58C424082AE7D01BDC84B408333F8FBC58C424095B88E71C5C74B403FC91D36918B424095B88E71C5C74B40
3374	2721	37.077522999999999	37.081277999999998	55.552953000000002	55.550249000000001	Комсомольская улица	0103000020E610000001000000050000000AD80E46EC8942400FD4298F6EC64B400AD80E46EC894240D09CF529C7C64B4030F14751678A4240D09CF529C7C64B4030F14751678A42400FD4298F6EC64B400AD80E46EC8942400FD4298F6EC64B40
80645	2721	37.072349000000003	37.080568	55.545228000000002	55.538927000000001	Горького	0103000020E61000000100000005000000FC7266BB4289424038F7578FFBC44B40FC7266BB42894240876EF607CAC54B40548D5E0D508A4240876EF607CAC54B40548D5E0D508A424038F7578FFBC44B40FC7266BB4289424038F7578FFBC44B40
80413	2721	37.064380999999997	37.068010000000001	55.548589	55.532513000000002	Апрелевская 	0103000020E61000000100000005000000ECBDF8A23D884240F1D8CF6229C44B40ECBDF8A23D88424001F9122A38C64B4086E63A8DB488424001F9122A38C64B4086E63A8DB4884240F1D8CF6229C44B40ECBDF8A23D884240F1D8CF6229C44B40
80625	10013	37.741701999999997	37.746903000000003	55.980195000000002	55.979782	Пионерская	0103000020E610000001000000050000005BB05417F0DE4240D09A1F7F69FD4B405BB05417F0DE4240F3599E0777FD4B4064247B849ADF4240F3599E0777FD4B4064247B849ADF4240D09A1F7F69FD4B405BB05417F0DE4240D09A1F7F69FD4B40
2467	2720	37.727058999999997	37.739842000000003	55.912410000000001	55.904882000000001	улица Щербакова	0103000020E6100000010000000500000098A1F14410DD42409A5E622CD3F34B4098A1F14410DD42408D45D3D9C9F44B40871A8524B3DE42408D45D3D9C9F44B40871A8524B3DE42409A5E622CD3F34B4098A1F14410DD42409A5E622CD3F34B40
2399	2720	37.706937000000003	37.747208000000001	55.922288000000002	55.903816999999997	улица Мира	0103000020E610000001000000050000008BAA5FE97CDA4240CF488446B0F34B408BAA5FE97CDA424023BF7E880DF64B40A0A70183A4DF424023BF7E880DF64B40A0A70183A4DF4240CF488446B0F34B408BAA5FE97CDA4240CF488446B0F34B40
2316	2720	37.740766999999998	37.747666000000002	55.921979999999998	55.915770000000002	улица Комарова	0103000020E610000001000000050000005F7AFB73D1DE424037548CF337F54B405F7AFB73D1DE424075C8CD7003F64B40632AFD84B3DF424075C8CD7003F64B40632AFD84B3DF424037548CF337F54B405F7AFB73D1DE424037548CF337F54B40
2410	2720	37.711689	37.748367000000002	55.924472000000002	55.911532000000001	улица Колпакова	0103000020E6100000010000000500000023F609A018DB4240F5A0A014ADF44B4023F609A018DB4240AB08371955F64B40EC33677DCADF4240AB08371955F64B40EC33677DCADF4240F5A0A014ADF44B4023F609A018DB4240F5A0A014ADF44B40
2656	2720	37.698151000000003	37.726556000000002	55.896518999999998	55.892249	улица Веры Волошиной	0103000020E61000000100000005000000B95510035DD94240C171193735F24B40B95510035DD942400E9F7422C1F24B40365B79C9FFDC42400E9F7422C1F24B40365B79C9FFDC4240C171193735F24B40B95510035DD94240C171193735F24B40
2269	2720	37.743166000000002	37.755769000000001	55.924824999999998	55.919134999999997	улица Белобородова	0103000020E61000000100000005000000E4BF401020DF4240F2CD3637A6F54B40E4BF401020DF4240F8C264AA60F64B40522AE109BDE04240F8C264AA60F64B40522AE109BDE04240F2CD3637A6F54B40E4BF401020DF4240F2CD3637A6F54B40
2437	2720	37.703218	37.724938999999999	55.916778999999998	55.901541000000002	Юбилейная улица	0103000020E61000000100000005000000B1FA230C03DA424067800BB265F34B40B1FA230C03DA42406D54A70359F54B40274C18CDCADC42406D54A70359F54B40274C18CDCADC424067800BB265F34B40B1FA230C03DA424067800BB265F34B40
80092	2720	37.703218	37.724938999999999	55.916778999999998	55.901541000000002	Юбилейная	0103000020E61000000100000005000000B1FA230C03DA424067800BB265F34B40B1FA230C03DA42406D54A70359F54B40274C18CDCADC42406D54A70359F54B40274C18CDCADC424067800BB265F34B40B1FA230C03DA424067800BB265F34B40
2045	2720	37.732458000000001	37.736939999999997	55.892727999999998	55.890855000000002	Школьный переулок	0103000020E61000000100000005000000C7D8092FC1DD4240323D618907F24B40C7D8092FC1DD42409B1C3EE944F24B409F8EC70C54DE42409B1C3EE944F24B409F8EC70C54DE4240323D618907F24B40C7D8092FC1DD4240323D618907F24B40
80628	2720	37.748294999999999	37.752158000000001	55.915871000000003	55.911532000000001	Шараповская	0103000020E6100000010000000500000052616C21C8DF4240F5A0A014ADF44B4052616C21C8DF42406B2DCC423BF54B405FB69DB646E042406B2DCC423BF54B405FB69DB646E04240F5A0A014ADF44B4052616C21C8DF4240F5A0A014ADF44B40
74131	2720	37.80294	37.804611000000001	55.933745999999999	55.93186	Чапаева	0103000020E610000001000000050000003B53E8BCC6E64240AC39403047F74B403B53E8BCC6E64240AA622AFD84F74B403D80457EFDE64240AA622AFD84F74B403D80457EFDE64240AC39403047F74B403B53E8BCC6E64240AC39403047F74B40
702	2720	37.765866000000003	37.782592999999999	55.949617000000003	55.919559	Силикатная улица	0103000020E61000000100000005000000268FA7E507E2424009DFFB1BB4F54B40268FA7E507E24240E25CC30C8DF94B400D8AE6012CE44240E25CC30C8DF94B400D8AE6012CE4424009DFFB1BB4F54B40268FA7E507E2424009DFFB1BB4F54B40
80071	2720	37.765866000000003	37.782592999999999	55.949617000000003	55.919559	Силикатная	0103000020E61000000100000005000000268FA7E507E2424009DFFB1BB4F54B40268FA7E507E24240E25CC30C8DF94B400D8AE6012CE44240E25CC30C8DF94B400D8AE6012CE4424009DFFB1BB4F54B40268FA7E507E2424009DFFB1BB4F54B40
2327	2720	37.719386999999998	37.759030000000003	55.916455999999997	55.898249999999997	Новомытищинский проспект	0103000020E6100000010000000500000072158BDF14DC4240E5D022DBF9F24B4072158BDF14DC42408A1C226E4EF54B40695721E527E142408A1C226E4EF54B40695721E527E14240E5D022DBF9F24B4072158BDF14DC4240E5D022DBF9F24B40
2456	2720	37.714869	37.734281000000003	55.916435999999997	55.903671000000003	Летная улица	0103000020E610000001000000050000004DF6CFD380DB4240FCABC77DABF34B404DF6CFD380DB424043705CC64DF54B407F8978EBFCDD424043705CC64DF54B407F8978EBFCDD4240FCABC77DABF34B404DF6CFD380DB4240FCABC77DABF34B40
80085	2720	37.714869	37.734281000000003	55.916435999999997	55.903671000000003	Летная	0103000020E610000001000000050000004DF6CFD380DB4240FCABC77DABF34B404DF6CFD380DB424043705CC64DF54B407F8978EBFCDD424043705CC64DF54B407F8978EBFCDD4240FCABC77DABF34B404DF6CFD380DB4240FCABC77DABF34B40
80060	2720	37.768614999999997	37.773133999999999	55.915644	55.909711000000001	Карла Маркса	0103000020E61000000100000005000000861BF0F961E24240DEE7F86871F44B40861BF0F961E24240AA6395D233F54B407CB60E0EF6E24240AA6395D233F54B407CB60E0EF6E24240DEE7F86871F44B40861BF0F961E24240DEE7F86871F44B40
80624	2720	37.698151000000003	37.726556000000002	55.896518999999998	55.892249	Веры Волошиной	0103000020E61000000100000005000000B95510035DD94240C171193735F24B40B95510035DD942400E9F7422C1F24B40365B79C9FFDC42400E9F7422C1F24B40365B79C9FFDC4240C171193735F24B40B95510035DD94240C171193735F24B40
80516	2720	37.771903000000002	37.783329000000002	55.919795999999998	55.915376999999999	Академика Каргина	0103000020E610000001000000050000009757AEB7CDE242405B41D3122BF54B409757AEB7CDE24240ED7E15E0BBF54B401381EA1F44E44240ED7E15E0BBF54B401381EA1F44E442405B41D3122BF54B409757AEB7CDE242405B41D3122BF54B40
2205	2720	37.784677000000002	37.794575999999999	55.948819999999998	55.943477000000001	2-я Новая улица	0103000020E610000001000000050000003276C24B70E442409CC3B5DAC3F84B403276C24B70E4424036E50AEF72F94B40DF1797AAB4E5424036E50AEF72F94B40DF1797AAB4E542409CC3B5DAC3F84B403276C24B70E442409CC3B5DAC3F84B40
2176	2720	37.781739000000002	37.803083000000001	55.931668000000002	55.929903000000003	2-я Институтская улица	0103000020E61000000100000005000000FE80070610E44240E5B9BE0F07F74B40FE80070610E44240685DA3E540F74B409E7C7A6CCBE64240685DA3E540F74B409E7C7A6CCBE64240E5B9BE0F07F74B40FE80070610E44240E5B9BE0F07F74B40
2106	2720	37.773304000000003	37.777552999999997	55.917934000000002	55.914538999999998	2-й Первомайский проезд	0103000020E61000000100000005000000D9EE1EA0FBE2424051F52B9D0FF54B40D9EE1EA0FBE2424078F17EDC7EF54B400EF450DB86E3424078F17EDC7EF54B400EF450DB86E3424051F52B9D0FF54B40D9EE1EA0FBE2424051F52B9D0FF54B40
2690	2720	37.714509999999997	37.723770999999999	55.897862000000003	55.888613999999997	1-я Крестьянская улица	0103000020E610000001000000050000001D554D1075DB42404562821ABEF14B401D554D1075DB42401C295B24EDF24B4088653387A4DC42401C295B24EDF24B4088653387A4DC42404562821ABEF14B401D554D1075DB42404562821ABEF14B40
2146	2720	37.783365000000003	37.787219	55.923381999999997	55.921374999999998	1-й Щелковский проезд	0103000020E6100000010000000500000060EAE74D45E442400E2DB29DEFF54B4060EAE74D45E4424087DBA16131F64B4019E59997C3E4424087DBA16131F64B4019E59997C3E442400E2DB29DEFF54B4060EAE74D45E442400E2DB29DEFF54B40
71879	10511	37.544449	37.570689000000002	56.080818999999998	56.067123000000002	Усадебная	0103000020E6100000010000000500000082AB3C81B0C542409BE7887C97084C4082AB3C81B0C542409DF2E846580A4C40EE974F560CC942409DF2E846580A4C40EE974F560CC942409BE7887C97084C4082AB3C81B0C542409BE7887C97084C40
80773	10364	37.510601000000001	37.533974999999998	55.995618999999998	55.982044000000002	Светлая	0103000020E610000001000000050000000727A25F5BC14240D49D279EB3FD4B400727A25F5BC142405B23827170FF4B40D8F0F44A59C442405B23827170FF4B40D8F0F44A59C44240D49D279EB3FD4B400727A25F5BC14240D49D279EB3FD4B40
80831	10157	37.729961000000003	37.734954999999999	55.960377000000001	55.957090999999998	Дубки	0103000020E61000000100000005000000802DAF5C6FDD4240E12538F581FA4B40802DAF5C6FDD4240516A2FA2EDFA4B400E84640113DE4240516A2FA2EDFA4B400E84640113DE4240E12538F581FA4B40802DAF5C6FDD4240E12538F581FA4B40
80739	9701	37.604035000000003	37.616	55.929848	55.923009	Заводская	0103000020E61000000100000005000000D751D50451CD4240F374AE2825F64B40D751D50451CD424021205F4205F74B40022B8716D9CE424021205F4205F74B40022B8716D9CE4240F374AE2825F64B40D751D50451CD4240F374AE2825F64B40
74999	60426	38.727485999999999	38.836253999999997	55.130631000000001	55.068081999999997	Октябрьской Революции	0103000020E610000001000000050000002026E1421E5D43401FB935E9B6884B402026E1421E5D4340016C4084B8904B401893FE5E0A6B4340016C4084B8904B401893FE5E0A6B43401FB935E9B6884B402026E1421E5D43401FB935E9B6884B40
80758	5763	35.581162999999997	35.640020999999997	55.543781000000003	55.510232000000002	Урицкого	0103000020E610000001000000050000009752978C63CA4140B4AF3C484FC14B409752978C63CA4140D597A59D9AC54B4069E04735ECD14140D597A59D9AC54B4069E04735ECD14140B4AF3C484FC14B409752978C63CA4140B4AF3C484FC14B40
80868	5763	35.581162999999997	35.640020999999997	55.543781000000003	55.510232000000002	Партизанская 	0103000020E610000001000000050000009752978C63CA4140B4AF3C484FC14B409752978C63CA4140D597A59D9AC54B4069E04735ECD14140D597A59D9AC54B4069E04735ECD14140B4AF3C484FC14B409752978C63CA4140B4AF3C484FC14B40
80842	5763	35.581162999999997	35.640020999999997	55.543781000000003	55.510232000000002	Партизанская	0103000020E610000001000000050000009752978C63CA4140B4AF3C484FC14B409752978C63CA4140D597A59D9AC54B4069E04735ECD14140D597A59D9AC54B4069E04735ECD14140B4AF3C484FC14B409752978C63CA4140B4AF3C484FC14B40
80977	7203	35.893166000000001	35.909748999999998	55.385663999999998	55.362803	Советская	0103000020E6100000010000000500000017F3734353F2414002F2255470AE4B4017F3734353F241404D9F1D705DB14B40CB48BDA772F441404D9F1D705DB14B40CB48BDA772F4414002F2255470AE4B4017F3734353F2414002F2255470AE4B40
80733	7290	35.799911999999999	35.825415	55.355356999999998	55.333737999999997	Школьная	0103000020E61000000100000005000000C7D6338463E641405AB741EDB7AA4B40C7D6338463E64140CCB392567CAD4B405D50DF32A7E94140CCB392567CAD4B405D50DF32A7E941405AB741EDB7AA4B40C7D6338463E641405AB741EDB7AA4B40
80728	6675	35.500405000000001	35.519629000000002	55.453968000000003	55.436188000000001	Пионерская	0103000020E61000000100000005000000A0E062450DC041402E742502D5B74B40A0E062450DC041401CB7989F1BBA4B40CF86FC3383C241401CB7989F1BBA4B40CF86FC3383C241402E742502D5B74B40A0E062450DC041402E742502D5B74B40
80482	4563	36.001871000000001	36.025891999999999	55.508977999999999	55.505485	Московская	0103000020E61000000100000005000000C9E7154F3D0042402DCF83BBB3C04B40C9E7154F3D0042401631EC3026C14B40309DD66D500342401631EC3026C14B40309DD66D500342402DCF83BBB3C04B40C9E7154F3D0042402DCF83BBB3C04B40
80531	4563	36.025891999999999	36.042475000000003	55.505485	55.503711000000003	Мира	0103000020E61000000100000005000000309DD66D5003424057D11F9A79C04B40309DD66D500342402DCF83BBB3C04B40E5F21FD26F0542402DCF83BBB3C04B40E5F21FD26F05424057D11F9A79C04B40309DD66D5003424057D11F9A79C04B40
6580	4563	36.02026	36.023997000000001	55.508344999999998	55.496934000000003	Красноармейская улица	0103000020E610000001000000050000005FB532E1970242409F2287889BBF4B405FB532E197024240E50AEF7211C14B40DF196D5512034240E50AEF7211C14B40DF196D55120342409F2287889BBF4B405FB532E1970242409F2287889BBF4B40
80623	4563	36.036375999999997	36.041685000000001	55.496001	55.495665000000002	Восточная 	0103000020E61000000100000005000000FD2D01F8A7044240CC6262F371BF4B40FD2D01F8A704424043E4F4F57CBF4B40ECDD1FEF5505424043E4F4F57CBF4B40ECDD1FEF55054240CC6262F371BF4B40FD2D01F8A7044240CC6262F371BF4B40
80539	4563	36.036375999999997	36.041685000000001	55.496001	55.495665000000002	Восточная	0103000020E61000000100000005000000FD2D01F8A7044240CC6262F371BF4B40FD2D01F8A704424043E4F4F57CBF4B40ECDD1FEF5505424043E4F4F57CBF4B40ECDD1FEF55054240CC6262F371BF4B40FD2D01F8A7044240CC6262F371BF4B40
80593	4563	36.032513000000002	36.034776999999998	55.492593999999997	55.483964	Ватутина	0103000020E61000000100000005000000F1D8CF62290442407E384888F2BD4B40F1D8CF6229044240581AF8510DBF4B4095D39E9273044240581AF8510DBF4B4095D39E92730442407E384888F2BD4B40F1D8CF62290442407E384888F2BD4B40
79930	4563	35.990282999999998	36.013540999999996	55.509354999999999	55.507993999999997	Бородинская	0103000020E610000001000000050000007364E597C1FE4140384888F205C14B407364E597C1FE4140EC866D8B32C14B40DB1324B6BB014240EC866D8B32C14B40DB1324B6BB014240384888F205C14B407364E597C1FE4140384888F205C14B40
80508	4563	36.032342	36.040553000000003	55.509217	55.504556999999998	20 Января	0103000020E61000000100000005000000C4245CC823044240E3FBE25295C04B40C4245CC8230442409BC8CC052EC14B409A6038D7300542409BC8CC052EC14B409A6038D730054240E3FBE25295C04B40C4245CC823044240E3FBE25295C04B40
80980	6429	35.792636000000002	35.828488	55.616396999999999	55.602305999999999	Центральная	0103000020E61000000100000005000000EED0B01875E54140A017EE5C18CD4B40EED0B01875E541401F2DCE18E6CE4B40719010E50BEA41401F2DCE18E6CE4B40719010E50BEA4140A017EE5C18CD4B40EED0B01875E54140A017EE5C18CD4B40
80919	62022	38.005958999999997	38.011223000000001	55.662160999999998	55.646076000000001	Большое Кореневское шоссе	0103000020E61000000100000005000000F50EB743C3004340815D4D9EB2D24B40F50EB743C3004340E4D70FB1C1D44B4044FB58C16F014340E4D70FB1C1D44B4044FB58C16F014340815D4D9EB2D24B40F50EB743C3004340815D4D9EB2D24B40
1048	3237	37.952185999999998	37.956839000000002	55.659495	55.659281999999997	улица Грибоедова	0103000020E61000000100000005000000C2DA183BE1F94240B56B425A63D44B40C2DA183BE1F94240117008556AD44B40C8444AB379FA4240117008556AD44B40C8444AB379FA4240B56B425A63D44B40C2DA183BE1F94240B56B425A63D44B40
947	3237	37.945709000000001	37.972551000000003	55.662562000000001	55.660384000000001	улица Гаршина	0103000020E61000000100000005000000354415FE0CF942409D66817687D44B40354415FE0CF9424043C9E4D4CED44B409758198D7CFC424043C9E4D4CED44B409758198D7CFC42409D66817687D44B40354415FE0CF942409D66817687D44B40
80881	3237	37.942079999999997	37.947901000000002	55.654426999999998	55.653582999999998	Чехова	0103000020E610000001000000050000009B1BD31396F842405C1C959BA8D34B409B1BD31396F84240484F9143C4D34B40406CE9D154F94240484F9143C4D34B40406CE9D154F942405C1C959BA8D34B409B1BD31396F842405C1C959BA8D34B40
71790	3237	37.903111000000003	37.970637000000004	55.672372000000003	55.616777999999996	Птицефабрика микрорайон	0103000020E6100000010000000500000035D4282499F342403672DD94F2CE4B4035D4282499F34240815F234910D64B40CFA44DD53DFC4240815F234910D64B40CFA44DD53DFC42403672DD94F2CE4B4035D4282499F342403672DD94F2CE4B40
80404	3237	37.944676000000001	37.952418999999999	55.671655999999999	55.666350000000001	Пионерская	0103000020E6100000010000000500000076A8A624EBF8424045D8F0F44AD54B4076A8A624EBF84240C214E5D2F8D54B40658BA4DDE8F94240C214E5D2F8D54B40658BA4DDE8F9424045D8F0F44AD54B4076A8A624EBF8424045D8F0F44AD54B40
80723	3237	37.903111000000003	37.970637000000004	55.672372000000003	55.616777999999996	Октябрьская	0103000020E6100000010000000500000035D4282499F342403672DD94F2CE4B4035D4282499F34240815F234910D64B40CFA44DD53DFC4240815F234910D64B40CFA44DD53DFC42403672DD94F2CE4B4035D4282499F342403672DD94F2CE4B40
79933	3237	37.950263	37.957971000000001	55.671950000000002	55.656320999999998	Гоголя	0103000020E61000000100000005000000A7CCCD37A2F94240C956975302D44B40A7CCCD37A2F942400B46257502D64B401AC231CB9EFA42400B46257502D64B401AC231CB9EFA4240C956975302D44B40A7CCCD37A2F94240C956975302D44B40
80385	3237	37.945709000000001	37.972551000000003	55.662562000000001	55.660384000000001	Гаршина	0103000020E61000000100000005000000354415FE0CF942409D66817687D44B40354415FE0CF9424043C9E4D4CED44B409758198D7CFC424043C9E4D4CED44B409758198D7CFC42409D66817687D44B40354415FE0CF942409D66817687D44B40
667	2591	37.961824999999997	37.97052	55.613965999999998	55.612065000000001	улица Гоголя	0103000020E61000000100000005000000D3BCE3141DFB42405C035B2558CE4B40D3BCE3141DFB42408F6D197096CE4B40950ED6FF39FC42408F6D197096CE4B40950ED6FF39FC42405C035B2558CE4B40D3BCE3141DFB42405C035B2558CE4B40
80301	2591	37.970484999999996	37.978839000000001	55.605128999999998	55.603537000000003	Первомайская	0103000020E6100000010000000500000018213CDA38FC424086764EB340CD4B4018213CDA38FC42403B6EF8DD74CD4B405186AA984AFD42403B6EF8DD74CD4B405186AA984AFD424086764EB340CD4B4018213CDA38FC424086764EB340CD4B40
80829	62005	37.966712000000001	37.968435999999997	55.61298	55.611434000000003	Пушкина	0103000020E610000001000000050000004C530438BDFB4240CCD4247843CE4B404C530438BDFB4240118DEE2076CE4B407022FAB5F5FB4240118DEE2076CE4B407022FAB5F5FB4240CCD4247843CE4B404C530438BDFB4240CCD4247843CE4B40
80893	4477	37.973736000000002	37.975209999999997	55.696823000000002	55.682924999999997	Заречная	0103000020E610000001000000050000000C789961A3FC4240764F1E166AD74B400C789961A3FC4240E10CFE7E31D94B40B75D68AED3FC4240E10CFE7E31D94B40B75D68AED3FC4240764F1E166AD74B400C789961A3FC4240764F1E166AD74B40
80402	2042	38.003991999999997	38.010756000000001	55.645440999999998	55.635432000000002	Шоссейная	0103000020E610000001000000050000000AB952CF820043407B6AF5D555D14B400AB952CF82004340AF3F89CF9DD24B402E1EDE7360014340AF3F89CF9DD24B402E1EDE73600143407B6AF5D555D14B400AB952CF820043407B6AF5D555D14B40
81076	2042	38.035513999999999	38.038711999999997	55.663150999999999	55.658479	Новая улица	0103000020E610000001000000050000006B4606B98B044340280D350A49D44B406B4606B98B044340A4A7C821E2D44B403BFBCA83F4044340A4A7C821E2D44B403BFBCA83F4044340280D350A49D44B406B4606B98B044340280D350A49D44B40
1015	2042	38.005958999999997	38.011223000000001	55.662160999999998	55.646076000000001	Большое Кореневское шоссе	0103000020E61000000100000005000000F50EB743C3004340815D4D9EB2D24B40F50EB743C3004340E4D70FB1C1D44B4044FB58C16F014340E4D70FB1C1D44B4044FB58C16F014340815D4D9EB2D24B40F50EB743C3004340815D4D9EB2D24B40
80613	61928	38.003991999999997	38.010756000000001	55.645440999999998	55.635432000000002	Шоссейная	0103000020E610000001000000050000000AB952CF820043407B6AF5D555D14B400AB952CF82004340AF3F89CF9DD24B402E1EDE7360014340AF3F89CF9DD24B402E1EDE73600143407B6AF5D555D14B400AB952CF820043407B6AF5D555D14B40
80475	61928	37.996419000000003	38.003991999999997	55.645090000000003	55.644506	1-я Комсомольская	0103000020E61000000100000005000000780E65A88AFF4240B309302C7FD24B40780E65A88AFF4240037D224F92D24B400AB952CF82004340037D224F92D24B400AB952CF82004340B309302C7FD24B40780E65A88AFF4240B309302C7FD24B40
654	877	37.888091000000003	37.895798999999997	55.705325999999999	55.696970999999998	улица Урицкого	0103000020E610000001000000050000009C6F44F7ACF1424055A1815836D94B409C6F44F7ACF142405E82531F48DA4B400E65A88AA9F242405E82531F48DA4B400E65A88AA9F2424055A1815836D94B409C6F44F7ACF1424055A1815836D94B40
745	877	37.889465000000001	37.900775000000003	55.691653000000002	55.689110999999997	улица Побратимов	0103000020E61000000100000005000000E4F736FDD9F142402C280CCA34D84B40E4F736FDD9F142401497E31588D84B40F7065F984CF342401497E31588D84B40F7065F984CF342402C280CCA34D84B40E4F736FDD9F142402C280CCA34D84B40
354	877	37.860655999999999	37.893571000000001	55.691668	55.675108000000002	улица Кирова	0103000020E61000000100000005000000978DCEF929EE42404DA25EF069D64B40978DCEF929EE424049D8B79388D84B40B7D3D68860F2424049D8B79388D84B40B7D3D68860F242404DA25EF069D64B40978DCEF929EE42404DA25EF069D64B40
793	877	37.906281999999997	37.917520000000003	55.692520999999999	55.686689999999999	проспект Победы	0103000020E610000001000000050000000B7A6F0C01F44240C03E3A75E5D74B400B7A6F0C01F4424088653387A4D84B4085B69C4B71F5424088653387A4D84B4085B69C4B71F54240C03E3A75E5D74B400B7A6F0C01F44240C03E3A75E5D74B40
80373	877	37.895502	37.908670999999998	55.670304999999999	55.657463999999997	Южная улица	0103000020E6100000010000000500000055C03DCF9FF242400F26C5C727D44B4055C03DCF9FF2424032ACE28DCCD54B406CE9D1544FF4424032ACE28DCCD54B406CE9D1544FF442400F26C5C727D44B4055C03DCF9FF242400F26C5C727D44B40
80042	877	37.888979999999997	37.902320000000003	55.698746	55.695006999999997	Попова	0103000020E610000001000000050000002766BD18CAF14240DBBE47FDF5D84B402766BD18CAF14240FC1A498270D94B406C43C5387FF34240FC1A498270D94B406C43C5387FF34240DBBE47FDF5D84B402766BD18CAF14240DBBE47FDF5D84B40
225	877	37.864609000000002	37.917619000000002	55.693657000000002	55.658301999999999	Октябрьский проспект	0103000020E61000000100000005000000E469F981ABEE424019726C3D43D44B40E469F981ABEE42401CD2A8C0C9D84B401898158A74F542401CD2A8C0C9D84B401898158A74F5424019726C3D43D44B40E469F981ABEE424019726C3D43D44B40
79925	877	37.887183999999998	37.901134999999996	55.672396999999997	55.667645	Котельническая	0103000020E6100000010000000500000069C4CC3E8FF14240412B306475D54B4069C4CC3E8FF14240D976DA1A11D64B40F623456458F34240D976DA1A11D64B40F623456458F34240412B306475D54B4069C4CC3E8FF14240412B306475D54B40
80360	877	37.901485000000001	37.914484000000002	55.660496000000002	55.657899999999998	Космонавтов	0103000020E61000000100000005000000D36A48DC63F34240EA04341136D44B40D36A48DC63F34240C59107228BD44B408E5BCCCF0DF54240C59107228BD44B408E5BCCCF0DF54240EA04341136D44B40D36A48DC63F34240EA04341136D44B40
80349	877	37.884084999999999	37.889816000000003	55.675885000000001	55.673118000000002	Калараш	0103000020E610000001000000050000002CF180B229F14240AA2C0ABB28D64B402CF180B229F14240B16D516683D64B4091BA9D7DE5F14240B16D516683D64B4091BA9D7DE5F14240AA2C0ABB28D64B402CF180B229F14240AA2C0ABB28D64B40
79894	877	37.896796000000002	37.902679999999997	55.706294	55.698746	Гоголя	0103000020E6100000010000000500000081971936CAF24240FC1A498270D94B4081971936CAF2424036AE7FD767DA4B406B60AB048BF3424036AE7FD767DA4B406B60AB048BF34240FC1A498270D94B4081971936CAF24240FC1A498270D94B40
80387	877	37.899410000000003	37.906281999999997	55.697989999999997	55.692520999999999	Воинов-Интернационалистов	0103000020E6100000010000000500000002D9EBDD1FF3424088653387A4D84B4002D9EBDD1FF34240AF777FBC57D94B400B7A6F0C01F44240AF777FBC57D94B400B7A6F0C01F4424088653387A4D84B4002D9EBDD1FF3424088653387A4D84B40
80018	877	37.868211000000002	37.884551999999999	55.672575000000002	55.668005000000001	Авиаторов	0103000020E610000001000000050000008483BD8921EF42404148163081D54B408483BD8921EF4240B98D06F016D64B4042CEFBFF38F14240B98D06F016D64B4042CEFBFF38F142404148163081D54B408483BD8921EF42404148163081D54B40
78618	877	37.856901999999998	37.961888000000002	55.707050000000002	55.652059999999999	3-е Почтовое отделение	0103000020E6100000010000000500000041F0F8F6AEED4240CF83BBB376D34B4041F0F8F6AEED42408351499D80DA4B401A355F251FFB42408351499D80DA4B401A355F251FFB4240CF83BBB376D34B4041F0F8F6AEED4240CF83BBB376D34B40
80476	2491	38.000210000000003	38.006022000000002	55.658656999999998	55.655087000000002	Чехова	0103000020E61000000100000005000000EB909BE10600434073840CE4D9D34B40EB909BE106004340072461DF4ED44B403C873254C5004340072461DF4ED44B403C873254C500434073840CE4D9D34B40EB909BE10600434073840CE4D9D34B40
80468	2491	37.985728999999999	37.991531999999999	55.661271999999997	55.658763999999998	Федянина	0103000020E6100000010000000500000001DC2C5E2CFE42401DE4F56052D44B4001DC2C5E2CFE424058E1968FA4D44B40FF774485EAFE424058E1968FA4D44B40FF774485EAFE42401DE4F56052D44B4001DC2C5E2CFE42401DE4F56052D44B40
80407	2491	37.975048000000001	37.980761000000001	55.662495999999997	55.661226999999997	2-я Заводская	0103000020E61000000100000005000000DE03745FCEFC4240B81D1A16A3D44B40DE03745FCEFC42408BDD3EABCCD44B409C18929389FD42408BDD3EABCCD44B409C18929389FD4240B81D1A16A3D44B40DE03745FCEFC4240B81D1A16A3D44B40
80064	61922	37.972434	37.997163999999998	55.662318999999997	55.657468999999999	Карла Маркса	0103000020E610000001000000050000005DC2A1B778FC42402191B6F127D44B405DC2A1B778FC42407C4276DEC6D44B40D05FE811A3FF42407C4276DEC6D44B40D05FE811A3FF42402191B6F127D44B405DC2A1B778FC42402191B6F127D44B40
81024	61922	37.982351000000001	38.008654	55.670057	55.667884000000001	Железнодорожная улица	0103000020E61000000100000005000000B11875ADBDFD4240C6C210397DD54B40B11875ADBDFD42405ABA826DC4D54B40637D03931B0143405ABA826DC4D54B40637D03931B014340C6C210397DD54B40B11875ADBDFD4240C6C210397DD54B40
71775	59213	38.956654999999998	38.975403	54.888635999999998	54.874651999999998	Садовая	0103000020E610000001000000050000000647C9AB737A4340C4B0C398F46F4B400647C9AB737A43402D060FD3BE714B40CCB56801DA7C43402D060FD3BE714B40CCB56801DA7C4340C4B0C398F46F4B400647C9AB737A4340C4B0C398F46F4B40
71857	32372	39.255650000000003	39.270104000000003	54.910668999999999	54.899937999999999	Вокзальная	0103000020E61000000100000005000000789CA223B9A04340BD361B2B31734B40789CA223B9A04340923D42CD90744B40684293C492A24340923D42CD90744B40684293C492A24340BD361B2B31734B40789CA223B9A04340BD361B2B31734B40
80802	61998	39.169682000000002	39.193541000000003	54.960622000000001	54.951616999999999	микрорайон Сельхозтехника	0103000020E61000000100000005000000255CC823B8954340A8A8FA95CE794B40255CC823B8954340B8E864A9F57A4B40B3B794F3C5984340B8E864A9F57A4B40B3B794F3C5984340A8A8FA95CE794B40255CC823B8954340A8A8FA95CE794B40
80987	24473	39.148643	39.154491	54.861336999999999	54.856481000000002	Победы	0103000020E61000000100000005000000C1E3DBBB069343409C525E2BA16D4B40C1E3DBBB06934340D9EA724A406E4B405F43705CC6934340D9EA724A406E4B405F43705CC69343409C525E2BA16D4B40C1E3DBBB069343409C525E2BA16D4B40
80782	49279	39.286093999999999	39.306260999999999	54.852443999999998	54.847285999999997	Парковая	0103000020E6100000010000000500000079CA6ABA9EA44340E82D1EDE736C4B4079CA6ABA9EA44340F1D58EE21C6D4B402785798F33A74340F1D58EE21C6D4B402785798F33A74340E82D1EDE736C4B4079CA6ABA9EA44340E82D1EDE736C4B40
80943	49566	39.218854999999998	39.243442000000002	54.950029999999998	54.933883999999999	Озерная	0103000020E6100000010000000500000075C8CD70039C4340FB20CB8289774B4075C8CD70039C4340041C42959A794B40863C821B299F4340041C42959A794B40863C821B299F4340FB20CB8289774B4075C8CD70039C4340FB20CB8289774B40
80717	31335	38.880513999999998	38.910482000000002	54.959733	54.941662999999998	Школьная	0103000020E61000000100000005000000C7D5C8AEB4704340376DC66988784B40C7D5C8AEB47043402CF2EB87D87A4B4060CC96AC8A7443402CF2EB87D87A4B4060CC96AC8A744340376DC66988784B40C7D5C8AEB4704340376DC66988784B40
80995	31571	39.309145000000001	39.321793	54.777805999999998	54.767356999999997	Молодежная	0103000020E61000000100000005000000685C381092A74340A7AD11C138624B40685C381092A74340F850A2258F634B40768A558330A94340F850A2258F634B40768A558330A94340A7AD11C138624B40685C381092A74340A7AD11C138624B40
80966	32071	39.200097999999997	39.238618000000002	55.034291000000003	55.027036000000003	Советская	0103000020E610000001000000050000005CFFAECF9C99434047E867EA75834B405CFFAECF9C99434009C6C1A563844B40541EDD088B9E434009C6C1A563844B40541EDD088B9E434047E867EA75834B405CFFAECF9C99434047E867EA75834B40
7815	158	39.025798000000002	39.037432000000003	54.945520999999999	54.941766999999999	улица Островского	0103000020E61000000100000005000000AF264F594D834340DCB930D28B784B40AF264F594D834340325706D506794B4075E95F92CA844340325706D506794B4075E95F92CA844340DCB930D28B784B40AF264F594D834340DCB930D28B784B40
7791	158	39.017785000000003	39.037432000000003	54.95111	54.942521999999997	улица Жуковского	0103000020E6100000010000000500000000AE64C74682434058E1968FA4784B4000AE64C7468243400473F4F8BD794B4075E95F92CA8443400473F4F8BD794B4075E95F92CA84434058E1968FA4784B4000AE64C74682434058E1968FA4784B40
7778	158	39.019860000000001	39.025869999999998	54.948442	54.945520999999999	улица Гайдара	0103000020E61000000100000005000000D13FC1C58A824340325706D506794B40D13FC1C58A8243409013268C66794B4048F949B54F8343409013268C66794B4048F949B54F834340325706D506794B40D13FC1C58A824340325706D506794B40
7732	158	39.021154000000003	39.025393999999999	54.957562000000003	54.950454000000001	улица 40 лет Октября	0103000020E61000000100000005000000FD169D2CB58243401B2D077AA8794B40FD169D2CB582434039F24064917A4B40DFC14F1C4083434039F24064917A4B40DFC14F1C408343401B2D077AA8794B40FD169D2CB58243401B2D077AA8794B40
80178	158	38.994762000000001	39.041347999999999	54.982506999999998	54.923946999999998	Пушкина	0103000020E61000000100000005000000DBA6785C547F4340601E32E543764B40DBA6785C547F4340A88B14CAC27D4B40A4E029E44A854340A88B14CAC27D4B40A4E029E44A854340601E32E543764B40DBA6785C547F4340601E32E543764B40
80964	158	38.990234000000001	39.070328000000003	54.987228999999999	54.922564999999999	Озерная	0103000020E6100000010000000500000092B1DAFCBF7E434095B7239C16764B4092B1DAFCBF7E4340D65416855D7E4B401EFF058200894340D65416855D7E4B401EFF05820089434095B7239C16764B4092B1DAFCBF7E434095B7239C16764B40
80348	158	39.018953000000003	39.039794000000001	54.953194000000003	54.944020999999999	Мира	0103000020E610000001000000050000009F94490D6D8243405DDE1CAED5784B409F94490D6D824340295FD042027A4B40DC4944F817854340295FD042027A4B40DC4944F8178543405DDE1CAED5784B409F94490D6D8243405DDE1CAED5784B40
80719	32165	39.231513	39.269286999999998	55.013295999999997	54.999191000000003	Садовая	0103000020E61000000100000005000000A7CCCD37A29D434091BA9D7DE57F4B40A7CCCD37A29D43407495EEAEB3814B40751E15FF77A243407495EEAEB3814B40751E15FF77A2434091BA9D7DE57F4B40A7CCCD37A29D434091BA9D7DE57F4B40
80973	32165	39.231513	39.269286999999998	55.013295999999997	54.999191000000003	Октябрьской революции	0103000020E61000000100000005000000A7CCCD37A29D434091BA9D7DE57F4B40A7CCCD37A29D43407495EEAEB3814B40751E15FF77A243407495EEAEB3814B40751E15FF77A2434091BA9D7DE57F4B40A7CCCD37A29D434091BA9D7DE57F4B40
80907	32051	39.143765000000002	39.166744000000001	55.109214000000001	55.102426000000001	Околопрудная	0103000020E610000001000000050000009CA73AE4669243404B21904B1C8D4B409CA73AE466924340F7216FB9FA8D4B40F1660DDE57954340F7216FB9FA8D4B40F1660DDE579543404B21904B1C8D4B409CA73AE4669243404B21904B1C8D4B40
72197	32244	39.058632000000003	39.098086000000002	55.019398000000002	54.988515	Школьная	0103000020E61000000100000005000000E23FDD40818743407F4DD6A8877E4B40E23FDD4081874340CDCD37A27B824B40051901158E8C4340CDCD37A27B824B40051901158E8C43407F4DD6A8877E4B40E23FDD40818743407F4DD6A8877E4B40
72200	32244	39.058632000000003	39.098086000000002	55.019398000000002	54.988515	Лесная	0103000020E61000000100000005000000E23FDD40818743407F4DD6A8877E4B40E23FDD4081874340CDCD37A27B824B40051901158E8C4340CDCD37A27B824B40051901158E8C43407F4DD6A8877E4B40E23FDD40818743407F4DD6A8877E4B40
80770	31974	39.082867999999998	39.162306000000001	55.066972999999997	55.039940000000001	Совхозная	0103000020E6100000010000000500000045F12A6B9B8A4340B0E600C11C854B4045F12A6B9B8A4340855B3E9292884B40E8F86871C6944340855B3E9292884B40E8F86871C6944340B0E600C11C854B4045F12A6B9B8A4340B0E600C11C854B40
80939	31974	39.082867999999998	39.162306000000001	55.066972999999997	55.039940000000001	Набережная	0103000020E6100000010000000500000045F12A6B9B8A4340B0E600C11C854B4045F12A6B9B8A4340855B3E9292884B40E8F86871C6944340855B3E9292884B40E8F86871C6944340B0E600C11C854B4045F12A6B9B8A4340B0E600C11C854B40
80751	31558	39.242930000000001	39.271963999999997	54.810585000000003	54.790635000000002	Центральная	0103000020E61000000100000005000000D09B8A54189F43405709168733654B40D09B8A54189F434068D0D03FC1674B403CD862B7CFA2434068D0D03FC1674B403CD862B7CFA243405709168733654B40D09B8A54189F43405709168733654B40
71931	49371	39.105649999999997	39.153458000000001	54.940572000000003	54.926124999999999	Мира	0103000020E6100000010000000500000044696FF0858D4340068195438B764B4044696FF0858D434044C4CDA964784B40A0A70183A493434044C4CDA964784B40A0A70183A4934340068195438B764B4044696FF0858D4340068195438B764B40
71866	31479	39.223301999999997	39.241574	54.843445000000003	54.831581999999997	Центральная	0103000020E61000000100000005000000D190F128959C43409CF86A47716A4B40D190F128959C4340C47C7901F66B4B402EC896E5EB9E4340C47C7901F66B4B402EC896E5EB9E43409CF86A47716A4B40D190F128959C43409CF86A47716A4B40
80765	31767	39.169178000000002	39.190548999999997	54.982728999999999	54.969709000000002	Советская	0103000020E61000000100000005000000F299EC9FA795434085D1AC6C1F7C4B40F299EC9FA795434057EA5910CA7D4B408BA4DDE86398434057EA5910CA7D4B408BA4DDE86398434085D1AC6C1F7C4B40F299EC9FA795434085D1AC6C1F7C4B40
80754	32440	39.209817999999999	39.233578999999999	54.919150000000002	54.906765999999998	Клубная	0103000020E610000001000000050000005A0EF450DB9A4340F78F85E810744B405A0EF450DB9A4340280F0BB5A6754B402504ABEAE59D4340280F0BB5A6754B402504ABEAE59D4340F78F85E810744B405A0EF450DB9A4340F78F85E810744B40
71894	30864	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	Советская площадь	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
80709	30864	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	Малая Огаревская	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
80704	30864	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	Большая Огаревская	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
80968	61952	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	Советская площадь	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
80781	61952	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	Гагарина	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
80708	61952	39.303764000000001	39.373527000000003	54.957273000000001	54.927480000000003	Большая Огаревская	0103000020E61000000100000005000000E0D91EBDE1A64340D8D825AAB7764B40E0D91EBDE1A64340022CF2EB877A4B40259694BBCFAF4340022CF2EB877A4B40259694BBCFAF4340D8D825AAB7764B40E0D91EBDE1A64340D8D825AAB7764B40
79942	61898	35.622332999999998	35.651060999999999	56.227935000000002	56.226184000000003	Центральная	0103000020E610000001000000050000005C1C959BA8CF41407270E998F31C4C405C1C959BA8CF4140904E5DF92C1D4C40BC5983F755D34140904E5DF92C1D4C40BC5983F755D341407270E998F31C4C405C1C959BA8CF41407270E998F31C4C40
80821	29974	35.704501999999998	35.728631	56.362127000000001	56.350397000000001	Школьная	0103000020E61000000100000005000000B9FB1C1F2DDA4140EACE13CFD92C4C40B9FB1C1F2DDA4140D2FF722D5A2E4C4007EDD5C743DD4140D2FF722D5A2E4C4007EDD5C743DD4140EACE13CFD92C4C40B9FB1C1F2DDA4140EACE13CFD92C4C40
80978	29821	35.545158999999998	35.564678999999998	56.190426000000002	56.176929999999999	Микрорайон	0103000020E610000001000000050000005E0F26C5C7C5414034D769A4A5164C405E0F26C5C7C54140702711E15F184C4076DEC66647C84140702711E15F184C4076DEC66647C8414034D769A4A5164C405E0F26C5C7C5414034D769A4A5164C40
71900	29853	35.584847000000003	35.617941000000002	56.456806	56.435825000000001	Микрорайон	0103000020E61000000100000005000000F5143944DCCA4140BDE3141DC9374C40F5143944DCCA4140EC4E779E783A4C40C4EDD0B018CF4140EC4E779E783A4C40C4EDD0B018CF4140BDE3141DC9374C40F5143944DCCA4140BDE3141DC9374C40
2304	8402	35.641826999999999	35.644216	56.23518	56.234945000000003	улица Микрорайон	0103000020E610000001000000050000004B581B6327D24140EBAD81AD121E4C404B581B6327D241402E56D4601A1E4C40ACC77DAB75D241402E56D4601A1E4C40ACC77DAB75D24140EBAD81AD121E4C404B581B6327D24140EBAD81AD121E4C40
80437	8402	35.641826999999999	35.644216	56.23518	56.234945000000003	Микрорайон	0103000020E610000001000000050000004B581B6327D24140EBAD81AD121E4C404B581B6327D241402E56D4601A1E4C40ACC77DAB75D241402E56D4601A1E4C40ACC77DAB75D24140EBAD81AD121E4C404B581B6327D24140EBAD81AD121E4C40
79970	61908	35.622332999999998	35.651060999999999	56.227935000000002	56.226184000000003	Центральная	0103000020E610000001000000050000005C1C959BA8CF41407270E998F31C4C405C1C959BA8CF4140904E5DF92C1D4C40BC5983F755D34140904E5DF92C1D4C40BC5983F755D341407270E998F31C4C405C1C959BA8CF41407270E998F31C4C40
80965	29771	35.635061999999998	35.653396999999998	56.167738999999997	56.156635999999999	Микрорайон	0103000020E6100000010000000500000057772CB649D1414029B000A60C144C4057772CB649D14140C2A1B77878154C40FA264D83A2D34140C2A1B77878154C40FA264D83A2D3414029B000A60C144C4057772CB649D1414029B000A60C144C40
71784	29616	35.641556999999999	35.671345000000002	56.234025000000003	56.211263000000002	Волоколамское шоссе	0103000020E610000001000000050000008BC22E8A1ED241406CED7DAA0A1B4C408BC22E8A1ED2414024B9FC87F41D4C40A4AA09A2EED5414024B9FC87F41D4C40A4AA09A2EED541406CED7DAA0A1B4C408BC22E8A1ED241406CED7DAA0A1B4C40
80820	29916	35.616098999999998	35.642077999999998	56.383896999999997	56.362206999999998	Микрорайон	0103000020E61000000100000005000000950C0055DCCE4140EEB089CC5C2E4C40950C0055DCCE41402904728923314C4094BDA59C2FD241402904728923314C4094BDA59C2FD24140EEB089CC5C2E4C40950C0055DCCE4140EEB089CC5C2E4C40
71819	397	37.733364999999999	37.745798000000001	55.588653999999998	55.582808	Каширское шоссе	0103000020E61000000100000005000000F98381E7DEDD424070ECD97399CA4B40F98381E7DEDD42406D54A70359CB4B400BB6114F76DF42406D54A70359CB4B400BB6114F76DF424070ECD97399CA4B40F98381E7DEDD424070ECD97399CA4B40
80497	2202	37.337612	37.356558	55.608266999999998	55.596203000000003	микрорайон №1	0103000020E610000001000000050000005B5EB9DE36AB42407863416150CC4B405B5EB9DE36AB4240361E6CB1DBCD4B4047904AB1A3AD4240361E6CB1DBCD4B4047904AB1A3AD42407863416150CC4B405B5EB9DE36AB42407863416150CC4B40
72029	28351	37.843786000000001	37.881731000000002	55.568863	55.555387000000003	Революционная	0103000020E610000001000000050000004D69FD2D01EC4240D1CFD4EB16C74B404D69FD2D01EC4240C573B680D0C84B40486FB88FDCF04240C573B680D0C84B40486FB88FDCF04240D1CFD4EB16C74B404D69FD2D01EC4240D1CFD4EB16C74B40
80915	27898	37.311579000000002	37.334082000000002	55.651668999999998	55.646289000000003	Погодина	0103000020E61000000100000005000000698F17D2E1A74240DD611399B9D24B40698F17D2E1A742409468C9E369D34B405517F032C3AA42409468C9E369D34B405517F032C3AA4240DD611399B9D24B40698F17D2E1A74240DD611399B9D24B40
80762	61978	37.746445000000001	37.766387000000002	55.517831999999999	55.498632000000001	Полковникова	0103000020E61000000100000005000000A1A17F828BDF42409A5E622CD3BF4B40A1A17F828BDF42404069A85148C24B402F8A1EF818E242404069A85148C24B402F8A1EF818E242409A5E622CD3BF4B40A1A17F828BDF42409A5E622CD3BF4B40
80401	24806	37.944119000000001	37.946427999999997	55.504582999999997	55.502068999999999	Текстильная	0103000020E61000000100000005000000204432E4D8F84240EFAA07CC43C04B40204432E4D8F842400C8FFD2C96C04B4064027E8D24F942400C8FFD2C96C04B4064027E8D24F94240EFAA07CC43C04B40204432E4D8F84240EFAA07CC43C04B40
7079	5502	37.693030999999998	37.727221	55.552928000000001	55.543053	проспект Ленинского Комсомола	0103000020E610000001000000050000009D0E643DB5D84240527FBDC282C54B409D0E643DB5D8424077853E58C6C64B4072FBE59315DD424077853E58C6C64B4072FBE59315DD4240527FBDC282C54B409D0E643DB5D84240527FBDC282C54B40
80755	5502	37.644117999999999	37.777329000000002	55.573540999999999	55.528345000000002	площадь Вокзальная	0103000020E61000000100000005000000E961687572D24240A80018CFA0C34B40E961687572D2424023F59ECA69C94B40BF9D44847FE3424023F59ECA69C94B40BF9D44847FE34240A80018CFA0C34B40E961687572D24240A80018CFA0C34B40
3407	5502	37.684559999999998	37.715434999999999	55.558875	55.552163999999998	Школьная улица	0103000020E610000001000000050000002B137EA99FD74240A703594FADC64B402B137EA99FD74240A8C64B3789C74B40F6B4C35F93DB4240A8C64B3789C74B40F6B4C35F93DB4240A703594FADC64B402B137EA99FD74240A703594FADC64B40
80259	5502	37.684559999999998	37.715434999999999	55.558875	55.552163999999998	Школьная	0103000020E610000001000000050000002B137EA99FD74240A703594FADC64B402B137EA99FD74240A8C64B3789C74B40F6B4C35F93DB4240A8C64B3789C74B40F6B4C35F93DB4240A703594FADC64B402B137EA99FD74240A703594FADC64B40
1508	5502	37.697899999999997	37.715775999999998	55.553936	55.549027000000002	Советская улица	0103000020E610000001000000050000006FF085C954D942407DCF488446C64B406FF085C954D94240DD09F65FE7C64B407FA1478C9EDB4240DD09F65FE7C64B407FA1478C9EDB42407DCF488446C64B406FF085C954D942407DCF488446C64B40
80315	5502	37.697899999999997	37.715775999999998	55.553936	55.549027000000002	Советская 	0103000020E610000001000000050000006FF085C954D942407DCF488446C64B406FF085C954D94240DD09F65FE7C64B407FA1478C9EDB4240DD09F65FE7C64B407FA1478C9EDB42407DCF488446C64B406FF085C954D942407DCF488446C64B40
80233	5502	37.697899999999997	37.715775999999998	55.553936	55.549027000000002	Советская	0103000020E610000001000000050000006FF085C954D942407DCF488446C64B406FF085C954D94240DD09F65FE7C64B407FA1478C9EDB4240DD09F65FE7C64B407FA1478C9EDB42407DCF488446C64B406FF085C954D942407DCF488446C64B40
16258	5502	37.662039	37.662461	55.544117	55.537999999999997	Петровский проезд	0103000020E6100000010000000500000099D6A6B1BDD44240BE9F1A2FDDC44B4099D6A6B1BDD442404C1938A0A5C54B400FF0A485CBD442404C1938A0A5C54B400FF0A485CBD44240BE9F1A2FDDC44B4099D6A6B1BDD44240BE9F1A2FDDC44B40
79872	5502	37.645591000000003	37.668138999999996	55.543073	55.542701000000001	Ольгинская	0103000020E61000000100000005000000C5CBD3B9A2D24240D540F33977C54B40C5CBD3B9A2D24240992B836A83C54B405017299485D54240992B836A83C54B405017299485D54240D540F33977C54B40C5CBD3B9A2D24240D540F33977C54B40
5718	5502	37.706020000000002	37.707988	55.558976999999999	55.556685999999999	Клубный переулок	0103000020E61000000100000005000000352905DD5EDA42400E12A27C41C74B40352905DD5EDA4240AC1BEF8E8CC74B40F0FACC599FDA4240AC1BEF8E8CC74B40F0FACC599FDA42400E12A27C41C74B40352905DD5EDA42400E12A27C41C74B40
7095	5502	37.713574999999999	37.716234	55.548411000000002	55.542523000000003	Жуковский проезд	0103000020E61000000100000005000000211FF46C56DB4240F629C76471C54B40211FF46C56DB424022E2E65432C64B404224438EADDB424022E2E65432C64B404224438EADDB4240F629C76471C54B40211FF46C56DB4240F629C76471C54B40
6534	25032	37.178063000000002	37.180587000000003	55.858685000000001	55.856937000000002	улица Кирова	0103000020E6100000010000000500000057D0B4C4CA964240BEDD921CB0ED4B4057D0B4C4CA9642406B48DC63E9ED4B40988A8D791D9742406B48DC63E9ED4B40988A8D791D974240BEDD921CB0ED4B4057D0B4C4CA964240BEDD921CB0ED4B40
80309	25032	37.136785000000003	37.14734	55.842149999999997	55.840204	Школьная	0103000020E61000000100000005000000ACCABE2B82914240F4FBFECD8BEB4B40ACCABE2B82914240C7293A92CBEB4B4042B28009DC924240C7293A92CBEB4B4042B28009DC924240F4FBFECD8BEB4B40ACCABE2B82914240F4FBFECD8BEB4B40
6762	25032	37.184522000000001	37.20035	55.849978999999998	55.844814	Советская улица	0103000020E610000001000000050000003EB2B96A9E974240FA997ADD22EC4B403EB2B96A9E974240B5A4A31CCCEC4B4076E09C11A5994240B5A4A31CCCEC4B4076E09C11A5994240FA997ADD22EC4B403EB2B96A9E974240FA997ADD22EC4B40
80581	25032	37.171056	37.184522000000001	55.851374	55.845365000000001	Красноармейская 	0103000020E610000001000000050000006DE4BA29E59542406E179AEB34EC4B406DE4BA29E59542401555BFD2F9EC4B403EB2B96A9E9742401555BFD2F9EC4B403EB2B96A9E9742406E179AEB34EC4B406DE4BA29E59542406E179AEB34EC4B40
80120	25032	37.166178000000002	37.186570000000003	55.840947	55.838824000000002	Институтская	0103000020E6100000010000000500000048A8195245954240CA8CB7955EEB4B4048A8195245954240AC55BB26A4EB4B4016359886E1974240AC55BB26A4EB4B4016359886E1974240CA8CB7955EEB4B4048A8195245954240CA8CB7955EEB4B40
6484	1264	37.292194000000002	37.323059999999998	55.836756999999999	55.819287000000003	улица Ленина	0103000020E61000000100000005000000310BED9C66A54240DC847B65DEE84B40310BED9C66A542407BD976DA1AEB4B40A852B3075AA942407BD976DA1AEB4B40A852B3075AA94240DC847B65DEE84B40310BED9C66A54240DC847B65DEE84B40
15745	1264	37.23516	37.243288999999997	55.831772000000001	55.830624	улица Геологов	0103000020E61000000100000005000000E7A90EB9199E4240E8A221E351EA4B40E7A90EB9199E424040DD408177EA4B40FF3C0D18249F424040DD408177EA4B40FF3C0D18249F4240E8A221E351EA4B40E7A90EB9199E4240E8A221E351EA4B40
80303	1264	37.328800000000001	37.338141999999998	55.817996999999998	55.816333	Чайковского	0103000020E6100000010000000500000060764F1E16AA4240A2D288997DE84B4060764F1E16AA4240F19C2D20B4E84B40B7B3AF3C48AB4240F19C2D20B4E84B40B7B3AF3C48AB4240A2D288997DE84B4060764F1E16AA4240A2D288997DE84B40
80288	1264	37.291789000000001	37.298319999999997	55.836523999999997	55.827357999999997	Успенская 	0103000020E61000000100000005000000912A8A5759A54240BF0AF0DDE6E94B40912A8A5759A54240D828EB3713EB4B4011DF89592FA64240D828EB3713EB4B4011DF89592FA64240BF0AF0DDE6E94B40912A8A5759A54240BF0AF0DDE6E94B40
79917	1264	37.328691999999997	37.334809999999997	55.829723999999999	55.821531999999998	Пионерская	0103000020E61000000100000005000000793A579412AA4240094FE8F527E94B40793A579412AA4240685A626534EA4B40D72FD80DDBAA4240685A626534EA4B40D72FD80DDBAA4240094FE8F527E94B40793A579412AA4240094FE8F527E94B40
80305	1264	37.255595999999997	37.257095999999997	55.827286999999998	55.825339999999997	Первомайская	0103000020E61000000100000005000000847EA65EB7A04240520ABABDA4E94B40847EA65EB7A04240F6B3588AE4E94B4059F78F85E8A04240F6B3588AE4E94B4059F78F85E8A04240520ABABDA4E94B40847EA65EB7A04240520ABABDA4E94B40
80275	1264	37.254868999999999	37.270032	55.825639000000002	55.821573000000001	Мира	0103000020E61000000100000005000000D2E1218C9FA042406823D74D29E94B40D2E1218C9FA04240ADA6EB89AEE94B40CE6F986890A24240ADA6EB89AEE94B40CE6F986890A242406823D74D29E94B40D2E1218C9FA042406823D74D29E94B40
80279	1264	37.292194000000002	37.323059999999998	55.836756999999999	55.819287000000003	Ленина	0103000020E61000000100000005000000310BED9C66A54240DC847B65DEE84B40310BED9C66A542407BD976DA1AEB4B40A852B3075AA942407BD976DA1AEB4B40A852B3075AA94240DC847B65DEE84B40310BED9C66A54240DC847B65DEE84B40
79909	1264	37.309792000000002	37.323014999999998	55.819287000000003	55.816929999999999	Комсомольская	0103000020E61000000100000005000000FE47A643A7A74240868F882991E84B40FE47A643A7A74240DC847B65DEE84B40088F368E58A94240DC847B65DEE84B40088F368E58A94240868F882991E84B40FE47A643A7A74240868F882991E84B40
80278	1264	37.292220999999998	37.308534000000002	55.840117999999997	55.833976	Карбышева	0103000020E610000001000000050000002A1A6B7F67A542400FD3BEB9BFEA4B402A1A6B7F67A54240F56393FC88EB4B401FDAC70A7EA74240F56393FC88EB4B401FDAC70A7EA742400FD3BEB9BFEA4B402A1A6B7F67A542400FD3BEB9BFEA4B40
71821	1264	37.365855000000003	37.374650000000003	55.824506	55.820652000000003	Игната Титова	0103000020E61000000100000005000000FF092E56D4AE4240D1B2EE1F0BE94B40FF092E56D4AE42408AADA06989E94B4024B9FC87F4AF42408AADA06989E94B4024B9FC87F4AF4240D1B2EE1F0BE94B40FF092E56D4AE4240D1B2EE1F0BE94B40
71796	1264	37.365855000000003	37.374650000000003	55.824506	55.820652000000003	Игната Титова	0103000020E61000000100000005000000FF092E56D4AE4240D1B2EE1F0BE94B40FF092E56D4AE42408AADA06989E94B4024B9FC87F4AF42408AADA06989E94B4024B9FC87F4AF4240D1B2EE1F0BE94B40FF092E56D4AE4240D1B2EE1F0BE94B40
79908	1264	37.334961999999997	37.351545000000002	55.816369000000002	55.810284000000003	Вокзальная	0103000020E610000001000000050000008DB3E908E0AA42406D3CD862B7E74B408DB3E908E0AA4240EF3B86C77EE84B404209336DFFAC4240EF3B86C77EE84B404209336DFFAC42406D3CD862B7E74B408DB3E908E0AA42406D3CD862B7E74B40
80927	25932	37.166915000000003	37.191169000000002	55.896245999999998	55.886477999999997	Центральная	0103000020E610000001000000050000001E1B81785D954240CE4F711C78F14B401E1B81785D954240DD955D30B8F24B402881CD3978984240DD955D30B8F24B402881CD3978984240CE4F711C78F14B401E1B81785D954240CE4F711C78F14B40
80877	62014	37.106628999999998	37.132517999999997	55.759217999999997	55.743831	Центральная	0103000020E6100000010000000500000010E7E104A68D42402060ADDA35DF4B4010E7E104A68D42406B44300E2EE14B40CF108E59F69042406B44300E2EE14B40CF108E59F69042402060ADDA35DF4B4010E7E104A68D42402060ADDA35DF4B40
81025	25704	37.306638	37.307465000000001	55.801904999999998	55.799405999999998	Центральная	0103000020E61000000100000005000000FDDAFAE93FA74240F31C91EF52E64B40FDDAFAE93FA74240DBBFB2D2A4E64B4013D55B035BA74240DBBFB2D2A4E64B4013D55B035BA74240F31C91EF52E64B40FDDAFAE93FA74240F31C91EF52E64B40
74294	60286	36.862862	36.888482000000003	56.480733000000001	56.466748000000003	Центральная	0103000020E61000000100000005000000077B1343726E424099BC0166BE3B4C40077B1343726E4240D28DB0A8883D4C40D78A36C7B9714240D28DB0A8883D4C40D78A36C7B971424099BC0166BE3B4C40077B1343726E424099BC0166BE3B4C40
72017	15906	36.545746999999999	36.574314000000001	56.459322999999998	56.431494999999998	Лесная	0103000020E61000000100000005000000EF71A609DB4542409AB1683A3B374C40EF71A609DB4542407AA69718CB3A4C4046D1031F834942407AA69718CB3A4C4046D1031F834942409AB1683A3B374C40EF71A609DB4542409AB1683A3B374C40
80935	15454	36.774369	36.849970999999996	56.248125999999999	56.215673000000002	Покровская	0103000020E61000000100000005000000A304FD851E634240ABD0402C9B1B4C40A304FD851E634240C6A4BF97C21F4C4032C687D9CB6C4240C6A4BF97C21F4C4032C687D9CB6C4240ABD0402C9B1B4C40A304FD851E634240ABD0402C9B1B4C40
74099	16590	36.461511999999999	36.481338000000001	56.259193000000003	56.253481999999998	Центральная	0103000020E61000000100000005000000145B41D3123B4240F50F221972204C40145B41D3123B4240132D793C2D214C403929CC7B9C3D4240132D793C2D214C403929CC7B9C3D4240F50F221972204C40145B41D3123B4240F50F221972204C40
67029	16417	36.490366000000002	36.513615000000001	56.098733000000003	56.083053999999997	Советская	0103000020E6100000010000000500000001892650C43E4240A7E67283A10A4C4001892650C43E42409B046F48A30C4C4016DEE522BE4142409B046F48A30C4C4016DEE522BE414240A7E67283A10A4C4001892650C43E4240A7E67283A10A4C40
71899	16249	36.790439999999997	36.807839999999999	56.376340999999996	56.367466999999998	Центральная	0103000020E61000000100000005000000A1B94E232D654240FBAD9D28092F4C40A1B94E232D6542406C921FF12B304C404833164D676742406C921FF12B304C404833164D67674240FBAD9D28092F4C40A1B94E232D654240FBAD9D28092F4C40
71882	16498	36.505251000000001	36.521762000000003	56.111739999999998	56.101754999999997	Королева	0103000020E61000000100000005000000BAA29410AC4042402C9ACE4E060D4C40BAA29410AC404240D8D30E7F4D0E4C40D525E318C9424240D8D30E7F4D0E4C40D525E318C94242402C9ACE4E060D4C40BAA29410AC4042402C9ACE4E060D4C40
5905	776	36.690052999999999	36.715330999999999	56.363967000000002	56.339517000000001	улица Терешковой	0103000020E61000000100000005000000DBC01DA853584240D0B7054B752B4C40DBC01DA85358424060E97C78962E4C40516859F78F5B424060E97C78962E4C40516859F78F5B4240D0B7054B752B4C40DBC01DA853584240D0B7054B752B4C40
3901	776	36.673667999999999	36.691104000000003	56.369396999999999	56.363931999999998	улица Мичурина	0103000020E610000001000000050000004D2EC6C03A564240E3FBE252952E4C404D2EC6C03A564240C91EA166482F4C4041118B1876584240C91EA166482F4C4041118B1876584240E3FBE252952E4C404D2EC6C03A564240E3FBE252952E4C40
319	776	36.724727999999999	36.735930000000003	56.329687	56.321511000000001	улица Мира	0103000020E610000001000000050000006C3F19E3C35C4240F226BF4527294C406C3F19E3C35C42404B75012F332A4C40991249F4325E42404B75012F332A4C40991249F4325E4240F226BF4527294C406C3F19E3C35C4240F226BF4527294C40
3833	776	36.722068999999998	36.732759000000001	56.337836000000003	56.333914	улица Ленина	0103000020E610000001000000050000004B3ACAC16C5C424099D6A6B1BD2A4C404B3ACAC16C5C4240ABB4C5353E2B4C40C26C020CCB5D4240ABB4C5353E2B4C40C26C020CCB5D424099D6A6B1BD2A4C404B3ACAC16C5C424099D6A6B1BD2A4C40
4091	776	36.712950999999997	36.732444000000001	56.333305000000003	56.318516000000002	улица Карла Маркса	0103000020E61000000100000005000000435376FA415B42405AA0DD21C5284C40435376FA415B4240F14BFDBCA92A4C40621399B9C05D4240F14BFDBCA92A4C40621399B9C05D42405AA0DD21C5284C40435376FA415B42405AA0DD21C5284C40
4165	776	36.719696999999996	36.735256	56.335464999999999	56.323518	улица Гагарина	0103000020E61000000100000005000000C00303081F5C42406BD5AE0969294C40C00303081F5C4240F0F96184F02A4C4009185DDE1C5E4240F0F96184F02A4C4009185DDE1C5E42406BD5AE0969294C40C00303081F5C42406BD5AE0969294C40
4069	776	36.753796999999999	36.760714	56.318755000000003	56.314442	улица 60 лет Комсомола	0103000020E6100000010000000500000055698B6B7C604240923EADA23F284C4055698B6B7C604240DF37BEF6CC284C40FFCD8B135F614240DF37BEF6CC284C40FFCD8B135F614240923EADA23F284C4055698B6B7C604240923EADA23F284C40
79895	776	36.735256	36.766292999999997	56.335464999999999	56.317093	Чайковского	0103000020E6100000010000000500000009185DDE1C5E42403065E08096284C4009185DDE1C5E4240F0F96184F02A4C40AD1397E315624240F0F96184F02A4C40AD1397E3156242403065E08096284C4009185DDE1C5E42403065E08096284C40
4025	776	36.749701000000002	36.766948999999997	56.337899999999998	56.336348999999998	Талицкий проезд	0103000020E61000000100000005000000A663CE33F65F42406A85E97B0D2B4C40A663CE33F65F4240C1A8A44E402B4C40965984622B624240C1A8A44E402B4C40965984622B6242406A85E97B0D2B4C40A663CE33F65F42406A85E97B0D2B4C40
80150	776	36.730953	36.752827000000003	56.330440000000003	56.326222999999999	Спортивная	0103000020E61000000100000005000000E0F42EDE8F5D4240FC19DEACC1294C40E0F42EDE8F5D424027A5A0DB4B2A4C40DD4598A25C60424027A5A0DB4B2A4C40DD4598A25C604240FC19DEACC1294C40E0F42EDE8F5D4240FC19DEACC1294C40
80890	776	36.741427000000002	36.758487000000002	56.335635000000003	56.333503999999998	Сестрорецкая	0103000020E610000001000000050000008AAF7614E75E4240E78A5242B02A4C408AAF7614E75E42404D327216F62A4C4078B81D1A166142404D327216F62A4C4078B81D1A16614240E78A5242B02A4C408AAF7614E75E4240E78A5242B02A4C40
3954	776	36.743907	36.746898000000002	56.343603000000002	56.34254	Пролетарский проезд	0103000020E61000000100000005000000FB213658385F424032C9C859D82B4C40FB213658385F42405CE7DF2EFB2B4C4052B9895A9A5F42405CE7DF2EFB2B4C4052B9895A9A5F424032C9C859D82B4C40FB213658385F424032C9C859D82B4C40
4219	776	36.690142999999999	36.718007999999998	56.327070999999997	56.311486000000002	Московская улица	0103000020E610000001000000050000001B48179B56584240B894F3C5DE274C401B48179B56584240293C6876DD294C401822A7AFE75B4240293C6876DD294C401822A7AFE75B4240B894F3C5DE274C401B48179B56584240B894F3C5DE274C40
80201	776	36.673667999999999	36.691104000000003	56.369396999999999	56.363931999999998	Мичурина	0103000020E610000001000000050000004D2EC6C03A564240E3FBE252952E4C404D2EC6C03A564240C91EA166482F4C4041118B1876584240C91EA166482F4C4041118B1876584240E3FBE252952E4C404D2EC6C03A564240E3FBE252952E4C40
79887	776	36.729354000000001	36.730854000000001	56.330329999999996	56.327230999999998	Захватаева	0103000020E61000000100000005000000789ACC785B5D4240629E95B4E2294C40789ACC785B5D42409F71E140482A4C404D13B69F8C5D42409F71E140482A4C404D13B69F8C5D4240629E95B4E2294C40789ACC785B5D4240629E95B4E2294C40
79961	776	36.715978	36.717739000000002	56.325888999999997	56.325504000000002	Загородная	0103000020E61000000100000005000000E753C72AA55B4240CD5B751DAA294C40E753C72AA55B4240259012BBB6294C4029081EDFDE5B4240259012BBB6294C4029081EDFDE5B4240CD5B751DAA294C40E753C72AA55B4240CD5B751DAA294C40
80107	776	36.719696999999996	36.735256	56.335464999999999	56.323518	Гагарина	0103000020E61000000100000005000000C00303081F5C42406BD5AE0969294C40C00303081F5C4240F0F96184F02A4C4009185DDE1C5E4240F0F96184F02A4C4009185DDE1C5E42406BD5AE0969294C40C00303081F5C42406BD5AE0969294C40
4230	776	36.678635	36.706887000000002	56.328803000000001	56.326692000000001	Волоколамское шоссе	0103000020E61000000100000005000000E275FD82DD564240B3EE1F0BD1294C40E275FD82DD564240D1E97937162A4C40D97BF1457B5A4240D1E97937162A4C40D97BF1457B5A4240B3EE1F0BD1294C40E275FD82DD564240B3EE1F0BD1294C40
4121	776	36.723219	36.730018999999999	56.325493999999999	56.319299999999998	Бородинский проезд	0103000020E61000000100000005000000446CB070925C424070CE88D2DE284C40446CB070925C4240A98592C9A9294C40B43A3943715D4240A98592C9A9294C40B43A3943715D424070CE88D2DE284C40446CB070925C424070CE88D2DE284C40
74123	776	36.724162	36.732371999999998	56.319744	56.315181000000003	50 лет Октября	0103000020E61000000100000005000000C3802557B15C424009A9DBD957284C40C3802557B15C4240CE8B135FED284C40C8409E5DBE5D4240CE8B135FED284C40C8409E5DBE5D424009A9DBD957284C40C3802557B15C424009A9DBD957284C40
79867	776	36.717298999999997	36.723219	56.334173	56.325305	 Дзержинского	0103000020E610000001000000050000000C3A2174D05B4240D61C2098A3294C400C3A2174D05B4240651A4D2EC62A4C40446CB070925C4240651A4D2EC62A4C40446CB070925C4240D61C2098A3294C400C3A2174D05B4240D61C2098A3294C40
81038	15606	36.809798000000001	36.833945	56.290903999999998	56.275393999999999	24а	0103000020E61000000100000005000000E02EFB75A7674240DFC14F1C40234C40E02EFB75A767424046239F573C254C40D4D4B2B5BE6A424046239F573C254C40D4D4B2B5BE6A4240DFC14F1C40234C40E02EFB75A7674240DFC14F1C40234C40
4673	16720	36.546286000000002	36.552771999999997	56.327295999999997	56.325004999999997	Текстильная улица	0103000020E610000001000000050000009F211CB3EC454240AB048BC399294C409F211CB3EC454240490ED8D5E4294C407F129F3BC1464240490ED8D5E4294C407F129F3BC1464240AB048BC399294C409F211CB3EC454240AB048BC399294C40
4656	16720	36.552593000000002	36.557955999999997	56.322119999999998	56.317551999999999	Первомайская улица	0103000020E61000000100000005000000D07F0F5EBB464240C3633F8BA5284C40D07F0F5EBB4642409AB1683A3B294C40B14D2A1A6B4742409AB1683A3B294C40B14D2A1A6B474240C3633F8BA5284C40D07F0F5EBB464240C3633F8BA5284C40
81063	16720	36.552593000000002	36.557955999999997	56.322119999999998	56.317551999999999	Первомайская	0103000020E61000000100000005000000D07F0F5EBB464240C3633F8BA5284C40D07F0F5EBB4642409AB1683A3B294C40B14D2A1A6B4742409AB1683A3B294C40B14D2A1A6B474240C3633F8BA5284C40D07F0F5EBB464240C3633F8BA5284C40
80198	16720	36.543824999999998	36.555979000000001	56.326058000000003	56.316853000000002	Ленина	0103000020E61000000100000005000000A4DFBE0E9C454240DB519CA38E284C40A4DFBE0E9C454240B24CBF44BC294C40A321E3512A474240B24CBF44BC294C40A321E3512A474240DB519CA38E284C40A4DFBE0E9C454240DB519CA38E284C40
80892	16720	36.544705	36.568268000000003	56.319713999999998	56.306618	Курятникова	0103000020E61000000100000005000000DD7BB8E4B8454240B62E35423F274C40DD7BB8E4B845424063096B63EC284C4082AE7D01BD48424063096B63EC284C4082AE7D01BD484240B62E35423F274C40DD7BB8E4B8454240B62E35423F274C40
80922	12844	38.255941999999997	38.278920999999997	54.755487000000002	54.741394999999997	Клубная	0103000020E610000001000000050000001FD61BB5C22043407E350708E65E4B401FD61BB5C2204340CEC64ACCB3604B407495EEAEB3234340CEC64ACCB3604B407495EEAEB32343407E350708E65E4B401FD61BB5C22043407E350708E65E4B40
80812	12926	38.468483999999997	38.493150999999997	54.721249999999998	54.708590999999998	Новая	0103000020E610000001000000050000008159A148F73B4340B69E211CB35A4B408159A148F73B4340B81E85EB515C4B40AE7E6C921F3F4340B81E85EB515C4B40AE7E6C921F3F4340B69E211CB35A4B408159A148F73B4340B69E211CB35A4B40
71883	46247	37.995097999999999	38.043320000000001	54.822935999999999	54.803528	Комсомольская	0103000020E6100000010000000500000052280B5F5FFF4240CCB56801DA664B4052280B5F5FFF4240BC5983F755694B40A1A17F828B054340BC5983F755694B40A1A17F828B054340CCB56801DA664B4052280B5F5FFF4240CCB56801DA664B40
746	2897	38.265509000000002	38.266587000000001	54.798909000000002	54.796090999999997	Строительная улица	0103000020E6100000010000000500000097E5EB32FC214340E9D1544FE6654B4097E5EB32FC21434073BD6DA642664B40F644D7851F22434073BD6DA642664B40F644D7851F224340E9D1544FE6654B4097E5EB32FC214340E9D1544FE6654B40
80252	2897	38.266246000000002	38.267862999999998	54.796090999999997	54.790427999999999	Советская	0103000020E610000001000000050000006D58535914224340DDEBA4BE2C654B406D58535914224340E9D1544FE6654B407B67B45549224340E9D1544FE6654B407B67B45549224340DDEBA4BE2C654B406D58535914224340DDEBA4BE2C654B40
1288	2897	38.276162999999997	38.279513999999999	54.801181999999997	54.795597999999998	Заводская улица	0103000020E61000000100000005000000C0AE264F59234340AA61BF27D6654B40C0AE264F592343406A12BC218D664B401763601DC72343406A12BC218D664B401763601DC7234340AA61BF27D6654B40C0AE264F59234340AA61BF27D6654B40
80834	2897	38.278911999999998	38.287123000000001	54.808618000000003	54.803874999999998	1 Мая	0103000020E61000000100000005000000213B6F63B323434037894160E5664B40213B6F63B32343407D7A6CCB80674B40F7764B72C02443407D7A6CCB80674B40F7764B72C024434037894160E5664B40213B6F63B323434037894160E5664B40
68090	46121	38.270127000000002	38.301423999999997	54.839474000000003	54.819507999999999	Центральная	0103000020E610000001000000050000002062838593224340BA675DA3E5684B402062838593224340D1EB4FE2736B4B40601DC70F95264340D1EB4FE2736B4B40601DC70F95264340BA675DA3E5684B402062838593224340BA675DA3E5684B40
80976	46446	38.474097999999998	38.489100000000001	54.743515000000002	54.734991000000001	Фабричная	0103000020E61000000100000005000000AC8C463EAF3C43405BED612F145E4B40AC8C463EAF3C4340F08AE07F2B5F4B409F3C2CD49A3E4340F08AE07F2B5F4B409F3C2CD49A3E43405BED612F145E4B40AC8C463EAF3C43405BED612F145E4B40
80933	12682	38.099797000000002	38.124491999999996	54.820976000000002	54.810268000000001	Иваньковское шоссе	0103000020E61000000100000005000000959EE925C60C4340677FA0DCB6674B40959EE925C60C43408466D7BD15694B408B4E965AEF0F43408466D7BD15694B408B4E965AEF0F4340677FA0DCB6674B40959EE925C60C4340677FA0DCB6674B40
71837	59526	38.388964999999999	38.409356000000002	54.757289999999998	54.740349999999999	Стадионная	0103000020E61000000100000005000000F224E99AC9314340FBCBEEC9C35E4B40F224E99AC93143403ECBF3E0EE604B40F03504C7653443403ECBF3E0EE604B40F03504C765344340FBCBEEC9C35E4B40F224E99AC9314340FBCBEEC9C35E4B40
80924	12586	38.082692999999999	38.129432000000001	54.810355999999999	54.794263999999998	Центральная	0103000020E61000000100000005000000D74D29AF950A4340F0315871AA654B40D74D29AF950A4340060FD3BEB9674B4027874F3A91104340060FD3BEB9674B4027874F3A91104340F0315871AA654B40D74D29AF950A4340F0315871AA654B40
80774	12446	38.192314000000003	38.226773999999999	54.772368999999998	54.757820000000002	Садовая	0103000020E610000001000000050000000F48C2BE9D1843409B20EA3E00614B400F48C2BE9D184340DCB8C5FCDC624B40A3CA30EE061D4340DCB8C5FCDC624B40A3CA30EE061D43409B20EA3E00614B400F48C2BE9D1843409B20EA3E00614B40
3420	10588	38.187814000000003	38.196841999999997	54.839441999999998	54.837431000000002	улица Победы	0103000020E6100000010000000500000090DD054A0A1843400BD462F0306B4B4090DD054A0A184340C571E0D5726B4B40573D601E32194340C571E0D5726B4B40573D601E321943400BD462F0306B4B4090DD054A0A1843400BD462F0306B4B40
3378	10588	38.156984000000001	38.169578000000001	54.838608000000001	54.834947	улица Моргунова	0103000020E6100000010000000500000065FF3C0D181443405872158BDF6A4B4065FF3C0D18144340FD14C781576B4B40800F5EBBB4154340FD14C781576B4B40800F5EBBB41543405872158BDF6A4B4065FF3C0D181443405872158BDF6A4B40
80861	10588	38.174636	38.182288999999997	54.843133999999999	54.842475	Школьная	0103000020E61000000100000005000000255AF2785A1643404B598638D66B4B40255AF2785A164340A5129ED0EB6B4B40D4B5F63E55174340A5129ED0EB6B4B40D4B5F63E551743404B598638D66B4B40255AF2785A1643404B598638D66B4B40
7646	10588	38.238568999999998	38.251809999999999	54.843325999999998	54.842194999999997	Центральная улица	0103000020E61000000100000005000000726BD26D891E434067EDB60BCD6B4B40726BD26D891E4340E9EE3A1BF26B4B402367614F3B204340E9EE3A1BF26B4B402367614F3B20434067EDB60BCD6B4B40726BD26D891E434067EDB60BCD6B4B40
3342	10588	38.146545000000003	38.152186999999998	54.831898000000002	54.819881000000002	Стрелецкая улица	0103000020E6100000010000000500000038328FFCC11243404FCE50DCF1684B4038328FFCC1124340CDCD37A27B6A4B402CF015DD7A134340CDCD37A27B6A4B402CF015DD7A1343404FCE50DCF1684B4038328FFCC11243404FCE50DCF1684B40
80168	10588	38.150596999999998	38.153067	54.843974000000003	54.831898000000002	Советская	0103000020E6100000010000000500000017F032C346134340CDCD37A27B6A4B4017F032C34613434050560C57076C4B40658C0FB39713434050560C57076C4B40658C0FB397134340CDCD37A27B6A4B4017F032C346134340CDCD37A27B6A4B40
7811	10588	38.244354000000001	38.247138999999997	54.852376	54.837820000000001	Садовая улица	0103000020E61000000100000005000000CA52EBFD461F4340A5F78DAF3D6B4B40CA52EBFD461F434099F221A81A6D4B4077483140A21F434099F221A81A6D4B4077483140A21F4340A5F78DAF3D6B4B40CA52EBFD461F4340A5F78DAF3D6B4B40
80045	10588	38.187814000000003	38.196841999999997	54.839441999999998	54.837431000000002	Победы	0103000020E6100000010000000500000090DD054A0A1843400BD462F0306B4B4090DD054A0A184340C571E0D5726B4B40573D601E32194340C571E0D5726B4B40573D601E321943400BD462F0306B4B4090DD054A0A1843400BD462F0306B4B40
80256	10588	38.241596000000001	38.243051000000001	54.848224000000002	54.842677999999999	Новокаширская	0103000020E61000000100000005000000166C239EEC1E4340838769DFDC6B4B40166C239EEC1E434056D7A19A926C4B404B21904B1C1F434056D7A19A926C4B404B21904B1C1F4340838769DFDC6B4B40166C239EEC1E4340838769DFDC6B4B40
80159	10588	38.238784000000003	38.249780000000001	54.848266000000002	54.847810000000003	Металлистов	0103000020E610000001000000050000006F675F79901E4340639CBF09856C4B406F675F79901E43408527F4FA936C4B40F29881CAF81F43408527F4FA936C4B40F29881CAF81F4340639CBF09856C4B406F675F79901E4340639CBF09856C4B40
80173	10588	38.146402000000002	38.154864000000003	54.832898999999998	54.831898000000002	Маршала Астахова	0103000020E61000000100000005000000D508FD4CBD124340CDCD37A27B6A4B40D508FD4CBD12434080EF366F9C6A4B40F4A96395D213434080EF366F9C6A4B40F4A96395D2134340CDCD37A27B6A4B40D508FD4CBD124340CDCD37A27B6A4B40
80218	10588	38.235666999999999	38.250183999999997	54.852401999999998	54.852049999999998	Клубная	0103000020E610000001000000050000008BDF14562A1E4340454772F90F6D4B408BDF14562A1E4340C2853C821B6D4B40C1FD800706204340C2853C821B6D4B40C1FD800706204340454772F90F6D4B408BDF14562A1E4340454772F90F6D4B40
80177	10588	38.153067	38.201450000000001	54.857683000000002	54.843974000000003	Ильича	0103000020E61000000100000005000000658C0FB39713434050560C57076C4B40658C0FB397134340E7AA798EC86D4B40BDE3141DC9194340E7AA798EC86D4B40BDE3141DC919434050560C57076C4B40658C0FB39713434050560C57076C4B40
72277	12437	38.142772000000001	38.170350999999997	54.814869999999999	54.797086999999998	Октябрьская	0103000020E610000001000000050000006B64575A461243408B8862F206664B406B64575A46124340EA3E00A94D684B40A2EBC20FCE154340EA3E00A94D684B40A2EBC20FCE1543408B8862F206664B406B64575A461243408B8862F206664B40
72010	12371	38.388236999999997	38.427143000000001	54.858739999999997	54.845751999999997	Южная	0103000020E610000001000000050000006F0C01C0B13143406743FE99416C4B406F0C01C0B13143402EE23B31EB6D4B4090DB2F9FAC3643402EE23B31EB6D4B4090DB2F9FAC3643406743FE99416C4B406F0C01C0B13143406743FE99416C4B40
71836	46393	38.511423000000001	38.539566999999998	54.688175000000001	54.675184000000002	Новая	0103000020E610000001000000050000000BB6114F764143402864E76D6C564B400BB6114F7641434060764F1E16584B401B800D881045434060764F1E16584B401B800D88104543402864E76D6C564B400BB6114F764143402864E76D6C564B40
80819	10812	36.924675000000001	36.944222000000003	55.901733	55.885604999999998	Железнодорожная	0103000020E61000000100000005000000E3361AC05B764240481630815BF14B40E3361AC05B764240AB5CA8FC6BF34B40F5143944DC784240AB5CA8FC6BF34B40F5143944DC784240481630815BF14B40E3361AC05B764240481630815BF14B40
74280	60278	37.031053	37.042802999999999	55.881822999999997	55.879959999999997	Станционная	0103000020E61000000100000005000000AAB8718BF9834240E2E47E87A2F04B40AAB8718BF983424028EE7893DFF04B40D99596917A85424028EE7893DFF04B40D99596917A854240E2E47E87A2F04B40AAB8718BF9834240E2E47E87A2F04B40
74283	60280	37.040522000000003	37.067174999999999	55.864035000000001	55.844085999999997	Южная	0103000020E610000001000000050000005F622CD32F854240778192020BEC4B405F622CD32F854240B8CCE9B298EE4B40ED0DBE3099884240B8CCE9B298EE4B40ED0DBE3099884240778192020BEC4B405F622CD32F854240778192020BEC4B40
80741	10780	36.941445999999999	36.963876999999997	55.876899999999999	55.866171999999999	Молодежная	0103000020E610000001000000050000009A79724D81784240FF5A5EB9DEEE4B409A79724D8178424063EE5A423EF04B40EC2E5052607B424063EE5A423EF04B40EC2E5052607B4240FF5A5EB9DEEE4B409A79724D81784240FF5A5EB9DEEE4B40
80158	773	37.090279000000002	37.09451	55.822386999999999	55.814279999999997	Комсомольская	0103000020E61000000100000005000000FF4124438E8B4240B8E4B8533AE84B40FF4124438E8B4240E9D32AFA43E94B408E9257E7188C4240E9D32AFA43E94B408E9257E7188C4240B8E4B8533AE84B40FF4124438E8B4240B8E4B8533AE84B40
80106	773	37.089892999999996	37.091788000000001	55.821931999999997	55.819110000000002	Дзержинского	0103000020E61000000100000005000000D591239D818B4240CDE9B298D8E84B40D591239D818B424097C4591135E94B4027158DB5BF8B424097C4591135E94B4027158DB5BF8B4240CDE9B298D8E84B40D591239D818B4240CDE9B298D8E84B40
80814	11402	36.497427000000002	36.522032000000003	55.857078000000001	55.845303999999999	Центральная	0103000020E61000000100000005000000DE921CB0AB3F4240C896E5EB32EC4B40DE921CB0AB3F4240800F5EBBB4ED4B4095BBCFF1D1424240800F5EBBB4ED4B4095BBCFF1D1424240C896E5EB32EC4B40DE921CB0AB3F4240C896E5EB32EC4B40
80061	11150	36.447704999999999	36.497418000000003	56.005983999999998	55.980291000000001	Северная	0103000020E61000000100000005000000BAA0BE654E39424015C8EC2C7AFD4B40BAA0BE654E3942404E266E15C4004C408B389D64AB3F42404E266E15C4004C408B389D64AB3F424015C8EC2C7AFD4B40BAA0BE654E39424015C8EC2C7AFD4B40
74118	11150	36.447704999999999	36.497418000000003	56.005983999999998	55.980291000000001	Полевая	0103000020E61000000100000005000000BAA0BE654E39424015C8EC2C7AFD4B40BAA0BE654E3942404E266E15C4004C408B389D64AB3F42404E266E15C4004C408B389D64AB3F424015C8EC2C7AFD4B40BAA0BE654E39424015C8EC2C7AFD4B40
81079	40338	36.812007999999999	36.832129999999999	55.914534000000003	55.902706999999999	Железнодорожная	0103000020E61000000100000005000000910BCEE0EF674240656F29E78BF34B40910BCEE0EF674240408A3A730FF54B409F02603C836A4240408A3A730FF54B409F02603C836A4240656F29E78BF34B40910BCEE0EF674240656F29E78BF34B40
71968	10871	36.679758	36.708765	55.897098999999997	55.889836000000003	Центральная	0103000020E61000000100000005000000E198654F02574240D8666325E6F14B40E198654F025742401C23D923D4F24B4054C6BFCFB85A42401C23D923D4F24B4054C6BFCFB85A4240D8666325E6F14B40E198654F02574240D8666325E6F14B40
71816	48961	36.904983999999999	36.924073	55.933624999999999	55.927145000000003	Ленина	0103000020E610000001000000050000009EB30584D673424031D3F6AFACF64B409EB30584D67342402FDD240681F74B40ED0E2906487642402FDD240681F74B40ED0E29064876424031D3F6AFACF64B409EB30584D673424031D3F6AFACF64B40
2657	9201	36.873066999999999	36.876328000000001	55.928355000000003	55.915452000000002	улица Кирова	0103000020E61000000100000005000000C11BD2A8C06F42406687F8872DF54B40C11BD2A8C06F4240FF092E56D4F64B40D84812842B704240FF092E56D4F64B40D84812842B7042406687F8872DF54B40C11BD2A8C06F42406687F8872DF54B40
80099	9201	36.858721000000003	36.873435000000001	55.910513000000002	55.903619999999997	Юбилейная	0103000020E61000000100000005000000B8B1D991EA6D42407901F6D1A9F34B40B8B1D991EA6D42409BCAA2B08BF44B404417D4B7CC6F42409BCAA2B08BF44B404417D4B7CC6F42407901F6D1A9F34B40B8B1D991EA6D42407901F6D1A9F34B40
16873	9201	36.840763000000003	36.888157999999997	55.925995	55.915649000000002	Советская улица	0103000020E61000000100000005000000EB573A1F9E6B4240BCCE86FC33F54B40EB573A1F9E6B424038A1100187F64B4023D74D29AF71424038A1100187F64B4023D74D29AF714240BCCE86FC33F54B40EB573A1F9E6B4240BCCE86FC33F54B40
80398	9201	36.857804000000002	36.859600999999998	55.920295000000003	55.914085	Первомайская 	0103000020E6100000010000000500000062307F85CC6D4240D061BEBC00F54B4062307F85CC6D42400FD6FF39CCF54B40F04DD367076E42400FD6FF39CCF54B40F04DD367076E4240D061BEBC00F54B4062307F85CC6D4240D061BEBC00F54B40
80154	9201	36.858110000000003	36.864524000000003	55.925006000000003	55.893793000000002	Ленина	0103000020E610000001000000050000006F2F698CD66D424066321CCF67F24B406F2F698CD66D4240494DBB9866F64B40B64DF1B8A86E4240494DBB9866F64B40B64DF1B8A86E424066321CCF67F24B406F2F698CD66D424066321CCF67F24B40
80874	9201	36.873066999999999	36.876328000000001	55.928355000000003	55.915452000000002	Кирова	0103000020E61000000100000005000000C11BD2A8C06F42406687F8872DF54B40C11BD2A8C06F4240FF092E56D4F64B40D84812842B704240FF092E56D4F64B40D84812842B7042406687F8872DF54B40C11BD2A8C06F42406687F8872DF54B40
80162	9201	36.864415999999999	36.868206999999998	55.912531000000001	55.907107000000003	Босова	0103000020E61000000100000005000000CF11F92EA56E4240817C09151CF44B40CF11F92EA56E424008CBD8D0CDF44B4042942F68216F424008CBD8D0CDF44B4042942F68216F4240817C09151CF44B40CF11F92EA56E4240817C09151CF44B40
74209	9201	36.859583000000001	36.873497999999998	55.914155999999998	55.910513000000002	9 Гвардейской Дивизии	0103000020E610000001000000050000004A99D4D0066E42409BCAA2B08BF44B404A99D4D0066E424099B8551003F54B408A8F4FC8CE6F424099B8551003F54B408A8F4FC8CE6F42409BCAA2B08BF44B404A99D4D0066E42409BCAA2B08BF44B40
2688	875	37.100161	37.118997999999998	55.874465999999998	55.868904999999998	улица Панфилова	0103000020E61000000100000005000000D6AA5D13D28C42405A2A6F4738EF4B40D6AA5D13D28C424062BB7B80EEEF4B400B2593533B8F424062BB7B80EEEF4B400B2593533B8F42405A2A6F4738EF4B40D6AA5D13D28C42405A2A6F4738EF4B40
2723	875	37.111362999999997	37.127065000000002	55.861412999999999	55.856861000000002	улица Гагарина	0103000020E61000000100000005000000027E8D24418E4240E31B0A9FADED4B40027E8D24418E4240B4ACFBC742EE4B40AEBB79AA43904240B4ACFBC742EE4B40AEBB79AA43904240E31B0A9FADED4B40027E8D24418E4240E31B0A9FADED4B40
224	875	37.111559999999997	37.113652999999999	55.871555999999998	55.868217999999999	улица 9 Мая	0103000020E6100000010000000500000058C51B99478E424036E675C421EF4B4058C51B99478E4240F850A2258FEF4B40D00B772E8C8E4240F850A2258FEF4B40D00B772E8C8E424036E675C421EF4B4058C51B99478E424036E675C421EF4B40
80167	875	37.100619000000002	37.104669999999999	55.873657000000001	55.867258	Энергетиков	0103000020E61000000100000005000000992D5915E18C4240E198654F02EF4B40992D5915E18C4240F37519FED3EF4B40A86F99D3658D4240F37519FED3EF4B40A86F99D3658D4240E198654F02EF4B40992D5915E18C4240E198654F02EF4B40
80054	875	37.103574000000002	37.119554999999998	55.871980999999998	55.864337999999996	Победы	0103000020E61000000100000005000000A35BAFE9418D42405358A9A0A2EE4B40A35BAFE9418D4240DFDDCA129DEF4B40618907944D8F4240DFDDCA129DEF4B40618907944D8F42405358A9A0A2EE4B40A35BAFE9418D42405358A9A0A2EE4B40
80286	875	37.126975000000002	37.135258	55.875112000000001	55.870672999999996	Осипенко	0103000020E610000001000000050000006E3480B7409042404E417E3672EF4B406E3480B740904240282B86AB03F04B40DD42572250914240282B86AB03F04B40DD425722509142404E417E3672EF4B406E3480B7409042404E417E3672EF4B40
80434	875	37.123148999999998	37.126913000000002	55.854864999999997	55.853318999999999	Ленина	0103000020E610000001000000050000007EC4AF58C38F42401807978E39ED4B407EC4AF58C38F42405DBF60376CED4B40F83768AF3E9042405DBF60376CED4B40F83768AF3E9042401807978E39ED4B407EC4AF58C38F42401807978E39ED4B40
79884	875	37.111362999999997	37.127065000000002	55.861412999999999	55.856861000000002	Гагарина	0103000020E61000000100000005000000027E8D24418E4240E31B0A9FADED4B40027E8D24418E4240B4ACFBC742EE4B40AEBB79AA43904240B4ACFBC742EE4B40AEBB79AA43904240E31B0A9FADED4B40027E8D24418E4240E31B0A9FADED4B40
71895	49687	36.678662000000003	36.716625000000001	55.948210000000003	55.929777000000001	Октябрьская	0103000020E61000000100000005000000DC847B65DE56424058C9C7EE02F74B40DC847B65DE564240BEDEFDF15EF94B407D3F355EBA5B4240BEDEFDF15EF94B407D3F355EBA5B424058C9C7EE02F74B40DC847B65DE56424058C9C7EE02F74B40
80918	62021	38.630046	38.652881000000001	54.784607999999999	54.767456000000003	Садовая	0103000020E61000000100000005000000E17CEA58A55043403B8F8AFF3B624B40E17CEA58A55043400917F2086E644B400397C79A915343400917F2086E644B400397C79A915343403B8F8AFF3B624B40E17CEA58A55043403B8F8AFF3B624B40
71818	48652	39.107014999999997	39.137242999999998	54.677422	54.661766	Центральная	0103000020E610000001000000050000003997E2AAB28D434068CD8FBFB4544B403997E2AAB28D4340A3CB9BC3B5564B406E4DBA2D91914340A3CB9BC3B5564B406E4DBA2D9191434068CD8FBFB4544B403997E2AAB28D434068CD8FBFB4544B40
81042	7420	39.002513999999998	39.028044000000001	54.706713999999998	54.694060999999998	Центральная	0103000020E610000001000000050000001DE4F56052804340EB36A8FDD6584B401DE4F560528043400BD0B69A755A4B40AD6C1FF2968343400BD0B69A755A4B40AD6C1FF296834340EB36A8FDD6584B401DE4F56052804340EB36A8FDD6584B40
74095	6754	38.853051999999998	38.908281000000002	54.798473000000001	54.744134000000003	Школьная	0103000020E61000000100000005000000C9E4D4CE306D4340BCEB6CC83F5F4B40C9E4D4CE306D434098DEFE5C34664B40024A438D4274434098DEFE5C34664B40024A438D42744340BCEB6CC83F5F4B40C9E4D4CE306D4340BCEB6CC83F5F4B40
74105	6754	38.853051999999998	38.908281000000002	54.798473000000001	54.744134000000003	Рабочая Слободка	0103000020E61000000100000005000000C9E4D4CE306D4340BCEB6CC83F5F4B40C9E4D4CE306D434098DEFE5C34664B40024A438D4274434098DEFE5C34664B40024A438D42744340BCEB6CC83F5F4B40C9E4D4CE306D4340BCEB6CC83F5F4B40
79903	6754	38.882643000000002	38.893718999999997	54.753529	54.752702999999997	Пионерская	0103000020E610000001000000050000008C852172FA704340F04C689258604B408C852172FA70434036CB65A373604B402B685A626572434036CB65A373604B402B685A6265724340F04C689258604B408C852172FA704340F04C689258604B40
74173	6754	38.875843000000003	38.877063999999997	54.764733999999997	54.759414999999997	Красноармейская	0103000020E610000001000000050000001CB7989F1B704340C18BBE8234614B401CB7989F1B704340D311C0CDE2614B40DD3F16A243704340D311C0CDE2614B40DD3F16A243704340C18BBE8234614B401CB7989F1B704340C18BBE8234614B40
74237	6754	38.876767999999998	38.879201999999999	54.765549999999998	54.754033	Карла Маркса	0103000020E61000000100000005000000F4160FEF39704340698D412784604B40F4160FEF39704340F5B9DA8AFD614B40F549EEB089704340F5B9DA8AFD614B40F549EEB089704340698D412784604B40F4160FEF39704340698D412784604B40
72194	6754	38.882409000000003	38.884808	54.762889999999999	54.752327999999999	Благоева	0103000020E61000000100000005000000195932C7F2704340BBEEAD484C604B40195932C7F270434004392861A6614B409D9E77634171434004392861A6614B409D9E776341714340BBEEAD484C604B40195932C7F2704340BBEEAD484C604B40
80135	6754	38.891545000000001	38.897205	54.76596	54.762734999999999	 2-й микрорайон	0103000020E61000000100000005000000C7F484251E724340DD41EC4CA1614B40C7F484251E724340A7052FFA0A624B4062670A9DD7724340A7052FFA0A624B4062670A9DD7724340DD41EC4CA1614B40C7F484251E724340DD41EC4CA1614B40
80810	48679	38.742164000000002	38.763579999999997	54.661630000000002	54.644269999999999	Микрорайон	0103000020E610000001000000050000006022DE3AFF5E43409FE5797077524B406022DE3AFF5E4340B806B64AB0544B4099F04BFDBC614340B806B64AB0544B4099F04BFDBC6143409FE5797077524B406022DE3AFF5E43409FE5797077524B40
74066	60225	39.051561999999997	39.116788999999997	55.479351999999999	55.457771000000001	Ленинская	0103000020E61000000100000005000000B1DB6795998643405307793D98BA4B40B1DB679599864340D7A205685BBD4B402AC423F1F28E4340D7A205685BBD4B402AC423F1F28E43405307793D98BA4B40B1DB6795998643405307793D98BA4B40
560	391	39.070948000000001	39.079877000000003	55.399279999999997	55.397654000000003	улица Юбилейная	0103000020E61000000100000005000000BADBF5D214894340D28F8653E6B24B40BADBF5D21489434033F9669B1BB34B40EF59D768398A434033F9669B1BB34B40EF59D768398A4340D28F8653E6B24B40BADBF5D214894340D28F8653E6B24B40
80586	391	39.070948000000001	39.079877000000003	55.399279999999997	55.397654000000003	 Юбилейная	0103000020E61000000100000005000000BADBF5D214894340D28F8653E6B24B40BADBF5D21489434033F9669B1BB34B40EF59D768398A434033F9669B1BB34B40EF59D768398A4340D28F8653E6B24B40BADBF5D214894340D28F8653E6B24B40
79957	61902	39.534928000000001	39.566198	55.143332000000001	55.122771	Ленина	0103000020E610000001000000050000007BDB4C8578C44340D8F2CAF5B68F4B407BDB4C8578C44340323CF6B358924B40C287122D79C84340323CF6B358924B40C287122D79C84340D8F2CAF5B68F4B407BDB4C8578C44340D8F2CAF5B68F4B40
80805	2718	39.288780000000003	39.314391000000001	55.266993999999997	55.251434000000003	Молодежная	0103000020E6100000010000000500000094DE37BEF6A443401E8D43FD2EA04B4094DE37BEF6A44340361D01DC2CA24B401094DBF63DA84340361D01DC2CA24B401094DBF63DA843401E8D43FD2EA04B4094DE37BEF6A443401E8D43FD2EA04B40
72000	2829	39.064390000000003	39.108379999999997	55.308233999999999	55.279933999999997	Гагарина	0103000020E61000000100000005000000401878EE3D884340EC8497E0D4A34B40401878EE3D884340F4C1323674A74B402EC55565DF8D4340F4C1323674A74B402EC55565DF8D4340EC8497E0D4A34B40401878EE3D884340EC8497E0D4A34B40
80804	2894	39.037027000000002	39.056035999999999	55.235774999999997	55.221567999999998	З.Самсоновой	0103000020E61000000100000005000000D508FD4CBD84434089EB18575C9C4B40D508FD4CBD844340711B0DE02D9E4B4007B309302C874340711B0DE02D9E4B4007B309302C87434089EB18575C9C4B40D508FD4CBD84434089EB18575C9C4B40
80934	2400	39.148130999999999	39.160221999999997	55.397623000000003	55.385576999999998	Фабричная	0103000020E610000001000000050000000B43E4F4F59243407E8B4E965AB14B400B43E4F4F592434097917A4FE5B24B40C30C8D278294434097917A4FE5B24B40C30C8D27829443407E8B4E965AB14B400B43E4F4F59243407E8B4E965AB14B40
58	98	39.029949000000002	39.042327	55.386200000000002	55.381141999999997	улица Парижской Коммуны	0103000020E6100000010000000500000022C66B5ED5834340E690D442C9B04B4022C66B5ED58343408CDB68006FB14B40705E9CF86A8543408CDB68006FB14B40705E9CF86A854340E690D442C9B04B4022C66B5ED5834340E690D442C9B04B40
4071	98	39.002181999999998	39.016159000000002	55.387335999999998	55.383485	улица Крупской	0103000020E61000000100000005000000E751F17F47804340D7C0560916B14B40E751F17F478043401F48DE3994B14B409E44847F118243401F48DE3994B14B409E44847F11824340D7C0560916B14B40E751F17F47804340D7C0560916B14B40
3762	98	39.033819999999999	39.056457999999999	55.386946999999999	55.373730999999999	улица Карла Маркса	0103000020E61000000100000005000000B1F9B836548443402D40DB6AD6AF4B40B1F9B836548443408524B37A87B14B407DCC07043A8743408524B37A87B14B407DCC07043A8743402D40DB6AD6AF4B40B1F9B836548443402D40DB6AD6AF4B40
318	98	39.048893999999997	39.058030000000002	55.377628999999999	55.368374000000003	улица Горького	0103000020E610000001000000050000003D7C9928428643402E5915E126AF4B403D7C992842864340B682A62556B04B40EC17EC866D874340B682A62556B04B40EC17EC866D8743402E5915E126AF4B403D7C9928428643402E5915E126AF4B40
95	98	39.034323000000001	39.053897999999997	55.387028999999998	55.376099000000004	улица 9 Января	0103000020E61000000100000005000000144031B2648443407787140324B04B40144031B26484434042CD902A8AB14B40EFA83121E686434042CD902A8AB14B40EFA83121E68643407787140324B04B40144031B2648443407787140324B04B40
223	98	39.051203000000001	39.066600000000001	55.373714999999997	55.368937000000003	проспект Ленина	0103000020E61000000100000005000000823AE5D18D86434066A4DE5339AF4B40823AE5D18D8643402783A3E4D5AF4B40F1F44A59868843402783A3E4D5AF4B40F1F44A598688434066A4DE5339AF4B40823AE5D18D86434066A4DE5339AF4B40
452	98	39.003646000000003	39.019312999999997	55.366190000000003	55.362060999999997	Совхозная улица	0103000020E610000001000000050000007061DD78778043401A14CD0358AE4B407061DD7877804340A60F5D50DFAE4B409EB12FD978824340A60F5D50DFAE4B409EB12FD9788243401A14CD0358AE4B407061DD78778043401A14CD0358AE4B40
80089	98	39.013806000000002	39.054239000000003	55.397382999999998	55.371332000000002	Советская	0103000020E610000001000000050000008A3E1F65C4814340A9FA95CE87AF4B408A3E1F65C4814340417E3672DDB24B407995B54DF1864340417E3672DDB24B407995B54DF1864340A9FA95CE87AF4B408A3E1F65C4814340A9FA95CE87AF4B40
80569	98	39.035598999999998	39.065072999999998	55.383443999999997	55.374364999999997	Рязанская 	0103000020E6100000010000000500000099620E828E8443402EE23B31EBAF4B4099620E828E84434078EC67B114B14B40226DE34F5488434078EC67B114B14B40226DE34F548843402EE23B31EBAF4B4099620E828E8443402EE23B31EBAF4B40
80888	98	39.018234999999997	39.031044999999999	55.387203	55.381030000000003	Профсоюзная	0103000020E610000001000000050000003F52448655824340BF654E97C5B04B403F52448655824340E0F42EDE8FB14B4027DA5548F9834340E0F42EDE8FB14B4027DA5548F9834340BF654E97C5B04B403F52448655824340BF654E97C5B04B40
80570	98	39.029949000000002	39.042327	55.386200000000002	55.381141999999997	Парижской Коммуны	0103000020E6100000010000000500000022C66B5ED5834340E690D442C9B04B4022C66B5ED58343408CDB68006FB14B40705E9CF86A8543408CDB68006FB14B40705E9CF86A854340E690D442C9B04B4022C66B5ED5834340E690D442C9B04B40
80062	98	39.034629000000002	39.041446999999998	55.404243000000001	55.389482999999998	Нечаевская	0103000020E61000000100000005000000213F1BB96E8443408AAC3594DAB14B40213F1BB96E8443408751103CBEB34B4037C2A2224E8543408751103CBEB34B4037C2A2224E8543408AAC3594DAB14B40213F1BB96E8443408AAC3594DAB14B40
80809	98	39.066546000000002	39.085940999999998	55.368994000000001	55.363565000000001	Касимовское шоссе	0103000020E61000000100000005000000FED64E9484884340317C444C89AE4B40FED64E9484884340CA3505323BAF4B4059315C1D008B4340CA3505323BAF4B4059315C1D008B4340317C444C89AE4B40FED64E9484884340317C444C89AE4B40
80568	98	39.030343999999999	39.032482000000002	55.403640000000003	55.387273999999998	Владимирская	0103000020E610000001000000050000009ED0EB4FE2834340A94BC63192B14B409ED0EB4FE2834340C1ADBB79AAB34B40B6DAC35E28844340C1ADBB79AAB34B40B6DAC35E28844340A94BC63192B14B409ED0EB4FE2834340A94BC63192B14B40
80104	98	38.998876000000003	39.002324999999999	55.391334999999998	55.382851000000002	50 лет ВЛКСМ	0103000020E610000001000000050000003161342BDB7F4340D61EF64201B14B403161342BDB7F4340DC63E94317B24B404A7B832F4C804340DC63E94317B24B404A7B832F4C804340D61EF64201B14B403161342BDB7F4340D61EF64201B14B40
80584	98	39.060940000000002	39.070211	55.368640999999997	55.362833000000002	4-й микрорайон	0103000020E610000001000000050000005682C5E1CC8743406D74CE4F71AE4B405682C5E1CC8743407C7BD7A02FAF4B40E4688EACFC8843407C7BD7A02FAF4B40E4688EACFC8843406D74CE4F71AE4B405682C5E1CC8743406D74CE4F71AE4B40
80611	98	39.048858000000003	39.060625999999999	55.369816999999998	55.362132000000003	3-й микрорайон	0103000020E61000000100000005000000F1129CFA40864340E46A64575AAE4B40F1129CFA408643409E40D82956AF4B40C6A4BF97C28743409E40D82956AF4B40C6A4BF97C2874340E46A64575AAE4B40F1129CFA40864340E46A64575AAE4B40
79931	98	39.058613999999999	39.070193000000003	55.375726	55.369152	1-й микрорайон	0103000020E610000001000000050000003B8BDEA98087434062A06B5F40AF4B403B8BDEA980874340E22021CA17B04B403EB48F15FC884340E22021CA17B04B403EB48F15FC88434062A06B5F40AF4B403B8BDEA98087434062A06B5F40AF4B40
80800	2292	39.294026000000002	39.313214000000002	55.436059999999998	55.428581999999999	Советская	0103000020E610000001000000050000003C16DBA4A2A54340BFD364C6DBB64B403C16DBA4A2A54340008C67D0D0B74B401E53776517A84340008C67D0D0B74B401E53776517A84340BFD364C6DBB64B403C16DBA4A2A54340BFD364C6DBB64B40
80962	3336	39.465406999999999	39.493273000000002	55.174850999999997	55.157156000000001	Горького	0103000020E610000001000000050000002C2AE27492BB4340622F14B01D944B402C2AE27492BB434021567F8461964B40FA7FD59123BF434021567F8461964B40FA7FD59123BF4340622F14B01D944B402C2AE27492BB4340622F14B01D944B40
81034	62060	37.610709	37.647801000000001	56.388770000000001	56.372821999999999	Транспортная	0103000020E61000000100000005000000BA2F67B62BCE42405A9D9CA1B82F4C40BA2F67B62BCE42403DD52137C3314C4076A8A624EBD242403DD52137C3314C4076A8A624EBD242405A9D9CA1B82F4C40BA2F67B62BCE42405A9D9CA1B82F4C40
71813	59515	37.489356000000001	37.570483000000003	56.401713999999998	56.317926999999997	Подъячево	0103000020E61000000100000005000000FA0CA837A3BE4240F8C1F9D4B1284C40FA0CA837A3BE4240342C465D6B334C4045F6419605C94240342C465D6B334C4045F6419605C94240F8C1F9D4B1284C40FA0CA837A3BE4240F8C1F9D4B1284C40
6418	24478	37.472054	37.476204000000003	56.294460999999998	56.287292000000001	улица Кирьянова	0103000020E6100000010000000500000016F9F5436CBC42408333F8FBC5244C4016F9F5436CBC42404679E6E5B0254C40B91CAF40F4BC42404679E6E5B0254C40B91CAF40F4BC42408333F8FBC5244C4016F9F5436CBC42408333F8FBC5244C40
80872	24478	37.483094999999999	37.489660999999998	56.288981	56.279122000000001	Ленина	0103000020E6100000010000000500000039EE940ED6BD42400CCC0A45BA234C4039EE940ED6BD42402B155454FD244C4036902E36ADBE42402B155454FD244C4036902E36ADBE42400CCC0A45BA234C4039EE940ED6BD42400CCC0A45BA234C40
74148	24478	37.475630000000002	37.483848999999999	56.28989	56.283140000000003	Конярова	0103000020E610000001000000050000008D7F9F71E1BC4240401878EE3D244C408D7F9F71E1BC4240FEB7921D1B254C40E59997C3EEBD4240FEB7921D1B254C40E59997C3EEBD4240401878EE3D244C408D7F9F71E1BC4240401878EE3D244C40
80847	24478	37.472054	37.476204000000003	56.294460999999998	56.287292000000001	Кирьянова	0103000020E6100000010000000500000016F9F5436CBC42408333F8FBC5244C4016F9F5436CBC42404679E6E5B0254C40B91CAF40F4BC42404679E6E5B0254C40B91CAF40F4BC42408333F8FBC5244C4016F9F5436CBC42408333F8FBC5244C40
74227	24478	37.485878999999997	37.486435999999998	56.292383000000001	56.290019999999998	Заречная	0103000020E610000001000000050000001668774831BE4240CC9717601F254C401668774831BE424004745FCE6C254C406CCCEB8843BE424004745FCE6C254C406CCCEB8843BE4240CC9717601F254C401668774831BE4240CC9717601F254C40
74187	24478	37.481648	37.489328999999998	56.284294000000003	56.275454000000003	Большевистская	0103000020E61000000100000005000000871744A4A6BD4240B5C6A01342234C40871744A4A6BD42407A39ECBE63244C4000FE2955A2BE42407A39ECBE63244C4000FE2955A2BE4240B5C6A01342234C40871744A4A6BD4240B5C6A01342234C40
74104	60240	37.291834000000001	37.314526000000001	56.393219999999999	56.384779000000002	мкр. Дуброво	0103000020E6100000010000000500000031EE06D15AA542400398327040314C4031EE06D15AA542400A11700855324C40F0DE516342A842400A11700855324C40F0DE516342A842400398327040314C4031EE06D15AA542400398327040314C40
80792	26148	37.139524999999999	37.195372999999996	56.440542999999998	56.422165999999997	пл. Осипова	0103000020E61000000100000005000000B9FC87F4DB914240D7BD158909364C40B9FC87F4DB914240A9BD88B663384C40BDC282FB01994240A9BD88B663384C40BDC282FB01994240D7BD158909364C40B9FC87F4DB914240D7BD158909364C40
80947	26148	37.139524999999999	37.195372999999996	56.440542999999998	56.422165999999997	Ракетчиков	0103000020E61000000100000005000000B9FC87F4DB914240D7BD158909364C40B9FC87F4DB914240A9BD88B663384C40BDC282FB01994240A9BD88B663384C40BDC282FB01994240D7BD158909364C40B9FC87F4DB914240D7BD158909364C40
80952	27717	37.366591999999997	37.374012	56.092536000000003	56.084581	2-й проезд строителей	0103000020E61000000100000005000000D47C957CECAE4240766EDA8CD30A4C40D47C957CECAE4240F1D93A38D80B4C40E1270EA0DFAF4240F1D93A38D80B4C40E1270EA0DFAF4240766EDA8CD30A4C40D47C957CECAE4240766EDA8CD30A4C40
72212	59588	37.507987	37.533768999999999	56.448951000000001	56.421563999999996	Фабричная	0103000020E6100000010000000500000086E5CFB705C14240E19524CFF5354C4086E5CFB705C14240D540F33977394C402F4FE78A52C44240D540F33977394C402F4FE78A52C44240E19524CFF5354C4086E5CFB705C14240E19524CFF5354C40
37284	26715	37.750757	37.763441	56.508118000000003	56.499617999999998	Центральная	0103000020E610000001000000050000001D1F2DCE18E04240183F8D7BF33F4C401D1F2DCE18E042402541B8020A414C4078B6476FB8E142402541B8020A414C4078B6476FB8E14240183F8D7BF33F4C401D1F2DCE18E04240183F8D7BF33F4C40
80818	46306	37.698779999999999	37.711841999999997	56.231772999999997	56.228110000000001	Новая	0103000020E61000000100000005000000A88C7F9F71D94240FEF15EB5321D4C40A88C7F9F71D94240438CD7BCAA1D4C40A9F57EA31DDB4240438CD7BCAA1D4C40A9F57EA31DDB4240FEF15EB5321D4C40A88C7F9F71D94240FEF15EB5321D4C40
80808	25396	37.481755999999997	37.518281999999999	56.101238000000002	56.067103000000003	микрорайон Строителей	0103000020E610000001000000050000006D533C2EAABD4240543BC3D496084C406D533C2EAABD4240658EE55DF50C4C40800D881057C24240658EE55DF50C4C40800D881057C24240543BC3D496084C406D533C2EAABD4240543BC3D496084C40
72271	25396	37.481755999999997	37.518281999999999	56.101238000000002	56.067103000000003	Ушакова	0103000020E610000001000000050000006D533C2EAABD4240543BC3D496084C406D533C2EAABD4240658EE55DF50C4C40800D881057C24240658EE55DF50C4C40800D881057C24240543BC3D496084C406D533C2EAABD4240543BC3D496084C40
37280	25396	37.481755999999997	37.518281999999999	56.101238000000002	56.067103000000003	Городок-1	0103000020E610000001000000050000006D533C2EAABD4240543BC3D496084C406D533C2EAABD4240658EE55DF50C4C40800D881057C24240658EE55DF50C4C40800D881057C24240543BC3D496084C406D533C2EAABD4240543BC3D496084C40
74103	60239	37.481755999999997	37.518281999999999	56.101238000000002	56.067103000000003	Краснофлотская	0103000020E610000001000000050000006D533C2EAABD4240543BC3D496084C406D533C2EAABD4240658EE55DF50C4C40800D881057C24240658EE55DF50C4C40800D881057C24240543BC3D496084C406D533C2EAABD4240543BC3D496084C40
80816	26334	37.340136999999999	37.357599999999998	56.49042	56.475687999999998	Насадкино	0103000020E610000001000000050000006C94F59B89AB4240C18C2958E33C4C406C94F59B89AB4240F4A62215C63E4C40598638D6C5AD4240F4A62215C63E4C40598638D6C5AD4240C18C2958E33C4C406C94F59B89AB4240C18C2958E33C4C40
80902	62003	37.292050000000003	37.310456000000002	56.186219000000001	56.174464999999998	Центральная	0103000020E61000000100000005000000FE65F7E461A54240F8A57EDE54164C40FE65F7E461A5424069723106D6174C406A6CAF05BDA7424069723106D6174C406A6CAF05BDA74240F8A57EDE54164C40FE65F7E461A54240F8A57EDE54164C40
71935	25306	37.481090999999999	37.516530000000003	56.187475999999997	56.160516000000001	Комсомольская	0103000020E6100000010000000500000031B3CF6394BD42400C3ECDC98B144C4031B3CF6394BD42407764AC36FF174C4092B3B0A71DC242407764AC36FF174C4092B3B0A71DC242400C3ECDC98B144C4031B3CF6394BD42400C3ECDC98B144C40
80925	62023	37.577561000000003	37.587119000000001	56.205554999999997	56.200172999999999	Триумфальная	0103000020E61000000100000005000000F838D384EDC942406745D4449F194C40F838D384EDC94240BF4351A04F1A4C401CEE23B726CB4240BF4351A04F1A4C401CEE23B726CB42406745D4449F194C40F838D384EDC942406745D4449F194C40
74045	15109	37.521569	37.534315999999997	56.353873999999998	56.349021	мкр. Аверьянова	0103000020E61000000100000005000000C0CDE2C5C2C24240014F5AB8AC2C4C40C0CDE2C5C2C24240CD7344BE4B2D4C4061DD787764C44240CD7344BE4B2D4C4061DD787764C44240014F5AB8AC2C4C40C0CDE2C5C2C24240014F5AB8AC2C4C40
74223	15109	37.515819999999998	37.522243000000003	56.339452000000001	56.338194999999999	Школьная	0103000020E61000000100000005000000B54FC76306C24240DA5548F9492B4C40B54FC76306C24240E947C329732B4C4050C8CEDBD8C24240E947C329732B4C4050C8CEDBD8C24240DA5548F9492B4C40B54FC76306C24240DA5548F9492B4C40
74186	15109	37.518300000000004	37.531207999999999	56.381041000000003	56.345913000000003	Профессиональная	0103000020E6100000010000000500000027C286A757C2424071218FE0462C4C4027C286A757C24240B3B794F3C5304C40D1AFAD9FFEC34240B3B794F3C5304C40D1AFAD9FFEC3424071218FE0462C4C4027C286A757C2424071218FE0462C4C40
74140	15109	37.514823	37.517032999999998	56.342998999999999	56.339652000000001	Почтовая	0103000020E61000000100000005000000431D56B8E5C14240B0027CB7792B4C40431D56B8E5C14240C5C72764E72B4C40F4F928232EC24240C5C72764E72B4C40F4F928232EC24240B0027CB7792B4C40431D56B8E5C14240B0027CB7792B4C40
72262	15109	37.511687999999999	37.532358000000002	56.353349999999999	56.348886	Маркова	0103000020E61000000100000005000000B9E00CFE7EC142402104E44BA82C4C40B9E00CFE7EC142405305A3923A2D4C40CAE1934E24C442405305A3923A2D4C40CAE1934E24C442402104E44BA82C4C40B9E00CFE7EC142402104E44BA82C4C40
39122	27652	39.995502999999999	40.009984000000003	53.269392000000003	53.257527000000003	Школьная	0103000020E61000000100000005000000F2086EA46CFF4340236B0DA5F6A04A40F2086EA46CFF4340EBE6E26F7BA24A40DCBDDC2747014440EBE6E26F7BA24A40DCBDDC2747014440236B0DA5F6A04A40F2086EA46CFF4340236B0DA5F6A04A40
74150	15109	37.543291000000004	37.558526000000001	56.341442999999998	56.335186	Космонавтов	0103000020E61000000100000005000000079B3A8F8AC54240DD09F65FE72A4C40079B3A8F8AC542405C397B67B42B4C409CFBABC77DC742405C397B67B42B4C409CFBABC77DC74240DD09F65FE72A4C40079B3A8F8AC54240DD09F65FE72A4C40
74216	15109	37.533239000000002	37.538125000000001	56.342984000000001	56.336497999999999	Комсомольская	0103000020E61000000100000005000000D3F9F02C41C44240AF95D05D122B4C40D3F9F02C41C44240908653E6E62B4C407B14AE47E1C44240908653E6E62B4C407B14AE47E1C44240AF95D05D122B4C40D3F9F02C41C44240AF95D05D122B4C40
74211	15109	37.528855	37.533580000000001	56.34263	56.334772000000001	Инженерная	0103000020E61000000100000005000000BDA94885B1C34240EACE13CFD92A4C40BDA94885B1C342407250C24CDB2B4C405CE674594CC442407250C24CDB2B4C405CE674594CC44240EACE13CFD92A4C40BDA94885B1C34240EACE13CFD92A4C40
6157	15109	37.509945000000002	37.524228000000001	56.344715999999998	56.341462999999997	Загорская улица	0103000020E610000001000000050000001EE1B4E045C14240A3E5400FB52B4C401EE1B4E045C14240373465A71F2C4C40E1D231E719C34240373465A71F2C4C40E1D231E719C34240A3E5400FB52B4C401EE1B4E045C14240A3E5400FB52B4C40
74137	15109	37.509945000000002	37.524228000000001	56.344715999999998	56.341462999999997	Загорская	0103000020E610000001000000050000001EE1B4E045C14240A3E5400FB52B4C401EE1B4E045C14240373465A71F2C4C40E1D231E719C34240373465A71F2C4C40E1D231E719C34240A3E5400FB52B4C401EE1B4E045C14240A3E5400FB52B4C40
74141	15109	37.517428000000002	37.519809000000002	56.336098999999997	56.331808000000002	Волгостроевская	0103000020E610000001000000050000007104A9143BC242408D463EAF782A4C407104A9143BC24240F19BC24A052B4C404F95EF1989C24240F19BC24A052B4C404F95EF1989C242408D463EAF782A4C407104A9143BC242408D463EAF782A4C40
74124	15109	37.540883000000001	37.566924999999998	56.360132999999998	56.352722	Внуковская	0103000020E610000001000000050000002FFB75A73BC54240344A97FE252D4C402FFB75A73BC54240ED9A90D6182E4C40742497FF90C84240ED9A90D6182E4C40742497FF90C84240344A97FE252D4C402FFB75A73BC54240344A97FE252D4C40
74156	15109	37.506900000000002	37.515317000000003	56.332425999999998	56.329956000000003	Веретенникова	0103000020E61000000100000005000000D42B6519E2C042403B8F8AFF3B2A4C40D42B6519E2C04240882B67EF8C2A4C4053094FE8F5C14240882B67EF8C2A4C4053094FE8F5C142403B8F8AFF3B2A4C40D42B6519E2C042403B8F8AFF3B2A4C40
6251	15109	37.529060999999999	37.543291000000004	56.343313999999999	56.341442999999998	Большевистская улица	0103000020E61000000100000005000000664B5645B8C342405C397B67B42B4C40664B5645B8C34240252191B6F12B4C40079B3A8F8AC54240252191B6F12B4C40079B3A8F8AC542405C397B67B42B4C40664B5645B8C342405C397B67B42B4C40
71934	25110	37.499695000000003	37.530687	56.258133000000001	56.228731000000003	Советская	0103000020E61000000100000005000000C47C7901F6BF42406B4AB20E471D4C40C47C7901F6BF42405A828C800A214C40C8B4368DEDC342405A828C800A214C40C8B4368DEDC342406B4AB20E471D4C40C47C7901F6BF42406B4AB20E471D4C40
72266	25110	37.499695000000003	37.530687	56.258133000000001	56.228731000000003	Заречная	0103000020E61000000100000005000000C47C7901F6BF42406B4AB20E471D4C40C47C7901F6BF42405A828C800A214C40C8B4368DEDC342405A828C800A214C40C8B4368DEDC342406B4AB20E471D4C40C47C7901F6BF42406B4AB20E471D4C40
79915	61896	38.62744	38.687995999999998	55.502110000000002	55.476270999999997	Зайцева	0103000020E61000000100000005000000E31934F44F5043404084B872F6BC4B40E31934F44F5043404E7FF62345C04B40B0E3BF40105843404E7FF62345C04B40B0E3BF40105843404084B872F6BC4B40E31934F44F5043404084B872F6BC4B40
74193	60266	38.62744	38.687995999999998	55.502110000000002	55.476270999999997	Октябрьская	0103000020E61000000100000005000000E31934F44F5043404084B872F6BC4B40E31934F44F5043404E7FF62345C04B40B0E3BF40105843404E7FF62345C04B40B0E3BF40105843404084B872F6BC4B40E31934F44F5043404084B872F6BC4B40
71773	59174	38.363551000000001	38.930720999999998	55.566837	55.208686999999998	Новомалинная	0103000020E61000000100000005000000CCB6D3D6882E4340D80C7041B69A4B40CCB6D3D6882E4340D594641D8EC84B40A759A0DD21774340D594641D8EC84B40A759A0DD21774340D80C7041B69A4B40CCB6D3D6882E4340D80C7041B69A4B40
71861	18806	38.648757000000003	38.684142000000001	55.363625999999996	55.346338000000003	Центральная	0103000020E610000001000000050000008A0629780A53434058AEB7CD54AC4B408A0629780A534340D6FCF84B8BAE4B40F7E80DF791574340D6FCF84B8BAE4B40F7E80DF79157434058AEB7CD54AC4B408A0629780A53434058AEB7CD54AC4B40
80518	61891	38.797806000000001	38.904463	55.344090999999999	55.315359999999998	Советская	0103000020E61000000100000005000000BB46CB811E664340B83B6BB75DA84B40BB46CB811E66434089EC832C0BAC4B4095B88E71C573434089EC832C0BAC4B4095B88E71C5734340B83B6BB75DA84B40BB46CB811E664340B83B6BB75DA84B40
79889	61891	38.797806000000001	38.904463	55.344090999999999	55.315359999999998	Зайцева	0103000020E61000000100000005000000BB46CB811E664340B83B6BB75DA84B40BB46CB811E66434089EC832C0BAC4B4095B88E71C573434089EC832C0BAC4B4095B88E71C5734340B83B6BB75DA84B40BB46CB811E664340B83B6BB75DA84B40
67060	21425	38.636181000000001	38.66375	55.281174999999998	55.263275	Некрасова	0103000020E6100000010000000500000015AB06616E5143405D6DC5FEB2A14B4015AB06616E514340F5B9DA8AFDA34B40295C8FC2F5544340F5B9DA8AFDA34B40295C8FC2F55443405D6DC5FEB2A14B4015AB06616E5143405D6DC5FEB2A14B40
80764	15658	38.648316999999999	38.680252000000003	55.416586000000002	55.397674000000002	Центральная	0103000020E610000001000000050000006D382C0DFC524340193C4CFBE6B24B406D382C0DFC52434059FCA6B052B54B40F1845E7F1257434059FCA6B052B54B40F1845E7F12574340193C4CFBE6B24B406D382C0DFC524340193C4CFBE6B24B40
9973	15658	38.648316999999999	38.680252000000003	55.416586000000002	55.397674000000002	Новые дома	0103000020E610000001000000050000006D382C0DFC524340193C4CFBE6B24B406D382C0DFC52434059FCA6B052B54B40F1845E7F1257434059FCA6B052B54B40F1845E7F12574340193C4CFBE6B24B406D382C0DFC524340193C4CFBE6B24B40
71874	19971	38.493250000000003	38.542163000000002	55.436464000000001	55.423698000000002	Моховая	0103000020E610000001000000050000004260E5D0223F4340B8B06EBC3BB64B404260E5D0223F4340D0F0660DDEB74B40F60CE19865454340D0F0660DDEB74B40F60CE19865454340B8B06EBC3BB64B404260E5D0223F4340B8B06EBC3BB64B40
80921	21864	38.815494000000001	38.854660000000003	55.319653000000002	55.306711999999997	Советская	0103000020E61000000100000005000000C80A7E1B6268434037A5BC5642A74B40C80A7E1B62684340BE88B663EAA84B408599B67F656D4340BE88B663EAA84B408599B67F656D434037A5BC5642A74B40C80A7E1B6268434037A5BC5642A74B40
80783	20208	38.556787999999997	38.610560999999997	55.466605999999999	55.442449000000003	Лесная	0103000020E61000000100000005000000126745D444474340EF92382BA2B84B40126745D444474340060FD3BEB9BB4B40459BE3DC264E4340060FD3BEB9BB4B40459BE3DC264E4340EF92382BA2B84B40126745D444474340EF92382BA2B84B40
80910	21199	38.561863000000002	38.593663999999997	55.352469999999997	55.340229999999998	Мира	0103000020E610000001000000050000008EEA7420EB4743401D8F19A88CAB4B408EEA7420EB4743401A69A9BC1DAD4B400168942EFD4B43401A69A9BC1DAD4B400168942EFD4B43401D8F19A88CAB4B408EEA7420EB4743401D8F19A88CAB4B40
16380	12774	38.655737000000002	38.669013999999997	55.326332999999998	55.321266999999999	улица Менделеева	0103000020E610000001000000050000007AE3A430EF5343405B24ED461FA94B407AE3A430EF534340834D9D47C5A94B4077483140A2554340834D9D47C5A94B4077483140A25543405B24ED461FA94B407AE3A430EF5343405B24ED461FA94B40
5045	12774	38.648263	38.661279999999998	55.316887000000001	55.302463000000003	улица Зелинского	0103000020E610000001000000050000007A1A3048FA52434002A08A1BB7A64B407A1A3048FA52434087C3D2C08FA84B40DBBFB2D2A454434087C3D2C08FA84B40DBBFB2D2A454434002A08A1BB7A64B407A1A3048FA52434002A08A1BB7A64B40
16463	12774	38.720407000000002	38.728492000000003	55.341050000000003	55.339748999999998	улица Андреса	0103000020E610000001000000050000009D67EC4B365C4340A2EC2DE57CAB4B409D67EC4B365C43408126C286A7AB4B40E6B2D1393F5D43408126C286A7AB4B40E6B2D1393F5D4340A2EC2DE57CAB4B409D67EC4B365C4340A2EC2DE57CAB4B40
74196	12774	38.672795999999998	38.673838000000003	55.323413000000002	55.322727	площадь Ленина	0103000020E610000001000000050000009770E82D1E564340A2444B1E4FA94B409770E82D1E564340F60CE19865A94B40AA66D65240564340F60CE19865A94B40AA66D65240564340A2444B1E4FA94B409770E82D1E564340A2444B1E4FA94B40
5259	12774	38.729802999999997	38.735508000000003	55.302463000000003	55.292664000000002	Юбилейная улица	0103000020E61000000100000005000000E7C2482F6A5D4340B85B920376A54B40E7C2482F6A5D434002A08A1BB7A64B4023F94A20255E434002A08A1BB7A64B4023F94A20255E4340B85B920376A54B40E7C2482F6A5D4340B85B920376A54B40
80501	12774	38.742263000000001	38.745632000000001	55.280549000000001	55.27617	Толстого	0103000020E61000000100000005000000F3035779025F43407311DF8959A34B40F3035779025F434077F69507E9A34B40F06C8FDE705F434077F69507E9A34B40F06C8FDE705F43407311DF8959A34B40F3035779025F43407311DF8959A34B40
80472	12774	38.673065999999999	38.684483	55.329917999999999	55.317870999999997	Советская	0103000020E610000001000000050000005706D5062756434064AC36FFAFA84B405706D506275643404D2EC6C03AAA4B4080D591239D5743404D2EC6C03AAA4B4080D591239D57434064AC36FFAFA84B405706D5062756434064AC36FFAFA84B40
74182	12774	38.739766000000003	38.755028000000003	55.288674999999998	55.271656999999998	Рабочая	0103000020E61000000100000005000000AC58FCA6B05E43405F5D15A8C5A24B40AC58FCA6B05E43401E166A4DF3A44B403BC8EBC1A46043401E166A4DF3A44B403BC8EBC1A46043405F5D15A8C5A24B40AC58FCA6B05E43405F5D15A8C5A24B40
80460	12774	38.659205	38.685021999999996	55.328156	55.321651000000003	Победы	0103000020E610000001000000050000000A2E56D460544340E4DC26DC2BA94B400A2E56D4605443403BFE0B0401AA4B402F8507CDAE5743403BFE0B0401AA4B402F8507CDAE574340E4DC26DC2BA94B400A2E56D460544340E4DC26DC2BA94B40
80462	12774	38.675725	38.687196	55.321235999999999	55.320912999999997	Пионерская	0103000020E61000000100000005000000780B24287E5643403DEE5BAD13A94B40780B24287E5643402026E1421EA94B4094F8DC09F65743402026E1421EA94B4094F8DC09F65743403DEE5BAD13A94B40780B24287E5643403DEE5BAD13A94B40
15525	12774	38.673622999999999	38.685372999999998	55.322710999999998	55.322465999999999	Октябрьская улица	0103000020E61000000100000005000000AD6A4947395643403509DE9046A94B40AD6A4947395643409C8713984EA94B40DC476E4DBA5743409C8713984EA94B40DC476E4DBA5743403509DE9046A94B40AD6A4947395643403509DE9046A94B40
80474	12774	38.673622999999999	38.685372999999998	55.322710999999998	55.322465999999999	Октябрьская	0103000020E61000000100000005000000AD6A4947395643403509DE9046A94B40AD6A4947395643409C8713984EA94B40DC476E4DBA5743409C8713984EA94B40DC476E4DBA5743403509DE9046A94B40AD6A4947395643403509DE9046A94B40
80884	12774	38.736396999999997	38.741410000000002	55.272374999999997	55.270153999999998	Некрасова	0103000020E61000000100000005000000AEEFC341425E43401971016894A24B40AEEFC341425E4340BE9F1A2FDDA24B40B476DB85E65E4340BE9F1A2FDDA24B40B476DB85E65E43401971016894A24B40AEEFC341425E43401971016894A24B40
80478	12774	38.715986999999998	38.742901000000003	55.297486999999997	55.264276000000002	Московская	0103000020E610000001000000050000003AAE4676A55B4340118FC4CBD3A14B403AAE4676A55B434019FED30D14A64B4036954561175F434019FED30D14A64B4036954561175F4340118FC4CBD3A14B403AAE4676A55B4340118FC4CBD3A14B40
80479	12774	38.738723999999998	38.748336000000002	55.290588	55.269862000000003	Ломоносова	0103000020E6100000010000000500000099620E828E5E4340723788D68AA24B4099620E828E5E4340164ED2FC31A54B40B1355B79C95F4340164ED2FC31A54B40B1355B79C95F4340723788D68AA24B4099620E828E5E4340723788D68AA24B40
80020	12774	38.757561000000003	38.764567999999997	55.251983000000003	55.240169000000002	Ленинская	0103000020E61000000100000005000000CFDC43C2F7604340AB4198DBBD9E4B40CFDC43C2F7604340F1129CFA40A04B40B8C83D5DDD614340F1129CFA40A04B40B8C83D5DDD614340AB4198DBBD9E4B40CFDC43C2F7604340AB4198DBBD9E4B40
15433	12774	38.721179999999997	38.730504000000003	55.342630999999997	55.341177999999999	Комсомольская улица	0103000020E61000000100000005000000BF4351A04F5C4340AE0E80B8ABAB4B40BF4351A04F5C434042CC2555DBAB4B4071CCB227815D434042CC2555DBAB4B4071CCB227815D4340AE0E80B8ABAB4B40BF4351A04F5C4340AE0E80B8ABAB4B40
74179	12774	38.646152000000001	38.662547000000004	55.316774000000002	55.310104000000003	Кагана	0103000020E610000001000000050000005C1FD61BB5524340ED2DE57CB1A74B405C1FD61BB55243408F1CE90C8CA84B400E881057CE5443408F1CE90C8CA84B400E881057CE544340ED2DE57CB1A74B405C1FD61BB5524340ED2DE57CB1A74B40
80485	12774	38.648263	38.661279999999998	55.316887000000001	55.302463000000003	Зелинского	0103000020E610000001000000050000007A1A3048FA52434002A08A1BB7A64B407A1A3048FA52434087C3D2C08FA84B40DBBFB2D2A454434087C3D2C08FA84B40DBBFB2D2A454434002A08A1BB7A64B407A1A3048FA52434002A08A1BB7A64B40
80491	12774	38.677737	38.680036999999999	55.329498000000001	55.328094	Зеленый переулок	0103000020E6100000010000000500000003250516C0564340C501F4FBFEA94B4003250516C0564340780C8FFD2CAA4B40F488D1730B574340780C8FFD2CAA4B40F488D1730B574340C501F4FBFEA94B4003250516C0564340C501F4FBFEA94B40
16324	12774	38.672832	38.685436000000003	55.338048999999998	55.317870999999997	Железнодорожная улица	0103000020E61000000100000005000000E4D9E55B1F56434064AC36FFAFA84B40E4D9E55B1F56434006B98B3045AB4B4023C0E95DBC57434006B98B3045AB4B4023C0E95DBC57434064AC36FFAFA84B40E4D9E55B1F56434064AC36FFAFA84B40
16491	12774	38.766328999999999	38.772984999999998	55.260156000000002	55.250767000000003	Гражданская улица	0103000020E61000000100000005000000FA7C94111762434041F50F2219A04B40FA7C941117624340D9EDB3CA4CA14B4037A6272CF1624340D9EDB3CA4CA14B4037A6272CF162434041F50F2219A04B40FA7C94111762434041F50F2219A04B40
80473	12774	38.702396	38.707714000000003	55.323878999999998	55.315098999999996	Быковского	0103000020E61000000100000005000000AD6BB41CE85943404B00FE2955A84B40AD6BB41CE85943403B6EF8DD74A94B40EF75525F965A43403B6EF8DD74A94B40EF75525F965A43404B00FE2955A84B40AD6BB41CE85943404B00FE2955A84B40
80788	20018	38.537545999999999	38.578392000000001	55.434849999999997	55.418005999999998	Коммунистическая	0103000020E610000001000000050000003D0CAD4ECE44434011C4793881B54B403D0CAD4ECE4443403255302AA9B74B404F22C2BF084A43403255302AA9B74B404F22C2BF084A434011C4793881B54B403D0CAD4ECE44434011C4793881B54B40
80789	20018	38.537545999999999	38.578392000000001	55.434849999999997	55.418005999999998	Зеленая	0103000020E610000001000000050000003D0CAD4ECE44434011C4793881B54B403D0CAD4ECE4443403255302AA9B74B404F22C2BF084A43403255302AA9B74B404F22C2BF084A434011C4793881B54B403D0CAD4ECE44434011C4793881B54B40
79890	59555	38.428418999999998	38.486558000000002	55.466239000000002	55.442444000000002	проспект 60 лет Октября	0103000020E6100000010000000500000015FE0C6FD6364340DD274701A2B84B4015FE0C6FD6364340548F34B8ADBB4B40B8CD5488473E4340548F34B8ADBB4B40B8CD5488473E4340DD274701A2B84B4015FE0C6FD6364340DD274701A2B84B40
71930	59555	38.428418999999998	38.486558000000002	55.466239000000002	55.442444000000002	Молодежная	0103000020E6100000010000000500000015FE0C6FD6364340DD274701A2B84B4015FE0C6FD6364340548F34B8ADBB4B40B8CD5488473E4340548F34B8ADBB4B40B8CD5488473E4340DD274701A2B84B4015FE0C6FD6364340DD274701A2B84B40
74169	60262	38.428418999999998	38.486558000000002	55.466239000000002	55.442444000000002	Молодежная	0103000020E6100000010000000500000015FE0C6FD6364340DD274701A2B84B4015FE0C6FD6364340548F34B8ADBB4B40B8CD5488473E4340548F34B8ADBB4B40B8CD5488473E4340DD274701A2B84B4015FE0C6FD6364340DD274701A2B84B40
71873	20692	38.737555999999998	38.778841999999997	55.409773999999999	55.391202	Центральная	0103000020E61000000100000005000000FA7B293C685E43409D103AE812B24B40FA7B293C685E43402460747973B44B4028603B18B16343402460747973B44B4028603B18B16343409D103AE812B24B40FA7B293C685E43409D103AE812B24B40
80787	20255	38.570990000000002	38.610705000000003	55.443603000000003	55.421337999999999	Школьная	0103000020E61000000100000005000000E92B483316494340F1475167EEB54B40E92B48331649434029B4ACFBC7B84B407940D9942B4E434029B4ACFBC7B84B407940D9942B4E4340F1475167EEB54B40E92B483316494340F1475167EEB54B40
80917	20255	38.570990000000002	38.610705000000003	55.443603000000003	55.421337999999999	Центральная	0103000020E61000000100000005000000E92B483316494340F1475167EEB54B40E92B48331649434029B4ACFBC7B84B407940D9942B4E434029B4ACFBC7B84B407940D9942B4E4340F1475167EEB54B40E92B483316494340F1475167EEB54B40
67053	20255	38.570990000000002	38.610705000000003	55.443603000000003	55.421337999999999	Парковая	0103000020E61000000100000005000000E92B483316494340F1475167EEB54B40E92B48331649434029B4ACFBC7B84B407940D9942B4E434029B4ACFBC7B84B407940D9942B4E4340F1475167EEB54B40E92B483316494340F1475167EEB54B40
80806	20255	38.570990000000002	38.610705000000003	55.443603000000003	55.421337999999999	Королькова	0103000020E61000000100000005000000E92B483316494340F1475167EEB54B40E92B48331649434029B4ACFBC7B84B407940D9942B4E434029B4ACFBC7B84B407940D9942B4E4340F1475167EEB54B40E92B483316494340F1475167EEB54B40
80791	20255	38.570990000000002	38.610705000000003	55.443603000000003	55.421337999999999	Заводская	0103000020E61000000100000005000000E92B483316494340F1475167EEB54B40E92B48331649434029B4ACFBC7B84B407940D9942B4E434029B4ACFBC7B84B407940D9942B4E4340F1475167EEB54B40E92B483316494340F1475167EEB54B40
80923	48808	36.003363	36.024284000000002	56.049298999999998	56.040787000000002	Советская	0103000020E610000001000000050000001B82E3326E0042400D8D278238054C401B82E3326E004240DD5CFC6D4F064C4075E8F4BC1B034240DD5CFC6D4F064C4075E8F4BC1B0342400D8D278238054C401B82E3326E0042400D8D278238054C40
80803	47877	35.824013999999998	35.833060000000003	56.045825000000001	56.039906999999999	Парковая	0103000020E610000001000000050000001BB96E4A79E94140D4F02DAC1B054C401BB96E4A79E941406B2BF697DD054C408ACDC7B5A1EA41406B2BF697DD054C408ACDC7B5A1EA4140D4F02DAC1B054C401BB96E4A79E94140D4F02DAC1B054C40
71976	6106	36.107953999999999	36.146509000000002	56.178637999999999	56.163944999999998	Теряевская	0103000020E6100000010000000500000077BCC96FD10D4240DEAB5626FC144C4077BCC96FD10D424053E9279CDD164C40EBC891CEC012424053E9279CDD164C40EBC891CEC0124240DEAB5626FC144C4077BCC96FD10D4240DEAB5626FC144C40
80735	18088	35.894370000000002	35.922344000000002	55.930377	55.910997000000002	Центральная	0103000020E61000000100000005000000034356B77AF2414087E0B88C9BF44B40034356B77AF24140ADF9F19716F74B40B7D4415E0FF64140ADF9F19716F74B40B7D4415E0FF6414087E0B88C9BF44B40034356B77AF2414087E0B88C9BF44B40
71864	17990	35.823312999999999	35.883032999999998	55.871429999999997	55.851500000000001	микрорайон	0103000020E6100000010000000500000092AF045262E94140A245B6F3FDEC4B4092AF045262E941406B60AB048BEF4B40F624B03907F141406B60AB048BEF4B40F624B03907F14140A245B6F3FDEC4B4092AF045262E94140A245B6F3FDEC4B40
71937	12447	36.007593999999997	36.028354	55.987971000000002	55.978569	Крестьянская	0103000020E61000000100000005000000AAD216D7F800424091F0BDBF41FD4B40AAD216D7F8004240BE326FD575FE4B40FB5A971AA1034240BE326FD575FE4B40FB5A971AA103424091F0BDBF41FD4B40AAD216D7F800424091F0BDBF41FD4B40
80796	47920	35.72007	35.740586999999998	56.030402000000002	56.02102	Центральная	0103000020E61000000100000005000000556AF6402BDC4140ED478AC8B0024C40556AF6402BDC4140D3DD7536E4034C40DF6B088ECBDE4140D3DD7536E4034C40DF6B088ECBDE4140ED478AC8B0024C40556AF6402BDC4140ED478AC8B0024C40
74096	5005	35.834938000000001	35.849311	55.915694000000002	55.902495000000002	 Центральная	0103000020E610000001000000050000000518963FDFEA4140DAE6C6F484F34B400518963FDFEA41405C92037635F54B4008910C39B6EC41405C92037635F54B4008910C39B6EC4140DAE6C6F484F34B400518963FDFEA4140DAE6C6F484F34B40
80941	17961	35.983231000000004	35.993732999999999	56.081442000000003	56.071389000000003	Центральная	0103000020E61000000100000005000000EAB46E83DAFD4140A725564623094C40EAB46E83DAFD4140AB4203B16C0A4C405DFA97A432FF4140AB4203B16C0A4C405DFA97A432FF4140A725564623094C40EAB46E83DAFD4140A725564623094C40
80772	49481	35.748313000000003	35.769773999999998	56.075342999999997	56.056835	Центральная	0103000020E61000000100000005000000F9156BB8C8DF41405322895E46074C40F9156BB8C8DF4140C37DE4D6A4094C40D2A755F487E24140C37DE4D6A4094C40D2A755F487E241405322895E46074C40F9156BB8C8DF41405322895E46074C40
80151	4726	35.955841999999997	35.957037	56.029083999999997	56.024591999999998	Школьная	0103000020E610000001000000050000005512D90759FA414022DFA5D425034C405512D90759FA41401E6B4606B9034C40EE073C3080FA41401E6B4606B9034C40EE073C3080FA414022DFA5D425034C405512D90759FA414022DFA5D425034C40
74162	4726	35.926853000000001	35.937983000000003	56.057080999999997	56.054070000000003	Тихая	0103000020E6100000010000000500000089997D1EA3F64140EDD808C4EB064C4089997D1EA3F641408A1C226E4E074C401C9AB2D30FF841408A1C226E4E074C401C9AB2D30FF84140EDD808C4EB064C4089997D1EA3F64140EDD808C4EB064C40
79854	4726	35.919998999999997	35.932862999999998	55.992986000000002	55.991459999999996	Терешковой	0103000020E6100000010000000500000025ADF886C2F5414065A54929E8FE4B4025ADF886C2F5414064B14D2A1AFF4B400053060E68F7414064B14D2A1AFF4B400053060E68F7414065A54929E8FE4B4025ADF886C2F5414065A54929E8FE4B40
80447	4726	35.927159000000003	35.929315000000003	56.067464000000001	56.065604999999998	Текстильщиков	0103000020E6100000010000000500000096986725ADF641401FBAA0BE65084C4096986725ADF6414024D40CA9A2084C4054573ECBF3F6414024D40CA9A2084C4054573ECBF3F641401FBAA0BE65084C4096986725ADF641401FBAA0BE65084C40
4815	4726	35.958860000000001	35.972002000000003	56.036974999999998	56.034610999999998	Советская улица	0103000020E61000000100000005000000A6B8AAECBBFA41407A8A1C226E044C40A6B8AAECBBFA414082E2C798BB044C40C4D2C08F6AFC414082E2C798BB044C40C4D2C08F6AFC41407A8A1C226E044C40A6B8AAECBBFA41407A8A1C226E044C40
79878	4726	35.958860000000001	35.972002000000003	56.036974999999998	56.034610999999998	Советская	0103000020E61000000100000005000000A6B8AAECBBFA41407A8A1C226E044C40A6B8AAECBBFA414082E2C798BB044C40C4D2C08F6AFC414082E2C798BB044C40C4D2C08F6AFC41407A8A1C226E044C40A6B8AAECBBFA41407A8A1C226E044C40
67810	4726	35.932583999999999	35.938952999999998	56.021991	56.019294000000002	Прохоровская улица	0103000020E61000000100000005000000ED629AE95EF741402881CD3978024C40ED629AE95EF7414036E7E099D0024C4094BDA59C2FF8414036E7E099D0024C4094BDA59C2FF841402881CD3978024C40ED629AE95EF741402881CD3978024C40
5646	4726	35.945098000000002	35.959012999999999	56.037272000000002	56.032826	Пролетарская улица	0103000020E61000000100000005000000ECC1A4F8F8F84140B03A72A433044C40ECC1A4F8F8F841403C873254C5044C402CB81FF0C0FA41403C873254C5044C402CB81FF0C0FA4140B03A72A433044C40ECC1A4F8F8F84140B03A72A433044C40
80239	4726	35.958447	35.964367000000003	56.034621000000001	56.025486999999998	Панфилова	0103000020E6100000010000000500000083F92B64AEFA414090BC732843034C4083F92B64AEFA41409E60FF756E044C40BB2BBB6070FB41409E60FF756E044C40BB2BBB6070FB414090BC732843034C4083F92B64AEFA414090BC732843034C40
4866	4726	35.942689999999999	35.949742000000001	56.035285000000002	56.030577999999998	Ново-Солдатский переулок	0103000020E610000001000000050000001422E010AAF8414011FDDAFAE9034C401422E010AAF841400A85083884044C409ED1562591F941400A85083884044C409ED1562591F9414011FDDAFAE9034C401422E010AAF8414011FDDAFAE9034C40
80779	18043	35.709657999999997	35.731020000000001	55.765458000000002	55.756081999999999	Новая	0103000020E6100000010000000500000021ACC612D6DA4140118C834BC7E04B4021ACC612D6DA4140153B1A87FAE14B40685C381092DD4140153B1A87FAE14B40685C381092DD4140118C834BC7E04B4021ACC612D6DA4140118C834BC7E04B40
38986	54699	39.916550000000001	39.997397999999997	53.256546	53.223835000000001	Советская	0103000020E610000001000000050000000C93A98251F543409F5912A0A69C4A400C93A98251F54340B6F5D37FD6A04A40438CD7BCAAFF4340B6F5D37FD6A04A40438CD7BCAAFF43409F5912A0A69C4A400C93A98251F543409F5912A0A69C4A40
38990	54699	39.916550000000001	39.997397999999997	53.256546	53.223835000000001	Московский переулок	0103000020E610000001000000050000000C93A98251F543409F5912A0A69C4A400C93A98251F54340B6F5D37FD6A04A40438CD7BCAAFF4340B6F5D37FD6A04A40438CD7BCAAFF43409F5912A0A69C4A400C93A98251F543409F5912A0A69C4A40
38868	54699	39.916550000000001	39.997397999999997	53.256546	53.223835000000001	Ленина	0103000020E610000001000000050000000C93A98251F543409F5912A0A69C4A400C93A98251F54340B6F5D37FD6A04A40438CD7BCAAFF4340B6F5D37FD6A04A40438CD7BCAAFF43409F5912A0A69C4A400C93A98251F543409F5912A0A69C4A40
39049	54735	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	улица Новоселов	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
39014	54735	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	Шмидта	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
39002	54735	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	Чернышевского	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
39003	54735	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	Радищева	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
38934	54735	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	Первомайская	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
39087	54735	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	Ленина	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
38997	19463	39.500692999999998	39.512182000000003	52.547643999999998	52.541412000000001	Центральная	0103000020E61000000100000005000000062B4EB516C04340BBD408FD4C454A40062B4EB516C04340E1ECD63219464A40C9CC052E8FC14340E1ECD63219464A40C9CC052E8FC14340BBD408FD4C454A40062B4EB516C04340BBD408FD4C454A40
4765	3727	39.511958	39.517617000000001	52.585008999999999	52.584035	улица Хорошавина	0103000020E610000001000000050000007976F9D687C14340145CACA8C14A4A407976F9D687C14340CE6E2D93E14A4A40446D1B4641C24340CE6E2D93E14A4A40446D1B4641C24340145CACA8C14A4A407976F9D687C14340145CACA8C14A4A40
6064	3727	39.586526999999997	39.593722	52.604472999999999	52.592531999999999	улица Фрунзе	0103000020E61000000100000005000000499C155113CB4340AFEAAC16D84B4A40499C155113CB434052280B5F5F4D4A4036751E15FFCB434052280B5F5F4D4A4036751E15FFCB4340AFEAAC16D84B4A40499C155113CB4340AFEAAC16D84B4A40
5887	3727	39.548186999999999	39.553019999999997	52.596082000000003	52.593111999999998	улица Студенческий Городок	0103000020E61000000100000005000000D28BDAFD2AC64340BD6E1118EB4B4A40D28BDAFD2AC64340FDDD3B6A4C4C4A405704FF5BC9C64340FDDD3B6A4C4C4A405704FF5BC9C64340BD6E1118EB4B4A40D28BDAFD2AC64340BD6E1118EB4B4A40
5747	3727	39.511805000000003	39.536724	52.596449	52.576456	улица Стаханова	0103000020E61000000100000005000000F37684D382C143409FCA694FC9494A40F37684D382C14340AF5DDA70584C4A40397D3D5FB3C44340AF5DDA70584C4A40397D3D5FB3C443409FCA694FC9494A40F37684D382C143409FCA694FC9494A40
5388	3727	39.755696999999998	39.768740999999999	52.528247999999998	52.517048000000003	улица Писарева	0103000020E61000000100000005000000B857E6ADBAE043402A3BFDA02E424A40B857E6ADBAE04340B51666A19D434A40130CE71A66E24340B51666A19D434A40130CE71A66E243402A3BFDA02E424A40B857E6ADBAE043402A3BFDA02E424A40
3605	3727	39.608787	39.618820999999997	52.582217999999997	52.580964999999999	улица Парковая	0103000020E610000001000000050000006F9D7FBBECCD4340718FA50F5D4A4A406F9D7FBBECCD43403E92921E864A4A40FC89CA8635CF43403E92921E864A4A40FC89CA8635CF4340718FA50F5D4A4A406F9D7FBBECCD4340718FA50F5D4A4A40
5914	3727	39.547817999999999	39.568713000000002	52.605200000000004	52.590535000000003	улица Папина	0103000020E610000001000000050000007F1475E61EC643405A12A0A6964B4A407F1475E61EC6434005C58F31774D4A40B0E76B96CBC8434005C58F31774D4A40B0E76B96CBC843405A12A0A6964B4A407F1475E61EC643405A12A0A6964B4A40
5093	3727	39.569153	39.574876000000003	52.542758999999997	52.539051000000001	улица Молодежная	0103000020E61000000100000005000000CCB56801DAC8434024F0879FFF444A40CCB56801DAC84340094E7D2079454A40AEA0698995C94340094E7D2079454A40AEA0698995C9434024F0879FFF444A40CCB56801DAC8434024F0879FFF444A40
15345	3727	39.717177999999997	39.752004999999997	52.660594000000003	52.644188	улица Ленина	0103000020E6100000010000000500000091B41B7DCCDB4340E23C9CC074524A4091B41B7DCCDB434088F71C588E544A40D8B628B341E0434088F71C588E544A40D8B628B341E04340E23C9CC074524A4091B41B7DCCDB4340E23C9CC074524A40
15723	3727	39.540864999999997	39.58296	52.617285000000003	52.605156000000001	улица Космонавтов	0103000020E61000000100000005000000884677103BC54340357D76C0754D4A40884677103BC54340DBA7E331034F4A402670EB6E9ECA4340DBA7E331034F4A402670EB6E9ECA4340357D76C0754D4A40884677103BC54340357D76C0754D4A40
4313	3727	39.586858999999997	39.589418999999999	52.543044000000002	52.530631	улица Ильича	0103000020E610000001000000050000007F2E1A321ECB4340349F73B7EB434A407F2E1A321ECB4340FF243E7782454A400D52F01472CB4340FF243E7782454A400D52F01472CB4340349F73B7EB434A407F2E1A321ECB4340349F73B7EB434A40
38826	3727	39.564912999999997	39.569791000000002	52.539335999999999	52.536158999999998	улица Ибаррури	0103000020E61000000100000005000000E90AB6114FC84340603AADDBA0444A40E90AB6114FC8434019C748F608454A400F4757E9EEC8434019C748F608454A400F4757E9EEC84340603AADDBA0444A40E90AB6114FC84340603AADDBA0444A40
6080	3727	39.579160999999999	39.594557999999999	52.595014999999997	52.582476	улица 50 лет НЛМК	0103000020E61000000100000005000000300F99F221CA43403A5AD5928E4A4A40300F99F221CA434091D09673294C4A409FC9FE791ACC434091D09673294C4A409FC9FE791ACC43403A5AD5928E4A4A40300F99F221CA43403A5AD5928E4A4A40
5799	3727	39.536633999999999	39.573842999999997	52.602657000000001	52.579470999999998	проспект Победы	0103000020E61000000100000005000000F9F5436CB0C443407EFD101B2C4A4A40F9F5436CB0C443404DDA54DD234D4A40EE04FBAF73C943404DDA54DD234D4A40EE04FBAF73C943407EFD101B2C4A4A40F9F5436CB0C443407EFD101B2C4A4A40
5494	3727	39.615740000000002	39.622298000000001	52.590069999999997	52.572609	проспект Мира	0103000020E61000000100000005000000666B7D91D0CE4340983270404B494A40666B7D91D0CE4340E42CEC69874B4A40E02EFB75A7CF4340E42CEC69874B4A40E02EFB75A7CF4340983270404B494A40666B7D91D0CE4340983270404B494A40
39026	3727	39.468246000000001	39.493461000000003	52.586809000000002	52.571229000000002	проезд Ударников	0103000020E61000000100000005000000CD3D247CEFBB43406EC328081E494A40CD3D247CEFBB4340CEFFAB8E1C4B4A40FD6CE4BA29BF4340CEFFAB8E1C4B4A40FD6CE4BA29BF43406EC328081E494A40CD3D247CEFBB43406EC328081E494A40
5833	3727	39.539715999999999	39.54533	52.589402999999997	52.585146000000002	проезд Сиреневый	0103000020E610000001000000050000006090F46915C543404FB16A10E64A4A406090F46915C543400795B88E714B4A408BC3995FCDC543400795B88E714B4A408BC3995FCDC543404FB16A10E64A4A406090F46915C543404FB16A10E64A4A40
38957	3727	39.511454999999998	39.522333000000003	52.601618000000002	52.598132999999997	проезд Кувшинова	0103000020E610000001000000050000001630815B77C1434045D4449F8F4C4A401630815B77C14340AC5791D1014D4A40904FC8CEDBC24340AC5791D1014D4A40904FC8CEDBC2434045D4449F8F4C4A401630815B77C1434045D4449F8F4C4A40
5569	3727	39.589832999999999	39.593542999999997	52.528719000000002	52.510351	проезд Ильича	0103000020E61000000100000005000000008DD2A57FCB43408E3D7B2E53414A40008DD2A57FCB43400DE36E10AD434A4086E28E37F9CB43400DE36E10AD434A4086E28E37F9CB43408E3D7B2E53414A40008DD2A57FCB43408E3D7B2E53414A40
6561	3727	39.547558000000002	39.560133999999998	52.633701000000002	52.625770000000003	проезд Боевой	0103000020E61000000100000005000000E3546B6116C64340B2683A3B19504A40E3546B6116C64340A438471D1D514A4057B08D78B2C74340A438471D1D514A4057B08D78B2C74340B2683A3B19504A40E3546B6116C64340B2683A3B19504A40
38877	3727	39.380229	39.814968	52.714798999999999	52.492085000000003	пр. Сержанта Кувшинова	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
6160	3727	39.584955000000001	39.587972999999998	52.599955000000001	52.597844000000002	площадь Торговая	0103000020E61000000100000005000000DB5031CEDFCA43400F0EF626864C4A40DB5031CEDFCA43402D095053CB4C4A402BF702B342CB43402D095053CB4C4A402BF702B342CB43400F0EF626864C4A40DB5031CEDFCA43400F0EF626864C4A40
5469	3727	39.611401000000001	39.615946999999998	52.594436000000002	52.589987999999998	площадь Мира	0103000020E61000000100000005000000F0DE516342CE434027840EBA844B4A40F0DE516342CE434054C8957A164C4A40DF88EE59D7CE434054C8957A164C4A40DF88EE59D7CE434027840EBA844B4A40F0DE516342CE434027840EBA844B4A40
6735	3727	39.656092000000001	39.659542000000002	52.638373999999999	52.637405999999999	площадь Константиновой	0103000020E61000000100000005000000689599D2FAD343401823128596514A40689599D2FAD34340F04E3E3DB6514A40522B4CDF6BD44340F04E3E3DB6514A40522B4CDF6BD443401823128596514A40689599D2FAD343401823128596514A40
5688	3727	39.519799999999996	39.522503999999998	52.580916000000002	52.580779	переулок Учебный	0103000020E61000000100000005000000FB3A70CE88C243400F9A5DF7564A4A40FB3A70CE88C2434090DC9A745B4A4A40BC033C69E1C2434090DC9A745B4A4A40BC033C69E1C243400F9A5DF7564A4A40FB3A70CE88C243400F9A5DF7564A4A40
5724	3727	39.516565999999997	39.525503999999998	52.592565	52.588904999999997	бульвар Шубина	0103000020E61000000100000005000000DE1CAED51EC24340B6B9313D614B4A40DE1CAED51EC243408BE07F2BD94B4A4066F50EB743C343408BE07F2BD94B4A4066F50EB743C34340B6B9313D614B4A40DE1CAED51EC24340B6B9313D614B4A40
5773	3727	39.523699000000001	39.532062000000003	52.587712000000003	52.585523000000002	бульвар Есенина	0103000020E6100000010000000500000055F99E9108C343402507EC6AF24A4A4055F99E9108C34340BFBB95253A4B4A40E1B88C9B1AC44340BFBB95253A4B4A40E1B88C9B1AC443402507EC6AF24A4A4055F99E9108C343402507EC6AF24A4A40
39074	3727	39.560152000000002	39.567258000000002	52.600453000000002	52.597472000000003	Юных Натуралистов	0103000020E61000000100000005000000FE648C0FB3C743404B2366F6794C4A40FE648C0FB3C743407EE4D6A4DB4C4A407B32FFE89BC843407EE4D6A4DB4C4A407B32FFE89BC843404B2366F6794C4A40FE648C0FB3C743404B2366F6794C4A40
39080	3727	39.438277999999997	39.482053000000001	52.593566000000003	52.576571000000001	Юношеская	0103000020E610000001000000050000003447567E19B8434038691A14CD494A403447567E19B843403F027FF8F94B4A4027F8A6E9B3BD43403F027FF8F94B4A4027F8A6E9B3BD434038691A14CD494A403447567E19B8434038691A14CD494A40
39037	3727	39.788781999999998	39.807493999999998	52.534427999999998	52.530543999999999	Энергостроителей	0103000020E6100000010000000500000034D6FECEF6E44340658BA4DDE8434A4034D6FECEF6E443408908FF2268444A40ADDBA0F65BE743408908FF2268444A40ADDBA0F65BE74340658BA4DDE8434A4034D6FECEF6E44340658BA4DDE8434A40
39253	3727	39.584001999999998	39.587038999999997	52.595393000000001	52.594839999999998	Школьная	0103000020E610000001000000050000003866D993C0CA4340232D95B7234C4A403866D993C0CA434038A27BD6354C4A40FF3C0D1824CB434038A27BD6354C4A40FF3C0D1824CB4340232D95B7234C4A403866D993C0CA4340232D95B7234C4A40
39019	3727	39.499884000000002	39.511814000000001	52.582695000000001	52.575975	Шерстобитова	0103000020E6100000010000000500000097E5EB32FCBF434024287E8CB9494A4097E5EB32FCBF43407845F0BF954A4A4046D1031F83C143407845F0BF954A4A4046D1031F83C1434024287E8CB9494A4097E5EB32FCBF434024287E8CB9494A40
39052	3727	39.548034000000001	39.571919999999999	52.619039999999998	52.610039999999998	Циолковского	0103000020E610000001000000050000004C8C65FA25C643403CA06CCA154E4A404C8C65FA25C643403A75E5B33C4F4A40D3F6AFAC34C943403A75E5B33C4F4A40D3F6AFAC34C943403CA06CCA154E4A404C8C65FA25C643403CA06CCA154E4A40
39261	3727	39.740309000000003	39.751448000000003	52.535226999999999	52.530521999999998	Центральная	0103000020E610000001000000050000009DF7FF71C2DE43407DE71725E8434A409DF7FF71C2DE4340D5777E5182444A408352B4722FE04340D5777E5182444A408352B4722FE043407DE71725E8434A409DF7FF71C2DE43407DE71725E8434A40
39264	3727	39.625684	39.630220999999999	52.596781999999997	52.593204999999998	Фурманова	0103000020E61000000100000005000000B3D0CE6916D043406E693524EE4B4A40B3D0CE6916D04340B56B425A634C4A404F20EC14ABD04340B56B425A634C4A404F20EC14ABD043406E693524EE4B4A40B3D0CE6916D043406E693524EE4B4A40
39053	3727	39.543047999999999	39.548726000000002	52.606431000000001	52.602361999999999	Филипченко	0103000020E610000001000000050000004014CC9882C54340342DB1321A4D4A404014CC9882C54340EA23F0879F4D4A40823B50A73CC64340EA23F0879F4D4A40823B50A73CC64340342DB1321A4D4A404014CC9882C54340342DB1321A4D4A40
39056	3727	39.653441999999998	39.662649999999999	52.645488	52.634920000000001	Ушинского	0103000020E610000001000000050000009AEAC9FCA3D34340C5C9FD0E45514A409AEAC9FCA3D34340F0FACC599F524A40E25817B7D1D44340F0FACC599F524A40E25817B7D1D44340C5C9FD0E45514A409AEAC9FCA3D34340C5C9FD0E45514A40
39081	3727	39.493461000000003	39.508642999999999	52.571229000000002	52.567233999999999	Ударников	0103000020E61000000100000005000000FD6CE4BA29BF4340F296AB1F9B484A40FD6CE4BA29BF43406EC328081E494A406F2BBD361BC143406EC328081E494A406F2BBD361BC14340F296AB1F9B484A40FD6CE4BA29BF4340F296AB1F9B484A40
39011	3727	39.548186999999999	39.553019999999997	52.596082000000003	52.593111999999998	Студенческий городок	0103000020E61000000100000005000000D28BDAFD2AC64340BD6E1118EB4B4A40D28BDAFD2AC64340FDDD3B6A4C4C4A405704FF5BC9C64340FDDD3B6A4C4C4A405704FF5BC9C64340BD6E1118EB4B4A40D28BDAFD2AC64340BD6E1118EB4B4A40
39073	3727	39.548186999999999	39.553019999999997	52.596082000000003	52.593111999999998	Студенческий Городок	0103000020E61000000100000005000000D28BDAFD2AC64340BD6E1118EB4B4A40D28BDAFD2AC64340FDDD3B6A4C4C4A405704FF5BC9C64340FDDD3B6A4C4C4A405704FF5BC9C64340BD6E1118EB4B4A40D28BDAFD2AC64340BD6E1118EB4B4A40
39062	3727	39.61627	39.656064999999998	52.632733999999999	52.618132000000003	Студеновская 	0103000020E61000000100000005000000C2C073EFE1CE4340384E0AF31E4F4A40C2C073EFE1CE43409C887E6DFD504A406E861BF0F9D343409C887E6DFD504A406E861BF0F9D34340384E0AF31E4F4A40C2C073EFE1CE4340384E0AF31E4F4A40
39033	3727	39.511805000000003	39.536724	52.596449	52.576456	Стаханова	0103000020E61000000100000005000000F37684D382C143409FCA694FC9494A40F37684D382C14340AF5DDA70584C4A40397D3D5FB3C44340AF5DDA70584C4A40397D3D5FB3C443409FCA694FC9494A40F37684D382C143409FCA694FC9494A40
39531	3727	39.556550000000001	39.581766000000002	52.628120000000003	52.625107999999997	Совхозная	0103000020E610000001000000050000005E4BC8073DC74340E63BF88903504A405E4BC8073DC7434055FB743C66504A405EF6EB4E77CA434055FB743C66504A405EF6EB4E77CA4340E63BF88903504A405E4BC8073DC74340E63BF88903504A40
39064	3727	39.726106999999999	39.729655000000001	52.674104999999997	52.656551999999998	Советская 	0103000020E61000000100000005000000C632FD12F1DC4340CB0F5CE509544A40C632FD12F1DC4340F888981249564A40732EC55565DD4340F888981249564A40732EC55565DD4340CB0F5CE509544A40C632FD12F1DC4340CB0F5CE509544A40
39070	3727	39.660764	39.662191999999997	52.590983999999999	52.58775	Силикатная	0103000020E61000000100000005000000E42F2DEA93D44340AC1C5A643B4B4A40E42F2DEA93D44340C93A1C5DA54B4A401FD61BB5C2D44340C93A1C5DA54B4A401FD61BB5C2D44340AC1C5A643B4B4A40E42F2DEA93D44340AC1C5A643B4B4A40
39075	3727	39.586157999999998	39.597602999999999	52.615831	52.615344	Семашко	0103000020E61000000100000005000000F624B03907CB434019E59997C34E4A40F624B03907CB4340766EDA8CD34E4A40E97E4E417ECC4340766EDA8CD34E4A40E97E4E417ECC434019E59997C34E4A40F624B03907CB434019E59997C34E4A40
39142	3727	39.380229	39.814968	52.714798999999999	52.492085000000003	Северный рудник	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
38998	3727	39.731138000000001	39.741405	52.668720999999998	52.662543999999997	Ракитная	0103000020E61000000100000005000000726E13EE95DD43409C14E63DCE544A40726E13EE95DD4340FF9254A698554A40A20BEA5BE6DE4340FF9254A698554A40A20BEA5BE6DE43409C14E63DCE544A40726E13EE95DD43409C14E63DCE544A40
39086	3727	39.612685999999997	39.628604000000003	52.578420999999999	52.576357999999999	Прокатная	0103000020E61000000100000005000000C85BAE7E6CCE4340DC645419C6494A40C85BAE7E6CCE4340E92807B3094A4A4041118B1876D04340E92807B3094A4A4041118B1876D04340DC645419C6494A40C85BAE7E6CCE4340DC645419C6494A40
39071	3727	39.725082999999998	39.729070999999998	52.563993000000004	52.561923999999998	Пришкольная	0103000020E610000001000000050000005AF10D85CFDC4340336B2920ED474A405AF10D85CFDC4340231631EC30484A4023BBD23252DD4340231631EC30484A4023BBD23252DD4340336B2920ED474A405AF10D85CFDC4340336B2920ED474A40
39000	3727	39.724615999999997	39.738503999999999	52.557856000000001	52.549944000000004	Привокзальная	0103000020E6100000010000000500000044149337C0DC4340D350A39064464A4044149337C0DC43404EF04DD367474A408BFB8F4C87DE43404EF04DD367474A408BFB8F4C87DE4340D350A39064464A4044149337C0DC4340D350A39064464A40
39255	3727	39.47766	39.480310000000003	52.580829000000001	52.578853000000002	Почтовая	0103000020E61000000100000005000000BE4D7FF623BD43408318E8DA174A4A40BE4D7FF623BD4340C1C8CB9A584A4A408CF84ECC7ABD4340C1C8CB9A584A4A408CF84ECC7ABD43408318E8DA174A4A40BE4D7FF623BD43408318E8DA174A4A40
39040	3727	39.505813000000003	39.510772000000003	52.609426999999997	52.603707	Политехническая 	0103000020E610000001000000050000002272FA7ABEC04340E2AE5E45464D4A402272FA7ABEC04340522635B4014E4A4034DB15FA60C14340522635B4014E4A4034DB15FA60C14340E2AE5E45464D4A402272FA7ABEC04340E2AE5E45464D4A40
39066	3727	39.612245999999999	39.619593999999999	52.578662000000001	52.577682000000003	Полины Осипенко	0103000020E61000000100000005000000AC8DB1135ECE434073BED87BF1494A40AC8DB1135ECE43400FB8AE98114A4A401F662FDB4ECF43400FB8AE98114A4A401F662FDB4ECF434073BED87BF1494A40AC8DB1135ECE434073BED87BF1494A40
39084	3727	39.593398999999998	39.607835000000001	52.617783000000003	52.605795999999998	Плеханова	0103000020E61000000100000005000000533D997FF4CB434018062CB98A4D4A40533D997FF4CB43402C836A83134F4A409D2E8B89CDCD43402C836A83134F4A409D2E8B89CDCD434018062CB98A4D4A40533D997FF4CB434018062CB98A4D4A40
39061	3727	39.574489	39.602246999999998	52.603575999999997	52.602634999999999	Первомайская	0103000020E61000000100000005000000B47405DB88C943406536C824234D4A40B47405DB88C94340435376FA414D4A409B8E006E16CD4340435376FA414D4A409B8E006E16CD43406536C824234D4A40B47405DB88C943406536C824234D4A40
39047	3727	39.547817999999999	39.568713000000002	52.605200000000004	52.590535000000003	Папина	0103000020E610000001000000050000007F1475E61EC643405A12A0A6964B4A407F1475E61EC6434005C58F31774D4A40B0E76B96CBC8434005C58F31774D4A40B0E76B96CBC843405A12A0A6964B4A407F1475E61EC643405A12A0A6964B4A40
39025	3727	39.580283000000001	39.604402999999998	52.602176	52.601349999999996	Октябрьская	0103000020E610000001000000050000005FB69DB646CA43408CB96B09F94C4A405FB69DB646CA4340D237691A144D4A40594DD7135DCD4340D237691A144D4A40594DD7135DCD43408CB96B09F94C4A405FB69DB646CA43408CB96B09F94C4A40
39254	3727	39.511085999999999	39.514023999999999	52.633564	52.630307000000002	Одоевского	0103000020E61000000100000005000000C3B81B446BC143404EB857E6AD504A40C3B81B446BC1434023F609A018514A40F7ADD689CBC1434023F609A018514A40F7ADD689CBC143404EB857E6AD504A40C3B81B446BC143404EB857E6AD504A40
39090	3727	39.607781000000003	39.622576000000002	52.581305	52.579273999999998	Невского	0103000020E61000000100000005000000AA108FC4CBCD434028B682A6254A4A40AA108FC4CBCD43402A00C633684A4A4023A30392B0CF43402A00C633684A4A4023A30392B0CF434028B682A6254A4A40AA108FC4CBCD434028B682A6254A4A40
39077	3727	39.487164	39.547674999999998	52.618827000000003	52.581736999999997	Московская	0103000020E61000000100000005000000EFE4D3635BBE4340C3EFA65B764A4A40EFE4D3635BBE4340DF701FB9354F4A401CEBE2361AC64340DF701FB9354F4A401CEBE2361AC64340C3EFA65B764A4A40EFE4D3635BBE4340C3EFA65B764A4A40
39044	3727	39.795951000000002	39.804080999999996	52.531101999999997	52.528055999999999	Моршанская	0103000020E61000000100000005000000F81BEDB8E1E54340713AC95697434A40F81BEDB8E1E543408B6B7C26FB434A40E02A4F20ECE643408B6B7C26FB434A40E02A4F20ECE64340713AC95697434A40F81BEDB8E1E54340713AC95697434A40
39519	3727	39.569153	39.574876000000003	52.542758999999997	52.539051000000001	Молодежная	0103000020E61000000100000005000000CCB56801DAC8434024F0879FFF444A40CCB56801DAC84340094E7D2079454A40AEA0698995C94340094E7D2079454A40AEA0698995C9434024F0879FFF444A40CCB56801DAC8434024F0879FFF444A40
39036	3727	39.567258000000002	39.582349999999998	52.601475000000001	52.595731999999998	Мичурина	0103000020E610000001000000050000007B32FFE89BC84340209738F2404C4A407B32FFE89BC84340492EFF21FD4C4A40AD69DE718ACA4340492EFF21FD4C4A40AD69DE718ACA4340209738F2404C4A407B32FFE89BC84340209738F2404C4A40
39072	3727	39.552560999999997	39.567608	52.593012999999999	52.583472	Механизаторов	0103000020E61000000100000005000000C405A051BAC64340DC10E335AF4A4A40C405A051BAC643402A8D98D9E74B4A4057790261A7C843402A8D98D9E74B4A4057790261A7C84340DC10E335AF4A4A40C405A051BAC64340DC10E335AF4A4A40
39057	3727	39.521048999999998	39.547817999999999	52.590535000000003	52.578113999999999	Меркулова	0103000020E61000000100000005000000874ECFBBB1C243400CAEB9A3FF494A40874ECFBBB1C243405A12A0A6964B4A407F1475E61EC643405A12A0A6964B4A407F1475E61EC643400CAEB9A3FF494A40874ECFBBB1C243400CAEB9A3FF494A40
39048	3727	39.583544000000003	39.584972999999998	52.617170000000002	52.598849999999999	Максима Горького	0103000020E6100000010000000500000076E3DD91B1CA4340D49AE61DA74C4A4076E3DD91B1CA43404209336DFF4E4A4081053065E0CA43404209336DFF4E4A4081053065E0CA4340D49AE61DA74C4A4076E3DD91B1CA4340D49AE61DA74C4A40
39525	3727	39.539904	39.543165000000002	52.608651000000002	52.607087	Луговая	0103000020E61000000100000005000000637D03931BC54340D369DD06B54D4A40637D03931BC54340BFD6A546E84D4A407AAA436E86C54340BFD6A546E84D4A407AAA436E86C54340D369DD06B54D4A40637D03931BC54340D369DD06B54D4A40
38942	3727	39.584488	39.595249000000003	52.605823999999998	52.605490000000003	Л. Толстого	0103000020E61000000100000005000000C573B680D0CA43400C0742B2804D4A40C573B680D0CA4340E2900DA48B4D4A4005FD851E31CC4340E2900DA48B4D4A4005FD851E31CC43400C0742B2804D4A40C573B680D0CA43400C0742B2804D4A40
39022	3727	39.562945999999997	39.57546	52.546312999999998	52.538108999999999	Краснознаменная	0103000020E61000000100000005000000FEB4519D0EC84340755776C1E0444A40FEB4519D0EC8434098309A95ED454A40FD135CACA8C9434098309A95ED454A40FD135CACA8C94340755776C1E0444A40FEB4519D0EC84340755776C1E0444A40
39058	3727	39.572360000000003	39.581254000000001	52.548290000000001	52.542648999999997	Краснозаводская	0103000020E61000000100000005000000F0C4AC1743C94340821ABE8575454A40F0C4AC1743C94340A75CE15D2E464A40A855F48766CA4340A75CE15D2E464A40A855F48766CA4340821ABE8575454A40F0C4AC1743C94340821ABE8575454A40
39259	3727	39.540864999999997	39.58296	52.617285000000003	52.605156000000001	Космонавтов	0103000020E61000000100000005000000884677103BC54340357D76C0754D4A40884677103BC54340DBA7E331034F4A402670EB6E9ECA4340DBA7E331034F4A402670EB6E9ECA4340357D76C0754D4A40884677103BC54340357D76C0754D4A40
39051	3727	39.540864999999997	39.58296	52.617285000000003	52.605156000000001	Космонавтов	0103000020E61000000100000005000000884677103BC54340357D76C0754D4A40884677103BC54340DBA7E331034F4A402670EB6E9ECA4340DBA7E331034F4A402670EB6E9ECA4340357D76C0754D4A40884677103BC54340357D76C0754D4A40
39091	3727	39.574013000000001	39.583976	52.545470000000002	52.536037999999998	Коммунистическая	0103000020E610000001000000050000004B3D0B4279C94340E5B4A7E49C444A404B3D0B4279C943407D7901F6D1454A400FD3BEB9BFCA43407D7901F6D1454A400FD3BEB9BFCA4340E5B4A7E49C444A404B3D0B4279C94340E5B4A7E49C444A40
39020	3727	39.597045999999999	39.611724000000002	52.618056000000003	52.609493000000001	Интернациональная	0103000020E61000000100000005000000931ADA006CCC43400A12DBDD034E4A40931ADA006CCC43405D8C81751C4F4A40D316D7F84CCE43405D8C81751C4F4A40D316D7F84CCE43400A12DBDD034E4A40931ADA006CCC43400A12DBDD034E4A40
39094	3727	39.586858999999997	39.589418999999999	52.543044000000002	52.530631	Ильича	0103000020E610000001000000050000007F2E1A321ECB4340349F73B7EB434A407F2E1A321ECB4340FF243E7782454A400D52F01472CB4340FF243E7782454A400D52F01472CB4340349F73B7EB434A407F2E1A321ECB4340349F73B7EB434A40
38846	3727	39.380229	39.814968	52.714798999999999	52.492085000000003	И.В. Шкатова	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
39045	3727	39.61609	39.667940999999999	52.590091999999999	52.574491000000002	Зои Космодемьянской	0103000020E6100000010000000500000042B28009DCCE4340556CCCEB88494A4042B28009DCCE4340CCD07822884B4A402A5437177FD54340CCD07822884B4A402A5437177FD54340556CCCEB88494A4042B28009DCCE4340556CCCEB88494A40
39059	3727	39.597566999999998	39.601421000000002	52.616301	52.609783	Зегеля	0103000020E610000001000000050000009C1551137DCC434011548D5E0D4E4A409C1551137DCC4340FDBE7FF3E24E4A405610035DFBCC4340FDBE7FF3E24E4A405610035DFBCC434011548D5E0D4E4A409C1551137DCC434011548D5E0D4E4A40
39054	3727	39.538277999999998	39.553576999999997	52.608935000000002	52.600349000000001	Звездная	0103000020E610000001000000050000000114234BE6C44340D9976C3CD84C4A400114234BE6C44340E4310395F14D4A40AD68739CDBC64340E4310395F14D4A40AD68739CDBC64340D9976C3CD84C4A400114234BE6C44340D9976C3CD84C4A40
39082	3727	39.556173000000001	39.564993999999999	52.630656999999999	52.628163999999998	Железнякова	0103000020E6100000010000000500000088F546AD30C7434024438EAD67504A4088F546AD30C743402AFF5A5EB9504A40D63730B951C843402AFF5A5EB9504A40D63730B951C8434024438EAD67504A4088F546AD30C7434024438EAD67504A40
39032	3727	39.624274	39.636257000000001	52.624178999999998	52.621287000000002	Елецкая	0103000020E610000001000000050000001EDFDE35E8CF434009371955864F4A401EDFDE35E8CF4340CCECF318E54F4A40F06C8FDE70D14340CCECF318E54F4A40F06C8FDE70D1434009371955864F4A401EDFDE35E8CF434009371955864F4A40
39083	3727	39.638755000000003	39.652194000000001	52.642330000000001	52.637045999999998	Дружбы	0103000020E6100000010000000500000008944DB9C2D1434018062CB98A514A4008944DB9C2D14340AE9E93DE37524A40DF52CE177BD34340AE9E93DE37524A40DF52CE177BD3434018062CB98A514A4008944DB9C2D1434018062CB98A514A40
39089	3727	39.61795	39.618775999999997	52.589177999999997	52.586956999999998	Дзержинского	0103000020E61000000100000005000000174850FC18CF434042942F68214B4A40174850FC18CF4340E7C2482F6A4B4A405CC64D0D34CF4340E7C2482F6A4B4A405CC64D0D34CF434042942F68214B4A40174850FC18CF434042942F68214B4A40
39055	3727	39.469197999999999	39.479196000000002	52.584144999999999	52.580992999999999	Детская	0103000020E610000001000000050000009FAC18AE0EBC43403B1A87FA5D4A4A409FAC18AE0EBC43409B8F6B43C54A4A40E02F664B56BD43409B8F6B43C54A4A40E02F664B56BD43403B1A87FA5D4A4A409FAC18AE0EBC43403B1A87FA5D4A4A40
39050	3727	39.562685000000002	39.576231999999997	52.593839000000003	52.586913000000003	Депутатская 	0103000020E610000001000000050000009279E40F06C84340734C16F71F4B4A409279E40F06C84340700B96EA024C4A404F745DF8C1C94340700B96EA024C4A404F745DF8C1C94340734C16F71F4B4A409279E40F06C84340734C16F71F4B4A40
39041	3727	39.637676999999996	39.644934999999997	52.642532000000003	52.639400999999999	Гражданская	0103000020E61000000100000005000000A83462669FD14340CD0358E4D7514A40A83462669FD143401651137D3E524A40DB85E63A8DD243401651137D3E524A40DB85E63A8DD24340CD0358E4D7514A40A83462669FD14340CD0358E4D7514A40
38944	3727	39.380229	39.814968	52.714798999999999	52.492085000000003	Германа Титова	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
39012	3727	39.547674999999998	39.616368999999999	52.623190000000001	52.616826000000003	Гагарина	0103000020E610000001000000050000001CEBE2361AC6434048A98427F44E4A401CEBE2361AC64340DD989EB0C44F4A4055A2EC2DE5CE4340DD989EB0C44F4A4055A2EC2DE5CE434048A98427F44E4A401CEBE2361AC6434048A98427F44E4A40
39063	3727	39.547674999999998	39.616368999999999	52.623190000000001	52.616826000000003	Гагарина	0103000020E610000001000000050000001CEBE2361AC6434048A98427F44E4A401CEBE2361AC64340DD989EB0C44F4A4055A2EC2DE5CE4340DD989EB0C44F4A4055A2EC2DE5CE434048A98427F44E4A401CEBE2361AC6434048A98427F44E4A40
39508	3727	39.547674999999998	39.616368999999999	52.623190000000001	52.616826000000003	Гагарина	0103000020E610000001000000050000001CEBE2361AC6434048A98427F44E4A401CEBE2361AC64340DD989EB0C44F4A4055A2EC2DE5CE4340DD989EB0C44F4A4055A2EC2DE5CE434048A98427F44E4A401CEBE2361AC6434048A98427F44E4A40
39046	3727	39.583257000000003	39.606316999999997	52.541213999999997	52.539358	Волгоградская	0103000020E61000000100000005000000E014562AA8CA4340016BD5AE09454A40E014562AA8CA43409411178046454A402101A3CB9BCD43409411178046454A402101A3CB9BCD4340016BD5AE09454A40E014562AA8CA4340016BD5AE09454A40
39078	3727	39.529519999999998	39.538539	52.609313	52.600211999999999	Вермишева	0103000020E61000000100000005000000F949B54FC7C3434058552FBFD34C4A40F949B54FC7C343408A03E8F7FD4D4A406E4F90D8EEC443408A03E8F7FD4D4A406E4F90D8EEC4434058552FBFD34C4A40F949B54FC7C3434058552FBFD34C4A40
38949	3727	39.380229	39.814968	52.714798999999999	52.492085000000003	В. Терешковой	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
39067	3727	39.665686000000001	39.695006999999997	52.655749	52.635783000000004	Баумана	0103000020E61000000100000005000000D9B3E73235D54340282D5C5661514A40D9B3E73235D543403EB14E95EF534A40DBBE47FDF5D843403EB14E95EF534A40DBBE47FDF5D84340282D5C5661514A40D9B3E73235D54340282D5C5661514A40
38994	3727	39.665489000000001	39.676017000000002	52.640389999999996	52.636898000000002	Арсеньева	0103000020E61000000100000005000000836C59BE2ED54340A471A8DF85514A40836C59BE2ED54340BC57AD4CF8514A4020459DB987D64340BC57AD4CF8514A4020459DB987D64340A471A8DF85514A40836C59BE2ED54340A471A8DF85514A40
39088	3727	39.619647999999998	39.624319	52.589320000000001	52.576681000000001	Адмирала Макарова	0103000020E6100000010000000500000012842BA050CF4340BF9CD9AED0494A4012842BA050CF43407A7077D66E4B4A40BEA25BAFE9CF43407A7077D66E4B4A40BEA25BAFE9CF4340BF9CD9AED0494A4012842BA050CF4340BF9CD9AED0494A40
38838	3727	39.537236	39.545276000000001	52.608454000000002	52.604734999999998	9 микрорайон	0103000020E61000000100000005000000EF1D3526C4C443408FDFDBF4674D4A40EF1D3526C4C44340698F17D2E14D4A4098A59D9ACBC54340698F17D2E14D4A4098A59D9ACBC543408FDFDBF4674D4A40EF1D3526C4C443408FDFDBF4674D4A40
39035	3727	39.380229	39.814968	52.714798999999999	52.492085000000003	8 Марта	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
39060	3727	39.380229	39.814968	52.714798999999999	52.492085000000003	50 лет НЛМК	0103000020E61000000100000005000000D2FE0758ABB0434014ED2AA4FC3E4A40D2FE0758ABB04340541B9C887E5B4A40ADA415DF50E84340541B9C887E5B4A40ADA415DF50E8434014ED2AA4FC3E4A40D2FE0758ABB0434014ED2AA4FC3E4A40
39108	3727	39.717177999999997	39.752004999999997	52.660594000000003	52.644188	 Ленина	0103000020E6100000010000000500000091B41B7DCCDB4340E23C9CC074524A4091B41B7DCCDB434088F71C588E544A40D8B628B341E0434088F71C588E544A40D8B628B341E04340E23C9CC074524A4091B41B7DCCDB4340E23C9CC074524A40
39007	18875	39.482951	39.511383000000002	52.527650999999999	52.520395999999998	Гурьева	0103000020E6100000010000000500000006499F56D1BD43400F7C0C569C424A4006499F56D1BD4340D15966118A434A407D5D86FF74C14340D15966118A434A407D5D86FF74C143400F7C0C569C424A4006499F56D1BD43400F7C0C569C424A40
38879	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Шоссейный проезд	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
38975	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Школьная	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
38971	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Шахрая	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
39118	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Тургенева	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
38860	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Студенческая	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
39239	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Привокзальная	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
38932	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Первомайская	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
38933	54697	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	 Антонова	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
39024	54743	38.906412000000003	38.948416999999999	52.402214999999998	52.375751000000001	Степанищева	0103000020E61000000100000005000000DA59F44E057443403B38D89B18304A40DA59F44E05744340F67AF7C77B334A4037FC6EBA65794340F67AF7C77B334A4037FC6EBA657943403B38D89B18304A40DA59F44E057443403B38D89B18304A40
38992	54743	38.906412000000003	38.948416999999999	52.402214999999998	52.375751000000001	Крупской	0103000020E61000000100000005000000DA59F44E057443403B38D89B18304A40DA59F44E05744340F67AF7C77B334A4037FC6EBA65794340F67AF7C77B334A4037FC6EBA657943403B38D89B18304A40DA59F44E057443403B38D89B18304A40
39034	54743	38.906412000000003	38.948416999999999	52.402214999999998	52.375751000000001	Коммуны	0103000020E61000000100000005000000DA59F44E057443403B38D89B18304A40DA59F44E05744340F67AF7C77B334A4037FC6EBA65794340F67AF7C77B334A4037FC6EBA657943403B38D89B18304A40DA59F44E057443403B38D89B18304A40
38839	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	микрорайон Александровский	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38854	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Юбилейная	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38853	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Электриков	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38824	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Спутников	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
39132	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Советская	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38844	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Свердлова	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38965	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Рязано-Уральская	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38850	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Радиотехническая	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38857	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Пушкина	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38849	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Профинтерна	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38830	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Проспект Мира	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
39270	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Пригородная	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38964	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Плеханова	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38923	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Орджоникидзе	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
37428	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Октябрьская	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38961	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Новолипецкая	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38845	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Мира	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
37426	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Маяковского	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38941	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Лермонтова	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38825	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Ленина	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38925	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Кротевича	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38881	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Красноармейская	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38851	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Костенко	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38823	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Комсомольская	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38958	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Коммунаров	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38924	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Клубная	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38852	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Известковая	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38963	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Задонское шоссе	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38962	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Задонская	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38848	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Ефремовская	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38922	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Гагарина	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38832	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Верхняя	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
37427	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Вермишева	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38855	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Барковского	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38926	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Ани Гайтеровой	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38983	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	Александровский микрорайон	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38960	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	А. Оборотова	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
38843	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	3-й Ламской переулок	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
37429	4018	38.456122999999998	38.589602999999997	52.646487999999998	52.580522000000002	1-я Речная	0103000020E6100000010000000500000009FA0B3D623A4340E44D7E8B4E4A4A4009FA0B3D623A4340D3A0681EC0524A40CE4F711C784B4340D3A0681EC0524A40CE4F711C784B4340E44D7E8B4E4A4A4009FA0B3D623A4340E44D7E8B4E4A4A40
35365	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Энгельса	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35356	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Чапаева	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
39217	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Свердлова	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35391	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Пионерская	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
39282	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Островского	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35360	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Моложедная	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35325	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Мичурина	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35313	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Мира	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35305	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Ленина	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
39143	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Коммунальная	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35374	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Зеленая	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
35382	54756	39.090217000000003	39.195104000000001	53.280101999999999	53.234237999999998	Володарского	0103000020E6100000010000000500000089450C3B8C8B43407FBDC282FB9D4A4089450C3B8C8B4340A8C5E061DAA34A40CEA8F92AF9984340A8C5E061DAA34A40CEA8F92AF99843407FBDC282FB9D4A4089450C3B8C8B43407FBDC282FB9D4A40
39030	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Шкатова	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39068	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Станционная	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39267	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Советская	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38816	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Правды	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38954	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Первомайская	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38939	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Осовиахима	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39008	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Орджоникидзе	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38917	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Некрасова	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38993	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Марины Расковой	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39004	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	М. Расковой	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39028	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Крылова	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38948	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Красная Площадь	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39015	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Коммунальная	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39085	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Гастелло	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39043	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Гагарина	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38929	54694	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	18 Партсъезд	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39159	27712	39.963800999999997	39.997596000000001	53.225296	53.213115999999999	Советская	0103000020E61000000100000005000000116DC7D45DFB43408E209562479B4A40116DC7D45DFB4340B6F5D37FD69C4A406A4FC939B1FF4340B6F5D37FD69C4A406A4FC939B1FF43408E209562479B4A40116DC7D45DFB43408E209562479B4A40
39441	26779	39.818041000000001	39.837184000000001	53.144208999999996	53.132536000000002	Зеленая	0103000020E61000000100000005000000C1E44691B5E8434076C58CF0F6904A40C1E44691B5E84340F964C57075924A40035E66D828EB4340F964C57075924A40035E66D828EB434076C58CF0F6904A40C1E44691B5E8434076C58CF0F6904A40
38833	26134	39.916550000000001	39.997397999999997	53.256546	53.223835000000001	Советская	0103000020E610000001000000050000000C93A98251F543409F5912A0A69C4A400C93A98251F54340B6F5D37FD6A04A40438CD7BCAAFF4340B6F5D37FD6A04A40438CD7BCAAFF43409F5912A0A69C4A400C93A98251F543409F5912A0A69C4A40
39326	27555	39.588970000000003	39.608877	53.524450000000002	53.508645000000001	Центральная	0103000020E610000001000000050000009E29745E63CB4340102384471BC14A409E29745E63CB43409031772D21C34A40AF2479AEEFCD43409031772D21C34A40AF2479AEEFCD4340102384471BC14A409E29745E63CB4340102384471BC14A40
39164	27507	39.691594000000002	39.765219999999999	53.454165000000003	53.398181999999998	Советская	0103000020E610000001000000050000000F0EF62686D843408DEDB5A0F7B24A400F0EF62686D8434072FE261422BA4A40601F9DBAF2E1434072FE261422BA4A40601F9DBAF2E143408DEDB5A0F7B24A400F0EF62686D843408DEDB5A0F7B24A40
39443	27172	39.822980999999999	39.856929000000001	53.408467000000002	53.397509999999997	Центральная	0103000020E610000001000000050000005C1D007157E943409EEA909BE1B24A405C1D007157E94340643F8BA548B44A403BFF76D9AFED4340643F8BA548B44A403BFF76D9AFED43409EEA909BE1B24A405C1D007157E943409EEA909BE1B24A40
39446	27415	40.074832999999998	40.108519999999999	53.377484000000003	53.343086	Центральная	0103000020E61000000100000005000000AED4B3209409444094DBF63DEAAB4A40AED4B32094094440B3614D6551B04A40207BBDFBE30D4440B3614D6551B04A40207BBDFBE30D444094DBF63DEAAB4A40AED4B3209409444094DBF63DEAAB4A40
39330	27448	40.111583000000003	40.149383999999998	53.344822999999998	53.322685	Школьная	0103000020E6100000010000000500000011E50B5A480E444073F4F8BD4DA94A4011E50B5A480E44404DF4F92823AC4A40D845D1031F1344404DF4F92823AC4A40D845D1031F13444073F4F8BD4DA94A4011E50B5A480E444073F4F8BD4DA94A40
39322	27335	39.821328000000001	39.856991999999998	53.303063999999999	53.283430000000003	Красиловка	0103000020E6100000010000000500000001A5A14621E94340475A2A6F47A44A4001A5A14621E94340274C18CDCAA64A408177F2E9B1ED4340274C18CDCAA64A408177F2E9B1ED4340475A2A6F47A44A4001A5A14621E94340475A2A6F47A44A40
39121	27266	39.787542999999999	39.836042999999997	53.189318	53.171211999999997	Школьная	0103000020E61000000100000005000000CC988235CEE4434064575A46EA954A40CC988235CEE44340A6457D923B984A405D86FF7403EB4340A6457D923B984A405D86FF7403EB434064575A46EA954A40CC988235CEE4434064575A46EA954A40
39281	27313	39.667375	39.714474000000003	53.533292000000003	53.517195999999998	Молодежная	0103000020E610000001000000050000008195438B6CD543409ECF807A33C24A408195438B6CD54340F69B89E942C44A40D1EB4FE273DB4340F69B89E942C44A40D1EB4FE273DB43409ECF807A33C24A408195438B6CD543409ECF807A33C24A40
39343	27128	39.854404000000002	39.896076999999998	53.306944000000001	53.265875999999999	Советская	0103000020E610000001000000050000002AC93A1C5DED434049658A3908A24A402AC93A1C5DED43400ADAE4F049A74A4051D9B0A6B2F243400ADAE4F049A74A4051D9B0A6B2F2434049658A3908A24A402AC93A1C5DED434049658A3908A24A40
39437	27101	39.908239999999999	39.922317	53.393853999999997	53.380755000000001	Центральная	0103000020E61000000100000005000000A375543541F44340ED647094BCB04A40A375543541F443400BB3D0CE69B24A40BDC5C37B0EF643400BB3D0CE69B24A40BDC5C37B0EF64340ED647094BCB04A40A375543541F44340ED647094BCB04A40
37438	26901	39.902104999999999	39.965831000000001	53.240113000000001	53.199545999999998	им.Радина	0103000020E610000001000000050000006F47382D78F3434018062CB98A994A406F47382D78F34340172CD505BC9E4A40433BA759A0FB4340172CD505BC9E4A40433BA759A0FB434018062CB98A994A406F47382D78F3434018062CB98A994A40
38870	26901	39.902104999999999	39.965831000000001	53.240113000000001	53.199545999999998	Пролетарская	0103000020E610000001000000050000006F47382D78F3434018062CB98A994A406F47382D78F34340172CD505BC9E4A40433BA759A0FB4340172CD505BC9E4A40433BA759A0FB434018062CB98A994A406F47382D78F3434018062CB98A994A40
38871	26901	39.902104999999999	39.965831000000001	53.240113000000001	53.199545999999998	Дзержинского	0103000020E610000001000000050000006F47382D78F3434018062CB98A994A406F47382D78F34340172CD505BC9E4A40433BA759A0FB4340172CD505BC9E4A40433BA759A0FB434018062CB98A994A406F47382D78F3434018062CB98A994A40
39438	26877	39.709156	39.769953999999998	53.437953	53.426654999999997	Центральная	0103000020E610000001000000050000008FE1B19FC5DA434062D68BA19CB64A408FE1B19FC5DA4340B1170AD80EB84A4052B648DA8DE24340B1170AD80EB84A4052B648DA8DE2434062D68BA19CB64A408FE1B19FC5DA434062D68BA19CB64A40
39161	27040	39.921104	39.953218999999997	53.115648999999998	53.084175999999999	Революционная	0103000020E610000001000000050000007E1B62BCE6F54340D68D7747C68A4A407E1B62BCE6F5434055682096CD8E4A408176871403FA434055682096CD8E4A408176871403FA4340D68D7747C68A4A407E1B62BCE6F54340D68D7747C68A4A40
39436	26789	39.932215999999997	39.997695	53.168264999999998	53.132725000000001	Ленинская	0103000020E610000001000000050000006A6798DA52F74340492EFF21FD904A406A6798DA52F74340DD0720B589954A40FD304278B4FF4340DD0720B589954A40FD304278B4FF4340492EFF21FD904A406A6798DA52F74340492EFF21FD904A40
39344	26714	39.696632999999999	39.789914000000003	53.144089999999998	53.120058999999998	Советская	0103000020E610000001000000050000003D2828452BD94340944BE3175E8F4A403D2828452BD943401FD7868A71924A408753E6E61BE543401FD7868A71924A408753E6E61BE54340944BE3175E8F4A403D2828452BD94340944BE3175E8F4A40
39320	26705	39.865057999999998	39.898045000000003	53.258927	53.250991999999997	Спортивная	0103000020E6100000010000000500000053927538BAEE434060C77F8120A04A4053927538BAEE434094861A8524A14A400DAB7823F3F2434094861A8524A14A400DAB7823F3F2434060C77F8120A04A4053927538BAEE434060C77F8120A04A40
39439	27216	39.839976999999998	39.875388999999998	53.449789000000003	53.418165999999999	Богдановка	0103000020E610000001000000050000003332C85D84EB43404A26A77686B54A403332C85D84EB4340DF8C9AAF92B94A409A232BBF0CF04340DF8C9AAF92B94A409A232BBF0CF043404A26A77686B54A403332C85D84EB43404A26A77686B54A40
39126	26600	40.028004000000003	40.113883000000001	53.146056000000002	53.108060000000002	Театральная	0103000020E610000001000000050000001F1494A295034440BD00FBE8D48D4A401F1494A2950344403AB187F6B1924A400249D8B7930E44403AB187F6B1924A400249D8B7930E4440BD00FBE8D48D4A401F1494A295034440BD00FBE8D48D4A40
39243	26600	40.028004000000003	40.113883000000001	53.146056000000002	53.108060000000002	Авиационная	0103000020E610000001000000050000001F1494A295034440BD00FBE8D48D4A401F1494A2950344403AB187F6B1924A400249D8B7930E44403AB187F6B1924A400249D8B7930E4440BD00FBE8D48D4A401F1494A295034440BD00FBE8D48D4A40
39485	26543	39.893095000000002	39.943570999999999	53.098669000000001	53.069260999999997	Махоново	0103000020E610000001000000050000004E9CDCEF50F24340B2F1608BDD884A404E9CDCEF50F243408410902FA18C4A401D3A3DEFC6F843408410902FA18C4A401D3A3DEFC6F84340B2F1608BDD884A404E9CDCEF50F24340B2F1608BDD884A40
39433	26331	39.931857000000001	39.965822000000003	53.345999999999997	53.313431999999999	Центральная	0103000020E610000001000000050000003BC6151747F743408BC22E8A1EA84A403BC6151747F743403F355EBA49AC4A40F0E0270EA0FB43403F355EBA49AC4A40F0E0270EA0FB43408BC22E8A1EA84A403BC6151747F743408BC22E8A1EA84A40
39435	26459	39.778748	39.794702000000001	53.494334000000002	53.484090000000002	Центральная	0103000020E61000000100000005000000A7E9B303AEE343400B293FA9F6BD4A40A7E9B303AEE3434083A6255646BF4A406C088ECBB8E5434083A6255646BF4A406C088ECBB8E543400B293FA9F6BD4A40A7E9B303AEE343400B293FA9F6BD4A40
39321	26393	39.947003000000002	40.017305	53.087491	53.052858999999998	Красноармейская	0103000020E61000000100000005000000611BF16437F943404E266E15C4864A40611BF16437F94340E0D8B3E7328B4A405587DC0C37024440E0D8B3E7328B4A405587DC0C370244404E266E15C4864A40611BF16437F943404E266E15C4864A40
75009	60438	39.941702999999997	39.997838000000002	53.351998999999999	53.324185	Свинушки	0103000020E61000000100000005000000C5C551B989F84340486DE2E47EA94A40C5C551B989F84340C39CA04D0EAD4A40605AD427B9FF4340C39CA04D0EAD4A40605AD427B9FF4340486DE2E47EA94A40C5C551B989F84340486DE2E47EA94A40
38985	25952	39.055810999999999	39.128646000000003	52.217464999999997	52.185125999999997	Юбилейная	0103000020E61000000100000005000000E7E099D024874340D4D17135B2174A40E7E099D0248743402783A3E4D51B4A407061DD78779043402783A3E4D51B4A407061DD7877904340D4D17135B2174A40E7E099D024874340D4D17135B2174A40
37436	25952	39.055810999999999	39.128646000000003	52.217464999999997	52.185125999999997	Свободы	0103000020E61000000100000005000000E7E099D024874340D4D17135B2174A40E7E099D0248743402783A3E4D51B4A407061DD78779043402783A3E4D51B4A407061DD7877904340D4D17135B2174A40E7E099D024874340D4D17135B2174A40
39189	25952	39.055810999999999	39.128646000000003	52.217464999999997	52.185125999999997	Пугачева	0103000020E61000000100000005000000E7E099D024874340D4D17135B2174A40E7E099D0248743402783A3E4D51B4A407061DD78779043402783A3E4D51B4A407061DD7877904340D4D17135B2174A40E7E099D024874340D4D17135B2174A40
39266	54767	39.034449000000002	39.085706999999999	52.049444999999999	52.026476000000002	Центральная	0103000020E61000000100000005000000A13028D3688443408010C99063034A40A13028D368844340B1F9B83654064A40E6046D72F88A4340B1F9B83654064A40E6046D72F88A43408010C99063034A40A13028D3688443408010C99063034A40
39516	54785	39.019967999999999	39.054248000000001	52.252681000000003	52.239502999999999	Школьная	0103000020E61000000100000005000000B77BB94F8E8243409E25C808A81E4A40B77BB94F8E82434009A9DBD957204A40CCEF3499F186434009A9DBD957204A40CCEF3499F18643409E25C808A81E4A40B77BB94F8E8243409E25C808A81E4A40
39483	25801	39.328800000000001	39.342472000000001	52.118839000000001	52.107506999999998	Центральная	0103000020E6100000010000000500000060764F1E16AA4340A88B14CAC20D4A4060764F1E16AA4340A33EC91D360F4A40DAE55B1FD6AB4340A33EC91D360F4A40DAE55B1FD6AB4340A88B14CAC20D4A4060764F1E16AA4340A88B14CAC20D4A40
39391	25881	39.349936999999997	39.370671000000002	52.181072999999998	52.161647000000002	Молодежная	0103000020E61000000100000005000000865451BCCAAC43408E3F51D9B0144A40865451BCCAAC434024986A662D174A40AE49B72572AF434024986A662D174A40AE49B72572AF43408E3F51D9B0144A40865451BCCAAC43408E3F51D9B0144A40
39190	25781	39.117831000000002	39.139076000000003	52.112091999999997	52.084225000000004	Центральная	0103000020E610000001000000050000003DBA1116158F4340B84082E2C70A4A403DBA1116158F43405512D907590E4A404AD40B3ECD9143405512D907590E4A404AD40B3ECD914340B84082E2C70A4A403DBA1116158F4340B84082E2C70A4A40
38938	25710	39.182535999999999	39.264102999999999	52.322561	52.295988000000001	Советская	0103000020E61000000100000005000000DC2BF3565D97434015014EEFE2254A40DC2BF3565D97434087FBC8AD49294A4043E38920CEA1434087FBC8AD49294A4043E38920CEA1434015014EEFE2254A40DC2BF3565D97434015014EEFE2254A40
39170	25703	38.979472000000001	39.013176999999999	52.199567999999999	52.184651000000002	Центральная	0103000020E6100000010000000500000082ACA7565F7D43403C16DBA4A2174A4082ACA7565F7D434000AAB8718B194A409A07B0C8AF81434000AAB8718B194A409A07B0C8AF8143403C16DBA4A2174A4082ACA7565F7D43403C16DBA4A2174A40
39482	25399	38.876103000000001	38.900042999999997	52.110399000000001	52.103209	Школьная	0103000020E61000000100000005000000B876A2242470434091D3D7F3350D4A40B876A224247043406C41EF8D210E4A4032FFE89B347343406C41EF8D210E4A4032FFE89B3473434091D3D7F3350D4A40B876A2242470434091D3D7F3350D4A40
39327	25641	39.310716999999997	39.337083	52.254534	52.240506000000003	Центральная	0103000020E61000000100000005000000D6A71C93C5A74340F33E8EE6C81E4A40D6A71C93C5A743402BDCF29194204A40CF84268925AB43402BDCF29194204A40CF84268925AB4340F33E8EE6C81E4A40D6A71C93C5A74340F33E8EE6C81E4A40
39345	22065	39.328781999999997	39.366852999999999	52.280287999999999	52.261026999999999	Мирная	0103000020E61000000100000005000000B9C1508715AA4340BE2F2E5569214A40B9C1508715AA43400ABB287AE0234A4041B8020AF5AE43400ABB287AE0234A4041B8020AF5AE4340BE2F2E5569214A40B9C1508715AA4340BE2F2E5569214A40
37435	25598	39.136066999999997	39.180613999999998	52.155282999999997	52.115957999999999	Ленина	0103000020E610000001000000050000004C88B9A46A914340D3DA34B6D70E4A404C88B9A46A914340F84F3750E0134A4091990B5C1E974340F84F3750E0134A4091990B5C1E974340D3DA34B6D70E4A404C88B9A46A914340D3DA34B6D70E4A40
39318	54770	39.071379	39.082912999999998	52.230699999999999	52.212383000000003	Дорожная	0103000020E61000000100000005000000834F73F222894340FA9CBB5D2F1B4A40834F73F222894340F697DD93871D4A40E5B4A7E49C8A4340F697DD93871D4A40E5B4A7E49C8A4340FA9CBB5D2F1B4A40834F73F222894340FA9CBB5D2F1B4A40
39201	54760	39.147205999999997	39.198140000000002	52.269295	52.246115000000003	Выгонская-Буторина	0103000020E6100000010000000500000032E36DA5D79243400C0742B2801F4A4032E36DA5D7924340F8FC304278224A40C503CAA65C994340F8FC304278224A40C503CAA65C9943400C0742B2801F4A4032E36DA5D79243400C0742B2801F4A40
38937	25314	39.044339999999998	39.113329999999998	52.164299	52.137985	Ленина	0103000020E61000000100000005000000CBF3E0EEAC854340562B137EA9114A40CBF3E0EEAC854340FCE1E7BF07154A40EDD3F198818E4340FCE1E7BF07154A40EDD3F198818E4340562B137EA9114A40CBF3E0EEAC854340562B137EA9114A40
39514	54784	39.255003000000002	39.291888	52.214165999999999	52.200529000000003	Дорожная	0103000020E61000000100000005000000E2B034F0A3A0434026732CEFAA194A40E2B034F0A3A0434023F59ECA691B4A40240C03965CA5434023F59ECA691B4A40240C03965CA5434026732CEFAA194A40E2B034F0A3A0434026732CEFAA194A40
39188	25238	39.167993000000003	39.220022999999998	52.242998999999998	52.213636000000001	Мира	0103000020E610000001000000050000007D7A6CCB80954340C79FA86C581B4A407D7A6CCB80954340F8FA5A971A1F4A4014AFB2B6299C4340F8FA5A971A1F4A4014AFB2B6299C4340C79FA86C581B4A407D7A6CCB80954340C79FA86C581B4A40
39187	25193	38.886181999999998	38.947294999999997	52.200380000000003	52.178516000000002	Мира	0103000020E61000000100000005000000E5266A696E71434008E8BE9CD9164A40E5266A696E714340E162450DA6194A4008556AF640794340E162450DA6194A4008556AF64079434008E8BE9CD9164A40E5266A696E71434008E8BE9CD9164A40
39242	25137	39.012574999999998	39.087179999999996	52.305053000000001	52.278095	Центральная	0103000020E61000000100000005000000A4DFBE0E9C8143402F17F19D98234A40A4DFBE0E9C814340FA4509FA0B274A40C16ED8B6288B4340FA4509FA0B274A40C16ED8B6288B43402F17F19D98234A40A4DFBE0E9C8143402F17F19D98234A40
38869	54700	39.780346999999999	39.780518000000001	52.287576999999999	52.285775999999998	Центральная	0103000020E610000001000000050000000F441669E2E34340A8FDD64E94244A400F441669E2E34340780AB952CF244A403CF88903E8E34340780AB952CF244A403CF88903E8E34340A8FDD64E94244A400F441669E2E34340A8FDD64E94244A40
39513	54783	39.348095999999998	40.151494999999997	52.353298000000002	51.919525999999998	Молодежная	0103000020E6100000010000000500000028EFE3688EAC43402DE92807B3F5494028EFE3688EAC434001DF6DDE382D4A40F6402B306413444001DF6DDE382D4A40F6402B30641344402DE92807B3F5494028EFE3688EAC43402DE92807B3F54940
39001	24577	39.701340000000002	39.751826000000001	52.083334000000001	52.010714	Карла Маркса	0103000020E6100000010000000500000036B05582C5D94340FFCD8B135F014A4036B05582C5D943408B5242B0AA0A4A40292499D53BE043408B5242B0AA0A4A40292499D53BE04340FFCD8B135F014A4036B05582C5D94340FFCD8B135F014A40
39430	25051	39.575603000000001	39.621057999999998	52.021844000000002	52.005496999999998	Первомайская	0103000020E61000000100000005000000603DEE5BADC94340F19C2D20B4004A40603DEE5BADC9434092CEC0C8CB024A40A7751BD47ECF434092CEC0C8CB024A40A7751BD47ECF4340F19C2D20B4004A40603DEE5BADC94340F19C2D20B4004A40
39162	54757	39.683427999999999	39.725127999999998	52.099392000000002	52.080632999999999	Г.Телегина	0103000020E61000000100000005000000D99596917AD743403BFDA02E520A4A40D99596917AD74340F5BD86E0B80C4A40FAB48AFED0DC4340F5BD86E0B80C4A40FAB48AFED0DC43403BFDA02E520A4A40D99596917AD743403BFDA02E520A4A40
39245	24982	39.871561999999997	39.945449000000004	52.208889999999997	52.133567999999997	Центральная	0103000020E61000000100000005000000DA37F7578FEF434064E597C118114A40DA37F7578FEF4340103B53E8BC1A4A4099840B7904F94340103B53E8BC1A4A4099840B7904F9434064E597C118114A40DA37F7578FEF434064E597C118114A40
37434	24844	39.766252999999999	39.810315000000003	52.121996000000003	52.078358000000001	Школьная	0103000020E610000001000000050000001FBB0B9414E24340A3B08BA2070A4A401FBB0B9414E24340151F9F909D0F4A40A83AE466B8E74340151F9F909D0F4A40A83AE466B8E74340A3B08BA2070A4A401FBB0B9414E24340A3B08BA2070A4A40
39263	54766	39.990302	40.021957999999998	52.277791999999998	52.241731000000001	Центральная	0103000020E61000000100000005000000EA944737C2FE4340F6B6990AF11E4A40EA944737C2FE4340938B31B08E234A405AF10D85CF024440938B31B08E234A405AF10D85CF024440F6B6990AF11E4A40EA944737C2FE4340F6B6990AF11E4A40
39374	24480	39.956066999999997	40.008006999999999	52.035763000000003	52.006262	 Заречная	0103000020E6100000010000000500000075E4486760FA4340919A7631CD004A4075E4486760FA434014B4C9E193044A40CD91955F0601444014B4C9E193044A40CD91955F06014440919A7631CD004A4075E4486760FA4340919A7631CD004A40
39240	24365	39.693390000000001	39.762856999999997	52.315696000000003	52.286993000000002	Проспект Революции	0103000020E61000000100000005000000CDAFE600C1D843402997C62FBC244A40CDAFE600C1D8434030BDFDB968284A402843554CA5E1434030BDFDB968284A402843554CA5E143402997C62FBC244A40CDAFE600C1D843402997C62FBC244A40
39241	24365	39.693390000000001	39.762856999999997	52.315696000000003	52.286993000000002	Базарная	0103000020E61000000100000005000000CDAFE600C1D843402997C62FBC244A40CDAFE600C1D8434030BDFDB968284A402843554CA5E1434030BDFDB968284A402843554CA5E143402997C62FBC244A40CDAFE600C1D843402997C62FBC244A40
38936	23711	39.726170000000003	39.774571000000002	52.033320000000003	52.003633999999998	Дзержинского	0103000020E610000001000000050000000DAB7823F3DC4340AB93331477004A400DAB7823F3DC4340C0266BD443044A400BB77C2425E34340C0266BD443044A400BB77C2425E34340AB93331477004A400DAB7823F3DC4340AB93331477004A40
39158	24270	39.631675999999999	39.696247	52.180835999999999	52.131025000000001	Ленина	0103000020E6100000010000000500000084D558C2DAD04340ADFA5C6DC5104A4084D558C2DAD0434040F850A225174A401478279F1ED9434040F850A225174A401478279F1ED94340ADFA5C6DC5104A4084D558C2DAD04340ADFA5C6DC5104A40
39319	25033	39.777518000000001	39.79269	51.959274999999998	51.942545000000003	Центральная	0103000020E610000001000000050000009206B7B585E3434011018750A5F849409206B7B585E34340696FF085C9FA4940E1EEACDD76E54340696FF085C9FA4940E1EEACDD76E5434011018750A5F849409206B7B585E3434011018750A5F84940
39370	23843	39.817923999999998	39.853596000000003	52.263513000000003	52.239221000000001	Центральная	0103000020E61000000100000005000000874ECFBBB1E843401AC231CB9E1E4A40874ECFBBB1E84340128942CBBA214A408BFF3BA242ED4340128942CBBA214A408BFF3BA242ED43401AC231CB9E1E4A40874ECFBBB1E843401AC231CB9E1E4A40
39317	24721	39.571040000000004	39.599355000000003	52.081884000000002	52.066982000000003	Молодежная	0103000020E610000001000000050000009B5AB6D617C94340D9B5BDDD92084A409B5AB6D617C943406808C72C7B0A4A40D8D825AAB7CC43406808C72C7B0A4A40D8D825AAB7CC4340D9B5BDDD92084A409B5AB6D617C94340D9B5BDDD92084A40
39449	24807	39.803452	39.823385999999999	52.213272000000003	52.193843999999999	Б.Котова	0103000020E61000000100000005000000F1F3DF83D7E643404E4354E1CF184A40F1F3DF83D7E643408693347F4C1B4A40FCFD62B664E943408693347F4C1B4A40FCFD62B664E943404E4354E1CF184A40F1F3DF83D7E643404E4354E1CF184A40
39372	24164	39.502813000000003	39.663854000000001	52.251522999999999	52.202179000000001	Лесная	0103000020E610000001000000050000007880272D5CC0434010786000E1194A407880272D5CC043408D98D9E731204A40CEA8F92AF9D443408D98D9E731204A40CEA8F92AF9D4434010786000E1194A407880272D5CC0434010786000E1194A40
39238	24164	39.502813000000003	39.663854000000001	52.251522999999999	52.202179000000001	Ленина	0103000020E610000001000000050000007880272D5CC0434010786000E1194A407880272D5CC043408D98D9E731204A40CEA8F92AF9D443408D98D9E731204A40CEA8F92AF9D4434010786000E1194A407880272D5CC0434010786000E1194A40
39127	24078	39.929853999999999	39.990983999999997	52.003169	51.972160000000002	Центральная	0103000020E610000001000000050000000307B47405F743405C3D27BD6FFC49400307B47405F7434036AE7FD767004A40FC6D4F90D8FE434036AE7FD767004A40FC6D4F90D8FE43405C3D27BD6FFC49400307B47405F743405C3D27BD6FFC4940
39252	24066	39.648034000000003	39.731973000000004	52.344864999999999	52.314985999999998	Садовая	0103000020E61000000100000005000000195932C7F2D243405359147651284A40195932C7F2D243407C444C89242C4A400B47904AB1DD43407C444C89242C4A400B47904AB1DD43405359147651284A40195932C7F2D243405359147651284A40
39484	24926	39.762506999999999	39.789293999999998	52.133434999999999	52.092232000000003	60 лет Победы	0103000020E610000001000000050000004CFC51D499E1434085D21742CE0B4A404CFC51D499E143402592E86514114A40EA76F69507E543402592E86514114A40EA76F69507E5434085D21742CE0B4A404CFC51D499E1434085D21742CE0B4A40
39339	23982	39.358885000000001	39.38711	52.147972000000003	52.091740000000001	Центральная	0103000020E61000000100000005000000320395F1EFAD434016DEE522BE0B4A40320395F1EFAD4340A35C1ABFF0124A402FFA0AD28CB14340A35C1ABFF0124A402FFA0AD28CB1434016DEE522BE0B4A40320395F1EFAD434016DEE522BE0B4A40
39373	23910	39.801403999999998	39.904575000000001	52.070177000000001	52.041879000000002	Пионерская	0103000020E610000001000000050000001971016894E64340D1B1834A5C054A401971016894E6434038F7578FFB084A40BDE3141DC9F3434038F7578FFB084A40BDE3141DC9F34340D1B1834A5C054A401971016894E64340D1B1834A5C054A40
39186	23910	39.801403999999998	39.904575000000001	52.070177000000001	52.041879000000002	Ленина	0103000020E610000001000000050000001971016894E64340D1B1834A5C054A401971016894E6434038F7578FFB084A40BDE3141DC9F3434038F7578FFB084A40BDE3141DC9F34340D1B1834A5C054A401971016894E64340D1B1834A5C054A40
39481	23773	39.854683000000001	39.878497000000003	52.295282999999998	52.269933999999999	Центральная	0103000020E610000001000000050000003DB9A64066ED43400B0A83328D224A403DB9A64066ED43404A0856D5CB254A402B51F69672F043404A0856D5CB254A402B51F69672F043400B0A83328D224A403DB9A64066ED43400B0A83328D224A40
38867	23669	39.772531999999998	39.825235999999997	52.014738000000001	51.963765000000002	Советская	0103000020E61000000100000005000000868E1D54E2E24340C503CAA65CFB4940868E1D54E2E2434015014EEFE2014A40ADBD4F55A1E9434015014EEFE2014A40ADBD4F55A1E94340C503CAA65CFB4940868E1D54E2E24340C503CAA65CFB4940
39185	23639	39.965867000000003	40.05348	52.127243999999997	52.070264999999999	Ленина	0103000020E6100000010000000500000090A4A487A1FB4340D7868A71FE084A4090A4A487A1FB43405D4E098849104A40BB7EC16ED80644405D4E098849104A40BB7EC16ED8064440D7868A71FE084A4090A4A487A1FB4340D7868A71FE084A40
39431	23581	40.062238999999998	40.090643	52.067352999999997	52.042582000000003	Попова	0103000020E6100000010000000500000093C49272F7074440FBB2B45373054A4093C49272F7074440CC24EA059F084A40404E98309A0B4440CC24EA059F084A40404E98309A0B4440FBB2B45373054A4093C49272F7074440FBB2B45373054A40
39432	24673	39.748682000000002	39.768256000000001	52.087031000000003	52.070686000000002	Заречная	0103000020E610000001000000050000004C8DD0CFD4DF43407D24253D0C094A404C8DD0CFD4DF43407D5EF1D4230B4A40577A6D3656E243407D5EF1D4230B4A40577A6D3656E243407D24253D0C094A404C8DD0CFD4DF43407D24253D0C094A40
39371	23493	39.495213	39.518901999999997	52.203972999999998	52.188152000000002	Новая	0103000020E61000000100000005000000EBC6BB2363BF4340A8565F5D15184A40EBC6BB2363BF43402D228AC91B1A4A401CEA77616BC243402D228AC91B1A4A401CEA77616BC24340A8565F5D15184A40EBC6BB2363BF4340A8565F5D15184A40
39184	23412	40.043472999999999	40.085926999999998	52.183700999999999	52.129803000000003	Ворошилова	0103000020E6100000010000000500000027A1F485900544401BF67B629D104A4027A1F485900544400A9FAD8383174A40F46BEBA7FF0A44400A9FAD8383174A40F46BEBA7FF0A44401BF67B629D104A4027A1F485900544401BF67B629D104A40
39480	25115	39.505094	39.682214999999999	51.995843999999998	51.960368000000003	Лесная	0103000020E61000000100000005000000F2B391EBA6C04340FE0FB056EDFA4940F2B391EBA6C043407BF5F1D077FF49409AEB34D252D743407BF5F1D077FF49409AEB34D252D74340FE0FB056EDFA4940F2B391EBA6C04340FE0FB056EDFA4940
75008	60436	38.574691000000001	38.608980000000003	52.143363000000001	52.109752	переулок Почтовый	0103000020E610000001000000050000001C2785798F494340D655815A0C0E4A401C2785798F4943406D3A02B859124A4084F57F0EF34D43406D3A02B859124A4084F57F0EF34D4340D655815A0C0E4A401C2785798F494340D655815A0C0E4A40
75003	60430	38.156373000000002	38.217333000000004	52.044454999999999	52.011738999999999	Пятая Сотня	0103000020E610000001000000050000001C7DCC07041443403B8BDEA980014A401C7DCC0704144340649291B3B0054A40B9AB5791D11B4340649291B3B0054A40B9AB5791D11B43403B8BDEA980014A401C7DCC07041443403B8BDEA980014A40
75001	60427	38.255107000000002	38.307082999999999	52.162481999999997	52.127332000000003	Октябрьская	0103000020E6100000010000000500000087FD9E58A7204340FDDD3B6A4C104A4087FD9E58A72043402618CE35CC144A402B14E97E4E2743402618CE35CC144A402B14E97E4E274340FDDD3B6A4C104A4087FD9E58A7204340FDDD3B6A4C104A40
75000	60427	38.255107000000002	38.307082999999999	52.162481999999997	52.127332000000003	Ленина	0103000020E6100000010000000500000087FD9E58A7204340FDDD3B6A4C104A4087FD9E58A72043402618CE35CC144A402B14E97E4E2743402618CE35CC144A402B14E97E4E274340FDDD3B6A4C104A4087FD9E58A7204340FDDD3B6A4C104A40
75002	60427	38.255107000000002	38.307082999999999	52.162481999999997	52.127332000000003	Красноармейская	0103000020E6100000010000000500000087FD9E58A7204340FDDD3B6A4C104A4087FD9E58A72043402618CE35CC144A402B14E97E4E2743402618CE35CC144A402B14E97E4E274340FDDD3B6A4C104A4087FD9E58A7204340FDDD3B6A4C104A40
75033	60453	38.298009999999998	38.376477999999999	52.146165000000003	52.098329	Сельская	0103000020E61000000100000005000000C3F0113125264340CB9F6F0B960C4A40C3F0113125264340F168E388B5124A40EDD45C6E30304340F168E388B5124A40EDD45C6E30304340CB9F6F0B960C4A40C3F0113125264340CB9F6F0B960C4A40
75011	60440	38.183511000000003	38.205492999999997	52.200699999999998	52.185971000000002	Высота	0103000020E6100000010000000500000067BAD7497D1743409180D1E5CD174A4067BAD7497D1743405227A089B0194A40494739984D1A43405227A089B0194A40494739984D1A43409180D1E5CD174A4067BAD7497D1743409180D1E5CD174A40
75010	60439	38.420746999999999	38.456310999999999	52.035547000000001	52.020985000000003	Садовая	0103000020E61000000100000005000000EF71A609DB354340715AF0A2AF024A40EF71A609DB354340473CD9CD8C044A400CE71A66683A4340473CD9CD8C044A400CE71A66683A4340715AF0A2AF024A40EF71A609DB354340715AF0A2AF024A40
39163	21292	38.283538	38.338327	52.031973000000001	51.994996	Центральная	0103000020E610000001000000050000002D9622F94A2443404ED367075CFF49402D9622F94A24434071ADF6B017044A40492D944C4E2B434071ADF6B017044A40492D944C4E2B43404ED367075CFF49402D9622F94A2443404ED367075CFF4940
75006	60434	38.196688999999999	38.234867999999999	52.020524999999999	52.007154999999997	Лесная	0103000020E61000000100000005000000D13DEB1A2D1943405E807D74EA004A40D13DEB1A2D1943400DE02D90A0024A403F709527101E43400DE02D90A0024A403F709527101E43405E807D74EA004A40D13DEB1A2D1943405E807D74EA004A40
39367	21238	38.313093000000002	38.331471999999998	52.830030000000001	52.815452000000001	Московская	0103000020E61000000100000005000000A3CD716E1328434099BA2BBB60684A40A3CD716E1328434075594C6C3E6A4A4015C5ABAC6D2A434075594C6C3E6A4A4015C5ABAC6D2A434099BA2BBB60684A40A3CD716E1328434099BA2BBB60684A40
39479	21136	38.449402999999997	38.480826	52.935974000000002	52.919618	Лесная	0103000020E61000000100000005000000B5DC9909863943400E68E90AB6754A40B5DC99098639434002F4FBFECD774A408388D4B48B3D434002F4FBFECD774A408388D4B48B3D43400E68E90AB6754A40B5DC9909863943400E68E90AB6754A40
39427	20530	37.979458999999999	38.004333000000003	53.033796000000002	53.022596	Центральная	0103000020E61000000100000005000000ED629AE95EFD42409D82FC6CE4824A40ED629AE95EFD4240295E656D53844A4094A5D6FB8D004340295E656D53844A4094A5D6FB8D0043409D82FC6CE4824A40ED629AE95EFD42409D82FC6CE4824A40
39316	21192	38.420836999999999	38.447265000000002	52.988627000000001	52.973900999999998	Соборная	0103000020E610000001000000050000002FF99FFCDD3543405645B8C9A87C4A402FF99FFCDD354340A7785C548B7E4A409ED2C1FA3F394340A7785C548B7E4A409ED2C1FA3F3943405645B8C9A87C4A402FF99FFCDD3543405645B8C9A87C4A40
39157	21035	38.366847999999997	38.395262000000002	52.717052000000002	52.695303000000003	Центральная	0103000020E610000001000000050000002F4D11E0F42E4340C5E74EB0FF584A402F4D11E0F42E434005C4245CC85B4A4000ADF9F19732434005C4245CC85B4A4000ADF9F197324340C5E74EB0FF584A402F4D11E0F42E4340C5E74EB0FF584A40
39183	20335	38.134041000000003	38.159408999999997	52.987532000000002	52.973396999999999	Центральная	0103000020E610000001000000050000005DA96741281143402383DC45987C4A405DA967412811434072E0D572677E4A4012D89C836714434072E0D572677E4A4012D89C83671443402383DC45987C4A405DA96741281143402383DC45987C4A40
39429	21097	38.346806999999998	38.379055999999999	52.704127	52.682065000000001	Механизаторов	0103000020E610000001000000050000000E83F92B642C4340855FEAE74D574A400E83F92B642C4340849D62D5205A4A4021AD31E884304340849D62D5205A4A4021AD31E884304340855FEAE74D574A400E83F92B642C4340855FEAE74D574A40
39440	54746	38.314951999999998	38.335020999999998	52.742137999999997	52.727229999999999	Новая	0103000020E61000000100000005000000A7E7DD5850284340C55565DF155D4A40A7E7DD5850284340368FC360FE5E4A40923CD7F7E12A4340368FC360FE5E4A40923CD7F7E12A4340C55565DF155D4A40A7E7DD5850284340C55565DF155D4A40
39016	54746	38.314951999999998	38.335020999999998	52.742137999999997	52.727229999999999	Московская	0103000020E61000000100000005000000A7E7DD5850284340C55565DF155D4A40A7E7DD5850284340368FC360FE5E4A40923CD7F7E12A4340368FC360FE5E4A40923CD7F7E12A4340C55565DF155D4A40A7E7DD5850284340C55565DF155D4A40
39123	54746	38.314951999999998	38.335020999999998	52.742137999999997	52.727229999999999	Ленина	0103000020E61000000100000005000000A7E7DD5850284340C55565DF155D4A40A7E7DD5850284340368FC360FE5E4A40923CD7F7E12A4340368FC360FE5E4A40923CD7F7E12A4340C55565DF155D4A40A7E7DD5850284340C55565DF155D4A40
39130	21007	38.435704000000001	38.471870000000003	52.790239999999997	52.777794	Садовая	0103000020E61000000100000005000000425E0F26C53743403483F8C08E634A40425E0F26C5374340DAFE959526654A4055FB743C663C4340DAFE959526654A4055FB743C663C43403483F8C08E634A40425E0F26C53743403483F8C08E634A40
39400	20387	38.067610000000002	38.093696999999999	53.033011000000002	53.007671000000002	Поволяева	0103000020E61000000100000005000000F870C971A70843405610035DFB804A40F870C971A708434042B456B439844A40DD5D6743FE0B434042B456B439844A40DD5D6743FE0B43405610035DFB804A40F870C971A70843405610035DFB804A40
39478	20203	38.227088000000002	38.248809999999999	52.913758999999999	52.897058000000001	Советская	0103000020E6100000010000000500000033A83638111D4340BE4EEACBD2724A4033A83638111D43407CB60E0EF6744A4079758E01D91F43407CB60E0EF6744A4079758E01D91F4340BE4EEACBD2724A4033A83638111D4340BE4EEACBD2724A40
39182	20777	38.537052000000003	38.556905	52.758245000000002	52.745299000000003	9 мая	0103000020E610000001000000050000002E20B41EBE444340EA5E27F5655F4A402E20B41EBE44434082AD122C0E614A404CFDBCA94847434082AD122C0E614A404CFDBCA948474340EA5E27F5655F4A402E20B41EBE444340EA5E27F5655F4A40
39235	20920	38.356130999999998	38.378489999999999	52.912005000000001	52.898020000000002	Ленина	0103000020E61000000100000005000000BF0B5BB3952D4340B493C151F2724A40BF0B5BB3952D4340ED647094BC744A4078EE3D5C72304340ED647094BC744A4078EE3D5C72304340B493C151F2724A40BF0B5BB3952D4340B493C151F2724A40
39463	20082	38.293329999999997	38.308179000000003	52.864305000000002	52.858198999999999	А.И.Бунина	0103000020E61000000100000005000000C47762D68B254340DE3AFF76D96D4A40C47762D68B2543407862D68BA16E4A403128D368722743407862D68BA16E4A403128D36872274340DE3AFF76D96D4A40C47762D68B254340DE3AFF76D96D4A40
39180	20257	38.239476000000003	38.263641	52.975060999999997	52.957109000000003	Центральная	0103000020E61000000100000005000000A5164A26A71E434088DA368C827A4A40A5164A26A71E4340724D81CCCE7C4A403F7100FDBE214340724D81CCCE7C4A403F7100FDBE21434088DA368C827A4A40A5164A26A71E434088DA368C827A4A40
39251	20476	38.033016000000003	38.054063999999997	52.972681000000001	52.960200999999998	Победы	0103000020E61000000100000005000000541F48DE39044340124BCADDE77A4A40541F48DE3904434065389ECF807C4A400AF2B391EB06434065389ECF807C4A400AF2B391EB064340124BCADDE77A4A40541F48DE39044340124BCADDE77A4A40
39428	20904	38.478301999999999	38.503284000000001	52.895026000000001	52.880470000000003	Фермерская	0103000020E6100000010000000500000042CEFBFF383D4340F88DAF3DB3704A4042CEFBFF383D4340EC88433690724A40CF4C309C6B404340EC88433690724A40CF4C309C6B404340F88DAF3DB3704A4042CEFBFF383D4340F88DAF3DB3704A40
39366	20742	38.001306	38.027769999999997	52.960526999999999	52.950035	Центральная	0103000020E61000000100000005000000F0A485CB2A004340168733BF9A794A40F0A485CB2A00434066F6798CF27A4A40ABE7A4F78D03434066F6798CF27A4A40ABE7A4F78D034340168733BF9A794A40F0A485CB2A004340168733BF9A794A40
39120	19882	38.218446	38.235937	52.736756	52.731194000000002	Центральная	0103000020E6100000010000000500000094F8DC09F61B43400684D6C3975D4A4094F8DC09F61B4340DE9046054E5E4A404B75012F331E4340DE9046054E5E4A404B75012F331E43400684D6C3975D4A4094F8DC09F61B43400684D6C3975D4A40
39314	19975	38.226728999999999	38.257810999999997	52.802017999999997	52.770380000000003	Центральная	0103000020E610000001000000050000000307B474051D43400ABFD4CF9B624A400307B474051D4340D3669C86A8664A4047C66AF3FF204340D3669C86A8664A4047C66AF3FF2043400ABFD4CF9B624A400307B474051D43400ABFD4CF9B624A40
39181	20027	38.132621	38.255780000000001	52.834552000000002	52.728423999999997	Центральная	0103000020E61000000100000005000000A4E194B9F91043408DCF64FF3C5D4A40A4E194B9F9104340DC679599D26A4A40467C2766BD204340DC679599D26A4A40467C2766BD2043408DCF64FF3C5D4A40A4E194B9F91043408DCF64FF3C5D4A40
39476	20132	38.238182000000002	38.277304000000001	52.864952000000002	52.834752999999999	Советская	0103000020E61000000100000005000000793F6EBF7C1E4340739EB12FD96A4A40793F6EBF7C1E43400E4E44BFB66E4A4066868DB27E2343400E4E44BFB66E4A4066868DB27E234340739EB12FD96A4A40793F6EBF7C1E4340739EB12FD96A4A40
39426	20834	38.459643999999997	38.477142999999998	52.828702999999997	52.821334999999998	Солнечная	0103000020E61000000100000005000000BCE6559DD53A4340B3075A8121694A40BCE6559DD53A43406D8C9DF0126A4A40F6419605133D43406D8C9DF0126A4A40F6419605133D4340B3075A8121694A40BCE6559DD53A4340B3075A8121694A40
39236	20625	38.000909999999998	38.030627000000003	52.916339000000001	52.905667999999999	Ю.Тарасова	0103000020E61000000100000005000000A31EA2D11D0043405184D4EDEC734A40A31EA2D11D0043405186AA984A754A40F3AFE595EB0343405186AA984A754A40F3AFE595EB0343405184D4EDEC734A40A31EA2D11D0043405184D4EDEC734A40
39425	20696	37.888846000000001	37.911788999999999	52.969611	52.954906999999999	Ленина	0103000020E610000001000000050000001897AAB4C5F1424059DC7F643A7A4A401897AAB4C5F14240C26B97361C7C4A4020ED7F80B5F44240C26B97361C7C4A4020ED7F80B5F4424059DC7F643A7A4A401897AAB4C5F1424059DC7F643A7A4A40
37433	19664	39.254320999999997	39.287647999999997	52.556767000000001	52.535704000000003	Московская	0103000020E61000000100000005000000CFD72C978DA043400F2BDCF291444A40CFD72C978DA04340FB3E1C2444474A40416150A6D1A44340FB3E1C2444474A40416150A6D1A443400F2BDCF291444A40CFD72C978DA043400F2BDCF291444A40
38872	54701	39.490693999999998	39.509245	52.567534999999999	52.534838999999998	Титова	0103000020E61000000100000005000000F52B9D0FCFBE43400BD0B69A75444A40F52B9D0FCFBE4340ED2AA4FCA4484A406553AEF02EC14340ED2AA4FCA4484A406553AEF02EC143400BD0B69A75444A40F52B9D0FCFBE43400BD0B69A75444A40
39196	18781	39.536786999999997	39.572648000000001	52.766184000000003	52.755235999999996	Центральная	0103000020E610000001000000050000007FF5B86FB5C443408461C092AB604A407FF5B86FB5C44340F75B3B5112624A40560F98874CC94340F75B3B5112624A40560F98874CC943408461C092AB604A407FF5B86FB5C443408461C092AB604A40
38882	18808	39.492527000000003	39.550217000000004	52.499273000000002	52.480035999999998	Гагарина	0103000020E61000000100000005000000D1B2EE1F0BBF43408A73D4D1713D4A40D1B2EE1F0BBF43404E637B2DE83F4A40045ABA826DC643404E637B2DE83F4A40045ABA826DC643408A73D4D1713D4A40D1B2EE1F0BBF43408A73D4D1713D4A40
39237	19582	39.480777000000003	39.515774999999998	52.830542000000001	52.812218999999999	Фрунзе	0103000020E61000000100000005000000A2D5C9198ABD43404C18CDCAF6674A40A2D5C9198ABD43402BFA43334F6A4A40158C4AEA04C243402BFA43334F6A4A40158C4AEA04C243404C18CDCAF6674A40A2D5C9198ABD43404C18CDCAF6674A40
39009	54744	39.511778	39.540891999999999	52.570239000000001	52.559384000000001	Советская	0103000020E61000000100000005000000F96706F181C14340EDF318E599474A40F96706F181C14340AEF36F97FD484A408255F5F23BC54340AEF36F97FD484A408255F5F23BC54340EDF318E599474A40F96706F181C14340EDF318E599474A40
38995	54744	39.521956000000003	39.540731000000001	52.572947999999997	52.562624999999997	Ленина	0103000020E61000000100000005000000BAF94674CFC24340BC74931804484A40BAF94674CFC2434080272D5C56494A40797764AC36C5434080272D5C56494A40797764AC36C54340BC74931804484A40BAF94674CFC24340BC74931804484A40
38883	18950	39.320050999999999	39.361930000000001	52.810853000000002	52.780141999999998	Ксении Константиновой	0103000020E61000000100000005000000AB06616EF7A84340361E6CB1DB634A40AB06616EF7A84340876EF607CA674A407CB8E4B853AE4340876EF607CA674A407CB8E4B853AE4340361E6CB1DB634A40AB06616EF7A84340361E6CB1DB634A40
39368	18457	39.359253000000002	39.393452000000003	52.564819999999997	52.541992	Терешковой	0103000020E61000000100000005000000B5FE9600FCAD4340C9586DFE5F454A40B5FE9600FCAD4340381092054C484A40DD4598A25CB24340381092054C484A40DD4598A25CB24340C9586DFE5F454A40B5FE9600FCAD4340C9586DFE5F454A40
39129	18601	39.492060000000002	39.523437999999999	52.739961999999998	52.711208999999997	Комсомольская	0103000020E61000000100000005000000BBD573D2FBBE434078CF81E5085B4A40BBD573D2FBBE434031242713B75E4A40E8BD310400C3434031242713B75E4A40E8BD310400C3434078CF81E5085B4A40BBD573D2FBBE434078CF81E5085B4A40
39155	17754	39.252963999999999	39.282662999999999	52.425176	52.412796	Шумная	0103000020E610000001000000050000005D88D51F61A04340B6F5D37FD6344A405D88D51F61A04340A585CB2A6C364A4006651A4D2EA44340A585CB2A6C364A4006651A4D2EA44340B6F5D37FD6344A405D88D51F61A04340B6F5D37FD6344A40
39125	17754	39.252963999999999	39.282662999999999	52.425176	52.412796	Садовая	0103000020E610000001000000050000005D88D51F61A04340B6F5D37FD6344A405D88D51F61A04340A585CB2A6C364A4006651A4D2EA44340A585CB2A6C364A4006651A4D2EA44340B6F5D37FD6344A405D88D51F61A04340B6F5D37FD6344A40
38866	54698	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	Парковая	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
38940	19228	39.338628	39.378225	52.659315999999997	52.623583000000004	8 Марта	0103000020E6100000010000000500000044C18C2958AB4340B9AB5791D14F4A4044C18C2958AB434061DD787764544A40CAC342AD69B0434061DD787764544A40CAC342AD69B04340B9AB5791D14F4A4044C18C2958AB4340B9AB5791D14F4A40
39198	19182	39.166384999999998	39.212414000000003	52.744208999999998	52.710625	50 лет октября 	0103000020E61000000100000005000000C1C58A1A4C954340295C8FC2F55A4A40C1C58A1A4C954340C631923D425F4A40359BC761309B4340C631923D425F4A40359BC761309B4340295C8FC2F55A4A40C1C58A1A4C954340295C8FC2F55A4A40
39504	54778	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	Юбилейная	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
38884	19097	39.218288999999999	39.242562	52.655709999999999	52.640259	Кирова	0103000020E61000000100000005000000CC09DAE4F09B43401EFCC401F4514A40CC09DAE4F09B434080D4264EEE534A404DA088450C9F434080D4264EEE534A404DA088450C9F43401EFCC401F4514A40CC09DAE4F09B43401EFCC401F4514A40
39099	54753	\N	\N	\N	\N	Советская	\N
39093	54752	39.458041000000001	39.491771999999997	52.705632999999999	52.682453000000002	Молодежная	0103000020E61000000100000005000000139D6516A1BA43404F07B29E5A574A40139D6516A1BA43403BFDA02E525A4A40548B8862F2BE43403BFDA02E525A4A40548B8862F2BE43404F07B29E5A574A40139D6516A1BA43404F07B29E5A574A40
39248	18408	39.331091000000001	39.380910999999998	52.514094	52.495258999999997	Школьная	0103000020E61000000100000005000000FE7F9C3061AA43405B069CA5643F4A40FE7F9C3061AA4340F0880AD5CD414A40E4D70FB1C1B04340F0880AD5CD414A40E4D70FB1C1B043405B069CA5643F4A40FE7F9C3061AA43405B069CA5643F4A40
39457	19134	39.418774999999997	39.464247999999998	52.432941	52.389626	Свободы	0103000020E61000000100000005000000F2B0506B9AB54340EDD5C743DF314A40F2B0506B9AB543407C0C569C6A374A40E09D7C7A6CBB43407C0C569C6A374A40E09D7C7A6CBB4340EDD5C743DF314A40F2B0506B9AB54340EDD5C743DF314A40
39039	54748	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	Советская	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
38837	18503	39.443280999999999	39.470779	52.684604	52.670408000000002	Котовского	0103000020E6100000010000000500000016F88A6EBDB84340077DE9EDCF554A4016F88A6EBDB84340FB5A971AA1574A4061527C7C42BC4340FB5A971AA1574A4061527C7C42BC4340077DE9EDCF554A4016F88A6EBDB84340077DE9EDCF554A40
38981	18009	39.649543999999999	39.682709000000003	52.732655999999999	52.714689999999997	Административная	0103000020E6100000010000000500000011A8FE4124D343409D6340F67A5B4A4011A8FE4124D34340ED9BFBABC75D4A40AAD72D0263D74340ED9BFBABC75D4A40AAD72D0263D743409D6340F67A5B4A4011A8FE4124D343409D6340F67A5B4A40
39315	18230	39.061138	39.105739	52.700628999999999	52.684232999999999	Советская	0103000020E610000001000000050000007C45B75ED387434007EC6AF294574A407C45B75ED387434089D00836AE594A40B47405DB888D434089D00836AE594A40B47405DB888D434007EC6AF294574A407C45B75ED387434007EC6AF294574A40
39234	18194	39.364023000000003	39.407384999999998	52.375207000000003	52.337629	Ленинская	0103000020E61000000100000005000000F4FE3F4E98AE43403197546D372B4A40F4FE3F4E98AE43407A1D71C806304A40C3F0113125B443407A1D71C806304A40C3F0113125B443403197546D372B4A40F4FE3F4E98AE43403197546D372B4A40
39195	19041	39.256557999999998	39.310501000000002	52.766897999999998	52.745010999999998	8 Марта	0103000020E610000001000000050000007AC37DE4D6A0434083143C855C5F4A407AC37DE4D6A0434014AFB2B629624A400A302C7FBEA7434014AFB2B629624A400A302C7FBEA7434083143C855C5F4A407AC37DE4D6A0434083143C855C5F4A40
39178	18144	39.395823	39.429223	52.314683000000002	52.285181000000001	Ленина	0103000020E610000001000000050000009700FC53AAB2434065389ECF80244A409700FC53AAB24340B8CD548847284A4073D87DC7F0B64340B8CD548847284A4073D87DC7F0B6434065389ECF80244A409700FC53AAB2434065389ECF80244A40
39119	17952	39.197969000000001	39.239516999999999	52.511485999999998	52.501252000000001	Центральная	0103000020E61000000100000005000000984F560C57994340FD86890629404A40984F560C57994340512E8D5F78414A4003EB387EA89E4340512E8D5F78414A4003EB387EA89E4340FD86890629404A40984F560C57994340FD86890629404A40
39489	18328	39.274963999999997	39.297708999999998	52.609247000000003	52.59722	Ленина	0103000020E61000000100000005000000E6C9350532A34340314278B4714C4A40E6C9350532A34340D31742CEFB4D4A40C85C19541BA64340D31742CEFB4D4A40C85C19541BA64340314278B4714C4A40E6C9350532A34340314278B4714C4A40
38984	17697	39.331871999999997	39.404446999999998	52.473531000000001	52.446199	Советская	0103000020E61000000100000005000000A33A1DC87AAA43400341800C1D394A40A33A1DC87AAA43403352EFA99C3C4A408FFB56EBC4B343403352EFA99C3C4A408FFB56EBC4B343400341800C1D394A40A33A1DC87AAA43400341800C1D394A40
38831	17697	39.331871999999997	39.404446999999998	52.473531000000001	52.446199	Салтыкова-Щедрина	0103000020E61000000100000005000000A33A1DC87AAA43400341800C1D394A40A33A1DC87AAA43403352EFA99C3C4A408FFB56EBC4B343403352EFA99C3C4A408FFB56EBC4B343400341800C1D394A40A33A1DC87AAA43400341800C1D394A40
38935	17697	39.331871999999997	39.404446999999998	52.473531000000001	52.446199	Дзержинского	0103000020E61000000100000005000000A33A1DC87AAA43400341800C1D394A40A33A1DC87AAA43403352EFA99C3C4A408FFB56EBC4B343403352EFA99C3C4A408FFB56EBC4B343400341800C1D394A40A33A1DC87AAA43400341800C1D394A40
39140	17887	39.701456999999998	39.736393	52.760801000000001	52.743172999999999	Московская	0103000020E610000001000000050000006F46CD57C9D943409622F94A205F4A406F46CD57C9D94340CEE15AED61614A406D00362042DE4340CEE15AED61614A406D00362042DE43409622F94A205F4A406F46CD57C9D943409622F94A205F4A40
39192	54759	39.227497	39.847101000000002	53.434846999999998	53.043098000000001	Центрльная	0103000020E610000001000000050000001478279F1E9D4340F2423A3C84854A401478279F1E9D4340C1E10511A9B74A4057B439CE6DEC4340C1E10511A9B74A4057B439CE6DEC4340F2423A3C84854A401478279F1E9D4340F2423A3C84854A40
39474	17613	39.58623	39.623635999999998	53.193159000000001	53.179335000000002	Новая	0103000020E6100000010000000500000090F7AA9509CB43409B030473F4964A4090F7AA9509CB4340CBF6216FB9984A40DB4DF04DD3CF4340CBF6216FB9984A40DB4DF04DD3CF43409B030473F4964A4090F7AA9509CB43409B030473F4964A40
39421	16996	39.564292999999999	39.616539000000003	53.341526999999999	53.331353999999997	Советская	0103000020E610000001000000050000004D2EC6C03AC843400BB3D0CE69AA4A404D2EC6C03AC84340BAD91F28B7AB4A40B2DAFCBFEACE4340BAD91F28B7AB4A40B2DAFCBFEACE43400BB3D0CE69AA4A404D2EC6C03AC843400BB3D0CE69AA4A40
39361	16703	39.435600999999998	39.465299000000002	53.29222	53.281793	Новая	0103000020E610000001000000050000006D8D08C6C1B74340F19E03CB11A44A406D8D08C6C1B743405A9E077767A54A4046EEE9EA8EBB43405A9E077767A54A4046EEE9EA8EBB4340F19E03CB11A44A406D8D08C6C1B74340F19E03CB11A44A40
39312	17485	39.594082	39.63747	53.093397000000003	53.072032	Центральная	0103000020E61000000100000005000000369204E10ACC4340FB21365838894A40369204E10ACC4340B345D26EF48B4A402F17F19D98D14340B345D26EF48B4A402F17F19D98D14340FB21365838894A40369204E10ACC4340FB21365838894A40
39308	16848	39.361193	39.388134000000001	53.206260999999998	53.198720999999999	Графская	0103000020E61000000100000005000000A6457D923BAE4340A30392B06F994A40A6457D923BAE43405AB8ACC2669A4A409B3BFA5FAEB143405AB8ACC2669A4A409B3BFA5FAEB14340A30392B06F994A40A6457D923BAE4340A30392B06F994A40
39415	16604	39.418506000000001	39.438412999999997	53.405687	53.391620000000003	Центральная	0103000020E610000001000000050000000397C79A91B54340D23AAA9A20B24A400397C79A91B54340C8B4368DEDB34A401492CCEA1DB84340C8B4368DEDB34A401492CCEA1DB84340D23AAA9A20B24A400397C79A91B54340D23AAA9A20B24A40
39422	17292	39.693928999999997	39.721786000000002	53.258561	53.246186000000002	Механизаторов	0103000020E610000001000000050000007C5F5CAAD2D84340D55DD905839F4A407C5F5CAAD2D84340B282DF8618A14A40F75AD07B63DC4340B282DF8618A14A40F75AD07B63DC4340D55DD905839F4A407C5F5CAAD2D84340D55DD905839F4A40
39434	17323	39.696821999999997	39.752400999999999	53.213600999999997	53.198014000000001	Горбатовка	0103000020E6100000010000000500000010919A7631D943403813D38558994A4010919A7631D943404AB20E47579B4A40253D0CAD4EE043404AB20E47579B4A40253D0CAD4EE043403813D38558994A4010919A7631D943403813D38558994A40
38980	16295	39.428531	39.482115999999998	53.223748000000001	53.196795000000002	переулок Советский	0103000020E610000001000000050000003D29931ADAB6434017821C9430994A403D29931ADAB64340D04543C6A39C4A406D7022FAB5BD4340D04543C6A39C4A406D7022FAB5BD434017821C9430994A403D29931ADAB6434017821C9430994A40
38865	16295	39.428531	39.482115999999998	53.223748000000001	53.196795000000002	Слонского	0103000020E610000001000000050000003D29931ADAB6434017821C9430994A403D29931ADAB64340D04543C6A39C4A406D7022FAB5BD4340D04543C6A39C4A406D7022FAB5BD434017821C9430994A403D29931ADAB6434017821C9430994A40
38976	16295	39.428531	39.482115999999998	53.223748000000001	53.196795000000002	Коммунистическая	0103000020E610000001000000050000003D29931ADAB6434017821C9430994A403D29931ADAB64340D04543C6A39C4A406D7022FAB5BD4340D04543C6A39C4A406D7022FAB5BD434017821C9430994A403D29931ADAB6434017821C9430994A40
38974	16295	39.428531	39.482115999999998	53.223748000000001	53.196795000000002	Володарского	0103000020E610000001000000050000003D29931ADAB6434017821C9430994A403D29931ADAB64340D04543C6A39C4A406D7022FAB5BD4340D04543C6A39C4A406D7022FAB5BD434017821C9430994A403D29931ADAB6434017821C9430994A40
38982	16295	39.428531	39.482115999999998	53.223748000000001	53.196795000000002	1-ая Садовая	0103000020E610000001000000050000003D29931ADAB6434017821C9430994A403D29931ADAB64340D04543C6A39C4A406D7022FAB5BD4340D04543C6A39C4A406D7022FAB5BD434017821C9430994A403D29931ADAB6434017821C9430994A40
39423	17551	39.598941000000003	39.627346000000003	53.131866000000002	53.110664999999997	Школьная	0103000020E61000000100000005000000E59D4319AACC4340EAE74D452A8E4A40E59D4319AACC434028BA2EFCE0904A4062A3ACDF4CD0434028BA2EFCE0904A4062A3ACDF4CD04340EAE74D452A8E4A40E59D4319AACC4340EAE74D452A8E4A40
39424	16945	39.317965999999998	39.352694999999997	53.157521000000003	53.136560000000003	Поповка	0103000020E61000000100000005000000B69E211CB3A843408CF84ECC7A914A40B69E211CB3A8434074B7EBA529944A403A3B191C25AD434074B7EBA529944A403A3B191C25AD43408CF84ECC7A914A40B69E211CB3A843408CF84ECC7A914A40
39418	16745	39.434460000000001	39.445833	53.256272000000003	53.248900999999996	Центральная	0103000020E61000000100000005000000C8B5A1629CB743408978EBFCDB9F4A40C8B5A1629CB74340B5705985CDA04A40213D450E11B94340B5705985CDA04A40213D450E11B943408978EBFCDB9F4A40C8B5A1629CB743408978EBFCDB9F4A40
39420	16815	39.275117000000002	39.312828000000003	53.251638	53.233263000000001	Центральная	0103000020E610000001000000050000006DC9AA0837A34340F52EDE8FDB9D4A406DC9AA0837A3434026378AAC35A04A40F5A276BF0AA8434026378AAC35A04A40F5A276BF0AA84340F52EDE8FDB9D4A406DC9AA0837A34340F52EDE8FDB9D4A40
39473	17240	39.606721	39.627077	53.243648	53.233764000000001	Школьная	0103000020E61000000100000005000000F165A208A9CD4340B77D8FFAEB9D4A40F165A208A9CD43402FDE8FDB2F9F4A407289230F44D043402FDE8FDB2F9F4A407289230F44D04340B77D8FFAEB9D4A40F165A208A9CD4340B77D8FFAEB9D4A40
39231	16900	39.251482000000003	39.284154000000001	53.179868999999997	53.165134000000002	Школьная	0103000020E610000001000000050000002FC4EA8F30A0434095BA641C23954A402FC4EA8F30A04340384888F205974A40888384285FA44340384888F205974A40888384285FA4434095BA641C23954A402FC4EA8F30A0434095BA641C23954A40
39342	16642	39.390182000000003	39.40654	53.291283999999997	53.277098000000002	Промстроевская	0103000020E6100000010000000500000073BED87BF1B14340BDE47FF277A34A4073BED87BF1B143408DEC4ACB48A54A400742B28009B443408DEC4ACB48A54A400742B28009B44340BDE47FF277A34A4073BED87BF1B14340BDE47FF277A34A40
39362	17095	39.563735999999999	39.583266000000002	53.370103	53.357346	Молодёжная	0103000020E61000000100000005000000F7C9518028C843409FAD8383BDAD4A40F7C9518028C843406493FC885FAF4A40336FD575A8CA43406493FC885FAF4A40336FD575A8CA43409FAD8383BDAD4A40F7C9518028C843409FAD8383BDAD4A40
39364	16537	39.436993000000001	39.467626000000003	53.354126999999998	53.324927000000002	Молодёжная	0103000020E610000001000000050000005CCAF962EFB74340304B3B3597A94A405CCAF962EFB74340B7D0950854AD4A403161342BDBBB4340B7D0950854AD4A403161342BDBBB4340304B3B3597A94A405CCAF962EFB74340304B3B3597A94A40
39456	17666	39.619441000000002	39.679341000000001	53.203488999999998	53.184159000000001	Вязинская	0103000020E610000001000000050000009966BAD749CF4340CD21A98592974A409966BAD749CF4340410C74ED0B9A4A407DEA58A5F4D64340410C74ED0B9A4A407DEA58A5F4D64340CD21A98592974A409966BAD749CF4340CD21A98592974A40
39287	17039	39.630347	39.657969999999999	53.342371	53.333908000000001	Центральная	0103000020E61000000100000005000000DC10E335AFD04340B7EF517FBDAA4A40DC10E335AFD04340A60C1CD0D2AB4A40E3DF675C38D44340A60C1CD0D2AB4A40E3DF675C38D44340B7EF517FBDAA4A40DC10E335AFD04340B7EF517FBDAA4A40
39309	17131	39.673887999999998	39.723483999999999	53.353766999999998	53.330283999999999	Новая	0103000020E610000001000000050000005B9544F641D643402F3201BF46AA4A405B9544F641D64340B7B3AF3C48AD4A40F296AB1F9BDC4340B7B3AF3C48AD4A40F296AB1F9BDC43402F3201BF46AA4A405B9544F641D643402F3201BF46AA4A40
39365	17190	39.764778999999997	39.787336000000003	53.379148999999998	53.372729999999997	Полевая	0103000020E6100000010000000500000073D53C47E4E14340791EDC9DB5AF4A4073D53C47E4E14340D2A755F487B04A40537B116DC7E44340D2A755F487B04A40537B116DC7E44340791EDC9DB5AF4A4073D53C47E4E14340791EDC9DB5AF4A40
39472	17454	39.513539000000002	39.538080999999998	53.216033000000003	53.199767000000001	Центральная	0103000020E610000001000000050000003B1C5DA5BBC14340F7E80DF791994A403B1C5DA5BBC14340ABED26F8A69B4A40ABCC94D6DFC44340ABED26F8A69B4A40ABCC94D6DFC44340F7E80DF791994A403B1C5DA5BBC14340F7E80DF791994A40
39471	16190	38.704236999999999	38.723928000000001	53.106000000000002	53.092320999999998	Школьная	0103000020E610000001000000050000000BD12170245A4340F4DDAD2CD18B4A400BD12170245A434021B07268918D4A40505436ACA95C434021B07268918D4A40505436ACA95C4340F4DDAD2CD18B4A400BD12170245A4340F4DDAD2CD18B4A40
39416	16035	39.396273000000001	39.434756	53.057167	53.035215000000001	Бутырки	0103000020E61000000100000005000000D7A4DB12B9B2434011AAD4EC81844A40D7A4DB12B9B2434089B48D3F51874A40B1DEA815A6B7434089B48D3F51874A40B1DEA815A6B7434011AAD4EC81844A40D7A4DB12B9B2434011AAD4EC81844A40
39469	14983	39.091833999999999	39.115485999999997	52.983021000000001	52.963098000000002	Школьная	0103000020E6100000010000000500000097546D37C18B4340E86B96CB467B4A4097546D37C18B4340FF23D3A1D37D4A40AB92C83EC88E4340FF23D3A1D37D4A40AB92C83EC88E4340E86B96CB467B4A4097546D37C18B4340E86B96CB467B4A40
39390	15231	39.009718999999997	39.040467999999997	53.086615000000002	53.074953000000001	Большой Порядок	0103000020E610000001000000050000002D93E1783E81434059DE550F98894A402D93E1783E814340E92B4833168B4A406B44300E2E854340E92B4833168B4A406B44300E2E85434059DE550F98894A402D93E1783E81434059DE550F98894A40
38863	15939	38.938921999999998	38.994698999999997	52.985298	52.971286999999997	Ленина	0103000020E6100000010000000500000059BF99982E784340D503E621537C4A4059BF99982E7843403868AF3E1E7E4A40942EFD4B527F43403868AF3E1E7E4A40942EFD4B527F4340D503E621537C4A4059BF99982E784340D503E621537C4A40
39311	14892	39.186371999999999	39.222960999999998	52.920226	52.908177000000002	Кривка	0103000020E61000000100000005000000EF71A609DB9743405DFDD8243F744A40EF71A609DB974340E6762FF7C9754A4048A46DFC899C4340E6762FF7C9754A4048A46DFC899C43405DFDD8243F744A40EF71A609DB9743405DFDD8243F744A40
39412	15067	39.362181	39.411121999999999	53.088572999999997	53.078139	Новая	0103000020E61000000100000005000000C51D6FF25BAE434065C57075008A4A40C51D6FF25BAE434080272D5C568B4A4043554CA59FB4434080272D5C568B4A4043554CA59FB4434065C57075008A4A40C51D6FF25BAE434065C57075008A4A40
39511	54782	38.898884000000002	38.916815	53.038274000000001	53.028039999999997	Садовая	0103000020E61000000100000005000000E77283A10E7343406B7D91D096834A40E77283A10E734340C0249529E6844A40BABDA4315A754340C0249529E6844A40BABDA4315A7543406B7D91D096834A40E77283A10E7343406B7D91D096834A40
39502	54776	38.856403	38.880631000000001	53.056496000000003	53.041074000000002	Школьная	0103000020E6100000010000000500000020990E9D9E6D4340A35BAFE941854A4020990E9D9E6D43406B2DCC423B874A40016C4084B87043406B2DCC423B874A40016C4084B8704340A35BAFE941854A4020990E9D9E6D4340A35BAFE941854A40
39230	14854	39.060985000000002	39.071244	52.912613999999998	52.902907999999996	Октябрьская	0103000020E61000000100000005000000F645425BCE874340FCA5457D92734A40F645425BCE87434095EF1989D0744A40A304FD851E89434095EF1989D0744A40A304FD851E894340FCA5457D92734A40F645425BCE874340FCA5457D92734A40
39470	15530	39.139668999999998	39.187835999999997	53.140644000000002	53.112783999999998	Ермаковка	0103000020E61000000100000005000000ECA17DACE09143408BC1C3B46F8E4A40ECA17DACE09143407730629F00924A40778192020B9843407730629F00924A40778192020B9843408BC1C3B46F8E4A40ECA17DACE09143408BC1C3B46F8E4A40
38835	15751	39.146729999999998	39.182769999999998	53.011800000000001	52.972788999999999	Серединка	0103000020E61000000100000005000000C9AB730CC89243404B749659847C4A40C9AB730CC8924340E10B93A982814A404F58E20165974340E10B93A982814A404F58E201659743404B749659847C4A40C9AB730CC89243404B749659847C4A40
37440	15751	39.146729999999998	39.182769999999998	53.011800000000001	52.972788999999999	Воронежская	0103000020E61000000100000005000000C9AB730CC89243404B749659847C4A40C9AB730CC8924340E10B93A982814A404F58E20165974340E10B93A982814A404F58E201659743404B749659847C4A40C9AB730CC89243404B749659847C4A40
39414	15645	39.192704999999997	39.230938000000002	52.873742	52.853017000000001	Почтовая	0103000020E610000001000000050000004963B48EAA9843404DF73AA92F6D4A404963B48EAA984340219221C7D66F4A40ABB35A608F9D4340219221C7D66F4A40ABB35A608F9D43404DF73AA92F6D4A404963B48EAA9843404DF73AA92F6D4A40
39176	15464	39.169924000000002	39.197052999999997	53.110146	53.064300000000003	Школьная	0103000020E610000001000000050000001B67D311C095434000917EFB3A884A401B67D311C095434082E49D43198E4A40124A5F083999434082E49D43198E4A40124A5F083999434000917EFB3A884A401B67D311C095434000917EFB3A884A40
39305	15568	39.165945000000001	39.189264999999999	53.058368000000002	53.041924000000002	Школьная	0103000020E61000000100000005000000A5F78DAF3D954340717500C45D854A40A5F78DAF3D9543400491459A78874A4083A3E4D5399843400491459A78874A4083A3E4D539984340717500C45D854A40A5F78DAF3D954340717500C45D854A40
39358	14691	39.456054999999999	39.481333999999997	52.925069000000001	52.913749000000003	Центральная	0103000020E61000000100000005000000B1169F0260BA434059E02BBAF5744A40B1169F0260BA43408FC536A968764A40F7393E5A9CBD43408FC536A968764A40F7393E5A9CBD434059E02BBAF5744A40B1169F0260BA434059E02BBAF5744A40
38864	13900	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Школьная	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
38836	13900	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Мира	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
37431	13900	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Ленина	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
38829	13900	39.100799000000002	39.188958999999997	53.037143	52.991970999999999	Карла Маркса	0103000020E61000000100000005000000193C4CFBE68C43404BCADDE7F87E4A40193C4CFBE68C43403E23111AC1844A4076A4FACE2F9843403E23111AC1844A4076A4FACE2F9843404BCADDE7F87E4A40193C4CFBE68C43404BCADDE7F87E4A40
39310	16099	39.468640999999998	39.486643000000001	53.059873000000003	53.048360000000002	Садовая	0103000020E610000001000000050000004948A46DFCBB4340A03715A930864A404948A46DFCBB4340EB7420EBA9874A40E6E95C514ABE4340EB7420EBA9874A40E6E95C514ABE4340A03715A930864A404948A46DFCBB4340A03715A930864A40
39419	15357	39.018377999999998	39.044851999999999	52.895271000000001	52.886111	Центральная	0103000020E61000000100000005000000A27BD6355A8243401CD0D2156C714A40A27BD6355A8243405307793D98724A408194D8B5BD8543405307793D98724A408194D8B5BD8543401CD0D2156C714A40A27BD6355A8243401CD0D2156C714A40
39177	15255	39.259135999999998	39.306288000000002	52.878692999999998	52.845458000000001	Центральная	0103000020E61000000100000005000000AE9B525E2BA143401F12BEF7376C4A40AE9B525E2BA14340B01C210379704A402194F77134A74340B01C210379704A402194F77134A743401F12BEF7376C4A40AE9B525E2BA143401F12BEF7376C4A40
39360	15167	39.108345	39.143279999999997	52.779124000000003	52.763612999999999	Школьная	0103000020E61000000100000005000000B2D7BB3FDE8D434075E61E12BE614A40B2D7BB3FDE8D4340ADC3D155BA634A40DF15C1FF56924340ADC3D155BA634A40DF15C1FF5692434075E61E12BE614A40B2D7BB3FDE8D434075E61E12BE614A40
39278	16133	39.508122	39.515003	53.088616000000002	53.083585999999997	Трудовая	0103000020E61000000100000005000000663046240AC14340A43330F2B28A4A40663046240AC1434080F3E2C4578B4A40C32B499EEBC1434080F3E2C4578B4A40C32B499EEBC14340A43330F2B28A4A40663046240AC14340A43330F2B28A4A40
39442	15434	39.020066999999997	39.046505000000003	52.859808999999998	52.838794999999998	Центральная	0103000020E610000001000000050000004A5D328E918243402F8672A25D6B4A404A5D328E918243403AE7A7380E6E4A40DD0C37E0F38543403AE7A7380E6E4A40DD0C37E0F38543402F8672A25D6B4A404A5D328E918243402F8672A25D6B4A40
39413	15119	39.021512999999999	39.063034000000002	52.799807000000001	52.790855000000001	Ленина	0103000020E610000001000000050000002CB81FF0C0824340657094BC3A654A402CB81FF0C0824340520E661360664A409E44847F11884340520E661360664A409E44847F11884340657094BC3A654A402CB81FF0C0824340657094BC3A654A40
39313	15704	39.220077000000003	39.253529999999998	52.819322	52.792053000000003	Центральная	0103000020E6100000010000000500000008CDAE7B2B9C43406FD921FE61654A4008CDAE7B2B9C43405872158BDF684A400647C9AB73A043405872158BDF684A400647C9AB73A043406FD921FE61654A4008CDAE7B2B9C43406FD921FE61654A40
39306	15034	39.284585	39.323033000000002	53.029004	53.017662000000001	Центральная	0103000020E6100000010000000500000051F701486DA44340E43098BF42824A4051F701486DA4434002BA2F67B6834A40AF43352559A9434002BA2F67B6834A40AF43352559A94340E43098BF42824A4051F701486DA44340E43098BF42824A40
39232	14953	39.074351999999998	39.118810000000003	52.974860999999997	52.953854	Центральная	0103000020E610000001000000050000003332C85D8489434053944BE3177A4A403332C85D84894340AB92C83EC87C4A400938842A358F4340AB92C83EC87C4A400938842A358F434053944BE3177A4A403332C85D8489434053944BE3177A4A40
39363	16230	38.735588999999997	38.754983000000003	53.106098000000003	53.091526000000002	Центральная	0103000020E610000001000000050000000F26C5C7275E4340EA5DBC1FB78B4A400F26C5C7275E4340E415889E948D4A409B046F48A3604340E415889E948D4A409B046F48A3604340EA5DBC1FB78B4A400F26C5C7275E4340EA5DBC1FB78B4A40
39151	14795	39.059987999999997	39.099155000000003	52.931984999999997	52.910516999999999	Центральная	0103000020E610000001000000050000008313D1AFAD874340DCB930D28B744A408313D1AFAD87434068AED3484B774A40111E6D1CB18C434068AED3484B774A40111E6D1CB18C4340DCB930D28B744A408313D1AFAD874340DCB930D28B744A40
39307	14661	39.350315000000002	39.409613	52.978395999999996	52.944271999999998	Большак	0103000020E610000001000000050000002D26361FD7AC4340A643A7E7DD784A402D26361FD7AC4340C34483143C7D4A401B82E3326EB44340C34483143C7D4A401B82E3326EB44340A643A7E7DD784A402D26361FD7AC4340A643A7E7DD784A40
39258	54764	39.001821999999997	39.026274000000001	53.043613000000001	53.036059999999999	Октябрьская	0103000020E61000000100000005000000E7340BB43B804340CD58349D9D844A40E7340BB43B80434019575C1C95854A40185E49F25C83434019575C1C95854A40185E49F25C834340CD58349D9D844A40E7340BB43B804340CD58349D9D844A40
39092	54751	38.965899	38.982311000000003	53.055435000000003	53.044657999999998	Советская	0103000020E610000001000000050000009B1E1494A27B43409CC0745AB7854A409B1E1494A27B4340E2067C7E18874A4023C0E95DBC7D4340E2067C7E18874A4023C0E95DBC7D43409CC0745AB7854A409B1E1494A27B43409CC0745AB7854A40
39304	13803	38.924405999999998	38.958353000000002	52.834752999999999	52.807206000000001	Советская	0103000020E61000000100000005000000F31C91EF527643404791B58652674A40F31C91EF52764340739EB12FD96A4A400283A44FAB7A4340739EB12FD96A4A400283A44FAB7A43404791B58652674A40F31C91EF527643404791B58652674A40
39411	13615	38.657443999999998	38.681564000000002	53.04063	53.027822999999998	Центральная	0103000020E61000000100000005000000C879FF1F27544340CE893DB48F834A40C879FF1F27544340459E245D33854A40C310397D3D574340459E245D33854A40C310397D3D574340CE893DB48F834A40C879FF1F27544340CE893DB48F834A40
39408	13731	38.556851000000002	38.574691000000001	52.933276999999997	52.919775999999999	Торговая	0103000020E6100000010000000500000059DFC0E446474340A6D24F38BB754A4059DFC0E446474340F38DE89E75774A401C2785798F494340F38DE89E75774A401C2785798F494340A6D24F38BB754A4059DFC0E446474340A6D24F38BB754A40
39303	13525	38.684914999999997	38.717955000000003	52.988289999999999	52.968890000000002	Парковая	0103000020E6100000010000000500000019C5724BAB574340F2B56796047C4A4019C5724BAB5743405F7B6649807E4A40F67F0EF3E55B43405F7B6649807E4A40F67F0EF3E55B4340F2B56796047C4A4019C5724BAB574340F2B56796047C4A40
39520	54788	38.814784000000003	38.866779000000001	53.035843	53.004815000000001	Новая	0103000020E61000000100000005000000ECA694D74A684340DFC325C79D804A40ECA694D74A6843403065E08096844A4007EE409DF26E43403065E08096844A4007EE409DF26E4340DFC325C79D804A40ECA694D74A684340DFC325C79D804A40
39417	13652	38.617109999999997	38.639074000000001	52.892446	52.878062	Центральная	0103000020E610000001000000050000006C04E275FD4E434020EEEA5564704A406C04E275FD4E434017B9A7AB3B724A40A9DC442DCD51434017B9A7AB3B724A40A9DC442DCD51434020EEEA5564704A406C04E275FD4E434020EEEA5564704A40
39175	12506	38.667352999999999	38.678697999999997	53.062736000000001	53.056793999999996	Клубная	0103000020E6100000010000000500000099F1B6D26B554340F44D9A0645874A4099F1B6D26B5543401424B6BB07884A4028EE7893DF5643401424B6BB07884A4028EE7893DF564340F44D9A0645874A4099F1B6D26B554340F44D9A0645874A40
39466	13557	38.610238000000003	38.629345000000001	53.019238000000001	53.005661000000003	Центральная	0103000020E6100000010000000500000063635E471C4E43406CEEE87FB9804A4063635E471C4E4340946B0A6476824A40587380608E504340946B0A6476824A40587380608E5043406CEEE87FB9804A4063635E471C4E43406CEEE87FB9804A40
39300	12991	38.595756999999999	38.616202999999999	52.784647	52.771501999999998	Клубная	0103000020E6100000010000000500000079AEEFC3414C43403866D993C0624A4079AEEFC3414C4340C7F319506F644A403A596ABDDF4E4340C7F319506F644A403A596ABDDF4E43403866D993C0624A4079AEEFC3414C43403866D993C0624A40
39117	13834	38.985759999999999	39.003456999999997	52.883941999999998	52.873350000000002	Мира	0103000020E610000001000000050000003CDA38622D7E434016FBCBEEC96F4A403CDA38622D7E4340C9C7EE0225714A409CF86A4771804340C9C7EE0225714A409CF86A477180434016FBCBEEC96F4A403CDA38622D7E434016FBCBEEC96F4A40
39357	12951	38.581617000000001	38.605961999999998	52.829737000000002	52.820236000000001	Цветочная	0103000020E6100000010000000500000019E6046D724A43403D80457EFD684A4019E6046D724A4340FDA36FD2346A4A40334FAE29904D4340FDA36FD2346A4A40334FAE29904D43403D80457EFD684A4019E6046D724A43403D80457EFD684A40
38862	13273	38.771782000000002	38.810679	52.876170999999999	52.856883000000003	Первомайская	0103000020E610000001000000050000001CD2A8C0C9624340CBBF9657AE6D4A401CD2A8C0C9624340105A0F5F26704A40E9465854C4674340105A0F5F26704A40E9465854C4674340CBBF9657AE6D4A401CD2A8C0C9624340CBBF9657AE6D4A40
39137	13273	38.771782000000002	38.810679	52.876170999999999	52.856883000000003	Октябрьская	0103000020E610000001000000050000001CD2A8C0C9624340CBBF9657AE6D4A401CD2A8C0C9624340105A0F5F26704A40E9465854C4674340105A0F5F26704A40E9465854C4674340CBBF9657AE6D4A401CD2A8C0C9624340CBBF9657AE6D4A40
38861	13273	38.771782000000002	38.810679	52.876170999999999	52.856883000000003	Красноармейская	0103000020E610000001000000050000001CD2A8C0C9624340CBBF9657AE6D4A401CD2A8C0C9624340105A0F5F26704A40E9465854C4674340105A0F5F26704A40E9465854C4674340CBBF9657AE6D4A401CD2A8C0C9624340CBBF9657AE6D4A40
39079	54750	38.500292999999999	39.027495999999999	53.092818000000001	52.697698000000003	Парковая	0103000020E6100000010000000500000078B5DC9909404340083E062B4E594A4078B5DC9909404340753DD175E18B4A40AA622AFD84834340753DD175E18B4A40AA622AFD84834340083E062B4E594A4078B5DC9909404340083E062B4E594A40
39302	13081	38.745102000000003	38.765555999999997	52.775571999999997	52.763928999999997	Клубная	0103000020E61000000100000005000000941799805F5F4340A5BBEB6CC8614A40941799805F5F4340BED87BF145634A40D7A02FBDFD614340BED87BF145634A40D7A02FBDFD614340A5BBEB6CC8614A40941799805F5F4340A5BBEB6CC8614A40
39369	13142	38.790241999999999	38.827072999999999	52.970267999999997	52.948872999999999	Школьная	0103000020E610000001000000050000007BF65CA6266543405987A3AB74794A407BF65CA6266543407B2DE8BD317C4A40CA332F87DD6943407B2DE8BD317C4A40CA332F87DD6943405987A3AB74794A407BF65CA6266543405987A3AB74794A40
39116	13417	38.688004999999997	38.706994999999999	52.870773999999997	52.861347000000002	Центральная	0103000020E61000000100000005000000033E3F8C10584340FDC0559E406E4A40033E3F8C10584340821ABE85756F4A40BFB7E9CF7E5A4340821ABE85756F4A40BFB7E9CF7E5A4340FDC0559E406E4A40033E3F8C10584340FDC0559E406E4A40
39356	13179	38.922069999999998	38.958973	52.936250999999999	52.924342000000003	Школьная	0103000020E61000000100000005000000B54FC76306764340DD28B2D650764A40B54FC7630676434074ECA012D7774A409E5F94A0BF7A434074ECA012D7774A409E5F94A0BF7A4340DD28B2D650764A40B54FC76306764340DD28B2D650764A40
39135	13048	38.796342000000003	38.817335	52.781945	52.758059000000003	Парковая	0103000020E610000001000000050000003337DF88EE65434020B8CA1308614A403337DF88EE654340A72215C616644A402670EB6E9E684340A72215C616644A402670EB6E9E68434020B8CA1308614A403337DF88EE65434020B8CA1308614A40
39407	12081	38.038128	38.059066999999999	52.629815000000001	52.620314	Советская	0103000020E61000000100000005000000EC87D860E10443401FA0FB72664F4A40EC87D860E1044340DFC325C79D504A40ECA2E8818F074340DFC325C79D504A40ECA2E8818F0743401FA0FB72664F4A40EC87D860E10443401FA0FB72664F4A40
39410	12224	37.973170000000003	38.006112000000002	52.586672	52.572203999999999	Центральная	0103000020E6100000010000000500000063B9A5D590FC4240F8510DFB3D494A4063B9A5D590FC42404DBD6E11184B4A407C0E2C47C80043404DBD6E11184B4A407C0E2C47C8004340F8510DFB3D494A4063B9A5D590FC4240F8510DFB3D494A40
38859	12755	38.013747000000002	38.082711000000003	52.502732000000002	52.469954000000001	Первомайская	0103000020E6100000010000000500000085B53176C2014340EC4FE273273C4A4085B53176C20143408B53AD8559404A407E022846960A43408B53AD8559404A407E022846960A4340EC4FE273273C4A4085B53176C2014340EC4FE273273C4A40
39404	11636	37.892716999999998	37.930087	52.735638000000002	52.721300999999997	Школьная	0103000020E61000000100000005000000A7CAF78C44F242403AC95697535C4A40A7CAF78C44F24240F1D8CF62295E4A40A6B73F170DF74240F1D8CF62295E4A40A6B73F170DF742403AC95697535C4A40A7CAF78C44F242403AC95697535C4A40
39521	54789	37.889412	37.918318999999997	52.716816999999999	52.696109999999997	Маяковского	0103000020E61000000100000005000000C1559E40D8F142409335EA211A594A40C1559E40D8F14240C11BD2A8C05B4A40D0251C7A8BF54240C11BD2A8C05B4A40D0251C7A8BF542409335EA211A594A40C1559E40D8F142409335EA211A594A40
39402	12608	37.924545000000002	37.955706999999997	52.425967	52.413455999999996	Московская	0103000020E610000001000000050000001557957D57F64240E02A4F20EC344A401557957D57F642406E162F1686364A4075C7629B54FA42406E162F1686364A4075C7629B54FA4240E02A4F20EC344A401557957D57F64240E02A4F20EC344A40
39115	12317	37.845565000000001	37.870196999999997	52.586629000000002	52.565733999999999	Ленина	0103000020E6100000010000000500000035D252793BEC42401D1EC2F869484A4035D252793BEC42404EF1B8A8164B4A40E509849D62EF42404EF1B8A8164B4A40E509849D62EF42401D1EC2F869484A4035D252793BEC42401D1EC2F869484A40
39299	11925	38.053165	38.083627	52.713129000000002	52.703722999999997	имени Белякова	0103000020E610000001000000050000005B25581CCE064340B4386398135A4A405B25581CCE064340236AA2CF475B4A4003081F4AB40A4340236AA2CF475B4A4003081F4AB40A4340B4386398135A4A405B25581CCE064340B4386398135A4A40
39133	12114	38.102733999999998	38.122722000000003	52.639378999999998	52.628219000000001	Школьная	0103000020E61000000100000005000000F8174163260D4340E8DCED7A69504A40F8174163260D4340E55FCB2BD7514A40F73FC05AB50F4340E55FCB2BD7514A40F73FC05AB50F4340E8DCED7A69504A40F8174163260D4340E8DCED7A69504A40
39276	12180	37.956085000000002	37.968508	52.639811000000002	52.629387999999999	Центральная	0103000020E610000001000000050000001C9947FE60FA4240573F36C98F504A401C9947FE60FA42407F4FAC53E5514A400AF5F411F8FB42407F4FAC53E5514A400AF5F411F8FB4240573F36C98F504A401C9947FE60FA4240573F36C98F504A40
39409	11683	38.179118000000003	38.201431999999997	52.692273	52.682906000000003	Молодежная	0103000020E61000000100000005000000FE0FB056ED164340001FBC7669574A40FE0FB056ED164340B073D3669C584A40162F1686C8194340B073D3669C584A40162F1686C8194340001FBC7669574A40FE0FB056ED164340001FBC7669574A40
39387	11867	37.922128000000001	37.950560000000003	52.679853999999999	52.668725999999999	Центральная	0103000020E61000000100000005000000EA5C514A08F6424011FE45D098554A40EA5C514A08F642400307B47405574A40617138F3ABF942400307B47405574A40617138F3ABF9424011FE45D098554A40EA5C514A08F6424011FE45D098554A40
39355	11953	37.957818000000003	37.997371000000001	52.892929000000002	52.861842000000003	Луговая	0103000020E6100000010000000500000094C2BCC799FA4240DD28B2D6506E4A4094C2BCC799FA424033535A7F4B724A404A7D59DAA9FF424033535A7F4B724A404A7D59DAA9FF4240DD28B2D6506E4A4094C2BCC799FA4240DD28B2D6506E4A40
38969	11755	37.945134000000003	38.001818	52.704121000000001	52.674280000000003	Советская	0103000020E61000000100000005000000392BA226FAF84240672C9ACE4E564A40392BA226FAF84240A2B60DA3205A4A40A6457D923B004340A2B60DA3205A4A40A6457D923B004340672C9ACE4E564A40392BA226FAF84240672C9ACE4E564A40
38970	11755	37.945134000000003	38.001818	52.704121000000001	52.674280000000003	Ленина	0103000020E61000000100000005000000392BA226FAF84240672C9ACE4E564A40392BA226FAF84240A2B60DA3205A4A40A6457D923B004340A2B60DA3205A4A40A6457D923B004340672C9ACE4E564A40392BA226FAF84240672C9ACE4E564A40
39335	11546	38.245350999999999	38.269874999999999	52.599150999999999	52.587634999999999	Центральная	0103000020E610000001000000050000003C855CA9671F4340137EA99F374B4A403C855CA9671F4340CF2EDFFAB04C4A40068195438B224340CF2EDFFAB04C4A40068195438B224340137EA99F374B4A403C855CA9671F4340137EA99F374B4A40
39354	11506	38.144111000000002	38.163334999999996	52.523941999999998	52.508882	Поселковая	0103000020E6100000010000000500000037FFAF3A72124340F4C29D0B23414A4037FFAF3A721243401B800D8810434A4065A54929E81443401B800D8810434A4065A54929E8144340F4C29D0B23414A4037FFAF3A72124340F4C29D0B23414A40
39298	11452	38.170009	38.195162000000003	52.536619000000002	52.522950000000002	Центральная	0103000020E610000001000000050000004983DBDAC2154340BBB88D06F0424A404983DBDAC2154340C4B46FEEAF444A4003B68311FB184340C4B46FEEAF444A4003B68311FB184340BBB88D06F0424A404983DBDAC2154340BBB88D06F0424A40
39403	11588	37.973063000000003	38.066595	52.781891000000002	52.582425999999998	Центральная	0103000020E610000001000000050000004DF910548DFC4240882B67EF8C4A4A404DF910548DFC4240B404190115644A40DF89592F86084340B404190115644A40DF89592F86084340882B67EF8C4A4A404DF910548DFC4240882B67EF8C4A4A40
39399	12432	37.933878	37.951960999999997	52.518380000000001	52.505462000000001	Центральная	0103000020E61000000100000005000000193A765089F7424075AF93FAB2404A40193A765089F7424043739D465A424A40A208A9DBD9F9424043739D465A424A40A208A9DBD9F9424075AF93FAB2404A40193A765089F7424075AF93FAB2404A40
39338	11359	38.173242999999999	38.207720999999999	52.580145000000002	52.563763000000002	переулок Школьный	0103000020E6100000010000000500000066A19DD32C164340F1D8CF6229484A4066A19DD32C1643400EF8FC30424A4A40A1D80A9A961A43400EF8FC30424A4A40A1D80A9A961A4340F1D8CF6229484A4066A19DD32C164340F1D8CF6229484A40
39194	11359	38.173242999999999	38.207720999999999	52.580145000000002	52.563763000000002	Елецкая	0103000020E6100000010000000500000066A19DD32C164340F1D8CF6229484A4066A19DD32C1643400EF8FC30424A4A40A1D80A9A961A43400EF8FC30424A4A40A1D80A9A961A4340F1D8CF6229484A4066A19DD32C164340F1D8CF6229484A40
39467	11255	38.734439000000002	38.756186999999997	52.367635999999997	52.351483000000002	Центральная	0103000020E6100000010000000500000017F4DE18025E4340CC0C1B65FD2C4A4017F4DE18025E4340876A4AB20E2F4A40865451BCCA604340876A4AB20E2F4A40865451BCCA604340CC0C1B65FD2C4A4017F4DE18025E4340CC0C1B65FD2C4A40
39296	11299	38.762224000000003	38.785966000000002	52.350504000000001	52.334856000000002	Советская	0103000020E61000000100000005000000F81C588E90614340486FB88FDC2A4A40F81C588E90614340008FA850DD2C4A404CE2AC889A644340008FA850DD2C4A404CE2AC889A644340486FB88FDC2A4A40F81C588E90614340486FB88FDC2A4A40
39346	10711	39.069330999999998	39.117013	52.504331999999998	52.488477000000003	Молодежная	0103000020E61000000100000005000000ABCC94D6DF88434092EC116A863E4A40ABCC94D6DF884340C32973F38D404A407A1A3048FA8E4340C32973F38D404A407A1A3048FA8E434092EC116A863E4A40ABCC94D6DF88434092EC116A863E4A40
39139	11075	38.873641999999997	38.899827999999999	52.475275000000003	52.462668000000001	Степанищева	0103000020E61000000100000005000000BD344580D36F4340EF737CB4383B4A40BD344580D36F43409FCDAACFD53C4A4036035C902D7343409FCDAACFD53C4A4036035C902D734340EF737CB4383B4A40BD344580D36F4340EF737CB4383B4A40
39226	9255	38.940530000000003	38.989524000000003	52.369148000000003	52.342371999999997	Центральная	0103000020E6100000010000000500000015747B496378434076887FD8D22B4A4015747B496378434021B1DD3D402F4A40B64DF1B8A87E434021B1DD3D402F4A40B64DF1B8A87E434076887FD8D22B4A4015747B496378434076887FD8D22B4A40
39490	9312	38.913958000000001	38.939120000000003	52.427855999999998	52.400067	Карла-Маркса	0103000020E6100000010000000500000073F56393FC744340BB9A3C6535334A4073F56393FC744340DDB243FCC3364A4080828B1535784340DDB243FCC3364A4080828B1535784340BB9A3C6535334A4073F56393FC744340BB9A3C6535334A40
39341	10846	38.987161999999998	39.013078	52.706057999999999	52.696120999999998	Школьная	0103000020E610000001000000050000004EED0C535B7E43408787307E1A594A404EED0C535B7E4340228AC91B605A4A400726378AAC814340228AC91B605A4A400726378AAC8143408787307E1A594A404EED0C535B7E43408787307E1A594A40
39524	54791	38.757409000000003	38.773784999999997	52.507989000000002	52.500435000000003	Дорожная	0103000020E61000000100000005000000195932C7F26043400B630B410E404A40195932C7F260434027DD96C805414A4053910A630B63434027DD96C805414A4053910A630B6343400B630B410E404A40195932C7F26043400B630B410E404A40
39386	9296	38.936048	38.963903999999999	52.381276	52.365518999999999	Задонская	0103000020E610000001000000050000003CBEBD6BD077434087889B53C92E4A403CBEBD6BD0774340F65FE7A6CD304A40E63DCE34617B4340F65FE7A6CD304A40E63DCE34617B434087889B53C92E4A403CBEBD6BD077434087889B53C92E4A40
39336	10587	38.893441000000003	38.924531000000002	52.255383000000002	52.239773	Клубная	0103000020E61000000100000005000000E9F351465C7243405EBBB4E1B01E4A40E9F351465C724340297AE063B0204A40B091240857764340297AE063B0204A40B0912408577643405EBBB4E1B01E4A40E9F351465C7243405EBBB4E1B01E4A40
39359	54772	39.021064000000003	39.039453000000002	52.343620999999999	52.331350999999998	Сосновая	0103000020E61000000100000005000000BD8FA339B28243409A3FA6B5692A4A40BD8FA339B2824340029CDEC5FB2B4A40535DC0CB0C854340029CDEC5FB2B4A40535DC0CB0C8543409A3FA6B5692A4A40BD8FA339B28243409A3FA6B5692A4A40
39332	10775	38.912574999999997	38.937385999999996	52.679335999999999	52.654688999999998	Советская	0103000020E61000000100000005000000D712F241CF744340850662D9CC534A40D712F241CF7443406B7F677BF4564A4037DDB243FC7743406B7F677BF4564A4037DDB243FC774340850662D9CC534A40D712F241CF744340850662D9CC534A40
39337	10655	39.038662000000002	39.078709000000003	52.569133000000001	52.553761000000002	Школьная	0103000020E610000001000000050000008ACC5CE0F28443406F66F4A3E1464A408ACC5CE0F28443408509A359D9484A405073F222138A43408509A359D9484A405073F222138A43406F66F4A3E1464A408ACC5CE0F28443406F66F4A3E1464A40
39293	10241	39.022069999999999	39.056798999999998	52.404170999999998	52.391768999999996	Покровская	0103000020E61000000100000005000000821C9430D3824340164B917C25324A40821C9430D3824340ED7E15E0BB334A4006B98B3045874340ED7E15E0BB334A4006B98B3045874340164B917C25324A40821C9430D3824340164B917C25324A40
39113	10089	38.804768000000003	38.858550000000001	52.392955999999998	52.376613999999996	Запрудная	0103000020E61000000100000005000000056F48A3026743409D9B36E334304A40056F48A3026743402C62D8614C324A408BFD65F7E46D43402C62D8614C324A408BFD65F7E46D43409D9B36E334304A40056F48A3026743409D9B36E334304A40
39247	10469	38.789326000000003	38.804822000000001	52.274794999999997	52.264158000000002	Заводская	0103000020E61000000100000005000000F6F065A208654340077DE9EDCF214A40F6F065A2086543405A0D897B2C234A40F88C4468046743405A0D897B2C234A40F88C446804674340077DE9EDCF214A40F6F065A208654340077DE9EDCF214A40
39385	9182	38.797887000000003	38.827989000000002	52.368378	52.342289999999998	Центральная	0103000020E61000000100000005000000A873452921664340B9DFA128D02B4A40A8734529216643406F48A302272F4A405039268BFB6943406F48A302272F4A405039268BFB694340B9DFA128D02B4A40A873452921664340B9DFA128D02B4A40
39522	54790	38.631698	39.251095999999997	52.794297	52.135596999999997	Кленовая	0103000020E610000001000000050000006C79E57ADB504340C537143E5B114A406C79E57ADB504340CC272B86AB654A400514EAE923A04340CC272B86AB654A400514EAE923A04340C537143E5B114A406C79E57ADB504340C537143E5B114A40
39340	9087	38.815009000000003	38.842120000000001	52.466661999999999	52.459139999999998	Молодежная	0103000020E610000001000000050000000C7904375268434089247A19C53A4A400C790437526843409A249694BB3B4A405DA79196CA6B43409A249694BB3B4A405DA79196CA6B434089247A19C53A4A400C7904375268434089247A19C53A4A40
39114	10375	38.928080000000001	38.958640000000003	52.301644000000003	52.278106000000001	Центральная	0103000020E610000001000000050000002D095053CB764340236937FA98234A402D095053CB7643406F8445459C264A4098512CB7B47A43406F8445459C264A4098512CB7B47A4340236937FA98234A402D095053CB764340236937FA98234A40
39512	9013	38.865969999999997	38.893943999999998	52.435949999999998	52.422502000000001	Солнечная	0103000020E6100000010000000500000097A8DE1AD86E43404F3FA88B14364A4097A8DE1AD86E43407958A835CD374A404B3ACAC16C7243407958A835CD374A404B3ACAC16C7243404F3FA88B14364A4097A8DE1AD86E43404F3FA88B14364A40
39462	9013	38.865969999999997	38.893943999999998	52.435949999999998	52.422502000000001	Мира	0103000020E6100000010000000500000097A8DE1AD86E43404F3FA88B14364A4097A8DE1AD86E43407958A835CD374A404B3ACAC16C7243407958A835CD374A404B3ACAC16C7243404F3FA88B14364A4097A8DE1AD86E43404F3FA88B14364A40
39454	11157	38.847186000000001	38.864102000000003	52.475943999999998	52.467995999999999	Молодежная	0103000020E6100000010000000500000085D04197706C43405454FD4AE73B4A4085D04197706C43401C5DA5BBEB3C4A404034F3E49A6E43401C5DA5BBEB3C4A404034F3E49A6E43405454FD4AE73B4A4085D04197706C43405454FD4AE73B4A40
39295	10247	38.949747000000002	38.971854999999998	52.488838000000001	52.475769	Донская	0103000020E61000000100000005000000B03C484F91794340AEB9A3FFE53C4A40B03C484F9179434062855B3E923E4A401FBAA0BE657C434062855B3E923E4A401FBAA0BE657C4340AEB9A3FFE53C4A40B03C484F91794340AEB9A3FFE53C4A40
39464	10165	39.067103000000003	39.111730999999999	52.403886	52.392263999999997	Центральная	0103000020E61000000100000005000000543BC3D496884340F6B2EDB435324A40543BC3D496884340F8A75489B2334A4085798F334D8E4340F8A75489B2334A4085798F334D8E4340F6B2EDB435324A40543BC3D496884340F6B2EDB435324A40
39453	9951	38.755656999999999	38.775914	52.386189999999999	52.371187999999997	Центральная	0103000020E610000001000000050000002AFF5A5EB96043407555A016832F4A402AFF5A5EB9604340680586AC6E314A401841632651634340680586AC6E314A4018416326516343407555A016832F4A402AFF5A5EB96043407555A016832F4A40
39111	9935	38.731150999999997	38.782147999999999	52.302933000000003	52.274343000000002	Весенняя	0103000020E6100000010000000500000006B8205B965D43407A71E2AB1D234A4006B8205B965D434089F02F82C6264A40DF50F86C1D64434089F02F82C6264A40DF50F86C1D6443407A71E2AB1D234A4006B8205B965D43407A71E2AB1D234A40
39465	9448	39.114705000000001	39.152639999999998	52.602410999999996	52.573999000000001	Центральная	0103000020E6100000010000000500000006D847A7AE8E4340E6779ACC78494A4006D847A7AE8E434015E0BBCD1B4D4A40DD0720B58993434015E0BBCD1B4D4A40DD0720B589934340E6779ACC78494A4006D847A7AE8E4340E6779ACC78494A40
39038	54739	38.906412000000003	38.948416999999999	52.402214999999998	52.375751000000001	Советская	0103000020E61000000100000005000000DA59F44E057443403B38D89B18304A40DA59F44E05744340F67AF7C77B334A4037FC6EBA65794340F67AF7C77B334A4037FC6EBA657943403B38D89B18304A40DA59F44E057443403B38D89B18304A40
38972	54739	38.906412000000003	38.948416999999999	52.402214999999998	52.375751000000001	Свободы	0103000020E61000000100000005000000DA59F44E057443403B38D89B18304A40DA59F44E05744340F67AF7C77B334A4037FC6EBA65794340F67AF7C77B334A4037FC6EBA657943403B38D89B18304A40DA59F44E057443403B38D89B18304A40
39275	9868	39.012036000000002	39.020274000000001	52.631821000000002	52.621571000000003	Первомайская	0103000020E61000000100000005000000F52F49658A8143402E9276A38F4F4A40F52F49658A81434088F6B182DF504A40C47AA3569882434088F6B182DF504A40C47AA356988243402E9276A38F4F4A40F52F49658A8143402E9276A38F4F4A40
39389	9633	38.935085999999998	39.013050999999997	52.633335000000002	52.598877000000002	Свердлова	0103000020E610000001000000050000004679E6E5B0774340CEA96400A84C4A404679E6E5B0774340C2340C1F11514A400D17B9A7AB814340C2340C1F11514A400D17B9A7AB814340CEA96400A84C4A404679E6E5B0774340CEA96400A84C4A40
39174	9633	38.935085999999998	39.013050999999997	52.633335000000002	52.598877000000002	Октябрьская	0103000020E610000001000000050000004679E6E5B0774340CEA96400A84C4A404679E6E5B0774340C2340C1F11514A400D17B9A7AB814340C2340C1F11514A400D17B9A7AB814340CEA96400A84C4A404679E6E5B0774340CEA96400A84C4A40
38931	9633	38.935085999999998	39.013050999999997	52.633335000000002	52.598877000000002	Мира	0103000020E610000001000000050000004679E6E5B0774340CEA96400A84C4A404679E6E5B0774340C2340C1F11514A400D17B9A7AB814340C2340C1F11514A400D17B9A7AB814340CEA96400A84C4A404679E6E5B0774340CEA96400A84C4A40
39405	9633	38.935085999999998	39.013050999999997	52.633335000000002	52.598877000000002	 Новая	0103000020E610000001000000050000004679E6E5B0774340CEA96400A84C4A404679E6E5B0774340C2340C1F11514A400D17B9A7AB814340C2340C1F11514A400D17B9A7AB814340CEA96400A84C4A404679E6E5B0774340CEA96400A84C4A40
39294	10530	38.861801999999997	38.887169999999998	52.264786999999998	52.244900999999999	Ерисова	0103000020E610000001000000050000004ED026874F6E4340FCE07CEA581F4A404ED026874F6E4340F6B3588AE4214A4004FF5BC98E714340F6B3588AE4214A4004FF5BC98E714340FCE07CEA581F4A404ED026874F6E4340FCE07CEA581F4A40
38987	9511	39.062565999999997	39.131207000000003	52.338031000000001	52.312074000000003	Ленина	0103000020E61000000100000005000000B7EBA5290288434049F7730AF2274A40B7EBA5290288434060048D99442B4A40CE001764CB90434060048D99442B4A40CE001764CB90434049F7730AF2274A40B7EBA5290288434049F7730AF2274A40
39503	54777	38.891643999999999	38.908774999999999	52.603788999999999	52.595649999999999	Рабочая	0103000020E610000001000000050000005AD6FD632172434063EE5A423E4C4A405AD6FD63217243409F573CF5484D4A4011363CBD527443409F573CF5484D4A4011363CBD5274434063EE5A423E4C4A405AD6FD632172434063EE5A423E4C4A40
39491	10801	38.952010999999999	38.957940000000001	52.750897999999999	52.747850999999997	Молодежная	0103000020E610000001000000050000005437177FDB794340F4A3E194B95F4A405437177FDB794340DF50F86C1D604A40DFC325C79D7A4340DF50F86C1D604A40DFC325C79D7A4340F4A3E194B95F4A405437177FDB794340F4A3E194B95F4A40
39138	9376	39.038257999999999	39.073104000000001	52.610931000000001	52.59263	Центральная	0103000020E61000000100000005000000BA675DA3E58443407250C24CDB4B4A40BA675DA3E5844340698EACFC324E4A40789ACC785B894340698EACFC324E4A40789ACC785B8943407250C24CDB4B4A40BA675DA3E58443407250C24CDB4B4A40
39291	9166	38.87003	38.912503000000001	52.356873	52.336325000000002	Молодежная	0103000020E61000000100000005000000FA449E245D6F4340E2E995B20C2B4A40FA449E245D6F4340A7E9B303AE2D4A403E40F7E5CC744340A7E9B303AE2D4A403E40F7E5CC744340E2E995B20C2B4A40FA449E245D6F4340E2E995B20C2B4A40
39468	9133	38.954796000000002	38.979598000000003	52.554482999999998	52.539878000000002	Центральная	0103000020E61000000100000005000000022D5DC1367A43403AEAE8B81A454A40022D5DC1367A43400F98874CF9464A400F9D9E77637D43400F98874CF9464A400F9D9E77637D43403AEAE8B81A454A40022D5DC1367A43403AEAE8B81A454A40
39228	8996	38.844698000000001	38.879902999999999	52.421661999999998	52.406896000000003	Центральная	0103000020E61000000100000005000000917F66101F6C4340C66F0A2B15344A40917F66101F6C4340A4FB3905F9354A407E5358A9A0704340A4FB3905F9354A407E5358A9A0704340C66F0A2B15344A40917F66101F6C4340C66F0A2B15344A40
39297	10406	38.840440000000001	38.873327000000003	52.303373999999998	52.283251999999997	Центральная	0103000020E610000001000000050000000820B589936B43406743FE9941244A400820B589936B4340753A90F5D4264A405EDBDB2DC96F4340753A90F5D4264A405EDBDB2DC96F43406743FE9941244A400820B589936B43406743FE9941244A40
39447	7655	38.400525999999999	38.451416000000002	52.527853999999998	52.512723999999999	Клубная	0103000020E610000001000000050000004E999B6F44334340E9EFA5F0A0414A404E999B6F44334340098849B890434A401172DEFFC7394340098849B890434A401172DEFFC7394340E9EFA5F0A0414A404E999B6F44334340E9EFA5F0A0414A40
39249	8682	38.693727000000003	38.740223999999998	52.704290999999998	52.681345	Советская	0103000020E6100000010000000500000015ADDC0BCC58434085251E5036574A4015ADDC0BCC584340FEEE1D35265A4A406EDBF7A8BF5E4340FEEE1D35265A4A406EDBF7A8BF5E434085251E5036574A4015ADDC0BCC58434085251E5036574A40
37430	8431	38.428904000000003	38.463200999999998	52.657060000000001	52.647734	Совхозная	0103000020E61000000100000005000000D28F8653E6364340EE409DF2E8524A40D28F8653E636434040C1C58A1A544A40BC3C9D2B4A3B434040C1C58A1A544A40BC3C9D2B4A3B4340EE409DF2E8524A40D28F8653E6364340EE409DF2E8524A40
39507	54779	38.674081000000001	38.691194000000003	52.548580000000001	52.537610000000001	Садовая	0103000020E6100000010000000500000070ED44494856434054008C67D0444A4070ED444948564340AE9E93DE37464A408198840B79584340AE9E93DE37464A408198840B7958434054008C67D0444A4070ED44494856434054008C67D0444A40
39459	7827	38.632570000000001	38.656725999999999	52.675136999999999	52.666710999999999	Центральная	0103000020E610000001000000050000002237C30DF850434015713AC956554A402237C30DF8504340E7A8A3E36A564A406937FA980F544340E7A8A3E36A564A406937FA980F54434015713AC956554A402237C30DF850434015713AC956554A40
38856	8013	38.704166000000001	38.745955000000002	52.719779000000003	52.700378000000001	Советская	0103000020E61000000100000005000000427A8A1C225A4340406B7EFCA5594A40427A8A1C225A43407EACE0B7215C4A40D3A414747B5F43407EACE0B7215C4A40D3A414747B5F4340406B7EFCA5594A40427A8A1C225A4340406B7EFCA5594A40
38880	7252	38.559752000000003	38.591652000000003	52.598505000000003	52.586246000000003	Первомайская	0103000020E6100000010000000500000070EF1AF4A547434096B4E21B0A4B4A4070EF1AF4A54743400ABFD4CF9B4C4A40774EB340BB4B43400ABFD4CF9B4C4A40774EB340BB4B434096B4E21B0A4B4A4070EF1AF4A547434096B4E21B0A4B4A40
38967	8526	38.720182999999999	38.737321999999999	52.624730999999997	52.611756999999997	Лорха	0103000020E610000001000000050000004D11E0F42E5C4340AE0CAA0D4E4E4A404D11E0F42E5C434010E6762FF74F4A40874F3A91605E434010E6762FF74F4A40874F3A91605E4340AE0CAA0D4E4E4A404D11E0F42E5C4340AE0CAA0D4E4E4A40
39455	7690	38.344372	38.387680000000003	52.479438000000002	52.455534999999998	Клубная	0103000020E610000001000000050000003DD4B661142C434078978BF84E3A4A403DD4B661142C4340D63A71395E3D4A401AA88C7F9F314340D63A71395E3D4A401AA88C7F9F31434078978BF84E3A4A403DD4B661142C434078978BF84E3A4A40
39172	8324	38.346967999999997	38.392404999999997	52.591804000000003	52.574365999999998	Школьная	0103000020E6100000010000000500000017618A72692C434098F738D384494A4017618A72692C43402DD2C43BC04B4A40B8E4B8533A3243402DD2C43BC04B4A40B8E4B8533A32434098F738D384494A4017618A72692C434098F738D384494A40
39171	8397	38.390106000000003	38.427278000000001	52.577610999999997	52.552802	Клубная	0103000020E6100000010000000500000098FC4FFEEE314340EA944737C2464A4098FC4FFEEE314340A9674128EF494A407026A60BB1364340A9674128EF494A407026A60BB1364340EA944737C2464A4098FC4FFEEE314340EA944737C2464A40
39169	7424	38.251252999999998	38.266551	52.497633	52.490116	Школьная	0103000020E61000000100000005000000CD02ED0E29204340889FFF1EBC3E4A40CD02ED0E2920434087342A70B23F4A40A9DBD9571E22434087342A70B23F4A40A9DBD9571E224340889FFF1EBC3E4A40CD02ED0E29204340889FFF1EBC3E4A40
39227	8235	38.551012	38.573658000000002	52.448405000000001	52.441713999999997	Мира	0103000020E610000001000000050000000EDAAB8F87464340B91798158A384A400EDAAB8F87464340732EC55565394A405D8B16A06D494340732EC55565394A405D8B16A06D494340B91798158A384A400EDAAB8F87464340B91798158A384A40
38928	8179	38.484482999999997	38.507218999999999	52.584122999999998	52.568755000000003	Северная	0103000020E61000000100000005000000E63BF889033E4340DF37BEF6CC484A40E63BF889033E4340B3EBDE8AC44A4A4075745C8DEC404340B3EBDE8AC44A4A4075745C8DEC404340DF37BEF6CC484A40E63BF889033E4340DF37BEF6CC484A40
39274	7569	38.344479999999997	38.378374000000001	52.542715000000001	52.526516999999998	Транспортная	0103000020E610000001000000050000002310AFEB172C4340DEE4B7E864434A402310AFEB172C43403A0664AF77454A400FD4298F6E3043403A0664AF77454A400FD4298F6E304340DEE4B7E864434A402310AFEB172C4340DEE4B7E864434A40
38858	8570	38.606338999999998	38.647733000000002	52.463282999999997	52.451413000000002	Октябрьская	0103000020E6100000010000000500000009A52F849C4D4340A0FEB3E6C7394A4009A52F849C4D434079E57ADB4C3B4A401EC539EAE852434079E57ADB4C3B4A401EC539EAE8524340A0FEB3E6C7394A4009A52F849C4D4340A0FEB3E6C7394A40
38828	8120	38.519022999999997	38.550607999999997	52.595945	52.576028999999998	Клубная	0103000020E61000000100000005000000976F7D586F42434017467A51BB494A40976F7D586F4243407C9BFEEC474C4A403E75AC527A4643407C9BFEEC474C4A403E75AC527A46434017467A51BB494A40976F7D586F42434017467A51BB494A40
38966	7929	38.231571000000002	38.295163000000002	52.642319000000001	52.599206000000002	Мира	0103000020E61000000100000005000000DCD9571EA41D434093C83EC8B24C4A40DCD9571EA41D4340BA4C4D8237524A40A0FEB3E6C7254340BA4C4D8237524A40A0FEB3E6C725434093C83EC8B24C4A40DCD9571EA41D434093C83EC8B24C4A40
38927	7929	38.231571000000002	38.295163000000002	52.642319000000001	52.599206000000002	Заводская	0103000020E61000000100000005000000DCD9571EA41D434093C83EC8B24C4A40DCD9571EA41D4340BA4C4D8237524A40A0FEB3E6C7254340BA4C4D8237524A40A0FEB3E6C725434093C83EC8B24C4A40DCD9571EA41D434093C83EC8B24C4A40
39292	8072	38.460721999999997	38.665852000000001	52.477978999999998	52.401511999999997	Центральная	0103000020E610000001000000050000001B4641F0F83A4340CC79C6BE64334A401B4641F0F83A43405F96766A2E3D4A40F4FC69A33A5543405F96766A2E3D4A40F4FC69A33A554340CC79C6BE64334A401B4641F0F83A4340CC79C6BE64334A40
39401	8072	38.460721999999997	38.665852000000001	52.477978999999998	52.401511999999997	Рабочая	0103000020E610000001000000050000001B4641F0F83A4340CC79C6BE64334A401B4641F0F83A43405F96766A2E3D4A40F4FC69A33A5543405F96766A2E3D4A40F4FC69A33A554340CC79C6BE64334A401B4641F0F83A4340CC79C6BE64334A40
39461	8701	38.756492000000001	38.781888000000002	52.696677999999999	52.676862	40 лет Победы	0103000020E61000000100000005000000C3D7D7BAD4604340DCF3FC69A3564A40C3D7D7BAD4604340DDEBA4BE2C594A404391EEE714644340DDEBA4BE2C594A404391EEE714644340DCF3FC69A3564A40C3D7D7BAD4604340DCF3FC69A3564A40
39112	7788	38.562770999999998	38.580790999999998	52.639094999999998	52.627595999999997	50 лет Октября	0103000020E61000000100000005000000901150E108484340DA8CD31055504A40901150E108484340C0046EDDCD514A40D367075C574A4340C0046EDDCD514A40D367075C574A4340DA8CD31055504A40901150E108484340DA8CD31055504A40
39450	7403	38.682389999999998	38.712457000000001	52.56673	52.548290000000001	Клубная	0103000020E61000000100000005000000088F368E58574340A75CE15D2E464A40088F368E58574340BFD4CF9B8A484A4034677DCA315B4340BFD4CF9B8A484A4034677DCA315B4340A75CE15D2E464A40088F368E58574340A75CE15D2E464A40
39397	7732	38.816239000000003	38.863050999999999	52.708655999999998	52.678936999999998	Центральная	0103000020E61000000100000005000000215C01857A684340AD855968E7564A40215C01857A6843409D0E643DB55A4A40DAE38574786E43409D0E643DB55A4A40DAE38574786E4340AD855968E7564A40215C01857A684340AD855968E7564A40
38930	54734	38.129091000000003	38.935796000000003	52.785943000000003	52.389899999999997	Советская	0103000020E610000001000000050000009E9ACB0D86104340EE5A423EE8314A409E9ACB0D8610434094C2BCC799644A4023DDCF29C877434094C2BCC799644A4023DDCF29C8774340EE5A423EE8314A409E9ACB0D86104340EE5A423EE8314A40
38875	7612	38.474178999999999	38.508971000000003	52.539181999999997	52.516002	Клубная	0103000020E6100000010000000500000099B9C0E5B13C4340D655815A0C424A4099B9C0E5B13C4340C24B70EA03454A4064CE33F625414340C24B70EA03454A4064CE33F625414340D655815A0C424A4099B9C0E5B13C4340D655815A0C424A40
39460	7535	38.276127000000002	38.298217000000001	52.533442000000001	52.517634999999999	Придорожная	0103000020E610000001000000050000007445292158234340EA211ADD41424A4074452921582343400B28D4D347444A403D0E83F92B2643400B28D4D347444A403D0E83F92B264340EA211ADD41424A407445292158234340EA211ADD41424A40
39396	7339	38.741624999999999	38.774369	52.556372000000003	52.536422000000002	Советская	0103000020E61000000100000005000000B0726891ED5E43406E6DE179A9444A40B0726891ED5E43407F349C3237474A40A304FD851E6343407F349C3237474A40A304FD851E6343406E6DE179A9444A40B0726891ED5E43406E6DE179A9444A40
39277	7298	38.594822999999998	38.624997	52.571136000000003	52.554597999999999	Клубная	0103000020E610000001000000050000004DF4F928234C4340A8363811FD464A404DF4F928234C4340BDC804FC1A494A408F8CD5E6FF4F4340BDC804FC1A494A408F8CD5E6FF4F4340A8363811FD464A404DF4F928234C4340A8363811FD464A40
39458	7878	38.579300000000003	38.602629	52.694603999999998	52.672691	Библиотечная	0103000020E6100000010000000500000052499D80264A434022A81ABD1A564A4052499D80264A4340DCD5ABC8E8584A40834F73F2224D4340DCD5ABC8E8584A40834F73F2224D434022A81ABD1A564A4052499D80264A434022A81ABD1A564A40
39383	54773	37.977096000000003	38.720497000000002	52.502101000000003	52.180697000000002	Фруктовая	0103000020E61000000100000005000000B686527B11FD42401FBE4C1421174A40B686527B11FD4240FB2477D844404A40DDEEE53E395C4340FB2477D844404A40DDEEE53E395C43401FBE4C1421174A40B686527B11FD42401FBE4C1421174A40
39394	3746	38.552027000000002	38.569867000000002	52.308214	52.298329000000003	Тепленькая	0103000020E6100000010000000500000027C11BD2A8464340653909A52F264A4027C11BD2A8464340AD156D8E73274A40EA08E066F1484340AD156D8E73274A40EA08E066F1484340653909A52F264A4027C11BD2A8464340653909A52F264A40
39398	4387	38.202635999999998	38.241928000000001	52.424413000000001	52.393977999999997	Архангельская	0103000020E61000000100000005000000027FF8F9EF194340F7AB00DF6D324A40027FF8F9EF194340A67F492A53364A404CFE277FF71E4340A67F492A53364A404CFE277FF71E4340F7AB00DF6D324A40027FF8F9EF194340F7AB00DF6D324A40
38956	4559	38.293447	38.342872	52.425643000000001	52.396720000000002	Центральная	0103000020E61000000100000005000000FE0DDAAB8F254340A6D590B8C7324A40FE0DDAAB8F254340BB6246787B364A40685BCD3AE32B4340BB6246787B364A40685BCD3AE32B4340A6D590B8C7324A40FE0DDAAB8F254340A6D590B8C7324A40
39273	3543	38.613084999999998	38.652997999999997	52.346272999999997	52.321993999999997	Центральная	0103000020E610000001000000050000008655BC91794E43400DC1711937294A408655BC91794E4340703E75AC522C4A403C2D3F7095534340703E75AC522C4A403C2D3F70955343400DC1711937294A408655BC91794E43400DC1711937294A40
39445	4494	38.240850000000002	38.269992000000002	52.461488000000003	52.449782999999996	Соборная	0103000020E61000000100000005000000ED9E3C2CD41E4340FCA5457D92394A40ED9E3C2CD41E43408CBFED09123B4A4040170D198F2243408CBFED09123B4A4040170D198F224340FCA5457D92394A40ED9E3C2CD41E4340FCA5457D92394A40
39352	3839	38.622526999999998	38.661935999999997	52.263210000000001	52.247835000000002	Речная	0103000020E6100000010000000500000041F0F8F6AE4F4340EFE6A90EB91F4A4041F0F8F6AE4F434076FD82DDB0214A40C405A051BA54434076FD82DDB0214A40C405A051BA544340EFE6A90EB91F4A4041F0F8F6AE4F4340EFE6A90EB91F4A40
39271	3916	38.406041999999999	38.439441000000002	52.258584999999997	52.250861999999998	Дорожная	0103000020E61000000100000005000000B6662B2FF933434092E7FA3E1C204A40B6662B2FF93343403A1E335019214A40C2C2499A3F3843403A1E335019214A40C2C2499A3F38434092E7FA3E1C204A40B6662B2FF933434092E7FA3E1C204A40
39272	4127	38.157899999999998	38.182378999999997	52.330503	52.314627999999999	Школьная	0103000020E61000000100000005000000EA04341136144340F433F5BA45284A40EA043411361443406D1D1CEC4D2A4A40143DF031581743406D1D1CEC4D2A4A40143DF03158174340F433F5BA45284A40EA04341136144340F433F5BA45284A40
39392	54775	38.569867000000002	38.607712999999997	52.304954000000002	52.290585	Нижняя	0103000020E61000000100000005000000EA08E066F1484340A5DAA7E331254A40EA08E066F1484340676490BB08274A40512D228AC94D4340676490BB08274A40512D228AC94D4340A5DAA7E331254A40EA08E066F1484340A5DAA7E331254A40
39444	4270	38.035063999999998	38.084076000000003	52.423067000000003	52.407083	Центральная	0103000020E610000001000000050000002BA226FA7C044340F8E0B54B1B344A402BA226FA7C0443402882380F27364A4073309B00C30A43402882380F27364A4073309B00C30A4340F8E0B54B1B344A402BA226FA7C044340F8E0B54B1B344A40
39301	54769	38.45579	38.488973999999999	52.320991999999997	52.305422	Центральная	0103000020E6100000010000000500000003ECA353573A43404DBD6E1118274A4003ECA353573A434089230F4416294A40124C35B3963E434089230F4416294A40124C35B3963E43404DBD6E1118274A4003ECA353573A43404DBD6E1118274A40
39105	3326	38.372463000000003	38.402673	52.335675999999999	52.323106000000003	Школьная	0103000020E610000001000000050000002BFC19DEAC2F4340199293895B294A402BFC19DEAC2F4340AB06616EF72A4A40B9FDF2C98A334340AB06616EF72A4A40B9FDF2C98A334340199293895B294A402BFC19DEAC2F4340199293895B294A40
39134	4060	38.163919	38.215643999999998	52.292011000000002	52.254148000000001	Центральная	0103000020E61000000100000005000000B5183C4CFB144340022CF2EB87204A40B5183C4CFB1443404089CF9D60254A4010CAFB389A1B43404089CF9D60254A4010CAFB389A1B4340022CF2EB87204A40B5183C4CFB144340022CF2EB87204A40
39351	3626	38.648138000000003	38.697698000000003	52.307904999999998	52.285285000000002	Центральная	0103000020E61000000100000005000000BEA59C2FF65243400A85083884244A40BEA59C2FF65243402FA3586E69274A40083E062B4E5943402FA3586E69274A40083E062B4E5943400A85083884244A40BEA59C2FF65243400A85083884244A40
38821	2943	38.325544000000001	38.369515999999997	52.331845999999999	52.312299000000003	Тимирязева	0103000020E610000001000000050000005BB4006DAB29434069C9E369F9274A405BB4006DAB2943407AA702EE792A4A40A3ACDF4C4C2F43407AA702EE792A4A40A3ACDF4C4C2F434069C9E369F9274A405BB4006DAB29434069C9E369F9274A40
39173	2943	38.325544000000001	38.369515999999997	52.331845999999999	52.312299000000003	Терешковой	0103000020E610000001000000050000005BB4006DAB29434069C9E369F9274A405BB4006DAB2943407AA702EE792A4A40A3ACDF4C4C2F43407AA702EE792A4A40A3ACDF4C4C2F434069C9E369F9274A405BB4006DAB29434069C9E369F9274A40
38822	2943	38.325544000000001	38.369515999999997	52.331845999999999	52.312299000000003	Советская	0103000020E610000001000000050000005BB4006DAB29434069C9E369F9274A405BB4006DAB2943407AA702EE792A4A40A3ACDF4C4C2F43407AA702EE792A4A40A3ACDF4C4C2F434069C9E369F9274A405BB4006DAB29434069C9E369F9274A40
39128	2943	38.325544000000001	38.369515999999997	52.331845999999999	52.312299000000003	Мира	0103000020E610000001000000050000005BB4006DAB29434069C9E369F9274A405BB4006DAB2943407AA702EE792A4A40A3ACDF4C4C2F43407AA702EE792A4A40A3ACDF4C4C2F434069C9E369F9274A405BB4006DAB29434069C9E369F9274A40
39290	4329	38.181544000000002	38.210946	52.447505	52.431145000000001	Рягузова	0103000020E610000001000000050000007C6473D53C174340BE6A65C22F374A407C6473D53C174340F3E505D847394A406B9C4D47001B4340F3E505D847394A406B9C4D47001B4340BE6A65C22F374A407C6473D53C174340BE6A65C22F374A40
39349	4241	38.154082000000002	38.183143000000001	52.383118000000003	52.364390999999998	Молодежная	0103000020E610000001000000050000007E737FF5B813434076FA415DA42E4A407E737FF5B81343402541B8020A314A40E4BED53A711743402541B8020A314A40E4BED53A7117434076FA415DA42E4A407E737FF5B813434076FA415DA42E4A40
39107	4174	38.067269000000003	38.086834000000003	52.361207	52.335368000000003	Молодежная	0103000020E610000001000000050000006F8445459C084340FE0FB056ED2A4A406F8445459C0843400B0BEE073C2E4A40271763601D0B43400B0BEE073C2E4A40271763601D0B4340FE0FB056ED2A4A406F8445459C084340FE0FB056ED2A4A40
39167	3821	38.587052	38.630414000000002	52.249929999999999	52.224980000000002	Центральная	0103000020E6100000010000000500000094861A85244B434086200725CC1C4A4094861A85244B43400725CCB4FD1F4A406478EC67B15043400725CCB4FD1F4A406478EC67B150434086200725CC1C4A4094861A85244B434086200725CC1C4A40
39131	3185	38.310299000000001	38.349905999999997	52.317089000000003	52.296081999999998	Власова	0103000020E61000000100000005000000A27DACE0B72743409677D503E6254A40A27DACE0B7274340EF75525F96284A404B5645B8C92C4340EF75525F96284A404B5645B8C92C43409677D503E6254A40A27DACE0B72743409677D503E6254A40
39269	3939	38.461790999999998	38.480457999999999	52.237406999999997	52.220517000000001	Центральная	0103000020E61000000100000005000000274BADF71B3B4340249BABE6391C4A40274BADF71B3B4340B56B425A631E4A40008DD2A57F3D4340B56B425A631E4A40008DD2A57F3D4340249BABE6391C4A40274BADF71B3B4340249BABE6391C4A40
39106	3513	38.533593000000003	38.559465000000003	52.398626999999998	52.383172999999999	Школьная	0103000020E61000000100000005000000F12F82C64C444340E8DA17D00B314A40F12F82C64C444340BB26A43506334A40DA20938C9C474340BB26A43506334A40DA20938C9C474340E8DA17D00B314A40F12F82C64C444340E8DA17D00B314A40
39384	1359	39.927239999999998	39.958016000000001	52.794514999999997	52.781677999999999	Романовская	0103000020E6100000010000000500000082C5E1CCAFF64340580053060E644A4082C5E1CCAFF643403997E2AAB2654A40BA85AE44A0FA43403997E2AAB2654A40BA85AE44A0FA4340580053060E644A4082C5E1CCAFF64340580053060E644A40
38819	1943	39.526806999999998	39.572566999999999	52.902957000000001	52.875464000000001	Почтовая	0103000020E61000000100000005000000E5266A696EC34340A56950340F704A40E5266A696EC34340DE58501894734A4069E21DE049C94340DE58501894734A4069E21DE049C94340A56950340F704A40E5266A696EC34340A56950340F704A40
39154	2486	39.884076	39.942987000000002	53.055911000000002	53.019249000000002	Ленина	0103000020E61000000100000005000000D996016729F1434088BD50C076824A40D996016729F143404B3E761728874A40CEC64ACCB3F843404B3E761728874A40CEC64ACCB3F8434088BD50C076824A40D996016729F1434088BD50C076824A40
39208	2528	39.722828	39.789034000000001	53.053297000000001	53.036585000000002	Костикова	0103000020E610000001000000050000000951BEA085DC4340184339D1AE844A400951BEA085DC4340CAFCA36FD2864A404EB7EC10FFE44340CAFCA36FD2864A404EB7EC10FFE44340184339D1AE844A400951BEA085DC4340184339D1AE844A40
39499	1215	40.064250999999999	40.092215000000003	52.969172	52.944358999999999	Центральная	0103000020E610000001000000050000001EDE736039084440755776C1E0784A401EDE7360390844407619FED30D7C4A40AF997CB3CD0B44407619FED30D7C4A40AF997CB3CD0B4440755776C1E0784A401EDE736039084440755776C1E0784A40
39100	2035	39.435887999999998	39.490551000000004	52.892538000000002	52.863782999999998	Сельская	0103000020E61000000100000005000000035C902DCBB743409EEBFB70906E4A40035C902DCBB74340F83768AF3E724A4093020B60CABE4340F83768AF3E724A4093020B60CABE43409EEBFB70906E4A40035C902DCBB743409EEBFB70906E4A40
39146	1709	39.739375000000003	39.782099000000002	52.814515999999998	52.795200999999999	Ленина	0103000020E61000000100000005000000713D0AD7A3DE43408D5F7825C9654A40713D0AD7A3DE4340CC086F0F42684A40FE9DEDD11BE44340CC086F0F42684A40FE9DEDD11BE443408D5F7825C9654A40713D0AD7A3DE43408D5F7825C9654A40
39501	1438	39.900955000000003	39.908051999999998	52.800553000000001	52.796595000000003	Центральная	0103000020E610000001000000050000007715527E52F343401D9430D3F6654A407715527E52F343407BDB4C8578664A40A088450C3BF443407BDB4C8578664A40A088450C3BF443401D9430D3F6654A407715527E52F343401D9430D3F6654A40
39150	2378	39.800074000000002	39.829403999999997	53.024718999999997	52.998534999999997	Комсомольская	0103000020E61000000100000005000000A13028D368E64340A774B0FECF7F4A40A13028D368E643407F4B00FE29834A40F69507E929EA43407F4B00FE29834A40F69507E929EA4340A774B0FECF7F4A40A13028D368E64340A774B0FECF7F4A40
39205	1257	40.019173000000002	40.081274000000001	52.893489000000002	52.858618	Новая	0103000020E61000000100000005000000ADFBC74274024440E3E0D231E76D4A40ADFBC74274024440FA2AF9D85D724A40EF01BA2F670A4440FA2AF9D85D724A40EF01BA2F670A4440E3E0D231E76D4A40ADFBC74274024440E3E0D231E76D4A40
38842	2188	39.765740999999998	39.843077000000001	52.968825000000002	52.929856999999998	пл.Ленина	0103000020E61000000100000005000000691A14CD03E24340747ADE8D05774A40691A14CD03E243400B462575027C4A40418177F2E9EB43400B462575027C4A40418177F2E9EB4340747ADE8D05774A40691A14CD03E24340747ADE8D05774A40
39207	2188	39.765740999999998	39.843077000000001	52.968825000000002	52.929856999999998	Советская	0103000020E61000000100000005000000691A14CD03E24340747ADE8D05774A40691A14CD03E243400B462575027C4A40418177F2E9EB43400B462575027C4A40418177F2E9EB4340747ADE8D05774A40691A14CD03E24340747ADE8D05774A40
39250	1899	39.664563000000001	39.701852000000002	52.880893999999998	52.829481000000001	Центральная	0103000020E61000000100000005000000DA907F6610D54340A2D3F36E2C6A4A40DA907F6610D543400E9F7422C1704A40EC504D49D6D943400E9F7422C1704A40EC504D49D6D94340A2D3F36E2C6A4A40DA907F6610D54340A2D3F36E2C6A4A40
39382	2069	39.535170000000001	39.574741000000003	52.943745999999997	52.932245999999999	Черемушки	0103000020E6100000010000000500000071E6577380C44340D5E940D653774A4071E6577380C443408BDD3EABCC784A40CE55F31C91C943408BDD3EABCC784A40CE55F31C91C94340D5E940D653774A4071E6577380C44340D5E940D653774A40
39165	2640	39.774382000000003	39.836258000000001	52.888534	52.840192999999999	площадь Октябрьская	0103000020E61000000100000005000000384E0AF31EE3434000AAB8718B6B4A40384E0AF31EE3434029B16B7BBB714A405A828C800AEB434029B16B7BBB714A405A828C800AEB434000AAB8718B6B4A40384E0AF31EE3434000AAB8718B6B4A40
39103	2640	39.774382000000003	39.836258000000001	52.888534	52.840192999999999	переулок Ленина	0103000020E61000000100000005000000384E0AF31EE3434000AAB8718B6B4A40384E0AF31EE3434029B16B7BBB714A405A828C800AEB434029B16B7BBB714A405A828C800AEB434000AAB8718B6B4A40384E0AF31EE3434000AAB8718B6B4A40
38953	2640	39.774382000000003	39.836258000000001	52.888534	52.840192999999999	Школьная	0103000020E61000000100000005000000384E0AF31EE3434000AAB8718B6B4A40384E0AF31EE3434029B16B7BBB714A405A828C800AEB434029B16B7BBB714A405A828C800AEB434000AAB8718B6B4A40384E0AF31EE3434000AAB8718B6B4A40
39225	2640	39.774382000000003	39.836258000000001	52.888534	52.840192999999999	Победы	0103000020E61000000100000005000000384E0AF31EE3434000AAB8718B6B4A40384E0AF31EE3434029B16B7BBB714A405A828C800AEB434029B16B7BBB714A405A828C800AEB434000AAB8718B6B4A40384E0AF31EE3434000AAB8718B6B4A40
39102	2640	39.774382000000003	39.836258000000001	52.888534	52.840192999999999	Ленина	0103000020E61000000100000005000000384E0AF31EE3434000AAB8718B6B4A40384E0AF31EE3434029B16B7BBB714A405A828C800AEB434029B16B7BBB714A405A828C800AEB434000AAB8718B6B4A40384E0AF31EE3434000AAB8718B6B4A40
39288	2252	39.789250000000003	39.817798000000003	52.998902999999999	52.978928000000003	Чкалова	0103000020E610000001000000050000001B2FDD2406E54340C19140834D7D4A401B2FDD2406E543402A70B20DDC7F4A40FB5DD89AADE843402A70B20DDC7F4A40FB5DD89AADE84340C19140834D7D4A401B2FDD2406E54340C19140834D7D4A40
39381	1593	39.794029000000002	39.849975999999998	52.776350999999998	52.753900999999999	Центральная	0103000020E61000000100000005000000AD8905BEA2E54340FAB5F5D37F604A40AD8905BEA2E54340C39B35785F634A4044317903CCEC4340C39B35785F634A4044317903CCEC4340FAB5F5D37F604A40AD8905BEA2E54340FAB5F5D37F604A40
39148	2147	39.609155000000001	39.653281	53.037495	53.017017000000003	Центральная	0103000020E61000000100000005000000F29881CAF8CD4340EF3CF19C2D824A40F29881CAF8CD4340BB61DBA2CC844A40910C39B69ED34340BB61DBA2CC844A40910C39B69ED34340EF3CF19C2D824A40F29881CAF8CD4340EF3CF19C2D824A40
38841	1327	39.950937000000003	40.017933999999997	52.862554000000003	52.832925000000003	Новая	0103000020E6100000010000000500000037C7B94DB8F94340AA8251499D6A4A4037C7B94DB8F943405A84622B686E4A4044BE4BA94B0244405A84622B686E4A4044BE4BA94B024440AA8251499D6A4A4037C7B94DB8F94340AA8251499D6A4A40
39244	1472	39.825524000000001	39.903407000000001	52.818297999999999	52.767656000000002	Советская	0103000020E6100000010000000500000014083BC5AAE94340024A438D42624A4014083BC5AAE94340EC3026FDBD684A401EFD2FD7A2F34340EC3026FDBD684A401EFD2FD7A2F34340024A438D42624A4014083BC5AAE94340024A438D42624A40
39286	129	40.543591999999997	40.566974999999999	52.260713000000003	52.252135000000003	Центральная	0103000020E61000000100000005000000012F336C94454440A796ADF545204A40012F336C944544402F52280B5F214A40265305A3924844402F52280B5F214A40265305A392484440A796ADF545204A40012F336C94454440A796ADF545204A40
38820	29358	40.330016999999998	40.342359999999999	52.023445000000002	52.010691999999999	Молодежная	0103000020E61000000100000005000000E00F3FFF3D2A4440172AFF5A5E014A40E00F3FFF3D2A44409B20EA3E00034A40B2BAD573D22B44409B20EA3E00034A40B2BAD573D22B4440172AFF5A5E014A40E00F3FFF3D2A4440172AFF5A5E014A40
39262	54765	40.565556000000001	40.604560999999997	52.059646000000001	52.031613	Школьная	0103000020E610000001000000050000003E07962364484440719010E50B044A403E079623644844402AABE97AA2074A40F1B73D41624D44402AABE97AA2074A40F1B73D41624D4440719010E50B044A403E07962364484440719010E50B044A40
39223	1131	40.216344999999997	40.256346999999998	52.365315000000002	52.313433000000003	Школьная	0103000020E6100000010000000500000099D36531B11B44405C3E92921E284A4099D36531B11B44407FDE54A4C22E4A40BFB67EFACF2044407FDE54A4C22E4A40BFB67EFACF2044405C3E92921E284A4099D36531B11B44405C3E92921E284A40
39153	1131	40.216344999999997	40.256346999999998	52.365315000000002	52.313433000000003	Первомайская	0103000020E6100000010000000500000099D36531B11B44405C3E92921E284A4099D36531B11B44407FDE54A4C22E4A40BFB67EFACF2044407FDE54A4C22E4A40BFB67EFACF2044405C3E92921E284A4099D36531B11B44405C3E92921E284A40
39285	351	40.329577	40.344982999999999	52.184838999999997	52.167043999999997	Садовая	0103000020E61000000100000005000000C44142942F2A44401B7FA2B261154A40C44142942F2A44403E03EACDA8174A4086562767282C44403E03EACDA8174A4086562767282C44401B7FA2B261154A40C44142942F2A44401B7FA2B261154A40
37424	32209	40.518295000000002	40.569265999999999	52.055714000000002	52.024991	Советская	0103000020E610000001000000050000001557957D57424440E0D8B3E732034A401557957D57424440F5F6E7A221074A40C45C52B5DD484440F5F6E7A221074A40C45C52B5DD484440E0D8B3E732034A401557957D57424440E0D8B3E732034A40
39101	494	40.181319000000002	40.209516999999998	52.119314000000003	52.095413999999998	Центральная	0103000020E610000001000000050000005C920376351744404FCAA486360C4A405C920376351744403CFA5FAE450F4A405F7AFB73D11A44403CFA5FAE450F4A405F7AFB73D11A44404FCAA486360C4A405C920376351744404FCAA486360C4A40
39376	617	40.156813	40.174303000000002	52.293080000000003	52.274954000000001	Молодежная	0103000020E61000000100000005000000384BC97212144440C3F352B131234A40384BC972121444404C8E3BA583254A401F4C8A8F4F1644404C8E3BA583254A401F4C8A8F4F164440C3F352B131234A40384BC97212144440C3F352B131234A40
39496	32190	40.501299000000003	40.533594000000001	51.964036	51.940857000000001	Чиркова	0103000020E610000001000000050000003E42CD902A404440399B8E006EF849403E42CD902A40444055151A8865FB4940C1ABE5CE4C44444055151A8865FB4940C1ABE5CE4C444440399B8E006EF849403E42CD902A404440399B8E006EF84940
38920	648	40.353876999999997	40.390518999999998	52.346631000000002	52.322879999999998	Мира	0103000020E610000001000000050000003EE76ED74B2D44402844C02154294A403EE76ED74B2D4440D06394675E2C4A40BABBCE86FC314440D06394675E2C4A40BABBCE86FC3144402844C02154294A403EE76ED74B2D44402844C02154294A40
38959	54737	40.340688999999998	40.341470999999999	52.240374000000003	52.239033999999997	Школьная	0103000020E61000000100000005000000B08D78B29B2B4440E75086AA981E4A40B08D78B29B2B444084674293C41E4A4026C45C52B52B444084674293C41E4A4026C45C52B52B4440E75086AA981E4A40B08D78B29B2B4440E75086AA981E4A40
37425	32384	40.639297999999997	40.668591999999997	52.246108999999997	52.238179000000002	Победы	0103000020E61000000100000005000000F8325184D451444008CC43A67C1E4A40F8325184D45144402920ED7F801F4A40012F336C945544402920ED7F801F4A40012F336C9455444008CC43A67C1E4A40F8325184D451444008CC43A67C1E4A40
39224	32146	40.503625999999997	40.541175000000003	52.008994999999999	51.977857	Победы	0103000020E6100000010000000500000028B517D17640444014950D6B2AFD494028B517D176404440EC6987BF26014A40D734EF3845454440EC6987BF26014A40D734EF384545444014950D6B2AFD494028B517D17640444014950D6B2AFD4940
39204	85	40.450194000000003	40.465716999999998	52.233817000000002	52.222662999999997	Центральная	0103000020E610000001000000050000007F6DFDF49F394440BE839F38801C4A407F6DFDF49F394440DA1F28B7ED1D4A407A185A9D9C3B4440DA1F28B7ED1D4A407A185A9D9C3B4440BE839F38801C4A407F6DFDF49F394440BE839F38801C4A40
39388	900	40.190994000000003	40.208959999999998	52.195372999999996	52.154929000000003	Васильевская	0103000020E61000000100000005000000BADDCB7D72184440DB19A6B6D4134A40BADDCB7D72184440BDC282FB01194A4009168733BF1A4440BDC282FB01194A4009168733BF1A4440DB19A6B6D4134A40BADDCB7D72184440DB19A6B6D4134A40
39289	1014	40.088073999999999	40.108547000000002	52.222375999999997	52.185546000000002	Дружбы	0103000020E610000001000000050000005FD04202460B4440AAF3A8F8BF174A405FD04202460B444028B517D1761C4A401A8A3BDEE40D444028B517D1761C4A401A8A3BDEE40D4440AAF3A8F8BF174A405FD04202460B4440AAF3A8F8BF174A40
39395	225	40.387348000000003	40.406427999999998	52.31879	52.299011999999998	Школьная	0103000020E61000000100000005000000E415889E94314440478E740646264A40E415889E943144405B25581CCE284A40DF162CD5053444405B25581CCE284A40DF162CD505344440478E740646264A40E415889E94314440478E740646264A40
39284	32465	40.633674999999997	40.657876000000002	52.204397999999998	52.192210000000003	Школьная	0103000020E610000001000000050000007AA52C431C5144406AFB57569A184A407AA52C431C51444014AFB2B6291A4A406269E0473554444014AFB2B6291A4A406269E047355444406AFB57569A184A407AA52C431C5144406AFB57569A184A40
39498	32435	40.588957000000001	40.607408	52.251198000000002	52.235393999999999	Молодёжная	0103000020E6100000010000000500000009E066F1624B44405AD6FD63211E4A4009E066F1624B44400A698D4127204A4015AA9B8BBF4D44400A698D4127204A4015AA9B8BBF4D44405AD6FD63211E4A4009E066F1624B44405AD6FD63211E4A40
39221	974	40.066558999999998	40.156975000000003	52.270302999999998	52.243335000000002	Центральная	0103000020E6100000010000000500000092205C0185084440707CED99251F4A4092205C01850844405E81E84999224A4012A5BDC1171444405E81E84999224A4012A5BDC117144440707CED99251F4A4092205C0185084440707CED99251F4A40
39495	32075	40.277664000000001	40.302664	51.979616	51.970229000000003	Центральная	0103000020E6100000010000000500000066A3737E8A234440BE50C07630FC494066A3737E8A234440B5519D0E64FD494099D6A6B1BD264440B5519D0E64FD494099D6A6B1BD264440BE50C07630FC494066A3737E8A234440BE50C07630FC4940
39500	32306	40.394911999999998	40.427880000000002	52.091279999999998	52.084074999999999	Центральная	0103000020E610000001000000050000002366F6798C324440A2B437F8C20A4A402366F6798C324440B2632310AF0B4A40664E97C5C4364440B2632310AF0B4A40664E97C5C4364440A2B437F8C20A4A402366F6798C324440A2B437F8C20A4A40
39451	32052	40.328651999999998	40.344723000000002	52.01088	51.994656999999997	Школьная	0103000020E61000000100000005000000EBE1CB44112A444065DEAAEB50FF4940EBE1CB44112A44401A170E8464014A40EA961DE21F2C44401A170E8464014A40EA961DE21F2C444065DEAAEB50FF4940EBE1CB44112A444065DEAAEB50FF4940
39109	54754	40.612186999999999	40.636442000000002	52.169922	52.162404000000002	60 лет Победы	0103000020E61000000100000005000000A704C4245C4E4440AB5E7EA7C9144A40A704C4245C4E44407A6F0C01C0154A4082E673EE765144407A6F0C01C0154A4082E673EE76514440AB5E7EA7C9144A40A704C4245C4E4440AB5E7EA7C9144A40
39497	32358	40.372301	40.380232999999997	52.358485000000002	52.345188999999998	Заречная	0103000020E6100000010000000500000051A2258FA72F44402FF834272F2C4A4051A2258FA72F4440A48D23D6E22D4A4013EE9579AB304440A48D23D6E22D4A4013EE9579AB3044402FF834272F2C4A4051A2258FA72F44402FF834272F2C4A40
39378	865	40.205969000000003	40.233654999999999	52.230440999999999	52.202934999999997	Центральная	0103000020E61000000100000005000000B37E33315D1A44405C1B2AC6F9194A40B37E33315D1A44402A5437177F1D4A4000C63368E81D44402A5437177F1D4A4000C63368E81D44405C1B2AC6F9194A40B37E33315D1A44405C1B2AC6F9194A40
38952	1098	40.297831000000002	40.322921000000001	52.386437999999998	52.367657999999999	Лермонтова	0103000020E61000000100000005000000145E82531F2644406F0ED76A0F2F4A40145E82531F26444040F7E5CC76314A408718AF795529444040F7E5CC76314A408718AF79552944406F0ED76A0F2F4A40145E82531F2644406F0ED76A0F2F4A40
39329	31620	40.421125000000004	40.503813999999998	52.193783000000003	52.149121000000001	Терпигорева	0103000020E6100000010000000500000096438B6CE7354440CB129D6516134A4096438B6CE7354440A9C29FE1CD184A402BA226FA7C404440A9C29FE1CD184A402BA226FA7C404440CB129D6516134A4096438B6CE7354440CB129D6516134A40
38873	31620	40.421125000000004	40.503813999999998	52.193783000000003	52.149121000000001	Октябрьская	0103000020E6100000010000000500000096438B6CE7354440CB129D6516134A4096438B6CE7354440A9C29FE1CD184A402BA226FA7C404440A9C29FE1CD184A402BA226FA7C404440CB129D6516134A4096438B6CE7354440CB129D6516134A40
39152	31620	40.421125000000004	40.503813999999998	52.193783000000003	52.149121000000001	Народная	0103000020E6100000010000000500000096438B6CE7354440CB129D6516134A4096438B6CE7354440A9C29FE1CD184A402BA226FA7C404440A9C29FE1CD184A402BA226FA7C404440CB129D6516134A4096438B6CE7354440CB129D6516134A40
38874	31620	40.421125000000004	40.503813999999998	52.193783000000003	52.149121000000001	Ленинская	0103000020E6100000010000000500000096438B6CE7354440CB129D6516134A4096438B6CE7354440A9C29FE1CD184A402BA226FA7C404440A9C29FE1CD184A402BA226FA7C404440CB129D6516134A4096438B6CE7354440CB129D6516134A40
38988	31620	40.421125000000004	40.503813999999998	52.193783000000003	52.149121000000001	Кирова	0103000020E6100000010000000500000096438B6CE7354440CB129D6516134A4096438B6CE7354440A9C29FE1CD184A402BA226FA7C404440A9C29FE1CD184A402BA226FA7C404440CB129D6516134A4096438B6CE7354440CB129D6516134A40
39246	31927	40.310218999999996	40.335901	52.126601999999998	52.101975000000003	Центральная	0103000020E6100000010000000500000085CC9541B52744403B014D840D0D4A4085CC9541B5274440D9CD8C7E34104A40CBD8D0CDFE2A4440D9CD8C7E34104A40CBD8D0CDFE2A44403B014D840D0D4A4085CC9541B52744403B014D840D0D4A40
39233	18032	40.504703999999997	40.516840000000002	52.120773999999997	52.109741	Звонная	0103000020E61000000100000005000000871403249A404440E2033BFE0B0E4A40871403249A404440821ABE85750F4A40E0A128D027424440821ABE85750F4A40E0A128D027424440E2033BFE0B0E4A40871403249A404440E2033BFE0B0E4A40
37439	31949	40.162714999999999	40.202475	52.070653	52.039158999999998	Центральная	0103000020E61000000100000005000000C9C859D8D31444400A2C802903054A40C9C859D8D3144440A12E52280B094A40F9A067B3EA194440A12E52280B094A40F9A067B3EA1944400A2C802903054A40C9C859D8D31444400A2C802903054A40
39375	400	40.331805000000003	40.361234000000003	52.227181000000002	52.184545999999997	Центральная	0103000020E610000001000000050000001CD31396782A4440C64D0D349F174A401CD31396782A4440E4A25A44141D4A40051A6CEA3C2E4440E4A25A44141D4A40051A6CEA3C2E4440C64D0D349F174A401CD31396782A4440C64D0D349F174A40
39377	725	40.332425000000001	40.366928999999999	52.293591999999997	52.234098000000003	Богородицкая	0103000020E61000000100000005000000B8AF03E78C2A44408E075BECF61D4A40B8AF03E78C2A4440012F336C94254A401C7A8B87F72E4440012F336C94254A401C7A8B87F72E44408E075BECF61D4A40B8AF03E78C2A44408E075BECF61D4A40
39220	32000	40.306994000000003	40.342171999999998	52.081851	52.040455000000001	Центральная	0103000020E61000000100000005000000BC0853944B274440D7FA22A12D054A40BC0853944B2744408C12F4177A0A4A40AFCDC64ACC2B44408C12F4177A0A4A40AFCDC64ACC2B4440D7FA22A12D054A40BC0853944B274440D7FA22A12D054A40
39523	269	40.189520999999999	40.484132000000002	52.311633	52.126879000000002	Интернациональная	0103000020E61000000100000005000000DE736039421844404CC631923D104A40DE736039421844405CAD1397E3274A403A799109F83D44405CAD1397E3274A403A799109F83D44404CC631923D104A40DE736039421844404CC631923D104A40
39380	31063	38.855629999999998	38.882724000000003	53.294598999999998	53.274686000000003	Центральная	0103000020E61000000100000005000000FDBCA948856D4340A4552DE928A34A40FDBCA948856D43409737876BB5A54A4079B29B19FD7043409737876BB5A54A4079B29B19FD704340A4552DE928A34A40FDBCA948856D4340A4552DE928A34A40
39156	31596	39.294269	39.309683999999997	53.345511000000002	53.333838	Советская	0103000020E61000000100000005000000029D499BAAA54340BE141E34BBAA4A40029D499BAAA5434042B456B439AC4A40170CAEB9A3A7434042B456B439AC4A40170CAEB9A3A74340BE141E34BBAA4A40029D499BAAA54340BE141E34BBAA4A40
39488	31556	38.981969999999997	39.014111	53.142076000000003	53.119599999999998	Деминская	0103000020E6100000010000000500000099D36531B17D4340014D840D4F8F4A4099D36531B17D4340F4C5DE8B2F924A40C6C1A563CE814340F4C5DE8B2F924A40C6C1A563CE814340014D840D4F8F4A4099D36531B17D4340014D840D4F8F4A40
39328	31476	39.118433000000003	39.136426	53.323647000000001	53.289485999999997	Центральная	0103000020E6100000010000000500000033E202D0288F43402E5393E00DA54A4033E202D0288F43406939D0436DA94A407C293C68769143406939D0436DA94A407C293C68769143402E5393E00DA54A4033E202D0288F43402E5393E00DA54A40
39193	31462	38.860157999999998	38.916015000000002	53.231251999999998	53.209378999999998	Советская	0103000020E6100000010000000500000046B247A8196E43400EBC5AEECC9A4A4046B247A8196E43403A9160AA999D4A409ED2C1FA3F7543403A9160AA999D4A409ED2C1FA3F7543400EBC5AEECC9A4A4046B247A8196E43400EBC5AEECC9A4A40
39486	31375	38.880001999999998	38.914622999999999	53.128494000000003	53.109968000000002	Советская	0103000020E610000001000000050000001135D1E7A3704340A3CD716E138E4A401135D1E7A3704340BADDCB7D72904A40AF95D05D12754340BADDCB7D72904A40AF95D05D12754340A3CD716E138E4A401135D1E7A3704340A3CD716E138E4A40
39191	31357	38.999433000000003	39.010939999999998	53.262842999999997	53.257441	Центральная	0103000020E6100000010000000500000087C5A86BED7F434024D3A1D3F3A04A4087C5A86BED7F4340C37DE4D6A4A14A40EF1B5F7B66814340C37DE4D6A4A14A40EF1B5F7B6681434024D3A1D3F3A04A4087C5A86BED7F434024D3A1D3F3A04A40
39218	54761	38.955010999999999	38.974406000000002	53.350149999999999	53.336129	Спортивная	0103000020E61000000100000005000000FE28EACC3D7A43405C1E6B4606AB4A40FE28EACC3D7A4340E25817B7D1AC4A405A83F755B97C4340E25817B7D1AC4A405A83F755B97C43405C1E6B4606AB4A40FE28EACC3D7A43405C1E6B4606AB4A40
39323	31266	38.974172000000003	38.995578999999999	53.517426	53.497836999999997	Школьная	0103000020E61000000100000005000000E75608ABB17C43408FDE701FB9BF4A40E75608ABB17C4340D00CE2033BC24A40CDCAF6216F7F4340D00CE2033BC24A40CDCAF6216F7F43408FDE701FB9BF4A40E75608ABB17C43408FDE701FB9BF4A40
39334	31251	38.680711000000002	38.698945999999999	53.264350999999998	53.248567000000001	Центральная	0103000020E610000001000000050000008483BD8921574340B3EE1F0BD19F4A408483BD89215743401BD5E940D6A14A40C3D50110775943401BD5E940D6A14A40C3D5011077594340B3EE1F0BD19F4A408483BD8921574340B3EE1F0BD19F4A40
39283	31171	39.068863999999998	39.123167000000002	53.151035999999998	53.125684	Школьная	0103000020E6100000010000000500000095EF1989D0884340B3D0CE6916904A4095EF1989D08843406342CC2555934A402579AEEFC38F43406342CC2555934A402579AEEFC38F4340B3D0CE6916904A4095EF1989D0884340B3D0CE6916904A40
39219	30972	39.136102000000001	39.174442999999997	53.209933999999997	53.195436000000001	Центральная	0103000020E61000000100000005000000C97553CA6B914340043BFE0B04994A40C97553CA6B914340C328081EDF9A4A401002F22554964340C328081EDF9A4A401002F22554964340043BFE0B04994A40C97553CA6B914340043BFE0B04994A40
39145	30915	38.987251999999998	39.023014000000003	53.394219	53.383124000000002	Зеленая	0103000020E610000001000000050000008E7406465E7E434007280D350AB14A408E7406465E7E43401D3BA8C475B24A40D2AC6C1FF28243401D3BA8C475B24A40D2AC6C1FF282434007280D350AB14A408E7406465E7E434007280D350AB14A40
39494	30879	38.784824999999998	38.808954	53.474359	53.453885999999997	Фролова	0103000020E61000000100000005000000A60A4625756443405E0EBBEF18BA4A40A60A46257564434019C8B3CBB7BC4A40F4FBFECD8B67434019C8B3CBB7BC4A40F4FBFECD8B6743405E0EBBEF18BA4A40A60A4625756443405E0EBBEF18BA4A40
39215	30771	39.086030000000001	39.130325999999997	53.470891000000002	53.444195999999998	Советская	0103000020E61000000100000005000000C93CF207038B4340CB811E6ADBB84A40C93CF207038B4340897D022846BC4A40C4E8B985AE904340897D022846BC4A40C4E8B985AE904340CB811E6ADBB84A40C93CF207038B4340CB811E6ADBB84A40
39147	30768	38.703842000000002	38.738562000000002	53.207684999999998	53.192214999999997	Мира	0103000020E610000001000000050000008FC6A17E175A43407B6649809A984A408FC6A17E175A4340546F0D6C959A4A40C0081A33895E4340546F0D6C959A4A40C0081A33895E43407B6649809A984A408FC6A17E175A43407B6649809A984A40
39202	30768	38.703842000000002	38.738562000000002	53.207684999999998	53.192214999999997	Гагарина	0103000020E610000001000000050000008FC6A17E175A43407B6649809A984A408FC6A17E175A4340546F0D6C959A4A40C0081A33895E4340546F0D6C959A4A40C0081A33895E43407B6649809A984A408FC6A17E175A43407B6649809A984A40
33443	30705	39.128861999999998	39.164524999999998	53.363332999999997	53.326912	Центральная	0103000020E610000001000000050000003CD9CD8C7E904340C1559E40D8A94A403CD9CD8C7E9043405E471CB281AE4A40EC2FBB270F9543405E471CB281AE4A40EC2FBB270F954340C1559E40D8A94A403CD9CD8C7E904340C1559E40D8A94A40
39214	30638	38.866481999999998	38.899881000000001	53.446936999999998	53.422051000000003	Парковая	0103000020E610000001000000050000004D49D6E1E86E43403F1F65C405B64A404D49D6E1E86E4340A92F4B3B35B94A4059A5F44C2F734340A92F4B3B35B94A4059A5F44C2F7343403F1F65C405B64A404D49D6E1E86E43403F1F65C405B64A40
39097	30591	38.745075	38.766643000000002	53.356034999999999	53.330488000000003	Центральная	0103000020E610000001000000050000009A081B9E5E5F434038DC476E4DAA4A409A081B9E5E5F43409D9D0C8E92AD4A408A5A9A5B216243409D9D0C8E92AD4A408A5A9A5B2162434038DC476E4DAA4A409A081B9E5E5F434038DC476E4DAA4A40
39144	30545	39.025924000000003	39.056063000000002	53.219683000000003	53.201990000000002	Ново-Советская	0103000020E610000001000000050000003C17467A518343403D0FEECEDA994A403C17467A518343405C3E92921E9C4A4001C287122D8743405C3E92921E9C4A4001C287122D8743403D0FEECEDA994A403C17467A518343403D0FEECEDA994A40
39518	54787	39.437344000000003	40.234239000000002	52.721736999999997	52.280304999999998	Лесная	0103000020E61000000100000005000000098D60E3FAB74340E0F3C308E1234A40098D60E3FAB7434015A8C5E0615C4A405039268BFB1D444015A8C5E0615C4A405039268BFB1D4440E0F3C308E1234A40098D60E3FAB74340E0F3C308E1234A40
39353	29094	39.576852000000002	39.607394999999997	52.392840999999997	52.381512999999998	Казанская	0103000020E61000000100000005000000EC504D49D6C94340DAFF006BD5304A40EC504D49D6C9434093C3279D48324A4080608E1EBFCD434093C3279D48324A4080608E1EBFCD4340DAFF006BD5304A40EC504D49D6C94340DAFF006BD5304A40
38919	29307	39.688485999999997	39.756298999999999	52.485706999999998	52.441460999999997	Советская	0103000020E610000001000000050000007EE02A4F20D84340CFBA46CB81384A407EE02A4F20D843401938A0A52B3E4A40AE7FD767CEE043401938A0A52B3E4A40AE7FD767CEE04340CFBA46CB81384A407EE02A4F20D84340CFBA46CB81384A40
39324	29814	39.601142000000003	39.699812999999999	52.373700999999997	52.339759000000001	Мира	0103000020E6100000010000000500000043209738F2CC4340C6C210397D2B4A4043209738F2CC4340C2BD326FD52F4A406728EE7893D94340C2BD326FD52F4A406728EE7893D94340C6C210397D2B4A4043209738F2CC4340C6C210397D2B4A40
38913	29814	39.601142000000003	39.699812999999999	52.373700999999997	52.339759000000001	Ленина	0103000020E6100000010000000500000043209738F2CC4340C6C210397D2B4A4043209738F2CC4340C2BD326FD52F4A406728EE7893D94340C2BD326FD52F4A406728EE7893D94340C6C210397D2B4A4043209738F2CC4340C6C210397D2B4A40
38878	29718	39.995054000000003	40.015517000000003	52.438135000000003	52.413922999999997	Центральная	0103000020E6100000010000000500000083E0F1ED5DFF4340F607CA6DFB344A4083E0F1ED5DFF4340D21DC4CE14384A401AC40776FC014440D21DC4CE14384A401AC40776FC014440F607CA6DFB344A4083E0F1ED5DFF4340F607CA6DFB344A40
39492	29754	39.899158	39.961123999999998	52.469630000000002	52.425922999999997	Авиационная	0103000020E61000000100000005000000E8F7FD9B17F343409ECE15A584364A40E8F7FD9B17F34340399CF9D51C3C4A404AB3791C06FB4340399CF9D51C3C4A404AB3791C06FB43409ECE15A584364A40E8F7FD9B17F343409ECE15A584364A40
39268	54768	39.817357999999999	39.842367000000003	52.426032999999997	52.413401	19 съезд ВЛКСМ	0103000020E61000000100000005000000DE8FDB2F9FE843401D91EF52EA344A40DE8FDB2F9FE843402502D53F88364A40651D8EAED2EB43402502D53F88364A40651D8EAED2EB43401D91EF52EA344A40DE8FDB2F9FE843401D91EF52EA344A40
38840	29167	39.823987000000002	39.871777999999999	52.651335000000003	52.618454999999997	Плеханова	0103000020E6100000010000000500000022AAF06778E943401A868F88294F4A4022AAF06778E94340BEDEFDF15E534A40A7AFE76B96EF4340BEDEFDF15E534A40A7AFE76B96EF43401A868F88294F4A4022AAF06778E943401A868F88294F4A40
39213	28981	40.111628000000003	40.134318999999998	52.495303	52.473235000000003	Асфальтная	0103000020E61000000100000005000000B1A888D3490E44404A29E8F6923C4A40B1A888D3490E44402B4EB516663F4A409F1D705D311144402B4EB516663F4A409F1D705D311144404A29E8F6923C4A40B1A888D3490E44404A29E8F6923C4A40
39256	54762	40.017862000000001	40.040903999999998	52.541006000000003	52.523229000000001	Школьная	0103000020E61000000100000005000000ABEB504D49024440CEA8F92AF9424A40ABEB504D490244404B7842AF3F454A4046239F573C0544404B7842AF3F454A4046239F573C054440CEA8F92AF9424A40ABEB504D49024440CEA8F92AF9424A40
39487	29286	40.006157000000002	40.042780999999998	52.346080999999998	52.321525999999999	Советская	0103000020E610000001000000050000001CD2A8C0C9004440276893C327294A401CD2A8C0C90044402C62D8614C2C4A40F1F109D9790544402C62D8614C2C4A40F1F109D979054440276893C327294A401CD2A8C0C9004440276893C327294A40
39166	29602	40.108519999999999	40.136744999999998	52.410818999999996	52.397556000000002	Лесная	0103000020E61000000100000005000000207BBDFBE30D44400F2A711DE3324A40207BBDFBE30D4440A7C98CB795344A401D7233DC80114440A7C98CB795344A401D7233DC801144400F2A711DE3324A40207BBDFBE30D44400F2A711DE3324A40
39331	29611	40.042476000000001	40.071725000000001	52.341920999999999	52.311776000000002	26 Партсъезд	0103000020E61000000100000005000000B56E83DA6F054440BFD6A546E8274A40B56E83DA6F05444066683C11C42B4A401EA7E8482E09444066683C11C42B4A401EA7E8482E094440BFD6A546E8274A40B56E83DA6F054440BFD6A546E8274A40
39257	54763	39.998764000000001	40.069057000000001	52.408670999999998	52.362493999999998	Советская	0103000020E610000001000000050000000936AE7FD7FF4340847F1134662E4A400936AE7FD7FF43406CE9D1544F344A40AA471ADCD60844406CE9D1544F344A40AA471ADCD6084440847F1134662E4A400936AE7FD7FF4340847F1134662E4A40
39168	29427	39.437344000000003	39.534838000000001	52.382623000000002	52.362130999999998	Центральная площадь	0103000020E61000000100000005000000098D60E3FAB7434013EF004F5A2E4A40098D60E3FAB7434045D95BCAF9304A403B54539275C4434045D95BCAF9304A403B54539275C4434013EF004F5A2E4A40098D60E3FAB7434013EF004F5A2E4A40
38979	54741	39.437344000000003	40.234239000000002	52.721736999999997	52.280304999999998	Гагарина	0103000020E61000000100000005000000098D60E3FAB74340E0F3C308E1234A40098D60E3FAB7434015A8C5E0615C4A405039268BFB1D444015A8C5E0615C4A405039268BFB1D4440E0F3C308E1234A40098D60E3FAB74340E0F3C308E1234A40
38977	54494	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Чернышевского	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39023	54494	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Тимирязева	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
37442	54494	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Песковатская	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39065	54494	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Партизанская	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
38916	54494	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Лихачева	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39029	54494	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	Авиационная	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39200	54494	39.855249000000001	40.007171999999997	52.513744000000003	52.469169999999998	2-я Чапаева	0103000020E61000000100000005000000E6779ACC78ED4340D52137C30D3C4A40E6779ACC78ED43401442075DC2414A4034B91803EB0044401442075DC2414A4034B91803EB004440D52137C30D3C4A40E6779ACC78ED4340D52137C30D3C4A40
39280	29149	39.860702000000003	39.909740999999997	52.627437	52.607880000000002	Школьная	0103000020E6100000010000000500000008CDAE7B2BEE43403DF20703CF4D4A4008CDAE7B2BEE434072A609DB4F504A40486AA16472F4434072A609DB4F504A40486AA16472F443403DF20703CF4D4A4008CDAE7B2BEE43403DF20703CF4D4A40
39149	29409	39.855572000000002	39.910243999999999	52.359864999999999	52.324266999999999	Некрасова	0103000020E61000000100000005000000C9AF1F6283ED43400516C09481294A40C9AF1F6283ED4340CEFC6A0E102E4A40ABB019E082F44340CEFC6A0E102E4A40ABB019E082F443400516C09481294A40C9AF1F6283ED43400516C09481294A40
39203	28788	39.807926000000002	39.885413999999997	52.704323000000002	52.668863000000002	Ленинская	0103000020E6100000010000000500000047CB811E6AE743409240834D9D554A4047CB811E6AE743400A698D41275A4A40D4B5F63E55F143400A698D41275A4A40D4B5F63E55F143409240834D9D554A4047CB811E6AE743409240834D9D554A40
38918	28706	39.928057000000003	39.962561999999998	52.552737	52.518532999999998	Советская	0103000020E6100000010000000500000075E95F92CAF64340C972124A5F424A4075E95F92CAF6434003250516C0464A40A92F4B3B35FB434003250516C0464A40A92F4B3B35FB4340C972124A5F424A4075E95F92CAF64340C972124A5F424A40
39124	28995	39.984650999999999	40.068373999999999	52.492550999999999	52.471204999999998	Социалистическая	0103000020E61000000100000005000000A27C410B09FE4340185B0872503C4A40A27C410B09FE4340594E42E90B3F4A40C7F2AE7AC0084440594E42E90B3F4A40C7F2AE7AC0084440185B0872503C4A40A27C410B09FE4340185B0872503C4A40
39209	28995	39.984650999999999	40.068373999999999	52.492550999999999	52.471204999999998	Набережная	0103000020E61000000100000005000000A27C410B09FE4340185B0872503C4A40A27C410B09FE4340594E42E90B3F4A40C7F2AE7AC0084440594E42E90B3F4A40C7F2AE7AC0084440185B0872503C4A40A27C410B09FE4340185B0872503C4A40
39493	27521	37.85718	37.879098999999997	52.20102	52.184297999999998	Центральная	0103000020E6100000010000000500000084640113B8ED4240EE5BAD1397174A4084640113B8ED4240C4EBFA05BB194A402079E75086F04240C4EBFA05BB194A402079E75086F04240EE5BAD1397174A4084640113B8ED4240EE5BAD1397174A40
39452	27023	37.980339000000001	38.012238000000004	52.226441999999999	52.208018000000003	Луговая	0103000020E6100000010000000500000026FF93BF7BFD42405B7D7555A01A4A4026FF93BF7BFD42406D382C0DFC1C4A405DE2C803910143406D382C0DFC1C4A405DE2C803910143405B7D7555A01A4A4026FF93BF7BFD42405B7D7555A01A4A40
39210	27237	37.944290000000002	37.996724	52.009428	52.003307	Центральная	0103000020E610000001000000050000004DF8A57EDEF84240876C205D6C004A404DF8A57EDEF8424056D5CBEF34014A40B491EBA694FF424056D5CBEF34014A40B491EBA694FF4240876C205D6C004A404DF8A57EDEF84240876C205D6C004A40
39216	26619	37.897002000000001	37.920358999999998	52.003169	51.989151	Молодёжная	0103000020E610000001000000050000002A3927F6D0F2424021E7FD7F9CFE49402A3927F6D0F2424036AE7FD767004A4025CADE52CEF5424036AE7FD767004A4025CADE52CEF5424021E7FD7F9CFE49402A3927F6D0F2424021E7FD7F9CFE4940
39212	27306	38.098655999999998	38.136088999999998	51.999676000000001	51.952615000000002	Совхозная	0103000020E61000000100000005000000EFC682C2A00C4340EB56CF49EFF94940EFC682C2A00C43404D4C1762F5FF4940342C465D6B1143404D4C1762F5FF4940342C465D6B114340EB56CF49EFF94940EFC682C2A00C4340EB56CF49EFF94940
39477	27245	37.846265000000002	37.857934999999998	52.142842999999999	52.136625000000002	Центральная	0103000020E61000000100000005000000EE5F596952EC4240736891ED7C114A40EE5F596952EC424034BBEEAD48124A40008C67D0D0ED424034BBEEAD48124A40008C67D0D0ED4240736891ED7C114A40EE5F596952EC4240736891ED7C114A40
39348	27340	38.177528000000002	38.194704000000002	51.956206000000002	51.950639000000002	Школьная	0103000020E61000000100000005000000E90FCD3CB9164340ADA6EB89AEF94940E90FCD3CB9164340971E4DF564FA49404033880FEC184340971E4DF564FA49404033880FEC184340ADA6EB89AEF94940E90FCD3CB9164340ADA6EB89AEF94940
39199	27436	37.934291000000002	37.954979999999999	52.061312999999998	52.054988999999999	Новая	0103000020E610000001000000050000003CF9F4D896F74240E3512AE109074A403CF9F4D896F74240EAE8B81AD9074A40C32ADEC83CFA4240EAE8B81AD9074A40C32ADEC83CFA4240E3512AE109074A403CF9F4D896F74240E3512AE109074A40
39211	27420	38.086691000000002	38.123144000000003	52.040793000000001	52.032615999999997	Центральная	0103000020E61000000100000005000000C4EDD0B0180B4340C5A9D6C22C044A40C4EDD0B0180B4340EF737CB438054A406D59BE2EC30F4340EF737CB438054A406D59BE2EC30F4340C5A9D6C22C044A40C4EDD0B0180B4340C5A9D6C22C044A40
39136	27083	37.944369999999999	37.984515999999999	52.111218000000001	52.089376999999999	Сельская	0103000020E6100000010000000500000069A9BC1DE1F84240DE019EB4700B4A4069A9BC1DE1F84240FF5C34643C0E4A40C231CB9E04FE4240FF5C34643C0E4A40C231CB9E04FE4240DE019EB4700B4A4069A9BC1DE1F84240DE019EB4700B4A40
39475	27051	37.766423000000003	37.823366999999998	52.079431999999997	52.059890000000003	Центральная	0103000020E610000001000000050000007CF31B261AE24240C1ADBB79AA074A407CF31B261AE24240C020E9D32A0A4A4085CD001764E94240C020E9D32A0A4A4085CD001764E94240C1ADBB79AA074A407CF31B261AE24240C1ADBB79AA074A40
39279	26975	37.925272	37.978155999999998	52.223452000000002	52.203448999999999	Центральная	0103000020E61000000100000005000000C7F319506FF64240B3B3E89D0A1A4A40C7F319506FF64240E71C3C139A1C4A406E313F3734FD4240E71C3C139A1C4A406E313F3734FD4240B3B3E89D0A1A4A40C7F319506FF64240B3B3E89D0A1A4A40
39096	26577	37.833339000000002	37.915562000000001	51.995655999999997	51.948645999999997	Центральная	0103000020E610000001000000050000009DBD33DAAAEA424098BD6C3B6DF949409DBD33DAAAEA42407808E3A771FF4940EDBAB72231F542407808E3A771FF4940EDBAB72231F5424098BD6C3B6DF949409DBD33DAAAEA424098BD6C3B6DF94940
39347	26897	37.787802999999997	37.833779	52.030389	52.008839999999999	Центральная	0103000020E6100000010000000500000068588CBAD6E44240C5724BAB21014A4068588CBAD6E442403E9468C9E3034A40B98B3045B9EA42403E9468C9E3034A40B98B3045B9EA4240C5724BAB21014A4068588CBAD6E44240C5724BAB21014A40
38943	26770	37.844881999999998	37.908878000000001	52.042465999999997	52.008679000000001	Первомайская	0103000020E61000000100000005000000527DE71725EC4240BC94BA641C014A40527DE71725EC42409198A0866F054A40E606431D56F442409198A0866F054A40E606431D56F44240BC94BA641C014A40527DE71725EC4240BC94BA641C014A40
38817	26770	37.844881999999998	37.908878000000001	52.042465999999997	52.008679000000001	Ленина	0103000020E61000000100000005000000527DE71725EC4240BC94BA641C014A40527DE71725EC42409198A0866F054A40E606431D56F442409198A0866F054A40E606431D56F44240BC94BA641C014A40527DE71725EC4240BC94BA641C014A40
39206	26734	37.964753000000002	38.020879999999998	51.930706999999998	51.921447999999998	В.Чернова	0103000020E61000000100000005000000E4DBBB067DFB4240787B1002F2F54940E4DBBB067DFB424042942F6821F74940FB912232AC02434042942F6821F74940FB912232AC024340787B1002F2F54940E4DBBB067DFB4240787B1002F2F54940
39197	26667	38.004513000000003	38.053552000000003	51.985035000000003	51.969974000000001	Парковая	0103000020E6100000010000000500000014B4C9E19300434033FCA71B28FC494014B4C9E1930043402B357BA015FE49405551BCCADA0643402B357BA015FE49405551BCCADA06434033FCA71B28FC494014B4C9E19300434033FCA71B28FC4940
39379	26547	37.999132000000003	38.029279000000002	52.152652000000003	52.142980999999999	Школьная	0103000020E610000001000000050000008C31B08EE3FF424085798F334D124A408C31B08EE3FF4240A2D5C9198A134A40D4BA0D6ABF034340A2D5C9198A134A40D4BA0D6ABF03434085798F334D124A408C31B08EE3FF424085798F334D124A40
39448	27159	37.885064	37.916683999999997	52.110460000000003	52.098140999999998	Центральная	0103000020E61000000100000005000000F86EF3C649F14240C8B260E28F0C4A40F86EF3C649F1424012C2A38D230E4A401B62BCE655F5424012C2A38D230E4A401B62BCE655F54240C8B260E28F0C4A40F86EF3C649F14240C8B260E28F0C4A40
39350	27165	38.029494999999997	38.058942000000002	52.105559999999997	52.094351000000003	Родниковая	0103000020E61000000100000005000000A032FE7DC603434026AC8DB1130C4A40A032FE7DC603434004E275FD820D4A40302E55698B07434004E275FD820D4A40302E55698B07434026AC8DB1130C4A40A032FE7DC603434026AC8DB1130C4A40
37302	1787	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	Черняховского	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
37637	1787	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	Плеханова	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
37335	1787	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	Октябрьская	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
37601	1787	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	Мичурина	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
37481	1787	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	Лермонтова	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
37473	1787	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	Лазарева	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
37295	1787	36.861829	37.036029999999997	51.897618999999999	51.855539999999998	Красная	0103000020E6100000010000000500000048DFA469506E4240BD35B05582ED494048DFA469506E424055A2EC2DE5F2494062D68BA19C84424055A2EC2DE5F2494062D68BA19C844240BD35B05582ED494048DFA469506E4240BD35B05582ED4940
37328	9704	36.098942999999998	36.115741999999997	51.639164999999998	51.628309000000002	Советская улица	0103000020E6100000010000000500000085950A2AAA0C42402864E76D6CD0494085950A2AAA0C4240B9DFA128D0D14940066344A2D00E4240B9DFA128D0D14940066344A2D00E42402864E76D6CD0494085950A2AAA0C42402864E76D6CD04940
37366	54478	35.227856000000003	35.291635999999997	51.209104000000004	51.185765000000004	Советская площадь	0103000020E610000001000000050000004419AA622A9D4140E8DEC325C79749404419AA622A9D41403DBB7CEBC39A49400A2B155454A541403DBB7CEBC39A49400A2B155454A54140E8DEC325C79749404419AA622A9D4140E8DEC325C7974940
37503	54502	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Маяковского	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37474	54463	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Луначарского	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37414	54463	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Ленина	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37437	54463	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Кирова	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37410	54486	36.222462	36.314188999999999	51.225825	51.197563000000002	Курская	0103000020E61000000100000005000000274D83A2791C424028F38FBE49994940274D83A2791C424042CF66D5E79C4940A8E15B583728424042CF66D5E79C4940A8E15B583728424028F38FBE49994940274D83A2791C424028F38FBE49994940
37458	54484	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	Энгельса	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37382	54484	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	Куйбышева	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37402	54484	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	Красная	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37469	54484	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	К. Маркса	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37411	54484	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	К. Либкнехта	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37493	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	Энергетиков	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
37479	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	Строителей	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
37480	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	Садовая 	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
37291	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	Набережная	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
37347	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	Молодежная	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
36710	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	Ленинградская	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
37348	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	Космонавтов	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
36712	24756	35.640991	35.664239999999999	51.664451	51.655343999999999	 Набережная	0103000020E61000000100000005000000E2033BFE0BD241409ED0EB4FE2D34940E2033BFE0BD24140B265F9BA0CD54940F758FAD005D54140B265F9BA0CD54940F758FAD005D541409ED0EB4FE2D34940E2033BFE0BD241409ED0EB4FE2D34940
5308	4134	36.161842999999998	36.168742999999999	51.728565000000003	51.721128	улица Чернышевского	0103000020E61000000100000005000000130B7C45B71442406D1D1CEC4DDC4940130B7C45B71442405001309E41DD4940E736E15E991542405001309E41DD4940E736E15E991542406D1D1CEC4DDC4940130B7C45B71442406D1D1CEC4DDC4940
4509	4134	36.197389999999999	36.200578999999998	51.717160999999997	51.706307000000002	улица Полевая	0103000020E610000001000000050000005A47551344194240CBF78C4468DA49405A47551344194240BB7B80EECBDB4940D7A19A92AC194240BB7B80EECBDB4940D7A19A92AC194240CBF78C4468DA49405A47551344194240CBF78C4468DA4940
5375	4134	36.149985999999998	36.161897000000003	51.725340000000003	51.720660000000002	улица Пирогова	0103000020E61000000100000005000000CE6DC2BD3213424087C43D963EDC4940CE6DC2BD32134240863DEDF0D7DC49400729780AB9144240863DEDF0D7DC49400729780AB914424087C43D963EDC4940CE6DC2BD3213424087C43D963EDC4940
37528	4134	36.142817000000001	36.157980999999999	51.671869000000001	51.668165999999999	улица Парковая	0103000020E610000001000000050000000B28D4D3471242404A26A77686D549400B28D4D3471242401E19ABCDFFD54940D731AEB8381442401E19ABCDFFD54940D731AEB8381442404A26A77686D549400B28D4D3471242404A26A77686D54940
5385	4134	36.142898000000002	36.171104999999997	51.755802000000003	51.721964999999997	улица Павлуновского	0103000020E61000000100000005000000F8544E7B4A124240A6ED5F5969DC4940F8544E7B4A1242402E20B41EBEE049404E97C5C4E61542402E20B41EBEE049404E97C5C4E6154240A6ED5F5969DC4940F8544E7B4A124240A6ED5F5969DC4940
5138	4134	36.063316	36.093705999999997	51.671824000000001	51.665500999999999	улица Менделеева	0103000020E6100000010000000500000022A81ABD1A084240473A03232FD5494022A81ABD1A0842407E552E54FED5494030B8E68EFE0B42407E552E54FED5494030B8E68EFE0B4240473A03232FD5494022A81ABD1A084240473A03232FD54940
5194	4134	36.066792999999997	36.075740000000003	51.677208	51.667250000000003	улица Крюкова	0103000020E61000000100000005000000054D4BAC8C084240C520B07268D54940054D4BAC8C084240774B72C0AED64940E17F2BD9B1094240774B72C0AED64940E17F2BD9B1094240C520B07268D54940054D4BAC8C084240C520B07268D54940
5806	4134	36.166164000000002	36.198540000000001	51.797913000000001	51.748151999999997	улица Карла Маркса	0103000020E61000000100000005000000E3E2A8DC44154240EF37DA71C3DF4940E3E2A8DC44154240D106600322E6494053793BC269194240D106600322E6494053793BC269194240EF37DA71C3DF4940E3E2A8DC44154240EF37DA71C3DF4940
5982	4134	36.198656	36.199751999999997	51.750912	51.745854999999999	улица Блинова	0103000020E61000000100000005000000BC934F8F6D1942406F47382D78DF4940BC934F8F6D194240441669E21DE04940C1A7397991194240441669E21DE04940C1A73979911942406F47382D78DF4940BC934F8F6D1942406F47382D78DF4940
5443	4134	36.130690000000001	36.166874	51.763890000000004	51.720263000000003	улица 50-летия Октября	0103000020E6100000010000000500000006F52D73BA1042406AC2F69331DC494006F52D73BA104240E8DEC325C7E14940BF4692205C154240E8DEC325C7E14940BF4692205C1542406AC2F69331DC494006F52D73BA1042406AC2F69331DC4940
5114	4134	36.063828000000001	36.135567999999999	51.668092999999999	51.661434	проспект Ленинского Комсомола	0103000020E61000000100000005000000D84812842B084240323B8BDEA9D44940D84812842B084240E0D7481284D549402B31CF4A5A114240E0D7481284D549402B31CF4A5A114240323B8BDEA9D44940D84812842B084240323B8BDEA9D44940
1254	4134	36.134318999999998	36.140822999999997	51.727460000000001	51.712870000000002	проспект Вячеслава Клыкова	0103000020E610000001000000050000009F1D705D311142405726FC523FDB49409F1D705D31114240F792C6681DDD494026C3F17C06124240F792C6681DDD494026C3F17C061242405726FC523FDB49409F1D705D311142405726FC523FDB4940
5553	4134	36.126010000000001	36.128435000000003	51.742710000000002	51.739313000000003	проезд Сергеева	0103000020E61000000100000005000000077C7E1821104240FB40F2CEA1DE4940077C7E1821104240C2340C1F11DF4940B554DE8E70104240C2340C1F11DF4940B554DE8E70104240FB40F2CEA1DE4940077C7E1821104240FB40F2CEA1DE4940
5089	4134	36.098799999999997	36.106687000000001	51.677432000000003	51.666898000000003	Широкая улица	0103000020E61000000100000005000000226C787AA50C424048E2E5E95CD54940226C787AA50C4240C7A17E17B6D6494045F46BEBA70D4240C7A17E17B6D6494045F46BEBA70D424048E2E5E95CD54940226C787AA50C424048E2E5E95CD54940
37461	4134	36.143509000000002	36.150354	51.712423999999999	51.710721999999997	Тракторная	0103000020E6100000010000000500000041D7BE805E1242401B4641F0F8DA494041D7BE805E1242405871AAB530DB49405169C4CC3E1342405871AAB530DB49405169C4CC3E1342401B4641F0F8DA494041D7BE805E1242401B4641F0F8DA4940
1108	4134	36.079521999999997	36.162329	51.715676999999999	51.705894000000001	Сумская улица	0103000020E6100000010000000500000000A8E2C62D0A4240A8380EBC5ADA494000A8E2C62D0A4240ECBFCE4D9BDB4940A0185932C7144240ECBFCE4D9BDB4940A0185932C7144240A8380EBC5ADA494000A8E2C62D0A4240A8380EBC5ADA4940
37505	4134	36.242260999999999	36.246420000000001	51.744751000000001	51.742682000000002	Социалистическая	0103000020E61000000100000005000000520C9068021F4240F8A92A3410DF4940520C9068021F4240E754320054DF4940488AC8B08A1F4240E754320054DF4940488AC8B08A1F4240F8A92A3410DF4940520C9068021F4240F8A92A3410DF4940
4443	4134	36.234580000000001	36.266928	51.745375000000003	51.740015999999997	Республиканская улица	0103000020E61000000100000005000000D925AAB7061E4240244223D8B8DE4940D925AAB7061E4240C520B07268DF49407F315BB22A224240C520B07268DF49407F315BB22A224240244223D8B8DE4940D925AAB7061E4240244223D8B8DE4940
37446	4134	36.234966	36.242800000000003	51.758127000000002	51.749896999999997	Парижской Коммуны	0103000020E6100000010000000500000002D6AA5D131E42402B2FF99FFCDF494002D6AA5D131E4240789B374E0AE1494002BC0512141F4240789B374E0AE1494002BC0512141F42402B2FF99FFCDF494002D6AA5D131E42402B2FF99FFCDF4940
5015	4134	36.129593999999997	36.174582000000001	51.660288999999999	51.64837	Магистральный проезд	0103000020E6100000010000000500000000E143899610424090DAC4C9FDD2494000E14389961042404B74965984D44940323CF6B3581642404B74965984D44940323CF6B35816424090DAC4C9FDD2494000E143899610424090DAC4C9FDD24940
37510	4134	36.162329	36.188657999999997	51.721769999999999	51.704754999999999	Литовская	0103000020E61000000100000005000000A0185932C7144240A3586E6935DA4940A0185932C7144240F19D98F562DC49407B1002F225184240F19D98F562DC49407B1002F225184240A3586E6935DA4940A0185932C7144240A3586E6935DA4940
4834	4134	36.149859999999997	36.155897000000003	51.676298000000003	51.663060000000002	Краснополянская улица	0103000020E61000000100000005000000417DCB9C2E13424094A46B26DFD44940417DCB9C2E134240D42CD0EE90D64940B345D26EF4134240D42CD0EE90D64940B345D26EF413424094A46B26DFD44940417DCB9C2E13424094A46B26DFD44940
37586	4134	36.135747000000002	36.137337000000002	51.712395999999998	51.705419999999997	Конорева	0103000020E61000000100000005000000DBC35E2860114240DFF8DA334BDA4940DBC35E28601142408EE6C8CA2FDB4940F0C34142941142408EE6C8CA2FDB4940F0C3414294114240DFF8DA334BDA4940DBC35E2860114240DFF8DA334BDA4940
37506	4134	36.129756	36.142961	51.673130999999998	51.667746999999999	Гагарина	0103000020E61000000100000005000000DA3A38D89B1042404580D3BB78D54940DA3A38D89B1042403E76172829D649403ECDC98B4C1242403E76172829D649403ECDC98B4C1242404580D3BB78D54940DA3A38D89B1042404580D3BB78D54940
37508	4134	36.121177000000003	36.129548999999997	51.734332999999999	51.731298000000002	Воробьева	0103000020E6100000010000000500000082035ABA820F4240ABD0402C9BDD494082035ABA820F4240D1AFAD9FFEDD4940601DC70F95104240D1AFAD9FFEDD4940601DC70F95104240ABD0402C9BDD494082035ABA820F4240ABD0402C9BDD4940
37511	4134	36.173521999999998	36.181731999999997	51.741104	51.736006000000003	Бойцов 9 Дивизии	0103000020E61000000100000005000000799109F83516424074D4D17135DE4940799109F835164240A777F17EDCDE49407E5182FE42174240A777F17EDCDE49407E5182FE4217424074D4D17135DE4940799109F83516424074D4D17135DE4940
37537	4134	36.189359000000003	36.193302000000003	51.718471999999998	51.717792000000003	Антокольского	0103000020E61000000100000005000000051A6CEA3C1842404CAAB69BE0DB4940051A6CEA3C184240BD8BF7E3F6DB49402E20B41EBE184240BD8BF7E3F6DB49402E20B41EBE1842404CAAB69BE0DB4940051A6CEA3C1842404CAAB69BE0DB4940
37459	4134	36.060343000000003	36.303086	51.817112999999999	51.617047999999997	7-й Промышленный переулок	0103000020E6100000010000000500000072C5C551B9074240F607CA6DFBCE494072C5C551B90742407711A62897E849400FF0A485CB2642407711A62897E849400FF0A485CB264240F607CA6DFBCE494072C5C551B9074240F607CA6DFBCE4940
37538	54503	36.136654999999998	36.143903999999999	51.737445000000001	51.729190000000003	проспект Хрущева	0103000020E61000000100000005000000DDEA39E97D114240FE48111956DD4940DDEA39E97D114240A3CC069964DE4940BDE13E726B124240A3CC069964DE4940BDE13E726B124240FE48111956DD4940DDEA39E97D114240FE48111956DD4940
37550	54503	36.106543000000002	36.144703999999997	51.744588999999998	51.726444999999998	проспект Дружбы	0103000020E61000000100000005000000124F7633A30D4240DEAB5626FCDC4940124F7633A30D42400DFB3DB14EDF4940D9CC21A9851242400DFB3DB14EDF4940D9CC21A985124240DEAB5626FCDC4940124F7633A30D4240DEAB5626FCDC4940
37547	54503	36.223432000000003	36.223899000000003	51.753483000000003	51.750923	проезд Театральный	0103000020E61000000100000005000000A070766B991C42403868AF3E1EE04940A070766B991C4240C68B852172E04940B64DF1B8A81C4240C68B852172E04940B64DF1B8A81C42403868AF3E1EE04940A070766B991C42403868AF3E1EE04940
37576	54503	36.126010000000001	36.128435000000003	51.742710000000002	51.739313000000003	проезд Сергеева	0103000020E61000000100000005000000077C7E1821104240FB40F2CEA1DE4940077C7E1821104240C2340C1F11DF4940B554DE8E70104240C2340C1F11DF4940B554DE8E70104240FB40F2CEA1DE4940077C7E1821104240FB40F2CEA1DE4940
37556	54503	36.195126000000002	36.197138000000002	51.774380000000001	51.769720999999997	проезд Светлый	0103000020E61000000100000005000000B64C86E3F9184240AF05BD3786E24940B64C86E3F9184240975643E21EE34940416667D13B194240975643E21EE34940416667D13B194240AF05BD3786E24940B64C86E3F9184240AF05BD3786E24940
37593	54503	36.178435	36.184930000000001	51.752178000000001	51.750711000000003	Южный переулок	0103000020E610000001000000050000001BBB44F5D6164240ADDF4C4C17E049401BBB44F5D6164240A662635E47E049404F0647C9AB174240A662635E47E049404F0647C9AB174240ADDF4C4C17E049401BBB44F5D6164240ADDF4C4C17E04940
37574	54503	36.153596999999998	36.166587	51.719771999999999	51.688555000000001	Энгельса	0103000020E61000000100000005000000C1E10511A9134240A73FFB9122D84940C1E10511A9134240CB49287D21DC494029780AB952154240CB49287D21DC494029780AB952154240A73FFB9122D84940C1E10511A9134240A73FFB9122D84940
37534	54503	36.173611000000001	36.185369999999999	51.770879999999998	51.755991000000002	Школьная	0103000020E61000000100000005000000E99C9FE23816424001892650C4E04940E99C9FE238164240FB912232ACE249406BD44334BA174240FB912232ACE249406BD44334BA17424001892650C4E04940E99C9FE23816424001892650C4E04940
37542	54503	36.098799999999997	36.106687000000001	51.677432000000003	51.666898000000003	Широкая	0103000020E61000000100000005000000226C787AA50C424048E2E5E95CD54940226C787AA50C4240C7A17E17B6D6494045F46BEBA70D4240C7A17E17B6D6494045F46BEBA70D424048E2E5E95CD54940226C787AA50C424048E2E5E95CD54940
37571	54503	36.145575000000001	36.174284999999998	51.675421	51.665188000000001	Черняховского	0103000020E61000000100000005000000BF0E9C33A212424088D860E124D54940BF0E9C33A21242400C04013274D6494078978BF84E1642400C04013274D6494078978BF84E16424088D860E124D54940BF0E9C33A212424088D860E124D54940
37543	54503	36.161842999999998	36.168742999999999	51.728565000000003	51.721128	Чернышевского	0103000020E61000000100000005000000130B7C45B71442406D1D1CEC4DDC4940130B7C45B71442405001309E41DD4940E736E15E991542405001309E41DD4940E736E15E991542406D1D1CEC4DDC4940130B7C45B71442406D1D1CEC4DDC4940
37535	54503	36.194605000000003	36.201765000000002	51.745989000000002	51.745682000000002	Челюскинцев	0103000020E61000000100000005000000AD510FD1E8184240A29BFD8172DF4940AD510FD1E81842407F164B917CDF49401D3D7E6FD31942407F164B917CDF49401D3D7E6FD3194240A29BFD8172DF4940AD510FD1E8184240A29BFD8172DF4940
37662	54503	36.226289000000001	36.258789999999998	51.738505000000004	51.726160999999998	Чайковского	0103000020E61000000100000005000000E738B709F71C4240B950F9D7F2DC4940E738B709F71C42405C77F35487DE49401344DD07202142405C77F35487DE49401344DD0720214240B950F9D7F2DC4940E738B709F71C4240B950F9D7F2DC4940
37548	54503	36.079521999999997	36.162329	51.715676999999999	51.705894000000001	Сумская	0103000020E6100000010000000500000000A8E2C62D0A4240A8380EBC5ADA494000A8E2C62D0A4240ECBFCE4D9BDB4940A0185932C7144240ECBFCE4D9BDB4940A0185932C7144240A8380EBC5ADA494000A8E2C62D0A4240A8380EBC5ADA4940
37520	54503	36.229675	36.236116000000003	51.754613999999997	51.738795000000003	Станционная	0103000020E61000000100000005000000BADA8AFD651D424063B9A5D590DE4940BADA8AFD651D4240478D093197E04940FB07910C391E4240478D093197E04940FB07910C391E424063B9A5D590DE4940BADA8AFD651D424063B9A5D590DE4940
37525	54503	36.234741999999997	36.273046000000001	51.747700999999999	51.737974999999999	Союзная	0103000020E61000000100000005000000B27F9E060C1E4240FF21FDF675DE4940B27F9E060C1E4240DF1797AAB4DF4940DD26DC2BF3224240DF1797AAB4DF4940DD26DC2BF3224240FF21FDF675DE4940B27F9E060C1E4240FF21FDF675DE4940
37531	54503	36.172182999999997	36.179720000000003	51.733266999999998	51.725150999999997	Советская	0103000020E61000000100000005000000ADF6B0170A164240B2D47ABFD1DC4940ADF6B0170A164240361E6CB1DBDD4940F437A11001174240361E6CB1DBDD4940F437A11001174240B2D47ABFD1DC4940ADF6B0170A164240B2D47ABFD1DC4940
37579	54503	36.133707999999999	36.143922000000003	51.679001	51.666479000000002	Серегина	0103000020E61000000100000005000000569BFF571D114240433C122F4FD54940569BFF571D114240C4793881E9D6494064963D096C124240C4793881E9D6494064963D096C124240433C122F4FD54940569BFF571D114240433C122F4FD54940
37655	54503	36.193086999999998	36.197848	51.733015999999999	51.732731999999999	Серафима Соровского	0103000020E6100000010000000500000031242713B7184240C85D8429CADD494031242713B7184240EDB8E177D3DD49401DCA501553194240EDB8E177D3DD49401DCA501553194240C85D8429CADD494031242713B7184240C85D8429CADD4940
37577	54503	36.184786000000003	36.185191000000003	51.746357000000003	51.732174000000001	Семеновская	0103000020E610000001000000050000001C615111A7174240A27DACE0B7DD49401C615111A717424002124DA088DF4940BC41B456B417424002124DA088DF4940BC41B456B4174240A27DACE0B7DD49401C615111A7174240A27DACE0B7DD4940
37554	54503	36.183151000000002	36.193958000000002	51.742190999999998	51.741700000000002	Садовая	0103000020E61000000100000005000000679DF17D71174240BBB88D06F0DE4940679DF17D7117424059315C1D00DF49401766A19DD318424059315C1D00DF49401766A19DD3184240BBB88D06F0DE4940679DF17D71174240BBB88D06F0DE4940
37529	54503	36.234580000000001	36.266928	51.745375000000003	51.740015999999997	Республиканская	0103000020E61000000100000005000000D925AAB7061E4240244223D8B8DE4940D925AAB7061E4240C520B07268DF49407F315BB22A224240C520B07268DF49407F315BB22A224240244223D8B8DE4940D925AAB7061E4240244223D8B8DE4940
37582	54503	36.144416	36.156264999999998	51.673622999999999	51.670869000000003	Резиновая	0103000020E61000000100000005000000738236397C1242403B730F09DFD54940738236397C124240AD6A494739D649403541D47D00144240AD6A494739D649403541D47D001442403B730F09DFD54940738236397C1242403B730F09DFD54940
37562	54503	36.190157999999997	36.190275	51.751246999999999	51.73001	Радищева	0103000020E610000001000000050000005089EB185718424061E0B9F770DD49405089EB1857184240EB1B98DC28E049408A1F63EE5A184240EB1B98DC28E049408A1F63EE5A18424061E0B9F770DD49405089EB185718424061E0B9F770DD4940
37517	54503	36.137417999999997	36.164259999999999	51.761516	51.754603000000003	Пучковка	0103000020E61000000100000005000000DCF0BBE996114240543BC3D496E04940DCF0BBE996114240BCB0355B79E149403E05C07806154240BCB0355B79E149403E05C07806154240543BC3D496E04940DCF0BBE996114240543BC3D496E04940
37526	54503	36.179845999999998	36.193086999999998	51.734242999999999	51.733015999999999	Почтовая	0103000020E610000001000000050000008028983105174240EDB8E177D3DD494080289831051742409128B4ACFBDD494031242713B71842409128B4ACFBDD494031242713B7184240EDB8E177D3DD49408028983105174240EDB8E177D3DD4940
37663	54503	36.149859999999997	36.156615000000002	51.778241000000001	51.764944	Понизовка	0103000020E61000000100000005000000417DCB9C2E134240BEA25BAFE9E14940417DCB9C2E13424003B4AD669DE349401288D7F50B14424003B4AD669DE349401288D7F50B144240BEA25BAFE9E14940417DCB9C2E134240BEA25BAFE9E14940
37584	54503	36.166505999999998	36.188513999999998	51.721590999999997	51.714466000000002	Пионеров	0103000020E610000001000000050000003C4B9011501542404E0D349F73DB49403C4B901150154240410B09185DDC4940486B0C3A21184240410B09185DDC4940486B0C3A211842404E0D349F73DB49403C4B9011501542404E0D349F73DB4940
37559	54503	36.146670999999998	36.154539999999997	51.708545000000001	51.706485999999998	Пигорева	0103000020E61000000100000005000000C422861DC61242407A8A1C226EDA4940C422861DC6124240465F419AB1DA494040F67AF7C7134240465F419AB1DA494040F67AF7C71342407A8A1C226EDA4940C422861DC61242407A8A1C226EDA4940
37551	54503	36.142898000000002	36.171104999999997	51.755802000000003	51.721964999999997	Павлуновского	0103000020E61000000100000005000000F8544E7B4A124240A6ED5F5969DC4940F8544E7B4A1242402E20B41EBEE049404E97C5C4E61542402E20B41EBEE049404E97C5C4E6154240A6ED5F5969DC4940F8544E7B4A124240A6ED5F5969DC4940
37585	54503	36.209947999999997	36.213541999999997	51.761710999999998	51.754252000000001	Островского	0103000020E6100000010000000500000028EE7893DF1A4240A7785C548BE0494028EE7893DF1A42407100FDBE7FE1494045292158551B42407100FDBE7FE1494045292158551B4240A7785C548BE0494028EE7893DF1A4240A7785C548BE04940
37541	54503	36.137337000000002	36.162050000000001	51.708360999999996	51.702238000000001	Ольшанского	0103000020E61000000100000005000000F0C341429411424015014EEFE2D94940F0C34142941142408461C092ABDA49408D28ED0DBE1442408461C092ABDA49408D28ED0DBE14424015014EEFE2D94940F0C341429411424015014EEFE2D94940
37539	54503	36.146419000000002	36.152923000000001	51.674219999999998	51.663992999999998	Обоянская	0103000020E61000000100000005000000AB4198DBBD124240EFE2FDB8FDD44940AB4198DBBD124240912749D74CD6494032E719FB92134240912749D74CD6494032E719FB92134240EFE2FDB8FDD44940AB4198DBBD124240EFE2FDB8FDD44940
37589	54503	36.140445999999997	36.156489000000001	51.667383999999998	51.664422999999999	Народная	0103000020E61000000100000005000000506D7022FA114240E8DA17D00BD54940506D7022FA114240D4EFC2D66CD549408597E0D407144240D4EFC2D66CD549408597E0D407144240E8DA17D00BD54940506D7022FA114240E8DA17D00BD54940
37546	54503	36.136017000000002	36.140248	51.733223000000002	51.729134000000002	Мыльникова	0103000020E610000001000000050000009B594B01691142406A334E4354DD49409B594B016911424067D65240DADD49402AAA7EA5F311424067D65240DADD49402AAA7EA5F31142406A334E4354DD49409B594B01691142406A334E4354DD4940
37553	54503	36.193958000000002	36.205779999999997	51.742358000000003	51.741394	Мирная	0103000020E610000001000000050000001766A19DD3184240AEB9A3FFE5DE49401766A19DD318424045F6419605DF4940DF15C1FF561A424045F6419605DF4940DF15C1FF561A4240AEB9A3FFE5DE49401766A19DD3184240AEB9A3FFE5DE4940
37519	54503	36.063316	36.093705999999997	51.671824000000001	51.665500999999999	Менделеева	0103000020E6100000010000000500000022A81ABD1A084240473A03232FD5494022A81ABD1A0842407E552E54FED5494030B8E68EFE0B42407E552E54FED5494030B8E68EFE0B4240473A03232FD5494022A81ABD1A084240473A03232FD54940
37587	54503	36.205950999999999	36.229675	51.762987000000003	51.754613999999997	Маяковского	0103000020E610000001000000050000000CCA349A5C1A4240478D093197E049400CCA349A5C1A4240F722DA8EA9E14940BADA8AFD651D4240F722DA8EA9E14940BADA8AFD651D4240478D093197E049400CCA349A5C1A4240478D093197E04940
37581	54503	36.129593999999997	36.174582000000001	51.660288999999999	51.64837	Магистральный проезд	0103000020E6100000010000000500000000E143899610424090DAC4C9FDD2494000E14389961042404B74965984D44940323CF6B3581642404B74965984D44940323CF6B35816424090DAC4C9FDD2494000E143899610424090DAC4C9FDD24940
37592	54503	36.167656000000001	36.175362999999997	51.731845	51.723515999999996	Ломоносова	0103000020E61000000100000005000000357D76C075154240FD101B2C9CDC4940357D76C075154240DD5ED218ADDD4940D7F6764B72164240DD5ED218ADDD4940D7F6764B72164240FD101B2C9CDC4940357D76C075154240FD101B2C9CDC4940
37516	54503	36.192746	36.194856999999999	51.748151999999997	51.731414999999998	Ленина	0103000020E61000000100000005000000A837A3E6AB184240E466B8019FDD4940A837A3E6AB184240EF37DA71C3DF4940C632FD12F1184240EF37DA71C3DF4940C632FD12F1184240E466B8019FDD4940A837A3E6AB184240E466B8019FDD4940
37590	54503	36.166091999999999	36.188209000000001	51.725406999999997	51.717222999999997	Красной Армии	0103000020E610000001000000050000004910AE8042154240317898F6CDDB49404910AE80421542400DA5F622DADC49400CE8853B171842400DA5F622DADC49400CE8853B17184240317898F6CDDB49404910AE8042154240317898F6CDDB4940
37540	54503	36.239187999999999	36.240302	51.747221000000003	51.742983000000002	Краснознаменная	0103000020E610000001000000050000003ECC5EB69D1E4240F33D23111ADF49403ECC5EB69D1E424035F10EF0A4DF4940EA944737C21E424035F10EF0A4DF4940EA944737C21E4240F33D23111ADF49403ECC5EB69D1E4240F33D23111ADF4940
37575	54503	36.130259000000002	36.136834	51.737617999999998	51.731979000000003	Косухина	0103000020E610000001000000050000003D81B053AC104240ED2DE57CB1DD49403D81B053AC104240707841446ADE49408D7DC9C683114240707841446ADE49408D7DC9C683114240ED2DE57CB1DD49403D81B053AC104240ED2DE57CB1DD4940
37572	54503	36.135764999999999	36.149348000000003	51.705419999999997	51.700977000000002	Комарова	0103000020E6100000010000000500000081785DBF60114240C51F459DB9D9494081785DBF60114240DFF8DA334BDA49408CDCD3D51D134240DFF8DA334BDA49408CDCD3D51D134240C51F459DB9D9494081785DBF60114240C51F459DB9D94940
37563	54503	36.187049999999999	36.193123	51.734817999999997	51.734527999999997	Кирова	0103000020E61000000100000005000000C05B2041F117424086FF740305DE4940C05B2041F11742408D4127840EDE49407E8D2441B81842408D4127840EDE49407E8D2441B818424086FF740305DE4940C05B2041F117424086FF740305DE4940
37522	54503	36.240777999999999	36.260486999999998	51.75365	51.749223000000001	Каширцева	0103000020E6100000010000000500000053CC41D0D11E42409C340D8AE6DF494053CC41D0D11E4240B1506B9A77E049403E0455A357214240B1506B9A77E049403E0455A3572142409C340D8AE6DF494053CC41D0D11E42409C340D8AE6DF4940
37527	54503	36.166164000000002	36.198540000000001	51.797913000000001	51.748151999999997	Карла Маркса	0103000020E61000000100000005000000E3E2A8DC44154240EF37DA71C3DF4940E3E2A8DC44154240D106600322E6494053793BC269194240D106600322E6494053793BC269194240EF37DA71C3DF4940E3E2A8DC44154240EF37DA71C3DF4940
37564	54503	36.234966	36.268805999999998	51.765841000000002	51.758127000000002	Ильича	0103000020E6100000010000000500000002D6AA5D131E4240789B374E0AE1494002D6AA5D131E4240CD77F01307E24940FA7B293C68224240CD77F01307E24940FA7B293C68224240789B374E0AE1494002D6AA5D131E4240789B374E0AE14940
37545	54503	36.148161999999999	36.169981999999997	51.746417999999998	51.741236999999998	Запольная	0103000020E610000001000000050000004641F0F8F6124240E6CAA0DAE0DE49404641F0F8F6124240A79201A08ADF49404F745DF8C1154240A79201A08ADF49404F745DF8C1154240E6CAA0DAE0DE49404641F0F8F6124240E6CAA0DAE0DE4940
37544	54503	36.135109999999997	36.155321999999998	51.707712999999998	51.696120000000001	Заводская	0103000020E6100000010000000500000068AED3484B114240B70BCD751AD9494068AED3484B1142401EFAEE5696DA4940B62C5F97E11342401EFAEE5696DA4940B62C5F97E1134240B70BCD751AD9494068AED3484B114240B70BCD751AD94940
37661	54503	36.184956999999997	36.188091999999997	51.726394999999997	51.722914000000003	Добролюбова	0103000020E610000001000000050000004815C5ABAC17424008E9297288DC49404815C5ABAC1742402C7DE882FADC4940D2510E66131842402C7DE882FADC4940D2510E661318424008E9297288DC49404815C5ABAC17424008E9297288DC4940
37555	54503	36.186987000000002	36.189816999999998	51.751676000000003	51.733305999999999	Димитрова	0103000020E610000001000000050000007AE3A430EF174240F4FA93F8DCDD49407AE3A430EF17424014984EEB36E04940C79C67EC4B18424014984EEB36E04940C79C67EC4B184240F4FA93F8DCDD49407AE3A430EF174240F4FA93F8DCDD4940
37660	54503	36.164439999999999	36.192807999999999	51.72992	51.719332000000001	Дзержинского	0103000020E61000000100000005000000BE13B35E0C154240AF7B2B1213DC4940BE13B35E0C1542402159C0046EDD49401E34BBEEAD1842402159C0046EDD49401E34BBEEAD184240AF7B2B1213DC4940BE13B35E0C154240AF7B2B1213DC4940
37558	54503	36.141012000000003	36.147381000000003	51.709722999999997	51.696299000000003	Дейнеки	0103000020E61000000100000005000000FA2B64AE0C124240679E5C5320D94940FA2B64AE0C124240081C0934D8DA4940A1866F61DD124240081C0934D8DA4940A1866F61DD124240679E5C5320D94940FA2B64AE0C124240679E5C5320D94940
37552	54503	36.129756	36.142961	51.673130999999998	51.667746999999999	Гагарина	0103000020E61000000100000005000000DA3A38D89B1042404580D3BB78D54940DA3A38D89B1042403E76172829D649403ECDC98B4C1242403E76172829D649403ECDC98B4C1242404580D3BB78D54940DA3A38D89B1042404580D3BB78D54940
37566	54503	36.196230999999997	36.200687000000002	51.741326999999998	51.730193999999997	Володарского	0103000020E610000001000000050000000EBBEF181E19424022DE3AFF76DD49400EBBEF181E19424026529ACDE3DE4940BEDD921CB019424026529ACDE3DE4940BEDD921CB019424022DE3AFF76DD49400EBBEF181E19424022DE3AFF76DD4940
37565	54503	36.132252999999999	36.135953999999998	51.746105999999997	51.741728000000002	Веспремская	0103000020E6100000010000000500000021E692AAED10424085436FF1F0DE494021E692AAED104240B8ACC26680DF494054E1CFF066114240B8ACC26680DF494054E1CFF06611424085436FF1F0DE494021E692AAED10424085436FF1F0DE4940
37569	54503	36.149608000000001	36.183897000000002	51.765718999999997	51.727583000000003	Верхняя Луговая	0103000020E61000000100000005000000289CDD5A261342401310937021DD4940289CDD5A261342408176871403E24940906AD8EF891742408176871403E24940906AD8EF891742401310937021DD4940289CDD5A261342401310937021DD4940
37599	54503	36.149850999999998	36.173952999999997	51.760964000000001	51.734695000000002	Верхняя Казацкая	0103000020E61000000100000005000000EE224C512E13424072C45A7C0ADE4940EE224C512E13424078B7B24467E14940420587174416424078B7B24467E14940420587174416424072C45A7C0ADE4940EE224C512E13424072C45A7C0ADE4940
37568	54503	36.214951999999997	36.227348999999997	51.753092000000002	51.738906	ВЧК	0103000020E61000000100000005000000DA1A118C831B4240BA68C87894DE4940DA1A118C831B42408B70935165E049409FE3A3C5191D42408B70935165E049409FE3A3C5191D4240BA68C87894DE4940DA1A118C831B4240BA68C87894DE4940
37557	54503	36.145656000000002	36.149959000000003	51.674689999999998	51.668311000000003	Белгородская	0103000020E61000000100000005000000AC3B16DBA41242404E4700378BD54940AC3B16DBA41242401878EE3D5CD64940D55E44DB311342401878EE3D5CD64940D55E44DB311342404E4700378BD54940AC3B16DBA41242404E4700378BD54940
37561	54503	36.141064999999998	36.153004000000003	51.735548999999999	51.732542000000002	Аэродромная	0103000020E610000001000000050000001CCEFC6A0E1242402579AEEFC3DD49401CCEFC6A0E12424081CD397826DE49401F1494A29513424081CD397826DE49401F1494A2951342402579AEEFC3DD49401CCEFC6A0E1242402579AEEFC3DD4940
37524	54503	36.189359000000003	36.193302000000003	51.718471999999998	51.717792000000003	Антокольского	0103000020E61000000100000005000000051A6CEA3C1842404CAAB69BE0DB4940051A6CEA3C184240BD8BF7E3F6DB49402E20B41EBE184240BD8BF7E3F6DB49402E20B41EBE1842404CAAB69BE0DB4940051A6CEA3C1842404CAAB69BE0DB4940
37532	54503	36.130690000000001	36.166874	51.763890000000004	51.720263000000003	50-летия Октября	0103000020E6100000010000000500000006F52D73BA1042406AC2F69331DC494006F52D73BA104240E8DEC325C7E14940BF4692205C154240E8DEC325C7E14940BF4692205C1542406AC2F69331DC494006F52D73BA1042406AC2F69331DC4940
37573	54503	36.163541000000002	36.168725000000002	51.704754999999999	51.697544000000001	3-я Песковская	0103000020E610000001000000050000000F4757E9EE144240B1C22D1F49D949400F4757E9EE144240A3586E6935DA49404182E2C798154240A3586E6935DA49404182E2C798154240B1C22D1F49D949400F4757E9EE144240B1C22D1F49D94940
37560	54503	36.074860000000001	36.074886999999997	51.670813000000003	51.669477999999998	3-й Промышленный переулок	0103000020E61000000100000005000000A8E33103950942401CB28174B1D54940A8E3310395094240A75D4C33DDD54940A1F2AFE595094240A75D4C33DDD54940A1F2AFE5950942401CB28174B1D54940A8E33103950942401CB28174B1D54940
37536	54503	36.132953999999998	36.135154999999997	51.665807999999998	51.66225	2-я Энергетиков	0103000020E61000000100000005000000AAEFFCA20411424054E3A59BC4D44940AAEFFCA20411424024B5503239D54940087250C24C11424024B5503239D54940087250C24C11424054E3A59BC4D44940AAEFFCA20411424054E3A59BC4D44940
37518	54503	36.215544999999999	36.222884000000001	51.732408	51.731538	2-я Стрелецкая	0103000020E610000001000000050000007DE882FA961B424000E48409A3DD49407DE882FA961B424015AA9B8BBFDD49409D668176871C424015AA9B8BBFDD49409D668176871C424000E48409A3DD49407DE882FA961B424000E48409A3DD4940
37533	54503	36.243617	36.247183	51.746640999999997	51.730902	2-я Рабочая	0103000020E61000000100000005000000F4DF83D72E1F42405E4A5D328EDD4940F4DF83D72E1F4240266DAAEE91DF494047904AB1A31F4240266DAAEE91DF494047904AB1A31F42405E4A5D328EDD4940F4DF83D72E1F42405E4A5D328EDD4940
37580	54503	36.165526999999997	36.181516999999999	51.758834999999998	51.751151999999998	1-я Офицерская	0103000020E6100000010000000500000070CD1DFD2F1542409929ADBF25E0494070CD1DFD2F154240B3075A8121E149408255F5F23B174240B3075A8121E149408255F5F23B1742409929ADBF25E0494070CD1DFD2F1542409929ADBF25E04940
37591	54503	36.227088000000002	36.229998999999999	51.761888999999996	51.755249999999997	 Профсоюзная	0103000020E6100000010000000500000033A83638111D4240E9263108ACE0494033A83638111D42405017299485E149406D8E739B701D42405017299485E149406D8E739B701D4240E9263108ACE0494033A83638111D4240E9263108ACE04940
37578	54503	36.130690000000001	36.166874	51.763890000000004	51.720263000000003	 50-летия Октября	0103000020E6100000010000000500000006F52D73BA1042406AC2F69331DC494006F52D73BA104240E8DEC325C7E14940BF4692205C154240E8DEC325C7E14940BF4692205C1542406AC2F69331DC494006F52D73BA1042406AC2F69331DC4940
37415	54489	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Ленина	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37812	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	проезд Ветеранов	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37499	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Энтузиастов	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37603	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Привокзальная	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37450	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Первомайская	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37494	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Парковая	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
36677	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Мира	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37349	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Маршала Жукова	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37478	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Ленина	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37423	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Лени Голенькова	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37278	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Курская	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37044	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Комсомольская	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37447	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Дружбы	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37496	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Детский переулок	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37421	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Гагарина	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
37296	4934	35.341906000000002	35.392957000000003	52.34948	52.316082000000002	Воинов Интернационалистов	0103000020E6100000010000000500000031276893C3AB4140596DFE5F75284A4031276893C3AB4140944DB9C2BB2C4A40FDDD3B6A4CB24140944DB9C2BB2C4A40FDDD3B6A4CB24140596DFE5F75284A4031276893C3AB4140596DFE5F75284A40
5814	21688	36.174284999999998	36.192117000000003	51.668053999999998	51.665188000000001	улица Центральная	0103000020E6100000010000000500000078978BF84E16424088D860E124D5494078978BF84E16424022FB20CB82D54940B900344A9718424022FB20CB82D54940B900344A9718424088D860E124D5494078978BF84E16424088D860E124D54940
37855	21688	36.174284999999998	36.192117000000003	51.668053999999998	51.665188000000001	Центральная	0103000020E6100000010000000500000078978BF84E16424088D860E124D5494078978BF84E16424022FB20CB82D54940B900344A9718424022FB20CB82D54940B900344A9718424088D860E124D5494078978BF84E16424088D860E124D54940
37368	1360	37.239930000000001	37.309305999999999	51.903903999999997	51.873370999999999	Советская	0103000020E6100000010000000500000026AAB706B69E42402D23F59ECAEF494026AAB706B69E42409E5C5320B3F34940713AC95697A742409E5C5320B3F34940713AC95697A742402D23F59ECAEF494026AAB706B69E42402D23F59ECAEF4940
37340	1360	37.239930000000001	37.309305999999999	51.903903999999997	51.873370999999999	Кооперативная	0103000020E6100000010000000500000026AAB706B69E42402D23F59ECAEF494026AAB706B69E42409E5C5320B3F34940713AC95697A742409E5C5320B3F34940713AC95697A742402D23F59ECAEF494026AAB706B69E42402D23F59ECAEF4940
37492	32148	34.533458000000003	34.584015999999998	51.940207000000001	51.910555000000002	Советская	0103000020E6100000010000000500000011E50B5A48444140CA1AF5108DF4494011E50B5A48444140323CF6B358F849409D2B4A09C14A4140323CF6B358F849409D2B4A09C14A4140CA1AF5108DF4494011E50B5A48444140CA1AF5108DF44940
37369	32148	34.533458000000003	34.584015999999998	51.940207000000001	51.910555000000002	Кирова	0103000020E6100000010000000500000011E50B5A48444140CA1AF5108DF4494011E50B5A48444140323CF6B358F849409D2B4A09C14A4140323CF6B358F849409D2B4A09C14A4140CA1AF5108DF4494011E50B5A48444140CA1AF5108DF44940
37793	234	34.594552999999998	34.625311000000004	51.846350000000001	51.825324999999999	Школьная	0103000020E610000001000000050000008D5E0D501A4C41401DC9E53FA4E949408D5E0D501A4C41401C7C613255EC49401F6ADB300A5041401C7C613255EC49401F6ADB300A5041401DC9E53FA4E949408D5E0D501A4C41401DC9E53FA4E94940
37698	268	34.601433999999998	34.634734000000002	51.809323999999997	51.795596000000003	Ольховская	0103000020E61000000100000005000000EA5910CAFB4C41400A6AF816D6E54940EA5910CAFB4C414017EFC7ED97E7494063D4B5F63E51414017EFC7ED97E7494063D4B5F63E5141400A6AF816D6E54940EA5910CAFB4C41400A6AF816D6E54940
37339	32373	34.489854000000001	34.519480999999999	51.913637999999999	51.889015000000001	Пионерская	0103000020E610000001000000050000004BE82E89B33E4140A453573ECBF149404BE82E89B33E414001310917F2F449405AF2785A7E42414001310917F2F449405AF2785A7E424140A453573ECBF149404BE82E89B33E4140A453573ECBF14940
37301	30548	35.832557000000001	35.871858000000003	52.100923999999999	52.081468999999998	Тихая	0103000020E6100000010000000500000027874F3A91EA4140A45181936D0A4A4027874F3A91EA4140D5B0DF13EB0C4A40C460FE0A99EF4140D5B0DF13EB0C4A40C460FE0A99EF4140A45181936D0A4A4027874F3A91EA4140A45181936D0A4A40
37352	30548	35.832557000000001	35.871858000000003	52.100923999999999	52.081468999999998	Карла Маркса	0103000020E6100000010000000500000027874F3A91EA4140A45181936D0A4A4027874F3A91EA4140D5B0DF13EB0C4A40C460FE0A99EF4140D5B0DF13EB0C4A40C460FE0A99EF4140A45181936D0A4A4027874F3A91EA4140A45181936D0A4A40
37719	30301	37.075088999999998	37.149999000000001	51.700329000000004	51.660283	Шабаново	0103000020E6100000010000000500000009A52F849C894240698D412784D4494009A52F849C8942405FB87361A4D9494063B7CF2A339342405FB87361A4D9494063B7CF2A33934240698D412784D4494009A52F849C894240698D412784D44940
37744	30331	37.158577999999999	37.187745999999997	51.745046000000002	51.728006999999998	Школьная	0103000020E61000000100000005000000BBEEAD484C944240292158552FDD4940BBEEAD484C9442400002D6AA5DDF494037FA980F089842400002D6AA5DDF494037FA980F08984240292158552FDD4940BBEEAD484C944240292158552FDD4940
37472	6585	37.111694999999997	37.144168999999998	51.633419000000004	51.608646999999998	Красноармейская	0103000020E61000000100000005000000381092054C8E42407DE71725E8CD4940381092054C8E424020D5B0DF13D149406B0C3A217492424020D5B0DF13D149406B0C3A21749242407DE71725E8CD4940381092054C8E42407DE71725E8CD4940
37470	6585	37.111694999999997	37.144168999999998	51.633419000000004	51.608646999999998	Кирова	0103000020E61000000100000005000000381092054C8E42407DE71725E8CD4940381092054C8E424020D5B0DF13D149406B0C3A217492424020D5B0DF13D149406B0C3A21749242407DE71725E8CD4940381092054C8E42407DE71725E8CD4940
37741	29980	37.022078999999998	37.077567999999999	51.653846999999999	51.628968999999998	Бахаровская	0103000020E61000000100000005000000D576137CD38242405299620E82D04940D576137CD38242403ACB2C42B1D34940AA9B8BBFED8942403ACB2C42B1D34940AA9B8BBFED8942405299620E82D04940D576137CD38242405299620E82D04940
37712	27991	36.954273999999998	37.008012000000001	51.739916000000001	51.690325000000001	 Школьная	0103000020E6100000010000000500000028B682A6257A42403C4ED1915CD8494028B682A6257A4240C1E44691B5DE4940DFFC868906814240C1E44691B5DE4940DFFC8689068142403C4ED1915CD8494028B682A6257A42403C4ED1915CD84940
37804	29497	36.892882999999998	36.927917999999998	51.630887000000001	51.590107000000003	Центральная	0103000020E61000000100000005000000C2137AFD4972424002124DA088CB4940C2137AFD497242405C3CBCE7C0D0494053AF5B04C67642405C3CBCE7C0D0494053AF5B04C676424002124DA088CB4940C2137AFD4972424002124DA088CB4940
37805	29617	37.464436999999997	37.514634000000001	51.602829999999997	51.569040999999999	Школьная	0103000020E61000000100000005000000B306EFAB72BB4240A48AE255D6C84940B306EFAB72BB42401A868F8829CD494070B4E386DFC142401A868F8829CD494070B4E386DFC14240A48AE255D6C84940B306EFAB72BB4240A48AE255D6C84940
37845	54559	37.415703000000001	37.458831000000004	51.700139	51.671478	Мирная	0103000020E61000000100000005000000AFEC82C135B54240E3FDB8FDF2D54940AFEC82C135B54240BBD39D279ED949400CB265F9BABA4240BBD39D279ED949400CB265F9BABA4240E3FDB8FDF2D54940AFEC82C135B54240E3FDB8FDF2D54940
37740	29898	37.224263000000001	37.302695	51.615654999999997	51.573295000000002	Садовая	0103000020E61000000100000005000000F75965A6B49C4240ECFA05BB61C94940F75965A6B49C4240374F75C8CDCE4940D4D4B2B5BEA64240374F75C8CDCE4940D4D4B2B5BEA64240ECFA05BB61C94940F75965A6B49C4240ECFA05BB61C94940
37824	29543	36.837798999999997	36.860301999999997	51.627471	51.609850000000002	Новая	0103000020E610000001000000050000008DCF64FF3C6B424099BB96900FCE49408DCF64FF3C6B42401E1840F850D0494079573D601E6E42401E1840F850D0494079573D601E6E424099BB96900FCE49408DCF64FF3C6B424099BB96900FCE4940
37837	29969	37.314354999999999	37.334989	51.598646000000002	51.584063999999998	Репьевская	0103000020E61000000100000005000000C32ADEC83CA84240AE62F19BC2CA4940C32ADEC83CA84240CCF09F6EA0CC494087C267EBE0AA4240CCF09F6EA0CC494087C267EBE0AA4240AE62F19BC2CA4940C32ADEC83CA84240AE62F19BC2CA4940
37672	30482	37.027738999999997	37.074711000000001	51.766075000000001	51.738180999999997	Школьная	0103000020E6100000010000000500000070E998F38C834240A8C30AB77CDE494070E998F38C83424040A4DFBE0EE2494063D34A219089424040A4DFBE0EE2494063D34A2190894240A8C30AB77CDE494070E998F38C834240A8C30AB77CDE4940
37670	29721	37.016905000000001	37.041697999999997	51.564120000000003	51.549191	Центральная	0103000020E61000000100000005000000C7116BF129824240F72004E44BC64940C7116BF12982424080828B1535C8494080272D5C5685424080828B1535C8494080272D5C56854240F72004E44BC64940C7116BF129824240F72004E44BC64940
37720	30455	37.203924999999998	37.252668	51.751424999999998	51.730322000000001	Школьная	0103000020E610000001000000050000001CEBE2361A9A424050C6F8307BDD49401CEBE2361A9A4240CA32C4B12EE04940745FCE6C57A04240CA32C4B12EE04940745FCE6C57A0424050C6F8307BDD49401CEBE2361A9A424050C6F8307BDD4940
37807	30371	37.186093999999997	37.212117999999997	51.742252000000001	51.728208000000002	Молодежный переулок	0103000020E61000000100000005000000ACFD9DEDD1974240C15774EB35DD4940ACFD9DEDD1974240FFB1101D02DF49404B72C0AE269B4240FFB1101D02DF49404B72C0AE269B4240C15774EB35DD4940ACFD9DEDD1974240C15774EB35DD4940
37767	30069	37.028869999999998	37.092120999999999	51.691397000000002	51.678409000000002	Камышенская	0103000020E61000000100000005000000F2EA1C03B2834240F2272A1BD6D64940F2EA1C03B2834240B9C667B27FD849402D23F59ECA8B4240B9C667B27FD849402D23F59ECA8B4240F2272A1BD6D64940F2EA1C03B2834240F2272A1BD6D64940
37806	30074	36.97551	37.003833999999998	51.678845000000003	51.651572000000002	Ниженка	0103000020E61000000100000005000000E275FD82DD7C4240A27E17B666D34940E275FD82DD7C4240CD069964E4D64940724EECA17D804240CD069964E4D64940724EECA17D804240A27E17B666D34940E275FD82DD7C4240A27E17B666D34940
37721	30158	37.076839999999997	37.133344000000001	51.659238999999999	51.631405999999998	Запрудная	0103000020E610000001000000050000002783A3E4D5894240C43F6CE9D1D049402783A3E4D5894240B69F8CF161D44940158F8B6A11914240B69F8CF161D44940158F8B6A11914240C43F6CE9D1D049402783A3E4D5894240C43F6CE9D1D04940
37673	29681	37.076839999999997	37.133344000000001	51.659238999999999	51.631405999999998	Придорожная	0103000020E610000001000000050000002783A3E4D5894240C43F6CE9D1D049402783A3E4D5894240B69F8CF161D44940158F8B6A11914240B69F8CF161D44940158F8B6A11914240C43F6CE9D1D049402783A3E4D5894240C43F6CE9D1D04940
37613	30209	37.076839999999997	37.133344000000001	51.659238999999999	51.631405999999998	Мичурина	0103000020E610000001000000050000002783A3E4D5894240C43F6CE9D1D049402783A3E4D5894240B69F8CF161D44940158F8B6A11914240B69F8CF161D44940158F8B6A11914240C43F6CE9D1D049402783A3E4D5894240C43F6CE9D1D04940
37696	29747	37.318917999999996	37.367435999999998	51.690984	51.665764000000003	Придорожная	0103000020E61000000100000005000000880D164ED2A84240556D37C137D54940880D164ED2A842409607E92972D84940C0AF912408AF42409607E92972D84940C0AF912408AF4240556D37C137D54940880D164ED2A84240556D37C137D54940
37790	30225	37.149442000000001	37.184009000000003	51.684786000000003	51.653232000000003	Хуторская	0103000020E610000001000000050000000D535BEA20934240B0592E1B9DD349400D535BEA209342401C615111A7D74940B8955E9B8D9742401C615111A7D74940B8955E9B8D974240B0592E1B9DD349400D535BEA20934240B0592E1B9DD34940
37768	29608	37.415595000000003	37.447080999999997	51.623477999999999	51.597805999999999	Новая	0103000020E61000000100000005000000C9B08A3732B5424021AD31E884CC4940C9B08A3732B5424043E38920CECF4940DCD440F339B9424043E38920CECF4940DCD440F339B9424021AD31E884CC4940C9B08A3732B5424021AD31E884CC4940
37697	29432	36.880595	36.895381	51.703220999999999	51.693702999999999	Школьная	0103000020E61000000100000005000000B4024356B77042408C118942CBD84940B4024356B7704240226E4E2503DA4940DA3A38D89B724240226E4E2503DA4940DA3A38D89B7242408C118942CBD84940B4024356B77042408C118942CBD84940
37789	28060	35.51361	35.532483999999997	51.199582999999997	51.179470000000002	Советская	0103000020E610000001000000050000000473F4F8BDC141407B4E7ADFF89649400473F4F8BDC1414035EB8CEF8B99494056D28A6F28C4414035EB8CEF8B99494056D28A6F28C441407B4E7ADFF89649400473F4F8BDC141407B4E7ADFF8964940
37618	28430	35.315621	35.354869000000001	51.310479999999998	51.280946	Выгонок 2	0103000020E610000001000000050000002577D84466A8414094F8DC09F6A349402577D84466A84140F20703CFBDA749409FAEEE586CAD4140F20703CFBDA749409FAEEE586CAD414094F8DC09F6A349402577D84466A8414094F8DC09F6A34940
37791	28123	35.388133000000003	35.421388999999998	51.147280000000002	51.124442000000002	Центральная	0103000020E61000000100000005000000CBBF9657AEB14140DA1F28B7ED8F4940CBBF9657AEB141406DAD2F12DA92494073F22213F0B541406DAD2F12DA92494073F22213F0B54140DA1F28B7ED8F4940CBBF9657AEB14140DA1F28B7ED8F4940
37303	6248	35.227856000000003	35.291635999999997	51.209104000000004	51.185765000000004	Щепкина	0103000020E610000001000000050000004419AA622A9D4140E8DEC325C79749404419AA622A9D41403DBB7CEBC39A49400A2B155454A541403DBB7CEBC39A49400A2B155454A54140E8DEC325C79749404419AA622A9D4140E8DEC325C7974940
37476	6248	35.227856000000003	35.291635999999997	51.209104000000004	51.185765000000004	Октябрьская	0103000020E610000001000000050000004419AA622A9D4140E8DEC325C79749404419AA622A9D41403DBB7CEBC39A49400A2B155454A541403DBB7CEBC39A49400A2B155454A54140E8DEC325C79749404419AA622A9D4140E8DEC325C7974940
37343	6248	35.227856000000003	35.291635999999997	51.209104000000004	51.185765000000004	Заводской переулок	0103000020E610000001000000050000004419AA622A9D4140E8DEC325C79749404419AA622A9D41403DBB7CEBC39A49400A2B155454A541403DBB7CEBC39A49400A2B155454A54140E8DEC325C79749404419AA622A9D4140E8DEC325C7974940
37792	28873	35.107337999999999	35.137369	51.259993999999999	51.231917000000003	Село	0103000020E610000001000000050000001CCF6740BD8D41407731CD74AF9D49401CCF6740BD8D4140FF93BF7B47A14940FB3DB14E95914140FF93BF7B47A14940FB3DB14E959141407731CD74AF9D49401CCF6740BD8D41407731CD74AF9D4940
37841	28491	35.321289999999998	35.346784	51.332774999999998	51.311639999999997	Гора	0103000020E610000001000000050000001344DD0720A941400E10CCD1E3A749401344DD0720A9414094F6065F98AA49405663096B63AC414094F6065F98AA49405663096B63AC41400E10CCD1E3A749401344DD0720A941400E10CCD1E3A74940
37680	28263	35.392660999999997	35.415810999999998	51.195259999999998	51.178007999999998	Центральная	0103000020E6100000010000000500000013B534B742B24140933655F7C896494013B534B742B24140C51B9947FE98494095287B4B39B54140C51B9947FE98494095287B4B39B54140933655F7C896494013B534B742B24140933655F7C8964940
37742	29160	35.213527999999997	35.243701999999999	51.389515000000003	51.370638	Село	0103000020E61000000100000005000000E063B0E2549B4140D253E41071AF4940E063B0E2549B41409626A5A0DBB1494022FC8BA0319F41409626A5A0DBB1494022FC8BA0319F4140D253E41071AF4940E063B0E2549B4140D253E41071AF4940
37612	28291	35.312280000000001	35.359414000000001	51.111607999999997	51.093814999999999	Новая	0103000020E61000000100000005000000F29881CAF8A74140E76F4221028C4940F29881CAF8A7414069FCC22B498E4940BEDC274701AE414069FCC22B498E4940BEDC274701AE4140E76F4221028C4940F29881CAF8A74140E76F4221028C4940
37695	6378	35.477021999999998	35.489023000000003	51.131124	51.110470999999997	Мира	0103000020E610000001000000050000007BBC900E0FBD41400514EAE9238E49407BBC900E0FBD414040DCD5ABC8904940F4FE3F4E98BE414040DCD5ABC8904940F4FE3F4E98BE41400514EAE9238E49407BBC900E0FBD41400514EAE9238E4940
37633	28212	35.286048999999998	35.324765999999997	51.181660999999998	51.155433000000002	Школьная	0103000020E61000000100000005000000D906EE409DA441400EDC813AE5934940D906EE409DA44140B5FAEAAA40974940266DAAEE91A94140B5FAEAAA40974940266DAAEE91A941400EDC813AE5934940D906EE409DA441400EDC813AE5934940
37615	28169	35.350458000000003	35.378504	51.255794999999999	51.234048999999999	Центр	0103000020E61000000100000005000000904FC8CEDBAC4140AC545051F59D4940904FC8CEDBAC41407BBDFBE3BDA04940DDB3AED172B041407BBDFBE3BDA04940DDB3AED172B04140AC545051F59D4940904FC8CEDBAC4140AC545051F59D4940
9892	29152	35.217903	35.240073000000002	51.344788000000001	51.324052000000002	Молодежная	0103000020E61000000100000005000000A359D93EE49B4140091A33897AA94940A359D93EE49B4140D106600322AC494089D349B6BA9E4140D106600322AC494089D349B6BA9E4140091A33897AA94940A359D93EE49B4140091A33897AA94940
37758	28983	35.152172999999998	35.198382000000002	51.271818000000003	51.247407000000003	Церковщина	0103000020E61000000100000005000000C72AA5677A93414097E65608AB9F4940C72AA5677A934140693BA6EECAA24940BB0ED59464994140693BA6EECAA24940BB0ED5946499414097E65608AB9F4940C72AA5677A93414097E65608AB9F4940
37644	29101	35.230758000000002	35.266295	51.251995999999998	51.229768	Новоселовка	0103000020E610000001000000050000002BA5677A899D41406BD5AE09699D49402BA5677A899D4140855CA96741A049404E0B5EF415A24140855CA96741A049404E0B5EF415A241406BD5AE09699D49402BA5677A899D41406BD5AE09699D4940
37298	28702	35.248975000000002	35.271540999999999	51.221685000000001	51.207822999999998	Школьная	0103000020E61000000100000005000000C442AD69DE9F4140A52DAEF1999A4940C442AD69DE9F4140C381902C609C4940F64201DBC1A24140C381902C609C4940F64201DBC1A24140A52DAEF1999A4940C442AD69DE9F4140A52DAEF1999A4940
37292	28702	35.248975000000002	35.271540999999999	51.221685000000001	51.207822999999998	Новоселовка	0103000020E61000000100000005000000C442AD69DE9F4140A52DAEF1999A4940C442AD69DE9F4140C381902C609C4940F64201DBC1A24140C381902C609C4940F64201DBC1A24140A52DAEF1999A4940C442AD69DE9F4140A52DAEF1999A4940
37319	54466	35.277740000000001	35.322555999999999	51.207371000000002	51.174292000000001	Ленина	0103000020E610000001000000050000004165FCFB8CA341402BFA43334F9649404165FCFB8CA34140C59107228B9A49407590D78349A94140C59107228B9A49407590D78349A941402BFA43334F9649404165FCFB8CA341402BFA43334F964940
37836	28918	35.020408000000003	35.041060000000002	51.264142999999997	51.251719999999999	Большая	0103000020E61000000100000005000000D449B6BA9C824140E3DF675C38A04940D449B6BA9C824140D13B1570CFA149403E963E7441854140D13B1570CFA149403E963E7441854140E3DF675C38A04940D449B6BA9C824140E3DF675C38A04940
37640	28598	35.236730999999999	35.279842000000002	51.100026	51.084203000000002	Шлях	0103000020E6100000010000000500000085798F334D9E4140D09CF529C78A494085798F334D9E4140F65FE7A6CD8C49400C06D7DCD1A34140F65FE7A6CD8C49400C06D7DCD1A34140D09CF529C78A494085798F334D9E4140D09CF529C78A4940
37293	28620	35.240729000000002	35.263069999999999	51.197946999999999	51.182841000000003	пер. Гагарина 2й	0103000020E6100000010000000500000072193735D09E414019AF79556797494072193735D09E4140B0ABC9535699494084471B47ACA14140B0ABC9535699494084471B47ACA1414019AF79556797494072193735D09E414019AF795567974940
37337	28620	35.240729000000002	35.263069999999999	51.197946999999999	51.182841000000003	Мира	0103000020E6100000010000000500000072193735D09E414019AF79556797494072193735D09E4140B0ABC9535699494084471B47ACA14140B0ABC9535699494084471B47ACA1414019AF79556797494072193735D09E414019AF795567974940
37803	28842	35.167668999999997	35.187899000000002	51.189157999999999	51.173484999999999	Центральная	0103000020E61000000100000005000000C9C6832D769541405CACA8C134964940C9C6832D769541406DE34F5436984940BEF90D130D9841406DE34F5436984940BEF90D130D9841405CACA8C134964940C9C6832D769541405CACA8C134964940
37823	27980	35.478431999999998	35.495598999999999	51.165996	51.157060000000001	Центральная	0103000020E6100000010000000500000010AE80423DBD414040C1C58A1A94494010AE80423DBD414027A25F5B3F9549401477BCC96FBF414027A25F5B3F9549401477BCC96FBF414040C1C58A1A94494010AE80423DBD414040C1C58A1A944940
37766	5197	35.394798999999999	35.432510000000001	51.112766999999998	51.085278000000002	Королевка	0103000020E610000001000000050000002BBF0CC688B24140BE88B663EA8A49402BBF0CC688B24140B58828266F8E4940B398D87C5CB74140B58828266F8E4940B398D87C5CB74140BE88B663EA8A49402BBF0CC688B24140BE88B663EA8A4940
37616	27740	36.625042000000001	36.698056999999999	51.527348000000003	51.494259999999997	Садовая	0103000020E610000001000000050000002F5052600150424048DC63E943BF49402F5052600150424036CEA62380C3494037DF88EE5959424036CEA62380C3494037DF88EE5959424048DC63E943BF49402F5052600150424048DC63E943BF4940
37838	54558	36.58963	36.597921999999997	51.339708000000002	51.328234000000002	Центральная	0103000020E61000000100000005000000C85EEFFE784B4240B7B75B9203AA4940C85EEFFE784B424044183F8D7BAB49408AC745B5884C424044183F8D7BAB49408AC745B5884C4240B7B75B9203AA4940C85EEFFE784B4240B7B75B9203AA4940
37813	27236	36.539450000000002	36.605207	51.399883000000003	51.353366999999999	Центральная	0103000020E61000000100000005000000E2E995B20C454240293E3E213BAD4940E2E995B20C454240FA9CBB5D2FB34940B727486C774D4240FA9CBB5D2FB34940B727486C774D4240293E3E213BAD4940E2E995B20C454240293E3E213BAD4940
37703	26283	36.703321000000003	36.714855	51.582653999999998	51.572578999999998	Садовая	0103000020E6100000010000000500000086CB2A6C065A42402DB0C7444AC9494086CB2A6C065A42401971016894CA4940E8305F5E805B42401971016894CA4940E8305F5E805B42402DB0C7444AC9494086CB2A6C065A42402DB0C7444AC94940
37738	26774	36.771701	36.814155	51.585675999999999	51.572965000000003	Толмачевская	0103000020E610000001000000050000002FA52E19C76242405760C8EA56C949402FA52E19C7624240AB06616EF7CA4940FC6F253B36684240AB06616EF7CA4940FC6F253B366842405760C8EA56C949402FA52E19C76242405760C8EA56C94940
37641	27427	36.865772	36.884780999999997	51.441721000000001	51.406491000000003	переулок Школьный	0103000020E6100000010000000500000071E5EC9DD16E4240268FA7E507B4494071E5EC9DD16E42406C7A50508AB84940A38FF980407142406C7A50508AB84940A38FF98040714240268FA7E507B4494071E5EC9DD16E4240268FA7E507B44940
37444	26665	36.720928000000001	36.782992999999998	51.431956999999997	51.389684000000003	Первомайская	0103000020E61000000100000005000000A662635E475C424022E3512AE1B14940A662635E475C42409E23F25D4AB749409BFF571D396442409E23F25D4AB749409BFF571D3964424022E3512AE1B14940A662635E475C424022E3512AE1B14940
37816	27512	36.861514	36.895336	51.374887999999999	51.359357000000003	Сеймская	0103000020E61000000100000005000000E8853B17466E42405A4B0169FFAD4940E8853B17466E4240D8D47954FCAF49403A77BB5E9A724240D8D47954FCAF49403A77BB5E9A7242405A4B0169FFAD4940E8853B17466E42405A4B0169FFAD4940
37669	26972	36.819840999999997	36.852504000000003	51.320489000000002	51.283498000000002	Школьная	0103000020E61000000100000005000000C075C58CF06842409F3D97A949A44940C075C58CF068424027DD96C805A94940C7DADFD91E6D424027DD96C805A94940C7DADFD91E6D42409F3D97A949A44940C075C58CF06842409F3D97A949A44940
37694	54522	36.758603000000001	36.77948	51.355336000000001	51.330322000000002	Припрудная	0103000020E61000000100000005000000E1D231E7196142401D93C5FD47AA4940E1D231E719614240B58B69A67BAD49406BF12900C6634240B58B69A67BAD49406BF12900C66342401D93C5FD47AA4940E1D231E7196142401D93C5FD47AA4940
37656	27691	36.576991	36.624538999999999	51.554181	51.525835999999998	Центральная	0103000020E610000001000000050000000D8B51D7DA4942409C8713984EC349400D8B51D7DA49424044882B67EFC64940CC09DAE4F04F424044882B67EFC64940CC09DAE4F04F42409C8713984EC349400D8B51D7DA4942409C8713984EC34940
37600	27566	36.903807	36.991607999999999	51.372374999999998	51.359323000000003	Молодежная	0103000020E61000000100000005000000AC72A1F2AF734240AED9CA4BFEAD4940AC72A1F2AF7342408B6CE7FBA9AF4940DA39CD02ED7E42408B6CE7FBA9AF4940DA39CD02ED7E4240AED9CA4BFEAD4940AC72A1F2AF734240AED9CA4BFEAD4940
37808	54552	36.521079999999998	36.829039999999999	51.469109000000003	51.333793999999997	Можайская	0103000020E61000000100000005000000C24CDBBFB2424240EECC04C3B9AA4940C24CDBBFB242424030A182C30BBC4940B58993FB1D6A424030A182C30BBC4940B58993FB1D6A4240EECC04C3B9AA4940C24CDBBFB2424240EECC04C3B9AA4940
37668	27092	36.799396000000002	36.823920000000001	51.409356000000002	51.393853999999997	Школьная	0103000020E61000000100000005000000D046AE9B526642400BB3D0CE69B24940D046AE9B52664240F03504C765B449409A42E73576694240F03504C765B449409A42E735766942400BB3D0CE69B24940D046AE9B526642400BB3D0CE69B24940
37290	27146	36.701146999999999	36.742055999999998	51.446936000000001	51.416580000000003	Жуковка	0103000020E610000001000000050000002158552FBF5942407715527E52B549402158552FBF594240D9B3E73235B9494079E6E5B0FB5E4240D9B3E73235B9494079E6E5B0FB5E42407715527E52B549402158552FBF5942407715527E52B54940
37620	27017	36.754426000000002	36.781807000000001	51.404766000000002	51.378515	Центральная	0103000020E6100000010000000500000045A0FA0791604240D105F52D73B0494045A0FA079160424031444E5FCFB34940566474401264424031444E5FCFB349405664744012644240D105F52D73B0494045A0FA0791604240D105F52D73B04940
37739	27342	36.875293999999997	36.889460999999997	51.552601000000003	51.542206	Набережная	0103000020E61000000100000005000000483140A209704240F5D8960167C54940483140A209704240535E2BA1BBC64940A208A9DBD9714240535E2BA1BBC64940A208A9DBD9714240F5D8960167C54940483140A209704240F5D8960167C54940
37782	27154	36.693340999999997	36.707444000000002	51.478231000000001	51.467453999999996	Веселая	0103000020E61000000100000005000000EBFCDB65BF58424033315D88D5BB4940EBFCDB65BF584240797764AC36BD49402FE065868D5A4240797764AC36BD49402FE065868D5A424033315D88D5BB4940EBFCDB65BF58424033315D88D5BB4940
37762	21233	36.702441	36.719796000000002	51.640160000000002	51.624524000000001	Победы	0103000020E610000001000000050000004D2F3196E959424097C80567F0CF49404D2F3196E95942408B1A4CC3F0D1494054E57B46225C42408B1A4CC3F0D1494054E57B46225C424097C80567F0CF49404D2F3196E959424097C80567F0CF4940
37765	26896	36.798174000000003	36.826193000000004	51.360818999999999	51.345936000000002	переулок Школьный	0103000020E610000001000000050000003E42CD902A66424029417FA147AC49403E42CD902A664240416326512FAE4940929735B1C0694240416326512FAE4940929735B1C069424029417FA147AC49403E42CD902A66424029417FA147AC4940
37692	26879	36.713337000000003	36.761432999999997	51.500315000000001	51.448497000000003	Марии Овсянниковой	0103000020E610000001000000050000006D0377A04E5B424054AD855968B949406D0377A04E5B4240605969520AC049402E8CF4A276614240605969520AC049402E8CF4A27661424054AD855968B949406D0377A04E5B424054AD855968B94940
37794	27315	36.907966000000002	36.961244999999998	51.54965	51.518555999999997	Школьная	0103000020E61000000100000005000000A2F0D93A387442408192020B60C24940A2F0D93A387442408A1F63EE5AC64940C5387F130A7B42408A1F63EE5AC64940C5387F130A7B42408192020B60C24940A2F0D93A387442408192020B60C24940
37835	22851	36.720253999999997	36.743502999999997	51.501565999999997	51.480682000000002	Гвардейская	0103000020E6100000010000000500000016687748315C424050E3DEFC86BD494016687748315C42408C648F5033C049402BBD361B2B5F42408C648F5033C049402BBD361B2B5F424050E3DEFC86BD494016687748315C424050E3DEFC86BD4940
37717	27589	36.452925	36.474474999999998	51.457785000000001	51.436225	Центральная	0103000020E6100000010000000500000039454772F93942404B598638D6B7494039454772F9394240B8CCE9B298BA494082E2C798BB3C4240B8CCE9B298BA494082E2C798BB3C42404B598638D6B7494039454772F93942404B598638D6B74940
37748	25290	36.653869	36.715986999999998	51.569879999999998	51.522832000000001	Центральная	0103000020E61000000100000005000000226FB9FAB1534240B1A6B228ECC24940226FB9FAB15342407E52EDD3F1C849403AAE4676A55B42407E52EDD3F1C849403AAE4676A55B4240B1A6B228ECC24940226FB9FAB1534240B1A6B228ECC24940
37769	27424	36.881932999999997	36.907004999999998	51.482483000000002	51.439368999999999	Молодежная	0103000020E61000000100000005000000AF21382EE370424028F04E3E3DB84940AF21382EE370424020F0C000C2BD49407C2766BD1874424020F0C000C2BD49407C2766BD1874424028F04E3E3DB84940AF21382EE370424028F04E3E3DB84940
37781	26724	36.790546999999997	36.832093999999998	51.597324999999998	51.585535999999998	Школьная	0103000020E61000000100000005000000B779E3A430654240B950F9D7F2CA4940B779E3A430654240A60A462575CC49405299620E826A4240A60A462575CC49405299620E826A4240B950F9D7F2CA4940B779E3A430654240B950F9D7F2CA4940
37468	5153	37.690758000000002	37.739652999999997	51.864879000000002	51.824278	Свердлова	0103000020E61000000100000005000000A6B915C26AD84240F96706F181E94940A6B915C26AD84240A4FFE55AB4EE4940B3B112F3ACDE4240A4FFE55AB4EE4940B3B112F3ACDE4240F96706F181E94940A6B915C26AD84240F96706F181E94940
37398	5153	37.690758000000002	37.739652999999997	51.864879000000002	51.824278	Пролетарская	0103000020E61000000100000005000000A6B915C26AD84240F96706F181E94940A6B915C26AD84240A4FFE55AB4EE4940B3B112F3ACDE4240A4FFE55AB4EE4940B3B112F3ACDE4240F96706F181E94940A6B915C26AD84240F96706F181E94940
37300	5153	37.690758000000002	37.739652999999997	51.864879000000002	51.824278	Ленина	0103000020E61000000100000005000000A6B915C26AD84240F96706F181E94940A6B915C26AD84240A4FFE55AB4EE4940B3B112F3ACDE4240A4FFE55AB4EE4940B3B112F3ACDE4240F96706F181E94940A6B915C26AD84240F96706F181E94940
37475	5153	37.690758000000002	37.739652999999997	51.864879000000002	51.824278	Заводская	0103000020E61000000100000005000000A6B915C26AD84240F96706F181E94940A6B915C26AD84240A4FFE55AB4EE4940B3B112F3ACDE4240A4FFE55AB4EE4940B3B112F3ACDE4240F96706F181E94940A6B915C26AD84240F96706F181E94940
9676	22418	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Розы Люксембург	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37490	40354	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Советская площадь	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37611	40354	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Советская	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
9914	40354	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Розы Люксембург	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
67738	40354	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Кирова	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37412	40354	34.652152999999998	34.748218999999999	51.584366000000003	51.548915999999998	Дзержинского	0103000020E61000000100000005000000807EDFBF79534140252026E142C64940807EDFBF795341407A724D81CCCA4940779FE3A3C55F41407A724D81CCCA4940779FE3A3C55F4140252026E142C64940807EDFBF79534140252026E142C64940
37787	24076	34.436602000000001	34.462617000000002	51.691603999999998	51.668427999999999	Центральная	0103000020E6100000010000000500000021AF0793E237414087DD770C8FD5494021AF0793E237414032E4D87A86D849406DC9AA08373B414032E4D87A86D849406DC9AA08373B414087DD770C8FD5494021AF0793E237414087DD770C8FD54940
37811	23035	34.559266999999998	34.576864999999998	51.576413000000002	51.563470000000002	Бобровского	0103000020E61000000100000005000000B35DA10F964741407923F3C81FC84940B35DA10F96474140A0FEB3E6C7C94940809A5AB6D6494140A0FEB3E6C7C94940809A5AB6D64941407923F3C81FC84940B35DA10F964741407923F3C81FC84940
37396	23701	34.708100000000002	34.746125999999997	51.510361000000003	51.498851999999999	Лесная	0103000020E6100000010000000500000018265305A35A4140A8C5E061DABF494018265305A35A4140B2135E8253C14940FF58880E815F4140B2135E8253C14940FF58880E815F4140A8C5E061DABF494018265305A35A4140A8C5E061DABF4940
37743	54534	34.893287999999998	34.979624999999999	51.635173999999999	51.592933000000002	Комаровка	0103000020E6100000010000000500000062F4DC42577241400EDC813AE5CB494062F4DC42577241407FA2B2614DD1494008AC1C5A647D41407FA2B2614DD1494008AC1C5A647D41400EDC813AE5CB494062F4DC42577241400EDC813AE5CB4940
37443	23129	34.893287999999998	34.979624999999999	51.635173999999999	51.592933000000002	Ананьева	0103000020E6100000010000000500000062F4DC42577241400EDC813AE5CB494062F4DC42577241407FA2B2614DD1494008AC1C5A647D41407FA2B2614DD1494008AC1C5A647D41400EDC813AE5CB494062F4DC42577241400EDC813AE5CB4940
37772	24087	34.338290000000001	34.382218000000002	51.694350999999997	51.671495	Дубовка	0103000020E610000001000000050000002C4833164D2B4140B936548CF3D549402C4833164D2B4140F2785A7EE0D84940A5F8F884EC304140F2785A7EE0D84940A5F8F884EC304140B936548CF3D549402C4833164D2B4140B936548CF3D54940
37788	21994	36.691597999999999	36.732813	51.215237000000002	51.195473999999997	Центральная	0103000020E6100000010000000500000050FD834886584240F19BC24A0599494050FD834886584240D0F1D1E28C9B4940B58AFED0CC5D4240D0F1D1E28C9B4940B58AFED0CC5D4240F19BC24A0599494050FD834886584240F19BC24A05994940
37726	21025	36.472740999999999	37.014183000000003	51.245010999999998	51.186121	Клубная	0103000020E610000001000000050000003A3DEFC6823C4240A60C1CD0D29749403A3DEFC6823C424083143C855C9F49406094A0BFD081424083143C855C9F49406094A0BFD0814240A60C1CD0D29749403A3DEFC6823C4240A60C1CD0D2974940
37763	21959	36.565358000000003	36.614280000000001	51.167973000000003	51.127529000000003	Школьная	0103000020E610000001000000050000001844A4A65D4842405325CADE529049401844A4A65D48424036CEA623809549401F4B1FBAA04E424036CEA623809549401F4B1FBAA04E42405325CADE529049401844A4A65D4842405325CADE52904940
37617	21162	36.917264000000003	36.970022	51.355319000000001	51.327975000000002	Школьная	0103000020E610000001000000050000002AE620E868754240EB73B515FBA949402AE620E868754240DF52CE177BAD494044334FAE297C4240DF52CE177BAD494044334FAE297C4240EB73B515FBA949402AE620E868754240EB73B515FBA94940
37407	22244	36.675643999999998	36.720154999999998	51.252464000000003	51.219963999999997	Советская	0103000020E610000001000000050000008BDEA9807B5642400F26C5C7279C49408BDEA9807B5642406CB587BD50A049408386FE092E5C42406CB587BD50A049408386FE092E5C42400F26C5C7279C49408BDEA9807B5642400F26C5C7279C4940
37466	22244	36.675643999999998	36.720154999999998	51.252464000000003	51.219963999999997	Почтовая	0103000020E610000001000000050000008BDEA9807B5642400F26C5C7279C49408BDEA9807B5642406CB587BD50A049408386FE092E5C42406CB587BD50A049408386FE092E5C42400F26C5C7279C49408BDEA9807B5642400F26C5C7279C4940
37693	20680	36.806142000000001	36.837142999999998	51.229221000000003	51.193261999999997	Центральная	0103000020E610000001000000050000004DF73AA92F6742409FC728CFBC9849404DF73AA92F67424039471D1D579D4940A4897780276B424039471D1D579D4940A4897780276B42409FC728CFBC9849404DF73AA92F6742409FC728CFBC984940
37735	21858	36.833531999999998	36.851956000000001	51.270341999999999	51.219631	Пигоревых	0103000020E61000000100000005000000B115342DB16A424009185DDE1C9C4940B115342DB16A42401C5E10919AA24940C4D0EAE40C6D42401C5E10919AA24940C4D0EAE40C6D424009185DDE1C9C4940B115342DB16A424009185DDE1C9C4940
37736	21563	36.527233000000003	36.600329000000002	51.231324999999998	51.209311999999997	Центральная	0103000020E610000001000000050000009D2FF65E7C434240865451BCCA9A49409D2FF65E7C434240A4DFBE0E9C9D494092EBA694D74C4240A4DFBE0E9C9D494092EBA694D74C4240865451BCCA9A49409D2FF65E7C434240865451BCCA9A4940
37764	21411	36.388255000000001	36.429442999999999	51.25761	51.228645	Кирова	0103000020E6100000010000000500000016C1FF56B23142406CB2463D449D494016C1FF56B2314240B08F4E5DF9A04940813FFCFCF7364240B08F4E5DF9A04940813FFCFCF73642406CB2463D449D494016C1FF56B23142406CB2463D449D4940
37727	21371	36.413632	36.444578999999997	51.278112	51.263365	Центральная	0103000020E610000001000000050000001F4AB4E4F13442409DF4BEF1B5A149401F4AB4E4F134424005508C2C99A3494083BEF4F6E738424005508C2C99A3494083BEF4F6E73842409DF4BEF1B5A149401F4AB4E4F13442409DF4BEF1B5A14940
37834	21323	36.763095	36.793151999999999	51.266188	51.251792999999999	Центральная	0103000020E61000000100000005000000DD5ED218AD6142404D2EC6C03AA04940DD5ED218AD614240384BC97212A24940E560360186654240384BC97212A24940E5603601866542404D2EC6C03AA04940DD5ED218AD6142404D2EC6C03AA04940
37394	22145	36.643897000000003	36.783855000000003	51.332669000000003	51.273513999999999	Ломоносова	0103000020E610000001000000050000000B7F86376B524240C37FBA8102A349400B7F86376B5242404FB2D5E594AA49402EE7525C556442404FB2D5E594AA49402EE7525C55644240C37FBA8102A349400B7F86376B524240C37FBA8102A34940
37604	22145	36.643897000000003	36.783855000000003	51.332669000000003	51.273513999999999	Дзержинского	0103000020E610000001000000050000000B7F86376B524240C37FBA8102A349400B7F86376B5242404FB2D5E594AA49402EE7525C556442404FB2D5E594AA49402EE7525C55644240C37FBA8102A349400B7F86376B524240C37FBA8102A34940
37761	21182	36.850968000000002	36.880442000000002	51.331840999999997	51.308368000000002	Центральная	0103000020E61000000100000005000000A5F8F884EC6C42400491459A78A74940A5F8F884EC6C4240683C11C479AA49402E03CE52B2704240683C11C479AA49402E03CE52B27042400491459A78A74940A5F8F884EC6C42400491459A78A74940
37678	6432	36.452350000000003	36.513624	51.260885000000002	51.245472999999997	Центральная	0103000020E610000001000000050000003D2CD49AE63942408786C5A86B9F49403D2CD49AE63942402C82FFAD64A149406938656EBE4142402C82FFAD64A149406938656EBE4142408786C5A86B9F49403D2CD49AE63942408786C5A86B9F4940
37725	21767	37.056106999999997	37.075375999999999	51.284776999999998	51.273847000000004	Владимировская	0103000020E61000000100000005000000D009A1832E874240CA8D226B0DA34940D009A1832E87424095D39E9273A449409F73B7EBA589424095D39E9273A449409F73B7EBA5894240CA8D226B0DA34940D009A1832E874240CA8D226B0DA34940
37737	22089	36.670684999999999	36.688490000000002	51.222507999999998	51.216375999999997	Ватутина	0103000020E6100000010000000500000079758E01D9554240D4D17135B29B494079758E01D9554240978C63247B9C4940C0CFB87020584240978C63247B9C4940C0CFB87020584240D4D17135B29B494079758E01D9554240D4D17135B29B4940
37770	22060	36.725535999999998	36.749926000000002	51.205317000000001	51.183230000000002	Молодежная	0103000020E610000001000000050000000B09185DDE5C4240B3D2A414749749400B09185DDE5C42400B28D4D3479A4940C6353E93FD5F42400B28D4D3479A4940C6353E93FD5F4240B3D2A414749749400B09185DDE5C4240B3D2A41474974940
37679	21286	36.883164000000001	36.926067000000003	51.211213999999998	51.189405999999998	Садовая	0103000020E61000000100000005000000958098840B71424045D5AF743E984940958098840B7142408A3A730F099B4940D2730B5D897642408A3A730F099B4940D2730B5D8976424045D5AF743E984940958098840B71424045D5AF743E984940
37654	20938	36.401730000000001	36.465591000000003	51.225250000000003	51.194203999999999	Плант	0103000020E610000001000000050000003AE97DE36B3342404E603AADDB9849403AE97DE36B33424046B6F3FDD49C4940EE27637C983B424046B6F3FDD49C4940EE27637C983B42404E603AADDB9849403AE97DE36B3342404E603AADDB984940
37465	19867	36.278911999999998	36.322192999999999	52.336463000000002	52.300317	Октябрьская	0103000020E61000000100000005000000213B6F63B323424067B796C970264A40213B6F63B323424033A83638112B4A400400C79E3D29424033A83638112B4A400400C79E3D29424067B796C970264A40213B6F63B323424067B796C970264A40
37406	19867	36.278911999999998	36.322192999999999	52.336463000000002	52.300317	Ленина	0103000020E61000000100000005000000213B6F63B323424067B796C970264A40213B6F63B323424033A83638112B4A400400C79E3D29424033A83638112B4A400400C79E3D29424067B796C970264A40213B6F63B323424067B796C970264A40
37334	19867	36.278911999999998	36.322192999999999	52.336463000000002	52.300317	Веселая	0103000020E61000000100000005000000213B6F63B323424067B796C970264A40213B6F63B323424033A83638112B4A400400C79E3D29424033A83638112B4A400400C79E3D29424067B796C970264A40213B6F63B323424067B796C970264A40
37659	20349	36.268490999999997	36.289161999999997	52.193379999999998	52.177053000000001	Комсомольская	0103000020E610000001000000050000009A22C0E95D224240505436ACA9164A409A22C0E95D224240A9D903ADC0184A407B9FAA4203254240A9D903ADC0184A407B9FAA4203254240505436ACA9164A409A22C0E95D224240505436ACA9164A40
37652	20784	36.188037999999999	36.230860999999997	52.285361999999999	52.251142999999999	Писаревка	0103000020E61000000100000005000000DF3312A11118424046CF2D7425204A40DF3312A111184240B5C2F4BD86244A40FF756EDA8C1D4240B5C2F4BD86244A40FF756EDA8C1D424046CF2D7425204A40DF3312A11118424046CF2D7425204A40
37724	20828	36.225299999999997	36.303435999999998	52.347726000000002	52.295724	Майоровка	0103000020E61000000100000005000000F7E461A1D61C42403752B648DA254A40F7E461A1D61C424005FC1A49822C4A40EB36A8FDD626424005FC1A49822C4A40EB36A8FDD62642403752B648DA254A40F7E461A1D61C42403752B648DA254A40
37802	20828	36.225299999999997	36.303435999999998	52.347726000000002	52.295724	Бугровка 	0103000020E61000000100000005000000F7E461A1D61C42403752B648DA254A40F7E461A1D61C424005FC1A49822C4A40EB36A8FDD626424005FC1A49822C4A40EB36A8FDD62642403752B648DA254A40F7E461A1D61C42403752B648DA254A40
37609	18723	35.971274999999999	35.996437	51.655467000000002	51.643022000000002	Центральная	0103000020E6100000010000000500000011363CBD52FC4140E44D7E8B4ED2494011363CBD52FC4140BA4DB857E6D349401EC3633F8BFF4140BA4DB857E6D349401EC3633F8BFF4140E44D7E8B4ED2494011363CBD52FC4140E44D7E8B4ED24940
37651	18505	35.909802999999997	35.971921999999999	51.662824999999998	51.642094	Сеймская	0103000020E61000000100000005000000BE66B96C74F441409A7ADD2230D24940BE66B96C74F4414050FC1873D7D44940A721AAF067FC414050FC1873D7D44940A721AAF067FC41409A7ADD2230D24940BE66B96C74F441409A7ADD2230D24940
37386	18505	35.909802999999997	35.971921999999999	51.662824999999998	51.642094	Первомайская	0103000020E61000000100000005000000BE66B96C74F441409A7ADD2230D24940BE66B96C74F4414050FC1873D7D44940A721AAF067FC414050FC1873D7D44940A721AAF067FC41409A7ADD2230D24940BE66B96C74F441409A7ADD2230D24940
37405	18505	35.909802999999997	35.971921999999999	51.662824999999998	51.642094	Октябрьская	0103000020E61000000100000005000000BE66B96C74F441409A7ADD2230D24940BE66B96C74F4414050FC1873D7D44940A721AAF067FC414050FC1873D7D44940A721AAF067FC41409A7ADD2230D24940BE66B96C74F441409A7ADD2230D24940
37485	18505	35.909802999999997	35.971921999999999	51.662824999999998	51.642094	Коммунистическая	0103000020E61000000100000005000000BE66B96C74F441409A7ADD2230D24940BE66B96C74F4414050FC1873D7D44940A721AAF067FC414050FC1873D7D44940A721AAF067FC41409A7ADD2230D24940BE66B96C74F441409A7ADD2230D24940
37289	18924	35.889780000000002	35.905878000000001	51.654864000000003	51.632143999999997	Школьная	0103000020E610000001000000050000004451A04FE4F141406A2E3718EAD049404451A04FE4F14140F4A96395D2D349403C1570CFF3F34140F4A96395D2D349403C1570CFF3F341406A2E3718EAD049404451A04FE4F141406A2E3718EAD04940
37389	18924	35.889780000000002	35.905878000000001	51.654864000000003	51.632143999999997	Победы	0103000020E610000001000000050000004451A04FE4F141406A2E3718EAD049404451A04FE4F14140F4A96395D2D349403C1570CFF3F34140F4A96395D2D349403C1570CFF3F341406A2E3718EAD049404451A04FE4F141406A2E3718EAD04940
37751	18924	35.889780000000002	35.905878000000001	51.654864000000003	51.632143999999997	Красной Звезды	0103000020E610000001000000050000004451A04FE4F141406A2E3718EAD049404451A04FE4F14140F4A96395D2D349403C1570CFF3F34140F4A96395D2D349403C1570CFF3F341406A2E3718EAD049404451A04FE4F141406A2E3718EAD04940
37783	16991	36.393303000000003	36.435119999999998	51.142510999999999	51.123555000000003	Садовая	0103000020E610000001000000050000009835B1C057324240EF2076A6D08F49409835B1C057324240FE28EACC3D924940F2EA1C03B2374240FE28EACC3D924940F2EA1C03B2374240EF2076A6D08F49409835B1C057324240EF2076A6D08F4940
37784	18007	35.999464000000003	36.030887	51.250953000000003	51.220996999999997	Молодежная	0103000020E61000000100000005000000C2C3B46FEEFF4140CEC133A1499C4940C2C3B46FEEFF4140A3EA573A1FA049408F6FEF1AF4034240A3EA573A1FA049408F6FEF1AF4034240CEC133A1499C4940C2C3B46FEEFF4140CEC133A1499C4940
37829	16859	36.085926999999998	36.105699000000001	51.287278000000001	51.265140000000002	Выгон	0103000020E61000000100000005000000F46BEBA7FF0A4240446E861BF0A14940F46BEBA7FF0A42401E6E8786C5A44940261C7A8B870D42401E6E8786C5A44940261C7A8B870D4240446E861BF0A14940F46BEBA7FF0A4240446E861BF0A14940
37832	17808	35.847684999999998	35.874930999999997	51.23997	51.229441000000001	План	0103000020E61000000100000005000000A6272CF180EC414047AE9B525E9D4940A6272CF180EC4140B4024356B79E4940D7A02FBDFDEF4140B4024356B79E4940D7A02FBDFDEF414047AE9B525E9D4940A6272CF180EC414047AE9B525E9D4940
37639	17838	36.118661000000003	36.150435000000002	51.196502000000002	51.182586999999998	Центральная	0103000020E61000000100000005000000C4279D48300F42405ED6C4025F974940C4279D48300F42409FCC3FFA269949403E963E74411342409FCC3FFA269949403E963E74411342405ED6C4025F974940C4279D48300F42405ED6C4025F974940
37653	17949	36.201549	36.221375000000002	51.206744999999998	51.191488999999997	Центральная	0103000020E6100000010000000500000050C58D5BCC194240994528B68298494050C58D5BCC19424046CEC29E769A494075931804561C424046CEC29E769A494075931804561C4240994528B68298494050C58D5BCC194240994528B682984940
37650	17608	36.284948999999997	36.303821999999997	51.234955999999997	51.224003000000003	Ленина	0103000020E6100000010000000500000092037635792442405B9A5B21AC9C49409203763579244240DEFFC709139E494014E7A8A3E3264240DEFFC709139E494014E7A8A3E32642405B9A5B21AC9C494092037635792442405B9A5B21AC9C4940
37638	17711	35.938620999999998	35.968364000000001	51.215434000000002	51.194453000000003	Карачёвка	0103000020E610000001000000050000005E2BA1BB24F84140F7CDFDD5E39849405E2BA1BB24F8414026396057939B4940D74FFF59F3FB414026396057939B4940D74FFF59F3FB4140F7CDFDD5E39849405E2BA1BB24F84140F7CDFDD5E3984940
37608	17550	36.302599999999998	36.315778999999999	51.254589000000003	51.245404999999998	Лесная	0103000020E6100000010000000500000082E2C798BB2642402FA3586E699F494082E2C798BB264240EF75525F96A04940BDE13E726B284240EF75525F96A04940BDE13E726B2842402FA3586E699F494082E2C798BB2642402FA3586E699F4940
37682	17504	36.330348999999998	36.363875	51.271338999999998	51.246217000000001	Выгон	0103000020E6100000010000000500000016A243E0482A4240105CE509849F494016A243E0482A42408E90813CBBA249407F6ABC74932E42408E90813CBBA249407F6ABC74932E4240105CE509849F494016A243E0482A4240105CE509849F4940
37830	17641	36.257818999999998	36.284697000000001	51.229908999999999	51.213526999999999	Верхняя Поповка	0103000020E61000000100000005000000CAA486360021424010E84CDA549B4940CAA48636002142402D077AA86D9D4940792288F3702442402D077AA86D9D4940792288F37024424010E84CDA549B4940CAA486360021424010E84CDA549B4940
37627	16962	36.283977999999998	36.308565000000002	51.204239000000001	51.195095999999999	Центральная	0103000020E6100000010000000500000049641F64592442404BCADDE7F898494049641F6459244240ACC8E880249A49405AD8D30E7F274240ACC8E880249A49405AD8D30E7F2742404BCADDE7F898494049641F64592442404BCADDE7F8984940
37833	17435	36.290706999999998	36.308861999999998	51.363013000000002	51.340922999999997	Молодежная	0103000020E61000000100000005000000F0DB10E33525424023BA675DA3AB4940F0DB10E335254240ED82C13577AE4940137D3ECA88274240ED82C13577AE4940137D3ECA8827424023BA675DA3AB4940F0DB10E33525424023BA675DA3AB4940
37750	17054	36.453724000000001	36.486503999999996	51.096445000000003	51.078935000000001	Тополевая	0103000020E6100000010000000500000085B4C6A0133A424040C1C58A1A8A494085B4C6A0133A42406E6E4C4F588C4940C4AF58C3453E42406E6E4C4F588C4940C4AF58C3453E424040C1C58A1A8A494085B4C6A0133A424040C1C58A1A8A4940
37711	16769	36.218634999999999	36.22663	51.267162999999996	51.262287999999998	Садовая	0103000020E6100000010000000500000067614F3BFC1B42400E1137A792A1494067614F3BFC1B4240C2D9AD6532A2494070253B36021D4240C2D9AD6532A2494070253B36021D42400E1137A792A1494067614F3BFC1B42400E1137A792A14940
37632	17902	36.088514000000004	36.136502	51.164656999999998	51.147432999999999	Садовая	0103000020E610000001000000050000007C9E3F6D540B4240F3ACA415DF9249407C9E3F6D540B42405B07077B1395494057EBC4E5781142405B07077B1395494057EBC4E578114240F3ACA415DF9249407C9E3F6D540B4240F3ACA415DF924940
37486	5830	36.222462	36.314188999999999	51.225825	51.197563000000002	Мирная	0103000020E61000000100000005000000274D83A2791C424028F38FBE49994940274D83A2791C424042CF66D5E79C4940A8E15B583728424042CF66D5E79C4940A8E15B583728424028F38FBE49994940274D83A2791C424028F38FBE49994940
37489	5830	36.222462	36.314188999999999	51.225825	51.197563000000002	Луначарского	0103000020E61000000100000005000000274D83A2791C424028F38FBE49994940274D83A2791C424042CF66D5E79C4940A8E15B583728424042CF66D5E79C4940A8E15B583728424028F38FBE49994940274D83A2791C424028F38FBE49994940
37350	5830	36.222462	36.314188999999999	51.225825	51.197563000000002	Ленина	0103000020E61000000100000005000000274D83A2791C424028F38FBE49994940274D83A2791C424042CF66D5E79C4940A8E15B583728424042CF66D5E79C4940A8E15B583728424028F38FBE49994940274D83A2791C424028F38FBE49994940
37677	16291	36.229154000000001	36.248342000000001	51.188293999999999	51.169803000000002	Выгон	0103000020E61000000100000005000000B1DF13EB541D4240A0E1CD1ABC954940B1DF13EB541D42403A048E041A984940931CB0ABC91F42403A048E041A984940931CB0ABC91F4240A0E1CD1ABC954940B1DF13EB541D4240A0E1CD1ABC954940
37690	16496	35.798960000000001	35.833266999999999	51.276608000000003	51.256934000000001	Выгон	0103000020E61000000100000005000000F5673F5244E64140809D9B36E3A04940F5673F5244E64140EFE714E467A3494003EB387EA8EA4140EFE714E467A3494003EB387EA8EA4140809D9B36E3A04940F5673F5244E64140809D9B36E3A04940
37722	17403	36.369076	36.388623000000003	51.327114000000002	51.302669999999999	Молодежная	0103000020E6100000010000000500000087DEE2E13D2F42407BBDFBE3BDA6494087DEE2E13D2F424029081EDFDEA9494099BC0166BE31424029081EDFDEA9494099BC0166BE3142407BBDFBE3BDA6494087DEE2E13D2F42407BBDFBE3BDA64940
37796	17245	36.281525999999999	36.317799999999998	51.362456000000002	51.292431999999998	Центральна	0103000020E61000000100000005000000A27C410B09244240E5266A696EA54940A27C410B09244240971E4DF564AE49409B559FABAD284240971E4DF564AE49409B559FABAD284240E5266A696EA54940A27C410B09244240E5266A696EA54940
37714	16660	35.921553000000003	35.938890999999998	51.274923000000001	51.252091999999998	Выгон	0103000020E61000000100000005000000EE43DE72F5F54140A7CAF78C44A04940EE43DE72F5F5414088F546AD30A349401EC18D942DF8414088F546AD30A349401EC18D942DF84140A7CAF78C44A04940EE43DE72F5F54140A7CAF78C44A04940
37676	16342	36.340204	36.359661000000003	51.168757999999997	51.146309000000002	Молодежная	0103000020E61000000100000005000000F4FBFECD8B2B4240240ED940BA924940F4FBFECD8B2B42401C78B5DC99954940C652245F092E42401C78B5DC99954940C652245F092E4240240ED940BA924940F4FBFECD8B2B4240240ED940BA924940
37753	17087	36.025855999999997	36.065247999999997	51.184387999999998	51.160815999999997	Молодежная	0103000020E61000000100000005000000E333D93F4F0342403656629E95944940E333D93F4F0342402EE3A6069A9749409010E50B5A0842402EE3A6069A9749409010E50B5A0842403656629E95944940E333D93F4F0342403656629E95944940
37287	16384	36.341830000000002	36.378121999999998	51.190517999999997	51.159444000000001	Октябрьская	0103000020E610000001000000050000005665DF15C12B42408FC536A9689449405665DF15C12B424050A6D1E462984940F5F23B4D6630424050A6D1E462984940F5F23B4D663042408FC536A9689449405665DF15C12B42408FC536A968944940
37828	16443	36.346304000000003	36.390546000000001	51.146127999999997	51.121502	Верхняя Знобиловка	0103000020E61000000100000005000000AC3C81B0532C42400533A6608D8F4940AC3C81B0532C4240D3838252B4924940B4CA4C69FD314240D3838252B4924940B4CA4C69FD3142400533A6608D8F4940AC3C81B0532C42400533A6608D8F4940
37718	17312	36.179037000000001	36.188757000000003	51.319831000000001	51.311430999999999	Центральная	0103000020E6100000010000000500000011E335AFEA164240F4FA93F8DCA7494011E335AFEA1642409D9FE238F0A849400FF27A30291842409D9FE238F0A849400FF27A3029184240F4FA93F8DCA7494011E335AFEA164240F4FA93F8DCA74940
37831	17748	35.838476999999997	35.892178000000001	51.233417000000003	51.199086999999999	Выгон	0103000020E610000001000000050000005EB9DE3653EB41408507CDAE7B9949405EB9DE3653EB41404CAAB69BE09D4940F81A82E332F241404CAAB69BE09D4940F81A82E332F241408507CDAE7B9949405EB9DE3653EB41408507CDAE7B994940
37734	16805	36.075470000000003	36.095430999999998	51.237471999999997	51.211044999999999	Выгон	0103000020E6100000010000000500000021EA3E00A9094240FE7DC685039B494021EA3E00A90942409CDB847B659E494025034015370C42409CDB847B659E494025034015370C4240FE7DC685039B494021EA3E00A9094240FE7DC685039B4940
37689	16696	36.123997000000003	36.164664000000002	51.281345999999999	51.248759999999997	Молодежная	0103000020E61000000100000005000000ACE63922DF0F4240C746205ED79F4940ACE63922DF0F4240226E4E2503A449400E6ABFB513154240226E4E2503A449400E6ABFB513154240C746205ED79F4940ACE63922DF0F4240C746205ED79F4940
37713	17153	35.901618999999997	35.923467000000002	51.170023	51.153523999999997	Выгон	0103000020E61000000100000005000000E2395B4068F341405793A7ACA6934940E2395B4068F34140AE484C50C3954940B6F7A92A34F64140AE484C50C3954940B6F7A92A34F641405793A7ACA6934940E2395B4068F341405793A7ACA6934940
37715	17189	35.871948000000003	35.897962999999997	51.197450000000003	51.183072000000003	Кузьминова	0103000020E6100000010000000500000004E8F7FD9BEF41401B683EE76E97494004E8F7FD9BEF4140304CA60A469949404F029B73F0F24140304CA60A469949404F029B73F0F241401B683EE76E97494004E8F7FD9BEF41401B683EE76E974940
37716	16591	35.967933000000002	35.997729999999997	51.279874999999997	51.254058999999998	Лугачевка	0103000020E610000001000000050000000EDC813AE5FB414092205C0185A049400EDC813AE5FB4140E7FBA9F1D2A34940791EDC9DB5FF4140E7FBA9F1D2A34940791EDC9DB5FF414092205C0185A049400EDC813AE5FB414092205C0185A04940
37622	16179	36.277852000000003	36.308655000000002	51.182507999999999	51.162019999999998	Центральная	0103000020E61000000100000005000000699082A79023424022A64412BD944940699082A79023424012A1116C5C9749409A5FCD018227424012A1116C5C9749409A5FCD018227424022A64412BD944940699082A79023424022A64412BD944940
37404	15111	36.087615999999997	36.151145	51.431738000000003	51.408935	Советская	0103000020E610000001000000050000009C4D4700370B42404A9869FB57B449409C4D4700370B42406138D73043B749401AFA27B8581342406138D73043B749401AFA27B8581342404A9869FB57B449409C4D4700370B42404A9869FB57B44940
37383	15111	36.087615999999997	36.151145	51.431738000000003	51.408935	Промышленная	0103000020E610000001000000050000009C4D4700370B42404A9869FB57B449409C4D4700370B42406138D73043B749401AFA27B8581342406138D73043B749401AFA27B8581342404A9869FB57B449409C4D4700370B42404A9869FB57B44940
37607	5564	37.510565	37.599462000000003	51.467312999999997	51.431727000000002	Мира	0103000020E61000000100000005000000BABDA4315AC142406DE690D442B74940BABDA4315AC1424071FF91E9D0BB4940EE98BA2BBBCC424071FF91E9D0BB4940EE98BA2BBBCC42406DE690D442B74940BABDA4315AC142406DE690D442B74940
37710	15038	37.481549000000001	37.540129	51.512424000000003	51.461562000000001	Центральная	0103000020E61000000100000005000000F435CB65A3BD4240C689AF7614BB4940F435CB65A3BD4240BFD7101C97C14940834F73F222C54240BFD7101C97C14940834F73F222C54240C689AF7614BB4940F435CB65A3BD4240C689AF7614BB4940
37310	14978	37.018197999999998	37.074854999999999	51.362535000000001	51.332065999999998	Мира	0103000020E61000000100000005000000226DE34F54824240880E812381AA4940226DE34F54824240E353008C67AE4940967840D994894240E353008C67AE4940967840D994894240880E812381AA4940226DE34F54824240880E812381AA4940
37688	14903	37.136533999999997	37.181683	51.540677000000002	51.517301000000003	Центральная	0103000020E61000000100000005000000626534F27991424014984EEB36C24940626534F279914240865968E734C549409D9E776341974240865968E734C549409D9E77634197424014984EEB36C24940626534F27991424014984EEB36C24940
37675	14765	37.272843999999999	37.316861000000003	51.483874	51.460990000000002	Центральная	0103000020E6100000010000000500000075745C8DECA242403BE466B801BB494075745C8DECA242403EB14E95EFBD49405E30B8E68EA842403EB14E95EFBD49405E30B8E68EA842403BE466B801BB494075745C8DECA242403BE466B801BB4940
37827	14670	37.227604999999997	37.265135999999998	51.431581000000001	51.396956000000003	Центральная	0103000020E61000000100000005000000FAB31F29229D4240BAF94674CFB24940FAB31F29229D42409949D40B3EB74940027FF8F9EFA142409949D40B3EB74940027FF8F9EFA14240BAF94674CFB24940FAB31F29229D4240BAF94674CFB24940
37801	14608	37.146864000000001	37.163043000000002	51.414321999999999	51.396877000000003	Центральная	0103000020E61000000100000005000000D97A8670CC9242406EC493DDCCB24940D97A8670CC924240B401D88008B54940BE6BD097DE944240B401D88008B54940BE6BD097DE9442406EC493DDCCB24940D97A8670CC9242406EC493DDCCB24940
37332	14548	37.103448999999998	37.150286999999999	51.468688	51.437947999999999	Маяковского	0103000020E61000000100000005000000E6E61BD13D8D42409FAC18AE0EB84940E6E61BD13D8D42408A03E8F7FDBB4940C901BB9A3C9342408A03E8F7FDBB4940C901BB9A3C9342409FAC18AE0EB84940E6E61BD13D8D42409FAC18AE0EB84940
37709	14517	37.203924999999998	37.28145	51.540872999999998	51.529657	Центральная	0103000020E610000001000000050000001CEBE2361A9A42407A8CF2CCCBC349401CEBE2361A9A42400B2593533BC54940C7BAB88D06A442400B2593533BC54940C7BAB88D06A442407A8CF2CCCBC349401CEBE2361A9A42407A8CF2CCCBC34940
37708	14465	37.380955999999998	37.423445999999998	51.429896999999997	51.400562999999998	Школьная	0103000020E61000000100000005000000849B8C2AC3B042406B7EFCA545B34940849B8C2AC3B0424002D369DD06B749409ECF807A33B6424002D369DD06B749409ECF807A33B642406B7EFCA545B34940849B8C2AC3B042406B7EFCA545B34940
37647	14414	37.081178999999999	37.133766999999999	51.360593999999999	51.334845999999999	Школьная	0103000020E610000001000000050000009D0FCF12648A42402499D53BDCAA49409D0FCF12648A42402191B6F127AE49405B24ED461F9142402191B6F127AE49405B24ED461F9142402499D53BDCAA49409D0FCF12648A42402499D53BDCAA4940
37687	14371	37.094295000000002	37.126112999999997	51.499462999999999	51.470371	Центральная	0103000020E610000001000000050000009296CADB118C424050FEEE1D35BC49409296CADB118C4240F1475167EEBF4940DB4C857824904240F1475167EEBF4940DB4C85782490424050FEEE1D35BC49409296CADB118C424050FEEE1D35BC4940
37707	14321	37.094295000000002	37.126112999999997	51.499462999999999	51.470371	Школьная	0103000020E610000001000000050000009296CADB118C424050FEEE1D35BC49409296CADB118C4240F1475167EEBF4940DB4C857824904240F1475167EEBF4940DB4C85782490424050FEEE1D35BC49409296CADB118C424050FEEE1D35BC4940
37786	54544	37.300063000000002	37.371039000000003	51.563828000000001	51.541387999999998	Центральная	0103000020E61000000100000005000000ADDEE17668A642403239B5334CC54940ADDEE17668A64240D84812842BC849403145B9347EAF4240D84812842BC849403145B9347EAF42403239B5334CC54940ADDEE17668A642403239B5334CC54940
37775	14808	37.442239000000001	37.459944999999998	51.518555999999997	51.508634999999998	Центральная	0103000020E6100000010000000500000004029D499BB84240EC4CA1F31AC1494004029D499BB842408192020B60C24940B77A4E7ADFBA42408192020B60C24940B77A4E7ADFBA4240EC4CA1F31AC1494004029D499BB84240EC4CA1F31AC14940
37826	14239	37.186121	37.247034999999997	51.346701000000003	51.329573000000003	Школьная	0103000020E61000000100000005000000A60C1CD0D29742408352B4722FAA4940A60C1CD0D2974240C93EC8B260AC4940D2FBC6D79E9F4240C93EC8B260AC4940D2FBC6D79E9F42408352B4722FAA4940A60C1CD0D29742408352B4722FAA4940
37825	14175	37.363205000000001	37.416834999999999	51.486891	51.471195999999999	Центральная	0103000020E61000000100000005000000315F5E807DAE4240C500892650BC4940315F5E807DAE4240BEDBBC7152BE4940016A6AD95AB54240BEDBBC7152BE4940016A6AD95AB54240C500892650BC4940315F5E807DAE4240C500892650BC4940
37691	14841	37.427821000000002	37.443111000000002	51.559914999999997	51.551139999999997	Садовая	0103000020E6100000010000000500000061C5A9D6C2B642403BC269C18BC6494061C5A9D6C2B6424019C5724BABC74940BABF7ADCB7B8424019C5724BABC74940BABF7ADCB7B842403BC269C18BC6494061C5A9D6C2B642403BC269C18BC64940
37285	5951	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	Советская	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37299	5951	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	Свердлова	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37487	5951	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	М.Горького	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37422	5951	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	Литейная	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37330	5951	35.227721000000003	35.299784000000002	51.701390000000004	51.619799	Гагарина	0103000020E6100000010000000500000064CE33F6259D4140F88BD99255CF494064CE33F6259D4140E8DEC325C7D949409AEE75525FA64140E8DEC325C7D949409AEE75525FA64140F88BD99255CF494064CE33F6259D4140F88BD99255CF4940
37596	10785	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	Свободы	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
37399	10785	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	Пушкина	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
37595	10785	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	Красная Площадь	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
37380	10785	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	Кирова	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
37610	10785	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	Захара Суворова	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
37648	11067	35.562820000000002	35.600693	51.660563000000003	51.624653000000002	площадь Антипова	0103000020E6100000010000000500000072C45A7C0AC84140952C27A1F4CF494072C45A7C0AC841404DF910548DD44940D3F71A82E3CC41404DF910548DD44940D3F71A82E3CC4140952C27A1F4CF494072C45A7C0AC84140952C27A1F4CF4940
37628	11067	35.562820000000002	35.600693	51.660563000000003	51.624653000000002	Октябрьская	0103000020E6100000010000000500000072C45A7C0AC84140952C27A1F4CF494072C45A7C0AC841404DF910548DD44940D3F71A82E3CC41404DF910548DD44940D3F71A82E3CC4140952C27A1F4CF494072C45A7C0AC84140952C27A1F4CF4940
37602	54506	35.447322999999997	35.497539000000003	51.634028000000001	51.605978999999998	Кирова	0103000020E61000000100000005000000D2DF4BE141B94140098849B890CD4940D2DF4BE141B94140C85F5AD427D1494006BEA25BAFBF4140C85F5AD427D1494006BEA25BAFBF4140098849B890CD4940D2DF4BE141B94140098849B890CD4940
37706	6769	34.874198	34.924225999999997	51.434074000000003	51.393442999999998	Юбилейная	0103000020E61000000100000005000000431D56B8E56F414089EB18575CB24940431D56B8E56F41409F05A1BC8FB74940730E9E094D7641409F05A1BC8FB74940730E9E094D76414089EB18575CB24940431D56B8E56F414089EB18575CB24940
37484	6769	34.874198	34.924225999999997	51.434074000000003	51.393442999999998	Октябрьская	0103000020E61000000100000005000000431D56B8E56F414089EB18575CB24940431D56B8E56F41409F05A1BC8FB74940730E9E094D7641409F05A1BC8FB74940730E9E094D76414089EB18575CB24940431D56B8E56F414089EB18575CB24940
37286	6769	34.874198	34.924225999999997	51.434074000000003	51.393442999999998	Ленина	0103000020E61000000100000005000000431D56B8E56F414089EB18575CB24940431D56B8E56F41409F05A1BC8FB74940730E9E094D7641409F05A1BC8FB74940730E9E094D76414089EB18575CB24940431D56B8E56F414089EB18575CB24940
37309	6769	34.874198	34.924225999999997	51.434074000000003	51.393442999999998	70 лет Октября	0103000020E61000000100000005000000431D56B8E56F414089EB18575CB24940431D56B8E56F41409F05A1BC8FB74940730E9E094D7641409F05A1BC8FB74940730E9E094D76414089EB18575CB24940431D56B8E56F414089EB18575CB24940
37306	54461	35.272951999999997	35.309863	51.854506000000001	51.824483999999998	50 лет Советской власти	0103000020E610000001000000050000005BB05417F0A24140A20914B188E949405BB05417F0A241402E1EDE7360ED4940C79E3D97A9A741402E1EDE7360ED4940C79E3D97A9A74140A20914B188E949405BB05417F0A24140A20914B188E94940
37667	4392	38.128380999999997	38.140805	51.679637999999997	51.666702000000001	Училищный переулок	0103000020E61000000100000005000000C136E2C96E104340C216BB7D56D54940C136E2C96E104340368FC360FED64940800EF3E505124340368FC360FED64940800EF3E505124340C216BB7D56D54940C136E2C96E104340C216BB7D56D54940
37686	3721	38.284688000000003	38.310865	51.938474999999997	51.930607000000002	Заречная	0103000020E6100000010000000500000026C808A870244340DF3653211EF7494026C808A8702443408A8EE4F21FF849404B3CA06CCA2743408A8EE4F21FF849404B3CA06CCA274340DF3653211EF7494026C808A870244340DF3653211EF74940
37815	899	37.965589000000001	38.017654999999998	51.755873999999999	51.746825000000001	Центральная	0103000020E610000001000000050000004D309C6B98FB4240E86A2BF697DF49404D309C6B98FB4240C7F2AE7AC0E0494031CEDF8442024340C7F2AE7AC0E0494031CEDF8442024340E86A2BF697DF49404D309C6B98FB4240E86A2BF697DF4940
37625	4667	38.355646	38.397364000000003	51.777211000000001	51.737651	Центральная	0103000020E61000000100000005000000037AE1CE852D43404C6E14596BDE4940037AE1CE852D4340B58B69A67BE34940CB4DD4D2DC324340B58B69A67BE34940CB4DD4D2DC3243404C6E14596BDE4940037AE1CE852D43404C6E14596BDE4940
37305	3515	38.118347	38.174528000000002	51.790514999999999	51.76117	Садовая	0103000020E61000000100000005000000344A97FE250F43402159C0046EE14940344A97FE250F4340ACFF73982FE549403F1EFAEE56164340ACFF73982FE549403F1EFAEE561643402159C0046EE14940344A97FE250F43402159C0046EE14940
37327	3515	38.118347	38.174528000000002	51.790514999999999	51.76117	20 лет Победы	0103000020E61000000100000005000000344A97FE250F43402159C0046EE14940344A97FE250F4340ACFF73982FE549403F1EFAEE56164340ACFF73982FE549403F1EFAEE561643402159C0046EE14940344A97FE250F43402159C0046EE14940
37605	3410	38.103569999999998	38.127420000000001	51.793016999999999	51.760117000000001	Сварочный пер.	0103000020E61000000100000005000000616C21C8410D43401B118C834BE14940616C21C8410D43400516C09481E549409C6D6E4C4F1043400516C09481E549409C6D6E4C4F1043401B118C834BE14940616C21C8410D43401B118C834BE14940
37331	3410	38.103569999999998	38.127420000000001	51.793016999999999	51.760117000000001	Железнодорожная	0103000020E61000000100000005000000616C21C8410D43401B118C834BE14940616C21C8410D43400516C09481E549409C6D6E4C4F1043400516C09481E549409C6D6E4C4F1043401B118C834BE14940616C21C8410D43401B118C834BE14940
37749	4272	38.078453000000003	38.110225999999997	51.763683999999998	51.746930999999996	Школьная	0103000020E61000000100000005000000F5A276BF0A0A43402DAF5C6F9BDF4940F5A276BF0A0A43403E3DB665C0E149409E95B4E21B0E43403E3DB665C0E149409E95B4E21B0E43402DAF5C6F9BDF4940F5A276BF0A0A43402DAF5C6F9BDF4940
37800	4946	38.306697	38.347759000000003	51.869078000000002	51.826588000000001	Молодежная	0103000020E610000001000000050000000264E8D8412743400EA2B5A2CDE949400264E8D84127434028D6A9F23DEF4940E1F1ED5D832C434028D6A9F23DEF4940E1F1ED5D832C43400EA2B5A2CDE949400264E8D8412743400EA2B5A2CDE94940
67735	6107	37.885179999999998	37.941783000000001	51.872103000000003	51.861680999999997	Кооперативная	0103000020E61000000100000005000000618907944DF14240D34A21904BEE4940618907944DF142402BDF3312A1EF4940E27668588CF842402BDF3312A1EF4940E27668588CF84240D34A21904BEE4940618907944DF14240D34A21904BEE4940
37642	3231	38.085935999999997	38.170386999999998	51.839956000000001	51.815449000000001	Ленина	0103000020E6100000010000000500000047C66AF3FF0A4340284701A260E8494047C66AF3FF0A43401C0A9FAD83EB4940EF54C03DCF1543401C0A9FAD83EB4940EF54C03DCF154340284701A260E8494047C66AF3FF0A4340284701A260E84940
37643	3231	38.085935999999997	38.170386999999998	51.839956000000001	51.815449000000001	Буденного	0103000020E6100000010000000500000047C66AF3FF0A4340284701A260E8494047C66AF3FF0A43401C0A9FAD83EB4940EF54C03DCF1543401C0A9FAD83EB4940EF54C03DCF154340284701A260E8494047C66AF3FF0A4340284701A260E84940
37374	3231	38.085935999999997	38.170386999999998	51.839956000000001	51.815449000000001	50 лет Октября	0103000020E6100000010000000500000047C66AF3FF0A4340284701A260E8494047C66AF3FF0A43401C0A9FAD83EB4940EF54C03DCF1543401C0A9FAD83EB4940EF54C03DCF154340284701A260E8494047C66AF3FF0A4340284701A260E84940
37732	3820	37.990687999999999	38.039107000000001	51.837636000000003	51.820081000000002	Заречная	0103000020E61000000100000005000000134548DDCEFE42401689096AF8E84940134548DDCEFE4240E4F90CA837EB4940B8054B7501054340E4F90CA837EB4940B8054B75010543401689096AF8E84940134548DDCEFE42401689096AF8E84940
37898	54564	38.382658999999997	38.413668000000001	51.866396999999999	51.798614999999998	Центральная	0103000020E61000000100000005000000914259F8FA3043402A8C2D0439E64940914259F8FA3043401F2DCE18E6EE49406CB3B112F33443401F2DCE18E6EE49406CB3B112F33443402A8C2D0439E64940914259F8FA3043402A8C2D0439E64940
37747	3843	37.958329999999997	38.012138999999998	51.868611000000001	51.854377999999997	Центральная	0103000020E610000001000000050000004963B48EAAFA4240003620425CED49404963B48EAAFA424012F92EA52EEF4940C90050C58D01434012F92EA52EEF4940C90050C58D014340003620425CED49404963B48EAAFA4240003620425CED4940
37746	4832	38.389423000000001	38.421996	51.918481999999997	51.899275000000003	Центральная	0103000020E61000000100000005000000B5A7E49CD8314340228E75711BF34940B5A7E49CD83143407AFB73D190F549407B8505F7033643407AFB73D190F549407B8505F703364340228E75711BF34940B5A7E49CD8314340228E75711BF34940
37759	4170	37.970134000000002	38.005519	51.676639000000002	51.647370000000002	Школьная	0103000020E610000001000000050000006C5ED5592DFC4240AD342905DDD249406C5ED5592DFC42405D19541B9CD64940D940BAD8B40043405D19541B9CD64940D940BAD8B4004340AD342905DDD249406C5ED5592DFC4240AD342905DDD24940
37774	2978	38.160522999999998	38.187347000000003	51.862554000000003	51.850172000000001	Центральная	0103000020E61000000100000005000000BEA085048C144340CAFCA36FD2EC4940BEA085048C1443405A84622B68EE49407A008BFCFA1743405A84622B68EE49407A008BFCFA174340CAFCA36FD2EC4940BEA085048C144340CAFCA36FD2EC4940
37728	3095	36.282218	36.329315999999999	51.937376	51.923670000000001	Мирная	0103000020E61000000100000005000000D82B2CB81F244240EE258DD13AF64940D82B2CB81F2442401407D0EFFBF749405706D506272A42401407D0EFFBF749405706D506272A4240EE258DD13AF64940D82B2CB81F244240EE258DD13AF64940
37614	2868	36.336018000000003	36.356642999999998	52.034166999999997	52.014555000000001	Молодежная	0103000020E61000000100000005000000056F48A3022B4240247F30F0DC014A40056F48A3022B42401CCD91955F044A4075AC527AA62D42401CCD91955F044A4075AC527AA62D4240247F30F0DC014A40056F48A3022B4240247F30F0DC014A40
37681	1443	36.464404999999999	36.491515999999997	52.074489	52.061445999999997	Луговая	0103000020E61000000100000005000000A88C7F9F713B4240293C6876DD074A40A88C7F9F713B4240B47405DB88094A40F9BA0CFFE93E4240B47405DB88094A40F9BA0CFFE93E4240293C6876DD074A40A88C7F9F713B4240293C6876DD074A40
37795	1564	36.580053999999997	36.590851999999998	52.188941	52.172673000000003	Шевелева С.Н.	0103000020E61000000100000005000000FDF49F353F4A42407CF31B261A164A40FDF49F353F4A4240D0EFFB372F184A405A63D009A14B4240D0EFFB372F184A405A63D009A14B42407CF31B261A164A40FDF49F353F4A42407CF31B261A164A40
37626	54509	36.289259999999999	36.337257000000001	51.983170999999999	51.963414999999998	Советская	0103000020E610000001000000050000003E05C07806254240E8BCC62E51FB49403E05C0780625424014B01D8CD8FD49406DACC43C2B2B424014B01D8CD8FD49406DACC43C2B2B4240E8BCC62E51FB49403E05C07806254240E8BCC62E51FB4940
37799	1333	36.632246000000002	36.666212000000002	52.165128000000003	52.138908000000001	Школьная	0103000020E610000001000000050000006F83DA6FED5042408E93C2BCC7114A406F83DA6FED504240B3D30FEA22154A40F419506F46554240B3D30FEA22154A40F419506F465542408E93C2BCC7114A406F83DA6FED5042408E93C2BCC7114A40
37477	2258	36.356481000000002	36.400821999999998	52.096364999999999	52.072817000000001	Ленина	0103000020E610000001000000050000009C525E2BA12D4240E2CB441152094A409C525E2BA12D424051BD35B0550C4A4037C2A2224E33424051BD35B0550C4A4037C2A2224E334240E2CB441152094A409C525E2BA12D4240E2CB441152094A40
37333	2258	36.356481000000002	36.400821999999998	52.096364999999999	52.072817000000001	Железнодорожная	0103000020E610000001000000050000009C525E2BA12D4240E2CB441152094A409C525E2BA12D424051BD35B0550C4A4037C2A2224E33424051BD35B0550C4A4037C2A2224E334240E2CB441152094A409C525E2BA12D4240E2CB441152094A40
37683	2033	36.137571000000001	36.153947000000002	51.954529999999998	51.941966999999998	Садовая	0103000020E6100000010000000500000063F030ED9B114240A374E95F92F8494063F030ED9B1142408386FE092EFA49409E280989B41342408386FE092EFA49409E280989B4134240A374E95F92F8494063F030ED9B114240A374E95F92F84940
37619	1672	36.321905000000001	36.384580999999997	51.969397000000001	51.938020000000002	Советская	0103000020E610000001000000050000009EB5DB2E34294240397F130A11F849409EB5DB2E3429424096EB6D3315FC4940DCD440F33931424096EB6D3315FC4940DCD440F339314240397F130A11F849409EB5DB2E34294240397F130A11F84940
37606	2601	36.295440999999997	36.331328999999997	52.120126999999997	52.101671000000003	Молодежная	0103000020E61000000100000005000000E272BC02D1254240CFF9298E030D4A40E272BC02D1254240EC2E5052600F4A40B29B19FD682A4240EC2E5052600F4A40B29B19FD682A4240CFF9298E030D4A40E272BC02D1254240CFF9298E030D4A40
36729	54357	35.111550999999999	35.708796	52.444803999999998	52.025295999999997	Мира	0103000020E61000000100000005000000056B9C4D478E41401C5C3AE63C034A40056B9C4D478E4140A3906456EF384A408FC4CBD3B9DA4140A3906456EF384A408FC4CBD3B9DA41401C5C3AE63C034A40056B9C4D478E41401C5C3AE63C034A40
37630	31560	35.030082999999998	35.099828000000002	52.237887000000001	52.215401999999997	Рабочая	0103000020E6100000010000000500000031957EC2D98341401ABFF04A921B4A4031957EC2D98341406092CA14731E4A40D09CF529C78C41406092CA14731E4A40D09CF529C78C41401ABFF04A921B4A4031957EC2D98341401ABFF04A921B4A40
37635	31560	35.030082999999998	35.099828000000002	52.237887000000001	52.215401999999997	Комсомольская	0103000020E6100000010000000500000031957EC2D98341401ABFF04A921B4A4031957EC2D98341406092CA14731E4A40D09CF529C78C41406092CA14731E4A40D09CF529C78C41401ABFF04A921B4A4031957EC2D98341401ABFF04A921B4A40
37502	30785	35.045983	35.095094000000003	52.135553000000002	52.113380999999997	Промышленная	0103000020E6100000010000000500000003965CC5E28541406F7EC344830E4A4003965CC5E2854140F6EFFACC59114A40DE054A0A2C8C4140F6EFFACC59114A40DE054A0A2C8C41406F7EC344830E4A4003965CC5E28541406F7EC344830E4A40
37462	30785	35.045983	35.095094000000003	52.135553000000002	52.113380999999997	Ленина 	0103000020E6100000010000000500000003965CC5E28541406F7EC344830E4A4003965CC5E2854140F6EFFACC59114A40DE054A0A2C8C4140F6EFFACC59114A40DE054A0A2C8C41406F7EC344830E4A4003965CC5E28541406F7EC344830E4A40
37501	30785	35.045983	35.095094000000003	52.135553000000002	52.113380999999997	Володарского 	0103000020E6100000010000000500000003965CC5E28541406F7EC344830E4A4003965CC5E2854140F6EFFACC59114A40DE054A0A2C8C4140F6EFFACC59114A40DE054A0A2C8C41406F7EC344830E4A4003965CC5E28541406F7EC344830E4A40
37381	54483	35.045983	35.095094000000003	52.135553000000002	52.113380999999997	просп. Советских Космонавтов	0103000020E6100000010000000500000003965CC5E28541406F7EC344830E4A4003965CC5E2854140F6EFFACC59114A40DE054A0A2C8C4140F6EFFACC59114A40DE054A0A2C8C41406F7EC344830E4A4003965CC5E28541406F7EC344830E4A40
37723	54529	38.077671000000002	38.113990000000001	51.603898999999998	51.586174	Новая	0103000020E610000001000000050000007F6C921FF1094340FCE1E7BF07CB49407F6C921FF1094340268BFB8F4CCD494018096D39970E4340268BFB8F4CCD494018096D39970E4340FCE1E7BF07CB49407F6C921FF1094340FCE1E7BF07CB4940
37705	29975	38.180618000000003	38.297587999999998	51.408378999999996	51.342419999999997	Колхозная	0103000020E61000000100000005000000D388997D1E17434087BF266BD4AB4940D388997D1E174340C4AF58C345B449404DD7135D17264340C4AF58C345B449404DD7135D1726434087BF266BD4AB4940D388997D1E17434087BF266BD4AB4940
37731	30388	37.664194999999999	37.735494000000003	51.536951999999999	51.486336000000001	Советская	0103000020E6100000010000000500000057957D5704D54240096F0F4240BE494057957D5704D54240CAC2D7D7BAC44940BE33DAAA24DE4240CAC2D7D7BAC44940BE33DAAA24DE4240096F0F4240BE494057957D5704D54240096F0F4240BE4940
37665	4798	37.569935000000001	37.599525	51.520859000000002	51.471246000000001	Центральная	0103000020E6100000010000000500000042EC4CA1F3C84240772FF7C951BC494042EC4CA1F3C84240E469F981ABC249403411363CBDCC4240E469F981ABC249403411363CBDCC4240772FF7C951BC494042EC4CA1F3C84240772FF7C951BC4940
37621	29984	38.150587999999999	38.191963999999999	51.478966	51.423450000000003	переулок Школьный	0103000020E61000000100000005000000C495B37746134340E0BE0E9C33B64940C495B37746134340AEF204C24EBD49403201BF4692184340AEF204C24EBD49403201BF4692184340E0BE0E9C33B64940C495B37746134340E0BE0E9C33B64940
37780	30083	37.869244000000002	37.928327000000003	51.491892999999997	51.465305000000001	Парковый переулок 	0103000020E61000000100000005000000431F2C6343EF424028D53E1D8FBB4940431F2C6343EF4240CF108E59F6BE4940357F4C6BD3F64240CF108E59F6BE4940357F4C6BD3F6424028D53E1D8FBB4940431F2C6343EF424028D53E1D8FBB4940
37777	29609	37.593685999999998	37.627884999999999	51.441929000000002	51.422342999999998	Первомайская	0103000020E61000000100000005000000E90B21E7FDCB4240E658DE550FB64940E90B21E7FDCB4240B613252191B84940115322895ED04240B613252191B84940115322895ED04240E658DE550FB64940E90B21E7FDCB4240E658DE550FB64940
37684	30065	38.211798999999999	38.247416999999999	51.437645000000003	51.425730000000001	Школьный переулок	0103000020E61000000100000005000000AA29C93A1C1B43408A7615527EB64940AA29C93A1C1B4340042159C004B84940BABC395CAB1F4340042159C004B84940BABC395CAB1F43408A7615527EB64940AA29C93A1C1B43408A7615527EB64940
37776	29345	37.851754	37.911096999999998	51.640780999999997	51.504362999999998	Комсомольская	0103000020E610000001000000050000005C1E6B4606ED4240FE277FF78EC049405C1E6B4606ED4240F7729F1C05D24940EA3D95D39EF44240F7729F1C05D24940EA3D95D39EF44240FE277FF78EC049405C1E6B4606ED4240FE277FF78EC04940
37634	29903	38.193303	38.261386000000002	51.395466999999996	51.348686999999998	Центральная	0103000020E61000000100000005000000FE9B1727BE1843402AC58EC6A1AC4940FE9B1727BE184340D8D2A3A99EB24940EED0B01875214340D8D2A3A99EB24940EED0B018752143402AC58EC6A1AC4940FE9B1727BE1843402AC58EC6A1AC4940
37773	29865	37.622765000000001	37.676231999999999	51.449002	51.429487000000002	Школьная	0103000020E61000000100000005000000F60B76C3B6CF42405187156EF9B64940F60B76C3B6CF424057EBC4E578B949401C412AC58ED6424057EBC4E578B949401C412AC58ED642405187156EF9B64940F60B76C3B6CF42405187156EF9B64940
37702	29726	38.113712	38.142798999999997	51.368287000000002	51.355386000000003	Школьная	0103000020E61000000100000005000000D594641D8E0E434067BAD7497DAD4940D594641D8E0E43405F45460724AF49406473D53C471243405F45460724AF49406473D53C4712434067BAD7497DAD4940D594641D8E0E434067BAD7497DAD4940
37778	30210	37.860934999999998	37.892564999999998	51.502833000000003	51.477614000000003	Молодежная	0103000020E61000000100000005000000AA7D3A1E33EE42404E0E9F7422BD4940AA7D3A1E33EE4240BF2CEDD45CC04940F146E6913FF24240BF2CEDD45CC04940F146E6913FF242404E0E9F7422BD4940AA7D3A1E33EE42404E0E9F7422BD4940
37810	29507	37.647199000000001	37.684488000000002	51.422006000000003	51.410423999999999	Советская	0103000020E610000001000000050000008080B56AD7D242402BBF0CC688B449408080B56AD7D242409F5BE84A04B649409240834D9DD742409F5BE84A04B649409240834D9DD742402BBF0CC688B449408080B56AD7D242402BBF0CC688B44940
37821	30773	38.170737000000003	38.217278999999998	51.58023	51.552036000000001	Школьная	0103000020E61000000100000005000000CC9BC3B5DA1543407A1B9B1DA9C64940CC9BC3B5DA1543403C1405FA44CA4940C58D5BCCCF1B43403C1405FA44CA4940C58D5BCCCF1B43407A1B9B1DA9C64940CC9BC3B5DA1543407A1B9B1DA9C64940
37819	29435	37.917752999999998	37.970592000000003	51.548681000000002	51.528604000000001	Центральная	0103000020E61000000100000005000000276728EE78F542407444BE4BA9C34940276728EE78F54240E277D32D3BC649402FE1D05B3CFC4240E277D32D3BC649402FE1D05B3CFC42407444BE4BA9C34940276728EE78F542407444BE4BA9C34940
37730	30642	38.106966	38.134903000000001	51.633391000000003	51.602103	Юбилейная	0103000020E6100000010000000500000058E4D70FB10D434068E90AB611CD494058E4D70FB10D4340564ACFF412D14940EF90628044114340564ACFF412D14940EF9062804411434068E90AB611CD494058E4D70FB10D434068E90AB611CD4940
37664	29410	37.740785000000002	37.765515999999998	51.491512	51.455378000000003	Полевая	0103000020E61000000100000005000000062FFA0AD2DE4240B1A888D349BA4940062FFA0AD2DE4240B8CB7EDDE9BE49404948A46DFCE14240B8CB7EDDE9BE49404948A46DFCE14240B1A888D349BA4940062FFA0AD2DE4240B1A888D349BA4940
37685	30552	37.950280999999997	37.997720999999999	51.442849000000002	51.425820000000002	Центральная	0103000020E610000001000000050000004D81CCCEA2F94240CAFD0E4581B649404D81CCCEA2F942407D08AA46AFB8494026C45C52B5FF42407D08AA46AFB8494026C45C52B5FF4240CAFD0E4581B649404D81CCCEA2F94240CAFD0E4581B64940
37482	28986	38.000928000000002	38.071392000000003	51.546838000000001	51.504201000000002	переулок Больничный	0103000020E610000001000000050000004AD3A0681E00434025CE8AA889C049404AD3A0681E004340E31A9FC9FEC549401899805F23094340E31A9FC9FEC549401899805F2309434025CE8AA889C049404AD3A0681E00434025CE8AA889C04940
37448	28986	38.000928000000002	38.071392000000003	51.546838000000001	51.504201000000002	Центральная	0103000020E610000001000000050000004AD3A0681E00434025CE8AA889C049404AD3A0681E004340E31A9FC9FEC549401899805F23094340E31A9FC9FEC549401899805F2309434025CE8AA889C049404AD3A0681E00434025CE8AA889C04940
37449	28986	38.000928000000002	38.071392000000003	51.546838000000001	51.504201000000002	Октябрьская	0103000020E610000001000000050000004AD3A0681E00434025CE8AA889C049404AD3A0681E004340E31A9FC9FEC549401899805F23094340E31A9FC9FEC549401899805F2309434025CE8AA889C049404AD3A0681E00434025CE8AA889C04940
37498	28986	38.000928000000002	38.071392000000003	51.546838000000001	51.504201000000002	Кирова	0103000020E610000001000000050000004AD3A0681E00434025CE8AA889C049404AD3A0681E004340E31A9FC9FEC549401899805F23094340E31A9FC9FEC549401899805F2309434025CE8AA889C049404AD3A0681E00434025CE8AA889C04940
37757	30326	37.553522000000001	37.586697000000001	51.555905000000003	51.522663999999999	Почтовая	0103000020E61000000100000005000000EACE13CFD9C64240F56569A7E6C24940EACE13CFD9C64240695721E527C74940A6D425E318CB4240695721E527C74940A6D425E318CB4240F56569A7E6C24940EACE13CFD9C64240F56569A7E6C24940
37756	29820	38.044756999999997	38.072892000000003	51.386924	51.367882999999999	Светлая	0103000020E610000001000000050000002FA2ED98BA0543408FE046CA16AF49402FA2ED98BA054340CD04C3B986B14940ED116A8654094340CD04C3B986B14940ED116A86540943408FE046CA16AF49402FA2ED98BA0543408FE046CA16AF4940
37818	29304	37.856084000000003	37.901440000000001	51.607249000000003	51.581606999999998	Школьная	0103000020E610000001000000050000007F50172994ED4240F50F221972CA49407F50172994ED4240ADC3D155BACD494033A7CB6262F34240ADC3D155BACD494033A7CB6262F34240F50F221972CA49407F50172994ED4240F50F221972CA4940
37797	30224	37.785026999999999	37.800874	51.543377	51.518740999999999	Советская	0103000020E610000001000000050000000EBDC5C37BE44240130CE71A66C249400EBDC5C37BE442400533A6608DC54940BD1B0B0A83E642400533A6608DC54940BD1B0B0A83E64240130CE71A66C249400EBDC5C37BE44240130CE71A66C24940
37704	29762	38.098396000000001	38.156660000000002	51.421568000000001	51.383871999999997	Раздольная	0103000020E610000001000000050000005307793D980C4340D0ECBAB722B149405307793D980C43402385B2F0F5B54940B24B546F0D1443402385B2F0F5B54940B24B546F0D144340D0ECBAB722B149405307793D980C4340D0ECBAB722B14940
37822	29234	38.097659	38.132972000000002	51.494808999999997	51.460557999999999	Маяковского	0103000020E610000001000000050000007D941117800C4340A1F48590F3BA49407D941117800C43401B62BCE655BF494051A4FB39051143401B62BCE655BF494051A4FB3905114340A1F48590F3BA49407D941117800C4340A1F48590F3BA4940
37820	30456	37.731082999999998	37.762093	51.568295999999997	51.510216	Полевая	0103000020E61000000100000005000000AED4B32094DD4240AEF204C24EC14940AED4B32094DD42404B395FECBDC8494059C16F438CE142404B395FECBDC8494059C16F438CE14240AEF204C24EC14940AED4B32094DD4240AEF204C24EC14940
37666	30156	37.851512	37.859586999999998	51.456752999999999	51.450265000000002	Заводская	0103000020E6100000010000000500000066136058FEEC424048C49448A2B9494066136058FEEC4240C9ACDEE176BA49408B8862F206EE4240C9ACDEE176BA49408B8862F206EE424048C49448A2B9494066136058FEEC424048C49448A2B94940
37760	29545	37.708590000000001	37.754852999999997	51.405053000000002	51.389122	Лихачева	0103000020E61000000100000005000000E622BE13B3DA4240BA13ECBFCEB14940E622BE13B3DA4240C712D6C6D8B34940CC24EA059FE04240C712D6C6D8B34940CC24EA059FE04240BA13ECBFCEB14940E622BE13B3DA4240BA13ECBFCEB14940
37451	26971	34.241253999999998	34.321159999999999	51.282974000000003	51.253793999999999	Урицкого	0103000020E61000000100000005000000BC033C69E11E4140E4F560527CA04940BC033C69E11E414025CFF57D38A44940456458C51B29414025CFF57D38A44940456458C51B294140E4F560527CA04940BC033C69E11E4140E4F560527CA04940
37495	26971	34.241253999999998	34.321159999999999	51.282974000000003	51.253793999999999	Ленина	0103000020E61000000100000005000000BC033C69E11E4140E4F560527CA04940BC033C69E11E414025CFF57D38A44940456458C51B29414025CFF57D38A44940456458C51B294140E4F560527CA04940BC033C69E11E4140E4F560527CA04940
37497	26971	34.241253999999998	34.321159999999999	51.282974000000003	51.253793999999999	Коммунальная	0103000020E61000000100000005000000BC033C69E11E4140E4F560527CA04940BC033C69E11E414025CFF57D38A44940456458C51B29414025CFF57D38A44940456458C51B294140E4F560527CA04940BC033C69E11E4140E4F560527CA04940
37623	28930	34.508592999999998	34.557650000000002	51.332887999999997	51.302686999999999	Советская	0103000020E61000000100000005000000BDFC4E931941414051F69672BEA64940BDFC4E93194141408C9DF0129CAA4940A54E4013614741408C9DF0129CAA4940A54E40136147414051F69672BEA64940BDFC4E931941414051F69672BEA64940
37699	4739	34.636037000000002	34.673155000000001	51.412883999999998	51.391841999999997	Первомайская	0103000020E61000000100000005000000E20511A9695141408099EFE027B24940E20511A96951414055850662D9B44940C7116BF12956414055850662D9B44940C7116BF1295641408099EFE027B24940E20511A9695141408099EFE027B24940
37631	28869	34.274428999999998	34.346851000000001	51.307107000000002	51.273755999999999	Осипенко	0103000020E6100000010000000500000078094E7D20234140B98AC56F0AA3494078094E7D20234140B4AF3C484FA74940DECA129D652C4140B4AF3C484FA74940DECA129D652C4140B98AC56F0AA3494078094E7D20234140B98AC56F0AA34940
37729	28688	34.698954999999998	34.724800000000002	51.387087000000001	51.369283000000003	Школьный переулок	0103000020E610000001000000050000001630815B7759414001FC53AA44AF49401630815B7759414077DA1A118CB149400612143FC65C414077DA1A118CB149400612143FC65C414001FC53AA44AF49401630815B7759414001FC53AA44AF4940
37657	28592	34.373693000000003	34.425660999999998	51.419601999999998	51.397877000000001	Школьная	0103000020E6100000010000000500000040DF162CD52F4140516A2FA2EDB2494040DF162CD52F414008ABB184B5B549406117450F7C36414008ABB184B5B549406117450F7C364140516A2FA2EDB2494040DF162CD52F4140516A2FA2EDB24940
37755	28275	34.512456	34.559868999999999	51.417878000000002	51.403317000000001	Школьная	0103000020E61000000100000005000000CA51802898414140DE7536E49FB34940CA51802898414140E4DBBB067DB54940A98592C9A9474140E4DBBB067DB54940A98592C9A9474140DE7536E49FB34940CA51802898414140DE7536E49FB34940
37598	28421	34.345359999999999	34.411349999999999	51.342104999999997	51.324401000000002	Ленина	0103000020E610000001000000050000005CACA8C1342C414015E5D2F885A949405CACA8C1342C41402766BD18CAAB4940D49AE61DA73441402766BD18CAAB4940D49AE61DA734414015E5D2F885A949405CACA8C1342C414015E5D2F885A94940
37646	28360	34.654038999999997	34.703617000000001	51.337367	51.310766999999998	Средняя	0103000020E610000001000000050000007EA7C98CB753414088D68A36C7A749407EA7C98CB7534140F4DF83D72EAB49406FF4311F105A4140F4DF83D72EAB49406FF4311F105A414088D68A36C7A749407EA7C98CB753414088D68A36C7A74940
37594	28297	34.421959000000001	34.468491999999998	51.386592	51.366616999999998	Сеймовая	0103000020E610000001000000050000005EA0A4C0023641402D944C4EEDAE49405EA0A4C0023641409772BED87BB149400438BD8BF73B41409772BED87BB149400438BD8BF73B41402D944C4EEDAE49405EA0A4C0023641402D944C4EEDAE4940
37483	28221	34.522767999999999	34.572426999999998	51.386958	51.364649	Центральная	0103000020E610000001000000050000009AB2D30FEA42414072C284D1ACAE49409AB2D30FEA4241407976F9D687B14940772CB649454941407976F9D687B14940772CB6494549414072C284D1ACAE49409AB2D30FEA42414072C284D1ACAE4940
37354	27888	34.605134999999997	34.656922999999999	51.352383000000003	51.319324000000002	Советская	0103000020E610000001000000050000001D554D10754D4140F969DC9BDFA849401D554D10754D41404C55DAE21AAD4940BF7E880D165441404C55DAE21AAD4940BF7E880D16544140F969DC9BDFA849401D554D10754D4140F969DC9BDFA84940
37308	27888	34.605134999999997	34.656922999999999	51.352383000000003	51.319324000000002	М.Горького	0103000020E610000001000000050000001D554D10754D4140F969DC9BDFA849401D554D10754D41404C55DAE21AAD4940BF7E880D165441404C55DAE21AAD4940BF7E880D16544140F969DC9BDFA849401D554D10754D4140F969DC9BDFA84940
37304	27888	34.605134999999997	34.656922999999999	51.352383000000003	51.319324000000002	Ленина	0103000020E610000001000000050000001D554D10754D4140F969DC9BDFA849401D554D10754D41404C55DAE21AAD4940BF7E880D165441404C55DAE21AAD4940BF7E880D16544140F969DC9BDFA849401D554D10754D4140F969DC9BDFA84940
37629	28124	34.531804999999999	34.567630000000001	51.297832999999997	51.278410000000001	Советская	0103000020E61000000100000005000000B56CAD2F124441408F705AF0A2A34940B56CAD2F12444140B45549641FA649403F1D8F19A8484140B45549641FA649403F1D8F19A84841408F705AF0A2A34940B56CAD2F124441408F705AF0A2A34940
37671	5737	34.324159999999999	34.359437	51.397399999999998	51.378728000000002	Ленина	0103000020E61000000100000005000000EF552B137E2941402D0ABB287AB04940EF552B137E29414017B7D100DEB2494076FC1708022E414017B7D100DEB2494076FC1708022E41402D0ABB287AB04940EF552B137E2941402D0ABB287AB04940
37754	4983	35.454752999999997	35.484909000000002	51.361910000000002	51.351370000000003	Первомайская	0103000020E610000001000000050000000261A75835BA4140D46531B1F9AC49400261A75835BA4140350C1F1153AE49409E44847F11BE4140350C1F1153AE49409E44847F11BE4140D46531B1F9AC49400261A75835BA4140D46531B1F9AC4940
37817	27311	35.720033999999998	35.766216	51.349868000000001	51.297134	Мира	0103000020E610000001000000050000000801F9122ADC4140CC43A67C08A649400801F9122ADC41405EF58079C8AC494002D6AA5D13E241405EF58079C8AC494002D6AA5D13E24140CC43A67C08A649400801F9122ADC4140CC43A67C08A64940
37752	16547	35.756317000000003	35.793067000000001	51.298440999999997	51.282201999999998	Бугряновка	0103000020E610000001000000050000005534D6FECEE04140D26EF4311FA449405534D6FECEE041408C648F5033A64940B7442E3883E541408C648F5033A64940B7442E3883E54140D26EF4311FA449405534D6FECEE04140D26EF4311FA44940
37814	27097	35.553908999999997	35.590460999999998	51.476239	51.453251000000002	Школьная	0103000020E61000000100000005000000E3FA777DE6C641408DF0F62004BA4940E3FA777DE6C64140350A4966F5BC49401F48DE3994CB4140350A4966F5BC49401F48DE3994CB41408DF0F62004BA4940E3FA777DE6C641408DF0F62004BA4940
37281	26678	35.494951999999998	35.550980000000003	51.347793000000003	51.315322000000002	Советская	0103000020E610000001000000050000007E8B4E965ABF4140CBDAA6785CA849407E8B4E965ABF41408D63247B84AC494003603C8386C641408D63247B84AC494003603C8386C64140CBDAA6785CA849407E8B4E965ABF4140CBDAA6785CA84940
37636	26678	35.494951999999998	35.550980000000003	51.347793000000003	51.315322000000002	Кооперативная	0103000020E610000001000000050000007E8B4E965ABF4140CBDAA6785CA849407E8B4E965ABF41408D63247B84AC494003603C8386C641408D63247B84AC494003603C8386C64140CBDAA6785CA849407E8B4E965ABF4140CBDAA6785CA84940
37318	25234	35.701402999999999	35.737344999999998	51.068018000000002	51.044981999999997	площадь Советская	0103000020E610000001000000050000007C28D192C7D941404F745DF8C18549407C28D192C7D9414009C556D0B48849403F6F2A5261DE414009C556D0B48849403F6F2A5261DE41404F745DF8C18549407C28D192C7D941404F745DF8C1854940
32244	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	имени хирурга Крылова	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32145	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	Фурманова	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32308	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	Сергея Громова	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32337	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	Полярников	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32243	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	П. Морозова	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32398	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	Октябрьская	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32256	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	Куйбышева	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32242	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	Ивана Шатрова	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32240	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	Адмирала Виноградова	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32399	31594	45.454430000000002	45.562748999999997	58.389299000000001	58.341954000000001	 50 лет Советской власти	0103000020E61000000100000005000000202922C32ABA4640425E0F26C52B4D40202922C32ABA4640C9AEB48CD4314D40A86DC32808C84640C9AEB48CD4314D40A86DC32808C84640425E0F26C52B4D40202922C32ABA4640425E0F26C52B4D40
32352	53332	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	П. Морозова	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
32537	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	площадь 30-лет Победы	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32443	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	Школьная	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32312	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	Чкалова	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32356	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	ПМК-1	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32269	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	Октябрьская	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32530	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	Ленина	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32371	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	Красноармейская	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32273	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	К. Маркса,	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32538	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	Дружбы	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32315	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	30-лет Победы	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32374	26418	40.531697999999999	40.598191	57.477451000000002	57.436920999999998	 К. Либкнехта	0103000020E610000001000000050000009FAC18AE0E444440C2F7FE06EDB74C409FAC18AE0E444440A438471D1DBD4C407AE1CE85914C4440A438471D1DBD4C407AE1CE85914C4440C2F7FE06EDB74C409FAC18AE0E444440C2F7FE06EDB74C40
32509	53334	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Гвардейская	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32469	4664	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Юбилейная 	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32353	4664	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Советская	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32378	4664	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Нагорная	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32540	4664	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Ленина	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32276	4664	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Вокзальная	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32340	53324	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	пер. Полевой	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
32446	53341	40.521278000000002	40.573272000000003	57.489193	57.463690999999997	Школьная	0103000020E61000000100000005000000E90FCD3CB94244408A39083A5ABB4C40E90FCD3CB9424440503750E09DBE4C4034DB15FA60494440503750E09DBE4C4034DB15FA604944408A39083A5ABB4C40E90FCD3CB94244408A39083A5ABB4C40
4731	886	40.923434999999998	40.925196	57.788578000000001	57.776806999999998	улица Юных Пионеров	0103000020E61000000100000005000000AA7D3A1E33764440E5266A696EE34C40AA7D3A1E337644402C2CB81FF0E44C40EC3191D26C7644402C2CB81FF0E44C40EC3191D26C764440E5266A696EE34C40AA7D3A1E33764440E5266A696EE34C40
4987	886	40.927737999999998	40.980443000000001	57.772919999999999	57.767155000000002	улица Шагова	0103000020E61000000100000005000000D3A0681EC076444040FB912232E24C40D3A0681EC07644405036E50AEFE24C40CB4BFE277F7D44405036E50AEFE24C40CB4BFE277F7D444040FB912232E24C40D3A0681EC076444040FB912232E24C40
232	886	40.942022000000001	40.950097	57.785967999999997	57.781539000000002	улица Совхозная	0103000020E61000000100000005000000670E492D9478444037C64E7809E44C40670E492D94784440ECD973999AE44C408C834BC79C794440ECD973999AE44C408C834BC79C79444037C64E7809E44C40670E492D9478444037C64E7809E44C40
4737	886	40.927019999999999	40.967246000000003	57.827086000000001	57.767643999999997	улица Ленина	0103000020E61000000100000005000000745E6397A87644403D7C992842E24C40745E6397A87644405F7D3CF4DDE94C40EA9788B7CE7B44405F7D3CF4DDE94C40EA9788B7CE7B44403D7C992842E24C40745E6397A87644403D7C992842E24C40
3953	886	40.891500000000001	40.892730999999998	57.780262	57.778188999999998	улица Клубная	0103000020E61000000100000005000000273108AC1C724440B08D78B29BE34C40273108AC1C724440E1270EA0DFE34C400C90680245724440E1270EA0DFE34C400C90680245724440B08D78B29BE34C40273108AC1C724440B08D78B29BE34C40
4842	886	40.918512999999997	40.930604000000002	57.784461	57.783693	улица Задорина	0103000020E61000000100000005000000B5F97FD591754440548D5E0D50E44C40B5F97FD59175444065FED13769E44C406EC328081E77444065FED13769E44C406EC328081E774440548D5E0D50E44C40B5F97FD591754440548D5E0D50E44C40
5668	886	40.909215000000003	40.917299999999997	57.751390999999998	57.747520000000002	улица Голубкова	0103000020E610000001000000050000002E043928617444408F8D40BCAEDF4C402E043928617444401EC18D942DE04C40764F1E166A7544401EC18D942DE04C40764F1E166A7544408F8D40BCAEDF4C402E043928617444408F8D40BCAEDF4C40
1488	886	40.910966999999999	40.920425999999999	57.784471000000003	57.778717	улица Борьбы	0103000020E610000001000000050000001C5E10919A7444406CEBA7FFACE34C401C5E10919A74444089D4B48B69E44C40AD31E884D075444089D4B48B69E44C40AD31E884D07544406CEBA7FFACE34C401C5E10919A7444406CEBA7FFACE34C40
1814	886	40.939830000000001	40.953412	57.783309000000003	57.774614	улица Беговая	0103000020E610000001000000050000005CE674594C7844400A83328D26E34C405CE674594C784440CCD4247843E44C4096CE8767097A4440CCD4247843E44C4096CE8767097A44400A83328D26E34C405CE674594C7844400A83328D26E34C40
32632	886	40.908253999999999	40.928744999999999	57.779591000000003	57.766406000000003	проспект Текстильщиков	0103000020E61000000100000005000000083BC5AA41744440A6BA809719E24C40083BC5AA41744440C3A04CA3C9E34C4069A9BC1DE1764440C3A04CA3C9E34C4069A9BC1DE1764440A6BA809719E24C40083BC5AA41744440A6BA809719E24C40
32611	886	40.878421000000003	40.885112999999997	57.758763000000002	57.757148999999998	проезд Библиотечный	0103000020E61000000100000005000000508F6D19707044407C992842EAE04C40508F6D19707044401A355F251FE14C40D921FE614B7144401A355F251FE14C40D921FE614B7144407C992842EAE04C40508F6D19707044407C992842EAE04C40
32615	886	40.919806000000001	40.926651	57.733719000000001	57.729537999999998	проезд Березовый	0103000020E610000001000000050000001155F833BC75444039984D8061DD4C401155F833BC75444017BA1281EADD4C4021E7FD7F9C76444017BA1281EADD4C4021E7FD7F9C76444039984D8061DD4C401155F833BC75444039984D8061DD4C40
32490	886	40.994563999999997	41.004877	57.803457000000002	57.795855000000003	мкр Новый	0103000020E61000000100000005000000B4E386DF4D7F4440D6AD9E93DEE54C40B4E386DF4D7F4440035FD1ADD7E64C4055C03DCF9F804440035FD1ADD7E64C4055C03DCF9F804440D6AD9E93DEE54C40B4E386DF4D7F4440D6AD9E93DEE54C40
32232	886	40.902864000000001	40.909942999999998	57.739921000000002	57.73677	микрорайон Паново	0103000020E610000001000000050000002D5E2C0C917344404356B77A4EDE4C402D5E2C0C91734440D34F38BBB5DE4C40B01C210379744440D34F38BBB5DE4C40B01C2103797444404356B77A4EDE4C402D5E2C0C917344404356B77A4EDE4C40
32504	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	м/н Якиманиха	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32329	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	м/н Юбилейный	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32330	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	м/н Черноречье	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32671	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	м/н Паново	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32568	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	м/н Давыдовский-2	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32328	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	м/н Давыдовский-1	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32598	886	39.998198000000002	47.644737999999997	59.625143999999999	57.185422000000003	м-н Юбилейный	0103000020E610000001000000050000006077BAF3C4FF4340BEFA78E8BB974C406077BAF3C4FF434033A5F5B704D04D40853E58C686D2474033A5F5B704D04D40853E58C686D24740BEFA78E8BB974C406077BAF3C4FF4340BEFA78E8BB974C40
32521	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	квартал 3	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32654	886	40.901921000000002	40.913482000000002	57.755214000000002	57.748635	Юрия Беленогова	0103000020E61000000100000005000000AE49B725727344400BD28C45D3DF4C40AE49B725727344409DBD33DAAAE04C400ABE69FAEC7444409DBD33DAAAE04C400ABE69FAEC7444400BD28C45D3DF4C40AE49B725727344400BD28C45D3DF4C40
32640	886	40.946396	40.952649000000001	57.757874000000001	57.755890999999998	Юношеская	0103000020E6100000010000000500000059880E81237944409D2B4A09C1E04C4059880E81237944408E3EE60302E14C4097C80567F07944408E3EE60302E14C4097C80567F07944409D2B4A09C1E04C4059880E81237944409D2B4A09C1E04C40
32630	886	40.927791999999997	40.980325999999998	57.773739999999997	57.767730999999998	Шагова	0103000020E61000000100000005000000C6BE64E3C17644400C90680245E24C40C6BE64E3C1764440B3CD8DE909E34C4091B586527B7D4440B3CD8DE909E34C4091B586527B7D44400C90680245E24C40C6BE64E3C17644400C90680245E24C40
32651	886	40.988985999999997	41.003107	57.748769000000003	57.738773000000002	Центральная	0103000020E61000000100000005000000D619DF17977E44407B15191D90DE4C40D619DF17977E44401BA19FA9D7DF4C40C0B167CF658044401BA19FA9D7DF4C40C0B167CF658044407B15191D90DE4C40D619DF17977E44407B15191D90DE4C40
32648	886	40.902011000000002	40.908352999999998	57.756616000000001	57.755589000000001	Фрунзе	0103000020E61000000100000005000000EED0B01875734440D21BEE23B7E04C40EED0B01875734440AFD007CBD8E04C409B1C3EE944744440AFD007CBD8E04C409B1C3EE944744440D21BEE23B7E04C40EED0B01875734440D21BEE23B7E04C40
32644	886	41.004868000000002	41.016509999999997	57.754758000000002	57.747822999999997	Фестивальная	0103000020E610000001000000050000000266BE839F8044402A1900AAB8DF4C400266BE839F8044407B32FFE89BE04C404A07EBFF1C8244407B32FFE89BE04C404A07EBFF1C8244402A1900AAB8DF4C400266BE839F8044402A1900AAB8DF4C40
32656	886	40.908748000000003	40.920166000000002	57.738244000000002	57.730556999999997	Суслова	0103000020E610000001000000050000001827BEDA51744440936E4BE482DD4C401827BEDA51744440EF3B86C77EDE4C401172DEFFC7754440EF3B86C77EDE4C401172DEFFC7754440936E4BE482DD4C401827BEDA51744440936E4BE482DD4C40
32629	886	40.894528000000001	40.911416000000003	57.756242	57.753777999999997	Строительная	0103000020E610000001000000050000009BADBCE47F724440DE3829CC7BE04C409BADBCE47F7244404AEEB089CCE04C408C868C47A97444404AEEB089CCE04C408C868C47A9744440DE3829CC7BE04C409BADBCE47F724440DE3829CC7BE04C40
32655	886	40.912368000000001	40.923578999999997	57.77711	57.772641	Спасокукоцкого	0103000020E610000001000000050000005EF58079C87444403D4679E6E5E24C405EF58079C874444081B2295778E34C40DD2230D63776444081B2295778E34C40DD2230D6377644403D4679E6E5E24C405EF58079C87444403D4679E6E5E24C40
32634	886	40.941733999999997	40.949882000000002	57.786490999999998	57.782243999999999	Совхозная	0103000020E6100000010000000500000000C45DBD8A78444001BF469220E44C4000C45DBD8A78444096CCB1BCABE44C409087BEBB9579444096CCB1BCABE44C409087BEBB9579444001BF469220E44C4000C45DBD8A78444001BF469220E44C40
32451	886	40.928744999999999	40.975906000000002	57.766406000000003	57.756414999999997	Советская улица	0103000020E6100000010000000500000069A9BC1DE1764440179AEB34D2E04C4069A9BC1DE1764440A6BA809719E24C402FFCE07CEA7C4440A6BA809719E24C402FFCE07CEA7C4440179AEB34D2E04C4069A9BC1DE1764440179AEB34D2E04C40
32635	886	40.928744999999999	40.975906000000002	57.766406000000003	57.756414999999997	Советская	0103000020E6100000010000000500000069A9BC1DE1764440179AEB34D2E04C4069A9BC1DE1764440A6BA809719E24C402FFCE07CEA7C4440A6BA809719E24C402FFCE07CEA7C4440179AEB34D2E04C4069A9BC1DE1764440179AEB34D2E04C40
32652	886	40.940565999999997	40.940700999999997	57.769896000000003	57.763665000000003	Смоленская	0103000020E6100000010000000500000061DD787764784440C80C54C6BFE14C4061DD7877647844401EA9BEF38BE24C404128EFE3687844401EA9BEF38BE24C404128EFE368784440C80C54C6BFE14C4061DD787764784440C80C54C6BFE14C40
32609	886	40.927720000000001	40.965556999999997	57.767499999999998	57.766416	Свердлова	0103000020E610000001000000050000002DEC6987BF764440C99063EB19E24C402DEC6987BF7644400AD7A3703DE24C4041B62C5F977B44400AD7A3703DE24C4041B62C5F977B4440C99063EB19E24C402DEC6987BF764440C99063EB19E24C40
32672	886	40.898211000000003	40.901732000000003	57.758110000000002	57.755972999999997	Садовая	0103000020E6100000010000000500000028F4FA93F87244405AD427B9C3E04C4028F4FA93F8724440A2629CBF09E14C40DBE044F46B734440A2629CBF09E14C40DBE044F46B7344405AD427B9C3E04C4028F4FA93F87244405AD427B9C3E04C40
4805	886	40.890583999999997	40.916167999999999	57.819215999999997	57.795202000000003	Речной проспект	0103000020E61000000100000005000000A12B11A8FE7144405EDBDB2DC9E54C40A12B11A8FE714440122EE411DCE84C4024D236FE44754440122EE411DCE84C4024D236FE447544405EDBDB2DC9E54C40A12B11A8FE7144405EDBDB2DC9E54C40
32669	886	40.944169000000002	40.957903999999999	57.789427000000003	57.781078000000001	Пушкина	0103000020E61000000100000005000000D272A087DA78444003D0285DFAE34C40D272A087DA7844402ACAA5F10BE54C40925A28999C7A44402ACAA5F10BE54C40925A28999C7A444003D0285DFAE34C40D272A087DA78444003D0285DFAE34C40
32643	886	40.968387	41.020488999999998	57.742823000000001	57.731172000000001	Профсоюзная	0103000020E610000001000000050000008F6FEF1AF47B44401EE0490B97DD4C408F6FEF1AF47B4440BADBF5D214DF4C40C07630629F824440BADBF5D214DF4C40C07630629F8244401EE0490B97DD4C408F6FEF1AF47B44401EE0490B97DD4C40
32617	886	40.880271	40.894761000000003	57.782738000000002	57.777839	Просвещения	0103000020E61000000100000005000000014F5AB8AC704440D446753A90E34C40014F5AB8AC70444011AB3FC230E44C403E5E48878772444011AB3FC230E44C403E5E488787724440D446753A90E34C40014F5AB8AC704440D446753A90E34C40
32647	886	40.971235	40.989263999999999	57.805835000000002	57.796760999999996	Партизанская	0103000020E6100000010000000500000083DDB06D517C444037DDB243FCE54C4083DDB06D517C4440707CED9925E74C40198EE733A07E4440707CED9925E74C40198EE733A07E444037DDB243FCE54C4083DDB06D517C444037DDB243FCE54C40
32624	886	40.999999000000003	41.004859000000003	57.747822999999997	57.744532999999997	Новоселов	0103000020E6100000010000000500000030849CF7FF7F444079E57ADB4CDF4C4030849CF7FF7F44402A1900AAB8DF4C40AF0B3F389F8044402A1900AAB8DF4C40AF0B3F389F80444079E57ADB4CDF4C4030849CF7FF7F444079E57ADB4CDF4C40
32627	886	40.945444000000002	40.978529000000002	57.764927	57.76099	Никитская	0103000020E6100000010000000500000087191A4F04794440A14ACD1E68E14C4087191A4F04794440E869C020E9E14C4003983270407D4440E869C020E9E14C4003983270407D4440A14ACD1E68E14C4087191A4F04794440A14ACD1E68E14C40
32608	886	40.920901999999998	40.929876	57.737788000000002	57.730336000000001	Малышковская 	0103000020E610000001000000050000001669E21DE0754440B58B69A67BDD4C401669E21DE0754440CDB051D66FDE4C40EBAA402D06774440CDB051D66FDE4C40EBAA402D06774440B58B69A67BDD4C401669E21DE0754440B58B69A67BDD4C40
32668	886	40.920901999999998	40.929876	57.737788000000002	57.730336000000001	Малышковская	0103000020E610000001000000050000001669E21DE0754440B58B69A67BDD4C401669E21DE0754440CDB051D66FDE4C40EBAA402D06774440CDB051D66FDE4C40EBAA402D06774440B58B69A67BDD4C401669E21DE0754440B58B69A67BDD4C40
32667	886	40.907103999999997	40.918019000000001	57.804966999999998	57.801740000000002	Линейная	0103000020E610000001000000050000000F09DFFB1B74444091F2936A9FE64C400F09DFFB1B744440FBAD9D2809E74C40A60D87A581754440FBAD9D2809E74C40A60D87A58175444091F2936A9FE64C400F09DFFB1B74444091F2936A9FE64C40
32636	886	40.926704999999998	40.959690999999999	57.806694	57.768504	Ленина	0103000020E610000001000000050000001405FA449E7644402F6CCD565EE24C401405FA449E76444091F0BDBF41E74C40FDA19927D77A444091F0BDBF41E74C40FDA19927D77A44402F6CCD565EE24C401405FA449E7644402F6CCD565EE24C40
5149	886	40.980784	41.026938999999999	57.754004000000002	57.735612000000003	Кинешемское шоссе	0103000020E61000000100000005000000543882548A7D4440C845B58828DE4C40543882548A7D4440CF86FC3383E04C4054FEB5BC72834440CF86FC3383E04C4054FEB5BC72834440C845B58828DE4C40543882548A7D4440C845B58828DE4C40
32633	886	40.950457	40.951616000000001	57.771594999999998	57.761302999999998	Ивана Сусанина	0103000020E610000001000000050000008CA03193A879444060AC6F6072E14C408CA03193A8794440E960FD9FC3E24C40D82C978DCE794440E960FD9FC3E24C40D82C978DCE79444060AC6F6072E14C408CA03193A879444060AC6F6072E14C40
32665	886	40.915565999999998	40.918351000000001	57.795014999999999	57.791772999999999	Запрудня	0103000020E610000001000000050000002EAA4544317544408B6D52D158E54C402EAA4544317544402B6A300DC3E54C40DC9F8B868C7544402B6A300DC3E54C40DC9F8B868C7544408B6D52D158E54C402EAA4544317544408B6D52D158E54C40
32663	886	40.935841000000003	40.936210000000003	57.769142000000002	57.764634000000001	Долматова	0103000020E61000000100000005000000C3A04CA3C977444070B4E386DFE14C40C3A04CA3C977444072FDBB3E73E24C401618B2BAD577444072FDBB3E73E24C401618B2BAD577444070B4E386DFE14C40C3A04CA3C977444070B4E386DFE14C40
32621	886	40.934260000000002	40.944645000000001	57.761955999999998	57.758743000000003	Дзержинского	0103000020E6100000010000000500000001FBE8D495774440D388997D1EE14C4001FBE8D495774440D87E32C687E14C403BAA9A20EA784440D87E32C687E14C403BAA9A20EA784440D388997D1EE14C4001FBE8D495774440D388997D1EE14C40
32642	886	40.906933000000002	40.921782999999998	57.779586000000002	57.772731999999998	Депутатская	0103000020E61000000100000005000000E3546B61167444404D49D6E1E8E24C40E3546B6116744440B1355B79C9E34C401F813FFCFC754440B1355B79C9E34C401F813FFCFC7544404D49D6E1E8E24C40E3546B61167444404D49D6E1E8E24C40
32660	886	40.923578999999997	40.934601999999998	57.777718999999998	57.777113999999997	Горького	0103000020E61000000100000005000000DD2230D637764440C2A1B77878E34C40DD2230D637764440293DD34B8CE34C405A63D009A1774440293DD34B8CE34C405A63D009A1774440C2A1B77878E34C40DD2230D637764440C2A1B77878E34C40
32639	886	40.908954999999999	40.917084000000003	57.751862000000003	57.748365999999997	Голубкова	0103000020E6100000010000000500000091442FA3587444401BB80375CADF4C4091442FA358744440768D96033DE04C40AAD72D0263754440768D96033DE04C40AAD72D02637544401BB80375CADF4C4091442FA3587444401BB80375CADF4C40
32607	886	40.943046000000002	41.035122999999999	57.78519	57.771993000000002	Галичская	0103000020E61000000100000005000000D34F38BBB5784440D7DEA7AAD0E24C40D34F38BBB5784440B8921D1B81E44C40302B14E97E844440B8921D1B81E44C40302B14E97E844440D7DEA7AAD0E24C40D34F38BBB5784440D7DEA7AAD0E24C40
32625	886	40.940565999999997	40.958011999999997	57.765244000000003	57.764845999999999	Войкова	0103000020E6100000010000000500000061DD787764784440FB3C4679E6E14C4061DD787764784440E9BAF083F3E14C4078962023A07A4440E9BAF083F3E14C4078962023A07A4440FB3C4679E6E14C4061DD787764784440FB3C4679E6E14C40
32670	886	41.000053000000001	41.014865999999998	57.742117	57.730302000000002	Бульварная	0103000020E6100000010000000500000023A298BC01804440091A33897ADD4C4023A298BC018044401F679AB0FDDE4C4042E90B21E78144401F679AB0FDDE4C4042E90B21E7814440091A33897ADD4C4023A298BC01804440091A33897ADD4C40
32626	886	40.919922999999997	40.920175	57.803936	57.795293999999998	Боровая	0103000020E610000001000000050000004AEB6F09C07544403E5A9C31CCE54C404AEB6F09C0754440DD09F65FE7E64C4064CC5D4BC8754440DD09F65FE7E64C4064CC5D4BC87544403E5A9C31CCE54C404AEB6F09C07544403E5A9C31CCE54C40
32661	886	40.944859999999998	40.961632000000002	57.784322000000003	57.773432999999997	Боевая	0103000020E6100000010000000500000037A6272CF1784440D65240DAFFE24C4037A6272CF178444044C4CDA964E44C40BF64E3C1167B444044C4CDA964E44C40BF64E3C1167B4440D65240DAFFE24C4037A6272CF1784440D65240DAFFE24C40
32653	886	40.939523999999999	40.953133999999999	57.783726999999999	57.775467999999996	Беговая	0103000020E610000001000000050000004FE78A5242784440198C118942E34C404FE78A524278444000FF942A51E44C40535A7F4B007A444000FF942A51E44C40535A7F4B007A4440198C118942E34C404FE78A5242784440198C118942E34C40
32605	886	40.997096999999997	41.003314000000003	57.752164999999998	57.749101000000003	2-я Глазковская улица	0103000020E6100000010000000500000048F8DEDFA07F44405133A48AE2DF4C4048F8DEDFA07F4440111956F146E04C403ACFD8976C804440111956F146E04C403ACFD8976C8044405133A48AE2DF4C4048F8DEDFA07F44405133A48AE2DF4C40
5342	886	40.992353999999999	40.997033999999999	57.740622999999999	57.737183000000002	2-й Давыдовский проезд	0103000020E610000001000000050000000307B474057F4440661536035CDE4C400307B474057F44402CD505BCCCDE4C40028063CF9E7F44402CD505BCCCDE4C40028063CF9E7F4440661536035CDE4C400307B474057F4440661536035CDE4C40
32646	886	40.801578999999997	41.057132000000003	57.837389000000002	57.709806	1 Мая	0103000020E61000000100000005000000871403249A66444096404AECDADA4C40871403249A664440DC8310902FEB4C400DC7F31950874440DC8310902FEB4C400DC7F3195087444096404AECDADA4C40871403249A66444096404AECDADA4C40
32658	886	40.960275000000003	40.981242000000002	57.784351000000001	57.760956999999998	 Юрия Смирнова	0103000020E610000001000000050000004D158C4AEA7A4440C554FA0967E14C404D158C4AEA7A4440DECA129D65E44C4017BB7D56997D4440DECA129D65E44C4017BB7D56997D4440C554FA0967E14C404D158C4AEA7A4440C554FA0967E14C40
32641	886	40.903061999999998	40.916249000000001	57.751041000000001	57.744835000000002	 Машиностроителей	0103000020E6100000010000000500000053211E899773444045F5D6C056DF4C4053211E8997734440427A8A1C22E04C4011FFB0A547754440427A8A1C22E04C4011FFB0A54775444045F5D6C056DF4C4053211E899773444045F5D6C056DF4C40
32638	886	40.926704999999998	40.959690999999999	57.806694	57.768504	 Ленина	0103000020E610000001000000050000001405FA449E7644402F6CCD565EE24C401405FA449E76444091F0BDBF41E74C40FDA19927D77A444091F0BDBF41E74C40FDA19927D77A44402F6CCD565EE24C401405FA449E7644402F6CCD565EE24C40
32511	53351	44.293644999999998	44.358035999999998	58.835416000000002	58.806310000000003	Центральная	0103000020E6100000010000000500000024D1CB28962546400938842A35674D4024D1CB28962546400F4757E9EE6A4D403465A71FD42D46400F4757E9EE6A4D403465A71FD42D46400938842A35674D4024D1CB28962546400938842A35674D40
32362	29631	41.139929000000002	41.194718000000002	57.469189	57.423183999999999	Парковая	0103000020E6100000010000000500000089618731E99144406118B0E42AB64C4089618731E99144404C5299620EBC4C40A5F8F884EC9844404C5299620EBC4C40A5F8F884EC9844406118B0E42AB64C4089618731E99144406118B0E42AB64C40
32467	29631	41.139929000000002	41.194718000000002	57.469189	57.423183999999999	Набережная	0103000020E6100000010000000500000089618731E99144406118B0E42AB64C4089618731E99144404C5299620EBC4C40A5F8F884EC9844404C5299620EBC4C40A5F8F884EC9844406118B0E42AB64C4089618731E99144406118B0E42AB64C40
32339	29631	41.139929000000002	41.194718000000002	57.469189	57.423183999999999	Имени 50-летия Ленинского Комсомола	0103000020E6100000010000000500000089618731E99144406118B0E42AB64C4089618731E99144404C5299620EBC4C40A5F8F884EC9844404C5299620EBC4C40A5F8F884EC9844406118B0E42AB64C4089618731E99144406118B0E42AB64C40
32388	29631	41.139929000000002	41.194718000000002	57.469189	57.423183999999999	Зеленова	0103000020E6100000010000000500000089618731E99144406118B0E42AB64C4089618731E99144404C5299620EBC4C40A5F8F884EC9844404C5299620EBC4C40A5F8F884EC9844406118B0E42AB64C4089618731E99144406118B0E42AB64C40
32205	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	площадь Хазова	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32487	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Республиканская	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32207	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Октябрьской революции	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32590	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Овражная	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32272	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Лизы Чайкиной	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32377	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Клубная	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32303	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Карла Маркса	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32317	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Ивана Сусанина	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32181	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	Заря революции	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32432	3522	41.475774000000001	41.608257000000002	58.500701999999997	58.443235999999999	3 Интернационала 	0103000020E61000000100000005000000C0249529E6BC444076340EF5BB384D40C0249529E6BC44405985CD0017404D401348895DDBCD44405985CD0017404D401348895DDBCD444076340EF5BB384D40C0249529E6BC444076340EF5BB384D40
32468	53317	45.473537	45.562730999999999	58.388823000000002	58.341957999999998	1-й микрорайон	0103000020E61000000100000005000000153944DC9CBC4640834D9D47C52B4D40153944DC9CBC46406077BAF3C4314D4002B9C49107C846406077BAF3C4314D4002B9C49107C84640834D9D47C52B4D40153944DC9CBC4640834D9D47C52B4D40
32153	25316	45.151319999999998	45.198391999999998	58.352508999999998	58.330222999999997	Вокзальная	0103000020E61000000100000005000000889D29745E93464089B14CBF442A4D40889D29745E934640D845D1031F2D4D40DEE4B7E864994640D845D1031F2D4D40DEE4B7E86499464089B14CBF442A4D40889D29745E93464089B14CBF442A4D40
32263	25716	45.746149000000003	45.764879000000001	58.20937	58.204698999999998	Советская	0103000020E61000000100000005000000B87878CF81DF46400F43AB93331A4D40B87878CF81DF4640BB61DBA2CC1A4D40D732198EE7E14640BB61DBA2CC1A4D40D732198EE7E146400F43AB93331A4D40B87878CF81DF46400F43AB93331A4D40
32479	25516	45.636589999999998	45.659677000000002	58.119754	58.104664	Центральная	0103000020E61000000100000005000000F67AF7C77BD14640C68844A1650D4D40F67AF7C77BD1464058C85C19540F4D403276C24B70D4464058C85C19540F4D403276C24B70D44640C68844A1650D4D40F67AF7C77BD14640C68844A1650D4D40
32262	25381	45.55903	45.600047000000004	58.158420999999997	58.143698000000001	Коммунальная	0103000020E61000000100000005000000CFBD874B8EC74640144031B264124D40CFBD874B8EC74640F3FFAA2347144D400E881057CECC4640F3FFAA2347144D400E881057CECC4640144031B264124D40CFBD874B8EC74640144031B264124D40
32452	25014	45.456558999999999	45.465505999999998	58.59243	58.580576999999998	Центральная	0103000020E61000000100000005000000E4D87A8670BA4640A7E7DD58504A4D40E4D87A8670BA4640AB9509BFD44B4D40BF0B5BB395BB4640AB9509BFD44B4D40BF0B5BB395BB4640A7E7DD58504A4D40E4D87A8670BA4640A7E7DD58504A4D40
32408	25694	45.668641999999998	45.685530999999997	57.955514000000001	57.948326999999999	Школьная	0103000020E61000000100000005000000B35DA10F96D54640F77475C762F94C40B35DA10F96D54640616F62484EFA4C4074B2D47ABFD74640616F62484EFA4C4074B2D47ABFD74640F77475C762F94C40B35DA10F96D54640F77475C762F94C40
32570	25802	45.864016999999997	45.878641000000002	58.166500999999997	58.156278999999998	Советская	0103000020E610000001000000050000001118EB1B98EE46409A0645F300144D401118EB1B98EE46402AE09EE74F154D405EF6EB4E77F046402AE09EE74F154D405EF6EB4E77F046409A0645F300144D401118EB1B98EE46409A0645F300144D40
32357	24955	45.531326	45.550908999999997	58.459198999999998	58.446528000000001	Юрия Смирнова	0103000020E61000000100000005000000DBC1887D02C44640C85F5AD427394D40DBC1887D02C446408EAD6708C73A4D403909A52F84C646408EAD6708C73A4D403909A52F84C64640C85F5AD427394D40DBC1887D02C44640C85F5AD427394D40
32354	25489	45.460898	45.482241999999999	58.066687000000002	58.055911999999999	Центральная	0103000020E610000001000000050000005A65A6B4FEBA46401BBAD91F28074D405A65A6B4FEBA4640C0081A3389084D40FA60191BBABD4640C0081A3389084D40FA60191BBABD46401BBAD91F28074D405A65A6B4FEBA46401BBAD91F28074D40
32358	25071	45.436436999999998	45.460960999999998	58.668708000000002	58.656623000000003	Школьный переулок	0103000020E61000000100000005000000D6E1E82ADDB746409566F3380C544D40D6E1E82ADDB746406B49473998554D40A0DD21C500BB46406B49473998554D40A0DD21C500BB46409566F3380C544D40D6E1E82ADDB746409566F3380C544D40
32666	25878	45.912337000000001	45.938622000000002	58.097169000000001	58.077824	Школьная	0103000020E6100000010000000500000023F77475C7F44640056C0723F6094D4023F77475C7F44640AF97A608700C4D402FA704C424F84640AF97A608700C4D402FA704C424F84640056C0723F6094D4023F77475C7F44640056C0723F6094D40
32527	25620	45.622701999999997	45.640624000000003	58.021014000000001	58.007728	Центральная	0103000020E61000000100000005000000AF93FAB2B4CF4640BAA1293BFD004D40AF93FAB2B4CF46400B613596B0024D4030849CF7FFD146400B613596B0024D4030849CF7FFD14640BAA1293BFD004D40AF93FAB2B4CF4640BAA1293BFD004D40
32309	25228	45.727958000000001	45.776063000000001	58.382435000000001	58.364156999999999	Октябрьская	0103000020E61000000100000005000000486E4DBA2DDD464003CE52B29C2E4D40486E4DBA2DDD464042EC4CA1F3304D405D514A0856E3464042EC4CA1F3304D405D514A0856E3464003CE52B29C2E4D40486E4DBA2DDD464003CE52B29C2E4D40
32335	25167	45.820394999999998	45.834964999999997	58.297184000000001	58.278444999999998	Молодежная	0103000020E61000000100000005000000A5660FB402E946400B5EF415A4234D40A5660FB402E946407E7214200A264D40FE261422E0EA46407E7214200A264D40FE261422E0EA46400B5EF415A4234D40A5660FB402E946400B5EF415A4234D40
32575	25087	45.685108	45.701627999999999	58.629446999999999	58.622048999999997	Центральная	0103000020E610000001000000050000002E1D739EB1D7464037C1374D9F4F4D402E1D739EB1D746405CC823B891504D409CFA40F2CED946405CC823B891504D409CFA40F2CED9464037C1374D9F4F4D402E1D739EB1D7464037C1374D9F4F4D40
32507	53298	45.420222000000003	45.500216999999999	58.411980999999997	58.376947000000001	Чайковского	0103000020E61000000100000005000000A587A1D5C9B54640A4A99ECC3F304D40A587A1D5C9B5464064C91CCBBB344D409DF3531C07C0464064C91CCBBB344D409DF3531C07C04640A4A99ECC3F304D40A587A1D5C9B54640A4A99ECC3F304D40
32344	53298	45.420222000000003	45.500216999999999	58.411980999999997	58.376947000000001	Центральная	0103000020E61000000100000005000000A587A1D5C9B54640A4A99ECC3F304D40A587A1D5C9B5464064C91CCBBB344D409DF3531C07C0464064C91CCBBB344D409DF3531C07C04640A4A99ECC3F304D40A587A1D5C9B54640A4A99ECC3F304D40
32143	53298	45.420222000000003	45.500216999999999	58.411980999999997	58.376947000000001	Рабочая	0103000020E61000000100000005000000A587A1D5C9B54640A4A99ECC3F304D40A587A1D5C9B5464064C91CCBBB344D409DF3531C07C0464064C91CCBBB344D409DF3531C07C04640A4A99ECC3F304D40A587A1D5C9B54640A4A99ECC3F304D40
32519	25287	45.329331000000003	45.353881999999999	58.375262999999997	58.355871	Центральная	0103000020E610000001000000050000008D47A98427AA4640234C512E8D2D4D408D47A98427AA46400D33349E08304D40505260014CAD46400D33349E08304D40505260014CAD4640234C512E8D2D4D408D47A98427AA4640234C512E8D2D4D40
32422	25584	45.565246000000002	45.592329999999997	58.063611000000002	58.049959000000001	Молодежная	0103000020E61000000100000005000000F0181EFB59C846400892770E65064D40F0181EFB59C846403B55BE6724084D4047382D78D1CB46403B55BE6724084D4047382D78D1CB46400892770E65064D40F0181EFB59C846400892770E65064D40
32539	9862	45.620258999999997	45.636743000000003	58.501229000000002	58.493079000000002	Свободы	0103000020E610000001000000050000005B069CA564CF464015AC71361D3F4D405B069CA564CF46404567994528404D407D7A6CCB80D146404567994528404D407D7A6CCB80D1464015AC71361D3F4D405B069CA564CF464015AC71361D3F4D40
32582	25412	45.493417000000001	45.525647999999997	58.114449	58.101706	Центральная	0103000020E610000001000000050000002D25CB4928BF46404BE7C3B3040D4D402D25CB4928BF4640AB07CC43A60E4D40999A046F48C34640AB07CC43A60E4D40999A046F48C346404BE7C3B3040D4D402D25CB4928BF46404BE7C3B3040D4D40
32369	3313	43.033138000000001	43.051814	58.765875000000001	58.755485999999998	Зеленая	0103000020E610000001000000050000009F20B1DD3D844540FD4AE7C3B3604D409F20B1DD3D84454079E9263108624D40CBBC55D7A186454079E9263108624D40CBBC55D7A1864540FD4AE7C3B3604D409F20B1DD3D844540FD4AE7C3B3604D40
32198	3724	43.270175999999999	43.281657000000003	59.073881999999998	59.066490000000002	Береговая	0103000020E6100000010000000500000001158E2095A245406AC18BBE82884D4001158E2095A24540ACE122F774894D4041D829560DA44540ACE122F774894D4041D829560DA445406AC18BBE82884D4001158E2095A245406AC18BBE82884D40
32192	2951	42.655377999999999	42.713310999999997	58.767321000000003	58.743744	Советская	0103000020E610000001000000050000004A42226DE3534540514CDE00335F4D404A42226DE35345405B44149337624D4043705CC64D5B45405B44149337624D4043705CC64D5B4540514CDE00335F4D404A42226DE3534540514CDE00335F4D40
32587	2951	42.655377999999999	42.713310999999997	58.767321000000003	58.743744	Октября	0103000020E610000001000000050000004A42226DE3534540514CDE00335F4D404A42226DE35345405B44149337624D4043705CC64D5B45405B44149337624D4043705CC64D5B4540514CDE00335F4D404A42226DE3534540514CDE00335F4D40
32586	3077	42.532362999999997	42.550707000000003	58.827399999999997	58.819270000000003	пер. Ветеранов	0103000020E61000000100000005000000DB4C857824444540064CE0D6DD684D40DB4C857824444540EE5A423EE8694D40D25625917D464540EE5A423EE8694D40D25625917D464540064CE0D6DD684D40DB4C857824444540064CE0D6DD684D40
32433	9597	42.66075	42.672159000000001	58.745578999999999	58.740372000000001	Центральная	0103000020E610000001000000050000007F6ABC7493544540E36F7B82C45E4D407F6ABC7493544540CDCAF6216F5F4D40255B5D4E09564540CDCAF6216F5F4D40255B5D4E09564540E36F7B82C45E4D407F6ABC7493544540E36F7B82C45E4D40
32318	3525	43.111902000000001	43.150044999999999	58.992724000000003	58.956090000000003	Советская	0103000020E61000000100000005000000B22D03CE528E45402E043928617A4D40B22D03CE528E454027FA7C94117F4D40D3F6AFAC3493454027FA7C94117F4D40D3F6AFAC349345402E043928617A4D40B22D03CE528E45402E043928617A4D40
32266	3525	43.111902000000001	43.150044999999999	58.992724000000003	58.956090000000003	Пионерская	0103000020E61000000100000005000000B22D03CE528E45402E043928617A4D40B22D03CE528E454027FA7C94117F4D40D3F6AFAC3493454027FA7C94117F4D40D3F6AFAC349345402E043928617A4D40B22D03CE528E45402E043928617A4D40
32631	53364	42.459716	42.482551000000001	58.779839000000003	58.773676000000002	Сенная	0103000020E6100000010000000500000056B950F9D73A45409DD9AED007634D4056B950F9D73A45409B92ACC3D1634D4078D32D3BC43D45409B92ACC3D1634D4078D32D3BC43D45409DD9AED007634D4056B950F9D73A45409DD9AED007634D40
32373	3404	42.841096	42.858407	58.894502000000003	58.886662000000001	Центральная	0103000020E61000000100000005000000F165A208A96B4540904DF2237E714D40F165A208A96B4540721AA20A7F724D4028D4D347E06D4540721AA20A7F724D4028D4D347E06D4540904DF2237E714D40F165A208A96B4540904DF2237E714D40
32528	3198	43.470877999999999	43.496121000000002	59.170470999999999	59.160530999999999	Центральная	0103000020E61000000100000005000000F433F5BA45BC4540417FA1478C944D40F433F5BA45BC45404DF564FED1954D40EEED96E480BF45404DF564FED1954D40EEED96E480BF4540417FA1478C944D40F433F5BA45BC4540417FA1478C944D40
32314	3061	42.600535999999998	42.628573000000003	58.824641999999997	58.813231000000002	Приозерная	0103000020E610000001000000050000000B09185DDE4C4540F48B12F417684D400B09185DDE4C45403A747ADE8D694D4006137F14755045403A747ADE8D694D4006137F1475504540F48B12F417684D400B09185DDE4C4540F48B12F417684D40
32349	15295	42.542586	42.550877	58.680591999999997	58.675488000000001	Школьная	0103000020E610000001000000050000003CA2427573454540946B0A6476564D403CA2427573454540A9F57EA31D574D402E8F352383464540A9F57EA31D574D402E8F352383464540946B0A6476564D403CA2427573454540946B0A6476564D40
32270	3643	42.918711000000002	42.930937	59.121993000000003	59.116219999999998	Школьная	0103000020E61000000100000005000000DCBC7152987545401092054CE08E4D40DCBC715298754540A4AB74779D8F4D4074D190F128774540A4AB74779D8F4D4074D190F1287745401092054CE08E4D40DCBC7152987545401092054CE08E4D40
32199	3201	42.857706	42.872869000000001	58.689334000000002	58.679839000000001	Центральная	0103000020E610000001000000050000009FCA694FC96D4540CEC5DFF604574D409FCA694FC96D4540AC02B5183C584D409B58E02BBA6F4540AC02B5183C584D409B58E02BBA6F4540CEC5DFF604574D409FCA694FC96D4540CEC5DFF604574D40
32431	3427	42.79813	42.811703000000001	59.024340000000002	59.017110000000002	Кооперативная	0103000020E610000001000000050000006EFAB31F29664540A03715A930824D406EFAB31F2966454009FEB7921D834D40558847E2E567454009FEB7921D834D40558847E2E5674540A03715A930824D406EFAB31F29664540A03715A930824D40
32313	3745	43.278342000000002	43.303117999999998	59.101152999999996	59.077294999999999	Школьная	0103000020E61000000100000005000000378DEDB5A0A34540799274CDE4894D40378DEDB5A0A345403672DD94F28C4D401A6A1492CCA645403672DD94F28C4D401A6A1492CCA64540799274CDE4894D40378DEDB5A0A34540799274CDE4894D40
32367	3296	43.024585999999999	43.043908999999999	58.759934000000001	58.748978000000001	Сельская	0103000020E6100000010000000500000040F850A22583454035B6D782DE5F4D4040F850A2258345402A8F6E8445614D40028063CF9E8545402A8F6E8445614D40028063CF9E85454035B6D782DE5F4D4040F850A22583454035B6D782DE5F4D40
32274	9508	42.513506999999997	42.527206999999997	58.765959000000002	58.758150999999998	Молодежная	0103000020E610000001000000050000002FA2ED98BA41454000378B170B614D402FA2ED98BA414540D789CBF10A624D40739CDB847B434540D789CBF10A624D40739CDB847B43454000378B170B614D402FA2ED98BA41454000378B170B614D40
32455	9572	42.697671	42.710723999999999	58.730625000000003	58.724038	Центральная	0103000020E610000001000000050000000E2F88484D594540D787F546AD5C4D400E2F88484D594540EC51B81E855D4D40BC3D0801F95A4540EC51B81E855D4D40BC3D0801F95A4540D787F546AD5C4D400E2F88484D594540D787F546AD5C4D40
32259	2283	41.573852000000002	41.584712000000003	58.110356000000003	58.104425999999997	Центральная	0103000020E61000000100000005000000425F7AFB73C94440116DC7D45D0D4D40425F7AFB73C944406D753925200E4D4015CAC2D7D7CA44406D753925200E4D4015CAC2D7D7CA4440116DC7D45D0D4D40425F7AFB73C94440116DC7D45D0D4D40
32383	2149	41.567833	41.614733999999999	58.157766000000002	58.132624	Леонова	0103000020E61000000100000005000000774B72C0AEC844401555BFD2F9104D40774B72C0AEC84440DB3521AD31144D40A0DE8C9AAFCE4440DB3521AD31144D40A0DE8C9AAFCE44401555BFD2F9104D40774B72C0AEC844401555BFD2F9104D40
32252	2149	41.567833	41.614733999999999	58.157766000000002	58.132624	Крупской	0103000020E61000000100000005000000774B72C0AEC844401555BFD2F9104D40774B72C0AEC84440DB3521AD31144D40A0DE8C9AAFCE4440DB3521AD31144D40A0DE8C9AAFCE44401555BFD2F9104D40774B72C0AEC844401555BFD2F9104D40
32472	2255	41.78642	41.809480000000001	58.211123999999998	58.197823	Новая	0103000020E61000000100000005000000CD751A69A9E44440C4B2994352194D40CD751A69A9E444404AB3791C061B4D400F62670A9DE744404AB3791C061B4D400F62670A9DE74440C4B2994352194D40CD751A69A9E44440C4B2994352194D40
32196	2849	41.625926999999997	41.634425	58.147342000000002	58.142130999999999	Южная	0103000020E6100000010000000500000079573D601ED04440B75F3E5931124D4079573D601ED04440E3A9471ADC124D40E561A1D634D14440E3A9471ADC124D40E561A1D634D14440B75F3E5931124D4079573D601ED04440B75F3E5931124D40
32305	2723	41.883096999999999	41.915022999999998	58.186225	58.174210000000002	Школьная	0103000020E610000001000000050000000D198F5209F144406E5166834C164D400D198F5209F144404B598638D6174D403D0B42791FF544404B598638D6174D403D0B42791FF544406E5166834C164D400D198F5209F144406E5166834C164D40
32556	2710	41.785549000000003	41.805931000000001	58.108611000000003	58.097678000000002	Молодежная	0103000020E61000000100000005000000E833A0DE8CE44440F4C473B6800C4D40E833A0DE8CE44440317E1AF7E60D4D4092EA3BBF28E74440317E1AF7E60D4D4092EA3BBF28E74440F4C473B6800C4D40E833A0DE8CE44440F4C473B6800C4D40
32360	2626	41.495168	41.507367000000002	58.079300000000003	58.071218000000002	Садовая	0103000020E610000001000000050000004B033FAA61BF44407A71E2AB1D094D404B033FAA61BF444052499D80260A4D40EA08E066F1C0444052499D80260A4D40EA08E066F1C044407A71E2AB1D094D404B033FAA61BF44407A71E2AB1D094D40
32473	7592	41.503343000000001	41.509802000000001	58.173744999999997	58.170332000000002	Октябрьская	0103000020E61000000100000005000000D4D51D8B6DC044402CBB6070CD154D40D4D51D8B6DC04440F86BB2463D164D40BBB7223141C14440F86BB2463D164D40BBB7223141C144402CBB6070CD154D40D4D51D8B6DC044402CBB6070CD154D40
32412	2603	41.391323	41.413367999999998	58.142406000000001	58.134329999999999	Центральная	0103000020E6100000010000000500000018963FDF16B24440936FB6B931114D4018963FDF16B2444089601C5C3A124D40419B1C3EE9B4444089601C5C3A124D40419B1C3EE9B44440936FB6B931114D4018963FDF16B24440936FB6B931114D40
32222	2836	41.419674000000001	41.437272	58.030431999999998	58.026834000000001	Дорожная	0103000020E61000000100000005000000A27DACE0B7B54440DF35E84B6F034D40A27DACE0B7B544403D601E32E5034D406FBA6587F8B744403D601E32E5034D406FBA6587F8B74440DF35E84B6F034D40A27DACE0B7B54440DF35E84B6F034D40
32470	53345	41.148795999999997	42.027096999999998	58.288400000000003	57.968797000000002	Свободы	0103000020E6100000010000000500000047E350BF0B93444041BB438A01FC4C4047E350BF0B9344404D158C4AEA244D40EC681CEA770345404D158C4AEA244D40EC681CEA7703454041BB438A01FC4C4047E350BF0B93444041BB438A01FC4C40
32260	2488	41.660719	41.680112999999999	58.251958999999999	58.239539999999998	Северная	0103000020E61000000100000005000000446CB07092D44440BB0A293FA91E4D40446CB07092D444406877483140204D40CF4A5AF10DD744406877483140204D40CF4A5AF10DD74440BB0A293FA91E4D40446CB07092D44440BB0A293FA91E4D40
32247	2392	41.312280000000001	41.330309	58.215437999999999	58.209332000000003	Правды	0103000020E61000000100000005000000F29881CAF8A74440CE001764CB1A4D40F29881CAF8A744406728EE78931B4D408849B89047AA44406728EE78931B4D408849B89047AA4440CE001764CB1A4D40F29881CAF8A74440CE001764CB1A4D40
32581	2382	41.282977000000002	41.308138999999997	58.168913000000003	58.156891999999999	Советская	0103000020E610000001000000050000009642209738A4444084807C0915144D409642209738A44440446FF1F09E154D40A2CF471971A74440446FF1F09E154D40A2CF471971A7444084807C0915144D409642209738A4444084807C0915144D40
32283	31296	41.514060000000001	41.533651999999996	57.950194000000003	57.938524999999998	Корякова	0103000020E610000001000000050000004417D4B7CCC144403CBD529621F84C404417D4B7CCC144407F6DFDF49FF94C40F5B86FB54EC444407F6DFDF49FF94C40F5B86FB54EC444403CBD529621F84C404417D4B7CCC144403CBD529621F84C40
32363	2051	41.575091	41.607151999999999	57.914065000000001	57.902191999999999	Зелёная	0103000020E61000000100000005000000AA9CF6949CC944403E5B07077BF34C40AA9CF6949CC9444089B5F81400F54C40BAD91F28B7CD444089B5F81400F54C40BAD91F28B7CD44403E5B07077BF34C40AA9CF6949CC944403E5B07077BF34C40
32304	978	41.658985000000001	41.730517999999996	57.894817000000003	57.865051000000001	Юрьева	0103000020E61000000100000005000000FCC6D79E59D44440A12FBDFDB9EE4C40FCC6D79E59D44440D2730B5D89F24C40D591239D81DD4440D2730B5D89F24C40D591239D81DD4440A12FBDFDB9EE4C40FCC6D79E59D44440A12FBDFDB9EE4C40
32251	978	41.658985000000001	41.730517999999996	57.894817000000003	57.865051000000001	Шаховское шоссе	0103000020E61000000100000005000000FCC6D79E59D44440A12FBDFDB9EE4C40FCC6D79E59D44440D2730B5D89F24C40D591239D81DD4440D2730B5D89F24C40D591239D81DD4440A12FBDFDB9EE4C40FCC6D79E59D44440A12FBDFDB9EE4C40
32140	978	41.658985000000001	41.730517999999996	57.894817000000003	57.865051000000001	Октябрьская	0103000020E61000000100000005000000FCC6D79E59D44440A12FBDFDB9EE4C40FCC6D79E59D44440D2730B5D89F24C40D591239D81DD4440D2730B5D89F24C40D591239D81DD4440A12FBDFDB9EE4C40FCC6D79E59D44440A12FBDFDB9EE4C40
32261	2036	41.883347999999998	41.898547999999998	57.836962	57.827790999999998	 Новая	0103000020E61000000100000005000000567E198C11F144402976340EF5E94C40567E198C11F1444054FF209221EB4C406FF1F09E03F3444054FF209221EB4C406FF1F09E03F344402976340EF5E94C40567E198C11F144402976340EF5E94C40
32563	1334	41.932423	41.953093000000003	58.078200000000002	58.067295999999999	Центральная	0103000020E61000000100000005000000E48409A359F744406893C3279D084D40E48409A359F744400B462575020A4D40F58590F3FEF944400B462575020A4D40F58590F3FEF944406893C3279D084D40E48409A359F744406893C3279D084D40
32520	1599	41.417445999999998	41.449407999999998	57.830838999999997	57.815764999999999	площадь Октября	0103000020E610000001000000050000004AECDADE6EB54440581CCEFC6AE84C404AECDADE6EB54440E49EAEEE58EA4C40C7478B3386B94440E49EAEEE58EA4C40C7478B3386B94440581CCEFC6AE84C404AECDADE6EB54440581CCEFC6AE84C40
32301	1242	41.926538999999998	41.955052000000002	58.050173999999998	58.033566999999998	Центральная	0103000020E61000000100000005000000F9BB77D498F64440C79C67EC4B044D40F9BB77D498F64440048E041A6C064D405DFDD8243FFA4440048E041A6C064D405DFDD8243FFA4440C79C67EC4B044D40F9BB77D498F64440C79C67EC4B044D40
32464	1541	41.371192000000001	41.390478999999999	57.900297999999999	57.890602000000001	Центральная	0103000020E61000000100000005000000B7442E3883AF444048E00F3FFFF14C40B7442E3883AF4440BD5301F73CF34C402C634337FBB14440BD5301F73CF34C402C634337FBB1444048E00F3FFFF14C40B7442E3883AF444048E00F3FFFF14C40
32218	1917	41.631515	41.647621000000001	57.901240000000001	57.893697000000003	Заводская	0103000020E610000001000000050000007BF7C77BD5D0444044C4CDA964F24C407BF7C77BD5D044406CEC12D55BF34C40F699B33EE5D244406CEC12D55BF34C40F699B33EE5D2444044C4CDA964F24C407BF7C77BD5D0444044C4CDA964F24C40
32508	1432	41.448428999999997	41.469647000000002	57.756174000000001	57.744509000000001	Королёва	0103000020E61000000100000005000000FBC9181F66B94440F14927124CDF4C40FBC9181F66B94440F20A444FCAE04C400FD594641DBC4440F20A444FCAE04C400FD594641DBC4440F14927124CDF4C40FBC9181F66B94440F14927124CDF4C40
32562	1495	41.284090999999997	41.318730000000002	57.807782000000003	57.798031999999999	Центральная	0103000020E61000000100000005000000410B09185DA44440AB949EE925E64C40410B09185DA4444014268C6665E74C4086200725CCA8444014268C6665E74C4086200725CCA84440AB949EE925E64C40410B09185DA44440AB949EE925E64C40
32471	1900	41.643470999999998	41.658966999999997	57.874113000000001	57.869095999999999	Молодежная,	0103000020E610000001000000050000005376FA415DD24440CE8AA8893EEF4C405376FA415DD2444015014EEFE2EF4C405512D90759D4444015014EEFE2EF4C405512D90759D44440CE8AA8893EEF4C405376FA415DD24440CE8AA8893EEF4C40
32406	1231	41.879871999999999	41.900488000000003	57.949674000000002	57.939619	Центральная	0103000020E6100000010000000500000043554CA59FF04440A1D9756F45F84C4043554CA59FF0444046EEE9EA8EF94C406138D73043F3444046EEE9EA8EF94C406138D73043F34440A1D9756F45F84C4043554CA59FF04440A1D9756F45F84C40
32466	1801	41.73659	41.752077	57.843420000000002	57.835510999999997	Кашинцева	0103000020E61000000100000005000000C347C49448DE444060394206F2EA4C40C347C49448DE44406B65C22FF5EB4C407289230F44E044406B65C22FF5EB4C407289230F44E0444060394206F2EA4C40C347C49448DE444060394206F2EA4C40
32462	1793	41.723143	41.737659000000001	57.896577000000001	57.890132999999999	Цветочная	0103000020E6100000010000000500000069AA27F38FDC4440910BCEE0EFF14C4069AA27F38FDC444043ACFE08C3F24C40CF4C309C6BDE444043ACFE08C3F24C40CF4C309C6BDE4440910BCEE0EFF14C4069AA27F38FDC4440910BCEE0EFF14C40
32166	1384	41.532843999999997	41.555732999999996	57.830627999999997	57.820928000000002	Центральная	0103000020E6100000010000000500000056EF703B34C44440732F302B14E94C4056EF703B34C444402992AF0452EA4C406B274A4222C744402992AF0452EA4C406B274A4222C74440732F302B14E94C4056EF703B34C44440732F302B14E94C40
32421	1699	41.670385000000003	41.707844000000001	57.933450000000001	57.905315000000002	Школьная	0103000020E610000001000000050000004F5DF92CCFD5444004CAA65CE1F34C404F5DF92CCFD54440C139234A7BF74C40BD55D7A19ADA4440C139234A7BF74C40BD55D7A19ADA444004CAA65CE1F34C404F5DF92CCFD5444004CAA65CE1F34C40
32250	1157	41.984391000000002	42.019587000000001	58.011102999999999	57.991159000000003	Полевая	0103000020E6100000010000000500000006BD378600FE44406B11514CDEFE4C4006BD378600FE444099F1B6D26B014D40A036AAD38102454099F1B6D26B014D40A036AAD3810245406B11514CDEFE4C4006BD378600FE44406B11514CDEFE4C40
32249	770	42.254379	42.318133000000003	59.091216000000003	59.064644000000001	Серогодского	0103000020E6100000010000000500000004E5B67D8F204540FAF02C4146884D4004E5B67D8F2045409C6F44F7AC8B4D40A2630795B82845409C6F44F7AC8B4D40A2630795B8284540FAF02C4146884D4004E5B67D8F204540FAF02C4146884D40
32436	770	42.254379	42.318133000000003	59.091216000000003	59.064644000000001	Красноармейская	0103000020E6100000010000000500000004E5B67D8F204540FAF02C4146884D4004E5B67D8F2045409C6F44F7AC8B4D40A2630795B82845409C6F44F7AC8B4D40A2630795B8284540FAF02C4146884D4004E5B67D8F204540FAF02C4146884D40
32300	770	42.254379	42.318133000000003	59.091216000000003	59.064644000000001	В.Серогодского	0103000020E6100000010000000500000004E5B67D8F204540FAF02C4146884D4004E5B67D8F2045409C6F44F7AC8B4D40A2630795B82845409C6F44F7AC8B4D40A2630795B8284540FAF02C4146884D4004E5B67D8F204540FAF02C4146884D40
32405	112	42.193528000000001	42.219802999999999	58.874048000000002	58.859302999999997	Центральная	0103000020E610000001000000050000001E6E8786C5184540662D05A4FD6D4D401E6E8786C51845402E910BCEE06F4D4006483481221C45402E910BCEE06F4D4006483481221C4540662D05A4FD6D4D401E6E8786C5184540662D05A4FD6D4D40
32411	606	42.292746000000001	42.304622000000002	59.063764999999997	59.059620000000002	Новая	0103000020E61000000100000005000000750470B3782545400118CFA0A1874D40750470B37825454091D0967329884D4031D28BDAFD26454091D0967329884D4031D28BDAFD2645400118CFA0A1874D40750470B3782545400118CFA0A1874D40
32246	32327	42.698946999999997	42.714208999999997	59.084063999999998	59.076878000000001	Школьная	0103000020E61000000100000005000000935165187759454015E46723D7894D409351651877594540AE62F19BC28A4D4022C154336B5B4540AE62F19BC28A4D4022C154336B5B454015E46723D7894D40935165187759454015E46723D7894D40
32214	32312	42.571933999999999	42.589703	59.073242999999998	59.062294000000001	Ветеранов	0103000020E6100000010000000500000038BC202235494540575EF23FF9874D4038BC20223549454099D4D00660894D4032AD4D637B4B454099D4D00660894D4032AD4D637B4B4540575EF23FF9874D4038BC202235494540575EF23FF9874D40
32481	9785	45.853417	45.877195	58.874951000000003	58.864711	Новая	0103000020E61000000100000005000000DB6CACC43CED4640E8BE9CD9AE6E4D40DB6CACC43CED46401F4DF564FE6F4D407C9BFEEC47F046401F4DF564FE6F4D407C9BFEEC47F04640E8BE9CD9AE6E4D40DB6CACC43CED4640E8BE9CD9AE6E4D40
32434	4230	45.682493999999998	45.744208999999998	58.900917	58.872889999999998	Чапаева	0103000020E61000000100000005000000ADDBA0F65BD74640B28009DCBA6F4D40ADDBA0F65BD7464089B48D3F51734D40C631923D42DF464089B48D3F51734D40C631923D42DF4640B28009DCBA6F4D40ADDBA0F65BD74640B28009DCBA6F4D40
32209	4230	45.682493999999998	45.744208999999998	58.900917	58.872889999999998	Советская	0103000020E61000000100000005000000ADDBA0F65BD74640B28009DCBA6F4D40ADDBA0F65BD7464089B48D3F51734D40C631923D42DF464089B48D3F51734D40C631923D42DF4640B28009DCBA6F4D40ADDBA0F65BD74640B28009DCBA6F4D40
32279	10110	45.596328	45.620536999999999	59.078774000000003	59.061141999999997	Октябрьская	0103000020E6100000010000000500000034D8D47954CC4640BD344580D3874D4034D8D47954CC464037E33444158A4D409E7AA4C16DCF464037E33444158A4D409E7AA4C16DCF4640BD344580D3874D4034D8D47954CC4640BD344580D3874D40
32591	9820	45.643138999999998	45.680877000000002	58.778075999999999	58.759658999999999	Гагарина	0103000020E610000001000000050000001DE4F56052D24640588E90813C614D401DE4F56052D24640B8E68EFE97634D409FCC3FFA26D74640B8E68EFE97634D409FCC3FFA26D74640588E90813C614D401DE4F56052D24640588E90813C614D40
32484	10068	45.420644000000003	45.436176000000003	58.738359000000003	58.727584	Победы	0103000020E610000001000000050000001BA19FA9D7B54640E38BF678215D4D401BA19FA9D7B5464088DA368C825E4D406AA67B9DD4B7464088DA368C825E4D406AA67B9DD4B74640E38BF678215D4D401BA19FA9D7B54640E38BF678215D4D40
32482	9962	45.561059999999998	45.580122000000003	58.866213999999999	58.856859999999998	Советская	0103000020E61000000100000005000000008C67D0D0C7464012A0A696AD6D4D40008C67D0D0C746402EABB019E06E4D4056D80C7041CA46402EABB019E06E4D4056D80C7041CA464012A0A696AD6D4D40008C67D0D0C7464012A0A696AD6D4D40
32517	9928	45.517007	45.536014999999999	58.799779000000001	58.787885000000003	Шистерова	0103000020E61000000100000005000000CB660E492DC2464026016A6AD9644D40CB660E492DC24640888384285F664D402D95B7239CC44640888384285F664D402D95B7239CC4464026016A6AD9644D40CB660E492DC2464026016A6AD9644D40
32440	10037	45.478667000000002	45.507655	58.729554999999998	58.711981000000002	Первомайская	0103000020E610000001000000050000005456D3F544BD4640CB2F8331225B4D405456D3F544BD46400FD1E80E625D4D405053CBD6FAC046400FD1E80E625D4D405053CBD6FAC04640CB2F8331225B4D405456D3F544BD4640CB2F8331225B4D40
32310	31217	45.891711999999998	45.942591999999998	58.370704000000003	58.341434	Ленина	0103000020E61000000100000005000000B2B96A9E23F2464009DFFB1BB42B4D40B2B96A9E23F246408A3F8A3A732F4D4051BCCADAA6F846408A3F8A3A732F4D4051BCCADAA6F8464009DFFB1BB42B4D40B2B96A9E23F2464009DFFB1BB42B4D40
32230	30916	46.391686999999997	46.421889	58.411222000000002	58.400250999999997	Строителей	0103000020E6100000010000000500000059A2B3CC223247407C98BD6C3B334D4059A2B3CC22324740A7B228ECA2344D4065C5707500364740A7B228ECA2344D4065C57075003647407C98BD6C3B334D4059A2B3CC223247407C98BD6C3B334D40
32239	5704	46.288857	46.337941000000001	58.372497000000003	58.343404	площадь 50 лет ВЛКСМ	0103000020E610000001000000050000003F1C2444F924474065A88AA9F42B4D403F1C2444F9244740D76D50FBAD2F4D40207D93A6412B4740D76D50FBAD2F4D40207D93A6412B474065A88AA9F42B4D403F1C2444F924474065A88AA9F42B4D40
32235	5704	46.288857	46.337941000000001	58.372497000000003	58.343404	Пушкина	0103000020E610000001000000050000003F1C2444F924474065A88AA9F42B4D403F1C2444F9244740D76D50FBAD2F4D40207D93A6412B4740D76D50FBAD2F4D40207D93A6412B474065A88AA9F42B4D403F1C2444F924474065A88AA9F42B4D40
32551	12953	46.588633999999999	46.629292	58.624972	58.60398	Ленина	0103000020E6100000010000000500000026A8E15B584B474013B875374F4D4D4026A8E15B584B474036751E15FF4F4D4035D1E7A38C50474036751E15FF4F4D4035D1E7A38C50474013B875374F4D4D4026A8E15B584B474013B875374F4D4D40
32555	31020	46.495001999999999	46.517792999999998	58.562595000000002	58.554003999999999	Центральная	0103000020E6100000010000000500000030BABC395C3F474035ED629AE9464D4030BABC395C3F474052F2EA1C03484D40828C800A4742474052F2EA1C03484D40828C800A4742474035ED629AE9464D4030BABC395C3F474035ED629AE9464D40
32550	31193	46.456716	46.474196999999997	58.483220000000003	58.474260999999998	Северная	0103000020E61000000100000005000000ACC77DAB753A474056629E95B43C4D40ACC77DAB753A4740F6622827DA3D4D403F6EBF7CB23C4740F6622827DA3D4D403F6EBF7CB23C474056629E95B43C4D40ACC77DAB753A474056629E95B43C4D40
32332	30309	43.441834999999998	43.460304999999998	58.457340000000002	58.447282000000001	Центральная	0103000020E61000000100000005000000349D9D0C8EB84540740B5D8940394D40349D9D0C8EB845408A93FB1D8A3A4D40B7973446EBBA45408A93FB1D8A3A4D40B7973446EBBA4540740B5D8940394D40349D9D0C8EB84540740B5D8940394D40
32525	25978	43.779800000000002	43.805500000000002	58.450032	58.427779999999998	Ленина	0103000020E61000000100000005000000DDB5847CD0E3454002F1BA7EC1364D40DDB5847CD0E34540A51309A69A394D40C976BE9F1AE74540A51309A69A394D40C976BE9F1AE7454002F1BA7EC1364D40DDB5847CD0E3454002F1BA7EC1364D40
32552	30775	43.390262999999997	43.420518000000001	58.491540999999998	58.476340999999998	Песочная	0103000020E610000001000000050000005FEB5223F4B14540395FECBDF83C4D405FEB5223F4B1454052D2C3D0EA3E4D408EB0A888D3B5454052D2C3D0EA3E4D408EB0A888D3B54540395FECBDF83C4D405FEB5223F4B14540395FECBDF83C4D40
32391	30775	43.390262999999997	43.420518000000001	58.491540999999998	58.476340999999998	Ленина	0103000020E610000001000000050000005FEB5223F4B14540395FECBDF83C4D405FEB5223F4B1454052D2C3D0EA3E4D408EB0A888D3B5454052D2C3D0EA3E4D408EB0A888D3B54540395FECBDF83C4D405FEB5223F4B14540395FECBDF83C4D40
32536	4182	43.310887999999998	43.339894999999999	58.351838999999998	58.344835000000003	Полевая	0103000020E61000000100000005000000035C902DCBA7454012C2A38D232C4D40035C902DCBA745408A3A730F092D4D407689EAAD81AB45408A3A730F092D4D407689EAAD81AB454012C2A38D232C4D40035C902DCBA7454012C2A38D232C4D40
32404	30715	43.428548999999997	43.452373000000001	58.706195000000001	58.694347	Школьная	0103000020E61000000100000005000000E3DD91B1DAB64540B189CC5CE0584D40E3DD91B1DAB64540A3CC0699645A4D40F54BC45BE7B94540A3CC0699645A4D40F54BC45BE7B94540B189CC5CE0584D40E3DD91B1DAB64540B189CC5CE0584D40
32288	30624	43.362971999999999	43.386634000000001	58.274526999999999	58.263924000000003	Набережная	0103000020E610000001000000050000008EAED2DD75AE45409450FA42C8214D408EAED2DD75AE45403B6F63B323234D40C6C210397DB145403B6F63B323234D40C6C210397DB145409450FA42C8214D408EAED2DD75AE45409450FA42C8214D40
32287	29846	46.148971000000003	46.180807999999999	59.111767	59.096147999999999	Чапаева	0103000020E61000000100000005000000B686527B11134740B4C9E1934E8C4D40B686527B11134740D2E28C614E8E4D40766D6FB724174740D2E28C614E8E4D40766D6FB724174740B4C9E1934E8C4D40B686527B11134740B4C9E1934E8C4D40
32217	29822	46.114646999999998	46.194929000000002	59.128787000000003	59.093088000000002	Октябрьская	0103000020E61000000100000005000000D1CABDC0AC0E474035D3BD4EEA8B4D40D1CABDC0AC0E47403293A8177C904D406005F86EF31847403293A8177C904D406005F86EF318474035D3BD4EEA8B4D40D1CABDC0AC0E474035D3BD4EEA8B4D40
32396	29822	46.114646999999998	46.194929000000002	59.128787000000003	59.093088000000002	 Больничная	0103000020E61000000100000005000000D1CABDC0AC0E474035D3BD4EEA8B4D40D1CABDC0AC0E47403293A8177C904D406005F86EF31847403293A8177C904D406005F86EF318474035D3BD4EEA8B4D40D1CABDC0AC0E474035D3BD4EEA8B4D40
32387	30246	45.967205999999997	45.989421999999998	58.941778999999997	58.925080000000001	Советская	0103000020E610000001000000050000005B3FFD67CDFB464083177D0569764D405B3FFD67CDFB4640A087DA368C784D40B1F84D61A5FE4640A087DA368C784D40B1F84D61A5FE464083177D0569764D405B3FFD67CDFB464083177D0569764D40
32225	30274	46.239458999999997	46.264727999999998	59.192919000000003	59.183579999999999	Дзержинского	0103000020E61000000100000005000000CEDDAE97A61E47408F19A88C7F974D40CEDDAE97A61E474076E3DD91B1984D40F12A6B9BE221474076E3DD91B1984D40F12A6B9BE22147408F19A88C7F974D40CEDDAE97A61E47408F19A88C7F974D40
32241	28678	42.223692999999997	42.264781999999997	57.818981999999998	57.775579	пер. Школьный	0103000020E610000001000000050000000CACE3F8A11C4540713B342C46E34C400CACE3F8A11C45409F01F566D4E84C40E4486760E42145409F01F566D4E84C40E4486760E4214540713B342C46E34C400CACE3F8A11C4540713B342C46E34C40
32223	28678	42.223692999999997	42.264781999999997	57.818981999999998	57.775579	Советская	0103000020E610000001000000050000000CACE3F8A11C4540713B342C46E34C400CACE3F8A11C45409F01F566D4E84C40E4486760E42145409F01F566D4E84C40E4486760E4214540713B342C46E34C400CACE3F8A11C4540713B342C46E34C40
32597	28678	42.223692999999997	42.264781999999997	57.818981999999998	57.775579	Сахарова	0103000020E610000001000000050000000CACE3F8A11C4540713B342C46E34C400CACE3F8A11C45409F01F566D4E84C40E4486760E42145409F01F566D4E84C40E4486760E4214540713B342C46E34C400CACE3F8A11C4540713B342C46E34C40
32620	28678	42.223692999999997	42.264781999999997	57.818981999999998	57.775579	Заречная	0103000020E610000001000000050000000CACE3F8A11C4540713B342C46E34C400CACE3F8A11C45409F01F566D4E84C40E4486760E42145409F01F566D4E84C40E4486760E4214540713B342C46E34C400CACE3F8A11C4540713B342C46E34C40
32506	53350	42.543511000000002	42.577620000000003	57.955599999999997	57.943216	Школьная	0103000020E610000001000000050000001502B9C4914545402F88484DBBF84C401502B9C4914545405F07CE1951FA4C40FDC1C073EF4945405F07CE1951FA4C40FDC1C073EF4945402F88484DBBF84C401502B9C4914545402F88484DBBF84C40
32444	28589	42.145997999999999	42.178731999999997	57.877716999999997	57.865031999999999	Луговая	0103000020E6100000010000000500000005A4FD0FB01245402AFF5A5EB9EE4C4005A4FD0FB01245405512D90759F04C40D45FAFB0E01645405512D90759F04C40D45FAFB0E01645402AFF5A5EB9EE4C4005A4FD0FB01245402AFF5A5EB9EE4C40
32675	53369	42.349806999999998	42.364576	57.815323999999997	57.805087	Колхозная	0103000020E61000000100000005000000B874CC79C62C4540A6B73F170DE74C40B874CC79C62C45406BD26D895CE84C400874266DAA2E45406BD26D895CE84C400874266DAA2E4540A6B73F170DE74C40B874CC79C62C4540A6B73F170DE74C40
32578	53359	42.245404999999998	42.265635000000003	57.981425000000002	57.966743999999998	Школьная	0103000020E610000001000000050000002FA3586E691F454057CD7344BEFB4C402FA3586E691F4540083D9B559FFD4C4024D6E25300224540083D9B559FFD4C4024D6E2530022454057CD7344BEFB4C402FA3586E691F454057CD7344BEFB4C40
32456	53342	41.765894000000003	42.790593000000001	58.157598999999998	57.555652000000002	Колхозная	0103000020E61000000100000005000000F01989D008E244407FFACF9A1FC74C40F01989D008E24440EF703B342C144D4028B9C32632654540EF703B342C144D4028B9C326326545407FFACF9A1FC74C40F01989D008E244407FFACF9A1FC74C40
32327	29128	42.338965000000002	42.370756	58.020600000000002	58.007669999999997	Пушкина	0103000020E610000001000000050000008CBE8234632B454085949F54FB004D408CBE8234632B454018265305A3024D40DC65BFEE742F454018265305A3024D40DC65BFEE742F454085949F54FB004D408CBE8234632B454085949F54FB004D40
32447	28964	42.407972999999998	42.426397999999999	57.694935999999998	57.678958999999999	Совхозная	0103000020E6100000010000000500000054539275383445409529E620E8D64C4054539275383445401268B0A9F3D84C40378AAC35943645401268B0A9F3D84C40378AAC35943645409529E620E8D64C4054539275383445409529E620E8D64C40
32219	29204	42.674027000000002	42.718395000000001	57.818722999999999	57.803221999999998	Школьная	0103000020E610000001000000050000007DCF488446564540BFB67EFACFE64C407DCF488446564540D3BD4EEACBE84C40124E0B5EF45B4540D3BD4EEACBE84C40124E0B5EF45B4540BFB67EFACFE64C407DCF488446564540BFB67EFACFE64C40
32622	53363	42.332155999999998	42.355277999999998	58.081879000000001	58.071646999999999	 Лесная	0103000020E61000000100000005000000C8957A16842A4540A2ED98BA2B094D40C8957A16842A4540569DD5027B0A4D40807EDFBF792D4540569DD5027B0A4D40807EDFBF792D4540A2ED98BA2B094D40C8957A16842A4540A2ED98BA2B094D40
32612	28528	42.168393000000002	42.201737999999999	57.828173999999997	57.815308999999999	улица Транспортная	0103000020E610000001000000050000000BF0DDE68D1545403691990B5CE84C400BF0DDE68D154540E1B20A9B01EA4C40232E008DD2194540E1B20A9B01EA4C40232E008DD21945403691990B5CE84C400BF0DDE68D1545403691990B5CE84C40
32474	53346	42.414720000000003	42.444291999999997	57.783251999999997	57.772492	Заовражная	0103000020E61000000100000005000000A27F828B15354540F8359204E1E24C40A27F828B153545406743FE9941E44C40EDEF6C8FDE3845406743FE9941E44C40EDEF6C8FDE384540F8359204E1E24C40A27F828B15354540F8359204E1E24C40
32650	53366	42.308844000000001	42.333331999999999	57.678102000000003	57.667340000000003	Советская	0103000020E610000001000000050000006DC83F338827454005A8A9656BD54C406DC83F338827454015ADDC0BCCD64C40EA5A7B9FAA2A454015ADDC0BCCD64C40EA5A7B9FAA2A454005A8A9656BD54C406DC83F338827454005A8A9656BD54C40
32543	28815	42.123027999999998	42.156157999999998	57.671233999999998	57.655535	Комарова	0103000020E61000000100000005000000033FAA61BF0F454012312592E8D34C40033FAA61BF0F45404CFBE6FEEAD54C401F813FFCFC1345404CFBE6FEEAD54C401F813FFCFC13454012312592E8D34C40033FAA61BF0F454012312592E8D34C40
32319	28255	47.275629000000002	47.301231000000001	59.067960999999997	59.056316000000002	Центральная	0103000020E61000000100000005000000236AA2CF47A34740EB1ED95C35874D40236AA2CF47A34740A43330F2B2884D404CC5C6BC8EA64740A43330F2B2884D404CC5C6BC8EA64740EB1ED95C35874D40236AA2CF47A34740EB1ED95C35874D40
32280	28126	47.103763999999998	47.142966000000001	58.810887000000001	58.795265999999998	Советская	0103000020E6100000010000000500000046408523488D474074CFBA46CB654D4046408523488D474033E02C25CB674D405038BBB54C92474033E02C25CB674D405038BBB54C92474074CFBA46CB654D4046408523488D474074CFBA46CB654D40
32544	28225	47.097655000000003	47.109350999999997	58.901674	58.893604000000003	Молодёжная	0103000020E610000001000000050000003CA583F57F8C474093C9A99D61724D403CA583F57F8C4740A6D3BA0D6A734D407764AC36FF8D4740A6D3BA0D6A734D407764AC36FF8D474093C9A99D61724D403CA583F57F8C474093C9A99D61724D40
32417	28399	47.374372000000001	47.387873999999996	58.938491999999997	58.932014000000002	Школьная	0103000020E61000000100000005000000E144F46BEBAF474003B5183C4C774D40E144F46BEBAF474060C77F8120784D40FE7BF0DAA5B1474060C77F8120784D40FE7BF0DAA5B1474003B5183C4C774D40E144F46BEBAF474003B5183C4C774D40
32486	28437	46.880946000000002	46.899298000000002	58.809759	58.802241000000002	Интернатовский	0103000020E6100000010000000500000061C5A9D6C2704740534145D5AF664D4061C5A9D6C27047402252D32EA6674D40DAAD65321C7347402252D32EA6674D40DAAD65321C734740534145D5AF664D4061C5A9D6C2704740534145D5AF664D40
32307	28340	46.999828999999998	47.040460000000003	58.985973000000001	58.967253999999997	Победы	0103000020E61000000100000005000000D34B8C65FA7F47406C76A4FACE7B4D40D34B8C65FA7F474098DEFE5C347E4D40E96514CB2D85474098DEFE5C347E4D40E96514CB2D8547406C76A4FACE7B4D40D34B8C65FA7F47406C76A4FACE7B4D40
32297	28308	46.982850999999997	46.995409000000002	58.995055999999998	58.986252	Молодёжная	0103000020E61000000100000005000000A2EBC20FCE7D4740ABCE6A813D7E4D40A2EBC20FCE7D474023D8B8FE5D7F4D407192E68F697F474023D8B8FE5D7F4D407192E68F697F4740ABCE6A813D7E4D40A2EBC20FCE7D4740ABCE6A813D7E4D40
32445	53335	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	Махотина	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
32386	53335	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	Матросова	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
32580	53335	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	Любимова	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
32498	53335	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	Кирова	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
32370	53335	46.517667000000003	46.538544000000002	58.409129	58.399693999999997	Больничная	0103000020E61000000100000005000000F69B89E9424247402634492C29334D40F69B89E9424247402F6CCD565E344D4080BA8102EF4447402F6CCD565E344D4080BA8102EF4447402634492C29334D40F69B89E9424247402634492C29334D40
32459	27993	40.605764000000001	40.620964000000001	57.485947000000003	57.482081000000001	Мира	0103000020E610000001000000050000000D8CBCAC894D4440F18288D4B4BD4C400D8CBCAC894D44406F4BE48233BE4C4026FF93BF7B4F44406F4BE48233BE4C4026FF93BF7B4F4440F18288D4B4BD4C400D8CBCAC894D4440F18288D4B4BD4C40
32338	28037	40.820542000000003	40.836846999999999	57.470641000000001	57.466667999999999	Победы	0103000020E610000001000000050000004A7F2F85076944407C0BEBC6BBBB4C404A7F2F85076944401094DBF63DBC4C40BB6070CD1D6B44401094DBF63DBC4C40BB6070CD1D6B44407C0BEBC6BBBB4C404A7F2F85076944407C0BEBC6BBBB4C40
32277	27901	40.551192	40.573146000000001	57.419127000000003	57.410711999999997	пл. Мира	0103000020E610000001000000050000008EE89E758D4644409109F83592B44C408EE89E758D46444070EF1AF4A5B54C40A7EA1ED95C49444070EF1AF4A5B54C40A7EA1ED95C4944409109F83592B44C408EE89E758D4644409109F83592B44C40
32320	27969	40.578330000000001	40.603689000000003	57.508011000000003	57.498503999999997	Мира	0103000020E61000000100000005000000D925AAB7064A44406C76A4FACEBF4C40D925AAB7064A44400F81238106C14C403CFA5FAE454D44400F81238106C14C403CFA5FAE454D44406C76A4FACEBF4C40D925AAB7064A44406C76A4FACEBF4C40
32179	4826	40.888993999999997	40.910679000000002	57.519415000000002	57.510491000000002	Маршала Новикова	0103000020E610000001000000050000008C2B2E8ECA71444080F3E2C457C14C408C2B2E8ECA714440A306D3307CC24C40B613252191744440A306D3307CC24C40B61325219174444080F3E2C457C14C408C2B2E8ECA71444080F3E2C457C14C40
32533	27333	41.015566999999997	41.038896000000001	57.457625	57.447746000000002	Школьная	0103000020E61000000100000005000000CBF27519FE8144401975ADBD4FB94C40CBF27519FE8144407F6ABC7493BA4C40FDF84B8BFA8444407F6ABC7493BA4C40FDF84B8BFA8444401975ADBD4FB94C40CBF27519FE8144401975ADBD4FB94C40
32453	28077	40.892938000000001	40.919716000000001	57.451222999999999	57.44314	Школьная	0103000020E6100000010000000500000086ADD9CA4B72444054C6BFCFB8B84C4086ADD9CA4B724440FC19DEACC1B94C40D1CDFE40B9754440FC19DEACC1B94C40D1CDFE40B975444054C6BFCFB8B84C4086ADD9CA4B72444054C6BFCFB8B84C40
32458	27725	40.728223	40.747526999999998	57.369554999999998	57.361899999999999	Молодежная	0103000020E61000000100000005000000F6984869365D444011363CBD52AE4C40F6984869365D4440618907944DAF4C4041F0F8F6AE5F4440618907944DAF4C4041F0F8F6AE5F444011363CBD52AE4C40F6984869365D444011363CBD52AE4C40
32211	27611	40.521278000000002	40.573272000000003	57.489193	57.463690999999997	Советская	0103000020E61000000100000005000000E90FCD3CB94244408A39083A5ABB4C40E90FCD3CB9424440503750E09DBE4C4034DB15FA60494440503750E09DBE4C4034DB15FA604944408A39083A5ABB4C40E90FCD3CB94244408A39083A5ABB4C40
32365	26691	40.750689000000001	40.791831999999999	57.601182000000001	57.571525000000001	Техническая	0103000020E61000000100000005000000C53BC0931660444057EC2FBB27C94C40C53BC09316604440D1782288F3CC4C4090F63FC05A654440D1782288F3CC4C4090F63FC05A65444057EC2FBB27C94C40C53BC0931660444057EC2FBB27C94C40
32426	26691	40.750689000000001	40.791831999999999	57.601182000000001	57.571525000000001	Ленина	0103000020E61000000100000005000000C53BC0931660444057EC2FBB27C94C40C53BC09316604440D1782288F3CC4C4090F63FC05A654440D1782288F3CC4C4090F63FC05A65444057EC2FBB27C94C40C53BC0931660444057EC2FBB27C94C40
32323	27536	40.816761	40.834699999999998	57.347630000000002	57.340646	Октябрьская	0103000020E61000000100000005000000FAD2DB9F8B684440B1C1C2499AAB4C40FAD2DB9F8B684440E38DCC237FAC4C4050FC1873D76A4440E38DCC237FAC4C4050FC1873D76A4440B1C1C2499AAB4C40FAD2DB9F8B684440B1C1C2499AAB4C40
32480	27499	40.710723000000002	40.731105999999997	57.403900999999998	57.395623000000001	Центральная	0103000020E61000000100000005000000ECC1A4F8F85A4440D04543C6A3B24C40ECC1A4F8F85A44402DE92807B3B34C4066F4A3E1945D44402DE92807B3B34C4066F4A3E1945D4440D04543C6A3B24C40ECC1A4F8F85A4440D04543C6A3B24C40
32416	27445	40.46631	40.477997000000002	57.375509000000001	57.366554999999998	Школьная	0103000020E610000001000000050000001DE6CB0BB03B4440B7973446EBAE4C401DE6CB0BB03B4440452DCDAD10B04C40064B75012F3D4440452DCDAD10B04C40064B75012F3D4440B7973446EBAE4C401DE6CB0BB03B4440B7973446EBAE4C40
32204	27310	41.056476000000004	41.073104000000001	57.439250999999999	57.428640000000001	Фролова	0103000020E610000001000000050000002481069B3A874440F4E0EEACDDB64C402481069B3A8744401EDE736039B84C40789ACC785B8944401EDE736039B84C40789ACC785B894440F4E0EEACDDB64C402481069B3A874440F4E0EEACDDB64C40
32589	27399	40.705647999999997	40.720343999999997	57.546838999999999	57.540380999999996	Полевая	0103000020E61000000100000005000000703E75AC525A44409C3061342BC54C40703E75AC525A4440B39602D2FEC54C4056EF703B345C4440B39602D2FEC54C4056EF703B345C44409C3061342BC54C40703E75AC525A44409C3061342BC54C40
32372	27247	40.923507000000001	40.945804000000003	57.364784	57.355739	Школьная	0103000020E610000001000000050000004450357A35764440B47405DB88AD4C404450357A35764440520DFB3DB1AE4C408736001B10794440520DFB3DB1AE4C408736001B10794440B47405DB88AD4C404450357A35764440B47405DB88AD4C40
32531	26230	43.761519	43.776206000000002	58.187041000000001	58.180213000000002	Центральная	0103000020E610000001000000050000002D24607479E1454033A8363811174D402D24607479E145406D01A1F5F0174D40C07ADCB75AE345406D01A1F5F0174D40C07ADCB75AE3454033A8363811174D402D24607479E1454033A8363811174D40
32278	26152	43.564535999999997	43.599677999999997	58.313113999999999	58.299326000000001	Молодежная	0103000020E6100000010000000500000013B534B742C84540D76B7A5050264D4013B534B742C84540BAF59A1E14284D40BA10AB3FC2CC4540BAF59A1E14284D40BA10AB3FC2CC4540D76B7A5050264D4013B534B742C84540D76B7A5050264D40
32425	26129	44.022883999999998	44.041981999999997	58.389015999999998	58.380023999999999	Советская	0103000020E6100000010000000500000003CDE7DCED024640F9D85DA0A4304D4003CDE7DCED02464074CFBA46CB314D40A5828AAA5F05464074CFBA46CB314D40A5828AAA5F054640F9D85DA0A4304D4003CDE7DCED024640F9D85DA0A4304D40
32584	26061	44.121501000000002	44.131417999999996	58.438544999999998	58.431713999999999	Советская	0103000020E6100000010000000500000035B742588D0F4640D89C836742374D4035B742588D0F46408369183E22384D40880D164ED21046408369183E22384D40880D164ED2104640D89C836742374D4035B742588D0F4640D89C836742374D40
32316	26299	43.760342000000001	43.771248	58.262996000000001	58.257252999999999	Центральная	0103000020E610000001000000050000003BE3FBE252E1454021E692AAED204D403BE3FBE252E145404A7D59DAA9214D407E8D2441B8E245404A7D59DAA9214D407E8D2441B8E2454021E692AAED204D403BE3FBE252E1454021E692AAED204D40
32194	25897	43.728892000000002	43.750757	58.311346	58.294280000000001	Советская	0103000020E61000000100000005000000742843554CDD4540F6EE8FF7AA254D40742843554CDD4540C6DE8B2FDA274D401D1F2DCE18E04540C6DE8B2FDA274D401D1F2DCE18E04540F6EE8FF7AA254D40742843554CDD4540F6EE8FF7AA254D40
32529	26207	43.702697000000001	43.719315999999999	58.068534	58.063972999999997	Советская	0103000020E61000000100000005000000A8FFACF9F1D94540DB696B4430084D40A8FFACF9F1D945400055DCB8C5084D40A9BEF38B12DC45400055DCB8C5084D40A9BEF38B12DC4540DB696B4430084D40A8FFACF9F1D94540DB696B4430084D40
32478	25994	44.033520000000003	44.047559999999997	58.641869	58.634694000000003	Центральная	0103000020E6100000010000000500000087E123624A044640D57B2AA73D514D4087E123624A0446407AA86DC328524D40834C3272160646407AA86DC328524D40834C327216064640D57B2AA73D514D4087E123624A044640D57B2AA73D514D40
32427	26091	44.104379000000002	44.128526000000001	58.320739000000003	58.311024000000003	Вокзальная	0103000020E61000000100000005000000D1B1834A5C0D4640B4226AA2CF274D40D1B1834A5C0D4640A0C6BDF90D294D40C5573B8A73104640A0C6BDF90D294D40C5573B8A73104640B4226AA2CF274D40D1B1834A5C0D4640B4226AA2CF274D40
32593	10416	45.062278999999997	45.075412999999998	59.020972999999998	59.011842000000001	Заречная	0103000020E61000000100000005000000211D1EC2F8874640105CE50984814D40211D1EC2F8874640AC8C463EAF824D40BC581822A7894640AC8C463EAF824D40BC581822A7894640105CE50984814D40211D1EC2F8874640105CE50984814D40
32592	10471	44.956763000000002	44.985607999999999	58.820202000000002	58.808449000000003	Центральная	0103000020E61000000100000005000000ED82C135777A4640F1BDBF417B674D40ED82C135777A4640910E0F61FC684D4086562767287E4640910E0F61FC684D4086562767287E4640F1BDBF417B674D40ED82C135777A4640F1BDBF417B674D40
32448	10377	45.072017000000002	45.082788000000001	58.542738999999997	58.536091999999996	Советская	0103000020E61000000100000005000000C6E061DA37894640D8D2A3A99E444D40C6E061DA37894640C2A1B77878454D40294014CC988A4640C2A1B77878454D40294014CC988A4640D8D2A3A99E444D40C6E061DA37894640D8D2A3A99E444D40
32281	10314	44.986685999999999	45.003124999999997	58.780631999999997	58.772098999999997	Марьинская	0103000020E61000000100000005000000E5B512BA4B7E46401C23D923D4624D40E5B512BA4B7E4640041BD7BFEB634D406666666666804640041BD7BFEB634D4066666666668046401C23D923D4624D40E5B512BA4B7E46401C23D923D4624D40
32257	10270	44.906539000000002	44.941868999999997	58.869470999999997	58.85868	Новая 	0103000020E6100000010000000500000037C64E780974464059DDEA39E96D4D4037C64E780974464003E962D34A6F4D40E00ED4298F78464003E962D34A6F4D40E00ED4298F78464059DDEA39E96D4D4037C64E780974464059DDEA39E96D4D40
32483	10179	45.010168	45.055641000000001	58.744183	58.723281	Октябрьская	0103000020E610000001000000050000009DBB5D2F4D814640BA68C878945C4D409DBB5D2F4D8146409D9E7763415F4D408BA8893E1F8746409D9E7763415F4D408BA8893E1F874640BA68C878945C4D409DBB5D2F4D814640BA68C878945C4D40
32322	23852	44.297445000000003	44.359383999999999	58.330337	58.306806999999999	Горького	0103000020E61000000100000005000000EBAD81AD122646408997A77345274D40EBAD81AD1226464052D4997B482A4D40535A7F4B002E464052D4997B482A4D40535A7F4B002E46408997A77345274D40EBAD81AD122646408997A77345274D40
32606	53325	44.806457000000002	44.846082000000003	58.346322999999998	58.341174000000002	Заречная	0103000020E61000000100000005000000AD50A4FB396746406D1FF296AB2B4D40AD50A4FB39674640226DE34F542C4D40FDDD3B6A4C6C4640226DE34F542C4D40FDDD3B6A4C6C46406D1FF296AB2B4D40AD50A4FB396746406D1FF296AB2B4D40
32513	53352	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Советская	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32522	53352	44.718279000000003	44.819591000000003	58.365431000000001	58.289076000000001	Больничная	0103000020E61000000100000005000000A933F790F05B46407D073F7100254D40A933F790F05B4640E8F86871C62E4D40488C9E5BE8684640E8F86871C62E4D40488C9E5BE86846407D073F7100254D40A933F790F05B46407D073F7100254D40
32457	23018	43.998674000000001	44.027079000000001	58.026229000000001	58.0122	Советская	0103000020E61000000100000005000000C9AEB48CD4FF45406F8104C58F014D40C9AEB48CD4FF4540789ACC785B034D4046B41D5377034640789ACC785B034D4046B41D53770346406F8104C58F014D40C9AEB48CD4FF45406F8104C58F014D40
32414	23575	43.648574000000004	43.679403999999998	57.658034000000001	57.645156	Ленина	0103000020E6100000010000000500000099840B7904D34540BA68C87894D24C4099840B7904D34540FAD346753AD44C40C362D4B5F6D64540FAD346753AD44C40C362D4B5F6D64540BA68C87894D24C4099840B7904D34540BA68C87894D24C40
32393	23620	43.549084999999998	43.567860000000003	57.651350000000001	57.635371999999997	Коммунистическая	0103000020E61000000100000005000000B1DCD26A48C64540A565A4DE53D14C40B1DCD26A48C64540F31FD26F5FD34C40715AF0A2AFC84540F31FD26F5FD34C40715AF0A2AFC84540A565A4DE53D14C40B1DCD26A48C64540A565A4DE53D14C40
32559	23770	43.28022	43.312522999999999	57.491404000000003	57.466973000000003	Центральная	0103000020E61000000100000005000000B2D7BB3FDEA34540B98E71C5C5BB4C40B2D7BB3FDEA34540D28F8653E6BE4C40B81FF0C000A84540D28F8653E6BE4C40B81FF0C000A84540B98E71C5C5BB4C40B2D7BB3FDEA34540B98E71C5C5BB4C40
32376	22592	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	площадь Революции	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
32254	22592	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	Юрьевецкая	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
32415	22592	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	М. Советская	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
32554	22592	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	Дорожная	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
32515	22592	43.768318999999998	43.825406999999998	57.900737999999997	57.859703000000003	Ветлужская	0103000020E610000001000000050000009DF2E84658E24540F5A276BF0AEE4C409DF2E84658E24540D921FE614BF34C40DA71C3EFA6E94540D921FE614BF34C40DA71C3EFA6E94540F5A276BF0AEE4C409DF2E84658E24540F5A276BF0AEE4C40
32255	23409	43.667411000000001	43.680517999999999	57.752333	57.744787000000002	Культурный центр	0103000020E61000000100000005000000CEFE40B96DD5454034BE2F2E55DF4C40CEFE40B96DD54540CD599F724CE04C406F2BBD361BD74540CD599F724CE04C406F2BBD361BD7454034BE2F2E55DF4C40CEFE40B96DD5454034BE2F2E55DF4C40
32151	23680	43.543686000000001	43.557403999999998	57.599102999999999	57.589770000000001	 Горького	0103000020E6100000010000000500000083A5BA8097C54540BA1457957DCB4C4083A5BA8097C54540BEF73768AFCC4C406D54A70359C74540BEF73768AFCC4C406D54A70359C74540BA1457957DCB4C4083A5BA8097C54540BA1457957DCB4C40
32289	23511	43.710161999999997	43.737344999999998	57.714565999999998	57.698403999999996	20 Партсъезда	0103000020E61000000100000005000000546EA296E6DA4540A2B2614D65D94C40546EA296E6DA4540B16A10E676DB4C403F6F2A5261DE4540B16A10E676DB4C403F6F2A5261DE4540A2B2614D65D94C40546EA296E6DA4540A2B2614D65D94C40
32465	21744	41.196846999999998	41.226149999999997	57.558698999999997	57.546756999999999	Центральная	0103000020E6100000010000000500000069A8514832994440F6ED2422FCC54C4069A851483299444069A7E67283C74C40C5FEB27BF29C444069A7E67283C74C40C5FEB27BF29C4440F6ED2422FCC54C4069A8514832994440F6ED2422FCC54C40
32518	21987	41.308939000000002	41.322997000000001	57.675272	57.669342999999998	Молодежная	0103000020E61000000100000005000000BFBA2A508BA744403C670B08ADD54C40BFBA2A508BA74440C7F319506FD64C4062DA37F757A94440C7F319506FD64C4062DA37F757A944403C670B08ADD54C40BFBA2A508BA744403C670B08ADD54C40
32290	21813	41.338124999999998	41.362881999999999	57.579836	57.572177000000003	Речная	0103000020E61000000100000005000000E17A14AE47AB4440FF428F183DC94C40E17A14AE47AB44409085E81038CA4C404E27D9EA72AE44409085E81038CA4C404E27D9EA72AE4440FF428F183DC94C40E17A14AE47AB4440FF428F183DC94C40
32228	22073	41.475386999999998	41.499516	57.695321	57.687244	Центральная	0103000020E61000000100000005000000C6F8307BD9BC4440A52F849CF7D74C40C6F8307BD9BC44406B9C4D4700D94C4014EAE923F0BF44406B9C4D4700D94C4014EAE923F0BF4440A52F849CF7D74C40C6F8307BD9BC4440A52F849CF7D74C40
32413	22430	41.203080999999997	41.236452999999997	57.461230999999998	57.441445000000002	площадь Сыромятникова	0103000020E6100000010000000500000030B8E68EFE994440CAFD0E4581B84C4030B8E68EFE99444060730E9E09BB4C4042058717449E444060730E9E09BB4C4042058717449E4440CAFD0E4581B84C4030B8E68EFE994440CAFD0E4581B84C40
32347	22302	41.321111000000002	41.343488000000001	57.509737000000001	57.491625999999997	Центральная	0103000020E6100000010000000500000064B14D2A1AA9444080EECB99EDBE4C4064B14D2A1AA94440D447E00F3FC14C40C3482F6AF7AB4440D447E00F3FC14C40C3482F6AF7AB444080EECB99EDBE4C4064B14D2A1AA9444080EECB99EDBE4C40
32542	26611	41.212674999999997	41.264713999999998	57.522866	57.503770000000003	Советская	0103000020E61000000100000005000000A1D634EF389B44405C5A0D897BC04C40A1D634EF389B44405D18E945EDC24C408C65FA25E2A144405D18E945EDC24C408C65FA25E2A144405C5A0D897BC04C40A1D634EF389B44405C5A0D897BC04C40
32275	26611	41.212674999999997	41.264713999999998	57.522866	57.503770000000003	Луначарского	0103000020E61000000100000005000000A1D634EF389B44405C5A0D897BC04C40A1D634EF389B44405D18E945EDC24C408C65FA25E2A144405D18E945EDC24C408C65FA25E2A144405C5A0D897BC04C40A1D634EF389B44405C5A0D897BC04C40
32419	26611	41.212674999999997	41.264713999999998	57.522866	57.503770000000003	Ленина	0103000020E61000000100000005000000A1D634EF389B44405C5A0D897BC04C40A1D634EF389B44405D18E945EDC24C408C65FA25E2A144405D18E945EDC24C408C65FA25E2A144405C5A0D897BC04C40A1D634EF389B44405C5A0D897BC04C40
32602	22041	41.369970000000002	41.397108000000003	57.654378999999999	57.639659999999999	Советская	0103000020E6100000010000000500000025404D2D5BAF44409947FE60E0D14C4025404D2D5BAF44403718EAB0C2D34C40707D586FD4B244403718EAB0C2D34C40707D586FD4B244409947FE60E0D14C4025404D2D5BAF44409947FE60E0D14C40
32295	21927	41.141312999999997	41.165837000000003	57.719949999999997	57.710296999999997	Центральная	0103000020E61000000100000005000000F4BF5C8B1692444034B91803EBDA4C40F4BF5C8B16924440AA60545227DC4C40BFBB95253A954440AA60545227DC4C40BFBB95253A95444034B91803EBDA4C40F4BF5C8B1692444034B91803EBDA4C40
32535	53356	41.506532	41.544854000000001	57.472726999999999	57.463549999999998	Нагорная	0103000020E610000001000000050000005130630AD6C04440C8073D9B55BB4C405130630AD6C04440D5777E5182BC4C40228C9FC6BDC54440D5777E5182BC4C40228C9FC6BDC54440C8073D9B55BB4C405130630AD6C04440C8073D9B55BB4C40
32595	22224	41.461148999999999	41.482833999999997	57.541482000000002	57.526586999999999	Центральная	0103000020E61000000100000005000000A3CA30EE06BB4440D7BFEB3367C34C40A3CA30EE06BB4440B4AF3C484FC54C40CCB22781CDBD4440B4AF3C484FC54C40CCB22781CDBD4440D7BFEB3367C34C40A3CA30EE06BB4440D7BFEB3367C34C40
32549	21907	41.119044000000002	41.152487999999998	57.662058999999999	57.638933000000002	Центральная	0103000020E610000001000000050000007C6473D53C8F4440E7AA798EC8D14C407C6473D53C8F4440E0826C59BED44C4027840EBA84934440E0826C59BED44C4027840EBA84934440E7AA798EC8D14C407C6473D53C8F4440E7AA798EC8D14C40
32409	15276	40.823309000000002	40.836883	57.822543000000003	57.815559	Просвещения	0103000020E6100000010000000500000051C0763062694440AF7AC03C64E84C4051C0763062694440E146CA1649E94C4008CA6DFB1E6B4440E146CA1649E94C4008CA6DFB1E6B4440AF7AC03C64E84C4051C0763062694440AF7AC03C64E84C40
32348	16837	40.794285000000002	40.830649000000001	57.815981000000001	57.803950999999998	Юбилейная	0103000020E61000000100000005000000085A8121AB654440124BCADDE7E64C40085A8121AB6544402594BE1072E84C4041BAD8B4526A44402594BE1072E84C4041BAD8B4526A4440124BCADDE7E64C40085A8121AB654440124BCADDE7E64C40
32523	16282	41.023445000000002	41.050808000000004	57.907581	57.896089000000003	Победы	0103000020E610000001000000050000009B20EA3E0083444016A75A0BB3F24C409B20EA3E0083444049BC3C9D2BF44C40063065E08086444049BC3C9D2BF44C40063065E08086444016A75A0BB3F24C409B20EA3E0083444016A75A0BB3F24C40
32238	16096	40.603842	41.763979999999997	58.637991	57.536496999999997	Геофизиков	0103000020E61000000100000005000000C2F9D4B14A4D444078B306EFABC44C40C2F9D4B14A4D4440381268B0A9514D402766BD18CAE14440381268B0A9514D402766BD18CAE1444078B306EFABC44C40C2F9D4B14A4D444078B306EFABC44C40
32441	16164	40.940018000000002	40.973174999999998	57.927715999999997	57.917448999999998	Советская	0103000020E610000001000000050000005FD3838252784440BB5F05F86EF54C405FD3838252784440EBFCDB65BFF64C40742497FF907C4440EBFCDB65BFF64C40742497FF907C4440BB5F05F86EF54C405FD3838252784440BB5F05F86EF54C40
32267	16757	41.031816999999997	41.066420000000001	57.601635000000002	57.574266999999999	Советская	0103000020E61000000100000005000000793A5794128444400516C09481C94C40793A57941284444082902C6002CD4C4071E657738088444082902C6002CD4C4071E65773808844400516C09481C94C40793A5794128444400516C09481C94C40
32573	16598	40.958478999999997	40.974235	57.709532000000003	57.700929000000002	Кузьмина	0103000020E610000001000000050000008E739B70AF7A4440B4E89D0AB8D94C408E739B70AF7A444095BBCFF1D1DA4C402DCF83BBB37C444095BBCFF1D1DA4C402DCF83BBB37C4440B4E89D0AB8D94C408E739B70AF7A4440B4E89D0AB8D94C40
32155	16813	40.715322999999998	40.734743999999999	57.809080999999999	57.802843000000003	Малининой	0103000020E61000000100000005000000CE893DB48F5B44404969368FC3E64C40CE893DB48F5B4440516859F78FE74C40537765170C5E4440516859F78FE74C40537765170C5E44404969368FC3E64C40CE893DB48F5B44404969368FC3E64C40
32564	16316	40.873201999999999	40.886451999999998	57.895820999999998	57.891162000000001	Набережная	0103000020E61000000100000005000000A1664815C56F44400FB8AE9811F24C40A1664815C56F4440F6083543AAF24C40A5BC564277714440F6083543AAF24C40A5BC5642777144400FB8AE9811F24C40A1664815C56F44400FB8AE9811F24C40
32420	16420	40.814954999999998	40.828429999999997	57.672933	57.666713999999999	Нерехтская	0103000020E61000000100000005000000185B08725068444086E464E256D54C40185B08725068444018B325AB22D64C403C8386FE096A444018B325AB22D64C403C8386FE096A444086E464E256D54C40185B08725068444086E464E256D54C40
32524	16028	41.090395999999998	41.270606999999998	57.985056999999998	57.796104	Школьная	0103000020E6100000010000000500000038D89B18928B44407E1B62BCE6E54C4038D89B18928B444012D9075916FE4C40CA880B40A3A2444012D9075916FE4C40CA880B40A3A244407E1B62BCE6E54C4038D89B18928B44407E1B62BCE6E54C40
32182	16028	41.090395999999998	41.270606999999998	57.985056999999998	57.796104	Зеленая	0103000020E6100000010000000500000038D89B18928B44407E1B62BCE6E54C4038D89B18928B444012D9075916FE4C40CA880B40A3A2444012D9075916FE4C40CA880B40A3A244407E1B62BCE6E54C4038D89B18928B44407E1B62BCE6E54C40
32439	33157	41.054814	41.081341000000002	58.098182000000001	58.086218000000002	Некрасова	0103000020E6100000010000000500000075AE282504874440CC290131090B4D4075AE28250487444027874F3A910C4D407769C361698A444027874F3A910C4D407769C361698A4440CC290131090B4D4075AE282504874440CC290131090B4D40
32576	15825	41.005290000000002	41.050339999999998	57.703800000000001	57.682384999999996	Куколевского	0103000020E61000000100000005000000787FBC57AD804440F623456458D74C40787FBC57AD80444060764F1E16DA4C401FD7868A7186444060764F1E16DA4C401FD7868A71864440F623456458D74C40787FBC57AD804440F623456458D74C40
32375	15789	41.123247999999997	41.155264000000003	57.883688999999997	57.871068999999999	Зеленая	0103000020E6100000010000000500000011A62897C68F44409BC761307FEF4C4011A62897C68F4440DF6A9DB81CF14C40821FD5B0DF934440DF6A9DB81CF14C40821FD5B0DF9344409BC761307FEF4C4011A62897C68F44409BC761307FEF4C40
32224	16243	40.995668999999999	41.008361999999998	57.975689000000003	57.967618000000002	Новая	0103000020E610000001000000050000000D52F014727F4440AE8218E8DAFB4C400D52F014727F444092088D60E3FC4C40BB438A011281444092088D60E3FC4C40BB438A0112814440AE8218E8DAFB4C400D52F014727F4440AE8218E8DAFB4C40
32355	15521	41.041699000000001	41.095768	57.748649	57.726557999999997	Штеймана	0103000020E6100000010000000500000051A3906456854440D65240DAFFDC4C4051A39064568544407097FDBAD3DF4C406D003620428C44407097FDBAD3DF4C406D003620428C4440D65240DAFFDC4C4051A3906456854440D65240DAFFDC4C40
32188	15521	41.041699000000001	41.095768	57.748649	57.726557999999997	Учебный городок	0103000020E6100000010000000500000051A3906456854440D65240DAFFDC4C4051A39064568544407097FDBAD3DF4C406D003620428C44407097FDBAD3DF4C406D003620428C4440D65240DAFFDC4C4051A3906456854440D65240DAFFDC4C40
32299	16395	40.914048000000001	40.932949000000001	57.652949	57.645570999999997	Почтовая	0103000020E61000000100000005000000B37C5D86FF7444407D1F0E12A2D24C40B37C5D86FF7444405B7A34D593D34C40FFEA71DF6A7744405B7A34D593D34C40FFEA71DF6A7744407D1F0E12A2D24C40B37C5D86FF7444407D1F0E12A2D24C40
32428	15422	40.724781999999998	40.740233000000003	57.720655999999998	57.715829999999997	Центральная	0103000020E610000001000000050000005F5D15A8C55C444072BF4351A0DB4C405F5D15A8C55C444045D5AF743EDC4C40C23577F4BF5E444045D5AF743EDC4C40C23577F4BF5E444072BF4351A0DB4C405F5D15A8C55C444072BF4351A0DB4C40
32579	15900	41.056072	41.077190999999999	57.782383000000003	57.76943	Новая	0103000020E61000000100000005000000541C075E2D874440D847A7AE7CE24C40541C075E2D87444023F94A2025E44C40D4450A65E189444023F94A2025E44C40D4450A65E1894440D847A7AE7CE24C40541C075E2D874440D847A7AE7CE24C40
32574	15652	41.239291999999999	41.279150000000001	58.024379000000003	58.009977999999997	переулок Школьный	0103000020E61000000100000005000000E318C91EA19E4440F9D687F546014D40E318C91EA19E4440C7DADFD91E034D40D656EC2FBBA34440C7DADFD91E034D40D656EC2FBBA34440F9D687F546014D40E318C91EA19E4440F9D687F546014D40
32311	16656	40.940539000000001	40.975645999999998	58.212271000000001	58.179310999999998	Центральная	0103000020E6100000010000000500000068CEFA94637844401268B0A9F3164D4068CEFA9463784440D27135B22B1B4D40923CD7F7E17C4440D27135B22B1B4D40923CD7F7E17C44401268B0A9F3164D4068CEFA94637844401268B0A9F3164D40
32346	15165	40.851075999999999	40.861612999999998	57.805940999999997	57.797677999999998	1 Мая	0103000020E610000001000000050000008B34F10EF06C44408D5E0D501AE64C408B34F10EF06C4440B5C01E1329E74C407B67B455496E4440B5C01E1329E74C407B67B455496E44408D5E0D501AE64C408B34F10EF06C44408D5E0D501AE64C40
32512	15218	40.961928	41.006717999999999	57.845168999999999	57.837485000000001	Молодежная	0103000020E61000000100000005000000A88DEA74207B4440FEF15EB532EB4C40A88DEA74207B4440E84B6F7F2EEC4C40B325AB22DC804440E84B6F7F2EEC4C40B325AB22DC804440FEF15EB532EB4C40A88DEA74207B4440FEF15EB532EB4C40
32351	14885	44.158906999999999	44.198405999999999	58.948	58.934767999999998	Дорожная	0103000020E61000000100000005000000800D88105714464075AC527AA6774D40800D881057144640D34D621058794D4043AA285E65194640D34D621058794D4043AA285E6519464075AC527AA6774D40800D88105714464075AC527AA6774D40
32253	14855	44.260883	44.287806000000003	58.825420000000001	58.808169999999997	60 лет Октября	0103000020E610000001000000050000008B8A389D64214640DDCD531D72674D408B8A389D642146406FBBD05CA7694D40DACBB6D3D62446406FBBD05CA7694D40DACBB6D3D6244640DDCD531D72674D408B8A389D64214640DDCD531D72674D40
32623	10537	44.581941	44.597563000000001	58.922376	58.912308000000003	Набережная	0103000020E61000000100000005000000CC99ED0A7D4A464089F02F82C6744D40CC99ED0A7D4A4640C24EB16A10764D405B26C3F17C4C4640C24EB16A10764D405B26C3F17C4C464089F02F82C6744D40CC99ED0A7D4A464089F02F82C6744D40
32186	14729	44.527638000000003	44.544625000000003	58.782349000000004	58.775888000000002	Центральная	0103000020E610000001000000050000003D1059A489434640EFAD484C50634D403D1059A4894346407787140324644D40C1CAA145B64546407787140324644D40C1CAA145B6454640EFAD484C50634D403D1059A489434640EFAD484C50634D40
32402	14601	44.076396000000003	44.092179999999999	59.042532999999999	59.036464000000002	Набережная	0103000020E61000000100000005000000CAC51858C70946409DBD33DAAA844D40CAC51858C70946401900AAB871854D4032ACE28DCC0B46401900AAB871854D4032ACE28DCC0B46409DBD33DAAA844D40CAC51858C70946409DBD33DAAA844D40
32461	14309	44.293644999999998	44.358035999999998	58.835416000000002	58.806310000000003	Набережная речки Киченки	0103000020E6100000010000000500000024D1CB28962546400938842A35674D4024D1CB28962546400F4757E9EE6A4D403465A71FD42D46400F4757E9EE6A4D403465A71FD42D46400938842A35674D4024D1CB28962546400938842A35674D40
32567	14309	44.293644999999998	44.358035999999998	58.835416000000002	58.806310000000003	Набережная реки Унжи	0103000020E6100000010000000500000024D1CB28962546400938842A35674D4024D1CB28962546400F4757E9EE6A4D403465A71FD42D46400F4757E9EE6A4D403465A71FD42D46400938842A35674D4024D1CB28962546400938842A35674D40
32403	13931	43.132733999999999	43.153376999999999	57.545983999999997	57.533444000000003	Советская	0103000020E610000001000000050000009C887E6DFD904540AC1F9BE447C44C409C887E6DFD904540D311C0CDE2C54C40B37A87DBA1934540D311C0CDE2C54C40B37A87DBA1934540AC1F9BE447C44C409C887E6DFD904540AC1F9BE447C44C40
32146	13896	43.172449	43.198571999999999	57.649371000000002	57.630684000000002	Клубная	0103000020E610000001000000050000002C9D0FCF12964540240ED940BAD04C402C9D0FCF1296454044FCC3961ED34C405EF3AACE6A99454044FCC3961ED34C405EF3AACE6A994540240ED940BAD04C402C9D0FCF12964540240ED940BAD04C40
32341	14181	42.869329999999998	42.897196000000001	57.392194000000003	57.377290000000002	Набережная	0103000020E6100000010000000500000041B79734466F4540CE8DE9094BB04C4041B79734466F4540FED7B96933B24C400F0D8B51D7724540FED7B96933B24C400F0D8B51D7724540CE8DE9094BB04C4041B79734466F4540CE8DE9094BB04C40
32674	53368	\N	\N	\N	\N	Советская	\N
32176	13790	43.233426000000001	43.249237000000001	57.725977	57.712335000000003	Садиковская	0103000020E610000001000000050000009F0436E7E09D4540E96514CB2DDB4C409F0436E7E09D4540F85278D0ECDC4C4001FA7DFFE69F4540F85278D0ECDC4C4001FA7DFFE69F4540E96514CB2DDB4C409F0436E7E09D4540E96514CB2DDB4C40
32401	14215	42.845461999999998	42.863123000000002	57.467660000000002	57.461042999999997	Советская	0103000020E6100000010000000500000060014C19386C45405D86FF7403BB4C4060014C19386C4540DDD26A48DCBB4C4074B680D07A6E4540DDD26A48DCBB4C4074B680D07A6E45405D86FF7403BB4C4060014C19386C45405D86FF7403BB4C40
32265	13418	43.020184	43.040612000000003	58.005830000000003	57.996296000000001	Школьная	0103000020E6100000010000000500000084F3A963958245405C9198A086FF4C4084F3A96395824540F8AA9509BF004D409FE925C632854540F8AA9509BF004D409FE925C6328545405C9198A086FF4C4084F3A963958245405C9198A086FF4C40
32505	13689	43.317301999999998	43.333120999999998	57.848402	57.840316000000001	Лесная	0103000020E610000001000000050000004A7A185A9DA845401C2785798FEB4C404A7A185A9DA8454035EECD6F98EC4C402F4E7CB5A3AA454035EECD6F98EC4C402F4E7CB5A3AA45401C2785798FEB4C404A7A185A9DA845401C2785798FEB4C40
32557	13512	42.876130000000003	42.912619999999997	57.814782000000001	57.798876999999997	Советская	0103000020E61000000100000005000000B2852007257045406743FE9941E64C40B2852007257045404BAFCDC64AE84C4077D66EBBD07445404BAFCDC64AE84C4077D66EBBD07445406743FE9941E64C40B2852007257045406743FE9941E64C40
32336	13331	43.163052	43.217832000000001	57.795355999999998	57.768239999999999	Центральная	0103000020E6100000010000000500000011C64FE3DE94454051BD35B055E24C4011C64FE3DE944540B456B439CEE54C40DA0242EBE19B4540B456B439CEE54C40DA0242EBE19B454051BD35B055E24C4011C64FE3DE94454051BD35B055E24C40
32248	14086	43.138187000000002	43.164569999999998	57.420872000000003	57.403987999999998	Школьная	0103000020E61000000100000005000000BEDD921CB0914540FCFCF7E0B5B34C40BEDD921CB0914540ACE63922DFB54C408CF337A110954540ACE63922DFB54C408CF337A110954540FCFCF7E0B5B34C40BEDD921CB0914540FCFCF7E0B5B34C40
32394	13554	43.162585	43.185223000000001	57.936064000000002	57.925120999999997	Центральная	0103000020E61000000100000005000000FBE8D495CF944540E1EB6B5D6AF64C40FBE8D495CF944540427BF5F1D0F74C40C7BB2363B5974540427BF5F1D0F74C40C7BB2363B5974540E1EB6B5D6AF64C40FBE8D495CF944540E1EB6B5D6AF64C40
32245	13735	43.261417999999999	43.271155999999998	57.748821999999997	57.739854000000001	Полевая	0103000020E61000000100000005000000F94A202576A145404BE82E89B3DE4C40F94A202576A145403D433866D9DF4C409D0E643DB5A245403D433866D9DF4C409D0E643DB5A245404BE82E89B3DE4C40F94A202576A145404BE82E89B3DE4C40
32395	13364	42.987170999999996	43.021613000000002	57.804237999999998	57.792817999999997	Островская	0103000020E61000000100000005000000A1478C9E5B7E45400ED76A0F7BE54C40A1478C9E5B7E4540A8195245F1E64C409015FC36C4824540A8195245F1E64C409015FC36C48245400ED76A0F7BE54C40A1478C9E5B7E45400ED76A0F7BE54C40
32175	12225	42.260775000000002	42.284005999999998	58.371426	58.365828	Центральная	0103000020E61000000100000005000000A54E40136121454005FBAF73D32E4D40A54E4013612145402A711DE38A2F4D4013EF004F5A2445402A711DE38A2F4D4013EF004F5A24454005FBAF73D32E4D40A54E40136121454005FBAF73D32E4D40
32333	12575	42.077133000000003	42.098010000000002	58.482565999999998	58.468434999999999	Центральная	0103000020E61000000100000005000000A038807EDF094540A0A696ADF53B4D40A038807EDF094540AD1402B9C43D4D402A5778978B0C4540AD1402B9C43D4D402A5778978B0C4540A0A696ADF53B4D40A038807EDF094540A0A696ADF53B4D40
32492	12164	42.094506000000003	42.110191	58.186095999999999	58.176952999999997	Школьная	0103000020E610000001000000050000004DA3C9C5180C4540ECF65965A6164D404DA3C9C5180C45404DF564FED1174D4022A81ABD1A0E45404DF564FED1174D4022A81ABD1A0E4540ECF65965A6164D404DA3C9C5180C4540ECF65965A6164D40
32571	12615	42.499206000000001	42.511566999999999	58.459774000000003	58.450794999999999	Советская	0103000020E61000000100000005000000C6FB71FBE53F4540A4198BA6B3394D40C6FB71FBE53F45408BC6DADFD93A4D403E5B07077B4145408BC6DADFD93A4D403E5B07077B414540A4198BA6B3394D40C6FB71FBE53F4540A4198BA6B3394D40
32390	12421	41.989052999999998	42.026251999999999	58.449278999999997	58.425221000000001	Кооперативная	0103000020E610000001000000050000005E81E84999FE4440454948A46D364D405E81E84999FE4440C9E369F981394D4030BABC395C034540C9E369F981394D4030BABC395C034540454948A46D364D405E81E84999FE4440454948A46D364D40
32566	12421	41.989052999999998	42.026251999999999	58.449278999999997	58.425221000000001	Зеленая	0103000020E610000001000000050000005E81E84999FE4440454948A46D364D405E81E84999FE4440C9E369F981394D4030BABC395C034540C9E369F981394D4030BABC395C034540454948A46D364D405E81E84999FE4440454948A46D364D40
32569	12070	42.177573000000002	42.201801000000003	58.204301000000001	58.192433999999999	Центральная	0103000020E6100000010000000500000089D349B6BA164540B95164ADA1184D4089D349B6BA16454022C50089261A4D406AA67B9DD419454022C50089261A4D406AA67B9DD4194540B95164ADA1184D4089D349B6BA164540B95164ADA1184D40
32494	12385	41.980232000000001	42.007783000000003	58.464725999999999	58.442830999999998	1-го Мая	0103000020E61000000100000005000000103FFF3D78FD4440D653ABAFAE384D40103FFF3D78FD4440EACC3D247C3B4D407E3B8908FF004540EACC3D247C3B4D407E3B8908FF004540D653ABAFAE384D40103FFF3D78FD4440D653ABAFAE384D40
32331	12294	42.094487999999998	42.107747000000003	58.394134000000001	58.389449999999997	Молодежная	0103000020E61000000100000005000000A6EECA2E180C4540AEB6627FD9314D40A6EECA2E180C4540EF1EA0FB72324D40FE9E58A7CA0D4540EF1EA0FB72324D40FE9E58A7CA0D4540AEB6627FD9314D40A6EECA2E180C4540AEB6627FD9314D40
32389	11904	42.399448	42.416193	58.381825999999997	58.373204999999999	Центральная	0103000020E61000000100000005000000EF39B01C2133454012DA722EC52F4D40EF39B01C213345409961A3ACDF304D407DE9EDCF453545409961A3ACDF304D407DE9EDCF4535454012DA722EC52F4D40EF39B01C2133454012DA722EC52F4D40
32491	12148	42.157685000000001	42.181814000000003	58.152742000000003	58.143721999999997	Молодежная	0103000020E61000000100000005000000EE08A7052F1445409CDB847B65124D40EE08A7052F144540E25CC30C8D134D403CFA5FAE45174540E25CC30C8D134D403CFA5FAE451745409CDB847B65124D40EE08A7052F1445409CDB847B65124D40
32226	11869	42.327772000000003	42.343114999999997	58.298692000000003	58.291455999999997	Школьная	0103000020E61000000100000005000000B345D26EF42945408A1C226E4E254D40B345D26EF4294540D6C9198A3B264D402EE23B31EB2B4540D6C9198A3B264D402EE23B31EB2B45408A1C226E4E254D40B345D26EF42945408A1C226E4E254D40
32601	12303	42.644669999999998	42.680540000000001	58.346955999999999	58.331149000000003	Совхозная	0103000020E610000001000000050000002D5BEB8B84524540338D2617632A4D402D5BEB8B845245405393E00D692C4D4057CF49EF1B5745405393E00D692C4D4057CF49EF1B574540338D2617632A4D402D5BEB8B84524540338D2617632A4D40
32385	11735	42.168751999999998	42.181814000000003	58.595196999999999	58.588552	Ленина	0103000020E610000001000000050000003A9160AA9915454069FF03AC554B4D403A9160AA99154540B2D6506A2F4C4D403CFA5FAE45174540B2D6506A2F4C4D403CFA5FAE4517454069FF03AC554B4D403A9160AA9915454069FF03AC554B4D40
32302	12716	42.603634999999997	42.623910000000002	58.580722999999999	58.572831000000001	Комсомольская	0103000020E6100000010000000500000048DC63E9434D45404791B58652494D4048DC63E9434D45407B849A21554A4D40DDD26A48DC4F45407B849A21554A4D40DDD26A48DC4F45404791B58652494D4048DC63E9434D45404791B58652494D40
32171	11970	42.548828999999998	42.557983	58.353312000000003	58.349544000000002	Школьная	0103000020E61000000100000005000000560C570740464540AB4198DBBD2C4D40560C57074046454066A4DE53392D4D40AB5CA8FC6B47454066A4DE53392D4D40AB5CA8FC6B474540AB4198DBBD2C4D40560C570740464540AB4198DBBD2C4D40
32495	12528	41.879935000000003	41.920817	58.333658	58.321911	Молодежная	0103000020E610000001000000050000008ACDC7B5A1F04440809C306134294D408ACDC7B5A1F044403E062B4EB52A4D40E84CDA54DDF544403E062B4EB52A4D40E84CDA54DDF54440809C306134294D408ACDC7B5A1F04440809C306134294D40
32662	53362	41.682000000000002	42.787790000000001	58.731493	58.0792	Центральная улица	0103000020E610000001000000050000009EEFA7C64BD74440EEEBC039230A4D409EEFA7C64BD7444060200890A15D4D40D40E7F4DD664454060200890A15D4D40D40E7F4DD6644540EEEBC039230A4D409EEFA7C64BD74440EEEBC039230A4D40
32565	11817	42.349043999999999	42.363677000000003	58.345685000000003	58.334372000000002	Центральная	0103000020E61000000100000005000000B96E4A79AD2C45405C59A2B3CC2A4D40B96E4A79AD2C4540E0DBF4673F2C4D4059A7CAF78C2E4540E0DBF4673F2C4D4059A7CAF78C2E45405C59A2B3CC2A4D40B96E4A79AD2C45405C59A2B3CC2A4D40
32499	5814	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Пушкина	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32435	5814	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Лисья Гора	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32294	5814	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Лермонтова	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32392	5814	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Заводская Набережная	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32233	5814	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Гладышева	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32583	5814	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Гагарина	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32306	11687	42.257505999999999	42.284922000000002	58.638502000000003	58.626753000000001	Советская	0103000020E610000001000000050000000B43E4F4F5204540BFD53A7139504D400B43E4F4F52045401E37FC6EBA514D4099F4F752782445401E37FC6EBA514D4099F4F75278244540BFD53A7139504D400B43E4F4F5204540BFD53A7139504D40
32503	53330	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Школьная	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32603	53330	42.311737000000001	42.454892000000001	58.404051000000003	58.359493000000001	Советская	0103000020E6100000010000000500000001FA7DFFE62745400A12DBDD032E4D4001FA7DFFE6274540437573F1B7334D40249BABE6393A4540437573F1B7334D40249BABE6393A45400A12DBDD032E4D4001FA7DFFE62745400A12DBDD032E4D40
32345	53330	42.311737000000001	42.454892000000001	58.404051000000003	58.359493000000001	Свободы	0103000020E6100000010000000500000001FA7DFFE62745400A12DBDD032E4D4001FA7DFFE6274540437573F1B7334D40249BABE6393A4540437573F1B7334D40249BABE6393A45400A12DBDD032E4D4001FA7DFFE62745400A12DBDD032E4D40
32585	53330	42.311638000000002	42.455809000000002	58.402282999999997	58.358614000000003	Долматова	0103000020E610000001000000050000006E1805C1E3274540A2F14410E72D4D406E1805C1E32745404E5E64027E334D407A1C06F3573A45404E5E64027E334D407A1C06F3573A4540A2F14410E72D4D406E1805C1E3274540A2F14410E72D4D40
32384	29768	46.216847999999999	46.239773	58.873606000000002	58.863686999999999	Советская	0103000020E61000000100000005000000FC19DEACC11B47407C7DAD4B8D6E4D40FC19DEACC11B474071CB4752D26F4D405EBBB4E1B01E474071CB4752D26F4D405EBBB4E1B01E47407C7DAD4B8D6E4D40FC19DEACC11B47407C7DAD4B8D6E4D40
32545	11194	46.836047999999998	46.851993	58.982765000000001	58.977575000000002	Набережная	0103000020E610000001000000050000006FF1F09E036B47409031772D217D4D406FF1F09E036B4740A453573ECB7D4D40E1B54B1B0E6D4740A453573ECB7D4D40E1B54B1B0E6D47409031772D217D4D406FF1F09E036B47409031772D217D4D40
32282	11642	46.656312999999997	46.670245999999999	59.380701999999999	59.372804000000002	Больничная	0103000020E6100000010000000500000046787B1002544740B4E89D0AB8AF4D4046787B1002544740CAC2D7D7BAB04D402D23F59ECA554740CAC2D7D7BAB04D402D23F59ECA554740B4E89D0AB8AF4D4046787B1002544740B4E89D0AB8AF4D40
32350	11551	46.720731000000001	46.738678999999998	59.409112	59.399448	Строительная	0103000020E61000000100000005000000501BD5E9405C4740EF39B01C21B34D40501BD5E9405C4740593332C85DB44D40F99E91088D5E4740593332C85DB44D40F99E91088D5E4740EF39B01C21B34D40501BD5E9405C4740EF39B01C21B34D40
32450	11419	46.713023999999997	46.728762000000003	59.171563999999996	59.162233000000001	Школьная	0103000020E61000000100000005000000ADA1D45E445B47407EAA0A0DC4944D40ADA1D45E445B4740E19524CFF5954D40A648BE12485D4740E19524CFF5954D40A648BE12485D47407EAA0A0DC4944D40ADA1D45E445B47407EAA0A0DC4944D40
32489	11270	46.760570999999999	46.781106999999999	58.992446000000001	58.985639999999997	Школьная	0103000020E610000001000000050000009CA4F9635A61474091D09673297E4D409CA4F9635A614740E4857478087F4D409DD66D50FB634740E4857478087F4D409DD66D50FB63474091D09673297E4D409CA4F9635A61474091D09673297E4D40
32514	11285	46.604273999999997	46.619590000000002	59.050725999999997	59.044237000000003	Молодежная	0103000020E610000001000000050000005BE9B5D9584D4740F722DA8EA9854D405BE9B5D9584D4740488787307E864D40DE76A1B94E4F4740488787307E864D40DE76A1B94E4F4740F722DA8EA9854D405BE9B5D9584D4740F722DA8EA9854D40
32293	11578	46.656457000000003	46.678789000000002	59.331588000000004	59.320270999999998	Центральная	0103000020E610000001000000050000007A1D71C806544740B96DDFA3FEA84D407A1D71C8065447407FDFBF7971AA4D4039F1D58EE25647407FDFBF7971AA4D4039F1D58EE2564740B96DDFA3FEA84D407A1D71C806544740B96DDFA3FEA84D40
32212	508	46.708092000000001	46.715045000000003	59.047884000000003	59.044657999999998	Молодежная	0103000020E61000000100000005000000954737C2A25A47409CC0745AB7854D40954737C2A25A474037001B1021864D408C153598865B474037001B1021864D408C153598865B47409CC0745AB7854D40954737C2A25A47409CC0745AB7854D40
32286	10756	46.688651999999998	46.709843999999997	58.827995999999999	58.817942000000002	Школьная	0103000020E610000001000000050000009929ADBF255847402E03CE52B2684D409929ADBF25584740029CDEC5FB694D4083A10E2BDC5A4740029CDEC5FB694D4083A10E2BDC5A47402E03CE52B2684D409929ADBF255847402E03CE52B2684D40
32449	10813	46.547041999999998	46.573658999999999	58.763503999999998	58.754168999999997	Школьная	0103000020E61000000100000005000000EBC4E5780546474019541B9C88604D40EBC4E57805464740BE2EC37FBA614D402D077AA86D494740BE2EC37FBA614D402D077AA86D49474019541B9C88604D40EBC4E5780546474019541B9C88604D40
32380	10694	46.766078	46.791662000000002	58.883862999999998	58.873783000000003	Чичерина	0103000020E61000000100000005000000B1170AD80E6247408066101FD86F4D40B1170AD80E6247407D923B6C22714D4034BE2F2E556547407D923B6C22714D4034BE2F2E556547408066101FD86F4D40B1170AD80E6247408066101FD86F4D40
32157	11437	46.857157999999998	46.874944999999997	59.211773000000001	59.200454000000001	Центральная	0103000020E610000001000000050000009CC0745AB76D47401B2D077AA8994D409CC0745AB76D47408196AE601B9B4D403C66A032FE6F47408196AE601B9B4D403C66A032FE6F47401B2D077AA8994D409CC0745AB76D47401B2D077AA8994D40
32296	10945	46.493474999999997	46.508037000000002	58.890084999999999	58.885421000000001	Новая	0103000020E61000000100000005000000613255302A3F47408718AF7955714D40613255302A3F474080D4264EEE714D4038143E5B0741474080D4264EEE714D4038143E5B074147408718AF7955714D40613255302A3F47408718AF7955714D40
32485	10848	46.277403999999997	46.317118000000001	58.791555000000002	58.777338999999998	Центральная	0103000020E61000000100000005000000C9E369F981234740E27327D87F634D40C9E369F9812347401EFE9AAC51654D40897C9752972847401EFE9AAC51654D40897C975297284740E27327D87F634D40C9E369F981234740E27327D87F634D40
32292	10551	46.728430000000003	46.774422999999999	58.943868000000002	58.918728999999999	Советская	0103000020E6100000010000000500000070B6B9313D5D4740827170E998754D4070B6B9313D5D4740D7DEA7AAD0784D409622F94A20634740D7DEA7AAD0784D409622F94A20634740827170E998754D4070B6B9313D5D4740827170E998754D40
32547	11485	46.674242999999997	46.712583000000002	59.237470999999999	59.227251000000003	Школьная	0103000020E61000000100000005000000494739984D564740DD7D8E8F169D4D40494739984D564740CC5F2173659E4D40C15774EB355B4740CC5F2173659E4D40C15774EB355B4740DD7D8E8F169D4D40494739984D564740DD7D8E8F169D4D40
32560	10672	46.816752000000001	46.836281	58.943868000000002	58.934874999999998	Заводская	0103000020E61000000100000005000000A7785C548B6847408B6CE7FBA9774D40A7785C548B684740D7DEA7AAD0784D4012A27C410B6B4740D7DEA7AAD0784D4012A27C410B6B47408B6CE7FBA9774D40A7785C548B6847408B6CE7FBA9774D40
32526	8341	41.280299999999997	41.320922000000003	58.662599999999998	58.643897000000003	Центральная	0103000020E61000000100000005000000CE88D2DEE0A344400B7F86376B524D40CE88D2DEE0A34440302AA913D0544D409148DBF813A94440302AA913D0544D409148DBF813A944400B7F86376B524D40CE88D2DEE0A344400B7F86376B524D40
32423	53339	40.929696999999997	42.231895000000002	59.023015999999998	58.241695999999997	б-р Строителей	0103000020E610000001000000050000003B18B14F0077444079C9FFE4EF1E4D403B18B14F0077444072A43330F2824D408F8D40BCAE1D454072A43330F2824D408F8D40BCAE1D454079C9FFE4EF1E4D403B18B14F0077444079C9FFE4EF1E4D40
32264	7855	41.538547999999999	41.568587999999998	58.732123999999999	58.721715000000003	Советская	0103000020E61000000100000005000000C1A90F24EFC444402E043928615C4D40C1A90F24EFC44440F04E3E3DB65D4D40F372D87DC7C84440F04E3E3DB65D4D40F372D87DC7C844402E043928615C4D40C1A90F24EFC444402E043928615C4D40
32614	53361	41.665326999999998	41.700100999999997	58.471088999999999	58.420479999999998	Железнодорожная	0103000020E61000000100000005000000A912656F29D54440A04FE449D2354D40A912656F29D54440AF40F4A44C3C4D40CD72D9E89CD94440AF40F4A44C3C4D40CD72D9E89CD94440A04FE449D2354D40A912656F29D54440A04FE449D2354D40
32271	8971	41.486705999999998	41.504807	58.352580000000003	58.342165999999999	Молодежная	0103000020E610000001000000050000002C62D8614CBE4440CDE67118CC2B4D402C62D8614CBE4440A29C6857212D4D405CE509849DC04440A29C6857212D4D405CE509849DC04440CDE67118CC2B4D402C62D8614CBE4440CDE67118CC2B4D40
32534	8942	41.812928999999997	41.854503000000001	58.589934999999997	58.577734	Троицкая	0103000020E61000000100000005000000287CB60E0EE84440C5E40D30F3494D40287CB60E0EE8444004E275FD824B4D40BDAAB35A60ED444004E275FD824B4D40BDAAB35A60ED4440C5E40D30F3494D40287CB60E0EE84440C5E40D30F3494D40
32430	33156	41.21078	41.248635	58.321210999999998	58.309015000000002	Клубная	0103000020E610000001000000050000005053CBD6FA9A44409A7CB3CD8D274D405053CBD6FA9A4440C70E2A711D294D400BD28C45D39F4440C70E2A711D294D400BD28C45D39F44409A7CB3CD8D274D405053CBD6FA9A44409A7CB3CD8D274D40
32366	8820	41.339615999999999	41.363726999999997	58.559407	58.548825000000001	Почтовая	0103000020E6100000010000000500000063997E8978AB4440151DC9E53F464D4063997E8978AB4440A51309A69A474D400AD6389B8EAE4440A51309A69A474D400AD6389B8EAE4440151DC9E53F464D4063997E8978AB4440151DC9E53F464D40
32203	8807	41.409658	41.461041000000002	58.471592999999999	58.461483000000001	Сплавная	0103000020E61000000100000005000000BB4560AC6FB444407A54FCDF113B4D40BB4560AC6FB44440E202D0285D3C4D40BD8E386403BB4440E202D0285D3C4D40BD8E386403BB44407A54FCDF113B4D40BB4560AC6FB444407A54FCDF113B4D40
32500	8764	41.384360999999998	41.402982999999999	58.442340999999999	58.433410000000002	Верхняя	0103000020E61000000100000005000000CE6DC2BD32B1444033E197FA79374D40CE6DC2BD32B14440085740A19E384D4007EC6AF294B34440085740A19E384D4007EC6AF294B3444033E197FA79374D40CE6DC2BD32B1444033E197FA79374D40
32364	8375	41.422989000000001	41.444234000000002	58.489345	58.478929000000001	Черемушки	0103000020E61000000100000005000000ACC8E88024B64440910DA48B4D3D4D40ACC8E88024B6444006BB61DBA23E4D40B9E2E2A8DCB8444006BB61DBA23E4D40B9E2E2A8DCB84440910DA48B4D3D4D40ACC8E88024B64440910DA48B4D3D4D40
32200	8671	41.905653000000001	41.931561000000002	58.717001000000003	58.710555999999997	Задняя	0103000020E610000001000000050000001C430070ECF3444000FDBE7FF35A4D401C430070ECF34440831953B0C65B4D40529D0E643DF74440831953B0C65B4D40529D0E643DF7444000FDBE7FF35A4D401C430070ECF3444000FDBE7FF35A4D40
32368	8607	41.400754999999997	41.420878000000002	58.854584000000003	58.844524	Дъяконовский	0103000020E61000000100000005000000AF5A99F04BB34440F357C85C196C4D40AF5A99F04BB34440AAD72D02636D4D408ECD8E54DFB54440AAD72D02636D4D408ECD8E54DFB54440F357C85C196C4D40AF5A99F04BB34440F357C85C196C4D40
32476	8458	41.478513	41.497737000000001	58.53302	58.527997999999997	Новая	0103000020E61000000100000005000000FDDAFAE93FBD44403C2D3F7095434D40FDDAFAE93FBD4440950ED6FF39444D402C8194D8B5BF4440950ED6FF39444D402C8194D8B5BF44403C2D3F7095434D40FDDAFAE93FBD44403C2D3F7095434D40
32477	8511	41.082680000000003	41.102065000000003	58.490411999999999	58.476252000000002	Советская	0103000020E6100000010000000500000043041C42958A4440CA5356D3F53C4D4043041C42958A444071C806D2C53E4D407B884677108D444071C806D2C53E4D407B884677108D4440CA5356D3F53C4D4043041C42958A4440CA5356D3F53C4D40
32197	8270	41.323051	41.342958000000003	58.503914000000002	58.497453	Центральная	0103000020E6100000010000000500000055F833BC59A944400726378AAC3F4D4055F833BC59A944408FFF024180404D4067F3380CE6AB44408FFF024180404D4067F3380CE6AB44400726378AAC3F4D4055F833BC59A944400726378AAC3F4D40
32437	8164	41.586123000000001	41.641072999999999	58.380566000000002	58.346274999999999	Молодежная	0103000020E610000001000000050000007A37161406CB444011363CBD522C4D407A37161406CB44401AFCFD62B6304D409FAC18AE0ED244401AFCFD62B6304D409FAC18AE0ED2444011363CBD522C4D407A37161406CB444011363CBD522C4D40
32429	8030	41.587173999999997	41.615595999999996	58.490985999999999	58.481648	Главная	0103000020E61000000100000005000000DF87838428CB4440871744A4A63D4D40DF87838428CB44409D6516A1D83E4D4032C687D9CBCE44409D6516A1D83E4D4032C687D9CBCE4440871744A4A63D4D40DF87838428CB4440871744A4A63D4D40
32594	8055	41.576286000000003	41.598564000000003	58.515413000000002	58.508051000000002	Гагаринская	0103000020E61000000100000005000000439259BDC3C944409DD9AED007414D40439259BDC3C9444075779D0DF9414D400F48C2BE9DCC444075779D0DF9414D400F48C2BE9DCC44409DD9AED007414D40439259BDC3C944409DD9AED007414D40
32258	7199	43.107787999999999	43.131718999999997	58.035926000000003	58.024746	Садовая	0103000020E610000001000000050000005C7347FFCB8D4540795A7EE02A034D405C7347FFCB8D4540BE89213999044D4083A10E2BDC904540BE89213999044D4083A10E2BDC904540795A7EE02A034D405C7347FFCB8D4540795A7EE02A034D40
32510	7315	42.944491999999997	42.968890000000002	58.434596999999997	58.426149000000002	Центральная	0103000020E61000000100000005000000B4AA251DE57845408F1CE90C8C364D40B4AA251DE578454048F8DEDFA0374D40F2B56796047C454048F8DEDFA0374D40F2B56796047C45408F1CE90C8C364D40B4AA251DE57845408F1CE90C8C364D40
32148	7622	42.91677	42.949379	58.251192000000003	58.231096999999998	Советская	0103000020E610000001000000050000001AFA27B858754540139A2496941D4D401AFA27B8587545402882380F27204D402D414640857945402882380F27204D402D41464085794540139A2496941D4D401AFA27B858754540139A2496941D4D40
32173	7509	43.034126000000001	43.054563000000002	58.128495000000001	58.119911000000002	Школьная	0103000020E61000000100000005000000BEF8A23D5E84454020B75F3E590F4D40BEF8A23D5E8445408A592F8672104D402C499EEBFB8645408A592F8672104D402C499EEBFB86454020B75F3E590F4D40BEF8A23D5E84454020B75F3E590F4D40
32561	7108	42.981718000000001	43.034961000000003	58.410732000000003	58.386676000000001	Лебедева	0103000020E6100000010000000500000080F277EFA87D4540F51263997E314D4080F277EFA87D4540D9B5BDDD92344D4057D11F9A79844540D9B5BDDD92344D4057D11F9A79844540F51263997E314D4080F277EFA87D4540F51263997E314D40
32359	7108	42.981718000000001	43.034961000000003	58.410732000000003	58.386676000000001	Кирова	0103000020E6100000010000000500000080F277EFA87D4540F51263997E314D4080F277EFA87D4540D9B5BDDD92344D4057D11F9A79844540D9B5BDDD92344D4057D11F9A79844540F51263997E314D4080F277EFA87D4540F51263997E314D40
35225	54182	35.210509999999999	35.261102999999999	54.753607000000002	54.728544999999997	Билибина	0103000020E6100000010000000500000090BDDEFDF19A414008556AF6405D4B4090BDDEFDF19A4140B284B53176604B4099F1B6D26BA14140B284B53176604B4099F1B6D26BA1414008556AF6405D4B4090BDDEFDF19A414008556AF6405D4B40
35421	54204	36.144298999999997	36.170377000000002	54.503318	54.488588	Центральная	0103000020E6100000010000000500000039ECBE6378124240E99B340D8A3E4B4039ECBE63781242407BBE66B96C404B40CC7EDDE9CE1542407BBE66B96C404B40CC7EDDE9CE154240E99B340D8A3E4B4039ECBE6378124240E99B340D8A3E4B40
35522	25542	36.466344999999997	36.487634999999997	55.146718	55.134954999999998	Мира	0103000020E6100000010000000500000099D36531B13B424041B7973446914B4099D36531B13B424005DEC9A7C7924B4046B1DCD26A3E424005DEC9A7C7924B4046B1DCD26A3E424041B7973446914B4099D36531B13B424041B7973446914B40
35491	54197	37.144590999999998	37.198293	54.748764000000001	54.714115	Пушкина	0103000020E61000000100000005000000E12538F581924240A14ACD1E685B4B40E12538F5819242400936AE7FD75F4B404B033FAA619942400936AE7FD75F4B404B033FAA61994240A14ACD1E685B4B40E12538F581924240A14ACD1E685B4B40
35403	54197	37.144590999999998	37.198293	54.748764000000001	54.714115	Луначарского	0103000020E61000000100000005000000E12538F581924240A14ACD1E685B4B40E12538F5819242400936AE7FD75F4B404B033FAA619942400936AE7FD75F4B404B033FAA61994240A14ACD1E685B4B40E12538F581924240A14ACD1E685B4B40
35239	54180	33.994002000000002	34.052509000000001	54.427190000000003	54.400646999999999	пер.Пионерский	0103000020E610000001000000050000004D1421753BFF4040C91EA16648334B404D1421753BFF4040D1967329AE364B4072DF6A9DB8064140D1967329AE364B4072DF6A9DB8064140C91EA16648334B404D1421753BFF4040C91EA16648334B40
35216	54180	33.994002000000002	34.052509000000001	54.427190000000003	54.400646999999999	 Советская	0103000020E610000001000000050000004D1421753BFF4040C91EA16648334B404D1421753BFF4040D1967329AE364B4072DF6A9DB8064140D1967329AE364B4072DF6A9DB8064140C91EA16648334B404D1421753BFF4040C91EA16648334B40
4128	1634	36.604945999999998	36.622445999999997	55.120773999999997	55.117266999999998	улица Энгельса	0103000020E610000001000000050000004AECDADE6E4D424034F3E49A028F4B404AECDADE6E4D4240821ABE85758F4B4054C37E4FAC4F4240821ABE85758F4B4054C37E4FAC4F424034F3E49A028F4B404AECDADE6E4D424034F3E49A028F4B40
10007	1634	36.606014999999999	36.619014	55.100808999999998	55.098278999999998	улица Победы	0103000020E6100000010000000500000056F146E6914D424019710168948C4B4056F146E6914D42403C122F4FE78C4B4011E2CAD93B4F42403C122F4FE78C4B4011E2CAD93B4F424019710168948C4B4056F146E6914D424019710168948C4B40
4210	1634	36.612340000000003	36.625500000000002	55.123682000000002	55.094138000000001	улица Курчатова	0103000020E610000001000000050000002E043928614E4240CAA7C7B60C8C4B402E043928614E42404C8DD0CFD48F4B40F2D24D62105042404C8DD0CFD48F4B40F2D24D6210504240CAA7C7B60C8C4B402E043928614E4240CAA7C7B60C8C4B40
4047	1634	36.583179999999999	36.596772000000001	55.122272000000002	55.117277999999999	улица Гагарина	0103000020E6100000010000000500000034D769A4A54A424028452BF7028F4B4034D769A4A54A4240B79BE09BA68F4B4092955F06634C4240B79BE09BA68F4B4092955F06634C424028452BF7028F4B4034D769A4A54A424028452BF7028F4B40
4110	1634	36.586880999999998	36.625922000000003	55.125638000000002	55.112169999999999	проспект Маркса	0103000020E6100000010000000500000067D2A6EA1E4B4240D1CB28965B8E4B4067D2A6EA1E4B42404391EEE714904B4068EC4B361E5042404391EEE714904B4068EC4B361E504240D1CB28965B8E4B4067D2A6EA1E4B4240D1CB28965B8E4B40
3918	1634	36.572868	36.616247000000001	55.121226999999998	55.089047000000001	проспект Ленина	0103000020E61000000100000005000000647616BD53494240496760E4658B4B40647616BD534942403332C85D848F4B400AA1832EE14E42403332C85D848F4B400AA1832EE14E4240496760E4658B4B40647616BD53494240496760E4658B4B40
35453	1634	36.597436999999999	36.600123000000004	55.139422000000003	55.137075000000003	квартал Студенческий городок	0103000020E61000000100000005000000CE35CCD0784C4240B30C71AC8B914B40CE35CCD0784C4240E52B8194D8914B40E94999D4D04C4240E52B8194D8914B40E94999D4D04C4240B30C71AC8B914B40CE35CCD0784C4240B30C71AC8B914B40
35387	1634	36.604945999999998	36.622445999999997	55.120773999999997	55.117266999999998	Энгельса	0103000020E610000001000000050000004AECDADE6E4D424034F3E49A028F4B404AECDADE6E4D4240821ABE85758F4B4054C37E4FAC4F4240821ABE85758F4B4054C37E4FAC4F424034F3E49A028F4B404AECDADE6E4D424034F3E49A028F4B40
3928	1634	36.611719999999998	36.612645000000001	55.094658000000003	55.094565000000003	Треугольная площадь	0103000020E61000000100000005000000912749D74C4E4240522CB7B41A8C4B40912749D74C4E42400327DBC01D8C4B406A87BF266B4E42400327DBC01D8C4B406A87BF266B4E4240522CB7B41A8C4B40912749D74C4E4240522CB7B41A8C4B40
4298	1634	36.584761	36.602009000000002	55.099299000000002	55.092010000000002	Пионерский проезд	0103000020E61000000100000005000000F67CCD72D94A4240D673D2FBC68B4B40F67CCD72D94A424044C362D4B58C4B40E77283A10E4D424044C362D4B58C4B40E77283A10E4D4240D673D2FBC68B4B40F67CCD72D94A4240D673D2FBC68B4B40
35415	1634	36.601326	36.620362	55.104615000000003	55.100942000000003	Мира	0103000020E61000000100000005000000041E1840F84C42407C65DEAAEB8C4B40041E1840F84C4240E5D53906648D4B4030D7A205684F4240E5D53906648D4B4030D7A205684F42407C65DEAAEB8C4B40041E1840F84C42407C65DEAAEB8C4B40
35418	1634	36.585704999999997	36.595998999999999	55.104342000000003	55.099299000000002	Любого	0103000020E61000000100000005000000450DA661F84A424044C362D4B58C4B40450DA661F84A4240B4CC22145B8D4B406FB9FAB1494C4240B4CC22145B8D4B406FB9FAB1494C424044C362D4B58C4B40450DA661F84A424044C362D4B58C4B40
35433	1634	36.612340000000003	36.625500000000002	55.123682000000002	55.094138000000001	Курчатова	0103000020E610000001000000050000002E043928614E4240CAA7C7B60C8C4B402E043928614E42404C8DD0CFD48F4B40F2D24D62105042404C8DD0CFD48F4B40F2D24D6210504240CAA7C7B60C8C4B402E043928614E4240CAA7C7B60C8C4B40
35410	1634	36.606644000000003	36.610515999999997	55.095379000000001	55.092725999999999	Кончаловского	0103000020E610000001000000050000004628B682A64D424094BE1072DE8B4B404628B682A64D4240D3DC0A61358C4B40A5D76663254E4240D3DC0A61358C4B40A5D76663254E424094BE1072DE8B4B404628B682A64D424094BE1072DE8B4B40
35369	1634	36.591318999999999	36.596232999999998	55.110671000000004	55.10839	Комарова	0103000020E6100000010000000500000070404B57B04B4240529B38B9DF8D4B4070404B57B04B4240CDCEA2772A8E4B40E2E5E95C514C4240CDCEA2772A8E4B40E2E5E95C514C4240529B38B9DF8D4B4070404B57B04B4240529B38B9DF8D4B40
4161	1634	36.616157000000001	36.619014	55.124861000000003	55.118260999999997	Калужская улица	0103000020E61000000100000005000000CA198A3BDE4E424035B22B2D238F4B40CA198A3BDE4E4240DFC5FB71FB8F4B4011E2CAD93B4F4240DFC5FB71FB8F4B4011E2CAD93B4F424035B22B2D238F4B40CA198A3BDE4E424035B22B2D238F4B40
426	1634	36.601533000000003	36.612861000000002	55.119115999999998	55.114182999999997	Звездная улица	0103000020E610000001000000050000007E3B8908FF4C42402C616D8C9D8E4B407E3B8908FF4C424015376E313F8F4B4037FFAF3A724E424015376E313F8F4B4037FFAF3A724E42402C616D8C9D8E4B407E3B8908FF4C42402C616D8C9D8E4B40
35412	1634	36.595028999999997	36.606158999999998	55.113261000000001	55.103949999999998	Гурьянова	0103000020E61000000100000005000000F69507E9294C4240A835CD3B4E8D4B40F69507E9294C4240C57421567F8E4B4089963C9E964D4240C57421567F8E4B4089963C9E964D4240A835CD3B4E8D4B40F69507E9294C4240A835CD3B4E8D4B40
35352	1634	36.625993999999999	36.628132000000001	55.096245000000003	55.092716000000003	Гастелло	0103000020E6100000010000000500000001BF46922050424071E82D1EDE8B4B4001BF469220504240A7B393C1518C4B4019C91EA166504240A7B393C1518C4B4019C91EA16650424071E82D1EDE8B4B4001BF46922050424071E82D1EDE8B4B40
35357	1634	36.583179999999999	36.596772000000001	55.122272000000002	55.117277999999999	Гагарина	0103000020E6100000010000000500000034D769A4A54A424028452BF7028F4B4034D769A4A54A4240B79BE09BA68F4B4092955F06634C4240B79BE09BA68F4B4092955F06634C424028452BF7028F4B4034D769A4A54A424028452BF7028F4B40
35288	10625	36.412824000000001	36.510182999999998	55.046357	54.990043999999997	площадь Жукова	0103000020E610000001000000050000008080B56AD7344240EECC04C3B97E4B408080B56AD73442406878B306EF854B40D2FC31AD4D4142406878B306EF854B40D2FC31AD4D414240EECC04C3B97E4B408080B56AD7344240EECC04C3B97E4B40
35212	10625	36.412824000000001	36.510182999999998	55.046357	54.990043999999997	пл.Жукова	0103000020E610000001000000050000008080B56AD7344240EECC04C3B97E4B408080B56AD73442406878B306EF854B40D2FC31AD4D4142406878B306EF854B40D2FC31AD4D414240EECC04C3B97E4B408080B56AD7344240EECC04C3B97E4B40
35349	10625	36.492728999999997	36.493960000000001	55.011304000000003	55.010091000000003	Школьная	0103000020E6100000010000000500000038656EBE113F4240F27D71A94A814B4038656EBE113F42403128D36872814B401EC4CE143A3F42403128D36872814B401EC4CE143A3F4240F27D71A94A814B4038656EBE113F4240F27D71A94A814B40
35343	10625	36.438327000000001	36.461880999999998	55.003601000000003	54.997998000000003	Российских Газовиков	0103000020E6100000010000000500000016FA60191B38424099BC0166BE7F4B4016FA60191B384240D09D60FF75804B4067D2A6EA1E3B4240D09D60FF75804B4067D2A6EA1E3B424099BC0166BE7F4B4016FA60191B38424099BC0166BE7F4B40
35370	10625	36.431724000000003	36.446618000000001	55.006084000000001	54.990054000000001	Радищева	0103000020E61000000100000005000000FC7266BB4237424012A3E716BA7E4B40FC7266BB42374240B2834A5CC7804B4008E753C72A394240B2834A5CC7804B4008E753C72A39424012A3E716BA7E4B40FC7266BB4237424012A3E716BA7E4B40
35417	10625	36.467225999999997	36.498441999999997	55.019852	55.009780999999997	Московская	0103000020E61000000100000005000000A2EBC20FCE3B4240A38FF98040814B40A2EBC20FCE3B42404E61A5828A824B40F6798CF2CC3F42404E61A5828A824B40F6798CF2CC3F4240A38FF98040814B40A2EBC20FCE3B4240A38FF98040814B40
35346	10625	36.462788000000003	36.476801999999999	55.01484	55.009574000000001	Кутузова	0103000020E610000001000000050000009A7D1EA33C3B42402A7288B839814B409A7D1EA33C3B42401956F146E6814B406D5512D9073D42401956F146E6814B406D5512D9073D42402A7288B839814B409A7D1EA33C3B42402A7288B839814B40
35354	10625	36.470647999999997	36.474142999999998	55.007845000000003	54.996685999999997	Кирова	0103000020E61000000100000005000000C2F693313E3C4240C6302768937F4B40C2F693313E3C4240F437A11001814B404C50C3B7B03C4240F437A11001814B404C50C3B7B03C4240C6302768937F4B40C2F693313E3C4240C6302768937F4B40
35439	10625	36.447884999999999	36.466327	55.009878999999998	55.001742	Аузина	0103000020E610000001000000050000003AAFB14B54394240CB83F41439804B403AAFB14B5439424066F50EB743814B40F31E679AB03B424066F50EB743814B40F31E679AB03B4240CB83F41439804B403AAFB14B54394240CB83F41439804B40
35386	10625	36.431724000000003	36.446618000000001	55.006084000000001	54.990054000000001	 Радищева	0103000020E61000000100000005000000FC7266BB4237424012A3E716BA7E4B40FC7266BB42374240B2834A5CC7804B4008E753C72A394240B2834A5CC7804B4008E753C72A39424012A3E716BA7E4B40FC7266BB4237424012A3E716BA7E4B40
35235	54185	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Щербакова	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35256	54185	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Соколова	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35241	54185	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Салтыкова-Щедрина	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35259	54185	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Карла Маркса	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35484	54185	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Дзержинского	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35524	25613	36.671188000000001	36.687483999999998	55.254404999999998	55.244393000000002	Армейская	0103000020E61000000100000005000000DCBB067DE9554240882F1345489F4B40DCBB067DE95542402D78D15790A04B40FA42C879FF5742402D78D15790A04B40FA42C879FF574240882F1345489F4B40DCBB067DE9554240882F1345489F4B40
35226	54183	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	Орджоникидзе	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
35257	54187	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	Чкалова	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
35447	54187	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	Суворова	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
35275	36210	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Пролетарская	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35230	36210	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Ленина	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
74926	60378	36.263263000000002	36.265779000000002	54.600780999999998	54.597391000000002	Центральная	0103000020E61000000100000005000000999F1B9AB22142405EF6EB4E774C4B40999F1B9AB221424072874D64E64C4B40577BD80B0522424072874D64E64C4B40577BD80B052242405EF6EB4E774C4B40999F1B9AB22142405EF6EB4E774C4B40
15642	40	36.263263000000002	36.265779000000002	54.600780999999998	54.597391000000002	улица Центральная	0103000020E61000000100000005000000999F1B9AB22142405EF6EB4E774C4B40999F1B9AB221424072874D64E64C4B40577BD80B0522424072874D64E64C4B40577BD80B052242405EF6EB4E774C4B40999F1B9AB22142405EF6EB4E774C4B40
1163	40	36.292727999999997	36.311368000000002	54.522683000000001	54.520398999999998	улица Хрустальная	0103000020E61000000100000005000000CE4F711C7825424080EF366F9C424B40CE4F711C782542406C96CB46E7424B40AE8218E8DA2742406C96CB46E7424B40AE8218E8DA27424080EF366F9C424B40CE4F711C7825424080EF366F9C424B40
657	40	36.259895	36.264898000000002	54.540247000000001	54.521020999999998	улица Телевизионная	0103000020E610000001000000050000006CB2463D44214240BDC3EDD0B0424B406CB2463D442142408D614ED026454B404E637B2DE82142408D614ED026454B404E637B2DE8214240BDC3EDD0B0424B406CB2463D44214240BDC3EDD0B0424B40
1067	40	36.235244999999999	36.278463000000002	54.519222999999997	54.514180000000003	улица Суворова	0103000020E6100000010000000500000015C616821C1E4240EF2076A6D0414B4015C616821C1E42405E2A36E675424B40B212F3ACA42342405E2A36E675424B40B212F3ACA4234240EF2076A6D0414B4015C616821C1E4240EF2076A6D0414B40
748	40	36.244622999999997	36.254109	54.521752999999997	54.508859000000001	улица Рылеева	0103000020E61000000100000005000000B96C74CE4F1F42403CA3AD4A22414B40B96C74CE4F1F424081CB63CDC8424B40444FCAA48620424081CB63CDC8424B40444FCAA4862042403CA3AD4A22414B40B96C74CE4F1F42403CA3AD4A22414B40
891	40	36.295431999999998	36.305923999999997	54.566766999999999	54.555183	улица Новослободская	0103000020E610000001000000050000008F183DB7D0254240C8258E3C10474B408F183DB7D0254240DCB930D28B484B40DF87838428274240DCB930D28B484B40DF87838428274240C8258E3C10474B408F183DB7D0254240C8258E3C10474B40
427	40	36.245565999999997	36.254451000000003	54.583274000000003	54.577157999999997	улица Кибальчича	0103000020E610000001000000050000003881E9B46E1F4240F84F3750E0494B403881E9B46E1F4240B64DF1B8A84A4B409EB7B1D991204240B64DF1B8A84A4B409EB7B1D991204240F84F3750E0494B403881E9B46E1F4240F84F3750E0494B40
35385	40	36.255088999999998	36.256616000000001	54.594068	54.591532999999998	улица Звездная	0103000020E61000000100000005000000E048A0C1A62042409CC0745AB74B4B40E048A0C1A6204240D1CC936B0A4C4B40AFD007CBD8204240D1CC936B0A4C4B40AFD007CBD82042409CC0745AB74B4B40E048A0C1A62042409CC0745AB74B4B40
1287	40	36.328786000000001	36.330151999999998	54.545585000000003	54.543376000000002	улица Дубрава	0103000020E61000000100000005000000FBB0DEA8152A424035B742588D454B40FBB0DEA8152A42401618B2BAD5454B40C05AB56B422A42401618B2BAD5454B40C05AB56B422A424035B742588D454B40FBB0DEA8152A424035B742588D454B40
1394	40	36.260865000000003	36.280071	54.598011	54.594965000000002	улица Дорожная	0103000020E61000000100000005000000E5D5390664214240E0A128D0274C4B40E5D5390664214240FAD2DB9F8B4C4B406DC7D45DD9234240FAD2DB9F8B4C4B406DC7D45DD9234240E0A128D0274C4B40E5D5390664214240E0A128D0274C4B40
537	40	36.22504	36.243994000000001	54.568765999999997	54.564663000000003	улица Гурьянова	0103000020E610000001000000050000005B25581CCE1C424071218FE046484B405B25581CCE1C4240D2890453CD484B40CA3505323B1F4240D2890453CD484B40CA3505323B1F424071218FE046484B405B25581CCE1C424071218FE046484B40
1033	40	36.270772999999998	36.275795000000002	54.526560000000003	54.519046000000003	улица Веры Андриановой	0103000020E61000000100000005000000E5D18DB0A8224240508F6D1970424B40E5D18DB0A8224240DEB06D5166434B403EB324404D234240DEB06D5166434B403EB324404D234240508F6D1970424B40E5D18DB0A8224240508F6D1970424B40
986	40	36.258825999999999	36.274527999999997	54.531753000000002	54.529302999999999	улица Билибина	0103000020E6100000010000000500000060ADDA35212142405C566133C0434B4060ADDA35212142406346787B10444B400BEBC6BB232342406346787B10444B400BEBC6BB232342405C566133C0434B4060ADDA35212142405C566133C0434B40
35586	40	36.085127	36.388956	54.610413000000001	54.457101999999999	площадь Вокзальная	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
955	40	36.291505999999998	36.301530999999997	54.554243	54.553553999999998	переулок Малинники	0103000020E610000001000000050000003C4B901150254240F54883DBDA464B403C4B901150254240BA84436FF1464B4076DD5B9198264240BA84436FF1464B4076DD5B9198264240F54883DBDA464B403C4B901150254240F54883DBDA464B40
861	40	36.312347000000003	36.317763999999997	54.572972999999998	54.571731	переулок Дорожный	0103000020E610000001000000050000007A008BFCFA274240008E3D7B2E494B407A008BFCFA274240D93EE42D57494B404EECA17DAC284240D93EE42D57494B404EECA17DAC284240008E3D7B2E494B407A008BFCFA274240008E3D7B2E494B40
35413	40	36.281787000000001	36.286771999999999	54.517718000000002	54.515988	маршала Жукова	0103000020E610000001000000050000000FB8AE9811244240719010E50B424B400FB8AE981124424078465B9544424B404AB4E4F1B424424078465B9544424B404AB4E4F1B4244240719010E50B424B400FB8AE9811244240719010E50B424B40
35309	40	36.257002	36.267448999999999	54.504477999999999	54.502637999999997	вилонов	0103000020E61000000100000005000000D8800871E520424009DD257156404B40D8800871E520424097C62FBC92404B40882CD2C43B22424097C62FBC92404B40882CD2C43B22424009DD257156404B40D8800871E520424009DD257156404B40
490	40	36.265177000000001	36.270567	54.568379999999998	54.564861999999998	бульвар Моторостроителей	0103000020E610000001000000050000006153E751F12142406760E4654D484B406153E751F1214240A9D903ADC0484B403C3080F0A1224240A9D903ADC0484B403C3080F0A12242406760E4654D484B406153E751F12142406760E4654D484B40
35326	40	36.085127	36.388956	54.610413000000001	54.457101999999999	Школьная	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
35377	40	36.244793999999999	36.253093999999997	54.536841000000003	54.534308000000003	Широкая	0103000020E61000000100000005000000E620E868551F4240DFFE5C3464444B40E620E868551F42407313B534B7444B402B685A62652042407313B534B7444B402B685A6265204240DFFE5C3464444B40E620E868551F4240DFFE5C3464444B40
35427	40	36.263227000000001	36.277169000000001	54.518062999999998	54.516365	Чижевского	0103000020E610000001000000050000004C361E6CB121424047E6913F18424B404C361E6CB121424042226DE34F424B40863B17467A23424042226DE34F424B40863B17467A23424047E6913F18424B404C361E6CB121424047E6913F18424B40
35355	40	36.263263000000002	36.265779000000002	54.600780999999998	54.597391000000002	Центральная	0103000020E61000000100000005000000999F1B9AB22142405EF6EB4E774C4B40999F1B9AB221424072874D64E64C4B40577BD80B0522424072874D64E64C4B40577BD80B052242405EF6EB4E774C4B40999F1B9AB22142405EF6EB4E774C4B40
35414	40	36.292727999999997	36.311368000000002	54.522683000000001	54.520398999999998	Хрустальная	0103000020E61000000100000005000000CE4F711C7825424080EF366F9C424B40CE4F711C782542406C96CB46E7424B40AE8218E8DA2742406C96CB46E7424B40AE8218E8DA27424080EF366F9C424B40CE4F711C7825424080EF366F9C424B40
35366	40	36.273693000000002	36.282837999999998	54.516756999999998	54.500573000000003	Фридриха Энгельса	0103000020E6100000010000000500000073124A5F082342405C21ACC612404B4073124A5F08234240527DE71725424B4074081C0934244240527DE71725424B4074081C09342442405C21ACC612404B4073124A5F082342405C21ACC612404B40
35437	40	36.342342000000002	36.342700999999998	54.516323	54.514541000000001	Турынинская	0103000020E610000001000000050000000C06D7DCD12B4240BFB9BF7ADC414B400C06D7DCD12B424018963FDF16424B403BA759A0DD2B424018963FDF16424B403BA759A0DD2B4240BFB9BF7ADC414B400C06D7DCD12B4240BFB9BF7ADC414B40
35	40	36.262841000000002	36.296528000000002	54.513103000000001	54.509825999999997	Тульская улица	0103000020E6100000010000000500000023861DC6A4214240435376FA41414B4023861DC6A4214240603DEE5BAD414B40952C27A1F4254240603DEE5BAD414B40952C27A1F4254240435376FA41414B4023861DC6A4214240435376FA41414B40
35396	40	36.262841000000002	36.296528000000002	54.513103000000001	54.509825999999997	Тульская	0103000020E6100000010000000500000023861DC6A4214240435376FA41414B4023861DC6A4214240603DEE5BAD414B40952C27A1F4254240603DEE5BAD414B40952C27A1F4254240435376FA41414B4023861DC6A4214240435376FA41414B40
35364	40	36.314718999999997	36.314915999999997	54.515680000000003	54.514074999999998	Трудовая	0103000020E61000000100000005000000043752B6482842407958A835CD414B40043752B648284240C4995FCD01424B405A7EE02A4F284240C4995FCD01424B405A7EE02A4F2842407958A835CD414B40043752B6482842407958A835CD414B40
897	40	36.287194	36.312247999999997	54.574266999999999	54.548017999999999	Тарутинская улица	0103000020E61000000100000005000000C0CDE2C5C224424046CF2D7425464B40C0CDE2C5C22442400516C09481494B40E61E12BEF72742400516C09481494B40E61E12BEF727424046CF2D7425464B40C0CDE2C5C224424046CF2D7425464B40
35380	40	36.287194	36.312247999999997	54.574266999999999	54.548017999999999	Тарутинская	0103000020E61000000100000005000000C0CDE2C5C224424046CF2D7425464B40C0CDE2C5C22442400516C09481494B40E61E12BEF72742400516C09481494B40E61E12BEF727424046CF2D7425464B40C0CDE2C5C224424046CF2D7425464B40
35408	40	36.235244999999999	36.278463000000002	54.519222999999997	54.514180000000003	Суворова	0103000020E6100000010000000500000015C616821C1E4240EF2076A6D0414B4015C616821C1E42405E2A36E675424B40B212F3ACA42342405E2A36E675424B40B212F3ACA4234240EF2076A6D0414B4015C616821C1E4240EF2076A6D0414B40
35429	40	36.273009999999999	36.280968999999999	54.512058000000003	54.499135000000003	Степана Разина	0103000020E6100000010000000500000090BDDEFDF1224240FDA4DAA7E33F4B4090BDDEFDF1224240DDD3D51D8B414B404C18CDCAF6234240DDD3D51D8B414B404C18CDCAF6234240FDA4DAA7E33F4B4090BDDEFDF1224240FDA4DAA7E33F4B40
35479	40	36.236170000000001	36.239601999999998	54.468150000000001	54.462529000000004	Секиотовская	0103000020E61000000100000005000000EE258DD13A1E4240CE397826343B4B40EE258DD13A1E4240ABCFD556EC3B4B4031074147AB1E4240ABCFD556EC3B4B4031074147AB1E4240CE397826343B4B40EE258DD13A1E4240CE397826343B4B40
35440	40	36.261825999999999	36.301873000000001	54.504306	54.499029999999998	Салтыкова-Щедрина	0103000020E610000001000000050000000A9FAD838321424087DC0C37E03F4B400A9FAD83832142409A9658198D404B40D04543C6A32642409A9658198D404B40D04543C6A326424087DC0C37E03F4B400A9FAD838321424087DC0C37E03F4B40
35324	40	36.085127	36.388956	54.610413000000001	54.457101999999999	С-Щедрина,	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
35295	40	36.085127	36.388956	54.610413000000001	54.457101999999999	С-Щедрина	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
35422	40	36.244622999999997	36.254109	54.521752999999997	54.508859000000001	Рылеева	0103000020E61000000100000005000000B96C74CE4F1F42403CA3AD4A22414B40B96C74CE4F1F424081CB63CDC8424B40444FCAA48620424081CB63CDC8424B40444FCAA4862042403CA3AD4A22414B40B96C74CE4F1F42403CA3AD4A22414B40
35232	40	36.085127	36.388956	54.610413000000001	54.457101999999999	Ромодановские Дворики	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
35426	40	36.248243000000002	36.267538999999999	54.528274000000003	54.526555000000002	Пухова	0103000020E61000000100000005000000003B376DC61F4240CC457C2766434B40003B376DC61F4240DFA9807B9E434B40C8B3CBB73E224240DFA9807B9E434B40C8B3CBB73E224240CC457C2766434B40003B376DC61F4240CC457C2766434B40
779	40	36.24492	36.276639000000003	54.521177999999999	54.517347000000001	Пролетарская улица	0103000020E610000001000000050000007311DF89591F424084D72E6D38424B407311DF89591F424085B2F0F5B5424B402AE620E86823424085B2F0F5B5424B402AE620E86823424084D72E6D38424B407311DF89591F424084D72E6D38424B40
35328	40	36.123575000000002	36.127769999999998	54.538648999999999	54.535733999999998	Привокзальная	0103000020E6100000010000000500000036CD3B4ED10F424079AD84EE92444B4036CD3B4ED10F4240F5824F73F2444B4078B471C45A104240F5824F73F2444B4078B471C45A10424079AD84EE92444B4036CD3B4ED10F424079AD84EE92444B40
35424	40	36.267691999999997	36.273198999999998	54.554003000000002	54.551344999999998	Поселковая	0103000020E610000001000000050000004EB340BB4322424014E8137992464B404EB340BB432242406571FF91E9464B406326512FF82242406571FF91E9464B406326512FF822424014E8137992464B404EB340BB4322424014E8137992464B40
35407	40	36.242215999999999	36.251036999999997	54.522139000000003	54.509371000000002	Плеханова	0103000020E61000000100000005000000B24813EF001F4240F243A51133414B40B24813EF001F4240AB7B6473D5424B40008BFCFA21204240AB7B6473D5424B40008BFCFA21204240F243A51133414B40B24813EF001F4240F243A51133414B40
35482	40	36.263452000000001	36.265329000000001	54.531084	54.528790999999998	Окружная	0103000020E610000001000000050000006C088ECBB8214240A6B5696CAF434B406C088ECBB8214240E5B67D8FFA434B4017D7F84CF6214240E5B67D8FFA434B4017D7F84CF6214240A6B5696CAF434B406C088ECBB8214240A6B5696CAF434B40
35441	40	36.295431999999998	36.305923999999997	54.566766999999999	54.555183	Новослободская	0103000020E610000001000000050000008F183DB7D0254240C8258E3C10474B408F183DB7D0254240DCB930D28B484B40DF87838428274240DCB930D28B484B40DF87838428274240C8258E3C10474B408F183DB7D0254240C8258E3C10474B40
8145	40	36.269165000000001	36.277169000000001	54.512915	54.497701999999997	Николо-Козинская улица	0103000020E610000001000000050000002A1DACFF73224240AF93FAB2B43F4B402A1DACFF732242405D50DF32A7414B40863B17467A2342405D50DF32A7414B40863B17467A234240AF93FAB2B43F4B402A1DACFF73224240AF93FAB2B43F4B40
35397	40	36.262284000000001	36.305951	54.512335	54.504801999999998	Никитина	0103000020E61000000100000005000000CD21A985922142404A7A185A9D404B40CD21A985922142404FCC7A3194414B40D9960167292742404FCC7A3194414B40D9960167292742404A7A185A9D404B40CD21A985922142404A7A185A9D404B40
35406	40	36.252797999999999	36.273395999999998	54.610866000000001	54.513897999999998	Московская	0103000020E61000000100000005000000423F53AF5B2042406ABDDF68C7414B40423F53AF5B204240821E6ADB304E4B40B96DDFA3FE224240821E6ADB304E4B40B96DDFA3FE2242406ABDDF68C7414B40423F53AF5B2042406ABDDF68C7414B40
35559	40	36.295603	36.313084000000003	54.537353000000003	54.529909000000004	Молодежная	0103000020E61000000100000005000000BCCCB051D6254240946DE00ED4434B40BCCCB051D625424029B4ACFBC7444B405073F2221328424029B4ACFBC7444B405073F22213284240946DE00ED4434B40BCCCB051D6254240946DE00ED4434B40
35379	40	36.295603	36.313084000000003	54.537353000000003	54.529909000000004	Молодежная	0103000020E61000000100000005000000BCCCB051D6254240946DE00ED4434B40BCCCB051D625424029B4ACFBC7444B405073F2221328424029B4ACFBC7444B405073F22213284240946DE00ED4434B40BCCCB051D6254240946DE00ED4434B40
35416	40	36.269516000000003	36.284275000000001	54.510103000000001	54.507311999999999	Мичурина	0103000020E61000000100000005000000D7DF12807F224240266F8099EF404B40D7DF12807F224240B64B1B0E4B414B4003098A1F63244240B64B1B0E4B414B4003098A1F63244240266F8099EF404B40D7DF12807F224240266F8099EF404B40
35401	40	36.294102000000002	36.313352999999999	54.527996999999999	54.525571999999997	Маяковского	0103000020E6100000010000000500000017D86322A5254240BED87BF145434B4017D86322A52542406CB1DB6795434B403F8D7BF31B2842406CB1DB6795434B403F8D7BF31B284240BED87BF145434B4017D86322A5254240BED87BF145434B40
35320	40	36.085127	36.388956	54.610413000000001	54.457101999999999	М.Жукова	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
35402	40	36.344687	36.362743000000002	54.514508999999997	54.509481000000001	Льва Толстого	0103000020E610000001000000050000009D2D20B41E2C4240797764AC36414B409D2D20B41E2C4240B33F506EDB414B402DEDD45C6E2E4240B33F506EDB414B402DEDD45C6E2E4240797764AC36414B409D2D20B41E2C4240797764AC36414B40
35432	40	36.260748	36.262985	54.512183	54.499657999999997	Луначарского	0103000020E61000000100000005000000AB3FC23060214240A69718CBF43F4B40AB3FC23060214240994869368F414B40562B137EA9214240994869368F414B40562B137EA9214240A69718CBF43F4B40AB3FC23060214240A69718CBF43F4B40
35430	40	36.282882000000001	36.291282000000002	54.560101000000003	54.548619000000002	Луговая	0103000020E610000001000000050000004450357A352442406C7BBB2539464B404450357A352442407CBABA63B1474B40EDF483BA482542407CBABA63B1474B40EDF483BA482542406C7BBB2539464B404450357A352442406C7BBB2539464B40
35347	40	36.292673999999998	36.295305999999997	54.551234999999998	54.546953000000002	Лесная	0103000020E61000000100000005000000DB317557762542407CB94F8E02464B40DB317557762542408DB454DE8E464B4002284696CC2542408DB454DE8E464B4002284696CC2542407CB94F8E02464B40DB317557762542407CB94F8E02464B40
35400	40	36.253894000000003	36.27796	54.534390999999999	54.506407000000003	Ленина	0103000020E6100000010000000500000048533D997F20424095BBCFF1D1404B4048533D997F2042406C239EEC66444B404FCC7A31942342406C239EEC66444B404FCC7A319423424095BBCFF1D1404B4048533D997F20424095BBCFF1D1404B40
35483	40	36.253894000000003	36.261825999999999	54.506407000000003	54.502079000000002	Кутузова	0103000020E6100000010000000500000048533D997F2042401381EA1F44404B4048533D997F20424095BBCFF1D1404B400A9FAD838321424095BBCFF1D1404B400A9FAD83832142401381EA1F44404B4048533D997F2042401381EA1F44404B40
35399	40	36.247560999999997	36.255816000000003	54.577173999999999	54.576579000000002	Кубяка	0103000020E61000000100000005000000ED612F14B01F4240BB473657CD494B40ED612F14B01F4240FE0C6FD6E0494B4093E52494BE204240FE0C6FD6E0494B4093E52494BE204240BB473657CD494B40ED612F14B01F4240BB473657CD494B40
35375	40	36.230114999999998	36.242556999999998	54.518053000000002	54.512267000000001	Королева	0103000020E61000000100000005000000D6A88768741D4240F7E80DF791414B40D6A88768741D42401F4C8A8F4F424B403B35971B0C1F42401F4C8A8F4F424B403B35971B0C1F4240F7E80DF791414B40D6A88768741D4240F7E80DF791414B40
35409	40	36.245710000000003	36.272022	54.515915	54.512506999999999	Кирова	0103000020E610000001000000050000006C26DF6C731F42404CFC51D499414B406C26DF6C731F42400742B28009424B4071E5EC9DD12242400742B28009424B4071E5EC9DD12242404CFC51D499414B406C26DF6C731F42404CFC51D499414B40
35411	40	36.261142999999997	36.284266000000002	54.525911999999998	54.521673999999997	Карла Либкнехта	0103000020E61000000100000005000000274A42226D2142403596B036C6424B40274A42226D21424077499C1551434B40B0AE0AD46224424077499C1551434B40B0AE0AD4622442403596B036C6424B40274A42226D2142403596B036C6424B40
35394	40	36.220953000000002	36.230114999999998	54.501995000000001	54.493043	Заречная	0103000020E61000000100000005000000FF791A30481C4240C84274081C3F4B40FF791A30481C4240B5E0455F41404B40D6A88768741D4240B5E0455F41404B40D6A88768741D4240C84274081C3F4B40FF791A30481C4240C84274081C3F4B40
35263	40	36.244622999999997	36.270009999999999	54.514074999999998	54.511215999999997	Дзержинского	0103000020E61000000100000005000000B96C74CE4F1F42409198A0866F414B40B96C74CE4F1F42407958A835CD414B40E6CB0BB08F2242407958A835CD414B40E6CB0BB08F2242409198A0866F414B40B96C74CE4F1F42409198A0866F414B40
35389	40	36.22504	36.243994000000001	54.568765999999997	54.564663000000003	Гурьянова	0103000020E610000001000000050000005B25581CCE1C424071218FE046484B405B25581CCE1C4240D2890453CD484B40CA3505323B1F4240D2890453CD484B40CA3505323B1F424071218FE046484B405B25581CCE1C424071218FE046484B40
1200	40	36.278911999999998	36.375633999999998	54.563426	54.518445	Грабцевское шоссе	0103000020E61000000100000005000000213B6F63B32342402AE3DF675C424B40213B6F63B3234240A9DBD9571E484B4001A260C614304240A9DBD9571E484B4001A260C6143042402AE3DF675C424B40213B6F63B32342402AE3DF675C424B40
35435	40	36.269947000000002	36.287194	54.548017999999999	54.530149000000002	Глаголева	0103000020E61000000100000005000000A053909F8D224240E98024ECDB434B40A053909F8D22424046CF2D7425464B40C0CDE2C5C224424046CF2D7425464B40C0CDE2C5C2244240E98024ECDB434B40A053909F8D224240E98024ECDB434B40
35395	40	36.253957	36.255349000000002	54.518962000000002	54.515701	Герцена	0103000020E610000001000000050000008ECBB8A981204240DBC1887D02424B408ECBB8A981204240F2EEC8586D424B407D08AA46AF204240F2EEC8586D424B407D08AA46AF204240DBC1887D02424B408ECBB8A981204240DBC1887D02424B40
35393	40	36.203488999999998	36.228427000000003	54.493550999999997	54.490931000000003	Генерала Попова	0103000020E61000000100000005000000410C74ED0B1A4240DACBB6D3D63E4B40410C74ED0B1A42403CF4DDAD2C3F4B40FF428F183D1D42403CF4DDAD2C3F4B40FF428F183D1D4240DACBB6D3D63E4B40410C74ED0B1A4240DACBB6D3D63E4B40
35423	40	36.233806999999999	36.242818	54.515506999999999	54.510547000000003	Гагарина	0103000020E61000000100000005000000B6494563ED1D42401409A69A59414B40B6494563ED1D4240F6ED2422FC414B40A87004A9141F4240F6ED2422FC414B40A87004A9141F42401409A69A59414B40B6494563ED1D42401409A69A59414B40
35398	40	36.169255	36.181812999999998	54.538319999999999	54.531925000000001	Вишневского	0103000020E610000001000000050000009DD7D825AA15424060764F1E16444B409DD7D825AA154240306475ABE7444B406B7EFCA545174240306475ABE7444B406B7EFCA54517424060764F1E16444B409DD7D825AA15424060764F1E16444B40
35372	40	36.257002	36.267448999999999	54.504477999999999	54.502637999999997	Вилонова	0103000020E61000000100000005000000D8800871E520424009DD257156404B40D8800871E520424097C62FBC92404B40882CD2C43B22424097C62FBC92404B40882CD2C43B22424009DD257156404B40D8800871E520424009DD257156404B40
35428	40	36.270772999999998	36.275795000000002	54.526560000000003	54.519046000000003	Веры Андриановой	0103000020E61000000100000005000000E5D18DB0A8224240508F6D1970424B40E5D18DB0A8224240DEB06D5166434B403EB324404D234240DEB06D5166434B403EB324404D234240508F6D1970424B40E5D18DB0A8224240508F6D1970424B40
35392	40	36.286610000000003	36.301873000000001	54.508383000000002	54.504306	Болдина	0103000020E61000000100000005000000715AF0A2AF2442409A9658198D404B40715AF0A2AF244240D36BB3B112414B40D04543C6A3264240D36BB3B112414B40D04543C6A32642409A9658198D404B40715AF0A2AF2442409A9658198D404B40
35425	40	36.268312000000002	36.269426000000003	54.501603000000003	54.496563000000002	Беляева	0103000020E61000000100000005000000EB8F300C58224240ABB35A608F3F4B40EB8F300C58224240AA49F08634404B409758198D7C224240AA49F08634404B409758198D7C224240ABB35A608F3F4B40EB8F300C58224240ABB35A608F3F4B40
35434	40	36.237715000000001	36.245089999999998	54.515250999999999	54.508524000000001	Баумана	0103000020E610000001000000050000006362F3716D1E4240959D7E5017414B406362F3716D1E42409B1DA9BEF3414B40CF49EF1B5F1F42409B1DA9BEF3414B40CF49EF1B5F1F4240959D7E5017414B406362F3716D1E4240959D7E5017414B40
35339	40	36.246572999999998	36.253894000000003	54.510359000000001	54.506407000000003	Баженова	0103000020E61000000100000005000000CE893DB48F1F424095BBCFF1D1404B40CE893DB48F1F4240111C977153414B4048533D997F204240111C977153414B4048533D997F20424095BBCFF1D1404B40CE893DB48F1F424095BBCFF1D1404B40
35633	40	36.085127	36.388956	54.610413000000001	54.457101999999999	Архангельская	0103000020E61000000100000005000000D8800871E50A4240D5777E51823A4B40D8800871E50A4240D1066003224E4B409FCA694FC9314240D1066003224E4B409FCA694FC9314240D5777E51823A4B40D8800871E50A4240D5777E51823A4B40
208	40	36.213532999999998	36.229010000000002	54.491025	54.489863999999997	Академическая улица	0103000020E61000000100000005000000F2CEA10C551B42406EBE11DDB33E4B40F2CEA10C551B42405B423EE8D93E4B407E3A1E33501D42405B423EE8D93E4B407E3A1E33501D42406EBE11DDB33E4B40F2CEA10C551B42406EBE11DDB33E4B40
35376	40	36.230114999999998	36.242556999999998	54.518053000000002	54.512267000000001	Академика Королева	0103000020E61000000100000005000000D6A88768741D4240F7E80DF791414B40D6A88768741D42401F4C8A8F4F424B403B35971B0C1F42401F4C8A8F4F424B403B35971B0C1F4240F7E80DF791414B40D6A88768741D4240F7E80DF791414B40
515	40	36.245700999999997	36.279899999999998	54.571919000000001	54.556274000000002	Азаровская улица	0103000020E6100000010000000500000018CC5F21731F4240BCCE86FC33474B4018CC5F21731F4240037B4CA434494B40401361C3D3234240037B4CA434494B40401361C3D3234240BCCE86FC33474B4018CC5F21731F4240BCCE86FC33474B40
1316	40	36.330492999999997	36.334257000000001	54.515569999999997	54.513348999999998	5-я линия	0103000020E61000000100000005000000494739984D2A42409737876BB5414B40494739984D2A42403C66A032FE414B40C3BAF1EEC82A42403C66A032FE414B40C3BAF1EEC82A42409737876BB5414B40494739984D2A42409737876BB5414B40
35436	40	36.328786000000001	36.330151999999998	54.545585000000003	54.543376000000002	 Дубрава	0103000020E61000000100000005000000FBB0DEA8152A424035B742588D454B40FBB0DEA8152A42401618B2BAD5454B40C05AB56B422A42401618B2BAD5454B40C05AB56B422A424035B742588D454B40FBB0DEA8152A424035B742588D454B40
74928	54233	36.697229999999998	36.705818000000001	55.156131999999999	55.151991000000002	Совхозная	0103000020E6100000010000000500000021E527D53E594240A724EB7074934B4021E527D53E594240F6ED2422FC934B40CD76853E585A4240F6ED2422FC934B40CD76853E585A4240A724EB7074934B4021E527D53E594240A724EB7074934B40
35348	30672	36.705179999999999	36.74353	55.034703999999998	55.017105999999998	Ленина	0103000020E610000001000000050000008AE59656435A42405E48878730824B408AE59656435A42402B85402E71844B4025CCB4FD2B5F42402B85402E71844B4025CCB4FD2B5F42405E48878730824B408AE59656435A42405E48878730824B40
35278	30672	36.689442	36.781976999999998	55.044206000000003	55.005412999999997	Гурьянова	0103000020E61000000100000005000000923EADA23F58424093FC885FB1804B40923EADA23F584240BC24CE8AA8854B40B29C84D217644240BC24CE8AA8854B40B29C84D21764424093FC885FB1804B40923EADA23F58424093FC885FB1804B40
35264	26155	36.549646000000003	36.582704	55.222020000000001	55.195005000000002	Русиново	0103000020E610000001000000050000004930D5CC5A4642403BC780ECF5984B404930D5CC5A4642406A87BF266B9C4B40CB9F6F0B964A42406A87BF266B9C4B40CB9F6F0B964A42403BC780ECF5984B404930D5CC5A4642403BC780ECF5984B40
35557	26155	36.592306999999998	36.620891999999998	55.219540000000002	55.207977999999997	Московское Большое кольцо	0103000020E610000001000000050000008F183DB7D04B4240CC24EA059F9A4B408F183DB7D04B4240F91400E3199C4B408C2C9963794F4240F91400E3199C4B408C2C9963794F4240CC24EA059F9A4B408F183DB7D04B4240CC24EA059F9A4B40
35248	26155	36.583486000000001	36.631068999999997	55.239789000000002	55.185172999999999	К. Маркса	0103000020E6100000010000000500000041D653ABAF4A4240158DB5BFB3974B4041D653ABAF4A42406478EC67B19E4B407C4276DEC65042406478EC67B19E4B407C4276DEC6504240158DB5BFB3974B4041D653ABAF4A4240158DB5BFB3974B40
35342	26155	36.583486000000001	36.631068999999997	55.239789000000002	55.185172999999999	1 Мая	0103000020E6100000010000000500000041D653ABAF4A4240158DB5BFB3974B4041D653ABAF4A42406478EC67B19E4B407C4276DEC65042406478EC67B19E4B407C4276DEC6504240158DB5BFB3974B4041D653ABAF4A4240158DB5BFB3974B40
74935	49017	36.663057999999999	36.672724000000002	55.009497000000003	55.004514999999998	Центральная	0103000020E61000000100000005000000F3ACA415DF544240B4AB90F293804B40F3ACA415DF5442407F349C3237814B40FE9DEDD11B5642407F349C3237814B40FE9DEDD11B564240B4AB90F293804B40F3ACA415DF544240B4AB90F293804B40
35469	20188	36.364378000000002	36.380645999999999	54.571714999999998	54.560366999999999	Советская	0103000020E61000000100000005000000E2B034F0A32E4240FA60191BBA474B40E2B034F0A32E4240FAD005F52D494B4036AD1402B9304240FAD005F52D494B4036AD1402B9304240FA60191BBA474B40E2B034F0A32E4240FA60191BBA474B40
35304	25664	36.637016000000003	36.683782999999998	55.242159999999998	55.219518999999998	школьная	0103000020E61000000100000005000000AE8383BD89514240E1ECD632199C4B40AE8383BD895142401E335019FF9E4B40C7478B33865742401E335019FF9E4B40C7478B3386574240E1ECD632199C4B40AE8383BD89514240E1ECD632199C4B40
6499	24875	36.485731000000001	36.496932999999999	55.207320000000003	55.196098999999997	улица Ленина	0103000020E61000000100000005000000A2D3F36E2C3E42409FE3A3C519994B40A2D3F36E2C3E424043E73576899A4B40CEA623809B3F424043E73576899A4B40CEA623809B3F42409FE3A3C519994B40A2D3F36E2C3E42409FE3A3C519994B40
35261	24875	36.445478000000001	36.548504999999999	55.225983999999997	55.186098000000001	калинина	0103000020E61000000100000005000000338B506C05394240EEEC2B0FD2974B40338B506C05394240AAB5300BED9C4B40A3586E6935464240AAB5300BED9C4B40A3586E6935464240EEEC2B0FD2974B40338B506C05394240EEEC2B0FD2974B40
35335	24875	36.485731000000001	36.496932999999999	55.207320000000003	55.196098999999997	Ленина	0103000020E61000000100000005000000A2D3F36E2C3E42409FE3A3C519994B40A2D3F36E2C3E424043E73576899A4B40CEA623809B3F424043E73576899A4B40CEA623809B3F42409FE3A3C519994B40A2D3F36E2C3E42409FE3A3C519994B40
35477	24875	36.485300000000002	36.513497999999998	55.216335000000001	55.208302000000003	Коммунистическая	0103000020E61000000100000005000000D95F764F1E3E424080D8D2A3A99A4B40D95F764F1E3E424076FD82DDB09B4B40DC476E4DBA41424076FD82DDB09B4B40DC476E4DBA41424080D8D2A3A99A4B40D95F764F1E3E424080D8D2A3A99A4B40
35553	24875	\N	\N	\N	\N	Большая	\N
35338	24875	36.446466000000001	36.478921999999997	55.208111000000002	55.200184	Берникова	0103000020E61000000100000005000000526342CC253942405B971AA19F994B40526342CC253942400C789961A39A4B40DEAAEB504D3D42400C789961A39A4B40DEAAEB504D3D42405B971AA19F994B40526342CC253942405B971AA19F994B40
35465	24875	36.445478000000001	36.548504999999999	55.225983999999997	55.186098000000001	 1 Мая	0103000020E61000000100000005000000338B506C05394240EEEC2B0FD2974B40338B506C05394240AAB5300BED9C4B40A3586E6935464240AAB5300BED9C4B40A3586E6935464240EEEC2B0FD2974B40338B506C05394240EEEC2B0FD2974B40
35334	30198	36.646970000000003	36.693978000000001	55.103580000000001	55.082189	московская	0103000020E610000001000000050000001FBFB7E9CF524240A48B4D2B858A4B401FBFB7E9CF5242408542041C428D4B405E126745D45842408542041C428D4B405E126745D4584240A48B4D2B858A4B401FBFB7E9CF524240A48B4D2B858A4B40
35250	30198	36.646970000000003	36.693978000000001	55.103580000000001	55.082189	Московская	0103000020E610000001000000050000001FBFB7E9CF524240A48B4D2B858A4B401FBFB7E9CF5242408542041C428D4B405E126745D45842408542041C428D4B405E126745D4584240A48B4D2B858A4B401FBFB7E9CF524240A48B4D2B858A4B40
35291	30198	36.646970000000003	36.693978000000001	55.103580000000001	55.082189	Мирная	0103000020E610000001000000050000001FBFB7E9CF524240A48B4D2B858A4B401FBFB7E9CF5242408542041C428D4B405E126745D45842408542041C428D4B405E126745D4584240A48B4D2B858A4B401FBFB7E9CF524240A48B4D2B858A4B40
35249	30198	36.646970000000003	36.693978000000001	55.103580000000001	55.082189	Гурьянова	0103000020E610000001000000050000001FBFB7E9CF524240A48B4D2B858A4B401FBFB7E9CF5242408542041C428D4B405E126745D45842408542041C428D4B405E126745D4584240A48B4D2B858A4B401FBFB7E9CF524240A48B4D2B858A4B40
6717	25742	36.646754000000001	36.648972999999998	55.183359000000003	55.176301000000002	улица Гагарина	0103000020E610000001000000050000005247C7D5C852424045A0FA0791964B405247C7D5C8524240B136C64E78974B40567E198C11534240B136C64E78974B40567E198C1153424045A0FA0791964B405247C7D5C852424045A0FA0791964B40
35345	25742	36.668025999999998	36.677674000000003	55.185260999999997	55.183985999999997	Московская	0103000020E6100000010000000500000058703FE081554240FF756EDA8C974B4058703FE081554240B41CE8A1B6974B40BDAC8905BE564240B41CE8A1B6974B40BDAC8905BE564240FF756EDA8C974B4058703FE081554240FF756EDA8C974B40
35478	25742	36.656025	36.658261000000003	55.175550000000001	55.170794000000001	Мичурина	0103000020E61000000100000005000000E02D90A0F8534240302DEA93DC954B40E02D90A0F85342400A68226C78964B40BB9D7DE5415442400A68226C78964B40BB9D7DE541544240302DEA93DC954B40E02D90A0F8534240302DEA93DC954B40
35490	25742	36.635219999999997	36.678455999999997	55.196058000000001	55.161974999999998	Коммунальная	0103000020E61000000100000005000000EFE192E34E51424082E2C798BB944B40EFE192E34E514240410FB56D18994B4032E36DA5D7564240410FB56D18994B4032E36DA5D756424082E2C798BB944B40EFE192E34E51424082E2C798BB944B40
35319	25742	36.635219999999997	36.678455999999997	55.196058000000001	55.161974999999998	Кап. Королева	0103000020E61000000100000005000000EFE192E34E51424082E2C798BB944B40EFE192E34E514240410FB56D18994B4032E36DA5D7564240410FB56D18994B4032E36DA5D756424082E2C798BB944B40EFE192E34E51424082E2C798BB944B40
35279	25742	36.635219999999997	36.678455999999997	55.196058000000001	55.161974999999998	Дзержинского	0103000020E61000000100000005000000EFE192E34E51424082E2C798BB944B40EFE192E34E514240410FB56D18994B4032E36DA5D7564240410FB56D18994B4032E36DA5D756424082E2C798BB944B40EFE192E34E51424082E2C798BB944B40
35371	25742	36.646754000000001	36.648972999999998	55.183359000000003	55.176301000000002	Гагарина	0103000020E610000001000000050000005247C7D5C852424045A0FA0791964B405247C7D5C8524240B136C64E78974B40567E198C11534240B136C64E78974B40567E198C1153424045A0FA0791964B405247C7D5C852424045A0FA0791964B40
6710	25742	36.636271000000001	36.659509999999997	55.190137999999997	55.179622000000002	Боровская улица	0103000020E61000000100000005000000553200547151424031D28BDAFD964B40553200547151424009DD257156984B4046B1DCD26A54424009DD257156984B4046B1DCD26A54424031D28BDAFD964B40553200547151424031D28BDAFD964B40
35229	21631	35.210509999999999	35.261102999999999	54.753607000000002	54.728544999999997	Карла Маркса	0103000020E6100000010000000500000090BDDEFDF19A414008556AF6405D4B4090BDDEFDF19A4140B284B53176604B4099F1B6D26BA14140B284B53176604B4099F1B6D26BA1414008556AF6405D4B4090BDDEFDF19A414008556AF6405D4B40
35646	45734	35.420867999999999	35.450557000000003	54.583744000000003	54.569459999999999	Молодежная	0103000020E610000001000000050000006AF7AB00DFB54140A930B610E4484B406AF7AB00DFB541403D9E961FB84A4B40F0FD0DDAABB941403D9E961FB84A4B40F0FD0DDAABB94140A930B610E4484B406AF7AB00DFB54140A930B610E4484B40
35533	22207	35.521129000000002	35.544656000000003	54.637163000000001	54.626640999999999	Центральная	0103000020E61000000100000005000000A4FFE55AB4C2414097AAB4C535504B40A4FFE55AB4C24140529CA38E8E514B40FCC8AD49B7C54140529CA38E8E514B40FCC8AD49B7C5414097AAB4C535504B40A4FFE55AB4C2414097AAB4C535504B40
35640	22187	35.445247999999999	35.464463000000002	54.665739000000002	54.656402	Цветочная	0103000020E61000000100000005000000014EEFE2FDB84140B68311FB04544B40014EEFE2FDB84140FC5580EF36554B40DD99098673BB4140FC5580EF36554B40DD99098673BB4140B68311FB04544B40014EEFE2FDB84140B68311FB04544B40
35457	22127	35.101920999999997	35.124577000000002	54.716965000000002	54.700631999999999	Новые Черемушки	0103000020E6100000010000000500000047E350BF0B8D4140FA43334FAE594B4047E350BF0B8D414036B05582C55B4B40BA6A9E23F28F414036B05582C55B4B40BA6A9E23F28F4140FA43334FAE594B4047E350BF0B8D4140FA43334FAE594B40
35539	22103	35.585690999999997	35.604222999999998	54.587004	54.574074000000003	Зеленая	0103000020E61000000100000005000000E04735ECF7CA4140F1BDBF417B494B40E04735ECF7CA4140834F73F2224B4B40D93EE42D57CD4140834F73F2224B4B40D93EE42D57CD4140F1BDBF417B494B40E04735ECF7CA4140F1BDBF417B494B40
74947	15883	35.404743000000003	35.425252	54.803279000000003	54.793771	Цветочная	0103000020E6100000010000000500000079245E9ECEB34140B1C1C2499A654B4079245E9ECEB341402448A5D8D1664B40804754A86EB641402448A5D8D1664B40804754A86EB64140B1C1C2499A654B4079245E9ECEB34140B1C1C2499A654B40
35566	45634	35.332321	35.351275999999999	54.652579000000003	54.639100999999997	калужская	0103000020E610000001000000050000001363997E89AA4140A2EBC20FCE514B401363997E89AA414038876BB587534B4052EFA99CF6AC414038876BB587534B4052EFA99CF6AC4140A2EBC20FCE514B401363997E89AA4140A2EBC20FCE514B40
35737	54254	35.198929999999997	35.213726000000001	54.639971000000003	54.627918000000001	Молодежная	0103000020E61000000100000005000000BD18CA8976994140ED48F59D5F504B40BD18CA8976994140B8B1D991EA514B400727A25F5B9B4140B8B1D991EA514B400727A25F5B9B4140ED48F59D5F504B40BD18CA8976994140ED48F59D5F504B40
35604	45597	35.276885999999998	35.294789999999999	54.599701000000003	54.590364000000001	Школьная	0103000020E61000000100000005000000315C1D0071A341402D5E2C0C914B4B40315C1D0071A3414073309B00C34C4B400B98C0ADBBA5414073309B00C34C4B400B98C0ADBBA541402D5E2C0C914B4B40315C1D0071A341402D5E2C0C914B4B40
35567	21846	35.274092000000003	35.297367999999999	54.766069000000002	54.755097999999997	центральная	0103000020E61000000100000005000000310C587215A3414033A31F0DA7604B40310C587215A341405EBD8A8C0E624B403F70952710A641405EBD8A8C0E624B403F70952710A6414033A31F0DA7604B40310C587215A3414033A31F0DA7604B40
35513	21805	34.895848000000001	34.935777999999999	54.844465999999997	54.820306000000002	Генерала М.Г. Ефремова	0103000020E61000000100000005000000F017B325AB724140365B79C9FF684B40F017B325AB724140BE4A3E76176C4B407C28D192C7774140BE4A3E76176C4B407C28D192C7774140365B79C9FF684B40F017B325AB724140365B79C9FF684B40
74953	60398	35.468496999999999	35.487667000000002	54.563780999999999	54.553496000000003	Шоссейная	0103000020E6100000010000000500000016A3AEB5F7BB4140C13BF9F4D8464B4016A3AEB5F7BB4140978DCEF929484B40522B4CDF6BBE4140978DCEF929484B40522B4CDF6BBE4140C13BF9F4D8464B4016A3AEB5F7BB4140C13BF9F4D8464B40
35658	54234	37.197583000000002	37.216169000000001	54.832588000000001	54.812446999999999	Полевая	0103000020E610000001000000050000006F9F55664A994240DD5D6743FE674B406F9F55664A99424062855B3E926A4B405BB4006DAB9B424062855B3E926A4B405BB4006DAB9B4240DD5D6743FE674B406F9F55664A994240DD5D6743FE674B40
74950	60395	35.220165999999999	35.238438000000002	54.700730999999998	54.690308999999999	Центральная	0103000020E6100000010000000500000077D844662E9C41403691990B5C584B4077D844662E9C41408D25AC8DB1594B40D40FEA22859E41408D25AC8DB1594B40D40FEA22859E41403691990B5C584B4077D844662E9C41403691990B5C584B40
35596	45510	35.08267	35.097304000000001	54.806345	54.798437	Центральная	0103000020E610000001000000050000001F2E39EE948A41404B75012F33664B401F2E39EE948A414085251E5036674B408FE21C75748C414085251E5036674B408FE21C75748C41404B75012F33664B401F2E39EE948A41404B75012F33664B40
35299	21485	35.069932000000001	35.110258000000002	53.482799	53.451177999999999	ленина	0103000020E61000000100000005000000D1782288F38841405C566133C0B94A40D1782288F388414050C58D5BCCBD4A40AA0F24EF1C8E414050C58D5BCCBD4A40AA0F24EF1C8E41405C566133C0B94A40D1782288F38841405C566133C0B94A40
35258	21485	35.069932000000001	35.110258000000002	53.482799	53.451177999999999	Павлова	0103000020E61000000100000005000000D1782288F38841405C566133C0B94A40D1782288F388414050C58D5BCCBD4A40AA0F24EF1C8E414050C58D5BCCBD4A40AA0F24EF1C8E41405C566133C0B94A40D1782288F38841405C566133C0B94A40
35601	49549	35.253494000000003	35.274163999999999	53.437078	53.422496000000002	Советская	0103000020E61000000100000005000000BADDCB7D72A041406D58535914B64A40BADDCB7D72A041408AE6012CF2B74A40CADE52CE17A341408AE6012CF2B74A40CADE52CE17A341406D58535914B64A40BADDCB7D72A041406D58535914B64A40
35649	54231	35.107365000000001	35.128160999999999	53.416057000000002	53.395136999999998	Школьная	0103000020E6100000010000000500000016DEE522BE8D4140433866D993B24A4016DEE522BE8D4140CD22145B41B54A40B3CF639467904140CD22145B41B54A40B3CF639467904140433866D993B24A4016DEE522BE8D4140433866D993B24A40
35536	21368	34.904857999999997	34.955863999999998	53.510787000000001	53.488618000000002	Молодежная	0103000020E6100000010000000500000011C30E63D2734140541EDD088BBE4A4011C30E63D2734140691CEA7761C14A403DB665C0597A4140691CEA7761C14A403DB665C0597A4140541EDD088BBE4A4011C30E63D2734140541EDD088BBE4A40
35588	21315	34.960419000000002	34.992983000000002	53.460245	53.446057000000003	декабристов	0103000020E6100000010000000500000080BA8102EF7A41407193516518B94A4080BA8102EF7A4140E292E34EE9BA4A40F33D23111A7F4140E292E34EE9BA4A40F33D23111A7F41407193516518B94A4080BA8102EF7A41407193516518B94A40
35595	21258	34.908002000000003	34.946800000000003	53.433290999999997	53.412326999999998	Центральная	0103000020E61000000100000005000000EF59D76839744140FF209221C7B44A40EF59D768397441405853591476B74A4029ED0DBE307941405853591476B74A4029ED0DBE30794140FF209221C7B44A40EF59D76839744140FF209221C7B44A40
35750	21399	35.163266999999998	35.201265999999997	53.509689000000002	53.485387000000003	Гривская	0103000020E610000001000000050000000DC2DCEEE5944140A873452921BE4A400DC2DCEEE5944140C310397D3DC14A40FBE59315C3994140C310397D3DC14A40FBE59315C3994140A873452921BE4A400DC2DCEEE5944140A873452921BE4A40
35531	21172	35.002890999999998	35.033406999999997	53.642394000000003	53.617654999999999	Волостная	0103000020E61000000100000005000000F33977BB5E804140FE9AAC510FCF4A40F33977BB5E804140C59272F739D24A408E3A3AAE46844140C59272F739D24A408E3A3AAE46844140FE9AAC510FCF4A40F33977BB5E804140FE9AAC510FCF4A40
35510	21086	35.263852	35.286399000000003	53.406357999999997	53.386082999999999	советская	0103000020E61000000100000005000000FA7DFFE6C5A141405245F12A6BB14A40FA7DFFE6C5A14140E63BF88903B44A40B64DF1B8A8A44140E63BF88903B44A40B64DF1B8A8A441405245F12A6BB14A40FA7DFFE6C5A141405245F12A6BB14A40
74982	60414	35.148606999999998	35.181215999999999	53.458877999999999	53.437899000000002	Комсомольская	0103000020E61000000100000005000000747ADE8D05934140BEF90D130DB84A40747ADE8D059341404C6DA983BCBA4A4087C1FC15329741404C6DA983BCBA4A4087C1FC1532974140BEF90D130DB84A40747ADE8D05934140BEF90D130DB84A40
35638	20995	35.190081999999997	35.213869000000003	53.56606	53.545791999999999	Новостройка	0103000020E6100000010000000500000075C7629B549841408F352383DCC54A4075C7629B5498414071C971A774C84A406A50340F609B414071C971A774C84A406A50340F609B41408F352383DCC54A4075C7629B549841408F352383DCC54A40
35323	54195	35.355156000000001	35.392257000000001	53.493819000000002	53.470103000000002	Партизанский проспект   	0103000020E61000000100000005000000357D76C075AD41403160C9552CBC4A40357D76C075AD41405C92037635BF4A404450357A35B241405C92037635BF4A404450357A35B241403160C9552CBC4A40357D76C075AD41403160C9552CBC4A40
35535	20923	34.961488000000003	34.997132999999998	53.553736999999998	53.537118999999997	Советская	0103000020E610000001000000050000008CBFED09127B4140B587BD50C0C44A408CBFED09127B4140E6CAA0DAE0C64A409561DC0DA27F4140E6CAA0DAE0C64A409561DC0DA27F4140B587BD50C0C44A408CBFED09127B4140B587BD50C0C44A40
35538	20895	34.822913999999997	34.872132000000001	53.422941999999999	53.401209999999999	коммунарская	0103000020E61000000100000005000000D4B5F63E55694140016A6AD95AB34A40D4B5F63E556941406B0DA5F622B64A40C5E57805A26F41406B0DA5F622B64A40C5E57805A26F4140016A6AD95AB34A40D4B5F63E55694140016A6AD95AB34A40
35625	49457	34.721018000000001	34.747194999999998	53.436332999999998	53.424841000000001	пер.Березовый	0103000020E61000000100000005000000E6E95C514A5C4140FE7F9C3061B64A40E6E95C514A5C414031957EC2D9B74A400B5EF415A45F414031957EC2D9B74A400B5EF415A45F4140FE7F9C3061B64A40E6E95C514A5C4140FE7F9C3061B64A40
35290	20605	36.732695999999997	36.756160000000001	54.553500999999997	54.533002000000003	красноцветова	0103000020E610000001000000050000007BF486FBC85D4240EF59D76839444B407BF486FBC85D4240D2A6EA1ED9464B408D45D3D9C9604240D2A6EA1ED9464B408D45D3D9C9604240EF59D76839444B407BF486FBC85D4240EF59D76839444B40
35294	20605	36.732695999999997	36.756160000000001	54.553500999999997	54.533002000000003	Карпова	0103000020E610000001000000050000007BF486FBC85D4240EF59D76839444B407BF486FBC85D4240D2A6EA1ED9464B408D45D3D9C9604240D2A6EA1ED9464B408D45D3D9C9604240EF59D76839444B407BF486FBC85D4240EF59D76839444B40
74966	40421	36.818494000000001	36.831403000000002	54.330911	54.323014999999998	Центральная	0103000020E6100000010000000500000072FC5069C4684240088F368E58294B4072FC5069C46842407E71A94A5B2A4B40ED65DB696B6A42407E71A94A5B2A4B40ED65DB696B6A4240088F368E58294B4072FC5069C4684240088F368E58294B40
74949	49356	36.662483999999999	36.711379000000001	54.484932000000001	54.439335	Колхозная	0103000020E61000000100000005000000C70F9546CC5442407C7E18213C384B40C70F9546CC54424056647440123E4B40D50792770E5B424056647440123E4B40D50792770E5B42407C7E18213C384B40C70F9546CC5442407C7E18213C384B40
35644	20393	36.774279	36.80077	54.389927	54.376120999999998	Лесная	0103000020E61000000100000005000000637D03931B6342405E2BA1BB24304B40637D03931B634240E869C020E9314B4018CFA0A17F664240E869C020E9314B4018CFA0A17F6642405E2BA1BB24304B40637D03931B6342405E2BA1BB24304B40
35584	19816	36.513776	36.540078999999999	54.599842000000002	54.589064999999998	школьная	0103000020E610000001000000050000001FBC7669C3414240EF1B5F7B664B4B401FBC7669C34142403562669FC74C4B40D120054F214542403562669FC74C4B40D120054F21454240EF1B5F7B664B4B401FBC7669C3414240EF1B5F7B664B4B40
35443	20300	36.838185000000003	36.861730000000001	54.427315999999998	54.406883000000001	Больничная	0103000020E61000000100000005000000B77F65A5496B42403126FDBD14344B40B77F65A5496B42405D876A4AB2364B40B5FD2B2B4D6E42405D876A4AB2364B40B5FD2B2B4D6E42403126FDBD14344B40B77F65A5496B42403126FDBD14344B40
35496	20740	36.772993999999997	36.791184999999999	54.467557999999997	54.457127999999997	центральная	0103000020E610000001000000050000008A00A777F1624240FE0A992B833A4B408A00A777F1624240D87DC7F0D83B4B40FA0AD28C45654240D87DC7F0D83B4B40FA0AD28C45654240FE0A992B833A4B408A00A777F1624240FE0A992B833A4B40
35456	16482	36.48415	36.516579	54.535545999999997	54.524949999999997	Центральная	0103000020E61000000100000005000000E02D90A0F83D42408104C58F31434B40E02D90A0F83D424076C075C58C444B407366BB421F42424076C075C58C444B407366BB421F4242408104C58F31434B40E02D90A0F83D42408104C58F31434B40
35448	22399	36.413021000000001	36.448442	54.469425999999999	54.452528000000001	Центральная	0103000020E61000000100000005000000D6C743DFDD3442401C430070EC394B40D6C743DFDD34424030F2B226163C4B409013268C6639424030F2B226163C4B409013268C663942401C430070EC394B40D6C743DFDD3442401C430070EC394B40
35221	54181	35.513430999999997	35.574992000000002	53.729159000000003	53.705815000000001	Большая Советская	0103000020E6100000010000000500000054E0641BB8C141405C035B2558DA4A4054E0641BB8C14140C34A051555DD4A4017BB7D5699C94140C34A051555DD4A4017BB7D5699C941405C035B2558DA4A4054E0641BB8C141405C035B2558DA4A40
74938	60389	35.573770000000003	35.592086999999999	53.735418000000003	53.725194999999999	Ани Морозовой	0103000020E6100000010000000500000085B69C4B71C94140821C9430D3DC4A4085B69C4B71C94140E371512D22DE4A4081B1BE81C9CB4140E371512D22DE4A4081B1BE81C9CB4140821C9430D3DC4A4085B69C4B71C94140821C9430D3DC4A40
35337	54176	37.144590999999998	37.198293	54.748764000000001	54.714115	Шевякова	0103000020E61000000100000005000000E12538F581924240A14ACD1E685B4B40E12538F5819242400936AE7FD75F4B404B033FAA619942400936AE7FD75F4B404B033FAA61994240A14ACD1E685B4B40E12538F581924240A14ACD1E685B4B40
35192	54176	37.144590999999998	37.198293	54.748764000000001	54.714115	Марины Цветаевой	0103000020E61000000100000005000000E12538F581924240A14ACD1E685B4B40E12538F5819242400936AE7FD75F4B404B033FAA619942400936AE7FD75F4B404B033FAA61994240A14ACD1E685B4B40E12538F581924240A14ACD1E685B4B40
35405	54176	37.144590999999998	37.198293	54.748764000000001	54.714115	Ленина	0103000020E61000000100000005000000E12538F581924240A14ACD1E685B4B40E12538F5819242400936AE7FD75F4B404B033FAA619942400936AE7FD75F4B404B033FAA61994240A14ACD1E685B4B40E12538F581924240A14ACD1E685B4B40
35663	54239	36.828249999999997	36.853797999999998	54.785012999999999	54.773335000000003	Центральная	0103000020E61000000100000005000000BC749318046A424014ED2AA4FC624B40BC749318046A4240A9F7544E7B644B40F2B1BB40496D4240A9F7544E7B644B40F2B1BB40496D424014ED2AA4FC624B40BC749318046A424014ED2AA4FC624B40
35662	54238	37.072816000000003	37.100133999999997	54.743656000000001	54.733426000000001	Центральная	0103000020E610000001000000050000001250E108528942409F0436E7E05D4B401250E10852894240B2BCAB1E305F4B40DC9BDF30D18C4240B2BCAB1E305F4B40DC9BDF30D18C42409F0436E7E05D4B401250E108528942409F0436E7E05D4B40
35660	54236	36.937646999999998	36.958083000000002	54.622289000000002	54.612231999999999	переулок Садовый	0103000020E61000000100000005000000A41820D10478424047C8409E5D4E4B40A41820D1047842408DD47B2AA74F4B4042EDB776A27A42408DD47B2AA74F4B4042EDB776A27A424047C8409E5D4E4B40A41820D10478424047C8409E5D4E4B40
35581	54225	37.127847000000003	37.14893	54.834553	54.823056000000001	Тарусская	0103000020E6100000010000000500000024F25D4A5D904240676325E659694B4024F25D4A5D904240ACE3F8A1D26A4B4057B2632310934240ACE3F8A1D26A4B4057B2632310934240676325E659694B4024F25D4A5D904240676325E659694B40
35495	54214	36.983936999999997	37.013527000000003	54.744653	54.730645000000003	Центральная	0103000020E610000001000000050000008429CAA5F17D424033FE7DC6855D4B408429CAA5F17D424024EF1CCA505F4B40774EB340BB81424024EF1CCA505F4B40774EB340BB81424033FE7DC6855D4B408429CAA5F17D424033FE7DC6855D4B40
35494	54213	37.187423000000003	37.211641999999998	54.772010999999999	54.759596999999999	Центральная	0103000020E6100000010000000500000055C2137AFD974240E29178793A614B4055C2137AFD9742407D93A641D1624B40E23AC615179B42407D93A641D1624B40E23AC615179B4240E29178793A614B4055C2137AFD974240E29178793A614B40
35508	54213	37.187423000000003	37.211641999999998	54.772010999999999	54.759596999999999	Вишневая	0103000020E6100000010000000500000055C2137AFD974240E29178793A614B4055C2137AFD9742407D93A641D1624B40E23AC615179B42407D93A641D1624B40E23AC615179B4240E29178793A614B4055C2137AFD974240E29178793A614B40
35666	54242	37.067534000000002	37.083362000000001	54.608921000000002	54.598517000000001	Центральная	0103000020E610000001000000050000001DAF40F4A4884240CE8C7E349C4C4B401DAF40F4A48842407F6C921FF14D4B4055DD239BAB8A42407F6C921FF14D4B4055DD239BAB8A4240CE8C7E349C4C4B401DAF40F4A4884240CE8C7E349C4C4B40
35664	54240	36.814784000000003	36.841194000000002	54.739216999999996	54.719996999999999	Советская	0103000020E61000000100000005000000ECA694D74A684240EB1B98DC285C4B40ECA694D74A684240D8D2A3A99E5E4B40B4CBB73EAC6B4240D8D2A3A99E5E4B40B4CBB73EAC6B4240EB1B98DC285C4B40ECA694D74A684240EB1B98DC285C4B40
35665	54241	37.166052000000001	37.182788000000002	54.668087	54.657724999999999	Садовая	0103000020E61000000100000005000000BBB72231419542407C61325530544B40BBB7223141954240FEF0F3DF83554B40F60CE19865974240FEF0F3DF83554B40F60CE198659742407C61325530544B40BBB72231419542407C61325530544B40
35550	17941	35.396208999999999	35.421855999999998	54.090938000000001	54.076042999999999	речная	0103000020E61000000100000005000000C0B0FCF9B6B241407C0BEBC6BB094B40C0B0FCF9B6B2414059FB3BDBA30B4B4089CF9D60FFB5414059FB3BDBA30B4B4089CF9D60FFB541407C0BEBC6BB094B40C0B0FCF9B6B241407C0BEBC6BB094B40
35271	17092	35.312216999999997	35.362594000000001	54.131247999999999	54.077517	чкалова	0103000020E61000000100000005000000AB2006BAF6A7414028F1B913EC094B40AB2006BAF6A741402CD505BCCC104B40E8DCED7A69AE41402CD505BCCC104B40E8DCED7A69AE414028F1B913EC094B40AB2006BAF6A7414028F1B913EC094B40
35277	17092	35.312216999999997	35.362594000000001	54.131247999999999	54.077517	ленина	0103000020E61000000100000005000000AB2006BAF6A7414028F1B913EC094B40AB2006BAF6A741402CD505BCCC104B40E8DCED7A69AE41402CD505BCCC104B40E8DCED7A69AE414028F1B913EC094B40AB2006BAF6A7414028F1B913EC094B40
35214	17092	35.312216999999997	35.362594000000001	54.131247999999999	54.077517	Марченко	0103000020E61000000100000005000000AB2006BAF6A7414028F1B913EC094B40AB2006BAF6A741402CD505BCCC104B40E8DCED7A69AE41402CD505BCCC104B40E8DCED7A69AE414028F1B913EC094B40AB2006BAF6A7414028F1B913EC094B40
35286	17092	35.312216999999997	35.362594000000001	54.131247999999999	54.077517	Ленина,	0103000020E61000000100000005000000AB2006BAF6A7414028F1B913EC094B40AB2006BAF6A741402CD505BCCC104B40E8DCED7A69AE41402CD505BCCC104B40E8DCED7A69AE414028F1B913EC094B40AB2006BAF6A7414028F1B913EC094B40
35287	17092	35.312216999999997	35.362594000000001	54.131247999999999	54.077517	Ленина	0103000020E61000000100000005000000AB2006BAF6A7414028F1B913EC094B40AB2006BAF6A741402CD505BCCC104B40E8DCED7A69AE41402CD505BCCC104B40E8DCED7A69AE414028F1B913EC094B40AB2006BAF6A7414028F1B913EC094B40
35333	17092	35.312216999999997	35.362594000000001	54.131247999999999	54.077517	Дзержинского	0103000020E61000000100000005000000AB2006BAF6A7414028F1B913EC094B40AB2006BAF6A741402CD505BCCC104B40E8DCED7A69AE41402CD505BCCC104B40E8DCED7A69AE414028F1B913EC094B40AB2006BAF6A7414028F1B913EC094B40
35272	17250	35.224451000000002	35.241222999999998	54.055968999999997	54.045904999999998	Комсомольская	0103000020E61000000100000005000000FA4674CFBA9C414087DC0C37E0054B40FA4674CFBA9C41407F4B00FE29074B4081053065E09E41407F4B00FE29074B4081053065E09E414087DC0C37E0054B40FA4674CFBA9C414087DC0C37E0054B40
35473	17758	35.163105999999999	35.189686999999999	54.092875999999997	54.083227000000001	им. Т.П. Полянской	0103000020E6100000010000000500000004E44BA8E09441407592AD2EA70A4B4004E44BA8E0944140A94A5B5CE30B4B40F9BCE2A947984140A94A5B5CE30B4B40F9BCE2A9479841407592AD2EA70A4B4004E44BA8E09441407592AD2EA70A4B40
35454	17044	34.183824999999999	34.207917999999999	54.395966000000001	54.380195999999998	Центральная	0103000020E61000000100000005000000F697DD9387174140F6083543AA304B40F697DD9387174140FA298E03AF324B40F71F990E9D1A4140FA298E03AF324B40F71F990E9D1A4140F6083543AA304B40F697DD9387174140F6083543AA304B40
35570	46366	33.737577999999999	33.744351000000002	54.385413	54.380574000000003	Мира	0103000020E61000000100000005000000E21FB6F468DE40409DDA19A6B6304B40E21FB6F468DE4040043A933655314B4059DFC0E446DF4040043A933655314B4059DFC0E446DF40409DDA19A6B6304B40E21FB6F468DE40409DDA19A6B6304B40
35509	48200	34.069380000000002	34.085028000000001	54.422628000000003	54.410688	Центральная	0103000020E610000001000000050000008D7F9F71E1084140096EA46C91344B408D7F9F71E1084140DC2F9FAC18364B40459F8F32E20A4140DC2F9FAC18364B40459F8F32E20A4140096EA46C91344B408D7F9F71E1084140096EA46C91344B40
35701	45416	34.181229000000002	34.198152999999998	54.306049999999999	54.285840999999998	Молодежная	0103000020E610000001000000050000001C0B0A83321741408F6D197096244B401C0B0A83321741406C787AA52C274B40594DD7135D1941406C787AA52C274B40594DD7135D1941408F6D197096244B401C0B0A83321741408F6D197096244B40
35499	16847	33.752246999999997	33.768507	54.360968	54.352311	Снопотская	0103000020E61000000100000005000000CEC133A149E04040B282DF86182D4B40CEC133A149E0404086730D33342E4B40A0DFF76F5EE2404086730D33342E4B40A0DFF76F5EE24040B282DF86182D4B40CEC133A149E04040B282DF86182D4B40
35636	48153	34.054962000000003	34.073512000000001	54.273009000000002	54.255808000000002	приозерная	0103000020E61000000100000005000000EA42ACFE0807414010070951BE204B40EA42ACFE08074140C0417BF5F1224B4089EE59D768094140C0417BF5F1224B4089EE59D76809414010070951BE204B40EA42ACFE0807414010070951BE204B40
35558	16693	33.740614000000001	33.773986999999998	54.488461999999998	54.472911000000003	Центральная	0103000020E61000000100000005000000D97A8670CCDE40409775FF58883C4B40D97A8670CCDE40405CAB3DEC853E4B40BB438A0112E340405CAB3DEC853E4B40BB438A0112E340409775FF58883C4B40D97A8670CCDE40409775FF58883C4B40
35722	54252	34.059040000000003	34.088845999999997	54.350715000000001	54.336854000000002	Школьный переулок	0103000020E61000000100000005000000F3936A9F8E0741406EC328081E2B4B40F3936A9F8E074140BB9BA73AE42C4B40B130444E5F0B4140BB9BA73AE42C4B40B130444E5F0B41406EC328081E2B4B40F3936A9F8E0741406EC328081E2B4B40
35506	16535	33.685718000000001	33.699615000000001	54.428274000000002	54.418928999999999	Бориса Кривельского	0103000020E61000000100000005000000A723809BC5D74040492C29779F354B40A723809BC5D7404012DDB3AED1364B404165FCFB8CD9404012DDB3AED1364B404165FCFB8CD94040492C29779F354B40A723809BC5D74040492C29779F354B40
35583	16335	33.831066	33.856614	54.340029999999999	54.322642000000002	переулок школьный	0103000020E61000000100000005000000A568E55E60EA4040742843554C294B40A568E55E60EA404056D4601A862B4B40DBA50D87A5ED404056D4601A862B4B40DBA50D87A5ED4040742843554C294B40A568E55E60EA4040742843554C294B40
35529	16985	33.937480000000001	33.953775999999998	54.313687000000002	54.302005000000001	Школьная	0103000020E61000000100000005000000B9533A58FFF740403F1D8F19A8264B40B9533A58FFF74040161747E526284B40D7DAFB5415FA4040161747E526284B40D7DAFB5415FA40403F1D8F19A8264B40B9533A58FFF740403F1D8F19A8264B40
74957	16268	33.951081000000002	33.972684999999998	54.405242999999999	54.395741000000001	Центральная	0103000020E610000001000000050000006A6CAF05BDF94040DA571EA4A7324B406A6CAF05BDF940406AF7AB00DF334B40A6272CF180FC40406AF7AB00DF334B40A6272CF180FC4040DA571EA4A7324B406A6CAF05BDF94040DA571EA4A7324B40
35289	15835	36.148836000000003	36.174483000000002	54.273335000000003	54.253925000000002	ленина	0103000020E61000000100000005000000D63BDC0E0D1342408351499D80204B40D63BDC0E0D13424014ED2AA4FC224B409F5A7D755516424014ED2AA4FC224B409F5A7D75551642408351499D80204B40D63BDC0E0D1342408351499D80204B40
35481	15687	36.174528000000002	36.197209999999998	54.347042000000002	54.309821999999997	Центральная	0103000020E610000001000000050000003F1EFAEE5616424068CA4E3FA8274B403F1EFAEE56164240522B4CDF6B2C4B40DA38622D3E194240522B4CDF6B2C4B40DA38622D3E19424068CA4E3FA8274B403F1EFAEE5616424068CA4E3FA8274B40
35362	54199	36.078085000000002	36.101531000000001	54.424309000000001	54.414324000000001	Центральная	0103000020E6100000010000000500000072A774B0FE09424055F99E9108354B4072A774B0FE0942400133DFC14F364B40DD43C2F7FE0C42400133DFC14F364B40DD43C2F7FE0C424055F99E9108354B4072A774B0FE09424055F99E9108354B40
35449	47960	36.427233000000001	36.468834000000001	54.446246000000002	54.437291999999999	Центральная	0103000020E61000000100000005000000D0622992AF364240B6662B2FF9374B40D0622992AF36424044FCC3961E394B405EA0A4C0023C424044FCC3961E394B405EA0A4C0023C4240B6662B2FF9374B40D0622992AF364240B6662B2FF9374B40
35612	12873	34.816419000000003	34.833765	54.638466000000001	54.629497000000001	центральная	0103000020E61000000100000005000000A16AF46A806841400EF7915B93504B40A16AF46A80684140D1CDFE40B9514B4054C6BFCFB86A4140D1CDFE40B9514B4054C6BFCFB86A41400EF7915B93504B40A16AF46A806841400EF7915B93504B40
35615	13740	34.908118999999999	34.927855000000001	54.461210999999999	54.451554000000002	широкая	0103000020E6100000010000000500000028F04E3E3D74414062307F85CC394B4028F04E3E3D74414019C748F6083B4B400D37E0F3C376414019C748F6083B4B400D37E0F3C376414062307F85CC394B4028F04E3E3D74414062307F85CC394B40
35497	46809	35.043323999999998	35.060141000000002	54.483576999999997	54.476928999999998	Молодежная	0103000020E61000000100000005000000E2900DA48B854140CAC16C020C3D4B40E2900DA48B854140840CE4D9E53D4B400A1346B3B2874140840CE4D9E53D4B400A1346B3B2874140CAC16C020C3D4B40E2900DA48B854140CAC16C020C3D4B40
35667	54243	34.886235999999997	34.907912000000003	54.596060999999999	54.582751999999999	Центральная	0103000020E61000000100000005000000D844662E70714140DCD6169E974A4B40D844662E70714140E5B512BA4B4C4B40AFD2DD7536744140E5B512BA4B4C4B40AFD2DD7536744140DCD6169E974A4B40D844662E70714140DCD6169E974A4B40
35585	13373	34.788975000000001	34.810372999999998	54.623091000000002	54.609530999999997	Садовая	0103000020E61000000100000005000000492EFF21FD644140F7729F1C054E4B40492EFF21FD6441404AB72572C14F4B40DC476E4DBA6741404AB72572C14F4B40DC476E4DBA674140F7729F1C054E4B40492EFF21FD644140F7729F1C054E4B40
35632	13180	35.075035	35.092013000000001	54.550362999999997	54.543678	Дружбы	0103000020E61000000100000005000000168733BF9A89414000C79E3D97454B40168733BF9A894140D7F6764B72464B4047E7FC14C78B4140D7F6764B72464B4047E7FC14C78B414000C79E3D97454B40168733BF9A89414000C79E3D97454B40
35564	13033	34.736522999999998	34.760587999999998	54.479334999999999	54.471927000000001	Центральная	0103000020E610000001000000050000003BE0BA62465E4140B98C9B1A683C4B403BE0BA62465E4140016A6AD95A3D4B4072DD94F25A614140016A6AD95A3D4B4072DD94F25A614140B98C9B1A683C4B403BE0BA62465E4140B98C9B1A683C4B40
35578	46704	34.954659999999997	34.972914000000003	54.573709000000001	54.563279999999999	школьная	0103000020E610000001000000050000005166834C327A4140D53E1D8F19484B405166834C327A4140DF35E84B6F494B4008E92972887C4140DF35E84B6F494B4008E92972887C4140D53E1D8F19484B405166834C327A4140D53E1D8F19484B40
35298	13454	34.9544	34.994644000000001	54.504306	54.474601	кирова	0103000020E61000000100000005000000B5A679C7297A41400FD3BEB9BF3C4B40B5A679C7297A41409A9658198D404B40D1949D7E507F41409A9658198D404B40D1949D7E507F41400FD3BEB9BF3C4B40B5A679C7297A41400FD3BEB9BF3C4B40
35331	13454	34.9544	34.994644000000001	54.504306	54.474601	Революции	0103000020E61000000100000005000000B5A679C7297A41400FD3BEB9BF3C4B40B5A679C7297A41409A9658198D404B40D1949D7E507F41409A9658198D404B40D1949D7E507F41400FD3BEB9BF3C4B40B5A679C7297A41400FD3BEB9BF3C4B40
35616	12994	34.707847999999998	34.731375	54.607987999999999	54.597405999999999	Шоссейная	0103000020E61000000100000005000000FE4465C39A5A41409337C0CC774C4B40FE4465C39A5A4140232E008DD24D4B40560E2DB29D5D4140232E008DD24D4B40560E2DB29D5D41409337C0CC774C4B40FE4465C39A5A41409337C0CC774C4B40
35708	54249	34.435937000000003	35.300997000000002	54.758485	54.353098000000003	Школьная	0103000020E61000000100000005000000E50E9BC8CC3741403A24B550322D4B40E50E9BC8CC374140D7C0560916614B40D998D71187A64140D7C0560916614B40D998D71187A641403A24B550322D4B40E50E9BC8CC3741403A24B550322D4B40
35580	46975	34.835158	34.856034000000001	54.434711	54.424739000000002	сельская	0103000020E61000000100000005000000137F1475E66A4140FA2AF9D85D364B40137F1475E66A4140111B2C9CA4374B40CD21A985926D4140111B2C9CA4374B40CD21A985926D4140FA2AF9D85D364B40137F1475E66A4140FA2AF9D85D364B40
35631	46929	34.981439000000002	34.993180000000002	54.507525999999999	54.501409000000002	центральная	0103000020E610000001000000050000006D020CCB9F7D4140C5758C2B2E404B406D020CCB9F7D414052EFA99CF6404B404985B185207F414052EFA99CF6404B404985B185207F4140C5758C2B2E404B406D020CCB9F7D4140C5758C2B2E404B40
35634	13413	35.140754999999999	35.167301000000002	54.485726999999997	54.478734000000003	центральная	0103000020E61000000100000005000000CEDF844204924140DCBDDC27473D4B40CEDF84420492414060E4654D2C3E4B4047CB811E6A95414060E4654D2C3E4B4047CB811E6A954140DCBDDC27473D4B40CEDF844204924140DCBDDC27473D4B40
35609	12205	35.416206000000003	35.439903000000001	54.384092000000003	54.371695000000003	центральная	0103000020E610000001000000050000001233FB3C46B541401A8BA6B3932F4B401233FB3C46B54140DF5339ED29314B40C634D3BD4EB84140DF5339ED29314B40C634D3BD4EB841401A8BA6B3932F4B401233FB3C46B541401A8BA6B3932F4B40
35461	12283	34.972079000000001	35.005549999999999	54.345289000000001	54.327336000000003	пушкина	0103000020E610000001000000050000006F10AD156D7C4140D8666325E6294B406F10AD156D7C41409355116E322C4B40143FC6DCB58041409355116E322C4B40143FC6DCB5804140D8666325E6294B406F10AD156D7C4140D8666325E6294B40
35614	12704	35.229832000000002	35.250781000000003	54.350431999999998	54.336984999999999	Центральная	0103000020E6100000010000000500000082C98D226B9D41400C1F1153222B4B4082C98D226B9D414066BCADF4DA2C4B40A6BA809719A0414066BCADF4DA2C4B40A6BA809719A041400C1F1153222B4B4082C98D226B9D41400C1F1153222B4B40
35579	46483	35.181547999999999	35.202720999999997	54.321401999999999	54.307431000000001	садовая	0103000020E61000000100000005000000BD5301F73C974140676325E659274B40BD5301F73C9741403B6F63B323294B40309B00C3F29941403B6F63B323294B40309B00C3F2994140676325E659274B40BD5301F73C974140676325E659274B40
35444	12034	35.517347000000001	35.544035999999998	54.253010000000003	54.243124999999999	Козельская	0103000020E6100000010000000500000084D72E6D38C2414085EB51B81E1F4B4084D72E6D38C24140CEC7B5A162204B405FECBDF8A2C54140CEC7B5A162204B405FECBDF8A2C5414085EB51B81E1F4B4084D72E6D38C2414085EB51B81E1F4B40
35527	46603	35.410195999999999	35.433650999999998	54.480355000000003	54.468139000000001	лесная	0103000020E610000001000000050000009A79724D81B44140B77D8FFAEB3B4B409A79724D81B441402CBCCB457C3D4B4058703FE081B741402CBCCB457C3D4B4058703FE081B74140B77D8FFAEB3B4B409A79724D81B44140B77D8FFAEB3B4B40
74958	46514	35.380676999999999	35.396641000000002	54.312359000000001	54.303192000000003	Коммунарская	0103000020E6100000010000000500000071AB2006BAB041405534D6FECE264B4071AB2006BAB041403ECE3461FB274B405AA0DD21C5B241403ECE3461FB274B405AA0DD21C5B241405534D6FECE264B4071AB2006BAB041405534D6FECE264B40
35525	12087	35.610691000000003	35.636499999999998	54.290266000000003	54.274833000000001	старая	0103000020E61000000100000005000000147B681F2BCE4140486E4DBA2D234B40147B681F2BCE41400492B06F27254B40B6F3FDD478D141400492B06F27254B40B6F3FDD478D14140486E4DBA2D234B40147B681F2BCE4140486E4DBA2D234B40
35237	12501	35.261353999999997	35.295471999999997	54.329867	54.308276999999997	проспект Революции	0103000020E61000000100000005000000E256410C74A14140F38DE89E75274B40E256410C74A14140CB83F414392A4B401D71C806D2A54140CB83F414392A4B401D71C806D2A54140F38DE89E75274B40E256410C74A14140F38DE89E75274B40
35211	12501	35.261353999999997	35.295471999999997	54.329867	54.308276999999997	площадь Ленина	0103000020E61000000100000005000000E256410C74A14140F38DE89E75274B40E256410C74A14140CB83F414392A4B401D71C806D2A54140CB83F414392A4B401D71C806D2A54140F38DE89E75274B40E256410C74A14140F38DE89E75274B40
35526	46280	35.500844999999998	35.523311999999997	54.383405000000003	54.370120999999997	Школьная	0103000020E61000000100000005000000BCAE5FB01BC041400A48FB1F602F4B40BCAE5FB01BC04140BB0F406A13314B405BCD3AE3FBC24140BB0F406A13314B405BCD3AE3FBC241400A48FB1F602F4B40BCAE5FB01BC041400A48FB1F602F4B40
35501	46572	35.326985000000001	35.347000000000001	54.446513000000003	54.429442000000002	Молодежная	0103000020E610000001000000050000002BA4FCA4DAA94140B1C398F4F7364B402BA4FCA4DAA94140931E865627394B4023DBF97E6AAC4140931E865627394B4023DBF97E6AAC4140B1C398F4F7364B402BA4FCA4DAA94140B1C398F4F7364B40
35507	46539	35.284719000000003	35.295211999999999	54.383232	54.375675999999999	Новая	0103000020E6100000010000000500000061C614AC71A4414030F2B22616304B4061C614AC71A44140ED6305BF0D314B4081B1BE81C9A54140ED6305BF0D314B4081B1BE81C9A5414030F2B22616304B4061C614AC71A4414030F2B22616304B40
74956	45666	35.839196000000001	35.850478000000003	55.067798000000003	55.061869000000002	Мира	0103000020E610000001000000050000008E7747C66AEB414070D1C952EB874B408E7747C66AEB4140FB5DD89AAD884B40D7FB8D76DCEC4140FB5DD89AAD884B40D7FB8D76DCEC414070D1C952EB874B408E7747C66AEB414070D1C952EB874B40
35316	11707	35.833041999999999	35.903596	54.982982999999997	54.950785000000003	проспект Ленина	0103000020E61000000100000005000000E318C91EA1EA41408143A852B3794B40E318C91EA1EA414011C30E63D27D4B40F165A208A9F3414011C30E63D27D4B40F165A208A9F341408143A852B3794B40E318C91EA1EA41408143A852B3794B40
35307	11707	35.833041999999999	35.903596	54.982982999999997	54.950785000000003	Володарского	0103000020E61000000100000005000000E318C91EA1EA41408143A852B3794B40E318C91EA1EA414011C30E63D27D4B40F165A208A9F3414011C30E63D27D4B40F165A208A9F341408143A852B3794B40E318C91EA1EA41408143A852B3794B40
74939	46791	34.327537999999997	34.353966	53.895901000000002	53.879896000000002	Центральная	0103000020E610000001000000050000003F19E3C3EC294140CCF09F6EA0F04A403F19E3C3EC29414013BA4BE2ACF24A40AEF204C24E2D414013BA4BE2ACF24A40AEF204C24E2D4140CCF09F6EA0F04A403F19E3C3EC294140CCF09F6EA0F04A40
35591	9758	34.327142000000002	34.358862000000002	53.981622999999999	53.968626999999998	Горчакова	0103000020E61000000100000005000000F392FFC9DF294140E48233F8FBFB4A40F392FFC9DF2941402E008DD2A5FD4A407AE3A430EF2D41402E008DD2A5FD4A407AE3A430EF2D4140E48233F8FBFB4A40F392FFC9DF294140E48233F8FBFB4A40
35205	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	энгельса	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35206	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	фокина	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35207	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	сестер хотеевых	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35254	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	попова	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35208	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	герцена	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35210	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Щербакова	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35268	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Чугунова	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35270	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Черняховского	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35284	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Московская	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35240	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Маяковского	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35204	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Ленина	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35253	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Крупской	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35318	8615	34.385488000000002	34.499664000000003	53.892330999999999	53.815117000000001	Кропоткина	0103000020E610000001000000050000000F80B8AB57314140F2B4FCC055E84A400F80B8AB573141407E1AF7E637F24A40897E6DFDF43F41407E1AF7E637F24A40897E6DFDF43F4140F2B4FCC055E84A400F80B8AB57314140F2B4FCC055E84A40
35607	54230	34.622687999999997	34.651138000000003	54.029798999999997	54.016674999999999	переулок Школьный	0103000020E610000001000000050000004ACE893DB44F414095D4096822024B404ACE893DB44F41400C3A2174D0034B4068976F7D585341400C3A2174D0034B4068976F7D5853414095D4096822024B404ACE893DB44F414095D4096822024B40
35648	9700	34.279487000000003	34.301343000000003	53.909852999999998	53.905695000000001	Новая	0103000020E610000001000000050000001E54E23AC62341404B9352D0EDF34A401E54E23AC62341407095271076F44A4074F04C68922641407095271076F44A4074F04C68922641404B9352D0EDF34A401E54E23AC62341404B9352D0EDF34A40
35608	9442	34.539558	34.566659999999999	53.937100999999998	53.922708	Центральная	0103000020E61000000100000005000000C8258E3C10454140F8E0B54B1BF64A40C8258E3C104541404206F2ECF2F74A40C6F99B50884841404206F2ECF2F74A40C6F99B5088484140F8E0B54B1BF64A40C8258E3C10454140F8E0B54B1BF64A40
35661	9909	34.617243999999999	34.635793999999997	53.854570000000002	53.846502000000001	Центральная	0103000020E610000001000000050000007CD3F4D9014F4140D2FF722D5AEC4A407CD3F4D9014F41404512BD8C62ED4A401B7FA2B2615141404512BD8C62ED4A401B7FA2B261514140D2FF722D5AEC4A407CD3F4D9014F4140D2FF722D5AEC4A40
35657	9859	34.531554	34.555816999999998	53.820151000000003	53.807578999999997	Центральная	0103000020E610000001000000050000006C0723F609444140DBF7A8BF5EE74A406C0723F6094441400F643DB5FAE84A40C9C7EE02254741400F643DB5FAE84A40C9C7EE0225474140DBF7A8BF5EE74A406C0723F609444140DBF7A8BF5EE74A40
35575	47253	33.888378000000003	33.908625999999998	54.066358999999999	54.050455999999997	центральная	0103000020E61000000100000005000000323ECC5EB6F1404088F19A5775064B40323ECC5EB6F14040CB65A3737E084B40CC2555DB4DF44040CB65A3737E084B40CC2555DB4DF4404088F19A5775064B40323ECC5EB6F1404088F19A5775064B40
35645	29633	33.696281999999997	33.729601000000002	54.246608000000002	54.230943000000003	центральная	0103000020E610000001000000050000009065C1C41FD94040BD1E4C8A8F1D4B409065C1C41FD940404B77D7D9901F4B408010C99063DD40404B77D7D9901F4B408010C99063DD4040BD1E4C8A8F1D4B409065C1C41FD94040BD1E4C8A8F1D4B40
35523	8489	34.038684000000003	34.058698999999997	53.922866999999997	53.904491	центральная	0103000020E610000001000000050000007270E998F30441405F43705CC6F34A407270E998F304414060C77F8120F64A4069A7E6728307414060C77F8120F64A4069A7E672830741405F43705CC6F34A407270E998F30441405F43705CC6F34A40
35466	8370	33.928927999999999	33.971570999999997	54.023493999999999	54.003028999999998	Ленина	0103000020E610000001000000050000005A2BDA1CE7F6404044F8174163004B405A2BDA1CE7F640407CD3F4D901034B40FA5E43705CFC40407CD3F4D901034B40FA5E43705CFC404044F8174163004B405A2BDA1CE7F6404044F8174163004B40
35300	8370	33.928927999999999	33.971570999999997	54.023493999999999	54.003028999999998	Калинина	0103000020E610000001000000050000005A2BDA1CE7F6404044F8174163004B405A2BDA1CE7F640407CD3F4D901034B40FA5E43705CFC40407CD3F4D901034B40FA5E43705CFC404044F8174163004B405A2BDA1CE7F6404044F8174163004B40
35283	7036	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	Чкалова	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
35329	7036	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	Заводская	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
35311	7036	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	Генерала Бурмака	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
35266	7036	35.742401999999998	35.831344000000001	54.052697999999999	54.009041000000003	Большая Советская	0103000020E61000000100000005000000143E5B0707DF41405DA9674128014B40143E5B0707DF41404548DDCEBE064B40E8DCED7A69EA41404548DDCEBE064B40E8DCED7A69EA41405DA9674128014B40143E5B0707DF41405DA9674128014B40
74969	16379	34.216093000000001	34.224787999999997	54.229312	54.223016000000001	Центральная	0103000020E6100000010000000500000080F277EFA81B41400C3ECDC98B1C4B4080F277EFA81B4140494A7A185A1D4B4041446ADAC51C4140494A7A185A1D4B4041446ADAC51C41400C3ECDC98B1C4B4080F277EFA81B41400C3ECDC98B1C4B40
35220	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	строительная	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35218	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	пролетарская	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35458	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Челюскина	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35314	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Урицкого	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35201	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Пушкина	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35228	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Плеханова	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35281	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Ленина	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35303	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Кирова	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35243	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	Болдина	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
35312	45938	34.242817000000002	34.398693000000002	54.111891999999997	54.040115999999998	 пер. Куракина	0103000020E61000000100000005000000D8F4A0A0141F4140EE05668522054B40D8F4A0A0141F41408E57207A520E4B4073124A5F083341408E57207A520E4B4073124A5F08334140EE05668522054B40D8F4A0A0141F4140EE05668522054B40
74945	54196	36.164655000000003	36.184409000000002	54.633978999999997	54.624999000000003	Центральная	0103000020E61000000100000005000000BB0F406A1315424030849CF7FF4F4B40BB0F406A13154240E6AC4F3926514B40460BD0B69A174240E6AC4F3926514B40460BD0B69A17424030849CF7FF4F4B40BB0F406A1315424030849CF7FF4F4B40
74954	54222	36.252555000000001	36.276333999999999	54.637605999999998	54.624332000000003	Юбилейная	0103000020E610000001000000050000007CB8E4B85320424053EC681CEA4F4B407CB8E4B853204240DFDDCA129D514B40ED629AE95E234240DFDDCA129D514B40ED629AE95E23424053EC681CEA4F4B407CB8E4B85320424053EC681CEA4F4B40
35565	54222	36.252555000000001	36.276333999999999	54.637605999999998	54.624332000000003	Успенская	0103000020E610000001000000050000007CB8E4B85320424053EC681CEA4F4B407CB8E4B853204240DFDDCA129D514B40ED629AE95E234240DFDDCA129D514B40ED629AE95E23424053EC681CEA4F4B407CB8E4B85320424053EC681CEA4F4B40
35659	54235	36.300130000000003	36.323630000000001	54.657110000000003	54.640028999999998	Центральная	0103000020E610000001000000050000003546EBA86A264240ECBE6378EC514B403546EBA86A264240F2EF332E1C544B40930035B56C294240F2EF332E1C544B40930035B56C294240ECBE6378EC514B403546EBA86A264240ECBE6378EC514B40
35628	31097	35.590192000000002	35.609901000000001	55.107370000000003	55.098211999999997	Центральная	0103000020E61000000100000005000000302E55698BCB41409109F835928C4B40302E55698BCB41402849D74CBE8D4B401B66683C11CE41402849D74CBE8D4B401B66683C11CE41409109F835928C4B40302E55698BCB41409109F835928C4B40
35521	30979	35.253036000000002	35.279958000000001	55.091546000000001	55.077561000000003	новая	0103000020E61000000100000005000000F75AD07B63A04140F838D384ED894B40F75AD07B63A04140310A82C7B78B4B407520EBA9D5A34140310A82C7B78B4B407520EBA9D5A34140F838D384ED894B40F75AD07B63A04140F838D384ED894B40
35292	30473	35.654528999999997	35.699677999999999	54.909829999999999	54.884633000000001	Интернациональная	0103000020E610000001000000050000004CA4349BC7D341402FFB75A73B714B404CA4349BC7D34140B875374F75744B4087DD770C8FD94140B875374F75744B4087DD770C8FD941402FFB75A73B714B404CA4349BC7D341402FFB75A73B714B40
35574	45638	35.427838999999999	35.445616999999999	54.953100999999997	54.943752000000003	центральная	0103000020E61000000100000005000000077AA86DC3B641406EC493DDCC784B40077AA86DC3B641407764AC36FF794B4054C554FA09B941407764AC36FF794B4054C554FA09B941406EC493DDCC784B40077AA86DC3B641406EC493DDCC784B40
35308	31328	35.299433999999998	35.345652000000001	54.996113000000001	54.981515000000002	40 лет октября	0103000020E61000000100000005000000BDA772DA53A6414048C49448A27D4B40BDA772DA53A641406B0F7BA1807F4B4004E621533EAC41406B0F7BA1807F4B4004E621533EAC414048C49448A27D4B40BDA772DA53A6414048C49448A27D4B40
35576	31227	35.203313999999999	35.244824999999999	54.938586000000001	54.926549000000001	Окружная	0103000020E61000000100000005000000D3687231069A41401D925A2899764B40D3687231069A4140E23D079623784B40211FF46C569F4140E23D079623784B40211FF46C569F41401D925A2899764B40D3687231069A41401D925A2899764B40
35302	30439	37.102091999999999	37.137638000000003	54.888755000000003	54.876910000000002	ленина	0103000020E610000001000000050000007497C459118D424087C43D963E704B407497C459118D424008944DB9C2714B40EB573A1F9E91424008944DB9C2714B40EB573A1F9E91424087C43D963E704B407497C459118D424087C43D963E704B40
35293	30439	37.102091999999999	37.137638000000003	54.888755000000003	54.876910000000002	Школьная	0103000020E610000001000000050000007497C459118D424087C43D963E704B407497C459118D424008944DB9C2714B40EB573A1F9E91424008944DB9C2714B40EB573A1F9E91424087C43D963E704B407497C459118D424087C43D963E704B40
35285	30439	37.102091999999999	37.137638000000003	54.888755000000003	54.876910000000002	Мира	0103000020E610000001000000050000007497C459118D424087C43D963E704B407497C459118D424008944DB9C2714B40EB573A1F9E91424008944DB9C2714B40EB573A1F9E91424087C43D963E704B407497C459118D424087C43D963E704B40
35274	30439	37.102091999999999	37.137638000000003	54.888755000000003	54.876910000000002	Ленина	0103000020E610000001000000050000007497C459118D424087C43D963E704B407497C459118D424008944DB9C2714B40EB573A1F9E91424008944DB9C2714B40EB573A1F9E91424087C43D963E704B407497C459118D424087C43D963E704B40
35563	29504	36.797320999999997	36.819274999999998	55.103960999999998	55.096218999999998	Дачная	0103000020E61000000100000005000000FEB4519D0E6642407D2079E7508C4B40FEB4519D0E6642409C8713984E8D4B4017B7D100DE6842409C8713984E8D4B4017B7D100DE6842407D2079E7508C4B40FEB4519D0E6642407D2079E7508C4B40
35622	29520	36.786658000000003	36.81747	55.153168999999998	55.141089000000001	Московская	0103000020E6100000010000000500000082919735B1644240A56950340F924B4082919735B164424069E1B20A9B934B4006BB61DBA268424069E1B20A9B934B4006BB61DBA2684240A56950340F924B4082919735B1644240A56950340F924B40
35252	54186	36.669580000000003	37.182464000000003	55.234814999999998	54.798499	мирная	0103000020E61000000100000005000000210725CCB4554240C171193735664B40210725CCB45542401CCEFC6A0E9E4B404359F8FA5A9742401CCEFC6A0E9E4B404359F8FA5A974240C171193735664B40210725CCB4554240C171193735664B40
74951	60396	36.961388999999997	36.968935000000002	55.060316999999998	55.05547	Центральная	0103000020E61000000100000005000000F8DD74CB0E7B42405EF415A419874B40F8DD74CB0E7B42404832AB77B8874B409279E40F067C42404832AB77B8874B409279E40F067C42405EF415A419874B40F8DD74CB0E7B42405EF415A419874B40
74959	46403	36.943944000000002	36.951112000000002	54.806418000000001	54.802843000000003	Полевая	0103000020E61000000100000005000000B2A03028D37842404969368FC3664B40B2A03028D3784240EF737CB438674B40A56ABB09BE794240EF737CB438674B40A56ABB09BE7942404969368FC3664B40B2A03028D37842404969368FC3664B40
35562	28942	34.689666000000003	34.707417	53.659545999999999	53.641406000000003	Центральная	0103000020E61000000100000005000000E294B9F946584140A6BA809719D24A40E294B9F946584140931ADA006CD44A4035D1E7A38C5A4140931ADA006CD44A4035D1E7A38C5A4140A6BA809719D24A40E294B9F946584140A6BA809719D24A40
35518	28927	34.624619000000003	34.650382999999998	53.551453000000002	53.537889	Центральная	0103000020E61000000100000005000000E9BAF083F34F414067F0F78BD9C44A40E9BAF083F34F4140FB230C0396C64A40EB6F09C03F534140FB230C0396C64A40EB6F09C03F53414067F0F78BD9C44A40E9BAF083F34F414067F0F78BD9C44A40
35597	46154	34.900410999999998	34.921297000000003	53.756163000000001	53.748618999999998	школьная	0103000020E61000000100000005000000B5FAEAAA40734140051555BFD2DF4A40B5FAEAAA40734140FEB8FDF2C9E04A409373620FED754140FEB8FDF2C9E04A409373620FED754140051555BFD2DF4A40B5FAEAAA40734140051555BFD2DF4A40
74964	60403	34.712888	34.721125000000001	53.504916999999999	53.497151000000002	Пристанционная	0103000020E61000000100000005000000FDDAFAE93F5B41403C16DBA4A2BF4A40FDDAFAE93F5B4140E318C91EA1C04A40FCA9F1D24D5C4140E318C91EA1C04A40FCA9F1D24D5C41403C16DBA4A2BF4A40FDDAFAE93F5B41403C16DBA4A2BF4A40
35512	49248	34.980181999999999	35.009224000000003	53.771141	53.755358999999999	Молодежная	0103000020E610000001000000050000005E10919A767D4140A0DE8C9AAFE04A405E10919A767D414068CD8FBFB4E24A404E2B85402E81414068CD8FBFB4E24A404E2B85402E814140A0DE8C9AAFE04A405E10919A767D4140A0DE8C9AAFE04A40
35555	29047	34.624664000000003	34.653869	53.499374000000003	53.476362999999999	центральная	0103000020E61000000100000005000000897E6DFDF44F414021037976F9BC4A40897E6DFDF44F4140823CBB7CEBBF4A40226FB9FAB1534140823CBB7CEBBF4A40226FB9FAB153414021037976F9BC4A40897E6DFDF44F414021037976F9BC4A40
35561	28850	34.688372999999999	34.716929999999998	53.579234999999997	53.560727999999997	Центральная	0103000020E610000001000000050000008639419B1C584140CAF962EFC5C74A408639419B1C5841406AD95A5F24CA4A40B9C2BB5CC45B41406AD95A5F24CA4A40B9C2BB5CC45B4140CAF962EFC5C74A408639419B1C584140CAF962EFC5C74A40
35626	29247	34.657291000000001	34.686512999999998	53.768858000000002	53.751398000000002	Молодежная	0103000020E61000000100000005000000427A8A1C22544140D12346CF2DE04A40427A8A1C225441404DA25EF069E24A40B1A371A8DF5741404DA25EF069E24A40B1A371A8DF574140D12346CF2DE04A40427A8A1C22544140D12346CF2DE04A40
35573	28832	34.809780000000003	34.831313000000002	53.615811999999998	53.599871	Центральная	0103000020E610000001000000050000003A7AFCDEA6674140CF68AB92C8CC4A403A7AFCDEA6674140FF3D78EDD2CE4A40ADDEE176686A4140FF3D78EDD2CE4A40ADDEE176686A4140CF68AB92C8CC4A403A7AFCDEA6674140CF68AB92C8CC4A40
35572	49285	34.590088000000002	34.62426	53.684995999999998	53.664135000000002	заречная	0103000020E610000001000000050000008BE1EA00884B414082902C6002D54A408BE1EA00884B414006F2ECF2ADD74A40B9196EC0E74F414006F2ECF2ADD74A40B9196EC0E74F414082902C6002D54A408BE1EA00884B414082902C6002D54A40
35668	54244	34.693106999999998	34.715960000000003	53.730496000000002	53.719057999999997	Центральная	0103000020E6100000010000000500000078D0ECBAB7584140ADF6B0170ADC4A4078D0ECBAB7584140EEED96E480DD4A40419FC893A45B4140EEED96E480DD4A40419FC893A45B4140ADF6B0170ADC4A4078D0ECBAB7584140ADF6B0170ADC4A40
35605	47363	34.848668000000004	34.896026999999997	53.742590999999997	53.713138000000001	Школьная	0103000020E61000000100000005000000B4942C27A16C414076C4211B48DB4A40B4942C27A16C4140E7A6CD380DDF4A409FAA4203B1724140E7A6CD380DDF4A409FAA4203B172414076C4211B48DB4A40B4942C27A16C414076C4211B48DB4A40
35199	29075	34.709356999999997	34.762968999999998	53.760992000000002	53.727204	пл. Коммуны	0103000020E610000001000000050000002618CE35CC5A41409CC24A0515DD4A402618CE35CC5A41404242942F68E14A40506EDBF7A86141404242942F68E14A40506EDBF7A86141409CC24A0515DD4A402618CE35CC5A41409CC24A0515DD4A40
35306	29075	34.709356999999997	34.762968999999998	53.760992000000002	53.727204	коммунистическая	0103000020E610000001000000050000002618CE35CC5A41409CC24A0515DD4A402618CE35CC5A41404242942F68E14A40506EDBF7A86141404242942F68E14A40506EDBF7A86141409CC24A0515DD4A402618CE35CC5A41409CC24A0515DD4A40
35459	29075	34.709356999999997	34.762968999999998	53.760992000000002	53.727204	Брянская,	0103000020E610000001000000050000002618CE35CC5A41409CC24A0515DD4A402618CE35CC5A41404242942F68E14A40506EDBF7A86141404242942F68E14A40506EDBF7A86141409CC24A0515DD4A402618CE35CC5A41409CC24A0515DD4A40
35511	29222	34.714585999999997	34.738920999999998	53.821353000000002	53.801969	Центральная	0103000020E61000000100000005000000F816D68D775B4140F2B391EBA6E64A40F816D68D775B41405ABC581822E94A40EFA99CF6945E41405ABC581822E94A40EFA99CF6945E4140F2B391EBA6E64A40F816D68D775B4140F2B391EBA6E64A40
35685	49049	35.250484999999998	35.292040999999998	53.849912000000003	53.833640000000003	Ленина	0103000020E61000000100000005000000BC9179E40FA0414098512CB7B4EA4A40BC9179E40FA041402E3D9AEAC9EC4A40AA0B789961A541402E3D9AEAC9EC4A40AA0B789961A5414098512CB7B4EA4A40BC9179E40FA0414098512CB7B4EA4A40
35547	49020	35.203530000000001	35.241518999999997	53.775818999999998	53.755662999999998	Центральная	0103000020E61000000100000005000000A0E062450D9A41400CE6AF90B9E04A40A0E062450D9A4140C64E78094EE34A406A2E3718EA9E4140C64E78094EE34A406A2E3718EA9E41400CE6AF90B9E04A40A0E062450D9A41400CE6AF90B9E04A40
35544	28379	34.930145000000003	34.949539999999999	54.053167999999999	54.034647999999997	центральная	0103000020E61000000100000005000000DBC4C9FD0E774140976F7D586F044B40DBC4C9FD0E774140CC988235CE064B40361FD7868A794140CC988235CE064B40361FD7868A794140976F7D586F044B40DBC4C9FD0E774140976F7D586F044B40
35492	28093	35.088158999999997	35.160131999999997	53.944378	53.884656999999997	Центральная	0103000020E610000001000000050000008DEC4ACB488B4140B796C9703CF14A408DEC4ACB488B4140EC87D860E1F84A40838593347F944140EC87D860E1F84A40838593347F944140B796C9703CF14A408DEC4ACB488B4140B796C9703CF14A40
35197	28093	35.088158999999997	35.160131999999997	53.944378	53.884656999999997	Ленина	0103000020E610000001000000050000008DEC4ACB488B4140B796C9703CF14A408DEC4ACB488B4140EC87D860E1F84A40838593347F944140EC87D860E1F84A40838593347F944140B796C9703CF14A408DEC4ACB488B4140B796C9703CF14A40
35500	28093	35.088158999999997	35.160131999999997	53.944378	53.884656999999997	Белинского	0103000020E610000001000000050000008DEC4ACB488B4140B796C9703CF14A408DEC4ACB488B4140EC87D860E1F84A40838593347F944140EC87D860E1F84A40838593347F944140B796C9703CF14A408DEC4ACB488B4140B796C9703CF14A40
35610	22639	35.933239999999998	35.944972	54.590707999999999	54.583002999999998	Школьная	0103000020E61000000100000005000000D6A8876874F74140253CA1D79F4A4B40D6A8876874F7414027BEDA519C4B4B405FD1ADD7F4F8414027BEDA519C4B4B405FD1ADD7F4F84140253CA1D79F4A4B40D6A8876874F74140253CA1D79F4A4B40
35341	54178	35.930500000000002	35.954619999999998	54.684297999999998	54.670414999999998	Школьная	0103000020E61000000100000005000000C976BE9F1AF74140B9DFA128D0554B40C976BE9F1AF74140EE5BAD1397574B40C30DF8FC30FA4140EE5BAD1397574B40C30DF8FC30FA4140B9DFA128D0554B40C976BE9F1AF74140B9DFA128D0554B40
35203	54178	35.930500000000002	35.954619999999998	54.684297999999998	54.670414999999998	Туркестанская	0103000020E61000000100000005000000C976BE9F1AF74140B9DFA128D0554B40C976BE9F1AF74140EE5BAD1397574B40C30DF8FC30FA4140EE5BAD1397574B40C30DF8FC30FA4140B9DFA128D0554B40C976BE9F1AF74140B9DFA128D0554B40
35196	54178	35.930500000000002	35.954619999999998	54.684297999999998	54.670414999999998	Ленина	0103000020E61000000100000005000000C976BE9F1AF74140B9DFA128D0554B40C976BE9F1AF74140EE5BAD1397574B40C30DF8FC30FA4140EE5BAD1397574B40C30DF8FC30FA4140B9DFA128D0554B40C976BE9F1AF74140B9DFA128D0554B40
35358	54178	35.930500000000002	35.954619999999998	54.684297999999998	54.670414999999998	Дзержинского	0103000020E61000000100000005000000C976BE9F1AF74140B9DFA128D0554B40C976BE9F1AF74140EE5BAD1397574B40C30DF8FC30FA4140EE5BAD1397574B40C30DF8FC30FA4140B9DFA128D0554B40C976BE9F1AF74140B9DFA128D0554B40
35505	54216	36.070377000000001	36.089447999999997	54.716709999999999	54.697811999999999	Ленина	0103000020E61000000100000005000000FFB1101D02094240D06053E751594B40FFB1101D02094240AB5B3D27BD5B4B40A7583508730B4240AB5B3D27BD5B4B40A7583508730B4240D06053E751594B40FFB1101D02094240D06053E751594B40
35327	28025	36.051602000000003	36.093688	54.696007000000002	54.685879999999997	ленина	0103000020E610000001000000050000004034F3E49A064240807D74EACA574B404034F3E49A064240BF64E3C116594B408A03E8F7FD0B4240BF64E3C116594B408A03E8F7FD0B4240807D74EACA574B404034F3E49A064240807D74EACA574B40
35431	54205	35.531424000000001	36.143545000000003	54.906486999999998	54.456871999999997	Советская	0103000020E610000001000000050000009E279EB305C44140A33A1DC87A3A4B409E279EB305C44140E49F19C407744B408E40BCAE5F124240E49F19C407744B408E40BCAE5F124240A33A1DC87A3A4B409E279EB305C44140A33A1DC87A3A4B40
35193	27349	35.950460999999997	36.012183999999998	54.750546	54.707718	Школьная	0103000020E61000000100000005000000CD8FBFB4A8F941403065E080965A4B40CD8FBFB4A8F9414062122EE411604B4069C4CC3E8F01424062122EE411604B4069C4CC3E8F0142403065E080965A4B40CD8FBFB4A8F941403065E080965A4B40
35246	27349	35.950460999999997	36.012183999999998	54.750546	54.707718	Ленина	0103000020E61000000100000005000000CD8FBFB4A8F941403065E080965A4B40CD8FBFB4A8F9414062122EE411604B4069C4CC3E8F01424062122EE411604B4069C4CC3E8F0142403065E080965A4B40CD8FBFB4A8F941403065E080965A4B40
74937	46425	35.706982000000004	35.717851000000003	54.724027	54.717911999999998	Новая	0103000020E610000001000000050000002B6EDC627EDA4140F6B3588AE45B4B402B6EDC627EDA4140E335AFEAAC5C4B405133A48AE2DB4140E335AFEAAC5C4B405133A48AE2DB4140F6B3588AE45B4B402B6EDC627EDA4140F6B3588AE45B4B40
35629	27865	35.726035000000003	35.747171999999999	54.806215999999999	54.801935	Заводская	0103000020E610000001000000050000002D6002B7EEDC414046425BCEA5664B402D6002B7EEDC414087C1FC1532674B40533E0455A3DF414087C1FC1532674B40533E0455A3DF414046425BCEA5664B402D6002B7EEDC414046425BCEA5664B40
35571	27818	35.998835	36.027985000000001	54.857621000000002	54.838394999999998	Центральная	0103000020E61000000100000005000000D28C45D3D9FF4140A1100187506B4B40D28C45D3D9FF414071AE6186C66D4B40A8E331039503424071AE6186C66D4B40A8E3310395034240A1100187506B4B40D28C45D3D9FF4140A1100187506B4B40
35269	46550	36.019748	36.053443999999999	54.614364999999999	54.601396000000001	советская	0103000020E61000000100000005000000A9143B1A87024240FDF84B8BFA4C4B40A9143B1A870242404D672783A34E4B406E15C440D70642404D672783A34E4B406E15C440D7064240FDF84B8BFA4C4B40A9143B1A87024240FDF84B8BFA4C4B40
35194	46550	36.019748	36.053443999999999	54.614364999999999	54.601396000000001	Полевая	0103000020E61000000100000005000000A9143B1A87024240FDF84B8BFA4C4B40A9143B1A870242404D672783A34E4B406E15C440D70642404D672783A34E4B406E15C440D7064240FDF84B8BFA4C4B40A9143B1A87024240FDF84B8BFA4C4B40
74946	48244	35.731721	35.748779999999996	54.712279000000002	54.700246999999997	Центральная	0103000020E61000000100000005000000F165A208A9DD4140A10F96B1A1594B40F165A208A9DD4140555051F52B5B4B400EF3E505D8DF4140555051F52B5B4B400EF3E505D8DF4140A10F96B1A1594B40F165A208A9DD4140A10F96B1A1594B40
35227	28009	36.012597	36.030284999999999	54.537942999999999	54.527191999999999	Мира	0103000020E610000001000000050000008C834BC79C0142403E5B07077B434B408C834BC79C0142405A0EF450DB444B409947FE60E00342405A0EF450DB444B409947FE60E00342403E5B07077B434B408C834BC79C0142403E5B07077B434B40
35474	26997	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	маяковского	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
35322	26997	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	Южная	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
35191	26997	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	Советская	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
35223	26997	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	Ленина	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
35251	26997	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	Кооперативная	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
35222	26997	35.901699999999998	35.957090000000001	54.822598999999997	54.768754999999999	Интернациональная	0103000020E61000000100000005000000CF66D5E76AF3414078D1579066624B40CF66D5E76AF34140745C8DEC4A694B4011AAD4EC81FA4140745C8DEC4A694B4011AAD4EC81FA414078D1579066624B40CF66D5E76AF3414078D1579066624B40
35520	46736	35.905842	35.929952	54.573217999999997	54.562987999999997	центральная	0103000020E61000000100000005000000EFAB72A1F2F341402D05A4FD0F484B40EFAB72A1F2F3414040BD19355F494B40C66CC9AA08F7414040BD19355F494B40C66CC9AA08F741402D05A4FD0F484B40EFAB72A1F2F341402D05A4FD0F484B40
35462	26845	36.021678999999999	36.045448999999998	54.799354999999998	54.779384999999998	Центральная	0103000020E610000001000000050000004701A260C602424019FF3EE3C2634B404701A260C60242407172BF4351664B406551D845D10542407172BF4351664B406551D845D105424019FF3EE3C2634B404701A260C602424019FF3EE3C2634B40
35546	27923	35.636239000000003	35.656756999999999	54.749341000000001	54.737828999999998	Речная	0103000020E610000001000000050000004AB8904770D141402B85402E715E4B404AB8904770D14140A646E867EA5F4B40A435069D10D44140A646E867EA5F4B40A435069D10D441402B85402E715E4B404AB8904770D141402B85402E715E4B40
35213	26935	36.008699	36.031722000000002	54.704258000000003	54.691333999999998	Садовая	0103000020E610000001000000050000000341800C1D014240724EECA17D584B400341800C1D01424023F94A20255A4B4028486C770F04424023F94A20255A4B4028486C770F044240724EECA17D584B400341800C1D014240724EECA17D584B40
35653	48256	35.873781000000001	35.902293	54.782640000000001	54.765264000000002	переулок светлый	0103000020E61000000100000005000000DF6E490ED8EF41403067B62BF4614B40DF6E490ED8EF41404E452A8C2D644B40723447567EF341404E452A8C2D644B40723447567EF341403067B62BF4614B40DF6E490ED8EF41403067B62BF4614B40
35244	46673	35.986069999999998	36.022190999999999	54.623742999999997	54.606914000000003	Федорова	0103000020E610000001000000050000008AC8B08A37FE414006BEA25BAF4D4B408AC8B08A37FE4140F10D85CFD64F4B40FDA19927D7024240F10D85CFD64F4B40FDA19927D702424006BEA25BAF4D4B408AC8B08A37FE414006BEA25BAF4D4B40
74927	47719	35.691656000000002	35.699399999999997	54.632640000000002	54.628146999999998	Кузнецова	0103000020E61000000100000005000000850A0E2F88D841404E0AF31E67504B40850A0E2F88D841401B12F758FA504B4044696FF085D941401B12F758FA504B4044696FF085D941404E0AF31E67504B40850A0E2F88D841404E0AF31E67504B40
35475	26406	36.422831000000002	36.435721999999998	55.232156000000003	55.225876	Центральная	0103000020E61000000100000005000000145E82531F364240C4793881E99C4B40145E82531F364240FCC8AD49B79D4B40E8120EBDC5374240FCC8AD49B79D4B40E8120EBDC5374240C4793881E99C4B40145E82531F364240C4793881E99C4B40
35383	54201	36.031184000000003	36.668889	55.286270999999999	55.072788000000003	Центральная	0103000020E6100000010000000500000049145AD6FD03424048C5FF1D51894B4049145AD6FD03424088653387A4A44B40BBD39D279E55424088653387A4A44B40BBD39D279E55424048C5FF1D51894B4049145AD6FD03424048C5FF1D51894B40
35619	25278	36.164808000000001	36.177905000000003	55.162740999999997	55.151764999999997	центральная	0103000020E61000000100000005000000410FB56D18154240B6D617096D934B40410FB56D18154240F25B74B2D4944B40BF654E97C5164240F25B74B2D4944B40BF654E97C5164240B6D617096D934B40410FB56D18154240B6D617096D934B40
35321	54194	36.031184000000003	36.668889	55.286270999999999	55.072788000000003	Мигунова	0103000020E6100000010000000500000049145AD6FD03424048C5FF1D51894B4049145AD6FD03424088653387A4A44B40BBD39D279E55424088653387A4A44B40BBD39D279E55424048C5FF1D51894B4049145AD6FD03424048C5FF1D51894B40
35654	54232	36.031184000000003	36.668889	55.286270999999999	55.072788000000003	Центральная	0103000020E6100000010000000500000049145AD6FD03424048C5FF1D51894B4049145AD6FD03424088653387A4A44B40BBD39D279E55424088653387A4A44B40BBD39D279E55424048C5FF1D51894B4049145AD6FD03424048C5FF1D51894B40
35556	25369	36.073385999999999	36.086888000000002	55.180813999999998	55.170366999999999	Центральная	0103000020E61000000100000005000000FCFD62B664094240A8A8FA95CE954B40FCFD62B6640942405854C4E924974B401A355F251F0B42405854C4E924974B401A355F251F0B4240A8A8FA95CE954B40FCFD62B664094240A8A8FA95CE954B40
35470	25212	36.301054999999998	36.313901000000001	55.130147999999998	55.121160000000003	Центральная	0103000020E610000001000000050000000DA661F888264240ACCABE2B828F4B400DA661F888264240E5D18DB0A8904B40429770E82D284240E5D18DB0A8904B40429770E82D284240ACCABE2B828F4B400DA661F888264240ACCABE2B828F4B40
35650	47529	34.511045000000003	34.528858999999997	54.353439000000002	54.339426000000003	Озерная	0103000020E6100000010000000500000065E42CEC69414140C0B4A84F722B4B4065E42CEC69414140C310397D3D2D4B40FE98D6A6B1434140C310397D3D2D4B40FE98D6A6B1434140C0B4A84F722B4B4065E42CEC69414140C0B4A84F722B4B40
35621	47505	34.397857999999999	34.429496	54.486538000000003	54.467306999999998	Центральная	0103000020E61000000100000005000000DA39CD02ED3241408F183DB7D03B4B40DA39CD02ED32414071218FE0463E4B40A4E194B9F936414071218FE0463E4B40A4E194B9F93641408F183DB7D03B4B40DA39CD02ED3241408F183DB7D03B4B40
35606	47456	34.677287999999997	34.703465000000001	54.403236	54.395175000000002	Молодежная	0103000020E6100000010000000500000093FC885FB156414031992A1895324B4093FC885FB1564140F148BC3C9D334B40B97020240B5A4140F148BC3C9D334B40B97020240B5A414031992A1895324B4093FC885FB156414031992A1895324B40
35652	24613	34.454873999999997	34.483108000000001	54.264254000000001	54.250664	центральная	0103000020E610000001000000050000007DE6AC4F393A41406C2409C215204B407DE6AC4F393A414029EB3713D3214B40CE37A27BD63D414029EB3713D3214B40CE37A27BD63D41406C2409C215204B407DE6AC4F393A41406C2409C215204B40
35517	24511	34.619041000000003	34.635651000000003	54.377091999999998	54.358936999999997	центральная	0103000020E610000001000000050000000BF148BC3C4F41408429CAA5F12D4B400BF148BC3C4F4140A7CAF78C44304B40B95510035D514140A7CAF78C44304B40B95510035D5141408429CAA5F12D4B400BF148BC3C4F41408429CAA5F12D4B40
35519	9565	34.603231000000001	34.609347999999997	54.191699999999997	54.188116999999998	Школьная	0103000020E61000000100000005000000797764AC364D41402B69C53714184B40797764AC364D4140545227A089184B4006F1811DFF4D4140545227A089184B4006F1811DFF4D41402B69C53714184B40797764AC364D41402B69C53714184B40
74960	60401	34.666651999999999	34.678707000000003	54.275900999999998	54.268877000000003	Центральная	0103000020E6100000010000000500000010E84CDA54554140C4D2C08F6A224B4010E84CDA5455414083F755B950234B407C48F8DEDF56414083F755B950234B407C48F8DEDF564140C4D2C08F6A224B4010E84CDA54554140C4D2C08F6A224B40
35502	48262	34.581913	34.60933	54.434249999999999	54.419877	советская	0103000020E61000000100000005000000020F0C207C4A4140DAAB8F87BE354B40020F0C207C4A4140DD24068195374B40603C8386FE4D4140DD24068195374B40603C8386FE4D4140DAAB8F87BE354B40020F0C207C4A4140DAAB8F87BE354B40
74932	60383	34.540025	34.560488999999997	54.451884	54.439642999999997	Глазово	0103000020E61000000100000005000000DE02098A1F4541402975C93846384B40DE02098A1F454140F7CABC55D7394B404562821ABE474140F7CABC55D7394B404562821ABE4741402975C93846384B40DE02098A1F4541402975C93846384B40
35516	47084	34.296680000000002	34.316406999999998	54.355615999999998	54.341588999999999	Центральная	0103000020E610000001000000050000004BB0389CF925414030D63730B92B4B404BB0389CF925414098F738D3842D4B40DC9C4A068028414098F738D3842D4B40DC9C4A068028414030D63730B92B4B404BB0389CF925414030D63730B92B4B40
35419	46873	34.489530999999999	34.547714999999997	54.318640000000002	54.288406000000002	40 лет Победы	0103000020E6100000010000000500000068B0A9F3A83E41402FFCE07CEA244B4068B0A9F3A83E414046990D32C9284B40AA436E861B46414046990D32C9284B40AA436E861B4641402FFCE07CEA244B4068B0A9F3A83E41402FFCE07CEA244B40
35548	47375	34.646169999999998	34.662770999999999	54.227584999999998	54.212324000000002	Мира	0103000020E6100000010000000500000002D4D4B2B5524140F513CE6E2D1B4B4002D4D4B2B5524140B3075A81211D4B405DDE1CAED5544140B3075A81211D4B405DDE1CAED5544140F513CE6E2D1B4B4002D4D4B2B5524140F513CE6E2D1B4B40
74929	23850	35.865867000000001	35.896203	54.297117999999998	54.285373	Центральная	0103000020E61000000100000005000000C3D7D7BAD4EE4140A9143B1A87244B40C3D7D7BAD4EE4140C6866EF607264B40DEC9A7C7B6F24140C6866EF607264B40DEC9A7C7B6F24140A9143B1A87244B40C3D7D7BAD4EE4140A9143B1A87244B40
35551	13224	35.885961999999999	35.899220999999997	54.441094	54.433002999999999	Дачная	0103000020E61000000100000005000000D7BFEB3367F14140F2086EA46C374B40D7BFEB3367F141401D3BA8C475384B402E7079AC19F341401D3BA8C475384B402E7079AC19F34140F2086EA46C374B40D7BFEB3367F14140F2086EA46C374B40
35260	24227	36.029179999999997	36.067304999999998	54.482976000000001	54.458452999999999	школьная	0103000020E6100000010000000500000040D9942BBC03424065E08096AE3A4B4040D9942BBC0342405F605628D23D4B40BBED42739D0842405F605628D23D4B40BBED42739D08424065E08096AE3A4B4040D9942BBC03424065E08096AE3A4B40
35219	24227	36.029179999999997	36.067304999999998	54.482976000000001	54.458452999999999	центральная	0103000020E6100000010000000500000040D9942BBC03424065E08096AE3A4B4040D9942BBC0342405F605628D23D4B40BBED42739D0842405F605628D23D4B40BBED42739D08424065E08096AE3A4B4040D9942BBC03424065E08096AE3A4B40
35245	24227	36.029179999999997	36.067304999999998	54.482976000000001	54.458452999999999	Школьная	0103000020E6100000010000000500000040D9942BBC03424065E08096AE3A4B4040D9942BBC0342405F605628D23D4B40BBED42739D0842405F605628D23D4B40BBED42739D08424065E08096AE3A4B4040D9942BBC03424065E08096AE3A4B40
35280	24227	36.029179999999997	36.067304999999998	54.482976000000001	54.458452999999999	50-лет Победы	0103000020E6100000010000000500000040D9942BBC03424065E08096AE3A4B4040D9942BBC0342405F605628D23D4B40BBED42739D0842405F605628D23D4B40BBED42739D08424065E08096AE3A4B4040D9942BBC03424065E08096AE3A4B40
74942	23549	35.590488000000001	35.630149000000003	54.534526999999997	54.522514999999999	Центральная	0103000020E6100000010000000500000019575C1C95CB4140B05582C5E1424B4019575C1C95CB41401CEA77616B444B40B64DF1B8A8D041401CEA77616B444B40B64DF1B8A8D04140B05582C5E1424B4019575C1C95CB4140B05582C5E1424B40
35455	23389	35.757511999999998	35.776637000000001	54.398828000000002	54.384469000000003	моторная	0103000020E61000000100000005000000ED293927F6E04140B5A9BA4736314B40ED293927F6E04140535DC0CB0C334B4089EE59D768E34140535DC0CB0C334B4089EE59D768E34140B5A9BA4736314B40ED293927F6E04140B5A9BA4736314B40
35541	23389	35.757511999999998	35.776637000000001	54.398828000000002	54.384469000000003	Центральная	0103000020E61000000100000005000000ED293927F6E04140B5A9BA4736314B40ED293927F6E04140535DC0CB0C334B4089EE59D768E34140535DC0CB0C334B4089EE59D768E34140B5A9BA4736314B40ED293927F6E04140B5A9BA4736314B40
35247	23389	35.757511999999998	35.776637000000001	54.398828000000002	54.384469000000003	Новая	0103000020E61000000100000005000000ED293927F6E04140B5A9BA4736314B40ED293927F6E04140535DC0CB0C334B4089EE59D768E34140535DC0CB0C334B4089EE59D768E34140B5A9BA4736314B40ED293927F6E04140B5A9BA4736314B40
35488	23340	35.751573999999998	35.769396	54.333646999999999	54.317847	Центральная	0103000020E610000001000000050000000F43AB9333E04140DC10E335AF284B400F43AB9333E041404AB4E4F1B42A4B402CD670917BE241404AB4E4F1B42A4B402CD670917BE24140DC10E335AF284B400F43AB9333E04140DC10E335AF284B40
34462	54128	40.998480999999998	40.999065000000002	56.958081	56.956088000000001	Вичугский проезд	0103000020E61000000100000005000000B456B439CE7F44408D0C7217617A4C40B456B439CE7F4440A1F5F065A27A4C4004CAA65CE17F4440A1F5F065A27A4C4004CAA65CE17F44408D0C7217617A4C40B456B439CE7F44408D0C7217617A4C40
34226	54107	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	Тарковского	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
34104	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	площадь Сехская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34041	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	переулок Фабричный	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34191	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Ярославская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34200	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Советская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34190	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Свердлова	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34193	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Кооперативная	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34132	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Зинаиды Касаткиной	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34198	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Дуниловская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
33984	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Вихрева	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34147	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Аникина	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34224	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	2-я Первомайская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34098	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	2-я Мичуринская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
33971	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	2-я Металлистов	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34144	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	11-я Мичуринская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34093	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	1-я Текстильная	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34196	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	1-я Нагорная	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34173	54083	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	1-я Московская	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34137	54100	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Колосова	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
34421	54100	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Демьяна бедного	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
33968	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	пр. Красноармейский	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
34201	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	пл.Ленина	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
33966	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	Шестагинская	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
34195	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	Чапаева	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
34203	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	Октябрьская	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
34209	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	Молодежная	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
34029	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	Ленинская	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
33926	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	Лежневская	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
33941	54076	40.484805999999999	40.581842000000002	56.877135000000003	56.831566000000002	Гвардейская	0103000020E61000000100000005000000C9737D1F0E3E4440973B33C1706A4C40C9737D1F0E3E4440A796ADF545704C4039B874CC794A4440A796ADF545704C4039B874CC794A4440973B33C1706A4C40C9737D1F0E3E4440973B33C1706A4C40
34157	54104	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	площадь Ленина	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34180	54104	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	мкр. Гагарина	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34257	54105	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	Радищева	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
34223	54105	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	Калинина	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
34110	54094	41.264113000000002	41.316457	57.399667000000001	57.364691000000001	Социалистическая	0103000020E6100000010000000500000067B96C74CEA14440A112D731AEAE4C4067B96C74CEA144402D25CB4928B34C408ECBB8A981A844402D25CB4928B34C408ECBB8A981A84440A112D731AEAE4C4067B96C74CEA14440A112D731AEAE4C40
34279	54109	41.485214999999997	41.532862000000002	57.465733	57.448134000000003	Корнилова	0103000020E61000000100000005000000AA436E861BBE4440E31C75745CB94C40AA436E861BBE444080D591239DBB4C40FDA36FD234C4444080D591239DBB4C40FDA36FD234C44440E31C75745CB94C40AA436E861BBE4440E31C75745CB94C40
34154	54103	41.925775999999999	41.996284000000003	57.480649	57.455585999999997	Энгельса	0103000020E61000000100000005000000FAB5F5D37FF64440FA415DA450BA4C40FAB5F5D37FF6444074ED0BE885BD4C4098C3EE3B86FF444074ED0BE885BD4C4098C3EE3B86FF4440FA415DA450BA4C40FAB5F5D37FF64440FA415DA450BA4C40
34140	54092	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	переулок Ивановский	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
34146	54092	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	Советская	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
34138	54092	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	Октябрьская	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
34058	54092	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	Кочетовой	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
34100	54092	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	Ивановская	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
34123	54092	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	8 Марта	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
34102	54095	40.356338000000001	40.391829999999999	57.042841000000003	57.014111	Советская 	0103000020E610000001000000050000003929CC7B9C2D4440C6C1A563CE814C403929CC7B9C2D4440C7F65AD07B854C40BCCB457C27324440C7F65AD07B854C40BCCB457C27324440C6C1A563CE814C403929CC7B9C2D4440C6C1A563CE814C40
33979	21279	40.955595000000002	40.981403999999998	56.953968000000003	56.941600999999999	Школьная	0103000020E610000001000000050000004E9CDCEF507A4440C170AE6186784C404E9CDCEF507A44401CB7989F1B7A4C40F01472A59E7D44401CB7989F1B7A4C40F01472A59E7D4440C170AE6186784C404E9CDCEF507A4440C170AE6186784C40
34003	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	им. Юрия Горохова	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34060	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	им. 50 лет Комсомола	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33945	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Юрьевецкая	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33996	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Щорса	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33903	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Фабричный двор	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34009	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Спортиваная	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33937	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Социалистическая	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33925	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Правды	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33969	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Наволокская	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34077	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Межевая	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34115	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Ломоносова	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33940	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Ленина	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33995	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Котовского	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34086	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Королева	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34016	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Ивана Виноградова	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34085	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Волжский бульвар	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34076	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Воеводы Боборыкина	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34118	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Вичугская 	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33934	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Вичугская	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33915	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	Веснина	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33900	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	50-летия Комсомола	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33936	6105	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	3 Трудовой пер	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
33899	429	40.962297	40.975591999999999	56.988860000000003	56.965142	улица Ташкентская	0103000020E61000000100000005000000FB04508C2C7B44407EFFE6C5897B4C40FB04508C2C7B44404A29E8F6927E4C409F1EDB32E07C44404A29E8F6927E4C409F1EDB32E07C44407EFFE6C5897B4C40FB04508C2C7B44407EFFE6C5897B4C40
34090	429	40.958461	40.966563999999998	56.978977	56.978070000000002	улица Нефедова	0103000020E61000000100000005000000E8BE9CD9AE7A44407099D365317D4C40E8BE9CD9AE7A4440A2444B1E4F7D4C40D7BE805EB87B4440A2444B1E4F7D4C40D7BE805EB87B44407099D365317D4C40E8BE9CD9AE7A44407099D365317D4C40
3353	429	40.947268000000001	40.952640000000002	57.006044000000003	56.996999000000002	улица Ленинградская	0103000020E610000001000000050000000F46EC13407944408692C9A99D7F4C400F46EC1340794440242BBF0CC6804C40446E861BF0794440242BBF0CC6804C40446E861BF07944408692C9A99D7F4C400F46EC13407944408692C9A99D7F4C40
34012	429	40.971693000000002	40.978628	57.013758000000003	57.013170000000002	улица 9 Января	0103000020E610000001000000050000004660AC6F607C4440E8A4F78DAF814C404660AC6F607C4440790778D2C2814C409679ABAE437D4440790778D2C2814C409679ABAE437D4440E8A4F78DAF814C404660AC6F607C4440E8A4F78DAF814C40
33901	429	40.888095999999997	40.891311999999999	57.004524000000004	57.001283999999998	улица 1-я Талицкая	0103000020E61000000100000005000000ADDA3521AD7144400801F9122A804C40ADDA3521AD7144400806103E94804C402444F982167244400806103E94804C402444F982167244400801F9122A804C40ADDA3521AD7144400801F9122A804C40
33963	429	41.041545999999997	41.058309000000001	56.987237	56.969994999999997	маршала Жаворонкова	0103000020E61000000100000005000000CAA31B61518544404A24D1CB287C4C40CAA31B6151854440593332C85D7E4C40FF0758AB76874440593332C85D7E4C40FF0758AB768744404A24D1CB287C4C40CAA31B61518544404A24D1CB287C4C40
34000	429	40.993881000000002	41.004868000000002	56.965398	56.949981999999999	маршала Василевского	0103000020E61000000100000005000000D28E1B7E377F4440F3E49A0299794C40D28E1B7E377F4440D9CF6229927B4C400266BE839F804440D9CF6229927B4C400266BE839F804440F3E49A0299794C40D28E1B7E377F4440F3E49A0299794C40
34117	429	40.973830999999997	41.007913000000002	56.975014000000002	56.971178000000002	генерала Хлебникова	0103000020E610000001000000050000005D6A847EA67C44401F4C8A8F4F7C4C405D6A847EA67C444032923D42CD7C4C404C1B0E4B0381444032923D42CD7C4C404C1B0E4B038144401F4C8A8F4F7C4C405D6A847EA67C44401F4C8A8F4F7C4C40
33929	429	40.952962999999997	40.968772999999999	57.022509999999997	57.018971999999998	академика Мальцева	0103000020E6100000010000000500000026A60BB1FA79444015C5ABAC6D824C4026A60BB1FA7944409EEA909BE1824C40B81FF0C0007C44409EEA909BE1824C40B81FF0C0007C444015C5ABAC6D824C4026A60BB1FA79444015C5ABAC6D824C40
33988	429	41.005515000000003	41.034198000000004	57.025526999999997	57.016483000000001	Шувандиной	0103000020E6100000010000000500000098512CB7B480444051F86C1D1C824C4098512CB7B48044401E15FF7744834C4058CB9D99608444401E15FF7744834C4058CB9D996084444051F86C1D1C824C4098512CB7B480444051F86C1D1C824C40
34024	429	40.991959000000001	41.002935999999998	57.010793	57.005980000000001	Шошина	0103000020E6100000010000000500000087FC3383F87E44400D37E0F3C3804C4087FC3383F87E44404B033FAA61814C4093FDF334608044404B033FAA61814C4093FDF334608044400D37E0F3C3804C4087FC3383F87E44400D37E0F3C3804C40
34162	429	41.008020999999999	41.013041999999999	57.013517999999998	57.013004000000002	Чайковского	0103000020E61000000100000005000000325706D506814440CD5B751DAA814C40325706D50681444023F433F5BA814C40BABC395CAB81444023F433F5BA814C40BABC395CAB814440CD5B751DAA814C40325706D506814440CD5B751DAA814C40
34131	429	41.012647000000001	41.018073000000001	57.038733000000001	57.032111	Хвойная	0103000020E610000001000000050000003EB2B96A9E814440C26B97361C844C403EB2B96A9E8144405323F433F5844C4066F84F37508244405323F433F5844C4066F84F3750824440C26B97361C844C403EB2B96A9E814440C26B97361C844C40
34017	429	40.965611000000003	40.970120999999999	57.049618000000002	57.022632000000002	Фрунзе	0103000020E6100000010000000500000035D42824997B4440EAEBF99AE5824C4035D42824997B44407FA5F3E159864C40D714C8EC2C7C44407FA5F3E159864C40D714C8EC2C7C4440EAEBF99AE5824C4035D42824997B4440EAEBF99AE5824C40
33935	429	40.980702999999998	40.991402000000001	57.016100999999999	56.996450000000003	Фридриха Энгельса проспект	0103000020E61000000100000005000000670B08AD877D4440B30C71AC8B7F4C40670B08AD877D44406937FA980F824C403198BF42E67E44406937FA980F824C403198BF42E67E4440B30C71AC8B7F4C40670B08AD877D4440B30C71AC8B7F4C40
34114	429	40.979751	40.993288	56.986761000000001	56.982140999999999	Типографская	0103000020E61000000100000005000000959C137B687D4440C687D9CBB67D4C40959C137B687D4440F0FB372F4E7E4C402FC1A90F247F4440F0FB372F4E7E4C402FC1A90F247F4440C687D9CBB67D4C40959C137B687D4440C687D9CBB67D4C40
33897	429	40.962297	40.975591999999999	56.988860000000003	56.965142	Ташкентская	0103000020E61000000100000005000000FB04508C2C7B44407EFFE6C5897B4C40FB04508C2C7B44404A29E8F6927E4C409F1EDB32E07C44404A29E8F6927E4C409F1EDB32E07C44407EFFE6C5897B4C40FB04508C2C7B44407EFFE6C5897B4C40
33958	429	40.965620000000001	40.974684000000003	56.986938000000002	56.984445999999998	Танкиста Белороссова	0103000020E61000000100000005000000882EA86F997B4440C9569753027E4C40882EA86F997B4440FF9600FC537E4C409DF7FF71C27C4440FF9600FC537E4C409DF7FF71C27C4440C9569753027E4C40882EA86F997B4440C9569753027E4C40
33994	429	40.997554999999998	41.018234999999997	56.994695	56.993499	Суворова	0103000020E610000001000000050000000B7BDAE1AF7F4440EACDA8F92A7F4C400B7BDAE1AF7F4440533F6F2A527F4C403F52448655824440533F6F2A527F4C403F52448655824440EACDA8F92A7F4C400B7BDAE1AF7F4440EACDA8F92A7F4C40
33921	429	40.973930000000003	41.014929000000002	56.970162000000002	56.963203999999998	Строителей проспект	0103000020E61000000100000005000000F14BFDBCA97C44402DB0C7444A7B4C40F14BFDBCA97C444036E9B6442E7C4C4089618731E981444036E9B6442E7C4C4089618731E98144402DB0C7444A7B4C40F14BFDBCA97C44402DB0C7444A7B4C40
33905	429	40.972653999999999	40.977730000000001	56.998024000000001	56.995081999999996	Степанова	0103000020E610000001000000050000006B2920ED7F7C44404C6BD3D85E7F4C406B2920ED7F7C4440C24F1C40BF7F4C40B728B341267D4440C24F1C40BF7F4C40B728B341267D44404C6BD3D85E7F4C406B2920ED7F7C44404C6BD3D85E7F4C40
34112	429	40.981574000000002	41.017865999999998	56.993729000000002	56.983902	Смирнова	0103000020E610000001000000050000004D4D8237A47D4440083C3080F07D4C404D4D8237A47D44401C0B0A83327F4C40ECDADE6E498244401C0B0A83327F4C40ECDADE6E49824440083C3080F07D4C404D4D8237A47D4440083C3080F07D4C40
34091	429	41.002828999999998	41.037413999999998	57.018124	57.015483000000003	Свободы	0103000020E610000001000000050000007D3D5FB35C8044406E52D158FB814C407D3D5FB35C804440E8A221E351824C40CE3461FBC9844440E8A221E351824C40CE3461FBC98444406E52D158FB814C407D3D5FB35C8044406E52D158FB814C40
67225	429	40.977657999999998	40.979076999999997	57.033575999999996	57.03049	Светлая	0103000020E610000001000000050000001D56B8E5237D4440726DA818E7834C401D56B8E5237D44401AF7E6374C844C4005A22765527D44401AF7E6374C844C4005A22765527D4440726DA818E7834C401D56B8E5237D4440726DA818E7834C40
34015	429	40.990530999999997	41.005074	57.001274000000002	56.995871999999999	Сакко	0103000020E610000001000000050000004B5645B8C97E44404580D3BB787F4C404B5645B8C97E4440E52A16BF29804C40AB07CC43A6804440E52A16BF29804C40AB07CC43A68044404580D3BB787F4C404B5645B8C97E44404580D3BB787F4C40
33932	429	40.940998	40.953330999999999	57.009852000000002	56.996440999999997	Рабфаковская	0103000020E61000000100000005000000FBCC599F727844405FB2F1608B7F4C40FBCC599F727844406DE690D442814C40A9A10DC0067A44406DE690D442814C40A9A10DC0067A44405FB2F1608B7F4C40FBCC599F727844405FB2F1608B7F4C40
33902	429	40.980200000000004	40.987062999999999	56.950816000000003	56.946727000000003	Профессиональная	0103000020E6100000010000000500000005C58F31777D4440BF9EAF592E794C4005C58F31777D4440BC41B456B4794C40BB0B9414587E4440BC41B456B4794C40BB0B9414587E4440BF9EAF592E794C4005C58F31777D4440BF9EAF592E794C40
33959	429	40.952917999999997	40.973840000000003	56.998852999999997	56.991734000000001	Почтовая	0103000020E6100000010000000500000086E28E37F9794440672AC423F17E4C4086E28E37F97944407841446ADA7F4C40B1C403CAA67C44407841446ADA7F4C40B1C403CAA67C4440672AC423F17E4C4086E28E37F9794440672AC423F17E4C40
34455	429	40.952917999999997	40.973840000000003	56.998852999999997	56.991734000000001	Почтова	0103000020E6100000010000000500000086E28E37F9794440672AC423F17E4C4086E28E37F97944407841446ADA7F4C40B1C403CAA67C44407841446ADA7F4C40B1C403CAA67C4440672AC423F17E4C4086E28E37F9794440672AC423F17E4C40
33933	429	40.976131000000002	40.991869000000001	57.045740000000002	57.019525999999999	Полка Нормандия-Неман	0103000020E610000001000000050000004FCE50DCF17C4440FAB5F5D37F824C404FCE50DCF17C44403D0FEECEDA854C4047753A90F57E44403D0FEECEDA854C4047753A90F57E4440FAB5F5D37F824C404FCE50DCF17C4440FAB5F5D37F824C40
34164	429	40.982311000000003	40.982581000000003	56.967140000000001	56.964101999999997	Полевой проезд	0103000020E6100000010000000500000023C0E95DBC7D44400C01C0B1677B4C4023C0E95DBC7D4440A453573ECB7B4C40E355D636C57D4440A453573ECB7B4C40E355D636C57D44400C01C0B1677B4C4023C0E95DBC7D44400C01C0B1677B4C40
34048	429	40.897348000000001	40.962125999999998	57.000951000000001	56.995764000000001	Парижской Коммуны	0103000020E61000000100000005000000C5909C4CDC7244405F44DB31757F4C40C5909C4CDC72444002F390291F804C40CE50DCF1267B444002F390291F804C40CE50DCF1267B44405F44DB31757F4C40C5909C4CDC7244405F44DB31757F4C40
33895	429	40.998857999999998	41.011614000000002	56.972383999999998	56.967503000000001	Панина	0103000020E610000001000000050000008AAC3594DA7F444015E46723D77B4C408AAC3594DA7F4440AB933314777C4C407F164B917C814440AB933314777C4C407F164B917C81444015E46723D77B4C408AAC3594DA7F444015E46723D77B4C40
33892	429	41.018099999999997	41.074730000000002	57.005136999999998	56.993611999999999	Окуловой	0103000020E610000001000000050000005F07CE1951824440E27492AD2E7F4C405F07CE1951824440F17F4754A8804C40DA03ADC090894440F17F4754A8804C40DA03ADC090894440E27492AD2E7F4C405F07CE1951824440E27492AD2E7F4C40
34066	429	40.979247999999998	41.002828999999998	57.023083	57.016463000000002	Носова	0103000020E6100000010000000500000032569BFF577D44400A4CA7751B824C4032569BFF577D4440FA0B3D62F4824C407D3D5FB35C804440FA0B3D62F4824C407D3D5FB35C8044400A4CA7751B824C4032569BFF577D44400A4CA7751B824C40
34150	429	41.001840000000001	41.007472999999997	56.956068000000002	56.952922000000001	Новосельская	0103000020E610000001000000050000008EE9094B3C804440C8D11C59F9794C408EE9094B3C8044404660AC6F607A4C402F4D11E0F48044404660AC6F607A4C402F4D11E0F4804440C8D11C59F9794C408EE9094B3C804440C8D11C59F9794C40
34128	429	40.952379000000001	40.95476	56.988349999999997	56.965730999999998	Некрасова	0103000020E61000000100000005000000D732198EE7794440DFDDCA129D7B4C40D732198EE77944403480B740827E4C40B5C35F93357A44403480B740827E4C40B5C35F93357A4440DFDDCA129D7B4C40D732198EE7794440DFDDCA129D7B4C40
34133	429	40.979751	40.983057000000002	56.993429999999996	56.986761000000001	Московская	0103000020E61000000100000005000000959C137B687D4440F0FB372F4E7E4C40959C137B687D4440C16ED8B6287F4C404C8DD0CFD47D4440C16ED8B6287F4C404C8DD0CFD47D4440F0FB372F4E7E4C40959C137B687D4440F0FB372F4E7E4C40
33893	429	40.924548999999999	40.950789	57.053758999999999	57.028516000000003	Минская	0103000020E610000001000000050000005646239F57764440D5B48B69A6834C405646239F57764440CE6E2D93E1864C40C2323674B3794440CE6E2D93E1864C40C2323674B3794440D5B48B69A6834C405646239F57764440D5B48B69A6834C40
33938	429	40.867938000000002	41.125475999999999	57.07038	56.946736999999999	Микрорайон ТЭЦ № 3	0103000020E61000000100000005000000537AA697186F4440E27492AD2E794C40537AA697186F444070253B3602894C406937FA980F90444070253B3602894C406937FA980F904440E27492AD2E794C40537AA697186F4440E27492AD2E794C40
33998	429	40.993881000000002	41.004868000000002	56.965398	56.949981999999999	Маршала Василевского	0103000020E61000000100000005000000D28E1B7E377F4440F3E49A0299794C40D28E1B7E377F4440D9CF6229927B4C400266BE839F804440D9CF6229927B4C400266BE839F804440F3E49A0299794C40D28E1B7E377F4440F3E49A0299794C40
34135	429	40.957275000000003	40.966348000000004	57.002554000000003	56.997391999999998	Мархлевского	0103000020E61000000100000005000000A323B9FC877A444061A5828AAA7F4C40A323B9FC877A4440AC3C81B053804C400B47904AB17B4440AC3C81B053804C400B47904AB17B444061A5828AAA7F4C40A323B9FC877A444061A5828AAA7F4C40
34018	429	41.004913000000002	41.035868999999998	56.960872999999999	56.951695000000001	Любимова	0103000020E61000000100000005000000A2293BFDA080444024624A24D1794C40A2293BFDA0804440014EEFE2FD7A4C4059F8FA5A97844440014EEFE2FD7A4C4059F8FA5A9784444024624A24D1794C40A2293BFDA080444024624A24D1794C40
34139	429	40.926121000000002	40.932338000000001	56.999366999999999	56.989266999999998	Линия 19 	0103000020E61000000100000005000000C59107228B7644408A01124DA07E4C40C59107228B764440CFD90242EB7F4C40B66801DA56774440CFD90242EB7F4C40B66801DA567744408A01124DA07E4C40C59107228B7644408A01124DA07E4C40
34049	429	40.978538	40.984538999999998	56.97963	56.974787999999997	Летчика Лазарева	0103000020E6100000010000000500000056F2B1BB407D444041446ADAC57C4C4056F2B1BB407D44401A170E84647D4C407A51BB5F057E44401A170E84647D4C407A51BB5F057E444041446ADAC57C4C4056F2B1BB407D444041446ADAC57C4C40
34186	429	40.947268000000001	40.952640000000002	57.006044000000003	56.996999000000002	Ленинградская	0103000020E610000001000000050000000F46EC13407944408692C9A99D7F4C400F46EC1340794440242BBF0CC6804C40446E861BF0794440242BBF0CC6804C40446E861BF07944408692C9A99D7F4C400F46EC13407944408692C9A99D7F4C40
33987	429	40.967551999999998	40.981332000000002	57.022646999999999	56.995474999999999	Ленина проспект	0103000020E61000000100000005000000F69672BED87B4440287E8CB96B7F4C40F69672BED87B44401F2DCE18E6824C40574277499C7D44401F2DCE18E6824C40574277499C7D4440287E8CB96B7F4C40F69672BED87B4440287E8CB96B7F4C40
3983	429	40.971243999999999	40.973165999999999	57.011983999999998	57.010283999999999	Ленина площадь	0103000020E61000000100000005000000D63730B9517C444006D671FC50814C40D63730B9517C4440A20914B188814C4021CA17B4907C4440A20914B188814C4021CA17B4907C444006D671FC50814C40D63730B9517C444006D671FC50814C40
34019	429	40.973174999999998	40.986415999999998	56.992690000000003	56.954718999999997	Лежневская	0103000020E61000000100000005000000742497FF907C444056EF703B347A4C40742497FF907C44407B884677107F4C40252026E1427E44407B884677107F4C40252026E1427E444056EF703B347A4C40742497FF907C444056EF703B347A4C40
34025	429	40.966644000000002	40.968530999999999	56.972045999999999	56.966217	Куликова	0103000020E61000000100000005000000F46F97FDBA7B44406CEBA7FFAC7B4C40F46F97FDBA7B4440931ADA006C7C4C40C214E5D2F87B4440931ADA006C7C4C40C214E5D2F87B44406CEBA7FFAC7B4C40F46F97FDBA7B44406CEBA7FFAC7B4C40
34167	429	40.925753	40.969940999999999	57.017251999999999	56.996293000000001	Кузнецова	0103000020E61000000100000005000000429605137F764440EB1D6E87867F4C40429605137F76444032E5435035824C405706D506277C444032E5435035824C405706D506277C4440EB1D6E87867F4C40429605137F764440EB1D6E87867F4C40
34013	429	40.974595000000001	40.986182999999997	56.979149	56.953451999999999	Кудряшова	0103000020E610000001000000050000002DEC6987BF7C4440242713B70A7A4C402DEC6987BF7C44409F7422C1547D4C40826F9A3E3B7E44409F7422C1547D4C40826F9A3E3B7E4440242713B70A7A4C402DEC6987BF7C4440242713B70A7A4C40
34125	429	41.038536999999998	41.052847	56.957045000000001	56.947845999999998	Кохомское шоссе	0103000020E61000000100000005000000CD57C9C7EE8444407CD2890453794C40CD57C9C7EE84444071E65773807A4C408A58C4B0C386444071E65773807A4C408A58C4B0C38644407CD2890453794C40CD57C9C7EE8444407CD2890453794C40
34020	429	40.970103000000002	40.989362999999997	57.008949999999999	57.007666	Комсомольская	0103000020E610000001000000050000003160C9552C7C444044A51133FB804C403160C9552C7C44404CA60A4625814C40AC6F6072A37E44404CA60A4625814C40AC6F6072A37E444044A51133FB804C403160C9552C7C444044A51133FB804C40
34063	429	40.993243999999997	41.012574999999998	56.998038999999999	56.991140000000001	Колотилова	0103000020E610000001000000050000005F79909E227F4440F4E0EEACDD7E4C405F79909E227F4440F790F0BDBF7F4C40A4DFBE0E9C814440F790F0BDBF7F4C40A4DFBE0E9C814440F4E0EEACDD7E4C405F79909E227F4440F4E0EEACDD7E4C40
33985	429	40.994312999999998	41.000107	56.984549000000001	56.981822000000001	Колесанова	0103000020E610000001000000050000006B7EFCA5457F4440253FE257AC7D4C406B7EFCA5457F44409E279EB3057E4C4016C09481038044409E279EB3057E4C4016C0948103804440253FE257AC7D4C406B7EFCA5457F4440253FE257AC7D4C40
34111	429	40.969681000000001	40.983747999999999	57.016409000000003	57.016100999999999	Карла Маркса	0103000020E61000000100000005000000BB46CB811E7C44406937FA980F824C40BB46CB811E7C4440172EABB019824C40B1C05774EB7D4440172EABB019824C40B1C05774EB7D44406937FA980F824C40BB46CB811E7C44406937FA980F824C40
34120	429	40.950339999999997	40.969698999999999	57.021348000000003	57.01688	Ермака	0103000020E61000000100000005000000520ABABDA47944406EFAB31F29824C40520ABABDA4794440E2EA0088BB824C4061FBC9181F7C4440E2EA0088BB824C4061FBC9181F7C44406EFAB31F29824C40520ABABDA47944406EFAB31F29824C40
34061	429	40.976283000000002	40.986848000000002	57.007714999999997	57.007108000000002	Дунаева	0103000020E61000000100000005000000055262D7F67C44401EC539EAE8804C40055262D7F67C444025581CCEFC804C40BF0F0709517E444025581CCEFC804C40BF0F0709517E44401EC539EAE8804C40055262D7F67C44401EC539EAE8804C40
34084	429	40.867938000000002	41.125475999999999	57.07038	56.946736999999999	Героя Советского Союза Сахарова П.И	0103000020E61000000100000005000000537AA697186F4440E27492AD2E794C40537AA697186F444070253B3602894C406937FA980F90444070253B3602894C406937FA980F904440E27492AD2E794C40537AA697186F4440E27492AD2E794C40
34182	429	40.929983999999997	40.941625999999999	57.015076000000001	57.007798999999999	Героя Советского Союза Сахарова	0103000020E61000000100000005000000D1E638B70977444083F8C08EFF804C40D1E638B7097744402D7AA702EE814C401A886533877844402D7AA702EE814C401A8865338778444083F8C08EFF804C40D1E638B70977444083F8C08EFF804C40
33894	429	40.962736999999997	40.973984000000002	56.972492000000003	56.971629	Воронина	0103000020E6100000010000000500000017D34CF73A7B44402F6CCD565E7C4C4017D34CF73A7B444092CF2B9E7A7C4C40E469F981AB7C444092CF2B9E7A7C4C40E469F981AB7C44402F6CCD565E7C4C4017D34CF73A7B44402F6CCD565E7C4C40
34046	429	40.941868999999997	40.946513000000003	56.988002000000002	56.980100999999998	Володиной	0103000020E61000000100000005000000E00ED4298F78444071E316F3737D4C40E00ED4298F784440F9307BD9767E4C40931E865627794440F9307BD9767E4C40931E86562779444071E316F3737D4C40E00ED4298F78444071E316F3737D4C40
34134	429	40.946513000000003	40.973049000000003	56.995165999999998	56.988002000000002	Большая Воробьевская	0103000020E61000000100000005000000931E865627794440F9307BD9767E4C40931E865627794440AA0B7899617F4C40E833A0DE8C7C4440AA0B7899617F4C40E833A0DE8C7C4440F9307BD9767E4C40931E865627794440F9307BD9767E4C40
33990	429	40.929858000000003	40.952306999999998	56.994062999999997	56.988545999999999	Бакинский проезд	0103000020E6100000010000000500000045F6419605774440BA4BE2AC887E4C4045F6419605774440F294D5743D7F4C403D601E32E5794440F294D5743D7F4C403D601E32E5794440BA4BE2AC887E4C4045F6419605774440BA4BE2AC887E4C40
34080	429	40.968944	40.980901000000003	56.995749000000004	56.989811000000003	Багаева	0103000020E61000000100000005000000E5D3635B067C44404C1C7920B27E4C40E5D3635B067C44402A0307B4747F4C408ECEF9298E7D44402A0307B4747F4C408ECEF9298E7D44404C1C7920B27E4C40E5D3635B067C44404C1C7920B27E4C40
34052	429	40.980702999999998	40.993504000000001	57.001283999999998	56.995725	Арсения	0103000020E61000000100000005000000670B08AD877D4440A167B3EA737F4C40670B08AD877D44400801F9122A804C40FC389A232B7F44400801F9122A804C40FC389A232B7F4440A167B3EA737F4C40670B08AD877D4440A167B3EA737F4C40
34064	429	40.912053999999998	40.933639999999997	57.038943000000003	57.035426999999999	Апрельская	0103000020E61000000100000005000000CE177B2FBE7444409C3237DF88844C40CE177B2FBE7444403EB48F15FC844C40641EF983817744403EB48F15FC844C40641EF983817744409C3237DF88844C40CE177B2FBE7444409C3237DF88844C40
34126	429	41.013598999999999	41.018855000000002	57.025224000000001	57.014311999999997	Академическая	0103000020E610000001000000050000001021AE9CBD8144405DF8C1F9D4814C401021AE9CBD81444083893F8A3A834C40DC2E34D76982444083893F8A3A834C40DC2E34D7698244405DF8C1F9D4814C401021AE9CBD8144405DF8C1F9D4814C40
33907	429	40.941986	40.943773	56.996416000000004	56.994748999999999	9-я линия	0103000020E610000001000000050000001AA54BFF92784440465D6BEF537F4C401AA54BFF92784440079B3A8F8A7F4C4085ECBC8DCD784440079B3A8F8A7F4C4085ECBC8DCD784440465D6BEF537F4C401AA54BFF92784440465D6BEF537F4C40
34181	429	40.984206999999998	41.007662000000003	56.955537999999997	56.953118000000003	5-я Коляновская	0103000020E6100000010000000500000044BFB67EFA7D44404E9D47C5FF794C4044BFB67EFA7D4440E90AB6114F7A4C4003B68311FB804440E90AB6114F7A4C4003B68311FB8044404E9D47C5FF794C4044BFB67EFA7D44404E9D47C5FF794C40
33931	429	41.022151000000001	41.025438999999999	57.004004999999999	56.986437000000002	4-я Сосневская	0103000020E610000001000000050000006F490ED8D58244403D484F91437E4C406F490ED8D58244409F02603C83804C407F85CC95418344409F02603C83804C407F85CC95418344403D484F91437E4C406F490ED8D58244403D484F91437E4C40
34065	429	40.975143000000003	40.991869000000001	57.037649999999999	57.036529000000002	4-я Деревенская	0103000020E6100000010000000500000030F65E7CD17C4440842D76FBAC844C4030F65E7CD17C4440E25817B7D1844C4047753A90F57E4440E25817B7D1844C4047753A90F57E4440842D76FBAC844C4030F65E7CD17C4440842D76FBAC844C40
34021	429	41.023589000000001	41.023732000000003	57.007029000000003	57.005412	4-й Котельницкий переулок	0103000020E61000000100000005000000CEC5DFF604834440C3802557B1804C40CEC5DFF604834440D28F8653E6804C4031EF71A609834440D28F8653E6804C4031EF71A609834440C3802557B1804C40CEC5DFF604834440C3802557B1804C40
34166	429	40.993630000000003	41.007275	56.973218000000003	56.964911999999998	30 микрорайон	0103000020E61000000100000005000000892991442F7F44404CC2853C827B4C40892991442F7F444074F04C68927C4C40098A1F63EE80444074F04C68927C4C40098A1F63EE8044404CC2853C827B4C40892991442F7F44404CC2853C827B4C40
9738	429	41.018234999999997	41.024568000000002	57.003667	56.986922999999997	3-я Сосневская	0103000020E610000001000000050000003F52448655824440C9552C7E537E4C403F524486558244408789062978804C409A43520B258344408789062978804C409A43520B25834440C9552C7E537E4C403F52448655824440C9552C7E537E4C40
33957	429	41.068064	41.074325999999999	56.987378999999997	56.981783	2-я Ягодная	0103000020E6100000010000000500000079043752B68844406762BA10AB7D4C4079043752B6884440EBE0606F627E4C400A9FAD8383894440EBE0606F627E4C400A9FAD83838944406762BA10AB7D4C4079043752B68844406762BA10AB7D4C40
34160	429	40.920264000000003	40.930478000000001	57.033971999999999	57.029153000000001	2-я Ключевая	0103000020E61000000100000005000000D4D7F335CB75444047CA1649BB834C40D4D7F335CB754440677DCA3159844C40E1D231E719774440677DCA3159844C40E1D231E71977444047CA1649BB834C40D4D7F335CB75444047CA1649BB834C40
34130	429	40.914909999999999	40.94115	56.977927999999999	56.974052	13-я Березниковская	0103000020E61000000100000005000000456458C51B7544403C4D66BCAD7C4C40456458C51B754440DDEBA4BE2C7D4C40B1506B9A77784440DDEBA4BE2C7D4C40B1506B9A777844403C4D66BCAD7C4C40456458C51B7544403C4D66BCAD7C4C40
34083	429	41.020812999999997	41.038077999999999	56.990473000000001	56.989395000000002	10-й проезд	0103000020E61000000100000005000000732A1900AA824440B8E9CF7EA47E4C40732A1900AA8244401749BBD1C77E4C403A596ABDDF8444401749BBD1C77E4C403A596ABDDF844440B8E9CF7EA47E4C40732A1900AA824440B8E9CF7EA47E4C40
34163	429	40.867938000000002	41.125475999999999	57.07038	56.946736999999999	10 Августа	0103000020E61000000100000005000000537AA697186F4440E27492AD2E794C40537AA697186F444070253B3602894C406937FA980F90444070253B3602894C406937FA980F904440E27492AD2E794C40537AA697186F4440E27492AD2E794C40
34023	429	40.966284999999999	40.97587	57.034056	57.032949000000002	1-я Минеевская	0103000020E61000000100000005000000C4CE143AAF7B4440CCB73EAC37844C40C4CE143AAF7B4440C51D6FF25B844C40E292E34EE97C4440C51D6FF25B844C40E292E34EE97C4440CCB73EAC37844C40C4CE143AAF7B4440CCB73EAC37844C40
34027	429	41.029482000000002	41.031762999999998	56.990046999999997	56.987453000000002	1-я Меланжевая	0103000020E610000001000000050000000CE9F010C683444026AB22DC647E4C400CE9F010C68344405F402FDCB97E4C40861C5BCF108444405F402FDCB97E4C40861C5BCF1084444026AB22DC647E4C400CE9F010C683444026AB22DC647E4C40
34004	429	40.950339999999997	40.961900999999997	57.026609999999998	57.021348000000003	1-й Северный переулок	0103000020E61000000100000005000000520ABABDA4794440E2EA0088BB824C40520ABABDA47944408FDFDBF467834C40AE7E6C921F7B44408FDFDBF467834C40AE7E6C921F7B4440E2EA0088BB824C40520ABABDA4794440E2EA0088BB824C40
34107	54096	42.105114999999998	42.193752000000003	57.502479000000001	57.454109000000003	переулок Парковский	0103000020E61000000100000005000000D6A88768740D4540DEE8633E20BA4C40D6A88768740D4540A1F65B3B51C04C406EC493DDCC184540A1F65B3B51C04C406EC493DDCC184540DEE8633E20BA4C40D6A88768740D4540DEE8633E20BA4C40
34238	54096	42.105114999999998	42.193752000000003	57.502479000000001	57.454109000000003	Почтовая	0103000020E61000000100000005000000D6A88768740D4540DEE8633E20BA4C40D6A88768740D4540A1F65B3B51C04C406EC493DDCC184540A1F65B3B51C04C406EC493DDCC184540DEE8633E20BA4C40D6A88768740D4540DEE8633E20BA4C40
34437	54123	40.983524000000003	40.998156999999999	57.001612999999999	56.995052999999999	Садовая	0103000020E61000000100000005000000626A4B1DE47D4440B2648EE55D7F4C40626A4B1DE47D4440CD1FD3DA34804C4001A3CB9BC37F4440CD1FD3DA34804C4001A3CB9BC37F4440B2648EE55D7F4C40626A4B1DE47D4440B2648EE55D7F4C40
34205	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Ульяновская	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34055	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Покровская	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34050	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Парковая	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
33973	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Н.П. Куликовой	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
33923	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Металлистов	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
33981	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Ленинская	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34184	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Ленинградская	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34051	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Желябова	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34202	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Дачная	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34188	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Володарского	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34207	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Б.Хмельницкого	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
33962	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Б-Пролетарская	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34211	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	Абрамовой	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34142	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	50-лет Октября	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34033	54075	41.861645000000003	41.964717999999998	57.237324000000001	57.185709000000003	1-Ломоносова	0103000020E6100000010000000500000087E123624AEE444054C90050C5974C4087E123624AEE4440284701A2609E4C4067EE21E17BFB4440284701A2609E4C4067EE21E17BFB444054C90050C5974C4087E123624AEE444054C90050C5974C40
34347	46088	43.081215999999998	43.093567999999998	57.300815	57.292524	Молодежная	0103000020E61000000100000005000000BAF42F49658A4540C6A52A6D71A54C40BAF42F49658A4540B8921D1B81A64C40DFF94509FA8B4540B8921D1B81A64C40DFF94509FA8B4540C6A52A6D71A54C40BAF42F49658A4540C6A52A6D71A54C40
33986	3460	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	Школьная	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
34269	3460	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	Чкалова	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
33980	3460	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	Титова	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
33954	3460	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	Советская	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
34284	3460	43.065216999999997	43.123759999999997	57.340646	57.269238999999999	Промышленная	0103000020E610000001000000050000005512D9075988454064E76D6C76A24C405512D90759884540B1C1C2499AAB4C40C746205ED78F4540B1C1C2499AAB4C40C746205ED78F454064E76D6C76A24C405512D9075988454064E76D6C76A24C40
34314	4328	42.960535999999998	42.985159000000003	57.245068000000003	57.235872000000001	Школьная	0103000020E61000000100000005000000B950F9D7F27A45406405BF0D319E4C40B950F9D7F27A4540E8A562635E9F4C40172EABB0197E4540E8A562635E9F4C40172EABB0197E45406405BF0D319E4C40B950F9D7F27A45406405BF0D319E4C40
34375	3862	43.013159000000002	43.027540999999999	57.306590999999997	57.299337000000001	Школьная	0103000020E61000000100000005000000F452B131AF814540CBBDC0AC50A64C40F452B131AF814540BC1FB75F3EA74C404A26A77686834540BC1FB75F3EA74C404A26A77686834540CBBDC0AC50A64C40F452B131AF814540CBBDC0AC50A64C40
34327	47709	43.015009999999997	43.044133000000002	57.267915000000002	57.257283999999999	Молодежная	0103000020E61000000100000005000000758E01D9EB8145405CE49EAEEEA04C40758E01D9EB814540CE8DE9094BA24C4052D66F26A6854540CE8DE9094BA24C4052D66F26A68545405CE49EAEEEA04C40758E01D9EB8145405CE49EAEEEA04C40
34397	46012	42.941806	42.963571999999999	57.322519999999997	57.316124000000002	Cоветская	0103000020E610000001000000050000009A9658198D78454088BD50C076A84C409A9658198D7845402827DA5548A94C40B0ABC953567B45402827DA5548A94C40B0ABC953567B454088BD50C076A84C409A9658198D78454088BD50C076A84C40
34321	4452	42.952272000000001	42.972195999999997	57.183661000000001	57.173009999999998	Реформатовского	0103000020E61000000100000005000000C172840CE4794540C3F0113125964C40C172840CE47945407C46223482974C40A8A624EB707C45407C46223482974C40A8A624EB707C4540C3F0113125964C40C172840CE4794540C3F0113125964C40
34313	37443	42.985294000000003	43.003008000000001	57.148527000000001	57.140675000000002	Нагорная 	0103000020E61000000100000005000000F778211D1E7E4540B22E6EA301924C40F778211D1E7E454058C9C7EE02934C402DD0EE906280454058C9C7EE02934C402DD0EE9062804540B22E6EA301924C40F778211D1E7E4540B22E6EA301924C40
34297	46076	42.751283000000001	42.783163999999999	57.342230000000001	57.333938000000003	Советская	0103000020E610000001000000050000003885950A2A6045402272FA7ABEAA4C403885950A2A604540E4DA5031CEAB4C40C8B3CBB73E644540E4DA5031CEAB4C40C8B3CBB73E6445402272FA7ABEAA4C403885950A2A6045402272FA7ABEAA4C40
34376	3887	43.039920000000002	43.055883000000001	57.350675000000003	57.340651000000001	Волжская	0103000020E61000000100000005000000693A3B191C854540C32CB4739AAB4C40693A3B191C8545402D431CEBE2AC4C4081B3942C278745402D431CEBE2AC4C4081B3942C27874540C32CB4739AAB4C40693A3B191C854540C32CB4739AAB4C40
34396	4388	42.720632000000002	42.737169999999999	57.264882999999998	57.254109999999997	Набережная	0103000020E61000000100000005000000BD395CAB3D5C454014CB2DAD86A04C40BD395CAB3D5C45401822A7AFE7A14C40D1CB28965B5E45401822A7AFE7A14C40D1CB28965B5E454014CB2DAD86A04C40BD395CAB3D5C454014CB2DAD86A04C40
34417	46264	42.881627999999999	42.899324999999997	57.225597999999998	57.221187999999998	Сиреневая	0103000020E61000000100000005000000739EB12FD970454042226DE34F9C4C40739EB12FD970454081053065E09C4C40D3BCE3141D73454081053065E09C4C40D3BCE3141D73454042226DE34F9C4C40739EB12FD970454042226DE34F9C4C40
34285	4081	42.807751000000003	42.842426000000003	57.346203000000003	57.330032000000003	Сиротина	0103000020E61000000100000005000000D9278062646745401651137D3EAA4C40D9278062646745407863416150AC4C406AA67B9DD46B45407863416150AC4C406AA67B9DD46B45401651137D3EAA4C40D9278062646745401651137D3EAA4C40
34506	46028	42.831547	42.854086000000002	57.293399000000001	57.283884999999998	Школьная	0103000020E61000000100000005000000200BD121706A45409869FB5756A44C40200BD121706A4540EDD632198EA54C4059FCA6B0526D4540EDD632198EA54C4059FCA6B0526D45409869FB5756A44C40200BD121706A45409869FB5756A44C40
34412	46128	42.698300000000003	42.714055999999999	57.280707999999997	57.271447999999999	Солнечеая	0103000020E61000000100000005000000FE65F7E4615945404548DDCEBEA24C40FE65F7E461594540DFDC5F3DEEA34C409CC1DF2F665B4540DFDC5F3DEEA34C409CC1DF2F665B45404548DDCEBEA24C40FE65F7E4615945404548DDCEBEA24C40
33920	2087	41.969631	42.053533999999999	56.601534999999998	56.568371999999997	Советская	0103000020E6100000010000000500000009185DDE1CFC444026FBE769C0484C4009185DDE1CFC44401E335019FF4C4C40AE9CBD33DA0645401E335019FF4C4C40AE9CBD33DA06454026FBE769C0484C4009185DDE1CFC444026FBE769C0484C40
34174	2087	41.969631	42.053533999999999	56.601534999999998	56.568371999999997	Речная	0103000020E6100000010000000500000009185DDE1CFC444026FBE769C0484C4009185DDE1CFC44401E335019FF4C4C40AE9CBD33DA0645401E335019FF4C4C40AE9CBD33DA06454026FBE769C0484C4009185DDE1CFC444026FBE769C0484C40
33949	2087	41.969631	42.053533999999999	56.601534999999998	56.568371999999997	Пушкина	0103000020E6100000010000000500000009185DDE1CFC444026FBE769C0484C4009185DDE1CFC44401E335019FF4C4C40AE9CBD33DA0645401E335019FF4C4C40AE9CBD33DA06454026FBE769C0484C4009185DDE1CFC444026FBE769C0484C40
34044	2087	41.969631	42.053533999999999	56.601534999999998	56.568371999999997	Новая	0103000020E6100000010000000500000009185DDE1CFC444026FBE769C0484C4009185DDE1CFC44401E335019FF4C4C40AE9CBD33DA0645401E335019FF4C4C40AE9CBD33DA06454026FBE769C0484C4009185DDE1CFC444026FBE769C0484C40
33952	2087	41.969631	42.053533999999999	56.601534999999998	56.568371999999997	Глушицкий проезд	0103000020E6100000010000000500000009185DDE1CFC444026FBE769C0484C4009185DDE1CFC44401E335019FF4C4C40AE9CBD33DA0645401E335019FF4C4C40AE9CBD33DA06454026FBE769C0484C4009185DDE1CFC444026FBE769C0484C40
34354	3347	41.692428999999997	41.71848	56.660407999999997	56.650686	Юбилейная	0103000020E61000000100000005000000A7E67283A1D8444087FBC8AD49534C40A7E67283A1D844402502D53F88544C40406A1327F7DB44402502D53F88544C40406A1327F7DB444087FBC8AD49534C40A7E67283A1D8444087FBC8AD49534C40
34307	54111	41.845852999999998	41.883356999999997	56.584094999999998	56.570554000000001	Полевая	0103000020E610000001000000050000009B1C3EE944EC44400E4DD9E907494C409B1C3EE944EC4440E960FD9FC34A4C40A9D898D711F14440E960FD9FC34A4C40A9D898D711F144400E4DD9E907494C409B1C3EE944EC44400E4DD9E907494C40
34178	2656	42.316040000000001	42.346969000000001	56.536957000000001	56.518557999999999	Ленина	0103000020E610000001000000050000002A1DACFF73284540228AC91B60424C402A1DACFF73284540DC2DC901BB444C40E8DCED7A692C4540DC2DC901BB444C40E8DCED7A692C4540228AC91B60424C402A1DACFF73284540228AC91B60424C40
34411	3277	41.816217000000002	41.846850000000003	56.655633999999999	56.644464999999997	Преображенская	0103000020E6100000010000000500000039B874CC79E84440543541D47D524C4039B874CC79E84440A5129ED0EB534C400E4FAF9465EC4440A5129ED0EB534C400E4FAF9465EC4440543541D47D524C4039B874CC79E84440543541D47D524C40
34428	2892	41.999077999999997	42.026350999999998	56.437328000000001	56.423575	Придорожная	0103000020E610000001000000050000009813B4C9E1FF44409C33A2B437364C409813B4C9E1FF444003D0285DFA374C40C39B35785F03454003D0285DFA374C40C39B35785F0345409C33A2B437364C409813B4C9E1FF44409C33A2B437364C40
34371	2464	41.998987999999997	42.016981999999999	56.60915	56.596198000000001	Центральная	0103000020E61000000100000005000000588CBAD6DEFF444066F84F37504C4C40588CBAD6DEFF4440E02D90A0F84D4C40724F57772C024540E02D90A0F84D4C40724F57772C02454066F84F37504C4C40588CBAD6DEFF444066F84F37504C4C40
34291	2688	42.340797000000002	42.373694	56.604483000000002	56.591068999999997	Школьная	0103000020E6100000010000000500000097C9703C9F2B4540F7562426A84B4C4097C9703C9F2B454076FEEDB25F4D4C40105B7A34D52F454076FEEDB25F4D4C40105B7A34D52F4540F7562426A84B4C4097C9703C9F2B4540F7562426A84B4C40
34429	2568	42.214539000000002	42.252034999999999	56.639668999999998	56.623068000000004	Центральная	0103000020E61000000100000005000000B85B9203761B4540929735B1C04F4C40B85B9203761B4540ECA17DACE0514C404339D1AE42204540ECA17DACE0514C404339D1AE42204540929735B1C04F4C40B85B9203761B4540929735B1C04F4C40
34346	2768	42.151001000000001	42.173872000000003	56.537939000000001	56.522570000000002	Восточная	0103000020E61000000100000005000000E75432005413454074EFE192E3424C40E754320054134540191F662FDB444C4056D80C7041164540191F662FDB444C4056D80C704116454074EFE192E3424C40E75432005413454074EFE192E3424C40
34345	3238	41.685979000000003	41.710369	56.552667999999997	56.542267000000002	Центральная	0103000020E61000000100000005000000145FED28CED744409B594B0169454C40145FED28CED74440DAC534D3BD464C40CE8B135FEDDA4440DAC534D3BD464C40CE8B135FEDDA44409B594B0169454C40145FED28CED744409B594B0169454C40
34344	2544	42.059157999999996	42.069749000000002	56.709038	56.700775999999998	Центральная	0103000020E61000000100000005000000FCA5457D920745402DE92807B3594C40FCA5457D9207454085CFD6C1C15A4C40E0F60489ED08454085CFD6C1C15A4C40E0F60489ED0845402DE92807B3594C40FCA5457D920745402DE92807B3594C40
34148	54093	41.317149000000001	41.438654999999997	56.882618999999998	56.821223000000003	Горелова	0103000020E61000000100000005000000C47AA35698A844408CDCD3D51D694C40C47AA35698A8444003EACDA8F9704C400A9DD7D825B8444003EACDA8F9704C400A9DD7D825B844408CDCD3D51D694C40C47AA35698A844408CDCD3D51D694C40
34365	1164	41.467697999999999	41.485413000000001	56.892758000000001	56.880189000000001	Арсения	0103000020E61000000100000005000000CA332F87DDBB444044A67C08AA704C40CA332F87DDBB4440069FE6E445724C40D106600322BE4440069FE6E445724C40D106600322BE444044A67C08AA704C40CA332F87DDBB444044A67C08AA704C40
34152	1039	41.622135999999998	41.650092000000001	56.985799999999998	56.976661999999997	5-я Клинцевская	0103000020E6100000010000000500000006D50627A2CF44407B9FAA42037D4C4006D50627A2CF4440CA32C4B12E7E4C4014B2F33636D34440CA32C4B12E7E4C4014B2F33636D344407B9FAA42037D4C4006D50627A2CF44407B9FAA42037D4C40
34253	1039	41.622135999999998	41.650092000000001	56.985799999999998	56.976661999999997	 Большая Клинцевская	0103000020E6100000010000000500000006D50627A2CF44407B9FAA42037D4C4006D50627A2CF4440CA32C4B12E7E4C4014B2F33636D34440CA32C4B12E7E4C4014B2F33636D344407B9FAA42037D4C4006D50627A2CF44407B9FAA42037D4C40
34410	1305	41.332861000000001	41.352651000000002	56.948307999999997	56.930193000000003	Школьная	0103000020E61000000100000005000000938E72309BAA4440ECFB709010774C40938E72309BAA44408044132862794C406BF3FFAA23AD44408044132862794C406BF3FFAA23AD4440ECFB709010774C40938E72309BAA4440ECFB709010774C40
34043	1876	41.323194999999998	41.347467000000002	56.830128000000002	56.826399000000002	Набережная	0103000020E61000000100000005000000889D29745EA944403B394371C7694C40889D29745EA9444038BF61A2416A4C4039B874CC79AC444038BF61A2416A4C4039B874CC79AC44403B394371C7694C40889D29745EA944403B394371C7694C40
34309	2009	41.321981999999998	41.353440999999997	56.813108999999997	56.802332	Колхозная	0103000020E6100000010000000500000049F3C7B436A944406344A2D0B2664C4049F3C7B436A94440A88AA9F413684C406308008E3DAD4440A88AA9F413684C406308008E3DAD44406344A2D0B2664C4049F3C7B436A944406344A2D0B2664C40
34306	712	41.610906999999997	41.641046000000003	56.852051000000003	56.843471999999998	Квартал 2	0103000020E61000000100000005000000E0F2583332CE4440BD8BF7E3F66B4C40E0F2583332CE444016C3D501106D4C40A69D9ACB0DD2444016C3D501106D4C40A69D9ACB0DD24440BD8BF7E3F66B4C40E0F2583332CE4440BD8BF7E3F66B4C40
34270	1734	41.395572000000001	41.409962999999998	56.881965000000001	56.875678999999998	Центральная	0103000020E610000001000000050000004E9B711AA2B24440A165DD3F16704C404E9B711AA2B24440BB9BA73AE4704C40F7C8E6AA79B44440BB9BA73AE4704C40F7C8E6AA79B44440A165DD3F16704C404E9B711AA2B24440A165DD3F16704C40
34268	1416	41.395994000000002	41.416009000000003	56.826483000000003	56.820917000000001	Зеленая	0103000020E61000000100000005000000C4B46FEEAFB244407FDDE9CE13694C40C4B46FEEAFB2444099D9E731CA694C40BCEB6CC83FB5444099D9E731CA694C40BCEB6CC83FB544407FDDE9CE13694C40C4B46FEEAFB244407FDDE9CE13694C40
34392	1065	41.518875000000001	41.545769999999997	56.897596	56.888795000000002	Центральная	0103000020E6100000010000000500000023DBF97E6AC2444096ECD808C4714C4023DBF97E6AC244409D82FC6CE4724C40A79196CADBC544409D82FC6CE4724C40A79196CADBC5444096ECD808C4714C4023DBF97E6AC2444096ECD808C4714C40
34373	951	41.198948999999999	41.228943999999998	56.774594	56.758398	Зеленая	0103000020E6100000010000000500000034492C297799444008AD872F13614C4034492C2977994440C3D66CE525634C40C64E78094E9D4440C3D66CE525634C40C64E78094E9D444008AD872F13614C4034492C297799444008AD872F13614C40
34177	556	41.314616000000001	41.377730999999997	56.721120999999997	56.697547999999998	Садовая	0103000020E6100000010000000500000030664B5645A84440F2B1BB4049594C4030664B5645A84440BABA63B14D5C4C40BAD7497D59B04440BABA63B14D5C4C40BAD7497D59B04440F2B1BB4049594C4030664B5645A84440F2B1BB4049594C40
34158	1386	41.279752000000002	41.30424	56.872264999999999	56.861593999999997	Центральная	0103000020E61000000100000005000000CC7EDDE9CEA34440043752B6486E4C40CC7EDDE9CEA3444004392861A66F4C4049111956F1A6444004392861A66F4C4049111956F1A64440043752B6486E4C40CC7EDDE9CEA34440043752B6486E4C40
34308	1846	41.439050000000002	41.449902000000002	56.943368999999997	56.938724000000001	Северная	0103000020E6100000010000000500000087A757CA32B8444033FCA71B28784C4087A757CA32B84440B587BD50C0784C40D733846396B94440B587BD50C0784C40D733846396B9444033FCA71B28784C4087A757CA32B8444033FCA71B28784C40
34266	48810	41.453288999999998	41.469360000000002	56.869776000000002	56.862056000000003	Ивановская	0103000020E610000001000000050000007A51BB5F05BA444009A9DBD9576E4C407A51BB5F05BA4440406CE9D1546F4C4079060DFD13BC4440406CE9D1546F4C4079060DFD13BC444009A9DBD9576E4C407A51BB5F05BA444009A9DBD9576E4C40
34281	46808	41.267850000000003	41.287469000000002	56.722127999999998	56.709364000000001	Половинская	0103000020E61000000100000005000000E71DA7E848A24440D97A8670CC5A4C40E71DA7E848A2444050C3B7B06E5C4C4092CEC0C8CBA4444050C3B7B06E5C4C4092CEC0C8CBA44440D97A8670CC5A4C40E71DA7E848A24440D97A8670CC5A4C40
34225	1283	41.401142	41.425477000000001	57.007807999999997	56.986089	Советская	0103000020E61000000100000005000000A986FD9E58B3444001F9122A387E4C40A986FD9E58B34440D65240DAFF804C40A019C40776B64440D65240DAFF804C40A019C40776B6444001F9122A387E4C40A986FD9E58B3444001F9122A387E4C40
34374	1187	41.322592999999998	41.345194999999997	56.972535999999998	56.959254000000001	Мира	0103000020E61000000100000005000000927538BA4AA944405247C7D5C87A4C40927538BA4AA944406117450F7C7C4C4011DF89592FAC44406117450F7C7C4C4011DF89592FAC44405247C7D5C87A4C40927538BA4AA944405247C7D5C87A4C40
34256	839	41.640084000000002	41.682099000000001	56.944307000000002	56.922269999999997	Советская	0103000020E61000000100000005000000B058C345EED144407C0A80F10C764C40B058C345EED144402331410DDF784C4031D120054FD744402331410DDF784C4031D120054FD744407C0A80F10C764C40B058C345EED144407C0A80F10C764C40
33912	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Тимирязева	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
34089	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Социалистическая	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
34032	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Советская	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
33919	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Пролетарская	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
33993	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Нижний Двор	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
34035	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Наримановская	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
34092	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Карла Либкнехта	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
33951	14742	41.071190000000001	41.155776000000003	57.278261000000001	57.227128	Возрождения	0103000020E61000000100000005000000B0E600C11C894440C100C287129D4C40B0E600C11C8944404A60730E9EA34C4038C0CC77F09344404A60730E9EA34C4038C0CC77F0934440C100C287129D4C40B0E600C11C894440C100C287129D4C40
34389	54116	41.234054999999998	41.244287	57.17201	57.168404000000002	Школьная	0103000020E610000001000000050000008E3BA583F59D4440FF4124438E954C408E3BA583F59D4440E04A766C04964C4042EBE1CB449F4440E04A766C04964C4042EBE1CB449F4440FF4124438E954C408E3BA583F59D4440FF4124438E954C40
34355	15510	40.796503999999999	40.829282999999997	57.266449999999999	57.241644000000001	Текстильная	0103000020E610000001000000050000000C91D3D7F365444027A3CA30EE9E4C400C91D3D7F365444075029A081BA24C407B1002F2256A444075029A081BA24C407B1002F2256A444027A3CA30EE9E4C400C91D3D7F365444027A3CA30EE9E4C40
34271	15510	40.796503999999999	40.829282999999997	57.266449999999999	57.241644000000001	Советская	0103000020E610000001000000050000000C91D3D7F365444027A3CA30EE9E4C400C91D3D7F365444075029A081BA24C407B1002F2256A444075029A081BA24C407B1002F2256A444027A3CA30EE9E4C400C91D3D7F365444027A3CA30EE9E4C40
33964	54081	40.950232	40.957751000000002	57.000461000000001	56.999769000000001	Строительная	0103000020E610000001000000050000006CCEC133A1794440FE463B6EF87F4C406CCEC133A179444034F6251B0F804C400C5BB395977A444034F6251B0F804C400C5BB395977A4440FE463B6EF87F4C406CCEC133A1794440FE463B6EF87F4C40
34521	45376	40.366354000000001	40.377152000000002	56.627108999999997	56.619914000000001	Центральная	0103000020E61000000100000005000000206118B0E42E4440912A8A57594F4C40206118B0E42E44407D03931B45504C407DCF4884463044407D03931B45504C407DCF488446304440912A8A57594F4C40206118B0E42E4440912A8A57594F4C40
34326	296	40.474907000000002	40.495199999999997	56.602015999999999	56.591267000000002	Зеленая	0103000020E610000001000000050000001CD2A8C0C93C44401E1A16A3AE4B4C401CD2A8C0C93C444099D53BDC0E4D4C40567DAEB6623F444099D53BDC0E4D4C40567DAEB6623F44401E1A16A3AE4B4C401CD2A8C0C93C44401E1A16A3AE4B4C40
34372	32484	40.406849999999999	40.427556000000003	56.800434000000003	56.788884000000003	Постышева	0103000020E6100000010000000500000055302AA913344440392BA226FA644C4055302AA913344440A14D0E9F74664C40B39AAE27BA364440A14D0E9F74664C40B39AAE27BA364440392BA226FA644C4055302AA913344440392BA226FA644C40
34075	333	40.504460999999999	40.527692000000002	56.814646000000003	56.802075000000002	площадь Ленина	0103000020E61000000100000005000000C18D942D9240444038F8C264AA664C40C18D942D924044409BE8F35146684C40302E55698B4344409BE8F35146684C40302E55698B43444038F8C264AA664C40C18D942D9240444038F8C264AA664C40
34265	32166	40.368986	40.402349999999998	56.672438	56.649206	Пограничная	0103000020E610000001000000050000004757E9EE3A2F4440F92EA52E19534C404757E9EE3A2F4440384BC97212564C40D6C56D3480334440384BC97212564C40D6C56D3480334440F92EA52E19534C404757E9EE3A2F4440F92EA52E19534C40
34263	32166	40.368986	40.402349999999998	56.672438	56.649206	Ленина	0103000020E610000001000000050000004757E9EE3A2F4440F92EA52E19534C404757E9EE3A2F4440384BC97212564C40D6C56D3480334440384BC97212564C40D6C56D3480334440F92EA52E19534C404757E9EE3A2F4440F92EA52E19534C40
34264	7	40.505234000000002	40.541606999999999	56.734247000000003	56.721145	Школьная	0103000020E61000000100000005000000E469F981AB4044404356B77A4E5C4C40E469F981AB404440D31742CEFB5D4C407024D06053454440D31742CEFB5D4C407024D060534544404356B77A4E5C4C40E469F981AB4044404356B77A4E5C4C40
34246	7	40.505234000000002	40.541606999999999	56.734247000000003	56.721145	Молодежная	0103000020E61000000100000005000000E469F981AB4044404356B77A4E5C4C40E469F981AB404440D31742CEFB5D4C407024D06053454440D31742CEFB5D4C407024D060534544404356B77A4E5C4C40E469F981AB4044404356B77A4E5C4C40
67227	7	40.505234000000002	40.541606999999999	56.734247000000003	56.721145	Гусева	0103000020E61000000100000005000000E469F981AB4044404356B77A4E5C4C40E469F981AB404440D31742CEFB5D4C407024D06053454440D31742CEFB5D4C407024D060534544404356B77A4E5C4C40E469F981AB4044404356B77A4E5C4C40
34267	32426	40.192135	40.363489000000001	56.87623	56.675944000000001	Центральная	0103000020E610000001000000050000005FB532E197184440B6F63E5585564C405FB532E19718444015E3FC4D28704C4056BABBCE862E444015E3FC4D28704C4056BABBCE862E4440B6F63E5585564C405FB532E197184440B6F63E5585564C40
34324	200	40.492486999999997	40.518222999999999	56.630569999999999	56.617863	Школьная	0103000020E61000000100000005000000425A63D0093F444048348122164F4C40425A63D0093F44405BEB8B84B6504C407B849A21554244405BEB8B84B6504C407B849A215542444048348122164F4C40425A63D0093F444048348122164F4C40
74899	60371	40.545971999999999	40.554451999999998	56.738630999999998	56.734696	Речная	0103000020E610000001000000050000000F441669E24544404240BE840A5E4C400F441669E2454440E867EA758B5E4C40D4997B48F8464440E867EA758B5E4C40D4997B48F84644404240BE840A5E4C400F441669E24544404240BE840A5E4C40
34233	32294	40.597481999999999	40.622571999999998	56.888401999999999	56.879303999999998	Центральная	0103000020E610000001000000050000006EF9484A7A4C4440F99E91088D704C406EF9484A7A4C4440BAD91F28B7714C40E1B37570B04F4440BAD91F28B7714C40E1B37570B04F4440F99E91088D704C406EF9484A7A4C4440F99E91088D704C40
34370	31947	41.224569000000002	41.242167000000002	56.607283000000002	56.598497999999999	Молодежная	0103000020E6100000010000000500000004594FADBE9C4440575C1C959B4C4C4004594FADBE9C444059350873BB4D4C40D1950854FF9E444059350873BB4D4C40D1950854FF9E4440575C1C959B4C4C4004594FADBE9C4440575C1C959B4C4C40
34473	31291	41.191510999999998	41.237540000000003	56.609943000000001	56.577412000000002	Полевая	0103000020E6100000010000000500000081E9B46E83984440B328ECA2E8494C4081E9B46E839844404AB6BA9C124E4C40F5BEF1B5679E44404AB6BA9C124E4C40F5BEF1B5679E4440B328ECA2E8494C4081E9B46E83984440B328ECA2E8494C40
33975	31291	41.191510999999998	41.237540000000003	56.609943000000001	56.577412000000002	Первомайская	0103000020E6100000010000000500000081E9B46E83984440B328ECA2E8494C4081E9B46E839844404AB6BA9C124E4C40F5BEF1B5679E44404AB6BA9C124E4C40F5BEF1B5679E4440B328ECA2E8494C4081E9B46E83984440B328ECA2E8494C40
34503	48853	41.051049999999996	41.091375999999997	56.591400999999998	56.575814999999999	Центральная	0103000020E61000000100000005000000FB3A70CE88864440EBC5504EB4494C40FB3A70CE888644402DE92807B34B4C40D4D17135B28B44402DE92807B34B4C40D4D17135B28B4440EBC5504EB4494C40FB3A70CE88864440EBC5504EB4494C40
34323	48963	41.155569	41.190297999999999	56.571615000000001	56.559944999999999	Советская	0103000020E61000000100000005000000BEA25BAFE993444084471B47AC474C40BEA25BAFE9934440977329AE2A494C40423F53AF5B984440977329AE2A494C40423F53AF5B98444084471B47AC474C40BEA25BAFE993444084471B47AC474C40
34409	48889	41.354762000000001	41.382069999999999	56.610711000000002	56.596876999999999	Фабричная	0103000020E6100000010000000500000089EE59D768AD4440075E2D77664C4C4089EE59D768AD44405B272EC72B4E4C40306475ABE7B044405B272EC72B4E4C40306475ABE7B04440075E2D77664C4C4089EE59D768AD4440075E2D77664C4C40
34399	48992	41.142256000000003	41.160877999999997	56.675331	56.664558999999997	Первомайская	0103000020E6100000010000000500000074D4D1713592444098A1F14410554C4074D4D17135924440CC7C073F71564C40AC527AA697944440CC7C073F71564C40AC527AA69794444098A1F14410554C4074D4D1713592444098A1F14410554C40
34393	48921	41.541494	41.575972	56.553595000000001	56.541885000000001	Бреховская	0103000020E61000000100000005000000787DE6AC4FC54440B398D87C5C454C40787DE6AC4FC54440541D7233DC464C40B3B45373B9C94440541D7233DC464C40B3B45373B9C94440B398D87C5C454C40787DE6AC4FC54440B398D87C5C454C40
34388	48799	40.998812999999998	41.024909000000001	56.600727999999997	56.589418000000002	Центральная	0103000020E61000000100000005000000EAE8B81AD97F44403DD68C0C724B4C40EAE8B81AD97F44404FE5B4A7E44C4C402330D637308344404FE5B4A7E44C4C402330D637308344403DD68C0C724B4C40EAE8B81AD97F44403DD68C0C724B4C40
34074	48786	41.231028000000002	41.267158000000002	56.66677	56.654015999999999	1-я Кооперативная	0103000020E61000000100000005000000EB3A5453929D4440C687D9CBB6534C40EB3A5453929D44401AFA27B858554C40B16EBC3B32A244401AFA27B858554C40B16EBC3B32A24440C687D9CBB6534C40EB3A5453929D4440C687D9CBB6534C40
34286	31687	40.992193	41.017606000000001	56.582811	56.570103000000003	Центральная	0103000020E61000000100000005000000FA28232E007F4440FE2C9622F9484C40FA28232E007F4440E15F048D994A4C40501BD5E940824440E15F048D994A4C40501BD5E940824440FE2C9622F9484C40FA28232E007F4440FE2C9622F9484C40
34426	30684	41.530535	41.552318999999997	57.123724000000003	57.111736999999998	Молодежный	0103000020E6100000010000000500000012312592E8C344406760E4654D8E4C4012312592E8C344407BDD2230D68F4C40CEFA9463B2C644407BDD2230D68F4C40CEFA9463B2C644406760E4654D8E4C4012312592E8C344406760E4654D8E4C40
34369	48589	41.764797999999999	41.787633	56.96208	56.947718999999999	Центральная	0103000020E61000000100000005000000EA059FE6E4E144401F662FDB4E794C40EA059FE6E4E144405E11FC6F257B4C400C207C28D1E444405E11FC6F257B4C400C207C28D1E444401F662FDB4E794C40EA059FE6E4E144401F662FDB4E794C40
34073	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	пр Северный	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34072	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	площадь Ленина	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34109	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	мкр. Южный	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34047	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	микрорайон Машиностроитель	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34040	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	Советская	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34042	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	Народная	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
33917	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	60 лет Октября	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
33950	28577	41.693461999999997	41.779620000000001	57.127744999999997	57.089472000000001	3-я Куликовская	0103000020E610000001000000050000006682E15CC3D8444030F488D1738B4C406682E15CC3D844401F9DBAF259904C405DA79196CAE344401F9DBAF259904C405DA79196CAE3444030F488D1738B4C406682E15CC3D8444030F488D1738B4C40
34255	31139	41.675199999999997	41.690058000000001	57.144840000000002	57.132810999999997	Школьная	0103000020E610000001000000050000002D211FF46CD6444047C66AF3FF904C402D211FF46CD644408A93FB1D8A924C40ED2B0FD253D844408A93FB1D8A924C40ED2B0FD253D8444047C66AF3FF904C402D211FF46CD6444047C66AF3FF904C40
34283	30897	41.695608999999997	41.718786000000001	57.016302000000003	57.006328000000003	Светлая	0103000020E61000000100000005000000D1E638B709D9444049861C5BCF804C40D1E638B709D94440016E162F16824C404D69FD2D01DC4440016E162F16824C404D69FD2D01DC444049861C5BCF804C40D1E638B709D9444049861C5BCF804C40
34243	48468	41.540875	41.568317999999998	57.210859999999997	57.196634000000003	Центральная	0103000020E61000000100000005000000AC1C5A643BC544400EA48B4D2B994C40AC1C5A643BC544406C04E275FD9A4C4033DDEBA4BEC844406C04E275FD9A4C4033DDEBA4BEC844400EA48B4D2B994C40AC1C5A643BC544400EA48B4D2B994C40
34342	48575	41.738988999999997	41.753127999999997	57.005229999999997	56.993375999999998	Молодежная	0103000020E61000000100000005000000478D093197DE4440CE50DCF1267F4C40478D093197DE4440A27A6B60AB804C40D7D9907F66E04440A27A6B60AB804C40D7D9907F66E04440CE50DCF1267F4C40478D093197DE4440CE50DCF1267F4C40
34216	54106	41.459110000000003	41.481676	57.163347999999999	57.146037	Каминского	0103000020E610000001000000050000001FA2D11DC4BA4440C3802557B1924C401FA2D11DC4BA4440FAEE5696E8944C4051A2258FA7BD4440FAEE5696E8944C4051A2258FA7BD4440C3802557B1924C401FA2D11DC4BA4440C3802557B1924C40
34304	29914	43.008794000000002	43.021971999999998	57.094397000000001	57.078242000000003	Советская	0103000020E6100000010000000500000055336B29208145403A9677D5038A4C4055336B292081454096EB6D33158C4C40BFB67EFACF82454096EB6D33158C4C40BFB67EFACF8245403A9677D5038A4C4055336B29208145403A9677D5038A4C40
33976	28910	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	Ленина	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
34156	28910	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	Кирова	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
33924	28910	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	Заводская	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
34175	28910	43.148212000000001	43.184260999999999	56.994337000000002	56.962738000000002	60 лет Октября	0103000020E61000000100000005000000F86F5E9CF8924540E84EB0FF3A7B4C40F86F5E9CF8924540F419506F467F4C40D1764CDD95974540F419506F467F4C40D1764CDD95974540E84EB0FF3A7B4C40F86F5E9CF8924540E84EB0FF3A7B4C40
34339	29664	42.949181000000003	42.960284999999999	56.871079999999999	56.866228999999997	Центральная	0103000020E61000000100000005000000077E54C37E79454063EC8497E06E4C40077E54C37E7945408F19A88C7F6F4C4070EB6E9EEA7A45408F19A88C7F6F4C4070EB6E9EEA7A454063EC8497E06E4C40077E54C37E79454063EC8497E06E4C40
34352	29931	42.926192999999998	42.949038000000002	57.091760999999998	57.077145999999999	Центральная	0103000020E610000001000000050000005E64027E8D76454034828DEBDF894C405E64027E8D7645402D060FD3BE8B4C40A454C2137A7945402D060FD3BE8B4C40A454C2137A79454034828DEBDF894C405E64027E8D76454034828DEBDF894C40
34330	29778	43.101301999999997	43.122826000000003	56.866169999999997	56.855536000000001	Школьная	0103000020E610000001000000050000007B82C476F78C45407C462234826D4C407B82C476F78C45405E6397A8DE6E4C409C8C2AC3B88F45405E6397A8DE6E4C409C8C2AC3B88F45407C462234826D4C407B82C476F78C45407C462234826D4C40
34386	30004	42.754705000000001	42.771009999999997	57.088157000000002	57.077478999999997	Школьная	0103000020E610000001000000050000005890662C9A6045403A90F5D4EA894C405890662C9A604540EDF483BA488B4C40C971A774B0624540EDF483BA488B4C40C971A774B06245403A90F5D4EA894C405890662C9A6045403A90F5D4EA894C40
34322	29380	42.919178000000002	42.929938999999997	56.919685999999999	56.915156000000003	Школьная	0103000020E61000000100000005000000F299EC9FA77545407D5EF1D423754C40F299EC9FA7754540664B5645B8754C403123BC3D08774540664B5645B8754C403123BC3D087745407D5EF1D423754C40F299EC9FA77545407D5EF1D423754C40
34408	29857	43.040135999999997	43.061551999999999	57.031851000000003	57.021073999999999	Школьная	0103000020E6100000010000000500000035B22B2D23854540E065868DB2824C4035B22B2D2385454026AC8DB113844C406F8099EFE087454026AC8DB113844C406F8099EFE0874540E065868DB2824C4035B22B2D23854540E065868DB2824C40
34343	29572	42.973022999999998	42.986460999999998	56.927014999999997	56.923164	Садовая	0103000020E61000000100000005000000BEA085048C7C45401A6CEA3C2A764C40BEA085048C7C454062F3716DA8764C40C5E3A25A447E454062F3716DA8764C40C5E3A25A447E45401A6CEA3C2A764C40BEA085048C7C45401A6CEA3C2A764C40
34398	29716	43.010005999999997	43.033757999999999	56.894365999999998	56.879967999999998	центральная	0103000020E61000000100000005000000C36169E04781454065C39ACAA2704C40C36169E047814540C153C8957A724C403BFDA02E52844540C153C8957A724C403BFDA02E5284454065C39ACAA2704C40C36169E04781454065C39ACAA2704C40
34229	52400	43.032024	43.061399000000002	56.944758	56.928066999999999	Школьная	0103000020E61000000100000005000000F357C85C1984454098BF42E6CA764C40F357C85C19844540335184D4ED784C40E98024ECDB874540335184D4ED784C40E98024ECDB87454098BF42E6CA764C40F357C85C1984454098BF42E6CA764C40
34219	29303	42.857230000000001	42.884179000000003	56.962148999999997	56.950859999999999	Школьная	0103000020E6100000010000000500000036936FB6B96D45408B89CDC7B5794C4036936FB6B96D45408670CCB2277B4C40AE6708C72C7145408670CCB2277B4C40AE6708C72C7145408B89CDC7B5794C4036936FB6B96D45408B89CDC7B5794C40
34351	29350	42.934674000000001	42.947069999999997	56.981327	56.974415	Клубная	0103000020E61000000100000005000000F435CB65A3774540ADDD76A1B97C4C40F435CB65A377454045D7851F9C7D4C40E882FA963979454045D7851F9C7D4C40E882FA9639794540ADDD76A1B97C4C40F435CB65A3774540ADDD76A1B97C4C40
34282	29481	43.158534000000003	43.184091000000002	56.949480999999999	56.939210000000003	Советская	0103000020E61000000100000005000000ECA694D74A944540C009850838784C40ECA694D74A9445403196E99788794C40753E3C4B909745403196E99788794C40753E3C4B90974540C009850838784C40ECA694D74A944540C009850838784C40
34341	30059	42.999307000000002	43.010815000000001	57.130462000000001	57.119883999999999	Садовая	0103000020E61000000100000005000000FAD4B14AE97F454026A8E15B588F4C40FAD4B14AE97F454075AF93FAB2904C4033A7CB626281454075AF93FAB2904C4033A7CB626281454026A8E15B588F4C40FAD4B14AE97F454026A8E15B588F4C40
34395	29802	43.174658999999998	43.188806999999997	56.896362000000003	56.891308000000002	Центральная	0103000020E61000000100000005000000DD79E2395B964540E3546B6116724C40DD79E2395B96454047B071FDBB724C40C020E9D32A98454047B071FDBB724C40C020E9D32A984540E3546B6116724C40DD79E2395B964540E3546B6116724C40
34357	28347	41.376474000000002	41.386471999999998	57.406784999999999	57.403716000000003	Школьная	0103000020E61000000100000005000000ACE5CE4C30B044409C6F44F7ACB34C40ACE5CE4C30B044406EC0E78711B44C40EC681CEA77B144406EC0E78711B44C40EC681CEA77B144409C6F44F7ACB34C40ACE5CE4C30B044409C6F44F7ACB34C40
34385	28347	41.376474000000002	41.386471999999998	57.406784999999999	57.403716000000003	Зеленая	0103000020E61000000100000005000000ACE5CE4C30B044409C6F44F7ACB34C40ACE5CE4C30B044406EC0E78711B44C40EC681CEA77B144406EC0E78711B44C40EC681CEA77B144409C6F44F7ACB34C40ACE5CE4C30B044409C6F44F7ACB34C40
34232	28497	41.222700000000003	41.241619	57.333098	57.324424999999998	Центральная	0103000020E61000000100000005000000DC68006F819C44409D8026C286A94C40DC68006F819C4440772E8CF4A2AA4C40CE8B135FED9E4440772E8CF4A2AA4C40CE8B135FED9E44409D8026C286A94C40DC68006F819C44409D8026C286A94C40
34231	28290	41.480229000000001	41.497197999999997	57.457653999999998	57.446153000000002	Гагарина	0103000020E610000001000000050000009FCBD42478BD44409301A08A1BB94C409FCBD42478BD44401971016894BA4C407CD11E2FA4BF44401971016894BA4C407CD11E2FA4BF44409301A08A1BB94C409FCBD42478BD44409301A08A1BB94C40
34302	28835	41.363700000000001	41.377282000000001	57.258380000000002	57.246859999999998	Центральная	0103000020E6100000010000000500000011C7BAB88DAE44406458C51B999F4C4011C7BAB88DAE444062F8889812A14C404BAFCDC64AB0444062F8889812A14C404BAFCDC64AB044406458C51B999F4C4011C7BAB88DAE44406458C51B999F4C40
33914	27821	41.264113000000002	41.316457	57.399667000000001	57.364691000000001	Коминтерновская	0103000020E6100000010000000500000067B96C74CEA14440A112D731AEAE4C4067B96C74CEA144402D25CB4928B34C408ECBB8A981A844402D25CB4928B34C408ECBB8A981A84440A112D731AEAE4C4067B96C74CEA14440A112D731AEAE4C40
34071	27821	41.264113000000002	41.316457	57.399667000000001	57.364691000000001	Дружбы	0103000020E6100000010000000500000067B96C74CEA14440A112D731AEAE4C4067B96C74CEA144402D25CB4928B34C408ECBB8A981A844402D25CB4928B34C408ECBB8A981A84440A112D731AEAE4C4067B96C74CEA14440A112D731AEAE4C40
33948	27821	41.264113000000002	41.316457	57.399667000000001	57.364691000000001	1 Мая	0103000020E6100000010000000500000067B96C74CEA14440A112D731AEAE4C4067B96C74CEA144402D25CB4928B34C408ECBB8A981A844402D25CB4928B34C408ECBB8A981A84440A112D731AEAE4C4067B96C74CEA14440A112D731AEAE4C40
34248	28215	41.485214999999997	41.532862000000002	57.465733	57.448134000000003	Советская	0103000020E61000000100000005000000AA436E861BBE4440E31C75745CB94C40AA436E861BBE444080D591239DBB4C40FDA36FD234C4444080D591239DBB4C40FDA36FD234C44440E31C75745CB94C40AA436E861BBE4440E31C75745CB94C40
34300	54113	\N	\N	\N	\N	Советская	\N
34179	28452	41.293990999999998	41.320284000000001	57.399638000000003	57.391558000000003	Спортивная	0103000020E61000000100000005000000BF28417FA1A544405C3E92921EB24C40BF28417FA1A54440931E865627B34C404EB7EC10FFA84440931E865627B34C404EB7EC10FFA844405C3E92921EB24C40BF28417FA1A544405C3E92921EB24C40
34368	27687	42.745452	42.769114000000002	56.688116999999998	56.677303999999999	Центральная	0103000020E61000000100000005000000705E9CF86A5F454099B9C0E5B1564C40705E9CF86A5F45402B69C53714584C40A872DA53726245402B69C53714584C40A872DA537262454099B9C0E5B1564C40705E9CF86A5F454099B9C0E5B1564C40
34338	47237	42.575904000000001	42.600132000000002	56.729897000000001	56.722790000000003	Центральная	0103000020E610000001000000050000005BD1E638B74945401CF0F961845C4C405BD1E638B74945406939D0436D5D4C403CA41820D14C45406939D0436D5D4C403CA41820D14C45401CF0F961845C4C405BD1E638B74945401CF0F961845C4C40
34172	27747	42.652521999999998	42.691750999999996	56.719248999999998	56.689388000000001	Социалистическая	0103000020E61000000100000005000000D3F544D7855345409F20B1DD3D584C40D3F544D7855345402157EA59105C4C40D6FCF84B8B5845402157EA59105C4C40D6FCF84B8B5845409F20B1DD3D584C40D3F544D7855345409F20B1DD3D584C40
33977	27747	42.652521999999998	42.691750999999996	56.719248999999998	56.689388000000001	Гагарина	0103000020E61000000100000005000000D3F544D7855345409F20B1DD3D584C40D3F544D7855345402157EA59105C4C40D6FCF84B8B5845402157EA59105C4C40D6FCF84B8B5845409F20B1DD3D584C40D3F544D7855345409F20B1DD3D584C40
34290	27473	42.409734	42.443547000000002	56.670943999999999	56.648474	Советская	0103000020E610000001000000050000009607E9297234454035272F3201534C409607E9297234454045B9347EE1554C40959EE925C638454045B9347EE1554C40959EE925C638454035272F3201534C409607E9297234454035272F3201534C40
34336	27387	42.659393999999999	42.688014000000003	56.586410000000001	56.574705000000002	Зелёная	0103000020E61000000100000005000000DD96C8056754454081ECF5EE8F494C40DD96C8056754454010069E7B0F4B4C405798BED71058454010069E7B0F4B4C405798BED71058454081ECF5EE8F494C40DD96C8056754454081ECF5EE8F494C40
34367	27554	42.597760000000001	42.604596999999998	56.687869999999997	56.684009000000003	Галашовская	0103000020E61000000100000005000000B16D5166834C4540B8955E9B8D574C40B16D5166834C454023F3C81F0C584C403E213B6F634D454023F3C81F0C584C403E213B6F634D4540B8955E9B8D574C40B16D5166834C4540B8955E9B8D574C40
34340	27617	42.720866000000001	42.744320999999999	56.636986	56.629773	Школьная	0103000020E6100000010000000500000030664B56455C4540B073D3669C504C4030664B56455C45404301DBC188514C40EE5C18E9455F45404301DBC188514C40EE5C18E9455F4540B073D3669C504C4030664B56455C4540B073D3669C504C40
34301	27362	42.707337000000003	42.729363999999997	56.780476999999998	56.769252000000002	Молодежная	0103000020E610000001000000050000001920D1048A5A4540F9307BD976624C401920D1048A5A4540DD239BABE6634C409B70AFCC5B5D4540DD239BABE6634C409B70AFCC5B5D4540F9307BD976624C401920D1048A5A4540F9307BD976624C40
34406	47061	42.578769999999999	42.597876999999997	56.618065999999999	56.609096000000001	Центральная	0103000020E61000000100000005000000F5F3A622154A4540ED0F94DBF64D4C40F5F3A622154A4540806264C91C4F4C40EA03C93B874C4540806264C91C4F4C40EA03C93B874C4540ED0F94DBF64D4C40F5F3A622154A4540ED0F94DBF64D4C40
34335	46845	42.209428000000003	42.226047000000001	56.827488000000002	56.814807999999999	40 лет Победы	0103000020E61000000100000005000000F06E6589CE1A45407442E8A04B684C40F06E6589CE1A45408EEA7420EB694C40F12DAC1BEF1C45408EEA7420EB694C40F12DAC1BEF1C45407442E8A04B684C40F06E6589CE1A45407442E8A04B684C40
34407	46853	42.091614	42.103003999999999	56.852642000000003	56.847459000000001	Центральная	0103000020E6100000010000000500000089EDEE01BA0B4540B6D95889796C4C4089EDEE01BA0B45401899805F236D4C40B8AD2D3C2F0D45401899805F236D4C40B8AD2D3C2F0D4540B6D95889796C4C4089EDEE01BA0B4540B6D95889796C4C40
34106	27113	41.837336999999998	41.895107000000003	56.813907	56.782341000000002	Ленина	0103000020E61000000100000005000000895DDBDB2DEB4440F4A8F8BF23644C40895DDBDB2DEB4440247EC51A2E684C40D9B5BDDD92F24440247EC51A2E684C40D9B5BDDD92F24440F4A8F8BF23644C40895DDBDB2DEB4440F4A8F8BF23644C40
33946	27113	41.837336999999998	41.895107000000003	56.813907	56.782341000000002	Баканова	0103000020E61000000100000005000000895DDBDB2DEB4440F4A8F8BF23644C40895DDBDB2DEB4440247EC51A2E684C40D9B5BDDD92F24440247EC51A2E684C40D9B5BDDD92F24440F4A8F8BF23644C40895DDBDB2DEB4440F4A8F8BF23644C40
34081	27084	41.798422000000002	41.838388000000002	56.904353999999998	56.890422999999998	Северная	0103000020E6100000010000000500000016342DB132E64440984D8061F9714C4016342DB132E64440DE0033DFC1734C40EFAD484C50EB4440DE0033DFC1734C40EFAD484C50EB4440984D8061F9714C4016342DB132E64440984D8061F9714C40
34382	26900	41.641961999999999	41.676789999999997	56.794376	56.783441000000003	Центральная	0103000020E610000001000000050000002BA391CF2BD244403BAC70CB47644C402BA391CF2BD24440185DDE1CAE654C404221020EA1D64440185DDE1CAE654C404221020EA1D644403BAC70CB47644C402BA391CF2BD244403BAC70CB47644C40
34425	26606	42.257685000000002	42.273935999999999	56.968370999999998	56.956265000000002	Набережная	0103000020E61000000100000005000000BBD573D2FB2045409CA73AE4667A4C40BBD573D2FB20454089B2B794F37B4C403999B8551023454089B2B794F37B4C403999B855102345409CA73AE4667A4C40BBD573D2FB2045409CA73AE4667A4C40
34234	47737	42.224519000000001	42.241228	57.052079999999997	57.040647999999997	Центральная	0103000020E61000000100000005000000522AE109BD1C4540EB5223F433854C40522AE109BD1C45404963B48EAA864C409370218FE01E45404963B48EAA864C409370218FE01E4540EB5223F433854C40522AE109BD1C4540EB5223F433854C40
34358	33155	42.320379000000003	42.354182000000002	56.927688000000003	56.916212000000002	Центральная	0103000020E61000000100000005000000A0A9D72D02294540F419506F46754C40A0A9D72D022945402272FA7ABE764C407B6AF5D5552D45402272FA7ABE764C407B6AF5D5552D4540F419506F46754C40A0A9D72D02294540F419506F46754C40
34467	46700	42.205205999999997	42.225974999999998	56.927418000000003	56.918792000000003	Школьная	0103000020E61000000100000005000000B378B130441A4540C9E9EBF99A754C40B378B130441A454062DC0DA2B5764C40575BB1BFEC1C454062DC0DA2B5764C40575BB1BFEC1C4540C9E9EBF99A754C40B378B130441A4540C9E9EBF99A754C40
34424	26323	42.542676	42.565170000000002	57.010787999999998	57.000877000000003	Советская	0103000020E610000001000000050000007C293C6876454540C828CFBC1C804C407C293C687645454039984D8061814C401557957D5748454039984D8061814C401557957D57484540C828CFBC1C804C407C293C6876454540C828CFBC1C804C40
33947	26052	42.246223000000001	42.274915	57.018590000000003	57.002651999999998	 Красноармейская	0103000020E61000000100000005000000F2423A3C841F45406EA296E656804C40F2423A3C841F45402E04392861824C4005172B6A302345402E04392861824C4005172B6A302345406EA296E656804C40F2423A3C841F45406EA296E656804C40
34384	45673	42.398477999999997	42.423326000000003	57.021427000000003	57.011318000000003	Центральная	0103000020E610000001000000050000007616BD530133454096ED43DE72814C407616BD53013345402E20B41EBE824C40F4C5DE8B2F3645402E20B41EBE824C40F4C5DE8B2F36454096ED43DE72814C407616BD530133454096ED43DE72814C40
34217	25951	40.726821000000001	40.754741000000003	56.927998000000002	56.914772999999997	Зеленая	0103000020E61000000100000005000000E4857478085D4440C4211B4817754C40E4857478085D4440706072A3C8764C40A5F9635A9B604440706072A3C8764C40A5F9635A9B604440C4211B4817754C40E4857478085D4440C4211B4817754C40
34262	25922	40.749746000000002	40.777621000000003	56.868428000000002	56.856800999999997	Центральная	0103000020E6100000010000000500000046274BADF75F44400D17B9A7AB6D4C4046274BADF75F4440217711A6286F4C4067D7BD1589634440217711A6286F4C4067D7BD15896344400D17B9A7AB6D4C4046274BADF75F44400D17B9A7AB6D4C40
34218	25866	41.104059999999997	41.122717999999999	56.809517	56.800916999999998	Лежневска	0103000020E610000001000000050000002F698CD6518D4440BCE7C07284664C402F698CD6518D44402C47C8409E674C40B5503239B58F44402C47C8409E674C40B5503239B58F4440BCE7C07284664C402F698CD6518D4440BCE7C07284664C40
75528	60490	40.658298000000002	41.161093999999999	56.969695999999999	56.553897999999997	Московская	0103000020E61000000100000005000000D882DE1B43544440EFA83121E6464C40D882DE1B43544440F0879FFF1E7C4C4079CA6ABA9E944440F0879FFF1E7C4C4079CA6ABA9E944440EFA83121E6464C40D882DE1B43544440EFA83121E6464C40
34250	25806	40.933326000000001	40.948084999999999	56.827886999999997	56.818750000000001	Мичурина	0103000020E61000000100000005000000D540F33977774440CDCCCCCCCC684C40D540F339777744404BE48233F8694C40016A6AD95A7944404BE48233F8694C40016A6AD95A794440CDCCCCCCCC684C40D540F33977774440CDCCCCCCCC684C40
34235	25660	41.050673000000003	41.09796	56.737273000000002	56.724784999999997	Советская	0103000020E6100000010000000500000026E5EE737C864440D0D03FC1C55C4C4026E5EE737C864440A69C2FF65E5E4C4078280AF4898C4440A69C2FF65E5E4C4078280AF4898C4440D0D03FC1C55C4C4026E5EE737C864440D0D03FC1C55C4C40
34261	25660	41.050673000000003	41.09796	56.737273000000002	56.724784999999997	Московская	0103000020E6100000010000000500000026E5EE737C864440D0D03FC1C55C4C4026E5EE737C864440A69C2FF65E5E4C4078280AF4898C4440A69C2FF65E5E4C4078280AF4898C4440D0D03FC1C55C4C4026E5EE737C864440D0D03FC1C55C4C40
34277	25660	41.050673000000003	41.09796	56.737273000000002	56.724784999999997	Большая Шуйская	0103000020E6100000010000000500000026E5EE737C864440D0D03FC1C55C4C4026E5EE737C864440A69C2FF65E5E4C4078280AF4898C4440A69C2FF65E5E4C4078280AF4898C4440D0D03FC1C55C4C4026E5EE737C864440D0D03FC1C55C4C40
34260	25190	40.865206999999998	40.916896000000001	56.790979999999998	56.761048000000002	Советская	0103000020E6100000010000000500000098A25C1ABF6E4440D65757056A614C4098A25C1ABF6E444021E527D53E654C40A7EA1ED95C75444021E527D53E654C40A7EA1ED95C754440D65757056A614C4098A25C1ABF6E4440D65757056A614C40
34215	25190	40.865206999999998	40.916896000000001	56.790979999999998	56.761048000000002	Островского	0103000020E6100000010000000500000098A25C1ABF6E4440D65757056A614C4098A25C1ABF6E444021E527D53E654C40A7EA1ED95C75444021E527D53E654C40A7EA1ED95C754440D65757056A614C4098A25C1ABF6E4440D65757056A614C40
34245	25190	40.865206999999998	40.916896000000001	56.790979999999998	56.761048000000002	Ивановская	0103000020E6100000010000000500000098A25C1ABF6E4440D65757056A614C4098A25C1ABF6E444021E527D53E654C40A7EA1ED95C75444021E527D53E654C40A7EA1ED95C754440D65757056A614C4098A25C1ABF6E4440D65757056A614C40
34244	25190	40.865206999999998	40.916896000000001	56.790979999999998	56.761048000000002	1-я Луначарского	0103000020E6100000010000000500000098A25C1ABF6E4440D65757056A614C4098A25C1ABF6E444021E527D53E654C40A7EA1ED95C75444021E527D53E654C40A7EA1ED95C754440D65757056A614C4098A25C1ABF6E4440D65757056A614C40
34249	25190	40.865206999999998	40.916896000000001	56.790979999999998	56.761048000000002	1-я Комсомольская	0103000020E6100000010000000500000098A25C1ABF6E4440D65757056A614C4098A25C1ABF6E444021E527D53E654C40A7EA1ED95C75444021E527D53E654C40A7EA1ED95C754440D65757056A614C4098A25C1ABF6E4440D65757056A614C40
34247	25515	40.947789	40.979553000000003	56.706152000000003	56.694133000000001	Молодежная	0103000020E6100000010000000500000018416326517944408509A359D9584C401841632651794440A4005130635A4C406FD921FE617D4440A4005130635A4C406FD921FE617D44408509A359D9584C4018416326517944408509A359D9584C40
34295	48762	40.096553999999998	40.107756000000002	57.023077999999998	57.016154999999998	Советская	0103000020E610000001000000050000002426A8E15B0C44405C55F65D11824C402426A8E15B0C4440E8A04B38F4824C4051F9D7F2CA0D4440E8A04B38F4824C4051F9D7F2CA0D44405C55F65D11824C402426A8E15B0C44405C55F65D11824C40
34153	25131	40.326819	40.346060999999999	57.220959000000001	57.210357999999999	Ленина	0103000020E61000000100000005000000105B7A34D5294440DA39CD02ED9A4C40105B7A34D5294440E1606F62489C4C40E5B512BA4B2C4440E1606F62489C4C40E5B512BA4B2C4440DA39CD02ED9A4C40105B7A34D5294440DA39CD02ED9A4C40
33997	24900	40.502907	40.547823000000001	57.193021000000002	57.166978999999998	Советская 	0103000020E61000000100000005000000F9F6AE415F404440340F60915F954C40F9F6AE415F4044407A3881E9B4984C40917F66101F4644407A3881E9B4984C40917F66101F464440340F60915F954C40F9F6AE415F404440340F60915F954C40
34070	24900	40.502907	40.547823000000001	57.193021000000002	57.166978999999998	Советская	0103000020E61000000100000005000000F9F6AE415F404440340F60915F954C40F9F6AE415F4044407A3881E9B4984C40917F66101F4644407A3881E9B4984C40917F66101F464440340F60915F954C40F9F6AE415F404440340F60915F954C40
34273	45955	40.317934999999999	40.346348999999996	57.146945000000002	57.131144999999997	Техническая	0103000020E610000001000000050000007BA01518B22844405704FF5BC9904C407BA01518B2284440C6A70018CF924C404B00FE29552C4440C6A70018CF924C404B00FE29552C44405704FF5BC9904C407BA01518B22844405704FF5BC9904C40
34403	24759	40.358656000000003	40.375194	57.021824000000002	57.015428999999997	Зои Космодемьянской	0103000020E61000000100000005000000D1419770E82D44407A34D593F9814C40D1419770E82D44404B22FB20CB824C40E5D3635B063044404B22FB20CB824C40E5D3635B063044407A34D593F9814C40D1419770E82D44407A34D593F9814C40
67299	47162	40.567146000000001	40.574584000000002	57.175576999999997	57.170268	Центральная	0103000020E610000001000000050000005307793D9848444015C78157CB954C405307793D984844400377A04E79964C400667F0F78B4944400377A04E79964C400667F0F78B49444015C78157CB954C405307793D9848444015C78157CB954C40
33982	54084	40.460731000000003	40.523936999999997	57.033996999999999	57.007337999999997	Центральная	0103000020E610000001000000050000006FA0C03BF93A44404F029B73F0804C406FA0C03BF93A4440C09481035A844C4009151C5E10434440C09481035A844C4009151C5E104344404F029B73F0804C406FA0C03BF93A44404F029B73F0804C40
34105	24523	40.356338000000001	40.391829999999999	57.042841000000003	57.014111	Первомайская	0103000020E610000001000000050000003929CC7B9C2D4440C6C1A563CE814C403929CC7B9C2D4440C7F65AD07B854C40BCCB457C27324440C7F65AD07B854C40BCCB457C27324440C6C1A563CE814C403929CC7B9C2D4440C6C1A563CE814C40
33974	24523	40.356338000000001	40.391829999999999	57.042841000000003	57.014111	Колганова	0103000020E610000001000000050000003929CC7B9C2D4440C6C1A563CE814C403929CC7B9C2D4440C7F65AD07B854C40BCCB457C27324440C7F65AD07B854C40BCCB457C27324440C6C1A563CE814C403929CC7B9C2D4440C6C1A563CE814C40
33906	54071	42.066560000000003	42.246868999999997	57.480935000000002	57.402509000000002	50 летия Комсомола	0103000020E61000000100000005000000639CBF09850845403FAC376A85B34C40639CBF09850845403A4030478FBD4C40B7B24467991F45403A4030478FBD4C40B7B24467991F45403FAC376A85B34C40639CBF09850845403FAC376A85B34C40
34423	23654	42.431994000000003	42.442469000000003	57.183022000000001	57.177953000000002	Новая	0103000020E61000000100000005000000BC0853944B374540D09CF529C7964C40BC0853944B3745406939D0436D974C40363FFED2A23845406939D0436D974C40363FFED2A2384540D09CF529C7964C40BC0853944B374540D09CF529C7964C40
34318	23720	42.520181999999998	42.550257999999999	57.183011999999998	57.172561999999999	Центральная	0103000020E61000000100000005000000E3FBE252954245402444F98216964C40E3FBE252954245404563EDEF6C974C40622EA9DA6E4645404563EDEF6C974C40622EA9DA6E4645402444F98216964C40E3FBE252954245402444F98216964C40
34252	24012	42.537483000000002	42.575428000000002	57.412951999999997	57.400550000000003	Ленина	0103000020E61000000100000005000000F793313ECC444540D734EF3845B34C40F793313ECC444540AD68739CDBB44C40F299EC9FA7494540AD68739CDBB44C40F299EC9FA7494540D734EF3845B34C40F793313ECC444540D734EF3845B34C40
34103	24135	42.067205999999999	42.084893999999998	57.486629000000001	57.477310000000003	Садовая	0103000020E61000000100000005000000280CCA349A084540E2067C7E18BD4C40280CCA349A0845408124ECDB49BE4C4035D07CCEDD0A45408124ECDB49BE4C4035D07CCEDD0A4540E2067C7E18BD4C40280CCA349A084540E2067C7E18BD4C40
33944	20632	41.925775999999999	41.996284000000003	57.480649	57.455585999999997	Юбилейная	0103000020E61000000100000005000000FAB5F5D37FF64440FA415DA450BA4C40FAB5F5D37FF6444074ED0BE885BD4C4098C3EE3B86FF444074ED0BE885BD4C4098C3EE3B86FF4440FA415DA450BA4C40FAB5F5D37FF64440FA415DA450BA4C40
33927	20632	41.925775999999999	41.996284000000003	57.480649	57.455585999999997	Энгельса	0103000020E61000000100000005000000FAB5F5D37FF64440FA415DA450BA4C40FAB5F5D37FF6444074ED0BE885BD4C4098C3EE3B86FF444074ED0BE885BD4C4098C3EE3B86FF4440FA415DA450BA4C40FAB5F5D37FF64440FA415DA450BA4C40
34037	20632	41.925775999999999	41.996284000000003	57.480649	57.455585999999997	Ульянова	0103000020E61000000100000005000000FAB5F5D37FF64440FA415DA450BA4C40FAB5F5D37FF6444074ED0BE885BD4C4098C3EE3B86FF444074ED0BE885BD4C4098C3EE3B86FF4440FA415DA450BA4C40FAB5F5D37FF64440FA415DA450BA4C40
34069	20632	41.925775999999999	41.996284000000003	57.480649	57.455585999999997	Спортивная	0103000020E61000000100000005000000FAB5F5D37FF64440FA415DA450BA4C40FAB5F5D37FF6444074ED0BE885BD4C4098C3EE3B86FF444074ED0BE885BD4C4098C3EE3B86FF4440FA415DA450BA4C40FAB5F5D37FF64440FA415DA450BA4C40
34068	23960	42.218411000000003	42.226064999999998	57.422781999999998	57.416916999999998	Школьная	0103000020E61000000100000005000000180B43E4F41B4540BE1248895DB54C40180B43E4F41B454032AB77B81DB64C4097E2AAB2EF1C454032AB77B81DB64C4097E2AAB2EF1C4540BE1248895DB54C40180B43E4F41B4540BE1248895DB54C40
34317	23592	42.280754000000002	42.292064000000003	57.223356000000003	57.214584000000002	Торговая	0103000020E61000000100000005000000501C40BFEF234540581F0F7D779B4C40501C40BFEF234540C5AEEDED969C4C40632B685A62254540C5AEEDED969C4C40632B685A62254540581F0F7D779B4C40501C40BFEF234540581F0F7D779B4C40
34350	23842	42.809871000000001	42.842523999999997	57.519680999999999	57.505147999999998	Красногорская	0103000020E610000001000000050000004A7D59DAA9674540E5D18DB0A8C04C404A7D59DAA967454021AD31E884C24C402C0C91D3D76B454021AD31E884C24C402C0C91D3D76B4540E5D18DB0A8C04C404A7D59DAA9674540E5D18DB0A8C04C40
34404	23794	42.591113	42.612385000000003	57.440897999999997	57.429046999999997	школьная	0103000020E61000000100000005000000C79E3D97A94B454034B91803EBB64C40C79E3D97A94B4540976F7D586FB84C40CEC7B5A1624E4540976F7D586FB84C40CEC7B5A1624E454034B91803EBB64C40C79E3D97A94B454034B91803EBB64C40
34319	23763	42.595945999999998	42.614899999999999	57.205556999999999	57.196395000000003	Совхозная	0103000020E610000001000000050000004C1762F5474C4540890CAB7823994C404C1762F5474C4540603B18B14F9A4C40BB270F0BB54E4540603B18B14F9A4C40BB270F0BB54E4540890CAB7823994C404C1762F5474C4540890CAB7823994C40
34366	23512	42.364082000000003	42.395693000000001	57.304164999999998	57.290908999999999	Фабричная	0103000020E61000000100000005000000F9872D3D9A2E4540588E90813CA54C40F9872D3D9A2E45403ECBF3E0EEA64C40C9207711A63245403ECBF3E0EEA64C40C9207711A6324540588E90813CA54C40F9872D3D9A2E4540588E90813CA54C40
34337	24106	42.520164000000001	42.541696999999999	57.26388	57.250692000000001	Урожайная	0103000020E610000001000000050000003D47E4BB9442454036AFEAAC16A04C403D47E4BB94424540C408E1D1C6A14C40B0ABC95356454540C408E1D1C6A14C40B0ABC9535645454036AFEAAC16A04C403D47E4BB9442454036AFEAAC16A04C40
33911	24030	42.457991999999997	42.484546000000002	57.412598000000003	57.405059000000001	микрорайон санатория Решма	0103000020E6100000010000000500000031EA5A7B9F3A4540A9F92AF9D8B34C4031EA5A7B9F3A45409032E202D0B44C402DB4739A053E45409032E202D0B44C402DB4739A053E4540A9F92AF9D8B34C4031EA5A7B9F3A4540A9F92AF9D8B34C40
34251	23648	42.097749	42.232649000000002	57.429445000000001	57.365788000000002	Завражная	0103000020E61000000100000005000000BD1B0B0A830C454077A22424D2AE4C40BD1B0B0A830C45402237C30DF8B64C403B394371C71D45402237C30DF8B64C403B394371C71D454077A22424D2AE4C40BD1B0B0A830C454077A22424D2AE4C40
34349	23485	42.223126999999998	42.251289	57.270353	57.256428	Большегорковская	0103000020E6100000010000000500000063EDEF6C8F1C4540ACE3F8A1D2A04C4063EDEF6C8F1C454010B056ED9AA24C401A6CEA3C2A20454010B056ED9AA24C401A6CEA3C2A204540ACE3F8A1D2A04C4063EDEF6C8F1C4540ACE3F8A1D2A04C40
34363	23438	42.293519000000003	42.31427	57.269584000000002	57.258316000000001	Центральная	0103000020E6100000010000000500000098E0D407922545404B04AA7F10A14C4098E0D407922545402FC37FBA81A24C40950ED6FF392845402FC37FBA81A24C40950ED6FF392845404B04AA7F10A14C4098E0D407922545404B04AA7F10A14C40
34380	23341	39.588054	39.615290999999999	56.861868999999999	56.853808000000001	Советская	0103000020E6100000010000000500000018247D5A45CB434016889E94496D4C4018247D5A45CB4340D63730B9516E4C40F64201DBC1CE4340D63730B9516E4C40F64201DBC1CE434016889E94496D4C4018247D5A45CB434016889E94496D4C40
34242	48915	40.128650999999998	40.133097999999997	56.941572000000001	56.938670000000002	 Малиновского	0103000020E6100000010000000500000081CCCEA27710444040DEAB5626784C4081CCCEA277104440276A696E85784C40DD94F25A09114440276A696E85784C40DD94F25A0911444040DEAB5626784C4081CCCEA27710444040DEAB5626784C40
34361	23272	39.917358	39.936186999999997	57.118682	57.107201000000003	Советская	0103000020E61000000100000005000000AB5CA8FC6BF543409C8C2AC3B88D4C40AB5CA8FC6BF54340DB4FC6F8308F4C405DF8C1F9D4F74340DB4FC6F8308F4C405DF8C1F9D4F743409C8C2AC3B88D4C40AB5CA8FC6BF543409C8C2AC3B88D4C40
34320	49565	39.640290999999998	39.668947000000003	56.982106999999999	56.972276000000001	Школьная	0103000020E610000001000000050000002976340EF5D14340C5573B8A737C4C402976340EF5D143401A16A3AEB57D4C40F0E0270EA0D543401A16A3AEB57D4C40F0E0270EA0D54340C5573B8A737C4C402976340EF5D14340C5573B8A737C4C40
34381	23001	40.048862999999997	40.068041999999998	56.986001000000002	56.977673000000003	Советская	0103000020E61000000100000005000000027E8D244106444053978C63247D4C40027E8D24410644406269E047357E4C409160AA99B50844406269E047357E4C409160AA99B508444053978C63247D4C40027E8D244106444053978C63247D4C40
34333	49555	39.683590000000002	39.709460999999997	57.020457	57.007559000000001	Советская	0103000020E61000000100000005000000B3EF8AE07FD743402EE57CB1F7804C40B3EF8AE07FD74340B5FCC0559E824C40CB64389ECFDA4340B5FCC0559E824C40CB64389ECFDA43402EE57CB1F7804C40B3EF8AE07FD743402EE57CB1F7804C40
34348	22722	39.739339000000001	39.787255000000002	56.983127000000003	56.962409000000001	Школьная	0103000020E6100000010000000500000024D40CA9A2DE43402330D637307B4C4024D40CA9A2DE43404568041BD77D4C40664E97C5C4E443404568041BD77D4C40664E97C5C4E443402330D637307B4C4024D40CA9A2DE43402330D637307B4C40
34096	22722	39.739339000000001	39.787255000000002	56.983127000000003	56.962409000000001	Советская	0103000020E6100000010000000500000024D40CA9A2DE43402330D637307B4C4024D40CA9A2DE43404568041BD77D4C40664E97C5C4E443404568041BD77D4C40664E97C5C4E443402330D637307B4C4024D40CA9A2DE43402330D637307B4C40
34079	22722	39.739339000000001	39.787255000000002	56.983127000000003	56.962409000000001	Революционная	0103000020E6100000010000000500000024D40CA9A2DE43402330D637307B4C4024D40CA9A2DE43404568041BD77D4C40664E97C5C4E443404568041BD77D4C40664E97C5C4E443402330D637307B4C4024D40CA9A2DE43402330D637307B4C40
74886	48873	39.879511999999998	39.891342999999999	56.926613000000003	56.919082000000003	Советская	0103000020E61000000100000005000000433866D993F04340D02B9E7AA4754C40433866D993F04340348639419B764C405F42058717F24340348639419B764C405F42058717F24340D02B9E7AA4754C40433866D993F04340D02B9E7AA4754C40
34228	22918	39.935108999999997	39.972461000000003	56.950133999999998	56.927624000000002	Строительная	0103000020E61000000100000005000000FE98D6A6B1F743400B7E1B62BC764C40FE98D6A6B1F74340A968ACFD9D794C4057D11F9A79FC4340A968ACFD9D794C4057D11F9A79FC43400B7E1B62BC764C40FE98D6A6B1F743400B7E1B62BC764C40
34276	22918	39.935108999999997	39.972461000000003	56.950133999999998	56.927624000000002	Полевая	0103000020E61000000100000005000000FE98D6A6B1F743400B7E1B62BC764C40FE98D6A6B1F74340A968ACFD9D794C4057D11F9A79FC4340A968ACFD9D794C4057D11F9A79FC43400B7E1B62BC764C40FE98D6A6B1F743400B7E1B62BC764C40
33965	54082	40.618322999999997	41.427318	57.194682999999998	56.813631000000001	Парковская	0103000020E61000000100000005000000ABAE4335254F44408201840F25684C40ABAE4335254F4440280B5F5FEB984C40FE7E315BB2B64440280B5F5FEB984C40FE7E315BB2B644408201840F25684C40ABAE4335254F44408201840F25684C40
34119	54098	41.140846000000003	41.141618000000001	56.951031999999998	56.950389000000001	Ивановская	0103000020E61000000100000005000000DFE2E13D0792444034BDC458A6794C40DFE2E13D0792444088B9A46ABB794C403143E3892092444088B9A46ABB794C403143E3892092444034BDC458A6794C40DFE2E13D0792444034BDC458A6794C40
34214	49352	40.847186000000001	40.880774000000002	56.983587999999997	56.968381000000001	Победы	0103000020E6100000010000000500000085D04197706C4440AD889AE8F37B4C4085D04197706C4440785E2A36E67D4C406495D233BD704440785E2A36E67D4C406495D233BD704440AD889AE8F37B4C4085D04197706C4440AD889AE8F37B4C40
34526	46985	41.192822	41.204644000000002	56.912827	56.909210000000002	Зеленая	0103000020E6100000010000000500000083F92B64AE9844401C9947FE60744C4083F92B64AE984440F1F3DF83D7744C404CA94BC6319A4440F1F3DF83D7744C404CA94BC6319A44401C9947FE60744C4083F92B64AE9844401C9947FE60744C40
34240	49204	40.969231999999998	40.996881999999999	57.164627000000003	57.149118000000001	Школьная 	0103000020E610000001000000050000004B1E4FCB0F7C44405A9F724C16934C404B1E4FCB0F7C4440F1845E7F12954C404CFC51D4997F4440F1845E7F12954C404CFC51D4997F44405A9F724C16934C404B1E4FCB0F7C44405A9F724C16934C40
34204	54099	40.816589999999998	40.875151000000002	57.019942	56.998696000000002	Школьная	0103000020E61000000100000005000000CD1E680586684440B1524145D57F4C40CD1E6805866844408EE89E758D824C40E607AEF2047044408EE89E758D824C40E607AEF204704440B1524145D57F4C40CD1E680586684440B1524145D57F4C40
34122	54099	40.816589999999998	40.875151000000002	57.019942	56.998696000000002	Радужная	0103000020E61000000100000005000000CD1E680586684440B1524145D57F4C40CD1E6805866844408EE89E758D824C40E607AEF2047044408EE89E758D824C40E607AEF204704440B1524145D57F4C40CD1E680586684440B1524145D57F4C40
34212	54099	40.816589999999998	40.875151000000002	57.019942	56.998696000000002	Радужная	0103000020E61000000100000005000000CD1E680586684440B1524145D57F4C40CD1E6805866844408EE89E758D824C40E607AEF2047044408EE89E758D824C40E607AEF204704440B1524145D57F4C40CD1E680586684440B1524145D57F4C40
34220	54099	40.816589999999998	40.875151000000002	57.019942	56.998696000000002	Новинская	0103000020E61000000100000005000000CD1E680586684440B1524145D57F4C40CD1E6805866844408EE89E758D824C40E607AEF2047044408EE89E758D824C40E607AEF204704440B1524145D57F4C40CD1E680586684440B1524145D57F4C40
34379	54099	40.816589999999998	40.875151000000002	57.019942	56.998696000000002	2 Шиймановская	0103000020E61000000100000005000000CD1E680586684440B1524145D57F4C40CD1E6805866844408EE89E758D824C40E607AEF2047044408EE89E758D824C40E607AEF204704440B1524145D57F4C40CD1E680586684440B1524145D57F4C40
34434	54099	40.816589999999998	40.875151000000002	57.019942	56.998696000000002	1-я Яковлевская улица	0103000020E61000000100000005000000CD1E680586684440B1524145D57F4C40CD1E6805866844408EE89E758D824C40E607AEF2047044408EE89E758D824C40E607AEF204704440B1524145D57F4C40CD1E680586684440B1524145D57F4C40
34272	20887	41.074280999999999	41.083758000000003	56.924702000000003	56.918751999999998	Спортивная	0103000020E610000001000000050000006ADB300A828944403A9160AA99754C406ADB300A82894440DD4598A25C764C40A2630795B88A4440DD4598A25C764C40A2630795B88A44403A9160AA99754C406ADB300A828944403A9160AA99754C40
34422	21532	41.200035999999997	41.222754000000002	57.044637999999999	57.031880999999998	Школьная	0103000020E61000000100000005000000E60297C79A994440902E36AD14844C40E60297C79A9944405514AFB2B6854C40CF86FC33839C44405514AFB2B6854C40CF86FC33839C4440902E36AD14844C40E60297C79A994440902E36AD14844C40
34364	22441	41.400664999999996	41.416798999999997	57.047840000000001	57.039942000000003	Троицкая	0103000020E610000001000000050000006FD39FFD48B3444051DEC7D11C854C406FD39FFD48B3444067B8019F1F864C40B4006DAB59B5444067B8019F1F864C40B4006DAB59B5444051DEC7D11C854C406FD39FFD48B3444051DEC7D11C854C40
34405	49170	40.747751999999998	40.764955	57.026114999999997	57.018917999999999	Запрудная	0103000020E6100000010000000500000061C26856B65F444022A7AFE76B824C4061C26856B65F4440AF777FBC57834C40B2F4A10BEA614440AF777FBC57834C40B2F4A10BEA61444022A7AFE76B824C4061C26856B65F444022A7AFE76B824C40
34305	54114	41.237900000000003	41.260950999999999	57.098430999999998	57.089427999999998	Колхозная	0103000020E61000000100000005000000F5DBD781739E444060AC6F60728B4C40F5DBD781739E4440CFF41263998C4C40E36DA5D766A14440CFF41263998C4C40E36DA5D766A1444060AC6F60728B4C40F5DBD781739E444060AC6F60728B4C40
34387	21239	41.06174	41.075592	57.068300000000001	57.059153000000002	Озерная	0103000020E61000000100000005000000726DA818E7874440EB3A545392874C40726DA818E78744408D28ED0DBE884C406CEBA7FFAC8944408D28ED0DBE884C406CEBA7FFAC894440EB3A545392874C40726DA818E7874440EB3A545392874C40
34334	48779	40.694930999999997	40.722976000000003	57.071098999999997	57.059251000000003	Лесная	0103000020E6100000010000000500000000FDBE7FF3584440AEA0698995874C4000FDBE7FF35844409FE3A3C519894C407EE5417A8A5C44409FE3A3C519894C407EE5417A8A5C4440AEA0698995874C4000FDBE7FF3584440AEA0698995874C40
34236	49239	41.029266	41.051113000000001	57.143799999999999	57.132288000000003	Садовая	0103000020E610000001000000050000003F7100FDBE8344409ED32CD0EE904C403F7100FDBE8344401895D40968924C4042B3EBDE8A8644401895D40968924C4042B3EBDE8A8644409ED32CD0EE904C403F7100FDBE8344409ED32CD0EE904C40
34401	20565	40.744185999999999	40.778277000000003	57.098807000000001	57.086762999999998	Центральная	0103000020E610000001000000050000000E12A27C415F44405DC0CB0C1B8B4C400E12A27C415F4440D5CE30B5A58C4C40501DAB949E634440D5CE30B5A58C4C40501DAB949E6344405DC0CB0C1B8B4C400E12A27C415F44405DC0CB0C1B8B4C40
34315	19994	41.714742999999999	41.736096000000003	57.462015999999998	57.448013000000003	Центральная	0103000020E61000000100000005000000C005D9B27CDB444068976F7D58B94C40C005D9B27CDB4440471D1D5723BB4C40B45BCB6438DE4440471D1D5723BB4C40B45BCB6438DE444068976F7D58B94C40C005D9B27CDB444068976F7D58B94C40
34259	20085	42.210425000000001	42.236404	57.459401	57.451324999999997	Центральная	0103000020E6100000010000000500000062A1D634EF1A4540006F8104C5B94C4062A1D634EF1A4540F65FE7A6CDBA4C4061527C7C421E4540F65FE7A6CDBA4C4061527C7C421E4540006F8104C5B94C4062A1D634EF1A4540006F8104C5B94C40
34316	20383	41.883654	41.904656000000003	57.586517999999998	57.573765000000002	Зеленая	0103000020E61000000100000005000000637D03931BF14440734BAB2171C94C40637D03931BF14440F641960513CB4C40AA108FC4CBF34440F641960513CB4C40AA108FC4CBF34440734BAB2171C94C40637D03931BF14440734BAB2171C94C40
34418	20265	41.638944000000002	41.683903999999998	57.682533999999997	57.671095000000001	школьная	0103000020E61000000100000005000000DBFCBFEAC8D144402BC1E270E6D54C40DBFCBFEAC8D144403B342C465DD74C4042CD902A8AD744403B342C465DD74C4042CD902A8AD744402BC1E270E6D54C40DBFCBFEAC8D144402BC1E270E6D54C40
34275	20173	42.264333000000001	42.300283	57.474798999999997	57.460776000000003	Фабричная	0103000020E610000001000000050000007520EBA9D52145400F643DB5FABA4C407520EBA9D52145403596B036C6BC4C40BB4560AC6F2645403596B036C6BC4C40BB4560AC6F2645400F643DB5FABA4C407520EBA9D52145400F643DB5FABA4C40
33978	19473	42.105114999999998	42.193752000000003	57.502479000000001	57.454109000000003	Школьная	0103000020E61000000100000005000000D6A88768740D4540DEE8633E20BA4C40D6A88768740D4540A1F65B3B51C04C406EC493DDCC184540A1F65B3B51C04C406EC493DDCC184540DEE8633E20BA4C40D6A88768740D4540DEE8633E20BA4C40
33910	19473	42.105114999999998	42.193752000000003	57.502479000000001	57.454109000000003	Мира	0103000020E61000000100000005000000D6A88768740D4540DEE8633E20BA4C40D6A88768740D4540A1F65B3B51C04C406EC493DDCC184540A1F65B3B51C04C406EC493DDCC184540DEE8633E20BA4C40D6A88768740D4540DEE8633E20BA4C40
34287	20468	42.393312999999999	42.438955999999997	57.466057999999997	57.450085000000001	Школьная	0103000020E61000000100000005000000BB0B941458324540C8B5A1629CB94C40BB0B9414583245400305DEC9A7BB4C400531D0B52F3845400305DEC9A7BB4C400531D0B52F384540C8B5A1629CB94C40BB0B941458324540C8B5A1629CB94C40
34213	19892	41.819020000000002	41.860756000000002	57.542158999999998	57.520448999999999	Административная	0103000020E610000001000000050000008D62B9A5D5E84440321EA5129EC24C408D62B9A5D5E84440B41D537765C54C40FBEAAA402DEE4440B41D537765C54C40FBEAAA402DEE4440321EA5129EC24C408D62B9A5D5E84440321EA5129EC24C40
34400	19962	41.889204999999997	41.914205000000003	57.480246999999999	57.469475000000003	Центральная	0103000020E6100000010000000500000047382D78D1F1444012A5BDC117BC4C4047382D78D1F144404580D3BB78BD4C407B6B60AB04F544404580D3BB78BD4C407B6B60AB04F5444012A5BDC117BC4C4047382D78D1F1444012A5BDC117BC4C40
34239	19866	42.004621	42.025309	57.502251999999999	57.495742	Центральная	0103000020E61000000100000005000000FAEFC16B9700454077A04E7974BF4C40FAEFC16B97004540E02C25CB49C04C40B1A547533D034540E02C25CB49C04C40B1A547533D03454077A04E7974BF4C40FAEFC16B9700454077A04E7974BF4C40
34377	18913	40.164566000000001	40.196061	56.533918999999997	56.521219000000002	Конец	0103000020E610000001000000050000004B04AA7F10154440E486DF4DB7424C404B04AA7F1015444044DB317557444C40B282DF861819444044DB317557444C40B282DF8618194440E486DF4DB7424C404B04AA7F10154440E486DF4DB7424C40
34149	45589	40.295127000000001	40.321024999999999	56.649236000000002	56.634743999999998	Чкалова	0103000020E610000001000000050000005395B6B8C625444086AA984A3F514C405395B6B8C625444064B14D2A1A534C406519E2581729444064B14D2A1A534C406519E2581729444086AA984A3F514C405395B6B8C625444086AA984A3F514C40
74887	60367	40.123099000000003	40.147857000000002	56.482999999999997	56.468259000000003	Старая	0103000020E61000000100000005000000CD9541B5C10F4440628731E9EF3B4C40CD9541B5C10F4440E7FBA9F1D23D4C400ABE69FAEC124440E7FBA9F1D23D4C400ABE69FAEC124440628731E9EF3B4C40CD9541B5C10F4440628731E9EF3B4C40
75051	60466	39.822280999999997	40.417988999999999	56.837893000000001	56.435366999999999	пл. 70 лет Октября	0103000020E61000000100000005000000A38FF98040E94340FA60191BBA374C40A38FF98040E943400F46EC13406B4C403B8BDEA9803544400F46EC13406B4C403B8BDEA980354440FA60191BBA374C40A38FF98040E94340FA60191BBA374C40
33989	18475	40.092053999999997	40.148378000000001	56.575279999999999	56.544158000000003	пос. 9 Января	0103000020E61000000100000005000000A5BBEB6CC80B4440ABED26F8A6454C40A5BBEB6CC80B44407D0569C6A2494C4013B9E00CFE1244407D0569C6A2494C4013B9E00CFE124440ABED26F8A6454C40A5BBEB6CC80B4440ABED26F8A6454C40
34095	18475	40.092053999999997	40.148378000000001	56.575279999999999	56.544158000000003	пл. Советская	0103000020E61000000100000005000000A5BBEB6CC80B4440ABED26F8A6454C40A5BBEB6CC80B44407D0569C6A2494C4013B9E00CFE1244407D0569C6A2494C4013B9E00CFE124440ABED26F8A6454C40A5BBEB6CC80B4440ABED26F8A6454C40
33939	18475	40.092053999999997	40.148378000000001	56.575279999999999	56.544158000000003	Советская	0103000020E61000000100000005000000A5BBEB6CC80B4440ABED26F8A6454C40A5BBEB6CC80B44407D0569C6A2494C4013B9E00CFE1244407D0569C6A2494C4013B9E00CFE124440ABED26F8A6454C40A5BBEB6CC80B4440ABED26F8A6454C40
33956	18334	41.864789000000002	41.887965999999999	57.307806999999997	57.293253	Парковая	0103000020E610000001000000050000006478EC67B1EE4440193A765089A54C406478EC67B1EE44406C3D433866A74C40DFFAB0DEA8F144406C3D433866A74C40DFFAB0DEA8F14440193A765089A54C406478EC67B1EE4440193A765089A54C40
34171	17870	41.856757999999999	41.902734000000002	57.286935	57.255532000000002	Школьная	0103000020E610000001000000050000000E4B033FAAED44406E8AC745B5A04C400E4B033FAAED4440F4893C49BAA44C405F7EA7C98CF34440F4893C49BAA44C405F7EA7C98CF344406E8AC745B5A04C400E4B033FAAED44406E8AC745B5A04C40
33970	17870	41.856757999999999	41.902734000000002	57.286935	57.255532000000002	Советская	0103000020E610000001000000050000000E4B033FAAED44406E8AC745B5A04C400E4B033FAAED4440F4893C49BAA44C405F7EA7C98CF34440F4893C49BAA44C405F7EA7C98CF344406E8AC745B5A04C400E4B033FAAED44406E8AC745B5A04C40
34094	17870	41.856757999999999	41.902734000000002	57.286935	57.255532000000002	Клшубная	0103000020E610000001000000050000000E4B033FAAED44406E8AC745B5A04C400E4B033FAAED4440F4893C49BAA44C405F7EA7C98CF34440F4893C49BAA44C405F7EA7C98CF344406E8AC745B5A04C400E4B033FAAED44406E8AC745B5A04C40
34289	47896	41.993876999999998	42.012166999999998	57.237074999999997	57.225558999999997	1 Школьная	0103000020E61000000100000005000000909F8D5C37FF4440C328081EDF9C4C40909F8D5C37FF44407FD93D79589E4C40938B31B08E0145407FD93D79589E4C40938B31B08E014540C328081EDF9C4C40909F8D5C37FF4440C328081EDF9C4C40
34481	46779	42.047263999999998	42.063631000000001	57.128708000000003	57.120226000000002	Центральная	0103000020E610000001000000050000009A232BBF0C0645408010C990638F4C409A232BBF0C064540E65DF58079904C408201840F25084540E65DF58079904C408201840F250845408010C990638F4C409A232BBF0C0645408010C990638F4C40
67300	48930	41.912588	41.919541000000002	57.13729	57.134594	Центральная	0103000020E610000001000000050000006C5CFFAECFF44440711E4E603A914C406C5CFFAECFF44440AF08FEB792914C40632AFD84B3F54440AF08FEB792914C40632AFD84B3F54440711E4E603A914C406C5CFFAECFF44440711E4E603A914C40
34038	17769	41.818857999999999	41.869613000000001	57.331242000000003	57.312809000000001	пер.Почтовый	0103000020E61000000100000005000000B308C556D0E844407E7214200AA84C40B308C556D0E84440E4874A2366AA4C409696917A4FEF4440E4874A2366AA4C409696917A4FEF44407E7214200AA84C40B308C556D0E844407E7214200AA84C40
34067	17769	41.818857999999999	41.869613000000001	57.331242000000003	57.312809000000001	Аптечная	0103000020E61000000100000005000000B308C556D0E844407E7214200AA84C40B308C556D0E84440E4874A2366AA4C409696917A4FEF4440E4874A2366AA4C409696917A4FEF44407E7214200AA84C40B308C556D0E844407E7214200AA84C40
34487	48049	42.200533999999998	42.212850000000003	57.170135999999999	57.163679999999999	Центральная	0103000020E6100000010000000500000037DE1D19AB19454030815B77F3944C4037DE1D19AB194540A6EF3504C7954C40107A36AB3E1B4540A6EF3504C7954C40107A36AB3E1B454030815B77F3944C4037DE1D19AB19454030815B77F3944C40
33909	47723	41.778542000000002	41.814473999999997	57.404400000000003	57.377668999999997	Николаева	0103000020E61000000100000005000000FE47A643A7E3444044DB317557B04C40FE47A643A7E344404F401361C3B34C409DB81CAF40E844404F401361C3B34C409DB81CAF40E8444044DB317557B04C40FE47A643A7E3444044DB317557B04C40
34036	47723	41.778542000000002	41.814473999999997	57.404400000000003	57.377668999999997	1 Мая	0103000020E61000000100000005000000FE47A643A7E3444044DB317557B04C40FE47A643A7E344404F401361C3B34C409DB81CAF40E844404F401361C3B34C409DB81CAF40E8444044DB317557B04C40FE47A643A7E3444044DB317557B04C40
34241	49584	41.766666000000001	41.775640000000003	57.315609000000002	57.309144000000003	Совхозная	0103000020E61000000100000005000000427A8A1C22E2444098E0D40792A74C40427A8A1C22E2444061A92EE065A84C4017BCE82B48E3444061A92EE065A84C4017BCE82B48E3444098E0D40792A74C40427A8A1C22E2444098E0D40792A74C40
34356	47076	41.852536000000001	41.864168999999997	57.278407000000001	57.271949999999997	Клубная	0103000020E61000000100000005000000D2544FE61FED4440D712F241CFA24C40D2544FE61FED44401EFD2FD7A2A34C40C79BFC169DEE44401EFD2FD7A2A34C40C79BFC169DEE4440D712F241CFA24C40D2544FE61FED4440D712F241CFA24C40
67312	49446	41.640155999999998	41.649121999999998	57.29372	57.289411000000001	Школьная	0103000020E61000000100000005000000492BBEA1F0D14440240D6E6B0BA54C40492BBEA1F0D144402F17F19D98A54C409B8E006E16D344402F17F19D98A54C409B8E006E16D34440240D6E6B0BA54C40492BBEA1F0D14440240D6E6B0BA54C40
34360	45582	42.754750000000001	42.771026999999997	56.882235000000001	56.870524000000003	Советская	0103000020E61000000100000005000000F853E3A59B6045400A3197546D6F4C40F853E3A59B6045407B319413ED704C409FAA4203B16245407B319413ED704C409FAA4203B16245400A3197546D6F4C40F853E3A59B6045400A3197546D6F4C40
34331	12285	42.299501999999997	42.335397999999998	56.827221999999999	56.802405999999998	Торговая	0103000020E61000000100000005000000158BDF14562645409D0E643DB5664C40158BDF14562645400F441669E2694C4068925852EE2A45400F441669E2694C4068925852EE2A45409D0E643DB5664C40158BDF14562645409D0E643DB5664C40
34362	12285	42.299501999999997	42.335397999999998	56.827221999999999	56.802405999999998	Восточная	0103000020E61000000100000005000000158BDF14562645409D0E643DB5664C40158BDF14562645400F441669E2694C4068925852EE2A45400F441669E2694C4068925852EE2A45409D0E643DB5664C40158BDF14562645409D0E643DB5664C40
34332	49118	42.499124999999999	42.524431	56.885496000000003	56.875895	Черемушки	0103000020E61000000100000005000000D9CEF753E33F45406EDDCD531D704C40D9CEF753E33F4540925ED4EE57714C401901158E20434540925ED4EE57714C401901158E204345406EDDCD531D704C40D9CEF753E33F45406EDDCD531D704C40
34419	47705	42.789712000000002	42.807732999999999	56.844062000000001	56.837076000000003	Школьная	0103000020E610000001000000050000001FA16648156545401D226E4E256B4C401FA1664815654540EFE53E390A6C4C40327381CB63674540EFE53E390A6C4C40327381CB636745401D226E4E256B4C401FA16648156545401D226E4E256B4C40
34230	17545	42.575176999999996	42.616211999999997	56.845976999999998	56.831088000000001	пер.Школьный	0103000020E61000000100000005000000A83462669F4945408D0C7217616A4C40A83462669F49454087156EF9486C4C408DB3E908E04E454087156EF9486C4C408DB3E908E04E45408D0C7217616A4C40A83462669F4945408D0C7217616A4C40
34359	47364	42.631383999999997	42.637366999999998	56.906458000000001	56.903233999999998	Колхозная	0103000020E61000000100000005000000DC9BDF30D15045405051F52B9D734C40DC9BDF30D15045404A99D4D006744C405A46EA3D955145404A99D4D006744C405A46EA3D955145405051F52B9D734C40DC9BDF30D15045405051F52B9D734C40
74968	60404	39.184494999999998	39.195805	51.646196000000003	51.628180999999998	Чапаева	0103000020E6100000010000000500000044A33B889D974340FA7B293C68D0494044A33B889D9743402C67EF8CB6D2494057B26323109943402C67EF8CB6D2494057B2632310994340FA7B293C68D0494044A33B889D974340FA7B293C68D04940
36555	54257	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	площадь Ленина	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36113	54257	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Труда	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36013	54257	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Советская	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36618	54257	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Лермонтова	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
35774	54257	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Горная	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36217	54284	39.161866000000003	39.163545999999997	51.738861999999997	51.736541000000003	переулок Гагарина	0103000020E61000000100000005000000CC2A6C06B8944340E294B9F946DE4940CC2A6C06B8944340EA20AF0793DE494020B24813EF944340EA20AF0793DE494020B24813EF944340E294B9F946DE4940CC2A6C06B8944340E294B9F946DE4940
36272	54284	39.184494999999998	39.195805	51.646196000000003	51.628180999999998	Чапаева	0103000020E6100000010000000500000044A33B889D974340FA7B293C68D0494044A33B889D9743402C67EF8CB6D2494057B26323109943402C67EF8CB6D2494057B2632310994340FA7B293C68D0494044A33B889D974340FA7B293C68D04940
36331	54284	39.201635000000003	39.210572999999997	51.675148	51.672773999999997	Чайковского	0103000020E610000001000000050000004F5DF92CCF994340AFCC5B751DD649404F5DF92CCF994340DBFAE93F6BD64940D6355A0EF49A4340DBFAE93F6BD64940D6355A0EF49A4340AFCC5B751DD649404F5DF92CCF994340AFCC5B751DD64940
36332	54284	39.207895999999998	39.213915	51.698180000000001	51.682245999999999	Транспортная	0103000020E610000001000000050000000F7C0C569C9A4340D5E940D653D749400F7C0C569C9A4340535C55F65DD94940DA8F1491619B4340535C55F65DD94940DA8F1491619B4340D5E940D653D749400F7C0C569C9A4340D5E940D653D74940
36118	54284	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	Крупской переулок	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
36301	54284	39.202713000000003	39.207168000000003	51.661909000000001	51.659757999999997	Дзержинского	0103000020E61000000100000005000000AEBCE47FF29943401EA33CF372D44940AEBCE47FF2994340CBF6216FB9D449408D63247B849A4340CBF6216FB9D449408D63247B849A43401EA33CF372D44940AEBCE47FF29943401EA33CF372D44940
36672	54284	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	Башкирцева переулок	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
36233	54284	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	8 Марта	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
36232	54284	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	25 лет Октября	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
36010	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	проспект Труда	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35869	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	пролетарская	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36956	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	площадь Танкистов	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35810	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	переулок Школьный	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35935	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	луговая	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35761	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Элеваторная	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36635	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Центральная	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36175	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Фурманова	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36008	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Урицкого	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35977	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Толбухина	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36107	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Свердлова	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36171	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Розы Люксембург	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35934	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Простеева	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35822	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Пролетарская	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35812	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Пески	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35786	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Октябрьская	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35768	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Маршака	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36023	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Ленина	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35811	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Крупской	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36108	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Заводская	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35890	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Дзержинского	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35793	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Деповская	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
35940	2019	39.509523000000002	39.640011999999999	50.213695999999999	50.166491000000001	Белинского	0103000020E61000000100000005000000A8C7B60C38C14340070ABC934F154940A8C7B60C38C143409CA4F9635A1B49401686C8E9EBD143409CA4F9635A1B49401686C8E9EBD14340070ABC934F154940A8C7B60C38C14340070ABC934F154940
36088	54278	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	Советская	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
36001	54278	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	Садовая	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
36003	54278	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	Народная	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
36077	54278	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	Линейная	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
36089	54255	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	проспект Революции	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
36184	54255	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	микрорайон Гранитный	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
35746	54255	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	Ю.Фучика	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
36102	54255	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	Покровская	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
35939	54255	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	К.Готвальда	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
36071	54258	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Энгельса	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
35944	54258	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Комсомольская	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
35785	54258	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Карла Маркса	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
36047	54258	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	50 лет Октября	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
36079	54270	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	Советская	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
35968	54270	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	Плотникова	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
35999	54270	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	Ленина	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
35990	54253	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Победы	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35919	54253	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Первомайская	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35817	54253	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Октябрьская	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35723	54253	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Набережная	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35725	54253	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Космонавтов	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
36038	54281	39.450800000000001	39.514518000000002	50.963075000000003	50.922620999999999	Советская	0103000020E61000000100000005000000B6847CD0B3B9434029CDE67118764940B6847CD0B3B94340304CA60A467B4940079ACFB9DBC14340304CA60A467B4940079ACFB9DBC1434029CDE67118764940B6847CD0B3B9434029CDE67118764940
36094	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	проспект Ленина	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36060	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	площадь Революции	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36092	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Энтузиастов	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35715	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Чернышевского	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35897	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Советская	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36054	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Первомайская	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35859	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Ломоносова	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35717	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	40 лет Победы	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36056	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	40 лет Октября	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35719	54251	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	19 Партсъезда	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36143	54271	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	Пугачева	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
36150	54271	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	Комсомольская	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
36139	54277	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	Советская	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
35984	54277	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	Мебельная	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
35889	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	федора тютчева	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
45	19	39.185986	39.197889000000004	51.713540000000002	51.688510999999998	улица Шишкова	0103000020E61000000100000005000000C6C1A563CE974340D7F7E12021D84940C6C1A563CE974340A5315A4755DB49407C9E3F6D54994340A5315A4755DB49407C9E3F6D54994340D7F7E12021D84940C6C1A563CE974340D7F7E12021D84940
7687	19	39.110114000000003	39.11148	51.661132000000002	51.654299000000002	улица Шендрикова	0103000020E61000000100000005000000776A2E37188E43401B67D311C0D34940776A2E37188E4340672B2FF99FD449403C1405FA448E4340672B2FF99FD449403C1405FA448E43401B67D311C0D34940776A2E37188E43401B67D311C0D34940
16214	19	39.086452999999999	39.094394000000001	51.554858000000003	51.548490999999999	улица Теплоэнергетиков	0103000020E610000001000000050000000FD253E4108B43403E93FDF334C649400FD253E4108B434045F6419605C749402578431A158C434045F6419605C749402578431A158C43403E93FDF334C649400FD253E4108B43403E93FDF334C64940
6658	19	39.218603999999999	39.237558	51.612803	51.611795999999998	улица Танеева	0103000020E610000001000000050000002C634337FB9B43406CE9D1544FCE49402C634337FB9B434002F2255470CE49409B73F04C689E434002F2255470CE49409B73F04C689E43406CE9D1544FCE49402C634337FB9B43406CE9D1544FCE4940
7231	19	39.139274	39.181404999999998	51.645392000000001	51.632714999999997	улица Матросова	0103000020E610000001000000050000007097FDBAD391434025581CCEFCD049407097FDBAD3914340CE8C7E349CD249405A2A6F4738974340CE8C7E349CD249405A2A6F473897434025581CCEFCD049407097FDBAD391434025581CCEFCD04940
7476	19	39.151257000000001	39.185833000000002	51.657702	51.641742000000001	улица Ворошилова	0103000020E610000001000000050000004225AE635C9343401D3C139A24D249404225AE635C934340C44142942FD4494040C23060C9974340C44142942FD4494040C23060C99743401D3C139A24D249404225AE635C9343401D3C139A24D24940
5629	19	39.259881	39.276797000000002	51.730874	51.703003000000002	улица Богдана Хмельницкого	0103000020E6100000010000000500000007EDD5C743A14340B5FE9600FCD9494007EDD5C743A1434094BF7B478DDD4940C25087156EA3434094BF7B478DDD4940C25087156EA34340B5FE9600FCD9494007EDD5C743A14340B5FE9600FCD94940
6008	19	39.135140999999997	39.196244999999998	51.698760999999998	51.693072000000001	улица Беговая	0103000020E61000000100000005000000A3ACDF4C4C914340FCE25295B6D84940A3ACDF4C4C914340315C1D0071D949407380608E1E994340315C1D0071D949407380608E1E994340FCE25295B6D84940A3ACDF4C4C914340FCE25295B6D84940
7448	19	39.184117000000001	39.195354999999999	51.675148	51.671221000000003	улица III Интернационала	0103000020E610000001000000050000009ED1562591974340B8B1D991EAD549409ED1562591974340DBFAE93F6BD64940170E846401994340DBFAE93F6BD64940170E846401994340B8B1D991EAD549409ED1562591974340B8B1D991EAD54940
4345	19	39.157913999999998	39.159143999999998	51.711686999999998	51.701658000000002	улица 60 лет ВЛКСМ	0103000020E610000001000000050000004FCAA48636944340077DE9EDCFD949404FCAA4863694434082FE428F18DB494064ADA1D45E94434082FE428F18DB494064ADA1D45E944340077DE9EDCFD949404FCAA48636944340077DE9EDCFD94940
5898	19	39.161335999999999	39.205857000000002	51.684322999999999	51.670489000000003	проспект Труда	0103000020E610000001000000050000006FD575A8A6944340F4A96395D2D549406FD575A8A6944340477364E597D749408B53AD85599A4340477364E597D749408B53AD85599A4340F4A96395D2D549406FD575A8A6944340F4A96395D2D54940
42	19	39.204796999999999	39.215980999999999	51.681978000000001	51.664361999999997	проспект Революции	0103000020E61000000100000005000000D2A8C0C9369A4340425A63D009D54940D2A8C0C9369A4340B64B1B0E4BD7494058C7F143A59B4340B64B1B0E4BD7494058C7F143A59B4340425A63D009D54940D2A8C0C9369A4340425A63D009D54940
7817	19	39.098821999999998	39.135330000000003	51.648409999999998	51.645162999999997	проспект Патриотов	0103000020E610000001000000050000000A100533A68C43406CCB80B394D249400A100533A68C43401E335019FFD249407715527E529143401E335019FFD249407715527E529143406CCB80B394D249400A100533A68C43406CCB80B394D24940
36213	19	39.139031000000003	39.140621000000003	51.734544999999997	51.732368999999998	площадь Советов	0103000020E61000000100000005000000AA108FC4CB91434057CD7344BEDD4940AA108FC4CB9143405C38109205DE4940BF1072DEFF9143405C38109205DE4940BF1072DEFF91434057CD7344BEDD4940AA108FC4CB91434057CD7344BEDD4940
15775	19	39.196829000000001	39.204859999999996	51.664377999999999	51.659227000000001	площадь Ленина	0103000020E61000000100000005000000C3F352B131994340F2D1E28C61D44940C3F352B13199434048179B560AD5494018213CDA389A434048179B560AD5494018213CDA389A4340F2D1E28C61D44940C3F352B131994340F2D1E28C61D44940
36048	19	39.196829000000001	39.204859999999996	51.664377999999999	51.659227000000001	площадь Ленина	0103000020E61000000100000005000000C3F352B131994340F2D1E28C61D44940C3F352B13199434048179B560AD5494018213CDA389A434048179B560AD5494018213CDA389A4340F2D1E28C61D44940C3F352B131994340F2D1E28C61D44940
15841	19	39.235734999999998	39.241923999999997	51.551856999999998	51.550966000000003	переулок Звездный	0103000020E61000000100000005000000E3C281902C9E43409E9ACB0D86C64940E3C281902C9E4340CA880B40A3C649400A0F9A5DF79E4340CA880B40A3C649400A0F9A5DF79E43409E9ACB0D86C64940E3C281902C9E43409E9ACB0D86C64940
6835	19	39.228872000000003	39.233227999999997	51.646006	51.632603000000003	набережная Авиастроителей	0103000020E610000001000000050000002D7C7DAD4B9D4340FE2C9622F9D049402D7C7DAD4B9D434088821953B0D249407841446ADA9D434088821953B0D249407841446ADA9D4340FE2C9622F9D049402D7C7DAD4B9D4340FE2C9622F9D04940
36293	19	39.137036999999999	39.181170999999999	51.710034999999998	51.702483999999998	генерала Лизюкова	0103000020E61000000100000005000000C5ABAC6D8A9143404CFBE6FEEAD94940C5ABAC6D8A914340F701486DE2DA4940E7FD7F9C30974340F701486DE2DA4940E7FD7F9C309743404CFBE6FEEAD94940C5ABAC6D8A9143404CFBE6FEEAD94940
6465	19	39.141483000000001	39.186003999999997	51.714303999999998	51.711407999999999	бульвар Победы	0103000020E6100000010000000500000051F86C1D1C9243406F0ED76A0FDB494051F86C1D1C92434074B33F506EDB49406C76A4FACE97434074B33F506EDB49406C76A4FACE9743406F0ED76A0FDB494051F86C1D1C9243406F0ED76A0FDB4940
5120	19	39.148715000000003	39.156925000000001	51.657646	51.654237999999999	бульвар Пионеров	0103000020E610000001000000050000005BB6D6170993434075E61E12BED349405BB6D61709934340302C7FBE2DD4494060764F1E16944340302C7FBE2DD4494060764F1E1694434075E61E12BED349405BB6D6170993434075E61E12BED34940
36320	19	39.143144999999997	39.149873999999997	51.651572000000002	51.648772999999998	Юлюса Янониса	0103000020E61000000100000005000000FFCA4A93529243408FC360FE0AD34940FFCA4A9352924340A27E17B666D34940A6423C122F934340A27E17B666D34940A6423C122F9343408FC360FE0AD34940FFCA4A93529243408FC360FE0AD34940
36264	19	39.103098000000003	39.138024999999999	51.655534000000003	51.653657000000003	Южно-Моравская	0103000020E610000001000000050000003A24B550328D434097E65608ABD349403A24B550328D434042B5C189E8D34940E4839ECDAA91434042B5C189E8D34940E4839ECDAA91434097E65608ABD349403A24B550328D434097E65608ABD34940
36256	19	39.165557999999997	39.184323999999997	51.687567000000001	51.684524000000003	Электросигнальная	0103000020E61000000100000005000000ABCB290131954340DFA9807B9ED74940ABCB2901319543408867093202D8494017EFC7ED979743408867093202D8494017EFC7ED97974340DFA9807B9ED74940ABCB290131954340DFA9807B9ED74940
36329	19	39.290711999999999	39.291421	51.738605	51.734327	Электровозная	0103000020E610000001000000050000000247020D36A54340EFC8586DFEDD49400247020D36A54340BFD4CF9B8ADE49400E2F88484DA54340BFD4CF9B8ADE49400E2F88484DA54340EFC8586DFEDD49400247020D36A54340EFC8586DFEDD4940
36361	19	39.185986	39.197889000000004	51.713540000000002	51.688510999999998	Шишкова	0103000020E61000000100000005000000C6C1A563CE974340D7F7E12021D84940C6C1A563CE974340A5315A4755DB49407C9E3F6D54994340A5315A4755DB49407C9E3F6D54994340D7F7E12021D84940C6C1A563CE974340D7F7E12021D84940
36334	19	39.110114000000003	39.11148	51.661132000000002	51.654299000000002	Шендрикова	0103000020E61000000100000005000000776A2E37188E43401B67D311C0D34940776A2E37188E4340672B2FF99FD449403C1405FA448E4340672B2FF99FD449403C1405FA448E43401B67D311C0D34940776A2E37188E43401B67D311C0D34940
36367	19	39.160266999999997	39.170670000000001	51.647219	51.637718	Черняховского	0103000020E6100000010000000500000063D009A183944340070951BEA0D1494063D009A183944340C72C7B12D8D249404434BA83D8954340C72C7B12D8D249404434BA83D8954340070951BEA0D1494063D009A183944340070951BEA0D14940
36246	19	39.264857999999997	39.277282	51.631132999999998	51.630701999999999	Черепанова	0103000020E61000000100000005000000BF0AF0DDE6A14340CAC2D7D7BAD04940BF0AF0DDE6A14340933655F7C8D049407EE200FA7DA34340933655F7C8D049407EE200FA7DA34340CAC2D7D7BAD04940BF0AF0DDE6A14340CAC2D7D7BAD04940
36350	19	39.185088	39.202308000000002	51.654891999999997	51.638947000000002	Челюскинцев	0103000020E61000000100000005000000E770ADF6B09743404C70EA03C9D14940E770ADF6B0974340BD344580D3D349400EDC813AE5994340BD344580D3D349400EDC813AE59943404C70EA03C9D14940E770ADF6B09743404C70EA03C9D14940
36221	19	39.250728000000002	39.292194000000002	51.603194000000002	51.589688000000002	Чебышева	0103000020E610000001000000050000008318E8DA17A04340FD6B79E57ACB49408318E8DA17A043405C92037635CD4940310BED9C66A543405C92037635CD4940310BED9C66A54340FD6B79E57ACB49408318E8DA17A04340FD6B79E57ACB4940
36279	19	39.184494999999998	39.195805	51.646196000000003	51.628180999999998	Чапаева	0103000020E6100000010000000500000044A33B889D974340FA7B293C68D0494044A33B889D9743402C67EF8CB6D2494057B26323109943402C67EF8CB6D2494057B2632310994340FA7B293C68D0494044A33B889D974340FA7B293C68D04940
36269	19	39.231206999999998	39.286723000000002	51.640366999999998	51.629634000000003	Циолковского	0103000020E610000001000000050000009ACDE330989D43408F39CFD897D049409ACDE330989D43400438BD8BF7D149406901DA56B3A443400438BD8BF7D149406901DA56B3A443408F39CFD897D049409ACDE330989D43408F39CFD897D04940
6574	19	39.237836999999999	39.249335000000002	51.622075000000002	51.617635	Цимлянский переулок	0103000020E61000000100000005000000AE635C71719E4340B7EEE6A90ECF4940AE635C71719E434061545227A0CF4940C45F9335EA9F434061545227A0CF4940C45F9335EA9F4340B7EEE6A90ECF4940AE635C71719E4340B7EEE6A90ECF4940
36338	19	39.243603999999998	39.247691000000003	51.619945000000001	51.612954000000002	Цимлянская	0103000020E610000001000000050000005F96766A2E9F4340E8F9D34675CE49405F96766A2E9F4340CC28965B5ACF4940BC41B456B49F4340CC28965B5ACF4940BC41B456B49F4340E8F9D34675CE49405F96766A2E9F4340E8F9D34675CE4940
36210	19	39.085096	39.092381000000003	51.66263	51.648935000000002	Центральная	0103000020E610000001000000050000009D82FC6CE48A4340691D554D10D349409D82FC6CE48A43409BAC510FD1D44940CAE2FE23D38B43409BAC510FD1D44940CAE2FE23D38B4340691D554D10D349409D82FC6CE48A4340691D554D10D34940
67147	19	39.085096	39.092381000000003	51.66263	51.648935000000002	Центральная	0103000020E610000001000000050000009D82FC6CE48A4340691D554D10D349409D82FC6CE48A43409BAC510FD1D44940CAE2FE23D38B43409BAC510FD1D44940CAE2FE23D38B4340691D554D10D349409D82FC6CE48A4340691D554D10D34940
36271	19	39.135446999999999	39.202218000000002	51.703701000000002	51.700904000000001	Хользунова	0103000020E61000000100000005000000B0ABC953569143405BD1E638B7D94940B0ABC95356914340CD94D6DF12DA4940CE548847E2994340CD94D6DF12DA4940CE548847E29943405BD1E638B7D94940B0ABC953569143405BD1E638B7D94940
36311	19	39.186174999999999	39.215980999999999	51.681978000000001	51.657283	Фридриха Энгельса	0103000020E61000000100000005000000992A1895D4974340BF9B6ED921D44940992A1895D4974340B64B1B0E4BD7494058C7F143A59B4340B64B1B0E4BD7494058C7F143A59B4340BF9B6ED921D44940992A1895D4974340BF9B6ED921D44940
6252	19	39.182490999999999	39.186982999999998	51.701461999999999	51.701093999999998	Ученический переулок	0103000020E610000001000000050000003C6876DD5B974340FEB5BC72BDD949403C6876DD5B97434081B1BE81C9D9494038F4160FEF97434081B1BE81C9D9494038F4160FEF974340FEB5BC72BDD949403C6876DD5B974340FEB5BC72BDD94940
36286	19	39.185006999999999	39.215262000000003	51.683284	51.679057	Урицкого	0103000020E61000000100000005000000FA43334FAE974340588FFB56EBD64940FA43334FAE974340A6F0A0D975D74940290989B48D9B4340A6F0A0D975D74940290989B48D9B4340588FFB56EBD64940FA43334FAE974340588FFB56EBD64940
16302	19	39.204535999999997	39.205919999999999	51.657691	51.656908999999999	Университетская площадь	0103000020E61000000100000005000000656D533C2E9A43405AB9179815D44940656D533C2E9A4340D0EFFB372FD44940D1CB28965B9A4340D0EFFB372FD44940D1CB28965B9A43405AB9179815D44940656D533C2E9A43405AB9179815D44940
7185	19	39.168270999999997	39.173859	51.640261000000002	51.634498000000001	Туркменский переулок	0103000020E61000000100000005000000BFEE74E7899543404FB0FF3A37D14940BFEE74E789954340BFF38B12F4D14940C18EFF0241964340BFF38B12F4D14940C18EFF02419643404FB0FF3A37D14940BFEE74E7899543404FB0FF3A37D14940
36248	19	39.265945000000002	39.274901	51.644134000000001	51.632167000000003	Туполева	0103000020E6100000010000000500000072C45A7C0AA24340234E27D9EAD0494072C45A7C0AA24340EF1EA0FB72D24940A051BAF42FA34340EF1EA0FB72D24940A051BAF42FA34340234E27D9EAD0494072C45A7C0AA24340234E27D9EAD04940
36196	19	39.207895999999998	39.213915	51.698180000000001	51.682245999999999	Транспортная	0103000020E610000001000000050000000F7C0C569C9A4340D5E940D653D749400F7C0C569C9A4340535C55F65DD94940DA8F1491619B4340535C55F65DD94940DA8F1491619B4340D5E940D653D749400F7C0C569C9A4340D5E940D653D74940
36368	19	39.215719999999997	39.227182999999997	51.725569	51.709304000000003	Тимирязева	0103000020E61000000100000005000000EB8B84B69C9B434004763579CADA4940EB8B84B69C9B4340E7FEEA71DFDC4940849A2155149D4340E7FEEA71DFDC4940849A2155149D434004763579CADA4940EB8B84B69C9B434004763579CADA4940
36365	19	39.086452999999999	39.094394000000001	51.554858000000003	51.548490999999999	Теплоэнергетиков	0103000020E610000001000000050000000FD253E4108B43403E93FDF334C649400FD253E4108B434045F6419605C749402578431A158C434045F6419605C749402578431A158C43403E93FDF334C649400FD253E4108B43403E93FDF334C64940
36283	19	39.069789	39.087179999999996	51.637180999999998	51.622382999999999	Тепличная	0103000020E610000001000000050000006E4F90D8EE8843400E4B033FAACF49406E4F90D8EE884340F850A2258FD14940C16ED8B6288B4340F850A2258FD14940C16ED8B6288B43400E4B033FAACF49406E4F90D8EE8843400E4B033FAACF4940
36690	19	39.186579000000002	39.210177999999999	51.554645000000001	51.553300999999998	Тавровская	0103000020E61000000100000005000000698F17D2E19743400BEC3191D2C64940698F17D2E1974340E9F17B9BFEC649405A2BDA1CE79A4340E9F17B9BFEC649405A2BDA1CE79A43400BEC3191D2C64940698F17D2E19743400BEC3191D2C64940
36235	19	39.365918000000001	39.380229	51.748564999999999	51.744829000000003	Сухумская	0103000020E610000001000000050000004582A966D6AE4340630E828E56DF49404582A966D6AE434012F758FAD0DF4940D2FE0758ABB0434012F758FAD0DF4940D2FE0758ABB04340630E828E56DF49404582A966D6AE4340630E828E56DF4940
36308	19	39.199793	39.205336000000003	51.676459999999999	51.668790999999999	Студенческая	0103000020E61000000100000005000000207C28D192994340F86D88F19AD54940207C28D192994340AD86C43D96D6494082583673489A4340AD86C43D96D6494082583673489A4340F86D88F19AD54940207C28D192994340F86D88F19AD54940
36429	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	Степная	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
164	19	39.209288000000001	39.217489999999998	51.692179000000003	51.692112000000002	Советский переулок	0103000020E61000000100000005000000FEB8FDF2C99A4340A795422097D84940FEB8FDF2C99A43402FFD4B5299D84940809A5AB6D69B43402FFD4B5299D84940809A5AB6D69B4340A795422097D84940FEB8FDF2C99A4340A795422097D84940
101	19	39.217821999999998	39.224927999999998	51.680252000000003	51.679653999999999	Смоленская улица	0103000020E61000000100000005000000B62C5F97E19B43403C4CFBE6FED64940B62C5F97E19B4340F1845E7F12D7494033FAD170CA9C4340F1845E7F12D7494033FAD170CA9C43403C4CFBE6FED64940B62C5F97E19B43403C4CFBE6FED64940
36319	19	39.073256000000001	39.076723999999999	51.684474000000002	51.682659000000001	Силикатная	0103000020E610000001000000050000002E1EDE7360894340F8A8BF5E61D749402E1EDE73608943402D7B12D89CD74940BE688F17D28943402D7B12D89CD74940BE688F17D2894340F8A8BF5E61D749402E1EDE7360894340F8A8BF5E61D74940
36340	19	39.250404000000003	39.269438999999998	51.667853000000001	51.664394999999999	Серова	0103000020E61000000100000005000000D064FF3C0DA043401E5036E50AD54940D064FF3C0DA043408BC404357CD549402BA226FA7CA243408BC404357CD549402BA226FA7CA243401E5036E50AD54940D064FF3C0DA043401E5036E50AD54940
36359	19	39.170571000000002	39.200395	51.667299999999997	51.657719	Свободы	0103000020E61000000100000005000000B1524145D59543409A7ADD2230D44940B1524145D5954340764F1E166AD5494016A4198BA6994340764F1E166AD5494016A4198BA69943409A7ADD2230D44940B1524145D59543409A7ADD2230D44940
36346	19	39.216008000000002	39.223472999999998	51.685913999999997	51.673532999999999	Сакко и Ванцетти	0103000020E6100000010000000500000052D66F26A69B43406DE34F5436D6494052D66F26A69B43402CEFAA07CCD74940FE4465C39A9C43402CEFAA07CCD74940FE4465C39A9C43406DE34F5436D6494052D66F26A69B43406DE34F5436D64940
36214	19	39.215755999999999	39.236407999999997	51.610269000000002	51.608165999999997	Саврасова	0103000020E6100000010000000500000038F581E49D9B434002452C62D8CD494038F581E49D9B43409E616A4B1DCE4940A2410A9E429E43409E616A4B1DCE4940A2410A9E429E434002452C62D8CD494038F581E49D9B434002452C62D8CD4940
36282	19	39.243667000000002	39.250718999999997	51.619419000000001	51.589565	Ростовская	0103000020E61000000100000005000000A60EF27A309F4340E1EEACDD76CB4940A60EF27A309F4340B1C22D1F49CF49402FBE688F17A04340B1C22D1F49CF49402FBE688F17A04340E1EEACDD76CB4940A60EF27A309F4340E1EEACDD76CB4940
36281	19	39.287315999999997	39.290900000000001	51.666221999999998	51.663640999999998	Рижская	0103000020E610000001000000050000000BCF4BC5C6A4434072A43330F2D449400BCF4BC5C6A4434017F032C346D54940053411363CA5434017F032C346D54940053411363CA5434072A43330F2D449400BCF4BC5C6A4434072A43330F2D44940
36207	19	39.320985	39.331305999999998	51.694288999999998	51.676935	Репненская	0103000020E61000000100000005000000D7C0560916A9434046425BCEA5D64940D7C0560916A943407C7C4276DED84940FA7B293C68AA43407C7C4276DED84940FA7B293C68AA434046425BCEA5D64940D7C0560916A9434046425BCEA5D64940
36299	19	39.207393000000003	39.220787000000001	51.668042999999997	51.666730000000001	Пятницкого	0103000020E61000000100000005000000AD3594DA8B9A43408CA19C6857D54940AD3594DA8B9A43402EA9DA6E82D54940E43098BF429C43402EA9DA6E82D54940E43098BF429C43408CA19C6857D54940AD3594DA8B9A43408CA19C6857D54940
36358	19	39.187036999999997	39.203952000000001	51.664306000000003	51.656511999999999	Пушкинская	0103000020E610000001000000050000002B1213D4F09743403DB7D09508D449402B1213D4F0974340AF44A0FA07D5494016FA60191B9A4340AF44A0FA07D5494016FA60191B9A43403DB7D09508D449402B1213D4F09743403DB7D09508D44940
6107	19	39.184513000000003	39.194214000000002	51.685355999999999	51.684964999999998	Политехнический переулок	0103000020E61000000100000005000000EB573A1F9E974340CBF3E0EEACD74940EB573A1F9E974340060FD3BEB9D7494072361D01DC984340060FD3BEB9D7494072361D01DC984340CBF3E0EEACD74940EB573A1F9E974340CBF3E0EEACD74940
36318	19	39.237791999999999	39.246316999999998	51.643447000000002	51.641558000000003	Полины Осипенко	0103000020E610000001000000050000000EA0DFF76F9E43405C3E92921ED249400EA0DFF76F9E4340CBDAA6785CD2494073B9C150879F4340CBDAA6785CD2494073B9C150879F43405C3E92921ED249400EA0DFF76F9E43405C3E92921ED24940
36343	19	39.185833000000002	39.205191999999997	51.673521999999998	51.657691	Плехановская	0103000020E6100000010000000500000040C23060C9974340D0EFFB372FD4494040C23060C9974340799109F835D649404EB340BB439A4340799109F835D649404EB340BB439A4340D0EFFB372FD4494040C23060C9974340D0EFFB372FD44940
36342	19	39.196829000000001	39.204535999999997	51.659925999999999	51.657170999999998	Платонова	0103000020E61000000100000005000000C3F352B1319943409770E82D1ED44940C3F352B131994340DAE3857478D44940656D533C2E9A4340DAE3857478D44940656D533C2E9A43409770E82D1ED44940C3F352B1319943409770E82D1ED44940
36355	19	39.139111999999997	39.170571000000002	51.667299999999997	51.655589999999997	Пеше-Стрелецкая	0103000020E61000000100000005000000963D096CCE914340D5CA845FEAD34940963D096CCE914340764F1E166AD54940B1524145D5954340764F1E166AD54940B1524145D5954340D5CA845FEAD34940963D096CCE914340D5CA845FEAD34940
36261	19	39.254069000000001	39.263492999999997	51.694612999999997	51.680396999999999	Переверткина	0103000020E61000000100000005000000B6F63E5585A04340F4A5B73F17D74940B6F63E5585A043402F302B14E9D84940CADC7C23BAA143402F302B14E9D84940CADC7C23BAA14340F4A5B73F17D74940B6F63E5585A04340F4A5B73F17D74940
67151	19	39.208156000000002	39.213385000000002	51.663232999999998	51.661417	Первомайская 	0103000020E61000000100000005000000AC3B16DBA49A43405C02F04FA9D44940AC3B16DBA49A43406150A6D1E4D449407E3A1E33509B43406150A6D1E4D449407E3A1E33509B43405C02F04FA9D44940AC3B16DBA49A43405C02F04FA9D44940
36218	19	39.259908000000003	39.276463999999997	51.733657999999998	51.730874	Паровозная	0103000020E6100000010000000500000001FC53AA44A1434094BF7B478DDD494001FC53AA44A1434071395E81E8DD4940BB421F2C63A3434071395E81E8DD4940BB421F2C63A3434094BF7B478DDD494001FC53AA44A1434094BF7B478DDD4940
36327	19	39.229850999999996	39.292203000000001	51.694606999999998	51.678671999999999	Остужева	0103000020E61000000100000005000000F8F9EFC16B9D4340FF5A5EB9DED64940F8F9EFC16B9D43404D49D6E1E8D8494084656CE866A543404D49D6E1E8D8494084656CE866A54340FF5A5EB9DED64940F8F9EFC16B9D4340FF5A5EB9DED64940
4698	19	39.169815999999997	39.172556	51.634838999999999	51.633088999999998	Острогожский переулок	0103000020E61000000100000005000000342BDB87BC9543408A3A730F09D14940342BDB87BC954340D89C836742D14940425DA45016964340D89C836742D14940425DA450169643408A3A730F09D14940342BDB87BC9543408A3A730F09D14940
36262	19	39.094394000000001	39.179734000000003	51.635134999999998	51.554858000000003	Острогожская	0103000020E610000001000000050000002578431A158C434045F6419605C749402578431A158C4340C1C58A1A4CD1494059FD118601974340C1C58A1A4CD1494059FD11860197434045F6419605C749402578431A158C434045F6419605C74940
36364	19	39.121316	39.137341999999997	51.652019000000003	51.651623000000001	Олеко Дундича	0103000020E61000000100000005000000A33D5E48878F43402429E96168D34940A33D5E48878F434071AFCC5B75D34940012F336C9491434071AFCC5B75D34940012F336C949143402429E96168D34940A33D5E48878F43402429E96168D34940
36197	19	39.032949000000002	39.075052999999997	51.58605	51.553161000000003	Октябрьская	0103000020E61000000100000005000000CCB73EAC378443401A36CAFACDC64940CCB73EAC3784434010E9B7AF03CB4940BC3B32569B89434010E9B7AF03CB4940BC3B32569B8943401A36CAFACDC64940CCB73EAC378443401A36CAFACDC64940
36306	19	39.274918999999997	39.283759000000003	51.665450999999997	51.663127000000003	Окружная	0103000020E610000001000000050000004606B98B30A343401C0C7558E1D449404606B98B30A34340950B957F2DD549400C79043752A44340950B957F2DD549400C79043752A443401C0C7558E1D449404606B98B30A343401C0C7558E1D44940
36339	19	39.233182999999997	39.252569000000001	51.624232999999997	51.594907999999997	Новосибирская	0103000020E61000000100000005000000D87DC7F0D89D43407B1002F225CC4940D87DC7F0D89D4340BF0AF0DDE6CF4940E17D552E54A04340BF0AF0DDE6CF4940E17D552E54A043407B1002F225CC4940D87DC7F0D89D43407B1002F225CC4940
36321	19	39.189013000000003	39.203862000000001	51.670974999999999	51.662545999999999	Никитинская	0103000020E610000001000000050000006AC2F693319843403D0CAD4ECED449406AC2F6933198434080B74082E2D54940D6726726189A434080B74082E2D54940D6726726189A43403D0CAD4ECED449406AC2F693319843403D0CAD4ECED44940
35795	19	39.203764	39.205317999999998	51.665317000000002	51.663930999999998	Никитина	0103000020E61000000100000005000000130D52F0149A434079E6E5B0FBD44940130D52F0149A4340863C821B29D54940DBA337DC479A4340863C821B29D54940DBA337DC479A434079E6E5B0FBD44940130D52F0149A434079E6E5B0FBD44940
36313	19	39.244098000000001	39.244484	51.677838999999999	51.674835000000002	Набережная	0103000020E610000001000000050000006F826F9A3E9F43401C9947FE60D649406F826F9A3E9F4340077AA86DC3D64940983270404B9F4340077AA86DC3D64940983270404B9F43401C9947FE60D649406F826F9A3E9F43401C9947FE60D64940
4365	19	39.178655999999997	39.185986	51.734873999999998	51.673471999999997	Московский проспект	0103000020E61000000100000005000000F99D2633DE964340C7629B5434D64940F99D2633DE9643402157EA5910DE4940C6C1A563CE9743402157EA5910DE4940C6C1A563CE974340C7629B5434D64940F99D2633DE964340C7629B5434D64940
36298	19	39.127415999999997	39.128619999999998	51.651634000000001	51.646464999999999	Молодогвардейцев	0103000020E610000001000000050000005A7EE02A4F9043401B81785DBFD249405A7EE02A4F904340187B2FBE68D3494046CEC29E76904340187B2FBE68D3494046CEC29E769043401B81785DBFD249405A7EE02A4F9043401B81785DBFD24940
36336	19	39.225251	39.228915999999998	51.713138000000001	51.712139000000001	Мичурина	0103000020E6100000010000000500000016325706D59C4340639AE95E27DB494016325706D59C434076C4211B48DB4940FCC3961E4D9D434076C4211B48DB4940FCC3961E4D9D4340639AE95E27DB494016325706D59C4340639AE95E27DB4940
36193	19	39.207411	39.208919999999999	51.678274999999999	51.675896000000002	Мира	0103000020E6100000010000000500000053EA92718C9A4340A5BF97C283D6494053EA92718C9A4340E25817B7D1D649407BBDFBE3BD9A4340E25817B7D1D649407BBDFBE3BD9A4340A5BF97C283D6494053EA92718C9A4340A5BF97C283D64940
36245	19	39.254697999999998	39.300179999999997	51.690905999999998	51.665585	Минская	0103000020E61000000100000005000000A52DAEF199A04340A5DAA7E331D54940A52DAEF199A043401A4E999B6FD84940E674594C6CA643401A4E999B6FD84940E674594C6CA64340A5DAA7E331D54940A52DAEF199A04340A5DAA7E331D54940
36348	19	39.2333	39.257618000000001	51.624232999999997	51.617350000000002	Менделеева	0103000020E6100000010000000500000012143FC6DC9D4340C217265305CF494012143FC6DC9D4340BF0AF0DDE6CF4940336E6AA0F9A04340BF0AF0DDE6CF4940336E6AA0F9A04340C217265305CF494012143FC6DC9D4340C217265305CF4940
36263	19	39.151473000000003	39.170724	51.68186	51.667428000000001	Машиностроителей	0103000020E610000001000000050000000F9D9E7763934340A437DC476ED549400F9D9E7763934340AC39403047D749403752B648DA954340AC39403047D749403752B648DA954340A437DC476ED549400F9D9E7763934340A437DC476ED54940
36335	19	39.270921999999999	39.276679999999999	51.713890999999997	51.708288000000003	Маршала Одинцова	0103000020E610000001000000050000002AE27492ADA243401B13622EA9DA49402AE27492ADA2434051F4C0C760DB494088BA0F406AA3434051F4C0C760DB494088BA0F406AA343401B13622EA9DA49402AE27492ADA243401B13622EA9DA4940
36280	19	39.173319999999997	39.178834999999999	51.719777999999998	51.702333000000003	Маршала Жукова	0103000020E6100000010000000500000011DF89592F96434067F3380CE6D9494011DF89592F964340AD307DAF21DC4940A930B610E4964340AD307DAF21DC4940A930B610E496434067F3380CE6D9494011DF89592F96434067F3380CE6D94940
36259	19	39.221603999999999	39.225332000000002	51.685662999999998	51.681033999999997	Мало-Терновая	0103000020E61000000100000005000000D65416855D9C434066BB421F2CD74940D65416855D9C4340E38920CEC3D74940035FD1ADD79C4340E38920CEC3D74940035FD1ADD79C434066BB421F2CD74940D65416855D9C434066BB421F2CD74940
36305	19	39.103870999999998	39.114820999999999	51.659903	51.658209999999997	Любы Шевцовой	0103000020E610000001000000050000005C001AA54B8D434038F3AB3940D449405C001AA54B8D434022C495B377D449406FF25B74B28E434022C495B377D449406FF25B74B28E434038F3AB3940D449405C001AA54B8D434038F3AB3940D44940
36353	19	39.179822999999999	39.233794000000003	51.726858	51.700279000000002	Ломоносова	0103000020E61000000100000005000000C808A87004974340AD8905BEA2D94940C808A87004974340016BD5AE09DD4940220038F6EC9D4340016BD5AE09DD4940220038F6EC9D4340AD8905BEA2D94940C808A87004974340AD8905BEA2D94940
36244	19	39.338636999999999	39.359630000000003	51.736753	51.730806999999999	Липецкая	0103000020E61000000100000005000000971B0C7558AB43400C5872158BDD4940971B0C7558AB43406D1D1CEC4DDE49408B54185B08AE43406D1D1CEC4DDE49408B54185B08AE43400C5872158BDD4940971B0C7558AB43400C5872158BDD4940
36294	19	39.184055000000001	39.197808000000002	51.688594000000002	51.686858000000001	Лидии Рябцевой	0103000020E6100000010000000500000028D53E1D8F9743407C7F83F6EAD7494028D53E1D8F974340651C23D923D849408F71C5C551994340651C23D923D849408F71C5C5519943407C7F83F6EAD7494028D53E1D8F9743407C7F83F6EAD74940
37252	19	39.236741000000002	39.240065000000001	51.722099	51.718114999999997	Лесной поселок	0103000020E61000000100000005000000A94F72874D9E43402EE23B31EBDB4940A94F72874D9E4340B6BC72BD6DDC494006F52D73BA9E4340B6BC72BD6DDC494006F52D73BA9E43402EE23B31EBDB4940A94F72874D9E43402EE23B31EBDB4940
74970	19	39.083803000000003	39.087682999999998	51.645145999999997	51.640742000000003	Лесная	0103000020E610000001000000050000004227840EBA8A43403A9677D503D249404227840EBA8A43409692E52494D2494024B55032398B43409692E52494D2494024B55032398B43403A9677D503D249404227840EBA8A43403A9677D503D24940
5475	19	39.231107999999999	39.275233999999998	51.703003000000002	51.630522999999997	Ленинский проспект	0103000020E6100000010000000500000007EC6AF2949D43401A3048FAB4D0494007EC6AF2949D4340B5FE9600FCD94940A65F22DE3AA34340B5FE9600FCD94940A65F22DE3AA343401A3048FAB4D0494007EC6AF2949D43401A3048FAB4D04940
36326	19	39.239246999999999	39.257384000000002	51.675761999999999	51.638674000000002	Ленинградская	0103000020E6100000010000000500000043554CA59F9E43401B67D311C0D1494043554CA59F9E434095F0845E7FD64940C0417BF5F1A0434095F0845E7FD64940C0417BF5F1A043401B67D311C0D1494043554CA59F9E43401B67D311C0D14940
36267	19	39.196829000000001	39.204859999999996	51.664377999999999	51.659227000000001	Ленина	0103000020E61000000100000005000000C3F352B131994340F2D1E28C61D44940C3F352B13199434048179B560AD5494018213CDA389A434048179B560AD5494018213CDA389A4340F2D1E28C61D44940C3F352B131994340F2D1E28C61D44940
36215	19	39.230182999999997	39.2333	51.630887000000001	51.624133	Лебедева	0103000020E610000001000000050000002E8CF4A2769D43405CAD1397E3CF49402E8CF4A2769D43405C3CBCE7C0D0494012143FC6DC9D43405C3CBCE7C0D0494012143FC6DC9D43405CAD1397E3CF49402E8CF4A2769D43405CAD1397E3CF4940
36249	19	39.115333	39.118720000000003	51.562277999999999	51.558028	Курчатова	0103000020E610000001000000050000002593533BC38E43404B2025766DC749402593533BC38E434051A1BAB9F8C74940C9B08A37328F434051A1BAB9F8C74940C9B08A37328F43404B2025766DC749402593533BC38E43404B2025766DC74940
36347	19	39.231377999999999	39.241788999999997	51.632669999999997	51.630546000000002	Кулибина	0103000020E61000000100000005000000C78157CB9D9D4340D34F38BBB5D04940C78157CB9D9D434085949F54FBD049402AC423F1F29E434085949F54FBD049402AC423F1F29E4340D34F38BBB5D04940C78157CB9D9D4340D34F38BBB5D04940
36194	19	39.265872999999999	39.267651999999998	51.744092999999999	51.729813999999998	Куйбышева	0103000020E61000000100000005000000D8F15F2008A24340DB148F8B6ADD4940D8F15F2008A243405D177E703EDF4940C05AB56B42A243405D177E703EDF4940C05AB56B42A24340DB148F8B6ADD4940D8F15F2008A24340DB148F8B6ADD4940
36333	19	39.141976999999997	39.155254999999997	51.644581000000002	51.640059999999998	Кривошеина	0103000020E6100000010000000500000060E4654D2C92434027BD6F7CEDD1494060E4654D2C924340BE4F55A181D249402EC55565DF934340BE4F55A181D249402EC55565DF93434027BD6F7CEDD1494060E4654D2C92434027BD6F7CEDD14940
36352	19	39.164003999999998	39.188088	51.655171000000003	51.628348000000003	Краснознаменная	0103000020E61000000100000005000000E3344415FE944340E6400FB56DD04940E3344415FE944340D124B1A4DCD349409162804413984340D124B1A4DCD349409162804413984340E6400FB56DD04940E3344415FE944340E6400FB56DD04940
36345	19	39.113796999999998	39.118217000000001	51.661211000000002	51.653689999999997	Краснозвездная	0103000020E6100000010000000500000003B16CE6908E434072DC291DACD3494003B16CE6908E4340B360E28FA2D44940666A12BC218F4340B360E28FA2D44940666A12BC218F434072DC291DACD3494003B16CE6908E434072DC291DACD34940
36303	19	39.150565	39.164228999999999	51.667428000000001	51.650767999999999	Космонавтов	0103000020E610000001000000050000000C76C3B64593434044A4A65D4CD349400C76C3B645934340A437DC476ED549400307B47405954340A437DC476ED549400307B4740595434044A4A65D4CD349400C76C3B64593434044A4A65D4CD34940
36288	19	39.185034000000002	39.214345999999999	51.679620999999997	51.658244000000003	Кольцовская	0103000020E61000000100000005000000F452B131AF974340E564E25641D44940F452B131AF974340605628D2FDD64940A30392B06F9B4340605628D2FDD64940A30392B06F9B4340E564E25641D44940F452B131AF974340E564E25641D44940
36302	19	39.080846999999999	39.097655000000003	51.688544	51.683413000000002	Киселева	0103000020E61000000100000005000000677DCA31598A4340A454C2137AD74940677DCA31598A4340B3EDB43522D849403CA583F57F8C4340B3EDB43522D849403CA583F57F8C4340A454C2137AD74940677DCA31598A4340A454C2137AD74940
36307	19	39.194718000000002	39.213330999999997	51.673181999999997	51.656796999999997	Карла Маркса	0103000020E61000000100000005000000A5F8F884EC984340328E91EC11D44940A5F8F884EC984340C020E9D32AD649408A1C226E4E9B4340C020E9D32AD649408A1C226E4E9B4340328E91EC11D44940A5F8F884EC984340328E91EC11D44940
36356	19	39.168692999999998	39.179850000000002	51.65193	51.643754000000001	Карла Либкнехта	0103000020E61000000100000005000000350873BB97954340A855F48766D24940350873BB9795434001A4367172D34940C21726530597434001A4367172D34940C217265305974340A855F48766D24940350873BB97954340A855F48766D24940
36315	19	39.261552000000002	39.296334999999999	51.740935999999998	51.738605	Калининградская	0103000020E61000000100000005000000091A33897AA14340BFD4CF9B8ADE4940091A33897AA14340EB36A8FDD6DE494080D4264EEEA54340EB36A8FDD6DE494080D4264EEEA54340BFD4CF9B8ADE4940091A33897AA14340BFD4CF9B8ADE4940
36349	19	39.276851000000001	39.290092000000001	51.636794999999999	51.631759000000002	Иркутская	0103000020E61000000100000005000000B56E83DA6FA3434012FA997ADDD04940B56E83DA6FA34340CFA0A17F82D14940666A12BC21A54340CFA0A17F82D14940666A12BC21A5434012FA997ADDD04940B56E83DA6FA3434012FA997ADDD04940
36369	19	39.075206000000001	39.088833000000001	51.695650999999998	51.681168	Защитников Родины	0103000020E61000000100000005000000433BA759A0894340768A558330D74940433BA759A089434000378B170BD949401DE736E15E8B434000378B170BD949401DE736E15E8B4340768A558330D74940433BA759A0894340768A558330D74940
36304	19	39.076723999999999	39.088464999999999	51.682659000000001	51.681274000000002	Заполярная	0103000020E61000000100000005000000BE688F17D2894340BCCE86FC33D74940BE688F17D2894340F8A8BF5E61D749409AEB34D2528B4340F8A8BF5E61D749409AEB34D2528B4340BCCE86FC33D74940BE688F17D2894340BCCE86FC33D74940
36290	19	39.152361999999997	39.166555000000002	51.680101000000001	51.669947999999998	Загородная	0103000020E610000001000000050000009A93179980934340A30227DBC0D549409A931799809343400B7DB08C0DD749401EFE9AAC519543400B7DB08C0DD749401EFE9AAC51954340A30227DBC0D549409A93179980934340A30227DBC0D54940
36241	19	39.365918000000001	39.365999000000002	51.751330000000003	51.742899000000001	Дубовая	0103000020E610000001000000050000004582A966D6AE4340959D7E5017DF49404582A966D6AE43407940D9942BE0494032AF230ED9AE43407940D9942BE0494032AF230ED9AE4340959D7E5017DF49404582A966D6AE4340959D7E5017DF4940
36716	19	39.125925000000002	39.159198000000004	51.664686000000003	51.655875000000002	Дорожная	0103000020E61000000100000005000000D95F764F1E904340CBA145B6F3D34940D95F764F1E904340F60D4C6E14D5494058CB9D9960944340F60D4C6E14D5494058CB9D9960944340CBA145B6F3D34940D95F764F1E904340CBA145B6F3D34940
36310	19	39.170571000000002	39.183757999999997	51.6736	51.667299999999997	Донбасская	0103000020E61000000100000005000000B1524145D5954340764F1E166AD54940B1524145D5954340F54A598638D649406E30D46185974340F54A598638D649406E30D46185974340764F1E166AD54940B1524145D5954340764F1E166AD54940
36211	19	39.139031000000003	39.161372	51.733629999999998	51.721986999999999	Дмитрия Горина	0103000020E61000000100000005000000AA108FC4CB9143408E91EC116ADC4940AA108FC4CB914340A7AE7C96E7DD4940BC3E73D6A7944340A7AE7C96E7DD4940BC3E73D6A79443408E91EC116ADC4940AA108FC4CB9143408E91EC116ADC4940
36309	19	39.244304999999997	39.296379999999999	51.674863000000002	51.652237	Димитрова	0103000020E61000000100000005000000E89FE062459F4340DE1E84807CD34940E89FE062459F4340E62329E961D649402098A3C7EFA54340E62329E961D649402098A3C7EFA54340DE1E84807CD34940E89FE062459F4340DE1E84807CD34940
36351	19	39.198751000000001	39.199235999999999	51.637667	51.634385999999999	Державина	0103000020E610000001000000050000000E863AAC709943402785798F33D149400E863AAC70994340855E7F129FD14940CA17B49080994340855E7F129FD14940CA17B490809943402785798F33D149400E863AAC709943402785798F33D14940
36270	19	39.268514000000003	39.273373999999997	51.703935000000001	51.700468999999998	Грибоедова	0103000020E610000001000000050000005342B0AA5EA24340506EDBF7A8D949405342B0AA5EA2434040C1C58A1ADA4940D1C952EBFDA2434040C1C58A1ADA4940D1C952EBFDA24340506EDBF7A8D949405342B0AA5EA24340506EDBF7A8D94940
36287	19	39.181378000000002	39.210985999999998	51.640501	51.632714999999997	Грамши	0103000020E61000000100000005000000611BF1643797434025581CCEFCD04940611BF164379743401407D0EFFBD14940F9F4D896019B43401407D0EFFBD14940F9F4D896019B434025581CCEFCD04940611BF1643797434025581CCEFCD04940
36205	19	39.310662999999998	39.319654999999997	51.588831999999996	51.586531999999998	Глинки	0103000020E61000000100000005000000E38920CEC3A743405B07077B13CB4940E38920CEC3A743404C6BD3D85ECB49405E807D74EAA843404C6BD3D85ECB49405E807D74EAA843405B07077B13CB4940E38920CEC3A743405B07077B13CB4940
36322	19	39.115594000000002	39.153700000000001	51.675694999999997	51.643078000000003	Героев Сибиряков	0103000020E6100000010000000500000092CEC0C8CB8E43407863416150D2494092CEC0C8CB8E43400D897B2C7DD6494096B20C71AC9343400D897B2C7DD6494096B20C71AC9343407863416150D2494092CEC0C8CB8E43407863416150D24940
35689	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	Героев России	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
35989	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	Генерала Лохматикова	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36325	19	39.137036999999999	39.181170999999999	51.710034999999998	51.702483999999998	Генерала Лизюкова	0103000020E61000000100000005000000C5ABAC6D8A9143404CFBE6FEEAD94940C5ABAC6D8A914340F701486DE2DA4940E7FD7F9C30974340F701486DE2DA4940E7FD7F9C309743404CFBE6FEEAD94940C5ABAC6D8A9143404CFBE6FEEAD94940
6815	19	39.242831000000002	39.246290000000002	51.654539999999997	51.649298000000002	Гвардейский переулок	0103000020E610000001000000050000003DBA1116159F4340DAAD65321CD349403DBA1116159F434040F67AF7C7D349407AAA436E869F434040F67AF7C7D349407AAA436E869F4340DAAD65321CD349403DBA1116159F4340DAAD65321CD34940
36360	19	39.134251999999996	39.143388000000002	51.680922000000002	51.668019999999999	Газовая	0103000020E6100000010000000500000017B6662B2F9143407689EAAD81D5494017B6662B2F9143403F90BC7328D74940C651B9895A9243403F90BC7328D74940C651B9895A9243407689EAAD81D5494017B6662B2F9143407689EAAD81D54940
36297	19	39.151257000000001	39.185833000000002	51.657702	51.641742000000001	Ворошилова	0103000020E610000001000000050000004225AE635C9343401D3C139A24D249404225AE635C934340C44142942FD4494040C23060C9974340C44142942FD4494040C23060C99743401D3C139A24D249404225AE635C9343401D3C139A24D24940
36323	19	39.205533000000003	39.208336000000003	51.661071	51.654153999999998	Володарского	0103000020E61000000100000005000000D89FC4E74E9A434017467A51BBD34940D89FC4E74E9A4340C1AA7AF99DD449402C4A09C1AA9A4340C1AA7AF99DD449402C4A09C1AA9A434017467A51BBD34940D89FC4E74E9A434017467A51BBD34940
36363	19	39.244771999999998	39.254294000000002	51.615805999999999	51.613010000000003	Волгодонская	0103000020E61000000100000005000000FE7C5BB0549F43407C0F971C77CE4940FE7C5BB0549F43401D5723BBD2CE4940D6C8AEB48CA043401D5723BBD2CE4940D6C8AEB48CA043407C0F971C77CE4940FE7C5BB0549F43407C0F971C77CE4940
36247	19	39.264364	39.277622999999998	51.661071	51.638002999999998	Волгоградская	0103000020E61000000100000005000000B01EF7ADD6A14340FCDF1115AAD14940B01EF7ADD6A14340C1AA7AF99DD4494007CF842689A34340C1AA7AF99DD4494007CF842689A34340FCDF1115AAD14940B01EF7ADD6A14340FCDF1115AAD14940
36284	19	39.147950999999999	39.178108000000002	51.726038000000003	51.701239000000001	Владимира Невского	0103000020E610000001000000050000008B34F10EF092434002D71533C2D949408B34F10EF09243409ED32CD0EEDC4940F793313ECC9643409ED32CD0EEDC4940F793313ECC96434002D71533C2D949408B34F10EF092434002D71533C2D94940
36236	19	39.204850999999998	39.206629	51.643044000000003	51.640647000000001	Веры Фигнер	0103000020E61000000100000005000000C5C6BC8E389A4340E8A38CB800D24940C5C6BC8E389A4340CCF10A444FD24940DDB3AED1729A4340CCF10A444FD24940DDB3AED1729A4340E8A38CB800D24940C5C6BC8E389A4340E8A38CB800D24940
36344	19	39.150233	39.160176999999997	51.640405999999999	51.633028000000003	Броневая	0103000020E61000000100000005000000D6E3BED53A934340E5B9BE0F07D14940D6E3BED53A934340C214E5D2F8D14940234910AE80944340C214E5D2F8D14940234910AE80944340E5B9BE0F07D14940D6E3BED53A934340E5B9BE0F07D14940
36199	19	39.143189999999997	39.153638000000001	51.529085000000002	51.512591999999998	Большая Советская	0103000020E610000001000000050000009F8EC70C549243407A185A9D9CC149409F8EC70C54924340EFE6A90EB9C3494020B6F468AA934340EFE6A90EB9C3494020B6F468AA9343407A185A9D9CC149409F8EC70C549243407A185A9D9CC14940
36295	19	39.264481000000004	39.267812999999997	51.723700000000001	51.720944000000003	Богдана Хмельницкого	0103000020E61000000100000005000000EAB46E83DAA14340AC1F9BE447DC4940EAB46E83DAA14340BF0E9C33A2DC4940C93846B247A24340BF0E9C33A2DC4940C93846B247A24340AC1F9BE447DC4940EAB46E83DAA14340AC1F9BE447DC4940
36362	19	39.222799000000002	39.231574999999999	51.703968000000003	51.694752000000001	Березовая Роща	0103000020E610000001000000050000006F4A79AD849C4340516A2FA2EDD849406F4A79AD849C43401CB7989F1BDA49401DC9E53FA49D43401CB7989F1BDA49401DC9E53FA49D4340516A2FA2EDD849406F4A79AD849C4340516A2FA2EDD84940
36195	19	39.135140999999997	39.196244999999998	51.698760999999998	51.693072000000001	Беговая	0103000020E61000000100000005000000A3ACDF4C4C914340FCE25295B6D84940A3ACDF4C4C914340315C1D0071D949407380608E1E994340315C1D0071D949407380608E1E994340FCE25295B6D84940A3ACDF4C4C914340FCE25295B6D84940
36273	19	39.264364	39.273139999999998	51.638019999999997	51.636482000000001	Баррикадная	0103000020E61000000100000005000000B01EF7ADD6A14340103FFF3D78D14940B01EF7ADD6A14340D218ADA3AAD149405E9D6340F6A24340D218ADA3AAD149405E9D6340F6A24340103FFF3D78D14940B01EF7ADD6A14340103FFF3D78D14940
36337	19	39.264481000000004	39.275063000000003	51.720944000000003	51.713890999999997	Артамонова	0103000020E61000000100000005000000EAB46E83DAA1434051F4C0C760DB4940EAB46E83DAA14340AC1F9BE447DC49407AABAE4335A34340AC1F9BE447DC49407AABAE4335A3434051F4C0C760DB4940EAB46E83DAA1434051F4C0C760DB4940
36296	19	39.237090999999999	39.243944999999997	51.657434000000002	51.655428000000001	Арзамасская	0103000020E61000000100000005000000859675FF589E4340FC709010E5D34940859675FF589E4340A5A31CCC26D44940E882FA96399F4340A5A31CCC26D44940E882FA96399F4340FC709010E5D34940859675FF589E4340FC709010E5D34940
36238	19	39.059593	39.088833000000001	51.724414000000003	51.695601000000003	Арбатская	0103000020E61000000100000005000000070951BEA08743404F081D7409D94940070951BEA0874340DD611399B9DC49401DE736E15E8B4340DD611399B9DC49401DE736E15E8B43404F081D7409D94940070951BEA08743404F081D7409D94940
37017	19	39.184117000000001	39.195354999999999	51.675148	51.671221000000003	III Интернационала	0103000020E610000001000000050000009ED1562591974340B8B1D991EAD549409ED1562591974340DBFAE93F6BD64940170E846401994340DBFAE93F6BD64940170E846401994340B8B1D991EAD549409ED1562591974340B8B1D991EAD54940
36285	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	9 Января	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36252	19	39.157913999999998	39.159143999999998	51.711686999999998	51.701658000000002	60-летия ВЛКСМ	0103000020E610000001000000050000004FCAA48636944340077DE9EDCFD949404FCAA4863694434082FE428F18DB494064ADA1D45E94434082FE428F18DB494064ADA1D45E944340077DE9EDCFD949404FCAA48636944340077DE9EDCFD94940
36278	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	45 Стрелковой Дивизии	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36289	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	40 лет Октября	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36253	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	303 стрелковой дивизии	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36328	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	25 Января	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36203	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	206 Стрелковой Дивизии	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36274	19	39.013249000000002	39.658518000000001	51.902819999999998	51.484775999999997	20 лет Октября	0103000020E6100000010000000500000034DAAA24B28143405EF1D4230DBE494034DAAA24B28143405D16139B8FF34940E6E95C514AD443405D16139B8FF34940E6E95C514AD443405EF1D4230DBE494034DAAA24B28143405EF1D4230DBE4940
36366	19	39.135446999999999	39.202218000000002	51.703701000000002	51.700904000000001	 Хользунова	0103000020E61000000100000005000000B0ABC953569143405BD1E638B7D94940B0ABC95356914340CD94D6DF12DA4940CE548847E2994340CD94D6DF12DA4940CE548847E29943405BD1E638B7D94940B0ABC953569143405BD1E638B7D94940
36144	54256	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Маяковского	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
35747	54256	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Ленина	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
36125	54256	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Заводская	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
36036	54256	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Дорожная	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
35776	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	чкалова	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36044	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	рубежная	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36379	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	пос.Водострой	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36148	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	переулок Сенной	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35791	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	переулок Куйбышева	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36059	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	переулок Гражданский	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36533	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	пер.Суровикина	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35985	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	народная	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36040	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	бланская	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35986	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Юго-восточный микрорайон	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35790	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Чкалова	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35789	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Третьяковская	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35788	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Советская	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35787	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Северный микрорайон	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35826	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Северный м/р-н	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35949	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Проходная	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36478	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Первомайская	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35903	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Металлистов	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35898	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Матросовская	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36816	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Корнаковского	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35848	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Дубровинская	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36556	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Бланская	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36179	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	Аэродромная	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
35683	11742	42.056939	42.142288000000001	51.396444000000002	51.334108999999998	40 лет Октября	0103000020E61000000100000005000000F86EF3C6490745404E266E15C4AA4940F86EF3C64907454004594FADBEB249407F4E417E3612454004594FADBEB249407F4E417E361245404E266E15C4AA4940F86EF3C6490745404E266E15C4AA4940
36665	54328	40.520775	40.579551000000002	49.950671999999997	49.918503000000001	Дзержинского	0103000020E6100000010000000500000086C954C1A842444092239D8191F5484086C954C1A8424440889CBE9EAFF948409BAE27BA2E4A4440889CBE9EAFF948409BAE27BA2E4A444092239D8191F5484086C954C1A842444092239D8191F54840
36219	54290	40.794141000000003	40.818925	51.527337000000003	51.508595999999997	Советская	0103000020E61000000100000005000000D5B48B69A66544402E7079AC19C14940D5B48B69A6654440427C60C77FC349403B70CE88D2684440427C60C77FC349403B70CE88D26844402E7079AC19C14940D5B48B69A66544402E7079AC19C14940
35825	54259	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Революционная	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
35824	54259	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	60 лет Октября	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
36966	14491	40.583368999999998	40.617604	51.856135000000002	51.834758999999998	Ф.Усова	0103000020E610000001000000050000000740DCD5AB4A444055850662D9EA49400740DCD5AB4A444001FBE8D495ED49407CF0DAA50D4F444001FBE8D495ED49407CF0DAA50D4F444055850662D9EA49400740DCD5AB4A444055850662D9EA4940
36012	14627	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	степная	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36550	14627	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	площадь Ленина	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
37025	14627	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Пионерская	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36583	14627	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Первомайская	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36580	14627	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Лесная	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36415	14627	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	Комарова	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
36532	14627	40.765070999999999	40.853385000000003	51.870952000000003	51.823169999999998	9 Мая	0103000020E610000001000000050000001B0FB6D8ED6144402F8672A25DE949401B0FB6D8ED6144406231EA5A7BEF4940D0F23CB83B6D44406231EA5A7BEF4940D0F23CB83B6D44402F8672A25DE949401B0FB6D8ED6144402F8672A25DE94940
35794	49160	40.471080000000001	40.916195000000002	51.875833999999998	51.738103000000002	Ленина	0103000020E610000001000000050000005CE674594C3C44402D0ABB287ADE49405CE674594C3C4440C85C19541BF049401EE1B4E045754440C85C19541BF049401EE1B4E0457544402D0ABB287ADE49405CE674594C3C44402D0ABB287ADE4940
36706	54345	40.510184000000002	40.550418999999998	51.779879999999999	51.737555999999998	Советская	0103000020E61000000100000005000000A37895B54D414440FA7B293C68DE4940A37895B54D414440F9669B1BD3E349406B0C3A2174464440F9669B1BD3E349406B0C3A2174464440FA7B293C68DE4940A37895B54D414440FA7B293C68DE4940
37077	48949	40.899163000000001	40.971415	51.624267000000003	51.570954999999998	Ленинская	0103000020E61000000100000005000000FA62EFC5177344406C3EAE0D15C94940FA62EFC5177344406C7C26FBE7CF494003ECA353577C44406C7C26FBE7CF494003ECA353577C44406C3EAE0D15C94940FA62EFC5177344406C3EAE0D15C94940
36189	48949	40.899163000000001	40.971415	51.624267000000003	51.570954999999998	 Ленинская	0103000020E61000000100000005000000FA62EFC5177344406C3EAE0D15C94940FA62EFC5177344406C7C26FBE7CF494003ECA353577C44406C7C26FBE7CF494003ECA353577C44406C3EAE0D15C94940FA62EFC5177344406C3EAE0D15C94940
37230	54433	40.813696999999998	40.830136000000003	51.749054999999998	51.717272999999999	Центральная	0103000020E6100000010000000500000039ED293927684440E3A6069ACFDB494039ED293927684440E0F3C308E1DF4940BB9D7DE5416A4440E0F3C308E1DF4940BB9D7DE5416A4440E3A6069ACFDB494039ED293927684440E3A6069ACFDB4940
36884	49453	40.814720999999999	40.828043000000001	51.824367000000002	51.808020999999997	Докучаева	0103000020E61000000100000005000000A52E19C74868444098BD6C3B6DE74940A52E19C74868444069739CDB84E9494043572250FD69444069739CDB84E9494043572250FD69444098BD6C3B6DE74940A52E19C74868444098BD6C3B6DE74940
37413	46394	40.702306	40.724926000000004	51.918492999999998	51.904265000000002	Советская	0103000020E610000001000000050000006DE4BA29E55944406FF59CF4BEF349406DE4BA29E55944406E4DBA2D91F5494093020B60CA5C44406E4DBA2D91F5494093020B60CA5C44406FF59CF4BEF349406DE4BA29E55944406FF59CF4BEF34940
36546	46183	40.777594000000001	40.797033999999996	51.830044999999998	51.817107999999998	Гагарина	0103000020E610000001000000050000006DC83F338863444065A6B4FE96E849406DC83F3388634440AA9A20EA3EEA494068E6C93505664440AA9A20EA3EEA494068E6C9350566444065A6B4FE96E849406DC83F338863444065A6B4FE96E84940
37022	13384	41.010725000000001	41.061363	51.670501000000002	51.636755999999998	Ленина	0103000020E61000000100000005000000F31FD26F5F81444011C4793881D14940F31FD26F5F814440B8770DFAD2D549409C1727BEDA874440B8770DFAD2D549409C1727BEDA87444011C4793881D14940F31FD26F5F81444011C4793881D14940
37274	15226	40.427942999999999	40.455385999999997	51.887247000000002	51.868544	Советская	0103000020E61000000100000005000000ACC612D6C63644408A9125732CEF4940ACC612D6C6364440B03C484F91F149403387A4164A3A4440B03C484F91F149403387A4164A3A44408A9125732CEF4940ACC612D6C63644408A9125732CEF4940
67127	49052	40.800744000000002	40.824404999999999	51.756447999999999	51.713875000000002	Фрунзе	0103000020E61000000100000005000000EF3B86C77E6644404C37894160DB4940EF3B86C77E664440F38FBE49D3E0494056D4601A86694440F38FBE49D3E0494056D4601A866944404C37894160DB4940EF3B86C77E6644404C37894160DB4940
37023	13671	40.864694999999998	40.881843000000003	51.702350000000003	51.684384000000001	Школьная	0103000020E61000000100000005000000E2016553AE6E4440EDF318E599D74940E2016553AE6E44403D2CD49AE6D94940709A3E3BE07044403D2CD49AE6D94940709A3E3BE0704440EDF318E599D74940E2016553AE6E4440EDF318E599D74940
37130	49262	40.410992	40.432758	51.867103999999998	51.857008999999998	Рабочая	0103000020E610000001000000050000007575C7629B34444057B08D78B2ED49407575C7629B3444408A1D8D43FDEE49408B8A389D643744408A1D8D43FDEE49408B8A389D6437444057B08D78B2ED49407575C7629B34444057B08D78B2ED4940
37117	14325	40.503616999999998	40.539665999999997	51.938692000000003	51.920904	Советская	0103000020E61000000100000005000000D55A988576404440B760A92EE0F54940D55A9885764044402882380F27F84940AE6186C6134544402882380F27F84940AE6186C613454440B760A92EE0F54940D55A988576404440B760A92EE0F54940
37336	47185	40.797977000000003	40.824323999999997	51.793166999999997	51.783439999999999	Центральная	0103000020E61000000100000005000000E8FA3E1C246644406A300DC347E44940E8FA3E1C246644401AA20A7F86E5494069A7E672836944401AA20A7F86E5494069A7E672836944406A300DC347E44940E8FA3E1C246644406A300DC347E44940
37187	54406	40.732686999999999	40.751758000000002	51.784681999999997	51.771186	 Молодежная-1	0103000020E61000000100000005000000289A07B0C85D444008910C39B6E24940289A07B0C85D444043E1B37570E44940D1402C9B3960444043E1B37570E44940D1402C9B3960444008910C39B6E24940289A07B0C85D444008910C39B6E24940
37180	48998	40.824036999999997	40.858344000000002	51.729402	51.704655000000002	Восточная	0103000020E61000000100000005000000D3D85E0B7A69444040FB912232DA4940D3D85E0B7A69444089D1730B5DDD4940E25B5837DE6D444089D1730B5DDD4940E25B5837DE6D444040FB912232DA4940D3D85E0B7A69444040FB912232DA4940
37079	13491	40.942695000000001	40.966878000000001	51.699548	51.674219999999998	Молодежная	0103000020E61000000100000005000000268DD13AAA784440912749D74CD64940268DD13AAA784440B9FDF2C98AD94940679C86A8C27B4440B9FDF2C98AD94940679C86A8C27B4440912749D74CD64940268DD13AAA784440912749D74CD64940
36375	14041	40.525463999999999	40.564253000000001	51.724615	51.680039999999998	Центральная	0103000020E61000000100000005000000D89C83674243444065FCFB8C0BD74940D89C83674243444074982F2FC0DC4940BFD53A713948444074982F2FC0DC4940BFD53A713948444065FCFB8C0BD74940D89C83674243444065FCFB8C0BD74940
36581	49243	40.456249	40.490240999999997	51.92342	51.887636000000001	Школьная	0103000020E6100000010000000500000096EA025E663A44404A60730E9EF1494096EA025E663A4440753C66A032F6494044149337C03E4440753C66A032F6494044149337C03E44404A60730E9EF1494096EA025E663A44404A60730E9EF14940
36787	14615	40.830207999999999	40.862026999999998	51.894162000000001	51.863337999999999	Центральная	0103000020E6100000010000000500000054707841446A444070B20DDC81EE494054707841446A4440B9A981E673F249406EA296E6566E4440B9A981E673F249406EA296E6566E444070B20DDC81EE494054707841446A444070B20DDC81EE4940
36784	14253	40.470486999999999	40.503292999999999	51.881360000000001	51.847023	Центральная	0103000020E61000000100000005000000B91803EB383C4440DBFAE93F6BEC4940B91803EB383C444054008C67D0F0494022A7AFE76B40444054008C67D0F0494022A7AFE76B404440DBFAE93F6BEC4940B91803EB383C4440DBFAE93F6BEC4940
37357	47160	41.003079999999997	41.042354000000003	51.702795999999999	51.669533999999999	Центральная	0103000020E61000000100000005000000C6A2E9EC64804440B0C7444AB3D54940C6A2E9EC648044403BE12538F5D949406A6D1ADB6B8544403BE12538F5D949406A6D1ADB6B854440B0C7444AB3D54940C6A2E9EC64804440B0C7444AB3D54940
37282	47160	41.003079999999997	41.042354000000003	51.702795999999999	51.669533999999999	Ленина	0103000020E61000000100000005000000C6A2E9EC64804440B0C7444AB3D54940C6A2E9EC648044403BE12538F5D949406A6D1ADB6B8544403BE12538F5D949406A6D1ADB6B854440B0C7444AB3D54940C6A2E9EC64804440B0C7444AB3D54940
36542	13032	38.983666999999997	39.033999999999999	51.311909999999997	51.289762000000003	пер. Школьный	0103000020E61000000100000005000000C493DDCCE87D4340D1CFD4EB16A54940C493DDCCE87D4340CEA5B8AAECA749403108AC1C5A844340CEA5B8AAECA749403108AC1C5A844340D1CFD4EB16A54940C493DDCCE87D4340D1CFD4EB16A54940
36412	11827	38.761676000000001	38.808343000000001	51.598461	51.553682000000002	мира	0103000020E61000000100000005000000F51263997E6143402331410DDFC64940F51263997E6143403A77BB5E9ACC4940AB798EC8776743403A77BB5E9ACC4940AB798EC8776743402331410DDFC64940F51263997E6143402331410DDFC64940
35957	11827	38.761676000000001	38.808343000000001	51.598461	51.553682000000002	Ленина	0103000020E61000000100000005000000F51263997E6143402331410DDFC64940F51263997E6143403A77BB5E9ACC4940AB798EC8776743403A77BB5E9ACC4940AB798EC8776743402331410DDFC64940F51263997E6143402331410DDFC64940
35821	11827	38.761676000000001	38.808343000000001	51.598461	51.553682000000002	Заводская	0103000020E61000000100000005000000F51263997E6143402331410DDFC64940F51263997E6143403A77BB5E9ACC4940AB798EC8776743403A77BB5E9ACC4940AB798EC8776743402331410DDFC64940F51263997E6143402331410DDFC64940
35765	11827	38.761676000000001	38.808343000000001	51.598461	51.553682000000002	Дружбы	0103000020E61000000100000005000000F51263997E6143402331410DDFC64940F51263997E6143403A77BB5E9ACC4940AB798EC8776743403A77BB5E9ACC4940AB798EC8776743402331410DDFC64940F51263997E6143402331410DDFC64940
35820	12028	38.676946999999998	38.898471000000001	51.628236999999999	51.529953999999996	пер.Советский	0103000020E610000001000000050000000A100533A656434033315D88D5C349400A100533A65643408E91EC116AD04940C4B30419017343408E91EC116AD04940C4B304190173434033315D88D5C349400A100533A656434033315D88D5C34940
36544	12028	38.676946999999998	38.898471000000001	51.628236999999999	51.529953999999996	Сосновый переулок	0103000020E610000001000000050000000A100533A656434033315D88D5C349400A100533A65643408E91EC116AD04940C4B30419017343408E91EC116AD04940C4B304190173434033315D88D5C349400A100533A656434033315D88D5C34940
36918	12028	38.676946999999998	38.898471000000001	51.628236999999999	51.529953999999996	Красноармейская	0103000020E610000001000000050000000A100533A656434033315D88D5C349400A100533A65643408E91EC116AD04940C4B30419017343408E91EC116AD04940C4B304190173434033315D88D5C349400A100533A656434033315D88D5C34940
35720	12028	38.676946999999998	38.898471000000001	51.628236999999999	51.529953999999996	Верхняя Слобода	0103000020E610000001000000050000000A100533A656434033315D88D5C349400A100533A65643408E91EC116AD04940C4B30419017343408E91EC116AD04940C4B304190173434033315D88D5C349400A100533A656434033315D88D5C34940
36416	48564	38.680081999999999	38.817129000000001	51.478186000000001	51.430627000000001	Веры Чуркиной	0103000020E61000000100000005000000944C4EED0C57434026E318C91EB74940944C4EED0C574340D9B3E73235BD49407DCEDDAE97684340D9B3E73235BD49407DCEDDAE9768434026E318C91EB74940944C4EED0C57434026E318C91EB74940
36783	12629	38.682246999999997	38.812987	51.364018999999999	51.278382000000001	Бабенко	0103000020E61000000100000005000000A565A4DE53574340C5E57805A2A34940A565A4DE53574340B20FB22C98AE49405D8940F50F684340B20FB22C98AE49405D8940F50F684340C5E57805A2A34940A565A4DE53574340C5E57805A2A34940
36460	12938	39.014856999999999	39.046486999999999	51.449035000000002	51.415934	Школьная	0103000020E61000000100000005000000EF8E8CD5E6814340B1A547533DB54940EF8E8CD5E681434033E197FA79B9494036583849F385434033E197FA79B9494036583849F3854340B1A547533DB54940EF8E8CD5E6814340B1A547533DB54940
37192	54408	38.607120999999999	39.17597	51.677475999999999	51.230365999999997	Советская	0103000020E610000001000000050000007FDB1324B64D43401F0E12A27C9D49407FDB1324B64D434096E99788B7D64940DF89592F8696434096E99788B7D64940DF89592F869643401F0E12A27C9D49407FDB1324B64D43401F0E12A27C9D4940
36543	48828	39.008003000000002	39.054994000000001	51.262011999999999	51.230365999999997	Советская	0103000020E610000001000000050000008CA2073E068143401F0E12A27C9D49408CA2073E068143406C94F59B89A14940F5BC1B0B0A8743406C94F59B89A14940F5BC1B0B0A8743401F0E12A27C9D49408CA2073E068143401F0E12A27C9D4940
36545	54318	38.970416999999998	38.987521000000001	51.609603999999997	51.597800999999997	Чаянова	0103000020E61000000100000005000000C03DCF9F367C43400F4240BE84CC4940C03DCF9F367C434061C1FD8007CE49407E8E8F16677E434061C1FD8007CE49407E8E8F16677E43400F4240BE84CC4940C03DCF9F367C43400F4240BE84CC4940
37128	12356	38.812466000000001	38.896495000000002	51.477052999999998	51.461753000000002	Центральная	0103000020E61000000100000005000000548EC9E2FE6743403AEAE8B81ABB4940548EC9E2FE674340B6BA9C1210BD494086032159C0724340B6BA9C1210BD494086032159C07243403AEAE8B81ABB4940548EC9E2FE6743403AEAE8B81ABB4940
36920	48610	38.773318000000003	38.827207999999999	51.365847000000002	51.341323000000003	Центральная	0103000020E610000001000000050000003EB48F15FC624340B22FD978B0AB49403EB48F15FC6243407C2B1213D4AE4940AA7EA5F3E16943407C2B1213D4AE4940AA7EA5F3E1694340B22FD978B0AB49403EB48F15FC624340B22FD978B0AB4940
36046	12995	39.006233000000002	39.082751999999999	51.417501999999999	51.349074999999999	Набережная	0103000020E61000000100000005000000F793313ECC804340F46C567DAEAC4940F793313ECC804340DE019EB470B54940DCD6169E978A4340DE019EB470B54940DCD6169E978A4340F46C567DAEAC4940F793313ECC804340F46C567DAEAC4940
37127	12309	38.891258000000001	38.922258999999997	51.574207999999999	51.540531000000001	Центральная	0103000020E610000001000000050000003126FDBD14724340B2BCAB1E30C549403126FDBD14724340008DD2A57FC9494088B839950C764340008DD2A57FC9494088B839950C764340B2BCAB1E30C549403126FDBD14724340B2BCAB1E30C54940
37133	48758	38.919176999999998	38.943269999999998	51.513309999999997	51.491943999999997	Советская	0103000020E61000000100000005000000211E8997A775434051BB5F05F8BE4940211E8997A7754340D95A5F24B4C1494022A64412BD784340D95A5F24B4C1494022A64412BD78434051BB5F05F8BE4940211E8997A775434051BB5F05F8BE4940
36220	48729	38.982939999999999	39.035707000000002	51.513091000000003	51.441547	Чехова	0103000020E6100000010000000500000012F758FAD07D4340CE52B29C84B8494012F758FAD07D43409C6F44F7ACC14940809E060C928443409C6F44F7ACC14940809E060C92844340CE52B29C84B8494012F758FAD07D4340CE52B29C84B84940
37075	48729	38.982939999999999	39.035707000000002	51.513091000000003	51.441547	Ленина	0103000020E6100000010000000500000012F758FAD07D4340CE52B29C84B8494012F758FAD07D43409C6F44F7ACC14940809E060C928443409C6F44F7ACC14940809E060C92844340CE52B29C84B8494012F758FAD07D4340CE52B29C84B84940
37015	45990	38.607120999999999	38.646780999999997	51.520606999999998	51.480418	Свердлова	0103000020E610000001000000050000007FDB1324B64D4340723447567EBD49407FDB1324B64D4340CA880B40A3C249404B5645B8C9524340CA880B40A3C249404B5645B8C9524340723447567EBD49407FDB1324B64D4340723447567EBD4940
37373	45878	39.068916999999999	39.167929999999998	51.365645000000001	51.317303000000003	Архипова	0103000020E61000000100000005000000B891B245D28843401BF67B629DA84940B891B245D288434014799274CDAE49403602F1BA7E95434014799274CDAE49403602F1BA7E9543401BF67B629DA84940B891B245D28843401BF67B629DA84940
37344	45878	39.068916999999999	39.167929999999998	51.365645000000001	51.317303000000003	 Гагарина	0103000020E61000000100000005000000B891B245D28843401BF67B629DA84940B891B245D288434014799274CDAE49403602F1BA7E95434014799274CDAE49403602F1BA7E9543401BF67B629DA84940B891B245D28843401BF67B629DA84940
36849	8349	38.807211000000002	38.882911999999997	51.596916999999998	51.579323000000002	переулок Школьный	0103000020E6100000010000000500000059FCA6B0526743400A698D4127CA494059FCA6B05267434095B6B8C667CC49407B9FAA420371434095B6B8C667CC49407B9FAA42037143400A698D4127CA494059FCA6B0526743400A698D4127CA4940
37312	48858	39.110616999999998	39.168126999999998	51.288437999999999	51.235863999999999	Центральная	0103000020E61000000100000005000000D9B0A6B2288E4340E126A3CA309E4940D9B0A6B2288E43403A765089EBA449408C497F2F859543403A765089EBA449408C497F2F85954340E126A3CA309E4940D9B0A6B2288E4340E126A3CA309E4940
36208	45846	41.567338999999997	41.655464000000002	51.702556000000001	51.647683000000001	Советская	0103000020E61000000100000005000000675F79909EC844406C96CB46E7D24940675F79909EC84440E6CDE15AEDD9494049DA8D3EE6D34440E6CDE15AEDD9494049DA8D3EE6D344406C96CB46E7D24940675F79909EC844406C96CB46E7D24940
36055	45846	41.567338999999997	41.655464000000002	51.702556000000001	51.647683000000001	Первомайская	0103000020E61000000100000005000000675F79909EC844406C96CB46E7D24940675F79909EC84440E6CDE15AEDD9494049DA8D3EE6D34440E6CDE15AEDD9494049DA8D3EE6D344406C96CB46E7D24940675F79909EC844406C96CB46E7D24940
36085	45846	41.567338999999997	41.655464000000002	51.702556000000001	51.647683000000001	Октябрьская	0103000020E61000000100000005000000675F79909EC844406C96CB46E7D24940675F79909EC84440E6CDE15AEDD9494049DA8D3EE6D34440E6CDE15AEDD9494049DA8D3EE6D344406C96CB46E7D24940675F79909EC844406C96CB46E7D24940
37064	45846	41.567338999999997	41.655464000000002	51.702556000000001	51.647683000000001	Звездная	0103000020E61000000100000005000000675F79909EC844406C96CB46E7D24940675F79909EC84440E6CDE15AEDD9494049DA8D3EE6D34440E6CDE15AEDD9494049DA8D3EE6D344406C96CB46E7D24940675F79909EC844406C96CB46E7D24940
37283	48217	41.087997999999999	41.110537000000001	51.696393999999998	51.681083999999998	Школьная	0103000020E61000000100000005000000840EBA84438B444018EAB0C22DD74940840EBA84438B4440B890477023D94940BDFF8F13268E4440B890477023D94940BDFF8F13268E444018EAB0C22DD74940840EBA84438B444018EAB0C22DD74940
36430	45490	41.437199999999997	41.514743000000003	51.735655000000001	51.688578	Советская	0103000020E61000000100000005000000D5E76A2BF6B744405F5FEB5223D84940D5E76A2BF6B74440C7116BF129DE4940276C3F19E3C14440C7116BF129DE4940276C3F19E3C144405F5FEB5223D84940D5E76A2BF6B744405F5FEB5223D84940
37242	45490	41.437199999999997	41.514743000000003	51.735655000000001	51.688578	 Проезжая	0103000020E61000000100000005000000D5E76A2BF6B744405F5FEB5223D84940D5E76A2BF6B74440C7116BF129DE4940276C3F19E3C14440C7116BF129DE4940276C3F19E3C144405F5FEB5223D84940D5E76A2BF6B744405F5FEB5223D84940
37085	47846	41.614868999999999	41.646552	51.526955999999998	51.513826000000002	Проезжая	0103000020E6100000010000000500000080290307B4CE4440D1EAE40CC5C1494080290307B4CE44402A37514B73C34940EA944737C2D244402A37514B73C34940EA944737C2D24440D1EAE40CC5C1494080290307B4CE4440D1EAE40CC5C14940
37170	54394	41.440649000000001	41.476545999999999	51.761342999999997	51.736730999999999	Школьная	0103000020E61000000100000005000000EF01BA2F67B8444085798F334DDE4940EF01BA2F67B84440EE04FBAF73E1494012859675FFBC4440EE04FBAF73E1494012859675FFBC444085798F334DDE4940EF01BA2F67B8444085798F334DDE4940
37176	46835	41.416826	41.446227999999998	51.677247999999999	51.642921000000001	Паринского	0103000020E61000000100000005000000AE0FEB8D5AB54440B0743E3C4BD24940AE0FEB8D5AB5444005A4FD0FB0D649409D47C5FF1DB9444005A4FD0FB0D649409D47C5FF1DB94440B0743E3C4BD24940AE0FEB8D5AB54440B0743E3C4BD24940
36788	11179	41.614967999999998	41.646687	51.570613999999999	51.545869000000003	Центральная	0103000020E61000000100000005000000130B7C45B7CE44403B730F09DFC54940130B7C45B7CE4440E3512AE109C94940CADFBDA3C6D24440E3512AE109C94940CADFBDA3C6D244403B730F09DFC54940130B7C45B7CE44403B730F09DFC54940
37131	49564	41.216411999999998	41.251455	51.736105999999999	51.718125999999998	Октябрьская	0103000020E61000000100000005000000213B6F63B39B44402234828DEBDB4940213B6F63B39B4440D731AEB838DE494035B56CAD2FA04440D731AEB838DE494035B56CAD2FA044402234828DEBDB4940213B6F63B39B44402234828DEBDB4940
37178	10479	41.776654999999998	41.790804000000001	51.696655999999997	51.682994000000001	Центральная	0103000020E610000001000000050000002FA3586E69E344409FAEEE586CD749402FA3586E69E34440F54718062CD94940E3C5C21039E54440F54718062CD94940E3C5C21039E544409FAEEE586CD749402FA3586E69E344409FAEEE586CD74940
36499	11031	41.751251000000003	41.838118000000001	51.602387999999998	51.559618	Центральная	0103000020E610000001000000050000002D0B26FE28E0444060200890A1C749402D0B26FE28E044405DC0CB0C1BCD49402F185C7347EB44405DC0CB0C1BCD49402F185C7347EB444060200890A1C749402D0B26FE28E0444060200890A1C74940
36498	48039	41.824382999999997	41.846480999999997	51.584567	51.562266000000001	Набережная	0103000020E610000001000000050000006E30D46185E944408DD31055F8C749406E30D46185E9444011A96917D3CA4940BAD7497D59EC444011A96917D3CA4940BAD7497D59EC44408DD31055F8C749406E30D46185E944408DD31055F8C74940
36043	10949	41.433939000000002	41.476025	51.560273000000002	51.516779	Лениская	0103000020E61000000100000005000000BFBA2A508BB744403A2174D025C24940BFBA2A508BB7444079EA9106B7C74940098A1F63EEBC444079EA9106B7C74940098A1F63EEBC44403A2174D025C24940BFBA2A508BB744403A2174D025C24940
36191	47946	41.254393	41.334108999999998	51.684294999999999	51.640635000000003	Советская	0103000020E6100000010000000500000069AA27F38FA0444024D6E25300D2494069AA27F38FA044407DE882FA96D749404E266E15C4AA44407DE882FA96D749404E266E15C4AA444024D6E25300D2494069AA27F38FA0444024D6E25300D24940
36781	47946	41.254393	41.334108999999998	51.684294999999999	51.640635000000003	Горького	0103000020E6100000010000000500000069AA27F38FA0444024D6E25300D2494069AA27F38FA044407DE882FA96D749404E266E15C4AA44407DE882FA96D749404E266E15C4AA444024D6E25300D2494069AA27F38FA0444024D6E25300D24940
36818	47407	41.131799999999998	41.160142	51.598399000000001	51.569997999999998	Советская	0103000020E6100000010000000500000070CE88D2DE9044408864C8B1F5C8494070CE88D2DE904440C47AA35698CC4940A75B76887F944440C47AA35698CC4940A75B76887F9444408864C8B1F5C8494070CE88D2DE9044408864C8B1F5C84940
35883	47739	41.503478000000001	41.540236999999998	51.782559999999997	51.738169999999997	Молодежная	0103000020E61000000100000005000000B42094F771C04440B471C45A7CDE4940B42094F771C04440319413ED2AE44940698B6B7C26C54440319413ED2AE44940698B6B7C26C54440B471C45A7CDE4940B42094F771C04440B471C45A7CDE4940
37387	47403	41.129598999999999	41.166258999999997	51.627006999999999	51.608272999999997	Солнечная	0103000020E61000000100000005000000124C35B3969044401805C1E3DBCD4940124C35B39690444079AEEFC341D0494034D593F94795444079AEEFC341D0494034D593F9479544401805C1E3DBCD4940124C35B3969044401805C1E3DBCD4940
36599	47403	41.129598999999999	41.166258999999997	51.627006999999999	51.608272999999997	Лесная	0103000020E61000000100000005000000124C35B3969044401805C1E3DBCD4940124C35B39690444079AEEFC341D0494034D593F94795444079AEEFC341D0494034D593F9479544401805C1E3DBCD4940124C35B3969044401805C1E3DBCD4940
37166	16029	41.546723	41.584569000000002	51.637332000000001	51.618955	Садовая	0103000020E610000001000000050000004A7CEE04FBC544400C59DDEA39CF49404A7CEE04FBC54440DE58501894D14940B2A03028D3CA4440DE58501894D14940B2A03028D3CA44400C59DDEA39CF49404A7CEE04FBC544400C59DDEA39CF4940
36616	10570	41.461877000000001	41.524462	51.615627000000003	51.567104	Ленинская	0103000020E6100000010000000500000026E318C91EBB444024B726DD96C8494026E318C91EBB44406EC493DDCCCE494054FF209221C344406EC493DDCCCE494054FF209221C3444024B726DD96C8494026E318C91EBB444024B726DD96C84940
37021	45871	41.611939999999997	41.634452000000003	51.619889000000001	51.607270999999997	Комарова	0103000020E610000001000000050000009F8EC70C54CE444094675E0EBBCD49409F8EC70C54CE44403813D38558CF4940DF701FB935D144403813D38558CF4940DF701FB935D1444094675E0EBBCD49409F8EC70C54CE444094675E0EBBCD4940
37124	10441	41.740983	41.798206	51.643312999999999	51.601219	Фруктовая	0103000020E610000001000000050000002CF2EB87D8DE4440EE5D83BEF4CC49402CF2EB87D8DE4440BB0B941458D2494049BC3C9D2BE64440BB0B941458D2494049BC3C9D2BE64440EE5D83BEF4CC49402CF2EB87D8DE4440EE5D83BEF4CC4940
36615	10441	41.740983	41.798206	51.643312999999999	51.601219	Советская	0103000020E610000001000000050000002CF2EB87D8DE4440EE5D83BEF4CC49402CF2EB87D8DE4440BB0B941458D2494049BC3C9D2BE64440BB0B941458D2494049BC3C9D2BE64440EE5D83BEF4CC49402CF2EB87D8DE4440EE5D83BEF4CC4940
36822	54367	41.884067000000002	41.939529	51.642747999999997	51.614888999999998	Свободы	0103000020E61000000100000005000000863C821B29F14440C7D5C8AEB4CE4940863C821B29F14440E2C8039145D2494061527C7C42F84440E2C8039145D2494061527C7C42F84440C7D5C8AEB4CE4940863C821B29F14440C7D5C8AEB4CE4940
74952	60397	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	Центральная 	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
36698	54338	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	Проезжая	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
74931	60382	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	4 квартал	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
37255	54451	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	Мира	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
9962	9542	40.861919	40.892983000000001	51.070932999999997	51.045575999999997	Свободы	0103000020E6100000010000000500000088669E5C536E4440C2BD326FD585494088669E5C536E4440849A215514894940267156444D724440849A215514894940267156444D724440C2BD326FD585494088669E5C536E4440C2BD326FD5854940
36612	40379	40.768628999999997	40.791733000000001	50.985795000000003	50.955438999999998	Центральная	0103000020E61000000100000005000000EBE0606F6262444056293DD34B7A4940EBE0606F62624440B9C7D2872E7E4940FD14C78157654440B9C7D2872E7E4940FD14C7815765444056293DD34B7A4940EBE0606F6262444056293DD34B7A4940
36153	46932	40.698963999999997	40.768773000000003	51.132694999999998	51.101478999999998	проезд Свободы	0103000020E61000000100000005000000698A00A7775944408A1D8D43FD8C4940698A00A777594440DEAB5626FC9049401F86562767624440DEAB5626FC9049401F865627676244408A1D8D43FD8C4940698A00A7775944408A1D8D43FD8C4940
35838	46932	40.698963999999997	40.768773000000003	51.132694999999998	51.101478999999998	Советская	0103000020E61000000100000005000000698A00A7775944408A1D8D43FD8C4940698A00A777594440DEAB5626FC9049401F86562767624440DEAB5626FC9049401F865627676244408A1D8D43FD8C4940698A00A7775944408A1D8D43FD8C4940
36183	46932	40.698963999999997	40.768773000000003	51.132694999999998	51.101478999999998	Садовая	0103000020E61000000100000005000000698A00A7775944408A1D8D43FD8C4940698A00A777594440DEAB5626FC9049401F86562767624440DEAB5626FC9049401F865627676244408A1D8D43FD8C4940698A00A7775944408A1D8D43FD8C4940
35958	46932	40.698963999999997	40.768773000000003	51.132694999999998	51.101478999999998	Пролетарская	0103000020E61000000100000005000000698A00A7775944408A1D8D43FD8C4940698A00A777594440DEAB5626FC9049401F86562767624440DEAB5626FC9049401F865627676244408A1D8D43FD8C4940698A00A7775944408A1D8D43FD8C4940
36614	10050	40.958578000000003	41.016230999999998	51.274788000000001	51.243747999999997	Советская	0103000020E61000000100000005000000225514AFB27A4440923B6C22339F4940225514AFB27A4440A8AAD0402CA3494037177FDB13824440A8AAD0402CA3494037177FDB13824440923B6C22339F4940225514AFB27A4440923B6C22339F4940
37034	46021	40.509106000000003	40.567002000000002	51.055416999999998	50.988765999999998	Центральная	0103000020E610000001000000050000004419AA622A414440C8B260E28F7E49404419AA622A4144403B527DE71787494020628385934844403B527DE7178749402062838593484440C8B260E28F7E49404419AA622A414440C8B260E28F7E4940
37165	46021	40.509106000000003	40.567002000000002	51.055416999999998	50.988765999999998	Заречная	0103000020E610000001000000050000004419AA622A414440C8B260E28F7E49404419AA622A4144403B527DE71787494020628385934844403B527DE7178749402062838593484440C8B260E28F7E49404419AA622A414440C8B260E28F7E4940
36639	9326	40.702953000000001	40.734456999999999	51.191020999999999	51.169673000000003	Центральная	0103000020E6100000010000000500000003D0285DFA594440D20149D8B795494003D0285DFA594440B3EC496073984940BDA8DDAF025E4440B3EC496073984940BDA8DDAF025E4440D20149D8B795494003D0285DFA594440D20149D8B7954940
37417	54490	40.744267000000001	40.759655000000002	51.151789000000001	51.142415	Солнечная	0103000020E61000000100000005000000FB3E1C24445F4440DCBA9BA73A924940FB3E1C24445F44403F726BD26D934940179F02603C6144403F726BD26D934940179F02603C614440DCBA9BA73A924940FB3E1C24445F4440DCBA9BA73A924940
36176	9021	40.425319999999999	40.530351000000003	51.250991999999997	51.191144999999999	ленинская	0103000020E61000000100000005000000D82AC1E2703644409FE5797077984940D82AC1E27036444060C77F8120A049405133A48AE243444060C77F8120A049405133A48AE24344409FE5797077984940D82AC1E2703644409FE5797077984940
36588	9021	40.425319999999999	40.530351000000003	51.250991999999997	51.191144999999999	Садовая	0103000020E61000000100000005000000D82AC1E2703644409FE5797077984940D82AC1E27036444060C77F8120A049405133A48AE243444060C77F8120A049405133A48AE24344409FE5797077984940D82AC1E2703644409FE5797077984940
36682	47182	40.427224000000002	40.465214000000003	51.120117	51.100535000000001	просп.Революции	0103000020E610000001000000050000007D08AA46AF3644403B8DB454DE8C49407D08AA46AF364440C9586DFE5F8F494018D2E1218C3B4440C9586DFE5F8F494018D2E1218C3B44403B8DB454DE8C49407D08AA46AF3644403B8DB454DE8C4940
36459	47448	40.814388999999998	40.852702000000001	51.130721999999999	51.120168	Центральная	0103000020E610000001000000050000006F9C14E63D6844404B033FAA618F49406F9C14E63D684440116F9D7FBB904940ED9DD156256D4440116F9D7FBB904940ED9DD156256D44404B033FAA618F49406F9C14E63D6844404B033FAA618F4940
37125	47391	40.690286999999998	40.724611000000003	51.007019	50.989209000000002	Центральная	0103000020E610000001000000050000004EED0C535B58444056F487669E7E49404EED0C535B584440AEB9A3FFE580494033A9A10DC05C4440AEB9A3FFE580494033A9A10DC05C444056F487669E7E49404EED0C535B58444056F487669E7E4940
37057	46251	40.556877999999998	40.560848	51.115752000000001	51.110945999999998	пер.Цветочный	0103000020E6100000010000000500000052EE3EC7474744409ECF807A338E494052EE3EC7474744402A3927F6D08E4940750305DEC94744402A3927F6D08E4940750305DEC94744409ECF807A338E494052EE3EC7474744409ECF807A338E4940
36960	47059	40.62621	40.653896000000003	51.121813000000003	51.117007999999998	Молодежная	0103000020E61000000100000005000000CE3637A62750444068AF3E1EFA8E4940CE3637A627504440249D8191978F49401C7E37DDB2534440249D8191978F49401C7E37DDB253444068AF3E1EFA8E4940CE3637A62750444068AF3E1EFA8E4940
37263	47695	40.953043999999998	40.997546	51.136260999999998	51.125013000000003	Набережная	0103000020E6100000010000000500000013D38558FD79444095490D6D0090494013D38558FD794440315C1D0071914940B8205B96AF7F4440315C1D0071914940B8205B96AF7F444095490D6D0090494013D38558FD79444095490D6D00904940
36472	9780	40.788670000000003	40.800114999999998	51.258456000000002	51.240290999999999	Центральная	0103000020E610000001000000050000000DAB7823F3644440F64201DBC19E49400DAB7823F36444403DBA111615A14940FF04172B6A6644403DBA111615A14940FF04172B6A664440F64201DBC19E49400DAB7823F3644440F64201DBC19E4940
37029	54387	41.055712	41.071863999999998	51.309747999999999	51.287131000000002	Мира	0103000020E6100000010000000500000054FF2092218744407A5567B5C0A4494054FF2092218744402E008DD2A5A749403FE1ECD6328944402E008DD2A5A749403FE1ECD6328944407A5567B5C0A4494054FF2092218744407A5567B5C0A44940
36962	47656	41.015251999999997	41.040863000000002	51.324711000000001	51.309899999999999	Центральная	0103000020E610000001000000050000006B990CC7F3814440E4839ECDAAA749406B990CC7F381444063D34A2190A94940E84EB0FF3A85444063D34A2190A94940E84EB0FF3A854440E4839ECDAAA749406B990CC7F3814440E4839ECDAAA74940
36275	54302	40.706726000000003	40.736342999999998	51.080863999999998	51.061802999999998	Гагарина	0103000020E61000000100000005000000D09D60FF755A4440B8E52329E9874940D09D60FF755A44403DB665C0598A4940BBD1C77C405E44403DB665C0598A4940BBD1C77C405E4440B8E52329E9874940D09D60FF755A4440B8E52329E9874940
36401	8728	40.652863000000004	40.685093999999999	51.078454000000001	51.061016000000002	Дужнова	0103000020E610000001000000050000005DE2C8039153444031444E5FCF8749405DE2C80391534440C51EDAC70A8A4940C9570229B1574440C51EDAC70A8A4940C9570229B157444031444E5FCF8749405DE2C8039153444031444E5FCF874940
36466	9098	40.467460000000003	40.621952	51.341040999999997	51.307068000000001	Школьная	0103000020E610000001000000050000001618B2BAD53B4440F6D214014EA749401618B2BAD53B44402DCC423BA7AB494045D7851F9C4F44402DCC423BA7AB494045D7851F9C4F4440F6D214014EA749401618B2BAD53B4440F6D214014EA74940
36540	9098	40.467460000000003	40.621952	51.341040999999997	51.307068000000001	Чеснокова	0103000020E610000001000000050000001618B2BAD53B4440F6D214014EA749401618B2BAD53B44402DCC423BA7AB494045D7851F9C4F44402DCC423BA7AB494045D7851F9C4F4440F6D214014EA749401618B2BAD53B4440F6D214014EA74940
36683	9098	40.467460000000003	40.621952	51.341040999999997	51.307068000000001	Гагарина	0103000020E610000001000000050000001618B2BAD53B4440F6D214014EA749401618B2BAD53B44402DCC423BA7AB494045D7851F9C4F44402DCC423BA7AB494045D7851F9C4F4440F6D214014EA749401618B2BAD53B4440F6D214014EA74940
36850	9434	40.686667	40.759053000000002	51.046720000000001	51.032273000000004	Мичурина	0103000020E61000000100000005000000081F4AB4E45744409CC58B8521844940081F4AB4E4574440D908C4EBFA854940217711A628614440D908C4EBFA854940217711A6286144409CC58B8521844940081F4AB4E45744409CC58B8521844940
36780	47309	40.697707000000001	40.731527999999997	51.355713000000002	51.334986999999998	Колхозная	0103000020E610000001000000050000005B9885764E594440E6CAA0DAE0AA49405B9885764E5944408BE1EA0088AD4940DC0DA2B5A25D44408BE1EA0088AD4940DC0DA2B5A25D4440E6CAA0DAE0AA49405B9885764E594440E6CAA0DAE0AA4940
37223	46904	40.773111	40.789057	51.103560999999999	51.090952000000001	Комсомольская	0103000020E61000000100000005000000C4961E4DF5624440BEC0AC50A48B4940C4961E4DF56244400E12A27C418D494006D7DCD1FF6444400E12A27C418D494006D7DCD1FF644440BEC0AC50A48B4940C4961E4DF5624440BEC0AC50A48B4940
36917	10176	40.958514999999998	40.990628999999998	51.044471999999999	51.022506	Центральная	0103000020E61000000100000005000000DBDC989EB07A44405DFB027AE1824940DBDC989EB07A44403ACB2C42B18549400EBC5AEECC7E44403ACB2C42B18549400EBC5AEECC7E44405DFB027AE1824940DBDC989EB07A44405DFB027AE1824940
36539	47352	40.657929000000003	40.703735000000002	51.230122999999999	51.204087000000001	Пятницкого	0103000020E61000000100000005000000850B790437544440F644D7851F9A4940850B7904375444405987A3AB749D494079060DFD135A44405987A3AB749D494079060DFD135A4440F644D7851F9A4940850B790437544440F644D7851F9A4940
36173	47623	40.992829999999998	41.109171000000003	51.232661	51.173490000000001	Ломоносова	0103000020E610000001000000050000006C3EAE0D157F44406E179AEB349649406C3EAE0D157F4440FF06EDD5C79D4940F855B950F98D4440FF06EDD5C79D4940F855B950F98D44406E179AEB349649406C3EAE0D157F44406E179AEB34964940
37401	47623	40.992829999999998	41.109171000000003	51.232661	51.173490000000001	Ленина	0103000020E610000001000000050000006C3EAE0D157F44406E179AEB349649406C3EAE0D157F4440FF06EDD5C79D4940F855B950F98D4440FF06EDD5C79D4940F855B950F98D44406E179AEB349649406C3EAE0D157F44406E179AEB34964940
36068	47623	40.992829999999998	41.109171000000003	51.232661	51.173490000000001	 Ленина	0103000020E610000001000000050000006C3EAE0D157F44406E179AEB349649406C3EAE0D157F4440FF06EDD5C79D4940F855B950F98D4440FF06EDD5C79D4940F855B950F98D44406E179AEB349649406C3EAE0D157F44406E179AEB34964940
36684	48696	38.627412999999997	38.643386	51.797533999999999	51.789585000000002	Ленина	0103000020E61000000100000005000000E90AB6114F504340C2340C1F11E54940E90AB6114F5043405AB9179815E64940255AF2785A5243405AB9179815E64940255AF2785A524340C2340C1F11E54940E90AB6114F504340C2340C1F11E54940
36161	46387	38.873542999999998	38.927396999999999	51.631278000000002	51.592171999999998	Победы	0103000020E610000001000000050000002A53CC41D06F4340AFCDC64ACCCB49402A53CC41D06F43409757AEB7CDD049404AB4E4F1B47643409757AEB7CDD049404AB4E4F1B4764340AFCDC64ACCCB49402A53CC41D06F4340AFCDC64ACCCB4940
35938	46387	38.873542999999998	38.927396999999999	51.631278000000002	51.592171999999998	 Центральная	0103000020E610000001000000050000002A53CC41D06F4340AFCDC64ACCCB49402A53CC41D06F43409757AEB7CDD049404AB4E4F1B47643409757AEB7CDD049404AB4E4F1B4764340AFCDC64ACCCB49402A53CC41D06F4340AFCDC64ACCCB4940
37123	8079	38.523432999999997	38.627189000000001	51.874665999999998	51.807034999999999	Ольшанская	0103000020E61000000100000005000000D65240DAFF4243401ADD41EC4CE74940D65240DAFF4243402976340EF5EF49409AB4A9BA475043402976340EF5EF49409AB4A9BA475043401ADD41EC4CE74940D65240DAFF4243401ADD41EC4CE74940
36913	7990	38.451712000000001	38.630647000000003	51.843217000000003	51.782404	Победы	0103000020E61000000100000005000000FA9AE5B2D13943403A2174D025E44940FA9AE5B2D13943403337DF88EEEB49400729780AB95043403337DF88EEEB49400729780AB95043403A2174D025E44940FA9AE5B2D13943403A2174D025E44940
36681	7990	38.451712000000001	38.630647000000003	51.843217000000003	51.782404	Ленина	0103000020E61000000100000005000000FA9AE5B2D13943403A2174D025E44940FA9AE5B2D13943403337DF88EEEB49400729780AB95043403337DF88EEEB49400729780AB95043403A2174D025E44940FA9AE5B2D13943403A2174D025E44940
37019	46728	38.740322999999997	38.762044000000003	51.848008	51.792805000000001	Новая	0103000020E6100000010000000500000001BD70E7C25E43407A8D5DA27AE5494001BD70E7C25E4340895FB1868BEC4940780E65A88A614340895FB1868BEC4940780E65A88A6143407A8D5DA27AE5494001BD70E7C25E43407A8D5DA27AE54940
37016	46305	38.725149999999999	38.759196000000003	51.894945999999997	51.820113999999997	Школьная	0103000020E61000000100000005000000E25817B7D15C4340F17EDC7EF9E84940E25817B7D15C4340CFD72C978DF2494084A0A3552D614340CFD72C978DF2494084A0A3552D614340F17EDC7EF9E84940E25817B7D15C4340F17EDC7EF9E84940
37215	54425	38.982894999999999	39.028447999999997	51.808638999999999	51.788314999999997	Школьная	0103000020E610000001000000050000007233DC80CF7D43401EF98381E7E449407233DC80CF7D434094A2957B81E749407CD11E2FA483434094A2957B81E749407CD11E2FA48343401EF98381E7E449407233DC80CF7D43401EF98381E7E44940
36959	46634	38.824368999999997	38.926462999999998	51.874065999999999	51.816817999999998	Центральная	0103000020E61000000100000005000000096B63EC846943405E64027E8DE84940096B63EC84694340D4450A65E1EF49401EFAEE5696764340D4450A65E1EF49401EFAEE56967643405E64027E8DE84940096B63EC846943405E64027E8DE84940
36637	46634	38.824368999999997	38.926462999999998	51.874065999999999	51.816817999999998	Транспортная	0103000020E61000000100000005000000096B63EC846943405E64027E8DE84940096B63EC84694340D4450A65E1EF49401EFAEE5696764340D4450A65E1EF49401EFAEE56967643405E64027E8DE84940096B63EC846943405E64027E8DE84940
36854	7363	38.685623999999997	38.705728999999998	52.085476	52.064956000000002	Мира	0103000020E6100000010000000500000025ADF886C2574340E9D66B7A50084A4025ADF886C2574340E44BA8E0F00A4A405D6BEF53555A4340E44BA8E0F00A4A405D6BEF53555A4340E9D66B7A50084A4025ADF886C2574340E9D66B7A50084A40
36576	6828	38.984763000000001	38.998094000000002	51.654533999999998	51.643228999999998	переулок Школьный	0103000020E61000000100000005000000CAA7C7B60C7E43405D6BEF5355D24940CAA7C7B60C7E43405E0F26C5C7D34940BB2A508BC17F43405E0F26C5C7D34940BB2A508BC17F43405D6BEF5355D24940CAA7C7B60C7E43405D6BEF5355D24940
36575	7604	38.483297	38.541445000000003	51.954307999999997	51.901052999999997	Струковская	0103000020E61000000100000005000000A1A014ADDC3D4340397B67B455F34940A1A014ADDC3D4340D427B9C326FA494097CADB114E454340D427B9C326FA494097CADB114E454340397B67B455F34940A1A014ADDC3D4340397B67B455F34940
37126	47285	38.591839999999998	38.634456	51.829883000000002	51.816367	Станиславского	0103000020E61000000100000005000000793BC269C14B43404E44BFB67EE84940793BC269C14B4340D1402C9B39EA49402060ADDA35514340D1402C9B39EA49402060ADDA355143404E44BFB67EE84940793BC269C14B43404E44BFB67EE84940
36413	7534	38.639127999999999	38.681483	51.775348999999999	51.687651000000002	Ленина	0103000020E610000001000000050000009CFA40F2CE514340E607AEF204D849409CFA40F2CE5143403FFED2A23EE34940D6E3BED53A5743403FFED2A23EE34940D6E3BED53A574340E607AEF204D849409CFA40F2CE514340E607AEF204D84940
36778	46535	38.648496999999999	38.678742999999997	51.879426000000002	51.798169000000001	Центральная	0103000020E61000000100000005000000ED461FF3015343402CD7DB662AE64940ED461FF30153434045A0FA0791F04940C8B1F50CE156434045A0FA0791F04940C8B1F50CE15643402CD7DB662AE64940ED461FF3015343402CD7DB662AE64940
37238	46533	38.969248999999998	38.991033999999999	51.861474999999999	51.841698000000001	Центральная	0103000020E610000001000000050000002157EA59107C4340E78D93C2BCEB49402157EA59107C43402AA913D044EE4940AE9CBD33DA7E43402AA913D044EE4940AE9CBD33DA7E4340E78D93C2BCEB49402157EA59107C4340E78D93C2BCEB4940
37175	7296	38.633144999999999	38.660857999999998	52.017122000000001	52.000951000000001	Набережная	0103000020E610000001000000050000001E5036E50A51434002F390291F004A401E5036E50A5143406405BF0D31024A4065A6B4FE965443406405BF0D31024A4065A6B4FE9654434002F390291F004A401E5036E50A51434002F390291F004A40
37353	45426	38.820399000000002	38.85069	51.744148000000003	51.725909999999999	Школьная	0103000020E61000000100000005000000E7559DD50269434070EB6E9EEADC4940E7559DD50269434021B1DD3D40DF49406284F068E36C434021B1DD3D40DF49406284F068E36C434070EB6E9EEADC4940E7559DD50269434070EB6E9EEADC4940
37393	45426	38.820399000000002	38.85069	51.744148000000003	51.725909999999999	Кахиповка	0103000020E61000000100000005000000E7559DD50269434070EB6E9EEADC4940E7559DD50269434021B1DD3D40DF49406284F068E36C434021B1DD3D40DF49406284F068E36C434070EB6E9EEADC4940E7559DD50269434070EB6E9EEADC4940
36111	7051	38.876354999999997	38.969859999999997	51.714286999999999	51.682313000000001	Октябрьская	0103000020E61000000100000005000000D15790662C7043405D514A0856D74940D15790662C7043409E7AA4C16DDB49406AD95A5F247C43409E7AA4C16DDB49406AD95A5F247C43405D514A0856D74940D15790662C7043405D514A0856D74940
35716	8196	38.858811000000003	38.923623999999997	51.676918000000001	51.644396999999998	переулок заводской	0103000020E61000000100000005000000F838D384ED6D4340FC51D4997BD24940F838D384ED6D43407009C03FA5D649407DE6AC4F397643407009C03FA5D649407DE6AC4F39764340FC51D4997BD24940F838D384ED6D4340FC51D4997BD24940
35941	8196	38.858811000000003	38.923623999999997	51.676918000000001	51.644396999999998	Школьная	0103000020E61000000100000005000000F838D384ED6D4340FC51D4997BD24940F838D384ED6D43407009C03FA5D649407DE6AC4F397643407009C03FA5D649407DE6AC4F39764340FC51D4997BD24940F838D384ED6D4340FC51D4997BD24940
37244	54444	38.712285999999999	38.781232000000003	51.806038000000001	51.757033999999997	Садовая	0103000020E6100000010000000500000007B309302C5B4340E3FA777DE6E0494007B309302C5B4340A8AAD0402CE749405A4B0169FF634340A8AAD0402CE749405A4B0169FF634340E3FA777DE6E0494007B309302C5B4340E3FA777DE6E04940
36912	46345	38.602781999999998	38.622787000000002	51.9343	51.903143	Молодежная	0103000020E61000000100000005000000094FE8F5274D4340404E98309AF34940094FE8F5274D43408F53742497F74940DEAF027CB74F43408F53742497F74940DEAF027CB74F4340404E98309AF34940094FE8F5274D4340404E98309AF34940
37358	49091	38.573973000000002	38.623533000000002	52.053471999999999	52.03481	Центральная	0103000020E61000000100000005000000BDE47FF27749434071C971A774044A40BDE47FF27749434038A0A52BD8064A40077DE9EDCF4F434038A0A52BD8064A40077DE9EDCF4F434071C971A774044A40BDE47FF27749434071C971A774044A40
35882	6846	38.699745999999998	38.762915	51.920965000000002	51.885784999999998	Садовая	0103000020E61000000100000005000000DFC0E44691594340C824236761F14940DFC0E446915943405DE15D2EE2F549405D50DF32A76143405DE15D2EE2F549405D50DF32A7614340C824236761F14940DFC0E44691594340C824236761F14940
35837	7784	38.968567	39.030982000000002	51.741739000000003	51.686227000000002	Калинина	0103000020E610000001000000050000000F7EE200FA7B4340EC504D49D6D749400F7EE200FA7B43407995B54DF1DE4940E161DA37F78343407995B54DF1DE4940E161DA37F7834340EC504D49D6D749400F7EE200FA7B4340EC504D49D6D74940
37324	45956	38.719140000000003	38.727530999999999	52.015746999999998	52.006407000000003	Центральная	0103000020E610000001000000050000006B9F8EC70C5C434095BBCFF1D1004A406B9F8EC70C5C43404B0169FF03024A40C0E95DBC1F5D43404B0169FF03024A40C0E95DBC1F5D434095BBCFF1D1004A406B9F8EC70C5C434095BBCFF1D1004A40
35835	46198	38.901957000000003	38.988976000000001	51.669137999999997	51.593744000000001	Танкистов	0103000020E61000000100000005000000FBB2B453737343401E19ABCDFFCB4940FBB2B4537373434063416150A6D54940B343FCC3967E434063416150A6D54940B343FCC3967E43401E19ABCDFFCB4940FBB2B453737343401E19ABCDFFCB4940
36634	48844	39.022106000000001	39.056009000000003	51.778140999999998	51.756414999999997	Вислевского	0103000020E61000000100000005000000CF85915ED4824340179AEB34D2E04940CF85915ED48243409F56D11F9AE349400EA48B4D2B8743409F56D11F9AE349400EA48B4D2B874340179AEB34D2E04940CF85915ED4824340179AEB34D2E04940
36541	46407	38.750393000000003	38.806204999999999	51.760986000000003	51.733199999999997	Школьная	0103000020E61000000100000005000000DC12B9E00C604340AEB6627FD9DD4940DC12B9E00C604340605B3FFD67E14940936FB6B931674340605B3FFD67E14940936FB6B931674340AEB6627FD9DD4940DC12B9E00C604340AEB6627FD9DD4940
36908	6535	38.550714999999997	38.582165000000003	52.035713000000001	51.994900999999999	Молодежная	0103000020E61000000100000005000000543541D47D464340FCE07CEA58FF4940543541D47D46434062855B3E92044A401CF0F961844A434062855B3E92044A401CF0F961844A4340FCE07CEA58FF4940543541D47D464340FCE07CEA58FF4940
37163	49210	38.48283	38.634267999999999	51.757848000000003	51.723165000000002	Центральная	0103000020E610000001000000050000008BC3995FCD3D4340514EB4AB90DC49408BC3995FCD3D434065ABCB2901E149401D739EB12F51434065ABCB2901E149401D739EB12F514340514EB4AB90DC49408BC3995FCD3D4340514EB4AB90DC4940
37264	49210	38.48283	38.634267999999999	51.757848000000003	51.723165000000002	Луговая	0103000020E610000001000000050000008BC3995FCD3D4340514EB4AB90DC49408BC3995FCD3D434065ABCB2901E149401D739EB12F51434065ABCB2901E149401D739EB12F514340514EB4AB90DC49408BC3995FCD3D4340514EB4AB90DC4940
37154	54397	38.305439	38.359023999999998	51.980575000000002	51.956173	Ольшанка	0103000020E6100000010000000500000023F609A018274340BB287AE063FA494023F609A0182743403A234A7B83FD4940533D997FF42D43403A234A7B83FD4940533D997FF42D4340BB287AE063FA494023F609A018274340BB287AE063FA4940
37055	5730	39.546444000000001	39.57987	49.931337999999997	49.911009	Советская	0103000020E61000000100000005000000378C82E0F1C543404BAE62F19BF44840378C82E0F1C54340D2C2651536F748403CF71E2E39CA4340D2C2651536F748403CF71E2E39CA43404BAE62F19BF44840378C82E0F1C543404BAE62F19BF44840
36636	5689	39.298211999999999	39.321550999999999	50.052370000000003	50.039667000000001	Центральная	0103000020E610000001000000050000002BA391CF2BA643407FDDE9CE130549402BA391CF2BA6434051A5660FB4064940807F4A9528A9434051A5660FB4064940807F4A9528A943407FDDE9CE130549402BA391CF2BA643407FDDE9CE13054940
37212	54423	39.511733	39.557043999999998	50.151133999999999	50.130108	Зеленая	0103000020E6100000010000000500000059A4897780C1434057790261A710494059A4897780C1434026A8E15B581349406D37C1374DC7434026A8E15B581349406D37C1374DC7434057790261A710494059A4897780C1434057790261A7104940
37272	54459	39.446505999999999	39.468704000000002	50.063214000000002	50.049363	Мира	0103000020E61000000100000005000000E0BBCD1B27B94340F450DB8651064940E0BBCD1B27B943401E5377651708494090C01F7EFEBB43401E5377651708494090C01F7EFEBB4340F450DB8651064940E0BBCD1B27B94340F450DB8651064940
37120	4915	40.144443000000003	40.173782000000003	50.035941000000001	50.018324999999997	Центральная	0103000020E610000001000000050000006D91B41B7D1244407FD93D79580249406D91B41B7D124440F3CAF5B6990449401651137D3E164440F3CAF5B6990449401651137D3E1644407FD93D79580249406D91B41B7D1244407FD93D7958024940
37052	54390	39.709074999999999	39.727274999999999	50.228985999999999	50.217286999999999	Садовая	0103000020E61000000100000005000000A2B437F8C2DA4340486C770FD01B4940A2B437F8C2DA4340F59ECA694F1D49406519E25817DD4340F59ECA694F1D49406519E25817DD4340486C770FD01B4940A2B437F8C2DA4340486C770FD01B4940
36906	5577	39.819153999999997	39.859147	50.138219999999997	50.124535000000002	Школьная	0103000020E610000001000000050000009C31CC09DAE843408B1A4CC3F00F49409C31CC09DAE8434099D36531B11149406FBA6587F8ED434099D36531B11149406FBA6587F8ED43408B1A4CC3F00F49409C31CC09DAE843408B1A4CC3F00F4940
36907	4889	40.111960000000003	40.136502	49.969743999999999	49.950868999999997	Мира	0103000020E61000000100000005000000E73A8DB4540E4440DEE34C13B6F94840E73A8DB4540E444001BF469220FC484057EBC4E57811444001BF469220FC484057EBC4E578114440DEE34C13B6F94840E73A8DB4540E4440DEE34C13B6F94840
36453	5472	39.945025999999999	40.017107000000003	50.158591000000001	50.125661000000001	Школьная	0103000020E6100000010000000500000052EFA99CF6F84340FBB0DEA81510494052EFA99CF6F843405038BBB54C1449402FC4EA8F300244405038BBB54C1449402FC4EA8F30024440FBB0DEA81510494052EFA99CF6F84340FBB0DEA815104940
36497	5472	39.945025999999999	40.017107000000003	50.158591000000001	50.125661000000001	Центральная	0103000020E6100000010000000500000052EFA99CF6F84340FBB0DEA81510494052EFA99CF6F843405038BBB54C1449402FC4EA8F300244405038BBB54C1449402FC4EA8F30024440FBB0DEA81510494052EFA99CF6F84340FBB0DEA815104940
37234	54436	39.453809999999997	39.475073000000002	50.203457	50.192489999999999	Молодежная	0103000020E61000000100000005000000834C327216BA43404D672783A3184940834C327216BA4340369204E10A1A4940371B2B31CFBC4340369204E10A1A4940371B2B31CFBC43404D672783A3184940834C327216BA43404D672783A3184940
35813	5369	39.587029999999999	39.635395000000003	50.335802000000001	50.28378	Ленина	0103000020E61000000100000005000000ACE28DCC23CB434023A12DE752244940ACE28DCC23CB434038F7578FFB2A49405E85949F54D1434038F7578FFB2A49405E85949F54D1434023A12DE752244940ACE28DCC23CB434023A12DE752244940
36847	3997	39.348948999999998	39.394665000000003	49.910800000000002	49.877884999999999	Молодежная	0103000020E61000000100000005000000677C5F5CAAAC4340115322895EF04840677C5F5CAAAC434031992A1895F448401CF0F96184B2434031992A1895F448401CF0F96184B24340115322895EF04840677C5F5CAAAC4340115322895EF04840
35881	5279	39.479537000000001	39.562415999999999	50.195010000000003	50.157603999999999	Луначарского	0103000020E61000000100000005000000691CEA7761BD434001DC2C5E2C144940691CEA7761BD43404D327216F6184940A25F5B3FFDC743404D327216F6184940A25F5B3FFDC7434001DC2C5E2C144940691CEA7761BD434001DC2C5E2C144940
36229	5279	39.479537000000001	39.562415999999999	50.195010000000003	50.157603999999999	Ленина	0103000020E61000000100000005000000691CEA7761BD434001DC2C5E2C144940691CEA7761BD43404D327216F6184940A25F5B3FFDC743404D327216F6184940A25F5B3FFDC7434001DC2C5E2C144940691CEA7761BD434001DC2C5E2C144940
36260	5279	39.479537000000001	39.562415999999999	50.195010000000003	50.157603999999999	Вокзальная	0103000020E61000000100000005000000691CEA7761BD434001DC2C5E2C144940691CEA7761BD43404D327216F6184940A25F5B3FFDC743404D327216F6184940A25F5B3FFDC7434001DC2C5E2C144940691CEA7761BD434001DC2C5E2C144940
36776	4204	39.936231999999997	39.972119999999997	49.976388999999998	49.956938000000001	Центральная	0103000020E61000000100000005000000FDBB3E73D6F743405B26C3F17CFA4840FDBB3E73D6F743404A969350FAFC4840CDE49B6D6EFC43404A969350FAFC4840CDE49B6D6EFC43405B26C3F17CFA4840FDBB3E73D6F743405B26C3F17CFA4840
37121	54393	39.455497999999999	39.472746000000001	50.338664999999999	50.3277	Ленинская	0103000020E610000001000000050000005BB22AC24DBA43401973D712F22949405BB22AC24DBA434061A6ED5F592B49404CA8E0F082BC434061A6ED5F592B49404CA8E0F082BC43401973D712F22949405BB22AC24DBA43401973D712F2294940
36177	4645	39.988694000000002	40.032001000000001	50.088709000000001	50.067441000000002	переулок Советский	0103000020E610000001000000050000002FE065868DFE43406CB41CE8A10849402FE065868DFE434031EE06D15A0B49403B38D89B1804444031EE06D15A0B49403B38D89B180444406CB41CE8A10849402FE065868DFE43406CB41CE8A1084940
37013	3691	39.947155000000002	39.983573	50.271720000000002	50.260041999999999	Центральная	0103000020E61000000100000005000000179F02603CF9434010CB660E49214940179F02603CF94340A6D590B8C7224940431D56B8E5FD4340A6D590B8C7224940431D56B8E5FD434010CB660E49214940179F02603CF9434010CB660E49214940
35815	5008	39.557727	39.595033999999998	50.243355999999999	50.219090999999999	Рябцева	0103000020E61000000100000005000000508C2C9963C7434089EC832C0B1C4940508C2C9963C7434087A4164A261F49400801F9122ACC434087A4164A261F49400801F9122ACC434089EC832C0B1C4940508C2C9963C7434089EC832C0B1C4940
36110	4475	39.62086	39.653315999999997	50.155214000000001	50.121572	Дзержинского	0103000020E6100000010000000500000081B2295778CF4340FE0DDAAB8F0F494081B2295778CF4340D0F0660DDE1349400DFAD2DB9FD34340D0F0660DDE1349400DFAD2DB9FD34340FE0DDAAB8F0F494081B2295778CF4340FE0DDAAB8F0F4940
37265	54455	39.622171999999999	39.634227000000003	50.218676000000002	50.210951999999999	Юбилейная	0103000020E61000000100000005000000533E0455A3CF43404D83A279001B4940533E0455A3CF4340C6353E93FD1B4940BF9EAF592ED14340C6353E93FD1B4940BF9EAF592ED143404D83A279001B4940533E0455A3CF43404D83A279001B4940
37211	54422	39.863675000000001	39.914717000000003	50.141891999999999	50.125447000000001	Школьная	0103000020E61000000100000005000000B8AF03E78CEE4340CF30B5A50E104940B8AF03E78CEE434032C85D8429124940310C587215F5434032C85D8429124940310C587215F54340CF30B5A50E104940B8AF03E78CEE4340CF30B5A50E104940
36496	4277	39.414974999999998	39.507258999999998	50.134062999999998	50.109521999999998	Ленина	0103000020E610000001000000050000002CD49AE61DB54340A41820D1040E49402CD49AE61DB54340444DF4F92811494003CDE7DCEDC04340444DF4F92811494003CDE7DCEDC04340A41820D1040E49402CD49AE61DB54340A41820D1040E4940
37058	4623	39.729835000000001	39.803784	50.074356000000002	50.051462000000001	Лебедь-Сергеевка	0103000020E61000000100000005000000F33CB83B6BDD43404E7E8B4E96064940F33CB83B6BDD43407521567F840949402786E464E2E643407521567F840949402786E464E2E643404E7E8B4E96064940F33CB83B6BDD43404E7E8B4E96064940
36536	4199	39.828280999999997	39.859938	50.035570999999997	49.995381000000002	Центральная	0103000020E61000000100000005000000F7729F1C05EA4340A70705A568FF4840F7729F1C05EA4340CFD72C978D044940384BC97212EE4340CFD72C978D044940384BC97212EE4340A70705A568FF4840F7729F1C05EA4340A70705A568FF4840
36680	4109	39.230417000000003	39.288483999999997	49.940086999999998	49.903483999999999	Мира	0103000020E61000000100000005000000A2B8E34D7E9D4340C93A1C5DA5F34840A2B8E34D7E9D4340873254C554F84840AAB5300BEDA44340873254C554F84840AAB5300BEDA44340C93A1C5DA5F34840A2B8E34D7E9D4340C93A1C5DA5F34840
36957	4058	39.543551000000001	39.563665	50.061582999999999	50.046841000000001	Веселова	0103000020E61000000100000005000000A35A441493C54340548EC9E2FE054940A35A441493C54340AA7EA5F3E10749402E73BA2C26C84340AA7EA5F3E10749402E73BA2C26C84340548EC9E2FE054940A35A441493C54340548EC9E2FE054940
37173	54400	39.505355000000002	39.517949000000002	50.289408999999999	50.275922000000001	Озерная	0103000020E610000001000000050000005FEFFE78AFC043409B1F7F69512349405FEFFE78AFC043408315A75A0B2549407AFF1F274CC243408315A75A0B2549407AFF1F274CC243409B1F7F69512349405FEFFE78AFC043409B1F7F6951234940
37254	54450	39.746156999999997	39.766432000000002	50.311245	50.295883000000003	Центральная	0103000020E610000001000000050000003A57941282DF4340A038807EDF2549403A57941282DF434092054CE0D6274940CF4D9B711AE2434092054CE0D6274940CF4D9B711AE24340A038807EDF2549403A57941282DF4340A038807EDF254940
37218	54424	39.580212000000003	39.596974000000003	50.268881	50.252744999999997	Гагарина	0103000020E61000000100000005000000965F066344CA43401F9DBAF259204940965F066344CA434005C24EB16A224940FA47DFA469CC434005C24EB16A224940FA47DFA469CC43401F9DBAF259204940965F066344CA43401F9DBAF259204940
36747	4845	40.012652000000003	40.047272999999997	50.015998000000003	49.994947000000003	площадь Имени 172-ой Стрелковой дивизии	0103000020E61000000100000005000000501DAB949E0144406D205D6C5AFF4840501DAB949E0144409566F3380C024940ED7DAA0A0D0644409566F3380C024940ED7DAA0A0D0644406D205D6C5AFF4840501DAB949E0144406D205D6C5AFF4840
36407	3964	39.402183000000001	39.435295000000004	49.922336999999999	49.883121000000003	центральная	0103000020E61000000100000005000000EB0088BB7AB3434096B4E21B0AF14840EB0088BB7AB34340047289230FF64840618E1EBFB7B74340047289230FF64840618E1EBFB7B7434096B4E21B0AF14840EB0088BB7AB3434096B4E21B0AF14840
36777	5793	39.439957999999997	39.498491999999999	49.971446999999998	49.940503999999997	Центральная	0103000020E6100000010000000500000089CE328B50B84340EBE0606F62F8484089CE328B50B843400E66136058FC4840A8A8FA95CEBF43400E66136058FC4840A8A8FA95CEBF4340EBE0606F62F8484089CE328B50B84340EBE0606F62F84840
37118	4466	39.292284000000002	39.393172999999997	50.124834999999997	50.099048000000003	Победы	0103000020E610000001000000050000007192E68F69A54340FB5DD89AAD0C49407192E68F69A54340B532E197FA0F4940C9552C7E53B24340B532E197FA0F4940C9552C7E53B24340FB5DD89AAD0C49407192E68F69A54340FB5DD89AAD0C4940
35937	3884	39.698878999999998	39.759632000000003	50.142059000000003	50.120862000000002	Пролетарская	0103000020E610000001000000050000003B6EF8DD74D9434022AAF067780F49403B6EF8DD74D943401E8D43FD2E1249405F7F129F3BE143401E8D43FD2E1249405F7F129F3BE1434022AAF067780F49403B6EF8DD74D9434022AAF067780F4940
37253	54449	39.885226000000003	39.907198000000001	50.081553	50.065088000000003	Мира	0103000020E61000000100000005000000D2C8E7154FF1434058AEB7CD54084940D2C8E7154FF1434002F22554700A4940917F66101FF4434002F22554700A4940917F66101FF4434058AEB7CD54084940D2C8E7154FF1434058AEB7CD54084940
37054	3271	39.603864000000002	39.620753000000001	50.049328000000003	50.034407999999999	Верхняя	0103000020E61000000100000005000000AA9D616A4BCD4340425C397B67044940AA9D616A4BCD434078634161500649406BF294D574CF434078634161500649406BF294D574CF4340425C397B67044940AA9D616A4BCD4340425C397B67044940
35714	3788	39.398544999999999	39.445922000000003	50.226813999999997	50.201110999999997	октябрьская	0103000020E61000000100000005000000FE7DC68503B34340D4EE5701BE194940FE7DC68503B343403123BC3D081D49409148DBF813B943403123BC3D081D49409148DBF813B94340D4EE5701BE194940FE7DC68503B34340D4EE5701BE194940
36641	54326	39.576923999999998	39.611364999999999	50.151277999999998	50.137435000000004	Кутузова	0103000020E61000000100000005000000852348A5D8C94340B329577897114940852348A5D8C94340594DD7135D134940A375543541CE4340594DD7135D134940A375543541CE4340B329577897114940852348A5D8C94340B329577897114940
36574	3778	39.344591999999999	39.430444000000001	50.007002	49.963689000000002	Ленина	0103000020E610000001000000050000004B3B35971BAC4340EA4141295AFB48404B3B35971BAC4340D8800871E50049403561FBC918B74340D8800871E50049403561FBC918B74340EA4141295AFB48404B3B35971BAC4340EA4141295AFB4840
37051	3595	39.793894000000002	39.810971000000002	50.251863999999998	50.231862	Кирова	0103000020E61000000100000005000000CD3E8F519EE54340B3976DA7AD1D4940CD3E8F519EE5434016855D143D2049409180D1E5CDE7434016855D143D2049409180D1E5CDE74340B3976DA7AD1D4940CD3E8F519EE54340B3976DA7AD1D4940
37116	1847	38.768368000000002	38.799737	51.106931000000003	51.088960999999998	Трушова	0103000020E610000001000000050000007FA5F3E1596243404ACFF412638B49407FA5F3E159624340DCF63DEAAF8D4940593332C85D664340DCF63DEAAF8D4940593332C85D6643404ACFF412638B49407FA5F3E1596243404ACFF412638B4940
36858	1750	38.836334999999998	38.863912999999997	51.060398999999997	51.038440999999999	Первомайская	0103000020E6100000010000000500000005C078060D6B4340ABE97AA2EB84494005C078060D6B434005DB8827BB8749406CCB80B3946E434005DB8827BB8749406CCB80B3946E4340ABE97AA2EB84494005C078060D6B4340ABE97AA2EB844940
36976	1737	38.880586000000001	38.931474999999999	51.244954	51.221921999999999	Школьная	0103000020E6100000010000000500000061A8C30AB7704340A721AAF0679C494061A8C30AB77043401F8315A75A9F49405305A3923A7743401F8315A75A9F49405305A3923A774340A721AAF0679C494061A8C30AB7704340A721AAF0679C4940
37008	48699	38.598182000000001	38.706564	51.089934	51.06109	Спортивная	0103000020E6100000010000000500000027874F3A914C43406B0E10CCD187494027874F3A914C4340346612F5828B4940F6436CB0705A4340346612F5828B4940F6436CB0705A43406B0E10CCD187494027874F3A914C43406B0E10CCD1874940
36106	48699	38.598182000000001	38.706564	51.089934	51.06109	Октябрьская	0103000020E6100000010000000500000027874F3A914C43406B0E10CCD187494027874F3A914C4340346612F5828B4940F6436CB0705A4340346612F5828B4940F6436CB0705A43406B0E10CCD187494027874F3A914C43406B0E10CCD1874940
35784	48699	38.598182000000001	38.706564	51.089934	51.06109	Воронежская	0103000020E6100000010000000500000027874F3A914C43406B0E10CCD187494027874F3A914C4340346612F5828B4940F6436CB0705A4340346612F5828B4940F6436CB0705A43406B0E10CCD187494027874F3A914C43406B0E10CCD1874940
36435	48939	38.884143000000002	38.937376999999998	51.194577000000002	51.166108999999999	Советская	0103000020E6100000010000000500000061FE0A992B7143401F49490F4395494061FE0A992B714340E3C62DE6E7984940E48233F8FB774340E3C62DE6E7984940E48233F8FB7743401F49490F4395494061FE0A992B7143401F49490F43954940
36774	48772	38.422355000000003	38.456608000000003	51.105195000000002	51.087308999999998	Школьная	0103000020E61000000100000005000000AB2688BA0F364340BFD2F9F02C8B4940AB2688BA0F364340F3599E07778D4940C68B8521723A4340F3599E07778D4940C68B8521723A4340BFD2F9F02C8B4940AB2688BA0F364340BFD2F9F02C8B4940
36648	45442	38.782668999999999	38.824809000000002	51.258257999999998	51.232593000000001	Воронежская	0103000020E61000000100000005000000E84B6F7F2E644340A723809BC59D4940E84B6F7F2E64434016F71F990EA14940263960579369434016F71F990EA149402639605793694340A723809BC59D4940E84B6F7F2E644340A723809BC59D4940
35709	1559	38.750087000000001	38.795524	51.227697999999997	51.186228	площадь ленина	0103000020E61000000100000005000000CF13CFD902604340BCCCB051D6974940CF13CFD902604340ABAE4335259D49407097FDBAD3654340ABAE4335259D49407097FDBAD3654340BCCCB051D6974940CF13CFD902604340BCCCB051D6974940
36586	47276	38.896872000000002	38.928044	51.047767999999998	51.032522	Советская	0103000020E610000001000000050000005C59A2B3CC72434044334FAE298449405C59A2B3CC724340CDE506431D864940E09F5225CA764340CDE506431D864940E09F5225CA76434044334FAE298449405C59A2B3CC72434044334FAE29844940
36495	47157	38.631483000000003	38.686549999999997	51.289541999999997	51.234465999999998	Терешковой	0103000020E61000000100000005000000707D586FD450434010035DFB029E4940707D586FD4504340C26856B60FA54940CE88D2DEE0574340C26856B60FA54940CE88D2DEE057434010035DFB029E4940707D586FD450434010035DFB029E4940
36528	48746	38.578617000000001	38.636674999999997	51.074537999999997	51.054177000000003	Школьный переулок	0103000020E610000001000000050000006FF4311F104A434003999D45EF8649406FF4311F104A4340952710768A8949402497FF907E514340952710768A8949402497FF907E51434003999D45EF8649406FF4311F104A434003999D45EF864940
36237	54295	38.707633000000001	40.088352999999998	52.092751999999997	50.452804	Советская площадь	0103000020E610000001000000050000000249D8B7935A4340BEBF417BF53949400249D8B7935A4340BD512B4CDF0B4A4072C0AE264F0B4440BD512B4CDF0B4A4072C0AE264F0B4440BEBF417BF53949400249D8B7935A4340BEBF417BF5394940
36904	858	38.807436000000003	38.858854999999998	51.905121000000001	51.870162000000001	Школьная	0103000020E6100000010000000500000079CE16105A674340691CEA7761EF494079CE16105A6743401FF64201DBF34940C780ECF5EE6D43401FF64201DBF34940C780ECF5EE6D4340691CEA7761EF494079CE16105A674340691CEA7761EF4940
36255	54298	38.707633000000001	40.088352999999998	52.092751999999997	50.452804	Школьная	0103000020E610000001000000050000000249D8B7935A4340BEBF417BF53949400249D8B7935A4340BD512B4CDF0B4A4072C0AE264F0B4440BD512B4CDF0B4A4072C0AE264F0B4440BEBF417BF53949400249D8B7935A4340BEBF417BF5394940
36928	54378	39.367939999999997	39.419853000000003	51.982339000000003	51.942439	Зубарева	0103000020E61000000100000005000000F3716DA818AF4340CBBC55D7A1F84940F3716DA818AF4340ED4ACB48BDFD494052103CBEBDB54340ED4ACB48BDFD494052103CBEBDB54340CBBC55D7A1F84940F3716DA818AF4340CBBC55D7A1F84940
37011	48568	38.788049999999998	38.813400999999999	51.949218000000002	51.933250000000001	Мира	0103000020E6100000010000000500000070CE88D2DE644340FA7E6ABC74F7494070CE88D2DE6443402463B5F97FF9494050C422861D6843402463B5F97FF9494050C422861D684340FA7E6ABC74F7494070CE88D2DE644340FA7E6ABC74F74940
36823	46600	39.198832000000003	39.218046999999999	51.971494	51.960318000000001	Центральная	0103000020E61000000100000005000000FBB2B453739943404CE141B3EBFA4940FBB2B453739943404F2157EA59FC4940D6FECEF6E89B43404F2157EA59FC4940D6FECEF6E89B43404CE141B3EBFA4940FBB2B453739943404CE141B3EBFA4940
36573	687	39.016339000000002	39.049765000000001	51.961955000000003	51.946958000000002	Центральная	0103000020E610000001000000050000001E53776517824340C15774EB35F949401E53776517824340A29C685721FB494023BE13B35E864340A29C685721FB494023BE13B35E864340C15774EB35F949401E53776517824340C15774EB35F94940
36457	609	39.056080999999999	39.094141999999998	51.839399999999998	51.792487000000001	Ленина	0103000020E61000000100000005000000A77686A92D874340A9C0C93670E54940A77686A92D87434096218E7571EB49400B9755D80C8C434096218E7571EB49400B9755D80C8C4340A9C0C93670E54940A77686A92D874340A9C0C93670E54940
37012	1023	39.307681000000002	39.381531000000003	51.927129999999998	51.883088999999998	Школьная	0103000020E61000000100000005000000E04C4C1762A743408A3A730F09F14940E04C4C1762A74340FB912232ACF6494081B4FF01D6B04340FB912232ACF6494081B4FF01D6B043408A3A730F09F14940E04C4C1762A743408A3A730F09F14940
36006	1023	39.307681000000002	39.381531000000003	51.927129999999998	51.883088999999998	Советская	0103000020E61000000100000005000000E04C4C1762A743408A3A730F09F14940E04C4C1762A74340FB912232ACF6494081B4FF01D6B04340FB912232ACF6494081B4FF01D6B043408A3A730F09F14940E04C4C1762A743408A3A730F09F14940
35809	1023	39.307681000000002	39.381531000000003	51.927129999999998	51.883088999999998	Мосина	0103000020E61000000100000005000000E04C4C1762A743408A3A730F09F14940E04C4C1762A74340FB912232ACF6494081B4FF01D6B04340FB912232ACF6494081B4FF01D6B043408A3A730F09F14940E04C4C1762A743408A3A730F09F14940
37169	1023	39.307681000000002	39.381531000000003	51.927129999999998	51.883088999999998	Лесная	0103000020E61000000100000005000000E04C4C1762A743408A3A730F09F14940E04C4C1762A74340FB912232ACF6494081B4FF01D6B04340FB912232ACF6494081B4FF01D6B043408A3A730F09F14940E04C4C1762A743408A3A730F09F14940
37370	7268	38.865592999999997	38.886567999999997	52.005446999999997	52.000430000000001	Колхозная	0103000020E61000000100000005000000C1525DC0CB6E4340F9F719170E004A40C1525DC0CB6E43403F6EBF7CB2004A400ED76A0F7B7143403F6EBF7CB2004A400ED76A0F7B714340F9F719170E004A40C1525DC0CB6E4340F9F719170E004A40
36955	48289	39.321883	39.349578000000001	51.999569999999999	51.972436999999999	Садовая	0103000020E61000000100000005000000B6114F7633A94340CE35CCD078FC4940B6114F7633A943400708E6E8F1FF494057B3CEF8BEAC43400708E6E8F1FF494057B3CEF8BEAC4340CE35CCD078FC4940B6114F7633A94340CE35CCD078FC4940
36903	48485	38.798983	38.876606000000002	52.072696000000001	52.044227999999997	Центральная	0103000020E61000000100000005000000AD872F1345664340A3C85A43A9054A40AD872F134566434067463F1A4E094A401BBD1AA03470434067463F1A4E094A401BBD1AA034704340A3C85A43A9054A40AD872F1345664340A3C85A43A9054A40
36902	32485	39.143414999999997	39.168190000000003	52.046177	52.035735000000003	Песчаная	0103000020E61000000100000005000000BF60376C5B9243404A29E8F692044A40BF60376C5B924340E869C020E9054A40D3C1FA3F87954340E869C020E9054A40D3C1FA3F879543404A29E8F692044A40BF60376C5B9243404A29E8F692044A40
37024	54386	39.215307000000003	39.234206999999998	51.991663000000003	51.976742000000002	Центральная	0103000020E61000000100000005000000C9CC052E8F9B43409850C1E105FD4940C9CC052E8F9B43409ED32CD0EEFE494044BFB67EFA9D43409ED32CD0EEFE494044BFB67EFA9D43409850C1E105FD4940C9CC052E8F9B43409850C1E105FD4940
36846	45960	39.181952000000003	39.196289999999998	52.072701000000002	52.058233999999999	Школьная	0103000020E610000001000000050000008DB800344A974340F4C1323674074A408DB800344A97434079B130444E094A401344DD072099434079B130444E094A401344DD0720994340F4C1323674074A408DB800344A974340F4C1323674074A40
36842	21	39.339939000000001	39.367319999999999	52.022891000000001	52.001488999999999	Солнечная	0103000020E6100000010000000500000046D1031F83AB4340E126A3CA30004A4046D1031F83AB4340B62FA017EE024A4057957D5704AF4340B62FA017EE024A4057957D5704AF4340E126A3CA30004A4046D1031F83AB4340E126A3CA30004A40
37231	46498	38.943790999999997	38.980362	51.968164999999999	51.952858999999997	Транспортная	0103000020E610000001000000050000002BA1BB24CE7843408159A148F7F949402BA1BB24CE784340E010AAD4ECFB4940DE1E84807C7D4340E010AAD4ECFB4940DE1E84807C7D43408159A148F7F949402BA1BB24CE7843408159A148F7F94940
37161	47378	38.778663000000002	38.818027000000001	51.98554	51.968093000000003	Центральная	0103000020E6100000010000000500000079CDAB3AAB634340473EAF78EAFB494079CDAB3AAB6343402E73BA2C26FE49405C1FD61BB56843402E73BA2C26FE49405C1FD61BB5684340473EAF78EAFB494079CDAB3AAB634340473EAF78EAFB4940
36845	32434	39.107824000000001	39.125672999999999	52.009017999999998	51.985179000000002	Центральная	0103000020E61000000100000005000000A9DC442DCD8D43405EDA70581AFE4940A9DC442DCD8D4340A489778027014A40BF7E880D16904340A489778027014A40BF7E880D169043405EDA70581AFE4940A9DC442DCD8D43405EDA70581AFE4940
36844	176	39.330829999999999	39.360843000000003	52.054147	52.035961999999998	Центральная	0103000020E6100000010000000500000091442FA358AA43400AF31E679A044A4091442FA358AA43409816F549EE064A40CAFE791A30AE43409816F549EE064A40CAFE791A30AE43400AF31E679A044A4091442FA358AA43400AF31E679A044A40
36638	48192	39.452480000000001	39.485332	51.904715000000003	51.887642	Пристанционная	0103000020E610000001000000050000000B0C59DDEAB943402C47C8409EF149400B0C59DDEAB94340AF997CB3CDF34940E4D9E55B1FBE4340AF997CB3CDF34940E4D9E55B1FBE43402C47C8409EF149400B0C59DDEAB943402C47C8409EF14940
36679	32352	38.873148	38.956052999999997	52.045358	52.004022999999997	Советская	0103000020E61000000100000005000000AE484C50C36F434045B75ED383004A40AE484C50C36F4340554E7B4ACE054A40101FD8F15F7A4340554E7B4ACE054A40101FD8F15F7A434045B75ED383004A40AE484C50C36F434045B75ED383004A40
36458	48356	39.192363999999998	39.212693000000002	51.944693000000001	51.932428000000002	Почтовая	0103000020E61000000100000005000000C07630629F984340F6EFFACC59F74940C07630629F9843404CE141B3EBF84940488B3386399B43404CE141B3EBF84940488B3386399B4340F6EFFACC59F74940C07630629F984340F6EFFACC59F74940
35843	47673	39.329338999999997	39.37068	51.945653999999998	51.922275999999997	Ленина	0103000020E610000001000000050000000F26C5C727AA43405EF1D4230DF649400F26C5C727AA434071AAB5300BF9494001A4367172AF434071AAB5300BF9494001A4367172AF43405EF1D4230DF649400F26C5C727AA43405EF1D4230DF64940
37111	47673	39.329338999999997	39.37068	51.945653999999998	51.922275999999997	 Центральная	0103000020E610000001000000050000000F26C5C727AA43405EF1D4230DF649400F26C5C727AA434071AAB5300BF9494001A4367172AF434071AAB5300BF9494001A4367172AF43405EF1D4230DF649400F26C5C727AA43405EF1D4230DF64940
9882	40341	38.888337999999997	38.951957	52.014344999999999	51.983643000000001	Мира	0103000020E61000000100000005000000A3E5400FB57143403CF88903E8FD4940A3E5400FB571434039EE940ED6014A4061191BBAD979434039EE940ED6014A4061191BBAD97943403CF88903E8FD4940A3E5400FB57143403CF88903E8FD4940
35759	48228	39.271918999999997	39.303314999999998	51.911420999999997	51.894162000000001	Центральная	0103000020E610000001000000050000009C14E63DCEA24340B9A981E673F249409C14E63DCEA243409DF17D71A9F4494070B1A206D3A643409DF17D71A9F4494070B1A206D3A64340B9A981E673F249409C14E63DCEA24340B9A981E673F24940
37213	54314	39.313276999999999	39.326841999999999	50.528036999999998	50.518690999999997	Терновская	0103000020E6100000010000000500000064CBF27519A8434061DD78776442494064CBF27519A84340FA0967B796434940C87A6AF5D5A94340FA0967B796434940C87A6AF5D5A9434061DD78776442494064CBF27519A8434061DD787764424940
36704	54343	39.604556000000002	39.630957000000002	50.363076	50.334836000000003	Зеленая	0103000020E61000000100000005000000E04C4C1762CD434001C3F2E7DB2A4940E04C4C1762CD434033FB3C46792E49405517F032C3D0434033FB3C46792E49405517F032C3D0434001C3F2E7DB2A4940E04C4C1762CD434001C3F2E7DB2A4940
37004	47901	39.587550999999998	39.631765999999999	50.547176	50.522911999999998	Центральная	0103000020E61000000100000005000000B5DD04DF34CB4340CD57C9C7EE424940B5DD04DF34CB4340FB93F8DC09464940C45C52B5DDD04340FB93F8DC09464940C45C52B5DDD04340CD57C9C7EE424940B5DD04DF34CB4340CD57C9C7EE424940
37221	46477	39.776062000000003	39.840831000000001	50.432594000000002	50.411726999999999	 Советская	0103000020E610000001000000050000008DD5E6FF55E34340AAF06778B33449408DD5E6FF55E3434011397D3D5F374940433BA759A0EB434011397D3D5F374940433BA759A0EB4340AAF06778B33449408DD5E6FF55E34340AAF06778B3344940
37171	30961	39.871310999999999	39.901268999999999	50.39011	50.370182999999997	Школьная	0103000020E6100000010000000500000091D26C1E87EF434080441328622F494091D26C1E87EF4340D9EBDD1FEF31494006F357C85CF34340D9EBDD1FEF31494006F357C85CF3434080441328622F494091D26C1E87EF434080441328622F4940
35868	16435	39.624696	39.659227000000001	50.432468	50.393422999999999	калинина	0103000020E6100000010000000500000094F8DC09F6CF4340423F53AF5B32494094F8DC09F6CF43408448861C5B374940F2D1E28C61D443408448861C5B374940F2D1E28C61D44340423F53AF5B32494094F8DC09F6CF4340423F53AF5B324940
36024	16435	39.624696	39.659227000000001	50.432468	50.393422999999999	Цемзавода	0103000020E6100000010000000500000094F8DC09F6CF4340423F53AF5B32494094F8DC09F6CF43408448861C5B374940F2D1E28C61D443408448861C5B374940F2D1E28C61D44340423F53AF5B32494094F8DC09F6CF4340423F53AF5B324940
37049	16435	39.624696	39.659227000000001	50.432468	50.393422999999999	Северная	0103000020E6100000010000000500000094F8DC09F6CF4340423F53AF5B32494094F8DC09F6CF43408448861C5B374940F2D1E28C61D443408448861C5B374940F2D1E28C61D44340423F53AF5B32494094F8DC09F6CF4340423F53AF5B324940
35998	16435	39.624696	39.659227000000001	50.432468	50.393422999999999	Первомайская	0103000020E6100000010000000500000094F8DC09F6CF4340423F53AF5B32494094F8DC09F6CF43408448861C5B374940F2D1E28C61D443408448861C5B374940F2D1E28C61D44340423F53AF5B32494094F8DC09F6CF4340423F53AF5B324940
36570	16435	39.624696	39.659227000000001	50.432468	50.393422999999999	Ленина	0103000020E6100000010000000500000094F8DC09F6CF4340423F53AF5B32494094F8DC09F6CF43408448861C5B374940F2D1E28C61D443408448861C5B374940F2D1E28C61D44340423F53AF5B32494094F8DC09F6CF4340423F53AF5B324940
37270	54458	39.494081000000001	39.527453999999999	50.556739	50.531061000000001	Школьная	0103000020E610000001000000050000009949D40B3EBF43402D978DCEF94349409949D40B3EBF434031B43A39434749407B12D89C83C3434031B43A39434749407B12D89C83C343402D978DCEF94349409949D40B3EBF43402D978DCEF9434940
37003	47839	39.759892999999998	39.791485999999999	50.553562999999997	50.536682999999996	Центральная	0103000020E61000000100000005000000CBBA7F2C44E14340DAA84E07B2444940CBBA7F2C44E1434048A30227DB464940F59ECA694FE5434048A30227DB464940F59ECA694FE54340DAA84E07B2444940CBBA7F2C44E14340DAA84E07B2444940
37202	54414	39.648034000000003	39.654519999999998	50.516131000000001	50.501064999999997	Центральная	0103000020E61000000100000005000000195932C7F2D24340CA15DEE522404940195932C7F2D24340D4B9A29410424940F949B54FC7D34340D4B9A29410424940F949B54FC7D34340CA15DEE522404940195932C7F2D24340CA15DEE522404940
36534	30815	39.609909999999999	39.625720000000001	50.612805000000002	50.592464	Челябинская	0103000020E610000001000000050000006EC0E78711CE4340570740DCD54B49406EC0E78711CE4340A3E9EC64704E4940003ACC9717D04340A3E9EC64704E4940003ACC9717D04340570740DCD54B49406EC0E78711CE4340570740DCD54B4940
37006	48104	39.751241999999998	39.773439000000003	50.723492	50.674717000000001	Донская	0103000020E61000000100000005000000D9B0A6B228E0434012876C205D564940D9B0A6B228E043407575C7629B5C4940B939950C00E343407575C7629B5C4940B939950C00E3434012876C205D564940D9B0A6B228E0434012876C205D564940
37247	54447	39.921616	39.945340999999999	50.437815000000001	50.415934	Центральная	0103000020E6100000010000000500000034BC5983F7F54340B1A547533D35494034BC5983F7F54340605969520A384940B24813EF00F94340605969520A384940B24813EF00F94340B1A547533D35494034BC5983F7F54340B1A547533D354940
37395	45525	39.526304000000003	39.562164000000003	50.616629000000003	50.593435999999997	Богучарская	0103000020E6100000010000000500000083E0F1ED5DC343407022FAB5F54B494083E0F1ED5DC34340F261F6B2ED4E4940897E6DFDF4C74340F261F6B2ED4E4940897E6DFDF4C743407022FAB5F54B494083E0F1ED5DC343407022FAB5F54B4940
37326	45369	39.790075999999999	39.815722999999998	50.513044000000001	50.497059999999998	пл.им.Н Зацепина	0103000020E6100000010000000500000060ADDA3521E543402B137EA99F3F494060ADDA3521E543405BB4006DAB41494029CC7B9C69E843405BB4006DAB41494029CC7B9C69E843402B137EA99F3F494060ADDA3521E543402B137EA99F3F4940
36632	29590	42.346690000000002	42.380467000000003	51.210706000000002	51.187899000000002	Молодежная	0103000020E61000000100000005000000D5EC8156602C4540BEF90D130D984940D5EC8156602C45401689096AF89A4940871A8524B33045401689096AF89A4940871A8524B3304540BEF90D130D984940D5EC8156602C4540BEF90D130D984940
35819	47203	42.124115000000003	42.220934999999997	51.252288999999998	51.224246000000001	18 Партсъезда	0103000020E61000000100000005000000B6F81400E30F45402121CA17B49C4940B6F81400E30F4540FD1186014BA0494058C51B99471C4540FD1186014BA0494058C51B99471C45402121CA17B49C4940B6F81400E30F45402121CA17B49C4940
37002	29206	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	Центральная	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
36168	29206	42.219093999999998	42.283377000000002	51.219344	51.153241000000001	Советская	0103000020E61000000100000005000000FA5FAE450B1C454003B4AD669D934940FA5FAE450B1C45407349D576139C494024B891B2452445407349D576139C494024B891B24524454003B4AD669D934940FA5FAE450B1C454003B4AD669D934940
36565	45522	42.415537	42.516579999999998	51.282162999999997	51.215293000000003	площадь Свободы	0103000020E6100000010000000500000094A3005130354540640795B88E9B494094A30051303545401492CCEA1DA4494043E21E4B1F4245401492CCEA1DA4494043E21E4B1F424540640795B88E9B494094A3005130354540640795B88E9B4940
36488	45522	42.415537	42.516579999999998	51.282162999999997	51.215293000000003	площадь Революции	0103000020E6100000010000000500000094A3005130354540640795B88E9B494094A30051303545401492CCEA1DA4494043E21E4B1F4245401492CCEA1DA4494043E21E4B1F424540640795B88E9B494094A3005130354540640795B88E9B4940
36127	45522	42.415537	42.516579999999998	51.282162999999997	51.215293000000003	Советская	0103000020E6100000010000000500000094A3005130354540640795B88E9B494094A30051303545401492CCEA1DA4494043E21E4B1F4245401492CCEA1DA4494043E21E4B1F424540640795B88E9B494094A3005130354540640795B88E9B4940
36678	47167	41.926457999999997	41.968473000000003	51.260067999999997	51.206648999999999	Ленинская	0103000020E610000001000000050000000C8FFD2C96F6444024607479739A49400C8FFD2C96F64440395E81E849A149408E075BECF6FB4440395E81E849A149408E075BECF6FB444024607479739A49400C8FFD2C96F6444024607479739A4940
37351	47441	42.811729999999997	42.839865000000003	51.380859000000001	51.370446999999999	Садовая	0103000020E610000001000000050000004E97C5C4E66745405EF3AACE6AAF49404E97C5C4E667454092B1DAFCBFB049400C0742B2806B454092B1DAFCBFB049400C0742B2806B45405EF3AACE6AAF49404E97C5C4E66745405EF3AACE6AAF4940
37376	47441	42.811729999999997	42.839865000000003	51.380859000000001	51.370446999999999	Молодежная	0103000020E610000001000000050000004E97C5C4E66745405EF3AACE6AAF49404E97C5C4E667454092B1DAFCBFB049400C0742B2806B454092B1DAFCBFB049400C0742B2806B45405EF3AACE6AAF49404E97C5C4E66745405EF3AACE6AAF4940
37112	29826	42.519733000000002	42.592514000000001	51.295997	51.264367999999997	площадь Революции	0103000020E6100000010000000500000074D3669C86424540F10D85CFD6A1494074D3669C86424540685BCD3AE3A549400936AE7FD74B4540685BCD3AE3A549400936AE7FD74B4540F10D85CFD6A1494074D3669C86424540F10D85CFD6A14940
36772	29057	42.667479	42.686649000000003	51.252051999999999	51.237493999999998	Горская	0103000020E6100000010000000500000026E2ADF36F554540847F1134669E494026E2ADF36F55454019726C3D43A04940626A4B1DE457454019726C3D43A04940626A4B1DE4574540847F1134669E494026E2ADF36F554540847F1134669E4940
36529	47336	42.546394999999997	42.578221999999997	51.314504999999997	51.295642000000001	Садовая	0103000020E6100000010000000500000055D97745F04545407AA9D898D7A5494055D97745F0454540D8B628B341A84940F2E9B12D034A4540D8B628B341A84940F2E9B12D034A45407AA9D898D7A5494055D97745F04545407AA9D898D7A54940
36898	47451	42.837142999999998	42.870353999999999	51.273277999999998	51.255789999999998	Советская	0103000020E61000000100000005000000A4897780276B454069520ABABDA04940A4897780276B4540AF5B04C6FAA24940ADF886C2676F4540AF5B04C6FAA24940ADF886C2676F454069520ABABDA04940A4897780276B454069520ABABDA04940
36002	29959	42.668331999999999	42.699674000000002	51.352933999999998	51.329675000000002	Октябрьская	0103000020E61000000100000005000000656F29E78B55454087A757CA32AA4940656F29E78B554540BFD2F9F02CAD494046EEE9EA8E594540BFD2F9F02CAD494046EEE9EA8E59454087A757CA32AA4940656F29E78B55454087A757CA32AA4940
37001	46878	41.026938999999999	41.073552999999997	50.104098	50.075391000000003	Советская	0103000020E6100000010000000500000054FEB5BC72834440D5B48B69A609494054FEB5BC728344401DCA5015530D4940E7C2482F6A8944401DCA5015530D4940E7C2482F6A894440D5B48B69A609494054FEB5BC72834440D5B48B69A6094940
36925	54377	40.837952000000001	40.88841	50.306314999999998	50.254375000000003	Первомайская	0103000020E6100000010000000500000014CFD902426B4440C3F5285C8F20494014CFD902426B44401AA37554352749403DB83B6BB77144401AA37554352749403DB83B6BB7714440C3F5285C8F20494014CFD902426B4440C3F5285C8F204940
36914	54377	40.837952000000001	40.88841	50.306314999999998	50.254375000000003	Мира	0103000020E6100000010000000500000014CFD902426B4440C3F5285C8F20494014CFD902426B44401AA37554352749403DB83B6BB77144401AA37554352749403DB83B6BB7714440C3F5285C8F20494014CFD902426B4440C3F5285C8F204940
36631	29088	41.091726000000001	41.201563	50.226202999999998	50.163473000000003	Садовая	0103000020E61000000100000005000000B11875ADBD8B4440B763EAAEEC144940B11875ADBD8B4440E8A04B38F41C4940B58AFED0CC994440E8A04B38F41C4940B58AFED0CC994440B763EAAEEC144940B11875ADBD8B4440B763EAAEEC144940
36445	29088	41.091726000000001	41.201563	50.226202999999998	50.163473000000003	Молодежная	0103000020E61000000100000005000000B11875ADBD8B4440B763EAAEEC144940B11875ADBD8B4440E8A04B38F41C4940B58AFED0CC994440E8A04B38F41C4940B58AFED0CC994440B763EAAEEC144940B11875ADBD8B4440B763EAAEEC144940
37115	29088	41.091726000000001	41.201563	50.226202999999998	50.163473000000003	Ленина	0103000020E61000000100000005000000B11875ADBD8B4440B763EAAEEC144940B11875ADBD8B4440E8A04B38F41C4940B58AFED0CC994440E8A04B38F41C4940B58AFED0CC994440B763EAAEEC144940B11875ADBD8B4440B763EAAEEC144940
36109	54283	40.859555999999998	40.91827	50.123772000000002	50.069065999999999	Победы	0103000020E61000000100000005000000508A56EE056E4440FDA19927D7084940508A56EE056E44408C14CAC2D70F4940EF7211DF897544408C14CAC2D70F4940EF7211DF89754440FDA19927D7084940508A56EE056E4440FDA19927D7084940
36292	46662	40.853026	40.912018000000003	50.286180000000002	50.249664000000003	Центральная	0103000020E61000000100000005000000A051BAF42F6D4440897E6DFDF41F4940A051BAF42F6D44407862D68BA124494082AE7D01BD7444407862D68BA124494082AE7D01BD744440897E6DFDF41F4940A051BAF42F6D4440897E6DFDF41F4940
35962	46662	40.853026	40.912018000000003	50.286180000000002	50.249664000000003	Международная	0103000020E61000000100000005000000A051BAF42F6D4440897E6DFDF41F4940A051BAF42F6D44407862D68BA124494082AE7D01BD7444407862D68BA124494082AE7D01BD744440897E6DFDF41F4940A051BAF42F6D4440897E6DFDF41F4940
37250	54448	41.306244	41.343415999999998	50.115045000000002	50.096372000000002	Октября	0103000020E61000000100000005000000514CDE0033A744400420EEEA550C4940514CDE0033A74440BF4868CBB90E49402976340EF5AB4440BF4868CBB90E49402976340EF5AB44400420EEEA550C4940514CDE0033A744400420EEEA550C4940
36696	54336	40.898147999999999	40.930838000000001	49.966307999999998	49.934666	Советская	0103000020E61000000100000005000000E17B7F83F67244407157AF22A3F74840E17B7F83F67244407CEE04FBAFFB4840E1EF17B3257744407CEE04FBAFFB4840E1EF17B3257744407157AF22A3F74840E17B7F83F67244407157AF22A3F74840
36771	54362	41.059745999999997	41.126176000000001	50.151468999999999	50.116911000000002	Степная	0103000020E610000001000000050000008D08C6C1A587444076C58CF0F60E49408D08C6C1A5874440CDAD10566313494022C5008926904440CDAD10566313494022C500892690444076C58CF0F60E49408D08C6C1A587444076C58CF0F60E4940
36494	28720	40.950609999999998	41.008856000000002	50.050508000000001	50.022660000000002	Ленина	0103000020E6100000010000000500000012A0A696AD794440B476DB85E602494012A0A696AD794440DB17D00B77064940CB2F833122814440DB17D00B77064940CB2F833122814440B476DB85E602494012A0A696AD794440B476DB85E6024940
36611	46917	41.162135999999997	41.284216999999998	50.095384000000003	50.040165000000002	Ленина	0103000020E610000001000000050000008BC058DFC0944440D0B87020240549408BC058DFC0944440E547FC8A350C4940CEFBFF3861A44440E547FC8A350C4940CEFBFF3861A44440D0B87020240549408BC058DFC0944440D0B8702024054940
36995	46917	41.162135999999997	41.284216999999998	50.095384000000003	50.040165000000002	Космонавтов	0103000020E610000001000000050000008BC058DFC0944440D0B87020240549408BC058DFC0944440E547FC8A350C4940CEFBFF3861A44440E547FC8A350C4940CEFBFF3861A44440D0B87020240549408BC058DFC0944440D0B8702024054940
36105	28393	40.823371999999999	40.872016000000002	50.206114999999997	50.151192000000002	Ленина	0103000020E610000001000000050000009738F240646944405BB56B425A1349409738F24064694440861BF0F9611A49405CCB64389E6F4440861BF0F9611A49405CCB64389E6F44405BB56B425A1349409738F240646944405BB56B425A134940
37209	54420	40.819023999999999	40.848416999999998	50.251201999999999	50.224912000000003	Школьная	0103000020E61000000100000005000000CE5147C7D56844402E3D9AEAC91C4940CE5147C7D56844404B581B63272049406A2FA2ED986C44404B581B63272049406A2FA2ED986C44402E3D9AEAC91C4940CE5147C7D56844402E3D9AEAC91C4940
37000	46756	40.806933000000001	40.842928000000001	50.033326000000002	50.004356000000001	Пионерская	0103000020E6100000010000000500000016889E94496744404CC5C6BC8E00494016889E9449674440A20DC00644044940FC709010E56B4440A20DC00644044940FC709010E56B44404CC5C6BC8E00494016889E94496744404CC5C6BC8E004940
36411	46801	40.928896999999999	40.962494	49.915306999999999	49.866883000000001	Шестакова	0103000020E610000001000000050000001F2DCE18E6764440AC3AAB05F6EE48401F2DCE18E676444062669FC728F54840514CDE00337B444062669FC728F54840514CDE00337B4440AC3AAB05F6EE48401F2DCE18E6764440AC3AAB05F6EE4840
36444	28567	40.748632000000001	40.790063000000004	50.047314999999998	50.009278000000002	Ленина	0103000020E610000001000000050000009A5E622CD35F444041498105300149409A5E622CD35F44401CCEFC6A0E064940CC63CDC8206544401CCEFC6A0E064940CC63CDC82065444041498105300149409A5E622CD35F44404149810530014940
36808	27179	40.289746000000001	40.323639	51.757424	51.747756000000003	Колхозная	0103000020E61000000100000005000000CB129D6516254440A3B1F677B6DF4940CB129D65162544404E9A0645F3E04940E65AB4006D2944404E9A0645F3E04940E65AB4006D294440A3B1F677B6DF4940CB129D6516254440A3B1F677B6DF4940
37189	46595	40.360039	40.407173999999998	51.701439999999998	51.685250000000003	Пролетарская	0103000020E610000001000000050000006C2409C2152E4440C1CAA145B6D749406C2409C2152E4440990D32C9C8D9494008E412471E344440990D32C9C8D9494008E412471E344440C1CAA145B6D749406C2409C2152E4440C1CAA145B6D74940
37315	46595	40.360039	40.407173999999998	51.701439999999998	51.685250000000003	Народная	0103000020E610000001000000050000006C2409C2152E4440C1CAA145B6D749406C2409C2152E4440990D32C9C8D9494008E412471E344440990D32C9C8D9494008E412471E344440C1CAA145B6D749406C2409C2152E4440C1CAA145B6D74940
36694	17078	40.162526999999997	40.198467999999998	51.590218999999998	51.575831000000001	Школьная	0103000020E61000000100000005000000C6DB4AAFCD144440F18288D4B4C94940C6DB4AAFCD144440293DD34B8CCB4940B9A6406667194440293DD34B8CCB4940B9A6406667194440F18288D4B4C94940C6DB4AAFCD144440F18288D4B4C94940
36998	17078	40.162526999999997	40.198467999999998	51.590218999999998	51.575831000000001	Заводская	0103000020E61000000100000005000000C6DB4AAFCD144440F18288D4B4C94940C6DB4AAFCD144440293DD34B8CCB4940B9A6406667194440293DD34B8CCB4940B9A6406667194440F18288D4B4C94940C6DB4AAFCD144440F18288D4B4C94940
37379	46972	40.120350999999999	40.144936999999999	51.623013999999998	51.610247000000001	Придача	0103000020E610000001000000050000003C855CA9670F4440B6BDDD921CCE49403C855CA9670F44409E7939ECBECF49407C7DAD4B8D1244409E7939ECBECF49407C7DAD4B8D124440B6BDDD921CCE49403C855CA9670F4440B6BDDD921CCE4940
37314	49096	40.175651000000002	40.220647999999997	51.567259999999997	51.548580000000001	Тверская	0103000020E610000001000000050000003E4162BB7B164440AE9E93DE37C649403E4162BB7B1644401B2AC6F99BC84940C2F693313E1C44401B2AC6F99BC84940C2F693313E1C4440AE9E93DE37C649403E4162BB7B164440AE9E93DE37C64940
35818	26554	40.170476999999998	40.215527000000002	51.731973000000004	51.704766999999997	брянская	0103000020E610000001000000050000002FDCB930D2154440672618CE35DA49402FDCB930D21544400B47904AB1DD4940D7338463961B44400B47904AB1DD4940D7338463961B4440672618CE35DA49402FDCB930D2154440672618CE35DA4940
37047	26554	40.170476999999998	40.215527000000002	51.731973000000004	51.704766999999997	Майская	0103000020E610000001000000050000002FDCB930D2154440672618CE35DA49402FDCB930D21544400B47904AB1DD4940D7338463961B44400B47904AB1DD4940D7338463961B4440672618CE35DA49402FDCB930D2154440672618CE35DA4940
35932	26554	40.170476999999998	40.215527000000002	51.731973000000004	51.704766999999997	Ленина	0103000020E610000001000000050000002FDCB930D2154440672618CE35DA49402FDCB930D21544400B47904AB1DD4940D7338463961B44400B47904AB1DD4940D7338463961B4440672618CE35DA49402FDCB930D2154440672618CE35DA4940
36838	26554	40.170476999999998	40.215527000000002	51.731973000000004	51.704766999999997	Брянская	0103000020E610000001000000050000002FDCB930D2154440672618CE35DA49402FDCB930D21544400B47904AB1DD4940D7338463961B44400B47904AB1DD4940D7338463961B4440672618CE35DA49402FDCB930D2154440672618CE35DA4940
36080	27028	40.113838000000001	40.154027999999997	51.749217000000002	51.728900000000003	50 лет Октября	0103000020E6100000010000000500000062855B3E920E4440F7065F984CDD494062855B3E920E4440BA4DB857E6DF49408A558330B7134440BA4DB857E6DF49408A558330B7134440F7065F984CDD494062855B3E920E4440F7065F984CDD4940
35929	26296	40.107415000000003	40.158493	51.672992000000001	51.628069000000004	советская	0103000020E61000000100000005000000C80C54C6BF0D4440D350A39064D04940C80C54C6BF0D44401D3C139A24D649408DD2A57F491444401D3C139A24D649408DD2A57F49144440D350A39064D04940C80C54C6BF0D4440D350A39064D04940
35808	26296	40.107415000000003	40.158493	51.672992000000001	51.628069000000004	Красная площадь	0103000020E61000000100000005000000C80C54C6BF0D4440D350A39064D04940C80C54C6BF0D44401D3C139A24D649408DD2A57F491444401D3C139A24D649408DD2A57F49144440D350A39064D04940C80C54C6BF0D4440D350A39064D04940
36492	26296	40.107415000000003	40.158493	51.672992000000001	51.628069000000004	Железнодорожная	0103000020E61000000100000005000000C80C54C6BF0D4440D350A39064D04940C80C54C6BF0D44401D3C139A24D649408DD2A57F491444401D3C139A24D649408DD2A57F49144440D350A39064D04940C80C54C6BF0D4440D350A39064D04940
36078	26296	40.107415000000003	40.158493	51.672992000000001	51.628069000000004	9-е Января	0103000020E61000000100000005000000C80C54C6BF0D4440D350A39064D04940C80C54C6BF0D44401D3C139A24D649408DD2A57F491444401D3C139A24D649408DD2A57F49144440D350A39064D04940C80C54C6BF0D4440D350A39064D04940
36527	26296	40.107415000000003	40.158493	51.672992000000001	51.628069000000004	9-Января	0103000020E61000000100000005000000C80C54C6BF0D4440D350A39064D04940C80C54C6BF0D44401D3C139A24D649408DD2A57F491444401D3C139A24D649408DD2A57F49144440D350A39064D04940C80C54C6BF0D4440D350A39064D04940
37167	45902	40.438732000000002	40.462716999999998	51.669953	51.648544000000001	Верхняя	0103000020E61000000100000005000000B6DAC35E283844402E02637D03D34940B6DAC35E28384440B56D1805C1D54940D026874F3A3B4440B56D1805C1D54940D026874F3A3B44402E02637D03D34940B6DAC35E283844402E02637D03D34940
37159	46147	39.765678000000001	39.778640000000003	51.484115000000003	51.478712999999999	Школьная	0103000020E6100000010000000500000023A298BC01E24340C495B37746BD494023A298BC01E243406440F67AF7BD4940C1ADBB79AAE343406440F67AF7BD4940C1ADBB79AAE34340C495B37746BD494023A298BC01E24340C495B37746BD4940
37210	54416	39.665092999999999	40.539199000000004	51.792197999999999	51.326500000000003	Кольцевая	0103000020E6100000010000000500000036E675C421D543406F1283C0CAA9494036E675C421D5434072FA7ABE66E5494099840B790445444072FA7ABE66E5494099840B79044544406F1283C0CAA9494036E675C421D543406F1283C0CAA94940
37168	46311	40.057136	40.081803999999998	51.539074999999997	51.522126	50 лет Октября	0103000020E610000001000000050000004EB6813B5007444016325706D5C249404EB6813B50074440AC8BDB6800C549404B57B08D780A4440AC8BDB6800C549404B57B08D780A444016325706D5C249404EB6813B5007444016325706D5C24940
37046	27631	39.854036000000001	39.946958000000002	51.590935999999999	51.537444999999998	Школьная	0103000020E61000000100000005000000A7CD380D51ED434009336DFFCAC44940A7CD380D51ED4340B80375CAA3CB4940C15774EB35F94340B80375CAA3CB4940C15774EB35F9434009336DFFCAC44940A7CD380D51ED434009336DFFCAC44940
36770	27631	39.854036000000001	39.946958000000002	51.590935999999999	51.537444999999998	Совхозная	0103000020E61000000100000005000000A7CD380D51ED434009336DFFCAC44940A7CD380D51ED4340B80375CAA3CB4940C15774EB35F94340B80375CAA3CB4940C15774EB35F9434009336DFFCAC44940A7CD380D51ED434009336DFFCAC44940
36999	45932	39.975802999999999	40.005842000000001	51.746585000000003	51.732045999999997	Школьная	0103000020E610000001000000050000005A2BDA1CE7FC43407495EEAEB3DD49405A2BDA1CE7FC43409357E71890DF4940BC783F6EBF0044409357E71890DF4940BC783F6EBF0044407495EEAEB3DD49405A2BDA1CE7FC43407495EEAEB3DD4940
36629	46386	40.362231000000001	40.397767999999999	51.648392999999999	51.629365999999997	Центральная	0103000020E61000000100000005000000774CDD955D2E44406F9BA9108FD04940774CDD955D2E444048FAB48AFED249409AB2D30FEA32444048FAB48AFED249409AB2D30FEA3244406F9BA9108FD04940774CDD955D2E44406F9BA9108FD04940
37342	54475	40.307164	40.337141000000003	51.628951999999998	51.612578999999997	Мира	0103000020E610000001000000050000001841632651274440B29B19FD68CE494018416326512744407C60C77F81D049400492B06F272B44407C60C77F81D049400492B06F272B4440B29B19FD68CE49401841632651274440B29B19FD68CE4940
36628	46184	40.020026999999999	40.072659000000002	51.475465	51.455052000000002	Молодежная	0103000020E61000000100000005000000BC04A73E900244405DFDD8243FBA4940BC04A73E9002444042B28009DCBC49404A61DEE34C09444042B28009DCBC49404A61DEE34C0944405DFDD8243FBA4940BC04A73E900244405DFDD8243FBA4940
36613	54321	39.833896000000003	39.884920000000001	51.550595999999999	51.497416999999999	Советская	0103000020E61000000100000005000000F321A81ABDEA4340BABC395CABBF4940F321A81ABDEA43407AA702EE79C64940C5C9FD0E45F143407AA702EE79C64940C5C9FD0E45F14340BABC395CABBF4940F321A81ABDEA4340BABC395CABBF4940
36578	54321	39.833896000000003	39.884920000000001	51.550595999999999	51.497416999999999	Партизанская	0103000020E61000000100000005000000F321A81ABDEA4340BABC395CABBF4940F321A81ABDEA43407AA702EE79C64940C5C9FD0E45F143407AA702EE79C64940C5C9FD0E45F14340BABC395CABBF4940F321A81ABDEA4340BABC395CABBF4940
36768	46020	39.911231999999998	39.936852000000002	51.635067999999997	51.609498000000002	Пролетарская	0103000020E61000000100000005000000CA880B40A3F443401C7DCC0704CE4940CA880B40A3F44340395E81E849D149409A982EC4EAF74340395E81E849D149409A982EC4EAF743401C7DCC0704CE4940CA880B40A3F443401C7DCC0704CE4940
37268	40462	40.193976999999997	40.230744999999999	51.748491999999999	51.740568000000003	 Ломоносова	0103000020E610000001000000050000008D96033DD4184440693BA6EECADE49408D96033DD4184440A8A8FA95CEDF4940965B5A0D891D4440A8A8FA95CEDF4940965B5A0D891D4440693BA6EECADE49408D96033DD4184440693BA6EECADE4940
37114	26899	39.929036000000004	39.973359000000002	51.652298999999999	51.638612000000002	Проспект революции	0103000020E610000001000000050000004167D2A6EAF64340A56ABB09BED149404167D2A6EAF64340541B9C887ED349403622180797FC4340541B9C887ED349403622180797FC4340A56ABB09BED149404167D2A6EAF64340A56ABB09BED14940
37346	46138	40.073242999999998	40.106876	51.754631000000003	51.733775000000001	Бевз	0103000020E6100000010000000500000099D4D00660094440ABCFD556ECDD494099D4D006600944401EC6A4BF97E04940185DDE1CAE0D44401EC6A4BF97E04940185DDE1CAE0D4440ABCFD556ECDD494099D4D00660094440ABCFD556ECDD4940
36896	26943	39.921967000000002	39.966037999999998	51.687694999999998	51.656534000000001	Дзержинского	0103000020E61000000100000005000000E17EC00303F64340255B5D4E09D44940E17EC00303F64340B54FC76306D84940BC581822A7FB4340B54FC76306D84940BC581822A7FB4340255B5D4E09D44940E17EC00303F64340255B5D4E09D44940
36447	27385	40.002375000000001	40.047379999999997	51.416496000000002	51.383754000000003	Советская	0103000020E61000000100000005000000FCA9F1D24D004440C7DADFD91EB14940FCA9F1D24D0044401975ADBD4FB54940033E3F8C100644401975ADBD4FB54940033E3F8C10064440C7DADFD91EB14940FCA9F1D24D004440C7DADFD91EB14940
37009	54385	40.040095000000001	40.066065000000002	51.653143	51.643374000000001	Центральная	0103000020E61000000100000005000000D7DD3CD521054440618C48145AD24940D7DD3CD521054440404E98309AD34940833463D174084440404E98309AD34940833463D174084440618C48145AD24940D7DD3CD521054440618C48145AD24940
36630	27826	40.039546999999999	40.065067999999997	51.619866000000002	51.600313	Школьная	0103000020E61000000100000005000000D4D347E00F0544408C2E6F0ED7CC4940D4D347E00F05444080F3E2C457CF49401002F2255408444080F3E2C457CF49401002F225540844408C2E6F0ED7CC4940D4D347E00F0544408C2E6F0ED7CC4940
36862	27826	40.039546999999999	40.065067999999997	51.619866000000002	51.600313	Центральная	0103000020E61000000100000005000000D4D347E00F0544408C2E6F0ED7CC4940D4D347E00F05444080F3E2C457CF49401002F2255408444080F3E2C457CF49401002F225540844408C2E6F0ED7CC4940D4D347E00F0544408C2E6F0ED7CC4940
37323	49431	40.222740999999999	40.339243000000003	51.769168999999998	51.673014000000002	Центральная	0103000020E610000001000000050000003A3DEFC6821C444005E09F5225D649403A3DEFC6821C44406B0C3A2174E24940CF328B506C2B44406B0C3A2174E24940CF328B506C2B444005E09F5225D649403A3DEFC6821C444005E09F5225D64940
36996	54383	40.012014000000001	40.141424999999998	50.701206999999997	50.648389000000002	Герино	0103000020E610000001000000050000000D8CBCAC89014440070B2769FE5249400D8CBCAC89014440F65CA626C15949401CEBE2361A124440F65CA626C15949401CEBE2361A124440070B2769FE5249400D8CBCAC89014440070B2769FE524940
36442	25490	40.466507	40.506545000000003	50.523781999999997	50.504949000000003	Молодежная	0103000020E61000000100000005000000732D5A80B63B4440EF92382BA2404940732D5A80B63B4440E21DE0490B434940E6797077D6404440E21DE0490B434940E6797077D6404440EF92382BA2404940732D5A80B63B4440EF92382BA2404940
37240	54441	40.222389999999997	40.260254000000003	50.373480999999998	50.355437999999999	Мира	0103000020E610000001000000050000008D7A8846771C4440B9E00CFE7E2D49408D7A8846771C4440B456B439CE2F49409C53C90050214440B456B439CE2F49409C53C90050214440B9E00CFE7E2D49408D7A8846771C4440B9E00CFE7E2D4940
37113	45645	39.906201000000003	39.948332000000001	50.673563999999999	50.657212999999999	Мира	0103000020E610000001000000050000001F4DF564FEF34340C6C03A8E1F5449401F4DF564FEF34340A8E15B583756494009E066F162F94340A8E15B583756494009E066F162F94340C6C03A8E1F5449401F4DF564FEF34340C6C03A8E1F544940
35928	26183	40.031714000000001	40.099877999999997	50.389771000000003	50.341051	Советская	0103000020E61000000100000005000000A56950340F04444051A2258FA72B4940A56950340F044440F1F62004E431494081CB63CDC80C4440F1F62004E431494081CB63CDC80C444051A2258FA72B4940A56950340F04444051A2258FA72B4940
36916	49073	39.814106000000002	39.88015	50.685761999999997	50.653781000000002	Советская	0103000020E610000001000000050000001BBD1AA034E8434083DF8618AF5349401BBD1AA034E84340766B990CC757494086C954C1A8F04340766B990CC757494086C954C1A8F0434083DF8618AF5349401BBD1AA034E8434083DF8618AF534940
36530	54317	40.238433999999998	40.298738	50.543723999999997	50.507990999999997	проспект Революции	0103000020E6100000010000000500000092205C01851E4440C7D45DD90541494092205C01851E444070067FBF984549404609FA0B3D26444070067FBF984549404609FA0B3D264440C7D45DD90541494092205C01851E4440C7D45DD905414940
36633	54325	39.953524000000002	39.994765999999998	50.703043999999998	50.687393999999998	Скрынникова	0103000020E61000000100000005000000BEF90D130DFA4340BABBCE86FC574940BEF90D130DFA434013D38558FD5949401C96067E54FF434013D38558FD5949401C96067E54FF4340BABBCE86FC574940BEF90D130DFA4340BABBCE86FC574940
37208	54419	40.623972999999999	40.654434999999999	50.569401999999997	50.555903999999998	Новоселов	0103000020E61000000100000005000000234BE658DE4F444098DBBDDC27474940234BE658DE4F444074232C2AE2484940CB2DAD86C453444074232C2AE2484940CB2DAD86C453444098DBBDDC27474940234BE658DE4F444098DBBDDC27474940
35874	40402	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	проспект Революции	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
35865	40402	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	микрорайон гранитный	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
36145	40402	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	микрорайон Черемушки	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
35924	40402	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	восточная	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
35875	40402	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	Советская	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
36952	40402	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	Садовая	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
36164	40402	40.080142000000002	40.166415999999998	50.469754999999999	50.433672999999999	Гагарина	0103000020E610000001000000050000009D84D217420A44404014CC98823749409D84D217420A4440F5108DEE203C4940FCC3961E4D154440F5108DEE203C4940FCC3961E4D1544404014CC98823749409D84D217420A44404014CC9882374940
36978	54381	39.983815999999997	40.019190999999999	50.289484000000002	50.269837000000003	Победы	0103000020E6100000010000000500000009A4C4AEEDFD43401920D1048A22494009A4C4AEEDFD43408E5BCCCF0D25494053B0C6D9740244408E5BCCCF0D25494053B0C6D9740244401920D1048A22494009A4C4AEEDFD43401920D1048A224940
36899	25357	40.523757000000003	40.541246999999998	50.545281000000003	50.534782	Мира	0103000020E610000001000000050000008A0629780A434440A73E90BC734449408A0629780A434440AA108FC4CB4549407007EA9447454440AA108FC4CB4549407007EA9447454440A73E90BC734449408A0629780A434440A73E90BC73444940
37367	45568	40.223154000000001	40.255718000000002	50.550198000000002	50.516520999999997	60 лет Октября	0103000020E610000001000000050000005DFC6D4F901C44403E59315C1D4249405DFC6D4F901C44408D2958E36C464940D07F0F5EBB2044408D2958E36C464940D07F0F5EBB2044403E59315C1D4249405DFC6D4F901C44403E59315C1D424940
37288	54389	40.012014000000001	40.141424999999998	50.701206999999997	50.648389000000002	пл.Первомайская	0103000020E610000001000000050000000D8CBCAC89014440070B2769FE5249400D8CBCAC89014440F65CA626C15949401CEBE2361A124440F65CA626C15949401CEBE2361A124440070B2769FE5249400D8CBCAC89014440070B2769FE524940
37045	54389	40.012014000000001	40.141424999999998	50.701206999999997	50.648389000000002	Буденного	0103000020E610000001000000050000000D8CBCAC89014440070B2769FE5249400D8CBCAC89014440F65CA626C15949401CEBE2361A124440F65CA626C15949401CEBE2361A124440070B2769FE5249400D8CBCAC89014440070B2769FE524940
36617	45423	40.207047000000003	40.252412	50.752547	50.714252999999999	Ленина	0103000020E6100000010000000500000012DE1E84801A4440F2086EA46C5B494012DE1E84801A4440F9D9C87553604940198F52094F204440F9D9C87553604940198F52094F204440F2086EA46C5B494012DE1E84801A4440F2086EA46C5B4940
37164	49517	40.405144	40.424115999999998	50.465088000000002	50.454410000000003	Центральная	0103000020E61000000100000005000000D71533C2DB334440D97C5C1B2A3A4940D71533C2DB3344408BE1EA00883B4940ECDADE6E493644408BE1EA00883B4940ECDADE6E49364440D97C5C1B2A3A4940D71533C2DB334440D97C5C1B2A3A4940
36405	49561	40.190418999999999	40.228211000000002	50.706285000000001	50.675727999999999	Революции проспект	0103000020E61000000100000005000000BDC458A65F184440E97E4E417E564940BDC458A65F184440E353008C675A494032CB9E04361D4440E353008C675A494032CB9E04361D4440E97E4E417E564940BDC458A65F184440E97E4E417E564940
36135	49540	40.177303999999999	40.209409999999998	50.474542	50.450648000000001	проспект Революции	0103000020E6100000010000000500000099B9C0E5B116444000016BD5AE39494099B9C0E5B11644400A4AD1CABD3C494049BA66F2CD1A44400A4AD1CABD3C494049BA66F2CD1A444000016BD5AE39494099B9C0E5B116444000016BD5AE394940
36689	54331	40.436827000000001	40.467602999999997	50.595986000000003	50.575592	Центральная	0103000020E61000000100000005000000418177F2E93744406CEBA7FFAC494940418177F2E9374440DB6FED44494C49407841446ADA3B4440DB6FED44494C49407841446ADA3B44406CEBA7FFAC494940418177F2E93744406CEBA7FFAC494940
37160	26058	39.776808000000003	39.793776999999999	50.746465999999998	50.715530999999999	Первомайская	0103000020E61000000100000005000000B6A2CD716EE3434018231285965B4940B6A2CD716EE34340B8C9A8328C5F494093A8177C9AE54340B8C9A8328C5F494093A8177C9AE5434018231285965B4940B6A2CD716EE3434018231285965B4940
36423	25101	40.331194000000004	40.376182	50.443230999999997	50.415320000000001	Советская	0103000020E61000000100000005000000D350A390642A4440F7AFAC3429354940D350A390642A444064C91CCBBB38494004AC55BB2630444064C91CCBBB38494004AC55BB26304440F7AFAC3429354940D350A390642A4440F7AFAC3429354940
35867	49449	40.302869999999999	40.38053	50.641604000000001	50.587854	пролетарская	0103000020E610000001000000050000004278B471C42644405169C4CC3E4B49404278B471C4264440CC7D721420524940CD920035B5304440CC7D721420524940CD920035B53044405169C4CC3E4B49404278B471C42644405169C4CC3E4B4940
36165	49449	40.302869999999999	40.38053	50.641604000000001	50.587854	Советская	0103000020E610000001000000050000004278B471C42644405169C4CC3E4B49404278B471C4264440CC7D721420524940CD920035B5304440CC7D721420524940CD920035B53044405169C4CC3E4B49404278B471C42644405169C4CC3E4B4940
36441	49449	40.302869999999999	40.38053	50.641604000000001	50.587854	Почтовая	0103000020E610000001000000050000004278B471C42644405169C4CC3E4B49404278B471C4264440CC7D721420524940CD920035B5304440CC7D721420524940CD920035B53044405169C4CC3E4B49404278B471C42644405169C4CC3E4B4940
36568	49449	40.302869999999999	40.38053	50.641604000000001	50.587854	Мостовая	0103000020E610000001000000050000004278B471C42644405169C4CC3E4B49404278B471C4264440CC7D721420524940CD920035B5304440CC7D721420524940CD920035B53044405169C4CC3E4B49404278B471C42644405169C4CC3E4B4940
35727	25343	40.046464	40.117054000000003	50.266289999999998	50.237952	Почтовая	0103000020E610000001000000050000007E384888F205444047020D36751E49407E384888F20544403CA06CCA15224940D9EE1EA0FB0E44403CA06CCA15224940D9EE1EA0FB0E444047020D36751E49407E384888F205444047020D36751E4940
36836	49419	40.110388	40.134678999999998	50.594276000000001	50.584909000000003	Центральная	0103000020E6100000010000000500000078EFA831210E44406B11514CDE4A494078EFA831210E44401B66683C114C49409F3A56293D1144401B66683C114C49409F3A56293D1144406B11514CDE4A494078EFA831210E44406B11514CDE4A4940
36437	49406	39.956291	39.990220999999998	50.571838999999997	50.550055	Центральная	0103000020E61000000100000005000000C53A55BE67FA43402A00C63368464940C53A55BE67FA4340E6C9350532494940FD67CD8FBFFE4340E6C9350532494940FD67CD8FBFFE43402A00C63368464940C53A55BE67FA43402A00C63368464940
35930	24761	40.050317999999997	40.087947999999997	50.527613000000002	50.510323	Садовая	0103000020E610000001000000050000003733FAD170064440C4B29943524149403733FAD170064440E4F8A1D288434940D2DF4BE1410B4440E4F8A1D288434940D2DF4BE1410B4440C4B29943524149403733FAD170064440C4B2994352414940
36589	22669	38.848165000000002	38.884906999999998	50.867415999999999	50.846958000000001	Мира	0103000020E61000000100000005000000514EB4AB906C4340F48AA71E696C4940514EB4AB906C43407903CC7C076F49403080F0A1447143407903CC7C076F49403080F0A144714340F48AA71E696C4940514EB4AB906C4340F48AA71E696C4940
74933	60384	38.875762000000002	38.898955999999998	50.721490000000003	50.702103000000001	Заречная	0103000020E610000001000000050000002F8A1EF81870434035B6D782DE5949402F8A1EF8187043400E32C9C8595C494080457EFD107343400E32C9C8595C494080457EFD1073434035B6D782DE5949402F8A1EF81870434035B6D782DE594940
36807	22543	38.750743	38.811765999999999	50.839785999999997	50.787342000000002	пер. Мира	0103000020E61000000100000005000000B859BC58186043403562669FC7644940B859BC5818604340BFD18E1B7E6B49409B00C3F2E7674340BFD18E1B7E6B49409B00C3F2E76743403562669FC7644940B859BC58186043403562669FC7644940
35861	24009	39.118108999999997	39.199514999999998	51.138922999999998	51.098996	центральная	0103000020E610000001000000050000007F2E1A321E8F4340A837A3E6AB8C49407F2E1A321E8F4340C3D4963AC8914940DD0720B589994340C3D4963AC8914940DD0720B589994340A837A3E6AB8C49407F2E1A321E8F4340A837A3E6AB8C4940
36670	49099	38.951256000000001	38.988509000000001	50.980845000000002	50.961208999999997	Советская	0103000020E61000000100000005000000D80FB1C1C279434078CF81E5087B4940D80FB1C1C2794340FAB836548C7D49409D668176877E4340FAB836548C7D49409D668176877E434078CF81E5087B4940D80FB1C1C279434078CF81E5087B4940
36608	49201	39.149362000000004	39.19726	51.223958000000003	51.194763000000002	Советская	0103000020E61000000100000005000000F1A1444B1E93434045BC75FEED984940F1A1444B1E934340BBD6DEA7AA9C49408C67D0D03F994340BBD6DEA7AA9C49408C67D0D03F99434045BC75FEED984940F1A1444B1E93434045BC75FEED984940
36491	45762	38.944626999999997	39.033316999999997	51.058236999999998	51.037393000000002	Ленина	0103000020E6100000010000000500000094F59B89E9784340B70C384BC984494094F59B89E978434065355D4F748749404EB340BB4384434065355D4F748749404EB340BB43844340B70C384BC984494094F59B89E9784340B70C384BC9844940
36436	48861	39.09937	39.107626000000003	50.841607000000003	50.836550000000003	Советская	0103000020E610000001000000050000000D1AFA27B88C434002BC0512146B49400D1AFA27B88C4340D78A36C7B96B4940831953B0C68D4340D78A36C7B96B4940831953B0C68D434002BC0512146B49400D1AFA27B88C434002BC0512146B4940
36951	48977	39.154643999999998	39.169950999999998	50.899858999999999	50.883495000000003	Школьный переулок	0103000020E61000000100000005000000E542E55FCB934340FB96395D16714940E542E55FCB934340710168942E734940147651F4C0954340710168942E734940147651F4C0954340FB96395D16714940E542E55FCB934340FB96395D16714940
36989	22587	38.757551999999997	38.780486000000003	50.899512000000001	50.853656999999998	Победы	0103000020E610000001000000050000007B82C476F76043403080F0A1446D49407B82C476F7604340062E8F3523734940317E1AF7E6634340062E8F3523734940317E1AF7E66343403080F0A1446D49407B82C476F76043403080F0A1446D4940
36726	54355	39.181565999999997	39.237343000000003	51.014448999999999	50.997667	Молодежная	0103000020E610000001000000050000006308008E3D97434033A6608DB37F49406308008E3D974340DE3AFF76D98149409F776341619E4340DE3AFF76D98149409F776341619E434033A6608DB37F49406308008E3D97434033A6608DB37F4940
36895	23247	39.107410000000002	39.156252000000002	50.793149999999997	50.779505	Мира	0103000020E61000000100000005000000B6A1629CBF8D4340C408E1D1C6634940B6A1629CBF8D434044696FF085654940A1F7C6100094434044696FF085654940A1F7C61000944340C408E1D1C6634940B6A1629CBF8D4340C408E1D1C6634940
36723	54354	38.706240999999999	39.350493999999998	51.261994999999999	50.620697999999997	Школьная	0103000020E61000000100000005000000130CE71A665A4340A7583508734F4940130CE71A665A4340965B5A0D89A14940DCB8C5FCDCAC4340965B5A0D89A14940DCB8C5FCDCAC4340A7583508734F4940130CE71A665A4340A7583508734F4940
36868	54372	38.84901	38.876596999999997	50.892246	50.880591000000003	Садовая	0103000020E610000001000000050000000DFD135CAC6C43407313B534B77049400DFD135CAC6C434050FEEE1D35724940C7629B543470434050FEEE1D35724940C7629B54347043407313B534B77049400DFD135CAC6C43407313B534B7704940
35744	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	федосеенко	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
36073	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	комсомольская	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
36190	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Нарского	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
35724	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Милицейская	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
35850	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Ленина	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
35948	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Комсомольская	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
36763	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	Вокзальная	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
35945	20882	39.027272000000004	39.126103999999998	50.882295999999997	50.835543000000001	50 лет Октября	0103000020E610000001000000050000005B0C1EA67D8343406CB3B112F36A49405B0C1EA67D83434020B24813EF70494088F2052D2490434020B24813EF70494088F2052D249043406CB3B112F36A49405B0C1EA67D8343406CB3B112F36A4940
37227	54431	39.078825999999999	39.094537000000003	51.181153000000002	51.165098	Воронежская	0103000020E6100000010000000500000089096AF8168A4340485167EE2195494089096AF8168A4340414981053097494088A1D5C9198C4340414981053097494088A1D5C9198C4340485167EE2195494089096AF8168A4340485167EE21954940
36927	48625	38.914802999999999	38.968288000000001	50.801968000000002	50.773018	Подгорная	0103000020E610000001000000050000002FA4C34318754340139CFA40F26249402FA4C3431875434022382EE3A6664940FC8D76DCF07B434022382EE3A6664940FC8D76DCF07B4340139CFA40F26249402FA4C34318754340139CFA40F2624940
37390	48601	39.012278999999999	39.041168999999996	50.812060000000002	50.800311999999998	 60 лет Октября	0103000020E61000000100000005000000BBB6B75B92814340554CA59F70664940BBB6B75B92814340E4310395F1674940F44D9A0645854340E4310395F1674940F44D9A0645854340554CA59F70664940BBB6B75B92814340554CA59F70664940
36409	22793	38.891140999999998	38.946109	50.767743000000003	50.741917999999998	Почтовая	0103000020E61000000100000005000000F78F85E8107243402828452BF75E4940F78F85E810724340D15D126745624940C3B986191A794340D15D126745624940C3B986191A7943402828452BF75E4940F78F85E8107243402828452BF75E4940
36403	23885	39.027334000000003	39.051948000000003	51.205418999999999	51.190682000000002	Куркина	0103000020E61000000100000005000000D10836AE7F834340CBF78C4468984940D10836AE7F8343400F7D772B4B9A4940DB8B683BA68643400F7D772B4B9A4940DB8B683BA6864340CBF78C4468984940D10836AE7F834340CBF78C4468984940
36489	49012	39.232850999999997	39.253844999999998	50.948618000000003	50.932772	Садовая	0103000020E61000000100000005000000A2EBC20FCE9D4340F04FA91265774940A2EBC20FCE9D4340CF328B506C79494066A032FE7DA04340CF328B506C79494066A032FE7DA04340F04FA91265774940A2EBC20FCE9D4340F04FA91265774940
37097	46738	39.223976	39.254725000000001	50.896960999999997	50.867353999999999	пер.Рабочий	0103000020E61000000100000005000000618BDD3EAB9C43400307B474056F4940618BDD3EAB9C4340CB64389ECF7249409F3C2CD49AA04340CB64389ECF7249409F3C2CD49AA043400307B474056F4940618BDD3EAB9C43400307B474056F4940
37179	46738	39.223976	39.254725000000001	50.896960999999997	50.867353999999999	 Мира	0103000020E61000000100000005000000618BDD3EAB9C43400307B474056F4940618BDD3EAB9C4340CB64389ECF7249409F3C2CD49AA04340CB64389ECF7249409F3C2CD49AA043400307B474056F4940618BDD3EAB9C43400307B474056F4940
36834	23137	39.131754999999998	39.154491	50.653843000000002	50.641775000000003	Школьная	0103000020E61000000100000005000000D00A0C59DD904340F931E6AE25524940D00A0C59DD904340F9DB9E20B15349405F43705CC6934340F9DB9E20B15349405F43705CC6934340F931E6AE25524940D00A0C59DD904340F931E6AE25524940
35873	23514	39.121146000000003	39.204931000000002	51.002315000000003	50.974476000000003	Свободы	0103000020E6100000010000000500000047054EB6818F4340535E2BA1BB7C494047054EB6818F434027A5A0DB4B804940E277D32D3B9A434027A5A0DB4B804940E277D32D3B9A4340535E2BA1BB7C494047054EB6818F4340535E2BA1BB7C4940
36762	23718	38.960113999999997	38.987180000000002	51.031677999999999	51.023440999999998	Верхняя	0103000020E610000001000000050000004337FB03E57A434059315C1D008349404337FB03E57A4340580053060E844940F5A10BEA5B7E4340580053060E844940F5A10BEA5B7E434059315C1D008349404337FB03E57A434059315C1D00834940
74972	60406	39.203952000000001	39.223526999999997	50.834724000000001	50.823863000000003	Центральная	0103000020E6100000010000000500000016FA60191B9A434036B1C0577469494016FA60191B9A4340D9976C3CD86A4940F16261889C9C4340D9976C3CD86A4940F16261889C9C434036B1C0577469494016FA60191B9A434036B1C05774694940
36577	6788	39.101292999999998	39.135384000000002	51.096173999999998	51.060806999999997	Ленина	0103000020E610000001000000050000002828452BF78C4340162F1686C88749402828452BF78C4340DD5CFC6D4F8C49406A334E4354914340DD5CFC6D4F8C49406A334E4354914340162F1686C88749402828452BF78C4340162F1686C8874940
36832	23081	39.015926	39.044896999999999	50.744266000000003	50.708486000000001	Молодежная	0103000020E61000000100000005000000FB93F8DC0982434041D653ABAF5A4940FB93F8DC098243402BC3B81B445F49402158552FBF8543402BC3B81B445F49402158552FBF85434041D653ABAF5A4940FB93F8DC0982434041D653ABAF5A4940
36743	22723	38.932149000000003	38.946916999999999	50.846992999999998	50.836590000000001	Садовая	0103000020E61000000100000005000000E3FF8EA85077434090149161156B4940E3FF8EA850774340707841446A6C49406283859334794340707841446A6C4940628385933479434090149161156B4940E3FF8EA85077434090149161156B4940
36606	48812	39.056556999999998	39.081187999999997	50.818986000000002	50.80153	Ленина	0103000020E6100000010000000500000010AE80423D874340A661F8889866494010AE80423D874340E1F08288D4684940F0694E5E648A4340E1F08288D4684940F0694E5E648A4340A661F8889866494010AE80423D874340A661F88898664940
36734	48582	38.913967	38.958801999999999	50.881756000000003	50.861510000000003	Октябрьской революции	0103000020E61000000100000005000000C64FE3DEFC744340A796ADF5456E4940C64FE3DEFC744340A1866F61DD70494071AB2006BA7A4340A1866F61DD70494071AB2006BA7A4340A796ADF5456E4940C64FE3DEFC744340A796ADF5456E4940
74996	60425	38.966006	38.993710999999998	50.682343000000003	50.667422000000002	переулок Южный	0103000020E61000000100000005000000B1DEA815A67B4340C25087156E554940B1DEA815A67B4340C8D3F2035757494075560BEC317F4340C8D3F2035757494075560BEC317F4340C25087156E554940B1DEA815A67B4340C25087156E554940
36605	47480	38.852513000000002	38.915072000000002	50.790216999999998	50.767487000000003	Центральная	0103000020E610000001000000050000001A355F251F6D4340768D96033D6249401A355F251F6D434022DFA5D4256549401FBE4C142175434022DFA5D4256549401FBE4C1421754340768D96033D6249401A355F251F6D4340768D96033D624940
36567	49154	39.038536000000001	39.068584999999999	51.139805000000003	51.120440000000002	Мостовая	0103000020E61000000100000005000000FDDB65BFEE844340AC90F2936A8F4940FDDB65BFEE8443409D685721E591494082FFAD64C78843409D685721E591494082FFAD64C7884340AC90F2936A8F4940FDDB65BFEE844340AC90F2936A8F4940
36699	54339	39.082535999999998	39.093953999999997	50.821223000000003	50.806870000000004	Луговая	0103000020E610000001000000050000000F5F268A908A4340D00F2384476749400F5F268A908A43408CDCD3D51D69494008AA46AF068C43408CDCD3D51D69494008AA46AF068C4340D00F2384476749400F5F268A908A4340D00F238447674940
36950	23195	39.186615000000003	39.216591999999999	50.765658000000002	50.733834000000002	Центральная	0103000020E61000000100000005000000B6F81400E3974340B058C345EE5D4940B6F81400E3974340DCF5D21401624940A1496249B99B4340DCF5D21401624940A1496249B99B4340B058C345EE5D4940B6F81400E3974340B058C345EE5D4940
37363	49081	38.889226999999998	38.922311999999998	50.952835	50.936456	Клубная	0103000020E610000001000000050000002FDCB930D27143404D124BCADD7749402FDCB930D2714340F9BD4D7FF6794940AB5AD2510E764340F9BD4D7FF6794940AB5AD2510E7643404D124BCADD7749402FDCB930D27143404D124BCADD774940
36721	54352	39.163905	39.198067999999999	50.513857000000002	50.464886999999997	площадь Победы	0103000020E610000001000000050000005053CBD6FA944340F3AACE6A813B49405053CBD6FA9443400CE9F010C64149402B31CF4A5A9943400CE9F010C64149402B31CF4A5A994340F3AACE6A813B49405053CBD6FA944340F3AACE6A813B4940
36257	54299	39.347825999999998	39.395176999999997	50.251035000000002	50.222468999999997	Шевченко	0103000020E610000001000000050000006859F78F85AC4340D9AF3BDD791C49406859F78F85AC4340609335EA21204940D190F12895B24340609335EA21204940D190F12895B24340D9AF3BDD791C49406859F78F85AC4340D9AF3BDD791C4940
37256	54452	39.391933999999999	39.417572	50.418453999999997	50.405923000000001	Денисова	0103000020E610000001000000050000006118B0E42AB24340DCD8EC48F53349406118B0E42AB24340B07092E68F354940D7DCD1FF72B54340B07092E68F354940D7DCD1FF72B54340DCD8EC48F53349406118B0E42AB24340DCD8EC48F5334940
36703	21517	39.244107	39.307492000000003	50.292695000000002	50.271622000000001	Степана Разина	0103000020E61000000100000005000000C2DCEEE53E9F4340E36F7B82C4224940C2DCEEE53E9F4340F3599E07772549400DE4D9E55BA74340F3599E07772549400DE4D9E55BA74340E36F7B82C4224940C2DCEEE53E9F4340E36F7B82C4224940
37251	21517	39.244107	39.307492000000003	50.292695000000002	50.271622000000001	Пролетарская	0103000020E61000000100000005000000C2DCEEE53E9F4340E36F7B82C4224940C2DCEEE53E9F4340F3599E07772549400DE4D9E55BA74340F3599E07772549400DE4D9E55BA74340E36F7B82C4224940C2DCEEE53E9F4340E36F7B82C4224940
37014	21517	39.244107	39.307492000000003	50.292695000000002	50.271622000000001	Октябрьская	0103000020E61000000100000005000000C2DCEEE53E9F4340E36F7B82C4224940C2DCEEE53E9F4340F3599E07772549400DE4D9E55BA74340F3599E07772549400DE4D9E55BA74340E36F7B82C4224940C2DCEEE53E9F4340E36F7B82C4224940
36268	21517	39.244107	39.307492000000003	50.292695000000002	50.271622000000001	50 лет ВЛКСМ	0103000020E61000000100000005000000C2DCEEE53E9F4340E36F7B82C4224940C2DCEEE53E9F4340F3599E07772549400DE4D9E55BA74340F3599E07772549400DE4D9E55BA74340E36F7B82C4224940C2DCEEE53E9F4340E36F7B82C4224940
36688	54330	39.251455	39.28154	50.391649000000001	50.355708	Октябрьская	0103000020E6100000010000000500000035B56CAD2FA043407976F9D6872D494035B56CAD2FA043406C41EF8D213249400742B28009A443406C41EF8D213249400742B28009A443407976F9D6872D494035B56CAD2FA043407976F9D6872D4940
37243	54443	39.226590000000002	39.256396000000002	50.410677	50.390321999999998	Асфальтная	0103000020E61000000100000005000000E2CCAFE6009D434064744012F6314940E2CCAFE6009D4340151C5E1091344940A1698995D1A04340151C5E1091344940A1698995D1A0434064744012F6314940E2CCAFE6009D434064744012F6314940
37207	54418	39.229590000000002	39.255983000000001	50.158192	50.142584999999997	Тополиная	0103000020E610000001000000050000008CBE8234639D434038F3AB39401249408CBE8234639D4340923EADA23F1449407EAA0A0DC4A04340923EADA23F1449407EAA0A0DC4A0434038F3AB39401249408CBE8234639D434038F3AB3940124940
36707	54344	39.078386000000002	39.121684999999999	50.306781000000001	50.290582999999998	Гагарина	0103000020E610000001000000050000006D3B6D8D088A434004E3E0D2312549406D3B6D8D088A434060048D9944274940F6B4C35F938F434060048D9944274940F6B4C35F938F434004E3E0D2312549406D3B6D8D088A434004E3E0D231254940
37162	47681	39.133541999999998	39.174523000000001	50.323777999999997	50.301682999999997	Школьная	0103000020E610000001000000050000003B527DE7179143402C616D8C9D2649403B527DE7179143400795B88E712949402DB308C5569643400795B88E712949402DB308C5569643402C616D8C9D2649403B527DE7179143402C616D8C9D264940
37259	47681	39.133541999999998	39.174523000000001	50.323777999999997	50.301682999999997	Трудовая	0103000020E610000001000000050000003B527DE7179143402C616D8C9D2649403B527DE7179143400795B88E712949402DB308C5569643400795B88E712949402DB308C5569643402C616D8C9D2649403B527DE7179143402C616D8C9D264940
37217	54427	39.195875999999998	39.235115	50.280447000000002	50.262022999999999	Мичурина	0103000020E610000001000000050000002009FB761299434060E63BF8892149402009FB761299434073A1F2AFE523494047E6913F189E434073A1F2AFE523494047E6913F189E434060E63BF8892149402009FB761299434060E63BF889214940
36069	20568	39.290773999999999	39.349659000000003	50.272151000000001	50.249197000000002	Юбилейная	0103000020E6100000010000000500000078431A1538A5434073A1F2AFE51F494078431A1538A543406F490ED8D522494044E048A0C1AC43406F490ED8D522494044E048A0C1AC434073A1F2AFE51F494078431A1538A5434073A1F2AFE51F4940
37185	54403	39.073067999999999	39.090684000000003	50.396731000000003	50.383108999999997	Школьная	0103000020E610000001000000050000002B31CF4A5A894340D1E638B7093149402B31CF4A5A8943409A27D714C83249409F2287889B8B43409A27D714C83249409F2287889B8B4340D1E638B7093149402B31CF4A5A894340D1E638B709314940
36593	20658	39.156440000000003	39.174281000000001	50.194693000000001	50.179403000000001	38 Стрелковой Дивизии	0103000020E61000000100000005000000A4E4D53906944340F3E670ADF6164940A4E4D539069443404CE141B3EB18494037A8FDD64E9643404CE141B3EB18494037A8FDD64E964340F3E670ADF6164940A4E4D53906944340F3E670ADF6164940
36711	54347	39.055442999999997	39.121513999999998	50.461314999999999	50.443528999999998	Молодежная	0103000020E6100000010000000500000064E597C118874340EEE9EA8EC538494064E597C118874340BE13B35E0C3B4940C90050C58D8F4340BE13B35E0C3B4940C90050C58D8F4340EEE9EA8EC538494064E597C118874340EEE9EA8EC5384940
36692	54333	39.190764999999999	39.232661999999998	50.438096000000002	50.410418	Школьная	0103000020E61000000100000005000000581CCEFC6A98434049D8B79388344940581CCEFC6A98434014419C8713384940CF8250DEC79D434014419C8713384940CF8250DEC79D434049D8B79388344940581CCEFC6A98434049D8B79388344940
35863	47833	39.305847999999997	39.353971000000001	50.282611000000003	50.264822000000002	Зеленая	0103000020E6100000010000000500000004C6FA0626A7434073A1F2AFE521494004C6FA0626A74340B43EE5982C244940C05DF6EB4EAD4340B43EE5982C244940C05DF6EB4EAD434073A1F2AFE521494004C6FA0626A7434073A1F2AFE5214940
37219	54428	39.382465000000003	39.401131999999997	50.339193999999999	50.327108000000003	Ленина	0103000020E61000000100000005000000AD6EF59CF4B043404721C9ACDE294940AD6EF59CF4B04340ED7F80B56A2B494085B01A4B58B34340ED7F80B56A2B494085B01A4B58B343404721C9ACDE294940AD6EF59CF4B043404721C9ACDE294940
37226	54430	39.144717	39.191240999999998	50.307274999999997	50.287641999999998	Молодежная	0103000020E610000001000000050000006E162F16869243405F7AFB73D12449406E162F16869243406FF085C954274940C153C8957A9843406FF085C954274940C153C8957A9843405F7AFB73D12449406E162F16869243405F7AFB73D1244940
36204	47145	39.296595000000003	39.331243999999998	50.315674000000001	50.281160999999997	Победы	0103000020E610000001000000050000001D9430D3F6A5434090F46915FD2349401D9430D3F6A543404819710168284940847F113466AA43404819710168284940847F113466AA434090F46915FD2349401D9430D3F6A5434090F46915FD234940
36209	54287	39.260043000000003	39.300530000000002	50.275323999999998	50.258648999999998	Школьная	0103000020E61000000100000005000000E146CA1649A14340511212691B214940E146CA1649A14340E6E61BD13D234940C3BB5CC477A64340E6E61BD13D234940C3BB5CC477A64340511212691B214940E146CA1649A14340511212691B214940
35803	38561	33.663296000000003	33.671182999999999	56.090322	56.078643	Дерезовская	0103000020E61000000100000005000000A8C821E2E6D4404098874CF9100A4C40A8C821E2E6D44040FE0DDAAB8F0B4C40CA501553E9D54040FE0DDAAB8F0B4C40CA501553E9D5404098874CF9100A4C40A8C821E2E6D4404098874CF9100A4C40
37048	9177	41.112791000000001	41.171784000000002	51.371671999999997	51.315945999999997	Свобода	0103000020E610000001000000050000003E247CEF6F8E4440A8A624EB70A849403E247CEF6F8E4440616BB6F292AF4940F0FCA204FD954440616BB6F292AF4940F0FCA204FD954440A8A624EB70A849403E247CEF6F8E4440A8A624EB70A84940
36505	15793	41.316986999999997	41.347951999999999	50.936830999999998	50.917845999999997	Советская	0103000020E61000000100000005000000EA20AF0793A84440D8614CFA7B754940EA20AF0793A8444082700514EA774940F549EEB089AC444082700514EA774940F549EEB089AC4440D8614CFA7B754940EA20AF0793A84440D8614CFA7B754940
37043	20083	41.091546000000001	41.104320000000001	50.916226999999999	50.907100999999997	Лесная	0103000020E61000000100000005000000310A82C7B78B44409E95B4E21B744940310A82C7B78B4440295B24ED46754940CC28965B5A8D4440295B24ED46754940CC28965B5A8D44409E95B4E21B744940310A82C7B78B44409E95B4E21B744940
36504	46830	41.407069999999997	41.519351	51.326883000000002	51.226146999999997	Советская	0103000020E610000001000000050000006397A8DE1AB44440548B8862F29C49406397A8DE1AB44440274F594DD7A949408C12F4177AC24440274F594DD7A949408C12F4177AC24440548B8862F29C49406397A8DE1AB44440548B8862F29C4940
37191	46830	41.407069999999997	41.519351	51.326883000000002	51.226146999999997	Сельская	0103000020E610000001000000050000006397A8DE1AB44440548B8862F29C49406397A8DE1AB44440274F594DD7A949408C12F4177AC24440274F594DD7A949408C12F4177AC24440548B8862F29C49406397A8DE1AB44440548B8862F29C4940
36402	19958	41.068468000000003	41.110007000000003	51.093452999999997	51.060841000000003	Центральная	0103000020E610000001000000050000004969368FC3884440C3A04CA3C98749404969368FC3884440465B9544F68B494061AA99B5148E4440465B9544F68B494061AA99B5148E4440C3A04CA3C98749404969368FC3884440C3A04CA3C9874940
77122	61069	41.079096	41.107796999999998	50.990892000000002	50.973280000000003	Административная	0103000020E61000000100000005000000499F56D11F8A4440EAEC6470947C4940499F56D11F8A44401CEF8E8CD57E4940AFCDC64ACC8D44401CEF8E8CD57E4940AFCDC64ACC8D4440EAEC6470947C4940499F56D11F8A4440EAEC6470947C4940
37155	47173	41.453989	41.499749999999999	51.112490000000001	51.085957000000001	Верхняя	0103000020E6100000010000000500000033DFC14F1CBA44405FEE93A3008B494033DFC14F1CBA444043908312668E49408716D9CEF7BF444043908312668E49408716D9CEF7BF44405FEE93A3008B494033DFC14F1CBA44405FEE93A3008B4940
36627	18594	41.473061000000001	41.535331999999997	51.047434000000003	51.000512999999998	Советская	0103000020E61000000100000005000000AC014A438DBC4440861C5BCF10804940AC014A438DBC4440F75B3B51128649404A404CC285C44440F75B3B51128649404A404CC285C44440861C5BCF10804940AC014A438DBC4440861C5BCF10804940
36449	18816	41.747577	41.766979999999997	51.082991999999997	51.073123000000002	Приозерный переулок	0103000020E61000000100000005000000F31E679AB0DF4440EFCA2E185C894940F31E679AB0DF444031EA5A7B9F8A4940D15790662CE2444031EA5A7B9F8A4940D15790662CE24440EFCA2E185C894940F31E679AB0DF4440EFCA2E185C894940
37110	47500	41.295014999999999	41.369107999999997	51.150647999999997	51.130783999999998	Центральная	0103000020E610000001000000050000002B6A300DC3A54440876BB587BD9049402B6A300DC3A54440999A046F48934940925852EE3EAF4440999A046F48934940925852EE3EAF4440876BB587BD9049402B6A300DC3A54440876BB587BD904940
36098	54282	41.122034999999997	41.159045999999996	51.385626000000002	51.366376000000002	Школьная	0103000020E61000000100000005000000D2FBC6D79E8F44400805A568E5AE4940D2FBC6D79E8F4440603E59315CB14940A1478C9E5B944440603E59315CB14940A1478C9E5B9444400805A568E5AE4940D2FBC6D79E8F44400805A568E5AE4940
36969	54282	41.122034999999997	41.159045999999996	51.385626000000002	51.366376000000002	Октябрьская	0103000020E61000000100000005000000D2FBC6D79E8F44400805A568E5AE4940D2FBC6D79E8F4440603E59315CB14940A1478C9E5B944440603E59315CB14940A1478C9E5B9444400805A568E5AE4940D2FBC6D79E8F44400805A568E5AE4940
36893	47263	41.808275999999999	41.835441000000003	51.197535000000002	51.182310000000001	Проезжая	0103000020E610000001000000050000002312859675E74440ECDD1FEF559749402312859675E744405E68AED348994940685E0EBBEFEA44405E68AED348994940685E0EBBEFEA4440ECDD1FEF559749402312859675E74440ECDD1FEF55974940
36097	18049	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	переулок Пушкина	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
36070	18049	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	железнодорожная	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
36099	18049	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	Шолохова	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
36443	18049	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	Клиническая	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
9858	18049	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	Железнодорожная	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
35807	18049	41.52713	41.641252000000001	51.110613000000001	51.064492000000001	25 Октября	0103000020E61000000100000005000000C85EEFFE78C34440446D1B4641884940C85EEFFE78C3444098C11891288E49404F3FA88B14D2444098C11891288E49404F3FA88B14D24440446D1B4641884940C85EEFFE78C34440446D1B4641884940
36760	47428	41.290703000000001	41.324173999999999	51.262096999999997	51.235289000000002	Калинина	0103000020E61000000100000005000000AFEC82C135A54440E50D30F31D9E4940AFEC82C135A544409AB0FD648CA14940541B9C887EA944409AB0FD648CA14940541B9C887EA94440E50D30F31D9E4940AFEC82C135A54440E50D30F31D9E4940
36676	19076	41.437128000000001	41.491880000000002	51.151466999999997	51.116453999999997	Курортная	0103000020E610000001000000050000003C1570CFF3B7444083BEF4F6E78E49403C1570CFF3B744402CB64945639349403BC780ECF5BE44402CB64945639349403BC780ECF5BE444083BEF4F6E78E49403C1570CFF3B7444083BEF4F6E78E4940
37108	47446	41.250808999999997	41.281432000000002	51.291817999999999	51.276190999999997	Центральная	0103000020E610000001000000050000006F4562821AA044408A39083A5AA349406F4562821AA044402B31CF4A5AA549402106BAF605A444402B31CF4A5AA549402106BAF605A444408A39083A5AA349406F4562821AA044408A39083A5AA34940
36090	47385	41.425773	41.506936000000003	51.193516000000002	51.151394000000003	Советская	0103000020E610000001000000050000008942CBBA7FB64440C367EBE0609349408942CBBA7FB644405AA0DD21C598494021956247E3C044405AA0DD21C598494021956247E3C04440C367EBE0609349408942CBBA7FB64440C367EBE060934940
36737	54360	41.614294000000001	41.665551999999998	51.040723	51.020574000000003	Онысюка	0103000020E610000001000000050000008410902FA1CE4440EF92382BA28249408410902FA1CE4440F698486936854940C9E4D4CE30D54440F698486936854940C9E4D4CE30D54440EF92382BA28249408410902FA1CE4440EF92382BA2824940
36440	19864	41.113850999999997	41.166249999999998	51.171536000000003	51.142201	проспект Кольцова	0103000020E61000000100000005000000F6CE68AB928E4440B03A72A433924940F6CE68AB928E4440180B43E4F4954940E17A14AE47954440180B43E4F4954940E17A14AE47954440B03A72A433924940F6CE68AB928E4440B03A72A433924940
36087	19864	41.113850999999997	41.166249999999998	51.171536000000003	51.142201	Центральная	0103000020E61000000100000005000000F6CE68AB928E4440B03A72A433924940F6CE68AB928E4440180B43E4F4954940E17A14AE47954440180B43E4F4954940E17A14AE47954440B03A72A433924940F6CE68AB928E4440B03A72A433924940
36535	19376	41.171002000000001	41.275288000000003	51.164504999999998	51.106896999999996	проспект Революции	0103000020E610000001000000050000007AC6BE64E39544402F8507CDAE8D49407AC6BE64E3954440A583F57F0E9549409A7D1EA33CA34440A583F57F0E9549409A7D1EA33CA344402F8507CDAE8D49407AC6BE64E39544402F8507CDAE8D4940
35854	19376	41.171002000000001	41.275288000000003	51.164504999999998	51.106896999999996	крейзера	0103000020E610000001000000050000007AC6BE64E39544402F8507CDAE8D49407AC6BE64E3954440A583F57F0E9549409A7D1EA33CA34440A583F57F0E9549409A7D1EA33CA344402F8507CDAE8D49407AC6BE64E39544402F8507CDAE8D4940
36433	19376	41.171002000000001	41.275288000000003	51.164504999999998	51.106896999999996	Мостовая	0103000020E610000001000000050000007AC6BE64E39544402F8507CDAE8D49407AC6BE64E3954440A583F57F0E9549409A7D1EA33CA34440A583F57F0E9549409A7D1EA33CA344402F8507CDAE8D49407AC6BE64E39544402F8507CDAE8D4940
36826	47266	41.713171000000003	41.733383000000003	51.219495999999999	51.196987	Лесная	0103000020E6100000010000000500000052BAF42F49DB44405B5EB9DE3699494052BAF42F49DB444029CDE671189C4940A038807EDFDD444029CDE671189C4940A038807EDFDD44405B5EB9DE3699494052BAF42F49DB44405B5EB9DE36994940
36827	19653	41.280929	41.324703999999997	51.015321	50.988880000000002	Школьный переулок	0103000020E61000000100000005000000BEBF417BF5A3444091D5AD9E937E4940BEBF417BF5A3444094F8DC09F6814940B07092E68FA9444094F8DC09F6814940B07092E68FA9444091D5AD9E937E4940BEBF417BF5A3444091D5AD9E937E4940
36948	19256	41.330471000000003	41.356476999999998	51.224330000000002	51.209074999999999	Спортивная	0103000020E6100000010000000500000062A3ACDF4CAA4440A2B437F8C29A494062A3ACDF4CAA44407FC16ED8B69C49405A63D009A1AD44407FC16ED8B69C49405A63D009A1AD4440A2B437F8C29A494062A3ACDF4CAA4440A2B437F8C29A4940
37311	54462	41.168846000000002	41.176841000000003	51.040219	51.037092999999999	Центральная	0103000020E61000000100000005000000BC07E8BE9C9544408CF4A276BF844940BC07E8BE9C954440C3D66CE525854940C5CBD3B9A2964440C3D66CE525854940C5CBD3B9A29644408CF4A276BF844940BC07E8BE9C9544408CF4A276BF844940
36399	47330	41.640444000000002	41.685063	51.216619000000001	51.190489999999997	Центральная	0103000020E61000000100000005000000B075A911FAD14440861BF0F961984940B075A911FAD144409B58E02BBA9B49408E59F624B0D744409B58E02BBA9B49408E59F624B0D74440861BF0F961984940B075A911FAD14440861BF0F961984940
36866	54371	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	Подлесная	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
36697	54337	39.554124999999999	39.608778000000001	51.679074	51.634531000000003	Молодежная	0103000020E61000000100000005000000B0726891EDC643402BA6D24F38D14940B0726891EDC643402EC896E5EBD649401C430070ECCD43402EC896E5EBD649401C430070ECCD43402BA6D24F38D14940B0726891EDC643402BA6D24F38D14940
36626	17575	39.79101	39.826538999999997	51.622953000000003	51.602299000000002	Буденного	0103000020E610000001000000050000008C67D0D03FE54340EEB4352218CD49408C67D0D03FE54340F9F884ECBCCF49402CEFAA07CCE94340F9F884ECBCCF49402CEFAA07CCE94340EEB4352218CD49408C67D0D03FE54340EEB4352218CD4940
36424	46794	39.704287000000001	39.747369999999997	51.778381000000003	51.750461000000001	Центральная	0103000020E61000000100000005000000BDFF8F1326DA434034F6251B0FE04940BDFF8F1326DA4340F56915FDA1E349407901F6D1A9DF4340F56915FDA1E349407901F6D1A9DF434034F6251B0FE04940BDFF8F1326DA434034F6251B0FE04940
36964	46726	39.625235000000004	39.668768	51.581937000000003	51.571190000000001	Тимирязева	0103000020E6100000010000000500000044A852B307D04340B0E600C11CC9494044A852B307D043408BAA5FE97CCA4940404E98309AD543408BAA5FE97CCA4940404E98309AD54340B0E600C11CC9494044A852B307D04340B0E600C11CC94940
36316	54305	39.282043000000002	39.307690000000001	51.513903999999997	51.495016999999997	Воронежская	0103000020E610000001000000050000006A882AFC19A4434065FB90B75CBF49406A882AFC19A443404CA4349BC7C1494033A7CB6262A743404CA4349BC7C1494033A7CB6262A7434065FB90B75CBF49406A882AFC19A4434065FB90B75CBF4940
36397	17706	39.507933000000001	39.587865000000001	51.634537000000002	51.602550000000001	Центральная	0103000020E6100000010000000500000093C7D3F203C14340371AC05B20CD494093C7D3F203C143400D8D278238D1494045BB0A293FCB43400D8D278238D1494045BB0A293FCB4340371AC05B20CD494093C7D3F203C14340371AC05B20CD4940
36398	17023	39.657997000000002	39.723933000000002	51.675995999999998	51.618372999999998	Советская	0103000020E61000000100000005000000DDEEE53E39D443405DDDB1D826CF4940DDEEE53E39D44340081D740987D6494062BF27D6A9DC4340081D740987D6494062BF27D6A9DC43405DDDB1D826CF4940DDEEE53E39D443405DDDB1D826CF4940
36510	17023	39.657997000000002	39.723933000000002	51.675995999999998	51.618372999999998	Механизаторов	0103000020E61000000100000005000000DDEEE53E39D443405DDDB1D826CF4940DDEEE53E39D44340081D740987D6494062BF27D6A9DC4340081D740987D6494062BF27D6A9DC43405DDDB1D826CF4940DDEEE53E39D443405DDDB1D826CF4940
36395	17023	39.657997000000002	39.723933000000002	51.675995999999998	51.618372999999998	Карла Маркса	0103000020E61000000100000005000000DDEEE53E39D443405DDDB1D826CF4940DDEEE53E39D44340081D740987D6494062BF27D6A9DC4340081D740987D6494062BF27D6A9DC43405DDDB1D826CF4940DDEEE53E39D443405DDDB1D826CF4940
36625	19575	39.522880999999998	39.598860999999999	51.542161	51.491287999999997	Ворошилова	0103000020E610000001000000050000009259BDC3EDC2434068757286E2BE49409259BDC3EDC2434055151A8865C54940C8EC2C7AA7CC434055151A8865C54940C8EC2C7AA7CC434068757286E2BE49409259BDC3EDC2434068757286E2BE4940
36624	46249	39.507061999999998	39.537909999999997	51.597532000000001	51.573988999999997	Центральная	0103000020E61000000100000005000000AD855968E7C04340C2A1B77878C94940AD855968E7C043402028B7ED7BCC49407E18213CDAC443402028B7ED7BCC49407E18213CDAC44340C2A1B77878C94940AD855968E7C04340C2A1B77878C94940
37246	54446	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	Молодежная	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
36234	54294	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	Ленина	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
36276	54303	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	Ленина	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
35980	46497	39.564365000000002	39.621920000000003	51.785685000000001	51.724553999999998	Свободы	0103000020E61000000100000005000000E700C11C3DC84340CE177B2FBEDC4940E700C11C3DC8434098FA795391E449403A5D16139BCF434098FA795391E449403A5D16139BCF4340CE177B2FBEDC4940E700C11C3DC84340CE177B2FBEDC4940
36154	46497	39.564365000000002	39.621920000000003	51.785685000000001	51.724553999999998	Мира	0103000020E61000000100000005000000E700C11C3DC84340CE177B2FBEDC4940E700C11C3DC8434098FA795391E449403A5D16139BCF434098FA795391E449403A5D16139BCF4340CE177B2FBEDC4940E700C11C3DC84340CE177B2FBEDC4940
36949	46497	39.564365000000002	39.621920000000003	51.785685000000001	51.724553999999998	Анатолия Гуцало	0103000020E61000000100000005000000E700C11C3DC84340CE177B2FBEDC4940E700C11C3DC8434098FA795391E449403A5D16139BCF434098FA795391E449403A5D16139BCF4340CE177B2FBEDC4940E700C11C3DC84340CE177B2FBEDC4940
35942	15894	39.356594000000001	39.460852000000003	51.663440000000001	51.601089999999999	Школьная	0103000020E6100000010000000500000094F947DFA4AD4340F0F96184F0CC494094F947DFA4AD4340DB6D179AEBD44940EA25C632FDBA4340DB6D179AEBD44940EA25C632FDBA4340F0F96184F0CC494094F947DFA4AD4340F0F96184F0CC4940
35858	15894	39.356594000000001	39.460852000000003	51.663440000000001	51.601089999999999	Советская	0103000020E6100000010000000500000094F947DFA4AD4340F0F96184F0CC494094F947DFA4AD4340DB6D179AEBD44940EA25C632FDBA4340DB6D179AEBD44940EA25C632FDBA4340F0F96184F0CC494094F947DFA4AD4340F0F96184F0CC4940
35925	15894	39.356594000000001	39.460852000000003	51.663440000000001	51.601089999999999	Полевая	0103000020E6100000010000000500000094F947DFA4AD4340F0F96184F0CC494094F947DFA4AD4340DB6D179AEBD44940EA25C632FDBA4340DB6D179AEBD44940EA25C632FDBA4340F0F96184F0CC494094F947DFA4AD4340F0F96184F0CC4940
35726	15894	39.356594000000001	39.460852000000003	51.663440000000001	51.601089999999999	Песоцкая	0103000020E6100000010000000500000094F947DFA4AD4340F0F96184F0CC494094F947DFA4AD4340DB6D179AEBD44940EA25C632FDBA4340DB6D179AEBD44940EA25C632FDBA4340F0F96184F0CC494094F947DFA4AD4340F0F96184F0CC4940
35738	15894	39.356594000000001	39.460852000000003	51.663440000000001	51.601089999999999	Ленина	0103000020E6100000010000000500000094F947DFA4AD4340F0F96184F0CC494094F947DFA4AD4340DB6D179AEBD44940EA25C632FDBA4340DB6D179AEBD44940EA25C632FDBA4340F0F96184F0CC494094F947DFA4AD4340F0F96184F0CC4940
36169	15894	39.356594000000001	39.460852000000003	51.663440000000001	51.601089999999999	Заречная	0103000020E6100000010000000500000094F947DFA4AD4340F0F96184F0CC494094F947DFA4AD4340DB6D179AEBD44940EA25C632FDBA4340DB6D179AEBD44940EA25C632FDBA4340F0F96184F0CC494094F947DFA4AD4340F0F96184F0CC4940
36566	16795	39.849868000000001	39.892995999999997	51.691871999999996	51.677436999999998	Ленина	0103000020E610000001000000050000005EF58079C8EC4340D80C7041B6D649405EF58079C8EC43405182FE428FD84940BABA63B14DF243405182FE428FD84940BABA63B14DF24340D80C7041B6D649405EF58079C8EC4340D80C7041B6D64940
37107	46563	39.637667999999998	39.675306999999997	51.781500999999999	51.769258000000001	Буденного	0103000020E6100000010000000500000055DAE21A9FD14340DB17D00B77E2494055DAE21A9FD1434049658A3908E4494043E1B37570D6434049658A3908E4494043E1B37570D64340DB17D00B77E2494055DAE21A9FD14340DB17D00B77E24940
36607	46761	39.640884	39.686698	51.523862999999999	51.501044	Центральная	0103000020E61000000100000005000000CC43A67C08D24340B3EDB43522C04940CC43A67C08D24340CF4A5AF10DC34940431D56B8E5D74340CF4A5AF10DC34940431D56B8E5D74340B3EDB43522C04940CC43A67C08D24340B3EDB43522C04940
37040	17420	39.719414999999998	39.764097	51.562590999999998	51.537585	70 Лет Октября	0103000020E610000001000000050000003CA06CCA15DC4340FBE8D495CFC449403CA06CCA15DC434010035DFB02C8494061FC34EECDE1434010035DFB02C8494061FC34EECDE14340FBE8D495CFC449403CA06CCA15DC4340FBE8D495CFC44940
36129	17851	39.469152999999999	39.553127000000003	51.779249999999998	51.738638000000002	Школьная	0103000020E61000000100000005000000FFE89B340DBC43409BCAA2B08BDE4940FFE89B340DBC434039B4C876BEE349406EC493DDCCC6434039B4C876BEE349406EC493DDCCC643409BCAA2B08BDE4940FFE89B340DBC43409BCAA2B08BDE4940
36128	17851	39.469152999999999	39.553127000000003	51.779249999999998	51.738638000000002	Садовая	0103000020E61000000100000005000000FFE89B340DBC43409BCAA2B08BDE4940FFE89B340DBC434039B4C876BEE349406EC493DDCCC6434039B4C876BEE349406EC493DDCCC643409BCAA2B08BDE4940FFE89B340DBC43409BCAA2B08BDE4940
36052	17851	39.469152999999999	39.553127000000003	51.779249999999998	51.738638000000002	 Студенческая	0103000020E61000000100000005000000FFE89B340DBC43409BCAA2B08BDE4940FFE89B340DBC434039B4C876BEE349406EC493DDCCC6434039B4C876BEE349406EC493DDCCC643409BCAA2B08BDE4940FFE89B340DBC43409BCAA2B08BDE4940
37261	54454	38.392558000000001	38.416561000000002	51.437869999999997	51.422415999999998	Полевая	0103000020E610000001000000050000003FE42D573F32434050A73CBA11B649403FE42D573F32434023F3C81F0CB8494000E5EFDE5135434023F3C81F0CB8494000E5EFDE5135434050A73CBA11B649403FE42D573F32434050A73CBA11B64940
36713	54342	38.309705999999998	38.335200999999998	51.429873999999998	51.415137000000001	Садовая	0103000020E61000000100000005000000FFAF3A72A4274340062E8F3523B54940FFAF3A72A42743404AB3791C06B74940124BCADDE72A43404AB3791C06B74940124BCADDE72A4340062E8F3523B54940FFAF3A72A4274340062E8F3523B54940
36997	15103	38.481931000000003	38.538642000000003	51.286360000000002	51.201497000000003	Ленина	0103000020E61000000100000005000000DCF63DEAAF3D4340FE9E58A7CA994940DCF63DEAAF3D4340F870C971A7A4494043209738F2444340F870C971A7A4494043209738F2444340FE9E58A7CA994940DCF63DEAAF3D4340FE9E58A7CA994940
36421	14899	38.433861999999998	38.521808	51.409429000000003	51.351449000000002	Школьный переулок	0103000020E61000000100000005000000137D3ECA88374340209BE447FCAC4940137D3ECA883743405A84622B68B449404565C39ACA4243405A84622B68B449404565C39ACA424340209BE447FCAC4940137D3ECA88374340209BE447FCAC4940
37104	14899	38.433861999999998	38.521808	51.409429000000003	51.351449000000002	Первомайская	0103000020E61000000100000005000000137D3ECA88374340209BE447FCAC4940137D3ECA883743405A84622B68B449404565C39ACA4243405A84622B68B449404565C39ACA424340209BE447FCAC4940137D3ECA88374340209BE447FCAC4940
36994	14899	38.433861999999998	38.521808	51.409429000000003	51.351449000000002	Автоматчиков	0103000020E61000000100000005000000137D3ECA88374340209BE447FCAC4940137D3ECA883743405A84622B68B449404565C39ACA4243405A84622B68B449404565C39ACA424340209BE447FCAC4940137D3ECA88374340209BE447FCAC4940
36393	45521	38.313982000000003	38.400866999999998	51.517238999999996	51.467426000000003	Меркулова	0103000020E610000001000000050000002FC4EA8F302843406AA67B9DD4BB49402FC4EA8F302843409D9B36E334C24940D7851F9C4F3343409D9B36E334C24940D7851F9C4F3343406AA67B9DD4BB49402FC4EA8F302843406AA67B9DD4BB4940
36891	15021	38.391345000000001	38.432614000000001	51.299990000000001	51.287035000000003	Центральная	0103000020E61000000100000005000000003ACC971732434058E71890BDA44940003ACC97173243404390831266A6494058E542E55F3743404390831266A6494058E542E55F37434058E71890BDA44940003ACC971732434058E71890BDA44940
36748	14249	38.362113999999998	38.447615999999996	51.670394000000002	51.603265999999998	Советская	0103000020E610000001000000050000003DB665C0592E4340F564FED137CD49403DB665C0592E4340A2B77878CFD549404A95287B4B394340A2B77878CFD549404A95287B4B394340F564FED137CD49403DB665C0592E4340F564FED137CD4940
36945	14629	38.501379999999997	38.687637000000002	51.577537999999997	51.509794999999997	Чапаева	0103000020E610000001000000050000002A6F47382D40434008556AF640C149402A6F47382D4043403F19E3C3ECC9494081423D7D045843403F19E3C3ECC9494081423D7D0458434008556AF640C149402A6F47382D40434008556AF640C14940
37038	14629	38.501379999999997	38.687637000000002	51.577537999999997	51.509794999999997	Проспект Труда	0103000020E610000001000000050000002A6F47382D40434008556AF640C149402A6F47382D4043403F19E3C3ECC9494081423D7D045843403F19E3C3ECC9494081423D7D0458434008556AF640C149402A6F47382D40434008556AF640C14940
36741	54329	38.249240999999998	38.282702999999998	51.637873999999996	51.619928000000002	Чагадаева	0103000020E6100000010000000500000042E90B21E71F4340F6EFFACC59CF494042E90B21E71F4340FE7BF0DAA5D1494094BDA59C2F244340FE7BF0DAA5D1494094BDA59C2F244340F6EFFACC59CF494042E90B21E71F4340F6EFFACC59CF4940
36687	54329	38.249240999999998	38.282702999999998	51.637873999999996	51.619928000000002	Мира	0103000020E6100000010000000500000042E90B21E71F4340F6EFFACC59CF494042E90B21E71F4340FE7BF0DAA5D1494094BDA59C2F244340FE7BF0DAA5D1494094BDA59C2F244340F6EFFACC59CF494042E90B21E71F4340F6EFFACC59CF4940
35992	13762	38.302106999999999	38.445324999999997	51.693418000000001	51.495420000000003	площадь Ленина	0103000020E6100000010000000500000043723271AB26434065E42CEC69BF494043723271AB264340973AC8EBC1D84940AC8BDB6800394340973AC8EBC1D84940AC8BDB680039434065E42CEC69BF494043723271AB26434065E42CEC69BF4940
36942	13762	38.302106999999999	38.445324999999997	51.693418000000001	51.495420000000003	Центральная	0103000020E6100000010000000500000043723271AB26434065E42CEC69BF494043723271AB264340973AC8EBC1D84940AC8BDB6800394340973AC8EBC1D84940AC8BDB680039434065E42CEC69BF494043723271AB26434065E42CEC69BF4940
35721	13762	38.302106999999999	38.445324999999997	51.693418000000001	51.495420000000003	Луговая	0103000020E6100000010000000500000043723271AB26434065E42CEC69BF494043723271AB264340973AC8EBC1D84940AC8BDB6800394340973AC8EBC1D84940AC8BDB680039434065E42CEC69BF494043723271AB26434065E42CEC69BF4940
37156	13762	38.302106999999999	38.445324999999997	51.693418000000001	51.495420000000003	Заводская	0103000020E6100000010000000500000043723271AB26434065E42CEC69BF494043723271AB264340973AC8EBC1D84940AC8BDB6800394340973AC8EBC1D84940AC8BDB680039434065E42CEC69BF494043723271AB26434065E42CEC69BF4940
36946	45587	38.532749000000003	38.577044999999998	51.496490999999999	51.445425999999998	Садовая	0103000020E6100000010000000500000005FD851E31444340E0641BB803B9494005FD851E3144434011E15F048DBF494000A94D9CDC49434011E15F048DBF494000A94D9CDC494340E0641BB803B9494005FD851E31444340E0641BB803B94940
37271	46263	38.330170000000003	38.361961000000001	51.341822999999998	51.325077	Чапаева	0103000020E61000000100000005000000670FB402432A434045D7851F9CA94940670FB402432A4340A30227DBC0AB4940B7B6F0BC542E4340A30227DBC0AB4940B7B6F0BC542E434045D7851F9CA94940670FB402432A434045D7851F9CA94940
36944	19644	38.236449	38.359338000000001	51.616466000000003	51.578456000000003	Заречная	0103000020E610000001000000050000000116F9F5431E43406616A1D80ACA49400116F9F5431E4340488C9E5BE8CE4940E31A9FC9FE2D4340488C9E5BE8CE4940E31A9FC9FE2D43406616A1D80ACA49400116F9F5431E43406616A1D80ACA4940
36388	45349	38.555152999999997	38.608288000000002	51.656618000000002	51.636153	Школьная	0103000020E610000001000000050000005DA3E5400F4743404B2025766DD149405DA3E5400F47434083FB010F0CD449404E469561DC4D434083FB010F0CD449404E469561DC4D43404B2025766DD149405DA3E5400F4743404B2025766DD14940
36509	45349	38.555152999999997	38.608288000000002	51.656618000000002	51.636153	Гагарина	0103000020E610000001000000050000005DA3E5400F4743404B2025766DD149405DA3E5400F47434083FB010F0CD449404E469561DC4D434083FB010F0CD449404E469561DC4D43404B2025766DD149405DA3E5400F4743404B2025766DD14940
36941	45431	38.445324999999997	38.576873999999997	51.514845999999999	51.491658000000001	Октября	0103000020E61000000100000005000000AC8BDB68003943408C683BA6EEBE4940AC8BDB6800394340FB3C4679E6C14940D3F4D901D7494340FB3C4679E6C14940D3F4D901D74943408C683BA6EEBE4940AC8BDB68003943408C683BA6EEBE4940
37035	45431	38.445324999999997	38.576873999999997	51.514845999999999	51.491658000000001	Мира	0103000020E61000000100000005000000AC8BDB68003943408C683BA6EEBE4940AC8BDB6800394340FB3C4679E6C14940D3F4D901D7494340FB3C4679E6C14940D3F4D901D74943408C683BA6EEBE4940AC8BDB68003943408C683BA6EEBE4940
37032	13870	38.437510000000003	38.490681000000002	51.609738	51.524366999999998	Мира	0103000020E6100000010000000500000024D6E25300384340020D36751EC3494024D6E25300384340719010E50BCE494061E28FA2CE3E4340719010E50BCE494061E28FA2CE3E4340020D36751EC3494024D6E25300384340020D36751EC34940
36993	13870	38.437510000000003	38.490681000000002	51.609738	51.524366999999998	Загорского	0103000020E6100000010000000500000024D6E25300384340020D36751EC3494024D6E25300384340719010E50BCE494061E28FA2CE3E4340719010E50BCE494061E28FA2CE3E4340020D36751EC3494024D6E25300384340020D36751EC34940
37248	54412	38.534877999999999	38.630772999999998	51.651980000000002	51.577537999999997	Молодежная	0103000020E61000000100000005000000C9ACDEE1764443403F19E3C3ECC94940C9ACDEE176444340B3D2A41474D3494093196F2BBD504340B3D2A41474D3494093196F2BBD5043403F19E3C3ECC94940C9ACDEE1764443403F19E3C3ECC94940
37197	54412	38.534877999999999	38.630772999999998	51.651980000000002	51.577537999999997	Мира	0103000020E61000000100000005000000C9ACDEE1764443403F19E3C3ECC94940C9ACDEE176444340B3D2A41474D3494093196F2BBD504340B3D2A41474D3494093196F2BBD5043403F19E3C3ECC94940C9ACDEE1764443403F19E3C3ECC94940
37260	54412	38.534877999999999	38.630772999999998	51.651980000000002	51.577537999999997	Кирова	0103000020E61000000100000005000000C9ACDEE1764443403F19E3C3ECC94940C9ACDEE176444340B3D2A41474D3494093196F2BBD504340B3D2A41474D3494093196F2BBD5043403F19E3C3ECC94940C9ACDEE1764443403F19E3C3ECC94940
36572	48978	39.721696000000001	39.752355999999999	50.948470999999998	50.927219999999998	Советская	0103000020E61000000100000005000000B7D3D68860DC43403B191C25AF764940B7D3D68860DC43402A1A6B7F6779494085798F334DE043402A1A6B7F6779494085798F334DE043403B191C25AF764940B7D3D68860DC43403B191C25AF764940
37041	54388	39.214300999999999	39.251930999999999	51.093594000000003	51.071176000000001	Буденного	0103000020E61000000100000005000000034015376E9B43404B21904B1C894940034015376E9B4340098D60E3FA8B49409EEC66463FA04340098D60E3FA8B49409EEC66463FA043404B21904B1C894940034015376E9B43404B21904B1C894940
36508	13499	39.496586999999998	39.535511	51.223022	51.198397999999997	Советская	0103000020E61000000100000005000000334FAE2990BF4340C0CB0C1B65994940334FAE2990BF4340EE2422FC8B9C4940FAD2DB9F8BC44340EE2422FC8B9C4940FAD2DB9F8BC44340C0CB0C1B65994940334FAE2990BF4340C0CB0C1B65994940
37030	12624	39.649687	39.671039999999998	51.134656	51.095806000000003	Центральная	0103000020E6100000010000000500000074D190F128D343405B61FA5E438C494074D190F128D34340E71A66683C914940672783A3E4D54340E71A66683C914940672783A3E4D543405B61FA5E438C494074D190F128D343405B61FA5E438C4940
36462	13118	39.278574999999996	39.332473999999998	51.199651000000003	51.161071	переулок Советский	0103000020E61000000100000005000000D93D7958A8A34340C1AA7AF99D944940D93D7958A8A343408ECEF9298E99494099620E828EAA43408ECEF9298E99494099620E828EAA4340C1AA7AF99D944940D93D7958A8A34340C1AA7AF99D944940
36065	12427	39.735098999999998	39.784002999999998	51.114835999999997	51.050203000000003	площадь Кирова	0103000020E6100000010000000500000041295AB917DE43409F94490D6D86494041295AB917DE4340A43330F2B28E4940A27BD6355AE44340A43330F2B28E4940A27BD6355AE443409F94490D6D86494041295AB917DE43409F94490D6D864940
35783	12427	39.735098999999998	39.784002999999998	51.114835999999997	51.050203000000003	Площадь Революции	0103000020E6100000010000000500000041295AB917DE43409F94490D6D86494041295AB917DE4340A43330F2B28E4940A27BD6355AE44340A43330F2B28E4940A27BD6355AE443409F94490D6D86494041295AB917DE43409F94490D6D864940
35978	12427	39.735098999999998	39.784002999999998	51.114835999999997	51.050203000000003	Зеленая	0103000020E6100000010000000500000041295AB917DE43409F94490D6D86494041295AB917DE4340A43330F2B28E4940A27BD6355AE44340A43330F2B28E4940A27BD6355AE443409F94490D6D86494041295AB917DE43409F94490D6D864940
37181	48282	39.762802999999998	39.775604000000001	51.019226000000003	51.013089000000001	Путь Ленина	0103000020E6100000010000000500000035255987A3E14340FB777DE6AC81494035255987A3E14340D09D60FF75824940CA52EBFD46E34340D09D60FF75824940CA52EBFD46E34340FB777DE6AC81494035255987A3E14340FB777DE6AC814940
37201	11685	39.216214000000001	39.367849999999997	51.154235	50.978440999999997	площадь Победы	0103000020E61000000100000005000000FB777DE6AC9B43406308008E3D7D4940FB777DE6AC9B43400473F4F8BD934940B3EA73B515AF43400473F4F8BD934940B3EA73B515AF43406308008E3D7D4940FB777DE6AC9B43406308008E3D7D4940
36390	11685	39.216214000000001	39.367849999999997	51.154235	50.978440999999997	9 мая	0103000020E61000000100000005000000FB777DE6AC9B43406308008E3D7D4940FB777DE6AC9B43400473F4F8BD934940B3EA73B515AF43400473F4F8BD934940B3EA73B515AF43406308008E3D7D4940FB777DE6AC9B43406308008E3D7D4940
36991	49078	39.410870000000003	39.442858999999999	50.863447999999998	50.849432	Центральная	0103000020E610000001000000050000002A745E6397B4434083161230BA6C49402A745E6397B44340F7E5CC76856E4940A0DE8C9AAFB84340F7E5CC76856E4940A0DE8C9AAFB8434083161230BA6C49402A745E6397B4434083161230BA6C4940
37224	54429	39.841971999999998	39.871049999999997	50.797505000000001	50.778139000000003	Мичурина	0103000020E61000000100000005000000E8120EBDC5EB4340FF5E0A0F9A634940E8120EBDC5EB4340C0B2D2A4146649402497FF907EEF4340C0B2D2A4146649402497FF907EEF4340FF5E0A0F9A634940E8120EBDC5EB4340FF5E0A0F9A634940
36564	13467	39.453684000000003	39.506891000000003	51.200198999999998	51.180734999999999	Садовая	0103000020E61000000100000005000000F75B3B5112BA43400C1F115322974940F75B3B5112BA434090D8EE1EA099494081D1E5CDE1C0434090D8EE1EA099494081D1E5CDE1C043400C1F115322974940F75B3B5112BA43400C1F115322974940
37377	46694	39.823349999999998	39.868445000000001	50.874890999999998	50.850557999999999	Административная	0103000020E61000000100000005000000AF94658863E94340F3ACA415DF6C4940AF94658863E943404948A46DFC6F4940F7AFAC3429EF43404948A46DFC6F4940F7AFAC3429EF4340F3ACA415DF6C4940AF94658863E94340F3ACA415DF6C4940
36654	54327	40.196609000000002	40.226045999999997	51.709667000000003	51.695416999999999	40 лет Октября	0103000020E61000000100000005000000B58CD47B2A1944408D0A9C6C03D94940B58CD47B2A1944407506465ED6DA494020B24813EF1C44407506465ED6DA494020B24813EF1C44408D0A9C6C03D94940B58CD47B2A1944408D0A9C6C03D94940
36795	12120	39.753407000000003	39.770707999999999	50.922342999999998	50.908118000000002	Коммунистическая	0103000020E61000000100000005000000EBC9FCA36FE043405874EB353D744940EBC9FCA36FE04340E658DE550F764940FE614B8FA6E24340E658DE550F764940FE614B8FA6E243405874EB353D744940EBC9FCA36FE043405874EB353D744940
37216	54426	39.30433	39.321756999999998	51.128145000000004	51.116996	Центральная	0103000020E6100000010000000500000089981249F4A64340A4E194B9F98E494089981249F4A64340AE122C0E67904940292158552FA94340AE122C0E67904940292158552FA94340A4E194B9F98E494089981249F4A64340A4E194B9F98E4940
37235	54437	39.540703999999998	39.585664000000001	50.951745000000003	50.939867	Кирова	0103000020E610000001000000050000007F68E6C935C5434079CBD58F4D7849407F68E6C935C54340D690B8C7D2794940E738B709F7CA4340D690B8C7D2794940E738B709F7CA434079CBD58F4D7849407F68E6C935C5434079CBD58F4D784940
36160	11784	39.693677999999998	39.737470999999999	51.010317999999998	50.968232	Победы	0103000020E6100000010000000500000033FAD170CAD843406878B306EF7B494033FAD170CAD84340B247A81952814940CC5F217365DE4340B247A81952814940CC5F217365DE43406878B306EF7B494033FAD170CAD843406878B306EF7B4940
36693	54334	39.466538999999997	39.523797000000002	51.249273000000002	51.207208000000001	Школьная	0103000020E610000001000000050000007EA7C98CB7BB43401BBCAFCA859A49407EA7C98CB7BB43404E637B2DE89F4940185FB4C70BC343404E637B2DE89F4940185FB4C70BC343401BBCAFCA859A49407EA7C98CB7BB43401BBCAFCA859A4940
36063	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	титова	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35806	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	советская	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35918	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	проспект Ленина	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36020	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	площадь Революции	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35912	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	лысенко	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36119	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Трудовые резервы	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35710	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Трудовые Резервы	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35916	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Свердлова	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35713	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Маршала Жукова	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36158	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	Громовой	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35696	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	40 лет Победы	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35909	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	40 лет Октября	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
35697	10206	39.474085000000002	39.606532000000001	51.035874999999997	50.958174	19 Партсъезда	0103000020E61000000100000005000000184339D1AEBC434052F01472A57A4940184339D1AEBC43403BDF4F8D978449401EFD2FD7A2CD43403BDF4F8D978449401EFD2FD7A2CD434052F01472A57A4940184339D1AEBC434052F01472A57A4940
36563	12272	39.313941999999997	39.358677999999998	51.012199000000003	51.001441999999997	Советская	0103000020E61000000100000005000000A06B5F402FA84340A06B5F402F804940A06B5F402FA843409F05A1BC8F814940B8E52329E9AD43409F05A1BC8F814940B8E52329E9AD4340A06B5F402F804940A06B5F402FA84340A06B5F402F804940
35913	12026	39.778587000000002	39.833644	50.853071999999997	50.820984000000003	Садовая	0103000020E610000001000000050000009E0B23BDA8E343400745F300166949409E0B23BDA8E3434010919A76316D4940D940BAD8B4EA434010919A76316D4940D940BAD8B4EA43400745F300166949409E0B23BDA8E343400745F30016694940
36647	49237	39.515065999999997	39.540928000000001	50.887030000000003	50.866711000000002	Солнечная	0103000020E6100000010000000500000009A4C4AEEDC14340AF0AD462F06E494009A4C4AEEDC143401349F4328A714940CFBEF2203DC543401349F4328A714940CFBEF2203DC54340AF0AD462F06E494009A4C4AEEDC14340AF0AD462F06E4940
35849	49068	39.385213999999998	39.407645000000002	50.903522000000002	50.868831999999998	Юбилейная	0103000020E610000001000000050000000DFB3DB14EB14340F0DB10E3356F49400DFB3DB14EB14340B79BE09BA673494060B01BB62DB44340B79BE09BA673494060B01BB62DB44340F0DB10E3356F49400DFB3DB14EB14340F0DB10E3356F4940
36093	12714	39.504277000000002	39.541845000000002	50.954802999999998	50.942041000000003	Школьная	0103000020E61000000100000005000000009013268CC04340DE3EABCC94784940009013268CC04340B48F15FC367A494025404D2D5BC54340B48F15FC367A494025404D2D5BC54340DE3EABCC94784940009013268CC04340DE3EABCC94784940
36463	49389	39.415649000000002	39.449668000000003	51.200367999999997	51.175907000000002	Колхозная	0103000020E61000000100000005000000BCCE86FC33B543409911DE1E84964940BCCE86FC33B543401C959BA8A5994940640795B88EB943401C959BA8A5994940640795B88EB943409911DE1E84964940BCCE86FC33B543409911DE1E84964940
35965	54276	39.376285000000003	39.431728999999997	51.158099	51.130400000000002	Молодежная	0103000020E61000000100000005000000D97C5C1B2AB04340FFB27BF2B0904940D97C5C1B2AB04340E14389963C9449400DDE57E542B74340E14389963C9449400DDE57E542B74340FFB27BF2B0904940D97C5C1B2AB04340FFB27BF2B0904940
36123	54276	39.376285000000003	39.431728999999997	51.158099	51.130400000000002	Ленина	0103000020E61000000100000005000000D97C5C1B2AB04340FFB27BF2B0904940D97C5C1B2AB04340E14389963C9449400DDE57E542B74340E14389963C9449400DDE57E542B74340FFB27BF2B0904940D97C5C1B2AB04340FFB27BF2B0904940
36623	49426	39.511194000000003	39.543255000000002	51.239331999999997	51.223382999999998	Придорожная	0103000020E61000000100000005000000AAF413CE6EC14340BEBD6BD0979C4940AAF413CE6EC143407171546EA29E4940BA313D6189C543407171546EA29E4940BA313D6189C54340BEBD6BD0979C4940AAF413CE6EC14340BEBD6BD0979C4940
37239	54440	39.256117000000003	39.305579000000002	50.964703	50.943430999999997	Центральная	0103000020E610000001000000050000008E791D71C8A043402B84D558C27849408E791D71C8A0434032AD4D637B7B494015AC71361DA7434032AD4D637B7B494015AC71361DA743402B84D558C27849408E791D71C8A043402B84D558C2784940
35851	45408	39.415109999999999	39.446857000000001	51.172536000000001	51.137081000000002	ленина	0103000020E610000001000000050000000C1F115322B5434095F3C5DE8B9149400C1F115322B54340FBB0DEA8159649408D7E349C32B94340FBB0DEA8159649408D7E349C32B9434095F3C5DE8B9149400C1F115322B5434095F3C5DE8B914940
36657	45408	39.415109999999999	39.446857000000001	51.172536000000001	51.137081000000002	Филипченко	0103000020E610000001000000050000000C1F115322B5434095F3C5DE8B9149400C1F115322B54340FBB0DEA8159649408D7E349C32B94340FBB0DEA8159649408D7E349C32B9434095F3C5DE8B9149400C1F115322B5434095F3C5DE8B914940
36095	45408	39.415109999999999	39.446857000000001	51.172536000000001	51.137081000000002	Октябрьская	0103000020E610000001000000050000000C1F115322B5434095F3C5DE8B9149400C1F115322B54340FBB0DEA8159649408D7E349C32B94340FBB0DEA8159649408D7E349C32B9434095F3C5DE8B9149400C1F115322B5434095F3C5DE8B914940
35852	45408	39.415109999999999	39.446857000000001	51.172536000000001	51.137081000000002	Ленина	0103000020E610000001000000050000000C1F115322B5434095F3C5DE8B9149400C1F115322B54340FBB0DEA8159649408D7E349C32B94340FBB0DEA8159649408D7E349C32B9434095F3C5DE8B9149400C1F115322B5434095F3C5DE8B914940
36419	45408	39.415109999999999	39.446857000000001	51.172536000000001	51.137081000000002	Заводская	0103000020E610000001000000050000000C1F115322B5434095F3C5DE8B9149400C1F115322B54340FBB0DEA8159649408D7E349C32B94340FBB0DEA8159649408D7E349C32B9434095F3C5DE8B9149400C1F115322B5434095F3C5DE8B914940
36603	13386	39.270670000000003	39.297215000000001	51.127189000000001	51.110460000000003	Советская	0103000020E6100000010000000500000011018750A5A2434012C2A38D238E494011018750A5A243409AB4A9BA47904940B97020240BA643409AB4A9BA47904940B97020240BA6434012C2A38D238E494011018750A5A2434012C2A38D238E4940
36745	13183	39.231225000000002	39.354258000000002	51.244154000000002	51.196575000000003	Центральная	0103000020E610000001000000050000004182E2C7989D4340091B9E5E299949404182E2C7989D434003983270409F4940562C7E5358AD434003983270409F4940562C7E5358AD4340091B9E5E299949404182E2C7989D4340091B9E5E29994940
36517	54315	39.431334	39.605606999999999	51.004072000000001	50.958905000000001	Советская	0103000020E6100000010000000500000091D3D7F335B74340467C2766BD7A494091D3D7F335B74340276A696E85804940459DB98784CD4340276A696E85804940459DB98784CD4340467C2766BD7A494091D3D7F335B74340467C2766BD7A4940
36939	48252	39.458731999999998	39.516089999999998	51.312545999999998	51.287024000000002	Пришкольная	0103000020E6100000010000000500000078D0ECBAB7BA43406495D233BDA4494078D0ECBAB7BA4340703FE08101A8494075E5B33C0FC24340703FE08101A8494075E5B33C0FC243406495D233BDA4494078D0ECBAB7BA43406495D233BDA44940
36471	9546	39.224640000000001	39.262881999999998	51.388103999999998	51.352539999999998	Проспект Революции	0103000020E61000000100000005000000CDAFE600C19C43401344DD0720AD4940CDAFE600C19C434030B95164ADB14940815A0C1EA6A1434030B95164ADB14940815A0C1EA6A143401344DD0720AD4940CDAFE600C19C43401344DD0720AD4940
35967	15316	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	площадь имени Ленина	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35816	15316	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	коммунальная	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35917	15316	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Первомайская	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35923	15316	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Октябрьская	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35871	15316	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Ленина	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35757	15316	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Космонавтов	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
35960	15316	39.179617	39.249847000000003	51.332971999999998	51.299472000000002	Воронежское шоссе	0103000020E610000001000000050000001F679AB0FD964340AB08371955A649401F679AB0FD964340EA3D95D39EAA49407A008BFCFA9F4340EA3D95D39EAA49407A008BFCFA9F4340AB08371955A649401F679AB0FD964340AB08371955A64940
37103	48183	39.502443999999997	39.556649	51.359727999999997	51.321001000000003	Советская	0103000020E610000001000000050000002409C21550C04340DD7D8E8F16A949402409C21550C043404DBA2D910BAE4940F12C414640C743404DBA2D910BAE4940F12C414640C74340DD7D8E8F16A949402409C21550C04340DD7D8E8F16A94940
36562	48186	39.638593	39.681874000000001	51.338307	51.296486999999999	Ленина	0103000020E610000001000000050000002E3A596ABDD1434036583849F3A549402E3A596ABDD143400281CEA44DAB494011FFB0A547D743400281CEA44DAB494011FFB0A547D7434036583849F3A549402E3A596ABDD1434036583849F3A54940
36454	9875	39.389912000000002	39.423707	51.363788999999997	51.308205000000001	Пролетарская	0103000020E61000000100000005000000B328ECA2E8B143405ABBED4273A74940B328ECA2E8B1434080D250A390AE49400B0BEE073CB6434080D250A390AE49400B0BEE073CB643405ABBED4273A74940B328ECA2E8B143405ABBED4273A74940
36668	48117	39.284567000000003	39.315837000000002	51.332870999999997	51.314183999999997	Карла Маркса	0103000020E61000000100000005000000AB4203B16CA4434096766A2E37A84940AB4203B16CA44340B66455849BAA4940F2EEC8586DA84340B66455849BAA4940F2EEC8586DA8434096766A2E37A84940AB4203B16CA4434096766A2E37A84940
35899	9694	39.748367000000002	39.797272	51.416665000000002	51.366898999999997	Степная	0103000020E61000000100000005000000EC33677DCADF4340B1F7E28BF6AE4940EC33677DCADF4340A5315A4755B549401D0247020DE64340A5315A4755B549401D0247020DE64340B1F7E28BF6AE4940EC33677DCADF4340B1F7E28BF6AE4940
36561	9626	39.664914000000003	39.699624999999997	51.403193000000002	51.382669	Молодежная	0103000020E610000001000000050000008753E6E61BD54340B5183C4CFBB049408753E6E61BD54340F27C06D49BB34940643BDF4F8DD94340F27C06D49BB34940643BDF4F8DD94340B5183C4CFBB049408753E6E61BD54340B5183C4CFBB04940
37102	9656	39.657286999999997	39.684066000000001	51.447266999999997	51.428043000000002	Первомайская	0103000020E61000000100000005000000008BFCFA21D443401024EF1CCAB64940008BFCFA21D443403ECA880B40B949401C2785798FD743403ECA880B40B949401C2785798FD743401024EF1CCAB64940008BFCFA21D443401024EF1CCAB64940
36354	54308	39.113796999999998	39.797272	51.474426999999999	51.142415	Ленина	0103000020E6100000010000000500000003B16CE6908E4340DCBA9BA73A92494003B16CE6908E434071AB2006BABC49401D0247020DE6434071AB2006BABC49401D0247020DE64340DCBA9BA73A92494003B16CE6908E4340DCBA9BA73A924940
36265	54300	39.265352	39.328781999999997	51.366123000000002	51.333883999999998	Центральная	0103000020E61000000100000005000000CFF6E80DF7A143402E54FEB5BCAA4940CFF6E80DF7A143401EA8531EDDAE4940B9C1508715AA43401EA8531EDDAE4940B9C1508715AA43402E54FEB5BCAA4940CFF6E80DF7A143402E54FEB5BCAA4940
35983	47797	39.562766000000003	39.652113	51.436017	51.392938000000001	Олимпийская	0103000020E610000001000000050000007FA65EB708C8434086ADD9CA4BB249407FA65EB708C8434001C0B167CFB74940F225547078D3434001C0B167CFB74940F225547078D3434086ADD9CA4BB249407FA65EB708C8434086ADD9CA4BB24940
36091	47797	39.562766000000003	39.652113	51.436017	51.392938000000001	Мира	0103000020E610000001000000050000007FA65EB708C8434086ADD9CA4BB249407FA65EB708C8434001C0B167CFB74940F225547078D3434001C0B167CFB74940F225547078D3434086ADD9CA4BB249407FA65EB708C8434086ADD9CA4BB24940
36461	47797	39.562766000000003	39.652113	51.436017	51.392938000000001	3 Интернационала	0103000020E610000001000000050000007FA65EB708C8434086ADD9CA4BB249407FA65EB708C8434001C0B167CFB74940F225547078D3434001C0B167CFB74940F225547078D3434086ADD9CA4BB249407FA65EB708C8434086ADD9CA4BB24940
37237	54439	39.125897999999999	39.174576999999999	51.375326999999999	51.345345000000002	Мира	0103000020E61000000100000005000000DF50F86C1D904340276BD44334AC4940DF50F86C1D904340242713B70AB0494020D1048A58964340242713B70AB0494020D1048A58964340276BD44334AC4940DF50F86C1D904340276BD44334AC4940
35706	47934	39.21987	39.255830000000003	51.463974999999998	51.423000000000002	Школьная	0103000020E610000001000000050000008EAF3DB3249C4340A01A2FDD24B649408EAF3DB3249C4340AF94658863BB4940F8AA9509BFA04340AF94658863BB4940F8AA9509BFA04340A01A2FDD24B649408EAF3DB3249C4340A01A2FDD24B64940
37027	48224	39.683202999999999	39.713540000000002	51.221966999999999	51.208291000000003	Новая	0103000020E61000000100000005000000B9C3263273D743408C868C47A99A4940B9C3263273D7434047E5266A699C4940A5315A4755DB434047E5266A699C4940A5315A4755DB43408C868C47A99A4940B9C3263273D743408C868C47A99A4940
36503	9332	39.712057000000001	39.768614999999997	51.363709999999998	51.334778999999997	Ленина	0103000020E61000000100000005000000A6F10BAF24DB43409C31CC09DAAA4940A6F10BAF24DB4340349D9D0C8EAE4940861BF0F961E24340349D9D0C8EAE4940861BF0F961E243409C31CC09DAAA4940A6F10BAF24DB43409C31CC09DAAA4940
36644	9185	39.512362000000003	39.549470999999997	51.321176000000001	51.275328999999999	Мира	0103000020E6100000010000000500000049DBF81395C14340F8510DFB3DA3494049DBF81395C143404B21904B1CA94940DA8CD31055C643404B21904B1CA94940DA8CD31055C64340F8510DFB3DA3494049DBF81395C14340F8510DFB3DA34940
36620	9185	39.512362000000003	39.549470999999997	51.321176000000001	51.275328999999999	Кольцовская	0103000020E6100000010000000500000049DBF81395C14340F8510DFB3DA3494049DBF81395C143404B21904B1CA94940DA8CD31055C643404B21904B1CA94940DA8CD31055C64340F8510DFB3DA3494049DBF81395C14340F8510DFB3DA34940
36156	47857	39.301769999999998	39.352893000000002	51.431114999999998	51.381646000000003	Школьная	0103000020E61000000100000005000000FB743C66A0A643401A53B0C6D9B04940FB743C66A0A6434053E8BCC62EB7494061FE0A992BAD434053E8BCC62EB7494061FE0A992BAD43401A53B0C6D9B04940FB743C66A0A643401A53B0C6D9B04940
36887	9105	39.515084000000002	39.545833000000002	51.433591	51.409514000000001	Пушкинская	0103000020E61000000100000005000000B058C345EEC1434088A06AF46AB44940B058C345EEC14340836BEEE87FB74940EE0912DBDDC54340836BEEE87FB74940EE0912DBDDC5434088A06AF46AB44940B058C345EEC1434088A06AF46AB44940
36938	8490	39.734416000000003	39.823889000000001	50.027377000000001	49.839899000000003	Советская	0103000020E610000001000000050000005FD4EE5701DE4340B87878CF81EB48405FD4EE5701DE4340D0D4EB16810349405F44DB3175E94340D0D4EB16810349405F44DB3175E94340B87878CF81EB48405FD4EE5701DE4340B87878CF81EB4840
37091	8791	39.807881000000002	39.849570999999997	49.912168999999999	49.887996000000001	Советская	0103000020E61000000100000005000000A70705A568E743404A7D59DAA9F14840A70705A568E7434067B62BF4C1F44840A45016BEBEEC434067B62BF4C1F44840A45016BEBEEC43404A7D59DAA9F14840A70705A568E743404A7D59DAA9F14840
36667	8727	40.129460000000002	40.185504999999999	49.750165000000003	49.728530999999997	Победы	0103000020E61000000100000005000000F111312592104440A38FF98040DD4840F1113125921044404BCD1E6805E048404B1FBAA0BE1744404BCD1E6805E048404B1FBAA0BE174440A38FF98040DD4840F111312592104440A38FF98040DD4840
35771	8633	40.023961	40.120342000000001	49.886823999999997	49.835779000000002	Центральная	0103000020E6100000010000000500000092B06F271103444080D767CEFAEA484092B06F271103444069A7E67283F14840E92ADD5D670F444069A7E67283F14840E92ADD5D670F444080D767CEFAEA484092B06F271103444080D767CEFAEA4840
37093	48832	39.594647999999999	39.612515000000002	49.973348000000001	49.947640999999997	Луговая	0103000020E61000000100000005000000DF50F86C1DCC4340A3ACDF4C4CF94840DF50F86C1DCC434042D0D1AA96FC48409CA73AE466CE434042D0D1AA96FC48409CA73AE466CE4340A3ACDF4C4CF94840DF50F86C1DCC4340A3ACDF4C4CF94840
37184	54402	39.641674000000002	39.664177000000002	49.844203	49.826225999999998	Школьная	0103000020E61000000100000005000000C558A65F22D243406D8D08C6C1E94840C558A65F22D24340B1170AD80EEC4840B1E07EC003D54340B1170AD80EEC4840B1E07EC003D543406D8D08C6C1E94840C558A65F22D243406D8D08C6C1E94840
36502	8517	39.872407000000003	39.913648000000002	49.819251999999999	49.783552	50 лет Октября	0103000020E6100000010000000500000097E65608ABEF4340925B936E4BE4484097E65608ABEF43405F97E13FDDE848402507EC6AF2F443405F97E13FDDE848402507EC6AF2F44340925B936E4BE4484097E65608ABEF4340925B936E4BE44840
36732	8584	39.920403999999998	39.960675000000002	49.832793000000002	49.805928999999999	Широкая	0103000020E61000000100000005000000C58D5BCCCFF54340F1F274AE28E74840C58D5BCCCFF543403BAB05F698EA4840DB8AFD65F7FA43403BAB05F698EA4840DB8AFD65F7FA4340F1F274AE28E74840C58D5BCCCFF54340F1F274AE28E74840
36733	8765	40.086502000000003	40.118113999999998	49.787030000000001	49.757474999999999	Центральная	0103000020E61000000100000005000000F1845E7F120B4440D044D8F0F4E04840F1845E7F120B4440467C2766BDE4484091990B5C1E0F4440467C2766BDE4484091990B5C1E0F4440D044D8F0F4E04840F1845E7F120B4440D044D8F0F4E04840
36519	54316	40.144317999999998	40.210191000000002	49.919373	49.872770000000003	Ленина	0103000020E61000000100000005000000B01C210379124440087767EDB6EF4840B01C210379124440A7E9B303AEF54840EF74E789E71A4440A7E9B303AEF54840EF74E789E71A4440087767EDB6EF4840B01C210379124440087767EDB6EF4840
37153	7593	39.692762000000002	39.713332999999999	49.819665000000001	49.809237000000003	Колхозная	0103000020E61000000100000005000000AEF4DA6CACD8434049DBF81395E74840AEF4DA6CACD84340825660C8EAE848402B14E97E4EDB4340825660C8EAE848402B14E97E4EDB434049DBF81395E74840AEF4DA6CACD8434049DBF81395E74840
37101	47565	39.711590000000001	39.734110999999999	49.870342999999998	49.858643000000001	Мира	0103000020E610000001000000050000009014916115DB43403CF88903E8ED48409014916115DB4340B9A6406667EF484022516859F7DD4340B9A6406667EF484022516859F7DD43403CF88903E8ED48409014916115DB43403CF88903E8ED4840
36708	54346	39.812533999999999	39.856712999999999	49.774698999999998	49.767164000000001	Школьная	0103000020E61000000100000005000000AC71361D01E843409355116E32E24840AC71361D01E84340389F3A5629E348406E8786C5A8ED4340389F3A5629E348406E8786C5A8ED43409355116E32E24840AC71361D01E843409355116E32E24840
37056	6561	40.260505999999999	40.280700000000003	49.676409	49.661011000000002	Центральная	0103000020E61000000100000005000000B534B74258214440ECA529029CD44840B534B742582144402BDCF29194D648405DFE43FAED2344402BDCF29194D648405DFE43FAED234440ECA529029CD44840B534B74258214440ECA529029CD44840
37096	47296	39.999006000000001	40.019855999999997	49.746493000000001	49.731431000000001	Мира	0103000020E61000000100000005000000FF40B96DDFFF4340EA23F0879FDD4840FF40B96DDFFF4340B2D826158DDF48408F5033A48A024440B2D826158DDF48408F5033A48A024440EA23F0879FDD4840FF40B96DDFFF4340EA23F0879FDD4840
37198	47296	39.999006000000001	40.019855999999997	49.746493000000001	49.731431000000001	Луговая	0103000020E61000000100000005000000FF40B96DDFFF4340EA23F0879FDD4840FF40B96DDFFF4340B2D826158DDF48408F5033A48A024440B2D826158DDF48408F5033A48A024440EA23F0879FDD4840FF40B96DDFFF4340EA23F0879FDD4840
36051	8255	39.702356000000002	39.771237999999997	49.738948000000001	49.707039000000002	Советская	0103000020E610000001000000050000001F1329CDE6D943408FFF024180DA48401F1329CDE6D94340E9B81AD995DE48405AB741EDB7E24340E9B81AD995DE48405AB741EDB7E243408FFF024180DA48401F1329CDE6D943408FFF024180DA4840
36228	54293	39.253467000000001	39.339230000000001	49.860472000000001	49.801707999999998	Советская	0103000020E61000000100000005000000C0CE4D9B71A043408578245E9EE64840C0CE4D9B71A04340D68F4DF223EE48403AE97DE36BAB4340D68F4DF223EE48403AE97DE36BAB43408578245E9EE64840C0CE4D9B71A043408578245E9EE64840
36910	54376	39.590640999999998	39.654592000000001	49.908769999999997	49.874656999999999	Юбилейная	0103000020E610000001000000050000009F56D11F9ACB4340D61BB5C2F4EF48409F56D11F9ACB4340FFCA4A9352F44840931CB0ABC9D34340FFCA4A9352F44840931CB0ABC9D34340D61BB5C2F4EF48409F56D11F9ACB4340D61BB5C2F4EF4840
36958	47324	39.666890000000002	39.714545999999999	49.986885000000001	49.949326999999997	пр-кт Строителей	0103000020E61000000100000005000000C503CAA65CD54340DA1A118C83F94840C503CAA65CD54340DCF4673F52FE48406ABE4A3E76DB4340DCF4673F52FE48406ABE4A3E76DB4340DA1A118C83F94840C503CAA65CD54340DA1A118C83F94840
36083	47324	39.666890000000002	39.714545999999999	49.986885000000001	49.949326999999997	Элеваторская	0103000020E61000000100000005000000C503CAA65CD54340DA1A118C83F94840C503CAA65CD54340DCF4673F52FE48406ABE4A3E76DB4340DCF4673F52FE48406ABE4A3E76DB4340DA1A118C83F94840C503CAA65CD54340DA1A118C83F94840
37036	47324	39.666890000000002	39.714545999999999	49.986885000000001	49.949326999999997	Ленина	0103000020E61000000100000005000000C503CAA65CD54340DA1A118C83F94840C503CAA65CD54340DCF4673F52FE48406ABE4A3E76DB4340DCF4673F52FE48406ABE4A3E76DB4340DA1A118C83F94840C503CAA65CD54340DA1A118C83F94840
36427	47324	39.666890000000002	39.714545999999999	49.986885000000001	49.949326999999997	Большевик	0103000020E61000000100000005000000C503CAA65CD54340DA1A118C83F94840C503CAA65CD54340DCF4673F52FE48406ABE4A3E76DB4340DCF4673F52FE48406ABE4A3E76DB4340DA1A118C83F94840C503CAA65CD54340DA1A118C83F94840
36982	47463	39.482627999999998	39.552264999999998	49.859600999999998	49.824181000000003	Центральная	0103000020E6100000010000000500000023111AC1C6BD4340077E54C37EE9484023111AC1C6BD4340F04DD36707EE4840DBDC989EB0C64340F04DD36707EE4840DBDC989EB0C64340077E54C37EE9484023111AC1C6BD4340077E54C37EE94840
36731	47547	40.294974000000003	40.307712000000002	49.709090000000003	49.691645000000001	Центральная	0103000020E61000000100000005000000CD9541B5C125444091B8C7D287D84840CD9541B5C1254440D8F50B76C3DA48401B4B581B63274440D8F50B76C3DA48401B4B581B6327444091B8C7D287D84840CD9541B5C125444091B8C7D287D84840
37099	7431	39.870573999999998	39.910530999999999	49.593023000000002	49.569239000000003	Ленина	0103000020E61000000100000005000000BB5F05F86EEF4340CB4DD4D2DCC84840BB5F05F86EEF43404E637B2DE8CB4840417FA1478CF443404E637B2DE8CB4840417FA1478CF44340CB4DD4D2DCC84840BB5F05F86EEF4340CB4DD4D2DCC84840
36598	47234	39.715497999999997	39.821283000000001	49.762393000000003	49.735478000000001	Театральная	0103000020E610000001000000050000003C2D3F7095DB4340B876A22424DE48403C2D3F7095DB434084D9041896E1484061E124CD1FE9434084D9041896E1484061E124CD1FE94340B876A22424DE48403C2D3F7095DB4340B876A22424DE4840
35691	6847	39.821652	39.933734999999999	49.740537000000003	49.662813	победы	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
35805	6847	39.821652	39.933734999999999	49.740537000000003	49.662813	первомайская	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
35892	6847	39.821652	39.933734999999999	49.740537000000003	49.662813	Шевченко	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
36619	6847	39.821652	39.933734999999999	49.740537000000003	49.662813	Строителей	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
35702	6847	39.821652	39.933734999999999	49.740537000000003	49.662813	Победы	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
36666	6847	39.821652	39.933734999999999	49.740537000000003	49.662813	Кирпичная	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
36391	6847	39.821652	39.933734999999999	49.740537000000003	49.662813	Дунай	0103000020E61000000100000005000000B4588AE42BE943408C2E6F0ED7D44840B4588AE42BE943402E3D9AEAC9DE4840B610E4A084F743402E3D9AEAC9DE4840B610E4A084F743408C2E6F0ED7D44840B4588AE42BE943408C2E6F0ED7D44840
36984	47126	39.963980999999997	40.025281999999997	49.696266000000001	49.673419000000003	Центральная	0103000020E61000000100000005000000917BBABA63FB4340A5C0029832D64840917BBABA63FB43408BA8893E1FD94840B796C9703C0344408BA8893E1FD94840B796C9703C034440A5C0029832D64840917BBABA63FB4340A5C0029832D64840
36885	7995	39.709505999999998	39.750495999999998	49.971905	49.963799000000002	Центральная	0103000020E610000001000000050000006B28B517D1DA4340717500C45DFB48406B28B517D1DA4340D1E80E6267FC4840B0E3BF4010E04340D1E80E6267FC4840B0E3BF4010E04340717500C45DFB48406B28B517D1DA4340717500C45DFB4840
36889	54374	39.972217999999998	39.979117000000002	49.605074999999999	49.601804999999999	Вокзальная	0103000020E61000000100000005000000904AB1A371FC4340DEC83CF207CD4840904AB1A371FC43404850FC1873CD484094FAB2B453FD43404850FC1873CD484094FAB2B453FD4340DEC83CF207CD4840904AB1A371FC4340DEC83CF207CD4840
36856	7710	40.051360000000003	40.100282	49.667799000000002	49.639809999999997	Победы	0103000020E610000001000000050000004A29E8F692064440AED3484BE5D148404A29E8F69206444098A608707AD548405130630AD60C444098A608707AD548405130630AD60C4440AED3484BE5D148404A29E8F692064440AED3484BE5D14840
37098	47117	39.362234999999998	39.424776000000001	49.861365999999997	49.830781999999999	Школьная	0103000020E61000000100000005000000B83B6BB75DAE4340800D881057EA4840B83B6BB75DAE434073F1B73D41EE484017105A0F5FB6434073F1B73D41EE484017105A0F5FB64340800D881057EA4840B83B6BB75DAE4340800D881057EA4840
36796	46887	39.736429000000001	39.751762999999997	49.945067000000002	49.9208	Победы	0103000020E61000000100000005000000BA69334E43DE434012143FC6DCF54840BA69334E43DE4340B1C398F4F7F84840E2AB1DC539E04340B1C398F4F7F84840E2AB1DC539E0434012143FC6DCF54840BA69334E43DE434012143FC6DCF54840
37266	7399	39.724167000000001	39.984831	49.844163000000002	49.631326999999999	Советская	0103000020E61000000100000005000000D5EB1681B1DC4340780AB952CFD04840D5EB1681B1DC434023BF7E880DEC4840228B34F10EFE434023BF7E880DEC4840228B34F10EFE4340780AB952CFD04840D5EB1681B1DC4340780AB952CFD04840
36905	7399	39.724167000000001	39.984831	49.844163000000002	49.631326999999999	Лесная	0103000020E61000000100000005000000D5EB1681B1DC4340780AB952CFD04840D5EB1681B1DC434023BF7E880DEC4840228B34F10EFE434023BF7E880DEC4840228B34F10EFE4340780AB952CFD04840D5EB1681B1DC4340780AB952CFD04840
36467	47106	39.426276000000001	39.457662999999997	49.818776	49.758854999999997	Базарная	0103000020E61000000100000005000000EC88433690B64340FAB31F2922E14840EC88433690B64340F65FE7A6CDE848406CCB80B394BA4340F65FE7A6CDE848406CCB80B394BA4340FAB31F2922E14840EC88433690B64340FAB31F2922E14840
36791	6545	39.250683000000002	39.276778999999998	50.746723000000003	50.727848000000002	Школьная	0103000020E61000000100000005000000E3546B6116A04340C13A8E1F2A5D4940E3546B6116A04340E415889E945F49401B9C887E6DA34340E415889E945F49401B9C887E6DA34340C13A8E1F2A5D4940E3546B6116A04340C13A8E1F2A5D4940
37076	5908	39.328907999999998	39.362676	50.813226999999998	50.799748000000001	Молодежная	0103000020E6100000010000000500000046B247A819AA43404D8578245E66494046B247A819AA4340B29C84D217684940A585CB2A6CAE4340B29C84D217684940A585CB2A6CAE43404D8578245E66494046B247A819AA43404D8578245E664940
36981	6485	39.318522999999999	39.346012000000002	50.715029000000001	50.695822	Центральная	0103000020E610000001000000050000000C03965CC5A843402DEBFEB1105949400C03965CC5A843408658FD11865B49400403081F4AAC43408658FD11865B49400403081F4AAC43402DEBFEB1105949400C03965CC5A843402DEBFEB110594940
36811	6371	39.422809000000001	39.458157	50.666057000000002	50.648983000000001	Центральная	0103000020E610000001000000050000002CBAF59A1EB643407A54FCDF115349402CBAF59A1EB64340CD22145B415549407CB779E3A4BA4340CD22145B415549407CB779E3A4BA43407A54FCDF115349402CBAF59A1EB643407A54FCDF11534940
36500	6551	39.364624999999997	39.393236000000002	50.724085000000002	50.710608000000001	Центральная	0103000020E61000000100000005000000E9263108ACAE43405323F433F55A4940E9263108ACAE4340184339D1AE5C494010CEA78E55B24340184339D1AE5C494010CEA78E55B243405323F433F55A4940E9263108ACAE43405323F433F55A4940
36448	6324	39.097771000000002	39.155676999999997	50.598878999999997	50.572536999999997	Центральная	0103000020E61000000100000005000000A5BF97C2838C4340FE5F75E448494940A5BF97C2838C43406EA12B11A84C4940A4DE5339ED9343406EA12B11A84C4940A4DE5339ED934340FE5F75E448494940A5BF97C2838C4340FE5F75E448494940
36396	6228	39.485852999999999	39.524624000000003	50.698622999999998	50.684061	Ленина	0103000020E61000000100000005000000EDD45C6E30BE43400ABC934F8F574940EDD45C6E30BE4340E09D7C7A6C5949402E5915E126C34340E09D7C7A6C5949402E5915E126C343400ABC934F8F574940EDD45C6E30BE43400ABC934F8F574940
36793	6425	39.483058999999997	39.518408000000001	50.651336000000001	50.632097000000002	Механизаторов	0103000020E61000000100000005000000EC8497E0D4BD43402A73F38DE8504940EC8497E0D4BD43408E5A61FA5E5349400DFE7E315BC243408E5A61FA5E5349400DFE7E315BC243402A73F38DE8504940EC8497E0D4BD43402A73F38DE8504940
36883	6013	39.247107	39.276949000000002	50.586711000000001	50.557231000000002	Центральная	0103000020E610000001000000050000006CCEC133A19F4340A0A86C58534749406CCEC133A19F43400B9A9658194B494078D4981073A343400B9A9658194B494078D4981073A34340A0A86C58534749406CCEC133A19F4340A0A86C5853474940
37267	54456	39.583499000000003	39.602885000000001	50.707574000000001	50.686532	Новая	0103000020E61000000100000005000000D61F6118B0CA434028D4D347E0574940D61F6118B0CA4340FDBFEAC8915A4940DE1FEF552BCD4340FDBFEAC8915A4940DE1FEF552BCD434028D4D347E0574940D61F6118B0CA434028D4D347E0574940
36656	6092	39.628163999999998	39.742410999999997	50.791117	50.765453000000001	Центральная	0103000020E6100000010000000500000024438EAD67D0434003D0285DFA61494024438EAD67D04340A2276552436549406798DA5207DF4340A2276552436549406798DA5207DF434003D0285DFA61494024438EAD67D0434003D0285DFA614940
36935	54379	39.465685000000001	39.486382999999996	50.809106	50.780776000000003	Железнодорожная	0103000020E610000001000000050000006F9EEA909BBB434038C0CC77F06349406F9EEA909BBB4340AA7F10C990674940492A53CC41BE4340AA7F10C990674940492A53CC41BE434038C0CC77F06349406F9EEA909BBB434038C0CC77F0634940
36655	6063	39.410420999999999	39.479430000000001	50.620738000000003	50.580654000000003	Красная	0103000020E61000000100000005000000BA4BE2AC88B443405325CADE524A4940BA4BE2AC88B4434036B1C057744F4940535C55F65DBD434036B1C057744F4940535C55F65DBD43405325CADE524A4940BA4BE2AC88B443405325CADE524A4940
36560	5933	39.31908	39.362136999999997	50.628024000000003	50.603938999999997	Дружбы	0103000020E6100000010000000500000062670A9DD7A84340B4E386DF4D4D494062670A9DD7A84340338D261763504940F5D555815AAE4340338D261763504940F5D555815AAE4340B4E386DF4D4D494062670A9DD7A84340B4E386DF4D4D4940
36291	47411	39.399785000000001	39.452157	50.728257999999997	50.693750000000001	Солнечная	0103000020E610000001000000050000003737A6272CB34340CDCCCCCCCC5849403737A6272CB343407286E28E375D494028D4D347E0B943407286E28E375D494028D4D347E0B94340CDCCCCCCCC5849403737A6272CB34340CDCCCCCCCC584940
36225	47411	39.399785000000001	39.452157	50.728257999999997	50.693750000000001	Советская	0103000020E610000001000000050000003737A6272CB34340CDCCCCCCCC5849403737A6272CB343407286E28E375D494028D4D347E0B943407286E28E375D494028D4D347E0B94340CDCCCCCCCC5849403737A6272CB34340CDCCCCCCCC584940
36152	47411	39.399785000000001	39.452157	50.728257999999997	50.693750000000001	Привокзальная	0103000020E610000001000000050000003737A6272CB34340CDCCCCCCCC5849403737A6272CB343407286E28E375D494028D4D347E0B943407286E28E375D494028D4D347E0B94340CDCCCCCCCC5849403737A6272CB34340CDCCCCCCCC584940
36222	47411	39.399785000000001	39.452157	50.728257999999997	50.693750000000001	Полевая	0103000020E610000001000000050000003737A6272CB34340CDCCCCCCCC5849403737A6272CB343407286E28E375D494028D4D347E0B943407286E28E375D494028D4D347E0B94340CDCCCCCCCC5849403737A6272CB34340CDCCCCCCCC584940
37345	47411	39.399785000000001	39.452157	50.728257999999997	50.693750000000001	Народная	0103000020E610000001000000050000003737A6272CB34340CDCCCCCCCC5849403737A6272CB343407286E28E375D494028D4D347E0B943407286E28E375D494028D4D347E0B94340CDCCCCCCCC5849403737A6272CB34340CDCCCCCCCC584940
36226	47411	39.399785000000001	39.452157	50.728257999999997	50.693750000000001	Гагарина	0103000020E610000001000000050000003737A6272CB34340CDCCCCCCCC5849403737A6272CB343407286E28E375D494028D4D347E0B943407286E28E375D494028D4D347E0B94340CDCCCCCCCC5849403737A6272CB34340CDCCCCCCCC584940
36767	5815	39.372467	39.411588999999999	50.759703999999999	50.742618999999998	Садовая	0103000020E610000001000000050000006CEBA7FFACAF4340B131AF230E5F49406CEBA7FFACAF4340F8510DFB3D6149405932C7F2AEB44340F8510DFB3D6149405932C7F2AEB44340B131AF230E5F49406CEBA7FFACAF4340B131AF230E5F4940
36431	5787	39.255155999999999	39.281737	50.653992000000002	50.632617000000003	Мира	0103000020E6100000010000000500000068B0A9F3A8A0434063F20698F950494068B0A9F3A8A043403EEC8502B65349405D8940F50FA443403EEC8502B65349405D8940F50FA4434063F20698F950494068B0A9F3A8A0434063F20698F9504940
37152	5677	39.517302999999998	39.547063999999999	50.784545999999999	50.766751999999997	Центральная	0103000020E61000000100000005000000B48F15FC36C243404012F6ED24624940B48F15FC36C24340931ADA006C644940D368723106C64340931ADA006C644940D368723106C643404012F6ED24624940B48F15FC36C243404012F6ED24624940
37078	6166	39.574831000000003	39.641790999999998	50.783748000000003	50.751976999999997	Новая Жизнь	0103000020E610000001000000050000000EDDEC0F94C943400E2C47C8406049400EDDEC0F94C943401827BEDA51644940FEEE1D3526D243401827BEDA51644940FEEE1D3526D243400E2C47C8406049400EDDEC0F94C943400E2C47C840604940
36487	46395	40.786146000000002	40.818485000000003	50.547668000000002	50.508792999999997	Центральная	0103000020E61000000100000005000000CCF09F6EA064444084B7072120414940CCF09F6EA06444406A882AFC194649401FA2D11DC46844406A882AFC194649401FA2D11DC468444084B7072120414940CCF09F6EA064444084B7072120414940
36821	4619	40.576174000000002	40.60942	50.516584000000002	50.498240000000003	Комсомольская	0103000020E610000001000000050000001B67D311C04944408FC70C54C63F49401B67D311C049444085D1AC6C1F424940A0C37C79014E444085D1AC6C1F424940A0C37C79014E44408FC70C54C63F49401B67D311C04944408FC70C54C63F4940
36547	46359	40.909717999999998	40.997042999999998	50.349944000000001	50.304318000000002	Ленина площадь	0103000020E61000000100000005000000904AB1A371744440C5CA68E4F3264940904AB1A37174444039B709F7CA2C494055DAE21A9F7F444039B709F7CA2C494055DAE21A9F7F4440C5CA68E4F3264940904AB1A371744440C5CA68E4F3264940
35994	46359	40.909717999999998	40.997042999999998	50.349944000000001	50.304318000000002	Ленина	0103000020E61000000100000005000000904AB1A371744440C5CA68E4F3264940904AB1A37174444039B709F7CA2C494055DAE21A9F7F444039B709F7CA2C494055DAE21A9F7F4440C5CA68E4F3264940904AB1A371744440C5CA68E4F3264940
36766	46339	40.820632000000003	40.837575000000001	50.378777999999997	50.355604999999997	Кирова	0103000020E610000001000000050000008A0629780A694440A4A5F276842D49408A0629780A694440DE3829CC7B3049403E7958A8356B4440DE3829CC7B3049403E7958A8356B4440A4A5F276842D49408A0629780A694440A4A5F276842D4940
36653	5263	40.684339999999999	40.718943000000003	50.371361	50.346041	Восточная	0103000020E610000001000000050000001DACFF73985744409E094D124B2C49401DACFF73985744404301DBC1882F494015580053065C44404301DBC1882F494015580053065C44409E094D124B2C49401DACFF73985744409E094D124B2C4940
37188	54407	40.740278000000004	40.763948999999997	50.582135000000001	50.548332000000002	переулок Гагарина	0103000020E6100000010000000500000062F9F36DC15E4440D6AC33BE2F46494062F9F36DC15E4440B16D5166834A4940EC67B114C9614440B16D5166834A4940EC67B114C9614440D6AC33BE2F46494062F9F36DC15E4440D6AC33BE2F464940
36829	54368	41.367086	41.427183999999997	50.363914999999999	50.343753	Советская	0103000020E61000000100000005000000E4688EACFCAE444071732A19002C4940E4688EACFCAE44400DC347C4942E4940EEAF1EF7ADB644400DC347C4942E4940EEAF1EF7ADB6444071732A19002C4940E4688EACFCAE444071732A19002C4940
37151	5148	41.359746999999999	41.418604999999999	50.274580999999998	50.250458999999999	Ленина	0103000020E61000000100000005000000C4EA8F300CAE444093FE5E0A0F204940C4EA8F300CAE44402E8D5F7825234940967840D994B544402E8D5F7825234940967840D994B5444093FE5E0A0F204940C4EA8F300CAE444093FE5E0A0F204940
37225	46173	40.572921999999998	40.610894000000002	50.432834999999997	50.411256000000002	Свердлова	0103000020E61000000100000005000000579412825549444053245F09A4344940579412825549444036C82423673749404CA94BC6314E444036C82423673749404CA94BC6314E444053245F09A4344940579412825549444053245F09A4344940
36622	46173	40.572921999999998	40.610894000000002	50.432834999999997	50.411256000000002	Ленина	0103000020E61000000100000005000000579412825549444053245F09A4344940579412825549444036C82423673749404CA94BC6314E444036C82423673749404CA94BC6314E444053245F09A4344940579412825549444053245F09A4344940
35801	45868	40.993738	41.021532000000001	50.471519999999998	50.447631000000001	Щербакова	0103000020E610000001000000050000006F6589CE327F444080D6FCF84B3949406F6589CE327F444078B471C45A3C4940A3E8818FC182444078B471C45A3C4940A3E8818FC182444080D6FCF84B3949406F6589CE327F444080D6FCF84B394940
35802	46084	40.999226	41.035032999999999	50.383333	50.356150999999997	Космонавтов	0103000020E610000001000000050000000DA837A3E67F444006B8205B962D49400DA837A3E67F4440213D450E11314940F0A31AF67B844440213D450E11314940F0A31AF67B84444006B8205B962D49400DA837A3E67F444006B8205B962D4940
37321	54467	40.645316999999999	40.686279999999996	50.495134999999998	50.478209999999997	Октябрьская	0103000020E61000000100000005000000C34659BF99524440614F3BFC353D4940C34659BF995244406F0D6C95603F49400EF3E505D85744406F0D6C95603F49400EF3E505D8574440614F3BFC353D4940C34659BF99524440614F3BFC353D4940
36824	46192	40.593510999999999	40.625599000000001	50.460844000000002	50.437654999999999	Красный Флот	0103000020E610000001000000050000007B681F2BF84B444027F73B14053849407B681F2BF84B44406747AAEFFC3A494085B4C6A0135044406747AAEFFC3A494085B4C6A01350444027F73B14053849407B681F2BF84B444027F73B1405384940
37232	54434	40.690573999999998	40.733612000000001	50.323548000000002	50.296056	Первомайская	0103000020E61000000100000005000000E4BB94BA645844406DE4BA29E5254940E4BB94BA64584440D65757056A29494001FA7DFFE65D4440D65757056A29494001FA7DFFE65D44406DE4BA29E5254940E4BB94BA645844406DE4BA29E5254940
36455	54285	40.502692000000003	41.537973000000001	50.635987999999998	50.176997	Кирова	0103000020E61000000100000005000000FDFA213658404440BC3E73D6A7164940FDFA2136584044400053060E68514940C5909C4CDCC444400053060E68514940C5909C4CDCC44440BC3E73D6A7164940FDFA213658404440BC3E73D6A7164940
36126	54285	40.502692000000003	41.537973000000001	50.635987999999998	50.176997	Заброденская	0103000020E61000000100000005000000FDFA213658404440BC3E73D6A7164940FDFA2136584044400053060E68514940C5909C4CDCC444400053060E68514940C5909C4CDCC44440BC3E73D6A7164940FDFA213658404440BC3E73D6A7164940
35906	4488	40.748748999999997	40.818458	50.477488000000001	50.420233000000003	Ленина	0103000020E61000000100000005000000D3F4D901D75F444099D9E731CA354940D3F4D901D75F4440C11DA8531E3D49402593533BC3684440C11DA8531E3D49402593533BC368444099D9E731CA354940D3F4D901D75F444099D9E731CA354940
36138	4661	41.242068000000003	41.349291000000001	50.273907000000001	50.238407000000002	советская	0103000020E610000001000000050000003EB48F15FC9E44409911DE1E841E49403EB48F15FC9E44409F9273620F234940C1E44691B5AC44409F9273620F234940C1E44691B5AC44409911DE1E841E49403EB48F15FC9E44409911DE1E841E4940
37385	46140	40.683469000000002	40.713095000000003	50.562289999999997	50.539636999999999	Победы	0103000020E61000000100000005000000386A85E97B574440145B41D312454940386A85E97B574440156F641EF947494077F86BB2465B4440156F641EF947494077F86BB2465B4440145B41D312454940386A85E97B574440145B41D312454940
36434	45895	41.344780999999998	41.417464000000002	50.529589000000001	50.463276	Щербинина площадь	0103000020E610000001000000050000001EA4A7C821AC4440C782C2A04C3B49401EA4A7C821AC444022A98592C9434940F1A0D9756FB5444022A98592C9434940F1A0D9756FB54440C782C2A04C3B49401EA4A7C821AC4440C782C2A04C3B4940
36062	45895	41.344780999999998	41.417464000000002	50.529589000000001	50.463276	Федота Щербинина	0103000020E610000001000000050000001EA4A7C821AC4440C782C2A04C3B49401EA4A7C821AC444022A98592C9434940F1A0D9756FB5444022A98592C9434940F1A0D9756FB54440C782C2A04C3B49401EA4A7C821AC4440C782C2A04C3B4940
36714	54348	40.71199	40.742578000000002	50.384641999999999	50.355483999999997	Садовая	0103000020E610000001000000050000001E8A027D225B44402920ED7F802D49401E8A027D225B44408255F5F23B314940535DC0CB0C5F44408255F5F23B314940535DC0CB0C5F44402920ED7F802D49401E8A027D225B44402920ED7F802D4940
36387	4295	41.419297	41.461365000000001	50.589112999999998	50.557293999999999	Школьная	0103000020E61000000100000005000000CC272B86ABB54440E620E86855474940CC272B86ABB544400053060E684B4940704221020EBB44400053060E684B4940704221020EBB4440E620E86855474940CC272B86ABB54440E620E86855474940
36432	4202	41.128377	41.173859	50.349415	50.331133000000001	Ленина	0103000020E61000000100000005000000804754A86E9044402DD0EE90622A4940804754A86E904440ADDD76A1B92C4940C18EFF0241964440ADDD76A1B92C4940C18EFF02419644402DD0EE90622A4940804754A86E9044402DD0EE90622A4940
36116	3503	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	Селянская	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
35751	3503	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	Северная	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
36185	3503	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	Луначарского	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
35678	3503	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	Ленина площадь	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
36019	3503	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	Коммунистическая	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
35907	3503	40.958630999999997	41.051130999999998	50.455762999999997	50.401415999999998	1 Мая	0103000020E6100000010000000500000044F7AC6BB47A4440AA0B78996133494044F7AC6BB47A444009DD2571563A4940E867EA758B86444009DD2571563A4940E867EA758B864440AA0B78996133494044F7AC6BB47A4440AA0B789961334940
37177	53581	41.105524000000003	41.142867000000003	50.465505999999998	50.432369999999999	Первомайская	0103000020E61000000100000005000000B87878CF818D4440C1E270E657374940B87878CF818D4440BF0B5BB3953B4940BD56427749924440BF0B5BB3953B4940BD56427749924440C1E270E657374940B87878CF818D4440C1E270E657374940
37196	54411	40.905369999999998	40.918934999999998	50.416991000000003	50.402276999999998	Центральная	0103000020E61000000100000005000000C763062AE37344406C770FD07D334940C763062AE3734440F9DC09F65F3549402B137EA99F754440F9DC09F65F3549402B137EA99F7544406C770FD07D334940C763062AE37344406C770FD07D334940
36521	54307	40.502692000000003	41.537973000000001	50.635987999999998	50.176997	Магистральная	0103000020E61000000100000005000000FDFA213658404440BC3E73D6A7164940FDFA2136584044400053060E68514940C5909C4CDCC444400053060E68514940C5909C4CDCC44440BC3E73D6A7164940FDFA213658404440BC3E73D6A7164940
37089	45488	41.246012	41.273096000000002	51.553390999999998	51.536515000000001	Садовая	0103000020E6100000010000000500000037363B527D9F44401F680586ACC4494037363B527D9F44404B732B84D5C649408F554ACFF4A244404B732B84D5C649408F554ACFF4A244401F680586ACC4494037363B527D9F44401F680586ACC44940
36880	45421	41.497225	41.521462	51.371414000000001	51.360415000000003	Степная	0103000020E6100000010000000500000076E09C11A5BF444072FE261422AE494076E09C11A5BF444066A3737E8AAF4940AA0D4E44BFC2444066A3737E8AAF4940AA0D4E44BFC2444072FE261422AE494076E09C11A5BF444072FE261422AE4940
36936	2642	41.470014999999997	41.505400000000002	51.475819000000001	51.458565	Центральная	0103000020E6100000010000000500000091D0967329BC44408D0B0742B2BA494091D0967329BC444060E811A3E7BC4940FFB27BF2B0C0444060E811A3E7BC4940FFB27BF2B0C044408D0B0742B2BA494091D0967329BC44408D0B0742B2BA4940
36559	2304	41.753982000000001	41.793660000000003	51.394972000000003	51.358857	Мира	0103000020E61000000100000005000000E7E26F7B82E044406878B306EFAD4940E7E26F7B82E04440F96A47718EB249405A12A0A696E54440F96A47718EB249405A12A0A696E544406878B306EFAD4940E7E26F7B82E044406878B306EFAD4940
9824	2455	41.587048000000003	41.596732000000003	51.447239000000003	51.437505000000002	Центральная	0103000020E6100000010000000500000053978C6324CB4440126BF12900B8494053978C6324CB4440753FA7203FB94940043DD4B661CC4440753FA7203FB94940043DD4B661CC4440126BF12900B8494053978C6324CB4440126BF12900B84940
37138	2097	42.230232999999998	42.253337000000002	51.675511	51.653942000000001	Максима Горького	0103000020E61000000100000005000000E0BA6246781D45408CBD175FB4D34940E0BA6246781D45404C8BFA2477D64940F2EEC8586D2045404C8BFA2477D64940F2EEC8586D2045408CBD175FB4D34940E0BA6246781D45408CBD175FB4D34940
37365	54477	41.127191000000003	42.372633999999998	51.732514000000002	51.245291999999999	Школьная	0103000020E610000001000000050000003BAC70CB4790444037FC6EBA659F49403BAC70CB479044405BEECC04C3DD494057B08D78B22F45405BEECC04C3DD494057B08D78B22F454037FC6EBA659F49403BAC70CB4790444037FC6EBA659F4940
36553	3166	41.219861999999999	41.252811999999999	51.473737	51.439031999999997	Советская	0103000020E610000001000000050000000BD12170249C4440E0F2583332B849400BD12170249C4440DCF3FC69A3BC4940A704C4245CA04440DCF3FC69A3BC4940A704C4245CA04440E0F2583332B849400BD12170249C4440E0F2583332B84940
37269	54457	41.435484000000002	41.495905	51.507249999999999	51.473300000000002	Советская	0103000020E6100000010000000500000034F790F0BDB7444031992A1895BC494034F790F0BDB74440B0726891EDC049402176A6D079BF4440B0726891EDC049402176A6D079BF444031992A1895BC494034F790F0BDB7444031992A1895BC4940
36695	54335	41.244646000000003	41.271236000000002	51.529141000000003	51.494444999999999	Октябрьская	0103000020E61000000100000005000000728C648F509F4440DA5548F949BF4940728C648F509F444083FC6CE4BAC34940BABF7ADCB7A2444083FC6CE4BAC34940BABF7ADCB7A24440DA5548F949BF4940728C648F509F4440DA5548F949BF4940
37329	47371	41.200988000000002	41.225135000000002	51.428049000000001	51.421180999999997	Центральная	0103000020E61000000100000005000000B9718BF9B999444029594E42E9B54940B9718BF9B9994440F20A444FCAB64940AD174339D19C4440F20A444FCAB64940AD174339D19C444029594E42E9B54940B9718BF9B999444029594E42E9B54940
35796	2368	41.722056000000002	41.794541000000002	51.371526000000003	51.313339999999997	Ленинская	0103000020E61000000100000005000000B7F0BC546CDC4440AA436E861BA84940B7F0BC546CDC44408ECEF9298EAF4940632AFD84B3E544408ECEF9298EAF4940632AFD84B3E54440AA436E861BA84940B7F0BC546CDC4440AA436E861BA84940
36878	54373	42.138675999999997	42.172201999999999	51.576279	51.526155000000003	Свободы	0103000020E61000000100000005000000BB5E9A22C01145403ED00A0C59C34940BB5E9A22C0114540902FA182C3C94940242713B70A164540902FA182C3C94940242713B70A1645403ED00A0C59C34940BB5E9A22C01145403ED00A0C59C34940
36526	1754	42.138675999999997	42.172201999999999	51.576279	51.526155000000003	Первомайская	0103000020E61000000100000005000000BB5E9A22C01145403ED00A0C59C34940BB5E9A22C0114540902FA182C3C94940242713B70A164540902FA182C3C94940242713B70A1645403ED00A0C59C34940BB5E9A22C01145403ED00A0C59C34940
36600	1741	42.045512000000002	42.100704999999998	51.526434999999999	51.495482000000003	Советская	0103000020E61000000100000005000000ACC95356D3054540DBE044F46BBF4940ACC95356D3054540213CDA3862C3494097C5C4E6E30C4540213CDA3862C3494097C5C4E6E30C4540DBE044F46BBF4940ACC95356D3054540DBE044F46BBF4940
36067	45350	41.413654999999999	41.478180999999999	51.452992000000002	51.398546000000003	Пионерская	0103000020E61000000100000005000000D769A4A5F2B44440CFF9298E03B34940D769A4A5F2B44440C1AC50A4FBB94940C748F60835BD4440C1AC50A4FBB94940C748F60835BD4440CFF9298E03B34940D769A4A5F2B44440CFF9298E03B34940
36602	45350	41.413654999999999	41.478180999999999	51.452992000000002	51.398546000000003	Глотова	0103000020E61000000100000005000000D769A4A5F2B44440CFF9298E03B34940D769A4A5F2B44440C1AC50A4FBB94940C748F60835BD4440C1AC50A4FBB94940C748F60835BD4440CFF9298E03B34940D769A4A5F2B44440CFF9298E03B34940
36819	45388	41.508257	41.539985000000001	51.396028999999999	51.387407000000003	Центральная	0103000020E61000000100000005000000467BBC900EC14440E99E758D96B14940467BBC900EC1444040A20914B1B2494050AA7D3A1EC5444040A20914B1B2494050AA7D3A1EC54440E99E758D96B14940467BBC900EC14440E99E758D96B14940
37139	3025	41.534362000000002	41.556164000000003	51.361162	51.333844999999997	Административная	0103000020E61000000100000005000000D21C59F965C444407077D66EBBAA4940D21C59F965C444406B47718E3AAE4940359BC76130C744406B47718E3AAE4940359BC76130C744407077D66EBBAA4940D21C59F965C444407077D66EBBAA4940
36764	49604	41.479807000000001	41.499363000000002	51.451022000000002	51.427121999999997	Заречная	0103000020E6100000010000000500000029B2D6506ABD444078B306EFABB6494029B2D6506ABD444065E3C116BBB949408EEA7420EBBF444065E3C116BBB949408EEA7420EBBF444078B306EFABB6494029B2D6506ABD444078B306EFABB64940
36924	3131	41.255766999999999	41.297189000000003	51.397050999999998	51.363114000000003	Ленинская	0103000020E61000000100000005000000B1321AF9BCA04440215C01857AAE4940B1321AF9BCA044400BEC3191D2B2494090DD054A0AA644400BEC3191D2B2494090DD054A0AA64440215C01857AAE4940B1321AF9BCA04440215C01857AAE4940
36486	49451	41.763027999999998	41.807971000000002	51.483032000000001	51.430008999999998	Свободы	0103000020E6100000010000000500000055F7C8E6AAE144402AFEEF880AB7494055F7C8E6AAE14440F37519FED3BD4940E78EFE976BE74440F37519FED3BD4940E78EFE976BE744402AFEEF880AB7494055F7C8E6AAE144402AFEEF880AB74940
36018	1289	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	машзаводская	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
36479	1289	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	Совхозная	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
35888	1289	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	Советская	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
36124	1289	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	Сахзаводская	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
36041	1289	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	Ленинская	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
35782	1289	41.888855	42.007683999999998	51.476761000000003	51.404136999999999	Красная Поляна	0103000020E610000001000000050000006BF12900C6F14440410DDFC2BAB349406BF12900C6F144400F81238106BD4940EA5910CAFB0045400F81238106BD4940EA5910CAFB004540410DDFC2BAB349406BF12900C6F14440410DDFC2BAB34940
36980	48003	42.292845	42.317647999999998	51.568379999999998	51.557048000000002	Пролетарская	0103000020E6100000010000000500000008E6E8F17B254540AF264F594DC7494008E6E8F17B254540A9D903ADC0C84940E5D18DB0A8284540A9D903ADC0C84940E5D18DB0A8284540AF264F594DC7494008E6E8F17B254540AF264F594DC74940
35904	2249	41.739311999999998	41.799678999999998	51.428100000000001	51.390155999999998	площадь революции	0103000020E610000001000000050000002AC58EC6A1DE4440492BBEA1F0B149402AC58EC6A1DE444074B515FBCBB649402426A8E15BE6444074B515FBCBB649402426A8E15BE64440492BBEA1F0B149402AC58EC6A1DE4440492BBEA1F0B14940
36720	54351	42.231589	42.265033000000003	51.593940000000003	51.569907999999998	площадь Революции	0103000020E61000000100000005000000828E56B5A41D454048DDCEBEF2C84940828E56B5A41D4540A4E4D53906CC49402EAEF199EC214540A4E4D53906CC49402EAEF199EC21454048DDCEBEF2C84940828E56B5A41D454048DDCEBEF2C84940
36357	54309	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	25 лет Октября	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
36652	19578	40.681825000000003	40.714928	50.625926	50.609186999999999	Садовая	0103000020E61000000100000005000000304CA60A46574440FD12F1D6F94D4940304CA60A46574440A9DBD9571E504940527FBDC2825B4440A9DBD9571E504940527FBDC2825B4440FD12F1D6F94D4940304CA60A46574440FD12F1D6F94D4940
36597	54323	41.236328	41.259208000000001	50.653461	50.644424999999998	Садовая	0103000020E610000001000000050000008690F3FE3F9E4440C6DCB5847C5249408690F3FE3F9E4440111B2C9CA4534940486E4DBA2DA14440111B2C9CA4534940486E4DBA2DA14440C6DCB5847C5249408690F3FE3F9E4440C6DCB5847C524940
36610	54324	40.810580000000002	40.835498999999999	50.698469000000003	50.680498999999998	Садовая	0103000020E610000001000000050000005665DF15C1674440F8FA5A971A5749405665DF15C16744408A22A46E675949409C6B98A1F16A44408A22A46E675949409C6B98A1F16A4440F8FA5A971A5749405665DF15C1674440F8FA5A971A574940
36651	19453	40.93965	40.988294000000003	50.578383000000002	50.519950999999999	40 лет Октября	0103000020E61000000100000005000000DCD7817346784440E1421EC18D424940DCD7817346784440FCC74274084A4940A16AF46A807E4440FCC74274084A4940A16AF46A807E4440E1421EC18D424940DCD7817346784440E1421EC18D424940
37222	18987	40.848390000000002	40.874693000000001	50.657304000000003	50.636896	Центральная	0103000020E610000001000000050000007120240B986C4440037AE1CE855149407120240B986C4440D7C39789225449402385B2F0F56F4440D7C39789225449402385B2F0F56F4440037AE1CE855149407120240B986C4440037AE1CE85514940
37149	18987	40.848390000000002	40.874693000000001	50.657304000000003	50.636896	Первомайская	0103000020E610000001000000050000007120240B986C4440037AE1CE855149407120240B986C4440D7C39789225449402385B2F0F56F4440D7C39789225449402385B2F0F56F4440037AE1CE855149407120240B986C4440037AE1CE85514940
37026	18987	40.848390000000002	40.874693000000001	50.657304000000003	50.636896	Памяти	0103000020E610000001000000050000007120240B986C4440037AE1CE855149407120240B986C4440D7C39789225449402385B2F0F56F4440D7C39789225449402385B2F0F56F4440037AE1CE855149407120240B986C4440037AE1CE85514940
36719	54350	40.951562000000003	40.959412999999998	50.581316999999999	50.557043	Пролетарская	0103000020E61000000100000005000000E50E9BC8CC7944409DBB5D2F4D474940E50E9BC8CC794440EECD6F98684A4940BA2D910BCE7A4440EECD6F98684A4940BA2D910BCE7A44409DBB5D2F4D474940E50E9BC8CC7944409DBB5D2F4D474940
36825	19294	41.119788999999997	41.180408	50.635348	50.539248000000001	Школьная площадь	0103000020E61000000100000005000000D4B5F63E558F44407A37161406454940D4B5F63E558F44401DCA501553514940E8F7FD9B179744401DCA501553514940E8F7FD9B179744407A37161406454940D4B5F63E558F44407A37161406454940
36769	19294	41.119788999999997	41.180408	50.635348	50.539248000000001	Советская	0103000020E61000000100000005000000D4B5F63E558F44407A37161406454940D4B5F63E558F44401DCA501553514940E8F7FD9B179744401DCA501553514940E8F7FD9B179744407A37161406454940D4B5F63E558F44407A37161406454940
37033	19294	41.119788999999997	41.180408	50.635348	50.539248000000001	Борцов Революции площадь	0103000020E61000000100000005000000D4B5F63E558F44407A37161406454940D4B5F63E558F44401DCA501553514940E8F7FD9B179744401DCA501553514940E8F7FD9B179744407A37161406454940D4B5F63E558F44407A37161406454940
37137	18685	41.122034999999997	41.136318000000003	50.704470999999998	50.676955	Горького	0103000020E61000000100000005000000D2FBC6D79E8F44408DEE2076A6564940D2FBC6D79E8F44407EFD101B2C5A494096ED43DE729144407EFD101B2C5A494096ED43DE729144408DEE2076A6564940D2FBC6D79E8F44408DEE2076A6564940
36383	19162	41.040647999999997	41.081502999999998	50.777915999999998	50.721724000000002	Школьный второй переулок	0103000020E61000000100000005000000EB5223F433854440815EB873615C4940EB5223F4338544407F8461C09263494050C3B7B06E8A44407F8461C09263494050C3B7B06E8A4440815EB873615C4940EB5223F433854440815EB873615C4940
36525	19128	40.877620999999998	40.905945000000003	50.610900999999998	50.585715999999998	Первомайская	0103000020E6100000010000000500000033A48AE255704440395FECBDF84A494033A48AE255704440FE0B0401324E4940C47C7901F6734440FE0B0401324E4940C47C7901F6734440395FECBDF84A494033A48AE255704440395FECBDF84A4940
36428	19008	41.270347000000001	41.312764999999999	50.632846000000001	50.611804999999997	50 лет Октября	0103000020E610000001000000050000002EC901BB9AA24440BF4351A04F4E49402EC901BB9AA24440C4B3041901514940AE2AFBAE08A84440C4B3041901514940AE2AFBAE08A84440BF4351A04F4E49402EC901BB9AA24440BF4351A04F4E4940
36812	18922	40.811146000000001	40.846215999999998	50.662489000000001	50.641838	Калинина	0103000020E61000000100000005000000FF23D3A1D36744403FAA61BF27524940FF23D3A1D3674440D97A8670CC5449400CAD4ECE506C4440D97A8670CC5449400CAD4ECE506C44403FAA61BF27524940FF23D3A1D36744403FAA61BF27524940
37074	19659	40.636575999999998	40.670316999999997	50.629783000000003	50.612335999999999	комсомольская	0103000020E6100000010000000500000091B586527B514440EC14AB06614E494091B586527B514440D449B6BA9C504940F6798CF2CC554440D449B6BA9C504940F6798CF2CC554440EC14AB06614E494091B586527B514440EC14AB06614E4940
36691	54332	40.718386000000002	40.758262000000002	50.661844000000002	50.649532000000001	Кирова	0103000020E61000000100000005000000BFF38B12F45B44404DDA54DD23534940BFF38B12F45B4440E486DF4DB754494058E6ADBA0E614440E486DF4DB754494058E6ADBA0E6144404DDA54DD23534940BFF38B12F45B44404DDA54DD23534940
36992	18591	40.873992000000001	40.948211000000001	50.768175999999997	50.729033999999999	Октябрьская	0103000020E610000001000000050000009A7B48F8DE6F444006D671FC505D49409A7B48F8DE6F44403AC95697536249408E5A61FA5E7944403AC95697536249408E5A61FA5E79444006D671FC505D49409A7B48F8DE6F444006D671FC505D4940
37236	54438	40.742766000000003	40.767901000000002	50.616622999999997	50.607134000000002	Кирова	0103000020E61000000100000005000000564ACFF4125F444014252191B64D4940564ACFF4125F44400F7BA180ED4E494069C878944A6244400F7BA180ED4E494069C878944A62444014252191B64D4940564ACFF4125F444014252191B64D4940
36669	49004	41.121712000000002	41.130873999999999	50.787917	50.772863999999998	Советская	0103000020E61000000100000005000000F0C34142948F4440BC202235ED624940F0C34142948F4440317BD976DA644940C7F2AE7AC0904440317BD976DA644940C7F2AE7AC0904440BC202235ED624940F0C34142948F4440BC202235ED624940
36392	49004	41.121712000000002	41.130873999999999	50.787917	50.772863999999998	Полевая	0103000020E61000000100000005000000F0C34142948F4440BC202235ED624940F0C34142948F4440317BD976DA644940C7F2AE7AC0904440317BD976DA644940C7F2AE7AC0904440BC202235ED624940F0C34142948F4440BC202235ED624940
35804	18777	40.902577000000001	40.974603999999999	50.675561999999999	50.616410999999999	Чкалова	0103000020E61000000100000005000000978FA4A48773444084F23E8EE64E4940978FA4A487734440CE35CCD0785649408046E9D2BF7C4440CE35CCD0785649408046E9D2BF7C444084F23E8EE64E4940978FA4A48773444084F23E8EE64E4940
35749	18777	40.902577000000001	40.974603999999999	50.675561999999999	50.616410999999999	Калинина	0103000020E61000000100000005000000978FA4A48773444084F23E8EE64E4940978FA4A487734440CE35CCD0785649408046E9D2BF7C4440CE35CCD0785649408046E9D2BF7C444084F23E8EE64E4940978FA4A48773444084F23E8EE64E4940
36933	18672	41.144942	41.221001999999999	50.727631000000002	50.704783999999997	Ленина	0103000020E610000001000000050000008EE89E758D9244403D5FB35C365A49408EE89E758D92444024473A03235D4940E02C25CB499C444024473A03235D4940E02C25CB499C44403D5FB35C365A49408EE89E758D9244403D5FB35C365A4940
36986	18531	41.025224000000001	41.041249999999998	50.770603000000001	50.740172999999999	Свободы	0103000020E6100000010000000500000083893F8A3A834440EC3026FDBD5E494083893F8A3A83444089997D1EA3624940E17A14AE4785444089997D1EA3624940E17A14AE47854440EC3026FDBD5E494083893F8A3A834440EC3026FDBD5E4940
36074	18489	40.956744999999998	40.998175000000003	50.723878999999997	50.696170000000002	Центральная	0103000020E6100000010000000500000046CEC29E767A4440693A3B191C59494046CEC29E767A44406EA12B11A85C4940A857CA32C47F44406EA12B11A85C4940A857CA32C47F4440693A3B191C59494046CEC29E767A4440693A3B191C594940
36814	19253	41.133955999999998	41.154060000000001	50.813898999999999	50.795211000000002	Ленина	0103000020E610000001000000050000002E8D5F7825914440B1355B79C96549402E8D5F7825914440A19FA9D72D68494096CFF23CB8934440A19FA9D72D68494096CFF23CB8934440B1355B79C96549402E8D5F7825914440B1355B79C9654940
36426	18289	40.153840000000002	40.213738999999997	51.888648000000003	51.865546000000002	Мира	0103000020E6100000010000000500000088687407B113444081971936CAEE494088687407B1134440F2D3B837BFF149409B70AFCC5B1B4440F2D3B837BFF149409B70AFCC5B1B444081971936CAEE494088687407B113444081971936CAEE4940
35797	18321	39.574911999999998	39.615200999999999	51.831158000000002	51.809769000000003	ломоносова	0103000020E61000000100000005000000FA0967B796C943404628B682A6E74940FA0967B796C9434086E7A56263EA4940B6BB07E8BECE434086E7A56263EA4940B6BB07E8BECE43404628B682A6E74940FA0967B796C943404628B682A6E74940
36813	18164	39.868256000000002	39.905724999999997	51.784159000000002	51.759058000000003	Ленина	0103000020E6100000010000000500000024473A0323EF434033E202D028E1494024473A0323EF43409AEE75525FE44940B515FBCBEEF343409AEE75525FE44940B515FBCBEEF3434033E202D028E1494024473A0323EF434033E202D028E14940
36524	18069	39.752867999999999	39.800379999999997	51.736369000000003	51.709957000000003	Леваневского	0103000020E610000001000000050000003B1A87FA5DE043407C48F8DEDFDA49403B1A87FA5DE04340E564E25641DE4940AD2F12DA72E64340E564E25641DE4940AD2F12DA72E643407C48F8DEDFDA49403B1A87FA5DE043407C48F8DEDFDA4940
35839	45616	40.08475	40.116173000000003	51.921798000000003	51.907465000000002	Молодежная	0103000020E61000000100000005000000022B8716D90A4440E0A128D027F44940022B8716D90A444055C2137AFDF54940D0D6C1C1DE0E444055C2137AFDF54940D0D6C1C1DE0E4440E0A128D027F44940022B8716D90A4440E0A128D027F44940
36025	47235	39.558086000000003	39.573753000000004	51.820754000000001	51.799906999999997	Школьная	0103000020E61000000100000005000000802DAF5C6FC74340B56B425A63E64940802DAF5C6FC74340D50792770EE94940AF7D01BD70C94340D50792770EE94940AF7D01BD70C94340B56B425A63E64940802DAF5C6FC74340B56B425A63E64940
37135	17866	40.096060000000001	40.120908	51.905498999999999	51.884628999999997	Заречная	0103000020E61000000100000005000000153AAFB14B0C4440ED0BE8853BF14940153AAFB14B0C4440C5C72764E7F3494092E9D0E9790F4440C5C72764E7F3494092E9D0E9790F4440ED0BE8853BF14940153AAFB14B0C4440ED0BE8853BF14940
36481	45581	39.613987999999999	39.648493000000002	51.809925	51.791952999999999	Совхозная	0103000020E610000001000000050000007711A62897CE43400B7C45B75EE549407711A62897CE43403D9B559FABE74940AC5791D101D343403D9B559FABE74940AC5791D101D343400B7C45B75EE549407711A62897CE43400B7C45B75EE54940
37148	47550	39.574283000000001	39.602103999999997	51.808337999999999	51.783718999999998	Некрасова	0103000020E610000001000000050000000BD3F71A82C943407D2079E750E449400BD3F71A82C94340990E9D9E77E7494038656EBE11CD4340990E9D9E77E7494038656EBE11CD43407D2079E750E449400BD3F71A82C943407D2079E750E44940
36931	47279	40.241380999999997	40.267431999999999	51.816155999999999	51.80444	Комсомольская	0103000020E6100000010000000500000019709692E51E444010CCD1E3F7E6494019709692E51E44409337C0CC77E84940B2F336363B2244409337C0CC77E84940B2F336363B22444010CCD1E3F7E6494019709692E51E444010CCD1E3F7E64940
37070	16938	39.893571000000001	39.958618000000001	51.964530000000003	51.922559	Московская	0103000020E61000000100000005000000B7D3D68860F24340B3D0CE6916F64940B7D3D68860F24340650113B875FB4940B0AD9FFEB3FA4340650113B875FB4940B0AD9FFEB3FA4340B3D0CE6916F64940B7D3D68860F24340B3D0CE6916F64940
36874	17732	40.316785000000003	40.341264000000002	51.944603999999998	51.913331999999997	Ленина	0103000020E61000000100000005000000836E2F698C284440F4311F10E8F44940836E2F698C284440DCD5ABC8E8F84940ADA6EB89AE2B4440DCD5ABC8E8F84940ADA6EB89AE2B4440F4311F10E8F44940836E2F698C284440F4311F10E8F44940
37072	17579	39.663485000000001	39.682915999999999	51.866357999999998	51.856090999999999	Ленина	0103000020E610000001000000050000007B319413EDD4434031B3CF6394ED49407B319413EDD443406150A6D1E4EE494023F59ECA69D743406150A6D1E4EE494023F59ECA69D7434031B3CF6394ED49407B319413EDD4434031B3CF6394ED4940
36022	54279	39.570959000000002	39.601447999999998	51.893006	51.862081000000003	Генерала Лохматикова	0103000020E61000000100000005000000AE2D3C2F15C9434062C092AB58EE4940AE2D3C2F15C94340DE9046054EF249404F1F813FFCCC4340DE9046054EF249404F1F813FFCCC434062C092AB58EE4940AE2D3C2F15C9434062C092AB58EE4940
35914	47638	39.827832000000001	39.863683999999999	51.851534999999998	51.822446999999997	Комарова	0103000020E61000000100000005000000884A2366F6E94340BED87BF145E94940884A2366F6E943401E335019FFEC49400B0A83328DEE43401E335019FFEC49400B0A83328DEE4340BED87BF145E94940884A2366F6E94340BED87BF145E94940
35748	17272	39.884614999999997	39.979117000000002	51.868459999999999	51.818516000000002	Школьная	0103000020E61000000100000005000000884677103BF143405AA0DD21C5E84940884677103BF143402CF180B229EF494094FAB2B453FD43402CF180B229EF494094FAB2B453FD43405AA0DD21C5E84940884677103BF143405AA0DD21C5E84940
35902	17272	39.884614999999997	39.979117000000002	51.868459999999999	51.818516000000002	Октябрьская	0103000020E61000000100000005000000884677103BF143405AA0DD21C5E84940884677103BF143402CF180B229EF494094FAB2B453FD43402CF180B229EF494094FAB2B453FD43405AA0DD21C5E84940884677103BF143405AA0DD21C5E84940
36021	17272	39.884614999999997	39.979117000000002	51.868459999999999	51.818516000000002	Ленина	0103000020E61000000100000005000000884677103BF143405AA0DD21C5E84940884677103BF143402CF180B229EF494094FAB2B453FD43402CF180B229EF494094FAB2B453FD43405AA0DD21C5E84940884677103BF143405AA0DD21C5E84940
36132	17272	39.884614999999997	39.979117000000002	51.868459999999999	51.818516000000002	50 лет Октября	0103000020E61000000100000005000000884677103BF143405AA0DD21C5E84940884677103BF143402CF180B229EF494094FAB2B453FD43402CF180B229EF494094FAB2B453FD43405AA0DD21C5E84940884677103BF143405AA0DD21C5E84940
36932	17251	40.186512	40.232092000000002	51.960002000000003	51.916137999999997	Ленина	0103000020E61000000100000005000000E1270EA0DF174440B94F8E0244F54940E1270EA0DF1744401C0C7558E1FA4940E5D4CE30B51D44401C0C7558E1FA4940E5D4CE30B51D4440B94F8E0244F54940E1270EA0DF174440B94F8E0244F54940
36761	17148	40.125166	40.171483000000002	51.828502999999998	51.801192999999998	50 лет Октября	0103000020E610000001000000050000001B498270051044405E64027E8DE649401B49827005104440A6D1E4620CEA4940F568AA27F3154440A6D1E4620CEA4940F568AA27F31544405E64027E8DE649401B498270051044405E64027E8DE64940
37073	18054	40.082019000000003	40.111080000000001	51.979849000000002	51.924109000000001	Харина	0103000020E6100000010000000500000048533D997F0A44403A78263449F6494048533D997F0A4440580229B16BFD4940AE9E93DE370E4440580229B16BFD4940AE9E93DE370E44403A78263449F6494048533D997F0A44403A78263449F64940
37146	47189	39.845061999999999	39.897838	51.938758	51.905098000000002	50 лет Октября	0103000020E61000000100000005000000D28BDAFD2AEC434067D65240DAF34940D28BDAFD2AEC4340DF6DDE3829F84940938D075BECF24340DF6DDE3829F84940938D075BECF2434067D65240DAF34940D28BDAFD2AEC434067D65240DAF34940
36806	17557	40.081561000000001	40.112031999999999	51.792743999999999	51.767803000000001	Кольцова	0103000020E6100000010000000500000085D04197700A4440A662635E47E2494085D04197700A4440D40CA9A278E54940800D8810570E4440D40CA9A278E54940800D8810570E4440A662635E47E2494085D04197700A4440A662635E47E24940
36595	17029	39.721741000000002	39.817672000000002	51.914555	51.884400999999997	Гагарина	0103000020E610000001000000050000005797530262DC43405CC64D0D34F149405797530262DC434057B2632310F549406E6DE179A9E8434057B2632310F549406E6DE179A9E843405CC64D0D34F149405797530262DC43405CC64D0D34F14940
37320	47408	40.012697000000003	40.076216000000002	51.836171999999998	51.816656999999999	Гагарина	0103000020E61000000100000005000000F0E0270EA00144405586713788E84940F0E0270EA00144405BEA20AF07EB49404AB72572C10944405BEA20AF07EB49404AB72572C10944405586713788E84940F0E0270EA00144405586713788E84940
35900	16793	40.529237000000002	40.575868	50.373159000000001	50.338107000000001	Центральная	0103000020E61000000100000005000000A56ABB09BE4344403BC61517472B4940A56ABB09BE434440A29A92ACC32F49400E68E90AB6494440A29A92ACC32F49400E68E90AB64944403BC61517472B4940A56ABB09BE4344403BC61517472B4940
36386	47034	40.438344999999998	40.499169999999999	50.231071999999998	50.196815000000001	Ленина	0103000020E61000000100000005000000BCAE5FB01B3844405E2EE23B31194940BCAE5FB01B384440BA826DC4931D4940799274CDE43F4440BA826DC4931D4940799274CDE43F44405E2EE23B31194940BCAE5FB01B3844405E2EE23B31194940
36385	46903	40.447113000000002	40.484338999999999	50.156720999999997	50.127063999999997	Алпеева	0103000020E61000000100000005000000E84EB0FF3A394440DD3F16A243104940E84EB0FF3A39444057CC086F0F144940B39602D2FE3D444057CC086F0F144940B39602D2FE3D4440DD3F16A243104940E84EB0FF3A394440DD3F16A243104940
37194	54410	40.216963999999997	40.241092999999999	50.042952999999997	50.031982999999997	Школьная	0103000020E610000001000000050000006534F279C51B44409483D904180449406534F279C51B4440EE21E17B7F054940B325AB22DC1E4440EE21E17B7F054940B325AB22DC1E44409483D904180449406534F279C51B44409483D90418044940
36389	46976	40.078803999999998	40.118409999999997	50.196002	50.157274999999998	Дьячкова	0103000020E61000000100000005000000A165DD3F160A44403CBD529621144940A165DD3F160A4440ADF9F197161949407AC2120F280F4440ADF9F197161949407AC2120F280F44403CBD529621144940A165DD3F160A44403CBD529621144940
36382	16629	40.489711	40.572508999999997	50.235325000000003	50.112133999999998	Ленина	0103000020E61000000100000005000000E8BE9CD9AE3E444084622B685A0E4940E8BE9CD9AE3E444032772D211F1E494034D593F94749444032772D211F1E494034D593F94749444084622B685A0E4940E8BE9CD9AE3E444084622B685A0E4940
36558	16629	40.489711	40.572508999999997	50.235325000000003	50.112133999999998	50 лет Победы	0103000020E61000000100000005000000E8BE9CD9AE3E444084622B685A0E4940E8BE9CD9AE3E444032772D211F1E494034D593F94749444032772D211F1E494034D593F94749444084622B685A0E4940E8BE9CD9AE3E444084622B685A0E4940
36045	16629	40.489711	40.572508999999997	50.235325000000003	50.112133999999998	40 лет Победы	0103000020E61000000100000005000000E8BE9CD9AE3E444084622B685A0E4940E8BE9CD9AE3E444032772D211F1E494034D593F94749444032772D211F1E494034D593F94749444084622B685A0E4940E8BE9CD9AE3E444084622B685A0E4940
36802	47130	40.487375	40.515501999999998	50.406612000000003	50.384141999999997	Первомайская	0103000020E61000000100000005000000AAF1D24D623E44409082A7902B314940AAF1D24D623E4440A114ADDC0B344940E48233F8FB414440A114ADDC0B344940E48233F8FB4144409082A7902B314940AAF1D24D623E44409082A7902B314940
36485	47004	40.322723000000003	40.396286000000003	50.320959999999999	50.237036000000003	Октябрьская	0103000020E610000001000000050000006155BDFC4E294440C2FC1532571E49406155BDFC4E2944407EA99F37152949406CEEE87FB93244407EA99F37152949406CEEE87FB9324440C2FC1532571E49406155BDFC4E294440C2FC1532571E4940
36594	47004	40.322723000000003	40.396286000000003	50.320959999999999	50.237036000000003	Авдеева	0103000020E610000001000000050000006155BDFC4E294440C2FC1532571E49406155BDFC4E2944407EA99F37152949406CEEE87FB93244407EA99F37152949406CEEE87FB9324440C2FC1532571E49406155BDFC4E294440C2FC1532571E4940
36645	37645	40.276198999999998	40.324367000000002	50.091448	50.065804999999997	Центральная	0103000020E610000001000000050000000D18247D5A234440E674594C6C0849400D18247D5A2344406EA46C91B40B494069739CDB842944406EA46C91B40B494069739CDB84294440E674594C6C0849400D18247D5A234440E674594C6C084940
67103	46954	40.106569999999998	40.257344000000003	50.119926	50.094061000000004	Центральная	0103000020E610000001000000050000000B5EF415A40D44401F6ADB300A0C49400B5EF415A40D444055F833BC590F494032E9EFA5F020444055F833BC590F494032E9EFA5F02044401F6ADB300A0C49400B5EF415A40D44401F6ADB300A0C4940
36202	46954	40.106569999999998	40.257344000000003	50.119926	50.094061000000004	Советская	0103000020E610000001000000050000000B5EF415A40D44401F6ADB300A0C49400B5EF415A40D444055F833BC590F494032E9EFA5F020444055F833BC590F494032E9EFA5F02044401F6ADB300A0C49400B5EF415A40D44401F6ADB300A0C4940
36557	15955	40.334257000000001	40.461091000000003	50.184218999999999	50.123413999999997	Прогресс	0103000020E61000000100000005000000C3BAF1EEC82A44402CEFAA07CC0F4940C3BAF1EEC82A4440A226FA7C941749406FBDA607053B4440A226FA7C941749406FBDA607053B44402CEFAA07CC0F4940C3BAF1EEC82A44402CEFAA07CC0F4940
36425	15955	40.334257000000001	40.461091000000003	50.184218999999999	50.123413999999997	Правды	0103000020E61000000100000005000000C3BAF1EEC82A44402CEFAA07CC0F4940C3BAF1EEC82A4440A226FA7C941749406FBDA607053B4440A226FA7C941749406FBDA607053B44402CEFAA07CC0F4940C3BAF1EEC82A44402CEFAA07CC0F4940
36483	15955	40.334257000000001	40.461091000000003	50.184218999999999	50.123413999999997	Первомайская	0103000020E61000000100000005000000C3BAF1EEC82A44402CEFAA07CC0F4940C3BAF1EEC82A4440A226FA7C941749406FBDA607053B4440A226FA7C941749406FBDA607053B44402CEFAA07CC0F4940C3BAF1EEC82A44402CEFAA07CC0F4940
36134	15955	40.334257000000001	40.461091000000003	50.184218999999999	50.123413999999997	Братская Площадь	0103000020E61000000100000005000000C3BAF1EEC82A44402CEFAA07CC0F4940C3BAF1EEC82A4440A226FA7C941749406FBDA607053B4440A226FA7C941749406FBDA607053B44402CEFAA07CC0F4940C3BAF1EEC82A44402CEFAA07CC0F4940
35686	15955	40.334257000000001	40.461091000000003	50.184218999999999	50.123413999999997	60 лет октября	0103000020E61000000100000005000000C3BAF1EEC82A44402CEFAA07CC0F4940C3BAF1EEC82A4440A226FA7C941749406FBDA607053B4440A226FA7C941749406FBDA607053B44402CEFAA07CC0F4940C3BAF1EEC82A44402CEFAA07CC0F4940
36181	15955	40.334257000000001	40.461091000000003	50.184218999999999	50.123413999999997	22-го Партсъезда	0103000020E61000000100000005000000C3BAF1EEC82A44402CEFAA07CC0F4940C3BAF1EEC82A4440A226FA7C941749406FBDA607053B4440A226FA7C941749406FBDA607053B44402CEFAA07CC0F4940C3BAF1EEC82A44402CEFAA07CC0F4940
37384	54485	39.144447999999997	39.158434999999997	51.732168000000001	51.724738000000002	1-е Мая	0103000020E610000001000000050000007EFCA5457D9243409015FC36C4DC49407EFCA5457D924340C09657AEB7DD494058C51B9947944340C09657AEB7DD494058C51B99479443409015FC36C4DC49407EFCA5457D9243409015FC36C4DC4940
37205	54417	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	Молодежная площадь	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
37199	54413	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	40 лет Победы	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
36876	15820	40.625365000000002	40.670901000000001	50.951217	50.923563999999999	Советская	0103000020E610000001000000050000001288D7F50B504440A8E15B58377649401288D7F50B5044401A33897AC179494046ED7E15E05544401A33897AC179494046ED7E15E0554440A8E15B58377649401288D7F50B504440A8E15B5837764940
36484	15669	40.733010999999998	40.765304999999998	50.756154000000002	50.732796999999998	Комарова	0103000020E61000000100000005000000DB4DF04DD35D4440AFCDC64ACC5D4940DB4DF04DD35D4440AB5E7EA7C96049408E3BA583F5614440AB5E7EA7C96049408E3BA583F5614440AFCDC64ACC5D4940DB4DF04DD35D4440AFCDC64ACC5D4940
37069	46755	40.706079000000003	40.735652000000002	50.930943999999997	50.914268	Ленина	0103000020E610000001000000050000003AB2F2CB605A4440C1E3DBBB067549403AB2F2CB605A44402634492C29774940569E40D8295E44402634492C29774940569E40D8295E4440C1E3DBBB067549403AB2F2CB605A4440C1E3DBBB06754940
37067	15562	40.853608999999999	40.883487000000002	50.960799999999999	50.94661	Советская	0103000020E610000001000000050000001F49490F436D4440850838842A7949401F49490F436D444097FF907EFB7A494078B81D1A1671444097FF907EFB7A494078B81D1A16714440850838842A7949401F49490F436D4440850838842A794940
36380	46540	40.360371000000001	40.425480999999998	50.682805000000002	50.655928000000003	Пески	0103000020E61000000100000005000000A2B60DA3202E4440EE43DE72F5534940A2B60DA3202E4440CC457C2766574940E108522976364440CC457C2766574940E108522976364440EE43DE72F5534940A2B60DA3202E4440EE43DE72F5534940
36182	46540	40.360371000000001	40.425480999999998	50.682805000000002	50.655928000000003	Ленина	0103000020E61000000100000005000000A2B60DA3202E4440EE43DE72F5534940A2B60DA3202E4440CC457C2766574940E108522976364440CC457C2766574940E108522976364440EE43DE72F5534940A2B60DA3202E4440EE43DE72F5534940
36800	46659	40.769303000000001	40.804220000000001	50.808213000000002	50.794168999999997	Школьная	0103000020E610000001000000050000007BDB4C85786244409E3F6D54A76549407BDB4C8578624440DD99098673674940026553AEF0664440DD99098673674940026553AEF06644409E3F6D54A76549407BDB4C85786244409E3F6D54A7654940
35931	46397	40.558782000000001	40.578904999999999	50.892552999999999	50.878346999999998	Советская	0103000020E61000000100000005000000F7CB272B8647444015C5ABAC6D704940F7CB272B864744402D793C2D3F724940D53E1D8F194A44402D793C2D3F724940D53E1D8F194A444015C5ABAC6D704940F7CB272B8647444015C5ABAC6D704940
36064	46397	40.558782000000001	40.578904999999999	50.892552999999999	50.878346999999998	50 Лет Октября	0103000020E61000000100000005000000F7CB272B8647444015C5ABAC6D704940F7CB272B864744402D793C2D3F724940D53E1D8F194A44402D793C2D3F724940D53E1D8F194A444015C5ABAC6D704940F7CB272B8647444015C5ABAC6D704940
36477	46507	40.451388999999999	40.501694000000001	50.995938000000002	50.973103999999999	Октябрьская	0103000020E610000001000000050000001763601DC7394440ABCDFFAB8E7C49401763601DC7394440FD6B79E57A7F4940BA4C4D8237404440FD6B79E57A7F4940BA4C4D8237404440ABCDFFAB8E7C49401763601DC7394440ABCDFFAB8E7C4940
35792	14904	40.149303000000003	40.221662999999999	50.868535999999999	50.818058999999998	Советская	0103000020E61000000100000005000000EC18575C1C13444067994528B6684940EC18575C1C13444007B309302C6F4940DBDD03745F1C444007B309302C6F4940DBDD03745F1C444067994528B6684940EC18575C1C13444067994528B6684940
36157	14904	40.149303000000003	40.221662999999999	50.868535999999999	50.818058999999998	Заводская	0103000020E61000000100000005000000EC18575C1C13444067994528B6684940EC18575C1C13444007B309302C6F4940DBDD03745F1C444007B309302C6F4940DBDD03745F1C444067994528B6684940EC18575C1C13444067994528B6684940
36990	15615	40.803061	40.825043000000001	50.936967000000003	50.922808000000003	Зеленая	0103000020E61000000100000005000000B6D8EDB3CA6644405C3E92921E764940B6D8EDB3CA6644403337DF88EE77494099654F029B6944403337DF88EE77494099654F029B6944405C3E92921E764940B6D8EDB3CA6644405C3E92921E764940
36520	15256	40.889451999999999	40.933478999999998	50.896262999999998	50.870952000000003	Ленина	0103000020E610000001000000050000004FAE2990D97144406231EA5A7B6F49404FAE2990D9714440B3CEF8BEB87249405B40683D7C774440B3CEF8BEB87249405B40683D7C7744406231EA5A7B6F49404FAE2990D97144406231EA5A7B6F4940
37249	48455	40.284157999999998	40.305475000000001	50.850296999999998	50.839706999999997	Дальняя	0103000020E61000000100000005000000C972124A5F244440739CDB847B6B4940C972124A5F24444086713788D66C4940705F07CE1927444086713788D66C4940705F07CE19274440739CDB847B6B4940C972124A5F244440739CDB847B6B4940
36198	46429	40.405358999999997	40.513300999999998	50.885393000000001	50.841481000000002	Октябрьская	0103000020E61000000100000005000000D311C0CDE23344404A9A3FA6B56B4940D311C0CDE2334440BD8DCD8E547149408600E0D8B3414440BD8DCD8E547149408600E0D8B34144404A9A3FA6B56B4940D311C0CDE23344404A9A3FA6B56B4940
36015	46429	40.405358999999997	40.513300999999998	50.885393000000001	50.841481000000002	Дзержинского	0103000020E61000000100000005000000D311C0CDE23344404A9A3FA6B56B4940D311C0CDE2334440BD8DCD8E547149408600E0D8B3414440BD8DCD8E547149408600E0D8B34144404A9A3FA6B56B4940D311C0CDE23344404A9A3FA6B56B4940
36523	15022	40.403103999999999	40.522275	50.770175000000002	50.677782999999998	Советская	0103000020E61000000100000005000000827170E9983344407364E597C1564940827170E99833444031992A18956249405B423EE8D942444031992A18956249405B423EE8D94244407364E597C1564940827170E9983344407364E597C1564940
36482	15022	40.403103999999999	40.522275	50.770175000000002	50.677782999999998	Ленинская	0103000020E61000000100000005000000827170E9983344407364E597C1564940827170E99833444031992A18956249405B423EE8D942444031992A18956249405B423EE8D94244407364E597C1564940827170E9983344407364E597C1564940
36422	14981	40.266317999999998	40.305008000000001	50.897001000000003	50.875078999999999	50 лет Октября	0103000020E61000000100000005000000062B4EB5162244404C35B39602704940062B4EB5162244405ABDC3EDD07249405A828C800A2744405ABDC3EDD07249405A828C800A2744404C35B39602704940062B4EB5162244404C35B39602704940
36756	14609	40.516939000000001	40.534914000000001	50.815105000000003	50.806840999999999	Набережная	0103000020E610000001000000050000007383A10E2B4244403509DE90466749407383A10E2B4244402EE7525C556849401616DC0F784444402EE7525C556849401616DC0F784444403509DE90466749407383A10E2B4244403509DE9046674940
36480	46203	40.642865	40.677143999999998	50.808126999999999	50.781697999999999	Ленина	0103000020E610000001000000050000001C5F7B66495244409FAC18AE0E6449401C5F7B6649524440DE019EB470674940605793A7AC564440DE019EB470674940605793A7AC5644409FAC18AE0E6449401C5F7B66495244409FAC18AE0E644940
37183	46676	40.793171000000001	40.822195000000001	50.774157000000002	50.752256000000003	Советская	0103000020E610000001000000050000005C9198A086654440221CB3EC496049405C9198A086654440187C9A9317634940A5F78DAF3D694440187C9A9317634940A5F78DAF3D694440221CB3EC496049405C9198A086654440221CB3EC49604940
37316	54465	40.513795000000002	40.534483000000002	50.786385000000003	50.774926000000001	Пролетарская	0103000020E6100000010000000500000096ECD808C4414440F96871C63063494096ECD808C441444051888043A86449404DA25EF06944444051888043A86449404DA25EF069444440F96871C63063494096ECD808C4414440F96871C630634940
36522	14807	40.405611	40.499341000000001	50.780383	50.700744999999998	Ленина	0103000020E61000000100000005000000EDF2AD0FEB334440F2EA1C03B2594940EDF2AD0FEB3344405CAD1397E3634940A646E867EA3F44405CAD1397E3634940A646E867EA3F4440F2EA1C03B2594940EDF2AD0FEB334440F2EA1C03B2594940
35878	14807	40.405611	40.499341000000001	50.780383	50.700744999999998	Ивана Бочарникова	0103000020E61000000100000005000000EDF2AD0FEB334440F2EA1C03B2594940EDF2AD0FEB3344405CAD1397E3634940A646E867EA3F44405CAD1397E3634940A646E867EA3F4440F2EA1C03B2594940EDF2AD0FEB334440F2EA1C03B2594940
36475	14706	40.714028999999996	40.800294000000001	50.869059	50.832391000000001	Октябрьская	0103000020E61000000100000005000000A2B2614D655B44400C3ECDC98B6A4940A2B2614D655B4440B1A547533D6F4940AF97A60870664440B1A547533D6F4940AF97A608706644400C3ECDC98B6A4940A2B2614D655B44400C3ECDC98B6A4940
37065	14706	40.714028999999996	40.800294000000001	50.869059	50.832391000000001	Ленина	0103000020E61000000100000005000000A2B2614D655B44400C3ECDC98B6A4940A2B2614D655B4440B1A547533D6F4940AF97A60870664440B1A547533D6F4940AF97A608706644400C3ECDC98B6A4940A2B2614D655B44400C3ECDC98B6A4940
37200	46950	40.944744	41.008173999999997	50.931165	50.909855	Советская	0103000020E61000000100000005000000CE8B135FED784440118DEE2076744940CE8B135FED78444005172B6A30774940B8567BD80B81444005172B6A30774940B8567BD80B814440118DEE2076744940CE8B135FED784440118DEE2076744940
36954	46950	40.944744	41.008173999999997	50.931165	50.909855	Ленина	0103000020E61000000100000005000000CE8B135FED784440118DEE2076744940CE8B135FED78444005172B6A30774940B8567BD80B81444005172B6A30774940B8567BD80B814440118DEE2076744940CE8B135FED784440118DEE2076744940
36537	13865	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	площадь Воли	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
36016	13865	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	пер. Связистов	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
35780	13865	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Чехова	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
35781	13865	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Победы	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
36147	13865	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Красная	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
36029	13865	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Кирова	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
36031	13865	40.538246999999998	40.655351000000003	50.866660000000003	50.792226999999997	Блинова	0103000020E61000000100000005000000C6151747E54444400C01C0B167654940C6151747E54444402D6002B7EE6E49405133A48AE25344402D6002B7EE6E49405133A48AE25344400C01C0B167654940C6151747E54444400C01C0B167654940
35778	13280	42.120502999999999	42.174213999999999	51.440767000000001	51.414850000000001	Переулок Первомайский	0103000020E61000000100000005000000F2086EA46C0F4540705F07CE19B54940F2086EA46C0F4540F913950D6BB84940AF40F4A44C164540F913950D6BB84940AF40F4A44C164540705F07CE19B54940F2086EA46C0F4540705F07CE19B54940
36551	13280	42.120502999999999	42.174213999999999	51.440767000000001	51.414850000000001	Красная	0103000020E61000000100000005000000F2086EA46C0F4540705F07CE19B54940F2086EA46C0F4540F913950D6BB84940AF40F4A44C164540F913950D6BB84940AF40F4A44C164540705F07CE19B54940F2086EA46C0F4540705F07CE19B54940
37010	45640	42.000236999999998	42.022281999999997	51.290387000000003	51.278894999999999	Ворошилова	0103000020E61000000100000005000000E49F19C4070045404B02D4D4B2A34940E49F19C4070045407F17B6662BA549400DA5F622DA0245407F17B6662BA549400DA5F622DA0245404B02D4D4B2A34940E49F19C4070045404B02D4D4B2A34940
37086	13747	42.596798999999997	42.632705000000001	51.458004000000003	51.429592999999997	Молодежная	0103000020E610000001000000050000008BA4DDE8634C454096CB46E7FCB649408BA4DDE8634C4540F6B704E09FBA49400282397AFC504540F6B704E09FBA49400282397AFC50454096CB46E7FCB649408BA4DDE8634C454096CB46E7FCB64940
36674	45737	42.450508999999997	42.502189000000001	51.377715999999999	51.345587000000002	Народная	0103000020E61000000100000005000000DEC66647AA3945401D76DF313CAC4940DEC66647AA394540859675FF58B049409AB4A9BA47404540859675FF58B049409AB4A9BA474045401D76DF313CAC4940DEC66647AA3945401D76DF313CAC4940
36592	13830	42.343060999999999	42.381104999999998	51.349789999999999	51.319954000000003	Московская	0103000020E610000001000000050000003BC43F6CE92B4540B91CAF40F4A849403BC43F6CE92B4540E23B31EBC5AC4940C9AB730CC8304540E23B31EBC5AC4940C9AB730CC8304540B91CAF40F4A849403BC43F6CE92B4540B91CAF40F4A84940
37257	54453	42.523434000000002	42.559654000000002	51.410946000000003	51.393521999999997	Борисоглебская	0103000020E61000000100000005000000A7CEA3E2FF424540D520CCED5EB24940A7CEA3E2FF4245400536E7E099B44940AD8905BEA24745400536E7E099B44940AD8905BEA2474540D520CCED5EB24940A7CEA3E2FF424540D520CCED5EB24940
36394	45809	42.276774000000003	42.307955	51.289338999999998	51.270983999999999	Первомайская	0103000020E610000001000000050000000A3197546D234540A0DE8C9AAFA249400A3197546D2345408A3A730F09A54940E1D1C6116B2745408A3A730F09A54940E1D1C6116B274540A0DE8C9AAFA249400A3197546D234540A0DE8C9AAFA24940
36469	13404	42.292350999999996	42.333449000000002	51.503549999999997	51.484479	Свободы	0103000020E61000000100000005000000F8F9EFC16B254540A54C6A6803BE4940F8F9EFC16B2545404DF38E5374C0494024F1F274AE2A45404DF38E5374C0494024F1F274AE2A4540A54C6A6803BE4940F8F9EFC16B254540A54C6A6803BE4940
36922	13469	42.371250000000003	42.407919	51.574582999999997	51.516387000000002	Свободы	0103000020E61000000100000005000000EC51B81E852F45402F8A1EF818C24940EC51B81E852F454035EB8CEF8BC94940613596B03634454035EB8CEF8BC94940613596B0363445402F8A1EF818C24940EC51B81E852F45402F8A1EF818C24940
36940	54380	42.590268000000002	42.631419999999999	51.507452000000001	51.473619999999997	Коммуны	0103000020E610000001000000050000000BF0DDE68D4B4540A25D85949FBC49400BF0DDE68D4B45401825E82FF4C049402905DD5ED25045401825E82FF4C049402905DD5ED2504540A25D85949FBC49400BF0DDE68D4B4540A25D85949FBC4940
36646	45695	42.534995000000002	42.568412000000002	51.527572999999997	51.490020000000001	Советская	0103000020E61000000100000005000000034356B77A4445406631B1F9B8BE4940034356B77A44454055A0168387C34940B55373B9C148454055A0168387C34940B55373B9C14845406631B1F9B8BE4940034356B77A4445406631B1F9B8BE4940
37088	13586	42.618287000000002	42.667470000000002	51.443747999999999	51.412154000000001	Советская	0103000020E610000001000000050000005F454607244F454032755776C1B449405F454607244F45402CD505BCCCB84940D3872EA86F5545402CD505BCCCB84940D3872EA86F55454032755776C1B449405F454607244F454032755776C1B44940
36468	29588	42.145341999999999	42.216191999999999	51.489437000000002	51.465663999999997	Советская	0103000020E610000001000000050000001C5E10919A1245405776C1E09ABB49401C5E10919A124540E73922DFA5BE494013D4F02DAC1B4540E73922DFA5BE494013D4F02DAC1B45405776C1E09ABB49401C5E10919A1245405776C1E09ABB4940
37122	10327	40.377223999999998	40.399430000000002	49.746586000000001	49.728076999999999	Октябрьская	0103000020E6100000010000000500000016A243E04830444022FC8BA031DD484016A243E04830444063D34A2190DF48404985B1852033444063D34A2190DF48404985B1852033444022FC8BA031DD484016A243E04830444022FC8BA031DD4840
36873	49319	40.469723000000002	40.502789999999997	50.052132999999998	50.033394999999999	Молодёжная	0103000020E61000000100000005000000EA961DE21F3C4440CA6C904946044940EA961DE21F3C44406C054D4BAC064940BF60376C5B4044406C054D4BAC064940BF60376C5B404440CA6C904946044940EA961DE21F3C4440CA6C904946044940
74980	60412	40.188496999999998	41.04663	50.127197000000002	49.578563000000003	Парковая	0103000020E61000000100000005000000723271AB201844407CD6355A0ECA4840723271AB201844401D93C5FD471049409981CAF8F78544401D93C5FD471049409981CAF8F78544407CD6355A0ECA4840723271AB201844407CD6355A0ECA4840
36869	9974	40.646647000000002	40.674188999999998	49.932242000000002	49.911543000000002	Ленина	0103000020E610000001000000050000003C873254C5524440E9F2E670ADF448403C873254C552444094FAB2B453F7484056293DD34B56444094FAB2B453F7484056293DD34B564440E9F2E670ADF448403C873254C5524440E9F2E670ADF44840
36587	11552	40.326604000000003	40.367333000000002	49.956543000000003	49.923305999999997	Калинина	0103000020E61000000100000005000000145FED28CE294440AC1919E42EF64840145FED28CE294440DF1B430070FA4840ECDE8AC4042F4440DF1B430070FA4840ECDE8AC4042F4440AC1919E42EF64840145FED28CE294440AC1919E42EF64840
36664	11459	40.880316000000001	40.933182000000002	49.817037999999997	49.789287000000002	Советская	0103000020E61000000100000005000000A112D731AE70444038143E5B07E54840A112D731AE7044406CCB80B394E84840A29BFD81727744406CCB80B394E84840A29BFD817277444038143E5B07E54840A112D731AE70444038143E5B07E54840
36755	10972	40.750185999999999	40.772554	49.979470999999997	49.958300000000001	Героя Бондарева	0103000020E6100000010000000500000062F5471806604440DFE00B93A9FA484062F5471806604440B130444E5FFD48406E32AA0CE3624440B130444E5FFD48406E32AA0CE3624440DFE00B93A9FA484062F5471806604440DFE00B93A9FA4840
37136	48943	40.767515000000003	40.791508999999998	49.760652999999998	49.747377	Садовая	0103000020E61000000100000005000000401878EE3D6244402C64AE0CAADF4840401878EE3D624440594DD7135DE14840ADBEBA2A50654440594DD7135DE14840ADBEBA2A506544402C64AE0CAADF4840401878EE3D6244402C64AE0CAADF4840
37322	49304	40.434688999999999	40.461486000000001	50.038423000000002	50.020085000000002	 Центральная	0103000020E6100000010000000500000029779FE3A3374440F11131259202494029779FE3A337444005357C0BEB044940EBC726F9113B444005357C0BEB044940EBC726F9113B4440F11131259202494029779FE3A3374440F111312592024940
36549	11312	40.469301000000002	40.523001999999998	49.818555000000003	49.776845000000002	Воробьева	0103000020E61000000100000005000000747D1F0E123C4440D3872EA86FE34840747D1F0E123C4440187D0569C6E848400DDFC2BAF1424440187D0569C6E848400DDFC2BAF1424440D3872EA86FE34840747D1F0E123C4440D3872EA86FE34840
37090	48133	40.477978999999998	40.516587999999999	49.919773999999997	49.906292000000001	Калинина	0103000020E610000001000000050000005F96766A2E3D44402F50526001F448405F96766A2E3D444005DB8827BBF54840C6C03A8E1F42444005DB8827BBF54840C6C03A8E1F4244402F50526001F448405F96766A2E3D44402F50526001F44840
37355	48133	40.477978999999998	40.516587999999999	49.919773999999997	49.906292000000001	 Крупской	0103000020E610000001000000050000005F96766A2E3D44402F50526001F448405F96766A2E3D444005DB8827BBF54840C6C03A8E1F42444005DB8827BBF54840C6C03A8E1F4244402F50526001F448405F96766A2E3D44402F50526001F44840
36987	48726	40.535741000000002	40.564711000000003	49.894402999999997	49.852521000000003	Мира	0103000020E610000001000000050000002C103D29934444409D137B681FED48402C103D2993444440DE3829CC7BF248408258367348484440DE3829CC7BF2484082583673484844409D137B681FED48402C103D29934444409D137B681FED4840
36753	10906	40.487645000000001	40.504255000000001	49.657103999999997	49.635708999999999	Советская	0103000020E610000001000000050000006A87BF266B3E4440ED629AE95ED148406A87BF266B3E44400F09DFFB1BD4484018EC866D8B4044400F09DFFB1BD4484018EC866D8B404440ED629AE95ED148406A87BF266B3E4440ED629AE95ED14840
37233	54435	40.499071000000001	40.521107000000001	49.999237999999998	49.989531999999997	Садовая	0103000020E61000000100000005000000E6B0FB8EE13F4440382C0DFCA8FE4840E6B0FB8EE13F4440D175E107E7FF4840BC5B59A2B3424440D175E107E7FF4840BC5B59A2B3424440382C0DFCA8FE4840E6B0FB8EE13F4440382C0DFCA8FE4840
37063	49259	40.188496999999998	41.04663	50.127197000000002	49.578563000000003	Школьная	0103000020E61000000100000005000000723271AB201844407CD6355A0ECA4840723271AB201844401D93C5FD471049409981CAF8F78544401D93C5FD471049409981CAF8F78544407CD6355A0ECA4840723271AB201844407CD6355A0ECA4840
74934	60385	40.371932999999999	40.392440999999998	49.636361999999998	49.620199	Кирова	0103000020E61000000100000005000000CEA623809B2F444086014BAE62CF4840CEA623809B2F444065355D4F74D14840054EB6813B32444065355D4F74D14840054EB6813B32444086014BAE62CF4840CEA623809B2F444086014BAE62CF4840
36649	49016	40.888238999999999	40.929831	49.860211	49.808301	Центральная	0103000020E610000001000000050000001004C8D0B17144407C293C6876E748401004C8D0B17144406954E0641BEE48404BE7C3B3047744406954E0641BEE48404BE7C3B3047744407C293C6876E748401004C8D0B17144407C293C6876E74840
36870	48991	40.690466000000001	40.733172000000003	49.755961999999997	49.742255	Низовая	0103000020E61000000100000005000000FE7F9C306158444070253B3602DF4840FE7F9C30615844406682E15CC3E04840E52B8194D85D44406682E15CC3E04840E52B8194D85D444070253B3602DF4840FE7F9C306158444070253B3602DF4840
37193	54409	40.712600999999999	40.732894000000002	49.806986999999999	49.791711999999997	Российская	0103000020E61000000100000005000000670C7382365B4440E5EC9DD156E54840670C7382365B444009A69A594BE74840A2B77878CF5D444009A69A594BE74840A2B77878CF5D4440E5EC9DD156E54840670C7382365B4440E5EC9DD156E54840
36585	48896	40.315339000000002	40.353419000000002	49.922575000000002	49.899509999999999	Мира	0103000020E61000000100000005000000A11342075D2844406536C82423F34840A11342075D284440B98D06F016F648407C6473D53C2D4440B98D06F016F648407C6473D53C2D44406536C82423F34840A11342075D2844406536C82423F34840
36663	11114	40.432245999999999	40.473154999999998	49.915672999999998	49.890282999999997	Ленина	0103000020E61000000100000005000000D5E940D653374440A69718CBF4F14840D5E940D653374440446ADAC534F548402D78D157903C4440446ADAC534F548402D78D157903C4440A69718CBF4F14840D5E940D653374440A69718CBF4F14840
36516	10209	40.454883000000002	40.483745999999996	49.801475000000003	49.761561	Кирова	0103000020E61000000100000005000000D1402C9B393A44405C74B2D47AE14840D1402C9B393A4440E3C798BB96E6484010C99063EB3D4440E3C798BB96E6484010C99063EB3D44405C74B2D47AE14840D1402C9B393A44405C74B2D47AE14840
36515	10836	40.401811000000002	40.443061	49.663017000000004	49.642155000000002	Первомайская	0103000020E610000001000000050000002716F88A6E33444040FB912232D248402716F88A6E33444095D8B5BDDDD4484008910C39B638444095D8B5BDDDD4484008910C39B638444040FB912232D248402716F88A6E33444040FB912232D24840
36650	11083	40.532443999999998	40.558621000000002	49.913828000000002	49.883713	Октябрьская	0103000020E61000000100000005000000C879FF1F274444406806F1811DF14840C879FF1F27444440A515DF50F8F44840EEED96E480474440A515DF50F8F44840EEED96E4804744406806F1811DF14840C879FF1F274444406806F1811DF14840
36751	46558	40.754390999999998	40.774683000000003	49.930942999999999	49.914565000000003	Западная	0103000020E61000000100000005000000C8B260E28F6044407B88467710F54840C8B260E28F60444056B8E52329F7484033E202D02863444056B8E52329F7484033E202D0286344407B88467710F54840C8B260E28F6044407B88467710F54840
35682	10174	40.564711000000003	40.596879999999999	49.959823999999998	49.936463000000003	Малаховского	0103000020E61000000100000005000000825836734848444000750305DEF7484082583673484844403CF54883DBFA484078D15790664C44403CF54883DBFA484078D15790664C444000750305DEF74840825836734848444000750305DEF74840
37391	47193	40.564523000000001	40.615574000000002	50.072749000000002	50.029384999999998	Пролетарская	0103000020E610000001000000050000007F6B274A4248444019FF3EE3C20349407F6B274A424844408AE8D7D64F0949404B22FB20CB4E44408AE8D7D64F0949404B22FB20CB4E444019FF3EE3C20349407F6B274A4248444019FF3EE3C2034940
37273	47193	40.564523000000001	40.615574000000002	50.072749000000002	50.029384999999998	Ленина	0103000020E610000001000000050000007F6B274A4248444019FF3EE3C20349407F6B274A424844408AE8D7D64F0949404B22FB20CB4E44408AE8D7D64F0949404B22FB20CB4E444019FF3EE3C20349407F6B274A4248444019FF3EE3C2034940
37186	54405	40.508476999999999	40.541013999999997	49.846231000000003	49.813561999999997	переулок Рабочий	0103000020E6100000010000000500000054E23AC61541444059A2B3CC22E8484054E23AC61541444042EE224C51EC4840CD565EF23F45444042EE224C51EC4840CD565EF23F45444059A2B3CC22E8484054E23AC61541444059A2B3CC22E84840
35884	9770	40.575868	40.621538999999999	49.920267000000003	49.896335999999998	Школьная	0103000020E610000001000000050000000E68E90AB64944401D1D5723BBF248400E68E90AB6494440454B1E4FCBF54840221807978E4F4440454B1E4FCBF54840221807978E4F44401D1D5723BBF248400E68E90AB64944401D1D5723BBF24840
36420	10438	40.213999999999999	40.284669999999998	49.915064000000001	49.897902999999999	Центральная	0103000020E6100000010000000500000008AC1C5A641B44407AFD497CEEF2484008AC1C5A641B44409CDF30D120F548407F130A11702444409CDF30D120F548407F130A11702444407AFD497CEEF2484008AC1C5A641B44407AFD497CEEF24840
36930	10130	40.589692999999997	40.616041000000003	50.020774000000003	50.003684999999997	Центральная	0103000020E610000001000000050000000ED76A0F7B4B44402D3E05C0780049400ED76A0F7B4B4440B64DF1B8A802494061FF756EDA4E4440B64DF1B8A802494061FF756EDA4E44402D3E05C0780049400ED76A0F7B4B44402D3E05C078004940
37147	52290	40.619256999999998	40.639577000000003	49.992502999999999	49.972906999999999	1-е Мая	0103000020E61000000100000005000000D76839D0434F44405586713788FC4840D76839D0434F444048179B560AFF48400C23BDA8DD51444048179B560AFF48400C23BDA8DD5144405586713788FC4840D76839D0434F44405586713788FC4840
37061	11026	40.441687000000002	40.512976999999999	49.929476000000001	49.918509	Пролетарская	0103000020E61000000100000005000000C0081A3389384440740AF2B391F54840C0081A33893844405D35CF11F9F64840D34CF73AA94144405D35CF11F9F64840D34CF73AA9414440740AF2B391F54840C0081A3389384440740AF2B391F54840
37275	54460	40.532192000000002	40.546565000000001	49.606212999999997	49.593986999999998	Авиаторов	0103000020E61000000100000005000000AF9811DE1E444440E49F19C407CC4840AF9811DE1E4444407CB4386398CD4840B21188D7F54544407CB4386398CD4840B21188D7F5454440E49F19C407CC4840AF9811DE1E444440E49F19C407CC4840
36039	9513	40.520775	40.579551000000002	49.950671999999997	49.918503000000001	урицкого	0103000020E6100000010000000500000086C954C1A842444092239D8191F5484086C954C1A8424440889CBE9EAFF948409BAE27BA2E4A4440889CBE9EAFF948409BAE27BA2E4A444092239D8191F5484086C954C1A842444092239D8191F54840
36140	9513	40.520775	40.579551000000002	49.950671999999997	49.918503000000001	военный городок	0103000020E6100000010000000500000086C954C1A842444092239D8191F5484086C954C1A8424440889CBE9EAFF948409BAE27BA2E4A4440889CBE9EAFF948409BAE27BA2E4A444092239D8191F5484086C954C1A842444092239D8191F54840
35988	9513	40.520775	40.579551000000002	49.950671999999997	49.918503000000001	Советская	0103000020E6100000010000000500000086C954C1A842444092239D8191F5484086C954C1A8424440889CBE9EAFF948409BAE27BA2E4A4440889CBE9EAFF948409BAE27BA2E4A444092239D8191F5484086C954C1A842444092239D8191F54840
35893	9513	40.520775	40.579551000000002	49.950671999999997	49.918503000000001	Карла Маркса	0103000020E6100000010000000500000086C954C1A842444092239D8191F5484086C954C1A8424440889CBE9EAFF948409BAE27BA2E4A4440889CBE9EAFF948409BAE27BA2E4A444092239D8191F5484086C954C1A842444092239D8191F54840
36739	11416	40.931170000000002	40.949756000000001	49.799881999999997	49.788198999999999	Коммунаров	0103000020E6100000010000000500000017821C9430774440B5DE6FB4E3E4484017821C94307744405C548B8862E648400397C79A917944405C548B8862E648400397C79A91794440B5DE6FB4E3E4484017821C9430774440B5DE6FB4E3E44840
36146	9176	39.952616999999996	39.985235000000003	51.059522000000001	51.034118999999997	Свободы	0103000020E610000001000000050000008B4E965AEFF943400B96EA025E8449408B4E965AEFF943403EB2B96A9E874940F2EF332E1CFE43403EB2B96A9E874940F2EF332E1CFE43400B96EA025E8449408B4E965AEFF943400B96EA025E844940
36439	9176	39.952616999999996	39.985235000000003	51.059522000000001	51.034118999999997	Микрорайон Юбилейный	0103000020E610000001000000050000008B4E965AEFF943400B96EA025E8449408B4E965AEFF943403EB2B96A9E874940F2EF332E1CFE43403EB2B96A9E874940F2EF332E1CFE43400B96EA025E8449408B4E965AEFF943400B96EA025E844940
36590	8636	39.824382999999997	39.851709	51.295512000000002	51.255586999999998	Советская	0103000020E610000001000000050000006E30D46185E9434031242713B7A049406E30D46185E94340ACC95356D3A54940BC5AEECC04ED4340ACC95356D3A54940BC5AEECC04ED434031242713B7A049406E30D46185E9434031242713B7A04940
36378	8943	40.176440999999997	40.214449000000002	51.257733999999999	51.232137000000002	Большая Советская	0103000020E610000001000000050000003656629E9516444085984BAAB69D49403656629E951644409C887E6DFDA0494078D49810731B44409C887E6DFDA0494078D49810731B444085984BAAB69D49403656629E9516444085984BAAB69D4940
36661	7994	40.015832000000003	40.117386000000003	50.823931000000002	50.765338999999997	Чибисовка	0103000020E610000001000000050000007A1D71C8060244403AADDBA0F66149407A1D71C8060244408E942D92766949400F812381060F44408E942D92766949400F812381060F44403AADDBA0F66149407A1D71C8060244403AADDBA0F6614940
36373	7994	40.015832000000003	40.117386000000003	50.823931000000002	50.765338999999997	Советская	0103000020E610000001000000050000007A1D71C8060244403AADDBA0F66149407A1D71C8060244408E942D92766949400F812381060F44408E942D92766949400F812381060F44403AADDBA0F66149407A1D71C8060244403AADDBA0F6614940
36473	8884	40.139341000000002	40.201019000000002	51.307766000000001	51.276708999999997	Советская	0103000020E61000000100000005000000F8FE06EDD511444022C154336BA34940F8FE06EDD51144400E6954E064A74940F46F97FDBA1944400E6954E064A74940F46F97FDBA19444022C154336BA34940F8FE06EDD511444022C154336BA34940
35970	8735	40.247883999999999	40.323549999999997	51.140991	51.098973999999998	пушкина	0103000020E61000000100000005000000D099B4A9BA1F4440C093162EAB8C4940D099B4A9BA1F4440E2033BFE0B924940764F1E166A294440E2033BFE0B924940764F1E166A294440C093162EAB8C4940D099B4A9BA1F4440C093162EAB8C4940
36673	8735	40.247883999999999	40.323549999999997	51.140991	51.098973999999998	Сахарного завода	0103000020E61000000100000005000000D099B4A9BA1F4440C093162EAB8C4940D099B4A9BA1F4440E2033BFE0B924940764F1E166A294440E2033BFE0B924940764F1E166A294440C093162EAB8C4940D099B4A9BA1F4440C093162EAB8C4940
36017	8735	40.247883999999999	40.323549999999997	51.140991	51.098973999999998	Базарная площадь	0103000020E61000000100000005000000D099B4A9BA1F4440C093162EAB8C4940D099B4A9BA1F4440E2033BFE0B924940764F1E166A294440E2033BFE0B924940764F1E166A294440C093162EAB8C4940D099B4A9BA1F4440C093162EAB8C4940
36671	8735	40.247883999999999	40.323549999999997	51.140991	51.098973999999998	40 лет Октября	0103000020E61000000100000005000000D099B4A9BA1F4440C093162EAB8C4940D099B4A9BA1F4440E2033BFE0B924940764F1E166A294440E2033BFE0B924940764F1E166A294440C093162EAB8C4940D099B4A9BA1F4440C093162EAB8C4940
36738	8391	40.411054	40.442990000000002	51.046607000000002	51.034215000000003	Гагарина	0103000020E61000000100000005000000EB71DF6A9D3444402E04392861844940EB71DF6A9D344440E161DA37F78549403F3A75E5B3384440E161DA37F78549403F3A75E5B33844402E04392861844940EB71DF6A9D3444402E04392861844940
36372	8578	39.968516999999999	40.032378999999999	51.196326999999997	51.157789000000001	карла маркса	0103000020E610000001000000050000005D4F745DF8FB43409355116E329449405D4F745DF8FB434030293E3E21994940E109BDFE2404444030293E3E21994940E109BDFE240444409355116E329449405D4F745DF8FB43409355116E32944940
35961	54275	40.272542999999999	40.314261000000002	51.159376000000002	51.129500999999998	Рубежная	0103000020E610000001000000050000007AE063B0E22244404FE61F7D939049407AE063B0E222444037E2C96E6694494042B456B43928444037E2C96E6694494042B456B4392844404FE61F7D939049407AE063B0E22244404FE61F7D93904940
36717	54275	40.272542999999999	40.314261000000002	51.159376000000002	51.129500999999998	Ленина	0103000020E610000001000000050000007AE063B0E22244404FE61F7D939049407AE063B0E222444037E2C96E6694494042B456B43928444037E2C96E6694494042B456B4392844404FE61F7D939049407AE063B0E22244404FE61F7D93904940
36240	54275	40.272542999999999	40.314261000000002	51.159376000000002	51.129500999999998	Большая	0103000020E610000001000000050000007AE063B0E22244404FE61F7D939049407AE063B0E222444037E2C96E6694494042B456B43928444037E2C96E6694494042B456B4392844404FE61F7D939049407AE063B0E22244404FE61F7D93904940
35672	8351	40.182459999999999	40.237698000000002	51.061751999999998	51.015146000000001	Проспект Революции	0103000020E61000000100000005000000016A6AD95A1744402655DB4DF0814940016A6AD95A174440363B527DE78749408D2958E36C1E4440363B527DE78749408D2958E36C1E44402655DB4DF0814940016A6AD95A1744402655DB4DF0814940
36730	54358	39.943930000000002	39.951692000000001	51.332729999999998	51.328769000000001	Центральная	0103000020E610000001000000050000004DDBBFB2D2F843402578431A15AA49404DDBBFB2D2F84340F4328AE596AA4940B3EE1F0BD1F94340F4328AE596AA4940B3EE1F0BD1F943402578431A15AA49404DDBBFB2D2F843402578431A15AA4940
36621	7862	39.980365999999997	40.01267	50.951098000000002	50.931285000000003	Школьная	0103000020E610000001000000050000001F0E12A27CFD4340B020CD58347749401F0E12A27CFD434040A54A94BD794940F6D1A92B9F01444040A54A94BD794940F6D1A92B9F014440B020CD58347749401F0E12A27CFD4340B020CD5834774940
36804	8646	39.916728999999997	39.966217999999998	51.273857999999997	51.250045	Центральная	0103000020E61000000100000005000000BB25396057F54340A0C37C7901A04940BB25396057F54340BDDF68C70DA349403C670B08ADFB4340BDDF68C70DA349403C670B08ADFB4340A0C37C7901A04940BB25396057F54340A0C37C7901A04940
37228	46653	40.068302000000003	40.106983999999997	50.988092000000002	50.971997999999999	Строительная	0103000020E610000001000000050000002E20B41EBE08444082E3326E6A7C49402E20B41EBE08444039B874CC797E4940FE98D6A6B10D444039B874CC797E4940FE98D6A6B10D444082E3326E6A7C49402E20B41EBE08444082E3326E6A7C4940
36700	54340	39.806604999999998	39.825982000000003	51.133814000000001	51.116058000000002	Школьная	0103000020E6100000010000000500000021E527D53EE74340373811FDDA8E494021E527D53EE743409CDF30D120914940D78A36C7B9E943409CDF30D120914940D78A36C7B9E94340373811FDDA8E494021E527D53EE74340373811FDDA8E4940
36513	7936	39.969901	39.991999	51.017611000000002	50.989933999999998	Микрорайон	0103000020E61000000100000005000000C9AD49B725FC434067994528B67E4940C9AD49B725FC43406286C613418249401555BFD2F9FE43406286C613418249401555BFD2F9FE434067994528B67E4940C9AD49B725FC434067994528B67E4940
36799	8128	40.353580000000001	40.379479000000003	51.011049	50.993307999999999	Молодежная	0103000020E610000001000000050000008542041C422D4440766D6FB7247F49408542041C422D4440A6D3BA0D6A814940684293C492304440A6D3BA0D6A814940684293C492304440766D6FB7247F49408542041C422D4440766D6FB7247F4940
36591	8192	40.047946000000003	40.155295000000002	50.955807999999998	50.891745999999998	Ленинская	0103000020E61000000100000005000000ADFC3218230644405E2BA1BB24724940ADFC321823064440A9A0A2EA577A4940BD1DE1B4E0134440A9A0A2EA577A4940BD1DE1B4E01344405E2BA1BB24724940ADFC3218230644405E2BA1BB24724940
36538	7856	39.989061999999997	40.062184999999999	50.873766000000003	50.844859999999997	Мира	0103000020E61000000100000005000000B1DB679599FE43406AD95A5F246C4940B1DB679599FE4340AA2D7590D76F4940A0A696ADF5074440AA2D7590D76F4940A0A696ADF50744406AD95A5F246C4940B1DB679599FE43406AD95A5F246C4940
36863	8254	40.190050999999997	40.229891000000002	50.910530999999999	50.897585999999997	Центральная	0103000020E610000001000000050000003AC956975318444079AC1919E47249403AC9569753184440417FA1478C74494087527B116D1D4440417FA1478C74494087527B116D1D444079AC1919E47249403AC956975318444079AC1919E4724940
35959	8507	40.077356999999999	40.145629	51.204690999999997	51.167318000000002	советская	0103000020E61000000100000005000000EF8E8CD5E60944401D041DAD6A954940EF8E8CD5E60944408C648F50339A4940B22C98F8A31244408C648F50339A4940B22C98F8A31244401D041DAD6A954940EF8E8CD5E60944401D041DAD6A954940
36474	8994	39.776924999999999	39.818534999999997	51.238582999999998	51.150032000000003	Центральная	0103000020E61000000100000005000000EF38454772E343403FADA23F34934940EF38454772E34340D73043E3899E4940D0D03FC1C5E84340D73043E3899E4940D0D03FC1C5E843403FADA23F34934940EF38454772E343403FADA23F34934940
36805	8994	39.776924999999999	39.818534999999997	51.238582999999998	51.150032000000003	Ранняя Весна	0103000020E61000000100000005000000EF38454772E343403FADA23F34934940EF38454772E34340D73043E3899E4940D0D03FC1C5E84340D73043E3899E4940D0D03FC1C5E843403FADA23F34934940EF38454772E343403FADA23F34934940
36452	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Центральная	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
35730	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Красная печать	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
35964	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Комсомольская	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
36096	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Кирова	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
36120	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Калинина	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
35681	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Зои Космодемьянской	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
35729	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	Гоголя	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
36026	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	3 Интернационала	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
35745	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	22 января	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
35971	7352	39.958464999999997	40.135945	51.135176000000001	51.051250000000003	22 Января	0103000020E6100000010000000500000029AE2AFBAEFA4340C3F5285C8F86494029AE2AFBAEFA4340209A79724D914940018750A566114440209A79724D914940018750A566114440C3F5285C8F86494029AE2AFBAEFA4340C3F5285C8F864940
37059	8067	40.294794000000003	40.338974	50.997745999999999	50.973495	Советская	0103000020E610000001000000050000004D874ECFBB254440E6E8F17B9B7C49404D874ECFBB2544407FDB1324B67F4940DF180280632B44407FDB1324B67F4940DF180280632B4440E6E8F17B9B7C49404D874ECFBB254440E6E8F17B9B7C4940
36451	7283	40.653348000000001	40.705494999999999	51.482802	51.454237999999997	Советская	0103000020E61000000100000005000000197442E8A0534440DB4C857824BA4940197442E8A0534440C138B874CCBD4940EA3E00A94D5A4440C138B874CCBD4940EA3E00A94D5A4440DB4C857824BA4940197442E8A0534440DB4C857824BA4940
36797	6681	41.018217	41.044213999999997	51.394888000000002	51.382736000000001	Лесная	0103000020E61000000100000005000000999D45EF548244403D80457EFDB04940999D45EF548244409BCAA2B08BB249403E03EACDA88544409BCAA2B08BB249403E03EACDA88544403D80457EFDB04940999D45EF548244403D80457EFDB04940
37144	47198	40.182800999999998	40.214629000000002	51.417001999999997	51.388739000000001	Советская	0103000020E610000001000000050000008A56EE056617444002D71533C2B149408A56EE0566174440EC2E505260B54940F8E28BF6781B4440EC2E505260B54940F8E28BF6781B444002D71533C2B149408A56EE056617444002D71533C2B14940
37084	47317	40.499619000000003	40.557389999999998	51.423893	51.403215000000003	Ленина	0103000020E61000000100000005000000E9BAF083F33F4440DA20938C9CB34940E9BAF083F33F44406D00362042B64940088F368E584744406D00362042B64940088F368E58474440DA20938C9CB34940E9BAF083F33F4440DA20938C9CB34940
36725	7204	40.354495999999997	40.403500000000001	51.310288	51.266227999999998	Труда	0103000020E610000001000000050000000A48FB1F602D4440C6A354C213A249400A48FB1F602D4440AE2B6684B7A74940CFF753E3A5334440AE2B6684B7A74940CFF753E3A5334440C6A354C213A249400A48FB1F602D4440C6A354C213A24940
37062	7204	40.354495999999997	40.403500000000001	51.310288	51.266227999999998	Ленина	0103000020E610000001000000050000000A48FB1F602D4440C6A354C213A249400A48FB1F602D4440AE2B6684B7A74940CFF753E3A5334440AE2B6684B7A74940CFF753E3A5334440C6A354C213A249400A48FB1F602D4440C6A354C213A24940
36548	7148	40.349240999999999	40.4482	51.388925	51.358080000000001	Октябрьская	0103000020E610000001000000050000000FB6D8EDB32C444004ADC090D5AD49400FB6D8EDB32C444064CC5D4BC8B149409A081B9E5E39444064CC5D4BC8B149409A081B9E5E39444004ADC090D5AD49400FB6D8EDB32C444004ADC090D5AD4940
36709	53058	40.453536	40.528464	51.555988999999997	51.501739000000001	Мира	0103000020E6100000010000000500000082C7B7770D3A44405A10CAFB38C0494082C7B7770D3A4440C6F7C5A52AC74940828E56B5A4434440C6F7C5A52AC74940828E56B5A44344405A10CAFB38C0494082C7B7770D3A44405A10CAFB38C04940
35671	53058	40.453536	40.528464	51.555988999999997	51.501739000000001	Малая Советская	0103000020E6100000010000000500000082C7B7770D3A44405A10CAFB38C0494082C7B7770D3A4440C6F7C5A52AC74940828E56B5A4434440C6F7C5A52AC74940828E56B5A44344405A10CAFB38C0494082C7B7770D3A44405A10CAFB38C04940
36377	53058	40.453536	40.528464	51.555988999999997	51.501739000000001	Красная Площадь	0103000020E6100000010000000500000082C7B7770D3A44405A10CAFB38C0494082C7B7770D3A4440C6F7C5A52AC74940828E56B5A4434440C6F7C5A52AC74940828E56B5A44344405A10CAFB38C0494082C7B7770D3A44405A10CAFB38C04940
36792	47128	40.355161000000003	40.387464999999999	51.590688999999998	51.580840000000002	Молодежная	0103000020E6100000010000000500000047E867EA752D4440B51A12F758CA494047E867EA752D4440B08D78B29BCB49401DACFF7398314440B08D78B29BCB49401DACFF7398314440B51A12F758CA494047E867EA752D4440B51A12F758CA4940
36660	6844	40.623289999999997	40.663975000000001	51.629282000000003	51.606225999999999	Советская	0103000020E6100000010000000500000040F67AF7C74F444011FE45D098CD494040F67AF7C74F444012FB04508CD04940492EFF21FD54444012FB04508CD04940492EFF21FD54444011FE45D098CD494040F67AF7C74F444011FE45D098CD4940
37094	47222	40.115886000000003	40.155096999999998	51.375810000000001	51.345857000000002	Школьная	0103000020E610000001000000050000003A083A5AD50E4440DD0BCC0A45AC49403A083A5AD50E444040C1C58A1AB04940965AEF37DA13444040C1C58A1AB04940965AEF37DA134440DD0BCC0A45AC49403A083A5AD50E4440DD0BCC0A45AC4940
36659	6832	41.086039999999997	41.129302000000003	51.420316	51.388300999999998	Центральная	0103000020E61000000100000005000000EC12D55B038B44408600E0D8B3B14940EC12D55B038B444026FE28EACCB5494059A7CAF78C90444026FE28EACCB5494059A7CAF78C9044408600E0D8B3B14940EC12D55B038B44408600E0D8B3B14940
36370	6792	40.657732000000003	40.678797000000003	51.575080999999997	51.562328000000001	паркова	0103000020E610000001000000050000002FC4EA8F3054444003D0285DFAC749402FC4EA8F3054444086C613419CC94940BCCFF1D1E256444086C613419CC94940BCCFF1D1E256444003D0285DFAC749402FC4EA8F3054444003D0285DFAC74940
36554	47450	40.909987999999998	40.962845000000002	51.448557999999998	51.396664000000001	Ленинская	0103000020E6100000010000000500000050E09D7C7A74444012C0CDE2C5B2494050E09D7C7A744440F92D3A596AB94940FE0E45813E7B4440F92D3A596AB94940FE0E45813E7B444012C0CDE2C5B2494050E09D7C7A74444012C0CDE2C5B24940
36865	54370	40.501649999999998	40.575544999999998	51.47298	51.421894000000002	Ленина	0103000020E61000000100000005000000EA043411364044407730629F00B64940EA04341136404440BFD4CF9B8ABC49402B306475AB494440BFD4CF9B8ABC49402B306475AB4944407730629F00B64940EA043411364044407730629F00B64940
36658	5470	40.212715000000003	40.224815999999997	51.452621999999998	51.439138999999997	Плошадь Мира	0103000020E61000000100000005000000302FC03E3A1B4440F6B2EDB435B84940302FC03E3A1B44409DB98784EFB949400BCF4BC5C61C44409DB98784EFB949400BCF4BC5C61C4440F6B2EDB435B84940302FC03E3A1B4440F6B2EDB435B84940
36601	54312	40.939345000000003	40.974972000000001	51.496856000000001	51.446357999999996	50 лет Октября	0103000020E61000000100000005000000A054FB743C7844406B274A4222B94940A054FB743C784440236937FA98BF49400342EBE1CB7C4440236937FA98BF49400342EBE1CB7C44406B274A4222B94940A054FB743C7844406B274A4222B94940
36596	54322	40.248846	40.288910000000001	51.535601	51.508063	Юбилейная	0103000020E61000000100000005000000C6DE8B2FDA1F444061A7583508C14940C6DE8B2FDA1F44403A5AD5928EC4494062BEBC00FB2444403A5AD5928EC4494062BEBC00FB24444061A7583508C14940C6DE8B2FDA1F444061A7583508C14940
36794	47172	40.122525000000003	40.149769999999997	51.413626000000001	51.387171000000002	Школьная	0103000020E61000000100000005000000A1F831E6AE0F4440D57ABFD18EB14940A1F831E6AE0F44403D635FB2F1B4494001F6D1A92B1344403D635FB2F1B4494001F6D1A92B134440D57ABFD18EB14940A1F831E6AE0F4440D57ABFD18EB14940
36750	47354	40.582669000000003	40.613759000000002	51.424404000000003	51.413052999999998	Советская	0103000020E610000001000000050000004FB2D5E5944A4440E141B3EBDEB449404FB2D5E5944A44405325CADE52B649401650A8A78F4E44405325CADE52B649401650A8A78F4E4440E141B3EBDEB449404FB2D5E5944A4440E141B3EBDEB44940
37142	47104	40.414019000000003	40.440545999999998	51.578971000000003	51.562232999999999	Центральная	0103000020E6100000010000000500000019761893FE344440B1DD3D40F7C7494019761893FE3444408D2AC3B81BCA49401A31B3CF633844408D2AC3B81BCA49401A31B3CF63384440B1DD3D40F7C7494019761893FE344440B1DD3D40F7C74940
37245	54445	40.321581999999999	40.347183999999999	51.491467	51.472239000000002	Школьная	0103000020E61000000100000005000000BB7D569929294440A872DA5372BC4940BB7D56992929444018080264E8BE4940E4D87A86702C444018080264E8BE4940E4D87A86702C4440A872DA5372BC4940BB7D569929294440A872DA5372BC4940
37143	6164	40.287652999999999	40.351028999999997	51.541612000000001	51.524659	Школьная	0103000020E6100000010000000500000053CC41D0D1244440AA46AF0628C3494053CC41D0D1244440828FC18A53C549404A79AD84EE2C4440828FC18A53C549404A79AD84EE2C4440AA46AF0628C3494053CC41D0D1244440AA46AF0628C34940
16742	6709	41.043477000000003	41.070219999999999	51.433664	51.418422999999997	Школьная	0103000020E61000000100000005000000699082A790854440757286E28EB54940699082A790854440EDB94C4D82B7494037C30DF8FC884440EDB94C4D82B7494037C30DF8FC884440757286E28EB54940699082A790854440757286E28EB54940
37100	5675	41.059610999999997	41.089112	51.539707999999997	51.521033000000003	Коммунальная	0103000020E61000000100000005000000ADBD4F55A187444082919735B1C24940ADBD4F55A1874440DDB1D82615C5494030D7A205688B4440DDB1D82615C5494030D7A205688B444082919735B1C24940ADBD4F55A187444082919735B1C24940
36789	46327	40.410029999999999	40.439126999999999	51.539965000000002	51.522877000000001	Коммунистическая	0103000020E610000001000000050000007F30F0DC7B344440516A2FA2EDC249407F30F0DC7B34444009FEB7921DC5494032E543503538444009FEB7921DC5494032E5435035384440516A2FA2EDC249407F30F0DC7B344440516A2FA2EDC24940
37141	47055	40.914380000000001	40.959350000000001	51.545409999999997	51.517569999999999	Центральная площадь	0103000020E61000000100000005000000E90E62670A75444003B2D7BB3FC24940E90E62670A754440A774B0FECFC5494074B515FBCB7A4440A774B0FECFC5494074B515FBCB7A444003B2D7BB3FC24940E90E62670A75444003B2D7BB3FC24940
37157	47406	41.093953999999997	41.118963000000001	51.440845000000003	51.430962999999998	Центральная	0103000020E6100000010000000500000008AA46AF068C44409D64ABCB29B7494008AA46AF068C444075CDE49B6DB849408F37F92D3A8F444075CDE49B6DB849408F37F92D3A8F44409D64ABCB29B7494008AA46AF068C44409D64ABCB29B74940
36512	5516	40.285856000000003	40.323791999999997	51.445414999999997	51.398865999999998	Ленина	0103000020E61000000100000005000000C5AEEDED9624444040BE840A0EB34940C5AEEDED96244440EC12D55B03B949406C5A290472294440EC12D55B03B949406C5A29047229444040BE840A0EB34940C5AEEDED9624444040BE840A0EB34940
37325	54468	40.174644999999998	40.226900000000001	51.500523000000001	51.474018000000001	Молодежная	0103000020E6100000010000000500000078B471C45A16444090DB2F9FACBC494078B471C45A164440AAF23D2311C0494030BB270F0B1D4440AAF23D2311C0494030BB270F0B1D444090DB2F9FACBC494078B471C45A16444090DB2F9FACBC4940
35762	46942	40.481788000000002	40.529569000000002	51.499048000000002	51.47298	школьная	0103000020E6100000010000000500000079CDAB3AAB3D4440BFD4CF9B8ABC494079CDAB3AAB3D44402E910BCEE0BF4940DBFCBFEAC84344402E910BCEE0BF4940DBFCBFEAC8434440BFD4CF9B8ABC494079CDAB3AAB3D4440BFD4CF9B8ABC4940
36983	46840	40.758532000000002	40.813122	51.555512999999998	51.532795	Центральная	0103000020E61000000100000005000000187C9A9317614440753C66A032C44940187C9A93176144405DC0CB0C1BC749403DD4B661146844405DC0CB0C1BC749403DD4B66114684440753C66A032C44940187C9A9317614440753C66A032C44940
74974	54382	40.464756000000001	40.496799000000003	51.631697000000003	51.609940000000002	Садовая	0103000020E61000000100000005000000554FE61F7D3B4440D942908312CE4940554FE61F7D3B44409CFD8172DBD04940BFD7101C973F44409CFD8172DBD04940BFD7101C973F4440D942908312CE4940554FE61F7D3B4440D942908312CE4940
67095	54382	40.464756000000001	40.496799000000003	51.631697000000003	51.609940000000002	 Жданова	0103000020E61000000100000005000000554FE61F7D3B4440D942908312CE4940554FE61F7D3B44409CFD8172DBD04940BFD7101C973F44409CFD8172DBD04940BFD7101C973F4440D942908312CE4940554FE61F7D3B4440D942908312CE4940
36722	54353	40.794141000000003	40.818925	51.527337000000003	51.508595999999997	Совхозная	0103000020E61000000100000005000000D5B48B69A66544402E7079AC19C14940D5B48B69A6654440427C60C77FC349403B70CE88D2684440427C60C77FC349403B70CE88D26844402E7079AC19C14940D5B48B69A66544402E7079AC19C14940
36609	48878	40.173206999999998	40.231031999999999	51.349063999999998	51.298282999999998	Советская	0103000020E610000001000000050000001938A0A52B164440F4F928232EA649401938A0A52B164440001B1021AEAC49402C2AE274921D4440001B1021AEAC49402C2AE274921D4440F4F928232EA649401938A0A52B164440F4F928232EA64940
35946	54273	40.900924000000003	40.951633999999999	51.482897999999999	51.432248999999999	Мира	0103000020E610000001000000050000003C17467A51734440465D6BEF53B749403C17467A51734440E3A6069ACFBD49407EE19524CF794440E3A6069ACFBD49407EE19524CF794440465D6BEF53B749403C17467A51734440465D6BEF53B74940
36867	46872	40.939956000000002	40.987682999999997	51.371644000000003	51.333956999999998	Свободы	0103000020E61000000100000005000000E9D66B7A5078444098A25C1ABFAA4940E9D66B7A5078444098E0D40792AF494057E883656C7E444098E0D40792AF494057E883656C7E444098A25C1ABFAA4940E9D66B7A5078444098A25C1ABFAA4940
35823	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Чехова	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
35670	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Фридриха Энгельса	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
35887	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Советская	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
35763	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	М.Горького	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
36115	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Ленина	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
36114	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Красноармейская	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
35736	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Коммунальная	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
36141	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	К.Маркса	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
36050	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Гнездилова	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
35735	2900	40.378473	40.459913999999998	51.512273	51.462690000000002	Ватутина	0103000020E61000000100000005000000A2B5A2CD71304440D717096D39BB4940A2B5A2CD71304440D9CF622992C149407C7C4276DE3A4440D9CF622992C149407C7C4276DE3A4440D717096D39BB4940A2B5A2CD71304440D717096D39BB4940
37397	46242	40.826605999999998	40.875717000000002	51.346071000000002	51.329253000000001	Школьная	0103000020E61000000100000005000000B456B439CE694440118E59F624AA4940B456B439CE694440098CF50D4CAC49408FC6A17E17704440098CF50D4CAC49408FC6A17E17704440118E59F624AA4940B456B439CE694440118E59F624AA4940
36053	46242	40.826605999999998	40.875717000000002	51.346071000000002	51.329253000000001	Первомайская	0103000020E61000000100000005000000B456B439CE694440118E59F624AA4940B456B439CE694440098CF50D4CAC49408FC6A17E17704440098CF50D4CAC49408FC6A17E17704440118E59F624AA4940B456B439CE694440118E59F624AA4940
36765	38741	38.841123000000003	38.893763999999997	50.780810000000002	50.759151000000003	Ольшанская	0103000020E61000000100000005000000EB7420EBA96B4340E4DC26DC2B614940EB7420EBA96B4340E4310395F1634940CB2BD7DB66724340E4310395F1634940CB2BD7DB66724340E4DC26DC2B614940EB7420EBA96B4340E4DC26DC2B614940
34831	54153	40.405476	40.412168000000001	56.133989	56.133091	Воровского	0103000020E610000001000000050000000DA837A3E63344402B323A2009114C400DA837A3E63344400A83328D26114C40973AC8EBC13444400A83328D26114C40973AC8EBC13444402B323A2009114C400DA837A3E63344402B323A2009114C40
34789	54133	39.646013000000004	39.72034	56.520761999999998	56.477691	Шибанкова	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34560	54133	39.646013000000004	39.72034	56.520761999999998	56.477691	Авангардский переулок	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34469	54130	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	Ленина	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
34773	54145	38.5565	38.598236	56.389009999999999	56.359713999999997	Клубный переулок	0103000020E61000000100000005000000AC1C5A643B474340E8F4BC1B0B2E4C40AC1C5A643B47434092E86514CB314C401AA54BFF924C434092E86514CB314C401AA54BFF924C4340E8F4BC1B0B2E4C40AC1C5A643B474340E8F4BC1B0B2E4C40
34660	54136	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	Чайковского	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
34624	54136	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	Центральная площадь	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
34856	54136	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	Ленина	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
34584	54136	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	Димитрова	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
34862	54157	40.443545999999998	40.445037999999997	56.112527999999998	56.109957999999999	Школьная	0103000020E61000000100000005000000C422861DC63844407FF78E1A130E4C40C422861DC638444030F14751670E4C4016BD5301F738444030F14751670E4C4016BD5301F73844407FF78E1A130E4C40C422861DC63844407FF78E1A130E4C40
34754	54142	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	3 квартал	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
34666	54142	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	1 квартал	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
34559	54132	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	1 квартал	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
34567	54134	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	Пролетарская	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
34605	54138	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Советская площадь	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34710	54138	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Полевой проезд	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34959	54138	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Ленина	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34913	54138	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Клязьменская	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34634	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Тихомирова	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
74890	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Привокзальная площадь им. Гастелло	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
74892	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Московская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34815	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Мичуринская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34640	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Ленинградская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
13369	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Красногвардейская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34619	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Комсомольская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34769	41177	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Воровского	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34629	54140	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Королева	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34778	54140	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Дзержинского	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34460	54127	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Шмелева	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34736	54127	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Мира	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34749	54127	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Ленина	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34604	54127	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Дружбы	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34501	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	чернышевского	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34706	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	свердлова	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34522	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	проспект Ленина	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34708	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	подлесная	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34670	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	моховая	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34885	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	микрорайон Заречная Слободка	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34874	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Элеваторная	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34671	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Шмидта	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34574	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Циолковского	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34664	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Труда	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34757	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Строителей	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34756	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Сосновая	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34573	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Пионерская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34480	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Первомайская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
74915	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Октябрьская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34669	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Муромская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34817	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Московская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34875	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Малеева	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34520	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Лопатина	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34575	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Кошевого	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34752	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Колхозная	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34667	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Ковров-8	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34704	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Клязьминская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34637	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Зои Космодемьянской	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34608	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Запольная	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34758	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Жуковского	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34801	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Еловая	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34572	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Дегтярева	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34478	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Грибоедова	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34712	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Волго-Донская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34709	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Владимирская	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34542	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	Белинского	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34482	8940	41.379401999999999	41.398823999999998	56.410525	56.404772000000001	Абельмана	0103000020E61000000100000005000000BC04A73E90B04440132BA391CF334C40BC04A73E90B044405F984C158C344C40116E32AA0CB344405F984C158C344C40116E32AA0CB34440132BA391CF334C40BC04A73E90B04440132BA391CF334C40
34802	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	19 Партсъезда	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34799	8940	41.264885	41.406225999999997	56.408289000000003	56.286268	 Строителей	0103000020E61000000100000005000000B9196EC0E7A1444017F2086EA4244C40B9196EC0E7A1444085285FD042344C407764AC36FFB3444085285FD042344C407764AC36FFB3444017F2086EA4244C40B9196EC0E7A1444017F2086EA4244C40
34638	54126	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Пушкина	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
35107	54126	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Гагарина	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34458	54126	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	50 лет октября	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34448	54125	38.673749000000001	38.727072999999997	56.330140999999998	56.292777000000001	Мира	0103000020E610000001000000050000003A5B40683D564340B0027CB779254C403A5B40683D564340CC086F0F422A4C40FD6662BA105D4340CC086F0F422A4C40FD6662BA105D4340B0027CB779254C403A5B40683D564340B0027CB779254C40
34681	54125	38.673749000000001	38.727072999999997	56.330140999999998	56.292777000000001	Лермонтова	0103000020E610000001000000050000003A5B40683D564340B0027CB779254C403A5B40683D564340CC086F0F422A4C40FD6662BA105D4340CC086F0F422A4C40FD6662BA105D4340B0027CB779254C403A5B40683D564340B0027CB779254C40
34730	54144	40.962251999999999	41.032895000000003	56.363498999999997	56.337924999999998	Ленина	0103000020E610000001000000050000005B41D3122B7B44401AC05B20412B4C405B41D3122B7B444079909E22872E4C40D99942E73584444079909E22872E4C40D99942E7358444401AC05B20412B4C405B41D3122B7B44401AC05B20412B4C40
34860	54156	40.260865000000003	40.263012000000003	56.121220000000001	56.119529	Центральная	0103000020E61000000100000005000000E5D539066421444038F6ECB94C0F4C40E5D539066421444081CF0F23840F4C40503A9160AA21444081CF0F23840F4C40503A9160AA21444038F6ECB94C0F4C40E5D539066421444038F6ECB94C0F4C40
34468	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	торфяная	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34500	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	проспект 50-летия Советской власти	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34895	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	писарева	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34472	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Торфяная	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34516	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Рылеева	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34603	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Мира	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34662	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Микрорайон	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34563	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Менжинского	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
9878	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Менделеева	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34747	11724	40.553213	40.562798000000001	55.731175999999998	55.726872	Лесная	0103000020E610000001000000050000006C5CFFAECF464440663046240ADD4B406C5CFFAECF4644405FCFD72C97DD4B408A20CEC3094844405FCFD72C97DD4B408A20CEC309484440663046240ADD4B406C5CFFAECF464440663046240ADD4B40
34457	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Курская	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34565	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Кирова	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34441	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Интернациональная	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34697	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Димитрова	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34791	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	Александра Невского	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34470	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	2-я Народная	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
34471	11724	40.594014000000001	40.698120000000003	55.649524999999997	55.585937000000001	2-ая Народная	0103000020E61000000100000005000000DEAE97A6084C44401842CEFBFFCA4B40DEAE97A6084C44409A779CA223D34B407E5704FF5B5944409A779CA223D34B407E5704FF5B5944401842CEFBFFCA4B40DEAE97A6084C44401842CEFBFFCA4B40
74906	54137	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Ленина	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34678	54137	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Гагарина	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34675	54135	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Физкультурная	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34676	54135	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Советский переулок	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34580	54135	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Ленина	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34810	54135	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Железнодорожная	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34674	54135	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Горького	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
16314	3510	40.344012999999997	40.348047000000001	56.116016000000002	56.109662	улица Завадского	0103000020E610000001000000050000000D33349E082C444096CE8767090E4C400D33349E082C444008E8BE9CD90E4C40473CD9CD8C2C444008E8BE9CD90E4C40473CD9CD8C2C444096CE8767090E4C400D33349E082C444096CE8767090E4C40
15554	3510	40.455027000000001	40.498389000000003	56.175727000000002	56.151516999999998	улица Добросельская	0103000020E6100000010000000500000004E621533E3A4440DEE4B7E864134C4004E621533E3A44401903EB387E164C40D4D7F335CB3F44401903EB387E164C40D4D7F335CB3F4440DEE4B7E864134C4004E621533E3A4440DEE4B7E864134C40
16273	3510	40.351163999999997	40.363354000000001	56.144320999999998	56.141446999999999	улица Дачная	0103000020E610000001000000050000002AC423F1F22C4440048F6FEF1A124C402AC423F1F22C444021904B1C79124C40766F4562822E444021904B1C79124C40766F4562822E4440048F6FEF1A124C402AC423F1F22C4440048F6FEF1A124C40
15340	3510	40.367693000000003	40.405512000000002	56.152951000000002	56.133989	улица Горького	0103000020E61000000100000005000000ECFB7090102F44400A83328D26114C40ECFB7090102F4440FC71FBE593134C405A1135D1E7334440FC71FBE593134C405A1135D1E73344400A83328D26114C40ECFB7090102F44400A83328D26114C40
15502	3510	40.414180999999999	40.432668	56.137801000000003	56.127792999999997	улица Вокзальная	0103000020E61000000100000005000000F2CF0CE20335444030D461855B104C40F2CF0CE203354440952D9276A3114C404B033FAA61374440952D9276A3114C404B033FAA6137444030D461855B104C40F2CF0CE20335444030D461855B104C40
34864	3510	40.358611000000003	40.375562000000002	56.151367	56.132223000000003	проспект Строителей	0103000020E61000000100000005000000317E1AF7E62D4440B763EAAEEC104C40317E1AF7E62D4440C9586DFE5F134C4068CF656A12304440C9586DFE5F134C4068CF656A12304440B763EAAEEC104C40317E1AF7E62D4440B763EAAEEC104C40
74897	3510	40.165346999999997	40.517271000000001	56.187385999999996	56.051913999999996	микрорайон Оргтруд	0103000020E61000000100000005000000F0BE2A172A1544402E1A321EA5064C40F0BE2A172A15444037DDB243FC174C40A915A6EF3542444037DDB243FC174C40A915A6EF354244402E1A321EA5064C40F0BE2A172A1544402E1A321EA5064C40
74903	3510	40.456958	40.488453	56.172359999999998	56.158304999999999	Юбилейная	0103000020E61000000100000005000000A2D288997D3A44408AE5965643144C40A2D288997D3A4440BC9179E40F164C400951BEA0853E4440BC9179E40F164C400951BEA0853E44408AE5965643144C40A2D288997D3A44408AE5965643144C40
74917	3510	40.456958	40.488453	56.172359999999998	56.158304999999999	Юбилейная	0103000020E61000000100000005000000A2D288997D3A44408AE5965643144C40A2D288997D3A4440BC9179E40F164C400951BEA0853E4440BC9179E40F164C400951BEA0853E44408AE5965643144C40A2D288997D3A44408AE5965643144C40
34865	3510	40.197327000000001	40.230393999999997	56.100830999999999	56.089247	Энергетиков	0103000020E6100000010000000500000014CFD90242194440102219726C0B4C4014CFD9024219444024B6BB07E80C4C40E998F38C7D1D444024B6BB07E80C4C40E998F38C7D1D4440102219726C0B4C4014CFD90242194440102219726C0B4C40
34845	3510	40.443545999999998	40.445037999999997	56.112527999999998	56.109957999999999	Школьная	0103000020E61000000100000005000000C422861DC63844407FF78E1A130E4C40C422861DC638444030F14751670E4C4016BD5301F738444030F14751670E4C4016BD5301F73844407FF78E1A130E4C40C422861DC63844407FF78E1A130E4C40
34839	3510	40.356166999999999	40.368582000000004	56.14734	56.133056000000003	Чернышевского	0103000020E610000001000000050000000C7558E1962D4440AF44A0FA07114C400C7558E1962D444042B28009DC124C4078F2E9B12D2F444042B28009DC124C4078F2E9B12D2F4440AF44A0FA07114C400C7558E1962D4440AF44A0FA07114C40
34847	3510	40.358611000000003	40.363534000000001	56.132223000000003	56.119469000000002	Чайковского	0103000020E61000000100000005000000317E1AF7E62D444063F19BC24A0F4C40317E1AF7E62D4440B763EAAEEC104C40F67D3848882E4440B763EAAEEC104C40F67D3848882E444063F19BC24A0F4C40317E1AF7E62D444063F19BC24A0F4C40
35181	3510	40.260865000000003	40.263012000000003	56.121220000000001	56.119529	Центральная	0103000020E61000000100000005000000E5D539066421444038F6ECB94C0F4C40E5D539066421444081CF0F23840F4C40503A9160AA21444081CF0F23840F4C40503A9160AA21444038F6ECB94C0F4C40E5D539066421444038F6ECB94C0F4C40
34858	3510	40.421501999999997	40.432668	56.153086000000002	56.137726000000001	Усти-На-Лабе	0103000020E610000001000000050000006B990CC7F33544408AE76C01A1114C406B990CC7F3354440DCBC715298134C404B033FAA61374440DCBC715298134C404B033FAA613744408AE76C01A1114C406B990CC7F33544408AE76C01A1114C40
34848	3510	40.364153000000002	40.371572999999998	56.138562999999998	56.136662000000001	Университетская	0103000020E61000000100000005000000C2DEC4909C2E4440904DF2237E114C40C2DEC4909C2E4440C3B7B06EBC114C40CE893DB48F2F4440C3B7B06EBC114C40CE893DB48F2F4440904DF2237E114C40C2DEC4909C2E4440904DF2237E114C40
34863	3510	40.372202000000001	40.395558000000001	56.153658	56.145328999999997	Тракторная	0103000020E61000000100000005000000BEC0AC50A42F4440871403249A124C40BEC0AC50A42F44406762BA10AB134C40E9D500A5A13244406762BA10AB134C40E9D500A5A1324440871403249A124C40BEC0AC50A42F4440871403249A124C40
34866	3510	40.349933	40.356419000000002	56.105716000000001	56.103889000000002	Тихонравова	0103000020E610000001000000050000004565C39ACA2C444003B5183C4C0D4C404565C39ACA2C4440FC54151A880D4C40265646239F2D4440FC54151A880D4C40265646239F2D444003B5183C4C0D4C404565C39ACA2C444003B5183C4C0D4C40
74901	3510	40.458917	40.473128000000003	56.173036000000003	56.161583999999998	Суздальский проспект 	0103000020E610000001000000050000000A4AD1CABD3A444047C7D5C8AE144C400A4AD1CABD3A4440ED832C0B26164C40346953758F3C4440ED832C0B26164C40346953758F3C444047C7D5C8AE144C400A4AD1CABD3A444047C7D5C8AE144C40
34835	3510	40.382235999999999	40.386826999999997	56.143875000000001	56.140183999999998	Студенческая	0103000020E610000001000000050000004BADF71BED30444013B69F8CF1114C404BADF71BED30444023DBF97E6A124C40DA1A118C8331444023DBF97E6A124C40DA1A118C8331444013B69F8CF1114C404BADF71BED30444013B69F8CF1114C40
16290	3510	40.358611000000003	40.375562000000002	56.151367	56.132223000000003	Строителей проспект	0103000020E61000000100000005000000317E1AF7E62D4440B763EAAEEC104C40317E1AF7E62D4440C9586DFE5F134C4068CF656A12304440C9586DFE5F134C4068CF656A12304440B763EAAEEC104C40317E1AF7E62D4440B763EAAEEC104C40
67594	3510	40.452125000000002	40.458781999999999	56.173501999999999	56.160716999999998	Соколова-Соколенка	0103000020E610000001000000050000001D5A643BDF394440A374E95F92144C401D5A643BDF39444032E5435035164C402AFF5A5EB93A444032E5435035164C402AFF5A5EB93A4440A374E95F92144C401D5A643BDF394440A374E95F92144C40
74925	3510	40.389791000000002	40.436647000000001	56.150680000000001	56.142705999999997	Северная	0103000020E6100000010000000500000038A3E6ABE4314440B378B13044124C4038A3E6ABE4314440A514747B49134C40C172840CE4374440A514747B49134C40C172840CE4374440B378B13044124C4038A3E6ABE4314440B378B13044124C40
74895	3510	40.389791000000002	40.436647000000001	56.150680000000001	56.142705999999997	Северная	0103000020E6100000010000000500000038A3E6ABE4314440B378B13044124C4038A3E6ABE4314440A514747B49134C40C172840CE4374440A514747B49134C40C172840CE4374440B378B13044124C4038A3E6ABE4314440B378B13044124C40
74904	3510	40.458288000000003	40.491463000000003	56.174970999999999	56.173431999999998	Растопчина	0103000020E610000001000000050000001B13622EA93A4440390A100533164C401B13622EA93A4440CC5F217365164C40D7187442E83E4440CC5F217365164C40D7187442E83E4440390A100533164C401B13622EA93A4440390A100533164C40
34859	3510	40.352269	40.378787000000003	56.119649000000003	56.116267000000001	Разина	0103000020E6100000010000000500000083328D26172D4440514D49D6E10E4C4083328D26172D4440E3FF8EA8500F4C403293A8177C304440E3FF8EA8500F4C403293A8177C304440514D49D6E10E4C4083328D26172D4440514D49D6E10E4C40
34841	3510	40.402358999999997	40.421520000000001	56.162927000000003	56.138007000000002	Полины Осипенко	0103000020E610000001000000050000002920ED7F803344403ECF9F36AA114C402920ED7F803344405551BCCADA144C40124E0B5EF43544405551BCCADA144C40124E0B5EF43544403ECF9F36AA114C402920ED7F803344403ECF9F36AA114C40
34834	3510	40.352331999999997	40.369048999999997	56.117496000000003	56.115389	Парижской Коммуны	0103000020E61000000100000005000000C9AA0837192D4440B9A81611C50E4C40C9AA0837192D444096B4E21B0A0F4C408DCF64FF3C2F444096B4E21B0A0F4C408DCF64FF3C2F4440B9A81611C50E4C40C9AA0837192D4440B9A81611C50E4C40
34694	3510	40.389153	40.394283000000001	56.142705999999997	56.127085999999998	Октябрьский проспект	0103000020E61000000100000005000000F511F8C3CF314440C5E3A25A44104C40F511F8C3CF314440B378B13044124C40342F87DD77324440B378B13044124C40342F87DD77324440C5E3A25A44104C40F511F8C3CF314440C5E3A25A44104C40
34849	3510	40.208053	40.281311000000002	56.101599999999998	56.083240000000004	Ноябрьская	0103000020E61000000100000005000000D76A0F7BA11A44400ADCBA9BA70A4C40D76A0F7BA11A444005A3923A010D4C40A680B4FF0124444005A3923A010D4C40A680B4FF012444400ADCBA9BA70A4C40D76A0F7BA11A44400ADCBA9BA70A4C40
34832	3510	40.339629000000002	40.355943000000003	56.107236999999998	56.104410999999999	Нижняя Дуброва	0103000020E61000000100000005000000F8E28BF6782B4440DC2BF3565D0D4C40F8E28BF6782B4440E8F527F1B90D4C40BD1E4C8A8F2D4440E8F527F1B90D4C40BD1E4C8A8F2D4440DC2BF3565D0D4C40F8E28BF6782B4440DC2BF3565D0D4C40
34474	3510	40.378687999999997	40.380789999999998	56.149988	56.147621000000001	Молодежная	0103000020E610000001000000050000009EB12FD978304440F699B33EE5124C409EB12FD9783044406F6589CE32134C4069520ABABD3044406F6589CE32134C4069520ABABD304440F699B33EE5124C409EB12FD978304440F699B33EE5124C40
34842	3510	40.367055000000001	40.440258999999998	56.147511000000002	56.136220999999999	Мира	0103000020E61000000100000005000000A96A82A8FB2E4440A30392B06F114C40A96A82A8FB2E44406F66F4A3E1124C4084622B685A3844406F66F4A3E1124C4084622B685A384440A30392B06F114C40A96A82A8FB2E4440A30392B06F114C40
35150	3510	40.165346999999997	40.517271000000001	56.187385999999996	56.051913999999996	Луневская	0103000020E61000000100000005000000F0BE2A172A1544402E1A321EA5064C40F0BE2A172A15444037DDB243FC174C40A915A6EF3542444037DDB243FC174C40A915A6EF354244402E1A321EA5064C40F0BE2A172A1544402E1A321EA5064C40
34840	3510	40.405206	40.426639999999999	56.138939999999998	56.134991999999997	Луначарского	0103000020E610000001000000050000004D124BCADD3344405E9CF86A47114C404D124BCADD334440990D32C9C8114C402D95B7239C364440990D32C9C8114C402D95B7239C3644405E9CF86A47114C404D124BCADD3344405E9CF86A47114C40
16311	3510	40.335963999999997	40.384490999999997	56.122224000000003	56.114258999999997	Ленина проспект	0103000020E6100000010000000500000011514CDE002B44400723F609A00E4C4011514CDE002B4440A6643909A50F4C409C4D470037314440A6643909A50F4C409C4D4700373144400723F609A00E4C4011514CDE002B44400723F609A00E4C40
34846	3510	40.336520999999998	40.367674999999998	56.152940999999998	56.114384999999999	Лакина	0103000020E6100000010000000500000067B5C01E132B44409413ED2AA40E4C4067B5C01E132B4440D89B189293134C40454772F90F2F4440D89B189293134C40454772F90F2F44409413ED2AA40E4C4067B5C01E132B44409413ED2AA40E4C40
67460	3510	40.367674999999998	40.458288000000003	56.173633000000002	56.152946	Куйбышева	0103000020E61000000100000005000000454772F90F2F4440EA060ABC93134C40454772F90F2F4440D1402C9B39164C401B13622EA93A4440D1402C9B39164C401B13622EA93A4440EA060ABC93134C40454772F90F2F4440EA060ABC93134C40
34843	3510	40.358611000000003	40.382810999999997	56.132223000000003	56.125484999999998	Красноармейская	0103000020E61000000100000005000000317E1AF7E62D4440BC9179E40F104C40317E1AF7E62D4440B763EAAEEC104C4047C66AF3FF304440B763EAAEEC104C4047C66AF3FF304440BC9179E40F104C40317E1AF7E62D4440BC9179E40F104C40
74916	3510	40.446770999999998	40.490096999999999	56.173467000000002	56.164371000000003	Комиссарова	0103000020E610000001000000050000008EE6C8CA2F39444096B4E21B0A154C408EE6C8CA2F394440B6F7A92A34164C40116F9D7FBB3E4440B6F7A92A34164C40116F9D7FBB3E444096B4E21B0A154C408EE6C8CA2F39444096B4E21B0A154C40
67502	3510	40.446770999999998	40.490096999999999	56.173467000000002	56.164371000000003	Комиссарова	0103000020E610000001000000050000008EE6C8CA2F39444096B4E21B0A154C408EE6C8CA2F394440B6F7A92A34164C40116F9D7FBB3E4440B6F7A92A34164C40116F9D7FBB3E444096B4E21B0A154C408EE6C8CA2F39444096B4E21B0A154C40
34479	3510	40.390509999999999	40.400885000000002	56.140891000000003	56.138027000000001	Кирова	0103000020E6100000010000000500000067614F3BFC314440857B65DEAA114C4067614F3BFC3144407FA65EB708124C407E3A1E33503344407FA65EB708124C407E3A1E3350334440857B65DEAA114C4067614F3BFC314440857B65DEAA114C40
34853	3510	40.390509999999999	40.400885000000002	56.140891000000003	56.138027000000001	Кирова	0103000020E6100000010000000500000067614F3BFC314440857B65DEAA114C4067614F3BFC3144407FA65EB708124C407E3A1E33503344407FA65EB708124C407E3A1E3350334440857B65DEAA114C4067614F3BFC314440857B65DEAA114C40
34822	3510	40.414530999999997	40.429181999999997	56.143318000000001	56.140740000000001	Каманина	0103000020E61000000100000005000000CE16105A0F354440999EB0C403124C40CE16105A0F354440CD76853E58124C4014048F6FEF364440CD76853E58124C4014048F6FEF364440999EB0C403124C40CE16105A0F354440999EB0C403124C40
16408	3510	40.271259000000001	40.281841	56.128109000000002	56.101739999999999	Институтский городок	0103000020E6100000010000000500000072DF6A9DB8224440F758FAD0050D4C4072DF6A9DB822444061A92EE065104C4002D6AA5D1324444061A92EE065104C4002D6AA5D13244440F758FAD0050D4C4072DF6A9DB8224440F758FAD0050D4C40
74924	3510	40.271259000000001	40.281841	56.128109000000002	56.101739999999999	Институтский городок	0103000020E6100000010000000500000072DF6A9DB8224440F758FAD0050D4C4072DF6A9DB822444061A92EE065104C4002D6AA5D1324444061A92EE065104C4002D6AA5D13244440F758FAD0050D4C4072DF6A9DB8224440F758FAD0050D4C40
67609	3510	40.455430999999997	40.462088000000001	56.159168000000001	56.155413000000003	Жуковского	0103000020E61000000100000005000000D34A21904B3A4440C72FBC92E4134C40D34A21904B3A4440ED48F59D5F144C40E1EF17B3253B4440ED48F59D5F144C40E1EF17B3253B4440C72FBC92E4134C40D34A21904B3A4440C72FBC92E4134C40
67548	3510	40.455027000000001	40.498389000000003	56.175727000000002	56.151516999999998	Добросельская	0103000020E6100000010000000500000004E621533E3A4440DEE4B7E864134C4004E621533E3A44401903EB387E164C40D4D7F335CB3F44401903EB387E164C40D4D7F335CB3F4440DEE4B7E864134C4004E621533E3A4440DEE4B7E864134C40
34658	3510	40.358376999999997	40.375185000000002	56.120477000000001	56.101730000000003	Диктора Левитана	0103000020E61000000100000005000000BD512B4CDF2D4440D482177D050D4C40BD512B4CDF2D4440C97553CA6B0F4C409279E40F06304440C97553CA6B0F4C409279E40F06304440D482177D050D4C40BD512B4CDF2D4440D482177D050D4C40
34833	3510	40.358376999999997	40.375185000000002	56.120477000000001	56.101730000000003	Диктора Левитана	0103000020E61000000100000005000000BD512B4CDF2D4440D482177D050D4C40BD512B4CDF2D4440C97553CA6B0F4C409279E40F06304440C97553CA6B0F4C409279E40F06304440D482177D050D4C40BD512B4CDF2D4440D482177D050D4C40
34861	3510	40.386971000000003	40.396366999999998	56.126714	56.125509999999998	Дворянская	0103000020E610000001000000050000000EC006448831444015A930B610104C400EC006448831444001F9122A38104C40581B6327BC32444001F9122A38104C40581B6327BC32444015A930B610104C400EC006448831444015A930B610104C40
34821	3510	40.366812000000003	40.405512000000002	56.153407000000001	56.133989	Горького	0103000020E61000000100000005000000E3E313B2F32E44400A83328D26114C40E3E313B2F32E44401EFD2FD7A2134C405A1135D1E73344401EFD2FD7A2134C405A1135D1E73344400A83328D26114C40E3E313B2F32E44400A83328D26114C40
34820	3510	40.414530999999997	40.421888000000003	56.135728999999998	56.133332000000003	Герцена	0103000020E61000000100000005000000CE16105A0F35444051C1E10511114C40CE16105A0F354440340F60915F114C4095490D6D00364440340F60915F114C4095490D6D0036444051C1E10511114C40CE16105A0F35444051C1E10511114C40
34517	3510	40.414530999999997	40.421888000000003	56.135728999999998	56.133332000000003	Герцена	0103000020E61000000100000005000000CE16105A0F35444051C1E10511114C40CE16105A0F354440340F60915F114C4095490D6D00364440340F60915F114C4095490D6D0036444051C1E10511114C40CE16105A0F35444051C1E10511114C40
34829	3510	40.342647999999997	40.348638999999999	56.115740000000002	56.099640999999998	Верхняя Дуброва	0103000020E610000001000000050000001805C1E3DB2B44409D2B4A09C10C4C401805C1E3DB2B4440666B7D91D00E4C40198EE733A02C4440666B7D91D00E4C40198EE733A02C44409D2B4A09C10C4C401805C1E3DB2B44409D2B4A09C10C4C40
34838	3510	40.339638000000001	40.354253999999997	56.110455000000002	56.109647000000002	Василисина	0103000020E610000001000000050000004B3D0B42792B4440618DB3E9080E4C404B3D0B42792B44400057B263230E4C40143DF031582D44400057B263230E4C40143DF031582D4440618DB3E9080E4C404B3D0B42792B4440618DB3E9080E4C40
34826	3510	40.397633999999996	40.419975000000001	56.133783000000001	56.126930000000002	Большая Московская улица	0103000020E610000001000000050000008AE3C0ABE5324440CE70033E3F104C408AE3C0ABE532444061E124CD1F114C409D11A5BDC135444061E124CD1F114C409D11A5BDC1354440CE70033E3F104C408AE3C0ABE5324440CE70033E3F104C40
67576	3510	40.444831000000001	40.445954	56.173152000000002	56.165063000000004	Безыменского	0103000020E610000001000000050000009D9FE238F0384440CC63CDC820154C409D9FE238F0384440569E40D829164C409CC24A0515394440569E40D829164C409CC24A0515394440CC63CDC820154C409D9FE238F0384440CC63CDC820154C40
34855	3510	40.353588999999999	40.357883000000001	56.132404000000001	56.120722999999998	Балакирева	0103000020E61000000100000005000000D89C8367422D44400070ECD9730F4C40D89C8367422D444007EE409DF2104C40AE65321CCF2D444007EE409DF2104C40AE65321CCF2D44400070ECD9730F4C40D89C8367422D44400070ECD9730F4C40
74913	3510	40.452125000000002	40.458781999999999	56.173501999999999	56.160716999999998	 Соколова-Соколенка	0103000020E610000001000000050000001D5A643BDF394440A374E95F92144C401D5A643BDF39444032E5435035164C402AFF5A5EB93A444032E5435035164C402AFF5A5EB93A4440A374E95F92144C401D5A643BDF394440A374E95F92144C40
34733	54129	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Советская	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34463	54129	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Маяковского	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34550	54129	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Ленина	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34772	54129	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Королева	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
35000	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	перфильева	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34558	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	набережная	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34976	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	Чехова	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34600	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	Набережная	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
35100	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	Железнодорожная	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34687	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	Горького	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34741	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	Артиллерийская	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34555	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	Авангардский переулок	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
34785	10146	39.646013000000004	39.72034	56.520761999999998	56.477691	1 Мая	0103000020E610000001000000050000003BE5D18DB0D24340F94B8BFA243D4C403BE5D18DB0D24340F17F4754A8424C401500E31934DC4340F17F4754A8424C401500E31934DC4340F94B8BFA243D4C403BE5D18DB0D24340F94B8BFA243D4C40
35001	47757	39.760646999999999	39.791198999999999	56.592996999999997	56.576270999999998	жевлаковича	0103000020E61000000100000005000000776682E15CE143400D51853FC3494C40776682E15CE1434024D06053E74B4C405FD0420246E5434024D06053E74B4C405FD0420246E543400D51853FC3494C40776682E15CE143400D51853FC3494C40
35072	48036	39.942968999999998	39.975569	56.299675999999998	56.285817999999999	VII	0103000020E6100000010000000500000027124C35B3F84340D74D29AF95244C4027124C35B3F84340B3B27DC85B264C40E7FEEA71DFFC4340B3B27DC85B264C40E7FEEA71DFFC4340D74D29AF95244C4027124C35B3F84340D74D29AF95244C40
35020	54166	39.652661000000002	39.674041000000003	56.451647999999999	56.440503	улица Школьная	0103000020E61000000100000005000000F52F49658AD343401B65FD6662384C40F52F49658AD34340E3A6069ACF394C40E294B9F946D64340E3A6069ACF394C40E294B9F946D643401B65FD6662384C40F52F49658AD343401B65FD6662384C40
34745	10708	39.534118999999997	39.570016000000003	56.693283000000001	56.671187000000003	Советская	0103000020E610000001000000050000000B96EA025EC443400C40A374E9554C400B96EA025EC44340B7EF517FBD584C402F19C748F6C84340B7EF517FBD584C402F19C748F6C843400C40A374E9554C400B96EA025EC443400C40A374E9554C40
35055	10708	39.534118999999997	39.570016000000003	56.693283000000001	56.671187000000003	Богомолова	0103000020E610000001000000050000000B96EA025EC443400C40A374E9554C400B96EA025EC44340B7EF517FBD584C402F19C748F6C84340B7EF517FBD584C402F19C748F6C843400C40A374E9554C400B96EA025EC443400C40A374E9554C40
35172	47772	39.795645999999998	39.819513999999998	56.693891000000001	56.682248999999999	Школьная	0103000020E61000000100000005000000BB9866BAD7E54340465D6BEF53574C40BB9866BAD7E543408FFE976BD1584C409C4EB2D5E5E843408FFE976BD1584C409C4EB2D5E5E84340465D6BEF53574C40BB9866BAD7E54340465D6BEF53574C40
34578	48457	39.991576999999999	40.007199	56.285668000000001	56.277943	Школьная	0103000020E610000001000000050000009F3BC1FEEBFE43407993DFA293234C409F3BC1FEEBFE4340C2C1DEC490244C402EC896E5EB004440C2C1DEC490244C402EC896E5EB0044407993DFA293234C409F3BC1FEEBFE43407993DFA293234C40
34507	11730	39.975200999999998	40.010541000000003	56.376280999999999	56.357165000000002	Первомайская	0103000020E610000001000000050000006403E962D3FC43404F232D95B72D4C406403E962D3FC4340978DCEF929304C403222516859014440978DCEF929304C4032225168590144404F232D95B72D4C406403E962D3FC43404F232D95B72D4C40
35087	10768	39.463664000000001	39.484209	56.66583	56.648766000000002	Школьный переулок	0103000020E61000000100000005000000912A8A5759BB4340DD60A8C30A534C40912A8A5759BB43400C59DDEA39554C40E5B67D8FFABD43400C59DDEA39554C40E5B67D8FFABD4340DD60A8C30A534C40912A8A5759BB4340DD60A8C30A534C40
35363	40411	39.664059999999999	39.689069000000003	56.533914000000003	56.518994999999997	Центральная	0103000020E61000000100000005000000774A07EBFFD44340CDE49B6D6E424C40774A07EBFFD443403370404B57444C40FED7B96933D843403370404B57444C40FED7B96933D84340CDE49B6D6E424C40774A07EBFFD44340CDE49B6D6E424C40
34871	47949	39.550854999999999	39.588216000000003	56.516015000000003	56.503816	Школьная	0103000020E6100000010000000500000046EBA86A82C64340CC99ED0A7D404C4046EBA86A82C643406B9F8EC70C424C40F27D71A94ACB43406B9F8EC70C424C40F27D71A94ACB4340CC99ED0A7D404C4046EBA86A82C64340CC99ED0A7D404C40
34930	48177	39.528846000000001	39.549048999999997	56.628287	56.617333000000002	Огурцова	0103000020E610000001000000050000006A4FC939B1C34340ECDE8AC4044F4C406A4FC939B1C3434040C05AB56B504C406473D53C47C6434040C05AB56B504C406473D53C47C64340ECDE8AC4044F4C406A4FC939B1C34340ECDE8AC4044F4C40
35460	47880	39.699534999999997	39.721390999999997	56.605355000000003	56.591351000000003	Школьная	0103000020E6100000010000000500000024B4E55C8AD943407CBABA63B14B4C4024B4E55C8AD943402CBCCB457C4D4C407A50508A56DC43402CBCCB457C4D4C407A50508A56DC43407CBABA63B14B4C4024B4E55C8AD943407CBABA63B14B4C40
35209	47955	39.374623	39.393487999999998	56.590018000000001	56.575294999999997	Механическая	0103000020E610000001000000050000002AAA7EA5F3AF4340B2463D44A3494C402AAA7EA5F3AF43409206B7B5854B4C4029AF95D05DB243409206B7B5854B4C4029AF95D05DB24340B2463D44A3494C402AAA7EA5F3AF4340B2463D44A3494C40
35060	13424	40.421717000000001	40.440052000000001	56.37679	56.364037000000003	Центральная	0103000020E61000000100000005000000689599D2FA35444059C4B0C3982E4C40689599D2FA354440DCBA9BA73A304C400B45BA9F53384440DCBA9BA73A304C400B45BA9F5338444059C4B0C3982E4C40689599D2FA35444059C4B0C3982E4C40
35026	48444	40.180366999999997	40.208215000000003	56.348132999999997	56.338354000000002	центральная	0103000020E6100000010000000500000089230F4416174440433C122F4F2B4C4089230F441617444045D4449F8F2C4C40B1C403CAA61A444045D4449F8F2C4C40B1C403CAA61A4440433C122F4F2B4C4089230F4416174440433C122F4F2B4C40
35027	13494	40.324286000000001	40.340797000000002	56.349429999999998	56.336118999999997	совхозная	0103000020E610000001000000050000007C46223482294440384888F2052B4C407C46223482294440E21E4B1FBA2C4C4097C9703C9F2B4440E21E4B1FBA2C4C4097C9703C9F2B4440384888F2052B4C407C46223482294440384888F2052B4C40
34926	12619	40.536710999999997	40.562969000000002	56.565069000000001	56.547046000000002	Центральная	0103000020E61000000100000005000000A43330F2B24444402DB4739A05464C40A43330F2B2444440E17D552E54484C40B7D4415E0F484440E17D552E54484C40B7D4415E0F4844402DB4739A05464C40A43330F2B24444402DB4739A05464C40
35134	48561	40.427061999999999	40.447094999999997	56.199821999999998	56.190325999999999	Александрова	0103000020E61000000100000005000000A3AEB5F7A93644400CCA349A5C184C40A3AEB5F7A9364440BA826DC493194C40419AB1683A394440BA826DC493194C40419AB1683A3944400CCA349A5C184C40A3AEB5F7A93644400CCA349A5C184C40
35173	12222	40.481212999999997	40.508270000000003	56.195230000000002	56.186067999999999	Школьная	0103000020E610000001000000050000007CB43863983D4440836A8313D1174C407CB43863983D44405B99F04BFD184C40DBC4C9FD0E4144405B99F04BFD184C40DBC4C9FD0E414440836A8313D1174C407CB43863983D4440836A8313D1174C40
34894	8829	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	колхозная	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
34798	8829	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	Промышленная	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
34657	8829	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	Лоунская	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
34743	8829	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	Красная площадь,	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
34508	8829	40.424411999999997	40.475625000000001	56.451334000000003	56.401943000000003	Гоголя	0103000020E61000000100000005000000D503E6215336444096ED43DE72334C40D503E6215336444054C90050C5394C407B14AE47E13C444054C90050C5394C407B14AE47E13C444096ED43DE72334C40D503E6215336444096ED43DE72334C40
34949	48425	40.169227999999997	40.196500999999998	56.29027	56.278702000000003	красная	0103000020E61000000100000005000000A3C85A43A915444037AAD381AC234C40A3C85A43A915444045813E9127254C40CE50DCF12619444045813E9127254C40CE50DCF12619444037AAD381AC234C40A3C85A43A915444037AAD381AC234C40
35058	12796	40.517162999999996	40.534860000000002	56.369934999999998	56.355249999999998	Школьная	0103000020E61000000100000005000000C2D9AD6532424440B6F3FDD4782D4C40C2D9AD6532424440A852B3075A2F4C4023F8DF4A76444440A852B3075A2F4C4023F8DF4A76444440B6F3FDD4782D4C40C2D9AD6532424440B6F3FDD4782D4C40
35059	47678	40.517162999999996	40.534860000000002	56.369934999999998	56.355249999999998	Центральная	0103000020E61000000100000005000000C2D9AD6532424440B6F3FDD4782D4C40C2D9AD6532424440A852B3075A2F4C4023F8DF4A76444440A852B3075A2F4C4023F8DF4A76444440B6F3FDD4782D4C40C2D9AD6532424440B6F3FDD4782D4C40
34906	12617	40.380063	40.391345000000001	56.195720999999999	56.189435000000003	Прибольничная	0103000020E61000000100000005000000B7B585E7A5304440E0DBF4673F184C40B7B585E7A5304440F911BF620D194C40003ACC9717324440F911BF620D194C40003ACC9717324440E0DBF4673F184C40B7B585E7A5304440E0DBF4673F184C40
34693	48534	40.395792	40.415762000000001	56.228600999999998	56.214587000000002	Центральная	0103000020E610000001000000050000005C02F04FA9324440C9923996771B4C405C02F04FA93244409C6A2DCC421D4C40B47570B0373544409C6A2DCC421D4C40B47570B037354440C9923996771B4C405C02F04FA9324440C9923996771B4C40
35489	48213	40.582022000000002	40.602387	56.295054999999998	56.286388000000002	Западная	0103000020E61000000100000005000000B9C667B27F4A4440C2FBAA5CA8244C40B9C667B27F4A4440B9C2BB5CC4254C408D4468041B4D4440B9C2BB5CC4254C408D4468041B4D4440C2FBAA5CA8244C40B9C667B27F4A4440C2FBAA5CA8244C40
34887	48490	40.515726000000001	40.534761000000003	56.279451999999999	56.257548	Молодежная	0103000020E6100000010000000500000034D93F4F034244403A933655F7204C4034D93F4F03424440A1664815C5234C409016670C73444440A1664815C5234C409016670C734444403A933655F7204C4034D93F4F034244403A933655F7204C40
35054	12277	40.528599	40.543106999999999	56.237126000000004	56.223061000000001	Центральная	0103000020E6100000010000000500000062D9CC21A9434440AC014A438D1C4C4062D9CC21A943444002840F255A1E4C40459DB9878445444002840F255A1E4C40459DB98784454440AC014A438D1C4C4062D9CC21A9434440AC014A438D1C4C40
35073	13214	40.419445000000003	40.442495000000001	56.496433000000003	56.477367999999998	Молодежная	0103000020E6100000010000000500000041BCAE5FB0354440161406651A3D4C4041BCAE5FB0354440DDD3D51D8B3F4C405FD218ADA3384440DDD3D51D8B3F4C405FD218ADA3384440161406651A3D4C4041BCAE5FB0354440161406651A3D4C40
34852	54154	\N	\N	\N	\N	Центральная	\N
34836	54154	\N	\N	\N	\N	Молодежная	\N
34924	48311	40.248423000000003	40.278965999999997	56.230567000000001	56.217120000000001	Школьная	0103000020E6100000010000000500000080492A53CC1F44405DA79196CA1B4C4080492A53CC1F4440B7442E38831D4C4014596B28B5234440B7442E38831D4C4014596B28B52344405DA79196CA1B4C4080492A53CC1F44405DA79196CA1B4C40
34931	12917	40.595540999999997	40.627225000000003	56.314791	56.304206000000001	Центральная	0103000020E61000000100000005000000AC36FFAF3A4C44409D9FE238F0264C40AC36FFAF3A4C44409E094D124B284C40E71DA7E8485044409E094D124B284C40E71DA7E8485044409D9FE238F0264C40AC36FFAF3A4C44409D9FE238F0264C40
35047	13135	40.613650999999997	40.636639000000002	56.418053999999998	56.408875999999999	центральная	0103000020E610000001000000050000002F14B01D8C4E4440450F7C0C56344C402F14B01D8C4E444022FB20CB82354C40D82D02637D51444022FB20CB82354C40D82D02637D514440450F7C0C56344C402F14B01D8C4E4440450F7C0C56344C40
35155	12063	40.563704999999999	40.595289999999999	56.211723999999997	56.203392000000001	Вокзальная	0103000020E61000000100000005000000BCCB457C274844404F22C2BF081A4C40BCCB457C274844409FE3A3C5191B4C4063D17476324C44409FE3A3C5191B4C4063D17476324C44404F22C2BF081A4C40BCCB457C274844404F22C2BF081A4C40
35056	48333	40.213819999999998	40.235073999999997	56.264046999999998	56.255653000000002	садовая	0103000020E61000000100000005000000889D29745E1B4440E90FCD3CB9204C40889D29745E1B4440AFCDC64ACC214C40E811A3E7161E4440AFCDC64ACC214C40E811A3E7161E4440E90FCD3CB9204C40889D29745E1B4440E90FCD3CB9204C40
34654	48595	40.530467000000002	40.551586999999998	56.508614999999999	56.494525000000003	Октябрьская	0103000020E61000000100000005000000BA4DB857E6434440F7065F984C3F4C40BA4DB857E6434440A5A0DB4B1A414C400AF31E679A464440A5A0DB4B1A414C400AF31E679A464440F7065F984C3F4C40BA4DB857E6434440F7065F984C3F4C40
35215	48305	40.116452000000002	40.139915999999999	56.282344999999999	56.266857000000002	Новая	0103000020E61000000100000005000000E3C62DE6E70E4440B6DAC35E28224C40E3C62DE6E70E4440359886E123244C40F4177AC4E8114440359886E123244C40F4177AC4E8114440B6DAC35E28224C40E3C62DE6E70E4440B6DAC35E28224C40
35036	48391	40.304577000000002	40.323639	56.206422000000003	56.198779999999999	Полевая	0103000020E61000000100000005000000910E0F61FC264440A88C7F9F71194C40910E0F61FC26444064963D096C1A4C40E65AB4006D29444064963D096C1A4C40E65AB4006D294440A88C7F9F71194C40910E0F61FC264440A88C7F9F71194C40
35175	48046	40.603158999999998	40.608603000000002	56.470208999999997	56.464485000000003	Молодежная	0103000020E61000000100000005000000DFA46950344D4440C53D963E743B4C40DFA46950344D444076A4FACE2F3C4C40AE9FFEB3E64D444076A4FACE2F3C4C40AE9FFEB3E64D4440C53D963E743B4C40DFA46950344D4440C53D963E743B4C40
35048	48697	40.496690999999998	40.507057000000003	56.416316000000002	56.402048000000001	Западная	0103000020E61000000100000005000000D89B1892933F44400BB6114F76334C40D89B1892933F44409966BAD749354C409C1A683EE74044409966BAD749354C409C1A683EE74044400BB6114F76334C40D89B1892933F44400BB6114F76334C40
35002	48567	40.268706999999999	40.295253000000002	56.403576999999999	56.385261999999997	Школьная	0103000020E61000000100000005000000679AB0FD642244401E32E54350314C40679AB0FD642244407A354069A8334C40E085ADD9CA2544407A354069A8334C40E085ADD9CA2544401E32E54350314C40679AB0FD642244401E32E54350314C40
34950	13199	40.335928000000003	40.371150999999998	56.493447000000003	56.480772999999999	Набережная	0103000020E61000000100000005000000C5E74EB0FF2A444060E63BF8893D4C40C5E74EB0FF2A444098A77345293F4C4058703FE0812F444098A77345293F4C4058703FE0812F444060E63BF8893D4C40C5E74EB0FF2A444060E63BF8893D4C40
34907	48499	40.467702000000003	40.489899999999999	56.279822000000003	56.259887999999997	большая дорога	0103000020E610000001000000050000000C23BDA8DD3B4440B94F8E0244214C400C23BDA8DD3B4440C5591135D1234C40BB270F0BB53E4440C5591135D1234C40BB270F0BB53E4440B94F8E0244214C400C23BDA8DD3B4440B94F8E0244214C40
35078	48370	40.311942999999999	40.335120000000003	56.164216000000003	56.151271000000001	Совхозная	0103000020E61000000100000005000000AA9B8BBFED274440A7EA1ED95C134C40AA9B8BBFED2744406FBDA60705154C40261E5036E52A44406FBDA60705154C40261E5036E52A4440A7EA1ED95C134C40AA9B8BBFED274440A7EA1ED95C134C40
34444	11927	40.511046	40.547392000000002	56.208514999999998	56.182296000000001	ленина	0103000020E61000000100000005000000356090F4694144408718AF7955174C40356090F469414440DBDC989EB01A4C40C80BE9F010464440DBDC989EB01A4C40C80BE9F0104644408718AF7955174C40356090F4694144408718AF7955174C40
34511	11927	40.511046	40.547392000000002	56.208514999999998	56.182296000000001	Ленина	0103000020E61000000100000005000000356090F4694144408718AF7955174C40356090F469414440DBDC989EB01A4C40C80BE9F010464440DBDC989EB01A4C40C80BE9F0104644408718AF7955174C40356090F4694144408718AF7955174C40
34934	23432	40.782147999999999	40.803941999999999	56.076152	56.062086999999998	Судогодская	0103000020E61000000100000005000000DF50F86C1D644440DD408177F2074C40DF50F86C1D64444033C34659BF094C40BFF04A92E766444033C34659BF094C40BFF04A92E7664440DD408177F2074C40DF50F86C1D644440DD408177F2074C40
35161	48081	40.318420000000003	40.340814999999999	56.024124	56.016571999999996	Школьная	0103000020E6100000010000000500000038328FFCC1284440C00303081F024C4038328FFCC12844403C86C77E16034C403D7E6FD39F2B44403C86C77E16034C403D7E6FD39F2B4440C00303081F024C4038328FFCC1284440C00303081F024C40
34965	9169	41.112755	41.131628999999997	55.933675000000001	55.920940999999999	Муромская	0103000020E61000000100000005000000F1BA7EC16E8E4440D4450A65E1F54B40F1BA7EC16E8E4440E10B93A982F74B40431A1538D9904440E10B93A982F74B40431A1538D9904440D4450A65E1F54B40F1BA7EC16E8E4440D4450A65E1F54B40
34568	22285	40.845272999999999	40.878888000000003	55.973047999999999	55.942701	Чапаева	0103000020E610000001000000050000008D98D9E7316C44400874266DAAF84B408D98D9E7316C444017B83CD68CFC4B40666CE8667F70444017B83CD68CFC4B40666CE8667F7044400874266DAAF84B408D98D9E7316C44400874266DAAF84B40
34566	22285	40.845272999999999	40.878888000000003	55.973047999999999	55.942701	Химиков	0103000020E610000001000000050000008D98D9E7316C44400874266DAAF84B408D98D9E7316C444017B83CD68CFC4B40666CE8667F70444017B83CD68CFC4B40666CE8667F7044400874266DAAF84B408D98D9E7316C44400874266DAAF84B40
34703	22285	40.845272999999999	40.878888000000003	55.973047999999999	55.942701	Ошмарина	0103000020E610000001000000050000008D98D9E7316C44400874266DAAF84B408D98D9E7316C444017B83CD68CFC4B40666CE8667F70444017B83CD68CFC4B40666CE8667F7044400874266DAAF84B408D98D9E7316C44400874266DAAF84B40
34793	22285	40.845272999999999	40.878888000000003	55.973047999999999	55.942701	Ленина	0103000020E610000001000000050000008D98D9E7316C44400874266DAAF84B408D98D9E7316C444017B83CD68CFC4B40666CE8667F70444017B83CD68CFC4B40666CE8667F7044400874266DAAF84B408D98D9E7316C44400874266DAAF84B40
34794	22285	40.845272999999999	40.878888000000003	55.973047999999999	55.942701	Коммунистическая	0103000020E610000001000000050000008D98D9E7316C44400874266DAAF84B408D98D9E7316C444017B83CD68CFC4B40666CE8667F70444017B83CD68CFC4B40666CE8667F7044400874266DAAF84B408D98D9E7316C44400874266DAAF84B40
34748	22285	40.845272999999999	40.878888000000003	55.973047999999999	55.942701	 Халтурина	0103000020E610000001000000050000008D98D9E7316C44400874266DAAF84B408D98D9E7316C444017B83CD68CFC4B40666CE8667F70444017B83CD68CFC4B40666CE8667F7044400874266DAAF84B408D98D9E7316C44400874266DAAF84B40
35012	46719	40.678330000000003	40.681879000000002	56.054285999999998	56.051054000000001	Рябиновая	0103000020E61000000100000005000000A6F27684D35644403D2AFEEF88064C40A6F27684D3564440B950F9D7F2064C40236AA2CF47574440B950F9D7F2064C40236AA2CF475744403D2AFEEF88064C40A6F27684D35644403D2AFEEF88064C40
35130	23295	40.714784000000002	40.739801999999997	55.979076999999997	55.968694999999997	Лесная	0103000020E610000001000000050000001FDAC70A7E5B44403C66A032FEFB4B401FDAC70A7E5B444005A2276552FD4B40F8C1F9D4B15E444005A2276552FD4B40F8C1F9D4B15E44403C66A032FEFB4B401FDAC70A7E5B44403C66A032FEFB4B40
35162	23829	40.978960000000001	41.009683000000003	55.919327000000003	55.899006999999997	Северная	0103000020E61000000100000005000000CC0BB08F4E7D444002F04FA912F34B40CC0BB08F4E7D444037AAD381ACF54B40E129E44A3D81444037AAD381ACF54B40E129E44A3D81444002F04FA912F34B40CC0BB08F4E7D444002F04FA912F34B40
35367	49580	41.368650000000002	41.374983	55.895130999999999	55.893045999999998	Вторая	0103000020E61000000100000005000000D0D556EC2FAF44406CE9D1544FF24B40D0D556EC2FAF4440615111A793F24B402AC76471FFAF4440615111A793F24B402AC76471FFAF44406CE9D1544FF24B40D0D556EC2FAF44406CE9D1544FF24B40
35183	54172	40.760750999999999	40.782921000000002	56.004891000000001	55.995367000000002	Центральная	0103000020E610000001000000050000001CB3EC49606144404242942F68FF4B401CB3EC4960614440BA85AE44A0004C40022D5DC136644440BA85AE44A0004C40022D5DC1366444404242942F68FF4B401CB3EC49606144404242942F68FF4B40
35182	54171	40.668934	40.688760000000002	56.038910999999999	56.030043999999997	Школьная	0103000020E610000001000000050000005B971AA19F55444073B8567BD8034C405B971AA19F554440323A2009FB044C408065A54929584440323A2009FB044C408065A5492958444073B8567BD8034C405B971AA19F55444073B8567BD8034C40
34606	23812	40.887512000000001	40.925905999999998	55.939523999999999	55.920129000000003	Шкурина	0103000020E610000001000000050000005E6743FE99714440F48C7DC9C6F54B405E6743FE997144404FE78A5242F84B40C8957A16847644404FE78A5242F84B40C8957A1684764440F48C7DC9C6F54B405E6743FE99714440F48C7DC9C6F54B40
34610	23812	40.887512000000001	40.925905999999998	55.939523999999999	55.920129000000003	Школьная	0103000020E610000001000000050000005E6743FE99714440F48C7DC9C6F54B405E6743FE997144404FE78A5242F84B40C8957A16847644404FE78A5242F84B40C8957A1684764440F48C7DC9C6F54B405E6743FE99714440F48C7DC9C6F54B40
34476	23541	41.214651000000003	41.244089000000002	55.810400000000001	55.794224	Заводская	0103000020E61000000100000005000000E08618AF799B444062D9CC21A9E54B40E08618AF799B4440D656EC2FBBE74B401C28F04E3E9F4440D656EC2FBBE74B401C28F04E3E9F444062D9CC21A9E54B40E08618AF799B444062D9CC21A9E54B40
35177	48320	41.269196999999998	41.286427000000003	55.868127000000001	55.854658000000001	советская	0103000020E6100000010000000500000035971B0C75A24440E4A1EF6E65ED4B4035971B0C75A2444026E318C91EEF4B4080D8D2A3A9A4444026E318C91EEF4B4080D8D2A3A9A44440E4A1EF6E65ED4B4035971B0C75A24440E4A1EF6E65ED4B40
34908	47915	41.118999000000002	41.141762	56.023319000000001	56.010770000000001	парковая	0103000020E61000000100000005000000DCA0F65B3B8F444093E34EE960014C40DCA0F65B3B8F44400E30F31DFC024C4064E8D841259244400E30F31DFC024C4064E8D8412592444093E34EE960014C40DCA0F65B3B8F444093E34EE960014C40
35176	23559	41.037126000000001	41.074576999999998	55.836872999999997	55.818407000000001	Колхозная	0103000020E6100000010000000500000068EA758BC0844440A3E8818FC1E84B4068EA758BC0844440E4F38AA71EEB4B40530438BD8B894440E4F38AA71EEB4B40530438BD8B894440A3E8818FC1E84B4068EA758BC0844440A3E8818FC1E84B40
35128	47953	41.088006999999998	41.118765000000003	56.069780999999999	56.057121000000002	Полевая	0103000020E61000000100000005000000D76839D0438B44401975ADBD4F074C40D76839D0438B4440EB707495EE084C40697407B1338F4440EB707495EE084C40697407B1338F44401975ADBD4F074C40D76839D0438B44401975ADBD4F074C40
35273	46836	40.600572	40.612411999999999	55.921318999999997	55.910361999999999	Школьная	0103000020E610000001000000050000005872158BDF4C4440B5C2F4BD86F44B405872158BDF4C44407A17EFC7EDF54B40C7D63384634E44407A17EFC7EDF54B40C7D63384634E4440B5C2F4BD86F44B405872158BDF4C4440B5C2F4BD86F44B40
35083	23660	41.320490999999997	41.336741000000004	55.817421000000003	55.808225	Центральная	0103000020E61000000100000005000000C7D45DD905A94440A167B3EA73E74B40C7D45DD905A9444025085740A1E84B40761C3F541AAB444025085740A1E84B40761C3F541AAB4440A167B3EA73E74B40C7D45DD905A94440A167B3EA73E74B40
34857	46523	40.420800999999997	40.458252000000002	55.966996999999999	55.935929000000002	Юбилейная	0103000020E61000000100000005000000E28FA2CEDC35444062307F85CCF74B40E28FA2CEDC354440412AC58EC6FB4B40CEA96400A83A4440412AC58EC6FB4B40CEA96400A83A444062307F85CCF74B40E28FA2CEDC35444062307F85CCF74B40
34767	46523	40.420800999999997	40.458252000000002	55.966996999999999	55.935929000000002	Советская	0103000020E61000000100000005000000E28FA2CEDC35444062307F85CCF74B40E28FA2CEDC354440412AC58EC6FB4B40CEA96400A83A4440412AC58EC6FB4B40CEA96400A83A444062307F85CCF74B40E28FA2CEDC35444062307F85CCF74B40
34722	48020	40.474843999999997	40.494112999999999	56.075614000000002	56.058252000000003	Докучаева	0103000020E61000000100000005000000D5592DB0C73C44409B7631CD74074C40D5592DB0C73C4440548F34B8AD094C40A4C343183F3F4440548F34B8AD094C40A4C343183F3F44409B7631CD74074C40D5592DB0C73C44409B7631CD74074C40
34952	23922	40.830728999999998	40.849881000000003	55.943643000000002	55.932051999999999	Спортивная	0103000020E610000001000000050000005D6BEF53556A4440F015DD7A4DF74B405D6BEF53556A4440B70C384BC9F84B40F33E8EE6C86C4440B70C384BC9F84B40F33E8EE6C86C4440F015DD7A4DF74B405D6BEF53556A4440F015DD7A4DF74B40
34979	48043	40.523955000000001	40.558010000000003	56.053516999999999	56.034295	красноармейская	0103000020E61000000100000005000000B0C91AF5104344404AB54FC763044C40B0C91AF510434440D86322A5D9064C40A56B26DF6C474440D86322A5D9064C40A56B26DF6C4744404AB54FC763044C40B0C91AF5104344404AB54FC763044C40
34547	22522	41.131503000000002	41.169196999999997	55.954434999999997	55.933948000000001	Первомайская	0103000020E61000000100000005000000B7291E17D59044401215AA9B8BF74B40B7291E17D5904440319413ED2AFA4B4068CA4E3FA8954440319413ED2AFA4B4068CA4E3FA89544401215AA9B8BF74B40B7291E17D59044401215AA9B8BF74B40
34518	22522	41.131503000000002	41.169196999999997	55.954434999999997	55.933948000000001	Красная Слобода	0103000020E61000000100000005000000B7291E17D59044401215AA9B8BF74B40B7291E17D5904440319413ED2AFA4B4068CA4E3FA8954440319413ED2AFA4B4068CA4E3FA89544401215AA9B8BF74B40B7291E17D59044401215AA9B8BF74B40
67331	9372	39.741791999999997	39.781379999999999	56.197989	56.182912000000002	Первомайская	0103000020E610000001000000050000009B374E0AF3DE4340E20511A969174C409B374E0AF3DE4340DFFB1BB457194C40CEDF844204E44340DFFB1BB457194C40CEDF844204E44340E20511A969174C409B374E0AF3DE4340E20511A969174C40
74908	9472	39.846426999999998	39.862085	56.284109000000001	56.272889999999997	Суворова	0103000020E61000000100000005000000C7B94DB857EC4340E5B33C0FEE224C40C7B94DB857EC4340E8BF07AF5D244C40A3AF20CD58EE4340E8BF07AF5D244C40A3AF20CD58EE4340E5B33C0FEE224C40C7B94DB857EC4340E5B33C0FEE224C40
35065	48849	39.874364999999997	39.885908000000001	56.083289999999998	56.073047000000003	Школьная	0103000020E610000001000000050000002EE23B31EBEF43401409A69A59094C402EE23B31EBEF4340BB0A293FA90A4C40E4A1EF6E65F14340BB0A293FA90A4C40E4A1EF6E65F143401409A69A59094C402EE23B31EBEF43401409A69A59094C40
34688	9085	39.993257	40.041226999999999	56.138558000000003	56.121682	Школьная,	0103000020E61000000100000005000000F4C29D0B23FF434085419946930F4C40F4C29D0B23FF4340B24CBF44BC114C40295B24ED46054440B24CBF44BC114C40295B24ED4605444085419946930F4C40F4C29D0B23FF434085419946930F4C40
34686	9085	39.993257	40.041226999999999	56.138558000000003	56.121682	Советская	0103000020E61000000100000005000000F4C29D0B23FF434085419946930F4C40F4C29D0B23FF4340B24CBF44BC114C40295B24ED46054440B24CBF44BC114C40295B24ED4605444085419946930F4C40F4C29D0B23FF434085419946930F4C40
34705	6413	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	Ленина	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
34652	6413	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	Красная звезда	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
34786	6413	39.972416000000003	40.072920000000003	56.005530999999998	55.977097999999998	Димитрова	0103000020E61000000100000005000000B70DA32078FC4340567E198C11FD4B40B70DA32078FC43409D0E643DB5004C40B79C4B71550944409D0E643DB5004C40B79C4B7155094440567E198C11FD4B40B70DA32078FC4340567E198C11FD4B40
74896	9282	39.872945999999999	39.896732999999998	56.201118999999998	56.186408999999998	Порошина	0103000020E610000001000000050000004696CCB1BCEF43400C570740DC174C404696CCB1BCEF434057CD7344BE194C403A1F9E25C8F2434057CD7344BE194C403A1F9E25C8F243400C570740DC174C404696CCB1BCEF43400C570740DC174C40
35136	46392	40.163029999999999	40.170997999999997	56.002243999999997	55.993243	Зеленая	0103000020E610000001000000050000002922C32ADE1444408FFD2C9622FF4B402922C32ADE1444405D4E098849004C4038D73043E31544405D4E098849004C4038D73043E31544408FFD2C9622FF4B402922C32ADE1444408FFD2C9622FF4B40
34556	9853	39.911205000000002	40.009444999999999	56.035657999999998	56.001066000000002	Центральная площадь	0103000020E61000000100000005000000D1798D5DA2F443409B9141EE22004C40D1798D5DA2F443409EEBFB7090044C402C0E677E350144409EEBFB7090044C402C0E677E350144409B9141EE22004C40D1798D5DA2F443409B9141EE22004C40
34779	9853	39.911205000000002	40.009444999999999	56.035657999999998	56.001066000000002	Карла Маркса	0103000020E61000000100000005000000D1798D5DA2F443409B9141EE22004C40D1798D5DA2F443409EEBFB7090044C402C0E677E350144409EEBFB7090044C402C0E677E350144409B9141EE22004C40D1798D5DA2F443409B9141EE22004C40
67328	8922	39.963523000000002	39.988154999999999	56.098612000000003	56.087394000000003	Юбилейная	0103000020E61000000100000005000000CFF8BEB854FB4340EEEE01BA2F0B4C40CFF8BEB854FB4340207F69519F0C4C407F30F0DC7BFE4340207F69519F0C4C407F30F0DC7BFE4340EEEE01BA2F0B4C40CFF8BEB854FB4340EEEE01BA2F0B4C40
35122	8618	39.874535999999999	39.894953999999998	55.907590999999996	55.894278	Молодежная	0103000020E610000001000000050000005B96AFCBF0EF434022C495B377F24B405B96AFCBF0EF43406C921FF12BF44B4052B648DA8DF243406C921FF12BF44B4052B648DA8DF2434022C495B377F24B405B96AFCBF0EF434022C495B377F24B40
34925	8741	40.137903999999999	40.152537000000002	56.082822999999998	56.074925999999998	Советская	0103000020E6100000010000000500000069FE98D6A61144405FCFD72C97094C4069FE98D6A6114440A52DAEF1990A4C400937195586134440A52DAEF1990A4C4009371955861344405FCFD72C97094C4069FE98D6A61144405FCFD72C97094C40
35133	9412	40.012481000000001	40.037382000000001	56.249296000000001	56.227530000000002	Строителей	0103000020E61000000100000005000000236937FA98014440F06DFAB31F1D4C40236937FA9801444006836BEEE81F4C40C3BAF1EEC804444006836BEEE81F4C40C3BAF1EEC8044440F06DFAB31F1D4C40236937FA98014440F06DFAB31F1D4C40
67318	8648	39.913567	39.927545000000002	55.937461999999996	55.926141000000001	Парковая	0103000020E6100000010000000500000038DA71C3EFF443400C3ECDC98BF64B4038DA71C3EFF44340129F3BC1FEF74B40BF4868CBB9F64340129F3BC1FEF74B40BF4868CBB9F643400C3ECDC98BF64B4038DA71C3EFF443400C3ECDC98BF64B40
74909	9338	39.876888999999998	39.899078000000003	56.239902999999998	56.230176999999998	Первомайская	0103000020E610000001000000050000006F9C14E63DF043404CA59F70761D4C406F9C14E63DF043402C9B3924B51E4C40CC46E7FC14F343402C9B3924B51E4C40CC46E7FC14F343404CA59F70761D4C406F9C14E63DF043404CA59F70761D4C40
67324	46553	40.007747000000002	40.029961999999998	56.035657999999998	56.027045999999999	Зелёная	0103000020E6100000010000000500000031D28BDAFD0044406ABE4A3E76034C4031D28BDAFD0044409EEBFB7090044C40B60F79CBD50344409EEBFB7090044C40B60F79CBD50344406ABE4A3E76034C4031D28BDAFD0044406ABE4A3E76034C40
74902	9030	39.835585000000002	39.854287999999997	56.134394999999998	56.124139999999997	Новая	0103000020E610000001000000050000009B030473F4EA43400E10CCD1E30F4C409B030473F4EA43407ADFF8DA33114C40C0AE264F59ED43407ADFF8DA33114C40C0AE264F59ED43400E10CCD1E30F4C409B030473F4EA43400E10CCD1E30F4C40
74920	8561	40.189323000000002	40.218159	55.999682	55.990977000000001	Сысоевская	0103000020E61000000100000005000000B8B06EBC3B1844404A0B9755D8FE4B40B8B06EBC3B1844402F336C94F5FF4B40FE2955A2EC1B44402F336C94F5FF4B40FE2955A2EC1B44404A0B9755D8FE4B40B8B06EBC3B1844404A0B9755D8FE4B40
35344	9253	40.152061000000003	40.173118000000002	56.176394000000002	56.166029999999999	Мичуринская	0103000020E61000000100000005000000A0FF1EBC76134440D313967840154C40A0FF1EBC76134440F69A1E1494164C40AA2C0ABB28164440F69A1E1494164C40AA2C0ABB28164440D313967840154C40A0FF1EBC76134440D313967840154C40
67334	8998	39.965400000000002	39.983410999999997	56.048470000000002	56.034300000000002	Механизаторов	0103000020E610000001000000050000007AC7293A92FB43405C2041F163044C407AC7293A92FB4340276BD44334064C4069C36169E0FD4340276BD44334064C4069C36169E0FD43405C2041F163044C407AC7293A92FB43405C2041F163044C40
35011	8485	40.087094999999998	40.122605	55.879697	55.863778000000003	Владимирская	0103000020E610000001000000050000009352D0ED250B44408D800A4790EE4B409352D0ED250B4440D5B14AE999F04B40BDA94885B10F4440D5B14AE999F04B40BDA94885B10F44408D800A4790EE4B409352D0ED250B44408D800A4790EE4B40
34995	8910	40.067349999999998	40.084156999999998	56.107398000000003	56.097161	Полевая	0103000020E610000001000000050000005BB1BFEC9E0844402CB98AC56F0C4C405BB1BFEC9E084440F2D3B837BF0D4C405F5D15A8C50A4440F2D3B837BF0D4C405F5D15A8C50A44402CB98AC56F0C4C405BB1BFEC9E0844402CB98AC56F0C4C40
67325	8540	40.240921999999998	40.256265999999997	55.951729	55.939514000000003	Лесной проспект	0103000020E6100000010000000500000086713788D61E44402C11A8FE41F84B4086713788D61E4440D0D38041D2F94B40D2890453CD204440D0D38041D2F94B40D2890453CD2044402C11A8FE41F84B4086713788D61E44402C11A8FE41F84B40
35046	5906	42.001001000000002	42.030807000000003	55.941606999999998	55.925677	Советская	0103000020E61000000100000005000000B421FFCC2000454067D47C957CF64B40B421FFCC20004540A357039486F84B4073BED87BF1034540A357039486F84B4073BED87BF103454067D47C957CF64B40B421FFCC2000454067D47C957CF64B40
35169	5082	41.599677999999997	41.630220999999999	55.757621999999998	55.737856000000001	Свободы	0103000020E61000000100000005000000BA10AB3FC2CC44402594BE1072DE4B40BA10AB3FC2CC4440745DF8C1F9E04B404F20EC14ABD04440745DF8C1F9E04B404F20EC14ABD044402594BE1072DE4B40BA10AB3FC2CC44402594BE1072DE4B40
35115	5506	41.357978000000003	41.379573000000001	55.681843999999998	55.668827999999998	Школьная	0103000020E6100000010000000500000000581D39D2AD44401553E9279CD54B4000581D39D2AD4440A67C08AA46D74B40E9B81AD995B04440A67C08AA46D74B40E9B81AD995B044401553E9279CD54B4000581D39D2AD44401553E9279CD54B40
34724	5683	41.597810000000003	41.638638	55.990684999999999	55.963102999999997	Молодежная	0103000020E61000000100000005000000639CBF0985CC4440F9D687F546FB4B40639CBF0985CC4440A2D11DC4CEFE4B40CEFDD5E3BED14440A2D11DC4CEFE4B40CEFDD5E3BED14440F9D687F546FB4B40639CBF0985CC4440F9D687F546FB4B40
34641	5013	41.711078000000001	41.756945999999999	55.812913999999999	55.794953	совхозная	0103000020E61000000100000005000000DA73999A04DB4440B56D1805C1E54B40DA73999A04DB4440F33AE2900DE84B40446B459BE3E04440F33AE2900DE84B40446B459BE3E04440B56D1805C1E54B40DA73999A04DB4440B56D1805C1E54B40
34940	5013	41.711078000000001	41.756945999999999	55.812913999999999	55.794953	Совхозная	0103000020E61000000100000005000000DA73999A04DB4440B56D1805C1E54B40DA73999A04DB4440F33AE2900DE84B40446B459BE3E04440F33AE2900DE84B40446B459BE3E04440B56D1805C1E54B40DA73999A04DB4440B56D1805C1E54B40
35378	46994	41.543604999999999	41.551879	55.742584999999998	55.735230999999999	Школьная	0103000020E61000000100000005000000967840D994C54440B000A60C1CDE4B40967840D994C5444005C078060DDF4B40B22C98F8A3C6444005C078060DDF4B40B22C98F8A3C64440B000A60C1CDE4B40967840D994C54440B000A60C1CDE4B40
35041	5813	41.891432999999999	41.906992000000002	55.953231000000002	55.935823999999997	школьная	0103000020E610000001000000050000009FC9FE791AF24440EC67B114C9F74B409FC9FE791AF244404644317903FA4B40E8DD585018F444404644317903FA4B40E8DD585018F44440EC67B114C9F74B409FC9FE791AF24440EC67B114C9F74B40
34969	5152	41.521633000000001	41.553783000000003	55.732711999999999	55.718344000000002	ленина	0103000020E61000000100000005000000D7C1C1DEC4C2444090A339B2F2DB4B40D7C1C1DEC4C2444081B1BE81C9DD4B40570A815CE2C6444081B1BE81C9DD4B40570A815CE2C6444090A339B2F2DB4B40D7C1C1DEC4C2444090A339B2F2DB4B40
34886	5269	41.547513000000002	41.572693000000001	55.805785999999998	55.791232999999998	заводская	0103000020E610000001000000050000004391EEE714C644400B42791F47E54B404391EEE714C644408EC9E2FE23E74B40F6D214014EC944408EC9E2FE23E74B40F6D214014EC944400B42791F47E54B404391EEE714C644400B42791F47E54B40
34538	5925	41.720177999999997	41.793723	55.897841	55.856592999999997	красноармейская	0103000020E610000001000000050000003BA6EECA2EDC4440C37DE4D6A4ED4B403BA6EECA2EDC444004013274ECF24B40A08A1BB798E5444004013274ECF24B40A08A1BB798E54440C37DE4D6A4ED4B403BA6EECA2EDC4440C37DE4D6A4ED4B40
34504	5925	41.720177999999997	41.793723	55.897841	55.856592999999997	Школьная	0103000020E610000001000000050000003BA6EECA2EDC4440C37DE4D6A4ED4B403BA6EECA2EDC444004013274ECF24B40A08A1BB798E5444004013274ECF24B40A08A1BB798E54440C37DE4D6A4ED4B403BA6EECA2EDC4440C37DE4D6A4ED4B40
34776	5925	41.720177999999997	41.793723	55.897841	55.856592999999997	Пролетарская	0103000020E610000001000000050000003BA6EECA2EDC4440C37DE4D6A4ED4B403BA6EECA2EDC444004013274ECF24B40A08A1BB798E5444004013274ECF24B40A08A1BB798E54440C37DE4D6A4ED4B403BA6EECA2EDC4440C37DE4D6A4ED4B40
34541	5925	41.720177999999997	41.793723	55.897841	55.856592999999997	 Механизаторов	0103000020E610000001000000050000003BA6EECA2EDC4440C37DE4D6A4ED4B403BA6EECA2EDC444004013274ECF24B40A08A1BB798E5444004013274ECF24B40A08A1BB798E54440C37DE4D6A4ED4B403BA6EECA2EDC4440C37DE4D6A4ED4B40
35154	5464	41.390937000000001	41.414256999999999	55.710417999999997	55.699883	Центральная	0103000020E61000000100000005000000EFE53E390AB24440600322C495D94B40EFE53E390AB24440AF3E1EFAEEDA4B40CD91955F06B54440AF3E1EFAEEDA4B40CD91955F06B54440600322C495D94B40EFE53E390AB24440600322C495D94B40
35040	5612	41.602086	41.634748000000002	55.930539000000003	55.921536000000003	молодежная	0103000020E6100000010000000500000092B06F2711CD4440180B43E4F4F54B4092B06F2711CD44408753E6E61BF74B40C899266C3FD144408753E6E61BF74B40C899266C3FD14440180B43E4F4F54B4092B06F2711CD4440180B43E4F4F54B40
35110	54167	41.332385000000002	41.354922999999999	55.638174999999997	55.630650000000003	Центральная	0103000020E610000001000000050000002A5778978BAA4440789CA223B9D04B402A5778978BAA4440F90FE9B7AFD14B4092CCEA1D6EAD4440F90FE9B7AFD14B4092CCEA1D6EAD4440789CA223B9D04B402A5778978BAA4440789CA223B9D04B40
34888	5272	41.617320999999997	41.644657000000002	55.701931999999999	55.692242	кирпичная	0103000020E610000001000000050000002711E15F04CF44407575C7629BD84B402711E15F04CF4440080264E8D8D94B409911DE1E84D24440080264E8D8D94B409911DE1E84D244407575C7629BD84B402711E15F04CF44407575C7629BD84B40
34917	5389	41.667824000000003	41.690731	55.694311999999996	55.682842999999998	Школьная	0103000020E61000000100000005000000F1BDBF417BD54440B9A6406667D74B40F1BDBF417BD54440349C3237DFD84B40ACAA97DF69D84440349C3237DFD84B40ACAA97DF69D84440B9A6406667D74B40F1BDBF417BD54440B9A6406667D74B40
34937	4919	41.758420000000001	41.782710000000002	55.847659	55.830275	Зеленая	0103000020E61000000100000005000000F05014E813E14440DCD7817346EA4B40F05014E813E144407D94111780EC4B4047205ED72FE444407D94111780EC4B4047205ED72FE44440DCD7817346EA4B40F05014E813E14440DCD7817346EA4B40
34677	54143	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	1 квартал	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
34904	6554	39.610332	39.636231000000002	55.970030000000001	55.961948999999997	профсоюзная	0103000020E61000000100000005000000E4D9E55B1FCE4340BFB5132521FB4B40E4D9E55B1FCE4340C7116BF129FC4B40C7D9740470D14340C7116BF129FC4B40C7D9740470D14340BFB5132521FB4B40E4D9E55B1FCE4340BFB5132521FB4B40
34958	6054	39.451177999999999	39.498860000000001	55.949213999999998	55.933413000000002	Шоссейная	0103000020E610000001000000050000005C566133C0B94340A454C2137AF74B405C566133C0B94340E27327D87FF94B402BA4FCA4DABF4340E27327D87FF94B402BA4FCA4DABF4340A454C2137AF74B405C566133C0B94340A454C2137AF74B40
35127	6167	39.311228999999997	39.334909000000003	55.910518000000003	55.897216	Артельная	0103000020E610000001000000050000008C48145AD6A7434056B950F9D7F24B408C48145AD6A74340AD3594DA8BF44B406B11514CDEAA4340AD3594DA8BF44B406B11514CDEAA434056B950F9D7F24B408C48145AD6A7434056B950F9D7F24B40
35092	7998	39.192974999999997	39.222448999999997	55.900970999999998	55.884625	Вокзальная	0103000020E6100000010000000500000009F9A067B3984340AC1C5A643BF14B4009F9A067B39843407CD2890453F34B4092037635799C43407CD2890453F34B4092037635799C4340AC1C5A643BF14B4009F9A067B3984340AC1C5A643BF14B40
34998	8249	38.904777000000003	38.918512999999997	56.009441000000002	56.000900000000001	клубная	0103000020E61000000100000005000000259694BBCF7343408048BF7D1D004C40259694BBCF734340EB1ED95C35014C40B5F97FD591754340EB1ED95C35014C40B5F97FD5917543408048BF7D1D004C40259694BBCF7343408048BF7D1D004C40
34495	7350	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	советская	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
34553	7350	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	Советская	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
34597	7350	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	Ленина	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
34554	7350	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	Больничный проезд	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
34497	7350	39.153134999999999	39.209755000000001	55.927315999999998	55.909196000000001	3 Интернационала	0103000020E61000000100000005000000BD6F7CED99934340B7D3D68860F44B40BD6F7CED999343405D876A4AB2F64B4014967840D99A43405D876A4AB2F64B4014967840D99A4340B7D3D68860F44B40BD6F7CED99934340B7D3D68860F44B40
34872	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	пушкина	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34883	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	покровка	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
35019	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	ленина	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34740	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Школьная	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34596	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Чкалова	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
35167	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Профсоюзная	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34551	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Московская	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
9728	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Кирова	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
74918	5290	39.424318	39.504618000000001	55.936469000000002	55.913111000000001	Вокзальная	0103000020E61000000100000005000000548D5E0D50B64340164F3DD2E0F44B40548D5E0D50B64340E25B5837DEF74B40897C975297C04340E25B5837DEF74B40897C975297C04340164F3DD2E0F44B40548D5E0D50B64340164F3DD2E0F44B40
34993	6652	39.689725000000003	39.711815000000001	55.969053000000002	55.956839000000002	центральная	0103000020E61000000100000005000000E71DA7E848D84340C8444AB379FA4B40E71DA7E848D843409C8BBFED09FC4B40B0E600C11CDB43409C8BBFED09FC4B40B0E600C11CDB4340C8444AB379FA4B40E71DA7E848D84340C8444AB379FA4B40
35075	6908	39.698231999999997	39.710144	56.066786	56.059609000000002	Начальная школа	0103000020E61000000100000005000000A5828AAA5FD943400DC68844A1074C40A5828AAA5FD9434053EA92718C084C40AEB9A3FFE5DA434053EA92718C084C40AEB9A3FFE5DA43400DC68844A1074C40A5828AAA5FD943400DC68844A1074C40
35108	8172	39.075232999999997	39.096953999999997	56.006683000000002	55.993333	Верхняя	0103000020E610000001000000050000003C4A253CA1894340CF84268925FF4B403C4A253CA1894340373811FDDA004C40B29B19FD688C4340373811FDDA004C40B29B19FD688C4340CF84268925FF4B403C4A253CA1894340CF84268925FF4B40
34960	6245	39.386777000000002	39.395473000000003	55.937306	55.932243	центральная	0103000020E6100000010000000500000029ECA2E881B14340647616BD53F74B4029ECA2E881B143401B2C9CA4F9F74B40BBB9F8DB9EB243401B2C9CA4F9F74B40BBB9F8DB9EB24340647616BD53F74B4029ECA2E881B14340647616BD53F74B40
74930	60380	\N	\N	\N	\N	Муромская	\N
35099	6725	39.722701999999998	39.745457000000002	55.921919000000003	55.910266	Центральная	0103000020E610000001000000050000007C60C77F81DC43409354A69883F44B407C60C77F81DC4340D047197101F64B4082C98D226BDF4340D047197101F64B4082C98D226BDF43409354A69883F44B407C60C77F81DC43409354A69883F44B40
35076	8093	39.274084000000002	39.306648000000003	55.870747999999999	55.858362	Советская	0103000020E61000000100000005000000AE2D3C2F15A34340881057CEDEED4B40AE2D3C2F15A343405987A3AB74EF4B4021B1DD3D40A743405987A3AB74EF4B4021B1DD3D40A74340881057CEDEED4B40AE2D3C2F15A34340881057CEDEED4B40
35105	6839	39.627516999999997	39.642555000000002	56.031357	56.021456999999998	Совхозная	0103000020E610000001000000050000008E57207A52D0434098A25C1ABF024C408E57207A52D0434016C0948103044C40CE70033E3FD2434016C0948103044C40CE70033E3FD2434098A25C1ABF024C408E57207A52D0434098A25C1ABF024C40
34961	6318	39.334854999999997	39.367023000000003	55.995165999999998	55.978448	Спортивная	0103000020E6100000010000000500000077F35487DCAA4340166BB8C83DFD4B4077F35487DCAA4340AA0B789961FF4B409EF0129CFAAE4340AA0B789961FF4B409EF0129CFAAE4340166BB8C83DFD4B4077F35487DCAA4340166BB8C83DFD4B40
34650	7053	39.609883000000004	39.641243000000003	55.943452000000001	55.922984	южная	0103000020E6100000010000000500000075B169A510CE43409A5DF75624F64B4075B169A510CE434043ACFE08C3F84B40FCE4284014D2434043ACFE08C3F84B40FCE4284014D243409A5DF75624F64B4075B169A510CE43409A5DF75624F64B40
34459	7053	39.609883000000004	39.641243000000003	55.943452000000001	55.922984	писцова	0103000020E6100000010000000500000075B169A510CE43409A5DF75624F64B4075B169A510CE434043ACFE08C3F84B40FCE4284014D2434043ACFE08C3F84B40FCE4284014D243409A5DF75624F64B4075B169A510CE43409A5DF75624F64B40
34649	7053	39.609883000000004	39.641243000000003	55.943452000000001	55.922984	пионерская	0103000020E6100000010000000500000075B169A510CE43409A5DF75624F64B4075B169A510CE434043ACFE08C3F84B40FCE4284014D2434043ACFE08C3F84B40FCE4284014D243409A5DF75624F64B4075B169A510CE43409A5DF75624F64B40
34999	7053	39.609883000000004	39.641243000000003	55.943452000000001	55.922984	Заречная	0103000020E6100000010000000500000075B169A510CE43409A5DF75624F64B4075B169A510CE434043ACFE08C3F84B40FCE4284014D2434043ACFE08C3F84B40FCE4284014D243409A5DF75624F64B4075B169A510CE43409A5DF75624F64B40
34784	7053	39.609883000000004	39.641243000000003	55.943452000000001	55.922984	Горького	0103000020E6100000010000000500000075B169A510CE43409A5DF75624F64B4075B169A510CE434043ACFE08C3F84B40FCE4284014D2434043ACFE08C3F84B40FCE4284014D243409A5DF75624F64B4075B169A510CE43409A5DF75624F64B40
35125	6087	39.441242000000003	39.461095	55.968076000000003	55.953876000000001	им. Н.К. Погодина	0103000020E6100000010000000500000092CF2B9E7AB843403B38D89B18FA4B4092CF2B9E7AB84340710514EAE9FB4B40B0AC342905BB4340710514EAE9FB4B40B0AC342905BB43403B38D89B18FA4B4092CF2B9E7AB843403B38D89B18FA4B40
35086	6992	39.506289000000002	39.528486999999998	56.137084000000002	56.127206000000001	Каргополова	0103000020E610000001000000050000008BA9F413CEC0434070ED444948104C408BA9F413CEC043400667F0F78B114C403AAE4676A5C343400667F0F78B114C403AAE4676A5C3434070ED444948104C408BA9F413CEC0434070ED444948104C40
34655	8290	39.101239	39.105362	55.870187999999999	55.867303999999997	Ленина	0103000020E61000000100000005000000350A4966F58C434051D845D103EF4B40350A4966F58C434092AF045262EF4B40DE1E84807C8D434092AF045262EF4B40DE1E84807C8D434051D845D103EF4B40350A4966F58C434051D845D103EF4B40
34738	8290	39.101239	39.105362	55.870187999999999	55.867303999999997	К. Соловьева	0103000020E61000000100000005000000350A4966F58C434051D845D103EF4B40350A4966F58C434092AF045262EF4B40DE1E84807C8D434092AF045262EF4B40DE1E84807C8D434051D845D103EF4B40350A4966F58C434051D845D103EF4B40
35077	7891	39.154401	39.172618999999997	55.889048000000003	55.883262000000002	 Школьная	0103000020E610000001000000050000001FBC7669C393434058E6ADBA0EF14B401FBC7669C393434080492A53CCF14B4088D51F611896434080492A53CCF14B4088D51F611896434058E6ADBA0EF14B401FBC7669C393434058E6ADBA0EF14B40
34933	6479	39.431486999999997	39.452021999999999	56.083195000000003	56.06559	круглова	0103000020E6100000010000000500000017D34CF73AB74340EA78CC4065084C4017D34CF73AB743406A183E22A60A4C4048895DDBDBB943406A183E22A60A4C4048895DDBDBB94340EA78CC4065084C4017D34CF73AB74340EA78CC4065084C40
34499	7711	39.212989	39.242840000000001	55.959384	55.945780999999997	старовская	0103000020E6100000010000000500000031B43A39439B4340CE16105A0FF94B4031B43A39439B434020274C18CDFA4B4090149161159F434020274C18CDFA4B4090149161159F4340CE16105A0FF94B4031B43A39439B4340CE16105A0FF94B40
34598	7711	39.212989	39.242840000000001	55.959384	55.945780999999997	Старовская	0103000020E6100000010000000500000031B43A39439B4340CE16105A0FF94B4031B43A39439B434020274C18CDFA4B4090149161159F434020274C18CDFA4B4090149161159F4340CE16105A0FF94B4031B43A39439B4340CE16105A0FF94B40
35051	6689	39.721031000000004	39.783580999999998	55.967834000000003	55.947631000000001	Лесхозная	0103000020E610000001000000050000007B336ABE4ADC434080D6FCF84BF94B407B336ABE4ADC43407BFA08FCE1FB4B402C62D8614CE443407BFA08FCE1FB4B402C62D8614CE4434080D6FCF84BF94B407B336ABE4ADC434080D6FCF84BF94B40
35157	6986	39.575684000000003	39.589176999999999	56.088543999999999	56.074001000000003	Арханинская	0103000020E610000001000000050000004D6A6803B0C94340876F61DD78094C404D6A6803B0C94340E620E868550B4C401747E5266ACB4340E620E868550B4C401747E5266ACB4340876F61DD78094C404D6A6803B0C94340876F61DD78094C40
34777	54146	42.029440999999998	42.057451	55.606710999999997	55.591025000000002	Клубная	0103000020E61000000100000005000000AD1402B9C4034540280F0BB5A6CB4B40AD1402B9C4034540CD8FBFB4A8CD4B40AE0FEB8D5A074540CD8FBFB4A8CD4B40AE0FEB8D5A074540280F0BB5A6CB4B40AD1402B9C4034540280F0BB5A6CB4B40
34985	48841	42.017313999999999	42.043581000000003	55.677204000000003	55.658687999999998	муромская	0103000020E61000000100000005000000A8E15B583702454042226DE34FD44B40A8E15B5837024540365CE49EAED64B400EDDEC0F94054540365CE49EAED64B400EDDEC0F9405454042226DE34FD44B40A8E15B583702454042226DE34FD44B40
35111	48712	42.120170999999999	42.154927000000001	55.896326999999999	55.882928999999997	Мира	0103000020E61000000100000005000000BC7669C3610F454051D845D103F14B40BC7669C3610F4540CAC2D7D7BAF24B403A22DFA5D4134540CAC2D7D7BAF24B403A22DFA5D413454051D845D103F14B40BC7669C3610F454051D845D103F14B40
35022	48737	41.867941999999999	41.889240999999998	55.781123999999998	55.770487000000003	сельская	0103000020E61000000100000005000000946934B918EF4440207F69519FE24B40946934B918EF4440730F09DFFBE34B4094A12AA6D2F14440730F09DFFBE34B4094A12AA6D2F14440207F69519FE24B40946934B918EF4440207F69519FE24B40
35143	49002	41.867736000000001	41.893732999999997	55.565106	55.550910999999999	Первая	0103000020E61000000100000005000000EBC726F911EF4440DA006C4084C64B40EBC726F911EF4440FE62B66455C84B40902DCBD765F24440FE62B66455C84B40902DCBD765F24440DA006C4084C64B40EBC726F911EF4440DA006C4084C64B40
35034	4771	41.899563000000001	41.914510999999997	55.516134000000001	55.509068999999997	совхозная	0103000020E6100000010000000500000088D860E124F344402634492C29C14B4088D860E124F34440452DCDAD10C24B40876A4AB20EF54440452DCDAD10C24B40876A4AB20EF544402634492C29C14B4088D860E124F344402634492C29C14B40
35168	3469	41.924168000000002	41.957307	55.658586	55.640680000000003	Заречная	0103000020E610000001000000050000003F0114234BF64440C4995FCD01D24B403F0114234BF644403ECDC98B4CD44B40AE9D280989FA44403ECDC98B4CD44B40AE9D280989FA4440C4995FCD01D24B403F0114234BF64440C4995FCD01D24B40
35152	48765	41.875191999999998	41.895232999999998	55.738185999999999	55.724713000000001	Молодежная	0103000020E6100000010000000500000044DC9C4A06F0444037FE4465C3DC4B4044DC9C4A06F04440BA2EFCE07CDE4B4065A6B4FE96F24440BA2EFCE07CDE4B4065A6B4FE96F2444037FE4465C3DC4B4044DC9C4A06F0444037FE4465C3DC4B40
35063	48694	42.212176999999997	42.236798999999998	55.773691999999997	55.767052999999997	Юбилейная	0103000020E6100000010000000500000050FBAD9D281B45403BA6EECA2EE24B4050FBAD9D281B4540A296E65608E34B40DD5CFC6D4F1E4540A296E65608E34B40DD5CFC6D4F1E45403BA6EECA2EE24B4050FBAD9D281B45403BA6EECA2EE24B40
34918	4478	41.852446	41.883474	55.616875	55.600347999999997	центральная	0103000020E6100000010000000500000092CD55F31CED4440081C0934D8CC4B4092CD55F31CED4440295C8FC2F5CE4B40E36E10AD15F14440295C8FC2F5CE4B40E36E10AD15F14440081C0934D8CC4B4092CD55F31CED4440081C0934D8CC4B40
35010	2441	42.018571999999999	42.035693999999999	55.560488999999997	55.554403999999998	Центральная	0103000020E61000000100000005000000874F3A9160024540C362D4B5F6C64B40874F3A91600245404562821ABEC74B40EB54F99E910445404562821ABEC74B40EB54F99E91044540C362D4B5F6C64B40874F3A9160024540C362D4B5F6C64B40
34533	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	пионеров	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34723	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	орловская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34766	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	московская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34719	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	лакина	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34532	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	куйбышева	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34715	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Филатова	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34491	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Привокзальная	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34579	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Первомайская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34576	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Орловская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34540	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Муромская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34530	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Московская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34763	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Мечникова	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34588	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Льва Толстого	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34490	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Ленинградская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34631	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Ленина	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34581	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Лакина	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34531	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Красина	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34623	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Кооперативная	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34617	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Комсомольская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34620	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Колхозная	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34485	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Ковровская	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34762	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Кирова	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34618	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Карла Маркса	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34616	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Карачаровское шоссе	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34720	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Гоголева	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34813	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Артема	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34488	701	41.981003999999999	42.092574999999997	55.593277999999998	55.527484000000001	Амосова	0103000020E61000000100000005000000629F008A91FD4440E694809884C34B40629F008A91FD4440D8B79388F0CB4B40AEB6627FD90B4540D8B79388F0CB4B40AEB6627FD90B4540E694809884C34B40629F008A91FD4440E694809884C34B40
34916	3790	41.92671	41.975541999999997	55.763351	55.738449000000003	гагарина	0103000020E610000001000000050000002670EB6E9EF64440C861307F85DE4B402670EB6E9EF64440382F4E7CB5E14B40EDEF6C8FDEFC4440382F4E7CB5E14B40EDEF6C8FDEFC4440C861307F85DE4B402670EB6E9EF64440C861307F85DE4B40
35091	49084	41.972712999999999	42.002797000000001	55.511964999999996	55.496858000000003	Комсомольская	0103000020E6100000010000000500000070B20DDC81FC4440C460FE0A99BF4B4070B20DDC81FC44402BD9B11188C14B4072C3EFA65B0045402BD9B11188C14B4072C3EFA65B004540C460FE0A99BF4B4070B20DDC81FC4440C460FE0A99BF4B40
35446	48952	41.849769000000002	41.884723000000001	55.674655999999999	55.661237	Кооперативная	0103000020E61000000100000005000000CB13083BC5EC4440DCF3FC69A3D44B40CB13083BC5EC44406C06B8205BD64B406F826F9A3EF144406C06B8205BD64B406F826F9A3EF14440DCF3FC69A3D44B40CB13083BC5EC4440DCF3FC69A3D44B40
35066	4196	41.785539999999997	41.819918000000001	55.710545000000003	55.699289	Полевая	0103000020E6100000010000000500000094D920938CE44440EDB94C4D82D94B4094D920938CE444400DAB7823F3DA4B406CB3B112F3E844400DAB7823F3DA4B406CB3B112F3E84440EDB94C4D82D94B4094D920938CE44440EDB94C4D82D94B40
35114	49001	41.934319000000002	41.954261000000002	55.588740000000001	55.579433999999999	Центральная	0103000020E610000001000000050000000684D6C397F744406118B0E42ACA4B400684D6C397F744406CEC12D55BCB4B40946C753925FA44406CEC12D55BCB4B40946C753925FA44406118B0E42ACA4B400684D6C397F744406118B0E42ACA4B40
35080	46962	41.921436999999997	41.944280999999997	55.685608999999999	55.675910000000002	Центральная	0103000020E610000001000000050000008429CAA5F1F544400A85083884D64B408429CAA5F1F54440F06B2409C2D74B40F99D2633DEF84440F06B2409C2D74B40F99D2633DEF844400A85083884D64B408429CAA5F1F544400A85083884D64B40
35064	49041	41.943221000000001	41.966540999999999	55.564459999999997	55.549031999999997	Школьная	0103000020E6100000010000000500000041F33977BBF844408E3A3AAE46C64B4041F33977BBF8444038F3AB3940C84B401F9F909DB7FB444038F3AB3940C84B401F9F909DB7FB44408E3A3AAE46C64B4041F33977BBF844408E3A3AAE46C64B40
35032	48730	41.900767000000002	41.917546999999999	55.807592	55.791804999999997	муромская	0103000020E61000000100000005000000742843554CF3444096E7C1DD59E54B40742843554CF344407041B62C5FE74B407EC51A2E72F544407041B62C5FE74B407EC51A2E72F5444096E7C1DD59E54B40742843554CF3444096E7C1DD59E54B40
34816	4464	41.934876000000003	41.970681999999996	55.630609	55.600724999999997	Школьная	0103000020E610000001000000050000005CE84A04AAF74440DE718A8EE4CC4B405CE84A04AAF7444019C8B3CBB7D04B406E68CA4E3FFC444019C8B3CBB7D04B406E68CA4E3FFC4440DE718A8EE4CC4B405CE84A04AAF74440DE718A8EE4CC4B40
35062	49032	41.903129	41.936439	55.555072000000003	55.542924999999997	Школьная	0103000020E61000000100000005000000DB8827BB99F344402497FF907EC54B40DB8827BB99F3444071766B990CC74B4077D9AF3BDDF7444071766B990CC74B4077D9AF3BDDF744402497FF907EC54B40DB8827BB99F344402497FF907EC54B40
34668	46979	41.831237000000002	41.839402999999997	55.719171000000003	55.711762	 Молодёжная	0103000020E61000000100000005000000D21C59F965EA44408D4468041BDB4B40D21C59F965EA4440A69D9ACB0DDC4B400795B88E71EB4440A69D9ACB0DDC4B400795B88E71EB44408D4468041BDB4B40D21C59F965EA44408D4468041BDB4B40
34982	48898	41.742168999999997	41.774616000000002	55.695529999999998	55.677286000000002	Мира	0103000020E61000000100000005000000718DCF64FFDE4440F304C24EB1D64B40718DCF64FFDE444085B1852007D94B40AB7AF99D26E3444085B1852007D94B40AB7AF99D26E34440F304C24EB1D64B40718DCF64FFDE4440F304C24EB1D64B40
35120	48660	42.352466	42.374457	55.808259999999997	55.799987999999999	Приокская	0103000020E61000000100000005000000D9791B9B1D2D4540A298BC0166E64B40D9791B9B1D2D45401D554D1075E74B400F61FC34EE2F45401D554D1075E74B400F61FC34EE2F4540A298BC0166E64B40D9791B9B1D2D4540A298BC0166E64B40
34968	48790	42.003058000000003	42.024526999999999	55.720250999999998	55.705879000000003	Коминтерна	0103000020E61000000100000005000000DFFE5C346400454073F7393E5ADA4B40DFFE5C3464004540A5F44C2F31DC4B403B6F63B323034540A5F44C2F31DC4B403B6F63B32303454073F7393E5ADA4B40DFFE5C346400454073F7393E5ADA4B40
35147	46024	41.989646	42.017467000000003	55.423233000000003	55.411537000000003	Центральная	0103000020E61000000100000005000000014F5AB8ACFE4440070C923EADB44B40014F5AB8ACFE444043CBBA7F2CB64B402FE1D05B3C02454043CBBA7F2CB64B402FE1D05B3C024540070C923EADB44B40014F5AB8ACFE4440070C923EADB44B40
35023	46023	42.008375999999998	42.031471000000003	55.444654999999997	55.424725000000002	Центральная	0103000020E610000001000000050000002009FB7612014540956588635DB64B402009FB76120145405E807D74EAB84B40DFE2E13D070445405E807D74EAB84B40DFE2E13D07044540956588635DB64B402009FB7612014540956588635DB64B40
35361	46129	41.853667999999999	41.892313000000001	55.459006000000002	55.424545999999999	Совхозная	0103000020E6100000010000000500000024D236FE44ED4440E5D2F88557B64B4024D236FE44ED44407A5567B5C0BA4B40D865F84F37F244407A5567B5C0BA4B40D865F84F37F24440E5D2F88557B64B4024D236FE44ED4440E5D2F88557B64B40
34938	45529	41.362378999999997	41.400889999999997	55.415339000000003	55.403855	Молодежная	0103000020E61000000100000005000000EBE0606F62AE4440BDA94885B1B34B40EBE0606F62AE44406EE00ED429B54B408FA50F5D50B344406EE00ED429B54B408FA50F5D50B34440BDA94885B1B34B40EBE0606F62AE4440BDA94885B1B34B40
35042	45419	41.490084000000003	41.514572000000001	55.608947999999998	55.593482000000002	новая	0103000020E610000001000000050000007D259012BBBE4440E161DA37F7CB4B407D259012BBBE4440787B1002F2CD4B40FAB7CB7EDDC14440787B1002F2CD4B40FAB7CB7EDDC14440E161DA37F7CB4B407D259012BBBE4440E161DA37F7CB4B40
35093	7262	41.401446999999997	41.432420999999998	55.445559000000003	55.424725000000002	Комсомольская	0103000020E61000000100000005000000E509849D62B34440956588635DB64B40E509849D62B3444020B8CA1308B94B40438D429259B7444020B8CA1308B94B40438D429259B74440956588635DB64B40E509849D62B34440956588635DB64B40
35097	46069	41.828460999999997	41.848286999999999	55.432909000000002	55.413417000000003	Советская	0103000020E61000000100000005000000778192020BEA4440234E27D9EAB44B40778192020BEA44407192E68F69B74B409C4F1DAB94EC44407192E68F69B74B409C4F1DAB94EC4440234E27D9EAB44B40778192020BEA4440234E27D9EAB44B40
35359	4319	41.817447999999999	41.836905000000002	55.408158999999998	55.389642000000002	Советская	0103000020E610000001000000050000001E17D522A2E84440F392FFC9DFB14B401E17D522A2E84440B648DA8D3EB44B40F06DFAB31FEB4440B648DA8D3EB44B40F06DFAB31FEB4440F392FFC9DFB14B401E17D522A2E84440F392FFC9DFB14B40
35094	45610	41.670627000000003	41.681874000000001	55.441147000000001	55.426420999999998	Зеленая	0103000020E610000001000000050000004568041BD7D54440EFA99CF694B64B404568041BD7D5444040DD408177B84B4011FFB0A547D7444040DD408177B84B4011FFB0A547D74440EFA99CF694B64B404568041BD7D54440EFA99CF694B64B40
34921	45600	41.734470000000002	41.771785999999999	55.568877999999998	55.554673999999999	советская	0103000020E6100000010000000500000052F2EA1C03DE444083F8C08EFFC64B4052F2EA1C03DE4440FAB48AFED0C84B405DC136E2C9E24440FAB48AFED0C84B405DC136E2C9E2444083F8C08EFFC64B4052F2EA1C03DE444083F8C08EFFC64B40
35096	45964	41.796166999999997	41.817869999999999	55.342703	55.332340000000002	Центральная	0103000020E61000000100000005000000C493DDCCE8E544408A93FB1D8AAA4B40C493DDCCE8E54440DC9E20B1DDAB4B409430D3F6AFE84440DC9E20B1DDAB4B409430D3F6AFE844408A93FB1D8AAA4B40C493DDCCE8E544408A93FB1D8AAA4B40
35095	7708	41.699013999999998	41.708347000000003	55.144238000000001	55.132911	Центральная	0103000020E610000001000000050000001BB96E4A79D94440AB23473A03914B401BB96E4A79D94440946B0A6476924B40209C4F1DABDA4440946B0A6476924B40209C4F1DABDA4440AB23473A03914B401BB96E4A79D94440AB23473A03914B40
35442	45396	41.387191000000001	41.417921999999997	55.562469	55.553584999999998	Центральная	0103000020E610000001000000050000001C2785798FB1444030478FDFDBC64B401C2785798FB14440C501F4FBFEC74B40B323D5777EB54440C501F4FBFEC74B40B323D5777EB5444030478FDFDBC64B401C2785798FB1444030478FDFDBC64B40
34543	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	комсомольская	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
35170	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Свердлова	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34941	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Пушкина	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34891	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Мичурина	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34986	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Ленина	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34651	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Комсомольская	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34514	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	Дзержинского	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
34889	5375	41.597343000000002	41.658177000000002	55.352316999999999	55.320632000000003	1 Мая	0103000020E610000001000000050000004DBF44BC75CC44408A0629780AA94B404DBF44BC75CC4440946934B918AD4B405DFDD8243FD44440946934B918AD4B405DFDD8243FD444408A0629780AA94B404DBF44BC75CC44408A0629780AA94B40
35043	7665	41.737085	41.762200999999997	55.179518999999999	55.170568000000003	центральная	0103000020E61000000100000005000000A3AF20CD58DE444040DF162CD5954B40A3AF20CD58DE44405C01857AFA964B403FFD67CD8FE144405C01857AFA964B403FFD67CD8FE1444040DF162CD5954B40A3AF20CD58DE444040DF162CD5954B40
35145	7157	41.567338999999997	41.596786000000002	55.342298999999997	55.329363999999998	Центральная	0103000020E61000000100000005000000675F79909EC84440683D7C9928AA4B40675F79909EC844400C3A2174D0AB4B40F75AD07B63CC44400C3A2174D0AB4B40F75AD07B63CC4440683D7C9928AA4B40675F79909EC84440683D7C9928AA4B40
35144	45385	41.400655999999998	41.432637	55.504103999999998	55.488309999999998	Каманина	0103000020E610000001000000050000001C7920B248B34440A6272CF180BE4B401C7920B248B3444032E4D87A86C04B40100533A660B7444032E4D87A86C04B40100533A660B74440A6272CF180BE4B401C7920B248B34440A6272CF180BE4B40
34881	8247	41.914600999999998	41.936421000000003	55.345677999999999	55.314611999999997	советская	0103000020E61000000100000005000000C7F143A511F54440EE76BD3445A84B40C7F143A511F544402D793C2D3FAC4B40D124B1A4DCF744402D793C2D3FAC4B40D124B1A4DCF74440EE76BD3445A84B40C7F143A511F54440EE76BD3445A84B40
34919	8247	41.914600999999998	41.936421000000003	55.345677999999999	55.314611999999997	горького	0103000020E61000000100000005000000C7F143A511F54440EE76BD3445A84B40C7F143A511F544402D793C2D3FAC4B40D124B1A4DCF744402D793C2D3FAC4B40D124B1A4DCF74440EE76BD3445A84B40C7F143A511F54440EE76BD3445A84B40
35138	7987	41.610314000000002	41.625559000000003	55.308956000000002	55.290171999999998	Центральная	0103000020E610000001000000050000003E25E7C41ECE4440821B295B24A54B403E25E7C41ECE444095F3C5DE8BA74B40F75B3B5112D0444095F3C5DE8BA74B40F75B3B5112D04440821B295B24A54B403E25E7C41ECE4440821B295B24A54B40
35202	45558	41.607286999999999	41.639339	55.536731000000003	55.518596000000002	Школьная	0103000020E610000001000000050000009A249694BBCD444010EB8D5A61C24B409A249694BBCD4440ECDFF599B3C44B40570740DCD5D14440ECDFF599B3C44B40570740DCD5D1444010EB8D5A61C24B409A249694BBCD444010EB8D5A61C24B40
35171	8185	41.779234000000002	41.809435000000001	55.321871000000002	55.313454999999998	Новая	0103000020E6100000010000000500000034F790F0BDE3444043E21E4B1FA84B4034F790F0BDE34440F243A51133A94B406F9EEA909BE74440F243A51133A94B406F9EEA909BE7444043E21E4B1FA84B4034F790F0BDE3444043E21E4B1FA84B40
35137	7947	41.627265999999999	41.640911000000003	55.210664999999999	55.193412000000002	Центральная	0103000020E6100000010000000500000045F295404AD04440B55373B9C1984B4045F295404AD04440B7B41A12F79A4B40C652245F09D24440B7B41A12F79A4B40C652245F09D24440B55373B9C1984B4045F295404AD04440B55373B9C1984B40
35038	45779	41.596102999999999	41.616872000000001	55.275457000000003	55.256205999999999	новая	0103000020E610000001000000050000001406651A4DCC4440FD84B35BCBA04B401406651A4DCC4440263ACB2C42A34B40B8E864A9F5CE4440263ACB2C42A34B40B8E864A9F5CE4440FD84B35BCBA04B401406651A4DCC4440FD84B35BCBA04B40
67411	45459	41.491475999999999	41.516385999999997	55.388665000000003	55.371245000000002	Зелёная	0103000020E610000001000000050000006B6281AFE8BE4440DAE6C6F484AF4B406B6281AFE8BE4440C80C54C6BFB14B405E0EBBEF18C24440C80C54C6BFB14B405E0EBBEF18C24440DAE6C6F484AF4B406B6281AFE8BE4440DAE6C6F484AF4B40
35119	45671	41.767097	41.801000000000002	55.249339999999997	55.237730999999997	клубная	0103000020E610000001000000050000000BEE073C30E24440681F2BF86D9E4B400BEE073C30E24440D5CA845FEA9F4B404A0C022B87E64440D5CA845FEA9F4B404A0C022B87E64440681F2BF86D9E4B400BEE073C30E24440681F2BF86D9E4B40
35021	45775	41.593597000000003	41.615848	55.234983999999997	55.208280999999999	Центральная	0103000020E610000001000000050000007A008BFCFACB444068B0A9F3A89A4B407A008BFCFACB4440A88AA9F4139E4B404CA7751BD4CE4440A88AA9F4139E4B404CA7751BD4CE444068B0A9F3A89A4B407A008BFCFACB444068B0A9F3A89A4B40
35068	45448	41.576627000000002	41.594898999999998	55.382880999999998	55.363124999999997	Центральная	0103000020E61000000100000005000000CC7EDDE9CEC9444014AE47E17AAE4B40CC7EDDE9CEC9444040A19E3E02B14B4028B682A625CC444040A19E3E02B14B4028B682A625CC444014AE47E17AAE4B40CC7EDDE9CEC9444014AE47E17AAE4B40
35156	45352	41.548923000000002	41.573196000000003	55.420248999999998	55.399413000000003	Центральная	0103000020E61000000100000005000000D882DE1B43C64440734C16F71FB34B40D882DE1B43C644409E961FB8CAB54B4059198D7C5EC944409E961FB8CAB54B4059198D7C5EC94440734C16F71FB34B40D882DE1B43C64440734C16F71FB34B40
35118	45874	42.071420000000003	42.084004999999998	55.428179	55.418998000000002	Новая	0103000020E61000000100000005000000E223624A24094540728BF9B9A1B54B40E223624A24094540C0EAC891CEB64B40A9D903ADC00A4540C0EAC891CEB64B40A9D903ADC00A4540728BF9B9A1B54B40E223624A24094540728BF9B9A1B54B40
34942	7589	41.771265	41.803919	55.215411000000003	55.197502	Первомайская	0103000020E6100000010000000500000054C6BFCFB8E244408272DBBE47994B4054C6BFCFB8E244406E197096929B4B4007D15AD1E6E644406E197096929B4B4007D15AD1E6E644408272DBBE47994B4054C6BFCFB8E244408272DBBE47994B40
34920	7366	41.649005000000002	41.686940999999997	55.515472000000003	55.495899000000001	Советская	0103000020E6100000010000000500000062F8889812D344403F8F519E79BF4B4062F8889812D344407A008BFCFAC14B4009A4C4AEEDD744407A008BFCFAC14B4009A4C4AEEDD744403F8F519E79BF4B4062F8889812D344403F8F519E79BF4B40
35069	7780	41.517446	41.539428000000001	55.206349000000003	55.192357999999999	Школьная	0103000020E6100000010000000500000017B9A7AB3BC24440DE8FDB2F9F984B4017B9A7AB3BC24440FA47DFA4699A4B40FA4509FA0BC54440FA47DFA4699A4B40FA4509FA0BC54440DE8FDB2F9F984B4017B9A7AB3BC24440DE8FDB2F9F984B40
35195	45856	41.918886000000001	41.935333999999997	55.363298999999998	55.348565000000001	Центральная	0103000020E610000001000000050000004A60730E9EF54440DFC325C79DAC4B404A60730E9EF54440B2D5E59480AE4B401E6B4606B9F74440B2D5E59480AE4B401E6B4606B9F74440DFC325C79DAC4B404A60730E9EF54440DFC325C79DAC4B40
35146	45649	41.821463000000001	41.845089000000002	55.257765999999997	55.238022999999998	Центральная	0103000020E61000000100000005000000E1EF17B325E944401059A489779E4B40E1EF17B325E94440A702EE79FEA04B40CC9A58E02BEC4440A702EE79FEA04B40CC9A58E02BEC44401059A489779E4B40E1EF17B325E944401059A489779E4B40
35117	45729	41.621022000000004	41.637039000000001	55.279184999999998	55.265183999999998	Центральная	0103000020E610000001000000050000005B0C1EA67DCF444013B69F8CF1A14B405B0C1EA67DCF444052448655BCA34B4066A3737E8AD1444052448655BCA34B4066A3737E8AD1444013B69F8CF1A14B405B0C1EA67DCF444013B69F8CF1A14B40
35037	6783	41.513575000000003	41.536006	55.457796000000002	55.448096	Центральная	0103000020E6100000010000000500000088855AD3BCC14440F5BBB0355BB94B4088855AD3BCC14440AC1E300F99BA4B40DA3A38D89BC44440AC1E300F99BA4B40DA3A38D89BC44440F5BBB0355BB94B4088855AD3BCC14440F5BBB0355BB94B40
34635	6719	41.484217999999998	41.515191999999999	55.525934999999997	55.504261999999997	Садовая	0103000020E610000001000000050000003811FDDAFABD4440CA4E3FA88BC04B403811FDDAFABD44402F698CD651C34B409694BBCFF1C144402F698CD651C34B409694BBCFF1C14440CA4E3FA88BC04B403811FDDAFABD4440CA4E3FA88BC04B40
35067	6990	41.554842999999998	41.582780999999997	55.358110000000003	55.345539000000002	Центральная	0103000020E610000001000000050000000FB56D1805C744400C3F389F3AAC4B400FB56D1805C744406F2F698CD6AD4B4076DD5B9198CA44406F2F698CD6AD4B4076DD5B9198CA44400C3F389F3AAC4B400FB56D1805C744400C3F389F3AAC4B40
34870	49568	41.540047999999999	41.570034	55.458174	55.446412000000002	Центральная	0103000020E610000001000000050000009622F94A20C544405F45460724B94B409622F94A20C5444052F01472A5BA4B40D5CDC5DFF6C8444052F01472A5BA4B40D5CDC5DFF6C844405F45460724B94B409622F94A20C544405F45460724B94B40
35044	8509	41.758662000000001	41.793301	55.390884999999997	55.379404000000001	Центральная	0103000020E61000000100000005000000E65B1FD61BE144405DFC6D4F90B04B40E65B1FD61BE144409CBF098508B24B402A711DE38AE544409CBF098508B24B402A711DE38AE544405DFC6D4F90B04B40E65B1FD61BE144405DFC6D4F90B04B40
35185	37527	37.291789000000001	37.298319999999997	55.836523999999997	55.827357999999997	Успенская	0103000020E61000000100000005000000912A8A5759A54240BF0AF0DDE6E94B40912A8A5759A54240D828EB3713EB4B4011DF89592FA64240D828EB3713EB4B4011DF89592FA64240BF0AF0DDE6E94B40912A8A5759A54240BF0AF0DDE6E94B40
34892	47766	39.449182999999998	39.466611	56.280231999999998	56.269095999999998	Первомайская	0103000020E61000000100000005000000A7751BD47EB9434001BEDBBC71224C40A7751BD47EB9434076A565A4DE234C40187AC4E8B9BB434076A565A4DE234C40187AC4E8B9BB434001BEDBBC71224C40A7751BD47EB9434001BEDBBC71224C40
35126	5177	39.665201000000003	39.687838999999997	56.291753	56.280605999999999	Четвертая	0103000020E610000001000000050000001D226E4E25D54340DB87BCE5EA234C401D226E4E25D5434044C18C2958254C40E8F4BC1B0BD8434044C18C2958254C40E8F4BC1B0BD84340DB87BCE5EA234C401D226E4E25D54340DB87BCE5EA234C40
34955	5256	39.220678999999997	39.244655000000002	56.367950999999998	56.358612000000001	Школьная	0103000020E61000000100000005000000FDF49F353F9C434001FA7DFFE62D4C40FDF49F353F9C4340E7C3B304192F4C40C5E6E3DA509F4340E7C3B304192F4C40C5E6E3DA509F434001FA7DFFE62D4C40FDF49F353F9C434001FA7DFFE62D4C40
34980	54160	39.593497999999997	39.597684000000001	56.148693999999999	56.146894000000003	Молодежная	0103000020E61000000100000005000000E61E12BEF7CB434044FD2E6CCD124C40E61E12BEF7CB4340438EAD6708134C40D6ABC8E880CC4340438EAD6708134C40D6ABC8E880CC434044FD2E6CCD124C40E61E12BEF7CB434044FD2E6CCD124C40
34438	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	шмелева	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34648	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	темкина	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34456	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	луговая	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34440	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	алексеева	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34685	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Садовая	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34548	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Молодежная	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34739	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Мира	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34494	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Интернационала	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34549	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	Гагарина	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34732	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	50 лет СССР	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
34454	3272	39.323526999999999	39.408445	56.322195000000001	56.282854999999998	3 Интернационала	0103000020E61000000100000005000000BE2F2E5569A943404A41B79734244C40BE2F2E5569A94340A5F78DAF3D294C407C9BFEEC47B44340A5F78DAF3D294C407C9BFEEC47B443404A41B79734244C40BE2F2E5569A943404A41B79734244C40
35340	49518	39.346111000000001	39.369385999999999	56.399093999999998	56.388297000000001	Первая 	0103000020E6100000010000000500000097E4805D4DAC4340451152B7B3314C4097E4805D4DAC4340D1031F8315334C40D5CC5A0A48AF4340D1031F8315334C40D5CC5A0A48AF4340451152B7B3314C4097E4805D4DAC4340451152B7B3314C40
35050	49536	39.342103999999999	39.361210999999997	56.429957000000002	56.421892	Тринадцатая	0103000020E6100000010000000500000057EA5910CAAB4340D6389B8E00364C4057EA5910CAAB4340D8D7BAD408374C404CFA7B293CAE4340D8D7BAD408374C404CFA7B293CAE4340D6389B8E00364C4057EA5910CAAB4340D6389B8E00364C40
35104	5155	39.533453999999999	39.547027999999997	56.308419999999998	56.296559000000002	Коллективная	0103000020E61000000100000005000000CFF57D3848C44340D02A33A5F5254C40CFF57D3848C4434056B77A4E7A274C4086FF740305C6434056B77A4E7A274C4086FF740305C64340D02A33A5F5254C40CFF57D3848C44340D02A33A5F5254C40
35166	5044	39.605902999999998	39.623303999999997	56.214927000000003	56.201824999999999	Школьная	0103000020E610000001000000050000002EC6C03A8ECD4340F241CF66D5194C402EC6C03A8ECD434082035ABA821B4C40A5BBEB6CC8CF434082035ABA821B4C40A5BBEB6CC8CF4340F241CF66D5194C402EC6C03A8ECD4340F241CF66D5194C40
35102	47607	39.456046000000001	39.471829999999997	56.207312999999999	56.196891999999998	Первая	0103000020E610000001000000050000005EBC1FB75FBA4340096CCEC133194C405EBC1FB75FBA434090847D3B891A4C40C6A2E9EC64BC434090847D3B891A4C40C6A2E9EC64BC4340096CCEC133194C405EBC1FB75FBA4340096CCEC133194C40
35018	49550	39.275728000000001	39.292408999999999	56.136136	56.126964999999998	первая	0103000020E61000000100000005000000B64B1B0E4BA343404A5E9D6340104C40B64B1B0E4BA3434075E789E76C114C402D077AA86DA5434075E789E76C114C402D077AA86DA543404A5E9D6340104C40B64B1B0E4BA343404A5E9D6340104C40
34929	4762	39.522333000000003	39.549444000000001	56.426054000000001	56.410075999999997	Молодежная	0103000020E61000000100000005000000904FC8CEDBC24340EF6FD05E7D344C40904FC8CEDBC243403D2AFEEF88364C40E17D552E54C643403D2AFEEF88364C40E17D552E54C64340EF6FD05E7D344C40904FC8CEDBC24340EF6FD05E7D344C40
35158	49506	39.406315999999997	39.420876999999997	56.396244000000003	56.384031	Спортивная	0103000020E61000000100000005000000B7EBA52902B4434039D384ED27314C40B7EBA52902B443403D9E961FB8324C40BD512B4CDFB543403D9E961FB8324C40BD512B4CDFB5434039D384ED27314C40B7EBA52902B4434039D384ED27314C40
34851	54151	39.389445000000002	39.414409999999997	56.292966999999997	56.270516000000001	улица Школьная	0103000020E610000001000000050000009D4B7155D9B14340BA85AE44A0224C409D4B7155D9B1434053E751F17F254C4053910A630BB5434053E751F17F254C4053910A630BB54340BA85AE44A0224C409D4B7155D9B14340BA85AE44A0224C40
34552	4743	39.549129999999998	39.579214	56.405206	56.388148000000001	пл. Мира	0103000020E6100000010000000500000051A04FE449C6434000016BD5AE314C4051A04FE449C643404D124BCADD334C4053B131AF23CA43404D124BCADD334C4053B131AF23CA434000016BD5AE314C4051A04FE449C6434000016BD5AE314C40
35163	26761	41.633310999999999	41.657665000000001	56.038162	56.023862000000001	Советская	0103000020E610000001000000050000003999B85510D14440FFCEF6E80D034C403999B85510D1444098F90E7EE2044C40A75CE15D2ED4444098F90E7EE2044C40A75CE15D2ED44440FFCEF6E80D034C403999B85510D14440FFCEF6E80D034C40
35029	25847	41.471040000000002	41.496938	56.409104999999997	56.399586999999997	совхозная	0103000020E61000000100000005000000CE8DE9094BBC44401074B4AA25334C40CE8DE9094BBC4440A6D0798D5D344C40E01115AA9BBF4440A6D0798D5D344C40E01115AA9BBF44401074B4AA25334C40CE8DE9094BBC44401074B4AA25334C40
35149	26591	41.398724999999999	41.417051000000001	56.085504999999998	56.065927000000002	Дорожная	0103000020E610000001000000050000007E8CB96B09B344403276C24B70084C407E8CB96B09B344407E52EDD3F10A4C40CEE15AED61B544407E52EDD3F10A4C40CEE15AED61B544403276C24B70084C407E8CB96B09B344403276C24B70084C40
34996	54162	41.633265999999999	41.642913999999998	56.201014000000001	56.195630000000001	Старое Серково	0103000020E6100000010000000500000099D53BDC0ED14440E90E62670A194C4099D53BDC0ED14440E204A6D3BA194C40FD1186014BD24440E204A6D3BA194C40FD1186014BD24440E90E62670A194C4099D53BDC0ED14440E90E62670A194C40
35030	25787	41.647657000000002	41.658634999999997	56.412695999999997	56.399940999999998	Центральная	0103000020E610000001000000050000004303B16CE6D244402EAA454431334C404303B16CE6D244405298F738D3344C401F80D4264ED444405298F738D3344C401F80D4264ED444402EAA454431334C404303B16CE6D244402EAA454431334C40
34828	54152	41.227893000000002	41.268082999999997	56.404339	56.384410000000003	Центральная	0103000020E6100000010000000500000061FE0A992B9D4440B020CD5834314C4061FE0A992B9D4440A9BF5E61C1334C4089CE328B50A24440A9BF5E61C1334C4089CE328B50A24440B020CD5834314C4061FE0A992B9D4440B020CD5834314C40
35131	25676	41.828865	41.849544999999999	56.467424000000001	56.452528000000001	Подгородица	0103000020E6100000010000000500000047E6913F18EA44401C430070EC394C4047E6913F18EA4440C9AEB48CD43B4C407BBDFBE3BDEC4440C9AEB48CD43B4C407BBDFBE3BDEC44401C430070EC394C4047E6913F18EA44401C430070EC394C40
34486	10849	41.223643000000003	41.253746	56.373793999999997	56.355863999999997	Школьная	0103000020E610000001000000050000005B7D7555A09C444070E998F38C2D4C405B7D7555A09C444073B8567BD82F4C40D3BEB9BF7AA0444073B8567BD82F4C40D3BEB9BF7AA0444070E998F38C2D4C405B7D7555A09C444070E998F38C2D4C40
35082	26450	41.469566	41.491027000000003	56.227395000000001	56.210697000000003	Советская	0103000020E6100000010000000500000022A81ABD1ABC4440C32E8A1EF81A4C4022A81ABD1ABC4440102384471B1D4C40FC3905F9D9BE4440102384471B1D4C40FC3905F9D9BE4440C32E8A1EF81A4C4022A81ABD1ABC4440C32E8A1EF81A4C40
35016	54165	\N	\N	\N	\N	Школьная	\N
35178	26356	41.327165000000001	41.343460999999998	56.208599999999997	56.198765000000002	Школьная	0103000020E61000000100000005000000ABB2EF8AE0A94440734BAB2171194C40ABB2EF8AE0A9444009F9A067B31A4C40C939B187F6AB444009F9A067B31A4C40C939B187F6AB4440734BAB2171194C40ABB2EF8AE0A94440734BAB2171194C40
34701	26839	41.279347999999999	41.329186999999997	56.296754	56.239438	школьный переулок	0103000020E61000000100000005000000FC19DEACC1A34440B7B585E7A51E4C40FC19DEACC1A34440857AFA08FC254C4059A2B3CC22AA4440857AFA08FC254C4059A2B3CC22AA4440B7B585E7A51E4C40FC19DEACC1A34440B7B585E7A51E4C40
34571	26839	41.279347999999999	41.329186999999997	56.296754	56.239438	Первомайская	0103000020E61000000100000005000000FC19DEACC1A34440B7B585E7A51E4C40FC19DEACC1A34440857AFA08FC254C4059A2B3CC22AA4440857AFA08FC254C4059A2B3CC22AA4440B7B585E7A51E4C40FC19DEACC1A34440B7B585E7A51E4C40
34707	26839	41.279347999999999	41.329186999999997	56.296754	56.239438	Парковая	0103000020E61000000100000005000000FC19DEACC1A34440B7B585E7A51E4C40FC19DEACC1A34440857AFA08FC254C4059A2B3CC22AA4440857AFA08FC254C4059A2B3CC22AA4440B7B585E7A51E4C40FC19DEACC1A34440B7B585E7A51E4C40
34570	25537	41.14911	41.167265	56.417845	56.402380999999998	Школьная	0103000020E61000000100000005000000D7C056091693444011C4793881334C40D7C056091693444008E6E8F17B354C40FA6184F06895444008E6E8F17B354C40FA6184F06895444011C4793881334C40D7C056091693444011C4793881334C40
34981	26384	41.333641999999998	41.357537000000001	56.193711999999998	56.182932000000001	Танеева	0103000020E610000001000000050000003849F3C7B4AA444029B2D6506A174C403849F3C7B4AA4440DF6B088ECB184C40130EBDC5C3AD4440DF6B088ECB184C40130EBDC5C3AD444029B2D6506A174C403849F3C7B4AA444029B2D6506A174C40
35132	26099	41.593004000000001	41.643714000000003	56.341822000000001	56.310378	Школьная	0103000020E61000000100000005000000D732198EE7CB4440EEB25F77BA274C40D732198EE7CB4440D386C3D2C02B4C401AFD683865D24440D386C3D2C02B4C401AFD683865D24440EEB25F77BA274C40D732198EE7CB4440EEB25F77BA274C40
34973	9355	41.367482000000003	41.399299999999997	56.111598999999998	56.094450000000002	комсомольская	0103000020E6100000010000000500000031EF71A609AF4440B98D06F0160C4C4031EF71A609AF444016A243E0480E4C407AA52C431CB3444016A243E0480E4C407AA52C431CB34440B98D06F0160C4C4031EF71A609AF4440B98D06F0160C4C40
34867	26663	41.354519000000003	41.377946999999999	56.056528	56.041431000000003	маяковского	0103000020E61000000100000005000000C367EBE060AD444032056B9C4D054C40C367EBE060AD444076A73B4F3C074C40874F3A9160B0444076A73B4F3C074C40874F3A9160B0444032056B9C4D054C40C367EBE060AD444032056B9C4D054C40
35014	54164	41.495967999999998	41.517195000000001	56.455781000000002	56.437114000000001	Фабричный поселок	0103000020E6100000010000000500000067EE21E17BBF4440D74FFF59F3374C4067EE21E17BBF4440B0912408573A4C40CE531D7233C24440B0912408573A4C40CE531D7233C24440D74FFF59F3374C4067EE21E17BBF4440D74FFF59F3374C40
35153	25473	41.449902000000002	41.473258000000001	56.478769999999997	56.467995999999999	Центральная	0103000020E61000000100000005000000D733846396B944405454FD4AE73B4C40D733846396B944402827DA55483D4C400249D8B793BC44402827DA55483D4C400249D8B793BC44405454FD4AE73B4C40D733846396B944405454FD4AE73B4C40
35081	25473	41.449902000000002	41.473258000000001	56.478769999999997	56.467995999999999	Молодежная	0103000020E61000000100000005000000D733846396B944405454FD4AE73B4C40D733846396B944402827DA55483D4C400249D8B793BC44402827DA55483D4C400249D8B793BC44405454FD4AE73B4C40D733846396B944405454FD4AE73B4C40
34700	26491	41.455435999999999	41.489229999999999	56.194893999999998	56.168461000000001	Коммунистическая	0103000020E61000000100000005000000E5B512BA4BBA444063D34A2190154C40E5B512BA4BBA4440E3175E49F2184C406D1CB1169FBE4440E3175E49F2184C406D1CB1169FBE444063D34A2190154C40E5B512BA4BBA444063D34A2190154C40
34911	26491	41.455435999999999	41.489229999999999	56.194893999999998	56.168461000000001	Гагарина	0103000020E61000000100000005000000E5B512BA4BBA444063D34A2190154C40E5B512BA4BBA4440E3175E49F2184C406D1CB1169FBE4440E3175E49F2184C406D1CB1169FBE444063D34A2190154C40E5B512BA4BBA444063D34A2190154C40
34750	25996	41.456037999999999	41.484127999999998	56.389169000000003	56.377502	Фабричная	0103000020E61000000100000005000000DBDD03745FBA444059164CFC51304C40DBDD03745FBA4440FBCE2F4AD0314C40F88903E8F7BD4440FBCE2F4AD0314C40F88903E8F7BD444059164CFC51304C40DBDD03745FBA444059164CFC51304C40
35140	9619	41.455795000000002	41.473025	56.427596999999999	56.418202999999998	Школьная	0103000020E610000001000000050000001557957D57BA4440670B08AD87354C401557957D57BA4440116F9D7FBB364C405F984C158CBC4440116F9D7FBB364C405F984C158CBC4440670B08AD87354C401557957D57BA4440670B08AD87354C40
34912	25388	41.287505000000003	41.309638999999997	56.450612999999997	56.438955	Юбилейная	0103000020E61000000100000005000000DF37BEF6CCA4444035B56CAD2F384C40DF37BEF6CCA444408313D1AFAD394C4077483140A2A744408313D1AFAD394C4077483140A2A7444035B56CAD2F384C40DF37BEF6CCA4444035B56CAD2F384C40
35031	26739	41.524515999999998	41.542087000000002	56.100244000000004	56.083190000000002	советская	0103000020E61000000100000005000000471D1D5723C3444058AD4CF8A50A4C40471D1D5723C3444064CF9ECBD40C4C401B4B581B63C5444064CF9ECBD40C4C401B4B581B63C5444058AD4CF8A50A4C40471D1D5723C3444058AD4CF8A50A4C40
35079	47917	41.298572	41.315280999999999	56.005571000000003	56.000793999999999	Школьная	0103000020E610000001000000050000002BC0779B37A644403A048E041A004C402BC0779B37A644402C67EF8CB6004C406C06B8205BA844402C67EF8CB6004C406C06B8205BA844403A048E041A004C402BC0779B37A644403A048E041A004C40
35024	25416	41.318765999999997	41.336643000000002	56.450305	56.441369000000002	центральная	0103000020E61000000100000005000000D2890453CDA84440EF3B86C77E384C40D2890453CDA84440D61C2098A3394C40B3B6291E17AB4440D61C2098A3394C40B3B6291E17AB4440EF3B86C77E384C40D2890453CDA84440EF3B86C77E384C40
34948	3604	38.596898000000003	38.626156000000002	56.110348999999999	56.091656999999998	Сельская Новь	0103000020E610000001000000050000001F865627674C434088B9A46ABB0B4C401F865627674C4340BA1281EA1F0E4C40DB183BE125504340BA1281EA1F0E4C40DB183BE12550434088B9A46ABB0B4C401F865627674C434088B9A46ABB0B4C40
34884	3368	38.846369000000003	38.866329	56.119810000000001	56.105420000000002	Советская	0103000020E6100000010000000500000093ACC3D1556C4340132C0E677E0D4C4093ACC3D1556C4340ECDD1FEF550F4C40C74961DEE36E4340ECDD1FEF550F4C40C74961DEE36E4340132C0E677E0D4C4093ACC3D1556C4340132C0E677E0D4C40
35151	3683	38.791364999999999	38.810319	56.028132999999997	56.015374000000001	Советская	0103000020E610000001000000050000007A19C5724B654340B79A75C6F7014C407A19C5724B6543401C78B5DC99034C40E9297288B86743401C78B5DC99034C40E9297288B8674340B79A75C6F7014C407A19C5724B654340B79A75C6F7014C40
34823	54149	38.722436999999999	38.743080999999997	56.141804	56.132108000000002	Школьная	0103000020E61000000100000005000000CE35CCD0785C43401EC539EAE8104C40CE35CCD0785C434093382BA226124C40B5A338471D5F434093382BA226124C40B5A338471D5F43401EC539EAE8104C40CE35CCD0785C43401EC539EAE8104C40
34902	3358	39.043917	39.073264999999999	56.072484000000003	56.056317	школьная	0103000020E61000000100000005000000855E7F129F854340BB9A3C6535074C40855E7F129F854340DCBDDC2747094C4081785DBF60894340DCBDDC2747094C4081785DBF60894340BB9A3C6535074C40855E7F129F854340BB9A3C6535074C40
34992	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	пионерская	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34647	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	набережная	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34721	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	закодская	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34453	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	гастелло	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34493	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	вокзальная	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34988	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Шелковиков	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34492	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Чехова	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34953	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Фрунзе	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34535	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Серёгина	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34505	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Садовая	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34539	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Пушкина	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34775	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Октябрьская	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34534	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	Ленинградская	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34537	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	40 лет Октября	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34633	1947	38.834125	38.902945000000003	56.177064999999999	56.139040000000001	40 Лет Октября	0103000020E6100000010000000500000054E3A59BC46A4340FD6A0E10CC114C4054E3A59BC46A43401422E010AA164C401A8BA6B3937343401422E010AA164C401A8BA6B393734340FD6A0E10CC114C4054E3A59BC46A4340FD6A0E10CC114C40
34928	3170	38.972366999999998	38.997563999999997	56.243279000000001	56.234290000000001	Центральная	0103000020E61000000100000005000000D55A9885767C4340D2E3F736FD1D4C40D55A9885767C4340DC662AC4231F4C405ED5592DB07F4340DC662AC4231F4C405ED5592DB07F4340D2E3F736FD1D4C40D55A9885767C4340D2E3F736FD1D4C40
35103	3018	38.840826	38.860894999999999	56.223821999999998	56.213746	Центральная	0103000020E6100000010000000500000031D0B52FA06B43404ED367075C1B4C4031D0B52FA06B43400A100533A61C4C401C25AFCE316E43400A100533A61C4C401C25AFCE316E43404ED367075C1B4C4031D0B52FA06B43404ED367075C1B4C40
35124	3686	38.595675999999997	38.62771	56.006959999999999	55.994627000000001	Центральная	0103000020E610000001000000050000008C81751C3F4C4340FB5B02F04FFF4B408C81751C3F4C4340A930B610E4004C40A3AF20CD58504340A930B610E4004C40A3AF20CD58504340FB5B02F04FFF4B408C81751C3F4C4340FB5B02F04FFF4B40
34946	3127	38.971764999999998	39.005693999999998	56.226184000000003	56.216909999999999	Восточная	0103000020E61000000100000005000000DF32A7CB627C43407216F6B4C31B4C40DF32A7CB627C43407270E998F31C4C4047E4BB94BA8043407270E998F31C4C4047E4BB94BA8043407216F6B4C31B4C40DF32A7CB627C43407216F6B4C31B4C40
35123	2939	38.766103999999999	38.786110000000001	56.179651	56.167624000000004	Молодежная	0103000020E61000000100000005000000DAAA24B20F6243402A0307B474154C40DAAA24B20F624340CBD8D0CDFE164C407F87A2409F644340CBD8D0CDFE164C407F87A2409F6443402A0307B474154C40DAAA24B20F6243402A0307B474154C40
34945	3014	38.775339000000002	38.796674000000003	56.248941000000002	56.237287000000002	Школьный переулок	0103000020E610000001000000050000001C28F04E3E6343400B62A06B5F1E4C401C28F04E3E63434018D1764CDD1F4C4069C9E369F965434018D1764CDD1F4C4069C9E369F96543400B62A06B5F1E4C401C28F04E3E6343400B62A06B5F1E4C40
35017	3222	39.069924	39.089615000000002	56.277118000000002	56.265642	центральная	0103000020E610000001000000050000004E9A0645F3884340D6389B8E00224C404E9A0645F38843400491459A78234C40931D1B81788B43400491459A78234C40931D1B81788B4340D6389B8E00224C404E9A0645F3884340D6389B8E00224C40
34947	3550	38.617505000000001	38.644517	56.123823999999999	56.108342	Центральная	0103000020E61000000100000005000000E90E62670A4F434041649126DE0D4C40E90E62670A4F4340DE3AFF76D90F4C40A75B76887F524340DE3AFF76D90F4C40A75B76887F52434041649126DE0D4C40E90E62670A4F434041649126DE0D4C40
67622	24921	40.745542	40.762377000000001	56.419457999999999	56.407068000000002	Центральная	0103000020E61000000100000005000000B0E595EB6D5F4440C39FE1CD1A344C40B0E595EB6D5F4440D505BCCCB0354C407E1CCD9195614440D505BCCCB0354C407E1CCD9195614440C39FE1CD1A344C40B0E595EB6D5F4440C39FE1CD1A344C40
34964	24921	40.745542	40.762377000000001	56.419457999999999	56.407068000000002	Карла Либкнехта	0103000020E61000000100000005000000B0E595EB6D5F4440C39FE1CD1A344C40B0E595EB6D5F4440D505BCCCB0354C407E1CCD9195614440D505BCCCB0354C407E1CCD9195614440C39FE1CD1A344C40B0E595EB6D5F4440C39FE1CD1A344C40
35098	25258	40.896306000000003	40.923713999999997	56.194904000000001	56.179665999999997	Лесная	0103000020E61000000100000005000000B39AAE27BA724440001AA54BFF164C40B39AAE27BA72444007EE409DF2184C40BD6DA6423C76444007EE409DF2184C40BD6DA6423C764440001AA54BFF164C40B39AAE27BA724440001AA54BFF164C40
34699	9512	41.061551000000001	41.092497999999999	56.370049999999999	56.355080999999998	ильича	0103000020E610000001000000050000009F0436E7E08744402A37514B732D4C409F0436E7E087444041F163CC5D2F4C40037976F9D68B444041F163CC5D2F4C40037976F9D68B44402A37514B732D4C409F0436E7E08744402A37514B732D4C40
34569	9512	41.061551000000001	41.092497999999999	56.370049999999999	56.355080999999998	Фрунзе	0103000020E610000001000000050000009F0436E7E08744402A37514B732D4C409F0436E7E087444041F163CC5D2F4C40037976F9D68B444041F163CC5D2F4C40037976F9D68B44402A37514B732D4C409F0436E7E08744402A37514B732D4C40
34900	25102	40.769689	40.789434	56.299090999999997	56.278117999999999	Школьная	0103000020E61000000100000005000000A48B4D2B85624440E736E15E99234C40A48B4D2B8562444093C3279D48264C40DC2C5E2C0C65444093C3279D48264C40DC2C5E2C0C654440E736E15E99234C40A48B4D2B85624440E736E15E99234C40
74910	48744	40.998632999999998	41.007202999999997	56.459378000000001	56.453026000000001	Шоссейная	0103000020E610000001000000050000006ADAC534D37F44406D1E87C1FC394C406ADAC534D37F44403E40F7E5CC3A4C406FB72407EC8044403E40F7E5CC3A4C406FB72407EC8044406D1E87C1FC394C406ADAC534D37F44406D1E87C1FC394C40
9876	24896	40.876849	40.909205999999998	56.365721999999998	56.356048000000001	Садовая	0103000020E61000000100000005000000E14389963C70444032E719FB922D4C40E14389963C704440BFB67EFACF2E4C40DAA9B9DC60744440BFB67EFACF2E4C40DAA9B9DC6074444032E719FB922D4C40E14389963C70444032E719FB922D4C40
34795	8993	40.962251999999999	41.032895000000003	56.363498999999997	56.337924999999998	гоголя	0103000020E610000001000000050000005B41D3122B7B44401AC05B20412B4C405B41D3122B7B444079909E22872E4C40D99942E73584444079909E22872E4C40D99942E7358444401AC05B20412B4C405B41D3122B7B44401AC05B20412B4C40
34607	8993	40.962251999999999	41.032895000000003	56.363498999999997	56.337924999999998	Школьная,	0103000020E610000001000000050000005B41D3122B7B44401AC05B20412B4C405B41D3122B7B444079909E22872E4C40D99942E73584444079909E22872E4C40D99942E7358444401AC05B20412B4C405B41D3122B7B44401AC05B20412B4C40
34796	8993	40.962251999999999	41.032895000000003	56.363498999999997	56.337924999999998	Гоголя	0103000020E610000001000000050000005B41D3122B7B44401AC05B20412B4C405B41D3122B7B444079909E22872E4C40D99942E73584444079909E22872E4C40D99942E7358444401AC05B20412B4C405B41D3122B7B44401AC05B20412B4C40
35005	8993	40.962251999999999	41.032895000000003	56.363498999999997	56.337924999999998	Герцена	0103000020E610000001000000050000005B41D3122B7B44401AC05B20412B4C405B41D3122B7B444079909E22872E4C40D99942E73584444079909E22872E4C40D99942E7358444401AC05B20412B4C405B41D3122B7B44401AC05B20412B4C40
34896	24745	40.897402	40.911208999999999	56.447229999999998	56.439498	рабочая	0103000020E61000000100000005000000B8AE9811DE7244402654707841384C40B8AE9811DE72444021E527D53E394C4012691B7FA274444021E527D53E394C4012691B7FA27444402654707841384C40B8AE9811DE7244402654707841384C40
34753	24498	41.086938000000004	41.106997	56.418666000000002	56.409972000000003	Шоссейная	0103000020E61000000100000005000000CC63CDC8208B44404B2366F679344C40CC63CDC8208B44403CF9F4D896354C4093E2E313B28D44403CF9F4D896354C4093E2E313B28D44404B2366F679344C40CC63CDC8208B44404B2366F679344C40
67611	24498	41.086938000000004	41.106997	56.418666000000002	56.409972000000003	Карла Маркса	0103000020E61000000100000005000000CC63CDC8208B44404B2366F679344C40CC63CDC8208B44403CF9F4D896354C4093E2E313B28D44403CF9F4D896354C4093E2E313B28D44404B2366F679344C40CC63CDC8208B44404B2366F679344C40
34609	24659	40.943503999999997	40.972411999999998	56.477899999999998	56.466116	Морозова	0103000020E6100000010000000500000095D233BDC4784440381268B0A93B4C4095D233BDC47844401361C3D32B3D4C40751E15FF777C44401361C3D32B3D4C40751E15FF777C4440381268B0A93B4C4095D233BDC4784440381268B0A93B4C40
74905	48753	40.912674000000003	40.930109999999999	56.359000999999999	56.348227999999999	Центральная	0103000020E610000001000000050000006BF46A80D274444097C62FBC922C4C406BF46A80D27444409B1DA9BEF32D4C405ED72FD80D7744409B1DA9BEF32D4C405ED72FD80D77444097C62FBC922C4C406BF46A80D274444097C62FBC922C4C40
34873	25348	40.852207999999997	40.867102000000003	56.220377999999997	56.205950999999999	Новая	0103000020E61000000100000005000000DDB1D826156D44400CCA349A5C1A4C40DDB1D826156D44400261A758351C4C40EA25C632FD6E44400261A758351C4C40EA25C632FD6E44400CCA349A5C1A4C40DDB1D826156D44400CCA349A5C1A4C40
34989	9094	40.775016000000001	40.816409999999998	56.27364	56.255913	советская	0103000020E6100000010000000500000039F06AB93363444085CFD6C1C1204C4039F06AB9336344405070B1A206234C404D10751F806844405070B1A206234C404D10751F8068444085CFD6C1C1204C4039F06AB93363444085CFD6C1C1204C40
74907	9094	40.775016000000001	40.816409999999998	56.27364	56.255913	Советская	0103000020E6100000010000000500000039F06AB93363444085CFD6C1C1204C4039F06AB9336344405070B1A206234C404D10751F806844405070B1A206234C404D10751F8068444085CFD6C1C1204C4039F06AB93363444085CFD6C1C1204C40
34546	10803	40.193913999999999	40.236843999999998	55.688465999999998	55.661897000000003	Театральная	0103000020E61000000100000005000000471E882CD21844400729780AB9D44B40471E882CD2184440373465A71FD84B407D2079E7501E4440373465A71FD84B407D2079E7501E44400729780AB9D44B40471E882CD21844400729780AB9D44B40
34513	10803	40.193913999999999	40.236843999999998	55.688465999999998	55.661897000000003	Весёлкина	0103000020E61000000100000005000000471E882CD21844400729780AB9D44B40471E882CD2184440373465A71FD84B407D2079E7501E4440373465A71FD84B407D2079E7501E44400729780AB9D44B40471E882CD21844400729780AB9D44B40
34966	19682	40.735740999999997	40.757454000000003	55.342207000000002	55.326726999999998	Колхозная	0103000020E61000000100000005000000C5A9D6C22C5E44402FDCB930D2A94B40C5A9D6C22C5E44402CBB6070CDAB4B40B91CAF40F46044402CBB6070CDAB4B40B91CAF40F46044402FDCB930D2A94B40C5A9D6C22C5E44402FDCB930D2A94B40
67346	59043	40.972385000000003	40.986623000000002	55.757156000000002	55.747439	Центральная	0103000020E610000001000000050000007C0F971C777C4440A260C614ACDF4B407C0F971C777C44402FFCE07CEAE04B409F3D97A9497E44402FFCE07CEAE04B409F3D97A9497E4440A260C614ACDF4B407C0F971C777C4440A260C614ACDF4B40
35174	12818	41.106960999999998	41.121487000000002	55.358443000000001	55.336528999999999	центральная	0103000020E610000001000000050000004679E6E5B08D4440EA93DC6113AB4B404679E6E5B08D4440753DD175E1AD4B40D0F1D1E28C8F4440753DD175E1AD4B40D0F1D1E28C8F4440EA93DC6113AB4B404679E6E5B08D4440EA93DC6113AB4B40
35129	20951	40.141343999999997	40.173729000000002	55.629962999999996	55.584567999999997	Центральная	0103000020E610000001000000050000002FBE688F17124440E124CD1FD3CA4B402FBE688F171244405358A9A0A2D04B40F3AE7AC03C1644405358A9A0A2D04B40F3AE7AC03C164440E124CD1FD3CA4B402FBE688F17124440E124CD1FD3CA4B40
35004	21002	40.172587999999998	40.193778999999999	55.582630000000002	55.566434999999998	Новая	0103000020E610000001000000050000004DD7135D17164440A6272CF180C84B404DD7135D1716444091D5AD9E93CA4B4067D311C0CD18444091D5AD9E93CA4B4067D311C0CD184440A6272CF180C84B404DD7135D17164440A6272CF180C84B40
35189	32997	41.037027000000002	41.051329000000003	55.270805000000003	55.248041999999998	Центральная	0103000020E61000000100000005000000D508FD4CBD84444068041BD7BF9F4B40D508FD4CBD844440F14BFDBCA9A24B400F2BDCF291864440F14BFDBCA9A24B400F2BDCF29186444068041BD7BF9F4B40D508FD4CBD84444068041BD7BF9F4B40
35180	46578	40.365428999999999	40.392234999999999	55.441045000000003	55.429158999999999	Школьная	0103000020E610000001000000050000004701A260C62E44405CE49EAEEEB64B404701A260C62E44403C889D2974B84B405CACA8C1343244403C889D2974B84B405CACA8C1343244405CE49EAEEEB64B404701A260C62E44405CE49EAEEEB64B40
34661	49089	40.553517999999997	40.578968000000003	55.726325000000003	55.716802999999999	Октябрьская	0103000020E61000000100000005000000A8DF85ADD94644405C566133C0DB4B40A8DF85ADD946444034A2B437F8DC4B401CB7989F1B4A444034A2B437F8DC4B401CB7989F1B4A44405C566133C0DB4B40A8DF85ADD94644405C566133C0DB4B40
35003	47120	40.586979999999997	40.616444999999999	55.513458	55.500518999999997	Стрельцова	0103000020E61000000100000005000000FAB31F29224B44406803B00111C04B40FAB31F29224B44404EEFE2FDB8C14B40306475ABE74E44404EEFE2FDB8C14B40306475ABE74E44406803B00111C04B40FAB31F29224B44406803B00111C04B40
34997	54163	40.748767000000001	40.759798000000004	55.407733999999998	55.403252000000002	Владимирская	0103000020E610000001000000050000007AA9D898D75F4440F705F4C29DB34B407AA9D898D75F4440CFBBB1A030B44B407AC8940F41614440CFBBB1A030B44B407AC8940F41614440F705F4C29DB34B407AA9D898D75F4440F705F4C29DB34B40
34561	20657	40.349403000000002	40.432299999999998	55.509258000000003	55.466596000000003	строительная	0103000020E61000000100000005000000E90FCD3CB92C4440E338F06AB9BB4B40E90FCD3CB92C4440FA9CBB5D2FC14B40C8073D9B55374440FA9CBB5D2FC14B40C8073D9B55374440E338F06AB9BB4B40E90FCD3CB92C4440E338F06AB9BB4B40
34790	20640	40.474017000000003	40.488543	55.435039000000003	55.430900999999999	советская	0103000020E61000000100000005000000C05FCC96AC3C4440276893C327B74B40C05FCC96AC3C444006BEA25BAFB74B4049D8B793883E444006BEA25BAFB74B4049D8B793883E4440276893C327B74B40C05FCC96AC3C4440276893C327B74B40
34977	19448	41.004022999999997	41.048571000000003	55.336641	55.325626	школьная	0103000020E6100000010000000500000045B75ED383804440185DDE1CAEA94B4045B75ED38380444012BF620D17AB4B405B4414933786444012BF620D17AB4B405B44149337864440185DDE1CAEA94B4045B75ED383804440185DDE1CAEA94B40
35267	46632	40.899557999999999	40.918683000000001	55.413775000000001	55.396917999999999	Октябрьская	0103000020E61000000100000005000000766D6FB724734440CC988235CEB24B40766D6FB72473444082734694F6B44B40123290679775444082734694F6B44B401232906797754440CC988235CEB24B40766D6FB724734440CC988235CEB24B40
34746	20433	40.685633000000003	40.720075000000001	55.800646	55.781975000000003	Почтовая	0103000020E61000000100000005000000790778D2C257444012A5BDC117E44B40790778D2C25744402CD670917BE64B4067D5E76A2B5C44402CD670917BE64B4067D5E76A2B5C444012A5BDC117E44B40790778D2C257444012A5BDC117E44B40
34951	19521	41.026203000000002	41.057042000000003	55.248092999999997	55.229793999999998	центральная	0103000020E610000001000000050000004F07B29E5A8344409468C9E3699D4B404F07B29E5A834440EAAEEC82C19F4B40CD3FFA264D874440EAAEEC82C19F4B40CD3FFA264D8744409468C9E3699D4B404F07B29E5A8344409468C9E3699D4B40
35160	20117	41.062027999999998	41.090792	55.517383000000002	55.507559999999998	Дачная	0103000020E61000000100000005000000D8B79388F0874440FE60E0B9F7C04B40D8B79388F0874440D1402C9B39C24B40855E7F129F8B4440D1402C9B39C24B40855E7F129F8B4440FE60E0B9F7C04B40D8B79388F0874440FE60E0B9F7C04B40
34602	46877	41.080137999999998	41.119267999999998	55.539822999999998	55.519702000000002	Социалистическая	0103000020E610000001000000050000005B9544F6418A444039D55A9885C24B405B9544F6418A4440765089EB18C54B40CBBA7F2C448F4440765089EB18C54B40CBBA7F2C448F444039D55A9885C24B405B9544F6418A444039D55A9885C24B40
34562	46877	41.080137999999998	41.119267999999998	55.539822999999998	55.519702000000002	Гагарина	0103000020E610000001000000050000005B9544F6418A444039D55A9885C24B405B9544F6418A4440765089EB18C54B40CBBA7F2C448F4440765089EB18C54B40CBBA7F2C448F444039D55A9885C24B405B9544F6418A444039D55A9885C24B40
35159	19095	40.951174999999999	41.014201	55.530754999999999	55.500590000000003	Молодёжная	0103000020E61000000100000005000000EBE2361AC0794440325A475513C04B40EBE2361AC07944402098A3C7EFC34B4006499F56D18144402098A3C7EFC34B4006499F56D1814440325A475513C04B40EBE2361AC0794440325A475513C04B40
34564	19917	41.298769999999998	41.342112999999998	55.514767999999997	55.497377999999998	60 лет Октября	0103000020E61000000100000005000000518369183EA64440FCDF1115AABF4B40518369183EA644407F83F6EAE3C14B40AA44D95BCAAB44407F83F6EAE3C14B40AA44D95BCAAB4440FCDF1115AABF4B40518369183EA64440FCDF1115AABF4B40
34475	47657	40.463498000000001	40.591830999999999	55.667243999999997	55.609786999999997	Мира	0103000020E6100000010000000500000076E107E7533B444052431B800DCE4B4076E107E7533B4440E2395B4068D54B4026E1421EC14B4440E2395B4068D54B4026E1421EC14B444052431B800DCE4B4076E107E7533B444052431B800DCE4B40
34932	46472	40.944555000000001	40.990161999999998	55.512199000000003	55.503129999999999	Черёмушки	0103000020E61000000100000005000000FB22A12DE778444078D1579066C04B40FB22A12DE77844409F05A1BC8FC14B40F8DEDFA0BD7E44409F05A1BC8FC14B40F8DEDFA0BD7E444078D1579066C04B40FB22A12DE778444078D1579066C04B40
34663	19865	40.647114000000002	40.698999999999998	55.256262	55.231478000000003	Ленина	0103000020E610000001000000050000005264ADA1D45244402BDF3312A19D4B405264ADA1D4524440919A7631CDA04B40B6F3FDD478594440919A7631CDA04B40B6F3FDD4785944402BDF3312A19D4B405264ADA1D45244402BDF3312A19D4B40
34962	47928	40.724359999999997	40.741822999999997	55.709718000000002	55.699461999999997	центральная	0103000020E61000000100000005000000E94317D4B75C4440BA6587F887D94B40E94317D4B75C4440F7B0170AD8DA4B40D6355A0EF45E4440F7B0170AD8DA4B40D6355A0EF45E4440BA6587F887D94B40E94317D4B75C4440BA6587F887D94B40
35438	48824	41.219349999999999	41.238475000000001	55.587009999999999	55.578192000000001	Куйбышева	0103000020E6100000010000000500000055302AA9139C44408867093202CA4B4055302AA9139C44406536C82423CB4B40F1F44A59869E44406536C82423CB4B40F1F44A59869E44408867093202CA4B4055302AA9139C44408867093202CA4B40
34696	19789	40.645091999999998	40.678167999999999	55.706806999999998	55.693306999999997	Мира	0103000020E61000000100000005000000A374E95F925244403F8BA548BED84B40A374E95F92524440BCCADAA678DA4B40CC988235CE564440BCCADAA678DA4B40CC988235CE5644403F8BA548BED84B40A374E95F925244403F8BA548BED84B40
34899	689	42.498497	42.508459000000002	56.126553999999999	56.121471	центральная	0103000020E61000000100000005000000BA13ECBFCE3F4540CA349A5C8C0F4C40BA13ECBFCE3F4540C896E5EB32104C40AE2D3C2F15414540C896E5EB32104C40AE2D3C2F15414540CA349A5C8C0F4C40BA13ECBFCE3F4540CA349A5C8C0F4C40
13338	600	42.351810999999998	42.394174999999997	55.974004999999998	55.951366	Советская	0103000020E61000000100000005000000C0AF9124082D45405F43705CC6F94B40C0AF9124082D4540FB912232ACFC4B404DF38E5374324540FB912232ACFC4B404DF38E53743245405F43705CC6F94B40C0AF9124082D45405F43705CC6F94B40
35013	47025	42.830559000000001	42.842201000000003	56.167639000000001	56.161372999999998	Сельская Новь	0103000020E610000001000000050000000133DFC14F6A45408CBAD6DEA7144C400133DFC14F6A45405F44DB3175154C404AD40B3ECD6B45405F44DB3175154C404AD40B3ECD6B45408CBAD6DEA7144C400133DFC14F6A45408CBAD6DEA7144C40
34527	355	42.320073000000001	42.353931000000003	56.111272999999997	56.089537999999997	Советская	0103000020E6100000010000000500000093AAED26F8284540E7DF2EFB750B4C4093AAED26F8284540C2F693313E0E4C4032056B9C4D2D4540C2F693313E0E4C4032056B9C4D2D4540E7DF2EFB750B4C4093AAED26F8284540E7DF2EFB750B4C40
35464	46860	42.419490000000003	42.429065999999999	55.913021000000001	55.903120000000001	Шоссейная	0103000020E61000000100000005000000E17F2BD9B1354540882EA86F99F34B40E17F2BD9B1354540D6C743DFDDF44B40ABE97AA2EB364540D6C743DFDDF44B40ABE97AA2EB364540882EA86F99F34B40E17F2BD9B1354540882EA86F99F34B40
35090	421	42.412860000000002	42.433458999999999	56.177230999999999	56.168616	Колхозная	0103000020E61000000100000005000000CDE9B298D83445408ACA863595154C40CDE9B298D83445402F6B6281AF164C401494A2957B3745402F6B6281AF164C401494A2957B3745408ACA863595154C40CDE9B298D83445408ACA863595154C40
35025	4284	42.316434999999998	42.327987	55.875289000000002	55.866546	Кооперативная	0103000020E61000000100000005000000A6272CF180284540643DB5FAEAEE4B40A6272CF18028454037C64E7809F04B40AF415F7AFB29454037C64E7809F04B40AF415F7AFB294540643DB5FAEAEE4B40A6272CF180284540643DB5FAEAEE4B40
35089	308	42.283126000000003	42.305897999999999	56.012228999999998	56.000456999999997	Ленина	0103000020E61000000100000005000000DB5207793D244540F20698F90E004C40DB5207793D244540098849B890014C40B6F468AA27274540098849B890014C40B6F468AA27274540F20698F90E004C40DB5207793D244540F20698F90E004C40
34679	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	революции	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
74912	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Революции	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34583	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Парковая	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
35007	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Московская	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34484	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Мира	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34614	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Ленина	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34613	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Кутузова	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34893	32092	42.660508	42.735517000000002	56.214976999999998	56.188363000000003	Комсомольская	0103000020E61000000100000005000000895FB1868B54454063635E471C184C40895FB1868B5445403332C85D841B4C407653CA6B255E45403332C85D841B4C407653CA6B255E454063635E471C184C40895FB1868B54454063635E471C184C40
34936	181	42.831637000000001	42.859368000000003	56.187660999999999	56.170876	Железнодорожная	0103000020E610000001000000050000006092CA14736A4540EDD5C743DF154C406092CA14736A454009DE904605184C404E9D47C5FF6D454009DE904605184C404E9D47C5FF6D4540EDD5C743DF154C406092CA14736A4540EDD5C743DF154C40
34897	54158	42.145899	42.972968999999999	56.407178000000002	55.801298000000003	Полевая	0103000020E6100000010000000500000072C284D1AC124540D42CD0EE90E64B4072C284D1AC1245404AD3A0681E344C40CB82893F8A7C45404AD3A0681E344C40CB82893F8A7C4540D42CD0EE90E64B4072C284D1AC124540D42CD0EE90E64B40
34915	171	42.79813	42.825726000000003	56.164079999999998	56.149321	школьная	0103000020E610000001000000050000006EFAB31F2966454092CD55F31C134C406EFAB31F29664540BEF6CC9200154C407CBABA63B1694540BEF6CC9200154C407CBABA63B169454092CD55F31C134C406EFAB31F2966454092CD55F31C134C40
35033	533	42.567891000000003	42.595433999999997	55.970115999999997	55.962760000000003	Садовая	0103000020E61000000100000005000000AC58FCA6B0484540D0F23CB83BFB4B40AC58FCA6B0484540C5A9D6C22CFC4B4096766A2E374C4540C5A9D6C22CFC4B4096766A2E374C4540D0F23CB83BFB4B40AC58FCA6B0484540D0F23CB83BFB4B40
34880	18	42.626613999999996	42.637222999999999	56.178632999999998	56.172173999999998	Центральная	0103000020E610000001000000050000009D9B36E3345045405A9C31CC09164C409D9B36E334504540417E3672DD164C4027A1F48590514540417E3672DD164C4027A1F485905145405A9C31CC09164C409D9B36E3345045405A9C31CC09164C40
35187	54173	41.549992000000003	42.594616000000002	56.450741999999998	55.904497999999997	Шоссейная	0103000020E61000000100000005000000E4874A2366C6444011A62897C6F34B40E4874A2366C644408177F2E9B1394C40D4D688601C4C45408177F2E9B1394C40D4D688601C4C454011A62897C6F34B40E4874A2366C6444011A62897C6F34B40
35006	31148	41.742168999999997	41.766567000000002	56.099983000000002	56.087705	Советская	0103000020E61000000100000005000000718DCF64FFDE44400C59DDEA390B4C40718DCF64FFDE4440F793313ECC0C4C40AF9811DE1EE24440F793313ECC0C4C40AF9811DE1EE244400C59DDEA390B4C40718DCF64FFDE44400C59DDEA390B4C40
34967	31300	41.924168000000002	41.944316999999998	56.102156999999998	56.086530000000003	заречная	0103000020E610000001000000050000003F0114234BF64440BB0F406A130B4C403F0114234BF644405B07077B130D4C4046072461DFF844405B07077B130D4C4046072461DFF84440BB0F406A130B4C403F0114234BF64440BB0F406A130B4C40
34808	46519	42.053210999999997	42.082360999999999	56.246326000000003	56.236266000000001	Центральная	0103000020E61000000100000005000000CB64389ECF0645401094DBF63D1E4C40CB64389ECF064540C713419C871F4C40A1BB24CE8A0A4540C713419C871F4C40A1BB24CE8A0A45401094DBF63D1E4C40CB64389ECF0645401094DBF63D1E4C40
34943	54159	42.117288000000002	42.141255000000001	56.211328000000002	56.196432000000001	Главная	0103000020E610000001000000050000004C1B0E4B030F4540A6F10BAF24194C404C1B0E4B030F4540535DC0CB0C1B4C40C0B2D2A414124540535DC0CB0C1B4C40C0B2D2A414124540A6F10BAF24194C404C1B0E4B030F4540A6F10BAF24194C40
35164	46943	41.68403	41.728226999999997	56.139857999999997	56.123027	Совхозная	0103000020E61000000100000005000000CFBD874B8ED7444033C34659BF0F4C40CFBD874B8ED74440BF0AF0DDE6114C403788D68A36DD4440BF0AF0DDE6114C403788D68A36DD444033C34659BF0F4C40CFBD874B8ED7444033C34659BF0F4C40
34717	46943	41.68403	41.728226999999997	56.139857999999997	56.123027	Первомайская	0103000020E61000000100000005000000CFBD874B8ED7444033C34659BF0F4C40CFBD874B8ED74440BF0AF0DDE6114C403788D68A36DD4440BF0AF0DDE6114C403788D68A36DD444033C34659BF0F4C40CFBD874B8ED7444033C34659BF0F4C40
34879	31819	42.090338000000003	42.119748999999999	55.992800000000003	55.978240999999997	Муромская	0103000020E6100000010000000500000004CB1132900B45409C4D470037FD4B4004CB1132900B454002BC051214FF4B40465D6BEF530F454002BC051214FF4B40465D6BEF530F45409C4D470037FD4B4004CB1132900B45409C4D470037FD4B40
35190	54175	42.125875000000001	42.143914000000002	56.197949000000001	56.181043000000003	Центральная	0103000020E61000000100000005000000273108AC1C104540BA15C26A2C174C40273108AC1C10454051A3906456194C40E1B721C66B12454051A3906456194C40E1B721C66B124540BA15C26A2C174C40273108AC1C104540BA15C26A2C174C40
35116	31009	41.693722999999999	41.774552999999997	56.305933000000003	56.263272000000001	Советская	0103000020E61000000100000005000000D3BD4EEACBD84440ECF99AE5B2214C40D3BD4EEACBD8444033E202D028274C4064027E8D24E3444033E202D028274C4064027E8D24E34440ECF99AE5B2214C40D3BD4EEACBD84440ECF99AE5B2214C40
34927	47075	41.960028000000001	41.973188999999998	56.144742000000001	56.138288000000003	Советская	0103000020E61000000100000005000000459F8F32E2FA4440F2B6D26BB3114C40459F8F32E2FA4440C72DE6E786124C40D9E9077591FC4440C72DE6E786124C40D9E9077591FC4440F2B6D26BB3114C40459F8F32E2FA4440F2B6D26BB3114C40
34890	12752	42.244228	42.265096	56.234115000000003	56.223700999999998	центральная	0103000020E610000001000000050000003D62F4DC421F45408F8AFF3BA21C4C403D62F4DC421F45406440F67AF71D4C4074266DAAEE2145406440F67AF71D4C4074266DAAEE2145408F8AFF3BA21C4C403D62F4DC421F45408F8AFF3BA21C4C40
34983	54161	42.241525000000003	42.262104999999998	56.204478999999999	56.184916000000001	Новая	0103000020E610000001000000050000004D158C4AEA1E4540EA40D653AB174C404D158C4AEA1E454001DC2C5E2C1A4C401D8F19A88C21454001DC2C5E2C1A4C401D8F19A88C214540EA40D653AB174C404D158C4AEA1E4540EA40D653AB174C40
34914	31913	42.149447000000002	42.180295000000001	56.127516999999997	56.111634000000002	Центральная	0103000020E610000001000000050000001FBE4C1421134540938FDD054A0E4C401FBE4C14211345408E57207A52104C40F05014E8131745408E57207A52104C40F05014E813174540938FDD054A0E4C401FBE4C1421134540938FDD054A0E4C40
34824	54150	42.005932000000001	42.059579999999997	56.230511999999997	56.20872	Советская	0103000020E61000000100000005000000FCFF3861C2004540B4024356B71A4C40FCFF3861C2004540F3AACE6A811D4C4072BF4351A0074540F3AACE6A811D4C4072BF4351A0074540B4024356B71A4C40FCFF3861C2004540B4024356B71A4C40
34819	54139	42.109274999999997	42.130906000000003	56.078729000000003	56.06653	Советская	0103000020E610000001000000050000009CA223B9FC0D4540F819170E84084C409CA223B9FC0D4540971FB8CA130A4C40D36C1E87C1104540971FB8CA130A4C40D36C1E87C1104540F819170E84084C409CA223B9FC0D4540F819170E84084C40
34760	31447	41.969991	42.020080999999998	56.155056999999999	56.123649	Пушкинский переулок	0103000020E61000000100000005000000093543AA28FC44407097FDBAD30F4C40093543AA28FC4440080264E8D8134C40AF22A30392024540080264E8D8134C40AF22A303920245407097FDBAD30F4C40093543AA28FC44407097FDBAD30F4C40
34615	31447	41.969991	42.020080999999998	56.155056999999999	56.123649	Базарная	0103000020E61000000100000005000000093543AA28FC44407097FDBAD30F4C40093543AA28FC4440080264E8D8134C40AF22A30392024540080264E8D8134C40AF22A303920245407097FDBAD30F4C40093543AA28FC44407097FDBAD30F4C40
34639	31447	41.969991	42.020080999999998	56.155056999999999	56.123649	2 Пролетарская	0103000020E61000000100000005000000093543AA28FC44407097FDBAD30F4C40093543AA28FC4440080264E8D8134C40AF22A30392024540080264E8D8134C40AF22A303920245407097FDBAD30F4C40093543AA28FC44407097FDBAD30F4C40
34525	30700	41.908347999999997	41.953173999999997	56.389035	56.366829000000003	площадь Ленина	0103000020E6100000010000000500000089B14CBF44F44440B91CAF40F42E4C4089B14CBF44F44440EBFF1CE6CB314C40E1B20A9B01FA4440EBFF1CE6CB314C40E1B20A9B01FA4440B91CAF40F42E4C4089B14CBF44F44440B91CAF40F42E4C40
34850	30700	41.908347999999997	41.953173999999997	56.389035	56.366829000000003	Шоссейная	0103000020E6100000010000000500000089B14CBF44F44440B91CAF40F42E4C4089B14CBF44F44440EBFF1CE6CB314C40E1B20A9B01FA4440EBFF1CE6CB314C40E1B20A9B01FA4440B91CAF40F42E4C4089B14CBF44F44440B91CAF40F42E4C40
34612	30700	41.908347999999997	41.953173999999997	56.389035	56.366829000000003	Школьная	0103000020E6100000010000000500000089B14CBF44F44440B91CAF40F42E4C4089B14CBF44F44440EBFF1CE6CB314C40E1B20A9B01FA4440EBFF1CE6CB314C40E1B20A9B01FA4440B91CAF40F42E4C4089B14CBF44F44440B91CAF40F42E4C40
34876	30700	41.908347999999997	41.953173999999997	56.389035	56.366829000000003	Дзержинского	0103000020E6100000010000000500000089B14CBF44F44440B91CAF40F42E4C4089B14CBF44F44440EBFF1CE6CB314C40E1B20A9B01FA4440EBFF1CE6CB314C40E1B20A9B01FA4440B91CAF40F42E4C4089B14CBF44F44440B91CAF40F42E4C40
35112	47048	41.957621000000003	41.979889999999997	56.120994000000003	56.110976999999998	Заречная	0103000020E610000001000000050000003E7B2E5393FA4440D9CD8C7E340E4C403E7B2E5393FA444091813CBB7C0F4C40B6D617096DFD444091813CBB7C0F4C40B6D617096DFD4440D9CD8C7E340E4C403E7B2E5393FA4440D9CD8C7E340E4C40
34809	31575	42.029952999999999	42.054873000000001	56.196457000000002	56.172269999999997	советская	0103000020E6100000010000000500000063B5F97FD50345407C0A80F10C164C4063B5F97FD5034540FF08C38025194C407A37161406074540FF08C38025194C407A371614060745407C0A80F10C164C4063B5F97FD50345407C0A80F10C164C40
34877	31575	42.029952999999999	42.054873000000001	56.196457000000002	56.172269999999997	Центральная	0103000020E6100000010000000500000063B5F97FD50345407C0A80F10C164C4063B5F97FD5034540FF08C38025194C407A37161406074540FF08C38025194C407A371614060745407C0A80F10C164C4063B5F97FD50345407C0A80F10C164C40
35109	29990	41.982441000000001	42.001899000000002	56.242119000000002	56.233744000000002	Школьная	0103000020E61000000100000005000000F19F6EA0C0FD444070D1C952EB1D4C40F19F6EA0C0FD4440C05E61C1FD1E4C409372F7393E004540C05E61C1FD1E4C409372F7393E00454070D1C952EB1D4C40F19F6EA0C0FD444070D1C952EB1D4C40
35148	47011	41.813611999999999	41.838405999999999	56.121831999999998	56.112738999999998	Советская	0103000020E610000001000000050000000BD1217024E84440EBFD463B6E0E4C400BD1217024E844409ACDE330980F4C40956247E350EB44409ACDE330980F4C40956247E350EB4440EBFD463B6E0E4C400BD1217024E84440EBFD463B6E0E4C40
34954	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	южная	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34714	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	стахановская	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34805	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	сенькова	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
35084	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	мк-н Ефимьево	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34807	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	механизаторов	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34806	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	железнодорожная	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34627	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Южная	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34711	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Чапаевская	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34582	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Текстильная	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34483	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Свердлова	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34611	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Металлистов	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34502	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Комсомольская	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34804	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Киселева	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34524	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Ефимьево	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34713	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Владимирская	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34529	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	Благовещенская	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
34759	11032	42.086969000000003	42.221868999999998	56.264476999999999	56.219692999999999	1 шоссейная	0103000020E610000001000000050000000762D9CC210B45407F1475E61E1C4C400762D9CC210B4540A8C5E061DA214C40847F1134661C4540A8C5E061DA214C40847F1134661C45407F1475E61E1C4C400762D9CC210B45407F1475E61E1C4C40
35179	47333	42.137535999999997	42.166182999999997	56.165353000000003	56.151240999999999	Главная	0103000020E61000000100000005000000E60297C79A1145403C6876DD5B134C40E60297C79A114540D3A57F492A154C4059130B7C45154540D3A57F492A154C4059130B7C451545403C6876DD5B134C40E60297C79A1145403C6876DD5B134C40
35008	31173	41.814349	41.838611999999998	56.050545999999997	56.037433	Фабричный переулок	0103000020E61000000100000005000000E14389963CE844404565C39ACA044C40E14389963CE84440C878944A78064C403E0455A357EB4440C878944A78064C403E0455A357EB44404565C39ACA044C40E14389963CE844404565C39ACA044C40
35165	31703	41.856820999999997	41.878345000000003	56.174655000000001	56.166235	Центральная	0103000020E6100000010000000500000054C37E4FACED4440AC39403047154C4054C37E4FACED44409C8A54185B164C4075CDE49B6DF044409C8A54185B164C4075CDE49B6DF04440AC39403047154C4054C37E4FACED4440AC39403047154C40
34718	30649	41.901234000000002	41.925991000000003	56.394494999999999	56.382989999999999	Шибанова	0103000020E610000001000000050000008A05BEA25BF34440F758FAD005314C408A05BEA25BF34440BFB7E9CF7E324C40F7B182DF86F64440BFB7E9CF7E324C40F7B182DF86F64440F758FAD005314C408A05BEA25BF34440F758FAD005314C40
35217	46611	42.403455000000001	42.417307000000001	56.200257999999998	56.195185000000002	Школьная	0103000020E610000001000000050000002F34D769A4334540BBD573D2FB184C402F34D769A43345409561DC0DA2194C4029B2D6506A3545409561DC0DA2194C4029B2D6506A354540BBD573D2FB184C402F34D769A4334540BBD573D2FB184C40
35242	46091	38.369840000000003	38.379272	56.517578999999998	56.511287000000003	Школьная	0103000020E610000001000000050000005760C8EA562F43405BEF37DA71414C405760C8EA562F4340560C570740424C40EE2422FC8B304340560C570740424C40EE2422FC8B3043405BEF37DA71414C405760C8EA562F43405BEF37DA71414C40
34645	1608	38.5565	38.598236	56.389009999999999	56.359713999999997	шувалова	0103000020E61000000100000005000000AC1C5A643B474340E8F4BC1B0B2E4C40AC1C5A643B47434092E86514CB314C401AA54BFF924C434092E86514CB314C401AA54BFF924C4340E8F4BC1B0B2E4C40AC1C5A643B474340E8F4BC1B0B2E4C40
34646	1608	38.5565	38.598236	56.389009999999999	56.359713999999997	заречная	0103000020E61000000100000005000000AC1C5A643B474340E8F4BC1B0B2E4C40AC1C5A643B47434092E86514CB314C401AA54BFF924C434092E86514CB314C401AA54BFF924C4340E8F4BC1B0B2E4C40AC1C5A643B474340E8F4BC1B0B2E4C40
34682	1608	38.5565	38.598236	56.389009999999999	56.359713999999997	воронина	0103000020E61000000100000005000000AC1C5A643B474340E8F4BC1B0B2E4C40AC1C5A643B47434092E86514CB314C401AA54BFF924C434092E86514CB314C401AA54BFF924C4340E8F4BC1B0B2E4C40AC1C5A643B474340E8F4BC1B0B2E4C40
34593	1608	38.5565	38.598236	56.389009999999999	56.359713999999997	Фрунзе	0103000020E61000000100000005000000AC1C5A643B474340E8F4BC1B0B2E4C40AC1C5A643B47434092E86514CB314C401AA54BFF924C434092E86514CB314C401AA54BFF924C4340E8F4BC1B0B2E4C40AC1C5A643B474340E8F4BC1B0B2E4C40
34972	177	38.592531999999999	38.6081	56.422575000000002	56.411071999999997	Октябрьский квартал	0103000020E61000000100000005000000AFEAAC16D84B43409126DE019E344C40AFEAAC16D84B4340B98D06F016364C404B598638D64D4340B98D06F016364C404B598638D64D43409126DE019E344C40AFEAAC16D84B43409126DE019E344C40
35101	32443	38.833128000000002	38.848281999999998	56.467812000000002	56.455582	Владимирская	0103000020E61000000100000005000000E2B034F0A36A4340B952CF82503A4C40E2B034F0A36A434093567C43E13B4C408AE42B81946C434093567C43E13B4C408AE42B81946C4340B952CF82503A4C40E2B034F0A36A4340B952CF82503A4C40
35121	1026	38.806789000000002	38.822285000000001	56.383263999999997	56.372866999999999	Лесная	0103000020E61000000100000005000000E3E2A8DC44674340FA60191BBA2F4C40E3E2A8DC44674340F8DD74CB0E314C40E57E87A240694340F8DD74CB0E314C40E57E87A240694340FA60191BBA2F4C40E3E2A8DC44674340FA60191BBA2F4C40
35085	1288	38.670307999999999	38.686746999999997	56.272885000000002	56.263522000000002	Монастырская	0103000020E61000000100000005000000A31F0DA7CC55434065E3C116BB214C40A31F0DA7CC554340D4484BE5ED224C4024D06053E7574340D4484BE5ED224C4024D06053E757434065E3C116BB214C40A31F0DA7CC55434065E3C116BB214C40
34974	698	38.870336000000002	38.891320999999998	56.428902000000001	56.421753000000002	Первомайская	0103000020E610000001000000050000000744882B676F4340B5FE9600FC354C400744882B676F43403198BF42E6364C40779E78CE167243403198BF42E6364C40779E78CE16724340B5FE9600FC354C400744882B676F4340B5FE9600FC354C40
35061	409	38.336440000000003	38.354666999999999	56.502291	56.490076999999999	Кирпичная	0103000020E610000001000000050000007B884677102B4340CAC2D7D7BA3E4C407B884677102B43409E094D124B404C4037FC6EBA652D43409E094D124B404C4037FC6EBA652D4340CAC2D7D7BA3E4C407B884677102B4340CAC2D7D7BA3E4C40
34944	1300	38.483701000000003	38.503078000000002	56.303032000000002	56.288480999999997	Мусатова	0103000020E61000000100000005000000710514EAE93D4340394206F2EC244C40710514EAE93D43401CD2A8C0C9264C4026AB22DC644043401CD2A8C0C9264C4026AB22DC64404340394206F2EC244C40710514EAE93D4340394206F2EC244C40
34869	909	38.883899999999997	38.893998000000003	56.397523999999997	56.389871999999997	Весенняя	0103000020E610000001000000050000009A779CA22371434024D06053E7314C409A779CA22371434003B00111E2324C403F58C6866E72434003B00111E2324C403F58C6866E72434024D06053E7314C409A779CA22371434024D06053E7314C40
34905	340	38.529119999999999	38.547338000000003	56.568471000000002	56.551640999999996	Клубная	0103000020E610000001000000050000006BD44334BA434340FD101B2C9C464C406BD44334BA434340BADC60A8C3484C40D5EDEC2B0F464340BADC60A8C3484C40D5EDEC2B0F464340FD101B2C9C464C406BD44334BA434340FD101B2C9C464C40
34452	15	38.673749000000001	38.727072999999997	56.330140999999998	56.292777000000001	вокзальная	0103000020E610000001000000050000003A5B40683D564340B0027CB779254C403A5B40683D564340CC086F0F422A4C40FD6662BA105D4340CC086F0F422A4C40FD6662BA105D4340B0027CB779254C403A5B40683D564340B0027CB779254C40
34782	15	38.673749000000001	38.727072999999997	56.330140999999998	56.292777000000001	Торговая площадь	0103000020E610000001000000050000003A5B40683D564340B0027CB779254C403A5B40683D564340CC086F0F422A4C40FD6662BA105D4340CC086F0F422A4C40FD6662BA105D4340B0027CB779254C403A5B40683D564340B0027CB779254C40
34684	15	38.673749000000001	38.727072999999997	56.330140999999998	56.292777000000001	Победы	0103000020E610000001000000050000003A5B40683D564340B0027CB779254C403A5B40683D564340CC086F0F422A4C40FD6662BA105D4340CC086F0F422A4C40FD6662BA105D4340B0027CB779254C403A5B40683D564340B0027CB779254C40
35015	488	38.372731999999999	38.394840000000002	56.532851999999998	56.521715999999998	Кооперативная	0103000020E610000001000000050000001A16A3AEB52F434064E60297C7424C401A16A3AEB52F4340D9CD8C7E34444C408A93FB1D8A324340D9CD8C7E34444C408A93FB1D8A32434064E60297C7424C401A16A3AEB52F434064E60297C7424C40
34991	693	39.023327999999999	39.052847	56.492283999999998	56.478675000000003	Новлянская	0103000020E61000000100000005000000618A7269FC824340D734EF38453D4C40618A7269FC8243400A2C8029033F4C408A58C4B0C38643400A2C8029033F4C408A58C4B0C3864340D734EF38453D4C40618A7269FC824340D734EF38453D4C40
34975	1151	38.638390999999999	38.659779999999998	56.372951	56.364516000000002	Деревенская	0103000020E61000000100000005000000C687D9CBB6514340336FD575A82E4C40C687D9CBB65143405801BEDBBC2F4C400647C9AB735443405801BEDBBC2F4C400647C9AB73544340336FD575A82E4C40C687D9CBB6514340336FD575A82E4C40
34644	32289	38.820497000000003	38.863382999999999	56.517763000000002	56.491349999999997	Юго-Западный квартал	0103000020E61000000100000005000000AABBB20B06694340DE718A8EE43E4C40AABBB20B06694340180AD80E46424C4010768A55836E4340180AD80E46424C4010768A55836E4340DE718A8EE43E4C40AABBB20B06694340DE718A8EE43E4C40
34589	32289	38.820497000000003	38.863382999999999	56.517763000000002	56.491349999999997	Октябрьская	0103000020E61000000100000005000000AABBB20B06694340DE718A8EE43E4C40AABBB20B06694340180AD80E46424C4010768A55836E4340180AD80E46424C4010768A55836E4340DE718A8EE43E4C40AABBB20B06694340DE718A8EE43E4C40
34498	32289	38.820497000000003	38.863382999999999	56.517763000000002	56.491349999999997	Вокзальная	0103000020E61000000100000005000000AABBB20B06694340DE718A8EE43E4C40AABBB20B06694340180AD80E46424C4010768A55836E4340180AD80E46424C4010768A55836E4340DE718A8EE43E4C40AABBB20B06694340DE718A8EE43E4C40
34987	32488	38.692874000000003	38.713337000000003	56.456254000000001	56.444394000000003	Центральная	0103000020E61000000100000005000000D61F6118B0584340F24410E7E1384C40D61F6118B0584340A855F487663A4C406D0377A04E5B4340A855F487663A4C406D0377A04E5B4340F24410E7E1384C40D61F6118B0584340F24410E7E1384C40
35049	1091	38.967084	38.988670999999997	56.337831000000001	56.326931999999999	центральная	0103000020E61000000100000005000000103E9468C97B4340080264E8D8294C40103E9468C97B43409949D40B3E2B4C4076C075C58C7E43409949D40B3E2B4C4076C075C58C7E4340080264E8D8294C40103E9468C97B4340080264E8D8294C40
34882	969	38.986659000000003	39.022744000000003	56.413522999999998	56.394838999999997	советская	0103000020E61000000100000005000000ECA694D74A7E4340B91798158A324C40ECA694D74A7E434068925852EE344C4012178046E982434068925852EE344C4012178046E9824340B91798158A324C40ECA694D74A7E4340B91798158A324C40
35231	969	38.986659000000003	39.022744000000003	56.413522999999998	56.394838999999997	Хивинская	0103000020E61000000100000005000000ECA694D74A7E4340B91798158A324C40ECA694D74A7E434068925852EE344C4012178046E982434068925852EE344C4012178046E9824340B91798158A324C40ECA694D74A7E4340B91798158A324C40
34512	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	советская	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34868	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	парковая	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34509	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	ленина	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34643	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	кубасова	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34729	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Ческа-Липа	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34731	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Терешковой	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34587	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Стрелецкая набережная	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34601	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Перфильева	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34592	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Первомайская	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34781	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Маяковского	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34728	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Ленина	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34461	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Красный переулок	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34585	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Двориковское шоссе	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34496	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Геологов	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34590	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Гагарина	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34449	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Восстания 1905 года	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
74922	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Вокзальная	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
34510	9113	38.679363000000002	38.773560000000003	56.410997999999999	56.373764000000001	Базунова	0103000020E61000000100000005000000658EE55DF55643400936AE7FD72F4C40658EE55DF5564340575C1C959B344C4034BF9A0304634340575C1C959B344C4034BF9A03046343400936AE7FD72F4C40658EE55DF55643400936AE7FD72F4C40
24509	12390	34.304989999999997	34.362229999999997	53.225037	53.202513000000003	Чувиной	0103000020E61000000100000005000000B3CD8DE909274140E7012CF2EB994A40B3CD8DE909274140EAB12D03CE9C4A40A6D0798D5D2E4140EAB12D03CE9C4A40A6D0798D5D2E4140E7012CF2EB994A40B3CD8DE909274140E7012CF2EB994A40
24888	12390	34.296339000000003	34.400722999999999	53.282336999999998	53.215127000000003	Советская	0103000020E61000000100000005000000C2C3B46FEE25414049BE1248899B4A40C2C3B46FEE254140B2B96A9E23A44A40A4E029E44A334140B2B96A9E23A44A40A4E029E44A33414049BE1248899B4A40C2C3B46FEE25414049BE1248899B4A40
25057	10879	34.005122999999998	34.147469999999998	53.402729000000001	53.340634999999999	Школьная	0103000020E610000001000000050000008CBAD6DEA7004140BD6F7CED99AB4A408CBAD6DEA70041404D13B69F8CB34A401092054CE01241404D13B69F8CB34A401092054CE0124140BD6F7CED99AB4A408CBAD6DEA7004140BD6F7CED99AB4A40
24452	10879	34.005122999999998	34.147469999999998	53.402729000000001	53.340634999999999	Мейпариани	0103000020E610000001000000050000008CBAD6DEA7004140BD6F7CED99AB4A408CBAD6DEA70041404D13B69F8CB34A401092054CE01241404D13B69F8CB34A401092054CE0124140BD6F7CED99AB4A408CBAD6DEA7004140BD6F7CED99AB4A40
75041	10879	34.005122999999998	34.147469999999998	53.402729000000001	53.340634999999999	Ленина	0103000020E610000001000000050000008CBAD6DEA7004140BD6F7CED99AB4A408CBAD6DEA70041404D13B69F8CB34A401092054CE01241404D13B69F8CB34A401092054CE0124140BD6F7CED99AB4A408CBAD6DEA7004140BD6F7CED99AB4A40
24908	10879	34.005122999999998	34.147469999999998	53.402729000000001	53.340634999999999	Куйбышева	0103000020E610000001000000050000008CBAD6DEA7004140BD6F7CED99AB4A408CBAD6DEA70041404D13B69F8CB34A401092054CE01241404D13B69F8CB34A401092054CE0124140BD6F7CED99AB4A408CBAD6DEA7004140BD6F7CED99AB4A40
24829	10879	34.005122999999998	34.147469999999998	53.402729000000001	53.340634999999999	Горького	0103000020E610000001000000050000008CBAD6DEA7004140BD6F7CED99AB4A408CBAD6DEA70041404D13B69F8CB34A401092054CE01241404D13B69F8CB34A401092054CE0124140BD6F7CED99AB4A408CBAD6DEA7004140BD6F7CED99AB4A40
24579	10879	34.005122999999998	34.147469999999998	53.402729000000001	53.340634999999999	Брянская	0103000020E610000001000000050000008CBAD6DEA7004140BD6F7CED99AB4A408CBAD6DEA70041404D13B69F8CB34A401092054CE01241404D13B69F8CB34A401092054CE0124140BD6F7CED99AB4A408CBAD6DEA7004140BD6F7CED99AB4A40
24890	51076	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	Мира	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
24758	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Синицына	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
25154	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Садовая	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24550	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Садовая	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24602	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Рошаля	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24721	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Наримановская	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24792	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Мичурина	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24834	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Ломоносова	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
25064	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Ленина	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24931	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Красногвардейская	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24506	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Красная	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24818	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Коммунистическая	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24612	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Голодеда	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24656	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Воровского	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
25075	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Вокзальная	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24932	1088	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	114 квартал	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24707	51061	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	площадь Советская	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
24450	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	проспект Ленина	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24832	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Станционная	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24514	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Свердлова	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24652	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Пушкина	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24679	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Площадь Свободы	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24608	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Первомайская	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24533	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Октябрьская	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24499	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Мира	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24412	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Калинина	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
25074	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Декабристов	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24921	22579	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Ворошилова	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24681	51057	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Советская	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
1106	1655	34.272067	34.314017999999997	53.30986	53.304340000000003	улица ХХII Съезда КПСС	0103000020E6100000010000000500000011A96917D3224140AD6EF59CF4A64A4011A96917D3224140562B137EA9A74A407B2DE8BD31284140562B137EA9A74A407B2DE8BD31284140AD6EF59CF4A64A4011A96917D3224140AD6EF59CF4A64A40
992	1655	34.320962000000002	34.350659999999998	53.244838999999999	53.217154999999998	улица Фрунзе	0103000020E610000001000000050000001FA1664815294140D9942BBCCB9B4A401FA166481529414086E464E2569F4A40F701486DE22C414086E464E2569F4A40F701486DE22C4140D9942BBCCB9B4A401FA1664815294140D9942BBCCB9B4A40
1764	1655	34.444310000000002	34.462572000000002	53.253093	53.248891	улица Фосфоритная	0103000020E6100000010000000500000094A46B26DF38414066A208A9DB9F4A4094A46B26DF3841405BECF65965A04A40CD052E8F353B41405BECF65965A04A40CD052E8F353B414066A208A9DB9F4A4094A46B26DF38414066A208A9DB9F4A40
1997	1655	34.339737	34.370199	53.259793999999999	53.238421000000002	улица Фокина	0103000020E61000000100000005000000DE1E84807C2B4140FED64E94849E4A40DE1E84807C2B414038D906EE40A14A4086014BAE622F414038D906EE40A14A4086014BAE622F4140FED64E94849E4A40DE1E84807C2B4140FED64E94849E4A40
1403	1655	34.284230000000001	34.285756999999997	53.289895000000001	53.283068999999998	улица Федюнинского	0103000020E6100000010000000500000063450DA66124414076C1E09A3BA44A4063450DA661244140102384471BA54A4031CD74AF93244140102384471BA54A4031CD74AF9324414076C1E09A3BA44A4063450DA66124414076C1E09A3BA44A40
1071	1655	34.276288999999998	34.317351000000002	53.316074	53.286088999999997	улица Ульянова	0103000020E610000001000000050000004D9F1D705D234140675F79909EA44A404D9F1D705D234140D68EE21C75A84A402C2D23F59E284140D68EE21C75A84A402C2D23F59E284140675F79909EA44A404D9F1D705D234140675F79909EA44A40
1754	1655	34.417161999999998	34.459096000000002	53.261156999999997	53.250926999999997	улица Тельмана	0103000020E6100000010000000500000025917D906535414079573D601EA04A4025917D90653541408C0FB3976DA14A40BADC60A8C33A41408C0FB3976DA14A40BADC60A8C33A414079573D601EA04A4025917D906535414079573D601EA04A40
1543	1655	34.393194999999999	34.413739999999997	53.277420999999997	53.262374999999999	улица Пушкина	0103000020E61000000100000005000000B1F9B83654324140DD24068195A14A40B1F9B836543241409F1C058882A34A400586AC6EF53441409F1C058882A34A400586AC6EF5344140DD24068195A14A40B1F9B83654324140DD24068195A14A40
2474	1655	34.383754000000003	34.388120000000001	53.216287000000001	53.21537	улица Полесская	0103000020E61000000100000005000000C7DADFD91E3141400F45813E919B4A40C7DADFD91E31414065C6DB4AAF9B4A40367689EAAD31414065C6DB4AAF9B4A40367689EAAD3141400F45813E919B4A40C7DADFD91E3141400F45813E919B4A40
1040	1655	34.217134999999999	34.227124000000003	53.329714000000003	53.325799000000004	улица Отрадная	0103000020E6100000010000000500000092E86514CB1B4140E60819C8B3A94A4092E86514CB1B414045847F1134AA4A4080113466121D414045847F1134AA4A4080113466121D4140E60819C8B3A94A4092E86514CB1B4140E60819C8B3A94A40
1326	1655	34.284275000000001	34.302573000000002	53.307088999999998	53.303409000000002	улица Орловская	0103000020E6100000010000000500000003098A1F63244140F2272A1BD6A64A4003098A1F632441400DFB3DB14EA74A4089D349B6BA2641400DFB3DB14EA74A4089D349B6BA264140F2272A1BD6A64A4003098A1F63244140F2272A1BD6A64A40
2442	1655	34.403508000000002	34.412607999999999	53.230913000000001	53.212651999999999	улица Олега Кошевого	0103000020E6100000010000000500000052D66F26A6334140E9B6442E389B4A4052D66F26A6334140529CA38E8E9D4A40B308C556D0344140529CA38E8E9D4A40B308C556D0344140E9B6442E389B4A4052D66F26A6334140E9B6442E389B4A40
3400	1655	34.310344000000001	34.310991000000001	53.304808000000001	53.303818	улица Молодежная	0103000020E610000001000000050000004241295AB9274140D3F71A82E3A64A404241295AB927414093C7D3F203A74A40D82C978DCE27414093C7D3F203A74A40D82C978DCE274140D3F71A82E3A64A404241295AB9274140D3F71A82E3A64A40
1203	1655	34.300642000000003	34.302115000000001	53.30039	53.29813	улица Ленинградская	0103000020E61000000100000005000000EBE6E26F7B2641406EFAB31F29A64A40EBE6E26F7B264140D105F52D73A64A40C6504EB4AB264140D105F52D73A64A40C6504EB4AB2641406EFAB31F29A64A40EBE6E26F7B2641406EFAB31F29A64A40
1063	1655	34.278219999999997	34.298772999999997	53.318758000000003	53.315868999999999	улица Кромская	0103000020E61000000100000005000000EB8B84B69C234140FD6838656EA84A40EB8B84B69C23414050ABE80FCDA84A40C2F693313E26414050ABE80FCDA84A40C2F693313E264140FD6838656EA84A40EB8B84B69C234140FD6838656EA84A40
24692	1655	34.393194999999999	34.395252999999997	53.280101999999999	53.277420999999997	улица Королева	0103000020E61000000100000005000000B1F9B836543241409F1C058882A34A40B1F9B83654324140A8C5E061DAA34A40AC527AA697324140A8C5E061DAA34A40AC527AA6973241409F1C058882A34A40B1F9B836543241409F1C058882A34A40
919	1655	34.281095000000001	34.314072000000003	53.323512999999998	53.315207999999998	улица Коммунистическая	0103000020E61000000100000005000000D908C4EBFA23414002B859BC58A84A40D908C4EBFA234140596ABDDF68A94A406F4BE48233284140596ABDDF68A94A406F4BE4823328414002B859BC58A84A40D908C4EBFA23414002B859BC58A84A40
931	1655	34.274608999999998	34.292225000000002	53.332498999999999	53.306055999999998	улица Клинцовская	0103000020E61000000100000005000000F8174163262341404E5FCFD72CA74A40F817416326234140F279C5538FAA4A406C09F9A067254140F279C5538FAA4A406C09F9A0672541404E5FCFD72CA74A40F8174163262341404E5FCFD72CA74A40
2385	1655	34.319676999999999	34.354855000000001	53.225037	53.219526999999999	улица Карачижская	0103000020E6100000010000000500000046240A2DEB28414064CBF275199C4A4046240A2DEB284140EAB12D03CE9C4A403AE97DE36B2D4140EAB12D03CE9C4A403AE97DE36B2D414064CBF275199C4A4046240A2DEB28414064CBF275199C4A40
1122	1655	34.301530999999997	34.311960999999997	53.305565999999999	53.302914000000001	улица Институтская	0103000020E6100000010000000500000076DD5B919826414012C0CDE2C5A64A4076DD5B9198264140806264C91CA74A4050508A56EE274140806264C91CA74A4050508A56EE27414012C0CDE2C5A64A4076DD5B919826414012C0CDE2C5A64A40
1893	1655	34.356670000000001	34.373108999999999	53.268154000000003	53.255656999999999	улица Дуки	0103000020E610000001000000050000006FBBD05CA72D41402AFF5A5EB9A04A406FBBD05CA72D41405325CADE52A24A40F06B2409C22F41405325CADE52A24A40F06B2409C22F41402AFF5A5EB9A04A406FBBD05CA72D41402AFF5A5EB9A04A40
2577	1655	34.414881000000001	34.420765000000003	53.214447999999997	53.195759000000002	улица Дзержинского	0103000020E61000000100000005000000AB5D13D21A354140E77283A10E994A40AB5D13D21A354140A7583508739B4A409626A5A0DB354140A7583508739B4A409626A5A0DB354140E77283A10E994A40AB5D13D21A354140E77283A10E994A40
1440	1655	34.232180999999997	34.289889000000002	53.303930999999999	53.288758999999999	улица Делегатская	0103000020E6100000010000000500000054E0641BB81D41407CB60E0EF6A44A4054E0641BB81D4140CB9E0436E7A64A402E3C2F151B254140CB9E0436E7A64A402E3C2F151B2541407CB60E0EF6A44A4054E0641BB81D41407CB60E0EF6A44A40
1026	1655	34.247596000000001	34.312832	53.330488000000003	53.313943999999999	улица Вокзальная	0103000020E610000001000000050000006A4FC939B11F4140416326512FA84A406A4FC939B11F414038DC476E4DAA4A40369204E10A28414038DC476E4DAA4A40369204E10A284140416326512FA84A406A4FC939B11F4140416326512FA84A40
1396	1655	34.270656000000002	34.356670000000001	53.292009999999998	53.268154000000003	улица Бежицкая	0103000020E61000000100000005000000AC3B16DBA42241405325CADE52A24A40AC3B16DBA42241406F0D6C9560A54A406FBBD05CA72D41406F0D6C9560A54A406FBBD05CA72D41405325CADE52A24A40AC3B16DBA42241405325CADE52A24A40
1511	1655	34.395252999999997	34.402448	53.280101999999999	53.277932999999997	улица Афанасьева	0103000020E61000000100000005000000AC527AA69732414055BDFC4E93A34A40AC527AA697324140A8C5E061DAA34A40992B836A83334140A8C5E061DAA34A40992B836A8333414055BDFC4E93A34A40AC527AA69732414055BDFC4E93A34A40
25275	1655	34.374358000000001	34.377079999999999	53.252172000000002	53.249090000000002	Ямская	0103000020E610000001000000050000007C7F83F6EA2F41405DE15D2EE29F4A407C7F83F6EA2F4140C47B0E2C47A04A40E3FC4D2844304140C47B0E2C47A04A40E3FC4D28443041405DE15D2EE29F4A407C7F83F6EA2F41405DE15D2EE29F4A40
25280	1655	34.209831000000001	34.246375	53.338768999999999	53.328809999999997	Шоссейная	0103000020E61000000100000005000000EF5701BEDB1A4140834C327216AA4A40EF5701BEDB1A414006F357C85CAB4A40A8C64B37891F414006F357C85CAB4A40A8C64B37891F4140834C327216AA4A40EF5701BEDB1A4140834C327216AA4A40
25235	1655	34.437463999999999	34.470711000000001	53.261733999999997	53.250114000000004	Чернышевского	0103000020E61000000100000005000000B39602D2FE374140C9224DBC03A04A40B39602D2FE3741402920ED7F80A14A40096F0F42403C41402920ED7F80A14A40096F0F42403C4140C9224DBC03A04A40B39602D2FE374140C9224DBC03A04A40
25171	1655	34.428911999999997	34.432702999999997	53.211390000000002	53.211013000000001	Челюскинцев	0103000020E61000000100000005000000546EA296E6364140F3035779029B4A40546EA296E6364140C959D8D30E9B4A40C7F0D8CF62374140C959D8D30E9B4A40C7F0D8CF62374140F3035779029B4A40546EA296E6364140F3035779029B4A40
25195	1655	34.493977000000001	34.509132000000001	53.238722000000003	53.236055	Центральная	0103000020E61000000100000005000000F4FC69A33A3F41405587DC0C379E4A40F4FC69A33A3F4140F96A47718E9E4A406DACC43C2B414140F96A47718E9E4A406DACC43C2B4141405587DC0C379E4A40F4FC69A33A3F41405587DC0C379E4A40
25254	1655	34.272067	34.314017999999997	53.30986	53.304340000000003	ХХII Съезда КПСС	0103000020E6100000010000000500000011A96917D3224140AD6EF59CF4A64A4011A96917D3224140562B137EA9A74A407B2DE8BD31284140562B137EA9A74A407B2DE8BD31284140AD6EF59CF4A64A4011A96917D3224140AD6EF59CF4A64A40
25288	1655	34.339737	34.370199	53.259793999999999	53.238421000000002	Фокина	0103000020E61000000100000005000000DE1E84807C2B4140FED64E94849E4A40DE1E84807C2B414038D906EE40A14A4086014BAE622F414038D906EE40A14A4086014BAE622F4140FED64E94849E4A40DE1E84807C2B4140FED64E94849E4A40
25192	1655	34.284230000000001	34.285756999999997	53.289895000000001	53.283068999999998	Федюнинского	0103000020E6100000010000000500000063450DA66124414076C1E09A3BA44A4063450DA661244140102384471BA54A4031CD74AF93244140102384471BA54A4031CD74AF9324414076C1E09A3BA44A4063450DA66124414076C1E09A3BA44A40
2567	1655	34.393258000000003	34.394004000000002	53.205700999999998	53.204340999999999	Трофименко проезд	0103000020E61000000100000005000000F871344756324140B01D8CD8279A4A40F87134475632414093E00D69549A4A40213F1BB96E32414093E00D69549A4A40213F1BB96E324140B01D8CD8279A4A40F871344756324140B01D8CD8279A4A40
25218	1655	34.417161999999998	34.459096000000002	53.261156999999997	53.250926999999997	Тельмана	0103000020E6100000010000000500000025917D906535414079573D601EA04A4025917D90653541408C0FB3976DA14A40BADC60A8C33A41408C0FB3976DA14A40BADC60A8C33A414079573D601EA04A4025917D906535414079573D601EA04A40
25241	1655	34.424222999999998	34.438713	53.269230999999998	53.255167	Суворова	0103000020E61000000100000005000000029B73F04C3641405C02F04FA9A04A40029B73F04C364140E108522976A24A403FAA61BF27384140E108522976A24A403FAA61BF273841405C02F04FA9A04A40029B73F04C3641405C02F04FA9A04A40
24433	1655	34.318438	34.353282999999998	53.254159999999999	53.219748000000003	Станке Димитрова проспект	0103000020E61000000100000005000000DEE68D93C228414043AED4B3209C4A40DEE68D93C2284140C6F99B5088A04A40CB9D9960382D4140C6F99B5088A04A40CB9D9960382D414043AED4B3209C4A40DEE68D93C228414043AED4B3209C4A40
25260	1655	34.321733999999999	34.350803999999997	53.230460000000001	53.225037	Спартаковская	0103000020E61000000100000005000000710168942E294140EAB12D03CE9C4A40710168942E294140A18499B67F9D4A402AA73D25E72C4140A18499B67F9D4A402AA73D25E72C4140EAB12D03CE9C4A40710168942E294140EAB12D03CE9C4A40
25194	1655	34.340518000000003	34.356121999999999	53.260215000000002	53.244999999999997	Советская	0103000020E6100000010000000500000084D90418962B41408FC2F5285C9F4A4084D90418962B4140DE76A1B94EA14A406CB1DB67952D4140DE76A1B94EA14A406CB1DB67952D41408FC2F5285C9F4A4084D90418962B41408FC2F5285C9F4A40
948	1655	34.279532000000003	34.307290000000002	53.335425000000001	53.329670999999998	Северный переулок	0103000020E61000000100000005000000BE175FB4C723414045B8C9A832AA4A40BE175FB4C723414062A1D634EFAA4A40A5315A475527414062A1D634EFAA4A40A5315A475527414045B8C9A832AA4A40BE175FB4C723414045B8C9A832AA4A40
25255	1655	34.393194999999999	34.413739999999997	53.277420999999997	53.262374999999999	Пушкина	0103000020E61000000100000005000000B1F9B83654324140DD24068195A14A40B1F9B836543241409F1C058882A34A400586AC6EF53441409F1C058882A34A400586AC6EF5344140DD24068195A14A40B1F9B83654324140DD24068195A14A40
25269	1655	34.400103000000001	34.42991	53.282212999999999	53.270324000000002	Профсоюзов	0103000020E6100000010000000500000008043A933633414076A911FA99A24A4008043A9336334140C6C03A8E1FA44A40971C774A07374140C6C03A8E1FA44A40971C774A0737414076A911FA99A24A4008043A933633414076A911FA99A24A40
25271	1655	34.3125	34.313361999999998	53.299615000000003	53.298313	Протасова	0103000020E6100000010000000500000000000000002841405F7CD11E2FA64A4000000000002841400E32C9C859A64A4092E7FA3E1C2841400E32C9C859A64A4092E7FA3E1C2841405F7CD11E2FA64A4000000000002841405F7CD11E2FA64A40
24968	1655	34.307890999999998	34.325893999999998	53.356841000000003	53.310662000000001	Почтовая	0103000020E61000000100000005000000CADDE7F868274140130EBDC5C3A74A40CADDE7F8682741409C6F44F7ACAD4A4037FB03E5B62941409C6F44F7ACAD4A4037FB03E5B6294140130EBDC5C3A74A40CADDE7F868274140130EBDC5C3A74A40
25251	1655	34.422201999999999	34.430681999999997	53.201304999999998	53.200091	Победы	0103000020E61000000100000005000000242713B70A364140AA9CF6949C994A40242713B70A364140B9C2BB5CC4994A40E97C789620374140B9C2BB5CC4994A40E97C789620374140AA9CF6949C994A40242713B70A364140AA9CF6949C994A40
25287	1655	34.359777999999999	34.361440000000002	53.257958000000002	53.257407999999998	Петрова	0103000020E61000000100000005000000FFE89B340D2E414048DDCEBEF2A04A40FFE89B340D2E4140ECDE8AC404A14A40AEBB79AA432E4140ECDE8AC404A14A40AEBB79AA432E414048DDCEBEF2A04A40FFE89B340D2E414048DDCEBEF2A04A40
25237	1655	34.329909000000001	34.348027999999999	53.241836999999997	53.238027000000002	Пересвета	0103000020E61000000100000005000000FAD346753A2A4140524832AB779E4A40FAD346753A2A41403BFBCA83F49E4A40D00B772E8C2C41403BFBCA83F49E4A40D00B772E8C2C4140524832AB779E4A40FAD346753A2A4140524832AB779E4A40
2162	1655	34.352834000000001	34.354595000000003	53.234949999999998	53.233494999999998	Партизан площадь	0103000020E610000001000000050000005C751DAA292D4140C763062AE39D4A405C751DAA292D4140FC1873D7129E4A409E29745E632D4140FC1873D7129E4A409E29745E632D4140C763062AE39D4A405C751DAA292D4140C763062AE39D4A40
2180	1655	34.330052999999999	34.348979999999997	53.246023999999998	53.223726999999997	Осоавиахима переулок	0103000020E610000001000000050000002D793C2D3F2A4140B81D1A16A39C4A402D793C2D3F2A4140FB03E5B67D9F4A40A27A6B60AB2C4140FB03E5B67D9F4A40A27A6B60AB2C4140B81D1A16A39C4A402D793C2D3F2A4140B81D1A16A39C4A40
25230	1655	34.311179000000003	34.315472999999997	53.363810999999998	53.358341000000003	Орджоникидзе	0103000020E61000000100000005000000DB19A6B6D427414071E82D1EDEAD4A40DB19A6B6D42741406876DD5B91AE4A40B0E2546B612841406876DD5B91AE4A40B0E2546B6128414071E82D1EDEAD4A40DB19A6B6D427414071E82D1EDEAD4A40
25183	1655	34.386009000000001	34.40314	53.212133999999999	53.211784000000002	Олега Кошевого	0103000020E61000000100000005000000187B2FBE6831414075E8F4BC1B9B4A40187B2FBE68314140512FF834279B4A40CFDA6D179A334140512FF834279B4A40CFDA6D179A33414075E8F4BC1B9B4A40187B2FBE6831414075E8F4BC1B9B4A40
25265	1655	34.358871000000001	34.373953	53.254466999999998	53.241923	Октябрьская	0103000020E61000000100000005000000CD3D247CEF2D41403A933655F79E4A40CD3D247CEF2D4140A374E95F92A04A40DC9E20B1DD2F4140A374E95F92A04A40DC9E20B1DD2F41403A933655F79E4A40CD3D247CEF2D41403A933655F79E4A40
25261	1655	34.296303000000002	34.305708000000003	53.331778999999997	53.318128999999999	Окружная	0103000020E61000000100000005000000755AB741ED25414060747973B8A84A40755AB741ED254140F23FF9BB77AA4A401310937021274140F23FF9BB77AA4A40131093702127414060747973B8A84A40755AB741ED25414060747973B8A84A40
25189	1655	34.447102999999998	34.455663999999999	53.208461999999997	53.207129999999999	Новозыбковская	0103000020E61000000100000005000000C478CDAB3A3941409F02603C839A4A40C478CDAB3A394140B83A00E2AE9A4A4076FBAC32533A4140B83A00E2AE9A4A4076FBAC32533A41409F02603C839A4A40C478CDAB3A3941409F02603C839A4A40
25253	1655	34.252510000000001	34.326774	53.334069999999997	53.316386000000001	Ново-Советская	0103000020E61000000100000005000000DCF4673F52204140C57421567FA84A40DCF4673F52204140904946CEC2AA4A407097FDBAD3294140904946CEC2AA4A407097FDBAD3294140C57421567FA84A40DCF4673F52204140C57421567FA84A40
25157	1655	34.417630000000003	34.420000999999999	53.264038999999997	53.262962000000002	Никитина	0103000020E610000001000000050000000CEA5BE6743541409E0B23BDA8A14A400CEA5BE6743541402CEFAA07CCA14A40C6A4BF97C23541402CEFAA07CCA14A40C6A4BF97C23541409E0B23BDA8A14A400CEA5BE6743541409E0B23BDA8A14A40
25268	1655	34.273961999999997	34.313048000000002	53.326217999999997	53.316240999999998	Нахимова	0103000020E61000000100000005000000622CD32F11234140C153C8957AA84A40622CD32F11234140EAAEEC82C1A94A40030AF5F411284140EAAEEC82C1A94A40030AF5F411284140C153C8957AA84A40622CD32F11234140C153C8957AA84A40
2445	1655	34.362644000000003	34.46904	53.224626999999998	53.207296999999997	Московский проспект	0103000020E610000001000000050000009A0B5C1E6B2E41408AC745B5889A4A409A0B5C1E6B2E41403866D993C09C4A400742B280093C41403866D993C09C4A400742B280093C41408AC745B5889A4A409A0B5C1E6B2E41408AC745B5889A4A40
24690	1655	34.183151000000002	34.569310000000002	53.382426000000002	53.179409999999997	Московский м/район	0103000020E61000000100000005000000679DF17D71174140A54929E8F6964A40679DF17D71174140EF91CD55F3B04A4094A46B26DF484140EF91CD55F3B04A4094A46B26DF484140A54929E8F6964A40679DF17D71174140A54929E8F6964A40
25149	1655	34.183151000000002	34.569310000000002	53.382426000000002	53.179409999999997	Московский м/р-н	0103000020E61000000100000005000000679DF17D71174140A54929E8F6964A40679DF17D71174140EF91CD55F3B04A4094A46B26DF484140EF91CD55F3B04A4094A46B26DF484140A54929E8F6964A40679DF17D71174140A54929E8F6964A40
25243	1655	34.279423999999999	34.298926000000002	53.335849000000003	53.304586999999998	Молодой Гвардии	0103000020E61000000100000005000000D7DB662AC4234140B4E4F1B4FCA64A40D7DB662AC423414079B29B19FDAA4A4049F608354326414079B29B19FDAA4A4049F6083543264140B4E4F1B4FCA64A40D7DB662AC4234140B4E4F1B4FCA64A40
25226	1655	34.412571999999997	34.438578	53.272649999999999	53.257063000000002	Мичурина	0103000020E61000000100000005000000669FC728CF3441407E01BD70E7A04A40669FC728CF34414090A0F831E6A24A405F5FEB522338414090A0F831E6A24A405F5FEB52233841407E01BD70E7A04A40669FC728CF3441407E01BD70E7A04A40
25236	1655	34.423108999999997	34.429523000000003	53.213082999999997	53.192144999999996	Менжинского	0103000020E6100000010000000500000056D28A6F28364140828B153598984A4056D28A6F28364140B22AC24D469B4A409EF0129CFA364140B22AC24D469B4A409EF0129CFA364140828B153598984A4056D28A6F28364140828B153598984A40
25234	1655	34.275049000000003	34.300049000000001	53.314455000000002	53.311107999999997	Медведева	0103000020E6100000010000000500000015E63DCE3423414011C30E63D2A74A4015E63DCE342341402788BA0F40A84A4048197101682641402788BA0F40A84A40481971016826414011C30E63D2A74A4015E63DCE3423414011C30E63D2A74A40
25262	1655	34.274016000000003	34.275686999999998	53.334370999999997	53.328955999999998	Марии Ульяновой	0103000020E61000000100000005000000564ACFF41223414057E9EE3A1BAA4A40564ACFF4122341408BDD3EABCCAA4A4057772CB6492341408BDD3EABCCAA4A4057772CB64923414057E9EE3A1BAA4A40564ACFF41223414057E9EE3A1BAA4A40
25219	1655	34.308520000000001	34.311295999999999	53.312641999999997	53.308736000000003	Майской Стачки	0103000020E61000000100000005000000BA1457957D274140878C47A984A74A40BA1457957D27414092AD2EA704A84A4014B01D8CD827414092AD2EA704A84A4014B01D8CD8274140878C47A984A74A40BA1457957D274140878C47A984A74A40
754	1655	34.313003000000002	34.315725	53.360055000000003	53.359710999999997	Магистральный переулок	0103000020E610000001000000050000006346787B10284140778192020BAE4A406346787B1028414072E1404816AE4A40CAC342AD6928414072E1404816AE4A40CAC342AD69284140778192020BAE4A406346787B10284140778192020BAE4A40
25249	1655	34.355196999999997	34.370899000000001	53.243529000000002	53.230454999999999	Луначарского	0103000020E6100000010000000500000093516518772D41408F19A88C7F9D4A4093516518772D4140555051F52B9F4A403F8F519E792F4140555051F52B9F4A403F8F519E792F41408F19A88C7F9D4A4093516518772D41408F19A88C7F9D4A40
25201	1655	34.263092	34.287984999999999	53.337117999999997	53.298296000000001	Литейная	0103000020E610000001000000050000006CEBA7FFAC214140894336902EA64A406CEBA7FFAC2141404B72C0AE26AB4A40895E46B1DC2441404B72C0AE26AB4A40895E46B1DC244140894336902EA64A406CEBA7FFAC214140894336902EA64A40
964	1655	34.354531999999999	34.375939000000002	53.255656999999999	53.235585999999998	Ленина проспект	0103000020E6100000010000000500000057B1F84D612D41409EB29AAE279E4A4057B1F84D612D41402AFF5A5EB9A04A403E25E7C41E3041402AFF5A5EB9A04A403E25E7C41E3041409EB29AAE279E4A4057B1F84D612D41409EB29AAE279E4A40
25167	1655	34.281140000000001	34.300615000000001	53.309274000000002	53.308031	Куйбышева	0103000020E6100000010000000500000079CC4065FC234140BC934F8F6DA74A4079CC4065FC23414066C0594A96A74A40F1D7648D7A26414066C0594A96A74A40F1D7648D7A264140BC934F8F6DA74A4079CC4065FC234140BC934F8F6DA74A40
25216	1655	34.411782000000002	34.416533999999999	53.212372000000002	53.203198	Красных Партизан	0103000020E610000001000000050000006E8AC745B53441406A4E5E64029A4A406E8AC745B5344140064B75012F9B4A4006D671FC50354140064B75012F9B4A4006D671FC503541406A4E5E64029A4A406E8AC745B53441406A4E5E64029A4A40
25258	1655	34.327466000000001	34.364063000000002	53.255679000000001	53.230848000000002	Красноармейская	0103000020E61000000100000005000000A646E867EA2941406B2C616D8C9D4A40A646E867EA29414012A3E716BAA04A408257CB9D992E414012A3E716BAA04A408257CB9D992E41406B2C616D8C9D4A40A646E867EA2941406B2C616D8C9D4A40
25240	1655	34.329495999999999	34.342188999999998	53.266047999999998	53.250765999999999	Костычева	0103000020E61000000100000005000000D714C8EC2C2A41407079AC1919A04A40D714C8EC2C2A4140469561DC0DA24A40850662D9CC2B4140469561DC0DA24A40850662D9CC2B41407079AC1919A04A40D714C8EC2C2A41407079AC1919A04A40
25272	1655	34.282262000000003	34.315024000000001	53.310822999999999	53.307062000000002	Комсомольская	0103000020E61000000100000005000000A87345292124414014ECBFCE4DA74A40A8734529212441401CEC4D0CC9A74A4041BAD8B4522841401CEC4D0CC9A74A4041BAD8B45228414014ECBFCE4DA74A40A87345292124414014ECBFCE4DA74A40
24951	1655	34.183151000000002	34.569310000000002	53.382426000000002	53.179409999999997	Клубная	0103000020E61000000100000005000000679DF17D71174140A54929E8F6964A40679DF17D71174140EF91CD55F3B04A4094A46B26DF484140EF91CD55F3B04A4094A46B26DF484140A54929E8F6964A40679DF17D71174140A54929E8F6964A40
25250	1655	34.274608999999998	34.292225000000002	53.332498999999999	53.306055999999998	Клинцовская	0103000020E61000000100000005000000F8174163262341404E5FCFD72CA74A40F817416326234140F279C5538FAA4A406C09F9A067254140F279C5538FAA4A406C09F9A0672541404E5FCFD72CA74A40F8174163262341404E5FCFD72CA74A40
25187	1655	34.272461999999997	34.313811000000001	53.328164999999998	53.317611999999997	Кирова	0103000020E610000001000000050000008DB3E908E022414098689082A7A84A408DB3E908E02241408E588B4F01AA4A40021077F52A2841408E588B4F01AA4A40021077F52A28414098689082A7A84A408DB3E908E022414098689082A7A84A40
25273	1655	34.391821	34.403643000000002	53.216583	53.215127000000003	Киевская	0103000020E610000001000000050000006971C6302732414049BE1248899B4A406971C630273241404EEFE2FDB89B4A403221E692AA3341404EEFE2FDB89B4A403221E692AA33414049BE1248899B4A406971C6302732414049BE1248899B4A40
25233	1655	34.362644000000003	34.380996000000003	53.270243000000001	53.224606000000001	Калинина	0103000020E610000001000000050000009A0B5C1E6B2E4140213EB0E3BF9C4A409A0B5C1E6B2E4140897C975297A24A4013F4177AC4304140897C975297A24A4013F4177AC4304140213EB0E3BF9C4A409A0B5C1E6B2E4140213EB0E3BF9C4A40
25165	1655	34.301530999999997	34.311960999999997	53.305565999999999	53.302914000000001	Институтская	0103000020E6100000010000000500000076DD5B919826414012C0CDE2C5A64A4076DD5B9198264140806264C91CA74A4050508A56EE274140806264C91CA74A4050508A56EE27414012C0CDE2C5A64A4076DD5B919826414012C0CDE2C5A64A40
24672	1655	34.183151000000002	34.569310000000002	53.382426000000002	53.179409999999997	Инженерная	0103000020E61000000100000005000000679DF17D71174140A54929E8F6964A40679DF17D71174140EF91CD55F3B04A4094A46B26DF484140EF91CD55F3B04A4094A46B26DF484140A54929E8F6964A40679DF17D71174140A54929E8F6964A40
25220	1655	34.209426999999998	34.218913000000001	53.311711000000003	53.298952999999997	Ильича	0103000020E610000001000000050000001FF30181CE1A41404205871744A64A401FF30181CE1A4140D8666325E6A74A40AAD55757051C4140D8666325E6A74A40AAD55757051C41404205871744A64A401FF30181CE1A41404205871744A64A40
25190	1655	34.438560000000003	34.447184	53.261781999999997	53.256400999999997	Есенина	0103000020E61000000100000005000000B9AAECBB22384140B2D47ABFD1A04A40B9AAECBB223841403A57941282A14A40B1A547533D3941403A57941282A14A40B1A547533D394140B2D47ABFD1A04A40B9AAECBB22384140B2D47ABFD1A04A40
24879	1655	34.183151000000002	34.569310000000002	53.382426000000002	53.179409999999997	Ермакова	0103000020E61000000100000005000000679DF17D71174140A54929E8F6964A40679DF17D71174140EF91CD55F3B04A4094A46B26DF484140EF91CD55F3B04A4094A46B26DF484140A54929E8F6964A40679DF17D71174140A54929E8F6964A40
25274	1655	34.356670000000001	34.373108999999999	53.268154000000003	53.255656999999999	Дуки	0103000020E610000001000000050000006FBBD05CA72D41402AFF5A5EB9A04A406FBBD05CA72D41405325CADE52A24A40F06B2409C22F41405325CADE52A24A40F06B2409C22F41402AFF5A5EB9A04A406FBBD05CA72D41402AFF5A5EB9A04A40
25231	1655	34.399662999999997	34.424537999999998	53.272725999999999	53.255592999999998	Димитрова	0103000020E61000000100000005000000EB353D2828334140130B7C45B7A04A40EB353D28283341406B6281AFE8A24A4062F4DC42573641406B6281AFE8A24A4062F4DC4257364140130B7C45B7A04A40EB353D2828334140130B7C45B7A04A40
25224	1655	34.414881000000001	34.420765000000003	53.214447999999997	53.195759000000002	Дзержинского	0103000020E61000000100000005000000AB5D13D21A354140E77283A10E994A40AB5D13D21A354140A7583508739B4A409626A5A0DB354140A7583508739B4A409626A5A0DB354140E77283A10E994A40AB5D13D21A354140E77283A10E994A40
25259	1655	34.355151999999997	34.375705000000004	53.249381	53.240819000000002	Горького	0103000020E61000000100000005000000F38DE89E752D4140B2A03028D39E4A40F38DE89E752D4140349F73B7EB9F4A40CBF8F71917304140349F73B7EB9F4A40CBF8F71917304140B2A03028D39E4A40F38DE89E752D4140B2A03028D39E4A40
1295	1655	34.286969999999997	34.307980999999998	53.332526000000001	53.327869	Гончарова переулок	0103000020E610000001000000050000007077D66EBB244140A52F849CF7A94A407077D66EBB244140EC88433690AA4A400A65E1EB6B274140EC88433690AA4A400A65E1EB6B274140A52F849CF7A94A407077D66EBB244140A52F849CF7A94A40
917	1655	34.357838000000001	34.370961999999999	53.244936000000003	53.240161000000001	Гагарина бульвар	0103000020E610000001000000050000000EA2B5A2CD2D414028637C98BD9E4A400EA2B5A2CD2D414079CE16105A9F4A408507CDAE7B2F414079CE16105A9F4A408507CDAE7B2F414028637C98BD9E4A400EA2B5A2CD2D414028637C98BD9E4A40
25217	1655	34.299959000000001	34.327123999999998	53.303198999999999	53.296461000000001	Брянской Пролетарской Дивизии	0103000020E610000001000000050000000892770E652641400DC51D6FF2A54A400892770E6526414007978E39CFA64A404CDE0033DF29414007978E39CFA64A404CDE0033DF2941400DC51D6FF2A54A400892770E652641400DC51D6FF2A54A40
25284	1655	34.309418999999998	34.326692999999999	53.260398000000002	53.255974999999999	Брянского Фронта	0103000020E6100000010000000500000069E1B20A9B274140FBCBEEC9C3A04A4069E1B20A9B274140CFF8BEB854A14A40836A8313D1294140CFF8BEB854A14A40836A8313D1294140FBCBEEC9C3A04A4069E1B20A9B274140FBCBEEC9C3A04A40
25277	1655	34.277385000000002	34.303615000000001	53.317618000000003	53.314320000000002	Болховская	0103000020E6100000010000000500000053B3075A81234140473D44A33BA84A4053B3075A812341407B4FE5B4A7A84A409BC937DBDC2641407B4FE5B4A7A84A409BC937DBDC264140473D44A33BA84A4053B3075A81234140473D44A33BA84A40
25222	1655	34.4178	34.438668	53.209735000000002	53.204945000000002	Богдана Хмельницкого	0103000020E6100000010000000500000068226C787A354140473D44A33B9A4A4068226C787A354140CDE9B298D89A4A409FE6E44526384140CDE9B298D89A4A409FE6E44526384140473D44A33B9A4A4068226C787A354140473D44A33B9A4A40
25270	1655	34.270656000000002	34.356670000000001	53.292009999999998	53.268154000000003	Бежицкая	0103000020E61000000100000005000000AC3B16DBA42241405325CADE52A24A40AC3B16DBA42241406F0D6C9560A54A406FBBD05CA72D41406F0D6C9560A54A406FBBD05CA72D41405325CADE52A24A40AC3B16DBA42241405325CADE52A24A40
25276	1655	34.395252999999997	34.402448	53.280101999999999	53.277932999999997	Афанасьева	0103000020E61000000100000005000000AC527AA69732414055BDFC4E93A34A40AC527AA697324140A8C5E061DAA34A40992B836A83334140A8C5E061DAA34A40992B836A8333414055BDFC4E93A34A40AC527AA69732414055BDFC4E93A34A40
24696	1655	34.183151000000002	34.569310000000002	53.382426000000002	53.179409999999997	Академика Королева	0103000020E61000000100000005000000679DF17D71174140A54929E8F6964A40679DF17D71174140EF91CD55F3B04A4094A46B26DF484140EF91CD55F3B04A4094A46B26DF484140A54929E8F6964A40679DF17D71174140A54929E8F6964A40
25176	1655	34.322453000000003	34.327672	53.265675999999999	53.255954000000003	Авиационная	0103000020E61000000100000005000000A1BFD02346294140E4A3C519C3A04A40A1BFD0234629414082AAD1AB01A24A404FE8F527F129414082AAD1AB01A24A404FE8F527F1294140E4A3C519C3A04A40A1BFD02346294140E4A3C519C3A04A40
25256	1655	34.408808000000001	34.429783999999998	53.274017999999998	53.266720999999997	Абашева	0103000020E61000000100000005000000ED2B0FD2533441400514EAE923A24A40ED2B0FD253344140F641960513A34A400A2C802903374140F641960513A34A400A2C8029033741400514EAE923A24A40ED2B0FD2533441400514EAE923A24A40
1165	1655	34.295161999999998	34.303373000000001	53.30209	53.297172000000003	50 Лет Октября бульвар	0103000020E61000000100000005000000CF8250DEC7254140BAA46ABB09A64A40CF8250DEC72541406D3997E2AAA64A40A5BE2CEDD42641406D3997E2AAA64A40A5BE2CEDD4264140BAA46ABB09A64A40CF8250DEC7254140BAA46ABB09A64A40
25223	1655	34.421509999999998	34.443275999999997	53.265908000000003	53.256400999999997	2-я Мичурина	0103000020E61000000100000005000000EE77280AF4354140B2D47ABFD1A04A40EE77280AF435414055DFF94509A24A40048D9944BD38414055DFF94509A24A40048D9944BD384140B2D47ABFD1A04A40EE77280AF4354140B2D47ABFD1A04A40
25252	1655	34.334014000000003	34.339216	53.252948000000004	53.251251000000003	2-й Станке Димитрова проезд	0103000020E61000000100000005000000FD3383F8C02A41402D0B26FE28A04A40FD3383F8C02A414058CB9D9960A04A40D5230D6E6B2B414058CB9D9960A04A40D5230D6E6B2B41402D0B26FE28A04A40FD3383F8C02A41402D0B26FE28A04A40
25266	1655	34.332577000000001	34.340204	53.252226	53.249904000000001	1-й Станке Димитрова проезд	0103000020E610000001000000050000006E3315E2912A4140DE91B1DAFC9F4A406E3315E2912A4140B7990AF148A04A40F4FBFECD8B2B4140B7990AF148A04A40F4FBFECD8B2B4140DE91B1DAFC9F4A406E3315E2912A4140DE91B1DAFC9F4A40
25211	1655	34.417161999999998	34.459096000000002	53.261156999999997	53.250926999999997	 Тельмана	0103000020E6100000010000000500000025917D906535414079573D601EA04A4025917D90653541408C0FB3976DA14A40BADC60A8C33A41408C0FB3976DA14A40BADC60A8C33A414079573D601EA04A4025917D906535414079573D601EA04A40
25247	1655	34.362644000000003	34.380996000000003	53.270243000000001	53.224606000000001	 Калинина	0103000020E610000001000000050000009A0B5C1E6B2E4140213EB0E3BF9C4A409A0B5C1E6B2E4140897C975297A24A4013F4177AC4304140897C975297A24A4013F4177AC4304140213EB0E3BF9C4A409A0B5C1E6B2E4140213EB0E3BF9C4A40
25200	51135	32.758710999999998	32.790233000000001	52.898775000000001	52.880633000000003	Советская	0103000020E61000000100000005000000C70E2A711D614040A2630795B8704A40C70E2A711D61404030BB270F0B734A40289CDD5A2665404030BB270F0B734A40289CDD5A26654040A2630795B8704A40C70E2A711D614040A2630795B8704A40
24591	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Чапаева	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24576	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Совхозная	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24578	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Попова	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24574	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Первомайская	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24991	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Октябрьская	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24910	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Луначарского	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24402	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Ленина	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24671	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Комсомольская	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24427	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Иванова	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
24406	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Гомельская	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
25067	16687	32.628742000000003	32.727215999999999	52.869892999999998	52.821508999999999	Володарского	0103000020E6100000010000000500000092CF2B9E7A504040512FF83427694A4092CF2B9E7A504040790261A7586F4A406090F469155D4040790261A7586F4A406090F469155D4040512FF83427694A4092CF2B9E7A504040512FF83427694A40
25015	21250	33.114739999999998	33.146566999999997	52.869844000000001	52.852038	Новоселов	0103000020E6100000010000000500000082C5E1CCAF8E40408179C8940F6D4A4082C5E1CCAF8E4040984F560C576F4A401FD61BB5C2924040984F560C576F4A401FD61BB5C29240408179C8940F6D4A4082C5E1CCAF8E40408179C8940F6D4A40
25079	21095	32.507936999999998	32.551245000000002	52.823974	52.806901000000003	Садовая	0103000020E61000000100000005000000D4B66114044140400B0E2F8848674A40D4B66114044140408D60E3FA77694A40B18A37328F4640408D60E3FA77694A40B18A37328F4640400B0E2F8848674A40D4B66114044140400B0E2F8848674A40
24581	19911	32.608198000000002	32.626612999999999	52.825350999999998	52.811528000000003	Октябрьская	0103000020E610000001000000050000000EBF9B6ED94D4040E7E44526E0674A400EBF9B6ED94D4040465C001AA5694A40CD1FD3DA34504040465C001AA5694A40CD1FD3DA34504040E7E44526E0674A400EBF9B6ED94D4040E7E44526E0674A40
25285	51153	32.760741000000003	32.781438000000001	52.782347999999999	52.762005000000002	Октябрьская	0103000020E61000000100000005000000F9DC09F65F614040BA313D6189614A40F9DC09F65F614040A60BB1FA23644A4003ED0E2906644040A60BB1FA23644A4003ED0E2906644040BA313D6189614A40F9DC09F65F614040BA313D6189614A40
24410	20209	32.866320000000002	32.885480999999999	52.761187999999997	52.741073999999998	Центральная	0103000020E6100000010000000500000074EFE192E36E40403CF54883DB5E4A4074EFE192E36E4040C70DBF9B6E614A405C1D007157714040C70DBF9B6E614A405C1D0071577140403CF54883DB5E4A4074EFE192E36E40403CF54883DB5E4A40
24913	21133	32.472067000000003	32.517719999999997	52.800972000000002	52.783180999999999	Щорса	0103000020E61000000100000005000000AB4203B16C3C40409EEC66463F644A40AB4203B16C3C40408081204086664A40183E22A6444240408081204086664A40183E22A6444240409EEC66463F644A40AB4203B16C3C40409EEC66463F644A40
25001	48521	33.040512	33.056331999999998	52.899464999999999	52.884388000000001	Луговая	0103000020E610000001000000050000003B8C497F2F854040C87C40A033714A403B8C497F2F854040C5724BAB21734A40F0DB10E335874040C5724BAB21734A40F0DB10E335874040C87C40A033714A403B8C497F2F854040C87C40A033714A40
24720	48234	32.698587000000003	32.727089999999997	52.937016	52.913097	Школьная	0103000020E6100000010000000500000094347F4C6B594040B189CC5CE0744A4094347F4C6B59404014EAE923F0774A40D39FFD48115D404014EAE923F0774A40D39FFD48115D4040B189CC5CE0744A4094347F4C6B594040B189CC5CE0744A40
24994	20328	33.051552999999998	33.078294999999997	52.790294000000003	52.771273000000001	Зеленая	0103000020E610000001000000050000005E81E84999864040D7A4DB12B9624A405E81E84999864040CE1C925A28654A405C381092058A4040CE1C925A28654A405C381092058A4040D7A4DB12B9624A405E81E84999864040D7A4DB12B9624A40
24719	20634	32.636476999999999	32.664963	52.768161999999997	52.749104000000003	Октябрьская	0103000020E61000000100000005000000FED30D1478514040C2A6CEA3E25F4A40FED30D1478514040D503E62153624A406806F1811D554040D503E62153624A406806F1811D554040C2A6CEA3E25F4A40FED30D1478514040C2A6CEA3E25F4A40
25185	51130	32.426900000000003	33.198894000000003	52.991798000000003	52.660494999999997	Щорса	0103000020E61000000100000005000000CA54C1A8A4364040F415A4198B544A40CA54C1A8A43640407E1EA33CF37E4A4071AFCC5B759940407E1EA33CF37E4A4071AFCC5B75994040F415A4198B544A40CA54C1A8A4364040F415A4198B544A40
24611	21256	33.111325999999998	33.143135999999998	52.921990999999998	52.909002000000001	Советская	0103000020E61000000100000005000000E5982CEE3F8E4040D2FF722D5A744A40E5982CEE3F8E4040691A14CD03764A40AC70CB4752924040691A14CD03764A40AC70CB4752924040D2FF722D5A744A40E5982CEE3F8E4040D2FF722D5A744A40
24417	20430	32.584958999999998	32.626280999999999	52.918826000000003	52.904625000000003	Школьная	0103000020E610000001000000050000001C40BFEFDF4A40406F1283C0CA734A401C40BFEFDF4A4040755B22179C754A40978DCEF929504040755B22179C754A40978DCEF9295040406F1283C0CA734A401C40BFEFDF4A40406F1283C0CA734A40
25078	20858	32.893728000000003	32.911245000000001	52.875410000000002	52.866767000000003	Центральная	0103000020E610000001000000050000007FC2D9AD6572404043209738F26E4A407FC2D9AD65724040B24B546F0D704A405FD218ADA3744040B24B546F0D704A405FD218ADA374404043209738F26E4A407FC2D9AD6572404043209738F26E4A40
25227	20858	32.893728000000003	32.911245000000001	52.875410000000002	52.866767000000003	Сосновый переулок	0103000020E610000001000000050000007FC2D9AD6572404043209738F26E4A407FC2D9AD65724040B24B546F0D704A405FD218ADA3744040B24B546F0D704A405FD218ADA374404043209738F26E4A407FC2D9AD6572404043209738F26E4A40
24593	47777	32.654119999999999	32.664504000000001	52.801223	52.795299	Школьная	0103000020E610000001000000050000006BD44334BA53404050C58D5BCC654A406BD44334BA534040C9E6AA798E664A40D50792770E554040C9E6AA798E664A40D50792770E55404050C58D5BCC654A406BD44334BA53404050C58D5BCC654A40
75042	47777	32.654119999999999	32.664504000000001	52.801223	52.795299	Буденного	0103000020E610000001000000050000006BD44334BA53404050C58D5BCC654A406BD44334BA534040C9E6AA798E664A40D50792770E554040C9E6AA798E664A40D50792770E55404050C58D5BCC654A406BD44334BA53404050C58D5BCC654A40
24899	20400	33.027478000000002	33.054974999999999	52.81315	52.784097000000003	Школьная	0103000020E6100000010000000500000004AE2B668483404024F25D4A5D644A4004AE2B6684834040075F984C15684A407E8CB96B09874040075F984C15684A407E8CB96B0987404024F25D4A5D644A4004AE2B668483404024F25D4A5D644A40
24694	10615	32.469614999999997	32.489530999999999	52.905928000000003	52.892625000000002	Центральная	0103000020E61000000100000005000000035B25581C3C4040C74B378941724A40035B25581C3C4040EE43DE72F5734A4068B0A9F3A83E4040EE43DE72F5734A4068B0A9F3A83E4040C74B378941724A40035B25581C3C4040C74B378941724A40
75044	48936	32.908110000000001	32.923434999999998	52.760354	52.748111999999999	Цветочная	0103000020E61000000100000005000000D595CFF23C74404061DF4E22C25F4A40D595CFF23C744040FFB0A54753614A40AA7D3A1E33764040FFB0A54753614A40AA7D3A1E3376404061DF4E22C25F4A40D595CFF23C74404061DF4E22C25F4A40
24416	20649	32.582183000000001	32.614423000000002	52.706937000000003	52.694718999999999	Первомайская	0103000020E61000000100000005000000C2A4F8F8844A404075745C8DEC584A40C2A4F8F8844A40408BAA5FE97C5A4A408274B169A54E40408BAA5FE97C5A4A408274B169A54E404075745C8DEC584A40C2A4F8F8844A404075745C8DEC584A40
25203	51137	32.983029000000002	32.995525000000001	52.790990999999998	52.779471999999998	Лесная 	0103000020E610000001000000050000008202EFE4D37D4040E8120EBDC5634A408202EFE4D37D404015376E313F654A40DAACFA5C6D7F404015376E313F654A40DAACFA5C6D7F4040E8120EBDC5634A408202EFE4D37D4040E8120EBDC5634A40
25143	51111	32.721943000000003	32.739172000000003	52.909669999999998	52.890604000000003	Мглинская	0103000020E61000000100000005000000BF49D3A0685C4040E9D7D64FFF714A40BF49D3A0685C40407F130A1170744A40390F27309D5E40407F130A1170744A40390F27309D5E4040E9D7D64FFF714A40BF49D3A0685C4040E9D7D64FFF714A40
24992	20020	32.758315000000003	32.778213000000001	52.825840999999997	52.815229000000002	Переулок Совхозный	0103000020E610000001000000050000007B884677106140401AE0826C59684A407B8846771061404014596B28B5694A403929CC7B9C63404014596B28B5694A403929CC7B9C6340401AE0826C59684A407B884677106140401AE0826C59684A40
24476	47165	33.872414999999997	33.901708999999997	52.742829999999998	52.728439999999999	Центральная	0103000020E6100000010000000500000019C5724BABEF4040938C9C853D5D4A4019C5724BABEF40406C3EAE0D155F4A4022C154336BF340406C3EAE0D155F4A4022C154336BF34040938C9C853D5D4A4019C5724BABEF4040938C9C853D5D4A40
24481	47382	33.649282999999997	33.668453	52.583399999999997	52.572975	Новая	0103000020E61000000100000005000000A46C91B41BD340407A36AB3E57494A40A46C91B41BD34040423EE8D9AC4A4A40E0F42EDE8FD54040423EE8D9AC4A4A40E0F42EDE8FD540407A36AB3E57494A40A46C91B41BD340407A36AB3E57494A40
25212	16980	33.743389999999998	33.788646999999997	52.598205	52.533540000000002	Советская	0103000020E6100000010000000500000033164D6727DF4040CE8DE9094B444A4033164D6727DF4040DFA63FFB914C4A40548B8862F2E44040DFA63FFB914C4A40548B8862F2E44040CE8DE9094B444A4033164D6727DF4040CE8DE9094B444A40
24805	16980	33.743389999999998	33.788646999999997	52.598205	52.533540000000002	Луначарского	0103000020E6100000010000000500000033164D6727DF4040CE8DE9094B444A4033164D6727DF4040DFA63FFB914C4A40548B8862F2E44040DFA63FFB914C4A40548B8862F2E44040CE8DE9094B444A4033164D6727DF4040CE8DE9094B444A40
24802	16980	33.743389999999998	33.788646999999997	52.598205	52.533540000000002	Ленина	0103000020E6100000010000000500000033164D6727DF4040CE8DE9094B444A4033164D6727DF4040DFA63FFB914C4A40548B8862F2E44040DFA63FFB914C4A40548B8862F2E44040CE8DE9094B444A4033164D6727DF4040CE8DE9094B444A40
24960	16980	33.743389999999998	33.788646999999997	52.598205	52.533540000000002	Комсомольская	0103000020E6100000010000000500000033164D6727DF4040CE8DE9094B444A4033164D6727DF4040DFA63FFB914C4A40548B8862F2E44040DFA63FFB914C4A40548B8862F2E44040CE8DE9094B444A4033164D6727DF4040CE8DE9094B444A40
9810	16980	33.743389999999998	33.788646999999997	52.598205	52.533540000000002	Володарского	0103000020E6100000010000000500000033164D6727DF4040CE8DE9094B444A4033164D6727DF4040DFA63FFB914C4A40548B8862F2E44040DFA63FFB914C4A40548B8862F2E44040CE8DE9094B444A4033164D6727DF4040CE8DE9094B444A40
24892	17930	33.733338000000003	33.756037999999997	52.574748999999997	52.564698999999997	Трубчевская 	0103000020E6100000010000000500000000750305DEDD4040BD8A8C0E48484A4000750305DEDD404050340F6091494A4041446ADAC5E0404050340F6091494A4041446ADAC5E04040BD8A8C0E48484A4000750305DEDD4040BD8A8C0E48484A40
25130	17879	33.964312999999997	33.980392999999999	52.812762999999997	52.804004999999997	Строительная 	0103000020E61000000100000005000000C70DBF9B6EFB40400569C6A2E9664A40C70DBF9B6EFB40400D33349E08684A40191D90847DFD40400D33349E08684A40191D90847DFD40400569C6A2E9664A40C70DBF9B6EFB40400569C6A2E9664A40
25133	47210	33.802813999999998	33.833015000000003	52.774242999999998	52.750734000000001	Молодежная 	0103000020E61000000100000005000000AE62F19BC2E6404065FF3C0D18604A40AE62F19BC2E64040161406651A634A40EA094B3CA0EA4040161406651A634A40EA094B3CA0EA404065FF3C0D18604A40AE62F19BC2E6404065FF3C0D18604A40
24853	49396	33.993237999999998	34.011268000000001	52.641390000000001	52.633111	Октябрьская 	0103000020E610000001000000050000007D923B6C22FF404072DEFFC709514A407D923B6C22FF4040A0FD481119524A40E4BED53A71014140A0FD481119524A40E4BED53A7101414072DEFFC709514A407D923B6C22FF404072DEFFC709514A40
24564	47265	33.973987999999999	33.99004	52.808321999999997	52.794798	Молодежная	0103000020E61000000100000005000000255987A3ABFC40408E76DCF0BB654A40255987A3ABFC40409351651877674A40ADDD76A1B9FE40409351651877674A40ADDD76A1B9FE40408E76DCF0BB654A40255987A3ABFC40408E76DCF0BB654A40
25127	17634	34.002608000000002	34.017789	52.728102	52.719985999999999	Центральная 	0103000020E610000001000000050000009F5A7D7555004140F7C95180285C4A409F5A7D75550041407B134372325D4A40419DF2E8460241407B134372325D4A40419DF2E846024140F7C95180285C4A409F5A7D7555004140F7C95180285C4A40
24563	45579	33.717194999999997	33.739410999999997	52.774133999999997	52.765138	Ложковская	0103000020E6100000010000000500000067EDB60BCDDB4040A376BF0AF0614A4067EDB60BCDDB40405F5CAAD216634A40BDA60705A5DE40405F5CAAD216634A40BDA60705A5DE4040A376BF0AF0614A4067EDB60BCDDB4040A376BF0AF0614A40
25007	51097	33.980662000000002	33.998286999999998	52.757573999999998	52.751278999999997	Деснянская	0103000020E610000001000000050000000937195586FD4040F69507E929604A400937195586FD40406326512FF8604A40CF8250DEC7FF40406326512FF8604A40CF8250DEC7FF4040F69507E929604A400937195586FD4040F69507E929604A40
24677	47169	34.003416000000001	34.008114999999997	52.655607000000003	52.650914	Центральная	0103000020E610000001000000050000003E247CEF6F0041401841632651534A403E247CEF6F004140AC0320EEEA534A40B3CD8DE909014140AC0320EEEA534A40B3CD8DE9090141401841632651534A403E247CEF6F0041401841632651534A40
25161	51116	33.462783000000002	33.497996999999998	52.396242000000001	52.370714999999997	Ленина	0103000020E6100000010000000500000088122D793CBB40407D91D096732F4A4088122D793CBB40409CA6CF0EB8324A40C8409E5DBEBF40409CA6CF0EB8324A40C8409E5DBEBF40407D91D096732F4A4088122D793CBB40407D91D096732F4A40
25228	51116	33.462783000000002	33.497996999999998	52.396242000000001	52.370714999999997	Дзержинского	0103000020E6100000010000000500000088122D793CBB40407D91D096732F4A4088122D793CBB40409CA6CF0EB8324A40C8409E5DBEBF40409CA6CF0EB8324A40C8409E5DBEBF40407D91D096732F4A4088122D793CBB40407D91D096732F4A40
25292	51116	33.462783000000002	33.497996999999998	52.396242000000001	52.370714999999997	 Калинина	0103000020E6100000010000000500000088122D793CBB40407D91D096732F4A4088122D793CBB40409CA6CF0EB8324A40C8409E5DBEBF40409CA6CF0EB8324A40C8409E5DBEBF40407D91D096732F4A4088122D793CBB40407D91D096732F4A40
24706	14985	32.354469000000002	32.425120999999997	53.033628	52.998784000000001	Октябрьская	0103000020E6100000010000000500000011397D3D5F2D404050E27327D87F4A4011397D3D5F2D40406D1D1CEC4D844A40E1EB6B5D6A3640406D1D1CEC4D844A40E1EB6B5D6A36404050E27327D87F4A4011397D3D5F2D404050E27327D87F4A40
24783	14985	32.354469000000002	32.425120999999997	53.033628	52.998784000000001	Ленина	0103000020E6100000010000000500000011397D3D5F2D404050E27327D87F4A4011397D3D5F2D40406D1D1CEC4D844A40E1EB6B5D6A3640406D1D1CEC4D844A40E1EB6B5D6A36404050E27327D87F4A4011397D3D5F2D404050E27327D87F4A40
25123	14985	32.354469000000002	32.425120999999997	53.033628	52.998784000000001	Комсомольская	0103000020E6100000010000000500000011397D3D5F2D404050E27327D87F4A4011397D3D5F2D40406D1D1CEC4D844A40E1EB6B5D6A3640406D1D1CEC4D844A40E1EB6B5D6A36404050E27327D87F4A4011397D3D5F2D404050E27327D87F4A40
24542	14985	32.354469000000002	32.425120999999997	53.033628	52.998784000000001	Ворошилова	0103000020E6100000010000000500000011397D3D5F2D404050E27327D87F4A4011397D3D5F2D40406D1D1CEC4D844A40E1EB6B5D6A3640406D1D1CEC4D844A40E1EB6B5D6A36404050E27327D87F4A4011397D3D5F2D404050E27327D87F4A40
24541	14985	32.354469000000002	32.425120999999997	53.033628	52.998784000000001	Белорусская	0103000020E6100000010000000500000011397D3D5F2D404050E27327D87F4A4011397D3D5F2D40406D1D1CEC4D844A40E1EB6B5D6A3640406D1D1CEC4D844A40E1EB6B5D6A36404050E27327D87F4A4011397D3D5F2D404050E27327D87F4A40
24867	14985	32.354469000000002	32.425120999999997	53.033628	52.998784000000001	29 квартал	0103000020E6100000010000000500000011397D3D5F2D404050E27327D87F4A4011397D3D5F2D40406D1D1CEC4D844A40E1EB6B5D6A3640406D1D1CEC4D844A40E1EB6B5D6A36404050E27327D87F4A4011397D3D5F2D404050E27327D87F4A40
24799	15951	32.497813000000001	32.522975000000002	53.237855000000003	53.226357999999998	Новая	0103000020E6100000010000000500000007431D56B83F40400F98874CF99C4A4007431D56B83F404055185B08729E4A4014D044D8F042404055185B08729E4A4014D044D8F04240400F98874CF99C4A4007431D56B83F40400F98874CF99C4A40
24429	14429	32.440733999999999	32.459850000000003	53.163449	53.139719999999997	Советская	0103000020E610000001000000050000001D1EC2F8693840406E4C4F58E2914A401D1EC2F8693840402EC896E5EB944A406688635DDC3A40402EC896E5EB944A406688635DDC3A40406E4C4F58E2914A401D1EC2F8693840406E4C4F58E2914A40
25155	51118	\N	\N	\N	\N	Клинцовская	\N
24791	15600	32.175893000000002	32.200363000000003	53.036352000000001	53.021621000000003	Ковалевка	0103000020E61000000100000005000000344C6DA98316404013F4177AC4824A40344C6DA9831640407592AD2EA7844A400B2AAA7EA51940407592AD2EA7844A400B2AAA7EA519404013F4177AC4824A40344C6DA98316404013F4177AC4824A40
25125	16566	32.458179000000001	32.493662999999998	53.053654000000002	53.037657000000003	Молодежная	0103000020E61000000100000005000000645B069CA53A404095BBCFF1D1844A40645B069CA53A404059A65F22DE864A40641F6459303F404059A65F22DE864A40641F6459303F404095BBCFF1D1844A40645B069CA53A404095BBCFF1D1844A40
25044	16541	32.517836000000003	32.553958000000002	53.099653000000004	53.085814999999997	пер.Молодежный	0103000020E610000001000000050000008258367348424040CC4065FCFB8A4A40825836734842404062F9F36DC18C4A40C5AD8218E846404062F9F36DC18C4A40C5AD8218E8464040CC4065FCFB8A4A408258367348424040CC4065FCFB8A4A40
24877	16453	32.568106	32.595343	53.200091	53.163071000000002	Ленина  	0103000020E61000000100000005000000A85489B2B748404088F6B182DF944A40A85489B2B7484040AA9CF6949C994A4086730D33344C4040AA9CF6949C994A4086730D33344C404088F6B182DF944A40A85489B2B748404088F6B182DF944A40
25042	16370	32.515419999999999	32.571734999999997	53.020403000000002	52.988225	Мичурина	0103000020E6100000010000000500000027DA5548F9414040780B24287E7E4A4027DA5548F9414040C2DEC4909C824A40417DCB9C2E494040C2DEC4909C824A40417DCB9C2E494040780B24287E7E4A4027DA5548F9414040780B24287E7E4A40
24952	16260	32.610201000000004	32.656402	53.044066999999998	53.014211000000003	Дубиновка	0103000020E61000000100000005000000467EFD101B4E40402A1F82AAD1814A40467EFD101B4E40409AEAC9FCA3854A40B68311FB045440409AEAC9FCA3854A40B68311FB045440402A1F82AAD1814A40467EFD101B4E40402A1F82AAD1814A40
24793	16070	32.40437	32.416595999999998	52.969507999999998	52.958193999999999	Школьная	0103000020E61000000100000005000000E4BD6A65C2334040999CDA19A67A4A40E4BD6A65C2334040ED9A90D6187C4A407CD2890453354040ED9A90D6187C4A407CD2890453354040999CDA19A67A4A40E4BD6A65C2334040999CDA19A67A4A40
25040	15963	32.372695999999998	32.417287999999999	52.927990000000001	52.892206999999999	Октябрьская	0103000020E61000000100000005000000CDACA580B42F40409221C7D633724A40CDACA580B42F4040ED815660C8764A40B28174B169354040ED815660C8764A40B28174B1693540409221C7D633724A40CDACA580B42F40409221C7D633724A40
24669	15473	32.348567000000003	32.374789	53.015667999999998	52.996248000000001	Гагарина	0103000020E6100000010000000500000080BBECD79D2C40404B5AF10D857F4A4080BBECD79D2C4040FFCBB56801824A4045F30016F92F4040FFCBB56801824A4045F30016F92F40404B5AF10D857F4A4080BBECD79D2C40404B5AF10D857F4A40
24798	16350	32.657128999999998	32.699196999999998	53.070056999999998	53.046872	Заречье	0103000020E61000000100000005000000682096CD1C5440408F8CD5E6FF854A40682096CD1C5440408DEDB5A0F7884A400C3B8C497F5940408DEDB5A0F7884A400C3B8C497F5940408F8CD5E6FF854A40682096CD1C5440408F8CD5E6FF854A40
24548	16155	32.456437000000001	32.474609999999998	52.993803	52.984999999999999	.Новая	0103000020E6100000010000000500000099D711876C3A4040AE47E17A147E4A4099D711876C3A404056D5CBEF347F4A40622D3E05C03C404056D5CBEF347F4A40622D3E05C03C4040AE47E17A147E4A4099D711876C3A4040AE47E17A147E4A40
24674	16652	32.389018	32.425390999999998	53.042476000000001	53.028446000000002	Садовая	0103000020E6100000010000000500000015C78157CB314040DCD9571EA4834A4015C78157CB314040B56E83DA6F854A40A181583673364040B56E83DA6F854A40A181583673364040DCD9571EA4834A4015C78157CB314040DCD9571EA4834A40
25034	15679	32.574852999999997	32.609042000000002	53.280042999999999	53.268557999999999	Центральная	0103000020E61000000100000005000000F58079C894494040228AC91B60A24A40F58079C894494040A33CF372D8A34A40FAF19716F54D4040A33CF372D8A34A40FAF19716F54D4040228AC91B60A24A40F58079C894494040228AC91B60A24A40
24610	51049	32.261555999999999	32.286636999999999	53.078415	53.057946000000001	Школьная	0103000020E610000001000000050000004A09C1AA7A2140408E7747C66A874A404A09C1AA7A2140400742B280098A4A406A696E85B02440400742B280098A4A406A696E85B02440408E7747C66A874A404A09C1AA7A2140408E7747C66A874A40
25035	15850	32.442315000000001	32.466183000000001	53.097496	53.083835000000001	Центральная	0103000020E61000000100000005000000DFC325C79D3840404DA1F31ABB8A4A40DFC325C79D384040D3BEB9BF7A8C4A40C07971E2AB3B4040D3BEB9BF7A8C4A40C07971E2AB3B40404DA1F31ABB8A4A40DFC325C79D3840404DA1F31ABB8A4A40
24790	15667	32.632371999999997	32.669535000000003	53.262003	53.250712	пер.Садовый	0103000020E61000000100000005000000FB73D190F15040407D5BB05417A04A40FB73D190F1504040193A765089A14A408143A852B3554040193A765089A14A408143A852B35540407D5BB05417A04A40FB73D190F15040407D5BB05417A04A40
24457	15874	32.370800000000003	32.392611000000002	53.150809000000002	53.134096999999997	Октябрьская	0103000020E61000000100000005000000ACADD85F762F4040F0BE2A172A914A40ACADD85F762F4040A37895B54D934A406286C61341324040A37895B54D934A406286C61341324040F0BE2A172A914A40ACADD85F762F4040F0BE2A172A914A40
25041	16229	32.521051999999997	32.546044000000002	52.950310999999999	52.933422999999998	Садовая	0103000020E61000000100000005000000F8C1F9D4B1424040C72AA5677A774A40F8C1F9D4B1424040B80375CAA3794A40A91611C5E4454040B80375CAA3794A40A91611C5E4454040C72AA5677A774A40F8C1F9D4B1424040C72AA5677A774A40
25092	15758	32.667541	32.689450999999998	53.295583999999998	53.284103000000002	пер.Сентябрьский	0103000020E610000001000000050000009CDEC5FB7155404006D9B27C5DA44A409CDEC5FB71554040459C4EB2D5A54A40E5982CEE3F584040459C4EB2D5A54A40E5982CEE3F58404006D9B27C5DA44A409CDEC5FB7155404006D9B27C5DA44A40
24955	16471	32.526811000000002	32.550418000000001	53.139726000000003	53.121398999999997	Молодежная	0103000020E610000001000000050000002716F88A6E43404030629F008A8F4A402716F88A6E4340405133A48AE2914A409B90D618744640405133A48AE2914A409B90D6187446404030629F008A8F4A402716F88A6E43404030629F008A8F4A40
24544	15427	32.264197000000003	32.310423999999998	53.026864000000003	53.001888999999998	Ленина	0103000020E61000000100000005000000C5591135D12140406F9C14E63D804A40C5591135D12140404AB8904770834A405EF23FF9BB2740404AB8904770834A405EF23FF9BB2740406F9C14E63D804A40C5591135D12140406F9C14E63D804A40
24894	31812	32.364207	32.384149000000001	52.966970000000003	52.95852	 60 лет Октября	0103000020E61000000100000005000000B5FCC0559E2E4040ED478AC8B07A4A40B5FCC0559E2E4040481B47ACC57B4A4043E55FCB2B314040481B47ACC57B4A4043E55FCB2B314040ED478AC8B07A4A40B5FCC0559E2E4040ED478AC8B07A4A40
25008	15502	32.219909999999999	32.236303999999997	53.009307	52.996724	Октябрьская	0103000020E610000001000000050000001C08C902261C4040B491EBA6947F4A401C08C902261C4040DB4FC6F830814A40FDF49F353F1E4040DB4FC6F830814A40FDF49F353F1E4040B491EBA6947F4A401C08C902261C4040B491EBA6947F4A40
25006	14794	33.909246000000003	33.927742000000002	52.412340999999998	52.400111000000003	Заречная	0103000020E610000001000000050000006902452C62F440408BE255D636334A406902452C62F4404064E60297C7344A401590F63FC0F6404064E60297C7344A401590F63FC0F640408BE255D636334A406902452C62F440408BE255D636334A40
25005	14521	34.186143000000001	34.210514000000003	52.261011000000003	52.238731000000001	Молодёжная	0103000020E610000001000000050000008EB0A888D31741404CC5C6BC8E1E4A408EB0A888D3174140B972F6CE68214A40D2AC6C1FF21A4140B972F6CE68214A40D2AC6C1FF21A41404CC5C6BC8E1E4A408EB0A888D31741404CC5C6BC8E1E4A40
24536	14886	34.198233999999999	34.218544999999999	52.514642000000002	52.492517999999997	Будённого	0103000020E61000000100000005000000467A51BB5F1941407D586FD40A3F4A40467A51BB5F194140F392FFC9DF414A4027DA5548F91B4140F392FFC9DF414A4027DA5548F91B41407D586FD40A3F4A40467A51BB5F1941407D586FD40A3F4A40
24547	13774	34.013379	34.134039999999999	52.342883999999998	52.294412999999999	пер. 1-й Трубчевский	0103000020E6100000010000000500000002BA2F67B601414035423F53AF254A4002BA2F67B60141402C29779FE32B4A408C2D0439281141402C29779FE32B4A408C2D04392811414035423F53AF254A4002BA2F67B601414035423F53AF254A40
25032	13774	34.013379	34.134039999999999	52.342883999999998	52.294412999999999	Площадь Ленина	0103000020E6100000010000000500000002BA2F67B601414035423F53AF254A4002BA2F67B60141402C29779FE32B4A408C2D0439281141402C29779FE32B4A408C2D04392811414035423F53AF254A4002BA2F67B601414035423F53AF254A40
25116	13774	34.013379	34.134039999999999	52.342883999999998	52.294412999999999	Переулок Интернациональный	0103000020E6100000010000000500000002BA2F67B601414035423F53AF254A4002BA2F67B60141402C29779FE32B4A408C2D0439281141402C29779FE32B4A408C2D04392811414035423F53AF254A4002BA2F67B601414035423F53AF254A40
24501	13774	34.013379	34.134039999999999	52.342883999999998	52.294412999999999	Первомайская	0103000020E6100000010000000500000002BA2F67B601414035423F53AF254A4002BA2F67B60141402C29779FE32B4A408C2D0439281141402C29779FE32B4A408C2D04392811414035423F53AF254A4002BA2F67B601414035423F53AF254A40
24743	14453	34.127932000000001	34.159382000000001	52.159095000000001	52.136642000000002	 им. Мореева	0103000020E61000000100000005000000520E66136010414049A12C7C7D114A40520E66136010414083FA96395D144A4019C91EA16614414083FA96395D144A4019C91EA16614414049A12C7C7D114A40520E66136010414049A12C7C7D114A40
24445	14655	34.369902000000003	34.403911999999998	52.305906999999998	52.289372999999998	 Центральная	0103000020E61000000100000005000000CD5CE0F2582F414036ACA92C0A254A40CD5CE0F2582F4140094FE8F527274A40213B6F63B3334140094FE8F527274A40213B6F63B333414036ACA92C0A254A40CD5CE0F2582F414036ACA92C0A254A40
24732	51063	34.345297000000002	34.389916999999997	52.400083000000002	52.370407	Школьная	0103000020E6100000010000000500000016342DB1322C4140D09A1F7F692F4A4016342DB1322C4140C15774EB35334A40C493DDCCE8314140C15774EB35334A40C493DDCCE8314140D09A1F7F692F4A4016342DB1322C4140D09A1F7F692F4A40
24776	14341	34.175182999999997	34.207334000000003	52.197172999999999	52.180466000000003	Молодёжная	0103000020E6100000010000000500000057E883656C1641401D05888219174A4057E883656C164140BD5301F73C194A40A8ACA6EB891A4140BD5301F73C194A40A8ACA6EB891A41401D05888219174A4057E883656C1641401D05888219174A40
24655	14329	34.204881999999998	34.223899000000003	52.211621999999998	52.196007999999999	Молодёжная	0103000020E6100000010000000500000000C5C892391A41408FE046CA16194A4000C5C892391A41409B8E006E161B4A40B64DF1B8A81C41409B8E006E161B4A40B64DF1B8A81C41408FE046CA16194A4000C5C892391A41408FE046CA16194A40
24657	14752	33.820286000000003	33.832332000000001	52.395142999999997	52.383656000000002	Школьная	0103000020E61000000100000005000000EFAEB321FFE840400475CAA31B314A40EFAEB321FFE84040251FBB0B94324A4007B5DFDA89EA4040251FBB0B94324A4007B5DFDA89EA40400475CAA31B314A40EFAEB321FFE840400475CAA31B314A40
24844	14686	33.887039999999999	33.911824000000003	52.344216000000003	52.323210000000003	Центральная	0103000020E61000000100000005000000361FD7868AF14040BEDEFDF15E294A40361FD7868AF14040466117450F2C4A409DDA19A6B6F44040466117450F2C4A409DDA19A6B6F44040BEDEFDF15E294A40361FD7868AF14040BEDEFDF15E294A40
24454	14137	34.113253	34.133501000000003	52.388432999999999	52.383167	станция Лесная	0103000020E61000000100000005000000429605137F0E414006F4C29D0B314A40429605137F0E4140F5D72B2CB8314A40DD7D8E8F16114140F5D72B2CB8314A40DD7D8E8F1611414006F4C29D0B314A40429605137F0E414006F4C29D0B314A40
24860	14137	34.113253	34.133501000000003	52.388432999999999	52.383167	Центральная	0103000020E61000000100000005000000429605137F0E414006F4C29D0B314A40429605137F0E4140F5D72B2CB8314A40DD7D8E8F16114140F5D72B2CB8314A40DD7D8E8F1611414006F4C29D0B314A40429605137F0E414006F4C29D0B314A40
25027	14603	34.179001	34.251683999999997	52.326832000000003	52.302453999999997	Центральная	0103000020E61000000100000005000000C4793881E9164140AE450BD0B6264A40C4793881E9164140A5A487A1D5294A4096766A2E37204140A5A487A1D5294A4096766A2E37204140AE450BD0B6264A40C4793881E9164140AE450BD0B6264A40
25109	14541	34.264853000000002	34.301585000000003	52.315095999999997	52.289614999999998	Центральная	0103000020E61000000100000005000000AE9FFEB3E62141402CB7B41A12254A40AE9FFEB3E6214140DA8CD31055284A406AFB57569A264140DA8CD31055284A406AFB57569A2641402CB7B41A12254A40AE9FFEB3E62141402CB7B41A12254A40
24953	51087	34.002374000000003	34.042977999999998	52.457801000000003	52.444842999999999	Школьная	0103000020E610000001000000050000002C2E8ECA4D004140616D8C9DF0384A402C2E8ECA4D004140BE892139993A4A404739984D80054140BE892139993A4A404739984D80054140616D8C9DF0384A402C2E8ECA4D004140616D8C9DF0384A40
24770	14176	34.243428000000002	34.307702999999997	52.604669999999999	52.578043000000001	Гагарина	0103000020E61000000100000005000000217711A6281F414043572250FD494A40217711A6281F4140A86F99D3654D4A40C7F0D8CF62274140A86F99D3654D4A40C7F0D8CF6227414043572250FD494A40217711A6281F414043572250FD494A40
24528	14278	34.056103	34.104899000000003	52.204827999999999	52.185898999999999	Молодёжная	0103000020E610000001000000050000008F1A13622E074140F7ADD689CB174A408F1A13622E0741400DA7CCCD371A4A400A3197546D0D41400DA7CCCD371A4A400A3197546D0D4140F7ADD689CB174A408F1A13622E074140F7ADD689CB174A40
24919	14051	34.013091000000003	34.064070999999998	52.416603000000002	52.396450999999999	пер. Речной	0103000020E610000001000000050000009C6F44F7AC014140B6BB07E8BE324A409C6F44F7AC0141402F35423F53354A409ECF807A330841402F35423F53354A409ECF807A33084140B6BB07E8BE324A409C6F44F7AC014140B6BB07E8BE324A40
24918	13991	33.960351000000003	33.987408000000002	52.309711	52.293686000000001	Лесная	0103000020E6100000010000000500000028D714C8ECFA404083A5BA8097254A4028D714C8ECFA4040111B2C9CA4274A4086E7A56263FE4040111B2C9CA4274A4086E7A56263FE404083A5BA8097254A4028D714C8ECFA404083A5BA8097254A40
24653	14214	34.148845000000001	34.193885999999999	52.238895999999997	52.219754999999999	пер. Советский	0103000020E6100000010000000500000029965B5A0D134140F5108DEE201C4A4029965B5A0D1341409692E524941E4A407D93A641D11841409692E524941E4A407D93A641D1184140F5108DEE201C4A4029965B5A0D134140F5108DEE201C4A40
24519	13083	32.646690999999997	32.677629000000003	52.597926000000001	52.582788000000001	Садовая	0103000020E610000001000000050000000BCF4BC5C6524040294014CC984A4A400BCF4BC5C6524040CCB6D3D6884C4A401DE90C8CBC564040CCB6D3D6884C4A401DE90C8CBC564040294014CC984A4A400BCF4BC5C6524040294014CC984A4A40
25014	12399	32.586655999999998	32.630243	52.548563999999999	52.516922000000001	Зеленая Дубрава	0103000020E610000001000000050000004700378B174B40409D4A06802A424A404700378B174B4040A8E15B5837464A4037C478CDAB504040A8E15B5837464A4037C478CDAB5040409D4A06802A424A404700378B174B40409D4A06802A424A40
25096	12828	32.941913	32.991204000000003	52.462426999999998	52.447493999999999	Новая	0103000020E61000000100000005000000B056ED9A90784040FF93BF7B47394A40B056ED9A90784040C9E4D4CE303B4A400BD5CDC5DF7E4040C9E4D4CE303B4A400BD5CDC5DF7E4040FF93BF7B47394A40B056ED9A90784040FF93BF7B47394A40
24780	12053	32.718915000000003	32.802709999999998	52.613380999999997	52.556705999999998	Урицкого	0103000020E610000001000000050000004BCD1E68055C404055BE672442474A404BCD1E68055C40406F7EC344834E4A4009168733BF6640406F7EC344834E4A4009168733BF66404055BE672442474A404BCD1E68055C404055BE672442474A40
24911	12053	32.718915000000003	32.802709999999998	52.613380999999997	52.556705999999998	Совхозная	0103000020E610000001000000050000004BCD1E68055C404055BE672442474A404BCD1E68055C40406F7EC344834E4A4009168733BF6640406F7EC344834E4A4009168733BF66404055BE672442474A404BCD1E68055C404055BE672442474A40
24540	12053	32.718915000000003	32.802709999999998	52.613380999999997	52.556705999999998	Семашко	0103000020E610000001000000050000004BCD1E68055C404055BE672442474A404BCD1E68055C40406F7EC344834E4A4009168733BF6640406F7EC344834E4A4009168733BF66404055BE672442474A404BCD1E68055C404055BE672442474A40
24733	12053	32.718915000000003	32.802709999999998	52.613380999999997	52.556705999999998	Ленина	0103000020E610000001000000050000004BCD1E68055C404055BE672442474A404BCD1E68055C40406F7EC344834E4A4009168733BF6640406F7EC344834E4A4009168733BF66404055BE672442474A404BCD1E68055C404055BE672442474A40
24744	12053	32.718915000000003	32.802709999999998	52.613380999999997	52.556705999999998	Красных Партизан	0103000020E610000001000000050000004BCD1E68055C404055BE672442474A404BCD1E68055C40406F7EC344834E4A4009168733BF6640406F7EC344834E4A4009168733BF66404055BE672442474A404BCD1E68055C404055BE672442474A40
24524	12053	32.718915000000003	32.802709999999998	52.613380999999997	52.556705999999998	Краснооктябрьская	0103000020E610000001000000050000004BCD1E68055C404055BE672442474A404BCD1E68055C40406F7EC344834E4A4009168733BF6640406F7EC344834E4A4009168733BF66404055BE672442474A404BCD1E68055C404055BE672442474A40
24606	11528	32.614055	32.652259999999998	52.430079999999997	52.408880000000003	Пролетарская	0103000020E61000000100000005000000FF78AF5A994E404087FE092E56344A40FF78AF5A994E4040F35487DC0C374A40963E74417D534040F35487DC0C374A40963E74417D53404087FE092E56344A40FF78AF5A994E404087FE092E56344A40
24763	12918	32.937341000000004	32.967703999999998	52.526183000000003	52.511128999999997	пер. Коммунистический	0103000020E61000000100000005000000981936CAFA774040C284D1AC6C414A40981936CAFA774040085BECF659434A40AC1A84B9DD7B4040085BECF659434A40AC1A84B9DD7B4040C284D1AC6C414A40981936CAFA774040C284D1AC6C414A40
24859	13204	32.688858000000003	32.728411000000001	52.676054000000001	52.647433999999997	Стародубская	0103000020E6100000010000000500000043CBBA7F2C584040C328081EDF524A4043CBBA7F2C5840403D2AFEEF88564A40F98557923C5D40403D2AFEEF88564A40F98557923C5D4040C328081EDF524A4043CBBA7F2C584040C328081EDF524A40
25221	51144	32.974504000000003	32.992775999999999	52.611094999999999	52.595098	Молодежная	0103000020E610000001000000050000001DE90C8CBC7C40401FF5D72B2C4C4A401DE90C8CBC7C4040E3DF675C384E4A407920B248137F4040E3DF675C384E4A407920B248137F40401FF5D72B2C4C4A401DE90C8CBC7C40401FF5D72B2C4C4A40
25099	13291	32.818618999999998	32.859276999999999	52.382376000000001	52.347814	Бриггена	0103000020E610000001000000050000002E71E481C8684040A48B4D2B852C4A402E71E481C86840403D635FB2F1304A403D9AEAC9FC6D40403D635FB2F1304A403D9AEAC9FC6D4040A48B4D2B852C4A402E71E481C8684040A48B4D2B852C4A40
24835	11708	33.045623999999997	33.077827999999997	52.675638999999997	52.663018999999998	Центральная	0103000020E61000000100000005000000D3F4D901D785404035D07CCEDD544A40D3F4D901D78540407973B8567B564A40465B9544F68940407973B8567B564A40465B9544F689404035D07CCEDD544A40D3F4D901D785404035D07CCEDD544A40
24917	51080	32.781239999999997	32.801318000000002	52.642406999999999	52.623517999999997	Школьная	0103000020E61000000100000005000000DC291DACFF634040D13B1570CF4F4A40DC291DACFF63404059DC7F643A524A401BD995969166404059DC7F643A524A401BD9959691664040D13B1570CF4F4A40DC291DACFF634040D13B1570CF4F4A40
24736	13043	32.694561999999998	32.727288000000001	52.623693000000003	52.602679000000002	Мацкевича	0103000020E61000000100000005000000AD855968E7584040357EE195244D4A40AD855968E758404040DF162CD54F4A40FA62EFC5175D404040DF162CD54F4A40FA62EFC5175D4040357EE195244D4A40AD855968E7584040357EE195244D4A40
24928	49164	32.752099000000001	32.771323000000002	52.668590000000002	52.652524999999997	Советская	0103000020E610000001000000050000005A2DB0C74460404044696FF085534A405A2DB0C74460404061376C5B94554A4089D349B6BA62404061376C5B94554A4089D349B6BA62404044696FF085534A405A2DB0C74460404044696FF085534A40
24651	13217	32.737385000000003	32.746259999999999	52.682474999999997	52.677621000000002	Садовая	0103000020E61000000100000005000000CEC7B5A1625E40409A0AF148BC564A40CEC7B5A1625E404036AB3E575B574A400F289B72855F404036AB3E575B574A400F289B72855F40409A0AF148BC564A40CEC7B5A1625E40409A0AF148BC564A40
24926	12233	32.739649	32.764702999999997	52.452834000000003	52.435251999999998	переулок Школьный	0103000020E6100000010000000500000072C284D1AC5E404061C26856B6374A4072C284D1AC5E40402942EA76F6394A409813B4C9E16140402942EA76F6394A409813B4C9E161404061C26856B6374A4072C284D1AC5E404061C26856B6374A40
25263	51149	\N	\N	\N	\N	Озерная	\N
24516	51041	32.496223000000001	32.533934000000002	52.553865000000002	52.510899000000002	Школьная	0103000020E61000000100000005000000F2423A3C843F40409147702365414A40F2423A3C843F404014B35E0CE5464A407A1C06F35744404014B35E0CE5464A407A1C06F3574440409147702365414A40F2423A3C843F40409147702365414A40
24648	12940	32.636181000000001	32.654515000000004	52.641969000000003	52.622554999999998	Пролетарская	0103000020E6100000010000000500000015AB06616E5140400B7BDAE1AF4F4A4015AB06616E514040DE054A0A2C524A40E8DEC325C7534040DE054A0A2C524A40E8DEC325C75340400B7BDAE1AF4F4A4015AB06616E5140400B7BDAE1AF4F4A40
25095	12802	32.899396000000003	32.935561999999997	52.505285999999998	52.474359	Центральная	0103000020E610000001000000050000009D137B681F73404019C8B3CBB73C4A409D137B681F73404036902E36AD404A40AFB0E07EC077404036902E36AD404A40AFB0E07EC077404019C8B3CBB73C4A409D137B681F73404019C8B3CBB73C4A40
24738	51064	33.049863999999999	33.074415000000002	52.720723	52.705812999999999	Садовая	0103000020E61000000100000005000000B69F8CF161864040BB0B9414585A4A40B69F8CF161864040CD3CB9A6405C4A407AAA436E86894040CD3CB9A6405C4A407AAA436E86894040BB0B9414585A4A40B69F8CF161864040BB0B9414585A4A40
25159	51120	32.810614999999999	32.852234000000003	52.576028999999998	52.563187999999997	Первомайская	0103000020E61000000100000005000000D252793BC2674040F4BF5C8B16484A40D252793BC267404017467A51BB494A400745F300166D404017467A51BB494A400745F300166D4040F4BF5C8B16484A40D252793BC2674040F4BF5C8B16484A40
25091	12668	32.922195000000002	32.936433000000001	52.639150000000001	52.627262000000002	Комсомольская	0103000020E6100000010000000500000072C45A7C0A7640400403081F4A504A4072C45A7C0A764040849ECDAACF514A4095F25A09DD774040849ECDAACF514A4095F25A09DD7740400403081F4A504A4072C45A7C0A7640400403081F4A504A40
24855	12763	32.767415	32.791921000000002	52.709713999999998	52.692425999999998	Садовая	0103000020E61000000100000005000000DCBA9BA73A6240403673486AA1584A40DCBA9BA73A624040B5C189E8D75A4A400002D6AA5D654040B5C189E8D75A4A400002D6AA5D6540403673486AA1584A40DCBA9BA73A6240403673486AA1584A40
25076	11318	32.541139000000001	32.605674	52.369020999999996	52.348914000000001	Советская	0103000020E610000001000000050000008ACBF10A44454040EB8EC536A92C4A408ACBF10A44454040C34483143C2F4A40CD04C3B9864D4040C34483143C2F4A40CD04C3B9864D4040EB8EC536A92C4A408ACBF10A44454040EB8EC536A92C4A40
24500	11434	32.630493999999999	32.680548000000002	52.311439999999997	52.293587000000002	Семеновская	0103000020E6100000010000000500000080290307B4504040F0C3414294254A4080290307B450404047551344DD274A40DAAD65321C57404047551344DD274A40DAAD65321C574040F0C3414294254A4080290307B4504040F0C3414294254A40
24849	12504	32.555807999999999	32.597121999999999	52.602339999999998	52.588132999999999	Трудовая	0103000020E61000000100000005000000766D6FB724474040645930F1474B4A40766D6FB7244740404C89247A194D4A406EDC627E6E4C40404C89247A194D4A406EDC627E6E4C4040645930F1474B4A40766D6FB724474040645930F1474B4A40
25182	51088	32.861209000000002	32.906097000000003	52.589528000000001	52.577578000000003	Садовая	0103000020E61000000100000005000000AC02B5183C6E4040CE716E13EE494A40AC02B5183C6E4040C4094CA7754B4A407A008BFCFA734040C4094CA7754B4A407A008BFCFA734040CE716E13EE494A40AC02B5183C6E4040CE716E13EE494A40
24596	13422	32.785255999999997	32.827233999999997	52.309672999999997	52.285021	Луговая	0103000020E610000001000000050000006F7EC344836440402CD670917B244A406F7EC3448364404023BA675DA3274A40D311C0CDE269404023BA675DA3274A40D311C0CDE26940402CD670917B244A406F7EC344836440402CD670917B244A40
24930	12466	32.592046000000003	32.624519999999997	52.589002999999998	52.569248000000002	Советская	0103000020E6100000010000000500000023DDCF29C84B40401EA8531EDD484A4023DDCF29C84B4040791F4773644B4A4055D97745F04F4040791F4773644B4A4055D97745F04F40401EA8531EDD484A4023DDCF29C84B40401EA8531EDD484A40
24723	11430	32.712671999999998	32.743169999999999	52.339120999999999	52.326915	Набережная	0103000020E6100000010000000500000030630AD6385B404032C9C859D8294A4030630AD6385B404083312251682B4A4025AFCE31205F404083312251682B4A4025AFCE31205F404032C9C859D8294A4030630AD6385B404032C9C859D8294A40
25089	12147	32.736316000000002	32.759006999999997	52.536613000000003	52.528691999999999	Культуры	0103000020E61000000100000005000000C2C2499A3F5E404013D4F02DAC434A40C2C2499A3F5E4040E2CD1ABCAF444A40B037312427614040E2CD1ABCAF444A40B03731242761404013D4F02DAC434A40C2C2499A3F5E404013D4F02DAC434A40
24420	11723	33.124316	33.147824999999997	52.704421000000004	52.692383	Новая	0103000020E610000001000000050000004D2F3196E98F404037A79201A0584A404D2F3196E98F4040CDCEA2772A5A4A40FE43FAEDEB924040CDCEA2772A5A4A40FE43FAEDEB92404037A79201A0584A404D2F3196E98F404037A79201A0584A40
25282	51151	32.776138000000003	32.813625000000002	52.503487999999997	52.477733000000001	Советская	0103000020E6100000010000000500000068976F7D58634040289CDD5A263D4A4068976F7D58634040D7F6764B72404A40A01A2FDD24684040D7F6764B72404A40A01A2FDD24684040289CDD5A263D4A4068976F7D58634040289CDD5A263D4A40
24754	12394	32.629111000000002	32.661512999999999	52.556055000000001	52.530543999999999	Центральная	0103000020E61000000100000005000000E54691B586504040658BA4DDE8434A40E54691B5865040407EE36BCF2C474A407E703E75AC5440407EE36BCF2C474A407E703E75AC544040658BA4DDE8434A40E54691B586504040658BA4DDE8434A40
24418	11617	32.983649	33.006197	52.707962999999999	52.697141999999999	Центральная	0103000020E610000001000000050000001EDFDE35E87D40408255F5F23B594A401EDFDE35E87D404097E315889E5A4A40AA2A3410CB80404097E315889E5A4A40AA2A3410CB8040408255F5F23B594A401EDFDE35E87D40408255F5F23B594A40
24634	12279	32.504666999999998	32.531571999999997	52.673192999999998	52.652535999999998	Комсомольская	0103000020E610000001000000050000006A2FA2ED9840404038BBB54C86534A406A2FA2ED98404040B4722F302B564A4012BC218D0A444040B4722F302B564A4012BC218D0A44404038BBB54C86534A406A2FA2ED9840404038BBB54C86534A40
25077	11509	32.583261	32.613804000000002	52.447505	52.419519999999999	Магистральная	0103000020E610000001000000050000002104E44BA84A40404B02D4D4B2354A402104E44BA84A4040F3E505D847394A40B6132521914E4040F3E505D847394A40B6132521914E40404B02D4D4B2354A402104E44BA84A40404B02D4D4B2354A40
24645	12887	32.854705000000003	32.905504000000001	52.525798999999999	52.508822000000002	Магистральная	0103000020E61000000100000005000000255D33F9666D40401FBE4C1421414A40255D33F9666D40407FA2B2614D434A40D732198EE77340407FA2B2614D434A40D732198EE77340401FBE4C1421414A40255D33F9666D40401FBE4C1421414A40
24836	11891	32.829588000000001	32.865997	52.603237	52.579903999999999	площадь Ленина	0103000020E61000000100000005000000B89388F02F6A4040E868554B3A4A4A40B89388F02F6A40405B5EB9DE364D4A4091B75CFDD86E40405B5EB9DE364D4A4091B75CFDD86E4040E868554B3A4A4A40B89388F02F6A4040E868554B3A4A4A40
24493	13359	32.855584999999998	32.897050999999998	52.344144	52.318311000000001	Садовая	0103000020E610000001000000050000005DF92CCF836D4040817A336ABE284A405DF92CCF836D4040AC8E1CE90C2C4A400BEC3191D2724040AC8E1CE90C2C4A400BEC3191D2724040817A336ABE284A405DF92CCF836D4040817A336ABE284A40
24615	13007	32.576227000000003	32.602215000000001	52.643127999999997	52.621735000000001	Садовая	0103000020E610000001000000050000003E096CCEC1494040A8E33103954F4A403E096CCEC14940402992AF0452524A4090149161154D40402992AF0452524A4090149161154D4040A8E33103954F4A403E096CCEC1494040A8E33103954F4A40
24419	11603	32.983792999999999	33.004589000000003	52.751415999999999	52.733381000000001	Школьная	0103000020E610000001000000050000005184D4EDEC7D4040FF40B96DDF5D4A405184D4EDEC7D404077D844662E604A40EF75525F9680404077D844662E604A40EF75525F96804040FF40B96DDF5D4A405184D4EDEC7D4040FF40B96DDF5D4A40
24718	11258	32.63212	32.69361	52.374316	52.353276000000001	 Площадь 1 Мая	0103000020E61000000100000005000000E292E34EE9504040193BE125382D4A40E292E34EE95040404D2F3196E92F4A40DB166536C85840404D2F3196E92F4A40DB166536C8584040193BE125382D4A40E292E34EE9504040193BE125382D4A40
25138	11354	32.653984999999999	32.692433000000001	52.334377000000003	52.322544000000001	Центральная	0103000020E610000001000000050000008B89CDC7B5534040B1C22D1F49294A408B89CDC7B55340406EC493DDCC2A4A40E9D500A5A15840406EC493DDCC2A4A40E9D500A5A1584040B1C22D1F49294A408B89CDC7B5534040B1C22D1F49294A40
25137	13332	32.860022999999998	32.896566	52.321460000000002	52.288271000000002	Комсомольская	0103000020E610000001000000050000006667D13B156E40404FB16A10E6244A406667D13B156E4040707CED9925294A404F5AB8ACC2724040707CED9925294A404F5AB8ACC27240404FB16A10E6244A406667D13B156E40404FB16A10E6244A40
24700	10233	34.556527000000003	34.593429999999998	52.237810000000003	52.217697000000001	Центральная	0103000020E61000000100000005000000A62BD8463C474140FAB7CB7EDD1B4A40A62BD8463C474140B554DE8E701E4A408E3BA583F54B4140B554DE8E701E4A408E3BA583F54B4140FAB7CB7EDD1B4A40A62BD8463C474140FAB7CB7EDD1B4A40
24582	10012	34.406365000000001	34.427160999999998	52.260824	52.235846000000002	Лушникова	0103000020E61000000100000005000000999EB0C4033441403B72A433301E4A40999EB0C40334414086014BAE62214A4036902E36AD36414086014BAE62214A4036902E36AD3641403B72A433301E4A40999EB0C4033441403B72A433301E4A40
24447	9711	34.199832999999998	34.231282999999998	51.986204999999998	51.9666	Парковая	0103000020E61000000100000005000000AED4B3209419414024287E8CB9FB4940AED4B320941941406A1327F73BFE4940758F6CAE9A1D41406A1327F73BFE4940758F6CAE9A1D414024287E8CB9FB4940AED4B3209419414024287E8CB9FB4940
25172	51125	34.377682	34.397461999999997	51.898425000000003	51.884200999999997	Новая	0103000020E61000000100000005000000D9243FE257304140950B957F2DF14940D9243FE25730414054742497FFF249408DB3E908E032414054742497FFF249408DB3E908E0324140950B957F2DF14940D9243FE257304140950B957F2DF14940
25135	51108	34.570658000000002	34.602457999999999	52.099961	52.087218999999997	Молодежная	0103000020E61000000100000005000000B39943520B4941407F4B00FE290B4A40B39943520B4941400FF0A485CB0C4A40569BFF571D4D41400FF0A485CB0C4A40569BFF571D4D41407F4B00FE290B4A40B39943520B4941407F4B00FE290B4A40
25071	10705	34.470162999999999	34.507353000000002	52.173865999999997	52.104675	Советская	0103000020E6100000010000000500000006651A4D2E3C4140BADA8AFD650D4A4006651A4D2E3C414073F1B73D41164A4085436FF1F040414073F1B73D41164A4085436FF1F0404140BADA8AFD650D4A4006651A4D2E3C4140BADA8AFD650D4A40
24905	10705	34.470162999999999	34.507353000000002	52.173865999999997	52.104675	С.Щедрина	0103000020E6100000010000000500000006651A4D2E3C4140BADA8AFD650D4A4006651A4D2E3C414073F1B73D41164A4085436FF1F040414073F1B73D41164A4085436FF1F0404140BADA8AFD650D4A4006651A4D2E3C4140BADA8AFD650D4A40
24904	10705	34.470162999999999	34.507353000000002	52.173865999999997	52.104675	Ленина	0103000020E6100000010000000500000006651A4D2E3C4140BADA8AFD650D4A4006651A4D2E3C414073F1B73D41164A4085436FF1F040414073F1B73D41164A4085436FF1F0404140BADA8AFD650D4A4006651A4D2E3C4140BADA8AFD650D4A40
24813	48412	34.217117000000002	34.240482	51.999153999999997	51.989772000000002	Садовая	0103000020E61000000100000005000000EC33677DCA1B41408E3F51D9B0FE4940EC33677DCA1B414073D53C47E4FF49406AA33A1DC81E414073D53C47E4FF49406AA33A1DC81E41408E3F51D9B0FE4940EC33677DCA1B41408E3F51D9B0FE4940
24747	9840	34.352393999999997	34.379496000000003	51.987924999999997	51.970999999999997	Центральная	0103000020E610000001000000050000003FA7203F1B2D41403F355EBA49FC49403FA7203F1B2D41404DF38E5374FE49403E7B2E53933041404DF38E5374FE49403E7B2E53933041403F355EBA49FC49403FA7203F1B2D41403F355EBA49FC4940
24809	9503	34.115724	34.165329	52.067242999999998	52.043945000000001	Молодежная	0103000020E6100000010000000500000060AE450BD00E41404FE960FD9F054A4060AE450BD00E414045F12A6B9B084A404A0A2C802915414045F12A6B9B084A404A0A2C80291541404FE960FD9F054A4060AE450BD00E41404FE960FD9F054A40
24811	9567	34.224635999999997	34.255887999999999	52.097006999999998	52.074561000000003	Центральная	0103000020E610000001000000050000008BC058DFC01C41404E4700378B094A408BC058DFC01C4140D53DB2B96A0C4A402CB81FF0C0204140D53DB2B96A0C4A402CB81FF0C02041404E4700378B094A408BC058DFC01C41404E4700378B094A40
24577	47727	34.323225999999998	34.356777999999998	52.105111999999998	52.087119000000001	65-й Армии	0103000020E61000000100000005000000C39B35785F2941401CEE23B7260B4A40C39B35785F29414065355D4F740D4A4055F7C8E6AA2D414065355D4F740D4A4055F7C8E6AA2D41401CEE23B7260B4A40C39B35785F2941401CEE23B7260B4A40
75039	47495	34.310901000000001	34.321114999999999	52.110643000000003	52.103098000000003	Школьная	0103000020E6100000010000000500000098A59D9ACB2741403A24B550320D4A4098A59D9ACB2741400344C18C290E4A40A5A0DB4B1A2941400344C18C290E4A40A5A0DB4B1A2941403A24B550320D4A4098A59D9ACB2741403A24B550320D4A40
24824	48583	34.45234	34.511170999999997	52.236944000000001	52.199745	Молодежная	0103000020E610000001000000050000001956F146E63941400F45813E91194A401956F146E6394140E17D552E541E4A40F1D4230D6E414140E17D552E541E4A40F1D4230D6E4141400F45813E91194A401956F146E63941400F45813E91194A40
25107	10370	34.359679	34.376010999999998	51.879848000000003	51.858477000000001	8 Марта	0103000020E610000001000000050000006C0723F6092E414021AF0793E2ED49406C0723F6092E4140BBB9F8DB9EF04940D7F7E12021304140BBB9F8DB9EF04940D7F7E1202130414021AF0793E2ED49406C0723F6092E414021AF0793E2ED4940
24785	51065	34.408026999999997	34.441318000000003	52.163609000000001	52.145623000000001	Тихая Долина	0103000020E6100000010000000500000047718E3A3A344140D04543C6A3124A4047718E3A3A344140672AC423F1144A406D91B41B7D384140672AC423F1144A406D91B41B7D384140D04543C6A3124A4047718E3A3A344140D04543C6A3124A40
24594	10476	34.253346000000001	34.278103000000002	51.937936999999998	51.917627000000003	Центральная	0103000020E61000000100000005000000454948A46D2041409B7631CD74F54940454948A46D204140AB5AD2510EF84940B2F50CE198234140AB5AD2510EF84940B2F50CE1982341409B7631CD74F54940454948A46D2041409B7631CD74F54940
24814	48645	34.561432000000003	34.578383000000002	52.178339000000001	52.166116000000002	Провинциальная	0103000020E61000000100000005000000C576F700DD474140D2AB014A43154A40C576F700DD474140F94CF6CFD3164A40FCC74274084A4140F94CF6CFD3164A40FCC74274084A4140D2AB014A43154A40C576F700DD474140D2AB014A43154A40
24659	9739	34.470306999999998	34.488667999999997	52.069268999999998	52.052197999999997	Школьный переулок	0103000020E61000000100000005000000390A1005333C414053758F6CAE064A40390A1005333C414035D07CCEDD084A40054D4BAC8C3E414035D07CCEDD084A40054D4BAC8C3E414053758F6CAE064A40390A1005333C414053758F6CAE064A40
24986	10127	34.270530000000001	34.335515000000001	52.253160999999999	52.236060999999999	Копылова	0103000020E610000001000000050000001F4B1FBAA0224140376E313F371E4A401F4B1FBAA0224140B3CF639467204A40A228D027F22A4140B3CF639467204A40A228D027F22A4140376E313F371E4A401F4B1FBAA0224140376E313F371E4A40
24983	48778	34.469346000000002	34.48706	52.199567999999999	52.190939999999998	Молодежная	0103000020E6100000010000000500000014419C87133C4140C6BFCFB870184A4014419C87133C414000AAB8718B194A404A9869FB573E414000AAB8718B194A404A9869FB573E4140C6BFCFB870184A4014419C87133C4140C6BFCFB870184A40
81115	62084	34.060971000000002	34.744455000000002	52.330294000000002	51.843623000000001	Миловидова	0103000020E610000001000000050000009180D1E5CD074140A393A5D6FBEB49409180D1E5CD0741405308E412472A4A40FE2B2B4D4A5F41405308E412472A4A40FE2B2B4D4A5F4140A393A5D6FBEB49409180D1E5CD074140A393A5D6FBEB4940
24401	10515	34.643951000000001	34.702008999999997	52.121985000000002	52.092115999999997	Ульянова	0103000020E61000000100000005000000FE9C82FC6C5241401BB80375CA0B4A40FE9C82FC6C52414021CD58349D0F4A40B33F506EDB59414021CD58349D0F4A40B33F506EDB5941401BB80375CA0B4A40FE9C82FC6C5241401BB80375CA0B4A40
25163	51121	34.530557000000002	34.562806000000002	52.319609999999997	52.301281000000003	Центральная	0103000020E61000000100000005000000FAD4B14AE9434140FEF3346090264A40FAD4B14AE9434140BEBC00FBE8284A400DFFE9060A484140BEBC00FBE8284A400DFFE9060A484140FEF3346090264A40FAD4B14AE9434140FEF3346090264A40
25156	51119	34.644077000000003	34.683190000000003	52.163310000000003	52.139052	Центральная	0103000020E610000001000000050000008B8D791D71524140C138B874CC114A408B8D791D715241400D8E9257E7144A40257A19C5725741400D8E9257E7144A40257A19C572574140C138B874CC114A408B8D791D71524140C138B874CC114A40
24486	9248	33.720419999999997	33.773178000000001	53.968871	53.936973999999999	Центральная	0103000020E6100000010000000500000031B1F9B836DC4040E59997C3EEF74A4031B1F9B836DC40407B8505F703FC4A404CFE277FF7E240407B8505F703FC4A404CFE277FF7E24040E59997C3EEF74A4031B1F9B836DC4040E59997C3EEF74A40
24893	9462	33.372799000000001	33.405335999999998	53.853386	53.839925000000001	Школьная	0103000020E61000000100000005000000A27DACE0B7AF4040E10B93A982EB4A40A27DACE0B7AF4040A06EA0C03BED4A401BF2CF0CE2B34040A06EA0C03BED4A401BF2CF0CE2B34040E10B93A982EB4A40A27DACE0B7AF4040E10B93A982EB4A40
24490	48334	33.357877999999999	33.386767999999996	53.896326000000002	53.884089000000003	Специалистов	0103000020E610000001000000050000009CFA40F2CEAD40406EE00ED429F14A409CFA40F2CEAD4040FA4674CFBAF24A40D591239D81B14040FA4674CFBAF24A40D591239D81B140406EE00ED429F14A409CFA40F2CEAD40406EE00ED429F14A40
24686	9203	33.782457999999998	33.813180000000003	53.856498000000002	53.836578000000003	Школьная	0103000020E610000001000000050000002D3F709527E44040CC46E7FC14EB4A402D3F709527E44040728BF9B9A1ED4A4072E1404816E84040728BF9B9A1ED4A4072E1404816E84040CC46E7FC14EB4A402D3F709527E44040CC46E7FC14EB4A40
24786	48209	33.659621999999999	33.694881000000002	53.898972999999998	53.882061999999998	Центральная	0103000020E610000001000000050000006EDC627E6ED44040AD855968E7F04A406EDC627E6ED44040567E198C11F34A404FCE50DCF1D84040567E198C11F34A404FCE50DCF1D84040AD855968E7F04A406EDC627E6ED44040AD855968E7F04A40
24479	8912	33.523904999999999	33.583013999999999	53.818381000000002	53.788921999999999	Ленина	0103000020E61000000100000005000000FE9AAC510FC34040268C6665FBE44A40FE9AAC510FC340407A5567B5C0E84A40198EE733A0CA40407A5567B5C0E84A40198EE733A0CA4040268C6665FBE44A40FE9AAC510FC34040268C6665FBE44A40
24552	10524	33.555579000000002	33.586643000000002	53.885415999999999	53.870961999999999	Молодежная	0103000020E6100000010000000500000015AC71361DC740408507CDAE7BEF4A4015AC71361DC7404075ADBD4F55F14A40B3B6291E17CB404075ADBD4F55F14A40B3B6291E17CB40408507CDAE7BEF4A4015AC71361DC740408507CDAE7BEF4A40
24488	48323	33.503287999999998	33.524020999999998	53.991269000000003	53.977429000000001	Школьная	0103000020E61000000100000005000000103CBEBD6BC04040BC94BA641CFD4A40103CBEBD6BC04040F24410E7E1FE4A4067B5C01E13C34040F24410E7E1FE4A4067B5C01E13C34040BC94BA641CFD4A40103CBEBD6BC04040BC94BA641CFD4A40
24685	9081	33.628036999999999	33.653486999999998	53.713185000000003	53.694758999999998	Набережная	0103000020E61000000100000005000000C7D6338463D0404003CDE7DCEDD84A40C7D6338463D04040B77F65A549DB4A403AAE4676A5D34040B77F65A549DB4A403AAE4676A5D3404003CDE7DCEDD84A40C7D6338463D0404003CDE7DCEDD84A40
25090	48551	33.603810000000003	33.617984999999997	53.835962000000002	53.827655999999998	Молодежная	0103000020E61000000100000005000000B77F65A549CD4040492BBEA1F0E94A40B77F65A549CD4040715985CD00EB4A409335EA211ACF4040715985CD00EB4A409335EA211ACF4040492BBEA1F0E94A40B77F65A549CD4040492BBEA1F0E94A40
24487	9341	33.546847999999997	33.573338999999997	53.951363000000001	53.933841000000001	Советская	0103000020E6100000010000000500000006F1811DFFC54040FC54151A88F74A4006F1811DFFC54040EECF4543C6F94A40BB421F2C63C94040EECF4543C6F94A40BB421F2C63C94040FC54151A88F74A4006F1811DFFC54040FC54151A88F74A40
24485	48137	33.673690000000001	33.729501999999997	53.769379999999998	53.748896000000002	имени Старостина	0103000020E6100000010000000500000035D252793BD64040780DFAD2DBDF4A4035D252793BD640402619390B7BE24A40EC2E505260DD40402619390B7BE24A40EC2E505260DD4040780DFAD2DBDF4A4035D252793BD64040780DFAD2DBDF4A40
24729	7714	33.423912999999999	33.446613999999997	53.096722999999997	53.083489	Тупицина	0103000020E61000000100000005000000B4ACFBC742B64040B2497EC4AF8A4A40B4ACFBC742B64040B0E2546B618C4A40C6F7C5A52AB94040B0E2546B618C4A40C6F7C5A52AB94040B2497EC4AF8A4A40B4ACFBC742B64040B2497EC4AF8A4A40
24560	8725	33.320813999999999	33.341043999999997	52.974308000000001	52.959387	Школьная	0103000020E61000000100000005000000AA0CE36E10A94040919A7631CD7A4A40AA0CE36E10A94040971DE21FB67C4A409E3F6D54A7AB4040971DE21FB67C4A409E3F6D54A7AB4040919A7631CD7A4A40AA0CE36E10A94040919A7631CD7A4A40
24851	10430	33.254572000000003	33.273014000000003	52.880519	52.868127000000001	Лесная	0103000020E61000000100000005000000193DB7D095A0404026E318C91E6F4A40193DB7D095A04040D940BAD8B4704A40D2AC6C1FF2A24040D940BAD8B4704A40D2AC6C1FF2A2404026E318C91E6F4A40193DB7D095A0404026E318C91E6F4A40
24842	47588	33.387611999999997	33.401032999999998	53.050066000000001	53.043418000000003	Клубная	0103000020E61000000100000005000000C1C41F459DB14040640795B88E854A40C1C41F459DB140401E520C9068864A40F2CEA10C55B340401E520C9068864A40F2CEA10C55B34040640795B88E854A40C1C41F459DB14040640795B88E854A40
25120	8073	33.236848000000002	33.263554999999997	53.051943999999999	53.039769	Молодежная	0103000020E61000000100000005000000BF0F0709519E404083328D2617854A40BF0F0709519E4040999CDA19A6864A4040D9942BBCA14040999CDA19A6864A4040D9942BBCA1404083328D2617854A40BF0F0709519E404083328D2617854A40
25205	51139	33.266824999999997	33.296028999999997	52.994697000000002	52.979984999999999	Центральная	0103000020E61000000100000005000000AA60545227A2404008C90226707D4A40AA60545227A24040F436363B527F4A4073D53C47E4A54040F436363B527F4A4073D53C47E4A5404008C90226707D4A40AA60545227A2404008C90226707D4A40
25202	51136	33.586939000000001	33.615704000000001	52.828795	52.807406999999998	Школьный переулок	0103000020E610000001000000050000009CDF30D120CB4040DEC7D11C59674A409CDF30D120CB40404E0B5EF4156A4A4019028063CFCE40404E0B5EF4156A4A4019028063CFCE4040DEC7D11C59674A409CDF30D120CB4040DEC7D11C59674A40
24551	47507	33.250259999999997	33.272295999999997	52.907091000000001	52.895786999999999	Колхозная	0103000020E610000001000000050000009CBF098508A040404A97FE25A9724A409CBF098508A040407BBFD18E1B744A40726A6798DAA240407BBFD18E1B744A40726A6798DAA240404A97FE25A9724A409CBF098508A040404A97FE25A9724A40
25049	8534	33.440451000000003	33.478414000000001	52.834960000000002	52.799011999999998	Щемелинина	0103000020E61000000100000005000000C93EC8B260B84040478E740646664A40C93EC8B260B84040EDBB22F8DF6A4A406AF981AB3CBD4040EDBB22F8DF6A4A406AF981AB3CBD4040478E740646664A40C93EC8B260B84040478E740646664A40
25267	51150	33.48516	33.514947999999997	53.002453000000003	52.969557000000002	улица Советская	0103000020E61000000100000005000000E7A90EB919BE4040CF4D9B711A7C4A40E7A90EB919BE40407863416150804A40FF91E9D0E9C140407863416150804A40FF91E9D0E9C14040CF4D9B711A7C4A40E7A90EB919BE4040CF4D9B711A7C4A40
24965	47994	33.352730999999999	33.388663000000001	52.869083000000003	52.84722	Центральная	0103000020E6100000010000000500000087A4164A26AD4040314278B4716C4A4087A4164A26AD40403A419B1C3E6F4A4027158DB5BFB140403A419B1C3E6F4A4027158DB5BFB14040314278B4716C4A4087A4164A26AD4040314278B4716C4A40
25177	51126	33.527299999999997	33.555418000000003	52.748427999999997	52.732334000000002	Почепская	0103000020E610000001000000050000002497FF907EC34040DBDFD91EBD5D4A402497FF907EC3404091B41B7DCC5F4A400CCEE0EF17C7404091B41B7DCC5F4A400CCEE0EF17C74040DBDFD91EBD5D4A402497FF907EC34040DBDFD91EBD5D4A40
24689	47334	33.391736000000002	33.405667999999999	52.701932999999997	52.698140000000002	Володарского 	0103000020E610000001000000050000003B55BE6724B24040C503CAA65C594A403B55BE6724B24040D87DC7F0D8594A405184D4EDECB34040D87DC7F0D8594A405184D4EDECB34040C503CAA65C594A403B55BE6724B24040C503CAA65C594A40
24546	6463	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	Усиевича	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
25068	6463	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	Стародубская	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
24768	6463	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	Октябрьская площадь	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
24778	6463	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	Ново-Полянская	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
24741	6463	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	Ново-Затинская	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
24825	6463	33.409387000000002	33.491008000000001	52.957341999999997	52.892108999999998	Колхозная	0103000020E610000001000000050000002B3410CB66B44040CFBBB1A030724A402B3410CB66B440402A8BC22E8A7A4A408509A359D9BE40402A8BC22E8A7A4A408509A359D9BE4040CFBBB1A030724A402B3410CB66B44040CFBBB1A030724A40
24801	8002	33.235706999999998	33.249792999999997	53.015602999999999	53.006056000000001	Польниковская	0103000020E610000001000000050000001938A0A52B9E4040E8F86871C6804A401938A0A52B9E4040185C7347FF814A4086E28E37F99F4040185C7347FF814A4086E28E37F99F4040E8F86871C6804A401938A0A52B9E4040E8F86871C6804A40
24600	7451	33.163752000000002	33.197619000000003	52.955655	52.940832	Школьная	0103000020E61000000100000005000000CA5356D3F5944040E083D72E6D784A40CA5356D3F594404023A12DE7527A4A40BC0853944B99404023A12DE7527A4A40BC0853944B994040E083D72E6D784A40CA5356D3F5944040E083D72E6D784A40
25141	51110	33.565109999999997	33.637030000000003	52.911821000000003	52.889746000000002	Советская	0103000020E610000001000000050000003F52448655C8404098DF6932E3714A403F52448655C840402C67EF8CB6744A401349F4328AD140402C67EF8CB6744A401349F4328AD1404098DF6932E3714A403F52448655C8404098DF6932E3714A40
24999	7539	33.589796	33.614804999999997	53.051640999999996	53.036709000000002	Центральная	0103000020E61000000100000005000000E3A7716F7ECB4040043C69E1B2844A40E3A7716F7ECB4040FD101B2C9C864A40693524EEB1CE4040FD101B2C9C864A40693524EEB1CE4040043C69E1B2844A40E3A7716F7ECB4040043C69E1B2844A40
24460	47365	33.278098999999997	33.298229999999997	52.746645999999998	52.737492000000003	Школьная	0103000020E6100000010000000500000070067FBF98A34040E4874A23665E4A4070067FBF98A3404038D89B18925F4A40D15790662CA6404038D89B18925F4A40D15790662CA64040E4874A23665E4A4070067FBF98A34040E4874A23665E4A40
24614	7837	33.741790999999999	33.786321000000001	52.885708000000001	52.865696999999997	Центральная	0103000020E61000000100000005000000CBBBEA01F3DE4040669FC728CF6E4A40CBBBEA01F3DE40401DE736E15E714A403A94A12AA6E440401DE736E15E714A403A94A12AA6E44040669FC728CF6E4A40CBBBEA01F3DE4040669FC728CF6E4A40
24923	7729	33.719521999999998	33.745465000000003	52.955145000000002	52.936984000000002	2-й переулок Толстого	0103000020E610000001000000050000005260014C19DC404009707A17EF774A405260014C19DC40400EF8FC30427A4A4005A8A9656BDF40400EF8FC30427A4A4005A8A9656BDF404009707A17EF774A405260014C19DC404009707A17EF774A40
24959	47312	33.239884000000004	33.274343999999999	52.796159000000003	52.776999000000004	Гагарина	0103000020E61000000100000005000000B66AD784B49E40402A0307B474634A40B66AD784B49E404042B5C189E8654A404AED45B41DA3404042B5C189E8654A404AED45B41DA340402A0307B474634A40B66AD784B49E40402A0307B474634A40
24804	8245	33.394573999999999	33.413879000000001	52.889761999999997	52.874665999999998	Набережная	0103000020E610000001000000050000000BED9C6681B240402976340EF56F4A400BED9C6681B240409D9CA1B8E3714A4027C0B0FCF9B440409D9CA1B8E3714A4027C0B0FCF9B440402976340EF56F4A400BED9C6681B240402976340EF56F4A40
25038	47356	33.177407000000002	33.191383999999999	52.780714000000003	52.771399000000002	Школьная	0103000020E610000001000000050000006E8AC745B59640406495D233BD624A406E8AC745B5964040C2C3B46FEE634A40247D5A457F984040C2C3B46FEE634A40247D5A457F9840406495D233BD624A406E8AC745B59640406495D233BD624A40
24466	47458	33.327981999999999	33.363142000000003	52.801091999999997	52.788257999999999	Набережная 	0103000020E610000001000000050000009DD66D50FBA94040BA675DA3E5644A409DD66D50FBA940402A8BC22E8A664A40EBE6E26F7BAE40402A8BC22E8A664A40EBE6E26F7BAE4040BA675DA3E5644A409DD66D50FBA94040BA675DA3E5644A40
24478	48074	33.345886	33.378908000000003	52.959116000000002	52.943257000000003	Школьная	0103000020E61000000100000005000000771211FE45AC40408E5C37A5BC784A40771211FE45AC404001892650C47A4A40AD18AE0E80B0404001892650C47A4A40AD18AE0E80B040408E5C37A5BC784A40771211FE45AC40408E5C37A5BC784A40
25169	51123	33.391888000000002	33.436884999999997	53.013765999999997	52.998491000000001	улица Почепская	0103000020E61000000100000005000000F1D8CF6229B24040D82C978DCE7F4A40F1D8CF6229B24040FBE59315C3814A40758E01D9EBB74040FBE59315C3814A40758E01D9EBB74040D82C978DCE7F4A40F1D8CF6229B24040D82C978DCE7F4A40
24876	47549	33.552551999999999	33.578476999999999	53.078789	53.055430000000001	Дмитировская	0103000020E6100000010000000500000071AB2006BAC64040D09B8A5418874A4071AB2006BAC640406C2409C2158A4A407D3ECA880BCA40406C2409C2158A4A407D3ECA880BCA4040D09B8A5418874A4071AB2006BAC64040D09B8A5418874A40
24806	8440	33.466413000000003	33.491717999999999	52.980401999999998	52.957700000000003	Клубный	0103000020E61000000100000005000000F2B6D26BB3BB40408AB0E1E9957A4A40F2B6D26BB3BB40406C770FD07D7D4A40616D8C9DF0BE40406C770FD07D7D4A40616D8C9DF0BE40408AB0E1E9957A4A40F2B6D26BB3BB40408AB0E1E9957A4A40
24875	47788	33.256008999999999	33.270059000000003	53.067383999999997	53.052539000000003	Центральная	0103000020E61000000100000005000000A73D25E7C4A04040DD611399B9864A40A73D25E7C4A040400723F609A0884A40C87E164B91A240400723F609A0884A40C87E164B91A24040DD611399B9864A40A73D25E7C4A04040DD611399B9864A40
24820	32366	33.18815	33.202424999999998	52.902256999999999	52.893467000000001	им. Новикова	0103000020E61000000100000005000000075F984C1598404012876C205D724A40075F984C1598404025CB49287D734A404772F90FE999404025CB49287D734A404772F90FE999404012876C205D724A40075F984C1598404012876C205D724A40
24884	51075	33.506315999999998	33.521811999999997	53.045566999999998	53.035322999999998	Громышева	0103000020E6100000010000000500000084B872F6CEC04040F7E5CC7685844A4084B872F6CEC040406F63B323D5854A40865451BCCAC240406F63B323D5854A40865451BCCAC24040F7E5CC7685844A4084B872F6CEC04040F7E5CC7685844A40
24714	7289	33.478648	33.521757999999998	52.930742000000002	52.911517000000003	Почепская	0103000020E61000000100000005000000DD25715644BD4040C05FCC96AC744A40DD25715644BD4040BF81C98D22774A40933655F7C8C24040BF81C98D22774A40933655F7C8C24040C05FCC96AC744A40DD25715644BD4040C05FCC96AC744A40
24553	8161	33.335070000000002	33.366591999999997	52.902278000000003	52.886963999999999	 Советская	0103000020E6100000010000000500000074EFE192E3AA40405B5D4E0988714A4074EFE192E3AA40403DF372D87D734A40D47C957CECAE40403DF372D87D734A40D47C957CECAE40405B5D4E0988714A4074EFE192E3AA40405B5D4E0988714A40
24567	8745	33.282463999999997	33.301814	52.958243000000003	52.945112999999999	Садовая	0103000020E610000001000000050000000F26C5C727A4404021037976F9784A400F26C5C727A440407B4FE5B4A77A4A40CBBC55D7A1A640407B4FE5B4A77A4A40CBBC55D7A1A6404021037976F9784A400F26C5C727A4404021037976F9784A40
24864	7179	33.370894999999997	33.407321000000003	52.764664000000003	52.728499999999997	Клубная	0103000020E61000000100000005000000FD9FC37C79AF40406891ED7C3F5D4A40FD9FC37C79AF4040DB368C82E0614A40ADFC321823B44040DB368C82E0614A40ADFC321823B440406891ED7C3F5D4A40FD9FC37C79AF40406891ED7C3F5D4A40
24464	47389	33.219923999999999	33.249181999999998	53.118442999999999	53.098626000000003	Центральная	0103000020E6100000010000000500000081CD3978269C40408544DAC69F8C4A4081CD3978269C404056B8E523298F4A403D601E32E59F404056B8E523298F4A403D601E32E59F40408544DAC69F8C4A4081CD3978269C40408544DAC69F8C4A40
24795	47412	33.181511999999998	33.203583000000002	53.096029999999999	53.084695000000004	Мира	0103000020E6100000010000000500000070EA03C93B9740403F912749D78A4A4070EA03C93B974040AAB706B64A8C4A40C382FB010F9A4040AAB706B64A8C4A40C382FB010F9A40403F912749D78A4A4070EA03C93B9740403F912749D78A4A40
24826	6897	33.234557000000002	33.273274999999998	52.757939999999998	52.726657000000003	Ленина	0103000020E610000001000000050000002106BAF6059E40406A34B918035D4A402106BAF6059E4040452A8C2D04614A403EE8D9ACFAA24040452A8C2D04614A403EE8D9ACFAA240406A34B918035D4A402106BAF6059E40406A34B918035D4A40
24432	7636	33.327398000000002	33.350377000000002	53.047305000000001	53.030926000000001	Заречная	0103000020E610000001000000050000004E637B2DE8A940404D4C1762F5834A404E637B2DE8A94040F9F719170E864A40A3224E27D9AC4040F9F719170E864A40A3224E27D9AC40404D4C1762F5834A404E637B2DE8A940404D4C1762F5834A40
25062	6268	33.250134000000003	33.289183999999999	52.679029999999997	52.652569	Бойня	0103000020E6100000010000000500000010CF126404A0404014B1886187534A4010CF126404A040405E807D74EA564A40634337FB03A540405E807D74EA564A40634337FB03A5404014B1886187534A4010CF126404A0404014B1886187534A40
24650	5875	33.354500000000002	33.394952000000004	52.642991000000002	52.625813999999998	 Советская	0103000020E610000001000000050000004C37894160AD404081B053AC1A504A404C37894160AD4040A94F72874D524A40B2BE81C98DB24040A94F72874D524A40B2BE81C98DB2404081B053AC1A504A404C37894160AD404081B053AC1A504A40
24902	6162	33.281511999999999	33.303987999999997	52.409269999999999	52.395989999999998	Кооперативная	0103000020E610000001000000050000003DB7D09508A4404082C5E1CCAF324A403DB7D09508A44040F19D98F562344A402F302B14E9A64040F19D98F562344A402F302B14E9A6404082C5E1CCAF324A403DB7D09508A4404082C5E1CCAF324A40
24658	4492	33.199173000000002	33.219484000000001	52.546624999999999	52.537616	Светлая	0103000020E61000000100000005000000849F38807E99404036E7E099D0444A40849F38807E9940408716D9CEF7454A4065FF3C0D189C40408716D9CEF7454A4065FF3C0D189C404036E7E099D0444A40849F38807E99404036E7E099D0444A40
24985	5995	33.259486000000003	33.289202000000003	52.518380000000001	52.501607999999997	Первомайская	0103000020E610000001000000050000008BE255D636A14040BBB4E1B034404A408BE255D636A1404043739D465A424A400AF8359204A5404043739D465A424A400AF8359204A54040BBB4E1B034404A408BE255D636A14040BBB4E1B034404A40
24934	5665	33.367615999999998	33.396838000000002	52.591689000000002	52.576954000000001	Новая	0103000020E6100000010000000500000040BE840A0EAF4040F0A5F0A0D9494A4040BE840A0EAF404094331477BC4B4A40B0E76B96CBB2404094331477BC4B4A40B0E76B96CBB24040F0A5F0A0D9494A4040BE840A0EAF4040F0A5F0A0D9494A40
24586	6212	33.331000000000003	33.346837999999998	52.379721000000004	52.363363	Садовя	0103000020E61000000100000005000000EE7C3F355EAA4040C9C9C4AD822E4A40EE7C3F355EAA40405E4D9EB29A304A404981053065AC40405E4D9EB29A304A404981053065AC4040C9C9C4AD822E4A40EE7C3F355EAA4040C9C9C4AD822E4A40
24920	51082	33.139471	33.175457000000002	52.560172000000001	52.548673000000001	Козина	0103000020E61000000100000005000000C6DE8B2FDA9140405F99B7EA3A464A40C6DE8B2FDA914040451152B7B3474A40596DFE5F75964040451152B7B3474A40596DFE5F759640405F99B7EA3A464A40C6DE8B2FDA9140405F99B7EA3A464A40
25024	5012	33.175528999999997	33.212189000000002	52.721634000000002	52.704360999999999	Воробьевка	0103000020E61000000100000005000000F23FF9BB77964040F7C95180285A4A40F23FF9BB7796404041D7BE805E5C4A4015C95702299B404041D7BE805E5C4A4015C95702299B4040F7C95180285A4A40F23FF9BB77964040F7C95180285A4A40
24817	5858	33.433416999999999	33.463197000000001	52.590885	52.577742000000001	Заречная	0103000020E61000000100000005000000E54350357AB7404048C32973F3494A40E54350357AB740403659A31EA24B4A407B4D0F0A4ABB40403659A31EA24B4A407B4D0F0A4ABB404048C32973F3494A40E54350357AB7404048C32973F3494A40
24815	20238	33.079625	33.09796	52.643357000000002	52.633253000000003	пер. Брянский	0103000020E61000000100000005000000D578E926318A4040058C2E6F0E514A40D578E926318A40408B53AD8559524A4078280AF4898C40408B53AD8559524A4078280AF4898C4040058C2E6F0E514A40D578E926318A4040058C2E6F0E514A40
24724	20238	33.079625	33.09796	52.643357000000002	52.633253000000003	Линейная	0103000020E61000000100000005000000D578E926318A4040058C2E6F0E514A40D578E926318A40408B53AD8559524A4078280AF4898C40408B53AD8559524A4078280AF4898C4040058C2E6F0E514A40D578E926318A4040058C2E6F0E514A40
24901	51078	33.121046	33.131996999999998	52.636263999999997	52.632328999999999	Новая	0103000020E61000000100000005000000E3A7716F7E8F4040FCA71B28F0504A40E3A7716F7E8F4040A2CF471971514A40C6151747E5904040A2CF471971514A40C6151747E5904040FCA71B28F0504A40E3A7716F7E8F4040FCA71B28F0504A40
25160	51098	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	улица Фрунзе	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
25206	51098	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	улица Урицкого	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
25011	51098	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	площадь Советская	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
25181	51098	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	Чехова	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
25197	51098	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	Октябрьская	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
25151	51098	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	Ленина	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
25281	51098	33.241295000000001	33.294277000000001	52.575634999999998	52.541713000000001	Гагарина	0103000020E610000001000000050000001BD82AC1E29E4040B66801DA56454A401BD82AC1E29E40406BB75D68AE494A40857B65DEAAA540406BB75D68AE494A40857B65DEAAA54040B66801DA56454A401BD82AC1E29E4040B66801DA56454A40
24646	4017	33.025455999999998	33.051391000000002	52.489342999999998	52.474952000000002	 Кизеевская	0103000020E6100000010000000500000055BE672442834040BC95253ACB3C4A4055BE67244283404065C39ACAA23E4A408527F4FA9386404065C39ACAA23E4A408527F4FA93864040BC95253ACB3C4A4055BE672442834040BC95253ACB3C4A40
25112	4675	33.224046999999999	33.247017	52.479821999999999	52.471156000000001	Пушкина	0103000020E610000001000000050000002AE27492AD9C404037A8FDD64E3C4A402AE27492AD9C40405EF3AACE6A3D4A402C47C8409E9F40405EF3AACE6A3D4A402C47C8409E9F404037A8FDD64E3C4A402AE27492AD9C404037A8FDD64E3C4A40
25105	5099	33.285446999999998	33.301724	52.701540000000001	52.680700999999999	Советская	0103000020E61000000100000005000000E3DEFC8689A4404060ADDA3521574A40E3DEFC8689A44040FD6A0E10CC594A408B355CE49EA64040FD6A0E10CC594A408B355CE49EA6404060ADDA3521574A40E3DEFC8689A4404060ADDA3521574A40
24687	5471	33.213977	33.228745000000004	52.582053999999999	52.568558000000003	Полевая	0103000020E61000000100000005000000508C2C99639B404089F02F82C6484A40508C2C99639B4040C440D7BE804A4A40D00F2384479D4040C440D7BE804A4A40D00F2384479D404089F02F82C6484A40508C2C99639B404089F02F82C6484A40
24924	4788	33.234853999999999	33.248669999999997	52.457334000000003	52.431638999999997	Центральная	0103000020E61000000100000005000000DAAA24B20F9E4040CD565EF23F374A40DAAA24B20F9E4040A8ACA6EB893A4A4087BF266BD49F4040A8ACA6EB893A4A4087BF266BD49F4040CD565EF23F374A40DAAA24B20F9E4040CD565EF23F374A40
24642	3955	33.146217	33.176777999999999	52.503691000000003	52.484808000000001	Пушкина	0103000020E61000000100000005000000438F183DB79240406A6B44300E3E4A40438F183DB792404010255AF278404A407E5358A9A096404010255AF278404A407E5358A9A09640406A6B44300E3E4A40438F183DB79240406A6B44300E3E4A40
24847	6055	33.269672	33.293514000000002	52.545338000000001	52.522154999999998	Первомайская	0103000020E61000000100000005000000CE52B29C84A24040B0389CF9D5424A40CE52B29C84A240400EA2B5A2CD454A408675E3DD91A540400EA2B5A2CD454A408675E3DD91A54040B0389CF9D5424A40CE52B29C84A24040B0389CF9D5424A40
25022	4381	33.328628999999999	33.35539	52.457548000000003	52.443151999999998	Мичурина	0103000020E6100000010000000500000033C2DB8310AA404018946934B9384A4033C2DB8310AA4040D42CD0EE903A4A40A8A9656B7DAD4040D42CD0EE903A4A40A8A9656B7DAD404018946934B9384A4033C2DB8310AA404018946934B9384A40
24531	5123	33.066276000000002	33.132714999999997	52.421815000000002	52.379742999999998	Центральная	0103000020E610000001000000050000003E4162BB7B88404045F12A6B9B304A403E4162BB7B8840402BFBAE08FE354A4025581CCEFC9040402BFBAE08FE354A4025581CCEFC90404045F12A6B9B304A403E4162BB7B88404045F12A6B9B304A40
24527	5123	33.066276000000002	33.132714999999997	52.421815000000002	52.379742999999998	 Центральная	0103000020E610000001000000050000003E4162BB7B88404045F12A6B9B304A403E4162BB7B8840402BFBAE08FE354A4025581CCEFC9040402BFBAE08FE354A4025581CCEFC90404045F12A6B9B304A403E4162BB7B88404045F12A6B9B304A40
25009	5953	33.424757999999997	33.459890999999999	52.657021	52.638330000000003	Партизанская	0103000020E61000000100000005000000705B5B785EB64040210725CCB4514A40705B5B785EB6404082E49D4319544A40C45C52B5DDBA404082E49D4319544A40C45C52B5DDBA4040210725CCB4514A40705B5B785EB64040210725CCB4514A40
24400	6431	33.321289999999998	33.350251	52.664237	52.650224999999999	Зеленая	0103000020E610000001000000050000001344DD0720A940405305A3923A534A401344DD0720A9404086E5CFB705554A4016325706D5AC404086E5CFB705554A4016325706D5AC40405305A3923A534A401344DD0720A940405305A3923A534A40
24573	4346	33.399110999999998	33.418829000000002	52.495583000000003	52.481918	Первомайская	0103000020E61000000100000005000000A73CBA1116B3404047AD307DAF3D4A40A73CBA1116B340400FBA84436F3F4A40E6CE4C309CB540400FBA84436F3F4A40E6CE4C309CB5404047AD307DAF3D4A40A73CBA1116B3404047AD307DAF3D4A40
24861	6300	33.214103000000001	33.243944999999997	52.654491999999998	52.644784000000001	Центральная	0103000020E61000000100000005000000DD7C23BA679B4040F67D384888524A40DD7C23BA679B40402FBFD364C6534A40E882FA96399F40402FBFD364C6534A40E882FA96399F4040F67D384888524A40DD7C23BA679B4040F67D384888524A40
25153	51117	33.402605000000001	33.415218000000003	52.378912	52.372627999999999	Центральная	0103000020E61000000100000005000000611A868F88B3404075C93846B22F4A40611A868F88B34040EE073C3080304A40F35A09DD25B54040EE073C3080304A40F35A09DD25B5404075C93846B22F4A40611A868F88B3404075C93846B22F4A40
25010	5627	33.135984999999998	33.154831999999999	52.628793000000002	52.616185999999999	Луговая	0103000020E610000001000000050000008FDFDBF4679140406420CF2EDF4E4A408FDFDBF467914040147AFD497C504A40E82FF488D1934040147AFD497C504A40E82FF488D19340406420CF2EDF4E4A408FDFDBF4679140406420CF2EDF4E4A40
24525	4178	33.355272999999997	33.389615999999997	52.408720000000002	52.39161	 Советская	0103000020E610000001000000050000006E13EE9579AD4040AE64C74620324A406E13EE9579AD40404E9CDCEF50344A40C9FFE4EFDEB140404E9CDCEF50344A40C9FFE4EFDEB14040AE64C74620324A406E13EE9579AD4040AE64C74620324A40
24444	4925	33.223562000000001	33.258470000000003	52.704869000000002	52.680013000000002	Новая	0103000020E610000001000000050000006E50FBAD9D9C40406CED7DAA0A574A406E50FBAD9D9C40406C7BBB25395A4A40A27F828B15A140406C7BBB25395A4A40A27F828B15A140406CED7DAA0A574A406E50FBAD9D9C40406CED7DAA0A574A40
24543	4723	33.188778999999997	33.224074000000002	52.444496999999998	52.404038999999997	 Ленина	0103000020E61000000100000005000000F69507E9299840407EA7C98CB7334A40F69507E929984040C6151747E5384A4024F1F274AE9C4040C6151747E5384A4024F1F274AE9C40407EA7C98CB7334A40F69507E9299840407EA7C98CB7334A40
24863	5243	33.127738999999998	33.144770999999999	52.379638	52.358781999999998	Центральная	0103000020E610000001000000050000003DB665C0599040405D328E91EC2D4A403DB665C059904040D0285DFA97304A4061342BDB87924040D0285DFA97304A4061342BDB879240405D328E91EC2D4A403DB665C0599040405D328E91EC2D4A40
24936	5760	33.403432000000002	33.428477000000001	52.548783	52.527569	Центральная	0103000020E610000001000000050000007714E7A8A3B3404014B1886187434A407714E7A8A3B34040E6CC76853E464A404A0B9755D8B64040E6CC76853E464A404A0B9755D8B6404014B1886187434A407714E7A8A3B3404014B1886187434A40
25118	4830	33.024099999999997	33.084566000000002	52.562192000000003	52.540233999999998	Новая	0103000020E61000000100000005000000B3EA73B515834040F817416326454A40B3EA73B51583404053094FE8F5474A40412D060FD38A404053094FE8F5474A40412D060FD38A4040F817416326454A40B3EA73B515834040F817416326454A40
24782	4597	33.188653000000002	33.230003000000004	52.486173000000001	52.464868000000003	Чапаева	0103000020E610000001000000050000006AA510C8259840407D7A6CCB803B4A406AA510C8259840405F99B7EA3A3E4A40AF7D01BD709D40405F99B7EA3A3E4A40AF7D01BD709D40407D7A6CCB803B4A406AA510C8259840407D7A6CCB803B4A40
25026	4481	33.108964	33.138249000000002	52.533622000000001	52.518698000000001	Центральная	0103000020E610000001000000050000007E384888F28D4040144031B264424A407E384888F28D40408B36C7B94D444A4034DAAA24B29140408B36C7B94D444A4034DAAA24B2914040144031B264424A407E384888F28D4040144031B264424A40
24759	4126	33.408434999999997	33.427658999999998	52.404814000000002	52.381633999999998	Школьная	0103000020E6100000010000000500000058C51B9947B4404055850662D9304A4058C51B9947B44040427BF5F1D0334A40876BB587BDB64040427BF5F1D0334A40876BB587BDB6404055850662D9304A4058C51B9947B4404055850662D9304A40
24436	4265	33.344718	33.372664	52.479695999999997	52.464945	Советская	0103000020E61000000100000005000000D82B2CB81FAC404028B85851833B4A40D82B2CB81FAC4040D102B4AD663D4A40C2323674B3AF4040D102B4AD663D4A40C2323674B3AF404028B85851833B4A40D82B2CB81FAC404028B85851833B4A40
24757	4061	33.304912999999999	33.316412	52.563538999999999	52.553826000000001	 Советская	0103000020E610000001000000050000000890A16307A7404056D636C5E3464A400890A16307A74040A182C30B22484A40EE073C3080A84040A182C30B22484A40EE073C3080A8404056D636C5E3464A400890A16307A7404056D636C5E3464A40
25101	5767	33.355336000000001	33.373617000000003	52.563468	52.550151999999997	Светлая	0103000020E61000000100000005000000B58B69A67BAD40401CEA77616B464A40B58B69A67BAD4040D82B2CB81F484A40651D8EAED2AF4040D82B2CB81F484A40651D8EAED2AF40401CEA77616B464A40B58B69A67BAD40401CEA77616B464A40
25084	4907	33.058281000000001	33.101228999999996	52.603651999999997	52.583405999999997	Школьная	0103000020E61000000100000005000000357D76C07587404024253D0CAD4A4A40357D76C0758740401E15FF77444D4A4011346612F58C40401E15FF77444D4A4011346612F58C404024253D0CAD4A4A40357D76C07587404024253D0CAD4A4A40
24590	6368	33.310581999999997	33.349370999999998	52.699308000000002	52.672308000000001	Новая	0103000020E61000000100000005000000F65CA626C1A740406A6B44300E564A40F65CA626C1A7404064EAAEEC82594A40DD955D30B8AC404064EAAEEC82594A40DD955D30B8AC40406A6B44300E564A40F65CA626C1A740406A6B44300E564A40
24756	6086	33.198749999999997	33.237656999999999	52.518917000000002	52.505127000000002	Советская	0103000020E610000001000000050000003D0AD7A370994040CEA96400A8404A403D0AD7A370994040522B4CDF6B424A402E55698B6B9E4040522B4CDF6B424A402E55698B6B9E4040CEA96400A8404A403D0AD7A370994040CEA96400A8404A40
25100	5562	33.109889000000003	33.130685	52.659779999999998	52.648471999999998	Центральная	0103000020E610000001000000050000005798BED7108E4040942F682101534A405798BED7108E40400647C9AB73544A40F4893C49BA9040400647C9AB73544A40F4893C49BA904040942F682101534A405798BED7108E4040942F682101534A40
24946	5311	32.972501000000001	33.040368999999998	52.402732	52.366866000000002	Слободская	0103000020E61000000100000005000000E529ABE97A7C4040D6011077F52E4A40E529ABE97A7C4040BE86E0B88C334A40D862B7CF2A854040BE86E0B88C334A40D862B7CF2A854040D6011077F52E4A40E529ABE97A7C4040D6011077F52E4A40
24775	5311	32.972501000000001	33.040368999999998	52.402732	52.366866000000002	Зеленая	0103000020E61000000100000005000000E529ABE97A7C4040D6011077F52E4A40E529ABE97A7C4040BE86E0B88C334A40D862B7CF2A854040BE86E0B88C334A40D862B7CF2A854040D6011077F52E4A40E529ABE97A7C4040D6011077F52E4A40
24943	51084	33.159745999999998	33.186793999999999	52.686886000000001	52.672893000000002	Хуторская	0103000020E610000001000000050000005AD5928E729440408A5A9A5B21564A405AD5928E72944040460A65E1EB574A40658BA4DDE8974040460A65E1EB574A40658BA4DDE89740408A5A9A5B21564A405AD5928E729440408A5A9A5B21564A40
25023	23550	31.827418000000002	31.875667	52.582436999999999	52.563127999999999	Центральная	0103000020E610000001000000050000002A1F82AAD1D33F401FBB0B9414484A402A1F82AAD1D33F407C7DAD4B8D4A4A40BA2F67B62BE03F407C7DAD4B8D4A4A40BA2F67B62BE03F401FBB0B9414484A402A1F82AAD1D33F401FBB0B9414484A40
25119	51106	31.496891999999999	32.266596	52.760196000000001	52.412092999999999	Набережная	0103000020E61000000100000005000000DFA46950347F3F408CF4A276BF344A40DFA46950347F3F4067463F1A4E614A40499F56D11F22404067463F1A4E614A40499F56D11F2240408CF4A276BF344A40DFA46950347F3F408CF4A276BF344A40
24539	23296	32.000684999999997	32.033760999999998	52.533819999999999	52.519047999999998	Хутор Сибирский	0103000020E61000000100000005000000834C327216004040F086342A70424A40834C327216004040B1F9B83654444A40AC70CB4752044040B1F9B83654444A40AC70CB4752044040F086342A70424A40834C327216004040F086342A70424A40
24976	23186	32.184175000000003	32.241630999999998	52.547632999999998	52.515103000000003	Школьная	0103000020E61000000100000005000000D3DEE00B93174040278925E5EE414A40D3DEE00B93174040ED9A90D618464A409259BDC3ED1E4040ED9A90D618464A409259BDC3ED1E4040278925E5EE414A40D3DEE00B93174040278925E5EE414A40
24545	23164	31.608436000000001	31.689050999999999	52.603417	52.574266999999999	1 Мая	0103000020E6100000010000000500000085B53176C29B3F400516C09481494A4085B53176C29B3F40DB6CACC43C4D4A40AE4676A565B03F40DB6CACC43C4D4A40AE4676A565B03F400516C09481494A4085B53176C29B3F400516C09481494A40
25108	23051	31.723043000000001	31.757259999999999	52.595404000000002	52.578322	Ленина	0103000020E610000001000000050000000B9A965819B93F4056478E74064A4A400B9A965819B93F402CF4C132364C4A40A79196CADBC13F402CF4C132364C4A40A79196CADBC13F4056478E74064A4A400B9A965819B93F4056478E74064A4A40
25020	23385	32.041918000000003	32.080716000000002	52.498049999999999	52.478000999999999	Новая	0103000020E610000001000000050000008F8EAB915D054040473A03232F3D4A408F8EAB915D054040EBE2361AC03F4A40C921E2E6540A4040EBE2361AC03F4A40C921E2E6540A4040473A03232F3D4A408F8EAB915D054040473A03232F3D4A40
24866	23024	31.966504	31.995691000000001	52.633592	52.609651999999997	Центральный переулок	0103000020E6100000010000000500000004745FCE6CF73F4072F8A413094E4A4004745FCE6CF73F40ED80EB8A19514A40EAEBF99AE5FE3F40ED80EB8A19514A40EAEBF99AE5FE3F4072F8A413094E4A4004745FCE6CF73F4072F8A413094E4A40
24625	12145	32.220475999999998	32.241945999999999	52.583323999999998	52.570900999999999	Советская	0103000020E61000000100000005000000C5C6BC8E381C40407920B24813494A40C5C6BC8E381C4040677C5F5CAA4A4A40F2B22616F81E4040677C5F5CAA4A4A40F2B22616F81E40407920B24813494A40C5C6BC8E381C40407920B24813494A40
24781	23107	31.705839999999998	31.744126999999999	52.641258999999998	52.607436999999997	Советская	0103000020E61000000100000005000000693524EEB1B43F40AFB0E07EC04D4A40693524EEB1B43F4001A260C614524A401212691B7FBE3F4001A260C614524A401212691B7FBE3F40AFB0E07EC04D4A40693524EEB1B43F40AFB0E07EC04D4A40
25025	23561	31.793112000000001	31.824767999999999	52.552326000000001	52.531616999999997	Луговая	0103000020E61000000100000005000000AE10566309CB3F40B27F9E060C444A40AE10566309CB3F40815D4D9EB2464A408EC9E2FE23D33F40815D4D9EB2464A408EC9E2FE23D33F40B27F9E060C444A40AE10566309CB3F40B27F9E060C444A40
24480	22978	32.064169	32.092556000000002	52.590628000000002	52.569752000000001	Первомайская	0103000020E61000000100000005000000613596B036084040516A2FA2ED484A40613596B0360840400B0DC4B2994B4A40388600E0D80B40400B0DC4B2994B4A40388600E0D80B4040516A2FA2ED484A40613596B036084040516A2FA2ED484A40
25104	23328	31.985620999999998	32.007531	52.512017	52.502118000000003	Молодежная	0103000020E61000000100000005000000354069A851FC3F40D15D126745404A40354069A851FC3F407EFFE6C589414A40645A9BC6F60040407EFFE6C589414A40645A9BC6F6004040D15D126745404A40354069A851FC3F40D15D126745404A40
24483	22894	31.766414000000001	31.787631999999999	52.588697000000003	52.577883999999997	Лесная	0103000020E61000000100000005000000513239B533C43F40DA70581AF8494A40513239B533C43F406D205D6C5A4B4A4077483140A2C93F406D205D6C5A4B4A4077483140A2C93F40DA70581AF8494A40513239B533C43F40DA70581AF8494A40
25102	22909	31.980491000000001	32.003183	52.583559000000001	52.563949000000001	Восточная	0103000020E61000000100000005000000B8054B7501FB3F4053CE177B2F484A40B8054B7501FB3F40AB24B20FB24A4A409B73F04C68004040AB24B20FB24A4A409B73F04C6800404053CE177B2F484A40B8054B7501FB3F4053CE177B2F484A40
24933	22728	31.750361000000002	31.785242	52.676065000000001	52.663276000000003	Ленина	0103000020E61000000100000005000000A13193A817C03F40611C5C3AE6544A40A13193A817C03F40317C444C89564A401572A59E05C93F40317C444C89564A401572A59E05C93F40611C5C3AE6544A40A13193A817C03F40611C5C3AE6544A40
24977	23250	32.145898000000003	32.189636999999998	52.611041	52.587482000000001	Молодежная	0103000020E61000000100000005000000A24621C9AC1240408D7E349C324B4A40A24621C9AC124040F0C16B97364E4A40478E740646184040F0C16B97364E4A40478E7406461840408D7E349C324B4A40A24621C9AC1240408D7E349C324B4A40
25086	22829	31.991002000000002	32.027752	52.548164	52.537402	Манюковская	0103000020E6100000010000000500000046459C4EB2FD3F400A67B796C9444A4046459C4EB2FD3F401A6CEA3C2A464A400533A6608D0340401A6CEA3C2A464A400533A6608D0340400A67B796C9444A4046459C4EB2FD3F400A67B796C9444A40
24857	22758	31.847954000000001	31.870087999999999	52.502583999999999	52.482126000000001	Гагарина	0103000020E610000001000000050000002C836A8313D93F409146054EB63D4A402C836A8313D93F4016BF29AC54404A405DA45016BEDE3F4016BF29AC54404A405DA45016BEDE3F409146054EB63D4A402C836A8313D93F409146054EB63D4A40
24850	22662	31.627732000000002	31.674274	52.746569999999998	52.716527999999997	Коммунистическая	0103000020E6100000010000000500000016A75A0BB3A03F408A558330B75B4A4016A75A0BB3A03F405D16139B8F5F4A40098B8A389DAC3F405D16139B8F5F4A40098B8A389DAC3F408A558330B75B4A4016A75A0BB3A03F408A558330B75B4A40
24915	51055	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	РОС	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
25115	51055	31.898779999999999	31.987247	52.569932000000001	52.499887000000001	Красногвардейская	0103000020E61000000100000005000000834C327216E63F400859164CFC3F4A40834C327216E63F40D1782288F3484A40F9122A38BCFC3F40D1782288F3484A40F9122A38BCFC3F400859164CFC3F4A40834C327216E63F400859164CFC3F4A40
24428	2476	34.670344	34.712465999999999	52.806579999999997	52.788034000000003	Школьная	0103000020E61000000100000005000000F0880AD5CD5541406B11514CDE644A40F0880AD5CD554140C8CD70033E674A4087C1FC15325B4140C8CD70033E674A4087C1FC15325B41406B11514CDE644A40F0880AD5CD5541406B11514CDE644A40
25002	1964	34.484473000000001	34.516426000000003	53.009134000000003	52.986924000000002	Л. Мирошина	0103000020E61000000100000005000000C3651536033E41409AD18F86537E4A40C3651536033E41400EA48B4D2B814A40ED66463F1A4241400EA48B4D2B814A40ED66463F1A4241409AD18F86537E4A40C3651536033E41409AD18F86537E4A40
25083	2352	34.623083000000001	34.66375	52.903315999999997	52.883442000000002	Северная	0103000020E61000000100000005000000C7D8092FC14F4140D8F4A0A014714A40C7D8092FC14F41400DFAD2DB9F734A40295C8FC2F55441400DFAD2DB9F734A40295C8FC2F5544140D8F4A0A014714A40C7D8092FC14F4140D8F4A0A014714A40
24507	2301	34.424232000000003	34.449762	53.032811000000002	53.020099000000002	Школьная	0103000020E6100000010000000500000056F5F23B4D36414056D7A19A92824A4056F5F23B4D3641407BF99D2633844A40E57D1CCD913941407BF99D2633844A40E57D1CCD9139414056D7A19A92824A4056F5F23B4D36414056D7A19A92824A40
75023	60442	\N	\N	\N	\N	Центральная	\N
25082	2186	34.274904999999997	34.312482000000003	52.803896000000002	52.731952	Школьная	0103000020E61000000100000005000000E140481630234140F31E679AB05D4A40E1404816302341404FB16A10E6664A405A4B0169FF2741404FB16A10E6664A405A4B0169FF274140F31E679AB05D4A40E140481630234140F31E679AB05D4A40
25000	2186	34.274904999999997	34.312482000000003	52.803896000000002	52.731952	Молодежная	0103000020E61000000100000005000000E140481630234140F31E679AB05D4A40E1404816302341404FB16A10E6664A405A4B0169FF2741404FB16A10E6664A405A4B0169FF274140F31E679AB05D4A40E140481630234140F31E679AB05D4A40
24737	2084	34.266767000000002	34.294218999999998	52.996946999999999	52.984610000000004	Центральная	0103000020E610000001000000050000007653CA6B2522414044A852B3077E4A407653CA6B25224140336C94F59B7F4A40506EDBF7A8254140336C94F59B7F4A40506EDBF7A825414044A852B3077E4A407653CA6B2522414044A852B3077E4A40
24854	2013	34.128965000000001	34.153022	52.878318	52.868729999999999	Центральная	0103000020E6100000010000000500000011AAD4EC81104140EC866D8B326F4A4011AAD4EC811041407BBE66B96C704A40C5C89239961341407BBE66B96C704A40C5C8923996134140EC866D8B326F4A4011AAD4EC81104140EC866D8B326F4A40
24414	1374	34.565528	34.587868999999998	53.021090000000001	53.013565999999997	Центральная	0103000020E61000000100000005000000747CB43863484140342BDB87BC814A40747CB43863484140E622BE13B3824A4086AA984A3F4B4140E622BE13B3824A4086AA984A3F4B4140342BDB87BC814A40747CB43863484140342BDB87BC814A40
24617	1891	34.447848999999998	34.473225999999997	52.995386000000003	52.981579000000004	Полевая	0103000020E61000000100000005000000ED45B41D533941405FB87361A47D4A40ED45B41D53394140B972F6CE687F4A40F6CE68AB923C4140B972F6CE687F4A40F6CE68AB923C41405FB87361A47D4A40ED45B41D533941405FB87361A47D4A40
24837	2420	34.685021999999996	34.703716	52.900376999999999	52.874394000000002	Слободская	0103000020E610000001000000050000002F8507CDAE574140C9E88024EC6F4A402F8507CDAE5741400989B48D3F734A4002D6AA5D135A41400989B48D3F734A4002D6AA5D135A4140C9E88024EC6F4A402F8507CDAE574140C9E88024EC6F4A40
24598	798	34.472102999999997	34.531984999999999	52.845371	52.811408	Филиппа Стрельца	0103000020E61000000100000005000000F7AB00DF6D3C41403CDBA337DC674A40F7AB00DF6D3C414050FEEE1D356C4A40357BA0151844414050FEEE1D356C4A40357BA015184441403CDBA337DC674A40F7AB00DF6D3C41403CDBA337DC674A40
24709	798	34.472102999999997	34.531984999999999	52.845371	52.811408	Леонардо Гарсиа	0103000020E61000000100000005000000F7AB00DF6D3C41403CDBA337DC674A40F7AB00DF6D3C414050FEEE1D356C4A40357BA0151844414050FEEE1D356C4A40357BA015184441403CDBA337DC674A40F7AB00DF6D3C41403CDBA337DC674A40
24711	798	34.472102999999997	34.531984999999999	52.845371	52.811408	Ленина	0103000020E61000000100000005000000F7AB00DF6D3C41403CDBA337DC674A40F7AB00DF6D3C414050FEEE1D356C4A40357BA0151844414050FEEE1D356C4A40357BA015184441403CDBA337DC674A40F7AB00DF6D3C41403CDBA337DC674A40
24710	798	34.472102999999997	34.531984999999999	52.845371	52.811408	Красных Партизан	0103000020E61000000100000005000000F7AB00DF6D3C41403CDBA337DC674A40F7AB00DF6D3C414050FEEE1D356C4A40357BA0151844414050FEEE1D356C4A40357BA015184441403CDBA337DC674A40F7AB00DF6D3C41403CDBA337DC674A40
24734	1771	34.621439000000002	34.650939999999999	52.757863	52.738380999999997	микрорайон Молодежный	0103000020E61000000100000005000000BFBA2A508B4F41406F7EC344835E4A40BFBA2A508B4F41409AEC9FA701614A4041D47D00525341409AEC9FA701614A4041D47D00525341406F7EC344835E4A40BFBA2A508B4F41406F7EC344835E4A40
24498	1719	34.798065999999999	34.836613	52.832909000000001	52.812272999999998	 Молодежная	0103000020E610000001000000050000005706D506276641403F36C98FF8674A405706D50627664140A4C519C39C6A4A4048348122166B4140A4C519C39C6A4A4048348122166B41403F36C98FF8674A405706D506276641403F36C98FF8674A40
24996	1666	34.450589000000001	34.456831999999999	52.932158999999999	52.921019000000001	Школьная	0103000020E61000000100000005000000FB777DE6AC39414050FF59F3E3754A40FB777DE6AC39414006D671FC50774A4015E29178793A414006D671FC50774A4015E29178793A414050FF59F3E3754A40FB777DE6AC39414050FF59F3E3754A40
24503	2143	34.384346999999998	34.410263	53.023777000000003	53.009203999999997	Советская	0103000020E6100000010000000500000069A8514832314140067FBF982D814A4069A8514832314140D1B2EE1F0B834A4022E17B7F83344140D1B2EE1F0B834A4022E17B7F83344140067FBF982D814A4069A8514832314140067FBF982D814A40
24833	1609	34.794930999999998	34.828232	52.900137999999998	52.881447999999999	Молодежная	0103000020E61000000100000005000000CDC98B4CC0654140F38FBE49D3704A40CDC98B4CC065414084F1D3B837734A4016C09481036A414084F1D3B837734A4016C09481036A4140F38FBE49D3704A40CDC98B4CC0654140F38FBE49D3704A40
24641	49258	34.138827999999997	34.183466000000003	52.694102000000001	52.687224000000001	  Зеленая	0103000020E6100000010000000500000071E2AB1DC51141405E83BEF4F6574A4071E2AB1DC51141404A0B9755D8584A40C7F65AD07B1741404A0B9755D8584A40C7F65AD07B1741405E83BEF4F6574A4071E2AB1DC51141405E83BEF4F6574A40
24716	1558	34.021031999999998	34.051448999999998	52.782086999999997	52.760027000000001	Центральная	0103000020E61000000100000005000000B115342DB1024140DB89929048614A40B115342DB102414039D0436D1B644A40B9347EE19506414039D0436D1B644A40B9347EE195064140DB89929048614A40B115342DB1024140DB89929048614A40
24909	1439	34.539144999999998	34.564387000000004	52.884236000000001	52.859726999999999	Клубная	0103000020E61000000100000005000000A5660FB4024541407D3ECA880B6E4A40A5660FB40245414012F92EA52E714A40CFA44DD53D48414012F92EA52E714A40CFA44DD53D4841407D3ECA880B6E4A40A5660FB4024541407D3ECA880B6E4A40
24496	1321	34.634824000000002	34.667855000000003	52.991363999999997	52.975375999999997	Садовая	0103000020E61000000100000005000000A35BAFE941514140D2A6EA1ED97C4A40A35BAFE9415141404337FB03E57E4A402CBCCB457C5541404337FB03E57E4A402CBCCB457C554140D2A6EA1ED97C4A40A35BAFE941514140D2A6EA1ED97C4A40
25081	1825	34.468581999999998	34.492235000000001	52.742944000000001	52.724612	Центральная	0103000020E6100000010000000500000044BFB67EFA3B414003250516C05C4A4044BFB67EFA3B41403561FBC9185F4A402979758E013F41403561FBC9185F4A402979758E013F414003250516C05C4A4044BFB67EFA3B414003250516C05C4A40
24882	1825	34.468581999999998	34.492235000000001	52.742944000000001	52.724612	Александра Яковца	0103000020E6100000010000000500000044BFB67EFA3B414003250516C05C4A4044BFB67EFA3B41403561FBC9185F4A402979758E013F41403561FBC9185F4A402979758E013F414003250516C05C4A4044BFB67EFA3B414003250516C05C4A40
24907	1155	34.336395000000003	34.395871999999997	52.701141999999997	52.661183999999999	Вяльцевой	0103000020E61000000100000005000000DBC4C9FD0E2B4140B95164ADA1544A40DBC4C9FD0E2B41400FED6305BF594A4078B306EFAB3241400FED6305BF594A4078B306EFAB324140B95164ADA1544A40DBC4C9FD0E2B4140B95164ADA1544A40
24914	51079	34.362796000000003	34.406427999999998	52.86007	52.842275999999998	Лесная	0103000020E61000000100000005000000508F6D19702E4140541A31B3CF6B4A40508F6D19702E4140A72215C6166E4A40DF162CD505344140A72215C6166E4A40DF162CD505344140541A31B3CF6B4A40508F6D19702E4140541A31B3CF6B4A40
24828	1212	34.402538	34.421052000000003	52.834556999999997	52.805556000000003	переулок Дорожный	0103000020E61000000100000005000000D9B27C5D863341405D8C81751C674A40D9B27C5D86334140EDD286C3D26A4A402CF52C08E5354140EDD286C3D26A4A402CF52C08E53541405D8C81751C674A40D9B27C5D863341405D8C81751C674A40
24819	49131	32.902253000000002	32.927638999999999	53.119047999999999	53.101475000000001	пер. Афанасьева	0103000020E61000000100000005000000E4DBBB067D734040492EFF21FD8C4A40E4DBBB067D734040BD5301F73C8F4A4040BFEFDFBC764040BD5301F73C8F4A4040BFEFDFBC764040492EFF21FD8C4A40E4DBBB067D734040492EFF21FD8C4A40
24572	31741	32.703051000000002	32.728068999999998	53.057963000000001	53.040872999999998	Центральная	0103000020E61000000100000005000000C6353E93FD5940400B2593533B854A40C6353E93FD59404064B0E2546B874A409F1D705D315D404064B0E2546B874A409F1D705D315D40400B2593533B854A40C6353E93FD5940400B2593533B854A40
25283	51152	32.81747	32.827368999999997	53.171838000000001	53.158892000000002	Советская	0103000020E6100000010000000500000006BB61DBA26840404BCCB39256944A4006BB61DBA2684040E31A9FC9FE954A40B35C363AE7694040E31A9FC9FE954A40B35C363AE76940404BCCB39256944A4006BB61DBA26840404BCCB39256944A40
25055	32112	32.734842999999998	32.757883999999997	53.200392999999998	53.191433000000004	Суворова	0103000020E61000000100000005000000E658DE550F5E4040063065E080984A40E658DE550F5E404075AC527AA6994A40B114C9570261404075AC527AA6994A40B114C95702614040063065E080984A40E658DE550F5E4040063065E080984A40
24588	350	32.951704999999997	32.975923000000002	52.981209999999997	52.962035	Молодёжная	0103000020E6100000010000000500000047382D78D1794040BE4D7FF6237B4A4047382D78D17940400B410E4A987D4A4005357C0BEB7C40400B410E4A987D4A4005357C0BEB7C4040BE4D7FF6237B4A4047382D78D1794040BE4D7FF6237B4A40
24997	48902	32.835867	32.850456000000001	52.995651000000002	52.986659000000003	Партизан	0103000020E610000001000000050000001F679AB0FD6A4040ECA694D74A7E4A401F679AB0FD6A4040679DF17D717F4A40EF5701BEDB6C4040679DF17D717F4A40EF5701BEDB6C4040ECA694D74A7E4A401F679AB0FD6A4040ECA694D74A7E4A40
24812	31638	32.760506999999997	32.784933000000002	53.049568000000001	53.031759999999998	Цветочная	0103000020E6100000010000000500000085B01A4B5861404015A930B610844A4085B01A4B58614040CD76853E58864A408D463EAF78644040CD76853E58864A408D463EAF7864404015A930B610844A4085B01A4B5861404015A930B610844A40
75047	220	32.982013999999999	33.003906000000001	53.013641999999997	52.997993000000001	Колхозная	0103000020E61000000100000005000000691B7FA2B27D40408751103CBE7F4A40691B7FA2B27D40400FED6305BF814A400C21E7FD7F8040400FED6305BF814A400C21E7FD7F8040408751103CBE7F4A40691B7FA2B27D40408751103CBE7F4A40
24701	49265	33.009124999999997	33.045192	52.990448000000001	52.968021999999998	Молодёжная	0103000020E61000000100000005000000BA490C022B8140407DE71725E87B4A40BA490C022B814040BE310400C77E4A403A05F9D9C8854040BE310400C77E4A403A05F9D9C88540407DE71725E87B4A40BA490C022B8140407DE71725E87B4A40
24810	31993	32.783009999999997	32.812089	53.128208000000001	53.105249000000001	Молодёжная	0103000020E610000001000000050000007138F3AB39644040E6779ACC788D4A407138F3AB39644040F48AA71E69904A407E384888F2674040F48AA71E69904A407E384888F2674040E6779ACC788D4A407138F3AB39644040E6779ACC788D4A40
24774	148	32.928958999999999	32.961163999999997	53.014595	52.998199	 Школьная	0103000020E610000001000000050000009529E620E876404030F31DFCC47F4A409529E620E8764040B2D7BB3FDE814A40D80B056C077B4040B2D7BB3FDE814A40D80B056C077B404030F31DFCC47F4A409529E620E876404030F31DFCC47F4A40
24979	31848	32.786352000000001	32.813274	53.083094000000003	53.068584999999999	Школьная	0103000020E610000001000000050000007592AD2EA764404082FFAD64C7884A407592AD2EA7644040363FFED2A28A4A40F357C85C19684040363FFED2A28A4A40F357C85C1968404082FFAD64C7884A407592AD2EA764404082FFAD64C7884A40
24575	32180	32.819535999999999	32.842846999999999	53.205582	53.192996999999998	Молодёжная	0103000020E6100000010000000500000084F23E8EE6684040F19C2D20B4984A4084F23E8EE6684040B952CF82509A4A400F441669E26B4040B952CF82509A4A400F441669E26B4040F19C2D20B4984A4084F23E8EE6684040F19C2D20B4984A40
24704	441	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	площадь Советская	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
24708	441	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	Первомайская	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
25066	441	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	Октябрьская	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
24903	441	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	Кирова	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
25122	441	32.820416000000002	32.871915999999999	53.083570000000002	53.01784	Будённого	0103000020E61000000100000005000000BD8E386403694040C347C49448824A40BD8E3864036940409F76F86BB28A4A40F86D88F19A6F40409F76F86BB28A4A40F86D88F19A6F4040C347C49448824A40BD8E386403694040C347C49448824A40
24530	31906	32.656222	32.679219000000003	53.148966999999999	53.130634000000001	Прудная	0103000020E6100000010000000500000036751E15FF53404072DF6A9DB8904A4036751E15FF5340407497C45911934A4032E9EFA5F05640407497C45911934A4032E9EFA5F056404072DF6A9DB8904A4036751E15FF53404072DF6A9DB8904A40
24489	31969	32.740896999999997	32.749566000000002	53.163212000000001	53.152251	 Садовая	0103000020E610000001000000050000002D5A80B6D55E404043E4F4F57C934A402D5A80B6D55E40404A287D21E4944A40C61858C7F15F40404A287D21E4944A40C61858C7F15F404043E4F4F57C934A402D5A80B6D55E404043E4F4F57C934A40
24895	32102	32.809851999999999	32.829121000000001	53.280721999999997	53.266925999999998	Ипутьская	0103000020E61000000100000005000000D34CF73AA9674040DE3994A12AA24A40D34CF73AA967404044A2D0B2EEA34A40A2B60DA3206A404044A2D0B2EEA34A40A2B60DA3206A4040DE3994A12AA24A40D34CF73AA9674040DE3994A12AA24A40
25139	49225	33.024360999999999	33.052756000000002	53.048045999999999	53.021853999999998	Молодёжная	0103000020E610000001000000050000002026E1421E834040B5A4A31CCC824A402026E1421E834040105A0F5F26864A407A5567B5C0864040105A0F5F26864A407A5567B5C0864040B5A4A31CCC824A402026E1421E834040B5A4A31CCC824A40
25121	32464	33.119976999999999	33.155127999999998	53.067238000000003	53.047592000000002	Советская	0103000020E61000000100000005000000D7A205685B8F40408FC6A17E17864A40D7A205685B8F4040348639419B884A40D158FB3BDB934040348639419B884A40D158FB3BDB9340408FC6A17E17864A40D7A205685B8F40408FC6A17E17864A40
25051	32292	32.930638999999999	32.953986999999998	53.067227000000003	53.054656000000001	Октябрьская	0103000020E61000000100000005000000EAB0C22D1F774040DD43C2F7FE864A40EAB0C22D1F7740404034F3E49A884A4092E7FA3E1C7A40404034F3E49A884A4092E7FA3E1C7A4040DD43C2F7FE864A40EAB0C22D1F774040DD43C2F7FE864A40
24585	32429	33.089829999999999	33.125304	53.097717000000003	53.077739000000001	Пролетарская	0103000020E610000001000000050000008F19A88C7F8B4040D74FFF59F3894A408F19A88C7F8B4040B2A19BFD818C4A406C0723F609904040B2A19BFD818C4A406C0723F609904040D74FFF59F3894A408F19A88C7F8B4040D74FFF59F3894A40
24891	31764	32.654812	32.686109000000002	53.003937999999998	52.986148999999997	Советская	0103000020E61000000100000005000000A1832EE1D0534040D6FD63213A7E4A40A1832EE1D0534040179B560A81804A40E23E726BD2574040179B560A81804A40E23E726BD2574040D6FD63213A7E4A40A1832EE1D0534040D6FD63213A7E4A40
25056	49057	32.836773999999998	32.859501999999999	53.113714000000002	53.096809	Советская	0103000020E61000000100000005000000511212691B6B4040AF7AC03C648C4A40511212691B6B4040768C2B2E8E8E4A405D6C5A29046E4040768C2B2E8E8E4A405D6C5A29046E4040AF7AC03C648C4A40511212691B6B4040AF7AC03C648C4A40
25052	31534	32.888705999999999	32.905343000000002	52.946584000000001	52.93186	Лесная	0103000020E6100000010000000500000026E1421EC1714040AC39403047774A4026E1421EC17140405C751DAA29794A40CE548847E27340405C751DAA29794A40CE548847E2734040AC39403047774A4026E1421EC1714040AC39403047774A40
24565	31408	31.618506	31.660430000000002	52.841672000000003	52.815576999999998	Луговая	0103000020E610000001000000050000003961C268569E3F40552FBFD364684A403961C268569E3F40BEFA78E8BB6B4A401B4CC3F011A93F40BEFA78E8BB6B4A401B4CC3F011A93F40552FBFD364684A403961C268569E3F40552FBFD364684A40
25039	30861	31.348275000000001	31.377192000000001	53.070922000000003	53.055824999999999	Центральная	0103000020E61000000100000005000000B003E78C28593F404CA60A4625874A40B003E78C28593F409148DBF813894A401650A8A78F603F409148DBF813894A401650A8A78F603F404CA60A4625874A40B003E78C28593F404CA60A4625874A40
24695	31426	31.638888999999999	31.670321000000001	52.794007999999998	52.773539999999997	Советская	0103000020E610000001000000050000002EC6C03A8EA33F40EC12D55B03634A402EC6C03A8EA33F409561DC0DA2654A4070D234289AAB3F409561DC0DA2654A4070D234289AAB3F40EC12D55B03634A402EC6C03A8EA33F40EC12D55B03634A40
24469	48576	31.677786000000001	31.698392999999999	52.971656000000003	52.950105000000001	Советская	0103000020E61000000100000005000000C9AF1F6283AD3F400F62670A9D794A40C9AF1F6283AD3F40297B4B395F7C4A405DC136E2C9B23F40297B4B395F7C4A405DC136E2C9B23F400F62670A9D794A40C9AF1F6283AD3F400F62670A9D794A40
24970	48785	31.437487000000001	31.494700000000002	53.052360999999998	53.022688000000002	Советская	0103000020E61000000100000005000000D76CE525FF6F3F407E01BD70E7824A40D76CE525FF6F3F40FD4AE7C3B3864A40CA54C1A8A47E3F40FD4AE7C3B3864A40CA54C1A8A47E3F407E01BD70E7824A40D76CE525FF6F3F407E01BD70E7824A40
24477	31172	31.578271000000001	31.599730999999998	53.081093000000003	53.059711	Центральная	0103000020E61000000100000005000000A839799109943F40111B2C9CA4874A40A839799109943F409F776341618A4A40BA6587F887993F409F776341618A4A40BA6587F887993F40111B2C9CA4874A40A839799109943F40111B2C9CA4874A40
24966	48776	31.674139	31.700468000000001	53.192684	53.169139000000001	Центральная	0103000020E6100000010000000500000049F59D5F94AC3F4034BDC458A6954A4049F59D5F94AC3F40323B8BDEA9984A4000E5EFDE51B33F40323B8BDEA9984A4000E5EFDE51B33F4034BDC458A6954A4049F59D5F94AC3F4034BDC458A6954A40
24561	31146	31.622216000000002	31.657385000000001	53.101166999999997	53.076214	Центральная	0103000020E61000000100000005000000460C3B8C499F3F40A9BF5E61C1894A40460C3B8C499F3F409B374E0AF38C4A4087E123624AA83F409B374E0AF38C4A4087E123624AA83F40A9BF5E61C1894A40460C3B8C499F3F40A9BF5E61C1894A40
25245	51146	31.520913	31.557563999999999	52.994855000000001	52.976346999999997	Советская	0103000020E61000000100000005000000AE0FEB8D5A853F401B4641F0F87C4A40AE0FEB8D5A853F408CA19C68577F4A404C6DA983BC8E3F408CA19C68577F4A404C6DA983BC8E3F401B4641F0F87C4A40AE0FEB8D5A853F401B4641F0F87C4A40
24803	30889	31.561346	31.584047000000002	53.140574000000001	53.122242	Центральная	0103000020E610000001000000050000008CBD175FB48F3F404C1938A0A58F4A408CBD175FB48F3F407E552E54FE914A40B153AC1A84953F407E552E54FE914A40B153AC1A84953F404C1938A0A58F4A408CBD175FB48F3F404C1938A0A58F4A40
24916	31320	31.401517999999999	31.441106999999999	52.999662000000001	52.980255999999997	Коммунистическая	0103000020E610000001000000050000005DC136E2C9663F4098DA5207797D4A405DC136E2C9663F40E886A6ECF47F4A4063096B63EC703F40E886A6ECF47F4A4063096B63EC703F4098DA5207797D4A405DC136E2C9663F4098DA5207797D4A40
24472	31015	31.503055	31.524875000000002	53.157127000000003	53.141492	Центральная	0103000020E61000000100000005000000DB166536C8803F40A452EC681C924A40DB166536C8803F40C828CFBC1C944A40EE7C3F355E863F40C828CFBC1C944A40EE7C3F355E863F40A452EC681C924A40DB166536C8803F40A452EC681C924A40
24962	48607	31.417318999999999	31.434055000000001	53.134971999999998	53.119880999999999	Центральная	0103000020E61000000100000005000000DAFF006BD56A3F40B534B742588F4A40DAFF006BD56A3F4017F032C346914A4050AA7D3A1E6F3F4017F032C346914A4050AA7D3A1E6F3F40B534B742588F4A40DAFF006BD56A3F40B534B742588F4A40
24558	51031	31.566511999999999	31.629663000000001	53.026648000000002	52.982598000000003	переулок Московский	0103000020E61000000100000005000000A3CA30EE06913F40B98E71C5C57D4A40A3CA30EE06913F407D40A03369834A405280289831A13F407D40A03369834A405280289831A13F40B98E71C5C57D4A40A3CA30EE06913F40B98E71C5C57D4A40
25246	51031	31.566511999999999	31.629663000000001	53.026648000000002	52.982598000000003	Центральная	0103000020E61000000100000005000000A3CA30EE06913F40B98E71C5C57D4A40A3CA30EE06913F407D40A03369834A405280289831A13F407D40A03369834A405280289831A13F40B98E71C5C57D4A40A3CA30EE06913F40B98E71C5C57D4A40
25158	51031	31.566511999999999	31.629663000000001	53.026648000000002	52.982598000000003	Куйбышева	0103000020E61000000100000005000000A3CA30EE06913F40B98E71C5C57D4A40A3CA30EE06913F407D40A03369834A405280289831A13F407D40A03369834A405280289831A13F40B98E71C5C57D4A40A3CA30EE06913F40B98E71C5C57D4A40
24874	51031	31.566511999999999	31.629663000000001	53.026648000000002	52.982598000000003	Буйневича	0103000020E61000000100000005000000A3CA30EE06913F40B98E71C5C57D4A40A3CA30EE06913F407D40A03369834A405280289831A13F407D40A03369834A405280289831A13F40B98E71C5C57D4A40A3CA30EE06913F40B98E71C5C57D4A40
24455	51031	31.566511999999999	31.629663000000001	53.026648000000002	52.982598000000003	Больничная	0103000020E61000000100000005000000A3CA30EE06913F40B98E71C5C57D4A40A3CA30EE06913F407D40A03369834A405280289831A13F407D40A03369834A405280289831A13F40B98E71C5C57D4A40A3CA30EE06913F40B98E71C5C57D4A40
25129	30723	31.387280000000001	31.432051999999999	53.094349000000001	53.072805000000002	Центральная	0103000020E61000000100000005000000176536C824633F401EFE9AAC51894A40176536C824633F4085B4C6A0138C4A40E02BBAF59A6E3F4085B4C6A0138C4A40E02BBAF59A6E3F401EFE9AAC51894A40176536C824633F401EFE9AAC51894A40
24471	30959	31.588619000000001	31.608059000000001	53.196261	53.175600000000003	Центральная	0103000020E61000000100000005000000E2CD1ABCAF963F40BC96900F7A964A40E2CD1ABCAF963F40793D98141F994A40D9092FC1A99B3F40793D98141F994A40D9092FC1A99B3F40BC96900F7A964A40E2CD1ABCAF963F40BC96900F7A964A40
24675	30648	31.705724	31.725954000000002	53.015625	53.000334000000002	Центральная	0103000020E610000001000000050000009700FC53AAB43F40D789CBF10A804A409700FC53AAB43F400000000000824A408066101FD8B93F400000000000824A408066101FD8B93F40D789CBF10A804A409700FC53AAB43F40D789CBF10A804A40
24969	31512	31.611885999999998	31.631226000000002	52.917538999999998	52.903522000000002	Совхозная	0103000020E6100000010000000500000058E1968FA49C3F40B79BE09BA6734A4058E1968FA49C3F40FBE6FEEA71754A408962F20698A13F40FBE6FEEA71754A408962F20698A13F40B79BE09BA6734A4058E1968FA49C3F40B79BE09BA6734A40
24554	31116	31.487207999999999	31.519988000000001	52.923527	52.908969999999997	Молодежная	0103000020E610000001000000050000007D59DAA9B97C3F40C685032159744A407D59DAA9B97C3F408BFCFA2136764A40FD4FFEEE1D853F408BFCFA2136764A40FD4FFEEE1D853F40C685032159744A407D59DAA9B97C3F40C685032159744A40
24794	29189	34.756833	34.837287000000003	52.475171000000003	52.437728	Горького	0103000020E610000001000000050000004CC45BE7DF60414091459A7807384A404CC45BE7DF604140FA804067D23C4A40D82E6D382C6B4140FA804067D23C4A40D82E6D382C6B414091459A7807384A404CC45BE7DF60414091459A7807384A40
24666	28876	34.770209000000001	34.821306	52.429613000000003	52.399780999999997	Советская	0103000020E61000000100000005000000DD0A613596624140F54718062C334A40DD0A613596624140DE770C8FFD364A401901158E20694140DE770C8FFD364A401901158E20694140F54718062C334A40DD0A613596624140F54718062C334A40
24990	28876	34.770209000000001	34.821306	52.429613000000003	52.399780999999997	Рабочая	0103000020E61000000100000005000000DD0A613596624140F54718062C334A40DD0A613596624140DE770C8FFD364A401901158E20694140DE770C8FFD364A401901158E20694140F54718062C334A40DD0A613596624140F54718062C334A40
25070	28876	34.770209000000001	34.821306	52.429613000000003	52.399780999999997	Переулок Кирова	0103000020E61000000100000005000000DD0A613596624140F54718062C334A40DD0A613596624140DE770C8FFD364A401901158E20694140DE770C8FFD364A401901158E20694140F54718062C334A40DD0A613596624140F54718062C334A40
25037	28876	34.770209000000001	34.821306	52.429613000000003	52.399780999999997	Ленина	0103000020E61000000100000005000000DD0A613596624140F54718062C334A40DD0A613596624140DE770C8FFD364A401901158E20694140DE770C8FFD364A401901158E20694140F54718062C334A40DD0A613596624140F54718062C334A40
24456	28876	34.770209000000001	34.821306	52.429613000000003	52.399780999999997	Комсомольская	0103000020E61000000100000005000000DD0A613596624140F54718062C334A40DD0A613596624140DE770C8FFD364A401901158E20694140DE770C8FFD364A401901158E20694140F54718062C334A40DD0A613596624140F54718062C334A40
24474	51036	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Школьная	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24643	51036	32.193949000000003	32.301153999999997	52.780856	52.730082000000003	Ворошилова	0103000020E61000000100000005000000C40B2252D3184040FBB2B453735D4A40C40B2252D31840405471E316F3634A40A087DA368C2640405471E316F3634A40A087DA368C264040FBB2B453735D4A40C40B2252D3184040FBB2B453735D4A40
24633	22570	32.202142000000002	32.216766	52.800606999999999	52.789461000000003	Школьная	0103000020E61000000100000005000000F392FFC9DF194040D63BDC0E0D654A40F392FFC9DF1940406EF9484A7A664A403F7100FDBE1B40406EF9484A7A664A403F7100FDBE1B4040D63BDC0E0D654A40F392FFC9DF194040D63BDC0E0D654A40
24628	22501	31.868929000000001	31.897971999999999	52.728926000000001	52.703963000000002	Школьная	0103000020E61000000100000005000000C68B852172DE3F400A4CA7751B5A4A40C68B852172DE3F40209A79724D5D4A4045B9347EE1E53F40209A79724D5D4A4045B9347EE1E53F400A4CA7751B5A4A40C68B852172DE3F400A4CA7751B5A4A40
24788	21495	32.191882999999997	32.239708999999998	52.672471999999999	52.649645999999997	Центральная	0103000020E6100000010000000500000045D4449F8F18404015FDA19927534A4045D4449F8F184040E4BCFF8F13564A4047C7D5C8AE1E4040E4BCFF8F13564A4047C7D5C8AE1E404015FDA19927534A4045D4449F8F18404015FDA19927534A40
24435	21978	32.347417	32.366731000000001	52.834307000000003	52.821204999999999	Школьная	0103000020E6100000010000000500000087890629782C4040E527D53E1D694A4087890629782C404075E95F92CA6A4A40F6B6990AF12E404075E95F92CA6A4A40F6B6990AF12E4040E527D53E1D694A4087890629782C4040E527D53E1D694A40
25094	22080	32.274914000000003	32.310082999999999	52.687213	52.662013999999999	Советская	0103000020E61000000100000005000000359BC7613023404040BFEFDFBC544A40359BC761302340406A317898F6574A40D505BCCCB02740406A317898F6574A40D505BCCCB027404040BFEFDFBC544A40359BC7613023404040BFEFDFBC544A40
25018	22521	32.200794000000002	32.233474999999999	52.839072000000002	52.821840999999999	Ленина	0103000020E61000000100000005000000D49D279EB319404087C1FC1532694A40D49D279EB3194040A27E17B6666B4A4080B74082E21D4040A27E17B6666B4A4080B74082E21D404087C1FC1532694A40D49D279EB319404087C1FC1532694A40
24762	22303	32.145798999999997	32.168579999999999	52.704700000000003	52.693376000000001	Клинцовская	0103000020E610000001000000050000000E65A88AA912404068EA758BC0584A400E65A88AA9124040E0BE0E9C335A4A403D61890794154040E0BE0E9C335A4A403D6189079415404068EA758BC0584A400E65A88AA912404068EA758BC0584A40
24856	22388	32.067062	32.089556000000002	52.750079999999997	52.728532999999999	Зеленая	0103000020E61000000100000005000000F566D47C950840404487C091405D4A40F566D47C950840401CB1169F02604A408E942D92760B40401CB1169F02604A408E942D92760B40404487C091405D4A40F566D47C950840404487C091405D4A40
24954	22651	32.181938000000002	32.218184999999998	52.901985000000003	52.891131000000001	Мира	0103000020E6100000010000000500000028F38FBE49174040D4B9A29410724A4028F38FBE49174040C53D963E74734A4027BD6F7CED1B4040C53D963E74734A4027BD6F7CED1B4040D4B9A29410724A4028F38FBE49174040D4B9A29410724A40
24940	22651	32.181938000000002	32.218184999999998	52.901985000000003	52.891131000000001	Зеленая	0103000020E6100000010000000500000028F38FBE49174040D4B9A29410724A4028F38FBE49174040C53D963E74734A4027BD6F7CED1B4040C53D963E74734A4027BD6F7CED1B4040D4B9A29410724A4028F38FBE49174040D4B9A29410724A40
24760	22210	32.183295000000001	32.227204999999998	52.755268999999998	52.735577999999997	Центральная	0103000020E610000001000000050000009A42E735761740401BD47E6B275E4A409A42E73576174040605793A7AC604A406C3EAE0D151D4040605793A7AC604A406C3EAE0D151D40401BD47E6B275E4A409A42E735761740401BD47E6B275E4A40
24935	22184	32.495199	32.523020000000002	52.725850000000001	52.705719999999999	Центральная	0103000020E6100000010000000500000086014BAE623F40400A117008555A4A4086014BAE623F40409BE61DA7E85C4A40B493C151F24240409BE61DA7E85C4A40B493C151F24240400A117008555A4A4086014BAE623F40400A117008555A4A40
24730	22282	32.112659999999998	32.160001999999999	52.749932999999999	52.726858999999997	Молодежная	0103000020E610000001000000050000009FC893A46B0E4040D1E638B7095D4A409FC893A46B0E40407898F6CDFD5F4A40B5A50EF27A1440407898F6CDFD5F4A40B5A50EF27A144040D1E638B7095D4A409FC893A46B0E4040D1E638B7095D4A40
24437	21818	32.311205999999999	32.327357999999997	52.633794000000002	52.627732000000002	Октябрьская	0103000020E61000000100000005000000D4282499D52740408B53AD8559504A40D4282499D527404055336B2920514A40BF0AF0DDE629404055336B2920514A40BF0AF0DDE62940408B53AD8559504A40D4282499D52740408B53AD8559504A40
24511	21642	32.436889000000001	32.497399999999999	52.596803999999999	52.566445000000002	Центральная	0103000020E61000000100000005000000B77D8FFAEB374040CAFD0E4581484A40B77D8FFAEB3740409D0FCF12644C4A40E4839ECDAA3F40409D0FCF12644C4A40E4839ECDAA3F4040CAFD0E4581484A40B77D8FFAEB374040CAFD0E4581484A40
24439	22133	32.323557999999998	32.374789	52.720739000000002	52.696480999999999	Центральная	0103000020E61000000100000005000000F92D3A596A29404087A4164A26594A40F92D3A596A294040D3F9F02C415C4A4045F30016F92F4040D3F9F02C415C4A4045F30016F92F404087A4164A26594A40F92D3A596A29404087A4164A26594A40
24840	21424	32.302276999999997	32.339494000000002	52.555993999999998	52.529989999999998	Школьная	0103000020E610000001000000050000009FAA4203B1264040809A5AB6D6434A409FAA4203B1264040D862B7CF2A474A401898158A742B4040D862B7CF2A474A401898158A742B4040809A5AB6D6434A409FAA4203B1264040809A5AB6D6434A40
25013	21556	32.116900000000001	32.178075999999997	52.838163999999999	52.810786999999998	Совхозная	0103000020E6100000010000000500000082734694F60E4040CF8250DEC7674A4082734694F60E40409F573CF5486B4A40EB19C231CB1640409F573CF5486B4A40EB19C231CB164040CF8250DEC7674A4082734694F60E4040CF8250DEC7674A40
25286	51154	32.331346000000003	32.377547	52.781117000000002	52.751645000000003	Советская	0103000020E6100000010000000500000089D4B48B692A4040D99942E735604A4089D4B48B692A4040C1AC50A4FB634A40F9D9C87553304040C1AC50A4FB634A40F9D9C87553304040D99942E735604A4089D4B48B692A4040D99942E735604A40
24755	21731	32.348962	32.383754000000003	52.615578999999997	52.592762	Буденного	0103000020E61000000100000005000000FCC56CC9AA2C4040E1270EA0DF4B4A40FCC56CC9AA2C40405C8DEC4ACB4E4A40C7DADFD91E3140405C8DEC4ACB4E4A40C7DADFD91E314040E1270EA0DF4B4A40FCC56CC9AA2C4040E1270EA0DF4B4A40
24937	22368	32.214421999999999	32.232433	52.711857999999999	52.696235999999999	Займищенская	0103000020E610000001000000050000007EC51A2E721B40402026E1421E594A407EC51A2E721B4040AFB2B6291E5B4A406EC1525DC01D4040AFB2B6291E5B4A406EC1525DC01D40402026E1421E594A407EC51A2E721B40402026E1421E594A40
24702	47779	32.183286000000003	32.255429999999997	52.736178000000002	52.709086999999997	Клинцовская	0103000020E6100000010000000500000047E867EA751740406682E15CC35A4A4047E867EA751740407104A9143B5E4A40693524EEB12040407104A9143B5E4A40693524EEB12040406682E15CC35A4A4047E867EA751740406682E15CC35A4A40
24927	21697	32.414081000000003	32.440078	52.633439000000003	52.617809999999999	Центральная	0103000020E610000001000000050000008F72309B003540402592E865144F4A408F72309B003540406781768714514A4034D8D479543840406781768714514A4034D8D479543840402592E865144F4A408F72309B003540402592E865144F4A40
24512	21580	32.023476000000002	32.046086000000003	52.851598000000003	52.839573000000001	Свердлова	0103000020E61000000100000005000000D61EF6420103404064CDC820776B4A40D61EF6420103404065ABCB29016D4A40D8666325E605404065ABCB29016D4A40D8666325E605404064CDC820776B4A40D61EF6420103404064CDC820776B4A40
24605	21461	32.212248000000002	32.245009000000003	52.621211000000002	52.600546000000001	Заводская	0103000020E610000001000000050000001A5245F12A1B40402FDFFAB0DE4C4A401A5245F12A1B40402E7590D7834F4A40E31C75745C1F40402E7590D7834F4A40E31C75745C1F40402FDFFAB0DE4C4A401A5245F12A1B40402FDFFAB0DE4C4A40
24517	21948	32.271006	32.289413000000003	52.803466	52.794117	пер.1 Центральный	0103000020E6100000010000000500000088821953B02240404C1938A0A5654A4088821953B022404056B950F9D7664A40C504357C0B25404056B950F9D7664A40C504357C0B2540404C1938A0A5654A4088821953B02240404C1938A0A5654A40
24649	51054	31.937992000000001	31.972864999999999	52.702511999999999	52.691721999999999	Песчаная	0103000020E61000000100000005000000DEE8633E20F03F403CF6B3588A584A40DEE8633E20F03F401686C8E9EB594A404C6C3EAE0DF93F401686C8E9EB594A404C6C3EAE0DF93F403CF6B3588A584A40DEE8633E20F03F403CF6B3588A584A40
24748	21347	32.333008	32.391309	52.552162000000003	52.525218000000002	Октябрьская	0103000020E6100000010000000500000037A79201A02A4040A1A2EA573A434A4037A79201A02A4040070C923EAD464A40B3D0CE6916324040070C923EAD464A40B3D0CE6916324040A1A2EA573A434A4037A79201A02A4040A1A2EA573A434A40
24636	21833	32.368482999999998	32.437195000000003	52.590857999999997	52.570715	Ленина	0103000020E61000000100000005000000E41071732A2F4040172B6A300D494A40E41071732A2F40403C4A253CA14B4A40C47C7901F63740403C4A253CA14B4A40C47C7901F6374040172B6A300D494A40E41071732A2F4040172B6A300D494A40
24735	28639	32.287365000000001	32.333852999999998	52.744028999999998	52.725718999999998	Зеленая	0103000020E61000000100000005000000ED815660C8244040FC8A355CE45C4A40ED815660C824404046239F573C5F4A40F355F2B1BB2A404046239F573C5F4A40F355F2B1BB2A4040FC8A355CE45C4A40ED815660C8244040FC8A355CE45C4A40
24549	27563	32.184210999999998	32.204332999999998	52.138542999999999	52.122345000000003	Октябрьская	0103000020E610000001000000050000001F48DE399417404021EA3E00A90F4A401F48DE39941740407C0BEBC6BB114A402D3F7095271A40407C0BEBC6BB114A402D3F7095271A404021EA3E00A90F4A401F48DE399417404021EA3E00A90F4A40
24529	27728	31.977715	32.027661999999999	52.182364999999997	52.156497999999999	Советская	0103000020E6100000010000000500000003CFBD874BFA3F40D8F15F2008144A4003CFBD874BFA3F40AF777FBC57174A40C5ABAC6D8A034040AF777FBC57174A40C5ABAC6D8A034040D8F15F2008144A4003CFBD874BFA3F40D8F15F2008144A40
25103	27728	31.977715	32.027661999999999	52.182364999999997	52.156497999999999	Ленинская	0103000020E6100000010000000500000003CFBD874BFA3F40D8F15F2008144A4003CFBD874BFA3F40AF777FBC57174A40C5ABAC6D8A034040AF777FBC57174A40C5ABAC6D8A034040D8F15F2008144A4003CFBD874BFA3F40D8F15F2008144A40
25170	51124	32.043543999999997	32.092771999999997	52.263409000000003	52.231670999999999	Набережная	0103000020E61000000100000005000000F0F78BD9920540403F373465A71D4A40F0F78BD9920540406D3CD862B7214A4004FEF0F3DF0B40406D3CD862B7214A4004FEF0F3DF0B40403F373465A71D4A40F0F78BD9920540403F373465A71D4A40
24630	26673	32.408341	32.449241000000001	52.423698999999999	52.377346000000003	Молодежная	0103000020E61000000100000005000000D74E94844434404062A3ACDF4C304A40D74E948444344040882CD2C43B364A40DC82A5BA80394040882CD2C43B364A40DC82A5BA8039404062A3ACDF4C304A40D74E94844434404062A3ACDF4C304A40
25017	26241	32.208367000000003	32.239224	52.440753000000001	52.428196999999997	Школьная	0103000020E61000000100000005000000674815C5AB1A4040669FC728CF364A40674815C5AB1A4040944E24986A384A408B355CE49E1E4040944E24986A384A408B355CE49E1E4040669FC728CF364A40674815C5AB1A4040669FC728CF364A40
24942	27696	32.000596000000002	32.063468999999998	52.077699000000003	52.063195	Октябрьская	0103000020E6100000010000000500000014419C8713004040A72215C616084A4014419C871300404049F7730AF2094A40A8A78FC01F08404049F7730AF2094A40A8A78FC01F084040A72215C616084A4014419C8713004040A72215C616084A40
24698	27277	31.952850000000002	31.989177999999999	52.253067000000001	52.230677999999997	Советская	0103000020E610000001000000050000005DFE43FAEDF33F400EF450DB861D4A405DFE43FAEDF33F403259DC7F64204A4035ECF7C43AFD3F403259DC7F64204A4035ECF7C43AFD3F400EF450DB861D4A405DFE43FAEDF33F400EF450DB861D4A40
24431	26361	32.236358000000003	32.286898000000001	52.498241999999998	52.469016000000003	Школьная	0103000020E61000000100000005000000F1129CFA401E40407FA65EB7083C4A40F1129CFA401E40402FBFD364C63F4A40D7A4DB12B92440402FBFD364C63F4A40D7A4DB12B92440407FA65EB7083C4A40F1129CFA401E40407FA65EB7083C4A40
24441	27055	32.298152999999999	32.322462000000002	52.199910000000003	52.190029000000003	Октябрьская	0103000020E61000000100000005000000261AA4E0292640405325CADE52184A40261AA4E0292640405A12A0A696194A40F419506F462940405A12A0A696194A40F419506F462940405325CADE52184A40261AA4E0292640405325CADE52184A40
25016	26967	32.240805000000002	32.275157	52.320596000000002	52.300857000000001	Ленина	0103000020E610000001000000050000004DDBBFB2D21E4040E7E26F7B82264A404DDBBFB2D21E40403D9D2B4A09294A40FB213658382340403D9D2B4A09294A40FB21365838234040E7E26F7B82264A404DDBBFB2D21E4040E7E26F7B82264A40
24945	27835	31.841100000000001	31.867079	52.181592000000002	52.153702000000003	Пролетарская	0103000020E6100000010000000500000065AA605452D73F4037AAD381AC134A4065AA605452D73F408D9B1A683E174A40630CACE3F8DD3F408D9B1A683E174A40630CACE3F8DD3F4037AAD381AC134A4065AA605452D73F4037AAD381AC134A40
25033	27480	32.167439999999999	32.200749000000002	52.210231	52.181460000000001	Мичурина	0103000020E61000000100000005000000680586AC6E1540401EC4CE143A174A40680586AC6E1540407DCD72D9E81A4A4034DAAA24B21940407DCD72D9E81A4A4034DAAA24B21940401EC4CE143A174A40680586AC6E1540401EC4CE143A174A40
24443	27095	32.201844999999999	32.241810999999998	52.357066000000003	52.330938000000003	Ленина	0103000020E6100000010000000500000039EE940ED61940407880272D5C2A4A4039EE940ED6194040BC41B456B42D4A401268B0A9F31E4040BC41B456B42D4A401268B0A9F31E40407880272D5C2A4A4039EE940ED61940407880272D5C2A4A40
24515	26389	32.278740999999997	32.313747999999997	52.497188999999999	52.469855000000003	Мира	0103000020E61000000100000005000000F486FBC8AD234040596E6935243C4A40F486FBC8AD23404029779FE3A33F4A40BB97FBE42828404029779FE3A33F4A40BB97FBE428284040596E6935243C4A40F486FBC8AD234040596E6935243C4A40
24518	26454	32.407955000000001	32.444156999999997	52.465575999999999	52.446714999999998	Центральная площадь	0103000020E61000000100000005000000AE9E93DE37344040FAD005F52D394A40AE9E93DE37344040B8E68EFE973B4A400DA5F622DA384040B8E68EFE973B4A400DA5F622DA384040FAD005F52D394A40AE9E93DE37344040FAD005F52D394A40
25019	26922	32.282198999999999	32.334113000000002	52.319026999999998	52.284404000000002	Ленина	0103000020E6100000010000000500000061FBC9181F244040016DAB5967244A4061FBC9181F2440403FC571E0D5284A409015FC36C42A40403FC571E0D5284A409015FC36C42A4040016DAB5967244A4061FBC9181F244040016DAB5967244A40
24446	27859	31.849688	31.872819	52.119889999999998	52.111820999999999	Советская	0103000020E61000000100000005000000BCCD1B2785D93F40C5008926500E4A40BCCD1B2785D93F40088F368E580F4A40D253E41071DF3F40088F368E580F4A40D253E41071DF3F40C5008926500E4A40BCCD1B2785D93F40C5008926500E4A40
24938	26762	32.267180000000003	32.293275999999999	52.389681000000003	52.368262999999999	Школьная	0103000020E61000000100000005000000991249F432224040D6A9F23D232F4A40991249F432224040B16F2711E1314A40D15966118A254040B16F2711E1314A40D15966118A254040D6A9F23D232F4A40991249F432224040D6A9F23D232F4A40
24982	26212	32.135719999999999	32.177185999999999	52.438552000000001	52.424858	Школьная	0103000020E61000000100000005000000E1B4E0455F114040D4B837BF61364A40E1B4E0455F11404036CCD07822384A408FA7E507AE16404036CCD07822384A408FA7E507AE164040D4B837BF61364A40E1B4E0455F114040D4B837BF61364A40
24520	26843	32.340724999999999	32.371518999999999	52.346691	52.321708000000001	Коммунистическая	0103000020E61000000100000005000000FDF675E09C2B4040486E4DBA2D294A40FDF675E09C2B4040A568E55E602C4A40DB6B41EF8D2F4040A568E55E602C4A40DB6B41EF8D2F4040486E4DBA2D294A40FDF675E09C2B4040486E4DBA2D294A40
24858	26744	32.311079999999997	32.342835999999998	52.420349000000002	52.398918000000002	Садовая	0103000020E6100000010000000500000047382D78D127404093E4B9BE0F334A4047382D78D127404002F4FBFECD354A401BF2CF0CE22B404002F4FBFECD354A401BF2CF0CE22B404093E4B9BE0F334A4047382D78D127404093E4B9BE0F334A40
24640	26291	32.127321000000002	32.155338999999998	52.495342000000001	52.474836000000003	Заречная	0103000020E61000000100000005000000098CF50D4C104040537B116DC73C4A40098CF50D4C104040E92ADD5D673F4A408C65FA25E2134040E92ADD5D673F4A408C65FA25E2134040537B116DC73C4A40098CF50D4C104040537B116DC73C4A40
24566	27339	32.092807999999998	32.134912	52.190022999999997	52.164563999999999	Советская	0103000020E610000001000000050000005167EE21E10B4040AA0CE36E10154A405167EE21E10B4040703E75AC52184A4042EBE1CB44114040703E75AC52184A4042EBE1CB44114040AA0CE36E10154A405167EE21E10B4040AA0CE36E10154A40
24883	26509	32.437373999999998	32.457973000000003	52.470629000000002	52.450859000000001	Гагарина	0103000020E61000000100000005000000730F09DFFB374040BB0D6ABFB5394A40730F09DFFB3740404CC631923D3C4A40BBB9F8DB9E3A40404CC631923D3C4A40BBB9F8DB9E3A4040BB0D6ABFB5394A40730F09DFFB374040BB0D6ABFB5394A40
25208	51141	32.129531	32.160837000000001	52.265123000000003	52.247073999999998	Заречная	0103000020E61000000100000005000000BA68C8789410404090D8EE1EA01F4A40BA68C878941040406E35EB8CEF214A404E7E8B4E961440406E35EB8CEF214A404E7E8B4E9614404090D8EE1EA01F4A40BA68C8789410404090D8EE1EA01F4A40
24415	25913	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	площадь Ленина	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
24841	25913	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	Советская	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
24753	25913	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	Полевая	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
24881	25913	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	Октябрьская	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
24639	25913	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	Лесная	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
24898	25913	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	Коммунистическая	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
24878	25913	32.139412	32.229593999999999	52.413549000000003	52.356592999999997	Брянская	0103000020E61000000100000005000000C1559E40D8114040C37DE4D6A42D4A40C1559E40D81140409225732CEF344A40CDAD1056631D40409225732CEF344A40CDAD1056631D4040C37DE4D6A42D4A40C1559E40D8114040C37DE4D6A42D4A40
24767	27585	32.146742000000003	32.175417000000003	52.117229999999999	52.093538000000002	Советская	0103000020E610000001000000050000008E791D71C812404075779D0DF90B4A408E791D71C8124040170E8464010F4A40CB14731074164040170E8464010F4A40CB1473107416404075779D0DF90B4A408E791D71C812404075779D0DF90B4A40
24603	51048	32.227133000000002	32.291739999999997	52.149790000000003	52.123472999999997	Ленина	0103000020E61000000100000005000000D36BB3B1121D4040317898F6CD0F4A40D36BB3B1121D404049A297512C134A40AF777FBC5725404049A297512C134A40AF777FBC57254040317898F6CD0F4A40D36BB3B1121D4040317898F6CD0F4A40
25098	26651	32.443913999999999	32.464782	52.428032000000002	52.408983999999997	Октябрьская	0103000020E61000000100000005000000471E882CD23840402B4B749659344A40471E882CD23840401CD2A8C0C9364A407EE200FA7D3B40401CD2A8C0C9364A407EE200FA7D3B40402B4B749659344A40471E882CD23840402B4B749659344A40
24451	27410	32.294910999999999	32.309795999999999	52.141295999999997	52.132500999999998	Набережная	0103000020E61000000100000005000000861DC6A4BF254040F9D7F2CAF5104A40861DC6A4BF2540401E87C1FC15124A403F373465A72740401E87C1FC15124A403F373465A7274040F9D7F2CAF5104A40861DC6A4BF254040F9D7F2CAF5104A40
24638	51052	32.080582	32.109642000000001	52.301071999999998	52.281655000000001	Первомайская	0103000020E61000000100000005000000B952CF82500A4040A0E062450D244A40B952CF82500A4040E3DEFC8689264A404F22C2BF080E4040E3DEFC8689264A404F22C2BF080E4040A0E062450D244A40B952CF82500A4040A0E062450D244A40
24848	27114	32.039150999999997	32.066685	52.334234000000002	52.322330000000001	Озерная	0103000020E61000000100000005000000874D64E6020540408542041C42294A40874D64E6020540400B9B012EC82A4A401F115322890840400B9B012EC82A4A401F115322890840408542041C42294A40874D64E6020540408542041C42294A40
24941	27646	32.063630000000003	32.089978000000002	52.144474000000002	52.127060999999998	Комсомольская	0103000020E61000000100000005000000B2852007250840406CCCEB8843104A40B285200725084040A88FC01F7E124A4004AE2B66840B4040A88FC01F7E124A4004AE2B66840B40406CCCEB8843104A40B2852007250840406CCCEB8843104A40
24746	26826	32.442791	32.471294999999998	52.371952	52.348413000000001	Цветная	0103000020E6100000010000000500000048FB1F60AD384040294014CC982C4A4048FB1F60AD38404045D7851F9C2F4A4058E20165533C404045D7851F9C2F4A4058E20165533C4040294014CC982C4A4048FB1F60AD384040294014CC982C4A40
24584	48489	33.377237000000001	33.386426999999998	53.353993000000003	53.349494	Понизовка	0103000020E61000000100000005000000ABEB504D49B04040F9122A38BCAC4A40ABEB504D49B04040A80183A44FAD4A404CA59F7076B14040A80183A44FAD4A404CA59F7076B14040F9122A38BCAC4A40ABEB504D49B04040F9122A38BCAC4A40
25162	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	улица Лесная	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
24771	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Первомайская	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
24497	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Орджоникидзе	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
25174	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Медведева	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
25166	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Ленина	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
25184	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Красных Партизан	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
25180	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Кирова	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
24409	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Карла Маркса	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
25229	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Гоголя	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
24712	51024	33.180658000000001	33.282482000000002	53.41816	53.369866000000002	Вокзальная	0103000020E6100000010000000500000061E124CD1F97404080F3E2C457AF4A4061E124CD1F974040683F524486B54A40B6DAC35E28A44040683F524486B54A40B6DAC35E28A4404080F3E2C457AF4A4061E124CD1F97404080F3E2C457AF4A40
24684	48187	35.266078999999998	35.284844999999997	53.073335	53.061816	Молодежная	0103000020E6100000010000000500000081936DE00EA241404D2F3196E9874A4081936DE00EA241407A53910A63894A40EDB60BCD75A441407A53910A63894A40EDB60BCD75A441404D2F3196E9874A4081936DE00EA241404D2F3196E9874A40
24470	47700	35.024531000000003	35.030253999999999	53.315353000000002	53.307816000000003	Школьная	0103000020E610000001000000050000007D5EF1D423834140C097C28366A74A407D5EF1D42383414006D9B27C5DA84A405E49F25CDF83414006D9B27C5DA84A405E49F25CDF834140C097C28366A74A407D5EF1D423834140C097C28366A74A40
24570	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Федюнинского	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24571	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Советская	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24973	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Свердлова	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24502	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Первомайская	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24680	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Кольцова	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24929	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	К.Либкнехта	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
25048	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Заводская	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24482	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Дзержинского	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24975	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Горького	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
24484	22361	34.959592000000001	35.013761000000002	53.138997000000003	53.108114	Володарского	0103000020E610000001000000050000006AC020E9D37A4140B01EF7ADD68D4A406AC020E9D37A4140FE9E58A7CA914A40EA7AA2EBC2814140FE9E58A7CA914A40EA7AA2EBC2814140B01EF7ADD68D4A406AC020E9D37A4140B01EF7ADD68D4A40
25046	22038	31.757251	31.799759000000002	52.299287	52.263888000000001	Ленина	0103000020E6100000010000000500000001DD9733DBC13F4047E7FC14C7214A4001DD9733DBC13F40198F52094F264A4082AE7D01BDCC3F40198F52094F264A4082AE7D01BDCC3F4047E7FC14C7214A4001DD9733DBC13F4047E7FC14C7214A40
24556	49354	31.929241999999999	31.950416000000001	52.379021999999999	52.367691000000001	Ленина	0103000020E61000000100000005000000D311C0CDE2ED3F404B04AA7F102F4A40D311C0CDE2ED3F40753BFBCA83304A405B9885764EF33F40753BFBCA83304A405B9885764EF33F404B04AA7F102F4A40D311C0CDE2ED3F404B04AA7F102F4A40
24557	22292	31.931677000000001	31.960692000000002	52.329909000000001	52.307850000000002	Ленина	0103000020E61000000100000005000000766F456282EE3F406C09F9A067274A40766F456282EE3F40FAD346753A2A4A40628731E9EFF53F40FAD346753A2A4A40628731E9EFF53F406C09F9A067274A40766F456282EE3F406C09F9A067274A40
24961	22137	31.841702000000002	31.870421	52.255443	52.242001000000002	Первомайская	0103000020E6100000010000000500000051FA42C879D73F40B64C86E3F91E4A4051FA42C879D73F40FE7E315BB2204A406AC020E9D3DE3F40FE7E315BB2204A406AC020E9D3DE3F40B64C86E3F91E4A4051FA42C879D73F40B64C86E3F91E4A40
24887	22182	31.881119999999999	31.919513999999999	52.305356000000003	52.289653999999999	Молодежная	0103000020E61000000100000005000000FDD98F1491E13F40EA93DC6113254A40FDD98F1491E13F4096D1C8E715274A40D236FE4465EB3F4096D1C8E715274A40D236FE4465EB3F40EA93DC6113254A40FDD98F1491E13F40EA93DC6113254A40
24967	21895	31.624624000000001	31.655759	52.348336000000003	52.329832000000003	Молодежная	0103000020E61000000100000005000000F54BC45BE79F3F404F965AEF372A4A40F54BC45BE79F3F407E022846962C4A40C30E63D2DFA73F407E022846962C4A40C30E63D2DFA73F404F965AEF372A4A40F54BC45BE79F3F404F965AEF372A4A40
24886	49297	31.811886000000001	31.845223000000001	52.220483000000002	52.206820999999998	Школьная	0103000020E610000001000000050000008C14CAC2D7CF3F4021904B1C791A4A408C14CAC2D7CF3F40782975C9381C4A40B7D3D68860D83F40782975C9381C4A40B7D3D68860D83F4021904B1C791A4A408C14CAC2D7CF3F4021904B1C791A4A40
25186	51131	31.533238000000001	32.051898000000001	52.552571999999998	52.184198000000002	Молодежная	0103000020E6100000010000000500000005FC1A4982883F408BFED0CC93174A4005FC1A4982883F40B857E6ADBA464A40295DFA97A4064040B857E6ADBA464A40295DFA97A40640408BFED0CC93174A4005FC1A4982883F408BFED0CC93174A40
24958	21722	31.703665999999998	31.760242000000002	52.441895000000002	52.409896000000003	площадь Свободы	0103000020E61000000100000005000000A04E797423B43F407061DD7877344A40A04E797423B43F400AA2EE0390384A40AF0B3F389FC23F400AA2EE0390384A40AF0B3F389FC23F407061DD7877344A40A04E797423B43F407061DD7877344A40
24742	21722	31.703665999999998	31.760242000000002	52.441895000000002	52.409896000000003	Республиканская	0103000020E61000000100000005000000A04E797423B43F407061DD7877344A40A04E797423B43F400AA2EE0390384A40AF0B3F389FC23F400AA2EE0390384A40AF0B3F389FC23F407061DD7877344A40A04E797423B43F407061DD7877344A40
24468	21722	31.703665999999998	31.760242000000002	52.441895000000002	52.409896000000003	Коммунальная	0103000020E61000000100000005000000A04E797423B43F407061DD7877344A40A04E797423B43F400AA2EE0390384A40AF0B3F389FC23F400AA2EE0390384A40AF0B3F389FC23F407061DD7877344A40A04E797423B43F407061DD7877344A40
25128	21583	31.619403999999999	31.657691	52.490884000000001	52.469307000000001	Школьная	0103000020E61000000100000005000000F702B342919E3F4056647440123C4A40F702B342919E3F4099107349D53E4A40A0DFF76F5EA83F4099107349D53E4A40A0DFF76F5EA83F4056647440123C4A40F702B342919E3F4056647440123C4A40
25045	21945	31.681756	31.728406	52.322049	52.294913999999999	Злынковская	0103000020E610000001000000050000000EDAAB8F87AE3F40F790F0BDBF254A400EDAAB8F87AE3F40D15AD1E638294A40CE35CCD078BA3F40D15AD1E638294A40CE35CCD078BA3F40F790F0BDBF254A400EDAAB8F87AE3F40F790F0BDBF254A40
24885	21640	31.653009999999998	31.704259	52.488005000000001	52.464967000000001	Школьная	0103000020E6100000010000000500000001F6D1A92BA73F40105CE509843B4A4001F6D1A92BA73F406AA4A5F2763E4A40E6E95C514AB43F406AA4A5F2763E4A40E6E95C514AB43F40105CE509843B4A4001F6D1A92BA73F40105CE509843B4A40
24673	21640	31.653009999999998	31.704259	52.488005000000001	52.464967000000001	Клубная площадь	0103000020E6100000010000000500000001F6D1A92BA73F40105CE509843B4A4001F6D1A92BA73F406AA4A5F2763E4A40E6E95C514AB43F406AA4A5F2763E4A40E6E95C514AB43F40105CE509843B4A4001F6D1A92BA73F40105CE509843B4A40
24475	22206	31.844873	31.885009	52.328808000000002	52.304133	Центральная	0103000020E61000000100000005000000FE45D09849D83F40335184D4ED264A40FE45D09849D83F40E3546B61162A4A4069AA27F38FE23F40E3546B61162A4A4069AA27F38FE23F40335184D4ED264A40FE45D09849D83F40335184D4ED264A40
24972	51091	33.792653999999999	33.803083000000001	53.629553999999999	53.621035999999997	Школьная	0103000020E610000001000000050000009485AFAF75E54040BFD18E1B7ECF4A409485AFAF75E540407288B83995D04A409E7C7A6CCBE640407288B83995D04A409E7C7A6CCBE64040BFD18E1B7ECF4A409485AFAF75E54040BFD18E1B7ECF4A40
24473	47848	33.904682999999999	33.937362999999998	53.381920999999998	53.362096999999999	70 лет Октября	0103000020E61000000100000005000000A31F0DA7CCF34040677DCA3159AE4A40A31F0DA7CCF34040EB538EC9E2B04A407FBDC282FBF74040EB538EC9E2B04A407FBDC282FBF74040677DCA3159AE4A40A31F0DA7CCF34040677DCA3159AE4A40
24750	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	переулок Школьный	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
25113	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	пер. Первомайский	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
25030	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Смоленская	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24988	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Переулок Первомайский	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24663	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Ленина	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24715	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Краснофокинская	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24784	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Карла Маркса	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
25073	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Карла Либкнехта	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24897	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Калинина	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24947	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Калина	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24717	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Заречная	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24559	8782	33.694431999999999	33.771039999999999	53.551366999999999	53.508029000000001	Дзержинского	0103000020E61000000100000005000000DFA5D425E3D84040B535221807C14A40DFA5D425E3D84040FC8BA03193C64A4034F44F70B1E24040FC8BA03193C64A4034F44F70B1E24040B535221807C14A40DFA5D425E3D84040B535221807C14A40
24613	47662	33.531433	33.543990999999998	53.155355999999998	53.151224999999997	Молодежная	0103000020E61000000100000005000000F1811DFF05C4404036AB3E575B934A40F1811DFF05C44040629E95B4E2934A40BF28417FA1C54040629E95B4E2934A40BF28417FA1C5404036AB3E575B934A40F1811DFF05C4404036AB3E575B934A40
24944	18895	33.872900000000001	33.909362999999999	53.274093000000001	53.256072000000003	Школьная	0103000020E61000000100000005000000D656EC2FBBEF4040EEB5A0F7C6A04A40D656EC2FBBEF40400188BB7A15A34A40A298BC0166F440400188BB7A15A34A40A298BC0166F44040EEB5A0F7C6A04A40D656EC2FBBEF4040EEB5A0F7C6A04A40
24535	19364	33.674973999999999	33.720275999999998	53.203370999999997	53.171768	Юбилейная	0103000020E610000001000000050000003DD34B8C65D64040EA3F6B7EFC954A403DD34B8C65D6404037FA980F089A4A40FE0B040132DC404037FA980F089A4A40FE0B040132DC4040EA3F6B7EFC954A403DD34B8C65D64040EA3F6B7EFC954A40
24661	19603	33.347960999999998	33.366798000000003	53.141140999999998	53.124614999999999	Набережная	0103000020E6100000010000000500000048A46DFC89AC4040A7CB6262F38F4A4048A46DFC89AC4040F78F85E810924A407E1EA33CF3AE4040F78F85E810924A407E1EA33CF3AE4040A7CB6262F38F4A4048A46DFC89AC4040A7CB6262F38F4A40
24458	19261	33.587622000000003	33.622405000000001	53.308978000000003	53.295498000000002	Пролетарская	0103000020E610000001000000050000007F349C3237CB40404704E3E0D2A54A407F349C3237CB40407D9752978CA74A40F6EE8FF7AACF40407D9752978CA74A40F6EE8FF7AACF40404704E3E0D2A54A407F349C3237CB40404704E3E0D2A54A40
24662	19655	33.531765	33.541097999999998	53.201720000000002	53.191113999999999	Клубная	0103000020E61000000100000005000000271422E010C4404064E76D6C76984A40271422E010C440407D7901F6D1994A402BF702B342C540407D7901F6D1994A402BF702B342C5404064E76D6C76984A40271422E010C4404064E76D6C76984A40
25106	18978	33.730849999999997	33.761643999999997	53.223441000000001	53.207447999999999	Полевая	0103000020E610000001000000050000000B24287E8CDD404070CFF3A78D9A4A400B24287E8CDD4040F3CAF5B6999C4A40E998F38C7DE14040F3CAF5B6999C4A40E998F38C7DE1404070CFF3A78D9A4A400B24287E8CDD404070CFF3A78D9A4A40
24537	19447	33.572324000000002	33.597414000000001	53.128554000000001	53.117784	Центральная	0103000020E61000000100000005000000A35BAFE941C94040FCFECD8B138F4A40A35BAFE941C940408FE21C7574904A401616DC0F78CC40408FE21C7574904A401616DC0F78CC4040FCFECD8B138F4A40A35BAFE941C94040FCFECD8B138F4A40
24777	19193	33.669790999999996	33.695860000000003	53.302827999999998	53.285378000000001	Пришкольная	0103000020E61000000100000005000000DB1324B6BBD54040BB7F2C4487A44A40DB1324B6BBD5404013286211C3A64A401B4CC3F011D9404013286211C3A64A401B4CC3F011D94040BB7F2C4487A44A40DB1324B6BBD54040BB7F2C4487A44A40
25028	19002	33.712649999999996	33.753343000000001	53.235903999999998	53.217030999999999	Молодежная	0103000020E6100000010000000500000048BF7D1D38DB4040ED9BFBABC79B4A4048BF7D1D38DB40406F7F2E1A329E4A40D4D51D8B6DE040406F7F2E1A329E4A40D4D51D8B6DE04040ED9BFBABC79B4A4048BF7D1D38DB4040ED9BFBABC79B4A40
24534	19002	33.712649999999996	33.753343000000001	53.235903999999998	53.217030999999999	Мира	0103000020E6100000010000000500000048BF7D1D38DB4040ED9BFBABC79B4A4048BF7D1D38DB40406F7F2E1A329E4A40D4D51D8B6DE040406F7F2E1A329E4A40D4D51D8B6DE04040ED9BFBABC79B4A4048BF7D1D38DB4040ED9BFBABC79B4A40
25278	19002	33.712649999999996	33.753343000000001	53.235903999999998	53.217030999999999	Ленина	0103000020E6100000010000000500000048BF7D1D38DB4040ED9BFBABC79B4A4048BF7D1D38DB40406F7F2E1A329E4A40D4D51D8B6DE040406F7F2E1A329E4A40D4D51D8B6DE04040ED9BFBABC79B4A4048BF7D1D38DB4040ED9BFBABC79B4A40
24862	19278	33.382078999999997	33.593237000000002	53.272058000000001	53.108828000000003	Центральная	0103000020E6100000010000000500000083BEF4F6E7B04040CE716E13EE8D4A4083BEF4F6E7B04040BE4EEACBD2A24A407AE3A430EFCB4040BE4EEACBD2A24A407AE3A430EFCB4040CE716E13EE8D4A4083BEF4F6E7B04040CE716E13EE8D4A40
24939	19278	33.382078999999997	33.593237000000002	53.272058000000001	53.108828000000003	Дружбы	0103000020E6100000010000000500000083BEF4F6E7B04040CE716E13EE8D4A4083BEF4F6E7B04040BE4EEACBD2A24A407AE3A430EFCB4040BE4EEACBD2A24A407AE3A430EFCB4040CE716E13EE8D4A4083BEF4F6E7B04040CE716E13EE8D4A40
24796	19486	33.488996	33.521577999999998	53.158957000000001	53.147995000000002	Центральная	0103000020E61000000100000005000000FAEFC16B97BE40405B7C0A80F1924A40FAEFC16B97BE4040323CF6B358944A4013286211C3C24040323CF6B358944A4013286211C3C240405B7C0A80F1924A40FAEFC16B97BE40405B7C0A80F1924A40
24865	19527	33.419898000000003	33.459082000000002	53.175669999999997	53.160874	Молодежная	0103000020E61000000100000005000000F2D3B837BFB540406B63EC8497944A40F2D3B837BFB54040B471C45A7C964A405517F032C3BA4040B471C45A7C964A405517F032C3BA40406B63EC8497944A40F2D3B837BFB540406B63EC8497944A40
24769	18533	34.259588999999998	34.295216000000003	53.581555000000002	53.569685	переулок Мира	0103000020E610000001000000050000005FB35C363A214140C9022670EBC84A405FB35C363A214140A3E9EC6470CA4A40C3A04CA3C9254140A3E9EC6470CA4A40C3A04CA3C9254140C9022670EBC84A405FB35C363A214140C9022670EBC84A40
24896	48156	34.36842	34.449969000000003	53.485225999999997	53.410888	площадь Ленина	0103000020E610000001000000050000009E98F562282F4140D0285DFA97B44A409E98F562282F41409E95B4E21BBE4A405F9B8D95983941409E95B4E21BBE4A405F9B8D9598394140D0285DFA97B44A409E98F562282F4140D0285DFA97B44A40
24773	48156	34.36842	34.449969000000003	53.485225999999997	53.410888	К.Маркса	0103000020E610000001000000050000009E98F562282F4140D0285DFA97B44A409E98F562282F41409E95B4E21BBE4A405F9B8D95983941409E95B4E21BBE4A405F9B8D9598394140D0285DFA97B44A409E98F562282F4140D0285DFA97B44A40
25021	48156	34.36842	34.449969000000003	53.485225999999997	53.410888	Гайдара	0103000020E610000001000000050000009E98F562282F4140D0285DFA97B44A409E98F562282F41409E95B4E21BBE4A405F9B8D95983941409E95B4E21BBE4A405F9B8D9598394140D0285DFA97B44A409E98F562282F4140D0285DFA97B44A40
24538	18024	34.056812000000001	34.179845999999998	53.640424000000003	53.608894999999997	Ленина	0103000020E610000001000000050000009B02999D4507414055D97745F0CD4A409B02999D4507414069C9E369F9D14A40802898310517414069C9E369F9D14A40802898310517414055D97745F0CD4A409B02999D4507414055D97745F0CD4A40
24772	18024	34.056812000000001	34.179845999999998	53.640424000000003	53.608894999999997	 площадь 30 лет Победы	0103000020E610000001000000050000009B02999D4507414055D97745F0CD4A409B02999D4507414069C9E369F9D14A40802898310517414069C9E369F9D14A40802898310517414055D97745F0CD4A409B02999D4507414055D97745F0CD4A40
24664	19689	34.103138000000001	34.120206000000003	53.880926000000002	53.865048000000002	Пролетарская	0103000020E61000000100000005000000C87C40A0330D414030BC92E4B9EE4A40C87C40A0330D41401A19E42EC2F04A40396403E9620F41401A19E42EC2F04A40396403E9620F414030BC92E4B9EE4A40C87C40A0330D414030BC92E4B9EE4A40
24665	48010	34.353679	34.374079000000002	53.547621999999997	53.540179000000002	Советская	0103000020E6100000010000000500000018247D5A452D4140357EE19524C54A4018247D5A452D4140F9484A7A18C64A40698F17D2E12F4140F9484A7A18C64A40698F17D2E12F4140357EE19524C54A4018247D5A452D4140357EE19524C54A40
25029	18179	34.434814000000003	34.460020999999998	53.520237000000002	53.50676	Советская	0103000020E61000000100000005000000E6EB32FCA7374140E275FD82DDC04A40E6EB32FCA7374140A795422097C24A40923CD7F7E13A4140A795422097C24A40923CD7F7E13A4140E275FD82DDC04A40E6EB32FCA7374140E275FD82DDC04A40
24453	18447	33.976799	34.025379999999998	53.873387999999998	53.828017000000003	Школьная	0103000020E61000000100000005000000FCE1E7BF07FD40401AC40776FCE94A40FCE1E7BF07FD4040035C902DCBEF4A407AFCDEA63F034140035C902DCBEF4A407AFCDEA63F0341401AC40776FCE94A40FCE1E7BF07FD40401AC40776FCE94A40
25031	18280	34.385613999999997	34.401918000000002	53.535046999999999	53.520794000000002	Озерная	0103000020E610000001000000050000009B70AFCC5B314140FDF9B660A9C24A409B70AFCC5B31414055698B6B7CC44A403DD68C0C7233414055698B6B7CC44A403DD68C0C72334140FDF9B660A9C24A409B70AFCC5B314140FDF9B660A9C24A40
24438	17937	34.349285999999999	34.402546999999998	53.520563000000003	53.490851999999997	Пушкина	0103000020E61000000100000005000000AF795567B52C41408D96033DD4BE4A40AF795567B52C4140FB40F2CEA1C24A402C0DFCA886334140FB40F2CEA1C24A402C0DFCA8863341408D96033DD4BE4A40AF795567B52C41408D96033DD4BE4A40
24766	17937	34.349285999999999	34.402546999999998	53.520563000000003	53.490851999999997	 Брянская	0103000020E61000000100000005000000AF795567B52C41408D96033DD4BE4A40AF795567B52C4140FB40F2CEA1C24A402C0DFCA886334140FB40F2CEA1C24A402C0DFCA8863341408D96033DD4BE4A40AF795567B52C41408D96033DD4BE4A40
24765	17733	34.156525000000002	34.248944000000002	53.700991000000002	53.661696999999997	Пролетарская	0103000020E61000000100000005000000D200DE02091441403F6EBF7CB2D44A40D200DE02091441402AE5B512BAD94A408944A165DD1F41402AE5B512BAD94A408944A165DD1F41403F6EBF7CB2D44A40D200DE02091441403F6EBF7CB2D44A40
24523	17733	34.156525000000002	34.248944000000002	53.700991000000002	53.661696999999997	Горохова	0103000020E61000000100000005000000D200DE02091441403F6EBF7CB2D44A40D200DE02091441402AE5B512BAD94A408944A165DD1F41402AE5B512BAD94A408944A165DD1F41403F6EBF7CB2D44A40D200DE02091441403F6EBF7CB2D44A40
24697	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	площадь Ленина	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24873	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	Орджоникидзе	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24822	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	Ленина	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24513	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	Крупской	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24440	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	Краснофлотская	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24495	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	Красина	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
25093	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	Киевская	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24609	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	Карла Маркса	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24667	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	В.Рябка	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24521	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	13 микрорайон	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
24676	16658	34.295369000000001	34.38794	53.638966000000003	53.571739000000001	12 микрорайон	0103000020E6100000010000000500000049A0C1A6CE254140836C59BE2EC94A4049A0C1A6CE254140C3A04CA3C9D14A40B6679604A8314140C3A04CA3C9D14A40B6679604A8314140836C59BE2EC94A4049A0C1A6CE254140836C59BE2EC94A40
25060	48050	34.360173000000003	34.384338	53.582569999999997	53.560487000000002	Октябрьская	0103000020E610000001000000050000007CF31B261A2E4140A56ABB09BEC74A407CF31B261A2E4140BBD05CA791CA4A40164ED2FC31314140BBD05CA791CA4A40164ED2FC31314140A56ABB09BEC74A407CF31B261A2E4140A56ABB09BEC74A40
24978	48072	34.467413999999998	34.510057000000003	53.441879	53.431590999999997	Рябка	0103000020E61000000100000005000000A5D8D138D43B4140BC1FB75F3EB74A40A5D8D138D43B414004E5B67D8FB84A40460C3B8C4941414004E5B67D8FB84A40460C3B8C49414140BC1FB75F3EB74A40A5D8D138D43B4140BC1FB75F3EB74A40
25087	17602	34.045214999999999	34.204360999999999	53.843628000000002	53.766655	Ленина	0103000020E61000000100000005000000F224E99AC90541404E2844C021E24A40F224E99AC9054140B5FE9600FCEB4A40F7C95180281A4140B5FE9600FCEB4A40F7C95180281A41404E2844C021E24A40F224E99AC90541404E2844C021E24A40
25012	17602	34.045214999999999	34.204360999999999	53.843628000000002	53.766655	Алексеева	0103000020E61000000100000005000000F224E99AC90541404E2844C021E24A40F224E99AC9054140B5FE9600FCEB4A40F7C95180281A4140B5FE9600FCEB4A40F7C95180281A41404E2844C021E24A40F224E99AC90541404E2844C021E24A40
24644	17707	34.146365000000003	34.175156000000001	53.848855	53.831589000000001	Центральная	0103000020E61000000100000005000000B8239C16BC1241404F5B238271EA4A40B8239C16BC124140E605D847A7EC4A405ED905836B164140E605D847A7EC4A405ED905836B1641404F5B238271EA4A40B8239C16BC1241404F5B238271EA4A40
25043	47982	34.429414999999999	34.460740000000001	53.492249999999999	53.480029000000002	Керамическая	0103000020E61000000100000005000000B7B41A12F7364140D8101C9771BD4A40B7B41A12F73641405EBA490C02BF4A40C2FA3F87F93A41405EBA490C02BF4A40C2FA3F87F93A4140D8101C9771BD4A40B7B41A12F7364140D8101C9771BD4A40
24964	17827	33.957441000000003	34.020843999999997	53.737298000000003	53.712333000000001	Приозерная	0103000020E61000000100000005000000BE6C3B6D8DFA4040486E4DBA2DDB4A40BE6C3B6D8DFA4040FFB3E6C75FDE4A40AE282504AB024140FFB3E6C75FDE4A40AE282504AB024140486E4DBA2DDB4A40BE6C3B6D8DFA4040486E4DBA2DDB4A40
24925	16689	33.283524999999997	33.30265	53.687305000000002	53.67051	Центральная	0103000020E61000000100000005000000984C158C4AA440400BD28C45D3D54A40984C158C4AA440404BB0389CF9D74A403411363CBDA640404BB0389CF9D74A403411363CBDA640400BD28C45D3D54A40984C158C4AA440400BD28C45D3D54A40
24752	16449	33.383318000000003	33.404204	53.723261000000001	53.712145999999997	Центральная	0103000020E61000000100000005000000ECFB709010B1404015FDA19927DB4A40ECFB709010B1404073BC02D193DC4A40C974E8F4BCB3404073BC02D193DC4A40C974E8F4BCB3404015FDA19927DB4A40ECFB709010B1404015FDA19927DB4A40
25085	16374	33.353782000000002	33.375520999999999	53.587862000000001	53.571407000000001	Центральная	0103000020E61000000100000005000000EDF483BA48AD40404DDA54DD23C94A40EDF483BA48AD4040D447E00F3FCB4A4009FB761211B04040D447E00F3FCB4A4009FB761211B040404DDA54DD23C94A40EDF483BA48AD40404DDA54DD23C94A40
24616	16354	33.446810999999997	33.486956999999997	53.579042000000001	53.553341000000003	Центральная	0103000020E610000001000000050000001C3F541A31B940409A44BDE0D3C64A401C3F541A31B9404056815A0C1ECA4A4075C7629B54BE404056815A0C1ECA4A4075C7629B54BE40409A44BDE0D3C64A401C3F541A31B940409A44BDE0D3C64A40
24423	51026	33.578288999999998	33.615496999999998	53.671550000000003	53.647705000000002	Журавлева	0103000020E610000001000000050000007A51BB5F05CA4040543A58FFE7D24A407A51BB5F05CA40407DD0B359F5D54A409FE40E9BC8CE40407DD0B359F5D54A409FE40E9BC8CE4040543A58FFE7D24A407A51BB5F05CA4040543A58FFE7D24A40
24580	16574	33.351958000000003	33.372987999999999	53.775019999999998	53.758766000000001	Центральная	0103000020E6100000010000000500000065C8B1F50CAD40408BA8893E1FE14A4065C8B1F50CAD40407ADFF8DA33E34A4075E61E12BEAF40407ADFF8DA33E34A4075E61E12BEAF40408BA8893E1FE14A4065C8B1F50CAD40408BA8893E1FE14A40
24607	16152	33.506199000000002	33.537649000000002	53.563406999999998	53.545439000000002	Калинина	0103000020E610000001000000050000004B22FB20CBC04040427BF5F1D0C54A404B22FB20CBC0404032AB77B81DC84A4012DDB3AED1C4404032AB77B81DC84A4012DDB3AED1C44040427BF5F1D0C54A404B22FB20CBC04040427BF5F1D0C54A40
24731	16165	33.564697000000002	33.599606000000001	53.598882000000003	53.585836	Центральная	0103000020E610000001000000050000001D93C5FD47C84040E4688EACFCCA4A401D93C5FD47C84040E014562AA8CC4A40213EB0E3BFCC4040E014562AA8CC4A40213EB0E3BFCC4040E4688EACFCCA4A401D93C5FD47C84040E4688EACFCCA4A40
24728	15970	33.480058	33.505687000000002	53.728104000000002	53.708244999999998	переулок Садовый	0103000020E610000001000000050000007217618A72BD40401B47ACC5A7DA4A407217618A72BD40401C0B0A8332DD4A409581035ABAC040401C0B0A8332DD4A409581035ABAC040401B47ACC5A7DA4A407217618A72BD40401B47ACC5A7DA4A40
25080	16068	33.487586	33.509891000000003	53.509860000000003	53.496240999999998	Клубная	0103000020E6100000010000000500000065FED13769BE404098F738D384BF4A4065FED13769BE4040F0C4AC1743C14A402BC3B81B44C14040F0C4AC1743C14A402BC3B81B44C1404098F738D384BF4A4065FED13769BE404098F738D384BF4A40
24838	16265	33.557160000000003	33.580489999999998	53.704807000000002	53.692487999999997	Совхозная	0103000020E61000000100000005000000D751D50451C74040AC6F6072A3D84A40D751D50451C74040F67EA31D37DA4A40D8D30E7F4DCA4040F67EA31D37DA4A40D8D30E7F4DCA4040AC6F6072A3D84A40D751D50451C74040AC6F6072A3D84A40
24421	15779	33.468145999999997	33.532626999999998	53.7042	53.675364000000002	переулок Матросова	0103000020E6100000010000000500000069E04735ECBB4040A872DA5372D64A4069E04735ECBB4040EEEBC03923DA4A40B9FB1C1F2DC44040EEEBC03923DA4A40B9FB1C1F2DC44040A872DA5372D64A4069E04735ECBB4040A872DA5372D64A40
24726	15779	33.468145999999997	33.532626999999998	53.7042	53.675364000000002	Ленина	0103000020E6100000010000000500000069E04735ECBB4040A872DA5372D64A4069E04735ECBB4040EEEBC03923DA4A40B9FB1C1F2DC44040EEEBC03923DA4A40B9FB1C1F2DC44040A872DA5372D64A4069E04735ECBB4040A872DA5372D64A40
24725	15779	33.468145999999997	33.532626999999998	53.7042	53.675364000000002	60 лет Октября	0103000020E6100000010000000500000069E04735ECBB4040A872DA5372D64A4069E04735ECBB4040EEEBC03923DA4A40B9FB1C1F2DC44040EEEBC03923DA4A40B9FB1C1F2DC44040A872DA5372D64A4069E04735ECBB4040A872DA5372D64A40
24839	15779	33.468145999999997	33.532626999999998	53.7042	53.675364000000002	1-ый Микрорайон	0103000020E6100000010000000500000069E04735ECBB4040A872DA5372D64A4069E04735ECBB4040EEEBC03923DA4A40B9FB1C1F2DC44040EEEBC03923DA4A40B9FB1C1F2DC44040A872DA5372D64A4069E04735ECBB4040A872DA5372D64A40
25145	51113	33.475727999999997	33.501455999999997	53.682009999999998	53.664577999999999	Центральная	0103000020E610000001000000050000004FE5B4A7E4BC40400FD253E410D54A404FE5B4A7E4BC4040C1C58A1A4CD74A400531D0B52FC04040C1C58A1A4CD74A400531D0B52FC040400FD253E410D54A404FE5B4A7E4BC40400FD253E410D54A40
24635	16565	33.289876	33.318953999999998	53.748161000000003	53.736306999999996	Центральная	0103000020E6100000010000000500000099F221A81AA540406E68CA4E3FDE4A4099F221A81AA54040439259BDC3DF4A40D576137CD3A84040439259BDC3DF4A40D576137CD3A840406E68CA4E3FDE4A4099F221A81AA540406E68CA4E3FDE4A40
24587	9932	33.606864000000002	33.630220000000001	53.606842999999998	53.594088999999997	Центральная	0103000020E61000000100000005000000548F34B8ADCD4040E8F4BC1B0BCC4A40548F34B8ADCD40403C670B08ADCD4A407FA4880CABD040403C670B08ADCD4A407FA4880CABD04040E8F4BC1B0BCC4A40548F34B8ADCD4040E8F4BC1B0BCC4A40
24761	16789	33.119734999999999	33.413564999999998	53.686463000000003	53.586557999999997	Школьная	0103000020E61000000100000005000000E197FA79538F4040849A215514CB4A40E197FA79538F404000750305DED74A4097E2AAB2EFB4404000750305DED74A4097E2AAB2EFB44040849A215514CB4A40E197FA79538F4040849A215514CB4A40
24727	16044	33.444287000000003	33.527659999999997	53.644550000000002	53.477145	Административная	0103000020E61000000100000005000000DC847B65DEB8404097395D1613BD4A40DC847B65DEB840408351499D80D24A4024B4E55C8AC340408351499D80D24A4024B4E55C8AC3404097395D1613BD4A40DC847B65DEB8404097395D1613BD4A40
25058	16754	33.154184999999998	33.279840999999998	53.649984000000003	53.627861000000003	Лесная	0103000020E6100000010000000500000052448655BC93404089B7CEBF5DD04A4052448655BC9340402E76FBAC32D34A403B8A73D4D1A340402E76FBAC32D34A403B8A73D4D1A3404089B7CEBF5DD04A4052448655BC93404089B7CEBF5DD04A40
24948	47024	31.825316000000001	31.852696999999999	52.991081999999999	52.978471999999996	Центральная	0103000020E6100000010000000500000094DDCCE847D33F409E060C923E7D4A4094DDCCE847D33F40BFD364C6DB7E4A40B665C0594ADA3F40BFD364C6DB7E4A40B665C0594ADA3F409E060C923E7D4A4094DDCCE847D33F409E060C923E7D4A40
25069	45572	31.897145999999999	31.917672	53.073357000000001	53.056463000000001	Дорожная	0103000020E61000000100000005000000BABC395CABE53F408F37F92D3A874A40BABC395CABE53F4062F71DC363894A4075745C8DECEA3F4062F71DC363894A4075745C8DECEA3F408F37F92D3A874A40BABC395CABE53F408F37F92D3A874A40
24713	46807	32.085656999999998	32.107737999999998	52.963982000000001	52.951276999999997	Совхозная	0103000020E6100000010000000500000034D6FECEF60A4040EF37DA71C3794A4034D6FECEF60A404062F71DC3637B4A40AA44D95BCA0D404062F71DC3637B4A40AA44D95BCA0D4040EF37DA71C3794A4034D6FECEF60A4040EF37DA71C3794A40
25257	51148	31.779565000000002	31.806694	53.055311000000003	53.045448	Центральная	0103000020E61000000100000005000000331B649291C73F4095D5743DD1854A40331B649291C73F40F60D4C6E14874A4022E17B7F83CE3F40F60D4C6E14874A4022E17B7F83CE3F4095D5743DD1854A40331B649291C73F4095D5743DD1854A40
24422	15575	31.797082	31.821804	53.012537000000002	52.992784	Красногорская	0103000020E61000000100000005000000F33AE2900DCC3F40FCFECD8B137F4A40F33AE2900DCC3F40B77EFACF9A814A40D4B837BF61D23F40B77EFACF9A814A40D4B837BF61D23F40FCFECD8B137F4A40F33AE2900DCC3F40FCFECD8B137F4A40
24827	15122	32.017232	32.066217000000002	52.948369	52.921709	Школьная	0103000020E61000000100000005000000EB387EA834024040E5B67D8FFA754A40EB387EA83402404026C5C72764794A4039B874CC7908404026C5C72764794A4039B874CC79084040E5B67D8FFA754A40EB387EA834024040E5B67D8FFA754A40
25142	51109	31.994046999999998	32.046804999999999	53.059596999999997	53.026090000000003	Юбилейная	0103000020E61000000100000005000000D9AF3BDD79FE3F405760C8EA56834A40D9AF3BDD79FE3F4048F8DEDFA0874A400725CCB4FD05404048F8DEDFA0874A400725CCB4FD0540405760C8EA56834A40D9AF3BDD79FE3F405760C8EA56834A40
24670	20747	32.066352000000002	32.085118000000001	53.022855999999997	53.008488999999997	Цветочная	0103000020E610000001000000050000001903EB387E08404018B0E42A16814A401903EB387E084040394206F2EC824A4085268925E50A4040394206F2EC824A4085268925E50A404018B0E42A16814A401903EB387E08404018B0E42A16814A40
24949	11217	31.907700999999999	31.928569	53.018182000000003	53.005585000000004	Школьная	0103000020E61000000100000005000000E78BBD175FE83F40912C6002B7804A40E78BBD175FE83F401DB0ABC953824A405514AFB2B6ED3F401DB0ABC953824A405514AFB2B6ED3F40912C6002B7804A40E78BBD175FE83F40912C6002B7804A40
25072	15324	31.829763	31.857135	52.950614999999999	52.936235000000003	Школьная	0103000020E610000001000000050000004C6E14596BD43F406F2F698CD6774A404C6E14596BD43F40240B98C0AD794A40C84109336DDB3F40240B98C0AD794A40C84109336DDB3F406F2F698CD6774A404C6E14596BD43F406F2F698CD6774A40
24830	15494	31.825234999999999	31.865210000000001	52.810504000000002	52.793371	Советская	0103000020E61000000100000005000000BA83D89942D33F40234C512E8D654A40BA83D89942D33F407BA35698BE674A40132C0E677EDD3F407BA35698BE674A40132C0E677EDD3F40234C512E8D654A40BA83D89942D33F40234C512E8D654A40
24411	15198	31.945098000000002	31.969729000000001	53.000627000000001	52.986583000000003	Центральная	0103000020E61000000100000005000000D88349F1F1F13F4011E50B5A487E4A40D88349F1F1F13F404F3FA88B14804A4098FBE42840F83F404F3FA88B14804A4098FBE42840F83F4011E50B5A487E4A40D88349F1F1F13F4011E50B5A487E4A40
25003	51096	31.894504000000001	31.932601999999999	52.989477999999998	52.975164999999997	Первомайская	0103000020E610000001000000050000002524D236FEE43F40179AEB34D27C4A402524D236FEE43F40450E1137A77E4A40272F3201BFEE3F40450E1137A77E4A40272F3201BFEE3F40179AEB34D27C4A402524D236FEE43F40179AEB34D27C4A40
24405	46762	31.962273	31.992671999999999	52.913525999999997	52.891457000000003	Красноармейская	0103000020E61000000100000005000000E5D2F88557F63F40286552431B724A40E5D2F88557F63F40D905836BEE744A40A8A78FC01FFE3F40D905836BEE744A40A8A78FC01FFE3F40286552431B724A40E5D2F88557F63F40286552431B724A40
74991	15366	31.755230000000001	31.781056	52.867083000000001	52.851081000000001	Красногорская	0103000020E6100000010000000500000045F5D6C056C13F409D9FE238F06C4A4045F5D6C056C13F4073F56393FC6E4A4036583849F3C73F4073F56393FC6E4A4036583849F3C73F409D9FE238F06C4A4045F5D6C056C13F409D9FE238F06C4A40
24599	15420	31.827283999999999	31.859397999999999	52.892783000000001	52.875894000000002	Гордеевская	0103000020E610000001000000050000000A815CE2C8D33F409E616A4B1D704A400A815CE2C8D33F405FB69DB646724A40703FE08101DC3F405FB69DB646724A40703FE08101DC3F409E616A4B1D704A400A815CE2C8D33F409E616A4B1D704A40
24831	46281	31.725629999999999	31.741368999999999	52.825100999999997	52.814324999999997	Ленина	0103000020E6100000010000000500000019FF3EE3C2B93F4058A835CD3B684A4019FF3EE3C2B93F40CD72D9E89C694A40AA44D95BCABD3F40CD72D9E89C694A40AA44D95BCABD3F4058A835CD3B684A4019FF3EE3C2B93F4058A835CD3B684A40
24912	15482	31.70187	31.730086	52.890369999999997	52.873474999999999	Школьная	0103000020E61000000100000005000000240B98C0ADB33F40D26F5F07CE6F4A40240B98C0ADB33F4075ABE7A4F7714A40784485EAE6BA3F4075ABE7A4F7714A40784485EAE6BA3F40D26F5F07CE6F4A40240B98C0ADB33F40D26F5F07CE6F4A40
24668	47041	31.709603999999999	31.733696999999999	52.955058999999999	52.943339000000002	Недоливко	0103000020E610000001000000050000005C1C959BA8B53F404B051555BF784A405C1C959BA8B53F400F60915F3F7A4A405E2C0C91D3BB3F400F60915F3F7A4A405E2C0C91D3BB3F404B051555BF784A405C1C959BA8B53F404B051555BF784A40
24491	49234	31.708580000000001	31.740416	52.806209000000003	52.774825	Садовая	0103000020E610000001000000050000008599B67F65B53F40C58F31772D634A408599B67F65B53F40D55E44DB31674A40656F29E78BBD3F40D55E44DB31674A40656F29E78BBD3F40C58F31772D634A408599B67F65B53F40C58F31772D634A40
24998	51094	31.934011999999999	31.946400000000001	52.898780000000002	52.880806999999997	улица Школьная	0103000020E61000000100000005000000511212691BEF3F403F8BA548BE704A40511212691BEF3F40422619390B734A4035EF384547F23F40422619390B734A4035EF384547F23F403F8BA548BE704A40511212691BEF3F403F8BA548BE704A40
24403	46715	31.951637000000002	31.989671999999999	52.970235000000002	52.942323999999999	Ленина	0103000020E61000000100000005000000DFA9807B9EF33F40321EA5129E784A40DFA9807B9EF33F40A03715A9307C4A4054C4E9245BFD3F40A03715A9307C4A4054C4E9245BFD3F40321EA5129E784A40DFA9807B9EF33F40321EA5129E784A40
25144	51112	31.955024000000002	31.968705	53.045665	53.033282	Буденного	0103000020E6100000010000000500000026E5EE737CF43F40D2C5A69542844A4026E5EE737CF43F4032C9C859D8854A40C078060DFDF73F4032C9C859D8854A40C078060DFDF73F40D2C5A69542844A4026E5EE737CF43F40D2C5A69542844A40
24592	14942	34.196095999999997	34.248333000000002	53.123100999999998	53.099296000000002	Луговая	0103000020E610000001000000050000002E7079AC19194140D34F38BBB58C4A402E7079AC191941406D8D08C6C18F4A4040C23060C91F41406D8D08C6C18F4A4040C23060C91F4140D34F38BBB58C4A402E7079AC19194140D34F38BBB58C4A40
24989	14879	33.883276000000002	33.909246000000003	53.037170000000003	53.025516000000003	Молодежная	0103000020E61000000100000005000000BDAB1E300FF140402BC3B81B44834A40BDAB1E300FF1404038328FFCC1844A406902452C62F4404038328FFCC1844A406902452C62F440402BC3B81B44834A40BDAB1E300FF140402BC3B81B44834A40
24703	14651	33.950972999999998	33.983356999999998	52.924233000000001	52.909692	Центральная	0103000020E610000001000000050000008330B77BB9F9404067B796C970744A408330B77BB9F94040267156444D764A4076A565A4DEFD4040267156444D764A4076A565A4DEFD404067B796C970744A408330B77BB9F9404067B796C970744A40
24413	51025	33.836230999999998	33.86636	52.936284000000001	52.917288999999997	Партизанская	0103000020E6100000010000000500000060730E9E09EB404082FDD7B969754A4060730E9E09EB404050E27327D8774A4002486DE2E4EE404050E27327D8774A4002486DE2E4EE404082FDD7B969754A4060730E9E09EB404082FDD7B969754A40
24987	14602	33.989142000000001	34.019640000000003	53.013506	52.995677999999998	Салова	0103000020E61000000100000005000000CE8C7E349CFE404060AC6F60727F4A40CE8C7E349CFE40405F268A90BA814A40C3D84290830241405F268A90BA814A40C3D842908302414060AC6F60727F4A40CE8C7E349CFE404060AC6F60727F4A40
24922	13888	34.078246	34.097847000000002	53.168481	53.160442000000003	Ольховая	0103000020E610000001000000050000007B8505F7030A4140D2730B5D89944A407B8505F7030A4140AA7F10C990954A4080812040860C4140AA7F10C990954A4080812040860C4140D2730B5D89944A407B8505F7030A4140D2730B5D89944A40
25063	14516	34.104019000000001	34.138908999999998	53.143988	53.132584000000001	Школьная	0103000020E61000000100000005000000D1949D7E500D414087FC3383F8904A40D1949D7E500D41401B82E3326E924A405E0F26C5C71141401B82E3326E924A405E0F26C5C711414087FC3383F8904A40D1949D7E500D414087FC3383F8904A40
24995	51093	34.169128999999998	34.210343000000002	53.156581000000003	53.141832999999998	Школьная	0103000020E6100000010000000500000010E7E104A61541402D3F709527924A4010E7E104A61541406616A1D80A944A40A5F8F884EC1A41406616A1D80A944A40A5F8F884EC1A41402D3F709527924A4010E7E104A61541402D3F709527924A40
24691	13990	33.915013000000002	33.931784999999998	53.114865000000002	53.103200000000001	Садовая	0103000020E610000001000000050000001A355F251FF540403E7958A8358D4A401A355F251FF540403F3A75E5B38E4A40A1F31ABB44F740403F3A75E5B38E4A40A1F31ABB44F740403E7958A8358D4A401A355F251FF540403E7958A8358D4A40
24722	48343	33.966665999999996	33.974311	52.887560999999998	52.875872000000001	Школьная	0103000020E61000000100000005000000DB1324B6BBFB4040B6BDDD921C704A40DB1324B6BBFB40403F1A4E999B714A4008910C39B6FC40403F1A4E999B714A4008910C39B6FC4040B6BDDD921C704A40DB1324B6BBFB4040B6BDDD921C704A40
24583	14432	33.896948000000002	33.939940999999997	53.160383000000003	53.145316000000001	Парковая	0103000020E61000000100000005000000371B2B31CFF24040F3CAF5B699924A40371B2B31CFF24040CDEA1D6E87944A40B39597FC4FF84040CDEA1D6E87944A40B39597FC4FF84040F3CAF5B699924A40371B2B31CFF24040F3CAF5B699924A40
24494	14187	34.002662000000001	34.022900999999997	53.03933	53.028104999999996	Молодежная	0103000020E610000001000000050000009278793A5700414052EDD3F198834A409278793A5700414037E0F3C308854A40D905836BEE02414037E0F3C308854A40D905836BEE02414052EDD3F198834A409278793A5700414052EDD3F198834A40
24984	14353	33.759874000000003	33.787291000000003	53.126317	53.102410999999996	Больничная	0103000020E61000000100000005000000558A1D8D43E1404015E0BBCD1B8D4A40558A1D8D43E14040E4F6CB272B904A40B3B794F3C5E44040E4F6CB272B904A40B3B794F3C5E4404015E0BBCD1B8D4A40558A1D8D43E1404015E0BBCD1B8D4A40
25117	14148	34.039375999999997	34.062201999999999	53.071480000000001	53.043559000000002	Деснянская	0103000020E61000000100000005000000A71FD4450A0541402639605793854A40A71FD4450A054140B728B34126894A4076DF313CF6074140B728B34126894A4076DF313CF60741402639605793854A40A71FD4450A0541402639605793854A40
25065	14788	33.727930000000001	33.755913	53.015689999999999	52.996263999999996	Переулок Заводской	0103000020E610000001000000050000007EE36BCF2CDD404050172994857F4A407EE36BCF2CDD4040E76F422102824A4085CFD6C1C1E04040E76F422102824A4085CFD6C1C1E0404050172994857F4A407EE36BCF2CDD404050172994857F4A40
24492	13925	33.889079000000002	33.928434000000003	53.081125	53.054769	Школьная	0103000020E61000000100000005000000BB473657CDF14040D5EAABAB02874A40BB473657CDF14040AAF1D24D628A4A404B3FE1ECD6F64040AAF1D24D628A4A404B3FE1ECD6F64040D5EAABAB02874A40BB473657CDF14040D5EAABAB02874A40
25214	51095	34.108680999999997	34.122093	53.165008999999998	53.155399000000003	Советская	0103000020E6100000010000000500000029594E42E90D4140626A4B1DE4934A4029594E42E90D4140D845D1031F954A40070951BEA00F4140D845D1031F954A40070951BEA00F4140626A4B1DE4934A4029594E42E90D4140626A4B1DE4934A40
24900	14288	33.952041999999999	33.969667000000001	53.194546000000003	53.183183	Соловьиная	0103000020E610000001000000050000008F352383DCF940407217618A72974A408F352383DCF94040A8C821E2E6984A4056815A0C1EFC4040A8C821E2E6984A4056815A0C1EFC40407217618A72974A408F352383DCF940407217618A72974A40
24399	14685	33.935952999999998	33.960225000000001	52.878475000000002	52.866239999999998	Школьная	0103000020E61000000100000005000000EACBD24ECDF74040573ECBF3E06E4A40EACBD24ECDF7404043AD69DE71704A409BE61DA7E8FA404043AD69DE71704A409BE61DA7E8FA4040573ECBF3E06E4A40EACBD24ECDF74040573ECBF3E06E4A40
24595	14536	34.006084000000001	34.018275000000003	52.976129999999998	52.968916999999998	Заречная	0103000020E61000000100000005000000B2834A5CC7004140EBC4E578057C4A40B2834A5CC70041407E52EDD3F17C4A40CEAACFD5560241407E52EDD3F17C4A40CEAACFD556024140EBC4E578057C4A40B2834A5CC7004140EBC4E578057C4A40
24981	13755	34.029099000000002	34.079369	53.133076000000003	53.124236000000003	Центральная 	0103000020E6100000010000000500000054AC1A84B9034140317E1AF7E68F4A4054AC1A84B9034140F6F065A208914A407AA86DC3280A4140F6F065A208914A407AA86DC3280A4140317E1AF7E68F4A4054AC1A84B9034140317E1AF7E68F4A40
24980	13604	34.006048	34.086132999999997	53.113945999999999	53.073346000000001	Свердлова	0103000020E61000000100000005000000651A4D2EC60041406EA5D76663894A40651A4D2EC600414048C153C8958E4A409D0DF967060B414048C153C8958E4A409D0DF967060B41406EA5D76663894A40651A4D2EC60041406EA5D76663894A40
24808	13604	34.006048	34.086132999999997	53.113945999999999	53.073346000000001	Ленина	0103000020E61000000100000005000000651A4D2EC60041406EA5D76663894A40651A4D2EC600414048C153C8958E4A409D0DF967060B414048C153C8958E4A409D0DF967060B41406EA5D76663894A40651A4D2EC60041406EA5D76663894A40
25059	14217	33.738143999999998	33.785637999999999	53.138596999999997	53.124035999999997	Школьная	0103000020E610000001000000050000008BDEA9807BDE404069C36169E08F4A408BDEA9807BDE40406F29E78BBD914A40573F36C98FE440406F29E78BBD914A40573F36C98FE4404069C36169E08F4A408BDEA9807BDE404069C36169E08F4A40
24705	14747	33.866979999999998	33.900649000000001	53.008960999999999	52.999899999999997	 Молодежная	0103000020E610000001000000050000009E245D33F9EE40409CA223B9FC7F4A409E245D33F9EE404040F850A225814A406A16687748F3404040F850A225814A406A16687748F340409CA223B9FC7F4A409E245D33F9EE40409CA223B9FC7F4A40
25198	51134	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	Центральная	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
24621	12066	34.112758999999997	34.138945	53.341973000000003	53.334074999999999	Школьная	0103000020E6100000010000000500000032AA0CE36E0E4140A2B437F8C2AA4A4032AA0CE36E0E4140B98E71C5C5AB4A40AB7823F3C8114140B98E71C5C5AB4A40AB7823F3C8114140A2B437F8C2AA4A4032AA0CE36E0E4140A2B437F8C2AA4A40
24562	13008	34.254621	34.291479000000002	53.266736999999999	53.234943999999999	Трудовая	0103000020E61000000100000005000000FAEFC16B972041401A321EA5129E4A40FAEFC16B972041400BD1217024A24A40433C122F4F2541400BD1217024A24A40433C122F4F2541401A321EA5129E4A40FAEFC16B972041401A321EA5129E4A40
24430	13478	34.203561000000001	34.216524	53.386696000000001	53.367932000000003	Толвинская	0103000020E61000000100000005000000DBDE6E490E1A41407193516518AF4A40DBDE6E490E1A41403CBF28417FB14A404966F50EB71B41403CBF28417FB14A404966F50EB71B41407193516518AF4A40DBDE6E490E1A41407193516518AF4A40
24956	11950	34.049706999999998	34.084057999999999	53.270141000000002	53.247171999999999	пл.им.К.Маркса	0103000020E61000000100000005000000EEB089CC5C064140533E0455A39F4A40EEB089CC5C0641408527F4FA93A24A40CC7B9C69C20A41408527F4FA93A24A40CC7B9C69C20A4140533E0455A39F4A40EEB089CC5C064140533E0455A39F4A40
25134	13219	34.192979000000001	34.230969000000002	53.206553	53.193477000000001	Садовая	0103000020E610000001000000050000004BE82E89B31841409CC3B5DAC3984A404BE82E89B318414002F22554709A4A40E6B16664901D414002F22554709A4A40E6B16664901D41409CC3B5DAC3984A404BE82E89B31841409CC3B5DAC3984A40
24683	13295	34.135728999999998	34.170521000000001	53.226109999999998	53.215482999999999	Светлая	0103000020E61000000100000005000000340F60915F11414007EC6AF2949B4A40340F60915F11414037A6272CF19C4A40FF23D3A1D315414037A6272CF19C4A40FF23D3A1D315414007EC6AF2949B4A40340F60915F11414007EC6AF2949B4A40
25088	51105	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	Свенская	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
25047	12830	34.420611999999998	34.437787999999998	53.117950999999998	53.111010999999998	Киевская	0103000020E610000001000000050000000F27309DD6354140853FC39B358E4A400F27309DD6354140E7C3B304198F4A40664AEB6F09384140E7C3B304198F4A40664AEB6F09384140853FC39B358E4A400F27309DD6354140853FC39B358E4A40
24462	11431	34.476784000000002	34.496295000000003	53.387141	53.360393000000002	Комсомольская	0103000020E61000000100000005000000C7A01342073D41408A5A9A5B21AE4A40C7A01342073D41406AF816D68DB14A408C153598863F41406AF816D68DB14A408C153598863F41408A5A9A5B21AE4A40C7A01342073D41408A5A9A5B21AE4A40
24504	12153	34.120916000000001	34.148099000000002	53.314928000000002	53.292741999999997	Центральная	0103000020E6100000010000000500000015C8EC2C7A0F41403315E29178A54A4015C8EC2C7A0F41401F4C8A8F4FA84A4000C974E8F41241401F4C8A8F4FA84A4000C974E8F41241403315E29178A54A4015C8EC2C7A0F41403315E29178A54A40
25207	51140	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	12	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
25004	12689	34.354137000000001	34.373891	53.147551999999997	53.132455	Клубная	0103000020E61000000100000005000000DBA6785C542D414089981249F4904A40DBA6785C542D4140CD3AE3FBE2924A4066A208A9DB2F4140CD3AE3FBE2924A4066A208A9DB2F414089981249F4904A40DBA6785C542D414089981249F4904A40
24846	12791	34.297642000000003	34.318517999999997	53.164555999999997	53.13702	Школьная	0103000020E6100000010000000500000041F50F2219264140EF7211DF89914A4041F50F2219264140272EC72B10954A40FA97A432C5284140272EC72B10954A40FA97A432C5284140EF7211DF89914A4041F50F2219264140EF7211DF89914A40
74987	51129	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	Центральная	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
25061	13575	34.912618999999999	34.936604000000003	53.292504999999998	53.280329000000002	Ленина	0103000020E61000000100000005000000A75A0BB3D0744140698F17D2E1A34A40A75A0BB3D07441404F75C8CD70A54A40C2A6CEA3E27741404F75C8CD70A54A40C2A6CEA3E2774140698F17D2E1A34A40A75A0BB3D0744140698F17D2E1A34A40
24740	45658	33.767688999999997	33.792904999999998	53.330858999999997	53.308562999999999	 Резцова	0103000020E61000000100000005000000DD3F16A243E24040B9E00CFE7EA74A40DD3F16A243E240402B4B749659AA4A40DDEA39E97DE540402B4B749659AA4A40DDEA39E97DE54040B9E00CFE7EA74A40DD3F16A243E24040B9E00CFE7EA74A40
24823	13340	34.178713999999999	34.205357999999997	53.354379999999999	53.343231000000003	Школьная	0103000020E610000001000000050000002EABB019E016414098FC4FFEEEAB4A402EABB019E0164140A12DE7525CAD4A4069FCC22B491A4140A12DE7525CAD4A4069FCC22B491A414098FC4FFEEEAB4A402EABB019E016414098FC4FFEEEAB4A40
24971	13340	34.178713999999999	34.205357999999997	53.354379999999999	53.343231000000003	Мира	0103000020E610000001000000050000002EABB019E016414098FC4FFEEEAB4A402EABB019E0164140A12DE7525CAD4A4069FCC22B491A4140A12DE7525CAD4A4069FCC22B491A414098FC4FFEEEAB4A402EABB019E016414098FC4FFEEEAB4A40
25126	12669	33.867033999999997	33.889932000000002	53.341183000000001	53.333575000000003	Школьная	0103000020E61000000100000005000000914259F8FAEE4040B1E1E995B2AA4A40914259F8FAEE4040C07971E2ABAB4A40FAD4B14AE9F14040C07971E2ABAB4A40FAD4B14AE9F14040B1E1E995B2AA4A40914259F8FAEE4040B1E1E995B2AA4A40
24629	13046	34.22486	34.244964000000003	53.282519999999998	53.269333000000003	Березовая	0103000020E61000000100000005000000DB166536C81C4140E65DF58079A24A40DB166536C81C4140A33B889D29A44A404359F8FA5A1F4140A33B889D29A44A404359F8FA5A1F4140E65DF58079A24A40DB166536C81C4140E65DF58079A24A40
24797	11715	34.808701999999997	34.821961000000002	53.325373999999996	53.313965000000003	Школьная	0103000020E61000000100000005000000DA1A118C83674140598B4F0130A84A40DA1A118C83674140FE7BF0DAA5A94A4032CB9E0436694140FE7BF0DAA5A94A4032CB9E0436694140598B4F0130A84A40DA1A118C83674140598B4F0130A84A40
24889	13127	34.144478999999997	34.171222	53.283171000000003	53.266500000000001	Воинская	0103000020E61000000100000005000000B9FAB1497E124140273108AC1CA24A40B9FAB1497E1241407B1684F23EA44A40882D3D9AEA1541407B1684F23EA44A40882D3D9AEA154140273108AC1CA24A40B9FAB1497E124140273108AC1CA24A40
25124	11628	34.609482999999997	34.633288	53.284053999999998	53.264955	Молодежная	0103000020E61000000100000005000000E63BF889034E4140B2F4A10BEAA14A40E63BF889034E41402426A8E15BA44A408179C8940F5141402426A8E15BA44A408179C8940F514140B2F4A10BEAA14A40E63BF889034E4140B2F4A10BEAA14A40
24678	13079	34.099257999999999	34.127070000000003	53.275531000000001	53.265115999999999	Тамбовская	0103000020E61000000100000005000000E5EE737CB40C4140BBD23252EFA14A40E5EE737CB40C414060048D9944A34A40C0266BD44310414060048D9944A34A40C0266BD443104140BBD23252EFA14A40E5EE737CB40C4140BBD23252EFA14A40
24463	11537	34.479928000000001	34.50844	53.332338	53.327126999999997	Лесная	0103000020E61000000100000005000000A437DC476E3D4140BD512B4CDFA94A40A437DC476E3D4140E99B340D8AAA4A4037FDD98F14414140E99B340D8AAA4A4037FDD98F14414140BD512B4CDFA94A40A437DC476E3D4140BD512B4CDFA94A40
24623	12039	34.078048000000003	34.101529999999997	53.322873000000001	53.312077000000002	Советская	0103000020E6100000010000000500000055C2137AFD094140BA6A9E23F2A74A4055C2137AFD09414076E107E753A94A400CC85EEFFE0C414076E107E753A94A400CC85EEFFE0C4140BA6A9E23F2A74A4055C2137AFD094140BA6A9E23F2A74A40
24467	11602	34.697130999999999	34.723641000000001	53.329445	53.305033999999999	Песочная	0103000020E610000001000000050000008E03AF963B5941408315A75A0BA74A408E03AF963B594140556AF6402BAA4A40BA85AE44A05C4140556AF6402BAA4A40BA85AE44A05C41408315A75A0BA74A408E03AF963B5941408315A75A0BA74A40
25053	13505	34.040354999999998	34.068103999999998	53.468483999999997	53.453933999999997	Советская	0103000020E61000000100000005000000739D465A2A0541406F4562821ABA4A40739D465A2A0541408159A148F7BB4A40075DC2A1B70841408159A148F7BB4A40075DC2A1B70841406F4562821ABA4A40739D465A2A0541406F4562821ABA4A40
25131	13190	34.225031000000001	34.264834999999998	53.196945999999997	53.169857	Юбилейная	0103000020E6100000010000000500000008CBD8D0CD1C414093FFC9DFBD954A4008CBD8D0CD1C4140FC89CA8635994A4007EBFF1CE6214140FC89CA8635994A4007EBFF1CE621414093FFC9DFBD954A4008CBD8D0CD1C414093FFC9DFBD954A40
24626	12328	33.954017999999998	33.985010000000003	53.305712	53.291030999999997	Сельская	0103000020E61000000100000005000000CDE506431DFA4040A38FF98040A54A40CDE506431DFA404054FF209221A74A40D21DC4CE14FE404054FF209221A74A40D21DC4CE14FE4040A38FF98040A54A40CDE506431DFA4040A38FF98040A54A40
24624	12280	34.017924000000001	34.045844000000002	53.350982999999999	53.343924999999999	Школьная	0103000020E6100000010000000500000021E868554B0241406EA301BC05AC4A4021E868554B024140DA39CD02EDAC4A40E25B5837DE054140DA39CD02EDAC4A40E25B5837DE0541406EA301BC05AC4A4021E868554B0241406EA301BC05AC4A40
24800	11894	34.058779999999999	34.106057999999997	53.312835	53.294049999999999	П.М.Яшенина	0103000020E6100000010000000500000056D4601A86074140C4B12E6EA3A54A4056D4601A86074140A7052FFA0AA84A4055BDFC4E930D4140A7052FFA0AA84A4055BDFC4E930D4140C4B12E6EA3A54A4056D4601A86074140C4B12E6EA3A54A40
24618	11894	34.058779999999999	34.106057999999997	53.312835	53.294049999999999	Клубная	0103000020E6100000010000000500000056D4601A86074140C4B12E6EA3A54A4056D4601A86074140A7052FFA0AA84A4055BDFC4E930D4140A7052FFA0AA84A4055BDFC4E930D4140C4B12E6EA3A54A4056D4601A86074140C4B12E6EA3A54A40
24569	13428	34.151116999999999	34.171509	53.378779000000002	53.367663999999998	Набережная	0103000020E61000000100000005000000506F46CD5713414051F52B9D0FAF4A40506F46CD57134140AFB48CD47BB04A401EFCC401F4154140AFB48CD47BB04A401EFCC401F415414051F52B9D0FAF4A40506F46CD5713414051F52B9D0FAF4A40
24845	12228	33.999319999999997	34.021293	53.352907000000002	53.342129	Молодежная	0103000020E610000001000000050000008E1EBFB7E9FF4040B00111E2CAAB4A408E1EBFB7E9FF4040C6C37B0E2CAD4A401E51A1BAB9024140C6C37B0E2CAD4A401E51A1BAB9024140B00111E2CAAB4A408E1EBFB7E9FF4040B00111E2CAAB4A40
25168	51069	34.644283999999999	34.693691000000001	53.221046999999999	53.199416999999997	улица Ленина	0103000020E6100000010000000500000004ABEAE5775241401AA20A7F86994A4004ABEAE57752414080F0A1444B9C4A40C843DFDDCA58414080F0A1444B9C4A40C843DFDDCA5841401AA20A7F86994A4004ABEAE5775241401AA20A7F86994A40
25196	51069	34.644283999999999	34.693691000000001	53.221046999999999	53.199416999999997	Ромашина	0103000020E6100000010000000500000004ABEAE5775241401AA20A7F86994A4004ABEAE57752414080F0A1444B9C4A40C843DFDDCA58414080F0A1444B9C4A40C843DFDDCA5841401AA20A7F86994A4004ABEAE5775241401AA20A7F86994A40
24868	51069	34.644283999999999	34.693691000000001	53.221046999999999	53.199416999999997	Коминтерна	0103000020E6100000010000000500000004ABEAE5775241401AA20A7F86994A4004ABEAE57752414080F0A1444B9C4A40C843DFDDCA58414080F0A1444B9C4A40C843DFDDCA5841401AA20A7F86994A4004ABEAE5775241401AA20A7F86994A40
25199	51069	34.644283999999999	34.693691000000001	53.221046999999999	53.199416999999997	Карла Маркса	0103000020E6100000010000000500000004ABEAE5775241401AA20A7F86994A4004ABEAE57752414080F0A1444B9C4A40C843DFDDCA58414080F0A1444B9C4A40C843DFDDCA5841401AA20A7F86994A4004ABEAE5775241401AA20A7F86994A40
24993	51092	34.585318000000001	34.594005000000003	53.218729000000003	53.216928000000003	Центральная	0103000020E610000001000000050000004CE141B3EB4A414019CBF44BC49B4A404CE141B3EB4A4140E9D7D64FFF9B4A408B54185B084C4140E9D7D64FFF9B4A408B54185B084C414019CBF44BC49B4A404CE141B3EB4A414019CBF44BC49B4A40
24660	11514	34.611747000000001	34.631284999999998	53.405585000000002	53.394579	Центральная	0103000020E610000001000000050000008B36C7B94D4E41401D588E9081B24A408B36C7B94D4E4140C45F9335EAB34A4049BA66F2CD504140C45F9335EAB34A4049BA66F2CD5041401D588E9081B24A408B36C7B94D4E41401D588E9081B24A40
24852	12570	34.266478999999997	34.297049000000001	53.231693999999997	53.204448999999997	переулок Школьный	0103000020E610000001000000050000000F09DFFB1B224140965984622B9A4A400F09DFFB1B224140F7562426A89D4A409E279EB305264140F7562426A89D4A409E279EB305264140965984622B9A4A400F09DFFB1B224140965984622B9A4A40
33408	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Чкалова	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33410	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Харьковская	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
9901	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Фрунзе	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33555	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Садовая	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33459	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Ржевское шоссе	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33319	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Октябрьская	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33458	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Нежегольдское шоссе	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33407	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Мочалина	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33406	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Московская	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33275	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Мичурина	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33391	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Ленина	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33340	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Дзержинского	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33842	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Дачная	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33317	28629	36.863985	36.924486000000002	50.436720000000001	50.380242000000003	Белгородская	0103000020E61000000100000005000000069E7B0F976E4240674815C5AB304940069E7B0F976E42402BC1E270E637494010CEA78E557642402BC1E270E637494010CEA78E55764240674815C5AB304940069E7B0F976E4240674815C5AB304940
33400	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Юность	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33196	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Юбилейный	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33243	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Углы	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33256	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Студенческий	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33404	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Солнечный	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33290	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Северный	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33453	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Рудничный	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33254	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Приборостроитель	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33287	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Парковый	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33403	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Ольминского	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33426	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Олимпийский	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33294	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Молодогвардеец	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33372	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Макаренко	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33221	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Лебединец	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33513	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Космос	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33405	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Королева	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33449	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Конева	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33241	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Интернациональный	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33268	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Зеленый Лог	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33324	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Звездный	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33200	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Жукова	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33514	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Дубрава	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33223	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Горняк	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33270	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Восточный	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33289	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Весенний	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33269	21346	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	м-н Буденного	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
33455	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	бульвар Дружбы	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33627	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Южная	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33328	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Стадионная	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33288	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Советская	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33421	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Свердлова	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33420	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Революционная	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33326	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Пролетарская	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33508	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Первой Конной Армии	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33242	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Октябрьская	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33401	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Мира	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33402	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Ленина	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33818	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Комсомольская	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33430	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Зои Космодемьянской	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33552	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Заречная	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33409	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Жукова	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33418	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Ватутина	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33671	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	Большевистская	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33356	21346	37.764716	37.905653000000001	51.332994999999997	51.269508000000002	19 Партсъезда	0103000020E610000001000000050000002D5DC136E2E142405401F73C7FA249402D5DC136E2E14240A25D85949FAA49401C430070ECF34240A25D85949FAA49401C430070ECF342405401F73C7FA249402D5DC136E2E142405401F73C7FA24940
33339	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	проспект Горняков	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33358	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Школьная	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33438	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Чайковского	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33605	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Фрунзе	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33368	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Ударников	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33388	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Спортивный проезд	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33381	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Советская	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33813	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Революционная	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33213	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Раевского	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33493	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Преображенская	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33320	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Победы	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33205	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Павлика Морозова	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33202	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Осколецкая	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33599	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Народня	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33675	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Народная	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33255	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Мичурина	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33263	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Мира	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33354	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Лазарева	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33203	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Королева	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33266	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Комсомольская	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33298	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Карла Маркса	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33556	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Добролюбова	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33416	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Дзержинского	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33370	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Гастелло	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33470	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Воинов-интернационалистов	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33260	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Белгородская	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33640	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Артема	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33369	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	Агошкова	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33641	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	9 Января	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33261	930	37.508957000000002	37.687066000000002	51.315755000000003	51.248275	2-я Академическая	0103000020E61000000100000005000000FF08C38025C142400BB5A679C79F4940FF08C38025C142403546EBA86AA84940C61858C7F1D742403546EBA86AA84940C61858C7F1D742400BB5A679C79F4940FF08C38025C142400BB5A679C79F4940
33427	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	бульвар Первого Салюта	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33329	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Юности бульвар	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33283	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Щорса	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33569	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Шумилова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33636	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Широкая	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33341	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Шершнева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33236	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Шаландина	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33291	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Шаландина	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33380	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Чумичева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33425	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Чапаева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33367	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Хихлушки	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33299	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Сумская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33435	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Студенческая	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33431	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Спортивная	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33519	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Славы пр	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33303	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Садовая	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33308	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Садовая	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33188	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Репина	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33464	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Пугачева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33198	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Привольная	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33240	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Преображенская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33345	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Попова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33377	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Победы	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33436	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Первомайская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33347	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Первого салюта бульвар	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33349	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Октябрьская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33180	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Озембловского	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33352	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Некрасова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33304	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Некрасова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33182	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Народный бульвар	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33433	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Молодежная	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33204	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Мокроусова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33179	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Мичурина	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33434	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Менделеева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33237	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Менделеев	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33343	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Макаренко	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33496	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Кутузова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33346	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Курская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33342	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Куйбышева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33666	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Крупской	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33503	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Костюкова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33185	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Костюкова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33497	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Корочанская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33386	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Королепа	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33284	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Королева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33253	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Конева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33740	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Индустриальная	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33302	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Железнякова	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33201	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Есенина	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33184	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Донецкая	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33461	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Дегтярева	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33325	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Губкина	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33189	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Гражданский проспект	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33183	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Гражданский пр	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33364	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Горького	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33581	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Волчанская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33762	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Везельская	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33465	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Ватутина пр	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33344	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Ватутина	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33178	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Буденного	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33498	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Белгородского полка	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33247	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Белгородский пр	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33469	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Б.Хмельницкого	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33257	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	Апанасенко	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33366	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	8 марта	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33176	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	60 лет Октября	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33333	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	5 Августа	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33248	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	2 Карьерный пр	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33494	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	2 Декабристов переулок	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33495	11717	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	1 Центральная	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
33313	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	площадь 3 Интернационала	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33375	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Чкалова	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33474	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Фрунзе	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33335	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Ф.Энгельса	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33473	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Урицкого	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33258	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Тимирязева	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33376	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Спортивная	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33432	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Свердлова	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33373	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Привокзальная	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33472	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Ленина	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33374	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Л.Толстого	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33300	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Комсомольская	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33297	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	Кирова	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
33475	10381	38.630540000000003	38.749054000000001	50.650440000000003	50.603172999999998	В.Собины	0103000020E61000000100000005000000F168E388B5504340446ADAC5344D4940F168E388B55043405001309E4153494010786000E15F43405001309E4153494010786000E15F4340446ADAC5344D4940F168E388B5504340446ADAC5344D4940
9885	344	36.424205000000001	36.460811999999997	50.879176000000001	50.843392999999999	Шаландина	0103000020E610000001000000050000005CE674594C3642407156444DF46B49405CE674594C364240CCB6D3D6887049405BCD3AE3FB3A4240CCB6D3D6887049405BCD3AE3FB3A42407156444DF46B49405CE674594C3642407156444DF46B4940
33228	344	36.424205000000001	36.460811999999997	50.879176000000001	50.843392999999999	Октябрьская	0103000020E610000001000000050000005CE674594C3642407156444DF46B49405CE674594C364240CCB6D3D6887049405BCD3AE3FB3A4240CCB6D3D6887049405BCD3AE3FB3A42407156444DF46B49405CE674594C3642407156444DF46B4940
33653	2690	36.565088000000003	36.610093999999997	50.714880000000001	50.687040000000003	Школьный переулок	0103000020E6100000010000000500000058AEB7CD544842409D853DEDF057494058AEB7CD5448424041481630815B49402FBE688F174E424041481630815B49402FBE688F174E42409D853DEDF057494058AEB7CD544842409D853DEDF0574940
33739	1044	36.145691999999997	36.178443999999999	50.818434000000003	50.794949000000003	Озерная	0103000020E61000000100000005000000F8A41309A6124240747E8AE3C0654940F8A41309A61242409DF7FF71C26849406E15C440D71642409DF7FF71C26849406E15C440D7164240747E8AE3C0654940F8A41309A6124240747E8AE3C0654940
9843	1604	36.272902000000002	36.29589	50.794322999999999	50.780285999999997	Школьная	0103000020E61000000100000005000000AA81E673EE22424069C36169E0634940AA81E673EE224240F5BA4560AC654940529B38B9DF254240F5BA4560AC654940529B38B9DF25424069C36169E0634940AA81E673EE22424069C36169E0634940
33276	561	36.199644999999997	36.257863999999998	50.698652000000003	50.668762999999998	Ватутина	0103000020E61000000100000005000000ABE7A4F78D1942402EE3A6069A554940ABE7A4F78D1942407BA4C16D6D5949406A6803B0012142407BA4C16D6D5949406A6803B0012142402EE3A6069A554940ABE7A4F78D1942402EE3A6069A554940
33278	561	36.199644999999997	36.257863999999998	50.698652000000003	50.668762999999998	32-го Гвардейского Корпуса	0103000020E61000000100000005000000ABE7A4F78D1942402EE3A6069A554940ABE7A4F78D1942407BA4C16D6D5949406A6803B0012142407BA4C16D6D5949406A6803B0012142402EE3A6069A554940ABE7A4F78D1942402EE3A6069A554940
33280	2646	36.583548999999998	36.605907999999999	50.744722000000003	50.718837999999998	Центральная	0103000020E61000000100000005000000874ECFBBB14A42409F8F32E2025C4940874ECFBBB14A42404D4EED0C535F49404031B2648E4D42404D4EED0C535F49404031B2648E4D42409F8F32E2025C4940874ECFBBB14A42409F8F32E2025C4940
33321	54	36.444991999999999	36.50085	50.796868000000003	50.771172	Юбилейная	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
33279	54	36.444991999999999	36.50085	50.796868000000003	50.771172	Победы	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
33518	54	36.444991999999999	36.50085	50.796868000000003	50.771172	Октябрьская	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
33230	54	36.444991999999999	36.50085	50.796868000000003	50.771172	Ленина	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
33452	54	36.444991999999999	36.50085	50.796868000000003	50.771172	5-Августа	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
33521	53995	36.444991999999999	36.50085	50.796868000000003	50.771172	Магистральная	0103000020E61000000100000005000000A67D737FF5384240A3CB9BC3B5624940A67D737FF53842404E9D47C5FF654940CE1951DA1B4042404E9D47C5FF654940CE1951DA1B404240A3CB9BC3B5624940A67D737FF5384240A3CB9BC3B5624940
33578	2536	36.289889000000002	36.337985000000003	50.748044999999998	50.722648	Школьная	0103000020E610000001000000050000002E3C2F151B2542408942CBBA7F5C49402E3C2F151B254240D97745F0BF5F4940F0C4AC17432B4240D97745F0BF5F4940F0C4AC17432B42408942CBBA7F5C49402E3C2F151B2542408942CBBA7F5C4940
33598	455	36.522984000000001	36.544822000000003	50.819516	50.808906999999998	Советская	0103000020E61000000100000005000000672AC423F1424240B340BB438A674940672AC423F14242403D4679E6E5684940171230BABC4542403D4679E6E5684940171230BABC454240B340BB438A674940672AC423F1424240B340BB438A674940
33658	54019	36.131903000000001	36.180160000000001	50.657080999999998	50.639175999999999	Калинина	0103000020E61000000100000005000000459F8F32E2104240AD31E884D0514940459F8F32E210424057E9EE3A1B54494010069E7B0F17424057E9EE3A1B54494010069E7B0F174240AD31E884D0514940459F8F32E2104240AD31E884D0514940
14688	1953	36.623443000000002	36.729669000000001	50.838324999999998	50.782477999999998	Центральная	0103000020E61000000100000005000000C7F5EFFACC4F424074EB353D28644940C7F5EFFACC4F4240A835CD3B4E6B4940D8F335CB655D4240A835CD3B4E6B4940D8F335CB655D424074EB353D28644940C7F5EFFACC4F424074EB353D28644940
33833	1830	36.713957000000001	36.747706999999998	50.772579	50.756900999999999	Центральная	0103000020E6100000010000000500000009E066F1625B4240A4A7C821E260494009E066F1625B4240C74961DEE3624940C1FEEBDCB45F4240C74961DEE3624940C1FEEBDCB45F4240A4A7C821E260494009E066F1625B4240A4A7C821E2604940
33845	2428	36.272399	36.306426999999999	50.731085999999998	50.703256000000003	Школьный переулок	0103000020E61000000100000005000000473B6EF8DD2242409F5BE84A045A4940473B6EF8DD2242401F48DE39945D494042CEFBFF382742401F48DE39945D494042CEFBFF382742409F5BE84A045A4940473B6EF8DD2242409F5BE84A045A4940
33711	1494	36.110936000000002	36.118572	50.877789999999997	50.870241999999998	Центральная	0103000020E610000001000000050000007BF99D26330E424085CD0017646F49407BF99D26330E4240BF60376C5B704940541C075E2D0F4240BF60376C5B704940541C075E2D0F424085CD0017646F49407BF99D26330E424085CD0017646F4940
33713	1883	36.652413000000003	36.686369999999997	50.846559999999997	50.805373000000003	Центральная	0103000020E610000001000000050000001D3EE944825342406C0A6476166749401D3EE94482534240060DFD135C6C49404E7ADFF8DA574240060DFD135C6C49404E7ADFF8DA5742406C0A6476166749401D3EE944825342406C0A647616674940
33753	2192	36.166550999999998	36.190463999999999	50.706929000000002	50.692033000000002	Центральная	0103000020E61000000100000005000000DC0E0D8B511542405B608F8994584940DC0E0D8B5115424008CC43A67C5A49405D88D51F6118424008CC43A67C5A49405D88D51F611842405B608F8994584940DC0E0D8B511542405B608F8994584940
33795	2305	36.12433	36.15719	50.694789	50.679169999999999	Садовая	0103000020E61000000100000005000000B2F4A10BEA0F42405036E50AEF564940B2F4A10BEA0F42406E4F90D8EE5849400EA14ACD1E1442406E4F90D8EE5849400EA14ACD1E1442405036E50AEF564940B2F4A10BEA0F42405036E50AEF564940
33887	2305	36.12433	36.15719	50.694789	50.679169999999999	Набережная	0103000020E61000000100000005000000B2F4A10BEA0F42405036E50AEF564940B2F4A10BEA0F42406E4F90D8EE5849400EA14ACD1E1442406E4F90D8EE5849400EA14ACD1E1442405036E50AEF564940B2F4A10BEA0F42405036E50AEF564940
33757	934	36.240186000000001	36.269694999999999	50.868701000000001	50.853924999999997	Новая	0103000020E61000000100000005000000817A336ABE1E42404F1E166A4D6D4940817A336ABE1E424052802898316F49408672A25D8522424052802898316F49408672A25D852242404F1E166A4D6D4940817A336ABE1E42404F1E166A4D6D4940
33727	2243	36.079109000000003	36.096688999999998	50.718490000000003	50.706279000000002	Лесная	0103000020E61000000100000005000000DEE8633E200A4240016DAB59675A4940DEE8633E200A42406440F67AF75B494004711E4E600C42406440F67AF75B494004711E4E600C4240016DAB59675A4940DEE8633E200A4240016DAB59675A4940
33323	2137	36.157774000000003	36.202464999999997	50.666410999999997	50.653106999999999	Проворова	0103000020E610000001000000050000005E143DF031144240F3E49A02995349405E143DF031144240EA58A5F44C554940D5CA845FEA194240EA58A5F44C554940D5CA845FEA194240F3E49A02995349405E143DF031144240F3E49A0299534940
33537	1716	36.740564999999997	36.764344000000001	50.814064000000002	50.786361999999997	Центральная	0103000020E61000000100000005000000F7C77BD5CA5E424098689082A7644940F7C77BD5CA5E4240EC6CC83F3368494069723106D6614240EC6CC83F3368494069723106D661424098689082A7644940F7C77BD5CA5E424098689082A7644940
33575	54007	36.206372999999999	36.222093000000001	50.671041000000002	50.661968999999999	Малиновского	0103000020E6100000010000000500000082E3326E6A1A4240A0FB7266BB54494082E3326E6A1A424038A3E6ABE4554940D4D51D8B6D1C424038A3E6ABE4554940D4D51D8B6D1C4240A0FB7266BB54494082E3326E6A1A4240A0FB7266BB544940
33554	1433	36.135441999999998	36.154747	50.863858	50.855072999999997	Школьная	0103000020E610000001000000050000009E40D82956114240A7583508736D49409E40D82956114240A93121E6926E4940BA13ECBFCE134240A93121E6926E4940BA13ECBFCE134240A7583508736D49409E40D82956114240A7583508736D4940
33875	2354	36.270037000000002	36.340204	50.767276000000003	50.734763999999998	Центральная	0103000020E61000000100000005000000E0DA8992902242409A232BBF0C5E4940E0DA899290224240BB80971936624940F4FBFECD8B2B4240BB80971936624940F4FBFECD8B2B42409A232BBF0C5E4940E0DA8992902242409A232BBF0C5E4940
33630	1366	36.330879000000003	36.374600000000001	50.834508	50.817791	Центральная	0103000020E6100000010000000500000073F7393E5A2A424048FB1F60AD68494073F7393E5A2A42400C207C28D16A4940728A8EE4F22F42400C207C28D16A4940728A8EE4F22F424048FB1F60AD68494073F7393E5A2A424048FB1F60AD684940
33322	1141	36.636926000000003	36.679453000000002	50.787255999999999	50.763778000000002	Советская	0103000020E610000001000000050000006EFC89CA86514240C0B33D7AC36149406EFC89CA8651424036CAFACDC4644940A515DF50F856424036CAFACDC4644940A515DF50F8564240C0B33D7AC36149406EFC89CA86514240C0B33D7AC3614940
33831	2594	36.586423000000003	36.609940999999999	50.768791	50.748843000000001	Школьная	0103000020E61000000100000005000000A54FABE80F4B4240556B6116DA5F4940A54FABE80F4B4240C53A55BE67624940A9BEF38B124E4240C53A55BE67624940A9BEF38B124E4240556B6116DA5F4940A54FABE80F4B4240556B6116DA5F4940
33760	1772	36.812682000000002	36.841644000000002	50.793064000000001	50.770209999999999	Школьная	0103000020E610000001000000050000002106BAF605684240AD86C43D966249402106BAF60568424046D1031F83654940F46F97FDBA6B424046D1031F83654940F46F97FDBA6B4240AD86C43D966249402106BAF605684240AD86C43D96624940
33175	1078	36.422587999999998	36.450938999999998	50.815185	50.800448000000003	Центральная	0103000020E610000001000000050000004DD7135D1736424006137F14756649404DD7135D173642404A9869FB57684940D7BE805EB83942404A9869FB57684940D7BE805EB839424006137F14756649404DD7135D1736424006137F1475664940
14703	938	36.163936999999997	36.199986000000003	50.773381999999998	50.754956999999997	Речная	0103000020E610000001000000050000005BCD3AE3FB1442407171546EA26049405BCD3AE3FB14424054A86E2EFE62494035D428249919424054A86E2EFE62494035D42824991942407171546EA26049405BCD3AE3FB1442407171546EA2604940
33680	860	36.186826000000003	36.224572999999999	50.870547999999999	50.857035000000003	Центральная	0103000020E61000000100000005000000710514EAE91742408143A852B36D4940710514EAE917424092CCEA1D6E6F49404548DDCEBE1C424092CCEA1D6E6F49404548DDCEBE1C42408143A852B36D4940710514EAE91742408143A852B36D4940
33768	54038	36.562294000000001	37.577894000000001	50.692495000000001	50.219748000000003	Подлесная	0103000020E61000000100000005000000575EF23FF947424043AED4B3201C4940575EF23FF94742405FD218ADA3584940FE463B6EF8C942405FD218ADA3584940FE463B6EF8C9424043AED4B3201C4940575EF23FF947424043AED4B3201C4940
33580	31987	36.863391999999997	36.882866999999997	50.505499	50.470998999999999	Гагарина	0103000020E6100000010000000500000063D009A1836E42406FB9FAB1493C494063D009A1836E42409294F430B4404940DBDB2DC9017142409294F430B4404940DBDB2DC9017142406FB9FAB1493C494063D009A1836E42406FB9FAB1493C4940
33731	54027	37.265369999999997	37.291213999999997	50.532336999999998	50.508232	Центральная	0103000020E6100000010000000500000075ABE7A4F7A14240ED6305BF0D41494075ABE7A4F7A14240B2B96A9E234449409411178046A54240B2B96A9E234449409411178046A54240ED6305BF0D41494075ABE7A4F7A14240ED6305BF0D414940
33645	31916	37.230812	37.267651999999998	50.509653	50.492728	Ленин	0103000020E610000001000000050000001EC3633F8B9D424068E90AB6113F49401EC3633F8B9D424076A73B4F3C414940C05AB56B42A2424076A73B4F3C414940C05AB56B42A2424068E90AB6113F49401EC3633F8B9D424068E90AB6113F4940
33679	31959	37.203843999999997	37.236220000000003	50.496268999999998	50.481167999999997	Фрунзе	0103000020E610000001000000050000002FBE688F179A4240DCF0BBE9963D49402FBE688F179A424062821ABE853F4940A054FB743C9E424062821ABE853F4940A054FB743C9E4240DCF0BBE9963D49402FBE688F179A4240DCF0BBE9963D4940
33839	30293	37.087063000000001	37.115028000000002	50.671560999999997	50.645408000000003	Больничная	0103000020E6100000010000000500000088D860E1248B4240D449B6BA9C52494088D860E1248B42407022FAB5F5554940E90FCD3CB98E42407022FAB5F5554940E90FCD3CB98E4240D449B6BA9C52494088D860E1248B4240D449B6BA9C524940
33868	29806	37.353682999999997	37.388987	50.656892999999997	50.644288000000003	Октябрьская	0103000020E6100000010000000500000059130B7C45AD4240469A78077852494059130B7C45AD424054FCDF1115544940DAC87553CAB1424054FCDF1115544940DAC87553CAB14240469A78077852494059130B7C45AD4240469A780778524940
33637	30320	37.031475999999998	37.053798999999998	50.589530000000003	50.578170999999998	Ленина	0103000020E61000000100000005000000F04DD36707844240703FE081014A4940F04DD36707844240650113B8754B49405CC7B8E2E2864240650113B8754B49405CC7B8E2E2864240703FE081014A4940F04DD36707844240703FE081014A4940
33721	31681	36.601722000000002	36.648029999999999	50.255417999999999	50.228490999999998	Октябрьская	0103000020E6100000010000000500000051A4FB39054D424015376E313F1D494051A4FB39054D4240A5677A89B1204940D769A4A5F2524240A5677A89B1204940D769A4A5F252424015376E313F1D494051A4FB39054D424015376E313F1D4940
33596	30693	36.969411000000001	36.998021999999999	50.445984000000003	50.417197000000002	Пионерская	0103000020E61000000100000005000000FBB0DEA8157C4240A27E17B666354940FBB0DEA8157C42400745F300163949402158552FBF7F42400745F300163949402158552FBF7F4240A27E17B666354940FBB0DEA8157C4240A27E17B666354940
33412	30693	36.969411000000001	36.998021999999999	50.445984000000003	50.417197000000002	Ленина	0103000020E61000000100000005000000FBB0DEA8157C4240A27E17B666354940FBB0DEA8157C42400745F300163949402158552FBF7F42400745F300163949402158552FBF7F4240A27E17B666354940FBB0DEA8157C4240A27E17B666354940
33724	31038	37.004778000000002	37.038086999999997	50.563285999999998	50.534965	 1 Мая	0103000020E61000000100000005000000C2DEC4909C80424098C0ADBB79444940C2DEC4909C804240B72572C1194849408DB3E908E0844240B72572C1194849408DB3E908E084424098C0ADBB79444940C2DEC4909C80424098C0ADBB79444940
33756	30142	37.453315000000003	37.496470000000002	50.578057000000001	50.551977999999998	Центральная	0103000020E61000000100000005000000A4E4D53906BA4240450E1137A7464940A4E4D53906BA4240A81C93C5FD494940FAB836548CBF4240A81C93C5FD494940FAB836548CBF4240450E1137A7464940A4E4D53906BA4240450E1137A7464940
33843	31517	36.806294999999999	36.813355999999999	50.508541000000001	50.505133000000001	Центральная	0103000020E61000000100000005000000D3F6AFAC34674240B090B932A8404940D3F6AFAC346742406BD619DF17414940B000A60C1C6842406BD619DF17414940B000A60C1C684240B090B932A8404940D3F6AFAC34674240B090B932A8404940
33517	31730	36.801775999999997	36.85201	50.368459999999999	50.31767	Харьковская	0103000020E61000000100000005000000DD5B9198A0664240CD751A69A9284940DD5B9198A06642402CF180B2292F4940B7EEE6A90E6D42402CF180B2292F4940B7EEE6A90E6D4240CD751A69A9284940DD5B9198A0664240CD751A69A9284940
33613	31730	36.801775999999997	36.85201	50.368459999999999	50.31767	Колхозная	0103000020E61000000100000005000000DD5B9198A0664240CD751A69A9284940DD5B9198A06642402CF180B2292F4940B7EEE6A90E6D42402CF180B2292F4940B7EEE6A90E6D4240CD751A69A9284940DD5B9198A0664240CD751A69A9284940
33334	31730	36.801775999999997	36.85201	50.368459999999999	50.31767	Кирова	0103000020E61000000100000005000000DD5B9198A0664240CD751A69A9284940DD5B9198A06642402CF180B2292F4940B7EEE6A90E6D42402CF180B2292F4940B7EEE6A90E6D4240CD751A69A9284940DD5B9198A0664240CD751A69A9284940
33846	32113	36.880710999999998	36.908523000000002	50.582346999999999	50.557718000000001	Ленина	0103000020E610000001000000050000001D1D5723BB704240FD31AD4D634749401D1D5723BB7042403CF6B3588A4A4940F8544E7B4A7442403CF6B3588A4A4940F8544E7B4A744240FD31AD4D634749401D1D5723BB704240FD31AD4D63474940
33761	29905	37.088132000000002	37.112414000000001	50.450923000000003	50.431355000000003	Октябрьская	0103000020E6100000010000000500000094DDCCE8478B4240A9FB00A43637494094DDCCE8478B4240D20149D8B739494068CEFA94638E4240D20149D8B739494068CEFA94638E4240A9FB00A43637494094DDCCE8478B4240A9FB00A436374940
33830	32175	36.901902999999997	36.927180999999997	50.602395000000001	50.574401999999999	Советская	0103000020E610000001000000050000000795B88E71734240E5603601864949400795B88E71734240102384471B4D49407D3CF4DDAD764240102384471B4D49407D3CF4DDAD764240E5603601864949400795B88E71734240E560360186494940
33673	30628	36.999181	37.031951999999997	50.447659000000002	50.423217999999999	Ленина	0103000020E610000001000000050000006DE4BA29E57F42400D8AE6012C3649406DE4BA29E57F42404A61DEE34C3949405985CD00178442404A61DEE34C3949405985CD00178442400D8AE6012C3649406DE4BA29E57F42400D8AE6012C364940
33541	31593	36.688625000000002	36.740448000000001	50.327246000000002	50.292298000000002	Гагарина	0103000020E61000000100000005000000A01A2FDD24584240D65757056A254940A01A2FDD2458424098DF6932E3294940BE310400C75E424098DF6932E3294940BE310400C75E4240D65757056A254940A01A2FDD24584240D65757056A254940
33676	31292	37.417634	37.433705000000003	50.488143000000001	50.477173000000001	Молодежная	0103000020E610000001000000050000004DD9E90775B5424061C43E01143D49404DD9E90775B54240BB6246787B3E49404C8E3BA583B74240BB6246787B3E49404C8E3BA583B7424061C43E01143D49404DD9E90775B5424061C43E01143D4940
33277	31314	36.720371	36.753582000000002	50.465769999999999	50.443092999999998	Шумилова	0103000020E6100000010000000500000050FEEE1D355C4240130B7C45B738494050FEEE1D355C42409DBAF2599E3B4940596DFE5F756042409DBAF2599E3B4940596DFE5F75604240130B7C45B738494050FEEE1D355C4240130B7C45B7384940
33413	31314	36.720371	36.753582000000002	50.465769999999999	50.443092999999998	1 Мая	0103000020E6100000010000000500000050FEEE1D355C4240130B7C45B738494050FEEE1D355C42409DBAF2599E3B4940596DFE5F756042409DBAF2599E3B4940596DFE5F75604240130B7C45B738494050FEEE1D355C4240130B7C45B7384940
33644	30521	37.067686999999999	37.098686999999998	50.439743	50.420876	ул. Садовая	0103000020E61000000100000005000000A3AEB5F7A9884240EDD5C743DF354940A3AEB5F7A98842408DD2A57F493849402AC58EC6A18C42408DD2A57F493849402AC58EC6A18C4240EDD5C743DF354940A3AEB5F7A9884240EDD5C743DF354940
33570	31187	37.312936000000001	37.371029999999998	50.531587000000002	50.518096	Коммунистическая	0103000020E61000000100000005000000DBDE6E490EA842401E1840F850424940DBDE6E490EA8424048FDF50A0B444940DDEA39E97DAF424048FDF50A0B444940DDEA39E97DAF42401E1840F850424940DBDE6E490EA842401E1840F850424940
33274	30906	36.991923	37.030352999999998	50.538691999999998	50.512259	Ленина	0103000020E610000001000000050000003A933655F77E4240740AF2B3914149403A933655F77E4240F44E05DCF3444940F12A6B9BE2834240F44E05DCF3444940F12A6B9BE2834240740AF2B3914149403A933655F77E4240740AF2B391414940
33672	30593	37.137701	37.160212999999999	50.375044000000003	50.361587	Школьная	0103000020E6100000010000000500000031D0B52FA091424052D4997B482E494031D0B52FA0914240D04719710130494070B20DDC81944240D04719710130494070B20DDC8194424052D4997B482E494031D0B52FA091424052D4997B482E4940
33534	31008	37.124127999999999	37.154850000000003	50.562908	50.536665999999997	Гагарина	0103000020E610000001000000050000004A42226DE38F42400470B378B14449404A42226DE38F424011548D5E0D4849408FE4F21FD293424011548D5E0D4849408FE4F21FD29342400470B378B14449404A42226DE38F42400470B378B1444940
33646	32103	36.860633999999997	36.893818000000003	50.462014000000003	50.445262	Победы	0103000020E61000000100000005000000AFE94141296E424066136058FE384940AFE94141296E4240A7255646233B4940BF49D3A068724240A7255646233B4940BF49D3A06872424066136058FE384940AFE94141296E424066136058FE384940
33597	32038	36.862242000000002	36.884456999999998	50.534970999999999	50.508552999999999	Молодежная	0103000020E610000001000000050000006B9E23F25D6E42402FA4C343184149406B9E23F25D6E42407AA702EE79444940F0DB10E3357142407AA702EE79444940F0DB10E3357142402FA4C343184149406B9E23F25D6E42402FA4C34318414940
33565	29994	37.121881999999999	37.139263999999997	50.459135000000003	50.447246	Прилужная	0103000020E610000001000000050000004CFC51D4998F424027A25F5B3F3949404CFC51D4998F424078B988EFC43A49404CC11A67D391424078B988EFC43A49404CC11A67D391424027A25F5B3F3949404CFC51D4998F424027A25F5B3F394940
33812	29711	37.194474999999997	37.229779000000001	50.618423	50.608209000000002	Гагарина	0103000020E61000000100000005000000DE718A8EE49842400211E2CAD94D4940DE718A8EE49842400F0C207C284F49405F27F565699D42400F0C207C284F49405F27F565699D42400211E2CAD94D4940DE718A8EE49842400211E2CAD94D4940
33737	54030	36.717505000000003	36.736899999999999	50.442914999999999	50.428927999999999	Центральная	0103000020E61000000100000005000000B6DB2E34D75B42405A2BDA1CE7364940B6DB2E34D75B424034F44F70B138494011363CBD525E424034F44F70B138494011363CBD525E42405A2BDA1CE7364940B6DB2E34D75B42405A2BDA1CE7364940
33829	31108	37.199244999999998	37.220911999999998	50.552298	50.528042999999997	Серпа и молота	0103000020E610000001000000050000001D7233DC80994240DCF0BBE9964349401D7233DC80994240B7D26BB3B1464940A0A52BD8469C4240B7D26BB3B1464940A0A52BD8469C4240DCF0BBE9964349401D7233DC80994240DCF0BBE996434940
33801	29936	37.155738999999997	37.193972000000002	50.492161000000003	50.470534000000001	Базарная	0103000020E610000001000000050000001ADB6B41EF934240FAD346753A3C49401ADB6B41EF934240EFAEB321FF3E49407C2B1213D4984240EFAEB321FF3E49407C2B1213D4984240FAD346753A3C49401ADB6B41EF934240FAD346753A3C4940
33688	31634	36.656509999999997	36.681384000000001	50.383355999999999	50.361972000000002	Зеленая	0103000020E610000001000000050000009CBF098508544240AB083719552E49409CBF098508544240D95C35CF113149404302469737574240D95C35CF113149404302469737574240AB083719552E49409CBF098508544240AB083719552E4940
33674	30939	36.983280999999998	37.022852	50.500720999999999	50.474254999999999	Победы	0103000020E610000001000000050000009BE3DC26DC7D4240747B4963B43C49409BE3DC26DC7D4240D0B52FA017404940F85278D0EC824240D0B52FA017404940F85278D0EC824240747B4963B43C49409BE3DC26DC7D4240747B4963B43C4940
33460	12823	36.732795000000003	36.745747999999999	50.403736000000002	50.395513999999999	Центральная	0103000020E610000001000000050000000FD6FF39CC5D4240198EE733A03249400FD6FF39CC5D4240E31B0A9FAD3349405987A3AB745F4240E31B0A9FAD3349405987A3AB745F4240198EE733A03249400FD6FF39CC5D4240198EE733A0324940
33429	30495	37.000034999999997	37.045876	50.426775999999997	50.405515999999999	Административная	0103000020E610000001000000050000007CED9925018042409B00C3F2E73349407CED992501804240DD5B9198A0364940EDD5C743DF854240DD5B9198A0364940EDD5C743DF8542409B00C3F2E73349407CED9925018042409B00C3F2E7334940
33677	54021	37.212575999999999	37.244447999999998	50.580401999999999	50.563326000000004	Кооперативная	0103000020E610000001000000050000000EF5BBB0359B4240467EFD101B4849400EF5BBB0359B42403944DC9C4A4A49404BC972124A9F42403944DC9C4A4A49404BC972124A9F4240467EFD101B4849400EF5BBB0359B4240467EFD101B484940
33668	30203	37.437154999999997	37.466233000000003	50.615788000000002	50.595477000000002	Ленина	0103000020E610000001000000050000003524EEB1F4B7424096422097384C49403524EEB1F4B7424077A22424D24E494072A8DF85ADBB424077A22424D24E494072A8DF85ADBB424096422097384C49403524EEB1F4B7424096422097384C4940
33595	30221	37.064658999999999	37.095911999999998	50.646476	50.614610999999996	Советская	0103000020E610000001000000050000002F3201BF468842408461C092AB4E49402F3201BF468842400FD3BEB9BF524940A0A52BD8468C42400FD3BEB9BF524940A0A52BD8468C42408461C092AB4E49402F3201BF468842408461C092AB4E4940
33411	30386	37.276491	37.310958999999997	50.563285999999998	50.528621000000001	пер. Чапаева	0103000020E61000000100000005000000B5519D0E64A342404A7D59DAA9434940B5519D0E64A34240B72572C119484940CCB22781CDA74240B72572C119484940CCB22781CDA742404A7D59DAA9434940B5519D0E64A342404A7D59DAA9434940
33579	30040	37.430489000000001	37.459809999999997	50.553579999999997	50.542785000000002	Калинина	0103000020E61000000100000005000000D52478431AB7424033E197FA79454940D52478431AB742401EDC9DB5DB464940D72FD80DDBBA42401EDC9DB5DB464940D72FD80DDBBA424033E197FA79454940D52478431AB7424033E197FA79454940
33515	29854	37.157527000000002	37.207833000000001	50.477867000000003	50.454994999999997	Школьная	0103000020E61000000100000005000000569E40D829944240F86BB2463D3A4940569E40D829944240386BF0BE2A3D4940C90391459A9A4240386BF0BE2A3D4940C90391459A9A4240F86BB2463D3A4940569E40D829944240F86BB2463D3A4940
33755	29647	37.299478999999998	37.331952999999999	50.636153999999998	50.618675000000003	Кирова	0103000020E610000001000000050000005D6BEF5355A6424029ED0DBE304F49405D6BEF5355A642401B9C887E6D5149409067976F7DAA42401B9C887E6D5149409067976F7DAA424029ED0DBE304F49405D6BEF5355A6424029ED0DBE304F4940
33568	30833	36.769626000000002	36.788176	50.400433999999997	50.391798000000001	Садовый	0103000020E610000001000000050000005E13D21A83624240B151D66F263249405E13D21A836242406D1ADB6B41334940FDBE7FF3E26442406D1ADB6B41334940FDBE7FF3E2644240B151D66F263249405E13D21A83624240B151D66F26324940
33886	31533	36.814864999999998	36.836029000000003	50.571615999999999	50.564224000000003	Центральная	0103000020E61000000100000005000000D8D30E7F4D68424025CFF57D38484940D8D30E7F4D68424067EF8CB62A494940F9C08EFF026B424067EF8CB62A494940F9C08EFF026B424025CFF57D38484940D8D30E7F4D68424025CFF57D38484940
33678	31855	36.768799000000001	36.803097000000001	50.365340000000003	50.344890999999997	Ушакова	0103000020E610000001000000050000004819710168624240A5D76663252C49404819710168624240D8F50B76C32E49400342EBE1CB664240D8F50B76C32E49400342EBE1CB664240A5D76663252C49404819710168624240A5D76663252C4940
33758	29750	37.302191999999998	37.329788000000001	50.617440000000002	50.592967000000002	Пролетарская	0103000020E61000000100000005000000718E3A3AAEA64240BA4DB857E64B4940718E3A3AAEA64240029F1F46084F49407F4E417E36AA4240029F1F46084F49407F4E417E36AA4240BA4DB857E64B4940718E3A3AAEA64240BA4DB857E64B4940
33918	54073	37.225341	37.232132	50.648349000000003	50.644043000000003	Центральная	0103000020E6100000010000000500000056B950F9D79C4240DF1B43007052494056B950F9D79C424079B29B19FD524940732D5A80B69D424079B29B19FD524940732D5A80B69D4240DF1B43007052494056B950F9D79C4240DF1B430070524940
33719	30094	37.509757	37.523851000000001	50.533293999999998	50.525740999999996	Степная	0103000020E610000001000000050000001BF4A5B73FC142404A95287B4B4349401BF4A5B73FC14240969350FA424449400B7DB08C0DC34240969350FA424449400B7DB08C0DC342404A95287B4B4349401BF4A5B73FC142404A95287B4B434940
33450	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	пл. Октябрьская	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33532	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	переулок Оскольский	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33227	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	Строительная	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33456	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	Советская	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33331	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	Революции	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33451	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	Первомайская	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33292	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	Крупская	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33422	26758	37.783644000000002	37.845502000000003	50.984990000000003	50.914296999999998	Кольцова	0103000020E6100000010000000500000073DA53724EE442405BEA20AF0775494073DA53724EE442408B71FE26147E4940EF59D76839EC42408B71FE26147E4940EF59D76839EC42405BEA20AF0775494073DA53724EE442405BEA20AF07754940
33710	27606	37.688952	37.763098999999997	50.870787	50.838273000000001	Школьная	0103000020E61000000100000005000000C44142942FD84240560F98874C6B4940C44142942FD842401764CBF2756F49401E4E603AADE142401764CBF2756F49401E4E603AADE14240560F98874C6B4940C44142942FD84240560F98874C6B4940
33720	48014	38.017035	38.036079000000001	50.987144999999998	50.973132	Центральная	0103000020E6100000010000000500000095F1EF332E0243407558E1968F7C494095F1EF332E02434078B471C45A7E49404489963C9E04434078B471C45A7E49404489963C9E0443407558E1968F7C494095F1EF332E0243407558E1968F7C4940
33867	48002	37.970726999999997	37.992438999999997	51.064328000000003	51.045656000000001	Центральная	0103000020E610000001000000050000000E2C47C840FC4240DF6E490ED88549400E2C47C840FC4240CA1B60E63B8849403123BC3D08FF4240CA1B60E63B8849403123BC3D08FF4240DF6E490ED88549400E2C47C840FC4240DF6E490ED8854940
33631	28548	37.707593000000003	37.746713999999997	50.955416	50.934055000000001	Пятый Центральный переулок	0103000020E6100000010000000500000074F04C6892DA424028D53E1D8F77494074F04C6892DA42409E094D124B7A494090BB085394DF42409E094D124B7A494090BB085394DF424028D53E1D8F77494074F04C6892DA424028D53E1D8F774940
33728	48247	37.582053000000002	37.631272000000003	50.939946999999997	50.923257	им. Ивлева Д.Д	0103000020E61000000100000005000000F4C473B680CA4240CB660E492D764940F4C473B680CA4240957CEC2E50784940B5705985CDD04240957CEC2E50784940B5705985CDD04240CB660E492D764940F4C473B680CA4240CB660E492D764940
33628	48182	37.675891	37.749040999999998	51.077537	51.047960000000003	Центральная	0103000020E610000001000000050000009354A69883D6424012C2A38D238649409354A69883D642406F9D7FBBEC8949407B2E5393E0DF42406F9D7FBBEC8949407B2E5393E0DF424012C2A38D238649409354A69883D6424012C2A38D23864940
33535	48148	37.646856999999997	37.710943	51.014851	51.000217999999997	Школьная	0103000020E610000001000000050000002618CE35CCD242406D6FB724078049402618CE35CCD242400DA837A3E6814940FA28232E00DB42400DA837A3E6814940FA28232E00DB42406D6FB724078049402618CE35CCD242406D6FB72407804940
33826	47836	37.828667000000003	37.870493000000003	51.032493000000002	51.011088000000001	Центральная	0103000020E610000001000000050000002123A0C211EA424064B0E2546B8149402123A0C211EA4240AA2C0ABB28844940CF328B506CEF4240AA2C0ABB28844940CF328B506CEF424064B0E2546B8149402123A0C211EA424064B0E2546B814940
33794	48087	37.545186000000001	37.590820999999998	51.076591999999998	51.051799000000003	Центральная	0103000020E61000000100000005000000581EA4A7C8C54240967B8159A1864940581EA4A7C8C542404F9143C4CD8949401F65C405A0CB42404F9143C4CD8949401F65C405A0CB4240967B8159A1864940581EA4A7C8C54240967B8159A1864940
33836	27971	38.169488000000001	38.238703000000001	51.036684999999999	51.002586999999998	Центральная	0103000020E61000000100000005000000408864C8B1154340873254C554804940408864C8B11543407BA01518B2844940823AE5D18D1E43407BA01518B2844940823AE5D18D1E4340873254C554804940408864C8B1154340873254C554804940
33791	27569	37.921598000000003	37.965237999999999	50.902597	50.877312000000003	Парковая	0103000020E610000001000000050000008E075BECF6F54240B63176C24B7049408E075BECF6F54240DE3B6A4C88734940A06D35EB8CFB4240DE3B6A4C88734940A06D35EB8CFB4240B63176C24B7049408E075BECF6F54240B63176C24B704940
33844	54059	37.902985000000001	37.931910999999999	50.939287999999998	50.922542	Молодёжная	0103000020E61000000100000005000000A8E3310395F34240DD9733DB15764940A8E3310395F342403BC3D4963A7849402EE411DC48F742403BC3D4963A7849402EE411DC48F74240DD9733DB15764940A8E3310395F34240DD9733DB15764940
33536	27767	38.011977999999999	38.059911999999997	51.05386	51.021383999999998	Садовая	0103000020E61000000100000005000000C022BF7E880143402E54FEB5BC824940C022BF7E8801434002486DE2E4864940A8514832AB07434002486DE2E4864940A8514832AB0743402E54FEB5BC824940C022BF7E880143402E54FEB5BC824940
33810	27746	38.219110999999998	38.253849000000002	50.963728000000003	50.946103999999998	Школьная	0103000020E61000000100000005000000D09849D40B1C4340B14E95EF19794940D09849D40B1C4340A81E69705B7B4940A88FC01F7E204340A81E69705B7B4940A88FC01F7E204340B14E95EF19794940D09849D40B1C4340B14E95EF19794940
33793	47938	37.493892000000002	37.529114999999997	50.892121000000003	50.868468	Магистральная	0103000020E61000000100000005000000C6E061DA37BF4240AFCF9CF5296F4940C6E061DA37BF424094895B05317249405969520ABAC3424094895B05317249405969520ABAC34240AFCF9CF5296F4940C6E061DA37BF4240AFCF9CF5296F4940
33891	27996	38.252529000000003	38.306652	51.046658000000001	51.018495000000001	Зеленая	0103000020E610000001000000050000005325CADE52204340DC114E0B5E8249405325CADE52204340630CACE3F885494062A06B5F40274340630CACE3F885494062A06B5F40274340DC114E0B5E8249405325CADE52204340DC114E0B5E824940
33697	54022	37.771183999999998	37.790362999999999	50.949548999999998	50.938420000000001	Воровского	0103000020E6100000010000000500000067994528B6E24240C7F484251E78494067994528B6E24240897956D28A794940F67B629D2AE54240897956D28A794940F67B629D2AE54240C7F484251E78494067994528B6E24240C7F484251E784940
33594	27654	37.552624000000002	37.644871999999999	51.023220000000002	51.008963000000001	Центральная	0103000020E610000001000000050000000B7E1B62BCC64240E1EF17B3258149400B7E1B62BCC642407B4E7ADFF8824940950D6B2A8BD242407B4E7ADFF8824940950D6B2A8BD24240E1EF17B3258149400B7E1B62BCC64240E1EF17B325814940
33709	28268	37.740740000000002	37.759776000000002	51.104053	51.082816999999999	Новая	0103000020E61000000100000005000000666B7D91D0DE4240C34659BF998A4940666B7D91D0DE42407D06D49B518D49409224085740E142407D06D49B518D49409224085740E14240C34659BF998A4940666B7D91D0DE4240C34659BF998A4940
33716	48253	37.636409999999998	37.666854000000001	50.948	50.929122	Центральная	0103000020E61000000100000005000000766C04E275D142403FFF3D78ED764940766C04E275D14240D34D621058794940789ACC785BD54240D34D621058794940789ACC785BD542403FFF3D78ED764940766C04E275D142403FFF3D78ED764940
33706	48155	37.692473999999997	37.741962000000001	50.998607999999997	50.989061	Покровская	0103000020E6100000010000000500000047AAEFFCA2D84240E15F048D997E494047AAEFFCA2D8424011C30E63D27F4940F86F5E9CF8DE424011C30E63D27F4940F86F5E9CF8DE4240E15F048D997E494047AAEFFCA2D84240E15F048D997E4940
33751	27338	37.812362999999998	37.836294000000002	51.051459999999999	51.037880000000001	Садовая	0103000020E610000001000000050000007FBDC282FBE7424014967840D98449407FBDC282FBE74240AD86C43D96864940A7EB89AE0BEB4240AD86C43D96864940A7EB89AE0BEB424014967840D98449407FBDC282FBE7424014967840D9844940
33332	47870	37.772019999999998	37.797721000000003	50.908237	50.861294000000001	Центральная	0103000020E61000000100000005000000D0ED258DD1E24240DA1EBDE13E6E4940D0ED258DD1E2424032022A1C417449408D2AC3B81BE6424032022A1C417449408D2AC3B81BE64240DA1EBDE13E6E4940D0ED258DD1E24240DA1EBDE13E6E4940
33717	48211	37.741621000000002	37.767572999999999	51.044539999999998	51.034441999999999	Полевая	0103000020E610000001000000050000006F83DA6FEDDE4240EECD6F98688449406F83DA6FEDDE424092AE997CB3854940742502D53FE2424092AE997CB3854940742502D53FE24240EECD6F98688449406F83DA6FEDDE4240EECD6F9868844940
33559	47852	38.126181000000003	38.169767	50.950065000000002	50.925238999999998	Центральная	0103000020E610000001000000050000003430F2B226104340EBFD463B6E7649403430F2B2261043408109DCBA9B7949405378D0ECBA1543408109DCBA9B7949405378D0ECBA154340EBFD463B6E7649403430F2B226104340EBFD463B6E764940
33647	27307	37.844881999999998	37.873474999999999	51.064520000000002	51.043939999999999	Покровская	0103000020E61000000100000005000000527DE71725EC42403D7E6FD39F854940527DE71725EC42400EF8FC3042884940D26F5F07CEEF42400EF8FC3042884940D26F5F07CEEF42403D7E6FD39F854940527DE71725EC42403D7E6FD39F854940
33505	27307	37.844881999999998	37.873474999999999	51.064520000000002	51.043939999999999	Курочкина	0103000020E61000000100000005000000527DE71725EC42403D7E6FD39F854940527DE71725EC42400EF8FC3042884940D26F5F07CEEF42400EF8FC3042884940D26F5F07CEEF42403D7E6FD39F854940527DE71725EC42403D7E6FD39F854940
33506	27307	37.844881999999998	37.873474999999999	51.064520000000002	51.043939999999999	Коммунистическая	0103000020E61000000100000005000000527DE71725EC42403D7E6FD39F854940527DE71725EC42400EF8FC3042884940D26F5F07CEEF42400EF8FC3042884940D26F5F07CEEF42403D7E6FD39F854940527DE71725EC42403D7E6FD39F854940
33835	54056	37.584029000000001	37.627121000000002	51.097242999999999	51.076751000000002	Хуторская	0103000020E6100000010000000500000032755776C1CA4240B8770DFAD289494032755776C1CA4240E9616875728C494042D13C8045D04240E9616875728C494042D13C8045D04240B8770DFAD289494032755776C1CA4240B8770DFAD2894940
33708	28474	37.477075999999997	37.495050999999997	50.965882999999998	50.960267000000002	Дачная	0103000020E610000001000000050000006EDA8CD310BD4240CA367007EA7A49406EDA8CD310BD42409561DC0DA27B4940116DC7D45DBF42409561DC0DA27B4940116DC7D45DBF4240CA367007EA7A49406EDA8CD310BD4240CA367007EA7A4940
33718	28463	37.534559000000002	37.575476999999999	50.931302000000002	50.887540999999999	Центральная	0103000020E610000001000000050000002864E76D6CC44240F86D88F19A7149402864E76D6CC44240865968E734774940D34CF73AA9C94240865968E734774940D34CF73AA9C94240F86D88F19A7149402864E76D6CC44240F86D88F19A714940
33790	27198	37.932495000000003	37.954728000000003	50.994191999999998	50.982847	Верхняя	0103000020E610000001000000050000007E5704FF5BF7424061FC34EECD7D49407E5704FF5BF74240F0F8F6AE417F4940AA49F08634FA4240F0F8F6AE417F4940AA49F08634FA424061FC34EECD7D49407E5704FF5BF7424061FC34EECD7D4940
33714	54025	\N	\N	\N	\N	Красовка	\N
33827	48038	38.124724999999998	38.146923000000001	51.023684000000003	51.009127999999997	Центральная	0103000020E610000001000000050000002EFF21FDF60F43402BBD361B2B8149402EFF21FDF60F434020B8CA1308834940DE03745FCE12434020B8CA1308834940DE03745FCE1243402BBD361B2B8149402EFF21FDF60F43402BBD361B2B814940
33930	54078	38.091738999999997	38.123144000000003	50.975577000000001	50.954008999999999	Школьная	0103000020E610000001000000050000004562821ABE0B43407A8B87F71C7A49404562821ABE0B43406ADD06B5DF7C49406D59BE2EC30F43406ADD06B5DF7C49406D59BE2EC30F43407A8B87F71C7A49404562821ABE0B43407A8B87F71C7A4940
33667	53986	37.469853000000001	37.481926999999999	50.406187000000003	50.400433999999997	Ленина	0103000020E61000000100000005000000B876A22424BC42406D1ADB6B41334940B876A22424BC4240BA8784EFFD3349409A07B0C8AFBD4240BA8784EFFD3349409A07B0C8AFBD42406D1ADB6B41334940B876A22424BC42406D1ADB6B41334940
33423	53986	37.469853000000001	37.481926999999999	50.406187000000003	50.400433999999997	Ватутина	0103000020E61000000100000005000000B876A22424BC42406D1ADB6B41334940B876A22424BC4240BA8784EFFD3349409A07B0C8AFBD4240BA8784EFFD3349409A07B0C8AFBD42406D1ADB6B41334940B876A22424BC42406D1ADB6B41334940
33904	54070	37.723905999999999	37.752552999999999	51.225408000000002	51.211005	Центральная	0103000020E6100000010000000500000068B0A9F3A8DC424070253B36029B494068B0A9F3A8DC4240DE205A2BDA9C4940DBC01DA853E04240DE205A2BDA9C4940DBC01DA853E0424070253B36029B494068B0A9F3A8DC424070253B36029B4940
33445	53988	37.586598000000002	38.527251	51.432057999999998	51.020795	м-н Королева	0103000020E6100000010000000500000013F3ACA415CB4240CD751A69A982494013F3ACA415CB4240D2FC31AD4DB7494043E4F4F57C434340D2FC31AD4DB7494043E4F4F57C434340CD751A69A982494013F3ACA415CB4240CD751A69A9824940
33792	47069	37.845691000000002	37.877158999999999	51.128720999999999	51.115763999999999	Центральная	0103000020E61000000100000005000000C2C2499A3FEC4240EE06D15AD18E4940C2C2499A3FEC42407AA702EE799049402F3201BF46F042407AA702EE799049402F3201BF46F04240EE06D15AD18E4940C2C2499A3FEC4240EE06D15AD18E4940
33271	47534	38.260263000000002	38.296232000000003	51.153669999999998	51.126862000000003	Центральная	0103000020E61000000100000005000000EFAD484C50214340768D96033D904940EFAD484C502143402B306475AB934940AC0320EEEA2543402B306475AB934940AC0320EEEA254340768D96033D904940EFAD484C50214340768D96033D904940
33889	25999	37.999338000000002	38.027104999999999	51.233744000000002	51.218870000000003	Мельничная	0103000020E6100000010000000500000035D3BD4EEAFF4240AB09A2EE039C494035D3BD4EEAFF424070D1C952EB9D49406F47382D7803434070D1C952EB9D49406F47382D78034340AB09A2EE039C494035D3BD4EEAFF4240AB09A2EE039C4940
33870	47258	38.050632	38.100003999999998	51.279981999999997	51.257756999999998	Центральная	0103000020E61000000100000005000000C710001C7B06434054A86E2EFEA04940C710001C7B064340FDBB3E73D6A349400EBC5AEECC0C4340FDBB3E73D6A349400EBC5AEECC0C434054A86E2EFEA04940C710001C7B06434054A86E2EFEA04940
33330	26495	37.772162999999999	37.814329999999998	51.370294999999999	51.331660999999997	Натальи Лихачевой	0103000020E610000001000000050000003317B83CD6E24240E82D1EDE73AA49403317B83CD6E24240A86F99D365AF49406A1327F73BE84240A86F99D365AF49406A1327F73BE84240E82D1EDE73AA49403317B83CD6E24240E82D1EDE73AA4940
33837	40476	38.032494999999997	38.069451999999998	51.360532999999997	51.326247000000002	Парковая	0103000020E610000001000000050000004A24D1CB2804434085B53176C2A949404A24D1CB280443407B1002F225AE494026529ACDE30843407B1002F225AE494026529ACDE308434085B53176C2A949404A24D1CB2804434085B53176C2A94940
33707	54015	37.586598000000002	38.527251	51.432057999999998	51.020795	Губкина	0103000020E6100000010000000500000013F3ACA415CB4240CD751A69A982494013F3ACA415CB4240D2FC31AD4DB7494043E4F4F57C434340D2FC31AD4DB7494043E4F4F57C434340CD751A69A982494013F3ACA415CB4240CD751A69A9824940
33638	26232	38.349680999999997	38.427546999999997	51.248517	51.201276	Ленина	0103000020E610000001000000050000002B84D558C22C43401FBC7669C39949402B84D558C22C434001C0B167CF9F49405F402FDCB936434001C0B167CF9F49405F402FDCB93643401FBC7669C39949402B84D558C22C43401FBC7669C3994940
33557	26232	38.349680999999997	38.427546999999997	51.248517	51.201276	Владимира Ленина	0103000020E610000001000000050000002B84D558C22C43401FBC7669C39949402B84D558C22C434001C0B167CF9F49405F402FDCB936434001C0B167CF9F49405F402FDCB93643401FBC7669C39949402B84D558C22C43401FBC7669C3994940
33803	47416	38.475130999999998	38.494562000000002	51.186509999999998	51.162126999999998	Центральная	0103000020E610000001000000050000006B28B517D13C43403866D993C09449406B28B517D13C43404030478FDF97494014ECBFCE4D3F43404030478FDF97494014ECBFCE4D3F43403866D993C09449406B28B517D13C43403866D993C0944940
33828	26175	38.228912000000001	38.262554000000002	51.286050000000003	51.249070000000003	Центральная	0103000020E61000000100000005000000BBD408FD4C1D434016359886E19F4940BBD408FD4C1D4340AA8251499DA449408DB7955E9B214340AA8251499DA449408DB7955E9B21434016359886E19F4940BBD408FD4C1D434016359886E19F4940
33562	54004	37.700792	37.757395000000002	51.308306999999999	51.292814999999997	Заводская	0103000020E6100000010000000500000033A6608DB3D942409D6340F67AA5494033A6608DB3D942405E10919A76A74940B493C151F2E042405E10919A76A74940B493C151F2E042409D6340F67AA5494033A6608DB3D942409D6340F67AA54940
33592	47217	38.004423000000003	38.034849000000001	51.258766000000001	51.237720000000003	Парковая	0103000020E61000000100000005000000D42CD0EE9000434075CDE49B6D9E4940D42CD0EE900043408BA8893E1FA149402FA699EE750443408BA8893E1FA149402FA699EE7504434075CDE49B6D9E4940D42CD0EE9000434075CDE49B6D9E4940
33226	47196	37.962966000000002	37.985360999999997	51.185088	51.172581000000001	пер. Школьный	0103000020E6100000010000000500000079944A7842FB42409B745B221796494079944A7842FB4240E770ADF6B09749407EE02A4F20FE4240E770ADF6B09749407EE02A4F20FE42409B745B221796494079944A7842FB42409B745B2217964940
33841	25823	37.907234000000003	37.936286000000003	51.393802999999998	51.371346000000003	Городок	0103000020E61000000100000005000000DEE8633E20F442400EC0064488AF4940DEE8633E20F442408908FF2268B24940F1D93A38D8F742408908FF2268B24940F1D93A38D8F742400EC0064488AF4940DEE8633E20F442400EC0064488AF4940
33224	25842	37.895178999999999	37.959642000000002	51.279243999999998	51.260688000000002	Центральная	0103000020E610000001000000050000007288B83995F24240D63A71395EA149407288B83995F2424057CD7344BEA349401CEF8E8CD5FA424057CD7344BEA349401CEF8E8CD5FA4240D63A71395EA149407288B83995F24240D63A71395EA14940
33272	47029	37.760781999999999	37.797091999999999	51.160420999999999	51.149258000000003	Южная	0103000020E6100000010000000500000057B1F84D61E142404C55DAE21A93494057B1F84D61E14240BA4BE2AC889449409DF3531C07E64240BA4BE2AC889449409DF3531C07E642404C55DAE21A93494057B1F84D61E142404C55DAE21A934940
33233	16865	37.948664000000001	37.981489000000003	51.371560000000002	51.351618000000002	Центральная	0103000020E610000001000000050000003F726BD26DF94240AC5791D101AD49403F726BD26DF942403A4030478FAF49401F317A6EA1FD42403A4030478FAF49401F317A6EA1FD4240AC5791D101AD49403F726BD26DF94240AC5791D101AD4940
33566	46955	38.203606000000001	38.235388999999998	51.095393000000001	51.070439999999998	Центральная	0103000020E610000001000000050000007BA2EBC20F1A4340452A8C2D048949407BA2EBC20F1A434038A27BD6358C4940486B0C3A211E434038A27BD6358C4940486B0C3A211E4340452A8C2D048949407BA2EBC20F1A4340452A8C2D04894940
33551	47133	37.976809000000003	38.039259999999999	51.328724000000001	51.287633	Котовская	0103000020E6100000010000000500000020B8CA1308FD42400C207C28D1A4494020B8CA1308FD424085B4C6A013AA49403E05C0780605434085B4C6A013AA49403E05C078060543400C207C28D1A4494020B8CA1308FD42400C207C28D1A44940
33593	47498	37.797451000000002	37.874777999999999	51.369748999999999	51.328178000000001	Московская	0103000020E61000000100000005000000CD94D6DF12E6424023A298BC01AA4940CD94D6DF12E64240465D6BEF53AF494051A1BAB9F8EF4240465D6BEF53AF494051A1BAB9F8EF424023A298BC01AA4940CD94D6DF12E6424023A298BC01AA4940
33840	25684	37.874194000000003	37.905392999999997	51.125867	51.103645	Центральная	0103000020E61000000100000005000000022EC896E5EF42406CB2463D448D4940022EC896E5EF4240A452EC681C9049407F83F6EAE3F34240A452EC681C9049407F83F6EAE3F342406CB2463D448D4940022EC896E5EF42406CB2463D448D4940
33619	47142	37.850918999999998	37.867708	51.105387	51.089770000000001	Молодежная	0103000020E61000000100000005000000C345EEE9EAEC4240BA1457957D8B4940C345EEE9EAEC424037363B527D8D4940213D450E11EF424037363B527D8D4940213D450E11EF4240BA1457957D8B4940C345EEE9EAEC4240BA1457957D8B4940
33669	47083	38.258763000000002	38.294218999999998	51.217663000000002	51.175556999999998	Центральная	0103000020E610000001000000050000001A355F251F214340BCCADAA6789649401A355F251F2143404E469561DC9B4940506EDBF7A82543404E469561DC9B4940506EDBF7A8254340BCCADAA6789649401A355F251F214340BCCADAA678964940
33629	46990	37.716763999999998	37.748744000000002	51.162517000000001	51.143782999999999	Центральная	0103000020E610000001000000050000009E7939ECBEDB4240425C397B679249409E7939ECBEDB4240A305685BCD944940C289E8D7D6DF4240A305685BCD944940C289E8D7D6DF4240425C397B679249409E7939ECBEDB4240425C397B67924940
33548	54001	38.097731000000003	38.145646999999997	51.241509000000001	51.203935000000001	Садовая	0103000020E6100000010000000500000017670C73820C434040C1C58A1A9A494017670C73820C4340475854C4E99E494058E1968FA4124340475854C4E99E494058E1968FA412434040C1C58A1A9A494017670C73820C434040C1C58A1A9A4940
33419	46915	37.999302	38.120987999999997	51.165385999999998	51.062528	Гагарина	0103000020E61000000100000005000000E869C020E9FF4240CA8AE1EA00884940E869C020E9FF4240AE9B525E2B954940AE9AE7887C0F4340AE9B525E2B954940AE9AE7887C0F4340CA8AE1EA00884940E869C020E9FF4240CA8AE1EA00884940
33561	46859	38.089798999999999	38.133941999999998	51.267952000000001	51.244914999999999	Центральная	0103000020E61000000100000005000000541B9C887E0B434061A6ED5F599F4940541B9C887E0B4340EB724A404CA24940C9C7EE0225114340EB724A404CA24940C9C7EE022511434061A6ED5F599F4940541B9C887E0B434061A6ED5F599F4940
33396	20522	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	Шевченко	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
33545	20522	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	Чапаева	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
33338	20522	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	Пролетарская	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
33399	20522	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	Московская	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
33219	20522	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	Ленина	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
33397	20522	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	Докучаева	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
33225	20522	38.842739999999999	38.929228999999999	49.943593999999997	49.878267999999998	Горького	0103000020E61000000100000005000000F98381E7DE6B4340C98FF8156BF04840F98381E7DE6B4340D5592DB0C7F8484055BFD2F9F0764340D5592DB0C7F8484055BFD2F9F0764340C98FF8156BF04840F98381E7DE6B4340C98FF8156BF04840
33567	54005	35.542195	36.161897000000003	51.035518000000003	50.650297000000002	Совхозное	0103000020E61000000100000005000000018750A566C54140EDD79DEE3C534940018750A566C54140AD3594DA8B8449400729780AB9144240AD3594DA8B8449400729780AB9144240EDD79DEE3C534940018750A566C54140EDD79DEE3C534940
33695	18977	35.879952000000003	35.901708999999997	50.731695999999999	50.703631999999999	Почтовая	0103000020E6100000010000000500000060066344A2F04140A435069D105A494060066344A2F04140984EEB36A85D494022C154336BF34140984EEB36A85D494022C154336BF34140A435069D105A494060066344A2F04140A435069D105A4940
33296	18873	35.747630000000001	35.816253000000003	50.746403000000001	50.707363000000001	Центральная	0103000020E6100000010000000500000016C1FF56B2DF414042B3EBDE8A5A494016C1FF56B2DF414072512D228A5F4940862172FA7AE8414072512D228A5F4940862172FA7AE8414042B3EBDE8A5A494016C1FF56B2DF414042B3EBDE8A5A4940
33664	18873	35.747630000000001	35.816253000000003	50.746403000000001	50.707363000000001	Третьяковка	0103000020E6100000010000000500000016C1FF56B2DF414042B3EBDE8A5A494016C1FF56B2DF414072512D228A5F4940862172FA7AE8414072512D228A5F4940862172FA7AE8414042B3EBDE8A5A494016C1FF56B2DF414042B3EBDE8A5A4940
33696	18790	35.723205	35.748654000000002	50.680362000000002	50.659931	Новостороевка	0103000020E61000000100000005000000DFA63FFB91DC4140EC4E779E78544940DFA63FFB91DC414078B81D1A165749408202EFE4D3DF414078B81D1A165749408202EFE4D3DF4140EC4E779E78544940DFA63FFB91DC4140EC4E779E78544940
33218	19262	35.802759999999999	35.909407999999999	50.863987999999999	50.814233999999999	Федутенко	0103000020E61000000100000005000000BB44F5D6C0E6414048A5D8D138684940BB44F5D6C0E641407711A628976E4940425C397B67F441407711A628976E4940425C397B67F4414048A5D8D138684940BB44F5D6C0E6414048A5D8D138684940
33394	19262	35.802759999999999	35.909407999999999	50.863987999999999	50.814233999999999	Пролетарская	0103000020E61000000100000005000000BB44F5D6C0E6414048A5D8D138684940BB44F5D6C0E641407711A628976E4940425C397B67F441407711A628976E4940425C397B67F4414048A5D8D138684940BB44F5D6C0E6414048A5D8D138684940
33285	19262	35.802759999999999	35.909407999999999	50.863987999999999	50.814233999999999	Новосадовая	0103000020E61000000100000005000000BB44F5D6C0E6414048A5D8D138684940BB44F5D6C0E641407711A628976E4940425C397B67F441407711A628976E4940425C397B67F4414048A5D8D138684940BB44F5D6C0E6414048A5D8D138684940
33286	19262	35.802759999999999	35.909407999999999	50.863987999999999	50.814233999999999	Коммунаров	0103000020E61000000100000005000000BB44F5D6C0E6414048A5D8D138684940BB44F5D6C0E641407711A628976E4940425C397B67F441407711A628976E4940425C397B67F4414048A5D8D138684940BB44F5D6C0E6414048A5D8D138684940
33749	18269	35.943750000000001	35.981938	50.918959000000001	50.899433000000002	Центральная	0103000020E61000000100000005000000CDCCCCCCCCF84140BAF8DB9E20734940CDCCCCCCCCF84140B4AED172A07549408E59F624B0FD4140B4AED172A07549408E59F624B0FD4140BAF8DB9E20734940CDCCCCCCCCF84140BAF8DB9E20734940
33424	19092	35.743363000000002	35.796930000000003	50.804859999999998	50.783912999999998	Пролетарская	0103000020E610000001000000050000003A07CF8426DF414062F4DC42576449403A07CF8426DF4140E5ED08A705674940C4995FCD01E64140E5ED08A705674940C4995FCD01E6414062F4DC42576449403A07CF8426DF414062F4DC4257644940
33281	19092	35.743363000000002	35.796930000000003	50.804859999999998	50.783912999999998	Почтовый	0103000020E610000001000000050000003A07CF8426DF414062F4DC42576449403A07CF8426DF4140E5ED08A705674940C4995FCD01E64140E5ED08A705674940C4995FCD01E6414062F4DC42576449403A07CF8426DF414062F4DC4257644940
33511	19092	35.743363000000002	35.796930000000003	50.804859999999998	50.783912999999998	Ватутина	0103000020E610000001000000050000003A07CF8426DF414062F4DC42576449403A07CF8426DF4140E5ED08A705674940C4995FCD01E64140E5ED08A705674940C4995FCD01E6414062F4DC42576449403A07CF8426DF414062F4DC4257644940
33874	18344	36.057405000000003	36.080492	50.922955999999999	50.902828999999997	Центральная	0103000020E610000001000000050000003ED00A0C59074240B07092E68F7349403ED00A0C59074240D0D2156C2376494079CBD58F4D0A4240D0D2156C2376494079CBD58F4D0A4240B07092E68F7349403ED00A0C59074240B07092E68F734940
33834	19006	35.825029000000001	35.850892000000002	50.737237999999998	50.711567000000002	Центральная	0103000020E6100000010000000500000034A0DE8C9AE94140D8F4A0A0145B494034A0DE8C9AE9414029AF95D05D5E4940CA367007EAEC414029AF95D05D5E4940CA367007EAEC4140D8F4A0A0145B494034A0DE8C9AE94140D8F4A0A0145B4940
33564	18603	35.595581000000003	35.625692999999998	50.908951999999999	50.893303000000003	Советская	0103000020E610000001000000050000003B8F8AFF3BCC41409835B1C0577249403B8F8AFF3BCC414020D1048A58744940062B4EB516D0414020D1048A58744940062B4EB516D041409835B1C0577249403B8F8AFF3BCC41409835B1C057724940
33884	18450	35.984399000000003	36.017493000000002	50.790774999999996	50.765675000000002	Шатилова	0103000020E61000000100000005000000899B53C900FE4140B22E6EA301624940899B53C900FE414048BF7D1D386549405874EB353D02424048BF7D1D386549405874EB353D024240B22E6EA301624940899B53C900FE4140B22E6EA301624940
33591	18450	35.984399000000003	36.017493000000002	50.790774999999996	50.765675000000002	Выгон	0103000020E61000000100000005000000899B53C900FE4140B22E6EA301624940899B53C900FE414048BF7D1D386549405874EB353D02424048BF7D1D386549405874EB353D024240B22E6EA301624940899B53C900FE4140B22E6EA301624940
33665	18776	35.982872	36.028381000000003	50.982722000000003	50.945757999999998	Центральная	0103000020E61000000100000005000000BA13ECBFCEFD414016F71F990E794940BA13ECBFCEFD4140A587A1D5C97D4940F56915FDA1034240A587A1D5C97D4940F56915FDA103424016F71F990E794940BA13ECBFCEFD414016F71F990E794940
33590	18218	35.99588	36.043588999999997	50.942540000000001	50.917254999999997	Центральная	0103000020E61000000100000005000000C85EEFFE78FF4140D68BA19C68754940C85EEFFE78FF4140FF959526A578494090BB085394054240FF959526A578494090BB085394054240D68BA19C68754940C85EEFFE78FF4140D68BA19C68754940
33754	18896	35.889150999999998	35.910305999999999	50.750889000000001	50.721375999999999	Гордеевка	0103000020E61000000100000005000000541A31B3CFF14140450F7C0C565C4940541A31B3CFF141408CF678211D60494021AD31E884F441408CF678211D60494021AD31E884F44140450F7C0C565C4940541A31B3CFF14140450F7C0C565C4940
33883	19493	35.972819999999999	36.013764999999999	50.859662	50.819873999999999	Ленина	0103000020E610000001000000050000008672A25D85FC41409C6B98A1F16849408672A25D85FC414096CE8767096E49402B6A300DC301424096CE8767096E49402B6A300DC30142409C6B98A1F16849408672A25D85FC41409C6B98A1F1684940
33876	18123	35.758589999999998	35.771436000000001	50.890172	50.867956	Молодёжная	0103000020E610000001000000050000004C89247A19E14140F92EA52E196F49404C89247A19E141404FE8F527F1714940817A336ABEE241404FE8F527F1714940817A336ABEE24140F92EA52E196F49404C89247A19E14140F92EA52E196F4940
33824	18360	36.011249999999997	36.037849000000001	50.901983000000001	50.868695000000002	Центральная	0103000020E610000001000000050000003D0AD7A3700142407099D365316F49403D0AD7A3700142402446CF2D74734940D9976C3CD80442402446CF2D74734940D9976C3CD80442407099D365316F49403D0AD7A3700142407099D365316F4940
33543	4051	36.883209000000001	36.909305000000003	51.164177000000002	51.136780999999999	Центральная	0103000020E61000000100000005000000354415FE0C7142406ADB300A82914940354415FE0C714240B1E07EC0039549406E8B321B64744240B1E07EC0039549406E8B321B647442406ADB300A82914940354415FE0C7142406ADB300A82914940
33682	4051	36.883209000000001	36.909305000000003	51.164177000000002	51.136780999999999	Белгородская	0103000020E61000000100000005000000354415FE0C7142406ADB300A82914940354415FE0C714240B1E07EC0039549406E8B321B64744240B1E07EC0039549406E8B321B647442406ADB300A82914940354415FE0C7142406ADB300A82914940
33234	17324	36.690897	36.774791	51.051307000000001	51.018126000000002	переулок 1-й Советский	0103000020E61000000100000005000000C7F319506F584240899AE8F351824940C7F319506F58424027874F3A91864940191EFB592C63424027874F3A91864940191EFB592C634240899AE8F351824940C7F319506F584240899AE8F351824940
33239	17324	36.690897	36.774791	51.051307000000001	51.018126000000002	Советская	0103000020E61000000100000005000000C7F319506F584240899AE8F351824940C7F319506F58424027874F3A91864940191EFB592C63424027874F3A91864940191EFB592C634240899AE8F351824940C7F319506F584240899AE8F351824940
33512	17324	36.690897	36.774791	51.051307000000001	51.018126000000002	Первомайская	0103000020E61000000100000005000000C7F319506F584240899AE8F351824940C7F319506F58424027874F3A91864940191EFB592C63424027874F3A91864940191EFB592C634240899AE8F351824940C7F319506F584240899AE8F351824940
33486	17324	36.690897	36.774791	51.051307000000001	51.018126000000002	Парковая	0103000020E61000000100000005000000C7F319506F584240899AE8F351824940C7F319506F58424027874F3A91864940191EFB592C63424027874F3A91864940191EFB592C634240899AE8F351824940C7F319506F584240899AE8F351824940
33454	17324	36.690897	36.774791	51.051307000000001	51.018126000000002	Мичурина	0103000020E61000000100000005000000C7F319506F584240899AE8F351824940C7F319506F58424027874F3A91864940191EFB592C63424027874F3A91864940191EFB592C634240899AE8F351824940C7F319506F584240899AE8F351824940
33602	15950	36.654704000000002	36.669516999999999	51.028250999999997	51.020330000000001	Центральная	0103000020E61000000100000005000000BB473657CD5342405890662C9A824940BB473657CD534240268A90BA9D834940DA8EA9BBB2554240268A90BA9D834940DA8EA9BBB25542405890662C9A824940BB473657CD5342405890662C9A824940
33446	20833	36.603904	36.615617999999998	50.989849	50.980322999999999	Гайдара	0103000020E6100000010000000500000038F6ECB94C4D424020425C397B7D494038F6ECB94C4D4240397D3D5FB37E49401A6A1492CC4E4240397D3D5FB37E49401A6A1492CC4E424020425C397B7D494038F6ECB94C4D424020425C397B7D4940
33744	13922	37.730688000000001	37.775585999999997	50.738771	50.721153999999999	Александра Адонина	0103000020E6100000010000000500000032CA332F87DD424096B036C64E5C494032CA332F87DD4240DA1D520C905E4940239EEC6646E34240DA1D520C905E4940239EEC6646E3424096B036C64E5C494032CA332F87DD424096B036C64E5C4940
33509	13498	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	площадь Центральная	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
33362	13498	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	Сушкова	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
33448	13498	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	Оскольская	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
33315	13498	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	Ливенская	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
33389	13498	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	Кооперативная	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
33489	13498	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	Дорожная	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
33267	13498	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	Авиационная	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
33750	13194	35.491691000000003	35.529240999999999	50.730373999999998	50.710014999999999	Новостроевка	0103000020E61000000100000005000000685E0EBBEFBE4140B05582C5E15A4940685E0EBBEFBE4140A2EC2DE57C5D4940E659492BBEC34140A2EC2DE57C5D4940E659492BBEC34140B05582C5E15A4940685E0EBBEFBE4140B05582C5E15A4940
33880	46617	35.466304999999998	35.478000999999999	50.710785000000001	50.699091000000003	Подлесье	0103000020E610000001000000050000000B7BDAE1AFBB4140C7F65AD07B5949400B7BDAE1AFBB414062BEBC00FB5A4940473A03232FBD414062BEBC00FB5A4940473A03232FBD4140C7F65AD07B5949400B7BDAE1AFBB4140C7F65AD07B594940
33662	46532	35.456612	35.511158000000002	50.879539999999999	50.850962000000003	Садовая	0103000020E61000000100000005000000077B134372BA4140C311A452EC6C4940077B134372BA41400DC347C4947049405D8B16A06DC141400DC347C4947049405D8B16A06DC14140C311A452EC6C4940077B134372BA4140C311A452EC6C4940
33610	10482	35.631352	35.68835	50.825671999999997	50.773569999999999	Центральная	0103000020E61000000100000005000000D1217024D0D0414057957D5704634940D1217024D0D04140889CBE9EAF694940CE1951DA1BD84140889CBE9EAF694940CE1951DA1BD8414057957D5704634940D1217024D0D0414057957D5704634940
33314	10482	35.631352	35.68835	50.825671999999997	50.773569999999999	Театральная	0103000020E61000000100000005000000D1217024D0D0414057957D5704634940D1217024D0D04140889CBE9EAF694940CE1951DA1BD84140889CBE9EAF694940CE1951DA1BD8414057957D5704634940D1217024D0D0414057957D5704634940
33316	10482	35.631352	35.68835	50.825671999999997	50.773569999999999	Мира	0103000020E61000000100000005000000D1217024D0D0414057957D5704634940D1217024D0D04140889CBE9EAF694940CE1951DA1BD84140889CBE9EAF694940CE1951DA1BD8414057957D5704634940D1217024D0D0414057957D5704634940
33588	10482	35.631352	35.68835	50.825671999999997	50.773569999999999	Крыловка	0103000020E61000000100000005000000D1217024D0D0414057957D5704634940D1217024D0D04140889CBE9EAF694940CE1951DA1BD84140889CBE9EAF694940CE1951DA1BD8414057957D5704634940D1217024D0D0414057957D5704634940
33363	10482	35.631352	35.68835	50.825671999999997	50.773569999999999	 Парковая	0103000020E61000000100000005000000D1217024D0D0414057957D5704634940D1217024D0D04140889CBE9EAF694940CE1951DA1BD84140889CBE9EAF694940CE1951DA1BD8414057957D5704634940D1217024D0D0414057957D5704634940
33864	46492	35.422072	35.449866	50.822553999999997	50.804223	Центральная	0103000020E6100000010000000500000056478E7406B6414073D87DC7F066494056478E7406B64140D4981073496949408ACA863595B94140D4981073496949408ACA863595B9414073D87DC7F066494056478E7406B6414073D87DC7F0664940
33888	46438	35.382033999999997	35.400827	50.951920999999999	50.940060000000003	Школьная	0103000020E61000000100000005000000E3FA777DE6B041408E23D6E253784940E3FA777DE6B0414014B01D8CD8794940492D944C4EB3414014B01D8CD8794940492D944C4EB341408E23D6E253784940E3FA777DE6B041408E23D6E253784940
33861	11128	38.436647000000001	38.466605999999999	50.657423999999999	50.638913000000002	Горького	0103000020E61000000100000005000000C172840CE4374340A0FEB3E6C7514940C172840CE437434081CD397826544940060FD3BEB93B434081CD397826544940060FD3BEB93B4340A0FEB3E6C7514940C172840CE4374340A0FEB3E6C7514940
33823	12614	38.296187000000003	38.332811	50.840679000000002	50.823816999999998	Советская	0103000020E610000001000000050000000C40A374E9254340C571E0D5726949400C40A374E92543408DB7955E9B6B4940E15F048D992A43408DB7955E9B6B4940E15F048D992A4340C571E0D5726949400C40A374E9254340C571E0D572694940
33777	12750	38.330331999999999	38.353040999999997	50.816989	50.805337999999999	Садовая	0103000020E610000001000000050000004069A851482A4340EF1CCA50156749404069A851482A43408B18761893684940D5928E72302D43408B18761893684940D5928E72302D4340EF1CCA50156749404069A851482A4340EF1CCA5015674940
33626	12398	38.454478999999999	38.487006999999998	50.695394	50.667335999999999	Победы	0103000020E6100000010000000500000001DC2C5E2C3A4340C3B81B446B55494001DC2C5E2C3A4340D5EAABAB0259494027F6D03E563E4340D5EAABAB0259494027F6D03E563E4340C3B81B446B55494001DC2C5E2C3A4340C3B81B446B554940
33622	10627	38.464323999999998	38.505412999999997	50.765338999999997	50.743212	пер. Первомайский	0103000020E61000000100000005000000BB5F05F86E3B434054FF2092215F4940BB5F05F86E3B43403AADDBA0F661494093FC885FB14043403AADDBA0F661494093FC885FB140434054FF2092215F4940BB5F05F86E3B434054FF2092215F4940
33611	10627	38.464323999999998	38.505412999999997	50.765338999999997	50.743212	Центральная	0103000020E61000000100000005000000BB5F05F86E3B434054FF2092215F4940BB5F05F86E3B43403AADDBA0F661494093FC885FB14043403AADDBA0F661494093FC885FB140434054FF2092215F4940BB5F05F86E3B434054FF2092215F4940
33624	12044	38.364646999999998	38.421590999999999	50.346575000000001	50.308304999999997	Октябрьская	0103000020E61000000100000005000000D1CABDC0AC2E4340BD18CA8976274940D1CABDC0AC2E43403C4ED1915C2C4940DBA4A2B1F63543403C4ED1915C2C4940DBA4A2B1F6354340BD18CA8976274940D1CABDC0AC2E4340BD18CA8976274940
33733	10235	38.304909000000002	38.326658000000002	50.648485999999998	50.637348000000003	Лесная	0103000020E61000000100000005000000C7A0134207274340E415889E94514940C7A0134207274340F9F4D89601534940077DE9EDCF294340F9F4D89601534940077DE9EDCF294340E415889E94514940C7A0134207274340E415889E94514940
33863	12500	38.372301	38.393259	50.726080000000003	50.714041999999999	Подлесная	0103000020E6100000010000000500000051A2258FA72F434037FC6EBA655B494051A2258FA72F4340CD237F30F05C4940C8ED974F56324340CD237F30F05C4940C8ED974F5632434037FC6EBA655B494051A2258FA72F434037FC6EBA655B4940
33574	11041	38.194713	38.226612000000003	50.637501999999998	50.625611999999997	Школьная	0103000020E61000000100000005000000938D075BEC18434019FED30D14504940938D075BEC1843403A9160AA99514940CA703C9F011D43403A9160AA99514940CA703C9F011D434019FED30D14504940938D075BEC18434019FED30D14504940
33878	10508	38.478454999999997	38.518177999999999	50.817284999999998	50.801102999999998	Коммунистичесая	0103000020E61000000100000005000000C8CD70033E3D43401EDD088B8A664940C8CD70033E3D434074417DCB9C684940DBC01DA85342434074417DCB9C684940DBC01DA8534243401EDD088B8A664940C8CD70033E3D43401EDD088B8A664940
33746	12572	38.309005999999997	38.341363000000001	50.763761000000002	50.742203000000003	Мира	0103000020E61000000100000005000000462234828D2743401EFF0582005F4940462234828D274340EA7AA2EBC2614940408864C8B12B4340EA7AA2EBC2614940408864C8B12B43401EFF0582005F4940462234828D2743401EFF0582005F4940
33701	11443	38.478831999999997	38.498002	50.509120000000003	50.499775999999997	Гагарина	0103000020E610000001000000050000009E23F25D4A3D4340B0A9F3A8F83F49409E23F25D4A3D4340A9DE1AD82A414940DAAB8F87BE3F4340A9DE1AD82A414940DAAB8F87BE3F4340B0A9F3A8F83F49409E23F25D4A3D4340B0A9F3A8F83F4940
33734	12700	38.268141	38.308160999999998	50.830241000000001	50.820711000000003	Заречная	0103000020E61000000100000005000000BEDBBC7152224340D63BDC0E0D694940BEDBBC715222434030664B56456A49408A73D4D17127434030664B56456A49408A73D4D171274340D63BDC0E0D694940BEDBBC7152224340D63BDC0E0D694940
33781	10420	38.435093000000002	38.453823	50.773234000000002	50.757949000000004	Цветочная	0103000020E61000000100000005000000F9DB9E20B137434099840B7904614940F9DB9E20B1374340E013EB54F962494018963FDF163A4340E013EB54F962494018963FDF163A434099840B7904614940F9DB9E20B137434099840B7904614940
33577	12232	38.136735999999999	38.190750999999999	50.436467	50.403328000000002	Набережная	0103000020E61000000100000005000000CA17B49080114340D2C77C40A0334940CA17B4908011434041649126DE374940F3565D876A18434041649126DE374940F3565D876A184340D2C77C40A0334940CA17B49080114340D2C77C40A0334940
33702	11496	38.415239999999997	38.442819	50.447980000000001	50.421519000000004	Чапаева	0103000020E61000000100000005000000DAFE95952635434042D2A755F4354940DAFE9595263543408CA19C68573949401286014BAE3843408CA19C68573949401286014BAE38434042D2A755F4354940DAFE95952635434042D2A755F4354940
33785	10776	38.215248000000003	38.238011999999998	50.686441000000002	50.677433999999998	Октябрьская	0103000020E61000000100000005000000C443183F8D1B434067994528B6564940C443183F8D1B434018D1764CDD5749401C075E2D771E434018D1764CDD5749401C075E2D771E434067994528B6564940C443183F8D1B434067994528B6564940
33703	12140	38.174850999999997	38.218823999999998	50.574528000000001	50.551296999999998	Молодежная	0103000020E6100000010000000500000021567F846116434003B16CE69046494021567F846116434072512D228A4949403ACAC16C021C434072512D228A4949403ACAC16C021C434003B16CE69046494021567F846116434003B16CE690464940
33745	10957	38.032235	38.049770000000002	50.627251999999999	50.619509000000001	Народная	0103000020E61000000100000005000000AE64C74620044340F14927124C4F4940AE64C74620044340E02C25CB49504940352905DD5E064340E02C25CB49504940352905DD5E064340F14927124C4F4940AE64C74620044340F14927124C4F4940
33531	11932	38.380609999999997	38.467936000000002	50.388765999999997	50.324967999999998	Калинина	0103000020E61000000100000005000000E94317D4B73043408E1F2A8D98294940E94317D4B7304340FBE59315C33149407F4FAC53E53B4340FBE59315C33149407F4FAC53E53B43408E1F2A8D98294940E94317D4B73043408E1F2A8D98294940
33392	11932	38.380609999999997	38.467936000000002	50.388765999999997	50.324967999999998	1 Мая	0103000020E61000000100000005000000E94317D4B73043408E1F2A8D98294940E94317D4B7304340FBE59315C33149407F4FAC53E53B4340FBE59315C33149407F4FAC53E53B43408E1F2A8D98294940E94317D4B73043408E1F2A8D98294940
33850	54060	38.017898000000002	38.609392999999997	50.913201000000001	50.280194000000002	Мирная	0103000020E61000000100000005000000F8544E7B4A0243408944A165DD234940F8544E7B4A02434056D636C5E3744940A6B4FE96004E434056D636C5E3744940A6B4FE96004E43408944A165DD234940F8544E7B4A0243408944A165DD234940
33822	12475	38.350723000000002	38.380305	50.74259	50.723201000000003	Моледежная	0103000020E610000001000000050000003E7AC37DE42C43409EB7B1D9915C49403E7AC37DE42C4340172B6A300D5F4940ADC090D5AD304340172B6A300D5F4940ADC090D5AD3043409EB7B1D9915C49403E7AC37DE42C43409EB7B1D9915C4940
33589	12380	38.467567000000003	38.523173	50.665823000000003	50.657297999999997	Пушкарная	0103000020E610000001000000050000002CD8463CD93B4340F4DC4257225449402CD8463CD93B43405AF624B0395549403A933655F74243405AF624B0395549403A933655F7424340F4DC4257225449402CD8463CD93B4340F4DC425722544940
33558	11719	38.234949	38.311574999999998	50.469943999999998	50.426735999999998	Учительская	0103000020E610000001000000050000002C9D0FCF121E43404F0306499F3649402C9D0FCF121E4340C879FF1F273C494027A089B0E1274340C879FF1F273C494027A089B0E12743404F0306499F3649402C9D0FCF121E43404F0306499F364940
33195	11719	38.234949	38.311574999999998	50.469943999999998	50.426735999999998	Транспортная	0103000020E610000001000000050000002C9D0FCF121E43404F0306499F3649402C9D0FCF121E4340C879FF1F273C494027A089B0E1274340C879FF1F273C494027A089B0E12743404F0306499F3649402C9D0FCF121E43404F0306499F364940
33538	11719	38.234949	38.311574999999998	50.469943999999998	50.426735999999998	Советская	0103000020E610000001000000050000002C9D0FCF121E43404F0306499F3649402C9D0FCF121E4340C879FF1F273C494027A089B0E1274340C879FF1F273C494027A089B0E12743404F0306499F3649402C9D0FCF121E43404F0306499F364940
33847	12270	38.116883000000001	38.138244999999998	50.474203000000003	50.462288999999998	Московская	0103000020E61000000100000005000000AC3AAB05F60E4340782634492C3B4940AC3AAB05F60E4340225514AFB23C4940F2EA1C03B2114340225514AFB23C4940F2EA1C03B2114340782634492C3B4940AC3AAB05F60E4340782634492C3B4940
33802	10296	38.316910999999998	38.359068999999998	50.396127999999997	50.384923999999998	Молодежная	0103000020E610000001000000050000000F5F268A9028434006B98B30453149400F5F268A90284340D3838252B4324940F30016F9F52D4340D3838252B4324940F30016F9F52D434006B98B30453149400F5F268A9028434006B98B3045314940
33820	10986	38.145403999999999	38.173665	50.705731	50.678924000000002	Пролетарская	0103000020E61000000100000005000000925A28999C124340193C4CFBE6564940925A28999C124340FE62B664555A4940DCBA9BA73A164340FE62B664555A4940DCBA9BA73A164340193C4CFBE6564940925A28999C124340193C4CFBE6564940
33686	11521	38.360174000000001	38.382623000000002	50.551656999999999	50.537095000000001	Советская	0103000020E610000001000000050000004C6F7F2E1A2E43402DEC6987BF4449404C6F7F2E1A2E434003CE52B29C46494045D95BCAF930434003CE52B29C46494045D95BCAF93043402DEC6987BF4449404C6F7F2E1A2E43402DEC6987BF444940
33821	11710	38.309193999999998	38.322488999999997	50.560934000000003	50.549619999999997	Пушкина	0103000020E61000000100000005000000490F43AB932743401F9DBAF259464940490F43AB93274340749B70AFCC474940ED28CE5147294340749B70AFCC474940ED28CE51472943401F9DBAF259464940490F43AB932743401F9DBAF259464940
33776	11426	38.420208000000002	38.449241999999998	50.503712	50.490228999999999	Мира	0103000020E6100000010000000500000040C23060C93543408046E9D2BF3E494040C23060C9354340274D83A279404940ACFE08C380394340274D83A279404940ACFE08C3803943408046E9D2BF3E494040C23060C93543408046E9D2BF3E4940
33337	12324	38.480494	38.516148000000001	50.708874000000002	50.678125000000001	Ленина	0103000020E610000001000000050000004DF6CFD3803D4340CDCCCCCCCC5649404DF6CFD3803D43400B7E1B62BC5A4940AAF23D23114243400B7E1B62BC5A4940AAF23D2311424340CDCCCCCCCC5649404DF6CFD3803D4340CDCCCCCCCC564940
33608	11156	38.350192999999997	38.435524000000001	50.641952000000003	50.615685999999997	имени Чапаева	0103000020E61000000100000005000000E124CD1FD32C4340724D81CCCE4E4940E124CD1FD32C434008CDAE7B2B524940C24F1C40BF37434008CDAE7B2B524940C24F1C40BF374340724D81CCCE4E4940E124CD1FD32C4340724D81CCCE4E4940
33576	11156	38.350192999999997	38.435524000000001	50.641952000000003	50.615685999999997	Пролетарская	0103000020E61000000100000005000000E124CD1FD32C4340724D81CCCE4E4940E124CD1FD32C434008CDAE7B2B524940C24F1C40BF37434008CDAE7B2B524940C24F1C40BF374340724D81CCCE4E4940E124CD1FD32C4340724D81CCCE4E4940
33661	11156	38.350192999999997	38.435524000000001	50.641952000000003	50.615685999999997	Ленина	0103000020E61000000100000005000000E124CD1FD32C4340724D81CCCE4E4940E124CD1FD32C434008CDAE7B2B524940C24F1C40BF37434008CDAE7B2B524940C24F1C40BF374340724D81CCCE4E4940E124CD1FD32C4340724D81CCCE4E4940
33507	11156	38.350192999999997	38.435524000000001	50.641952000000003	50.615685999999997	60 лет Октября	0103000020E61000000100000005000000E124CD1FD32C4340724D81CCCE4E4940E124CD1FD32C434008CDAE7B2B524940C24F1C40BF37434008CDAE7B2B524940C24F1C40BF374340724D81CCCE4E4940E124CD1FD32C4340724D81CCCE4E4940
33879	10692	38.218114	38.245260999999999	50.705874000000001	50.691969999999998	 Садовая	0103000020E610000001000000050000005E66D828EB1B434014E81379925849405E66D828EB1B4340618C48145A5A4940FCFD62B6641F4340618C48145A5A4940FCFD62B6641F434014E81379925849405E66D828EB1B434014E8137992584940
33789	54041	38.487555	38.502799000000003	50.588580999999998	50.576712999999998	Народная	0103000020E610000001000000050000002A00C633683E4340CA1649BBD14949402A00C633683E43400306499F564B494013BBB6B75B4043400306499F564B494013BBB6B75B404340CA1649BBD14949402A00C633683E4340CA1649BBD1494940
33704	11070	38.219884	38.267378000000001	50.629612000000002	50.620469	Трудовая	0103000020E61000000100000005000000F374AE28251C4340469737876B4F4940F374AE28251C4340A795422097504940BFD53A7139224340A795422097504940BFD53A7139224340469737876B4F4940F374AE28251C4340469737876B4F4940
33866	12162	38.228355000000001	38.270414000000002	50.586013000000001	50.577840000000002	Мира	0103000020E61000000100000005000000657094BC3A1D43400B293FA9F6494940657094BC3A1D4340F3035779024B4940B6300BED9C224340F3035779024B4940B6300BED9C2243400B293FA9F6494940657094BC3A1D43400B293FA9F6494940
33615	10807	38.115293000000001	38.184517	50.665976999999998	50.588867	Свободы	0103000020E61000000100000005000000973AC8EBC10E4340C9586DFE5F4B4940973AC8EBC10E4340B071FDBB3E5549402C47C8409E174340B071FDBB3E5549402C47C8409E174340C9586DFE5F4B4940973AC8EBC10E4340C9586DFE5F4B4940
33660	10807	38.115293000000001	38.184517	50.665976999999998	50.588867	Мира	0103000020E61000000100000005000000973AC8EBC10E4340C9586DFE5F4B4940973AC8EBC10E4340B071FDBB3E5549402C47C8409E174340B071FDBB3E5549402C47C8409E174340C9586DFE5F4B4940973AC8EBC10E4340C9586DFE5F4B4940
33726	10807	38.115293000000001	38.184517	50.665976999999998	50.588867	Куйбышева	0103000020E61000000100000005000000973AC8EBC10E4340C9586DFE5F4B4940973AC8EBC10E4340B071FDBB3E5549402C47C8409E174340B071FDBB3E5549402C47C8409E174340C9586DFE5F4B4940973AC8EBC10E4340C9586DFE5F4B4940
33573	10667	38.213093000000001	38.265284999999999	50.748313000000003	50.709456000000003	Центральная	0103000020E61000000100000005000000D600A5A1461B4340BAF94674CF5A4940D600A5A1461B4340F9156BB8C85F4940478FDFDBF4214340F9156BB8C85F4940478FDFDBF4214340BAF94674CF5A4940D600A5A1461B4340BAF94674CF5A4940
33530	10395	38.397041000000002	38.495199	50.806629999999998	50.759931999999999	Советская	0103000020E61000000100000005000000E8154F3DD23243408997A77345614940E8154F3DD23243407AFCDEA63F67494086014BAE623F43407AFCDEA63F67494086014BAE623F43408997A77345614940E8154F3DD23243408997A77345614940
33609	10284	38.240788000000002	38.275274000000003	50.422046999999999	50.365913999999997	Черняховского	0103000020E6100000010000000500000077A22424D21E434003931B45D62E494077A22424D21E4340FD2FD7A20536494035B8AD2D3C234340FD2FD7A20536494035B8AD2D3C23434003931B45D62E494077A22424D21E434003931B45D62E4940
33778	11616	38.368321000000002	38.404946000000002	50.522024000000002	50.500411999999997	Железнодорожная	0103000020E610000001000000050000000BB77C24252F434052431B800D4049400BB77C24252F434012DDB3AED1424940B1524145D533434012DDB3AED1424940B1524145D533434052431B800D4049400BB77C24252F434052431B800D404940
33587	54008	38.375624999999999	38.415663000000002	50.877108	50.846559999999997	Центральная	0103000020E61000000100000005000000AE47E17A14304340060DFD135C6C4940AE47E17A14304340AD872F13457049402194F77134354340AD872F13457049402194F77134354340060DFD135C6C4940AE47E17A14304340060DFD135C6C4940
33491	9918	38.410569000000002	38.435381	50.540564000000003	50.518256000000001	имени Ольминского	0103000020E610000001000000050000002FE065868D344340577A6D36564249402FE065868D3443408EB27E33314549405F268A90BA3743408EB27E33314549405F268A90BA374340577A6D36564249402FE065868D344340577A6D3656424940
33563	9918	38.410569000000002	38.435381	50.540564000000003	50.518256000000001	Ямская	0103000020E610000001000000050000002FE065868D344340577A6D36564249402FE065868D3443408EB27E33314549405F268A90BA3743408EB27E33314549405F268A90BA374340577A6D36564249402FE065868D344340577A6D3656424940
33282	9918	38.410569000000002	38.435381	50.540564000000003	50.518256000000001	Соборная площадь	0103000020E610000001000000050000002FE065868D344340577A6D36564249402FE065868D3443408EB27E33314549405F268A90BA3743408EB27E33314549405F268A90BA374340577A6D36564249402FE065868D344340577A6D3656424940
33862	9918	38.410569000000002	38.435381	50.540564000000003	50.518256000000001	Привокзальная	0103000020E610000001000000050000002FE065868D344340577A6D36564249402FE065868D3443408EB27E33314549405F268A90BA3743408EB27E33314549405F268A90BA374340577A6D36564249402FE065868D344340577A6D3656424940
33787	12059	38.390860000000004	38.436396000000002	50.411290999999999	50.385928999999997	Заречная	0103000020E6100000010000000500000044A852B307324340FBC9181F6631494044A852B307324340CF11F92EA5344940780DFAD2DB374340CF11F92EA5344940780DFAD2DB374340FBC9181F6631494044A852B307324340FBC9181F66314940
33216	8747	37.325485	37.387414999999997	50.869622	50.841078000000003	Центральная	0103000020E61000000100000005000000562B137EA9A942404BB1A371A86B4940562B137EA9A94240E9F010C64F6F49406B7D91D096B14240E9F010C64F6F49406B7D91D096B142404BB1A371A86B4940562B137EA9A942404BB1A371A86B4940
33773	8722	36.799799999999998	36.832391000000001	50.720753999999999	50.712387999999997	Административная	0103000020E610000001000000050000009FABADD85F6642400B08AD872F5B49409FABADD85F664240083BC5AA415C49400C3ECDC98B6A4240083BC5AA415C49400C3ECDC98B6A42400B08AD872F5B49409FABADD85F6642400B08AD872F5B4940
33586	8626	36.862323000000004	36.907912000000003	50.690047	50.671201000000003	Школьная	0103000020E6100000010000000500000058CB9D99606E4240710514EAE955494058CB9D99606E4240F9D9C87553584940AFD2DD7536744240F9D9C87553584940AFD2DD7536744240710514EAE955494058CB9D99606E4240710514EAE9554940
33784	7573	37.019654000000003	37.462091999999998	50.945127999999997	50.858024	Интернациональная	0103000020E61000000100000005000000289EB305848242407097FDBAD36D4940289EB3058482424056444DF4F978494022DFA5D425BB424056444DF4F978494022DFA5D425BB42407097FDBAD36D4940289EB305848242407097FDBAD36D4940
33799	8551	37.306333000000002	37.325620000000001	50.752541000000001	50.739317999999997	Центральная	0103000020E61000000100000005000000C15774EB35A742400CACE3F8A15E4940C15774EB35A7424017F3734353604940367689EAADA9424017F3734353604940367689EAADA942400CACE3F8A15E4940C15774EB35A742400CACE3F8A15E4940
33550	8541	37.235995000000003	37.281233999999998	50.731081000000003	50.710008999999999	Зеленая	0103000020E6100000010000000500000080828B15359E4240CE6E2D93E15A494080828B15359E42400EDDEC0F945D4940FA42C879FFA342400EDDEC0F945D4940FA42C879FFA34240CE6E2D93E15A494080828B15359E4240CE6E2D93E15A4940
33859	7295	37.154473000000003	37.188195999999998	50.766255999999998	50.74344	Центральная	0103000020E61000000100000005000000B98E71C5C5934240E544BB0A295F4940B98E71C5C5934240902E36AD14624940779E78CE16984240902E36AD14624940779E78CE16984240E544BB0A295F4940B98E71C5C5934240E544BB0A295F4940
33774	8012	37.072034000000002	37.086542000000001	50.845992000000003	50.833182000000001	Самойловская	0103000020E610000001000000050000009C19FD6838894240D5CE30B5A56A49409C19FD6838894240BD564277496C49407FDDE9CE138B4240BD564277496C49407FDDE9CE138B4240D5CE30B5A56A49409C19FD6838894240D5CE30B5A56A4940
33659	8448	37.087502999999998	37.112234000000001	50.771599999999999	50.752307999999999	Центральная	0103000020E61000000100000005000000A4A65D4C338B42407442E8A04B604940A4A65D4C338B4240FBCBEEC9C3624940E8BF07AF5D8E4240FBCBEEC9C3624940E8BF07AF5D8E42407442E8A04B604940A4A65D4C338B42407442E8A04B604940
33361	8334	37.184781999999998	37.222555999999997	50.884217	50.859439999999999	Бельгия	0103000020E61000000100000005000000DA71C3EFA6974240E76F4221026E4940DA71C3EFA69742409BC8CC052E714940A8C30AB77C9C42409BC8CC052E714940A8C30AB77C9C4240E76F4221026E4940DA71C3EFA6974240E76F4221026E4940
33360	8251	37.149549999999998	37.182608000000002	50.824807	50.797511	Шевченко	0103000020E61000000100000005000000F38E537424934240A29927D714664940F38E537424934240854199469369494076FEEDB25F974240854199469369494076FEEDB25F974240A29927D714664940F38E537424934240A29927D714664940
33215	8251	37.149549999999998	37.182608000000002	50.824807	50.797511	Центральная	0103000020E61000000100000005000000F38E537424934240A29927D714664940F38E537424934240854199469369494076FEEDB25F974240854199469369494076FEEDB25F974240A29927D714664940F38E537424934240A29927D714664940
33796	8165	37.195929999999997	37.233739999999997	50.919890000000002	50.900444	Центральная	0103000020E610000001000000050000001327F73B1499424091F0BDBF417349401327F73B149942406FF59CF4BE7549402EE23B31EB9D42406FF59CF4BE7549402EE23B31EB9D424091F0BDBF417349401327F73B1499424091F0BDBF41734940
33748	8090	36.991850999999997	37.020184	50.73856	50.713517000000003	Центральная	0103000020E61000000100000005000000A0C03BF9F47E4240ED116A86545B4940A0C03BF9F47E42401F115322895E494084F3A963958242401F115322895E494084F3A96395824240ED116A86545B4940A0C03BF9F47E4240ED116A86545B4940
33860	7792	36.995156999999999	37.016986000000003	50.934627999999996	50.916108000000001	Садовая	0103000020E6100000010000000500000057B1F84D617F42404FCDE5064375494057B1F84D617F424083F6EAE3A1774940B43EE5982C82424083F6EAE3A1774940B43EE5982C8242404FCDE5064375494057B1F84D617F42404FCDE50643754940
33572	7996	36.999037000000001	37.032868000000001	50.851252000000002	50.818137999999998	Сытник	0103000020E610000001000000050000003A3FC571E07F4240B3CEF8BEB86849403A3FC571E07F4240CA5356D3F56C4940DF8AC40435844240CA5356D3F56C4940DF8AC40435844240B3CEF8BEB86849403A3FC571E07F4240B3CEF8BEB8684940
33816	7263	37.113573000000002	37.156018000000003	50.708292999999998	50.682724999999998	Центральная	0103000020E61000000100000005000000B45A608F898E4240AF94658863574940B45A608F898E42402C7E5358A95A49402ECBD765F89342402C7E5358A95A49402ECBD765F8934240AF94658863574940B45A608F898E4240AF94658863574940
33571	7917	36.777602999999999	36.806716999999999	50.704464999999999	50.687570999999998	Центральная	0103000020E61000000100000005000000C022BF7E88634240C956975302584940C022BF7E886342409C16BCE82B5A49404910AE80426742409C16BCE82B5A49404910AE8042674240C956975302584940C022BF7E88634240C956975302584940
33811	7171	37.413052999999998	37.430399000000001	50.796183999999997	50.778371999999997	Центральная	0103000020E61000000100000005000000E141B3EBDEB44240A10F96B1A1634940E141B3EBDEB442409ACC785BE9654940959D7E5017B742409ACC785BE9654940959D7E5017B74240A10F96B1A1634940E141B3EBDEB44240A10F96B1A1634940
33819	8655	36.862654999999997	37.031340999999998	50.799754	50.707985000000001	Лисовенька	0103000020E610000001000000050000008D5DA27A6B6E42407F87A2409F5A49408D5DA27A6B6E42402F6CCD565E66494010035DFB028442402F6CCD565E66494010035DFB028442407F87A2409F5A49408D5DA27A6B6E42407F87A2409F5A4940
33487	7839	36.918953000000002	36.951822	50.762991999999997	50.743473999999999	Мозгового	0103000020E61000000100000005000000D2C77C40A075424091B6F1272A5F4940D2C77C40A0754240088ECBB8A961494081CEA44DD5794240088ECBB8A961494081CEA44DD579424091B6F1272A5F4940D2C77C40A075424091B6F1272A5F4940
33663	7721	37.100403	37.127856000000001	50.906595000000003	50.881506000000002	Центральная	0103000020E61000000100000005000000CCB56801DA8C4240289D4830D5704940CCB56801DA8C4240CBDB114E0B744940774CDD955D904240CBDB114E0B744940774CDD955D904240289D4830D5704940CCB56801DA8C4240289D4830D5704940
33584	6804	37.175753999999998	37.208480000000002	50.822434999999999	50.801177000000003	площадь Васильева	0103000020E610000001000000050000001212691B7F96424059A7CAF78C6649401212691B7F964240FA0AD28C456949405FEFFE78AF9A4240FA0AD28C456949405FEFFE78AF9A424059A7CAF78C6649401212691B7F96424059A7CAF78C664940
33265	6804	37.175753999999998	37.208480000000002	50.822434999999999	50.801177000000003	Советская	0103000020E610000001000000050000001212691B7F96424059A7CAF78C6649401212691B7F964240FA0AD28C456949405FEFFE78AF9A4240FA0AD28C456949405FEFFE78AF9A424059A7CAF78C6649401212691B7F96424059A7CAF78C664940
33264	6804	37.175753999999998	37.208480000000002	50.822434999999999	50.801177000000003	Пролетарская	0103000020E610000001000000050000001212691B7F96424059A7CAF78C6649401212691B7F964240FA0AD28C456949405FEFFE78AF9A4240FA0AD28C456949405FEFFE78AF9A424059A7CAF78C6649401212691B7F96424059A7CAF78C664940
33632	7712	37.24973	37.304878000000002	50.921081999999998	50.868729000000002	Центральная	0103000020E61000000100000005000000406A1327F79F42401C0B0A83326F4940406A1327F79F42409677D503E67549408CA2073E06A742409677D503E67549408CA2073E06A742401C0B0A83326F4940406A1327F79F42401C0B0A83326F4940
33747	7448	37.277560000000001	37.297924999999999	50.792222000000002	50.783406999999997	Кожанова	0103000020E61000000100000005000000C156091687A342408E3A3AAE46644940C156091687A34240FB95CE876765494095D4096822A64240FB95CE876765494095D4096822A642408E3A3AAE46644940C156091687A342408E3A3AAE46644940
33817	8471	37.184305999999999	37.248778000000001	50.709085000000002	50.690669	Центральная	0103000020E61000000100000005000000713AC9569797424036AE7FD767584940713AC95697974240C68A1A4CC35A49406EFB1EF5D79F4240C68A1A4CC35A49406EFB1EF5D79F424036AE7FD767584940713AC9569797424036AE7FD767584940
33585	7643	36.962223999999999	36.997950000000003	50.787393000000002	50.757978000000001	Выгон	0103000020E6100000010000000500000091B6F1272A7B4240338B506C0561494091B6F1272A7B4240B70C384BC964494088855AD3BC7F4240B70C384BC964494088855AD3BC7F4240338B506C0561494091B6F1272A7B4240338B506C05614940
33529	7623	37.362172000000001	37.395293000000002	50.721426999999998	50.706108	Базарная	0103000020E6100000010000000500000072C3EFA65BAE4240D4B837BF615A494072C3EFA65BAE4240C7B94DB8575C49403BAB05F698B24240C7B94DB8575C49403BAB05F698B24240D4B837BF615A494072C3EFA65BAE4240D4B837BF615A4940
33612	54010	36.725490999999998	36.754964999999999	50.699770000000001	50.674791999999997	Центральная	0103000020E610000001000000050000006B459BE3DC5C42401CCD91955F5649406B459BE3DC5C4240685C381092594940F44F70B1A2604240685C381092594940F44F70B1A26042401CCD91955F5649406B459BE3DC5C42401CCD91955F564940
33869	8395	37.052765999999998	37.078206000000002	50.757852	50.742721000000003	Вершина	0103000020E610000001000000050000009D2B4A09C1864240B686527B115F49409D2B4A09C1864240A69A594B01614940ED2C7AA7028A4240A69A594B01614940ED2C7AA7028A4240B686527B115F49409D2B4A09C1864240B686527B115F4940
33858	7550	37.505256000000003	37.540174	50.855164000000002	50.835025000000002	Маркашовой А.И	0103000020E61000000100000005000000CC0D863AACC04240D42B6519E26A4940CC0D863AACC04240B85B9203766D49402313F06B24C54240B85B9203766D49402313F06B24C54240D42B6519E26A4940CC0D863AACC04240D42B6519E26A4940
33705	8806	37.332949999999997	37.370652	50.921190000000003	50.910594000000003	 Песчаная	0103000020E61000000100000005000000029A081B9EAA424088F71C588E744940029A081B9EAA42407DB3CD8DE97549403719558671AF42407DB3CD8DE97549403719558671AF424088F71C588E744940029A081B9EAA424088F71C588E744940
33528	7463	37.393470000000001	37.454070000000002	50.940337999999997	50.910150999999999	Базарная	0103000020E6100000010000000500000083FA96395DB24240FAB5F5D37F74494083FA96395DB24240D097DEFE5C784940200C3CF71EBA4240D097DEFE5C784940200C3CF71EBA4240FAB5F5D37F74494083FA96395DB24240FAB5F5D37F744940
33447	7358	37.195076999999998	37.239722999999998	50.823008999999999	50.782308	Ленина	0103000020E61000000100000005000000D4997B48F898424018B325AB22644940D4997B48F898424026A8E15B58694940AC8C463EAF9E424026A8E15B58694940AC8C463EAF9E424018B325AB22644940D4997B48F898424018B325AB22644940
33881	8155	37.249524000000001	37.279086999999997	50.950916999999997	50.930591999999997	Выгон	0103000020E6100000010000000500000097C80567F09F4240A9F57EA31D77494097C80567F09F4240EF1AF4A5B77949408FDE701FB9A34240EF1AF4A5B77949408FDE701FB9A34240A9F57EA31D77494097C80567F09F4240A9F57EA31D774940
33607	7181	37.141573000000001	37.171595000000003	50.739255999999997	50.720395000000003	Центральная	0103000020E61000000100000005000000917F66101F924240D99942E7355C4940917F66101F92424096AFCBF09F5E49401D9430D3F695424096AFCBF09F5E49401D9430D3F6954240D99942E7355C4940917F66101F924240D99942E7355C4940
33657	7082	37.424165000000002	37.4925	50.780541999999997	50.765993999999999	Центральная	0103000020E61000000100000005000000CE8DE9094BB64240537765170C624940CE8DE9094BB64240C493DDCCE8634940D7A3703D0ABF4240C493DDCCE8634940D7A3703D0ABF4240537765170C624940CE8DE9094BB64240537765170C624940
33815	6995	37.026255999999997	37.061255000000003	50.787177	50.745280999999999	Мирошникова	0103000020E6100000010000000500000071A94A5B5C83424043AA285E655F494071A94A5B5C834240EA944737C2644940B6DB2E34D7874240EA944737C2644940B6DB2E34D787424043AA285E655F494071A94A5B5C83424043AA285E655F4940
33359	6995	37.026255999999997	37.061255000000003	50.787177	50.745280999999999	Богомазова	0103000020E6100000010000000500000071A94A5B5C83424043AA285E655F494071A94A5B5C834240EA944737C2644940B6DB2E34D7874240EA944737C2644940B6DB2E34D787424043AA285E655F494071A94A5B5C83424043AA285E655F4940
33457	5946	36.119056999999998	36.169739999999997	51.096727999999999	51.039647000000002	Советская	0103000020E6100000010000000500000010AE80423D0F4240383124271385494010AE80423D0F4240C24D4695618C49405969520ABA154240C24D4695618C49405969520ABA154240383124271385494010AE80423D0F42403831242713854940
33318	5946	36.119056999999998	36.169739999999997	51.096727999999999	51.039647000000002	Садовая	0103000020E6100000010000000500000010AE80423D0F4240383124271385494010AE80423D0F4240C24D4695618C49405969520ABA154240C24D4695618C49405969520ABA154240383124271385494010AE80423D0F42403831242713854940
33485	5946	36.119056999999998	36.169739999999997	51.096727999999999	51.039647000000002	Ленина	0103000020E6100000010000000500000010AE80423D0F4240383124271385494010AE80423D0F4240C24D4695618C49405969520ABA154240C24D4695618C49405969520ABA154240383124271385494010AE80423D0F42403831242713854940
33390	5946	36.119056999999998	36.169739999999997	51.096727999999999	51.039647000000002	Заречная	0103000020E6100000010000000500000010AE80423D0F4240383124271385494010AE80423D0F4240C24D4695618C49405969520ABA154240C24D4695618C49405969520ABA154240383124271385494010AE80423D0F42403831242713854940
33855	47613	37.345913000000003	37.376842000000003	51.207332000000001	51.186663000000003	Троицкая	0103000020E6100000010000000500000071218FE046AC4240C72FBC92E497494071218FE046AC424007B5DFDA899A49402FE1D05B3CB0424007B5DFDA899A49402FE1D05B3CB04240C72FBC92E497494071218FE046AC4240C72FBC92E4974940
33732	47970	37.33428	37.354104999999997	51.062657999999999	51.049908000000002	Мира	0103000020E610000001000000050000007BDAE1AFC9AA424086E7A562638649407BDAE1AFC9AA4240986A662D05884940CF2C095053AD4240986A662D05884940CF2C095053AD424086E7A562638649407BDAE1AFC9AA424086E7A56263864940
33621	4811	37.093567	37.123167000000002	51.148890999999999	51.124533	Центральная	0103000020E610000001000000050000000F7EE200FA8B4240EA2285B2F08F49400F7EE200FA8B424099D53BDC0E9349402579AEEFC38F424099D53BDC0E9349402579AEEFC38F4240EA2285B2F08F49400F7EE200FA8B4240EA2285B2F08F4940
33722	3768	37.249865	37.271604000000004	51.248376	51.226993	Садовая	0103000020E6100000010000000500000020B58993FB9F4240E1B54B1B0E9D494020B58993FB9F42403F8EE6C8CA9F49403DBB7CEBC3A242403F8EE6C8CA9F49403DBB7CEBC3A24240E1B54B1B0E9D494020B58993FB9F4240E1B54B1B0E9D4940
33694	47520	37.693956	37.726959999999998	51.130020999999999	51.112026	Заречная	0103000020E61000000100000005000000766EDA8CD3D842409E2633DE568E4940766EDA8CD3D8424088653387A490494005C078060DDD424088653387A490494005C078060DDD42409E2633DE568E4940766EDA8CD3D842409E2633DE568E4940
33742	4781	37.053052999999998	37.087135000000004	51.230043999999999	51.203257000000001	Центральная	0103000020E6100000010000000500000033FAD170CA8642406FD74B53049A494033FAD170CA8642400D52F014729D494022AB5B3D278B42400D52F014729D494022AB5B3D278B42406FD74B53049A494033FAD170CA8642406FD74B53049A4940
33471	47086	37.488323000000001	37.532950999999997	51.368636000000002	51.349226999999999	Центральная	0103000020E610000001000000050000003B71395E81BE4240AAF06778B3AC49403B71395E81BE42406B10E6762FAF49406CAF05BD37C442406B10E6762FAF49406CAF05BD37C44240AAF06778B3AC49403B71395E81BE4240AAF06778B3AC4940
33618	47855	37.237217000000001	37.272547000000003	51.013406000000003	50.984864999999999	Центральная	0103000020E6100000010000000500000012876C205D9E4240CEFC6A0E107E494012876C205D9E4240FCC8AD49B7814940BCCFF1D1E2A24240FCC8AD49B7814940BCCFF1D1E2A24240CEFC6A0E107E494012876C205D9E4240CEFC6A0E107E4940
33633	3291	37.477111999999998	37.540784000000002	51.328977000000002	51.300226000000002	Центральная	0103000020E61000000100000005000000BB438A0112BD424057B439CE6DA64940BB438A0112BD42406F1118EB1BAA49409C19FD6838C542406F1118EB1BAA49409C19FD6838C5424057B439CE6DA64940BB438A0112BD424057B439CE6DA64940
33771	47819	37.260303	37.282043000000002	51.053905	51.035772999999999	Григория Найдина	0103000020E610000001000000050000007D06D49B51A14240378AAC35948449407D06D49B51A14240A20BEA5BE68649406A882AFC19A44240A20BEA5BE68649406A882AFC19A44240378AAC35948449407D06D49B51A14240378AAC3594844940
33693	47308	37.236417000000003	37.266618999999999	51.329945000000002	51.304972999999997	Ракитная	0103000020E61000000100000005000000F69B89E9429E4240DD94F25A09A74940F69B89E9429E4240473D44A33BAA494001BF469220A24240473D44A33BAA494001BF469220A24240DD94F25A09A74940F69B89E9429E4240DD94F25A09A74940
33698	47967	37.345427999999998	37.361094000000001	51.011989	51.004435000000001	Народная	0103000020E61000000100000005000000B48F15FC36AC424098FA795391804940B48F15FC36AC4240B47405DB888149401364045438AE4240B47405DB888149401364045438AE424098FA795391804940B48F15FC36AC424098FA795391804940
33738	47593	37.246344000000001	37.273257000000001	51.198562000000003	51.190320999999997	Медовая	0103000020E610000001000000050000006DC83F33889F4240FA5E43705C9849406DC83F33889F42403B1DC87A6A9949409833DB15FAA242403B1DC87A6A9949409833DB15FAA24240FA5E43705C9849406DC83F33889F4240FA5E43705C984940
33603	47773	37.205146999999997	37.255363000000003	51.095205999999997	51.054420999999998	Красноармейская	0103000020E61000000100000005000000AEEFC341429A4240999B6F44F7864940AEEFC341429A42400531D0B52F8C4940E2CD1ABCAFA042400531D0B52F8C4940E2CD1ABCAFA04240999B6F44F7864940AEEFC341429A4240999B6F44F7864940
33395	47773	37.205146999999997	37.255363000000003	51.095205999999997	51.054420999999998	1 Мая	0103000020E61000000100000005000000AEEFC341429A4240999B6F44F7864940AEEFC341429A42400531D0B52F8C4940E2CD1ABCAFA042400531D0B52F8C4940E2CD1ABCAFA04240999B6F44F7864940AEEFC341429A4240999B6F44F7864940
33643	47512	37.619522000000003	37.655230000000003	51.134605000000001	51.122045	Центральная	0103000020E610000001000000050000008693347F4CCF4240F6D1A92B9F8F49408693347F4CCF4240657094BC3A914940D6AD9E93DED34240657094BC3A914940D6AD9E93DED34240F6D1A92B9F8F49408693347F4CCF4240F6D1A92B9F8F4940
33854	4003	37.392985000000003	37.417464000000002	51.175443999999999	51.161715000000001	Светлая	0103000020E61000000100000005000000C7681D554DB24240E622BE13B3944940C7681D554DB24240C423F1F274964940F1A0D9756FB54240C423F1F274964940F1A0D9756FB54240E622BE13B3944940C7681D554DB24240E622BE13B3944940
33730	3905	37.344152000000001	37.369925000000002	51.295985999999999	51.283588000000002	Юбилейная	0103000020E610000001000000050000002F6D382C0DAC4240DFC4909C4CA449402F6D382C0DAC4240740987DEE2A54940857CD0B359AF4240740987DEE2A54940857CD0B359AF4240DFC4909C4CA449402F6D382C0DAC4240DFC4909C4CA44940
33736	3452	37.373958000000002	37.420059999999999	51.288302999999999	51.265642	Центральная	0103000020E61000000100000005000000EE0912DBDDAF4240D6389B8E00A24940EE0912DBDDAF42405A2BDA1CE7A44940CB2DAD86C4B542405A2BDA1CE7A44940CB2DAD86C4B54240D6389B8E00A24940EE0912DBDDAF4240D6389B8E00A24940
33648	47652	37.144969000000003	37.182400999999999	51.206592000000001	51.192256999999998	Владимира Уколова	0103000020E6100000010000000500000088F71C588E924240AAB69BE09B98494088F71C588E924240C0CE4D9B719A4940FCE07CEA58974240C0CE4D9B719A4940FCE07CEA58974240AAB69BE09B98494088F71C588E924240AAB69BE09B984940
33849	47686	37.195059000000001	37.222143000000003	51.182327000000001	51.158302999999997	Сиреневая	0103000020E610000001000000050000002EE57CB1F7984240E9EDCF45439449402EE57CB1F7984240C216BB7D5697494086048C2E6F9C4240C216BB7D5697494086048C2E6F9C4240E9EDCF45439449402EE57CB1F7984240E9EDCF4543944940
33877	4567	37.371946000000001	37.434415000000001	51.137430999999999	51.112110999999999	Школьная	0103000020E6100000010000000500000063F030ED9BAF4240CC423BA7598E494063F030ED9BAF4240713AC9569791494028F224E99AB74240713AC9569791494028F224E99AB74240CC423BA7598E494063F030ED9BAF4240CC423BA7598E4940
33772	5196	37.286327999999997	37.309801	51.035789999999999	50.996243999999997	Троицкая	0103000020E61000000100000005000000ECF65965A6A44240096B63EC847F4940ECF65965A6A442400DC347C49484494051A2258FA7A742400DC347C49484494051A2258FA7A74240096B63EC847F4940ECF65965A6A44240096B63EC847F4940
33650	47944	37.433418000000003	37.518650000000001	51.052348000000002	51.033830000000002	Тихая	0103000020E61000000100000005000000B6BFB33D7AB74240D5CF9B8A54844940B6BFB33D7AB742406901DA56B386494003098A1F63C242406901DA56B386494003098A1F63C24240D5CF9B8A54844940B6BFB33D7AB74240D5CF9B8A54844940
33692	4366	37.325170999999997	37.363241000000002	51.236423000000002	51.219096	Народная	0103000020E61000000100000005000000C64D0D349FA942409B5775560B9C4940C64D0D349FA94240D882DE1B439E49407EC85BAE7EAE4240D882DE1B439E49407EC85BAE7EAE42409B5775560B9C4940C64D0D349FA942409B5775560B9C4940
33882	54067	37.215252999999997	37.236417000000003	51.146206999999997	51.130744999999997	Мира	0103000020E61000000100000005000000D5AE09698D9B4240C98E8D40BC904940D5AE09698D9B42401FB935E9B6924940F69B89E9429E42401FB935E9B6924940F69B89E9429E4240C98E8D40BC904940D5AE09698D9B4240C98E8D40BC904940
33735	3175	37.599533999999998	37.618766999999998	51.358530000000002	51.344518000000001	Школьная	0103000020E61000000100000005000000876BB587BDCC42401171732A19AC4940876BB587BDCC42404451A04FE4AD4940096CCEC133CF42404451A04FE4AD4940096CCEC133CF42401171732A19AC4940876BB587BDCC42401171732A19AC4940
33549	5346	37.309027999999998	37.345238999999999	51.144297000000002	51.098159000000003	Центральная	0103000020E610000001000000050000002EC6C03A8EA742406F675F79908C49402EC6C03A8EA7424099F4F75278924940E126A3CA30AC424099F4F75278924940E126A3CA30AC42406F675F79908C49402EC6C03A8EA742406F675F79908C4940
33769	5346	37.309027999999998	37.345238999999999	51.144297000000002	51.098159000000003	Солнечная	0103000020E610000001000000050000002EC6C03A8EA742406F675F79908C49402EC6C03A8EA7424099F4F75278924940E126A3CA30AC424099F4F75278924940E126A3CA30AC42406F675F79908C49402EC6C03A8EA742406F675F79908C4940
33775	47424	37.572763999999999	37.594036000000003	51.215834999999998	51.200265999999999	Центральная	0103000020E61000000100000005000000BF29AC5450C942401840F850A2994940BF29AC5450C94240842A357BA09B4940C652245F09CC4240842A357BA09B4940C652245F09CC42401840F850A2994940BF29AC5450C942401840F850A2994940
33856	47397	37.312693000000003	37.344206	51.275649999999999	51.263905999999999	Урожайная	0103000020E610000001000000050000001558005306A84240ED9BFBABC7A149401558005306A842403A92CB7F48A34940228B34F10EAC42403A92CB7F48A34940228B34F10EAC4240ED9BFBABC7A149401558005306A84240ED9BFBABC7A14940
33814	47287	37.151778	37.248742	51.344963	51.316391000000003	Железнодорожная	0103000020E610000001000000050000004B2025766D934240D7DF12807FA849404B2025766D9342403FAA61BF27AC4940219221C7D69F42403FAA61BF27AC4940219221C7D69F4240D7DF12807FA849404B2025766D934240D7DF12807FA84940
33759	47290	37.257510000000003	37.294673000000003	51.303013999999997	51.261184	Каштановая	0103000020E610000001000000050000004D327216F6A04240861E317A6EA149404D327216F6A04240751DAA29C9A64940D20149D8B7A54240751DAA29C9A64940D20149D8B7A54240861E317A6EA149404D327216F6A04240861E317A6EA14940
33741	47561	37.332303000000003	37.360906	51.165657000000003	51.154862000000001	Центральная	0103000020E610000001000000050000006DAE9AE788AA424053B29C84D29349406DAE9AE788AA42403FADA23F349549401077F52A32AE42403FADA23F349549401077F52A32AE424053B29C84D29349406DAE9AE788AA424053B29C84D2934940
33606	4257	37.365369999999999	37.401967999999997	51.195869999999999	51.181887000000003	Белгородская	0103000020E610000001000000050000004278B471C4AE4240A648BE12489749404278B471C4AE42403E22A64412994940EE04FBAF73B342403E22A64412994940EE04FBAF73B34240A648BE12489749404278B471C4AE4240A648BE1248974940
33872	47264	37.145004999999998	37.185338999999999	51.295940000000002	51.241064000000001	Мичурина	0103000020E61000000100000005000000D4601A868F924240191F662FDB9E4940D4601A868F92424004CAA65CE1A5494030D63730B997424004CAA65CE1A5494030D63730B9974240191F662FDB9E4940D4601A868F924240191F662FDB9E4940
33625	47166	37.430973999999999	37.452767000000001	51.298085999999998	51.280794	Центральная	0103000020E6100000010000000500000091B6F1272AB74240DE74CB0EF1A3494091B6F1272AB742409EB29AAE27A64940A1DAE044F4B942409EB29AAE27A64940A1DAE044F4B94240DE74CB0EF1A3494091B6F1272AB74240DE74CB0EF1A34940
33685	54009	37.581181999999998	37.618766999999998	51.309010000000001	51.286726000000002	Павлика Морозова	0103000020E610000001000000050000000E83F92B64CA4240DA740470B3A449400E83F92B64CA42408811C2A38DA74940096CCEC133CF42408811C2A38DA74940096CCEC133CF4240DA740470B3A449400E83F92B64CA4240DA740470B3A44940
33767	47186	37.476582000000001	37.525844999999997	51.266544000000003	51.256189999999997	Заречная 	0103000020E610000001000000050000005FEE93A300BD4240F7C77BD5CAA049405FEE93A300BD4240F778211D1EA24940EFE192E34EC34240F778211D1EA24940EFE192E34EC34240F7C77BD5CAA049405FEE93A300BD4240F7C77BD5CAA04940
33212	49527	37.815049000000002	37.847639999999998	50.440792999999999	50.411911000000003	проспект Маресевой	0103000020E610000001000000050000009AD18F8653E842406CEEE87FB93449409AD18F8653E8424022A7AFE76B3849400664AF777FEC424022A7AFE76B3849400664AF777FEC42406CEEE87FB93449409AD18F8653E842406CEEE87FB9344940
33229	29645	37.790461999999998	37.876241999999998	50.506720000000001	50.462179999999996	Чехова	0103000020E61000000100000005000000895DDBDB2DE54240C16ED8B6283B4940895DDBDB2DE54240541D7233DC404940D9B0A6B228F04240541D7233DC404940D9B0A6B228F04240C16ED8B6283B4940895DDBDB2DE54240C16ED8B6283B4940
33217	29645	37.790461999999998	37.876241999999998	50.506720000000001	50.462179999999996	Пионерская	0103000020E61000000100000005000000895DDBDB2DE54240C16ED8B6283B4940895DDBDB2DE54240541D7233DC404940D9B0A6B228F04240541D7233DC404940D9B0A6B228F04240C16ED8B6283B4940895DDBDB2DE54240C16ED8B6283B4940
33398	29645	37.790461999999998	37.876241999999998	50.506720000000001	50.462179999999996	Ленина	0103000020E61000000100000005000000895DDBDB2DE54240C16ED8B6283B4940895DDBDB2DE54240541D7233DC404940D9B0A6B228F04240541D7233DC404940D9B0A6B228F04240C16ED8B6283B4940895DDBDB2DE54240C16ED8B6283B4940
33222	29645	37.790461999999998	37.876241999999998	50.506720000000001	50.462179999999996	Гагарина	0103000020E61000000100000005000000895DDBDB2DE54240C16ED8B6283B4940895DDBDB2DE54240541D7233DC404940D9B0A6B228F04240541D7233DC404940D9B0A6B228F04240C16ED8B6283B4940895DDBDB2DE54240C16ED8B6283B4940
33393	29645	37.790461999999998	37.876241999999998	50.506720000000001	50.462179999999996	60 лет Октября	0103000020E61000000100000005000000895DDBDB2DE54240C16ED8B6283B4940895DDBDB2DE54240541D7233DC404940D9B0A6B228F04240541D7233DC404940D9B0A6B228F04240C16ED8B6283B4940895DDBDB2DE54240C16ED8B6283B4940
33670	46891	37.890211000000001	37.901144000000002	50.355415000000001	50.344282	Школьная	0103000020E610000001000000050000000DC51D6FF2F14240FD4CBD6E112C49400DC51D6FF2F1424001C11C3D7E2D49404A7EC4AF58F3424001C11C3D7E2D49404A7EC4AF58F34240FD4CBD6E112C49400DC51D6FF2F14240FD4CBD6E112C4940
33654	28182	38.372427000000002	38.489342000000001	50.170938999999997	50.124136	Центральная	0103000020E61000000100000005000000DE921CB0AB2F4340CD203EB0E30F4940DE921CB0AB2F4340334E4354E1154940954737C2A23E4340334E4354E1154940954737C2A23E4340CD203EB0E30F4940DE921CB0AB2F4340CD203EB0E30F4940
33583	28182	38.372427000000002	38.489342000000001	50.170938999999997	50.124136	Пролетарская	0103000020E61000000100000005000000DE921CB0AB2F4340CD203EB0E30F4940DE921CB0AB2F4340334E4354E1154940954737C2A23E4340334E4354E1154940954737C2A23E4340CD203EB0E30F4940DE921CB0AB2F4340CD203EB0E30F4940
33783	28182	38.372427000000002	38.489342000000001	50.170938999999997	50.124136	Октябрьская	0103000020E61000000100000005000000DE921CB0AB2F4340CD203EB0E30F4940DE921CB0AB2F4340334E4354E1154940954737C2A23E4340334E4354E1154940954737C2A23E4340CD203EB0E30F4940DE921CB0AB2F4340CD203EB0E30F4940
33620	28182	38.372427000000002	38.489342000000001	50.170938999999997	50.124136	Мира	0103000020E61000000100000005000000DE921CB0AB2F4340CD203EB0E30F4940DE921CB0AB2F4340334E4354E1154940954737C2A23E4340334E4354E1154940954737C2A23E4340CD203EB0E30F4940DE921CB0AB2F4340CD203EB0E30F4940
33655	28182	38.372427000000002	38.489342000000001	50.170938999999997	50.124136	Комсомольская	0103000020E61000000100000005000000DE921CB0AB2F4340CD203EB0E30F4940DE921CB0AB2F4340334E4354E1154940954737C2A23E4340334E4354E1154940954737C2A23E4340CD203EB0E30F4940DE921CB0AB2F4340CD203EB0E30F4940
33483	28182	38.372427000000002	38.489342000000001	50.170938999999997	50.124136	Гайдара	0103000020E61000000100000005000000DE921CB0AB2F4340CD203EB0E30F4940DE921CB0AB2F4340334E4354E1154940954737C2A23E4340334E4354E1154940954737C2A23E4340CD203EB0E30F4940DE921CB0AB2F4340CD203EB0E30F4940
33681	53979	38.024455000000003	38.060845999999998	50.104646000000002	50.065266999999999	Рабочая	0103000020E61000000100000005000000A29C685721034340074147AB5A084940A29C68572103434020D4450A650D4940D40B3ECDC907434020D4450A650D4940D40B3ECDC9074340074147AB5A084940A29C685721034340074147AB5A084940
33444	53979	38.024455000000003	38.060845999999998	50.104646000000002	50.065266999999999	Ленина	0103000020E61000000100000005000000A29C685721034340074147AB5A084940A29C68572103434020D4450A650D4940D40B3ECDC907434020D4450A650D4940D40B3ECDC9074340074147AB5A084940A29C685721034340074147AB5A084940
33301	53979	38.024455000000003	38.060845999999998	50.104646000000002	50.065266999999999	Калинина	0103000020E61000000100000005000000A29C685721034340074147AB5A084940A29C68572103434020D4450A650D4940D40B3ECDC907434020D4450A650D4940D40B3ECDC9074340074147AB5A084940A29C685721034340074147AB5A084940
33520	53979	38.024455000000003	38.060845999999998	50.104646000000002	50.065266999999999	2-я Пролетарская	0103000020E61000000100000005000000A29C685721034340074147AB5A084940A29C68572103434020D4450A650D4940D40B3ECDC907434020D4450A650D4940D40B3ECDC9074340074147AB5A084940A29C685721034340074147AB5A084940
9772	40306	37.896616000000002	37.913378999999999	50.069302999999998	50.061594999999997	Центральная	0103000020E6100000010000000500000001892650C4F242406E4C4F58E207494001892650C4F24240E141B3EBDE08494035ED629AE9F44240E141B3EBDE08494035ED629AE9F442406E4C4F58E207494001892650C4F242406E4C4F58E2074940
74898	47361	37.895412	37.920844000000002	50.100261000000003	50.079779000000002	Центральная	0103000020E61000000100000005000000153944DC9CF242402CF4C132360A4940153944DC9CF242403A083A5AD50C4940E25B5837DEF542403A083A5AD50C4940E25B5837DEF542402CF4C132360A4940153944DC9CF242402CF4C132360A4940
33442	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Фурманова	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33385	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Суржикова	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33350	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Ст. Разина	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33484	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Соколова	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33414	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Свердлова	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33782	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Речная	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33353	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Привокзальная площадь	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33232	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Никольская 	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33211	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Никольская	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33492	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Курячего	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33355	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Котовского	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33312	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Комсомольская	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33209	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	Горького	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33259	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	9 Января	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33357	24814	38.06832	38.161619000000002	50.232202000000001	50.148369000000002	1 Мая	0103000020E61000000100000005000000D4D4B2B5BE084340C05E61C1FD124940D4D4B2B5BE0843406C088ECBB81D4940C4B46FEEAF1443406C088ECBB81D4940C4B46FEEAF144340C05E61C1FD124940D4D4B2B5BE084340C05E61C1FD124940
33510	9972	37.709704000000002	37.731003000000001	50.261285999999998	50.250683000000002	Красная	0103000020E6100000010000000500000092EBA694D7DA4240E3546B611620494092EBA694D7DA42408A73D4D17121494092239D8191DD42408A73D4D17121494092239D8191DD4240E3546B611620494092EBA694D7DA4240E3546B6116204940
33689	24411	35.989618	36.028426000000003	50.690407	50.675414000000004	Мирная	0103000020E6100000010000000500000037C478CDABFE41405AA148F77356494037C478CDABFE4140F9F6AE415F584940952D9276A3034240F9F6AE415F584940952D9276A30342405AA148F77356494037C478CDABFE41405AA148F773564940
33384	24730	35.838180000000001	35.918418000000003	50.610118	50.571055000000001	Данкова	0103000020E61000000100000005000000A514747B49EB4140D09B8A5418494940A514747B49EB4140B859BC58184E4940640795B88EF54140B859BC58184E4940640795B88EF54140D09B8A5418494940A514747B49EB4140D09B8A5418494940
33527	24595	36.067169999999997	36.124420000000001	50.636851	50.611519000000001	Набережная	0103000020E61000000100000005000000DBA2CC0699084240FAF02C41464E4940DBA2CC069908424063B6645584514940F27B9BFEEC0F424063B6645584514940F27B9BFEEC0F4240FAF02C41464E4940DBA2CC0699084240FAF02C41464E4940
33488	24595	36.067169999999997	36.124420000000001	50.636851	50.611519000000001	Комсомольская	0103000020E61000000100000005000000DBA2CC0699084240FAF02C41464E4940DBA2CC069908424063B6645584514940F27B9BFEEC0F424063B6645584514940F27B9BFEEC0F4240FAF02C41464E4940DBA2CC0699084240FAF02C41464E4940
33687	24489	35.887202000000002	35.909309	50.673616000000003	50.643636999999998	Советская	0103000020E610000001000000050000001079CBD58FF141406EBF7CB2625249401079CBD58FF14140FB07910C39564940AF7AC03C64F44140FB07910C39564940AF7AC03C64F441406EBF7CB2625249401079CBD58FF141406EBF7CB262524940
33798	54044	36.089188	36.110954	50.556659000000003	50.549711000000002	Новоалександровская	0103000020E610000001000000050000000B992B836A0B424030A017EE5C4649400B992B836A0B42401503249A4047494021AE9CBD330E42401503249A4047494021AE9CBD330E424030A017EE5C4649400B992B836A0B424030A017EE5C464940
33691	23551	35.770439000000003	35.804907	50.650308000000003	50.631920000000001	Подлесовка	0103000020E610000001000000050000000F48C2BE9DE241401BD82AC1E25049400F48C2BE9DE24140E129E44A3D53494026A94C3107E74140E129E44A3D53494026A94C3107E741401BD82AC1E25049400F48C2BE9DE241401BD82AC1E2504940
33526	24330	35.968040999999999	36.014403000000001	50.686776999999999	50.653244000000001	Ленина	0103000020E61000000100000005000000F4177AC4E8FB41407427D87F9D534940F4177AC4E8FB41408F52094FE85749406EFB1EF5D70142408F52094FE85749406EFB1EF5D70142407427D87F9D534940F4177AC4E8FB41407427D87F9D534940
33765	24561	35.892789	35.955832999999998	50.647390000000001	50.619469000000002	Середенко	0103000020E61000000100000005000000419DF2E846F2414063F19BC24A4F4940419DF2E846F24140F4E0EEACDD52494002B859BC58FA4140F4E0EEACDD52494002B859BC58FA414063F19BC24A4F4940419DF2E846F2414063F19BC24A4F4940
33852	24452	36.023251000000002	36.059265000000003	50.714190000000002	50.682771000000002	Центральная	0103000020E61000000100000005000000B64C86E3F902424020D4450A65574940B64C86E3F9024240AC90F2936A5B49401366DAFE95074240AC90F2936A5B49401366DAFE9507424020D4450A65574940B64C86E3F902424020D4450A65574940
33547	23646	35.911940999999999	35.945008000000001	50.575842999999999	50.547685000000001	Колхозная	0103000020E61000000100000005000000D670917BBAF4414040C1C58A1A464940D670917BBAF44140B5503239B5494940AC3AAB05F6F84140B5503239B5494940AC3AAB05F6F8414040C1C58A1A464940D670917BBAF4414040C1C58A1A464940
33525	24217	35.962822000000003	36.030582000000003	50.527830999999999	50.483753	Центральная	0103000020E6100000010000000500000046EF54C03DFB4140C32B499EEB3D494046EF54C03DFB4140516859F78F43494053EC681CEA034240516859F78F43494053EC681CEA034240C32B499EEB3D494046EF54C03DFB4140C32B499EEB3D4940
33504	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	пл. Ушакова	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33382	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	переулок Дегтярева	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33441	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	Совхозная	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33481	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	Советская	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33604	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	Республиканская	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33383	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	Первомайская	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33502	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	Грайворонская	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33440	23752	35.949060000000003	36.061843000000003	50.639347000000001	50.581339999999997	Белгородская	0103000020E610000001000000050000008CF84ECC7AF94140A6ED5F59694A49408CF84ECC7AF94140DAE55B1FD6514940473EAF78EA074240DAE55B1FD6514940473EAF78EA074240A6ED5F59694A49408CF84ECC7AF94140A6ED5F59694A4940
33560	23663	35.871948000000003	35.941783000000001	50.543593000000001	50.476210000000002	Садовая	0103000020E6100000010000000500000004E8F7FD9BEF41409B030473F43C494004E8F7FD9BEF4140D2AA967494454940E27668588CF84140D2AA967494454940E27668588CF841409B030473F43C494004E8F7FD9BEF41409B030473F43C4940
33617	23663	35.871948000000003	35.941783000000001	50.543593000000001	50.476210000000002	Колхозная	0103000020E6100000010000000500000004E8F7FD9BEF41409B030473F43C494004E8F7FD9BEF4140D2AA967494454940E27668588CF84140D2AA967494454940E27668588CF841409B030473F43C494004E8F7FD9BEF41409B030473F43C4940
33310	23564	35.900990999999998	35.949373999999999	50.600543000000002	50.575133999999998	Первомайская	0103000020E61000000100000005000000C37E4FAC53F34140A968ACFD9D494940C37E4FAC53F34140BE6BD097DE4C49401BD6541685F94140BE6BD097DE4C49401BD6541685F94140A968ACFD9D494940C37E4FAC53F34140A968ACFD9D494940
33853	24300	36.053704000000003	36.081102999999999	50.546002000000001	50.511125	Молодежная	0103000020E610000001000000050000000BD5CDC5DF0642408195438B6C4149400BD5CDC5DF0642407AC6BE64E3454940C24D4695610A42407AC6BE64E3454940C24D4695610A42408195438B6C4149400BD5CDC5DF0642408195438B6C414940
33806	23462	35.831837999999998	35.871077	50.657657999999998	50.641986000000003	Центральная	0103000020E61000000100000005000000F7C8E6AA79EA4140B43EE5982C524940F7C8E6AA79EA4140F4F928232E5449401EA67D737FEF4140F4F928232E5449401EA67D737FEF4140B43EE5982C524940F7C8E6AA79EA4140B43EE5982C524940
33766	19374	36.748694999999998	36.770173999999997	50.607883000000001	50.592429000000003	Кидалова	0103000020E61000000100000005000000E0D6DD3CD55F4240DB19A6B6D44B4940E0D6DD3CD55F4240AE65321CCF4D4940601DC70F95624240AE65321CCF4D4940601DC70F95624240DB19A6B6D44B4940E0D6DD3CD55F4240DB19A6B6D44B4940
33251	22354	36.501945999999997	36.511504000000002	50.37124	50.363869000000001	Кирова	0103000020E61000000100000005000000D32D3BC43F4042409D836742932E4940D32D3BC43F404240C87BD5CA842F4940F8E28BF678414240C87BD5CA842F4940F8E28BF6784142409D836742932E4940D32D3BC43F4042409D836742932E4940
33614	22300	36.152895999999998	36.192359000000003	50.463464999999999	50.432566000000001	Молодежная	0103000020E6100000010000000500000038D89B189213424047AE9B525E37494038D89B18921342409AEB34D2523B4940AF0B3F389F1842409AEB34D2523B4940AF0B3F389F18424047AE9B525E37494038D89B189213424047AE9B525E374940
33873	22380	36.477781	36.504469999999998	50.392091000000001	50.375543	Мира	0103000020E6100000010000000500000039D384ED273D4240F19E03CB1130494039D384ED273D42402907B3093032494014E81379924042402907B3093032494014E8137992404240F19E03CB1130494039D384ED273D4240F19E03CB11304940
33652	22212	36.671250999999998	36.703221999999997	50.723576999999999	50.700409000000001	Центральная	0103000020E610000001000000050000002234828DEB5542407B698A00A75949402234828DEB554240A391CF2B9E5C4940F2E9B12D035A4240A391CF2B9E5C4940F2E9B12D035A42407B698A00A75949402234828DEB5542407B698A00A7594940
33804	22572	36.485380999999997	36.497463000000003	50.343741000000001	50.334215	Центральная	0103000020E61000000100000005000000C58CF0F6203E4240946A9F8EC72A4940C58CF0F6203E4240ADA580B4FF2B49402BFC19DEAC3F4240ADA580B4FF2B49402BFC19DEAC3F4240946A9F8EC72A4940C58CF0F6203E4240946A9F8EC72A4940
33351	22045	36.554882999999997	36.575741999999998	50.507997000000003	50.500968	Садовая	0103000020E610000001000000050000009D0DF96706474240D82B2CB81F4049409D0DF96706474240AABBB20B064149408177F2E9B1494240AABBB20B064149408177F2E9B1494240D82B2CB81F4049409D0DF96706474240D82B2CB81F404940
33477	22045	36.554882999999997	36.575741999999998	50.507997000000003	50.500968	Комсомольская	0103000020E610000001000000050000009D0DF96706474240D82B2CB81F4049409D0DF96706474240AABBB20B064149408177F2E9B1494240AABBB20B064149408177F2E9B1494240D82B2CB81F4049409D0DF96706474240D82B2CB81F404940
33501	21897	36.465977000000002	36.521089000000003	50.641534999999998	50.615313999999998	Чапаева	0103000020E6100000010000000500000017D86322A53B4240AE62F19BC24E494017D86322A53B4240A31EA2D11D52494016A75A0BB3424240A31EA2D11D52494016A75A0BB3424240AE62F19BC24E494017D86322A53B4240AE62F19BC24E4940
33365	21897	36.465977000000002	36.521089000000003	50.641534999999998	50.615313999999998	Краснооктябрьская	0103000020E6100000010000000500000017D86322A53B4240AE62F19BC24E494017D86322A53B4240A31EA2D11D52494016A75A0BB3424240A31EA2D11D52494016A75A0BB3424240AE62F19BC24E494017D86322A53B4240AE62F19BC24E4940
33327	21897	36.465977000000002	36.521089000000003	50.641534999999998	50.615313999999998	Королева	0103000020E6100000010000000500000017D86322A53B4240AE62F19BC24E494017D86322A53B4240A31EA2D11D52494016A75A0BB3424240A31EA2D11D52494016A75A0BB3424240AE62F19BC24E494017D86322A53B4240AE62F19BC24E4940
33851	19937	36.152239999999999	36.168024000000003	50.537999999999997	50.531381000000003	Школьная	0103000020E610000001000000050000004F92AE997C1342409F5BE84A044449404F92AE997C134240BE9F1A2FDD444940B87878CF81154240BE9F1A2FDD444940B87878CF811542409F5BE84A044449404F92AE997C1342409F5BE84A04444940
33415	23298	36.546080000000003	36.576946	50.684534999999997	50.669614000000003	Школьная	0103000020E61000000100000005000000F67F0EF3E5454240CD785BE9B5554940F67F0EF3E5454240D2FBC6D79E5749406DC7D45DD9494240D2FBC6D79E5749406DC7D45DD9494240CD785BE9B5554940F67F0EF3E5454240CD785BE9B5554940
33193	23298	36.546080000000003	36.576946	50.684534999999997	50.669614000000003	Олимпийская	0103000020E61000000100000005000000F67F0EF3E5454240CD785BE9B5554940F67F0EF3E5454240D2FBC6D79E5749406DC7D45DD9494240D2FBC6D79E5749406DC7D45DD9494240CD785BE9B5554940F67F0EF3E5454240CD785BE9B5554940
33479	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Школьная	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33480	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Чехова	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33417	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Филиппова	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33600	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Станционная	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33252	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Сиреневый бульвар	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33208	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Ленина	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33336	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Железнодорожная	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33207	22834	36.664613000000003	36.699601999999999	50.542395999999997	50.528581000000003	Бельгина	0103000020E610000001000000050000008CBFED0912554240BC24CE8AA84349408CBFED091255424098BD6C3B6D454940AC1BEF8E8C59424098BD6C3B6D454940AC1BEF8E8C594240BC24CE8AA84349408CBFED0912554240BC24CE8AA8434940
33439	21724	36.406948999999997	36.462581	50.635057000000003	50.614908	Центральная	0103000020E61000000100000005000000E811A3E7163442403E062B4EB54E4940E811A3E716344240460C3B8C495149402060ADDA353B4240460C3B8C495149402060ADDA353B42403E062B4EB54E4940E811A3E7163442403E062B4EB54E4940
33249	21724	36.406948999999997	36.462581	50.635057000000003	50.614908	Пушкарская	0103000020E61000000100000005000000E811A3E7163442403E062B4EB54E4940E811A3E716344240460C3B8C495149402060ADDA353B4240460C3B8C495149402060ADDA353B42403E062B4EB54E4940E811A3E7163442403E062B4EB54E4940
33715	19525	36.631582000000002	36.663876000000002	50.704573000000003	50.687325000000001	Гагарина	0103000020E61000000100000005000000035FD1ADD7504240925CFE43FA574940035FD1ADD75042408352B4722F5A4940B64C86E3F95442408352B4722F5A4940B64C86E3F9544240925CFE43FA574940035FD1ADD7504240925CFE43FA574940
33683	21501	36.398235	36.413983000000002	50.383223000000001	50.373888999999998	Трудовая	0103000020E61000000100000005000000B08F4E5DF9324240C5AA4198DB2F4940B08F4E5DF93242409A0986730D314940CC0C1B65FD3442409A0986730D314940CC0C1B65FD344240C5AA4198DB2F4940B08F4E5DF9324240C5AA4198DB2F4940
33797	19923	36.230592000000001	36.262985	50.549762999999999	50.533946	переулок Лесной	0103000020E61000000100000005000000105CE509841D42403EEAAF5758444940105CE509841D424082C64CA25E464940562B137EA921424082C64CA25E464940562B137EA92142403EEAAF5758444940105CE509841D42403EEAAF5758444940
33306	22649	36.340159	36.377538000000001	50.461899000000003	50.424852999999999	Чернышевского	0103000020E61000000100000005000000543882548A2B4240C24D469561364940543882548A2B42400E87A5811F3B4940A67F492A533042400E87A5811F3B4940A67F492A53304240C24D469561364940543882548A2B4240C24D469561364940
33309	22649	36.340159	36.377538000000001	50.461899000000003	50.424852999999999	Привокзальная	0103000020E61000000100000005000000543882548A2B4240C24D469561364940543882548A2B42400E87A5811F3B4940A67F492A533042400E87A5811F3B4940A67F492A53304240C24D469561364940543882548A2B4240C24D469561364940
33307	22649	36.340159	36.377538000000001	50.461899000000003	50.424852999999999	Матросова	0103000020E61000000100000005000000543882548A2B4240C24D469561364940543882548A2B42400E87A5811F3B4940A67F492A533042400E87A5811F3B4940A67F492A53304240C24D469561364940543882548A2B4240C24D469561364940
33546	22649	36.340159	36.377538000000001	50.461899000000003	50.424852999999999	Кутузова	0103000020E61000000100000005000000543882548A2B4240C24D469561364940543882548A2B42400E87A5811F3B4940A67F492A533042400E87A5811F3B4940A67F492A53304240C24D469561364940543882548A2B4240C24D469561364940
33478	22649	36.340159	36.377538000000001	50.461899000000003	50.424852999999999	Коммунистическая	0103000020E61000000100000005000000543882548A2B4240C24D469561364940543882548A2B42400E87A5811F3B4940A67F492A533042400E87A5811F3B4940A67F492A53304240C24D469561364940543882548A2B4240C24D469561364940
33379	21635	36.660165999999997	36.672060000000002	50.657995	50.646127999999997	Лейтенанта Павлова	0103000020E610000001000000050000002FF7C95180544240D3838252B45249402FF7C951805442403CF71E2E395449409279E40F065642403CF71E2E395449409279E40F06564240D3838252B45249402FF7C95180544240D3838252B4524940
33684	20256	36.507272999999998	36.537106000000001	50.451577	50.445112000000002	Зеленая	0103000020E6100000010000000500000068925852EE4042405187156EF938494068925852EE4042401A506F46CD394940213EB0E3BF4442401A506F46CD394940213EB0E3BF4442405187156EF938494068925852EE4042405187156EF9384940
33462	21560	36.567495999999998	36.584654	50.444400999999999	50.421903999999998	Школьная	0103000020E610000001000000050000002F4E7CB5A34842409A0645F3003649402F4E7CB5A3484240A4A7C821E2384940E0BC38F1D54A4240A4A7C821E2384940E0BC38F1D54A42409A0645F3003649402F4E7CB5A34842409A0645F300364940
33206	21560	36.567495999999998	36.584654	50.444400999999999	50.421903999999998	Советская	0103000020E610000001000000050000002F4E7CB5A34842409A0645F3003649402F4E7CB5A3484240A4A7C821E2384940E0BC38F1D54A4240A4A7C821E2384940E0BC38F1D54A42409A0645F3003649402F4E7CB5A34842409A0645F300364940
33725	19859	36.244236999999998	36.258547	50.485255000000002	50.473911000000001	Николаевка	0103000020E6100000010000000500000090BC7328431F42407A1B9B1DA93C494090BC7328431F4240399CF9D51C3E49404DBD6E1118214240399CF9D51C3E49404DBD6E11182142407A1B9B1DA93C494090BC7328431F42407A1B9B1DA93C4940
33779	21099	36.676003000000001	36.690097999999999	50.500532	50.477345	Придорожная	0103000020E61000000100000005000000BB7F2C44875642405EF415A4193D4940BB7F2C4487564240FD4CBD6E114049407B849A2155584240FD4CBD6E114049407B849A21555842405EF415A4193D4940BB7F2C44875642405EF415A4193D4940
33805	22488	36.589891000000001	36.621079999999999	50.365087000000003	50.348731000000001	Мира	0103000020E61000000100000005000000359A5C8C814B4240FA0CA837A32C4940359A5C8C814B4240EE98BA2BBB2E49408F19A88C7F4F4240EE98BA2BBB2E49408F19A88C7F4F4240FA0CA837A32C4940359A5C8C814B4240FA0CA837A32C4940
33871	20759	36.291336000000001	36.305079999999997	50.348402999999998	50.336703999999997	Зелёная	0103000020E61000000100000005000000E012807F4A2542405837DE1D192B4940E012807F4A254240056A3178982C4940F35487DC0C274240056A3178982C4940F35487DC0C2742405837DE1D192B4940E012807F4A2542405837DE1D192B4940
33542	19340	36.791473000000003	36.810993000000003	50.641198000000003	50.622548999999999	Трунова	0103000020E610000001000000050000006155BDFC4E654240299485AFAF4F49406155BDFC4E6542405C21ACC61252494079245E9ECE6742405C21ACC61252494079245E9ECE674240299485AFAF4F49406155BDFC4E654240299485AFAF4F4940
33500	53989	36.404155000000003	36.408934000000002	50.372796999999998	50.368856000000001	Мирная	0103000020E61000000100000005000000E8C1DD59BB334240797764AC362F4940E8C1DD59BB3342400186E5CFB72F49407A1C06F3573442400186E5CFB72F49407A1C06F357344240797764AC362F4940E8C1DD59BB334240797764AC362F4940
33476	21127	36.450885	36.463012999999997	50.522551	50.515535	Садовая	0103000020E61000000100000005000000E4A08499B6394240C078060DFD414940E4A08499B6394240FDBE7FF3E2424940B94F8E02443B4240FDBE7FF3E2424940B94F8E02443B4240C078060DFD414940E4A08499B6394240C078060DFD414940
33634	21127	36.450885	36.463012999999997	50.522551	50.515535	Пионерская	0103000020E61000000100000005000000E4A08499B6394240C078060DFD414940E4A08499B6394240FDBE7FF3E2424940B94F8E02443B4240FDBE7FF3E2424940B94F8E02443B4240C078060DFD414940E4A08499B6394240C078060DFD414940
33192	21127	36.450885	36.463012999999997	50.522551	50.515535	Кирова	0103000020E61000000100000005000000E4A08499B6394240C078060DFD414940E4A08499B6394240FDBE7FF3E2424940B94F8E02443B4240FDBE7FF3E2424940B94F8E02443B4240C078060DFD414940E4A08499B6394240C078060DFD414940
33246	21127	36.450885	36.463012999999997	50.522551	50.515535	Вавилова	0103000020E61000000100000005000000E4A08499B6394240C078060DFD414940E4A08499B6394240FDBE7FF3E2424940B94F8E02443B4240FDBE7FF3E2424940B94F8E02443B4240C078060DFD414940E4A08499B6394240C078060DFD414940
33305	21032	36.710192999999997	36.752800000000001	50.541755000000002	50.506777	Октябрьская	0103000020E610000001000000050000008F6CAE9AE75A4240B8AE9811DE4049408F6CAE9AE75A4240E5B8533A58454940E3361AC05B604240E5B8533A58454940E3361AC05B604240B8AE9811DE4049408F6CAE9AE75A4240B8AE9811DE404940
33540	20997	36.242809000000001	36.271213000000003	50.380662000000001	50.363931999999998	Калинина	0103000020E610000001000000050000005516855D141F4240E3FBE252952E49405516855D141F42403C6A4C88B930494002A08A1BB72242403C6A4C88B930494002A08A1BB7224240E3FBE252952E49405516855D141F4240E3FBE252952E4940
33616	20865	36.300821999999997	36.350758999999996	50.472076999999999	50.451445	Победы	0103000020E610000001000000050000006AF5D55581264240AB7823F3C83949406AF5D55581264240CE18E6046D3C49408AE3C0ABE52C4240CE18E6046D3C49408AE3C0ABE52C4240AB7823F3C83949406AF5D55581264240AB7823F3C8394940
33244	20865	36.300821999999997	36.350758999999996	50.472076999999999	50.451445	Гагарина	0103000020E610000001000000050000006AF5D55581264240AB7823F3C83949406AF5D55581264240CE18E6046D3C49408AE3C0ABE52C4240CE18E6046D3C49408AE3C0ABE52C4240AB7823F3C83949406AF5D55581264240AB7823F3C8394940
33482	53984	36.470306999999998	36.545631	50.587448000000002	50.529749000000002	Ворошилова	0103000020E61000000100000005000000390A1005333C42405B0BB3D0CE434940390A1005333C4240E10CFE7E314B49408657923CD7454240E10CFE7E314B49408657923CD74542405B0BB3D0CE434940390A1005333C42405B0BB3D0CE434940
33800	22284	36.690026000000003	36.715296000000002	50.749246999999997	50.728965000000002	Центральная	0103000020E61000000100000005000000E2B19FC552584240DE76A1B94E5D4940E2B19FC55258424024D06053E75F4940D57ABFD18E5B424024D06053E75F4940D57ABFD18E5B4240DE76A1B94E5D4940E2B19FC552584240DE76A1B94E5D4940
33649	19502	36.619543999999998	36.643160999999999	50.640946999999997	50.623612000000001	Донецкая	0103000020E610000001000000050000006D37C1374D4F424053B29C84D24F49406D37C1374D4F424012BC218D0A524940058882195352424012BC218D0A524940058882195352424053B29C84D24F49406D37C1374D4F424053B29C84D24F4940
33522	20745	36.302708000000003	36.343384	50.322730999999997	50.303674000000001	Коммунистическая	0103000020E61000000100000005000000691EC022BF264240A05225CADE264940691EC022BF264240E333D93F4F2949401EFCC401F42B4240E333D93F4F2949401EFCC401F42B4240A05225CADE264940691EC022BF264240A05225CADE264940
33544	20650	36.498612999999999	36.519283000000001	50.723194999999997	50.709890000000001	Советская	0103000020E61000000100000005000000232E008DD23F4240F4E0EEACDD5A4940232E008DD23F4240BBD05CA7915C4940342F87DD77424240BBD05CA7915C4940342F87DD77424240F4E0EEACDD5A4940232E008DD23F4240F4E0EEACDD5A4940
33190	53971	36.576343999999999	36.590725999999997	50.539082000000001	50.531725000000002	Ягодная	0103000020E61000000100000005000000779FE3A3C549424099BB96900F444940779FE3A3C54942405FEE93A300454940CD72D9E89C4B42405FEE93A300454940CD72D9E89C4B424099BB96900F444940779FE3A3C549424099BB96900F444940
33250	53971	36.576343999999999	36.590725999999997	50.539082000000001	50.531725000000002	Лесная	0103000020E61000000100000005000000779FE3A3C549424099BB96900F444940779FE3A3C54942405FEE93A300454940CD72D9E89C4B42405FEE93A300454940CD72D9E89C4B424099BB96900F444940779FE3A3C549424099BB96900F444940
33524	21829	36.435972999999997	36.462581	50.660381999999998	50.634880000000003	Драгунская	0103000020E61000000100000005000000317898F6CD374240377172BF43514940317898F6CD374240FC6EBA65875449402060ADDA353B4240FC6EBA65875449402060ADDA353B4240377172BF43514940317898F6CD374240377172BF43514940
33788	20123	36.394022	36.413137999999996	50.523237999999999	50.507778999999999	Школьная	0103000020E61000000100000005000000C7F319506F3242403C4CFBE6FE404940C7F319506F32424021037976F94249400F5EBBB4E134424021037976F94249400F5EBBB4E13442403C4CFBE6FE404940C7F319506F3242403C4CFBE6FE404940
33582	20199	36.427852999999999	36.456302000000001	50.485689999999998	50.464852	Катульского	0103000020E610000001000000050000006C3F19E3C336424077BD3445803B49406C3F19E3C336424043FF04172B3E4940B98C9B1A683A424043FF04172B3E4940B98C9B1A683A424077BD3445803B49406C3F19E3C336424077BD3445803B4940
33809	22524	36.567909	36.593457000000001	50.312958999999999	50.305974999999997	Центральная	0103000020E61000000100000005000000520DFB3DB1484240613255302A274940520DFB3DB148424093FE5E0A0F284940884A2366F64B424093FE5E0A0F284940884A2366F64B4240613255302A274940520DFB3DB1484240613255302A274940
33651	20025	36.365563000000002	36.399070999999999	50.503076	50.483134	Заводская	0103000020E6100000010000000500000057D0B4C4CA2E4240F7CABC55D73D494057D0B4C4CA2E424085B35BCB6440494019E42EC21433424085B35BCB6440494019E42EC214334240F7CABC55D73D494057D0B4C4CA2E4240F7CABC55D73D4940
33499	20025	36.365563000000002	36.399070999999999	50.503076	50.483134	Гагарина	0103000020E6100000010000000500000057D0B4C4CA2E4240F7CABC55D73D494057D0B4C4CA2E424085B35BCB6440494019E42EC21433424085B35BCB6440494019E42EC214334240F7CABC55D73D494057D0B4C4CA2E4240F7CABC55D73D4940
33848	20318	36.399807000000003	36.414450000000002	50.427802999999997	50.419182999999997	Зелёная	0103000020E610000001000000050000001FDB32E02C3342400305DEC9A73549401FDB32E02C334240BA10AB3FC2364940E2E995B20C354240BA10AB3FC2364940E2E995B20C3542400305DEC9A73549401FDB32E02C3342400305DEC9A7354940
33723	22435	36.559832999999998	36.577565999999997	50.378777999999997	50.359375	Советская	0103000020E610000001000000050000005C1C959BA847424000000000002E49405C1C959BA8474240DE3829CC7B30494009A4C4AEED494240DE3829CC7B30494009A4C4AEED49424000000000002E49405C1C959BA847424000000000002E4940
33523	21699	36.697006000000002	36.728411000000001	50.622777999999997	50.609192	Центральная	0103000020E61000000100000005000000D28E1B7E375942400F7EE200FA4D4940D28E1B7E375942408A558330B74F4940F98557923C5D42408A558330B74F4940F98557923C5D42400F7EE200FA4D4940D28E1B7E375942400F7EE200FA4D4940
33808	54046	36.367835999999997	36.387869000000002	50.583765	50.570283000000003	Луговой переулок	0103000020E610000001000000050000004E250340152F42407E3B8908FF4849404E250340152F424054C6BFCFB84A4940ED10FFB0A531424054C6BFCFB84A4940ED10FFB0A53142407E3B8908FF4849404E250340152F42407E3B8908FF484940
33187	19656	36.285046999999999	36.321483000000001	50.541274000000001	50.516807	Партизанская	0103000020E6100000010000000500000055698B6B7C24424004AC55BB2642494055698B6B7C2442406A16687748454940289CDD5A262942406A16687748454940289CDD5A2629424004AC55BB2642494055698B6B7C24424004AC55BB26424940
33437	19450	36.612906000000002	36.655306000000003	50.691319999999997	50.667763999999998	Центральная	0103000020E61000000100000005000000D7C22CB4734E42401BB96E4A79554940D7C22CB4734E42400D897B2C7D584940B16F2711E15342400D897B2C7D584940B16F2711E15342401BB96E4A79554940D7C22CB4734E42401BB96E4A79554940
33186	19265	36.724009000000002	36.753672000000002	50.591743000000001	50.565505999999999	Центральная	0103000020E610000001000000050000003D81B053AC5C42408CD82780624849403D81B053AC5C42408751103CBE4B494099F4F752786042408751103CBE4B494099F4F752786042408CD82780624849403D81B053AC5C42408CD8278062484940
33262	53978	36.546080000000003	36.576946	50.684534999999997	50.669614000000003	Школьная,	0103000020E61000000100000005000000F67F0EF3E5454240CD785BE9B5554940F67F0EF3E5454240D2FBC6D79E5749406DC7D45DD9494240D2FBC6D79E5749406DC7D45DD9494240CD785BE9B5554940F67F0EF3E5454240CD785BE9B5554940
33490	46930	38.714801999999999	38.732084999999998	50.752524000000001	50.744984000000002	Революционная	0103000020E61000000100000005000000C58EC6A17E5B43408A05BEA25B5F4940C58EC6A17E5B434041BAD8B452604940327216F6B45D434041BAD8B452604940327216F6B45D43408A05BEA25B5F4940C58EC6A17E5B43408A05BEA25B5F4940
33700	54024	38.478895000000001	39.126579999999997	50.822702	50.250297000000003	поселок Опытная станция	0103000020E61000000100000005000000E59B6D6E4C3D4340BAA46ABB09204940E59B6D6E4C3D4340492D944C4E694940F12900C633904340492D944C4E694940F12900C633904340BAA46ABB09204940E59B6D6E4C3D4340BAA46ABB09204940
203	1	37.685180000000003	37.842519000000003	55.776988000000003	55.746887000000001	шоссе Энтузиастов	0103000020E61000000100000005000000C8EF6DFAB3D742405E6743FE99DF4B40C8EF6DFAB3D7424036B1C05774E34B401BA19FA9D7EB424036B1C05774E34B401BA19FA9D7EB42405E6743FE99DF4B40C8EF6DFAB3D742405E6743FE99DF4B40
609	1	37.579008000000002	37.583077000000003	55.828465000000001	55.812002999999997	улица Яблочкова	0103000020E61000000100000005000000AA0F24EF1CCA42407FA0DCB6EFE74B40AA0F24EF1CCA4240B97020240BEA4B4060066344A2CA4240B97020240BEA4B4060066344A2CA42407FA0DCB6EFE74B40AA0F24EF1CCA42407FA0DCB6EFE74B40
3442	1	37.732861999999997	37.791342	55.701227000000003	55.696762999999997	улица Юных Ленинцев	0103000020E61000000100000005000000963D096CCEDD42400B08AD872FD94B40963D096CCEDD42403E096CCEC1D94B40C2F9D4B14AE542403E096CCEC1D94B40C2F9D4B14AE542400B08AD872FD94B40963D096CCEDD42400B08AD872FD94B40
5485	1	37.403252000000002	37.408659999999998	55.648687000000002	55.642997000000001	улица Щорса	0103000020E61000000100000005000000F705F4C29DB342408B36C7B94DD24B40F705F4C29DB34240912BF52C08D34B4078978BF84EB44240912BF52C08D34B4078978BF84EB442408B36C7B94DD24B40F705F4C29DB342408B36C7B94DD24B40
945	1	37.628675999999999	37.629618999999998	55.788915000000003	55.773322	улица Щепкина	0103000020E61000000100000005000000DAE3857478D042407FA31D37FCE24B40DAE3857478D042407429AE2AFBE44B4059F8FA5A97D042407429AE2AFBE44B4059F8FA5A97D042407FA31D37FCE24B40DAE3857478D042407FA31D37FCE24B40
3332	1	37.768624000000003	37.779888999999997	55.709794000000002	55.706741000000001	улица Шумилова	0103000020E61000000100000005000000DA756F4562E2424005DF347D76DA4B40DA756F4562E24240D272A087DADA4B404CC11A67D3E34240D272A087DADA4B404CC11A67D3E3424005DF347D76DA4B40DA756F4562E2424005DF347D76DA4B40
4524	1	37.339652000000001	37.360168999999999	55.645527000000001	55.634883000000002	улица Шолохова	0103000020E61000000100000005000000B0027CB779AB4240A8E49CD843D14B40B0027CB779AB4240AED7F4A0A0D24B403A048E041AAE4240AED7F4A0A0D24B403A048E041AAE4240A8E49CD843D14B40B0027CB779AB4240A8E49CD843D14B40
6290	1	37.605911999999996	37.611885999999998	55.727628000000003	55.711244999999998	улица Шаболовка	0103000020E61000000100000005000000812040868ECD4240C5387F130ADB4B40812040868ECD4240B3D30FEA22DD4B40AC70CB4752CE4240B3D30FEA22DD4B40AC70CB4752CE4240C5387F130ADB4B40812040868ECD4240C5387F130ADB4B40
2975	1	37.791693000000002	37.802849999999999	55.697975	55.695326999999999	улица Чугунные Ворота	0103000020E610000001000000050000006FBC3B3256E542404D83A27900D94B406FBC3B3256E542407A36AB3E57D94B40FBCBEEC9C3E642407A36AB3E57D94B40FBCBEEC9C3E642404D83A27900D94B406FBC3B3256E542404D83A27900D94B40
5314	1	37.733598999999998	37.751987	55.697676000000001	55.696143999999997	улица Чистова	0103000020E610000001000000050000006CB07092E6DD42403FA7203F1BD94B406CB07092E6DD4240209A79724DD94B4032022A1C41E04240209A79724DD94B4032022A1C41E042403FA7203F1BD94B406CB07092E6DD42403FA7203F1BD94B40
2165	1	37.564211999999998	37.580077000000003	55.672142999999998	55.666837999999998	улица Цюрупы	0103000020E6100000010000000500000060014C1938C8424072DD94F25AD54B4060014C1938C842401F9E25C808D64B40B61490F63FCA42401F9E25C808D64B40B61490F63FCA424072DD94F25AD54B4060014C1938C8424072DD94F25AD54B40
6630	1	37.630274999999997	37.631317000000003	55.821314999999998	55.815944000000002	улица Цандера	0103000020E61000000100000005000000423EE8D9ACD0424008AF5DDA70E84B40423EE8D9ACD042406C5B94D920E94B405534D6FECED042406C5B94D920E94B405534D6FECED0424008AF5DDA70E84B40423EE8D9ACD0424008AF5DDA70E84B40
6753	1	37.437244999999997	37.449613999999997	55.859361999999997	55.855314999999997	улица Фомичевой	0103000020E6100000010000000500000075ABE7A4F7B742409D6340F67AED4B4075ABE7A4F7B742406BB6F292FFED4B4070E998F38CB942406BB6F292FFED4B4070E998F38CB942409D6340F67AED4B4075ABE7A4F7B742409D6340F67AED4B40
2668	1	37.514006000000002	37.534514000000001	55.809154999999997	55.803747000000001	улица Усиевича	0103000020E6100000010000000500000051F9D7F2CAC142400AA1832EE1E64B4051F9D7F2CAC142408B321B6492E74B4088A06AF46AC442408B321B6492E74B4088A06AF46AC442400AA1832EE1E64B4051F9D7F2CAC142400AA1832EE1E64B40
7121	1	37.645420000000001	37.656227000000001	55.885973	55.883101000000003	улица Тихомирова	0103000020E610000001000000050000009817601F9DD242404F081D7409F14B409817601F9DD24240CB11329067F14B4048E00F3FFFD34240CB11329067F14B4048E00F3FFFD342404F081D7409F14B409817601F9DD242404F081D7409F14B40
5389	1	37.498356999999999	37.507447999999997	55.706009999999999	55.702911	улица Столетова	0103000020E61000000100000005000000C85D8429CABF4240D47FD6FCF8D94B40C85D8429CABF4240115322895EDA4B40D6355A0EF4C04240115322895EDA4B40D6355A0EF4C04240D47FD6FCF8D94B40C85D8429CABF4240D47FD6FCF8D94B40
6280	1	37.590505999999998	37.599687000000003	55.714587000000002	55.714105000000004	улица Стасовой	0103000020E61000000100000005000000BF0B5BB395CB42407E74EACA67DB4B40BF0B5BB395CB4240C992399677DB4B400E6B2A8BC2CC4240C992399677DB4B400E6B2A8BC2CC42407E74EACA67DB4B40BF0B5BB395CB42407E74EACA67DB4B40
2754	1	37.651394000000003	37.677785999999998	55.793773000000002	55.790626000000003	улица Сокольнический Вал	0103000020E61000000100000005000000C367EBE060D3424004AF963B33E54B40C367EBE060D3424052B9895A9AE54B40E4D70FB1C1D6424052B9895A9AE54B40E4D70FB1C1D6424004AF963B33E54B40C367EBE060D3424004AF963B33E54B40
6787	1	37.428037000000003	37.455319000000003	55.876657000000002	55.820166999999998	улица Свободы	0103000020E610000001000000050000002E3D9AEAC9B642401421753BFBE84B402E3D9AEAC9B642409D67EC4B36F04B40AC1F9BE447BA42409D67EC4B36F04B40AC1F9BE447BA42401421753BFBE84B402E3D9AEAC9B642401421753BFBE84B40
4641	1	37.505201999999997	37.511248000000002	55.796506000000001	55.793762999999998	улица Сальвадора Альенде	0103000020E61000000100000005000000D8EF8975AAC042402EE3A6069AE54B40D8EF8975AAC04240AD889AE8F3E54B409D12109370C14240AD889AE8F3E54B409D12109370C142402EE3A6069AE54B40D8EF8975AAC042402EE3A6069AE54B40
3304	1	37.544997000000002	37.555903000000001	55.611801	55.609340000000003	улица Рокотова	0103000020E6100000010000000500000085B53176C2C54240841266DAFECD4B4085B53176C2C542407E54C37E4FCE4B40C85F5AD427C742407E54C37E4FCE4B40C85F5AD427C74240841266DAFECD4B4085B53176C2C54240841266DAFECD4B40
5188	1	37.537371	37.544925999999997	55.773667000000003	55.770131999999997	улица Розанова	0103000020E61000000100000005000000CF68AB92C8C4424031CD74AF93E24B40CF68AB92C8C442404A7F2F8507E34B40BB5E9A22C0C542404A7F2F8507E34B40BB5E9A22C0C5424031CD74AF93E24B40CF68AB92C8C4424031CD74AF93E24B40
42612	1	37.671193000000002	37.685367999999997	55.764429999999997	55.762124999999997	улица Радио	0103000020E61000000100000005000000EE26F8A6E9D54240643BDF4F8DE14B40EE26F8A6E9D54240670A9DD7D8E14B40CADC7C23BAD74240670A9DD7D8E14B40CADC7C23BAD74240643BDF4F8DE14B40EE26F8A6E9D54240643BDF4F8DE14B40
5153	1	37.525278999999998	37.533670000000001	55.727420000000002	55.724297	улица Пудовкина	0103000020E6100000010000000500000046239F573CC34240A3CB9BC3B5DC4B4046239F573CC34240693A3B191CDD4B409C6D6E4C4FC44240693A3B191CDD4B409C6D6E4C4FC44240A3CB9BC3B5DC4B4046239F573CC34240A3CB9BC3B5DC4B40
2074	1	37.586266000000002	37.601833999999997	55.744495000000001	55.738636999999997	улица Пречистенка	0103000020E61000000100000005000000DD60A8C30ACB4240CA4E3FA88BDE4B40DD60A8C30ACB42408C84B69C4BDF4B4078CF81E508CD42408C84B69C4BDF4B4078CF81E508CD4240CA4E3FA88BDE4B40DD60A8C30ACB4240CA4E3FA88BDE4B40
2880	1	37.538763000000003	37.572826999999997	55.581088000000001	55.550336000000001	улица Поляны	0103000020E61000000100000005000000BEA59C2FF6C44240DEE7F86871C64B40BEA59C2FF6C442408D0C721761CA4B4005A2276552C942408D0C721761CA4B4005A2276552C94240DEE7F86871C64B40BEA59C2FF6C44240DEE7F86871C64B40
2152	1	37.574300999999998	37.580679000000003	55.745756999999998	55.735191	улица Плющиха	0103000020E61000000100000005000000B187F6B182C9424022A81ABD1ADE4B40B187F6B182C94240ACE122F774DF4B40AC3C81B053CA4240ACE122F774DF4B40AC3C81B053CA424022A81ABD1ADE4B40B187F6B182C9424022A81ABD1ADE4B40
1576	1	37.760952000000003	37.761321000000002	55.747276999999997	55.738875	улица Плющева	0103000020E61000000100000005000000B4E908E066E142407F6ABC7493DE4B40B4E908E066E14240C806D2C5A6DF4B4007616EF772E14240C806D2C5A6DF4B4007616EF772E142407F6ABC7493DE4B40B4E908E066E142407F6ABC7493DE4B40
1700	1	37.755949000000001	37.770178000000001	55.759258000000003	55.738191	улица Плеханова	0103000020E61000000100000005000000D238D4EFC2E04240CC99ED0A7DDE4B40D238D4EFC2E04240FA9CBB5D2FE14B40A20C553195E24240FA9CBB5D2FE14B40A20C553195E24240CC99ED0A7DDE4B40D238D4EFC2E04240CC99ED0A7DDE4B40
6804	1	37.612847000000002	37.614832	55.867874	55.861646	улица Пестеля	0103000020E61000000100000005000000D2393FC571CE4240575D876A4AEE4B40D2393FC571CE42403C86C77E16EF4B406344A2D0B2CE42403C86C77E16EF4B406344A2D0B2CE4240575D876A4AEE4B40D2393FC571CE4240575D876A4AEE4B40
4330	1	37.713853999999998	37.792096999999998	55.675448000000003	55.651623000000001	улица Перерва	0103000020E61000000100000005000000340F60915FDB42402429E96168D34B40340F60915FDB424006137F1475D64B403E213B6F63E5424006137F1475D64B403E213B6F63E542402429E96168D34B40340F60915FDB42402429E96168D34B40
7282	1	37.448366	37.465747999999998	55.789541999999997	55.789011000000002	улица Паршина	0103000020E61000000100000005000000B5519D0E64B942409697FC4FFEE44B40B5519D0E64B94240C26856B60FE54B40B51666A19DBB4240C26856B60FE54B40B51666A19DBB42409697FC4FFEE44B40B5519D0E64B942409697FC4FFEE44B40
1555	1	37.540308000000003	37.547603000000002	55.684162999999998	55.680731999999999	улица Панферова	0103000020E6100000010000000500000033E202D028C542409BABE63922D74B4033E202D028C542400E1137A792D74B408318E8DA17C642400E1137A792D74B408318E8DA17C642409BABE63922D74B4033E202D028C542409BABE63922D74B40
5405	1	37.654251000000002	37.664257999999997	55.820819	55.811380999999997	улица Павла Корчагина	0103000020E610000001000000050000000A302C7FBED3424042CC2555DBE74B400A302C7FBED34240BC77D49810E94B409D0DF96706D54240BC77D49810E94B409D0DF96706D5424042CC2555DBE74B400A302C7FBED3424042CC2555DBE74B40
981	1	37.481406	37.540658999999998	55.649403	55.631599999999999	улица Островитянова	0103000020E61000000100000005000000910C39B69EBD4240A913D044D8D04B40910C39B69EBD42404F7633A31FD34B40DFA4695034C542404F7633A31FD34B40DFA4695034C54240A913D044D8D04B40910C39B69EBD4240A913D044D8D04B40
1784	1	37.508715000000002	37.563206000000001	55.663476000000003	55.649509999999999	улица Обручева	0103000020E6100000010000000500000009FEB7921DC142406536C82423D34B4009FEB7921DC1424028D714C8ECD44B409B745B2217C8424028D714C8ECD44B409B745B2217C842406536C82423D34B4009FEB7921DC142406536C82423D34B40
20	1	37.573663000000003	37.600603	55.752986999999997	55.752434999999998	улица Новый Арбат	0103000020E610000001000000050000006FF607CA6DC94240D1AE42CA4FE04B406FF607CA6DC9424015A8C5E061E04B409370218FE0CC424015A8C5E061E04B409370218FE0CC4240D1AE42CA4FE04B406FF607CA6DC94240D1AE42CA4FE04B40
1747	1	37.518309000000002	37.526555000000002	55.670954999999999	55.657834000000001	улица Новаторов	0103000020E610000001000000050000007A1C06F357C2424033198EE733D44B407A1C06F357C24240390B7BDAE1D54B40CC457C2766C34240390B7BDAE1D54B40CC457C2766C3424033198EE733D44B407A1C06F357C2424033198EE733D44B40
3893	1	37.474291000000001	37.499929000000002	55.797432000000001	55.769027999999999	улица Народного Ополчения	0103000020E61000000100000005000000C1E44691B5BC4240A9DA6E826FE24B40C1E44691B5BC42405664744012E64B4037A968ACFDBF42405664744012E64B4037A968ACFDBF4240A9DA6E826FE24B40C1E44691B5BC4240A9DA6E826FE24B40
233	1	37.831443	37.833005999999997	55.766997000000003	55.750073999999998	улица Молостовых	0103000020E610000001000000050000007BBE66B96CEA42403ACAC16C02E04B407BBE66B96CEA4240A8902BF52CE24B4096AFCBF09FEA4240A8902BF52CE24B4096AFCBF09FEA42403ACAC16C02E04B407BBE66B96CEA42403ACAC16C02E04B40
7852	1	37.806694999999998	37.838765000000002	55.729407000000002	55.718674	улица Молдагуловой	0103000020E61000000100000005000000616C21C841E74240253E7782FDDB4B40616C21C841E742409B3C65355DDD4B40C503CAA65CEB42409B3C65355DDD4B40C503CAA65CEB4240253E7782FDDB4B40616C21C841E74240253E7782FDDB4B40
7007	1	37.477246999999998	37.503413999999999	55.776183000000003	55.772131999999999	улица Мневники	0103000020E610000001000000050000009B8E006E16BD4240F818AC38D5E24B409B8E006E16BD4240085BECF659E34B409D2CB5DE6FC04240085BECF659E34B409D2CB5DE6FC04240F818AC38D5E24B409B8E006E16BD4240F818AC38D5E24B40
1815	1	37.495572000000003	37.543911000000001	55.655569	55.637703000000002	улица Миклухо-Маклая	0103000020E610000001000000050000001B683EE76EBF4240D2C77C40A0D14B401B683EE76EBF4240BEA25BAFE9D34B40A3772AE09EC54240BEA25BAFE9D34B40A3772AE09EC54240D2C77C40A0D14B401B683EE76EBF4240D2C77C40A0D14B40
12490	1	37.878362000000003	37.896588999999999	55.718867000000003	55.714677999999999	улица Медведева	0103000020E610000001000000050000004B06802A6EF04240D99596917ADB4B404B06802A6EF042403A9677D503DC4B40077AA86DC3F242403A9677D503DC4B40077AA86DC3F24240D99596917ADB4B404B06802A6EF04240D99596917ADB4B40
7143	1	37.456397000000003	37.487721000000001	55.785634999999999	55.780045999999999	улица Маршала Тухачевского	0103000020E610000001000000050000000B7F86376BBA424014B01D8CD8E34B400B7F86376BBA4240E6CB0BB08FE44B40454948A46DBE4240E6CB0BB08FE44B40454948A46DBE424014B01D8CD8E34B400B7F86376BBA424014B01D8CD8E34B40
7333	1	37.483201999999999	37.493901000000001	55.796394999999997	55.793059999999997	улица Маршала Соколовского	0103000020E610000001000000050000004FAE2990D9BD424004E275FD82E54B404FAE2990D9BD424055D97745F0E54B40193BE12538BF424055D97745F0E54B40193BE12538BF424004E275FD82E54B404FAE2990D9BD424004E275FD82E54B40
7214	1	37.483193	37.492733000000001	55.800423000000002	55.795216000000003	улица Маршала Конева	0103000020E61000000100000005000000FC53AA44D9BD4240C3A04CA3C9E54B40FC53AA44D9BD4240ADFBC74274E64B407A54FCDF11BF4240ADFBC74274E64B407A54FCDF11BF4240C3A04CA3C9E54B40FC53AA44D9BD4240C3A04CA3C9E54B40
1487	1	37.518856	37.530265	55.684254000000003	55.677701999999996	улица Марии Ульяновой	0103000020E61000000100000005000000ACAA97DF69C2424086376BF0BED64B40ACAA97DF69C242401F1494A295D74B40529B38B9DFC342401F1494A295D74B40529B38B9DFC3424086376BF0BED64B40ACAA97DF69C2424086376BF0BED64B40
4944	1	37.764941	37.775263000000002	55.729979999999998	55.728270999999999	улица Маевок	0103000020E610000001000000050000004D2F3196E9E1424007D0EFFB37DD4B404D2F3196E9E14240F65D11FC6FDD4B40416667D13BE34240F65D11FC6FDD4B40416667D13BE3424007D0EFFB37DD4B404D2F3196E9E1424007D0EFFB37DD4B40
3514	1	37.466780999999997	37.508831000000001	55.694184999999997	55.66339	улица Лобачевского	0103000020E6100000010000000500000074B2D47ABFBB4240293FA9F6E9D44B4074B2D47ABFBB4240D72FD80DDBD84B407218CC5F21C14240D72FD80DDBD84B407218CC5F21C14240293FA9F6E9D44B4074B2D47ABFBB4240293FA9F6E9D44B40
6263	1	37.658104000000002	37.664940999999999	55.70317	55.699776	улица Лобанова	0103000020E61000000100000005000000F3AE7AC03CD442404A438D4292D94B40F3AE7AC03CD44240A0C37C7901DA4B40806264C91CD54240A0C37C7901DA4B40806264C91CD542404A438D4292D94B40F3AE7AC03CD442404A438D4292D94B40
5278	1	37.508265000000002	37.517563000000003	55.795124999999999	55.777191000000002	улица Куусинена	0103000020E61000000100000005000000C959D8D30EC142406EDFA3FE7AE34B40C959D8D30EC14240B29DEFA7C6E54B40514F1F813FC24240B29DEFA7C6E54B40514F1F813FC242406EDFA3FE7AE34B40C959D8D30EC142406EDFA3FE7AE34B40
887	1	37.390414999999997	37.402408000000001	55.818336000000002	55.80057	улица Кулакова	0103000020E61000000100000005000000156F641EF9B142405114E81379E64B40156F641EF9B14240DA91EA3BBFE84B400BD3F71A82B34240DA91EA3BBFE84B400BD3F71A82B342405114E81379E64B40156F641EF9B142405114E81379E64B40
1424	1	37.522665000000003	37.533706000000002	55.686354999999999	55.680000999999997	улица Крупской	0103000020E61000000100000005000000C6E1CCAFE6C24240A71FD4450AD74B40C6E1CCAFE6C2424019390B7BDAD74B40E9D66B7A50C4424019390B7BDAD74B40E9D66B7A50C44240A71FD4450AD74B40C6E1CCAFE6C24240A71FD4450AD74B40
1146	1	37.582861000000001	37.590578000000001	55.770760000000003	55.765939000000003	улица Красина	0103000020E61000000100000005000000938E72309BCA424090DD054A0AE24B40938E72309BCA424051888043A8E24B4059DE550F98CB424051888043A8E24B4059DE550F98CB424090DD054A0AE24B40938E72309BCA424090DD054A0AE24B40
3356	1	37.500943999999997	37.532457000000001	55.816727999999998	55.815007999999999	улица Космонавта Волкова	0103000020E610000001000000050000004F90D8EE1EC042403BFDA02E52E84B404F90D8EE1EC042401EDD088B8AE84B405DC30C8D27C442401EDD088B8AE84B405DC30C8D27C442403BFDA02E52E84B404F90D8EE1EC042403BFDA02E52E84B40
5875	1	37.609217999999998	37.633014000000003	55.902509999999999	55.890946	улица Корнейчука	0103000020E610000001000000050000003811FDDAFACD42404240BE840AF24B403811FDDAFACD42400F289B7285F34B4080F44D9A06D142400F289B7285F34B4080F44D9A06D142404240BE840AF24B403811FDDAFACD42404240BE840AF24B40
5661	1	37.673951000000002	37.695428999999997	55.874752999999998	55.860715999999996	улица Коминтерна	0103000020E61000000100000005000000A20DC00644D642406C921FF12BEE4B40A20DC00644D64240F88903E8F7EF4B4051D845D103D94240F88903E8F7EF4B4051D845D103D942406C921FF12BEE4B40A20DC00644D642406C921FF12BEE4B40
525	1	37.558723999999998	37.598348000000001	55.660865999999999	55.651465000000002	улица Каховка	0103000020E61000000100000005000000C2BE9D4484C742408CBE823463D34B40C2BE9D4484C74240E884D04197D44B4042D0D1AA96CC4240E884D04197D44B4042D0D1AA96CC42408CBE823463D34B40C2BE9D4484C742408CBE823463D34B40
1701	1	37.648887999999999	37.667689000000003	55.827655999999998	55.821947000000002	улица Касаткина	0103000020E61000000100000005000000286211C30ED34240CD052E8F35E94B40286211C30ED34240492BBEA1F0E94B40117349D576D54240492BBEA1F0E94B40117349D576D54240CD052E8F35E94B40286211C30ED34240CD052E8F35E94B40
3989	1	37.393675999999999	37.458525999999999	55.730207999999998	55.727074999999999	улица Ивана Франко	0103000020E610000001000000050000002C9CA4F963B242409E5E29CB10DD4B402C9CA4F963B2424087A3AB7477DD4B40CF2EDFFAB0BA424087A3AB7477DD4B40CF2EDFFAB0BA42409E5E29CB10DD4B402C9CA4F963B242409E5E29CB10DD4B40
166	1	37.557250000000003	37.566305999999997	55.689917999999999	55.681457999999999	улица Ивана Бабушкина	0103000020E6100000010000000500000017D9CEF753C742407DCC07043AD74B4017D9CEF753C74240FB75A73B4FD84B40A8C30AB77CC84240FB75A73B4FD84B40A8C30AB77CC842407DCC07043AD74B4017D9CEF753C742407DCC07043AD74B40
12313	1	37.42483	37.434764999999999	55.731855000000003	55.729300000000002	улица Екатерины Будановой	0103000020E610000001000000050000000A2E56D460B64240857CD0B359DD4B400A2E56D460B642400135B56CADDD4B4004392861A6B742400135B56CADDD4B4004392861A6B74240857CD0B359DD4B400A2E56D460B64240857CD0B359DD4B40
5167	1	37.507950999999998	37.517150000000001	55.722937999999999	55.717720999999997	улица Довженко	0103000020E61000000100000005000000397CD28904C1424082531F48DEDB4B40397CD28904C1424090847D3B89DC4B402E90A0F831C2424090847D3B89DC4B402E90A0F831C2424082531F48DEDB4B40397CD28904C1424082531F48DEDB4B40
2272	1	37.563467000000003	37.571758000000003	55.725214000000001	55.721482999999999	улица Доватора	0103000020E6100000010000000500000008B0C8AF1FC842405BCF108E59DC4B4008B0C8AF1FC84240F94CF6CFD3DC4B40FA9CBB5D2FC94240F94CF6CFD3DC4B40FA9CBB5D2FC942405BCF108E59DC4B4008B0C8AF1FC842405BCF108E59DC4B40
38	1	37.556783000000003	37.595950000000002	55.694490000000002	55.679777999999999	улица Дмитрия Ульянова	0103000020E6100000010000000500000001FC53AA44C7424028452BF702D74B4001FC53AA44C7424014B35E0CE5D84B408E06F01648CC424014B35E0CE5D84B408E06F01648CC424028452BF702D74B4001FC53AA44C7424028452BF702D74B40
6711	1	37.584541000000002	37.625118000000001	55.872515999999997	55.857801000000002	улица Декабристов	0103000020E61000000100000005000000E8154F3DD2CA4240F1BC546CCCED4B40E8154F3DD2CA42404D9EB29AAEEF4B400A12DBDD03D042404D9EB29AAEEF4B400A12DBDD03D04240F1BC546CCCED4B40E8154F3DD2CA4240F1BC546CCCED4B40
3552	1	37.596246000000001	37.600333999999997	55.798752999999998	55.792549000000001	улица Двинцев	0103000020E61000000100000005000000772FF7C951CC42401FBDE13E72E54B40772FF7C951CC42407B4ACE893DE64B40A35698BED7CC42407B4ACE893DE64B40A35698BED7CC42401FBDE13E72E54B40772FF7C951CC42401FBDE13E72E54B40
4793	1	37.716459	37.728191000000002	55.693489999999997	55.669803000000002	улица Гурьянова	0103000020E6100000010000000500000062F6B2EDB4DB4240A0E1CD1ABCD54B4062F6B2EDB4DB4240300DC347C4D84B40EB1ED95C35DD4240300DC347C4D84B40EB1ED95C35DD4240A0E1CD1ABCD54B4062F6B2EDB4DB4240A0E1CD1ABCD54B40
1972	1	37.562443000000002	37.591862999999996	55.569301000000003	55.560184	улица Грина	0103000020E610000001000000050000009C6ED921FEC7424009DFFB1BB4C74B409C6ED921FEC74240414AECDADEC84B40315BB22AC2CB4240414AECDADEC84B40315BB22AC2CB424009DFFB1BB4C74B409C6ED921FEC7424009DFFB1BB4C74B40
5490	1	37.405704999999998	37.409872999999997	55.657026999999999	55.649886000000002	улица Главмосстроя	0103000020E610000001000000050000006E693524EEB342406B10E6762FD34B406E693524EEB3424064CBF27519D44B40B741EDB776B4424064CBF27519D44B40B741EDB776B442406B10E6762FD34B406E693524EEB342406B10E6762FD34B40
6608	1	37.405982999999999	37.439607000000002	55.858432999999998	55.850444000000003	улица Героев Панфиловцев	0103000020E61000000100000005000000B1DD3D40F7B342402B8A5759DBEC4B40B1DD3D40F7B342405167EE21E1ED4B40DD0BCC0A45B842405167EE21E1ED4B40DD0BCC0A45B842402B8A5759DBEC4B40B1DD3D40F7B342402B8A5759DBEC4B40
7245	1	37.460250000000002	37.465747999999998	55.789344999999997	55.778112	улица Генерала Глаголева	0103000020E61000000100000005000000F4FDD478E9BA424005508C2C99E34B40F4FDD478E9BA42406C21C84109E54B40B51666A19DBB42406C21C84109E54B40B51666A19DBB424005508C2C99E34B40F4FDD478E9BA424005508C2C99E34B40
4672	1	37.495832999999998	37.503891000000003	55.806975000000001	55.803655999999997	улица Врубеля	0103000020E6100000010000000500000087A3AB7477BF4240F99D2633DEE64B4087A3AB7477BF424045D8F0F44AE74B40D7DF12807FC0424045D8F0F44AE74B40D7DF12807FC04240F99D2633DEE64B4087A3AB7477BF4240F99D2633DEE64B40
256	1	37.647494999999999	37.656891999999999	55.754947999999999	55.752957000000002	улица Воронцово Поле	0103000020E6100000010000000500000069A9BC1DE1D24240AB251DE560E04B4069A9BC1DE1D242401E17D522A2E04B4084807C0915D442401E17D522A2E04B4084807C0915D44240AB251DE560E04B4069A9BC1DE1D24240AB251DE560E04B40
851	1	37.406253	37.433759000000002	55.865273000000002	55.855795000000001	улица Вилиса Лациса	0103000020E6100000010000000500000071732A1900B44240488AC8B08AED4B4071732A1900B44240508E0244C1EE4B403FAC376A85B74240508E0244C1EE4B403FAC376A85B74240488AC8B08AED4B4071732A1900B44240488AC8B08AED4B40
2972	1	37.741145000000003	37.838952999999997	55.669001000000002	55.656930000000003	улица Верхние Поля	0103000020E61000000100000005000000064CE0D6DDDE424072E1404816D44B40064CE0D6DDDE4240E3FE23D3A1D54B40C7F0D8CF62EB4240E3FE23D3A1D54B40C7F0D8CF62EB424072E1404816D44B40064CE0D6DDDE424072E1404816D44B40
1012	1	37.528621000000001	37.551070000000003	55.651394000000003	55.632443000000002	улица Введенского	0103000020E610000001000000050000004A7D59DAA9C34240C5CA68E4F3D04B404A7D59DAA9C34240C367EBE060D34B4043E7357689C64240C367EBE060D34B4043E7357689C64240C5CA68E4F3D04B404A7D59DAA9C34240C5CA68E4F3D04B40
6180	1	37.450628999999999	37.460762000000003	55.722669000000003	55.720925000000001	улица Ватутина	0103000020E6100000010000000500000089D00836AEB9424035EF384547DC4B4089D00836AEB94240A16AF46A80DC4B40AA9ECC3FFABA4240A16AF46A80DC4B40AA9ECC3FFABA424035EF384547DC4B4089D00836AEB9424035EF384547DC4B40
190	1	37.539796000000003	37.593514999999996	55.709870000000002	55.675564999999999	улица Вавилова	0103000020E610000001000000050000007D410B0918C542403FA9F6E978D64B407D410B0918C54240AD342905DDDA4B40BC57AD4CF8CB4240AD342905DDDA4B40BC57AD4CF8CB42403FA9F6E978D64B407D410B0918C542403FA9F6E978D64B40
792	1	37.522278999999997	37.551743999999999	55.654879000000001	55.641468000000003	улица Бутлерова	0103000020E610000001000000050000009C31CC09DAC242401CB7989F1BD24B409C31CC09DAC2424029EB3713D3D34B40D2E1218C9FC6424029EB3713D3D34B40D2E1218C9FC642401CB7989F1BD24B409C31CC09DAC242401CB7989F1BD24B40
4096	1	37.492581000000001	37.496640999999997	55.886347000000001	55.880701999999999	улица Бусиновская Горка	0103000020E61000000100000005000000C4D0EAE40CBF4240CAC2D7D7BAF04B40C4D0EAE40CBF424030F488D173F14B40266DAAEE91BF424030F488D173F14B40266DAAEE91BF4240CAC2D7D7BAF04B40C4D0EAE40CBF4240CAC2D7D7BAF04B40
12306	1	37.731560000000002	37.739905	55.776744999999998	55.764606999999998	улица Бориса Жигуленкова	0103000020E61000000100000005000000E88711C2A3DD424076A565A4DEE14B40E88711C2A3DD42406F2A52616CE34B40CD920035B5DE42406F2A52616CE34B40CD920035B5DE424076A565A4DEE14B40E88711C2A3DD424076A565A4DEE14B40
2721	1	37.645294	37.649759000000003	55.637900999999999	55.617896000000002	улица Бехтерева	0103000020E610000001000000050000000B2769FE98D24240242A543717CF4B400B2769FE98D24240F88A6EBDA6D14B400EA48B4D2BD34240F88A6EBDA6D14B400EA48B4D2BD34240242A543717CF4B400B2769FE98D24240242A543717CF4B40
146	1	37.633786999999998	37.637855999999999	55.737360000000002	55.731430000000003	улица Бахрушина	0103000020E61000000100000005000000A2D0B2EE1FD142401AA88C7F9FDD4B40A2D0B2EE1FD1424075B0FECF61DE4B4058C7F143A5D1424075B0FECF61DE4B4058C7F143A5D142401AA88C7F9FDD4B40A2D0B2EE1FD142401AA88C7F9FDD4B40
6332	1	37.342238999999999	37.372584000000003	55.861499000000002	55.839359999999999	улица Барышиха	0103000020E610000001000000050000003735D07CCEAB424008C9022670EB4B403735D07CCEAB4240B344679945EE4B40A6811FD5B0AF4240B344679945EE4B40A6811FD5B0AF424008C9022670EB4B403735D07CCEAB424008C9022670EB4B40
5853	1	37.492024000000001	37.516233	55.752941	55.736255	улица Барклая	0103000020E610000001000000050000006E6C76A4FABE42401C42959A3DDE4B406E6C76A4FABE4240A568E55E60E04B40D80E46EC13C24240A568E55E60E04B40D80E46EC13C242401C42959A3DDE4B406E6C76A4FABE42401C42959A3DDE4B40
1423	1	37.536329000000002	37.540326	55.756746	55.752045000000003	улица Антонова-Овсеенко	0103000020E61000000100000005000000BD72BD6DA6C44240670FB40243E04B40BD72BD6DA6C442407DB08C0DDDE04B40D996016729C542407DB08C0DDDE04B40D996016729C54240670FB40243E04B40BD72BD6DA6C44240670FB40243E04B40
6967	1	37.654646	37.659874000000002	55.856295000000003	55.847512999999999	улица Амундсена	0103000020E61000000100000005000000863AAC70CBD34240A9F7544E7BEC4B40863AAC70CBD342403A5D16139BED4B4088BD50C076D442403A5D16139BED4B4088BD50C076D44240A9F7544E7BEC4B40863AAC70CBD34240A9F7544E7BEC4B40
1645	1	37.524588000000001	37.544502999999999	55.673752	55.668197999999997	улица Академика Пилюгина	0103000020E61000000100000005000000E1EF17B325C3424055A0168387D54B40E1EF17B325C34240ABCE6A813DD64B4075C93846B2C54240ABCE6A813DD64B4075C93846B2C5424055A0168387D54B40E1EF17B325C3424055A0168387D54B40
3085	1	37.484963	37.54551	55.546812000000003	55.530836999999998	улица Адмирала Лазарева	0103000020E610000001000000050000009162804413BE4240DD408177F2C34B409162804413BE4240BA8784EFFDC54B400BD28C45D3C54240BA8784EFFDC54B400BD28C45D3C54240DD408177F2C34B409162804413BE4240DD408177F2C34B40
5552	1	37.388860999999999	37.416026000000002	55.647472999999998	55.639282999999999	улица Авиаторов	0103000020E610000001000000050000004DD87E32C6B14240C3F17C06D4D14B404DD87E32C6B1424081053065E0D24B409224085740B5424081053065E0D24B409224085740B54240C3F17C06D4D14B404DD87E32C6B14240C3F17C06D4D14B40
3210	1	37.847082999999998	37.859138000000002	55.689228	55.677753000000003	улица Авиаконструктора Миля	0103000020E61000000100000005000000B0FF3A376DEC424009E23C9CC0D64B40B0FF3A376DEC424066BE839F38D84B401C60E63BF8ED424066BE839F38D84B401C60E63BF8ED424009E23C9CC0D64B40B0FF3A376DEC424009E23C9CC0D64B40
5436	1	37.410178000000002	37.416080000000001	55.660103999999997	55.646425999999998	улица 50 лет Октября	0103000020E61000000100000005000000F4C473B680B442405DA45016BED24B40F4C473B680B44240B9FAB1497ED44B408542041C42B54240B9FAB1497ED44B408542041C42B542405DA45016BED24B40F4C473B680B442405DA45016BED24B40
76467	1	37.169348999999997	37.172851999999999	55.977404999999997	55.975138000000001	улица 2-я Пятилетка	0103000020E610000001000000050000001E4E603AAD9542401E8B6D52D1FC4B401E4E603AAD95424033F9669B1BFD4B402B86AB032096424033F9669B1BFD4B402B86AB03209642401E8B6D52D1FC4B401E4E603AAD9542401E8B6D52D1FC4B40
75071	1	37.169348999999997	37.172851999999999	55.977404999999997	55.975138000000001	улица 2-я Пятилетка	0103000020E610000001000000050000001E4E603AAD9542401E8B6D52D1FC4B401E4E603AAD95424033F9669B1BFD4B402B86AB032096424033F9669B1BFD4B402B86AB03209642401E8B6D52D1FC4B401E4E603AAD9542401E8B6D52D1FC4B40
74879	1	37.131233000000002	37.205255000000001	56.021296	55.980466999999997	район Силино	0103000020E61000000100000005000000F793313ECC90424053E751F17FFD4B40F793313ECC9042408FC4CBD3B9024C40952BBCCB459A42408FC4CBD3B9024C40952BBCCB459A424053E751F17FFD4B40F793313ECC90424053E751F17FFD4B40
76444	1	37.144466000000001	37.220050000000001	55.999329000000003	55.947777000000002	район Крюково	0103000020E6100000010000000500000025B1A4DC7D9242405473B9C150F94B4025B1A4DC7D924240E2783E03EAFF4B400EBE30992A9C4240E2783E03EAFF4B400EBE30992A9C42405473B9C150F94B4025B1A4DC7D9242405473B9C150F94B40
6576	1	37.632142999999999	37.670518999999999	55.846234000000003	55.772846000000001	проспект Мира	0103000020E610000001000000050000009AB2D30FEAD04240166C239EECE24B409AB2D30FEAD04240B3614D6551EC4B405E2C0C91D3D54240B3614D6551EC4B405E2C0C91D3D54240166C239EECE24B409AB2D30FEAD04240166C239EECE24B40
7049	1	37.367392000000002	37.503413999999999	55.790798000000002	55.772148000000001	проспект Маршала Жукова	0103000020E61000000100000005000000F16778B306AF4240FED5E3BED5E24B40F16778B306AF424001DF6DDE38E54B409D2CB5DE6FC0424001DF6DDE38E54B409D2CB5DE6FC04240FED5E3BED5E24B40F16778B306AF4240FED5E3BED5E24B40
1452	1	37.479367000000003	37.554060999999997	55.706415999999997	55.648453000000003	проспект Вернадского	0103000020E610000001000000050000000DE4D9E55BBD42401EFF058200D34B400DE4D9E55BBD424081AFE8D66BDA4B40997E8978EBC6424081AFE8D66BDA4B40997E8978EBC642401EFF058200D34B400DE4D9E55BBD42401EFF058200D34B40
12311	1	37.720447	37.741422999999998	55.779817999999999	55.756194000000001	проспект Буденного	0103000020E610000001000000050000002BC0779B37DC424039B709F7CAE04B402BC0779B37DC4240836A8313D1E34B4048C0E8F2E6DE4240836A8313D1E34B4048C0E8F2E6DE424039B709F7CAE04B402BC0779B37DC424039B709F7CAE04B40
6686	1	37.652535	37.667591000000002	55.703052999999997	55.650820000000003	проспект Андропова	0103000020E61000000100000005000000683F524486D3424097CADB114ED34B40683F524486D34240662D05A4FDD94B404E0D349F73D54240662D05A4FDD94B404E0D349F73D5424097CADB114ED34B40683F524486D3424097CADB114ED34B40
12312	1	37.717959	37.722109000000003	55.763821999999998	55.752389000000001	проезд Энтузиастов	0103000020E61000000100000005000000376F9C14E6DB4240616F62484EE04B40376F9C14E6DB42408FFB56EBC4E14B40DA9255116EDC42408FFB56EBC4E14B40DA9255116EDC4240616F62484EE04B40376F9C14E6DB4240616F62484EE04B40
7206	1	37.644854000000002	37.677553000000003	55.885765999999997	55.871698000000002	проезд Шокальского	0103000020E61000000100000005000000EF586C938AD242408BFED0CC93EF4B40EF586C938AD2424051F4C0C760F14B404227840EBAD6424051F4C0C760F14B404227840EBAD642408BFED0CC93EF4B40EF586C938AD242408BFED0CC93EF4B40
4175	1	37.509827999999999	37.555821999999999	55.847299999999997	55.832079999999998	проезд Черепановых	0103000020E61000000100000005000000E44A3D0B42C14240EDD3F19881EA4B40E44A3D0B42C142404DF38E5374EC4B40DB32E02C25C742404DF38E5374EC4B40DB32E02C25C74240EDD3F19881EA4B40E44A3D0B42C14240EDD3F19881EA4B40
6586	1	37.428674999999998	37.442805	55.828606999999998	55.825785000000003	проезд Стратонавтов	0103000020E6100000010000000500000070CE88D2DEB642408143A852B3E94B4070CE88D2DEB642404B1E4FCB0FEA4B40ADC090D5ADB842404B1E4FCB0FEA4B40ADC090D5ADB842408143A852B3E94B4070CE88D2DEB642408143A852B3E94B40
3435	1	37.533445	37.547279000000003	55.596834000000001	55.588486000000003	проезд Карамзина	0103000020E610000001000000050000007C9BFEEC47C44240B2135E8253CB4B407C9BFEEC47C442400892770E65CC4B40D064FF3C0DC642400892770E65CC4B40D064FF3C0DC64240B2135E8253CB4B407C9BFEEC47C44240B2135E8253CB4B40
2113	1	37.575566999999999	37.583292999999998	55.737588000000002	55.736939	проезд Девичьего Поля	0103000020E6100000010000000500000013D4F02DACC94240CF12640454DE4B4013D4F02DACC9424006F6984869DE4B402C7E5358A9CA424006F6984869DE4B402C7E5358A9CA4240CF12640454DE4B4013D4F02DACC94240CF12640454DE4B40
5332	1	37.521011999999999	37.525657000000002	55.797012000000002	55.795084000000003	проезд Аэропорта	0103000020E610000001000000050000006A696E85B0C2424054C90050C5E54B406A696E85B0C2424081423D7D04E64B40EDF483BA48C3424081423D7D04E64B40EDF483BA48C3424054C90050C5E54B406A696E85B0C2424054C90050C5E54B40
12377	1	37.182743000000002	37.964969000000004	56.010739999999998	55.490667000000002	поселок Акуловского гидроузла	0103000020E610000001000000050000005649641F64974240FC1C1F2DCEBE4B405649641F649742402861A6ED5F014C40B153AC1A84FB42402861A6ED5F014C40B153AC1A84FB4240FC1C1F2DCEBE4B405649641F64974240FC1C1F2DCEBE4B40
1054	1	37.581800999999999	37.585636999999998	55.777797999999997	55.775281999999997	площадь Тверская Застава	0103000020E61000000100000005000000DAE3857478CA4240B796C9703CE34B40DAE3857478CA4240757286E28EE34B40ED293927F6CA4240757286E28EE34B40ED293927F6CA4240B796C9703CE34B40DAE3857478CA4240B796C9703CE34B40
2221	1	37.575352000000002	37.581567999999997	55.733741000000002	55.726897999999998	переулок Хользунова	0103000020E6100000010000000500000017D86322A5C942408FC360FE0ADD4B4017D86322A5C94240FF5D9F39EBDD4B403733FAD170CA4240FF5D9F39EBDD4B403733FAD170CA42408FC360FE0ADD4B4017D86322A5C942408FC360FE0ADD4B40
185	1	37.640146999999999	37.644602999999996	55.766424999999998	55.765006999999997	переулок Огородная Слобода	0103000020E61000000100000005000000F6D03E56F0D14240041BD7BFEBE14B40F6D03E56F0D142401CEBE2361AE24B40A5F3E15982D242401CEBE2361AE24B40A5F3E15982D24240041BD7BFEBE14B40F6D03E56F0D14240041BD7BFEBE14B40
120	1	37.582915	37.587389000000002	55.750427999999999	55.74944	переулок Каменная Слобода	0103000020E6100000010000000500000086AC6EF59CCA4240392861A6EDDF4B4086AC6EF59CCA4240580053060EE04B40DC8310902FCB4240580053060EE04B40DC8310902FCB4240392861A6EDDF4B4086AC6EF59CCA4240392861A6EDDF4B40
920	1	37.448177000000001	37.448940999999998	55.789011000000002	55.779544999999999	набережная Новикова-Прибоя	0103000020E61000000100000005000000E2E82ADD5DB9424052616C21C8E34B40E2E82ADD5DB942409697FC4FFEE44B40B16A10E676B942409697FC4FFEE44B40B16A10E676B9424052616C21C8E34B40E2E82ADD5DB9424052616C21C8E34B40
6727	1	37.402614	37.439607000000002	55.850656000000001	55.848709999999997	бульвар Яна Райниса	0103000020E61000000100000005000000B47405DB88B34240E2E47E87A2EC4B40B47405DB88B34240B612BA4BE2EC4B40DD0BCC0A45B84240B612BA4BE2EC4B40DD0BCC0A45B84240E2E47E87A2EC4B40B47405DB88B34240E2E47E87A2EC4B40
4159	1	37.524776000000003	37.532330999999999	55.838318999999998	55.825051999999999	бульвар Матроса Железняка	0103000020E61000000100000005000000E4DC26DC2BC34240ECBFCE4D9BE94B40E4DC26DC2BC34240C64E78094EEB4B40D0D2156C23C44240C64E78094EEB4B40D0D2156C23C44240ECBFCE4D9BE94B40E4DC26DC2BC34240ECBFCE4D9BE94B40
7633	1	37.712505999999998	37.725810000000003	55.818210000000001	55.811245	бульвар Маршала Рокоссовского	0103000020E61000000100000005000000151A886533DB424092054CE0D6E74B40151A886533DB42404DA1F31ABBE84B400D8E9257E7DC42404DA1F31ABBE84B400D8E9257E7DC424092054CE0D6E74B40151A886533DB424092054CE0D6E74B40
1888	1	37.570760999999997	37.579385000000002	55.57779	55.56221	бульвар Дмитрия Донского	0103000020E61000000100000005000000876A4AB20EC94240F9BD4D7FF6C74B40876A4AB20EC9424059FAD005F5C94B408065A54929CA424059FAD005F5C94B408065A54929CA4240F9BD4D7FF6C74B40876A4AB20EC94240F9BD4D7FF6C74B40
7177	1	37.467768999999997	37.472935	55.784359000000002	55.776629	бульвар Генерала Карбышева	0103000020E61000000100000005000000938AC6DADFBB424006103E9468E34B40938AC6DADFBB424061A92EE065E44B401F11532289BC424061A92EE065E44B401F11532289BC424006103E9468E34B40938AC6DADFBB424006103E9468E34B40
7814	1	37.812308999999999	37.829799000000001	55.733725999999997	55.731124999999999	аллея Жемчуговой	0103000020E610000001000000050000008C9FC6BDF9E74240DD24068195DD4B408C9FC6BDF9E74240C91CCBBBEADD4B4073A087DA36EA4240C91CCBBBEADD4B4073A087DA36EA4240DD24068195DD4B408C9FC6BDF9E74240DD24068195DD4B40
12352	1	37.538817000000002	37.542752	55.551492000000003	55.546154000000001	аллея Витте	0103000020E61000000100000005000000B1C398F4F7C44240304AD05FE8C54B40B1C398F4F7C44240B900344A97C64B4057EBC4E578C54240B900344A97C64B4057EBC4E578C54240304AD05FE8C54B40B1C398F4F7C44240304AD05FE8C54B40
7585	1	37.673645	37.693956	55.830806000000003	55.829996999999999	Яузская аллея	0103000020E61000000100000005000000950ED6FF39D64240996379573DEA4B40950ED6FF39D6424009A9DBD957EA4B40766EDA8CD3D8424009A9DBD957EA4B40766EDA8CD3D84240996379573DEA4B40950ED6FF39D64240996379573DEA4B40
7271	1	37.619278999999999	37.632359000000001	55.879717999999997	55.870359000000001	Ясный проезд	0103000020E61000000100000005000000BF0CC68844CF4240BF6378EC67EF4B40BF0CC68844CF4240ECD973999AF04B40672AC423F1D04240ECD973999AF04B40672AC423F1D04240BF6378EC67EF4B40BF0CC68844CF4240BF6378EC67EF4B40
12442	1	37.712857	37.744692999999998	55.613987000000002	55.599193999999997	Ясеневая улица	0103000020E61000000100000005000000C2DCEEE53EDB4240CEFA9463B2CC4B40C2DCEEE53EDB4240A795422097CE4B40B247A81952DF4240A795422097CE4B40B247A81952DF4240CEFA9463B2CC4B40C2DCEEE53EDB4240CEFA9463B2CC4B40
12426	1	37.712857	37.744692999999998	55.613987000000002	55.599193999999997	Ясеневая 	0103000020E61000000100000005000000C2DCEEE53EDB4240CEFA9463B2CC4B40C2DCEEE53EDB4240A795422097CE4B40B247A81952DF4240A795422097CE4B40B247A81952DF4240CEFA9463B2CC4B40C2DCEEE53EDB4240CEFA9463B2CC4B40
12428	1	37.712857	37.744692999999998	55.613987000000002	55.599193999999997	Ясеневая	0103000020E61000000100000005000000C2DCEEE53EDB4240CEFA9463B2CC4B40C2DCEEE53EDB4240A795422097CE4B40B247A81952DF4240A795422097CE4B40B247A81952DF4240CEFA9463B2CC4B40C2DCEEE53EDB4240CEFA9463B2CC4B40
4188	1	37.405695999999999	37.421838000000001	55.744636999999997	55.733913000000001	Ярцевская улица	0103000020E610000001000000050000001B0FB6D8EDB34240FC8D76DCF0DD4B401B0FB6D8EDB342401E32E54350DF4B40E31A9FC9FEB542401E32E54350DF4B40E31A9FC9FEB54240FC8D76DCF0DD4B401B0FB6D8EDB34240FC8D76DCF0DD4B40
7381	1	37.670473999999999	37.732160999999998	55.885750999999999	55.845992000000003	Ярославское шоссе	0103000020E61000000100000005000000BE688F17D2D54240BD56427749EC4B40BE688F17D2D542401CB3EC4960F14B400D349F73B7DD42401CB3EC4960F14B400D349F73B7DD4240BD56427749EC4B40BE688F17D2D54240BD56427749EC4B40
5520	1	37.646247000000002	37.653827999999997	55.827311999999999	55.813192000000001	Ярославская улица	0103000020E61000000100000005000000AE11C138B8D2424036AFEAAC16E84B40AE11C138B8D242404FCB0F5CE5E94B40C39ACAA2B0D342404FCB0F5CE5E94B40C39ACAA2B0D3424036AFEAAC16E84B40AE11C138B8D2424036AFEAAC16E84B40
12503	1	37.646247000000002	37.653827999999997	55.827311999999999	55.813192000000001	Ярославская	0103000020E61000000100000005000000AE11C138B8D2424036AFEAAC16E84B40AE11C138B8D242404FCB0F5CE5E94B40C39ACAA2B0D342404FCB0F5CE5E94B40C39ACAA2B0D3424036AFEAAC16E84B40AE11C138B8D2424036AFEAAC16E84B40
6316	1	37.678334	37.691279000000002	55.873981000000001	55.865495000000003	Янтарный проезд	0103000020E61000000100000005000000E7E104A6D3D64240FFEC478AC8EE4B40E7E104A6D3D64240A629029CDEEF4B40AFB48CD47BD84240A629029CDEEF4B40AFB48CD47BD84240FFEC478AC8EE4B40E7E104A6D3D64240FFEC478AC8EE4B40
12901	1	37.680436	37.687964000000001	55.688918000000001	55.680925000000002	Якорная	0103000020E61000000100000005000000B282DF8618D74240B003E78C28D74B40B282DF8618D7424018D00B772ED84B40A56950340FD8424018D00B772ED84B40A56950340FD84240B003E78C28D74B40B282DF8618D74240B003E78C28D74B40
13098	1	37.579008000000002	37.583077000000003	55.828465000000001	55.812002999999997	Яблочкова	0103000020E61000000100000005000000AA0F24EF1CCA42407FA0DCB6EFE74B40AA0F24EF1CCA4240B97020240BEA4B4060066344A2CA4240B97020240BEA4B4060066344A2CA42407FA0DCB6EFE74B40AA0F24EF1CCA42407FA0DCB6EFE74B40
12823	1	37.369	37.399496999999997	55.899577999999998	55.897983000000004	Юровская 	0103000020E61000000100000005000000AC1C5A643BAF424097AE601BF1F24B40AC1C5A643BAF4240BD19355F25F34B40D0ECBAB722B34240BD19355F25F34B40D0ECBAB722B3424097AE601BF1F24B40AC1C5A643BAF424097AE601BF1F24B40
12521	1	37.732861999999997	37.791342	55.701227000000003	55.696762999999997	Юных Ленинцев	0103000020E61000000100000005000000963D096CCEDD42400B08AD872FD94B40963D096CCEDD42403E096CCEC1D94B40C2F9D4B14AE542403E096CCEC1D94B40C2F9D4B14AE542400B08AD872FD94B40963D096CCEDD42400B08AD872FD94B40
2955	1	37.510646000000001	37.546812000000003	55.545110000000001	55.528156000000003	Южнобутовская улица	0103000020E61000000100000005000000A7EA1ED95CC14240D597A59D9AC34B40A7EA1ED95CC142407D5C1B2AC6C54B40BA8784EFFDC542407D5C1B2AC6C54B40BA8784EFFDC54240D597A59D9AC34B40A7EA1ED95CC14240D597A59D9AC34B40
12967	1	37.510646000000001	37.546812000000003	55.545110000000001	55.528156000000003	Южнобутовская	0103000020E61000000100000005000000A7EA1ED95CC14240D597A59D9AC34B40A7EA1ED95CC142407D5C1B2AC6C54B40BA8784EFFDC542407D5C1B2AC6C54B40BA8784EFFDC54240D597A59D9AC34B40A7EA1ED95CC14240D597A59D9AC34B40
3711	1	37.706110000000002	37.710189	55.758629999999997	55.755023000000001	Энергетический проезд	0103000020E6100000010000000500000075B0FECF61DA4240295DFA97A4E04B4075B0FECF61DA4240DAE1AFC91AE14B404E7D2079E7DA4240DAE1AFC91AE14B404E7D2079E7DA4240295DFA97A4E04B4075B0FECF61DA4240295DFA97A4E04B40
13018	1	37.698411999999998	37.716028000000001	55.762833999999998	55.756624000000002	Энергетическая	0103000020E6100000010000000500000025917D9065D9424032AF230ED9E04B4025917D9065D942407023658BA4E14B40998235CEA6DB42407023658BA4E14B40998235CEA6DB424032AF230ED9E04B4025917D9065D9424032AF230ED9E04B40
5604	1	37.653945	37.670824000000003	55.602001000000001	55.601711000000002	Элеваторная улица	0103000020E61000000100000005000000FD304278B4D342405D52B5DD04CD4B40FD304278B4D342406494675E0ECD4B409BAF928FDDD542406494675E0ECD4B409BAF928FDDD542405D52B5DD04CD4B40FD304278B4D342405D52B5DD04CD4B40
12596	1	37.464877000000001	37.483885000000001	55.808912999999997	55.808112999999999	Щукинская	0103000020E61000000100000005000000D0D4EB1681BB4240793C2D3F70E74B40D0D4EB1681BB4240952710768AE74B40320395F1EFBD4240952710768AE74B40320395F1EFBD4240793C2D3F70E74B40D0D4EB1681BB4240793C2D3F70E74B40
12892	1	37.403252000000002	37.408659999999998	55.648687000000002	55.642997000000001	Щорса	0103000020E61000000100000005000000F705F4C29DB342408B36C7B94DD24B40F705F4C29DB34240912BF52C08D34B4078978BF84EB44240912BF52C08D34B4078978BF84EB442408B36C7B94DD24B40F705F4C29DB342408B36C7B94DD24B40
12330	1	37.718687000000003	37.746364	55.783296	55.782142	Щербаковская	0103000020E61000000100000005000000BA8784EFFDDB4240FD69A33A1DE44B40BA8784EFFDDB4240378B170B43E44B40B47405DB88DF4240378B170B43E44B40B47405DB88DF4240FD69A33A1DE44B40BA8784EFFDDB4240FD69A33A1DE44B40
2044	1	37.747334000000002	37.838997999999997	55.813980999999998	55.801454999999997	Щелковское шоссе	0103000020E610000001000000050000002D98F8A3A8DF42409B1BD31396E64B402D98F8A3A8DF42405E48878730E84B4067B4554964EB42405E48878730E84B4067B4554964EB42409B1BD31396E64B402D98F8A3A8DF42409B1BD31396E64B40
8161	1	37.577506999999997	37.579762000000002	55.746471	55.745904000000003	Шубинский переулок	0103000020E61000000100000005000000041BD7BFEBC9424051FA42C879DF4B40041BD7BFEBC94240CA349A5C8CDF4B4056BB26A435CA4240CA349A5C8CDF4B4056BB26A435CA424051FA42C879DF4B40041BD7BFEBC9424051FA42C879DF4B40
7635	1	37.445310999999997	37.447431000000002	55.849922999999997	55.843677	Штурвальная улица	0103000020E6100000010000000500000047C66AF3FFB8424096B1A19BFDEB4B4047C66AF3FFB84240218FE046CAEC4B40B91B446B45B94240218FE046CAEC4B40B91B446B45B9424096B1A19BFDEB4B4047C66AF3FFB8424096B1A19BFDEB4B40
12834	1	37.701627999999999	37.730877	55.712218	55.650692999999997	Шоссейная	0103000020E610000001000000050000009CFA40F2CED94240395E81E849D34B409CFA40F2CED94240AFCF9CF529DB4B400533A6608DDD4240AFCF9CF529DB4B400533A6608DDD4240395E81E849D34B409CFA40F2CED94240395E81E849D34B40
13022	1	37.339652000000001	37.360168999999999	55.645527000000001	55.634883000000002	Шолохова	0103000020E61000000100000005000000B0027CB779AB4240A8E49CD843D14B40B0027CB779AB4240AED7F4A0A0D24B403A048E041AAE4240AED7F4A0A0D24B403A048E041AAE4240A8E49CD843D14B40B0027CB779AB4240A8E49CD843D14B40
1409	1	37.519171	37.558031999999997	55.758969999999998	55.754162000000001	Шмитовский проезд	0103000020E610000001000000050000000C04013274C2424067F1626188E04B400C04013274C242409352D0ED25E14B408C0FB3976DC742409352D0ED25E14B408C0FB3976DC7424067F1626188E04B400C04013274C2424067F1626188E04B40
12550	1	37.734909999999999	37.755139999999997	55.694336999999997	55.692596999999999	Шкулева	0103000020E610000001000000050000006EC0E78711DE42406327BC04A7D84B406EC0E78711DE42408DB3E908E0D84B4062F3716DA8E042408DB3E908E0D84B4062F3716DA8E042406327BC04A7D84B406EC0E78711DE42406327BC04A7D84B40
13030	1	37.621901999999999	37.681362	55.890946	55.886958	Широкая 	0103000020E6100000010000000500000093A8177C9ACF42407976F9D687F14B4093A8177C9ACF42404240BE840AF24B405B5EB9DE36D742404240BE840AF24B405B5EB9DE36D742407976F9D687F14B4093A8177C9ACF42407976F9D687F14B40
12943	1	37.621901999999999	37.681362	55.890946	55.886958	Широкая	0103000020E6100000010000000500000093A8177C9ACF42407976F9D687F14B4093A8177C9ACF42404240BE840AF24B405B5EB9DE36D742404240BE840AF24B405B5EB9DE36D742407976F9D687F14B4093A8177C9ACF42407976F9D687F14B40
12423	1	37.691772999999998	37.718462000000002	55.636111999999997	55.595379000000001	Шипиловский проезд	0103000020E61000000100000005000000BEA085048CD84240D3DC0A6135CC4B40BEA085048CD84240EC4B361E6CD14B409AB51490F6DB4240EC4B361E6CD14B409AB51490F6DB4240D3DC0A6135CC4B40BEA085048CD84240D3DC0A6135CC4B40
6380	1	37.694262000000002	37.753999999999998	55.624459000000002	55.617260999999999	Шипиловская улица	0103000020E61000000100000005000000836DC493DDD84240520C906802CF4B40836DC493DDD84240B058C345EECF4B408D976E1283E04240B058C345EECF4B408D976E1283E04240520C906802CF4B40836DC493DDD84240520C906802CF4B40
12497	1	37.694262000000002	37.753999999999998	55.624459000000002	55.617260999999999	Шипиловская	0103000020E61000000100000005000000836DC493DDD84240520C906802CF4B40836DC493DDD84240B058C345EECF4B408D976E1283E04240B058C345EECF4B408D976E1283E04240520C906802CF4B40836DC493DDD84240520C906802CF4B40
12582	1	37.700324999999999	37.703055999999997	55.748387000000001	55.744708000000003	Шепелюгинская	0103000020E610000001000000050000001DC9E53FA4D94240E8887C9752DF4B401DC9E53FA4D9424033E02C25CBDF4B40D7A02FBDFDD9424033E02C25CBDF4B40D7A02FBDFDD94240E8887C9752DF4B401DC9E53FA4D94240E8887C9752DF4B40
5990	1	37.590865000000001	37.591090000000001	55.898048000000003	55.889643999999997	Шенкурский проезд	0103000020E61000000100000005000000EFACDD76A1CB4240938AC6DADFF14B40EFACDD76A1CB42407E1EA33CF3F24B400F7F4DD6A8CB42407E1EA33CF3F24B400F7F4DD6A8CB4240938AC6DADFF14B40EFACDD76A1CB4240938AC6DADFF14B40
12689	1	37.576231999999997	37.596552000000003	55.693896000000002	55.688755999999998	Шверника	0103000020E610000001000000050000004F745DF8C1C942403E76172829D84B404F745DF8C1C94240A1698995D1D84B40842EE1D05BCC4240A1698995D1D84B40842EE1D05BCC42403E76172829D84B404F745DF8C1C942403E76172829D84B40
12988	1	37.764510000000001	37.770825000000002	55.730212999999999	55.727317999999997	Шатурская	0103000020E6100000010000000500000084BBB376DBE1424064E597C118DD4B4084BBB376DBE14240990E9D9E77DD4B4038F8C264AAE24240990E9D9E77DD4B4038F8C264AAE2424064E597C118DD4B4084BBB376DBE1424064E597C118DD4B40
7010	1	37.598348000000001	37.619630000000001	55.653633999999997	55.653015000000003	Чонгарский бульвар	0103000020E6100000010000000500000042D0D1AA96CC42401366DAFE95D34B4042D0D1AA96CC4240DEC66647AAD34B406CCF2C0950CF4240DEC66647AAD34B406CCF2C0950CF42401366DAFE95D34B4042D0D1AA96CC42401366DAFE95D34B40
4503	1	37.343425000000003	37.358642000000003	55.647925000000001	55.641539000000002	Чоботовская улица	0103000020E610000001000000050000007DD0B359F5AB4240E50D30F31DD24B407DD0B359F5AB424062A1D634EFD24B406C7C26FBE7AD424062A1D634EFD24B406C7C26FBE7AD4240E50D30F31DD24B407DD0B359F5AB4240E50D30F31DD24B40
12634	1	37.343425000000003	37.358642000000003	55.647925000000001	55.641539000000002	Чоботовская	0103000020E610000001000000050000007DD0B359F5AB4240E50D30F31DD24B407DD0B359F5AB424062A1D634EFD24B406C7C26FBE7AD424062A1D634EFD24B406C7C26FBE7AD4240E50D30F31DD24B407DD0B359F5AB4240E50D30F31DD24B40
12748	1	37.819108999999997	37.837829999999997	55.782881000000003	55.778699000000003	Чечулина	0103000020E61000000100000005000000FC6D4F90D8E84240C636A968ACE34B40FC6D4F90D8E8424074D4D17135E44B40C8CD70033EEB424074D4D17135E44B40C8CD70033EEB4240C636A968ACE34B40FC6D4F90D8E84240C636A968ACE34B40
2913	1	37.516053999999997	37.548456000000002	55.543353000000003	55.52646	Чечерский проезд	0103000020E61000000100000005000000287CB60E0EC242407A53910A63C34B40287CB60E0EC242407D9752978CC54B40C2A563CE33C642407D9752978CC54B40C2A563CE33C642407A53910A63C34B40287CB60E0EC242407A53910A63C34B40
12348	1	37.587586999999999	37.605777000000003	55.641961000000002	55.595968999999997	Чертановская улица	0103000020E610000001000000050000000247020D36CB4240043752B648CC4B400247020D36CB42405B272EC72BD24B40A2D5C9198ACD42405B272EC72BD24B40A2D5C9198ACD4240043752B648CC4B400247020D36CB4240043752B648CC4B40
12319	1	37.587586999999999	37.605777000000003	55.641961000000002	55.595968999999997	Чертановская	0103000020E610000001000000050000000247020D36CB4240043752B648CC4B400247020D36CB42405B272EC72BD24B40A2D5C9198ACD42405B272EC72BD24B40A2D5C9198ACD4240043752B648CC4B400247020D36CB4240043752B648CC4B40
7036	1	37.596462000000002	37.619790999999999	55.647249000000002	55.644770000000001	Черноморский бульвар	0103000020E6100000010000000500000044A7E7DD58CC424091B8C7D287D24B4044A7E7DD58CC424032AF230ED9D24B4075ADBD4F55CF424032AF230ED9D24B4075ADBD4F55CF424091B8C7D287D24B4044A7E7DD58CC424091B8C7D287D24B40
13223	1	37.552515999999997	37.587093000000003	55.898764999999997	55.897680000000001	Череповецкая	0103000020E61000000100000005000000244223D8B8C64240FB22A12DE7F24B40244223D8B8C642400CE544BB0AF34B40F35A09DD25CB42400CE544BB0AF34B40F35A09DD25CB4240FB22A12DE7F24B40244223D8B8C64240FB22A12DE7F24B40
404	1	37.819432999999997	37.838414	55.779868999999998	55.775407999999999	Челябинская улица	0103000020E61000000100000005000000AF21382EE3E842404487C09140E34B40AF21382EE3E84240051555BFD2E34B401841632651EB4240051555BFD2E34B401841632651EB42404487C09140E34B40AF21382EE3E842404487C09140E34B40
13165	1	37.819432999999997	37.838414	55.779868999999998	55.775407999999999	Челябинская	0103000020E61000000100000005000000AF21382EE3E842404487C09140E34B40AF21382EE3E84240051555BFD2E34B401841632651EB4240051555BFD2E34B401841632651EB42404487C09140E34B40AF21382EE3E842404487C09140E34B40
12692	1	37.543902000000003	37.557493000000001	55.916395999999999	55.914881999999999	Челобитьевское шоссе	0103000020E61000000100000005000000501DAB949EC542407BD976DA1AF54B40501DAB949EC54240B517D1764CF54B40DD5F3DEE5BC74240B517D1764CF54B40DD5F3DEE5BC742407BD976DA1AF54B40501DAB949EC542407BD976DA1AF54B40
1140	1	37.517221999999997	37.537838000000001	55.811877000000003	55.806488999999999	Часовая улица	0103000020E61000000100000005000000C7629B5434C24240B8CA13083BE74B40C7629B5434C24240F3AFE595EBE74B40E54526E0D7C44240F3AFE595EBE74B40E54526E0D7C44240B8CA13083BE74B40C7629B5434C24240B8CA13083BE74B40
13191	1	37.645043000000001	37.650523	55.764668	55.761077	Чаплыгина	0103000020E61000000100000005000000C2C1DEC490D24240705E9CF86AE14B40C2C1DEC490D242401C261AA4E0E14B40DD25715644D342401C261AA4E0E14B40DD25715644D34240705E9CF86AE14B40C2C1DEC490D24240705E9CF86AE14B40
4747	1	37.518056999999999	37.520204	55.803221000000001	55.795847999999999	Чапаевский переулок	0103000020E61000000100000005000000603B18B14FC24240234BE658DEE54B40603B18B14FC24240EF3A1BF2CFE64B40CB9F6F0B96C24240EF3A1BF2CFE64B40CB9F6F0B96C24240234BE658DEE54B40603B18B14FC24240234BE658DEE54B40
12767	1	37.564211999999998	37.580077000000003	55.672142999999998	55.666837999999998	Цюрупы	0103000020E6100000010000000500000060014C1938C8424072DD94F25AD54B4060014C1938C842401F9E25C808D64B40B61490F63FCA42401F9E25C808D64B40B61490F63FCA424072DD94F25AD54B4060014C1938C8424072DD94F25AD54B40
13202	1	37.270868	37.305857000000003	55.621043	55.600369000000001	Центральная	0103000020E6100000010000000500000037C478CDABA24240204432E4D8CC4B4037C478CDABA24240723447567ECF4B4058207A5226A74240723447567ECF4B4058207A5226A74240204432E4D8CC4B4037C478CDABA24240204432E4D8CC4B40
3488	1	37.503379000000002	37.555553000000003	55.778202999999998	55.773307000000003	Хорошевское шоссе	0103000020E61000000100000005000000213F1BB96EC042404A6249B9FBE24B40213F1BB96EC042401553E9279CE34B40EC18575C1CC742401553E9279CE34B40EC18575C1CC742404A6249B9FBE24B40213F1BB96EC042404A6249B9FBE24B40
5355	1	37.521911000000003	37.545724999999997	55.794486999999997	55.784829999999999	Ходынский бульвар	0103000020E610000001000000050000001A36CAFACDC24240B875374F75E44B401A36CAFACDC242406F0C01C0B1E54B4007CE1951DAC542406F0C01C0B1E54B4007CE1951DAC54240B875374F75E44B401A36CAFACDC24240B875374F75E44B40
13157	1	37.800711999999997	37.820610000000002	55.721198999999999	55.711463000000002	Хлобыстова	0103000020E61000000100000005000000E3C116BB7DE6424033A8363811DB4B40E3C116BB7DE642403674B33F50DC4B40A2629CBF09E942403674B33F50DC4B40A2629CBF09E9424033A8363811DB4B40E3C116BB7DE6424033A8363811DB4B40
801	1	37.682448999999998	37.690137999999997	55.864434000000003	55.857579000000001	Хибинский проезд	0103000020E610000001000000050000000D18247D5AD74240425E0F26C5ED4B400D18247D5AD7424076C6F7C5A5EE4B4009DD257156D8424076C6F7C5A5EE4B4009DD257156D84240425E0F26C5ED4B400D18247D5AD74240425E0F26C5ED4B40
2593	1	37.559631000000003	37.578648000000001	55.659408999999997	55.649616000000002	Херсонская улица	0103000020E61000000100000005000000F56915FDA1C74240AB7AF99D26D34B40F56915FDA1C7424012D89C8367D44B40AAF23D2311CA424012D89C8367D44B40AAF23D2311CA4240AB7AF99D26D34B40F56915FDA1C74240AB7AF99D26D34B40
12663	1	37.559631000000003	37.578648000000001	55.659408999999997	55.649616000000002	Херсонская	0103000020E61000000100000005000000F56915FDA1C74240AB7AF99D26D34B40F56915FDA1C7424012D89C8367D44B40AAF23D2311CA424012D89C8367D44B40AAF23D2311CA4240AB7AF99D26D34B40F56915FDA1C74240AB7AF99D26D34B40
3097	1	37.847397000000001	37.854053999999998	55.700263	55.696097999999999	Хвалынский бульвар	0103000020E6100000010000000500000040DD408177EC4240CF6740BD19D94B4040DD408177EC4240A7CCCD37A2D94B404D8237A451ED4240A7CCCD37A2D94B404D8237A451ED4240CF6740BD19D94B4040DD408177EC4240CF6740BD19D94B40
5852	1	37.638755000000003	37.649867	55.597667999999999	55.587743000000003	Харьковский проезд	0103000020E6100000010000000500000008944DB9C2D14240FAB9A1293BCB4B4008944DB9C2D14240D0EE906280CC4B40F4DF83D72ED34240D0EE906280CC4B40F4DF83D72ED34240FAB9A1293BCB4B4008944DB9C2D14240FAB9A1293BCB4B40
12770	1	37.548932000000001	37.577516000000003	55.727576999999997	55.715255999999997	Хамовнический Вал	0103000020E610000001000000050000002BDD5D6743C64240462234828DDB4B402BDD5D6743C6424030293E3E21DD4B405875560BECC9424030293E3E21DD4B405875560BECC94240462234828DDB4B402BDD5D6743C64240462234828DDB4B40
1934	1	37.724857999999998	37.729061999999999	55.806631000000003	55.798313	Халтуринская улица	0103000020E610000001000000050000003A1F9E25C8DC42405F7CD11E2FE64B403A1F9E25C8DC42404B7842AF3FE74B40D06053E751DD42404B7842AF3FE74B40D06053E751DD42405F7CD11E2FE64B403A1F9E25C8DC42405F7CD11E2FE64B40
12951	1	37.724857999999998	37.729061999999999	55.806631000000003	55.798313	Халтуринская	0103000020E610000001000000050000003A1F9E25C8DC42405F7CD11E2FE64B403A1F9E25C8DC42404B7842AF3FE74B40D06053E751DD42404B7842AF3FE74B40D06053E751DD42405F7CD11E2FE64B403A1F9E25C8DC42405F7CD11E2FE64B40
6104	1	37.613548000000002	37.617635	55.720261000000001	55.711803000000003	Хавская улица	0103000020E610000001000000050000005B43A9BD88CE4240EC18575C1CDB4B405B43A9BD88CE4240C9CA2F8331DC4B40B7EEE6A90ECF4240C9CA2F8331DC4B40B7EEE6A90ECF4240EC18575C1CDB4B405B43A9BD88CE4240EC18575C1CDB4B40
13077	1	37.613548000000002	37.617635	55.720261000000001	55.711803000000003	Хавская	0103000020E610000001000000050000005B43A9BD88CE4240EC18575C1CDB4B405B43A9BD88CE4240C9CA2F8331DC4B40B7EEE6A90ECF4240C9CA2F8331DC4B40B7EEE6A90ECF4240EC18575C1CDB4B405B43A9BD88CE4240EC18575C1CDB4B40
12539	1	37.82432	37.830185999999998	55.830537999999997	55.812742	Хабаровская	0103000020E6100000010000000500000028B8585183E94240F60A0BEE07E84B4028B8585183E94240E90AB6114FEA4B406CCCEB8843EA4240E90AB6114FEA4B406CCCEB8843EA4240F60A0BEE07E84B4028B8585183E94240F60A0BEE07E84B40
1357	1	37.809165	37.831218999999997	55.749451000000001	55.743309000000004	Фрязевская улица	0103000020E61000000100000005000000AF08FEB792E7424047E9D2BF24DF4B40AF08FEB792E742402D7AA702EEDF4B402B685A6265EA42402D7AA702EEDF4B402B685A6265EA424047E9D2BF24DF4B40AF08FEB792E7424047E9D2BF24DF4B40
13186	1	37.809165	37.831218999999997	55.749451000000001	55.743309000000004	Фрязевская	0103000020E61000000100000005000000AF08FEB792E7424047E9D2BF24DF4B40AF08FEB792E742402D7AA702EEDF4B402B685A6265EA42402D7AA702EEDF4B402B685A6265EA424047E9D2BF24DF4B40AF08FEB792E7424047E9D2BF24DF4B40
2252	1	37.577139000000003	37.597575999999997	55.734425000000002	55.715255999999997	Фрунзенская набережная	0103000020E61000000100000005000000821FD5B0DFC94240462234828DDB4B40821FD5B0DFC94240B22E6EA301DE4B40EF6FD05E7DCC4240B22E6EA301DE4B40EF6FD05E7DCC4240462234828DDB4B40821FD5B0DFC94240462234828DDB4B40
1975	1	37.605670000000003	37.619323999999999	55.662770000000002	55.659652999999999	Фруктовая улица	0103000020E610000001000000050000008C15359886CD4240A9DA6E826FD44B408C15359886CD42408D62B9A5D5D44B405FD0420246CF42408D62B9A5D5D44B405FD0420246CF4240A9DA6E826FD44B408C15359886CD4240A9DA6E826FD44B40
13034	1	37.554681000000002	37.566800000000001	55.701886000000002	55.696224999999998	Фотиевой	0103000020E61000000100000005000000365B79C9FFC642402CD49AE61DD94B40365B79C9FFC6424098C28366D7D94B40B8AF03E78CC8424098C28366D7D94B40B8AF03E78CC842402CD49AE61DD94B40365B79C9FFC642402CD49AE61DD94B40
12851	1	37.437244999999997	37.449613999999997	55.859361999999997	55.855314999999997	Фомичевой	0103000020E6100000010000000500000075ABE7A4F7B742409D6340F67AED4B4075ABE7A4F7B742406BB6F292FFED4B4070E998F38CB942406BB6F292FFED4B4070E998F38CB942409D6340F67AED4B4075ABE7A4F7B742409D6340F67AED4B40
13054	1	37.474128999999998	37.519385999999997	55.863874000000003	55.849696000000002	Флотская 	0103000020E61000000100000005000000E78A5242B0BC424061C5A9D6C2EC4B40E78A5242B0BC4240AFEE586C93EE4B4008008E3D7BC24240AFEE586C93EE4B4008008E3D7BC2424061C5A9D6C2EC4B40E78A5242B0BC424061C5A9D6C2EC4B40
13182	1	37.474128999999998	37.519385999999997	55.863874000000003	55.849696000000002	Флотская	0103000020E61000000100000005000000E78A5242B0BC424061C5A9D6C2EC4B40E78A5242B0BC4240AFEE586C93EE4B4008008E3D7BC24240AFEE586C93EE4B4008008E3D7BC2424061C5A9D6C2EC4B40E78A5242B0BC424061C5A9D6C2EC4B40
6004	1	37.478019000000003	37.502678000000003	55.763542999999999	55.760910000000003	Филевский бульвар	0103000020E61000000100000005000000EEEE01BA2FBD42408599B67F65E14B40EEEE01BA2FBD42407C0BEBC6BBE14B409835B1C057C042407C0BEBC6BBE14B409835B1C057C042408599B67F65E14B40EEEE01BA2FBD42408599B67F65E14B40
3771	1	37.471246000000001	37.513224000000001	55.866591	55.853673000000001	Фестивальная улица	0103000020E61000000100000005000000772FF7C951BC4240363D282845ED4B40772FF7C951BC424004013274ECEE4B40DBC2F352B1C1424004013274ECEE4B40DBC2F352B1C14240363D282845ED4B40772FF7C951BC4240363D282845ED4B40
12872	1	37.471246000000001	37.513224000000001	55.866591	55.853673000000001	Фестивальная	0103000020E61000000100000005000000772FF7C951BC4240363D282845ED4B40772FF7C951BC424004013274ECEE4B40DBC2F352B1C1424004013274ECEE4B40DBC2F352B1C14240363D282845ED4B40772FF7C951BC4240363D282845ED4B40
3040	1	37.816082000000002	37.827455	55.700150999999998	55.692850999999997	Ферганский проезд	0103000020E61000000100000005000000596DFE5F75E842401D007157AFD84B40596DFE5F75E842407FA1478C9ED94B40B2F4A10BEAE942407FA1478C9ED94B40B2F4A10BEAE942401D007157AFD84B40596DFE5F75E842401D007157AFD84B40
13232	1	37.796031999999997	37.827202999999997	55.712670000000003	55.700150999999998	Ферганская	0103000020E61000000100000005000000E4486760E4E542407FA1478C9ED94B40E4486760E4E54240906B43C538DB4B409813B4C9E1E94240906B43C538DB4B409813B4C9E1E942407FA1478C9ED94B40E4486760E4E542407FA1478C9ED94B40
12857	1	37.577454000000003	37.583238999999999	55.565249000000001	55.562851000000002	Феодосийская	0103000020E61000000100000005000000E2783E03EAC94240ADC266800BC84B40E2783E03EAC94240618C48145AC84B4039605793A7CA4240618C48145AC84B4039605793A7CA4240ADC266800BC84B40E2783E03EAC94240ADC266800BC84B40
12948	1	37.331989	37.342525999999999	55.641579999999998	55.634048999999997	Федосьино	0103000020E61000000100000005000000DDD0949D7EAA4240DF87838428D14B40DDD0949D7EAA424043E21E4B1FD24B40CD0358E4D7AB424043E21E4B1FD24B40CD0358E4D7AB4240DF87838428D14B40DDD0949D7EAA4240DF87838428D14B40
13072	1	37.698115000000001	37.705311000000002	55.870728	55.867122000000002	Федоскинская 	0103000020E610000001000000050000006CEC12D55BD9424031D28BDAFDEE4B406CEC12D55BD9424012DBDD0374EF4B4029417FA147DA424012DBDD0374EF4B4029417FA147DA424031D28BDAFDEE4B406CEC12D55BD9424031D28BDAFDEE4B40
13115	1	37.774346000000001	37.794530999999999	55.716853	55.7074	Федора Полетаева	0103000020E61000000100000005000000EBE40CC51DE342405F984C158CDA4B40EBE40CC51DE342400E85CFD6C1DB4B403F541A31B3E542400E85CFD6C1DB4B403F541A31B3E542405F984C158CDA4B40EBE40CC51DE342405F984C158CDA4B40
381	1	37.777338	37.827787000000001	55.757480000000001	55.750230999999999	Федеративный проспект	0103000020E6100000010000000500000012F8C3CF7FE3424002B9C49107E04B4012F8C3CF7FE34240E2AFC91AF5E04B40E886A6ECF4E94240E2AFC91AF5E04B40E886A6ECF4E9424002B9C49107E04B4012F8C3CF7FE3424002B9C49107E04B40
13011	1	37.594242999999999	37.602902999999998	55.776932000000002	55.772466999999999	Фадеева	0103000020E610000001000000050000003F70952710CC42409F1EDB32E0E24B403F70952710CC4240A29BFD8172E34B4084D4EDEC2BCD4240A29BFD8172E34B4084D4EDEC2BCD42409F1EDB32E0E24B403F70952710CC42409F1EDB32E0E24B40
12530	1	37.420203999999998	37.454752999999997	55.844602000000002	55.843232	Фабрициуса	0103000020E61000000100000005000000FED2A23EC9B542406878B306EFEB4B40FED2A23EC9B542406F1118EB1BEC4B400261A75835BA42406F1118EB1BEC4B400261A75835BA42406878B306EFEB4B40FED2A23EC9B542406878B306EFEB4B40
3968	1	37.536428000000001	37.536597999999998	55.887458000000002	55.882348	Учинская улица	0103000020E61000000100000005000000505436ACA9C4424073D87DC7F0F04B40505436ACA9C442406B49473998F14B40AC8C463EAFC442406B49473998F14B40AC8C463EAFC4424073D87DC7F0F04B40505436ACA9C4424073D87DC7F0F04B40
13234	1	37.710090000000001	37.716234	55.773544999999999	55.766267999999997	Ухтомская	0103000020E61000000100000005000000BB9BA73AE4DA424054FCDF1115E24B40BB9BA73AE4DA4240FE7DC68503E34B404224438EADDB4240FE7DC68503E34B404224438EADDB424054FCDF1115E24B40BB9BA73AE4DA424054FCDF1115E24B40
13129	1	37.782125999999998	37.800469	55.749527	55.746212999999997	Утренняя	0103000020E61000000100000005000000F7AC6BB41CE44240CE6C57E883DF4B40F7AC6BB41CE44240083C3080F0DF4B401D3BA8C475E64240083C3080F0DF4B401D3BA8C475E64240CE6C57E883DF4B40F7AC6BB41CE44240CE6C57E883DF4B40
83	1	37.808554000000001	37.82432	55.823630999999999	55.823205999999999	Уссурийская улица	0103000020E6100000010000000500000066868DB27EE742407CEF6FD05EE94B4066868DB27EE74240637C98BD6CE94B4028B8585183E94240637C98BD6CE94B4028B8585183E942407CEF6FD05EE94B4066868DB27EE742407CEF6FD05EE94B40
12782	1	37.514006000000002	37.534514000000001	55.809154999999997	55.803747000000001	Усиевича	0103000020E6100000010000000500000051F9D7F2CAC142400AA1832EE1E64B4051F9D7F2CAC142408B321B6492E74B4088A06AF46AC442408B321B6492E74B4088A06AF46AC442400AA1832EE1E64B4051F9D7F2CAC142400AA1832EE1E64B40
2405	1	37.559074000000003	37.578387999999997	55.731059000000002	55.722065999999998	Усачева улица	0103000020E610000001000000050000009F05A1BC8FC74240DAC69FA86CDC4B409F05A1BC8FC742402639605793DD4B400D33349E08CA42402639605793DD4B400D33349E08CA4240DAC69FA86CDC4B409F05A1BC8FC74240DAC69FA86CDC4B40
12933	1	37.559074000000003	37.578387999999997	55.731059000000002	55.722065999999998	Усачева	0103000020E610000001000000050000009F05A1BC8FC74240DAC69FA86CDC4B409F05A1BC8FC742402639605793DD4B400D33349E08CA42402639605793DD4B400D33349E08CA4240DAC69FA86CDC4B409F05A1BC8FC74240DAC69FA86CDC4B40
13218	1	37.797972000000001	37.808554000000001	55.823205999999999	55.810156999999997	Уральская	0103000020E61000000100000005000000D68F4DF223E642400FD07D39B3E74B40D68F4DF223E642407CEF6FD05EE94B4066868DB27EE742407CEF6FD05EE94B4066868DB27EE742400FD07D39B3E74B40D68F4DF223E642400FD07D39B3E74B40
12670	1	37.517401	37.556711	55.716549000000001	55.694591000000003	Университетский проспект	0103000020E6100000010000000500000077F52A323AC24240488C9E5BE8D84B4077F52A323AC24240A27DACE0B7DB4B406729594E42C74240A27DACE0B7DB4B406729594E42C74240488C9E5BE8D84B4077F52A323AC24240488C9E5BE8D84B40
3705	1	37.561706000000001	37.567087000000001	55.752470000000002	55.745564000000002	Украинский бульвар	0103000020E61000000100000005000000C6FB71FBE5C74240988922A46EDF4B40C6FB71FBE5C742404E9CDCEF50E04B404E7E8B4E96C842404E9CDCEF50E04B404E7E8B4E96C84240988922A46EDF4B40C6FB71FBE5C74240988922A46EDF4B40
12869	1	37.484397000000001	37.519978999999999	55.689704999999996	55.670915000000001	Удальцова	0103000020E61000000100000005000000E8A38CB800BE4240ABB2EF8AE0D54B40E8A38CB800BE42409F71E14048D84B40ABCDFFAB8EC242409F71E14048D84B40ABCDFFAB8EC24240ABB2EF8AE0D54B40E8A38CB800BE4240ABB2EF8AE0D54B40
12993	1	37.567608	37.568300000000001	55.905200000000001	55.891426000000003	Угличская 	0103000020E6100000010000000500000057790261A7C84240ED66463F1AF24B4057790261A7C842406B2BF697DDF34B408D28ED0DBEC842406B2BF697DDF34B408D28ED0DBEC84240ED66463F1AF24B4057790261A7C84240ED66463F1AF24B40
12923	1	37.567608	37.568300000000001	55.905200000000001	55.891426000000003	Угличская	0103000020E6100000010000000500000057790261A7C84240ED66463F1AF24B4057790261A7C842406B2BF697DDF34B408D28ED0DBEC842406B2BF697DDF34B408D28ED0DBEC84240ED66463F1AF24B4057790261A7C84240ED66463F1AF24B40
6262	1	37.350197999999999	37.353450000000002	55.831907999999999	55.827793	Уваровский переулок	0103000020E61000000100000005000000F38FBE49D3AC4240CA6DFB1EF5E94B40F38FBE49D3AC4240F0A31AF67BEA4B40B7627FD93DAD4240F0A31AF67BEA4B40B7627FD93DAD4240CA6DFB1EF5E94B40F38FBE49D3AC4240CA6DFB1EF5E94B40
6535	1	37.441358999999999	37.454689999999999	55.829000999999998	55.826453000000001	Тушинская улица	0103000020E61000000100000005000000CB65A3737EB842402E573F36C9E94B40CB65A3737EB84240F7AC6BB41CEA4B40BCE82B4833BA4240F7AC6BB41CEA4B40BCE82B4833BA42402E573F36C9E94B40CB65A3737EB842402E573F36C9E94B40
12653	1	37.441358999999999	37.454689999999999	55.829000999999998	55.826453000000001	Тушинская	0103000020E61000000100000005000000CB65A3737EB842402E573F36C9E94B40CB65A3737EB84240F7AC6BB41CEA4B40BCE82B4833BA4240F7AC6BB41CEA4B40BCE82B4833BA42402E573F36C9E94B40CB65A3737EB842402E573F36C9E94B40
6598	1	37.419521000000003	37.424622999999997	55.862271999999997	55.844338999999998	Туристская улица	0103000020E610000001000000050000001C7E37DDB2B5424061DEE34C13EC4B401C7E37DDB2B54240D520CCED5EEE4B409010E50B5AB64240D520CCED5EEE4B409010E50B5AB6424061DEE34C13EC4B401C7E37DDB2B5424061DEE34C13EC4B40
13198	1	37.419521000000003	37.424622999999997	55.862271999999997	55.844338999999998	Туристская 	0103000020E610000001000000050000001C7E37DDB2B5424061DEE34C13EC4B401C7E37DDB2B54240D520CCED5EEE4B409010E50B5AB64240D520CCED5EEE4B409010E50B5AB6424061DEE34C13EC4B401C7E37DDB2B5424061DEE34C13EC4B40
12942	1	37.419521000000003	37.424622999999997	55.862271999999997	55.844338999999998	Туристская	0103000020E610000001000000050000001C7E37DDB2B5424061DEE34C13EC4B401C7E37DDB2B54240D520CCED5EEE4B409010E50B5AB64240D520CCED5EEE4B409010E50B5AB6424061DEE34C13EC4B401C7E37DDB2B5424061DEE34C13EC4B40
12615	1	37.658805000000001	37.686734000000001	55.706249	55.702509999999997	Трофимова	0103000020E610000001000000050000007CB8E4B853D44240758E01D9EBD94B407CB8E4B853D4424096EA025E66DA4B40908653E6E6D7424096EA025E66DA4B40908653E6E6D74240758E01D9EBD94B407CB8E4B853D44240758E01D9EBD94B40
12693	1	37.609693999999998	37.634829000000003	55.790149999999997	55.788139999999999	Трифоновская	0103000020E61000000100000005000000A148F7730ACE4240B05582C5E1E44B40A148F7730ACE42409A779CA223E54B40B5C6A01342D142409A779CA223E54B40B5C6A01342D14240B05582C5E1E44B40A148F7730ACE4240B05582C5E1E44B40
12931	1	37.399614	37.401994999999999	55.724012999999999	55.716132999999999	Толбухина	0103000020E610000001000000050000000A83328D26B342400E4B033FAADB4B400A83328D26B342407E703E75ACDC4B40E813799274B342407E703E75ACDC4B40E813799274B342400E4B033FAADB4B400A83328D26B342400E4B033FAADB4B40
353	1	37.667527999999997	37.671193000000002	55.768562000000003	55.764429999999997	Токмаков переулок	0103000020E610000001000000050000000795B88E71D54240670A9DD7D8E14B400795B88E71D542406479573D60E24B40EE26F8A6E9D542406479573D60E24B40EE26F8A6E9D54240670A9DD7D8E14B400795B88E71D54240670A9DD7D8E14B40
1521	1	37.657691	37.668227999999999	55.745153999999999	55.741129999999998	Товарищеский переулок	0103000020E61000000100000005000000D0EFFB372FD44240D00A0C59DDDE4B40D0EFFB372FD44240E63DCE3461DF4B40C022BF7E88D54240E63DCE3461DF4B40C022BF7E88D54240D00A0C59DDDE4B40D0EFFB372FD44240D00A0C59DDDE4B40
12374	1	37.717618000000002	37.745654000000002	55.787103000000002	55.785144000000003	Ткацкая улица	0103000020E61000000100000005000000AE8218E8DADB424048533D997FE44B40AE8218E8DADB4240B0CA85CABFE44B40D8101C9771DF4240B0CA85CABFE44B40D8101C9771DF424048533D997FE44B40AE8218E8DADB424048533D997FE44B40
12395	1	37.717618000000002	37.745654000000002	55.787103000000002	55.785144000000003	Ткацкая	0103000020E61000000100000005000000AE8218E8DADB424048533D997FE44B40AE8218E8DADB4240B0CA85CABFE44B40D8101C9771DF4240B0CA85CABFE44B40D8101C9771DF424048533D997FE44B40AE8218E8DADB424048533D997FE44B40
3959	1	37.772154	37.780230000000003	55.680438000000002	55.674925000000002	Тихорецкий бульвар	0103000020E61000000100000005000000E0BC38F1D5E242405C2041F163D64B40E0BC38F1D5E24240537AA69718D74B40D6AD9E93DEE34240537AA69718D74B40D6AD9E93DEE342405C2041F163D64B40E0BC38F1D5E242405C2041F163D64B40
13029	1	37.645420000000001	37.656227000000001	55.885973	55.883101000000003	Тихомирова	0103000020E610000001000000050000009817601F9DD242404F081D7409F14B409817601F9DD24240CB11329067F14B4048E00F3FFFD34240CB11329067F14B4048E00F3FFFD342404F081D7409F14B409817601F9DD242404F081D7409F14B40
2018	1	37.594664999999999	37.600675000000003	55.787770999999999	55.786287999999999	Тихвинский переулок	0103000020E61000000100000005000000B58993FB1DCC42405E9ECE15A5E44B40B58993FB1DCC42405DDE1CAED5E44B402D431CEBE2CC42405DDE1CAED5E44B402D431CEBE2CC42405E9ECE15A5E44B40B58993FB1DCC42405E9ECE15A5E44B40
3831	1	37.737372000000001	37.751151999999998	55.685254	55.684832999999998	Тихая улица	0103000020E61000000100000005000000397EA83462DE42405C1C959BA8D74B40397EA83462DE424002BA2F67B6D74B409929ADBF25E0424002BA2F67B6D74B409929ADBF25E042405C1C959BA8D74B40397EA83462DE42405C1C959BA8D74B40
12600	1	37.584775	37.593048000000003	55.510216	55.507652	Типографская	0103000020E610000001000000050000005B423EE8D9CA4240DFDFA0BDFAC04B405B423EE8D9CA4240AEF204C24EC14B40A77A32FFE8CB4240AEF204C24EC14B40A77A32FFE8CB4240DFDFA0BDFAC04B405B423EE8D9CA4240DFDFA0BDFAC04B40
12682	1	37.584055999999997	37.592159000000002	55.737588000000002	55.732219999999998	Тимура Фрунзе	0103000020E610000001000000050000002B84D558C2CA424012BD8C62B9DD4B402B84D558C2CA424006F6984869DE4B401B84B9DDCBCB424006F6984869DE4B401B84B9DDCBCB424012BD8C62B9DD4B402B84D558C2CA424012BD8C62B9DD4B40
4840	1	37.548681000000002	37.570976999999999	55.835053000000002	55.808022000000001	Тимирязевская улица	0103000020E61000000100000005000000E277D32D3BC642406939D0436DE74B40E277D32D3BC642409EB64604E3EA4B4054E23AC615C942409EB64604E3EA4B4054E23AC615C942406939D0436DE74B40E277D32D3BC642406939D0436DE74B40
13176	1	37.548681000000002	37.570976999999999	55.835053000000002	55.808022000000001	Тимирязевская	0103000020E61000000100000005000000E277D32D3BC642406939D0436DE74B40E277D32D3BC642409EB64604E3EA4B4054E23AC615C942409EB64604E3EA4B4054E23AC615C942406939D0436DE74B40E277D32D3BC642406939D0436DE74B40
12700	1	37.480893999999999	37.505381999999997	55.632047	55.619329999999998	Теплый Стан	0103000020E61000000100000005000000DB6B41EF8DBD424041B7973446CF4B40DB6B41EF8DBD4240784485EAE6D04B4058FE7C5BB0C04240784485EAE6D04B4058FE7C5BB0C0424041B7973446CF4B40DB6B41EF8DBD424041B7973446CF4B40
7067	1	37.637963999999997	37.643273000000001	55.863211999999997	55.860221000000003	Тенистый проезд	0103000020E610000001000000050000003E03EACDA8D142408D2AC3B81BEE4B403E03EACDA8D14240E3C116BB7DEE4B402DB308C556D24240E3C116BB7DEE4B402DB308C556D242408D2AC3B81BEE4B403E03EACDA8D142408D2AC3B81BEE4B40
12958	1	37.389893999999998	37.409917999999998	55.800204999999998	55.794452	Твардовского	0103000020E610000001000000050000000C74ED0BE8B14240F31E679AB0E54B400C74ED0BE8B142403F8C101E6DE64B4057056A3178B442403F8C101E6DE64B4057056A3178B44240F31E679AB0E54B400C74ED0BE8B14240F31E679AB0E54B40
2932	1	37.818021999999999	37.824823000000002	55.707729999999998	55.703747999999997	Ташкентский переулок	0103000020E610000001000000050000004AB4E4F1B4E842400D501A6A14DA4B404AB4E4F1B4E84240F4328AE596DA4B408BFED0CC93E94240F4328AE596DA4B408BFED0CC93E942400D501A6A14DA4B404AB4E4F1B4E842400D501A6A14DA4B40
2890	1	37.801628000000001	37.819577000000002	55.711488000000003	55.694175000000001	Ташкентская улица	0103000020E6100000010000000500000069C70DBF9BE64240B459F5B9DAD84B4069C70DBF9BE642408CBFED0912DB4B40E3C62DE6E7E842408CBFED0912DB4B40E3C62DE6E7E84240B459F5B9DAD84B4069C70DBF9BE64240B459F5B9DAD84B40
13158	1	37.801628000000001	37.819577000000002	55.711488000000003	55.694175000000001	Ташкентская 	0103000020E6100000010000000500000069C70DBF9BE64240B459F5B9DAD84B4069C70DBF9BE642408CBFED0912DB4B40E3C62DE6E7E842408CBFED0912DB4B40E3C62DE6E7E84240B459F5B9DAD84B4069C70DBF9BE64240B459F5B9DAD84B40
12551	1	37.801628000000001	37.819577000000002	55.711488000000003	55.694175000000001	Ташкентская	0103000020E6100000010000000500000069C70DBF9BE64240B459F5B9DAD84B4069C70DBF9BE642408CBFED0912DB4B40E3C62DE6E7E842408CBFED0912DB4B40E3C62DE6E7E84240B459F5B9DAD84B4069C70DBF9BE64240B459F5B9DAD84B40
12863	1	37.885486	37.886079000000002	55.714196000000001	55.708922000000001	Татьяны Макаровой	0103000020E610000001000000050000006E88F19A57F142401CB5C2F4BDDA4B406E88F19A57F142408E7747C66ADB4B40115663096BF142408E7747C66ADB4B40115663096BF142401CB5C2F4BDDA4B406E88F19A57F142401CB5C2F4BDDA4B40
3661	1	37.685592999999997	37.692070000000001	55.758280999999997	55.755519999999997	Танковый проезд	0103000020E61000000100000005000000EAAEEC82C1D74240A9BC1DE1B4E04B40EAAEEC82C1D74240CE16105A0FE14B407845F0BF95D84240CE16105A0FE14B407845F0BF95D84240A9BC1DE1B4E04B40EAAEEC82C1D74240A9BC1DE1B4E04B40
12446	1	37.743076000000002	37.747810000000001	55.606349000000002	55.603771000000002	Тамбовская	0103000020E61000000100000005000000A438471D1DDF4240F9A23D5E48CD4B40A438471D1DDF42402D7B12D89CCD4B4096CFF23CB8DF42402D7B12D89CCD4B4096CFF23CB8DF4240F9A23D5E48CD4B40A438471D1DDF4240F9A23D5E48CD4B40
6966	1	37.384262	37.410690000000002	55.805289999999999	55.798864000000002	Таллинская улица	0103000020E610000001000000050000003B8C497F2FB14240D3F9F02C41E64B403B8C497F2FB14240DEE522BE13E74B40AA656B7D91B44240DEE522BE13E74B40AA656B7D91B44240D3F9F02C41E64B403B8C497F2FB14240D3F9F02C41E64B40
12959	1	37.384262	37.410690000000002	55.805289999999999	55.798864000000002	Таллинская	0103000020E610000001000000050000003B8C497F2FB14240D3F9F02C41E64B403B8C497F2FB14240DEE522BE13E74B40AA656B7D91B44240DEE522BE13E74B40AA656B7D91B44240D3F9F02C41E64B403B8C497F2FB14240D3F9F02C41E64B40
12922	1	37.513016999999998	37.526564	55.874884999999999	55.869081999999999	Талдомская 	0103000020E6100000010000000500000061A5828AAAC1424069C537143EEF4B4061A5828AAAC1424067614F3BFCEF4B401FA0FB7266C3424067614F3BFCEF4B401FA0FB7266C3424069C537143EEF4B4061A5828AAAC1424069C537143EEF4B40
12620	1	37.672809999999998	37.681029000000002	55.738880000000002	55.727673000000003	Талалихина	0103000020E61000000100000005000000FC3559A31ED6424053978C6324DD4B40FC3559A31ED6424091D5AD9E93DE4B40555051F52BD7424091D5AD9E93DE4B40555051F52BD7424053978C6324DD4B40FC3559A31ED6424053978C6324DD4B40
12996	1	37.680643000000003	37.686922000000003	55.885205999999997	55.876854000000002	Тайнинская	0103000020E610000001000000050000002CA0504F1FD74240F3AE7AC03CF04B402CA0504F1FD742408A1C226E4EF14B409373620FEDD742408A1C226E4EF14B409373620FEDD74240F3AE7AC03CF04B402CA0504F1FD74240F3AE7AC03CF04B40
12995	1	37.696139000000002	37.708787000000001	55.884726000000001	55.884408000000001	Таймырская 	0103000020E610000001000000050000002E3C2F151BD942400F29064834F14B402E3C2F151BD94240E0F599B33EF14B403C6A4C88B9DA4240E0F599B33EF14B403C6A4C88B9DA42400F29064834F14B402E3C2F151BD942400F29064834F14B40
12927	1	37.696139000000002	37.708787000000001	55.884726000000001	55.884408000000001	Таймырская	0103000020E610000001000000050000002E3C2F151BD942400F29064834F14B402E3C2F151BD94240E0F599B33EF14B403C6A4C88B9DA4240E0F599B33EF14B403C6A4C88B9DA42400F29064834F14B402E3C2F151BD942400F29064834F14B40
7648	1	37.437998999999998	37.440280999999999	55.850594999999998	55.837611000000003	Сходненская улица	0103000020E610000001000000050000002157EA5910B842408BE255D636EB4B402157EA5910B842401092054CE0EC4B406C06B8205BB842401092054CE0EC4B406C06B8205BB842408BE255D636EB4B402157EA5910B842408BE255D636EB4B40
13143	1	37.437998999999998	37.440280999999999	55.850594999999998	55.837611000000003	Сходненская 	0103000020E610000001000000050000002157EA5910B842408BE255D636EB4B402157EA5910B842401092054CE0EC4B406C06B8205BB842401092054CE0EC4B406C06B8205BB842408BE255D636EB4B402157EA5910B842408BE255D636EB4B40
7099	1	37.652427000000003	37.656199999999998	55.881692000000001	55.871465999999998	Сухонская улица	0103000020E6100000010000000500000082035ABA82D34240B8C9A8328CEF4B4082035ABA82D342408A929048DBF04B404ED1915CFED342408A929048DBF04B404ED1915CFED34240B8C9A8328CEF4B4082035ABA82D34240B8C9A8328CEF4B40
12654	1	37.590147000000002	37.619754999999998	55.634618000000003	55.624906000000003	Сумской проезд	0103000020E61000000100000005000000906AD8EF89CB42407F8978EBFCCF4B40906AD8EF89CB4240FAB9A1293BD14B402844C02154CF4240FAB9A1293BD14B402844C02154CF42407F8978EBFCCF4B40906AD8EF89CB42407F8978EBFCCF4B40
1406	1	37.845646000000002	37.885593999999998	55.748832	55.731302999999997	Суздальская улица	0103000020E6100000010000000500000022FFCC203EEC4240BC3B32569BDD4B4022FFCC203EEC424061191BBAD9DF4B4054C4E9245BF1424061191BBAD9DF4B4054C4E9245BF14240BC3B32569BDD4B4022FFCC203EEC4240BC3B32569BDD4B40
12573	1	37.845646000000002	37.885593999999998	55.748832	55.731302999999997	Суздальская	0103000020E6100000010000000500000022FFCC203EEC4240BC3B32569BDD4B4022FFCC203EEC424061191BBAD9DF4B4054C4E9245BF1424061191BBAD9DF4B4054C4E9245BF14240BC3B32569BDD4B4022FFCC203EEC4240BC3B32569BDD4B40
2671	1	37.665416999999998	37.695006999999997	55.690258	55.677061999999999	Судостроительная улица	0103000020E61000000100000005000000E9995E622CD54240A3AEB5F7A9D64B40E9995E622CD54240B4E6C75F5AD84B40DBBE47FDF5D84240B4E6C75F5AD84B40DBBE47FDF5D84240A3AEB5F7A9D64B40E9995E622CD54240A3AEB5F7A9D64B40
12514	1	37.665416999999998	37.695006999999997	55.690258	55.677061999999999	Судостроительная	0103000020E61000000100000005000000E9995E622CD54240A3AEB5F7A9D64B40E9995E622CD54240B4E6C75F5AD84B40DBBE47FDF5D84240B4E6C75F5AD84B40DBBE47FDF5D84240A3AEB5F7A9D64B40E9995E622CD54240A3AEB5F7A9D64B40
12786	1	37.739662000000003	37.757888999999999	55.673462999999998	55.672325999999998	Судакова	0103000020E61000000100000005000000070C923EADDE4240102043C70ED64B40070C923EADDE424074081C0934D64B40C37FBA8102E1424074081C0934D64B40C37FBA8102E14240102043C70ED64B40070C923EADDE4240102043C70ED64B40
13145	1	37.537982	37.553316000000002	55.744281999999998	55.738276999999997	Студенческая 	0103000020E6100000010000000500000018EB1B98DCC44240CA3159DC7FDE4B4018EB1B98DCC442403080F0A144DF4B40412D060FD3C642403080F0A144DF4B40412D060FD3C64240CA3159DC7FDE4B4018EB1B98DCC44240CA3159DC7FDE4B40
13075	1	37.537982	37.553316000000002	55.744281999999998	55.738276999999997	Студенческая	0103000020E6100000010000000500000018EB1B98DCC44240CA3159DC7FDE4B4018EB1B98DCC442403080F0A144DF4B40412D060FD3C642403080F0A144DF4B40412D060FD3C64240CA3159DC7FDE4B4018EB1B98DCC44240CA3159DC7FDE4B40
12710	1	37.681972999999999	37.704179000000003	55.795160000000003	55.789673999999998	Стромынка	0103000020E61000000100000005000000A4E029E44AD742403140A20914E54B40A4E029E44AD742402F8B89CDC7E54B40D7C3978922DA42402F8B89CDC7E54B40D7C3978922DA42403140A20914E54B40A4E029E44AD742403140A20914E54B40
12439	1	37.529716999999998	37.539527	55.690100000000001	55.684528	Строителей	0103000020E610000001000000050000004F9143C4CDC3424020990E9D9ED74B404F9143C4CDC342401C7C613255D84B408D2782380FC542401C7C613255D84B408D2782380FC5424020990E9D9ED74B404F9143C4CDC3424020990E9D9ED74B40
6907	1	37.390082999999997	37.408759000000003	55.806651000000002	55.802289999999999	Строгинский бульвар	0103000020E61000000100000005000000DFDC5F3DEEB1424034F44F70B1E64B40DFDC5F3DEEB142409224085740E74B400C79043752B442409224085740E74B400C79043752B4424034F44F70B1E64B40DFDC5F3DEEB1424034F44F70B1E64B40
711	1	37.625190000000003	37.637020999999997	55.728352999999998	55.726658999999998	Стремянный переулок	0103000020E61000000100000005000000A4E4D53906D042400A2C802903DD4B40A4E4D53906D04240C478CDAB3ADD4B40BFEE74E789D14240C478CDAB3ADD4B40BFEE74E789D142400A2C802903DD4B40A4E4D53906D042400A2C802903DD4B40
12866	1	37.709505999999998	37.718085000000002	55.766359000000001	55.764485000000001	Сторожевая	0103000020E610000001000000050000006B28B517D1DA42402BA4FCA4DAE14B406B28B517D1DA424065FF3C0D18E24B40C45F9335EADB424065FF3C0D18E24B40C45F9335EADB42402BA4FCA4DAE14B406B28B517D1DA42402BA4FCA4DAE14B40
1271	1	37.563799000000003	37.571703999999997	55.764136000000001	55.763553999999999	Столярный переулок	0103000020E610000001000000050000003E42CD902AC84240705D3123BCE14B403E42CD902AC842401FD95C35CFE14B40067FBF982DC942401FD95C35CFE14B40067FBF982DC94240705D3123BCE14B403E42CD902AC84240705D3123BCE14B40
1107	1	37.591557000000002	37.596784999999997	55.75703	55.755966000000001	Столовый переулок	0103000020E61000000100000005000000255CC823B8CB4240A8716F7EC3E04B40255CC823B8CB4240A20BEA5BE6E04B4026DF6C7363CC4240A20BEA5BE6E04B4026DF6C7363CC4240A8716F7EC3E04B40255CC823B8CB4240A8716F7EC3E04B40
13188	1	37.802346999999997	37.813296999999999	55.679305999999997	55.672894999999997	Степана Шутова	0103000020E610000001000000050000009885764EB3E642402A52616C21D64B409885764EB3E6424000FDBE7FF3D64B40AB77B81D1AE8424000FDBE7FF3D64B40AB77B81D1AE842402A52616C21D64B409885764EB3E642402A52616C21D64B40
13224	1	37.686922000000003	37.714213000000001	55.887332000000001	55.882787999999998	Стартовая	0103000020E610000001000000050000009373620FEDD742408FA67A32FFF04B409373620FEDD74240DE58501894F14B4064B0E2546BDB4240DE58501894F14B4064B0E2546BDB42408FA67A32FFF04B409373620FEDD742408FA67A32FFF04B40
12856	1	37.669800000000002	37.673430000000003	55.791606999999999	55.787036999999998	Старослободская	0103000020E610000001000000050000002F6EA301BCD54240F8DEDFA0BDE44B402F6EA301BCD542407024D06053E54B40991249F432D642407024D06053E54B40991249F432D64240F8DEDFA0BDE44B402F6EA301BCD54240F8DEDFA0BDE44B40
1928	1	37.599310000000003	37.605291999999999	55.770319999999998	55.768065999999997	Старопименовский переулок	0103000020E610000001000000050000003815A930B6CC4240B39597FC4FE24B403815A930B6CC424034BA83D899E24B40E54350357ACD424034BA83D899E24B40E54350357ACD4240B39597FC4FE24B403815A930B6CC4240B39597FC4FE24B40
6539	1	37.610314000000002	37.614913000000001	55.807926000000002	55.800843	Старомарьинское шоссе	0103000020E610000001000000050000003E25E7C41ECE4240821DFF0582E64B403E25E7C41ECE424047CB811E6AE74B4050711C78B5CE424047CB811E6AE74B4050711C78B5CE4240821DFF0582E64B403E25E7C41ECE4240821DFF0582E64B40
6653	1	37.624229	37.637793000000002	55.661506000000003	55.659962	Старокаширское шоссе	0103000020E610000001000000050000007E1B62BCE6CF4240274D83A279D44B407E1B62BCE6CF4240CC0D863AACD44B40124F7633A3D14240CC0D863AACD44B40124F7633A3D14240274D83A279D44B407E1B62BCE6CF4240274D83A279D44B40
13016	1	37.577812999999999	37.590353	55.571337	55.568134999999998	Старокачаловская	0103000020E61000000100000005000000111AC1C6F5C94240425BCEA5B8C84B40111AC1C6F5C9424054FF209221C94B40390CE6AF90CB424054FF209221C94B40390CE6AF90CB4240425BCEA5B8C84B40111AC1C6F5C94240425BCEA5B8C84B40
5800	1	37.660736	37.677984000000002	55.875853999999997	55.873339000000001	Староватутинский проезд	0103000020E610000001000000050000001AA54BFF92D4424022A98592C9EF4B401AA54BFF92D442400F09DFFB1BF04B400B9B012EC8D642400F09DFFB1BF04B400B9B012EC8D6424022A98592C9EF4B401AA54BFF92D4424022A98592C9EF4B40
12494	1	37.637542000000003	37.646892999999999	55.810349000000002	55.809747000000002	Староалексеевская	0103000020E61000000100000005000000C9E9EBF99AD142405E8429CAA5E74B40C9E9EBF99AD1424054AC1A84B9E74B407381CB63CDD2424054AC1A84B9E74B407381CB63CDD242405E8429CAA5E74B40C9E9EBF99AD142405E8429CAA5E74B40
12891	1	37.656334999999999	37.669764000000001	55.769646000000002	55.764040000000001	Старая Басманная	0103000020E610000001000000050000002E1C08C902D44240FD6A0E10CCE14B402E1C08C902D44240A5BF97C283E24B40E204A6D3BAD54240A5BF97C283E24B40E204A6D3BAD54240FD6A0E10CCE14B402E1C08C902D44240FD6A0E10CCE14B40
5587	1	37.570850999999998	37.586356000000002	55.883175999999999	55.881929	Стандартная улица	0103000020E61000000100000005000000C7F143A511C942406E32AA0CE3F04B40C7F143A511C94240594E42E90BF14B401DE8A1B60DCB4240594E42E90BF14B401DE8A1B60DCB42406E32AA0CE3F04B40C7F143A511C942406E32AA0CE3F04B40
12535	1	37.570850999999998	37.586356000000002	55.883175999999999	55.881929	Стандартная	0103000020E61000000100000005000000C7F143A511C942406E32AA0CE3F04B40C7F143A511C94240594E42E90BF14B401DE8A1B60DCB4240594E42E90BF14B401DE8A1B60DCB42406E32AA0CE3F04B40C7F143A511C942406E32AA0CE3F04B40
12835	1	37.831963999999999	37.840552000000002	55.775205999999997	55.749760000000002	Сталеваров	0103000020E6100000010000000500000084B9DDCB7DEA4240ABECBB22F8DF4B4084B9DDCB7DEA4240DCD440F339E34B40304B3B3597EB4240DCD440F339E34B40304B3B3597EB4240ABECBB22F8DF4B4084B9DDCB7DEA4240ABECBB22F8DF4B40
13078	1	37.738207000000003	37.807035999999997	55.683052000000004	55.672763000000003	Ставропольская 	0103000020E61000000100000005000000D25625917DDE4240BC7A15191DD64B40D25625917DDE4240D4BB783F6ED74B40EA58A5F44CE74240D4BB783F6ED74B40EA58A5F44CE74240BC7A15191DD64B40D25625917DDE4240BC7A15191DD64B40
12687	1	37.738207000000003	37.807035999999997	55.683052000000004	55.672763000000003	Ставропольская	0103000020E61000000100000005000000D25625917DDE4240BC7A15191DD64B40D25625917DDE4240D4BB783F6ED74B40EA58A5F44CE74240D4BB783F6ED74B40EA58A5F44CE74240BC7A15191DD64B40D25625917DDE4240BC7A15191DD64B40
13148	1	37.631281000000001	37.632421999999998	55.772629000000002	55.766359000000001	Сретенка	0103000020E6100000010000000500000008CBD8D0CDD0424065FF3C0D18E24B4008CBD8D0CDD042407978CF81E5E24B40ADA23F34F3D042407978CF81E5E24B40ADA23F34F3D0424065FF3C0D18E24B4008CBD8D0CDD0424065FF3C0D18E24B40
12519	1	37.802194	37.819082000000002	55.796622999999997	55.795068999999998	Средняя Первомайская	0103000020E610000001000000050000001286014BAEE642401E882CD2C4E54B401286014BAEE64240E61E12BEF7E54B40035FD1ADD7E84240E61E12BEF7E54B40035FD1ADD7E842401E882CD2C4E54B401286014BAEE642401E882CD2C4E54B40
12515	1	37.679411999999999	37.704754000000001	55.736873000000003	55.730835999999996	Средняя Калитниковская	0103000020E610000001000000050000004641F0F8F6D64240A65EB7088CDD4B404641F0F8F6D642401827BEDA51DE4B40D3DC0A6135DA42401827BEDA51DE4B40D3DC0A6135DA4240A65EB7088CDD4B404641F0F8F6D64240A65EB7088CDD4B40
1209	1	37.572755000000001	37.581685	55.770643999999997	55.769686999999998	Средний Тишинский переулок	0103000020E610000001000000050000006CCF2C0950C942400394861A85E24B406CCF2C0950C94240E76D6C76A4E24B4071C971A774CA4240E76D6C76A4E24B4071C971A774CA42400394861A85E24B406CCF2C0950C942400394861A85E24B40
2968	1	37.750532	37.755777999999999	55.684133000000003	55.682822999999999	Спортивный проезд	0103000020E61000000100000005000000FD4CBD6E11E0424072FA7ABE66D74B40FD4CBD6E11E04240A48E8EAB91D74B40A5846055BDE04240A48E8EAB91D74B40A5846055BDE0424072FA7ABE66D74B40FD4CBD6E11E0424072FA7ABE66D74B40
1251	1	37.802185000000001	37.820475000000002	55.751309999999997	55.748745999999997	Союзный проспект	0103000020E61000000100000005000000BF2B82FFADE642406281AFE8D6DF4B40BF2B82FFADE64240319413ED2AE04B40C217265305E94240319413ED2AE04B40C217265305E942406281AFE8D6DF4B40BF2B82FFADE642406281AFE8D6DF4B40
12739	1	37.532716999999998	37.536642999999998	55.893616999999999	55.876151999999998	Софьи Ковалевской	0103000020E61000000100000005000000F982161230C442409929ADBF25F04B40F982161230C442402713B70A62F24B404C50C3B7B0C442402713B70A62F24B404C50C3B7B0C442409929ADBF25F04B40F982161230C442409929ADBF25F04B40
3264	1	37.542177000000002	37.555920999999998	55.619700999999999	55.611780000000003	Соловьиный проезд	0103000020E610000001000000050000005BD2510E66C54240672C9ACE4ECE4B405BD2510E66C542403526C45C52CF4B406E14596B28C742403526C45C52CF4B406E14596B28C74240672C9ACE4ECE4B405BD2510E66C54240672C9ACE4ECE4B40
5511	1	37.395015000000001	37.416080000000001	55.652800999999997	55.646420999999997	Солнцевский проспект	0103000020E61000000100000005000000F836FDD98FB242404B395FECBDD24B40F836FDD98FB24240E6E5B0FB8ED34B408542041C42B54240E6E5B0FB8ED34B408542041C42B542404B395FECBDD24B40F836FDD98FB242404B395FECBDD24B40
3743	1	37.518586999999997	37.521515999999998	55.859831999999997	55.858640000000001	Солнечногорский проезд	0103000020E61000000100000005000000BC900E0F61C24240CB845FEAE7ED4B40BC900E0F61C24240F20698F90EEE4B409D2B4A09C1C24240F20698F90EEE4B409D2B4A09C1C24240CB845FEAE7ED4B40BC900E0F61C24240CB845FEAE7ED4B40
12649	1	37.513537999999997	37.522449999999999	55.862741999999997	55.855947	Солнечногорская	0103000020E610000001000000050000006AA0F99CBBC14240FE0DDAAB8FED4B406AA0F99CBBC142405C7171546EEE4B40C9E53FA4DFC242405C7171546EEE4B40C9E53FA4DFC24240FE0DDAAB8FED4B406AA0F99CBBC14240FE0DDAAB8FED4B40
13236	1	37.697288999999998	37.706533	55.766795000000002	55.763376000000001	Солдатская	0103000020E61000000100000005000000266E15C440D942409146054EB6E14B40266E15C440D9424040DEAB5626E24B40BB4560AC6FDA424040DEAB5626E24B40BB4560AC6FDA42409146054EB6E14B40266E15C440D942409146054EB6E14B40
2727	1	37.677624999999999	37.680489999999999	55.792093000000001	55.788671999999998	Сокольническая площадь	0103000020E61000000100000005000000DBF97E6ABCD64240ADA23F34F3E44B40DBF97E6ABCD64240FD31AD4D63E54B40A5A0DB4B1AD74240FD31AD4D63E54B40A5A0DB4B1AD74240ADA23F34F3E44B40DBF97E6ABCD64240ADA23F34F3E44B40
6253	1	37.385232000000002	37.389867000000002	55.907834000000001	55.893571000000001	Соколово-Мещерская улица	0103000020E61000000100000005000000B4AF3C484FB14240B7D3D68860F24B40B4AF3C484FB1424033198EE733F44B4013656F29E7B1424033198EE733F44B4013656F29E7B14240B7D3D68860F24B40B4AF3C484FB14240B7D3D68860F24B40
4114	1	37.740335999999999	37.764276000000002	55.681854000000001	55.668619999999997	Совхозная улица	0103000020E6100000010000000500000096067E54C3DE4240CBB9145795D54B4096067E54C3DE4240CA52EBFD46D74B40118FC4CBD3E14240CA52EBFD46D74B40118FC4CBD3E14240CBB9145795D54B4096067E54C3DE4240CBB9145795D54B40
13163	1	37.614859000000003	37.616827000000001	55.793160999999998	55.783332000000001	Советской Армии	0103000020E610000001000000050000005D5320B3B3CE424084F4143944E44B405D5320B3B3CE424038BBB54C86E54B401825E82FF4CE424038BBB54C86E54B401825E82FF4CE424084F4143944E44B405D5320B3B3CE424084F4143944E44B40
12501	1	37.748294999999999	37.753362000000003	55.800128999999998	55.799467	Советская	0103000020E6100000010000000500000052616C21C8DF4240999D45EF54E64B4052616C21C8DF424064CA87A06AE64B404B06802A6EE0424064CA87A06AE64B404B06802A6EE04240999D45EF54E64B4052616C21C8DF4240999D45EF54E64B40
4183	1	37.516916000000002	37.529249999999998	55.839025999999997	55.826720999999999	Соболевский проезд	0103000020E61000000100000005000000BB63B14D2AC242404DF564FED1E94B40BB63B14D2AC24240313F373465EB4B4039B4C876BEC34240313F373465EB4B4039B4C876BEC342404DF564FED1E94B40BB63B14D2AC242404DF564FED1E94B40
13128	1	37.639806	37.654646	55.857022999999998	55.846558000000002	Снежная	0103000020E610000001000000050000006DE4BA29E5D14240661536035CEC4B406DE4BA29E5D14240BC75FEEDB2ED4B40863AAC70CBD34240BC75FEEDB2ED4B40863AAC70CBD34240661536035CEC4B406DE4BA29E5D14240661536035CEC4B40
7901	1	37.810054000000001	37.817196000000003	55.725366999999999	55.719617	Снайперская улица	0103000020E610000001000000050000003BFF76D9AFE74240A452EC681CDC4B403BFF76D9AFE742407F4C6BD3D8DC4B400536E7E099E842407F4C6BD3D8DC4B400536E7E099E84240A452EC681CDC4B403BFF76D9AFE74240A452EC681CDC4B40
13207	1	37.810054000000001	37.817196000000003	55.725366999999999	55.719617	Снайперская	0103000020E610000001000000050000003BFF76D9AFE74240A452EC681CDC4B403BFF76D9AFE742407F4C6BD3D8DC4B400536E7E099E842407F4C6BD3D8DC4B400536E7E099E84240A452EC681CDC4B403BFF76D9AFE74240A452EC681CDC4B40
3469	1	37.467374	37.500881	55.874839000000001	55.844065999999998	Смольная улица	0103000020E61000000100000005000000178046E9D2BB424030D5CC5A0AEC4B40178046E9D2BB4240F7216FB9FAEF4B4009185DDE1CC04240F7216FB9FAEF4B4009185DDE1CC0424030D5CC5A0AEC4B40178046E9D2BB424030D5CC5A0AEC4B40
12813	1	37.467374	37.500881	55.874839000000001	55.844065999999998	Смольная 	0103000020E61000000100000005000000178046E9D2BB424030D5CC5A0AEC4B40178046E9D2BB4240F7216FB9FAEF4B4009185DDE1CC04240F7216FB9FAEF4B4009185DDE1CC0424030D5CC5A0AEC4B40178046E9D2BB424030D5CC5A0AEC4B40
12850	1	37.467374	37.500881	55.874839000000001	55.844065999999998	Смольная	0103000020E61000000100000005000000178046E9D2BB424030D5CC5A0AEC4B40178046E9D2BB4240F7216FB9FAEF4B4009185DDE1CC04240F7216FB9FAEF4B4009185DDE1CC0424030D5CC5A0AEC4B40178046E9D2BB424030D5CC5A0AEC4B40
6144	1	37.461148999999999	37.478765000000003	55.727673000000003	55.725554000000002	Славянский бульвар	0103000020E61000000100000005000000A3CA30EE06BB4240B2BD16F4DEDC4B40A3CA30EE06BB424053978C6324DD4B4017BCE82B48BD424053978C6324DD4B4017BCE82B48BD4240B2BD16F4DEDC4B40A3CA30EE06BB4240B2BD16F4DEDC4B40
769	1	37.639752000000001	37.643929	55.773803000000001	55.771864000000001	Скорняжный переулок	0103000020E610000001000000050000007AC6BE64E3D14240D97A8670CCE24B407AC6BE64E3D14240FA4509FA0BE34B4016F9F5436CD24240FA4509FA0BE34B4016F9F5436CD24240D97A8670CCE24B407AC6BE64E3D14240D97A8670CCE24B40
12785	1	37.551923000000002	37.558140000000002	55.554369000000001	55.540557	Скобелевская	0103000020E610000001000000050000008274B169A5C64240DB4FC6F830C54B408274B169A5C6424047753A90F5C64B40734BAB2171C7424047753A90F5C64B40734BAB2171C74240DB4FC6F830C54B408274B169A5C64240DB4FC6F830C54B40
2887	1	37.566305999999997	37.574651000000003	55.783053000000002	55.776288999999998	Скаковая улица	0103000020E61000000100000005000000A8C30AB77CC842404D9F1D705DE34B40A8C30AB77CC842407104A9143BE44B408ECEF9298EC942407104A9143BE44B408ECEF9298EC942404D9F1D705DE34B40A8C30AB77CC842404D9F1D705DE34B40
12652	1	37.566305999999997	37.574651000000003	55.783053000000002	55.776288999999998	Скаковая	0103000020E61000000100000005000000A8C30AB77CC842404D9F1D705DE34B40A8C30AB77CC842407104A9143BE44B408ECEF9298EC942407104A9143BE44B408ECEF9298EC942404D9F1D705DE34B40A8C30AB77CC842404D9F1D705DE34B40
472	1	37.751924000000002	37.829439999999998	55.803387999999998	55.802228999999997	Сиреневый бульвар	0103000020E61000000100000005000000EC89AE0B3FE042408E739B70AFE64B40EC89AE0B3FE04240DAFF006BD5E64B4043FF04172BEA4240DAFF006BD5E64B4043FF04172BEA42408E739B70AFE64B40EC89AE0B3FE042408E739B70AFE64B40
7017	1	37.605167000000002	37.613584000000003	55.663426000000001	55.641939999999998	Симферопольский бульвар	0103000020E6100000010000000500000029CFBC1C76CD424043FF04172BD24B4029CFBC1C76CD424076A8A624EBD44B40A8ACA6EB89CE424076A8A624EBD44B40A8ACA6EB89CE424043FF04172BD24B4029CFBC1C76CD424043FF04172BD24B40
13183	1	37.663367999999998	37.66592	55.730668999999999	55.717917999999997	Симоновский Вал	0103000020E61000000100000005000000419B1C3EE9D44240D89AADBCE4DB4B40419B1C3EE9D44240BB99D18F86DD4B404CE0D6DD3CD54240BB99D18F86DD4B404CE0D6DD3CD54240D89AADBCE4DB4B40419B1C3EE9D44240D89AADBCE4DB4B40
12603	1	37.598339000000003	37.608041	55.662689	55.658875999999999	Сивашская	0103000020E61000000100000005000000EF75525F96CC4240450F7C0C56D44B40EF75525F96CC4240A0353FFED2D44B4046D09849D4CD4240A0353FFED2D44B4046D09849D4CD4240450F7C0C56D44B40EF75525F96CC4240450F7C0C56D44B40
12882	1	37.611750999999998	37.615174000000003	55.745801999999998	55.743127000000001	Серафимовича	0103000020E61000000100000005000000CC2555DB4DCE424026E318C91EDF4B40CC2555DB4DCE42404CA59F7076DF4B40BDAC8905BECE42404CA59F7076DF4B40BDAC8905BECE424026E318C91EDF4B40CC2555DB4DCE424026E318C91EDF4B40
497	1	37.698196000000003	37.703325999999997	55.782643	55.774040999999997	Семеновская набережная	0103000020E6100000010000000500000059198D7C5ED94240AE6186C613E34B4059198D7C5ED94240BFB854A52DE44B4097361C9606DA4240BFB854A52DE44B4097361C9606DA4240AE6186C613E34B4059198D7C5ED94240AE6186C613E34B40
12657	1	37.624974000000002	37.654457000000001	55.857801000000002	55.830522999999999	Сельскохозяйственная	0103000020E61000000100000005000000D76CE525FFCF4240B4C9E1934EEA4B40D76CE525FFCF4240F1BC546CCCED4B40B3D1393FC5D34240F1BC546CCCED4B40B3D1393FC5D34240B4C9E1934EEA4B40D76CE525FFCF4240B4C9E1934EEA4B40
12778	1	37.636482000000001	37.644880999999998	55.852637000000001	55.851287999999997	Седова	0103000020E61000000100000005000000103FFF3D78D1424016BD5301F7EC4B40103FFF3D78D14240062E8F3523ED4B40E867EA758BD24240062E8F3523ED4B40E867EA758BD2424016BD5301F7EC4B40103FFF3D78D1424016BD5301F7EC4B40
6754	1	37.601564000000003	37.621856999999999	55.869560999999997	55.863878999999997	Северный бульвар	0103000020E61000000100000005000000B939950C00CD4240C0594A9693EE4B40B939950C00CD424043705CC64DEF4B40F3E49A0299CF424043705CC64DEF4B40F3E49A0299CF4240C0594A9693EE4B40B939950C00CD4240C0594A9693EE4B40
1268	1	37.539490999999998	37.609901000000001	55.694723000000003	55.619304999999997	Севастопольский проспект	0103000020E6100000010000000500000040BE840A0EC54240E89FE06245CF4B4040BE840A0EC54240B763EAAEECD84B401B66683C11CE4240B763EAAEECD84B401B66683C11CE4240E89FE06245CF4B4040BE840A0EC54240E89FE06245CF4B40
7499	1	37.638305000000003	37.666755000000002	55.624921999999998	55.618139999999997	Севанская улица	0103000020E61000000100000005000000C8EF6DFAB3D14240BA2C26361FCF4B40C8EF6DFAB3D142408446B071FDCF4B40E5B8533A58D542408446B071FDCF4B40E5B8533A58D54240BA2C26361FCF4B40C8EF6DFAB3D14240BA2C26361FCF4B40
13227	1	37.638305000000003	37.666755000000002	55.624921999999998	55.618139999999997	Севанская	0103000020E61000000100000005000000C8EF6DFAB3D14240BA2C26361FCF4B40C8EF6DFAB3D142408446B071FDCF4B40E5B8533A58D542408446B071FDCF4B40E5B8533A58D54240BA2C26361FCF4B40C8EF6DFAB3D14240BA2C26361FCF4B40
12452	1	37.877293000000002	37.898178999999999	55.714205999999997	55.712518000000003	Святоозерская	0103000020E610000001000000050000003F0114234BF04240DAE731CA33DB4B403F0114234BF04240B14D2A1A6BDB4B401C7A8B87F7F24240B14D2A1A6BDB4B401C7A8B87F7F24240DAE731CA33DB4B403F0114234BF04240DAE731CA33DB4B40
12346	1	37.428037000000003	37.455319000000003	55.876657000000002	55.820166999999998	Свободы	0103000020E610000001000000050000002E3D9AEAC9B642401421753BFBE84B402E3D9AEAC9B642409D67EC4B36F04B40AC1F9BE447BA42409D67EC4B36F04B40AC1F9BE447BA42401421753BFBE84B402E3D9AEAC9B642401421753BFBE84B40
4682	1	37.487639999999999	37.491340999999998	55.814619	55.812196	Светлый проезд	0103000020E61000000100000005000000581CCEFC6ABE424094F8DC09F6E74B40581CCEFC6ABE4240A1D9756F45E84B408B170B43E4BE4240A1D9756F45E84B408B170B43E4BE424094F8DC09F6E74B40581CCEFC6ABE424094F8DC09F6E74B40
7754	1	37.402560999999999	37.403953000000001	55.850620999999997	55.842725999999999	Светлогорский проезд	0103000020E6100000010000000500000091D26C1E87B3424094BE1072DEEB4B4091D26C1E87B3424039252026E1EC4B40800F5EBBB4B3424039252026E1EC4B40800F5EBBB4B3424094BE1072DEEB4B4091D26C1E87B3424094BE1072DEEB4B40
187	1	37.822800999999998	37.840012999999999	55.768146999999999	55.766961999999999	Саянская улица	0103000020E61000000100000005000000DC0E0D8B51E942402BA391CF2BE24B40DC0E0D8B51E94240A0C211A452E24B40809BC58B85EB4240A0C211A452E24B40809BC58B85EB42402BA391CF2BE24B40DC0E0D8B51E942402BA391CF2BE24B40
12833	1	37.822800999999998	37.840012999999999	55.768146999999999	55.766961999999999	Саянская	0103000020E61000000100000005000000DC0E0D8B51E942402BA391CF2BE24B40DC0E0D8B51E94240A0C211A452E24B40809BC58B85EB4240A0C211A452E24B40809BC58B85EB42402BA391CF2BE24B40DC0E0D8B51E942402BA391CF2BE24B40
5187	1	37.730041	37.750047000000002	55.718353999999998	55.713014999999999	Саратовская улица	0103000020E610000001000000050000009CDEC5FB71DD42405A47551344DB4B409CDEC5FB71DD4240B3791C06F3DB4B4041BB438A01E04240B3791C06F3DB4B4041BB438A01E042405A47551344DB4B409CDEC5FB71DD42405A47551344DB4B40
12629	1	37.730041	37.750047000000002	55.718353999999998	55.713014999999999	Саратовская	0103000020E610000001000000050000009CDEC5FB71DD42405A47551344DB4B409CDEC5FB71DD4240B3791C06F3DB4B4041BB438A01E04240B3791C06F3DB4B4041BB438A01E042405A47551344DB4B409CDEC5FB71DD42405A47551344DB4B40
13014	1	37.594287999999999	37.601564000000003	55.865147	55.857734999999998	Санникова	0103000020E61000000100000005000000DF3312A111CC424039D1AE42CAED4B40DF3312A111CC4240C39D0B23BDEE4B40B939950C00CD4240C39D0B23BDEE4B40B939950C00CD424039D1AE42CAED4B40DF3312A111CC424039D1AE42CAED4B40
13230	1	37.490425000000002	37.504680999999998	55.652867000000001	55.646807000000003	Саморы Машела	0103000020E610000001000000050000000612143FC6BE424075E95F92CAD24B400612143FC6BE42409ED1562591D34B40CFF4126399C042409ED1562591D34B40CFF4126399C0424075E95F92CAD24B400612143FC6BE424075E95F92CAD24B40
13161	1	37.80921	37.829647000000001	55.708973	55.694865	Самаркандский бульвар	0103000020E610000001000000050000004FCC7A3194E7424049111956F1D84B404FCC7A3194E742409E5F94A0BFDA4B40BD1C76DF31EA42409E5F94A0BFDA4B40BD1C76DF31EA424049111956F1D84B404FCC7A3194E7424049111956F1D84B40
12947	1	37.505201999999997	37.511248000000002	55.796506000000001	55.793762999999998	Сальвадора Альенде	0103000020E61000000100000005000000D8EF8975AAC042402EE3A6069AE54B40D8EF8975AAC04240AD889AE8F3E54B409D12109370C14240AD889AE8F3E54B409D12109370C142402EE3A6069AE54B40D8EF8975AAC042402EE3A6069AE54B40
1525	1	37.85859	37.887363000000001	55.748488000000002	55.707410000000003	Салтыковская улица	0103000020E610000001000000050000001956F146E6ED4240836E2F698CDA4B401956F146E6ED424067B96C74CEDF4B4019575C1C95F1424067B96C74CEDF4B4019575C1C95F14240836E2F698CDA4B401956F146E6ED4240836E2F698CDA4B40
12877	1	37.85859	37.887363000000001	55.748488000000002	55.707410000000003	Салтыковская	0103000020E610000001000000050000001956F146E6ED4240836E2F698CDA4B401956F146E6ED424067B96C74CEDF4B4019575C1C95F1424067B96C74CEDF4B4019575C1C95F14240836E2F698CDA4B401956F146E6ED4240836E2F698CDA4B40
12644	1	37.625621000000002	37.643524999999997	55.747844000000001	55.734405000000002	Садовническая	0103000020E610000001000000050000006D58535914D042406B82A8FB00DE4B406D58535914D042404241295AB9DF4B404694F6065FD242404241295AB9DF4B404694F6065FD242406B82A8FB00DE4B406D58535914D042406B82A8FB00DE4B40
12896	1	37.648977000000002	37.656928000000001	55.678609999999999	55.667340000000003	Садовники	0103000020E61000000100000005000000986DA7AD11D3424005A8A9656BD54B40986DA7AD11D34240895E46B1DCD64B40D1E9793716D44240895E46B1DCD64B40D1E9793716D4424005A8A9656BD54B40986DA7AD11D3424005A8A9656BD54B40
12630	1	37.621516	37.627355000000001	55.773758000000001	55.773353	Садовая-Сухаревская	0103000020E610000001000000050000006AF816D68DCF4240BAA1293BFDE24B406AF816D68DCF42405A828C800AE34B40B5FD2B2B4DD042405A828C800AE34B40B5FD2B2B4DD04240BAA1293BFDE24B406AF816D68DCF4240BAA1293BFDE24B40
757	1	37.637210000000003	37.649515999999998	55.772021000000002	55.768689000000002	Садовая-Спасская улица	0103000020E610000001000000050000009357E71890D14240C1E5B16664E24B409357E71890D14240A1698995D1E24B40471D1D5723D34240A1698995D1E24B40471D1D5723D34240C1E5B16664E24B409357E71890D14240C1E5B16664E24B40
2849	1	37.725729999999999	37.835242999999998	55.731475000000003	55.707901999999997	Рязанский проспект	0103000020E61000000100000005000000F0DC7BB8E4DC4240F16261889CDA4B40F0DC7BB8E4DC4240BA6B09F9A0DD4B40419B1C3EE9EA4240BA6B09F9A0DD4B40419B1C3EE9EA4240F16261889CDA4B40F0DC7BB8E4DC4240F16261889CDA4B40
13006	1	37.664194999999999	37.674939000000002	55.591715999999998	55.589432000000002	Ряжская	0103000020E6100000010000000500000057957D5704D54240A29BFD8172CB4B4057957D5704D542408D429259BDCB4B40C1E5B16664D642408D429259BDCB4B40C1E5B16664D64240A29BFD8172CB4B4057957D5704D54240A29BFD8172CB4B40
12487	1	37.420177000000002	37.437451000000003	55.720255999999999	55.667949999999998	Рябиновая	0103000020E6100000010000000500000005C4245CC8B542407DAEB6627FD54B4005C4245CC8B54240B75F3E5931DC4B401F4DF564FEB74240B75F3E5931DC4B401F4DF564FEB742407DAEB6627FD54B4005C4245CC8B542407DAEB6627FD54B40
13217	1	37.579492999999999	37.605246999999999	55.815508999999999	55.810065999999999	Руставели	0103000020E6100000010000000500000066A19DD32CCA4240FFCC203EB0E74B4066A19DD32CCA4240FD4B529962E84B404580D3BB78CD4240FD4B529962E84B404580D3BB78CD4240FFCC203EB0E74B4066A19DD32CCA4240FFCC203EB0E74B40
800	1	37.669504000000003	37.682116000000001	55.789790000000004	55.781154999999998	Русаковская улица	0103000020E6100000010000000500000046459C4EB2D54240AE0D15E3FCE34B4046459C4EB2D542409B5AB6D617E54B40070ABC934FD742409B5AB6D617E54B40070ABC934FD74240AE0D15E3FCE34B4046459C4EB2D54240AE0D15E3FCE34B40
13044	1	37.675846	37.682251000000001	55.866686999999999	55.863596000000001	Рудневой	0103000020E61000000100000005000000F390291F82D642406C7A50508AEE4B40F390291F82D64240266F8099EFEE4B40E754320054D74240266F8099EFEE4B40E754320054D742406C7A50508AEE4B40F390291F82D642406C7A50508AEE4B40
12471	1	37.87715	37.899706000000002	55.716478000000002	55.714435000000002	Рудневка	0103000020E61000000100000005000000DCD7817346F04240130F289B72DB4B40DCD7817346F04240D926158DB5DB4B40EB01F39029F34240D926158DB5DB4B40EB01F39029F34240130F289B72DB4B40DCD7817346F04240130F289B72DB4B40
470	1	37.689239999999998	37.694468000000001	55.774273999999998	55.772329999999997	Рубцов переулок	0103000020E610000001000000050000002A8C2D0439D842401EDC9DB5DBE24B402A8C2D0439D84240511212691BE34B402C0FD253E4D84240511212691BE34B402C0FD253E4D842401EDC9DB5DBE24B402A8C2D0439D842401EDC9DB5DBE24B40
12673	1	37.369591999999997	37.471694999999997	55.769879000000003	55.723688000000003	Рублевское шоссе	0103000020E610000001000000050000007E6E68CA4EAF4240FB40F2CEA1DC4B407E6E68CA4EAF4240487023658BE24B40E657738060BC4240487023658BE24B40E657738060BC4240FB40F2CEA1DC4B407E6E68CA4EAF4240FB40F2CEA1DC4B40
12800	1	37.720464999999997	37.726914999999998	55.879004999999999	55.873545999999997	Ротерта	0103000020E61000000100000005000000D174763238DC42409BC6F65AD0EF4B40D174763238DC42409F02603C83F04B4065FCFB8C0BDD42409F02603C83F04B4065FCFB8C0BDD42409BC6F65AD0EF4B40D174763238DC42409BC6F65AD0EF4B40
13073	1	37.657431000000003	37.666001000000001	55.836407999999999	55.832858999999999	Ростокинская	0103000020E610000001000000050000003430F2B226D44240F296AB1F9BEA4B403430F2B226D442406F0ED76A0FEB4B40390D51853FD542406F0ED76A0FEB4B40390D51853FD54240F296AB1F9BEA4B403430F2B226D44240F296AB1F9BEA4B40
12622	1	37.605381999999999	37.608984	55.602561000000001	55.595038000000002	Россошанский проезд	0103000020E6100000010000000500000025CB49287DCD42404AF086342ACC4B4025CB49287DCD42402B6C06B820CD4B40C5E40D30F3CD42402B6C06B820CD4B40C5E40D30F3CD42404AF086342ACC4B4025CB49287DCD42404AF086342ACC4B40
13092	1	37.379742999999998	37.410159999999998	55.640030000000003	55.630918999999999	Родниковая	0103000020E6100000010000000500000045F12A6B9BB0424067B62BF4C1D04B4045F12A6B9BB04240BD3AC780ECD14B404D10751F80B44240BD3AC780ECD14B404D10751F80B4424067B62BF4C1D04B4045F12A6B9BB0424067B62BF4C1D04B40
5570	1	37.382886999999997	37.402146999999999	55.894212000000003	55.893555999999997	Родионовская улица	0103000020E610000001000000050000002288F37002B142408192020B60F24B402288F37002B142406BD8EF8975F24B409E978A8D79B342406BD8EF8975F24B409E978A8D79B342408192020B60F24B402288F37002B142408192020B60F24B40
12798	1	37.382886999999997	37.402146999999999	55.894212000000003	55.893555999999997	Родионовская	0103000020E610000001000000050000002288F37002B142408192020B60F24B402288F37002B142406BD8EF8975F24B409E978A8D79B342406BD8EF8975F24B409E978A8D79B342408192020B60F24B402288F37002B142408192020B60F24B40
13242	1	37.453594000000002	37.465919	55.796112000000001	55.795914000000003	Рогова	0103000020E61000000100000005000000B7D4415E0FBA4240DB368C82E0E54B40B7D4415E0FBA424001FA7DFFE6E54B40E2CAD93BA3BB424001FA7DFFE6E54B40E2CAD93BA3BB4240DB368C82E0E54B40B7D4415E0FBA4240DB368C82E0E54B40
13048	1	37.829799000000001	37.838351000000003	55.743639000000002	55.732114000000003	Реутовская	0103000020E6100000010000000500000073A087DA36EA4240CD785BE9B5DD4B4073A087DA36EA4240DC8310902FDF4B40D2C8E7154FEB4240DC8310902FDF4B40D2C8E7154FEB4240CD785BE9B5DD4B4073A087DA36EA4240CD785BE9B5DD4B40
12820	1	37.595303000000001	37.608598000000001	55.679777999999999	55.671675999999998	Ремизова	0103000020E61000000100000005000000F81A82E332CC424009C1AA7AF9D54B40F81A82E332CC424028452BF702D74B409C340D8AE6CD424028452BF702D74B409C340D8AE6CD424009C1AA7AF9D54B40F81A82E332CC424009C1AA7AF9D54B40
3550	1	37.547727999999999	37.554834	55.741661999999998	55.739372000000003	Резервный проезд	0103000020E610000001000000050000003F8D7BF31BC6424000CADFBDA3DE4B403F8D7BF31BC64240CD57C9C7EEDE4B40BC5AEECC04C74240CD57C9C7EEDE4B40BC5AEECC04C7424000CADFBDA3DE4B403F8D7BF31BC6424000CADFBDA3DE4B40
12752	1	37.436346	37.445554000000001	55.725351000000003	55.725022000000003	Ращупкина	0103000020E61000000100000005000000C6DE8B2FDAB74240B5705985CDDC4B40C6DE8B2FDAB742407A8F334DD8DC4B400E4DD9E907B942407A8F334DD8DC4B400E4DD9E907B94240B5705985CDDC4B40C6DE8B2FDAB74240B5705985CDDC4B40
1858	1	37.568452000000001	37.593254999999999	55.576258000000003	55.571714	Ратная улица	0103000020E6100000010000000500000043ACFE08C3C842402A55A2EC2DC94B4043ACFE08C3C84240790778D2C2C94B402098A3C7EFCB4240790778D2C2C94B402098A3C7EFCB42402A55A2EC2DC94B4043ACFE08C3C842402A55A2EC2DC94B40
12754	1	37.568452000000001	37.593254999999999	55.576258000000003	55.571714	Ратная	0103000020E6100000010000000500000043ACFE08C3C842402A55A2EC2DC94B4043ACFE08C3C84240790778D2C2C94B402098A3C7EFCB4240790778D2C2C94B402098A3C7EFCB42402A55A2EC2DC94B4043ACFE08C3C842402A55A2EC2DC94B40
12665	1	37.568613999999997	37.578189999999999	55.791556999999997	55.784621999999999	Расковой	0103000020E610000001000000050000001C06F357C8C842406EDC627E6EE44B401C06F357C8C84240BEF561BD51E54B40E76F422102CA4240BEF561BD51E54B40E76F422102CA42406EDC627E6EE44B401C06F357C8C842406EDC627E6EE44B40
12965	1	37.487037999999998	37.495356999999998	55.694718000000002	55.687401000000001	Раменки	0103000020E6100000010000000500000062F4DC4257BE42406D1E87C1FCD74B4062F4DC4257BE4240A5F8F884ECD84B401E6CB1DB67BF4240A5F8F884ECD84B401E6CB1DB67BF42406D1E87C1FCD74B4062F4DC4257BE42406D1E87C1FCD74B40
5675	1	37.654035	37.673951000000002	55.860715999999996	55.857022999999998	Радужная улица	0103000020E610000001000000050000003DB83B6BB7D34240BC75FEEDB2ED4B403DB83B6BB7D342406C921FF12BEE4B40A20DC00644D642406C921FF12BEE4B40A20DC00644D64240BC75FEEDB2ED4B403DB83B6BB7D34240BC75FEEDB2ED4B40
12722	1	37.654035	37.673951000000002	55.860715999999996	55.857022999999998	Радужная	0103000020E610000001000000050000003DB83B6BB7D34240BC75FEEDB2ED4B403DB83B6BB7D342406C921FF12BEE4B40A20DC00644D642406C921FF12BEE4B40A20DC00644D64240BC75FEEDB2ED4B403DB83B6BB7D34240BC75FEEDB2ED4B40
13038	1	37.671193000000002	37.685367999999997	55.764429999999997	55.762124999999997	Радио	0103000020E61000000100000005000000EE26F8A6E9D54240643BDF4F8DE14B40EE26F8A6E9D54240670A9DD7D8E14B40CADC7C23BAD74240670A9DD7D8E14B40CADC7C23BAD74240643BDF4F8DE14B40EE26F8A6E9D54240643BDF4F8DE14B40
12580	1	37.680974999999997	37.688360000000003	55.745959999999997	55.740157000000004	Рабочая	0103000020E61000000100000005000000613255302AD74240E773EE76BDDE4B40613255302AD74240E40F069E7BDF4B40F2EF332E1CD84240E40F069E7BDF4B40F2EF332E1CD84240E773EE76BDDE4B40613255302AD74240E773EE76BDDE4B40
843	1	37.345545000000001	37.390433000000002	55.863641000000001	55.833303999999998	Пятницкое шоссе	0103000020E61000000100000005000000EE258DD13AAC424020D099B4A9EA4B40EE258DD13AAC42400C3ECDC98BEE4B40BC2363B5F9B142400C3ECDC98BEE4B40BC2363B5F9B1424020D099B4A9EA4B40EE258DD13AAC424020D099B4A9EA4B40
13197	1	37.625433000000001	37.628523000000001	55.745975000000001	55.729872999999998	Пятницкая	0103000020E610000001000000050000006A6B44300ED04240E09D7C7A6CDD4B406A6B44300ED042401A51DA1B7CDF4B4054E4107173D042401A51DA1B7CDF4B4054E4107173D04240E09D7C7A6CDD4B406A6B44300ED04240E09D7C7A6CDD4B40
13131	1	37.525423000000004	37.530327999999997	55.728377999999999	55.724012999999999	Пырьева	0103000020E610000001000000050000007AC8940F41C342407E703E75ACDC4B407AC8940F41C342401D90847D3BDD4B409813B4C9E1C342401D90847D3BDD4B409813B4C9E1C342407E703E75ACDC4B407AC8940F41C342407E703E75ACDC4B40
5560	1	37.569890000000001	37.587029999999999	55.888215000000002	55.873466000000001	Путевой проезд	0103000020E61000000100000005000000A228D027F2C842407F15E0BBCDEF4B40A228D027F2C8424088687407B1F14B40ACE28DCC23CB424088687407B1F14B40ACE28DCC23CB42407F15E0BBCDEF4B40A228D027F2C842407F15E0BBCDEF4B40
3623	1	37.478665999999997	37.489589000000002	55.845900999999998	55.843257000000001	Пулковская улица	0103000020E6100000010000000500000083DA6FED44BD4240C18F6AD8EFEB4B4083DA6FED44BD4240AC53E57B46EC4B409DBD33DAAABE4240AC53E57B46EC4B409DBD33DAAABE4240C18F6AD8EFEB4B4083DA6FED44BD4240C18F6AD8EFEB4B40
12917	1	37.549596999999999	37.557098000000003	55.906647999999997	55.897906999999996	Псковская 	0103000020E61000000100000005000000677DCA3159C64240BBECD79DEEF24B40677DCA3159C64240ED7DAA0A0DF44B406155BDFC4EC74240ED7DAA0A0DF44B406155BDFC4EC74240BBECD79DEEF24B40677DCA3159C64240BBECD79DEEF24B40
12742	1	37.549596999999999	37.557098000000003	55.906647999999997	55.897906999999996	Псковская	0103000020E61000000100000005000000677DCA3159C64240BBECD79DEEF24B40677DCA3159C64240ED7DAA0A0DF44B406155BDFC4EC74240ED7DAA0A0DF44B406155BDFC4EC74240BBECD79DEEF24B40677DCA3159C64240BBECD79DEEF24B40
13039	1	37.707394999999998	37.725155000000001	55.879086000000001	55.865586	Проходчиков	0103000020E610000001000000050000004D2D5BEB8BDA42400FF0A485CBEE4B404D2D5BEB8BDA42408C2FDAE385F04B40F4C308E1D1DC42408C2FDAE385F04B40F4C308E1D1DC42400FF0A485CBEE4B404D2D5BEB8BDA42400FF0A485CBEE4B40
82	1	37.492032999999999	37.573393000000003	55.687604	55.611170000000001	Профсоюзная улица	0103000020E61000000100000005000000C1C6F5EFFABE4240EE258DD13ACE4B40C1C6F5EFFABE4240A54C6A6803D84B40AF601BF164C94240A54C6A6803D84B40AF601BF164C94240EE258DD13ACE4B40C1C6F5EFFABE4240EE258DD13ACE4B40
13093	1	37.492032999999999	37.573393000000003	55.687604	55.611170000000001	Профсоюзная 	0103000020E61000000100000005000000C1C6F5EFFABE4240EE258DD13ACE4B40C1C6F5EFFABE4240A54C6A6803D84B40AF601BF164C94240A54C6A6803D84B40AF601BF164C94240EE258DD13ACE4B40C1C6F5EFFABE4240EE258DD13ACE4B40
12427	1	37.492032999999999	37.573393000000003	55.687604	55.611170000000001	Профсоюзная	0103000020E61000000100000005000000C1C6F5EFFABE4240EE258DD13ACE4B40C1C6F5EFFABE4240A54C6A6803D84B40AF601BF164C94240A54C6A6803D84B40AF601BF164C94240EE258DD13ACE4B40C1C6F5EFFABE4240EE258DD13ACE4B40
924	1	37.633122	37.644306	55.780532000000001	55.779671	Протопоповский переулок	0103000020E61000000100000005000000663046240AD14240DF516342CCE34B40663046240AD14240A1BDFA78E8E34B40EC4E779E78D24240A1BDFA78E8E34B40EC4E779E78D24240DF516342CCE34B40663046240AD14240DF516342CCE34B40
13107	1	37.845205	37.846615999999997	55.703631000000001	55.699750999999999	Пронская 	0103000020E6100000010000000500000035B56CAD2FEC4240F12BD67091D94B4035B56CAD2FEC4240D4B9A29410DA4B409A22C0E95DEC4240D4B9A29410DA4B409A22C0E95DEC4240F12BD67091D94B4035B56CAD2FEC4240F12BD67091D94B40
6474	1	37.654646	37.662677000000002	55.651364000000001	55.629328000000001	Пролетарский проспект	0103000020E61000000100000005000000863AAC70CBD34240823AE5D18DD04B40863AAC70CBD3424058E542E55FD34B40DC679599D2D4424058E542E55FD34B40DC679599D2D44240823AE5D18DD04B40863AAC70CBD34240823AE5D18DD04B40
5602	1	37.379761000000002	37.388933000000002	55.652405000000002	55.640030000000003	Производственная улица	0103000020E61000000100000005000000ECA529029CB04240BD3AC780ECD14B40ECA529029CB042409A5FCD0182D34B40E7AA798EC8B142409A5FCD0182D34B40E7AA798EC8B14240BD3AC780ECD14B40ECA529029CB04240BD3AC780ECD14B40
1468	1	37.515757000000001	37.520949999999999	55.761127000000002	55.759110999999997	Причальный проезд	0103000020E610000001000000050000006FD74B5304C2424055849B8C2AE14B406FD74B5304C24240228D0A9C6CE14B40F46C567DAEC24240228D0A9C6CE14B40F46C567DAEC2424055849B8C2AE14B406FD74B5304C2424055849B8C2AE14B40
13071	1	37.370930999999999	37.373140999999997	55.649214999999998	55.639822000000002	Приречная 	0103000020E610000001000000050000004A09C1AA7AAF424073A1F2AFE5D14B404A09C1AA7AAF42404C89247A19D34B40FBE59315C3AF42404C89247A19D34B40FBE59315C3AF424073A1F2AFE5D14B404A09C1AA7AAF424073A1F2AFE5D14B40
13170	1	37.370930999999999	37.373140999999997	55.649214999999998	55.639822000000002	Приречная	0103000020E610000001000000050000004A09C1AA7AAF424073A1F2AFE5D14B404A09C1AA7AAF42404C89247A19D34B40FBE59315C3AF42404C89247A19D34B40FBE59315C3AF424073A1F2AFE5D14B404A09C1AA7AAF424073A1F2AFE5D14B40
3088	1	37.837398999999998	37.857934999999998	55.705173000000002	55.676651	Привольная улица	0103000020E61000000100000005000000FF59F3E32FEB424021E7FD7F9CD64B40FF59F3E32FEB4240D882DE1B43DA4B40008C67D0D0ED4240D882DE1B43DA4B40008C67D0D0ED424021E7FD7F9CD64B40FF59F3E32FEB424021E7FD7F9CD64B40
13162	1	37.837398999999998	37.857934999999998	55.705173000000002	55.676651	Привольная	0103000020E61000000100000005000000FF59F3E32FEB424021E7FD7F9CD64B40FF59F3E32FEB4240D882DE1B43DA4B40008C67D0D0ED4240D882DE1B43DA4B40008C67D0D0ED424021E7FD7F9CD64B40FF59F3E32FEB424021E7FD7F9CD64B40
12392	1	37.171846000000002	37.173454	55.979787000000002	55.979193000000002	Привокзальная площадь	0103000020E6100000010000000500000066F9BA0CFF9542406FBC3B3256FD4B4066F9BA0CFF954240E20511A969FD4B4021AE9CBD33964240E20511A969FD4B4021AE9CBD339642406FBC3B3256FD4B4066F9BA0CFF9542406FBC3B3256FD4B40
4413	1	37.458427	37.469791000000001	55.875632000000003	55.871178	Прибрежный проезд	0103000020E610000001000000050000003C4D66BCADBA4240527FBDC282EF4B403C4D66BCADBA424061AA99B514F04B40427A8A1C22BC424061AA99B514F04B40427A8A1C22BC4240527FBDC282EF4B403C4D66BCADBA4240527FBDC282EF4B40
12962	1	37.586266000000002	37.601833999999997	55.744495000000001	55.738636999999997	Пречистенка	0103000020E61000000100000005000000DD60A8C30ACB4240CA4E3FA88BDE4B40DD60A8C30ACB42408C84B69C4BDF4B4078CF81E508CD42408C84B69C4BDF4B4078CF81E508CD4240CA4E3FA88BDE4B40DD60A8C30ACB4240CA4E3FA88BDE4B40
12522	1	37.573878000000001	37.584747999999998	55.791719000000001	55.781626000000003	Правды	0103000020E610000001000000050000006BF294D574C9424006DA1D520CE44B406BF294D574C94240984F560C57E54B406133C005D9CA4240984F560C57E54B406133C005D9CA424006DA1D520CE44B406BF294D574C9424006DA1D520CE44B40
7731	1	37.404735000000002	37.424622999999997	55.844344	55.830705000000002	Походный проезд	0103000020E61000000100000005000000F645425BCEB34240D5CF9B8A54EA4B40F645425BCEB342407349D57613EC4B409010E50B5AB642407349D57613EC4B409010E50B5AB64240D5CF9B8A54EA4B40F645425BCEB34240D5CF9B8A54EA4B40
180	1	37.638610999999997	37.641683	55.762220999999997	55.758802000000003	Потаповский переулок	0103000020E61000000100000005000000D4EE5701BED14240D811876C20E14B40D4EE5701BED1424086A92D7590E14B4018B325AB22D2424086A92D7590E14B4018B325AB22D24240D811876C20E14B40D4EE5701BED14240D811876C20E14B40
12886	1	37.538763000000003	37.572826999999997	55.581088000000001	55.550336000000001	Поляны	0103000020E61000000100000005000000BEA59C2FF6C44240DEE7F86871C64B40BEA59C2FF6C442408D0C721761CA4B4005A2276552C942408D0C721761CA4B4005A2276552C94240DEE7F86871C64B40BEA59C2FF6C44240DEE7F86871C64B40
13122	1	37.572468000000001	37.574219999999997	55.800499000000002	55.791849999999997	Полтавская	0103000020E61000000100000005000000D600A5A146C9424036AB3E575BE54B40D600A5A146C9424088BD50C076E64B40C45A7C0A80C9424088BD50C076E64B40C45A7C0A80C9424036AB3E575BE54B40D600A5A146C9424036AB3E575BE54B40
12506	1	37.423878000000002	37.424857000000003	55.737425999999999	55.727815	Полоцкая	0103000020E6100000010000000500000038BF61A241B64240E544BB0A29DD4B4038BF61A241B642402C9CA4F963DE4B40043DD4B661B642402C9CA4F963DE4B40043DD4B661B64240E544BB0A29DD4B4038BF61A241B64240E544BB0A29DD4B40
12773	1	37.795088	37.804178999999998	55.748345999999998	55.745179	Полимерная 	0103000020E6100000010000000500000095B88E71C5E542403F55850662DF4B4095B88E71C5E54240D40B3ECDC9DF4B40A3906456EFE64240D40B3ECDC9DF4B40A3906456EFE642403F55850662DF4B4095B88E71C5E542403F55850662DF4B40
12787	1	37.545644000000003	37.555121	55.780664000000002	55.776283999999997	Поликарпова	0103000020E610000001000000050000001BA19FA9D7C542403B342C465DE34B401BA19FA9D7C54240109546CCECE34B40522976340EC74240109546CCECE34B40522976340EC742403B342C465DE34B401BA19FA9D7C542403B342C465DE34B40
12651	1	37.720132999999997	37.732762999999998	55.691679000000001	55.666547999999999	Полбина	0103000020E610000001000000050000009BE271512DDC42406B9BE27151D54B409BE271512DDC42403D2AFEEF88D84B40035C902DCBDD42403D2AFEEF88D84B40035C902DCBDD42406B9BE27151D54B409BE271512DDC42406B9BE27151D54B40
3590	1	37.518487999999998	37.532592000000001	55.739193999999998	55.733280000000001	Поклонная улица	0103000020E6100000010000000500000029AF95D05DC24240CB67791EDCDD4B4029AF95D05DC2424020B3B3E89DDE4B403D0E83F92BC4424020B3B3E89DDE4B403D0E83F92BC44240CB67791EDCDD4B4029AF95D05DC24240CB67791EDCDD4B40
13206	1	37.518487999999998	37.532592000000001	55.739193999999998	55.733280000000001	Поклонная	0103000020E6100000010000000500000029AF95D05DC24240CB67791EDCDD4B4029AF95D05DC2424020B3B3E89DDE4B403D0E83F92BC4424020B3B3E89DDE4B403D0E83F92BC44240CB67791EDCDD4B4029AF95D05DC24240CB67791EDCDD4B40
12726	1	37.704456999999998	37.707583999999997	55.743644000000003	55.736316000000002	Подъемная	0103000020E610000001000000050000001938A0A52BDA4240C2C2499A3FDE4B401938A0A52BDA4240EEEE01BA2FDF4B402096CD1C92DA4240EEEE01BA2FDF4B402096CD1C92DA4240C2C2499A3FDE4B401938A0A52BDA4240C2C2499A3FDE4B40
12464	1	37.609164	37.639508999999997	55.610143000000001	55.587631000000002	Подольских Курсантов	0103000020E6100000010000000500000045F30016F9CD4240D28E1B7E37CB4B4045F30016F9CD42401171732A19CE4B40B33F506EDBD142401171732A19CE4B40B33F506EDBD14240D28E1B7E37CB4B4045F30016F9CD4240D28E1B7E37CB4B40
12794	1	37.708060000000003	37.713853999999998	55.656163999999997	55.646889000000002	Подольская	0103000020E610000001000000050000008ACDC7B5A1DA424032923D42CDD24B408ACDC7B5A1DA42400168942EFDD34B40340F60915FDB42400168942EFDD34B40340F60915FDB424032923D42CDD24B408ACDC7B5A1DA424032923D42CDD24B40
13111	1	37.535215000000001	37.537919000000002	55.765853	55.756746	Подвойского	0103000020E6100000010000000500000011AAD4EC81C442407DB08C0DDDE04B4011AAD4EC81C4424091459A7807E24B40D272A087DAC4424091459A7807E24B40D272A087DAC442407DB08C0DDDE04B4011AAD4EC81C442407DB08C0DDDE04B40
12791	1	37.760952000000003	37.761321000000002	55.747276999999997	55.738875	Плющева	0103000020E61000000100000005000000B4E908E066E142407F6ABC7493DE4B40B4E908E066E14240C806D2C5A6DF4B4007616EF772E14240C806D2C5A6DF4B4007616EF772E142407F6ABC7493DE4B40B4E908E066E142407F6ABC7493DE4B40
12811	1	37.605724000000002	37.622081999999999	55.890946	55.884216000000002	Плещеева	0103000020E610000001000000050000007F33315D88CD4240CB4C69FD2DF14B407F33315D88CD42404240BE840AF24B4013B70A62A0CF42404240BE840AF24B4013B70A62A0CF4240CB4C69FD2DF14B407F33315D88CD4240CB4C69FD2DF14B40
12878	1	37.537739000000002	37.553361000000002	55.806550000000001	55.797792000000001	Планетная	0103000020E610000001000000050000005264ADA1D4C4424056815A0C1EE64B405264ADA1D4C442405E4BC8073DE74B40E1F08288D4C642405E4BC8073DE74B40E1F08288D4C6424056815A0C1EE64B405264ADA1D4C4424056815A0C1EE64B40
875	1	37.431648000000003	37.441187999999997	55.871476000000001	55.857619	Планерная улица	0103000020E6100000010000000500000021B1DD3D40B74240D0B69A75C6ED4B4021B1DD3D40B74240DC9F8B868CEF4B409EB12FD978B84240DC9F8B868CEF4B409EB12FD978B84240D0B69A75C6ED4B4021B1DD3D40B74240D0B69A75C6ED4B40
13008	1	37.431648000000003	37.441187999999997	55.871476000000001	55.857619	Планерная	0103000020E6100000010000000500000021B1DD3D40B74240D0B69A75C6ED4B4021B1DD3D40B74240DC9F8B868CEF4B409EB12FD978B84240DC9F8B868CEF4B409EB12FD978B84240D0B69A75C6ED4B4021B1DD3D40B74240D0B69A75C6ED4B40
12941	1	37.568613999999997	37.582115999999999	55.798099999999998	55.797311000000001	Писцовая	0103000020E610000001000000050000001C06F357C8C84240DBDE6E490EE64B401C06F357C8C8424003780B2428E64B403A3DEFC682CA424003780B2428E64B403A3DEFC682CA4240DBDE6E490EE64B401C06F357C8C84240DBDE6E490EE64B40
13089	1	37.655768999999999	37.674534999999999	55.865535999999999	55.863236999999998	Печорская	0103000020E61000000100000005000000855D143DF0D342403CD9CD8C7EEE4B40855D143DF0D342405DC136E2C9EE4B40F180B22957D642405DC136E2C9EE4B40F180B22957D642403CD9CD8C7EEE4B40855D143DF0D342403CD9CD8C7EEE4B40
13238	1	37.484746999999999	37.505021999999997	55.867091000000002	55.862313	Петрозаводская	0103000020E61000000100000005000000C4EA8F300CBE424034F5BA4560EE4B40C4EA8F300CBE4240F6D37FD6FCEE4B4058E1968FA4C04240F6D37FD6FCEE4B4058E1968FA4C0424034F5BA4560EE4B40C4EA8F300CBE424034F5BA4560EE4B40
4499	1	37.561517000000002	37.569611000000002	55.805168999999999	55.790883999999998	Петровско-Разумовский проезд	0103000020E61000000100000005000000F392FFC9DFC74240FF76D9AF3BE54B40F392FFC9DFC7424063601DC70FE74B408F386403E9C8424063601DC70FE74B408F386403E9C84240FF76D9AF3BE54B40F392FFC9DFC74240FF76D9AF3BE54B40
2594	1	37.553719999999998	37.571497999999998	55.797797000000003	55.789729999999999	Петровско-Разумовская аллея	0103000020E610000001000000050000001092054CE0C64240C55565DF15E54B401092054CE0C6424068EC4B361EE64B405DDDB1D826C9424068EC4B361EE64B405DDDB1D826C94240C55565DF15E54B401092054CE0C64240C55565DF15E54B40
12702	1	37.611598999999998	37.620061	55.770207999999997	55.758813000000004	Петровка	0103000020E6100000010000000500000016A243E048CE4240CC63CDC820E14B4016A243E048CE42400C8FFD2C96E24B403543AA285ECF42400C8FFD2C96E24B403543AA285ECF4240CC63CDC820E14B4016A243E048CE4240CC63CDC820E14B40
12746	1	37.679017000000002	37.684272	55.710641000000003	55.705101999999997	Петра Романова	0103000020E61000000100000005000000CA367007EAD642400E2C47C840DA4B40CA367007EAD642402F19C748F6DA4B40C5C8923996D742402F19C748F6DA4B40C5C8923996D742400E2C47C840DA4B40CA367007EAD642400E2C47C840DA4B40
4727	1	37.510205999999997	37.512495999999999	55.801611999999999	55.796146999999998	Песчаный переулок	0103000020E610000001000000050000008A1C226E4EC142407DE71725E8E54B408A1C226E4EC14240630AD6389BE64B4058AA0B7899C14240630AD6389BE64B4058AA0B7899C142407DE71725E8E54B408A1C226E4EC142407DE71725E8E54B40
13042	1	37.506405999999998	37.517051000000002	55.804071	55.801288	Песчаная	0103000020E61000000100000005000000C43F6CE9D1C04240B056ED9A90E64B40C43F6CE9D1C04240BD546CCCEBE64B409BAE27BA2EC24240BD546CCCEBE64B409BAE27BA2EC24240B056ED9A90E64B40C43F6CE9D1C04240B056ED9A90E64B40
12950	1	37.612847000000002	37.614832	55.867874	55.861646	Пестеля	0103000020E61000000100000005000000D2393FC571CE4240575D876A4AEE4B40D2393FC571CE42403C86C77E16EF4B406344A2D0B2CE42403C86C77E16EF4B406344A2D0B2CE4240575D876A4AEE4B40D2393FC571CE4240575D876A4AEE4B40
4706	1	37.732691000000003	37.760278999999997	55.737420999999998	55.733471999999999	Перовское шоссе	0103000020E610000001000000050000006A8995D1C8DD42400F441669E2DD4B406A8995D1C8DD42401A31B3CF63DE4B40F46A80D250E142401A31B3CF63DE4B40F46A80D250E142400F441669E2DD4B406A8995D1C8DD42400F441669E2DD4B40
12870	1	37.750154999999999	37.814464999999998	55.747864999999997	55.744140000000002	Перовская	0103000020E6100000010000000500000027F73B1405E042409ED2C1FA3FDF4B4027F73B1405E042405969520ABADF4B404A5E9D6340E842405969520ABADF4B404A5E9D6340E842409ED2C1FA3FDF4B4027F73B1405E042409ED2C1FA3FDF4B40
4551	1	37.761311999999997	37.776305000000001	55.664233000000003	55.652329000000002	Перервинский бульвар	0103000020E61000000100000005000000B306EFAB72E14240BF9D44847FD34B40B306EFAB72E1424045F6419605D54B40535C55F65DE3424045F6419605D54B40535C55F65DE34240BF9D44847FD34B40B306EFAB72E14240BF9D44847FD34B40
12797	1	37.713853999999998	37.792096999999998	55.675448000000003	55.651623000000001	Перерва	0103000020E61000000100000005000000340F60915FDB42402429E96168D34B40340F60915FDB424006137F1475D64B403E213B6F63E5424006137F1475D64B403E213B6F63E542402429E96168D34B40340F60915FDB42402429E96168D34B40
12836	1	37.562702999999999	37.58614	55.661195999999997	55.658495000000002	Перекопская	0103000020E61000000100000005000000382EE3A606C842402ECA6C9049D44B40382EE3A606C842407D1F0E12A2D44B405070B1A206CB42407D1F0E12A2D44B405070B1A206CB42402ECA6C9049D44B40382EE3A606C842402ECA6C9049D44B40
445	1	37.682116000000001	37.694253000000003	55.781174999999998	55.776401	Переведеновский переулок	0103000020E61000000100000005000000070ABC934FD7424075CAA31B61E34B40070ABC934FD74240F5B9DA8AFDE34B4030134548DDD84240F5B9DA8AFDE34B4030134548DDD8424075CAA31B61E34B40070ABC934FD7424075CAA31B61E34B40
13173	1	37.762273	37.823447999999999	55.793677000000002	55.788338000000003	Первомайская улица	0103000020E61000000100000005000000D9CF622992E14240D7187442E8E44B40D9CF622992E14240304B3B3597E54B4072FA7ABE66E94240304B3B3597E54B4072FA7ABE66E94240D7187442E8E44B40D9CF622992E14240D7187442E8E44B40
13040	1	37.762273	37.823447999999999	55.793677000000002	55.788338000000003	Первомайская	0103000020E61000000100000005000000D9CF622992E14240D7187442E8E44B40D9CF622992E14240304B3B3597E54B4072FA7ABE66E94240304B3B3597E54B4072FA7ABE66E94240D7187442E8E44B40D9CF622992E14240D7187442E8E44B40
12994	1	37.352227999999997	37.360951	55.838759000000003	55.832227000000003	Пенягинская	0103000020E61000000100000005000000245E9ECE15AD424092EC116A86EA4B40245E9ECE15AD4240E31C75745CEB4B40B03A72A433AE4240E31C75745CEB4B40B03A72A433AE424092EC116A86EA4B40245E9ECE15AD424092EC116A86EA4B40
13007	1	37.663054000000002	37.672072999999997	55.596294999999998	55.594971999999999	Педагогическая	0103000020E61000000100000005000000B2BD16F4DED442409204E10A28CC4B40B2BD16F4DED4424058E2016553CC4B4026C3F17C06D6424058E2016553CC4B4026C3F17C06D642409204E10A28CC4B40B2BD16F4DED442409204E10A28CC4B40
12719	1	37.535429999999998	37.542670999999999	55.604019999999998	55.596812999999997	Паустовского	0103000020E610000001000000050000000DA661F888C44240F0694E5E64CC4B400DA661F888C44240A110018750CD4B406ABE4A3E76C54240A110018750CD4B406ABE4A3E76C54240F0694E5E64CC4B400DA661F888C44240F0694E5E64CC4B40
12879	1	37.448366	37.465747999999998	55.789541999999997	55.789011000000002	Паршина	0103000020E61000000100000005000000B5519D0E64B942409697FC4FFEE44B40B5519D0E64B94240C26856B60FE54B40B51666A19DBB4240C26856B60FE54B40B51666A19DBB42409697FC4FFEE44B40B5519D0E64B942409697FC4FFEE44B40
4036	1	37.399200999999998	37.411983999999997	55.742852999999997	55.728231000000001	Партизанская улица	0103000020E61000000100000005000000E7C3B30419B34240797764AC36DD4B40E7C3B30419B34240245E9ECE15DF4B40D53C47E4BBB44240245E9ECE15DF4B40D53C47E4BBB44240797764AC36DD4B40E7C3B30419B34240797764AC36DD4B40
13059	1	37.399200999999998	37.411983999999997	55.742852999999997	55.728231000000001	Партизанская 	0103000020E61000000100000005000000E7C3B30419B34240797764AC36DD4B40E7C3B30419B34240245E9ECE15DF4B40D53C47E4BBB44240245E9ECE15DF4B40D53C47E4BBB44240797764AC36DD4B40E7C3B30419B34240797764AC36DD4B40
12632	1	37.399200999999998	37.411983999999997	55.742852999999997	55.728231000000001	Партизанская	0103000020E61000000100000005000000E7C3B30419B34240797764AC36DD4B40E7C3B30419B34240245E9ECE15DF4B40D53C47E4BBB44240245E9ECE15DF4B40D53C47E4BBB44240797764AC36DD4B40E7C3B30419B34240797764AC36DD4B40
6063	1	37.758662000000001	37.763863000000001	55.640945000000002	55.635071000000003	Паромная улица	0103000020E61000000100000005000000E65B1FD61BE14240ABD1AB014AD14B40E65B1FD61BE1424072C45A7C0AD24B40EECF4543C6E1424072C45A7C0AD24B40EECF4543C6E14240ABD1AB014AD14B40E65B1FD61BE14240ABD1AB014AD14B40
12507	1	37.490181999999997	37.500692999999998	55.809883999999997	55.797938000000002	Панфилова	0103000020E610000001000000050000003F8BA548BEBE42402A1E17D522E64B403F8BA548BEBE4240DEC66647AAE74B40062B4EB516C04240DEC66647AAE74B40062B4EB516C042402A1E17D522E64B403F8BA548BEBE42402A1E17D522E64B40
7500	1	37.690282000000003	37.715066999999998	55.879100999999999	55.861488999999999	Палехская улица	0103000020E610000001000000050000003D821B295BD842408F6E844545EE4B403D821B295BD84240C170AE6186F04B4073B9C15087DB4240C170AE6186F04B4073B9C15087DB42408F6E844545EE4B403D821B295BD842408F6E844545EE4B40
13142	1	37.690282000000003	37.715066999999998	55.879100999999999	55.861488999999999	Палехская 	0103000020E610000001000000050000003D821B295BD842408F6E844545EE4B403D821B295BD84240C170AE6186F04B4073B9C15087DB4240C170AE6186F04B4073B9C15087DB42408F6E844545EE4B403D821B295BD842408F6E844545EE4B40
13041	1	37.690282000000003	37.715066999999998	55.879100999999999	55.861488999999999	Палехская	0103000020E610000001000000050000003D821B295BD842408F6E844545EE4B403D821B295BD84240C170AE6186F04B4073B9C15087DB4240C170AE6186F04B4073B9C15087DB42408F6E844545EE4B403D821B295BD842408F6E844545EE4B40
12776	1	37.627274	37.627822000000002	55.721812	55.711463000000002	Павловская	0103000020E61000000100000005000000C8D0B1834AD0424033A8363811DB4B40C8D0B1834AD0424020EEEA5564DC4B40CBDAA6785CD0424020EEEA5564DC4B40CBDAA6785CD0424033A8363811DB4B40C8D0B1834AD0424033A8363811DB4B40
12528	1	37.654251000000002	37.664257999999997	55.820819	55.811380999999997	Павла Корчагина	0103000020E610000001000000050000000A302C7FBED3424042CC2555DBE74B400A302C7FBED34240BC77D49810E94B409D0DF96706D54240BC77D49810E94B409D0DF96706D5424042CC2555DBE74B400A302C7FBED3424042CC2555DBE74B40
983	1	37.636679999999998	37.641638	55.732033000000001	55.730029999999999	Павелецкая площадь	0103000020E610000001000000050000003602F1BA7ED14240A88C7F9F71DD4B403602F1BA7ED14240E04BE141B3DD4B4078EFA83121D24240E04BE141B3DD4B4078EFA83121D24240A88C7F9F71DD4B403602F1BA7ED14240A88C7F9F71DD4B40
4869	1	37.436562000000002	37.461975000000002	55.698121999999998	55.685960000000001	Очаковское шоссе	0103000020E6100000010000000500000093567C43E1B742409D2E8B89CDD74B4093567C43E1B742401E4FCB0F5CD94B40E9482EFF21BB42401E4FCB0F5CD94B40E9482EFF21BB42409D2E8B89CDD74B4093567C43E1B742409D2E8B89CDD74B40
6848	1	37.601357999999998	37.619782000000001	55.859983999999997	55.854081999999998	Отрадная улица	0103000020E610000001000000050000000F98874CF9CC4240170D198F52ED4B400F98874CF9CC4240A88AA9F413EE4B4022533E0455CF4240A88AA9F413EE4B4022533E0455CF4240170D198F52ED4B400F98874CF9CC4240170D198F52ED4B40
12765	1	37.601357999999998	37.619782000000001	55.859983999999997	55.854081999999998	Отрадная	0103000020E610000001000000050000000F98874CF9CC4240170D198F52ED4B400F98874CF9CC4240A88AA9F413EE4B4022533E0455CF4240A88AA9F413EE4B4022533E0455CF4240170D198F52ED4B400F98874CF9CC4240170D198F52ED4B40
1092	1	37.724139999999998	37.768247000000002	55.829770000000003	55.806534999999997	Открытое шоссе	0103000020E61000000100000005000000DBDC989EB0DC4240280AF4893CE74B40DBDC989EB0DC4240D99942E735EA4B400420EEEA55E24240D99942E735EA4B400420EEEA55E24240280AF4893CE74B40DBDC989EB0DC4240280AF4893CE74B40
12884	1	37.525261	37.531038000000002	55.800356999999998	55.799461000000001	Острякова	0103000020E61000000100000005000000A06EA0C03BC34240B7B6F0BC54E64B40A06EA0C03BC34240F50F221972E64B4075779D0DF9C34240F50F221972E64B4075779D0DF9C34240B7B6F0BC54E64B40A06EA0C03BC34240B7B6F0BC54E64B40
12470	1	37.481406	37.540658999999998	55.649403	55.631599999999999	Островитянова	0103000020E61000000100000005000000910C39B69EBD4240A913D044D8D04B40910C39B69EBD42404F7633A31FD34B40DFA4695034C542404F7633A31FD34B40DFA4695034C54240A913D044D8D04B40910C39B69EBD4240A913D044D8D04B40
5803	1	37.672378999999999	37.684398000000002	55.895302999999998	55.872338999999997	Осташковская улица	0103000020E6100000010000000500000033C2DB8310D642403E03EACDA8EF4B4033C2DB8310D642405E81E84999F24B4052B9895A9AD742405E81E84999F24B4052B9895A9AD742403E03EACDA8EF4B4033C2DB8310D642403E03EACDA8EF4B40
13134	1	37.672378999999999	37.684398000000002	55.895302999999998	55.872338999999997	Осташковская	0103000020E6100000010000000500000033C2DB8310D642403E03EACDA8EF4B4033C2DB8310D642405E81E84999F24B4052B9895A9AD742405E81E84999F24B4052B9895A9AD742403E03EACDA8EF4B4033C2DB8310D642403E03EACDA8EF4B40
3845	1	37.397053999999997	37.405470999999999	55.771596000000002	55.756856999999997	Осенняя улица	0103000020E610000001000000050000007C5F5CAAD2B24240D45FAFB0E0E04B407C5F5CAAD2B24240BADC60A8C3E24B40FB3C4679E6B34240BADC60A8C3E24B40FB3C4679E6B34240D45FAFB0E0E04B407C5F5CAAD2B24240D45FAFB0E0E04B40
3800	1	37.406359999999999	37.409109000000001	55.764100999999997	55.751913000000002	Осенний бульвар	0103000020E610000001000000050000008733BF9A03B44240F83768AF3EE04B408733BF9A03B44240A2EBC20FCEE14B40E8BF07AF5DB44240A2EBC20FCEE14B40E8BF07AF5DB44240F83768AF3EE04B408733BF9A03B44240F83768AF3EE04B40
2326	1	37.401437999999999	37.412846000000002	55.744348000000002	55.738885000000003	Оршанская улица	0103000020E6100000010000000500000092AF045262B34240A3409FC893DE4B4092AF045262B34240E86B96CB46DF4B4068244223D8B44240E86B96CB46DF4B4068244223D8B44240A3409FC893DE4B4092AF045262B34240A3409FC893DE4B40
13063	1	37.401437999999999	37.412846000000002	55.744348000000002	55.738885000000003	Оршанская 	0103000020E6100000010000000500000092AF045262B34240A3409FC893DE4B4092AF045262B34240E86B96CB46DF4B4068244223D8B44240E86B96CB46DF4B4068244223D8B44240A3409FC893DE4B4092AF045262B34240A3409FC893DE4B40
6241	1	37.729582999999998	37.742268000000003	55.626776999999997	55.613168000000002	Ореховый проезд	0103000020E61000000100000005000000D95BCAF962DD4240147AFD497CCE4B40D95BCAF962DD424047718E3A3AD04B40056F48A302DF424047718E3A3AD04B40056F48A302DF4240147AFD497CCE4B40D95BCAF962DD4240147AFD497CCE4B40
2515	1	37.699840000000002	37.762830000000001	55.620199	55.607509	Ореховый бульвар	0103000020E6100000010000000500000061376C5B94D942404983DBDAC2CD4B4061376C5B94D9424086014BAE62CF4B402F34D769A4E1424086014BAE62CF4B402F34D769A4E142404983DBDAC2CD4B4061376C5B94D942404983DBDAC2CD4B40
4721	1	37.739607999999997	37.760683	55.732514000000002	55.731419000000002	Орехово-Зуевский проезд	0103000020E6100000010000000500000013EE9579ABDE4240265646239FDD4B4013EE9579ABDE42405BEECC04C3DD4B40C4CF7F0F5EE142405BEECC04C3DD4B40C4CF7F0F5EE14240265646239FDD4B4013EE9579ABDE4240265646239FDD4B40
12434	1	37.855159	37.866171999999999	55.714196000000001	55.711868000000003	Оренбургская	0103000020E61000000100000005000000A6F0A0D975ED4240D388997D1EDB4B40A6F0A0D975ED42408E7747C66ADB4B40FF5A5EB9DEEE42408E7747C66ADB4B40FF5A5EB9DEEE4240D388997D1EDB4B40A6F0A0D975ED4240D388997D1EDB4B40
13031	1	37.589114000000002	37.606011000000002	55.711320999999998	55.709743000000003	Орджоникидзе	0103000020E61000000100000005000000D1CE691668CB424050C8CEDBD8DA4B40D1CE691668CB4240A0FA07910CDB4B401502B9C491CD4240A0FA07910CDB4B401502B9C491CD424050C8CEDBD8DA4B40D1CE691668CB424050C8CEDBD8DA4B40
3551	1	37.504933000000001	37.522387000000002	55.862141000000001	55.841695000000001	Онежская улица	0103000020E61000000100000005000000E9D500A5A1C04240761A69A9BCEB4B40E9D500A5A1C0424037C5E3A25AEE4B40836DC493DDC2424037C5E3A25AEE4B40836DC493DDC24240761A69A9BCEB4B40E9D500A5A1C04240761A69A9BCEB4B40
12989	1	37.504933000000001	37.522387000000002	55.862141000000001	55.841695000000001	Онежская 	0103000020E61000000100000005000000E9D500A5A1C04240761A69A9BCEB4B40E9D500A5A1C0424037C5E3A25AEE4B40836DC493DDC2424037C5E3A25AEE4B40836DC493DDC24240761A69A9BCEB4B40E9D500A5A1C04240761A69A9BCEB4B40
12505	1	37.504933000000001	37.522387000000002	55.862141000000001	55.841695000000001	Онежская	0103000020E61000000100000005000000E9D500A5A1C04240761A69A9BCEB4B40E9D500A5A1C0424037C5E3A25AEE4B40836DC493DDC2424037C5E3A25AEE4B40836DC493DDC24240761A69A9BCEB4B40E9D500A5A1C04240761A69A9BCEB4B40
5792	1	37.660018000000001	37.662551000000001	55.878343999999998	55.873702999999999	Олонецкий проезд	0103000020E61000000100000005000000BB6246787BD4424063B5F97FD5EF4B40BB6246787BD44240A45181936DF04B404F779E78CED44240A45181936DF04B404F779E78CED4424063B5F97FD5EF4B40BB6246787BD4424063B5F97FD5EF4B40
13126	1	37.615893	37.620348	55.859236000000003	55.850155999999998	Олонецкая	0103000020E61000000100000005000000EC6AF294D5CE4240C43F6CE9D1EC4B40EC6AF294D5CE4240DFC5FB71FBED4B40CB11329067CF4240DFC5FB71FBED4B40CB11329067CF4240C43F6CE9D1EC4B40EC6AF294D5CE4240C43F6CE9D1EC4B40
969	1	37.619943999999997	37.623941000000002	55.792625000000001	55.773868999999998	Олимпийский проспект	0103000020E61000000100000005000000FBAC32535ACF4240B131AF230EE34B40FBAC32535ACF4240FA7E6ABC74E54B4018D1764CDDCF4240FA7E6ABC74E54B4018D1764CDDCF4240B131AF230EE34B40FBAC32535ACF4240B131AF230EE34B40
12830	1	37.456792	37.473860000000002	55.680411999999997	55.669305000000001	Олимпийская деревня	0103000020E610000001000000050000008789062978BA42404F0647C9ABD54B408789062978BA424029E78BBD17D74B40F870C971A7BC424029E78BBD17D74B40F870C971A7BC42404F0647C9ABD54B408789062978BA42404F0647C9ABD54B40
13159	1	37.677785999999998	37.699129999999997	55.801374000000003	55.791967	Олений Вал	0103000020E61000000100000005000000E4D70FB1C1D642407041B62C5FE54B40E4D70FB1C1D64240AFEE586C93E64B4084D382177DD94240AFEE586C93E64B4084D382177DD942407041B62C5FE54B40E4D70FB1C1D642407041B62C5FE54B40
13149	1	37.475898999999998	37.499704000000001	55.742168999999997	55.736958999999999	Олеко Дундича	0103000020E610000001000000050000007C992842EABC424016BF29AC54DE4B407C992842EABC4240718DCF64FFDE4B4017D7F84CF6BF4240718DCF64FFDE4B4017D7F84CF6BF424016BF29AC54DE4B407C992842EABC424016BF29AC54DE4B40
6473	1	37.611472999999997	37.616790999999999	55.791029999999999	55.786423999999997	Октябрьский переулок	0103000020E6100000010000000500000089B14CBF44CE42400E65A88AA9E44B4089B14CBF44CE4240D313967840E54B40CBBBEA01F3CE4240D313967840E54B40CBBBEA01F3CE42400E65A88AA9E44B4089B14CBF44CE42400E65A88AA9E44B40
12956	1	37.612487999999999	37.613925000000002	55.800119000000002	55.784348999999999	Октябрьская 	0103000020E61000000100000005000000A298BC0166CE42403DD34B8C65E44B40A298BC0166CE424041F4A44C6AE64B4031992A1895CE424041F4A44C6AE64B4031992A1895CE42403DD34B8C65E44B40A298BC0166CE42403DD34B8C65E44B40
12937	1	37.748950999999998	37.781379999999999	55.718735000000002	55.710265999999997	Окская	0103000020E610000001000000050000003BA759A0DDDF4240F9BA0CFFE9DA4B403BA759A0DDDF4240CBBE2B82FFDB4B40CEDF844204E44240CBBE2B82FFDB4B40CEDF844204E44240F9BA0CFFE9DA4B403BA759A0DDDF4240F9BA0CFFE9DA4B40
4942	1	37.432133	37.473519000000003	55.689182000000002	55.662202000000001	Озерная улица	0103000020E61000000100000005000000DD42572250B7424043ACFE08C3D44B40DD42572250B74240F67EA31D37D84B406F8445459CBC4240F67EA31D37D84B406F8445459CBC424043ACFE08C3D44B40DD42572250B7424043ACFE08C3D44B40
13025	1	37.398321000000003	37.405157000000003	55.792847000000002	55.785097999999998	Одинцовская	0103000020E61000000100000005000000AF27BA2EFCB24240D7135D177EE44B40AF27BA2EFCB24240A9DDAF027CE54B406C5F402FDCB34240A9DDAF027CE54B406C5F402FDCB34240D7135D177EE44B40AF27BA2EFCB24240D7135D177EE44B40
12899	1	37.588413000000003	37.601123999999999	55.664912999999999	55.651465000000002	Одесская	0103000020E6100000010000000500000048C5FF1D51CB42408CBE823463D34B4048C5FF1D51CB4240B6D782DE1BD54B409C6B98A1F1CC4240B6D782DE1BD54B409C6B98A1F1CC42408CBE823463D34B4048C5FF1D51CB42408CBE823463D34B40
649	1	37.626339999999999	37.636239000000003	55.745995000000001	55.743096999999999	Овчинниковская набережная	0103000020E610000001000000050000009C16BCE82BD04240BB6070CD1DDF4B409C16BCE82BD0424061FD9FC37CDF4B404AB8904770D1424061FD9FC37CDF4B404AB8904770D14240BB6070CD1DDF4B409C16BCE82BD04240BB6070CD1DDF4B40
12672	1	37.508715000000002	37.563206000000001	55.663476000000003	55.649509999999999	Обручева	0103000020E6100000010000000500000009FEB7921DC142406536C82423D34B4009FEB7921DC1424028D714C8ECD44B409B745B2217C8424028D714C8ECD44B409B745B2217C842406536C82423D34B4009FEB7921DC142406536C82423D34B40
12743	1	37.695428999999997	37.696300999999998	55.887210000000003	55.874752999999998	Норильская	0103000020E6100000010000000500000051D845D103D94240F88903E8F7EF4B4051D845D103D942409357E71890F14B400796236420D942409357E71890F14B400796236420D94240F88903E8F7EF4B4051D845D103D94240F88903E8F7EF4B40
1161	1	37.550513000000002	37.555067999999999	55.80104	55.79851	Новый Зыковский проезд	0103000020E61000000100000005000000ED82C13577C64240B5C35F9335E64B40ED82C13577C64240D8648D7A88E64B402F87DD770CC74240D8648D7A88E64B402F87DD770CC74240B5C35F9335E64B40ED82C13577C64240B5C35F9335E64B40
3220	1	37.504421000000001	37.557124999999999	55.618898000000002	55.598533000000003	Новоясеневский проспект	0103000020E61000000100000005000000333509DE90C04240D449B6BA9CCC4B40333509DE90C04240A8C7B60C38CF4B405A643BDF4FC74240A8C7B60C38CF4B405A643BDF4FC74240D449B6BA9CCC4B40333509DE90C04240D449B6BA9CCC4B40
4227	1	37.712209999999999	37.744701999999997	55.648519	55.646161999999997	Новочеркасский бульвар	0103000020E610000001000000050000002CF180B229DB42407FF5B86FB5D24B402CF180B229DB4240D5EAABAB02D34B4005A2276552DF4240D5EAABAB02D34B4005A2276552DF42407FF5B86FB5D24B402CF180B229DB42407FF5B86FB5D24B40
2301	1	37.558723999999998	37.589590000000001	55.691307999999999	55.660775000000001	Новочеремушкинская улица	0103000020E61000000100000005000000C2BE9D4484C74240D881734694D44B40C2BE9D4484C7424049BBD1C77CD84B403A0664AF77CB424049BBD1C77CD84B403A0664AF77CB4240D881734694D44B40C2BE9D4484C74240D881734694D44B40
12572	1	37.558723999999998	37.589590000000001	55.691307999999999	55.660775000000001	Новочеремушкинская	0103000020E61000000100000005000000C2BE9D4484C74240D881734694D44B40C2BE9D4484C7424049BBD1C77CD84B403A0664AF77CB424049BBD1C77CD84B403A0664AF77CB4240D881734694D44B40C2BE9D4484C74240D881734694D44B40
7091	1	37.492759999999997	37.501832999999998	55.778416	55.778162999999999	Новохорошевский проезд	0103000020E6100000010000000500000073637AC212BF424087FA5DD89AE34B4073637AC212BF42407157AF22A3E34B40DB8651103CC042407157AF22A3E34B40DB8651103CC0424087FA5DD89AE34B4073637AC212BF424087FA5DD89AE34B40
6475	1	37.376365999999997	37.394781000000002	55.839779999999998	55.830973	Новотушинский проезд	0103000020E61000000100000005000000C5A9D6C22CB04240F46DC1525DEA4B40C5A9D6C22CB04240DDEA39E97DEB4B40850A0E2F88B24240DDEA39E97DEB4B40850A0E2F88B24240F46DC1525DEA4B40C5A9D6C22CB04240F46DC1525DEA4B40
12697	1	37.603665999999997	37.608553000000001	55.792639999999999	55.780760000000001	Новосущевская	0103000020E6100000010000000500000083DA6FED44CD4240320395F1EFE34B4083DA6FED44CD42402FC03E3A75E54B40FC709010E5CD42402FC03E3A75E54B40FC709010E5CD4240320395F1EFE34B4083DA6FED44CD4240320395F1EFE34B40
1787	1	37.588808	37.601187000000003	55.791952000000002	55.778978000000002	Новослободская улица	0103000020E61000000100000005000000C4CF7F0F5ECB4240D926158DB5E34B40C4CF7F0F5ECB42403B00E2AE5EE54B40E3E313B2F3CC42403B00E2AE5EE54B40E3E313B2F3CC4240D926158DB5E34B40C4CF7F0F5ECB4240D926158DB5E34B40
12482	1	37.588808	37.601187000000003	55.791952000000002	55.778978000000002	Новослободская 	0103000020E61000000100000005000000C4CF7F0F5ECB4240D926158DB5E34B40C4CF7F0F5ECB42403B00E2AE5EE54B40E3E313B2F3CC42403B00E2AE5EE54B40E3E313B2F3CC4240D926158DB5E34B40C4CF7F0F5ECB4240D926158DB5E34B40
36	1	37.820466000000003	37.820906000000001	55.817385000000002	55.811881999999997	Новосибирская улица	0103000020E610000001000000050000006FBDA60705E94240041BD7BFEBE74B406FBDA60705E94240D89E5912A0E84B408B8BA37213E94240D89E5912A0E84B408B8BA37213E94240041BD7BFEBE74B406FBDA60705E94240041BD7BFEBE74B40
12826	1	37.820466000000003	37.820906000000001	55.817385000000002	55.811881999999997	Новосибирская	0103000020E610000001000000050000006FBDA60705E94240041BD7BFEBE74B406FBDA60705E94240D89E5912A0E84B408B8BA37213E94240D89E5912A0E84B408B8BA37213E94240041BD7BFEBE74B406FBDA60705E94240041BD7BFEBE74B40
12819	1	37.355148	37.363241000000002	55.787613999999998	55.786313	Новорублевская	0103000020E61000000100000005000000B29E5A7D75AD4240B7B585E7A5E44B40B29E5A7D75AD424095EF1989D0E44B407EC85BAE7EAE424095EF1989D0E44B407EC85BAE7EAE4240B7B585E7A5E44B40B29E5A7D75AD4240B7B585E7A5E44B40
13185	1	37.757807999999997	37.763854000000002	55.681640999999999	55.668950000000002	Новороссийская	0103000020E61000000100000005000000D65240DAFFE0424061545227A0D54B40D65240DAFFE042406E4E250340D74B409B75C6F7C5E142406E4E250340D74B409B75C6F7C5E1424061545227A0D54B40D65240DAFFE0424061545227A0D54B40
1592	1	37.676969	37.696570000000001	55.743375	55.736741000000002	Новорогожская улица	0103000020E61000000100000005000000F2B391EBA6D64240A94F72874DDE4B40F2B391EBA6D64240FED478E926DF4B40F7AFAC3429D94240FED478E926DF4B40F7AFAC3429D94240A94F72874DDE4B40F2B391EBA6D64240A94F72874DDE4B40
12928	1	37.676969	37.696570000000001	55.743375	55.736741000000002	Новорогожская	0103000020E61000000100000005000000F2B391EBA6D64240A94F72874DDE4B40F2B391EBA6D64240FED478E926DF4B40F7AFAC3429D94240FED478E926DF4B40F7AFAC3429D94240A94F72874DDE4B40F2B391EBA6D64240A94F72874DDE4B40
13225	1	37.515515000000001	37.530588000000002	55.828995999999997	55.825820999999998	Новопетровская	0103000020E6100000010000000500000079CC4065FCC14240CDACA580B4E94B4079CC4065FCC14240E5417A8A1CEA4B4035D3BD4EEAC34240E5417A8A1CEA4B4035D3BD4EEAC34240CDACA580B4E94B4079CC4065FCC14240CDACA580B4E94B40
13021	1	37.505749999999999	37.518963999999997	55.803646000000001	55.792923000000002	Новопесчаная	0103000020E61000000100000005000000DBF97E6ABCC04240849F38807EE54B40DBF97E6ABCC04240D6C743DFDDE64B4092E68F696DC24240D6C743DFDDE64B4092E68F696DC24240849F38807EE54B40DBF97E6ABCC04240849F38807EE54B40
12756	1	37.361130000000003	37.379761000000002	55.643348000000003	55.639699999999998	Новопеределкинская 	0103000020E6100000010000000500000060CD018239AE424027A089B0E1D14B4060CD018239AE424038F92D3A59D24B40ECA529029CB0424038F92D3A59D24B40ECA529029CB0424027A089B0E1D14B4060CD018239AE424027A089B0E1D14B40
12849	1	37.361130000000003	37.379761000000002	55.643348000000003	55.639699999999998	Новопеределкинская	0103000020E6100000010000000500000060CD018239AE424027A089B0E1D14B4060CD018239AE424038F92D3A59D24B40ECA529029CB0424038F92D3A59D24B40ECA529029CB0424027A089B0E1D14B4060CD018239AE424027A089B0E1D14B40
13164	1	37.663791000000003	37.695366	55.724753	55.717680000000001	Новоостаповская	0103000020E6100000010000000500000088307E1AF7D44240247F30F0DCDB4B4088307E1AF7D44240C556D0B4C4DC4B400B60CAC001D94240C556D0B4C4DC4B400B60CAC001D94240247F30F0DCDB4B4088307E1AF7D44240247F30F0DCDB4B40
6612	1	37.616674000000003	37.618605000000002	55.824455	55.812069000000001	Новомосковская улица	0103000020E610000001000000050000009225732CEFCE4240378C82E0F1E74B409225732CEFCE42400803CFBD87E94B403012DA722ECF42400803CFBD87E94B403012DA722ECF4240378C82E0F1E74B409225732CEFCE4240378C82E0F1E74B40
13140	1	37.743704999999999	37.773412	55.662253	55.650748999999998	Новомарьинская	0103000020E61000000100000005000000936FB6B931DF4240CD7344BE4BD34B40936FB6B931DF4240C556D0B4C4D44B40BF2A172AFFE24240C556D0B4C4D44B40BF2A172AFFE24240CD7344BE4BD34B40936FB6B931DF4240CD7344BE4BD34B40
1389	1	37.854413000000001	37.880896	55.744459999999997	55.730933	Новокосинская улица	0103000020E610000001000000050000007D23BA675DED4240994869368FDD4B407D23BA675DED42400F971C774ADF4B40AF963B33C1F042400F971C774ADF4B40AF963B33C1F04240994869368FDD4B407D23BA675DED4240994869368FDD4B40
12875	1	37.854413000000001	37.880896	55.744459999999997	55.730933	Новокосинская 	0103000020E610000001000000050000007D23BA675DED4240994869368FDD4B407D23BA675DED42400F971C774ADF4B40AF963B33C1F042400F971C774ADF4B40AF963B33C1F04240994869368FDD4B407D23BA675DED4240994869368FDD4B40
13208	1	37.479753000000002	37.516331999999998	55.753042999999998	55.745443000000002	Новозаводская	0103000020E610000001000000050000003694DA8B68BD42401D041DAD6ADF4B403694DA8B68BD4240A9BD88B663E04B406BF0BE2A17C24240A9BD88B663E04B406BF0BE2A17C242401D041DAD6ADF4B403694DA8B68BD42401D041DAD6ADF4B40
1769	1	37.78969	37.804313999999998	55.765735999999997	55.745747000000001	Новогиреевская улица	0103000020E6100000010000000500000037FDD98F14E54240890B40A374DF4B4037FDD98F14E5424057AF22A303E24B4083DBDAC2F3E6424057AF22A303E24B4083DBDAC2F3E64240890B40A374DF4B4037FDD98F14E54240890B40A374DF4B40
12801	1	37.639966999999999	37.654187999999998	55.811183999999997	55.806575000000002	Новоалексеевская	0103000020E6100000010000000500000076C24B70EAD14240B7627FD93DE74B4076C24B70EAD14240EC8497E0D4E74B40C3B7B06EBCD34240EC8497E0D4E74B40C3B7B06EBCD34240B7627FD93DE74B4076C24B70EAD14240B7627FD93DE74B40
34	1	37.582745000000003	37.584451000000001	55.757648000000003	55.749885999999996	Новинский бульвар	0103000020E610000001000000050000002A745E6397CA424037DDB243FCDF4B402A745E6397CA42409EF0129CFAE04B40A88E554ACFCA42409EF0129CFAE04B40A88E554ACFCA424037DDB243FCDF4B402A745E6397CA424037DDB243FCDF4B40
12987	1	37.664087000000002	37.679844000000003	55.677128000000003	55.675763000000003	Новинки	0103000020E61000000100000005000000715985CD00D54240666CE8667FD64B40715985CD00D542405B9A5B21ACD64B40E030D12005D742405B9A5B21ACD64B40E030D12005D74240666CE8667FD64B40715985CD00D54240666CE8667FD64B40
6219	1	37.579510999999997	37.580167000000003	55.905805000000001	55.891133000000004	Новгородская улица	0103000020E610000001000000050000000C569C6A2DCA424075B169A510F24B400C569C6A2DCA4240D2C6116BF1F34B40F69B89E942CA4240D2C6116BF1F34B40F69B89E942CA424075B169A510F24B400C569C6A2DCA424075B169A510F24B40
12921	1	37.579510999999997	37.580167000000003	55.905805000000001	55.891133000000004	Новгородская 	0103000020E610000001000000050000000C569C6A2DCA424075B169A510F24B400C569C6A2DCA4240D2C6116BF1F34B40F69B89E942CA4240D2C6116BF1F34B40F69B89E942CA424075B169A510F24B400C569C6A2DCA424075B169A510F24B40
12821	1	37.579510999999997	37.580167000000003	55.905805000000001	55.891133000000004	Новгородская	0103000020E610000001000000050000000C569C6A2DCA424075B169A510F24B400C569C6A2DCA4240D2C6116BF1F34B40F69B89E942CA4240D2C6116BF1F34B40F69B89E942CA424075B169A510F24B400C569C6A2DCA424075B169A510F24B40
12525	1	37.648825000000002	37.669612000000001	55.769711999999998	55.768684	Новая Басманная	0103000020E61000000100000005000000E2E995B20CD34240AF7AC03C64E24B40E2E995B20CD342405CAB3DEC85E24B402C8194D8B5D542405CAB3DEC85E24B402C8194D8B5D54240AF7AC03C64E24B40E2E995B20CD34240AF7AC03C64E24B40
13221	1	37.761932000000002	37.766154	55.440058999999998	55.427489000000001	Новая	0103000020E6100000010000000500000050E3DEFC86E142402B33A5F5B7B64B4050E3DEFC86E14240BDA772DA53B84B408CD9925511E24240BDA772DA53B84B408CD9925511E242402B33A5F5B7B64B4050E3DEFC86E142402B33A5F5B7B64B40
12655	1	37.518309000000002	37.526555000000002	55.670954999999999	55.657834000000001	Новаторов	0103000020E610000001000000050000007A1C06F357C2424033198EE733D44B407A1C06F357C24240390B7BDAE1D54B40CC457C2766C34240390B7BDAE1D54B40CC457C2766C3424033198EE733D44B407A1C06F357C2424033198EE733D44B40
13087	1	37.451573000000003	37.464804999999998	55.670976000000003	55.665325000000003	Никулинская	0103000020E61000000100000005000000D960E124CDB94240091B9E5E29D54B40D960E124CDB942405133A48AE2D54B403602F1BA7EBB42405133A48AE2D54B403602F1BA7EBB4240091B9E5E29D54B40D960E124CDB94240091B9E5E29D54B40
12548	1	37.645015999999998	37.66874	55.748508000000001	55.746319	Николоямская	0103000020E61000000100000005000000C8B260E28FD2424014B1886187DF4B40C8B260E28FD24240AE65321CCFDF4B4076C3B64599D54240AE65321CCFDF4B4076C3B64599D5424014B1886187DF4B40C8B260E28FD2424014B1886187DF4B40
13222	1	37.567554000000001	37.569026999999998	55.756923	55.754430999999997	Николаева	0103000020E61000000100000005000000645B069CA5C84240560BEC3191E04B40645B069CA5C842408C4B55DAE2E04B403FC571E0D5C842408C4B55DAE2E04B403FC571E0D5C84240560BEC3191E04B40645B069CA5C84240560BEC3191E04B40
1901	1	37.608643000000001	37.612470000000002	55.758352000000002	55.755682	Никитский переулок	0103000020E610000001000000050000003CF88903E8CD424083161230BAE04B403CF88903E8CD4240986DA7AD11E14B40FCE3BD6A65CE4240986DA7AD11E14B40FCE3BD6A65CE424083161230BAE04B403CF88903E8CD424083161230BAE04B40
12753	1	37.773026000000002	37.776916	55.807810000000003	55.791516000000001	Никитинская 	0103000020E61000000100000005000000967A1684F2E242406021736550E54B40967A1684F2E24240DEB06D5166E74B409CDEC5FB71E34240DEB06D5166E74B409CDEC5FB71E342406021736550E54B40967A1684F2E242406021736550E54B40
13169	1	37.773026000000002	37.776916	55.807810000000003	55.791516000000001	Никитинская	0103000020E61000000100000005000000967A1684F2E242406021736550E54B40967A1684F2E24240DEB06D5166E74B409CDEC5FB71E34240DEB06D5166E74B409CDEC5FB71E342406021736550E54B40967A1684F2E242406021736550E54B40
12345	1	37.790776999999999	37.823447999999999	55.791525999999998	55.790899000000003	Нижняя Первомайская	0103000020E61000000100000005000000E9B6442E38E5424035B8AD2D3CE54B40E9B6442E38E5424083F755B950E54B4072FA7ABE66E9424083F755B950E54B4072FA7ABE66E9424035B8AD2D3CE54B40E9B6442E38E5424035B8AD2D3CE54B40
13172	1	37.569557000000003	37.587873999999999	55.792265	55.791187000000001	Нижняя Масловка	0103000020E610000001000000050000009C1A683EE7C842409B02999D45E54B409C1A683EE7C84240FA6184F068E54B4098158A743FCB4240FA6184F068E54B4098158A743FCB42409B02999D45E54B409C1A683EE7C842409B02999D45E54B40
1608	1	37.673169000000001	37.725746999999998	55.739139000000002	55.730643999999998	Нижегородская улица	0103000020E610000001000000050000002CD7DB662AD6424062821ABE85DD4B402CD7DB662AD642405D19541B9CDE4B40C6151747E5DC42405D19541B9CDE4B40C6151747E5DC424062821ABE85DD4B402CD7DB662AD6424062821ABE85DD4B40
12981	1	37.673169000000001	37.725746999999998	55.739139000000002	55.730643999999998	Нижегородская 	0103000020E610000001000000050000002CD7DB662AD6424062821ABE85DD4B402CD7DB662AD642405D19541B9CDE4B40C6151747E5DC42405D19541B9CDE4B40C6151747E5DC424062821ABE85DD4B402CD7DB662AD6424062821ABE85DD4B40
12647	1	37.673169000000001	37.725746999999998	55.739139000000002	55.730643999999998	Нижегородская	0103000020E610000001000000050000002CD7DB662AD6424062821ABE85DD4B402CD7DB662AD642405D19541B9CDE4B40C6151747E5DC42405D19541B9CDE4B40C6151747E5DC424062821ABE85DD4B402CD7DB662AD6424062821ABE85DD4B40
13026	1	37.562945999999997	37.572736999999996	55.824390000000001	55.822538999999999	Немчинова	0103000020E61000000100000005000000FEB4519D0EC842409F573CF548E94B40FEB4519D0EC8424021938C9C85E94B40C51A2E724FC9424021938C9C85E94B40C51A2E724FC942409F573CF548E94B40FEB4519D0EC842409F573CF548E94B40
7676	1	37.433193000000003	37.446668000000003	55.846632999999997	55.845632999999999	Нелидовская улица	0103000020E6100000010000000500000096ED43DE72B742408DB5BFB33DEC4B4096ED43DE72B74240705B5B785EEC4B40BA15C26A2CB94240705B5B785EEC4B40BA15C26A2CB942408DB5BFB33DEC4B4096ED43DE72B742408DB5BFB33DEC4B40
12658	1	37.457599999999999	37.478746999999998	55.722918	55.706207999999997	Нежинская	0103000020E61000000100000005000000265305A392BA42403716140665DA4B40265305A392BA424049D8B79388DC4B407007EA9447BD424049D8B79388DC4B407007EA9447BD42403716140665DA4B40265305A392BA42403716140665DA4B40
1360	1	37.552183999999997	37.620142000000001	55.684041000000001	55.662984000000002	Нахимовский проспект	0103000020E61000000100000005000000EEAF1EF7ADC64240B9E2E2A8DCD44B40EEAF1EF7ADC64240C30FCEA78ED74B40227024D060CF4240C30FCEA78ED74B40227024D060CF4240B9E2E2A8DCD44B40EEAF1EF7ADC64240B9E2E2A8DCD44B40
12569	1	37.474291000000001	37.499929000000002	55.797432000000001	55.769027999999999	Народного Ополчения	0103000020E61000000100000005000000C1E44691B5BC4240A9DA6E826FE24B40C1E44691B5BC42405664744012E64B4037A968ACFDBF42405664744012E64B4037A968ACFDBF4240A9DA6E826FE24B40C1E44691B5BC4240A9DA6E826FE24B40
12749	1	37.648636000000003	37.652301000000001	55.739776999999997	55.736103	Народная	0103000020E610000001000000050000000F81238106D3424066BE839F38DE4B400F81238106D342409FAA4203B1DE4B40F51263997ED342409FAA4203B1DE4B40F51263997ED3424066BE839F38DE4B400F81238106D3424066BE839F38DE4B40
12804	1	37.502498000000003	37.508876000000001	55.843640999999998	55.831513999999999	Нарвская	0103000020E610000001000000050000001827BEDA51C042404415FE0C6FEA4B401827BEDA51C042404948A46DFCEB4B4012DC48D922C142404948A46DFCEB4B4012DC48D922C142404415FE0C6FEA4B401827BEDA51C042404415FE0C6FEA4B40
315	1	37.819935999999998	37.832144	55.75864	55.756937999999998	Напольный проезд	0103000020E610000001000000050000001268B0A9F3E84240C18C2958E3E04B401268B0A9F3E84240FEB7921D1BE14B4004C8D0B183EA4240FEB7921D1BE14B4004C8D0B183EA4240C18C2958E3E04B401268B0A9F3E84240C18C2958E3E04B40
1160	1	37.590560000000004	37.613619999999997	55.684615000000001	55.668498	Нагорная улица	0103000020E61000000100000005000000B329577897CB424080B8AB5791D54B40B329577897CB4240EFACDD76A1D74B40F415A4198BCE4240EFACDD76A1D74B40F415A4198BCE424080B8AB5791D54B40B329577897CB424080B8AB5791D54B40
13156	1	37.590560000000004	37.613619999999997	55.684615000000001	55.668498	Нагорная	0103000020E61000000100000005000000B329577897CB424080B8AB5791D54B40B329577897CB4240EFACDD76A1D74B40F415A4198BCE4240EFACDD76A1D74B40F415A4198BCE424080B8AB5791D54B40B329577897CB424080B8AB5791D54B40
6445	1	37.627059000000003	37.695438000000003	55.691668	55.683118	Нагатинская набережная	0103000020E61000000100000005000000CCD4247843D042408BA71E6970D74B40CCD4247843D0424049D8B79388D84B40A532C51C04D9424049D8B79388D84B40A532C51C04D942408BA71E6970D74B40CCD4247843D042408BA71E6970D74B40
12897	1	37.627059000000003	37.695438000000003	55.691668	55.683118	Нагатинская 	0103000020E61000000100000005000000CCD4247843D042408BA71E6970D74B40CCD4247843D0424049D8B79388D84B40A532C51C04D9424049D8B79388D84B40A532C51C04D942408BA71E6970D74B40CCD4247843D042408BA71E6970D74B40
4386	1	37.749032	37.762766999999997	55.659027999999999	55.647717	Мячковский бульвар	0103000020E6100000010000000500000028D4D347E0DF424018080264E8D24B4028D4D347E0DF4240FB928D075BD44B40E8BB5B59A2E14240FB928D075BD44B40E8BB5B59A2E1424018080264E8D24B4028D4D347E0DF424018080264E8D24B40
6128	1	37.614069000000001	37.621732000000002	55.729706	55.711666000000001	Мытная улица	0103000020E61000000100000005000000643E20D099CE42406BD619DF17DB4B40643E20D099CE4240F5D8960167DD4B40377007EA94CF4240F5D8960167DD4B40377007EA94CF42406BD619DF17DB4B40643E20D099CE42406BD619DF17DB4B40
12880	1	37.741683999999999	37.744298000000001	55.630329000000003	55.613987000000002	Мусы Джалиля	0103000020E61000000100000005000000B5FB5580EFDE4240A795422097CE4B40B5FB5580EFDE4240365CE49EAED04B40363D282845DF4240365CE49EAED04B40363D282845DF4240A795422097CE4B40B5FB5580EFDE4240A795422097CE4B40
12683	1	37.620185999999997	37.627749999999999	55.864221999999998	55.859236000000003	Мусоргского	0103000020E61000000100000005000000F1B73D4162CF4240DFC5FB71FBED4B40F1B73D4162CF4240EA3D95D39EEE4B403108AC1C5AD04240EA3D95D39EEE4B403108AC1C5AD04240DFC5FB71FBED4B40F1B73D4162CF4240DFC5FB71FBED4B40
12481	1	37.842573000000002	37.855024	55.718806000000001	55.713830999999999	Муромская улица	0103000020E610000001000000050000000EBF9B6ED9EB42407CEF6FD05EDB4B400EBF9B6ED9EB42409415C3D501DC4B40C6A52A6D71ED42409415C3D501DC4B40C6A52A6D71ED42407CEF6FD05EDB4B400EBF9B6ED9EB42407CEF6FD05EDB4B40
12488	1	37.842573000000002	37.855024	55.718806000000001	55.713830999999999	Муромская 	0103000020E610000001000000050000000EBF9B6ED9EB42407CEF6FD05EDB4B400EBF9B6ED9EB42409415C3D501DC4B40C6A52A6D71ED42409415C3D501DC4B40C6A52A6D71ED42407CEF6FD05EDB4B400EBF9B6ED9EB42407CEF6FD05EDB4B40
6551	1	37.61786	37.634397999999997	55.811279999999996	55.799998000000002	Мурманский проезд	0103000020E61000000100000005000000D7C0560916CF4240C66E9F5566E64B40D7C0560916CF42400EF3E505D8E74B40EB5223F433D142400EF3E505D8E74B40EB5223F433D14240C66E9F5566E64B40D7C0560916CF4240C66E9F5566E64B40
5958	1	37.596075999999996	37.603558999999997	55.898260000000001	55.889234999999999	Мурановская улица	0103000020E610000001000000050000001AF7E6374CCC4240B2BAD573D2F14B401AF7E6374CCC424009A7052FFAF24B406D1ADB6B41CD424009A7052FFAF24B406D1ADB6B41CD4240B2BAD573D2F14B401AF7E6374CCC4240B2BAD573D2F14B40
12912	1	37.596075999999996	37.603558999999997	55.898260000000001	55.889234999999999	Мурановская	0103000020E610000001000000050000001AF7E6374CCC4240B2BAD573D2F14B401AF7E6374CCC424009A7052FFAF24B406D1ADB6B41CD424009A7052FFAF24B406D1ADB6B41CD4240B2BAD573D2F14B401AF7E6374CCC4240B2BAD573D2F14B40
1453	1	37.521802999999998	37.525404999999999	55.754846000000001	55.749597999999999	Мукомольный проезд	0103000020E6100000010000000500000033FAD170CAC24240D192C7D3F2DF4B4033FAD170CAC242401AC231CB9EE04B40D313967840C342401AC231CB9EE04B40D313967840C34240D192C7D3F2DF4B4033FAD170CAC24240D192C7D3F2DF4B40
13081	1	37.493605000000002	37.534019999999998	55.726045999999997	55.703510000000001	Мосфильмовская	0103000020E610000001000000050000003012DA722EBF424059349D9D0CDA4B403012DA722EBF424020B24813EFDC4B4078B471C45AC4424020B24813EFDC4B4078B471C45AC4424059349D9D0CDA4B403012DA722EBF424059349D9D0CDA4B40
13147	1	37.831443	37.833005999999997	55.766997000000003	55.750073999999998	Молостовых	0103000020E610000001000000050000007BBE66B96CEA42403ACAC16C02E04B407BBE66B96CEA4240A8902BF52CE24B4096AFCBF09FEA4240A8902BF52CE24B4096AFCBF09FEA42403ACAC16C02E04B407BBE66B96CEA42403ACAC16C02E04B40
12780	1	37.619512999999998	37.653441999999998	55.879778000000002	55.876793999999997	Молодцова	0103000020E610000001000000050000003239B5334CCF42401DAA29C93AF04B403239B5334CCF4240C2DEC4909CF04B409AEAC9FCA3D34240C2DEC4909CF04B409AEAC9FCA3D342401DAA29C93AF04B403239B5334CCF42401DAA29C93AF04B40
4019	1	37.374299999999998	37.440173000000001	55.734713999999997	55.731977000000001	Молодогвардейская улица	0103000020E610000001000000050000004772F90FE9AF42404C361E6CB1DD4B404772F90FE9AF4240E8F4BC1B0BDE4B4086CABF9657B84240E8F4BC1B0BDE4B4086CABF9657B842404C361E6CB1DD4B404772F90FE9AF42404C361E6CB1DD4B40
13100	1	37.374299999999998	37.440173000000001	55.734713999999997	55.731977000000001	Молодогвардейская	0103000020E610000001000000050000004772F90FE9AF42404C361E6CB1DD4B404772F90FE9AF4240E8F4BC1B0BDE4B4086CABF9657B84240E8F4BC1B0BDE4B4086CABF9657B842404C361E6CB1DD4B404772F90FE9AF42404C361E6CB1DD4B40
12986	1	37.806694999999998	37.838765000000002	55.729407000000002	55.718674	Молдагуловой	0103000020E61000000100000005000000616C21C841E74240253E7782FDDB4B40616C21C841E742409B3C65355DDD4B40C503CAA65CEB42409B3C65355DDD4B40C503CAA65CEB4240253E7782FDDB4B40616C21C841E74240253E7782FDDB4B40
12750	1	37.435861000000003	37.445813999999999	55.733589000000002	55.730232999999998	Молдавская	0103000020E610000001000000050000000A4D124BCAB74240E0BA624678DD4B400A4D124BCAB7424049DA8D3EE6DD4B40AA0CE36E10B9424049DA8D3EE6DD4B40AA0CE36E10B94240E0BA624678DD4B400A4D124BCAB74240E0BA624678DD4B40
2380	1	37.386032	37.449057000000003	55.723444999999998	55.713495999999999	Можайское шоссе	0103000020E61000000100000005000000D09A1F7F69B14240D5E940D653DB4B40D09A1F7F69B1424034BA83D899DC4B401B8524B37AB9424034BA83D899DC4B401B8524B37AB94240D5E940D653DB4B40D09A1F7F69B14240D5E940D653DB4B40
12771	1	37.477246999999998	37.503413999999999	55.776183000000003	55.772131999999999	Мневники	0103000020E610000001000000050000009B8E006E16BD4240F818AC38D5E24B409B8E006E16BD4240085BECF659E34B409D2CB5DE6FC04240085BECF659E34B409D2CB5DE6FC04240F818AC38D5E24B409B8E006E16BD4240F818AC38D5E24B40
3529	1	37.446092999999998	37.536265999999998	55.715519999999998	55.669122000000002	Мичуринский проспект	0103000020E61000000100000005000000BDFC4E9319B942405E8429CAA5D54B40BDFC4E9319B9424024D1CB2896DB4B4076FA415DA4C4424024D1CB2896DB4B4076FA415DA4C442405E8429CAA5D54B40BDFC4E9319B942405E8429CAA5D54B40
4200	1	37.505021999999997	37.538682000000001	55.841731000000003	55.836443000000003	Михалковская улица	0103000020E6100000010000000500000058E1968FA4C04240ECFB709010EB4B4058E1968FA4C04240C38366D7BDEB4B40D1782288F3C44240C38366D7BDEB4B40D1782288F3C44240ECFB709010EB4B4058E1968FA4C04240ECFB709010EB4B40
13064	1	37.505021999999997	37.538682000000001	55.841731000000003	55.836443000000003	Михалковская 	0103000020E6100000010000000500000058E1968FA4C04240ECFB709010EB4B4058E1968FA4C04240C38366D7BDEB4B40D1782288F3C44240C38366D7BDEB4B40D1782288F3C44240ECFB709010EB4B4058E1968FA4C04240ECFB709010EB4B40
13000	1	37.505021999999997	37.538682000000001	55.841731000000003	55.836443000000003	Михалковская	0103000020E6100000010000000500000058E1968FA4C04240ECFB709010EB4B4058E1968FA4C04240C38366D7BDEB4B40D1782288F3C44240C38366D7BDEB4B40D1782288F3C44240ECFB709010EB4B4058E1968FA4C04240ECFB709010EB4B40
12542	1	37.761384	37.785817999999999	55.729422	55.721305000000001	Михайлова	0103000020E610000001000000050000004DD9E90775E142407CB8E4B853DC4B404DD9E90775E14240D07D39B35DDD4B40D74D29AF95E44240D07D39B35DDD4B40D74D29AF95E442407CB8E4B853DC4B404DD9E90775E142407CB8E4B853DC4B40
12925	1	37.353476999999998	37.376474000000002	55.856194000000002	55.839764000000002	Митинская 	0103000020E61000000100000005000000B071FDBB3EAD4240D82D02637DEB4B40B071FDBB3EAD42400684D6C397ED4B40ACE5CE4C30B042400684D6C397ED4B40ACE5CE4C30B04240D82D02637DEB4B40B071FDBB3EAD4240D82D02637DEB4B40
12829	1	37.353476999999998	37.376474000000002	55.856194000000002	55.839764000000002	Митинская	0103000020E61000000100000005000000B071FDBB3EAD4240D82D02637DEB4B40B071FDBB3EAD42400684D6C397ED4B40ACE5CE4C30B042400684D6C397ED4B40ACE5CE4C30B04240D82D02637DEB4B40B071FDBB3EAD4240D82D02637DEB4B40
4523	1	37.559100999999998	37.568066000000002	55.798090000000002	55.795226	Мирской переулок	0103000020E6100000010000000500000098141F9F90C74240E6762FF7C9E54B4098141F9F90C74240E0A128D027E64B401AFCFD62B6C84240E0A128D027E64B401AFCFD62B6C84240E6762FF7C9E54B4098141F9F90C74240E6762FF7C9E54B40
12691	1	37.694890000000001	37.701385000000002	55.817183	55.814425999999997	Миллионная	0103000020E61000000100000005000000A228D027F2D842408C81751C3FE84B40A228D027F2D8424070ECD97399E84B40D673D2FBC6D9424070ECD97399E84B40D673D2FBC6D942408C81751C3FE84B40A228D027F2D842408C81751C3FE84B40
12627	1	37.577300999999999	37.589958000000003	55.834395999999998	55.821548	Милашенкова	0103000020E610000001000000050000005B79C9FFE4C942400F0C207C28E94B405B79C9FFE4C94240E4F4F57CCDEA4B40BD0166BE83CB4240E4F4F57CCDEA4B40BD0166BE83CB42400F0C207C28E94B405B79C9FFE4C942400F0C207C28E94B40
13045	1	37.655571000000002	37.683472999999999	55.871087000000003	55.864393999999997	Менжинского	0103000020E610000001000000050000005F9A22C0E9D34240E76D6C76A4EE4B405F9A22C0E9D34240427C60C77FEF4B407959130B7CD74240427C60C77FEF4B407959130B7CD74240E76D6C76A4EE4B405F9A22C0E9D34240E76D6C76A4EE4B40
5861	1	37.645420000000001	37.651573999999997	55.592052000000002	55.580263000000002	Медынская улица	0103000020E610000001000000050000009817601F9DD24240180AD80E46CA4B409817601F9DD2424005C4245CC8CB4B404276DEC666D3424005C4245CC8CB4B404276DEC666D34240180AD80E46CA4B409817601F9DD24240180AD80E46CA4B40
12944	1	37.645420000000001	37.651573999999997	55.592052000000002	55.580263000000002	Медынская 	0103000020E610000001000000050000009817601F9DD24240180AD80E46CA4B409817601F9DD2424005C4245CC8CB4B404276DEC666D3424005C4245CC8CB4B404276DEC666D34240180AD80E46CA4B409817601F9DD24240180AD80E46CA4B40
13019	1	37.645420000000001	37.651573999999997	55.592052000000002	55.580263000000002	Медынская	0103000020E610000001000000050000009817601F9DD24240180AD80E46CA4B409817601F9DD2424005C4245CC8CB4B404276DEC666D3424005C4245CC8CB4B404276DEC666D34240180AD80E46CA4B409817601F9DD24240180AD80E46CA4B40
12795	1	37.414597999999998	37.426122999999997	55.666497999999997	55.663268000000002	Матросова	0103000020E61000000100000005000000567E198C11B54240DE3D40F7E5D44B40567E198C11B54240B96C74CE4FD54B406589CE328BB64240B96C74CE4FD54B406589CE328BB64240DE3D40F7E5D44B40567E198C11B54240DE3D40F7E5D44B40
4823	1	37.458247	37.484703000000003	55.707943	55.701891000000003	Матвеевская улица	0103000020E61000000100000005000000BC3E73D6A7BA4240AA2D7590D7D94B40BC3E73D6A7BA4240503750E09DDA4B40F5A276BF0ABE4240503750E09DDA4B40F5A276BF0ABE4240AA2D7590D7D94B40BC3E73D6A7BA4240AA2D7590D7D94B40
13175	1	37.458247	37.484703000000003	55.707943	55.701891000000003	Матвеевская	0103000020E61000000100000005000000BC3E73D6A7BA4240AA2D7590D7D94B40BC3E73D6A7BA4240503750E09DDA4B40F5A276BF0ABE4240503750E09DDA4B40F5A276BF0ABE4240AA2D7590D7D94B40BC3E73D6A7BA4240AA2D7590D7D94B40
13241	1	37.776161000000002	37.795411999999999	55.675448000000003	55.652876999999997	Марьинский Парк	0103000020E6100000010000000500000020B75F3E59E34240C1A7397991D34B4020B75F3E59E3424006137F1475D64B40486C770FD0E5424006137F1475D64B40486C770FD0E54240C1A7397991D34B4020B75F3E59E34240C1A7397991D34B40
12566	1	37.755139999999997	37.764501000000003	55.705534	55.694291999999997	Маршала Чуйкова	0103000020E6100000010000000500000062F3716DA8E04240EDEF6C8FDED84B4062F3716DA8E04240A81B28F04EDA4B403161342BDBE14240A81B28F04EDA4B403161342BDBE14240EDEF6C8FDED84B4062F3716DA8E04240EDEF6C8FDED84B40
12684	1	37.456397000000003	37.487721000000001	55.785634999999999	55.780045999999999	Маршала Тухачевского	0103000020E610000001000000050000000B7F86376BBA424014B01D8CD8E34B400B7F86376BBA4240E6CB0BB08FE44B40454948A46DBE4240E6CB0BB08FE44B40454948A46DBE424014B01D8CD8E34B400B7F86376BBA424014B01D8CD8E34B40
12924	1	37.39152	37.405695999999999	55.752505999999997	55.740796000000003	Маршала Тимошенко	0103000020E610000001000000050000006EDDCD531DB24240FA804067D2DE4B406EDDCD531DB242409A05DA1D52E04B401B0FB6D8EDB342409A05DA1D52E04B401B0FB6D8EDB34240FA804067D2DE4B406EDDCD531DB24240FA804067D2DE4B40
12964	1	37.574013000000001	37.603459999999998	55.507162999999998	55.502538000000001	Маршала Савицкого	0103000020E610000001000000050000004B3D0B4279C94240A67F492A53C04B404B3D0B4279C94240E15E99B7EAC04B40DA38622D3ECD4240E15E99B7EAC04B40DA38622D3ECD4240A67F492A53C04B404B3D0B4279C94240A67F492A53C04B40
12666	1	37.482968999999997	37.496237000000001	55.800528999999997	55.795245999999999	Маршала Рыбалко	0103000020E61000000100000005000000ACFD9DEDD1BD42402D23F59ECAE54B40ACFD9DEDD1BD4240F23FF9BB77E64B405708ABB184BF4240F23FF9BB77E64B405708ABB184BF42402D23F59ECAE54B40ACFD9DEDD1BD42402D23F59ECAE54B40
12845	1	37.856856999999998	37.864438	55.690658999999997	55.675981	Маршала Полубоярова	0103000020E61000000100000005000000A12C7C7DADED4240D3DB9F8B86D64B40A12C7C7DADED424012D89C8367D84B40B7B585E7A5EE424012D89C8367D84B40B7B585E7A5EE4240D3DB9F8B86D64B40A12C7C7DADED4240D3DB9F8B86D64B40
12894	1	37.457554999999999	37.471272999999997	55.806635999999997	55.800792000000001	Маршала Новикова	0103000020E61000000100000005000000868F882991BA424000732D5A80E64B40868F882991BA42405CE333D93FE74B40703E75AC52BC42405CE333D93FE74B40703E75AC52BC424000732D5A80E64B40868F882991BA424000732D5A80E64B40
13020	1	37.390397	37.419674000000001	55.815448000000004	55.804319	Маршала Катукова	0103000020E610000001000000050000006FBA6587F8B142409546CCECF3E64B406FBA6587F8B1424058CB9D9960E84B40A27DACE0B7B5424058CB9D9960E84B40A27DACE0B7B542409546CCECF3E64B406FBA6587F8B142409546CCECF3E64B40
12473	1	37.696129999999997	37.710619999999999	55.624251000000001	55.617306999999997	Маршала Захарова	0103000020E61000000100000005000000DAE1AFC91AD94240C24B70EA03CF4B40DAE1AFC91AD9424066BFEE74E7CF4B4017F19D98F5DA424066BFEE74E7CF4B4017F19D98F5DA4240C24B70EA03CF4B40DAE1AFC91AD94240C24B70EA03CF4B40
13192	1	37.726511000000002	37.729781000000003	55.651780000000002	55.643231	Маршала Голованова	0103000020E610000001000000050000009697FC4FFEDC4240FE62B66455D24B409697FC4FFEDC4240EC17EC866DD34B40001FBC7669DD4240EC17EC866DD34B40001FBC7669DD4240FE62B66455D24B409697FC4FFEDC4240FE62B66455D24B40
12971	1	37.462622000000003	37.475575999999997	55.809398000000002	55.802689999999998	Маршала Василевского	0103000020E610000001000000050000007F349C3237BB4240C269C18BBEE64B407F349C3237BB424052B9895A9AE74B409961A3ACDFBC424052B9895A9AE74B409961A3ACDFBC4240C269C18BBEE64B407F349C3237BB4240C269C18BBEE64B40
12793	1	37.476582000000001	37.502471	55.802249000000003	55.789831	Маршала Бирюзова	0103000020E610000001000000050000005FEE93A300BD4240F92EA52E19E54B405FEE93A300BD4240D61F6118B0E64B401E1840F850C04240D61F6118B0E64B401E1840F850C04240F92EA52E19E54B405FEE93A300BD4240F92EA52E19E54B40
1698	1	37.662146999999997	37.664662	55.739676000000003	55.737613000000003	Марксистский переулок	0103000020E610000001000000050000007F129F3BC1D442405F0D501A6ADE4B407F129F3BC1D442406CD102B4ADDE4B406D72F8A413D542406CD102B4ADDE4B406D72F8A413D542405F0D501A6ADE4B407F129F3BC1D442405F0D501A6ADE4B40
1676	1	37.655005000000003	37.668560999999997	55.741352999999997	55.733770999999997	Марксистская улица	0103000020E61000000100000005000000B6DB2E34D7D3424069E04735ECDD4B40B6DB2E34D7D342404FE5B4A7E4DE4B40C630276893D542404FE5B4A7E4DE4B40C630276893D5424069E04735ECDD4B40B6DB2E34D7D3424069E04735ECDD4B40
74862	1	37.655005000000003	37.668560999999997	55.741352999999997	55.733770999999997	Марксистская	0103000020E61000000100000005000000B6DB2E34D7D3424069E04735ECDD4B40B6DB2E34D7D342404FE5B4A7E4DE4B40C630276893D542404FE5B4A7E4DE4B40C630276893D5424069E04735ECDD4B40B6DB2E34D7D3424069E04735ECDD4B40
13184	1	37.739249000000001	37.746147999999998	55.674981000000002	55.674427999999999	Мариупольская	0103000020E61000000100000005000000E44C13B69FDE4240DBC01DA853D64B40E44C13B69FDE4240F03504C765D64B40E7FC14C781DF4240F03504C765D64B40E7FC14C781DF4240DBC01DA853D64B40E44C13B69FDE4240DBC01DA853D64B40
12695	1	37.518856	37.530265	55.684254000000003	55.677701999999996	Марии Ульяновой	0103000020E61000000100000005000000ACAA97DF69C2424086376BF0BED64B40ACAA97DF69C242401F1494A295D74B40529B38B9DFC342401F1494A295D74B40529B38B9DFC3424086376BF0BED64B40ACAA97DF69C2424086376BF0BED64B40
854	1	37.622225999999998	37.625379000000002	55.770476000000002	55.770263999999997	Малый Сухаревский переулок	0103000020E61000000100000005000000465C001AA5CF4240A0A4C00298E24B40465C001AA5CF42402C2D23F59EE24B40774D486B0CD042402C2D23F59EE24B40774D486B0CD04240A0A4C00298E24B40465C001AA5CF4240A0A4C00298E24B40
2451	1	37.558624999999999	37.563080999999997	55.731611999999998	55.730167000000002	Малый Саввинский переулок	0103000020E610000001000000050000002FDD240681C7424029CFBC1C76DD4B402FDD240681C742403AAE4676A5DD4B40DEFFC70913C842403AAE4676A5DD4B40DEFFC70913C8424029CFBC1C76DD4B402FDD240681C7424029CFBC1C76DD4B40
1889	1	37.601052000000003	37.603198999999996	55.765782000000002	55.764626999999997	Малый Палашевский переулок	0103000020E6100000010000000500000003999D45EFCC4240BD512B4CDFE14B4003999D45EFCC4240C8EE022505E24B406DFDF49F35CD4240C8EE022505E24B406DFDF49F35CD4240BD512B4CDFE14B4003999D45EFCC4240BD512B4CDFE14B40
2778	1	37.530759000000003	37.532860999999997	55.809646000000001	55.808335999999997	Малый Коптевский проезд	0103000020E61000000100000005000000628731E9EFC34240F816D68D77E74B40628731E9EFC342402AABE97AA2E74B402C280CCA34C442402AABE97AA2E74B402C280CCA34C44240F816D68D77E74B40628731E9EFC34240F816D68D77E74B40
1086	1	37.601861	37.603189999999998	55.757060000000003	55.753950000000003	Малый Кисловский переулок	0103000020E6100000010000000500000072DEFFC709CD4240DC68006F81E04B4072DEFFC709CD42400D8E9257E7E04B401AA3755435CD42400D8E9257E7E04B401AA3755435CD4240DC68006F81E04B4072DEFFC709CD4240DC68006F81E04B40
13195	1	37.638252000000001	37.654206000000002	55.813754000000003	55.811228999999997	Маломосковская	0103000020E61000000100000005000000A54DD53DB2D142408C48145AD6E74B40A54DD53DB2D142409E7E501729E84B406A6CAF05BDD342409E7E501729E84B406A6CAF05BDD342408C48145AD6E74B40A54DD53DB2D142408C48145AD6E74B40
12597	1	37.671337000000001	37.676600999999998	55.791592000000001	55.785898000000003	Маленковская	0103000020E6100000010000000500000021CCED5EEED54240F4FE3F4E98E44B4021CCED5EEED542403BE3FBE252E54B406FB88FDC9AD642403BE3FBE252E54B406FB88FDC9AD64240F4FE3F4E98E44B4021CCED5EEED54240F4FE3F4E98E44B40
12979	1	37.589761000000003	37.598348000000001	55.655482999999997	55.653649000000001	Малая Юшуньская	0103000020E6100000010000000500000067BAD7497DCB424014083BC5AAD34B4067BAD7497DCB4240BF0AF0DDE6D34B4042D0D1AA96CC4240BF0AF0DDE6D34B4042D0D1AA96CC424014083BC5AAD34B4067BAD7497DCB424014083BC5AAD34B40
12625	1	37.445813999999999	37.482393999999999	55.740394999999999	55.730806000000001	Малая Филевская 	0103000020E61000000100000005000000AA0CE36E10B942403CDC0E0D8BDD4B40AA0CE36E10B942409B8F6B43C5DE4B40B0E42A16BFBD42409B8F6B43C5DE4B40B0E42A16BFBD42403CDC0E0D8BDD4B40AA0CE36E10B942403CDC0E0D8BDD4B40
13150	1	37.445813999999999	37.482393999999999	55.740394999999999	55.730806000000001	Малая Филевская	0103000020E61000000100000005000000AA0CE36E10B942403CDC0E0D8BDD4B40AA0CE36E10B942409B8F6B43C5DE4B40B0E42A16BFBD42409B8F6B43C5DE4B40B0E42A16BFBD42403CDC0E0D8BDD4B40AA0CE36E10B942403CDC0E0D8BDD4B40
12526	1	37.615901000000001	37.620995000000001	55.711584000000002	55.701464999999999	Малая Тульская	0103000020E610000001000000050000006F490ED8D5CE4240F224E99AC9D94B406F490ED8D5CE4240AE2D3C2F15DB4B4061FD9FC37CCF4240AE2D3C2F15DB4B4061FD9FC37CCF4240F224E99AC9D94B406F490ED8D5CE4240F224E99AC9D94B40
13151	1	37.636913	37.637757999999998	55.791449999999998	55.788570999999997	Малая Переяславская	0103000020E61000000100000005000000D9B27C5D86D1424079C9FFE4EFE44B40D9B27C5D86D14240A835CD3B4EE54B409561DC0DA2D14240A835CD3B4EE54B409561DC0DA2D1424079C9FFE4EFE44B40D9B27C5D86D1424079C9FFE4EFE44B40
12463	1	37.590694999999997	37.598627	55.765757000000001	55.758589999999998	Малая Бронная	0103000020E610000001000000050000009274CDE49BCB42404C89247A19E14B409274CDE49BCB42406FD74B5304E24B4055C03DCF9FCC42406FD74B5304E24B4055C03DCF9FCC42404C89247A19E14B409274CDE49BCB42404C89247A19E14B40
12837	1	37.583598000000002	37.595239999999997	55.833444999999998	55.831519	Малая Ботаническая 	0103000020E610000001000000050000006901DA56B3CA42405680EF366FEA4B406901DA56B3CA4240E2016553AEEA4B40B1A206D330CC4240E2016553AEEA4B40B1A206D330CC42405680EF366FEA4B406901DA56B3CA42405680EF366FEA4B40
3589	1	37.654215000000001	37.669504000000003	55.836447999999997	55.828865	Малахитовая улица	0103000020E61000000100000005000000BDC62E51BDD3424047E6913F18EA4B40BDC62E51BDD34240FD6662BA10EB4B4046459C4EB2D54240FD6662BA10EB4B4046459C4EB2D5424047E6913F18EA4B40BDC62E51BDD3424047E6913F18EA4B40
12327	1	37.711635000000001	37.711841999999997	55.784956000000001	55.781731999999998	Мажоров переулок	0103000020E6100000010000000500000030D80DDB16DB42404B1E4FCB0FE44B4030D80DDB16DB424045662E7079E44B40A9F57EA31DDB424045662E7079E44B40A9F57EA31DDB42404B1E4FCB0FE44B4030D80DDB16DB42404B1E4FCB0FE44B40
12936	1	37.819764999999997	37.835917000000002	55.776612999999998	55.772846000000001	Магнитогорская	0103000020E61000000100000005000000E5B33C0FEEE84240166C239EECE24B40E5B33C0FEEE842400053060E68E34B40D1950854FFEA42400053060E68E34B40D1950854FFEA4240166C239EECE24B40E5B33C0FEEE84240166C239EECE24B40
231	1	37.650523	37.653658	55.761077	55.756199000000002	Лялин переулок	0103000020E61000000100000005000000DD25715644D342404B22FB20CBE04B40DD25715644D34240705E9CF86AE14B406762BA10ABD34240705E9CF86AE14B406762BA10ABD342404B22FB20CBE04B40DD25715644D342404B22FB20CBE04B40
728	1	37.622280000000003	37.623491999999999	55.729148000000002	55.712243999999998	Люсиновская улица	0103000020E610000001000000050000003A7AFCDEA6CF4240D862B7CF2ADB4B403A7AFCDEA6CF4240CFF8BEB854DD4B40A8A8FA95CECF4240CFF8BEB854DD4B40A8A8FA95CECF4240D862B7CF2ADB4B403A7AFCDEA6CF4240D862B7CF2ADB4B40
2912	1	37.725693999999997	37.748654999999999	55.715691999999997	55.638047999999998	Люблинская улица	0103000020E61000000100000005000000A3737E8AE3DC42409CA38E8EABD14B40A3737E8AE3DC42402101A3CB9BDB4B40527E52EDD3DF42402101A3CB9BDB4B40527E52EDD3DF42409CA38E8EABD14B40A3737E8AE3DC42409CA38E8EABD14B40
12553	1	37.725693999999997	37.748654999999999	55.715691999999997	55.638047999999998	Люблинская	0103000020E61000000100000005000000A3737E8AE3DC42409CA38E8EABD14B40A3737E8AE3DC42402101A3CB9BDB4B40527E52EDD3DF42402101A3CB9BDB4B40527E52EDD3DF42409CA38E8EABD14B40A3737E8AE3DC42409CA38E8EABD14B40
12441	1	37.89649	37.910567	55.724291999999998	55.708601999999999	Лухмановская	0103000020E6100000010000000500000074982F2FC0F24240AAF06778B3DA4B4074982F2FC0F242409160AA99B5DC4B408EE89E758DF442409160AA99B5DC4B408EE89E758DF44240AAF06778B3DA4B4074982F2FC0F24240AAF06778B3DA4B40
12759	1	37.333022	37.352865999999999	55.655726999999999	55.641325999999999	Лукинская	0103000020E610000001000000050000009C6C0377A0AA424089096AF816D24B409C6C0377A0AA4240560DC2DCEED34B4067EF8CB62AAD4240560DC2DCEED34B4067EF8CB62AAD424089096AF816D24B409C6C0377A0AA424089096AF816D24B40
12554	1	37.692016000000002	37.750137000000002	55.827869	55.820560999999998	Лосиноостровская	0103000020E610000001000000050000008527F4FA93D84240C0AF912408E94B408527F4FA93D84240A52F849CF7E94B4081423D7D04E04240A52F849CF7E94B4081423D7D04E04240C0AF912408E94B408527F4FA93D84240C0AF912408E94B40
12669	1	37.709290000000003	37.716943999999998	55.878292999999999	55.872067000000001	Лосевская	0103000020E610000001000000050000009FB0C403CADA4240DE7536E49FEF4B409FB0C403CADA424022A7AFE76BF04B401E882CD2C4DB424022A7AFE76BF04B401E882CD2C4DB4240DE7536E49FEF4B409FB0C403CADA4240DE7536E49FEF4B40
3785	1	37.709505999999998	37.712694999999997	55.770482000000001	55.766247999999997	Лонгиновская улица	0103000020E610000001000000050000006B28B517D1DA42400D501A6A14E24B406B28B517D1DA42400E1478279FE24B40E882FA9639DB42400E1478279FE24B40E882FA9639DB42400D501A6A14E24B406B28B517D1DA42400D501A6A14E24B40
356	1	37.506135999999998	37.552129999999998	55.710540000000002	55.684050999999997	Ломоносовский проспект	0103000020E6100000010000000500000004AA7F10C9C04240E6E5B0FB8ED74B4004AA7F10C9C04240FB3F87F9F2DA4B40FB912232ACC64240FB3F87F9F2DA4B40FB912232ACC64240E6E5B0FB8ED74B4004AA7F10C9C04240E6E5B0FB8ED74B40
12520	1	37.438034999999999	37.464976	55.844698000000001	55.836019	Лодочная	0103000020E610000001000000050000006EC0E78711B84240D5EAABAB02EB4B406EC0E78711B84240917F66101FEC4B4063B6645584BB4240917F66101FEC4B4063B6645584BB4240D5EAABAB02EB4B406EC0E78711B84240D5EAABAB02EB4B40
12774	1	37.466780999999997	37.508831000000001	55.694184999999997	55.66339	Лобачевского	0103000020E6100000010000000500000074B2D47ABFBB4240293FA9F6E9D44B4074B2D47ABFBB4240D72FD80DDBD84B407218CC5F21C14240D72FD80DDBD84B407218CC5F21C14240293FA9F6E9D44B4074B2D47ABFBB4240293FA9F6E9D44B40
2905	1	37.524714000000003	37.545257999999997	55.613433000000001	55.603994999999998	Литовский бульвар	0103000020E610000001000000050000006EE00ED429C3424048F949B54FCD4B406EE00ED429C34240C2A4F8F884CE4B40F1F09E03CBC54240C2A4F8F884CE4B40F1F09E03CBC5424048F949B54FCD4B406EE00ED429C3424048F949B54FCD4B40
4879	1	37.550217000000004	37.570850999999998	55.837322999999998	55.832777999999998	Лиственничная аллея	0103000020E61000000100000005000000045ABA826DC64240056A317898EA4B40045ABA826DC6424024986A662DEB4B40C7F143A511C9424024986A662DEB4B40C7F143A511C94240056A317898EA4B40045ABA826DC64240056A317898EA4B40
13017	1	37.659227000000001	37.688045000000002	55.615552999999998	55.575892000000003	Липецкая	0103000020E61000000100000005000000F2D1E28C61D4424097033DD4B6C94B40F2D1E28C61D4424033FAD170CACE4B409296CADB11D8424033FAD170CACE4B409296CADB11D8424097033DD4B6C94B40F2D1E28C61D4424097033DD4B6C94B40
4920	1	37.567743	37.575819000000003	55.842221000000002	55.840891999999997	Линейный проезд	0103000020E6100000010000000500000037C478CDABC84240E8BB5B59A2EB4B4037C478CDABC842409180D1E5CDEB4B402DB5DE6FB4C942409180D1E5CDEB4B402DB5DE6FB4C94240E8BB5B59A2EB4B4037C478CDABC84240E8BB5B59A2EB4B40
12368	1	37.732781000000003	37.743093999999999	55.790503999999999	55.790008	Лечебная	0103000020E61000000100000005000000AA108FC4CBDD424008CA6DFB1EE54B40AA108FC4CBDD4240B8AD2D3C2FE54B404AED45B41DDF4240B8AD2D3C2FE54B404AED45B41DDF424008CA6DFB1EE54B40AA108FC4CBDD424008CA6DFB1EE54B40
380	1	37.675235000000001	37.679223999999998	55.770178000000001	55.769767999999999	Лефортовский переулок	0103000020E61000000100000005000000AA0EB9196ED64240F0C000C287E24B40AA0EB9196ED64240A20C553195E24B404354E1CFF0D64240A20C553195E24B404354E1CFF0D64240F0C000C287E24B40AA0EB9196ED64240F0C000C287E24B40
13023	1	37.696516000000003	37.703361000000001	55.761071999999999	55.754992999999999	Лефортовский Вал	0103000020E610000001000000050000000492B06F27D94240BEDA519CA3E04B400492B06F27D942405EF3AACE6AE14B401424B6BB07DA42405EF3AACE6AE14B401424B6BB07DA4240BEDA519CA3E04B400492B06F27D94240BEDA519CA3E04B40
12694	1	37.584738999999999	37.596910999999999	55.784095999999998	55.776319999999998	Лесная улица	0103000020E610000001000000050000000ED940BAD8CA4240889D29745EE34B400ED940BAD8CA42405376FA415DE44B40B3CF639467CC42405376FA415DE44B40B3CF639467CC4240889D29745EE34B400ED940BAD8CA4240889D29745EE34B40
12731	1	37.587093000000003	37.622081999999999	55.898518000000003	55.890774999999998	Лескова	0103000020E61000000100000005000000F35A09DD25CB4240158C4AEA04F24B40F35A09DD25CB4240056F48A302F34B4013B70A62A0CF4240056F48A302F34B4013B70A62A0CF4240158C4AEA04F24B40F35A09DD25CB4240158C4AEA04F24B40
3113	1	37.835180000000001	37.856596000000003	55.708013999999999	55.698766999999997	Лермонтовский проспект	0103000020E61000000100000005000000FB22A12DE7EA42401343723271D94B40FB22A12DE7EA4240198EE733A0DA4B4035F10EF0A4ED4240198EE733A0DA4B4035F10EF0A4ED42401343723271D94B40FB22A12DE7EA42401343723271D94B40
12900	1	37.644700999999998	37.675010999999998	55.867854000000001	55.863328000000003	Ленская	0103000020E610000001000000050000006859F78F85D242404DDC2A8881EE4B406859F78F85D24240F5D901D715EF4B405AB8ACC266D64240F5D901D715EF4B405AB8ACC266D642404DDC2A8881EE4B406859F78F85D242404DDC2A8881EE4B40
234	1	37.459603999999999	37.612245000000001	55.729883000000001	55.638911999999998	Ленинский проспект	0103000020E610000001000000050000002E8ECA4DD4BA4240CF8250DEC7D14B402E8ECA4DD4BA424004745FCE6CDD4B40DC114E0B5ECE424004745FCE6CDD4B40DC114E0B5ECE4240CF8250DEC7D14B402E8ECA4DD4BA4240CF8250DEC7D14B40
12571	1	37.514364999999998	37.553548999999997	55.715023000000002	55.693460000000002	Ленинские горы	0103000020E61000000100000005000000809A5AB6D6C14240C68A1A4CC3D84B40809A5AB6D6C14240A471A8DF85DB4B40E3DD91B1DAC64240A471A8DF85DB4B40E3DD91B1DAC64240C68A1A4CC3D84B40809A5AB6D6C14240C68A1A4CC3D84B40
12454	1	37.340774000000003	37.508921000000001	55.956989999999998	55.806601000000001	Ленинградское шоссе	0103000020E61000000100000005000000DFA9807B9EAB4240E0F599B33EE74B40DFA9807B9EAB4240AD4CF8A57EFA4B40B29FC55224C14240AD4CF8A57EFA4B40B29FC55224C14240E0F599B33EE74B40DFA9807B9EAB4240E0F599B33EE74B40
2609	1	37.506163000000001	37.583041000000001	55.807465999999998	55.777388000000002	Ленинградский проспект	0103000020E61000000100000005000000FEB8FDF2C9C04240C426327381E34B40FEB8FDF2C9C04240E350BF0B5BE74B40139D6516A1CA4240E350BF0B5BE74B40139D6516A1CA4240C426327381E34B40FEB8FDF2C9C04240C426327381E34B40
5693	1	37.660449	37.697009999999999	55.587015999999998	55.583016000000001	Лебедянская улица	0103000020E6100000010000000500000084D6C39789D44240BA85AE44A0CA4B4084D6C39789D44240471D1D5723CB4B40137EA99F37D94240471D1D5723CB4B40137EA99F37D94240BA85AE44A0CA4B4084D6C39789D44240BA85AE44A0CA4B40
12755	1	37.660449	37.697009999999999	55.587015999999998	55.583016000000001	Лебедянская 	0103000020E6100000010000000500000084D6C39789D44240BA85AE44A0CA4B4084D6C39789D44240471D1D5723CB4B40137EA99F37D94240471D1D5723CB4B40137EA99F37D94240BA85AE44A0CA4B4084D6C39789D44240BA85AE44A0CA4B40
13119	1	37.660449	37.697009999999999	55.587015999999998	55.583016000000001	Лебедянская	0103000020E6100000010000000500000084D6C39789D44240BA85AE44A0CA4B4084D6C39789D44240471D1D5723CB4B40137EA99F37D94240471D1D5723CB4B40137EA99F37D94240BA85AE44A0CA4B4084D6C39789D44240BA85AE44A0CA4B40
13102	1	37.392580000000002	37.393523999999999	55.888871000000002	55.885741000000003	Ландышевая	0103000020E610000001000000050000002788BA0F40B24240F9DC09F65FF14B402788BA0F40B2424071AE6186C6F14B40761893FE5EB2424071AE6186C6F14B40761893FE5EB24240F9DC09F65FF14B402788BA0F40B24240F9DC09F65FF14B40
266	1	37.678811000000003	37.688206999999998	55.771697000000003	55.771272000000003	Ладожская улица	0103000020E6100000010000000500000021956247E3D642400729780AB9E24B4021956247E3D64240EEB5A0F7C6E24B406BF0BE2A17D84240EEB5A0F7C6E24B406BF0BE2A17D842400729780AB9E24B4021956247E3D642400729780AB9E24B40
1734	1	37.658678999999999	37.662712999999997	55.733756	55.733001000000002	Лавров переулок	0103000020E61000000100000005000000EFC7ED974FD44240B8770DFAD2DD4B40EFC7ED974FD44240349F73B7EBDD4B4028D192C7D3D44240349F73B7EBDD4B4028D192C7D3D44240B8770DFAD2DD4B40EFC7ED974FD44240B8770DFAD2DD4B40
5387	1	37.638655999999997	37.638800000000003	55.804557000000003	55.803190999999998	Кучин переулок	0103000020E6100000010000000500000074B2D47ABFD1424084B872F6CEE64B4074B2D47ABFD142404A6249B9FBE64B40A857CA32C4D142404A6249B9FBE64B40A857CA32C4D1424084B872F6CEE64B4074B2D47ABFD1424084B872F6CEE64B40
3650	1	37.449002999999998	37.570563999999997	55.751634000000003	55.723303000000001	Кутузовский проспект	0103000020E61000000100000005000000276728EE78B94240A20C553195DC4B40276728EE78B94240E547FC8A35E04B403123BC3D08C94240E547FC8A35E04B403123BC3D08C94240A20C553195DC4B40276728EE78B94240A20C553195DC4B40
12840	1	37.413448000000002	37.417661000000003	55.722988999999998	55.719175999999997	Кутузова	0103000020E610000001000000050000005E4C33DDEBB44240B7088CF50DDC4B405E4C33DDEBB44240122F4FE78ADC4B4047E867EA75B54240122F4FE78ADC4B4047E867EA75B54240B7088CF50DDC4B405E4C33DDEBB44240B7088CF50DDC4B40
12970	1	37.749661000000003	37.753793000000002	55.622553000000003	55.614570999999998	Кустанайская	0103000020E61000000100000005000000180B43E4F4DF4240F6083543AACE4B40180B43E4F4DF42406B8313D1AFCF4B40147AFD497CE042406B8313D1AFCF4B40147AFD497CE04240F6083543AACE4B40180B43E4F4DF4240F6083543AACE4B40
13228	1	37.560178999999998	37.574786000000003	55.580620000000003	55.566246999999997	Куликовская	0103000020E61000000100000005000000F7730AF2B3C74240A33A1DC87AC84B40F7730AF2B3C74240A7B393C151CA4B406E19709692C94240A7B393C151CA4B406E19709692C94240A33A1DC87AC84B40F7730AF2B3C74240A33A1DC87AC84B40
12616	1	37.390414999999997	37.402408000000001	55.818336000000002	55.80057	Кулакова	0103000020E61000000100000005000000156F641EF9B142405114E81379E64B40156F641EF9B14240DA91EA3BBFE84B400BD3F71A82B34240DA91EA3BBFE84B400BD3F71A82B342405114E81379E64B40156F641EF9B142405114E81379E64B40
12674	1	37.405569999999997	37.408265	55.728743000000001	55.717244000000001	Кубинка	0103000020E610000001000000050000008E1EBFB7E9B3424049A0C1A6CEDB4B408E1EBFB7E9B342402F185C7347DD4B40FC8C0B0742B442402F185C7347DD4B40FC8C0B0742B4424049A0C1A6CEDB4B408E1EBFB7E9B3424049A0C1A6CEDB4B40
13235	1	37.734515000000002	37.750532	55.684218999999999	55.683681	Кубанская	0103000020E61000000100000005000000F2B5679604DE4240C3F2E7DB82D74B40F2B5679604DE4240A226FA7C94D74B40FD4CBD6E11E04240A226FA7C94D74B40FD4CBD6E11E04240C3F2E7DB82D74B40F2B5679604DE4240C3F2E7DB82D74B40
13074	1	37.600343000000002	37.612003000000001	55.733562999999997	55.729883000000001	Крымский Вал	0103000020E61000000100000005000000F7B0170AD8CC424004745FCE6CDD4B40F7B0170AD8CC42401F477364E5DD4B40E606431D56CE42401F477364E5DD4B40E606431D56CE424004745FCE6CDD4B40F7B0170AD8CC424004745FCE6CDD4B40
12738	1	37.404806000000001	37.425601999999998	55.764673000000002	55.743820999999997	Крылатские Холмы	0103000020E61000000100000005000000BF9CD9AED0B34240FC89CA8635DF4B40BF9CD9AED0B342402E910BCEE0E14B405C8E57207AB642402E910BCEE0E14B405C8E57207AB64240FC89CA8635DF4B40BF9CD9AED0B34240FC89CA8635DF4B40
12913	1	37.387189999999997	37.433211	55.772072000000001	55.745032000000002	Крылатская	0103000020E610000001000000050000004BAB21718FB142409B3C65355DDF4B404BAB21718FB1424023145B41D3E24B403CA2427573B7424023145B41D3E24B403CA2427573B742409B3C65355DDF4B404BAB21718FB142409B3C65355DDF4B40
12489	1	37.663521000000003	37.668624000000001	55.730573	55.728544999999997	Крутицкий вал	0103000020E61000000100000005000000C89A9141EED4424008556AF640DD4B40C89A9141EED44240992B836A83DD4B400DA9A27895D54240992B836A83DD4B400DA9A27895D5424008556AF640DD4B40C89A9141EED4424008556AF640DD4B40
12456	1	37.663521000000003	37.668624000000001	55.730573	55.728544999999997	Крутицкий Вал	0103000020E61000000100000005000000C89A9141EED4424008556AF640DD4B40C89A9141EED44240992B836A83DD4B400DA9A27895D54240992B836A83DD4B400DA9A27895D5424008556AF640DD4B40C89A9141EED4424008556AF640DD4B40
13103	1	37.522665000000003	37.533706000000002	55.686354999999999	55.680000999999997	Крупской	0103000020E61000000100000005000000C6E1CCAFE6C24240A71FD4450AD74B40C6E1CCAFE6C2424019390B7BDAD74B40E9D66B7A50C4424019390B7BDAD74B40E9D66B7A50C44240A71FD4450AD74B40C6E1CCAFE6C24240A71FD4450AD74B40
3594	1	37.487262999999999	37.518560000000001	55.853318999999999	55.83934	Кронштадтский бульвар	0103000020E6100000010000000500000082C64CA25EBE4240C11C3D7E6FEB4B4082C64CA25EBE42401807978E39ED4B40C381902C60C242401807978E39ED4B40C381902C60C24240C11C3D7E6FEB4B4082C64CA25EBE4240C11C3D7E6FEB4B40
6961	1	37.608598000000001	37.621623999999997	55.671675999999998	55.668452000000002	Криворожская улица	0103000020E610000001000000050000009C340D8AE6CD42401079CBD58FD54B409C340D8AE6CD424009C1AA7AF9D54B4050340F6091CF424009C1AA7AF9D54B4050340F6091CF42401079CBD58FD54B409C340D8AE6CD42401079CBD58FD54B40
12876	1	37.553873000000003	37.580292	55.685685999999997	55.672680999999997	Кржижановского	0103000020E6100000010000000500000097917A4FE5C64240FED137691AD64B4097917A4FE5C642409BA9108FC4D74B40B2101D0247CA42409BA9108FC4D74B40B2101D0247CA4240FED137691AD64B4097917A4FE5C64240FED137691AD64B40
6213	1	37.454428999999998	37.462567999999997	55.726061000000001	55.711336000000003	Кременчугская улица	0103000020E610000001000000050000004FADBEBA2ABA4240D63BDC0E0DDB4B404FADBEBA2ABA424056F31C91EFDC4B408B16A06D35BB424056F31C91EFDC4B408B16A06D35BB4240D63BDC0E0DDB4B404FADBEBA2ABA4240D63BDC0E0DDB4B40
12842	1	37.423715999999999	37.449964999999999	55.726396000000001	55.726162000000002	Красных Зорь	0103000020E610000001000000050000005E656D533CB642408ACC5CE0F2DC4B405E656D533CB64240FDF84B8BFADC4B401DACFF7398B94240FDF84B8BFADC4B401DACFF7398B942408ACC5CE0F2DC4B405E656D533CB642408ACC5CE0F2DC4B40
13052	1	37.799067999999998	37.821185	55.724463999999998	55.716017000000001	Красный Казанец	0103000020E61000000100000005000000DBA337DC47E64240A530EF71A6DB4B40DBA337DC47E642408E90813CBBDC4B409E7B0F971CE942408E90813CBBDC4B409E7B0F971CE94240A530EF71A6DB4B40DBA337DC47E64240A530EF71A6DB4B40
12862	1	37.685287000000002	37.715910999999998	55.762220999999997	55.753078000000002	Красноказарменная 	0103000020E61000000100000005000000DEAF027CB7D7424026AB22DC64E04B40DEAF027CB7D7424086A92D7590E14B405FECBDF8A2DB424086A92D7590E14B405FECBDF8A2DB424026AB22DC64E04B40DEAF027CB7D7424026AB22DC64E04B40
12953	1	37.685287000000002	37.715910999999998	55.762220999999997	55.753078000000002	Красноказарменная	0103000020E61000000100000005000000DEAF027CB7D7424026AB22DC64E04B40DEAF027CB7D7424086A92D7590E14B405FECBDF8A2DB424086A92D7590E14B405FECBDF8A2DB424026AB22DC64E04B40DEAF027CB7D7424026AB22DC64E04B40
3875	1	37.748646000000001	37.756172999999997	55.694336999999997	55.666401	Краснодонская улица	0103000020E61000000100000005000000FF23D3A1D3DF4240C782C2A04CD54B40FF23D3A1D3DF42408DB3E908E0D84B40218FE046CAE042408DB3E908E0D84B40218FE046CAE04240C782C2A04CD54B40FF23D3A1D3DF4240C782C2A04CD54B40
12590	1	37.736401999999998	37.785926000000003	55.677838999999999	55.665075999999999	Краснодарская	0103000020E61000000100000005000000C05AB56B42DE424060ADDA3521D54B40C05AB56B42DE4240077AA86DC3D64B40BE89213999E44240077AA86DC3D64B40BE89213999E4424060ADDA3521D54B40C05AB56B42DE424060ADDA3521D54B40
12465	1	37.578809999999997	37.609226999999997	55.613366999999997	55.605148999999997	Красного Маяка	0103000020E61000000100000005000000834C327216CA4240821ABE8575CD4B40834C327216CA42400AB952CF82CE4B408B6B7C26FBCD42400AB952CF82CE4B408B6B7C26FBCD4240821ABE8575CD4B40834C327216CA4240821ABE8575CD4B40
7612	1	37.684677000000001	37.714976999999998	55.817126999999999	55.795914000000003	Краснобогатырская улица	0103000020E6100000010000000500000065A9F57EA3D74240DB368C82E0E54B4065A9F57EA3D74240DCD6169E97E84B403332C85D84DB4240DCD6169E97E84B403332C85D84DB4240DB368C82E0E54B4065A9F57EA3D74240DB368C82E0E54B40
12510	1	37.684677000000001	37.714976999999998	55.817126999999999	55.795914000000003	Краснобогатырская	0103000020E6100000010000000500000065A9F57EA3D74240DB368C82E0E54B4065A9F57EA3D74240DCD6169E97E84B403332C85D84DB4240DCD6169E97E84B403332C85D84DB4240DB368C82E0E54B4065A9F57EA3D74240DB368C82E0E54B40
13065	1	37.582861000000001	37.590578000000001	55.770760000000003	55.765939000000003	Красина	0103000020E61000000100000005000000938E72309BCA424090DD054A0AE24B40938E72309BCA424051888043A8E24B4059DE550F98CB424051888043A8E24B4059DE550F98CB424090DD054A0AE24B40938E72309BCA424090DD054A0AE24B40
12478	1	37.511921000000001	37.523986000000001	55.679544	55.673692000000003	Кравченко	0103000020E610000001000000050000005C9198A086C14240D6C9198A3BD64B405C9198A086C14240B5183C4CFBD64B40EBC726F911C34240B5183C4CFBD64B40EBC726F911C34240D6C9198A3BD64B405C9198A086C14240D6C9198A3BD64B40
2821	1	37.539850000000001	37.547432000000001	55.807744	55.805734999999999	Кочновский проезд	0103000020E61000000100000005000000705F07CE19C542400C1F115322E74B40705F07CE19C5424026C5C72764E74B405664744012C6424026C5C72764E74B405664744012C642400C1F115322E74B40705F07CE19C542400C1F115322E74B40
1780	1	37.639544999999998	37.646183999999998	55.747703000000001	55.740791000000002	Котельническая набережная	0103000020E6100000010000000500000000A94D9CDCD14240E8154F3DD2DE4B4000A94D9CDCD14240800F5EBBB4DF4B4067994528B6D24240800F5EBBB4DF4B4067994528B6D24240E8154F3DD2DE4B4000A94D9CDCD14240E8154F3DD2DE4B40
12604	1	37.586491000000002	37.602732000000003	55.887225999999998	55.882883	Костромская 	0103000020E61000000100000005000000FD32182312CB4240E198654F02F14B40FD32182312CB424098141F9F90F14B4058207A5226CD424098141F9F90F14B4058207A5226CD4240E198654F02F14B40FD32182312CB4240E198654F02F14B40
12626	1	37.586491000000002	37.602732000000003	55.887225999999998	55.882883	Костромская	0103000020E61000000100000005000000FD32182312CB4240E198654F02F14B40FD32182312CB424098141F9F90F14B4058207A5226CD424098141F9F90F14B4058207A5226CD4240E198654F02F14B40FD32182312CB4240E198654F02F14B40
13139	1	37.641351	37.660277999999998	55.821649000000001	55.821032000000002	Космонавтов	0103000020E61000000100000005000000E22021CA17D24240187C9A9317E94B40E22021CA17D2424043E55FCB2BE94B40572250FD83D4424043E55FCB2BE94B40572250FD83D44240187C9A9317E94B40E22021CA17D24240187C9A9317E94B40
13144	1	37.500943999999997	37.532457000000001	55.816727999999998	55.815007999999999	Космонавта Волкова	0103000020E610000001000000050000004F90D8EE1EC042403BFDA02E52E84B404F90D8EE1EC042401EDD088B8AE84B405DC30C8D27C442401EDD088B8AE84B405DC30C8D27C442403BFDA02E52E84B404F90D8EE1EC042403BFDA02E52E84B40
3643	1	37.821185	37.836931999999997	55.728104000000002	55.714413999999998	Косинская улица	0103000020E610000001000000050000009E7B0F971CE94240FBE6FEEA71DB4B409E7B0F971CE942401C0B0A8332DD4B40E97C789620EB42401C0B0A8332DD4B40E97C789620EB4240FBE6FEEA71DB4B409E7B0F971CE94240FBE6FEEA71DB4B40
12907	1	37.821185	37.836931999999997	55.728104000000002	55.714413999999998	Косинская	0103000020E610000001000000050000009E7B0F971CE94240FBE6FEEA71DB4B409E7B0F971CE942401C0B0A8332DD4B40E97C789620EB42401C0B0A8332DD4B40E97C789620EB4240FBE6FEEA71DB4B409E7B0F971CE94240FBE6FEEA71DB4B40
3832	1	37.511516999999998	37.548141999999999	55.889381	55.863646000000003	Коровинское шоссе	0103000020E610000001000000050000008C2C996379C142401EA9BEF38BEE4B408C2C996379C142408657923CD7F14B4032C85D8429C642408657923CD7F14B4032C85D8429C642401EA9BEF38BEE4B408C2C996379C142401EA9BEF38BEE4B40
13049	1	37.609217999999998	37.633014000000003	55.902509999999999	55.890946	Корнейчука	0103000020E610000001000000050000003811FDDAFACD42404240BE840AF24B403811FDDAFACD42400F289B7285F34B4080F44D9A06D142400F289B7285F34B4080F44D9A06D142404240BE840AF24B403811FDDAFACD42404240BE840AF24B40
12911	1	37.601609000000003	37.611562999999997	55.895636000000003	55.887104000000001	Коненкова	0103000020E6100000010000000500000059FD118601CD42404D13B69F8CF14B4059FD118601CD4240658F5033A4F24B40C93846B247CE4240658F5033A4F24B40C93846B247CE42404D13B69F8CF14B4059FD118601CD42404D13B69F8CF14B40
13010	1	37.630552999999999	37.637146999999999	55.819965000000003	55.818365999999997	Кондратюка	0103000020E6100000010000000500000085B2F0F5B5D0424044149337C0E84B4085B2F0F5B5D04240AD6EF59CF4E84B404CDF6B088ED14240AD6EF59CF4E84B404CDF6B088ED1424044149337C0E84B4085B2F0F5B5D0424044149337C0E84B40
3635	1	37.479132999999997	37.485466000000002	55.850444000000003	55.841503000000003	Конаковский проезд	0103000020E6100000010000000500000099B7EA3A54BD4240323ECC5EB6EB4B4099B7EA3A54BD42402B8A5759DBEC4B40F4A8F8BF23BE42402B8A5759DBEC4B40F4A8F8BF23BE4240323ECC5EB6EB4B4099B7EA3A54BD4240323ECC5EB6EB4B40
2333	1	37.566969999999998	37.594369	55.735545000000002	55.716042000000002	Комсомольский проспект	0103000020E6100000010000000500000014E8137992C84240FE47A643A7DB4B4014E8137992C8424040DEAB5626DE4B40CC608C4814CC424040DEAB5626DE4B40CC608C4814CC4240FE47A643A7DB4B4014E8137992C84240FE47A643A7DB4B40
794	1	37.652695999999999	37.657907000000002	55.776071999999999	55.773915000000002	Комсомольская площадь	0103000020E61000000100000005000000711DE38A8BD3424022718FA50FE34B40711DE38A8BD34240B0ABC95356E34B409D67EC4B36D44240B0ABC95356E34B409D67EC4B36D4424022718FA50FE34B40711DE38A8BD3424022718FA50FE34B40
12745	1	37.673951000000002	37.695428999999997	55.874752999999998	55.860715999999996	Коминтерна	0103000020E61000000100000005000000A20DC00644D642406C921FF12BEE4B40A20DC00644D64240F88903E8F7EF4B4051D845D103D94240F88903E8F7EF4B4051D845D103D942406C921FF12BEE4B40A20DC00644D642406C921FF12BEE4B40
13082	1	37.641646999999999	37.654035	55.865349000000002	55.856977000000001	Кольская	0103000020E61000000100000005000000CB49287D21D242404C361E6CB1ED4B40CB49287D21D242402B508BC1C3EE4B403DB83B6BB7D342402B508BC1C3EE4B403DB83B6BB7D342404C361E6CB1ED4B40CB49287D21D242404C361E6CB1ED4B40
2624	1	37.620052000000001	37.661346999999999	55.668432000000003	55.662891999999999	Коломенский проезд	0103000020E61000000100000005000000E2E82ADD5DCF4240D86322A5D9D44B40E2E82ADD5DCF4240C9CC052E8FD54B406327BC04A7D44240C9CC052E8FD54B406327BC04A7D44240D86322A5D9D44B40E2E82ADD5DCF4240D86322A5D9D44B40
6869	1	37.687192000000003	37.709406999999999	55.685502999999997	55.673996000000002	Коломенская набережная	0103000020E6100000010000000500000053094FE8F5D7424042D13C8045D64B4053094FE8F5D74240AA27F38FBED74B40D8463CD9CDDA4240AA27F38FBED74B40D8463CD9CDDA424042D13C8045D64B4053094FE8F5D7424042D13C8045D64B40
3850	1	37.517985000000003	37.534486999999999	55.898356	55.883004999999997	Клязьминская улица	0103000020E61000000100000005000000C7681D554DC242402C9ACE4E06F14B40C7681D554DC242402B155454FDF24B408E91EC116AC442402B155454FDF24B408E91EC116AC442402C9ACE4E06F14B40C7681D554DC242402C9ACE4E06F14B40
13060	1	37.517985000000003	37.534486999999999	55.898356	55.883004999999997	Клязьминская	0103000020E61000000100000005000000C7681D554DC242402C9ACE4E06F14B40C7681D554DC242402B155454FDF24B408E91EC116AC442402B155454FDF24B408E91EC116AC442402C9ACE4E06F14B40C7681D554DC242402C9ACE4E06F14B40
12768	1	37.756281000000001	37.762318	55.640284000000001	55.633516	Ключевая 	0103000020E6100000010000000500000008CBD8D0CDE0424012BF620D17D14B4008CBD8D0CDE0424077137CD3F4D14B407993DFA293E1424077137CD3F4D14B407993DFA293E1424012BF620D17D14B4008CBD8D0CDE0424012BF620D17D14B40
12605	1	37.490856000000001	37.508966000000001	55.872247999999999	55.86401	Клинская	0103000020E61000000100000005000000CF85915ED4BE42405FB532E197EE4B40CF85915ED4BE42402E008DD2A5EF4B40526342CC25C142402E008DD2A5EF4B40526342CC25C142405FB532E197EE4B40CF85915ED4BE42405FB532E197EE4B40
12546	1	37.564912999999997	37.578854999999997	55.767933999999997	55.767158999999999	Климашкина	0103000020E61000000100000005000000E90AB6114FC8424081EA1F4432E24B40E90AB6114FC8424044BE4BA94BE24B402310AFEB17CA424044BE4BA94BE24B402310AFEB17CA424081EA1F4432E24B40E90AB6114FC8424081EA1F4432E24B40
821	1	37.671506999999998	37.681955000000002	55.686112000000001	55.675142999999998	Кленовый бульвар	0103000020E610000001000000050000007D04FEF0F3D54240C98FF8156BD64B407D04FEF0F3D5424053B29C84D2D74B40FE2B2B4D4AD7424053B29C84D2D74B40FE2B2B4D4AD74240C98FF8156BD64B407D04FEF0F3D54240C98FF8156BD64B40
12978	1	37.508876000000001	37.521794	55.831513999999999	55.817421000000003	Клары Цеткин	0103000020E6100000010000000500000012DC48D922C1424025085740A1E84B4012DC48D922C142404415FE0C6FEA4B40E09F5225CAC242404415FE0C6FEA4B40E09F5225CAC2424025085740A1E84B4012DC48D922C1424025085740A1E84B40
12385	1	37.596085000000002	37.614859000000003	55.633358000000001	55.595613	Кировоградская улица	0103000020E610000001000000050000006E5166834CCC42404609FA0B3DCC4B406E5166834CCC42407A54FCDF11D14B405D5320B3B3CE42407A54FCDF11D14B405D5320B3B3CE42404609FA0B3DCC4B406E5166834CCC42404609FA0B3DCC4B40
12419	1	37.596085000000002	37.614859000000003	55.633358000000001	55.595613	Кировоградская 	0103000020E610000001000000050000006E5166834CCC42404609FA0B3DCC4B406E5166834CCC42407A54FCDF11D14B405D5320B3B3CE42407A54FCDF11D14B405D5320B3B3CE42404609FA0B3DCC4B406E5166834CCC42404609FA0B3DCC4B40
12362	1	37.596085000000002	37.614859000000003	55.633358000000001	55.595613	Кировоградская	0103000020E610000001000000050000006E5166834CCC42404609FA0B3DCC4B406E5166834CCC42407A54FCDF11D14B405D5320B3B3CE42407A54FCDF11D14B405D5320B3B3CE42404609FA0B3DCC4B406E5166834CCC42404609FA0B3DCC4B40
12974	1	37.639051000000002	37.660575000000001	55.816738000000001	55.813839999999999	Кибальчича	0103000020E61000000100000005000000F1BC546CCCD142409C16BCE82BE84B40F1BC546CCCD1424042B3EBDE8AE84B4011C7BAB88DD4424042B3EBDE8AE84B4011C7BAB88DD442409C16BCE82BE84B40F1BC546CCCD142409C16BCE82BE84B40
7761	1	37.815398999999999	37.842033999999998	55.744875	55.742696000000002	Кетчерская улица	0103000020E61000000100000005000000761893FE5EE842405D6F9BA910DF4B40761893FE5EE84240D34D621058DF4B405E0F26C5C7EB4240D34D621058DF4B405E0F26C5C7EB42405D6F9BA910DF4B40761893FE5EE842405D6F9BA910DF4B40
12723	1	37.815398999999999	37.842033999999998	55.744875	55.742696000000002	Кетчерская	0103000020E61000000100000005000000761893FE5EE842405D6F9BA910DF4B40761893FE5EE84240D34D621058DF4B405E0F26C5C7EB4240D34D621058DF4B405E0F26C5C7EB42405D6F9BA910DF4B40761893FE5EE842405D6F9BA910DF4B40
3482	1	37.557330999999998	37.569907999999998	55.894005	55.871526000000003	Керамический проезд	0103000020E610000001000000050000000306499F56C742408ECEF9298EEF4B400306499F56C74240F1BA7EC16EF24B4048DDCEBEF2C84240F1BA7EC16EF24B4048DDCEBEF2C842408ECEF9298EEF4B400306499F56C742408ECEF9298EEF4B40
13033	1	37.563000000000002	37.579124	55.686816999999998	55.681372000000003	Кедрова	0103000020E61000000100000005000000F2D24D6210C842407F349C3237D74B40F2D24D6210C842401DAB949EE9D74B40132A38BC20CA42401DAB949EE9D74B40132A38BC20CA42407F349C3237D74B40F2D24D6210C842407F349C3237D74B40
2561	1	37.626052000000001	37.733652999999997	55.675052000000001	55.588445	Каширское шоссе	0103000020E6100000010000000500000036CCD07822D04240533F6F2A52CB4B4036CCD07822D04240B98C9B1A68D64B405FCE6C57E8DD4240B98C9B1A68D64B405FCE6C57E8DD4240533F6F2A52CB4B4036CCD07822D04240533F6F2A52CB4B40
12721	1	37.558723999999998	37.598348000000001	55.660865999999999	55.651465000000002	Каховка	0103000020E61000000100000005000000C2BE9D4484C742408CBE823463D34B40C2BE9D4484C74240E884D04197D44B4042D0D1AA96CC4240E884D04197D44B4042D0D1AA96CC42408CBE823463D34B40C2BE9D4484C742408CBE823463D34B40
5838	1	37.446308999999999	37.501133000000003	55.741205999999998	55.729847999999997	Кастанаевская улица	0103000020E610000001000000050000008A743FA720B942408786C5A86BDD4B408A743FA720B94240ABCC94D6DFDE4B4023F94A2025C04240ABCC94D6DFDE4B4023F94A2025C042408786C5A86BDD4B408A743FA720B942408786C5A86BDD4B40
12902	1	37.446308999999999	37.501133000000003	55.741205999999998	55.729847999999997	Кастанаевская 	0103000020E610000001000000050000008A743FA720B942408786C5A86BDD4B408A743FA720B94240ABCC94D6DFDE4B4023F94A2025C04240ABCC94D6DFDE4B4023F94A2025C042408786C5A86BDD4B408A743FA720B942408786C5A86BDD4B40
12623	1	37.446308999999999	37.501133000000003	55.741205999999998	55.729847999999997	Кастанаевская	0103000020E610000001000000050000008A743FA720B942408786C5A86BDD4B408A743FA720B94240ABCC94D6DFDE4B4023F94A2025C04240ABCC94D6DFDE4B4023F94A2025C042408786C5A86BDD4B408A743FA720B942408786C5A86BDD4B40
12885	1	37.648887999999999	37.667689000000003	55.827655999999998	55.821947000000002	Касаткина	0103000020E61000000100000005000000286211C30ED34240CD052E8F35E94B40286211C30ED34240492BBEA1F0E94B40117349D576D54240492BBEA1F0E94B40117349D576D54240CD052E8F35E94B40286211C30ED34240CD052E8F35E94B40
3904	1	37.529654000000001	37.539329000000002	55.898274999999998	55.891779	Карельский бульвар	0103000020E610000001000000050000000919C8B3CBC342403A2174D025F24B400919C8B3CBC342403EE8D9ACFAF24B40676490BB08C542403EE8D9ACFAF24B40676490BB08C542403A2174D025F24B400919C8B3CBC342403A2174D025F24B40
13069	1	37.589913000000003	37.595528000000002	55.867071000000003	55.857109000000001	Каргопольская	0103000020E610000001000000050000001D3EE94482CB4240BB0D6ABFB5ED4B401D3EE94482CB4240AF27BA2EFCEE4B4018EDF1423ACC4240AF27BA2EFCEE4B4018EDF1423ACC4240BB0D6ABFB5ED4B401D3EE94482CB4240BB0D6ABFB5ED4B40
7034	1	37.457707999999997	37.496003000000002	55.776071999999999	55.767609999999998	Карамышевская набережная	0103000020E610000001000000050000000C8FFD2C96BA4240910A630B41E24B400C8FFD2C96BA4240B0ABC95356E34B40E4DBBB067DBF4240B0ABC95356E34B40E4DBBB067DBF4240910A630B41E24B400C8FFD2C96BA4240910A630B41E24B40
6493	1	37.642086999999997	37.685943000000002	55.638531	55.636138000000003	Кантемировская улица	0103000020E61000000100000005000000E71725E82FD2424016DF50F86CD14B40E71725E82FD24240B83D4162BBD14B40C7F5EFFACCD74240B83D4162BBD14B40C7F5EFFACCD7424016DF50F86CD14B40E71725E82FD2424016DF50F86CD14B40
12838	1	37.642086999999997	37.685943000000002	55.638531	55.636138000000003	Кантемировская	0103000020E61000000100000005000000E71725E82FD2424016DF50F86CD14B40E71725E82FD24240B83D4162BBD14B40C7F5EFFACCD74240B83D4162BBD14B40C7F5EFFACCD7424016DF50F86CD14B40E71725E82FD2424016DF50F86CD14B40
97	1	37.808401000000003	37.824598000000002	55.828783999999999	55.823205999999999	Камчатская улица	0103000020E61000000100000005000000E08618AF79E742407CEF6FD05EE94B40E08618AF79E742405AB9179815EA4B406B2C616D8CE942405AB9179815EA4B406B2C616D8CE942407CEF6FD05EE94B40E08618AF79E742407CEF6FD05EE94B40
12985	1	37.808401000000003	37.824598000000002	55.828783999999999	55.823205999999999	Камчатская	0103000020E61000000100000005000000E08618AF79E742407CEF6FD05EE94B40E08618AF79E742405AB9179815EA4B406B2C616D8CE942405AB9179815EA4B406B2C616D8CE942407CEF6FD05EE94B40E08618AF79E742407CEF6FD05EE94B40
2555	1	37.611311000000001	37.614131999999998	55.730330000000002	55.728580999999998	Калужская площадь	0103000020E61000000100000005000000B05758703FCE424055BE672442DD4B40B05758703FCE4240D3A414747BDD4B40AAB69BE09BCE4240D3A414747BDD4B40AAB69BE09BCE424055BE672442DD4B40B05758703FCE424055BE672442DD4B40
13189	1	37.503934999999998	37.514239000000003	55.537993999999998	55.536124999999998	Кадырова	0103000020E61000000100000005000000A6272CF180C04240B4C876BE9FC44B40A6272CF180C04240DCB8C5FCDCC44B40F4A96395D2C14240DCB8C5FCDCC44B40F4A96395D2C14240B4C876BE9FC44B40A6272CF180C04240B4C876BE9FC44B40
7425	1	37.631360999999998	37.674129999999998	55.637036999999999	55.627808999999999	Кавказский бульвар	0103000020E61000000100000005000000247CEF6FD0D042403691990B5CD04B40247CEF6FD0D04240C5ABAC6D8AD14B4051A04FE449D64240C5ABAC6D8AD14B4051A04FE449D642403691990B5CD04B40247CEF6FD0D042403691990B5CD04B40
12764	1	37.393982000000001	37.418281	55.81955	55.804783999999998	Исаковского	0103000020E61000000100000005000000399B8E006EB242400A2C802903E74B40399B8E006EB24240E9B7AF03E7E84B40E3C4573B8AB54240E9B7AF03E7E84B40E3C4573B8AB542400A2C802903E74B40399B8E006EB242400A2C802903E74B40
12816	1	37.452452999999998	37.461965999999997	55.717249000000002	55.715463999999997	Инициативная	0103000020E6100000010000000500000011FDDAFAE9B9424090BB085394DB4B4011FDDAFAE9B942405B0BB3D0CEDB4B4095EEAEB321BB42405B0BB3D0CEDB4B4095EEAEB321BB424090BB085394DB4B4011FDDAFAE9B9424090BB085394DB4B40
12716	1	37.570779000000002	37.586311000000002	55.880085999999999	55.879617000000003	Инженерная	0103000020E610000001000000050000002E1F49490FC94240B900344A97F04B402E1F49490FC942406FD575A8A6F04B407D24253D0CCB42406FD575A8A6F04B407D24253D0CCB4240B900344A97F04B402E1F49490FC94240B900344A97F04B40
13099	1	37.536481000000002	37.542724999999997	55.885928	55.885866999999998	Икшинская	0103000020E6100000010000000500000073F6CE68ABC4424085CD001764F14B4073F6CE68ABC442402B4EB51666F14B405DDC460378C542402B4EB51666F14B405DDC460378C5424085CD001764F14B4073F6CE68ABC4424085CD001764F14B40
2780	1	37.557977999999999	37.567526999999998	55.550178000000002	55.541958000000001	Изюмская улица	0103000020E6100000010000000500000099F1B6D26BC742401DE736E15EC54B4099F1B6D26BC74240467D923B6CC64B406A4C88B9A4C84240467D923B6CC64B406A4C88B9A4C842401DE736E15EC54B4099F1B6D26BC742401DE736E15EC54B40
12642	1	37.557977999999999	37.567526999999998	55.550178000000002	55.541958000000001	Изюмская	0103000020E6100000010000000500000099F1B6D26BC742401DE736E15EC54B4099F1B6D26BC74240467D923B6CC64B406A4C88B9A4C84240467D923B6CC64B406A4C88B9A4C842401DE736E15EC54B4099F1B6D26BC742401DE736E15EC54B40
12827	1	37.675145000000001	37.694118000000003	55.878804000000002	55.866211999999997	Изумрудная	0103000020E610000001000000050000006A87BF266BD642408DB3E908E0EE4B406A87BF266BD6424008CC43A67CF04B4050C8CEDBD8D8424008CC43A67CF04B4050C8CEDBD8D842408DB3E908E0EE4B406A87BF266BD642408DB3E908E0EE4B40
12305	1	37.717967999999999	37.762300000000003	55.788454000000002	55.778790000000001	Измайловское шоссе	0103000020E610000001000000050000008AC91B60E6DB4240D6390664AFE34B408AC91B60E6DB42404033880FECE44B40D3DEE00B93E142404033880FECE44B40D3DEE00B93E14240D6390664AFE34B408AC91B60E6DB4240D6390664AFE34B40
589	1	37.747559000000003	37.818911999999997	55.789076999999999	55.786504999999998	Измайловский проспект	0103000020E610000001000000050000004D6A6803B0DF4240FB912232ACE44B404D6A6803B0DF42404D83A27900E54B40A626C11BD2E842404D83A27900E54B40A626C11BD2E84240FB912232ACE44B404D6A6803B0DF4240FB912232ACE44B40
510	1	37.768039999999999	37.770384999999997	55.802396000000002	55.789912000000001	Измайловский проезд	0103000020E610000001000000050000008A027D224FE24240E65B1FD61BE54B408A027D224FE242407A3881E9B4E64B401B2AC6F99BE242407A3881E9B4E64B401B2AC6F99BE24240E65B1FD61BE54B408A027D224FE24240E65B1FD61BE54B40
611	1	37.782144000000002	37.823439	55.797320999999997	55.796242999999997	Измайловский бульвар	0103000020E610000001000000050000009E616A4B1DE442409F55664AEBE54B409E616A4B1DE44240FEB4519D0EE64B401FA0FB7266E94240FEB4519D0EE64B401FA0FB7266E942409F55664AEBE54B409E616A4B1DE442409F55664AEBE54B40
12662	1	37.641530000000003	37.646884	55.860988999999996	55.857897000000001	Ивовая	0103000020E6100000010000000500000092B3B0A71DD24240132BA391CFED4B4092B3B0A71DD242409D9B36E334EE4B4020274C18CDD242409D9B36E334EE4B4020274C18CDD24240132BA391CFED4B4092B3B0A71DD24240132BA391CFED4B40
12671	1	37.708437000000004	37.737209999999997	55.824865000000003	55.813288	Ивантеевская	0103000020E6100000010000000500000060234910AEDA4240581D39D219E84B4060234910AEDA4240BA4E232D95E94B405F24B4E55CDE4240BA4E232D95E94B405F24B4E55CDE4240581D39D219E84B4060234910AEDA4240581D39D219E84B40
12408	1	37.729925000000001	37.731082999999998	55.788964999999997	55.779170000000001	Ибрагимова	0103000020E6100000010000000500000033C4B12E6EDD42401D03B2D7BBE34B4033C4B12E6EDD424025581CCEFCE44B40AED4B32094DD424025581CCEFCE44B40AED4B32094DD42401D03B2D7BBE34B4033C4B12E6EDD42401D03B2D7BBE34B40
13083	1	37.502076000000002	37.513708999999999	55.798161	55.777625999999998	Зорге	0103000020E61000000100000005000000A20DC00644C042407842AF3F89E34B40A20DC00644C04240A9F8BF232AE64B4097546D37C1C14240A9F8BF232AE64B4097546D37C1C142407842AF3F89E34B40A20DC00644C042407842AF3F89E34B40
12534	1	37.499031000000002	37.529905999999997	55.825912000000002	55.817915999999997	Зои и Александра Космодемьянских	0103000020E610000001000000050000005858703FE0BF42400470B378B1E84B405858703FE0BF4240DEAF027CB7E94B4022FAB5F5D3C34240DEAF027CB7E94B4022FAB5F5D3C342400470B378B1E84B405858703FE0BF42400470B378B1E84B40
13123	1	37.711329999999997	37.726224000000002	55.803894	55.801394000000002	Знаменская	0103000020E61000000100000005000000F35487DC0CDB4240F69A1E1494E64B40F35487DC0CDB4240AEB9A3FFE5E64B4000C974E8F4DC4240AEB9A3FFE5E64B4000C974E8F4DC4240F69A1E1494E64B40F35487DC0CDB4240F69A1E1494E64B40
12492	1	37.860709999999997	37.874445999999999	55.705193999999999	55.697031000000003	Златоустовская	0103000020E610000001000000050000008AABCABE2BEE42402BA6D24F38D94B408AABCABE2BEE4240EFAA07CC43DA4B401B0FB6D8EDEF4240EFAA07CC43DA4B401B0FB6D8EDEF42402BA6D24F38D94B408AABCABE2BEE42402BA6D24F38D94B40
12583	1	37.654915000000003	37.657826	55.764040000000001	55.744048999999997	Земляной Вал	0103000020E6100000010000000500000076543541D4D342408DCF64FF3CDF4B4076543541D4D34240FD6A0E10CCE14B40B03A72A433D44240FD6A0E10CCE14B40B03A72A433D442408DCF64FF3CDF4B4076543541D4D342408DCF64FF3CDF4B40
2140	1	37.577542999999999	37.579276999999998	55.743127000000001	55.738987000000002	Земледельческий переулок	0103000020E610000001000000050000005184D4EDECC94240A795422097DE4B405184D4EDECC9424026E318C91EDF4B409929ADBF25CA424026E318C91EDF4B409929ADBF25CA4240A795422097DE4B405184D4EDECC94240A795422097DE4B40
1977	1	37.716082	37.720528000000002	55.808765999999999	55.800407999999997	Зельев переулок	0103000020E610000001000000050000008CA03193A8DB424077BAF3C473E64B408CA03193A8DB4240F10EF0A485E74B4018EDF1423ADC4240F10EF0A485E74B4018EDF1423ADC424077BAF3C473E64B408CA03193A8DB424077BAF3C473E64B40
1272	1	37.764167999999998	37.830725000000001	55.753950000000003	55.747033999999999	Зеленый проспект	0103000020E610000001000000050000002A53CC41D0E14240028063CF9EDF4B402A53CC41D0E14240DC68006F81E04B401C7C613255EA4240DC68006F81E04B401C7C613255EA4240028063CF9EDF4B402A53CC41D0E14240028063CF9EDF4B40
3308	1	37.764842000000002	37.790579000000001	55.718049999999998	55.700232999999997	Зеленодольская улица	0103000020E61000000100000005000000BA4DB857E6E142403C4A253CA1D94B40BA4DB857E6E142404772F90FE9DB4B40C3F352B131E542404772F90FE9DB4B40C3F352B131E542403C4A253CA1D94B40BA4DB857E6E142403C4A253CA1D94B40
12757	1	37.764842000000002	37.790579000000001	55.718049999999998	55.700232999999997	Зеленодольская	0103000020E61000000100000005000000BA4DB857E6E142403C4A253CA1D94B40BA4DB857E6E142404772F90FE9DB4B40C3F352B131E542404772F90FE9DB4B40C3F352B131E542403C4A253CA1D94B40BA4DB857E6E142403C4A253CA1D94B40
3784	1	37.482529	37.525091000000003	55.879218000000002	55.861449	Зеленоградская улица	0103000020E61000000100000005000000902FA182C3BD42400116F9F543EE4B40902FA182C3BD4240FB0626378AF04B404436902E36C34240FB0626378AF04B404436902E36C342400116F9F543EE4B40902FA182C3BD42400116F9F543EE4B40
12511	1	37.482529	37.525091000000003	55.879218000000002	55.861449	Зеленоградская 	0103000020E61000000100000005000000902FA182C3BD42400116F9F543EE4B40902FA182C3BD4240FB0626378AF04B404436902E36C34240FB0626378AF04B404436902E36C342400116F9F543EE4B40902FA182C3BD42400116F9F543EE4B40
12399	1	37.724848999999999	37.742725999999998	55.784880999999999	55.784014999999997	Зверинецкая улица	0103000020E61000000100000005000000E7C41EDAC7DC42406649809A5AE44B40E7C41EDAC7DC42403A2009FB76E44B40C7F143A511DF42403A2009FB76E44B40C7F143A511DF42406649809A5AE44B40E7C41EDAC7DC42406649809A5AE44B40
6784	1	37.681550000000001	37.687192000000003	55.682879	55.676265000000001	Затонная улица	0103000020E610000001000000050000005E4BC8073DD74240F836FDD98FD64B405E4BC8073DD7424006103E9468D74B4053094FE8F5D7424006103E9468D74B4053094FE8F5D74240F836FDD98FD64B405E4BC8073DD74240F836FDD98FD64B40
12982	1	37.681550000000001	37.687192000000003	55.682879	55.676265000000001	Затонная	0103000020E610000001000000050000005E4BC8073DD74240F836FDD98FD64B405E4BC8073DD7424006103E9468D74B4053094FE8F5D7424006103E9468D74B4053094FE8F5D74240F836FDD98FD64B405E4BC8073DD74240F836FDD98FD64B40
12733	1	37.764060999999998	37.778666999999999	55.733493000000003	55.726486999999999	Зарайская	0103000020E61000000100000005000000149337C0CCE142400DFCA886FDDC4B40149337C0CCE14240276C3F19E3DD4B40BABC395CABE34240276C3F19E3DD4B40BABC395CABE342400DFCA886FDDC4B40149337C0CCE142400DFCA886FDDC4B40
13193	1	37.629294999999999	37.647091000000003	55.871698000000002	55.86645	Заповедная	0103000020E61000000100000005000000A64412BD8CD0424042CF66D5E7EE4B40A64412BD8CD042408BFED0CC93EF4B409A44BDE0D3D242408BFED0CC93EF4B409A44BDE0D3D2424042CF66D5E7EE4B40A64412BD8CD0424042CF66D5E7EE4B40
12998	1	37.858114	37.865623999999997	55.819555000000001	55.814922000000003	Западная	0103000020E61000000100000005000000B01EF7ADD6ED42403D65355D4FE84B40B01EF7ADD6ED4240FB22A12DE7E84B40FC5069C4CCEE4240FB22A12DE7E84B40FC5069C4CCEE42403D65355D4FE84B40B01EF7ADD6ED42403D65355D4FE84B40
6459	1	37.742268000000003	37.762821000000002	55.626868000000002	55.620199	Задонский проезд	0103000020E61000000100000005000000056F48A302DF424086014BAE62CF4B40056F48A302DF42405874EB353DD04B40DCD9571EA4E142405874EB353DD04B40DCD9571EA4E1424086014BAE62CF4B40056F48A302DF424086014BAE62CF4B40
5748	1	37.662533000000003	37.698439	55.586404999999999	55.573531000000003	Загорьевский проезд	0103000020E61000000100000005000000A9C29FE1CDD44240001FBC7669C94B40A9C29FE1CDD44240FE9AAC510FCB4B401FA0FB7266D94240FE9AAC510FCB4B401FA0FB7266D94240001FBC7669C94B40A9C29FE1CDD44240001FBC7669C94B40
5836	1	37.671885000000003	37.694530999999998	55.585881000000001	55.579631999999997	Загорьевская улица	0103000020E6100000010000000500000024D6E25300D6424087DBA16131CA4B4024D6E25300D64240842C0B26FECA4B4072874D64E6D84240842C0B26FECA4B4072874D64E6D8424087DBA16131CA4B4024D6E25300D6424087DBA16131CA4B40
2482	1	37.602085000000002	37.615901000000001	55.701464999999999	55.691755000000001	Загородное шоссе	0103000020E61000000100000005000000C2340C1F11CD424018EC866D8BD84B40C2340C1F11CD4240F224E99AC9D94B406F490ED8D5CE4240F224E99AC9D94B406F490ED8D5CE424018EC866D8BD84B40C2340C1F11CD424018EC866D8BD84B40
76471	1	37.185113999999999	37.189318999999998	55.974201000000001	55.973058000000002	Заводской переулок	0103000020E610000001000000050000001004C8D0B19742403B8E1F2A8DFC4B401004C8D0B1974240815D4D9EB2FC4B4076C1E09A3B984240815D4D9EB2FC4B4076C1E09A3B9842403B8E1F2A8DFC4B401004C8D0B19742403B8E1F2A8DFC4B40
3188	1	37.843300999999997	37.854647	55.699750999999999	55.684517999999997	Жулебинский бульвар	0103000020E6100000010000000500000090D78349F1EB4240FCC22B499ED74B4090D78349F1EB4240F12BD67091D94B40F04FA91265ED4240F12BD67091D94B40F04FA91265ED4240FCC22B499ED74B4090D78349F1EB4240FCC22B499ED74B40
2349	1	37.614258	37.623815999999998	55.730212999999999	55.729792000000003	Житная улица	0103000020E6100000010000000500000037A79201A0CE4240F47002D369DD4B4037A79201A0CE4240990E9D9E77DD4B405B5CE333D9CF4240990E9D9E77DD4B405B5CE333D9CF4240F47002D369DD4B4037A79201A0CE4240F47002D369DD4B40
7263	1	37.450423000000001	37.456530999999998	55.802953000000002	55.779027999999997	Живописная улица	0103000020E61000000100000005000000E02EFB75A7B942408A558330B7E34B40E02EFB75A7B94240D09CF529C7E64B401A4E999B6FBA4240D09CF529C7E64B401A4E999B6FBA42408A558330B7E34B40E02EFB75A7B942408A558330B7E34B40
12790	1	37.450423000000001	37.456530999999998	55.802953000000002	55.779027999999997	Живописная	0103000020E61000000100000005000000E02EFB75A7B942408A558330B7E34B40E02EFB75A7B94240D09CF529C7E64B401A4E999B6FBA4240D09CF529C7E64B401A4E999B6FBA42408A558330B7E34B40E02EFB75A7B942408A558330B7E34B40
12545	1	37.676150999999997	37.688045000000002	55.785822000000003	55.783366999999998	Жебрунова	0103000020E610000001000000050000002F14B01D8CD6424000E2AE5E45E44B402F14B01D8CD64240193DB7D095E44B409296CADB11D84240193DB7D095E44B409296CADB11D8424000E2AE5E45E44B402F14B01D8CD6424000E2AE5E45E44B40
3281	1	37.776583000000002	37.781793	55.709180000000003	55.698624000000002	Есенинский бульвар	0103000020E6100000010000000500000096D05D1267E34240B119E0826CD94B4096D05D1267E34240187D0569C6DA4B40F19E03CB11E44240187D0569C6DA4B40F19E03CB11E44240B119E0826CD94B4096D05D1267E34240B119E0826CD94B40
7465	1	37.667501000000001	37.680320000000002	55.631934999999999	55.627392	Ереванская улица	0103000020E610000001000000050000000E863AAC70D54240D2E28C614ED04B400E863AAC70D542405019FF3EE3D04B404968CBB914D742405019FF3EE3D04B404968CBB914D74240D2E28C614ED04B400E863AAC70D54240D2E28C614ED04B40
12846	1	37.667501000000001	37.680320000000002	55.631934999999999	55.627392	Ереванская	0103000020E610000001000000050000000E863AAC70D54240D2E28C614ED04B400E863AAC70D542405019FF3EE3D04B404968CBB914D742405019FF3EE3D04B404968CBB914D74240D2E28C614ED04B400E863AAC70D54240D2E28C614ED04B40
12983	1	37.660206000000002	37.672575999999999	55.884807000000002	55.842725999999999	Енисейская	0103000020E61000000100000005000000BE4F55A181D4424094BE1072DEEB4B40BE4F55A181D44240CD22145B41F14B4089096AF816D64240CD22145B41F14B4089096AF816D6424094BE1072DEEB4B40BE4F55A181D4424094BE1072DEEB4B40
12825	1	37.410635999999997	37.431873000000003	55.743634	55.733730999999999	Ельнинская	0103000020E61000000100000005000000B6476FB88FB44240DB87BCE5EADD4B40B6476FB88FB44240CA181F662FDF4B4041834D9D47B74240CA181F662FDF4B4041834D9D47B74240DB87BCE5EADD4B40B6476FB88FB44240DB87BCE5EADD4B40
402	1	37.671768	37.675038000000001	55.773327000000002	55.771169999999998	Елоховский проезд	0103000020E61000000100000005000000EA3F6B7EFCD5424002D4D4B2B5E24B40EA3F6B7EFCD54240910E0F61FCE24B4054C72AA567D64240910E0F61FCE24B4054C72AA567D6424002D4D4B2B5E24B40EA3F6B7EFCD5424002D4D4B2B5E24B40
12430	1	37.730383000000003	37.738719000000003	55.612985000000002	55.599086999999997	Елецкая	0103000020E61000000100000005000000F646AD307DDD4240B83A00E2AECC4B40F646AD307DDD424023F8DF4A76CE4B4088F71C588EDE424023F8DF4A76CE4B4088F71C588EDE4240B83A00E2AECC4B40F646AD307DDD4240B83A00E2AECC4B40
2773	1	37.682817	37.685502999999997	55.795074	55.792350999999996	Егерская улица	0103000020E610000001000000050000009013268C66D74240F8F9EFC16BE54B409013268C66D7424030F31DFCC4E54B40AA27F38FBED7424030F31DFCC4E54B40AA27F38FBED74240F8F9EFC16BE54B409013268C66D74240F8F9EFC16BE54B40
13101	1	37.341242000000001	37.368191000000003	55.849989000000001	55.839052000000002	Дубравная	0103000020E61000000100000005000000C5025FD1ADAB42405BD2510E66EB4B40C5025FD1ADAB4240D97A8670CCEC4B403DD7F7E120AF4240D97A8670CCEC4B403DD7F7E120AF42405BD2510E66EB4B40C5025FD1ADAB42405BD2510E66EB4B40
12667	1	37.496586999999998	37.501734999999996	55.812351999999997	55.808821999999999	Дубосековская	0103000020E61000000100000005000000334FAE2990BF42408524B37A87E74B40334FAE2990BF42408B6B7C26FBE74B4018213CDA38C042408B6B7C26FBE74B4018213CDA38C042408524B37A87E74B40334FAE2990BF42408524B37A87E74B40
2995	1	37.543937	37.567931000000002	55.900123000000001	55.854638000000001	Дубнинская улица	0103000020E61000000100000005000000CC0A45BA9FC542409DF529C764ED4B40CC0A45BA9FC542404FB0FF3A37F34B403AB187F6B1C842404FB0FF3A37F34B403AB187F6B1C842409DF529C764ED4B40CC0A45BA9FC542409DF529C764ED4B40
12807	1	37.543937	37.567931000000002	55.900123000000001	55.854638000000001	Дубнинская 	0103000020E61000000100000005000000CC0A45BA9FC542409DF529C764ED4B40CC0A45BA9FC542404FB0FF3A37F34B403AB187F6B1C842404FB0FF3A37F34B403AB187F6B1C842409DF529C764ED4B40CC0A45BA9FC542409DF529C764ED4B40
12717	1	37.543937	37.567931000000002	55.900123000000001	55.854638000000001	Дубнинская	0103000020E61000000100000005000000CC0A45BA9FC542409DF529C764ED4B40CC0A45BA9FC542404FB0FF3A37F34B403AB187F6B1C842404FB0FF3A37F34B403AB187F6B1C842409DF529C764ED4B40CC0A45BA9FC542409DF529C764ED4B40
12602	1	37.629134000000001	37.637343999999999	55.731034000000001	55.710042999999999	Дубининская	0103000020E610000001000000050000009D66817687D042407AE063B0E2DA4B409D66817687D04240CD21A98592DD4B40A226FA7C94D14240CD21A98592DD4B40A226FA7C94D142407AE063B0E2DA4B409D66817687D042407AE063B0E2DA4B40
12540	1	37.603729000000001	37.614859000000003	55.785316000000002	55.782567	Достоевского	0103000020E61000000100000005000000CA52EBFD46CD4240E4F6CB272BE44B40CA52EBFD46CD42404583143C85E44B405D5320B3B3CE42404583143C85E44B405D5320B3B3CE4240E4F6CB272BE44B40CA52EBFD46CD4240E4F6CB272BE44B40
12363	1	37.606586	37.628469000000003	55.632362000000001	55.575439000000003	Дорожная	0103000020E61000000100000005000000111B2C9CA4CD4240E6EB32FCA7C94B40111B2C9CA4CD4240D89DEE3CF1D04B4061C614AC71D04240D89DEE3CF1D04B4061C614AC71D04240E6EB32FCA7C94B40111B2C9CA4CD4240E6EB32FCA7C94B40
12930	1	37.409126999999998	37.421424999999999	55.715803999999999	55.711751999999997	Дорогобужская	0103000020E610000001000000050000008E7406465EB44240696E85B01ADB4B408E7406465EB44240492C29779FDB4B40C05B2041F1B54240492C29779FDB4B40C05B2041F1B54240696E85B01ADB4B408E7406465EB44240696E85B01ADB4B40
12908	1	37.599345999999997	37.611193999999998	55.727545999999997	55.710504	Донская	0103000020E61000000100000005000000847EA65EB7CC4240AED689CBF1DA4B40847EA65EB7CC4240F52A323A20DD4B4076C1E09A3BCE4240F52A323A20DD4B4076C1E09A3BCE4240AED689CBF1DA4B40847EA65EB7CC4240AED689CBF1DA4B40
13137	1	37.690111000000002	37.721668999999999	55.653405999999997	55.642301000000003	Донецкая 	0103000020E6100000010000000500000010CEA78E55D8424014984EEB36D24B4010CEA78E55D842404D81CCCEA2D34B40BDC458A65FDC42404D81CCCEA2D34B40BDC458A65FDC424014984EEB36D24B4010CEA78E55D8424014984EEB36D24B40
12422	1	37.704870999999997	37.716028000000001	55.618034000000002	55.600033000000003	Домодедовская	0103000020E610000001000000050000000C73823639DA4240A9C29FE1CDCC4B400C73823639DA424075E8F4BC1BCF4B40998235CEA6DB424075E8F4BC1BCF4B40998235CEA6DB4240A9C29FE1CDCC4B400C73823639DA4240A9C29FE1CDCC4B40
12589	1	37.601078999999999	37.604734999999998	55.779027999999997	55.772779999999997	Долгоруковская	0103000020E61000000100000005000000FCA71B28F0CC42405E807D74EAE24B40FCA71B28F0CC42408A558330B7E34B408FDFDBF467CD42408A558330B7E34B408FDFDBF467CD42405E807D74EAE24B40FCA71B28F0CC42405E807D74EAE24B40
13168	1	37.446874000000001	37.458274000000003	55.830365999999998	55.829754999999999	Долгова	0103000020E6100000010000000500000063B7CF2A33B94240A3586E6935EA4B4063B7CF2A33B94240ECDADE6E49EA4B40B64DF1B8A8BA4240ECDADE6E49EA4B40B64DF1B8A8BA4240A3586E6935EA4B4063B7CF2A33B94240A3586E6935EA4B40
13233	1	37.644710000000003	37.657178999999999	55.843389000000002	55.836064	Докукина	0103000020E61000000100000005000000BCB376DB85D2424075AE282504EB4B40BCB376DB85D242403067B62BF4EB4B401A4F04711ED442403067B62BF4EB4B401A4F04711ED4424075AE282504EB4B40BCB376DB85D2424075AE282504EB4B40
12704	1	37.563467000000003	37.571758000000003	55.725214000000001	55.721482999999999	Доватора	0103000020E6100000010000000500000008B0C8AF1FC842405BCF108E59DC4B4008B0C8AF1FC84240F94CF6CFD3DC4B40FA9CBB5D2FC94240F94CF6CFD3DC4B40FA9CBB5D2FC942405BCF108E59DC4B4008B0C8AF1FC842405BCF108E59DC4B40
12991	1	37.591467000000002	37.595824	55.820486000000002	55.807834999999997	Добролюбова	0103000020E61000000100000005000000E5D4CE30B5CB424036C8242367E74B40E5D4CE30B5CB4240B6696CAF05E94B400116F9F543CC4240B6696CAF05E94B400116F9F543CC424036C8242367E74B40E5D4CE30B5CB424036C8242367E74B40
12318	1	37.583858999999997	37.614258	55.624108	55.614652999999997	Днепропетровская улица	0103000020E61000000100000005000000D53C47E4BBCA4240B3B112F3ACCE4B40D53C47E4BBCA424003965CC5E2CF4B4037A79201A0CE424003965CC5E2CF4B4037A79201A0CE4240B3B112F3ACCE4B40D53C47E4BBCA4240B3B112F3ACCE4B40
12370	1	37.583858999999997	37.614258	55.624108	55.614652999999997	Днепропетровская	0103000020E61000000100000005000000D53C47E4BBCA4240B3B112F3ACCE4B40D53C47E4BBCA424003965CC5E2CF4B4037A79201A0CE424003965CC5E2CF4B4037A79201A0CE4240B3B112F3ACCE4B40D53C47E4BBCA4240B3B112F3ACCE4B40
3011	1	37.537019999999998	37.579672000000002	55.953265999999999	55.810065999999999	Дмитровское шоссе	0103000020E6100000010000000500000022A64412BDC44240FFCC203EB0E74B4022A64412BDC44240C231CB9E04FA4B4016342DB132CA4240C231CB9E04FA4B4016342DB132CA4240FFCC203EB0E74B4022A64412BDC44240FFCC203EB0E74B40
4784	1	37.561706000000001	37.579529000000001	55.810136999999997	55.806530000000002	Дмитровский проезд	0103000020E61000000100000005000000C6FB71FBE5C74240179F02603CE74B40C6FB71FBE5C74240C823B891B2E74B40B30A9B012ECA4240C823B891B2E74B40B30A9B012ECA4240179F02603CE74B40C6FB71FBE5C74240179F02603CE74B40
12574	1	37.556783000000003	37.595950000000002	55.694490000000002	55.679777999999999	Дмитрия Ульянова	0103000020E6100000010000000500000001FC53AA44C7424028452BF702D74B4001FC53AA44C7424014B35E0CE5D84B408E06F01648CC424014B35E0CE5D84B408E06F01648CC424028452BF702D74B4001FC53AA44C7424028452BF702D74B40
12457	1	37.877751000000004	37.896832000000003	55.710366999999998	55.708419999999997	Дмитриевского	0103000020E6100000010000000500000002840F255AF0424089EAAD81ADDA4B4002840F255AF042402D944C4EEDDA4B40CE001764CBF242402D944C4EEDDA4B40CE001764CBF2424089EAAD81ADDA4B4002840F255AF0424089EAAD81ADDA4B40
12873	1	37.571641	37.578054999999999	55.540785999999997	55.539971000000001	Джанкойская 	0103000020E61000000100000005000000C00644882BC94240EBE40CC51DC54B40C00644882BC942403C11C47938C54B400725CCB4FDC942403C11C47938C54B400725CCB4FDC94240EBE40CC51DC54B40C00644882BC94240EBE40CC51DC54B40
12966	1	37.646633000000001	37.651941999999998	55.726781000000003	55.716448	Дербеневская	0103000020E61000000100000005000000D7C1C1DEC4D242406EA46C91B4DB4B40D7C1C1DEC4D24240562DE92807DD4B40C571E0D572D34240562DE92807DD4B40C571E0D572D342406EA46C91B4DB4B40D7C1C1DEC4D242406EA46C91B4DB4B40
13051	1	37.515371000000002	37.520904999999999	55.739519000000001	55.738505000000004	Дениса Давыдова	0103000020E6100000010000000500000046274BADF7C142405C77F35487DE4B4046274BADF7C14240A4E2FF8EA8DE4B4054A9D903ADC24240A4E2FF8EA8DE4B4054A9D903ADC242405C77F35487DE4B4046274BADF7C142405C77F35487DE4B40
12677	1	37.609622000000002	37.61786	55.778072000000002	55.773505	Делегатская	0103000020E610000001000000050000000876FC1708CE424070253B3602E34B400876FC1708CE424077F700DD97E34B40D7C0560916CF424077F700DD97E34B40D7C0560916CF424070253B3602E34B400876FC1708CE424070253B3602E34B40
12853	1	37.584541000000002	37.625118000000001	55.872515999999997	55.857801000000002	Декабристов	0103000020E61000000100000005000000E8154F3DD2CA4240F1BC546CCCED4B40E8154F3DD2CA42404D9EB29AAEEF4B400A12DBDD03D042404D9EB29AAEEF4B400A12DBDD03D04240F1BC546CCCED4B40E8154F3DD2CA4240F1BC546CCCED4B40
12631	1	37.529223000000002	37.541727999999999	55.872394999999997	55.862721999999998	Дегунинская	0103000020E6100000010000000500000040A54A94BDC3424015C5ABAC6DEE4B4040A54A94BDC34240D218ADA3AAEF4B40EBA9D55757C54240D218ADA3AAEF4B40EBA9D55757C5424015C5ABAC6DEE4B4040A54A94BDC3424015C5ABAC6DEE4B40
12848	1	37.710126000000002	37.713287999999999	55.793419	55.784820000000003	Девятая Рота	0103000020E610000001000000050000000805A568E5DA4240959F54FB74E44B400805A568E5DA42403483F8C08EE54B408B506C054DDB42403483F8C08EE54B408B506C054DDB4240959F54FB74E44B400805A568E5DA4240959F54FB74E44B40
6187	1	37.633212	37.645178000000001	55.708804999999998	55.707740000000001	Даниловская набережная	0103000020E61000000100000005000000A6B73F170DD1424018096D3997DA4B40A6B73F170DD14240E21E4B1FBADA4B40A20C553195D24240E21E4B1FBADA4B40A20C553195D2424018096D3997DA4B40A6B73F170DD1424018096D3997DA4B40
6154	1	37.462029000000001	37.479052000000003	55.728971000000001	55.719864999999999	Давыдковская улица	0103000020E61000000100000005000000DC662AC423BB42407C444C8924DC4B40DC662AC423BB4240C05DF6EB4EDD4B40AD8A709351BD4240C05DF6EB4EDD4B40AD8A709351BD42407C444C8924DC4B40DC662AC423BB42407C444C8924DC4B40
12990	1	37.462029000000001	37.479052000000003	55.728971000000001	55.719864999999999	Давыдковская	0103000020E61000000100000005000000DC662AC423BB42407C444C8924DC4B40DC662AC423BB4240C05DF6EB4EDD4B40AD8A709351BD4240C05DF6EB4EDD4B40AD8A709351BD42407C444C8924DC4B40DC662AC423BB42407C444C8924DC4B40
12737	1	37.716459	37.728191000000002	55.693489999999997	55.669803000000002	Гурьянова	0103000020E6100000010000000500000062F6B2EDB4DB4240A0E1CD1ABCD54B4062F6B2EDB4DB4240300DC347C4D84B40EB1ED95C35DD4240300DC347C4D84B40EB1ED95C35DD4240A0E1CD1ABCD54B4062F6B2EDB4DB4240A0E1CD1ABCD54B40
4209	1	37.433641999999999	37.435564999999997	55.721032000000001	55.714962	Гродненская улица	0103000020E610000001000000050000000516C09481B74240FEF0F3DF83DB4B400516C09481B742404BAFCDC64ADC4B4020240B98C0B742404BAFCDC64ADC4B4020240B98C0B74240FEF0F3DF83DB4B400516C09481B74240FEF0F3DF83DB4B40
13167	1	37.414068	37.421129000000001	55.726014999999997	55.719763999999998	Гришина	0103000020E61000000100000005000000FA28232E00B54240486B0C3A21DC4B40FA28232E00B54240E5B33C0FEEDC4B40D732198EE7B54240E5B33C0FEEDC4B40D732198EE7B54240486B0C3A21DC4B40FA28232E00B54240486B0C3A21DC4B40
12760	1	37.562443000000002	37.591862999999996	55.569301000000003	55.560184	Грина	0103000020E610000001000000050000009C6ED921FEC7424009DFFB1BB4C74B409C6ED921FEC74240414AECDADEC84B40315BB22AC2CB4240414AECDADEC84B40315BB22AC2CB424009DFFB1BB4C74B409C6ED921FEC7424009DFFB1BB4C74B40
12592	1	37.575997999999998	37.583302000000003	55.693277000000002	55.686568999999999	Гримау	0103000020E61000000100000005000000DC476E4DBAC9424045B9347EE1D74B40DC476E4DBAC94240D508FD4CBDD84B4080D8D2A3A9CA4240D508FD4CBDD84B4080D8D2A3A9CA424045B9347EE1D74B40DC476E4DBAC9424045B9347EE1D74B40
12788	1	37.661715999999998	37.662407000000002	55.893293999999997	55.883029999999998	Грекова	0103000020E61000000100000005000000B69E211CB3D4424085B1852007F14B40B69E211CB3D4424044DB317557F24B401CD2A8C0C9D4424044DB317557F24B401CD2A8C0C9D4424085B1852007F14B40B69E211CB3D4424085B1852007F14B40
12390	1	37.733221	37.740031000000002	55.724696999999999	55.720018000000003	Грайвороново квартал 90А	0103000020E61000000100000005000000C6DE8B2FDADD42400344C18C29DC4B40C6DE8B2FDADD424031410DDFC2DC4B405A83F755B9DE424031410DDFC2DC4B405A83F755B9DE42400344C18C29DC4B40C6DE8B2FDADD42400344C18C29DC4B40
6460	1	37.579681000000001	37.580660999999999	55.847411999999998	55.840426999999998	Гостиничная улица	0103000020E61000000100000005000000698EACFC32CA424073D6A71C93EB4B40698EACFC32CA4240751E15FF77EC4B400588821953CA4240751E15FF77EC4B400588821953CA424073D6A71C93EB4B40698EACFC32CA424073D6A71C93EB4B40
13178	1	37.579681000000001	37.580660999999999	55.847411999999998	55.840426999999998	Гостиничная 	0103000020E61000000100000005000000698EACFC32CA424073D6A71C93EB4B40698EACFC32CA4240751E15FF77EC4B400588821953CA4240751E15FF77EC4B400588821953CA424073D6A71C93EB4B40698EACFC32CA424073D6A71C93EB4B40
12599	1	37.697288999999998	37.714267	55.775672	55.766714	Госпитальный Вал	0103000020E61000000100000005000000266E15C440D9424053B131AF23E24B40266E15C440D942402236583849E34B4057CEDE196DDB42402236583849E34B4057CEDE196DDB424053B131AF23E24B40266E15C440D9424053B131AF23E24B40
526	1	37.692456	37.698196000000003	55.774040999999997	55.769292	Госпитальная набережная	0103000020E61000000100000005000000A1F5F065A2D842408789062978E24B40A1F5F065A2D84240AE6186C613E34B4059198D7C5ED94240AE6186C613E34B4059198D7C5ED942408789062978E24B40A1F5F065A2D842408789062978E24B40
13037	1	37.524579000000003	37.537146	55.548878999999999	55.534179000000002	Горчакова	0103000020E610000001000000050000008E95986725C34240E19A3BFA5FC44B408E95986725C34240083BC5AA41C64B40AF963B33C1C44240083BC5AA41C64B40AF963B33C1C44240E19A3BFA5FC44B408E95986725C34240E19A3BFA5FC44B40
306	1	37.660476000000003	37.670124000000001	55.765757000000001	55.764906000000003	Гороховский переулок	0103000020E610000001000000050000007EE5417A8AD44240D1419770E8E14B407EE5417A8AD442406FD74B5304E24B40E2218C9FC6D542406FD74B5304E24B40E2218C9FC6D54240D1419770E8E14B407EE5417A8AD44240D1419770E8E14B40
12636	1	37.380974000000002	37.407744000000001	55.727449999999997	55.722389999999997	Горбунова	0103000020E610000001000000050000002B508BC1C3B042408D7A884677DC4B402B508BC1C3B04240D3BCE3141DDD4B40F39194F430B44240D3BCE3141DDD4B40F39194F430B442408D7A884677DC4B402B508BC1C3B042408D7A884677DC4B40
12915	1	37.582089000000003	37.593308999999998	55.815973999999997	55.814796000000001	Гончарова	0103000020E61000000100000005000000412E71E481CA4240B0743E3C4BE84B40412E71E481CA4240723106D671E84B4013B69F8CF1CB4240723106D671E84B4013B69F8CF1CB4240B0743E3C4BE84B40412E71E481CA4240B0743E3C4BE84B40
12973	1	37.510835	37.547485999999999	55.611277000000001	55.594183999999998	Голубинская 	0103000020E610000001000000050000007A53910A63C142403AE7A7380ECC4B407A53910A63C1424004E621533ECE4B404982700514C6424004E621533ECE4B404982700514C642403AE7A7380ECC4B407A53910A63C142403AE7A7380ECC4B40
12713	1	37.510835	37.547485999999999	55.611277000000001	55.594183999999998	Голубинская	0103000020E610000001000000050000007A53910A63C142403AE7A7380ECC4B407A53910A63C1424004E621533ECE4B404982700514C6424004E621533ECE4B404982700514C642403AE7A7380ECC4B407A53910A63C142403AE7A7380ECC4B40
12552	1	37.623609000000002	37.631281000000001	55.812843000000001	55.802076999999997	Годовикова	0103000020E61000000100000005000000E23E726BD2CF4240D8EF8975AAE64B40E23E726BD2CF42402AE44A3D0BE84B4008CBD8D0CDD042402AE44A3D0BE84B4008CBD8D0CDD04240D8EF8975AAE64B40E23E726BD2CF4240D8EF8975AAE64B40
13127	1	37.392257000000001	37.399155999999998	55.721604999999997	55.715642000000003	Говорова	0103000020E610000001000000050000004450357A35B2424070D234289ADB4B404450357A35B24240A6D0798D5DDC4B404700378B17B34240A6D0798D5DDC4B404700378B17B3424070D234289ADB4B404450357A35B2424070D234289ADB4B40
1060	1	37.637388999999999	37.640515000000001	55.787280000000003	55.786192	Глинистый переулок	0103000020E6100000010000000500000042EA76F695D142403C3080F0A1E44B4042EA76F695D14240BF654E97C5E44B4079CC4065FCD14240BF654E97C5E44B4079CC4065FCD142403C3080F0A1E44B4042EA76F695D142403C3080F0A1E44B40
7677	1	37.711607999999998	37.718488999999998	55.815356999999999	55.811073	Глебовская улица	0103000020E6100000010000000500000036C98FF815DB424095D5743DD1E74B4036C98FF815DB424047C8409E5DE84B4093C49272F7DB424047C8409E5DE84B4093C49272F7DB424095D5743DD1E74B4036C98FF815DB424095D5743DD1E74B40
13203	1	37.630364	37.633445999999999	55.791758999999999	55.773063999999998	Гиляровского	0103000020E61000000100000005000000B2497EC4AFD0424083DBDAC2F3E24B40B2497EC4AFD0424026A8E15B58E54B4019E42EC214D1424026A8E15B58E54B4019E42EC214D1424083DBDAC2F3E24B40B2497EC4AFD0424083DBDAC2F3E24B40
12926	1	37.435564999999997	37.441242000000003	55.715535000000003	55.714739000000002	Гжатская	0103000020E6100000010000000500000020240B98C0B742407F164B917CDB4B4020240B98C0B742405A12A0A696DB4B4092CF2B9E7AB842405A12A0A696DB4B4092CF2B9E7AB842407F164B917CDB4B4020240B98C0B742407F164B917CDB4B40
13009	1	37.405982999999999	37.439607000000002	55.858432999999998	55.850444000000003	Героев Панфиловцев	0103000020E61000000100000005000000B1DD3D40F7B342402B8A5759DBEC4B40B1DD3D40F7B342405167EE21E1ED4B40DD0BCC0A45B842405167EE21E1ED4B40DD0BCC0A45B842402B8A5759DBEC4B40B1DD3D40F7B342402B8A5759DBEC4B40
13062	1	37.459963000000002	37.487549999999999	55.733365999999997	55.729832999999999	Герасима Курина	0103000020E610000001000000050000005E2F4D11E0BA42405245F12A6BDD4B405E2F4D11E0BA4240C9FFE4EFDEDD4B401895D40968BE4240C9FFE4EFDEDD4B401895D40968BE42405245F12A6BDD4B405E2F4D11E0BA42405245F12A6BDD4B40
12467	1	37.482340000000001	37.494377	55.625908000000003	55.612344999999998	Генерала Тюленева	0103000020E61000000100000005000000BDC62E51BDBD42403F6F2A5261CE4B40BDC62E51BDBD42400327DBC01DD04B408272DBBE47BF42400327DBC01DD04B408272DBBE47BF42403F6F2A5261CE4B40BDC62E51BDBD42403F6F2A5261CE4B40
13179	1	37.460250000000002	37.465747999999998	55.789344999999997	55.778112	Генерала Глаголева	0103000020E61000000100000005000000F4FDD478E9BA424005508C2C99E34B40F4FDD478E9BA42406C21C84109E54B40B51666A19DBB42406C21C84109E54B40B51666A19DBB424005508C2C99E34B40F4FDD478E9BA424005508C2C99E34B40
13220	1	37.350431	37.357483000000002	55.840496999999999	55.826478000000002	Генерала Белобородова	0103000020E6100000010000000500000096404AECDAAC4240876EF607CAE94B4096404AECDAAC42406CB1DB6795EB4B4020F0C000C2AD42406CB1DB6795EB4B4020F0C000C2AD4240876EF607CAE94B4096404AECDAAC4240876EF607CAE94B40
12727	1	37.529187	37.541286999999997	55.646604000000004	55.642713000000001	Генерала Антонова	0103000020E61000000100000005000000F33B4D66BCC3424066DB696B44D24B40F33B4D66BCC342403DBB7CEBC3D24B40FE5F75E448C542403DBB7CEBC3D24B40FE5F75E448C5424066DB696B44D24B40F33B4D66BCC3424066DB696B44D24B40
13166	1	37.423715999999999	37.424137999999999	55.726354999999998	55.720255999999999	Гвардейская	0103000020E610000001000000050000005E656D533CB64240B75F3E5931DC4B405E656D533CB642409E245D33F9DC4B40D47E6B274AB642409E245D33F9DC4B40D47E6B274AB64240B75F3E5931DC4B405E656D533CB64240B75F3E5931DC4B40
12740	1	37.678873000000003	37.698906000000001	55.787902000000003	55.782592000000001	Гастелло	0103000020E6100000010000000500000097917A4FE5D642403D0E83F92BE44B4097917A4FE5D64240FC3905F9D9E44B40357D76C075D94240FC3905F9D9E44B40357D76C075D942403D0E83F92BE44B4097917A4FE5D642403D0E83F92BE44B40
12934	1	37.531756000000001	37.564211999999998	55.679118000000003	55.666111999999998	Гарибальди	0103000020E61000000100000005000000D4B9A29410C4424090BC732843D54B40D4B9A29410C44240FE0FB056EDD64B4060014C1938C84240FE0FB056EDD64B4060014C1938C8424090BC732843D54B40D4B9A29410C4424090BC732843D54B40
12715	1	37.456117999999996	37.466124999999998	55.803342000000001	55.797741000000002	Гамалеи	0103000020E61000000100000005000000F78E1A1362BA4240D4D688601CE64B40F78E1A1362BA42406AC020E9D3E64B408B6CE7FBA9BB42406AC020E9D3E64B408B6CE7FBA9BB4240D4D688601CE64B40F78E1A1362BA4240D4D688601CE64B40
12476	1	37.600397000000001	37.613826000000003	55.591985999999999	55.588963999999997	Газопровод	0103000020E61000000100000005000000EACE13CFD9CC4240BB421F2C63CB4B40EACE13CFD9CC42404DD87E32C6CB4B409EB7B1D991CE42404DD87E32C6CB4B409EB7B1D991CE4240BB421F2C63CB4B40EACE13CFD9CC4240BB421F2C63CB4B40
12633	1	37.451231	37.459792	55.817172999999997	55.811432000000003	Габричевского	0103000020E610000001000000050000007FF8F9EFC1B94240C576F700DDE74B407FF8F9EFC1B942404C16F71F99E84B40317BD976DABA42404C16F71F99E84B40317BD976DABA4240C576F700DDE74B407FF8F9EFC1B94240C576F700DDE74B40
4574	1	37.579475000000002	37.582780999999997	55.807080999999997	55.792259999999999	Вятская улица	0103000020E61000000100000005000000C0EC9E3C2CCA4240E8F692C668E54B40C0EC9E3C2CCA42408A1C226E4EE74B4076DD5B9198CA42408A1C226E4EE74B4076DD5B9198CA4240E8F692C668E54B40C0EC9E3C2CCA4240E8F692C668E54B40
13226	1	37.402084000000002	37.405687	55.716011999999999	55.708562000000001	Вяземская	0103000020E61000000100000005000000581F0F7D77B342401C98DC28B2DA4B40581F0F7D77B3424093C5FD47A6DB4B40C8B4368DEDB3424093C5FD47A6DB4B40C8B4368DEDB342401C98DC28B2DA4B40581F0F7D77B342401C98DC28B2DA4B40
13043	1	37.648977000000002	37.663755000000002	55.681773	55.678544000000002	Высокая	0103000020E61000000100000005000000986DA7AD11D34240D272A087DAD64B40986DA7AD11D34240DD25715644D74B403BC780ECF5D44240DD25715644D74B403BC780ECF5D44240D272A087DAD64B40986DA7AD11D34240D272A087DAD64B40
12864	1	37.555174999999998	37.562955000000002	55.817678999999998	55.805553000000003	Вучетича	0103000020E61000000100000005000000454772F90FC74240EC18575C1CE74B40454772F90FC7424020D099B4A9E84B40520FD1E80EC8424020D099B4A9E84B40520FD1E80EC84240EC18575C1CE74B40454772F90FC74240EC18575C1CE74B40
12854	1	37.495832999999998	37.503891000000003	55.806975000000001	55.803655999999997	Врубеля	0103000020E6100000010000000500000087A3AB7477BF4240F99D2633DEE64B4087A3AB7477BF424045D8F0F44AE74B40D7DF12807FC0424045D8F0F44AE74B40D7DF12807FC04240F99D2633DEE64B4087A3AB7477BF4240F99D2633DEE64B40
6494	1	37.450916999999997	37.464058999999999	55.815544000000003	55.812100000000001	Врачебный проезд	0103000020E61000000100000005000000EF1AF4A5B7B94240728A8EE4F2E74B40EF1AF4A5B7B942407A39ECBE63E84B400D350A4966BB42407A39ECBE63E84B400D350A4966BB4240728A8EE4F2E74B40EF1AF4A5B7B94240728A8EE4F2E74B40
5931	1	37.639463999999997	37.659613999999998	55.587743000000003	55.574477000000002	Востряковский проезд	0103000020E61000000100000005000000137CD3F4D9D14240F0A65B7688C94B40137CD3F4D9D14240FAB9A1293BCB4B40EBFD463B6ED44240FAB9A1293BCB4B40EBFD463B6ED44240F0A65B7688C94B40137CD3F4D9D14240F0A65B7688C94B40
12783	1	37.657637000000001	37.663888999999998	55.717680000000001	55.710529999999999	Восточная	0103000020E61000000100000005000000DDD1FF722DD44240D769A4A5F2DA4B40DDD1FF722DD44240247F30F0DCDB4B404A969350FAD44240247F30F0DCDB4B404A969350FAD44240D769A4A5F2DA4B40DDD1FF722DD44240D769A4A5F2DA4B40
12424	1	37.719009999999997	37.761420000000001	55.611826000000001	55.608154999999996	Воронежская	0103000020E610000001000000050000009CBF098508DC42400EF3E505D8CD4B409CBF098508DC4240D76B7A5050CE4B409A42E73576E14240D76B7A5050CE4B409A42E73576E142400EF3E505D8CD4B409CBF098508DC42400EF3E505D8CD4B40
12952	1	37.675020000000004	37.686948999999998	55.761664000000003	55.748305999999999	Волочаевская 	0103000020E61000000100000005000000AE122C0E67D6424046B3B27DC8DF4B40AE122C0E67D642403145B9347EE14B408C82E0F1EDD742403145B9347EE14B408C82E0F1EDD7424046B3B27DC8DF4B40AE122C0E67D6424046B3B27DC8DF4B40
6268	1	37.349758000000001	37.352074999999999	55.837955000000001	55.83428	Волоцкой переулок	0103000020E61000000100000005000000D7C1C1DEC4AC42407BDAE1AFC9EA4B40D7C1C1DEC4AC42408542041C42EB4B409E5E29CB10AD42408542041C42EB4B409E5E29CB10AD42407BDAE1AFC9EA4B40D7C1C1DEC4AC42407BDAE1AFC9EA4B40
12920	1	37.73977	37.756703000000002	55.720018000000003	55.694251000000001	Волжский бульвар	0103000020E61000000100000005000000ED478AC8B0DE42408F1B7E37DDD84B40ED478AC8B0DE42400344C18C29DC4B407EE4D6A4DBE042400344C18C29DC4B407EE4D6A4DBE042408F1B7E37DDD84B40ED478AC8B0DE42408F1B7E37DDD84B40
1529	1	37.672307000000004	37.836537	55.731347999999997	55.684635	Волгоградский проспект	0103000020E610000001000000050000009AEFE0270ED642403659A31EA2D74B409AEFE0270ED642405CFFAECF9CDD4B406D72F8A413EB42405CFFAECF9CDD4B406D72F8A413EB42403659A31EA2D74B409AEFE0270ED642403659A31EA2D74B40
12999	1	37.446092999999998	37.448914000000002	55.835118999999999	55.827033999999998	Вишневая	0103000020E61000000100000005000000BDFC4E9319B942400C570740DCE94B40BDFC4E9319B9424055A2EC2DE5EA4B40B85B920376B9424055A2EC2DE5EA4B40B85B920376B942400C570740DCE94B40BDFC4E9319B942400C570740DCE94B40
13152	1	37.580229000000003	37.599677999999997	55.690527000000003	55.683838000000002	Винокурова	0103000020E610000001000000050000006C98A1F144CA42408BE1EA0088D74B406C98A1F144CA4240A400513063D84B40BA10AB3FC2CC4240A400513063D84B40BA10AB3FC2CC42408BE1EA0088D74B406C98A1F144CA42408BE1EA0088D74B40
12796	1	37.518219000000002	37.525081999999998	55.607855000000001	55.598140999999998	Вильнюсская	0103000020E610000001000000050000003A950C0055C24240C8B260E28FCC4B403A950C0055C24240E4DA5031CECD4B40F0DB10E335C34240E4DA5031CECD4B40F0DB10E335C34240C8B260E28FCC4B403A950C0055C24240C8B260E28FCC4B40
12564	1	37.406253	37.433759000000002	55.865273000000002	55.855795000000001	Вилиса Лациса	0103000020E6100000010000000500000071732A1900B44240488AC8B08AED4B4071732A1900B44240508E0244C1EE4B403FAC376A85B74240508E0244C1EE4B403FAC376A85B74240488AC8B08AED4B4071732A1900B44240488AC8B08AED4B40
12729	1	37.815426000000002	37.829861999999999	55.742736999999998	55.716022000000002	Вешняковская	0103000020E61000000100000005000000702711E15FE84240B79BE09BA6DB4B40702711E15FE84240BB438A0112DF4B40B91803EB38EA4240BB438A0112DF4B40B91803EB38EA4240B79BE09BA6DB4B40702711E15FE84240B79BE09BA6DB4B40
12841	1	37.659756999999999	37.668219000000001	55.625917999999999	55.620153999999999	Веселая	0103000020E610000001000000050000004E27D9EA72D44240E63DCE3461CF4B404E27D9EA72D4424026FDBD141ED04B406DC83F3388D5424026FDBD141ED04B406DC83F3388D54240E63DCE3461CF4B404E27D9EA72D44240E63DCE3461CF4B40
500	1	37.775010999999999	37.812246000000002	55.799501999999997	55.799101999999998	Верхняя Первомайская улица	0103000020E610000001000000050000002785798F33E3424087156EF948E64B402785798F33E34240158BDF1456E64B4046274BADF7E74240158BDF1456E64B4046274BADF7E7424087156EF948E64B402785798F33E3424087156EF948E64B40
12852	1	37.775010999999999	37.812246000000002	55.799501999999997	55.799101999999998	Верхняя Первомайская	0103000020E610000001000000050000002785798F33E3424087156EF948E64B402785798F33E34240158BDF1456E64B4046274BADF7E74240158BDF1456E64B4046274BADF7E7424087156EF948E64B402785798F33E3424087156EF948E64B40
12939	1	37.557206000000001	37.569557000000003	55.799224000000002	55.791395000000001	Верхняя Масловка	0103000020E610000001000000050000004791B58652C74240E59B6D6E4CE54B404791B58652C74240D316D7F84CE64B409C1A683EE7C84240D316D7F84CE64B409C1A683EE7C84240E59B6D6E4CE54B404791B58652C74240E59B6D6E4CE54B40
820	1	37.658904	37.666125999999998	55.786273000000001	55.779463999999997	Верхняя Красносельская улица	0103000020E610000001000000050000000F9A5DF756D442406534F279C5E34B400F9A5DF756D44240295DFA97A4E44B40F581E49D43D54240295DFA97A4E44B40F581E49D43D542406534F279C5E34B400F9A5DF756D442406534F279C5E34B40
12646	1	37.658904	37.666125999999998	55.786273000000001	55.779463999999997	Верхняя Красносельская	0103000020E610000001000000050000000F9A5DF756D442406534F279C5E34B400F9A5DF756D44240295DFA97A4E44B40F581E49D43D54240295DFA97A4E44B40F581E49D43D542406534F279C5E34B400F9A5DF756D442406534F279C5E34B40
3634	1	37.679332000000002	37.680157999999999	55.751537999999996	55.749116000000001	Верхний Золоторожский переулок	0103000020E610000001000000050000002A90D959F4D6424086747808E3DF4B402A90D959F4D64240C2D9AD6532E04B406F0ED76A0FD74240C2D9AD6532E04B406F0ED76A0FD7424086747808E3DF4B402A90D959F4D6424086747808E3DF4B40
12645	1	37.741145000000003	37.838952999999997	55.669001000000002	55.656930000000003	Верхние Поля	0103000020E61000000100000005000000064CE0D6DDDE424072E1404816D44B40064CE0D6DDDE4240E3FE23D3A1D54B40C7F0D8CF62EB4240E3FE23D3A1D54B40C7F0D8CF62EB424072E1404816D44B40064CE0D6DDDE424072E1404816D44B40
4681	1	37.473204000000003	37.491214999999997	55.712694999999997	55.707830999999999	Веерная улица	0103000020E610000001000000050000000F2BDCF291BC4240280CCA349ADA4B400F2BDCF291BC4240E882FA9639DB4B40FE261422E0BE4240E882FA9639DB4B40FE261422E0BE4240280CCA349ADA4B400F2BDCF291BC4240280CCA349ADA4B40
12699	1	37.473204000000003	37.491214999999997	55.712694999999997	55.707830999999999	Веерная	0103000020E610000001000000050000000F2BDCF291BC4240280CCA349ADA4B400F2BDCF291BC4240E882FA9639DB4B40FE261422E0BE4240E882FA9639DB4B40FE261422E0BE4240280CCA349ADA4B400F2BDCF291BC4240280CCA349ADA4B40
12909	1	37.528621000000001	37.551070000000003	55.651394000000003	55.632443000000002	Введенского	0103000020E610000001000000050000004A7D59DAA9C34240C5CA68E4F3D04B404A7D59DAA9C34240C367EBE060D34B4043E7357689C64240C367EBE060D34B4043E7357689C64240C5CA68E4F3D04B404A7D59DAA9C34240C5CA68E4F3D04B40
4963	1	37.746794999999999	37.750971999999997	55.714343	55.713785000000001	Васильцовский переулок	0103000020E610000001000000050000007DE882FA96DF42400CB08F4E5DDB4B407DE882FA96DF4240329067976FDB4B40191BBAD91FE04240329067976FDB4B40191BBAD91FE042400CB08F4E5DDB4B407DE882FA96DF42400CB08F4E5DDB4B40
12734	1	37.750577	37.754421999999998	55.716782000000002	55.711416999999997	Васильцовский Стан	0103000020E610000001000000050000009D103AE812E04240C26856B60FDB4B409D103AE812E04240452E3883BFDB4B4003B16CE690E04240452E3883BFDB4B4003B16CE690E04240C26856B60FDB4B409D103AE812E04240C26856B60FDB4B40
13212	1	37.584702999999998	37.590578000000001	55.773083999999997	55.769807999999998	Васильевская	0103000020E61000000100000005000000C16F438CD7CA42407E198C1189E24B40C16F438CD7CA4240CA87A06AF4E24B4059DE550F98CB4240CA87A06AF4E24B4059DE550F98CB42407E198C1189E24B40C16F438CD7CA42407E198C1189E24B40
13199	1	37.398958	37.408929999999998	55.840688999999998	55.832084999999999	Василия Петушкова	0103000020E61000000100000005000000213D450E11B34240FF3EE3C281EA4B40213D450E11B34240B08D78B29BEB4B40382D78D157B44240B08D78B29BEB4B40382D78D157B44240FF3EE3C281EA4B40213D450E11B34240FF3EE3C281EA4B40
12919	1	37.331881000000003	37.358040000000003	55.792928000000003	55.767705999999997	Василия Ботылева	0103000020E61000000100000005000000F7949C137BAA4240B378B13044E24B40F7949C137BAA4240960A2AAA7EE54B4076543541D4AD4240960A2AAA7EE54B4076543541D4AD4240B378B13044E24B40F7949C137BAA4240B378B13044E24B40
6344	1	37.570653	37.627381999999997	55.703890000000001	55.498393	Варшавское шоссе	0103000020E61000000100000005000000A12E52280BC9424015C78157CBBF4B40A12E52280BC94240A0FD481119DA4B40AE0CAA0D4ED04240A0FD481119DA4B40AE0CAA0D4ED0424015C78157CBBF4B40A12E52280BC9424015C78157CBBF4B40
4385	1	37.463709000000001	37.468856000000002	55.873621999999997	55.863439	Валдайский проезд	0103000020E6100000010000000500000031EE06D15ABB4240A48B4D2B85EE4B4031EE06D15ABB424076887FD8D2EF4B404644317903BC424076887FD8D2EF4B404644317903BC4240A48B4D2B85EE4B4031EE06D15ABB4240A48B4D2B85EE4B40
2028	1	37.592312	37.599741000000002	55.790771999999997	55.788753	Вадковский переулок	0103000020E61000000100000005000000A1832EE1D0CB42409ACFB9DBF5E44B40A1832EE1D0CB4240D74B530438E54B4001892650C4CC4240D74B530438E54B4001892650C4CC42409ACFB9DBF5E44B40A1832EE1D0CB42409ACFB9DBF5E44B40
3914	1	37.516117000000001	37.543300000000002	55.900955000000003	55.898245000000003	Вагоноремонтная улица	0103000020E610000001000000050000006FF4311F10C24240D46531B1F9F24B406FF4311F10C242407715527E52F34B405AF5B9DA8AC542407715527E52F34B405AF5B9DA8AC54240D46531B1F9F24B406FF4311F10C24240D46531B1F9F24B40
12509	1	37.539796000000003	37.593514999999996	55.709870000000002	55.675564999999999	Вавилова	0103000020E610000001000000050000007D410B0918C542403FA9F6E978D64B407D410B0918C54240AD342905DDDA4B40BC57AD4CF8CB4240AD342905DDDA4B40BC57AD4CF8CB42403FA9F6E978D64B407D410B0918C542403FA9F6E978D64B40
13146	1	37.522278999999997	37.551743999999999	55.654879000000001	55.641468000000003	Бутлерова	0103000020E610000001000000050000009C31CC09DAC242401CB7989F1BD24B409C31CC09DAC2424029EB3713D3D34B40D2E1218C9FC6424029EB3713D3D34B40D2E1218C9FC642401CB7989F1BD24B409C31CC09DAC242401CB7989F1BD24B40
12555	1	37.492581000000001	37.496640999999997	55.886347000000001	55.880701999999999	Бусиновская Горка	0103000020E61000000100000005000000C4D0EAE40CBF4240CAC2D7D7BAF04B40C4D0EAE40CBF424030F488D173F14B40266DAAEE91BF424030F488D173F14B40266DAAEE91BF4240CAC2D7D7BAF04B40C4D0EAE40CBF4240CAC2D7D7BAF04B40
5912	1	37.621910999999997	37.659666999999999	55.581789999999998	55.579341999999997	Булатниковская улица	0103000020E61000000100000005000000E60297C79ACF42408099EFE027CA4B40E60297C79ACF4240E6913F1878CA4B400EA0DFF76FD44240E6913F1878CA4B400EA0DFF76FD442408099EFE027CA4B40E60297C79ACF42408099EFE027CA4B40
12859	1	37.621910999999997	37.659666999999999	55.581789999999998	55.579341999999997	Булатниковская	0103000020E61000000100000005000000E60297C79ACF42408099EFE027CA4B40E60297C79ACF4240E6913F1878CA4B400EA0DFF76FD44240E6913F1878CA4B400EA0DFF76FD442408099EFE027CA4B40E60297C79ACF42408099EFE027CA4B40
12367	1	37.720447	37.741422999999998	55.779817999999999	55.756194000000001	Буденного просп	0103000020E610000001000000050000002BC0779B37DC424039B709F7CAE04B402BC0779B37DC4240836A8313D1E34B4048C0E8F2E6DE4240836A8313D1E34B4048C0E8F2E6DE424039B709F7CAE04B402BC0779B37DC424039B709F7CAE04B40
12806	1	37.557152000000002	37.564185000000002	55.744672000000001	55.744191000000001	Брянская	0103000020E610000001000000050000005473B9C150C74240207D93A641DF4B405473B9C150C742409B1F7F6951DF4B4067F2CD3637C842409B1F7F6951DF4B4067F2CD3637C84240207D93A641DF4B405473B9C150C74240207D93A641DF4B40
12961	1	37.572279000000002	37.603459999999998	55.502543000000003	55.499845999999998	Брусилова	0103000020E610000001000000050000000398327040C94240A98427F4FABF4B400398327040C94240B8EA3A5453C04B40DA38622D3ECD4240B8EA3A5453C04B40DA38622D3ECD4240A98427F4FABF4B400398327040C94240A98427F4FABF4B40
1688	1	37.671346	37.676186999999999	55.736817000000002	55.734825999999998	Брошевский переулок	0103000020E6100000010000000500000074266DAAEED54240102043C70EDE4B4074266DAAEED542408411FB0450DE4B407C7DAD4B8DD642408411FB0450DE4B407C7DAD4B8DD64240102043C70EDE4B4074266DAAEED54240102043C70EDE4B40
2506	1	37.614382999999997	37.618766999999998	55.737552000000001	55.736721000000003	Бродников переулок	0103000020E61000000100000005000000F31B261AA4CE424062A3ACDF4CDE4B40F31B261AA4CE4240B98C9B1A68DE4B40096CCEC133CF4240B98C9B1A68DE4B40096CCEC133CF424062A3ACDF4CDE4B40F31B261AA4CE424062A3ACDF4CDE4B40
12977	1	37.751914999999997	37.768470999999998	55.666421	55.651415	Братиславская	0103000020E61000000100000005000000982F2FC03EE04240DA8F149161D34B40982F2FC03EE042400E2F88484DD54B405376FA415DE242400E2F88484DD54B405376FA415DE24240DA8F149161D34B40982F2FC03EE04240DA8F149161D34B40
6019	1	37.751798999999998	37.772540999999997	55.637509999999999	55.630735999999999	Братеевская улица	0103000020E610000001000000050000002F151BF33AE0424076340EF5BBD04B402F151BF33AE04240BD6F7CED99D14B40D9E89C9FE2E24240BD6F7CED99D14B40D9E89C9FE2E2424076340EF5BBD04B402F151BF33AE0424076340EF5BBD04B40
13130	1	37.751798999999998	37.772540999999997	55.637509999999999	55.630735999999999	Братеевская	0103000020E610000001000000050000002F151BF33AE0424076340EF5BBD04B402F151BF33AE04240BD6F7CED99D14B40D9E89C9FE2E24240BD6F7CED99D14B40D9E89C9FE2E2424076340EF5BBD04B402F151BF33AE0424076340EF5BBD04B40
6407	1	37.58464	37.602857999999998	55.847230000000003	55.821502000000002	Ботаническая улица	0103000020E610000001000000050000007BF7C77BD5CA42409FCC3FFA26E94B407BF7C77BD5CA424055185B0872EC4B40E41071732ACD424055185B0872EC4B40E41071732ACD42409FCC3FFA26E94B407BF7C77BD5CA42409FCC3FFA26E94B40
13003	1	37.58464	37.602857999999998	55.847230000000003	55.821502000000002	Ботаническая	0103000020E610000001000000050000007BF7C77BD5CA42409FCC3FFA26E94B407BF7C77BD5CA424055185B0872EC4B40E41071732ACD424055185B0872EC4B40E41071732ACD42409FCC3FFA26E94B407BF7C77BD5CA42409FCC3FFA26E94B40
12769	1	37.339193000000002	37.454205000000002	55.662368999999998	55.633322999999997	Боровское шоссе	0103000020E610000001000000050000001D041DAD6AAB4240FD6662BA10D14B401D041DAD6AAB42402E71E481C8D44B400057B26323BA42402E71E481C8D44B400057B26323BA4240FD6662BA10D14B401D041DAD6AAB4240FD6662BA10D14B40
12436	1	37.710619999999999	37.730383000000003	55.626269000000001	55.612985000000002	Борисовский проезд	0103000020E6100000010000000500000017F19D98F5DA424023F8DF4A76CE4B4017F19D98F5DA4240D3BF249529D04B40F646AD307DDD4240D3BF249529D04B40F646AD307DDD424023F8DF4A76CE4B4017F19D98F5DA424023F8DF4A76CE4B40
13024	1	37.688538999999999	37.775342999999999	55.644105000000003	55.635202999999997	Борисовские Пруды	0103000020E61000000100000005000000A182C30B22D8424019A9F7544ED14B40A182C30B22D8424055185B0872D24B405D177E703EE3424055185B0872D24B405D177E703EE3424019A9F7544ED14B40A182C30B22D8424019A9F7544ED14B40
1556	1	37.661662	37.671416999999998	55.743648999999998	55.740780999999998	Большой Факельный переулок	0103000020E61000000100000005000000C3802557B1D44240C43F6CE9D1DE4B40C3802557B1D44240FF59F3E32FDF4B403D7D04FEF0D54240FF59F3E32FDF4B403D7D04FEF0D54240C43F6CE9D1DE4B40C3802557B1D44240C43F6CE9D1DE4B40
168	1	37.642778999999997	37.648007	55.75517	55.755139999999997	Большой Трехсвятительский переулок	0103000020E610000001000000050000001DC70F9546D2424062F3716DA8E04B401DC70F9546D24240CD751A69A9E04B401F4AB4E4F1D24240CD751A69A9E04B401F4AB4E4F1D2424062F3716DA8E04B401DC70F9546D2424062F3716DA8E04B40
1317	1	37.563287000000003	37.565928	55.762464999999999	55.758828000000001	Большой Трехгорный переулок	0103000020E6100000010000000500000088A1D5C919C8424001A5A14621E14B4088A1D5C919C842401DACFF7398E14B4002F2255470C842401DACFF7398E14B4002F2255470C8424001A5A14621E14B4088A1D5C919C8424001A5A14621E14B40
2091	1	37.588422000000001	37.590659000000002	55.744028999999998	55.743563000000002	Большой Могильцевский переулок	0103000020E610000001000000050000009B1F7F6951CB424001C287122DDF4B409B1F7F6951CB424046239F573CDF4B40460BD0B69ACB424046239F573CDF4B40460BD0B69ACB424001C287122DDF4B409B1F7F6951CB424001C287122DDF4B40
1196	1	37.579878999999998	37.583193999999999	55.774121999999998	55.771621000000003	Большой Кондратьевский переулок	0103000020E610000001000000050000008F519E7939CA424013F4177AC4E24B408F519E7939CA42409B8E006E16E34B40999CDA19A6CA42409B8E006E16E34B40999CDA19A6CA424013F4177AC4E24B408F519E7939CA424013F4177AC4E24B40
1119	1	37.593586999999999	37.599102999999999	55.765903999999999	55.761522999999997	Большой Козихинский переулок	0103000020E61000000100000005000000562AA8A8FACB42406E13EE9579E14B40562AA8A8FACB424013F06B2409E24B40BEF73768AFCC424013F06B2409E24B40BEF73768AFCC42406E13EE9579E14B40562AA8A8FACB42406E13EE9579E14B40
1935	1	37.61591	37.616377999999997	55.773342999999997	55.769387999999999	Большой Каретный переулок	0103000020E61000000100000005000000C2A38D23D6CE4240A9F7544E7BE24B40C2A38D23D6CE424096CB46E7FCE24B40A8FC6B79E5CE424096CB46E7FCE24B40A8FC6B79E5CE4240A9F7544E7BE24B40C2A38D23D6CE4240A9F7544E7BE24B40
222	1	37.651780000000002	37.657404	55.760362999999998	55.759653	Большой Казенный переулок	0103000020E61000000100000005000000EC17EC866DD3424076A73B4F3CE14B40EC17EC866DD34240520B259353E14B403A2174D025D44240520B259353E14B403A2174D025D4424076A73B4F3CE14B40EC17EC866DD3424076A73B4F3CE14B40
81	1	37.597082	37.597495000000002	55.751361000000003	55.744768999999998	Большой Афанасьевский переулок	0103000020E61000000100000005000000E083D72E6DCC42408D09319754DF4B40E083D72E6DCC4240B43EE5982CE04B40034356B77ACC4240B43EE5982CE04B40034356B77ACC42408D09319754DF4B40E083D72E6DCC42408D09319754DF4B40
13204	1	37.588268999999997	37.595618000000002	55.653714999999998	55.642890000000001	Большая Юшуньская	0103000020E6100000010000000500000014200A664CCB4240757632384AD24B4014200A664CCB4240CBF3E0EEACD34B405874EB353DCC4240CBF3E0EEACD34B405874EB353DCC4240757632384AD24B4014200A664CCB4240757632384AD24B40
12637	1	37.719386999999998	37.747351999999999	55.801606999999997	55.796779999999998	Большая Черкизовская	0103000020E6100000010000000500000072158BDF14DC4240AE0D15E3FCE54B4072158BDF14DC4240519FE40E9BE64B40D34CF73AA9DF4240519FE40E9BE64B40D34CF73AA9DF4240AE0D15E3FCE54B4072158BDF14DC4240AE0D15E3FCE54B40
12992	1	37.579492999999999	37.602165999999997	55.691805000000002	55.676853999999999	Большая Черемушкинская	0103000020E6100000010000000500000066A19DD32CCA42405915E126A3D64B4066A19DD32CCA4240CA1AF5108DD84B40AE6186C613CD4240CA1AF5108DD84B40AE6186C613CD42405915E126A3D64B4066A19DD32CCA42405915E126A3D64B40
12728	1	37.460439000000001	37.519252000000002	55.754258999999998	55.737492000000003	Большая Филевская	0103000020E61000000100000005000000C76647AAEFBA4240E4874A2366DE4B40C76647AAEFBA424059DB148F8BE04B40F9307BD976C2424059DB148F8BE04B40F9307BD976C24240E4874A2366DE4B40C76647AAEFBA4240E4874A2366DE4B40
13201	1	37.630974999999999	37.636274999999998	55.743512000000003	55.73592	Большая Татарская	0103000020E61000000100000005000000FBCBEEC9C3D04240753C66A032DE4B40FBCBEEC9C3D042407F17B6662BDF4B4096218E7571D142407F17B6662BDF4B4096218E7571D14240753C66A032DE4B40FBCBEEC9C3D04240753C66A032DE4B40
12537	1	37.686114000000003	37.697054999999999	55.781655999999998	55.771611	Большая Почтовая	0103000020E61000000100000005000000F4A96395D2D74240EF1D3526C4E24B40F4A96395D2D74240705CC64D0DE44B40B341261939D94240705CC64D0DE44B40B341261939D94240EF1D3526C4E24B40F4A96395D2D74240EF1D3526C4E24B40
1013	1	37.639797000000002	37.644198000000003	55.792468	55.779808000000003	Большая Переяславская улица	0103000020E610000001000000050000001A8A3BDEE4D142406094A0BFD0E34B401A8A3BDEE4D14240329067976FE54B4006137F1475D24240329067976FE54B4006137F1475D242406094A0BFD0E34B401A8A3BDEE4D142406094A0BFD0E34B40
13096	1	37.639797000000002	37.644198000000003	55.792468	55.779808000000003	Большая Переяславская	0103000020E610000001000000050000001A8A3BDEE4D142406094A0BFD0E34B401A8A3BDEE4D14240329067976FE54B4006137F1475D24240329067976FE54B4006137F1475D242406094A0BFD0E34B401A8A3BDEE4D142406094A0BFD0E34B40
4878	1	37.443154999999997	37.469673999999998	55.691825999999999	55.673631	Большая Очаковская улица	0103000020E610000001000000050000008907944DB9B842403049658A39D64B408907944DB9B84240E1421EC18DD84B4008E412471EBC4240E1421EC18DD84B4008E412471EBC42403049658A39D64B408907944DB9B842403049658A39D64B40
12955	1	37.443154999999997	37.469673999999998	55.691825999999999	55.673631	Большая Очаковская	0103000020E610000001000000050000008907944DB9B842403049658A39D64B408907944DB9B84240E1421EC18DD84B4008E412471EBC4240E1421EC18DD84B4008E412471EBC42403049658A39D64B408907944DB9B842403049658A39D64B40
12579	1	37.684111000000001	37.690013	55.796911000000001	55.79186	Большая Остроумовская	0103000020E61000000100000005000000BCEA01F390D742405A8121AB5BE54B40BCEA01F390D742404D69FD2D01E64B404D68925852D842404D69FD2D01E64B404D68925852D842405A8121AB5BE54B40BCEA01F390D742405A8121AB5BE54B40
12541	1	37.623815999999998	37.625000999999997	55.745772000000002	55.729877999999999	Большая Ордынка	0103000020E610000001000000050000005B5CE333D9CF4240F2086EA46CDD4B405B5CE333D9CF4240E222F77475DF4B40D07B630800D04240E222F77475DF4B40D07B630800D04240F2086EA46CDD4B405B5CE333D9CF4240F2086EA46CDD4B40
13209	1	37.584110000000003	37.586005999999998	55.805866999999999	55.796298999999998	Большая Новодмитровская	0103000020E610000001000000050000001FA2D11DC4CA4240336B2920EDE54B401FA2D11DC4CA42407BF65CA626E74B4040A19E3E02CB42407BF65CA626E74B4040A19E3E02CB4240336B2920EDE54B401FA2D11DC4CA4240336B2920EDE54B40
6575	1	37.454689999999999	37.462352000000003	55.835234999999997	55.826391999999998	Большая Набережная улица	0103000020E61000000100000005000000BCE82B4833BA424088D68A36C7E94B40BCE82B4833BA4240BEBC00FBE8EA4B40BF9EAF592EBB4240BEBC00FBE8EA4B40BF9EAF592EBB424088D68A36C7E94B40BCE82B4833BA424088D68A36C7E94B40
12593	1	37.586588999999996	37.596983000000002	55.753605	55.753129000000001	Большая Молчановка	0103000020E61000000100000005000000BF982D5915CB4240A855F48766E04B40BF982D5915CB4240118DEE2076E04B404DA25EF069CC4240118DEE2076E04B404DA25EF069CC4240A855F48766E04B40BF982D5915CB4240A855F48766E04B40
6417	1	37.590865000000001	37.593659000000002	55.836179999999999	55.827899000000002	Большая Марфинская улица	0103000020E61000000100000005000000EFACDD76A1CB424010B22C98F8E94B40EFACDD76A1CB4240DEC83CF207EB4B40F0FCA204FDCB4240DEC83CF207EB4B40F0FCA204FDCB424010B22C98F8E94B40EFACDD76A1CB424010B22C98F8E94B40
12628	1	37.590865000000001	37.593659000000002	55.836179999999999	55.827899000000002	Большая Марфинская	0103000020E61000000100000005000000EFACDD76A1CB424010B22C98F8E94B40EFACDD76A1CB4240DEC83CF207EB4B40F0FCA204FDCB4240DEC83CF207EB4B40F0FCA204FDCB424010B22C98F8E94B40EFACDD76A1CB424010B22C98F8E94B40
12910	1	37.551861000000002	37.572386999999999	55.746487000000002	55.745189000000003	Большая Дорогомиловская	0103000020E610000001000000050000000C789961A3C64240632B685A62DF4B400C789961A3C64240D0F1D1E28CDF4B40E9D32AFA43C94240D0F1D1E28CDF4B40E9D32AFA43C94240632B685A62DF4B400C789961A3C64240632B685A62DF4B40
13211	1	37.577129999999997	37.588223999999997	55.774538	55.760697	Большая Грузинская	0103000020E610000001000000050000002EC55565DFC942402995F0845EE14B402EC55565DFC942402FC1A90F24E34B40745C8DEC4ACB42402FC1A90F24E34B40745C8DEC4ACB42402995F0845EE14B402EC55565DFC942402995F0845EE14B40
12730	1	37.287441000000001	37.306117	55.616253999999998	55.605367999999999	Большая Внуковская	0103000020E61000000100000005000000C843DFDDCAA44240C005D9B27CCD4B40C843DFDDCAA44240BC033C69E1CE4B40F4DF83D72EA74240BC033C69E1CE4B40F4DF83D72EA74240C005D9B27CCD4B40C843DFDDCAA44240C005D9B27CCD4B40
12779	1	37.571803000000003	37.584972	55.545741999999997	55.541829999999997	Большая Бутовская 	0103000020E610000001000000050000009A6038D730C94240EFFE78AF5AC54B409A6038D730C94240DD06B5DFDAC54B40B189CC5CE0CA4240DD06B5DFDAC54B40B189CC5CE0CA4240EFFE78AF5AC54B409A6038D730C94240EFFE78AF5AC54B40
12874	1	37.571803000000003	37.584972	55.545741999999997	55.541829999999997	Большая Бутовская	0103000020E610000001000000050000009A6038D730C94240EFFE78AF5AC54B409A6038D730C94240DD06B5DFDAC54B40B189CC5CE0CA4240DD06B5DFDAC54B40B189CC5CE0CA4240EFFE78AF5AC54B409A6038D730C94240EFFE78AF5AC54B40
4228	1	37.519620000000003	37.561221000000003	55.845162999999999	55.815812000000001	Большая Академическая улица	0103000020E610000001000000050000007C2C7DE882C2424099D711876CE84B407C2C7DE882C2424006651A4D2EEC4B400A6AF816D6C7424006651A4D2EEC4B400A6AF816D6C7424099D711876CE84B407C2C7DE882C2424099D711876CE84B40
12839	1	37.519620000000003	37.561221000000003	55.845162999999999	55.815812000000001	Большая Академическая	0103000020E610000001000000050000007C2C7DE882C2424099D711876CE84B407C2C7DE882C2424006651A4D2EEC4B400A6AF816D6C7424006651A4D2EEC4B400A6AF816D6C7424099D711876CE84B407C2C7DE882C2424099D711876CE84B40
935	1	37.629573999999998	37.635081	55.786226999999997	55.785837000000001	Больничный переулок	0103000020E61000000100000005000000B9347EE195D042404E7E8B4E96E44B40B9347EE195D04240B81D1A16A3E44B40CEA78E554AD14240B81D1A16A3E44B40CEA78E554AD142404E7E8B4E96E44B40B9347EE195D042404E7E8B4E96E44B40
13055	1	37.578747	37.619593999999999	55.663867000000003	55.656103000000002	Болотниковская	0103000020E610000001000000050000003DD4B66114CA42405CE7DF2EFBD34B403DD4B66114CA424063F20698F9D44B401F662FDB4ECF424063F20698F9D44B401F662FDB4ECF42405CE7DF2EFBD34B403DD4B66114CA42405CE7DF2EFBD34B40
7707	1	37.714329999999997	37.726546999999997	55.817041000000003	55.808235000000003	Бойцовая улица	0103000020E610000001000000050000009D465A2A6FDB4240C53D963E74E74B409D465A2A6FDB4240DE3EABCC94E84B40E200FA7DFFDC4240DE3EABCC94E84B40E200FA7DFFDC4240C53D963E74E74B409D465A2A6FDB4240C53D963E74E74B40
13046	1	37.714329999999997	37.726546999999997	55.817041000000003	55.808235000000003	Бойцовая	0103000020E610000001000000050000009D465A2A6FDB4240C53D963E74E74B409D465A2A6FDB4240DE3EABCC94E84B40E200FA7DFFDC4240DE3EABCC94E84B40E200FA7DFFDC4240C53D963E74E74B409D465A2A6FDB4240C53D963E74E74B40
13194	1	37.388860999999999	37.405704999999998	55.657026999999999	55.647407000000001	Богданова	0103000020E610000001000000050000004DD87E32C6B14240CA198A3BDED24B404DD87E32C6B1424064CBF27519D44B406E693524EEB3424064CBF27519D44B406E693524EEB34240CA198A3BDED24B404DD87E32C6B14240CA198A3BDED24B40
12414	1	37.725523000000003	37.730849999999997	55.780856	55.780394999999999	Благуша	0103000020E6100000010000000500000077BF0AF0DDDC4240207BBDFBE3E34B4077BF0AF0DDDC42405471E316F3E34B400B24287E8CDD42405471E316F3E34B400B24287E8CDD4240207BBDFBE3E34B4077BF0AF0DDDC4240207BBDFBE3E34B40
5616	1	37.662416	37.671885000000003	55.601878999999997	55.581153999999998	Бирюлевская улица	0103000020E610000001000000050000006F2C280CCAD4424044F8174163CA4B406F2C280CCAD442401893FE5E0ACD4B4024D6E25300D642401893FE5E0ACD4B4024D6E25300D6424044F8174163CA4B406F2C280CCAD4424044F8174163CA4B40
12594	1	37.662416	37.671885000000003	55.601878999999997	55.581153999999998	Бирюлевская	0103000020E610000001000000050000006F2C280CCAD4424044F8174163CA4B406F2C280CCAD442401893FE5E0ACD4B4024D6E25300D642401893FE5E0ACD4B4024D6E25300D6424044F8174163CA4B406F2C280CCAD4424044F8174163CA4B40
13160	1	37.668534000000001	37.678496000000003	55.744808999999997	55.744231999999997	Библиотечная 	0103000020E61000000100000005000000CD21A98592D542407E5182FE42DF4B40CD21A98592D542401B62BCE655DF4B40C13BF9F4D8D642401B62BCE655DF4B40C13BF9F4D8D642407E5182FE42DF4B40CD21A98592D542407E5182FE42DF4B40
586	1	37.587128	37.605724000000002	55.884216000000002	55.879353999999999	Бибиревская улица	0103000020E610000001000000050000006F48A30227CB4240ABCDFFAB8EF04B406F48A30227CB4240CB4C69FD2DF14B407F33315D88CD4240CB4C69FD2DF14B407F33315D88CD4240ABCDFFAB8EF04B406F48A30227CB4240ABCDFFAB8EF04B40
13141	1	37.587128	37.605724000000002	55.884216000000002	55.879353999999999	Бибиревская	0103000020E610000001000000050000006F48A30227CB4240ABCDFFAB8EF04B406F48A30227CB4240CB4C69FD2DF14B407F33315D88CD4240CB4C69FD2DF14B407F33315D88CD4240ABCDFFAB8EF04B406F48A30227CB4240ABCDFFAB8EF04B40
13070	1	37.595528000000002	37.612892000000002	55.871481000000003	55.867071000000003	Бестужевых	0103000020E6100000010000000500000018EDF1423ACC4240AF27BA2EFCEE4B4018EDF1423ACC4240EE0A7DB08CEF4B4072FDBB3E73CE4240EE0A7DB08CEF4B4072FDBB3E73CE4240AF27BA2EFCEE4B4018EDF1423ACC4240AF27BA2EFCEE4B40
3100	1	37.547701000000004	37.557664000000003	55.878065999999997	55.875000999999997	Бескудниковский проезд	0103000020E61000000100000005000000467EFD101BC64240D07B630800F04B40467EFD101BC6424061DD787764F04B400A14B18861C7424061DD787764F04B400A14B18861C74240D07B630800F04B40467EFD101BC64240D07B630800F04B40
3022	1	37.554653999999999	37.560305	55.864364000000002	55.862943999999999	Бескудниковский переулок	0103000020E610000001000000050000003C4CFBE6FEC64240C423F1F274EE4B403C4CFBE6FEC642407DEBC37AA3EE4B4084640113B8C742407DEBC37AA3EE4B4084640113B8C74240C423F1F274EE4B403C4CFBE6FEC64240C423F1F274EE4B40
1249	1	37.533732999999998	37.562657999999999	55.876151999999998	55.855967	Бескудниковский бульвар	0103000020E61000000100000005000000E2E5E95C51C4424045BA9F5390ED4B40E2E5E95C51C442409929ADBF25F04B40986A662D05C842409929ADBF25F04B40986A662D05C8424045BA9F5390ED4B40E2E5E95C51C4424045BA9F5390ED4B40
1509	1	37.645581999999997	37.655670000000001	55.749825999999999	55.748604	Берниковская набережная	0103000020E610000001000000050000007171546EA2D24240D0D38041D2DF4B407171546EA2D2424062D8614CFADF4B40F27B9BFEECD3424062D8614CFADF4B40F27B9BFEECD34240D0D38041D2DF4B407171546EA2D24240D0D38041D2DF4B40
12963	1	37.454501	37.499479999999998	55.791804999999997	55.787633999999997	Берзарина	0103000020E61000000100000005000000E97FB9162DBA4240DC9BDF30D1E44B40E97FB9162DBA424096E7C1DD59E54B40C780ECF5EEBF424096E7C1DD59E54B40C780ECF5EEBF4240DC9BDF30D1E44B40E97FB9162DBA4240DC9BDF30D1E44B40
76495	1	37.604923999999997	37.626626999999999	55.854137999999999	55.846871	Березовая аллея	0103000020E6100000010000000500000062484E266ECD42402577D84466EC4B4062484E266ECD4240AB22DC6454ED4B4032E5435035D04240AB22DC6454ED4B4032E5435035D042402577D84466EC4B4062484E266ECD42402577D84466EC4B40
3516	1	37.546210000000002	37.572530999999998	55.745316000000003	55.728591000000002	Бережковская набережная	0103000020E61000000100000005000000C45F9335EAC5424079944A7842DD4B40C45F9335EAC54240C097C28366DF4B401C7920B248C94240C097C28366DF4B401C7920B248C9424079944A7842DD4B40C45F9335EAC5424079944A7842DD4B40
5964	1	37.502040000000001	37.509137000000003	55.758813000000004	55.752935999999998	Береговой проезд	0103000020E6100000010000000500000055A4C2D842C0424093FDF33460E04B4055A4C2D842C04240CC63CDC820E14B407F17B6662BC14240CC63CDC820E14B407F17B6662BC1424093FDF33460E04B4055A4C2D842C0424093FDF33460E04B40
4010	1	37.763854000000002	37.779718000000003	55.676194000000002	55.660423999999999	Белореченская улица	0103000020E610000001000000050000009B75C6F7C5E142402BBF0CC688D44B409B75C6F7C5E142402FE065868DD64B40200DA7CCCDE342402FE065868DD64B40200DA7CCCDE342402BBF0CC688D44B409B75C6F7C5E142402BBF0CC688D44B40
13080	1	37.763854000000002	37.779718000000003	55.676194000000002	55.660423999999999	Белореченская	0103000020E610000001000000050000009B75C6F7C5E142402BBF0CC688D44B409B75C6F7C5E142402FE065868DD64B40200DA7CCCDE342402FE065868DD64B40200DA7CCCDE342402BBF0CC688D44B409B75C6F7C5E142402BBF0CC688D44B40
12516	1	37.460735	37.484765000000003	55.866979999999998	55.861595000000001	Беломорская	0103000020E61000000100000005000000B08F4E5DF9BA4240D5B2B5BE48EE4B40B08F4E5DF9BA42409E245D33F9EE4B406B9F8EC70CBE42409E245D33F9EE4B406B9F8EC70CBE4240D5B2B5BE48EE4B40B08F4E5DF9BA4240D5B2B5BE48EE4B40
5835	1	37.606999000000002	37.623626999999999	55.900677999999999	55.895626	Белозерская улица	0103000020E6100000010000000500000034DAAA24B2CD424041B96DDFA3F24B4034DAAA24B2CD4240041DAD6A49F34B4088F37002D3CF4240041DAD6A49F34B4088F37002D3CF424041B96DDFA3F24B4034DAAA24B2CD424041B96DDFA3F24B40
12724	1	37.606999000000002	37.623626999999999	55.900677999999999	55.895626	Белозерская	0103000020E6100000010000000500000034DAAA24B2CD424041B96DDFA3F24B4034DAAA24B2CD4240041DAD6A49F34B4088F37002D3CF4240041DAD6A49F34B4088F37002D3CF424041B96DDFA3F24B4034DAAA24B2CD424041B96DDFA3F24B40
13104	1	37.391070999999997	37.402425999999998	55.715429	55.703439000000003	Беловежская 	0103000020E61000000100000005000000FEB4519D0EB2424090DD054A0ADA4B40FEB4519D0EB2424014CE6E2D93DB4B40B187F6B182B3424014CE6E2D93DB4B40B187F6B182B3424090DD054A0ADA4B40FEB4519D0EB2424090DD054A0ADA4B40
12747	1	37.391070999999997	37.402425999999998	55.715429	55.703439000000003	Беловежская	0103000020E61000000100000005000000FEB4519D0EB2424090DD054A0ADA4B40FEB4519D0EB2424014CE6E2D93DB4B40B187F6B182B3424014CE6E2D93DB4B40B187F6B182B3424090DD054A0ADA4B40FEB4519D0EB2424090DD054A0ADA4B40
12969	1	37.553216999999997	37.565891999999998	55.785569000000002	55.774653999999998	Беговая	0103000020E61000000100000005000000AD4B8DD0CFC6424098DBBDDC27E34B40AD4B8DD0CFC642402FE065868DE44B40B58828266FC842402FE065868DE44B40B58828266FC8424098DBBDDC27E34B40AD4B8DD0CFC6424098DBBDDC27E34B40
12479	1	37.570976999999999	37.577632999999999	55.808022000000001	55.791916000000001	Башиловская	0103000020E6100000010000000500000054E23AC615C94240EE96E4805DE54B4054E23AC615C942406939D0436DE74B40910BCEE0EFC942406939D0436DE74B40910BCEE0EFC94240EE96E4805DE54B4054E23AC615C94240EE96E4805DE54B40
12547	1	37.673788999999999	37.680284	55.777392999999996	55.763001000000003	Бауманская	0103000020E61000000100000005000000C8B3CBB73ED642405CE84A04AAE14B40C8B3CBB73ED64240D591239D81E34B40FCFECD8B13D74240D591239D81E34B40FCFECD8B13D742405CE84A04AAE14B40C8B3CBB73ED642405CE84A04AAE14B40
4269	1	37.70664	37.746246999999997	55.643870999999997	55.642240000000001	Батайский проезд	0103000020E61000000100000005000000D105F52D73DA42406E179AEB34D24B40D105F52D73DA4240E1EB6B5D6AD24B407ADE8D0585DF4240E1EB6B5D6AD24B407ADE8D0585DF42406E179AEB34D24B40D105F52D73DA42406E179AEB34D24B40
4700	1	37.735548000000001	37.748663999999998	55.738647	55.738484999999997	Басовская улица	0103000020E61000000100000005000000B151D66F26DE424014CB2DAD86DE4B40B151D66F26DE4240EE2422FC8BDE4B40A5D8D138D4DF4240EE2422FC8BDE4B40A5D8D138D4DF424014CB2DAD86DE4B40B151D66F26DE424014CB2DAD86DE4B40
12832	1	37.342238999999999	37.372584000000003	55.861499000000002	55.839359999999999	Барышиха	0103000020E610000001000000050000003735D07CCEAB424008C9022670EB4B403735D07CCEAB4240B344679945EE4B40A6811FD5B0AF4240B344679945EE4B40A6811FD5B0AF424008C9022670EB4B403735D07CCEAB424008C9022670EB4B40
13136	1	37.512982000000001	37.538817000000002	55.551772	55.545757000000002	Бартеневская	0103000020E61000000100000005000000E5B7E864A9C142401348895DDBC54B40E5B7E864A9C142409C6C0377A0C64B40B1C398F4F7C442409C6C0377A0C64B40B1C398F4F7C442401348895DDBC54B40E5B7E864A9C142401348895DDBC54B40
13061	1	37.578774000000003	37.584541000000002	55.760807999999997	55.757648000000003	Баррикадная	0103000020E6100000010000000500000037E3344415CA42409EF0129CFAE04B4037E3344415CA42408044132862E14B40E8154F3DD2CA42408044132862E14B40E8154F3DD2CA42409EF0129CFAE04B4037E3344415CA42409EF0129CFAE04B40
12608	1	37.492024000000001	37.516233	55.752941	55.736255	Барклая	0103000020E610000001000000050000006E6C76A4FABE42401C42959A3DDE4B406E6C76A4FABE4240A568E55E60E04B40D80E46EC13C24240A568E55E60E04B40D80E46EC13C242401C42959A3DDE4B406E6C76A4FABE42401C42959A3DDE4B40
4309	1	37.386319	37.399614	55.724088999999999	55.715363000000004	Барвихинская улица	0103000020E610000001000000050000006669A7E672B142405DE2C80391DB4B406669A7E672B142405932C7F2AEDC4B400A83328D26B342405932C7F2AEDC4B400A83328D26B342405DE2C80391DB4B406669A7E672B142405DE2C80391DB4B40
12708	1	37.682107000000002	37.689895999999997	55.789679	55.786217000000001	Барболина	0103000020E61000000100000005000000B4AF3C484FD74240954737C2A2E44B40B4AF3C484FD7424043AB933314E54B4013D21A834ED8424043AB933314E54B4013D21A834ED84240954737C2A2E44B40B4AF3C484FD74240954737C2A2E44B40
700	1	37.563108	37.619880999999999	55.649687999999998	55.640501999999998	Балаклавский проспект	0103000020E61000000100000005000000D80E46EC13C84240E48233F8FBD14B40D80E46EC13C84240444DF4F928D34B40B534B74258CF4240444DF4F928D34B40B534B74258CF4240E48233F8FBD14B40D80E46EC13C84240E48233F8FBD14B40
408	1	37.678379	37.696911999999998	55.782623000000001	55.773083999999997	Бакунинская улица	0103000020E6100000010000000500000087A5811FD5D64240CA87A06AF4E24B4087A5811FD5D64240780C8FFD2CE44B405018946934D94240780C8FFD2CE44B405018946934D94240CA87A06AF4E24B4087A5811FD5D64240CA87A06AF4E24B40
13066	1	37.778461	37.827131000000001	55.817642999999997	55.816647000000003	Байкальская 	0103000020E61000000100000005000000111B2C9CA4E3424032B08EE387E84B40111B2C9CA4E34240D3669C86A8E84B40FF40B96DDFE94240D3669C86A8E84B40FF40B96DDFE9424032B08EE387E84B40111B2C9CA4E3424032B08EE387E84B40
12741	1	37.506729	37.518210000000003	55.882919000000001	55.872728000000002	Базовская	0103000020E61000000100000005000000A777F17EDCC04240D926158DB5EF4B40A777F17EDCC042402E02637D03F14B40E73A8DB454C242402E02637D03F14B40E73A8DB454C24240D926158DB5EF4B40A777F17EDCC04240D926158DB5EF4B40
5979	1	37.499704000000001	37.516350000000003	55.747368000000002	55.741940999999997	Багратионовский проезд	0103000020E6100000010000000500000017D7F84CF6BF4240E04735ECF7DE4B4017D7F84CF6BF4240D9092FC1A9DF4B4012A5BDC117C24240D9092FC1A9DF4B4012A5BDC117C24240E04735ECF7DE4B4017D7F84CF6BF4240E04735ECF7DE4B40
12803	1	37.430363	37.433193000000003	55.849831999999999	55.843940000000003	Аэродромная	0103000020E610000001000000050000004834812216B74240A4E4D53906EC4B404834812216B74240118C834BC7EC4B4096ED43DE72B74240118C834BC7EC4B4096ED43DE72B74240A4E4D53906EC4B404834812216B74240A4E4D53906EC4B40
4820	1	37.557977999999999	37.566592999999997	55.813364	55.811067999999999	Астрадамский проезд	0103000020E6100000010000000500000099F1B6D26BC74240836A8313D1E74B4099F1B6D26BC7424033DFC14F1CE84B403E92921E86C8424033DFC14F1CE84B403E92921E86C84240836A8313D1E74B4099F1B6D26BC74240836A8313D1E74B40
12570	1	37.540765999999998	37.555866999999999	55.682245000000002	55.665070999999998	Архитектора Власова	0103000020E61000000100000005000000F564FED137C542404E42E90B21D54B40F564FED137C54240056EDDCD53D74B407BF65CA626C74240056EDDCD53D74B407BF65CA626C742404E42E90B21D54B40F564FED137C542404E42E90B21D54B40
12744	1	37.736463999999998	37.74004	55.704554999999999	55.693043000000003	Артюхиной	0103000020E610000001000000050000003657CD7344DE424062DC0DA2B5D84B403657CD7344DE4240DC9DB5DB2EDA4B40ADDD76A1B9DE4240DC9DB5DB2EDA4B40ADDD76A1B9DE424062DC0DA2B5D84B403657CD7344DE424062DC0DA2B5D84B40
7031	1	37.613225	37.613314000000003	55.653401000000002	55.644841	Артековская улица	0103000020E61000000100000005000000780B24287ECE42405A0F5F268AD24B40780B24287ECE42403C16DBA4A2D34B40E816BA1281CE42403C16DBA4A2D34B40E816BA1281CE42405A0F5F268AD24B40780B24287ECE42405A0F5F268AD24B40
13213	1	37.451357000000002	37.461435999999999	55.719692999999999	55.718004999999998	Артамонова	0103000020E610000001000000050000000CE9F010C6B94240A7AE7C96E7DB4B400CE9F010C6B942407F1475E61EDC4B403999B85510BB42407F1475E61EDC4B403999B85510BB4240A7AE7C96E7DB4B400CE9F010C6B94240A7AE7C96E7DB4B40
150	1	37.633949000000001	37.638601999999999	55.761091999999998	55.758195000000001	Армянский переулок	0103000020E610000001000000050000007C2AA73D25D14240D07EA4880CE14B407C2AA73D25D14240A59F70766BE14B408194D8B5BDD14240A59F70766BE14B408194D8B5BDD14240D07EA4880CE14B407C2AA73D25D14240D07EA4880CE14B40
13239	1	37.751987	37.753172999999997	55.677686999999999	55.671371999999998	Армавирская	0103000020E6100000010000000500000032022A1C41E042409DB98784EFD54B4032022A1C41E0424051F69672BED64B40779D0DF967E0424051F69672BED64B40779D0DF967E042409DB98784EFD54B4032022A1C41E042409DB98784EFD54B40
12613	1	37.619477000000003	37.620725	55.821587999999998	55.812246000000002	Аргуновская 	0103000020E61000000100000005000000E6CFB7054BCF424046274BADF7E74B40E6CFB7054BCF42409D64ABCB29E94B40A167B3EA73CF42409D64ABCB29E94B40A167B3EA73CF424046274BADF7E74B40E6CFB7054BCF424046274BADF7E74B40
13187	1	37.582628	37.600324999999998	55.752293000000002	55.746673999999999	Арбат	0103000020E61000000100000005000000F0DDE68D93CA424002637D0393DF4B40F0DDE68D93CA42403F0114234BE04B4050FC1873D7CC42403F0114234BE04B4050FC1873D7CC424002637D0393DF4B40F0DDE68D93CA424002637D0393DF4B40
361	1	37.673015999999997	37.679385000000003	55.768613000000002	55.767884000000002	Аптекарский переулок	0103000020E61000000100000005000000A5D7666325D64240938FDD054AE24B40A5D7666325D64240E62329E961E24B404D327216F6D64240E62329E961E24B404D327216F6D64240938FDD054AE24B40A5D7666325D64240938FDD054AE24B40
729	1	37.607681999999997	37.608167000000002	55.804096000000001	55.800823000000001	Анненский проезд	0103000020E61000000100000005000000162F1686C8CD42403B71395E81E64B40162F1686C8CD4240166C239EECE64B40D3C08F6AD8CD4240166C239EECE64B40D3C08F6AD8CD42403B71395E81E64B40162F1686C8CD42403B71395E81E64B40
12980	1	37.707934000000002	37.713728000000003	55.818891999999998	55.816352999999999	Андреево-Забелинская 	0103000020E61000000100000005000000FDDCD0949DDA4240E97E4E417EE84B40FDDCD0949DDA42405F7AFB73D1E84B40A81E69705BDB42405F7AFB73D1E84B40A81E69705BDB4240E97E4E417EE84B40FDDCD0949DDA4240E97E4E417EE84B40
12675	1	37.510627999999997	37.530166000000001	55.887113999999997	55.870460000000001	Ангарская	0103000020E61000000100000005000000003620425CC14240F33CB83B6BEF4B40003620425CC1424070E998F38CF14B40BFB9BF7ADCC3424070E998F38CF14B40BFB9BF7ADCC34240F33CB83B6BEF4B40003620425CC14240F33CB83B6BEF4B40
6397	1	37.678154999999997	37.714221999999999	55.882787999999998	55.859544	Анадырский проезд	0103000020E61000000100000005000000374F75C8CDD642408CBCAC8905EE4B40374F75C8CDD642408FA67A32FFF04B40B70A62A06BDB42408FA67A32FFF04B40B70A62A06BDB42408CBCAC8905EE4B40374F75C8CDD642408CBCAC8905EE4B40
8082	1	37.748151	37.798411999999999	55.813383999999999	55.801738	Амурская улица	0103000020E610000001000000050000001FBC7669C3DF4240F0FACC599FE64B401FBC7669C3DF42407A8B87F71CE84B40F25D4A5D32E642407A8B87F71CE84B40F25D4A5D32E64240F0FACC599FE64B401FBC7669C3DF4240F0FACC599FE64B40
13214	1	37.748151	37.798411999999999	55.813383999999999	55.801738	Амурская	0103000020E610000001000000050000001FBC7669C3DF4240F0FACC599FE64B401FBC7669C3DF42407A8B87F71CE84B40F25D4A5D32E642407A8B87F71CE84B40F25D4A5D32E64240F0FACC599FE64B401FBC7669C3DF4240F0FACC599FE64B40
12685	1	37.654646	37.659874000000002	55.856295000000003	55.847512999999999	Амундсена	0103000020E61000000100000005000000863AAC70CBD34240A9F7544E7BEC4B40863AAC70CBD342403A5D16139BED4B4088BD50C076D442403A5D16139BED4B4088BD50C076D44240A9F7544E7BEC4B40863AAC70CBD34240A9F7544E7BEC4B40
4856	1	37.448895999999998	37.466880000000003	55.723734	55.694052999999997	Аминьевское шоссе	0103000020E6100000010000000500000011A7936C75B9424068588CBAD6D84B4011A7936C75B942406B80D250A3DC4B4008944DB9C2BB42406B80D250A3DC4B4008944DB9C2BB424068588CBAD6D84B4011A7936C75B9424068588CBAD6D84B40
7751	1	37.707377000000001	37.714329999999997	55.808235000000003	55.804101000000003	Алымов переулок	0103000020E61000000100000005000000A7785C548BDA424028D714C8ECE64B40A7785C548BDA4240C53D963E74E74B409D465A2A6FDB4240C53D963E74E74B409D465A2A6FDB424028D714C8ECE64B40A7785C548BDA424028D714C8ECE64B40
605	1	37.584074000000001	37.590749000000002	55.912954999999997	55.848215000000003	Алтуфьевское шоссе	0103000020E61000000100000005000000D238D4EFC2CA4240037D224F92EC4B40D238D4EFC2CA42401EDC9DB5DBF44B408692C9A99DCB42401EDC9DB5DBF44B408692C9A99DCB4240037D224F92EC4B40D238D4EFC2CA4240037D224F92EC4B40
13105	1	37.798017000000002	37.834434999999999	55.820526000000001	55.819792999999997	Алтайская 	0103000020E610000001000000050000007653CA6B25E64240AF3E1EFAEEE84B407653CA6B25E6424044C2F7FE06E94B40A2D11DC4CEEA424044C2F7FE06E94B40A2D11DC4CEEA4240AF3E1EFAEEE84B407653CA6B25E64240AF3E1EFAEEE84B40
13155	1	37.798017000000002	37.834434999999999	55.820526000000001	55.819792999999997	Алтайская	0103000020E610000001000000050000007653CA6B25E64240AF3E1EFAEEE84B407653CA6B25E6424044C2F7FE06E94B40A2D11DC4CEEA424044C2F7FE06E94B40A2D11DC4CEEA4240AF3E1EFAEEE84B407653CA6B25E64240AF3E1EFAEEE84B40
13076	1	37.767555000000002	37.772658	55.64349	55.637509999999999	Алма-Атинская	0103000020E61000000100000005000000CE70033E3FE24240BD6F7CED99D14B40CE70033E3FE24240CAA65CE15DD24B40137F1475E6E24240CAA65CE15DD24B40137F1475E6E24240BD6F7CED99D14B40CE70033E3FE24240BD6F7CED99D14B40
12903	1	37.805311000000003	37.818722999999999	55.748553999999999	55.746775	Алексея Дикого	0103000020E61000000100000005000000F60D4C6E14E74240363CBD5296DF4B40F60D4C6E14E742401EA5129ED0DF4B40D3BD4EEACBE842401EA5129ED0DF4B40D3BD4EEACBE84240363CBD5296DF4B40F60D4C6E14E74240363CBD5296DF4B40
13117	1	37.588386	37.591216000000003	55.776212999999998	55.774526999999999	Александра Невского	0103000020E610000001000000050000004EB6813B50CB42403B6F63B323E34B404EB6813B50CB424072DD94F25AE34B409C6F44F7ACCB424072DD94F25AE34B409C6F44F7ACCB42403B6F63B323E34B404EB6813B50CB42403B6F63B323E34B40
12889	1	37.670492000000003	37.674337000000001	55.644745	55.637027000000003	 Кошкина	0103000020E61000000100000005000000651D8EAED2D54240A2D5C9198AD14B40651D8EAED2D5424038A1100187D24B40CBBDC0AC50D6424038A1100187D24B40CBBDC0AC50D64240A2D5C9198AD14B40651D8EAED2D54240A2D5C9198AD14B40
13113	1	37.521956000000003	37.539006000000001	55.664856999999998	55.659145000000002	Академика Челомея	0103000020E61000000100000005000000BAF94674CFC24240352905DD5ED44B40BAF94674CFC2424022C2BF081AD54B40842C0B26FEC4424022C2BF081AD54B40842C0B26FEC44240352905DD5ED44B40BAF94674CFC24240352905DD5ED44B40
12559	1	37.79119	37.797351999999997	55.716285999999997	55.696680999999998	Академика Скрябина	0103000020E610000001000000050000000C76C3B645E542404E5FCFD72CD94B400C76C3B645E54240944A7842AFDB4B4039B35DA10FE64240944A7842AFDB4B4039B35DA10FE642404E5FCFD72CD94B400C76C3B645E542404E5FCFD72CD94B40
13085	1	37.499129000000003	37.499533999999997	55.540790999999999	55.531193000000002	Академика Понтрягина	0103000020E610000001000000050000001BBE8575E3BF42409C6ED921FEC34B401BBE8575E3BF42404E7CB5A338C54B40BA9EE8BAF0BF42404E7CB5A338C54B40BA9EE8BAF0BF42409C6ED921FEC34B401BBE8575E3BF42409C6ED921FEC34B40
12707	1	37.391170000000002	37.410393999999997	55.750270999999998	55.737527	Академика Павлова	0103000020E610000001000000050000009296CADB11B242406075E44867DE4B409296CADB11B24240901150E108E04B40C03C64CA87B44240901150E108E04B40C03C64CA87B442406075E44867DE4B409296CADB11B242406075E44867DE4B40
12718	1	37.639707000000001	37.655130999999997	55.675274999999999	55.659098999999998	Академика Миллионщикова	0103000020E61000000100000005000000DA0242EBE1D14240C4E9245B5DD44B40DA0242EBE1D14240386744696FD64B4042CC2555DBD34240386744696FD64B4042CC2555DBD34240C4E9245B5DD44B40DA0242EBE1D14240C4E9245B5DD44B40
12735	1	37.516108000000003	37.528621000000001	55.632443000000002	55.625328000000003	Академика Капицы	0103000020E610000001000000050000001C9AB2D30FC24240F5A276BF0AD04B401C9AB2D30FC24240C5CA68E4F3D04B404A7D59DAA9C34240C5CA68E4F3D04B404A7D59DAA9C34240F5A276BF0AD04B401C9AB2D30FC24240F5A276BF0AD04B40
13135	1	37.538125000000001	37.548366000000001	55.806832999999997	55.802410999999999	Академика Ильюшина	0103000020E610000001000000050000007B14AE47E1C44240AF795567B5E64B407B14AE47E1C44240B22AC24D46E74B40821E6ADB30C64240B22AC24D46E74B40821E6ADB30C64240AF795567B5E64B407B14AE47E1C44240AF795567B5E64B40
12814	1	37.503064000000002	37.525288000000003	55.657347000000001	55.640365000000003	Академика Волгина	0103000020E61000000100000005000000C1E5B16664C042406440F67AF7D14B40C1E5B16664C04240D68F4DF223D44B409A7D1EA33CC34240D68F4DF223D44B409A7D1EA33CC342406440F67AF7D14B40C1E5B16664C042406440F67AF7D14B40
12960	1	37.482044000000002	37.488404000000003	55.635649999999998	55.631005000000002	Академика Виноградова	0103000020E61000000100000005000000D49D279EB3BD4240664E97C5C4D04B40D49D279EB3BD4240E8D9ACFA5CD14B40289EB30584BE4240E8D9ACFA5CD14B40289EB30584BE4240664E97C5C4D04B40D49D279EB3BD4240664E97C5C4D04B40
12431	1	37.469844000000002	37.480992999999998	55.634878	55.629525999999998	Академика Варги	0103000020E61000000100000005000000651C23D923BC4240A8FDD64E94D04B40651C23D923BC42409679ABAE43D14B406E4DBA2D91BD42409679ABAE43D14B406E4DBA2D91BD4240A8FDD64E94D04B40651C23D923BC4240A8FDD64E94D04B40
12736	1	37.510232999999999	37.516942999999998	55.646518	55.637555999999996	Академика Арцимовича	0103000020E61000000100000005000000842BA0504FC142402DAF5C6F9BD14B40842BA0504FC142403E23111AC1D24B40B4722F302BC242403E23111AC1D24B40B4722F302BC242402DAF5C6F9BD14B40842BA0504FC142402DAF5C6F9BD14B40
12799	1	37.466745000000003	37.478127000000001	55.670163000000002	55.642955999999998	Академика Анохина	0103000020E610000001000000050000002849D74CBEBB42402C62D8614CD24B402849D74CBEBB4240A0FEB3E6C7D54B40D42AFA4333BD4240A0FEB3E6C7D54B40D42AFA4333BD42402C62D8614CD24B402849D74CBEBB42402C62D8614CD24B40
650	1	37.594019000000003	37.607456999999997	55.664157000000003	55.640613999999999	Азовская улица	0103000020E61000000100000005000000F01989D008CC42400CAEB9A3FFD14B40F01989D008CC42406A34B91803D54B40F65CA626C1CD42406A34B91803D54B40F65CA626C1CD42400CAEB9A3FFD14B40F01989D008CC42400CAEB9A3FFD14B40
13091	1	37.594019000000003	37.607456999999997	55.664157000000003	55.640613999999999	Азовская	0103000020E61000000100000005000000F01989D008CC42400CAEB9A3FFD14B40F01989D008CC42406A34B91803D54B40F65CA626C1CD42406A34B91803D54B40F65CA626C1CD42400CAEB9A3FFD14B40F01989D008CC42400CAEB9A3FFD14B40
12792	1	37.515433999999999	37.528100000000002	55.544809999999998	55.539150999999997	Адмирала Руднева	0103000020E610000001000000050000008C9FC6BDF9C14240874D64E602C54B408C9FC6BDF9C1424052448655BCC54B404182E2C798C3424052448655BCC54B404182E2C798C34240874D64E602C54B408C9FC6BDF9C14240874D64E602C54B40
2617	1	37.536912999999998	37.540909999999997	55.801333999999997	55.798636999999999	Авиационный переулок	0103000020E610000001000000050000000CE6AF90B9C442401230BABC39E64B400CE6AF90B9C442402096CD1C92E64B40280AF4893CC542402096CD1C92E64B40280AF4893CC542401230BABC39E64B400CE6AF90B9C442401230BABC39E64B40
13094	1	37.447926000000002	37.483750000000001	55.810657999999997	55.808821999999999	Авиационная	0103000020E610000001000000050000009983A0A355B942408524B37A87E74B409983A0A355B94240D11E2FA4C3E74B4052B81E85EBBD4240D11E2FA4C3E74B4052B81E85EBBD42408524B37A87E74B409983A0A355B942408524B37A87E74B40
3549	1	37.706434000000002	37.721812999999997	55.763446999999999	55.735581000000003	Авиамоторная улица	0103000020E610000001000000050000002864E76D6CDA42408D47A98427DE4B402864E76D6CDA42405A9D9CA1B8E14B40F0694E5E64DC42405A9D9CA1B8E14B40F0694E5E64DC42408D47A98427DE4B402864E76D6CDA42408D47A98427DE4B40
12865	1	37.706434000000002	37.721812999999997	55.763446999999999	55.735581000000003	Авиамоторная 	0103000020E610000001000000050000002864E76D6CDA42408D47A98427DE4B402864E76D6CDA42405A9D9CA1B8E14B40F0694E5E64DC42405A9D9CA1B8E14B40F0694E5E64DC42408D47A98427DE4B402864E76D6CDA42408D47A98427DE4B40
12949	1	37.706434000000002	37.721812999999997	55.763446999999999	55.735581000000003	Авиамоторная	0103000020E610000001000000050000002864E76D6CDA42408D47A98427DE4B402864E76D6CDA42405A9D9CA1B8E14B40F0694E5E64DC42405A9D9CA1B8E14B40F0694E5E64DC42408D47A98427DE4B402864E76D6CDA42408D47A98427DE4B40
3606	1	37.488816999999997	37.49391	55.851433999999998	55.841968000000001	Авангардная улица	0103000020E610000001000000050000004A5D328E91BE4240A723809BC5EB4B404A5D328E91BE4240EA5910CAFBEC4B406C95607138BF4240EA5910CAFBEC4B406C95607138BF4240A723809BC5EB4B404A5D328E91BE4240A723809BC5EB4B40
12440	1	37.569369000000002	37.574174999999997	55.908938999999997	55.891274000000003	Абрамцевская	0103000020E61000000100000005000000992D5915E1C8424037E3344415F24B40992D5915E1C842408B87F71C58F44B402497FF907EC942408B87F71C58F44B402497FF907EC9424037E3344415F24B40992D5915E1C8424037E3344415F24B40
12575	1	37.547800000000002	37.553172000000004	55.936982999999998	55.936408	9-я Северная линия	0103000020E61000000100000005000000D95F764F1EC642403CDBA337DCF74B40D95F764F1EC6424038F4160FEFF74B400E881057CEC6424038F4160FEFF74B400E881057CEC642403CDBA337DCF74B40D95F764F1EC642403CDBA337DCF74B40
12868	1	37.526564	37.566665	55.880803	55.874884999999999	800-летия Москвы	0103000020E610000001000000050000001FA0FB7266C3424067614F3BFCEF4B401FA0FB7266C34240FE9B1727BEF04B40D8648D7A88C84240FE9B1727BEF04B40D8648D7A88C8424067614F3BFCEF4B401FA0FB7266C3424067614F3BFCEF4B40
12831	1	37.738799999999998	37.748708000000001	55.705209000000004	55.700375000000001	8-я Текстильщиков	0103000020E61000000100000005000000742497FF90DE4240CFF753E3A5D94B40742497FF90DE424025ECDB4944DA4B407520EBA9D5DF424025ECDB4944DA4B407520EBA9D5DF4240CFF753E3A5D94B40742497FF90DE4240CFF753E3A5D94B40
12668	1	37.182743000000002	37.964969000000004	56.010739999999998	55.490667000000002	8 Марта	0103000020E610000001000000050000005649641F64974240FC1C1F2DCEBE4B405649641F649742402861A6ED5F014C40B153AC1A84FB42402861A6ED5F014C40B153AC1A84FB4240FC1C1F2DCEBE4B405649641F64974240FC1C1F2DCEBE4B40
5330	1	37.746732000000002	37.748493000000003	55.700263	55.693713000000002	7-я улица Текстильщиков	0103000020E61000000100000005000000377007EA94DF4240B0E76B96CBD84B40377007EA94DF4240A7CCCD37A2D94B4079245E9ECEDF4240A7CCCD37A2D94B4079245E9ECEDF4240B0E76B96CBD84B40377007EA94DF4240B0E76B96CBD84B40
4489	1	37.347296	37.351526999999997	55.659668000000003	55.657981999999997	7-я улица Лазенки	0103000020E610000001000000050000000C04013274AC4240A7AD11C138D44B400C04013274AC4240DF1B430070D44B409B5434D6FEAC4240DF1B430070D44B409B5434D6FEAC4240A7AD11C138D44B400C04013274AC4240A7AD11C138D44B40
13118	1	37.793560999999997	37.795906000000002	55.806534999999997	55.788646999999997	7-я Парковая	0103000020E61000000100000005000000C630276893E54240548B8862F2E44B40C630276893E54240280AF4893CE74B405858703FE0E54240280AF4893CE74B405858703FE0E54240548B8862F2E44B40C630276893E54240548B8862F2E44B40
13121	1	37.790686999999998	37.79092	55.796486000000002	55.788626000000001	6-я Парковая	0103000020E61000000100000005000000A92F4B3B35E542403D635FB2F1E44B40A92F4B3B35E5424066DCD440F3E54B404CE0D6DD3CE5424066DCD440F3E54B404CE0D6DD3CE542403D635FB2F1E44B40A92F4B3B35E542403D635FB2F1E44B40
12932	1	37.668182999999999	37.683292999999999	55.708261999999998	55.706766000000002	6-я Кожуховская	0103000020E61000000100000005000000205F420587D542405EF6EB4E77DA4B40205F420587D54240F17F4754A8DA4B40F94A202576D74240F17F4754A8DA4B40F94A202576D742405EF6EB4E77DA4B40205F420587D542405EF6EB4E77DA4B40
12888	1	37.182743000000002	37.964969000000004	56.010739999999998	55.490667000000002	50 лет Октября	0103000020E610000001000000050000005649641F64974240FC1C1F2DCEBE4B405649641F649742402861A6ED5F014C40B153AC1A84FB42402861A6ED5F014C40B153AC1A84FB4240FC1C1F2DCEBE4B405649641F64974240FC1C1F2DCEBE4B40
12307	1	37.730364999999999	37.743822000000002	55.765762000000002	55.761780999999999	5-я улица Соколиной Горы	0103000020E610000001000000050000004F92AE997CDD42406ADB300A82E14B404F92AE997CDD424081423D7D04E24B40CD052E8F35DF424081423D7D04E24B40CD052E8F35DF42406ADB300A82E14B404F92AE997CDD42406ADB300A82E14B40
663	1	37.787354000000001	37.788369000000003	55.810000000000002	55.788590999999997	5-я Парковая улица	0103000020E61000000100000005000000F92F1004C8E44240C075C58CF0E44B40F92F1004C8E4424048E17A14AEE74B4012178046E9E4424048E17A14AEE74B4012178046E9E44240C075C58CF0E44B40F92F1004C8E44240C075C58CF0E44B40
12387	1	37.787354000000001	37.788369000000003	55.810000000000002	55.788590999999997	5-я Парковая	0103000020E61000000100000005000000F92F1004C8E44240C075C58CF0E44B40F92F1004C8E4424048E17A14AEE74B4012178046E9E4424048E17A14AEE74B4012178046E9E44240C075C58CF0E44B40F92F1004C8E44240C075C58CF0E44B40
5551	1	37.662533000000003	37.684578000000002	55.706918000000002	55.705025999999997	5-я Кожуховская улица	0103000020E61000000100000005000000A9C29FE1CDD44240336ABE4A3EDA4B40A9C29FE1CDD44240147AFD497CDA4B40D2C77C40A0D74240147AFD497CDA4B40D2C77C40A0D74240336ABE4A3EDA4B40A9C29FE1CDD44240336ABE4A3EDA4B40
12935	1	37.662533000000003	37.684578000000002	55.706918000000002	55.705025999999997	5-я Кожуховская 	0103000020E61000000100000005000000A9C29FE1CDD44240336ABE4A3EDA4B40A9C29FE1CDD44240147AFD497CDA4B40D2C77C40A0D74240147AFD497CDA4B40D2C77C40A0D74240336ABE4A3EDA4B40A9C29FE1CDD44240336ABE4A3EDA4B40
7647	1	37.726546999999997	37.730967	55.819215999999997	55.817041000000003	5-й проезд Подбельского	0103000020E61000000100000005000000E200FA7DFFDC4240DE3EABCC94E84B40E200FA7DFFDC4240122EE411DCE84B4045BA9F5390DD4240122EE411DCE84B4045BA9F5390DD4240DE3EABCC94E84B40E200FA7DFFDC4240DE3EABCC94E84B40
6503	1	37.608293000000003	37.623896000000002	55.798656999999999	55.798211999999999	5-й проезд Марьиной Рощи	0103000020E6100000010000000500000060B1868BDCCD42402BA391CF2BE64B4060B1868BDCCD424059DC7F643AE64B40780DFAD2DBCF424059DC7F643AE64B40780DFAD2DBCF42402BA391CF2BE64B4060B1868BDCCD42402BA391CF2BE64B40
12432	1	37.182743000000002	37.964969000000004	56.010739999999998	55.490667000000002	5-й квартал Капотня	0103000020E610000001000000050000005649641F64974240FC1C1F2DCEBE4B405649641F649742402861A6ED5F014C40B153AC1A84FB42402861A6ED5F014C40B153AC1A84FB4240FC1C1F2DCEBE4B405649641F64974240FC1C1F2DCEBE4B40
6099	1	37.613475999999999	37.613484999999997	55.711360999999997	55.708075000000001	5-й Рощинский проезд	0103000020E61000000100000005000000C170AE6186CE4240BF0E9C33A2DA4B40C170AE6186CE42402E5393E00DDB4B4014CB2DAD86CE42402E5393E00DDB4B4014CB2DAD86CE4240BF0E9C33A2DA4B40C170AE6186CE4240BF0E9C33A2DA4B40
547	1	37.629358000000003	37.634568000000002	55.732717000000001	55.732016999999999	5-й Монетчиковский переулок	0103000020E61000000100000005000000EDBC8DCD8ED04240DA8EA9BBB2DD4B40EDBC8DCD8ED04240931CB0ABC9DD4B40488B338639D14240931CB0ABC9DD4B40488B338639D14240DA8EA9BBB2DD4B40EDBC8DCD8ED04240DA8EA9BBB2DD4B40
1770	1	37.646102999999997	37.652202000000003	55.742696000000002	55.740791000000002	5-й Котельнический переулок	0103000020E610000001000000050000007A6CCB80B3D24240E8154F3DD2DE4B407A6CCB80B3D242405D6F9BA910DF4B406231EA5A7BD342405D6F9BA910DF4B406231EA5A7BD34240E8154F3DD2DE4B407A6CCB80B3D24240E8154F3DD2DE4B40
13231	1	37.785575000000001	37.785926000000003	55.796394999999997	55.789906999999999	4-я Парковая	0103000020E6100000010000000500000011C7BAB88DE44240D4F02DAC1BE54B4011C7BAB88DE4424055D97745F0E54B40BE89213999E4424055D97745F0E54B40BE89213999E44240D4F02DAC1BE54B4011C7BAB88DE44240D4F02DAC1BE54B40
12824	1	37.785459000000003	37.795053000000003	55.712158000000002	55.709063999999998	4-я Новокузьминская	0103000020E61000000100000005000000A8ACA6EB89E44240AE62F19BC2DA4B40A8ACA6EB89E44240DACA4BFE27DB4B4019CBF44BC4E54240DACA4BFE27DB4B4019CBF44BC4E54240AE62F19BC2DA4B40A8ACA6EB89E44240AE62F19BC2DA4B40
4221	1	37.542276000000001	37.545985999999999	55.844676999999997	55.839249000000002	4-й Новомихалковский проезд	0103000020E61000000100000005000000EEB3CA4C69C54240B119E0826CEB4B40EEB3CA4C69C5424079573D601EEC4B40740987DEE2C5424079573D601EEC4B40740987DEE2C54240B119E0826CEB4B40EEB3CA4C69C54240B119E0826CEB4B40
5058	1	37.794252999999998	37.796616	55.722639000000001	55.717162999999999	4-й Вешняковский проезд	0103000020E61000000100000005000000FCDF1115AAE542405C7347FFCBDB4B40FCDF1115AAE5424036E84B6F7FDC4B4034BC5983F7E5424036E84B6F7FDC4B4034BC5983F7E542405C7347FFCBDB4B40FCDF1115AAE542405C7347FFCBDB4B40
12861	1	37.570779000000002	37.583103999999999	55.724784	55.718831000000002	3-я Фрунзенская	0103000020E610000001000000050000002E1F49490FC94240ED2C7AA702DC4B402E1F49490FC942400055DCB8C5DC4B405915E126A3CA42400055DCB8C5DC4B405915E126A3CA4240ED2C7AA702DC4B402E1F49490FC94240ED2C7AA702DC4B40
12477	1	37.552821999999999	37.553531	55.942402999999999	55.940260000000002	3-я Северная линия	0103000020E6100000010000000500000031410DDFC2C6424055DE8E705AF84B4031410DDFC2C642407E5358A9A0F84B403D29931ADAC642407E5358A9A0F84B403D29931ADAC6424055DE8E705AF84B4031410DDFC2C6424055DE8E705AF84B40
2735	1	37.658741999999997	37.664132000000002	55.791567000000001	55.788727000000002	3-я Рыбинская улица	0103000020E61000000100000005000000354069A851D44240713C9F01F5E44B40354069A851D44240E2CB441152E54B40111D024702D54240E2CB441152E54B40111D024702D54240713C9F01F5E44B40354069A851D44240713C9F01F5E44B40
13248	1	37.670186999999999	37.689815000000003	55.610463000000003	55.592215000000003	3-я Радиальная	0103000020E61000000100000005000000289A07B0C8D54240AF997CB3CDCB4B40289A07B0C8D542408335CEA623CE4B4027A5A0DB4BD842408335CEA623CE4B4027A5A0DB4BD84240AF997CB3CDCB4B40289A07B0C8D54240AF997CB3CDCB4B40
13013	1	37.781955000000004	37.784317999999999	55.809686999999997	55.788110000000003	3-я Парковая 	0103000020E61000000100000005000000CBF8F71917E4424046D3D9C9E0E44B40CBF8F71917E44240887FD8D2A3E74B4002D53F8864E44240887FD8D2A3E74B4002D53F8864E4424046D3D9C9E0E44B40CBF8F71917E4424046D3D9C9E0E44B40
6609	1	37.620240000000003	37.630571000000003	55.820146999999999	55.816611000000002	3-я Новоостанкинская улица	0103000020E61000000100000005000000E5D5390664CF4240E54691B586E84B40E5D5390664CF4240CD74AF93FAE84B402C67EF8CB6D04240CD74AF93FAE84B402C67EF8CB6D04240E54691B586E84B40E5D5390664CF4240E54691B586E84B40
13067	1	37.784101999999997	37.791755999999999	55.764698000000003	55.752136	3-я Владимирская 	0103000020E61000000100000005000000355D4F745DE44240771211FE45E04B40355D4F745DE4424087A8C29FE1E14B40B534B74258E5424087A8C29FE1E14B40B534B74258E54240771211FE45E04B40355D4F745DE44240771211FE45E04B40
13035	1	37.784101999999997	37.791755999999999	55.764698000000003	55.752136	3-я Владимирская	0103000020E61000000100000005000000355D4F745DE44240771211FE45E04B40355D4F745DE4424087A8C29FE1E14B40B534B74258E5424087A8C29FE1E14B40B534B74258E54240771211FE45E04B40355D4F745DE44240771211FE45E04B40
6523	1	37.609001999999997	37.624111999999997	55.796633	55.796171999999999	3-й проезд Марьиной Рощи	0103000020E610000001000000050000006B990CC7F3CD4240D6FECEF6E8E54B406B990CC7F3CD42400AF5F411F8E54B404485EAE6E2CF42400AF5F411F8E54B404485EAE6E2CF4240D6FECEF6E8E54B406B990CC7F3CD4240D6FECEF6E8E54B40
1984	1	37.608814000000002	37.617733999999999	55.780794999999998	55.778374999999997	3-й Самотечный переулок	0103000020E6100000010000000500000069ACFD9DEDCD42401283C0CAA1E34B4069ACFD9DEDCD4240AEF02E17F1E34B404AD05FE811CF4240AEF02E17F1E34B404AD05FE811CF42401283C0CAA1E34B4069ACFD9DEDCD42401283C0CAA1E34B40
6153	1	37.627580000000002	37.634172999999997	55.719064000000003	55.718201999999998	3-й Павловский переулок	0103000020E61000000100000005000000D5CF9B8A54D04240FDF50A0BEEDB4B40D5CF9B8A54D0424090DD054A0ADC4B40CB80B3942CD1424090DD054A0ADC4B40CB80B3942CD14240FDF50A0BEEDB4B40D5CF9B8A54D04240FDF50A0BEEDB4B40
3371	1	37.511274999999998	37.513942999999998	55.820976000000002	55.817946999999997	3-й Новоподмосковный переулок	0103000020E6100000010000000500000096218E7571C142403F6EBF7CB2E84B4096218E7571C142408466D7BD15E94B400A815CE2C8C142408466D7BD15E94B400A815CE2C8C142403F6EBF7CB2E84B4096218E7571C142403F6EBF7CB2E84B40
12397	1	37.561131000000003	37.573537000000002	55.846932000000002	55.845101999999997	3-й Нижнелихоборский проезд	0103000020E61000000100000005000000CAE2FE23D3C7424060E4654D2CEC4B40CAE2FE23D3C74240CBF78C4468EC4B40E20511A969C94240CBF78C4468EC4B40E20511A969C9424060E4654D2CEC4B40CAE2FE23D3C7424060E4654D2CEC4B40
4281	1	37.522089999999999	37.534109999999998	55.837045000000003	55.833860000000001	3-й Михалковский переулок	0103000020E61000000100000005000000C9C859D8D3C24240A6B8AAECBBEA4B40C9C859D8D3C24240E223624A24EB4B40B83B6BB75DC44240E223624A24EB4B40B83B6BB75DC44240A6B8AAECBBEA4B40C9C859D8D3C24240A6B8AAECBBEA4B40
6346	1	37.347602000000002	37.354806000000004	55.850090000000002	55.845587000000002	3-й Митинский проезд	0103000020E610000001000000050000001903EB387EAC42401D76DF313CEC4B401903EB387EAC42400D54C6BFCFEC4B40593673486AAD42400D54C6BFCFEC4B40593673486AAD42401D76DF313CEC4B401903EB387EAC42401D76DF313CEC4B40
3579	1	37.513807999999997	37.535161000000002	55.850403	55.847366000000001	3-й Лихачевский переулок	0103000020E610000001000000050000002A36E675C4C1424005DF347D76EC4B402A36E675C4C14240CCB56801DAEC4B401E8CD82780C44240CCB56801DAEC4B401E8CD82780C4424005DF347D76EC4B402A36E675C4C1424005DF347D76EC4B40
5491	1	37.674166	37.674436	55.709291999999998	55.706898000000002	3-й Кожуховский проезд	0103000020E610000001000000050000009E094D124BD64240CDCD37A27BDA4B409E094D124BD642403FA88B14CADA4B405E9F39EB53D642403FA88B14CADA4B405E9F39EB53D64240CDCD37A27BDA4B409E094D124BD64240CDCD37A27BDA4B40
2479	1	37.622441000000002	37.624991999999999	55.742362	55.741925999999999	3-й Кадашевский переулок	0103000020E6100000010000000500000043588D25ACCF4240AB06616EF7DE4B4043588D25ACCF424086E5CFB705DF4B407D21E4BCFFCF424086E5CFB705DF4B407D21E4BCFFCF4240AB06616EF7DE4B4043588D25ACCF4240AB06616EF7DE4B40
13079	1	37.605759999999997	37.632474999999999	55.603929000000001	55.600113999999998	3-й Дорожный проезд	0103000020E61000000100000005000000CB9C2E8B89CD424095EF1989D0CC4B40CB9C2E8B89CD4240910DA48B4DCD4B40D044D8F0F4D04240910DA48B4DCD4B40D044D8F0F4D0424095EF1989D0CC4B40CB9C2E8B89CD424095EF1989D0CC4B40
12720	1	37.933663000000003	37.950775	55.904887000000002	55.902828	26-ти Бакинских Комиссаров	0103000020E610000001000000050000001D3EE94482F74240E0F42EDE8FF34B401D3EE94482F74240ACC95356D3F34B405D6DC5FEB2F94240ACC95356D3F34B405D6DC5FEB2F94240E0F42EDE8FF34B401D3EE94482F74240E0F42EDE8FF34B40
12508	1	37.546390000000002	37.548088	55.764854999999997	55.760427999999997	2-я Черногрязская	0103000020E61000000100000005000000446E861BF0C54240397B67B455E14B40446E861BF0C542404E97C5C4E6E14B403FAA61BF27C642404E97C5C4E6E14B403FAA61BF27C64240397B67B455E14B40446E861BF0C54240397B67B455E14B40
4550	1	37.563161000000001	37.579475000000002	55.807085999999998	55.803190999999998	2-я Хуторская улица	0103000020E61000000100000005000000FBB0DEA815C8424084B872F6CEE64B40FBB0DEA815C842409C8713984EE74B40C0EC9E3C2CCA42409C8713984EE74B40C0EC9E3C2CCA424084B872F6CEE64B40FBB0DEA815C8424084B872F6CEE64B40
12858	1	37.578361000000001	37.585861999999999	55.724631000000002	55.721234000000003	2-я Фрунзенская	0103000020E610000001000000050000001424B6BB07CA4240B3614D6551DC4B401424B6BB07CA42407A5567B5C0DC4B400DFCA886FDCA42407A5567B5C0DC4B400DFCA886FDCA4240B3614D6551DC4B401424B6BB07CA4240B3614D6551DC4B40
13012	1	37.585780999999997	37.594683000000003	55.776639000000003	55.771489000000003	2-я Тверская-Ямская	0103000020E6100000010000000500000020CF2EDFFACA4240A41CCC26C0E24B4020CF2EDFFACA42402AE620E868E34B405C3E92921ECC42402AE620E868E34B405C3E92921ECC4240A41CCC26C0E24B4020CF2EDFFACA4240A41CCC26C0E24B40
12461	1	37.491143000000001	37.494557	55.820712999999998	55.816799000000003	2-я Радиаторская 	0103000020E61000000100000005000000655419C6DDBE4240E833A0DE8CE84B40655419C6DDBE42407633A31F0DE94B400281CEA44DBF42407633A31F0DE94B400281CEA44DBF4240E833A0DE8CE84B40655419C6DDBE4240E833A0DE8CE84B40
12895	1	37.491143000000001	37.494557	55.820712999999998	55.816799000000003	2-я Радиаторская	0103000020E61000000100000005000000655419C6DDBE4240E833A0DE8CE84B40655419C6DDBE42407633A31F0DE94B400281CEA44DBF42407633A31F0DE94B400281CEA44DBF4240E833A0DE8CE84B40655419C6DDBE4240E833A0DE8CE84B40
13171	1	37.729016999999999	37.729664	55.798313	55.791682999999999	2-я Пугачевская 	0103000020E61000000100000005000000309DD66D50DD42404BE658DE55E54B40309DD66D50DD42405F7CD11E2FE64B40C68844A165DD42405F7CD11E2FE64B40C68844A165DD42404BE658DE55E54B40309DD66D50DD42404BE658DE55E54B40
40897	30445	66.774443000000005	67.829100999999994	66.803721999999993	66.384331000000003	Школьная	0103000020E610000001000000050000006F675F7990B15040B2F50CE1989850406F675F7990B15040D844662E70B350402D05A4FD0FF55040D844662E70B350402D05A4FD0FF55040B2F50CE1989850406F675F7990B15040B2F50CE198985040
12679	1	37.729016999999999	37.729664	55.798313	55.791682999999999	2-я Пугачевская	0103000020E61000000100000005000000309DD66D50DD42404BE658DE55E54B40309DD66D50DD42405F7CD11E2FE64B40C68844A165DD42405F7CD11E2FE64B40C68844A165DD42404BE658DE55E54B40309DD66D50DD42404BE658DE55E54B40
4768	1	37.512495999999999	37.518830000000001	55.797134	55.793388999999998	2-я Песчаная улица	0103000020E6100000010000000500000058AA0B7899C14240C90050C58DE54B4058AA0B7899C14240CC43A67C08E64B4083177D0569C24240CC43A67C08E64B4083177D0569C24240C90050C58DE54B4058AA0B7899C14240C90050C58DE54B40
13005	1	37.683751000000001	37.691206999999999	55.880965000000003	55.874167999999997	2-я Напрудная	0103000020E61000000100000005000000BCCD1B2785D74240D89AADBCE4EF4B40BCCD1B2785D74240D8F50B76C3F04B4015E2917879D84240D8F50B76C3F04B4015E2917879D84240D89AADBCE4EF4B40BCCD1B2785D74240D89AADBCE4EF4B40
12680	1	37.777966999999997	37.782764	55.72419	55.719799999999999	2-я Институтская	0103000020E61000000100000005000000012F336C94E3424095D4096822DC4B40012F336C94E342408D0B0742B2DC4B403A3E5A9C31E442408D0B0742B2DC4B403A3E5A9C31E4424095D4096822DC4B40012F336C94E3424095D4096822DC4B40
1335	1	37.554887999999998	37.555157000000001	55.763969000000003	55.756335999999997	2-я Звенигородская улица	0103000020E61000000100000005000000AF78EA9106C74240CB64389ECFE04B40AF78EA9106C74240341477BCC9E14B409F9273620FC74240341477BCC9E14B409F9273620FC74240CB64389ECFE04B40AF78EA9106C74240CB64389ECFE04B40
13154	1	37.554887999999998	37.555157000000001	55.763969000000003	55.756335999999997	2-я Звенигородская 	0103000020E61000000100000005000000AF78EA9106C74240CB64389ECFE04B40AF78EA9106C74240341477BCC9E14B409F9273620FC74240341477BCC9E14B409F9273620FC74240CB64389ECFE04B40AF78EA9106C74240CB64389ECFE04B40
13153	1	37.554887999999998	37.555157000000001	55.763969000000003	55.756335999999997	2-я Звенигородская	0103000020E61000000100000005000000AF78EA9106C74240CB64389ECFE04B40AF78EA9106C74240341477BCC9E14B409F9273620FC74240341477BCC9E14B409F9273620FC74240CB64389ECFE04B40AF78EA9106C74240CB64389ECFE04B40
12660	1	37.670160000000003	37.672548999999997	55.729767000000002	55.726202999999998	2-я Дубровская	0103000020E610000001000000050000002F8B89CDC7D54240E8A04B38F4DC4B402F8B89CDC7D542409B594B0169DD4B408FFAEB1516D642409B594B0169DD4B408FFAEB1516D64240E8A04B38F4DC4B402F8B89CDC7D54240E8A04B38F4DC4B40
7650	1	37.701664000000001	37.703235999999997	55.814253999999998	55.812494000000001	2-я Гражданская улица	0103000020E61000000100000005000000E9633E20D0D942401E19ABCDFFE74B40E9633E20D0D942408F519E7939E84B4057AF22A303DA42408F519E7939E84B4057AF22A303DA42401E19ABCDFFE74B40E9633E20D0D942401E19ABCDFFE74B40
12805	1	37.918194	37.939942000000002	55.696615000000001	55.686391	2-я Вольская	0103000020E6100000010000000500000014B1886187F5424066A208A9DBD74B4014B1886187F54240977329AE2AD94B408411FB0450F84240977329AE2AD94B408411FB0450F8424066A208A9DBD74B4014B1886187F5424066A208A9DBD74B40
13138	1	37.776843999999997	37.789437999999997	55.763345999999999	55.742868999999999	2-я Владимирская	0103000020E61000000100000005000000020CCB9F6FE342402A1BD65416DF4B40020CCB9F6FE3424026C45C52B5E14B401D1CEC4D0CE5424026C45C52B5E14B401D1CEC4D0CE542402A1BD65416DF4B40020CCB9F6FE342402A1BD65416DF4B40
5578	1	37.674363999999997	37.699399999999997	55.704616000000001	55.698929	2-й Южнопортовый проезд	0103000020E61000000100000005000000C4CC3E8F51D64240ED9C668176D94B40C4CC3E8F51D64240821E6ADB30DA4B4044696FF085D94240821E6ADB30DA4B4044696FF085D94240ED9C668176D94B40C4CC3E8F51D64240ED9C668176D94B40
6335	1	37.617015000000002	37.621569999999998	55.703789	55.703052999999997	2-й Тульский переулок	0103000020E610000001000000050000001B12F758FACE4240662D05A4FDD94B401B12F758FACE42406C2409C215DA4B405D16139B8FCF42406C2409C215DA4B405D16139B8FCF4240662D05A4FDD94B401B12F758FACE4240662D05A4FDD94B40
884	1	37.620851000000002	37.622692999999998	55.776598	55.774715	2-й Троицкий переулок	0103000020E610000001000000050000002E58AA0B78CF42403E5C72DC29E34B402E58AA0B78CF4240CB11329067E34B405C397B67B4CF4240CB11329067E34B405C397B67B4CF42403E5C72DC29E34B402E58AA0B78CF42403E5C72DC29E34B40
5127	1	37.532547000000001	37.538826	55.732509	55.730683999999997	2-й Сетуньский проезд	0103000020E610000001000000050000009D4A06802AC44240F0DAA50D87DD4B409D4A06802AC442404983DBDAC2DD4B40041E1840F8C442404983DBDAC2DD4B40041E1840F8C44240F0DAA50D87DD4B409D4A06802AC44240F0DAA50D87DD4B40
6918	1	37.641944000000002	37.645510000000002	55.834871	55.831555000000002	2-й Сельскохозяйственный проезд	0103000020E6100000010000000500000085EE92382BD24240A3E9EC6470EA4B4085EE92382BD242407DB08C0DDDEA4B40D89E5912A0D242407DB08C0DDDEA4B40D89E5912A0D24240A3E9EC6470EA4B4085EE92382BD24240A3E9EC6470EA4B40
2054	1	37.600873	37.605840000000001	55.743156999999997	55.741318	2-й Обыденский переулок	0103000020E6100000010000000500000053060E68E9CC4240D3F71A82E3DE4B4053060E68E9CC42409065C1C41FDF4B40E84D452A8CCD42409065C1C41FDF4B40E84D452A8CCD4240D3F71A82E3DE4B4053060E68E9CC4240D3F71A82E3DE4B40
840	1	37.663547999999999	37.668928999999999	55.784025	55.781995000000002	2-й Красносельский переулок	0103000020E61000000100000005000000C1A90F24EFD442405951836918E44B40C1A90F24EFD442408A1F63EE5AE44B40492C29779FD542408A1F63EE5AE44B40492C29779FD542405951836918E44B40C1A90F24EFD442405951836918E44B40
4726	1	37.752957000000002	37.753461000000001	55.731475000000003	55.728605999999999	2-й Карачаровский проезд	0103000020E61000000100000005000000AB251DE560E04240AED51EF642DD4B40AB251DE560E04240BA6B09F9A0DD4B40DEE7F86871E04240BA6B09F9A0DD4B40DEE7F86871E04240AED51EF642DD4B40AB251DE560E04240AED51EF642DD4B40
6317	1	37.600603	37.606451	55.709535000000002	55.708089999999999	2-й Верхний Михайловский проезд	0103000020E610000001000000050000009370218FE0CC4240F44F70B1A2DA4B409370218FE0CC4240062FFA0AD2DA4B4031D0B52FA0CD4240062FFA0AD2DA4B4031D0B52FA0CD4240F44F70B1A2DA4B409370218FE0CC4240F44F70B1A2DA4B40
2700	1	37.522844999999997	37.525278999999998	55.809787999999998	55.806849	2-й Балтийский переулок	0103000020E6100000010000000500000045F0BF95ECC24240B8E7F9D346E74B4045F0BF95ECC24240BC581822A7E74B4046239F573CC34240BC581822A7E74B4046239F573CC34240B8E7F9D346E74B4045F0BF95ECC24240B8E7F9D346E74B40
12353	1	37.818705000000001	37.830266000000002	55.812823000000002	55.788874	16-я Парковая	0103000020E610000001000000050000002D095053CBE842401555BFD2F9E44B402D095053CBE84240E33785950AE84B40897D022846EA4240E33785950AE84B40897D022846EA42401555BFD2F9E44B402D095053CBE842401555BFD2F9E44B40
12405	1	37.816440999999998	37.819387999999996	55.811315	55.788874	15-я Парковая улица	0103000020E61000000100000005000000880E812381E842401555BFD2F9E44B40880E812381E842408BE07F2BD9E74B400F5EBBB4E1E842408BE07F2BD9E74B400F5EBBB4E1E842401555BFD2F9E44B40880E812381E842401555BFD2F9E44B40
12349	1	37.811689000000001	37.812578999999999	55.810586999999998	55.793433999999998	13-я Парковая улица	0103000020E61000000100000005000000F0C2D66CE5E7424069C4CC3E8FE54B40F0C2D66CE5E7424008C89750C1E74B404C35B39602E8424008C89750C1E74B404C35B39602E8424069C4CC3E8FE54B40F0C2D66CE5E7424069C4CC3E8FE54B40
13210	1	37.780957999999998	37.783921999999997	55.716645999999997	55.713242999999999	12-я Новокузьминская	0103000020E6100000010000000500000058C6866EF6E34240EB8CEF8B4BDB4B4058C6866EF6E3424094675E0EBBDB4B40B54E5C8E57E4424094675E0EBBDB4B40B54E5C8E57E44240EB8CEF8B4BDB4B4058C6866EF6E34240EB8CEF8B4BDB4B40
13219	1	37.731541999999997	37.745358000000003	55.707725000000003	55.704158999999997	11-я Текстильщиков	0103000020E6100000010000000500000041D3122BA3DD42408F17D2E121DA4B4041D3122BA3DD4240E3C798BB96DA4B40EFE714E467DF4240E3C798BB96DA4B40EFE714E467DF42408F17D2E121DA4B4041D3122BA3DD42408F17D2E121DA4B40
12338	1	37.804718000000001	37.805804999999999	55.810329000000003	55.788868999999998	11-я Парковая улица	0103000020E610000001000000050000005340DAFF00E7424003EACDA8F9E44B405340DAFF00E742400D0055DCB8E74B4005FA449E24E742400D0055DCB8E74B4005FA449E24E7424003EACDA8F9E44B405340DAFF00E7424003EACDA8F9E44B40
12359	1	37.804718000000001	37.805804999999999	55.810329000000003	55.788868999999998	11-я Парковая	0103000020E610000001000000050000005340DAFF00E7424003EACDA8F9E44B405340DAFF00E742400D0055DCB8E74B4005FA449E24E742400D0055DCB8E74B4005FA449E24E7424003EACDA8F9E44B405340DAFF00E7424003EACDA8F9E44B40
5242	1	37.732529999999997	37.742097000000001	55.701718999999997	55.700938000000001	1-я улица Текстильщиков	0103000020E6100000010000000500000060AB048BC3DD424007431D56B8D94B4060AB048BC3DD4240ACFD9DEDD1D94B40D8BAD408FDDE4240ACFD9DEDD1D94B40D8BAD408FDDE424007431D56B8D94B4060AB048BC3DD424007431D56B8D94B40
5434	1	37.665120000000002	37.678342999999998	55.715910000000001	55.713729999999998	1-я улица Машиностроения	0103000020E6100000010000000500000030F5F3A622D54240481630815BDB4B4030F5F3A622D542408F705AF0A2DB4B403A3C84F1D3D642408F705AF0A2DB4B403A3C84F1D3D64240481630815BDB4B4030F5F3A622D54240481630815BDB4B40
13112	1	37.732529999999997	37.742097000000001	55.701718999999997	55.700938000000001	1-я Текстильщиков	0103000020E6100000010000000500000060AB048BC3DD424007431D56B8D94B4060AB048BC3DD4240ACFD9DEDD1D94B40D8BAD408FDDE4240ACFD9DEDD1D94B40D8BAD408FDDE424007431D56B8D94B4060AB048BC3DD424007431D56B8D94B40
13229	1	37.777391999999999	37.778855999999998	55.792133999999997	55.788043999999999	1-я Парковая	0103000020E610000001000000050000000516C09481E342408EE733A0DEE44B400516C09481E342405B069CA564E54B408D25AC8DB1E342405B069CA564E54B408D25AC8DB1E342408EE733A0DEE44B400516C09481E342408EE733A0DEE44B40
12847	1	37.602426999999999	37.634371000000002	55.824480999999999	55.822978999999997	1-я Останкинская	0103000020E610000001000000050000001B9DF3531CCD4240BB25396057E94B401B9DF3531CCD42403196E99788E94B40F243A51133D142403196E99788E94B40F243A51133D14240BB25396057E94B401B9DF3531CCD4240BB25396057E94B40
5080	1	37.779556999999997	37.796031999999997	55.718359	55.712670000000003	1-я Новокузьминская улица	0103000020E61000000100000005000000162F1686C8E34240906B43C538DB4B40162F1686C8E34240C5E40D30F3DB4B40E4486760E4E54240C5E40D30F3DB4B40E4486760E4E54240906B43C538DB4B40162F1686C8E34240906B43C538DB4B40
13215	1	37.779556999999997	37.796031999999997	55.718359	55.712670000000003	1-я Новокузьминская	0103000020E61000000100000005000000162F1686C8E34240906B43C538DB4B40162F1686C8E34240C5E40D30F3DB4B40E4486760E4E54240C5E40D30F3DB4B40E4486760E4E54240906B43C538DB4B40162F1686C8E34240906B43C538DB4B40
12898	1	37.702489999999997	37.712533000000001	55.818264999999997	55.816814000000001	1-я Мясниковская	0103000020E610000001000000050000002EE23B31EBD942401D75745C8DE84B402EE23B31EBD94240103B53E8BCE84B400F29064834DB4240103B53E8BCE84B400F29064834DB42401D75745C8DE84B402EE23B31EBD942401D75745C8DE84B40
1823	1	37.592680000000001	37.598402	55.781109000000001	55.778283999999999	1-я Миусская улица	0103000020E61000000100000005000000247F30F0DCCB4240028063CF9EE34B40247F30F0DCCB42403ECE3461FBE34B4035EECD6F98CC42403ECE3461FBE34B4035EECD6F98CC4240028063CF9EE34B40247F30F0DCCB4240028063CF9EE34B40
5390	1	37.667591000000002	37.674579000000001	55.731850000000001	55.720809000000003	1-я Дубровская улица	0103000020E610000001000000050000004E0D349F73D54240CCD4247843DC4B404E0D349F73D54240EFC9C342ADDD4B40C1C8CB9A58D64240EFC9C342ADDD4B40C1C8CB9A58D64240CCD4247843DC4B404E0D349F73D54240CCD4247843DC4B40
13110	1	37.667591000000002	37.674579000000001	55.731850000000001	55.720809000000003	1-я Дубровская	0103000020E610000001000000050000004E0D349F73D54240CCD4247843DC4B404E0D349F73D54240EFC9C342ADDD4B40C1C8CB9A58D64240EFC9C342ADDD4B40C1C8CB9A58D64240CCD4247843DC4B404E0D349F73D54240CCD4247843DC4B40
12809	1	37.703451000000001	37.711472999999998	55.811872000000001	55.806085000000003	1-я Гражданская	0103000020E6100000010000000500000054ABAFAE0ADA4240E96514CB2DE74B4054ABAFAE0ADA4240E144F46BEBE74B40567E198C11DB4240E144F46BEBE74B40567E198C11DB4240E96514CB2DE74B4054ABAFAE0ADA4240E96514CB2DE74B40
12496	1	37.9131	37.929000000000002	55.683670999999997	55.683036000000001	1-я Вольская	0103000020E6100000010000000500000022FDF675E0F44240CEFE40B96DD74B4022FDF675E0F442409F1C058882D74B40F4FDD478E9F642409F1C058882D74B40F4FDD478E9F64240CEFE40B96DD74B4022FDF675E0F44240CEFE40B96DD74B40
1663	1	37.771875999999999	37.782179999999997	55.762348000000003	55.745883999999997	1-я Владимирская улица	0103000020E610000001000000050000009D4830D5CCE24240094E7D2079DF4B409D4830D5CCE24240E415889E94E14B40EACA67791EE44240E415889E94E14B40EACA67791EE44240094E7D2079DF4B409D4830D5CCE24240094E7D2079DF4B40
12524	1	37.771875999999999	37.782179999999997	55.762348000000003	55.745883999999997	1-я Владимирская	0103000020E610000001000000050000009D4830D5CCE24240094E7D2079DF4B409D4830D5CCE24240E415889E94E14B40EACA67791EE44240E415889E94E14B40EACA67791EE44240094E7D2079DF4B409D4830D5CCE24240094E7D2079DF4B40
12621	1	37.534630999999997	37.537073999999997	55.802805999999997	55.799649000000002	1-я Аэропортовская	0103000020E61000000100000005000000C136E2C96EC44240BAA3FFE55AE64B40C136E2C96EC442402B84D558C2E64B4015C440D7BEC442402B84D558C2E64B4015C440D7BEC44240BAA3FFE55AE64B40C136E2C96EC44240BAA3FFE55AE64B40
6491	1	37.616225	37.624156999999997	55.794578000000001	55.794361000000002	1-й проезд Марьиной Рощи	0103000020E6100000010000000500000022FDF675E0CE4240E31B0A9FADE54B4022FDF675E0CE4240800F5EBBB4E54B40E4486760E4CF4240800F5EBBB4E54B40E4486760E4CF4240E31B0A9FADE54B4022FDF675E0CE4240E31B0A9FADE54B40
2173	1	37.571426000000002	37.575774000000003	55.739468000000002	55.736341000000003	1-й переулок Тружеников	0103000020E61000000100000005000000C40AB77C24C942401BDA006C40DE4B40C40AB77C24C9424022382EE3A6DE4B408DF161F6B2C9424022382EE3A6DE4B408DF161F6B2C942401BDA006C40DE4B40C40AB77C24C942401BDA006C40DE4B40
703	1	37.627237999999998	37.633040999999999	55.724874999999997	55.721290000000003	1-й Щипковский переулок	0103000020E610000001000000050000007B67B45549D042404777103B53DC4B407B67B45549D04240105839B4C8DC4B407903CC7C07D14240105839B4C8DC4B407903CC7C07D142404777103B53DC4B407B67B45549D042404777103B53DC4B40
5218	1	37.544925999999997	37.550728999999997	55.777372999999997	55.773667000000003	1-й Хорошевский проезд	0103000020E61000000100000005000000BB5E9A22C0C542404A7F2F8507E34B40BB5E9A22C0C542408EE55DF580E34B40B9FAB1497EC642408EE55DF580E34B40B9FAB1497EC642404A7F2F8507E34B40BB5E9A22C0C542404A7F2F8507E34B40
6596	1	37.416879999999999	37.423167999999997	55.833471000000003	55.833131999999999	1-й Тушинский проезд	0103000020E61000000100000005000000A12DE7525CB5424023A0C211A4EA4B40A12DE7525CB542400C957F2DAFEA4B405B5B785E2AB642400C957F2DAFEA4B405B5B785E2AB6424023A0C211A4EA4B40A12DE7525CB5424023A0C211A4EA4B40
559	1	37.627633000000003	37.635430999999997	55.735191	55.734257999999997	1-й Новокузнецкий переулок	0103000020E61000000100000005000000F871344756D04240C669882AFCDD4B40F871344756D0424022A81ABD1ADE4B40AAEE91CD55D1424022A81ABD1ADE4B40AAEE91CD55D14240C669882AFCDD4B40F871344756D04240C669882AFCDD4B40
2128	1	37.577184000000003	37.584612999999997	55.741303000000002	55.740568000000003	1-й Неопалимовский переулок	0103000020E6100000010000000500000022E3512AE1C94240693BA6EECADE4B4022E3512AE1C942409EB64604E3DE4B4081E84999D4CA42409EB64604E3DE4B4081E84999D4CA4240693BA6EECADE4B4022E3512AE1C94240693BA6EECADE4B40
6577	1	37.632106999999998	37.634407000000003	55.683315	55.674118	1-й Нагатинский проезд	0103000020E610000001000000050000004D49D6E1E8D042408DD2A57F49D64B404D49D6E1E8D04240E1EEACDD76D74B403FADA23F34D14240E1EEACDD76D74B403FADA23F34D142408DD2A57F49D64B404D49D6E1E8D042408DD2A57F49D64B40
4918	1	37.696382	37.703263	55.657068000000002	55.654777000000003	1-й Курьяновский проезд	0103000020E61000000100000005000000F4C29D0B23D94240259694BBCFD34B40F4C29D0B23D94240C39FE1CD1AD44B4051BEA08504DA4240C39FE1CD1AD44B4051BEA08504DA4240259694BBCFD34B40F4C29D0B23D94240259694BBCFD34B40
13190	1	37.657808000000003	37.666530999999999	55.708744000000003	55.704234999999997	1-й Кожуховский	0103000020E610000001000000050000000A86730D33D442406AD95A5F24DA4B400A86730D33D442403D9E961FB8DA4B40956247E350D542403D9E961FB8DA4B40956247E350D542406AD95A5F24DA4B400A86730D33D442406AD95A5F24DA4B40
1818	1	37.703676000000002	37.705311000000002	55.802441999999999	55.798282	1-й Зборовский переулок	0103000020E61000000100000005000000747D1F0E12DA4240247EC51A2EE64B40747D1F0E12DA4240EA77616BB6E64B4029417FA147DA4240EA77616BB6E64B4029417FA147DA4240247EC51A2EE64B40747D1F0E12DA4240247EC51A2EE64B40
2168	1	37.571308999999999	37.575774000000003	55.739635	55.739387000000001	1-й Вражский переулок	0103000020E610000001000000050000008A743FA720C94240350BB43BA4DE4B408A743FA720C942400DFD135CACDE4B408DF161F6B2C942400DFD135CACDE4B408DF161F6B2C94240350BB43BA4DE4B408A743FA720C94240350BB43BA4DE4B40
7426	1	37.488484	37.492725	55.804490999999999	55.800423000000002	1-й Волоколамский проезд	0103000020E61000000100000005000000444FCAA486BE4240ADFBC74274E64B40444FCAA486BE42409276A38FF9E64B40F775E09C11BF42409276A38FF9E64B40F775E09C11BF4240ADFBC74274E64B40444FCAA486BE4240ADFBC74274E64B40
5046	1	37.786878000000002	37.794108999999999	55.725234999999998	55.722791000000001	1-й Вешняковский проезд	0103000020E6100000010000000500000090F8156BB8E44240EC6B5D6A84DC4B4090F8156BB8E4424010751F80D4DC4B40C93A1C5DA5E5424010751F80D4DC4B40C93A1C5DA5E54240EC6B5D6A84DC4B4090F8156BB8E44240EC6B5D6A84DC4B40
2929	1	37.554519999999997	37.562379999999997	55.786931000000003	55.781751999999997	1-й Боткинский проезд	0103000020E610000001000000050000002C7DE882FAC6424092CA147310E44B402C7DE882FAC64240B39AAE27BAE44B4055F65D11FCC74240B39AAE27BAE44B4055F65D11FCC7424092CA147310E44B402C7DE882FAC6424092CA147310E44B40
7030	1	37.633913	37.635440000000003	55.852536000000001	55.846406000000002	1-й Ботанический проезд	0103000020E610000001000000050000002FC1A90F24D14240B091240857EC4B402FC1A90F24D14240D2544FE61FED4B40FE48111956D14240D2544FE61FED4B40FE48111956D14240B091240857EC4B402FC1A90F24D14240B091240857EC4B40
2734	1	37.530669000000003	37.537685000000003	55.811407000000003	55.811132999999998	1-й Амбулаторный проезд	0103000020E61000000100000005000000220038F6ECC342406ADAC534D3E74B40220038F6ECC342406C5F402FDCE74B405F46B1DCD2C442406C5F402FDCE74B405F46B1DCD2C442406ADAC534D3E74B40220038F6ECC342406ADAC534D3E74B40
13050	1	37.9131	37.929000000000002	55.683670999999997	55.683036000000001	1-ая Вольская	0103000020E6100000010000000500000022FDF675E0F44240CEFE40B96DD74B4022FDF675E0F442409F1C058882D74B40F4FDD478E9F642409F1C058882D74B40F4FDD478E9F64240CEFE40B96DD74B4022FDF675E0F44240CEFE40B96DD74B40
12518	1	37.732861999999997	37.791342	55.701227000000003	55.696762999999997	 Юных Ленинцев	0103000020E61000000100000005000000963D096CCEDD42400B08AD872FD94B40963D096CCEDD42403E096CCEC1D94B40C2F9D4B14AE542403E096CCEC1D94B40C2F9D4B14AE542400B08AD872FD94B40963D096CCEDD42400B08AD872FD94B40
13177	1	37.548932000000001	37.577516000000003	55.727576999999997	55.715255999999997	 Хамовнический Вал	0103000020E610000001000000050000002BDD5D6743C64240462234828DDB4B402BDD5D6743C6424030293E3E21DD4B405875560BECC9424030293E3E21DD4B405875560BECC94240462234828DDB4B402BDD5D6743C64240462234828DDB4B40
13120	1	37.774346000000001	37.794530999999999	55.716853	55.7074	 Федора Полетаева	0103000020E61000000100000005000000EBE40CC51DE342405F984C158CDA4B40EBE40CC51DE342400E85CFD6C1DB4B403F541A31B3E542400E85CFD6C1DB4B403F541A31B3E542405F984C158CDA4B40EBE40CC51DE342405F984C158CDA4B40
12763	1	37.584055999999997	37.592159000000002	55.737588000000002	55.732219999999998	 Тимура Фрунзе	0103000020E610000001000000050000002B84D558C2CA424012BD8C62B9DD4B402B84D558C2CA424006F6984869DE4B401B84B9DDCBCB424006F6984869DE4B401B84B9DDCBCB424012BD8C62B9DD4B402B84D558C2CA424012BD8C62B9DD4B40
12957	1	37.679017000000002	37.684272	55.710641000000003	55.705101999999997	 Петра Романова	0103000020E61000000100000005000000CA367007EAD642400E2C47C840DA4B40CA367007EAD642402F19C748F6DA4B40C5C8923996D742402F19C748F6DA4B40C5C8923996D742400E2C47C840DA4B40CA367007EAD642400E2C47C840DA4B40
12906	1	37.806694999999998	37.838765000000002	55.729407000000002	55.718674	 Молдагуловой	0103000020E61000000100000005000000616C21C841E74240253E7782FDDB4B40616C21C841E742409B3C65355DDD4B40C503CAA65CEB42409B3C65355DDD4B40C503CAA65CEB4240253E7782FDDB4B40616C21C841E74240253E7782FDDB4B40
12918	1	37.577300999999999	37.589958000000003	55.834395999999998	55.821548	 Милашенкова	0103000020E610000001000000050000005B79C9FFE4C942400F0C207C28E94B405B79C9FFE4C94240E4F4F57CCDEA4B40BD0166BE83CB4240E4F4F57CCDEA4B40BD0166BE83CB42400F0C207C28E94B405B79C9FFE4C942400F0C207C28E94B40
12881	1	37.776161000000002	37.795411999999999	55.675448000000003	55.652876999999997	 Марьинский Парк	0103000020E6100000010000000500000020B75F3E59E34240C1A7397991D34B4020B75F3E59E3424006137F1475D64B40486C770FD0E5424006137F1475D64B40486C770FD0E54240C1A7397991D34B4020B75F3E59E34240C1A7397991D34B40
13084	1	37.482968999999997	37.496237000000001	55.800528999999997	55.795245999999999	 Маршала Рыбалко	0103000020E61000000100000005000000ACFD9DEDD1BD42402D23F59ECAE54B40ACFD9DEDD1BD4240F23FF9BB77E64B405708ABB184BF4240F23FF9BB77E64B405708ABB184BF42402D23F59ECAE54B40ACFD9DEDD1BD42402D23F59ECAE54B40
12468	1	37.696129999999997	37.710619999999999	55.624251000000001	55.617306999999997	 Маршала Захарова	0103000020E61000000100000005000000DAE1AFC91AD94240C24B70EA03CF4B40DAE1AFC91AD9424066BFEE74E7CF4B4017F19D98F5DA424066BFEE74E7CF4B4017F19D98F5DA4240C24B70EA03CF4B40DAE1AFC91AD94240C24B70EA03CF4B40
13036	1	37.508265000000002	37.517563000000003	55.795124999999999	55.777191000000002	 Куусинена	0103000020E61000000100000005000000C959D8D30EC142406EDFA3FE7AE34B40C959D8D30EC14240B29DEFA7C6E54B40514F1F813FC24240B29DEFA7C6E54B40514F1F813FC242406EDFA3FE7AE34B40C959D8D30EC142406EDFA3FE7AE34B40
12485	1	37.578809999999997	37.609226999999997	55.613366999999997	55.605148999999997	 Красного Маяка	0103000020E61000000100000005000000834C327216CA4240821ABE8575CD4B40834C327216CA42400AB952CF82CE4B408B6B7C26FBCD42400AB952CF82CE4B408B6B7C26FBCD4240821ABE8575CD4B40834C327216CA4240821ABE8575CD4B40
12711	1	37.600397000000001	37.613826000000003	55.591985999999999	55.588963999999997	 Газопровод	0103000020E61000000100000005000000EACE13CFD9CC4240BB421F2C63CB4B40EACE13CFD9CC42404DD87E32C6CB4B409EB7B1D991CE42404DD87E32C6CB4B409EB7B1D991CE4240BB421F2C63CB4B40EACE13CFD9CC4240BB421F2C63CB4B40
12976	1	37.688538999999999	37.775342999999999	55.644105000000003	55.635202999999997	 Борисовские Пруды	0103000020E61000000100000005000000A182C30B22D8424019A9F7544ED14B40A182C30B22D8424055185B0872D24B405D177E703EE3424055185B0872D24B405D177E703EE3424019A9F7544ED14B40A182C30B22D8424019A9F7544ED14B40
13068	1	37.342238999999999	37.372584000000003	55.861499000000002	55.839359999999999	 Барышиха	0103000020E610000001000000050000003735D07CCEAB424008C9022670EB4B403735D07CCEAB4240B344679945EE4B40A6811FD5B0AF4240B344679945EE4B40A6811FD5B0AF424008C9022670EB4B403735D07CCEAB424008C9022670EB4B40
12893	1	37.450594000000002	37.464112999999998	55.808709999999998	55.802953000000002	 Академика Бочвара	0103000020E610000001000000050000000DE36E10ADB94240D09CF529C7E64B400DE36E10ADB942405DF92CCF83E74B400053060E68BB42405DF92CCF83E74B400053060E68BB4240D09CF529C7E64B400DE36E10ADB94240D09CF529C7E64B40
13200	1	37.466745000000003	37.478127000000001	55.670163000000002	55.642955999999998	 Академика Анохина	0103000020E610000001000000050000002849D74CBEBB42402C62D8614CD24B402849D74CBEBB4240A0FEB3E6C7D54B40D42AFA4333BD4240A0FEB3E6C7D54B40D42AFA4333BD42402C62D8614CD24B402849D74CBEBB42402C62D8614CD24B40
12916	1	37.554250000000003	37.561121999999997	55.775149999999996	55.754080999999999	 1905 Года	0103000020E610000001000000050000006DE7FBA9F1C642407AC4E8B985E04B406DE7FBA9F1C6424048BF7D1D38E34B4076887FD8D2C7424048BF7D1D38E34B4076887FD8D2C742407AC4E8B985E04B406DE7FBA9F1C642407AC4E8B985E04B40
40405	54908	77.260836999999995	78.315494999999999	65.142611000000002	64.695008999999999	Ленина	0103000020E610000001000000050000008D25AC8DB15053403E5B07077B2C50408D25AC8DB15053403143E389204950404CC3F011319453403143E389204950404CC3F011319453403E5B07077B2C50408D25AC8DB15053403E5B07077B2C5040
40644	54908	77.260836999999995	78.315494999999999	65.142611000000002	64.695008999999999	Губкина	0103000020E610000001000000050000008D25AC8DB15053403E5B07077B2C50408D25AC8DB15053403143E389204950404CC3F011319453403143E389204950404CC3F011319453403E5B07077B2C50408D25AC8DB15053403E5B07077B2C5040
40308	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Чкалова	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
40448	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Титова	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
40587	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Республики	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
40594	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Маяковского	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
40824	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Матросова	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
40440	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Кооперативная	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
60208	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Комсомольская	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
40727	1053	66.075096000000002	67.129754000000005	66.740284000000003	66.319809000000006	Артеева	0103000020E61000000100000005000000DE03745FCE845040DBFD2AC077945040DE03745FCE845040227024D060AF50409DA1B8E34DC85040227024D060AF50409DA1B8E34DC85040DBFD2AC077945040DE03745FCE845040DBFD2AC077945040
40390	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Холмогорская	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40630	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Транспортная	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40383	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Советская	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40495	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Магистральная	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40399	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Лиственная	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40582	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Ленина	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40502	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Космонавтов	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40800	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Изыскателей	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40804	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Дружбы	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40386	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Дзержинского	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40424	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Высоцкого	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40504	54907	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	60 лет СССР	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40687	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	проспект Мира	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40790	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	проспект Ленинградский	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40380	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Юбилейный	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40896	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Энергетик	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40683	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Советский	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40370	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Приозерный	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40571	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Оптимистов	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40366	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Мирный	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40573	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Дружба	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40721	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Восточный	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40359	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Таежная	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40375	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Октябрьская	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40355	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Молодежная	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40796	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Звездная	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40681	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Губкина	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40909	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Газовиков	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40798	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Гагарина	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40786	54905	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	6 съезда КПСС	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40346	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	бульвар Стрижова	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40668	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	Пионерская	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40554	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	Парковая	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40420	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	Набережная им.Оруджева	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40413	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	Комсомольская	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40625	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	Зверева	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40416	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	Заводская	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40780	54904	72.016166999999996	73.070824999999999	65.753140000000002	65.315865000000002	Геологоразведчиков	0103000020E61000000100000005000000901150E108015240DE3CD52137545040901150E108015240CE531D72337050404FAF946588445240CE531D72337050404FAF946588445240DE3CD52137545040901150E108015240DE3CD52137545040
40513	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	площадь В.Нака	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40535	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	Школьная	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40333	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	Революции	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40607	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	Рабочая	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40328	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	Октябрьская	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40718	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	Корчагинцев	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40715	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	Дзержинского	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40407	24742	65.869452999999993	66.924110999999996	66.861812	66.443415000000002	Гиршгорна	0103000020E610000001000000050000002E1A321EA577504093E34EE9609C50402E1A321EA577504039D384ED27B75040EDB776A224BB504039D384ED27B75040EDB776A224BB504093E34EE9609C50402E1A321EA577504093E34EE9609C5040
40326	54903	62.001389000000003	86.014298999999994	73.524799999999999	62.203499999999998	микрорайон № 5	0103000020E610000001000000050000007EC9C6832D004F40355EBA490C1A4F407EC9C6832D004F40363CBD529661524064575A46EA805540363CBD529661524064575A46EA805540355EBA490C1A4F407EC9C6832D004F40355EBA490C1A4F40
40894	54903	62.001389000000003	86.014298999999994	73.524799999999999	62.203499999999998	4 микрорайон	0103000020E610000001000000050000007EC9C6832D004F40355EBA490C1A4F407EC9C6832D004F40363CBD529661524064575A46EA805540363CBD529661524064575A46EA805540355EBA490C1A4F407EC9C6832D004F40355EBA490C1A4F40
40855	54903	62.001389000000003	86.014298999999994	73.524799999999999	62.203499999999998	2 микрорайон	0103000020E610000001000000050000007EC9C6832D004F40355EBA490C1A4F407EC9C6832D004F40363CBD529661524064575A46EA805540363CBD529661524064575A46EA805540355EBA490C1A4F407EC9C6832D004F40355EBA490C1A4F40
40512	54903	62.001389000000003	86.014298999999994	73.524799999999999	62.203499999999998	14 микрорайон	0103000020E610000001000000050000007EC9C6832D004F40355EBA490C1A4F407EC9C6832D004F40363CBD529661524064575A46EA805540363CBD529661524064575A46EA805540355EBA490C1A4F407EC9C6832D004F40355EBA490C1A4F40
41252	55011	70.292021000000005	71.346678999999995	67.069590000000005	66.654747	Худи-Сэроко	0103000020E61000000100000005000000B22FD978B0925140DD09F65FE7A95040B22FD978B09251403C889D2974C4504070CD1DFD2FD651403C889D2974C4504070CD1DFD2FD65140DD09F65FE7A95040B22FD978B0925140DD09F65FE7A95040
41037	54999	70.724020999999993	71.778678999999997	67.110986999999994	66.696854000000002	Анагуричи	0103000020E6100000010000000500000080272D5C56AE51408E05854199AC504080272D5C56AE5140FED137691AC750403FC571E0D5F15140FED137691AC750403FC571E0D5F151408E05854199AC504080272D5C56AE51408E05854199AC5040
40707	52202	71.983566999999994	73.038224999999997	70.341596999999993	69.983427000000006	Вануйто	0103000020E61000000100000005000000309B00C3F2FE514038C0CC77F07E5140309B00C3F2FE514059DAA9B9DC955140EF3845477242524059DAA9B9DC955140EF3845477242524038C0CC77F07E5140309B00C3F2FE514038C0CC77F07E5140
40893	52189	68.631529999999998	69.686188000000001	66.965356999999997	66.548730000000006	Гагарина	0103000020E61000000100000005000000581CCEFC6A28514062156F641EA35040581CCEFC6A285140BDFDB968C8BD504017BA1281EA6B5140BDFDB968C8BD504017BA1281EA6B514062156F641EA35040581CCEFC6A28514062156F641EA35040
40833	686	69.573278999999999	70.627937000000003	66.959040000000002	66.542304999999999	Обская	0103000020E61000000100000005000000F31E679AB064514044DD0720B5A25040F31E679AB064514093E34EE960BD5040B2BCAB1E30A8514093E34EE960BD5040B2BCAB1E30A8514044DD0720B5A25040F31E679AB064514044DD0720B5A25040
40601	54939	72.377585999999994	73.432243999999997	67.892730999999998	67.492026999999993	Полярная	0103000020E610000001000000050000005B5B785E2A185240EF6FD05E7DDF50405B5B785E2A1852400648348122F950401AF9BCE2A95B52400648348122F950401AF9BCE2A95B5240EF6FD05E7DDF50405B5B785E2A185240EF6FD05E7DDF5040
77037	61043	73.068983000000003	74.123641000000006	68.661891999999995	68.274473	Геологов	0103000020E61000000100000005000000B83EAC376A445240A4A833F790115140B83EAC376A445240FA5E43705C2A514077DCF0BBE9875240FA5E43705C2A514077DCF0BBE9875240A4A833F790115140B83EAC376A445240A4A833F790115140
40891	568	64.822664000000003	65.877323000000004	66.122738999999996	65.691739999999996	Центральная	0103000020E610000001000000050000002EE6E786A63450407155D977456C50402EE6E786A634504066BCADF4DA875040D5415E0F2678504066BCADF4DA875040D5415E0F267850407155D977456C50402EE6E786A63450407155D977456C5040
40920	477	65.394316000000003	66.448974000000007	66.051670000000001	65.619462999999996	Советская	0103000020E6100000010000000500000088122D793C59504040852348A567504088122D793C595040CC0BB08F4E83504047B071FDBB9C5040CC0BB08F4E83504047B071FDBB9C504040852348A567504088122D793C59504040852348A5675040
40871	412	63.45091	64.505567999999997	65.057985000000002	64.608956000000006	Кооперативная	0103000020E610000001000000050000003DB83B6BB7B94F40FE2C9622F92650403DB83B6BB7B94F4026AAB706B6435040DD79E2395B20504026AAB706B6435040DD79E2395B205040FE2C9622F92650403DB83B6BB7B94F40FE2C9622F9265040
40829	329	64.172769000000002	65.227427000000006	65.623081999999997	65.183603000000005	Комсомольская	0103000020E61000000100000005000000CF30B5A50E0B5040A41CCC26C04B5040CF30B5A50E0B50407B2E5393E06750408ECEF9298E4E50407B2E5393E06750408ECEF9298E4E5040A41CCC26C04B5040CF30B5A50E0B5040A41CCC26C04B5040
40941	281	65.201770999999994	66.256429999999995	65.216747999999995	64.770397000000003	Советская	0103000020E61000000100000005000000FF91E9D0E94C5040F0FB372F4E315040FF91E9D0E94C50404CDE0033DF4D5040A6ED5F59699050404CDE0033DF4D5040A6ED5F5969905040F0FB372F4E315040FF91E9D0E94C5040F0FB372F4E315040
60140	57607	62.001389000000003	69.060897999999995	66.868706000000003	64.023398999999998	Школьная	0103000020E610000001000000050000007EC9C6832D004F4095F0845E7F0150407EC9C6832D004F40B2F50CE198B750401399B9C0E5435140B2F50CE198B750401399B9C0E543514095F0845E7F0150407EC9C6832D004F4095F0845E7F015040
40481	230	64.748697000000007	65.803354999999996	65.280449000000004	64.835173999999995	Заводская	0103000020E610000001000000050000004167D2A6EA2F50400C1EA67D733550404167D2A6EA2F50408ACC5CE0F2515040FF04172B6A7350408ACC5CE0F2515040FF04172B6A7350400C1EA67D733550404167D2A6EA2F50400C1EA67D73355040
40906	168	64.058368999999999	65.113027000000002	65.790817000000004	65.354180999999997	Советская	0103000020E610000001000000050000006A865451BC03504055F7C8E6AA5650406A865451BC035040BC07E8BE9C725040292499D53B475040BC07E8BE9C725040292499D53B47504055F7C8E6AA5650406A865451BC03504055F7C8E6AA565040
40899	57	64.526157999999995	65.580815999999999	65.119459000000006	64.671467000000007	Школьная	0103000020E61000000100000005000000D7A19A92AC215040F855B950F92A5040D7A19A92AC215040A08D5C37A5475040963FDF162C655040A08D5C37A5475040963FDF162C655040F855B950F92A5040D7A19A92AC215040F855B950F92A5040
40889	32450	78.190027000000001	79.244685000000004	67.676620999999997	67.272197000000006	Пристанская	0103000020E61000000100000005000000D9960167298C53407044F7AC6BD15040D9960167298C53405BB22AC24DEB5040983446EBA8CF53405BB22AC24DEB5040983446EBA8CF53407044F7AC6BD15040D9960167298C53407044F7AC6BD15040
40881	32450	78.190027000000001	79.244685000000004	67.676620999999997	67.272197000000006	Почтовая	0103000020E61000000100000005000000D9960167298C53407044F7AC6BD15040D9960167298C53405BB22AC24DEB5040983446EBA8CF53405BB22AC24DEB5040983446EBA8CF53407044F7AC6BD15040D9960167298C53407044F7AC6BD15040
40886	32450	78.190027000000001	79.244685000000004	67.676620999999997	67.272197000000006	Пиеттомина	0103000020E61000000100000005000000D9960167298C53407044F7AC6BD15040D9960167298C53405BB22AC24DEB5040983446EBA8CF53405BB22AC24DEB5040983446EBA8CF53407044F7AC6BD15040D9960167298C53407044F7AC6BD15040
40828	32450	78.190027000000001	79.244685000000004	67.676620999999997	67.272197000000006	Ленина	0103000020E61000000100000005000000D9960167298C53407044F7AC6BD15040D9960167298C53405BB22AC24DEB5040983446EBA8CF53405BB22AC24DEB5040983446EBA8CF53407044F7AC6BD15040D9960167298C53407044F7AC6BD15040
40703	32450	78.190027000000001	79.244685000000004	67.676620999999997	67.272197000000006	Геофизиков	0103000020E61000000100000005000000D9960167298C53407044F7AC6BD15040D9960167298C53405BB22AC24DEB5040983446EBA8CF53405BB22AC24DEB5040983446EBA8CF53407044F7AC6BD15040D9960167298C53407044F7AC6BD15040
40860	52166	77.020915000000002	78.075573000000006	67.925881000000004	67.525746999999996	Подгорная	0103000020E61000000100000005000000BC3FDEAB5641534016BEBED6A5E15040BC3FDEAB5641534038BF61A241FB50407BDD2230D684534038BF61A241FB50407BDD2230D684534016BEBED6A5E15040BC3FDEAB5641534016BEBED6A5E15040
40725	52173	77.976605000000006	79.031262999999996	71.066760000000002	70.721312999999995	Советская	0103000020E610000001000000050000000C0742B2807E53407F4B00FE29AE51400C0742B2807E5340952BBCCB45C45140CAA4863600C25340952BBCCB45C45140CAA4863600C253407F4B00FE29AE51400C0742B2807E53407F4B00FE29AE5140
40704	52165	78.484179999999995	79.538837999999998	67.569817999999998	67.163556999999997	Молодежная	0103000020E6100000010000000500000025581CCEFC9E53400A82C7B777CA504025581CCEFC9E534004ABEAE577E45040E4F560527CE2534004ABEAE577E45040E4F560527CE253400A82C7B777CA504025581CCEFC9E53400A82C7B777CA5040
40428	52172	76.335779000000002	77.390437000000006	69.281743000000006	68.905079999999998	Ленина	0103000020E61000000100000005000000C0EB33677D155340E010AAD4EC395140C0EB33677D15534020B8CA13085251407F8978EBFC58534020B8CA13085251407F8978EBFC585340E010AAD4EC395140C0EB33677D155340E010AAD4EC395140
40903	52127	77.573036999999999	78.627695000000003	64.508906999999994	64.050640999999999	Айваседо Энтак	0103000020E61000000100000005000000789961A3AC6453408DB5BFB33D035040789961A3AC645340266DAAEE912050403737A6272CA85340266DAAEE912050403737A6272CA853408DB5BFB33D035040789961A3AC6453408DB5BFB33D035040
40699	52119	75.438846999999996	76.493504999999999	63.957341999999997	63.489837999999999	Молодежная	0103000020E61000000100000005000000A73CBA1116DC5240452BF702B3BE4F40A73CBA1116DC52402A8BC22E8AFA4F4066DAFE95951F53402A8BC22E8AFA4F4066DAFE95951F5340452BF702B3BE4F40A73CBA1116DC5240452BF702B3BE4F40
40317	52119	75.438846999999996	76.493504999999999	63.957341999999997	63.489837999999999	Мира	0103000020E61000000100000005000000A73CBA1116DC5240452BF702B3BE4F40A73CBA1116DC52402A8BC22E8AFA4F4066DAFE95951F53402A8BC22E8AFA4F4066DAFE95951F5340452BF702B3BE4F40A73CBA1116DC5240452BF702B3BE4F40
40901	52130	77.821646000000001	78.876304000000005	63.622031	63.148933	Лесная	0103000020E61000000100000005000000E9B81AD995745340C8258E3C10934F40E9B81AD995745340910C39B69ECF4F40A8565F5D15B85340910C39B69ECF4F40A8565F5D15B85340C8258E3C10934F40E9B81AD995745340C8258E3C10934F40
40692	30595	77.857164999999995	78.911822999999998	66.171627000000001	65.741459000000006	Геологов	0103000020E61000000100000005000000A79196CADB765340CB147310746F5040A79196CADB7653401407D0EFFB8A5040662FDB4E5BBA53401407D0EFFB8A5040662FDB4E5BBA5340CB147310746F5040A79196CADB765340CB147310746F5040
40690	30595	77.857164999999995	78.911822999999998	66.171627000000001	65.741459000000006	4 микрорайон	0103000020E61000000100000005000000A79196CADB765340CB147310746F5040A79196CADB7653401407D0EFFB8A5040662FDB4E5BBA53401407D0EFFB8A5040662FDB4E5BBA5340CB147310746F5040A79196CADB765340CB147310746F5040
40695	30595	77.857164999999995	78.911822999999998	66.171627000000001	65.741459000000006	3 микрорайон	0103000020E61000000100000005000000A79196CADB765340CB147310746F5040A79196CADB7653401407D0EFFB8A5040662FDB4E5BBA53401407D0EFFB8A5040662FDB4E5BBA5340CB147310746F5040A79196CADB765340CB147310746F5040
40434	54910	77.260836999999995	78.315494999999999	65.142611000000002	64.695008999999999	Мира	0103000020E610000001000000050000008D25AC8DB15053403E5B07077B2C50408D25AC8DB15053403143E389204950404CC3F011319453403143E389204950404CC3F011319453403E5B07077B2C50408D25AC8DB15053403E5B07077B2C5040
40939	1437	77.234551999999994	78.289209999999997	65.489253000000005	65.047507999999993	Железнодорожная	0103000020E61000000100000005000000874D64E6024F53401893FE5E0A435040874D64E6024F5340139ED0EB4F5F504046EBA86A82925340139ED0EB4F5F504046EBA86A829253401893FE5E0A435040874D64E6024F53401893FE5E0A435040
59752	57590	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	Победы	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
40697	52117	76.146072000000004	77.200729999999993	64.714893000000004	64.260086999999999	Молодежная	0103000020E6100000010000000500000020B75F3E5909534058C7F143A510504020B75F3E59095340EBC891CEC02D5040DE54A4C2D84C5340EBC891CEC02D5040DE54A4C2D84C534058C7F143A510504020B75F3E5909534058C7F143A5105040
40816	52117	76.146072000000004	77.200729999999993	64.714893000000004	64.260086999999999	Железнодорожная	0103000020E6100000010000000500000020B75F3E5909534058C7F143A510504020B75F3E59095340EBC891CEC02D5040DE54A4C2D84C5340EBC891CEC02D5040DE54A4C2D84C534058C7F143A510504020B75F3E5909534058C7F143A5105040
40799	30813	77.257064	78.311722000000003	65.534594999999996	65.093616999999995	переулок Школьный	0103000020E61000000100000005000000A73E90BC73505340605628D2FD455040A73E90BC73505340BA66F2CD3662504066DCD440F3935340BA66F2CD3662504066DCD440F3935340605628D2FD455040A73E90BC73505340605628D2FD455040
40884	30813	77.257064	78.311722000000003	65.534594999999996	65.093616999999995	Новая	0103000020E61000000100000005000000A73E90BC73505340605628D2FD455040A73E90BC73505340BA66F2CD3662504066DCD440F3935340BA66F2CD3662504066DCD440F3935340605628D2FD455040A73E90BC73505340605628D2FD455040
40637	1179	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Ленина	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
60157	1179	74.886579999999995	75.941237999999998	63.413006000000003	62.936427999999999	Аэропорт	0103000020E6100000010000000500000069520ABABDB85240838769DFDC774F4069520ABABDB85240A1866F61DDB44F4028F04E3E3DFC5240A1866F61DDB44F4028F04E3E3DFC5240838769DFDC774F4069520ABABDB85240838769DFDC774F40
40336	25275	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	Школьная	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
40632	25275	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	Украинских строителей	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
40546	25275	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	Пионерская	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
40666	25275	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	Муравленко	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
40634	25275	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	Ленина	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
40548	25275	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	Дружбы народов	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
40545	25275	73.991607000000002	75.046265000000005	64.007710000000003	63.541048000000004	Губкина	0103000020E6100000010000000500000005DF347D767F52407AC8940F41C54F4005DF347D767F52408A7615527E005040C47C7901F6C252408A7615527E005040C47C7901F6C252407AC8940F41C54F4005DF347D767F52407AC8940F41C54F40
40489	54902	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	9 микрорайон	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
40323	54902	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	7 микрорайон	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
59708	54902	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	6 микрорайон	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
59487	54902	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	3 микрорайон	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
59526	54902	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	14 микрорайон	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
40809	1281	65.284910999999994	66.339568999999997	67.008905999999996	66.593024999999997	Дзержинского	0103000020E6100000010000000500000052D158FB3B525040772D211FF4A5504052D158FB3B5250403EAF78EA91C05040116F9D7FBB9550403EAF78EA91C05040116F9D7FBB955040772D211FF4A5504052D158FB3B525040772D211FF4A55040
40585	30219	67.628309999999999	68.682968000000002	67.073307	66.658528000000004	Новая	0103000020E61000000100000005000000FC6F253B36E8504005E09F5225AA5040FC6F253B36E8504058E4D70FB1C45040BB0D6ABFB52B514058E4D70FB1C45040BB0D6ABFB52B514005E09F5225AA5040FC6F253B36E8504005E09F5225AA5040
40722	30192	67.265722999999994	68.320380999999998	66.770247999999995	66.350285	Первомайская	0103000020E61000000100000005000000E1B20A9B01D15040E1D1C6116B965040E1B20A9B01D15040CD7344BE4BB15040A0504F1F81145140CD7344BE4BB15040A0504F1F81145140E1D1C6116B965040E1B20A9B01D15040E1D1C6116B965040
40783	52952	73.957928999999993	75.012586999999996	66.063156000000006	65.631142999999994	Спортивная	0103000020E61000000100000005000000F5B86FB54E7D52405B069CA564685040F5B86FB54E7D5240F5A276BF0A845040B456B439CEC05240F5A276BF0A845040B456B439CEC052405B069CA564685040F5B86FB54E7D52405B069CA564685040
40676	52952	73.957928999999993	75.012586999999996	66.063156000000006	65.631142999999994	Ленина	0103000020E61000000100000005000000F5B86FB54E7D52405B069CA564685040F5B86FB54E7D5240F5A276BF0A845040B456B439CEC05240F5A276BF0A845040B456B439CEC052405B069CA564685040F5B86FB54E7D52405B069CA564685040
40507	52952	73.957928999999993	75.012586999999996	66.063156000000006	65.631142999999994	Газодобытчиков	0103000020E61000000100000005000000F5B86FB54E7D52405B069CA564685040F5B86FB54E7D5240F5A276BF0A845040B456B439CEC05240F5A276BF0A845040B456B439CEC052405B069CA564685040F5B86FB54E7D52405B069CA564685040
40636	54906	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Студенческий	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
41408	54906	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Солнечный	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
59656	54906	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Советский	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
67863	54906	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	мкр. Оптимистов	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40358	54906	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Юбилейная	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
60183	54906	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	Монтажников	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
40678	54906	76.175186999999994	77.229844999999997	66.307186000000002	65.879324999999994	26 съезда КПСС	0103000020E61000000100000005000000CCEB8843360B534088635DDC46785040CCEB8843360B534080F277EFA89350408B89CDC7B54E534080F277EFA89350408B89CDC7B54E534088635DDC46785040CCEB8843360B534088635DDC46785040
59668	54990	72.191608000000002	73.246266000000006	65.815297000000001	65.379075999999998	Ленинградский проспект	0103000020E61000000100000005000000BA69334E430C5240B4ACFBC742585040BA69334E430C5240B9E177D32D745040790778D2C24F5240B9E177D32D745040790778D2C24F5240B4ACFBC742585040BA69334E430C5240B4ACFBC742585040
40310	24655	79.578787000000005	80.633444999999995	63.632683999999998	63.159762999999998	Центральная	0103000020E610000001000000050000006616A1D80AE55340300E2E1D73944F406616A1D80AE55340EA5910CAFBD04F4024B4E55C8A285440EA5910CAFBD04F4024B4E55C8A285440300E2E1D73944F406616A1D80AE55340300E2E1D73944F40
40905	24708	83.336826000000002	84.391484000000005	63.818736999999999	63.348919000000002	Центральная	0103000020E61000000100000005000000529CA38E8ED55440FDF9B660A9AC4F40529CA38E8ED554403883BF5FCCE84F40113AE8120E1955403883BF5FCCE84F40113AE8120E195540FDF9B660A9AC4F40529CA38E8ED55440FDF9B660A9AC4F40
40604	24608	81.932210999999995	82.986868999999999	65.922922999999997	65.488529	Советская	0103000020E610000001000000050000002C7E5358A97B54407289230F445F50402C7E5358A97B54407A6EA12B117B5040EB1B98DC28BF54407A6EA12B117B5040EB1B98DC28BF54407289230F445F50402C7E5358A97B54407289230F445F5040
43624	55159	60.173344	60.291553	56.082908000000003	56.001801	Строителей	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
42962	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Яблочкова	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43482	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Энергетиков	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
42677	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Строителей	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
42669	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Спортивная	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43148	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Советской Армии	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43304	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Советская	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43369	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Парковая	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43399	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Павлова	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43355	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Московская	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
42938	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Ленина	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43398	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Куйбышева	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
43263	4212	61.224615	61.321300999999998	54.467568999999997	54.420008000000003	Космонавтов	0103000020E6100000010000000500000074982F2FC09C4E40790778D2C2354B4074982F2FC09C4E40CCCF0D4DD93B4B400796236420A94E40CCCF0D4DD93B4B400796236420A94E40790778D2C2354B4074982F2FC09C4E40790778D2C2354B40
521	66	61.402994	61.405132000000002	55.260781999999999	55.252347	улица Ярослава Гашека	0103000020E61000000100000005000000FB3DB14E95B34E40321F10E84CA04B40FB3DB14E95B34E4057B1F84D61A14B401348895DDBB34E4057B1F84D61A14B401348895DDBB34E40321F10E84CA04B40FB3DB14E95B34E40321F10E84CA04B40
42727	66	61.375056000000001	61.376483999999998	55.162092999999999	55.145740000000004	улица Энтузиастов	0103000020E610000001000000050000009415C3D501B04E400ADCBA9BA7924B409415C3D501B04E408CF4A276BF944B40CFBBB1A030B04E408CF4A276BF944B40CFBBB1A030B04E400ADCBA9BA7924B409415C3D501B04E400ADCBA9BA7924B40
43079	66	61.379187999999999	61.381658999999999	55.167735	55.147567000000002	улица Энгельса	0103000020E6100000010000000500000090847D3B89B04E40037CB779E3924B4090847D3B89B04E4081B2295778954B40AE9CBD33DAB04E4081B2295778954B40AE9CBD33DAB04E40037CB779E3924B4090847D3B89B04E40037CB779E3924B40
6501	66	61.517367	61.521642999999997	55.119712999999997	55.119224000000003	улица Угольная	0103000020E61000000100000005000000CB83F41439C24E40FC7266BB428F4B40CB83F41439C24E40F9F36DC1528F4B40FA97A432C5C24E40F9F36DC1528F4B40FA97A432C5C24E40FC7266BB428F4B40CB83F41439C24E40FC7266BB428F4B40
16068	66	61.410558000000002	61.416612000000001	55.173333999999997	55.138876000000003	улица Свободы	0103000020E610000001000000050000003B8E1F2A8DB44E40831953B0C6914B403B8E1F2A8DB44E4076A4FACE2F964B40828FC18A53B54E4076A4FACE2F964B40828FC18A53B54E40831953B0C6914B403B8E1F2A8DB44E40831953B0C6914B40
1197	66	61.436591	61.469433000000002	55.172218000000001	55.168388	улица Салютная	0103000020E610000001000000050000002D5DC136E2B74E40F984ECBC8D954B402D5DC136E2B74E402AE44A3D0B964B40E3546B6116BC4E402AE44A3D0B964B40E3546B6116BC4E40F984ECBC8D954B402D5DC136E2B74E40F984ECBC8D954B40
43030	66	61.425218000000001	61.445852000000002	55.148791000000003	55.140681999999998	улица Пограничная	0103000020E61000000100000005000000D4D51D8B6DB64E40649126DE01924B40D4D51D8B6DB64E4036785F950B934B40986DA7AD11B94E4036785F950B934B40986DA7AD11B94E40649126DE01924B40D4D51D8B6DB64E40649126DE01924B40
6283	66	61.397604000000001	61.409255000000002	55.247430999999999	55.245496000000003	улица Пекинская	0103000020E61000000100000005000000206118B0E4B24E4040A6B5696C9F4B40206118B0E4B24E401F82AAD1AB9F4B40BC5CC47762B44E401F82AAD1AB9F4B40BC5CC47762B44E4040A6B5696C9F4B40206118B0E4B24E4040A6B5696C9F4B40
1485	66	61.458429000000002	61.475729999999999	55.183785	55.179755	улица Октябрьская	0103000020E61000000100000005000000DD442DCDADBA4E4070253B3602974B40DD442DCDADBA4E40683F524486974B40F0DC7BB8E4BC4E40683F524486974B40F0DC7BB8E4BC4E4070253B3602974B40DD442DCDADBA4E4070253B3602974B40
43128	66	61.402985000000001	61.412596999999998	55.144047999999998	55.142046000000001	улица Овчинникова	0103000020E61000000100000005000000A8E3310395B34E40894336902E924B40A8E3310395B34E40F086342A70924B40BFB67EFACFB44E40F086342A70924B40BFB67EFACFB44E40894336902E924B40A8E3310395B34E40894336902E924B40
42692	66	61.418866999999999	61.495933000000001	55.119413999999999	55.095410000000001	улица Новороссийская	0103000020E61000000100000005000000D32F116F9DB54E400EDB1665368C4B40D32F116F9DB54E409F573CF5488F4B40EB0088BB7ABF4E409F573CF5488F4B40EB0088BB7ABF4E400EDB1665368C4B40D32F116F9DB54E400EDB1665368C4B40
6569	66	61.454656	61.470106999999999	55.120058	55.116844999999998	улица Масленникова	0103000020E610000001000000050000001077F52A32BA4E40BED9E6C6F48E4B401077F52A32BA4E40C4CF7F0F5E8F4B40724F57772CBC4E40C4CF7F0F5E8F4B40724F57772CBC4E40BED9E6C6F48E4B401077F52A32BA4E40BED9E6C6F48E4B40
1362	66	61.462812999999997	61.486798	55.175863999999997	55.172505999999998	улица Кулибина	0103000020E61000000100000005000000F294D5743DBB4E40902E36AD14964B40F294D5743DBB4E40994528B682964B400DE198654FBE4E40994528B682964B400DE198654FBE4E40902E36AD14964B40F294D5743DBB4E40902E36AD14964B40
6707	66	61.412489000000001	61.414231999999998	55.174429000000003	55.160848999999999	улица Красноармейская	0103000020E61000000100000005000000D97A8670CCB44E40124C35B396944B40D97A8670CCB44E40AC3C81B053964B40747ADE8D05B54E40AC3C81B053964B40747ADE8D05B54E40124C35B396944B40D97A8670CCB44E40124C35B396944B40
43138	66	61.374552999999999	61.383653000000002	55.118296999999998	55.104562999999999	улица Короленко	0103000020E6100000010000000500000031CF4A5AF1AF4E4092AF0452628D4B4031CF4A5AF1AF4E40821B295B248F4B409301A08A1BB14E40821B295B248F4B409301A08A1BB14E4092AF0452628D4B4031CF4A5AF1AF4E4092AF0452628D4B40
16016	66	61.398637000000001	61.400281	55.184401999999999	55.167786	улица Кирова	0103000020E61000000100000005000000DFFC868906B34E40035DFB027A954B40DFFC868906B34E4093A8177C9A974B40E71A66683CB34E4093A8177C9A974B40E71A66683CB34E40035DFB027A954B40DFFC868906B34E40035DFB027A954B40
1824	66	61.388027999999998	61.39481	55.197240000000001	55.174259999999997	улица Каслинская	0103000020E6100000010000000500000055F7C8E6AAB14E401F80D4264E964B4055F7C8E6AAB14E4045BB0A293F994B401F11532289B24E4045BB0A293F994B401F11532289B24E401F80D4264E964B4055F7C8E6AAB14E401F80D4264E964B40
162	66	61.297818999999997	61.318444	55.198811999999997	55.193765999999997	улица Захаренко	0103000020E610000001000000050000004F90D8EE1EA64E40D2890453CD984B404F90D8EE1EA64E40B306EFAB72994B40C0CDE2C5C2A84E40B306EFAB72994B40C0CDE2C5C2A84E40D2890453CD984B404F90D8EE1EA64E40D2890453CD984B40
562	66	61.390929	61.397531999999998	55.260007999999999	55.245953	улица Жукова	0103000020E610000001000000050000006C0723F609B24E4032AD4D637B9F4B406C0723F609B24E40645930F147A14B40868E1D54E2B24E40645930F147A14B40868E1D54E2B24E4032AD4D637B9F4B406C0723F609B24E4032AD4D637B9F4B40
42837	66	61.397658	61.398645999999999	55.167842999999998	55.146192999999997	улица Елькина	0103000020E61000000100000005000000137F1475E6B24E40BAF3C473B6924B40137F1475E6B24E4067EE21E17B954B40325706D506B34E4067EE21E17B954B40325706D506B34E40BAF3C473B6924B40137F1475E6B24E40BAF3C473B6924B40
423	66	61.396382000000003	61.402670000000001	55.274405999999999	55.240738999999998	улица Дегтярева	0103000020E610000001000000050000008E5C37A5BCB24E4095EF1989D09E4B408E5C37A5BCB24E40C0E95DBC1FA34B40488AC8B08AB34E40C0E95DBC1FA34B40488AC8B08AB34E4095EF1989D09E4B408E5C37A5BCB24E4095EF1989D09E4B40
6595	66	61.43289	61.438386999999999	55.177427000000002	55.161634999999997	улица Грибоедова	0103000020E61000000100000005000000FA6184F068B74E40C971A774B0944B40FA6184F068B74E40B5368DEDB5964B40EBFEB1101DB84E40B5368DEDB5964B40EBFEB1101DB84E40C971A774B0944B40FA6184F068B74E40C971A774B0944B40
1009	66	61.43112	61.442951000000001	55.192112000000002	55.160730000000001	улица Горького	0103000020E610000001000000050000006553AEF02EB74E4038BEF6CC92944B406553AEF02EB74E40A795422097984B40815D4D9EB2B84E40A795422097984B40815D4D9EB2B84E4038BEF6CC92944B406553AEF02EB74E4038BEF6CC92944B40
3752	66	61.433653	61.446840999999999	55.146799999999999	55.117050999999996	улица Гагарина	0103000020E61000000100000005000000F96706F181B74E40677BF486FB8E4B40F96706F181B74E40C286A757CA924B4087C1FC1532B94E40C286A757CA924B4087C1FC1532B94E40677BF486FB8E4B40F96706F181B74E40677BF486FB8E4B40
2695	66	61.448529000000001	61.450235999999997	55.167091999999997	55.157274000000001	улица 40 Лет Октября	0103000020E610000001000000050000005F27F56569B94E406C41EF8D21944B405F27F56569B94E402CB6494563954B40ADBD4F55A1B94E402CB6494563954B40ADBD4F55A1B94E406C41EF8D21944B405F27F56569B94E406C41EF8D21944B40
340	66	61.384830000000001	61.416198999999999	55.239666	55.234327	улица 26 Бакинских Комиссаров	0103000020E610000001000000050000008542041C42B14E40EFC8586DFE9D4B408542041C42B14E4048FB1F60AD9E4B405FD0420246B54E4048FB1F60AD9E4B405FD0420246B54E40EFC8586DFE9D4B408542041C42B14E40EFC8586DFE9D4B40
42956	66	61.514555999999999	61.516216999999997	55.121479000000001	55.118003999999999	улица 1-я Трубосварочная	0103000020E61000000100000005000000F4FA93F8DCC14E400A664CC11A8F4B40F4FA93F8DCC14E404D13B69F8C8F4B40D2510E6613C24E404D13B69F8C8F4B40D2510E6613C24E400A664CC11A8F4B40F4FA93F8DCC14E400A664CC11A8F4B40
43411	66	61.283994	61.466468999999996	55.192979999999999	55.178953	проспект Победы	0103000020E610000001000000050000004F2157EA59A44E40B34291EEE7964B404F2157EA59A44E401B649291B3984B4085CC9541B5BB4E401B649291B3984B4085CC9541B5BB4E40B34291EEE7964B404F2157EA59A44E40B34291EEE7964B40
42946	66	61.450361999999998	61.475802000000002	55.139113000000002	55.124876999999998	Энергетиков	0103000020E610000001000000050000003AAE4676A5B94E40E48233F8FB8F4B403AAE4676A5B94E4067B96C74CE914B408AAF7614E7BC4E4067B96C74CE914B408AAF7614E7BC4E40E48233F8FB8F4B403AAE4676A5B94E40E48233F8FB8F4B40
42882	66	61.379187999999999	61.381658999999999	55.167735	55.147567000000002	Энгельса	0103000020E6100000010000000500000090847D3B89B04E40037CB779E3924B4090847D3B89B04E4081B2295778954B40AE9CBD33DAB04E4081B2295778954B40AE9CBD33DAB04E40037CB779E3924B4090847D3B89B04E40037CB779E3924B40
43425	66	61.37988	61.403120000000001	55.252367999999997	55.252070000000003	Электростальская	0103000020E61000000100000005000000C63368E89FB04E40C0266BD443A04B40C63368E89FB04E40494739984DA04B40882EA86F99B34E40494739984DA04B40882EA86F99B34E40C0266BD443A04B40C63368E89FB04E40C0266BD443A04B40
43402	66	61.459094	61.463926000000001	55.177303000000002	55.170865999999997	Шуменская	0103000020E6100000010000000500000019E59997C3BA4E40C9FFE4EFDE954B4019E59997C3BA4E40C93D5DDDB1964B40CEE15AED61BB4E40C93D5DDDB1964B40CEE15AED61BB4E40C9FFE4EFDE954B4019E59997C3BA4E40C9FFE4EFDE954B40
42823	66	61.404961	61.411546000000001	55.141238000000001	55.140115999999999	Ширшова	0103000020E61000000100000005000000E69315C3D5B34E40BBD23252EF914B40E69315C3D5B34E40EA79371614924B405A66118AADB44E40EA79371614924B405A66118AADB44E40BBD23252EF914B40E69315C3D5B34E40BBD23252EF914B40
43415	66	61.397685000000003	61.398287000000003	55.191341000000001	55.187666	Шенкурская	0103000020E610000001000000050000000D8E9257E7B24E401B49827005984B400D8E9257E7B24E4025B1A4DC7D984B4003B68311FBB24E4025B1A4DC7D984B4003B68311FBB24E401B49827005984B400D8E9257E7B24E401B49827005984B40
43068	66	61.280957999999998	61.304637	55.191088999999998	55.173380000000002	Чичерина	0103000020E6100000010000000500000058C6866EF6A34E40E7E3DA5031964B4058C6866EF6A34E400BD0B69A75984B4066136058FEA64E400BD0B69A75984B4066136058FEA64E40E7E3DA5031964B4058C6866EF6A34E40E7E3DA5031964B40
43430	66	61.373116000000003	61.411312000000002	55.246831	55.219535	Черкасская	0103000020E61000000100000005000000A3CEDC43C2AF4E40E7A90EB9199C4B40A3CEDC43C2AF4E40CA518028989F4B40E73922DFA5B44E40CA518028989F4B40E73922DFA5B44E40E7A90EB9199C4B40A3CEDC43C2AF4E40E7A90EB9199C4B40
43481	66	61.368974999999999	61.378720999999999	55.047517999999997	55.036535000000001	Челябинская	0103000020E610000001000000050000005305A3923AAF4E406614CB2DAD844B405305A3923AAF4E4054FCDF1115864B407AA702EE79B04E4054FCDF1115864B407AA702EE79B04E406614CB2DAD844B405305A3923AAF4E406614CB2DAD844B40
43410	66	61.352499000000002	61.363503999999999	55.198509000000001	55.174491000000003	Чайковского	0103000020E61000000100000005000000B56FEEAF1EAD4E40223999B855964B40B56FEEAF1EAD4E40187B2FBE68994B408BFB8F4C87AE4E40187B2FBE68994B408BFB8F4C87AE4E40223999B855964B40B56FEEAF1EAD4E40223999B855964B40
43097	66	61.400073999999996	61.400163999999997	55.141849999999998	55.140687	Цеховая	0103000020E610000001000000050000006DFDF49F35B34E4076FC170802924B406DFDF49F35B34E4003780B2428924B40AD84EE9238B34E4003780B2428924B40AD84EE9238B34E4076FC170802924B406DFDF49F35B34E4076FC170802924B40
42738	66	61.361958999999999	61.373717999999997	55.123533000000002	55.118833000000002	Центральная	0103000020E6100000010000000500000016BF29AC54AE4E40C15774EB358F4B4016BF29AC54AE4E40077DE9EDCF8F4B4098F6CDFDD5AF4E40077DE9EDCF8F4B4098F6CDFDD5AF4E40C15774EB358F4B4016BF29AC54AE4E40C15774EB358F4B40
43037	66	61.403137999999998	61.413881000000003	55.168016999999999	55.143208999999999	Цвиллинга	0103000020E610000001000000050000002EE3A6069AB34E4016BF29AC54924B402EE3A6069AB34E400516C09481954B40C8B7770DFAB44E400516C09481954B40C8B7770DFAB44E4016BF29AC54924B402EE3A6069AB34E4016BF29AC54924B40
42880	66	61.350316999999997	61.382153000000002	55.147711000000001	55.146425000000001	Худякова	0103000020E61000000100000005000000CD1DFD2FD7AC4E408D28ED0DBE924B40CD1DFD2FD7AC4E403621AD31E8924B40BE88B663EAB04E403621AD31E8924B40BE88B663EAB04E408D28ED0DBE924B40CD1DFD2FD7AC4E408D28ED0DBE924B40
43427	66	61.484633000000002	61.488666000000002	55.186503999999999	55.172716999999999	Хохрякова	0103000020E61000000100000005000000FCC7427408BE4E404B3B35971B964B40FCC7427408BE4E405E49F25CDF974B406555849B8CBE4E405E49F25CDF974B406555849B8CBE4E404B3B35971B964B40FCC7427408BE4E404B3B35971B964B40
43071	66	61.403289999999998	61.419065000000003	55.250827999999998	55.219754999999999	Хлебозаводская	0103000020E61000000100000005000000E466B8019FB34E40F5108DEE209C4B40E466B8019FB34E40E675C4211BA04B40FAF202ECA3B54E40E675C4211BA04B40FAF202ECA3B54E40F5108DEE209C4B40E466B8019FB34E40F5108DEE209C4B40
42693	66	61.428156000000001	61.445124999999997	55.149752999999997	55.146641000000002	Харлова	0103000020E6100000010000000500000008CBD8D0CDB64E405AA0DD21C5924B4008CBD8D0CDB64E402BBD361B2B934B40E5D022DBF9B84E402BBD361B2B934B40E5D022DBF9B84E405AA0DD21C5924B4008CBD8D0CDB64E405AA0DD21C5924B40
43583	66	61.375883000000002	61.384937999999998	55.136879	55.132865000000002	Учебная	0103000020E61000000100000005000000AA0F24EF1CB04E403BE466B801914B40AA0F24EF1CB04E402D41464085914B406B7EFCA545B14E402D41464085914B406B7EFCA545B14E403BE466B801914B40AA0F24EF1CB04E403BE466B801914B40
43032	66	61.500677000000003	61.515247000000002	55.125062	55.123218999999999	Уральская	0103000020E61000000100000005000000016E162F16C04E40779FE3A3C58F4B40016E162F16C04E4076FC170802904B405A2E1B9DF3C14E4076FC170802904B405A2E1B9DF3C14E40779FE3A3C58F4B40016E162F16C04E40779FE3A3C58F4B40
43412	66	61.302275000000002	61.353028999999999	55.178465000000003	55.159922999999999	Университетская Набережная	0103000020E61000000100000005000000FFB27BF2B0A64E4069705B5B78944B40FFB27BF2B0A64E40863DEDF0D7964B4011C5E40D30AD4E40863DEDF0D7964B4011C5E40D30AD4E4069705B5B78944B40FFB27BF2B0A64E4069705B5B78944B40
42826	66	61.426377000000002	61.438864000000002	55.147669999999998	55.144984000000001	Тухачевского	0103000020E610000001000000050000002062838593B64E40BD38F1D58E924B402062838593B64E40D74CBED9E6924B4025B20FB22CB84E40D74CBED9E6924B4025B20FB22CB84E40BD38F1D58E924B402062838593B64E40BD38F1D58E924B40
42950	66	61.477096000000003	61.487399000000003	55.106608000000001	55.099037000000003	Туруханская	0103000020E61000000100000005000000B686527B11BD4E40070C923EAD8C4B40B686527B11BD4E40F9BEB854A58D4B40338D261763BE4E40F9BEB854A58D4B40338D261763BE4E40070C923EAD8C4B40B686527B11BD4E40070C923EAD8C4B40
43476	66	61.387579000000002	61.402563000000001	55.267943000000002	55.267691999999997	Трудовая	0103000020E61000000100000005000000E6CE4C309CB14E404EB340BB43A24B40E6CE4C309CB14E409818CBF44BA24B4032CA332F87B34E409818CBF44BA24B4032CA332F87B34E404EB340BB43A24B40E6CE4C309CB14E404EB340BB43A24B40
43135	66	61.383887000000001	61.441397000000002	55.131794999999997	55.037753000000002	Троицкий тракт	0103000020E61000000100000005000000062E8F3523B14E40B7291E17D5844B40062E8F3523B14E405E6397A8DE904B40B9C667B27FB84E405E6397A8DE904B40B9C667B27FB84E40B7291E17D5844B40062E8F3523B14E40B7291E17D5844B40
5927	66	61.383887000000001	61.441397000000002	55.131794999999997	55.037753000000002	Троицкий тракт	0103000020E61000000100000005000000062E8F3523B14E40B7291E17D5844B40062E8F3523B14E405E6397A8DE904B40B9C667B27FB84E405E6397A8DE904B40B9C667B27FB84E40B7291E17D5844B40062E8F3523B14E40B7291E17D5844B40
43686	66	61.331982000000004	61.343336999999998	55.111772999999999	55.097759000000003	Трактовая	0103000020E610000001000000050000002B6EDC627EAA4E40E1F1ED5D838C4B402B6EDC627EAA4E40B4C9E1934E8E4B40DD408177F2AB4E40B4C9E1934E8E4B40DD408177F2AB4E40E1F1ED5D838C4B402B6EDC627EAA4E40E1F1ED5D838C4B40
42708	66	61.398439000000003	61.421481	55.158745000000003	55.157521000000003	Тимирязева	0103000020E61000000100000005000000B939950C00B34E4074B7EBA529944B40B939950C00B34E40A7B393C151944B405471E316F3B54E40A7B393C151944B405471E316F3B54E4074B7EBA529944B40B939950C00B34E4074B7EBA529944B40
591	66	61.384641000000002	61.387174000000002	55.256518999999997	55.256473	Театральный переулок	0103000020E61000000100000005000000B2D991EA3BB14E404CA7751BD4A04B40B2D991EA3BB14E40BCE6559DD5A04B4046EEE9EA8EB14E40BCE6559DD5A04B4046EEE9EA8EB14E404CA7751BD4A04B40B2D991EA3BB14E404CA7751BD4A04B40
42720	66	61.465237999999999	61.476916000000003	55.192979999999999	55.158996999999999	Танкистов	0103000020E61000000100000005000000A06D35EB8CBB4E40C09481035A944B40A06D35EB8CBB4E401B649291B3984B4036785F950BBD4E401B649291B3984B4036785F950BBD4E40C09481035A944B40A06D35EB8CBB4E40C09481035A944B40
43424	66	61.364365999999997	61.373995999999998	55.25226	55.252023999999999	Сурикова	0103000020E610000001000000050000001DE38A8BA3AE4E404FE78A5242A04B401DE38A8BA3AE4E40630B410E4AA04B40DB6AD619DFAF4E40630B410E4AA04B40DB6AD619DFAF4E404FE78A5242A04B401DE38A8BA3AE4E404FE78A5242A04B40
44266	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Стрелковая	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
42704	66	61.351035000000003	61.357942999999999	55.117956999999997	55.109090000000002	Столбовая	0103000020E610000001000000050000002D6002B7EEAC4E400B293FA9F68D4B402D6002B7EEAC4E40C9AA0837198F4B40836A8313D1AD4E40C9AA0837198F4B40836A8313D1AD4E400B293FA9F68D4B402D6002B7EEAC4E400B293FA9F68D4B40
43734	66	61.365363000000002	61.366979999999998	55.039326000000003	55.034455999999999	Станционная	0103000020E610000001000000050000009015FC36C4AE4E405393E00D69844B409015FC36C4AE4E40F6F065A208854B409E245D33F9AE4E40F6F065A208854B409E245D33F9AE4E405393E00D69844B409015FC36C4AE4E405393E00D69844B40
43459	66	61.402149000000001	61.403765999999997	55.271425999999998	55.242683999999997	Сталеваров	0103000020E610000001000000050000003F8F519E79B34E4098A1F144109F4B403F8F519E79B34E405DA45016BEA24B404D9EB29AAEB34E405DA45016BEA24B404D9EB29AAEB34E4098A1F144109F4B403F8F519E79B34E4098A1F144109F4B40
42889	66	61.364491999999998	61.398439000000003	55.158034999999998	55.157156000000001	Сони Кривой	0103000020E61000000100000005000000AAD381ACA7AE4E40622F14B01D944B40AAD381ACA7AE4E40CA4FAA7D3A944B40B939950C00B34E40CA4FAA7D3A944B40B939950C00B34E40622F14B01D944B40AAD381ACA7AE4E40622F14B01D944B40
43421	66	61.317950000000003	61.324579999999997	55.203704000000002	55.189069000000003	Солнечная	0103000020E61000000100000005000000B1E1E995B2A84E40FED7B96933984B40B1E1E995B2A84E403E0801F9129A4B40C47762D68BA94E403E0801F9129A4B40C47762D68BA94E40FED7B96933984B40B1E1E995B2A84E40FED7B96933984B40
43299	66	61.405734000000002	61.406371	55.167991999999998	55.160504000000003	Советская	0103000020E6100000010000000500000009707A17EFB34E40487023658B944B4009707A17EFB34E40ACFE08C380954B407B8505F703B44E40ACFE08C380954B407B8505F703B44E40487023658B944B4009707A17EFB34E40487023658B944B40
42884	66	61.364832999999997	61.376097999999999	55.152264000000002	55.152053000000002	Смирных	0103000020E6100000010000000500000033C005D9B2AE4E401D21037976934B4033C005D9B2AE4E40D82D02637D934B40A60BB1FA23B04E40D82D02637D934B40A60BB1FA23B04E401D21037976934B4033C005D9B2AE4E401D21037976934B40
42701	66	61.410558000000002	61.416612000000001	55.173333999999997	55.138876000000003	Свободы	0103000020E610000001000000050000003B8E1F2A8DB44E40831953B0C6914B403B8E1F2A8DB44E4076A4FACE2F964B40828FC18A53B54E4076A4FACE2F964B40828FC18A53B54E40831953B0C6914B403B8E1F2A8DB44E40831953B0C6914B40
1854	66	61.385584000000001	61.389707999999999	55.197040000000001	55.146943999999998	Свердловский проспект	0103000020E6100000010000000500000031EE06D15AB14E40F52B9D0FCF924B4031EE06D15AB14E407E00529B38994B40AA7EA5F3E1B14E407E00529B38994B40AA7EA5F3E1B14E40F52B9D0FCF924B4031EE06D15AB14E40F52B9D0FCF924B40
43209	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Санаторная	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
42698	66	61.436591	61.469433000000002	55.172218000000001	55.168388	Салютная	0103000020E610000001000000050000002D5DC136E2B74E40F984ECBC8D954B402D5DC136E2B74E402AE44A3D0B964B40E3546B6116BC4E402AE44A3D0B964B40E3546B6116BC4E40F984ECBC8D954B402D5DC136E2B74E40F984ECBC8D954B40
42635	66	61.275613	61.296849000000002	55.191021999999997	55.169462000000003	Салавата Юлаева	0103000020E610000001000000050000001DAD6A4947A34E4017F549EEB0954B401DAD6A4947A34E408368AD6873984B40D76CE525FFA54E408368AD6873984B40D76CE525FFA54E4017F549EEB0954B401DAD6A4947A34E4017F549EEB0954B40
42879	66	61.432125999999997	61.449894999999998	55.165976000000001	55.164926999999999	Савина	0103000020E610000001000000050000002AE09EE74FB74E401B9DF3531C954B402AE09EE74FB74E40E0F599B33E954B4024D1CB2896B94E40E0F599B33E954B4024D1CB2896B94E401B9DF3531C954B402AE09EE74FB74E401B9DF3531C954B40
43607	66	61.369791999999997	61.385477000000002	55.132736999999999	55.126235999999999	Рылеева	0103000020E610000001000000050000004529215855AF4E40F7C9518028904B404529215855AF4E400DFCA886FD904B401B2E724F57B14E400DFCA886FD904B401B2E724F57B14E40F7C9518028904B404529215855AF4E40F7C9518028904B40
43465	66	61.405841000000002	61.418866999999999	55.199731999999997	55.146490999999997	Российская	0103000020E610000001000000050000001F300F99F2B34E4044149337C0924B401F300F99F2B34E407AFB73D190994B40D32F116F9DB54E407AFB73D190994B40D32F116F9DB54E4044149337C0924B401F300F99F2B34E4044149337C0924B40
43452	66	61.373914999999997	61.374535000000002	55.187609999999999	55.177667999999997	Речная	0103000020E61000000100000005000000EE3D5C72DCAF4E40DAC534D3BD964B40EE3D5C72DCAF4E408733BF9A03984B408B1A4CC3F0AF4E408733BF9A03984B408B1A4CC3F0AF4E40DAC534D3BD964B40EE3D5C72DCAF4E40DAC534D3BD964B40
42699	66	61.400621999999998	61.403928000000001	55.160463	55.160184999999998	Революции площадь	0103000020E610000001000000050000007007EA9447B34E40A6272CF180944B407007EA9447B34E40E99B340D8A944B4027F8A6E9B3B34E40E99B340D8A944B4027F8A6E9B3B34E40A6272CF180944B407007EA9447B34E40A6272CF180944B40
43065	66	61.339599999999997	61.361806000000001	55.237197000000002	55.233141000000003	Рабоче-Крестьянская	0103000020E610000001000000050000005DDC460378AB4E40AA2D7590D79D4B405DDC460378AB4E40CBDAA6785C9E4B4090BFB4A84FAE4E40CBDAA6785C9E4B4090BFB4A84FAE4E40AA2D7590D79D4B405DDC460378AB4E40AA2D7590D79D4B40
43446	66	61.380177000000003	61.392105999999998	55.179298000000003	55.175823000000001	Работниц	0103000020E6100000010000000500000080D8D2A3A9B04E403B71395E81964B4080D8D2A3A9B04E407E1EA33CF3964B405E48878730B24E407E1EA33CF3964B405E48878730B24E403B71395E81964B4080D8D2A3A9B04E403B71395E81964B40
44108	66	61.411546000000001	61.416801	55.142328999999997	55.137785000000001	Привокзальная площадь	0103000020E610000001000000050000005A66118AADB44E408F705AF0A2914B405A66118AADB44E40DD2230D637924B4055F833BC59B54E40DD2230D637924B4055F833BC59B54E408F705AF0A2914B405A66118AADB44E408F705AF0A2914B40
42695	66	61.425218000000001	61.445852000000002	55.148791000000003	55.140681999999998	Пограничная	0103000020E61000000100000005000000D4D51D8B6DB64E40649126DE01924B40D4D51D8B6DB64E4036785F950B934B40986DA7AD11B94E4036785F950B934B40986DA7AD11B94E40649126DE01924B40D4D51D8B6DB64E40649126DE01924B40
1463	66	61.283994	61.466468999999996	55.192979999999999	55.178953	Победы проспект	0103000020E610000001000000050000004F2157EA59A44E40B34291EEE7964B404F2157EA59A44E401B649291B3984B4085CC9541B5BB4E401B649291B3984B4085CC9541B5BB4E40B34291EEE7964B404F2157EA59A44E40B34291EEE7964B40
43214	66	61.347478000000002	61.348035000000003	55.194563000000002	55.189326000000001	Пионерская	0103000020E610000001000000050000002D0ABB287AAC4E40292499D53B984B402D0ABB287AAC4E407E01BD70E7984B40836E2F698CAC4E407E01BD70E7984B40836E2F698CAC4E40292499D53B984B402D0ABB287AAC4E40292499D53B984B40
43457	66	61.347478000000002	61.348035000000003	55.194563000000002	55.189326000000001	Пионерская	0103000020E610000001000000050000002D0ABB287AAC4E40292499D53B984B402D0ABB287AAC4E407E01BD70E7984B40836E2F698CAC4E407E01BD70E7984B40836E2F698CAC4E40292499D53B984B402D0ABB287AAC4E40292499D53B984B40
42734	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Первой Пятилетки	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
42875	66	61.397604000000001	61.409255000000002	55.247430999999999	55.245496000000003	Пекинская	0103000020E61000000100000005000000206118B0E4B24E4040A6B5696C9F4B40206118B0E4B24E401F82AAD1AB9F4B40BC5CC47762B44E401F82AAD1AB9F4B40BC5CC47762B44E4040A6B5696C9F4B40206118B0E4B24E4040A6B5696C9F4B40
42812	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Панькова	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43123	66	61.421526	61.425020000000004	55.138252999999999	55.135531	Отечественная	0103000020E61000000100000005000000F4346090F4B54E400E4C6E1459914B40F4346090F4B54E4075C93846B2914B40AE122C0E67B64E4075C93846B2914B40AE122C0E67B64E400E4C6E1459914B40F4346090F4B54E400E4C6E1459914B40
8074	66	61.386761	61.391503999999998	55.188139	55.186402000000001	Островского переулок	0103000020E61000000100000005000000232F6B6281B14E405AF44E05DC974B40232F6B6281B14E40130D52F014984B40682096CD1CB24E40130D52F014984B40682096CD1CB24E405AF44E05DC974B40232F6B6281B14E405AF44E05DC974B40
43127	66	61.402831999999997	61.414347999999997	55.152988999999998	55.151580000000003	Орджоникидзе	0103000020E6100000010000000500000021E4BCFF8FB34E40255D33F966934B4021E4BCFF8FB34E40E9D2BF2495934B40DD94F25A09B54E40E9D2BF2495934B40DD94F25A09B54E40255D33F966934B4021E4BCFF8FB34E40255D33F966934B40
43395	66	61.458429000000002	61.475729999999999	55.183785	55.179755	Октябрьская	0103000020E61000000100000005000000DD442DCDADBA4E4070253B3602974B40DD442DCDADBA4E40683F524486974B40F0DC7BB8E4BC4E40683F524486974B40F0DC7BB8E4BC4E4070253B3602974B40DD442DCDADBA4E4070253B3602974B40
42739	66	61.368183999999999	61.379978999999999	55.145740000000004	55.144818999999998	Образцова	0103000020E610000001000000050000008A743FA720AF4E40726BD26D89924B408A743FA720AF4E400ADCBA9BA7924B405915E126A3B04E400ADCBA9BA7924B405915E126A3B04E40726BD26D89924B408A743FA720AF4E40726BD26D89924B40
42694	66	61.418866999999999	61.495933000000001	55.119413999999999	55.095410000000001	Новороссийская	0103000020E61000000100000005000000D32F116F9DB54E400EDB1665368C4B40D32F116F9DB54E409F573CF5488F4B40EB0088BB7ABF4E409F573CF5488F4B40EB0088BB7ABF4E400EDB1665368C4B40D32F116F9DB54E400EDB1665368C4B40
43292	66	61.380563000000002	61.383132000000003	55.129776999999997	55.127929000000002	Московская	0103000020E61000000100000005000000A988D349B6B04E40E19A3BFA5F904B40A988D349B6B04E40F16261889C904B408A0629780AB14E40F16261889C904B408A0629780AB14E40E19A3BFA5F904B40A988D349B6B04E40E19A3BFA5F904B40
43419	66	61.317644999999999	61.332880000000003	55.208100999999999	55.178465000000003	Молодогвардейцев	0103000020E61000000100000005000000745E6397A8A84E40863DEDF0D7964B40745E6397A8A84E40E8A1B60DA39A4B400ABFD4CF9BAA4E40E8A1B60DA39A4B400ABFD4CF9BAA4E40863DEDF0D7964B40745E6397A8A84E40863DEDF0D7964B40
42646	66	61.301313	61.312559999999998	55.238249000000003	55.237726000000002	Молодова	0103000020E61000000100000005000000096EA46C91A64E4057B439CE6D9E4B40096EA46C91A64E4001A777F17E9E4B40D50451F701A84E4001A777F17E9E4B40D50451F701A84E4057B439CE6D9E4B40096EA46C91A64E4057B439CE6D9E4B40
42871	66	61.301538000000001	61.307223999999998	55.193765999999997	55.188293000000002	Молдавская	0103000020E61000000100000005000000294014CC98A64E406A882AFC19984B40294014CC98A64E40D2890453CD984B40ED45B41D53A74E40D2890453CD984B40ED45B41D53A74E406A882AFC19984B40294014CC98A64E406A882AFC19984B40
42643	66	61.368758999999997	61.403173000000002	55.254795000000001	55.245095999999997	Мира	0103000020E61000000100000005000000868DB27E33AF4E40B130444E5F9F4B40868DB27E33AF4E409817601F9DA04B40ABD0402C9BB34E409817601F9DA04B40ABD0402C9BB34E40B130444E5F9F4B40868DB27E33AF4E40B130444E5F9F4B40
3855	66	61.363764000000003	61.419361000000002	55.264598999999997	55.243828000000001	Металлургов шоссе	0103000020E6100000010000000500000028BB99D18FAE4E40AFEC82C1359F4B4028BB99D18FAE4E40F3C64961DEA14B40E31B0A9FADB54E40F3C64961DEA14B40E31B0A9FADB54E40AFEC82C1359F4B4028BB99D18FAE4E40AFEC82C1359F4B40
42703	66	61.466845999999997	61.480276000000003	55.128155999999997	55.111587999999998	Машиностроителей	0103000020E610000001000000050000005B22179CC1BB4E402250FD83488E4B405B22179CC1BB4E40A164726A67904B40E08618AF79BD4E40A164726A67904B40E08618AF79BD4E402250FD83488E4B405B22179CC1BB4E402250FD83488E4B40
43241	66	61.316817999999998	61.332368000000002	55.232411999999997	55.225974000000001	Матросова	0103000020E610000001000000050000005E64027E8DA84E4087DF4DB7EC9C4B405E64027E8DA84E40569929ADBF9D4B40541EDD088BAA4E40569929ADBF9D4B40541EDD088BAA4E4087DF4DB7EC9C4B405E64027E8DA84E4087DF4DB7EC9C4B40
43051	66	61.454656	61.470106999999999	55.120058	55.116844999999998	Масленникова	0103000020E610000001000000050000001077F52A32BA4E40BED9E6C6F48E4B401077F52A32BA4E40C4CF7F0F5E8F4B40724F57772CBC4E40C4CF7F0F5E8F4B40724F57772CBC4E40BED9E6C6F48E4B401077F52A32BA4E40BED9E6C6F48E4B40
42644	66	61.454970000000003	61.465722999999997	55.175139000000001	55.161147	Марченко	0103000020E61000000100000005000000A054FB743CBA4E409C6C0377A0944B40A054FB743CBA4E4088A06AF46A964B405CFFAECF9CBB4E4088A06AF46A964B405CFFAECF9CBB4E409C6C0377A0944B40A054FB743CBA4E409C6C0377A0944B40
43677	66	61.385458999999997	61.389465000000001	55.129859000000003	55.126925	Марата	0103000020E61000000100000005000000747973B856B14E40BC0512143F904B40747973B856B14E40AF0B3F389F904B40E4F736FDD9B14E40AF0B3F389F904B40E4F736FDD9B14E40BC0512143F904B40747973B856B14E40BC0512143F904B40
43432	66	61.470224000000002	61.484633000000002	55.197465999999999	55.172891999999997	Мамина	0103000020E61000000100000005000000ACE5CE4C30BC4E40B9DE365321964B40ACE5CE4C30BC4E403509DE9046994B40FCC7427408BE4E403509DE9046994B40FCC7427408BE4E40B9DE365321964B40ACE5CE4C30BC4E40B9DE365321964B40
43462	66	61.385207000000001	61.385629000000002	55.259920000000001	55.248263000000001	Липецкая	0103000020E610000001000000050000005B9885764EB14E4047E7FC14C79F4B405B9885764EB14E40C5C9FD0E45A14B40D1B1834A5CB14E40C5C9FD0E45A14B40D1B1834A5CB14E4047E7FC14C79F4B405B9885764EB14E4047E7FC14C79F4B40
42718	66	61.453021	61.465156999999998	55.185049999999997	55.177019999999999	Лермонтова	0103000020E610000001000000050000005BB39597FCB94E40745E6397A8964B405BB39597FCB94E40F90FE9B7AF974B40B340BB438ABB4E40F90FE9B7AF974B40B340BB438ABB4E40745E6397A8964B405BB39597FCB94E40745E6397A8964B40
125	66	61.364294000000001	61.502374000000003	55.161259999999999	55.156326999999997	Ленина проспект	0103000020E610000001000000050000008410902FA1AE4E40AB3DEC8502944B408410902FA1AE4E409413ED2AA4944B402C2E8ECA4DC04E409413ED2AA4944B402C2E8ECA4DC04E40AB3DEC8502944B408410902FA1AE4E40AB3DEC8502944B40
43739	66	61.378990999999999	61.392969000000001	55.292664000000002	55.285496999999999	Лазурная	0103000020E610000001000000050000003A3DEFC682B04E40950D6B2A8BA44B403A3DEFC682B04E40B85B920376A54B40C1ABE5CE4CB24E40B85B920376A54B40C1ABE5CE4CB24E40950D6B2A8BA44B403A3DEFC682B04E40950D6B2A8BA44B40
43130	66	61.381273	61.398529000000003	55.153317999999999	55.146084999999999	Курчатова	0103000020E6100000010000000500000085ECBC8DCDB04E40D4B7CCE9B2924B4085ECBC8DCDB04E40AEF199EC9F934B40F9C08EFF02B34E40AEF199EC9F934B40F9C08EFF02B34E40D4B7CCE9B2924B4085ECBC8DCDB04E40D4B7CCE9B2924B40
43428	66	61.462812999999997	61.486798	55.175863999999997	55.172505999999998	Кулибина	0103000020E61000000100000005000000F294D5743DBB4E40902E36AD14964B40F294D5743DBB4E40994528B682964B400DE198654FBE4E40994528B682964B400DE198654FBE4E40902E36AD14964B40F294D5743DBB4E40902E36AD14964B40
43420	66	61.332090000000001	61.384371999999999	55.198576000000003	55.194459999999999	Куйбышева	0103000020E6100000010000000500000011AAD4EC81AA4E40A930B610E4984B4011AAD4EC81AA4E40A0E238F06A994B40C2BF081A33B14E40A0E238F06A994B40C2BF081A33B14E40A930B610E4984B4011AAD4EC81AA4E40A930B610E4984B40
42700	66	61.323788999999998	61.36159	55.118147999999998	55.111021000000001	Кузнецова	0103000020E61000000100000005000000FBE6FEEA71A94E40A915A6EF358E4B40FBE6FEEA71A94E403D0B42791F8F4B40C347C49448AE4E403D0B42791F8F4B40C347C49448AE4E40A915A6EF358E4B40FBE6FEEA71A94E40A915A6EF358E4B40
42989	66	61.420043999999997	61.436869000000002	55.189712	55.175055999999998	Кудрявцева	0103000020E61000000100000005000000C5707500C4B54E40FA7B293C68964B40C5707500C4B54E4052D4997B48984B4070D1C952EBB74E4052D4997B48984B4070D1C952EBB74E40FA7B293C68964B40C5707500C4B54E40FA7B293C68964B40
42949	66	61.463864000000001	61.475532999999999	55.130296999999999	55.118049999999997	Кронштадтская	0103000020E6100000010000000500000058E542E55FBB4E407AA52C431C8F4B4058E542E55FBB4E402AE27492AD904B409A95ED43DEBC4E402AE27492AD904B409A95ED43DEBC4E407AA52C431C8F4B4058E542E55FBB4E407AA52C431C8F4B40
43455	66	61.37997	61.391379000000001	55.250802999999998	55.250653999999997	Краснооктябрьская	0103000020E6100000010000000500000006BB61DBA2B04E40484E266E15A04B4006BB61DBA2B04E408D5E0D501AA04B40ACAB02B518B24E408D5E0D501AA04B40ACAB02B518B24E40484E266E15A04B4006BB61DBA2B04E40484E266E15A04B40
43484	66	61.354557	61.354646000000002	55.198576000000003	55.189326000000001	Красного Урала	0103000020E61000000100000005000000B0C8AF1F62AD4E40292499D53B984B40B0C8AF1F62AD4E40A0E238F06A994B4020D4450A65AD4E40A0E238F06A994B4020D4450A65AD4E40292499D53B984B40B0C8AF1F62AD4E40292499D53B984B40
42726	66	61.412489000000001	61.414231999999998	55.174429000000003	55.160848999999999	Красноармейская	0103000020E61000000100000005000000D97A8670CCB44E40124C35B396944B40D97A8670CCB44E40AC3C81B053964B40747ADE8D05B54E40AC3C81B053964B40747ADE8D05B54E40124C35B396944B40D97A8670CCB44E40124C35B396944B40
43223	66	61.392735000000002	61.393912	55.167543999999999	55.155051999999998	Красная	0103000020E610000001000000050000004E7FF62345B24E40F69672BED8934B404E7FF62345B24E400D52F01472954B4040C05AB56BB24E400D52F01472954B4040C05AB56BB24E40F69672BED8934B404E7FF62345B24E40F69672BED8934B40
42874	66	61.431353999999999	61.457827000000002	55.179817	55.174171999999999	Котина	0103000020E61000000100000005000000D87F9D9B36B74E4080F0A1444B964B40D87F9D9B36B74E40E621533E04974B40E71C3C139ABA4E40E621533E04974B40E71C3C139ABA4E4080F0A1444B964B40D87F9D9B36B74E4080F0A1444B964B40
42821	66	61.433580999999997	61.540300999999999	55.159073999999997	55.119681999999997	Копейское шоссе	0103000020E610000001000000050000005F950B957FB74E40BEF561BD518F4B405F950B957FB74E406BD26D895C944B40807F4A9528C54E406BD26D895C944B40807F4A9528C54E40BEF561BD518F4B405F950B957FB74E40BEF561BD518F4B40
32	66	61.286302999999997	61.390292000000002	55.194563000000002	55.186926	Комсомольский проспект	0103000020E6100000010000000500000093DFA293A5A44E40D462F030ED974B4093DFA293A5A44E407E01BD70E7984B40FAF19716F5B14E407E01BD70E7984B40FAF19716F5B14E40D462F030ED974B4093DFA293A5A44E40D462F030ED974B40
42990	66	61.365901999999998	61.421247999999999	55.163291000000001	55.161903000000002	Коммуны	0103000020E610000001000000050000003FC571E0D5AE4E40E90FCD3CB9944B403FC571E0D5AE4E40965D30B8E6944B40B1C05774EBB54E40965D30B8E6944B40B1C05774EBB54E40E90FCD3CB9944B403FC571E0D5AE4E40E90FCD3CB9944B40
43302	66	61.396894000000003	61.402813999999999	55.261721000000001	55.261187	Коммунистическая	0103000020E6100000010000000500000044FD2E6CCDB24E40F7915B936EA14B4044FD2E6CCDB24E4095D6DF1280A14B407B2FBE688FB34E4095D6DF1280A14B407B2FBE688FB34E40F7915B936EA14B4044FD2E6CCDB24E40F7915B936EA14B40
42839	66	61.429718999999999	61.438864000000002	55.144984000000001	55.116129999999998	Коммунаров	0103000020E6100000010000000500000023BC3D0801B74E40D00A0C59DD8E4B4023BC3D0801B74E40BD38F1D58E924B4025B20FB22CB84E40BD38F1D58E924B4025B20FB22CB84E40D00A0C59DD8E4B4023BC3D0801B74E40D00A0C59DD8E4B40
43414	66	61.355885999999998	61.367258999999997	55.184618	55.179991999999999	Коммунальная	0103000020E61000000100000005000000588D25AC8DAD4E4054C554FA09974B40588D25AC8DAD4E4060200890A1974B40B114C95702AF4E4060200890A1974B40B114C95702AF4E4054C554FA09974B40588D25AC8DAD4E4054C554FA09974B40
43069	66	61.366855000000001	61.380364999999998	55.242154999999997	55.238188000000001	Комаровского	0103000020E61000000100000005000000E2AFC91AF5AE4E405B26C3F17C9E4B40E2AFC91AF5AE4E400CC85EEFFE9E4B4082C5E1CCAFB04E400CC85EEFFE9E4B4082C5E1CCAFB04E405B26C3F17C9E4B40E2AFC91AF5AE4E405B26C3F17C9E4B40
43045	66	61.452590000000001	61.473494000000002	55.196545999999998	55.170459999999999	Комарова	0103000020E61000000100000005000000923F1878EEB94E4059A31EA2D1954B40923F1878EEB94E406E14596B28994B40166D8E739BBC4E406E14596B28994B40166D8E739BBC4E4059A31EA2D1954B40923F1878EEB94E4059A31EA2D1954B40
43077	66	61.452590000000001	61.473494000000002	55.196545999999998	55.170459999999999	Комарова	0103000020E61000000100000005000000923F1878EEB94E4059A31EA2D1954B40923F1878EEB94E406E14596B28994B40166D8E739BBC4E406E14596B28994B40166D8E739BBC4E4059A31EA2D1954B40923F1878EEB94E4059A31EA2D1954B40
43454	66	61.398637000000001	61.400281	55.184401999999999	55.167786	Кирова	0103000020E61000000100000005000000DFFC868906B34E40035DFB027A954B40DFFC868906B34E4093A8177C9A974B40E71A66683CB34E4093A8177C9A974B40E71A66683CB34E40035DFB027A954B40DFFC868906B34E40035DFB027A954B40
43444	66	61.398637000000001	61.400281	55.184401999999999	55.167786	Кирова	0103000020E61000000100000005000000DFFC868906B34E40035DFB027A954B40DFFC868906B34E4093A8177C9A974B40E71A66683CB34E4093A8177C9A974B40E71A66683CB34E40035DFB027A954B40DFFC868906B34E40035DFB027A954B40
43140	66	61.395941999999998	61.400900999999998	55.121211000000002	55.117694999999998	Карабанова	0103000020E61000000100000005000000718E3A3AAEB24E408CF337A1108F4B40718E3A3AAEB24E402E7590D7838F4B4083F755B950B34E402E7590D7838F4B4083F755B950B34E408CF337A1108F4B40718E3A3AAEB24E408CF337A1108F4B40
43149	66	61.338476999999997	61.338763999999998	55.085894000000003	55.0839	Капитанская	0103000020E610000001000000050000005EB9DE3653AB4E403411363CBD8A4B405EB9DE3653AB4E4019761893FE8A4B40F487669E5CAB4E4019761893FE8A4B40F487669E5CAB4E403411363CBD8A4B405EB9DE3653AB4E403411363CBD8A4B40
43449	66	61.387174000000002	61.408366000000001	55.179796000000003	55.179149000000002	Калинина	0103000020E6100000010000000500000046EEE9EA8EB14E40390EBC5AEE964B4046EEE9EA8EB14E40CFF9298E03974B4030664B5645B44E40CFF9298E03974B4030664B5645B44E40390EBC5AEE964B4046EEE9EA8EB14E40390EBC5AEE964B40
42707	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Зои Космодемьянской	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43423	66	61.297818999999997	61.318444	55.198811999999997	55.193765999999997	Захаренко	0103000020E610000001000000050000004F90D8EE1EA64E40D2890453CD984B404F90D8EE1EA64E40B306EFAB72994B40C0CDE2C5C2A84E40B306EFAB72994B40C0CDE2C5C2A84E40D2890453CD984B404F90D8EE1EA64E40D2890453CD984B40
43306	66	61.302796000000001	61.309165	55.153590999999999	55.152068	Заводская	0103000020E6100000010000000500000008AEF204C2A64E405262D7F676934B4008AEF204C2A64E40DFFAB0DEA8934B40AF08FEB792A74E40DFFAB0DEA8934B40AF08FEB792A74E405262D7F676934B4008AEF204C2A64E405262D7F676934B40
43460	66	61.390929	61.397531999999998	55.260007999999999	55.245953	Жукова	0103000020E610000001000000050000006C0723F609B24E4032AD4D637B9F4B406C0723F609B24E40645930F147A14B40868E1D54E2B24E40645930F147A14B40868E1D54E2B24E4032AD4D637B9F4B406C0723F609B24E4032AD4D637B9F4B40
42666	66	61.442402999999999	61.467547000000003	55.116968999999997	55.112870000000001	Ереванская	0103000020E610000001000000050000007E5358A9A0B84E408A592F86728E4B407E5358A9A0B84E40AAD216D7F88E4B40E52B8194D8BB4E40AAD216D7F88E4B40E52B8194D8BB4E408A592F86728E4B407E5358A9A0B84E408A592F86728E4B40
42728	66	61.397658	61.398645999999999	55.167842999999998	55.146192999999997	Елькина	0103000020E61000000100000005000000137F1475E6B24E40BAF3C473B6924B40137F1475E6B24E4067EE21E17B954B40325706D506B34E4067EE21E17B954B40325706D506B34E40BAF3C473B6924B40137F1475E6B24E40BAF3C473B6924B40
43742	66	61.438243999999997	61.438774000000002	55.043942999999999	55.040940999999997	Дорожная	0103000020E6100000010000000500000088D51F6118B84E406308008E3D854B4088D51F6118B84E40AEF199EC9F854B40E52A16BF29B84E40AEF199EC9F854B40E52A16BF29B84E406308008E3D854B4088D51F6118B84E406308008E3D854B40
42705	66	61.381990999999999	61.417330999999997	55.146532999999998	55.135269000000001	Доватора	0103000020E61000000100000005000000E42EC214E5B04E40D1949D7E50914B40E42EC214E5B04E407364E597C1924B40B14D2A1A6BB54E407364E597C1924B40B14D2A1A6BB54E40D1949D7E50914B40E42EC214E5B04E40D1949D7E50914B40
43136	66	61.381990999999999	61.417330999999997	55.146532999999998	55.135269000000001	Доватора	0103000020E61000000100000005000000E42EC214E5B04E40D1949D7E50914B40E42EC214E5B04E407364E597C1924B40B14D2A1A6BB54E407364E597C1924B40B14D2A1A6BB54E40D1949D7E50914B40E42EC214E5B04E40D1949D7E50914B40
43131	66	61.381990999999999	61.417330999999997	55.146532999999998	55.135269000000001	Доватора	0103000020E61000000100000005000000E42EC214E5B04E40D1949D7E50914B40E42EC214E5B04E407364E597C1924B40B14D2A1A6BB54E407364E597C1924B40B14D2A1A6BB54E40D1949D7E50914B40E42EC214E5B04E40D1949D7E50914B40
42729	66	61.417295000000003	61.472513999999997	55.135458999999997	55.120665000000002	Дзержинского	0103000020E6100000010000000500000065E42CEC69B54E40CC6262F3718F4B4065E42CEC69B54E40747973B856914B407973B8567BBC4E40747973B856914B407973B8567BBC4E40CC6262F3718F4B4065E42CEC69B54E40CC6262F3718F4B40
43456	66	61.396382000000003	61.402670000000001	55.274405999999999	55.240738999999998	Дегтярева	0103000020E610000001000000050000008E5C37A5BCB24E4095EF1989D09E4B408E5C37A5BCB24E40C0E95DBC1FA34B40488AC8B08AB34E40C0E95DBC1FA34B40488AC8B08AB34E4095EF1989D09E4B408E5C37A5BCB24E4095EF1989D09E4B40
42675	66	61.344234999999998	61.352535000000003	55.181637000000002	55.181555000000003	Двинская	0103000020E61000000100000005000000BC9179E40FAC4E4070B6B9313D974B40BC9179E40FAC4E402D5F97E13F974B4002D9EBDD1FAD4E402D5F97E13F974B4002D9EBDD1FAD4E4070B6B9313D974B40BC9179E40FAC4E4070B6B9313D974B40
43101	66	61.399211999999999	61.400343999999997	55.073225999999998	55.070283000000003	Дачный переулок	0103000020E61000000100000005000000DB15FA6019B34E407E3B8908FF884B40DB15FA6019B34E40C39B35785F894B402D93E1783EB34E40C39B35785F894B402D93E1783EB34E407E3B8908FF884B40DB15FA6019B34E407E3B8908FF884B40
43468	66	61.369791999999997	61.379942999999997	55.182026999999998	55.181168999999997	Дальневосточная	0103000020E610000001000000050000004529215855AF4E404606B98B30974B404529215855AF4E4097FE25A94C974B400CACE3F8A1B04E4097FE25A94C974B400CACE3F8A1B04E404606B98B30974B404529215855AF4E404606B98B30974B40
42670	66	61.43289	61.438386999999999	55.177427000000002	55.161634999999997	Грибоедова	0103000020E61000000100000005000000FA6184F068B74E40C971A774B0944B40FA6184F068B74E40B5368DEDB5964B40EBFEB1101DB84E40B5368DEDB5964B40EBFEB1101DB84E40C971A774B0944B40FA6184F068B74E40C971A774B0944B40
43072	66	61.43112	61.442951000000001	55.192112000000002	55.160730000000001	Горького	0103000020E610000001000000050000006553AEF02EB74E4038BEF6CC92944B406553AEF02EB74E40A795422097984B40815D4D9EB2B84E40A795422097984B40815D4D9EB2B84E4038BEF6CC92944B406553AEF02EB74E4038BEF6CC92944B40
43208	66	61.306964000000001	61.308374000000001	55.251607999999997	55.237730999999997	Городок 11	0103000020E610000001000000050000005186AA984AA74E40681F2BF86D9E4B405186AA984AA74E40BBB4E1B034A04B40E6779ACC78A74E40BBB4E1B034A04B40E6779ACC78A74E40681F2BF86D9E4B405186AA984AA74E40681F2BF86D9E4B40
42691	66	61.418436	61.450065000000002	55.129519999999999	55.125098000000001	Гончаренко	0103000020E610000001000000050000000ABC934F8FB54E40C365153603904B400ABC934F8FB54E40C616821C94904B408109DCBA9BB94E40C616821C94904B408109DCBA9BB94E40C365153603904B400ABC934F8FB54E40C365153603904B40
43205	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Героя России Молодова	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
42648	66	61.435817999999998	61.452849999999998	55.202882000000002	55.160144000000003	Героев Танкограда	0103000020E610000001000000050000000A815CE2C8B74E4048533D997F944B400A815CE2C8B74E403A799109F8994B402EFF21FDF6B94E403A799109F8994B402EFF21FDF6B94E4048533D997F944B400A815CE2C8B74E4048533D997F944B40
42995	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Генерала Мартынова	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43406	66	61.433653	61.446840999999999	55.146799999999999	55.117050999999996	Гагарина	0103000020E61000000100000005000000F96706F181B74E40677BF486FB8E4B40F96706F181B74E40C286A757CA924B4087C1FC1532B94E40C286A757CA924B4087C1FC1532B94E40677BF486FB8E4B40F96706F181B74E40677BF486FB8E4B40
43458	66	61.321427	61.327176000000001	55.202198000000003	55.189712	Ворошилова	0103000020E6100000010000000500000094861A8524A94E4052D4997B48984B4094861A8524A94E4087A8C29FE1994B409F0436E7E0A94E4087A8C29FE1994B409F0436E7E0A94E4052D4997B48984B4094861A8524A94E4052D4997B48984B40
42878	66	61.374535000000002	61.400883	55.160266999999997	55.135973999999997	Воровского	0103000020E610000001000000050000008B1A4CC3F0AF4E409B8D959867914B408B1A4CC3F0AF4E4063D009A183944B40DD42572250B34E4063D009A183944B40DD42572250B34E409B8D959867914B408B1A4CC3F0AF4E409B8D959867914B40
42724	66	61.385665000000003	61.386293999999999	55.167735	55.159820000000003	Володарского	0103000020E610000001000000050000001E1B81785DB14E40959F54FB74944B401E1B81785DB14E4081B2295778954B400D52F01472B14E4081B2295778954B400D52F01472B14E40959F54FB74944B401E1B81785DB14E40959F54FB74944B40
42964	66	61.467421000000002	61.485934999999998	55.111587999999998	55.095992000000003	Васильевского	0103000020E61000000100000005000000583B8A73D4BB4E40BD564277498C4B40583B8A73D4BB4E402250FD83488E4B40AA7D3A1E33BE4E402250FD83488E4B40AA7D3A1E33BE4E40BD564277498C4B40583B8A73D4BB4E40BD564277498C4B40
42948	66	61.422514	61.430410000000002	55.127198	55.115985000000002	Вагнера	0103000020E61000000100000005000000130D52F014B64E40CDE9B298D88E4B40130D52F014B64E40ED0E290648904B4089EFC4AC17B74E40ED0E290648904B4089EFC4AC17B74E40CDE9B298D88E4B40130D52F014B64E40CDE9B298D88E4B40
42722	66	61.451548000000003	61.456111	55.123702999999999	55.120851000000002	Брестская	0103000020E6100000010000000500000080492A53CCB94E402E58AA0B788F4B4080492A53CCB94E4063B5F97FD58F4B40452C62D861BA4E4063B5F97FD58F4B40452C62D861BA4E402E58AA0B788F4B4080492A53CCB94E402E58AA0B788F4B40
42642	66	61.362910999999997	61.372101000000001	55.257821999999997	55.253439999999998	Богдана Хмельницкого	0103000020E61000000100000005000000E82D1EDE73AE4E40C6BFCFB870A04B40E82D1EDE73AE4E403B18B14F00A14B408AE76C01A1AF4E403B18B14F00A14B408AE76C01A1AF4E40C6BFCFB870A04B40E82D1EDE73AE4E40C6BFCFB870A04B40
42954	66	61.361375000000002	61.389555000000001	55.146965000000002	55.118102	Блюхера	0103000020E61000000100000005000000C74B378941AE4E40CDCB61F71D8F4B40C74B378941AE4E400D54C6BFCF924B40247F30F0DCB14E400D54C6BFCF924B40247F30F0DCB14E40CDCB61F71D8F4B40C74B378941AE4E40CDCB61F71D8F4B40
43448	66	61.402931000000002	61.403137999999998	55.173437	55.170974000000001	Береговая	0103000020E61000000100000005000000B5C5353E93B34E40B03BDD79E2954B40B5C5353E93B34E404B75012F33964B402EE3A6069AB34E404B75012F33964B402EE3A6069AB34E40B03BDD79E2954B40B5C5353E93B34E40B03BDD79E2954B40
43282	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	Бахметьева	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
42943	66	61.463943999999998	61.470151999999999	55.122864	55.113565000000001	Батумская	0103000020E610000001000000050000007496598462BB4E40317C444C898E4B407496598462BB4E4089EDEE01BA8F4B401213D4F02DBC4E4089EDEE01BA8F4B401213D4F02DBC4E40317C444C898E4B407496598462BB4E40317C444C898E4B40
42819	66	61.425218000000001	61.437471000000002	55.148251000000002	55.122138	Барбюса	0103000020E61000000100000005000000D4D51D8B6DB64E40A7CCCD37A28F4B40D4D51D8B6DB64E40B64C86E3F9924B4066F9BA0CFFB74E40B64C86E3F9924B4066F9BA0CFFB74E40A7CCCD37A28F4B40D4D51D8B6DB64E40A7CCCD37A28F4B40
43403	66	61.436608999999997	61.491945000000001	55.217464999999997	55.179236000000003	Бажова	0103000020E61000000100000005000000D311C0CDE2B74E4008228B34F1964B40D311C0CDE2B74E402783A3E4D59B4B402237C30DF8BE4E402783A3E4D59B4B402237C30DF8BE4E4008228B34F1964B40D311C0CDE2B74E4008228B34F1964B40
42645	66	61.423645999999998	61.434874999999998	55.191972999999997	55.159073999999997	Артиллерийская	0103000020E61000000100000005000000658A39083AB64E406BD26D895C944B40658A39083AB64E40855B3E9292984B408B6CE7FBA9B74E40855B3E9292984B408B6CE7FBA9B74E406BD26D895C944B40658A39083AB64E406BD26D895C944B40
42828	66	61.283698000000001	61.302275000000002	55.167323000000003	55.16704	Академика Макеева	0103000020E6100000010000000500000066F84F3750A44E40DA8F149161954B4066F84F3750A44E402F6F0ED76A954B40FFB27BF2B0A64E402F6F0ED76A954B40FFB27BF2B0A64E40DA8F149161954B4066F84F3750A44E40DA8F149161954B40
43029	66	61.430303000000002	61.449787000000001	55.136446999999997	55.132392000000003	Агалакова	0103000020E61000000100000005000000732F302B14B74E4043209738F2904B40732F302B14B74E409351651877914B403E95D39E92B94E409351651877914B403E95D39E92B94E4043209738F2904B40732F302B14B74E4043209738F2904B40
43422	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	60 Лет Октября	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43391	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	50 Лет ВЛКСМ	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43125	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	40 лет Победы	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43058	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	40 Лет Победы	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43133	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	40 Лет Победы	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43172	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	40 Лет Победы	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
42638	66	61.384444000000002	61.420411999999999	55.242145000000001	55.236564999999999	32-й Годовщины Октября	0103000020E610000001000000050000005C92037635B14E406A300DC3479E4B405C92037635B14E40E9F17B9BFE9E4B40486C770FD0B54E40E9F17B9BFE9E4B40486C770FD0B54E406A300DC3479E4B405C92037635B14E406A300DC3479E4B40
42723	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	3 Интернационала	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
42649	66	61.190569000000004	61.583770999999999	55.318547000000002	54.985115999999998	26 Бакинских Комиссаров	0103000020E61000000100000005000000D350A39064984E401762F547187E4B40D350A39064984E40959EE925C6A84B4036AD1402B9CA4E40959EE925C6A84B4036AD1402B9CA4E401762F547187E4B40D350A39064984E401762F547187E4B40
43413	66	61.290156000000003	61.312821	55.181961000000001	55.174320999999999	250-летия Челябинска	0103000020E610000001000000050000007D5EF1D423A54E40C500892650964B407D5EF1D423A54E40E012807F4A974B404240BE840AA84E40E012807F4A974B404240BE840AA84E40C500892650964B407D5EF1D423A54E40C500892650964B40
43472	66	61.528892999999997	61.536375999999997	55.170994999999998	55.162402	2-я Эльтонская	0103000020E61000000100000005000000AA0A0DC4B2C34E400A67B796C9944B40AA0A0DC4B2C34E40C763062AE3954B40FD2D01F8A7C44E40C763062AE3954B40FD2D01F8A7C44E400A67B796C9944B40AA0A0DC4B2C34E400A67B796C9944B40
43082	66	61.347693	61.358401000000001	55.170994999999998	55.168335999999996	2-й Мелькомбинат	0103000020E610000001000000050000002906483481AC4E40A65EB7088C954B402906483481AC4E40C763062AE3954B4046ED7E15E0AD4E40C763062AE3954B4046ED7E15E0AD4E40A65EB7088C954B402906483481AC4E40A65EB7088C954B40
43450	66	61.398637000000001	61.400281	55.184401999999999	55.167786	 Кирова	0103000020E61000000100000005000000DFFC868906B34E40035DFB027A954B40DFFC868906B34E4093A8177C9A974B40E71A66683CB34E4093A8177C9A974B40E71A66683CB34E40035DFB027A954B40DFFC868906B34E40035DFB027A954B40
43470	66	61.294027999999997	61.411591000000001	55.178722	55.159875999999997	 Братьев Кашириных	0103000020E61000000100000005000000DC0DA2B5A2A54E4028B517D176944B40DC0DA2B5A2A54E40B189CC5CE0964B40FA298E03AFB44E40B189CC5CE0964B40FA298E03AFB44E4028B517D176944B40DC0DA2B5A2A54E4028B517D176944B40
43124	66	61.425218000000001	61.437471000000002	55.148251000000002	55.122138	 Барбюса	0103000020E61000000100000005000000D4D51D8B6DB64E40A7CCCD37A28F4B40D4D51D8B6DB64E40B64C86E3F9924B4066F9BA0CFFB74E40B64C86E3F9924B4066F9BA0CFFB74E40A7CCCD37A28F4B40D4D51D8B6DB64E40A7CCCD37A28F4B40
43442	66	61.436608999999997	61.491945000000001	55.217464999999997	55.179236000000003	 Бажова	0103000020E61000000100000005000000D311C0CDE2B74E4008228B34F1964B40D311C0CDE2B74E402783A3E4D59B4B402237C30DF8BE4E402783A3E4D59B4B402237C30DF8BE4E4008228B34F1964B40D311C0CDE2B74E4008228B34F1964B40
42636	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Электростальская	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
43687	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Шоссейная	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
43078	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Фрунзе	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
43558	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Станционная	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
42626	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Советская	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
42869	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Мира	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
43952	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Миасское шоссе	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
42628	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Ленина	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
42627	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Комсомольская	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
42681	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Каширина	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
43204	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	Карпенко	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
42631	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	9 Мая	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
43495	27323	60.28734	60.464173000000002	55.031303000000001	54.953690000000002	1 Мая	0103000020E61000000100000005000000946A9F8EC7244E40D9429083127A4B40946A9F8EC7244E4023A298BC01844B40D65757056A3B4E4023A298BC01844B40D65757056A3B4E40D9429083127A4B40946A9F8EC7244E40D9429083127A4B40
42927	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Советская	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
42772	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Революционная	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43272	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Рабочая	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43287	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Первомайская	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
42905	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	МКР3	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
42998	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	МКР2	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
42771	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	МКР1	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43280	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Ломоносова	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43341	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Ленина	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43706	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Крупской	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43271	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Комсомольская	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
44290	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	Железнодорожный переулок	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43741	29076	58.109617	58.201577999999998	54.956347000000001	54.901434999999999	40 Лет Октября	0103000020E61000000100000005000000F60A0BEE070E4D40213CDA3862734B40F60A0BEE070E4D4059501894697A4B40EACBD24ECD194D4059501894697A4B40EACBD24ECD194D40213CDA3862734B40F60A0BEE070E4D40213CDA3862734B40
43338	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Челябинская	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43321	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Циолковского	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43489	55144	61.565202999999997	61.697003000000002	54.079988999999998	54.002415999999997	Троицкая	0103000020E61000000100000005000000F04C689258C84E405A7EE02A4F004B40F04C689258C84E4016855D143D0A4B40611BF16437D94E4016855D143D0A4B40611BF16437D94E405A7EE02A4F004B40F04C689258C84E405A7EE02A4F004B40
43375	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Субботина	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43340	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Строителей	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43370	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Советская	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43356	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Серафимовича	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43326	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Путевая	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43600	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Новая	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43365	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Малышева	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43346	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Ленина	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43335	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Культуры	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43393	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Крупской	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43309	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Крахмалева	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43371	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Красноармейская	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43301	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Климова	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43381	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Кирова	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43319	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Качинского	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43331	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Инженерная	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43376	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Иванова	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43324	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Жиркомбинат	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43359	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Дерибаса	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43358	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Гастелло	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43290	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Гагарина	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43327	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	Автодромная	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43352	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	5 микрорайон	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43373	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	2 микрорайон	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
43332	55144	61.511187	61.652276000000001	54.142985000000003	54.036520000000003	10 квартал	0103000020E61000000100000005000000F7915B936EC14E4031D3F6AFAC044B40F7915B936EC14E40C7681D554D124B409CFBABC77DD34E40C7681D554D124B409CFBABC77DD34E4031D3F6AFAC044B40F7915B936EC14E4031D3F6AFAC044B40
42890	55116	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Мира	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
42996	55123	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Свердлова	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43440	55123	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Дзержинского	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
44194	25916	61.432962000000003	61.453029999999998	55.036797999999997	54.996091999999997	Шоссейная	0103000020E6100000010000000500000094347F4C6BB74E4053E751F17F7F4B4094347F4C6BB74E407347FFCBB5844B40AE0D15E3FCB94E407347FFCBB5844B40AE0D15E3FCB94E4053E751F17F7F4B4094347F4C6BB74E4053E751F17F7F4B40
43215	48194	57.637543999999998	57.769343999999997	55.094416000000002	55.018757999999998	Симская	0103000020E6100000010000000500000069E1B20A9BD14C40E94482A966824B4069E1B20A9BD14C400D1CD0D2158C4B40D9AF3BDD79E24C400D1CD0D2158C4B40D9AF3BDD79E24C40E94482A966824B4069E1B20A9BD14C40E94482A966824B40
43276	48194	57.664053000000003	57.731749999999998	55.060234999999999	54.978549999999998	Нагорная	0103000020E61000000100000005000000C5E74EB0FFD44C401AC05B20417D4B40C5E74EB0FFD44C408B89CDC7B5874B408B6CE7FBA9DD4C408B89CDC7B5874B408B6CE7FBA9DD4C401AC05B20417D4B40C5E74EB0FFD44C401AC05B20417D4B40
43722	48194	57.664053000000003	57.731749999999998	55.060234999999999	54.978549999999998	Лесная	0103000020E61000000100000005000000C5E74EB0FFD44C401AC05B20417D4B40C5E74EB0FFD44C408B89CDC7B5874B408B6CE7FBA9DD4C408B89CDC7B5874B408B6CE7FBA9DD4C401AC05B20417D4B40C5E74EB0FFD44C401AC05B20417D4B40
43474	48194	57.664053000000003	57.731749999999998	55.060234999999999	54.978549999999998	Курчатова	0103000020E61000000100000005000000C5E74EB0FFD44C401AC05B20417D4B40C5E74EB0FFD44C408B89CDC7B5874B408B6CE7FBA9DD4C408B89CDC7B5874B408B6CE7FBA9DD4C401AC05B20417D4B40C5E74EB0FFD44C401AC05B20417D4B40
43475	48194	57.664053000000003	57.731749999999998	55.060234999999999	54.978549999999998	Кирова	0103000020E61000000100000005000000C5E74EB0FFD44C401AC05B20417D4B40C5E74EB0FFD44C408B89CDC7B5874B408B6CE7FBA9DD4C408B89CDC7B5874B408B6CE7FBA9DD4C401AC05B20417D4B40C5E74EB0FFD44C401AC05B20417D4B40
43361	48194	57.664053000000003	57.731749999999998	55.060234999999999	54.978549999999998	Заводская	0103000020E61000000100000005000000C5E74EB0FFD44C401AC05B20417D4B40C5E74EB0FFD44C408B89CDC7B5874B408B6CE7FBA9DD4C408B89CDC7B5874B408B6CE7FBA9DD4C401AC05B20417D4B40C5E74EB0FFD44C401AC05B20417D4B40
42763	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	площадь Ленина	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43000	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	микрорайон Западный	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43354	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	Солнечная	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43384	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	Пролетарская	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43342	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	Матросова	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43388	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	Ленина	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43745	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	Куйбышева	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43480	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	Кирова	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43728	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	Карла Маркса	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43725	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	50 лет ВЛКСМ	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43394	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	50 Лет ВЛКСМ	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43453	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	40 Лет Победы	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43645	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	4 квартал	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
42767	55105	58.912208	59.081153999999998	55.073571999999999	55.023913999999998	100летия Комбината Магнезит	0103000020E610000001000000050000002593533BC3744D4051F52B9D0F834B402593533BC3744D405EF3AACE6A894B4044F81741638A4D405EF3AACE6A894B4044F81741638A4D4051F52B9D0F834B402593533BC3744D4051F52B9D0F834B40
43040	55097	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	Проходчиков	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
42865	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	Учебный городок	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
43827	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	Строителей	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
43200	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	Приисковый	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
42621	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	Октябрьская	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
42625	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	Мамина-Сибиряка	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
43594	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	Красноармейская	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
42870	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	9 Января	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
43059	13165	60.788060999999999	60.875404000000003	54.401815999999997	54.323456	 Володарского	0103000020E610000001000000050000006420CF2EDF644E40F5D8960167294B406420CF2EDF644E403881E9B46E334B40D064FF3C0D704E403881E9B46E334B40D064FF3C0D704E40F5D8960167294B406420CF2EDF644E40F5D8960167294B40
43443	55153	57.151249999999997	57.164634	55.082616999999999	55.070143999999999	Нечепуренко	0103000020E610000001000000050000008FC2F5285C934C405C01857AFA884B408FC2F5285C934C40FC8BA031938A4B40A3E716BA12954C40FC8BA031938A4B40A3E716BA12954C405C01857AFA884B408FC2F5285C934C405C01857AFA884B40
43255	55134	38.494894000000002	38.500211999999998	54.858320999999997	54.857030000000002	Цветочная	0103000020E610000001000000050000004A7EC4AF583F43406FD8B628B36D4B404A7EC4AF583F4340293C6876DD6D4B408B8862F206404340293C6876DD6D4B408B8862F2064043406FD8B628B36D4B404A7EC4AF583F43406FD8B628B36D4B40
42774	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Южная	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43417	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Уральская	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43152	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Театральная	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
42909	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Студенческая	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43357	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Советская	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43266	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Семенова	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43378	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Победы проспект	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43264	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Матросова	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43467	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Лермонтова	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43161	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Красная	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43258	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Космонавтов	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43318	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Карла Маркса	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43426	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Калинина	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43316	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Иртышская	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
42770	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Ермолаева	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43312	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Герцена	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43245	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Гайдара	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43466	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Блюхера	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43364	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	Бажова	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
43313	55108	60.668801000000002	60.731403999999998	55.779985000000003	55.747287	8 Марта	0103000020E610000001000000050000001C446B459B554E40ECDCB419A7DF4B401C446B459B554E406F2F698CD6E34B40F01472A59E5D4E406F2F698CD6E34B40F01472A59E5D4E40ECDCB419A7DF4B401C446B459B554E40ECDCB419A7DF4B40
44051	20261	61.076293999999997	61.081235	53.955246000000002	53.951706999999999	Строительная	0103000020E61000000100000005000000C5707500C4894E40E82FF488D1F94A40C5707500C4894E4042D13C8045FA4A40312592E8658A4E4042D13C8045FA4A40312592E8658A4E40E82FF488D1F94A40C5707500C4894E40E82FF488D1F94A40
43650	7310	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	Южная	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
43793	7310	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	Свободы	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
42761	7310	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	Свердлова	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
44284	7310	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	Ленина	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
42762	7310	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	Колина	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
43156	7310	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	Клубная	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
42760	7310	59.553865999999999	59.625290999999997	56.066403999999999	55.997622999999997	Бархатовой	0103000020E61000000100000005000000E42EC214E5C64D40635E471CB2FF4B40E42EC214E5C64D406B2920ED7F084C40D7BD158909D04D406B2920ED7F084C40D7BD158909D04D40635E471CB2FF4B40E42EC214E5C64D40635E471CB2FF4B40
43719	1180	61.337668000000001	61.340201999999998	55.313547	55.313310999999999	Садовая	0103000020E61000000100000005000000EF737CB438AB4E40103D29931AA84B40EF737CB438AB4E402461DF4E22A84B40530438BD8BAB4E402461DF4E22A84B40530438BD8BAB4E40103D29931AA84B40EF737CB438AB4E40103D29931AA84B40
43277	55140	57.502293000000002	57.587668999999998	55.085296	55.044299000000002	Чертова	0103000020E610000001000000050000003F0114234BC04C406D1FF296AB854B403F0114234BC04C40643DB5FAEA8A4B40BFEFDFBC38CB4C40643DB5FAEA8A4B40BFEFDFBC38CB4C406D1FF296AB854B403F0114234BC04C406D1FF296AB854B40
43479	55140	57.502293000000002	57.587668999999998	55.085296	55.044299000000002	Центральная	0103000020E610000001000000050000003F0114234BC04C406D1FF296AB854B403F0114234BC04C40643DB5FAEA8A4B40BFEFDFBC38CB4C40643DB5FAEA8A4B40BFEFDFBC38CB4C406D1FF296AB854B403F0114234BC04C406D1FF296AB854B40
43325	55140	57.502293000000002	57.587668999999998	55.085296	55.044299000000002	Советская	0103000020E610000001000000050000003F0114234BC04C406D1FF296AB854B403F0114234BC04C40643DB5FAEA8A4B40BFEFDFBC38CB4C40643DB5FAEA8A4B40BFEFDFBC38CB4C406D1FF296AB854B403F0114234BC04C406D1FF296AB854B40
43737	55140	57.502293000000002	57.587668999999998	55.085296	55.044299000000002	Куйбышева	0103000020E610000001000000050000003F0114234BC04C406D1FF296AB854B403F0114234BC04C40643DB5FAEA8A4B40BFEFDFBC38CB4C40643DB5FAEA8A4B40BFEFDFBC38CB4C406D1FF296AB854B403F0114234BC04C406D1FF296AB854B40
43723	55140	57.502293000000002	57.587668999999998	55.085296	55.044299000000002	Кирова	0103000020E610000001000000050000003F0114234BC04C406D1FF296AB854B403F0114234BC04C40643DB5FAEA8A4B40BFEFDFBC38CB4C40643DB5FAEA8A4B40BFEFDFBC38CB4C406D1FF296AB854B403F0114234BC04C406D1FF296AB854B40
42605	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	проспект Октября	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42603	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	проспект Макеева	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42613	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	проспект Автозаводцев	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42607	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	проезд Автозаводцев	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42604	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	пр.Макеева	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43216	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	пр. Макеева	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42853	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	пл.Предзаводская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43487	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Школьная	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43190	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Циолковского	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42857	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Степана Разина	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42866	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Советская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43198	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Романенко	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43203	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Ровная	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42617	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Пушкина	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42616	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Пролетарская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42861	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Первомайская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42864	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Осипенко	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42970	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Орловская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43485	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Озерная	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42609	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Нахимова	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43483	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Нагорная	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43192	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Макурина	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42976	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Макеева проспект	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42614	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Лихачева	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42974	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Ленина	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42849	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Курортная	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42860	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Кирова	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42852	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Керченская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42606	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Калинина	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42991	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Зеленая	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42851	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Донская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42650	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Готвальда	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42862	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Герцена	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43195	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Вернадского	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43070	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Березовская	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42611	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Ак.Павлова	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42854	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	Автозаводцев	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42629	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	8 Марта	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42859	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	8 Июля	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42618	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	60 лет октября	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42615	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	60 лет Октября	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
43508	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	40 лет Октября	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42850	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	 пр.Октября	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42619	7529	60.034294000000003	60.168807000000001	55.164659	54.965604999999996	 Нефтянников	0103000020E610000001000000050000007A39ECBE63044E4052EDD3F1987B4B407A39ECBE63044E40FCFECD8B13954B40FE2AC0779B154E40FCFECD8B13954B40FE2AC0779B154E4052EDD3F1987B4B407A39ECBE63044E4052EDD3F1987B4B40
42786	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	проспект Пушкина	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43390	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	проспект Ленина 	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42788	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	проспект Ленина	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42634	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	проспект К. Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42683	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	проспект К. Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42911	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	проезд Сиреневый	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42672	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	проезд Карла Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42787	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	пр.Карла Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42779	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	пр. Карла Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43256	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	пр. К. Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43269	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	переулок Советский	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43011	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	пер. Советский	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43246	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	имени газеты Правда	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43166	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Ярославского	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43631	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Шоссейная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42780	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Школьный переулок	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43546	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Чкалова 	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42804	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Чкалова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43247	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Урицкого	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43344	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Уральская	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42914	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Труда	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42785	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Тихвинский переулок	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42794	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Тевосяна	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43283	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Суворова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
41580	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Строителей проспект	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43363	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Сталеваров	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42810	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Сосновая	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42781	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Советской армии	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42916	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Советская	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43171	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Рубинштейна	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43170	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Ржевского переулок	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43507	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Проспект Пушкина	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42799	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Проспект Карла Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42971	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Проезд Сереневый	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43006	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Полевая	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43502	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Покровская	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42782	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Планерная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43007	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Писарева	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42999	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Панькова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43368	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Набережная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42784	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Н.Шишка	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43281	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Московская	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43259	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Менделеева	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42789	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Маяковского	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43372	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Ломоносова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43260	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Лесопарковая	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43379	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Ленинградская	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43300	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Ленина проспект	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43397	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Комсомольская	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42653	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Коммунаров	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43005	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Коммунальная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43185	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Карла Маркса проспект	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43351	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Карла Маркса	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42809	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Калмыкова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43429	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Калинина	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43243	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Казакова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43343	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Индустриальная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42915	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Жукова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43009	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Жемчужная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43004	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Енисейская	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43315	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Дружбы	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42792	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Доменщиков	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42777	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Грязнова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42791	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Галиуллина	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43437	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Гагарина	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42656	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Ворошилова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43286	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Вокзальная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43297	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Войкова	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42806	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Бориса Ручьева	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42910	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Белинского	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43674	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	Бахметьева	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42797	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	50-летия Магнитки	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
43310	2116	58.8977	59.196210000000001	53.499690000000001	53.304834999999997	 Вокзальная	0103000020E6100000010000000500000042CF66D5E7724D408CD651D504A74A4042CF66D5E7724D40B21188D7F5BF4A40F792C6681D994D40B21188D7F5BF4A40F792C6681D994D408CD651D504A74A4042CF66D5E7724D408CD651D504A74A40
42783	55110	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Мира	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43565	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Школьная	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43235	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Челюскинцев	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
44095	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Станционная	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43547	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Садовая	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
42657	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Республики	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
42759	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Ленина	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
42673	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Кирова	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
42757	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Интернационала	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43520	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Дальняя	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43232	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Гагарина	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
42678	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Вокзальная	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43233	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	В. Сергеевой	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
42721	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	Бажова	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43234	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	2 Южная	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
42903	3348	60.499845999999998	60.597923999999999	55.744332999999997	55.669426999999999	 Ветеранов	0103000020E61000000100000005000000A98427F4FA3F4E409A07B0C8AFD54B40A98427F4FA3F4E40B22AC24D46DF4B402BBF0CC6884C4E40B22AC24D46DF4B402BBF0CC6884C4E409A07B0C8AFD54B40A98427F4FA3F4E409A07B0C8AFD54B40
43307	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Спартака	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
42661	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Советская	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
42904	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Свободы	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
43721	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Свердлова	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
42667	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Правды	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
42997	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Ленинградская	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
43033	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Есенина	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
43305	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	Бубнова	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
43716	55092	59.391711000000001	59.473754	55.362485	55.314996999999998	3 Интернационала	0103000020E61000000100000005000000E23D079623B24D4047AB5AD251A84B40E23D079623B24D40312592E865AE4B40B22C98F8A3BC4D40312592E865AE4B40B22C98F8A3BC4D4047AB5AD251A84B40E23D079623B24D4047AB5AD251A84B40
43980	16949	61.521500000000003	61.533267000000002	55.251660000000001	55.243161000000001	Озерная	0103000020E61000000100000005000000986E1283C0C24E40D2544FE61F9F4B40986E1283C0C24E400EDB166536A04B409D84D21742C44E400EDB166536A04B409D84D21742C44E40D2544FE61F9F4B40986E1283C0C24E40D2544FE61F9F4B40
43407	55152	61.317950000000003	61.324579999999997	55.203704000000002	55.189069000000003	Солнечная	0103000020E61000000100000005000000B1E1E995B2A84E40FED7B96933984B40B1E1E995B2A84E403E0801F9129A4B40C47762D68BA94E403E0801F9129A4B40C47762D68BA94E40FED7B96933984B40B1E1E995B2A84E40FED7B96933984B40
42934	55122	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	Победы	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
42925	55122	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	Ленина	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
43118	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Энгельса	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42941	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Чкалова	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42937	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Цвиллинга	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42689	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Сони Кривой	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42940	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Пушкова	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
43588	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Пролетарская	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
43024	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Новый	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42942	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Моргунова	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
43023	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Мира	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
43672	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Ленина	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
44009	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Керамиков	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
43580	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Заводская	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42687	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	Горняков	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42933	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	9 Января	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
43122	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	30 лет ВЛКСМ	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42939	26226	61.323402999999999	61.432791000000002	54.914178	54.874212	1 Мая	0103000020E61000000100000005000000D236FE4465A94E40A8E2C62DE66F4B40D236FE4465A94E40815CE2C803754B4067800BB265B74E40815CE2C803754B4067800BB265B74E40A8E2C62DE66F4B40D236FE4465A94E40A8E2C62DE66F4B40
42680	55095	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Меховова	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43039	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	проспект Славы	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43478	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	проспект Победы	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43392	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	пр. Победы	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
42920	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	пр. Ильича	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43350	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Электровозная	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43323	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Черняховского	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43347	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Чернышевского	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43383	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Троицкая	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
42929	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Театральная	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43022	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Свободы переулок	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43714	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Саратовская	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43436	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Российская	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43382	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Победы проспект	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43418	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Пионерская	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43746	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Орджоникидзе	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43189	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Новосибирская	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
42930	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Меховова	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
42688	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Лихачева	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43021	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Лизы Чайкиной	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43333	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Ленина	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43385	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Кузнецова	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
42686	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Коммунистический проспект	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43330	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Коммунистическая	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43469	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Калинина	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43720	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Ильфа	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43036	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Забойщиков	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
42664	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Гольца	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43116	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Борьбы	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43120	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	4 Пятилетка	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
42932	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	21 Партсъезда	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43114	55093	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	16 лет Октября	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43322	55126	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Октябрьская	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43121	55126	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Жданова	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
43389	55151	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	Карла Маркса	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
8834	35919	49.694667000000003	49.700181999999998	58.578302000000001	58.577997000000003	улица Приозерная	0103000020E61000000100000005000000234E27D9EAD84840D31742CEFB494D40234E27D9EAD848400F9BC8CC054A4D40BA9F53909FD948400F9BC8CC054A4D40BA9F53909FD94840D31742CEFB494D40234E27D9EAD84840D31742CEFB494D40
43531	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Цементников	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
43525	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Учительская	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
42901	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Степана Разина	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
42891	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Остров	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
43585	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Лесная	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
43160	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Ленина	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
43094	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Коммунальная	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
43093	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Дмитрия Тараканова	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
42907	55117	58.139504000000002	58.257551999999997	54.799303000000002	54.730822000000003	Гагарина	0103000020E61000000100000005000000A2D45E44DB114D40429946938B5D4B40A2D45E44DB114D401F4C8A8F4F664B407B82C476F7204D401F4C8A8F4F664B407B82C476F7204D40429946938B5D4B40A2D45E44DB114D40429946938B5D4B40
43610	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	Стадионная	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43609	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	Ретнева	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43515	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	Луначарского	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43689	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	Лобашова	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43511	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	Ленина	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43154	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	Куйбышева	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43514	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	Калинина	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43506	12375	60.723866999999998	60.797187999999998	55.913369000000003	55.861919	8 марта	0103000020E61000000100000005000000AAD381ACA75C4E4088669E5C53EE4B40AAD381ACA75C4E4012178046E9F44B40BF61A2410A664E4012178046E9F44B40BF61A2410A664E4088669E5C53EE4B40AAD381ACA75C4E4088669E5C53EE4B40
43575	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Хладопункт	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43367	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Учебный переулок	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43206	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Славы	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
42935	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Свердлова	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
42816	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Просвещения	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43293	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Орджоникидзе	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
42834	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Лобырина	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43401	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Ленина	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
42924	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Карташева	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43345	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Гагарина	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43353	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Братьев Кашириных	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43018	55111	60.598264999999998	60.728017999999999	53.088605999999999	53.028905999999999	Акмолинская	0103000020E61000000100000005000000B4AB90F2934C4E403F541A31B3834A40B4AB90F2934C4E405C1D0071578B4A401D739EB12F5D4E405C1D0071578B4A401D739EB12F5D4E403F541A31B3834A40B4AB90F2934C4E403F541A31B3834A40
43157	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Ремесленная	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
43717	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Пролетарская	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
42855	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Подлесная	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
43560	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Освобождение Урала	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
43409	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Металлургов	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
43718	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Комсомольская	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
43464	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Клубная	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
43630	13447	60.169266	60.257444	55.512672999999999	55.408766999999997	Декабристов	0103000020E6100000010000000500000091291F82AA154E408E57207A52B44B4091291F82AA154E406745D4449FC14B409546CCECF3204E406745D4449FC14B409546CCECF3204E408E57207A52B44B4091291F82AA154E408E57207A52B44B40
43061	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	прт Гагарина	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42592	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	проспект Мира	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42641	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	проспект Гагарина, 5 линия	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42589	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	проспект Гагарина	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43187	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	пос. Строителей	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43049	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Шишкина	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43053	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Чкалова	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43177	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Тургенева	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43680	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Тихомирова	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43168	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Тельмана	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42844	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Румянцева	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42595	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Профсоюзная	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42602	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Просвещения	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42640	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Октябрьская	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43048	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Н.Вокзальная	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42847	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Мира проспект	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43063	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Металлургов	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42639	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Машиностроителей	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43523	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Ленина	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43057	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Ленина	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42598	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Кусинское шоссе	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43046	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Космонавтов	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43054	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Копровая	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43173	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Ковшова	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43042	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Кирова	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42610	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Карла Маркса	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42975	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	К. Заслонова	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42846	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Зеленая	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43062	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Дворцовая	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42858	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Горького	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43155	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Веселовская	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42856	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	В. Рязанова	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43075	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Б. Кирпичная	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42843	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	Аносова	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43169	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	8го Марта	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42590	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	40летия Победы	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42597	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	40-летия Победы	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42591	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	40 лет Победы	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42845	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	3я Тесьминская	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42600	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	3я Н.Заводская	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42599	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	30 лет ВЛКСМ	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42601	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	2 квартал	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43052	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	1я Нагорная	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43186	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	1-я Н.Заводская	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
42593	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	 прт Гагарина	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43043	7465	59.613334000000002	59.781427000000001	55.217511000000002	55.074081999999997	 2я Закаменская	0103000020E610000001000000050000002FC37FBA81CE4D40739CDB847B894B402FC37FBA81CE4D4098C28366D79B4B400F9BC8CC05E44D4098C28366D79B4B400F9BC8CC05E44D40739CDB847B894B402FC37FBA81CE4D40739CDB847B894B40
43013	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Школенко	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
42836	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Чкалова	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43119	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Чайковского	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43111	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Фрунзе	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43016	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Титова	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
42684	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Спартака	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43387	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Советская	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43109	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Матросова	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
42835	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Горького	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
42830	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Гагарина	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43108	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Восточная	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43107	20314	61.292869000000003	61.379888999999999	54.808954999999997	54.739196	Вахрушева	0103000020E6100000010000000500000091813CBB7CA54E40C1AA7AF99D5E4B4091813CBB7CA54E40C47762D68B674B40198EE733A0B04E40C47762D68B674B40198EE733A0B04E40C1AA7AF99D5E4B4091813CBB7CA54E40C1AA7AF99D5E4B40
43084	55099	60.173344	60.291553	56.082908000000003	56.001801	Халтурина	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43226	55099	60.173344	60.291553	56.082908000000003	56.001801	Суворова	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43219	55099	60.173344	60.291553	56.082908000000003	56.001801	Прямицына	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
42754	55099	60.173344	60.291553	56.082908000000003	56.001801	Окишева	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
42732	55099	60.173344	60.291553	56.082908000000003	56.001801	Ленина	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43220	55099	60.173344	60.291553	56.082908000000003	56.001801	Бабикова	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43336	55147	59.186903999999998	59.246569999999998	53.898066	53.852186000000003	Советская	0103000020E61000000100000005000000ECBE6378EC974D40F60D4C6E14ED4A40ECBE6378EC974D4024D3A1D3F3F24A405D16139B8F9F4D4024D3A1D3F3F24A405D16139B8F9F4D40F60D4C6E14ED4A40ECBE6378EC974D40F60D4C6E14ED4A40
43756	34229	59.902222999999999	59.912069000000002	54.254246000000002	54.245660999999998	Новая	0103000020E610000001000000050000007959130B7CF34D408A73D4D1711F4B407959130B7CF34D40C59107228B204B4004594FADBEF44D40C59107228B204B4004594FADBEF44D408A73D4D1711F4B407959130B7CF34D408A73D4D1711F4B40
43805	55177	61.483159000000001	61.614960000000004	55.334950999999997	55.259751000000001	Железнодорожная	0103000020E6100000010000000500000050E27327D8BD4E40390D51853FA14B4050E27327D8BD4E409961A3ACDFAA4B40912C6002B7CE4E409961A3ACDFAA4B40912C6002B7CE4E40390D51853FA14B4050E27327D8BD4E40390D51853FA14B40
43400	55100	61.361958999999999	61.373717999999997	55.123533000000002	55.118833000000002	Центральная	0103000020E6100000010000000500000016BF29AC54AE4E40C15774EB358F4B4016BF29AC54AE4E40077DE9EDCF8F4B4098F6CDFDD5AF4E40077DE9EDCF8F4B4098F6CDFDD5AF4E40C15774EB358F4B4016BF29AC54AE4E40C15774EB358F4B40
43339	55100	61.418975000000003	61.452275	55.127676999999998	55.122523999999999	Фрунзе	0103000020E61000000100000005000000BA6B09F9A0B54E40D07CCEDDAE8F4B40BA6B09F9A0B54E40C7B94DB857904B4032E6AE25E4B94E40C7B94DB857904B4032E6AE25E4B94E40D07CCEDDAE8F4B40BA6B09F9A0B54E40D07CCEDDAE8F4B40
43212	55100	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	Узкоколейная	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
43712	55100	61.282223999999999	61.285179999999997	55.156168000000001	55.154696999999999	Тополиная	0103000020E61000000100000005000000BA1281EA1FA44E4008E57D1CCD934B40BA1281EA1FA44E4043572250FD934B4094BC3AC780A44E4043572250FD934B4094BC3AC780A44E4008E57D1CCD934B40BA1281EA1FA44E4008E57D1CCD934B40
43730	55100	61.426907	61.456479000000002	55.123899000000002	55.117230999999997	Толстого	0103000020E610000001000000050000007CB779E3A4B64E40E789E76C018F4B407CB779E3A4B64E40E98024ECDB8F4B40C82764E76DBA4E40E98024ECDB8F4B40C82764E76DBA4E40E789E76C018F4B407CB779E3A4B64E40E789E76C018F4B40
43360	55100	61.465237999999999	61.476916000000003	55.192979999999999	55.158996999999999	Танкистов	0103000020E61000000100000005000000A06D35EB8CBB4E40C09481035A944B40A06D35EB8CBB4E401B649291B3984B4036785F950BBD4E401B649291B3984B4036785F950BBD4E40C09481035A944B40A06D35EB8CBB4E40C09481035A944B40
43736	55100	61.405734000000002	61.406371	55.167991999999998	55.160504000000003	Советская	0103000020E6100000010000000500000009707A17EFB34E40487023658B944B4009707A17EFB34E40ACFE08C380954B407B8505F703B44E40ACFE08C380954B407B8505F703B44E40487023658B944B4009707A17EFB34E40487023658B944B40
42747	55100	57.637543999999998	57.769343999999997	55.094416000000002	55.018757999999998	Симская	0103000020E6100000010000000500000069E1B20A9BD14C40E94482A966824B4069E1B20A9BD14C400D1CD0D2158C4B40D9AF3BDD79E24C400D1CD0D2158C4B40D9AF3BDD79E24C40E94482A966824B4069E1B20A9BD14C40E94482A966824B40
42743	55100	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	Озимина	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
43593	55100	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	Некрасова	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
44319	55100	61.368758999999997	61.403173000000002	55.254795000000001	55.245095999999997	Мира	0103000020E61000000100000005000000868DB27E33AF4E40B130444E5F9F4B40868DB27E33AF4E409817601F9DA04B40ABD0402C9BB34E409817601F9DA04B40ABD0402C9BB34E40B130444E5F9F4B40868DB27E33AF4E40B130444E5F9F4B40
43377	55100	61.364294000000001	61.502374000000003	55.161259999999999	55.156326999999997	Ленина	0103000020E610000001000000050000008410902FA1AE4E40AB3DEC8502944B408410902FA1AE4E409413ED2AA4944B402C2E8ECA4DC04E409413ED2AA4944B402C2E8ECA4DC04E40AB3DEC8502944B408410902FA1AE4E40AB3DEC8502944B40
42736	55100	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	Лебедева	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
43747	55100	61.381273	61.398529000000003	55.153317999999999	55.146084999999999	Курчатова	0103000020E6100000010000000500000085ECBC8DCDB04E40D4B7CCE9B2924B4085ECBC8DCDB04E40AEF199EC9F934B40F9C08EFF02B34E40AEF199EC9F934B40F9C08EFF02B34E40D4B7CCE9B2924B4085ECBC8DCDB04E40D4B7CCE9B2924B40
43261	55100	61.396894000000003	61.402813999999999	55.261721000000001	55.261187	Коммунистическая	0103000020E6100000010000000500000044FD2E6CCDB24E40F7915B936EA14B4044FD2E6CCDB24E4095D6DF1280A14B407B2FBE688FB34E4095D6DF1280A14B407B2FBE688FB34E40F7915B936EA14B4044FD2E6CCDB24E40F7915B936EA14B40
43396	55100	61.372881999999997	61.379018000000002	55.134497000000003	55.129885000000002	Декабристов	0103000020E610000001000000050000002FA2ED98BAAF4E40D89E5912A0904B402FA2ED98BAAF4E407F349C3237914B40344C6DA983B04E407F349C3237914B40344C6DA983B04E40D89E5912A0904B402FA2ED98BAAF4E40D89E5912A0904B40
43083	55100	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	Давыдова	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
43473	55100	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	40 Лет Победы	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
43087	55100	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	22 Партсъезда	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
44228	5091	61.122853999999997	61.133760000000002	54.406359000000002	54.401024	Нижняя 	0103000020E6100000010000000500000065170CAEB98F4E409F7422C154334B4065170CAEB98F4E40B7B75B9203344B40A9C1340C1F914E40B7B75B9203344B40A9C1340C1F914E409F7422C154334B4065170CAEB98F4E409F7422C154334B40
44107	29960	58.468000000000004	58.497976999999999	54.989936	54.970933000000002	Школьная	0103000020E6100000010000000500000096438B6CE73B4D40B8CD5488477C4B4096438B6CE73B4D4008910C39B67E4B408194D8B5BD3F4D4008910C39B67E4B408194D8B5BD3F4D40B8CD5488477C4B4096438B6CE73B4D40B8CD5488477C4B40
43979	30008	58.237985999999999	58.260129999999997	55.013326999999997	54.995435999999998	Долгая	0103000020E61000000100000005000000F3734353761E4D406AA164726A7F4B40F3734353761E4D40AF93FAB2B4814B40AF5A99F04B214D40AF93FAB2B4814B40AF5A99F04B214D406AA164726A7F4B40F3734353761E4D406AA164726A7F4B40
44019	29816	58.090159999999997	58.106653000000001	54.921686000000001	54.916629999999998	Центральная	0103000020E6100000010000000500000024B4E55C8A0B4D402844C02154754B4024B4E55C8A0B4D402D978DCEF9754B40998235CEA60D4D402D978DCEF9754B40998235CEA60D4D402844C02154754B4024B4E55C8A0B4D402844C02154754B40
43978	30050	58.212716999999998	58.223272000000001	55.119985999999997	55.109960999999998	Нижняя	0103000020E61000000100000005000000D026874F3A1B4D40F06AB933138E4B40D026874F3A1B4D402AFD84B35B8F4B40670E492D941C4D402AFD84B35B8F4B40670E492D941C4D40F06AB933138E4B40D026874F3A1B4D40F06AB933138E4B40
44215	20590	60.754275	60.768594999999998	54.502502	54.493910999999997	Новоселов	0103000020E610000001000000050000005F984C158C604E403C11C479383F4B405F984C158C604E4059164CFC51404B403F6F2A5261624E4059164CFC51404B403F6F2A5261624E403C11C479383F4B405F984C158C604E403C11C479383F4B40
44054	20902	60.44238	60.452252999999999	54.475175999999998	54.464832000000001	Нагорная	0103000020E61000000100000005000000C63368E89F384E4030116F9D7F3B4B40C63368E89F384E400BEC3191D23C4B404A42226DE3394E400BEC3191D23C4B404A42226DE3394E4030116F9D7F3B4B40C63368E89F384E4030116F9D7F3B4B40
44056	20486	60.789624000000003	60.814596999999999	54.444335000000002	54.435580000000002	Советская	0103000020E610000001000000050000008011346612654E405665DF15C1374B408011346612654E40EDBB22F8DF384B40B935E9B644684E40EDBB22F8DF384B40B935E9B644684E405665DF15C1374B408011346612654E405665DF15C1374B40
44175	20703	60.578502	60.591383999999998	54.48977	54.482619999999997	Окружная	0103000020E61000000100000005000000D655815A0C4A4E40A032FE7DC63D4B40D655815A0C4A4E40ED478AC8B03E4B4057B08D78B24B4E40ED478AC8B03E4B4057B08D78B24B4E40A032FE7DC63D4B40D655815A0C4A4E40A032FE7DC63D4B40
44176	20614	60.646701999999998	60.681888999999998	54.459991000000002	54.446784999999998	Школьная	0103000020E61000000100000005000000FF209221C7524E40F3AB394030394B40FF209221C7524E4028BA2EFCE03A4B404640852348574E4028BA2EFCE03A4B404640852348574E40F3AB394030394B40FF209221C7524E40F3AB394030394B40
43830	20614	60.646701999999998	60.681888999999998	54.459991000000002	54.446784999999998	Центральная	0103000020E61000000100000005000000FF209221C7524E40F3AB394030394B40FF209221C7524E4028BA2EFCE03A4B404640852348574E4028BA2EFCE03A4B404640852348574E40F3AB394030394B40FF209221C7524E40F3AB394030394B40
43488	21060	60.539954999999999	60.570264000000002	54.212119000000001	54.194248999999999	Ленина	0103000020E61000000100000005000000E527D53E1D454E40EE23B726DD184B40E527D53E1D454E401CEE23B7261B4B40070B2769FE484E401CEE23B7261B4B40070B2769FE484E40EE23B726DD184B40E527D53E1D454E40EE23B726DD184B40
43490	21010	60.656996999999997	60.680658000000001	54.277267999999999	54.261266999999997	Школьная	0103000020E61000000100000005000000F9484A7A18544E401343723271214B40F9484A7A18544E40191D90847D234B4061E124CD1F574E40191D90847D234B4061E124CD1F574E401343723271214B40F9484A7A18544E401343723271214B40
43669	21010	60.656996999999997	60.680658000000001	54.277267999999999	54.261266999999997	Садовая	0103000020E61000000100000005000000F9484A7A18544E401343723271214B40F9484A7A18544E40191D90847D234B4061E124CD1F574E40191D90847D234B4061E124CD1F574E401343723271214B40F9484A7A18544E401343723271214B40
44154	55207	59.965150000000001	59.982532999999997	54.833691999999999	54.819040999999999	Зеленая	0103000020E6100000010000000500000001DE02098AFB4D40A48AE255D6684B4001DE02098AFB4D40EA77616BB66A4B40D11E2FA4C3FD4D40EA77616BB66A4B40D11E2FA4C3FD4D40A48AE255D6684B4001DE02098AFB4D40A48AE255D6684B40
43895	13929	60.262833999999998	60.270685	55.413049999999998	55.404862000000001	Центральная	0103000020E610000001000000050000007023658BA4214E4053B29C84D2B34B407023658BA4214E4070CE88D2DEB44B4046425BCEA5224E4070CE88D2DEB44B4046425BCEA5224E4053B29C84D2B34B407023658BA4214E4053B29C84D2B34B40
43550	31201	60.466033000000003	60.475079000000001	55.584792	55.575561	Солнечный переулок	0103000020E61000000100000005000000ABED26F8A63B4E4031ED9BFBABC94B40ABED26F8A63B4E40317BD976DACA4B4019028063CF3C4E40317BD976DACA4B4019028063CF3C4E4031ED9BFBABC94B40ABED26F8A63B4E4031ED9BFBABC94B40
43800	55175	60.341104000000001	60.374341999999999	55.676783	55.665537999999998	Школьная	0103000020E610000001000000050000007444BE4BA92B4E40641F645930D54B407444BE4BA92B4E4090BE49D3A0D64B4076C24B70EA2F4E4090BE49D3A0D64B4076C24B70EA2F4E40641F645930D54B407444BE4BA92B4E40641F645930D54B40
44191	45733	61.245913999999999	61.268157000000002	54.876035000000002	54.868724999999998	Школьная	0103000020E6100000010000000500000074D0251C7A9F4E40DA1B7C61326F4B4074D0251C7A9F4E40609335EA21704B40C498F4F752A24E40609335EA21704B40C498F4F752A24E40DA1B7C61326F4B4074D0251C7A9F4E40DA1B7C61326F4B40
43743	55098	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	Средняя	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
42713	55098	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	Проходчиков	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
43431	55098	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	Котельный	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
43303	55098	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	Борьбы	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
43477	55098	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	50 Лет Октября	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
43320	55098	61.396616000000002	61.476305000000004	54.936590000000002	54.895615999999997	50 Лет ВЛКСМ	0103000020E6100000010000000500000001892650C4B24E401DE38A8BA3724B4001892650C4B24E405DE15D2EE2774B40EDF5EE8FF7BC4E405DE15D2EE2774B40EDF5EE8FF7BC4E401DE38A8BA3724B4001892650C4B24E401DE38A8BA3724B40
43581	45715	61.312128999999999	61.327643000000002	54.966307999999998	54.934091000000002	Пришкольная	0103000020E610000001000000050000000C91D3D7F3A74E40753E3C4B90774B400C91D3D7F3A74E407CEE04FBAF7B4B40B5E1B034F0A94E407CEE04FBAF7B4B40B5E1B034F0A94E40753E3C4B90774B400C91D3D7F3A74E40753E3C4B90774B40
44080	55200	59.550075	59.561852000000002	54.973697999999999	54.963098000000002	Ленина	0103000020E6100000010000000500000071AC8BDB68C64D40E86B96CB467B4B4071AC8BDB68C64D401E17D522A27C4B409A982EC4EAC74D401E17D522A27C4B409A982EC4EAC74D40E86B96CB467B4B4071AC8BDB68C64D40E86B96CB467B4B40
43113	47851	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	Мира	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
43461	47851	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	Лермонтова	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
42923	47851	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	Ленина	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
42921	47851	61.198196000000003	61.283087000000002	54.630242000000003	54.573808	Западная	0103000020E6100000010000000500000059198D7C5E994E407217618A72494B4059198D7C5E994E40674815C5AB504B401D76DF313CA44E40674815C5AB504B401D76DF313CA44E407217618A72494B4059198D7C5E994E407217618A72494B40
43671	21196	61.220753000000002	61.258257	54.796947000000003	54.771189999999997	Пятилетки	0103000020E6100000010000000500000038BF61A2419C4E4049809A5AB6624B4038BF61A2419C4E409AD2FA5B02664B40467BBC900EA14E409AD2FA5B02664B40467BBC900EA14E4049809A5AB6624B4038BF61A2419C4E4049809A5AB6624B40
43688	21196	61.220753000000002	61.258257	54.796947000000003	54.771189999999997	Новолуговая	0103000020E6100000010000000500000038BF61A2419C4E4049809A5AB6624B4038BF61A2419C4E409AD2FA5B02664B40467BBC900EA14E409AD2FA5B02664B40467BBC900EA14E4049809A5AB6624B4038BF61A2419C4E4049809A5AB6624B40
42838	21196	61.220753000000002	61.258257	54.796947000000003	54.771189999999997	Заводская площадь	0103000020E6100000010000000500000038BF61A2419C4E4049809A5AB6624B4038BF61A2419C4E409AD2FA5B02664B40467BBC900EA14E409AD2FA5B02664B40467BBC900EA14E4049809A5AB6624B4038BF61A2419C4E4049809A5AB6624B40
42893	21196	61.220753000000002	61.258257	54.796947000000003	54.771189999999997	3й квартал	0103000020E6100000010000000500000038BF61A2419C4E4049809A5AB6624B4038BF61A2419C4E409AD2FA5B02664B40467BBC900EA14E409AD2FA5B02664B40467BBC900EA14E4049809A5AB6624B4038BF61A2419C4E4049809A5AB6624B40
43112	21196	61.220753000000002	61.258257	54.796947000000003	54.771189999999997	2й квартал	0103000020E6100000010000000500000038BF61A2419C4E4049809A5AB6624B4038BF61A2419C4E409AD2FA5B02664B40467BBC900EA14E409AD2FA5B02664B40467BBC900EA14E4049809A5AB6624B4038BF61A2419C4E4049809A5AB6624B40
44090	55201	60.173344	60.291553	56.082908000000003	56.001801	Путевая	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43708	55103	60.173344	60.291553	56.082908000000003	56.001801	переулок Пролетарский	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
42753	55103	60.173344	60.291553	56.082908000000003	56.001801	Энгельса	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
44216	55103	60.173344	60.291553	56.082908000000003	56.001801	Механизаторов	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43964	8980	59.963631999999997	60.005367999999997	55.927315999999998	55.905062999999998	переулок Школьный	0103000020E6100000010000000500000085B01A4B58FB4D40EAE8B81AD9F34B4085B01A4B58FB4D405D876A4AB2F64B40F3380CE6AF004E405D876A4AB2F64B40F3380CE6AF004E40EAE8B81AD9F34B4085B01A4B58FB4D40EAE8B81AD9F34B40
43086	8980	60.173344	60.291553	56.082908000000003	56.001801	Якушева	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
42735	8980	59.963631999999997	60.005367999999997	55.927315999999998	55.905062999999998	Шулина	0103000020E6100000010000000500000085B01A4B58FB4D40EAE8B81AD9F34B4085B01A4B58FB4D405D876A4AB2F64B40F3380CE6AF004E405D876A4AB2F64B40F3380CE6AF004E40EAE8B81AD9F34B4085B01A4B58FB4D40EAE8B81AD9F34B40
43572	8980	60.173344	60.291553	56.082908000000003	56.001801	Хохрякова	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43780	8980	60.173344	60.291553	56.082908000000003	56.001801	Советская	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43601	8980	60.173344	60.291553	56.082908000000003	56.001801	Садовая	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
44081	8980	60.173344	60.291553	56.082908000000003	56.001801	Полевая	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
42886	8980	60.173344	60.291553	56.082908000000003	56.001801	Победы	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43894	8980	60.173344	60.291553	56.082908000000003	56.001801	Мира	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
42741	8980	60.173344	60.291553	56.082908000000003	56.001801	Ленина	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
43085	8980	59.963631999999997	60.005367999999997	55.927315999999998	55.905062999999998	Карла Маркса	0103000020E6100000010000000500000085B01A4B58FB4D40EAE8B81AD9F34B4085B01A4B58FB4D405D876A4AB2F64B40F3380CE6AF004E405D876A4AB2F64B40F3380CE6AF004E40EAE8B81AD9F34B4085B01A4B58FB4D40EAE8B81AD9F34B40
43559	8980	59.963631999999997	60.005367999999997	55.927315999999998	55.905062999999998	Бакальская	0103000020E6100000010000000500000085B01A4B58FB4D40EAE8B81AD9F34B4085B01A4B58FB4D405D876A4AB2F64B40F3380CE6AF004E405D876A4AB2F64B40F3380CE6AF004E40EAE8B81AD9F34B4085B01A4B58FB4D40EAE8B81AD9F34B40
9784	6222	60.634323000000002	60.680416000000001	53.822569999999999	53.790858999999998	Чапаева	0103000020E61000000100000005000000E10CFE7E31514E40A65F22DE3AE54A40E10CFE7E31514E40DA5548F949E94A406BD619DF17574E40DA5548F949E94A406BD619DF17574E40A65F22DE3AE54A40E10CFE7E31514E40A65F22DE3AE54A40
42717	6222	60.634323000000002	60.680416000000001	53.822569999999999	53.790858999999998	Ленина	0103000020E61000000100000005000000E10CFE7E31514E40A65F22DE3AE54A40E10CFE7E31514E40DA5548F949E94A406BD619DF17574E40DA5548F949E94A406BD619DF17574E40A65F22DE3AE54A40E10CFE7E31514E40A65F22DE3AE54A40
43105	19146	60.489623000000002	60.515673999999997	53.933788	53.921695	Советская	0103000020E61000000100000005000000492F6AF7AB3E4E4080F10C1AFAF54A40492F6AF7AB3E4E40D9B27C5D86F74A40E1B20A9B01424E40D9B27C5D86F74A40E1B20A9B01424E4080F10C1AFAF54A40492F6AF7AB3E4E4080F10C1AFAF54A40
43923	46939	61.166207	61.186509000000001	53.846507000000003	53.836312	Мира	0103000020E61000000100000005000000E2AE5E4546954E404DA088450CEB4A40E2AE5E4546954E40E46A64575AEC4A4070B4E386DF974E40E46A64575AEC4A4070B4E386DF974E404DA088450CEB4A40E2AE5E4546954E404DA088450CEB4A40
43496	19907	60.288013999999997	60.309590999999998	53.826216000000002	53.813032999999997	Школьная	0103000020E6100000010000000500000023658BA4DD244E40CDC8207711E84A4023658BA4DD244E404AB72572C1E94A4066118AADA0274E404AB72572C1E94A4066118AADA0274E40CDC8207711E84A4023658BA4DD244E40CDC8207711E84A40
43633	47419	61.014651999999998	61.048006999999998	53.806877	53.782102000000002	Школьная	0103000020E610000001000000050000001669E21DE0814E406F1118EB1BE44A401669E21DE0814E408272DBBE47E74A40527DE71725864E408272DBBE47E74A40527DE71725864E406F1118EB1BE44A401669E21DE0814E406F1118EB1BE44A40
43494	46248	60.640773000000003	60.660679999999999	53.904814000000002	53.888795999999999	30 лет Победы	0103000020E61000000100000005000000759483D904524E4066683C11C4F14A40759483D904524E40427BF5F1D0F34A40868F882991544E40427BF5F1D0F34A40868F882991544E4066683C11C4F14A40759483D904524E4066683C11C4F14A40
43106	47242	60.358235000000001	60.382930000000002	53.702100000000002	53.683295000000001	Пушкина	0103000020E610000001000000050000002BA4FCA4DA2D4E409A42E73576D74A402BA4FCA4DA2D4E40C442AD69DED94A402254A9D903314E40C442AD69DED94A402254A9D903314E409A42E73576D74A402BA4FCA4DA2D4E409A42E73576D74A40
44141	19240	60.754930999999999	60.771307	53.682873999999998	53.667630000000003	Гагарина	0103000020E6100000010000000500000048DE3994A1604E400CEA5BE674D54A4048DE3994A1604E40F4A44C6A68D74A4083161230BA624E40F4A44C6A68D74A4083161230BA624E400CEA5BE674D54A4048DE3994A1604E400CEA5BE674D54A40
44321	55241	60.314926999999997	60.327342000000002	53.500574	53.494591	Ленина	0103000020E610000001000000050000004ED026874F284E40AEF204C24EBF4A404ED026874F284E402C9D0FCF12C04A40BA4DB857E6294E402C9D0FCF12C04A40BA4DB857E6294E40AEF204C24EBF4A404ED026874F284E40AEF204C24EBF4A40
43753	47112	60.401229000000001	60.414326000000003	53.786034000000001	53.778675999999997	Центральная	0103000020E61000000100000005000000789ACC785B334E400D17B9A7ABE34A40789ACC785B334E40A4C519C39CE44A40F6F065A208354E40A4C519C39CE44A40F6F065A208354E400D17B9A7ABE34A40789ACC785B334E400D17B9A7ABE34A40
44036	20071	60.871963999999998	60.887521999999997	53.760502000000002	53.745552000000004	Первомайская	0103000020E6100000010000000500000009A52F849C6F4E40D4BB783F6EDF4A4009A52F849C6F4E407445292158E14A40813D26529A714E407445292158E14A40813D26529A714E40D4BB783F6EDF4A4009A52F849C6F4E40D4BB783F6EDF4A40
44248	10141	60.140788999999998	60.151361999999999	53.685668	53.679738	Ленина	0103000020E610000001000000050000007A51BB5F05124E409AEC9FA701D74A407A51BB5F05124E40F5F411F8C3D74A40B7ED7BD45F134E40F5F411F8C3D74A40B7ED7BD45F134E409AEC9FA701D74A407A51BB5F05124E409AEC9FA701D74A40
43535	20013	60.870401000000001	60.903018000000003	53.869869000000001	53.855525999999998	Комсомольская 	0103000020E61000000100000005000000EEB3CA4C696F4E4058703FE081ED4A40EEB3CA4C696F4E40F1660DDE57EF4A4084D9041896734E40F1660DDE57EF4A4084D9041896734E4058703FE081ED4A40EEB3CA4C696F4E4058703FE081ED4A40
44122	9687	60.403779999999998	60.414316999999997	53.565514	53.558824000000001	Чапаева	0103000020E61000000100000005000000B2632310AF334E40261C7A8B87C74A40B2632310AF334E400FB743C362C84A40A296E65608354E400FB743C362C84A40A296E65608354E40261C7A8B87C74A40B2632310AF334E40261C7A8B87C74A40
43921	47197	60.575924000000001	60.589129	53.529915000000003	53.525306	Дружбы	0103000020E61000000100000005000000A27DACE0B7494E4040321D3A3DC34A40A27DACE0B7494E4076543541D4C34A4006103E94684B4E4076543541D4C34A4006103E94684B4E4040321D3A3DC34A40A27DACE0B7494E4040321D3A3DC34A40
44192	47381	61.111113000000003	61.122521999999996	53.775877000000001	53.767890000000001	Центральная	0103000020E610000001000000050000008A9466F3388E4E40757632384AE24A408A9466F3388E4E40FB5B02F04FE34A402F8507CDAE8F4E40FB5B02F04FE34A402F8507CDAE8F4E40757632384AE24A408A9466F3388E4E40757632384AE24A40
43885	19944	60.916421	60.932581999999996	53.684106	53.675466	Окружная	0103000020E610000001000000050000000E2F88484D754E40ACC77DAB75D64A400E2F88484D754E40AA7F10C990D74A404C6BD3D85E774E40AA7F10C990D74A404C6BD3D85E774E40ACC77DAB75D64A400E2F88484D754E40ACC77DAB75D64A40
44165	47270	60.108826999999998	60.122067999999999	53.801006000000001	53.787146	Ленина	0103000020E61000000100000005000000FDF50A0BEE0D4E40AF963B33C1E44A40FDF50A0BEE0D4E402CF3565D87E64A40AEF199EC9F0F4E402CF3565D87E64A40AEF199EC9F0F4E40AF963B33C1E44A40FDF50A0BEE0D4E40AF963B33C1E44A40
44138	19054	61.086311000000002	61.117401000000001	53.875245999999997	53.86844	Набережная	0103000020E610000001000000050000007D24253D0C8B4E40E544BB0A29EF4A407D24253D0C8B4E4037FA980F08F04A4044C2F7FE068F4E4037FA980F08F04A4044C2F7FE068F4E40E544BB0A29EF4A407D24253D0C8B4E40E544BB0A29EF4A40
43871	47103	60.481152000000002	60.495263999999999	53.782798999999997	53.771253000000002	Советская	0103000020E61000000100000005000000D7338463963D4E4090F8156BB8E24A40D7338463963D4E40B62BF4C132E44A406D718DCF643F4E40B62BF4C132E44A406D718DCF643F4E4090F8156BB8E24A40D7338463963D4E4090F8156BB8E24A40
44139	47256	60.138202	60.149304999999998	53.845348999999999	53.833745999999998	Ленина	0103000020E61000000100000005000000F31E679AB0114E40DD955D30B8EA4A40F31E679AB0114E40685A626534EC4A408C101E6D1C134E40685A626534EC4A408C101E6D1C134E40DD955D30B8EA4A40F31E679AB0114E40DD955D30B8EA4A40
44161	19040	61.154017000000003	61.161203	53.802059	53.790640000000003	Центральная	0103000020E6100000010000000500000097033DD4B6934E40697407B133E54A4097033DD4B6934E40323B8BDEA9E64A403082C64CA2944E40323B8BDEA9E64A403082C64CA2944E40697407B133E54A4097033DD4B6934E40697407B133E54A40
43608	22327	60.291868000000001	60.316597999999999	53.660640000000001	53.650207999999999	Кирова	0103000020E61000000100000005000000DD5F3DEE5B254E407DCC07043AD34A40DD5F3DEE5B254E40F836FDD98FD44A4050FD834886284E40F836FDD98FD44A4050FD834886284E407DCC07043AD34A40DD5F3DEE5B254E407DCC07043AD34A40
43612	47077	60.536307999999998	60.554831	53.761944	53.748767999999998	Центральная	0103000020E61000000100000005000000A54A94BDA5444E404A253CA1D7DF4A40A54A94BDA5444E4014B1886187E14A404BE7C3B304474E4014B1886187E14A404BE7C3B304474E404A253CA1D7DF4A40A54A94BDA5444E404A253CA1D7DF4A40
44190	47171	60.652316999999996	60.669024999999998	53.715850000000003	53.706076000000003	Набережная	0103000020E61000000100000005000000FACF9A1F7F534E40C93EC8B260DA4A40FACF9A1F7F534E40BA6B09F9A0DB4A406B9A779CA2554E40BA6B09F9A0DB4A406B9A779CA2554E40C93EC8B260DA4A40FACF9A1F7F534E40C93EC8B260DA4A40
43595	30533	60.623094000000002	60.646881999999998	54.992058999999998	54.978043	Солнечная	0103000020E61000000100000005000000BB2A508BC14F4E40768A5583307D4B40BB2A508BC14F4E40EA5910CAFB7E4B407F2F8507CD524E40EA5910CAFB7E4B407F2F8507CD524E40768A5583307D4B40BB2A508BC14F4E40768A5583307D4B40
43875	53076	60.621118000000003	60.639282000000001	54.604227999999999	54.595512999999997	Колхозная	0103000020E610000001000000050000007D7A6CCB804F4E40E2AB1DC5394C4B407D7A6CCB804F4E40EBA9D557574D4B40F37519FED3514E40EBA9D557574D4B40F37519FED3514E40E2AB1DC5394C4B407D7A6CCB804F4E40E2AB1DC5394C4B40
43835	55187	60.520426	60.539093000000001	54.900937999999996	54.896289000000003	Ленина	0103000020E610000001000000050000007AFEB4519D424E40DD611399B9724B407AFEB4519D424E40A0DCB6EF51734B405340DAFF00454E40A0DCB6EF51734B405340DAFF00454E40DD611399B9724B407AFEB4519D424E40DD611399B9724B40
43638	53060	60.347752	60.368735999999998	54.945872000000001	54.929177000000003	Куйбышева	0103000020E610000001000000050000002E8F3523832C4E4003999D45EF764B402E8F3523832C4E40DF196D5512794B40CE6DC2BD322F4E40DF196D5512794B40CE6DC2BD322F4E4003999D45EF764B402E8F3523832C4E4003999D45EF764B40
44031	27336	59.991660000000003	60.003832000000003	54.424796000000001	54.410221	Строителей	0103000020E610000001000000050000002D6002B7EEFE4D40F390291F82344B402D6002B7EEFE4D405EBC1FB75F364B40D25625917D004E405EBC1FB75F364B40D25625917D004E40F390291F82344B402D6002B7EEFE4D40F390291F82344B40
44188	7670	59.752994999999999	59.761600999999999	54.357647	54.350631	Клубная 	0103000020E610000001000000050000009886E12362E04D405DFB027AE12C4B409886E12362E04D409A417C60C72D4B40EACC3D247CE14D409A417C60C72D4B40EACC3D247CE14D405DFB027AE12C4B409886E12362E04D405DFB027AE12C4B40
43210	26883	59.979073999999997	60.018483000000003	54.394399	54.361015000000002	Таращенко	0103000020E61000000100000005000000942EFD4B52FD4D40C72E51BD352E4B40942EFD4B52FD4D409D499BAA7B324B401844A4A65D024E409D499BAA7B324B401844A4A65D024E40C72E51BD352E4B40942EFD4B52FD4D40C72E51BD352E4B40
43073	26883	59.979073999999997	60.018483000000003	54.394399	54.361015000000002	Пионерская	0103000020E61000000100000005000000942EFD4B52FD4D40C72E51BD352E4B40942EFD4B52FD4D409D499BAA7B324B401844A4A65D024E409D499BAA7B324B401844A4A65D024E40C72E51BD352E4B40942EFD4B52FD4D40C72E51BD352E4B40
42872	26883	59.979073999999997	60.018483000000003	54.394399	54.361015000000002	Ленина	0103000020E61000000100000005000000942EFD4B52FD4D40C72E51BD352E4B40942EFD4B52FD4D409D499BAA7B324B401844A4A65D024E409D499BAA7B324B401844A4A65D024E40C72E51BD352E4B40942EFD4B52FD4D40C72E51BD352E4B40
9736	25570	60.254570000000001	60.271988	54.422407999999997	54.418447	Ленина	0103000020E610000001000000050000007845F0BF95204E40FE0DDAAB8F354B407845F0BF95204E40CDC8207711364B40C573B680D0224E40CDC8207711364B40C573B680D0224E40FE0DDAAB8F354B407845F0BF95204E40FE0DDAAB8F354B40
43858	26812	60.277495000000002	60.304380999999999	54.559631000000003	54.550618999999998	Партизанская	0103000020E61000000100000005000000DAE6C6F484234E4032C7F2AE7A464B40DAE6C6F484234E40F56915FDA1474B400B43E4F4F5264E40F56915FDA1474B400B43E4F4F5264E4032C7F2AE7A464B40DAE6C6F484234E4032C7F2AE7A464B40
44185	26051	59.860388999999998	59.878723000000001	54.531073999999997	54.524777999999998	Клубная	0103000020E61000000100000005000000486B0C3A21EE4D4084D4EDEC2B434B40486B0C3A21EE4D40C1E09A3BFA434B401B9FC9FE79F04D40C1E09A3BFA434B401B9FC9FE79F04D4084D4EDEC2B434B40486B0C3A21EE4D4084D4EDEC2B434B40
42902	26306	59.800175000000003	59.820261000000002	54.177990000000001	54.164808999999998	Лесная	0103000020E61000000100000005000000D50968226CE64D40118B187618154B40D50968226CE64D40ED815660C8164B409697FC4FFEE84D40ED815660C8164B409697FC4FFEE84D40118B187618154B40D50968226CE64D40118B187618154B40
43634	26306	59.800175000000003	59.820261000000002	54.177990000000001	54.164808999999998	Ленина	0103000020E61000000100000005000000D50968226CE64D40118B187618154B40D50968226CE64D40ED815660C8164B409697FC4FFEE84D40ED815660C8164B409697FC4FFEE84D40118B187618154B40D50968226CE64D40118B187618154B40
43853	27229	59.867899000000001	59.885981999999998	54.452312999999997	54.444555000000001	Лесная	0103000020E61000000100000005000000959D7E5017EF4D40FB22A12DE7384B40959D7E5017EF4D401F477364E5394B401E6CB1DB67F14D401F477364E5394B401E6CB1DB67F14D40FB22A12DE7384B40959D7E5017EF4D40FB22A12DE7384B40
44075	26782	60.158206999999997	60.180647	54.581876000000001	54.567649000000003	Центральная	0103000020E61000000100000005000000C77F812040144E40B64DF1B8A8484B40C77F812040144E40E529ABE97A4A4B406D8FDE701F174E40E529ABE97A4A4B406D8FDE701F174E40B64DF1B8A8484B40C77F812040144E40B64DF1B8A8484B40
43685	26138	59.989790999999997	60.007587000000001	54.280380000000001	54.271825999999997	Ленина	0103000020E610000001000000050000000470B378B1FE4D40EB19C231CB224B400470B378B1FE4D40EB39E97DE3234B40F86F5E9CF8004E40EB39E97DE3234B40F86F5E9CF8004E40EB19C231CB224B400470B378B1FE4D40EB19C231CB224B40
43557	26330	60.295972999999996	60.316634000000001	54.580179999999999	54.569809999999997	Мира	0103000020E61000000100000005000000DFBF7971E2254E408577B988EF484B40DFBF7971E2254E408AE59656434A4B409D66817687284E408AE59656434A4B409D66817687284E408577B988EF484B40DFBF7971E2254E408577B988EF484B40
43637	26080	60.014594000000002	60.034716000000003	54.472628	54.462069	Ленина	0103000020E61000000100000005000000E25B5837DE014E406ABFB513253B4B40E25B5837DE014E40429605137F3C4B40F052EA9271044E40429605137F3C4B40F052EA9271044E406ABFB513253B4B40E25B5837DE014E406ABFB513253B4B40
43886	7616	60.282310000000003	60.294581000000001	54.222099999999998	54.214118999999997	Школьная	0103000020E61000000100000005000000B9AAECBB22244E40E2395B40681B4B40B9AAECBB22244E408638D6C56D1C4B40F18288D4B4254E408638D6C56D1C4B40F18288D4B4254E40E2395B40681B4B40B9AAECBB22244E40E2395B40681B4B40
44184	26720	60.372042	60.388832000000001	54.344140000000003	54.333824999999997	Механическая	0103000020E61000000100000005000000855E7F129F2F4E4029CB10C7BA2A4B40855E7F129F2F4E406B9F8EC70C2C4B40B3D1393FC5314E406B9F8EC70C2C4B40B3D1393FC5314E4029CB10C7BA2A4B40855E7F129F2F4E4029CB10C7BA2A4B40
43944	26689	60.318061999999998	60.326228	54.602089999999997	54.591841000000002	Зеленая	0103000020E61000000100000005000000D80C7041B6284E404AB72572C14B4B40D80C7041B6284E40D39FFD48114D4B400E85CFD6C1294E40D39FFD48114D4B400E85CFD6C1294E404AB72572C14B4B40D80C7041B6284E404AB72572C14B4B40
42867	25852	59.940581000000002	59.966389999999997	54.590124000000003	54.561019999999999	Дворцовая	0103000020E61000000100000005000000971E4DF564F84D407233DC80CF474B40971E4DF564F84D40D84AE82E894B4B403997E2AAB2FB4D40D84AE82E894B4B403997E2AAB2FB4D407233DC80CF474B40971E4DF564F84D407233DC80CF474B40
43503	25812	60.293008	60.320838000000002	54.363343999999998	54.341258000000003	Нагорная	0103000020E61000000100000005000000B2BB404981254E40CBBF9657AE2B4B40B2BB404981254E405299620E822E4B4033A8363811294E405299620E822E4B4033A8363811294E40CBBF9657AE2B4B40B2BB404981254E40CBBF9657AE2B4B40
43851	26634	60.220379999999999	60.23133	54.609113999999998	54.597672000000003	Ключевая	0103000020E61000000100000005000000A3586E69351C4E4012DE1E84804C4B40A3586E69351C4E4093C49272F74D4B40B64AB0389C1D4E4093C49272F74D4B40B64AB0389C1D4E4012DE1E84804C4B40A3586E69351C4E4012DE1E84804C4B40
44072	25908	59.954540999999999	59.962769999999999	54.536344999999997	54.524898	Центральная	0103000020E6100000010000000500000077D844662EFA4D402FDE8FDB2F434B4077D844662EFA4D40C22FF5F3A6444B40F3C81F0C3CFB4D40C22FF5F3A6444B40F3C81F0C3CFB4D402FDE8FDB2F434B4077D844662EFA4D402FDE8FDB2F434B40
43553	25680	60.078400999999999	60.102888999999998	54.155439999999999	54.145257999999998	Ленина	0103000020E61000000100000005000000A27C410B090A4E40BEBD6BD097124B40A27C410B090A4E40C03E3A75E5134B401F0F7D772B0D4E40C03E3A75E5134B401F0F7D772B0D4E40BEBD6BD097124B40A27C410B090A4E40BEBD6BD097124B40
43948	26597	60.327449999999999	60.341805000000001	54.454825	54.445869000000002	Садиковая	0103000020E61000000100000005000000A089B0E1E9294E406EA6423C12394B40A089B0E1E9294E409C33A2B4373A4B40FD4D2844C02B4E409C33A2B4373A4B40FD4D2844C02B4E406EA6423C12394B40A089B0E1E9294E406EA6423C12394B40
43888	26536	60.349539	60.363194	54.507641	54.500630000000001	Верхняя	0103000020E6100000010000000500000099D6A6B1BD2C4E40C0B2D2A414404B4099D6A6B1BD2C4E40EB8D5A61FA404B403D0D18247D2E4E40EB8D5A61FA404B403D0D18247D2E4E40C0B2D2A414404B4099D6A6B1BD2C4E40C0B2D2A414404B40
44105	55206	59.951082999999997	59.959868	54.493361999999998	54.486668000000002	Верхняя	0103000020E610000001000000050000000A647616BDF94D403F0114234B3E4B400A647616BDF94D40698B6B7C263F4B400C3D62F4DCFA4D40698B6B7C263F4B400C3D62F4DCFA4D403F0114234B3E4B400A647616BDF94D403F0114234B3E4B40
43850	25761	60.272697999999998	60.284061000000001	54.185445999999999	54.173490000000001	Советская	0103000020E61000000100000005000000A1D79FC4E7224E406E179AEB34164B40A1D79FC4E7224E404696CCB1BC174B40D788601C5C244E404696CCB1BC174B40D788601C5C244E406E179AEB34164B40A1D79FC4E7224E406E179AEB34164B40
44187	27188	60.009050999999999	60.019542999999999	54.349608000000003	54.341850999999998	Нагорная	0103000020E61000000100000005000000807F4A9528014E406D8D08C6C12B4B40807F4A9528014E40C23577F4BF2C4B40D0EE906280024E40C23577F4BF2C4B40D0EE906280024E406D8D08C6C12B4B40807F4A9528014E406D8D08C6C12B4B40
43946	27141	59.910711999999997	59.920530999999997	54.327303999999998	54.320887999999997	Солнечная	0103000020E610000001000000050000009109F83592F44D40E4D6A4DB12294B409109F83592F44D40CCECF318E5294B4022FAB5F5D3F54D40CCECF318E5294B4022FAB5F5D3F54D40E4D6A4DB12294B409109F83592F44D40E4D6A4DB12294B40
43941	25988	59.826054999999997	59.841065999999998	54.490136	54.480899000000001	Школьная	0103000020E6100000010000000500000040D9942BBCE94D40EDD632198E3D4B4040D9942BBCE94D40CF4BC5C6BC3E4B4086E3F90CA8EB4D40CF4BC5C6BC3E4B4086E3F90CA8EB4D40EDD632198E3D4B4040D9942BBCE94D40EDD632198E3D4B40
44077	26513	60.510913000000002	60.535527000000002	54.589815999999999	54.583316000000003	Кировская	0103000020E61000000100000005000000F60CE19865414E40E59D4319AA4A4B40F60CE19865414E402A5437177F4B4B40009013268C444E402A5437177F4B4B40009013268C444E40E59D4319AA4A4B40F60CE19865414E40E59D4319AA4A4B40
44078	21195	59.817827000000001	59.837491	54.372906	54.365924999999997	Мира	0103000020E6100000010000000500000095641D8EAEE84D40F7E461A1D62E4B4095641D8EAEE84D40B83D4162BB2F4B40E0D8B3E732EB4D40B83D4162BB2F4B40E0D8B3E732EB4D40F7E461A1D62E4B4095641D8EAEE84D40F7E461A1D62E4B40
43849	26219	60.035254999999999	60.058225	54.247928000000002	54.242429999999999	Молодежная	0103000020E610000001000000050000009F02603C83044E40DEC83CF2071F4B409F02603C83044E40A0E1CD1ABC1F4B40A167B3EA73074E40A0E1CD1ABC1F4B40A167B3EA73074E40DEC83CF2071F4B409F02603C83044E40DEC83CF2071F4B40
43590	25634	60.085560999999998	60.101298999999997	54.343325999999998	54.332276	Ленина	0103000020E610000001000000050000001268B0A9F30A4E40739F1C05882A4B401268B0A9F30A4E40E9EE3A1BF22B4B400A0F9A5DF70C4E40E9EE3A1BF22B4B400A0F9A5DF70C4E40739F1C05882A4B401268B0A9F30A4E40739F1C05882A4B40
43950	26424	60.367083999999998	60.403922999999999	54.568823999999999	54.554295000000003	Кульмухаметова	0103000020E610000001000000050000004371C79BFC2E4E400DAB7823F3464B404371C79BFC2E4E4007978E39CF484B40158DB5BFB3334E4007978E39CF484B40158DB5BFB3334E400DAB7823F3464B404371C79BFC2E4E400DAB7823F3464B40
44076	27064	59.999673000000001	60.009186	54.306790999999997	54.300680999999997	Ленина	0103000020E61000000100000005000000DCD8EC48F5FF4D40A8C30AB77C264B40DCD8EC48F5FF4D4083DA6FED44274B4060CAC0012D014E4083DA6FED44274B4060CAC0012D014E40A8C30AB77C264B40DCD8EC48F5FF4D40A8C30AB77C264B40
44071	25737	60.239891	60.251263999999999	54.142383000000002	54.137234999999997	Школьная	0103000020E6100000010000000500000068CD8FBFB41E4E40EB6E9EEA90114B4068CD8FBFB41E4E40D1402C9B39124B40C154336B29204E40D1402C9B39124B40C154336B29204E40EB6E9EEA90114B4068CD8FBFB41E4E40EB6E9EEA90114B40
43852	26146	59.902222999999999	59.912069000000002	54.254246000000002	54.245660999999998	Школьная	0103000020E610000001000000050000007959130B7CF34D408A73D4D1711F4B407959130B7CF34D40C59107228B204B4004594FADBEF44D40C59107228B204B4004594FADBEF44D408A73D4D1711F4B407959130B7CF34D408A73D4D1711F4B40
43551	25544	60.125526999999998	60.144112999999997	54.4251	54.41534	Космонавтов	0103000020E61000000100000005000000EBE1CB4411104E403E5C72DC29354B40EBE1CB4411104E40CAC342AD69364B40D7F6764B72124E40CAC342AD69364B40D7F6764B72124E403E5C72DC29354B40EBE1CB4411104E403E5C72DC29354B40
43486	25414	60.117010999999998	60.130881000000002	54.206147000000001	54.192515999999998	Молодежная	0103000020E61000000100000005000000D9226937FA0E4E4076FA415DA4184B40D9226937FA0E4E4092955F06631A4B407A5567B5C0104E4092955F06631A4B407A5567B5C0104E4076FA415DA4184B40D9226937FA0E4E4076FA415DA4184B40
43710	55164	61.520367999999998	61.534587999999999	54.376939	54.366596999999999	Лесная	0103000020E6100000010000000500000045F12A6B9BC24E40E6E786A6EC2E4B4045F12A6B9BC24E4021CB82893F304B40C26A2C616DC44E4021CB82893F304B40C26A2C616DC44E40E6E786A6EC2E4B4045F12A6B9BC24E40E6E786A6EC2E4B40
43146	3476	61.429547999999997	61.451242000000001	54.550409999999999	54.536386999999998	Луначарского	0103000020E61000000100000005000000F607CA6DFBB64E40F17F4754A8444B40F607CA6DFBB64E4018B2BAD573464B40734A404CC2B94E4018B2BAD573464B40734A404CC2B94E40F17F4754A8444B40F607CA6DFBB64E40F17F4754A8444B40
44316	55237	61.302984000000002	61.313215999999997	54.537249000000003	54.523634000000001	Станционная	0103000020E610000001000000050000000B9B012EC8A64E406E895C7006434B400B9B012EC8A64E4084674293C4444B40BE4A3E7617A84E4084674293C4444B40BE4A3E7617A84E406E895C7006434B400B9B012EC8A64E406E895C7006434B40
43679	2418	61.331614000000002	61.39331	54.466406999999997	54.383887000000001	Щербакова	0103000020E61000000100000005000000A872DA5372AA4E40062E8F3523314B40A872DA5372AA4E400FD07D39B33B4B404A9869FB57B24E400FD07D39B33B4B404A9869FB57B24E40062E8F3523314B40A872DA5372AA4E40062E8F3523314B40
43145	2418	61.331614000000002	61.39331	54.466406999999997	54.383887000000001	У. Громовой	0103000020E61000000100000005000000A872DA5372AA4E40062E8F3523314B40A872DA5372AA4E400FD07D39B33B4B404A9869FB57B24E400FD07D39B33B4B404A9869FB57B24E40062E8F3523314B40A872DA5372AA4E40062E8F3523314B40
42712	2418	61.331614000000002	61.39331	54.466406999999997	54.383887000000001	Советская	0103000020E61000000100000005000000A872DA5372AA4E40062E8F3523314B40A872DA5372AA4E400FD07D39B33B4B404A9869FB57B24E400FD07D39B33B4B404A9869FB57B24E40062E8F3523314B40A872DA5372AA4E40062E8F3523314B40
43681	2418	61.331614000000002	61.39331	54.466406999999997	54.383887000000001	Сафонова	0103000020E61000000100000005000000A872DA5372AA4E40062E8F3523314B40A872DA5372AA4E400FD07D39B33B4B404A9869FB57B24E400FD07D39B33B4B404A9869FB57B24E40062E8F3523314B40A872DA5372AA4E40062E8F3523314B40
43143	2418	61.331614000000002	61.39331	54.466406999999997	54.383887000000001	Кирова	0103000020E61000000100000005000000A872DA5372AA4E40062E8F3523314B40A872DA5372AA4E400FD07D39B33B4B404A9869FB57B24E400FD07D39B33B4B404A9869FB57B24E40062E8F3523314B40A872DA5372AA4E40062E8F3523314B40
43661	3370	61.311715999999997	61.346615999999997	54.55077	54.540925999999999	Центральная	0103000020E61000000100000005000000E9D1544FE6A74E402EC72B103D454B40E9D1544FE6A74E4018CFA0A17F464B409A22C0E95DAC4E4018CFA0A17F464B409A22C0E95DAC4E402EC72B103D454B40E9D1544FE6A74E402EC72B103D454B40
42963	3675	61.666164000000002	61.700893000000001	54.449993999999997	54.430557999999998	Свободы	0103000020E61000000100000005000000E3E2A8DC44D54E40FD8348861C374B40E3E2A8DC44D54E40B7B2446799394B40677FA0DCB6D94E40B7B2446799394B40677FA0DCB6D94E40FD8348861C374B40E3E2A8DC44D54E40FD8348861C374B40
43660	3576	61.326107	61.345061000000001	54.351438999999999	54.336849000000001	пер. Колхозный	0103000020E6100000010000000500000093FFC9DFBDA94E405C5837DE1D2B4B4093FFC9DFBDA94E40FCC401F4FB2C4B40021077F52AAC4E40FCC401F4FB2C4B40021077F52AAC4E405C5837DE1D2B4B4093FFC9DFBDA94E405C5837DE1D2B4B40
43904	3021	61.029834000000001	61.041106999999997	54.614834000000002	54.603279000000001	Гагарина	0103000020E610000001000000050000008927BB99D1834E408AAE0B3F384D4B408927BB99D1834E40043C69E1B24E4B407E5182FE42854E40043C69E1B24E4B407E5182FE42854E408AAE0B3F384D4B408927BB99D1834E408AAE0B3F384D4B40
43664	3958	61.849510000000002	61.875543999999998	54.512020999999997	54.494706000000001	Школьная	0103000020E61000000100000005000000FFCF61BEBCEC4E404791B586523F4B40FFCF61BEBCEC4E40BFEE74E789414B40C11A67D311F04E40BFEE74E789414B40C11A67D311F04E404791B586523F4B40FFCF61BEBCEC4E404791B586523F4B40
43586	6526	61.411096999999998	61.428677	54.386383000000002	54.371349000000002	Центральная	0103000020E61000000100000005000000EA3D95D39EB44E407F33315D882F4B40EA3D95D39EB44E407D5D86FF74314B4011C64FE3DEB64E407D5D86FF74314B4011C64FE3DEB64E407F33315D882F4B40EA3D95D39EB44E407F33315D882F4B40
42868	6526	61.411096999999998	61.428677	54.386383000000002	54.371349000000002	Советская	0103000020E61000000100000005000000EA3D95D39EB44E407F33315D882F4B40EA3D95D39EB44E407D5D86FF74314B4011C64FE3DEB64E407D5D86FF74314B4011C64FE3DEB64E407F33315D882F4B40EA3D95D39EB44E407F33315D882F4B40
43505	3261	61.260620000000003	61.299616	54.547392000000002	54.536245999999998	Школьная	0103000020E610000001000000050000007E5704FF5BA14E402F4E7CB5A3444B407E5704FF5BA14E40C80BE9F010464B40DEAD2CD159A64E40C80BE9F010464B40DEAD2CD159A64E402F4E7CB5A3444B407E5704FF5BA14E402F4E7CB5A3444B40
44017	3818	61.859445999999998	61.886512000000003	54.356361	54.342601999999999	Школьная 	0103000020E61000000100000005000000C956975302EE4E40A8C5E061DA2B4B40C956975302EE4E40F148BC3C9D2D4B407BC1A73979F14E40F148BC3C9D2D4B407BC1A73979F14E40A8C5E061DA2B4B40C956975302EE4E40A8C5E061DA2B4B40
43902	3896	61.094009	61.104367000000003	54.643379000000003	54.634968999999998	Мира	0103000020E61000000100000005000000CC43A67C088C4E40A67C08AA46514B40CC43A67C088C4E4073F7393E5A524B400DE4D9E55B8D4E4073F7393E5A524B400DE4D9E55B8D4E40A67C08AA46514B40CC43A67C088C4E40A67C08AA46514B40
44202	6590	61.407378000000001	61.419316000000002	54.352552000000003	54.347866000000003	Первостроителей	0103000020E61000000100000005000000118E59F624B44E40F7B182DF862C4B40118E59F624B44E40D811876C202D4B4043588D25ACB54E40D811876C202D4B4043588D25ACB54E40F7B182DF862C4B40118E59F624B44E40F7B182DF862C4B40
44200	4082	62.041848999999999	62.072130999999999	54.458494000000002	54.447145999999996	Центральная	0103000020E61000000100000005000000662FDB4E5B054F40C34483143C394B40662FDB4E5B054F40C4B46FEEAF3A4B408E03AF963B094F40C4B46FEEAF3A4B408E03AF963B094F40C34483143C394B40662FDB4E5B054F40C34483143C394B40
42665	3859	61.198878999999998	61.221291999999998	54.581954000000003	54.565963000000004	Островского	0103000020E610000001000000050000003B6EF8DD74994E407FDFBF7971484B403B6EF8DD74994E4061E3FA777D4A4B40E76ED74B539C4E4061E3FA777D4A4B40E76ED74B539C4E407FDFBF7971484B403B6EF8DD74994E407FDFBF7971484B40
44201	2799	61.391621000000001	61.401862000000001	54.491286000000002	54.483750000000001	Набережная	0103000020E61000000100000005000000A2B60DA320B24E4052B81E85EB3D4B40A2B60DA320B24E40C87DAB75E23E4B40A9C0C93670B34E40C87DAB75E23E4B40A9C0C93670B34E4052B81E85EB3D4B40A2B60DA320B24E4052B81E85EB3D4B40
44223	3685	61.687004999999999	61.694280999999997	54.490820999999997	54.475720000000003	Рабочая	0103000020E610000001000000050000002098A3C7EFD74E40CD069964E43C4B402098A3C7EFD74E405298F738D33E4B40F99D2633DED84E405298F738D33E4B40F99D2633DED84E40CD069964E43C4B402098A3C7EFD74E40CD069964E43C4B40
43665	3148	61.250064999999999	61.277005000000003	54.520211000000003	54.498215000000002	Мира	0103000020E61000000100000005000000E76F422102A04E4036B05582C53F4B40E76F422102A04E407E02284696424B400CEA5BE674A34E407E02284696424B400CEA5BE674A34E4036B05582C53F4B40E76F422102A04E4036B05582C53F4B40
42714	3148	61.250064999999999	61.277005000000003	54.520211000000003	54.498215000000002	Комсомольская	0103000020E61000000100000005000000E76F422102A04E4036B05582C53F4B40E76F422102A04E407E02284696424B400CEA5BE674A34E407E02284696424B400CEA5BE674A34E4036B05582C53F4B40E76F422102A04E4036B05582C53F4B40
44040	2908	61.386536999999997	61.399571000000002	54.459766000000002	54.451569999999997	Увельская	0103000020E61000000100000005000000D3D85E0B7AB14E4067EDB60BCD394B40D3D85E0B7AB14E4008E8BE9CD93A4B400BB77C2425B34E4008E8BE9CD93A4B400BB77C2425B34E4067EDB60BCD394B40D3D85E0B7AB14E4067EDB60BCD394B40
42955	3007	61.042644000000003	61.077255999999998	54.533064000000003	54.512554000000002	Советская	0103000020E6100000010000000500000071AFCC5B75854E408DB7955E9B414B4071AFCC5B75854E406556EF703B444B40BBB54C86E3894E406556EF703B444B40BBB54C86E3894E408DB7955E9B414B4071AFCC5B75854E408DB7955E9B414B40
43872	3771	61.561663000000003	61.585324999999997	54.540267999999998	54.530921999999997	Молодежная	0103000020E61000000100000005000000C72FBC92E4C74E400B5D8940F5434B40C72FBC92E4C74E40A489778027454B40FE43FAEDEBCA4E40A489778027454B40FE43FAEDEBCA4E400B5D8940F5434B40C72FBC92E4C74E400B5D8940F5434B40
43663	3588	61.230759999999997	61.245168999999997	54.397208999999997	54.384213000000003	Западная	0103000020E61000000100000005000000CB9C2E8B899D4E405AD93EE42D314B40CB9C2E8B899D4E40A35698BED7324B401B7FA2B2619F4E40A35698BED7324B401B7FA2B2619F4E405AD93EE42D314B40CB9C2E8B899D4E405AD93EE42D314B40
43908	3987	61.878507999999997	61.891336000000003	54.493378	54.478073999999999	Новая	0103000020E610000001000000050000001EA33CF372F04E40B1886187313D4B401EA33CF372F04E406F48A302273F4B40ADDF4C4C17F24E406F48A302273F4B40ADDF4C4C17F24E40B1886187313D4B401EA33CF372F04E40B1886187313D4B40
43629	3124	61.172055	61.186723999999998	54.534171999999998	54.523749000000002	Школьная	0103000020E61000000100000005000000800EF3E505964E4007280D350A434B40800EF3E505964E402E3883BF5F444B406CB07092E6974E402E3883BF5F444B406CB07092E6974E4007280D350A434B40800EF3E505964E4007280D350A434B40
42624	24191	61.390327999999997	61.418517000000001	54.204161999999997	54.176209	Ленина	0103000020E61000000100000005000000465B9544F6B14E4064213A048E164B40465B9544F6B14E40008BFCFA211A4B40F7E80DF791B54E40008BFCFA211A4B40F7E80DF791B54E4064213A048E164B40465B9544F6B14E4064213A048E164B40
43917	18859	62.217685000000003	62.240654999999997	54.121223000000001	54.110582999999998	Школьная	0103000020E6100000010000000500000036EA211ADD1B4F402D3F7095270E4B4036EA211ADD1B4F40F2423A3C840F4B40374F75C8CD1E4F40F2423A3C840F4B40374F75C8CD1E4F402D3F7095270E4B4036EA211ADD1B4F402D3F7095270E4B40
44180	45701	61.273591000000003	61.298915000000001	54.097053000000002	54.093128999999998	Центральная	0103000020E610000001000000050000006FBDA60705A34E4093A7ACA6EB0B4B406FBDA60705A34E40467D923B6C0C4B4055A4C2D842A64E40467D923B6C0C4B4055A4C2D842A64E4093A7ACA6EB0B4B406FBDA60705A34E4093A7ACA6EB0B4B40
43943	46114	60.654338000000003	60.675519999999999	54.021087000000001	54.014775999999998	Ленина	0103000020E61000000100000005000000D943FB58C1534E400262122EE4014B40D943FB58C1534E4075AF93FAB2024B409FE5797077564E4075AF93FAB2024B409FE5797077564E400262122EE4014B40D943FB58C1534E400262122EE4014B40
43619	45885	60.937171999999997	60.967751	54.13541	54.115406999999998	Садовая	0103000020E610000001000000050000000B5D8940F5774E405F5D15A8C50E4B400B5D8940F5774E4093C6681D55114B40EDD5C743DF7B4E4093C6681D55114B40EDD5C743DF7B4E405F5D15A8C50E4B400B5D8940F5774E405F5D15A8C50E4B40
43838	45732	61.214832999999999	61.231963999999998	54.052280000000003	54.038519000000001	Центральная	0103000020E61000000100000005000000008DD2A57F9B4E4027A3CA30EE044B40008DD2A57F9B4E40111E6D1CB1064B40B7EC10FFB09D4E40111E6D1CB1064B40B7EC10FFB09D4E4027A3CA30EE044B40008DD2A57F9B4E4027A3CA30EE044B40
43909	23528	61.814484999999998	61.828130000000002	54.166553999999998	54.159289000000001	Луговая	0103000020E61000000100000005000000910A630B41E84E4068CEFA9463144B40910A630B41E84E404D8237A451154B40126BF12900EA4E404D8237A451154B40126BF12900EA4E4068CEFA9463144B40910A630B41E84E4068CEFA9463144B40
43922	24701	61.115560000000002	61.139850000000003	54.269559999999998	54.261992999999997	Спутника	0103000020E61000000100000005000000E65C8AABCA8E4E40F56393FC88214B40E65C8AABCA8E4E40A6272CF180224B403D2CD49AE6914E40A6272CF180224B403D2CD49AE6914E40F56393FC88214B40E65C8AABCA8E4E40F56393FC88214B40
43938	24701	61.115560000000002	61.139850000000003	54.269559999999998	54.261992999999997	Левобережная	0103000020E61000000100000005000000E65C8AABCA8E4E40F56393FC88214B40E65C8AABCA8E4E40A6272CF180224B403D2CD49AE6914E40A6272CF180224B403D2CD49AE6914E40F56393FC88214B40E65C8AABCA8E4E40F56393FC88214B40
44173	23474	61.756948000000001	61.770378000000001	54.244492999999999	54.237704999999998	Мира	0103000020E61000000100000005000000E5620CACE3E04E403F8C101E6D1E4B40E5620CACE3E04E40EB8CEF8B4B1F4B4069C70DBF9BE24E40EB8CEF8B4B1F4B4069C70DBF9BE24E403F8C101E6D1E4B40E5620CACE3E04E403F8C101E6D1E4B40
43937	25385	60.565728	60.579427000000003	54.021594999999998	54.013665000000003	Центральная	0103000020E610000001000000050000003B376DC669484E40C80C54C6BF014B403B376DC669484E40E960FD9FC3024B40AFB5F7A92A4A4E40E960FD9FC3024B40AFB5F7A92A4A4E40C80C54C6BF014B403B376DC669484E40C80C54C6BF014B40
43958	21272	60.397706999999997	60.425797000000003	54.081716999999998	54.059863999999997	Центральная	0103000020E61000000100000005000000F4311F10E8324E40971AA19FA9074B40F4311F10E8324E407C43E1B3750A4B4012DE1E8480364E407C43E1B3750A4B4012DE1E8480364E40971AA19FA9074B40F4311F10E8324E40971AA19FA9074B40
43571	21272	60.397706999999997	60.425797000000003	54.081716999999998	54.059863999999997	Труда	0103000020E61000000100000005000000F4311F10E8324E40971AA19FA9074B40F4311F10E8324E407C43E1B3750A4B4012DE1E8480364E407C43E1B3750A4B4012DE1E8480364E40971AA19FA9074B40F4311F10E8324E40971AA19FA9074B40
43602	21272	60.397706999999997	60.425797000000003	54.081716999999998	54.059863999999997	Комсомольская	0103000020E61000000100000005000000F4311F10E8324E40971AA19FA9074B40F4311F10E8324E407C43E1B3750A4B4012DE1E8480364E407C43E1B3750A4B4012DE1E8480364E40971AA19FA9074B40F4311F10E8324E40971AA19FA9074B40
43949	21237	60.414200000000001	60.428348999999997	53.984662	53.977381000000001	Центральная	0103000020E6100000010000000500000069006F8104354E40AB5D13D21AFD4A4069006F8104354E4096CE876709FE4A401C23D923D4364E4096CE876709FE4A401C23D923D4364E40AB5D13D21AFD4A4069006F8104354E40AB5D13D21AFD4A40
43840	23624	61.686017	61.712392000000001	54.136960999999999	54.121228000000002	Центральная	0103000020E6100000010000000500000001C0B167CFD74E4004AE2B66840F4B4001C0B167CFD74E40EAE923F087114B404DF73AA92FDB4E40EAE923F087114B404DF73AA92FDB4E4004AE2B66840F4B4001C0B167CFD74E4004AE2B66840F4B40
43683	25153	61.146183000000001	61.160592000000001	54.093308999999998	54.087277999999998	Школьная	0103000020E61000000100000005000000971DE21FB6924E4084D4EDEC2B0B4B40971DE21FB6924E4013B69F8CF10B4B40E7FF55478E944E4013B69F8CF10B4B40E7FF55478E944E4084D4EDEC2B0B4B40971DE21FB6924E4084D4EDEC2B0B4B40
43932	23150	62.064549	62.084384	54.291269999999997	54.282803000000001	Центральная	0103000020E61000000100000005000000A8FE412443084F40F81A82E332244B40A8FE412443084F402827DA5548254B4020274C18CD0A4F402827DA5548254B4020274C18CD0A4F40F81A82E332244B40A8FE412443084F40F81A82E332244B40
43844	45916	61.052283000000003	61.067912999999997	54.206389999999999	54.197899999999997	Первомайская	0103000020E6100000010000000500000082919735B1864E406FF085C954194B4082919735B1864E40581CCEFC6A1A4B4093FC885FB1884E40581CCEFC6A1A4B4093FC885FB1884E406FF085C954194B4082919735B1864E406FF085C954194B40
44182	45858	60.993515000000002	61.007959999999997	54.251989000000002	54.243108999999997	Заречная	0103000020E61000000100000005000000F08AE07F2B7F4E407F2E1A321E1F4B40F08AE07F2B7F4E40D3F9F02C41204B408CD651D504814E40D3F9F02C41204B408CD651D504814E407F2E1A321E1F4B40F08AE07F2B7F4E407F2E1A321E1F4B40
43787	46001	60.82694	60.842202	54.023018	54.015675999999999	Набережная	0103000020E610000001000000050000008BE07F2BD9694E4082AAD1AB01024B408BE07F2BD9694E40139CFA40F2024B401A506F46CD6B4E40139CFA40F2024B401A506F46CD6B4E4082AAD1AB01024B408BE07F2BD9694E4082AAD1AB01024B40
43939	45539	61.388908000000001	61.402248	54.095263000000003	54.087246	Набережная	0103000020E610000001000000050000008E93C2BCC7B14E40795A7EE02A0B4B408E93C2BCC7B14E406AC2F693310C4B40D270CADC7CB34E406AC2F693310C4B40D270CADC7CB34E40795A7EE02A0B4B408E93C2BCC7B14E40795A7EE02A0B4B40
43936	24525	61.058140000000002	61.076895999999998	54.128641999999999	54.117677	Центральная	0103000020E61000000100000005000000734BAB2171874E40E63E390A100F4B40734BAB2171874E402E724F5777104B40BB9866BAD7894E402E724F5777104B40BB9866BAD7894E40E63E390A100F4B40734BAB2171874E40E63E390A100F4B40
43556	23020	61.363216000000001	61.390309999999999	54.144446000000002	54.135468000000003	Южная	0103000020E6100000010000000500000025B1A4DC7DAE4E40C8D3F20357114B4025B1A4DC7DAE4E40DE04DF347D124B40A0A696ADF5B14E40DE04DF347D124B40A0A696ADF5B14E40C8D3F20357114B4025B1A4DC7DAE4E40C8D3F20357114B40
43757	23020	61.363216000000001	61.390309999999999	54.144446000000002	54.135468000000003	30 Лет победы	0103000020E6100000010000000500000025B1A4DC7DAE4E40C8D3F20357114B4025B1A4DC7DAE4E40DE04DF347D124B40A0A696ADF5B14E40DE04DF347D124B40A0A696ADF5B14E40C8D3F20357114B4025B1A4DC7DAE4E40C8D3F20357114B40
43202	24309	61.188277999999997	61.218820999999998	54.132002	54.120854000000001	Советская	0103000020E610000001000000050000003447567E19984E409FCBD424780F4B403447567E19984E40D8800871E5104B40C9569753029C4E40D8800871E5104B40C9569753029C4E409FCBD424780F4B403447567E19984E409FCBD424780F4B40
44068	312	61.636960000000002	61.654755999999999	54.112240999999997	54.104258999999999	Школьная	0103000020E610000001000000050000001A6EC0E787D14E4026A8E15B580D4B401A6EC0E787D14E409A22C0E95D0E4B400D6E6B0BCFD34E409A22C0E95D0E4B400D6E6B0BCFD34E4026A8E15B580D4B401A6EC0E787D14E4026A8E15B580D4B40
43843	23425	61.683529	61.691398	54.246617999999998	54.235515999999997	Северная	0103000020E610000001000000050000000D6FD6E07DD74E40A5D76663251E4B400D6FD6E07DD74E406E4DBA2D911F4B408942CBBA7FD84E406E4DBA2D911F4B408942CBBA7FD84E40A5D76663251E4B400D6FD6E07DD74E40A5D76663251E4B40
43945	46059	61.060887999999998	61.075729000000003	54.008066999999997	54.001061	Школьная	0103000020E61000000100000005000000035C902DCB874E40892650C422004B40035C902DCB874E40A296E65608014B40ED2DE57CB1894E40A296E65608014B40ED2DE57CB1894E40892650C422004B40035C902DCB874E40892650C422004B40
44007	48418	61.553730999999999	61.562911999999997	54.159737	54.152397999999998	Комсомольская	0103000020E6100000010000000500000004E44BA8E0C64E40E7FC14C781134B4004E44BA8E0C64E40077B134372144B4052431B800DC84E40077B134372144B4052431B800DC84E40E7FC14C781134B4004E44BA8E0C64E40E7FC14C781134B40
44062	24656	61.251914999999997	61.266683	54.249727	54.241304	Садовая	0103000020E61000000100000005000000982F2FC03EA04E406E32AA0CE31E4B40982F2FC03EA04E40CFF6E80DF71F4B4018B325AB22A24E40CFF6E80DF71F4B4018B325AB22A24E406E32AA0CE31E4B40982F2FC03EA04E406E32AA0CE31E4B40
44057	23966	61.499876999999998	61.522433999999997	54.194217999999999	54.186653	Кольцевая	0103000020E61000000100000005000000E48233F8FBBF4E40A359D93EE4174B40E48233F8FBBF4E40B325AB22DC184B40C328081EDFC24E40B325AB22DC184B40C328081EDFC24E40A359D93EE4174B40E48233F8FBBF4E40A359D93EE4174B40
44181	45838	61.111570999999998	61.121237000000001	54.306806000000002	54.303465000000003	Центральная	0103000020E610000001000000050000004C1762F5478E4E40863DEDF0D7264B404C1762F5478E4E40B91B446B45274B405708ABB1848F4E40B91B446B45274B405708ABB1848F4E40863DEDF0D7264B404C1762F5478E4E40863DEDF0D7264B40
43842	24968	60.868944999999997	60.895311	54.215904000000002	54.205168	Красногвардейская	0103000020E61000000100000005000000E882FA96396F4E40C617EDF1421A4B40E882FA96396F4E40AD8905BEA21B4B40E15F048D99724E40AD8905BEA21B4B40E15F048D99724E40C617EDF1421A4B40E882FA96396F4E40C617EDF1421A4B40
43552	23869	61.488791999999997	61.515939000000003	54.123961999999999	54.109099999999998	Школьная	0103000020E61000000100000005000000F1457BBC90BE4E402EFF21FDF60D4B40F1457BBC90BE4E402FF99FFCDD0F4B4090DD054A0AC24E402FF99FFCDD0F4B4090DD054A0AC24E402EFF21FDF60D4B40F1457BBC90BE4E402EFF21FDF60D4B40
9694	40275	61.983809000000001	62.021619000000001	54.055790000000002	54.041294999999998	Школьная	0103000020E6100000010000000500000057410C74EDFD4E40813E912749054B4057410C74EDFD4E40D0B8702024074B4072FC5069C4024F40D0B8702024074B4072FC5069C4024F40813E912749054B4057410C74EDFD4E40813E912749054B40
43627	23760	61.731507999999998	61.749293999999999	54.035209000000002	54.015776000000002	Собко	0103000020E610000001000000050000009561DC0DA2DD4E40E607AEF204024B409561DC0DA2DD4E402FC37FBA81044B40658BA4DDE8DF4E402FC37FBA81044B40658BA4DDE8DF4E40E607AEF204024B409561DC0DA2DD4E40E607AEF204024B40
43493	24050	61.411563999999998	61.424419	54.260016	54.241925000000002	Кооперативный	0103000020E61000000100000005000000001B1021AEB44E40DB8AFD65F71E4B40001B1021AEB44E40E7374C3448214B4088669E5C53B64E40E7374C3448214B4088669E5C53B64E40DB8AFD65F71E4B40001B1021AEB44E40DB8AFD65F71E4B40
43837	23333	61.939943999999997	61.958081	54.181621	54.171961000000003	Молодежная	0103000020E610000001000000050000002409C21550F84E40FF976BD102164B402409C21550F84E4027A25F5B3F174B40A1F5F065A2FA4E4027A25F5B3F174B40A1F5F065A2FA4E40FF976BD102164B402409C21550F84E40FF976BD102164B40
43934	45584	61.379781000000001	61.394325000000002	54.344633000000002	54.326239000000001	Центральная	0103000020E610000001000000050000003352EFA99CB04E4002D71533C2294B403352EFA99CB04E40AA0F24EF1C2C4B40637FD93D79B24E40AA0F24EF1C2C4B40637FD93D79B24E4002D71533C2294B403352EFA99CB04E4002D71533C2294B40
43845	25025	60.719915	60.754373999999999	54.137562000000003	54.124426	Школьная	0103000020E610000001000000050000002E73BA2C265C4E40D462F030ED0F4B402E73BA2C265C4E401096B1A19B114B40F279C5538F604E401096B1A19B114B40F279C5538F604E40D462F030ED0F4B402E73BA2C265C4E40D462F030ED0F4B40
43554	19611	61.908664000000002	61.931247999999997	54.009723000000001	54.002822999999999	Школьная	0103000020E61000000100000005000000BA86191A4FF44E409B560A815C004B40BA86191A4FF44E406F826F9A3E014B40923B6C2233F74E406F826F9A3E014B40923B6C2233F74E409B560A815C004B40BA86191A4FF44E409B560A815C004B40
44034	46013	60.879069000000001	60.895077000000001	54.056365999999997	54.047279000000003	Мира	0103000020E61000000100000005000000B6F63E5585704E40D064FF3C0D064B40B6F63E5585704E409C4D470037074B406E3315E291724E409C4D470037074B406E3315E291724E40D064FF3C0D064B40B6F63E5585704E40D064FF3C0D064B40
43935	24162	61.491630999999998	61.510801000000001	54.298116999999998	54.278013999999999	Рабочая	0103000020E610000001000000050000009259BDC3EDBE4E4042EA76F695234B409259BDC3EDBE4E40D9B0A6B228264B40CEE15AED61C14E40D9B0A6B228264B40CEE15AED61C14E4042EA76F695234B409259BDC3EDBE4E4042EA76F695234B40
44155	49134	60.813924	60.833146999999997	53.976449000000002	53.96546	Мира	0103000020E61000000100000005000000FAB660A92E684E404FCC7A3194FB4A40FAB660A92E684E40209BE447FCFC4A4058E1968FA46A4E40209BE447FCFC4A4058E1968FA46A4E404FCC7A3194FB4A40FAB660A92E684E404FCC7A3194FB4A40
44061	23251	62.216777999999998	62.228149999999999	54.242288000000002	54.233463999999998	Набережная	0103000020E61000000100000005000000033FAA61BF1B4F408C65FA25E21D4B40033FAA61BF1B4F404C1B0E4B031F4B408C4AEA04341D4F404C1B0E4B031F4B408C4AEA04341D4F408C65FA25E21D4B40033FAA61BF1B4F408C65FA25E21D4B40
43930	49585	61.640211999999998	61.672767	54.208596	54.196883	Школьная	0103000020E61000000100000005000000DD408177F2D14E40B6114F7633194B40DD408177F2D14E40C8091346B31A4B40FD69A33A1DD64E40C8091346B31A4B40FD69A33A1DD64E40B6114F7633194B40DD408177F2D14E40B6114F7633194B40
44065	45888	60.957689999999999	60.973357	54.171629000000003	54.165647	Трудовая	0103000020E6100000010000000500000066DAFE95957A4E401BD7BFEB33154B4066DAFE95957A4E40C90567F0F7154B40952A51F6967C4E40C90567F0F7154B40952A51F6967C4E401BD7BFEB33154B4066DAFE95957A4E401BD7BFEB33154B40
43931	23187	62.138570000000001	62.154496999999999	54.357678	54.348663000000002	Центральная	0103000020E61000000100000005000000761A69A9BC114F40A2293BFDA02C4B40761A69A9BC114F40D53F8864C82D4B40412AC58EC6134F40D53F8864C82D4B40412AC58EC6134F40A2293BFDA02C4B40761A69A9BC114F40A2293BFDA02C4B40
42622	45437	61.723387000000002	61.756822	54.053258	54.036869000000003	Культуры	0103000020E6100000010000000500000000ADF9F197DC4E403D9E961FB8044B4000ADF9F197DC4E400C207C28D1064B405872158BDFE04E400C207C28D1064B405872158BDFE04E403D9E961FB8044B4000ADF9F197DC4E403D9E961FB8044B40
42623	45437	61.723387000000002	61.756822	54.053258	54.036869000000003	Водопроводная	0103000020E6100000010000000500000000ADF9F197DC4E403D9E961FB8044B4000ADF9F197DC4E400C207C28D1064B405872158BDFE04E400C207C28D1064B405872158BDFE04E403D9E961FB8044B4000ADF9F197DC4E403D9E961FB8044B40
43848	24420	61.183391999999998	61.201286000000003	54.010596	54.002251999999999	Школьная	0103000020E610000001000000050000008C2C996379974E40E02C25CB49004B408C2C996379974E40F5BBB0355B014B40439259BDC3994E40F5BBB0355B014B40439259BDC3994E40E02C25CB49004B408C2C996379974E40E02C25CB49004B40
43933	23798	61.749636000000002	61.763424999999998	54.096429999999998	54.088276	Новая	0103000020E61000000100000005000000BFF38B12F4DF4E40C782C2A04C0B4B40BFF38B12F4DF4E40382D78D1570C4B4072F90FE9B7E14E40382D78D1570C4B4072F90FE9B7E14E40C782C2A04C0B4B40BFF38B12F4DF4E40C782C2A04C0B4B40
43846	25225	61.005363000000003	61.017885999999997	54.035404	54.030793000000003	Школьная	0103000020E61000000100000005000000E2CD1ABCAF804E400EF96706F1034B40E2CD1ABCAF804E40E412471E88044B403387A4164A824E40E412471E88044B403387A4164A824E400EF96706F1034B40E2CD1ABCAF804E400EF96706F1034B40
43839	24554	61.074345000000001	61.082915	54.194307000000002	54.180757	Лассаля	0103000020E6100000010000000500000081CF0F2384894E40F4C29D0B23174B4081CF0F2384894E402331410DDF184B4086AC6EF59C8A4E402331410DDF184B4086AC6EF59C8A4E40F4C29D0B23174B4081CF0F2384894E40F4C29D0B23174B40
43549	49492	62.166445000000003	62.185138999999999	54.249954000000002	54.242804	Просвещения	0103000020E6100000010000000500000097CADB114E154F4043AB9333141F4B4097CADB114E154F4090C01F7EFE1F4B40691B7FA2B2174F4090C01F7EFE1F4B40691B7FA2B2174F4043AB9333141F4B4097CADB114E154F4043AB9333141F4B40
44066	45599	60.692588000000001	60.704625999999998	53.931032000000002	53.926276000000001	Центральная	0103000020E6100000010000000500000010CD3CB9A6584E40EC88433690F64A4010CD3CB9A6584E40C6C37B0E2CF74A40A5F44C2F315A4E40C6C37B0E2CF74A40A5F44C2F315A4E40EC88433690F64A4010CD3CB9A6584E40EC88433690F64A40
42824	428	61.206910000000001	61.219172	55.024692999999999	55.012852000000002	Федорова	0103000020E61000000100000005000000919BE1067C9A4E4017D86322A5814B40919BE1067C9A4E4056B8E52329834B407619FED30D9C4E4056B8E52329834B407619FED30D9C4E4017D86322A5814B40919BE1067C9A4E4017D86322A5814B40
43903	1423	61.353613000000003	61.371552999999999	55.556100000000001	55.545665999999997	Центральная	0103000020E610000001000000050000006138D73043AD4E4002452C62D8C54B406138D73043AD4E401EA7E8482EC74B4087DD770C8FAF4E401EA7E8482EC74B4087DD770C8FAF4E4002452C62D8C54B406138D73043AD4E4002452C62D8C54B40
43544	2213	61.104734999999998	61.121138000000002	55.020476000000002	55.013677999999999	Советская	0103000020E610000001000000050000008FDFDBF4678D4E405C566133C0814B408FDFDBF4678D4E402C2D23F59E824B40C4263273818F4E402C2D23F59E824B40C4263273818F4E405C566133C0814B408FDFDBF4678D4E405C566133C0814B40
44011	1027	61.246336999999997	61.261499999999998	55.328887999999999	55.313884999999999	Трактовая	0103000020E61000000100000005000000BA6587F8879F4E403CDA38622DA84B40BA6587F8879F4E40FF05820019AA4B40B6F3FDD478A14E40FF05820019AA4B40B6F3FDD478A14E403CDA38622DA84B40BA6587F8879F4E403CDA38622DA84B40
43534	32069	60.885348999999998	60.898051000000002	55.114415000000001	55.092736000000002	Плановая	0103000020E61000000100000005000000ED45B41D53714E40B894F3C5DE8B4B40ED45B41D53714E40FF959526A58E4B40EF91CD55F3724E40FF959526A58E4B40EF91CD55F3724E40B894F3C5DE8B4B40ED45B41D53714E40B894F3C5DE8B4B40
43620	32232	60.961875999999997	60.974767	55.118214999999999	55.107283000000002	Центральная	0103000020E610000001000000050000005567B5C01E7B4E4059350873BB8D4B405567B5C01E7B4E40C5724BAB218F4B402A1C412AC57C4E40C5724BAB218F4B402A1C412AC57C4E4059350873BB8D4B405567B5C01E7B4E4059350873BB8D4B40
42957	1852	61.172530999999999	61.195501	54.966540999999999	54.949098999999997	Мира	0103000020E61000000100000005000000E945ED7E15964E4049D576137C794B40E945ED7E15964E401F9F909DB77B4B40EBAA402D06994E401F9F909DB77B4B40EBAA402D06994E4049D576137C794B40E945ED7E15964E4049D576137C794B40
42952	1520	61.543723999999997	61.564205000000001	55.520263	55.507468000000003	Центральная	0103000020E6100000010000000500000070067FBF98C54E401EE21FB6F4C04B4070067FBF98C54E40D0285DFA97C24B40AE9E93DE37C84E40D0285DFA97C24B40AE9E93DE37C84E401EE21FB6F4C04B4070067FBF98C54E401EE21FB6F4C04B40
43770	1320	61.337955999999998	61.355356	55.484096999999998	55.466208000000002	Школьная	0103000020E6100000010000000500000055BE672442AB4E40199128B4ACBB4B4055BE672442AB4E40BD8BF7E3F6BD4B40FC372F4E7CAD4E40BD8BF7E3F6BD4B40FC372F4E7CAD4E40199128B4ACBB4B4055BE672442AB4E40199128B4ACBB4B40
42671	1759	61.522424999999998	61.546669999999999	55.331054000000002	55.317241000000003	Мира	0103000020E6100000010000000500000070CE88D2DEC24E40A5F9635A9BA84B4070CE88D2DEC24E40E19A3BFA5FAA4B4027DA5548F9C54E40E19A3BFA5FAA4B4027DA5548F9C54E40A5F9635A9BA84B4070CE88D2DEC24E40A5F9635A9BA84B40
44150	1373	61.281326	61.294459000000003	55.558570000000003	55.549968999999997	Школьная	0103000020E61000000100000005000000DBC1887D02A44E402B685A6265C64B40DBC1887D02A44E406C43C5387FC74B40A6811FD5B0A54E406C43C5387FC74B40A6811FD5B0A54E402B685A6265C64B40DBC1887D02A44E402B685A6265C64B40
43711	55165	60.86157	61.566882	55.641756999999998	54.92568	Школьная	0103000020E610000001000000050000007C9BFEEC476E4E40D847A7AE7C764B407C9BFEEC476E4E40527DE71725D24B407558E1968FC84E40527DE71725D24B407558E1968FC84E40D847A7AE7C764B407C9BFEEC476E4E40D847A7AE7C764B40
44196	587	61.198241000000003	61.213673999999997	55.134228999999998	55.124496000000001	Клубная	0103000020E61000000100000005000000F9DC09F65F994E40CD3D247CEF8F4B40F9DC09F65F994E405F96766A2E914B40B4006DAB599B4E405F96766A2E914B40B4006DAB599B4E40CD3D247CEF8F4B40F9DC09F65F994E40CD3D247CEF8F4B40
43104	1626	61.235906999999997	61.267339	55.033723000000002	55.012180999999998	Мичурина	0103000020E61000000100000005000000E0F25833329E4E40F850A2258F814B40E0F25833329E4E40BF0F070951844B4001F9122A38A24E40BF0F070951844B4001F9122A38A24E40F850A2258F814B40E0F25833329E4E40F850A2258F814B40
42710	1291	61.379250999999996	61.408357000000002	55.495364000000002	55.472796000000002	Мира	0103000020E61000000100000005000000D6FCF84B8BB04E40FED64E9484BC4B40D6FCF84B8BB04E40D1CE691668BF4B40DD0BCC0A45B44E40D1CE691668BF4B40DD0BCC0A45B44E40FED64E9484BC4B40D6FCF84B8BB04E40FED64E9484BC4B40
44153	485	61.174112000000001	61.199767999999999	55.184165999999998	55.172131	Центральная	0103000020E61000000100000005000000ABEB504D49964E405BD07B6308964B40ABEB504D49964E407F8461C092974B40C76471FF91994E407F8461C092974B40C76471FF91994E405BD07B6308964B40ABEB504D49964E405BD07B6308964B40
43538	485	61.174112000000001	61.199767999999999	55.184165999999998	55.172131	Трактовая	0103000020E61000000100000005000000ABEB504D49964E405BD07B6308964B40ABEB504D49964E407F8461C092974B40C76471FF91994E407F8461C092974B40C76471FF91994E405BD07B6308964B40ABEB504D49964E405BD07B6308964B40
43142	1069	61.259388999999999	61.275064999999998	55.315646999999998	55.308002999999999	Ленина	0103000020E6100000010000000500000098F8A3A833A14E40F2086EA46CA74B4098F8A3A833A14E404E0AF31E67A84B401AA3755435A34E404E0AF31E67A84B401AA3755435A34E40F2086EA46CA74B4098F8A3A833A14E40F2086EA46CA74B40
44297	55221	61.109802000000002	61.131478000000001	55.085991999999997	55.069040999999999	Советская	0103000020E610000001000000050000008884EFFD0D8E4E40A48AE255D6884B408884EFFD0D8E4E40DBDB2DC9018B4B405E126745D4904E40DBDB2DC9018B4B405E126745D4904E40A48AE255D6884B408884EFFD0D8E4E40A48AE255D6884B40
42841	2018	61.082600999999997	61.133526000000003	55.047595000000001	55.022851000000003	Почтовая	0103000020E61000000100000005000000F6CE68AB928A4E4028D714C8EC824B40F6CE68AB928A4E40003ACC9717864B403695456117914E40003ACC9717864B403695456117914E4028D714C8EC824B40F6CE68AB928A4E4028D714C8EC824B40
43163	2018	61.082600999999997	61.133526000000003	55.047595000000001	55.022851000000003	Полетаевская	0103000020E61000000100000005000000F6CE68AB928A4E4028D714C8EC824B40F6CE68AB928A4E40003ACC9717864B403695456117914E40003ACC9717864B403695456117914E4028D714C8EC824B40F6CE68AB928A4E4028D714C8EC824B40
43701	2018	61.082600999999997	61.133526000000003	55.047595000000001	55.022851000000003	Новостройка	0103000020E61000000100000005000000F6CE68AB928A4E4028D714C8EC824B40F6CE68AB928A4E40003ACC9717864B403695456117914E40003ACC9717864B403695456117914E4028D714C8EC824B40F6CE68AB928A4E4028D714C8EC824B40
43150	55128	60.86157	61.566882	55.641756999999998	54.92568	Центральная	0103000020E610000001000000050000007C9BFEEC476E4E40D847A7AE7C764B407C9BFEEC476E4E40527DE71725D24B407558E1968FC84E40527DE71725D24B407558E1968FC84E40D847A7AE7C764B407C9BFEEC476E4E40D847A7AE7C764B40
44314	55235	61.165075000000002	61.173447000000003	55.191535999999999	55.186205999999999	Центральная	0103000020E610000001000000050000009031772D21954E40D4282499D5974B409031772D21954E40DA006C4084984B406F4BE48233964E40DA006C4084984B406F4BE48233964E40D4282499D5974B409031772D21954E40D4282499D5974B40
43141	968	61.061984000000002	61.092806000000003	55.324806000000002	55.312046000000002	Школьная	0103000020E6100000010000000500000009707A17EF874E407F6C921FF1A74B4009707A17EF874E40B5C5353E93A94B40B16F2711E18B4E40B5C5353E93A94B40B16F2711E18B4E407F6C921FF1A74B4009707A17EF874E407F6C921FF1A74B40
43920	55189	61.032367000000001	61.042715000000001	55.304487999999999	55.292402000000003	Медиакская 	0103000020E610000001000000050000001D3C139A24844E407BA4C16D6DA54B401D3C139A24844E4021037976F9A64B403A0664AF77854E4021037976F9A64B403A0664AF77854E407BA4C16D6DA54B401D3C139A24844E407BA4C16D6DA54B40
43799	924	61.032367000000001	61.042715000000001	55.304487999999999	55.292402000000003	Центральная	0103000020E610000001000000050000001D3C139A24844E407BA4C16D6DA54B401D3C139A24844E4021037976F9A64B403A0664AF77854E4021037976F9A64B403A0664AF77854E407BA4C16D6DA54B401D3C139A24844E407BA4C16D6DA54B40
44146	711	60.892490000000002	60.913716999999998	55.202959	55.194609	Лесная	0103000020E61000000100000005000000E700C11C3D724E40EE409DF2E8984B40E700C11C3D724E40E5B67D8FFA994B404D66BCADF4744E40E5B67D8FFA994B404D66BCADF4744E40EE409DF2E8984B40E700C11C3D724E40EE409DF2E8984B40
44198	657	61.182008000000003	61.197594000000002	55.102621999999997	55.093122999999999	Школьная	0103000020E6100000010000000500000021CEC3094C974E40B1C05774EB8B4B4021CEC3094C974E40D0ECBAB7228D4B4063F19BC24A994E40D0ECBAB7228D4B4063F19BC24A994E40B1C05774EB8B4B4021CEC3094C974E40B1C05774EB8B4B40
43099	427	61.135331999999998	61.169908	55.191952000000001	55.173478000000003	Ленина	0103000020E61000000100000005000000170D198F52914E40AA49F08634964B40170D198F52914E406E3315E291984B4015AA9B8BBF954E406E3315E291984B4015AA9B8BBF954E40AA49F08634964B40170D198F52914E40AA49F08634964B40
44010	68	61.269801000000001	61.302526	55.353110000000001	55.334817999999999	 1 Мая	0103000020E61000000100000005000000CCB6D3D688A24E405A0EF450DBAA4B40CCB6D3D688A24E40FEF15EB532AD4B404818062CB9A64E40FEF15EB532AD4B404818062CB9A64E405A0EF450DBAA4B40CCB6D3D688A24E405A0EF450DBAA4B40
44197	311	61.071497000000001	61.083480999999999	55.252763000000002	55.248319000000002	Солнечная	0103000020E610000001000000050000008D614ED026894E40DBFCBFEAC89F4B408D614ED026894E40C651B9895AA04B402F6B6281AF8A4E40C651B9895AA04B402F6B6281AF8A4E40DBFCBFEAC89F4B408D614ED026894E40DBFCBFEAC89F4B40
44149	816	61.098061000000001	61.112496999999998	55.366661000000001	55.357322000000003	Больничная	0103000020E61000000100000005000000AC014A438D8C4E40171230BABCAD4B40AC014A438D8C4E40FDDB65BFEEAE4B40F5F23B4D668E4E40FDDB65BFEEAE4B40F5F23B4D668E4E40171230BABCAD4B40AC014A438D8C4E40171230BABCAD4B40
43667	810	61.168399000000001	61.192833	55.376185999999997	55.361083000000001	Школьная	0103000020E61000000100000005000000EDD632198E954E401F12BEF737AE4B40EDD632198E954E40459BE3DC26B04B40774B72C0AE984E40459BE3DC26B04B40774B72C0AE984E401F12BEF737AE4B40EDD632198E954E401F12BEF737AE4B40
43769	32143	61.060628000000001	61.074722000000001	55.137743999999998	55.119909	Школьная	0103000020E61000000100000005000000679C86A8C2874E407FBF982D598F4B40679C86A8C2874E40309C6B98A1914B405725917D90894E40309C6B98A1914B405725917D90894E407FBF982D598F4B40679C86A8C2874E407FBF982D598F4B40
43766	55171	61.344945000000003	61.357790999999999	55.274036000000002	55.271794999999997	Школьная	0103000020E6100000010000000500000099F5622827AC4E40B01BB62DCAA24B4099F5622827AC4E409DF6949C13A34B40CDE67118CCAD4E409DF6949C13A34B40CDE67118CCAD4E40B01BB62DCAA24B4099F5622827AC4E40B01BB62DCAA24B40
44008	320	61.197907999999998	61.216602000000002	55.290157000000001	55.285578999999998	Центральная	0103000020E61000000100000005000000F2CEA10C55994E4052B648DA8DA44B40F2CEA10C55994E404DDA54DD23A54B40C51F459DB99B4E404DDA54DD23A54B40C51F459DB99B4E4052B648DA8DA44B40F2CEA10C55994E4052B648DA8DA44B40
42968	139	61.199506999999997	61.238529999999997	55.307147000000001	55.292453000000002	Трактористов	0103000020E610000001000000050000005A29047289994E40FD4E93196FA54B405A29047289994E404208C89750A74B40B48EAA26889E4E404208C89750A74B40B48EAA26889E4E40FD4E93196FA54B405A29047289994E40FD4E93196FA54B40
42709	32340	61.274625	61.369396999999999	55.367203000000003	55.320293999999997	Строительная	0103000020E61000000100000005000000FED478E926A34E40718DCF64FFA84B40FED478E926A34E401EFF058200AF4B40C91EA16648AF4E401EFF058200AF4B40C91EA16648AF4E40718DCF64FFA84B40FED478E926A34E40718DCF64FFA84B40
42959	32340	61.274625	61.369396999999999	55.367203000000003	55.320293999999997	Свердловская	0103000020E61000000100000005000000FED478E926A34E40718DCF64FFA84B40FED478E926A34E401EFF058200AF4B40C91EA16648AF4E401EFF058200AF4B40C91EA16648AF4E40718DCF64FFA84B40FED478E926A34E40718DCF64FFA84B40
43139	32340	61.274625	61.369396999999999	55.367203000000003	55.320293999999997	Набережная	0103000020E61000000100000005000000FED478E926A34E40718DCF64FFA84B40FED478E926A34E401EFF058200AF4B40C91EA16648AF4E401EFF058200AF4B40C91EA16648AF4E40718DCF64FFA84B40FED478E926A34E40718DCF64FFA84B40
44012	31903	60.880650000000003	60.896056000000002	55.059379	55.051282999999998	Молодежная	0103000020E61000000100000005000000789CA223B9704E409EEBFB7090864B40789CA223B9704E40DB8827BB99874B403AB187F6B1724E40DB8827BB99874B403AB187F6B1724E409EEBFB7090864B40789CA223B9704E409EEBFB7090864B40
43545	32274	61.351457000000003	61.383122999999998	54.996991000000001	54.983266999999998	Школьная 	0103000020E61000000100000005000000A379008BFCAC4E40361E6CB1DB7D4B40A379008BFCAC4E4003B4AD669D7F4B4036ACA92C0AB14E4003B4AD669D7F4B4036ACA92C0AB14E40361E6CB1DB7D4B40A379008BFCAC4E40361E6CB1DB7D4B40
43883	2313	61.023366000000003	61.038277999999998	54.994197	54.987405000000003	Лесная	0103000020E610000001000000050000004FEB36A8FD824E4015747B49637E4B404FEB36A8FD824E400264E8D8417F4B400114234BE6844E400264E8D8417F4B400114234BE6844E4015747B49637E4B404FEB36A8FD824E4015747B49637E4B40
44226	2370	60.982033999999999	60.997692000000001	55.013756000000001	55.008712000000003	Школьная	0103000020E61000000100000005000000B0C7444AB37D4E40988A8D791D814B40B0C7444AB37D4E40D80FB1C1C2814B408CBD175FB47F4E40D80FB1C1C2814B408CBD175FB47F4E40988A8D791D814B40B0C7444AB37D4E40988A8D791D814B40
43584	31955	61.172944000000001	61.190595999999999	55.047708	55.023660999999997	Ленина	0103000020E610000001000000050000000C056C0723964E406798DA5207834B400C056C0723964E40F8E0B54B1B864B40CC5F217365984E40F8E0B54B1B864B40CC5F217365984E406798DA5207834B400C056C0723964E406798DA5207834B40
43901	1513	61.281227000000001	61.321058000000001	55.641756999999998	55.632219999999997	Победы	0103000020E6100000010000000500000048E00F3FFFA34E4045F0BF95ECD04B4048E00F3FFFA34E40527DE71725D24B40410FB56D18A94E40527DE71725D24B40410FB56D18A94E4045F0BF95ECD04B4048E00F3FFFA34E4045F0BF95ECD04B40
43539	32496	61.445887999999997	61.485019000000001	55.372456999999997	55.357106999999999	Озерная	0103000020E61000000100000005000000E4D6A4DB12B94E401A16A3AEB5AD4B40E4D6A4DB12B94E404815C5ABACAF4B402578431A15BE4E404815C5ABACAF4B402578431A15BE4E401A16A3AEB5AD4B40E4D6A4DB12B94E401A16A3AEB5AD4B40
44195	543	60.964489999999998	60.994458000000002	55.223956000000001	55.206868	Набережная	0103000020E61000000100000005000000D6A88768747B4E40624B8FA67A9A4B40D6A88768747B4E401ADF1797AA9C4B406F9F55664A7F4E401ADF1797AA9C4B406F9F55664A7F4E40624B8FA67A9A4B40D6A88768747B4E40624B8FA67A9A4B40
43537	1854	60.965074000000001	61.001258	54.938761999999997	54.926296000000001	Центральная	0103000020E61000000100000005000000261C7A8B877B4E40333509DE90764B40261C7A8B877B4E40205D6C5A29784B40DF6DDE3829804E40205D6C5A29784B40DF6DDE3829804E40333509DE90764B40261C7A8B877B4E40333509DE90764B40
43905	6453	60.86157	60.868127999999999	55.219482999999997	55.211331999999999	1 Мая	0103000020E610000001000000050000007C9BFEEC476E4E40944C4EED0C9B4B407C9BFEEC476E4E409483D904189C4B40F65E7CD11E6F4E409483D904189C4B40F65E7CD11E6F4E40944C4EED0C9B4B407C9BFEEC476E4E40944C4EED0C9B4B40
44018	32060	60.867804	60.887872999999999	55.131990000000002	55.123471000000002	Лесная	0103000020E6100000010000000500000043AB9333146F4E409180D1E5CD8F4B4043AB9333146F4E4014B35E0CE5904B402E008DD2A5714E4014B35E0CE5904B402E008DD2A5714E409180D1E5CD8F4B4043AB9333146F4E409180D1E5CD8F4B40
44104	25755	59.146731000000003	59.167149999999999	55.036169000000001	55.028388	Нагорная	0103000020E610000001000000050000009A27D714C8924D40A7CCCD37A2834B409A27D714C8924D408410902FA1844B4061C3D32B65954D408410902FA1844B4061C3D32B65954D40A7CCCD37A2834B409A27D714C8924D40A7CCCD37A2834B40
43695	26208	58.998806000000002	59.012810000000002	55.206955999999998	55.198047000000003	Центральная	0103000020E61000000100000005000000388600E0D87F4D401409A69A59994B40388600E0D87F4D4001DBC1887D9A4B40E88711C2A3814D4001DBC1887D9A4B40E88711C2A3814D401409A69A59994B40388600E0D87F4D401409A69A59994B40
43268	55137	58.855038999999998	58.904069	55.141922000000001	55.123460999999999	Луговая	0103000020E61000000100000005000000FBE6FEEA716D4D406DAAEE91CD8F4B40FBE6FEEA716D4D409D4A06802A924B40E9297288B8734D409D4A06802A924B40E9297288B8734D406DAAEE91CD8F4B40FBE6FEEA716D4D406DAAEE91CD8F4B40
43527	55137	58.855038999999998	58.904069	55.141922000000001	55.123460999999999	Кооперативная	0103000020E61000000100000005000000FBE6FEEA716D4D406DAAEE91CD8F4B40FBE6FEEA716D4D409D4A06802A924B40E9297288B8734D409D4A06802A924B40E9297288B8734D406DAAEE91CD8F4B40FBE6FEEA716D4D406DAAEE91CD8F4B40
42913	55120	58.907456000000003	58.912936000000002	54.975226999999997	54.969455000000004	Нахимова	0103000020E610000001000000050000008D47A98427744D40CBF8F719177C4B408D47A98427744D408D96033DD47C4B40A8AB3B16DB744D408D96033DD47C4B40A8AB3B16DB744D40CBF8F719177C4B408D47A98427744D40CBF8F719177C4B40
44291	26242	59.061444999999999	59.085538	55.218460999999998	55.208579	Школьная	0103000020E6100000010000000500000059C0046EDD874D40F2D077B7B29A4B4059C0046EDD874D40C939B187F69B4B405A48C0E8F28A4D40C939B187F69B4B405A48C0E8F28A4D40F2D077B7B29A4B4059C0046EDD874D40F2D077B7B29A4B40
43273	55139	58.767992	58.840063999999998	55.184479000000003	55.140667000000001	Ширпышева	0103000020E6100000010000000500000079CBD58F4D624D402F50526001924B4079CBD58F4D624D403FE603029D974B4002469737876B4D403FE603029D974B4002469737876B4D402F50526001924B4079CBD58F4D624D402F50526001924B40
43404	55139	58.767992	58.840063999999998	55.184479000000003	55.140667000000001	Советская	0103000020E6100000010000000500000079CBD58F4D624D402F50526001924B4079CBD58F4D624D403FE603029D974B4002469737876B4D403FE603029D974B4002469737876B4D402F50526001924B4079CBD58F4D624D402F50526001924B40
43311	55139	58.767992	58.840063999999998	55.184479000000003	55.140667000000001	Карла Маркса	0103000020E6100000010000000500000079CBD58F4D624D402F50526001924B4079CBD58F4D624D403FE603029D974B4002469737876B4D403FE603029D974B4002469737876B4D402F50526001924B4079CBD58F4D624D402F50526001924B40
43831	25691	59.171605999999997	59.192186	55.102626999999998	55.092917	Школьная	0103000020E6100000010000000500000010E6762FF7954D40081F4AB4E48B4B4010E6762FF7954D40E257ACE1228D4B40E15F048D99984D40E257ACE1228D4B40E15F048D99984D40081F4AB4E48B4B4010E6762FF7954D40081F4AB4E48B4B40
43278	55141	59.251223000000003	59.263485000000003	55.014541000000001	55.008308999999997	Рабочая	0103000020E610000001000000050000006380441328A04D4098A1F14410814B406380441328A04D40BFB9BF7ADC814B4048FE60E0B9A14D40BFB9BF7ADC814B4048FE60E0B9A14D4098A1F14410814B406380441328A04D4098A1F14410814B40
43704	55141	59.251223000000003	59.263485000000003	55.014541000000001	55.008308999999997	Карла Маркса	0103000020E610000001000000050000006380441328A04D4098A1F14410814B406380441328A04D40BFB9BF7ADC814B4048FE60E0B9A14D40BFB9BF7ADC814B4048FE60E0B9A14D4098A1F14410814B406380441328A04D4098A1F14410814B40
43649	55141	59.251223000000003	59.263485000000003	55.014541000000001	55.008308999999997	Гагарина	0103000020E610000001000000050000006380441328A04D4098A1F14410814B406380441328A04D40BFB9BF7ADC814B4048FE60E0B9A14D40BFB9BF7ADC814B4048FE60E0B9A14D4098A1F14410814B406380441328A04D4098A1F14410814B40
44287	25987	59.185654999999997	59.211554	55.177874000000003	55.164068	Наливная	0103000020E6100000010000000500000060AB048BC3974D40FA28232E00954B4060AB048BC3974D4084674293C4964B4043AB9333149B4D4084674293C4964B4043AB9333149B4D40FA28232E00954B4060AB048BC3974D40FA28232E00954B40
43807	55178	58.873607	58.886561	54.958219	54.947470000000003	Школьная	0103000020E610000001000000050000004147AB5AD26F4D4077F86BB246794B404147AB5AD26F4D40F2B391EBA67A4B405C74B2D47A714D40F2B391EBA67A4B405C74B2D47A714D4077F86BB246794B404147AB5AD26F4D4077F86BB246794B40
43798	26397	58.894421000000001	58.925404	55.235990999999999	55.230122999999999	Центральная	0103000020E6100000010000000500000085ED27637C724D405987A3AB749D4B4085ED27637C724D403E93FDF3349E4B4036CB65A373764D403E93FDF3349E4B4036CB65A373764D405987A3AB749D4B4085ED27637C724D405987A3AB749D4B40
44103	25735	59.090209000000002	59.105111999999998	55.037582	55.028120000000001	Речная	0103000020E610000001000000050000000667F0F78B8B4D40882EA86F99834B400667F0F78B8B4D408A75AA7CCF844B4065355D4F748D4D408A75AA7CCF844B4065355D4F748D4D40882EA86F99834B400667F0F78B8B4D40882EA86F99834B40
43279	55142	59.113143000000001	59.168658999999998	55.174197999999997	55.143821000000003	Советская	0103000020E61000000100000005000000BB6246787B8E4D4030BDFDB968924B40BB6246787B8E4D40A983BC1E4C964B4089963C9E96954D40A983BC1E4C964B4089963C9E96954D4030BDFDB968924B40BB6246787B8E4D4030BDFDB968924B40
43732	55142	59.113143000000001	59.168658999999998	55.174197999999997	55.143821000000003	Красноармейская	0103000020E61000000100000005000000BB6246787B8E4D4030BDFDB968924B40BB6246787B8E4D40A983BC1E4C964B4089963C9E96954D40A983BC1E4C964B4089963C9E96954D4030BDFDB968924B40BB6246787B8E4D4030BDFDB968924B40
43408	55142	59.113143000000001	59.168658999999998	55.174197999999997	55.143821000000003	 Пушкина	0103000020E61000000100000005000000BB6246787B8E4D4030BDFDB968924B40BB6246787B8E4D40A983BC1E4C964B4089963C9E96954D40A983BC1E4C964B4089963C9E96954D4030BDFDB968924B40BB6246787B8E4D4030BDFDB968924B40
43611	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	Чкалова	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
42988	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	Титова	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
43522	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	Леонова	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
42831	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	Ленина	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
44113	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	Кутузовых	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
42764	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	Калинина	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
43236	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	Андрея Костылева	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
42765	24783	58.767569999999999	58.864165999999997	54.958373999999999	54.867610999999997	50 лет ВЛКСМ	0103000020E6100000010000000500000003B2D7BB3F624D402E5393E00D6F4B4003B2D7BB3F624D4019ABCDFFAB7A4B405628D2FD9C6E4D4019ABCDFFAB7A4B405628D2FD9C6E4D402E5393E00D6F4B4003B2D7BB3F624D402E5393E00D6F4B40
44310	55232	58.666967999999997	58.708838	55.167122999999997	55.143785000000001	Центральная	0103000020E6100000010000000500000040BD19355F554D40E353008C67924B4040BD19355F554D4067B4554964954B40BE141E34BB5A4D4067B4554964954B40BE141E34BB5A4D40E353008C67924B4040BD19355F554D40E353008C67924B40
43592	26313	58.809989000000002	58.847377000000002	55.234368000000003	55.220860000000002	Степана Разина	0103000020E61000000100000005000000548F34B8AD674D404E7FF623459C4B40548F34B8AD674D404E9D47C5FF9D4B40F9307BD9766C4D404E9D47C5FF9D4B40F9307BD9766C4D404E7FF623459C4B40548F34B8AD674D404E7FF623459C4B40
43573	26313	58.809989000000002	58.847377000000002	55.234368000000003	55.220860000000002	Пугачева	0103000020E61000000100000005000000548F34B8AD674D404E7FF623459C4B40548F34B8AD674D404E9D47C5FF9D4B40F9307BD9766C4D404E9D47C5FF9D4B40F9307BD9766C4D404E7FF623459C4B40548F34B8AD674D404E7FF623459C4B40
9924	40358	59.040073999999997	59.062406000000003	55.157907000000002	55.140847000000001	Сергея Маринина	0103000020E61000000100000005000000BFB5132521854D40AF5E454607924B40BFB5132521854D409D67EC4B36944B407F8978EBFC874D409D67EC4B36944B407F8978EBFC874D40AF5E454607924B40BFB5132521854D40AF5E454607924B40
43834	55186	60.459484000000003	60.466752	54.506224000000003	54.498513000000003	Центральная	0103000020E610000001000000050000008484285FD03A4E40C0D02346CF3F4B408484285FD03A4E40A439B2F2CB404B40DAAB8F87BE3B4E40A439B2F2CB404B40DAAB8F87BE3B4E40C0D02346CF3F4B408484285FD03A4E40C0D02346CF3F4B40
44186	55213	60.407328	60.427208	54.290391999999997	54.279716999999998	Школьный	0103000020E610000001000000050000005F5FEB5223344E404F9143C4CD234B405F5FEB5223344E409082A7902B254B40774B72C0AE364E409082A7902B254B40774B72C0AE364E404F9143C4CD234B405F5FEB5223344E404F9143C4CD234B40
43833	55185	60.405755999999997	60.41977	54.245961000000001	54.232275000000001	Мира	0103000020E61000000100000005000000F01307D0EF334E40D656EC2FBB1D4B40F01307D0EF334E40B58B69A67B1F4B40C4EBFA05BB354E40B58B69A67B1F4B40C4EBFA05BB354E40D656EC2FBB1D4B40F01307D0EF334E40D656EC2FBB1D4B40
44172	55210	60.974282000000002	60.990703000000003	54.434306999999997	54.423979000000003	Библиотечная	0103000020E610000001000000050000006E8AC745B57C4E406C98A1F144364B406E8AC745B57C4E4041B62C5F97374B4049861C5BCF7E4E4041B62C5F97374B4049861C5BCF7E4E406C98A1F144364B406E8AC745B57C4E406C98A1F144364B40
12130	41023	59.790374	59.808205999999998	53.18036	53.167000999999999	Набережная	0103000020E61000000100000005000000EACDA8F92AE54D401CB3EC4960954A40EACDA8F92AE54D40D7C0560916974A402A37514B73E74D40D7C0560916974A402A37514B73E74D401CB3EC4960954A40EACDA8F92AE54D401CB3EC4960954A40
44177	55211	60.502181	60.513849999999998	54.557417000000001	54.550671000000001	Холмистая	0103000020E6100000010000000500000017D68D7747404E4085ED27637C464B4017D68D7747404E40029EB47059474B40598638D6C5414E40029EB47059474B40598638D6C5414E4085ED27637C464B4017D68D7747404E4085ED27637C464B40
43947	55193	59.817827000000001	59.837491	54.372906	54.365924999999997	 Береговой	0103000020E6100000010000000500000095641D8EAEE84D40F7E461A1D62E4B4095641D8EAEE84D40B83D4162BB2F4B40E0D8B3E732EB4D40B83D4162BB2F4B40E0D8B3E732EB4D40F7E461A1D62E4B4095641D8EAEE84D40F7E461A1D62E4B40
43491	55156	60.915244999999999	60.935834	54.448281999999999	54.435809999999996	Школьная	0103000020E61000000100000005000000EC6987BF26754E4087A2409FC8374B40EC6987BF26754E4057B1F84D61394B40103E9468C9774E4057B1F84D61394B40103E9468C9774E4087A2409FC8374B40EC6987BF26754E4087A2409FC8374B40
44326	55244	62.800620000000002	62.829141	54.263534	54.255650000000003	Центральная	0103000020E61000000100000005000000034356B77A664F40789CA223B9204B40034356B77A664F4029B16B7BBB214B40E962D34A216A4F4029B16B7BBB214B40E962D34A216A4F40789CA223B9204B40034356B77A664F40789CA223B9204B40
44300	55223	62.595480000000002	62.612450000000003	54.335830999999999	54.323523999999999	Победы	0103000020E6100000010000000500000007B64AB0384C4F404DBC033C69294B4007B64AB0384C4F40D2FD9C82FC2A4B40B537F8C2644E4F40D2FD9C82FC2A4B40B537F8C2644E4F404DBC033C69294B4007B64AB0384C4F404DBC033C69294B40
44312	55234	62.507840999999999	62.533622000000001	54.625973999999999	54.611564999999999	Ленина	0103000020E61000000100000005000000B24813EF00414F406A300DC3474E4B40B24813EF00414F40BA1281EA1F504B408B36C7B94D444F40BA1281EA1F504B408B36C7B94D444F406A300DC3474E4B40B24813EF00414F406A300DC3474E4B40
44320	55240	63.050260999999999	63.063277999999997	54.414622999999999	54.410808000000003	Центральная	0103000020E61000000100000005000000D3A1D3F36E864F40B477465B95344B40D3A1D3F36E864F40AF95D05D12354B403447567E19884F40AF95D05D12354B403447567E19884F40B477465B95344B40D3A1D3F36E864F40B477465B95344B40
43731	55167	62.624468999999998	62.658999999999999	54.100411000000001	54.089390999999999	Школьная	0103000020E61000000100000005000000D32EA699EE4F4F4043C70E2A710B4B40D32EA699EE4F4F404F948444DA0C4B403108AC1C5A544F404F948444DA0C4B403108AC1C5A544F4043C70E2A710B4B40D32EA699EE4F4F4043C70E2A710B4B40
44299	55222	62.719565000000003	62.741186999999996	54.284242999999996	54.271106000000003	Труда	0103000020E61000000100000005000000522CB7B41A5C4F40ECDFF599B3224B40522CB7B41A5C4F40F78E1A1362244B40349C3237DF5E4F40F78E1A1362244B40349C3237DF5E4F40ECDFF599B3224B40522CB7B41A5C4F40ECDFF599B3224B40
43814	48175	62.754463999999999	62.763249999999999	54.491076999999997	54.485956999999999	Центральная	0103000020E610000001000000050000003201BF4692604F409221C7D6333E4B403201BF4692604F40AD68739CDB3E4B4004560E2DB2614F40AD68739CDB3E4B4004560E2DB2614F409221C7D6333E4B403201BF4692604F409221C7D6333E4B40
44328	55246	62.528357999999997	62.550393999999997	54.220705000000002	54.215251000000002	Молодежная	0103000020E610000001000000050000003C4A253CA1434F4035B742588D1B4B403C4A253CA1434F402788BA0F401C4B4012F5824F73464F402788BA0F401C4B4012F5824F73464F4035B742588D1B4B403C4A253CA1434F4035B742588D1B4B40
44045	48171	62.615639000000002	62.626328999999998	54.375230000000002	54.371248999999999	Центральная	0103000020E6100000010000000500000032923D42CD4E4F401BD65416852F4B4032923D42CD4E4F40323D618907304B40A8C4758C2B504F40323D618907304B40A8C4758C2B504F401BD65416852F4B4032923D42CD4E4F401BD65416852F4B40
43841	55188	62.453150999999998	62.471494999999997	54.391311000000002	54.384180999999998	Лесная	0103000020E6100000010000000500000029931ADA003A4F404E5FCFD72C314B4029931ADA003A4F4054C8957A16324B401F9DBAF2593C4F4054C8957A16324B401F9DBAF2593C4F404E5FCFD72C314B4029931ADA003A4F404E5FCFD72C314B40
43298	55146	62.494895999999997	62.529409000000001	54.242378000000002	54.225833000000002	Гагарина	0103000020E61000000100000005000000EA758BC0583F4F40C5AD8218E81C4B40EA758BC0583F4F408CA2073E061F4B40A29A92ACC3434F408CA2073E061F4B40A29A92ACC3434F40C5AD8218E81C4B40EA758BC0583F4F40C5AD8218E81C4B40
43928	55191	63.149732	63.158786999999997	54.618670999999999	54.611862000000002	Восточная	0103000020E6100000010000000500000014950D6B2A934F4024D5777E514E4B4014950D6B2A934F40E7FD7F9C304F4B40D503E62153944F40E7FD7F9C304F4B40D503E62153944F4024D5777E514E4B4014950D6B2A934F4024D5777E514E4B40
43337	55125	62.696486999999998	62.759377999999998	54.429321999999999	54.395567999999997	Ленина	0103000020E61000000100000005000000698B6B7C26594F400CACE3F8A1324B40698B6B7C26594F4006BAF605F4364B40A4A65D4C33614F4006BAF605F4364B40A4A65D4C33614F400CACE3F8A1324B40698B6B7C26594F400CACE3F8A1324B40
43288	55125	62.696486999999998	62.759377999999998	54.429321999999999	54.395567999999997	Комсомольская	0103000020E61000000100000005000000698B6B7C26594F400CACE3F8A1324B40698B6B7C26594F4006BAF605F4364B40A4A65D4C33614F4006BAF605F4364B40A4A65D4C33614F400CACE3F8A1324B40698B6B7C26594F400CACE3F8A1324B40
43067	55125	62.696486999999998	62.759377999999998	54.429321999999999	54.395567999999997	Качалина	0103000020E61000000100000005000000698B6B7C26594F400CACE3F8A1324B40698B6B7C26594F4006BAF605F4364B40A4A65D4C33614F4006BAF605F4364B40A4A65D4C33614F400CACE3F8A1324B40698B6B7C26594F400CACE3F8A1324B40
43296	55125	62.696486999999998	62.759377999999998	54.429321999999999	54.395567999999997	Восточная	0103000020E61000000100000005000000698B6B7C26594F400CACE3F8A1324B40698B6B7C26594F4006BAF605F4364B40A4A65D4C33614F4006BAF605F4364B40A4A65D4C33614F400CACE3F8A1324B40698B6B7C26594F400CACE3F8A1324B40
43329	55125	62.696486999999998	62.759377999999998	54.429321999999999	54.395567999999997	1 Мая	0103000020E61000000100000005000000698B6B7C26594F400CACE3F8A1324B40698B6B7C26594F4006BAF605F4364B40A4A65D4C33614F4006BAF605F4364B40A4A65D4C33614F400CACE3F8A1324B40698B6B7C26594F400CACE3F8A1324B40
43927	19219	63.042454999999997	63.067267000000001	54.358879999999999	54.342728000000001	Октябрьская	0103000020E610000001000000050000009D465A2A6F854F4035B6D782DE2B4B409D465A2A6F854F402098A3C7EF2D4B40CE8C7E349C884F402098A3C7EF2D4B40CE8C7E349C884F4035B6D782DE2B4B409D465A2A6F854F4035B6D782DE2B4B40
44323	55242	62.323146999999999	62.343629	54.394373000000002	54.380437000000001	Мира	0103000020E61000000100000005000000776682E15C294F401C98DC28B2304B40776682E15C294F4074B680D07A324B40857AFA08FC2B4F4074B680D07A324B40857AFA08FC2B4F401C98DC28B2304B40776682E15C294F401C98DC28B2304B40
44302	55225	62.859316	62.872799000000001	54.664203000000001	54.651192999999999	Советская	0103000020E61000000100000005000000FB761211FE6D4F402B31CF4A5A534B40FB761211FE6D4F40DA73999A04554B40A27DACE0B76F4F40DA73999A04554B40A27DACE0B76F4F402B31CF4A5A534B40FB761211FE6D4F402B31CF4A5A534B40
44308	55230	62.573813000000001	62.593423000000001	54.585340000000002	54.573787000000003	Могильская	0103000020E61000000100000005000000848252B472494F405BEF37DA71494B40848252B472494F403485CE6BEC4A4B40DCD8EC48F54B4F403485CE6BEC4A4B40DCD8EC48F54B4F405BEF37DA71494B40848252B472494F405BEF37DA71494B40
44301	55224	62.767876000000001	62.783965000000002	54.268760999999998	54.260446999999999	Центральная	0103000020E6100000010000000500000010B1C1C249624F40B0ABC95356214B4010B1C1C249624F405AB8ACC266224B40B51A12F758644F405AB8ACC266224B40B51A12F758644F40B0ABC95356214B4010B1C1C249624F40B0ABC95356214B40
44020	18107	62.675232999999999	62.691160000000004	54.560299000000001	54.549349999999997	Центральная	0103000020E610000001000000050000000917F2086E564F405F07CE1951464B400917F2086E564F40A27DACE0B7474B40D5264EEE77584F40A27DACE0B7474B40D5264EEE77584F405F07CE1951464B400917F2086E564F405F07CE1951464B40
44053	55199	62.833973999999998	62.847709000000002	54.464523	54.452444	Школьная	0103000020E610000001000000050000006EDBF7A8BF6A4F40BEA25BAFE9394B406EDBF7A8BF6A4F40B29E5A7D753B4B402FC37FBA816C4F40B29E5A7D753B4B402FC37FBA816C4F40BEA25BAFE9394B406EDBF7A8BF6A4F40BEA25BAFE9394B40
44044	55198	63.125540000000001	63.138728	54.521313999999997	54.513866	 Рабочая	0103000020E61000000100000005000000802BD9B111904F405F43705CC6414B40802BD9B111904F403579CA6ABA424B400E85CFD6C1914F403579CA6ABA424B400E85CFD6C1914F405F43705CC6414B40802BD9B111904F405F43705CC6414B40
43810	55179	62.662754999999997	62.683937	54.610590000000002	54.607081000000001	Кузнецовская	0103000020E610000001000000050000005721E527D5544F40F18288D4B44D4B405721E527D5544F40E0A128D0274E4B401EC3633F8B574F40E0A128D0274E4B401EC3633F8B574F40F18288D4B44D4B405721E527D5544F40F18288D4B44D4B40
43635	55160	63.144773000000001	63.178809999999999	54.200591000000003	54.180529999999997	Школьная	0103000020E61000000100000005000000022CF2EB87924F4033F9669B1B174B40022CF2EB87924F409C6F44F7AC194B405019FF3EE3964F409C6F44F7AC194B405019FF3EE3964F4033F9669B1B174B40022CF2EB87924F4033F9669B1B174B40
43605	17530	62.967509	63.003377999999998	54.581384999999997	54.563223000000001	Школьная	0103000020E61000000100000005000000F7CABC55D77B4F4071ADF6B017484B40F7CABC55D77B4F4046B1DCD26A4A4B4050C3B7B06E804F4046B1DCD26A4A4B4050C3B7B06E804F4071ADF6B017484B40F7CABC55D77B4F4071ADF6B017484B40
44315	55236	62.868918999999998	62.885734999999997	54.401181000000001	54.389183000000003	Киевская	0103000020E61000000100000005000000BFEFDFBC386F4F406094A0BFD0314B40BFEFDFBC386F4F40676325E659334B4016F6B4C35F714F40676325E659334B4016F6B4C35F714F406094A0BFD0314B40BFEFDFBC386F4F406094A0BFD0314B40
43733	55168	62.398829999999997	62.447859999999999	54.068857999999999	54.053755000000002	Школьная	0103000020E61000000100000005000000F35487DC0C334F408D7F9F71E1064B40F35487DC0C334F40B308C556D0084B40E197FA7953394F40B308C556D0084B40E197FA7953394F408D7F9F71E1064B40F35487DC0C334F408D7F9F71E1064B40
44170	55209	62.507311000000001	62.520623999999998	54.121338999999999	54.113835000000002	Пионерская	0103000020E6100000010000000500000056F31C91EF404F40F1113125920E4B4056F31C91EF404F405B5D4E09880F4B40A0C1A6CEA3424F405B5D4E09880F4B40A0C1A6CEA3424F40F1113125920E4B4056F31C91EF404F40F1113125920E4B40
44292	55217	62.335363999999998	62.351875	54.641123	54.632984	Восточная	0103000020E61000000100000005000000BC202235ED2A4F401572A59E05514B40BC202235ED2A4F4051DB865110524B40D7A3703D0A2D4F4051DB865110524B40D7A3703D0A2D4F401572A59E05514B40BC202235ED2A4F401572A59E05514B40
44311	55233	62.419932000000003	62.426355000000001	54.679588000000003	54.671008	Северная	0103000020E610000001000000050000009E45EF54C0354F405CAD1397E3554B409E45EF54C0354F40856055BDFC564B4038BEF6CC92364F40856055BDFC564B4038BEF6CC92364F405CAD1397E3554B409E45EF54C0354F405CAD1397E3554B40
43940	55192	62.828360000000004	62.848562999999999	54.548723000000003	54.540837000000003	 Советская	0103000020E6100000010000000500000044A852B3076A4F40BFBB95253A454B4044A852B3076A4F4011C8258E3C464B403ECC5EB69D6C4F4011C8258E3C464B403ECC5EB69D6C4F40BFBB95253A454B4044A852B3076A4F40BFBB95253A454B40
44318	55239	62.695481000000001	62.720345999999999	54.266852	54.261750999999997	Свободы	0103000020E61000000100000005000000A4FE7A8505594F40FF58880E81214B40A4FE7A8505594F40A46FD23428224B40F7E6374C345C4F40A46FD23428224B40F7E6374C345C4F40FF58880E81214B40A4FE7A8505594F40FF58880E81214B40
43795	55174	62.995994000000003	63.010438999999998	54.505451000000001	54.495919000000001	Центральная	0103000020E6100000010000000500000091813CBB7C7F4F40863B17467A3F4B4091813CBB7C7F4F40815D4D9EB2404B402DCDAD1056814F40815D4D9EB2404B402DCDAD1056814F40863B17467A3F4B4091813CBB7C7F4F40863B17467A3F4B40
43819	55180	62.305720000000001	62.326875000000001	54.505749000000002	54.489409000000002	1 мая	0103000020E61000000100000005000000D7DD3CD521274F401DAF40F4A43E4B40D7DD3CD521274F400B7E1B62BC404B40A4703D0AD7294F400B7E1B62BC404B40A4703D0AD7294F401DAF40F4A43E4B40D7DD3CD521274F401DAF40F4A43E4B40
44306	55228	62.981945000000003	62.991512	54.292814999999997	54.281956000000001	Школьная	0103000020E6100000010000000500000041BCAE5FB07D4F409B745B2217244B4041BCAE5FB07D4F409D6340F67A254B40B8CB7EDDE97E4F409D6340F67A254B40B8CB7EDDE97E4F409B745B2217244B4041BCAE5FB07D4F409B745B2217244B40
44305	55227	62.634557000000001	62.648201999999998	54.494999	54.485863000000002	Центральная	0103000020E610000001000000050000005439ED2939514F4011AB3FC2303E4B405439ED2939514F40BF4692205C3F4B40D4997B48F8524F40BF4692205C3F4B40D4997B48F8524F4011AB3FC2303E4B405439ED2939514F4011AB3FC2303E4B40
44021	17329	62.290098	62.315519999999999	54.660823000000001	54.652537000000002	Калинина	0103000020E61000000100000005000000485167EE21254F400937195586534B40485167EE21254F40E9B81AD995544B40F19D98F562284F40E9B81AD995544B40F19D98F562284F400937195586534B40485167EE21254F400937195586534B40
44046	18616	62.163741000000002	62.190116000000003	54.556592000000002	54.535457000000001	Центральная	0103000020E61000000100000005000000D6011077F5144F4007B5DFDA89444B40D6011077F5144F408D9B1A683E474B40223999B855184F408D9B1A683E474B40223999B855184F4007B5DFDA89444B40D6011077F5144F4007B5DFDA89444B40
44309	55231	62.807572999999998	62.833157	54.122399999999999	54.112662999999998	Советская	0103000020E61000000100000005000000F910548D5E674F40103CBEBD6B0E4B40F910548D5E674F40E4839ECDAA0F4B407CB779E3A46A4F40E4839ECDAA0F4B407CB779E3A46A4F40103CBEBD6B0E4B40F910548D5E674F40103CBEBD6B0E4B40
44304	55226	62.630550999999997	62.652847000000001	54.451177000000001	54.443282000000004	 Молодежная	0103000020E61000000100000005000000E4BA29E5B5504F40E773EE76BD384B40E4BA29E5B5504F408CDAFD2AC0394B405725917D90534F408CDAFD2AC0394B405725917D90534F40E773EE76BD384B40E4BA29E5B5504F40E773EE76BD384B40
43801	55176	63.074883999999997	63.089616999999997	54.680774	54.673350999999997	Трудовая	0103000020E61000000100000005000000307F85CC95894F404CDD955D30564B40307F85CC95894F40CAFB389A23574B403315E291788B4F40CAFB389A23574B403315E291788B4F404CDD955D30564B40307F85CC95894F404CDD955D30564B40
44296	55220	62.287393999999999	62.307777000000002	54.633771000000003	54.619906	Южная	0103000020E6100000010000000500000087889B53C9244F400E4C6E14594F4B4087889B53C9244F409D137B681F514B4002BB9A3C65274F409D137B681F514B4002BB9A3C65274F400E4C6E14594F4B4087889B53C9244F400E4C6E14594F4B40
44334	55247	62.217281	62.234968000000002	54.484383000000001	54.470148000000002	Центральная	0103000020E61000000100000005000000668522DDCF1B4F40D12346CF2D3C4B40668522DDCF1B4F4083DE1B43003E4B40A3CD716E131E4F4083DE1B43003E4B40A3CD716E131E4F40D12346CF2D3C4B40668522DDCF1B4F40D12346CF2D3C4B40
44330	55247	62.217281	62.234968000000002	54.484383000000001	54.470148000000002	Береговая	0103000020E61000000100000005000000668522DDCF1B4F40D12346CF2D3C4B40668522DDCF1B4F4083DE1B43003E4B40A3CD716E131E4F4083DE1B43003E4B40A3CD716E131E4F40D12346CF2D3C4B40668522DDCF1B4F40D12346CF2D3C4B40
42986	51931	21.710574000000001	21.720195	54.463712000000001	54.456349000000003	Пономаренко	0103000020E610000001000000050000004E637B2DE8B53540FA47DFA4693A4B404E637B2DE8B53540A26131EA5A3B4B4023BE13B35EB83540A26131EA5A3B4B4023BE13B35EB83540FA47DFA4693A4B404E637B2DE8B53540FA47DFA4693A4B40
43521	23965	59.252526000000003	59.276896999999998	56.254716999999999	56.229807000000001	Октябрьская	0103000020E61000000100000005000000E2B19FC552A04D4029B2D6506A1D4C40E2B19FC552A04D401C5E10919A204C4025AE635C71A34D401C5E10919A204C4025AE635C71A34D4029B2D6506A1D4C40E2B19FC552A04D4029B2D6506A1D4C40
43705	24313	59.389536999999997	59.425964	55.811174000000001	55.792558999999997	Просвещенская	0103000020E610000001000000050000007DCA3159DCB14D404293C49272E54B407DCA3159DCB14D40C9AEB48CD4E74B40FDA204FD85B64D40C9AEB48CD4E74B40FDA204FD85B64D404293C49272E54B407DCA3159DCB14D404293C49272E54B40
43892	24177	59.185862	59.217185999999998	56.165669000000001	56.150108000000003	27 съезда КПСС	0103000020E61000000100000005000000DAC87553CA974D401A6F2BBD36134C40DAC87553CA974D40037B4CA434154C40149337C0CC9B4D40037B4CA434154C40149337C0CC9B4D401A6F2BBD36134C40DAC87553CA974D401A6F2BBD36134C40
44282	24018	59.310448999999998	59.329403999999997	56.292543000000002	56.282969999999999	Школьная	0103000020E61000000100000005000000B709F7CABCA74D40E3DF675C38244C40B709F7CABCA74D403DD68C0C72254C40F69507E929AA4D403DD68C0C72254C40F69507E929AA4D40E3DF675C38244C40B709F7CABCA74D40E3DF675C38244C40
43603	7338	59.718769000000002	59.745952000000003	55.795245999999999	55.779888999999997	Ленина	0103000020E610000001000000050000007730629F00DC4D404CC11A67D3E34B407730629F00DC4D402D23F59ECAE54B406231EA5A7BDF4D402D23F59ECAE54B406231EA5A7BDF4D404CC11A67D3E34B407730629F00DC4D404CC11A67D3E34B40
44099	24455	59.449311000000002	59.475560000000002	55.856735	55.848488000000003	Советская	0103000020E61000000100000005000000D55DD90583B94D40348639419BEC4B40D55DD90583B94D40562B137EA9ED4B4094A46B26DFBC4D40562B137EA9ED4B4094A46B26DFBC4D40348639419BEC4B40D55DD90583B94D40348639419BEC4B40
44218	24163	59.145679999999999	59.163431000000003	56.176915000000001	56.170811	Мира	0103000020E6100000010000000500000034D769A4A5924D4006668522DD154C4034D769A4A5924D40FF959526A5164C408813984EEB944D40FF959526A5164C408813984EEB944D4006668522DD154C4034D769A4A5924D4006668522DD154C40
44286	24520	59.593535000000003	59.610360999999997	55.864913999999999	55.857017999999997	Никитина	0103000020E61000000100000005000000040473F4F8CB4D40AA0A0DC4B2ED4B40040473F4F8CB4D4020ED7F80B5EE4B407EE02A4F20CE4D4020ED7F80B5EE4B407EE02A4F20CE4D40AA0A0DC4B2ED4B40040473F4F8CB4D40AA0A0DC4B2ED4B40
44101	24261	59.374544	59.379224000000001	55.970135999999997	55.967542000000002	Школьная	0103000020E61000000100000005000000DE74CB0EF1AF4D40D3C08F6AD8FB4B40DE74CB0EF1AF4D400C569C6A2DFC4B40DDED7A698AB04D400C569C6A2DFC4B40DDED7A698AB04D40D3C08F6AD8FB4B40DE74CB0EF1AF4D40D3C08F6AD8FB4B40
43973	24356	59.274867	59.306891999999998	55.828125999999997	55.818012000000003	Гагарина	0103000020E61000000100000005000000F4DF83D72EA34D4027DE019EB4E84B40F4DF83D72EA34D40D07B630800EA4B40B7B3AF3C48A74D40D07B630800EA4B40B7B3AF3C48A74D4027DE019EB4E84B40F4DF83D72EA34D4027DE019EB4E84B40
43797	24665	59.596715000000003	59.618760000000002	55.628698	55.621521000000001	Школьная	0103000020E610000001000000050000002E04392861CC4D407C6308008ECF4B402E04392861CC4D40C287122D79D04B405709168733CF4D40C287122D79D04B405709168733CF4D407C6308008ECF4B402E04392861CC4D407C6308008ECF4B40
44283	24406	59.281433999999997	59.314940999999997	55.905557999999999	55.896948000000002	Молодежная	0103000020E61000000100000005000000C1FD800706A44D40371B2B31CFF24B40C1FD800706A44D40CA501553E9F34B40B39597FC4FA84D40CA501553E9F34B40B39597FC4FA84D40371B2B31CFF24B40C1FD800706A44D40371B2B31CFF24B40
44097	24060	59.282367999999998	59.309559999999998	56.214922000000001	56.196567000000002	Школьная	0103000020E61000000100000005000000EDB776A224A44D40863C821B29194C40EDB776A224A44D4070986890821B4C402B137EA99FA74D4070986890821B4C402B137EA99FA74D40863C821B29194C40EDB776A224A44D40863C821B29194C40
43568	24060	59.282367999999998	59.309559999999998	56.214922000000001	56.196567000000002	Гагарина	0103000020E61000000100000005000000EDB776A224A44D40863C821B29194C40EDB776A224A44D4070986890821B4C402B137EA99FA74D4070986890821B4C402B137EA99FA74D40863C821B29194C40EDB776A224A44D40863C821B29194C40
44100	24617	59.703192999999999	59.722354000000003	55.714210999999999	55.703307000000002	Победы	0103000020E6100000010000000500000058E36C3A02DA4D402106BAF605DA4B4058E36C3A02DA4D40C3B81B446BDB4B4041118B1876DC4D40C3B81B446BDB4B4041118B1876DC4D402106BAF605DA4B4058E36C3A02DA4D402106BAF605DA4B40
42973	53078	60.037761000000003	60.088749999999997	53.540120999999999	53.519058999999999	Пионерская	0103000020E610000001000000050000003A083A5AD5044E40E4D87A8670C24A403A083A5AD5044E40007157AF22C54A408FC2F5285C0B4E40007157AF22C54A408FC2F5285C0B4E40E4D87A8670C24A403A083A5AD5044E40E4D87A8670C24A40
44003	17495	59.507601999999999	59.517178000000001	53.732498999999997	53.726393999999999	Молодежная	0103000020E610000001000000050000002DB1321AF9C04D405C01857AFADC4A402DB1321AF9C04D4025ADF886C2DD4A40F81A82E332C24D4025ADF886C2DD4A40F81A82E332C24D405C01857AFADC4A402DB1321AF9C04D405C01857AFADC4A40
43102	53077	59.799734999999998	59.843662000000002	53.532018000000001	53.507016999999998	Советская	0103000020E61000000100000005000000B83B6BB75DE64D400DC2DCEEE5C04A40B83B6BB75DE64D401171732A19C44A406170CD1DFDEB4D401171732A19C44A406170CD1DFDEB4D400DC2DCEEE5C04A40B83B6BB75DE64D400DC2DCEEE5C04A40
42969	53077	59.799734999999998	59.843662000000002	53.532018000000001	53.507016999999998	Мира	0103000020E61000000100000005000000B83B6BB75DE64D400DC2DCEEE5C04A40B83B6BB75DE64D401171732A19C44A406170CD1DFDEB4D401171732A19C44A406170CD1DFDEB4D400DC2DCEEE5C04A40B83B6BB75DE64D400DC2DCEEE5C04A40
44231	17223	59.590390999999997	59.599662000000002	53.415900999999998	53.406357999999997	Труда	0103000020E61000000100000005000000266DAAEE91CB4D40E63BF88903B44A40266DAAEE91CB4D40D5AF743E3CB54A40B55373B9C1CC4D40D5AF743E3CB54A40B55373B9C1CC4D40E63BF88903B44A40266DAAEE91CB4D40E63BF88903B44A40
43915	17875	59.393462	59.405355999999998	53.545417999999998	53.540244000000001	переулок Школьный	0103000020E61000000100000005000000001C7BF65CB24D401CEE23B726C54A40001C7BF65CB24D402A53CC41D0C54A40629E95B4E2B34D402A53CC41D0C54A40629E95B4E2B34D401CEE23B726C54A40001C7BF65CB24D401CEE23B726C54A40
44162	18869	59.880223999999998	59.889800000000001	53.407963000000002	53.399647000000002	Новая	0103000020E61000000100000005000000C093162EABF04D40E67805A227B34A40C093162EABF04D40317DAF2138B44A408BFD65F7E4F14D40317DAF2138B44A408BFD65F7E4F14D40E67805A227B34A40C093162EABF04D40E67805A227B34A40
43659	17586	60.039019000000003	60.055394999999997	53.594766999999997	53.579363000000001	Мира	0103000020E6100000010000000500000019761893FE044E4098C1189128CA4A4019761893FE044E40B9DE365321CC4A4053AEF02E17074E40B9DE365321CC4A4053AEF02E17074E4098C1189128CA4A4019761893FE044E4098C1189128CA4A40
44132	18698	59.807226999999997	59.818240000000003	53.451622999999998	53.446550000000002	Молодежная	0103000020E610000001000000050000005EB9DE3653E74D40B003E78C28B94A405EB9DE3653E74D408A8F4FC8CEB94A40B8239C16BCE84D408A8F4FC8CEB94A40B8239C16BCE84D40B003E78C28B94A405EB9DE3653E74D40B003E78C28B94A40
44157	18177	59.660828000000002	59.675623000000002	53.638159999999999	53.627620999999998	Центральная	0103000020E61000000100000005000000FB230C0396D44D4033A48AE255D04A40FB230C0396D44D40C4CE143AAFD14A4074B680D07AD64D40C4CE143AAFD14A4074B680D07AD64D4033A48AE255D04A40FB230C0396D44D4033A48AE255D04A40
43869	53072	59.424984000000002	59.440686999999997	53.721919	53.715801999999996	Центральная 	0103000020E6100000010000000500000061A92EE065B64D40A83462669FDB4A4061A92EE065B64D4036AE7FD767DC4A40DC627E6E68B84D4036AE7FD767DC4A40DC627E6E68B84D40A83462669FDB4A4061A92EE065B64D40A83462669FDB4A40
43749	17948	59.558284999999998	59.571032000000002	53.597872000000002	53.587674999999997	Центральная	0103000020E61000000100000005000000766C04E275C74D40A1D634EF38CB4A40766C04E275C74D40D998D71187CC4A40187C9A9317C94D40D998D71187CC4A40187C9A9317C94D40A1D634EF38CB4A40766C04E275C74D40A1D634EF38CB4A40
44074	18551	59.710909000000001	59.722875000000002	53.573990000000002	53.563567999999997	Центральная	0103000020E610000001000000050000004EB7EC10FFDA4D403B8908FF22C84A404EB7EC10FFDA4D40931D1B8178C94A404A0C022B87DC4D40931D1B8178C94A404A0C022B87DC4D403B8908FF22C84A404EB7EC10FFDA4D403B8908FF22C84A40
43103	18234	60.078696999999998	60.117719999999998	53.320635000000003	53.285975999999998	Пионерская	0103000020E610000001000000050000008BA548BE120A4E406FB88FDC9AA44A408BA548BE120A4E40FB7953910AA94A40E50AEF72110F4E40FB7953910AA94A40E50AEF72110F4E406FB88FDC9AA44A408BA548BE120A4E406FB88FDC9AA44A40
42682	53075	59.711942000000001	59.738137000000002	53.691879999999998	53.676543000000002	Васильева	0103000020E610000001000000050000000D535BEA20DB4D403BAB05F698D64A400D535BEA20DB4D40D4601A868FD84A40D97BF1457BDE4D40D4601A868FD84A40D97BF1457BDE4D403BAB05F698D64A400D535BEA20DB4D403BAB05F698D64A40
44058	18367	59.842908000000001	59.856938999999997	53.254477999999999	53.246304000000002	Молодежная	0103000020E61000000100000005000000B5C4CA68E4EB4D40DF6FB4E3869F4A40B5C4CA68E4EB4D4097C62FBC92A04A405ED5592DB0ED4D4097C62FBC92A04A405ED5592DB0ED4D40DF6FB4E3869F4A40B5C4CA68E4EB4D40DF6FB4E3869F4A40
43621	53073	59.509236999999999	59.544972000000001	53.551340000000003	53.534063000000003	Центральная	0103000020E61000000100000005000000E27492AD2EC14D407880272D5CC44A40E27492AD2EC14D40037D224F92C64A402C9E7AA4C1C54D40037D224F92C64A402C9E7AA4C1C54D407880272D5CC44A40E27492AD2EC14D407880272D5CC44A40
44156	17747	59.968904999999999	59.978983999999997	53.544170999999999	53.537959000000001	Целинная	0103000020E6100000010000000500000027F73B1405FC4D4060CB2BD7DBC44A4027F73B1405FC4D403F373465A7C54A4054A703594FFD4D403F373465A7C54A4054A703594FFD4D4060CB2BD7DBC44A4027F73B1405FC4D4060CB2BD7DBC44A40
44159	17787	59.878463000000004	59.888102000000003	53.650506999999998	53.645356	Центральная	0103000020E610000001000000050000007FDFBF7971F04D40812381069BD24A407FDFBF7971F04D40D76839D043D34A4090C18A53ADF14D40D76839D043D34A4090C18A53ADF14D40812381069BD24A407FDFBF7971F04D40812381069BD24A40
44135	18274	59.869928999999999	59.896859999999997	53.266365999999998	53.257612999999999	Новая	0103000020E61000000100000005000000C66B5ED559EF4D4021037976F9A04A40C66B5ED559EF4D401762F54718A24A40978BF84ECCF24D401762F54718A24A40978BF84ECCF24D4021037976F9A04A40C66B5ED559EF4D4021037976F9A04A40
44324	55243	59.660550000000001	59.674491000000003	53.761806	53.753241000000003	Мира	0103000020E61000000100000005000000B8AF03E78CD44D40D0807A336AE04A40B8AF03E78CD44D40C3F2E7DB82E14A40223999B855D64D40C3F2E7DB82E14A40223999B855D64D40D0807A336AE04A40B8AF03E78CD44D40D0807A336AE04A40
44033	18799	59.662185000000001	59.674860000000002	53.464550000000003	53.454535	Советская	0103000020E610000001000000050000006D73637AC2D44D4095F1EF332EBA4A406D73637AC2D44D40ACADD85F76BB4A4075B0FECF61D64D40ACADD85F76BB4A4075B0FECF61D64D4095F1EF332EBA4A406D73637AC2D44D4095F1EF332EBA4A40
43897	17661	60.016264	60.032874	53.603734000000003	53.594676	Советская	0103000020E61000000100000005000000130D52F014024E40A9DBD9571ECC4A40130D52F014024E40DCBDDC2747CD4A40C171193735044E40DCBDDC2747CD4A40C171193735044E40A9DBD9571ECC4A40130D52F014024E40A9DBD9571ECC4A40
43907	18325	60.265484000000001	60.279381000000001	53.311774999999997	53.303888000000001	Новая	0103000020E610000001000000050000003ECE3461FB214E40CCD24ECDE5A64A403ECE3461FB214E40EE5A423EE8A74A40D80FB1C1C2234E40EE5A423EE8A74A40D80FB1C1C2234E40CCD24ECDE5A64A403ECE3461FB214E40CCD24ECDE5A64A40
43752	18490	59.755358000000001	59.76567	53.616331000000002	53.601858	Степная	0103000020E61000000100000005000000D0622992AFE04D40016BD5AE09CD4A40D0622992AFE04D40684128EFE3CE4A40A0C37C7901E24D40684128EFE3CE4A40A0C37C7901E24D40016BD5AE09CD4A40D0622992AFE04D40016BD5AE09CD4A40
43530	53071	59.559462000000003	59.579206999999997	53.809285000000003	53.793103000000002	Труда	0103000020E6100000010000000500000069AD68739CC74D4004AE2B6684E54A4069AD68739CC74D405A12A0A696E74A40A04E797423CA4D405A12A0A696E74A40A04E797423CA4D4004AE2B6684E54A4069AD68739CC74D4004AE2B6684E54A40
44026	17123	59.938209999999998	59.954414999999997	53.687508000000001	53.680010000000003	переулок Южный	0103000020E61000000100000005000000DC63E94317F84D40FB7953910AD74A40DC63E94317F84D4083DE1B4300D84A40EAE74D452AFA4D4083DE1B4300D84A40EAE74D452AFA4D40FB7953910AD74A40DC63E94317F84D40FB7953910AD74A40
43918	18758	59.965591000000003	59.978149000000002	53.537391	53.529074999999999	Школьная	0103000020E61000000100000005000000EE27637C98FB4D40CB10C7BAB8C34A40EE27637C98FB4D401615713AC9C44A40BCCE86FC33FD4D401615713AC9C44A40BCCE86FC33FD4D40CB10C7BAB8C34A40EE27637C98FB4D40CB10C7BAB8C34A40
43847	17291	59.735926999999997	59.74474	53.406534999999998	53.400410000000001	Комсомольская	0103000020E61000000100000005000000279F1EDB32DE4D40E57E87A240B34A40279F1EDB32DE4D40F5D6C05609B44A40F302ECA353DF4D40F5D6C05609B44A40F302ECA353DF4D40E57E87A240B34A40279F1EDB32DE4D40E57E87A240B34A40
43498	18433	59.734310000000001	59.756346000000001	53.573647000000001	53.564354000000002	Придорожная	0103000020E610000001000000050000001990BDDEFDDD4D40F3AE7AC03CC84A401990BDDEFDDD4D406939D0436DC94A40EF3A1BF2CFE04D406939D0436DC94A40EF3A1BF2CFE04D40F3AE7AC03CC84A401990BDDEFDDD4D40F3AE7AC03CC84A40
44055	17989	59.487282999999998	59.498573999999998	53.561326999999999	53.55547	Березовая	0103000020E61000000100000005000000C972124A5FBE4D405EF415A419C74A40C972124A5FBE4D404FAE2990D9C74A406551D845D1BF4D404FAE2990D9C74A406551D845D1BF4D405EF415A419C74A40C972124A5FBE4D405EF415A419C74A40
44063	17192	59.595278	59.615417999999998	53.447366000000002	53.432727999999997	Советская	0103000020E610000001000000050000009F03CB1132CC4D40200890A163B74A409F03CB1132CC4D40D2AB014A43B94A4053AF5B04C6CE4D40D2AB014A43B94A4053AF5B04C6CE4D40200890A163B74A409F03CB1132CC4D40200890A163B74A40
43891	17677	60.064287999999998	60.078364999999998	53.477916999999998	53.471801999999997	Советская	0103000020E610000001000000050000003BC3D4963A084E40FC17080264BC4A403BC3D4963A084E40E9995E622CBD4A40551344DD070A4E40E9995E622CBD4A40551344DD070A4E40FC17080264BC4A403BC3D4963A084E40FC17080264BC4A40
43193	53070	59.877124000000002	59.893940999999998	53.760869	53.740962000000003	Мира	0103000020E61000000100000005000000B344679945F04D4015CAC2D7D7DE4A40B344679945F04D4026C5C72764E14A40DAC69FA86CF24D4026C5C72764E14A40DAC69FA86CF24D4015CAC2D7D7DE4A40B344679945F04D4015CAC2D7D7DE4A40
43919	18046	59.596544999999999	59.610711000000002	53.547750000000001	53.539349999999999	Школьная	0103000020E61000000100000005000000D1CB28965BCC4D407E8CB96B09C54A40D1CB28965BCC4D40273108AC1CC64A405B272EC72BCE4D40273108AC1CC64A405B272EC72BCE4D407E8CB96B09C54A40D1CB28965BCC4D407E8CB96B09C54A40
44133	17367	59.729970999999999	59.742907000000002	53.385831000000003	53.376232999999999	Советская	0103000020E61000000100000005000000A30392B06FDD4D408656276728B04A40A30392B06FDD4D40396403E962B14A40187C9A9317DF4D40396403E962B14A40187C9A9317DF4D408656276728B04A40A30392B06FDD4D408656276728B04A40
44102	55204	59.512363000000001	59.524310999999997	55.410806000000001	55.400742000000001	Школьная	0103000020E6100000010000000500000019575C1C95C14D401B118C834BB34B4019575C1C95C14D4013807F4A95B44B406EF7729F1CC34D4013807F4A95B44B406EF7729F1CC34D401B118C834BB34B4019575C1C95C14D401B118C834BB34B40
43735	55169	59.664017000000001	59.722766999999997	55.365397000000002	55.322307000000002	Карла Маркса	0103000020E61000000100000005000000787E5182FED44D40CD22145B41A94B40787E5182FED44D403C873254C5AE4B4063D009A183DC4D403C873254C5AE4B4063D009A183DC4D40CD22145B41A94B40787E5182FED44D40CD22145B41A94B40
44015	40400	59.646023999999997	59.666299000000002	55.343471000000001	55.327997000000003	Чернышевского	0103000020E610000001000000050000002E3718EAB0D24D40D31742CEFBA94B402E3718EAB0D24D40ED0F94DBF6AB4B40C32D1F4949D54D40ED0F94DBF6AB4B40C32D1F4949D54D40D31742CEFBA94B402E3718EAB0D24D40D31742CEFBA94B40
44289	22271	59.401628000000002	59.418750000000003	55.465482999999999	55.457377999999999	Школьная	0103000020E610000001000000050000003694DA8B68B34D4077F4BF5C8BBA4B403694DA8B68B34D4007EC6AF294BB4B409A99999999B54D4007EC6AF294BB4B409A99999999B54D4077F4BF5C8BBA4B403694DA8B68B34D4077F4BF5C8BBA4B40
43564	40401	59.434640999999999	59.478344	55.472898000000001	55.447324999999999	Трактовая	0103000020E610000001000000050000001840F850A2B74D4073D712F241B94B401840F850A2B74D40022CF2EB87BC4B40711E4E603ABD4D40022CF2EB87BC4B40711E4E603ABD4D4073D712F241B94B401840F850A2B74D4073D712F241B94B40
44227	55216	59.614806999999999	59.630671999999997	55.542385000000003	55.531523999999997	Школьная	0103000020E610000001000000050000000A2DEBFEB1CE4D4001857AFA08C44B400A2DEBFEB1CE4D40A56B26DF6CC54B405F402FDCB9D04D40A56B26DF6CC54B405F402FDCB9D04D4001857AFA08C44B400A2DEBFEB1CE4D4001857AFA08C44B40
44038	55197	59.825301000000003	59.837130999999999	55.483075999999997	55.471831999999999	Школьная	0103000020E61000000100000005000000952D9276A3E94D40679AB0FD64BC4B40952D9276A3E94D40C2BD326FD5BD4B40E0BBCD1B27EB4D40C2BD326FD5BD4B40E0BBCD1B27EB4D40679AB0FD64BC4B40952D9276A3E94D40679AB0FD64BC4B40
43826	20493	61.358086999999998	61.370071000000003	55.901097	55.893535999999997	Школьная	0103000020E61000000100000005000000B60F79CBD5AD4E403AE63C635FF24B40B60F79CBD5AD4E4009C3802557F34B4059198D7C5EAF4E4009C3802557F34B4059198D7C5EAF4E403AE63C635FF24B40B60F79CBD5AD4E403AE63C635FF24B40
44030	20693	61.885244999999998	61.892423000000001	56.116222	56.108673000000003	Вокзальная	0103000020E6100000010000000500000048F949B54FF14E40A77A32FFE80D4C4048F949B54FF14E40B189CC5CE00E4C405F99B7EA3AF24E40B189CC5CE00E4C405F99B7EA3AF24E40A77A32FFE80D4C4048F949B54FF14E40A77A32FFE80D4C40
44280	20910	61.694892000000003	61.707135999999998	56.043236	56.034174	Центральная	0103000020E6100000010000000500000043209738F2D84E40CF2F4AD05F044C4043209738F2D84E404301DBC188054C4081E9B46E83DA4E404301DBC188054C4081E9B46E83DA4E40CF2F4AD05F044C4043209738F2D84E40CF2F4AD05F044C40
42894	48266	61.730545999999997	61.762597999999997	55.876283999999998	55.855319999999999	Целинная	0103000020E610000001000000050000009F1C058882DD4E40AFCE31207BED4B409F1C058882DD4E400801F9122AF04B405CFFAECF9CE14E400801F9122AF04B405CFFAECF9CE14E40AFCE31207BED4B409F1C058882DD4E40AFCE31207BED4B40
44294	48112	61.826424000000003	61.902025999999999	56.146407000000004	56.114350000000002	Ленина	0103000020E610000001000000050000009450FA42C8E94E4018265305A30E4C409450FA42C8E94E40E773EE76BD124C402312859675F34E40E773EE76BD124C402312859675F34E4018265305A30E4C409450FA42C8E94E4018265305A30E4C40
43644	48112	61.826424000000003	61.902025999999999	56.146407000000004	56.114350000000002	Базарная	0103000020E610000001000000050000009450FA42C8E94E4018265305A30E4C409450FA42C8E94E40E773EE76BD124C402312859675F34E40E773EE76BD124C402312859675F34E4018265305A30E4C409450FA42C8E94E4018265305A30E4C40
43763	45933	61.725093999999999	61.753551999999999	55.995060000000002	55.986505999999999	Мира	0103000020E610000001000000050000004E4354E1CFDC4E4065A71FD445FE4B404E4354E1CFDC4E4065C746205EFF4B40EEEA556474E04E4065C746205EFF4B40EEEA556474E04E4065A71FD445FE4B404E4354E1CFDC4E4065A71FD445FE4B40
43974	21051	61.730690000000003	61.741227000000002	55.894944000000002	55.881338	Станционная	0103000020E61000000100000005000000D3C1FA3F87DD4E406C5CFFAECFF04B40D3C1FA3F87DD4E402FE065868DF24B40C3F4BD86E0DE4E402FE065868DF24B40C3F4BD86E0DE4E406C5CFFAECFF04B40D3C1FA3F87DD4E406C5CFFAECFF04B40
44206	20350	61.162855999999998	61.207709000000001	55.953099999999999	55.932015999999997	Школьная	0103000020E610000001000000050000008BFA2477D8944E40A3ACDF4C4CF74B408BFA2477D8944E40A7E8482EFFF94B40DD0A6135969A4E40A7E8482EFFF94B40DD0A6135969A4E40A3ACDF4C4CF74B408BFA2477D8944E40A3ACDF4C4CF74B40
43825	19817	61.592413000000001	61.608097000000001	55.498367000000002	55.480714999999996	Челябинская	0103000020E61000000100000005000000D55C6E30D4CB4E402BD9B11188BD4B40D55C6E30D4CB4E40EC33677DCABF4B40DAE55B1FD6CD4E40EC33677DCABF4B40DAE55B1FD6CD4E402BD9B11188BD4B40D55C6E30D4CB4E402BD9B11188BD4B40
43790	19636	61.776873000000002	61.793419999999998	55.640481999999999	55.623502999999999	Школьная	0103000020E610000001000000050000009D12109370E34E409CFA40F2CECF4B409D12109370E34E409DD66D50FBD14B4004FF5BC98EE54E409DD66D50FBD14B4004FF5BC98EE54E409CFA40F2CECF4B409D12109370E34E409CFA40F2CECF4B40
44029	19506	61.787005999999998	61.799618000000002	55.892843999999997	55.883606	Озерная	0103000020E61000000100000005000000BDE0D39CBCE44E4052465C001AF14B40BDE0D39CBCE44E40043752B648F24B407FA5F3E159E64E40043752B648F24B407FA5F3E159E64E4052465C001AF14B40BDE0D39CBCE44E4052465C001AF14B40
44281	48167	61.878427000000002	61.889916999999997	56.130958999999997	56.123638999999997	Станционная	0103000020E610000001000000050000003276C24B70F04E404CC11A67D30F4C403276C24B70F04E40F50EB743C3104C40C493DDCCE8F14E40F50EB743C3104C40C493DDCCE8F14E404CC11A67D30F4C403276C24B70F04E404CC11A67D30F4C40
43984	55195	61.824052000000002	61.835577000000001	56.010930999999999	56.002113000000001	Центральная	0103000020E61000000100000005000000091A33897AE94E40BFF2203D45004C40091A33897AE94E409CC1DF2F66014C401825E82FF4EA4E409CC1DF2F66014C401825E82FF4EA4E40BFF2203D45004C40091A33897AE94E40BFF2203D45004C40
44221	55215	61.050189000000003	61.070248999999997	55.769823000000002	55.757576999999998	Ленина	0103000020E610000001000000050000003ACFD8976C864E40D4997B48F8E04B403ACFD8976C864E40B45A608F89E24B40D1C952EBFD884E40B45A608F89E24B40D1C952EBFD884E40D4997B48F8E04B403ACFD8976C864E40D4997B48F8E04B40
77216	61103	60.923679999999997	62.242739	56.239848000000002	55.439450999999998	Железнодорожников	0103000020E6100000010000000500000011FC6F253B764E40E5982CEE3FB84B4011FC6F253B764E406901DA56B31E4C405C3B5112121F4F406901DA56B31E4C405C3B5112121F4F40E5982CEE3FB84B4011FC6F253B764E40E5982CEE3FB84B40
43598	19754	61.780565000000003	61.809094999999999	55.499656999999999	55.486372000000003	Школьная	0103000020E610000001000000050000007DB3CD8DE9E34E4056D80C7041BE4B407DB3CD8DE9E34E40D61BB5C2F4BF4B40B62DCA6C90E74E40D61BB5C2F4BF4B40B62DCA6C90E74E4056D80C7041BE4B407DB3CD8DE9E34E4056D80C7041BE4B40
43789	19698	61.714241999999999	61.750399000000002	55.541091999999999	55.524859999999997	Ленина	0103000020E61000000100000005000000FEB627486CDB4E40417DCB9C2EC34B40FEB627486CDB4E404910AE8042C54B40BEF90D130DE04E404910AE8042C54B40BEF90D130DE04E40417DCB9C2EC34B40FEB627486CDB4E40417DCB9C2EC34B40
43047	478	61.631956000000002	61.667251	55.991515999999997	55.968891999999997	Комсомольская	0103000020E61000000100000005000000684128EFE3D04E4092AD2EA704FC4B40684128EFE3D04E40F9BA0CFFE9FE4B40959C137B68D54E40F9BA0CFFE9FE4B40959C137B68D54E4092AD2EA704FC4B40684128EFE3D04E4092AD2EA704FC4B40
42899	19595	61.583914	61.625892999999998	55.599626000000001	55.573576000000003	Лесная	0103000020E6100000010000000500000099D6A6B1BDCA4E40A0E238F06AC94B4099D6A6B1BDCA4E4068EA758BC0CC4B40CDE506431DD04E4068EA758BC0CC4B40CDE506431DD04E40A0E238F06AC94B4099D6A6B1BDCA4E40A0E238F06AC94B40
42796	19595	61.583914	61.625892999999998	55.599626000000001	55.573576000000003	Вокзальная	0103000020E6100000010000000500000099D6A6B1BDCA4E40A0E238F06AC94B4099D6A6B1BDCA4E4068EA758BC0CC4B40CDE506431DD04E4068EA758BC0CC4B40CDE506431DD04E40A0E238F06AC94B4099D6A6B1BDCA4E40A0E238F06AC94B40
42811	28035	60.971901000000003	61.009189999999997	55.794097000000001	55.783867999999998	Центральная	0103000020E6100000010000000500000090F98040677C4E40C23060C955E44B4090F98040677C4E40056D72F8A4E54B40A1B94E232D814E40056D72F8A4E54B40A1B94E232D814E40C23060C955E44B4090F98040677C4E40C23060C955E44B40
44098	47716	61.683062	61.697408000000003	55.854956000000001	55.845638000000001	Центральная	0103000020E61000000100000005000000F7915B936ED74E409F20B1DD3DEC4B40F7915B936ED74E406EC2BD326FED4B4001FC53AA44D94E406EC2BD326FED4B4001FC53AA44D94E409F20B1DD3DEC4B40F7915B936ED74E409F20B1DD3DEC4B40
43976	21101	61.643706000000002	61.662787000000002	55.912495999999997	55.901176999999997	Дальняя	0103000020E61000000100000005000000971E4DF564D24E40257497C459F34B40971E4DF564D24E408BDD3EABCCF44B40639B5434D6D44E408BDD3EABCCF44B40639B5434D6D44E40257497C459F34B40971E4DF564D24E40257497C459F34B40
42985	19221	61.511662999999999	61.580689999999997	55.715327000000002	55.681285000000003	Пионерская	0103000020E6100000010000000500000060C9552C7EC14E40B020CD5834D74B4060C9552C7EC14E401079CBD58FDB4B409F8EC70C54CA4E401079CBD58FDB4B409F8EC70C54CA4E40B020CD5834D74B4060C9552C7EC14E40B020CD5834D74B40
42756	19221	61.511662999999999	61.580689999999997	55.715327000000002	55.681285000000003	Ленина	0103000020E6100000010000000500000060C9552C7EC14E40B020CD5834D74B4060C9552C7EC14E401079CBD58FDB4B409F8EC70C54CA4E401079CBD58FDB4B409F8EC70C54CA4E40B020CD5834D74B4060C9552C7EC14E40B020CD5834D74B40
43975	21181	61.530006999999998	61.545079999999999	55.961545999999998	55.955131000000002	Школьная	0103000020E6100000010000000500000056D3F544D7C34E40A9328CBB41FA4B4056D3F544D7C34E40C0CC77F013FB4B4012DA722EC5C54E40C0CC77F013FB4B4012DA722EC5C54E40A9328CBB41FA4B4056D3F544D7C34E40A9328CBB41FA4B40
44285	20799	62.041677999999997	62.057676999999998	56.022277000000003	56.015192999999996	Центральная	0103000020E61000000100000005000000397B67B455054F4066101FD8F1014C40397B67B455054F40FC3905F9D9024C409E5DBEF561074F40FC3905F9D9024C409E5DBEF561074F4066101FD8F1014C40397B67B455054F4066101FD8F1014C40
44279	21336	61.871600000000001	61.886718999999999	55.836114999999999	55.830047999999998	Галлямова	0103000020E61000000100000005000000C898BB9690EF4E401B0E4B033FEA4B40C898BB9690EF4E40F758FAD005EB4B40F4DE180280F14E40F758FAD005EB4B40F4DE180280F14E401B0E4B033FEA4B40C898BB9690EF4E401B0E4B033FEA4B40
43824	48033	61.228288999999997	61.248735000000003	55.785674999999998	55.762144999999997	Молодежная	0103000020E61000000100000005000000AD84EE92389D4E40ABE7A4F78DE14B40AD84EE92389D4E40742497FF90E44B406F2F698CD69F4E40742497FF90E44B406F2F698CD69F4E40ABE7A4F78DE14B40AD84EE92389D4E40ABE7A4F78DE14B40
44203	20032	61.300936	61.322693000000001	55.734324000000001	55.723633	Школьная	0103000020E610000001000000050000003318231285A64E4037A79201A0DC4B403318231285A64E407E552E54FEDD4B40F6D214014EA94E407E552E54FEDD4B40F6D214014EA94E4037A79201A0DC4B403318231285A64E4037A79201A0DC4B40
43971	20924	62.023721000000002	62.041840000000001	56.074247999999997	56.064957	Центральная	0103000020E610000001000000050000003D9D2B4A09034F40B952CF8250084C403D9D2B4A09034F408EE55DF580094C4013D55B035B054F408EE55DF580094C4013D55B035B054F40B952CF8250084C403D9D2B4A09034F40B952CF8250084C40
44205	20246	61.172279000000003	61.191324000000002	55.748331	55.741455000000002	Школьная	0103000020E61000000100000005000000D064FF3C0D964E40543A58FFE7DE4B40D064FF3C0D964E409FCA694FC9DF4B404F78094E7D984E409FCA694FC9DF4B404F78094E7D984E40543A58FFE7DE4B40D064FF3C0D964E40543A58FFE7DE4B40
43988	20125	61.158607000000003	61.173617999999998	55.838009999999997	55.828116000000001	Береговая	0103000020E6100000010000000500000056F5F23B4D944E40ADA580B4FFE94B4056F5F23B4D944E4048DC63E943EB4B409BFF571D39964E4048DC63E943EB4B409BFF571D39964E40ADA580B4FFE94B4056F5F23B4D944E40ADA580B4FFE94B40
43796	48360	61.826225999999998	61.845359999999999	55.937421999999998	55.927720000000001	Школьная	0103000020E610000001000000050000006D8D08C6C1E94E402DEC6987BFF64B406D8D08C6C1E94E408446B071FDF74B405CACA8C134EC4E408446B071FDF74B405CACA8C134EC4E402DEC6987BFF64B406D8D08C6C1E94E402DEC6987BFF64B40
43518	20080	61.087496000000002	61.120474000000002	55.851807999999998	55.818477999999999	Ленина	0103000020E61000000100000005000000F243A511338B4E406C3F19E3C3E84B40F243A511338B4E404F3C670B08ED4B40580229B16B8F4E404F3C670B08ED4B40580229B16B8F4E406C3F19E3C3E84B40F243A511338B4E406C3F19E3C3E84B40
43542	20465	61.519739000000001	61.5336	55.877651999999998	55.863337999999999	Центральная	0103000020E6100000010000000500000056BABBCE86C24E4070B20DDC81EE4B4056BABBCE86C24E406EA296E656F04B40A3923A014DC44E406EA296E656F04B40A3923A014DC44E4070B20DDC81EE4B4056BABBCE86C24E4070B20DDC81EE4B40
43972	21153	61.578884000000002	61.586635999999999	55.925203000000003	55.914988000000001	Зеленая	0103000020E61000000100000005000000BE16F4DE18CA4E40C11DA8531EF54B40BE16F4DE18CA4E409F94490D6DF64B40005471E316CB4E409F94490D6DF64B40005471E316CB4E40C11DA8531EF54B40BE16F4DE18CA4E40C11DA8531EF54B40
43791	21271	61.921483000000002	61.938524000000001	55.910876000000002	55.894041000000001	Межозерная	0103000020E61000000100000005000000F568AA27F3F54E403E247CEF6FF24B40F568AA27F3F54E400C5BB39597F44B406C41EF8D21F84E400C5BB39597F44B406C41EF8D21F84E403E247CEF6FF24B40F568AA27F3F54E403E247CEF6FF24B40
43794	21364	61.807091999999997	61.820971	55.759673999999997	55.751061999999997	Молодежная	0103000020E610000001000000050000007E6E68CA4EE74E4059A2B3CC22E04B407E6E68CA4EE74E408DCF64FF3CE14B4072FBE59315E94E408DCF64FF3CE14B4072FBE59315E94E4059A2B3CC22E04B407E6E68CA4EE74E4059A2B3CC22E04B40
43567	19951	61.389024999999997	61.406343999999997	55.713354000000002	55.696494000000001	Школьная	0103000020E61000000100000005000000C7293A92CBB14E401CEE23B726D94B40C7293A92CBB14E40433C122F4FDB4B408176871403B44E40433C122F4FDB4B408176871403B44E401CEE23B726D94B40C7293A92CBB14E401CEE23B726D94B40
44096	19199	62.140762000000002	62.168089000000002	55.352182999999997	55.343916	Центральная	0103000020E6100000010000000500000081423D7D04124F401B49827005AC4B4081423D7D04124F40849A215514AD4B409FE8BAF083154F40849A215514AD4B409FE8BAF083154F401B49827005AC4B4081423D7D04124F401B49827005AC4B40
44276	18730	62.355953999999997	62.397590000000001	55.766846000000001	55.752459999999999	Комсомольская	0103000020E61000000100000005000000B07092E68F2D4F402AC6F99B50E04B40B07092E68F2D4F40C2887D0228E24B40BB9BA73AE4324F40C2887D0228E24B40BB9BA73AE4324F402AC6F99B50E04B40B07092E68F2D4F402AC6F99B50E04B40
43563	18963	61.878687999999997	61.912948999999998	55.387197999999998	55.373623000000002	Советская	0103000020E610000001000000050000009EB12FD978F04E404704E3E0D2AF4B409EB12FD978F04E40CE893DB48FB14B403CF54883DBF44E40CE893DB48FB14B403CF54883DBF44E404704E3E0D2AF4B409EB12FD978F04E404704E3E0D2AF4B40
43823	16733	61.695197999999998	61.711852999999998	55.300069999999998	55.287747000000003	Мира	0103000020E610000001000000050000004F1F813FFCD84E40D542C9E4D4A44B404F1F813FFCD84E405F419AB168A64B409D47C5FF1DDB4E405F419AB168A64B409D47C5FF1DDB4E40D542C9E4D4A44B404F1F813FFCD84E40D542C9E4D4A44B40
43786	17832	61.695773000000003	61.724842000000002	55.284097000000003	55.271245999999998	Набережная	0103000020E610000001000000050000004C38F4160FD94E40DD955D30B8A24B404C38F4160FD94E4024F25D4A5DA44B403562669FC7DC4E4024F25D4A5DA44B403562669FC7DC4E40DD955D30B8A24B404C38F4160FD94E40DD955D30B8A24B40
44274	18305	61.741343999999998	61.757531999999998	55.354537999999998	55.345329	Молодежная	0103000020E61000000100000005000000FC8A355CE4DE4E4021AE9CBD33AC4B40FC8A355CE4DE4E4039984D8061AD4B4034D6FECEF6E04E4039984D8061AD4B4034D6FECEF6E04E4021AE9CBD33AC4B40FC8A355CE4DE4E4021AE9CBD33AC4B40
44273	16624	61.931669999999997	61.942881	55.081431000000002	55.067556000000003	Учительская	0103000020E6100000010000000500000008556AF640F74E400553CDACA5884B4008556AF640F74E40B7F0BC546C8A4B4088821953B0F84E40B7F0BC546C8A4B4088821953B0F84E400553CDACA5884B4008556AF640F74E400553CDACA5884B40
43900	16705	61.864575000000002	61.879002	55.116562000000002	55.103161999999998	Школьная	0103000020E6100000010000000500000038F8C264AAEE4E4050189469348D4B4038F8C264AAEE4E406AFAEC80EB8E4B402E8F352383F04E406AFAEC80EB8E4B402E8F352383F04E4050189469348D4B4038F8C264AAEE4E4050189469348D4B40
44268	16466	62.5105	62.522033999999998	55.533999999999999	55.522621999999998	Солнечная	0103000020E61000000100000005000000D34D621058414F40C6151747E5C24B40D34D621058414F403108AC1C5AC44B4035B39602D2424F403108AC1C5AC44B4035B39602D2424F40C6151747E5C24B40D34D621058414F40C6151747E5C24B40
44158	19062	62.023918000000002	62.038803000000001	55.350397000000001	55.344244000000003	Солнечная	0103000020E6100000010000000500000093E4B9BE0F034F4010ECF82F10AC4B4093E4B9BE0F034F40EACE13CFD9AC4B404CFE277FF7044F40EACE13CFD9AC4B404CFE277FF7044F4010ECF82F10AC4B4093E4B9BE0F034F4010ECF82F10AC4B40
44277	19062	62.023918000000002	62.038803000000001	55.350397000000001	55.344244000000003	Зеленая	0103000020E6100000010000000500000093E4B9BE0F034F4010ECF82F10AC4B4093E4B9BE0F034F40EACE13CFD9AC4B404CFE277FF7044F40EACE13CFD9AC4B404CFE277FF7044F4010ECF82F10AC4B4093E4B9BE0F034F4010ECF82F10AC4B40
44278	18849	62.027206	62.041606000000002	55.629958000000002	55.622582999999999	Школьная	0103000020E61000000100000005000000A320787C7B034F40D505BCCCB0CF4B40A320787C7B034F4042EDB776A2D04B40A0A86C5853054F4042EDB776A2D04B40A0A86C5853054F40D505BCCCB0CF4B40A320787C7B034F40D505BCCCB0CF4B40
44270	17126	62.200949000000001	62.222473000000001	55.606659999999998	55.595928000000001	Центральная	0103000020E61000000100000005000000FB9463B2B8194F40A662635E47CC4B40FB9463B2B8194F404BE5ED08A7CD4B401B9FC9FE791C4F404BE5ED08A7CD4B401B9FC9FE791C4F40A662635E47CC4B40FB9463B2B8194F40A662635E47CC4B40
43596	18938	62.294795999999998	62.323875000000001	55.640833000000001	55.620403000000003	Мира	0103000020E61000000100000005000000ED7E15E0BB254F408FAB915D69CF4B40ED7E15E0BB254F404A99D4D006D24B40FA7E6ABC74294F404A99D4D006D24B40FA7E6ABC74294F408FAB915D69CF4B40ED7E15E0BB254F408FAB915D69CF4B40
43965	17638	62.144875999999996	62.164045999999999	55.157854999999998	55.146903000000002	Салавата Юлаева	0103000020E61000000100000005000000D6FCF84B8B124F409757AEB7CD924B40D6FCF84B8B124F404A41B79734944B4012859675FF144F404A41B79734944B4012859675FF144F409757AEB7CD924B40D6FCF84B8B124F409757AEB7CD924B40
43768	17086	62.116436	62.138606000000003	55.468953999999997	55.456735000000002	Школьная	0103000020E61000000100000005000000DD09F65FE70E4F4023F8DF4A76BA4B40DD09F65FE70E4F4008AA46AF06BC4B40C38366D7BD114F4008AA46AF06BC4B40C38366D7BD114F4023F8DF4A76BA4B40DD09F65FE70E4F4023F8DF4A76BA4B40
43784	18509	61.623790999999997	61.641209000000003	55.309247999999997	55.298025000000003	Мира	0103000020E6100000010000000500000002452C62D8CF4E40F931E6AE25A64B4002452C62D8CF4E403C2D3F7095A74B405073F22213D24E403C2D3F7095A74B405073F22213D24E40F931E6AE25A64B4002452C62D8CF4E40F931E6AE25A64B40
43684	18741	62.044677999999998	62.073433000000001	55.752434999999998	55.727221999999998	Казанцева	0103000020E61000000100000005000000E36C3A02B8054F404277499C15DD4B40E36C3A02B8054F40D1AE42CA4FE04B403DB9A64066094F40D1AE42CA4FE04B403DB9A64066094F404277499C15DD4B40E36C3A02B8054F404277499C15DD4B40
43962	17928	61.684911999999997	61.706012999999999	55.386445999999999	55.375014999999998	Ленина	0103000020E61000000100000005000000A8514832ABD74E403541D47D00B04B40A8514832ABD74E40C3D5011077B14B4082C64CA25EDA4E40C3D5011077B14B4082C64CA25EDA4E403541D47D00B04B40A8514832ABD74E403541D47D00B04B40
44049	19051	61.980988000000004	61.997399999999999	55.351308000000003	55.344050000000003	40 лет Победы	0103000020E610000001000000050000005DE2C80391FD4E402B1895D409AC4B405DE2C80391FD4E405E6919A9F7AC4B40E4839ECDAAFF4E405E6919A9F7AC4B40E4839ECDAAFF4E402B1895D409AC4B405DE2C80391FD4E402B1895D409AC4B40
43682	18535	62.182623999999997	62.205261	55.771554999999999	55.753189999999996	Советская	0103000020E610000001000000050000007BBB253960174F404DD6A88768E04B407BBB253960174F405B087250C2E24B40771211FE451A4F405B087250C2E24B40771211FE451A4F404DD6A88768E04B407BBB253960174F404DD6A88768E04B40
44089	16811	61.939584000000004	61.957138	55.155802999999999	55.147540999999997	Школьная	0103000020E6100000010000000500000025ECDB4944F84E40D9E89C9FE2924B4025ECDB4944F84E4031CF4A5AF1934B4022E17B7F83FA4E4031CF4A5AF1934B4022E17B7F83FA4E40D9E89C9FE2924B4025ECDB4944F84E40D9E89C9FE2924B40
43785	19151	62.094031999999999	62.108989000000001	55.335473999999998	55.331612999999997	Лесная	0103000020E610000001000000050000008463963D090C4F40D7F6764B72AA4B408463963D090C4F404354E1CFF0AA4B40D74FFF59F30D4F404354E1CFF0AA4B40D74FFF59F30D4F40D7F6764B72AA4B408463963D090C4F40D7F6764B72AA4B40
44087	17186	61.887903999999999	61.921177999999998	55.488458000000001	55.479244999999999	Центральная	0103000020E6100000010000000500000069FE98D6A6F14E40C1E270E657BD4B4069FE98D6A6F14E401BBCAFCA85BE4B40B8E52329E9F54E401BBCAFCA85BE4B40B8E52329E9F54E40C1E270E657BD4B4069FE98D6A6F14E40C1E270E657BD4B40
43969	18105	61.890689000000002	61.914270000000002	55.022623000000003	55.011149000000003	Школьная	0103000020E6100000010000000500000017F4DE1802F24E400A3197546D814B4017F4DE1802F24E4097917A4FE5824B4062DBA2CC06F54E4097917A4FE5824B4062DBA2CC06F54E400A3197546D814B4017F4DE1802F24E400A3197546D814B40
44332	18397	61.590283999999997	61.642637000000001	55.233783000000003	55.217469999999999	Чкалова	0103000020E6100000010000000500000010AD156D8ECB4E4039EE940ED69B4B4010AD156D8ECB4E402EAEF199EC9D4B408B19E1ED41D24E402EAEF199EC9D4B408B19E1ED41D24E4039EE940ED69B4B4010AD156D8ECB4E4039EE940ED69B4B40
42984	18397	61.590283999999997	61.642637000000001	55.233783000000003	55.217469999999999	Ленина	0103000020E6100000010000000500000010AD156D8ECB4E4039EE940ED69B4B4010AD156D8ECB4E402EAEF199EC9D4B408B19E1ED41D24E402EAEF199EC9D4B408B19E1ED41D24E4039EE940ED69B4B4010AD156D8ECB4E4039EE940ED69B4B40
44295	55219	62.040877999999999	62.057794000000001	55.123682000000002	55.112586999999998	Ленина	0103000020E610000001000000050000001D90847D3B054F40357A3540698E4B401D90847D3B054F404C8DD0CFD48F4B40D8F335CB65074F404C8DD0CFD48F4B40D8F335CB65074F40357A3540698E4B401D90847D3B054F40357A3540698E4B40
44093	17509	62.040877999999999	62.057794000000001	55.123682000000002	55.112586999999998	Лесная	0103000020E610000001000000050000001D90847D3B054F40357A3540698E4B401D90847D3B054F404C8DD0CFD48F4B40D8F335CB65074F404C8DD0CFD48F4B40D8F335CB65074F40357A3540698E4B401D90847D3B054F40357A3540698E4B40
42898	16533	61.802286000000002	61.830061999999998	55.084977000000002	55.075262000000002	Школьная	0103000020E61000000100000005000000F304C24EB1E64E40D7506A2FA2894B40F304C24EB1E64E40C3F4BD86E08A4B4080D3BB783FEA4E40C3F4BD86E08A4B4080D3BB783FEA4E40D7506A2FA2894B40F304C24EB1E64E40D7506A2FA2894B40
43963	18430	61.683214	61.700372000000002	55.218193999999997	55.204478999999999	Центральная	0103000020E61000000100000005000000AD156D8E73D74E4001DC2C5E2C9A4B40AD156D8E73D74E407A17EFC7ED9B4B405E8429CAA5D94E407A17EFC7ED9B4B405E8429CAA5D94E4001DC2C5E2C9A4B40AD156D8E73D74E4001DC2C5E2C9A4B40
44092	18619	62.227530000000002	62.264100999999997	55.832135999999998	55.816409	Труда	0103000020E61000000100000005000000F06DFAB31F1D4F407D94111780E84B40F06DFAB31F1D4F4081E9B46E83EA4B40A2EBC20FCE214F4081E9B46E83EA4B40A2EBC20FCE214F407D94111780E84B40F06DFAB31F1D4F407D94111780E84B40
42981	37842	61.546024000000003	62.522033999999998	55.832135999999998	55.005181	Пионерская	0103000020E61000000100000005000000626A4B1DE4C54E40C1C760C5A9804B40626A4B1DE4C54E4081E9B46E83EA4B4035B39602D2424F4081E9B46E83EA4B4035B39602D2424F40C1C760C5A9804B40626A4B1DE4C54E40C1C760C5A9804B40
42982	18134	61.869560999999997	61.914296999999998	55.300069999999998	55.267687000000002	Школьная	0103000020E6100000010000000500000043705CC64DEF4E403D484F9143A24B4043705CC64DEF4E405F419AB168A64B405BEA20AF07F54E405F419AB168A64B405BEA20AF07F54E403D484F9143A24B4043705CC64DEF4E403D484F9143A24B40
43230	18134	61.869560999999997	61.914296999999998	55.300069999999998	55.267687000000002	Советская	0103000020E6100000010000000500000043705CC64DEF4E403D484F9143A24B4043705CC64DEF4E405F419AB168A64B405BEA20AF07F54E405F419AB168A64B405BEA20AF07F54E403D484F9143A24B4043705CC64DEF4E403D484F9143A24B40
42596	18134	61.869560999999997	61.914296999999998	55.300069999999998	55.267687000000002	Пионера	0103000020E6100000010000000500000043705CC64DEF4E403D484F9143A24B4043705CC64DEF4E405F419AB168A64B405BEA20AF07F54E405F419AB168A64B405BEA20AF07F54E403D484F9143A24B4043705CC64DEF4E403D484F9143A24B40
43643	18030	61.715850000000003	61.734796000000003	55.029415	55.019810999999997	Советская	0103000020E61000000100000005000000BA6B09F9A0DB4E40EF8CB62A89824B40BA6B09F9A0DB4E408481E7DEC3834B40A69D9ACB0DDE4E408481E7DEC3834B40A69D9ACB0DDE4E40EF8CB62A89824B40BA6B09F9A0DB4E40EF8CB62A89824B40
43754	17727	61.918653999999997	61.939431999999996	55.249977000000001	55.238202999999999	Северная	0103000020E61000000100000005000000772B4B7496F54E409067976F7D9E4B40772B4B7496F54E4048E00F3FFF9F4B406E68CA4E3FF84E4048E00F3FFF9F4B406E68CA4E3FF84E409067976F7D9E4B40772B4B7496F54E409067976F7D9E4B40
42647	17912	61.669775000000001	61.700524999999999	55.365079999999999	55.347043999999997	Космонавтов	0103000020E61000000100000005000000D656EC2FBBD54E40F22213F06BAC4B40D656EC2FBBD54E403B3602F1BAAE4B40E4839ECDAAD94E403B3602F1BAAE4B40E4839ECDAAD94E40F22213F06BAC4B40D656EC2FBBD54E40F22213F06BAC4B40
44214	17811	62.014333000000001	62.027296	55.275112999999997	55.268163999999999	Трактовая	0103000020E610000001000000050000007520EBA9D5014F4076FBAC3253A24B407520EBA9D5014F402BDA1CE736A34B40E3A7716F7E034F402BDA1CE736A34B40E3A7716F7E034F4076FBAC3253A24B407520EBA9D5014F4076FBAC3253A24B40
43893	18839	62.049501999999997	62.061926	55.830038000000002	55.813349000000002	Юбилейная	0103000020E61000000100000005000000158BDF1456064F40FE9DEDD11BE84B40158BDF1456064F40F83768AF3EEA4B40D462F030ED074F40F83768AF3EEA4B40D462F030ED074F40FE9DEDD11BE84B40158BDF1456064F40FE9DEDD11BE84B40
42900	17409	62.046188000000001	62.092379000000001	55.221322000000001	55.200024999999997	Солнечная	0103000020E61000000100000005000000DCBB067DE9054F40F2B0506B9A994B40DCBB067DE9054F4052F17F47549C4B4029EB3713D30B4F4052F17F47549C4B4029EB3713D30B4F40F2B0506B9A994B40DCBB067DE9054F40F2B0506B9A994B40
42807	17409	62.046188000000001	62.092379000000001	55.221322000000001	55.200024999999997	Механизаоров	0103000020E61000000100000005000000DCBB067DE9054F40F2B0506B9A994B40DCBB067DE9054F4052F17F47549C4B4029EB3713D30B4F4052F17F47549C4B4029EB3713D30B4F40F2B0506B9A994B40DCBB067DE9054F40F2B0506B9A994B40
43751	17540	62.217793	62.236756	55.085379000000003	55.076127999999997	Центральная	0103000020E610000001000000050000001C261AA4E01B4F40AA27F38FBE894B401C261AA4E01B4F40F261F6B2ED8A4B40DE9046054E1E4F40F261F6B2ED8A4B40DE9046054E1E4F40AA27F38FBE894B401C261AA4E01B4F40AA27F38FBE894B40
42803	17335	61.636690000000002	61.663145999999998	55.446427	55.425946000000003	Ленина	0103000020E610000001000000050000005AD8D30E7FD14E4057EE056685B64B405AD8D30E7FD14E4094861A8524B94B40923CD7F7E1D44E4094861A8524B94B40923CD7F7E1D44E4057EE056685B64B405AD8D30E7FD14E4057EE056685B64B40
42980	17010	62.032344000000002	62.114818999999997	55.584828000000002	55.562139000000002	Первая Краснознаменная	0103000020E61000000100000005000000651C23D923044F403067B62BF4C74B40651C23D923044F407EE4D6A4DBCA4B40CEFA9463B20E4F407EE4D6A4DBCA4B40CEFA9463B20E4F403067B62BF4C74B40651C23D923044F403067B62BF4C74B40
43678	17010	62.032344000000002	62.114818999999997	55.584828000000002	55.562139000000002	Могильникова	0103000020E61000000100000005000000651C23D923044F403067B62BF4C74B40651C23D923044F407EE4D6A4DBCA4B40CEFA9463B20E4F407EE4D6A4DBCA4B40CEFA9463B20E4F403067B62BF4C74B40651C23D923044F403067B62BF4C74B40
44088	17227	61.982120000000002	62.000311000000004	55.445706999999999	55.436177999999998	Центральная	0103000020E61000000100000005000000AF5FB01BB6FD4E400A9E42AED4B74B40AF5FB01BB6FD4E40944C4EED0CB94B401F6ADB300A004F40944C4EED0CB94B401F6ADB300A004F400A9E42AED4B74B40AF5FB01BB6FD4E400A9E42AED4B74B40
43959	17623	62.153590000000001	62.170011000000002	55.091670000000001	55.087119999999999	Школьная	0103000020E610000001000000050000000F7F4DD6A8134F40EC6987BF268B4B400F7F4DD6A8134F401D03B2D7BB8B4B40EA7AA2EBC2154F401D03B2D7BB8B4B40EA7AA2EBC2154F40EC6987BF268B4B400F7F4DD6A8134F40EC6987BF268B4B40
43956	16601	61.783583	61.801414999999999	55.135669999999998	55.124825000000001	Школьная	0103000020E61000000100000005000000CD599F724CE44E40925CFE43FA8F4B40CD599F724CE44E402F8672A25D914B400DC347C494E64E402F8672A25D914B400DC347C494E64E40925CFE43FA8F4B40CD599F724CE44E40925CFE43FA8F4B40
43750	16879	61.559398999999999	61.571769000000003	55.313675000000003	55.308331000000003	Образцовая	0103000020E610000001000000050000002235ED629AC74E40E7ABE46377A74B402235ED629AC74E4052499D8026A84B40EEEE01BA2FC94E4052499D8026A84B40EEEE01BA2FC94E40E7ABE46377A74B402235ED629AC74E40E7ABE46377A74B40
43961	18652	62.416418999999998	62.449306999999997	55.708373999999999	55.694159999999997	Центральная	0103000020E610000001000000050000006D37C1374D354F407E18213CDAD84B406D37C1374D354F4019ABCDFFABDA4B40936E4BE482394F4019ABCDFFABDA4B40936E4BE482394F407E18213CDAD84B406D37C1374D354F407E18213CDAD84B40
43792	16451	62.416024	62.439478999999999	55.538096000000003	55.519534	Школьная	0103000020E61000000100000005000000F12C414640354F407D94111780C24B40F12C414640354F40E10D6954E0C44B40AF230ED940384F40E10D6954E0C44B40AF230ED940384F407D94111780C24B40F12C414640354F407D94111780C24B40
43668	16387	62.328536999999997	62.373192000000003	55.541086999999997	55.530408999999999	Комсомольская	0103000020E6100000010000000500000052431B800D2A4F4085402E71E4C34B4052431B800D2A4F4037A5BC5642C54B407E9065C1C42F4F4037A5BC5642C54B407E9065C1C42F4F4085402E71E4C34B4052431B800D2A4F4085402E71E4C34B40
42936	25974	61.52017	61.558214	54.947929999999999	54.928251000000003	Зеленая	0103000020E610000001000000050000001F2E39EE94C24E405ABDC3EDD0764B401F2E39EE94C24E40DA722EC555794B40AD156D8E73C74E40DA722EC555794B40AD156D8E73C74E405ABDC3EDD0764B401F2E39EE94C24E405ABDC3EDD0764B40
43911	25820	61.539231999999998	61.562821999999997	55.013734999999997	55.007086000000001	Проектная	0103000020E61000000100000005000000747ADE8D05C54E403621AD31E8804B40747ADE8D05C54E40C0E78711C2814B4012BC218D0AC84E40C0E78711C2814B4012BC218D0AC84E403621AD31E8804B40747ADE8D05C54E403621AD31E8804B40
44047	6102	58.820777999999997	58.832698000000001	52.644416999999997	52.634548000000002	Российская	0103000020E610000001000000050000005DA3E5400F694D4001DF6DDE38514A405DA3E5400F694D4043FE99417C524A40E9B81AD9956A4D4043FE99417C524A40E9B81AD9956A4D4001DF6DDE38514A405DA3E5400F694D4001DF6DDE38514A40
44219	16377	59.649267000000002	59.673215999999996	52.693840000000002	52.683517999999999	Береговая	0103000020E610000001000000050000009FAF592E1BD34D40191D90847D574A409FAF592E1BD34D400D54C6BFCF584A406C921FF12BD64D400D54C6BFCF584A406C921FF12BD64D40191D90847D574A409FAF592E1BD34D40191D90847D574A40
44048	6249	59.689915999999997	59.701467999999998	52.832321	52.825747999999997	Центральная	0103000020E610000001000000050000005A7EE02A4FD84D40635E471CB2694A405A7EE02A4FD84D401363997E896A4A40639813B4C9D94D401363997E896A4A40639813B4C9D94D40635E471CB2694A405A7EE02A4FD84D40635E471CB2694A40
43882	16600	59.395716999999998	59.404763000000003	52.734188000000003	52.728538	Дружбы	0103000020E6100000010000000500000051BCCADAA6B24D4056F2B1BB405D4A4051BCCADAA6B24D40CE8E54DFF95D4A40C0D02346CFB34D40CE8E54DFF95D4A40C0D02346CFB34D4056F2B1BB405D4A4051BCCADAA6B24D4056F2B1BB405D4A40
44256	16054	58.983696000000002	59.004635999999998	52.625633000000001	52.611789999999999	Центральная	0103000020E610000001000000050000005F9A22C0E97D4D408A027D224F4E4A405F9A22C0E97D4D403126FDBD14504A402F3196E997804D403126FDBD14504A402F3196E997804D408A027D224F4E4A405F9A22C0E97D4D408A027D224F4E4A40
44262	16744	58.884341999999997	58.896675999999999	52.821781000000001	52.801124999999999	Молодежная	0103000020E61000000100000005000000573D601E32714D40068195438B664A40573D601E32714D40B2BCAB1E30694A40D68D7747C6724D40B2BCAB1E30694A40D68D7747C6724D40068195438B664A40573D601E32714D40068195438B664A40
42802	16707	58.879285000000003	58.897582999999997	52.918978000000003	52.898308	60 лет Октября	0103000020E61000000100000005000000836E2F698C704D401ADEACC1FB724A40836E2F698C704D402BDF3312A1754A400839EFFFE3724D402BDF3312A1754A400839EFFFE3724D401ADEACC1FB724A40836E2F698C704D401ADEACC1FB724A40
44130	16129	59.032322000000001	59.040523	52.680002000000002	52.674149	Центральная	0103000020E610000001000000050000007D78962023844D40C8D0B1834A564A407D78962023844D40789B374E0A574A402FDE8FDB2F854D40789B374E0A574A402FDE8FDB2F854D40C8D0B1834A564A407D78962023844D40C8D0B1834A564A40
44000	15898	59.192608	59.199759	52.708666999999998	52.697147000000001	Центральная	0103000020E6100000010000000500000057790261A7984D4094C0E61C3C594A4057790261A7984D409160AA99B55A4A40740AF2B391994D409160AA99B55A4A40740AF2B391994D4094C0E61C3C594A4057790261A7984D4094C0E61C3C594A40
43577	16186	59.460638000000003	59.486187000000001	52.892640999999998	52.879503	Октябрьская	0103000020E61000000100000005000000BEA59C2FF6BA4D40F0DDE68D93704A40BEA59C2FF6BA4D40CC086F0F42724A40C45E28603BBE4D40CC086F0F42724A40C45E28603BBE4D40F0DDE68D93704A40BEA59C2FF6BA4D40F0DDE68D93704A40
42820	16319	59.695701	59.718518000000003	52.776226000000001	52.761088999999998	Мира	0103000020E61000000100000005000000B265F9BA0CD94D40342C465D6B614A40B265F9BA0CD94D400727A25F5B634A402ECBD765F8DB4D400727A25F5B634A402ECBD765F8DB4D40342C465D6B614A40B265F9BA0CD94D40342C465D6B614A40
44079	16999	59.143183000000001	59.150756000000001	52.970343999999997	52.962420000000002	Школьная	0103000020E61000000100000005000000ED2B0FD253924D4017821C94307B4A40ED2B0FD253924D4056EF703B347C4A4080D6FCF84B934D4056EF703B347C4A4080D6FCF84B934D4017821C94307B4A40ED2B0FD253924D4017821C94307B4A40
44005	16947	59.062019999999997	59.072971000000003	52.819958	52.815886999999996	Школьная	0103000020E6100000010000000500000055D97745F0874D40A31D37FC6E684A4055D97745F0874D40FA0B3D62F4684A4039471D1D57894D40FA0B3D62F4684A4039471D1D57894D40A31D37FC6E684A4055D97745F0874D40A31D37FC6E684A40
43657	15840	59.203091999999998	59.227957000000004	52.771399000000002	52.762517000000003	Школьная	0103000020E61000000100000005000000240A2DEBFE994D4070D234289A614A40240A2DEBFE994D406495D233BD624A4078F2E9B12D9D4D406495D233BD624A4078F2E9B12D9D4D4070D234289A614A40240A2DEBFE994D4070D234289A614A40
43867	16636	59.412497999999999	59.419271000000002	52.602471000000001	52.596640000000001	Школьная	0103000020E610000001000000050000002CD505BCCCB44D4023BE13B35E4C4A402CD505BCCCB44D40EBE40CC51D4D4A40A39410ACAAB54D40EBE40CC51D4D4A40A39410ACAAB54D4023BE13B35E4C4A402CD505BCCCB44D4023BE13B35E4C4A40
44327	55245	\N	\N	\N	\N	Пионерская	\N
44004	15639	58.781331999999999	58.814560999999998	52.666770999999997	52.652847999999999	Ленина	0103000020E61000000100000005000000BDA8DDAF02644D4027A1F48590534A40BDA8DDAF02644D40EA758BC058554A406CCCEB8843684D40EA758BC058554A406CCCEB8843684D4027A1F48590534A40BDA8DDAF02644D4027A1F48590534A40
43658	15776	59.11618	59.127479999999998	52.454633999999999	52.447493999999999	Центральная	0103000020E6100000010000000500000082397AFCDE8E4D40FF93BF7B47394A4082397AFCDE8E4D4028D36872313A4A407172BF4351904D4028D36872313A4A407172BF4351904D40FF93BF7B47394A4082397AFCDE8E4D40FF93BF7B47394A40
43879	16447	59.883457999999997	59.896869000000002	52.708252000000002	52.698723999999999	Центральная	0103000020E61000000100000005000000DDB1D82615F14D401477BCC96F594A40DDB1D82615F14D40CEA96400A85A4A40EBE5779ACCF24D40CEA96400A85A4A40EBE5779ACCF24D401477BCC96F594A40DDB1D82615F14D401477BCC96F594A40
43889	6163	59.071237000000004	59.080399999999997	52.890206999999997	52.884881999999998	Школьная	0103000020E61000000100000005000000F1A1444B1E894D40D76839D043714A40F1A1444B1E894D40CBD58F4DF2714A40984C158C4A8A4D40CBD58F4DF2714A40984C158C4A8A4D40D76839D043714A40F1A1444B1E894D40D76839D043714A40
43913	16212	59.512479999999996	59.528111000000003	52.904310000000002	52.895330999999999	Центральная	0103000020E6100000010000000500000052EDD3F198C14D40280CCA349A724A4052EDD3F198C14D400FB9196EC0734A4035D4282499C34D400FB9196EC0734A4035D4282499C34D40280CCA349A724A4052EDD3F198C14D40280CCA349A724A40
43151	6214	58.876859000000003	58.926509000000003	52.742105000000002	52.704929	Советская	0103000020E61000000100000005000000051A6CEA3C704D4041800C1D3B5A4A40051A6CEA3C704D405B99F04BFD5E4A408F39CFD897764D405B99F04BFD5E4A408F39CFD897764D4041800C1D3B5A4A40051A6CEA3C704D4041800C1D3B5A4A40
42966	6214	58.876859000000003	58.926509000000003	52.742105000000002	52.704929	Комсомольская	0103000020E61000000100000005000000051A6CEA3C704D4041800C1D3B5A4A40051A6CEA3C704D405B99F04BFD5E4A408F39CFD897764D405B99F04BFD5E4A408F39CFD897764D4041800C1D3B5A4A40051A6CEA3C704D4041800C1D3B5A4A40
43543	16476	59.632333000000003	59.658473999999998	52.966802000000001	52.952736999999999	Труда	0103000020E610000001000000050000003E97A949F0D04D4036583849F3794A403E97A949F0D04D408CDAFD2AC07B4A4016A243E048D44D408CDAFD2AC07B4A4016A243E048D44D4036583849F3794A403E97A949F0D04D4036583849F3794A40
44253	15929	59.146003999999998	59.165954999999997	52.899590000000003	52.887203	Центральная	0103000020E61000000100000005000000E78A5242B0924D40E0F42EDE8F714A40E78A5242B0924D4082E7DEC325734A40C8CD70033E954D4082E7DEC325734A40C8CD70033E954D40E0F42EDE8F714A40E78A5242B0924D40E0F42EDE8F714A40
44269	17037	58.890630999999999	58.902918999999997	52.854267999999998	52.834035	Набережная	0103000020E61000000100000005000000E2E6543200724D40145CACA8C16A4A40E2E6543200724D40790261A7586D4A40F0F78BD992734D40790261A7586D4A40F0F78BD992734D40145CACA8C16A4A40E2E6543200724D40145CACA8C16A4A40
42801	16536	59.289059999999999	59.316073000000003	52.666831000000002	52.655721	Школьная	0103000020E61000000100000005000000774A07EBFFA44D4074266DAAEE534A40774A07EBFFA44D40C07ADCB75A554A4006137F1475A84D40C07ADCB75A554A4006137F1475A84D4074266DAAEE534A40774A07EBFFA44D4074266DAAEE534A40
43194	16810	59.528021000000003	59.566011000000003	53.005634000000001	52.984088999999997	Парковая	0103000020E61000000100000005000000F54C2F3196C34D403AADDBA0F67D4A40F54C2F3196C34D4072DF6A9DB8804A409016670C73C84D4072DF6A9DB8804A409016670C73C84D403AADDBA0F67D4A40F54C2F3196C34D403AADDBA0F67D4A40
43864	16073	59.186985	59.208598000000002	52.612445999999998	52.599632	Центральная	0103000020E61000000100000005000000D9EBDD1FEF974D404AD1CABDC04C4A40D9EBDD1FEF974D4073486AA1644E4A406901DA56B39A4D4073486AA1644E4A406901DA56B39A4D404AD1CABDC04C4A40D9EBDD1FEF974D404AD1CABDC04C4A40
43865	15760	58.960546000000001	58.974370999999998	52.552036000000001	52.543723	Советская	0103000020E61000000100000005000000DD26DC2BF37A4D40A08A1BB798454A40DD26DC2BF37A4D407A1B9B1DA9464A40DD955D30B87C4D407A1B9B1DA9464A40DD955D30B87C4D40A08A1BB798454A40DD26DC2BF37A4D40A08A1BB798454A40
43532	16875	58.956693000000001	58.976222	52.980798	52.968390999999997	переулок Школьный	0103000020E61000000100000005000000F4A78DEA747A4D40D05E7D3CF47B4A40F4A78DEA747A4D40B9FDF2C98A7D4A405FD1ADD7F47C4D40B9FDF2C98A7D4A405FD1ADD7F47C4D40D05E7D3CF47B4A40F4A78DEA747A4D40D05E7D3CF47B4A40
44261	16863	59.379125000000002	59.392043000000001	53.027639000000001	53.016047	Центральная	0103000020E610000001000000050000004A0C022B87B04D407619FED30D824A404A0C022B87B04D400D8CBCAC89834A4018D00B772EB24D400D8CBCAC89834A4018D00B772EB24D407619FED30D824A404A0C022B87B04D407619FED30D824A40
43536	15685	59.045904	59.078369000000002	52.427734999999998	52.408171000000003	Мира	0103000020E61000000100000005000000B760A92EE0854D407B1684F23E344A40B760A92EE0854D40622D3E05C0364A409702D2FE078A4D40622D3E05C0364A409702D2FE078A4D407B1684F23E344A40B760A92EE0854D407B1684F23E344A40
43868	16276	59.497326000000001	59.508276000000002	52.801015999999997	52.790289000000001	Школьная	0103000020E61000000100000005000000AAB9DC60A8BF4D40BCB1A03028654A40AAB9DC60A8BF4D404FC939B187664A40BDAB1E300FC14D404FC939B187664A40BDAB1E300FC14D40BCB1A03028654A40AAB9DC60A8BF4D40BCB1A03028654A40
43702	55107	58.397984999999998	58.466211999999999	54.884369	54.833843000000002	переулок Мичурина	0103000020E6100000010000000500000037A6272CF1324D40D07F0F5EBB6A4B4037A6272CF1324D40514CDE0033714B405A80B6D5AC3B4D40514CDE0033714B405A80B6D5AC3B4D40D07F0F5EBB6A4B4037A6272CF1324D40D07F0F5EBB6A4B40
42769	55107	58.397984999999998	58.466211999999999	54.884369	54.833843000000002	Советская	0103000020E6100000010000000500000037A6272CF1324D40D07F0F5EBB6A4B4037A6272CF1324D40514CDE0033714B405A80B6D5AC3B4D40514CDE0033714B405A80B6D5AC3B4D40D07F0F5EBB6A4B4037A6272CF1324D40D07F0F5EBB6A4B40
43095	55107	58.397984999999998	58.466211999999999	54.884369	54.833843000000002	Сахарова	0103000020E6100000010000000500000037A6272CF1324D40D07F0F5EBB6A4B4037A6272CF1324D40514CDE0033714B405A80B6D5AC3B4D40514CDE0033714B405A80B6D5AC3B4D40D07F0F5EBB6A4B4037A6272CF1324D40D07F0F5EBB6A4B40
43285	55107	58.397984999999998	58.466211999999999	54.884369	54.833843000000002	3 Интернационала	0103000020E6100000010000000500000037A6272CF1324D40D07F0F5EBB6A4B4037A6272CF1324D40514CDE0033714B405A80B6D5AC3B4D40514CDE0033714B405A80B6D5AC3B4D40D07F0F5EBB6A4B4037A6272CF1324D40D07F0F5EBB6A4B40
43960	16275	57.931904000000003	57.940652999999998	54.969864000000001	54.960099999999997	Уральская	0103000020E610000001000000050000007C8159A148F74C40DE718A8EE47A4B407C8159A148F74C40ACC8E880247C4B4030F1475167F84C40ACC8E880247C4B4030F1475167F84C40DE718A8EE47A4B407C8159A148F74C40DE718A8EE47A4B40
43955	15977	58.760050999999997	58.782167999999999	54.61768	54.604348000000002	Ленина	0103000020E610000001000000050000006325E65949614D4096B377465B4D4B406325E65949614D4057B26323104F4B4026FDBD141E644D4057B26323104F4B4026FDBD141E644D4096B377465B4D4B406325E65949614D4096B377465B4D4B40
9574	40213	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Строителей	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
42745	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Островского	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
42888	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Мира	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
43088	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Ленина	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
43089	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Космонавтов	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
42748	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Карла Маркса	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
42876	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	Калинина	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
42746	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	К.Маркса	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
42751	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	60 лет Октября	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
43227	11614	58.425159000000001	58.467883	54.827117000000001	54.808960999999996	50 лет Победы	0103000020E61000000100000005000000CF4C309C6B364D40A65EB7088C674B40CF4C309C6B364D409A7B48F8DE694B405CAD1397E33B4D409A7B48F8DE694B405CAD1397E33B4D40A65EB7088C674B40CF4C309C6B364D40A65EB7088C674B40
43781	16183	57.852034000000003	57.870432000000001	54.864803000000002	54.852392000000002	Карла Маркса	0103000020E61000000100000005000000408A3A730FED4C409FAF592E1B6D4B40408A3A730FED4C40C93D5DDDB16E4B4029B2D6506AEF4C40C93D5DDDB16E4B4029B2D6506AEF4C409FAF592E1B6D4B40408A3A730FED4C409FAF592E1B6D4B40
44271	16137	58.075302000000001	58.101874000000002	54.878765000000001	54.865757000000002	1-й Советский переулок	0103000020E6100000010000000500000065A9F57EA3094D403CA41820D16E4B4065A9F57EA3094D404AEF1B5F7B704B4007280D350A0D4D404AEF1B5F7B704B4007280D350A0D4D403CA41820D16E4B4065A9F57EA3094D403CA41820D16E4B40
44091	7882	58.68683	58.708694999999999	54.777666000000004	54.764037999999999	Советская	0103000020E61000000100000005000000B2F4A10BEA574D405C7347FFCB614B40B2F4A10BEA574D40079B3A8F8A634B405BEB8B84B65A4D40079B3A8F8A634B405BEB8B84B65A4D405C7347FFCB614B40B2F4A10BEA574D405C7347FFCB614B40
43779	15781	57.847731000000003	57.867297000000001	54.628377	54.618848	Островная	0103000020E6100000010000000500000017670C7382EC4C40F6984869364F4B4017670C7382EC4C40804754A86E504B409F758D9603EF4C40804754A86E504B409F758D9603EF4C40F6984869364F4B4017670C7382EC4C40F6984869364F4B40
43782	16325	57.981696999999997	58.000264999999999	54.781793999999998	54.774394999999998	Ворошилова	0103000020E6100000010000000500000068CA4E3FA8FD4C40CC9717601F634B4068CA4E3FA8FD4C40C11A67D311644B40AE2AFBAE08004D40C11A67D311644B40AE2AFBAE08004D40CC9717601F634B4068CA4E3FA8FD4C40CC9717601F634B40
43540	14446	58.270190999999997	58.296664	54.622157999999999	54.613666000000002	УстьКатавская	0103000020E610000001000000050000003656629E95224D406555849B8C4E4B403656629E95224D40EE7893DFA24F4B4045F30016F9254D40EE7893DFA24F4B4045F30016F9254D406555849B8C4E4B403656629E95224D406555849B8C4E4B40
42750	14446	58.270190999999997	58.296664	54.622157999999999	54.613666000000002	Свердловская	0103000020E610000001000000050000003656629E95224D406555849B8C4E4B403656629E95224D40EE7893DFA24F4B4045F30016F9254D40EE7893DFA24F4B4045F30016F9254D406555849B8C4E4B403656629E95224D406555849B8C4E4B40
44272	14446	58.270190999999997	58.296664	54.622157999999999	54.613666000000002	Олега Кошевого	0103000020E610000001000000050000003656629E95224D406555849B8C4E4B403656629E95224D40EE7893DFA24F4B4045F30016F9254D40EE7893DFA24F4B4045F30016F9254D406555849B8C4E4B403656629E95224D406555849B8C4E4B40
44043	14446	58.270190999999997	58.296664	54.622157999999999	54.613666000000002	Нагорнова	0103000020E610000001000000050000003656629E95224D406555849B8C4E4B403656629E95224D40EE7893DFA24F4B4045F30016F9254D40EE7893DFA24F4B4045F30016F9254D406555849B8C4E4B403656629E95224D406555849B8C4E4B40
43229	14446	58.270190999999997	58.296664	54.622157999999999	54.613666000000002	Ленинградская	0103000020E610000001000000050000003656629E95224D406555849B8C4E4B403656629E95224D40EE7893DFA24F4B4045F30016F9254D40EE7893DFA24F4B4045F30016F9254D406555849B8C4E4B403656629E95224D406555849B8C4E4B40
42752	14446	58.270190999999997	58.296664	54.622157999999999	54.613666000000002	Восточная	0103000020E610000001000000050000003656629E95224D406555849B8C4E4B403656629E95224D40EE7893DFA24F4B4045F30016F9254D40EE7893DFA24F4B4045F30016F9254D406555849B8C4E4B403656629E95224D406555849B8C4E4B40
43968	15762	57.687390999999998	57.71311	54.656875999999997	54.647458	Центральная	0103000020E610000001000000050000004948A46DFCD74C404CC45BE7DF524B404948A46DFCD74C407EC3448314544B40AC39403047DB4C407EC3448314544B40AC39403047DB4C404CC45BE7DF524B404948A46DFCD74C404CC45BE7DF524B40
44275	16215	57.883862000000001	57.898513000000001	54.894150000000003	54.883710999999998	Пролетарская	0103000020E61000000100000005000000AD16D86322F14C40C70E2A711D714B40AD16D86322F14C40F5DBD78173724B40F303577902F34C40F5DBD78173724B40F303577902F34C40C70E2A711D714B40AD16D86322F14C40C70E2A711D714B40
44264	13877	61.346867000000003	61.379575000000003	56.072906000000003	56.05883	Ленина	0103000020E61000000100000005000000E4874A2366AC4E400803CFBD87074C40E4874A2366AC4E4052D7DAFB54094C408AB0E1E995B04E4052D7DAFB54094C408AB0E1E995B04E400803CFBD87074C40E4874A2366AC4E400803CFBD87074C40
43776	13722	60.902119999999996	60.922054000000003	56.195689999999999	56.180953000000002	Колхозная	0103000020E61000000100000005000000A4880CAB78734E407A8EC87729174C40A4880CAB78734E40BE13B35E0C194C40B0928FDD05764E40BE13B35E0C194C40B0928FDD05764E407A8EC87729174C40A4880CAB78734E407A8EC87729174C40
43690	14316	61.218533999999998	61.261617000000001	56.224801999999997	56.206792	Парковая	0103000020E6100000010000000500000033880FECF89B4E4087890629781A4C4033880FECF89B4E40A609DB4FC61C4C40F08975AA7CA14E40A609DB4FC61C4C40F08975AA7CA14E4087890629781A4C4033880FECF89B4E4087890629781A4C40
44082	13572	60.852730999999999	60.860869000000001	56.186875000000001	56.182049999999997	Ленина	0103000020E6100000010000000500000087A4164A266D4E404F1E166A4D174C4087A4164A266D4E4052B81E85EB174C40F39194F4306E4E4052B81E85EB174C40F39194F4306E4E404F1E166A4D174C4087A4164A266D4E404F1E166A4D174C40
44293	55218	61.66921	61.681876000000003	56.056930000000001	56.049787000000002	Ленина	0103000020E61000000100000005000000FD135CACA8D54E400B62A06B5F064C40FD135CACA8D54E40A514747B49074C40B2F677B647D74E40A514747B49074C40B2F677B647D74E400B62A06B5F064C40FD135CACA8D54E400B62A06B5F064C40
42749	14018	60.920554000000003	60.953360000000004	56.070765999999999	56.039062000000001	Ленина	0103000020E61000000100000005000000DB19A6B6D4754E401842CEFBFF044C40DB19A6B6D4754E4099D53BDC0E094C4044A852B3077A4E4099D53BDC0E094C4044A852B3077A4E401842CEFBFF044C40DB19A6B6D4754E401842CEFBFF044C40
42755	14018	60.920554000000003	60.953360000000004	56.070765999999999	56.039062000000001	Гагарина	0103000020E61000000100000005000000DB19A6B6D4754E401842CEFBFF044C40DB19A6B6D4754E4099D53BDC0E094C4044A852B3077A4E4099D53BDC0E094C4044A852B3077A4E401842CEFBFF044C40DB19A6B6D4754E401842CEFBFF044C40
44267	14424	61.196803000000003	61.242410999999997	56.313828000000001	56.301732999999999	Ленина	0103000020E610000001000000050000009A6038D730994E40DE8FDB2F9F264C409A6038D730994E40D84812842B284C406798DA52079F4E40D84812842B284C406798DA52079F4E40DE8FDB2F9F264C409A6038D730994E40DE8FDB2F9F264C40
43439	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	улица 40 Лет Октября	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
42778	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Строителей	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
42994	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Свердлова	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
42993	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Нечая	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43447	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Мира	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43434	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Ленина	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43274	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Комсомольская	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
44313	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Кирова	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43162	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Забабахина	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43435	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Дзержинского	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43001	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	Васильева	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
42906	28226	60.708838999999998	60.786982999999999	56.095855999999998	56.027186999999998	40 лет Октября	0103000020E610000001000000050000008E90813CBB5A4E402CF015DD7A034C408E90813CBB5A4E400C906802450C4C4005C1E3DBBB644E400C906802450C4C4005C1E3DBBB644E402CF015DD7A034C408E90813CBB5A4E402CF015DD7A034C40
43774	13315	61.630707999999998	61.648342	56.186750000000004	56.172499999999999	Центральная	0103000020E61000000100000005000000ACA92C0ABBD04E40AE47E17A14164C40ACA92C0ABBD04E4096438B6CE7174C40C64FE3DEFCD24E4096438B6CE7174C40C64FE3DEFCD24E40AE47E17A14164C40ACA92C0ABBD04E40AE47E17A14164C40
43641	13852	61.508814999999998	61.529845000000002	56.132308000000002	56.092345000000002	Школьная	0103000020E610000001000000050000006C5B94D920C14E407D7901F6D10B4C406C5B94D920C14E40E57FF277EF104C407D7901F6D1C34E40E57FF277EF104C407D7901F6D1C34E407D7901F6D10B4C406C5B94D920C14E407D7901F6D10B4C40
43500	13782	60.451039999999999	60.476435000000002	55.914538999999998	55.899835000000003	Школьная	0103000020E610000001000000050000000B98C0ADBB394E40E96514CB2DF34B400B98C0ADBB394E4051F52B9D0FF54B40BBD573D2FB3C4E4051F52B9D0FF54B40BBD573D2FB3C4E40E96514CB2DF34B400B98C0ADBB394E40E96514CB2DF34B40
44086	14354	61.270913999999998	61.318750000000001	56.301108999999997	56.282026000000002	Ленина	0103000020E61000000100000005000000A703594FADA24E40944F8F6D19244C40A703594FADA24E4000C45DBD8A264C40CDCCCCCCCCA84E4000C45DBD8A264C40CDCCCCCCCCA84E40944F8F6D19244C40A703594FADA24E40944F8F6D19244C40
43954	13942	61.648170999999998	61.655501000000001	56.011394000000003	56.001826000000001	Береговая	0103000020E61000000100000005000000999B6F44F7D24E40292499D53B004C40999B6F44F7D24E4071AFCC5B75014C4066BFEE74E7D34E4071AFCC5B75014C4066BFEE74E7D34E40292499D53B004C40999B6F44F7D24E40292499D53B004C40
43778	14233	60.956217000000002	60.974964999999997	55.969627000000003	55.964075000000001	Победы	0103000020E610000001000000050000008B709351657A4E4013F241CF66FB4B408B709351657A4E40C828CFBC1CFC4B4050DF32A7CB7C4E40C828CFBC1CFC4B4050DF32A7CB7C4E4013F241CF66FB4B408B709351657A4E4013F241CF66FB4B40
44083	13303	61.580374999999997	61.608204999999998	56.165478999999998	56.139069999999997	Береговая	0103000020E610000001000000050000003F355EBA49CA4E4067EDB60BCD114C403F355EBA49CA4E405F96766A2E154C40C02154A9D9CD4E405F96766A2E154C40C02154A9D9CD4E4067EDB60BCD114C403F355EBA49CA4E4067EDB60BCD114C40
43777	13648	60.915720999999998	60.934316000000003	56.142189999999999	56.135568999999997	Новгородцева	0103000020E6100000010000000500000055A1815836754E40FBAC32535A114C4055A1815836754E40BCE82B4833124C409510ACAA97774E40BCE82B4833124C409510ACAA97774E40FBAC32535A114C4055A1815836754E40FBAC32535A114C40
43873	13231	61.660110000000003	61.671922000000002	56.198900999999999	56.190787	Трактовая	0103000020E610000001000000050000009CE1067C7ED44E4040C05AB56B184C409CE1067C7ED44E402312859675194C4041BB438A01D64E402312859675194C4041BB438A01D64E4040C05AB56B184C409CE1067C7ED44E4040C05AB56B184C40
44085	13709	60.872205999999998	60.902209999999997	56.117406000000003	56.109451	Ленина	0103000020E61000000100000005000000FFAF3A72A46F4E40DBC1887D020E4C40FFAF3A72A46F4E40562DE928070F4C40E40F069E7B734E40562DE928070F4C40E40F069E7B734E40DBC1887D020E4C40FFAF3A72A46F4E40DBC1887D020E4C40
44016	13587	60.926015	60.955084999999997	56.163142999999998	56.154153999999998	Ленина	0103000020E610000001000000050000007F4DD6A887764E4017467A51BB134C407F4DD6A887764E4021C9ACDEE1144C4038F3AB39407A4E4021C9ACDEE1144C4038F3AB39407A4E4017467A51BB134C407F4DD6A887764E4017467A51BB134C40
43967	14158	60.816394000000003	60.843854999999998	56.076960999999997	56.060262999999999	1е Мая	0103000020E6100000010000000500000048533D997F684E405514AFB2B6074C4048533D997F684E40A208A9DBD9094C4075C8CD70036C4E40A208A9DBD9094C4075C8CD70036C4E405514AFB2B6074C4048533D997F684E405514AFB2B6074C40
43890	13509	60.761353999999997	60.803277999999999	56.130206000000001	56.114766000000003	Мира	0103000020E61000000100000005000000E256410C74614E40AC58FCA6B00E4C40E256410C74614E401ADF1797AA104C4053CC41D0D1664E401ADF1797AA104C4053CC41D0D1664E40AC58FCA6B00E4C40E256410C74614E40AC58FCA6B00E4C40
44084	12947	60.623632999999998	60.673616000000003	56.019435000000001	55.979868000000003	Школьная	0103000020E610000001000000050000006ADAC534D34F4E40CF328B506CFD4B406ADAC534D34F4E40EAB298D87C024C40FB07910C39564E40EAB298D87C024C40FB07910C39564E40CF328B506CFD4B406ADAC534D34F4E40CF328B506CFD4B40
42895	12947	60.623632999999998	60.673616000000003	56.019435000000001	55.979868000000003	Советская	0103000020E610000001000000050000006ADAC534D34F4E40CF328B506CFD4B406ADAC534D34F4E40EAB298D87C024C40FB07910C39564E40EAB298D87C024C40FB07910C39564E40CF328B506CFD4B406ADAC534D34F4E40CF328B506CFD4B40
43231	12947	60.623632999999998	60.673616000000003	56.019435000000001	55.979868000000003	Пионерская	0103000020E610000001000000050000006ADAC534D34F4E40CF328B506CFD4B406ADAC534D34F4E40EAB298D87C024C40FB07910C39564E40EAB298D87C024C40FB07910C39564E40CF328B506CFD4B406ADAC534D34F4E40CF328B506CFD4B40
43639	13463	61.056783000000003	61.118505999999996	56.101819999999996	56.071047	Октябрьская	0103000020E6100000010000000500000001FC53AA44874E404DBD6E1118094C4001FC53AA44874E40130A1170080D4C409C3061342B8F4E40130A1170080D4C409C3061342B8F4E404DBD6E1118094C4001FC53AA44874E404DBD6E1118094C40
44225	29049	60.779240000000001	60.786389999999997	56.016305000000003	56.007407999999998	Центральная	0103000020E6100000010000000500000016DEE522BE634E4048DDCEBEF2004C4016DEE522BE634E4072E1404816024C4062F3716DA8644E4072E1404816024C4062F3716DA8644E4048DDCEBEF2004C4016DEE522BE634E4048DDCEBEF2004C40
42892	13370	61.266728000000001	61.298520000000003	55.997598000000004	55.981943000000001	Суворова	0103000020E61000000100000005000000B876A22424A24E40A0C4E74EB0FD4B40B876A22424A24E400B47904AB1FF4B40D99942E735A64E400B47904AB1FF4B40D99942E735A64E40A0C4E74EB0FD4B40B876A22424A24E40A0C4E74EB0FD4B40
43562	13370	61.266728000000001	61.298520000000003	55.997598000000004	55.981943000000001	Ленина	0103000020E61000000100000005000000B876A22424A24E40A0C4E74EB0FD4B40B876A22424A24E400B47904AB1FF4B40D99942E735A64E400B47904AB1FF4B40D99942E735A64E40A0C4E74EB0FD4B40B876A22424A24E40A0C4E74EB0FD4B40
43561	13144	61.476726999999997	61.529314999999997	56.215938999999999	56.190807	Свердлова	0103000020E61000000100000005000000620FED6305BD4E40876C205D6C184C40620FED6305BD4E4029779FE3A31B4C4020240B98C0C34E4029779FE3A31B4C4020240B98C0C34E40876C205D6C184C40620FED6305BD4E40876C205D6C184C40
43640	13144	61.476726999999997	61.529314999999997	56.215938999999999	56.190807	Пионерская	0103000020E61000000100000005000000620FED6305BD4E40876C205D6C184C40620FED6305BD4E4029779FE3A31B4C4020240B98C0C34E4029779FE3A31B4C4020240B98C0C34E40876C205D6C184C40620FED6305BD4E40876C205D6C184C40
44236	13090	60.522384000000002	60.539757999999999	56.011560000000003	56.003667999999998	Пионерская	0103000020E6100000010000000500000012FA997ADD424E4057056A3178004C4012FA997ADD424E408CF84ECC7A014C408FE046CA16454E408CF84ECC7A014C408FE046CA16454E4057056A3178004C4012FA997ADD424E4057056A3178004C40
43775	14142	60.958345999999999	60.993496999999998	56.004095999999997	55.994542000000003	Советская	0103000020E610000001000000050000004F20EC14AB7A4E40CD3FFA264DFF4B404F20EC14AB7A4E40AF05BD3786004C4049D6E1E82A7F4E40AF05BD3786004C4049D6E1E82A7F4E40CD3FFA264DFF4B404F20EC14AB7A4E40CD3FFA264DFF4B40
43528	14312	60.670138999999999	60.691276999999999	52.825732000000002	52.817275000000002	Мира	0103000020E610000001000000050000001763601DC7554E40516B9A779C684A401763601DC7554E405EA10F96B1694A400EBDC5C37B584E405EA10F96B1694A400EBDC5C37B584E40516B9A779C684A401763601DC7554E40516B9A779C684A40
42922	13937	60.701121999999998	60.73612	53.067920000000001	53.048344	Центральный переулок	0103000020E61000000100000005000000C8409E5DBE594E409A7ADD2230864A40C8409E5DBE594E40465F419AB1884A403CF71E2E395E4E40465F419AB1884A403CF71E2E395E4E409A7ADD2230864A40C8409E5DBE594E409A7ADD2230864A40
43896	15173	60.36985	60.384250000000002	53.362290000000002	53.355663999999997	Пушкина	0103000020E610000001000000050000007A36AB3E572F4E40A92EE06586AD4A407A36AB3E572F4E407CD5CA845FAE4A4077BE9F1A2F314E407CD5CA845FAE4A4077BE9F1A2F314E40A92EE06586AD4A407A36AB3E572F4E40A92EE06586AD4A40
44259	14141	60.860798000000003	60.877884000000002	52.942312999999999	52.934351999999997	Юбилейная	0103000020E610000001000000050000002A3BFDA02E6E4E40E179A9D898774A402A3BFDA02E6E4E403ECC5EB69D784A4041D7BE805E704E403ECC5EB69D784A4041D7BE805E704E40E179A9D898774A402A3BFDA02E6E4E40E179A9D898774A40
43700	14440	60.007389000000003	60.030602000000002	52.874713999999997	52.847904999999997	Черемушки	0103000020E61000000100000005000000D2AC6C1FF2004E40B48EAA26886C4A40D2AC6C1FF2004E403AADDBA0F66F4A409A982EC4EA034E403AADDBA0F66F4A409A982EC4EA034E40B48EAA26886C4A40D2AC6C1FF2004E40B48EAA26886C4A40
44255	14282	60.785429000000001	60.803807999999997	53.029663999999997	53.020977000000002	Гагарина	0103000020E610000001000000050000003D2AFEEF88644E40EE7BD45FAF824A403D2AFEEF88644E402CEFAA07CC834A40AF21382EE3664E402CEFAA07CC834A40AF21382EE3664E40EE7BD45FAF824A403D2AFEEF88644E40EE7BD45FAF824A40
44260	15368	60.537260000000003	60.556592000000002	53.104049000000003	53.093884000000003	Школьная	0103000020E6100000010000000500000078B988EFC4444E4010CF1264048C4A4078B988EFC4444E403C17467A518D4A408D9B1A683E474E403C17467A518D4A408D9B1A683E474E4010CF1264048C4A4078B988EFC4444E4010CF1264048C4A40
43632	15368	60.537260000000003	60.556592000000002	53.104049000000003	53.093884000000003	Просвещения	0103000020E6100000010000000500000078B988EFC4444E4010CF1264048C4A4078B988EFC4444E403C17467A518D4A408D9B1A683E474E403C17467A518D4A408D9B1A683E474E4010CF1264048C4A4078B988EFC4444E4010CF1264048C4A40
43999	14159	60.887487	60.897736000000002	52.946399	52.942459999999997	Набережная	0103000020E6100000010000000500000005508C2C99714E40E2E47E87A2784A4005508C2C99714E40CAFB389A23794A408F386403E9724E40CAFB389A23794A408F386403E9724E40E2E47E87A2784A4005508C2C99714E40E2E47E87A2784A40
44252	14563	59.917009999999998	59.934131999999998	52.971558000000002	52.964388999999997	Лесная	0103000020E610000001000000050000006F0D6C9560F54D40A2CF4719717B4A406F0D6C9560F54D40661536035C7C4A40D3122BA391F74D40661536035C7C4A40D3122BA391F74D40A2CF4719717B4A406F0D6C9560F54D40A2CF4719717B4A40
43859	14020	60.934548999999997	60.947135000000003	53.054006000000001	53.045712999999999	Центральная	0103000020E6100000010000000500000037C1374D9F774E40430070ECD9854A4037C1374D9F774E40D6E429ABE9864A40D0F23CB83B794E40D6E429ABE9864A40D0F23CB83B794E40430070ECD9854A4037C1374D9F774E40430070ECD9854A40
44140	15107	60.590637999999998	60.618943999999999	53.218809999999998	53.204788999999998	Пьянзина	0103000020E610000001000000050000002EE3A6069A4B4E404FCAA486369A4A402EE3A6069A4B4E40D50451F7019C4A401807978E394F4E40D50451F7019C4A401807978E394F4E404FCAA486369A4A402EE3A6069A4B4E404FCAA486369A4A40
44127	13997	60.867634000000002	60.878072000000003	53.095343999999997	53.086236999999997	Школьная	0103000020E61000000100000005000000E77283A10E6F4E40425A63D0098B4A40E77283A10E6F4E4056EF703B348C4A4044C4CDA964704E4056EF703B348C4A4044C4CDA964704E40425A63D0098B4A40E77283A10E6F4E40425A63D0098B4A40
44258	13866	60.850780999999998	60.869627999999999	53.154049000000001	53.147692999999997	Центральная	0103000020E6100000010000000500000072874D64E66C4E408F6CAE9AE7924A4072874D64E66C4E40A27DACE0B7934A40CBD765F84F6F4E40A27DACE0B7934A40CBD765F84F6F4E408F6CAE9AE7924A4072874D64E66C4E408F6CAE9AE7924A40
43874	14230	60.761291	60.773741999999999	52.944375000000001	52.941243999999998	Центральная	0103000020E610000001000000050000009CDEC5FB71614E4032C7F2AE7A784A409CDEC5FB71614E407B14AE47E1784A4054C554FA09634E407B14AE47E1784A4054C554FA09634E4032C7F2AE7A784A409CDEC5FB71614E4032C7F2AE7A784A40
42676	55094	59.865212999999997	59.997014	53.127813000000003	53.048462999999998	Кирова	0103000020E610000001000000050000007A89B14CBFEE4D4074081C0934864A407A89B14CBFEE4D407880272D5C904A40BBD39D279EFF4D407880272D5C904A40BBD39D279EFF4D4074081C0934864A407A89B14CBFEE4D4074081C0934864A40
43656	14591	60.097014000000001	60.140726000000001	52.913944000000001	52.888930999999999	Слонова	0103000020E6100000010000000500000088A06AF46A0C4E4046B3B27DC8714A4088A06AF46A0C4E400E30F31DFC744A4034D93F4F03124E400E30F31DFC744A4034D93F4F03124E4046B3B27DC8714A4088A06AF46A0C4E4046B3B27DC8714A40
44002	15501	60.347814999999997	60.365682	52.933011	52.916061999999997	Центральная	0103000020E610000001000000050000007407B133852C4E40DE8D058541754A407407B133852C4E4075E789E76C774A40315EF3AACE2E4E4075E789E76C774A40315EF3AACE2E4E40DE8D058541754A407407B133852C4E40DE8D058541754A40
43655	13851	60.750025999999998	60.769843000000002	53.115842999999998	53.101804999999999	Садовая	0103000020E6100000010000000500000029931ADA00604E40DEC83CF2078D4A4029931ADA00604E403A3C84F1D38E4A40FB0626378A624E403A3C84F1D38E4A40FB0626378A624E40DEC83CF2078D4A4029931ADA00604E40DEC83CF2078D4A40
44251	14836	59.790374	59.808205999999998	53.18036	53.167000999999999	Центральная	0103000020E61000000100000005000000EACDA8F92AE54D401CB3EC4960954A40EACDA8F92AE54D40D7C0560916974A402A37514B73E74D40D7C0560916974A402A37514B73E74D401CB3EC4960954A40EACDA8F92AE54D401CB3EC4960954A40
43188	12653	60.580227000000001	60.628717999999999	53.053806000000002	53.027644000000002	Школьная	0103000020E61000000100000005000000CBA0DAE0444A4E401FF7ADD689834A40CBA0DAE0444A4E400F2A711DE3864A400934D8D479504E400F2A711DE3864A400934D8D479504E401FF7ADD689834A40CBA0DAE0444A4E401FF7ADD689834A40
43184	12653	60.580227000000001	60.628717999999999	53.053806000000002	53.027644000000002	Ленина	0103000020E61000000100000005000000CBA0DAE0444A4E401FF7ADD689834A40CBA0DAE0444A4E400F2A711DE3864A400934D8D479504E400F2A711DE3864A400934D8D479504E401FF7ADD689834A40CBA0DAE0444A4E401FF7ADD689834A40
44131	15570	60.459744999999998	60.483676000000003	52.979143999999998	52.970989000000003	Северная	0103000020E61000000100000005000000F0BF95ECD83A4E404CE3175E497C4A40F0BF95ECD83A4E408D093197547D4A4018EE5C18E93D4E408D093197547D4A4018EE5C18E93D4E404CE3175E497C4A40F0BF95ECD83A4E404CE3175E497C4A40
43878	15402	60.505854999999997	60.531582999999998	53.075856999999999	53.064722000000003	Центральная	0103000020E6100000010000000500000050C24CDBBF404E4076AA7CCF48884A4050C24CDBBF404E401A16A3AEB5894A40060E68E90A444E401A16A3AEB5894A40060E68E90A444E4076AA7CCF48884A4050C24CDBBF404E4076AA7CCF48884A40
44128	14645	60.233342	60.247931000000001	52.849189000000003	52.841307999999998	Терешковой	0103000020E6100000010000000500000041649126DE1D4E407CEE04FBAF6B4A4041649126DE1D4E40BD8FA339B26C4A401155F833BC1F4E40BD8FA339B26C4A401155F833BC1F4E407CEE04FBAF6B4A4041649126DE1D4E407CEE04FBAF6B4A40
44129	14803	59.965392999999999	59.974870000000003	53.044809000000001	53.031115999999997	Октябрьская	0103000020E61000000100000005000000C76471FF91FB4D40F030ED9BFB834A40C76471FF91FB4D4082C8224DBC854A40FFEC478AC8FC4D4082C8224DBC854A40FFEC478AC8FC4D40F030ED9BFB834A40C76471FF91FB4D40F030ED9BFB834A40
44263	14504	60.068834000000003	60.086602999999997	52.788955000000001	52.779924000000001	Черемушки	0103000020E610000001000000050000002B6D718DCF084E40C9AEB48CD4634A402B6D718DCF084E400282397AFC644A40245E9ECE150B4E400282397AFC644A40245E9ECE150B4E40C9AEB48CD4634A402B6D718DCF084E40C9AEB48CD4634A40
43877	14992	60.016938000000003	60.064576000000002	53.119221000000003	53.106805999999999	Вокзальная	0103000020E61000000100000005000000A3073E062B024E401F82AAD1AB8D4A40A3073E062B024E408BFF3BA2428F4A40A20DC00644084E408BFF3BA2428F4A40A20DC00644084E401F82AAD1AB8D4A40A3073E062B024E401F82AAD1AB8D4A40
44001	14358	60.597330999999997	60.621710999999998	52.838690999999997	52.830013999999998	Центральная	0103000020E6100000010000000500000088F19A57754C4E406F9C14E63D6A4A4088F19A57754C4E408A39083A5A6B4A401F48DE39944F4E408A39083A5A6B4A401F48DE39944F4E406F9C14E63D6A4A4088F19A57754C4E406F9C14E63D6A4A40
43576	14736	59.861521000000003	59.886485	53.123085000000003	53.112228000000002	Будаковой	0103000020E610000001000000050000009BE8F35146EE4D4006D9B27C5D8E4A409BE8F35146EE4D4068D0D03FC18F4A4081B2295778F14D4068D0D03FC18F4A4081B2295778F14D4006D9B27C5D8E4A409BE8F35146EE4D4006D9B27C5D8E4A40
43574	14916	59.953212000000001	59.982900999999998	53.171978000000003	53.154902	Вокзальная	0103000020E61000000100000005000000CF13CFD902FA4D40E10A28D4D3934A40CF13CFD902FA4D40D5D0066003964A40541A31B3CFFD4D40D5D0066003964A40541A31B3CFFD4D40E10A28D4D3934A40CF13CFD902FA4D40E10A28D4D3934A40
44134	15205	60.464578000000003	60.475105999999997	53.342699000000003	53.337538000000002	Пушкина	0103000020E610000001000000050000007638BA4A773B4E402194F77134AB4A407638BA4A773B4E409BAF928FDDAB4A401211FE45D03C4E409BAF928FDDAB4A401211FE45D03C4E402194F77134AB4A407638BA4A773B4E402194F77134AB4A40
44250	14427	60.604050000000001	60.615772999999997	52.944685	52.936045	Центральная	0103000020E610000001000000050000000C93A982514D4E40CB4A9352D0774A400C93A982514D4E40C9022670EB784A40416150A6D14E4E40C9022670EB784A40416150A6D14E4E40CB4A9352D0774A400C93A982514D4E40CB4A9352D0774A40
43529	15077	60.472627000000003	60.498651000000002	53.257505000000002	53.241228	Мира	0103000020E61000000100000005000000721AA20A7F3C4E409370218FE09E4A40721AA20A7F3C4E403BC780ECF5A04A40118FC4CBD33F4E403BC780ECF5A04A40118FC4CBD33F4E409370218FE09E4A40721AA20A7F3C4E409370218FE09E4A40
43578	15465	60.325752000000001	60.353223	52.851261000000001	52.839001000000003	Центральная	0103000020E61000000100000005000000A54DD53DB2294E40D9278062646B4A40A54DD53DB2294E401DAED51EF66C4A40F6984869362D4E401DAED51EF66C4A40F6984869362D4E40D9278062646B4A40A54DD53DB2294E40D9278062646B4A40
43699	15270	60.357920999999997	60.399369	53.134929	53.109271	Переселенческая	0103000020E610000001000000050000009BC6F65AD02D4E405BB39597FC8D4A409BC6F65AD02D4E4018247D5A45914A40A304FD851E334E4018247D5A45914A40A304FD851E334E405BB39597FC8D4A409BC6F65AD02D4E405BB39597FC8D4A40
43694	15270	60.357920999999997	60.399369	53.134929	53.109271	Ленина	0103000020E610000001000000050000009BC6F65AD02D4E405BB39597FC8D4A409BC6F65AD02D4E4018247D5A45914A40A304FD851E334E4018247D5A45914A40A304FD851E334E405BB39597FC8D4A409BC6F65AD02D4E405BB39597FC8D4A40
43861	14716	60.139594000000002	60.159275999999998	53.041074000000002	53.028565	Гагарина	0103000020E61000000100000005000000E25B5837DE114E40B6679604A8834A40E25B5837DE114E40A35BAFE941854A40D384ED2763144E40A35BAFE941854A40D384ED2763144E40B6679604A8834A40E25B5837DE114E40B6679604A8834A40
44222	23146	61.619236000000001	61.637309999999999	54.913732000000003	54.903308000000003	Халтурина	0103000020E61000000100000005000000C040102043CF4E408B1BB7989F734B40C040102043CF4E4083A7902BF5744B40F6B4C35F93D14E4083A7902BF5744B40F6B4C35F93D14E408B1BB7989F734B40C040102043CF4E408B1BB7989F734B40
44224	23114	61.697128999999997	61.714573999999999	54.831079000000003	54.812654999999999	Центральная	0103000020E61000000100000005000000ED0BE8853BD94E4027F73B1405684B40ED0BE8853BD94E403AB2F2CB606A4B4034492C2977DB4E403AB2F2CB606A4B4034492C2977DB4E4027F73B1405684B40ED0BE8853BD94E4027F73B1405684B40
43760	48686	61.733933	61.755105999999998	54.959975999999997	54.950122999999998	Советская	0103000020E61000000100000005000000433A3C84F1DD4E40B51666A19D794B40433A3C84F1DD4E40F2785A7EE07A4B40B6813B50A7E04E40F2785A7EE07A4B40B6813B50A7E04E40B51666A19D794B40433A3C84F1DD4E40B51666A19D794B40
44160	55208	61.043182999999999	61.060996000000003	54.789732000000001	54.776918000000002	Школьная	0103000020E61000000100000005000000205F420587854E403DD68C0C72634B40205F420587854E40664D2CF015654B40EA9788B7CE874E40664D2CF015654B40EA9788B7CE874E403DD68C0C72634B40205F420587854E403DD68C0C72634B40
44174	48352	61.672955000000002	61.703076000000003	54.735796999999998	54.724437000000002	Центральная	0103000020E610000001000000050000000057B26323D64E409581035ABA5C4B400057B26323D64E4059BF99982E5E4B401F4DF564FED94E4059BF99982E5E4B401F4DF564FED94E409581035ABA5C4B400057B26323D64E409581035ABA5C4B40
44220	48053	61.529449999999997	61.547289999999997	54.717765999999997	54.705267999999997	Банная	0103000020E61000000100000005000000006F8104C5C34E402975C938465A4B40006F8104C5C34E4022179CC1DF5B4B40C3B645990DC64E4022179CC1DF5B4B40C3B645990DC64E402975C938465A4B40006F8104C5C34E402975C938465A4B40
43019	23428	61.814763999999997	61.83361	54.920222000000003	54.900689	Советская	0103000020E61000000100000005000000A4FACE2F4AE84E40F86EF3C649734B40A4FACE2F4AE84E40A587A1D5C9754B402DCF83BBB3EA4E40A587A1D5C9754B402DCF83BBB3EA4E40F86EF3C649734B40A4FACE2F4AE84E40F86EF3C649734B40
43880	21932	61.592492999999997	61.606112000000003	54.721249999999998	54.707946	Школьная	0103000020E61000000100000005000000F10D85CFD6CB4E40C1AA7AF99D5A4B40F10D85CFD6CB4E40B81E85EB515C4B4049DBF81395CD4E40B81E85EB515C4B4049DBF81395CD4E40C1AA7AF99D5A4B40F10D85CFD6CB4E40C1AA7AF99D5A4B40
44151	19910	61.309784999999998	61.315722000000001	54.824311000000002	54.815550000000002	Центральная	0103000020E610000001000000050000004BE5ED08A7A74E405C2041F163684B404BE5ED08A7A74E40D55DD90583694B405950189469A84E40D55DD90583694B405950189469A84E405C2041F163684B404BE5ED08A7A74E405C2041F163684B40
43642	19910	61.309784999999998	61.315722000000001	54.824311000000002	54.815550000000002	Свердлова	0103000020E610000001000000050000004BE5ED08A7A74E405C2041F163684B404BE5ED08A7A74E40D55DD90583694B405950189469A84E40D55DD90583694B405950189469A84E405C2041F163684B404BE5ED08A7A74E405C2041F163684B40
44037	48016	61.430159000000003	61.440354999999997	54.769616999999997	54.762397	Школьная	0103000020E61000000100000005000000408A3A730FB74E40C5C8923996614B40408A3A730FB74E400AB952CF82624B40A6D0798D5DB84E400AB952CF82624B40A6D0798D5DB84E40C5C8923996614B40408A3A730FB74E40C5C8923996614B40
44144	48503	61.715544999999999	61.741433999999998	54.778533000000003	54.768360000000001	Центральная	0103000020E610000001000000050000007DE882FA96DB4E40FCC6D79E59624B407DE882FA96DB4E40ABED26F8A6634B403C122F4FE7DE4E40ABED26F8A6634B403C122F4FE7DE4E40FCC6D79E59624B407DE882FA96DB4E40FCC6D79E59624B40
44147	48430	62.004612999999999	62.017927	54.762417999999997	54.753819999999997	Молодежная	0103000020E610000001000000050000007711A62897004F400D897B2C7D604B407711A62897004F40DCF0BBE996614B40925B936E4B024F40DCF0BBE996614B40925B936E4B024F400D897B2C7D604B407711A62897004F400D897B2C7D604B40
43764	48399	60.961112	60.974722	54.748196999999998	54.736691	Береговая	0103000020E6100000010000000500000086E5CFB7057B4E40F72004E44B5E4B4086E5CFB7057B4E408FFB56EBC45F4B408A58C4B0C37C4E408FFB56EBC45F4B408A58C4B0C37C4E40F72004E44B5E4B4086E5CFB7057B4E40F72004E44B5E4B40
44193	55214	62.005727	62.023954000000003	54.585304000000001	54.567805999999997	Колхозная	0103000020E6100000010000000500000023DA8EA9BB004F407D3CF4DDAD484B4023DA8EA9BB004F40E71BD13DEB4A4B40E04DB7EC10034F40E71BD13DEB4A4B40E04DB7EC10034F407D3CF4DDAD484B4023DA8EA9BB004F407D3CF4DDAD484B40
43788	55173	61.621212999999997	61.654440999999998	54.848582	54.839925000000001	Набережная	0103000020E61000000100000005000000CE6C57E883CF4E40E10B93A9826B4B40CE6C57E883CF4E40B5FCC0559E6C4B40AD1402B9C4D34E40B5FCC0559E6C4B40AD1402B9C4D34E40E10B93A9826B4B40CE6C57E883CF4E40E10B93A9826B4B40
43675	22923	61.346975	61.362552000000001	54.856144	54.848292000000001	Центральная	0103000020E61000000100000005000000CAC342AD69AC4E40AEBA0ED5946C4B40CAC342AD69AC4E4054556820966D4B40B98C9B1A68AE4E4054556820966D4B40B98C9B1A68AE4E40AEBA0ED5946C4B40CAC342AD69AC4E40AEBA0ED5946C4B40
43951	22629	61.738568000000001	61.750605999999998	54.596113000000003	54.586091000000003	Молодежная	0103000020E61000000100000005000000A2EF6E6589DE4E406FBDA607054B4B40A2EF6E6589DE4E4038DC476E4D4C4B4037177FDB13E04E4038DC476E4D4C4B4037177FDB13E04E406FBDA607054B4B40A2EF6E6589DE4E406FBDA607054B4B40
44199	48312	61.843411000000003	61.853318999999999	54.659829000000002	54.649082999999997	Береговая	0103000020E61000000100000005000000180B43E4F4EB4E40DDB1D82615534B40180B43E4F4EB4E40E8F9D34675544B401807978E39ED4E40E8F9D34675544B401807978E39ED4E40DDB1D82615534B40180B43E4F4EB4E40DDB1D82615534B40
43765	48628	61.764142999999997	61.791623000000001	54.834744999999998	54.824435000000001	Даровского	0103000020E61000000100000005000000D13B1570CFE14E40C156091687694B40D13B1570CFE14E40F0BF95ECD86A4B4076E107E753E54E40F0BF95ECD86A4B4076E107E753E54E40C156091687694B40D13B1570CFE14E40C156091687694B40
44183	45505	61.958134999999999	61.973128000000003	54.722845999999997	54.706698000000003	Центральная	0103000020E610000001000000050000009413ED2AA4FA4E4006137F14755A4B409413ED2AA4FA4E40AF05BD37865C4B40346953758FFC4E40AF05BD37865C4B40346953758FFC4E4006137F14755A4B409413ED2AA4FA4E4006137F14755A4B40
43762	48562	61.696375000000003	61.708689999999997	54.933366999999997	54.922927999999999	Школьный пер	0103000020E610000001000000050000004260E5D022D94E400648348122764B404260E5D022D94E403315E29178774B4049809A5AB6DA4E403315E29178774B4049809A5AB6DA4E400648348122764B404260E5D022D94E400648348122764B40
44148	48562	61.696375000000003	61.708689999999997	54.933366999999997	54.922927999999999	Октябрьская	0103000020E610000001000000050000004260E5D022D94E400648348122764B404260E5D022D94E403315E29178774B4049809A5AB6DA4E403315E29178774B4049809A5AB6DA4E400648348122764B404260E5D022D94E400648348122764B40
44142	48084	62.007469999999998	62.026918999999999	54.822800999999998	54.811067000000001	Мира	0103000020E61000000100000005000000BED9E6C6F4004F40B3EE1F0BD1674B40BED9E6C6F4004F40DC0E0D8B51694B400D52F01472034F40DC0E0D8B51694B400D52F01472034F40B3EE1F0BD1674B40BED9E6C6F4004F40B3EE1F0BD1674B40
43115	6443	60.890712000000001	60.915703000000001	54.661208999999999	54.642299999999999	Чапаева	0103000020E61000000100000005000000CF13CFD902724E40431CEBE236524B40CF13CFD902724E4012691B7FA2544B40AFEC82C135754E4012691B7FA2544B40AFEC82C135754E40431CEBE236524B40CF13CFD902724E40431CEBE236524B40
42679	6443	60.890712000000001	60.915703000000001	54.661208999999999	54.642299999999999	Заречная	0103000020E61000000100000005000000CF13CFD902724E40431CEBE236524B40CF13CFD902724E4012691B7FA2544B40AFEC82C135754E4012691B7FA2544B40AFEC82C135754E40431CEBE236524B40CF13CFD902724E40431CEBE236524B40
42928	22540	61.671751999999998	61.703732000000002	54.69211	54.672825000000003	Набережная	0103000020E61000000100000005000000E48233F8FBD54E4032772D211F564B40E48233F8FBD54E40069E7B0F97584B400893E2E313DA4E40069E7B0F97584B400893E2E313DA4E4032772D211F564B40E48233F8FBD54E4032772D211F564B40
44166	22965	61.664169999999999	61.677653999999997	54.861004999999999	54.850816000000002	Набережная	0103000020E61000000100000005000000FE7DC68503D54E40EF74E789E76C4B40FE7DC68503D54E40A3586E69356E4B407500C45DBDD64E40A3586E69356E4B407500C45DBDD64E40EF74E789E76C4B40FE7DC68503D54E40EF74E789E76C4B40
43153	6348	61.571660999999999	61.618329000000003	54.845720999999998	54.807414000000001	Первомайская	0103000020E6100000010000000500000007B309302CC94E40912A8A5759674B4007B309302CC94E402C45F295406C4B408E95986725CF4E402C45F295406C4B408E95986725CF4E40912A8A5759674B4007B309302CC94E40912A8A5759674B40
42685	6348	61.571660999999999	61.618329000000003	54.845720999999998	54.807414000000001	Ленина	0103000020E6100000010000000500000007B309302CC94E40912A8A5759674B4007B309302CC94E402C45F295406C4B408E95986725CF4E402C45F295406C4B408E95986725CF4E40912A8A5759674B4007B309302CC94E40912A8A5759674B40
43015	22259	61.283751000000002	61.311078000000002	54.812840999999999	54.788891	Октябрьская	0103000020E61000000100000005000000899AE8F351A44E40EB8D5A61FA644B40899AE8F351A44E4089EC832C0B684B40A7406667D1A74E4089EC832C0B684B40A7406667D1A74E40EB8D5A61FA644B40899AE8F351A44E40EB8D5A61FA644B40
43017	22259	61.283751000000002	61.311078000000002	54.812840999999999	54.788891	Заречная	0103000020E61000000100000005000000899AE8F351A44E40EB8D5A61FA644B40899AE8F351A44E4089EC832C0B684B40A7406667D1A74E4089EC832C0B684B40A7406667D1A74E40EB8D5A61FA644B40899AE8F351A44E40EB8D5A61FA644B40
43957	48377	60.932842999999998	60.950682999999998	54.795586999999998	54.78736	Новая	0103000020E61000000100000005000000B9A6406667774E40DB166536C8644B40B9A6406667774E40B60F79CBD5654B407CEE04FBAF794E40B60F79CBD5654B407CEE04FBAF794E40DB166536C8644B40B9A6406667774E40DB166536C8644B40
43758	22239	61.122000999999997	61.133426999999998	54.843865000000001	54.834781	Центральная	0103000020E61000000100000005000000268A90BA9D8F4E403D29931ADA6A4B40268A90BA9D8F4E40999EB0C4036C4B40A2B3CC2214914E40999EB0C4036C4B40A2B3CC2214914E403D29931ADA6A4B40268A90BA9D8F4E403D29931ADA6A4B40
43924	22485	61.553128999999998	61.558717000000001	54.648119999999999	54.639122	Труда	0103000020E610000001000000050000000EBC5AEECCC64E40BA13ECBFCE514B400EBC5AEECCC64E4017F19D98F5524B40105CE50984C74E4017F19D98F5524B40105CE50984C74E40BA13ECBFCE514B400EBC5AEECCC64E40BA13ECBFCE514B40
44167	48149	61.179394000000002	61.192329999999998	54.814822999999997	54.805728000000002	Лесная	0103000020E61000000100000005000000A08CF161F6964E405ABC581822674B40A08CF161F6964E40A983BC1E4C684B401405FA449E984E40A983BC1E4C684B401405FA449E984E405ABC581822674B40A08CF161F6964E405ABC581822674B40
77168	61087	61.939737000000001	61.957172999999997	54.801281000000003	54.787168000000001	Октябрьская	0103000020E61000000100000005000000ABEB504D49F84E40973AC8EBC1644B40ABEB504D49F84E40FEF3346090664B409ECE15A584FA4E40FEF3346090664B409ECE15A584FA4E40973AC8EBC1644B40ABEB504D49F84E40973AC8EBC1644B40
43533	21840	61.435395999999997	61.458140999999998	54.818631000000003	54.805967000000003	Советская	0103000020E6100000010000000500000094675E0EBBB74E40DF5339ED29674B4094675E0EBBB74E40F33E8EE6C8684B4076FA415DA4BA4E40F33E8EE6C8684B4076FA415DA4BA4E40DF5339ED29674B4094675E0EBBB74E40DF5339ED29674B40
43579	21750	61.433464999999998	61.454870999999997	54.869973999999999	54.856335999999999	Комсомольская	0103000020E61000000100000005000000F67AF7C77BB74E409831056B9C6D4B40F67AF7C77BB74E40662FDB4E5B6F4B400C73823639BA4E40662FDB4E5B6F4B400C73823639BA4E409831056B9C6D4B40F67AF7C77BB74E409831056B9C6D4B40
44189	48594	61.880341000000001	61.897328000000002	54.892302000000001	54.879722999999998	Школьная	0103000020E61000000100000005000000FA298E03AFF04E40FE4465C39A704B40FA298E03AFF04E40E413B2F336724B407EE4D6A4DBF24E40E413B2F336724B407EE4D6A4DBF24E40FE4465C39A704B40FA298E03AFF04E40FE4465C39A704B40
43898	6583	60.057406999999998	60.066983	54.032792000000001	54.025779	Молодежная	0103000020E61000000100000005000000DEC7D11C59074E4038F6ECB94C034B40DEC7D11C59074E4004C93B8732044B40A93121E692084E4004C93B8732044B40A93121E692084E4038F6ECB94C034B40DEC7D11C59074E4038F6ECB94C034B40
43818	7467	59.427796000000001	59.459668000000001	53.906267999999997	53.900644999999997	Центральная	0103000020E6100000010000000500000008AEF204C2B64D402827DA5548F34A4008AEF204C2B64D40A6B4FE9600F44A404582A966D6BA4D40A6B4FE9600F44A404582A966D6BA4D402827DA5548F34A4008AEF204C2B64D402827DA5548F34A40
44114	7174	59.573430999999999	59.586258999999998	54.056339000000001	54.050350999999999	Мира	0103000020E610000001000000050000009CC1DF2F66C94D401329CDE671064B409CC1DF2F66C94D40A33EC91D36074B402AFEEF880ACB4D40A33EC91D36074B402AFEEF880ACB4D401329CDE671064B409CC1DF2F66C94D401329CDE671064B40
43014	7256	59.188512000000003	59.212891999999997	53.894803000000003	53.886085000000001	Советская	0103000020E61000000100000005000000A873452921984D40F33CB83B6BF14A40A873452921984D406DAE9AE788F24A403ECA880B409B4D406DAE9AE788F24A403ECA880B409B4D40F33CB83B6BF14A40A873452921984D40F33CB83B6BF14A40
43910	5896	59.821078999999997	59.843276000000003	53.816817999999998	53.803590999999997	Школьная	0103000020E610000001000000050000005837DE1D19E94D40122EE411DCE64A405837DE1D19E94D405E64027E8DE84A4038C0CC77F0EB4D405E64027E8DE84A4038C0CC77F0EB4D40122EE411DCE64A405837DE1D19E94D40122EE411DCE64A40
44109	5443	59.412201000000003	59.429009000000001	54.031078999999998	54.022061000000001	Дружбы	0103000020E6100000010000000500000073309B00C3B44D402FC214E5D2024B4073309B00C3B44D40D34B8C65FA034B40475854C4E9B64D40D34B8C65FA034B40475854C4E9B64D402FC214E5D2024B4073309B00C3B44D402FC214E5D2024B40
44229	6295	60.248747999999999	60.257049000000002	53.939593000000002	53.932749000000001	Мира	0103000020E61000000100000005000000037976F9D61F4E403830B95164F74A40037976F9D61F4E4078465B9544F84A40193C4CFBE6204E4078465B9544F84A40193C4CFBE6204E403830B95164F74A40037976F9D61F4E403830B95164F74A40
43981	5786	58.901876999999999	58.916843	53.708384000000002	53.693154	Школьная	0103000020E61000000100000005000000DE019EB470734D40B98B3045B9D84A40DE019EB470734D403D81B053ACDA4A408448861C5B754D403D81B053ACDA4A408448861C5B754D40B98B3045B9D84A40DE019EB470734D40B98B3045B9D84A40
44238	6449	60.070433000000001	60.089216999999998	53.951410000000003	53.941468999999998	Школьная	0103000020E6100000010000000500000093C7D3F203094E405299620E82F84A4093C7D3F203094E402F8B89CDC7F94A40A59F70766B0B4E402F8B89CDC7F94A40A59F70766B0B4E405299620E82F84A4093C7D3F203094E405299620E82F84A40
44112	7094	59.670934000000003	59.698844999999999	54.052190000000003	54.034103000000002	Советская	0103000020E6100000010000000500000022E3512AE1D54D4006D9B27C5D044B4022E3512AE1D54D40D1967329AE064B408FFCC1C073D94D40D1967329AE064B408FFCC1C073D94D4006D9B27C5D044B4022E3512AE1D54D4006D9B27C5D044B40
42800	46396	59.181783000000003	59.212488	53.724167000000001	53.693393999999998	Ленина	0103000020E6100000010000000500000001FC53AA44974D400E9F7422C1D84A4001FC53AA44974D40D5EB1681B1DC4A406F6589CE329B4D40D5EB1681B1DC4A406F6589CE329B4D400E9F7422C1D84A4001FC53AA44974D400E9F7422C1D84A40
44233	46085	59.784553000000002	59.790202999999998	53.821224999999998	53.809136000000002	Российская	0103000020E61000000100000005000000467D923B6CE44D401502B9C491E74A40467D923B6CE44D402CD49AE61DE94A40BD19355F25E54D402CD49AE61DE94A40BD19355F25E54D401502B9C491E74A40467D923B6CE44D401502B9C491E74A40
43599	5753	58.844996000000002	58.885061	53.602206000000002	53.590122999999998	Братьев Каширинных	0103000020E610000001000000050000001BA034D4286C4D4007CF842689CB4A401BA034D4286C4D403DBA111615CD4A4087FBC8AD49714D403DBA111615CD4A4087FBC8AD49714D4007CF842689CB4A401BA034D4286C4D4007CF842689CB4A40
44243	7317	59.330167000000003	59.345545999999999	53.894266999999999	53.887087999999999	Школьная	0103000020E61000000100000005000000F69B89E942AA4D4047567E198CF14A40F69B89E942AA4D402E724F5777F24A40BEA1F0D93AAC4D402E724F5777F24A40BEA1F0D93AAC4D4047567E198CF14A40F69B89E942AA4D4047567E198CF14A40
43811	7388	59.240479000000001	59.253155	54.009146999999999	53.996206999999998	Советская	0103000020E61000000100000005000000F92F1004C89E4D40EC8502B683FF4A40F92F1004C89E4D40A2ED98BA2B014B40D1E80E6267A04D40A2ED98BA2B014B40D1E80E6267A04D40EC8502B683FF4A40F92F1004C89E4D40EC8502B683FF4A40
43802	2024	59.341386999999997	59.349345999999997	53.623899000000002	53.620266999999998	Ветеранов	0103000020E61000000100000005000000C823B891B2AB4D40DEE4B7E864CF4A40C823B891B2AB4D40E98024ECDBCF4A40847EA65EB7AC4D40E98024ECDBCF4A40847EA65EB7AC4D40DEE4B7E864CF4A40C823B891B2AB4D40DEE4B7E864CF4A40
43809	6627	59.414555	59.427867999999997	53.848759999999999	53.843299000000002	Солнечная	0103000020E6100000010000000500000057B2632310B54D40F0DFBC38F1EB4A4057B2632310B54D409413ED2AA4EC4A40A180ED60C4B64D409413ED2AA4EC4A40A180ED60C4B64D40F0DFBC38F1EB4A4057B2632310B54D40F0DFBC38F1EB4A40
44234	46130	59.643931000000002	59.658456999999999	53.858150000000002	53.850012999999997	Российская	0103000020E61000000100000005000000B7F0BC546CD24D406116DA39CDEC4A40B7F0BC546CD24D40FD87F4DBD7ED4A404069A85148D44D40FD87F4DBD7ED4A404069A85148D44D406116DA39CDEC4A40B7F0BC546CD24D406116DA39CDEC4A40
42919	46155	60.086297000000002	60.137546	54.028249000000002	54.007258	Клубная	0103000020E61000000100000005000000185FB4C70B0B4E40335184D4ED004B40185FB4C70B0B4E408692C9A99D034B400AD9791B9B114E408692C9A99D034B400AD9791B9B114E40335184D4ED004B40185FB4C70B0B4E40335184D4ED004B40
43812	7180	59.482574999999997	59.48854	53.986742999999997	53.982846000000002	Уральская	0103000020E61000000100000005000000006F8104C5BD4D409180D1E5CDFD4A40006F8104C5BD4D40494739984DFE4A40D8648D7A88BE4D40494739984DFE4A40D8648D7A88BE4D409180D1E5CDFD4A40006F8104C5BD4D409180D1E5CDFD4A40
43806	6343	60.262591999999998	60.270128	53.888229000000003	53.882703999999997	Школьная	0103000020E610000001000000050000007A185A9D9C214E403106D671FCF04A407A185A9D9C214E40ED2DE57CB1F14A40F0DDE68D93224E40ED2DE57CB1F14A40F0DDE68D93224E403106D671FCF04A407A185A9D9C214E403106D671FCF04A40
44288	47284	59.405957999999998	59.412712999999997	53.637577999999998	53.630156999999997	Солнечная	0103000020E6100000010000000500000058C6866EF6B34D40382C0DFCA8D04A4058C6866EF6B34D401553E9279CD14A4028D192C7D3B44D401553E9279CD14A4028D192C7D3B44D40382C0DFCA8D04A4058C6866EF6B34D40382C0DFCA8D04A40
44237	6270	59.913857	59.924042999999998	53.972875000000002	53.965978999999997	Степная	0103000020E610000001000000050000003F1C2444F9F44D40B7CF2A33A5FB4A403F1C2444F9F44D404A0C022B87FC4A40828C800A47F64D404A0C022B87FC4A40828C800A47F64D40B7CF2A33A5FB4A403F1C2444F9F44D40B7CF2A33A5FB4A40
44110	6764	59.295707999999998	59.311554000000001	53.764712000000003	53.751175000000003	Молодежная	0103000020E6100000010000000500000031957EC2D9A54D4052499D8026E04A4031957EC2D9A54D40EC6D3315E2E14A4010786000E1A74D40EC6D3315E2E14A4010786000E1A74D4052499D8026E04A4031957EC2D9A54D4052499D8026E04A40
43813	7450	59.257035000000002	59.270868999999998	53.956777000000002	53.946058000000001	Клубная	0103000020E61000000100000005000000B476DB85E6A04D40410FB56D18F94A40B476DB85E6A04D40524832AB77FA4A400740DCD5ABA24D40524832AB77FA4A400740DCD5ABA24D40410FB56D18F94A40B476DB85E6A04D40410FB56D18F94A40
43362	55148	59.360394999999997	59.394361000000004	54.159241999999999	54.129717999999997	Центральная	0103000020E610000001000000050000002A52616C21AE4D40ECD973999A104B402A52616C21AE4D402713B70A62144B40B0E8D66B7AB24D402713B70A62144B40B0E8D66B7AB24D40ECD973999A104B402A52616C21AE4D40ECD973999A104B40
43441	55148	59.360394999999997	59.394361000000004	54.159241999999999	54.129717999999997	Спортивная	0103000020E610000001000000050000002A52616C21AE4D40ECD973999A104B402A52616C21AE4D402713B70A62144B40B0E8D66B7AB24D402713B70A62144B40B0E8D66B7AB24D40ECD973999A104B402A52616C21AE4D40ECD973999A104B40
43405	55148	59.360394999999997	59.394361000000004	54.159241999999999	54.129717999999997	Ленина	0103000020E610000001000000050000002A52616C21AE4D40ECD973999A104B402A52616C21AE4D402713B70A62144B40B0E8D66B7AB24D402713B70A62144B40B0E8D66B7AB24D40ECD973999A104B402A52616C21AE4D40ECD973999A104B40
44242	6974	58.959702	58.989570999999998	53.826673	53.811194	Московская	0103000020E61000000100000005000000F1F3DF83D77A4D40105B7A34D5E74A40F1F3DF83D77A4D403CBEBD6BD0E94A40F6083543AA7E4D403CBEBD6BD0E94A40F6083543AA7E4D40105B7A34D5E74A40F1F3DF83D77A4D40105B7A34D5E74A40
43985	45908	59.303209000000003	59.316305999999997	54.072557000000003	54.064568000000001	Школьная	0103000020E610000001000000050000002B6D718DCFA64D401F2FA4C343084B402B6D718DCFA64D40460C3B8C49094B40A8C30AB77CA84D40460C3B8C49094B40A8C30AB77CA84D401F2FA4C343084B402B6D718DCFA64D401F2FA4C343084B40
44217	46334	60.263193000000001	60.274538999999997	54.000070999999998	53.992497	Юбилейная	0103000020E61000000100000005000000A0C4E74EB0214E40663046240AFF4A40A0C4E74EB0214E40C956975302004B40FF3C0D1824234E40C956975302004B40FF3C0D1824234E40663046240AFF4A40A0C4E74EB0214E40663046240AFF4A40
44115	6208	59.911602000000002	59.918922999999999	54.034103000000002	54.026339999999998	Школьная	0103000020E61000000100000005000000EE7BD45FAFF44D40CF49EF1B5F034B40EE7BD45FAFF44D4006D9B27C5D044B406745D4449FF54D4006D9B27C5D044B406745D4449FF54D40CF49EF1B5F034B40EE7BD45FAFF44D40CF49EF1B5F034B40
42917	5824	59.656103000000002	59.677177	53.927129999999998	53.907217000000003	Советская	0103000020E610000001000000050000005CE7DF2EFBD34D4008B0C8AF1FF44A405CE7DF2EFBD34D40FB912232ACF64A403C4D66BCADD64D40FB912232ACF64A403C4D66BCADD64D4008B0C8AF1FF44A405CE7DF2EFBD34D4008B0C8AF1FF44A40
44106	46174	60.114485999999999	60.125230000000002	54.078600000000002	54.070664999999998	Школьная	0103000020E61000000100000005000000C8EC2C7AA70E4E4065FCFB8C0B094B40C8EC2C7AA70E4E4099BB96900F0A4B40323D618907104E4099BB96900F0A4B40323D618907104E4065FCFB8C0B094B40C8EC2C7AA70E4E4065FCFB8C0B094B40
43998	46569	59.105255999999997	59.115281000000003	53.801175999999998	53.788581999999998	Центральная	0103000020E6100000010000000500000098DA5207798D4D406D1B4641F0E44A4098DA5207798D4D40882B67EF8CE64A40D36C1E87C18E4D40882B67EF8CE64A40D36C1E87C18E4D406D1B4641F0E44A4098DA5207798D4D406D1B4641F0E44A40
43509	5622	58.929527999999998	58.963420999999997	53.646102999999997	53.631507999999997	Юбилейная	0103000020E61000000100000005000000AF5B04C6FA764D40C8940F41D5D04A40AF5B04C6FA764D407A6CCB80B3D24A40CAA31B61517B4D407A6CCB80B3D24A40CAA31B61517B4D40C8940F41D5D04A40AF5B04C6FA764D40C8940F41D5D04A40
43808	6445	59.906751	59.922885000000001	54.106085999999998	54.098621000000001	Центральная	0103000020E61000000100000005000000C24EB16A10F44D4073D9E89C9F0C4B40C24EB16A10F44D401F48DE39940D4B40077C7E1821F64D401F48DE39940D4B40077C7E1821F64D4073D9E89C9F0C4B40C24EB16A10F44D4073D9E89C9F0C4B40
44240	5347	59.500515	59.531362999999999	54.131031999999998	54.103304000000001	микрорайон Карагайский Бор	0103000020E61000000100000005000000271422E010C04D40E3C5C210390D4B40271422E010C04D405F5D15A8C5104B40F8A6E9B303C44D405F5D15A8C5104B40F8A6E9B303C44D40E3C5C210390D4B40271422E010C04D40E3C5C210390D4B40
42795	5347	59.500515	59.531362999999999	54.131031999999998	54.103304000000001	Советская	0103000020E61000000100000005000000271422E010C04D40E3C5C210390D4B40271422E010C04D405F5D15A8C5104B40F8A6E9B303C44D405F5D15A8C5104B40F8A6E9B303C44D40E3C5C210390D4B40271422E010C04D40E3C5C210390D4B40
43977	5657	58.982025	58.995373999999998	53.683919000000003	53.669347000000002	Молодежная	0103000020E610000001000000050000005D6DC5FEB27D4D407E569929ADD54A405D6DC5FEB27D4D40780E65A88AD74A40F4A44C6A687F4D40780E65A88AD74A40F4A44C6A687F4D407E569929ADD54A405D6DC5FEB27D4D407E569929ADD54A40
43991	46414	59.216081000000003	59.225009999999997	53.619064999999999	53.612132000000003	Ленина	0103000020E61000000100000005000000BC24CE8AA89B4D40E46A64575ACE4A40BC24CE8AA89B4D40938C9C853DCF4A40F0A2AF20CD9C4D40938C9C853DCF4A40F0A2AF20CD9C4D40E46A64575ACE4A40BC24CE8AA89B4D40E46A64575ACE4A40
43987	46682	59.163404	59.179366999999999	53.845488000000003	53.834394000000003	Набережная	0103000020E610000001000000050000008E041A6CEA944D4044FD2E6CCDEA4A408E041A6CEA944D408A9466F338EC4A40A67D737FF5964D408A9466F338EC4A40A67D737FF5964D4044FD2E6CCDEA4A408E041A6CEA944D4044FD2E6CCDEA4A40
43804	6010	59.742942999999997	59.757199	54.001621999999998	53.989919	Молодежная	0103000020E6100000010000000500000064E597C118DF4D40325871AAB5FE4A4064E597C118DF4D40207A522635004B402EC896E5EBE04D40207A522635004B402EC896E5EBE04D40325871AAB5FE4A4064E597C118DF4D40325871AAB5FE4A40
44241	6864	58.969107000000001	58.993451999999998	53.907535000000003	53.898797999999999	Мира	0103000020E610000001000000050000008FA9BBB20B7C4D40E8DA17D00BF34A408FA9BBB20B7C4D40D97C5C1B2AF44A40A912656F297F4D40D97C5C1B2AF44A40A912656F297F4D40E8DA17D00BF34A408FA9BBB20B7C4D40E8DA17D00BF34A40
44111	7007	59.113799	59.140757000000001	53.936540000000001	53.901620999999999	Школьная	0103000020E61000000100000005000000A4A833F7908E4D408331225168F34A40A4A833F7908E4D40ABB2EF8AE0F74A406FD74B5304924D40ABB2EF8AE0F74A406FD74B5304924D408331225168F34A40A4A833F7908E4D408331225168F34A40
43334	55145	59.186903999999998	59.246569999999998	53.898066	53.852186000000003	Советская	0103000020E61000000100000005000000ECBE6378EC974D40F60D4C6E14ED4A40ECBE6378EC974D4024D3A1D3F3F24A405D16139B8F9F4D4024D3A1D3F3F24A405D16139B8F9F4D40F60D4C6E14ED4A40ECBE6378EC974D40F60D4C6E14ED4A40
43380	55145	59.186903999999998	59.246569999999998	53.898066	53.852186000000003	Розы Люксембург	0103000020E61000000100000005000000ECBE6378EC974D40F60D4C6E14ED4A40ECBE6378EC974D4024D3A1D3F3F24A405D16139B8F9F4D4024D3A1D3F3F24A405D16139B8F9F4D40F60D4C6E14ED4A40ECBE6378EC974D40F60D4C6E14ED4A40
43348	55145	59.186903999999998	59.246569999999998	53.898066	53.852186000000003	Мира	0103000020E61000000100000005000000ECBE6378EC974D40F60D4C6E14ED4A40ECBE6378EC974D4024D3A1D3F3F24A405D16139B8F9F4D4024D3A1D3F3F24A405D16139B8F9F4D40F60D4C6E14ED4A40ECBE6378EC974D40F60D4C6E14ED4A40
43291	55145	59.186903999999998	59.246569999999998	53.898066	53.852186000000003	Еремина	0103000020E61000000100000005000000ECBE6378EC974D40F60D4C6E14ED4A40ECBE6378EC974D4024D3A1D3F3F24A405D16139B8F9F4D4024D3A1D3F3F24A405D16139B8F9F4D40F60D4C6E14ED4A40ECBE6378EC974D40F60D4C6E14ED4A40
43982	6890	59.010466000000001	59.014850000000003	53.872236000000001	53.851416	Садовая	0103000020E6100000010000000500000027DC2BF356814D4044A51133FBEC4A4027DC2BF356814D406A32E36DA5EF4A403D2CD49AE6814D406A32E36DA5EF4A403D2CD49AE6814D4044A51133FBEC4A4027DC2BF356814D4044A51133FBEC4A40
44230	309	59.298268	59.316296999999999	53.549500000000002	53.540419999999997	Школьная	0103000020E61000000100000005000000BFB854A52DA64D405A0D897B2CC54A40BFB854A52DA64D407593180456C64A4055698B6B7CA84D407593180456C64A4055698B6B7CA84D405A0D897B2CC54A40BFB854A52DA64D405A0D897B2CC54A40
43820	55181	59.314824000000002	59.332934000000002	54.128630999999999	54.121597999999999	Верхняя	0103000020E610000001000000050000007AFF1F274CA84D4027A1F485900F4B407AFF1F274CA84D403A2009FB76104B40FDDCD0949DAA4D403A2009FB76104B40FDDCD0949DAA4D4027A1F485900F4B407AFF1F274CA84D4027A1F485900F4B40
43526	13169	60.724666999999997	60.745930000000001	53.349837999999998	53.341613000000002	Уральская	0103000020E61000000100000005000000C6BE64E3C15C4E40B9718BF9B9AB4A40C6BE64E3C15C4E40F372D87DC7AC4A407A8D5DA27A5F4E40F372D87DC7AC4A407A8D5DA27A5F4E40B9718BF9B9AB4A40C6BE64E3C15C4E40B9718BF9B9AB4A40
43899	13147	60.660643999999998	60.674836999999997	53.336827999999997	53.329734999999999	Центральная	0103000020E6100000010000000500000039268BFB8F544E405CACA8C134AA4A4039268BFB8F544E4044300E2E1DAB4A40BC900E0F61564E4044300E2E1DAB4A40BC900E0F61564E405CACA8C134AA4A4039268BFB8F544E405CACA8C134AA4A40
43995	12625	61.114652999999997	61.126753000000001	53.557828999999998	53.546038000000003	Южная	0103000020E61000000100000005000000B3B112F3AC8E4E40C72FBC92E4C54A40B3B112F3AC8E4E4054E1CFF066C74A40BFD53A7139904E4054E1CFF066C74A40BFD53A7139904E40C72FBC92E4C54A40B3B112F3AC8E4E40C72FBC92E4C54A40
43994	12625	61.114652999999997	61.126753000000001	53.557828999999998	53.546038000000003	Привокзальная	0103000020E61000000100000005000000B3B112F3AC8E4E40C72FBC92E4C54A40B3B112F3AC8E4E4054E1CFF066C74A40BFD53A7139904E4054E1CFF066C74A40BFD53A7139904E40C72FBC92E4C54A40B3B112F3AC8E4E40C72FBC92E4C54A40
43836	12311	61.268624000000003	61.288170999999998	53.049523999999998	53.042377999999999	Центральная	0103000020E61000000100000005000000DA756F4562A24E40F2086EA46C854A40DA756F4562A24E40FD2E6CCD56864A40EB538EC9E2A44E40FD2E6CCD56864A40EB538EC9E2A44E40F2086EA46C854A40DA756F4562A24E40F2086EA46C854A40
43862	12904	60.831035999999997	60.847996999999999	53.419029999999999	53.414220999999998	Уральская	0103000020E610000001000000050000003AE63C635F6A4E408028983105B54A403AE63C635F6A4E407D0569C6A2B54A40950D6B2A8B6C4E407D0569C6A2B54A40950D6B2A8B6C4E408028983105B54A403AE63C635F6A4E408028983105B54A40
43697	12890	60.754716000000002	60.776696999999999	53.419040000000003	53.403325000000002	переулок Школьный	0103000020E610000001000000050000004CE2AC889A604E4061545227A0B34A404CE2AC889A604E40A1DB4B1AA3B54A405EF3AACE6A634E40A1DB4B1AA3B54A405EF3AACE6A634E4061545227A0B34A404CE2AC889A604E4061545227A0B34A40
43524	13094	61.143416999999999	61.162523999999998	53.310603	53.291127000000003	Советская	0103000020E610000001000000050000006058FE7C5B924E40C6FD47A643A54A406058FE7C5B924E400E85CFD6C1A74A4055682096CD944E400E85CFD6C1A74A4055682096CD944E40C6FD47A643A54A406058FE7C5B924E40C6FD47A643A54A40
44126	12522	61.253729999999997	61.267724999999999	53.246881000000002	53.236533999999999	Школьная	0103000020E61000000100000005000000CD0182397AA04E402F3201BF469E4A40CD0182397AA04E407C80EECB999F4A402AA913D044A24E407C80EECB999F4A402AA913D044A24E402F3201BF469E4A40CD0182397AA04E402F3201BF469E4A40
44317	55238	61.336616999999997	61.347002000000003	53.050812999999998	53.045822000000001	Набережная	0103000020E6100000010000000500000089230F4416AB4E40FAB7CB7EDD854A4089230F4416AB4E40179B560A81864A40C4D2C08F6AAC4E40179B560A81864A40C4D2C08F6AAC4E40FAB7CB7EDD854A4089230F4416AB4E40FAB7CB7EDD854A40
43541	12706	61.995081999999996	62.022875999999997	53.042350999999996	53.029013999999997	Набережная	0103000020E610000001000000050000004C6BD3D85EFF4E40259012BBB6834A404C6BD3D85EFF4E40F8F9EFC16B854A4080EECB99ED024F40F8F9EFC16B854A4080EECB99ED024F40259012BBB6834A404C6BD3D85EFF4E40259012BBB6834A40
43876	11462	61.611339999999998	61.632818999999998	53.014319	53.00526	Советская	0103000020E610000001000000050000004A5E9D6340CE4E400DFD135CAC804A404A5E9D6340CE4E40105B7A34D5814A40CAA4863600D14E40105B7A34D5814A40CAA4863600D14E400DFD135CAC804A404A5E9D6340CE4E400DFD135CAC804A40
43587	12545	61.030157000000003	61.064732999999997	53.573951999999998	53.564000999999998	Юбилейная	0103000020E610000001000000050000006C5F402FDC834E40A5F44C2F31C84A406C5F402FDC834E40A5BC564277C94A4069FCC22B49884E40A5BC564277C94A4069FCC22B49884E40A5F44C2F31C84A406C5F402FDC834E40A5F44C2F31C84A40
43654	12461	61.409480000000002	61.438288999999997	53.168863999999999	53.155982000000002	Завалищина	0103000020E61000000100000005000000DC2E34D769B44E40E161DA37F7934A40DC2E34D769B44E4062BCE6559D954A4028999CDA19B84E4062BCE6559D954A4028999CDA19B84E40E161DA37F7934A40DC2E34D769B44E40E161DA37F7934A40
43696	12172	61.148465000000002	61.175370000000001	53.012357999999999	53.001797000000003	Гагарина	0103000020E61000000100000005000000E2CCAFE600934E408F1D54E23A804A40E2CCAFE600934E4007EC6AF294814A408A592F8672964E4007EC6AF294814A408A592F8672964E408F1D54E23A804A40E2CCAFE600934E408F1D54E23A804A40
43992	11951	60.942131000000003	60.950944	53.301208000000003	53.292149999999999	Озерная	0103000020E610000001000000050000001EC6A4BF97784E4061C3D32B65A54A401EC6A4BF97784E4094A5D6FB8DA64A40E9297288B8794E4094A5D6FB8DA64A40E9297288B8794E4061C3D32B65A54A401EC6A4BF97784E4061C3D32B65A54A40
44249	12836	60.689435000000003	60.699854999999999	53.423366000000001	53.418069000000003	переулок Школьный	0103000020E61000000100000005000000E0DBF4673F584E40583CF54883B54A40E0DBF4673F584E40821E6ADB30B64A40967840D994594E40821E6ADB30B64A40967840D994594E40583CF54883B54A40E0DBF4673F584E40583CF54883B54A40
44213	11912	61.007590999999998	61.038772000000002	53.286352999999998	53.274588999999999	Труда	0103000020E61000000100000005000000395FECBDF8804E40B16B7BBB25A34A40395FECBDF8804E40450E1137A7A44A4011001C7BF6844E40450E1137A7A44A4011001C7BF6844E40B16B7BBB25A34A40395FECBDF8804E40B16B7BBB25A34A40
43863	12414	61.516747000000002	61.522900999999997	53.19905	53.196492999999997	Центральная	0103000020E610000001000000050000002FA704C424C24E404B72C0AE26994A402FA704C424C24E4068226C787A994A40D905836BEEC24E4068226C787A994A40D905836BEEC24E404B72C0AE26994A402FA704C424C24E404B72C0AE26994A40
44124	11826	61.197073000000003	61.207287000000001	53.174477000000003	53.169663	Школьная	0103000020E610000001000000050000005AF624B039994E40AE2B6684B7954A405AF624B039994E40BD73284355964A4067F16261889A4E40BD73284355964A4067F16261889A4E40AE2B6684B7954A405AF624B039994E40AE2B6684B7954A40
44257	12133	61.189760999999997	61.199382	53.118254	53.111708999999998	Целинная	0103000020E610000001000000050000003387A4164A984E409DD5027B4C8E4A403387A4164A984E40834F73F2228F4A409EB4705985994E40834F73F2228F4A409EB4705985994E409DD5027B4C8E4A403387A4164A984E409DD5027B4C8E4A40
43866	11806	61.205857999999999	61.239446000000001	53.509543999999998	53.500199000000002	Центральная	0103000020E610000001000000050000005BCF108E599A4E40F73E558506C04A405BCF108E599A4E40BFEFDFBC38C14A403A94A12AA69E4E40BFEFDFBC38C14A403A94A12AA69E4E40F73E558506C04A405BCF108E599A4E40F73E558506C04A40
43870	13031	61.076241000000003	61.093955000000001	53.464329999999997	53.453774000000003	Центральная	0103000020E61000000100000005000000A3CEDC43C2894E4037E3344415BA4A40A3CEDC43C2894E409D465A2A6FBB4A40D925AAB7068C4E409D465A2A6FBB4A40D925AAB7068C4E4037E3344415BA4A40A3CEDC43C2894E4037E3344415BA4A40
43673	12772	60.912244000000001	60.928845000000003	53.557572	53.553319999999999	Центральная	0103000020E6100000010000000500000072FC5069C4744E40821C9430D3C64A4072FC5069C4744E402995F0845EC74A40CD069964E4764E402995F0845EC74A40CD069964E4764E40821C9430D3C64A4072FC5069C4744E40821C9430D3C64A40
43993	12080	61.123320999999997	61.144917	53.001716000000002	52.990729999999999	Гоголя	0103000020E610000001000000050000007BF486FBC88F4E4042959A3DD07E4A407BF486FBC88F4E40A2F0D93A38804A4035D1E7A38C924E40A2F0D93A38804A4035D1E7A38C924E4042959A3DD07E4A407BF486FBC88F4E4042959A3DD07E4A40
44125	12364	61.395977999999999	61.412390000000002	53.050704000000003	53.044424999999997	Школьная	0103000020E61000000100000005000000BEF73768AFB24E40F90FE9B7AF854A40BEF73768AFB24E4061E3FA777D864A4046990D32C9B44E4061E3FA777D864A4046990D32C9B44E40F90FE9B7AF854A40BEF73768AFB24E40F90FE9B7AF854A40
42961	6015	60.948734000000002	61.004671999999999	53.402321000000001	53.361414000000003	Спартак	0103000020E61000000100000005000000384D9F1D70794E4085285FD042AE4A40384D9F1D70794E403CBF28417FB34A407C9A931799804E403CBF28417FB34A407C9A931799804E4085285FD042AE4A40384D9F1D70794E4085285FD042AE4A40
42660	6015	60.948734000000002	61.004671999999999	53.402321000000001	53.361414000000003	Советская	0103000020E61000000100000005000000384D9F1D70794E4085285FD042AE4A40384D9F1D70794E403CBF28417FB34A407C9A931799804E403CBF28417FB34A407C9A931799804E4085285FD042AE4A40384D9F1D70794E4085285FD042AE4A40
43582	6015	60.948734000000002	61.004671999999999	53.402321000000001	53.361414000000003	Пугачева	0103000020E61000000100000005000000384D9F1D70794E4085285FD042AE4A40384D9F1D70794E403CBF28417FB34A407C9A931799804E403CBF28417FB34A407C9A931799804E4085285FD042AE4A40384D9F1D70794E4085285FD042AE4A40
42662	6015	60.948734000000002	61.004671999999999	53.402321000000001	53.361414000000003	Пролетарская	0103000020E61000000100000005000000384D9F1D70794E4085285FD042AE4A40384D9F1D70794E403CBF28417FB34A407C9A931799804E403CBF28417FB34A407C9A931799804E4085285FD042AE4A40384D9F1D70794E4085285FD042AE4A40
43020	6015	60.948734000000002	61.004671999999999	53.402321000000001	53.361414000000003	Магнитогорская	0103000020E61000000100000005000000384D9F1D70794E4085285FD042AE4A40384D9F1D70794E403CBF28417FB34A407C9A931799804E403CBF28417FB34A407C9A931799804E4085285FD042AE4A40384D9F1D70794E4085285FD042AE4A40
43183	6015	60.948734000000002	61.004671999999999	53.402321000000001	53.361414000000003	Ленина	0103000020E61000000100000005000000384D9F1D70794E4085285FD042AE4A40384D9F1D70794E403CBF28417FB34A407C9A931799804E403CBF28417FB34A407C9A931799804E4085285FD042AE4A40384D9F1D70794E4085285FD042AE4A40
43012	11507	60.745804	60.774864999999998	53.545209	53.536470999999999	Школьная	0103000020E61000000100000005000000ED9C6681765F4E404F20EC14ABC44A40ED9C6681765F4E40103E9468C9C54A4053E8BCC62E634E40103E9468C9C54A4053E8BCC62E634E404F20EC14ABC44A40ED9C6681765F4E404F20EC14ABC44A40
43996	12759	60.907240999999999	60.929312000000003	53.447167	53.442812000000004	Школьная	0103000020E61000000100000005000000904B1C7920744E4060234910AEB84A40904B1C7920744E40DB6CACC43CB94A40E3E313B2F3764E40DB6CACC43CB94A40E3E313B2F3764E4060234910AEB84A40904B1C7920744E4060234910AEB84A40
44123	12032	61.053783000000003	61.061354999999999	53.086593999999998	53.081260999999998	Центральная	0103000020E61000000100000005000000570A815CE2864E405AB8ACC2668A4A40570A815CE2864E40D1031F83158B4A4019390B7BDA874E40D1031F83158B4A4019390B7BDA874E405AB8ACC2668A4A40570A815CE2864E405AB8ACC2668A4A40
43164	11409	61.776072999999997	61.807378999999997	53.081108999999998	53.068196	Центральная	0103000020E6100000010000000500000080272D5C56E34E40E8DB82A5BA884A4080272D5C56E34E40A4349BC7618A4A40143DF03158E74E40A4349BC7618A4A40143DF03158E74E40E8DB82A5BA884A4080272D5C56E34E40E8DB82A5BA884A40
44232	13013	61.135250999999997	61.156010999999999	53.390455000000003	53.379133000000003	Центральная	0103000020E610000001000000050000002AE09EE74F914E40CDEA1D6E87B04A402AE09EE74F914E40A4C7EF6DFAB14A407B681F2BF8934E40A4C7EF6DFAB14A407B681F2BF8934E40CDEA1D6E87B04A402AE09EE74F914E40CDEA1D6E87B04A40
43622	11251	61.444721000000001	61.473942999999998	53.557566999999999	53.547387000000001	Школьная	0103000020E61000000100000005000000166C239EECB84E40B6A0F7C610C64A40166C239EECB84E40172AFF5A5EC74A4085950A2AAABC4E40172AFF5A5EC74A4085950A2AAABC4E40B6A0F7C610C64A40166C239EECB84E40B6A0F7C610C64A40
44209	11369	61.684849	61.704971	53.140994999999997	53.132038999999999	Советская	0103000020E6100000010000000500000062D9CC21A9D74E40F56569A7E6904A4062D9CC21A9D74E4023F3C81F0C924A4070D05E7D3CDA4E4023F3C81F0C924A4070D05E7D3CDA4E40F56569A7E6904A4062D9CC21A9D74E40F56569A7E6904A40
44298	11369	61.684849	61.704971	53.140994999999997	53.132038999999999	Набережная	0103000020E6100000010000000500000062D9CC21A9D74E40F56569A7E6904A4062D9CC21A9D74E4023F3C81F0C924A4070D05E7D3CDA4E4023F3C81F0C924A4070D05E7D3CDA4E40F56569A7E6904A4062D9CC21A9D74E40F56569A7E6904A40
44013	11302	61.657181000000001	61.671948999999998	53.218465000000002	53.210828999999997	Пролетарская	0103000020E61000000100000005000000BB46CB811ED44E403106D671FC9A4A40BB46CB811ED44E400B293FA9F69B4A403ACAC16C02D64E400B293FA9F69B4A403ACAC16C02D64E403106D671FC9A4A40BB46CB811ED44E403106D671FC9A4A40
43828	10899	60.641545999999998	60.664254999999997	52.470179000000002	52.450074000000001	Садовая	0103000020E610000001000000050000009770E82D1E524E40D4635B069C394A409770E82D1E524E400C2252D32E3C4A402C9ACE4E06554E400C2252D32E3C4A402C9ACE4E06554E40D4635B069C394A409770E82D1E524E40D4635B069C394A40
43829	11206	60.104478999999998	60.116920999999998	52.571672999999997	52.563122999999997	Школьная	0103000020E61000000100000005000000340F60915F0D4E400D501A6A14484A40340F60915F0D4E40CB80B3942C494A40999B6F44F70E4E40CB80B3942C494A40999B6F44F70E4E400D501A6A14484A40340F60915F0D4E400D501A6A14484A40
44211	11113	60.028058999999999	60.038623999999999	52.019699000000003	52.015276	Центральная	0103000020E61000000100000005000000E2ADF36F97034E40F4346090F4014A40E2ADF36F97034E40C861307F85024A409C6B98A1F1044E40C861307F85024A409C6B98A1F1044E40F4346090F4014A40E2ADF36F97034E40F4346090F4014A40
44014	10633	60.329183999999998	60.335472000000003	52.611713000000002	52.606364999999997	Центральная	0103000020E61000000100000005000000E82E89B3222A4E4032384A5E9D4D4A40E82E89B3222A4E40DFC4909C4C4E4A40A35C1ABFF02A4E40DFC4909C4C4E4A40A35C1ABFF02A4E4032384A5E9D4D4A40E82E89B3222A4E4032384A5E9D4D4A40
42659	11178	60.130386000000001	60.16384	52.509895999999998	52.495956	Гатьятуллина	0103000020E610000001000000050000009AED0A7DB0104E40A320787C7B3F4A409AED0A7DB0104E403C2EAA4544414A4069E388B5F8144E403C2EAA4544414A4069E388B5F8144E40A320787C7B3F4A409AED0A7DB0104E40A320787C7B3F4A40
42817	11020	60.015878000000001	60.038992	52.093311	52.081888999999997	Молодежная	0103000020E61000000100000005000000EA5C514A08024E407973B8567B0A4A40EA5C514A08024E40B4AD669DF10B4A401F679AB0FD044E40B4AD669DF10B4A401F679AB0FD044E407973B8567B0A4A40EA5C514A08024E407973B8567B0A4A40
44246	10316	60.480972000000001	60.49062	52.387492999999999	52.383321000000002	Школьная	0103000020E610000001000000050000005725917D903D4E405D6F9BA910314A405725917D903D4E40E736E15E99314A40BB61DBA2CC3E4E40E736E15E99314A40BB61DBA2CC3E4E405D6F9BA910314A405725917D903D4E405D6F9BA910314A40
43990	10361	\N	\N	\N	\N	Целинная	\N
44212	10559	60.456960000000002	60.477370000000001	52.682704000000001	52.667715999999999	Школьная	0103000020E6100000010000000500000043CA4FAA7D3A4E400A82C7B777554A4043CA4FAA7D3A4E40986C3CD862574A40B70BCD751A3D4E40986C3CD862574A40B70BCD751A3D4E400A82C7B777554A4043CA4FAA7D3A4E400A82C7B777554A40
43038	10934	60.321466999999998	60.343367999999998	52.170186999999999	52.153078000000001	Новостройки	0103000020E6100000010000000500000022DFA5D425294E4059DE550F98134A4022DFA5D425294E40289A07B0C8154A40183F8D7BF32B4E40289A07B0C8154A40183F8D7BF32B4E4059DE550F98134A4022DFA5D425294E4059DE550F98134A40
44039	10532	60.202359000000001	60.228985999999999	52.714770999999999	52.701044000000003	Дорожная	0103000020E61000000100000005000000908653E6E6194E404D874ECFBB594A40908653E6E6194E408A90BA9D7D5B4A40F59ECA694F1D4E408A90BA9D7D5B4A40F59ECA694F1D4E404D874ECFBB594A40908653E6E6194E404D874ECFBB594A40
43703	9912	60.245010999999998	60.262044000000003	52.446863	52.436866000000002	Мира	0103000020E6100000010000000500000083143C855C1F4E40FF5D9F39EB374A4083143C855C1F4E406F6589CE32394A40780E65A88A214E406F6589CE32394A40780E65A88A214E40FF5D9F39EB374A4083143C855C1F4E40FF5D9F39EB374A40
42818	10220	60.402180999999999	60.430765000000001	52.395775	52.387811999999997	Школьный переулок	0103000020E610000001000000050000004A09C1AA7A334E40887FD8D2A3314A404A09C1AA7A334E4086C954C1A8324A4077A1B94E23374E4086C954C1A8324A4077A1B94E23374E40887FD8D2A3314A404A09C1AA7A334E40887FD8D2A3314A40
44136	10220	60.402180999999999	60.430765000000001	52.395775	52.387811999999997	Мира	0103000020E610000001000000050000004A09C1AA7A334E40887FD8D2A3314A404A09C1AA7A334E4086C954C1A8324A4077A1B94E23374E4086C954C1A8324A4077A1B94E23374E40887FD8D2A3314A404A09C1AA7A334E40887FD8D2A3314A40
44239	10049	61.004286	61.020249	52.337755999999999	52.323374999999999	Комсомольская	0103000020E6100000010000000500000053EA92718C804E4008AC1C5A64294A4053EA92718C804E408E03AF963B2B4A406B63EC8497824E408E03AF963B2B4A406B63EC8497824E4008AC1C5A64294A4053EA92718C804E4008AC1C5A64294A40
44060	10816	60.706485000000001	60.714561000000003	52.530116	52.525447999999997	 Центральная	0103000020E61000000100000005000000AA0EB9196E5A4E40D2DF4BE141434A40AA0EB9196E5A4E400D8B51D7DA434A40A0FF1EBC765B4E400D8B51D7DA434A40A0FF1EBC765B4E40D2DF4BE141434A40AA0EB9196E5A4E40D2DF4BE141434A40
44059	10990	60.192082999999997	60.199691000000001	52.285235999999998	52.280123000000003	Центральная	0103000020E610000001000000050000000C8FFD2C96184E40C0ED0912DB234A400C8FFD2C96184E4028D2FD9C82244A401C2785798F194E4028D2FD9C82244A401C2785798F194E40C0ED0912DB234A400C8FFD2C96184E40C0ED0912DB234A40
43501	10833	60.621684000000002	60.651625000000003	52.388866999999998	52.377631999999998	Горького	0103000020E6100000010000000500000026396057934F4E4027F6D03E56304A4026396057934F4E402FBFD364C6314A40C520B07268534E402FBFD364C6314A40C520B07268534E4027F6D03E56304A4026396057934F4E4027F6D03E56304A40
43591	10719	60.644474000000002	60.679068000000001	52.652613000000002	52.644412000000003	Генерала Григорьева	0103000020E61000000100000005000000A88FC01F7E524E403293A8177C524A40A88FC01F7E524E40E4F8A1D288534A404CE141B3EB564E40E4F8A1D288534A404CE141B3EB564E403293A8177C524A40A88FC01F7E524E403293A8177C524A40
42815	10640	59.670853000000001	59.712426999999998	52.525973999999998	52.499195999999998	пер. Школьный	0103000020E6100000010000000500000035B6D782DED54D40A2258FA7E53F4A4035B6D782DED54D40ED45B41D53434A40C9E4D4CE30DB4D40ED45B41D53434A40C9E4D4CE30DB4D40A2258FA7E53F4A4035B6D782DED54D40A2258FA7E53F4A40
44064	10742	60.52516	60.541392999999999	52.561075000000002	52.554248000000001	Дорожная	0103000020E610000001000000050000006C95607138434E40CCEF3499F1464A406C95607138434E4036CD3B4ED1474A4044A4A65D4C454E4036CD3B4ED1474A4044A4A65D4C454E40CCEF3499F1464A406C95607138434E40CCEF3499F1464A40
43997	10451	60.493493999999998	60.509960999999997	52.716118999999999	52.700678000000003	Пристационная	0103000020E61000000100000005000000D862B7CF2A3F4E406B8313D1AF594A40D862B7CF2A3F4E40A98592C9A95B4A40239EEC6646414E40A98592C9A95B4A40239EEC6646414E406B8313D1AF594A40D862B7CF2A3F4E406B8313D1AF594A40
44207	10267	60.531447999999997	60.542209999999997	52.382897999999997	52.378951000000001	Школьная	0103000020E6100000010000000500000026C3F17C06444E40ACE4637781304A4026C3F17C06444E4016DA39CD02314A4036C8242367454E4016DA39CD02314A4036C8242367454E40ACE4637781304A4026C3F17C06444E40ACE4637781304A40
44210	11082	60.157246000000001	60.167980999999997	52.099176	52.092382000000001	Школьная	0103000020E61000000100000005000000A2B60DA320144E409A5E622CD30B4A40A2B60DA320144E40284696CCB10C4A40B8ACC26680154E40284696CCB10C4A40B8ACC26680154E409A5E622CD30B4A40A2B60DA320144E409A5E622CD30B4A40
42674	9521	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	мкр. Черемушки	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
43181	9521	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	Фрунзе	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
43626	9521	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	Пушкина	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
43692	9521	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	Победы	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
42668	9521	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	Мира	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
43182	9521	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	Гербанова	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
43178	9521	60.310929999999999	60.382040000000003	52.434835	52.389097999999997	Аэродромная	0103000020E6100000010000000500000032ACE28DCC274E40317898F6CD314A4032ACE28DCC274E40FD135CACA8374A40C6E1CCAFE6304E40FD135CACA8374A40C6E1CCAFE6304E40317898F6CD314A4032ACE28DCC274E40317898F6CD314A40
42658	10427	60.416105000000002	60.444913999999997	52.666831000000002	52.658158	Мира	0103000020E61000000100000005000000DE59BBED42354E40E6CC76853E544A40DE59BBED42354E40C07ADCB75A554A402AC423F1F2384E40C07ADCB75A554A402AC423F1F2384E40E6CC76853E544A40DE59BBED42354E40E6CC76853E544A40
43499	10123	60.699730000000002	60.716977	52.235272999999999	52.224091999999999	Школьная	0103000020E61000000100000005000000DA03ADC090594E40CAA5F10BAF1C4A40DA03ADC090594E40DF50F86C1D1E4A40FA7DFFE6C55B4E40DF50F86C1D1E4A40FA7DFFE6C55B4E40CAA5F10BAF1C4A40DA03ADC090594E40CAA5F10BAF1C4A40
43691	10035	60.778044999999999	60.803620000000002	52.377828999999998	52.365732999999999	Садиковая	0103000020E610000001000000050000007DE882FA96634E40B308C556D02E4A407DE882FA96634E407D3D5FB35C304A40AD342905DD664E407D3D5FB35C304A40AD342905DD664E40B308C556D02E4A407DE882FA96634E40B308C556D02E4A40
44035	9948	59.605671999999998	59.629027999999998	52.589621000000001	52.566992999999997	Центральная	0103000020E610000001000000050000002C0DFCA886CD4D40CC07043A93484A402C0DFCA886CD4D40750470B3784B4A40572250FD83D04D40750470B3784B4A40572250FD83D04D40CC07043A93484A402C0DFCA886CD4D40CC07043A93484A40
43755	55170	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	Кирова	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
43438	55149	57.151249999999997	57.164634	55.082616999999999	55.070143999999999	Школьная	0103000020E610000001000000050000008FC2F5285C934C405C01857AFA884B408FC2F5285C934C40FC8BA031938A4B40A3E716BA12954C40FC8BA031938A4B40A3E716BA12954C405C01857AFA884B408FC2F5285C934C405C01857AFA884B40
43374	55149	57.151249999999997	57.164634	55.082616999999999	55.070143999999999	Нечепуренко	0103000020E610000001000000050000008FC2F5285C934C405C01857AFA884B408FC2F5285C934C40FC8BA031938A4B40A3E716BA12954C40FC8BA031938A4B40A3E716BA12954C405C01857AFA884B408FC2F5285C934C405C01857AFA884B40
43492	55149	57.151249999999997	57.164634	55.082616999999999	55.070143999999999	Мира	0103000020E610000001000000050000008FC2F5285C934C405C01857AFA884B408FC2F5285C934C40FC8BA031938A4B40A3E716BA12954C40FC8BA031938A4B40A3E716BA12954C405C01857AFA884B408FC2F5285C934C405C01857AFA884B40
43471	55155	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	Ленина	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
43228	55133	57.968465000000002	58.008412999999997	55.026885999999998	54.997295000000001	Свердлова	0103000020E610000001000000050000000B293FA9F6FB4C406FBBD05CA77F4B400B293FA9F6FB4C40315C1D0071834B403DEE5BAD13014D40315C1D0071834B403DEE5BAD13014D406FBBD05CA77F4B400B293FA9F6FB4C406FBBD05CA77F4B40
43566	55133	57.968465000000002	58.008412999999997	55.026885999999998	54.997295000000001	Рокутова	0103000020E610000001000000050000000B293FA9F6FB4C406FBBD05CA77F4B400B293FA9F6FB4C40315C1D0071834B403DEE5BAD13014D40315C1D0071834B403DEE5BAD13014D406FBBD05CA77F4B400B293FA9F6FB4C406FBBD05CA77F4B40
43724	55133	57.968465000000002	58.008412999999997	55.026885999999998	54.997295000000001	Ленина	0103000020E610000001000000050000000B293FA9F6FB4C406FBBD05CA77F4B400B293FA9F6FB4C40315C1D0071834B403DEE5BAD13014D40315C1D0071834B403DEE5BAD13014D406FBBD05CA77F4B400B293FA9F6FB4C406FBBD05CA77F4B40
43617	22367	60.429003999999999	60.460867999999998	55.240265999999998	55.226481999999997	Центральная	0103000020E6100000010000000500000035ED629AE9364E40FB90B75CFD9C4B4035ED629AE9364E409D2B4A09C19E4B40EFE2FDB8FD3A4E409D2B4A09C19E4B40EFE2FDB8FD3A4E40FB90B75CFD9C4B4035ED629AE9364E40FB90B75CFD9C4B40
43884	5250	60.521602999999999	60.539147	55.249802000000003	55.244397999999997	Школьная	0103000020E610000001000000050000006C3F19E3C3424E40999A046F489F4B406C3F19E3C3424E40DA3C0E83F99F4B40465ED6C402454E40DA3C0E83F99F4B40465ED6C402454E40999A046F489F4B406C3F19E3C3424E40999A046F489F4B40
43916	12961	60.811290999999997	60.824810999999997	55.249946000000001	55.239865999999999	Советская	0103000020E6100000010000000500000002452C62D8674E400FB6D8EDB39E4B4002452C62D8674E400DE2033BFE9F4B40C630276893694E400DE2033BFE9F4B40C630276893694E400FB6D8EDB39E4B4002452C62D8674E400FB6D8EDB39E4B40
44073	47947	60.804833000000002	60.828665000000001	55.365043999999997	55.358125000000001	Центральная	0103000020E61000000100000005000000ECDE8AC404674E40A4703D0AD7AD4B40ECDE8AC404674E40EECC04C3B9AE4B40802BD9B1116A4E40EECC04C3B9AE4B40802BD9B1116A4E40A4703D0AD7AD4B40ECDE8AC404674E40A4703D0AD7AD4B40
43615	2878	60.908704999999998	60.932537000000004	55.615161000000001	55.605097999999998	 Садовая	0103000020E61000000100000005000000185B087250744E400070ECD973CD4B40185B087250744E4028637C98BDCE4B40ADA7565F5D774E4028637C98BDCE4B40ADA7565F5D774E400070ECD973CD4B40185B087250744E400070ECD973CD4B40
44042	5306	60.393323000000002	60.412314000000002	55.316471999999997	55.309099000000003	Озёрная	0103000020E61000000100000005000000DFE1766858324E40F81C588E90A74B40DFE1766858324E40C30C8D2782A84B406BD784B4C6344E40C30C8D2782A84B406BD784B4C6344E40F81C588E90A74B40DFE1766858324E40F81C588E90A74B40
43761	24265	60.334214000000003	60.370595999999999	55.185749000000001	55.173744999999997	Набережная	0103000020E61000000100000005000000C4EE3B86C72A4E40F86BB2463D964B40C4EE3B86C72A4E40E2218C9FC6974B40A30392B06F2F4E40E2218C9FC6974B40A30392B06F2F4E40F86BB2463D964B40C4EE3B86C72A4E40F86BB2463D964B40
43912	13904	61.036301000000002	61.062469	55.549596999999999	55.543618000000002	Лесная	0103000020E61000000100000005000000F3E7DB82A5844E402BC24D4695C54B40F3E7DB82A5844E40677DCA3159C64B40C501F4FBFE874E40677DCA3159C64B40C501F4FBFE874E402BC24D4695C54B40F3E7DB82A5844E402BC24D4695C54B40
44069	27800	60.852415999999998	60.864831000000002	55.390542000000003	55.373336999999999	Труда	0103000020E61000000100000005000000274BADF71B6D4E4081B1BE81C9AF4B40274BADF71B6D4E4073DBBE47FDB14B4093C83EC8B26E4E4073DBBE47FDB14B4093C83EC8B26E4E4081B1BE81C9AF4B40274BADF71B6D4E4081B1BE81C9AF4B40
44235	47231	60.909486000000001	60.928691999999998	55.508692000000003	55.502380000000002	Северная	0103000020E61000000100000005000000BE1589096A744E400E15E3FC4DC04B40BE1589096A744E4051DEC7D11CC14B4046072461DF764E4051DEC7D11CC14B4046072461DF764E400E15E3FC4DC04B40BE1589096A744E400E15E3FC4DC04B40
43881	5150	60.511398	60.517919999999997	55.320509000000001	55.310606	Луговая	0103000020E61000000100000005000000B29E5A7D75414E407FF8F9EFC1A74B40B29E5A7D75414E406E895C7006A94B40DFF8DA334B424E406E895C7006A94B40DFF8DA334B424E407FF8F9EFC1A74B40B29E5A7D75414E407FF8F9EFC1A74B40
43614	23601	60.999290999999999	61.020840999999997	55.511750999999997	55.496955	Родниковая	0103000020E61000000100000005000000F4177AC4E87F4E40B64AB0389CBF4B40F4177AC4E87F4E40FF58880E81C14B403DB5FAEAAA824E40FF58880E81C14B403DB5FAEAAA824E40B64AB0389CBF4B40F4177AC4E87F4E40B64AB0389CBF4B40
44164	25865	60.983822000000004	61.003458999999999	55.358938999999999	55.344878999999999	Р.У.Кузыева	0103000020E61000000100000005000000EC8A19E1ED7D4E40E109BDFE24AC4B40EC8A19E1ED7D4E40252191B6F1AD4B403DF0315871804E40252191B6F1AD4B403DF0315871804E40E109BDFE24AC4B40EC8A19E1ED7D4E40E109BDFE24AC4B40
43771	11778	60.540179999999999	60.549055000000003	55.390045999999998	55.384681999999998	Полевая	0103000020E6100000010000000500000005FA449E24454E4010AE80423DB14B4005FA449E24454E40C2F7FE06EDB14B40475A2A6F47464E40C2F7FE06EDB14B40475A2A6F47464E4010AE80423DB14B4005FA449E24454E4010AE80423DB14B40
44027	55196	60.759898999999997	60.775233	55.410539999999997	55.405029999999996	Школьная	0103000020E61000000100000005000000ADA1D45E44614E400EF3E505D8B34B40ADA1D45E44614E4094D920938CB44B40D6E3BED53A634E4094D920938CB44B40D6E3BED53A634E400EF3E505D8B34B40ADA1D45E44614E400EF3E505D8B34B40
43555	5617	60.522554999999997	60.544079000000004	55.341577000000001	55.330413999999998	Полевая	0103000020E610000001000000050000003EAE0D15E3424E40FD1186014BAA4B403EAE0D15E3424E406C088ECBB8AB4B405FB87361A4454E406C088ECBB8AB4B405FB87361A4454E40FD1186014BAA4B403EAE0D15E3424E40FD1186014BAA4B40
43767	26875	60.897817000000003	60.918801999999999	55.300618	55.297902000000001	Интернациональная	0103000020E610000001000000050000007C65DEAAEB724E40DDB419A721A64B407C65DEAAEB724E40624B8FA67AA64B40ECBFCE4D9B754E40624B8FA67AA64B40ECBFCE4D9B754E40DDB419A721A64B407C65DEAAEB724E40DDB419A721A64B40
43914	16217	60.474153999999999	60.497708000000003	55.186200999999997	55.177838000000001	Колхозная	0103000020E6100000010000000500000040A20914B13C4E4037FE4465C3964B4040A20914B13C4E40C2BD326FD5974B40927A4FE5B43F4E40C2BD326FD5974B40927A4FE5B43F4E4037FE4465C3964B4040A20914B13C4E4037FE4465C3964B40
43625	1622	60.807087000000003	60.853529999999999	55.463737999999999	55.440987999999997	Школьная	0103000020E610000001000000050000006D0377A04E674E40D7F6764B72B84B406D0377A04E674E40CBF44BC45BBB4B40D3139678406D4E40CBF44BC45BBB4B40D3139678406D4E40D7F6764B72B84B406D0377A04E674E40D7F6764B72B84B40
42842	4107	60.588194999999999	60.616760999999997	55.234307000000001	55.210535999999998	Чапаева	0103000020E61000000100000005000000DA5548F9494B4E40B950F9D7F29A4B40DA5548F9494B4E40A81C93C5FD9D4B4060394206F24E4E40A81C93C5FD9D4B4060394206F24E4E40B950F9D7F29A4B40DA5548F9494B4E40B950F9D7F29A4B40
42979	4107	60.588194999999999	60.616760999999997	55.234307000000001	55.210535999999998	Салавата Юлаева	0103000020E61000000100000005000000DA5548F9494B4E40B950F9D7F29A4B40DA5548F9494B4E40A81C93C5FD9D4B4060394206F24E4E40A81C93C5FD9D4B4060394206F24E4E40B950F9D7F29A4B40DA5548F9494B4E40B950F9D7F29A4B40
43698	55163	60.757905000000001	60.786552	55.355372000000003	55.342703	Школьная	0103000020E61000000100000005000000C93CF20703614E40DC9E20B1DDAB4B40C93CF20703614E4002F566D47CAD4B403C4D66BCAD644E4002F566D47CAD4B403C4D66BCAD644E40DC9E20B1DDAB4B40C93CF20703614E40DC9E20B1DDAB4B40
43618	48615	60.612791000000001	60.666761999999999	55.503227000000003	55.477460000000001	Октябрьская	0103000020E610000001000000050000003E247CEF6F4E4E40F792C6681DBD4B403E247CEF6F4E4E406BBB09BE69C04B40971B0C7558554E406BBB09BE69C04B40971B0C7558554E40F792C6681DBD4B403E247CEF6F4E4E40F792C6681DBD4B40
43676	48615	60.612791000000001	60.666761999999999	55.503227000000003	55.477460000000001	Ленина	0103000020E610000001000000050000003E247CEF6F4E4E40F792C6681DBD4B403E247CEF6F4E4E406BBB09BE69C04B40971B0C7558554E406BBB09BE69C04B40971B0C7558554E40F792C6681DBD4B403E247CEF6F4E4E40F792C6681DBD4B40
44118	48115	60.925288000000002	60.935420999999998	55.235061000000002	55.225999999999999	 Восточная	0103000020E61000000100000005000000CDB051D66F764E40B0726891ED9C4B40CDB051D66F764E4054C8957A169E4B40ED7E15E0BB774E4054C8957A169E4B40ED7E15E0BB774E40B0726891ED9C4B40CDB051D66F764E40B0726891ED9C4B40
43516	46115	60.923580999999999	60.939939000000003	55.385418000000001	55.369346999999998	Советская	0103000020E610000001000000050000007E1AF7E637764E4017F032C346AF4B407E1AF7E637764E4016A5846055B14B40139ED0EB4F784E4016A5846055B14B40139ED0EB4F784E4017F032C346AF4B407E1AF7E637764E4017F032C346AF4B40
42594	23084	61.036777999999998	61.056693000000003	55.427770000000002	55.408225000000002	Школьная	0103000020E610000001000000050000002C9B3924B5844E406E3480B740B44B402C9B3924B5844E40DF1AD82AC1B64B40C1745AB741874E40DF1AD82AC1B64B40C1745AB741874E406E3480B740B44B402C9B3924B5844E406E3480B740B44B40
44163	16426	61.221031000000004	61.246974000000002	55.469611999999998	55.457459999999998	М. Усманова	0103000020E610000001000000050000007B336ABE4A9C4E40349D9D0C8EBA4B407B336ABE4A9C4E4092E7FA3E1CBC4B402D7B12D89C9F4E4092E7FA3E1CBC4B402D7B12D89C9F4E40349D9D0C8EBA4B407B336ABE4A9C4E40349D9D0C8EBA4B40
43165	16112	61.105490000000003	61.140101999999999	55.473030999999999	55.452212000000003	Набережная	0103000020E610000001000000050000000C0742B2808D4E40EC6D3315E2B94B400C0742B2808D4E40417FA1478CBC4B40560DC2DCEE914E40417FA1478CBC4B40560DC2DCEE914E40EC6D3315E2B94B400C0742B2808D4E40EC6D3315E2B94B40
44168	1617	60.568449999999999	60.634162000000003	55.497990000000001	55.459062000000003	Братьев Кауровых	0103000020E61000000100000005000000A2B437F8C2484E400E6B2A8BC2BA4B40A2B437F8C2484E4016DEE522BEBF4B40D82E6D382C514E4016DEE522BEBF4B40D82E6D382C514E400E6B2A8BC2BA4B40A2B437F8C2484E400E6B2A8BC2BA4B40
43773	1617	60.568449999999999	60.634162000000003	55.497990000000001	55.459062000000003	Архипова	0103000020E61000000100000005000000A2B437F8C2484E400E6B2A8BC2BA4B40A2B437F8C2484E4016DEE522BEBF4B40D82E6D382C514E4016DEE522BEBF4B40D82E6D382C514E400E6B2A8BC2BA4B40A2B437F8C2484E400E6B2A8BC2BA4B40
43925	9245	60.820363999999998	60.836516000000003	55.333466000000001	55.324129999999997	Ветеранов	0103000020E610000001000000050000006A6803B001694E4084D382177DA94B406A6803B001694E40FA298E03AFAA4B40564ACFF4126B4E40FA298E03AFAA4B40564ACFF4126B4E4084D382177DA94B406A6803B001694E4084D382177DA94B40
43926	55190	60.790405999999997	60.810420000000001	55.298578999999997	55.293643000000003	Пионерская	0103000020E61000000100000005000000F54718062C654E4084D9041896A54B40F54718062C654E40DD2230D637A64B401D03B2D7BB674E40DD2230D637A64B401D03B2D7BB674E4084D9041896A54B40F54718062C654E4084D9041896A54B40
43783	4742	60.589092999999998	60.612960999999999	55.154238999999997	55.147303999999998	Школьная	0103000020E61000000100000005000000B9A64066674B4E40F54883DBDA924B40B9A64066674B4E404562821ABE934B409A5C8C81754E4E404562821ABE934B409A5C8C81754E4E40F54883DBDA924B40B9A64066674B4E40F54883DBDA924B40
44041	5174	60.663077999999999	60.679265999999998	55.149752999999997	55.144767999999999	Центральная	0103000020E610000001000000050000003A596ABDDF544E40F0C000C287924B403A596ABDDF544E402BBD361B2B934B4072A43330F2564E402BBD361B2B934B4072A43330F2564E40F0C000C287924B403A596ABDDF544E40F0C000C287924B40
44052	9601	60.467291000000003	60.486469999999997	55.284205	55.273420999999999	Колхозная	0103000020E610000001000000050000008A5B0531D03B4E4012859675FFA24B408A5B0531D03B4E400A2E56D460A44B40183E22A6443E4E400A2E56D460A44B40183E22A6443E4E4012859675FFA24B408A5B0531D03B4E4012859675FFA24B40
44265	28153	60.720660000000002	60.731879999999997	55.59751	55.590322	Омская	0103000020E6100000010000000500000087C43D963E5C4E40FE0DDAAB8FCB4B4087C43D963E5C4E4038842A357BCC4B40594C6C3EAE5D4E4038842A357BCC4B40594C6C3EAE5D4E40FE0DDAAB8FCB4B4087C43D963E5C4E40FE0DDAAB8FCB4B40
43772	27488	60.919026000000002	60.929195	55.444318000000003	55.437638	Зеленая	0103000020E610000001000000050000003C16DBA4A2754E4051BEA08504B84B403C16DBA4A2754E4017838769DFB84B40A94D9CDCEF764E4017838769DFB84B40A94D9CDCEF764E4051BEA08504B84B403C16DBA4A2754E4051BEA08504B84B40
44152	22442	61.183481	61.204304	55.692535999999997	55.679971000000002	Школьная	0103000020E61000000100000005000000FC372F4E7C974E403D9D2B4A09D74B40FC372F4E7C974E40BDA60705A5D84B4093382BA2269A4E40BDA60705A5D84B4093382BA2269A4E403D9D2B4A09D74B40FC372F4E7C974E403D9D2B4A09D74B40
43510	2553	60.491526999999998	60.523363000000003	55.383617999999998	55.369259999999997	Титова	0103000020E61000000100000005000000ED0C535BEA3E4E4048DC63E943AF4B40ED0C535BEA3E4E40161406651AB14B40DE770C8FFD424E40161406651AB14B40DE770C8FFD424E4048DC63E943AF4B40ED0C535BEA3E4E4048DC63E943AF4B40
43497	8784	60.782384	60.799675999999998	55.160339	55.152346000000001	Центральная	0103000020E61000000100000005000000F374AE2825644E4095D6DF1280934B40F374AE2825644E40FDA204FD85944B40B3B27DC85B664E40FDA204FD85944B40B3B27DC85B664E4095D6DF1280934B40F374AE2825644E4095D6DF1280934B40
43504	14977	60.901553999999997	60.940047	55.473745000000001	55.461987000000001	Школьная	0103000020E61000000100000005000000FBC9181F66734E40AD16D86322BB4B40FBC9181F66734E405FD218ADA3BC4B40F9D9C87553784E405FD218ADA3BC4B40F9D9C87553784E40AD16D86322BB4B40FBC9181F66734E40AD16D86322BB4B40
43548	27619	60.815145000000001	60.828809	55.533617999999997	55.519294000000002	Школьная	0103000020E61000000100000005000000BC3FDEAB56684E402881CD3978C24B40BC3FDEAB56684E40494739984DC44B40B3D0CE69166A4E40494739984DC44B40B3D0CE69166A4E402881CD3978C24B40BC3FDEAB56684E402881CD3978C24B40
42883	7088	60.850287000000002	60.902551000000003	55.507238999999998	55.475582000000003	площадь СПТУ	0103000020E61000000100000005000000639B5434D66C4E407C48F8DEDFBC4B40639B5434D66C4E40BC202235EDC04B406EFC89CA86734E40BC202235EDC04B406EFC89CA86734E407C48F8DEDFBC4B40639B5434D66C4E407C48F8DEDFBC4B40
43628	7088	60.850287000000002	60.902551000000003	55.507238999999998	55.475582000000003	Октябрьская	0103000020E61000000100000005000000639B5434D66C4E407C48F8DEDFBC4B40639B5434D66C4E40BC202235EDC04B406EFC89CA86734E40BC202235EDC04B406EFC89CA86734E407C48F8DEDFBC4B40639B5434D66C4E407C48F8DEDFBC4B40
43167	7088	60.850287000000002	60.902551000000003	55.507238999999998	55.475582000000003	Ленина	0103000020E61000000100000005000000639B5434D66C4E407C48F8DEDFBC4B40639B5434D66C4E40BC202235EDC04B406EFC89CA86734E40BC202235EDC04B406EFC89CA86734E407C48F8DEDFBC4B40639B5434D66C4E407C48F8DEDFBC4B40
43003	7088	60.850287000000002	60.902551000000003	55.507238999999998	55.475582000000003	8 Марта	0103000020E61000000100000005000000639B5434D66C4E407C48F8DEDFBC4B40639B5434D66C4E40BC202235EDC04B406EFC89CA86734E40BC202235EDC04B406EFC89CA86734E407C48F8DEDFBC4B40639B5434D66C4E407C48F8DEDFBC4B40
43002	7088	60.850287000000002	60.902551000000003	55.507238999999998	55.475582000000003	 Чкалова	0103000020E61000000100000005000000639B5434D66C4E407C48F8DEDFBC4B40639B5434D66C4E40BC202235EDC04B406EFC89CA86734E40BC202235EDC04B406EFC89CA86734E407C48F8DEDFBC4B40639B5434D66C4E407C48F8DEDFBC4B40
43929	10624	60.423552000000001	60.434834000000002	55.361967999999997	55.353611000000001	Береговая	0103000020E61000000100000005000000E413B2F336364E40C040102043AD4B40E413B2F336364E406919A9F754AE4B402D98F8A3A8374E406919A9F754AE4B402D98F8A3A8374E40C040102043AD4B40E413B2F336364E40C040102043AD4B40
42978	32510	60.826698	60.863681	55.300654000000002	55.286316999999997	30 лет Победы	0103000020E6100000010000000500000095D5743DD1694E40F8A41309A6A44B4095D5743DD1694E40AFB48CD47BA64B409A9658198D6E4E40AFB48CD47BA64B409A9658198D6E4E40F8A41309A6A44B4095D5743DD1694E40F8A41309A6A44B40
43887	5514	60.653395000000003	60.665225	55.219411000000001	55.210997999999996	Центральная	0103000020E610000001000000050000005A2F8672A2534E40BDC282FB019B4B405A2F8672A2534E40FBB0DEA8159C4B40A5BDC11726554E40FBB0DEA8159C4B40A5BDC11726554E40BDC282FB019B4B405A2F8672A2534E40BDC282FB019B4B40
44070	19192	61.054653999999999	61.083570999999999	55.391129999999997	55.380999000000003	Солнечная	0103000020E610000001000000050000003C4CFBE6FE864E4084674293C4B04B403C4CFBE6FE864E40033E3F8C10B24B406FF25B74B28A4E40033E3F8C10B24B406FF25B74B28A4E4084674293C4B04B403C4CFBE6FE864E4084674293C4B04B40
43010	9409	58.968451999999999	58.996147000000001	53.134059000000001	53.115302999999997	Рабочая	0103000020E6100000010000000500000076DF313CF67B4D40BA10AB3FC28E4A4076DF313CF67B4D40035E66D828914A401781B1BE817F4D40035E66D828914A401781B1BE817F4D40BA10AB3FC28E4A4076DF313CF67B4D40BA10AB3FC28E4A40
43821	8539	59.450181999999998	59.461644999999997	53.123354999999997	53.117741000000002	Садовая	0103000020E61000000100000005000000BA9F53909FB94D40FD321823128F4A40BA9F53909FB94D402766BD18CA8F4A4053AEF02E17BB4D402766BD18CA8F4A4053AEF02E17BB4D40FD321823128F4A40BA9F53909FB94D40FD321823128F4A40
43989	9180	59.134757	59.142131999999997	53.165182000000001	53.156008999999997	Мирный переулок	0103000020E610000001000000050000001BF4A5B73F914D40DA70581AF8934A401BF4A5B73F914D40A6F10BAF24954A4087DBA16131924D40A6F10BAF24954A4087DBA16131924D40DA70581AF8934A401BF4A5B73F914D40DA70581AF8934A40
43653	9318	59.670135000000002	59.692627999999999	53.261971000000003	53.247866999999999	1 Мая	0103000020E61000000100000005000000D673D2FBC6D54D40FA60191BBA9F4A40D673D2FBC6D54D400EC0064488A14A409E25C808A8D84D400EC0064488A14A409E25C808A8D84D40FA60191BBA9F4A40D673D2FBC6D54D40FA60191BBA9F4A40
44244	8617	59.095078000000001	59.116224000000003	53.224412000000001	53.217311000000002	Центральная	0103000020E61000000100000005000000D84812842B8C4D40D107CBD8D09B4A40D84812842B8C4D403C6A4C88B99C4A405281936DE08E4D403C6A4C88B99C4A405281936DE08E4D40D107CBD8D09B4A40D84812842B8C4D40D107CBD8D09B4A40
44121	9303	59.355148999999997	59.363809000000003	53.144776	53.140687	Школьная	0103000020E61000000100000005000000821ABE8575AD4D4076FC170802924A40821ABE8575AD4D40739F1C0588924A40C87E164B91AE4D40739F1C0588924A40C87E164B91AE4D4076FC170802924A40821ABE8575AD4D4076FC170802924A40
44023	7880	59.276214000000003	59.291701000000003	53.462378999999999	53.453318000000003	Зеленая	0103000020E610000001000000050000004359F8FA5AA34D401558005306BA4A404359F8FA5AA34D40B8AD2D3C2FBB4A40F29A577556A54D40B8AD2D3C2FBB4A40F29A577556A54D401558005306BA4A404359F8FA5AA34D401558005306BA4A40
43857	9359	59.657172000000003	59.666226999999999	53.293453	53.282831999999999	Центральная	0103000020E6100000010000000500000068EC4B361ED44D409221C7D633A44A4068EC4B361ED44D40E0F42EDE8FA54A40295B24ED46D54D40E0F42EDE8FA54A40295B24ED46D54D409221C7D633A44A4068EC4B361ED44D409221C7D633A44A40
43856	9068	58.994512	59.005839000000002	53.041285000000002	53.031858	Целинная	0103000020E6100000010000000500000062BD512B4C7F4D40D80E46EC13844A4062BD512B4C7F4D405E68AED348854A404B051555BF804D405E68AED348854A404B051555BF804D40D80E46EC13844A4062BD512B4C7F4D40D80E46EC13844A40
43513	8287	59.548889000000003	59.597371000000003	53.244067999999999	53.226745999999999	Школьная	0103000020E610000001000000050000002C11A8FE41C64D40D93F4F03069D4A402C11A8FE41C64D400400C79E3D9F4A40174A26A776CC4D400400C79E3D9F4A40174A26A776CC4D40D93F4F03069D4A402C11A8FE41C64D40D93F4F03069D4A40
44050	8287	59.548889000000003	59.597371000000003	53.244067999999999	53.226745999999999	Северная	0103000020E610000001000000050000002C11A8FE41C64D40D93F4F03069D4A402C11A8FE41C64D400400C79E3D9F4A40174A26A776CC4D400400C79E3D9F4A40174A26A776CC4D40D93F4F03069D4A402C11A8FE41C64D40D93F4F03069D4A40
44117	7972	59.436464999999998	59.449472	53.463386999999997	53.455275	переулок Сиреневый	0103000020E61000000100000005000000A06CCA15DEB74D40DCD7817346BA4A40A06CCA15DEB74D401E32E54350BB4A40DE3B6A4C88B94D401E32E54350BB4A40DE3B6A4C88B94D40DCD7817346BA4A40A06CCA15DEB74D40DCD7817346BA4A40
43652	9048	59.145788000000003	59.157780000000002	53.141255000000001	53.130217999999999	Степная	0103000020E610000001000000050000001B13622EA9924D40DEACC1FBAA904A401B13622EA9924D40C0B2D2A414924A4040FB912232944D40C0B2D2A414924A4040FB912232944D40DEACC1FBAA904A401B13622EA9924D40DEACC1FBAA904A40
43648	8915	59.047072	59.062235999999999	53.606982000000002	53.597487000000001	Дружбы	0103000020E6100000010000000500000056478E7406864D4080643A747ACC4A4056478E7406864D405EA10F96B1CD4A4022516859F7874D405EA10F96B1CD4A4022516859F7874D4080643A747ACC4A4056478E7406864D4080643A747ACC4A40
42814	8828	59.104843000000002	59.129905999999998	53.562716999999999	53.525241999999999	Клубная	0103000020E61000000100000005000000761BD47E6B8D4D40293E3E213BC34A40761BD47E6B8D4D409DF3531C07C84A40EFC682C2A0904D409DF3531C07C84A40EFC682C2A0904D40293E3E213BC34A40761BD47E6B8D4D40293E3E213BC34A40
44245	8828	59.104843000000002	59.129905999999998	53.562716999999999	53.525241999999999	Калинина	0103000020E61000000100000005000000761BD47E6B8D4D40293E3E213BC34A40761BD47E6B8D4D409DF3531C07C84A40EFC682C2A0904D409DF3531C07C84A40EFC682C2A0904D40293E3E213BC34A40761BD47E6B8D4D40293E3E213BC34A40
43008	8675	59.368659999999998	59.393597	53.323157999999999	53.311253999999998	Центральная	0103000020E61000000100000005000000F3AB394030AF4D40E55FCB2BD7A74A40F3AB394030AF4D406BB8C83D5DA94A40E066F16261B24D406BB8C83D5DA94A40E066F16261B24D40E55FCB2BD7A74A40F3AB394030AF4D40E55FCB2BD7A74A40
43662	7831	59.226322000000003	59.235880000000002	53.379257000000003	53.371257999999997	Набережная	0103000020E61000000100000005000000C32E8A1EF89C4D406E30D46185AF4A40C32E8A1EF89C4D40B9E34D7E8BB04A40E7E3DA50319E4D40B9E34D7E8BB04A40E7E3DA50319E4D406E30D46185AF4A40C32E8A1EF89C4D406E30D46185AF4A40
43512	9458	58.913142000000001	58.936219999999999	53.203310999999999	53.194744999999998	Школьная	0103000020E61000000100000005000000514D49D6E1744D409E077767ED984A40514D49D6E1744D4062F54718069A4A4039EE940ED6774D4062F54718069A4A4039EE940ED6774D409E077767ED984A40514D49D6E1744D409E077767ED984A40
43569	8085	59.494334000000002	59.510899000000002	53.352004000000001	53.335155999999998	Зеленая	0103000020E6100000010000000500000083A6255646BF4D4072874D64E6AA4A4083A6255646BF4D40D50792770EAD4A409147702365C14D40D50792770EAD4A409147702365C14D4072874D64E6AA4A4083A6255646BF4D4072874D64E6AA4A40
43986	8029	59.465390999999997	59.474373999999997	53.359898999999999	53.352665000000002	Зеленая	0103000020E61000000100000005000000266DAAEE91BB4D40D0B8702024AD4A40266DAAEE91BB4D407A6EA12B11AE4A404E098849B8BC4D407A6EA12B11AE4A404E098849B8BC4D40D0B8702024AD4A40266DAAEE91BB4D40D0B8702024AD4A40
43179	8549	59.082087999999999	59.101717000000001	53.295513999999997	53.281373000000002	Кооперативная	0103000020E6100000010000000500000070B20DDC818A4D401C7DCC0704A44A4070B20DDC818A4D404CC11A67D3A54A403F390A10058D4D404CC11A67D3A54A403F390A10058D4D401C7DCC0704A44A4070B20DDC818A4D401C7DCC0704A44A40
43666	8712	59.404933999999997	59.422963000000003	53.295023999999998	53.282153999999998	Административная	0103000020E61000000100000005000000EC8497E0D4B34D40C1374D9F1DA44A40EC8497E0D4B34D407EC4AF58C3A54A408335CEA623B64D407EC4AF58C3A54A408335CEA623B64D40C1374D9F1DA44A40EC8497E0D4B34D40C1374D9F1DA44A40
44006	8213	59.284910000000004	59.298133	53.493524999999998	53.486077999999999	Новая	0103000020E61000000100000005000000D5264EEE77A44D400DA7CCCD37BE4A40D5264EEE77A44D401361C3D32BBF4A40DF6DDE3829A64D401361C3D32BBF4A40DF6DDE3829A64D400DA7CCCD37BE4A40D5264EEE77A44D400DA7CCCD37BE4A40
44028	8754	59.264518000000002	59.275495999999997	53.313851999999997	53.305636	Клубная	0103000020E61000000100000005000000079ACFB9DBA14D40793D98141FA74A40079ACFB9DBA14D4060E4654D2CA84A40E316F37343A34D4060E4654D2CA84A40E316F37343A34D40793D98141FA74A40079ACFB9DBA14D40793D98141FA74A40
43623	8228	59.515408999999998	59.536842999999998	53.214092000000001	53.198628999999997	Молодежная	0103000020E6100000010000000500000033880FECF8C14D40C284D1AC6C994A4033880FECF8C14D40E92ADD5D679B4A40130B7C45B7C44D40E92ADD5D679B4A40130B7C45B7C44D40C284D1AC6C994A4033880FECF8C14D40C284D1AC6C994A40
43822	7943	59.410854	59.419387999999998	53.484662999999998	53.478464000000002	Зеленая	0103000020E6100000010000000500000024B726DD96B44D401C28F04E3EBD4A4024B726DD96B44D40664AEB6F09BE4A40DC2A8881AEB54D40664AEB6F09BE4A40DC2A8881AEB54D401C28F04E3EBD4A4024B726DD96B44D401C28F04E3EBD4A40
44116	8469	59.581543000000003	59.593266	53.216545000000004	53.206741000000001	8 Марта	0103000020E61000000100000005000000DF1B430070CA4D4005DF347D769A4A40DF1B430070CA4D40618E1EBFB79B4A4014EAE923F0CB4D40618E1EBFB79B4A4014EAE923F0CB4D4005DF347D769A4A40DF1B430070CA4D4005DF347D769A4A40
44119	9187	59.268695000000001	59.285179999999997	53.111887000000003	53.105752000000003	Студенческая	0103000020E61000000100000005000000A3CC069964A24D4049BE1248898D4A40A3CC069964A24D407DEC2E50528E4A4094BC3AC780A44D407DEC2E50528E4A4094BC3AC780A44D4049BE1248898D4A40A3CC069964A24D4049BE1248898D4A40
43570	8134	59.211401000000002	59.234766	53.568112999999997	53.552325000000003	Советская	0103000020E61000000100000005000000BDAB1E300F9B4D40B1E1E995B2C64A40BDAB1E300F9B4D405AB741EDB7C84A403B1BF2CF0C9E4D405AB741EDB7C84A403B1BF2CF0C9E4D40B1E1E995B2C64A40BDAB1E300F9B4D40B1E1E995B2C64A40
43815	7671	59.238072000000003	59.248896999999999	53.281238000000002	53.271250000000002	Садовая	0103000020E61000000100000005000000F20BAF24799E4D401F85EB51B8A24A40F20BAF24799E4D403C32569BFFA34A4048895DDBDB9F4D403C32569BFFA34A4048895DDBDB9F4D401F85EB51B8A24A40F20BAF24799E4D401F85EB51B8A24A40
44025	8787	59.431111000000001	59.449804999999998	53.333466999999999	53.322443	Привокзальная	0103000020E6100000010000000500000012F92EA52EB74D407DE9EDCF45A94A4012F92EA52EB74D40CAA5F10BAFAA4A40E449D23593B94D40CAA5F10BAFAA4A40E449D23593B94D407DE9EDCF45A94A4012F92EA52EB74D407DE9EDCF45A94A40
44120	8456	59.516297999999999	59.527410000000003	53.221473000000003	53.209783000000002	Молодежная	0103000020E61000000100000005000000BF7E880D16C24D40DE205A2BDA9A4A40BF7E880D16C24D4038F92D3A599C4A40ACCABE2B82C34D4038F92D3A599C4A40ACCABE2B82C34D40DE205A2BDA9A4A40BF7E880D16C24D40DE205A2BDA9A4A40
43855	9111	59.005543000000003	59.018667000000001	53.078783000000001	53.069862000000001	Школьная	0103000020E6100000010000000500000062DC0DA2B5804D40D89DEE3CF1884A4062DC0DA2B5804D408A3DB48F158A4A40D94125AE63824D408A3DB48F158A4A40D94125AE63824D40D89DEE3CF1884A4062DC0DA2B5804D40D89DEE3CF1884A40
43647	8909	59.065955000000002	59.081522999999997	53.545524999999998	53.532617999999999	Школьная	0103000020E61000000100000005000000FC00A43671884D4066A19DD32CC44A40FC00A43671884D40401361C3D3C54A40976F7D586F8A4D40401361C3D3C54A40976F7D586F8A4D4066A19DD32CC44A40FC00A43671884D4066A19DD32CC44A40
43176	7745	59.323546999999998	59.360135	53.406036	53.389800000000001	Волынцева	0103000020E6100000010000000500000005DCF3FC69A94D408BFD65F7E4B14A4005DCF3FC69A94D40D47FD6FCF8B34A408E9257E718AE4D40D47FD6FCF8B34A408E9257E718AE4D408BFD65F7E4B14A4005DCF3FC69A94D408BFD65F7E4B14A40
43604	7802	59.291594000000003	59.318353999999999	53.404828000000002	53.387104000000001	Железнодорожная	0103000020E61000000100000005000000DCDAC2F352A54D404D13B69F8CB14A40DCDAC2F352A54D40A7406667D1B34A408046E9D2BFA84D40A7406667D1B34A408046E9D2BFA84D404D13B69F8CB14A40DCDAC2F352A54D404D13B69F8CB14A40
43854	9247	59.336896000000003	59.348744000000003	53.095467999999997	53.07987	Октябрьская	0103000020E610000001000000050000009D137B681FAB4D403CF71E2E398A4A409D137B681FAB4D4042E8A04B388C4A408F56B5A4A3AC4D4042E8A04B388C4A408F56B5A4A3AC4D403CF71E2E398A4A409D137B681FAB4D403CF71E2E398A4A40
43817	8380	59.718283999999997	59.728650999999999	53.137867999999997	53.130034000000002	Мира	0103000020E61000000100000005000000BA9EE8BAF0DB4D401DAF40F4A4904A40BA9EE8BAF0DB4D401C959BA8A5914A404E999B6F44DD4D401C959BA8A5914A404E999B6F44DD4D401DAF40F4A4904A40BA9EE8BAF0DB4D401DAF40F4A4904A40
42813	7531	59.121721999999998	59.149408000000001	53.318564000000002	53.286341999999998	Школьная	0103000020E61000000100000005000000139A2496948F4D4051BCCADAA6A44A40139A2496948F4D406BD784B4C6A84A4061E124CD1F934D406BD784B4C6A84A4061E124CD1F934D4051BCCADAA6A44A40139A2496948F4D4051BCCADAA6A44A40
43175	7531	59.121721999999998	59.149408000000001	53.318564000000002	53.286341999999998	Пролетарская	0103000020E61000000100000005000000139A2496948F4D4051BCCADAA6A44A40139A2496948F4D406BD784B4C6A84A4061E124CD1F934D406BD784B4C6A84A4061E124CD1F934D4051BCCADAA6A44A40139A2496948F4D4051BCCADAA6A44A40
42798	7531	59.121721999999998	59.149408000000001	53.318564000000002	53.286341999999998	Правобережная	0103000020E61000000100000005000000139A2496948F4D4051BCCADAA6A44A40139A2496948F4D406BD784B4C6A84A4061E124CD1F934D406BD784B4C6A84A4061E124CD1F934D4051BCCADAA6A44A40139A2496948F4D4051BCCADAA6A44A40
44247	7698	59.172710000000002	59.182287000000002	53.224881000000003	53.216819999999998	Степная	0103000020E6100000010000000500000099D87C5C1B964D40328FFCC1C09B4A4099D87C5C1B964D40F33E8EE6C89C4A4034BE2F2E55974D40F33E8EE6C89C4A4034BE2F2E55974D40328FFCC1C09B4A4099D87C5C1B964D40328FFCC1C09B4A40
42887	55115	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	Озимина	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
77418	61166	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	мкр. 40 лет Победы	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77595	61209	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Школьная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77052	61050	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Ленина	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77181	61090	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Советская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
81169	61053	\N	\N	\N	\N	Набережная	\N
81167	61053	\N	\N	\N	\N	3 микрорайон	\N
77344	61140	71.003532000000007	71.032655000000005	61.290883000000001	61.265014999999998	Лесная	0103000020E61000000100000005000000541F48DE39C0514087F9F202ECA14E40541F48DE39C051402FFB75A73BA54E404243FF0417C251402FFB75A73BA54E404243FF0417C2514087F9F202ECA14E40541F48DE39C0514087F9F202ECA14E40
77515	61190	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Центральная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
78031	61270	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Центральная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77307	61126	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Полевая	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76323	60780	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Чкалова	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76185	60780	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Спортивная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77356	60780	71.026348999999996	71.057889000000003	61.245474999999999	61.226711000000002	Садовая	0103000020E610000001000000050000001152B7B3AFC151405D52B5DD049D4E401152B7B3AFC15140287E8CB96B9F4E4015731074B4C35140287E8CB96B9F4E4015731074B4C351405D52B5DD049D4E401152B7B3AFC151405D52B5DD049D4E40
77261	60780	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Мира	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77675	60780	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Микрорайон Югорск 2	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77175	60780	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Ленина	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76306	60780	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Ермака	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76413	60780	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Геологов	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77858	61262	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Школьная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77717	61240	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Школьная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
78293	61294	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Шаимская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41825	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Ямская	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41790	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Чехова	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
76535	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Уральская	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41789	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Студенческая	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41829	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Строителей	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
76473	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Свердлова	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41834	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Рознина	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41793	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Мира	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41840	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Луговая	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
76507	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Лермонтова	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
76178	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Ленина	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
76767	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Кооперативная	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41848	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Комсомольская	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41856	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Калинина	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41801	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Дунина-Горкавича	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41797	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Дзержинского	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
77120	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Горная	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41796	55060	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Гагарина	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41780	3251	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Сургутская	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
41779	3251	68.980722999999998	69.162559999999999	61.044913999999999	60.963866000000003	Бориса Щербины	0103000020E61000000100000005000000D7DB662AC43E5140F9DC09F65F7B4E40D7DB662AC43E5140F790F0BDBF854E40D1E80E62674A5140F790F0BDBF854E40D1E80E62674A5140F9DC09F65F7B4E40D7DB662AC43E5140F9DC09F65F7B4E40
77148	61078	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Клубная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76532	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон Западный	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76587	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон 3	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41894	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон 2	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77128	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон 1Г	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77096	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон 1А	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76648	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Парковая	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41873	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Нагорная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41888	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Микрорайон №2	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41896	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Микрорайон западный	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77071	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Маяковского	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
9897	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Ленина	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41882	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Авиаторов	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41879	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	3-й микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41831	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	2 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41878	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	1-й микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76579	40347	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	 Ленина	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41827	55066	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	мкр. Центральный	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
81176	55066	\N	\N	\N	\N	2 микрорайон	\N
77267	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	проспект Пролетарский	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41803	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	проспект Мира	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41791	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	проспект Ленина	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77321	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	проспект Комсомольский	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77410	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	проезд Первопроходцев	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77513	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	проезд Дружбы	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77197	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	проезд Взлетный	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77287	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	бульвар Свободы	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41795	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Энтузиастов	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77213	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Энергетиков	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77389	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Энгельса	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41800	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Чехова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41837	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Флегонта Показаньева	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77338	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Федорова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77617	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Университетская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77274	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Толстого	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77342	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Сибирская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77433	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Северная	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77549	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Саянская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77490	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Рабочая	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41838	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Пушкина	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77285	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Просвещения	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77504	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Привокзальная	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41802	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Островского	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77260	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Нагорная	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41858	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Набережный проспект	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77020	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Мостостроителей	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77536	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Московская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77364	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Мечникова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77560	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Мелик-Карамова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77166	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Мелик Карамова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41892	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Маяковского	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41762	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Лермонтова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41890	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Ленинградская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77638	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Крылова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41832	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Киртбая	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77343	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Индустриальная	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77487	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Ивана Захарова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77518	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Еловая	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41777	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Декабристов	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41798	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Григория Кукуевицкого	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77155	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Грибоедова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77163	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Геологическая	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41839	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Быстринская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41836	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Бахилова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41891	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Бажова	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77277	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Аэрофлотская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77430	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Аэрофлотская	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
76477	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	Артема	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77256	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	50 лет ВЛКСМ	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
41804	7010	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	30 лет Победы	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
77439	61172	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Центральная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41899	55074	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	мкр. Хвойный	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
81178	55074	\N	\N	\N	\N	Советская	\N
77236	55074	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Ленина	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
81181	55074	\N	\N	\N	\N	Киевская	\N
77170	55074	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Гастелло	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77477	61183	69.775193000000002	69.796662999999995	60.581403000000002	60.563043	Центральная	0103000020E61000000100000005000000A4C519C39C715140F19E03CB11484E40A4C519C39C715140ED65DB696B4A4E40BABBCE86FC725140ED65DB696B4A4E40BABBCE86FC725140F19E03CB11484E40A4C519C39C715140F19E03CB11484E40
77105	61062	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Центральная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77648	61223	68.264675999999994	68.322599999999994	60.057971999999999	60.033346000000002	Набережная	0103000020E610000001000000050000004F029B73F0105140E9B985AE44044E404F029B73F0105140B70A62A06B074E40226C787AA5145140B70A62A06B074E40226C787AA5145140E9B985AE44044E404F029B73F0105140E9B985AE44044E40
77333	61137	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Н.Вокуева	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77542	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Ломоносова	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77424	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	9 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77650	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	7 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77435	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	6 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77652	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	3 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77603	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	2 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77658	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	1 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77677	61154	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	 5 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41893	55056	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	Советская	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41855	55056	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	Магистральная	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41854	55056	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	5 микрорайон	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41763	55056	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	3 микрорайон	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41812	55056	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	2-й микрорайон	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41852	55056	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	1 микрорвйон	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41853	55056	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	1 микрорайон	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
81168	61059	\N	\N	\N	\N	Югорская	\N
77108	61059	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Школьная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77408	61160	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	Молодежная	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
77403	61160	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	Аганская	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
81171	62113	\N	\N	\N	\N	Строителей	\N
77760	61248	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Почтовая	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77160	61077	70.601562999999999	70.736687000000003	61.271644999999999	61.254108000000002	Светлая	0103000020E61000000100000005000000F4DE180280A6514074D3669C86A04E40F4DE180280A651409B8F6B43C5A24E40DB183BE125AF51409B8F6B43C5A24E40DB183BE125AF514074D3669C86A04E40F4DE180280A6514074D3669C86A04E40
77113	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	проспект Нефтяников	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41872	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон №1	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76904	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Энергетиков	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41886	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Солнечная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41885	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Сибирская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41875	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Речная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41874	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Пионерская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41884	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Микрорайон №7	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41881	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Микрорайон №1	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77123	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Лазарева	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77341	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Авиционная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76934	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	30 лет Победы	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41887	55069	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	2-й микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41865	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон №2	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41861	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Чернышова	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41871	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Уральская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41819	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Пионерская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41860	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Комсомольская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41868	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Загородных	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41866	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	4-й микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41862	55065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	3-й микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77367	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	проспект Победы	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77130	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	проезд Заозерный	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77414	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Энтузиастов	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77312	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Школьная	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77368	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Чапаева	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77222	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	ХантыМансийская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77568	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Ханты-Мансийская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77198	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Спортивная	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77485	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Пионерская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77387	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Пермская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
9869	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Первомайская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77153	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Омская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77193	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Нефтяников	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77373	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Мусы Джалиля	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77259	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Мира	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77382	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Маршала Жукова	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77172	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Ленина	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77478	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Комсомольский бульвар	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77642	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Интернациональная	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77133	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Индустриальная	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77184	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Зырянова	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77541	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Заводская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77300	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Заводская	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77134	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Дружбы Народов	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77220	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Дзержинского	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77385	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	Авиаторов	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77258	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	60 лет Октября	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
77726	1172	76.473391000000007	76.684684000000004	60.972580999999998	60.880482000000001	2П-2	0103000020E6100000010000000500000021CEC3094C1E5340BC5B59A2B3704E4021CEC3094C1E534001DBC1887D7C4E400C06D7DCD12B534001DBC1887D7C4E400C06D7DCD12B5340BC5B59A2B3704E4021CEC3094C1E5340BC5B59A2B3704E40
41847	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	Мира	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
76279	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	Магистральная	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41826	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	Жилая	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
76668	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	9 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
76633	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	8А микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41821	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	8 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41820	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	7 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41818	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	5-й микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41810	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	3 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41773	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	2 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41775	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	16А микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41778	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	16 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41776	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	14 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41774	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	13 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41823	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	12 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41772	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	11 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
76510	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	10 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41845	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	1 микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
41771	8178	72.483909999999995	72.666233000000005	61.128492000000001	61.067037999999997	 8А микрорайон	0103000020E61000000100000005000000450DA661F81E52406CCB80B394884E40450DA661F81E524019E6046D72904E4006A1BC8FA32A524019E6046D72904E4006A1BC8FA32A52406CCB80B394884E40450DA661F81E52406CCB80B394884E40
77309	61128	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Волгоградская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41765	55058	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Центральная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41883	55058	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Первомайская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41824	55058	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Волгоградская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77291	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Сутормина	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77363	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Советская	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77288	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Свободы	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77398	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Проспект Победы	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77234	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Нефтяников	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77207	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Нефтеразведочная	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77315	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Ленина	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77139	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Ленина	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77298	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Ленина	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77273	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Кузьмина	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77353	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Заречная	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77586	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Геологов	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77534	80	76.056770999999998	76.145605000000003	61.049182999999999	61.017381999999998	Гагарина	0103000020E610000001000000050000001E17D522A203534000C5C89239824E401E17D522A20353407442E8A04B864E409548A297510953407442E8A04B864E409548A2975109534000C5C89239824E401E17D522A203534000C5C89239824E40
77178	61089	37.855544999999999	37.856029999999997	55.943219999999997	55.942847	Первомайский	0103000020E61000000100000005000000CFA0A17F82ED4240DC10E335AFF84B40CFA0A17F82ED42407077D66EBBF84B408B321B6492ED42407077D66EBBF84B408B321B6492ED4240DC10E335AFF84B40CFA0A17F82ED4240DC10E335AFF84B40
77243	61111	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Волгоградская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77598	61211	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Гагарина	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77301	61123	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Мира	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77509	61123	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Ленина	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77594	61123	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Дружбы народов	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77225	61099	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Почтовая	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77425	61167	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Обская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77407	61162	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Дружбы	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41880	55072	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Советская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77604	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Янтарная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77664	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Широкая	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77669	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Степана Повха	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77659	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Сопочинского	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77580	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Сибирская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77567	61139	68.977857999999998	69.265022000000002	61.334301000000004	61.235860000000002	Северная	0103000020E610000001000000050000007288B839953E5140A03715A9309E4E407288B839953E514093020B60CAAA4E401DAED51EF650514093020B60CAAA4E401DAED51EF6505140A03715A9309E4E407288B839953E5140A03715A9309E4E40
77442	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Привокзальная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77377	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Прибалтийская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77605	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Набережная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77666	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Мира	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77340	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Дружбы Народов	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77601	61139	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Бакинская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77264	61115	68.234547000000006	68.254822000000004	61.487358	61.470793999999998	Ленина	0103000020E61000000100000005000000FF976BD1020F5140969350FA42BC4E40FF976BD1020F5140D4B837BF61BE4E404913EF004F105140D4B837BF61BE4E404913EF004F105140969350FA42BC4E40FF976BD1020F5140969350FA42BC4E40
77571	61205	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Промысловая	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41863	55068	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Авиаторов	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77284	55064	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	микрорайон Мирный	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77098	55064	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Школьная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
41817	55064	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Центральная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77057	55064	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	3 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
76734	55062	73.356525000000005	73.489627999999996	61.302334000000002	61.239614000000003	проспект Ленина	0103000020E6100000010000000500000036CD3B4ED1565240F6D4EAABAB9E4E4036CD3B4ED1565240043C69E1B2A64E402DCDAD10565F5240043C69E1B2A64E402DCDAD10565F5240F6D4EAABAB9E4E4036CD3B4ED1565240F6D4EAABAB9E4E40
41786	55059	72.562072999999998	72.642418000000006	61.131489000000002	61.096054000000002	11 микрорайон	0103000020E61000000100000005000000BC3D0801F923524033535A7F4B8C4E40BC3D0801F92352405264ADA1D4904E40271763601D2952405264ADA1D4904E40271763601D29524033535A7F4B8C4E40BC3D0801F923524033535A7F4B8C4E40
77366	10910	69.491065000000006	69.520349999999993	60.968603999999999	60.962884000000003	Новая	0103000020E6100000010000000500000075CDE49B6D5F5140BCEB6CC83F7B4E4075CDE49B6D5F51402C634337FB7B4E404F1E166A4D6151402C634337FB7B4E404F1E166A4D615140BCEB6CC83F7B4E4075CDE49B6D5F5140BCEB6CC83F7B4E40
77121	61068	69.451468000000006	69.471832000000006	61.094465999999997	61.085814999999997	Молодежная	0103000020E6100000010000000500000032CC09DAE45C5140CC4065FCFB8A4E4032CC09DAE45C5140BE4A3E76178C4E40344DD87E325E5140BE4A3E76178C4E40344DD87E325E5140CC4065FCFB8A4E4032CC09DAE45C5140CC4065FCFB8A4E40
77279	52116	69.681974999999994	69.717314999999999	60.185749999999999	60.162962	Советская	0103000020E61000000100000005000000226C787AA56B5140D13E56F0DB144E40226C787AA56B5140B29DEFA7C6174E40897B2C7DE86D5140B29DEFA7C6174E40897B2C7DE86D5140D13E56F0DB144E40226C787AA56B5140D13E56F0DB144E40
77383	10732	69.631472000000002	69.661232999999996	60.746240999999998	60.737296000000001	переулок Дружбы	0103000020E61000000100000005000000BE1589096A6851405EBC1FB75F5E4E40BE1589096A68514098F738D3845F4E404D8237A4516A514098F738D3845F4E404D8237A4516A51405EBC1FB75F5E4E40BE1589096A6851405EBC1FB75F5E4E40
77336	11957	68.408576999999994	68.435526999999993	61.122948000000001	61.110840000000003	Молодежная	0103000020E6100000010000000500000075392520261A5140598B4F01308E4E4075392520261A5140E78D93C2BC8F4E409961A3ACDF1B5140E78D93C2BC8F4E409961A3ACDF1B5140598B4F01308E4E4075392520261A5140598B4F01308E4E40
77470	52178	68.066265000000001	68.076120000000003	60.510789000000003	60.507511000000001	Молодежная	0103000020E61000000100000005000000A5F78DAF3D0451401DAED51EF6404E40A5F78DAF3D0451400A14B18861414E4094A46B26DF0451400A14B18861414E4094A46B26DF0451401DAED51EF6404E40A5F78DAF3D0451401DAED51EF6404E40
77663	61225	70.336551	70.378888000000003	61.298561999999997	61.292788999999999	Лесная	0103000020E61000000100000005000000E99B340D8A95514074D0251C7AA54E40E99B340D8A95514007EA944737A64E40333674B33F98514007EA944737A64E40333674B33F98514074D0251C7AA54E40E99B340D8A95514074D0251C7AA54E40
77627	10543	69.817136000000005	69.844156999999996	60.658304000000001	60.650336000000003	Школьная	0103000020E610000001000000050000009818CBF44B745140ABB4C5353E534E409818CBF44B745140BA69334E43544E4020EC14AB06765140BA69334E43544E4020EC14AB06765140ABB4C5353E534E409818CBF44B745140ABB4C5353E534E40
77404	11095	69.212434999999999	69.227913000000001	61.404837999999998	61.396968999999999	Набережная	0103000020E61000000100000005000000A661F888984D51404E4354E1CFB24E40A661F888984D5140CA1649BBD1B34E4054556820964E5140CA1649BBD1B34E4054556820964E51404E4354E1CFB24E40A661F888984D51404E4354E1CFB24E40
77229	52159	69.541470000000004	69.568697999999998	61.297158000000003	61.281910000000003	Мира	0103000020E61000000100000005000000F870C971A76251402B357BA015A44E40F870C971A762514055DFF94509A64E403DD34B8C6564514055DFF94509A64E403DD34B8C656451402B357BA015A44E40F870C971A76251402B357BA015A44E40
77369	52184	68.490126000000004	68.517326999999995	61.069763000000002	61.04974	Гагарина	0103000020E61000000100000005000000D63A71395E1F5140CAA65CE15D864E40D63A71395E1F514045BC75FEED884E409E95B4E21B21514045BC75FEED884E409E95B4E21B215140CAA65CE15D864E40D63A71395E1F5140CAA65CE15D864E40
77475	52152	68.926599999999993	68.947413999999995	61.451785999999998	61.445121	Советская	0103000020E610000001000000050000004F1E166A4D3B5140A4E194B9F9B84E404F1E166A4D3B51403465A71FD4B94E407171546EA23C51403465A71FD4B94E407171546EA23C5140A4E194B9F9B84E404F1E166A4D3B5140A4E194B9F9B84E40
77218	11367	68.642444999999995	68.690577000000005	61.084975	61.075907999999998	Комсомольская	0103000020E61000000100000005000000A31EA2D11D2951409CC0745AB7894E40A31EA2D11D29514022FDF675E08A4E40AB97DF69322C514022FDF675E08A4E40AB97DF69322C51409CC0745AB7894E40A31EA2D11D2951409CC0745AB7894E40
81093	52206	68.234547000000006	68.254822000000004	61.487358	61.470793999999998	Кедровый	0103000020E61000000100000005000000FF976BD1020F5140969350FA42BC4E40FF976BD1020F5140D4B837BF61BE4E404913EF004F105140D4B837BF61BE4E404913EF004F105140969350FA42BC4E40FF976BD1020F5140969350FA42BC4E40
77645	11273	69.874780999999999	69.894453999999996	61.207680000000003	61.198622	Набережная	0103000020E61000000100000005000000618A7269FC775140102219726C994E40618A7269FC77514043041C42959A4E40B071FDBB3E79514043041C42959A4E40B071FDBB3E795140102219726C994E40618A7269FC775140102219726C994E40
77185	12191	68.288859000000002	68.303141999999994	61.400534999999998	61.387031	переулок Школьный	0103000020E61000000100000005000000F08975AA7C125140E3C4573B8AB14E40F08975AA7C125140A1F31ABB44B34E40D102B4AD66135140A1F31ABB44B34E40D102B4AD66135140E3C4573B8AB14E40F08975AA7C125140E3C4573B8AB14E40
77615	52113	69.905475999999993	69.947275000000005	60.066087000000003	60.051895000000002	Поспелова	0103000020E6100000010000000500000006D49B51F3795140B8E9CF7EA4064E4006D49B51F37951406BD8EF8975084E4061545227A07C51406BD8EF8975084E4061545227A07C5140B8E9CF7EA4064E4006D49B51F3795140B8E9CF7EA4064E40
77257	52084	69.540499999999994	69.562212000000002	60.652365000000003	60.635824	Школьная	0103000020E610000001000000050000003BDF4F8D9762514086014BAE62514E403BDF4F8D976251400C0742B280534E40CD5A0A48FB6351400C0742B280534E40CD5A0A48FB63514086014BAE62514E403BDF4F8D9762514086014BAE62514E40
77237	9980	69.912654000000003	69.931599000000006	59.973981999999999	59.963876999999997	Юбилейная	0103000020E6100000010000000500000012A452EC687A5140EC2E505260FB4D4012A452EC687A514043723271ABFC4D40207F69519F7B514043723271ABFC4D40207F69519F7B5140EC2E505260FB4D4012A452EC687A5140EC2E505260FB4D40
77581	61206	70.869234000000006	70.876878000000005	61.067213000000002	61.064183	Островского	0103000020E6100000010000000500000090A4A487A1B75140C6FA062637884E4090A4A487A1B75140DB6E826F9A884E403E25E7C41EB85140DB6E826F9A884E403E25E7C41EB85140C6FA062637884E4090A4A487A1B75140C6FA062637884E40
77575	61206	70.869234000000006	70.876878000000005	61.067213000000002	61.064183	1 микрорайон	0103000020E6100000010000000500000090A4A487A1B75140C6FA062637884E4090A4A487A1B75140DB6E826F9A884E403E25E7C41EB85140DB6E826F9A884E403E25E7C41EB85140C6FA062637884E4090A4A487A1B75140C6FA062637884E40
77724	61210	70.869234000000006	70.876878000000005	61.067213000000002	61.064183	Симонова	0103000020E6100000010000000500000090A4A487A1B75140C6FA062637884E4090A4A487A1B75140DB6E826F9A884E403E25E7C41EB85140DB6E826F9A884E403E25E7C41EB85140C6FA062637884E4090A4A487A1B75140C6FA062637884E40
77406	61161	70.869234000000006	70.876878000000005	61.067213000000002	61.064183	Лесная	0103000020E6100000010000000500000090A4A487A1B75140C6FA062637884E4090A4A487A1B75140DB6E826F9A884E403E25E7C41EB85140DB6E826F9A884E403E25E7C41EB85140C6FA062637884E4090A4A487A1B75140C6FA062637884E40
77226	11650	68.617624000000006	68.630370999999997	61.059916000000001	61.049273999999997	Мира	0103000020E61000000100000005000000624ED026872751408445459C4E864E40624ED02687275140EA40D653AB874E4032569BFF57285140EA40D653AB874E4032569BFF572851408445459C4E864E40624ED026872751408445459C4E864E40
77629	10305	69.816444000000004	69.849906000000004	60.409830999999997	60.402324999999998	Центральная	0103000020E61000000100000005000000FDC0559E407451407DAEB6627F334E40FDC0559E4074514088F19A5775344E4026AB22DC6476514088F19A5775344E4026AB22DC647651407DAEB6627F334E40FDC0559E407451407DAEB6627F334E40
77232	10817	69.581587999999996	69.596680000000006	60.840713999999998	60.825682	Центральная	0103000020E61000000100000005000000BFEFDFBC38655140AC72A1F2AF694E40BFEFDFBC3865514009A52F849C6B4E40598B4F013066514009A52F849C6B4E40598B4F0130665140AC72A1F2AF694E40BFEFDFBC38655140AC72A1F2AF694E40
77437	61169	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	Северная	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
77444	61134	73.677727000000004	73.750130999999996	61.622988999999997	61.597293000000001	переулок Тюменский	0103000020E61000000100000005000000702711E15F6B52409B90D61874CC4E40702711E15F6B52404562821ABECF4E40CF2D7425027052404562821ABECF4E40CF2D7425027052409B90D61874CC4E40702711E15F6B52409B90D61874CC4E40
81162	61134	\N	\N	\N	\N	переулок Парковый 	\N
81164	61134	\N	\N	\N	\N	Строителей	\N
77569	61134	73.677727000000004	73.750130999999996	61.622988999999997	61.597293000000001	Савуйская	0103000020E61000000100000005000000702711E15F6B52409B90D61874CC4E40702711E15F6B52404562821ABECF4E40CF2D7425027052404562821ABECF4E40CF2D7425027052409B90D61874CC4E40702711E15F6B52409B90D61874CC4E40
77322	61134	73.677727000000004	73.750130999999996	61.622988999999997	61.597293000000001	Ленина	0103000020E61000000100000005000000702711E15F6B52409B90D61874CC4E40702711E15F6B52404562821ABECF4E40CF2D7425027052404562821ABECF4E40CF2D7425027052409B90D61874CC4E40702711E15F6B52409B90D61874CC4E40
77621	52646	74.196736999999999	74.230109999999996	61.512081999999999	61.496581999999997	35 лет Победы	0103000020E61000000100000005000000713AC956978C524021E4BCFF8FBF4E40713AC956978C5240656F29E78BC14E40E21E4B1FBA8E5240656F29E78BC14E40E21E4B1FBA8E524021E4BCFF8FBF4E40713AC956978C524021E4BCFF8FBF4E40
77247	52634	74.035013000000006	74.070183	60.516117000000001	60.495350000000002	переулок Угутский	0103000020E61000000100000005000000D57B2AA73D8252406C09F9A0673F4E40D57B2AA73D8252406FF4311F10424E400D6FD6E07D8452406FF4311F10424E400D6FD6E07D8452406C09F9A0673F4E40D57B2AA73D8252406C09F9A0673F4E40
77624	52634	74.035013000000006	74.070183	60.516117000000001	60.495350000000002	Львовская	0103000020E61000000100000005000000D57B2AA73D8252406C09F9A0673F4E40D57B2AA73D8252406FF4311F10424E400D6FD6E07D8452406FF4311F10424E400D6FD6E07D8452406C09F9A0673F4E40D57B2AA73D8252406C09F9A0673F4E40
77135	26648	74.306700000000006	74.314515	61.681837999999999	61.676665	Центральная	0103000020E61000000100000005000000BA6B09F9A093524086AC6EF59CD64E40BA6B09F9A0935240C495B37746D74E407EC6850321945240C495B37746D74E407EC685032194524086AC6EF59CD64E40BA6B09F9A093524086AC6EF59CD64E40
77508	52607	71.274832000000004	71.316288999999998	61.310428999999999	61.290886999999998	Центральная	0103000020E610000001000000050000003CF9F4D896D1514070EA03C93BA54E403CF9F4D896D15140705D3123BCA74E4069C537143ED45140705D3123BCA74E4069C537143ED4514070EA03C93BA54E403CF9F4D896D1514070EA03C93BA54E40
77337	52591	73.168795000000003	73.198870999999997	61.287179000000002	61.270493999999999	Спортивная	0103000020E610000001000000050000009D2E8B89CD4A5240D2E1218C9FA24E409D2E8B89CD4A52408B8C0E48C2A44E40DC476E4DBA4C52408B8C0E48C2A44E40DC476E4DBA4C5240D2E1218C9FA24E409D2E8B89CD4A5240D2E1218C9FA24E40
77436	52591	73.168795000000003	73.198870999999997	61.287179000000002	61.270493999999999	Космонавтов	0103000020E610000001000000050000009D2E8B89CD4A5240D2E1218C9FA24E409D2E8B89CD4A52408B8C0E48C2A44E40DC476E4DBA4C52408B8C0E48C2A44E40DC476E4DBA4C5240D2E1218C9FA24E409D2E8B89CD4A5240D2E1218C9FA24E40
77600	52591	73.168795000000003	73.198870999999997	61.287179000000002	61.270493999999999	Зои Космодемьянской	0103000020E610000001000000050000009D2E8B89CD4A5240D2E1218C9FA24E409D2E8B89CD4A52408B8C0E48C2A44E40DC476E4DBA4C52408B8C0E48C2A44E40DC476E4DBA4C5240D2E1218C9FA24E409D2E8B89CD4A5240D2E1218C9FA24E40
77405	52601	72.870878000000005	72.912982	61.276707999999999	61.257703999999997	Центральная	0103000020E6100000010000000500000094331477BC3752403106D671FCA04E4094331477BC3752405245F12A6BA34E408CF50D4C6E3A52405245F12A6BA34E408CF50D4C6E3A52403106D671FCA04E4094331477BC3752403106D671FCA04E40
77361	61149	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	Ветеранов	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
77186	61093	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	Нефтяников	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
77631	61216	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	Хусаинова	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
78436	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №7	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
81163	56689	\N	\N	\N	\N	микрорайон №6	\N
77152	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №6	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
78291	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №4	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
77370	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №4	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
78422	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №3	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
77164	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №2	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
77199	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №10	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
78387	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	микрорайон №1	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
77413	56689	72.134304	72.186342999999994	61.632159000000001	61.607968	Набережная	0103000020E6100000010000000500000035EECD6F98085240DC813AE5D1CD4E4035EECD6F98085240A06F0B96EAD04E40AAB5300BED0B5240A06F0B96EAD04E40AAB5300BED0B5240DC813AE5D1CD4E4035EECD6F98085240DC813AE5D1CD4E40
77446	52625	74.773312000000004	74.861525999999998	61.148791000000003	61.126010999999998	Центральная	0103000020E61000000100000005000000AE669DF17DB15240D7F7E12021904E40AE669DF17DB1524036785F950B934E40D6A9F23D23B7524036785F950B934E40D6A9F23D23B75240D7F7E12021904E40AE669DF17DB15240D7F7E12021904E40
77427	5258	71.235656000000006	71.761899	61.276972000000001	60.966490999999998	Центральная	0103000020E61000000100000005000000CC46E7FC14CF51406D7022FAB57B4E40CC46E7FC14CF514030F488D173A34E40BAF605F4C2F0514030F488D173A34E40BAF605F4C2F051406D7022FAB57B4E40CC46E7FC14CF51406D7022FAB57B4E40
77538	5258	71.235656000000006	71.761899	61.276972000000001	60.966490999999998	Солнечная	0103000020E61000000100000005000000CC46E7FC14CF51406D7022FAB57B4E40CC46E7FC14CF514030F488D173A34E40BAF605F4C2F0514030F488D173A34E40BAF605F4C2F051406D7022FAB57B4E40CC46E7FC14CF51406D7022FAB57B4E40
77314	61131	72.129085000000003	72.143934000000002	61.228577000000001	61.218130000000002	Советская	0103000020E61000000100000005000000DE59BBED42085240642310AFEB9B4E40DE59BBED4208524014CFD902429D4E4014B2F3363609524014CFD902429D4E4014B2F33636095240642310AFEB9B4E40DE59BBED42085240642310AFEB9B4E40
77471	40335	73.224095000000005	73.288477999999998	61.272821	61.255181	микрорайон №1	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
77566	40335	73.224095000000005	73.288477999999998	61.272821	61.255181	Маяковского	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
77326	40335	73.224095000000005	73.288477999999998	61.272821	61.255181	Лесная	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
77527	40335	73.224095000000005	73.288477999999998	61.272821	61.255181	Ермака	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
77553	55063	73.224095000000005	73.288477999999998	61.272821	61.255181	Островского	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
77401	55063	73.224095000000005	73.288477999999998	61.272821	61.255181	Лесная	0103000020E610000001000000050000009E0C8E92574E5240C1C760C5A9A04E409E0C8E92574E5240BD546CCCEBA24E4064E76D6C76525240BD546CCCEBA24E4064E76D6C76525240C1C760C5A9A04E409E0C8E92574E5240C1C760C5A9A04E40
77519	61194	73.177598000000003	73.19896	61.25712	61.248842000000003	Мостостроителей	0103000020E61000000100000005000000717500C45D4B524085EFFD0DDA9F4E40717500C45D4B5240E292E34EE9A04E40944DB9C2BB4C5240E292E34EE9A04E40944DB9C2BB4C524085EFFD0DDA9F4E40717500C45D4B524085EFFD0DDA9F4E40
77145	61076	39.740085000000001	39.755958	54.631560999999998	54.621918999999998	Ленина	0103000020E610000001000000050000004DA1F31ABBDE434069E1B20A9B4F4B404DA1F31ABBDE4340EB36A8FDD6504B402593533BC3E04340EB36A8FDD6504B402593533BC3E0434069E1B20A9B4F4B404DA1F31ABBDE434069E1B20A9B4F4B40
81142	62101	36.096060000000001	36.106363999999999	52.977507000000003	52.973390999999999	Железнодорожная	0103000020E61000000100000005000000153AAFB14B0C4240419C8713987C4A40153AAFB14B0C4240384E0AF31E7D4A4062BCE6559D0D4240384E0AF31E7D4A4062BCE6559D0D4240419C8713987C4A40153AAFB14B0C4240419C8713987C4A40
77127	61070	93.130878999999993	93.131427000000002	56.034942999999998	56.032871	Юности	0103000020E61000000100000005000000EC2E50526048574050FEEE1D35044C40EC2E505260485740B01C210379044C40EEB3CA4C69485740B01C210379044C40EEB3CA4C6948574050FEEE1D35044C40EC2E50526048574050FEEE1D35044C40
81141	62100	39.574120999999998	39.596829999999997	52.604905000000002	52.603712000000002	Советская	0103000020E61000000100000005000000317903CC7CC94340F419506F464D4A40317903CC7CC94340EC17EC866D4D4A40C6A2E9EC64CC4340EC17EC866D4D4A40C6A2E9EC64CC4340F419506F464D4A40317903CC7CC94340F419506F464D4A40
81140	62100	40.925753	40.969940999999999	57.017251999999999	56.996293000000001	Кузнецова	0103000020E61000000100000005000000429605137F764440EB1D6E87867F4C40429605137F76444032E5435035824C405706D506277C444032E5435035824C405706D506277C4440EB1D6E87867F4C40429605137F764440EB1D6E87867F4C40
81180	62117	\N	\N	\N	\N	Матросова	\N
81179	61074	\N	\N	\N	\N	Дзержинского	\N
77173	61088	39.574120999999998	39.596829999999997	52.604905000000002	52.603712000000002	Мира	0103000020E61000000100000005000000317903CC7CC94340F419506F464D4A40317903CC7CC94340EC17EC866D4D4A40C6A2E9EC64CC4340EC17EC866D4D4A40C6A2E9EC64CC4340F419506F464D4A40317903CC7CC94340F419506F464D4A40
77208	61100	48.458396	48.494571000000001	56.772669999999998	56.743439000000002	Ленина	0103000020E61000000100000005000000014F5AB8AC3A484015C95702295F4C40014F5AB8AC3A4840D74CBED9E6624C4067463F1A4E3F4840D74CBED9E6624C4067463F1A4E3F484015C95702295F4C40014F5AB8AC3A484015C95702295F4C40
77180	61085	39.740085000000001	39.755958	54.631560999999998	54.621918999999998	Ленина	0103000020E610000001000000050000004DA1F31ABBDE434069E1B20A9B4F4B404DA1F31ABBDE4340EB36A8FDD6504B402593533BC3E04340EB36A8FDD6504B402593533BC3E0434069E1B20A9B4F4B404DA1F31ABBDE434069E1B20A9B4F4B40
77201	61085	39.580634000000003	39.588332000000001	52.597678999999999	52.588816999999999	Комсомольская	0103000020E610000001000000050000000C79043752CA4340172AFF5A5E4B4A400C79043752CA4340C440D7BE804C4A405B9885764ECB4340C440D7BE804C4A405B9885764ECB4340172AFF5A5E4B4A400C79043752CA4340172AFF5A5E4B4A40
41430	55025	44.080933000000002	44.094622999999999	56.288840999999998	56.288035999999998	Политехническая улица	0103000020E61000000100000005000000661536035C0A46400B09185DDE244C40661536035C0A4640395FECBDF8244C408639419B1C0C4640395FECBDF8244C408639419B1C0C46400B09185DDE244C40661536035C0A46400B09185DDE244C40
77808	61257	50.159813999999997	50.238857000000003	53.203619000000003	53.199675999999997	Гагарина	0103000020E61000000100000005000000B2B8FFC874144940E6E5B0FB8E994A40B2B8FFC87414494010ECF82F109A4A40D9B5BDDD921E494010ECF82F109A4A40D9B5BDDD921E4940E6E5B0FB8E994A40B2B8FFC874144940E6E5B0FB8E994A40
77499	61186	84.955662000000004	84.965875999999994	56.494017999999997	56.486375000000002	Октябрьская	0103000020E61000000100000005000000EB01F390293D5540C74B3789413E4C40EB01F390293D554052D158FB3B3F4C4071FF91E9D03D554052D158FB3B3F4C4071FF91E9D03D5540C74B3789413E4C40EB01F390293D5540C74B3789413E4C40
77767	61249	39.555050000000001	39.560997	52.576143999999999	52.572609	Речная	0103000020E6100000010000000500000089D2DEE00BC74340983270404B494A4089D2DEE00BC74340B0E42A16BF494A40BA13ECBFCEC74340B0E42A16BF494A40BA13ECBFCEC74340983270404B494A4089D2DEE00BC74340983270404B494A40
77765	61245	83.787582	83.792828	53.357362999999999	53.357035000000003	Мира	0103000020E61000000100000005000000C53A55BE67F254408143A852B3AD4A40C53A55BE67F2544075E61E12BEAD4A4099D6A6B1BDF2544075E61E12BEAD4A4099D6A6B1BDF254408143A852B3AD4A40C53A55BE67F254408143A852B3AD4A40
77915	61267	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	30 лет Победы	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77116	61065	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Газовиков	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77785	61251	83.770173	83.778131999999999	53.354751	53.354401000000003	Советская	0103000020E61000000100000005000000C8D0B1834AF15440B95510035DAD4A40C8D0B1834AF15440959C137B68AD4A4026FE28EACCF15440959C137B68AD4A4026FE28EACCF15440B95510035DAD4A40C8D0B1834AF15440B95510035DAD4A40
77409	61163	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	переулок Клубный	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77706	61237	84.954745000000003	84.954933999999994	56.51887	56.515146000000001	Зеленый переулок	0103000020E6100000010000000500000040C1C58A1A3D55402655DB4DF0414C4040C1C58A1A3D5540117008556A424C40A9F57EA31D3D5540117008556A424C40A9F57EA31D3D55402655DB4DF0414C4040C1C58A1A3D55402655DB4DF0414C40
77681	61230	40.515923999999998	40.520648999999999	64.540383000000006	64.537780999999995	Ленина	0103000020E610000001000000050000005A9C31CC0942444040DAFF006B2250405A9C31CC094244401F1494A295225040F9D85DA0A44244401F1494A295225040F9D85DA0A442444040DAFF006B2250405A9C31CC0942444040DAFF006B225040
77788	61252	50.188740000000003	50.196223000000003	53.222513999999997	53.219166000000001	Центральная	0103000020E6100000010000000500000039B9DFA1281849409432A9A10D9C4A4039B9DFA1281849407973B8567B9C4A408CDCD3D51D1949407973B8567B9C4A408CDCD3D51D1949409432A9A10D9C4A4039B9DFA1281849409432A9A10D9C4A40
77735	61244	83.791634000000002	83.802655999999999	53.370893000000002	53.367707000000003	Школьная	0103000020E61000000100000005000000B519A721AAF2544051C1E10511AF4A40B519A721AAF254405DA8FC6B79AF4A400B7C45B75EF354405DA8FC6B79AF4A400B7C45B75EF3544051C1E10511AF4A40B519A721AAF2544051C1E10511AF4A40
78049	61273	50.188740000000003	50.196223000000003	53.222513999999997	53.219166000000001	Центральная	0103000020E6100000010000000500000039B9DFA1281849409432A9A10D9C4A4039B9DFA1281849407973B8567B9C4A408CDCD3D51D1949407973B8567B9C4A408CDCD3D51D1949409432A9A10D9C4A4039B9DFA1281849409432A9A10D9C4A40
77263	52024	75.474007	75.497363000000007	61.010925	60.996012999999998	Центральная	0103000020E61000000100000005000000CEC4742156DE524007B29E5A7D7F4E40CEC4742156DE5240BADA8AFD65814E4064CF9ECBD4DF5240BADA8AFD65814E4064CF9ECBD4DF524007B29E5A7D7F4E40CEC4742156DE524007B29E5A7D7F4E40
77266	26519	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	Таежная	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
77191	26519	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	Молодежная	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
77230	26519	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	Мира	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
77269	26519	75.331597000000002	75.387337000000002	61.721885999999998	61.704768999999999	Ленина	0103000020E61000000100000005000000E99C9FE238D55240081EDFDE35DA4E40E99C9FE238D552405AB8ACC266DC4E40F8E12021CAD852405AB8ACC266DC4E40F8E12021CAD85240081EDFDE35DA4E40E99C9FE238D55240081EDFDE35DA4E40
77421	61117	76.637370000000004	76.696847000000005	61.960787000000003	61.935482999999998	Центральная	0103000020E61000000100000005000000E65C8AABCA285340637B2DE8BDF74E40E65C8AABCA28534003B68311FBFA4E4035D42824992C534003B68311FBFA4E4035D42824992C5340637B2DE8BDF74E40E65C8AABCA285340637B2DE8BDF74E40
77271	61117	76.637370000000004	76.696847000000005	61.960787000000003	61.935482999999998	Мелик Карамова	0103000020E61000000100000005000000E65C8AABCA285340637B2DE8BDF74E40E65C8AABCA28534003B68311FBFA4E4035D42824992C534003B68311FBFA4E4035D42824992C5340637B2DE8BDF74E40E65C8AABCA285340637B2DE8BDF74E40
81177	61117	\N	\N	\N	\N	70 лет Октября	\N
77211	29500	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Солнечная	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77202	29500	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Парковая	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77219	29500	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Мира	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77498	29500	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Ленина	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77303	29500	75.111303000000007	75.228740000000002	61.288355000000003	61.237743999999999	Комсомольская	0103000020E61000000100000005000000973C9E961FC75240FD6838656E9E4E40973C9E961FC75240AD510FD1E8A44E405FD218ADA3CE5240AD510FD1E8A44E405FD218ADA3CE5240FD6838656E9E4E40973C9E961FC75240FD6838656E9E4E40
77558	61108	76.868523999999994	76.902794999999998	60.959324000000002	60.939003999999997	переулок Молодёжный	0103000020E61000000100000005000000A1F2AFE5953753401668774831784E40A1F2AFE5953753404B22FB20CB7A4E4082FFAD64C73953404B22FB20CB7A4E4082FFAD64C73953401668774831784E40A1F2AFE5953753401668774831784E40
77329	61108	76.868523999999994	76.902794999999998	60.959324000000002	60.939003999999997	Энергетиков	0103000020E61000000100000005000000A1F2AFE5953753401668774831784E40A1F2AFE5953753404B22FB20CB7A4E4082FFAD64C73953404B22FB20CB7A4E4082FFAD64C73953401668774831784E40A1F2AFE5953753401668774831784E40
77238	61108	76.868523999999994	76.902794999999998	60.959324000000002	60.939003999999997	Школьная	0103000020E61000000100000005000000A1F2AFE5953753401668774831784E40A1F2AFE5953753404B22FB20CB7A4E4082FFAD64C73953404B22FB20CB7A4E4082FFAD64C73953401668774831784E40A1F2AFE5953753401668774831784E40
77612	61108	76.868523999999994	76.902794999999998	60.959324000000002	60.939003999999997	Лесная	0103000020E61000000100000005000000A1F2AFE5953753401668774831784E40A1F2AFE5953753404B22FB20CB7A4E4082FFAD64C73953404B22FB20CB7A4E4082FFAD64C73953401668774831784E40A1F2AFE5953753401668774831784E40
77587	61113	76.868523999999994	76.902794999999998	60.959324000000002	60.939003999999997	Савкинская	0103000020E61000000100000005000000A1F2AFE5953753401668774831784E40A1F2AFE5953753404B22FB20CB7A4E4082FFAD64C73953404B22FB20CB7A4E4082FFAD64C73953401668774831784E40A1F2AFE5953753401668774831784E40
77550	2120	76.646551000000002	76.669636999999994	60.649979000000002	60.639971000000003	Центральная	0103000020E610000001000000050000008D0C721761295340B8B1D991EA514E408D0C7217612953401C0B0A8332534E4042CC2555DB2A53401C0B0A8332534E4042CC2555DB2A5340B8B1D991EA514E408D0C721761295340B8B1D991EA514E40
77349	61141	74.478898000000001	77.063674000000006	62.000548000000002	59.630099000000001	Таежная	0103000020E61000000100000005000000AB07CC43A69E5240041F8315A7D04D40AB07CC43A69E5240030AF5F411004F40C1E61C3C13445340030AF5F411004F40C1E61C3C13445340041F8315A7D04D40AB07CC43A69E5240041F8315A7D04D40
77347	61141	74.478898000000001	77.063674000000006	62.000548000000002	59.630099000000001	Летная	0103000020E61000000100000005000000AB07CC43A69E5240041F8315A7D04D40AB07CC43A69E5240030AF5F411004F40C1E61C3C13445340030AF5F411004F40C1E61C3C13445340041F8315A7D04D40AB07CC43A69E5240041F8315A7D04D40
77539	52013	75.777951999999999	75.828940000000003	61.092244000000001	61.081516999999998	Центральная	0103000020E61000000100000005000000E6762FF7C9F15240B58828266F8A4E40E6762FF7C9F1524049A0C1A6CE8B4E4029965B5A0DF5524049A0C1A6CE8B4E4029965B5A0DF55240B58828266F8A4E40E6762FF7C9F15240B58828266F8A4E40
77196	3697	76.724649999999997	76.756530999999995	62.000776000000002	61.989353999999999	Центральная	0103000020E61000000100000005000000F8C264AA602E53405915E126A3FE4E40F8C264AA602E5340944F8F6D19004F4040DAFF006B305340944F8F6D19004F4040DAFF006B3053405915E126A3FE4E40F8C264AA602E53405915E126A3FE4E40
77551	2369	76.601427999999999	76.608750000000001	60.860886999999998	60.856031999999999	Зырянова	0103000020E6100000010000000500000084B9DDCB7D2653402C2AE274926D4E4084B9DDCB7D2653409946938B316E4E40295C8FC2F52653409946938B316E4E40295C8FC2F52653402C2AE274926D4E4084B9DDCB7D2653402C2AE274926D4E40
77431	52010	75.069575999999998	75.089787999999999	61.643464000000002	61.634402999999999	Новая	0103000020E610000001000000050000008925E5EE73C45240FDBD141E34D14E408925E5EE73C45240A11342075DD24E40B0E42A16BFC55240A11342075DD24E40B0E42A16BFC55240FDBD141E34D14E408925E5EE73C45240FDBD141E34D14E40
77511	6207	73.123357999999996	73.137893000000005	61.063578	61.059306999999997	Тобольская	0103000020E61000000100000005000000CCECF318E547524041B62C5F97874E40CCECF318E54752405F5FEB5223884E403B56293DD34852405F5FEB5223884E403B56293DD348524041B62C5F97874E40CCECF318E547524041B62C5F97874E40
9683	6582	72.426462999999998	72.440342000000001	61.124712000000002	61.115391000000002	Центральная	0103000020E610000001000000050000000F7D772B4B1B52405AA0DD21C58E4E400F7D772B4B1B52409AB51490F68F4E40894336902E1C52409AB51490F68F4E40894336902E1C52405AA0DD21C58E4E400F7D772B4B1B52405AA0DD21C58E4E40
77506	6019	73.084289999999996	73.112857000000005	60.937041000000001	60.923966	квартал 21	0103000020E610000001000000050000004F58E20165455240D74E948444764E404F58E201654552406D01A1F5F0774E40FB07910C394752406D01A1F5F0774E40FB07910C39475240D74E948444764E404F58E20165455240D74E948444764E40
77205	6680	72.645167000000001	72.679805999999999	61.160609999999998	61.146723999999999	Центральная	0103000020E61000000100000005000000575D876A4A295240E7C41EDAC7924E40575D876A4A2952408DB454DE8E944E40F96706F1812B52408DB454DE8E944E40F96706F1812B5240E7C41EDAC7924E40575D876A4A295240E7C41EDAC7924E40
77625	7184	71.694811999999999	71.710362000000003	60.166471000000001	60.159058000000002	Новая	0103000020E610000001000000050000009337C0CC77EC5140661536035C144E409337C0CC77EC5140C05DF6EB4E154E408E942D9276ED5140C05DF6EB4E154E408E942D9276ED5140661536035C144E409337C0CC77EC5140661536035C144E40
76431	6976	71.439727000000005	71.479512999999997	60.082875000000001	60.050691	Привокзальная	0103000020E61000000100000005000000C40AB77C24DC5140CC99ED0A7D064E40C40AB77C24DC5140F853E3A59B0A4E4070404B57B0DE5140F853E3A59B0A4E4070404B57B0DE5140CC99ED0A7D064E40C40AB77C24DC5140CC99ED0A7D064E40
76436	6976	71.439727000000005	71.479512999999997	60.082875000000001	60.050691	Новая	0103000020E61000000100000005000000C40AB77C24DC5140CC99ED0A7D064E40C40AB77C24DC5140F853E3A59B0A4E4070404B57B0DE5140F853E3A59B0A4E4070404B57B0DE5140CC99ED0A7D064E40C40AB77C24DC5140CC99ED0A7D064E40
76443	7528	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	Советская	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
76261	7528	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	Обская	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41850	7528	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	Магистральная	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
77101	7528	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	7 микрорайон	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41768	7528	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	5 микрорайон,	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41814	7528	72.736390999999998	72.875387000000003	60.767057999999999	60.678725	10 микрорайон Мамонтово	0103000020E610000001000000050000006684B707212F524022FDF675E0564E406684B707212F52404D11E0F42E624E40FD153257063852404D11E0F42E624E40FD1532570638524022FDF675E0564E406684B707212F524022FDF675E0564E40
41759	5402	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Микрорайон 1	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
76504	5402	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Байкальская	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
77110	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Шестая	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
41808	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Пятая	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
41764	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Промзона	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
41806	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Микрорайон 7	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
41895	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Микрорайон 5	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
41841	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Микрорайон 4	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
41807	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	Микрорайон 1	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
41769	55057	71.863416999999998	71.941165999999996	61.013528000000001	60.983336999999999	3-й микрорайон	0103000020E61000000100000005000000DE73603942F751402FF99FFCDD7D4E40DE73603942F7514047CA1649BB814E40DB8651103CFC514047CA1649BB814E40DB8651103CFC51402FF99FFCDD7D4E40DE73603942F751402FF99FFCDD7D4E40
77429	7386	72.026415999999998	72.045748000000003	60.336903999999997	60.314689000000001	Молодежная	0103000020E61000000100000005000000D505BCCCB00152409AB4A9BA47284E40D505BCCCB00152401FF296AB1F2B4E40E0F60489ED0252401FF296AB1F2B4E40E0F60489ED0252409AB4A9BA47284E40D505BCCCB00152409AB4A9BA47284E40
77649	61224	72.421881999999997	72.468952999999999	60.977334999999997	60.960166999999998	Центральная	0103000020E6100000010000000500000059315C1D001B524066D993C0E67A4E4059315C1D001B52403A1E3350197D4E401C977153031E52403A1E3350197D4E401C977153031E524066D993C0E67A4E4059315C1D001B524066D993C0E67A4E40
77324	61135	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	Мелитопольская	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
81172	62114	\N	\N	\N	\N	Борисова	\N
81170	62112	\N	\N	\N	\N	Строителей	\N
76831	60957	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	Комсомольская 	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
77268	61116	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	Центральная	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
77415	322	69.041908000000006	69.050549000000004	60.417622999999999	60.410435	Ленина	0103000020E61000000100000005000000365CE49EAE4251401F11532289344E40365CE49EAE4251405987A3AB74354E401D76DF313C4351405987A3AB74354E401D76DF313C4351401F11532289344E40365CE49EAE4251401F11532289344E40
77280	61118	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	Центральная	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
77525	590	68.791304999999994	68.831818999999996	59.821738000000003	59.807237999999998	Ленина	0103000020E61000000100000005000000520ABABDA4325140520B259353E74D40520ABABDA4325140B3F0F5B52EE94D40404CC2853C355140B3F0F5B52EE94D40404CC2853C355140520B259353E74D40520ABABDA4325140520B259353E74D40
77641	45965	68.956702000000007	68.966296	60.335363000000001	60.324727000000003	Ленина	0103000020E610000001000000050000002481069B3A3D5140699082A790294E402481069B3A3D5140ECA4BE2CED2A4E405C902DCBD73D5140ECA4BE2CED2A4E405C902DCBD73D5140699082A790294E402481069B3A3D5140699082A790294E40
77282	61119	37.517698000000003	38.180959999999999	56.742446999999999	55.649484000000001	Центральная	0103000020E61000000100000005000000319A95ED43C242403CA3AD4A22D34B40319A95ED43C24240B401D880085F4C402CF180B229174340B401D880085F4C402CF180B2291743403CA3AD4A22D34B40319A95ED43C242403CA3AD4A22D34B40
77320	61133	72.134088000000006	72.317245999999997	59.568114000000001	59.543022000000001	Таежная	0103000020E610000001000000050000004FB2D5E5940852401781B1BE81C54D404FB2D5E5940852402B33A5F5B7C84D405BB22AC24D1452402B33A5F5B7C84D405BB22AC24D1452401781B1BE81C54D404FB2D5E5940852401781B1BE81C54D40
77619	61214	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	мкр.3	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77895	61265	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	мкр.4	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77699	61235	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Школьная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
81174	62116	\N	\N	\N	\N	.Газопромысловая	\N
77360	61147	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Советская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
81166	55071	\N	\N	\N	\N	Королева	\N
41877	55071	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Кооперативная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77434	61168	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Центральная	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
81165	61220	\N	\N	\N	\N	Собянина	\N
77636	61220	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Астраханцева	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77375	61152	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Каксина	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77718	61241	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	Советская	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77705	61236	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	ЛПУ	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
77646	61222	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	3 микрорайон	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
42080	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Свободы	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
41966	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Революции	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
41926	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	О.Кошевого	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
41993	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Новикова	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
42081	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Ленина	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
42087	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Красноармейская	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
41999	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Комсомольская	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
41997	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Кармелюка	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
42095	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Железнодорожная	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
42014	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Ворошилова	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
42089	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Вокзальная	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
41994	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Бахтиярова	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
41910	55075	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	50 лет Октября	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
2175	922	65.548359000000005	65.634544000000005	57.120949000000003	57.090919999999997	улица Широтная	0103000020E61000000100000005000000E8DD585018635040B2463D44A38B4C40E8DD585018635040F1BDBF417B8F4C40E0F76F5E9C685040F1BDBF417B8F4C40E0F76F5E9C685040B2463D44A38B4C40E8DD585018635040B2463D44A38B4C40
3380	922	65.552501000000007	65.587992999999997	57.155465	57.136347999999998	улица Холодильная	0103000020E610000001000000050000007880272D5C6350400070ECD973914C407880272D5C6350401956F146E6934C40B95164ADA16550401956F146E6934C40B95164ADA16550400070ECD973914C407880272D5C6350400070ECD973914C40
15519	922	65.639043999999998	65.641819999999996	57.190635999999998	57.180705000000003	улица Строителей	0103000020E610000001000000050000001F2DCE18E6685040A29C685721974C401F2DCE18E66850405AB8ACC266984C40CC7A3194136950405AB8ACC266984C40CC7A319413695040A29C685721974C401F2DCE18E6685040A29C685721974C40
2339	922	65.561699000000004	65.608114999999998	57.136493999999999	57.104849999999999	улица Пермякова	0103000020E610000001000000050000008ACC5CE0F2635040287E8CB96B8D4C408ACC5CE0F2635040D40CA9A278914C40404D2D5BEB665040D40CA9A278914C40404D2D5BEB665040287E8CB96B8D4C408ACC5CE0F2635040287E8CB96B8D4C40
4441	922	65.549886999999998	65.570008999999999	57.148834999999998	57.137529999999998	улица Мельничная	0103000020E61000000100000005000000B75F3E5931635040041C42959A914C40B75F3E593163504005C078060D934C403E5B07077B64504005C078060D934C403E5B07077B645040041C42959A914C40B75F3E5931635040041C42959A914C40
16440	922	65.448745000000002	65.452742999999998	57.140825999999997	57.135556000000001	улица Ковалева	0103000020E6100000010000000500000096CFF23CB85C5040676325E659914C4096CFF23CB85C504097361C9606924C408C9FC6BDF95C504097361C9606924C408C9FC6BDF95C5040676325E659914C4096CFF23CB85C5040676325E659914C40
42044	922	65.689295999999999	65.714322999999993	57.170496999999997	57.164954000000002	улица Источник	0103000020E61000000100000005000000DF50F86C1D6C504015AC71361D954C40DF50F86C1D6C504076887FD8D2954C40F5F1D077B76D504076887FD8D2954C40F5F1D077B76D504015AC71361D954C40DF50F86C1D6C504015AC71361D954C40
2499	922	65.522659000000004	65.544630999999995	57.158599000000002	57.145954000000003	улица Герцена	0103000020E6100000010000000500000072FDBB3E73615040365CE49EAE924C4072FDBB3E73615040D316D7F84C944C40D158FB3BDB625040D316D7F84C944C40D158FB3BDB625040365CE49EAE924C4072FDBB3E73615040365CE49EAE924C40
3424	922	65.566595000000007	65.588504999999998	57.136133000000001	57.125483000000003	улица Геологоразведчиков	0103000020E61000000100000005000000F0C4AC17436450401C9AB2D30F904C40F0C4AC174364504004745FCE6C914C401422E010AA65504004745FCE6C914C401422E010AA6550401C9AB2D30F904C40F0C4AC17436450401C9AB2D30F904C40
4391	922	65.574734000000007	65.577177000000006	57.155977	57.155123000000003	улица Борцов Октября	0103000020E610000001000000050000008E791D71C8645040C0ED0912DB934C408E791D71C8645040CFF6E80DF7934C4038C0CC77F0645040CFF6E80DF7934C4038C0CC77F0645040C0ED0912DB934C408E791D71C8645040C0ED0912DB934C40
81131	922	65.257116999999994	65.859707	57.310547999999997	57.054262999999999	микрорайон Лесной	0103000020E61000000100000005000000B88FDC9A7450504001310917F2864C40B88FDC9A745050404AEB6F09C0A74C401B498270057750404AEB6F09C0A74C401B4982700577504001310917F2864C40B88FDC9A7450504001310917F2864C40
42380	922	65.530976999999993	65.541298999999995	57.151432	57.146774000000001	Ялуторовская	0103000020E61000000100000005000000677BF486FB61504099F38C7DC9924C40677BF486FB615040B0C8AF1F62934C40E1968FA4A4625040B0C8AF1F62934C40E1968FA4A462504099F38C7DC9924C40677BF486FB61504099F38C7DC9924C40
4040	922	65.584408999999994	65.602393000000006	57.185313999999998	57.181387999999998	Юганский проезд	0103000020E610000001000000050000003C9F01F56665504084F1D3B837974C403C9F01F566655040D7BE805EB8974C40B8955E9B8D665040D7BE805EB8974C40B8955E9B8D66504084F1D3B837974C403C9F01F56665504084F1D3B837974C40
42214	922	65.627877999999995	65.638289999999998	57.098782999999997	57.093882999999998	Энергостроителей	0103000020E610000001000000050000002FF834272F6850403F53AF5B048C4C402FF834272F6850404C33DDEBA48C4C4049D74CBED96850404C33DDEBA48C4C4049D74CBED96850403F53AF5B048C4C402FF834272F6850403F53AF5B048C4C40
42158	922	65.565059000000005	65.613371000000001	57.150446000000002	57.125639999999997	Энергетиков	0103000020E61000000100000005000000DF5339ED29645040E388B5F814904C40DF5339ED2964504032E884D041934C40265470784167504032E884D041934C402654707841675040E388B5F814904C40DF5339ED29645040E388B5F814904C40
42192	922	65.520583999999999	65.594569000000007	57.198403999999996	57.16675	Щербакова	0103000020E6100000010000000500000089B48D3F51615040D34D621058954C4089B48D3F51615040A2B2614D65994C40CA8D226B0D665040A2B2614D65994C40CA8D226B0D665040D34D621058954C4089B48D3F51615040D34D621058954C40
42077	922	65.658806999999996	65.669811999999993	57.128580999999997	57.125317000000003	Школьная	0103000020E610000001000000050000000ED8D5E4296A5040015130630A904C400ED8D5E4296A504088F19A5775904C40F99D2633DE6A504088F19A5775904C40F99D2633DE6A5040015130630A904C400ED8D5E4296A5040015130630A904C40
42226	922	65.564753999999994	65.578956000000005	57.190230999999997	57.185661000000003	Шишкова	0103000020E610000001000000050000004012F6ED24645040439259BDC3974C404012F6ED24645040BAD7497D59984C40AC74779D0D655040BAD7497D59984C40AC74779D0D655040439259BDC3974C404012F6ED24645040439259BDC3974C40
42164	922	65.548359000000005	65.634544000000005	57.120949000000003	57.090919999999997	Широтная	0103000020E61000000100000005000000E8DD585018635040B2463D44A38B4C40E8DD585018635040F1BDBF417B8F4C40E0F76F5E9C685040F1BDBF417B8F4C40E0F76F5E9C685040B2463D44A38B4C40E8DD585018635040B2463D44A38B4C40
4017	922	65.580313000000004	65.591649000000004	57.18291	57.181216999999997	Шаимский проезд	0103000020E61000000100000005000000651C23D923655040573D601E32974C40651C23D923655040410E4A9869974C40836DC493DD655040410E4A9869974C40836DC493DD655040573D601E32974C40651C23D923655040573D601E32974C40
81128	922	65.519721000000004	65.527213000000003	57.136606	57.104937999999997	Червишевский тракт	0103000020E61000000100000005000000D882DE1B43615040C70DBF9B6E8D4C40D882DE1B43615040FC372F4E7C914C40AB4198DBBD615040FC372F4E7C914C40AB4198DBBD615040C70DBF9B6E8D4C40D882DE1B43615040C70DBF9B6E8D4C40
41989	922	65.519721000000004	65.527213000000003	57.136606	57.104937999999997	Червишевский тракт	0103000020E61000000100000005000000D882DE1B43615040C70DBF9B6E8D4C40D882DE1B43615040FC372F4E7C914C40AB4198DBBD615040FC372F4E7C914C40AB4198DBBD615040C70DBF9B6E8D4C40D882DE1B43615040C70DBF9B6E8D4C40
42132	922	65.519721000000004	65.527213000000003	57.136606	57.104937999999997	Червишевский тракт	0103000020E61000000100000005000000D882DE1B43615040C70DBF9B6E8D4C40D882DE1B43615040FC372F4E7C914C40AB4198DBBD615040FC372F4E7C914C40AB4198DBBD615040C70DBF9B6E8D4C40D882DE1B43615040C70DBF9B6E8D4C40
42379	922	65.644839000000005	65.657782999999995	57.121456999999999	57.109380999999999	Чекистов	0103000020E61000000100000005000000DD0BCC0A45695040E2E65432008E4C40DD0BCC0A45695040656F29E78B8F4C405837DE1D196A5040656F29E78B8F4C405837DE1D196A5040E2E65432008E4C40DD0BCC0A45695040E2E65432008E4C40
42212	922	65.558554999999998	65.564610000000002	57.159520999999998	57.156557999999997	Циолковского	0103000020E610000001000000050000001B81785DBF635040ADF6B0170A944C401B81785DBF6350403A03232F6B944C40A73FFB91226450403A03232F6B944C40A73FFB9122645040ADF6B0170A944C401B81785DBF635040ADF6B0170A944C40
42197	922	65.532207999999997	65.552437999999995	57.160532000000003	57.150314000000002	Хохрякова	0103000020E61000000100000005000000DAAA24B20F625040C310397D3D934C40DAAA24B20F62504012FB04508C944C4054C4E9245B63504012FB04508C944C4054C4E9245B635040C310397D3D934C40DAAA24B20F625040C310397D3D934C40
42182	922	65.552501000000007	65.587992999999997	57.155465	57.136347999999998	Холодильная	0103000020E610000001000000050000007880272D5C6350400070ECD973914C407880272D5C6350401956F146E6934C40B95164ADA16550401956F146E6934C40B95164ADA16550400070ECD973914C407880272D5C6350400070ECD973914C40
42238	922	65.570718999999997	65.608114999999998	57.156173000000003	57.136493999999999	Харьковская	0103000020E610000001000000050000002C0DFCA886645040D40CA9A278914C402C0DFCA88664504055C2137AFD934C40404D2D5BEB66504055C2137AFD934C40404D2D5BEB665040D40CA9A278914C402C0DFCA886645040D40CA9A278914C40
42086	922	65.561133999999996	65.571068999999994	57.125082999999997	57.117221000000001	Федорова	0103000020E610000001000000050000001DAB949EE9635040C4B30419018F4C401DAB949EE96350408D2441B802904C409AB0FD648C6450408D2441B802904C409AB0FD648C645040C4B30419018F4C401DAB949EE9635040C4B30419018F4C40
42219	922	65.493247999999994	65.508195999999998	57.162590999999999	57.152160000000002	Уральская	0103000020E6100000010000000500000050340F60915F504033E197FA79934C4050340F60915F5040DDCF29C8CF944C4050FD834886605040DDCF29C8CF944C4050FD83488660504033E197FA79934C4050340F60915F504033E197FA79934C40
42162	922	65.501448999999994	65.510728999999998	57.144435000000001	57.132117999999998	Транспортная	0103000020E6100000010000000500000029E78BBD17605040419B1C3EE9904C4029E78BBD17605040EAB298D87C924C409A07B0C8AF605040EAB298D87C924C409A07B0C8AF605040419B1C3EE9904C4029E78BBD17605040419B1C3EE9904C40
42528	922	65.666056999999995	65.671069000000003	57.172069	57.171581000000003	Тобольский тракт	0103000020E6100000010000000500000066118AADA06A5040B8CEBF5DF6954C4066118AADA06A5040E5D3635B06964C40011764CBF26A5040E5D3635B06964C40011764CBF26A5040B8CEBF5DF6954C4066118AADA06A5040B8CEBF5DF6954C40
42208	922	65.548404000000005	65.563766000000001	57.194152000000003	57.186987000000002	Тимуровцев	0103000020E61000000100000005000000B83F170D196350407AE3A430EF974C40B83F170D19635040FC3905F9D9984C403126FDBD14645040FC3905F9D9984C403126FDBD146450407AE3A430EF974C40B83F170D196350407AE3A430EF974C40
42201	922	65.625246000000004	65.642196999999996	57.103583999999998	57.097037	Таллинская	0103000020E610000001000000050000001C7DCC070468504040C05AB56B8C4C401C7DCC0704685040C631923D428D4C40B72572C119695040C631923D428D4C40B72572C11969504040C05AB56B8C4C401C7DCC070468504040C05AB56B8C4C40
42170	922	65.486159999999998	65.490688000000006	57.158856999999998	57.152222999999999	Таврическая	0103000020E61000000100000005000000E527D53E1D5F50407959130B7C934C40E527D53E1D5F5040CEDE196D55944C408A22A46E675F5040CEDE196D55944C408A22A46E675F50407959130B7C934C40E527D53E1D5F50407959130B7C934C40
42215	922	65.579711000000003	65.581534000000005	57.106971000000001	57.103710999999997	Суходольская	0103000020E610000001000000050000006A882AFC19655040239EEC66468D4C406A882AFC196550406A4FC939B18D4C40C6E061DA376550406A4FC939B18D4C40C6E061DA37655040239EEC66468D4C406A882AFC19655040239EEC66468D4C40
42175	922	65.617008999999996	65.664214999999999	57.159961000000003	57.155918999999997	Судостроителей	0103000020E610000001000000050000009C1551137D6750409AE95E27F5934C409C1551137D67504057D11F9A79944C40CFA0A17F826A504057D11F9A79944C40CFA0A17F826A50409AE95E27F5934C409C1551137D6750409AE95E27F5934C40
42189	922	65.636968999999993	65.640822999999997	57.179406999999998	57.168906999999997	Судоремонтная	0103000020E6100000010000000500000036E49F19C468504061889CBE9E954C4036E49F19C468504034D6FECEF6964C4093E1783E0369504034D6FECEF6964C4093E1783E0369504061889CBE9E954C4036E49F19C468504061889CBE9E954C40
42174	922	65.640652000000003	65.651522	57.100171000000003	57.094866000000003	Станционная	0103000020E610000001000000050000007D073F71006950404DC0AF91248C4C407D073F7100695040FA804067D28C4C40F8A75489B2695040FA804067D28C4C40F8A75489B26950404DC0AF91248C4C407D073F71006950404DC0AF91248C4C40
42166	922	65.503524999999996	65.530895999999998	57.129035000000002	57.123153000000002	Ставропольская	0103000020E61000000100000005000000FAEDEBC039605040C0B33D7AC38F4C40FAEDEBC0396050400A85083884904C40F1643733FA6150400A85083884904C40F1643733FA615040C0B33D7AC38F4C40FAEDEBC039605040C0B33D7AC38F4C40
42157	922	65.536151000000004	65.543428000000006	57.140514000000003	57.122874000000003	Союзная	0103000020E61000000100000005000000EFAD484C50625040ADC3D155BA8F4C40EFAD484C50625040A950DD5CFC914C40C4EE3B86C7625040A950DD5CFC914C40C4EE3B86C7625040ADC3D155BA8F4C40EFAD484C50625040ADC3D155BA8F4C40
78160	922	65.535379000000006	65.560171999999994	57.160488000000001	57.147613999999997	Советская	0103000020E61000000100000005000000C6FD47A6436250404337FB03E5924C40C6FD47A64362504042B3EBDE8A944C40A208A9DBD963504042B3EBDE8A944C40A208A9DBD96350404337FB03E5924C40C6FD47A6436250404337FB03E5924C40
42146	922	65.546518000000006	65.566595000000007	57.156557999999997	57.144737999999997	Северная	0103000020E61000000100000005000000392BA226FA625040853E58C686924C40392BA226FA625040ADF6B0170A944C40F0C4AC1743645040ADF6B0170A944C40F0C4AC1743645040853E58C686924C40392BA226FA625040853E58C686924C40
42222	922	65.526601999999997	65.533726000000001	57.134310999999997	57.115622999999999	Самарцева	0103000020E610000001000000050000008600E0D8B36150402CD505BCCC8E4C408600E0D8B36150401C3F541A31914C4098C11891286250401C3F541A31914C4098C11891286250402CD505BCCC8E4C408600E0D8B36150402CD505BCCC8E4C40
42203	922	65.482979999999998	65.509741000000005	57.170766	57.159354999999998	Садовая	0103000020E61000000100000005000000D027F224E95E50401FBAA0BE65944C40D027F224E95E504066A208A9DB954C408B1BB7989F60504066A208A9DB954C408B1BB7989F6050401FBAA0BE65944C40D027F224E95E50401FBAA0BE65944C40
42382	922	65.509354999999999	65.518535	57.182791999999999	57.180509000000001	Рылеева	0103000020E6100000010000000500000076C3B645996050401CD13DEB1A974C4076C3B6459960504037FC6EBA65974C4035B56CAD2F61504037FC6EBA65974C4035B56CAD2F6150401CD13DEB1A974C4076C3B645996050401CD13DEB1A974C40
42220	922	65.513011000000006	65.518994000000006	57.158881999999998	57.156137999999999	Розы Люксембург	0103000020E6100000010000000500000040DF162CD5605040D8D47954FC934C4040DF162CD560504027F6D03E56944C407F349C323761504027F6D03E56944C407F349C3237615040D8D47954FC934C4040DF162CD5605040D8D47954FC934C40
42136	922	65.564627999999999	65.592027000000002	57.143151000000003	57.12903	Рижская	0103000020E61000000100000005000000FA997ADD22645040F819170E84904C40FA997ADD22645040E2B19FC552924C4056D636C5E3655040E2B19FC552924C4056D636C5E3655040F819170E84904C40FA997ADD22645040F819170E84904C40
42151	922	65.519972999999993	65.653300999999999	57.163685000000001	57.105505000000001	Республики	0103000020E610000001000000050000006473D53C4761504041481630818D4C406473D53C4761504042EC4CA1F3944C406C5CFFAECF69504042EC4CA1F3944C406C5CFFAECF69504041481630818D4C406473D53C4761504041481630818D4C40
42233	922	65.53192	65.541343999999995	57.139654	57.117444999999996	Революции	0103000020E61000000100000005000000A7052FFA0A625040130A1170088F4C40A7052FFA0A625040B760A92EE0914C40B1F84D61A5625040B760A92EE0914C40B1F84D61A5625040130A1170088F4C40A7052FFA0A625040130A1170088F4C40
78170	922	65.257116999999994	65.859707	57.310547999999997	57.054262999999999	Ратная	0103000020E61000000100000005000000B88FDC9A7450504001310917F2864C40B88FDC9A745050404AEB6F09C0A74C401B498270057750404AEB6F09C0A74C401B4982700577504001310917F2864C40B88FDC9A7450504001310917F2864C40
42199	922	65.544630999999995	65.572524000000001	57.157915000000003	57.145954000000003	Профсоюзная	0103000020E61000000100000005000000D158FB3BDB625040365CE49EAE924C40D158FB3BDB6250402046088F36944C40350BB43BA46450402046088F36944C40350BB43BA4645040365CE49EAE924C40D158FB3BDB625040365CE49EAE924C40
42139	922	65.579863000000003	65.587158000000002	57.139502999999998	57.135444	Пржевальского	0103000020E61000000100000005000000454AB3791C6550403F389F3A56914C40454AB3791C655040D158FB3BDB914C406DE525FF93655040D158FB3BDB914C406DE525FF936550403F389F3A56914C40454AB3791C6550403F389F3A56914C40
42239	922	65.548422000000002	65.556749999999994	57.199179000000001	57.199111000000002	Пирогова	0103000020E610000001000000050000000B9A9658196350400EA320787C994C400B9A96581963504066868DB27E994C401283C0CAA163504066868DB27E994C401283C0CAA16350400EA320787C994C400B9A9658196350400EA320787C994C40
42183	922	65.561699000000004	65.608114999999998	57.136493999999999	57.104849999999999	Пермякова	0103000020E610000001000000050000008ACC5CE0F2635040287E8CB96B8D4C408ACC5CE0F2635040D40CA9A278914C40404D2D5BEB665040D40CA9A278914C40404D2D5BEB665040287E8CB96B8D4C408ACC5CE0F2635040287E8CB96B8D4C40
42149	922	65.523539	65.541495999999995	57.157353999999998	57.146993999999999	Первомайская	0103000020E610000001000000050000008ECBB8A981615040A75A0BB3D0924C408ECBB8A98161504088F2052D24944C408CBAD6DEA762504088F2052D24944C408CBAD6DEA7625040A75A0BB3D0924C408ECBB8A981615040A75A0BB3D0924C40
42181	922	65.500209999999996	65.523674	57.133754000000003	57.128839999999997	Пархоменко	0103000020E6100000010000000500000075C8CD7003605040543541D47D904C4075C8CD7003605040C7DADFD91E914C40FEF0F3DF83615040C7DADFD91E914C40FEF0F3DF83615040543541D47D904C4075C8CD7003605040543541D47D904C40
42213	922	65.552249000000003	65.558681000000007	57.161796000000002	57.160423999999999	Пароходская	0103000020E61000000100000005000000EB8F300C586350402BBF0CC688944C40EB8F300C58635040D34F38BBB5944C4062F9F36DC1635040D34F38BBB5944C4062F9F36DC16350402BBF0CC688944C40EB8F300C586350402BBF0CC688944C40
42160	922	65.550910999999999	65.569488000000007	57.200792999999997	57.186216999999999	Павлова	0103000020E610000001000000050000006D00362042635040C87A6AF5D5974C406D003620426350400322C495B3994C40BADDCB7D726450400322C495B3994C40BADDCB7D72645040C87A6AF5D5974C406D00362042635040C87A6AF5D5974C40
42210	922	65.541173000000001	65.559354999999996	57.160659000000003	57.156689999999998	Осипенко	0103000020E610000001000000050000009B1E1494A26250401CCEFC6A0E944C409B1E1494A26250406F675F7990944C40A9F6E978CC6350406F675F7990944C40A9F6E978CC6350401CCEFC6A0E944C409B1E1494A26250401CCEFC6A0E944C40
42198	922	65.53828	65.551215999999997	57.160702000000001	57.147463000000002	Орджоникидзе	0103000020E61000000100000005000000D105F52D736250405E2F4D11E0924C40D105F52D736250406E3315E291944C400B42791F476350406E3315E291944C400B42791F476350405E2F4D11E0924C40D105F52D736250405E2F4D11E0924C40
42163	922	65.584722999999997	65.599716000000001	57.115583000000001	57.109679	Олимпийская	0103000020E61000000100000005000000048E041A6C6550406C0723F6098E4C40048E041A6C6550409E7C7A6CCB8E4C40D4B837BF616650409E7C7A6CCB8E4C40D4B837BF616650406C0723F6098E4C40048E041A6C6550406C0723F6098E4C40
42235	922	65.574779000000007	65.607180999999997	57.151989	57.135252999999999	Одесская	0103000020E610000001000000050000005EDBDB2DC9645040CBD765F84F914C405EDBDB2DC9645040062D246074934C402A70B20DDC665040062D246074934C402A70B20DDC665040CBD765F84F914C405EDBDB2DC9645040CBD765F84F914C40
42140	922	65.483771000000004	65.495637000000002	57.148795999999997	57.143487999999998	Новоселов	0103000020E6100000010000000500000035F0A31AF65E504029AF95D05D924C4035F0A31AF65E504047E350BF0B934C40016C4084B85F504047E350BF0B934C40016C4084B85F504029AF95D05D924C4035F0A31AF65E504029AF95D05D924C40
42200	922	65.542052999999996	65.547156000000001	57.221567999999998	57.210461000000002	Новая	0103000020E61000000100000005000000B7EC10FFB0625040AF0AD462F09A4C40B7EC10FFB062504089EB18575C9C4C40DA73999A0463504089EB18575C9C4C40DA73999A04635040AF0AD462F09A4C40B7EC10FFB0625040AF0AD462F09A4C40
42142	922	65.573628999999997	65.574805999999995	57.112591999999999	57.108848000000002	Николая Гондатти	0103000020E6100000010000000500000061C26856B6645040151E34BBEE8D4C4061C26856B664504047E5266A698E4C40DAE21A9FC964504047E5266A698E4C40DAE21A9FC9645040151E34BBEE8D4C4061C26856B6645040151E34BBEE8D4C40
42383	922	65.545098999999993	65.548475999999994	57.193469	57.184949000000003	Мусы Джалиля	0103000020E610000001000000050000004485EAE6E2625040C636A968AC974C404485EAE6E262504019E59997C3984C4004A9143B1A63504019E59997C3984C4004A9143B1A635040C636A968AC974C404485EAE6E2625040C636A968AC974C40
42209	922	65.546903999999998	65.554952999999998	57.146540000000002	57.142482000000001	Мурманская	0103000020E610000001000000050000004D83A279006350406422A5D93C924C404D83A2790063504026C79DD2C1924C404B7496598463504026C79DD2C1924C404B749659846350406422A5D93C924C404D83A279006350406422A5D93C924C40
42155	922	65.601682999999994	65.613200000000006	57.109684000000001	57.103388000000002	Моторостроителей	0103000020E61000000100000005000000C9E369F981665040416667D13B8D4C40C9E369F9816650407E7214200A8E4C40107A36AB3E6750407E7214200A8E4C40107A36AB3E675040416667D13B8D4C40C9E369F981665040416667D13B8D4C40
41955	922	65.480968000000004	65.513953999999998	57.140855999999999	57.128498	Московский тракт	0103000020E610000001000000050000000B9B012EC85E5040FBCC599F72904C400B9B012EC85E504002B9C49107924C407F69519FE460504002B9C49107924C407F69519FE4605040FBCC599F72904C400B9B012EC85E5040FBCC599F72904C40
42176	922	65.595547999999994	65.605816000000004	57.113931999999998	57.105960000000003	Монтажников	0103000020E61000000100000005000000AFCC5B751D6650409357E718908D4C40AFCC5B751D665040E3FBE252958E4C4030D978B0C5665040E3FBE252958E4C4030D978B0C56650409357E718908D4C40AFCC5B751D6650409357E718908D4C40
42134	922	65.552419999999998	65.554055000000005	57.220680999999999	57.211416	Молодежная	0103000020E61000000100000005000000016A6AD95A635040F2ECF2AD0F9B4C40016A6AD95A6350409EEC66463F9C4C40DC4B1AA3756350409EEC66463F9C4C40DC4B1AA375635040F2ECF2AD0F9B4C40016A6AD95A635040F2ECF2AD0F9B4C40
42184	922	65.503874999999994	65.527698000000001	57.146047000000003	57.140895	Мира	0103000020E610000001000000050000006891ED7C3F605040C095ECD808924C406891ED7C3F605040E75608ABB1924C40890AD5CDC5615040E75608ABB1924C40890AD5CDC5615040C095ECD808924C406891ED7C3F605040C095ECD808924C40
42221	922	65.503874999999994	65.527698000000001	57.146047000000003	57.140895	Мира	0103000020E610000001000000050000006891ED7C3F605040C095ECD808924C406891ED7C3F605040E75608ABB1924C40890AD5CDC5615040E75608ABB1924C40890AD5CDC5615040C095ECD808924C406891ED7C3F605040C095ECD808924C40
42195	922	65.564735999999996	65.587598	57.153351000000001	57.140577	Минская	0103000020E61000000100000005000000EDB776A224645040EFC8586DFE914C40EDB776A2246450408AE76C01A1934C407B4CA4349B6550408AE76C01A1934C407B4CA4349B655040EFC8586DFE914C40EDB776A224645040EFC8586DFE914C40
42135	922	65.425443000000001	65.431201000000001	57.213487999999998	57.211523	Метелева	0103000020E61000000100000005000000FAD346753A5B504008AD872F139B4C40FAD346753A5B5040520B2593539B4C40294014CC985B5040520B2593539B4C40294014CC985B504008AD872F139B4C40FAD346753A5B504008AD872F139B4C40
42229	922	65.549886999999998	65.570008999999999	57.148834999999998	57.137529999999998	Мельничная	0103000020E61000000100000005000000B75F3E5931635040041C42959A914C40B75F3E593163504005C078060D934C403E5B07077B64504005C078060D934C403E5B07077B645040041C42959A914C40B75F3E5931635040041C42959A914C40
42138	922	65.538702999999998	65.603461999999993	57.177889999999998	57.114513000000002	Мельникайте	0103000020E6100000010000000500000074D0251C7A625040C2FBAA5CA88E4C4074D0251C7A62504089247A19C5964C403D98141F9F66504089247A19C5964C403D98141F9F665040C2FBAA5CA88E4C4074D0251C7A625040C2FBAA5CA88E4C40
42223	922	65.488298	65.501233999999997	57.177802	57.172224999999997	Мельзаводская	0103000020E61000000100000005000000F12C4146405F5040DC4603780B964C40F12C4146405F5040EA944737C2964C402B69C53714605040EA944737C2964C402B69C53714605040DC4603780B964C40F12C4146405F5040DC4603780B964C40
42150	922	65.596975999999998	65.608744000000002	57.211182000000001	57.208457000000003	Мелиораторов	0103000020E61000000100000005000000CD1FD3DA34665040A7CF0EB8AE9A4C40CD1FD3DA346650407FC00303089B4C40B8E864A9F56650407FC00303089B4C40B8E864A9F5665040A7CF0EB8AE9A4C40CD1FD3DA34665040A7CF0EB8AE9A4C40
42144	922	65.525730999999993	65.533106000000004	57.175831000000002	57.167417999999998	Маяковского	0103000020E6100000010000000500000093DFA293A56150408061F9F36D954C4093DFA293A5615040BE4F55A181964C404AD3A0681E625040BE4F55A181964C404AD3A0681E6250408061F9F36D954C4093DFA293A56150408061F9F36D954C40
42211	922	65.607082000000005	65.620026999999993	57.188659999999999	57.180183	Малышева	0103000020E6100000010000000500000061FF756EDA665040C8258E3C10974C4061FF756EDA6650401C08C90226984C40C4E8B985AE6750401C08C90226984C40C4E8B985AE675040C8258E3C10974C4061FF756EDA665040C8258E3C10974C40
42169	922	65.544630999999995	65.557540000000003	57.145954000000003	57.139156	Малыгина	0103000020E61000000100000005000000D158FB3BDB625040668522DDCF914C40D158FB3BDB625040365CE49EAE924C408F8D40BCAE635040365CE49EAE924C408F8D40BCAE635040668522DDCF914C40D158FB3BDB625040668522DDCF914C40
42165	922	65.482665999999995	65.499787999999995	57.146213000000003	57.136527999999998	Магнитогорская	0103000020E610000001000000050000000839EFFFE35E5040807EDFBF79914C400839EFFFE35E504002A08A1BB7924C40BABBCE86FC5F504002A08A1BB7924C40BABBCE86FC5F5040807EDFBF79914C400839EFFFE35E5040807EDFBF79914C40
42178	922	65.498295999999996	65.515417999999997	57.167203000000001	57.161025000000002	Луначарского	0103000020E6100000010000000500000091EEE714E45F5040516B9A779C944C4091EEE714E45F504084656CE866954C404371C79BFC60504084656CE866954C404371C79BFC605040516B9A779C944C4091EEE714E45F5040516B9A779C944C40
41984	922	65.567062000000007	65.579404999999994	57.121881999999999	57.117742999999997	Логунова	0103000020E610000001000000050000007B336ABE4A6450409D2ADF33128F4C407B336ABE4A6450404CFC51D4998F4C40E388B5F8146550404CFC51D4998F4C40E388B5F8146550409D2ADF33128F4C407B336ABE4A6450409D2ADF33128F4C40
42196	922	65.509094000000005	65.522936999999999	57.143087000000001	57.123837000000002	Ленинградская	0103000020E61000000100000005000000C02500FF9460504073840CE4D98F4C40C02500FF94605040CBBDC0AC50924C409337C0CC77615040CBBDC0AC50924C409337C0CC7761504073840CE4D98F4C40C02500FF9460504073840CE4D98F4C40
42217	922	65.519774999999996	65.548225000000002	57.163620999999999	57.146979000000002	Ленина	0103000020E61000000100000005000000D1915CFE4361504072193735D0924C40D1915CFE436150402BF86D88F1944C4060764F1E166350402BF86D88F1944C4060764F1E1663504072193735D0924C40D1915CFE4361504072193735D0924C40
42218	922	65.526197999999994	65.527356999999995	57.155465	57.149673999999997	Крупской	0103000020E610000001000000050000001E4E603AAD615040DF87838428934C401E4E603AAD6150401956F146E6934C4044149337C06150401956F146E6934C4044149337C0615040DF87838428934C401E4E603AAD615040DF87838428934C40
42237	922	65.548979000000003	65.555527999999995	57.141323999999997	57.138086000000001	Красных Зорь	0103000020E6100000010000000500000036CCD078226350408A0453CDAC914C4036CCD07822635040E811A3E716924C40C90050C58D635040E811A3E716924C40C90050C58D6350408A0453CDAC914C4036CCD078226350408A0453CDAC914C40
42224	922	65.567053000000001	65.584535000000002	57.147379999999998	57.138041999999999	Котовского	0103000020E610000001000000050000005186AA984A645040BABC395CAB914C405186AA984A645040D00A0C59DD924C4083177D0569655040D00A0C59DD924C4083177D0569655040BABC395CAB914C405186AA984A645040BABC395CAB914C40
42194	922	65.568292999999997	65.594837999999996	57.154864000000003	57.141089999999998	Коммунаров	0103000020E61000000100000005000000ED629AE95E64504075E5B33C0F924C40ED629AE95E645040F4A96395D2934C40C11A67D311665040F4A96395D2934C40C11A67D31166504075E5B33C0F924C40ED629AE95E64504075E5B33C0F924C40
42185	922	65.569029999999998	65.578901999999999	57.145788000000003	57.140293999999997	Киевская	0103000020E61000000100000005000000581CCEFC6A6450409AE95E27F5914C40581CCEFC6A6450401B13622EA9924C40B265F9BA0C6550401B13622EA9924C40B265F9BA0C6550409AE95E27F5914C40581CCEFC6A6450409AE95E27F5914C40
42204	922	65.504611999999995	65.512120999999993	57.186796999999999	57.184241	Кемеровская	0103000020E61000000100000005000000D34A21904B6050408ACA863595974C40D34A21904B605040D6FECEF6E8974C4011A62897C6605040D6FECEF6E8974C4011A62897C66050408ACA863595974C40D34A21904B6050408ACA863595974C40
42230	922	65.548225000000002	65.558402999999998	57.146979000000002	57.142764999999997	Карская	0103000020E6100000010000000500000060764F1E16635040B8019F1F46924C4060764F1E1663504072193735D0924C4040BFEFDFBC63504072193735D0924C4040BFEFDFBC635040B8019F1F46924C4060764F1E16635040B8019F1F46924C40
42225	922	65.495340999999996	65.525919999999999	57.149030000000003	57.139868999999997	Карла Маркса	0103000020E610000001000000050000008CD7BCAAB35F5040B35C363AE7914C408CD7BCAAB35F5040BB0F406A13934C40FD135CACA8615040BB0F406A13934C40FD135CACA8615040B35C363AE7914C408CD7BCAAB35F5040B35C363AE7914C40
42143	922	65.658204999999995	65.690732999999994	57.159751	57.149113	Камчатская	0103000020E610000001000000050000001344DD07206A50404834812216934C401344DD07206A50406C4084B872944C4026512FF8346C50406C4084B872944C4026512FF8346C50404834812216934C401344DD07206A50404834812216934C40
42180	922	65.505007000000006	65.519074000000003	57.143878000000001	57.124042000000003	Калинина	0103000020E610000001000000050000001250E108526050404CAAB69BE08F4C401250E10852605040944E24986A924C400D8D278238615040944E24986A924C400D8D2782386150404CAAB69BE08F4C401250E108526050404CAAB69BE08F4C40
42148	922	65.649330000000006	65.654998000000006	57.150534	57.150328999999999	Казачьи Луга	0103000020E61000000100000005000000F3936A9F8E695040F8510DFB3D934C40F3936A9F8E695040D177B7B244934C40823CBB7CEB695040D177B7B244934C40823CBB7CEB695040F8510DFB3D934C40F3936A9F8E695040F8510DFB3D934C40
42216	922	65.549841999999998	65.553121000000004	57.223137000000001	57.211241000000001	Казаровская	0103000020E61000000100000005000000E7FD7F9C306350408449F1F1099B4C40E7FD7F9C3063504087C3D2C08F9C4C40C66E9F556663504087C3D2C08F9C4C40C66E9F55666350408449F1F1099B4C40E7FD7F9C306350408449F1F1099B4C40
42234	922	65.439187000000004	65.446796000000006	57.170678000000002	57.165529999999997	Институтская	0103000020E610000001000000050000000475CAA31B5C5040E140481630954C400475CAA31B5C5040C712D6C6D8954C40F4FE3F4E985C5040C712D6C6D8954C40F4FE3F4E985C5040E140481630954C400475CAA31B5C5040E140481630954C40
42161	922	65.568527000000003	65.578130000000002	57.155875000000002	57.149952999999996	Индустриальная	0103000020E6100000010000000500000027F911BF62645040F277EFA831934C4027F911BF62645040CBA145B6F3934C4089B5F81400655040CBA145B6F3934C4089B5F81400655040F277EFA831934C4027F911BF62645040F277EFA831934C40
42190	922	65.610442000000006	65.616640000000004	57.186939000000002	57.183017	Игримская	0103000020E61000000100000005000000B686527B1167504057CEDE196D974C40B686527B1167504069ACFD9DED974C40F3599E077767504069ACFD9DED974C40F3599E077767504057CEDE196D974C40B686527B1167504057CEDE196D974C40
4184	922	65.552392999999995	65.562094999999999	57.179884999999999	57.172269	Заречный проезд	0103000020E6100000010000000500000084622B685A635040AC8E1CE90C964C4084622B685A6350403E05C07806974C40B08F4E5DF96350403E05C07806974C40B08F4E5DF9635040AC8E1CE90C964C4084622B685A635040AC8E1CE90C964C40
42154	922	65.524482000000006	65.538577000000004	57.176020999999999	57.166519999999998	Заозерная	0103000020E61000000100000005000000CE55F31C91615040A110018750954C40CE55F31C9161504061342BDB87964C402E58AA0B7862504061342BDB87964C402E58AA0B78625040A110018750954C40CE55F31C91615040A110018750954C40
42236	922	65.633968999999993	65.651889999999995	57.174064000000001	57.172454000000002	Ершова	0103000020E61000000100000005000000616BB6F2926850403E0801F912964C40616BB6F2926850409AB4A9BA47964C40B9A5D590B86950409AB4A9BA47964C40B9A5D590B86950403E0801F912964C40616BB6F2926850403E0801F912964C40
42205	922	65.645736999999997	65.654252999999997	57.151949999999999	57.151881000000003	Домостроителей	0103000020E610000001000000050000004C3448C15369504020F12BD670934C404C3448C1536950404850FC1873934C40D593F947DF6950404850FC1873934C40D593F947DF69504020F12BD670934C404C3448C15369504020F12BD670934C40
42232	922	65.530276000000001	65.551017999999999	57.127569000000001	57.124930999999997	Демьяна Бедного	0103000020E61000000100000005000000A376BF0AF0615040D7A02FBDFD8F4C40A376BF0AF0615040E17D552E54904C40786000E143635040E17D552E54904C40786000E143635040D7A02FBDFD8F4C40A376BF0AF0615040D7A02FBDFD8F4C40
42101	922	65.554782000000003	65.562454000000002	57.126392000000003	57.121969999999997	Гнаровской	0103000020E61000000100000005000000359A5C8C81635040EB8B84B69C8F4C40359A5C8C81635040EF3CF19C2D904C4048E00F3FFF635040EF3CF19C2D904C4048E00F3FFF635040EB8B84B69C8F4C40359A5C8C81635040EB8B84B69C8F4C40
42588	922	65.621787999999995	65.642646999999997	57.132108000000002	57.122483000000003	Гилевская Роща	0103000020E61000000100000005000000E542E55FCB67504072A8DF85AD8F4C40E542E55FCB6750401EC539EAE8904C40D7F7E120216950401EC539EAE8904C40D7F7E1202169504072A8DF85AD8F4C40E542E55FCB67504072A8DF85AD8F4C40
42202	922	65.566595000000007	65.588504999999998	57.136133000000001	57.125483000000003	Геологоразведчиков	0103000020E61000000100000005000000F0C4AC17436450401C9AB2D30F904C40F0C4AC174364504004745FCE6C914C401422E010AA65504004745FCE6C914C401422E010AA6550401C9AB2D30F904C40F0C4AC17436450401C9AB2D30F904C40
42191	922	65.550461999999996	65.571168	57.179178	57.171537000000001	Газовиков	0103000020E6100000010000000500000035ECF7C43A635040E886A6ECF4954C4035ECF7C43A635040D314014EEF964C4064213A048E645040D314014EEF964C4064213A048E645040E886A6ECF4954C4035ECF7C43A635040E886A6ECF4954C40
42387	922	65.644577999999996	65.663227000000006	57.166369000000003	57.164797	Гагарина	0103000020E61000000100000005000000266E15C4406950404DBD6E1118954C40266E15C440695040BC0853944B954C40C0B4A84F726A5040BC0853944B954C40C0B4A84F726A50404DBD6E1118954C40266E15C4406950404DBD6E1118954C40
42186	922	65.602266999999998	65.615257	57.125757	57.118237000000001	Воровского	0103000020E61000000100000005000000711DE38A8B665040AD16D863228F4C40711DE38A8B6650401D1F2DCE18904C40A568E55E606750401D1F2DCE18904C40A568E55E60675040AD16D863228F4C40711DE38A8B665040AD16D863228F4C40
42207	922	65.490508000000005	65.533196000000004	57.149737999999999	57.141188	Волгоградская	0103000020E610000001000000050000004A9BAA7B645F5040384BC97212924C404A9BAA7B645F5040F67B629D2A934C40EA961DE21F625040F67B629D2A934C40EA961DE21F625040384BC97212924C404A9BAA7B645F5040384BC97212924C40
42168	922	65.578130000000002	65.602778999999998	57.193767000000001	57.180207000000003	Ватутина	0103000020E6100000010000000500000089B5F8140065504051C1E10511974C4089B5F81400655040A305685BCD984C40CCED5EEE93665040A305685BCD984C40CCED5EEE9366504051C1E10511974C4089B5F8140065504051C1E10511974C40
42193	922	65.516172999999995	65.568769000000003	57.176322999999996	57.163192000000002	Береговая	0103000020E6100000010000000500000001857AFA08615040037CB779E3944C4001857AFA086150402C4487C091964C40A27E17B6666450402C4487C091964C40A27E17B666645040037CB779E3944C4001857AFA08615040037CB779E3944C40
42156	922	65.487803999999997	65.488945000000001	57.157890999999999	57.152110999999998	Белинского	0103000020E61000000100000005000000E9B6442E385F5040512E8D5F78934C40E9B6442E385F504097AAB4C535944C40BC22F8DF4A5F504097AAB4C535944C40BC22F8DF4A5F5040512E8D5F78934C40E9B6442E385F5040512E8D5F78934C40
42153	922	65.440624999999997	65.476836000000006	57.172269	57.164661000000002	Барнаульская	0103000020E6100000010000000500000033333333335C50409DF6949C13954C4033333333335C5040AC8E1CE90C964C408D63247B845E5040AC8E1CE90C964C408D63247B845E50409DF6949C13954C4033333333335C50409DF6949C13954C40
42381	922	65.479062999999996	65.480366000000004	57.164611999999998	57.158706000000002	Бакинских Комиссаров	0103000020E61000000100000005000000506EDBF7A85E5040E9D66B7A50944C40506EDBF7A85E5040BB438A0112954C4010070951BE5E5040BB438A0112954C4010070951BE5E5040E9D66B7A50944C40506EDBF7A85E5040E9D66B7A50944C40
42179	922	65.458905000000001	65.482952999999995	57.180827000000001	57.175196	Бабарынка	0103000020E6100000010000000500000023BE13B35E5D5040EC3191D26C964C4023BE13B35E5D5040ED9DD15625974C405320B3B3E85E5040ED9DD15625974C405320B3B3E85E5040EC3191D26C964C4023BE13B35E5D5040EC3191D26C964C40
42206	922	65.440454000000003	65.476162000000002	57.158949999999997	57.153365000000001	Авторемонтная	0103000020E610000001000000050000001D59F965305C5040EFACDD76A1934C401D59F965305C50407FD93D7958944C4045662E70795E50407FD93D7958944C4045662E70795E5040EFACDD76A1934C401D59F965305C5040EFACDD76A1934C40
41908	922	65.557755999999998	65.562454000000002	57.121969999999997	57.118319999999997	9-го Мая проезд	0103000020E6100000010000000500000075C93846B26350403A3B191C258F4C4075C93846B2635040EB8B84B69C8F4C4048E00F3FFF635040EB8B84B69C8F4C4048E00F3FFF6350403A3B191C258F4C4075C93846B26350403A3B191C258F4C40
42228	922	65.257116999999994	65.859707	57.310547999999997	57.054262999999999	70 лет Октября	0103000020E61000000100000005000000B88FDC9A7450504001310917F2864C40B88FDC9A745050404AEB6F09C0A74C401B498270057750404AEB6F09C0A74C401B4982700577504001310917F2864C40B88FDC9A7450504001310917F2864C40
42171	922	65.257116999999994	65.859707	57.310547999999997	57.054262999999999	50 Лет Октября	0103000020E61000000100000005000000B88FDC9A7450504001310917F2864C40B88FDC9A745050404AEB6F09C0A74C401B498270057750404AEB6F09C0A74C401B4982700577504001310917F2864C40B88FDC9A7450504001310917F2864C40
42231	922	65.257116999999994	65.859707	57.310547999999997	57.054262999999999	30 лет Победы	0103000020E61000000100000005000000B88FDC9A7450504001310917F2864C40B88FDC9A745050404AEB6F09C0A74C401B498270057750404AEB6F09C0A74C401B4982700577504001310917F2864C40B88FDC9A7450504001310917F2864C40
42173	922	65.257116999999994	65.859707	57.310547999999997	57.054262999999999	30 Лет Победы	0103000020E61000000100000005000000B88FDC9A7450504001310917F2864C40B88FDC9A745050404AEB6F09C0A74C401B498270057750404AEB6F09C0A74C401B4982700577504001310917F2864C40B88FDC9A7450504001310917F2864C40
41961	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	микрорайон Южный	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42099	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	микрорайон Менделеево	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42029	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Рощинский переулок	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41946	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Ремезова	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42337	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Р. Люксембург	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42035	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Пушкина	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42378	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Полевая	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42587	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Панин бугор 	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42022	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Ленина	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42021	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Знаменского	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41970	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Заводская	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42026	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Железнодорожная	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41969	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Декабристов	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42515	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Береговая	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42023	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	9 микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41962	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	8 микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41949	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	7-й микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42094	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	7 микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41974	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	6 микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41967	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	4 микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41943	55078	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	2-я Трудовая	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41988	9877	65.528982999999997	65.529709999999994	57.092278999999998	57.083486000000001	Новая	0103000020E61000000100000005000000F54883DBDA61504041D653ABAF8A4C40F54883DBDA615040C58D5BCCCF8B4C404E97C5C4E6615040C58D5BCCCF8B4C404E97C5C4E661504041D653ABAF8A4C40F54883DBDA61504041D653ABAF8A4C40
42126	7814	65.423762999999994	65.427428000000006	57.111454000000002	57.111234000000003	Озерная	0103000020E610000001000000050000004F90D8EE1E5B5040051A6CEA3C8E4C404F90D8EE1E5B50401381EA1F448E4C404359F8FA5A5B50401381EA1F448E4C404359F8FA5A5B5040051A6CEA3C8E4C404F90D8EE1E5B5040051A6CEA3C8E4C40
42585	7814	65.412570000000002	65.423834999999997	57.109811000000001	57.108105000000002	Новая	0103000020E61000000100000005000000E353008C675A50405DC47762D68D4C40E353008C675A5040DBDE6E490E8E4C409CF9D51C205B5040DBDE6E490E8E4C409CF9D51C205B50405DC47762D68D4C40E353008C675A50405DC47762D68D4C40
81130	62094	65.321687999999995	65.381021000000004	57.229953000000002	57.203825999999999	Андрея Туполева	0103000020E6100000010000000500000000E143899654504089096AF8169A4C4000E1438996545040FD4E93196F9D4C40B685E7A562585040FD4E93196F9D4C40B685E7A56258504089096AF8169A4C4000E143899654504089096AF8169A4C40
42289	55088	66.895419000000004	66.923688999999996	56.316353999999997	56.288266	Советская	0103000020E61000000100000005000000E44D7E8B4EB950403D4679E6E5244C40E44D7E8B4EB95040B9FAB1497E284C4032AB77B81DBB5040B9FAB1497E284C4032AB77B81DBB50403D4679E6E5244C40E44D7E8B4EB950403D4679E6E5244C40
41932	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Ялуторовская	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42294	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Чернышевского	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42058	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Свердлова	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42115	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Республики	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42082	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Ражева	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42354	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Пушкина	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42008	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Путиловская	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42069	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Петропавловская	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42110	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Орджоникидзе	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42036	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Одоевского	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42078	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Непомнящего	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
78219	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	М. Садовая	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
78220	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Луначарского	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42037	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Луговая	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42043	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Ленина	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
41934	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Красина	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42072	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Карла Маркса	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42112	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Казанская	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42098	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	К. Маркса	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42066	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Ершова	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42009	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Деповская	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42013	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Большая	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
78196	55076	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	40 лет Победы	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42107	55086	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Дзержинского	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42057	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Энергетиков	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42304	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Щорса	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42064	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Шоссейная	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42287	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Школьная	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42061	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Сургутская	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42446	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Совхозная	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42102	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Республики	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42052	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Революционная	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42056	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Механическая	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42257	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Мелтораторов	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42060	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Королева	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42105	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Заводская	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42051	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Ермака	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
42106	55083	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Екатерины Дружининой	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
41978	55081	65.703902999999997	65.720350999999994	57.050846999999997	57.050185999999997	улица Октябрьская	0103000020E610000001000000050000009A232BBF0C6D5040C85BAE7E6C864C409A232BBF0C6D5040C30C8D2782864C4004A9143B1A6E5040C30C8D2782864C4004A9143B1A6E5040C85BAE7E6C864C409A232BBF0C6D5040C85BAE7E6C864C40
41915	24526	67.047926000000004	67.092078000000001	57.41825	57.384315999999998	Полевая	0103000020E6100000010000000500000033A8363811C350402EAA454431B14C4033A8363811C35040A8C64B3789B54C4097AB1F9BE4C55040A8C64B3789B54C4097AB1F9BE4C550402EAA454431B14C4033A8363811C350402EAA454431B14C40
42076	24526	67.047926000000004	67.092078000000001	57.41825	57.384315999999998	Пионерская	0103000020E6100000010000000500000033A8363811C350402EAA454431B14C4033A8363811C35040A8C64B3789B54C4097AB1F9BE4C55040A8C64B3789B54C4097AB1F9BE4C550402EAA454431B14C4033A8363811C350402EAA454431B14C40
42090	24526	67.047926000000004	67.092078000000001	57.41825	57.384315999999998	Мира	0103000020E6100000010000000500000033A8363811C350402EAA454431B14C4033A8363811C35040A8C64B3789B54C4097AB1F9BE4C55040A8C64B3789B54C4097AB1F9BE4C550402EAA454431B14C4033A8363811C350402EAA454431B14C40
42250	24407	67.064419000000001	67.085286999999994	57.46584	57.449364000000003	Береговая	0103000020E610000001000000050000006D8FDE701FC45040F8FF71C284B94C406D8FDE701FC45040969526A5A0BB4C4088F19A5775C55040969526A5A0BB4C4088F19A5775C55040F8FF71C284B94C406D8FDE701FC45040F8FF71C284B94C40
42573	23283	67.287470999999996	67.301242000000002	57.720790999999998	57.710681000000001	Зеленая	0103000020E6100000010000000500000019E3C3EC65D25040BD715298F7DA4C4019E3C3EC65D25040252026E142DC4C40A08B868C47D35040252026E142DC4C40A08B868C47D35040BD715298F7DA4C4019E3C3EC65D25040BD715298F7DA4C40
42481	24169	66.900566999999995	66.939741999999995	57.149600999999997	57.131926999999997	Мира	0103000020E61000000100000005000000D636C5E3A2B95040CD3AE3FBE2904C40D636C5E3A2B950407539252026934C405E2BA1BB24BC50407539252026934C405E2BA1BB24BC5040CD3AE3FBE2904C40D636C5E3A2B95040CD3AE3FBE2904C40
77911	23445	67.148807000000005	67.165353999999994	57.780315000000002	57.771801000000004	Мира	0103000020E610000001000000050000009E9ACB0D86C9504093020B60CAE24C409E9ACB0D86C9504004CAA65CE1E34C40D190F12895CA504004CAA65CE1E34C40D190F12895CA504093020B60CAE24C409E9ACB0D86C9504093020B60CAE24C40
42478	23614	66.953081999999995	66.975261000000003	57.325217000000002	57.311739000000003	Школьная	0103000020E61000000100000005000000001AA54BFFBC5040A2F14410E7A74C40001AA54BFFBC5040378DEDB5A0A94C401D041DAD6ABE5040378DEDB5A0A94C401D041DAD6ABE5040A2F14410E7A74C40001AA54BFFBC5040A2F14410E7A74C40
42480	24100	66.931297999999998	66.956451000000001	57.120244999999997	57.113545000000002	Советская	0103000020E610000001000000050000002235ED629ABB5040EACF7EA4888E4C402235ED629ABB5040F6402B30648F4C407F4E417E36BD5040F6402B30648F4C407F4E417E36BD5040EACF7EA4888E4C402235ED629ABB5040EACF7EA4888E4C40
42492	24316	67.465418	67.483249999999998	57.833838	57.823951999999998	Центральная	0103000020E61000000100000005000000103E9468C9DD5040A5BC564277E94C40103E9468C9DD5040BE141E34BBEA4C40B0726891EDDE5040BE141E34BBEA4C40B0726891EDDE5040A5BC564277E94C40103E9468C9DD5040A5BC564277E94C40
41900	23681	66.760392999999993	66.809414000000004	57.250565999999999	57.230426000000001	Советская	0103000020E61000000100000005000000DEC66647AAB05040F51263997E9D4C40DEC66647AAB05040A9BEF38B12A04C402CBB6070CDB35040A9BEF38B12A04C402CBB6070CDB35040F51263997E9D4C40DEC66647AAB05040F51263997E9D4C40
42483	23344	67.036732999999998	67.057357999999994	57.794454000000002	57.783347999999997	Школьная	0103000020E61000000100000005000000C66B5ED559C2504089B14CBF44E44C40C66B5ED559C2504094162EABB0E54C407E8AE3C0ABC3504094162EABB0E54C407E8AE3C0ABC3504089B14CBF44E44C40C66B5ED559C2504089B14CBF44E44C40
77890	24449	66.860007999999993	66.880920000000003	57.504176000000001	57.4998	Гагарина	0103000020E610000001000000050000001893FE5E0AB7504039454772F9BF4C401893FE5E0AB75040CCB6D3D688C04C401C9947FE60B85040CCB6D3D688C04C401C9947FE60B8504039454772F9BF4C401893FE5E0AB7504039454772F9BF4C40
42575	23766	67.191522000000006	67.203173000000007	57.538916999999998	57.534230999999998	Центральная	0103000020E61000000100000005000000BB9D7DE541CC504033C170AE61C44C40BB9D7DE541CC50401421753BFBC44C40899B53C900CD50401421753BFBC44C40899B53C900CD504033C170AE61C44C40BB9D7DE541CC504033C170AE61C44C40
42484	23870	67.803247999999996	67.832649000000004	57.492066000000001	57.481738	Центральная	0103000020E61000000100000005000000F4A44C6A68F35040C79E3D97A9BD4C40F4A44C6A68F350409DBCC804FCBE4C400403081F4AF550409DBCC804FCBE4C400403081F4AF55040C79E3D97A9BD4C40F4A44C6A68F35040C79E3D97A9BD4C40
42485	24268	66.472707999999997	66.498247000000006	57.135106999999998	57.128262999999997	Центральная	0103000020E61000000100000005000000AF230ED9409E5040B72407EC6A904C40AF230ED9409E5040F73AA92F4B914C4021956247E39F5040F73AA92F4B914C4021956247E39F5040B72407EC6A904C40AF230ED9409E5040B72407EC6A904C40
42392	24015	67.147926999999996	67.175360999999995	57.325819000000003	57.310082000000001	Школьная	0103000020E6100000010000000500000081CCCEA277C95040058A58C4B0A74C4081CCCEA277C950402DB5DE6FB4A94C409BFF571D39CB50402DB5DE6FB4A94C409BFF571D39CB5040058A58C4B0A74C4081CCCEA277C95040058A58C4B0A74C40
42576	24049	66.987559000000005	67.002848999999998	57.239778999999999	57.225952999999997	Школьная	0103000020E61000000100000005000000B6F7A92A34BF50406FB72407EC9C4C40B6F7A92A34BF504040A20914B19E4C40E27492AD2EC0504040A20914B19E4C40E27492AD2EC050406FB72407EC9C4C40B6F7A92A34BF50406FB72407EC9C4C40
42479	23539	67.226483999999999	67.247352000000006	57.659820000000003	57.648378999999998	Советская	0103000020E610000001000000050000004E44BFB67ECE5040E3344415FED24C404E44BFB67ECE5040959F54FB74D44C406AA67B9DD4CF5040959F54FB74D44C406AA67B9DD4CF5040E3344415FED24C404E44BFB67ECE5040E3344415FED24C40
42577	23727	67.142887000000002	67.160764	57.582315999999999	57.567968	Водопроводная	0103000020E610000001000000050000008201840F25C950405796E82CB3C84C408201840F25C9504001F8A75489CA4C40F29716F549CA504001F8A75489CA4C40F29716F549CA50405796E82CB3C84C408201840F25C950405796E82CB3C84C40
42372	24190	66.565154000000007	66.590783000000002	57.178651000000002	57.167324999999998	Центральная	0103000020E6100000010000000500000008CDAE7B2BA45040CF66D5E76A954C4008CDAE7B2BA45040E8323509DE964C4019028063CFA55040E8323509DE964C4019028063CFA55040CF66D5E76A954C4008CDAE7B2BA45040CF66D5E76A954C40
77046	23193	67.074813000000006	67.099687000000003	57.616225	57.607855999999998	Центральная	0103000020E61000000100000005000000341477BCC9C45040B456B439CECD4C40341477BCC9C4504022FDF675E0CE4C408735954561C6504022FDF675E0CE4C408735954561C65040B456B439CECD4C40341477BCC9C45040B456B439CECD4C40
42335	23810	67.227535000000003	67.246274	57.450032	57.439362000000003	Школьная	0103000020E6100000010000000500000081ECF5EE8FCE5040768D96033DB84C4081ECF5EE8FCE5040A51309A69AB94C40BAF605F4C2CF5040A51309A69AB94C40BAF605F4C2CF5040768D96033DB84C4081ECF5EE8FCE5040768D96033DB84C40
77986	23395	67.122900000000001	67.141378000000003	57.747179000000003	57.738239999999998	Краснознаменная	0103000020E610000001000000050000006B2BF697DDC75040AD4CF8A57EDE4C406B2BF697DDC7504006A1BC8FA3DF4C40EE974F560CC9504006A1BC8FA3DF4C40EE974F560CC95040AD4CF8A57EDE4C406B2BF697DDC75040AD4CF8A57EDE4C40
42570	23249	67.253990999999999	67.267330999999999	57.745103999999998	57.736379999999997	Сосновая	0103000020E610000001000000050000009D9E776341D05040D8B628B341DE4C409D9E776341D05040340F60915FDF4C403F8D7BF31BD15040340F60915FDF4C403F8D7BF31BD15040D8B628B341DE4C409D9E776341D05040D8B628B341DE4C40
41991	20691	66.253141999999997	66.346368999999996	56.682060999999997	56.622453999999998	Комсомольская	0103000020E610000001000000050000009ECF807A33905040D7A19A92AC4F4C409ECF807A3390504043705CC64D574C4049D6E1E82A96504043705CC64D574C4049D6E1E82A965040D7A19A92AC4F4C409ECF807A33905040D7A19A92AC4F4C40
77893	21912	65.978778000000005	65.994364000000004	56.643683000000003	56.638683999999998	Береговая	0103000020E61000000100000005000000D6027B4CA47E50403E3DB665C0514C40D6027B4CA47E5040DFFE5C3464524C407714E7A8A37F5040DFFE5C3464524C407714E7A8A37F50403E3DB665C0514C40D6027B4CA47E50403E3DB665C0514C40
77982	22090	65.957667999999998	65.974340999999995	56.714190000000002	56.708415000000002	Центральная	0103000020E610000001000000050000003F1BB96E4A7D5040787FBC57AD5A4C403F1BB96E4A7D5040AC90F2936A5B4C40B9895A9A5B7E5040AC90F2936A5B4C40B9895A9A5B7E5040787FBC57AD5A4C403F1BB96E4A7D5040787FBC57AD5A4C40
42488	21615	66.364057000000003	66.387699999999995	56.718561999999999	56.704827999999999	Мира	0103000020E610000001000000050000005038BBB54C9750400DA7CCCD375A4C405038BBB54C975040FD12F1D6F95B4C40302AA913D0985040FD12F1D6F95B4C40302AA913D09850400DA7CCCD375A4C405038BBB54C9750400DA7CCCD375A4C40
77851	21506	66.220461	66.234915000000001	56.777951999999999	56.762448999999997	Советский переулок	0103000020E61000000100000005000000C84274081C8E504017EFC7ED97614C40C84274081C8E5040CCED5EEE93634C40C095ECD8088F5040CCED5EEE93634C40C095ECD8088F504017EFC7ED97614C40C84274081C8E504017EFC7ED97614C40
42477	21751	66.189082999999997	66.196771999999996	56.679406	56.672443000000001	переулок Луговой	0103000020E61000000100000005000000B14E95EF198C50404AB6BA9C12564C40B14E95EF198C5040645A9BC6F6564C402F3196E9978C5040645A9BC6F6564C402F3196E9978C50404AB6BA9C12564C40B14E95EF198C50404AB6BA9C12564C40
77179	21426	66.450644999999994	66.470012999999994	56.762064000000002	56.736370000000001	Ленина	0103000020E61000000100000005000000C746205ED79C5040B5E0455F415E4C40C746205ED79C5040BFBA2A508B614C4078EC67B1149E5040BFBA2A508B614C4078EC67B1149E5040B5E0455F415E4C40C746205ED79C5040B5E0455F415E4C40
42326	21693	66.270568999999995	66.288284000000004	56.614950999999998	56.600766999999998	Ворошилова	0103000020E61000000100000005000000EE93A300519150400DC2DCEEE54C4C40EE93A300519150403DD2E0B6B64E4C4072FDBB3E739250403DD2E0B6B64E4C4072FDBB3E739250400DC2DCEEE54C4C40EE93A300519150400DC2DCEEE54C4C40
77850	21564	\N	\N	\N	\N	Новая	\N
42324	21050	66.652766	66.686300000000003	57.033301000000002	57.024729000000001	Школьная	0103000020E61000000100000005000000357C0BEBC6A95040A321E3512A834C40357C0BEBC6A9504049F6083543844C40ABCFD556ECAB504049F6083543844C40ABCFD556ECAB5040A321E3512A834C40357C0BEBC6A95040A321E3512A834C40
42571	21648	66.413734000000005	66.432293000000001	56.690291999999999	56.678308000000001	Гагарина	0103000020E6100000010000000500000092CF2B9E7A9A5040BE4EEACBD2564C4092CF2B9E7A9A50406058FE7C5B584C408B5242B0AA9B50406058FE7C5B584C408B5242B0AA9B5040BE4EEACBD2564C4092CF2B9E7A9A5040BE4EEACBD2564C40
77804	61256	65.946815999999998	65.975059000000002	56.792237	56.779437000000001	Строителей	0103000020E6100000010000000500000017D522A2987C50406C257497C4634C4017D522A2987C504030D7A20568654C40E92ADD5D677E504030D7A20568654C40E92ADD5D677E50406C257497C4634C4017D522A2987C50406C257497C4634C40
78111	22193	66.097337999999993	66.109672000000003	56.802731000000001	56.795495000000003	Школьная	0103000020E610000001000000050000001DAA29C93A865040D690B8C7D2654C401DAA29C93A865040213EB0E3BF664C405D52B5DD04875040213EB0E3BF664C405D52B5DD04875040D690B8C7D2654C401DAA29C93A865040D690B8C7D2654C40
42482	21852	66.118950999999996	66.143242000000001	56.645000000000003	56.635511000000001	Победы	0103000020E61000000100000005000000E5B4A7E49C875040C79FA86C58514C40E5B4A7E49C875040C3F5285C8F524C40795A7EE02A895040C3F5285C8F524C40795A7EE02A895040C79FA86C58514C40E5B4A7E49C875040C79FA86C58514C40
9939	20931	66.722026	66.735905000000002	57.038702999999998	57.033287000000001	Русанова	0103000020E6100000010000000500000026378AAC35AE5040E43098BF42844C4026378AAC35AE5040E8A04B38F4844C40A0FD481119AF5040E8A04B38F4844C40A0FD481119AF5040E43098BF42844C4026378AAC35AE5040E43098BF42844C40
42247	22055	66.043420999999995	66.068870000000004	56.748182999999997	56.735585	Первомайская	0103000020E610000001000000050000006ABDDF68C7825040CE3637A6275E4C406ABDDF68C78250402A36E675C45F4C403C6BB75D688450402A36E675C45F4C403C6BB75D68845040CE3637A6275E4C406ABDDF68C7825040CE3637A6275E4C40
77912	21462	66.397366000000005	66.416087000000005	56.818823999999999	56.80518	Набережная	0103000020E61000000100000005000000B6A2CD716E99504057B2632310674C40B6A2CD716E99504007978E39CF684C409C525E2BA19A504007978E39CF684C409C525E2BA19A504057B2632310674C40B6A2CD716E99504057B2632310674C40
42370	21098	66.504095000000007	66.533469999999994	56.875866000000002	56.861514999999997	Кирова	0103000020E61000000100000005000000F0C4AC1743A05040B8019F1F466E4C40F0C4AC1743A05040D4D688601C704C406AD95A5F24A25040D4D688601C704C406AD95A5F24A25040B8019F1F466E4C40F0C4AC1743A05040B8019F1F466E4C40
78110	21816	66.295955000000006	66.312296000000003	56.696762999999997	56.687815999999998	Школьная	0103000020E610000001000000050000009D853DEDF092504030D5CC5A0A584C409D853DEDF09250400B08AD872F594C40FCAA5CA8FC9350400B08AD872F594C40FCAA5CA8FC93504030D5CC5A0A584C409D853DEDF092504030D5CC5A0A584C40
42323	17510	67.353658999999993	67.419972000000001	56.835352999999998	56.806077000000002	Северная	0103000020E61000000100000005000000E8BB5B59A2D650406687F8872D674C40E8BB5B59A2D65040C8CEDBD8EC6A4C40164F3DD2E0DA5040C8CEDBD8EC6A4C40164F3DD2E0DA50406687F8872D674C40E8BB5B59A2D650406687F8872D674C40
77053	17510	67.353658999999993	67.419972000000001	56.835352999999998	56.806077000000002	Набережная	0103000020E61000000100000005000000E8BB5B59A2D650406687F8872D674C40E8BB5B59A2D65040C8CEDBD8EC6A4C40164F3DD2E0DA5040C8CEDBD8EC6A4C40164F3DD2E0DA50406687F8872D674C40E8BB5B59A2D650406687F8872D674C40
41954	17510	67.353658999999993	67.419972000000001	56.835352999999998	56.806077000000002	Ленина	0103000020E61000000100000005000000E8BB5B59A2D650406687F8872D674C40E8BB5B59A2D65040C8CEDBD8EC6A4C40164F3DD2E0DA5040C8CEDBD8EC6A4C40164F3DD2E0DA50406687F8872D674C40E8BB5B59A2D650406687F8872D674C40
42320	17510	67.353658999999993	67.419972000000001	56.835352999999998	56.806077000000002	Жукова	0103000020E61000000100000005000000E8BB5B59A2D650406687F8872D674C40E8BB5B59A2D65040C8CEDBD8EC6A4C40164F3DD2E0DA5040C8CEDBD8EC6A4C40164F3DD2E0DA50406687F8872D674C40E8BB5B59A2D650406687F8872D674C40
42473	20485	67.623225000000005	67.653722999999999	56.860166999999997	56.843383000000003	Ленина	0103000020E610000001000000050000002D431CEBE2E750404E8061F9F36B4C402D431CEBE2E75040990CC7F3196E4C402769FE98D6E95040990CC7F3196E4C402769FE98D6E950404E8061F9F36B4C402D431CEBE2E750404E8061F9F36B4C40
77853	20471	67.914648	67.927565000000001	56.844051999999998	56.834761999999998	Дениса Бобова	0103000020E6100000010000000500000084D6C39789FA5040C6F8307BD96A4C4084D6C39789FA5040CB0F5CE5096C4C4083FA96395DFB5040CB0F5CE5096C4C4083FA96395DFB5040C6F8307BD96A4C4084D6C39789FA5040C6F8307BD96A4C40
77976	19965	67.066278999999994	67.081460000000007	56.742215000000002	56.727970999999997	30 лет Победы	0103000020E61000000100000005000000575A46EA3DC45040DCB75A272E5D4C40575A46EA3DC45040E2CCAFE6005F4C40A9FB00A436C55040E2CCAFE6005F4C40A9FB00A436C55040DCB75A272E5D4C40575A46EA3DC45040DCB75A272E5D4C40
42369	20362	68.041471999999999	68.082920000000001	56.873981999999998	56.859265999999998	Ленина	0103000020E61000000100000005000000C8EC2C7AA70251404948A46DFC6D4C40C8EC2C7AA702514076A565A4DE6F4C40CC0BB08F4E05514076A565A4DE6F4C40CC0BB08F4E0551404948A46DFC6D4C40C8EC2C7AA70251404948A46DFC6D4C40
78107	20802	67.418381999999994	67.439150999999995	56.811861999999998	56.802908000000002	Колхозная	0103000020E610000001000000050000000BCF4BC5C6DA504030D978B0C5664C400BCF4BC5C6DA5040BD6E1118EB674C405DC0CB0C1BDC5040BD6E1118EB674C405DC0CB0C1BDC504030D978B0C5664C400BCF4BC5C6DA504030D978B0C5664C40
78200	20224	67.699268000000004	67.770467999999994	57.060890999999998	57.030715000000001	Центральная	0103000020E61000000100000005000000EBC891CEC0EC5040923F1878EE834C40EBC891CEC0EC504074CFBA46CB874C4054A703594FF1504074CFBA46CB874C4054A703594FF15040923F1878EE834C40EBC891CEC0EC5040923F1878EE834C40
42474	20224	67.699268000000004	67.770467999999994	57.060890999999998	57.030715000000001	Заречная	0103000020E61000000100000005000000EBC891CEC0EC5040923F1878EE834C40EBC891CEC0EC504074CFBA46CB874C4054A703594FF1504074CFBA46CB874C4054A703594FF15040923F1878EE834C40EBC891CEC0EC5040923F1878EE834C40
42321	20137	67.186473000000007	67.318274000000002	56.971938000000002	56.899886000000002	Лесная	0103000020E610000001000000050000009225732CEFCB50406B10E6762F734C409225732CEFCB5040ADDEE176687C4C40B24AE9995ED45040ADDEE176687C4C40B24AE9995ED450406B10E6762F734C409225732CEFCB50406B10E6762F734C40
42572	20043	67.776252999999997	67.800409000000002	56.883243	56.872943999999997	Ленина	0103000020E61000000100000005000000001B1021AEF15040A59E05A1BC6F4C40001B1021AEF15040E1B54B1B0E714C40249BABE639F35040E1B54B1B0E714C40249BABE639F35040A59E05A1BC6F4C40001B1021AEF15040A59E05A1BC6F4C40
42568	19922	67.481148000000005	67.516011000000006	56.747970000000002	56.728631999999998	Кирова	0103000020E610000001000000050000004B22FB20CBDE5040D76839D0435D4C404B22FB20CBDE5040CF31207BBD5F4C401558005306E15040CF31207BBD5F4C401558005306E15040D76839D0435D4C404B22FB20CBDE5040D76839D0435D4C40
42567	19868	67.328676999999999	67.376835	56.742013	56.721867000000003	Береговая	0103000020E61000000100000005000000A27C410B09D55040E4874A23665C4C40A27C410B09D550407A1A3048FA5E4C403E3F8C101ED850407A1A3048FA5E4C403E3F8C101ED85040E4874A23665C4C40A27C410B09D55040E4874A23665C4C40
42471	19757	67.935974000000002	67.953033000000005	56.977530000000002	56.962772000000001	Малахова	0103000020E6100000010000000500000001FA7DFFE6FB504094C0E61C3C7B4C4001FA7DFFE6FB5040F06DFAB31F7D4C4090C01F7EFEFC5040F06DFAB31F7D4C4090C01F7EFEFC504094C0E61C3C7B4C4001FA7DFFE6FB504094C0E61C3C7B4C40
77883	19597	66.293332000000007	66.304192999999998	56.375034999999997	56.366056	Речная	0103000020E61000000100000005000000B3B794F3C592504096404AECDA2E4C40B3B794F3C59250407CED992501304C4004ABEAE5779350407CED992501304C4004ABEAE57793504096404AECDA2E4C40B3B794F3C592504096404AECDA2E4C40
42312	19546	66.315753999999998	66.336783999999994	56.343977000000002	56.329042999999999	Молодежная	0103000020E6100000010000000500000032E543503594504026FDBD141E2A4C4032E5435035945040C1C93670072C4C403A747ADE8D955040C1C93670072C4C403A747ADE8D95504026FDBD141E2A4C4032E543503594504026FDBD141E2A4C40
77886	19647	66.313787000000005	66.320605	56.418019000000001	56.411839000000001	Центральная	0103000020E610000001000000050000003DBA111615945040D21BEE23B7344C403DBA111615945040A60D87A581354C40C87BD5CA84945040A60D87A581354C40C87BD5CA84945040D21BEE23B7344C403DBA111615945040D21BEE23B7344C40
41953	19388	66.247975999999994	66.298956000000004	56.326771999999998	56.301479	Строителей	0103000020E61000000100000005000000588CBAD6DE8F504024B726DD96264C40588CBAD6DE8F5040CF9F36AAD3294C405ABC581822935040CF9F36AAD3294C405ABC58182293504024B726DD96264C40588CBAD6DE8F504024B726DD96264C40
42074	19388	66.247975999999994	66.298956000000004	56.326771999999998	56.301479	Крупской	0103000020E61000000100000005000000588CBAD6DE8F504024B726DD96264C40588CBAD6DE8F5040CF9F36AAD3294C405ABC581822935040CF9F36AAD3294C405ABC58182293504024B726DD96264C40588CBAD6DE8F504024B726DD96264C40
42244	19388	66.247975999999994	66.298956000000004	56.326771999999998	56.301479	Дзержинского	0103000020E61000000100000005000000588CBAD6DE8F504024B726DD96264C40588CBAD6DE8F5040CF9F36AAD3294C405ABC581822935040CF9F36AAD3294C405ABC58182293504024B726DD96264C40588CBAD6DE8F504024B726DD96264C40
42566	19332	66.055916999999994	66.085552000000007	56.261943000000002	56.257078	Школьная	0103000020E610000001000000050000009692E52494835040B34291EEE7204C409692E524948350404435255987214C40E08618AF798550404435255987214C40E08618AF79855040B34291EEE7204C409692E52494835040B34291EEE7204C40
42309	19304	66.011189000000002	66.049592000000004	56.259408000000001	56.240433000000003	30 лет Победы	0103000020E61000000100000005000000CC441152B780504089F02F82C61E4C40CC441152B78050400F29064834214C402B89EC832C8350400F29064834214C402B89EC832C83504089F02F82C61E4C40CC441152B780504089F02F82C61E4C40
77975	18760	66.549252999999993	66.576975000000004	56.152343999999999	56.143929999999997	Садовая	0103000020E61000000100000005000000B60E0EF626A35040E674594C6C124C40B60E0EF626A35040F4DE180280134C4004E78C28EDA45040F4DE180280134C4004E78C28EDA45040E674594C6C124C40B60E0EF626A35040E674594C6C124C40
77977	19189	66.139010999999996	66.172274999999999	56.262922000000003	56.247340999999999	Центральная	0103000020E6100000010000000500000031B2648EE5885040DFFAB0DEA81F4C4031B2648EE588504010B3976DA7214C40C7BAB88D068B504010B3976DA7214C40C7BAB88D068B5040DFFAB0DEA81F4C4031B2648EE5885040DFFAB0DEA81F4C40
42310	19078	66.748103999999998	66.798490999999999	56.159478999999997	56.141227000000001	Вишнякова	0103000020E610000001000000050000006F8099EFE0AF5040F627F1B913124C406F8099EFE0AF50400BB3D0CE69144C409FC9FE791AB350400BB3D0CE69144C409FC9FE791AB35040F627F1B913124C406F8099EFE0AF5040F627F1B913124C40
77764	18309	66.460778000000005	66.472115000000002	56.114705999999998	56.108868999999999	Новая	0103000020E61000000100000005000000D82D02637D9D50402C465D6BEF0D4C40D82D02637D9D5040D653ABAFAE0E4C40DE3CD521379E5040D653ABAFAE0E4C40DE3CD521379E50402C465D6BEF0D4C40D82D02637D9D50402C465D6BEF0D4C40
42565	18861	66.011486000000005	66.016193000000001	56.130060999999998	56.116256999999997	Северная	0103000020E610000001000000050000002997C62FBC8050402D776682E10E4C402997C62FBC80504016BEBED6A5104C40255B5D4E0981504016BEBED6A5104C40255B5D4E098150402D776682E10E4C402997C62FBC8050402D776682E10E4C40
78100	18726	65.829414999999997	65.853526000000002	56.429125999999997	56.424123000000002	Шоссейная	0103000020E61000000100000005000000F5F3A622157550409F3D97A949364C40F5F3A6221575504080EECB99ED364C404912842BA076504080EECB99ED364C404912842BA07650409F3D97A949364C40F5F3A622157550409F3D97A949364C40
77950	19044	66.764381999999998	66.779625999999993	56.051088999999997	56.046543999999997	Нижнеманайская	0103000020E61000000100000005000000ABE97AA2EBB050409AE95E27F5054C40ABE97AA2EBB05040B91798158A064C401F477364E5B15040B91798158A064C401F477364E5B150409AE95E27F5054C40ABE97AA2EBB050409AE95E27F5054C40
42470	17820	66.260471999999993	66.281052000000003	56.164425999999999	56.153852999999998	Заречная	0103000020E610000001000000050000008461C092AB9050401CB28174B1134C408461C092AB905040594E42E90B154C406D1E87C1FC915040594E42E90B154C406D1E87C1FC9150401CB28174B1134C408461C092AB9050401CB28174B1134C40
42243	18016	66.560563000000002	66.575466000000006	56.086368999999998	56.068483999999998	Новый переулок	0103000020E610000001000000050000004016A243E0A350404E266E15C4084C404016A243E0A35040B131AF230E0B4C40707D586FD4A45040B131AF230E0B4C40707D586FD4A450404E266E15C4084C404016A243E0A350404E266E15C4084C40
77846	18206	66.558120000000002	66.573606999999996	56.110630999999998	56.105761000000001	Набережная	0103000020E6100000010000000500000096CFF23CB8A350409C189293890D4C4096CFF23CB8A350403E761728290E4C406D7022FAB5A450403E761728290E4C406D7022FAB5A450409C189293890D4C4096CFF23CB8A350409C189293890D4C40
78186	61281	65.903229999999994	65.918949999999995	56.377836000000002	56.373165999999998	Заречная	0103000020E6100000010000000500000007B13385CE79504054FD4AE7C32F4C4007B13385CE79504030A017EE5C304C40302AA913D07A504030A017EE5C304C40302AA913D07A504054FD4AE7C32F4C4007B13385CE79504054FD4AE7C32F4C40
42468	18958	65.730439000000004	65.766147000000004	56.367682000000002	56.360790999999999	Центральная	0103000020E61000000100000005000000452E3883BF6E504077D844662E2E4C40452E3883BF6E5040F8A92A34102F4C406D3B6D8D08715040F8A92A34102F4C406D3B6D8D0871504077D844662E2E4C40452E3883BF6E504077D844662E2E4C40
42469	19152	66.878045999999998	66.911185000000003	56.166722	56.159519000000003	Семкова	0103000020E610000001000000050000008D98D9E731B850409A0B5C1E6B144C408D98D9E731B8504009C3802557154C40C5E6E3DA50BA504009C3802557154C40C5E6E3DA50BA50409A0B5C1E6B144C408D98D9E731B850409A0B5C1E6B144C40
78102	18139	66.583668000000003	66.592346000000006	56.056925	56.046509	Кизакская	0103000020E6100000010000000500000031EE06D15AA550401EFCC401F4054C4031EE06D15AA5504093A9825149074C40A77A32FFE8A5504093A9825149074C40A77A32FFE8A550401EFCC401F4054C4031EE06D15AA550401EFCC401F4054C40
78097	18438	66.463842	66.480433000000005	56.203707999999999	56.197217999999999	Центральная	0103000020E61000000100000005000000B8205B96AF9D50405D177E703E194C40B8205B96AF9D50407FF78E1A131A4C40D4BA0D6ABF9E50407FF78E1A131A4C40D4BA0D6ABF9E50405D177E703E194C40B8205B96AF9D50405D177E703E194C40
42563	18624	65.931725	65.962474	56.427498	56.420628000000001	Школьная	0103000020E6100000010000000500000066F7E461A17B504015E46723D7354C4066F7E461A17B50407E8D2441B8364C4005508C2C997D50407E8D2441B8364C4005508C2C997D504015E46723D7354C4066F7E461A17B504015E46723D7354C40
42365	18304	66.488878	66.506097999999994	56.157589000000002	56.148502999999998	Нохрина	0103000020E61000000100000005000000F86EF3C6499F5040CF2D742502134C40F86EF3C6499F5040CC9A58E02B144C408BA4DDE863A05040CC9A58E02B144C408BA4DDE863A05040CF2D742502134C40F86EF3C6499F5040CF2D742502134C40
42246	18229	66.450654	66.490548000000004	56.163634000000002	56.151010999999997	Свободы	0103000020E61000000100000005000000F1F3DF83D79C50400A2B155454134C40F1F3DF83D79C5040C0417BF5F1144C4091477023659F5040C0417BF5F1144C4091477023659F50400A2B155454134C40F1F3DF83D79C50400A2B155454134C40
42493	18229	66.450654	66.490548000000004	56.163634000000002	56.151010999999997	Ленинградская	0103000020E61000000100000005000000F1F3DF83D79C50400A2B155454134C40F1F3DF83D79C5040C0417BF5F1144C4091477023659F5040C0417BF5F1144C4091477023659F50400A2B155454134C40F1F3DF83D79C50400A2B155454134C40
78059	18109	66.519132999999997	66.528880000000001	56.014423000000001	56.006098999999999	Заречная	0103000020E610000001000000050000008F519E7939A15040E7C41EDAC7004C408F519E7939A15040B5A7E49CD8014C408BE07F2BD9A15040B5A7E49CD8014C408BE07F2BD9A15040E7C41EDAC7004C408F519E7939A15040E7C41EDAC7004C40
78055	18033	66.600735999999998	66.609997000000007	56.042465999999997	56.025829000000002	Советская	0103000020E61000000100000005000000E961687572A65040EA245B5D4E034C40E961687572A650409198A0866F054C401F6ADB300AA750409198A0866F054C401F6ADB300AA75040EA245B5D4E034C40E961687572A65040EA245B5D4E034C40
42518	17845	66.187213999999997	66.197716	56.315555000000003	56.293072000000002	Советская	0103000020E610000001000000050000009DD66D50FB8B5040C9AF1F6283254C409DD66D50FB8B50406E8B321B64284C4057790261A78C50406E8B321B64284C4057790261A78C5040C9AF1F6283254C409DD66D50FB8B5040C9AF1F6283254C40
42393	17643	66.115887999999998	66.139854999999997	56.176473999999999	56.168446000000003	50 лет Октября	0103000020E61000000100000005000000ED7F80B56A8750402E9276A38F154C40ED7F80B56A875040124C35B396164C40A7CB6262F3885040124C35B396164C40A7CB6262F38850402E9276A38F154C40ED7F80B56A8750402E9276A38F154C40
41986	16942	68.860753000000003	68.925486000000006	59.156064999999998	59.131917000000001	Ленина	0103000020E61000000100000005000000C53BC09316375140AA6400A8E2904D40C53BC093163751406E861BF0F9934D40FAB9A1293B3B51406E861BF0F9934D40FAB9A1293B3B5140AA6400A8E2904D40C53BC09316375140AA6400A8E2904D40
42467	16942	68.860753000000003	68.925486000000006	59.156064999999998	59.131917000000001	Иртышская	0103000020E61000000100000005000000C53BC09316375140AA6400A8E2904D40C53BC093163751406E861BF0F9934D40FAB9A1293B3B51406E861BF0F9934D40FAB9A1293B3B5140AA6400A8E2904D40C53BC09316375140AA6400A8E2904D40
41950	17114	69.100801000000004	69.159192000000004	58.959314999999997	58.921173000000003	Школьная	0103000020E61000000100000005000000DD99098673465140A77A32FFE8754D40DD99098673465140F7C77BD5CA7A4D403B72A433304A5140F7C77BD5CA7A4D403B72A433304A5140A77A32FFE8754D40DD99098673465140A77A32FFE8754D40
42472	17114	69.066315000000003	69.198115999999999	58.965305000000001	58.897165000000001	Комсомольская	0103000020E61000000100000005000000FE0E45813E445140D40E7F4DD6724D40FE0E45813E44514028D53E1D8F7B4D401E34BBEEAD4C514028D53E1D8F7B4D401E34BBEEAD4C5140D40E7F4DD6724D40FE0E45813E445140D40E7F4DD6724D40
42562	17321	68.966583999999997	68.989185000000006	59.435951000000003	59.429101000000003	Центральная	0103000020E610000001000000050000008F352383DC3D514028D714C8ECB64D408F352383DC3D51404AD40B3ECDB74D40672C9ACE4E3F51404AD40B3ECDB74D40672C9ACE4E3F514028D714C8ECB64D408F352383DC3D514028D714C8ECB64D40
42506	17307	68.905696000000006	68.930508000000003	59.354539000000003	59.345699000000003	Мира	0103000020E610000001000000050000008E075BECF639514045A165DD3FAC4D408E075BECF63951400A14B18861AD4D40A62A6D718D3B51400A14B18861AD4D40A62A6D718D3B514045A165DD3FAC4D408E075BECF639514045A165DD3FAC4D40
42564	17224	68.826796999999999	68.848742999999999	59.276260000000001	59.264530000000001	Комсомольска	0103000020E6100000010000000500000094DBF63DEA345140CB67791EDCA14D4094DBF63DEA345140B398D87C5CA34D405FED28CE51365140B398D87C5CA34D405FED28CE51365140CB67791EDCA14D4094DBF63DEA345140CB67791EDCA14D40
42586	55090	69.021497999999994	69.035341000000003	59.135176999999999	59.130448999999999	Нефтяников	0103000020E610000001000000050000007BBB253960415140E065868DB2904D407BBB253960415140F015DD7A4D914D404FCDE50643425140F015DD7A4D914D404FCDE50643425140E065868DB2904D407BBB253960415140E065868DB2904D40
42465	16830	68.568657000000002	68.601202999999998	58.870783000000003	58.860228999999997	Стивы Дорониной	0103000020E610000001000000050000000E6954E0642451400F09DFFB1B6E4D400E6954E064245140D6743DD1756F4D4074D0251C7A265140D6743DD1756F4D4074D0251C7A2651400F09DFFB1B6E4D400E6954E0642451400F09DFFB1B6E4D40
42391	17031	68.881360999999998	68.904690000000002	59.090592000000001	59.077443000000002	Орджоникидзе	0103000020E6100000010000000500000012BEF73768385140EE26F8A6E9894D4012BEF73768385140BEA3C684988B4D402BC1E270E6395140BEA3C684988B4D402BC1E270E6395140EE26F8A6E9894D4012BEF73768385140EE26F8A6E9894D40
41987	17399	69.279961	69.348871000000003	59.606192	59.585489000000003	НПС	0103000020E61000000100000005000000F3C98AE1EA5151407995B54DF1CA4D40F3C98AE1EA515140658C0FB397CD4D4076E107E753565140658C0FB397CD4D4076E107E7535651407995B54DF1CA4D40F3C98AE1EA5151407995B54DF1CA4D40
41992	17521	69.980215999999999	70.008161999999999	59.551628000000001	59.532711999999997	Микрорайон Железнодорожный	0103000020E6100000010000000500000005C1E3DBBB7E5140E71725E82FC44D4005C1E3DBBB7E514069C70DBF9BC64D407AC4E8B98580514069C70DBF9BC64D407AC4E8B985805140E71725E82FC44D4005C1E3DBBB7E5140E71725E82FC44D40
42463	16729	68.775315000000006	68.821388999999996	58.767204999999997	58.755971000000002	Северная	0103000020E610000001000000050000004A46CEC29E315140BADC60A8C3604D404A46CEC29E315140F12900C633624D40D3122BA391345140F12900C633624D40D3122BA391345140BADC60A8C3604D404A46CEC29E315140BADC60A8C3604D40
77984	16910	68.788250000000005	68.818990999999997	59.029513000000001	59.020018999999998	Центральная	0103000020E610000001000000050000009CC420B07232514039268BFB8F824D409CC420B07232514047E7FC14C7834D40F92D3A596A34514047E7FC14C7834D40F92D3A596A34514039268BFB8F824D409CC420B07232514039268BFB8F824D40
42396	5639	65.861430999999996	65.879748000000006	57.323670999999997	57.313406999999998	Молодежная	0103000020E61000000100000005000000AD307DAF2177504032AB77B81DA84C40AD307DAF21775040F1D4230D6EA94C402C2E8ECA4D785040F1D4230D6EA94C402C2E8ECA4D78504032AB77B81DA84C40AD307DAF2177504032AB77B81DA84C40
77907	4147	66.016048999999995	66.033880999999994	57.135511999999999	57.123587999999998	Полевая	0103000020E610000001000000050000008B8862F206815040CA1649BBD18F4C408B8862F206815040971B0C7558914C402BBD361B2B825040971B0C7558914C402BBD361B2B825040CA1649BBD18F4C408B8862F206815040CA1649BBD18F4C40
77816	4693	66.242649	66.259007999999994	57.157983999999999	57.151408000000004	Трактовая	0103000020E610000001000000050000000EDAAB8F878F5040282D5C5661934C400EDAAB8F878F504048A5D8D138944C40C0594A969390504048A5D8D138944C40C0594A9693905040282D5C5661934C400EDAAB8F878F5040282D5C5661934C40
42024	4035	65.962007	65.990717000000004	57.154034000000003	57.140791999999998	Гагарина	0103000020E610000001000000050000007AE1CE85917D5040EBC4E57805924C407AE1CE85917D50406D3CD862B7934C40D7A546E8677F50406D3CD862B7934C40D7A546E8677F5040EBC4E57805924C407AE1CE85917D5040EBC4E57805924C40
41901	4026	65.417115999999993	65.437569999999994	56.956077999999998	56.928837999999999	Юбилейный квартал	0103000020E61000000100000005000000DAA84E07B25A50401AA4E029E4764C40DAA84E07B25A504069368FC3607A4C407CED9925015C504069368FC3607A4C407CED9925015C50401AA4E029E4764C40DAA84E07B25A50401AA4E029E4764C40
78150	7197	65.072350999999998	65.082070999999999	56.976446000000003	56.968449999999997	переулок Центральный	0103000020E610000001000000050000004EB51666A1445040D5E76A2BF67B4C404EB51666A1445040AF27BA2EFC7C4C40CD3CB9A640455040AF27BA2EFC7C4C40CD3CB9A640455040D5E76A2BF67B4C404EB51666A1445040D5E76A2BF67B4C40
42317	6900	65.148870000000002	65.175172000000003	57.086156000000003	57.078893000000001	Новая	0103000020E61000000100000005000000C1560916874950401171732A198A4C40C156091687495040562DE928078B4C4032CB9E04364B5040562DE928078B4C4032CB9E04364B50401171732A198A4C40C1560916874950401171732A198A4C40
42130	7095	65.034477999999993	65.097341999999998	57.087637999999998	57.067366	Коммунаров	0103000020E610000001000000050000009D9B36E334425040616EF7729F884C409D9B36E33442504084F1D3B8378B4C40BEA1F0D93A46504084F1D3B8378B4C40BEA1F0D93A465040616EF7729F884C409D9B36E334425040616EF7729F884C40
77059	5477	65.797301000000004	65.826207999999994	57.153574999999996	57.148766000000002	Аширбекова	0103000020E610000001000000050000005C04C6FA06735040DD60A8C30A934C405C04C6FA06735040D93D7958A8934C4063EC8497E0745040D93D7958A8934C4063EC8497E0745040DD60A8C30A934C405C04C6FA06735040DD60A8C30A934C40
42133	55087	65.399930999999995	65.464034999999996	57.014919999999996	57.003627000000002	Санаторная	0103000020E61000000100000005000000056A317898595040F9307BD976804C40056A317898595040350708E6E8814C40C24CDBBFB25D5040350708E6E8814C40C24CDBBFB25D5040F9307BD976804C40056A317898595040F9307BD976804C40
77818	6060	65.825327999999999	65.845495	57.119278000000001	57.112250000000003	Школьная	0103000020E61000000100000005000000471E882CD2745040EE7C3F355E8E4C40471E882CD2745040EF906280448F4C409E7B0F971C765040EF906280448F4C409E7B0F971C765040EE7C3F355E8E4C40471E882CD2745040EE7C3F355E8E4C40
42129	7061	66.288086000000007	66.320785000000001	57.148674	57.136434999999999	Молодежная	0103000020E61000000100000005000000DF1B430070925040CF83BBB376914C40DF1B430070925040FCE1E7BF07934C400803CFBD87945040FCE1E7BF07934C400803CFBD87945040CF83BBB376914C40DF1B430070925040CF83BBB376914C40
42284	7001	64.985448000000005	65.029430000000005	57.383510000000001	57.372762999999999	Новая	0103000020E6100000010000000500000027FA7C94113F50405514AFB2B6AF4C4027FA7C94113F504030D80DDB16B14C405DE15D2EE241504030D80DDB16B14C405DE15D2EE24150405514AFB2B6AF4C4027FA7C94113F50405514AFB2B6AF4C40
42490	6505	65.873334	65.880241999999996	56.970607999999999	56.965290000000003	Береговая	0103000020E61000000100000005000000081F4AB4E4775040F3936A9F8E7B4C40081F4AB4E4775040349E08E23C7C4C4033A48AE255785040349E08E23C7C4C4033A48AE255785040F3936A9F8E7B4C40081F4AB4E4775040F3936A9F8E7B4C40
78173	61279	65.181900999999996	65.191188999999994	57.129044999999998	57.125478000000001	Лесная	0103000020E6100000010000000500000005871744A44B50400A2FC1A90F904C4005871744A44B50402D5BEB8B84904C40B796C9703C4C50402D5BEB8B84904C40B796C9703C4C50400A2FC1A90F904C4005871744A44B50400A2FC1A90F904C40
42127	6863	65.215821000000005	65.247523000000001	57.091742000000004	57.074769000000003	Школьная	0103000020E610000001000000050000009032E202D04D504098E0D40792894C409032E202D04D5040B7D5AC33BE8B4C408080B56AD74F5040B7D5AC33BE8B4C408080B56AD74F504098E0D40792894C409032E202D04D504098E0D40792894C40
77743	6276	65.433492000000001	65.458887000000004	57.090451000000002	57.076172999999997	Озерная	0103000020E61000000100000005000000F8C43A55BE5B50404AEB6F09C0894C40F8C43A55BE5B5040FC71FBE5938B4C40D06394675E5D5040FC71FBE5938B4C40D06394675E5D50404AEB6F09C0894C40F8C43A55BE5B50404AEB6F09C0894C40
42124	6813	65.524150000000006	65.558097000000004	56.929628000000001	56.917662	Касьянова	0103000020E61000000100000005000000B30C71AC8B6150401764CBF275754C40B30C71AC8B61504013B9E00CFE764C40BABF7ADCB763504013B9E00CFE764C40BABF7ADCB76350401764CBF275754C40B30C71AC8B6150401764CBF275754C40
42034	6691	65.200855000000004	65.243678000000003	57.287125000000003	57.276383000000003	Центральная	0103000020E610000001000000050000003D0FEECEDA4C5040CF15A58460A34C403D0FEECEDA4C5040986E1283C0A44C404D309C6B984F5040986E1283C0A44C404D309C6B984F5040CF15A58460A34C403D0FEECEDA4C5040CF15A58460A34C40
42308	6386	66.070549999999997	66.089235000000002	57.005671	56.994709999999998	Советская	0103000020E61000000100000005000000E6AE25E483845040888043A8527F4C40E6AE25E4838450408FC4CBD3B9804C4026AAB706B68550408FC4CBD3B9804C4026AAB706B6855040888043A8527F4C40E6AE25E483845040888043A8527F4C40
42122	6090	65.406955999999994	65.455078	57.118892000000002	57.100825999999998	Озерная	0103000020E610000001000000050000004DBA2D910B5A5040124BCADDE78C4C404DBA2D910B5A5040C6E061DA378F4C4043C879FF1F5D5040C6E061DA378F4C4043C879FF1F5D5040124BCADDE78C4C404DBA2D910B5A5040124BCADDE78C4C40
42459	6780	65.162802999999997	65.190453000000005	57.290455999999999	57.281170000000003	Приозерная	0103000020E61000000100000005000000342C465D6B4A5040E44EE960FDA34C40342C465D6B4A5040A77686A92DA54C40359BC761304C5040A77686A92DA54C40359BC761304C5040E44EE960FDA34C40342C465D6B4A5040E44EE960FDA34C40
42505	7402	65.180364999999995	65.196444	56.961216999999998	56.949137	Центральная	0103000020E61000000100000005000000F415A4198B4B504037363B527D794C40F415A4198B4B5040FBAD9D28097B4C40B5DFDA89924C5040FBAD9D28097B4C40B5DFDA89924C504037363B527D794C40F415A4198B4B504037363B527D794C40
78043	6613	66.016920999999996	66.034653000000006	56.856411999999999	56.853656000000001	Школьная	0103000020E610000001000000050000006667D13B1581504060048D99446D4C406667D13B1581504073F38DE89E6D4C40556D37C13782504073F38DE89E6D4C40556D37C13782504060048D99446D4C406667D13B1581504060048D99446D4C40
41905	5972	65.855440000000002	65.886583999999999	57.134096	57.116003999999997	Совхозная	0103000020E610000001000000050000002DEC6987BF765040431A1538D98E4C402DEC6987BF7650402043C70E2A914C400A4AD1CABD7850402043C70E2A914C400A4AD1CABD785040431A1538D98E4C402DEC6987BF765040431A1538D98E4C40
78034	7272	65.063152000000002	65.073177999999999	57.109073000000002	57.102722999999997	Центральная	0103000020E6100000010000000500000054ABAFAE0A44504004C6FA06268D4C4054ABAFAE0A44504035F0A31AF68D4C405932C7F2AE44504035F0A31AF68D4C405932C7F2AE44504004C6FA06268D4C4054ABAFAE0A44504004C6FA06268D4C40
42033	5966	65.331029999999998	65.373287000000005	57.225003000000001	57.207999000000001	60 лет Октября	0103000020E61000000100000005000000ACFF73982F555040E44C13B69F9A4C40ACFF73982F5550403E40F7E5CC9C4C40684128EFE35750403E40F7E5CC9C4C40684128EFE3575040E44C13B69F9A4C40ACFF73982F555040E44C13B69F9A4C40
42560	7445	65.375578000000004	65.3904	56.841816999999999	56.830112999999997	Рабочая	0103000020E6100000010000000500000037C64E7809585040027E8D24416A4C4037C64E7809585040C11BD2A8C06B4C40F0164850FC585040C11BD2A8C06B4C40F0164850FC585040027E8D24416A4C4037C64E7809585040027E8D24416A4C40
77843	5565	65.053827999999996	65.104788999999997	57.253833	57.238128000000003	Транспортная	0103000020E61000000100000005000000FBE6FEEA71435040862172FA7A9E4C40FBE6FEEA71435040A2D288997DA04C40C1FEEBDCB4465040A2D288997DA04C40C1FEEBDCB4465040862172FA7A9E4C40FBE6FEEA71435040862172FA7A9E4C40
41981	5891	65.252302	65.287443999999994	57.237918000000001	57.216070999999999	Семеновых	0103000020E61000000100000005000000C9AD49B725505040984EEB36A89B4C40C9AD49B7255050409B90D618749E4C409CDB847B655250409B90D618749E4C409CDB847B65525040984EEB36A89B4C40C9AD49B725505040984EEB36A89B4C40
42245	4195	66.193646000000001	66.209132999999994	57.131517000000002	57.116292000000001	Центральная	0103000020E61000000100000005000000144031B2648C5040AA6400A8E28E4C40144031B2648C50401CEF8E8CD5904C40EBE0606F628D50401CEF8E8CD5904C40EBE0606F628D5040AA6400A8E28E4C40144031B2648C5040AA6400A8E28E4C40
42501	5842	65.738578000000004	65.754171999999997	56.885328000000001	56.872359000000003	Ленина	0103000020E61000000100000005000000E3E2A8DC446F504086AFAF75A96F4C40E3E2A8DC446F5040D61D8B6D52714C40C5E3A25A44705040D61D8B6D52714C40C5E3A25A4470504086AFAF75A96F4C40E3E2A8DC446F504086AFAF75A96F4C40
41980	5703	65.883071999999999	65.971439000000004	57.187674999999999	57.168990000000001	Школьная	0103000020E61000000100000005000000DA006C4084785040EFACDD76A1954C40DA006C40847850406EA301BC05984C40C6C37B0E2C7E50406EA301BC05984C40C6C37B0E2C7E5040EFACDD76A1954C40DA006C4084785040EFACDD76A1954C40
42121	5703	65.883071999999999	65.971439000000004	57.187674999999999	57.168990000000001	Ленина	0103000020E61000000100000005000000DA006C4084785040EFACDD76A1954C40DA006C40847850406EA301BC05984C40C6C37B0E2C7E50406EA301BC05984C40C6C37B0E2C7E5040EFACDD76A1954C40DA006C4084785040EFACDD76A1954C40
41979	5526	65.100854999999996	65.154798999999997	57.266469999999998	57.249918000000001	Новая	0103000020E61000000100000005000000D6A887687446504043572250FD9F4C40D6A8876874465040BCAE5FB01BA24C40069D103AE8495040BCAE5FB01BA24C40069D103AE849504043572250FD9F4C40D6A887687446504043572250FD9F4C40
42242	7149	65.016171	65.039732999999998	57.143073000000001	57.127091	Гагарина	0103000020E61000000100000005000000310917F208415040D74E948444904C40310917F20841504066F84F3750924C409BE447FC8A42504066F84F3750924C409BE447FC8A425040D74E948444904C40310917F208415040D74E948444904C40
42561	6599	66.011172000000002	66.030233999999993	56.981355999999998	56.972718	Мира	0103000020E6100000010000000500000061A8C30AB7805040821DFF05827C4C4061A8C30AB7805040DFDDCA129D7D4C408B4E965AEF815040DFDDCA129D7D4C408B4E965AEF815040821DFF05827C4C4061A8C30AB7805040821DFF05827C4C40
42119	5359	65.741478999999998	65.797928999999996	57.156812000000002	57.144669	М. Джалиля	0103000020E61000000100000005000000EEEA5564746F50405DDF878384924C40EEEA5564746F504068CF656A12944C40EBE1CB441173504068CF656A12944C40EBE1CB44117350405DDF878384924C40EEEA5564746F50405DDF878384924C40
77819	7346	65.319486999999995	65.341954000000001	56.964961000000002	56.959159999999997	Школьная	0103000020E61000000100000005000000D11F9A7972545040D0D03FC1C57A4C40D11F9A79725450402E7590D7837B4C4021AF0793E25550402E7590D7837B4C4021AF0793E2555040D0D03FC1C57A4C40D11F9A7972545040D0D03FC1C57A4C40
42489	6194	65.301332000000002	65.321149000000005	57.090338000000003	57.077587000000001	Рабочая	0103000020E61000000100000005000000404F03064953504021CCED5EEE894C40404F03064953504004CB1132908B4C40290989B48D54504004CB1132908B4C40290989B48D54504021CCED5EEE894C40404F03064953504021CCED5EEE894C40
41977	5329	65.249758999999997	65.281452000000002	57.146070999999999	57.132694000000001	Сибирская	0103000020E610000001000000050000006D382C0DFC4F50400E30F31DFC904C406D382C0DFC4F50406FF25B74B2924C4034D93F4F035250406FF25B74B2924C4034D93F4F035250400E30F31DFC904C406D382C0DFC4F50400E30F31DFC904C40
41942	55077	65.734489999999994	65.809005999999997	56.974463999999998	56.936902000000003	Первомайская	0103000020E610000001000000050000004C4F58E2016F50404CC79C67EC774C404C4F58E2016F50408E90813CBB7C4C4023111AC1C67350408E90813CBB7C4C4023111AC1C67350404CC79C67EC774C404C4F58E2016F50404CC79C67EC774C40
42123	55077	65.734489999999994	65.809005999999997	56.974463999999998	56.936902000000003	Комсомольская	0103000020E610000001000000050000004C4F58E2016F50404CC79C67EC774C404C4F58E2016F50408E90813CBB7C4C4023111AC1C67350408E90813CBB7C4C4023111AC1C67350404CC79C67EC774C404C4F58E2016F50404CC79C67EC774C40
41976	55077	65.734489999999994	65.809005999999997	56.974463999999998	56.936902000000003	Заводская	0103000020E610000001000000050000004C4F58E2016F50404CC79C67EC774C404C4F58E2016F50408E90813CBB7C4C4023111AC1C67350408E90813CBB7C4C4023111AC1C67350404CC79C67EC774C404C4F58E2016F50404CC79C67EC774C40
41948	55077	65.734489999999994	65.809005999999997	56.974463999999998	56.936902000000003	Вокзальная	0103000020E610000001000000050000004C4F58E2016F50404CC79C67EC774C404C4F58E2016F50408E90813CBB7C4C4023111AC1C67350408E90813CBB7C4C4023111AC1C67350404CC79C67EC774C404C4F58E2016F50404CC79C67EC774C40
42118	55077	65.734489999999994	65.809005999999997	56.974463999999998	56.936902000000003	60 лет Октября	0103000020E610000001000000050000004C4F58E2016F50404CC79C67EC774C404C4F58E2016F50408E90813CBB7C4C4023111AC1C67350408E90813CBB7C4C4023111AC1C67350404CC79C67EC774C404C4F58E2016F50404CC79C67EC774C40
42125	55073	65.695818000000003	65.750966000000005	57.061190000000003	57.028838999999998	Советская	0103000020E61000000100000005000000F67D3848886C5040B7EC10FFB0834C40F67D3848886C5040CF6BEC12D5874C401C9AB2D30F705040CF6BEC12D5874C401C9AB2D30F705040B7EC10FFB0834C40F67D3848886C5040B7EC10FFB0834C40
41941	55073	65.695818000000003	65.750966000000005	57.061190000000003	57.028838999999998	Мира	0103000020E61000000100000005000000F67D3848886C5040B7EC10FFB0834C40F67D3848886C5040CF6BEC12D5874C401C9AB2D30F705040CF6BEC12D5874C401C9AB2D30F705040B7EC10FFB0834C40F67D3848886C5040B7EC10FFB0834C40
42131	55073	65.695818000000003	65.750966000000005	57.061190000000003	57.028838999999998	Ленинградская	0103000020E61000000100000005000000F67D3848886C5040B7EC10FFB0834C40F67D3848886C5040CF6BEC12D5874C401C9AB2D30F705040CF6BEC12D5874C401C9AB2D30F705040B7EC10FFB0834C40F67D3848886C5040B7EC10FFB0834C40
41898	55073	65.695818000000003	65.750966000000005	57.061190000000003	57.028838999999998	Герцена	0103000020E61000000100000005000000F67D3848886C5040B7EC10FFB0834C40F67D3848886C5040CF6BEC12D5874C401C9AB2D30F705040CF6BEC12D5874C401C9AB2D30F705040B7EC10FFB0834C40F67D3848886C5040B7EC10FFB0834C40
42116	4633	66.047706000000005	66.084456000000003	57.181728999999997	57.168092000000001	Советская	0103000020E61000000100000005000000AC74779D0D835040105CE50984954C40AC74779D0D8350400DDE57E542974C40DD7C23BA678550400DDE57E542974C40DD7C23BA67855040105CE50984954C40AC74779D0D835040105CE50984954C40
77746	7281	65.364401999999998	65.395296000000002	56.956432	56.946083999999999	Совхозная	0103000020E610000001000000050000003526C45C525750406AA2CF4719794C403526C45C52575040876C205D6C7A4C40560F98874C595040876C205D6C7A4C40560F98874C5950406AA2CF4719794C403526C45C525750406AA2CF4719794C40
42462	6474	65.816209999999998	65.830233000000007	56.959622000000003	56.949407000000001	Садовая	0103000020E61000000100000005000000C32ADEC83C745040F7CB272B86794C40C32ADEC83C745040D542C9E4D47A4C40D7C3978922755040D542C9E4D47A4C40D7C3978922755040F7CB272B86794C40C32ADEC83C745040F7CB272B86794C40
77146	55080	65.830394999999996	65.916111999999998	56.904133000000002	56.859000999999999	п/о Сосновое	0103000020E61000000100000005000000C3F01131257550409B1DA9BEF36D4C40C3F0113125755040001E51A1BA734C4048DE3994A17A5040001E51A1BA734C4048DE3994A17A50409B1DA9BEF36D4C40C3F01131257550409B1DA9BEF36D4C40
41971	55080	65.830394999999996	65.916111999999998	56.904133000000002	56.859000999999999	Юбилейная	0103000020E61000000100000005000000C3F01131257550409B1DA9BEF36D4C40C3F0113125755040001E51A1BA734C4048DE3994A17A5040001E51A1BA734C4048DE3994A17A50409B1DA9BEF36D4C40C3F01131257550409B1DA9BEF36D4C40
42025	55080	65.830394999999996	65.916111999999998	56.904133000000002	56.859000999999999	Садовый	0103000020E61000000100000005000000C3F01131257550409B1DA9BEF36D4C40C3F0113125755040001E51A1BA734C4048DE3994A17A5040001E51A1BA734C4048DE3994A17A50409B1DA9BEF36D4C40C3F01131257550409B1DA9BEF36D4C40
78210	4239	65.761062999999993	65.811475999999999	57.087071000000002	57.053381999999999	пер. Лесной	0103000020E6100000010000000500000085CC9541B5705040F818AC38D5864C4085CC9541B57050400BB77C24258B4C404A5F0839EF7350400BB77C24258B4C404A5F0839EF735040F818AC38D5864C4085CC9541B5705040F818AC38D5864C40
78204	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Раздольная	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41975	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Мира	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41902	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Ленина	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
9607	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Знаменского	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
42018	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	Гагарина	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41937	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	8 микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41982	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	7-й микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
41951	1898	68.195784000000003	68.463329999999999	58.306462000000003	58.102096000000003	10-й микрорайон	0103000020E6100000010000000500000020459DB9870C5140B686527B110D4D4020459DB9870C5140BFBB95253A274D405D50DF32A71D5140BFBB95253A274D405D50DF32A71D5140B686527B110D4D4020459DB9870C5140B686527B110D4D40
77812	32427	68.34751	68.373030999999997	58.250084000000001	58.237412999999997	Тобольская	0103000020E610000001000000050000001C42959A3D1651409752978C631E4D401C42959A3D1651405EA0A4C002204D403A596ABDDF1751405EA0A4C002204D403A596ABDDF1751409752978C631E4D401C42959A3D1651409752978C631E4D40
77813	1466	68.45599	68.473094000000003	58.154274999999998	58.141902999999999	Советская	0103000020E610000001000000050000006553AEF02E1D5140261AA4E029124D406553AEF02E1D514092CB7F48BF134D40C47B0E2C471E514092CB7F48BF134D40C47B0E2C471E5140261AA4E029124D406553AEF02E1D5140261AA4E029124D40
77817	1579	68.584655999999995	68.620005000000006	58.055522000000003	58.037230999999998	Центральная	0103000020E6100000010000000500000040DAFF006B255140DDB243FCC3044D4040DAFF006B255140B11A4B581B074D40D1967329AE275140B11A4B581B074D40D1967329AE275140DDB243FCC3044D4040DAFF006B255140DDB243FCC3044D40
41925	1449	68.326443999999995	68.368934999999993	58.186950000000003	58.151634999999999	Советская	0103000020E610000001000000050000006DFE5F75E4145140E8F692C668134D406DFE5F75E41451405DFE43FAED174D4062D68BA19C1751405DFE43FAED174D4062D68BA19C175140E8F692C668134D406DFE5F75E4145140E8F692C668134D40
77932	32298	68.539929000000001	68.565441000000007	58.158923999999999	58.145502999999998	Береговая	0103000020E610000001000000050000005E4A5D328E225140253CA1D79F124D405E4A5D328E2251405646239F57144D4053B4722F302451405646239F57144D4053B4722F30245140253CA1D79F124D405E4A5D328E225140253CA1D79F124D40
42557	1566	68.794224	68.818047000000007	58.044144000000003	58.031846999999999	Первомайская	0103000020E61000000100000005000000B16CE690D4325140E4BCFF8F13044D40B16CE690D43251404628B682A6054D40D2E5CDE15A3451404628B682A6054D40D2E5CDE15A345140E4BCFF8F13044D40B16CE690D4325140E4BCFF8F13044D40
77844	162	68.742408999999995	68.754949999999994	58.273490000000002	58.264643999999997	Зелёная	0103000020E6100000010000000500000063D009A1832F5140938AC6DADF214D4063D009A1832F51403BE466B801234D405F07CE19513051403BE466B801234D405F07CE1951305140938AC6DADF214D4063D009A1832F5140938AC6DADF214D40
42303	1123	68.598939000000001	68.642489999999995	58.509241000000003	58.492297999999998	Сибирская	0103000020E6100000010000000500000022533E04552651406FF1F09E033F4D4022533E0455265140246420CF2E414D407380608E1E295140246420CF2E414D407380608E1E2951406FF1F09E033F4D4022533E04552651406FF1F09E033F4D40
77972	1223	68.563303000000005	68.581871000000007	58.634177999999999	58.617961999999999	Школьная	0103000020E6100000010000000500000047AF06280D245140DB15FA60194F4D4047AF06280D245140DDEBA4BE2C514D406ADFDC5F3D255140DDEBA4BE2C514D406ADFDC5F3D255140DB15FA60194F4D4047AF06280D245140DB15FA60194F4D40
42388	348	68.211640000000003	68.22878	58.146315999999999	58.132401000000002	Портовая	0103000020E61000000100000005000000A1A17F828B0D5140967A1684F2104D40A1A17F828B0D5140D670917BBA124D40A67EDE54A40E5140D670917BBA124D40A67EDE54A40E5140967A1684F2104D40A1A17F828B0D5140967A1684F2104D40
42390	1686	68.412385999999998	68.430406000000005	58.077486	58.065286999999998	Школьная	0103000020E6100000010000000500000002D53F88641A51404EED0C535B084D4002D53F88641A5140EDF2AD0FEB094D4024809BC58B1B5140EDF2AD0FEB094D4024809BC58B1B51404EED0C535B084D4002D53F88641A51404EED0C535B084D40
42241	1101	68.380432999999996	68.404176000000007	58.421041000000002	58.404994000000002	Учителей	0103000020E610000001000000050000006D54A70359185140C289E8D7D6334D406D54A7035918514038A3E6ABE4354D4000750305DE19514038A3E6ABE4354D4000750305DE195140C289E8D7D6334D406D54A70359185140C289E8D7D6334D40
42240	805	67.962474	67.986872000000005	57.842227000000001	57.825634000000001	Школьная	0103000020E6100000010000000500000005508C2C99FD50409B3BFA5FAEE94C4005508C2C99FD504073672618CEEB4C40A4552DE928FF504073672618CEEB4C40A4552DE928FF50409B3BFA5FAEE94C4005508C2C99FD50409B3BFA5FAEE94C40
42460	728	68.128140999999999	68.169392000000002	58.023836000000003	58.011474999999997	Мира	0103000020E61000000100000005000000B6114F76330851405DDC460378014D40B6114F7633085140D63BDC0E0D034D400F0D8B51D70A5140D63BDC0E0D034D400F0D8B51D70A51405DDC460378014D40B6114F76330851405DDC460378014D40
42499	608	68.669788999999994	68.685446999999996	58.123871000000001	58.115794999999999	Молодежная	0103000020E610000001000000050000001D8EAED2DD2A51402905DD5ED20E4D401D8EAED2DD2A51401FF64201DB0F4D400B09185DDE2B51401FF64201DB0F4D400B09185DDE2B51402905DD5ED20E4D401D8EAED2DD2A51402905DD5ED20E4D40
77761	665	68.71078	68.731234000000001	58.102851999999999	58.091732	пер. Школьный	0103000020E61000000100000005000000A8A9656B7D2D514093FFC9DFBD0B4D40A8A9656B7D2D5140022A1C412A0D4D404AEEB089CC2E5140022A1C412A0D4D404AEEB089CC2E514093FFC9DFBD0B4D40A8A9656B7D2D514093FFC9DFBD0B4D40
42306	432	68.066202000000004	68.102628999999993	57.898026000000002	57.889755000000001	Цетральная	0103000020E61000000100000005000000823B50A73C045140EB39E97DE3F14C40823B50A73C045140967A1684F2F24C40C1A7397991065140967A1684F2F24C40C1A7397991065140EB39E97DE3F14C40823B50A73C045140EB39E97DE3F14C40
42458	292	68.269833000000006	68.285956999999996	58.119712	58.103337000000003	Центральная	0103000020E610000001000000050000006C98A1F144115140BFBB95253A0D4D406C98A1F14411514029780AB9520F4D40FCC3961E4D12514029780AB9520F4D40FCC3961E4D125140BFBB95253A0D4D406C98A1F144115140BFBB95253A0D4D40
42559	64	68.576139999999995	68.600663999999995	58.314244000000002	58.302452000000002	Школьная	0103000020E61000000100000005000000B77A4E7ADF2451400E4E44BFB6264D40B77A4E7ADF2451406C7BBB2539284D409CF86A47712651406C7BBB2539284D409CF86A47712651400E4E44BFB6264D40B77A4E7ADF2451400E4E44BFB6264D40
42455	32494	67.836872	67.859814999999998	57.781202999999998	57.768878000000001	Рабочая	0103000020E610000001000000050000000ABC934F8FF55040944E24986AE24C400ABC934F8FF55040BF44BC75FEE34C400E677E3507F75040BF44BC75FEE34C400E677E3507F75040944E24986AE24C400ABC934F8FF55040944E24986AE24C40
42305	217	68.252054999999999	68.286163999999999	58.152414	58.131383999999997	Ленина	0103000020E61000000100000005000000C5724BAB21105140DC9BDF30D1104D40C5724BAB21105140EDB94C4D82134D40B952CF8250125140EDB94C4D82134D40B952CF8250125140DC9BDF30D1104D40C5724BAB21105140DC9BDF30D1104D40
77176	32406	68.294652999999997	68.301964999999996	58.310046	58.295264000000003	Строителей	0103000020E61000000100000005000000C5AA4198DB125140D4D7F335CB254D40C5AA4198DB125140B8205B96AF274D4058E2016553135140B8205B96AF274D4058E2016553135140D4D7F335CB254D40C5AA4198DB125140D4D7F335CB254D40
41929	32356	67.628012999999996	67.676000999999999	57.785117999999997	57.767735999999999	Советская	0103000020E610000001000000050000009F1D705D31E850401EFB592C45E24C409F1D705D31E850401EC022BF7EE44C400DC4B29943EB50401EC022BF7EE44C400DC4B29943EB50401EFB592C45E24C409F1D705D31E850401EFB592C45E24C40
42302	32269	68.581745999999995	68.603286999999995	58.134538999999997	58.120919000000001	Советская	0103000020E610000001000000050000000B2593533B255140863B17467A0F4D400B2593533B255140AD84EE9238114D4086C613419C265140AD84EE9238114D4086C613419C265140863B17467A0F4D400B2593533B255140863B17467A0F4D40
78007	32133	69.803956999999997	69.811233999999999	56.497427000000002	56.490141999999999	Сидякина	0103000020E61000000100000005000000FA980F0874735140B1321AF9BC3E4C40FA980F0874735140DE921CB0AB3F4C40CFD90242EB735140DE921CB0AB3F4C40CFD90242EB735140B1321AF9BC3E4C40FA980F0874735140B1321AF9BC3E4C40
42386	32155	69.551297000000005	69.575272999999996	56.799048999999997	56.786631	Центральная	0103000020E61000000100000005000000825836734863514088821953B0644C4082583673486351406473D53C47664C406551D845D16451406473D53C47664C406551D845D164514088821953B0644C40825836734863514088821953B0644C40
42553	31644	69.881373999999994	69.888425999999995	56.593131	56.580098999999997	Советская	0103000020E61000000100000005000000DC627E6E687851409DB81CAF404A4C40DC627E6E68785140349F73B7EB4B4C40A1BAB9F8DB785140349F73B7EB4B4C40A1BAB9F8DB7851409DB81CAF404A4C40DC627E6E687851409DB81CAF404A4C40
77754	32503	69.974485000000001	69.998262999999994	56.510075000000001	56.504272999999998	Центральная	0103000020E61000000100000005000000535C55F65D7E5140BEA085048C404C40535C55F65D7E5140ECC039234A414C40A3737E8AE37F5140ECC039234A414C40A3737E8AE37F5140BEA085048C404C40535C55F65D7E5140BEA085048C404C40
42385	31828	69.675921000000002	69.684769000000003	56.722622000000001	56.715499000000001	Центральная	0103000020E610000001000000050000007F6B274A426B51400DA9A278955B4C407F6B274A426B514060AFB0E07E5C4C4023145B41D36B514060AFB0E07E5C4C4023145B41D36B51400DA9A278955B4C407F6B274A426B51400DA9A278955B4C40
42558	32063	69.412175000000005	69.437427	56.850653999999999	56.839080000000003	Зеленая	0103000020E61000000100000005000000A54E4013615A5140255D33F9666B4C40A54E4013615A5140151BF33AE26C4C40CBD8D0CDFE5B5140151BF33AE26C4C40CBD8D0CDFE5B5140255D33F9666B4C40A54E4013615A5140255D33F9666B4C40
42556	31951	69.976308000000003	70.00421	56.740259999999999	56.733876000000002	Молодежная	0103000020E61000000100000005000000AFB48CD47B7E5140DFA815A6EF5D4C40AFB48CD47B7E5140BB44F5D6C05E4C403C1405FA44805140BB44F5D6C05E4C403C1405FA44805140DFA815A6EF5D4C40AFB48CD47B7E5140DFA815A6EF5D4C40
42457	31919	70.117209000000003	70.133109000000005	56.702060000000003	56.692897000000002	Школьная	0103000020E6100000010000000500000000732D5A808751408E3F51D9B0584C4000732D5A8087514036EA211ADD594C4069739CDB8488514036EA211ADD594C4069739CDB848851408E3F51D9B0584C4000732D5A808751408E3F51D9B0584C40
42314	31860	70.147824	70.179310000000001	56.780935999999997	56.765912	Центральная	0103000020E610000001000000050000001764CBF27589514096CE876709624C401764CBF2758951407022FAB5F5634C402176A6D0798B51407022FAB5F5634C402176A6D0798B514096CE876709624C401764CBF27589514096CE876709624C40
42583	31732	69.738918999999996	69.772623999999993	56.762878000000001	56.753157000000002	Новая	0103000020E6100000010000000500000027D9EA724A6F514072E0D57267604C4027D9EA724A6F5140406B7EFCA5614C40B306EFAB72715140406B7EFCA5614C40B306EFAB7271514072E0D57267604C4027D9EA724A6F514072E0D57267604C40
41924	25745	69.767422999999994	69.852287000000004	56.649766	56.618353999999997	Советская	0103000020E61000000100000005000000AFCC5B751D715140E6AC4F39264F4C40AFCC5B751D715140C00644882B534C4095F3C5DE8B765140C00644882B534C4095F3C5DE8B765140E6AC4F39264F4C40AFCC5B751D715140E6AC4F39264F4C40
42113	25745	69.767422999999994	69.852287000000004	56.649766	56.618353999999997	Ленина	0103000020E61000000100000005000000AFCC5B751D715140E6AC4F39264F4C40AFCC5B751D715140C00644882B534C4095F3C5DE8B765140C00644882B534C4095F3C5DE8B765140E6AC4F39264F4C40AFCC5B751D715140E6AC4F39264F4C40
41958	25745	69.767422999999994	69.852287000000004	56.649766	56.618353999999997	40 лет Октября	0103000020E61000000100000005000000AFCC5B751D715140E6AC4F39264F4C40AFCC5B751D715140C00644882B534C4095F3C5DE8B765140C00644882B534C4095F3C5DE8B765140E6AC4F39264F4C40AFCC5B751D715140E6AC4F39264F4C40
42554	31695	69.721923000000004	69.755753999999996	56.612073000000002	56.60425	Школьная	0103000020E61000000100000005000000BCCE86FC336E5140D34D6210584D4C40BCCE86FC336E5140DFE17668584E4C408E7406465E705140DFE17668584E4C408E7406465E705140D34D6210584D4C40BCCE86FC336E5140D34D6210584D4C40
77898	31024	70.107714000000001	70.121044999999995	55.886302000000001	55.881413999999999	Солнечная	0103000020E6100000010000000500000091D442C9E4865140471E882CD2F04B4091D442C9E486514090300C5872F14B4009168733BF87514090300C5872F14B4009168733BF875140471E882CD2F04B4091D442C9E4865140471E882CD2F04B40
42366	31417	69.897795000000002	69.915824999999998	55.456769999999999	55.440033999999997	Ленина	0103000020E61000000100000005000000CAE02879757951406490BB0853B84B40CAE02879757951409FE5797077BA4B40FDF675E09C7A51409FE5797077BA4B40FDF675E09C7A51406490BB0853B84B40CAE02879757951406490BB0853B84B40
77877	61264	70.226094000000003	70.242344000000003	55.751016	55.739624999999997	Приозерная	0103000020E6100000010000000500000099F4F752788E5140E9263108ACDE4B4099F4F752788E5140E962D34A21E04B4070986890828F5140E962D34A21E04B4070986890828F5140E9263108ACDE4B4099F4F752788E5140E9263108ACDE4B40
42550	31331	70.187646000000001	70.202692999999996	55.610518999999996	55.598055000000002	Школьная	0103000020E610000001000000050000006A4E5E64028C5140CA1AF5108DCC4B406A4E5E64028C5140164B917C25CE4B4033880FECF88C5140164B917C25CE4B4033880FECF88C5140CA1AF5108DCC4B406A4E5E64028C5140CA1AF5108DCC4B40
41956	25685	70.306206000000003	70.359798999999995	55.539929999999998	55.520105000000001	Ленина	0103000020E61000000100000005000000B2F50CE19893514038BEF6CC92C24B40B2F50CE1989351408C101E6D1CC54B408B8862F2069751408C101E6D1CC54B408B8862F20697514038BEF6CC92C24B40B2F50CE19893514038BEF6CC92C24B40
42364	31205	70.429373999999996	70.454688000000004	55.861772000000002	55.846957000000003	Школьная	0103000020E610000001000000050000002CF015DD7A9B5140240F441669EC4B402CF015DD7A9B5140E44D7E8B4EEE4B408E78B29B199D5140E44D7E8B4EEE4B408E78B29B199D5140240F441669EC4B402CF015DD7A9B5140240F441669EC4B40
77730	31152	70.618926999999999	70.634764000000004	55.561425999999997	55.542074999999997	Центральная	0103000020E6100000010000000500000021E7FD7F9CA75140567DAEB662C54B4021E7FD7F9CA75140E28FA2CEDCC74B40672B2FF99FA85140E28FA2CEDCC74B40672B2FF99FA85140567DAEB662C54B4021E7FD7F9CA75140567DAEB662C54B40
77802	31061	69.864333000000002	69.881752000000006	55.778390999999999	55.767913999999998	Карла Маркса	0103000020E61000000100000005000000A1F65B3B51775140FD1186014BE24B40A1F65B3B517751401840F850A2E34B40B0CBF09F6E7851401840F850A2E34B40B0CBF09F6E785140FD1186014BE24B40A1F65B3B51775140FD1186014BE24B40
41923	30942	70.107946999999996	70.160059000000004	55.936771	55.917369000000001	Сенная	0103000020E61000000100000005000000E2AC889AE88651409FAEEE586CF54B40E2AC889AE8865140AD6BB41CE8F74B408D9B1A683E8A5140AD6BB41CE8F74B408D9B1A683E8A51409FAEEE586CF54B40E2AC889AE88651409FAEEE586CF54B40
42422	30827	70.414192	70.435023999999999	55.488897000000001	55.471265000000002	Центральная	0103000020E61000000100000005000000F390291F829A5140EE5F596952BC4B40F390291F829A5140670E492D94BE4B40683EE76ED79B5140670E492D94BE4B40683EE76ED79B5140EE5F596952BC4B40F390291F829A5140EE5F596952BC4B40
42363	30250	69.929021000000006	69.963641999999993	55.274507999999997	55.257617000000003	Школьная	0103000020E6100000010000000500000006137F14757B514063F20698F9A04B4006137F14757B5140C43E011423A34B4054C37E4FAC7D5140C43E011423A34B4054C37E4FAC7D514063F20698F9A04B4006137F14757B514063F20698F9A04B40
42466	30692	67.477149999999995	67.521904000000006	56.419483	56.404936999999997	Строительная	0103000020E61000000100000005000000545227A089DE50405DF8C1F9D4334C40545227A089DE50402E1D739EB1354C40B4E908E066E150402E1D739EB1354C40B4E908E066E150405DF8C1F9D4334C40545227A089DE50405DF8C1F9D4334C40
42347	30664	67.864845000000003	67.902799000000002	56.494777999999997	56.475428999999998	Шабановская, 	0103000020E61000000100000005000000FCC6D79E59F75040F54883DBDA3C4C40FCC6D79E59F75040E063B0E2543F4C4023F77475C7F95040E063B0E2543F4C4023F77475C7F95040F54883DBDA3C4C40FCC6D79E59F75040F54883DBDA3C4C40
42301	30391	67.819524999999999	67.852187999999998	56.387504999999997	56.347020000000001	Победы	0103000020E610000001000000050000004850FC1873F450406A87BF266B2C4C404850FC1873F45040AB048BC399314C40CB82893F8AF65040AB048BC399314C40CB82893F8AF650406A87BF266B2C4C404850FC1873F450406A87BF266B2C4C40
42551	30391	67.819524999999999	67.852187999999998	56.387504999999997	56.347020000000001	МТС	0103000020E610000001000000050000004850FC1873F450406A87BF266B2C4C404850FC1873F45040AB048BC399314C40CB82893F8AF65040AB048BC399314C40CB82893F8AF650406A87BF266B2C4C404850FC1873F450406A87BF266B2C4C40
78146	30391	67.819524999999999	67.852187999999998	56.387504999999997	56.347020000000001	Леонова	0103000020E610000001000000050000004850FC1873F450406A87BF266B2C4C404850FC1873F45040AB048BC399314C40CB82893F8AF65040AB048BC399314C40CB82893F8AF650406A87BF266B2C4C404850FC1873F450406A87BF266B2C4C40
42345	30391	67.819524999999999	67.852187999999998	56.387504999999997	56.347020000000001	Заводская	0103000020E610000001000000050000004850FC1873F450406A87BF266B2C4C404850FC1873F45040AB048BC399314C40CB82893F8AF65040AB048BC399314C40CB82893F8AF650406A87BF266B2C4C404850FC1873F450406A87BF266B2C4C40
42272	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Тимирязева	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
42343	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Терешковой	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
41922	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Советская	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
41921	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Лермонтова	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
42281	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Зятькова	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
42271	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Герцена	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
42419	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Вокзальная	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
42344	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Водопроводная	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
42298	29904	67.621644000000003	67.693357000000006	56.491701999999997	56.458432999999999	Вагайская	0103000020E610000001000000050000004C70EA03C9E750401E34BBEEAD3A4C404C70EA03C9E750405BB05417F03E4C40F9DC09F65FEC50405BB05417F03E4C40F9DC09F65FEC50401E34BBEEAD3A4C404C70EA03C9E750401E34BBEEAD3A4C40
42274	25649	67.444091999999998	67.462732000000003	56.572017000000002	56.546917000000001	Мира	0103000020E61000000100000005000000931ADA006CDC50402F50526001464C40931ADA006CDC5040C6E061DA37494C4003B4AD669DDD5040C6E061DA37494C4003B4AD669DDD50402F50526001464C40931ADA006CDC50402F50526001464C40
42421	29769	67.306021000000001	67.321652	56.452444	56.444288999999998	Центральная	0103000020E61000000100000005000000E9B81AD995D350407C7C4276DE384C40E9B81AD995D35040BEA25BAFE9394C405A2C45F295D45040BEA25BAFE9394C405A2C45F295D450407C7C4276DE384C40E9B81AD995D350407C7C4276DE384C40
42548	29809	67.669740000000004	67.691424999999995	56.274614	56.265177000000001	Школьная	0103000020E61000000100000005000000AD342905DDEA50406153E751F1214C40AD342905DDEA50400A83328D26234C40C1A8A44E40EC50400A83328D26234C40C1A8A44E40EC50406153E751F1214C40AD342905DDEA50406153E751F1214C40
42311	29594	67.278614000000005	67.335386999999997	56.482066000000003	56.461596	Школьный переулок	0103000020E610000001000000050000004C8DD0CFD4D1504072FBE593153B4C404C8DD0CFD4D15040BC41B456B43D4C403A2009FB76D55040BC41B456B43D4C403A2009FB76D5504072FBE593153B4C404C8DD0CFD4D1504072FBE593153B4C40
77041	29594	67.278614000000005	67.335386999999997	56.482066000000003	56.461596	Совхозная	0103000020E610000001000000050000004C8DD0CFD4D1504072FBE593153B4C404C8DD0CFD4D15040BC41B456B43D4C403A2009FB76D55040BC41B456B43D4C403A2009FB76D5504072FBE593153B4C404C8DD0CFD4D1504072FBE593153B4C40
42253	29594	67.278614000000005	67.335386999999997	56.482066000000003	56.461596	Ленина	0103000020E610000001000000050000004C8DD0CFD4D1504072FBE593153B4C404C8DD0CFD4D15040BC41B456B43D4C403A2009FB76D55040BC41B456B43D4C403A2009FB76D5504072FBE593153B4C404C8DD0CFD4D1504072FBE593153B4C40
42342	29530	67.707594999999998	67.731966	56.56982	56.555674000000003	Советская	0103000020E610000001000000050000000AF4893C49ED5040679E5C5320474C400AF4893C49ED5040A94D9CDCEF484C402CF2EB87D8EE5040A94D9CDCEF484C402CF2EB87D8EE5040679E5C5320474C400AF4893C49ED5040679E5C5320474C40
42525	29714	67.342833999999996	67.372001999999995	56.456035	56.444274999999998	Центральная	0103000020E610000001000000050000003D7D04FEF0D5504017B7D100DE384C403D7D04FEF0D550406A6AD95A5F3A4C40FB027AE1CED750406A6AD95A5F3A4C40FB027AE1CED7504017B7D100DE384C403D7D04FEF0D5504017B7D100DE384C40
42270	29460	65.653542999999999	65.672766999999993	57.655394999999999	57.643456	Лесная	0103000020E61000000100000005000000E7E104A6D36950401E3526C45CD24C40E7E104A6D3695040207BBDFBE3D34C40FEB4519D0E6B5040207BBDFBE3D34C40FEB4519D0E6B50401E3526C45CD24C40E7E104A6D36950401E3526C45CD24C40
42584	29397	65.983035999999998	66.001047999999997	57.706349000000003	57.697346000000003	Советская	0103000020E610000001000000050000009AB2D30FEA7E50408BFF3BA242D94C409AB2D30FEA7E5040FA47DFA469DA4C407A6EA12B11805040FA47DFA469DA4C407A6EA12B118050408BFF3BA242D94C409AB2D30FEA7E50408BFF3BA242D94C40
42296	29209	65.683860999999993	65.713048000000001	57.396892999999999	57.382854999999999	Школьная	0103000020E61000000100000005000000A180ED60C46B5040170E846401B14C40A180ED60C46B50407381CB63CDB24C409B1E1494A26D50407381CB63CDB24C409B1E1494A26D5040170E846401B14C40A180ED60C46B5040170E846401B14C40
78033	28979	66.486057000000002	66.504238999999998	57.575353	57.567138	Центральная	0103000020E610000001000000050000007BBFD18E1B9F5040D0285DFA97C84C407BBFD18E1B9F5040E753C72AA5C94C408997A77345A05040E753C72AA5C94C408997A77345A05040D0285DFA97C84C407BBFD18E1B9F5040D0285DFA97C84C40
42547	28506	66.037321000000006	66.049440000000004	57.284424999999999	57.279263	Станционная	0103000020E610000001000000050000000F9D9E7763825040CEFDD5E3BEA34C400F9D9E77638250401895D40968A44C4050C763062A8350401895D40968A44C4050C763062A835040CEFDD5E3BEA34C400F9D9E7763825040CEFDD5E3BEA34C40
77739	27058	65.319441999999995	65.393237999999997	57.368530999999997	57.364030999999997	Школьная	0103000020E6100000010000000500000001BEDBBC7154504076DD5B9198AE4C4001BEDBBC71545040F54718062CAF4C40D862B7CF2A595040F54718062CAF4C40D862B7CF2A59504076DD5B9198AE4C4001BEDBBC7154504076DD5B9198AE4C40
78123	28740	66.057516000000007	66.071986999999993	57.592880999999998	57.578184999999998	Зеленая	0103000020E61000000100000005000000CBBF9657AE835040D50451F701CA4C40CBBF9657AE835040BBB54C86E3CB4C402DAF5C6F9B845040BBB54C86E3CB4C402DAF5C6F9B845040D50451F701CA4C40CBBF9657AE835040D50451F701CA4C40
78071	29056	66.300977000000003	66.328681000000003	57.679892000000002	57.662318999999997	Хохлова	0103000020E6100000010000000500000049F60835439350407C4276DEC6D44C4049F6083543935040F16778B306D74C404374081C09955040F16778B306D74C404374081C099550407C4276DEC6D44C4049F60835439350407C4276DEC6D44C40
77891	28233	65.371399999999994	65.390255999999994	57.478467000000002	57.468603999999999	Центральная	0103000020E61000000100000005000000006F8104C55750402C634337FBBB4C40006F8104C55750408D9B1A683EBD4C4056444DF4F95850408D9B1A683EBD4C4056444DF4F95850402C634337FBBB4C40006F8104C55750402C634337FBBB4C40
42454	28816	65.222154000000003	65.253487000000007	57.661732000000001	57.650790999999998	Центральная	0103000020E610000001000000050000003D2B69C5374E5040FCC3961E4DD34C403D2B69C5374E5040BC5B59A2B3D44C4084BD892139505040BC5B59A2B3D44C4084BD892139505040FCC3961E4DD34C403D2B69C5374E5040FCC3961E4DD34C40
42114	28683	66.134446999999994	66.214577000000006	57.696480000000001	57.659762000000001	Строителей	0103000020E61000000100000005000000E60297C79A8850406092CA1473D44C40E60297C79A885040B728B34126D94C40535E2BA1BB8D5040B728B34126D94C40535E2BA1BB8D50406092CA1473D44C40E60297C79A8850406092CA1473D44C40
42017	28683	66.134446999999994	66.214577000000006	57.696480000000001	57.659762000000001	Новая	0103000020E61000000100000005000000E60297C79A8850406092CA1473D44C40E60297C79A885040B728B34126D94C40535E2BA1BB8D5040B728B34126D94C40535E2BA1BB8D50406092CA1473D44C40E60297C79A8850406092CA1473D44C40
42071	28683	66.134446999999994	66.214577000000006	57.696480000000001	57.659762000000001	Мира	0103000020E61000000100000005000000E60297C79A8850406092CA1473D44C40E60297C79A885040B728B34126D94C40535E2BA1BB8D5040B728B34126D94C40535E2BA1BB8D50406092CA1473D44C40E60297C79A8850406092CA1473D44C40
42318	6395	65.083904000000004	65.107134000000002	57.378363	57.368355999999999	Центральная	0103000020E610000001000000050000003B00E2AE5E45504087A4164A26AF4C403B00E2AE5E4550401B82E3326EB04C408A929048DB4650401B82E3326EB04C408A929048DB46504087A4164A26AF4C403B00E2AE5E45504087A4164A26AF4C40
42453	28600	65.898450999999994	65.933413000000002	57.874969	57.859133999999997	Центральная	0103000020E61000000100000005000000BE839F3880795040DA70581AF8ED4C40BE839F3880795040C501F4FBFEEF4C40522AE109BD7B5040C501F4FBFEEF4C40522AE109BD7B5040DA70581AF8ED4C40BE839F3880795040DA70581AF8ED4C40
78069	29348	65.554817999999997	65.574438000000001	57.383695000000003	57.374504999999999	Мира	0103000020E61000000100000005000000DB4E5B23826350402098A3C7EFAF4C40DB4E5B2382635040C251F2EA1CB14C4019E59997C3645040C251F2EA1CB14C4019E59997C36450402098A3C7EFAF4C40DB4E5B23826350402098A3C7EFAF4C40
42452	28536	66.180755000000005	66.198282000000006	57.278756999999999	57.268962000000002	Лесная	0103000020E61000000100000005000000AA656B7D918B5040F2EEC8586DA24C40AA656B7D918B5040FA43334FAEA34C40AC58FCA6B08C5040FA43334FAEA34C40AC58FCA6B08C5040F2EEC8586DA24C40AA656B7D918B5040F2EEC8586DA24C40
42552	28331	65.952988000000005	65.983063000000001	57.474865999999999	57.458767000000002	70 лет Октября	0103000020E61000000100000005000000C05E61C1FD7C5040F5BD86E0B8BA4C40C05E61C1FD7C5040BDFDB968C8BC4C4017BA1281EA7E5040BDFDB968C8BC4C4017BA1281EA7E5040F5BD86E0B8BA4C40C05E61C1FD7C5040F5BD86E0B8BA4C40
78141	29150	66.302701999999996	66.325644999999994	57.476739000000002	57.466692000000002	Новая	0103000020E61000000100000005000000C39B35785F93504005A73E90BCBB4C40C39B35785F93504027DD96C805BD4C40C746205ED794504027DD96C805BD4C40C746205ED794504005A73E90BCBB4C40C39B35785F93504005A73E90BCBB4C40
42456	29000	66.377180999999993	66.399306999999993	57.642045000000003	57.631908000000003	Центральная	0103000020E610000001000000050000000BEBC6BB23985040570A815CE2D04C400BEBC6BB23985040B9C7D2872ED24C401684F23E8E995040B9C7D2872ED24C401684F23E8E995040570A815CE2D04C400BEBC6BB23985040570A815CE2D04C40
78044	29092	66.381843000000003	66.401328000000007	57.474479000000002	57.467984000000001	Железнодорожников	0103000020E61000000100000005000000384D9F1D70985040908653E6E6BB4C40384D9F1D70985040C4D155BABBBC4C4006BEA25BAF995040C4D155BABBBC4C4006BEA25BAF995040908653E6E6BB4C40384D9F1D70985040908653E6E6BB4C40
42524	29321	65.691416000000004	65.725416999999993	57.424191999999998	57.418066000000003	Водозабор	0103000020E6100000010000000500000098FBE428406C5040E7C8CA2F83B54C4098FBE428406C5040C79C67EC4BB64C4098BD6C3B6D6E5040C79C67EC4BB64C4098BD6C3B6D6E5040E7C8CA2F83B54C4098FBE428406C5040E7C8CA2F83B54C40
42451	28416	65.624634999999998	65.659418000000002	57.600921	57.591309000000003	Молодежная	0103000020E61000000100000005000000F73B1405FA6750404D6A6803B0CB4C40F73B1405FA675040643DB5FAEACC4C4033198EE7336A5040643DB5FAEACC4C4033198EE7336A50404D6A6803B0CB4C40F73B1405FA6750404D6A6803B0CB4C40
42295	28311	65.764529999999993	65.799330999999995	57.587342999999997	57.558356000000003	Береговая	0103000020E61000000100000005000000E5B33C0FEE70504040C39B3578C74C40E5B33C0FEE7050406B44300E2ECB4C4074EB353D287350406B44300E2ECB4C4074EB353D2873504040C39B3578C74C40E5B33C0FEE70504040C39B3578C74C40
42546	28916	65.211860000000001	65.242734999999996	57.612310999999998	57.606051999999998	Центральная	0103000020E6100000010000000500000028D53E1D8F4D504073D6A71C93CD4C4028D53E1D8F4D504093FDF33460CE4C400DA661F8884F504093FDF33460CE4C400DA661F8884F504073D6A71C93CD4C4028D53E1D8F4D504073D6A71C93CD4C40
41998	28258	65.736862000000002	65.791740000000004	57.56832	57.544685000000001	Советская	0103000020E6100000010000000500000092EA3BBF286F504096CFF23CB8C54C4092EA3BBF286F5040D4D4B2B5BEC84C40D8BB3FDEAB725040D4D4B2B5BEC84C40D8BB3FDEAB72504096CFF23CB8C54C4092EA3BBF286F504096CFF23CB8C54C40
42268	28162	65.142949999999999	65.191333	57.514436000000003	57.496626999999997	Чапаева	0103000020E61000000100000005000000A5BDC11726495040C1A7397991BF4C40A5BDC117264950404AF1F109D9C14C405169C4CC3E4C50404AF1F109D9C14C405169C4CC3E4C5040C1A7397991BF4C40A5BDC11726495040C1A7397991BF4C40
42450	28149	65.781938999999994	65.808925000000002	57.677241000000002	57.667209999999997	Школьная	0103000020E61000000100000005000000E21DE0490B72504036C8242367D54C40E21DE0490B725040534145D5AFD64C40ADFA5C6DC5735040534145D5AFD64C40ADFA5C6DC573504036C8242367D54C40E21DE0490B72504036C8242367D54C40
42362	28042	66.538347999999999	66.581520999999995	57.825240999999998	57.809992000000001	Новопашина	0103000020E610000001000000050000007D772B4B74A25040C5025FD1ADE74C407D772B4B74A25040BF28417FA1E94C40FB3BDBA337A55040BF28417FA1E94C40FB3BDBA337A55040C5025FD1ADE74C407D772B4B74A25040C5025FD1ADE74C40
42269	27977	65.947255999999996	65.978311000000005	57.763520999999997	57.750382999999999	Полевая	0103000020E61000000100000005000000253CA1D79F7C5040B83CD68C0CE04C40253CA1D79F7C504094675E0EBBE14C404B94BDA59C7E504094675E0EBBE14C404B94BDA59C7E5040B83CD68C0CE04C40253CA1D79F7C5040B83CD68C0CE04C40
42300	27883	69.129484000000005	69.151870000000002	55.579642999999997	55.567839999999997	Ленина	0103000020E61000000100000005000000BD5642774948514029AE2AFBAEC84B40BD564277494851407B2DE8BD31CA4B4096CFF23CB84951407B2DE8BD31CA4B4096CFF23CB849514029AE2AFBAEC84B40BD5642774948514029AE2AFBAEC84B40
42420	27736	68.976473999999996	69.001474000000002	55.759582999999999	55.750281999999999	Ельцова	0103000020E610000001000000050000003CD9CD8C7E3E51408463963D09E04B403CD9CD8C7E3E51407DCC07043AE14B40D6726726184051407DCC07043AE14B40D6726726184051408463963D09E04B403CD9CD8C7E3E51408463963D09E04B40
42346	27834	69.611969999999999	69.635559000000001	55.766911	55.759202999999999	Гагарина	0103000020E61000000100000005000000850838842A67514036035C902DE14B40850838842A675140A9F8BF232AE24B406CEBA7FFAC685140A9F8BF232AE24B406CEBA7FFAC68514036035C902DE14B40850838842A67514036035C902DE14B40
77892	27642	68.973375000000004	68.996848	55.818928	55.812018999999999	Молодёжная	0103000020E610000001000000050000009EEFA7C64B3E5140855D143DF0E74B409EEFA7C64B3E5140ACE3F8A1D2E84B4050C58D5BCC3F5140ACE3F8A1D2E84B4050C58D5BCC3F5140855D143DF0E74B409EEFA7C64B3E5140855D143DF0E74B40
78065	27937	69.218093999999994	69.226304999999996	55.535986999999999	55.522041000000002	Центральная	0103000020E610000001000000050000000B5D8940F54D5140E8154F3DD2C24B400B5D8940F54D5140630AD6389BC44B40F67AF7C77B4E5140630AD6389BC44B40F67AF7C77B4E5140E8154F3DD2C24B400B5D8940F54D5140E8154F3DD2C24B40
42523	27544	69.394891999999999	69.427032999999994	55.563813000000003	55.548955999999997	переулок Школьный	0103000020E61000000100000005000000EE5C18E945595140B378B13044C64B40EE5C18E945595140A3073E062BC84B4004543882545B5140A3073E062BC84B4004543882545B5140B378B13044C64B40EE5C18E945595140B378B13044C64B40
42549	27510	69.308537000000001	69.325963999999999	55.831260999999998	55.819696999999998	Новая	0103000020E61000000100000005000000C826F911BF5351408DD0CFD4EBE84B40C826F911BF5351405AB8ACC266EA4B4018EB1B98DC5451405AB8ACC266EA4B4018EB1B98DC5451408DD0CFD4EBE84B40C826F911BF5351408DD0CFD4EBE84B40
42361	27462	69.303353000000001	69.320330999999996	55.777424000000003	55.770836000000003	Победы	0103000020E610000001000000050000002F89B3226A5351402C4A09C1AAE24B402F89B3226A53514011902FA182E34B404739984D8054514011902FA182E34B404739984D805451402C4A09C1AAE24B402F89B3226A5351402C4A09C1AAE24B40
42075	27344	69.199282999999994	69.212254999999999	55.688679999999998	55.671244999999999	Садова	0103000020E6100000010000000500000085E97B0DC14C5140404D2D5BEBD54B4085E97B0DC14C514063B48EAA26D84B4066DAFE95954D514063B48EAA26D84B4066DAFE95954D5140404D2D5BEBD54B4085E97B0DC14C5140404D2D5BEBD54B40
41920	27344	69.199282999999994	69.212254999999999	55.688679999999998	55.671244999999999	Ленина	0103000020E6100000010000000500000085E97B0DC14C5140404D2D5BEBD54B4085E97B0DC14C514063B48EAA26D84B4066DAFE95954D514063B48EAA26D84B4066DAFE95954D5140404D2D5BEBD54B4085E97B0DC14C5140404D2D5BEBD54B40
42520	26502	69.433519000000004	69.452483000000001	55.385126999999997	55.380324000000002	Центральная	0103000020E6100000010000000500000075CC79C6BE5B514024F1F274AEB04B4075CC79C6BE5B51403EE76ED74BB14B40BEBF417BF55C51403EE76ED74BB14B40BEBF417BF55C514024F1F274AEB04B4075CC79C6BE5B514024F1F274AEB04B40
42545	26650	69.363684000000006	69.375955000000005	55.796643000000003	55.789825999999998	Малая	0103000020E610000001000000050000000685419946575140E7C3B30419E54B4006854199465751402ECBD765F8E54B4022718FA50F5851402ECBD765F8E54B4022718FA50F585140E7C3B30419E54B400685419946575140E7C3B30419E54B40
77815	61259	69.308384000000004	69.324202999999997	55.613289999999999	55.607880000000002	60 лет Октября	0103000020E6100000010000000500000005A73E90BC5351403DF20703CFCD4B4005A73E90BC5351405F7B664980CE4B40F790F0BDBF5451405F7B664980CE4B40F790F0BDBF5451403DF20703CFCD4B4005A73E90BC5351403DF20703CFCD4B40
78142	27711	69.051779999999994	69.061760000000007	55.832106000000003	55.823504999999997	Зеленая	0103000020E610000001000000050000008FA50F5D50435140D68BA19C68E94B408FA50F5D5043514017670C7382EA4B40DD0C37E0F343514017670C7382EA4B40DD0C37E0F3435140D68BA19C68E94B408FA50F5D50435140D68BA19C68E94B40
42487	27620	69.468446	69.493554000000003	55.539268	55.531351000000001	Центральная	0103000020E610000001000000050000004A7CEE04FB5D514034D93F4F03C44B404A7CEE04FB5D5140C1E3DBBB06C54B40D7338463965F5140C1E3DBBB06C54B40D7338463965F514034D93F4F03C44B404A7CEE04FB5D514034D93F4F03C44B40
42011	27139	69.190389999999994	69.253173000000004	55.673406999999997	55.620479000000003	Луначарского	0103000020E6100000010000000500000011DF89592F4C51406A6D1ADB6BCF4B4011DF89592F4C5140E0F2583332D64B40BCCE86FC33505140E0F2583332D64B40BCCE86FC335051406A6D1ADB6BCF4B4011DF89592F4C51406A6D1ADB6BCF4B40
42019	27139	69.190389999999994	69.253173000000004	55.673406999999997	55.620479000000003	Ленина	0103000020E6100000010000000500000011DF89592F4C51406A6D1ADB6BCF4B4011DF89592F4C5140E0F2583332D64B40BCCE86FC33505140E0F2583332D64B40BCCE86FC335051406A6D1ADB6BCF4B4011DF89592F4C51406A6D1ADB6BCF4B40
42015	27139	69.190389999999994	69.253173000000004	55.673406999999997	55.620479000000003	Ишимская	0103000020E6100000010000000500000011DF89592F4C51406A6D1ADB6BCF4B4011DF89592F4C5140E0F2583332D64B40BCCE86FC33505140E0F2583332D64B40BCCE86FC335051406A6D1ADB6BCF4B4011DF89592F4C51406A6D1ADB6BCF4B40
42070	26965	69.313316	69.334192000000002	55.455295	55.441457999999997	Ленина	0103000020E6100000010000000500000011548D5E0D5451405E471CB281B84B4011548D5E0D5451402384471B47BA4B406EA5D766635551402384471B47BA4B406EA5D766635551405E471CB281B84B4011548D5E0D5451405E471CB281B84B40
42544	27078	69.336582000000007	69.349913000000001	55.404125999999998	55.386496999999999	Пограничная	0103000020E61000000100000005000000079B3A8F8A5551404580D3BB78B14B40079B3A8F8A5551404DBB9866BAB34B407FDC7EF9645651404DBB9866BAB34B407FDC7EF9645651404580D3BB78B14B40079B3A8F8A5551404580D3BB78B14B40
42359	26793	68.880955999999998	68.916593000000006	55.490375999999998	55.480612000000001	Ленина	0103000020E61000000100000005000000C24D4695613851405708ABB184BD4B40C24D469561385140245F09A4C4BE4B4086AFAF75A93A5140245F09A4C4BE4B4086AFAF75A93A51405708ABB184BD4B40C24D4695613851405708ABB184BD4B40
42267	26867	68.836282999999995	68.867760000000004	55.570247999999999	55.558259	Зеленая	0103000020E61000000100000005000000D9CC21A9853551404DD9E90775C74B40D9CC21A985355140014EEFE2FDC84B40BA313D6189375140014EEFE2FDC84B40BA313D61893751404DD9E90775C74B40D9CC21A9853551404DD9E90775C74B40
42356	26790	69.218642000000003	69.237093999999999	55.747225999999998	55.734445000000001	Лугова	0103000020E610000001000000050000000DE2033BFE4D5140F9DA334B02DE4B400DE2033BFE4D5140465C001AA5DF4B40FB04508C2C4F5140465C001AA5DF4B40FB04508C2C4F5140F9DA334B02DE4B400DE2033BFE4D5140F9DA334B02DE4B40
42417	26599	69.425927999999999	69.446329000000006	55.795034000000001	55.783838000000003	Школьная	0103000020E61000000100000005000000D89C8367425B514058AEB7CD54E44B40D89C8367425B5140A29A92ACC3E54B40699082A7905C5140A29A92ACC3E54B40699082A7905C514058AEB7CD54E44B40D89C8367425B514058AEB7CD54E44B40
42355	26677	69.284767000000002	69.313046	55.599406999999999	55.584415999999997	Кирова	0103000020E61000000100000005000000B9FE5D9F395251402BA1BB24CECA4B40B9FE5D9F395251402AFF5A5EB9CC4B40310917F2085451402AFF5A5EB9CC4B40310917F2085451402BA1BB24CECA4B40B9FE5D9F395251402BA1BB24CECA4B40
42522	27061	69.157404	69.181990999999996	55.394478999999997	55.386783000000001	Мира	0103000020E610000001000000050000009D103AE8124A51400BD3F71A82B14B409D103AE8124A5140B9FAB1497EB24B40A54A94BDA54B5140B9FAB1497EB24B40A54A94BDA54B51400BD3F71A82B14B409D103AE8124A51400BD3F71A82B14B40
78030	26988	69.329881	69.356740000000002	55.489555000000003	55.476050999999998	Центральная	0103000020E6100000010000000500000098A432C51C555140321D3A3DEFBC4B4098A432C51C555140F14BFDBCA9BE4B40344B02D4D4565140F14BFDBCA9BE4B40344B02D4D4565140321D3A3DEFBC4B4098A432C51C555140321D3A3DEFBC4B40
42340	26429	69.417781000000005	69.435001	55.460864000000001	55.444946000000002	Мира	0103000020E61000000100000005000000F9F884ECBC5A5140363E93FDF3B84B40F9F884ECBC5A5140AEF36F97FDBA4B408C2E6F0ED75B5140AEF36F97FDBA4B408C2E6F0ED75B5140363E93FDF3B84B40F9F884ECBC5A5140363E93FDF3B84B40
77040	24963	69.754227	69.775606999999994	56.024275000000003	56.008324000000002	Ленина	0103000020E61000000100000005000000A7B0524145705140CEE2C5C210014C40A7B0524145705140228E75711B034C401DE38A8BA3715140228E75711B034C401DE38A8BA3715140CEE2C5C210014C40A7B0524145705140CEE2C5C210014C40
42542	24857	69.388549999999995	69.416020000000003	56.224952999999999	56.214962	Новая	0103000020E6100000010000000500000017B7D100DE585140FEF0F3DF831B4C4017B7D100DE5851408C118942CB1C4C40D89E5912A05A51408C118942CB1C4C40D89E5912A05A5140FEF0F3DF831B4C4017B7D100DE585140FEF0F3DF831B4C40
77132	24666	69.124983999999998	69.152939000000003	56.213155	56.197142999999997	Школьная	0103000020E610000001000000050000007D21E4BCFF47514052D158FB3B194C407D21E4BCFF4751404CFDBCA9481B4C401CD2A8C0C94951404CFDBCA9481B4C401CD2A8C0C949514052D158FB3B194C407D21E4BCFF47514052D158FB3B194C40
77961	23117	68.587898999999993	70.068196999999998	56.645198000000001	55.809398000000002	Интернатская	0103000020E6100000010000000500000078962023A025514052B9895A9AE74B4078962023A0255140E9B81AD995524C40DC2BF3565D845140E9B81AD995524C40DC2BF3565D84514052B9895A9AE74B4078962023A025514052B9895A9AE74B40
42007	24424	69.520951999999994	69.554630000000003	56.144562000000001	56.132523999999997	Стаханова	0103000020E610000001000000050000004AB20E4757615140B1F7E28BF6104C404AB20E4757615140471FF30181124C405AD8D30E7F635140471FF30181124C405AD8D30E7F635140B1F7E28BF6104C404AB20E4757615140B1F7E28BF6104C40
42002	24424	69.520951999999994	69.554630000000003	56.144562000000001	56.132523999999997	Мелиоративная	0103000020E610000001000000050000004AB20E4757615140B1F7E28BF6104C404AB20E4757615140471FF30181124C405AD8D30E7F635140471FF30181124C405AD8D30E7F635140B1F7E28BF6104C404AB20E4757615140B1F7E28BF6104C40
42266	23380	69.467341000000005	69.490481000000003	56.017688999999997	56.010699000000002	Мира	0103000020E610000001000000050000001EC539EAE85D5140CA8CB7955E014C401EC539EAE85D5140DD3F16A243024C40CD936B0A645F5140DD3F16A243024C40CD936B0A645F5140CA8CB7955E014C401EC539EAE85D5140CA8CB7955E014C40
77885	24949	69.496069000000006	69.520511999999997	56.242924000000002	56.235636	Димитрова	0103000020E61000000100000005000000CEE33098BF5F514050E10852291E4C40CEE33098BF5F5140EEB43522181F4C403C4B901150615140EEB43522181F4C403C4B90115061514050E10852291E4C40CEE33098BF5F514050E10852291E4C40
42541	24256	69.778580000000005	69.81268	56.197223000000001	56.187660999999999	Школьная	0103000020E6100000010000000500000076543541D471514009DE904605184C4076543541D47151406F826F9A3E194C404087F9F2027451406F826F9A3E194C404087F9F20274514009DE904605184C4076543541D471514009DE904605184C40
42264	24161	69.756005000000002	69.773145	56.318919999999999	56.304324999999999	Центральная	0103000020E6100000010000000500000033A7CB6262705140772D211FF4264C4033A7CB62627051402905DD5ED2284C4038842A357B7151402905DD5ED2284C4038842A357B715140772D211FF4264C4033A7CB6262705140772D211FF4264C40
77737	24021	69.405680000000004	69.418823000000003	56.086063000000003	56.075519	Светлая	0103000020E610000001000000050000000B293FA9F6595140029D499BAA094C400B293FA9F6595140A532C51C040B4C4002F4FBFECD5A5140A532C51C040B4C4002F4FBFECD5A5140029D499BAA094C400B293FA9F6595140029D499BAA094C40
77035	24090	69.669685999999999	69.702366999999995	56.082104999999999	56.070163000000001	Советская	0103000020E61000000100000005000000B325AB22DC6A5140D331E719FB084C40B325AB22DC6A514046EBA86A820A4C4089B2B794F36C514046EBA86A820A4C4089B2B794F36C5140D331E719FB084C40B325AB22DC6A5140D331E719FB084C40
42394	23865	69.389672000000004	69.407747000000001	56.060865999999997	56.050742	Новая	0103000020E61000000100000005000000AF0AD462F05851404E44BFB67E064C40AF0AD462F05851401BB80375CA074C40B282DF86185A51401BB80375CA074C40B282DF86185A51404E44BFB67E064C40AF0AD462F05851404E44BFB67E064C40
77792	61253	65.529064000000005	65.542862	57.087135000000004	57.086719000000002	Центральная	0103000020E610000001000000050000006C5F402FDC6150408E78B29B198B4C406C5F402FDC61504022AB5B3D278B4C406F0F4240BE62504022AB5B3D278B4C406F0F4240BE6250408E78B29B198B4C406C5F402FDC6150408E78B29B198B4C40
77879	23433	69.492332000000005	69.502689000000004	55.959978999999997	55.947485	Центральная	0103000020E610000001000000050000008EB1135E825F5140AC39403047F94B408EB1135E825F514063EC8497E0FA4B40C6C37B0E2C60514063EC8497E0FA4B40C6C37B0E2C605140AC39403047F94B408EB1135E825F5140AC39403047F94B40
77880	24802	69.156829000000002	69.174840000000003	56.237411999999999	56.232874000000002	Дорожная	0103000020E610000001000000050000001F84807C094A51405B0BB3D0CE1D4C401F84807C094A5140C7D63384631E4C4017821C94304B5140C7D63384631E4C4017821C94304B51405B0BB3D0CE1D4C401F84807C094A51405B0BB3D0CE1D4C40
42065	23158	68.914490999999998	68.945941000000005	56.296379000000002	56.280301999999999	Ленина	0103000020E61000000100000005000000205F4205873A51406F8099EFE0234C40205F4205873A5140501C40BFEF254C4084BC1E4C8A3C5140501C40BFEF254C4084BC1E4C8A3C51406F8099EFE0234C40205F4205873A51406F8099EFE0234C40
77884	23635	68.755767000000006	68.776499999999999	56.068776	56.063394000000002	Школьная	0103000020E6100000010000000500000059198D7C5E3051409E616A4B1D084C4059198D7C5E305140F65FE7A6CD084C4004560E2DB2315140F65FE7A6CD084C4004560E2DB23151409E616A4B1D084C4059198D7C5E3051409E616A4B1D084C40
77731	23797	69.23227	69.257035999999999	55.937446999999999	55.915210000000002	Центральная	0103000020E61000000100000005000000E275FD82DD4E5140707CED9925F54B40E275FD82DD4E5140DD5D6743FEF74B4042791F4773505140DD5D6743FEF74B4042791F4773505140707CED9925F54B40E275FD82DD4E5140707CED9925F54B40
77150	23717	69.040514999999999	69.068156000000002	56.028067999999998	56.007739999999998	Советская	0103000020E61000000100000005000000D6FF39CC974251407E6FD39FFD004C40D6FF39CC97425140350873BB97034C40ADC1FBAA5C445140350873BB97034C40ADC1FBAA5C4451407E6FD39FFD004C40D6FF39CC974251407E6FD39FFD004C40
42540	23302	68.947395999999998	68.962981999999997	56.337017000000003	56.327030999999998	Животноводов	0103000020E610000001000000050000001E17D522A23C51409BE3DC26DC294C401E17D522A23C51401899805F232B4C40BF28417FA13D51401899805F232B4C40BF28417FA13D51409BE3DC26DC294C401E17D522A23C51409BE3DC26DC294C40
77875	23075	69.216316000000006	69.238324000000006	56.108944000000001	56.102387999999998	Центральная	0103000020E610000001000000050000008066101FD84D51405DC0CB0C1B0D4C408066101FD84D5140378C82E0F10D4C4086764EB3404F5140378C82E0F10D4C4086764EB3404F51405DC0CB0C1B0D4C408066101FD84D51405DC0CB0C1B0D4C40
77066	22895	69.057332000000002	69.105383000000003	56.081391000000004	56.062710000000003	Зелёная	0103000020E61000000100000005000000EA40D653AB435140EB909BE106084C40EA40D653AB435140299831056B0A4C407BA35698BE465140299831056B0A4C407BA35698BE465140EB909BE106084C40EA40D653AB435140EB909BE106084C40
42578	22833	69.410729000000003	69.424806000000004	56.140022999999999	56.127893	Центральная	0103000020E6100000010000000500000034A14962495A514094313ECC5E104C4034A14962495A51400AD80E46EC114C4041498105305B51400AD80E46EC114C4041498105305B514094313ECC5E104C4034A14962495A514094313ECC5E104C40
78037	23017	69.355284999999995	69.375119999999995	56.160044999999997	56.153618000000002	Центральная	0103000020E6100000010000000500000099F04BFDBC565140D9092FC1A9134C4099F04BFDBC565140B471C45A7C144C40D50451F701585140B471C45A7C144C40D50451F701585140D9092FC1A9134C4099F04BFDBC565140D9092FC1A9134C40
77962	24315	69.838417000000007	69.854118999999997	56.171191999999998	56.165328000000002	Васильева	0103000020E6100000010000000500000045DAC69FA87551407A8EC87729154C4045DAC69FA87551401DAB949EE9154C401AF9BCE2A97651401DAB949EE9154C401AF9BCE2A97651407A8EC87729154C4045DAC69FA87551407A8EC87729154C40
78129	23771	68.964302000000004	68.981809999999996	55.992085000000003	55.980074000000002	Центральная	0103000020E61000000100000005000000EA5DBC1FB73D514078D4981073FD4B40EA5DBC1FB73D514014ED2AA4FCFE4B40B0389CF9D53E514014ED2AA4FCFE4B40B0389CF9D53E514078D4981073FD4B40EA5DBC1FB73D514078D4981073FD4B40
77881	24616	69.474518000000003	69.482010000000002	56.163549000000003	56.159413000000001	Надежд	0103000020E6100000010000000500000041D7BE805E5E514054C72AA567144C4041D7BE805E5E51409225732CEF144C4014967840D95E51409225732CEF144C4014967840D95E514054C72AA567144C4041D7BE805E5E514054C72AA567144C40
42292	23472	69.325496999999999	69.355069	55.874353999999997	55.864201999999999	Советская	0103000020E610000001000000050000008D7C5EF1D4545140A391CF2B9EEE4B408D7C5EF1D45451403A90F5D4EAEF4B40B3B45373B95651403A90F5D4EAEF4B40B3B45373B9565140A391CF2B9EEE4B408D7C5EF1D4545140A391CF2B9EEE4B40
77801	24704	68.984164000000007	69.005094999999997	56.237896999999997	56.229866999999999	Победы	0103000020E61000000100000005000000A379008BFC3E5140FEB627486C1D4C40A379008BFC3E51408368AD68731E4C40E197FA79534051408368AD68731E4C40E197FA7953405140FEB627486C1D4C40A379008BFC3E5140FEB627486C1D4C40
78040	23252	68.989563000000004	69.009326000000001	56.278162999999999	56.269886	Центральная 	0103000020E610000001000000050000003A950C00553F5140FAD2DB9F8B224C403A950C00553F514087FA5DD89A234C40294014CC9840514087FA5DD89A234C40294014CC98405140FAD2DB9F8B224C403A950C00553F5140FAD2DB9F8B224C40
77966	24351	69.802852999999999	69.823549999999997	56.120638	56.115569000000001	Ишимская	0103000020E61000000100000005000000B69F8CF16173514039B709F7CA0E4C40B69F8CF161735140D253E410710F4C40BB270F0BB5745140D253E410710F4C40BB270F0BB574514039B709F7CA0E4C40B69F8CF16173514039B709F7CA0E4C40
42297	23327	69.442753999999994	69.457262	55.971904000000002	55.955891999999999	Победы	0103000020E61000000100000005000000158BDF14565C5140074147AB5AFA4B40158BDF14565C5140016DAB5967FC4B4007EDD5C7435D5140016DAB5967FC4B4007EDD5C7435D5140074147AB5AFA4B40158BDF14565C5140074147AB5AFA4B40
77927	23204	68.915325999999993	68.941744999999997	56.313738000000001	56.299025999999998	Гагарина	0103000020E610000001000000050000006CCB80B3943A5140AC53E57B46264C406CCB80B3943A514098C1189128284C40FA0AD28C453C514098C1189128284C40FA0AD28C453C5140AC53E57B46264C406CCB80B3943A5140AC53E57B46264C40
77799	24194	69.738344999999995	69.756715	56.378833	56.373185999999997	Мира	0103000020E61000000100000005000000910A630B416F51409BA9108FC42F4C40910A630B416F5140A2D288997D304C402159C0046E705140A2D288997D304C402159C0046E7051409BA9108FC42F4C40910A630B416F51409BA9108FC42F4C40
41933	4461	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Уральская	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
42377	4461	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	М. Садовая	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
41919	4461	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	Курганская	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
41907	4461	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	К. Маркса	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
41906	4461	69.385935000000003	69.544650000000004	56.137962000000002	56.086579999999998	30 лет ВЛКСМ	0103000020E610000001000000050000006FD8B628B35851406C3EAE0D150B4C406FD8B628B35851409E0B23BDA8114C400D71AC8BDB6251409E0B23BDA8114C400D71AC8BDB6251406C3EAE0D150B4C406FD8B628B35851406C3EAE0D150B4C40
77048	24552	69.483986999999999	69.512148999999994	56.138753999999999	56.131695999999998	Дзержинского	0103000020E610000001000000050000001B2C9CA4F95E5140CB811E6ADB104C401B2C9CA4F95E51403718EAB0C2114C40766B990CC76051403718EAB0C2114C40766B990CC7605140CB811E6ADB104C401B2C9CA4F95E5140CB811E6ADB104C40
42357	24061	69.495467000000005	69.531400000000005	56.330216	56.319704000000002	Победы	0103000020E61000000100000005000000D34F38BBB55F51404033880FEC284C40D34F38BBB55F5140D74E9484442A4C400B46257502625140D74E9484442A4C400B462575026251404033880FEC284C40D34F38BBB55F51404033880FEC284C40
77970	24777	69.212335999999993	69.230104999999995	56.177306000000002	56.171317000000002	Советская	0103000020E61000000100000005000000DCF0BBE9964D5140DA1F28B7ED154C40DCF0BBE9964D51403AB187F6B1164C405969520ABA4E51403AB187F6B1164C405969520ABA4E5140DA1F28B7ED154C40DCF0BBE9964D5140DA1F28B7ED154C40
42555	22932	69.289761999999996	69.316953999999996	56.183228	56.174314000000003	Школьная площадь	0103000020E61000000100000005000000E867EA758B525140139ED0EB4F164C40E867EA758B52514012DBDD0374174C4087156EF94854514012DBDD0374174C4087156EF948545140139ED0EB4F164C40E867EA758B525140139ED0EB4F164C40
42291	22790	68.896182999999994	68.918263999999994	56.268366	56.249761999999997	Центральная	0103000020E61000000100000005000000CB0EF10F5B3951404BE48233F81F4C40CB0EF10F5B395140DEAD2CD159224C4006465ED6C43A5140DEAD2CD159224C4006465ED6C43A51404BE48233F81F4C40CB0EF10F5B3951404BE48233F81F4C40
77828	25058	69.996700000000004	70.014729000000003	56.074643999999999	56.063484000000003	Школьный переулок	0103000020E6100000010000000500000016FBCBEEC97F5140DEE8633E20084C4016FBCBEEC97F5140DB6B41EF8D094C406153E751F1805140DB6B41EF8D094C406153E751F1805140DEE8633E20084C4016FBCBEEC97F5140DEE8633E20084C40
42288	22760	69.360063999999994	69.398736	56.012124	56.000593000000002	Новая	0103000020E61000000100000005000000E21DE0490B575140A3CD716E13004C40E21DE0490B57514094BF7B478D014C4039EFFFE38459514094BF7B478D014C4039EFFFE384595140A3CD716E13004C40E21DE0490B575140A3CD716E13004C40
42416	22720	69.113197999999997	69.144244	55.879899000000002	55.863090999999997	Советская	0103000020E610000001000000050000003FFED2A23E475140683C11C479EE4B403FFED2A23E4751403D64CA87A0F04B403BA92F4B3B4951403D64CA87A0F04B403BA92F4B3B495140683C11C479EE4B403FFED2A23E475140683C11C479EE4B40
78354	61274	69.422775000000001	69.437884999999994	55.903221000000002	55.898274999999998	Центральная	0103000020E6100000010000000500000040A4DFBE0E5B51403EE8D9ACFAF24B4040A4DFBE0E5B5140BC07E8BE9CF34B402C9ACE4E065C5140BC07E8BE9CF34B402C9ACE4E065C51403EE8D9ACFAF24B4040A4DFBE0E5B51403EE8D9ACFAF24B40
77047	23970	69.367637000000002	69.381991999999997	56.092706999999997	56.086153000000003	 Дорожная	0103000020E610000001000000050000002CF3565D87575140E5B9BE0F070B4C402CF3565D875751401D8EAED2DD0B4C405AD5928E725851401D8EAED2DD0B4C405AD5928E72585140E5B9BE0F070B4C402CF3565D87575140E5B9BE0F070B4C40
77750	23882	69.269656999999995	69.288154000000006	56.065458999999997	56.059835999999997	Средняя	0103000020E61000000100000005000000CC086F0F42515140CD8FBFB4A8074C40CC086F0F425151404B1DE4F560084C408B8D791D715251404B1DE4F560084C408B8D791D71525140CD8FBFB4A8074C40CC086F0F42515140CD8FBFB4A8074C40
78035	22621	69.186347999999995	69.206801999999996	56.427208999999998	56.418287999999997	Центральная	0103000020E61000000100000005000000336B2920ED4B5140952710768A354C40336B2920ED4B514047C7D5C8AE364C40D5AF743E3C4D514047C7D5C8AE364C40D5AF743E3C4D5140952710768A354C40336B2920ED4B5140952710768A354C40
42290	22537	69.674232000000003	69.693365999999997	56.171337000000001	56.161313	Школьная	0103000020E61000000100000005000000AB7AF99D266B5140B7B585E7A5144C40AB7AF99D266B514021CCED5EEE154C40228AC91B606C514021CCED5EEE154C40228AC91B606C5140B7B585E7A5144C40AB7AF99D266B5140B7B585E7A5144C40
42449	22676	69.047162999999998	69.063539000000006	56.350861000000002	56.346032999999998	Центральная	0103000020E6100000010000000500000033A5F5B7044351401B2B31CF4A2C4C4033A5F5B7044351408F386403E92C4C4051C1E105114451408F386403E92C4C4051C1E105114451401B2B31CF4A2C4C4033A5F5B7044351401B2B31CF4A2C4C40
42519	22593	69.608851999999999	69.629181000000003	56.113506999999998	56.106073000000002	Зеленая	0103000020E61000000100000005000000AB06616EF76651408BFED0CC930D4C40AB06616EF7665140FC6EBA65870E4C40EF90628044685140FC6EBA65870E4C40EF906280446851408BFED0CC930D4C40AB06616EF76651408BFED0CC930D4C40
78062	24880	69.353442999999999	69.370555999999993	56.178358000000003	56.171973999999999	Заречная	0103000020E61000000100000005000000028063CF9E56514093E1783E03164C40028063CF9E565140707D586FD4164C408A558330B7575140707D586FD4164C408A558330B757514093E1783E03164C40028063CF9E56514093E1783E03164C40
77965	24515	69.635694000000001	69.643401999999995	56.212173999999997	56.208373999999999	п. Чернова	0103000020E61000000100000005000000DC10E335AF68514019ABCDFFAB1A4C40DC10E335AF685140DF878384281B4C40950B957F2D695140DF878384281B4C40950B957F2D69514019ABCDFFAB1A4C40DC10E335AF68514019ABCDFFAB1A4C40
41912	22439	65.364906000000005	65.394721000000004	56.674816999999997	56.646845999999996	Калинина	0103000020E610000001000000050000004F07B29E5A57504032C687D9CB524C404F07B29E5A57504075E4486760564C40D882DE1B4359504075E4486760564C40D882DE1B4359504032C687D9CB524C404F07B29E5A57504032C687D9CB524C40
77787	21059	65.111581000000001	65.138844000000006	56.448051	56.438164	Полевая	0103000020E61000000100000005000000B876A224244750406C2409C215384C40B876A2242447504055F833BC59394C40BCCFF1D1E248504055F833BC59394C40BCCFF1D1E24850406C2409C215384C40B876A224244750406C2409C215384C40
42448	22283	65.415013999999999	65.428407000000007	56.347977999999998	56.331412999999998	Кирова	0103000020E610000001000000050000007558E1968F5A5040103CBEBD6B2A4C407558E1968F5A50401EDD088B8A2C4C40299831056B5B50401EDD088B8A2C4C40299831056B5B5040103CBEBD6B2A4C407558E1968F5A5040103CBEBD6B2A4C40
42339	22243	65.362875000000003	65.398961	56.447727	56.433067999999999	Октябрьская	0103000020E610000001000000050000004E62105839575040D978B0C56E374C404E62105839575040A2444B1E4F394C4049D8B79388595040A2444B1E4F394C4049D8B79388595040D978B0C56E374C404E62105839575040D978B0C56E374C40
77016	61032	65.823469000000003	65.859536000000006	56.537795000000003	56.528283999999999	Им. Старцева	0103000020E61000000100000005000000451152B7B3745040028063CF9E434C40451152B7B3745040E6797077D6444C40056F48A302775040E6797077D6444C40056F48A302775040028063CF9E434C40451152B7B3745040028063CF9E434C40
77789	21146	65.152158	65.164473000000001	56.482174999999998	56.477269	Механизаторов	0103000020E61000000100000005000000C974E8F4BC49504083328D26173D4C40C974E8F4BC49504072F90FE9B73D4C40CD04C3B9864A504072F90FE9B73D4C40CD04C3B9864A504083328D26173D4C40C974E8F4BC49504083328D26173D4C40
77956	21644	65.127813000000003	65.141161999999994	56.626842000000003	56.621324999999999	Свободы	0103000020E610000001000000050000003CC093162E485040F697DD93874F4C403CC093162E4850402FE1D05B3C504C40075C57CC084950402FE1D05B3C504C40075C57CC08495040F697DD93874F4C403CC093162E485040F697DD93874F4C40
42349	55089	65.235637999999994	65.271102999999997	56.438397999999999	56.427487999999997	Исаковых	0103000020E6100000010000000500000078EC67B1144F50405AB741EDB7364C4078EC67B1144F5040DF50F86C1D384C403DB665C059515040DF50F86C1D384C403DB665C0595150405AB741EDB7364C4078EC67B1144F50405AB741EDB7364C40
9966	21942	65.720979999999997	65.747579000000002	56.55048	56.532662999999999	Ленина	0103000020E610000001000000050000007C444C89246E504006651A4D2E444C407C444C89246E5040118DEE2076464C404A0B9755D86F5040118DEE2076464C404A0B9755D86F504006651A4D2E444C407C444C89246E504006651A4D2E444C40
78032	21915	65.732325000000003	65.745225000000005	56.447887000000001	56.437393	Школьная	0103000020E61000000100000005000000C442AD69DE6E5040EA3F6B7EFC374C40C442AD69DE6E5040DBA6785C54394C4058CA32C4B16F5040DBA6785C54394C4058CA32C4B16F5040EA3F6B7EFC374C40C442AD69DE6E5040EA3F6B7EFC374C40
42447	21763	65.239052000000001	65.248402999999996	56.542138000000001	56.530290000000001	Ишимская	0103000020E61000000100000005000000C782C2A04C4F5040ABB2EF8AE0434C40C782C2A04C4F50409DF529C764454C409C4EB2D5E54F50409DF529C764454C409C4EB2D5E54F5040ABB2EF8AE0434C40C782C2A04C4F5040ABB2EF8AE0434C40
42332	21820	65.629306999999997	65.663083	56.431176000000001	56.422325999999998	Мира	0103000020E610000001000000050000003509DE9046685040102043C70E364C403509DE9046685040F96871C630374C4026E2ADF36F6A5040F96871C630374C4026E2ADF36F6A5040102043C70E364C403509DE9046685040102043C70E364C40
78115	22402	65.419595000000001	65.426242999999999	56.470388	56.463997999999997	Береговая	0103000020E610000001000000050000002BA4FCA4DA5A504067B45549643B4C402BA4FCA4DA5A504026378AAC353C4C408849B890475B504026378AAC353C4C408849B890475B504067B45549643B4C402BA4FCA4DA5A504067B45549643B4C40
77954	21860	65.600757999999999	65.614537999999996	56.440936000000001	56.433644999999999	Школьная	0103000020E61000000100000005000000DDB3AED1726650407689EAAD81374C40DDB3AED17266504085D0419770384C408D0931975467504085D0419770384C408D093197546750407689EAAD81374C40DDB3AED1726650407689EAAD81374C40
42414	21561	65.457009999999997	65.476943000000006	56.635649000000001	56.618844000000003	Северная	0103000020E610000001000000050000007AFCDEA63F5D5040B5A9BA47364F4C407AFCDEA63F5D5040185E49F25C514C4098C3EE3B865E5040185E49F25C514C4098C3EE3B865E5040B5A9BA47364F4C407AFCDEA63F5D5040B5A9BA47364F4C40
77820	22320	65.555564000000004	65.572424999999996	56.494272000000002	56.482627000000001	Центральная	0103000020E6100000010000000500000070B54E5C8E6350405395B6B8C63D4C4070B54E5C8E6350400DAA0D4E443F4C406B9A779CA26450400DAA0D4E443F4C406B9A779CA26450405395B6B8C63D4C4070B54E5C8E6350405395B6B8C63D4C40
42415	21601	65.168272999999999	65.179411999999999	56.608213999999997	56.590057999999999	Первомайская	0103000020E6100000010000000500000030F31DFCC44A5040205F4205874B4C4030F31DFCC44A5040137CD3F4D94D4C40A320787C7B4B5040137CD3F4D94D4C40A320787C7B4B5040205F4205874B4C4030F31DFCC44A5040205F4205874B4C40
41917	21523	65.518032000000005	65.555025000000001	56.572657	56.558228999999997	Ленина	0103000020E610000001000000050000000492B06F27615040E256410C74474C400492B06F27615040A96917D34C494C4098DD938785635040A96917D34C494C4098DD938785635040E256410C74474C400492B06F27615040E256410C74474C40
42277	21469	65.729101	65.749078999999995	56.722948000000002	56.711938000000004	Центральная	0103000020E61000000100000005000000C79E3D97A96E5040CC63CDC8205B4C40C79E3D97A96E5040B45A608F895C4C40B4C70BE9F06F5040B45A608F895C4C40B4C70BE9F06F5040CC63CDC8205B4C40C79E3D97A96E5040CC63CDC8205B4C40
41914	21319	65.301169999999999	65.350649000000004	56.501018999999999	56.465350000000001	Строителей	0103000020E610000001000000050000005322895E46535040C898BB96903B4C405322895E465350405AD6FD6321404C4002D88008715650405AD6FD6321404C4002D8800871565040C898BB96903B4C405322895E46535040C898BB96903B4C40
42003	21319	65.301169999999999	65.350649000000004	56.501018999999999	56.465350000000001	Свердлова	0103000020E610000001000000050000005322895E46535040C898BB96903B4C405322895E465350405AD6FD6321404C4002D88008715650405AD6FD6321404C4002D8800871565040C898BB96903B4C405322895E46535040C898BB96903B4C40
77796	22492	65.396732999999998	65.407054000000002	56.609065999999999	56.602590999999997	Рабочая	0103000020E610000001000000050000009D0FCF126459504095EEAEB3214D4C409D0FCF1264595040828DEBDFF54D4C402F6D382C0D5A5040828DEBDFF54D4C402F6D382C0D5A504095EEAEB3214D4C409D0FCF126459504095EEAEB3214D4C40
42412	21270	65.640347000000006	65.664430999999993	56.663169000000003	56.650216	Гагарина	0103000020E61000000100000005000000DFC5FB71FB68504000AB23473A534C40DFC5FB71FB6850404B5CC7B8E2544C40B5DC9909866A50404B5CC7B8E2544C40B5DC9909866A504000AB23473A534C40DFC5FB71FB68504000AB23473A534C40
77784	21009	65.198924000000005	65.229331999999999	56.460456999999998	56.450459000000002	60 лет Октября	0103000020E61000000100000005000000EE98BA2BBB4C50402D98F8A3A8394C40EE98BA2BBB4C50406D1B4641F03A4C4048FB1F60AD4E50406D1B4641F03A4C4048FB1F60AD4E50402D98F8A3A8394C40EE98BA2BBB4C50402D98F8A3A8394C40
78064	21227	65.783467000000002	65.803327999999993	56.439995000000003	56.434536000000001	Янтимирова	0103000020E61000000100000005000000B29FC55224725040A3772AE09E374C40B29FC55224725040A7B393C151384C4082FDD7B969735040A7B393C151384C4082FDD7B969735040A3772AE09E374C40B29FC55224725040A3772AE09E374C40
42410	21200	65.515013999999994	65.533331000000004	56.525796999999997	56.513953999999998	Революции	0103000020E61000000100000005000000DBBE47FDF5605040FED2A23EC9414C40DBBE47FDF5605040DEAAEB504D434C405ABC581822625040DEAAEB504D434C405ABC581822625040FED2A23EC9414C40DBBE47FDF5605040FED2A23EC9414C40
78138	22364	65.460001000000005	65.472829000000004	56.480778000000001	56.474803000000001	Береговая	0103000020E6100000010000000500000026C808A8705D504077853E58C63C4C4026C808A8705D504072512D228A3D4C406DE690D4425E504072512D228A3D4C406DE690D4425E504077853E58C63C4C4026C808A8705D504077853E58C63C4C40
77794	22110	65.321839999999995	65.335566999999998	56.395879999999998	56.384624000000002	Пановых	0103000020E61000000100000005000000DBA2CC0699545040DCA0F65B3B314C40DBA2CC0699545040FB912232AC324C407AA702EE79555040FB912232AC324C407AA702EE79555040DCA0F65B3B314C40DBA2CC0699545040DCA0F65B3B314C40
77028	20919	65.200595000000007	65.236975999999999	56.476199999999999	56.470272999999999	Гагрина	0103000020E610000001000000050000006F2F698CD64C50408D98D9E7313C4C406F2F698CD64C5040772D211FF43C4C40F67B629D2A4F5040772D211FF43C4C40F67B629D2A4F50408D98D9E7313C4C406F2F698CD64C50408D98D9E7313C4C40
77061	20906	65.656363999999996	65.676593999999994	56.534579000000001	56.520777000000002	Школьная	0103000020E61000000100000005000000649126DE016A504027C11BD2A8424C40649126DE016A50406F10AD156D444C40DEAAEB504D6B50406F10AD156D444C40DEAAEB504D6B504027C11BD2A8424C40649126DE016A504027C11BD2A8424C40
77987	18522	66.652648999999997	66.665558000000004	56.447349000000003	56.438352999999999	Набережная	0103000020E6100000010000000500000018B14F00C5A950403F8D7BF31B384C4018B14F00C5A95040FC7266BB42394C40D6E5948098AA5040FC7266BB42394C40D6E5948098AA50403F8D7BF31B384C4018B14F00C5A950403F8D7BF31B384C40
42411	20133	66.653313999999995	66.667767999999995	56.640822	56.632268000000003	Приозерная	0103000020E61000000100000005000000360186E5CFA9504057276728EE504C40360186E5CFA9504056478E7406524C402E54FEB5BCAA504056478E7406524C402E54FEB5BCAA504057276728EE504C40360186E5CFA9504057276728EE504C40
77783	20368	66.187483999999998	66.200491	56.454428	56.442945999999999	Приозерная	0103000020E610000001000000050000007D21E4BCFF8B50406FF25B74B2384C407D21E4BCFF8B50407F315BB22A3A4C401C0934D8D48C50407F315BB22A3A4C401C0934D8D48C50406FF25B74B2384C407D21E4BCFF8B50406FF25B74B2384C40
77829	19652	66.955211000000006	66.981055999999995	56.700316000000001	56.688319999999997	Шоссейна	0103000020E61000000100000005000000E371512D22BD50406397A8DE1A584C40E371512D22BD5040CA6E66F4A3594C40DAE21A9FC9BE5040CA6E66F4A3594C40DAE21A9FC9BE50406397A8DE1A584C40E371512D22BD50406397A8DE1A584C40
42444	18654	66.596675000000005	66.617165999999997	56.322769000000001	56.316713999999997	Центральная	0103000020E61000000100000005000000D0D556EC2FA65040B91798158A284C40D0D556EC2FA65040D1949D7E50294C40008DD2A57FA75040D1949D7E50294C40008DD2A57FA75040B91798158A284C40D0D556EC2FA65040B91798158A284C40
77791	19920	66.667237999999998	66.682276000000002	56.482125000000003	56.475538999999998	Молодежная	0103000020E6100000010000000500000080290307B4AA50407C7C4276DE3C4C4080290307B4AA5040C1CAA145B63D4C4020B6F468AAAB5040C1CAA145B63D4C4020B6F468AAAB50407C7C4276DE3C4C4080290307B4AA50407C7C4276DE3C4C40
42517	20073	66.743981000000005	66.771263000000005	56.625484999999998	56.616911999999999	Школьная	0103000020E610000001000000050000001BF67B629DAF50404641F0F8F64E4C401BF67B629DAF5040BC9179E40F504C405A677C5F5CB15040BC9179E40F504C405A677C5F5CB150404641F0F8F64E4C401BF67B629DAF50404641F0F8F64E4C40
77946	20356	66.372159999999994	66.383702999999997	56.485754	56.475166000000002	Клубная	0103000020E6100000010000000500000047382D78D1975040E8154F3DD23C4C4047382D78D19750405AF3E32F2D3E4C40221807978E9850405AF3E32F2D3E4C40221807978E985040E8154F3DD23C4C4047382D78D1975040E8154F3DD23C4C40
77873	19968	66.731296999999998	66.743110000000001	56.469417999999997	56.461834000000003	Береговая	0103000020E610000001000000050000006DAAEE91CDAE5040271763601D3B4C406DAAEE91CDAE5040AD1397E3153C4C4028D53E1D8FAF5040AD1397E3153C4C4028D53E1D8FAF5040271763601D3B4C406DAAEE91CDAE5040271763601D3B4C40
42261	19401	66.830911	66.85248	56.526929000000003	56.514093000000003	Клубная	0103000020E61000000100000005000000BFB854A52DB55040200DA7CCCD414C40BFB854A52DB550403128D36872434C409F1F46088FB650403128D36872434C409F1F46088FB65040200DA7CCCD414C40BFB854A52DB55040200DA7CCCD414C40
42283	19503	66.911238999999995	66.937226999999993	56.547834999999999	56.534505000000003	Центральна	0103000020E61000000100000005000000BEF561BD51BA50403546EBA86A444C40BEF561BD51BA5040554D10751F464C40677BF486FBBB5040554D10751F464C40677BF486FBBB50403546EBA86A444C40BEF561BD51BA50403546EBA86A444C40
77941	20038	66.682123000000004	66.719637000000006	56.519342000000002	56.510973999999997	Центральная	0103000020E610000001000000050000005D363AE7A7AB50409B8D959867414C405D363AE7A7AB504039B874CC79424C4076FF58880EAE504039B874CC79424C4076FF58880EAE50409B8D959867414C405D363AE7A7AB50409B8D959867414C40
78238	20727	66.880398999999997	66.893128000000004	56.398665000000001	56.385133000000003	Центральная	0103000020E61000000100000005000000971B0C7558B8504021CEC3094C314C40971B0C7558B85040A987687407334C4015C9570229B95040A987687407334C4015C9570229B9504021CEC3094C314C40971B0C7558B8504021CEC3094C314C40
42537	19854	66.650448999999995	66.667013999999995	56.512121	56.504626000000002	Шоссейная	0103000020E61000000100000005000000D1ADD7F4A0A950400C5BB39597404C40D1ADD7F4A0A95040234C512E8D414C4058FE7C5BB0AA5040234C512E8D414C4058FE7C5BB0AA50400C5BB39597404C40D1ADD7F4A0A950400C5BB39597404C40
42461	20612	66.397841999999997	66.407769000000002	56.538961999999998	56.531813999999997	Луговая	0103000020E610000001000000050000006ABE4A3E7699504008C72C7B12444C406ABE4A3E76995040B4E4F1B4FC444C40A6D425E3189A5040B4E4F1B4FC444C40A6D425E3189A504008C72C7B12444C406ABE4A3E7699504008C72C7B12444C40
77823	20689	66.768154999999993	66.780156000000005	56.413860999999997	56.405225000000002	Центральная	0103000020E6100000010000000500000091D0967329B15040C442AD69DE334C4091D0967329B15040800BB265F9344C40CE716E13EEB15040800BB265F9344C40CE716E13EEB15040C442AD69DE334C4091D0967329B15040C442AD69DE334C40
9975	19743	66.592686999999998	66.632006000000004	56.519286999999998	56.503557999999998	Школьная	0103000020E61000000100000005000000EB707495EEA55040D0D1AA9674404C40EB707495EEA55040751E15FF77424C400D384BC972A85040751E15FF77424C400D384BC972A85040D0D1AA9674404C40EB707495EEA55040D0D1AA9674404C40
42262	19743	66.592686999999998	66.632006000000004	56.519286999999998	56.503557999999998	Молодежная	0103000020E61000000100000005000000EB707495EEA55040D0D1AA9674404C40EB707495EEA55040751E15FF77424C400D384BC972A85040751E15FF77424C400D384BC972A85040D0D1AA9674404C40EB707495EEA55040D0D1AA9674404C40
77896	18759	66.522150999999994	66.529984999999996	56.436481999999998	56.432091999999997	1я Озерная	0103000020E61000000100000005000000B72407EC6AA150407E6E68CA4E374C40B72407EC6AA1504076A565A4DE374C40B7973446EBA1504076A565A4DE374C40B7973446EBA150407E6E68CA4E374C40B72407EC6AA150407E6E68CA4E374C40
77019	20221	66.340575000000001	66.360579999999999	56.494385999999999	56.482945000000001	Первомайская	0103000020E6100000010000000500000074B515FBCB95504024624A24D13D4C4074B515FBCB955040D5CC5A0A483F4C40DEE522BE13975040D5CC5A0A483F4C40DEE522BE1397504024624A24D13D4C4074B515FBCB95504024624A24D13D4C40
78229	61286	66.09599	67.314797999999996	56.967198000000003	56.158596000000003	Пионерская	0103000020E610000001000000050000008EAF3DB32486504062A3ACDF4C144C408EAF3DB324865040D960E124CD7B4C4028B682A625D45040D960E124CD7B4C4028B682A625D4504062A3ACDF4C144C408EAF3DB32486504062A3ACDF4C144C40
42259	19049	66.875539000000003	66.958749999999995	56.492930000000001	56.475513999999997	Мира	0103000020E61000000100000005000000D8D7BAD408B8504023658BA4DD3C4C40D8D7BAD408B85040D09B8A54183F4C408FC2F5285CBD5040D09B8A54183F4C408FC2F5285CBD504023658BA4DD3C4C40D8D7BAD408B8504023658BA4DD3C4C40
42328	19049	66.875539000000003	66.958749999999995	56.492930000000001	56.475513999999997	Ленина	0103000020E61000000100000005000000D8D7BAD408B8504023658BA4DD3C4C40D8D7BAD408B85040D09B8A54183F4C408FC2F5285CBD5040D09B8A54183F4C408FC2F5285CBD504023658BA4DD3C4C40D8D7BAD408B8504023658BA4DD3C4C40
42256	19049	66.875539000000003	66.958749999999995	56.492930000000001	56.475513999999997	Вокзальная	0103000020E61000000100000005000000D8D7BAD408B8504023658BA4DD3C4C40D8D7BAD408B85040D09B8A54183F4C408FC2F5285CBD5040D09B8A54183F4C408FC2F5285CBD504023658BA4DD3C4C40D8D7BAD408B8504023658BA4DD3C4C40
42331	19049	66.875539000000003	66.958749999999995	56.492930000000001	56.475513999999997	Базарная	0103000020E61000000100000005000000D8D7BAD408B8504023658BA4DD3C4C40D8D7BAD408B85040D09B8A54183F4C408FC2F5285CBD5040D09B8A54183F4C408FC2F5285CBD504023658BA4DD3C4C40D8D7BAD408B8504023658BA4DD3C4C40
77957	20474	66.129515999999995	66.140097999999995	56.472907999999997	56.465389999999999	Северная	0103000020E61000000100000005000000C2137AFD4988504056F146E6913B4C40C2137AFD498850402502D53F883C4C400A0F9A5DF78850402502D53F883C4C400A0F9A5DF788504056F146E6913B4C40C2137AFD4988504056F146E6913B4C40
42442	18731	66.556196999999997	66.572789	56.411451	56.403919999999999	Лесная	0103000020E6100000010000000500000088484DBB98A35040A4198BA6B3334C4088484DBB98A350400874266DAA344C408CA03193A8A450400874266DAA344C408CA03193A8A45040A4198BA6B3334C4088484DBB98A35040A4198BA6B3334C40
77952	19436	66.782330000000002	66.800036000000006	56.525241000000001	56.514977000000002	Центральная	0103000020E61000000100000005000000802BD9B111B250409A982EC4EA414C40802BD9B111B2504059C2DA183B434C40DAE731CA33B3504059C2DA183B434C40DAE731CA33B350409A982EC4EA414C40802BD9B111B250409A982EC4EA414C40
42445	18610	66.450914999999995	66.464336000000003	56.286282999999997	56.278942000000001	Лесная	0103000020E61000000100000005000000A79196CADB9C50408CBD175FB4234C40A79196CADB9C50404C33DDEBA4244C40C09657AEB79D50404C33DDEBA4244C40C09657AEB79D50408CBD175FB4234C40A79196CADB9C50408CBD175FB4234C40
42062	19693	66.933553000000003	66.979555000000005	56.798532000000002	56.770401	Советская	0103000020E610000001000000050000004B051555BFBB504021E7FD7F9C624C404B051555BFBB50409D67EC4B36664C4088687407B1BE50409D67EC4B36664C4088687407B1BE504021E7FD7F9C624C404B051555BFBB504021E7FD7F9C624C40
78135	52043	66.694699999999997	66.704006000000007	56.335484999999998	56.323177999999999	Красная	0103000020E61000000100000005000000FF21FDF675AC5040B2648EE55D294C40FF21FDF675AC504037A6272CF12A4C40058C2E6F0EAD504037A6272CF12A4C40058C2E6F0EAD5040B2648EE55D294C40FF21FDF675AC5040B2648EE55D294C40
77905	19554	66.993515000000002	67.008481000000003	56.555739000000003	56.546633999999997	Береговая	0103000020E610000001000000050000007845F0BF95BF5040DA70581AF8454C407845F0BF95BF50404E0E9F7422474C40CB68E4F38AC050404E0E9F7422474C40CB68E4F38AC05040DA70581AF8454C407845F0BF95BF5040DA70581AF8454C40
42260	20500	66.589821000000001	66.602461000000005	56.543329	56.538133000000002	Дачная	0103000020E610000001000000050000009E5F94A0BFA55040FEF2C98AE1444C409E5F94A0BFA55040F4FBFECD8B454C40640795B88EA65040F4FBFECD8B454C40640795B88EA65040FEF2C98AE1444C409E5F94A0BFA55040FEF2C98AE1444C40
77777	18866	66.838340000000002	66.865110000000001	56.248235999999999	56.242074000000002	Лесная	0103000020E610000001000000050000006FBBD05CA7B55040209BE447FC1E4C406FBBD05CA7B550404DD87E32C61F4C40535C55F65DB750404DD87E32C61F4C40535C55F65DB75040209BE447FC1E4C406FBBD05CA7B55040209BE447FC1E4C40
77872	20251	66.331654	66.336855999999997	56.459577000000003	56.450752000000001	Притобольная	0103000020E610000001000000050000009BE5B2D139955040A54DD53DB2394C409BE5B2D139955040357F4C6BD33A4C4087DD770C8F955040357F4C6BD33A4C4087DD770C8F955040A54DD53DB2394C409BE5B2D139955040A54DD53DB2394C40
78140	19615	66.827326999999997	66.844044999999994	56.673937000000002	56.666359	Первомайская	0103000020E610000001000000050000004206F2ECF2B45040983270404B554C404206F2ECF2B450403D484F9143564C408CD651D504B650403D484F9143564C408CD651D504B65040983270404B554C404206F2ECF2B45040983270404B554C40
9794	17108	66.462862000000001	66.602316999999999	56.526243999999998	56.483055	Вокзальная	0103000020E61000000100000005000000EA23F0879F9D5040AB9509BFD43D4C40EA23F0879F9D5040ADDBA0F65B434C40CA349A5C8CA65040ADDBA0F65B434C40CA349A5C8CA65040AB9509BFD43D4C40EA23F0879F9D5040AB9509BFD43D4C40
77951	18942	66.738671999999994	66.758920000000003	56.359026	56.351858999999997	Новая	0103000020E61000000100000005000000239EEC6646AF5040D1E638B7092D4C40239EEC6646AF5040F4346090F42D4C40F111312592B05040F4346090F42D4C40F111312592B05040D1E638B7092D4C40239EEC6646AF5040D1E638B7092D4C40
78154	61276	66.564121	66.583650000000006	56.279451999999999	56.265892000000001	Октябрьская	0103000020E61000000100000005000000287FF78E1AA450404F22C2BF08224C40287FF78E1AA45040A1664815C5234C40DE9387855AA55040A1664815C5234C40DE9387855AA550404F22C2BF08224C40287FF78E1AA450404F22C2BF08224C40
42368	20589	66.420354000000003	66.444788000000003	56.525151999999999	56.514946999999999	Советская	0103000020E610000001000000050000008AAF7614E79A50402F1686C8E9414C408AAF7614E79A5040E9B6442E38434C40CF691668779C5040E9B6442E38434C40CF691668779C50402F1686C8E9414C408AAF7614E79A50402F1686C8E9414C40
42285	19339	67.024722999999994	67.060034999999999	56.638233999999997	56.619280000000003	Ленина	0103000020E61000000100000005000000601DC70F95C1504090882991444F4C40601DC70F95C15040FE98D6A6B1514C4062670A9DD7C35040FE98D6A6B1514C4062670A9DD7C3504090882991444F4C40601DC70F95C1504090882991444F4C40
42409	18437	66.646900000000002	66.665818999999999	56.410445000000003	56.395122999999998	Советская	0103000020E6100000010000000500000013F241CF66A95040DE72F56393324C4013F241CF66A9504043E7357689344C408C834BC79CAA504043E7357689344C408C834BC79CAA5040DE72F56393324C4013F241CF66A95040DE72F56393324C40
78133	16300	68.596396999999996	68.616258999999999	56.540480000000002	56.518706000000002	Дзержинского	0103000020E61000000100000005000000AE9B525E2B265140971E4DF564424C40AE9B525E2B2651403012DA722E454C4067B796C9702751403012DA722E454C4067B796C970275140971E4DF564424C40AE9B525E2B265140971E4DF564424C40
42535	16322	68.712971999999993	68.731306000000004	56.427453	56.413293000000003	п. Лепустина,	0103000020E61000000100000005000000ADBD4F55A12D51403755F7C8E6344C40ADBD4F55A12D5140DEC9A7C7B6364C409757AEB7CD2E5140DEC9A7C7B6364C409757AEB7CD2E51403755F7C8E6344C40ADBD4F55A12D51403755F7C8E6344C40
42341	17516	68.049063000000004	68.091866999999993	56.513407999999998	56.489108000000002	Пищика	0103000020E61000000100000005000000651C23D923035140221B48179B3E4C40651C23D9230351409CC0745AB7414C4039252026E10551409CC0745AB7414C4039252026E1055140221B48179B3E4C40651C23D923035140221B48179B3E4C40
77039	17396	68.290799000000007	68.308819	56.105877	56.095779999999998	Советская	0103000020E6100000010000000500000069AD68739C12514031CEDF84420C4C4069AD68739C1251400533A6608D0D4C408A58C4B0C31351400533A6608D0D4C408A58C4B0C313514031CEDF84420C4C4069AD68739C12514031CEDF84420C4C40
77034	17313	68.373947000000001	68.412780999999995	56.159654000000003	56.146678000000001	Строительная	0103000020E61000000100000005000000FDDB65BFEE17514077853E58C6124C40FDDB65BFEE1751407A56D28A6F144C4040DAFF006B1A51407A56D28A6F144C4040DAFF006B1A514077853E58C6124C40FDDB65BFEE17514077853E58C6124C40
77989	16922	68.134231999999997	68.158090999999999	56.677022000000001	56.667200000000001	Центральная	0103000020E61000000100000005000000E884D0419708514013F241CF66554C40E884D0419708514015562AA8A8564C40AFB2B6291E0A514015562AA8A8564C40AFB2B6291E0A514013F241CF66554C40E884D0419708514013F241CF66554C40
42464	17617	68.806881000000004	68.833929999999995	56.615490999999999	56.607733000000003	Школьная	0103000020E61000000100000005000000E2B034F0A333514099D9E731CA4D4C40E2B034F0A3335140BDFDB968C84E4C40CF49EF1B5F355140BDFDB968C84E4C40CF49EF1B5F35514099D9E731CA4D4C40E2B034F0A333514099D9E731CA4D4C40
77837	17012	68.064099999999996	68.074099000000004	56.648933999999997	56.633763000000002	Мира	0103000020E610000001000000050000001CEBE2361A0451401A355F251F514C401CEBE2361A04514098A1F14410534C40A56ABB09BE04514098A1F14410534C40A56ABB09BE0451401A355F251F514C401CEBE2361A0451401A355F251F514C40
42352	17298	68.473139000000003	68.504301999999996	56.374158000000001	56.347209999999997	Молодежная	0103000020E6100000010000000500000094DDCCE8471E51400D6C9560712C4C4094DDCCE8471E5140B5C4CA68E42F4C40AC53E57B46205140B5C4CA68E42F4C40AC53E57B462051400D6C9560712C4C4094DDCCE8471E51400D6C9560712C4C40
42330	17215	68.579886000000002	68.604329000000007	56.625737000000001	56.607926999999997	50 лет Октября	0103000020E61000000100000005000000215A2BDA1C2551407DAD4B8DD04D4C40215A2BDA1C255140D672672618504C4090C18A53AD265140D672672618504C4090C18A53AD2651407DAD4B8DD04D4C40215A2BDA1C2551407DAD4B8DD04D4C40
77917	17424	68.149754999999999	68.169724000000002	56.178994000000003	56.170079999999999	Мельникайте	0103000020E6100000010000000500000066DAFE959509514012DA722EC5154C4066DAFE959509514012178046E9164C402A560DC2DC0A514012178046E9164C402A560DC2DC0A514012DA722EC5154C4066DAFE959509514012DA722EC5154C40
42279	17208	67.975329000000002	68.002593000000005	56.438307999999999	56.421947000000003	Пролетарская	0103000020E61000000100000005000000C97553CA6BFE50409AD2FA5B02364C40C97553CA6BFE50409FC9FE791A384C40B58CD47B2A0051409FC9FE791A384C40B58CD47B2A0051409AD2FA5B02364C40C97553CA6BFE50409AD2FA5B02364C40
42353	17132	68.478061999999994	68.511210000000005	56.559831000000003	56.546320999999999	Ленина	0103000020E6100000010000000500000076DD5B91981E51401B0FB6D8ED454C4076DD5B91981E5140BC24CE8AA8474C40D8D825AAB7205140BC24CE8AA8474C40D8D825AAB72051401B0FB6D8ED454C4076DD5B91981E51401B0FB6D8ED454C40
77845	17027	68.450924000000001	68.483344000000002	56.215632999999997	56.210397	Советская	0103000020E61000000100000005000000D13E56F0DB1C51409816F549EE1A4C40D13E56F0DB1C51401C78B5DC991B4C40F12DAC1BEF1E51401C78B5DC991B4C40F12DAC1BEF1E51409816F549EE1A4C40D13E56F0DB1C51409816F549EE1A4C40
42538	16914	68.279641999999996	68.300869000000006	56.710431	56.699787000000001	Подоляка	0103000020E61000000100000005000000A2258FA7E51151403E95D39E92594C40A2258FA7E511514044882B67EF5A4C4056D80C704113514044882B67EF5A4C4056D80C70411351403E95D39E92594C40A2258FA7E51151403E95D39E92594C40
41965	55079	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	Садовая	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
42265	55079	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	Московский переулок	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
42096	55079	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	Московская	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
42374	55079	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	Комсомольская	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
41964	55079	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	Карла Маркса	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
42360	55079	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	К. Маркса	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
42054	16408	68.323560999999998	68.406996000000007	56.413502999999999	56.379356000000001	Молодежная	0103000020E61000000100000005000000B5503239B51451404CC5C6BC8E304C40B5503239B514514021E692AAED344C409566F3380C1A514021E692AAED344C409566F3380C1A51404CC5C6BC8E304C40B5503239B51451404CC5C6BC8E304C40
42521	16218	68.589848000000003	68.614525	56.474260999999998	56.463476	Московская	0103000020E610000001000000050000001B67D311C02551408E3D7B2E533B4C401B67D311C025514056629E95B43C4C40C364AA605427514056629E95B43C4C40C364AA60542751408E3D7B2E533B4C401B67D311C02551408E3D7B2E533B4C40
42255	16200	68.534161999999995	68.563374999999994	56.385596	56.366923999999997	Кормильцева 	0103000020E610000001000000050000000531D0B52F2251400A0F9A5DF72E4C400531D0B52F225140F5BBB0355B314C40931804560E245140F5BBB0355B314C40931804560E2451400A0F9A5DF72E4C400531D0B52F2251400A0F9A5DF72E4C40
42325	16113	68.265646000000004	68.298426000000006	56.551388000000003	56.521889000000002	60 лет Октября	0103000020E610000001000000050000000C9414580011514032923D42CD424C400C9414580011514014B4C9E193464C40AC915D691913514014B4C9E193464C40AC915D691913514032923D42CD424C400C9414580011514032923D42CD424C40
42439	16108	68.502540999999994	68.529579999999996	56.697414999999999	56.686574999999998	Пролетарская	0103000020E610000001000000050000008BF9B9A12920514027A089B0E1574C408BF9B9A129205140B35E0CE544594C40672783A3E4215140B35E0CE544594C40672783A3E421514027A089B0E1574C408BF9B9A12920514027A089B0E1574C40
77944	15630	70.392775999999998	70.411326000000003	57.046612000000003	57.039810000000003	Школьная	0103000020E61000000100000005000000D6A9F23D23995140E2067C7E18854C40D6A9F23D23995140F3CCCB61F7854C40A67F492A539A5140F3CCCB61F7854C40A67F492A539A5140E2067C7E18854C40D6A9F23D23995140E2067C7E18854C40
42408	15937	70.567642000000006	70.585564000000005	56.705444999999997	56.692210000000003	Фрунзенская	0103000020E6100000010000000500000082751C3F54A451406AFB57569A584C4082751C3F54A45140381092054C5A4C40C26D6DE179A55140381092054C5A4C40C26D6DE179A551406AFB57569A584C4082751C3F54A451406AFB57569A584C40
42438	14793	70.555173999999994	70.574720999999997	56.781094000000003	56.770198999999998	Кузнецова	0103000020E61000000100000005000000BA6587F887A35140B9347EE195624C40BA6587F887A35140098D60E3FA634C40C3D4963AC8A45140098D60E3FA634C40C3D4963AC8A45140B9347EE195624C40BA6587F887A35140B9347EE195624C40
77990	15042	70.719061999999994	70.732151000000002	56.803342000000001	56.798053000000003	Садовая	0103000020E61000000100000005000000F7729F1C05AE5140C3BCC79926664C40F7729F1C05AE51406AC020E9D3664C40F52EDE8FDBAE51406AC020E9D3664C40F52EDE8FDBAE5140C3BCC79926664C40F7729F1C05AE5140C3BCC79926664C40
77929	15833	70.742688000000001	70.753315000000001	57.082267999999999	57.075723000000004	Солнечная	0103000020E610000001000000050000006DC83F3388AF51400B47904AB1894C406DC83F3388AF5140F0C000C2878A4C4085251E5036B05140F0C000C2878A4C4085251E5036B051400B47904AB1894C406DC83F3388AF51400B47904AB1894C40
42512	15729	70.713177999999999	70.738016999999999	56.883001999999998	56.866799	Молодежная	0103000020E61000000100000005000000828E56B5A4AD51404E9A0645F36E4C40828E56B5A4AD5140BB26A43506714C4017B9A7AB3BAF5140BB26A43506714C4017B9A7AB3BAF51404E9A0645F36E4C40828E56B5A4AD51404E9A0645F36E4C40
42418	15623	70.333847000000006	70.361721000000003	57.035128	57.025170000000003	Советская	0103000020E6100000010000000500000089B7CEBF5D955140906B43C538834C4089B7CEBF5D955140429605137F844C40B151D66F26975140429605137F844C40B151D66F26975140906B43C538834C4089B7CEBF5D955140906B43C538834C40
42574	15463	70.583848000000003	70.597645999999997	56.924491000000003	56.913888	Школьная	0103000020E61000000100000005000000717500C45DA551407A1A3048FA744C40717500C45DA55140223999B855764C40742502D53FA65140223999B855764C40742502D53FA651407A1A3048FA744C40717500C45DA551407A1A3048FA744C40
77055	15344	71.246086000000005	71.275389000000004	56.809147000000003	56.793292000000001	Советская	0103000020E6100000010000000500000039807EDFBFCF5140D7169E978A654C4039807EDFBFCF51400954FF2092674C40672B2FF99FD151400954FF2092674C40672B2FF99FD15140D7169E978A654C4039807EDFBFCF5140D7169E978A654C40
77902	15542	70.589965000000007	70.602397999999994	56.984082999999998	56.967624999999998	Зелёная	0103000020E6100000010000000500000038328FFCC1A5514060E5D022DB7B4C4038328FFCC1A5514058C6866EF67D4C40404B57B08DA6514058C6866EF67D4C40404B57B08DA6514060E5D022DB7B4C4038328FFCC1A5514060E5D022DB7B4C40
42407	15252	70.428745000000006	70.449972000000002	56.596446	56.588178999999997	Мира	0103000020E61000000100000005000000B554DE8E709B5140D4981073494B4C40B554DE8E709B51403EEAAF57584C4C4068075C57CC9C51403EEAAF57584C4C4068075C57CC9C5140D4981073494B4C40B554DE8E709B5140D4981073494B4C40
77840	15555	70.665773999999999	70.678134999999997	56.997774	56.991855999999999	Пушкина	0103000020E61000000100000005000000BC218D0A9CAA5140B22B2D23F57E4C40BC218D0A9CAA51404966F50EB77F4C4078D1579066AB51404966F50EB77F4C4078D1579066AB5140B22B2D23F57E4C40BC218D0A9CAA5140B22B2D23F57E4C40
78130	16000	70.378079999999997	70.392920000000004	56.691547999999997	56.682175000000001	Радищева	0103000020E6100000010000000500000063D17476329851400C93A98251574C4063D17476329851409ECE15A584584C40707CED99259951409ECE15A584584C40707CED99259951400C93A98251574C4063D17476329851400C93A98251574C40
42254	15141	70.934757000000005	70.954977999999997	56.819823999999997	56.804968000000002	8 Марта	0103000020E61000000100000005000000412D060FD3BB5140CC29013109674C40412D060FD3BB5140EA3C2AFEEF684C4091990B5C1EBD5140EA3C2AFEEF684C4091990B5C1EBD5140CC29013109674C40412D060FD3BB5140CC29013109674C40
77947	15331	70.380450999999994	70.396243999999996	56.588611	56.582608	Школьная	0103000020E61000000100000005000000C0AE264F59985140A93121E6924A4C40C0AE264F599851406E88F19A574B4C401E4FCB0F5C9951406E88F19A574B4C401E4FCB0F5C995140A93121E6924A4C40C0AE264F59985140A93121E6924A4C40
42351	15060	70.673553999999996	70.704410999999993	57.081994000000002	57.064898999999997	Советская	0103000020E61000000100000005000000C2853C821BAB51408445459C4E884C40C2853C821BAB5140EF3B86C77E8A4C4054FCDF1115AD5140EF3B86C77E8A4C4054FCDF1115AD51408445459C4E884C40C2853C821BAB51408445459C4E884C40
42440	14881	70.822333	70.848213000000001	56.831530999999998	56.817675999999999	60 лет СССР	0103000020E61000000100000005000000FB5A971AA1B45140AF5C6F9BA9684C40FB5A971AA1B451401A4E999B6F6A4C40B1C22D1F49B651401A4E999B6F6A4C40B1C22D1F49B65140AF5C6F9BA9684C40FB5A971AA1B45140AF5C6F9BA9684C40
42486	14481	70.734144999999998	70.752398999999997	56.625484999999998	56.616411999999997	Центральная	0103000020E6100000010000000500000067614F3BFCAE5140546EA296E64E4C4067614F3BFCAE5140BC9179E40F504C40C2A2224E27B05140BC9179E40F504C40C2A2224E27B05140546EA296E64E4C4067614F3BFCAE5140546EA296E64E4C40
42533	14860	70.926196000000004	70.950485999999998	57.262813999999999	57.243251000000001	Школьная	0103000020E61000000100000005000000E86B96CB46BB514012DC48D9229F4C40E86B96CB46BB514029779FE3A3A14C4093533BC3D4BC514029779FE3A3A14C4093533BC3D4BC514012DC48D9229F4C40E86B96CB46BB514012DC48D9229F4C40
77751	16022	70.572754000000003	70.584540000000004	56.732562999999999	56.721012000000002	Ишимская	0103000020E61000000100000005000000CEA96400A8A451400403081F4A5C4C40CEA96400A8A451403CA1D79FC45D4C400CCD751A69A551403CA1D79FC45D4C400CCD751A69A551400403081F4A5C4C40CEA96400A8A451400403081F4A5C4C40
77838	15808	70.658389999999997	70.674020999999996	56.911824000000003	56.903052000000002	Озёрная	0103000020E61000000100000005000000DC80CF0F23AA5140304B3B3597734C40DC80CF0F23AA51409DDA19A6B6744C404DF4F92823AB51409DDA19A6B6744C404DF4F92823AB5140304B3B3597734C40DC80CF0F23AA5140304B3B3597734C40
42045	14583	70.577093000000005	70.629212999999993	56.832476999999997	56.794963000000003	Солнечная	0103000020E6100000010000000500000009707A17EFA45140D943FB58C1654C4009707A17EFA451400AD6389B8E6A4C40F44D9A0645A851400AD6389B8E6A4C40F44D9A0645A85140D943FB58C1654C4009707A17EFA45140D943FB58C1654C40
41903	14583	70.577093000000005	70.629212999999993	56.832476999999997	56.794963000000003	Ленина	0103000020E6100000010000000500000009707A17EFA45140D943FB58C1654C4009707A17EFA451400AD6389B8E6A4C40F44D9A0645A851400AD6389B8E6A4C40F44D9A0645A85140D943FB58C1654C4009707A17EFA45140D943FB58C1654C40
42042	14583	70.577093000000005	70.629212999999993	56.832476999999997	56.794963000000003	Кузнецова	0103000020E6100000010000000500000009707A17EFA45140D943FB58C1654C4009707A17EFA451400AD6389B8E6A4C40F44D9A0645A851400AD6389B8E6A4C40F44D9A0645A85140D943FB58C1654C4009707A17EFA45140D943FB58C1654C40
41911	14583	70.577093000000005	70.629212999999993	56.832476999999997	56.794963000000003	 переулок Заводской	0103000020E6100000010000000500000009707A17EFA45140D943FB58C1654C4009707A17EFA451400AD6389B8E6A4C40F44D9A0645A851400AD6389B8E6A4C40F44D9A0645A85140D943FB58C1654C4009707A17EFA45140D943FB58C1654C40
78126	15240	71.139617999999999	71.173187999999996	56.812665000000003	56.807679	Строителей	0103000020E61000000100000005000000B5FB5580EFC851403F55850662674C40B5FB5580EFC851404BCD1E6805684C40D1031F8315CB51404BCD1E6805684C40D1031F8315CB51403F55850662674C40B5FB5580EFC851403F55850662674C40
78018	14955	70.713645	70.730722	56.848030000000001	56.841231000000001	Молодёжная	0103000020E610000001000000050000000DFD135CACAD5140D1B01875AD6B4C400DFD135CACAD514071033E3F8C6C4C40EF1D3526C4AE514071033E3F8C6C4C40EF1D3526C4AE5140D1B01875AD6B4C400DFD135CACAD5140D1B01875AD6B4C40
42514	14561	70.24512	70.283028999999999	56.807850999999999	56.800896999999999	Школьная	0103000020E610000001000000050000001DE6CB0BB08F5140753BFBCA83664C401DE6CB0BB08F51403C855CA967674C4074B4AA251D9251403C855CA967674C4074B4AA251D925140753BFBCA83664C401DE6CB0BB08F5140753BFBCA83664C40
42513	14485	70.441833000000003	70.459287000000003	56.820104000000001	56.812547000000002	Новая	0103000020E61000000100000005000000CA52EBFD469C514041BB438A01684C40CA52EBFD469C5140CEA8F92AF9684C40971E4DF5649D5140CEA8F92AF9684C40971E4DF5649D514041BB438A01684C40CA52EBFD469C514041BB438A01684C40
42322	14386	70.629698000000005	70.653655999999998	56.665202000000001	56.650556999999999	Ленина	0103000020E61000000100000005000000D316D7F84CA851408997A77345534C40D316D7F84CA85140ED9DD15625554C4063B5F97FD5A95140ED9DD15625554C4063B5F97FD5A951408997A77345534C40D316D7F84CA851408997A77345534C40
78015	15166	71.066835999999995	71.088063000000005	56.797038000000001	56.786833000000001	переулок Строителей	0103000020E61000000100000005000000828C800A47C45140F03499F1B6644C40828C800A47C45140AAD5575705664C40363FFED2A2C55140AAD5575705664C40363FFED2A2C55140F03499F1B6644C40828C800A47C45140F03499F1B6644C40
77836	15442	71.326403999999997	71.359928999999994	56.806125999999999	56.797960000000003	Озерная	0103000020E6100000010000000500000026529ACDE3D4514012C2A38D23664C4026529ACDE3D45140473A03232F674C4072F8A41309D75140473A03232F674C4072F8A41309D7514012C2A38D23664C4026529ACDE3D4514012C2A38D23664C40
42406	13082	68.087554999999995	68.110894000000002	57.388216	57.378430999999999	переул. Дорожный	0103000020E610000001000000050000007B6649809A0551407365506D70B04C407B6649809A05514058E4D70FB1B14C40A6D425E31807514058E4D70FB1B14C40A6D425E3180751407365506D70B04C407B6649809A0551407365506D70B04C40
42530	12968	68.69408	68.714472000000001	57.518892999999998	57.499127999999999	Зеленая	0103000020E61000000100000005000000B13385CE6B2C51404A42226DE3BF4C40B13385CE6B2C5140C98FF8156BC24C40187AC4E8B92D5140C98FF8156BC24C40187AC4E8B92D51404A42226DE3BF4C40B13385CE6B2C51404A42226DE3BF4C40
42510	13063	68.232984000000002	68.273938000000001	57.452264	57.442428	Совхозная	0103000020E61000000100000005000000711FB935E90E5140D76A0F7BA1B84C40711FB935E90E51403E9468C9E3B94C406DC83F33881151403E9468C9E3B94C406DC83F3388115140D76A0F7BA1B84C40711FB935E90E5140D76A0F7BA1B84C40
42350	12636	69.14958	69.185772999999998	57.664707	57.636494999999996	Библиотечная	0103000020E61000000100000005000000AF08FEB792495140A4880CAB78D14C40AF08FEB7924951400D36751E15D54C40B5DE6FB4E34B51400D36751E15D54C40B5DE6FB4E34B5140A4880CAB78D14C40AF08FEB792495140A4880CAB78D14C40
77935	14101	69.304961000000006	69.323215000000005	58.049840000000003	58.043039	Мира	0103000020E610000001000000050000008D63247B84535140EDB94C4D82054D408D63247B845351402E04392861064D40E8A4F78DAF5451402E04392861064D40E8A4F78DAF545140EDB94C4D82054D408D63247B84535140EDB94C4D82054D40
42509	12992	68.387422000000001	68.434466999999998	57.487958999999996	57.475166999999999	Ленина	0103000020E610000001000000050000000FF0A485CB185140B891B245D2BC4C400FF0A485CB185140F964C57075BE4C403D0CAD4ECE1B5140F964C57075BE4C403D0CAD4ECE1B5140B891B245D2BC4C400FF0A485CB185140B891B245D2BC4C40
42336	13346	69.750157000000002	69.782595999999998	57.658920000000002	57.641288000000003	Береговая	0103000020E6100000010000000500000064778192027051409CA8A5B915D24C4064778192027051401557957D57D44C40BF7E880D167251401557957D57D44C40BF7E880D167251409CA8A5B915D24C4064778192027051409CA8A5B915D24C40
42511	14003	69.549464999999998	69.570988	58.007961000000002	57.987127000000001	Новая	0103000020E61000000100000005000000FC523F6F2A635140D2FF722D5AFE4C40FC523F6F2A6351405D52B5DD04014D40249A40118B6451405D52B5DD04014D40249A40118B645140D2FF722D5AFE4C40FC523F6F2A635140D2FF722D5AFE4C40
77923	13254	69.578515999999993	69.595574999999997	57.811521999999997	57.803139999999999	Комсомольская	0103000020E610000001000000050000009D0DF96706655140020EA14ACDE64C409D0DF9670665514004FEF0F3DFE74C402CD49AE61D66514004FEF0F3DFE74C402CD49AE61D665140020EA14ACDE64C409D0DF96706655140020EA14ACDE64C40
77825	12434	68.923554999999993	68.939364999999995	57.950237000000001	57.946038999999999	Молодежная	0103000020E61000000100000005000000AA436E861B3B5140CADE52CE17F94C40AA436E861B3B51407E39B35DA1F94C407380608E1E3C51407E39B35DA1F94C407380608E1E3C5140CADE52CE17F94C40AA436E861B3B5140CADE52CE17F94C40
78003	13713	69.744399000000001	69.757649000000001	57.958747000000002	57.951946999999997	Ренченская	0103000020E61000000100000005000000350BB43BA46F51403D433866D9F94C40350BB43BA46F5140AE11C138B8FA4C4037363B527D705140AE11C138B8FA4C4037363B527D7051403D433866D9F94C40350BB43BA46F51403D433866D9F94C40
42435	12839	68.840864999999994	68.865702999999996	57.743417999999998	57.732508000000003	Школьная	0103000020E6100000010000000500000077D66EBBD0355140790778D2C2DD4C4077D66EBBD0355140FDA02E5228DF4C4024438EAD67375140FDA02E5228DF4C4024438EAD67375140790778D2C2DD4C4077D66EBBD0355140790778D2C2DD4C40
42516	12713	69.043929000000006	69.072970999999995	57.410276000000003	57.399900000000002	Советская	0103000020E61000000100000005000000259694BBCF425140D0D556EC2FB34C40259694BBCF425140B72A89EC83B44C409CA38E8EAB445140B72A89EC83B44C409CA38E8EAB445140D0D556EC2FB34C40259694BBCF425140D0D556EC2FB34C40
78004	10223	69.130651999999998	69.141136000000003	57.225212999999997	57.214120999999999	Береговая	0103000020E610000001000000050000000CCA349A5C48514083312251689B4C400CCA349A5C48514028D192C7D39C4C4073124A5F0849514028D192C7D39C4C4073124A5F0849514083312251689B4C400CCA349A5C48514083312251689B4C40
42436	13365	69.961765	69.976271999999994	57.604171999999998	57.597130999999997	Озерная	0103000020E61000000100000005000000FF5BC98E8D7D5140C136E2C96ECC4C40FF5BC98E8D7D51405794128255CD4C4008008E3D7B7E51405794128255CD4C4008008E3D7B7E5140C136E2C96ECC4C40FF5BC98E8D7D5140C136E2C96ECC4C40
78029	12906	68.691582999999994	68.700969999999998	57.695580999999997	57.687137999999997	Школьная	0103000020E610000001000000050000000DDE57E5422C51405FEB5223F4D74C400DDE57E5422C5140075C57CC08D94C40895E46B1DC2C5140075C57CC08D94C40895E46B1DC2C51405FEB5223F4D74C400DDE57E5422C51405FEB5223F4D74C40
42534	13914	69.782955000000001	69.807406999999998	57.999000000000002	57.988939999999999	Школьная	0103000020E6100000010000000500000057CF49EF1B72514066DAFE9595FE4C4057CF49EF1B7251401D5A643BDFFF4C40EFE3688EAC7351401D5A643BDFFF4C40EFE3688EAC73514066DAFE9595FE4C4057CF49EF1B72514066DAFE9595FE4C40
77916	12282	68.749919000000006	68.76634	57.984551000000003	57.976730000000003	Озерная	0103000020E610000001000000050000008AE942ACFE2F5140D482177D05FD4C408AE942ACFE2F51403F1F65C405FE4C407767EDB60B3151403F1F65C405FE4C407767EDB60B315140D482177D05FD4C408AE942ACFE2F5140D482177D05FD4C40
77871	12346	68.779824000000005	68.800970000000007	57.961741000000004	57.952114000000002	Школьная	0103000020E61000000100000005000000B328ECA2E831514029081EDFDEF94C40B328ECA2E8315140761C3F541AFB4C40F0C4AC1743335140761C3F541AFB4C40F0C4AC174333514029081EDFDEF94C40B328ECA2E831514029081EDFDEF94C40
78091	14297	68.912837999999994	68.933740999999998	58.045153999999997	58.033285999999997	Школьная	0103000020E61000000100000005000000F22213F06B3A514013B534B742044D40F22213F06B3A51404CA4349BC7054D40CC7B9C69C23B51404CA4349BC7054D40CC7B9C69C23B514013B534B742044D40F22213F06B3A514013B534B742044D40
78028	13625	69.136222000000004	69.161553999999995	58.022444	58.011313000000001	Школьная	0103000020E61000000100000005000000BABF7ADCB7485140848252B472014D40BABF7ADCB7485140E7FEEA71DF024D406EA296E6564A5140E7FEEA71DF024D406EA296E6564A5140848252B472014D40BABF7ADCB7485140848252B472014D40
42532	13275	69.635459999999995	69.662059999999997	57.797106999999997	57.785814000000002	Школьная	0103000020E61000000100000005000000A27A6B60AB685140965E9B8D95E44C40A27A6B60AB685140D234289A07E64C4058FFE7305F6A5140D234289A07E64C4058FFE7305F6A5140965E9B8D95E44C40A27A6B60AB685140965E9B8D95E44C40
77924	14024	69.469874000000004	69.501540000000006	58.046883000000001	58.035707000000002	Кедровая	0103000020E6100000010000000500000068CF656A125E5140809E060C92044D4068CF656A125E514083DE1B4300064D40B2683A3B1960514083DE1B4300064D40B2683A3B19605140809E060C92044D4068CF656A125E5140809E060C92044D40
77833	14109	69.185278999999994	69.206738999999999	58.065196999999998	58.058678999999998	Центральная	0103000020E61000000100000005000000AD68739CDB4B514022FB20CB82074D40AD68739CDB4B51400E66136058084D40B2F336363B4D51400E66136058084D40B2F336363B4D514022FB20CB82074D40AD68739CDB4B514022FB20CB82074D40
76997	13151	69.117554999999996	69.144675000000007	57.888277000000002	57.871772	Школьная	0103000020E61000000100000005000000CD1E680586475140C5C8923996EF4C40CD1E680586475140FE648C0FB3F14C402063EE5A42495140FE648C0FB3F14C402063EE5A42495140C5C8923996EF4C40CD1E680586475140C5C8923996EF4C40
41913	13639	69.404764	69.438505000000006	57.963703000000002	57.942025999999998	Запольная	0103000020E6100000010000000500000048A643A7E7595140A8FDD64E94F84C4048A643A7E75951404F07B29E5AFB4C407B884677105C51404F07B29E5AFB4C407B884677105C5140A8FDD64E94F84C4048A643A7E7595140A8FDD64E94F84C40
77870	13732	69.926353000000006	69.940708000000001	57.996791999999999	57.985185000000001	Центральная	0103000020E610000001000000050000004CE3175E497B514040C1C58A1AFE4C404CE3175E497B51400C7558E196FF4C407AC5538F347C51400C7558E196FF4C407AC5538F347C514040C1C58A1AFE4C404CE3175E497B514040C1C58A1AFE4C40
77938	14204	68.954033999999993	68.975297999999995	58.015155999999998	58.006307	Центральная	0103000020E6100000010000000500000069519FE40E3D5140315EF3AACE004D4069519FE40E3D5140492BBEA1F0014D40AB764D486B3E5140492BBEA1F0014D40AB764D486B3E5140315EF3AACE004D4069519FE40E3D5140315EF3AACE004D40
78192	12347	68.982915000000006	69.034452000000002	57.955199	57.914830000000002	Школьная	0103000020E61000000100000005000000DDEF5014E83E514029B3412619F54C40DDEF5014E83E51400116F9F543FA4C4009522976344251400116F9F543FA4C40095229763442514029B3412619F54C40DDEF5014E83E514029B3412619F54C40
42038	12347	68.982915000000006	69.034452000000002	57.955199	57.914830000000002	Мира	0103000020E61000000100000005000000DDEF5014E83E514029B3412619F54C40DDEF5014E83E51400116F9F543FA4C4009522976344251400116F9F543FA4C40095229763442514029B3412619F54C40DDEF5014E83E514029B3412619F54C40
42039	12347	68.982915000000006	69.034452000000002	57.955199	57.914830000000002	Дорожный переулок	0103000020E61000000100000005000000DDEF5014E83E514029B3412619F54C40DDEF5014E83E51400116F9F543FA4C4009522976344251400116F9F543FA4C40095229763442514029B3412619F54C40DDEF5014E83E514029B3412619F54C40
41909	12347	68.982915000000006	69.034452000000002	57.955199	57.914830000000002	 Ленина	0103000020E61000000100000005000000DDEF5014E83E514029B3412619F54C40DDEF5014E83E51400116F9F543FA4C4009522976344251400116F9F543FA4C40095229763442514029B3412619F54C40DDEF5014E83E514029B3412619F54C40
78026	12798	68.972251999999997	68.986562000000006	57.756371000000001	57.747385999999999	Октябрьская	0103000020E610000001000000050000001EDE7360393E51407FBE2D58AADF4C401EDE7360393E51404852D2C3D0E04C407D5EF1D4233F51404852D2C3D0E04C407D5EF1D4233F51407FBE2D58AADF4C401EDE7360393E51407FBE2D58AADF4C40
42437	13826	70.228914000000003	70.255756000000005	57.962777000000003	57.941009000000001	Первомайская	0103000020E610000001000000050000002EE6E786A68E5140EF1EA0FB72F84C402EE6E786A68E5140A62BD8463CFB4C405FF0694E5E905140A62BD8463CFB4C405FF0694E5E905140EF1EA0FB72F84C402EE6E786A68E5140EF1EA0FB72F84C40
42539	14194	69.082907000000006	69.109757000000002	58.048034999999999	58.039613000000003	переулок Школьный	0103000020E61000000100000005000000026729594E4551408CBFED0912054D40026729594E4551401C08C90226064D4074603942064751401C08C90226064D4074603942064751408CBFED0912054D40026729594E4551408CBFED0912054D40
77868	11373	68.247815000000003	68.262951000000001	55.950271999999998	55.939287	Мира	0103000020E61000000100000005000000541D7233DC0F51406B47718E3AF84B40541D7233DC0F5140FA264D83A2F94B40D55C6E30D4105140FA264D83A2F94B40D55C6E30D41051406B47718E3AF84B40541D7233DC0F51406B47718E3AF84B40
42494	12238	68.214146	68.237682000000007	55.694626999999997	55.683228999999997	Ленина	0103000020E610000001000000050000006EA46C91B40D5140E256410C74D74B406EA46C91B40D514094F59B89E9D84B404436902E360F514094F59B89E9D84B404436902E360F5140E256410C74D74B406EA46C91B40D5140E256410C74D74B40
42498	11280	68.279129999999995	68.303518999999994	55.890300000000003	55.873869999999997	площадь Волкова	0103000020E6100000010000000500000047551344DD1151404E7ADFF8DAEF4B4047551344DD1151407DD0B359F5F14B40BCADF4DA6C1351407DD0B359F5F14B40BCADF4DA6C1351404E7ADFF8DAEF4B4047551344DD1151404E7ADFF8DAEF4B40
42251	11579	68.671774999999997	68.716528999999994	55.870601999999998	55.857335999999997	Ленина	0103000020E610000001000000050000004ED1915CFE2A51407BD7A02FBDED4B404ED1915CFE2A514085EAE6E26FEF4B40AD68739CDB2D514085EAE6E26FEF4B40AD68739CDB2D51407BD7A02FBDED4B404ED1915CFE2A51407BD7A02FBDED4B40
77922	11657	68.808920999999998	68.821478999999997	55.880595999999997	55.876480999999998	Марикова	0103000020E610000001000000050000000C03965CC53351405E48878730F04B400C03965CC5335140847EA65EB7F04B4073D6A71C93345140847EA65EB7F04B4073D6A71C933451405E48878730F04B400C03965CC53351405E48878730F04B40
42327	11678	68.676320000000004	68.709925999999996	55.722259000000001	55.71266	Ленина	0103000020E610000001000000050000005E68AED3482B51406C95607138DB4B405E68AED3482B5140EF1EA0FB72DC4B402025766D6F2D5140EF1EA0FB72DC4B402025766D6F2D51406C95607138DB4B405E68AED3482B51406C95607138DB4B40
42507	11765	68.835475000000002	68.851168000000001	55.721508	55.712983999999999	Береговая	0103000020E610000001000000050000000A68226C783551401F49490F43DB4B400A68226C78355140B4E6C75F5ADC4B40B6D9588979365140B4E6C75F5ADC4B40B6D95889793651401F49490F43DB4B400A68226C783551401F49490F43DB4B40
42502	11489	68.563860000000005	68.589408000000006	56.055086000000003	56.047665000000002	Ленина	0103000020E6100000010000000500000072E1404816245140F91400E319064C4072E1404816245140D63BDC0E0D074C400D0055DCB8255140D63BDC0E0D074C400D0055DCB8255140F91400E319064C4072E1404816245140F91400E319064C40
77773	11466	68.247366	68.253204999999994	56.026784999999997	56.014145999999997	Чехова	0103000020E610000001000000050000001C0934D8D40F514042AF3F89CF014C401C0934D8D40F5140FD82DDB06D034C40C18BBE8234105140FD82DDB06D034C40C18BBE823410514042AF3F89CF014C401C0934D8D40F514042AF3F89CF014C40
42500	11191	68.167128000000005	68.179659999999998	55.895857999999997	55.883716999999997	Центральная	0103000020E61000000100000005000000BD8FA339B20A5140A9F57EA31DF14B40BD8FA339B20A514013EE9579ABF24B408F19A88C7F0B514013EE9579ABF24B408F19A88C7F0B5140A9F57EA31DF14B40BD8FA339B20A5140A9F57EA31DF14B40
77848	11843	68.672456999999994	68.687270999999996	55.785321000000003	55.780774999999998	Центральная	0103000020E61000000100000005000000D7BD1589092B51406744696FF0E34B40D7BD1589092B514057EE056685E44B404F1F813FFC2B514057EE056685E44B404F1F813FFC2B51406744696FF0E34B40D7BD1589092B51406744696FF0E34B40
42529	11287	68.220174	68.253141999999997	55.961319000000003	55.953301000000003	Алексеева	0103000020E610000001000000050000007D5BB054170E51403F1F65C405FA4B407D5BB054170E5140000341800CFB4B409ECF807A33105140000341800CFB4B409ECF807A331051403F1F65C405FA4B407D5BB054170E51403F1F65C405FA4B40
42504	11942	68.597807000000003	68.623283999999998	55.483204000000001	55.474618	Новая	0103000020E6100000010000000500000079944A7842265140E50B5A48C0BC4B4079944A7842265140F0A5F0A0D9BD4B40AF0793E2E3275140F0A5F0A0D9BD4B40AF0793E2E3275140E50B5A48C0BC4B4079944A7842265140E50B5A48C0BC4B40
78217	10774	68.233693000000002	68.259223000000006	55.795864000000002	55.791051000000003	Школьная	0103000020E6100000010000000500000077137CD3F40E5140EB3BBF2841E54B4077137CD3F40E514029081EDFDEE54B40BFD7101C9710514029081EDFDEE54B40BFD7101C97105140EB3BBF2841E54B4077137CD3F40E5140EB3BBF2841E54B40
42434	12142	68.223291000000003	68.233873000000003	55.647385999999997	55.636473000000002	Центральная	0103000020E610000001000000050000006F9F55664A0E5140BDE47FF277D14B406F9F55664A0E5140B2F1608BDDD24B40B79A75C6F70E5140B2F1608BDDD24B40B79A75C6F70E5140BDE47FF277D14B406F9F55664A0E5140BDE47FF277D14B40
77769	11398	68.244410000000002	68.270668000000001	55.978997	55.969925000000003	Победы	0103000020E610000001000000050000002F34D769A40F514052499D8026FC4B402F34D769A40F5140E9F010C64FFD4B40B804E09F52115140E9F010C64FFD4B40B804E09F5211514052499D8026FC4B402F34D769A40F514052499D8026FC4B40
42413	10823	68.286980999999997	68.335311000000004	55.819960000000002	55.788555000000002	Чкалова	0103000020E61000000100000005000000B2648EE55D125140740CC85EEFE44B40B2648EE55D1251409B030473F4E84B404DBF44BC751551409B030473F4E84B404DBF44BC75155140740CC85EEFE44B40B2648EE55D125140740CC85EEFE44B40
42316	10823	68.286980999999997	68.335311000000004	55.819960000000002	55.788555000000002	Молодежная	0103000020E61000000100000005000000B2648EE55D125140740CC85EEFE44B40B2648EE55D1251409B030473F4E84B404DBF44BC751551409B030473F4E84B404DBF44BC75155140740CC85EEFE44B40B2648EE55D125140740CC85EEFE44B40
42405	10823	68.286980999999997	68.335311000000004	55.819960000000002	55.788555000000002	Кирова	0103000020E61000000100000005000000B2648EE55D125140740CC85EEFE44B40B2648EE55D1251409B030473F4E84B404DBF44BC751551409B030473F4E84B404DBF44BC75155140740CC85EEFE44B40B2648EE55D125140740CC85EEFE44B40
42496	10823	68.286980999999997	68.335311000000004	55.819960000000002	55.788555000000002	Гнаровской	0103000020E61000000100000005000000B2648EE55D125140740CC85EEFE44B40B2648EE55D1251409B030473F4E84B404DBF44BC751551409B030473F4E84B404DBF44BC75155140740CC85EEFE44B40B2648EE55D125140740CC85EEFE44B40
42319	10823	68.286980999999997	68.335311000000004	55.819960000000002	55.788555000000002	Герцена	0103000020E61000000100000005000000B2648EE55D125140740CC85EEFE44B40B2648EE55D1251409B030473F4E84B404DBF44BC751551409B030473F4E84B404DBF44BC75155140740CC85EEFE44B40B2648EE55D125140740CC85EEFE44B40
42404	10823	68.286980999999997	68.335311000000004	55.819960000000002	55.788555000000002	Аф. Калинина	0103000020E61000000100000005000000B2648EE55D125140740CC85EEFE44B40B2648EE55D1251409B030473F4E84B404DBF44BC751551409B030473F4E84B404DBF44BC75155140740CC85EEFE44B40B2648EE55D125140740CC85EEFE44B40
42278	10738	68.609889999999993	68.630093000000002	56.776975999999998	56.754204000000001	Молчанова	0103000020E61000000100000005000000130A1170082751409641B5C189604C40130A11700827514071E316F373634C40111C97715328514071E316F373634C40111C9771532851409641B5C189604C40130A1170082751409641B5C189604C40
78201	61283	69.349660999999998	69.365589	56.968798	56.961649000000001	Центральная	0103000020E61000000100000005000000F2EB87D860565140959D7E50177B4C40F2EB87D8605651401137A792017C4C40C0B167CF655751401137A792017C4C40C0B167CF65575140959D7E50177B4C40F2EB87D860565140959D7E50177B4C40
42441	10628	68.835815999999994	68.861553000000001	56.986516000000002	56.972340000000003	Советская	0103000020E610000001000000050000004E5E64027E355140DC4B1AA3757C4C404E5E64027E355140897D0228467E4C4053B131AF23375140897D0228467E4C4053B131AF23375140DC4B1AA3757C4C404E5E64027E355140DC4B1AA3757C4C40
77936	9702	68.652298999999999	68.685779999999994	56.792661000000003	56.783278000000003	Школьная	0103000020E61000000100000005000000AA0D4E44BF29514091D6187442644C40AA0D4E44BF29514047E867EA75654C400E10CCD1E32B514047E867EA75654C400E10CCD1E32B514091D6187442644C40AA0D4E44BF29514091D6187442644C40
42432	10472	68.715298000000004	68.741331000000002	56.939013000000003	56.928145000000001	Береговая	0103000020E610000001000000050000003B394371C72D514014799274CD764C403B394371C72D51406AC2F69331784C40B42094F7712F51406AC2F69331784C40B42094F7712F514014799274CD764C403B394371C72D514014799274CD764C40
42403	10009	69.112937000000002	69.127840000000006	56.866715999999997	56.854531999999999	Одина	0103000020E6100000010000000500000089601C5C3A47514057B1F84D616D4C4089601C5C3A475140C075C58CF06E4C40B9C7D2872E485140C075C58CF06E4C40B9C7D2872E48514057B1F84D616D4C4089601C5C3A47514057B1F84D616D4C40
77939	10312	68.979294999999993	68.995806000000002	57.124603999999998	57.117137	Лесная	0103000020E61000000100000005000000B988EFC4AC3E514066136058FE8E4C40B988EFC4AC3E5140B3791C06F38F4C4047CA1649BB3F5140B3791C06F38F4C4047CA1649BB3F514066136058FE8E4C40B988EFC4AC3E514066136058FE8E4C40
77866	10172	69.124166000000002	69.148987000000005	57.192591	57.185070000000003	Школьная	0103000020E610000001000000050000009C51F355F247514041BCAE5FB0974C409C51F355F2475140814067D2A6984C40DE21C50089495140814067D2A6984C40DE21C5008949514041BCAE5FB0974C409C51F355F247514041BCAE5FB0974C40
77960	10172	69.124166000000002	69.148987000000005	57.192591	57.185070000000003	Посёлковая	0103000020E610000001000000050000009C51F355F247514041BCAE5FB0974C409C51F355F2475140814067D2A6984C40DE21C50089495140814067D2A6984C40DE21C5008949514041BCAE5FB0974C409C51F355F247514041BCAE5FB0974C40
77727	10090	69.356613999999993	69.391926999999995	57.123632000000001	57.086910000000003	Центральная	0103000020E61000000100000005000000EDD286C3D256514002D9EBDD1F8B4C40EDD286C3D25651409A5E622CD38F4C40D7DAFB54155951409A5E622CD38F4C40D7DAFB541559514002D9EBDD1F8B4C40EDD286C3D256514002D9EBDD1F8B4C40
42527	10660	68.914508999999995	68.940235999999999	57.067022999999999	57.040990000000001	Салавата Юлаева	0103000020E6100000010000000500000073B9C150873A514045BB0A293F854C4073B9C150873A5140378AAC3594884C4066A19DD32C3C5140378AAC3594884C4066A19DD32C3C514045BB0A293F854C4073B9C150873A514045BB0A293F854C40
77867	10549	68.865460999999996	68.888305000000003	56.875089000000003	56.869760999999997	Центральная	0103000020E61000000100000005000000A9BD88B6633751400A2B1554546F4C40A9BD88B663375140700B96EA02704C40E4F736FDD9385140700B96EA02704C40E4F736FDD93851400A2B1554546F4C40A9BD88B6633751400A2B1554546F4C40
42431	9908	68.870858999999996	68.898392999999999	57.157505	57.14087	Советская	0103000020E61000000100000005000000581B6327BC375140677E350708924C40581B6327BC3751406EFAB31F29944C40247D5A457F3951406EFAB31F29944C40247D5A457F395140677E350708924C40581B6327BC375140677E350708924C40
42402	9779	69.258069000000006	69.294342999999998	56.924554000000001	56.904663999999997	Советская	0103000020E6100000010000000500000022C7D633845051402CEFAA07CC734C4022C7D6338450514068B114C957764C409EB30584D652514068B114C957764C409EB30584D65251402CEFAA07CC734C4022C7D633845051402CEFAA07CC734C40
42433	9671	68.635671000000002	68.662701999999996	56.747176000000003	56.735491000000003	Мира	0103000020E6100000010000000500000000016BD5AE2851404DC0AF91245E4C4000016BD5AE285140952D9276A35F4C409A3FA6B5692A5140952D9276A35F4C409A3FA6B5692A51404DC0AF91245E4C4000016BD5AE2851404DC0AF91245E4C40
77864	9808	69.180921999999995	69.201933999999994	56.906463000000002	56.898524999999999	Центральная	0103000020E610000001000000050000001F48DE39944B5140B7D100DE02734C401F48DE39944B51405C04C6FA06744C40D47C957CEC4C51405C04C6FA06744C40D47C957CEC4C5140B7D100DE02734C401F48DE39944B5140B7D100DE02734C40
77983	10571	68.735536999999994	68.746765999999994	56.921661	56.907317999999997	Центральная	0103000020E61000000100000005000000DEFFC709132F51403B8908FF22744C40DEFFC709132F5140D47FD6FCF8754C40F1F09E03CB2F5140D47FD6FCF8754C40F1F09E03CB2F51403B8908FF22744C40DEFFC709132F51403B8908FF22744C40
78012	10107	69.398062999999993	69.429333	57.062598999999999	57.055115000000001	Школьная	0103000020E61000000100000005000000D9AF3BDD79595140704221020E874C40D9AF3BDD7959514093E1783E03884C40FD851E317A5B514093E1783E03884C40FD851E317A5B5140704221020E874C40D9AF3BDD79595140704221020E874C40
78038	9574	68.645291999999998	68.662109000000001	56.828615999999997	56.812260999999999	Центральная	0103000020E61000000100000005000000B517D1764C2951407B681F2BF8674C40B517D1764C2951409E78CE16106A4C40C9586DFE5F2A51409E78CE16106A4C40C9586DFE5F2A51407B681F2BF8674C40B517D1764C2951407B681F2BF8674C40
42028	9388	68.613033999999999	68.679608000000002	56.895836000000003	56.835470999999998	Октябрьская	0103000020E610000001000000050000008255F5F23B275140D2E0B6B6F06A4C408255F5F23B2751402C4A09C1AA724C4066868DB27E2B51402C4A09C1AA724C4066868DB27E2B5140D2E0B6B6F06A4C408255F5F23B275140D2E0B6B6F06A4C40
42252	9388	68.613033999999999	68.679608000000002	56.895836000000003	56.835470999999998	Ленина	0103000020E610000001000000050000008255F5F23B275140D2E0B6B6F06A4C408255F5F23B2751402C4A09C1AA724C4066868DB27E2B51402C4A09C1AA724C4066868DB27E2B5140D2E0B6B6F06A4C408255F5F23B275140D2E0B6B6F06A4C40
77042	9388	68.613033999999999	68.679608000000002	56.895836000000003	56.835470999999998	Декабристов	0103000020E610000001000000050000008255F5F23B275140D2E0B6B6F06A4C408255F5F23B2751402C4A09C1AA724C4066868DB27E2B51402C4A09C1AA724C4066868DB27E2B5140D2E0B6B6F06A4C408255F5F23B275140D2E0B6B6F06A4C40
42276	9388	68.613033999999999	68.679608000000002	56.895836000000003	56.835470999999998	1 Мая	0103000020E610000001000000050000008255F5F23B275140D2E0B6B6F06A4C408255F5F23B2751402C4A09C1AA724C4066868DB27E2B51402C4A09C1AA724C4066868DB27E2B5140D2E0B6B6F06A4C408255F5F23B275140D2E0B6B6F06A4C40
42401	9292	67.673738	67.693132000000006	55.781585	55.767513999999998	Береговая	0103000020E61000000100000005000000A304FD851EEB50406F9C14E63DE24B40A304FD851EEB5040A7052FFA0AE44B40E9F351465CEC5040A7052FFA0AE44B40E9F351465CEC50406F9C14E63DE24B40A304FD851EEB50406F9C14E63DE24B40
78016	8421	67.745413999999997	67.758960999999999	55.958284999999997	55.950302000000001	Снегиревская	0103000020E61000000100000005000000C1FEEBDCB4EF504065A9F57EA3F94B40C1FEEBDCB4EF5040A99F3715A9FA4B40207C28D192F05040A99F3715A9FA4B40207C28D192F0504065A9F57EA3F94B40C1FEEBDCB4EF504065A9F57EA3F94B40
77756	8413	67.670880999999994	67.683133999999995	55.974257000000001	55.969878999999999	Семискульская	0103000020E610000001000000050000007FA0DCB6EFEA5040E109BDFE24FC4B407FA0DCB6EFEA504015731074B4FC4B404832AB77B8EB504015731074B4FC4B404832AB77B8EB5040E109BDFE24FC4B407FA0DCB6EFEA5040E109BDFE24FC4B40
42429	9246	67.215380999999994	67.23818	56.123302000000002	56.114455	Школьная	0103000020E6100000010000000500000081CB63CDC8CD50408DEE2076A60E4C4081CB63CDC8CD504005C4245CC80F4C40ECA353573ECF504005C4245CC80F4C40ECA353573ECF50408DEE2076A60E4C4081CB63CDC8CD50408DEE2076A60E4C40
42430	9130	67.396283999999994	67.416397000000003	55.927331000000002	55.912565999999998	Новая	0103000020E6100000010000000500000065FB90B75CD9504084B872F6CEF44B4065FB90B75CD9504093C83EC8B2F64B40C3499A3FA6DA504093C83EC8B2F64B40C3499A3FA6DA504084B872F6CEF44B4065FB90B75CD9504084B872F6CEF44B40
77918	9325	67.771106000000003	67.776747	55.748325999999999	55.740091	Центральная	0103000020E61000000100000005000000F6EFFACC59F150402F88484DBBDE4B40F6EFFACC59F150408D5F7825C9DF4B4008910C39B6F150408D5F7825C9DF4B4008910C39B6F150402F88484DBBDE4B40F6EFFACC59F150402F88484DBBDE4B40
42428	8605	67.793537000000001	67.807191000000003	56.028872	56.017125	Старина	0103000020E610000001000000050000009FCA694FC9F25040D578E92631024C409FCA694FC9F2504093E2E313B2034C4009A87004A9F3504093E2E313B2034C4009A87004A9F35040D578E92631024C409FCA694FC9F25040D578E92631024C40
42427	9053	67.891560999999996	67.916659999999993	55.883277	55.867590999999997	Школьная	0103000020E61000000100000005000000E658DE550FF95040E7A6CD380DEF4B40E658DE550FF950408D2782380FF14B404963B48EAAFA50408D2782380FF14B404963B48EAAFA5040E7A6CD380DEF4B40E658DE550FF95040E7A6CD380DEF4B40
78023	8937	68.072113000000002	68.088436000000002	55.876874000000001	55.868828999999998	Центральная	0103000020E610000001000000050000007427D87F9D0451407F68E6C935EF4B407427D87F9D0451403A5B40683DF04B4080F277EFA80551403A5B40683DF04B4080F277EFA80551407F68E6C935EF4B407427D87F9D0451407F68E6C935EF4B40
77920	8771	68.067801000000003	68.082058000000004	55.783372	55.778871000000002	Мира	0103000020E61000000100000005000000B66801DA56045140C366800BB2E34B40B66801DA56045140124DA08845E44B400398327040055140124DA08845E44B400398327040055140C366800BB2E34B40B66801DA56045140C366800BB2E34B40
78240	61289	67.621707000000001	67.632029000000003	55.89873	55.892434999999999	улица Школьная	0103000020E610000001000000050000006F2C280CCAE750402367614F3BF24B406F2C280CCAE7504090F7AA9509F34B40E947C32973E8504090F7AA9509F34B40E947C32973E850402367614F3BF24B406F2C280CCAE750402367614F3BF24B40
78020	8693	67.869471000000004	67.885937999999996	56.111223000000003	56.104179999999999	Крашеневская	0103000020E610000001000000050000008274B169A5F75040DA722EC5550D4C408274B169A5F7504011C8258E3C0E4C4027124C35B3F8504011C8258E3C0E4C4027124C35B3F85040DA722EC5550D4C408274B169A5F75040DA722EC5550D4C40
42491	8861	67.946556000000001	67.96472	55.967520999999998	55.958547000000003	Республики	0103000020E6100000010000000500000049F59D5F94FC5040E75608ABB1FA4B4049F59D5F94FC5040BB9866BAD7FB4B400473F4F8BDFD5040BB9866BAD7FB4B400473F4F8BDFD5040E75608ABB1FA4B4049F59D5F94FC5040E75608ABB1FA4B40
42400	8852	67.247118999999998	67.270430000000005	56.177145000000003	56.162596000000001	Первомайская	0103000020E6100000010000000500000018CE35CCD0CF5040EF3A1BF2CF144C4018CE35CCD0CF504031D3F6AFAC164C40DE76A1B94ED1504031D3F6AFAC164C40DE76A1B94ED15040EF3A1BF2CF144C4018CE35CCD0CF5040EF3A1BF2CF144C40
42424	8710	67.989163000000005	68.021214999999998	55.762737999999999	55.755712000000003	Новая	0103000020E6100000010000000500000073DA53724EFF5040EE98BA2BBBE04B4073DA53724EFF50404EB51666A1E14B40D1CB28965B0151404EB51666A1E14B40D1CB28965B015140EE98BA2BBBE04B4073DA53724EFF5040EE98BA2BBBE04B40
42426	8592	67.759400999999997	67.774421000000004	56.097898999999998	56.083033999999998	50 лет Октября	0103000020E610000001000000050000002EE3A6069AF05040603AADDBA00A4C402EE3A6069AF05040D2A755F4870C4C407B15191D90F15040D2A755F4870C4C407B15191D90F15040603AADDBA00A4C402EE3A6069AF05040603AADDBA00A4C40
77841	8976	67.997652000000002	68.014432999999997	55.904260999999998	55.900233999999998	Набережная	0103000020E610000001000000050000007F32C687D9FF5040A65F22DE3AF34B407F32C687D9FF50402D060FD3BEF34B40ECBE6378EC0051402D060FD3BEF34B40ECBE6378EC005140A65F22DE3AF34B407F32C687D9FF5040A65F22DE3AF34B40
42497	9140	67.483931999999996	67.507998000000001	55.823372999999997	55.818640000000002	Центральная	0103000020E61000000100000005000000395FECBDF8DE504046990D32C9E84B40395FECBDF8DE504067B4554964E94B40BD1B0B0A83E0504067B4554964E94B40BD1B0B0A83E0504046990D32C9E84B40395FECBDF8DE504046990D32C9E84B40
77862	9211	67.435989000000006	67.460971999999998	55.945850999999998	55.937542999999998	Центральная	0103000020E610000001000000050000009C1A683EE7DB5040FFCBB56801F84B409C1A683EE7DB5040C7F143A511F94B40CA17B49080DD5040C7F143A511F94B40CA17B49080DD5040FFCBB56801F84B409C1A683EE7DB5040FFCBB56801F84B40
78073	9080	67.730519999999999	67.743537000000003	55.882393999999998	55.878898999999997	Центральная	0103000020E61000000100000005000000BB44F5D6C0EE504059BE2EC37FF04B40BB44F5D6C0EE5040E3175E49F2F04B406C97361C96EF5040E3175E49F2F04B406C97361C96EF504059BE2EC37FF04B40BB44F5D6C0EE504059BE2EC37FF04B40
42108	8204	67.657200000000003	67.713864999999998	55.957388000000002	55.929979000000003	Рабочая	0103000020E6100000010000000500000099BB96900FEA5040C07B478D09F74B4099BB96900FEA50409BCAA2B08BFA4B409430D3F6AFED50409BCAA2B08BFA4B409430D3F6AFED5040C07B478D09F74B4099BB96900FEA5040C07B478D09F74B40
42348	8204	67.657200000000003	67.713864999999998	55.957388000000002	55.929979000000003	Ленина	0103000020E6100000010000000500000099BB96900FEA5040C07B478D09F74B4099BB96900FEA50409BCAA2B08BFA4B409430D3F6AFED50409BCAA2B08BFA4B409430D3F6AFED5040C07B478D09F74B4099BB96900FEA5040C07B478D09F74B40
42020	8204	67.657200000000003	67.713864999999998	55.957388000000002	55.929979000000003	Кирова	0103000020E6100000010000000500000099BB96900FEA5040C07B478D09F74B4099BB96900FEA50409BCAA2B08BFA4B409430D3F6AFED50409BCAA2B08BFA4B409430D3F6AFED5040C07B478D09F74B4099BB96900FEA5040C07B478D09F74B40
78207	8204	67.657200000000003	67.713864999999998	55.957388000000002	55.929979000000003	Карла Маркса	0103000020E6100000010000000500000099BB96900FEA5040C07B478D09F74B4099BB96900FEA50409BCAA2B08BFA4B409430D3F6AFED50409BCAA2B08BFA4B409430D3F6AFED5040C07B478D09F74B4099BB96900FEA5040C07B478D09F74B40
78633	61344	70.552982	70.566681000000003	56.014462999999999	56.005667000000003	Лесная	0103000020E61000000100000005000000B5519D0E64A351404ED53DB2B9004C40B5519D0E64A35140430070ECD9014C40EF90628044A45140430070ECD9014C40EF90628044A451404ED53DB2B9004C40B5519D0E64A351404ED53DB2B9004C40
42531	7553	70.713807000000003	70.733362999999997	56.557941	56.549343	пер. Школьный	0103000020E61000000100000005000000FA298E03AFAD5140ADA415DF50464C40FA298E03AFAD51407C0C569C6A474C402C465D6BEFAE51407C0C569C6A474C402C465D6BEFAE5140ADA415DF50464C40FA298E03AFAD5140ADA415DF50464C40
42580	6095	70.313930999999997	70.337772000000001	56.328553999999997	56.32226	Игнатенко	0103000020E61000000100000005000000D68C0C72179451408C67D0D03F294C40D68C0C7217945140287CB60E0E2A4C404A60730E9E955140287CB60E0E2A4C404A60730E9E9551408C67D0D03F294C40D68C0C72179451408C67D0D03F294C40
42399	7933	70.451768999999999	70.475285999999997	56.187370999999999	56.176313999999998	Маслова	0103000020E610000001000000050000002F1686C8E99C5140D9E9077591164C402F1686C8E99C5140029CDEC5FB174C40C98FF8156B9E5140029CDEC5FB174C40C98FF8156B9E5140D9E9077591164C402F1686C8E99C5140D9E9077591164C40
78002	7473	70.522447999999997	70.541985999999994	56.510720999999997	56.500914999999999	Погорельская	0103000020E610000001000000050000001477BCC96FA15140B58993FB1D404C401477BCC96FA15140B130444E5F414C40F3380CE6AFA25140B130444E5F414C40F3380CE6AFA25140B58993FB1D404C401477BCC96FA15140B58993FB1D404C40
77876	7804	70.066175999999999	70.076183	56.172334999999997	56.168740999999997	Механизаторов	0103000020E61000000100000005000000EDF1423A3C845140463F1A4E99154C40EDF1423A3C845140637AC2120F164C40B760A92EE0845140637AC2120F164C40B760A92EE0845140463F1A4E99154C40EDF1423A3C845140463F1A4E99154C40
42526	7661	70.124054000000001	70.151785000000004	56.215868	56.206687000000002	Советская	0103000020E61000000100000005000000083C3080F087514012C138B8741A4C40083C3080F087514060200890A11B4C407FC16ED8B689514060200890A11B4C407FC16ED8B689514012C138B8741A4C40083C3080F087514012C138B8741A4C40
42508	7435	70.674999999999997	70.687460000000002	56.369781000000003	56.358043000000002	Школьная	0103000020E610000001000000050000003333333333AB5140E7C75F5AD42D4C403333333333AB514052D7DAFB542F4C40B9533A58FFAB514052D7DAFB542F4C40B9533A58FFAB5140E7C75F5AD42D4C403333333333AB5140E7C75F5AD42D4C40
78195	61282	70.473211000000006	70.485930999999994	56.221789999999999	56.210687	Совхозная	0103000020E61000000100000005000000E146CA16499E51409F58A7CAF71A4C40E146CA16499E5140384A5E9D631C4C403447567E199F5140384A5E9D631C4C403447567E199F51409F58A7CAF71A4C40E146CA16499E51409F58A7CAF71A4C40
77859	6275	70.199369000000004	70.221260999999998	56.125093999999997	56.11833	Лермонтова	0103000020E6100000010000000500000085B53176C28C51405E11FC6F250F4C4085B53176C28C51408176871403104C4056B8E523298E51408176871403104C4056B8E523298E51405E11FC6F250F4C4085B53176C28C51405E11FC6F250F4C40
42395	6408	70.208172000000005	70.222104999999999	56.325225000000003	56.319619000000003	Первомайская	0103000020E6100000010000000500000059FCA6B0528D514012178046E9284C4059FCA6B0528D5140BA6B09F9A0294C40CCD1E3F7368E5140BA6B09F9A0294C40CCD1E3F7368E514012178046E9284C4059FCA6B0528D514012178046E9284C40
42495	7056	70.105215999999999	70.122086999999993	56.089272000000001	56.078809	60 лет СССР	0103000020E6100000010000000500000005C1E3DBBB865140B3D0CE69160A4C4005C1E3DBBB8651406939D0436D0B4C401211FE45D08751406939D0436D0B4C401211FE45D0875140B3D0CE69160A4C4005C1E3DBBB865140B3D0CE69160A4C40
42423	7398	70.690550000000002	70.707545999999994	56.463783999999997	56.450901999999999	Мира	0103000020E610000001000000050000002E90A0F831AC5140BAD91F28B7394C402E90A0F831AC51403B342C465D3B4C40999A046F48AD51403B342C465D3B4C40999A046F48AD5140BAD91F28B7394C402E90A0F831AC5140BAD91F28B7394C40
77860	8092	70.628135	70.640450999999999	56.208804999999998	56.200603000000001	 Зеленая	0103000020E61000000100000005000000459E245D33A85140603DEE5BAD194C40459E245D33A85140E21E4B1FBA1A4C4031EC3026FDA85140E21E4B1FBA1A4C4031EC3026FDA85140603DEE5BAD194C40459E245D33A85140603DEE5BAD194C40
77889	7725	70.113552999999996	70.119642999999996	56.199686999999997	56.193382	Аризонская	0103000020E610000001000000050000003657CD73448751404AD1CABDC0184C403657CD7344875140DA37F7578F194C40800C1D3BA8875140DA37F7578F194C40800C1D3BA88751404AD1CABDC0184C403657CD73448751404AD1CABDC0184C40
42582	7362	70.651679999999999	70.664022000000003	56.527290999999998	56.510109999999997	Центральная	0103000020E6100000010000000500000044DD0720B5A9514068AED3484B414C4044DD0720B5A95140D13C80457E434C40C57421567FAA5140D13C80457E434C40C57421567FAA514068AED3484B414C4044DD0720B5A9514068AED3484B414C40
77926	7566	70.833112	70.863124999999997	56.052149999999997	56.034928000000001	8 марта	0103000020E61000000100000005000000EE79FEB451B551407BDB4C8578044C40EE79FEB451B55140423EE8D9AC064C400AD7A3703DB75140423EE8D9AC064C400AD7A3703DB751407BDB4C8578044C40EE79FEB451B551407BDB4C8578044C40
77856	6988	70.130971000000002	70.149952999999996	56.110134000000002	56.099752000000002	Школьная	0103000020E610000001000000050000005D6E30D461885140F5DA6CACC40C4C405D6E30D461885140BE16F4DE180E4C40F9BB77D498895140BE16F4DE180E4C40F9BB77D498895140F5DA6CACC40C4C405D6E30D461885140F5DA6CACC40C4C40
42275	7269	70.684459000000004	70.712828000000002	56.49127	56.473480000000002	Пушкина	0103000020E61000000100000005000000FC1C1F2DCEAB5140B1A71DFE9A3C4C40FC1C1F2DCEAB5140C2C073EFE13E4C4014EB54F99EAD5140C2C073EFE13E4C4014EB54F99EAD5140B1A71DFE9A3C4C40FC1C1F2DCEAB5140B1A71DFE9A3C4C40
42398	7110	70.772548	70.791888999999998	56.574665000000003	56.561973999999999	1 Мая	0103000020E61000000100000005000000C6A52A6D71B15140E59997C3EE474C40C6A52A6D71B15140F3936A9F8E494C40FA43334FAEB25140F3936A9F8E494C40FA43334FAEB25140E59997C3EE474C40C6A52A6D71B15140E59997C3EE474C40
77854	6975	70.058064000000002	70.076155999999997	56.085962000000002	56.082521999999997	Зеленая	0103000020E61000000100000005000000CC441152B7835140AA99B514900A4C40CC441152B7835140715985CD000B4C403A596ABDDF845140715985CD000B4C403A596ABDDF845140AA99B514900A4C40CC441152B7835140AA99B514900A4C40
78005	6873	70.286955000000006	70.301786000000007	56.052829000000003	56.046900999999998	Рабочая	0103000020E610000001000000050000001E1B81785D92514029931ADA00064C401E1B81785D925140E4A3C519C3064C4001193A7650935140E4A3C519C3064C4001193A765093514029931ADA00064C401E1B81785D92514029931ADA00064C40
42425	6901	70.125868999999994	70.167730000000006	55.940123999999997	55.925662000000003	Юбилейная	0103000020E6100000010000000500000022A5D93C0E8851403293A8177CF64B4022A5D93C0E885140A417B5FB55F84B40B8239C16BC8A5140A417B5FB55F84B40B8239C16BC8A51403293A8177CF64B4022A5D93C0E8851403293A8177CF64B40
42313	6713	70.402550000000005	70.426625000000001	56.061605	56.044758999999999	Ленина	0103000020E610000001000000050000004F401361C3995140D099B4A9BA054C404F401361C3995140922232ACE2074C40FCA9F1D24D9B5140922232ACE2074C40FCA9F1D24D9B5140D099B4A9BA054C404F401361C3995140D099B4A9BA054C40
42581	6601	70.574558999999994	70.592813000000007	56.258668	56.252327000000001	Советская	0103000020E61000000100000005000000D6A71C93C5A45140EB724A404C204C40D6A71C93C5A45140C84274081C214C4032E9EFA5F0A55140C84274081C214C4032E9EFA5F0A55140EB724A404C204C40D6A71C93C5A45140EB724A404C204C40
42397	6384	70.029785000000004	70.052638000000002	56.273544999999999	56.264156999999997	Армизонская	0103000020E61000000100000005000000543A58FFE7815140360186E5CF214C40543A58FFE7815140FE7DC68503234C40B821C66B5E835140FE7DC68503234C40B821C66B5E835140360186E5CF214C40543A58FFE7815140360186E5CF214C40
42373	6487	70.702236999999997	70.728153000000006	56.302897000000002	56.279896999999998	Советская	0103000020E61000000100000005000000A2427573F1AC5140CF9F36AAD3234C40A2427573F1AC51403C873254C5264C40FF5E0A0F9AAE51403C873254C5264C40FF5E0A0F9AAE5140CF9F36AAD3234C40A2427573F1AC5140CF9F36AAD3234C40
77997	7624	70.702973	70.729401999999993	56.110902000000003	56.101548999999999	8 марта	0103000020E61000000100000005000000253E7782FDAC514083F8C08EFF0C4C40253E7782FDAC5140CF876709320E4C40C4E8B985AEAE5140CF876709320E4C40C4E8B985AEAE514083F8C08EFF0C4C40253E7782FDAC514083F8C08EFF0C4C40
78205	61284	70.650215000000003	70.671460999999994	56.137554999999999	56.129539000000001	Энергетиков	0103000020E610000001000000050000009817601F9DA951403D47E4BB94104C409817601F9DA951405D33F9669B114C4086E28E37F9AA51405D33F9669B114C4086E28E37F9AA51403D47E4BB94104C409817601F9DA951403D47E4BB94104C40
77759	5860	70.467192999999995	70.476705999999993	56.346984999999997	56.339562000000001	Маслова	0103000020E61000000100000005000000E3FA777DE69D5140707B82C4762B4C40E3FA777DE69D5140ED9925016A2C4C40A5F3E159829E5140ED9925016A2C4C40A5F3E159829E5140707B82C4762B4C40E3FA777DE69D5140707B82C4762B4C40
78061	6825	70.542085	70.561597000000006	56.030236000000002	56.019883	пер. Восточный	0103000020E61000000100000005000000BDA94885B1A25140895FB1868B024C40BDA94885B1A25140B894F3C5DE034C4008228B34F1A35140B894F3C5DE034C4008228B34F1A35140895FB1868B024C40BDA94885B1A25140895FB1868B024C40
42375	7294	70.610518999999996	70.639436000000003	56.437486999999997	56.412756000000002	Центральная	0103000020E610000001000000050000008BA548BE12A75140289D4830D5344C408BA548BE12A751406BB6F292FF374C40A5F8F884ECA851406BB6F292FF374C40A5F8F884ECA85140289D4830D5344C408BA548BE12A75140289D4830D5344C40
42579	6307	70.111611999999994	70.149655999999993	56.326892000000001	56.316094999999997	Молодежная	0103000020E61000000100000005000000D575A8A624875140EDB60BCD75284C40D575A8A6248751407AA9D898D7294C409C69C2F6938951407AA9D898D7294C409C69C2F693895140EDB60BCD75284C40D575A8A624875140EDB60BCD75284C40
42475	5802	70.520588000000004	70.545857999999996	56.322493999999999	56.316654	Зеленая	0103000020E610000001000000050000002AAC545051A15140E412471E88284C402AAC545051A15140FF93BF7B47294C40A3906456EFA25140FF93BF7B47294C40A3906456EFA25140E412471E88284C402AAC545051A15140E412471E88284C40
42273	6179	70.260445000000004	70.293978999999993	56.124034999999999	56.112411999999999	Гагарина	0103000020E61000000100000005000000085A8121AB905140C7D63384630E4C40085A8121AB9051409947FE60E00F4C407DAD4B8DD09251409947FE60E00F4C407DAD4B8DD0925140C7D63384630E4C40085A8121AB905140C7D63384630E4C40
42046	5555	70.396458999999993	70.475583	56.306168	56.277453000000001	Ленина	0103000020E610000001000000050000001CCD91955F995140AB96749483234C401CCD91955F995140768A558330274C4026E2ADF36F9E5140768A558330274C4026E2ADF36F9E5140AB96749483234C401CCD91955F995140AB96749483234C40
42249	5555	70.396458999999993	70.475583	56.306168	56.277453000000001	Дорожная	0103000020E610000001000000050000001CCD91955F995140AB96749483234C401CCD91955F995140768A558330274C4026E2ADF36F9E5140768A558330274C4026E2ADF36F9E5140AB96749483234C401CCD91955F995140AB96749483234C40
42092	5555	70.396458999999993	70.475583	56.306168	56.277453000000001	1 Мая	0103000020E610000001000000050000001CCD91955F995140AB96749483234C401CCD91955F995140768A558330274C4026E2ADF36F9E5140768A558330274C4026E2ADF36F9E5140AB96749483234C401CCD91955F995140AB96749483234C40
18838	49962	61.777034	61.839503000000001	58.808472999999999	58.783392999999997	Парковая	0103000020E61000000100000005000000A6F0A0D975E34E402975C93846644D40A6F0A0D975E34E407959130B7C674D406BF294D574EB4E407959130B7C674D406BF294D574EB4E402975C93846644D40A6F0A0D975E34E402975C93846644D40
18265	49906	60.690333000000003	60.734538999999998	59.619056	59.594963	Путилова	0103000020E61000000100000005000000BF2CEDD45C584E403FAA61BF27CC4D40BF2CEDD45C584E4040321D3A3DCF4D407A51BB5F055E4E4040321D3A3DCF4D407A51BB5F055E4E403FAA61BF27CC4D40BF2CEDD45C584E403FAA61BF27CC4D40
78232	50103	63.661197000000001	63.733224	58.068415000000002	58.014274	Горького	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
20171	50169	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	Агатовая	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
77281	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	микрорайон Новый	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77272	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Энгельса	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77469	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Чапаева	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
78235	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Трактовая	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77289	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Тимерязева	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77283	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Свердлова	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77455	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Самстроя	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77192	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Розы Люксембург	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77276	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Орджоникидзе	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77278	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Ленина	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
77246	61096	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Красноармейская	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
19815	49883	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Юбилейная	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
77227	49883	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Октябрьская	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
17942	49868	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	Металлистов	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
20066	49868	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	Калинина	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
17878	49854	61.638793	61.652051999999998	56.433211999999997	56.424017999999997	Специалистов	0103000020E61000000100000005000000F5F411F8C3D14E402975C93846364C40F5F411F8C3D14E400C1EA67D73374C404CA59F7076D34E400C1EA67D73374C404CA59F7076D34E402975C93846364C40F5F411F8C3D14E402975C93846364C40
19178	49984	59.774419999999999	59.789681999999999	58.798268999999998	58.789400000000001	Клубная	0103000020E6100000010000000500000025AFCE3120E34D4030BB270F0B654D4025AFCE3120E34D408F34B8AD2D664D40B41EBE4C14E54D408F34B8AD2D664D40B41EBE4C14E54D4030BB270F0B654D4025AFCE3120E34D4030BB270F0B654D40
19980	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	пр.Серова	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
20359	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	пер.Толмачева	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18910	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Я.Свердлова	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
20368	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Ф.Революции	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18348	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Строителей	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18339	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Республиканская	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18344	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Попова	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
19828	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Победы	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18608	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Нансена	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
19042	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Луначарского	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18088	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Ломоносова	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18980	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Лесозаводская	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18142	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Ленина	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18310	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Л.Чайкиной	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18673	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Крупской	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
19999	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Короленко	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18331	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Киселевское шоссе	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
19216	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Кирова	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
17992	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Калинина	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
19271	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Каквинская	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18277	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	К.Маркса	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18279	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Зеленая	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
19820	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Заславского	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
20111	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	Восточная	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18627	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	8 Марта	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
19833	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	20 Партсъезда	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
18688	6144	60.479472000000001	60.703116000000001	59.653539000000002	59.560045000000002	1 Овощная ферма	0103000020E6100000010000000500000082ACA7565F3D4E40E8A4F78DAFC74D4082ACA7565F3D4E408DD47B2AA7D34D40ADA580B4FF594E408DD47B2AA7D34D40ADA580B4FF594E40E8A4F78DAFC74D4082ACA7565F3D4E40E8A4F78DAFC74D40
20028	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Степана Разина	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
18233	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Советская	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
18400	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Свердлова	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
18308	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Молодежная	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
18948	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Ленина	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
20182	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Комсомольская	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
20326	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Комарова	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
17899	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Кирова	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
19362	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Каржавина	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
78523	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Гагарина	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
18745	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Ватутина	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
20393	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	Больничный переулок	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
18725	4770	59.921843000000003	60.016964999999999	60.176684999999999	60.135739999999998	 Советская	0103000020E61000000100000005000000F58590F3FEF54D402861A6ED5F114E40F58590F3FEF54D40CD58349D9D164E409C16BCE82B024E40CD58349D9D164E409C16BCE82B024E402861A6ED5F114E40F58590F3FEF54D402861A6ED5F114E40
20118	49895	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Спортивная	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
77423	49895	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Советская	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
18188	49895	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	П.Морозова	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
20089	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Энгельса	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
20396	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Чехова	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
77064	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Чайковского	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18542	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Цветников	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
20247	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Толстого	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18504	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Спортивная	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
78521	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	С.Разина	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18135	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Российская	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
78577	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Павла Зыкина	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18985	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	П.Зыкина	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
20074	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Нахимова	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18096	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Мира	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18149	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Мамина-Сибиряка	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
19102	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	М.Горького	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18148	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Лесная	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18710	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Ленина	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
20336	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Калинина	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18115	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	К.Либкнехта	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
18094	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Жуковского	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
20262	6072	59.884059000000001	59.986530000000002	56.847380000000001	56.75676	Азина	0103000020E61000000100000005000000035E66D828F14D40E275FD82DD604C40035E66D828F14D406AA4A5F2766C4C40EE42739D46FE4D406AA4A5F2766C4C40EE42739D46FE4D40E275FD82DD604C40035E66D828F14D40E275FD82DD604C40
19831	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	микрорайон Зелёный Бор 1 	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
19041	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Ялунина	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
17868	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Челюскинцев	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
19215	1641	60.245531999999997	60.377333	56.475116	56.402101999999999	Ст. Разина	0103000020E610000001000000050000008C0FB3976D1F4E40FED30D1478334C408C0FB3976D1F4E4036E7E099D03C4C40CD599F724C304E4036E7E099D03C4C40CD599F724C304E40FED30D1478334C408C0FB3976D1F4E40FED30D1478334C40
18814	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Северская	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
18441	1641	59.635899999999999	60.567686000000002	56.676884000000001	56.200293000000002	Р. Люксембург	0103000020E6100000010000000500000061C3D32B65D14D40124F7633A3194C4061C3D32B65D14D40C4978922A4564C40D33252EFA9484E40C4978922A4564C40D33252EFA9484E40124F7633A3194C4061C3D32B65D14D40124F7633A3194C40
18456	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Победы	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
18425	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Партизанская	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
18790	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Микрорайон 2	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
18726	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Малышева	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
18774	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Ленина	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
18533	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Коммунистическая	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
17741	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	К. Маркса	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
18080	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	Вершинина	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
78431	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	1 Мая	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
19030	1641	60.14705	60.277341999999997	56.514752999999999	56.416311	 К. Маркса	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
19234	16	59.863757	60.054901000000001	56.933847	56.853822999999998	проспект Ильича	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
20197	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Энгельса	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18153	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Чкалова	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18854	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Трубников	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18487	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Строителей	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18027	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Советская	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18292	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Сантехизделий	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18676	16	59.863757	60.054901000000001	56.933847	56.853822999999998	СХПК Первоуральский	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18651	16	59.863757	60.054901000000001	56.933847	56.853822999999998	СТИ	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
17767	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Пушкина	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18278	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Проспект Ильича	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
17804	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Пролетарская	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
19387	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Пархоменко	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18868	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Папанинцев	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
78537	16	59.670547999999997	59.679341999999998	57.160800000000002	57.153252999999999	Новая	0103000020E61000000100000005000000F8325184D4D54D40C78157CB9D934C40F8325184D4D54D4031992A1895944C404D66BCADF4D64D4031992A1895944C404D66BCADF4D64D40C78157CB9D934C40F8325184D4D54D40C78157CB9D934C40
18303	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Набережная	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18523	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Ленина	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
17910	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Крупской	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18119	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Красноармейская	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18121	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Космонавтов	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18213	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Комсомольская	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18969	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Коммуны	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18537	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Клубная	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
20234	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Карбышева	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18852	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Калинина	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
17914	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Ильича проспект	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18276	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Ильича	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18678	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Заводская	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
78264	16	59.863757	60.054901000000001	56.933847	56.853822999999998	З.Космодемьянской	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
19133	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Гагарина	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18561	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Ватутина	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18833	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Вайнера	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18189	16	59.863757	60.054901000000001	56.933847	56.853822999999998	Береговая	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18515	16	59.863757	60.054901000000001	56.933847	56.853822999999998	50 лет СССР	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
17802	16	59.863757	60.054901000000001	56.933847	56.853822999999998	1ая Пильная	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
18180	16	59.863757	60.054901000000001	56.933847	56.853822999999998	1 Мая	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
78586	61334	63.095905000000002	63.105184000000001	59.652138999999998	59.646768999999999	Фестивальная	0103000020E61000000100000005000000EE42739D468C4F4087889B53C9D24D40EE42739D468C4F401BB96E4A79D34D40FF0758AB768D4F401BB96E4A79D34D40FF0758AB768D4F4087889B53C9D24D40EE42739D468C4F4087889B53C9D24D40
18089	49886	60.050859000000003	60.121772	57.263199	57.226635999999999	Чурина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
20079	49886	60.050859000000003	60.121772	57.263199	57.226635999999999	Ленина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
20389	49886	60.050859000000003	60.121772	57.263199	57.226635999999999	Гагарина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
19182	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Энгельса	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
18832	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Чкалова	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
18872	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Пархоменко	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
20342	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Набережная	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
17917	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Молодежная	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
18169	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Машиностроителей	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
19088	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Малышева	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
20199	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Ленина	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
20355	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Коммунистический прт	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
18312	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Декабристов	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
20094	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Гайдара	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
77078	1810	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	40 лет Октября	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
18105	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Центральная	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
19355	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Фрунзе	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
18669	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Строителей,	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
17807	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Строителей	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
20407	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Совхозная	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
18332	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Привокзальная	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
20169	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Первая	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
19992	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	Карла Либкнехта	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
18624	12051	60.682966999999998	60.767364000000001	58.092008	58.050798	К.Маркса	0103000020E61000000100000005000000A59F70766B574E40E259828C80064D40A59F70766B574E40357C0BEBC60B4D405A10CAFB38624E40357C0BEBC60B4D405A10CAFB38624E40E259828C80064D40A59F70766B574E40E259828C80064D40
17985	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	проспект Мира	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19347	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	проспект Мира	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
17990	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	проспект Мира	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19876	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	пр. Мира	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20409	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Юности	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
17964	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Энтузиастов	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
17959	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Энтузиастов	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18654	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Щорса	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18690	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Черноморская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19959	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Черноисточинское шоссе	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18281	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Черноисточинское шоссе	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20064	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Челюскинцев	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20090	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Циолковского	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19334	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Хохрякова	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
20135	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Фрунзе	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18613	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Фрунзе	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20015	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Уральский проспект	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18055	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Уральский проспект	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19860	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Тимирязева	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18023	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Тагилстроевская	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
20272	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Тагилстроевская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18134	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Строителей	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20382	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Совхозная	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18326	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Сланцевая	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20072	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Свердлова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18675	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Решетникова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18317	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Проезжая	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
19339	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Попова	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18633	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Полуденская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20253	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Покровское1	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18766	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Победы	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18801	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Пихтовая	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18093	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Пихтовая	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18856	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Перова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19005	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Патона	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18160	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Пархоменко	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18728	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Парковая	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18550	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Островского	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19915	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Оплетина	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18593	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Оплетина	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18406	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Окунева	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
19865	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Октябрьской революции	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18912	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Октябрьской революции	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18488	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Октябрьский проспект	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
20243	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Октябрьский проспект	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18755	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Новострой	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18921	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Некрасова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
17840	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Мира	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
20007	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Металлургов	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18444	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Максарева	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18184	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Липовый тракт	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20093	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Ленина	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18859	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Ленина	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19950	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Лайская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19848	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Краснофлотская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18730	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Красногвардейская	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
20040	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Красногвардейская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
17958	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Красногвардейская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19932	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Красноармейская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18013	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Космонавтов	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18762	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Коровина	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
17809	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Коминтерна	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20276	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Коминтерна	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18976	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Кольцова	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18521	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Карла Маркса	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19884	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Карла Маркса	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18035	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Карла Либкнехта	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20062	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Карла Либкнехта	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
19376	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Калинина	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18063	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Ильича	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18051	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Ильича	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
19940	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Известковая	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
17919	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Захарова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20053	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Зари	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18454	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Зари	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18468	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Зари	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
18448	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Жуковского	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
77102	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Дружинина	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19923	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Гвардейская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19899	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Газетная	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18520	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Газетная	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19969	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Гагарина	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20341	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Выйская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18885	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Верхняя Черепанова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19927	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Верхняя Черепанова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18707	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Вагоностроителей	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20026	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Вагоностроителей	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
18759	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	Бобкова	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
17880	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Басова	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
20027	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Алтайская	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19957	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	Аганичева	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19840	9945	59.787993999999998	60.163885000000001	58.041570999999998	57.831772999999998	 Тельмана	0103000020E61000000100000005000000DCB8C5FCDCE44D401059A48977EA4C40DCB8C5FCDCE44D4023BBD23252054D4009A7052FFA144E4023BBD23252054D4009A7052FFA144E401059A48977EA4C40DCB8C5FCDCE44D401059A48977EA4C40
20187	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	 Радищева	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19373	9945	59.851908999999999	60.154865999999998	58.007756000000001	57.842860000000002	 Коминтерна	0103000020E610000001000000050000008315A75A0BED4D40A48D23D6E2EB4C408315A75A0BED4D40842C0B26FE004D4094A12AA6D2134E40842C0B26FE004D4094A12AA6D2134E40A48D23D6E2EB4C408315A75A0BED4D40A48D23D6E2EB4C40
19988	50124	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	Нагорная	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
18905	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	проспект Октябрьский	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
18540	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Советская	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
18920	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Самойлова	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
18238	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Ракетная	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
19092	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Попова	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
77073	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Малышева	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
77075	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Красноармейская	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
18235	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Долгих,	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
18231	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Долгих	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
20112	20037	60.178697999999997	60.249009000000001	57.508726000000003	57.472876999999997	Демьяна Бедного	0103000020E6100000010000000500000028EE7893DF164E40EA03C93B87BC4C4028EE7893DF164E40FD4FFEEE1DC14C4070B4E386DF1F4E40FD4FFEEE1DC14C4070B4E386DF1F4E40EA03C93B87BC4C4028EE7893DF164E40EA03C93B87BC4C40
78423	50135	59.068559999999998	59.154744000000001	56.469383000000001	56.405943000000001	Энгельса	0103000020E6100000010000000500000029E8F692C6884D402385B2F0F5334C4029E8F692C6884D403126FDBD143C4C4049A0C1A6CE934D403126FDBD143C4C4049A0C1A6CE934D402385B2F0F5334C4029E8F692C6884D402385B2F0F5334C40
19340	49991	59.757837000000002	59.823917000000002	58.660030999999996	58.623361000000003	Строителей	0103000020E61000000100000005000000715985CD00E14D400A4D124BCA4F4D40715985CD00E14D404FAC53E57B544D4029CFBC1C76E94D404FAC53E57B544D4029CFBC1C76E94D400A4D124BCA4F4D40715985CD00E14D400A4D124BCA4F4D40
77223	49991	59.757837000000002	59.823917000000002	58.660030999999996	58.623361000000003	Мамина Сибиряка	0103000020E61000000100000005000000715985CD00E14D400A4D124BCA4F4D40715985CD00E14D404FAC53E57B544D4029CFBC1C76E94D404FAC53E57B544D4029CFBC1C76E94D400A4D124BCA4F4D40715985CD00E14D400A4D124BCA4F4D40
18558	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	пос.Строителей	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
20245	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	пер.Свердлова	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18849	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Энергетиков	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18827	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Строителей	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
20260	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Станционная	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18836	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Союзов	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18851	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Прокофьева	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18825	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Площадь Культуры	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
19960	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Первомайская	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18546	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Маяковского	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
20327	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Луначарского	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
19131	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Лесорубов	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18090	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Ленина	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18586	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Кушвинская	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18186	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Коммуны	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
20364	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Иканина	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
19890	8815	59.682324999999999	59.821123	58.314900999999999	58.256017	Дзержинского	0103000020E61000000100000005000000211FF46C56D74D402A1C412AC5204D40211FF46C56D74D40253D0CAD4E284D40287FF78E1AE94D40253D0CAD4E284D40287FF78E1AE94D402A1C412AC5204D40211FF46C56D74D402A1C412AC5204D40
18159	49894	60.190403000000003	60.205908000000001	56.625053999999999	56.615713999999997	Кунгурская	0103000020E61000000100000005000000B80721205F184E403CD862B7CF4E4C40B80721205F184E40F31DFCC401504C400DFE7E315B1A4E40F31DFCC401504C400DFE7E315B1A4E403CD862B7CF4E4C40B80721205F184E403CD862B7CF4E4C40
19913	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Ухтомского	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
18250	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Трактовая	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
18785	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Сухобского	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
20377	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Станционная	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
19942	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Советская	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
18909	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Селекционная	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
19935	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Свердлова	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
20248	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Саргинская	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
18526	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Ремесленная	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
18890	7561	57.719909999999999	57.797623000000002	56.641703	56.575166000000003	Р.Горбуновой	0103000020E610000001000000050000001C08C90226DC4C40B5E21B0A9F494C401C08C90226DC4C405F5FEB5223524C40CAC4AD8218E64C405F5FEB5223524C40CAC4AD8218E64C40B5E21B0A9F494C401C08C90226DC4C40B5E21B0A9F494C40
19883	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Пролетарская	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
20069	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Отдыха	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
19073	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Нефтяников	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
78411	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Мира	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
20304	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Механизаторов	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
19830	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Манчажская	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
78407	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Кирпично-Заводская	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
18511	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Докучаева	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
19099	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Высокая	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
77094	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	Буткинская	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
19172	7561	57.716316999999997	57.755285999999998	56.648924000000001	56.623399999999997	Березовая	0103000020E61000000100000005000000CF488446B0DB4C40C7293A92CB4F4C40CF488446B0DB4C4075CB0EF10F534C4036902E36ADE04C4075CB0EF10F534C4036902E36ADE04C40C7293A92CB4F4C40CF488446B0DB4C40C7293A92CB4F4C40
18619	7561	57.720844	57.805698999999997	56.650759999999998	56.575502999999998	8 Марта	0103000020E6100000010000000500000048C2BE9D44DC4C40FCDF1115AA494C4048C2BE9D44DC4C40C1C58A1A4C534C40BFB5132521E74C40C1C58A1A4C534C40BFB5132521E74C40FCDF1115AA494C4048C2BE9D44DC4C40FCDF1115AA494C40
18048	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Шахтеров	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
20233	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Челюскинцев	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
17989	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Советская	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
18469	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Победы	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
18420	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Парковая	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
20054	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Ленина	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
19096	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Каляева	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
18683	6272	60.017952999999999	60.140016000000003	58.383166000000003	58.307237000000001	Воровского	0103000020E61000000100000005000000BBEEAD484C024E40828FC18A53274D40BBEEAD484C024E4036785F950B314D405875560BEC114E4036785F950B314D405875560BEC114E40828FC18A53274D40BBEEAD484C024E40828FC18A53274D40
20219	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	бульвар Мира	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78378	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Чкалова	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78486	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Чернышевского	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78366	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Фрунзе	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
20148	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Серова	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
18045	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Рюмина	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
77397	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Попова	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
18408	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Парковая,	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
77662	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Октябрьская	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78487	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Молодежная	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
18990	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Микова	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
77399	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Металлургов	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78478	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Маркса	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78457	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Ленина проспект	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
77667	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Ленина	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
77394	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Космодемьянской	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
19971	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Колхозная	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
20013	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Клубная	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78444	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Карла Маркса	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
19213	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Животноводов	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
78544	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Восточная	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
20213	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Базстроевская	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
18376	49845	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	Абоимова	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
18154	450	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	Свердлова	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
19984	450	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	Набережная	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
18195	450	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	Максима Горького	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
18155	450	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	Лермонтова	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
19157	450	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	Ленина	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
18831	450	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	Калинина	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
20119	450	60.039064000000003	60.094453999999999	57.450496999999999	57.410876999999999	Дзержинского	0103000020E61000000100000005000000B939950C00054E40DCD6169E97B44C40B939950C00054E401AF9BCE2A9B94C40FA7C9411170C4E401AF9BCE2A9B94C40FA7C9411170C4E40DCD6169E97B44C40B939950C00054E40DCD6169E97B44C40
20100	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	микрорайон 5а	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
77391	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	Свердлова	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
18598	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	Гикалова	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
18816	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	8 микрорайон	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
20240	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	6а микрорайон	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
20246	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	4 микрорайон	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
18602	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	11 микрорайон	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
78355	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	11 микрорайон	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
18740	49875	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	10 микрорайон	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
18440	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	проезд Декабристов	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
19069	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Школьный	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
18419	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Шахтерский	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
77378	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Трудовая	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
18465	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Советская	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
19388	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Почтамтская	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
78348	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Попова	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
78255	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Пионерская	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
77376	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Мира	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
18457	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Малышева	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
20277	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Лесопильная	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
77661	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Куйбышева	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
18016	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Колхозная	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
19374	29288	59.921132999999998	60.059508999999998	59.798836999999999	59.735517999999999	Заречная	0103000020E610000001000000050000001822A7AFE7F54D4046CF2D7425DE4D401822A7AFE7F54D40D9EA724A40E64D40A968ACFD9D074E40D9EA724A40E64D40A968ACFD9D074E4046CF2D7425DE4D401822A7AFE7F54D4046CF2D7425DE4D40
18661	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Энгельса	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
78447	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Швельниса	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
18911	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Фарфористов	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
18418	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Строителей	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
19316	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Северная	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
18754	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Молокова	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
18737	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Маяковского	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
19987	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Ленинградская	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
77374	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Куйбышева	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
20160	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Красных Партизан,	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
18996	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Карловарская	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
18407	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Карла Либкнехта	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
19368	23556	62.647987000000001	62.793137000000002	56.869515	56.826217	Вокзальная	0103000020E61000000100000005000000D89DEE3CF1524F401A33897AC1694C40D89DEE3CF1524F40D3307C444C6F4C40B01F628385654F40D3307C444C6F4C40B01F628385654F401A33897AC1694C40D89DEE3CF1524F401A33897AC1694C40
18630	49945	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Челябинская	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
17786	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	проспект Победы	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
19294	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	бульвар Комсомольский	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
78261	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Школьная	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18603	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Челябинская	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
19200	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Центральная	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18046	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Уральская	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18474	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Тевосяна	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77620	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Строителей	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18018	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Спиридонова	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77422	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Пушкина	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18480	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Проспект Победы	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
19107	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Прокопьева	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77742	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Привокзальная	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
19022	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Олега Кошевого	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77381	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Октябрьская	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77520	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Мусоргского	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77453	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Мичурина	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77249	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Мичурина	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18267	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Механизаторов	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77346	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Машинистов	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77753	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Лесная	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77318	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Лермонтова	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
20216	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Ленина	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
78592	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Кутузова	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18112	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Кунавина	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
78278	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Кузнецова	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18072	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Кирова	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77411	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Карла Маркса	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77588	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Калинина	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77362	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Исетская	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77537	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Железнодорожная	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77352	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Добролюбова	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
77354	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Дзержинского	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
78337	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Гоголя	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
17790	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	Алюминиевая	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
17826	20970	61.781103999999999	62.003221000000003	56.455587000000001	56.330595000000002	2я Рабочая	0103000020E610000001000000050000002C634337FBE34E404E9CDCEF502A4C402C634337FBE34E40CBBDC0AC503A4C4089D4B48B69004F40CBBDC0AC503A4C4089D4B48B69004F404E9CDCEF502A4C402C634337FBE34E404E9CDCEF502A4C40
18230	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	ул.Красноармейская	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
77092	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Южная	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
18371	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Челюскинцев	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
19023	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Советская	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
9896	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Свердлова	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
19245	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Пролетарская	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
20230	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Первомайская	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
77076	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Орджоникидзе	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
17782	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Мальгина	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
77093	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	М. Жукова	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
19967	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Логинова	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
18165	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Кирова	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
18432	16563	63.005606	63.103791999999999	57.695076	57.644934999999997	Горького	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
20179	49923	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	Фестивальная	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
19991	49923	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	Советская	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
18623	49923	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	Данилова	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
18665	49923	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	Ворошилова	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
18906	49923	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	Вокзальная	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
18342	17774	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	Бабкина	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
18335	17774	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	50 лет Октября	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
17806	17774	60.330593999999998	60.553851999999999	60.710763999999998	60.637805	 Фрунзе	0103000020E610000001000000050000007D2079E7502A4E40D61C2098A3514E407D2079E7502A4E404A969350FA5A4E407F69519FE4464E404A969350FA5A4E407F69519FE4464E40D61C2098A3514E407D2079E7502A4E40D61C2098A3514E40
4129	13	60.586668000000003	60.604391	56.766765999999997	56.763801000000001	улица Эскадронная	0103000020E610000001000000050000000CCEE0EF174B4E4078D32D3BC4614C400CCEE0EF174B4E40A5D7666325624C40957F2DAF5C4D4E40A5D7666325624C40957F2DAF5C4D4E4078D32D3BC4614C400CCEE0EF174B4E4078D32D3BC4614C40
18462	13	60.472869000000003	60.473444000000001	56.917214999999999	56.916747999999998	улица Школьная	0103000020E610000001000000050000006825ADF8863C4E4032569BFF57754C406825ADF8863C4E404833164D67754C40643E20D0993C4E404833164D67754C40643E20D0993C4E4032569BFF57754C406825ADF8863C4E4032569BFF57754C40
3839	13	60.614291000000001	60.640621000000003	56.907848999999999	56.900736999999999	улица Фрезеровщиков	0103000020E61000000100000005000000139D6516A14E4E4009A69A594B734C40139D6516A14E4E40685A626534744C40BF1072DEFF514E40685A626534744C40BF1072DEFF514E4009A69A594B734C40139D6516A14E4E4009A69A594B734C40
4028	13	60.607149	60.615152999999999	56.785319999999999	56.768141999999997	улица Титова	0103000020E610000001000000050000004966F50EB74D4E408E57207A52624C404966F50EB74D4E408672A25D85644C40A5846055BD4E4E408672A25D85644C40A5846055BD4E4E408E57207A52624C404966F50EB74D4E408E57207A52624C40
6389	13	60.502935999999998	60.520076000000003	56.878615000000003	56.871257	улица Соликамская	0103000020E6100000010000000500000093FDF33460404E409EB47059856F4C4093FDF33460404E403563D17476704C409EB7B1D991424E403563D17476704C409EB7B1D991424E409EB47059856F4C4093FDF33460404E409EB47059856F4C40
160	13	60.596063999999998	60.601345999999999	56.816439000000003	56.79965	улица Серова	0103000020E6100000010000000500000056293DD34B4C4E408A1F63EE5A664C4056293DD34B4C4E40E816BA1281684C404BCADDE7F84C4E40E816BA1281684C404BCADDE7F84C4E408A1F63EE5A664C4056293DD34B4C4E408A1F63EE5A664C40
18301	13	60.688851	60.689281999999999	56.841068999999997	56.835071999999997	улица Рассветная	0103000020E61000000100000005000000906802452C584E4014E7A8A3E36A4C40906802452C584E40F7562426A86B4C4059DC7F643A584E40F7562426A86B4C4059DC7F643A584E4014E7A8A3E36A4C40906802452C584E4014E7A8A3E36A4C40
4860	13	60.567129000000001	60.588186	56.828040000000001	56.815970999999998	улица Посадская	0103000020E610000001000000050000007DCEDDAE97484E4001BEDBBC71684C407DCEDDAE97484E40D2E3F736FD694C4087FBC8AD494B4E40D2E3F736FD694C4087FBC8AD494B4E4001BEDBBC71684C407DCEDDAE97484E4001BEDBBC71684C40
7657	13	60.669331	60.689641999999999	56.841999999999999	56.825882	улица Новгородцевой	0103000020E61000000100000005000000789961A3AC554E40732D5A80B6694C40789961A3AC554E40B29DEFA7C66B4C4059F9653046584E40B29DEFA7C66B4C4059F9653046584E40732D5A80B6694C40789961A3AC554E40732D5A80B6694C40
4403	13	60.702092	60.704455000000003	56.756399999999999	56.751632000000001	улица Многостаночников	0103000020E6100000010000000500000041649126DE594E404450357A35604C4041649126DE594E40E25817B7D1604C407940D9942B5A4E40E25817B7D1604C407940D9942B5A4E404450357A35604C4041649126DE594E404450357A35604C40
20376	13	60.611910000000002	60.624459999999999	56.857075999999999	56.822040000000001	улица Мамина-Сибиряка	0103000020E61000000100000005000000350C1F11534E4E407E00529B38694C40350C1F11534E4E40DF1797AAB46D4C4080D4264EEE4F4E40DF1797AAB46D4C4080D4264EEE4F4E407E00529B38694C40350C1F11534E4E407E00529B38694C40
1562	13	60.632015000000003	60.637484999999998	56.804361999999998	56.801926999999999	улица Луганская	0103000020E610000001000000050000006DCA15DEE5504E40C3633F8BA5664C406DCA15DEE5504E4094128255F5664C406458C51B99514E4094128255F5664C406458C51B99514E40C3633F8BA5664C406DCA15DEE5504E40C3633F8BA5664C40
3946	13	60.607455000000002	60.637017999999998	56.796964000000003	56.787897999999998	улица Крестинского	0103000020E610000001000000050000005665DF15C14D4E40BA4A77D7D9644C405665DF15C14D4E40700B96EA02664C404E7B4ACE89514E40700B96EA02664C404E7B4ACE89514E40BA4A77D7D9644C405665DF15C14D4E40BA4A77D7D9644C40
689	13	60.530262999999998	60.552038000000003	56.7881	56.776156999999998	улица Краснолесья	0103000020E61000000100000005000000B1A371A8DF434E40DEC7D11C59634C40B1A371A8DF434E4022FDF675E0644C401B13622EA9464E4022FDF675E0644C401B13622EA9464E40DEC7D11C59634C40B1A371A8DF434E40DEC7D11C59634C40
4195	13	60.610284	60.622394	56.756	56.743765000000003	улица Колхозников	0103000020E61000000100000005000000D3A23EC91D4E4E40697407B1335F4C40D3A23EC91D4E4E4054E3A59BC4604C40029D499BAA4F4E4054E3A59BC4604C40029D499BAA4F4E40697407B1335F4C40D3A23EC91D4E4E40697407B1335F4C40
18391	13	60.568584999999999	60.606493999999998	56.901586999999999	56.887034999999997	улица Кировградская	0103000020E6100000010000000500000082FFAD64C7484E4024B4E55C8A714C4082FFAD64C7484E40D7BFEB3367734C40309C6B98A14D4E40D7BFEB3367734C40309C6B98A14D4E4024B4E55C8A714C4082FFAD64C7484E4024B4E55C8A714C40
1346	13	60.571297999999999	60.608874	56.903596999999998	56.889169000000003	улица Калинина	0103000020E610000001000000050000009622F94A20494E40FBCE2F4AD0714C409622F94A20494E40C1E10511A9734C403EB14E95EF4D4E40C1E10511A9734C403EB14E95EF4D4E40FBCE2F4AD0714C409622F94A20494E40FBCE2F4AD0714C40
3104	13	60.593145	60.613993999999998	56.906443000000003	56.895020000000002	улица Индустрии	0103000020E610000001000000050000009964E42CEC4B4E400AA2EE0390724C409964E42CEC4B4E401558005306744C4059F8FA5A974E4E401558005306744C4059F8FA5A974E4E400AA2EE0390724C409964E42CEC4B4E400AA2EE0390724C40
6049	13	60.581988000000003	60.592902000000002	56.853566999999998	56.849384000000001	улица Гражданская	0103000020E610000001000000050000000D5531957E4A4E4072DF6A9DB86C4C400D5531957E4A4E40F0F8F6AE416D4C40D3DD7536E44B4E40F0F8F6AE416D4C40D3DD7536E44B4E4072DF6A9DB86C4C400D5531957E4A4E4072DF6A9DB86C4C40
1492	13	60.595471000000003	60.610159000000003	56.858350999999999	56.858189000000003	улица Вокзальная	0103000020E61000000100000005000000B45BCB64384C4E40BB641C23D96D4C40B45BCB64384C4E4094BE1072DE6D4C40172EABB0194E4E4094BE1072DE6D4C40172EABB0194E4E40BB641C23D96D4C40B45BCB64384C4E40BB641C23D96D4C40
1828	13	60.773409999999998	60.775340999999997	56.795983	56.787976999999998	улица Белоярская	0103000020E610000001000000050000001E335019FF624E4006802A6EDC644C401E335019FF624E4003965CC5E2654C40BC1FB75F3E634E4003965CC5E2654C40BC1FB75F3E634E4006802A6EDC644C401E335019FF624E4006802A6EDC644C40
19166	13	60.549415000000003	60.560985000000002	56.875590000000003	56.846449999999997	улица Бебеля	0103000020E610000001000000050000004777103B53464E407FD93D79586C4C404777103B53464E40325A475513704C40F645425BCE474E40325A475513704C40F645425BCE474E407FD93D79586C4C404777103B53464E407FD93D79586C4C40
1035	13	60.666347999999999	60.680819999999997	56.827497999999999	56.824827999999997	улица Байкальская	0103000020E61000000100000005000000A4E029E44A554E409C69C2F693694C40A4E029E44A554E40B1C05774EB694C403A3B191C25574E40B1C05774EB694C403A3B191C25574E409C69C2F693694C40A4E029E44A554E409C69C2F693694C40
417	13	60.597582000000003	60.613159000000003	56.841123000000003	56.785305000000001	улица 8-го Марта	0103000020E61000000100000005000000D25625917D4C4E405131CEDF84644C40D25625917D4C4E40EB7420EBA96B4C40C11F7EFE7B4E4E40EB7420EBA96B4C40C11F7EFE7B4E4E405131CEDF84644C40D25625917D4C4E405131CEDF84644C40
77719	13	60.559215000000002	60.587629	56.816464000000003	56.805633999999998	Ясная	0103000020E6100000010000000500000061376C5B94474E40D845D1031F674C4061376C5B94474E40412E71E481684C403197546D374B4E40412E71E481684C403197546D374B4E40D845D1031F674C4061376C5B94474E40D845D1031F674C40
78174	13	60.603763000000001	60.609152999999999	56.856422000000002	56.847709999999999	Якова Свердлова	0103000020E6100000010000000500000076C4211B484D4E40FF3EE3C2816C4C4076C4211B484D4E4097C9703C9F6D4C4051A1BAB9F84D4E4097C9703C9F6D4C4051A1BAB9F84D4E40FF3EE3C2816C4C4076C4211B484D4E40FF3EE3C2816C4C40
78078	13	60.573309999999999	60.576104000000001	56.846159	56.841852000000003	Юмашева	0103000020E61000000100000005000000213CDA3862494E403E096CCEC16B4C40213CDA3862494E40A81B28F04E6C4C40228C9FC6BD494E40A81B28F04E6C4C40228C9FC6BD494E403E096CCEC16B4C40213CDA3862494E403E096CCEC16B4C40
19934	13	60.586668000000003	60.604391	56.766765999999997	56.763801000000001	Эскадронная	0103000020E610000001000000050000000CCEE0EF174B4E4078D32D3BC4614C400CCEE0EF174B4E40A5D7666325624C40957F2DAF5C4D4E40A5D7666325624C40957F2DAF5C4D4E4078D32D3BC4614C400CCEE0EF174B4E4078D32D3BC4614C40
78391	13	60.599010999999997	60.606043999999997	56.747900999999999	56.746194000000003	Энергетиков	0103000020E61000000100000005000000DD787764AC4C4E40583CF548835F4C40DD787764AC4C4E40A6D24F38BB5F4C40F0F78BD9924D4E40A6D24F38BB5F4C40F0F78BD9924D4E40583CF548835F4C40DD787764AC4C4E40583CF548835F4C40
77914	13	60.592390000000002	60.635680000000001	56.811098000000001	56.806638999999997	Щорса	0103000020E610000001000000050000001D3D7E6FD34B4E40CD565EF23F674C401D3D7E6FD34B4E40EEEC2B0FD2674C40535C55F65D514E40EEEC2B0FD2674C40535C55F65D514E40CD565EF23F674C401D3D7E6FD34B4E40CD565EF23F674C40
78398	13	60.641751999999997	60.672421	56.793729999999996	56.757559000000001	Щербакова	0103000020E610000001000000050000004012F6ED24524E402EE57CB1F7604C404012F6ED24524E4052EDD3F198654C4062122EE411564E4052EDD3F198654C4062122EE411564E402EE57CB1F7604C404012F6ED24524E402EE57CB1F7604C40
78380	13	60.611407	60.676670000000001	56.914434	56.860083000000003	Шефская	0103000020E61000000100000005000000D2C5A695424E4E403C6C2233176E4C40D2C5A695424E4E40DC2C5E2C0C754C409817601F9D564E40DC2C5E2C0C754C409817601F9D564E403C6C2233176E4C40D2C5A695424E4E403C6C2233176E4C40
78169	13	60.609107999999999	60.625152	56.849443000000001	56.847735	Шевченко	0103000020E61000000100000005000000B1DD3D40F74D4E4058569A94826C4C40B1DD3D40F74D4E407768588CBA6C4C40B68311FB04504E407768588CBA6C4C40B68311FB04504E4058569A94826C4C40B1DD3D40F74D4E4058569A94826C4C40
78209	13	60.557419000000003	60.591814999999997	56.819232	56.806455999999997	Шаумяна	0103000020E61000000100000005000000A3957B8159474E40DCD440F339674C40A3957B8159474E4018EB1B98DC684C4020240B98C04B4E4018EB1B98DC684C4020240B98C04B4E40DCD440F339674C40A3957B8159474E40DCD440F339674C40
77807	13	60.699801999999998	60.753906999999998	56.754351999999997	56.752555000000001	Черняховского	0103000020E6100000010000000500000073D6A71C93594E407CB8E4B853604C4073D6A71C93594E400AD6389B8E604C40DC9C4A0680604E400AD6389B8E604C40DC9C4A0680604E407CB8E4B853604C4073D6A71C93594E407CB8E4B853604C40
3598	13	60.638500999999998	60.641877999999998	56.895235999999997	56.894925999999998	Черноморский переулок	0103000020E610000001000000050000004DBB9866BA514E40882B67EF8C724C404DBB9866BA514E40D619DF1797724C40CD02ED0E29524E40D619DF1797724C40CD02ED0E29524E40882B67EF8C724C404DBB9866BA514E40882B67EF8C724C40
2375	13	60.560796000000003	60.570256000000001	56.890048999999998	56.884132999999999	Черниговский переулок	0103000020E6100000010000000500000023DDCF29C8474E403D2828452B714C4023DDCF29C8474E40336B2920ED714C40842C0B26FE484E40336B2920ED714C40842C0B26FE484E403D2828452B714C4023DDCF29C8474E403D2828452B714C40
77826	13	60.580173000000002	60.619374999999998	56.858547999999999	56.840846999999997	Челюскинцев	0103000020E61000000100000005000000D882DE1B434A4E4048F8DEDFA06B4C40D882DE1B434A4E40EA059FE6E46D4C40E17A14AE474F4E40EA059FE6E46D4C40E17A14AE474F4E4048F8DEDFA06B4C40D882DE1B434A4E4048F8DEDFA06B4C40
77888	13	60.635041999999999	60.636803	56.866745000000002	56.859842	Чекистов	0103000020E6100000010000000500000010CB660E49514E4016DD7A4D0F6E4C4010CB660E49514E405B7C0A80F16E4C40527FBDC282514E405B7C0A80F16E4C40527FBDC282514E4016DD7A4D0F6E4C4010CB660E49514E4016DD7A4D0F6E4C40
77463	13	60.615718999999999	60.623624	56.819833000000003	56.802079999999997	Чайковского	0103000020E610000001000000050000004E4354E1CF4E4E404963B48EAA664C404E4354E1CF4E4E403E97A949F0684C40178046E9D24F4E403E97A949F0684C40178046E9D24F4E404963B48EAA664C404E4354E1CF4E4E404963B48EAA664C40
78282	13	60.593404999999997	60.630757000000003	56.807841000000003	56.803770999999998	Циолковского	0103000020E610000001000000050000003524EEB1F44B4E40923CD7F7E1664C403524EEB1F44B4E4019AF795567674C408E5C37A5BC504E4019AF795567674C408E5C37A5BC504E40923CD7F7E1664C403524EEB1F44B4E40923CD7F7E1664C40
78345	13	60.623641999999997	60.632086999999999	56.816937000000003	56.804006999999999	Цвиллинга	0103000020E61000000100000005000000BD344580D34F4E40A6608DB3E9664C40BD344580D34F4E4039F2406491684C40069D103AE8504E4039F2406491684C40069D103AE8504E40A6608DB3E9664C40BD344580D34F4E40A6608DB3E9664C40
78311	13	60.590971000000003	60.596091000000001	56.836858999999997	56.823892000000001	Хохрякова	0103000020E6100000010000000500000035F10EF0A44B4E40D0B7054B75694C4035F10EF0A44B4E407F2E1A321E6B4C405038BBB54C4C4E407F2E1A321E6B4C405038BBB54C4C4E40D0B7054B75694C4035F10EF0A44B4E40D0B7054B75694C40
78342	13	60.767822000000002	60.774146000000002	56.792955999999997	56.789228999999999	Хвойная	0103000020E610000001000000050000001D93C5FD47624E400307B47405654C401D93C5FD47624E405F950B957F654C40242A543717634E405F950B957F654C40242A543717634E400307B47405654C401D93C5FD47624E400307B47405654C40
7081	13	60.656018000000003	60.660688999999998	56.838484000000001	56.837992	Фонвизина переулок	0103000020E610000001000000050000002ECBD765F8534E40A2276552436B4C402ECBD765F8534E40111C9771536B4C40D9E9077591544E40111C9771536B4C40D9E9077591544E40A2276552436B4C402ECBD765F8534E40A2276552436B4C40
78166	13	60.575662999999999	60.586578000000003	56.894508000000002	56.888283999999999	Фестивальная	0103000020E6100000010000000500000035423F53AF494E40B0C7444AB3714C4035423F53AF494E405401F73C7F724C40CC46E7FC144B4E405401F73C7F724C40CC46E7FC144B4E40B0C7444AB3714C4035423F53AF494E40B0C7444AB3714C40
77771	13	60.597968999999999	60.613697999999999	56.772882000000003	56.771214999999998	Ферганская	0103000020E61000000100000005000000CB82893F8A4C4E40A297512CB7624C40CB82893F8A4C4E4063D520CCED624C4070CFF3A78D4E4E4063D520CCED624C4070CFF3A78D4E4E40A297512CB7624C40CB82893F8A4C4E40A297512CB7624C40
78161	13	60.487233000000003	60.489587	56.797876000000002	56.795101000000003	Феофанова	0103000020E610000001000000050000001844A4A65D3E4E402A029CDEC5654C401844A4A65D3E4E40B421FFCC20664C40FCC56CC9AA3E4E40B421FFCC20664C40FCC56CC9AA3E4E402A029CDEC5654C401844A4A65D3E4E402A029CDEC5654C40
78124	13	60.630361999999998	60.634107999999998	56.873396999999997	56.857677000000002	Учителей	0103000020E610000001000000050000001152B7B3AF504E4005C4245CC86D4C401152B7B3AF504E4056B60F79CB6F4C40E41071732A514E4056B60F79CB6F4C40E41071732A514E4005C4245CC86D4C401152B7B3AF504E4005C4245CC86D4C40
2036	13	60.805084000000001	60.815280000000001	56.758975	56.754064999999997	Утренний переулок	0103000020E61000000100000005000000354415FE0C674E407407B13385604C40354415FE0C674E40A5BDC11726614C409C8A54185B684E40A5BDC11726614C409C8A54185B684E407407B13385604C40354415FE0C674E407407B13385604C40
78226	13	60.620497999999998	60.641114999999999	56.864452999999997	56.851179999999999	Уральская	0103000020E61000000100000005000000E09D7C7A6C4F4E4030815B77F36C4C40E09D7C7A6C4F4E40ECF65965A66E4C40CEFC6A0E10524E40ECF65965A66E4C40CEFC6A0E10524E4030815B77F36C4C40E09D7C7A6C4F4E4030815B77F36C4C40
78390	13	60.576830999999999	60.592264	56.764387999999997	56.758530999999998	Умельцев	0103000020E61000000100000005000000D4282499D5494E404700378B17614C40D4282499D5494E4038BA4A77D7614C40904C874ECF4B4E4038BA4A77D7614C40904C874ECF4B4E404700378B17614C40D4282499D5494E404700378B17614C40
78372	13	60.627459999999999	60.643270999999999	56.905529000000001	56.900171	Ульяновская	0103000020E610000001000000050000002AC6F99B50504E4060E7A6CD38734C402AC6F99B50504E40304AD05FE8734C408CBB41B456524E40304AD05FE8734C408CBB41B456524E4060E7A6CD38734C402AC6F99B50504E4060E7A6CD38734C40
78319	13	60.601840000000003	60.607337999999999	56.816907	56.800493000000003	Уктусская	0103000020E610000001000000050000005BB6D617094D4E40A6D6FB8D76664C405BB6D617094D4E40CE6F986890684C401CCF6740BD4D4E40CE6F986890684C401CCF6740BD4D4E40A6D6FB8D76664C405BB6D617094D4E40A6D6FB8D76664C40
78194	13	60.613365999999999	60.615071999999998	56.844441000000003	56.839750000000002	Тургенева	0103000020E610000001000000050000003A3DEFC6824E4E40736891ED7C6B4C403A3DEFC6824E4E40663387A4166C4C40B857E6ADBA4E4E40663387A4166C4C40B857E6ADBA4E4E40736891ED7C6B4C403A3DEFC6824E4E40736891ED7C6B4C40
78164	13	60.730685999999999	60.742210999999998	56.784457000000003	56.780960999999998	Трубачева	0103000020E6100000010000000500000091D26C1E875D4E40C939B187F6634C4091D26C1E875D4E40240F441669644C40A0DD21C5005F4E40240F441669644C40A0DD21C5005F4E40C939B187F6634C4091D26C1E875D4E40C939B187F6634C40
6899	13	60.615971000000002	60.619186999999997	56.860934	56.858837999999999	Трамвайный переулок	0103000020E6100000010000000500000068244223D84E4E40F1475167EE6D4C4068244223D84E4E40DA01D715336E4C40DE8D0585414F4E40DA01D715336E4C40DE8D0585414F4E40F1475167EE6D4C4068244223D84E4E40F1475167EE6D4C40
78303	13	60.607149	60.615152999999999	56.785319999999999	56.768141999999997	Титова	0103000020E610000001000000050000004966F50EB74D4E408E57207A52624C404966F50EB74D4E408672A25D85644C40A5846055BD4E4E408672A25D85644C40A5846055BD4E4E408E57207A52624C404966F50EB74D4E408E57207A52624C40
77766	13	60.488554000000001	60.549522000000003	56.892462999999999	56.86027	Техническая	0103000020E610000001000000050000003D2AFEEF883E4E406EDDCD531D6E4C403D2AFEEF883E4E40EDF1423A3C724C405D37A5BC56464E40EDF1423A3C724C405D37A5BC56464E406EDDCD531D6E4C403D2AFEEF883E4E406EDDCD531D6E4C40
3057	13	60.540134999999999	60.558874000000003	56.872731999999999	56.863370000000003	Теплоходный проезд	0103000020E610000001000000050000006536C82423454E407C2C7DE8826E4C406536C82423454E401A16A3AEB56F4C40D84AE82E89474E401A16A3AEB56F4C40D84AE82E89474E407C2C7DE8826E4C406536C82423454E407C2C7DE8826E4C40
78336	13	60.609960999999998	60.642533999999998	56.823661000000001	56.820532999999998	Тверитина	0103000020E61000000100000005000000F06AB933134E4E40F624B03907694C40F06AB933134E4E40CEFE40B96D694C40B648DA8D3E524E40CEFE40B96D694C40B648DA8D3E524E40F624B03907694C40F06AB933134E4E40F624B03907694C40
78120	13	60.530343000000002	60.571738000000003	56.836863999999998	56.835293	Татищева	0103000020E61000000100000005000000CE548847E2434E40F3C98AE1EA6A4C40CE548847E2434E4091990B5C1E6B4C40B3F0F5B52E494E4091990B5C1E6B4C40B3F0F5B52E494E40F3C98AE1EA6A4C40CE548847E2434E40F3C98AE1EA6A4C40
78251	13	60.631844000000001	60.642327000000002	56.905278000000003	56.896062000000001	Таганская	0103000020E610000001000000050000004016A243E0504E401C98DC28B2724C404016A243E0504E40E7E44526E0734C403D2B69C537524E40E7E44526E0734C403D2B69C537524E401C98DC28B2724C404016A243E0504E401C98DC28B2724C40
78321	13	60.598695999999997	60.604284	56.816645999999999	56.799920999999998	Сурикова	0103000020E610000001000000050000007D1F0E12A24C4E401A31B3CF63664C407D1F0E12A24C4E4061342BDB87684C407FBF982D594D4E4061342BDB87684C407FBF982D594D4E401A31B3CF63664C407D1F0E12A24C4E401A31B3CF63664C40
5028	13	60.554049999999997	60.555101000000001	56.839315999999997	56.838735	Субботников площадь	0103000020E61000000100000005000000A52C431CEB464E405A8121AB5B6B4C40A52C431CEB464E403881E9B46E6B4C400B7DB08C0D474E403881E9B46E6B4C400B7DB08C0D474E405A8121AB5B6B4C40A52C431CEB464E405A8121AB5B6B4C40
78288	13	60.655928000000003	60.665377999999997	56.858454000000002	56.836027000000001	Студенческая	0103000020E61000000100000005000000EE43DE72F5534E4058C9C7EE026B4C40EE43DE72F5534E40698F17D2E16D4C402BBD361B2B554E40698F17D2E16D4C402BBD361B2B554E4058C9C7EE026B4C40EE43DE72F5534E4058C9C7EE026B4C40
77474	13	60.491689000000001	60.513716000000002	56.879928999999997	56.870798999999998	Строителей	0103000020E61000000100000005000000C76647AAEF3E4E40DB317557766F4C40C76647AAEF3E4E40A7E67283A1704C404AB72572C1414E40A7E67283A1704C404AB72572C1414E40DB317557766F4C40C76647AAEF3E4E40DB317557766F4C40
78481	13	60.582085999999997	60.601427000000001	56.857283000000002	56.855502000000001	Стрелочников	0103000020E61000000100000005000000CFBA46CB814A4E40D0D4EB16816D4C40CFBA46CB814A4E4059350873BB6D4C4038F7578FFB4C4E4059350873BB6D4C4038F7578FFB4C4E40D0D4EB16816D4C40CFBA46CB814A4E40D0D4EB16816D4C40
78198	13	60.607778000000003	60.615197999999999	56.822882999999997	56.802917999999998	Степана Разина	0103000020E61000000100000005000000399D64ABCB4D4E4053AF5B04C6664C40399D64ABCB4D4E4099B7EA3A54694C404548DDCEBE4E4E4099B7EA3A54694C404548DDCEBE4E4E4053AF5B04C6664C40399D64ABCB4D4E4053AF5B04C6664C40
78374	13	60.615485999999997	60.630164000000001	56.899424000000003	56.886391000000003	Стачек	0103000020E61000000100000005000000AB92C83EC84E4E40003CA24275714C40AB92C83EC84E4E40679E5C5320734C40EB8EC536A9504E40679E5C5320734C40EB8EC536A9504E40003CA24275714C40AB92C83EC84E4E40003CA24275714C40
78364	13	60.591338999999998	60.606934000000003	56.901322	56.889448999999999	Стахановская	0103000020E61000000100000005000000B7EC10FFB04B4E40DE3AFF76D9714C40B7EC10FFB04B4E402995F0845E734C404D6A6803B04D4E402995F0845E734C404D6A6803B04D4E40DE3AFF76D9714C40B7EC10FFB04B4E40DE3AFF76D9714C40
78384	13	60.619304	60.639263999999997	56.900908999999999	56.88344	Старых большевиков	0103000020E6100000010000000500000018247D5A454F4E4037FDD98F14714C4018247D5A454F4E4006D671FC50734C404CC11A67D3514E4006D671FC50734C404CC11A67D3514E4037FDD98F14714C4018247D5A454F4E4037FDD98F14714C40
77723	13	60.619304	60.639263999999997	56.900908999999999	56.88344	Старых Большевиков	0103000020E6100000010000000500000018247D5A454F4E4037FDD98F14714C4018247D5A454F4E4006D671FC50734C404CC11A67D3514E4006D671FC50734C404CC11A67D3514E4037FDD98F14714C4018247D5A454F4E4037FDD98F14714C40
77757	13	60.607329	60.609557000000002	56.808239999999998	56.800773999999997	Союзная	0103000020E61000000100000005000000C974E8F4BC4D4E4059BE2EC37F664C40C974E8F4BC4D4E40D6A8876874674C402106BAF6054E4E40D6A8876874674C402106BAF6054E4E4059BE2EC37F664C40C974E8F4BC4D4E4059BE2EC37F664C40
77486	13	60.585689000000002	60.589381000000003	56.893431999999997	56.890515999999998	Социалистическая	0103000020E6100000010000000500000040506EDBF74A4E404948A46DFC714C4040506EDBF74A4E409599D2FA5B724C4020F12BD6704B4E409599D2FA5B724C4020F12BD6704B4E404948A46DFC714C4040506EDBF74A4E404948A46DFC714C40
78180	13	60.558613000000001	60.560149000000003	56.866489999999999	56.860098000000001	Софьи Перовской	0103000020E610000001000000050000006B0F7BA180474E4071ADF6B0176E4C406B0F7BA180474E40D027F224E96E4C408DF161F6B2474E40D027F224E96E4C408DF161F6B2474E4071ADF6B0176E4C406B0F7BA180474E4071ADF6B0176E4C40
78285	13	60.652892000000001	60.656835000000001	56.851233999999998	56.840783000000002	Софьи Ковалевской	0103000020E61000000100000005000000F7E80DF791534E40320400C79E6B4C40F7E80DF791534E40239F573CF56C4C4020EF552B13544E40239F573CF56C4C4020EF552B13544E40320400C79E6B4C40F7E80DF791534E40320400C79E6B4C40
78218	13	60.624189999999999	60.648445000000002	56.861161000000003	56.849398000000001	Советская	0103000020E61000000100000005000000C03E3A75E54F4E40D7A4DB12B96C4C40C03E3A75E54F4E409BCB0D863A6E4C409B20EA3E00534E409BCB0D863A6E4C409B20EA3E00534E40D7A4DB12B96C4C40C03E3A75E54F4E40D7A4DB12B96C4C40
78298	13	60.624189999999999	60.648445000000002	56.861161000000003	56.849398000000001	Советская	0103000020E61000000100000005000000C03E3A75E54F4E40D7A4DB12B96C4C40C03E3A75E54F4E409BCB0D863A6E4C409B20EA3E00534E409BCB0D863A6E4C409B20EA3E00534E40D7A4DB12B96C4C40C03E3A75E54F4E40D7A4DB12B96C4C40
7893	13	60.682006000000001	60.684899000000001	56.835185000000003	56.828437999999998	Сиреневый бульвар	0103000020E6100000010000000500000080D6FCF84B574E40BF61A2410A6A4C4080D6FCF84B574E400D8E9257E76A4C4014083BC5AA574E400D8E9257E76A4C4014083BC5AA574E40BF61A2410A6A4C4080D6FCF84B574E40BF61A2410A6A4C40
18934	13	60.682006000000001	60.684899000000001	56.835185000000003	56.828437999999998	Сиреневый бульвар	0103000020E6100000010000000500000080D6FCF84B574E40BF61A2410A6A4C4080D6FCF84B574E400D8E9257E76A4C4014083BC5AA574E400D8E9257E76A4C4014083BC5AA574E40BF61A2410A6A4C4080D6FCF84B574E40BF61A2410A6A4C40
18177	13	60.637988	60.791780000000003	56.826065	56.752096000000002	Сибирский тракт	0103000020E61000000100000005000000C79E3D97A9514E40E9B985AE44604C40C79E3D97A9514E4064AF777FBC694C403ED00A0C59654E4064AF777FBC694C403ED00A0C59654E40E9B985AE44604C40C79E3D97A9514E40E9B985AE44604C40
1722	13	60.637988	60.791780000000003	56.826065	56.752096000000002	Сибирский тракт	0103000020E61000000100000005000000C79E3D97A9514E40E9B985AE44604C40C79E3D97A9514E4064AF777FBC694C403ED00A0C59654E4064AF777FBC694C403ED00A0C59654E40E9B985AE44604C40C79E3D97A9514E40E9B985AE44604C40
78320	13	60.596063999999998	60.601345999999999	56.816439000000003	56.79965	Серова	0103000020E6100000010000000500000056293DD34B4C4E408A1F63EE5A664C4056293DD34B4C4E40E816BA1281684C404BCADDE7F84C4E40E816BA1281684C404BCADDE7F84C4E408A1F63EE5A664C4056293DD34B4C4E408A1F63EE5A664C40
78134	13	60.539093000000001	60.562072000000001	56.825502999999998	56.804637999999997	Серафимы Дерябиной	0103000020E610000001000000050000005340DAFF00454E40368FC360FE664C405340DAFF00454E40FCDF1115AA694C40A8FFACF9F1474E40FCDF1115AA694C40A8FFACF9F1474E40368FC360FE664C405340DAFF00454E40368FC360FE664C40
77734	13	60.600240999999997	60.614947000000001	56.768157000000002	56.739026000000003	Селькоровская	0103000020E61000000100000005000000F25B74B2D44C4E4065726A67985E4C40F25B74B2D44C4E40C498F4F752624C40FCE25295B64E4E40C498F4F752624C40FCE25295B64E4E4065726A67985E4C40F25B74B2D44C4E4065726A67985E4C40
6304	13	60.52525	60.543332999999997	56.872334000000002	56.864930000000001	Седова проспект	0103000020E61000000100000005000000AC1C5A643B434E4026AAB706B66E4C40AC1C5A643B434E402D98F8A3A86F4C4035EB8CEF8B454E402D98F8A3A86F4C4035EB8CEF8B454E4026AAB706B66E4C40AC1C5A643B434E4026AAB706B66E4C40
78304	13	60.681170000000002	60.687674000000001	56.876387000000001	56.874930999999997	Севастопольская	0103000020E6100000010000000500000017821C9430574E40D7A02FBDFD6F4C4017821C9430574E40DDD1FF722D704C409E279EB305584E40DDD1FF722D704C409E279EB305584E40D7A02FBDFD6F4C4017821C9430574E40D7A02FBDFD6F4C40
78442	13	60.589111000000003	60.614947000000001	56.770519999999998	56.76793	Санаторная	0103000020E61000000100000005000000605B3FFD674B4E4003CFBD874B624C40605B3FFD674B4E40FB743C66A0624C40FCE25295B64E4E40FB743C66A0624C40FCE25295B64E4E4003CFBD874B624C40605B3FFD674B4E4003CFBD874B624C40
78076	13	60.587466999999997	60.592973999999998	56.838588000000001	56.823543000000001	Сакко и Ванцетти	0103000020E61000000100000005000000573D601E324B4E40C4EC65DB69694C40573D601E324B4E40B66801DA566B4C406CB07092E64B4E40B66801DA566B4C406CB07092E64B4E40C4EC65DB69694C40573D601E324B4E40C4EC65DB69694C40
77316	13	60.641877999999998	60.642381	56.862375999999998	56.859423999999997	Садовая	0103000020E61000000100000005000000CD02ED0E29524E40E1B20A9B016E4C40CD02ED0E29524E407A6D3656626E4C403049658A39524E407A6D3656626E4C403049658A39524E40E1B20A9B016E4C40CD02ED0E29524E40E1B20A9B016E4C40
78155	13	60.630011000000003	60.640414	56.802498999999997	56.800597000000003	Саввы Белых	0103000020E61000000100000005000000658F5033A4504E404B2366F679664C40658F5033A4504E404E098849B8664C4045F30016F9514E404E098849B8664C4045F30016F9514E404B2366F679664C40658F5033A4504E404B2366F679664C40
78571	13	60.478762000000003	60.495865999999999	56.892949999999999	56.891716000000002	Решетская	0103000020E61000000100000005000000A648BE12483D4E40F4A8F8BF23724C40A648BE12483D4E404A7B832F4C724C4063997E89783F4E404A7B832F4C724C4063997E89783F4E40F4A8F8BF23724C40A648BE12483D4E40F4A8F8BF23724C40
516	13	60.568745999999997	60.574424	56.799546999999997	56.794035999999998	Решетникова проезд	0103000020E610000001000000050000008BDD3EABCC484E405FECBDF8A2654C408BDD3EABCC484E40B54E5C8E57664C40CD04C3B986494E40B54E5C8E57664C40CD04C3B986494E405FECBDF8A2654C408BDD3EABCC484E405FECBDF8A2654C40
78368	13	60.568584999999999	60.575394000000003	56.906821999999998	56.901434999999999	Республиканская	0103000020E6100000010000000500000082FFAD64C7484E40213CDA3862734C4082FFAD64C7484E408BA548BE12744C404628B682A6494E408BA548BE12744C404628B682A6494E40213CDA3862734C4082FFAD64C7484E40213CDA3862734C40
78092	13	60.502253000000003	60.579984000000003	56.836011999999997	56.815828000000003	Репина	0103000020E61000000100000005000000B1A888D349404E409F94490D6D684C40B1A888D349404E402288F370026B4C40051A6CEA3C4A4E402288F370026B4C40051A6CEA3C4A4E409F94490D6D684C40B1A888D349404E409F94490D6D684C40
78343	13	60.803018000000002	60.844718	56.775925000000001	56.773144000000002	Реактивная	0103000020E61000000100000005000000B70C384BC9664E40A08CF161F6624C40B70C384BC9664E400C93A98251634C40D82B2CB81F6C4E400C93A98251634C40D82B2CB81F6C4E40A08CF161F6624C40B70C384BC9664E40A08CF161F6624C40
77909	13	60.688851	60.689281999999999	56.841068999999997	56.835071999999997	Рассветная	0103000020E61000000100000005000000906802452C584E4014E7A8A3E36A4C40906802452C584E40F7562426A86B4C4059DC7F643A584E40F7562426A86B4C4059DC7F643A584E4014E7A8A3E36A4C40906802452C584E4014E7A8A3E36A4C40
77834	13	60.812711	60.819375999999998	56.759946999999997	56.758313999999999	Ракетная	0103000020E61000000100000005000000BB0CFFE906684E40AA0CE36E10614C40BB0CFFE906684E40BED87BF145614C404B901150E1684E40BED87BF145614C404B901150E1684E40AA0CE36E10614C40BB0CFFE906684E40AA0CE36E10614C40
78093	13	60.581107000000003	60.604301999999997	56.831246	56.827832999999998	Радищева	0103000020E61000000100000005000000043DD4B6614A4E4058C6866EF6694C40043DD4B6614A4E402577D844666A4C40257497C4594D4E402577D844666A4C40257497C4594D4E4058C6866EF6694C40043DD4B6614A4E4058C6866EF6694C40
6110	13	60.571792000000002	60.574424	56.863512999999998	56.862788999999999	Пугачевский переулок	0103000020E61000000100000005000000A60EF27A30494E409D2CB5DE6F6E4C40A60EF27A30494E40DE550F98876E4C40CD04C3B986494E40DE550F98876E4C40CD04C3B986494E409D2CB5DE6F6E4C40A60EF27A30494E409D2CB5DE6F6E4C40
77779	13	60.628411999999997	60.648085999999999	56.780137000000003	56.767105999999998	Походная	0103000020E61000000100000005000000FC34EECD6F504E405E48878730624C40FC34EECD6F504E4025B37A87DB634C406B7F677BF4524E4025B37A87DB634C406B7F677BF4524E405E48878730624C40FC34EECD6F504E405E48878730624C40
78096	13	60.567129000000001	60.588186	56.828040000000001	56.815970999999998	Посадская	0103000020E610000001000000050000007DCEDDAE97484E4001BEDBBC71684C407DCEDDAE97484E40D2E3F736FD694C4087FBC8AD494B4E40D2E3F736FD694C4087FBC8AD494B4E4001BEDBBC71684C407DCEDDAE97484E4001BEDBBC71684C40
78375	13	60.639820999999998	60.649693999999997	56.905622000000001	56.897266000000002	Ползунова	0103000020E61000000100000005000000A2258FA7E5514E4008E8BE9CD9724C40A2258FA7E5514E40E144F46BEB734C402634492C29534E40E144F46BEB734C402634492C29534E4008E8BE9CD9724C40A2258FA7E5514E4008E8BE9CD9724C40
78545	13	60.578664000000003	60.614083999999998	56.906835999999998	56.893259	Победы	0103000020E61000000100000005000000B0AF75A9114A4E40C8ED974F56724C40B0AF75A9114A4E40F06AB93313744C40997FF44D9A4E4E40F06AB93313744C40997FF44D9A4E4E40C8ED974F56724C40B0AF75A9114A4E40C8ED974F56724C40
78223	13	60.623345999999998	60.630361999999998	56.857677000000002	56.855713000000002	Пионеров	0103000020E61000000100000005000000D40B3ECDC94F4E408BE1EA00886D4C40D40B3ECDC94F4E4005C4245CC86D4C401152B7B3AF504E4005C4245CC86D4C401152B7B3AF504E408BE1EA00886D4C40D40B3ECDC94F4E408BE1EA00886D4C40
78149	13	60.537781000000003	60.566186000000002	56.875349	56.865682999999997	Пехотинцев	0103000020E6100000010000000500000081B4FF01D6444E4001DA56B3CE6E4C4081B4FF01D6444E400CCB9F6F0B704C40FEB968C878484E400CCB9F6F0B704C40FEB968C878484E4001DA56B3CE6E4C4081B4FF01D6444E4001DA56B3CE6E4C40
4633	13	60.581223999999999	60.584377000000003	56.838883000000003	56.838557999999999	Пестеревский переулок	0103000020E610000001000000050000003DD34B8C654A4E404BE658DE556B4C403DD34B8C654A4E40CF15A584606B4C406EC493DDCC4A4E40CF15A584606B4C406EC493DDCC4A4E404BE658DE556B4C403DD34B8C654A4E404BE658DE556B4C40
78241	13	60.605353000000001	60.667983	56.848173000000003	56.841546999999998	Первомайская	0103000020E610000001000000050000008BC404357C4D4E400186E5CFB76B4C408BC404357C4D4E40D42CD0EE906C4C4059A4897780554E40D42CD0EE906C4C4059A4897780554E400186E5CFB76B4C408BC404357C4D4E400186E5CFB76B4C40
78393	13	60.598436	60.610903999999998	56.780926000000001	56.758363000000003	Патриса Лумумбы	0103000020E61000000100000005000000E15F048D994C4E408CBFED0912614C40E15F048D994C4E404D4C1762F5634C406F7F2E1A324E4E404D4C1762F5634C406F7F2E1A324E4E408CBFED0912614C40E15F048D994C4E408CBFED0912614C40
78099	13	60.575842999999999	60.586578000000003	56.822837999999997	56.820577	Пальмиро Тольятти	0103000020E61000000100000005000000B5503239B5494E40C66CC9AA08694C40B5503239B5494E40F9F36DC152694C40CC46E7FC144B4E40F9F36DC152694C40CC46E7FC144B4E40C66CC9AA08694C40B5503239B5494E40C66CC9AA08694C40
78395	13	60.634746	60.654266	56.789363000000002	56.784565000000001	Павлодарская	0103000020E6100000010000000500000027A25F5B3F514E400A4B3CA06C644C4027A25F5B3F514E4013D6C6D809654C403F7100FDBE534E4013D6C6D809654C403F7100FDBE534E400A4B3CA06C644C4027A25F5B3F514E400A4B3CA06C644C40
18309	13	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	Павла Шаманова	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
2586	13	60.588526999999999	60.592174	56.899920999999999	56.886370999999997	Орджоникидзе проспект	0103000020E6100000010000000500000010E84CDA544B4E40B88FDC9A74714C4010E84CDA544B4E40E7FD7F9C30734C4050C58D5BCC4B4E40E7FD7F9C30734C4050C58D5BCC4B4E40B88FDC9A74714C4010E84CDA544B4E40B88FDC9A74714C40
78385	13	60.632157999999997	60.638429000000002	56.800414000000004	56.799128000000003	Онежская	0103000020E61000000100000005000000CFF3A78DEA504E40B1A888D349664C40CFF3A78DEA504E405AA148F773664C40B4E89D0AB8514E405AA148F773664C40B4E89D0AB8514E40B1A888D349664C40CFF3A78DEA504E40B1A888D349664C40
78389	13	60.588149999999999	60.609763000000001	56.757283000000001	56.755575	Окружная	0103000020E610000001000000050000003A92CB7F484B4E406D567DAEB6604C403A92CB7F484B4E408C683BA6EE604C40CAA7C7B60C4E4E408C683BA6EE604C40CAA7C7B60C4E4E406D567DAEB6604C403A92CB7F484B4E406D567DAEB6604C40
77937	13	60.669331	60.689641999999999	56.841999999999999	56.825882	Новгородцевой	0103000020E61000000100000005000000789961A3AC554E40732D5A80B6694C40789961A3AC554E40B29DEFA7C66B4C4059F9653046584E40B29DEFA7C66B4C4059F9653046584E40732D5A80B6694C40789961A3AC554E40732D5A80B6694C40
78349	13	60.471089999999997	60.477072999999997	56.919519000000001	56.916384000000001	Новая	0103000020E610000001000000050000007FBC57AD4C3C4E40F14927124C754C407FBC57AD4C3C4E407B8670CCB2754C40FD6662BA103D4E407B8670CCB2754C40FD6662BA103D4E40F14927124C754C407FBC57AD4C3C4E40F14927124C754C40
78156	13	60.547708	60.557499	56.823365000000003	56.819178000000001	Начдива Васильева	0103000020E61000000100000005000000F8E0B54B1B464E4025CD1FD3DA684C40F8E0B54B1B464E40E5D5390664694C40BF4692205C474E40E5D5390664694C40BF4692205C474E4025CD1FD3DA684C40F8E0B54B1B464E4025CD1FD3DA684C40
78317	13	60.589784999999999	60.633892000000003	56.828206999999999	56.823188000000002	Народной Воли	0103000020E61000000100000005000000EF552B137E4B4E40D63A71395E694C40EF552B137E4B4E40BDA8DDAF026A4C401899805F23514E40BDA8DDAF026A4C401899805F23514E40D63A71395E694C40EF552B137E4B4E40D63A71395E694C40
77811	13	60.528888000000002	60.539084000000003	56.869840000000003	56.864722999999998	Надеждинская	0103000020E61000000100000005000000999F1B9AB2434E40AC8C463EAF6E4C40999F1B9AB2434E405760C8EA566F4C4000E65AB400454E405760C8EA566F4C4000E65AB400454E40AC8C463EAF6E4C40999F1B9AB2434E40AC8C463EAF6E4C40
78306	13	60.716231999999998	60.723787000000002	56.908442999999998	56.899788000000001	Мурзинская	0103000020E61000000100000005000000A12C7C7DAD5B4E40A8AAD0402C734C40A12C7C7DAD5B4E40DBA337DC47744C408E226B0DA55C4E40DBA337DC47744C408E226B0DA55C4E40A8AAD0402C734C40A12C7C7DAD5B4E40A8AAD0402C734C40
78324	13	60.546351000000001	60.554696999999997	56.768886999999999	56.759932999999997	Мостовая	0103000020E6100000010000000500000086915ED4EE454E4059130B7C45614C4086915ED4EE454E40E7A8A3E36A624C403B18B14F00474E40E7A8A3E36A624C403B18B14F00474E4059130B7C45614C4086915ED4EE454E4059130B7C45614C40
5564	13	60.469580999999998	60.485166999999997	56.827818000000001	56.826251999999997	Московский тракт	0103000020E6100000010000000500000057E9EE3A1B3C4E40962023A0C2694C4057E9EE3A1B3C4E402385B2F0F5694C40990CC7F3193E4E402385B2F0F5694C40990CC7F3193E4E40962023A0C2694C4057E9EE3A1B3C4E40962023A0C2694C40
78334	13	60.626894	60.637754999999999	56.846035999999998	56.818384999999999	Мичурина	0103000020E61000000100000005000000810706103E504E40BB44F5D6C0684C40810706103E504E408C9E5BE84A6C4C4024EEB1F4A1514E408C9E5BE84A6C4C4024EEB1F4A1514E40BB44F5D6C0684C40810706103E504E40BB44F5D6C0684C40
78335	13	60.626894	60.637754999999999	56.846035999999998	56.818384999999999	Мичурина	0103000020E61000000100000005000000810706103E504E40BB44F5D6C0684C40810706103E504E408C9E5BE84A6C4C4024EEB1F4A1514E408C9E5BE84A6C4C4024EEB1F4A1514E40BB44F5D6C0684C40810706103E504E40BB44F5D6C0684C40
78347	13	60.645488999999998	60.655065	56.853448999999998	56.832053000000002	Мира	0103000020E61000000100000005000000C07630629F524E40F4C473B6806A4C40C07630629F524E40E6E61BD13D6D4C408BE07F2BD9534E40E6E61BD13D6D4C408BE07F2BD9534E40F4C473B6806A4C40C07630629F524E40F4C473B6806A4C40
78263	13	60.645488999999998	60.655065	56.853448999999998	56.832053000000002	Мира	0103000020E61000000100000005000000C07630629F524E40F4C473B6806A4C40C07630629F524E40E6E61BD13D6D4C408BE07F2BD9534E40E6E61BD13D6D4C408BE07F2BD9534E40F4C473B6806A4C40C07630629F524E40F4C473B6806A4C40
78294	13	60.645488999999998	60.655065	56.853448999999998	56.832053000000002	Мира	0103000020E61000000100000005000000C07630629F524E40F4C473B6806A4C40C07630629F524E40E6E61BD13D6D4C408BE07F2BD9534E40E6E61BD13D6D4C408BE07F2BD9534E40F4C473B6806A4C40C07630629F524E40F4C473B6806A4C40
78499	13	60.645488999999998	60.655065	56.853448999999998	56.832053000000002	Мира	0103000020E61000000100000005000000C07630629F524E40F4C473B6806A4C40C07630629F524E40E6E61BD13D6D4C408BE07F2BD9534E40E6E61BD13D6D4C408BE07F2BD9534E40F4C473B6806A4C40C07630629F524E40F4C473B6806A4C40
78058	13	60.513903999999997	60.544231000000003	56.870947000000001	56.861485999999999	Минометчиков	0103000020E610000001000000050000004CA4349BC7414E401EFB592C456E4C404CA4349BC7414E4050C6F8307B6F4C40153C855CA9454E4050C6F8307B6F4C40153C855CA9454E401EFB592C456E4C404CA4349BC7414E401EFB592C456E4C40
78151	13	60.525483000000001	60.561298999999998	56.827330000000003	56.825463999999997	Металлургов	0103000020E610000001000000050000004FCDE50643434E403E03EACDA8694C404FCDE50643434E40F67F0EF3E5694C40852348A5D8474E40F67F0EF3E5694C40852348A5D8474E403E03EACDA8694C404FCDE50643434E403E03EACDA8694C40
78309	13	60.638258	60.639640999999997	56.864856000000003	56.859625000000001	Менделеева	0103000020E6100000010000000500000087342A70B2514E4079E92631086E4C4087342A70B2514E40ECDFF599B36E4C4022179CC1DF514E40ECDFF599B36E4C4022179CC1DF514E4079E92631086E4C4087342A70B2514E4079E92631086E4C40
78352	13	60.561532999999997	60.613950000000003	56.887472000000002	56.883395999999998	Машиностроителей	0103000020E61000000100000005000000F84F3750E0474E4067B5C01E13714C40F84F3750E0474E40D00EB8AE98714C408AB0E1E9954E4E40D00EB8AE98714C408AB0E1E9954E4E4067B5C01E13714C40F84F3750E0474E4067B5C01E13714C40
78249	13	60.577415000000002	60.664821000000003	56.841783	56.831645000000002	Малышева	0103000020E61000000100000005000000249C16BCE8494E40E370E657736A4C40249C16BCE8494E4015AA9B8BBF6B4C40D658C2DA18554E4015AA9B8BBF6B4C40D658C2DA18554E40E370E657736A4C40249C16BCE8494E40E370E657736A4C40
78331	13	60.614345	60.629589000000003	56.856878999999999	56.817622	Луначарского	0103000020E6100000010000000500000006BB61DBA24E4E40BC3E73D6A7684C4006BB61DBA24E4E4089D00836AE6D4C40EF75525F96504E4089D00836AE6D4C40EF75525F96504E40BC3E73D6A7684C4006BB61DBA24E4E40BC3E73D6A7684C40
78365	13	60.583227000000001	60.612439999999999	56.910881000000003	56.895800999999999	Ломоносова	0103000020E610000001000000050000007592AD2EA74A4E40AF5C6F9BA9724C407592AD2EA74A4E401EC6A4BF97744C409161156F644E4E401EC6A4BF97744C409161156F644E4E40AF5C6F9BA9724C407592AD2EA74A4E40AF5C6F9BA9724C40
78284	13	60.658802000000001	60.66395	56.844056999999999	56.843373	Лодыгина	0103000020E610000001000000050000000B45BA9F53544E402AAA7EA5F36B4C400B45BA9F53544E40DD7A4D0F0A6C4C40F0164850FC544E40DD7A4D0F0A6C4C40F0164850FC544E402AAA7EA5F36B4C400B45BA9F53544E402AAA7EA5F36B4C40
78171	13	60.606178999999997	60.606889000000002	56.848542000000002	56.847036000000003	Лермонтова	0103000020E61000000100000005000000D0420246974D4E407044F7AC6B6C4C40D0420246974D4E4027A435069D6C4C40ADA6EB89AE4D4E4027A435069D6C4C40ADA6EB89AE4D4E407044F7AC6B6C4C40D0420246974D4E407044F7AC6B6C4C40
889	13	60.579984000000003	60.647402999999997	56.843367999999998	56.835760999999998	Ленина проспект	0103000020E61000000100000005000000051A6CEA3C4A4E40D9226937FA6A4C40051A6CEA3C4A4E40183F8D7BF36B4C40882AFC19DE524E40183F8D7BF36B4C40882AFC19DE524E40D9226937FA6A4C40051A6CEA3C4A4E40D9226937FA6A4C40
78400	13	60.671900000000001	60.68656	56.754795999999999	56.745389000000003	Кутузова	0103000020E610000001000000050000005917B7D100564E402AE620E8685F4C405917B7D100564E406893C3279D604C40F25EB532E1574E406893C3279D604C40F25EB532E1574E402AE620E8685F4C405917B7D100564E402AE620E8685F4C40
78011	13	60.501966000000003	60.514550999999997	56.883848	56.878678999999998	Кунарская	0103000020E610000001000000050000001BDA006C40404E404B57B08D78704C401BDA006C40404E40485167EE21714C40E28FA2CEDC414E40485167EE21714C40E28FA2CEDC414E404B57B08D78704C401BDA006C40404E404B57B08D78704C40
77805	13	60.585931000000002	60.658918999999997	56.830993999999997	56.825266999999997	Куйбышева	0103000020E61000000100000005000000365B79C9FF4A4E40E8BB5B59A2694C40365B79C9FF4A4E400B96EA025E6A4C4044DB317557544E400B96EA025E6A4C4044DB317557544E40E8BB5B59A2694C40365B79C9FF4A4E40E8BB5B59A2694C40
78356	13	60.606591999999999	60.612341999999998	56.891888000000002	56.887413000000002	Кузнецова	0103000020E61000000100000005000000F30181CEA44D4E40CB85CABF96714C40F30181CEA44D4E40F1D8CF6229724C40CEFBFF38614E4E40F1D8CF6229724C40CEFBFF38614E4E40CB85CABF96714C40F30181CEA44D4E40CB85CABF96714C40
77493	13	60.607455000000002	60.637017999999998	56.796964000000003	56.787897999999998	Крестинского	0103000020E610000001000000050000005665DF15C14D4E40BA4A77D7D9644C405665DF15C14D4E40700B96EA02664C404E7B4ACE89514E40700B96EA02664C404E7B4ACE89514E40BA4A77D7D9644C405665DF15C14D4E40BA4A77D7D9644C40
78087	13	60.531421000000002	60.571539999999999	56.831944999999997	56.829089000000003	Крауля	0103000020E610000001000000050000002DB4739A05444E40973C9E961F6A4C402DB4739A05444E400D897B2C7D6A4C408C2D043928494E400D897B2C7D6A4C408C2D043928494E40973C9E961F6A4C402DB4739A05444E40973C9E961F6A4C40
78357	13	60.583945999999997	60.590989	56.890732	56.885199999999998	Красных Партизан	0103000020E61000000100000005000000A45016BEBE4A4E40A835CD3B4E714C40A45016BEBE4A4E4016C0948103724C40DBA50D87A54B4E4016C0948103724C40DBA50D87A54B4E40A835CD3B4E714C40A45016BEBE4A4E40A835CD3B4E714C40
78376	13	60.614083999999998	60.643199000000003	56.902206	56.893196000000003	Красных Командиров	0103000020E61000000100000005000000997FF44D9A4E4E4082751C3F54724C40997FF44D9A4E4E40A320787C7B734C40F3E8465854524E40A320787C7B734C40F3E8465854524E4082751C3F54724C40997FF44D9A4E4E4082751C3F54724C40
78397	13	60.614381000000002	60.648004999999998	56.898027999999996	56.886099999999999	Краснофлотцев	0103000020E6100000010000000500000053245F09A44E4E40287E8CB96B714C4053245F09A44E4E403672DD94F2724C407E52EDD3F1524E403672DD94F2724C407E52EDD3F1524E40287E8CB96B714C4053245F09A44E4E40287E8CB96B714C40
78153	13	60.530262999999998	60.552038000000003	56.7881	56.776156999999998	Краснолесья	0103000020E61000000100000005000000B1A371A8DF434E40DEC7D11C59634C40B1A371A8DF434E4022FDF675E0644C401B13622EA9464E4022FDF675E0644C401B13622EA9464E40DEC7D11C59634C40B1A371A8DF434E40DEC7D11C59634C40
77126	13	60.615197999999999	60.621701999999999	56.839419999999997	56.821739999999998	Красноармейская	0103000020E610000001000000050000004548DDCEBE4E4E4053E8BCC62E694C404548DDCEBE4E4E40DDCD531D726B4C40CCED5EEE934F4E40DDCD531D726B4C40CCED5EEE934F4E4053E8BCC62E694C404548DDCEBE4E4E4053E8BCC62E694C40
78147	13	60.543441000000001	60.548651	56.824635999999998	56.824193000000001	Котельникова	0103000020E610000001000000050000001C2785798F454E40CB4BFE277F694C401C2785798F454E40588D25AC8D694C4077F52A323A464E40588D25AC8D694C4077F52A323A464E40CB4BFE277F694C401C2785798F454E40CB4BFE277F694C40
2645	13	60.610661999999998	60.625807000000002	56.943879000000003	56.857075999999999	Космонавтов проспект	0103000020E610000001000000050000007974232C2A4E4E40DF1797AAB46D4C407974232C2A4E4E40CB30EE06D1784C40CF4D9B711A504E40CB30EE06D1784C40CF4D9B711A504E40DF1797AAB46D4C407974232C2A4E4E40DF1797AAB46D4C40
78402	13	60.693010000000001	60.732069000000003	56.752560000000003	56.748823999999999	Косарева	0103000020E6100000010000000500000086E63A8DB4584E40DE3AFF76D95F4C4086E63A8DB4584E408E23D6E253604C402DB5DE6FB45D4E408E23D6E253604C402DB5DE6FB45D4E40DE3AFF76D95F4C4086E63A8DB4584E40DE3AFF76D95F4C40
4234	13	60.632536000000002	60.640135000000001	56.783479999999997	56.776837999999998	Короткий переулок	0103000020E6100000010000000500000076C58CF0F6504E402025766D6F634C4076C58CF0F6504E40F888981249644C40320395F1EF514E40F888981249644C40320395F1EF514E402025766D6F634C4076C58CF0F6504E402025766D6F634C40
4248	13	60.655451999999997	60.657176	56.791950999999997	56.790393000000002	Корейский переулок	0103000020E61000000100000005000000840CE4D9E5534E4061FE0A992B654C40840CE4D9E5534E406A847EA65E654C40A9DBD9571E544E406A847EA65E654C40A9DBD9571E544E4061FE0A992B654C40840CE4D9E5534E4061FE0A992B654C40
78143	13	60.653807999999998	60.665638999999999	56.857436	56.827286000000001	Комсомольская	0103000020E610000001000000050000007CEE04FBAF534E402638F581E4694C407CEE04FBAF534E40DF347D76C06D4C4098F8A3A833554E40DF347D76C06D4C4098F8A3A833554E402638F581E4694C407CEE04FBAF534E402638F581E4694C40
78371	13	60.57808	60.605415999999998	56.915120999999999	56.904584999999997	Коммунистическая	0103000020E61000000100000005000000603C8386FE494E40E0B9F770C9734C40603C8386FE494E40007157AF22754C40D13C80457E4D4E40007157AF22754C40D13C80457E4D4E40E0B9F770C9734C40603C8386FE494E40E0B9F770C9734C40
78363	13	60.569285000000001	60.572232	56.760672999999997	56.760367000000002	Комбинатская	0103000020E610000001000000050000003B8DB454DE484E4094FAB2B453614C403B8DB454DE484E40A0F99CBB5D614C40C2DCEEE53E494E40A0F99CBB5D614C40C2DCEEE53E494E4094FAB2B453614C403B8DB454DE484E4094FAB2B453614C40
78396	13	60.610284	60.622394	56.756	56.743765000000003	Колхозников	0103000020E61000000100000005000000D3A23EC91D4E4E40697407B1335F4C40D3A23EC91D4E4E4054E3A59BC4604C40029D499BAA4F4E4054E3A59BC4604C40029D499BAA4F4E40697407B1335F4C40D3A23EC91D4E4E40697407B1335F4C40
18224	13	60.735402000000001	60.740729000000002	56.876927999999999	56.876722000000001	Коломенский переулок	0103000020E61000000100000005000000DDB419A7215E4E4084D72E6D38704C40DDB419A7215E4E402D793C2D3F704C4072193735D05E4E402D793C2D3F704C4072193735D05E4E4084D72E6D38704C40DDB419A7215E4E4084D72E6D38704C40
78177	13	60.555568000000001	60.579498999999998	56.852637000000001	56.845382000000001	Колмогорова	0103000020E61000000100000005000000215A2BDA1C474E404450357A356C4C40215A2BDA1C474E40062E8F35236D4C404888F2052D4A4E40062E8F35236D4C404888F2052D4A4E404450357A356C4C40215A2BDA1C474E404450357A356C4C40
78083	13	60.528376000000002	60.571449999999999	56.834363000000003	56.832555999999997	Ключевская	0103000020E61000000100000005000000E3FE23D3A1434E40560BEC31916A4C40E3FE23D3A1434E4009FF2268CC6A4C404CA60A4625494E4009FF2268CC6A4C404CA60A4625494E40560BEC31916A4C40E3FE23D3A1434E40560BEC31916A4C40
78359	13	60.568584999999999	60.606493999999998	56.901586999999999	56.887034999999997	Кировградская	0103000020E6100000010000000500000082FFAD64C7484E4024B4E55C8A714C4082FFAD64C7484E40D7BFEB3367734C40309C6B98A14D4E40D7BFEB3367734C40309C6B98A14D4E4024B4E55C8A714C4082FFAD64C7484E4024B4E55C8A714C40
78373	13	60.617291000000002	60.642417000000002	56.906270999999997	56.897753000000002	Каширская	0103000020E61000000100000005000000BD8E3864034F4E406571FF91E9724C40BD8E3864034F4E40172829B000744C407DB262B83A524E40172829B000744C407DB262B83A524E406571FF91E9724C40BD8E3864034F4E406571FF91E9724C40
77482	13	60.607014999999997	60.632382999999997	56.832664000000001	56.830038999999999	Карла Маркса	0103000020E610000001000000050000003997E2AAB24D4E40C8B3CBB73E6A4C403997E2AAB24D4E403D47E4BB946A4C40EFC517EDF1504E403D47E4BB946A4C40EFC517EDF1504E40C8B3CBB73E6A4C403997E2AAB24D4E40C8B3CBB73E6A4C40
78316	13	60.713572999999997	60.719375999999997	56.807234999999999	56.802263000000004	Каменотесов	0103000020E6100000010000000500000080272D5C565B4E403BE5D18DB0664C4080272D5C565B4E40E197FA7953674C407EC34483145C4E40E197FA7953674C407EC34483145C4E403BE5D18DB0664C4080272D5C565B4E403BE5D18DB0664C40
78178	13	60.571297999999999	60.608874	56.903596999999998	56.889169000000003	Калинина	0103000020E610000001000000050000009622F94A20494E40FBCE2F4AD0714C409622F94A20494E40C1E10511A9734C403EB14E95EF4D4E40C1E10511A9734C403EB14E95EF4D4E40FBCE2F4AD0714C409622F94A20494E40FBCE2F4AD0714C40
78296	13	60.628968999999998	60.644986000000003	56.860427999999999	56.858370999999998	Июльская	0103000020E610000001000000050000005299620E82504E40DB6AD619DF6D4C405299620E82504E4006483481226E4C405E30B8E68E524E4006483481226E4C405E30B8E68E524E40DB6AD619DF6D4C405299620E82504E40DB6AD619DF6D4C40
78403	13	60.701886000000002	60.710689000000002	56.761699	56.744391999999998	Инженерная	0103000020E6100000010000000500000098C28366D7594E40B7B3AF3C485F4C4098C28366D7594E40AD32535A7F614C4040506EDBF75A4E40AD32535A7F614C4040506EDBF75A4E40B7B3AF3C485F4C4098C28366D7594E40B7B3AF3C485F4C40
78353	13	60.593558000000002	60.6143	56.900804999999998	56.886332000000003	Ильича	0103000020E61000000100000005000000BC2363B5F94B4E40FBB2B45373714C40BC2363B5F94B4E40618907944D734C4066F7E461A14E4E40618907944D734C4066F7E461A14E4E40FBB2B45373714C40BC2363B5F94B4E40FBB2B45373714C40
78369	13	60.575142	60.608460999999998	56.910826999999998	56.897959	Избирателей	0103000020E610000001000000050000002C47C8409E494E400E130D52F0724C402C47C8409E494E402AA8A8FA95744C401BF2CF0CE24D4E402AA8A8FA95744C401BF2CF0CE24D4E400E130D52F0724C402C47C8409E494E400E130D52F0724C40
78382	13	60.640431999999997	60.651625000000003	56.903224000000002	56.897758000000003	Замятина	0103000020E61000000100000005000000EBA7FFACF9514E4077DCF0BBE9724C40EBA7FFACF9514E402D7B12D89C734C40C520B07268534E402D7B12D89C734C40C520B07268534E4077DCF0BBE9724C40EBA7FFACF9514E4077DCF0BBE9724C40
78570	13	60.592497999999999	60.613213000000002	56.864609999999999	56.859872000000003	Завокзальная	0103000020E61000000100000005000000037976F9D64B4E40815F2349106E4C40037976F9D64B4E40B4E55C8AAB6E4C40B43D7AC37D4E4E40B4E55C8AAB6E4C40B43D7AC37D4E4E40815F2349106E4C40037976F9D64B4E40815F2349106E4C40
78127	13	60.550502000000002	60.555092000000002	56.839553000000002	56.821277000000002	Заводская	0103000020E61000000100000005000000F9307BD976464E407FFACF9A1F694C40F9307BD976464E401D210379766B4C40B82231410D474E401D210379766B4C40B82231410D474E407FFACF9A1F694C40F9307BD976464E407FFACF9A1F694C40
19232	13	60.649073999999999	60.65025	56.782741000000001	56.781275999999998	Жуковского площадь	0103000020E610000001000000050000008A5759DB14534E4029931ADA00644C408A5759DB14534E40821E6ADB30644C40AC1C5A643B534E40821E6ADB30644C40AC1C5A643B534E4029931ADA00644C408A5759DB14534E4029931ADA00644C40
77476	13	60.61748	60.619205000000001	56.862060999999997	56.860304999999997	Железнодорожников	0103000020E6100000010000000500000090F7AA95094F4E40EACA67791E6E4C4090F7AA95094F4E401A14CD03586E4C408542041C424F4E401A14CD03586E4C408542041C424F4E40EACA67791E6E4C4090F7AA95094F4E40EACA67791E6E4C40
77906	13	60.598768	60.599487000000003	56.850993000000003	56.848429000000003	Еремина	0103000020E6100000010000000500000017F2086EA44C4E402FFD4B52996C4C4017F2086EA44C4E40FE0FB056ED6C4C4047B071FDBB4C4E40FE0FB056ED6C4C4047B071FDBB4C4E402FFD4B52996C4C4017F2086EA44C4E402FFD4B52996C4C40
18772	13	60.580396999999998	60.595965	56.797303999999997	56.795658000000003	Денисова-Уральского бульвар	0103000020E6100000010000000500000027D9EA724A4A4E408066101FD8654C4027D9EA724A4A4E40287CB60E0E664C40C347C494484C4E40287CB60E0E664C40C347C494484C4E408066101FD8654C4027D9EA724A4A4E408066101FD8654C40
78332	13	60.601022999999998	60.638015000000003	56.826079	56.822054999999999	Декабристов	0103000020E6100000010000000500000068925852EE4C4E40B341261939694C4068925852EE4C4E40C974E8F4BC694C40C1ADBB79AA514E40C974E8F4BC694C40C1ADBB79AA514E40B341261939694C4068925852EE4C4E40B341261939694C40
78300	13	60.652558999999997	60.653897999999998	56.86862	56.857405999999997	Данилы Зверева	0103000020E61000000100000005000000F0DAA50D87534E4074B2D47ABF6D4C40F0DAA50D87534E406553AEF02E6F4C40BC75FEEDB2534E406553AEF02E6F4C40BC75FEEDB2534E4074B2D47ABF6D4C40F0DAA50D87534E4074B2D47ABF6D4C40
78381	13	60.636884000000002	60.646208000000001	56.904310000000002	56.896174999999999	Даниловская	0103000020E610000001000000050000003FAC376A85514E40143FC6DCB5724C403FAC376A85514E400FB9196EC0734C40F03499F1B6524E400FB9196EC0734C40F03499F1B6524E40143FC6DCB5724C403FAC376A85514E40143FC6DCB5724C40
78323	13	60.557921999999998	60.573991999999997	56.810935999999998	56.798591000000002	Громова	0103000020E6100000010000000500000005DCF3FC69474E40A2F0D93A38664C4005DCF3FC69474E40149337C0CC674C403315E29178494E40149337C0CC674C403315E29178494E40A2F0D93A38664C4005DCF3FC69474E40A2F0D93A38664C40
78313	13	60.687306	60.712314999999997	56.756197	56.746454999999997	Грибоедова	0103000020E610000001000000050000001B2C9CA4F9574E40C47762D68B5F4C401B2C9CA4F9574E40AA2A3410CB604C40A1B94E232D5B4E40AA2A3410CB604C40A1B94E232D5B4E40C47762D68B5F4C401B2C9CA4F9574E40C47762D68B5F4C40
78022	13	60.560949000000001	60.575358000000001	56.856062999999999	56.846415	Готвальда	0103000020E61000000100000005000000A9DC442DCD474E4003ECA353576C4C40A9DC442DCD474E406728EE78936D4C40F9BEB854A5494E406728EE78936D4C40F9BEB854A5494E4003ECA353576C4C40A9DC442DCD474E4003ECA353576C4C40
78327	13	60.565845000000003	60.570281999999999	56.763100000000001	56.754485000000003	Городская	0103000020E6100000010000000500000075CDE49B6D484E404A29E8F692604C4075CDE49B6D484E40EFC9C342AD614C40ADBF2500FF484E40EFC9C342AD614C40ADBF2500FF484E404A29E8F692604C4075CDE49B6D484E404A29E8F692604C40
1058	13	60.820086000000003	60.826535999999997	56.770470000000003	56.764426999999998	Горнистов проезд	0103000020E6100000010000000500000028F4FA93F8684E40F69672BED8614C4028F4FA93F8684E404A46CEC29E624C40BB7B80EECB694E404A46CEC29E624C40BB7B80EECB694E40F69672BED8614C4028F4FA93F8684E40F69672BED8614C40
18223	13	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	Главная	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
78305	13	60.659610999999998	60.663347999999999	56.787039999999998	56.784816999999997	Гаршина	0103000020E610000001000000050000007A8A1C226E544E40232C2AE274644C407A8A1C226E544E4069520ABABD644C40FAEE5696E8544E4069520ABABD644C40FAEE5696E8544E40232C2AE274644C407A8A1C226E544E40232C2AE274644C40
4670	13	60.574216999999997	60.580477999999999	56.841738999999997	56.839739999999999	Гаринский переулок	0103000020E6100000010000000500000053E751F17F494E404F92AE997C6B4C4053E751F17F494E404562821ABE6B4C401406651A4D4A4E404562821ABE6B4C401406651A4D4A4E404F92AE997C6B4C4053E751F17F494E404F92AE997C6B4C40
78308	13	60.670211000000002	60.751517999999997	56.845416	56.840930999999998	Высоцкого	0103000020E61000000100000005000000B1355B79C9554E40A69883A0A36B4C40B1355B79C9554E40F0C16B97366C4C407B2DE8BD31604E40F0C16B97366C4C407B2DE8BD31604E40A69883A0A36B4C40B1355B79C9554E40A69883A0A36B4C40
78167	13	60.614839000000003	60.640431999999997	56.857416000000001	56.818021000000002	Восточная	0103000020E6100000010000000500000016A75A0BB34E4E407A3881E9B4684C4016A75A0BB34E4E409888B7CEBF6D4C40EBA7FFACF9514E409888B7CEBF6D4C40EBA7FFACF9514E407A3881E9B4684C4016A75A0BB34E4E407A3881E9B4684C40
78383	13	60.583263000000002	60.610894999999999	56.910398999999998	56.899793000000003	Восстания	0103000020E61000000100000005000000C2FBAA5CA84A4E40BA15C26A2C734C40C2FBAA5CA84A4E40D2A755F487744C401C25AFCE314E4E40D2A755F487744C401C25AFCE314E4E40BA15C26A2C734C40C2FBAA5CA84A4E40BA15C26A2C734C40
78322	13	60.551526000000003	60.595345000000002	56.813896999999997	56.798191000000003	Волгоградская	0103000020E6100000010000000500000065726A6798464E40147B681F2B664C4065726A6798464E4000A8E2C62D684C40276BD443344C4E4000A8E2C62D684C40276BD443344C4E40147B681F2B664C4065726A6798464E40147B681F2B664C40
78562	13	60.595471000000003	60.610159000000003	56.858350999999999	56.858189000000003	Вокзальная	0103000020E61000000100000005000000B45BCB64384C4E40BB641C23D96D4C40B45BCB64384C4E4094BE1072DE6D4C40172EABB0194E4E4094BE1072DE6D4C40172EABB0194E4E40BB641C23D96D4C40B45BCB64384C4E40BB641C23D96D4C40
4994	13	60.570022000000002	60.579984000000003	56.839848000000003	56.835760999999998	Верх-Исетский бульвар	0103000020E6100000010000000500000011001C7BF6484E40D9226937FA6A4C4011001C7BF6484E4036CEA623806B4C40051A6CEA3C4A4E4036CEA623806B4C40051A6CEA3C4A4E40D9226937FA6A4C4011001C7BF6484E40D9226937FA6A4C40
18582	13	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	Верстовая	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
78228	13	60.594042999999999	60.598292000000001	56.839198000000003	56.826552	Вайнера	0103000020E6100000010000000500000078B5DC99094C4E40C138B874CC694C4078B5DC99094C4E402F6F0ED76A6B4C40AEBA0ED5944C4E402F6F0ED76A6B4C40AEBA0ED5944C4E40C138B874CC694C4078B5DC99094C4E40C138B874CC694C40
78193	13	60.595677999999999	60.605451000000002	56.852381000000001	56.850949	Братьев Быковых	0103000020E610000001000000050000002D793C2D3F4C4E402EC896E5EB6C4C402D793C2D3F4C4E40AB5D13D21A6D4C404E2A1A6B7F4D4E40AB5D13D21A6D4C404E2A1A6B7F4D4E402EC896E5EB6C4C402D793C2D3F4C4E402EC896E5EB6C4C40
78401	13	60.697375999999998	60.700313999999999	56.755949999999999	56.749417000000001	Бородина	0103000020E61000000100000005000000F581E49D43594E40810871E5EC5F4C40F581E49D43594E40A2B437F8C2604C4029779FE3A3594E40A2B437F8C2604C4029779FE3A3594E40810871E5EC5F4C40F581E49D43594E40810871E5EC5F4C40
78090	13	60.497689999999999	60.499988999999999	56.848503000000001	56.845953000000002	Большой Конный Полуостров	0103000020E61000000100000005000000EBC5504EB43F4E40FF791A30486C4C40EBC5504EB43F4E4069C70DBF9B6C4C400CAEB9A3FF3F4E4069C70DBF9B6C4C400CAEB9A3FF3F4E40FF791A30486C4C40EBC5504EB43F4E40FF791A30486C4C40
78314	13	60.588113999999997	60.639578	56.821173000000002	56.815843000000001	Большакова	0103000020E61000000100000005000000ED28CE51474B4E40D4D51D8B6D684C40ED28CE51474B4E40DAAD65321C694C40DC9E20B1DD514E40DAAD65321C694C40DC9E20B1DD514E40D4D51D8B6D684C40ED28CE51474B4E40D4D51D8B6D684C40
78214	13	60.630541000000001	60.675296000000003	56.867640999999999	56.843870000000003	Блюхера	0103000020E61000000100000005000000C1E44691B5504E40AB09A2EE036C4C40C1E44691B5504E4099D53BDC0E6F4C40508F6D1970564E4099D53BDC0E6F4C40508F6D1970564E40AB09A2EE036C4C40C1E44691B5504E40AB09A2EE036C4C40
78392	13	60.600240999999997	60.625978000000003	56.756265999999997	56.738788999999997	Бисертская	0103000020E61000000100000005000000F25B74B2D44C4E4080D250A3905E4C40F25B74B2D44C4E40D2890453CD604C40FC010F0C20504E40D2890453CD604C40FC010F0C20504E4080D250A3905E4C40F25B74B2D44C4E4080D250A3905E4C40
77822	13	60.505316000000001	60.517929000000002	56.889341000000002	56.880808999999999	Билимбаевская	0103000020E61000000100000005000000A112D731AE404E40E0826C59BE704C40A112D731AE404E40F8FE06EDD5714C4033535A7F4B424E40F8FE06EDD5714C4033535A7F4B424E40E0826C59BE704C40A112D731AE404E40E0826C59BE704C40
77480	13	60.694527999999998	60.698607000000003	56.834929000000002	56.831294999999997	Бетонщиков	0103000020E610000001000000050000000114234BE6584E40062AE3DF676A4C400114234BE6584E40B2BD16F4DE6A4C40DBE044F46B594E40B2BD16F4DE6A4C40DBE044F46B594E40062AE3DF676A4C400114234BE6584E40062AE3DF676A4C40
78341	13	60.773409999999998	60.775340999999997	56.795983	56.787976999999998	Белоярская	0103000020E610000001000000050000001E335019FF624E4006802A6EDC644C401E335019FF624E4003965CC5E2654C40BC1FB75F3E634E4003965CC5E2654C40BC1FB75F3E634E4006802A6EDC644C401E335019FF624E4006802A6EDC644C40
78118	13	60.558011	60.574081999999997	56.824945999999997	56.812133000000003	Белореченская	0103000020E6100000010000000500000075E789E76C474E404E8061F9F3674C4075E789E76C474E40A67B9DD497694C40739CDB847B494E40A67B9DD497694C40739CDB847B494E404E8061F9F3674C4075E789E76C474E404E8061F9F3674C40
77721	13	60.613940999999997	60.641796999999997	56.835431	56.793661	Белинского	0103000020E610000001000000050000003656629E954E4E402A8E03AF96654C403656629E954E4E4044882B67EF6A4C40E0D5726726524E4044882B67EF6A4C40E0D5726726524E402A8E03AF96654C403656629E954E4E402A8E03AF96654C40
20141	13	60.549415000000003	60.560985000000002	56.875590000000003	56.846449999999997	Бебеля	0103000020E610000001000000050000004777103B53464E407FD93D79586C4C404777103B53464E40325A475513704C40F645425BCE474E40325A475513704C40F645425BCE474E407FD93D79586C4C404777103B53464E407FD93D79586C4C40
78182	13	60.549415000000003	60.560985000000002	56.875590000000003	56.846449999999997	Бебеля	0103000020E610000001000000050000004777103B53464E407FD93D79586C4C404777103B53464E40325A475513704C40F645425BCE474E40325A475513704C40F645425BCE474E407FD93D79586C4C404777103B53464E407FD93D79586C4C40
3882	13	60.801921999999998	60.806404999999998	56.752087000000003	56.750404000000003	Бахчиванджи площадь	0103000020E61000000100000005000000B1F84D61A5664E40D064FF3C0D604C40B1F84D61A5664E40965F066344604C405A2A6F4738674E40965F066344604C405A2A6F4738674E40D064FF3C0D604C40B1F84D61A5664E40D064FF3C0D604C40
78379	13	60.613860000000003	60.641537	56.896883000000003	56.887104000000001	Баумана	0103000020E610000001000000050000004A29E8F6924E4E404D13B69F8C714C404A29E8F6924E4E4050ABE80FCD724C40441669E21D524E4050ABE80FCD724C40441669E21D524E404D13B69F8C714C404A29E8F6924E4E404D13B69F8C714C40
78362	13	60.571216999999997	60.611460999999998	56.914344999999997	56.892339999999997	Бакинских Комиссаров	0103000020E61000000100000005000000A9F57EA31D494E40D174763238724C40A9F57EA31D494E406C21C84109754C40C5E3A25A444E4E406C21C84109754C40C5E3A25A444E4E40D174763238724C40A9F57EA31D494E40D174763238724C40
78297	13	60.666347999999999	60.680819999999997	56.827497999999999	56.824827999999997	Байкальская	0103000020E61000000100000005000000A4E029E44A554E409C69C2F693694C40A4E029E44A554E40B1C05774EB694C403A3B191C25574E40B1C05774EB694C403A3B191C25574E409C69C2F693694C40A4E029E44A554E409C69C2F693694C40
78329	13	60.622653999999997	60.632849999999998	56.849142000000001	56.822862999999998	Бажова	0103000020E610000001000000050000009E5C5320B34F4E40520B259353694C409E5C5320B34F4E407CD45FAFB06C4C4005A3923A01514E407CD45FAFB06C4C4005A3923A01514E40520B259353694C409E5C5320B34F4E40520B259353694C40
78179	13	60.581583000000002	60.611685999999999	56.870764999999999	56.864579999999997	Артинская	0103000020E610000001000000050000006D74CE4F714A4E404963B48EAA6E4C406D74CE4F714A4E402FC03E3A756F4C40E5B512BA4B4E4E402FC03E3A756F4C40E5B512BA4B4E4E404963B48EAA6E4C406D74CE4F714A4E404963B48EAA6E4C40
78388	13	60.606655000000003	60.613339000000003	56.768279999999997	56.764457	Аптекарская	0103000020E610000001000000050000003A7AFCDEA64D4E4061191BBAD9614C403A7AFCDEA64D4E40DF15C1FF56624C40412E71E4814E4E40DF15C1FF56624C40412E71E4814E4E4061191BBAD9614C403A7AFCDEA64D4E4061191BBAD9614C40
77711	13	60.587466999999997	60.597195999999997	56.840611000000003	56.838588000000001	Антона Валека	0103000020E61000000100000005000000573D601E324B4E40B66801DA566B4C40573D601E324B4E4035D42824996B4C40A8A624EB704C4E4035D42824996B4C40A8A624EB704C4E40B66801DA566B4C40573D601E324B4E40B66801DA566B4C40
78006	13	60.491689000000001	60.52216	56.889384999999997	56.879928999999997	Ангарская	0103000020E61000000100000005000000C76647AAEF3E4E40A7E67283A1704C40C76647AAEF3E4E40C746205ED7714C40C2A38D23D6424E40C746205ED7714C40C2A38D23D6424E40A7E67283A1704C40C76647AAEF3E4E40A7E67283A1704C40
77495	13	60.695417999999997	60.735284999999998	56.761451999999998	56.753971999999997	Альпинистов	0103000020E610000001000000050000005D86FF7403594E40C30C8D2782604C405D86FF7403594E40A5BC564277614C40A31EA2D11D5E4E40A5BC564277614C40A31EA2D11D5E4E40C30C8D2782604C405D86FF7403594E40C30C8D2782604C40
77679	13	60.486145999999998	60.495857000000001	56.887354000000002	56.883253000000003	Акулова	0103000020E61000000100000005000000658A39083A3E4E40058C2E6F0E714C40658A39083A3E4E40C6FCDCD094714C40103FFF3D783F4E40C6FCDCD094714C40103FFF3D783F4E40058C2E6F0E714C40658A39083A3E4E40058C2E6F0E714C40
78292	13	60.642687000000002	60.660949000000002	56.852179	56.850062999999999	Академическая	0103000020E610000001000000050000003D484F9143524E40134548DDCE6C4C403D484F9143524E4043AB9333146D4C4076A911FA99544E4043AB9333146D4C4076A911FA99544E40134548DDCE6C4C403D484F9143524E40134548DDCE6C4C40
78330	13	60.578896999999998	60.582678999999999	56.793385000000001	56.790398000000003	Академика Постовского	0103000020E610000001000000050000005260014C194A4E407369FCC22B654C405260014C194A4E408811C2A38D654C407288B839954A4E408811C2A38D654C407288B839954A4E407369FCC22B654C405260014C194A4E407369FCC22B654C40
77933	13	60.546287999999997	60.580396999999998	56.810108	56.797303999999997	Академика Бардина	0103000020E610000001000000050000003F19E3C3EC454E40287CB60E0E664C403F19E3C3EC454E402E1D739EB1674C4027D9EA724A4A4E402E1D739EB1674C4027D9EA724A4A4E40287CB60E0E664C403F19E3C3EC454E40287CB60E0E664C40
78172	13	60.597582000000003	60.613159000000003	56.841123000000003	56.785305000000001	8-го Марта	0103000020E61000000100000005000000D25625917D4C4E405131CEDF84644C40D25625917D4C4E40EB7420EBA96B4C40C11F7EFE7B4E4E40EB7420EBA96B4C40C11F7EFE7B4E4E405131CEDF84644C40D25625917D4C4E405131CEDF84644C40
18655	13	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	40летия Комсомола	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
78350	13	60.561532999999997	60.613950000000003	56.887472000000002	56.883395999999998	 Машиностроителей	0103000020E61000000100000005000000F84F3750E0474E4067B5C01E13714C40F84F3750E0474E40D00EB8AE98714C408AB0E1E9954E4E40D00EB8AE98714C408AB0E1E9954E4E4067B5C01E13714C40F84F3750E0474E4067B5C01E13714C40
78310	13	60.642687000000002	60.660949000000002	56.852179	56.850062999999999	 Академическая	0103000020E610000001000000050000003D484F9143524E40134548DDCE6C4C403D484F9143524E4043AB9333146D4C4076A911FA99544E4043AB9333146D4C4076A911FA99544E40134548DDCE6C4C403D484F9143524E40134548DDCE6C4C40
17953	49870	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	Уральских Танкистов	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
19813	49870	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	Пролетарская	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
18668	49870	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	Почтовая	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
78250	61129	60.002439000000003	60.105044999999997	59.949162999999999	59.888649999999998	Советская	0103000020E61000000100000005000000139ED0EB4F004E4092CB7F48BFF14D40139ED0EB4F004E4060C9552C7EF94D40DDCD531D720D4E4060C9552C7EF94D40DDCD531D720D4E4092CB7F48BFF14D40139ED0EB4F004E4092CB7F48BFF14D40
77310	61129	60.002439000000003	60.105044999999997	59.949162999999999	59.888649999999998	Молодежная	0103000020E61000000100000005000000139ED0EB4F004E4092CB7F48BFF14D40139ED0EB4F004E4060C9552C7EF94D40DDCD531D720D4E4060C9552C7EF94D40DDCD531D720D4E4092CB7F48BFF14D40139ED0EB4F004E4092CB7F48BFF14D40
78070	61129	60.002439000000003	60.105044999999997	59.949162999999999	59.888649999999998	Карпинского	0103000020E61000000100000005000000139ED0EB4F004E4092CB7F48BFF14D40139ED0EB4F004E4060C9552C7EF94D40DDCD531D720D4E4060C9552C7EF94D40DDCD531D720D4E4092CB7F48BFF14D40139ED0EB4F004E4092CB7F48BFF14D40
20261	50206	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	Сенянского	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
20046	50137	59.789143000000003	59.877977999999999	58.377597999999999	58.343620999999999	Первомайская	0103000020E61000000100000005000000056F48A302E54D40029CDEC5FB2B4D40056F48A302E54D407B849A2155304D40C24D469561F04D407B849A2155304D40C24D469561F04D40029CDEC5FB2B4D40056F48A302E54D40029CDEC5FB2B4D40
20175	50137	59.789143000000003	59.877977999999999	58.377597999999999	58.343620999999999	Машиностроителей	0103000020E61000000100000005000000056F48A302E54D40029CDEC5FB2B4D40056F48A302E54D407B849A2155304D40C24D469561F04D407B849A2155304D40C24D469561F04D40029CDEC5FB2B4D40056F48A302E54D40029CDEC5FB2B4D40
18247	49904	60.511738999999999	60.597915	58.074283999999999	58.018836	Энгельса	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
20358	49904	60.511738999999999	60.597915	58.074283999999999	58.018836	Строителей	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
20360	49904	60.511738999999999	60.597915	58.074283999999999	58.018836	Пушкина	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
18259	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Щорса	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
19252	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Чкалова	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
19223	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Чистова	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
18961	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Советская	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
19257	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Петрова	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
18640	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Огнеупорщиков	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
19979	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Менделеевская	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
18283	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Машиностроителей	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
18648	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Лесная	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
18652	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Ленина	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
17757	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Кривоусова	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
20191	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Красноармейская	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
18243	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Калинина	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
20207	11998	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	Дружбы	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
78533	61314	59.911799000000002	59.980421999999997	57.391567999999999	57.343580000000003	Горького	0103000020E6100000010000000500000044C362D4B5F44D40A4C7EF6DFAAB4C4044C362D4B5F44D407F1475E61EB24C40B323D5777EFD4D407F1475E61EB24C40B323D5777EFD4D40A4C7EF6DFAAB4C4044C362D4B5F44D40A4C7EF6DFAAB4C40
19113	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Школьная	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
19037	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Степана Разина	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
20343	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Спортивная	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
20338	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Советская	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
18203	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Рокицанская	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
18893	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Пролетарская	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
18218	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Пищевиков	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
20149	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Некрасова	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
20405	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Кунавина	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
20313	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Декабристов	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
19175	10875	62.002619000000003	62.100265999999998	56.797727999999999	56.753048999999997	Гагарина	0103000020E6100000010000000500000093ACC3D155004F408BA4DDE863604C4093ACC3D155004F403F8D7BF31B664C404B732B84D50C4F403F8D7BF31B664C404B732B84D50C4F408BA4DDE863604C4093ACC3D155004F408BA4DDE863604C40
19877	50100	60.946874000000001	60.994467	56.694206999999999	56.649261000000003	Краснодеревцев	0103000020E6100000010000000500000063B7CF2A33794E40BDC804FC1A534C4063B7CF2A33794E40BFD364C6DB584C40C2F9D4B14A7F4E40BFD364C6DB584C40C2F9D4B14A7F4E40BDC804FC1A534C4063B7CF2A33794E40BDC804FC1A534C40
2391	888	60.802298999999998	60.823248	56.909972000000003	56.906182999999999	улица Театральная	0103000020E61000000100000005000000874ECFBBB1664E407898F6CDFD734C40874ECFBBB1664E404B2366F679744C40AB3FC23060694E404B2366F679744C40AB3FC23060694E407898F6CDFD734C40874ECFBBB1664E407898F6CDFD734C40
999	888	60.775314000000002	60.824756999999998	56.922801	56.903627	улица Ленина	0103000020E61000000100000005000000C310397D3D634E402C64AE0CAA734C40C310397D3D634E40A9DBD9571E764C40D3122BA391694E40A9DBD9571E764C40D3122BA391694E402C64AE0CAA734C40C310397D3D634E402C64AE0CAA734C40
19134	888	60.815918000000003	60.817588999999998	56.912624999999998	56.909480000000002	улица Брусницина	0103000020E61000000100000005000000DF1B430070684E40DC2E34D769744C40DF1B430070684E40894160E5D0744C40E048A0C1A6684E40894160E5D0744C40E048A0C1A6684E40DC2E34D769744C40DF1B430070684E40DC2E34D769744C40
18132	888	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	Школьная	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
77988	888	60.813789	60.834620999999999	56.908138999999998	56.904938999999999	Шиловская	0103000020E610000001000000050000001A6CEA3C2A684E40FEEF880AD5734C401A6CEA3C2A684E406F9C14E63D744C4004C765DCD46A4E406F9C14E63D744C4004C765DCD46A4E40FEEF880AD5734C401A6CEA3C2A684E40FEEF880AD5734C40
77700	888	60.768613000000002	60.777901	56.913387	56.912320999999999	Транспортников	0103000020E61000000100000005000000E62329E961624E401D3A3DEFC6744C40E62329E961624E40B8CB7EDDE9744C404A438D4292634E40B8CB7EDDE9744C404A438D4292634E401D3A3DEFC6744C40E62329E961624E401D3A3DEFC6744C40
77776	888	60.802298999999998	60.823248	56.909972000000003	56.906182999999999	Театральная	0103000020E61000000100000005000000874ECFBBB1664E407898F6CDFD734C40874ECFBBB1664E404B2366F679744C40AB3FC23060694E404B2366F679744C40AB3FC23060694E407898F6CDFD734C40874ECFBBB1664E407898F6CDFD734C40
78053	888	60.804589999999997	60.815972000000002	56.91234	56.892414000000002	Строителей	0103000020E6100000010000000500000025581CCEFC664E400C3F389F3A724C4025581CCEFC664E40946A9F8EC7744C40D2393FC571684E40946A9F8EC7744C40D2393FC571684E400C3F389F3A724C4025581CCEFC664E400C3F389F3A724C40
77955	888	60.816124000000002	60.823275000000002	56.913584	56.912624999999998	Спортивная	0103000020E6100000010000000500000088BD50C076684E40894160E5D0744C4088BD50C076684E400E130D52F0744C40A54E401361694E400E130D52F0744C40A54E401361694E40894160E5D0744C4088BD50C076684E40894160E5D0744C40
77993	888	60.735545999999999	60.750861999999998	56.898240000000001	56.892915000000002	Смирнова	0103000020E61000000100000005000000105A0F5F265E4E40CE8DE9094B724C40105A0F5F265E4E40C2FA3F87F9724C4092E7FA3E1C604E40C2FA3F87F9724C4092E7FA3E1C604E40CE8DE9094B724C40105A0F5F265E4E40CE8DE9094B724C40
77702	888	60.784287999999997	60.795095000000003	56.925998999999997	56.912374999999997	Свободы	0103000020E610000001000000050000009752978C63644E40105839B4C8744C409752978C63644E4079909E2287764C40481B47ACC5654E4079909E2287764C40481B47ACC5654E40105839B4C8744C409752978C63644E40105839B4C8744C40
78547	888	60.804248999999999	60.808210000000003	56.901277	56.895333999999998	Пионерская	0103000020E610000001000000050000009C6B98A1F1664E40997FF44D9A724C409C6B98A1F1664E4089D1730B5D734C406C26DF6C73674E4089D1730B5D734C406C26DF6C73674E40997FF44D9A724C409C6B98A1F1664E40997FF44D9A724C40
20159	888	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	Первого Мая	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
18553	888	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	Парковая	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
78556	888	60.799864999999997	60.804087000000003	56.921764000000003	56.912134000000002	Октябрьская	0103000020E61000000100000005000000861BF0F961664E40EBC891CEC0744C40861BF0F961664E40A950DD5CFC754C40C311A452EC664E40A950DD5CFC754C40C311A452EC664E40EBC891CEC0744C40861BF0F961664E40EBC891CEC0744C40
78001	888	60.822422000000003	60.822817000000001	56.904260999999998	56.890751999999999	Мира	0103000020E6100000010000000500000066C1C41F45694E405D6C5A2904724C4066C1C41F45694E402D060FD3BE734C40E2CB441152694E402D060FD3BE734C40E2CB441152694E405D6C5A2904724C4066C1C41F45694E405D6C5A2904724C40
77302	888	60.745210999999998	60.751418999999999	56.899040999999997	56.893697000000003	М.Горького	0103000020E610000001000000050000004ACFF412635F4E4044C4CDA964724C404ACFF412635F4E40AE6186C613734C40E84B6F7F2E604E40AE6186C613734C40E84B6F7F2E604E4044C4CDA964724C404ACFF412635F4E4044C4CDA964724C40
78558	888	60.746836999999999	60.749389000000001	56.896842999999997	56.894621000000001	Луговая	0103000020E61000000100000005000000AC38D55A985F4E404CA8E0F082724C40AC38D55A985F4E40C1525DC0CB724C40B77D8FFAEB5F4E40C1525DC0CB724C40B77D8FFAEB5F4E404CA8E0F082724C40AC38D55A985F4E404CA8E0F082724C40
78475	888	60.775314000000002	60.824756999999998	56.922801	56.903627	Ленина	0103000020E61000000100000005000000C310397D3D634E402C64AE0CAA734C40C310397D3D634E40A9DBD9571E764C40D3122BA391694E40A9DBD9571E764C40D3122BA391694E402C64AE0CAA734C40C310397D3D634E402C64AE0CAA734C40
78600	888	60.775314000000002	60.824756999999998	56.922801	56.903627	Ленина	0103000020E61000000100000005000000C310397D3D634E402C64AE0CAA734C40C310397D3D634E40A9DBD9571E764C40D3122BA391694E40A9DBD9571E764C40D3122BA391694E402C64AE0CAA734C40C310397D3D634E402C64AE0CAA734C40
18874	888	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	Крылосова	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
77963	888	60.798589	60.810859999999998	56.910280999999998	56.895575000000001	Красных Героев	0103000020E6100000010000000500000001F9122A38664E40BF0E9C33A2724C4001F9122A38664E40C8957A1684744C4039D1AE42CA674E40C8957A1684744C4039D1AE42CA674E40BF0E9C33A2724C4001F9122A38664E40BF0E9C33A2724C40
77999	888	60.815603000000003	60.822817000000001	56.904260999999998	56.90258	Косых	0103000020E610000001000000050000007FC2D9AD65684E400803CFBD87734C407FC2D9AD65684E402D060FD3BE734C40E2CB441152694E402D060FD3BE734C40E2CB441152694E400803CFBD87734C407FC2D9AD65684E400803CFBD87734C40
78014	888	60.745210999999998	60.751418999999999	56.899040999999997	56.893697000000003	Горького	0103000020E610000001000000050000004ACFF412635F4E4044C4CDA964724C404ACFF412635F4E40AE6186C613734C40E84B6F7F2E604E40AE6186C613734C40E84B6F7F2E604E4044C4CDA964724C404ACFF412635F4E4044C4CDA964724C40
18254	888	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	Волкова	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
2856	888	60.738869000000001	60.775359000000002	56.903666000000001	56.890000000000001	Березовский тракт	0103000020E610000001000000050000009D836742935E4E4052B81E85EB714C409D836742935E4E40EA40D653AB734C4063D4B5F63E634E40EA40D653AB734C4063D4B5F63E634E4052B81E85EB714C409D836742935E4E4052B81E85EB714C40
77981	888	60.747456999999997	60.747914999999999	56.903435000000002	56.900996999999997	Академика Королева	0103000020E610000001000000050000004815C5ABAC5F4E40A565A4DE53734C404815C5ABAC5F4E40E88711C2A3734C400B98C0ADBB5F4E40E88711C2A3734C400B98C0ADBB5F4E40A565A4DE53734C404815C5ABAC5F4E40A565A4DE53734C40
20116	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Химиков	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
18568	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Свердлова	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
18867	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Привокзальная	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
18171	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Переулок Светлый	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
77079	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Молодежная	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
18288	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Милицейская	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
19886	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Ленина	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
20228	9344	61.306173000000001	61.471525999999997	56.779702999999998	56.723900999999998	Горем	0103000020E6100000010000000500000088F546AD30A74E405645B8C9A85C4C4088F546AD30A74E40EACBD24ECD634C405A9BC6F65ABC4E40EACBD24ECD634C405A9BC6F65ABC4E405645B8C9A85C4C4088F546AD30A74E405645B8C9A85C4C40
18127	49890	63.735523000000001	63.786233000000003	57.409185000000001	57.388114000000002	Свердлова	0103000020E61000000100000005000000583A1F9E25DE4F40548F34B8ADB14C40583A1F9E25DE4F40C381902C60B44C409B046F48A3E44F40C381902C60B44C409B046F48A3E44F40548F34B8ADB14C40583A1F9E25DE4F40548F34B8ADB14C40
19818	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Школьная	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18110	6503	61.444217000000002	61.449005	57.113672999999999	57.111400000000003	Чапаева	0103000020E61000000100000005000000E3A9471ADCB84E402063EE5A428E4C40E3A9471ADCB84E4017B83CD68C8E4C40C85EEFFE78B94E4017B83CD68C8E4C40C85EEFFE78B94E402063EE5A428E4C40E3A9471ADCB84E402063EE5A428E4C40
19322	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Физкультурников	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
77420	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Тимирязева	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18703	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Советская	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
20293	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Серова	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
20333	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Садовая	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18478	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Победы	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18727	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Плеханова	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
19082	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Папанина	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18482	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Осипенко	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18066	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Октябрьской революции	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
19338	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Мира	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18029	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Лесная	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18951	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Ленинградская	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
19839	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Ленина	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
19065	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Ладыженского	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
20222	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Калинина	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
18999	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	Войкова	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
20081	6503	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	8 Марта 	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
20300	49978	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	пер. Заводской	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
78412	49978	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Пригородная	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
77466	49978	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Котовского	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
19010	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	улица Николая Островского	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77456	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Фрунзе	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77295	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Урицкого	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
78440	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Советская	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77454	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Розы Люксембург	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77297	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Павлова	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
78424	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Октябрьская	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
78593	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Мира	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77948	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Мира	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77448	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Ленина	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77460	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Краснофлотцев	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
17967	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Клубная	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77060	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Говырина	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
17998	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	Братьев Смольниковых	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
77459	49843	61.633834	61.728848999999997	57.877659000000001	57.813544999999998	3-го Интернационала	0103000020E61000000100000005000000E38BF67821D14E408369183E22E84C40E38BF67821D14E4021054F2157F04C40745C8DEC4ADD4E4021054F2157F04C40745C8DEC4ADD4E408369183E22E84C40E38BF67821D14E408369183E22E84C40
17813	49842	59.960262999999998	59.996195999999998	60.357675	60.334575000000001	Калинина	0103000020E610000001000000050000008847E2E5E9FA4D409487855AD32A4E408847E2E5E9FA4D4064CC5D4BC82D4E40F833BC5983FF4D4064CC5D4BC82D4E40F833BC5983FF4D409487855AD32A4E408847E2E5E9FA4D409487855AD32A4E40
18295	49912	59.889727999999998	59.912491000000003	60.409688000000003	60.398187999999998	40 лет Октября	0103000020E61000000100000005000000F12A6B9BE2F14D406FD40AD3F7324E40F12A6B9BE2F14D4026C808A870344E407A724D81CCF44D4026C808A870344E407A724D81CCF44D406FD40AD3F7324E40F12A6B9BE2F14D406FD40AD3F7324E40
18927	49967	59.974150999999999	60.001621999999998	60.250002000000002	60.233449999999998	Ленина	0103000020E61000000100000005000000CF2EDFFAB0FC4D4027A089B0E11D4E40CF2EDFFAB0FC4D40A1F7C61000204E40207A522635004E40A1F7C61000204E40207A522635004E4027A089B0E11D4E40CF2EDFFAB0FC4D4027A089B0E11D4E40
20097	47936	59.858161000000003	59.895881000000003	56.629426000000002	56.608575999999999	Мичурина	0103000020E61000000100000005000000F1D93A38D8ED4D40B49080D1E54D4C40F1D93A38D8ED4D4045A0FA0791504C40CC0D863AACF24D4045A0FA0791504C40CC0D863AACF24D40B49080D1E54D4C40F1D93A38D8ED4D40B49080D1E54D4C40
18773	15768	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	Советская	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
19836	15768	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	Площадь Ленина	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
77468	15768	60.057389000000001	60.144212000000003	56.733002999999997	56.673932000000001	Культуры	0103000020E610000001000000050000003813D38558074E402BDD5D6743564C403813D38558074E40586FD40AD35D4C406BD8EF8975124E40586FD40AD35D4C406BD8EF8975124E402BDD5D6743564C403813D38558074E402BDD5D6743564C40
18589	49940	60.266840999999999	60.306510000000003	56.307890999999998	56.288421	 М. Горького	0103000020E61000000100000005000000B01D8CD827224E40643DB5FAEA244C40B01D8CD827224E40CADDE7F868274C40D0F23CB83B274E40CADDE7F868274C40D0F23CB83B274E40643DB5FAEA244C40B01D8CD827224E40643DB5FAEA244C40
18869	49964	60.316571000000003	60.351776000000001	56.487081000000003	56.472445999999998	Советская	0103000020E6100000010000000500000057EE056685284E4021904B1C793C4C4057EE056685284E4062C092AB583E4C4044C2F7FE062D4E4062C092AB583E4C4044C2F7FE062D4E4021904B1C793C4C4057EE056685284E4021904B1C793C4C40
20019	50129	60.117818999999997	60.145235999999997	56.493203000000001	56.481324999999998	Ленина	0103000020E6100000010000000500000078EC67B1140F4E40A4DFBE0E9C3D4C4078EC67B1140F4E4001A5A146213F4C40D619DF1797124E4001A5A146213F4C40D619DF1797124E40A4DFBE0E9C3D4C4078EC67B1140F4E40A4DFBE0E9C3D4C40
19015	49975	60.226469999999999	60.265574000000001	56.852705999999998	56.843451999999999	Школьная	0103000020E6100000010000000500000037C30DF8FC1C4E4076DF313CF66B4C4037C30DF8FC1C4E402E8D5F78256D4C407E552E54FE214E402E8D5F78256D4C407E552E54FE214E4076DF313CF66B4C4037C30DF8FC1C4E4076DF313CF66B4C40
19009	49851	59.534120999999999	59.579953000000003	57.002955999999998	56.976790000000001	Культуры	0103000020E61000000100000005000000AC8DB1135EC44D40A9876874077D4C40AC8DB1135EC44D40DAA9B9DC60804C40CA1B60E63BCA4D40DAA9B9DC60804C40CA1B60E63BCA4D40A9876874077D4C40AC8DB1135EC44D40A9876874077D4C40
18321	49915	60.112555	60.153689	56.855964	56.841507	Буденого	0103000020E610000001000000050000002A00C633680E4E40732D5A80B66B4C402A00C633680E4E40D446753A906D4C40A260C614AC134E40D446753A906D4C40A260C614AC134E40732D5A80B66B4C402A00C633680E4E40732D5A80B66B4C40
18693	49948	59.672434000000003	59.706057999999999	56.953868999999997	56.933278000000001	КИЗ	0103000020E61000000100000005000000F75B3B5112D64D40C4094CA775774C40F75B3B5112D64D4088D51F61187A4C40228AC91B60DA4D4088D51F61187A4C40228AC91B60DA4D40C4094CA775774C40F75B3B5112D64D40C4094CA775774C40
17829	49847	59.745530000000002	59.765410000000003	56.93947	56.922437000000002	Заречная	0103000020E61000000100000005000000EC17EC866DDF4D4068CF656A12764C40EC17EC866DDF4D405CC98E8D40784C40040473F4F8E14D405CC98E8D40784C40040473F4F8E14D4068CF656A12764C40EC17EC866DDF4D4068CF656A12764C40
19300	49957	59.782451000000002	59.846733999999998	56.981920000000002	56.935732999999999	Лермонтова	0103000020E610000001000000050000007BDCB75A27E44D40DC645419C6774C407BDCB75A27E44D40E8A4F78DAF7D4C40A4349BC761EC4D40E8A4F78DAF7D4C40A4349BC761EC4D40DC645419C6774C407BDCB75A27E44D40DC645419C6774C40
19951	49957	59.782451000000002	59.846733999999998	56.981920000000002	56.935732999999999	Ленина	0103000020E610000001000000050000007BDCB75A27E44D40DC645419C6774C407BDCB75A27E44D40E8A4F78DAF7D4C40A4349BC761EC4D40E8A4F78DAF7D4C40A4349BC761EC4D40DC645419C6774C407BDCB75A27E44D40DC645419C6774C40
18796	49957	59.782451000000002	59.846733999999998	56.981920000000002	56.935732999999999	Красноармейская	0103000020E610000001000000050000007BDCB75A27E44D40DC645419C6774C407BDCB75A27E44D40E8A4F78DAF7D4C40A4349BC761EC4D40E8A4F78DAF7D4C40A4349BC761EC4D40DC645419C6774C407BDCB75A27E44D40DC645419C6774C40
18320	49914	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Культуры	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
18883	5314	59.762293	59.894094000000003	58.66619	58.597458000000003	Советская	0103000020E61000000100000005000000207C28D192E14D40E65DF580794C4D40207C28D192E14D400C76C3B645554D4061C614AC71F24D400C76C3B645554D4061C614AC71F24D40E65DF580794C4D40207C28D192E14D40E65DF580794C4D40
17870	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Юбилейная	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
18356	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Мира	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
19187	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Мамина-Сибиряка	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
17780	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Ленина	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
18751	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Кирова	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
77099	11234	59.757837000000002	59.823917000000002	58.660030999999996	58.623361000000003	Дзержинского	0103000020E61000000100000005000000715985CD00E14D400A4D124BCA4F4D40715985CD00E14D404FAC53E57B544D4029CFBC1C76E94D404FAC53E57B544D4029CFBC1C76E94D400A4D124BCA4F4D40715985CD00E14D400A4D124BCA4F4D40
18296	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Горького	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
18201	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Белинского	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
18352	11234	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Бажова	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
77800	61255	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Ленина проспект	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
78473	61255	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Ленина	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
18882	5221	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Советская	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
19283	49989	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	Клубная	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
9663	14675	59.789143000000003	59.877977999999999	58.377597999999999	58.343620999999999	Машиностроителей	0103000020E61000000100000005000000056F48A302E54D40029CDEC5FB2B4D40056F48A302E54D407B849A2155304D40C24D469561F04D407B849A2155304D40C24D469561F04D40029CDEC5FB2B4D40056F48A302E54D40029CDEC5FB2B4D40
18716	14675	59.789143000000003	59.877977999999999	58.377597999999999	58.343620999999999	Гробова	0103000020E61000000100000005000000056F48A302E54D40029CDEC5FB2B4D40056F48A302E54D407B849A2155304D40C24D469561F04D407B849A2155304D40C24D469561F04D40029CDEC5FB2B4D40056F48A302E54D40029CDEC5FB2B4D40
20134	49897	59.668346999999997	59.734202000000003	58.190522999999999	58.150157999999998	Победы	0103000020E610000001000000050000009AB0FD648CD54D40CB9D996038134D409AB0FD648CD54D406211C30E63184D403354C554FADD4D406211C30E63184D403354C554FADD4D40CB9D996038134D409AB0FD648CD54D40CB9D996038134D40
19145	49897	59.668346999999997	59.734202000000003	58.190522999999999	58.150157999999998	Ленина	0103000020E610000001000000050000009AB0FD648CD54D40CB9D996038134D409AB0FD648CD54D406211C30E63184D403354C554FADD4D406211C30E63184D403354C554FADD4D40CB9D996038134D409AB0FD648CD54D40CB9D996038134D40
18192	49897	59.668346999999997	59.734202000000003	58.190522999999999	58.150157999999998	Коммуны	0103000020E610000001000000050000009AB0FD648CD54D40CB9D996038134D409AB0FD648CD54D406211C30E63184D403354C554FADD4D406211C30E63184D403354C554FADD4D40CB9D996038134D409AB0FD648CD54D40CB9D996038134D40
18842	49267	57.716316999999997	57.755285999999998	56.648924000000001	56.623399999999997	Загородная	0103000020E61000000100000005000000CF488446B0DB4C40C7293A92CB4F4C40CF488446B0DB4C4075CB0EF10F534C4036902E36ADE04C4075CB0EF10F534C4036902E36ADE04C40C7293A92CB4F4C40CF488446B0DB4C40C7293A92CB4F4C40
18123	49889	59.947021999999997	59.963389999999997	58.37632	58.367607	Матросова	0103000020E61000000100000005000000D74B530438F94D40ED6305BF0D2F4D40D74B530438F94D40556AF6402B304D408FA50F5D50FB4D40556AF6402B304D408FA50F5D50FB4D40ED6305BF0D2F4D40D74B530438F94D40ED6305BF0D2F4D40
19874	49981	59.920037000000001	59.938640999999997	58.414318999999999	58.400519000000003	Советская 	0103000020E61000000100000005000000130EBDC5C3F54D409C36E33444334D40130EBDC5C3F54D40438EAD6708354D40A5D7666325F84D40438EAD6708354D40A5D7666325F84D409C36E33444334D40130EBDC5C3F54D409C36E33444334D40
18616	2105	60.274017999999998	60.301488999999997	59.709780000000002	59.688637	Пушкина	0103000020E61000000100000005000000F641960513234E4064E8D84125D84D40F641960513234E406DAD2F12DADA4D40478D093197264E406DAD2F12DADA4D40478D093197264E4064E8D84125D84D40F641960513234E4064E8D84125D84D40
17893	2105	60.274017999999998	60.301488999999997	59.709780000000002	59.688637	Первомайская	0103000020E61000000100000005000000F641960513234E4064E8D84125D84D40F641960513234E406DAD2F12DADA4D40478D093197264E406DAD2F12DADA4D40478D093197264E4064E8D84125D84D40F641960513234E4064E8D84125D84D40
18547	49900	60.093483999999997	60.225284000000002	59.791820000000001	59.725326000000003	Краснотурьинская	0103000020E610000001000000050000008159A148F70B4E4021787C7BD7DC4D408159A148F70B4E40CC28965B5AE54D40F2272A1BD61C4E40CC28965B5AE54D40F2272A1BD61C4E4021787C7BD7DC4D408159A148F70B4E4021787C7BD7DC4D40
18014	49881	60.115304000000002	60.166902999999998	57.354312	57.324128000000002	Ржанникова	0103000020E610000001000000050000008B8C0E48C20E4E40E4DBBB067DA94C408B8C0E48C20E4E40494A7A185AAD4C40594DD7135D154E40494A7A185AAD4C40594DD7135D154E40E4DBBB067DA94C408B8C0E48C20E4E40E4DBBB067DA94C40
19001	49974	59.882631000000003	59.923990000000003	57.606231000000001	57.571984	Малышева	0103000020E61000000100000005000000C8B7770DFAF04D40EAEA8EC536C94C40C8B7770DFAF04D40236937FA98CD4C4060EAE74D45F64D40236937FA98CD4C4060EAE74D45F64D40EAEA8EC536C94C40C8B7770DFAF04D40EAEA8EC536C94C40
19189	49987	59.879297999999999	59.907226999999999	57.513455	57.489879999999999	Дарвина	0103000020E6100000010000000500000017B83CD68CF04D40747B4963B4BE4C4017B83CD68CF04D40DD7BB8E4B8C14C402B86AB0320F44D40DD7BB8E4B8C14C402B86AB0320F44D40747B4963B4BE4C4017B83CD68CF04D40747B4963B4BE4C40
17955	14058	59.911799000000002	59.980421999999997	57.391567999999999	57.343580000000003	Чапаева	0103000020E6100000010000000500000044C362D4B5F44D40A4C7EF6DFAAB4C4044C362D4B5F44D407F1475E61EB24C40B323D5777EFD4D407F1475E61EB24C40B323D5777EFD4D40A4C7EF6DFAAB4C4044C362D4B5F44D40A4C7EF6DFAAB4C40
18397	14058	59.911799000000002	59.980421999999997	57.391567999999999	57.343580000000003	Центральная	0103000020E6100000010000000500000044C362D4B5F44D40A4C7EF6DFAAB4C4044C362D4B5F44D407F1475E61EB24C40B323D5777EFD4D407F1475E61EB24C40B323D5777EFD4D40A4C7EF6DFAAB4C4044C362D4B5F44D40A4C7EF6DFAAB4C40
17924	14058	59.911799000000002	59.980421999999997	57.391567999999999	57.343580000000003	Островского	0103000020E6100000010000000500000044C362D4B5F44D40A4C7EF6DFAAB4C4044C362D4B5F44D407F1475E61EB24C40B323D5777EFD4D407F1475E61EB24C40B323D5777EFD4D40A4C7EF6DFAAB4C4044C362D4B5F44D40A4C7EF6DFAAB4C40
77089	14058	59.911799000000002	59.980421999999997	57.391567999999999	57.343580000000003	Ленина	0103000020E6100000010000000500000044C362D4B5F44D40A4C7EF6DFAAB4C4044C362D4B5F44D407F1475E61EB24C40B323D5777EFD4D407F1475E61EB24C40B323D5777EFD4D40A4C7EF6DFAAB4C4044C362D4B5F44D40A4C7EF6DFAAB4C40
78272	61159	59.540776999999999	59.573385999999999	58.769015000000003	58.754015000000003	Кирова	0103000020E61000000100000005000000E9B6442E38C54D40C3D8429083604D40E9B6442E38C54D40159161156F624D40FCFD62B664C94D40159161156F624D40FCFD62B664C94D40C3D8429083604D40E9B6442E38C54D40C3D8429083604D40
77465	61180	60.002439000000003	60.105044999999997	59.949162999999999	59.888649999999998	Мичурина	0103000020E61000000100000005000000139ED0EB4F004E4092CB7F48BFF14D40139ED0EB4F004E4060C9552C7EF94D40DDCD531D720D4E4060C9552C7EF94D40DDCD531D720D4E4092CB7F48BFF14D40139ED0EB4F004E4092CB7F48BFF14D40
18792	26186	61.746662000000001	61.763891999999998	56.538727999999999	56.528612000000003	Кирова	0103000020E610000001000000050000003E95D39E92DF4E40F722DA8EA9434C403E95D39E92DF4E4041B8020AF5444C4088D68A36C7E14E4041B8020AF5444C4088D68A36C7E14E40F722DA8EA9434C403E95D39E92DF4E40F722DA8EA9434C40
20077	25763	61.773594000000003	61.827635999999998	56.511197000000003	56.484679999999997	Ленина	0103000020E61000000100000005000000E030D12005E34E403C8386FE093E4C40E030D12005E34E401B683EE76E414C40027FF8F9EFE94E401B683EE76E414C40027FF8F9EFE94E403C8386FE093E4C40E030D12005E34E403C8386FE093E4C40
18410	24127	61.399374000000002	61.426332000000002	56.395581	56.382052999999999	Ленина	0103000020E61000000100000005000000B56FEEAF1EB34E405A2BDA1CE7304C40B56FEEAF1EB34E40A1F5F065A2324C40809E060C92B64E40A1F5F065A2324C40809E060C92B64E405A2BDA1CE7304C40B56FEEAF1EB34E405A2BDA1CE7304C40
19369	24127	61.399374000000002	61.426332000000002	56.395581	56.382052999999999	Ленин	0103000020E61000000100000005000000B56FEEAF1EB34E405A2BDA1CE7304C40B56FEEAF1EB34E40A1F5F065A2324C40809E060C92B64E40A1F5F065A2324C40809E060C92B64E405A2BDA1CE7304C40B56FEEAF1EB34E405A2BDA1CE7304C40
19068	22021	61.974421	62.057758	56.453732000000002	56.425044	Ворошилова	0103000020E610000001000000050000008FC4CBD3B9FC4E4036AE7FD767364C408FC4CBD3B9FC4E400893E2E3133A4C408B8A389D64074F400893E2E3133A4C408B8A389D64074F4036AE7FD767364C408FC4CBD3B9FC4E4036AE7FD767364C40
17980	24235	61.235053999999998	61.269413999999998	56.452691999999999	56.424491000000003	Мира	0103000020E61000000100000005000000A165DD3F169E4E40223999B855364C40A165DD3F169E4E409694BBCFF1394C40D28A6F287CA24E409694BBCFF1394C40D28A6F287CA24E40223999B855364C40A165DD3F169E4E40223999B855364C40
19075	24997	62.186531000000002	62.246934000000003	56.360008000000001	56.341453000000001	Ани Семянниковой	0103000020E610000001000000050000005858703FE0174F40800F5EBBB42B4C405858703FE0174F403126FDBD142E4C409F2287889B1F4F403126FDBD142E4C409F2287889B1F4F40800F5EBBB42B4C405858703FE0174F40800F5EBBB42B4C40
18433	24820	61.649715999999998	61.704891000000003	56.354821000000001	56.340245000000003	Советская	0103000020E610000001000000050000000ED8D5E429D34E4053D0ED258D2B4C400ED8D5E429D34E408E7747C66A2D4C40541F48DE39DA4E408E7747C66A2D4C40541F48DE39DA4E4053D0ED258D2B4C400ED8D5E429D34E4053D0ED258D2B4C40
18770	25554	61.867790999999997	61.895747	56.467046000000003	56.451225000000001	Лесная	0103000020E61000000100000005000000AE6186C613EF4E409D11A5BDC1394C40AE6186C613EF4E4023DDCF29C83B4C40BC3E73D6A7F24E4023DDCF29C83B4C40BC3E73D6A7F24E409D11A5BDC1394C40AE6186C613EF4E409D11A5BDC1394C40
18931	26068	61.946258999999998	61.975876	56.275208999999997	56.256028000000001	Школьная	0103000020E61000000100000005000000D845D1031FF94E401E6E8786C5204C40D845D1031FF94E404D486B0C3A234C40C4793881E9FC4E404D486B0C3A234C40C4793881E9FC4E401E6E8786C5204C40D845D1031FF94E401E6E8786C5204C40
79425	21344	61.579656	61.60145	56.4985	56.487442999999999	Первомайская	0103000020E610000001000000050000001077F52A32CA4E4002D53F88643E4C401077F52A32CA4E402B8716D9CE3F4C40F0164850FCCC4E402B8716D9CE3F4C40F0164850FCCC4E4002D53F88643E4C401077F52A32CA4E4002D53F88643E4C40
19983	21344	61.579656	61.60145	56.4985	56.487442999999999	Ленина	0103000020E610000001000000050000001077F52A32CA4E4002D53F88643E4C401077F52A32CA4E402B8716D9CE3F4C40F0164850FCCC4E402B8716D9CE3F4C40F0164850FCCC4E4002D53F88643E4C401077F52A32CA4E4002D53F88643E4C40
17945	21344	61.579656	61.60145	56.4985	56.487442999999999	Кирова	0103000020E610000001000000050000001077F52A32CA4E4002D53F88643E4C401077F52A32CA4E402B8716D9CE3F4C40F0164850FCCC4E402B8716D9CE3F4C40F0164850FCCC4E4002D53F88643E4C401077F52A32CA4E4002D53F88643E4C40
19392	49996	61.847265	61.875633000000001	56.459640999999998	56.445239999999998	Кленовая	0103000020E61000000100000005000000D105F52D73EC4E407E6FD39FFD384C40D105F52D73EC4E404B732B84D53A4C403126FDBD14F04E404B732B84D53A4C403126FDBD14F04E407E6FD39FFD384C40D105F52D73EC4E407E6FD39FFD384C40
19105	25931	61.907299000000002	61.917549000000001	56.192805999999997	56.185682999999997	Ленина	0103000020E61000000100000005000000C558A65F22F44E402A36E675C4174C40C558A65F22F44E407D3CF4DDAD184C401FBDE13E72F54E407D3CF4DDAD184C401FBDE13E72F54E402A36E675C4174C40C558A65F22F44E402A36E675C4174C40
18442	23558	62.134312000000001	62.156177	56.3718	56.360930000000003	Ленина	0103000020E61000000100000005000000EDBAB72231114F40991249F4322E4C40EDBAB72231114F408F537424972F4C4096B1A19BFD134F408F537424972F4C4096B1A19BFD134F40991249F4322E4C40EDBAB72231114F40991249F4322E4C40
18686	27758	61.989503999999997	62.02373	56.391471000000003	56.375518	Комиссаров	0103000020E610000001000000050000006EA12B11A8FE4E4098874CF910304C406EA12B11A8FE4E408D2AC3B81B324C4090F7AA9509034F408D2AC3B81B324C4090F7AA9509034F4098874CF910304C406EA12B11A8FE4E4098874CF910304C40
18379	49919	61.873963000000003	61.898575999999998	56.404752000000002	56.390020999999997	Титова	0103000020E6100000010000000500000000750305DEEF4E4069E04735EC314C4000750305DEEF4E40CC7EDDE9CE334C40397CD28904F34E40CC7EDDE9CE334C40397CD28904F34E4069E04735EC314C4000750305DEEF4E4069E04735EC314C40
18986	49919	61.873963000000003	61.898575999999998	56.404752000000002	56.390020999999997	Ленина	0103000020E6100000010000000500000000750305DEEF4E4069E04735EC314C4000750305DEEF4E40CC7EDDE9CE334C40397CD28904F34E40CC7EDDE9CE334C40397CD28904F34E4069E04735EC314C4000750305DEEF4E4069E04735EC314C40
78257	61234	61.379044999999998	61.421553000000003	56.456795999999997	56.430196000000002	Чапаева	0103000020E610000001000000050000002D5BEB8B84B04E405D6F9BA910374C402D5BEB8B84B04E40C878944A783A4C40EE43DE72F5B54E40C878944A783A4C40EE43DE72F5B54E405D6F9BA910374C402D5BEB8B84B04E405D6F9BA910374C40
19032	24429	61.274650999999999	61.285026999999999	56.415480000000002	56.409219999999998	Советская	0103000020E61000000100000005000000276893C327A34E403F6F2A5261344C40276893C327A34E403012DA722E354C400EBDC5C37BA44E403012DA722E354C400EBDC5C37BA44E403F6F2A5261344C40276893C327A34E403F6F2A5261344C40
17993	49878	61.652752	61.664636999999999	56.550519000000001	56.541791000000003	Советская	0103000020E610000001000000050000000533A6608DD34E403222516859454C400533A6608DD34E40CF69166877464C40145B41D312D54E40CF69166877464C40145B41D312D54E403222516859454C400533A6608DD34E403222516859454C40
19053	24888	62.170065000000001	62.237411999999999	56.376021999999999	56.351061000000001	Ленина	0103000020E61000000100000005000000DD989EB0C4154F4056F31C91EF2C4C40DD989EB0C4154F40CB49287D21304C40C7D63384631E4F40CB49287D21304C40C7D63384631E4F4056F31C91EF2C4C40DD989EB0C4154F4056F31C91EF2C4C40
18056	25645	61.710236000000002	61.746698000000002	56.591831999999997	56.571649999999998	Уральская	0103000020E610000001000000050000008F386403E9DA4E401361C3D32B494C408F386403E9DA4E40F65CA626C14B4C408BFED0CC93DF4E40F65CA626C14B4C408BFED0CC93DF4E401361C3D32B494C408F386403E9DA4E401361C3D32B494C40
19875	23755	61.58493	61.596634999999999	56.435929000000002	56.430947000000003	Нагорная	0103000020E6100000010000000500000082397AFCDECA4E4098A7734529374C4082397AFCDECA4E4062307F85CC374C40115322895ECC4E4062307F85CC374C40115322895ECC4E4098A7734529374C4082397AFCDECA4E4098A7734529374C40
18381	23461	61.835020999999998	61.858341000000003	56.416345999999997	56.405903000000002	Ворошилова	0103000020E61000000100000005000000923CD7F7E1EA4E40952C27A1F4334C40923CD7F7E1EA4E4003E962D34A354C4071E82D1EDEED4E4003E962D34A354C4071E82D1EDEED4E40952C27A1F4334C40923CD7F7E1EA4E40952C27A1F4334C40
18081	25075	62.069794999999999	62.093662999999999	56.436148000000003	56.418371999999998	8е Марта	0103000020E610000001000000050000005036E50AEF084F40F3C7B4368D354C405036E50AEF084F40A01B9AB2D3374C4031EC3026FD0B4F40A01B9AB2D3374C4031EC3026FD0B4F40F3C7B4368D354C405036E50AEF084F40F3C7B4368D354C40
18455	25662	61.595629000000002	61.635154	56.615009999999998	56.605558000000002	Куйбышева	0103000020E610000001000000050000004CC631923DCC4E4064EAAEEC824D4C404CC631923DCC4E40425BCEA5B84E4C4038F6ECB94CD14E40425BCEA5B84E4C4038F6ECB94CD14E4064EAAEEC824D4C404CC631923DCC4E4064EAAEEC824D4C40
20073	26139	61.851261999999998	61.891416999999997	56.305764000000003	56.296894000000002	Кирова	0103000020E61000000100000005000000ED293927F6EC4E407730629F00264C40ED293927F6EC4E40A725564623274C40990CC7F319F24E40A725564623274C40990CC7F319F24E407730629F00264C40ED293927F6EC4E407730629F00264C40
17791	49839	63.005606	63.103791999999999	57.695076	57.644934999999997	Мальгина	0103000020E61000000100000005000000A85489B2B7804F40DB85E63A8DD24C40A85489B2B7804F40041E1840F8D84C4010CB660E498D4F40041E1840F8D84C4010CB660E498D4F40DB85E63A8DD24C40A85489B2B7804F40DB85E63A8DD24C40
18626	19003	60.524352	60.546989000000004	61.284728000000001	61.278196000000001	Титова	0103000020E61000000100000005000000CDCB61F71D434E4063F030ED9BA34E40CDCB61F71D434E40B42094F771A44E40C9224DBC03464E40B42094F771A44E40C9224DBC03464E4063F030ED9BA34E40CDCB61F71D434E4063F030ED9BA34E40
17940	19316	60.344617	60.382040000000003	60.205942999999998	60.194960000000002	Горняков	0103000020E61000000100000005000000A452EC681C2C4E409B030473F4184E40A452EC681C2C4E4089EB18575C1A4E40C6E1CCAFE6304E4089EB18575C1A4E40C6E1CCAFE6304E409B030473F4184E40A452EC681C2C4E409B030473F4184E40
17866	18998	60.388652	60.401587999999997	60.987290999999999	60.977815999999997	Ленина	0103000020E6100000010000000500000033C34659BF314E40B5C01E13297D4E4033C34659BF314E404C512E8D5F7E4E40A73B4F3C67334E404C512E8D5F7E4E40A73B4F3C67334E40B5C01E13297D4E4033C34659BF314E40B5C01E13297D4E40
18891	16308	61.975121999999999	62.005754000000003	61.023615999999997	61.011710000000001	Фестивальная	0103000020E6100000010000000500000018CE35CCD0FC4E40A18499B67F814E4018CE35CCD0FC4E40C7D45DD905834E401DE90C8CBC004F40C7D45DD905834E401DE90C8CBC004F40A18499B67F814E4018CE35CCD0FC4E40A18499B67F814E40
19017	19514	61.499670000000002	61.527276000000001	60.914991999999998	60.892187999999997	Молодежная	0103000020E610000001000000050000006B65C22FF5BF4E401BF1643733724E406B65C22FF5BF4E40020D36751E754E409CFBABC77DC34E40020D36751E754E409CFBABC77DC34E401BF1643733724E406B65C22FF5BF4E401BF1643733724E40
18399	19413	60.449576	60.487358999999998	60.124209	60.102082000000003	Ленина	0103000020E610000001000000050000008388D4B48B394E4051C1E105110D4E408388D4B48B394E40376F9C14E60F4E40A4349BC7613E4E40376F9C14E60F4E40A4349BC7613E4E4051C1E105110D4E408388D4B48B394E4051C1E105110D4E40
18380	19159	60.415871000000003	60.444419000000003	60.423907999999997	60.413348999999997	Красноармейская	0103000020E610000001000000050000006B2DCC423B354E40CA6ABA9EE8344E406B2DCC423B354E40A2410A9E42364E404B5CC7B8E2384E40A2410A9E42364E404B5CC7B8E2384E40CA6ABA9EE8344E406B2DCC423B354E40CA6ABA9EE8344E40
19367	19218	60.398254999999999	60.419437000000002	60.223146999999997	60.206806	Станционная	0103000020E61000000100000005000000F73B1405FA324E40EC4E779E781A4E40F73B1405FA324E40AA99B514901C4E40BEDD921CB0354E40AA99B514901C4E40BEDD921CB0354E40EC4E779E781A4E40F73B1405FA324E40EC4E779E781A4E40
18102	16461	62.277943999999998	62.301290999999999	61.080438000000001	61.066555000000001	Космонавтов	0103000020E61000000100000005000000490F43AB93234F405131CEDF84884E40490F43AB93234F4086ADD9CA4B8A4E4021CA17B490264F4086ADD9CA4B8A4E4021CA17B490264F405131CEDF84884E40490F43AB93234F405131CEDF84884E40
18884	15815	60.560687999999999	60.641734	56.649627000000002	56.624716999999997	Ленина	0103000020E610000001000000050000003CA1D79FC4474E40AB2006BAF64F4C403CA1D79FC4474E409FCC3FFA26534C409A5DF75624524E409FCC3FFA26534C409A5DF75624524E40AB2006BAF64F4C403CA1D79FC4474E40AB2006BAF64F4C40
18659	8040	60.280943999999998	60.316419000000003	56.879043000000003	56.855206000000003	Горная	0103000020E61000000100000005000000F30016F9F5234E40E7ABE463776D4C40F30016F9F5234E408D63247B84704C40A16AF46A80284E408D63247B84704C40A16AF46A80284E40E7ABE463776D4C40F30016F9F5234E40E7ABE463776D4C40
19878	50101	60.012222000000001	60.943604000000001	56.962198000000001	56.604092000000001	Адмирала Ушакова	0103000020E610000001000000050000005725917D90014E403BE3FBE2524D4C405725917D90014E406823D74D297B4C40F92F1004C8784E406823D74D297B4C40F92F1004C8784E403BE3FBE2524D4C405725917D90014E403BE3FBE2524D4C40
18900	48180	60.849353000000001	60.853180000000002	56.812907000000003	56.810442999999999	Студенческая	0103000020E6100000010000000500000037E15E99B76C4E40D522A298BC674C4037E15E99B76C4E4041D829560D684C40F7CC9200356D4E4041D829560D684C40F7CC9200356D4E40D522A298BC674C4037E15E99B76C4E40D522A298BC674C40
19924	15884	60.502198999999997	60.540404000000002	56.696776999999997	56.670188000000003	Ленина	0103000020E61000000100000005000000BD8A8C0E48404E40F9156BB8C8554C40BD8A8C0E48404E4070CD1DFD2F594C40555051F52B454E4070CD1DFD2F594C40555051F52B454E40F9156BB8C8554C40BD8A8C0E48404E40F9156BB8C8554C40
17971	10550	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	Уральская	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
18426	10550	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	Набережная	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
18002	10550	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	Лермонтова	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
18749	10550	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	Ленина	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
18351	10550	60.452584999999999	60.497338999999997	57.016120000000001	56.973340999999998	Бахтеева	0103000020E6100000010000000500000080D4264EEE394E408F6D1970967C4C4080D4264EEE394E40E0675C3810824C403E03EACDA83F4E40E0675C3810824C403E03EACDA83F4E408F6D1970967C4C4080D4264EEE394E408F6D1970967C4C40
20403	47122	60.625053000000001	60.633496999999998	57.083598000000002	57.078355000000002	Загородная	0103000020E6100000010000000500000023A298BC01504E40323D6189078A4C4023A298BC01504E406901DA56B38A4C409B8E006E16514E406901DA56B38A4C409B8E006E16514E40323D6189078A4C4023A298BC01504E40323D6189078A4C40
19306	47031	60.546495	60.563806	57.021304000000001	57.008651999999998	Огородная	0103000020E61000000100000005000000B936548CF3454E40C2853C821B814C40B936548CF3454E4012A3E716BA824C40F0A485CB2A484E4012A3E716BA824C40F0A485CB2A484E40C2853C821B814C40B936548CF3454E40C2853C821B814C40
19326	1406	60.641007000000002	60.655262999999998	57.168585	57.157510000000002	Садовая	0103000020E61000000100000005000000E8C072840C524E408065A54929944C40E8C072840C524E404FCC7A3194954C40B1A371A8DF534E404FCC7A3194954C40B1A371A8DF534E408065A54929944C40E8C072840C524E408065A54929944C40
20411	47129	60.666744000000001	60.703817000000001	57.062089999999998	57.046430000000001	Жданова	0103000020E61000000100000005000000F1660DDE57554E40D2C6116BF1854C40F1660DDE57554E404EB4AB90F2874C4036AFEAAC165A4E404EB4AB90F2874C4036AFEAAC165A4E40D2C6116BF1854C40F1660DDE57554E40D2C6116BF1854C40
18968	13208	60.347805999999999	60.389847000000003	56.988531000000002	56.966898999999998	Станционная	0103000020E6100000010000000500000021AD31E8842C4E407EC4AF58C37B4C4021AD31E8842C4E40850A0E2F887E4C40CCB8A981E6314E40850A0E2F887E4C40CCB8A981E6314E407EC4AF58C37B4C4021AD31E8842C4E407EC4AF58C37B4C40
18672	13208	60.347805999999999	60.389847000000003	56.988531000000002	56.966898999999998	Мира	0103000020E6100000010000000500000021AD31E8842C4E407EC4AF58C37B4C4021AD31E8842C4E40850A0E2F887E4C40CCB8A981E6314E40850A0E2F887E4C40CCB8A981E6314E407EC4AF58C37B4C4021AD31E8842C4E407EC4AF58C37B4C40
18978	13497	60.593055	60.614640999999999	57.003348000000003	56.987163000000002	Первомайская	0103000020E6100000010000000500000059DDEA39E94B4E401F69705B5B7E4C4059DDEA39E94B4E40E6400FB56D804C40EFE3688EAC4E4E40E6400FB56D804C40EFE3688EAC4E4E401F69705B5B7E4C4059DDEA39E94B4E401F69705B5B7E4C40
19090	48966	60.727173000000001	60.748328999999998	57.038679000000002	57.030273999999999	Кабакова	0103000020E6100000010000000500000061C43E01145D4E40A5F5B704E0834C4061C43E01145D4E406005F86EF3844C40FED2A23EC95F4E406005F86EF3844C40FED2A23EC95F4E40A5F5B704E0834C4061C43E01145D4E40A5F5B704E0834C40
19911	50105	60.832438000000003	60.927461999999998	57.078212999999998	57.037537999999998	Пушкина	0103000020E610000001000000050000004DF910548D6A4E40BA2D910BCE844C404DF910548D6A4E409F8F32E2028A4C4031242713B7764E409F8F32E2028A4C4031242713B7764E40BA2D910BCE844C404DF910548D6A4E40BA2D910BCE844C40
18605	49941	61.119638000000002	61.150036999999998	57.116712	57.108618999999997	Школьная	0103000020E61000000100000005000000EFAD484C508F4E40B35C363AE78D4C40EFAD484C508F4E407F86376BF08E4C405018946934934E407F86376BF08E4C405018946934934E40B35C363AE78D4C40EFAD484C508F4E40B35C363AE78D4C40
19168	15724	61.659041000000002	61.689591999999998	57.098562999999999	57.080077000000003	Молодежная	0103000020E6100000010000000500000090DC9A745BD44E40B61490F63F8A4C4090DC9A745BD44E403ECC5EB69D8C4C40A7CAF78C44D84E403ECC5EB69D8C4C40A7CAF78C44D84E40B61490F63F8A4C4090DC9A745BD44E40B61490F63F8A4C40
18599	15724	61.659041000000002	61.689591999999998	57.098562999999999	57.080077000000003	Гагарина	0103000020E6100000010000000500000090DC9A745BD44E40B61490F63F8A4C4090DC9A745BD44E403ECC5EB69D8C4C40A7CAF78C44D84E403ECC5EB69D8C4C40A7CAF78C44D84E40B61490F63F8A4C4090DC9A745BD44E40B61490F63F8A4C40
77438	61170	61.385593	61.405301999999999	57.127510999999998	57.101227000000002	Свободы	0103000020E610000001000000050000008448861C5BB14E40713C9F01F58C4C408448861C5BB14E40AC70CB4752904C406F8099EFE0B34E40AC70CB4752904C406F8099EFE0B34E40713C9F01F58C4C408448861C5BB14E40713C9F01F58C4C40
78595	61170	61.385593	61.405301999999999	57.127510999999998	57.101227000000002	Мопра	0103000020E610000001000000050000008448861C5BB14E40713C9F01F58C4C408448861C5BB14E40AC70CB4752904C406F8099EFE0B34E40AC70CB4752904C406F8099EFE0B34E40713C9F01F58C4C408448861C5BB14E40713C9F01F58C4C40
78472	6564	61.223672000000001	61.272126999999998	57.741318999999997	57.715792	Уральских Рабочих	0103000020E61000000100000005000000F583BA48A19C4E40855E7F129FDB4C40F583BA48A19C4E40A3737E8AE3DE4C40E6ADBA0ED5A24E40A3737E8AE3DE4C40E6ADBA0ED5A24E40855E7F129FDB4C40F583BA48A19C4E40855E7F129FDB4C40
18731	6564	61.223672000000001	61.272126999999998	57.741318999999997	57.715792	Спиридонова	0103000020E61000000100000005000000F583BA48A19C4E40855E7F129FDB4C40F583BA48A19C4E40A3737E8AE3DE4C40E6ADBA0ED5A24E40A3737E8AE3DE4C40E6ADBA0ED5A24E40855E7F129FDB4C40F583BA48A19C4E40855E7F129FDB4C40
20050	6271	61.495341000000003	61.526888999999997	57.755885999999997	57.740617999999998	Школьная	0103000020E6100000010000000500000019AF795567BF4E401A6A1492CCDE4C4019AF795567BF4E408BC058DFC0E04C40A2CF471971C34E408BC058DFC0E04C40A2CF471971C34E401A6A1492CCDE4C4019AF795567BF4E401A6A1492CCDE4C40
9669	6078	61.598773000000001	61.626620000000003	57.872748999999999	57.862011000000003	Мира	0103000020E61000000100000005000000295DFA97A4CC4E4069E55E6056EE4C40295DFA97A4CC4E40F04E3E3DB6EF4C4080828B1535D04E40F04E3E3DB6EF4C4080828B1535D04E4069E55E6056EE4C40295DFA97A4CC4E4069E55E6056EE4C40
18757	6141	61.380454999999998	61.410333000000001	57.762445	57.749158000000001	Калинина	0103000020E61000000100000005000000C24CDBBFB2B04E40B5C4CA68E4DF4C40C24CDBBFB2B04E40D6FF39CC97E14C401BBCAFCA85B44E40D6FF39CC97E14C401BBCAFCA85B44E40B5C4CA68E4DF4C40C24CDBBFB2B04E40B5C4CA68E4DF4C40
18634	2905	58.191175000000001	58.240420999999998	57.362991999999998	57.319763999999999	Первомайская	0103000020E610000001000000050000000A68226C78184D401538D906EEA84C400A68226C78184D40D55A988576AE4C40C422861DC61E4D40D55A988576AE4C40C422861DC61E4D401538D906EEA84C400A68226C78184D401538D906EEA84C40
20371	2905	58.191175000000001	58.240420999999998	57.362991999999998	57.319763999999999	Кирова	0103000020E610000001000000050000000A68226C78184D401538D906EEA84C400A68226C78184D40D55A988576AE4C40C422861DC61E4D40D55A988576AE4C40C422861DC61E4D401538D906EEA84C400A68226C78184D401538D906EEA84C40
78435	2670	58.706018	58.765594	57.270187999999997	57.236539999999998	Энгельса	0103000020E6100000010000000500000094313ECC5E5A4D40111956F1469E4C4094313ECC5E5A4D40C5E2378595A24C40C501F4FBFE614D40C5E2378595A24C40C501F4FBFE614D40111956F1469E4C4094313ECC5E5A4D40111956F1469E4C40
20363	2670	58.706018	58.765594	57.270187999999997	57.236539999999998	Свердлова	0103000020E6100000010000000500000094313ECC5E5A4D40111956F1469E4C4094313ECC5E5A4D40C5E2378595A24C40C501F4FBFE614D40C5E2378595A24C40C501F4FBFE614D40111956F1469E4C4094313ECC5E5A4D40111956F1469E4C40
20177	2670	58.706018	58.765594	57.270187999999997	57.236539999999998	Орджоникидзе	0103000020E6100000010000000500000094313ECC5E5A4D40111956F1469E4C4094313ECC5E5A4D40C5E2378595A24C40C501F4FBFE614D40C5E2378595A24C40C501F4FBFE614D40111956F1469E4C4094313ECC5E5A4D40111956F1469E4C40
19970	3638	57.940140999999997	59.742241999999997	57.696134000000001	57.011547999999998	Малышева	0103000020E610000001000000050000007A50508A56F84C40C72AA5677A814C407A50508A56F84C401CD13DEB1AD94C40DBDB2DC901DF4D401CD13DEB1AD94C40DBDB2DC901DF4D40C72AA5677A814C407A50508A56F84C40C72AA5677A814C40
20381	47506	58.760393000000001	58.801606999999997	57.326393000000003	57.300037000000003	Урицкого	0103000020E61000000100000005000000BD8DCD8E54614D40844BC79C67A64C40BD8DCD8E54614D405952EE3EC7A94C40519FE40E9B664D405952EE3EC7A94C40519FE40E9B664D40844BC79C67A64C40BD8DCD8E54614D40844BC79C67A64C40
18922	17069	59.302840000000003	59.370384999999999	57.243743000000002	57.216163000000002	Советская	0103000020E61000000100000005000000D8F50B76C3A64D4079CDAB3AAB9B4C40D8F50B76C3A64D4081D07AF8329F4C40E8F692C668AF4D4081D07AF8329F4C40E8F692C668AF4D4079CDAB3AAB9B4C40D8F50B76C3A64D4079CDAB3AAB9B4C40
18943	3365	58.925457999999999	58.954985999999998	57.206161000000002	57.189459999999997	Советская	0103000020E6100000010000000500000029E9616875764D4038F3AB3940984C4029E9616875764D40F75AD07B639A4C40A51133FB3C7A4D40F75AD07B639A4C40A51133FB3C7A4D4038F3AB3940984C4029E9616875764D4038F3AB3940984C40
78465	61299	57.940140999999997	59.742241999999997	57.696134000000001	57.011547999999998	Первомайская	0103000020E610000001000000050000007A50508A56F84C40C72AA5677A814C407A50508A56F84C401CD13DEB1AD94C40DBDB2DC901DF4D401CD13DEB1AD94C40DBDB2DC901DF4D40C72AA5677A814C407A50508A56F84C40C72AA5677A814C40
18280	47405	58.152062999999998	58.182398999999997	57.480038999999998	57.467292	Советская	0103000020E6100000010000000500000040F7E5CC76134D405AD76839D0BB4C4040F7E5CC76134D40FBE6FEEA71BD4C405BE9B5D958174D40FBE6FEEA71BD4C405BE9B5D958174D405AD76839D0BB4C4040F7E5CC76134D405AD76839D0BB4C40
17793	47595	59.169925999999997	59.195770000000003	57.401428000000003	57.389127999999999	Центральная	0103000020E61000000100000005000000BB5E9A22C0954D409CFA40F2CEB14C40BB5E9A22C0954D406FD921FE61B34C40DBC4C9FD0E994D406FD921FE61B34C40DBC4C9FD0E994D409CFA40F2CEB14C40BB5E9A22C0954D409CFA40F2CEB14C40
18639	3215	58.302503000000002	58.316490000000002	57.454045999999998	57.446201000000002	Школьная	0103000020E6100000010000000500000090F8156BB8264D40A438471D1DB94C4090F8156BB8264D409770E82D1EBA4C406AC18BBE82284D409770E82D1EBA4C406AC18BBE82284D40A438471D1DB94C4090F8156BB8264D40A438471D1DB94C40
20095	50147	58.265267999999999	58.287942000000001	57.400782999999997	57.386659000000002	Кропанцева	0103000020E610000001000000050000007156444DF4214D401FDAC70A7EB14C407156444DF4214D4079E57ADB4CB34C408A929048DB244D4079E57ADB4CB34C408A929048DB244D401FDAC70A7EB14C407156444DF4214D401FDAC70A7EB14C40
20384	3542	58.790379000000001	58.835419999999999	57.463594000000001	57.446390000000001	Школьная	0103000020E61000000100000005000000FC389A232B654D4077A1B94E23B94C40FC389A232B654D40984F560C57BB4C405036E50AEF6A4D40984F560C57BB4C405036E50AEF6A4D4077A1B94E23B94C40FC389A232B654D4077A1B94E23B94C40
18949	3480	58.951213000000003	58.980452999999997	57.374175000000001	57.358400000000003	Мира	0103000020E61000000100000005000000D943FB58C1794D4076711B0DE0AD4C40D943FB58C1794D408BFD65F7E4AF4C40EE21E17B7F7D4D408BFD65F7E4AF4C40EE21E17B7F7D4D4076711B0DE0AD4C40D943FB58C1794D4076711B0DE0AD4C40
20372	47367	58.211567000000002	58.228976000000003	57.369428999999997	57.358094000000001	8 Марта	0103000020E61000000100000005000000D8F4A0A0141B4D4069723106D6AD4C40D8F4A0A0141B4D40D498107349AF4C40D2C8E7154F1D4D40D498107349AF4C40D2C8E7154F1D4D4069723106D6AD4C40D8F4A0A0141B4D4069723106D6AD4C40
18942	29739	58.501407999999998	58.541032999999999	57.341132000000002	57.328505999999997	Луговая	0103000020E61000000100000005000000F4F928232E404D4017450F7C0CAA4C40F4F928232E404D403ECF9F36AAAB4C404487C09140454D403ECF9F36AAAB4C404487C09140454D4017450F7C0CAA4C40F4F928232E404D4017450F7C0CAA4C40
20188	50179	59.176608999999999	59.204259	57.119762000000001	57.102234000000003	Комсомольская	0103000020E61000000100000005000000F296AB1F9B964D400745F300168D4C40F296AB1F9B964D40DBA6785C548F4C40F374AE28259A4D40DBA6785C548F4C40F374AE28259A4D400745F300168D4C40F296AB1F9B964D400745F300168D4C40
20244	50203	58.674360999999998	58.693181000000003	57.590397000000003	57.581322	Железнодорожная	0103000020E610000001000000050000005359147651564D40003961C268CA4C405359147651564D400954FF2092CB4C40B39AAE27BA584D400954FF2092CB4C40B39AAE27BA584D40003961C268CA4C405359147651564D40003961C268CA4C40
19186	1743	63.480752000000003	63.511240999999998	58.095452000000002	58.082126000000002	Мира	0103000020E6100000010000000500000049BE124889BD4F405E13D21A830A4D4049BE124889BD4F403D2B69C5370C4D40EAAF575870C14F403D2B69C5370C4D40EAAF575870C14F405E13D21A830A4D4049BE124889BD4F405E13D21A830A4D40
19936	2212	63.204107	63.228459999999998	58.069986	58.060859000000001	Победы	0103000020E610000001000000050000003DF19C2D209A4F4069554B3ACA074D403DF19C2D209A4F40C4961E4DF5084D40DA38622D3E9D4F40C4961E4DF5084D40DA38622D3E9D4F4069554B3ACA074D403DF19C2D209A4F4069554B3ACA074D40
18604	1405	63.717198000000003	63.732244000000001	58.080379999999998	58.071232999999999	Садовая	0103000020E61000000100000005000000D960E124CDDB4F40AFB2B6291E094D40D960E124CDDB4F4051A04FE4490A4D409B58E02BBADD4F4051A04FE4490A4D409B58E02BBADD4F40AFB2B6291E094D40D960E124CDDB4F40AFB2B6291E094D40
18194	1516	63.744264000000001	63.783555999999997	58.104402999999998	58.087212999999998	Клубная	0103000020E610000001000000050000008ACBF10A44DF4F409D64ABCB290B4D408ACBF10A44DF4F40594DD7135D0D4D40D34A21904BE44F40594DD7135D0D4D40D34A21904BE44F409D64ABCB290B4D408ACBF10A44DF4F409D64ABCB290B4D40
19190	2104	63.379286999999998	63.403568999999997	58.083416	58.076549	Пионерская	0103000020E610000001000000050000002366F6798CB04F4050C58D5BCC094D402366F6798CB04F4048FB1F60AD0A4D40F7562426A8B34F4048FB1F60AD0A4D40F7562426A8B34F4050C58D5BCC094D402366F6798CB04F4050C58D5BCC094D40
18574	4	63.661197000000001	63.733224	58.068415000000002	58.014274	Спорта	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
19896	4	63.661197000000001	63.733224	58.068415000000002	58.014274	Путейцев	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
19125	4	63.661197000000001	63.733224	58.068415000000002	58.014274	Косогорная	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
19116	4	63.661197000000001	63.733224	58.068415000000002	58.014274	Ивашева	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
19139	4	63.661197000000001	63.733224	58.068415000000002	58.014274	Горького	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
18566	4	63.661197000000001	63.733224	58.068415000000002	58.014274	Гагарина	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
18571	4	63.661197000000001	63.733224	58.068415000000002	58.014274	8 Марта	0103000020E610000001000000050000004E9B711AA2D44F407097FDBAD3014D404E9B711AA2D44F4026C79DD2C1084D403752B648DADD4F4026C79DD2C1084D403752B648DADD4F407097FDBAD3014D404E9B711AA2D44F407097FDBAD3014D40
78527	1642	63.767969999999998	63.803220000000003	58.061644999999999	58.045487000000001	Молодёжная	0103000020E61000000100000005000000912749D74CE24F4053B29C84D2054D40912749D74CE24F40207BBDFBE3074D401FBFB7E9CFE64F40207BBDFBE3074D401FBFB7E9CFE64F4053B29C84D2054D40912749D74CE24F4053B29C84D2054D40
18889	1980	63.365533999999997	63.387245999999998	57.968089999999997	57.959220000000002	Гагарина	0103000020E61000000100000005000000BCC96FD1C9AE4F40A6D590B8C7FA4C40BCC96FD1C9AE4F40D5CA845FEAFB4C40DFC0E44691B14F40D5CA845FEAFB4C40DFC0E44691B14F40A6D590B8C7FA4C40BCC96FD1C9AE4F40A6D590B8C7FA4C40
18877	1184	63.850517000000004	63.886358999999999	57.862321999999999	57.848632000000002	Петереноко	0103000020E6100000010000000500000095D8B5BDDDEC4F40672B2FF99FEC4C4095D8B5BDDDEC4F40874F3A9160EE4C40F4C1323674F14F40874F3A9160EE4C40F4C1323674F14F40672B2FF99FEC4C4095D8B5BDDDEC4F40672B2FF99FEC4C40
18888	1855	63.494199999999999	63.534534000000001	58.043343	58.036811999999998	Советская	0103000020E6100000010000000500000073D712F241BF4F40D80C7041B6044D4073D712F241BF4F4059C16F438C054D40CF4C309C6BC44F4059C16F438C054D40CF4C309C6BC44F40D80C7041B6044D4073D712F241BF4F40D80C7041B6044D40
19944	2563	63.180974999999997	63.219279	58.161222000000002	58.149731000000003	Ленина	0103000020E61000000100000005000000613255302A974F404419AA622A134D40613255302A974F40A7B228ECA2144D408CD99255119C4F40A7B228ECA2144D408CD99255119C4F404419AA622A134D40613255302A974F404419AA622A134D40
18178	1054	63.787823000000003	63.818787999999998	57.977077999999999	57.962428000000003	Школьная	0103000020E61000000100000005000000B0045262D7E44F409A6038D730FB4C40B0045262D7E44F400FD253E410FD4C40BA2D910BCEE84F400FD253E410FD4C40BA2D910BCEE84F409A6038D730FB4C40B0045262D7E44F409A6038D730FB4C40
19151	946	63.708655	63.731634	58.008448000000001	58.000813000000001	Кирова	0103000020E61000000100000005000000CD920035B5DA4F40B134F0A31A004D40CD920035B5DA4F40BADBF5D214014D402252D32EA6DD4F40BADBF5D214014D402252D32EA6DD4F40B134F0A31A004D40CD920035B5DA4F40B134F0A31A004D40
19120	2334	63.058022999999999	63.082636999999998	58.073965000000001	58.062277999999999	Ленина	0103000020E6100000010000000500000039B5334C6D874F4051A1BAB9F8074D4039B5334C6D874F403A0664AF77094D40433866D9938A4F403A0664AF77094D40433866D9938A4F4051A1BAB9F8074D4039B5334C6D874F4051A1BAB9F8074D40
19164	1290	63.904065000000003	63.916884000000003	57.975603	57.960557000000001	Культуры	0103000020E61000000100000005000000A83AE466B8F34F40D1782288F3FA4C40A83AE466B8F34F409370218FE0FC4C40E31C75745CF54F409370218FE0FC4C40E31C75745CF54F40D1782288F3FA4C40A83AE466B8F34F40D1782288F3FA4C40
19039	2446	62.946002999999997	62.970123000000001	58.143498999999998	58.130780999999999	Свердлова	0103000020E610000001000000050000007D7555A016794F4016F88A6EBD104D407D7555A016794F401D01DC2C5E124D40780C8FFD2C7C4F401D01DC2C5E124D40780C8FFD2C7C4F4016F88A6EBD104D407D7555A016794F4016F88A6EBD104D40
78636	61340	64.070989999999995	65.237290999999999	57.397596999999998	56.734499	Победы	0103000020E61000000100000005000000F415A4198B045040ECF82F10045E4C40F415A4198B0450406DFE5F75E4B24C40A62897C62F4F50406DFE5F75E4B24C40A62897C62F4F5040ECF82F10045E4C40F415A4198B045040ECF82F10045E4C40
78575	61331	64.070989999999995	65.237290999999999	57.397596999999998	56.734499	Мира	0103000020E61000000100000005000000F415A4198B045040ECF82F10045E4C40F415A4198B0450406DFE5F75E4B24C40A62897C62F4F50406DFE5F75E4B24C40A62897C62F4F5040ECF82F10045E4C40F415A4198B045040ECF82F10045E4C40
19864	30264	64.705515000000005	64.727182999999997	57.127637999999997	57.116985999999997	переулок Школьный	0103000020E6100000010000000500000099F56228272D5040800BB265F98E4C4099F56228272D504009DD257156904C4042CD902A8A2E504009DD257156904C4042CD902A8A2E5040800BB265F98E4C4099F56228272D5040800BB265F98E4C40
18097	31428	64.242559	64.286064999999994	57.086924000000003	57.066426	Железнодорожная	0103000020E610000001000000050000006E162F16860F504053CDACA580884C406E162F16860F5040679E5C53208B4C40EFE192E34E125040679E5C53208B4C40EFE192E34E12504053CDACA580884C406E162F16860F504053CDACA580884C40
19858	31428	64.242559	64.286064999999994	57.086924000000003	57.066426	 Школьная	0103000020E610000001000000050000006E162F16860F504053CDACA580884C406E162F16860F5040679E5C53208B4C40EFE192E34E125040679E5C53208B4C40EFE192E34E12504053CDACA580884C406E162F16860F504053CDACA580884C40
18133	31802	64.431098000000006	64.445910999999995	57.202232000000002	57.192073999999998	Школьная	0103000020E61000000100000005000000BFD7101C971B5040B9347EE195984C40BFD7101C971B5040331AF9BCE2994C404E7B4ACE891C5040331AF9BCE2994C404E7B4ACE891C5040B9347EE195984C40BFD7101C971B5040B9347EE195984C40
20269	29557	64.775665000000004	64.806019000000006	57.058262999999997	57.050597000000003	Молодежная	0103000020E61000000100000005000000B8E9CF7EA43150404B2366F679864C40B8E9CF7EA43150408EC8772975874C40193DB7D0953350408EC8772975874C40193DB7D0953350404B2366F679864C40B8E9CF7EA43150404B2366F679864C40
18843	20423	64.603862000000007	64.617497999999998	57.160024	57.154800999999999	Новая	0103000020E610000001000000050000000553CDACA5265040AD31E884D0934C400553CDACA52650409D499BAA7B944C401BD65416852750409D499BAA7B944C401BD6541685275040AD31E884D0934C400553CDACA5265040AD31E884D0934C40
19385	20436	64.616536999999994	64.663645000000002	57.068618000000001	57.047694	Школьная	0103000020E6100000010000000500000088F19A5775275040931B45D61A864C4088F19A57752750405EF58079C8884C40DAC9E028792A50405EF58079C8884C40DAC9E028792A5040931B45D61A864C4088F19A5775275040931B45D61A864C40
18781	20436	64.616536999999994	64.663645000000002	57.068618000000001	57.047694	Войкова	0103000020E6100000010000000500000088F19A5775275040931B45D61A864C4088F19A57752750405EF58079C8884C40DAC9E028792A50405EF58079C8884C40DAC9E028792A5040931B45D61A864C4088F19A5775275040931B45D61A864C40
19879	32024	64.393655999999993	64.421486000000002	57.3371	57.317689000000001	Парковая	0103000020E61000000100000005000000F277EFA83119504044A67C08AAA84C40F277EFA831195040A5BDC11726AB4C40336E6AA0F91A5040A5BDC11726AB4C40336E6AA0F91A504044A67C08AAA84C40F277EFA83119504044A67C08AAA84C40
19849	31216	64.277252000000004	64.291355999999993	56.844445999999998	56.836272999999998	8 Марта	0103000020E610000001000000050000000A302C7FBE1150408FC360FE0A6B4C400A302C7FBE115040779E78CE166C4C4093DFA293A5125040779E78CE166C4C4093DFA293A51250408FC360FE0A6B4C400A302C7FBE1150408FC360FE0A6B4C40
78526	29979	64.959029000000001	64.973652999999999	57.180543999999998	57.167681999999999	Школьная	0103000020E6100000010000000500000099BA2BBB603D50405E10919A76954C4099BA2BBB603D504098BED7101C974C40BF29AC54503E504098BED7101C974C40BF29AC54503E50405E10919A76954C4099BA2BBB603D50405E10919A76954C40
18120	31752	64.539354000000003	64.571297999999999	57.094611999999998	57.079289000000003	Молодежная	0103000020E61000000100000005000000E0BDA3C6842250405EF75624268A4C40E0BDA3C68422504092E7FA3E1C8C4C404B917C259024504092E7FA3E1C8C4C404B917C25902450405EF75624268A4C40E0BDA3C6842250405EF75624268A4C40
18819	49960	64.871982000000003	64.890775000000005	56.984755	56.978821000000003	Речная	0103000020E61000000100000005000000D82C978DCE375040ABD1AB014A7D4C40D82C978DCE37504047C9AB730C7E4C400B4625750239504047C9AB730C7E4C400B46257502395040ABD1AB014A7D4C40D82C978DCE375040ABD1AB014A7D4C40
18791	30619	64.425286	64.453142	56.959724999999999	56.954374999999999	Центральная	0103000020E61000000100000005000000965CC5E2371B50405C8FC2F5287A4C40965CC5E2371B5040A913D044D87A4C406B9C4D47001D5040A913D044D87A4C406B9C4D47001D50405C8FC2F5287A4C40965CC5E2371B50405C8FC2F5287A4C40
17978	28609	64.947405000000003	64.962504999999993	57.070785999999998	57.062486	Центральная	0103000020E6100000010000000500000048C49448A23C50409B3A8F8AFF874C4048C49448A23C5040E08101840F894C40224F92AE993D5040E08101840F894C40224F92AE993D50409B3A8F8AFF874C4048C49448A23C50409B3A8F8AFF874C40
19000	30726	64.536379999999994	64.562862999999993	56.945799000000001	56.933822999999997	Центральная	0103000020E610000001000000050000009F8EC70C5422504055A0168387774C409F8EC70C5422504075CB0EF10F794C40384888F20524504075CB0EF10F794C40384888F20524504055A0168387774C409F8EC70C5422504055A0168387774C40
20115	32281	64.717606000000004	64.729463999999993	57.089267	57.078887999999999	Центральная	0103000020E61000000100000005000000755AB741ED2D5040FF058200198A4C40755AB741ED2D504057CEDE196D8B4C40FFE6C589AF2E504057CEDE196D8B4C40FFE6C589AF2E5040FF058200198A4C40755AB741ED2D5040FF058200198A4C40
18767	29835	64.846856000000002	64.879302999999993	57.099800000000002	57.090519	Привокзальная	0103000020E61000000100000005000000F81A82E33236504054556820968B4C40F81A82E3323650400612143FC68C4C4094111780463850400612143FC68C4C40941117804638504054556820968B4C40F81A82E33236504054556820968B4C40
18821	30516	64.749208999999993	64.766619000000006	56.860185999999999	56.853369999999998	Клубная	0103000020E610000001000000050000009B374E0AF32F50409AB1683A3B6D4C409B374E0AF32F5040103D29931A6E4C40815F234910315040103D29931A6E4C40815F2349103150409AB1683A3B6D4C409B374E0AF32F50409AB1683A3B6D4C40
18721	31894	64.384754000000001	64.391176999999999	57.286672000000003	57.279837000000001	Школьная	0103000020E6100000010000000500000055C03DCF9F185040FA9AE5B2D1A34C4055C03DCF9F185040E75608ABB1A44C40A27C410B09195040E75608ABB1A44C40A27C410B09195040FA9AE5B2D1A34C4055C03DCF9F185040FA9AE5B2D1A34C40
19121	32107	64.217865000000003	64.244742000000002	57.374267000000003	57.351883999999998	Школьная	0103000020E610000001000000050000005B7C0A80F10D50402AFEEF880AAD4C405B7C0A80F10D50406C7C26FBE7AF4C404A7D59DAA90F50406C7C26FBE7AF4C404A7D59DAA90F50402AFEEF880AAD4C405B7C0A80F10D50402AFEEF880AAD4C40
17898	30410	65.001259000000005	65.047701000000004	56.873972000000002	56.851253999999997	Победы	0103000020E61000000100000005000000D8F4A0A0144050406A4B1DE4F56C4C40D8F4A0A01440504053CF8250DE6F4C4023BF7E880D43504053CF8250DE6F4C4023BF7E880D4350406A4B1DE4F56C4C40D8F4A0A0144050406A4B1DE4F56C4C40
78524	48891	64.571639000000005	64.580568	57.082174999999999	57.073515999999998	Центральная	0103000020E610000001000000050000009087BEBB95245040CADDE7F868894C409087BEBB952450403FC6DCB5848A4C40AA46AF06282550403FC6DCB5848A4C40AA46AF0628255040CADDE7F868894C409087BEBB95245040CADDE7F868894C40
19354	31317	64.273345000000006	64.311487	56.806545	56.780458000000003	Кирова	0103000020E610000001000000050000009CE1067C7E11504067F3380CE6634C409CE1067C7E1150404CE0D6DD3C674C4044882B67EF1350404CE0D6DD3C674C4044882B67EF13504067F3380CE6634C409CE1067C7E11504067F3380CE6634C40
78551	61323	64.379812999999999	64.403420999999994	56.963621000000003	56.958041000000001	Школьная	0103000020E610000001000000050000001F662FDB4E185040139D6516A17A4C401F662FDB4E185040925ED4EE577B4C40416150A6D1195040925ED4EE577B4C40416150A6D1195040139D6516A17A4C401F662FDB4E185040139D6516A17A4C40
18628	30122	64.888996000000006	64.906234999999995	57.262990000000002	57.247537000000001	Центральная	0103000020E6100000010000000500000097917A4FE538504065C6DB4AAF9F4C4097917A4FE5385040689604A8A9A14C4065DF15C1FF395040689604A8A9A14C4065DF15C1FF39504065C6DB4AAF9F4C4097917A4FE538504065C6DB4AAF9F4C40
18769	20487	64.890396999999993	64.919368000000006	57.127212999999998	57.107005999999998	Филиппова	0103000020E6100000010000000500000037DDB243FC385040E63C635FB28D4C4037DDB243FC3850402250FD8348904C404B3FE1ECD63A50402250FD8348904C404B3FE1ECD63A5040E63C635FB28D4C4037DDB243FC385040E63C635FB28D4C40
20295	31130	64.269553999999999	64.291220999999993	56.920741999999997	56.907397000000003	8 марта	0103000020E6100000010000000500000062A06B5F4011504088BEBB9525744C4062A06B5F40115040DD06B5DFDA754C4023BA675DA3125040DD06B5DFDA754C4023BA675DA312504088BEBB9525744C4062A06B5F4011504088BEBB9525744C40
20185	50177	64.505936000000005	64.555452000000002	56.967953999999999	56.947904999999999	Клубная	0103000020E610000001000000050000009F77634161205040815B77F354794C409F776341612050402504ABEAE57B4C40DC9F8B868C2350402504ABEAE57B4C40DC9F8B868C235040815B77F354794C409F77634161205040815B77F354794C40
20281	50210	64.746810999999994	64.762944000000005	57.165202999999998	57.154429999999998	Юбилейная	0103000020E61000000100000005000000C1525DC0CB2F5040B9C2BB5CC4934C40C1525DC0CB2F5040BD19355F25954C407C2B1213D4305040BD19355F25954C407C2B1213D4305040B9C2BB5CC4934C40C1525DC0CB2F5040B9C2BB5CC4934C40
20254	49141	63.873629999999999	63.890959000000002	57.099784999999997	57.089379000000001	Совхозная	0103000020E61000000100000005000000F9669B1BD3EF4F407FF964C5708B4C40F9669B1BD3EF4F40D0D03FC1C58C4C40D789CBF10AF24F40D0D03FC1C58C4C40D789CBF10AF24F407FF964C5708B4C40F9669B1BD3EF4F407FF964C5708B4C40
18311	20551	63.697083999999997	63.786645999999998	57.073681999999998	57.047320999999997	Мичурина	0103000020E610000001000000050000004D486B0C3AD94F40FEB4519D0E864C404D486B0C3AD94F40E5266A696E894C40BDC3EDD0B0E44F40E5266A696E894C40BDC3EDD0B0E44F40FEB4519D0E864C404D486B0C3AD94F40FEB4519D0E864C40
17797	20551	63.697083999999997	63.786645999999998	57.073681999999998	57.047320999999997	Ленина	0103000020E610000001000000050000004D486B0C3AD94F40FEB4519D0E864C404D486B0C3AD94F40E5266A696E894C40BDC3EDD0B0E44F40E5266A696E894C40BDC3EDD0B0E44F40FEB4519D0E864C404D486B0C3AD94F40FEB4519D0E864C40
77088	20551	63.697083999999997	63.786645999999998	57.073681999999998	57.047320999999997	Комарова	0103000020E610000001000000050000004D486B0C3AD94F40FEB4519D0E864C404D486B0C3AD94F40E5266A696E894C40BDC3EDD0B0E44F40E5266A696E894C40BDC3EDD0B0E44F40FEB4519D0E864C404D486B0C3AD94F40FEB4519D0E864C40
19977	20551	63.697083999999997	63.786645999999998	57.073681999999998	57.047320999999997	Железнодорожная	0103000020E610000001000000050000004D486B0C3AD94F40FEB4519D0E864C404D486B0C3AD94F40E5266A696E894C40BDC3EDD0B0E44F40E5266A696E894C40BDC3EDD0B0E44F40FEB4519D0E864C404D486B0C3AD94F40FEB4519D0E864C40
18987	27765	63.594892000000002	63.614080000000001	56.639352000000002	56.623756999999998	Мира	0103000020E610000001000000050000007653CA6B25CC4F4056D3F544D74F4C407653CA6B25CC4F40EC504D49D6514C405890662C9ACE4F40EC504D49D6514C405890662C9ACE4F4056D3F544D74F4C407653CA6B25CC4F4056D3F544D74F4C40
18656	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Советская	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
18650	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Рябиновая	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
19142	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Нахимова	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
19273	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Луначарского	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
18972	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Лермонтова	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
18797	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Ленина	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
19904	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Красноармейская	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
19321	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Калинина	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
18653	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Запышминская	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
18179	26266	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Заозерная	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
17772	49835	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Урга	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
20044	49076	63.732531999999999	63.764843999999997	57.114015000000002	57.096221	Советская	0103000020E6100000010000000500000001A3CB9BC3DD4F401E1840F8508C4C4001A3CB9BC3DD4F407120240B988E4C405A457F68E6E14F407120240B988E4C405A457F68E6E14F401E1840F8508C4C4001A3CB9BC3DD4F401E1840F8508C4C40
19016	28389	64.061898999999997	64.082847999999998	57.107832000000002	57.098421000000002	Фестивальная	0103000020E61000000100000005000000ED293927F6035040AC1E300F998C4C40ED293927F60350402CBB6070CD8D4C407FA2B2614D0550402CBB6070CD8D4C407FA2B2614D055040AC1E300F998C4C40ED293927F6035040AC1E300F998C4C40
17822	48616	64.103005999999993	64.119103999999993	56.691108	56.684049000000002	Советская	0103000020E61000000100000005000000AC527AA69706504046EEE9EA8E574C40AC527AA6970650408200193A76584C40A83462669F0750408200193A76584C40A83462669F07504046EEE9EA8E574C40AC527AA69706504046EEE9EA8E574C40
18998	49228	63.462336999999998	63.481434999999998	57.189138	57.174826000000003	Береговая	0103000020E61000000100000005000000895DDBDB2DBB4F40C93EC8B260964C40895DDBDB2DBB4F4026378AAC35984C402B137EA99FBD4F4026378AAC35984C402B137EA99FBD4F40C93EC8B260964C40895DDBDB2DBB4F40C93EC8B260964C40
20395	27200	64.087779999999995	64.111962000000005	56.650750000000002	56.641134000000001	Победы	0103000020E610000001000000050000008B4F01309E055040452DCDAD10524C408B4F01309E0550409EEFA7C64B534C404419AA622A0750409EEFA7C64B534C404419AA622A075040452DCDAD10524C408B4F01309E055040452DCDAD10524C40
18674	28192	64.017397000000003	64.03998	57.018653999999998	57.008209999999998	Советская	0103000020E610000001000000050000001B834E081D01504005C078060D814C401B834E081D01504044F8174163824C409F1F46088F02504044F8174163824C409F1F46088F02504005C078060D814C401B834E081D01504005C078060D814C40
18403	28285	63.707684999999998	63.722830000000002	56.953688	56.948622	Центральная	0103000020E61000000100000005000000546F0D6C95DA4F40102219726C794C40546F0D6C95DA4F40384BC972127A4C40AA4885B185DC4F40384BC972127A4C40AA4885B185DC4F40102219726C794C40546F0D6C95DA4F40102219726C794C40
20399	48970	64.064117999999993	64.082012000000006	57.188586999999998	57.180934000000001	Ленина	0103000020E610000001000000050000006F4562821A045040035E66D828974C406F4562821A045040B2B96A9E23984C404B7842AF3F055040B2B96A9E23984C404B7842AF3F055040035E66D828974C406F4562821A045040035E66D828974C40
17852	48736	63.758673000000002	63.882883	56.694094	56.664762000000003	Центральная	0103000020E61000000100000005000000DAAD65321CE14F40D1CFD4EB16554C40DAAD65321CE14F40C72C7B12D8584C40E198654F02F14F40C72C7B12D8584C40E198654F02F14F40D1CFD4EB16554C40DAAD65321CE14F40D1CFD4EB16554C40
19013	49024	63.931688000000001	63.953113000000002	57.124594000000002	57.110436999999997	70 лет Октября	0103000020E61000000100000005000000AF09698D41F74F4059A2B3CC228E4C40AF09698D41F74F4090A339B2F28F4C403C32569BFFF94F4090A339B2F28F4C403C32569BFFF94F4059A2B3CC228E4C40AF09698D41F74F4059A2B3CC228E4C40
17854	27666	63.733808000000003	63.760182	56.671978000000003	56.650364000000003	Набережная	0103000020E6100000010000000500000087C5A86BEDDD4F40753FA7203F534C4087C5A86BEDDD4F40D5D0066003564C400281CEA44DE14F40D5D0066003564C400281CEA44DE14F40753FA7203F534C4087C5A86BEDDD4F40753FA7203F534C40
19995	48687	63.887860000000003	63.912959000000001	56.609952999999997	56.596139000000001	Уральская	0103000020E610000001000000050000009AB67F65A5F14F40616F62484E4C4C409AB67F65A5F14F406D8C9DF0124E4C4060CB2BD7DBF44F406D8C9DF0124E4C4060CB2BD7DBF44F40616F62484E4C4C409AB67F65A5F14F40616F62484E4C4C40
17994	28894	63.533482999999997	63.584876000000001	57.143932	57.114381000000002	Ленина	0103000020E6100000010000000500000069FCC22B49C44F4053245F09A48E4C4069FCC22B49C44F40876C205D6C924C408F1B7E37DDCA4F40876C205D6C924C408F1B7E37DDCA4F4053245F09A48E4C4069FCC22B49C44F4053245F09A48E4C40
20223	27661	63.722785000000002	63.739457999999999	56.643619000000001	56.627059000000003	Новая	0103000020E610000001000000050000000A85083884DC4F40CCD4247843504C400A85083884DC4F40C80A7E1B62524C40FE614B8FA6DE4F40C80A7E1B62524C40FE614B8FA6DE4F40CCD4247843504C400A85083884DC4F40CCD4247843504C40
20045	28744	63.619317000000002	63.650803000000003	57.092030000000001	57.079963999999997	Советская	0103000020E61000000100000005000000AD6D8AC745CF4F40BD6DA6423C8A4C40AD6D8AC745CF4F401D2098A3C78B4C40C19140834DD34F401D2098A3C78B4C40C19140834DD34F40BD6DA6423C8A4C40AD6D8AC745CF4F40BD6DA6423C8A4C40
77900	61266	63.324418000000001	63.359164999999997	57.216343999999999	57.197673000000002	Победы	0103000020E61000000100000005000000EB1D6E8786A94F40AF264F594D994C40EB1D6E8786A94F40C9570229B19B4C40156F641EF9AD4F40C9570229B19B4C40156F641EF9AD4F40AF264F594D994C40EB1D6E8786A94F40AF264F594D994C40
20413	27527	63.961872	63.991048999999997	56.702258	56.691983	Центральная	0103000020E610000001000000050000001478279F1EFB4F40A93121E692584C401478279F1EFB4F405CAD1397E3594C40E3DD91B1DAFE4F405CAD1397E3594C40E3DD91B1DAFE4F40A93121E692584C401478279F1EFB4F40A93121E692584C40
19324	27380	64.010327000000004	64.039306999999994	56.548484999999999	56.538876999999999	переулок Центральный	0103000020E6100000010000000500000003D19332A900504086C8E9EBF9444C4003D19332A90050405CACA8C134464C403FE08101840250405CACA8C134464C403FE081018402504086C8E9EBF9444C4003D19332A900504086C8E9EBF9444C40
20211	26977	63.758574000000003	63.810389000000001	56.729565999999998	56.71219	Строителей	0103000020E6100000010000000500000047CCECF318E14F40E544BB0A295B4C4047CCECF318E14F4003232F6B625D4C40E204A6D3BAE74F4003232F6B625D4C40E204A6D3BAE74F40E544BB0A295B4C4047CCECF318E14F40E544BB0A295B4C40
17808	26977	63.758574000000003	63.810389000000001	56.729565999999998	56.71219	Совхозная	0103000020E6100000010000000500000047CCECF318E14F40E544BB0A295B4C4047CCECF318E14F4003232F6B625D4C40E204A6D3BAE74F4003232F6B625D4C40E204A6D3BAE74F40E544BB0A295B4C4047CCECF318E14F40E544BB0A295B4C40
18971	26977	63.758574000000003	63.810389000000001	56.729565999999998	56.71219	Карла Маркса	0103000020E6100000010000000500000047CCECF318E14F40E544BB0A295B4C4047CCECF318E14F4003232F6B625D4C40E204A6D3BAE74F4003232F6B625D4C40E204A6D3BAE74F40E544BB0A295B4C4047CCECF318E14F40E544BB0A295B4C40
17819	48569	63.780565000000003	63.790770000000002	56.814793999999999	56.805486000000002	Школьная	0103000020E610000001000000050000007DB3CD8DE9E34F4064B14D2A1A674C407DB3CD8DE9E34F400F7D772B4B684C4037548CF337E54F400F7D772B4B684C4037548CF337E54F4064B14D2A1A674C407DB3CD8DE9E34F4064B14D2A1A674C40
19377	49097	63.459147999999999	63.467879000000003	57.058684	57.048017000000002	Победы	0103000020E610000001000000050000000C03965CC5BA4F407653CA6B25864C400C03965CC5BA4F40346612F582874C401BBE8575E3BB4F40346612F582874C401BBE8575E3BB4F407653CA6B25864C400C03965CC5BA4F407653CA6B25864C40
18977	48938	64.184070000000006	64.217001999999994	56.992190000000001	56.984617999999998	Клубная	0103000020E610000001000000050000002F8B89CDC70B5040C6866EF6077E4C402F8B89CDC70B504089B5F814007F4C40A94A5B5CE30D504089B5F814007F4C40A94A5B5CE30D5040C6866EF6077E4C402F8B89CDC70B5040C6866EF6077E4C40
20000	28749	63.672353999999999	63.704711000000003	57.021025000000002	57.007049000000002	Буденного	0103000020E61000000100000005000000DAAA24B20FD64F40193C4CFBE6804C40DAAA24B20FD64F40FFB27BF2B0824C40D41055F833DA4F40FFB27BF2B0824C40D41055F833DA4F40193C4CFBE6804C40DAAA24B20FD64F40193C4CFBE6804C40
19337	27756	63.677222999999998	63.701360000000001	56.618397999999999	56.598194999999997	Ленина	0103000020E61000000100000005000000AC8C463EAFD64F40BBD05CA7914C4C40AC8C463EAFD64F40B6F468AA274F4C407D5C1B2AC6D94F40B6F468AA274F4C407D5C1B2AC6D94F40BBD05CA7914C4C40AC8C463EAFD64F40BBD05CA7914C4C40
9908	40352	64.019938999999994	64.049008000000001	57.172015000000002	57.156748999999998	Жданова	0103000020E610000001000000050000008E3A3AAE460150402157EA5910944C408E3A3AAE46015040F2B5679604964C40834F73F222035040F2B5679604964C40834F73F2220350402157EA5910944C408E3A3AAE460150402157EA5910944C40
20273	50207	63.699564000000002	63.779774000000003	57.041063999999999	56.996867000000002	Вокзальная	0103000020E61000000100000005000000BFBA2A508BD94F4017BB7D56997F4C40BFBA2A508BD94F407F85CC9541854C40B4226AA2CFE34F407F85CC9541854C40B4226AA2CFE34F4017BB7D56997F4C40BFBA2A508BD94F4017BB7D56997F4C40
19115	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Шоссейная	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
18209	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Чехова	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
19920	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Строителей	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
77086	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Свердлова	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
19201	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Рабочая	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
77085	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Пушкина	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
19926	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Омская	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
78429	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Нахимова	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
19946	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Матросова	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
20164	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Ломоносова	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
18199	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Лесопильщиков	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
17997	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Ленина	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
19049	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Куйбышева	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
19938	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Кирова	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
20136	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Кардонская	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
18151	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	К. Маркса	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
20154	24821	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	9е Января	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
18903	48151	65.053090999999995	65.079815999999994	58.110218000000003	58.102415000000001	Центральная	0103000020E61000000100000005000000902DCBD76543504057CF49EF1B0D4D40902DCBD7654350401CB7989F1B0E4D40A46C91B41B4550401CB7989F1B0E4D40A46C91B41B45504057CF49EF1B0D4D40902DCBD76543504057CF49EF1B0D4D40
18412	25930	65.189429000000004	65.207575000000006	57.955868000000002	57.947581999999997	Советская	0103000020E610000001000000050000007FFACF9A1F4C50409E23F25D4AF94C407FFACF9A1F4C50407FA5F3E159FA4C40E71DA7E8484D50407FA5F3E159FA4C40E71DA7E8484D50409E23F25D4AF94C407FFACF9A1F4C50409E23F25D4AF94C40
20203	50186	65.207223999999997	65.346875999999995	58.101202000000001	58.004103000000001	Герцена	0103000020E6100000010000000500000090BC7328434D50406268757286004D4090BC7328434D50401825E82FF40C4D401BF16437335650401825E82FF40C4D401BF16437335650406268757286004D4090BC7328434D50406268757286004D40
78543	61320	64.052987999999999	64.067666000000003	58.895747999999998	58.882531999999998	Центральная	0103000020E6100000010000000500000026C5C7276403504034D6FECEF6704D4026C5C727640350408CBAD6DEA7724D404643C6A3540450408CBAD6DEA7724D404643C6A35404504034D6FECEF6704D4026C5C7276403504034D6FECEF6704D40
19914	24728	64.342605000000006	64.360992999999993	58.349355000000003	58.343994000000002	Лесная	0103000020E610000001000000050000008D9C853DED1550409702D2FE072C4D408D9C853DED155040D8D825AAB72C4D406F4562821A175040D8D825AAB72C4D406F4562821A1750409702D2FE072C4D408D9C853DED1550409702D2FE072C4D40
19900	6924	64.526993000000004	64.575959999999995	58.531281999999997	58.511538999999999	Октябрьская	0103000020E61000000100000005000000240ED940BA21504074D0251C7A414D40240ED940BA2150400B7A6F0C01444D4077F35487DC2450400B7A6F0C01444D4077F35487DC24504074D0251C7A414D40240ED940BA21504074D0251C7A414D40
17796	6924	64.526993000000004	64.575959999999995	58.531281999999997	58.511538999999999	Молодежная	0103000020E61000000100000005000000240ED940BA21504074D0251C7A414D40240ED940BA2150400B7A6F0C01444D4077F35487DC2450400B7A6F0C01444D4077F35487DC24504074D0251C7A414D40240ED940BA21504074D0251C7A414D40
18857	6924	64.526993000000004	64.575959999999995	58.531281999999997	58.511538999999999	Красноармейская	0103000020E61000000100000005000000240ED940BA21504074D0251C7A414D40240ED940BA2150400B7A6F0C01444D4077F35487DC2450400B7A6F0C01444D4077F35487DC24504074D0251C7A414D40240ED940BA21504074D0251C7A414D40
18590	24428	64.950907999999998	64.966575000000006	58.622644000000001	58.607332	Центральная 	0103000020E610000001000000050000004E603AADDB3C50403AE8120EBD4D4D404E603AADDB3C50407B8670CCB24F4D406688635DDC3D50407B8670CCB24F4D406688635DDC3D50403AE8120EBD4D4D404E603AADDB3C50403AE8120EBD4D4D40
18156	23978	64.356295000000003	64.394661999999997	58.828736999999997	58.826188999999999	Центральная	0103000020E610000001000000050000009D2E8B89CD16504050A8A78FC0694D409D2E8B89CD16504019FED30D146A4D4055BE67244219504019FED30D146A4D4055BE67244219504050A8A78FC0694D409D2E8B89CD16504050A8A78FC0694D40
20331	24531	64.759504000000007	64.779824000000005	58.275852	58.266263000000002	Советская	0103000020E61000000100000005000000994BAAB69B3050404391EEE714224D40994BAAB69B305040A2444B1E4F234D40B328ECA2E8315040A2444B1E4F234D40B328ECA2E83150404391EEE714224D40994BAAB69B3050404391EEE714224D40
18166	24275	64.763214000000005	64.796379999999999	58.467550000000003	58.456035999999997	Южная	0103000020E610000001000000050000005C76887FD83050403AE63C635F3A4D405C76887FD8305040569FABADD83B4D4010CCD1E3F7325040569FABADD83B4D4010CCD1E3F73250403AE63C635F3A4D405C76887FD83050403AE63C635F3A4D40
18595	24572	64.358011000000005	64.368970000000004	58.276868999999998	58.264814000000001	Центральная 	0103000020E61000000100000005000000EE26F8A6E9165040F0C2D66CE5214D40EE26F8A6E91650405B23827170234D4021CD58349D1750405B23827170234D4021CD58349D175040F0C2D66CE5214D40EE26F8A6E9165040F0C2D66CE5214D40
20319	23524	60.916817000000002	60.958587999999999	56.315320999999997	56.284523999999998	Ленина	0103000020E610000001000000050000005BB56B425A754E40AB764D486B244C405BB56B425A754E40FA5E43705C284C40452BF702B37A4E40FA5E43705C284C40452BF702B37A4E40AB764D486B244C405BB56B425A754E40AB764D486B244C40
78428	23456	60.927992000000003	60.958202	56.607658999999998	56.592536000000003	Ленина	0103000020E610000001000000050000008E791D71C8764E40F1D93A38D84B4C408E791D71C8764E405E0F26C5C74D4C401C7BF65CA67A4E405E0F26C5C74D4C401C7BF65CA67A4E40F1D93A38D84B4C408E791D71C8764E40F1D93A38D84B4C40
78446	61109	60.781261000000001	60.852865000000001	56.522823000000002	56.474643999999998	Энгельса	0103000020E61000000100000005000000F451465C00644E400E9F7422C13C4C40F451465C00644E405E4C33DDEB424C40977329AE2A6D4E405E4C33DDEB424C40977329AE2A6D4E400E9F7422C13C4C40F451465C00644E400E9F7422C13C4C40
78583	46984	60.788753	60.810941	56.700879	56.682001999999997	Колхозная	0103000020E610000001000000050000009ACFB9DBF5644E403EE76ED74B574C409ACFB9DBF5644E4002BA2F67B6594C4026FE28EACC674E4002BA2F67B6594C4026FE28EACC674E403EE76ED74B574C409ACFB9DBF5644E403EE76ED74B574C40
20109	50152	60.788753	60.810941	56.700879	56.682001999999997	Колхозная	0103000020E610000001000000050000009ACFB9DBF5644E403EE76ED74B574C409ACFB9DBF5644E4002BA2F67B6594C4026FE28EACC674E4002BA2F67B6594C4026FE28EACC674E403EE76ED74B574C409ACFB9DBF5644E403EE76ED74B574C40
20103	46892	61.058875999999998	61.093964	56.248876000000003	56.237161999999998	Мира	0103000020E610000001000000050000007842AF3F89874E404EED0C535B1E4C407842AF3F89874E403161342BDB1F4C402C802903078C4E403161342BDB1F4C402C802903078C4E404EED0C535B1E4C407842AF3F89874E404EED0C535B1E4C40
18844	46842	60.892229999999998	60.927632000000003	56.268216000000002	56.253712	1Мая	0103000020E610000001000000050000004A41B79734724E40274D83A279204C404A41B79734724E40C921E2E654224C408E5C37A5BC764E40C921E2E654224C408E5C37A5BC764E40274D83A279204C404A41B79734724E40274D83A279204C40
19982	50123	61.052570000000003	61.077300999999999	56.642674	56.617213999999997	Ленина	0103000020E6100000010000000500000018601F9DBA864E4011514CDE004F4C4018601F9DBA864E40A8FE412443524C405B79C9FFE4894E40A8FE412443524C405B79C9FFE4894E4011514CDE004F4C4018601F9DBA864E4011514CDE004F4C40
20306	22809	61.080337	61.109217999999998	56.608218999999998	56.585982999999999	Озерная	0103000020E6100000010000000500000052D4997B488A4E408881AE7D014B4C4052D4997B488A4E4025E7C41EDA4D4C403811FDDAFA8D4E4025E7C41EDA4D4C403811FDDAFA8D4E408881AE7D014B4C4052D4997B488A4E408881AE7D014B4C40
18387	22809	61.080337	61.109217999999998	56.608218999999998	56.585982999999999	Клубная	0103000020E6100000010000000500000052D4997B488A4E408881AE7D014B4C4052D4997B488A4E4025E7C41EDA4D4C403811FDDAFA8D4E4025E7C41EDA4D4C403811FDDAFA8D4E408881AE7D014B4C4052D4997B488A4E408881AE7D014B4C40
18733	22738	60.739668999999999	60.769834000000003	56.446846999999998	56.427791999999997	Ленина	0103000020E61000000100000005000000B96E4A79AD5E4E40C6BE64E3C1364C40B96E4A79AD5E4E4069A8514832394C40A8ACA6EB89624E4069A8514832394C40A8ACA6EB89624E40C6BE64E3C1364C40B96E4A79AD5E4E40C6BE64E3C1364C40
18131	46869	60.956710999999999	60.982618000000002	56.258743000000003	56.249195999999998	Ленина	0103000020E610000001000000050000009A5C8C81757A4E40A2258FA7E51F4C409A5C8C81757A4E40D388997D1E214C40003B376DC67D4E40D388997D1E214C40003B376DC67D4E40A2258FA7E51F4C409A5C8C81757A4E40A2258FA7E51F4C40
19122	47021	60.796405999999998	60.826599000000002	56.690306999999997	56.656916000000002	Садовая	0103000020E61000000100000005000000492BBEA1F0654E400D1CD0D215544C40492BBEA1F0654E409599D2FA5B584C4002F4FBFECD694E409599D2FA5B584C4002F4FBFECD694E400D1CD0D215544C40492BBEA1F0654E400D1CD0D215544C40
18530	46689	60.720948	60.812226000000003	56.732573000000002	56.708795000000002	Трудова	0103000020E61000000100000005000000ED0E2906485C4E40BF4868CBB95A4C40ED0E2906485C4E406077BAF3C45D4C40FF7A8505F7674E406077BAF3C45D4C40FF7A8505F7674E40BF4868CBB95A4C40ED0E2906485C4E40BF4868CBB95A4C40
19112	46689	60.720948	60.812226000000003	56.732573000000002	56.708795000000002	Степана Разина	0103000020E61000000100000005000000ED0E2906485C4E40BF4868CBB95A4C40ED0E2906485C4E406077BAF3C45D4C40FF7A8505F7674E406077BAF3C45D4C40FF7A8505F7674E40BF4868CBB95A4C40ED0E2906485C4E40BF4868CBB95A4C40
78584	46689	60.720948	60.812226000000003	56.732573000000002	56.708795000000002	Советская	0103000020E61000000100000005000000ED0E2906485C4E40BF4868CBB95A4C40ED0E2906485C4E406077BAF3C45D4C40FF7A8505F7674E406077BAF3C45D4C40FF7A8505F7674E40BF4868CBB95A4C40ED0E2906485C4E40BF4868CBB95A4C40
20314	46689	60.720948	60.812226000000003	56.732573000000002	56.708795000000002	Ленина	0103000020E61000000100000005000000ED0E2906485C4E40BF4868CBB95A4C40ED0E2906485C4E406077BAF3C45D4C40FF7A8505F7674E406077BAF3C45D4C40FF7A8505F7674E40BF4868CBB95A4C40ED0E2906485C4E40BF4868CBB95A4C40
19887	23366	60.690711	60.731943000000001	56.660477999999998	56.646098000000002	Лесная	0103000020E6100000010000000500000065FED13769584E406901DA56B3524C4065FED13769584E401EDD088B8A544C40A0C4E74EB05D4E401EDD088B8A544C40A0C4E74EB05D4E406901DA56B3524C4065FED13769584E406901DA56B3524C40
77087	23366	60.690711	60.731943000000001	56.660477999999998	56.646098000000002	1 Мая	0103000020E6100000010000000500000065FED13769584E406901DA56B3524C4065FED13769584E401EDD088B8A544C40A0C4E74EB05D4E401EDD088B8A544C40A0C4E74EB05D4E406901DA56B3524C4065FED13769584E406901DA56B3524C40
18834	46623	60.946874000000001	60.994467	56.694206999999999	56.649261000000003	переулок Советский	0103000020E6100000010000000500000063B7CF2A33794E40BDC804FC1A534C4063B7CF2A33794E40BFD364C6DB584C40C2F9D4B14A7F4E40BFD364C6DB584C40C2F9D4B14A7F4E40BDC804FC1A534C4063B7CF2A33794E40BDC804FC1A534C40
18681	46623	60.946874000000001	60.994467	56.694206999999999	56.649261000000003	Калинина	0103000020E6100000010000000500000063B7CF2A33794E40BDC804FC1A534C4063B7CF2A33794E40BFD364C6DB584C40C2F9D4B14A7F4E40BFD364C6DB584C40C2F9D4B14A7F4E40BDC804FC1A534C4063B7CF2A33794E40BDC804FC1A534C40
78510	22456	60.515332999999998	60.534134000000002	56.478437	56.470840000000003	Пролетарская	0103000020E6100000010000000500000058C6866EF6414E4007D3307C443C4C4058C6866EF6414E402219726C3D3D4C4041D7BE805E444E402219726C3D3D4C4041D7BE805E444E4007D3307C443C4C4058C6866EF6414E4007D3307C443C4C40
19286	3879	60.903719000000002	60.958939000000001	56.718325	56.709215	Станционная	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
18473	3879	60.903719000000002	60.958939000000001	56.718325	56.709215	Свердлова	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
19181	3879	60.903719000000002	60.958939000000001	56.718325	56.709215	Садовая	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
19843	3879	60.903719000000002	60.958939000000001	56.718325	56.709215	Рабочая	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
19063	3879	60.903719000000002	60.958939000000001	56.718325	56.709215	Красноармейская	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
18642	3879	60.903719000000002	60.958939000000001	56.718325	56.709215	Космонавтов	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
18955	3879	60.903719000000002	60.958939000000001	56.718325	56.709215	1 Мая	0103000020E610000001000000050000000DE36E10AD734E40946A9F8EC75A4C400DE36E10AD734E401973D712F25B4C40F2ED5D83BE7A4E401973D712F25B4C40F2ED5D83BE7A4E40946A9F8EC75A4C400DE36E10AD734E40946A9F8EC75A4C40
78273	61293	61.013142999999999	61.043084	56.335191000000002	56.314875999999998	Советская	0103000020E61000000100000005000000EE9579ABAE814E40CC2555DB4D284C40EE9579ABAE814E40EF74E789E72A4C408D7DC9C683854E40EF74E789E72A4C408D7DC9C683854E40CC2555DB4D284C40EE9579ABAE814E40CC2555DB4D284C40
78601	61337	61.002695000000003	61.022665000000003	56.388551	56.369979999999998	Ленина	0103000020E610000001000000050000006E6E4C4F58804E40481630815B2F4C406E6E4C4F58804E40FFE9060ABC314C40C6E1CCAFE6824E40FFE9060ABC314C40C6E1CCAFE6824E40481630815B2F4C406E6E4C4F58804E40481630815B2F4C40
18483	49930	61.945540000000001	61.973028999999997	56.925738000000003	56.915627999999998	Ленина	0103000020E61000000100000005000000A987687407F94E40A4A65D4C33754C40A987687407F94E400D5531957E764C40A087DA368CFC4E400D5531957E764C40A087DA368CFC4E40A4A65D4C33754C40A987687407F94E40A4A65D4C33754C40
17874	49853	62.280180999999999	62.325006999999999	56.856032999999996	56.841009999999997	Ленина	0103000020E61000000100000005000000F4FA93F8DC234F40F2CD3637A66B4C40F4FA93F8DC234F40FCA5457D926D4C404CFC51D499294F40FCA5457D926D4C404CFC51D499294F40F2CD3637A66B4C40F4FA93F8DC234F40F2CD3637A66B4C40
18011	11383	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Юбилейная	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18463	11383	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Кунарская	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
17769	11383	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Горького	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18007	11383	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Артиллеристов	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18137	11383	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	8 Марта	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18494	49931	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Юбилейная	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18779	49931	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Победы	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
19057	49931	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Кирова	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18756	49931	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Гоголя	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
78525	49931	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Ворошилова	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18795	49931	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	Белинского	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
19007	49931	61.812804999999997	62.244176000000003	56.950713	56.770173999999997	93 Стрелковой бригады	0103000020E610000001000000050000003C8386FE09E84E40601DC70F95624C403C8386FE09E84E40E770ADF6B0794C40EB3BBF28411F4F40E770ADF6B0794C40EB3BBF28411F4F40601DC70F95624C403C8386FE09E84E40601DC70F95624C40
18811	49959	61.784418000000002	61.805312999999998	56.933813000000001	56.922328999999998	Ленина	0103000020E6100000010000000500000066321CCF67E44E4081936DE00E764C4066321CCF67E44E4032CA332F87774C409605137F14E74E4032CA332F87774C409605137F14E74E4081936DE00E764C4066321CCF67E44E4081936DE00E764C40
19185	49985	61.930107	61.959015000000001	56.991453999999997	56.974331999999997	Калинина	0103000020E61000000100000005000000ED6305BF0DF74E401FB935E9B67C4C40ED6305BF0DF74E4083BEF4F6E77E4C40CDAFE600C1FA4E4083BEF4F6E77E4C40CDAFE600C1FA4E401FB935E9B67C4C40ED6305BF0DF74E401FB935E9B67C4C40
18508	49935	62.205998000000001	62.257398999999999	56.898372000000002	56.886287000000003	Ильича	0103000020E610000001000000050000004D8578245E1A4F405BEF37DA71714C404D8578245E1A4F4031D28BDAFD724C40F5824F73F2204F4031D28BDAFD724C40F5824F73F2204F405BEF37DA71714C404D8578245E1A4F405BEF37DA71714C40
18810	49925	62.095550000000003	62.167541	56.925699000000002	56.900137000000001	Школьная	0103000020E6100000010000000500000000917EFB3A0C4F40B47570B037734C4000917EFB3A0C4F404F78094E7D764C409CDEC5FB71154F404F78094E7D764C409CDEC5FB71154F40B47570B037734C4000917EFB3A0C4F40B47570B037734C40
18817	49925	62.095550000000003	62.167541	56.925699000000002	56.900137000000001	Свердлова	0103000020E6100000010000000500000000917EFB3A0C4F40B47570B037734C4000917EFB3A0C4F404F78094E7D764C409CDEC5FB71154F404F78094E7D764C409CDEC5FB71154F40B47570B037734C4000917EFB3A0C4F40B47570B037734C40
18427	49925	62.095550000000003	62.167541	56.925699000000002	56.900137000000001	Батенева	0103000020E6100000010000000500000000917EFB3A0C4F40B47570B037734C4000917EFB3A0C4F404F78094E7D764C409CDEC5FB71154F404F78094E7D764C409CDEC5FB71154F40B47570B037734C4000917EFB3A0C4F40B47570B037734C40
17775	49836	61.931319999999999	61.957129000000002	56.947403999999999	56.932245999999999	Горького	0103000020E610000001000000050000002C0E677E35F74E40D5E940D653774C402C0E677E35F74E40BF0CC68844794C40CF86FC3383FA4E40BF0CC68844794C40CF86FC3383FA4E40D5E940D653774C402C0E677E35F74E40D5E940D653774C40
18715	49949	62.171430999999998	62.197589999999998	56.855545999999997	56.844540000000002	Щепеткина	0103000020E61000000100000005000000A2427573F1154F40F91400E3196C4C40A2427573F1154F409F1C0588826D4C4021020EA14A194F409F1C0588826D4C4021020EA14A194F40F91400E3196C4C40A2427573F1154F40F91400E3196C4C40
19360	49956	61.951245	62.012168000000003	57.086689999999997	57.056603000000003	Вокзальная	0103000020E61000000100000005000000E4BD6A65C2F94E4081ED60C43E874C40E4BD6A65C2F94E40F3716DA8188B4C40640795B88E014F40F3716DA8188B4C40640795B88E014F4081ED60C43E874C40E4BD6A65C2F94E4081ED60C43E874C40
18789	49956	61.951245	62.012168000000003	57.086689999999997	57.056603000000003	1 Мая	0103000020E61000000100000005000000E4BD6A65C2F94E4081ED60C43E874C40E4BD6A65C2F94E40F3716DA8188B4C40640795B88E014F40F3716DA8188B4C40640795B88E014F4081ED60C43E874C40E4BD6A65C2F94E4081ED60C43E874C40
19975	50121	59.194682999999998	59.201169	60.182453000000002	60.168508000000003	Парковый переулок	0103000020E61000000100000005000000280B5F5FEB984D40A48E8EAB91154E40280B5F5FEB984D404F07B29E5A174E4009FCE1E7BF994D404F07B29E5A174E4009FCE1E7BF994D40A48E8EAB91154E40280B5F5FEB984D40A48E8EAB91154E40
18629	49944	59.194682999999998	59.201169	60.182453000000002	60.168508000000003	Толмачева	0103000020E61000000100000005000000280B5F5FEB984D40A48E8EAB91154E40280B5F5FEB984D404F07B29E5A174E4009FCE1E7BF994D404F07B29E5A174E4009FCE1E7BF994D40A48E8EAB91154E40280B5F5FEB984D40A48E8EAB91154E40
78515	46447	64.755758	64.765513999999996	57.425040000000003	57.420233000000003	Лаптева	0103000020E610000001000000050000002F6CCD565E30504099D9E731CAB54C402F6CCD565E305040F5BEF1B567B64C4054A86E2EFE305040F5BEF1B567B64C4054A86E2EFE30504099D9E731CAB54C402F6CCD565E30504099D9E731CAB54C40
18525	20985	64.296306000000001	64.329723000000001	57.682361	57.669612000000001	Новая	0103000020E61000000100000005000000F3E670ADF61250402C8194D8B5D54C40F3E670ADF61250406E88F19A57D74C404C6F7F2E1A1550406E88F19A57D74C404C6F7F2E1A1550402C8194D8B5D54C40F3E670ADF61250402C8194D8B5D54C40
78460	61300	64.516986000000003	64.533002999999994	57.483179999999997	57.468304000000003	Школьная	0103000020E610000001000000050000005A9F724C16215040024BAE62F1BB4C405A9F724C16215040670A9DD7D8BD4C40DF6A9DB81C225040670A9DD7D8BD4C40DF6A9DB81C225040024BAE62F1BB4C405A9F724C16215040024BAE62F1BB4C40
77270	49950	64.374199000000004	64.408154999999994	57.634269000000003	57.604225	Советская	0103000020E610000001000000050000008ACC5CE0F21750407A36AB3E57CD4C408ACC5CE0F2175040EEEE01BA2FD14C40BA2C26361F1A5040EEEE01BA2FD14C40BA2C26361F1A50407A36AB3E57CD4C408ACC5CE0F21750407A36AB3E57CD4C40
77443	49950	64.374199000000004	64.408154999999994	57.634269000000003	57.604225	Ленина	0103000020E610000001000000050000008ACC5CE0F21750407A36AB3E57CD4C408ACC5CE0F2175040EEEE01BA2FD14C40BA2C26361F1A5040EEEE01BA2FD14C40BA2C26361F1A50407A36AB3E57CD4C408ACC5CE0F21750407A36AB3E57CD4C40
17836	19414	64.494348000000002	64.514973999999995	57.558225999999998	57.549079999999996	Ленина	0103000020E61000000100000005000000F435CB65A31F50409F71E14048C64C40F435CB65A31F504071E316F373C74C4094128255F520504071E316F373C74C4094128255F52050409F71E14048C64C40F435CB65A31F50409F71E14048C64C40
78467	61302	64.203348000000005	64.231932	57.759891000000003	57.750114000000004	Ленина проспект	0103000020E61000000100000005000000406D54A7030D5040C9224DBC03E04C40406D54A7030D50402BC3B81B44E14C4056B950F9D70E50402BC3B81B44E14C4056B950F9D70E5040C9224DBC03E04C40406D54A7030D5040C9224DBC03E04C40
78542	18995	63.871699	64.979698999999997	57.893597	57.316099999999999	Школьная	0103000020E610000001000000050000005B7A34D593EF4F40FF21FDF675A84C405B7A34D593EF4F40E066F16261F24C40213B6F63B33E5040E066F16261F24C40213B6F63B33E5040FF21FDF675A84C405B7A34D593EF4F40FF21FDF675A84C40
20061	50141	64.012671999999995	64.034239999999997	57.779960000000003	57.773116000000002	45 лет Победы	0103000020E61000000100000005000000CB64389ECF005040D6011077F5E24C40CB64389ECF0050401618B2BAD5E34C40C30DF8FC300250401618B2BAD5E34C40C30DF8FC30025040D6011077F5E24C40CB64389ECF005040D6011077F5E24C40
18761	20164	64.167001999999997	64.198999999999998	57.533906999999999	57.527534000000003	Озерная	0103000020E6100000010000000500000076172829B00A504098C3EE3B86C34C4076172829B00A5040800D881057C44C40DBF97E6ABC0C5040800D881057C44C40DBF97E6ABC0C504098C3EE3B86C34C4076172829B00A504098C3EE3B86C34C40
17900	20852	64.256573000000003	64.272276000000005	57.800843	57.792579000000003	Центральный	0103000020E61000000100000005000000580229B16B1050408A3F8A3A73E54C40580229B16B105040821DFF0582E64C4016DF50F86C115040821DFF0582E64C4016DF50F86C1150408A3F8A3A73E54C40580229B16B1050408A3F8A3A73E54C40
20038	19106	64.735106000000002	64.752578	57.393537000000002	57.376640000000002	Ленина	0103000020E61000000100000005000000FA4509FA0B2F5040C72E51BD35B04C40FA4509FA0B2F50400B62A06B5FB24C401A6CEA3C2A3050400B62A06B5FB24C401A6CEA3C2A305040C72E51BD35B04C40FA4509FA0B2F5040C72E51BD35B04C40
18257	20548	64.090753000000007	64.120971999999995	57.796224000000002	57.789451	Советская	0103000020E61000000100000005000000E4C0ABE5CE055040B265F9BA0CE54C40E4C0ABE5CE055040292504ABEAE54C40D4EE5701BE075040292504ABEAE54C40D4EE5701BE075040B265F9BA0CE54C40E4C0ABE5CE055040B265F9BA0CE54C40
17885	19520	64.486641000000006	64.508919000000006	57.584926000000003	57.580559999999998	Школа	0103000020E6100000010000000500000023F94A20251F5040D1AE42CA4FCA4C4023F94A20251F5040414AECDADECA4C400954FF2092205040414AECDADECA4C400954FF2092205040D1AE42CA4FCA4C4023F94A20251F5040D1AE42CA4FCA4C40
19386	19883	64.314694000000003	64.339838	57.518830000000001	57.507339000000002	Октябрьская	0103000020E61000000100000005000000D68F4DF223145040207EFE7BF0C04C40D68F4DF22314504083177D0569C24C4009FCE1E7BF15504083177D0569C24C4009FCE1E7BF155040207EFE7BF0C04C40D68F4DF223145040207EFE7BF0C04C40
19212	20232	64.153491000000002	64.167658000000003	57.627401999999996	57.619007000000003	Новая	0103000020E61000000100000005000000BE4EEACBD20950405F7F129F3BCF4C40BE4EEACBD2095040F5B86FB54ED04C406BBA9EE8BA0A5040F5B86FB54ED04C406BBA9EE8BA0A50405F7F129F3BCF4C40BE4EEACBD20950405F7F129F3BCF4C40
19365	20052	64.146897999999993	64.173641000000003	57.505423999999998	57.497092000000002	Бобровская	0103000020E610000001000000050000004276DEC666095040378DEDB5A0BF4C404276DEC666095040874ECFBBB1C04C40AA0F24EF1C0B5040874ECFBBB1C04C40AA0F24EF1C0B5040378DEDB5A0BF4C404276DEC666095040378DEDB5A0BF4C40
18436	20918	64.271934000000002	64.287125000000003	57.737245000000001	57.725386	Центральная	0103000020E61000000100000005000000E92ADD5D67115040F67CCD72D9DC4C40E92ADD5D67115040DC114E0B5EDE4C404C37894160125040DC114E0B5EDE4C404C37894160125040F67CCD72D9DC4C40E92ADD5D67115040F67CCD72D9DC4C40
20310	50217	64.374199000000004	64.408154999999994	57.634269000000003	57.604225	Дегтева	0103000020E610000001000000050000008ACC5CE0F21750407A36AB3E57CD4C408ACC5CE0F2175040EEEE01BA2FD14C40BA2C26361F1A5040EEEE01BA2FD14C40BA2C26361F1A50407A36AB3E57CD4C408ACC5CE0F21750407A36AB3E57CD4C40
18325	49916	60.762611999999997	60.782231000000003	59.609552000000001	59.599977000000003	Заводская	0103000020E61000000100000005000000C1C41F459D614E4015ADDC0BCCCC4D40C1C41F459D614E400F9BC8CC05CE4D406D75392520644E400F9BC8CC05CE4D406D75392520644E4015ADDC0BCCCC4D40C1C41F459D614E4015ADDC0BCCCC4D40
18111	49873	61.814970000000002	61.877870000000001	59.190094000000002	59.156882000000003	Свободы	0103000020E610000001000000050000004E9CDCEF50E84E4061AA99B514944D404E9CDCEF50E84E403A950C0055984D40DC114E0B5EF04E403A950C0055984D40DC114E0B5EF04E4061AA99B514944D404E9CDCEF50E84E4061AA99B514944D40
17961	49873	61.814970000000002	61.877870000000001	59.190094000000002	59.156882000000003	Ленина,	0103000020E610000001000000050000004E9CDCEF50E84E4061AA99B514944D404E9CDCEF50E84E403A950C0055984D40DC114E0B5EF04E403A950C0055984D40DC114E0B5EF04E4061AA99B514944D404E9CDCEF50E84E4061AA99B514944D40
18393	49873	61.814970000000002	61.877870000000001	59.190094000000002	59.156882000000003	Ленина	0103000020E610000001000000050000004E9CDCEF50E84E4061AA99B514944D404E9CDCEF50E84E403A950C0055984D40DC114E0B5EF04E403A950C0055984D40DC114E0B5EF04E4061AA99B514944D404E9CDCEF50E84E4061AA99B514944D40
18925	49873	61.814970000000002	61.877870000000001	59.190094000000002	59.156882000000003	Балдина	0103000020E610000001000000050000004E9CDCEF50E84E4061AA99B514944D404E9CDCEF50E84E403A950C0055984D40DC114E0B5EF04E403A950C0055984D40DC114E0B5EF04E4061AA99B514944D404E9CDCEF50E84E4061AA99B514944D40
19331	18528	61.053226000000002	61.072423000000001	59.374707000000001	59.368431000000001	Зеленая	0103000020E6100000010000000500000001A60C1CD0864E4092EA3BBF28AF4D4001A60C1CD0864E40884A2366F6AF4D40363D282845894E40884A2366F6AF4D40363D282845894E4092EA3BBF28AF4D4001A60C1CD0864E4092EA3BBF28AF4D40
19346	49992	61.495448000000003	61.527267000000002	59.155996000000002	59.13814	Центральная	0103000020E610000001000000050000002F6F0ED76ABF4E407D224F92AE914D402F6F0ED76ABF4E4046274BADF7934D4049A12C7C7DC34E4046274BADF7934D4049A12C7C7DC34E407D224F92AE914D402F6F0ED76ABF4E407D224F92AE914D40
17847	18462	60.860438000000002	60.877605000000003	59.430542000000003	59.418554	Школьная	0103000020E610000001000000050000002A1E17D5226E4E4014CE6E2D93B54D402A1E17D5226E4E40F8C610001CB74D402EE7525C55704E40F8C610001CB74D402EE7525C55704E4014CE6E2D93B54D402A1E17D5226E4E4014CE6E2D93B54D40
18670	17859	61.388845000000003	61.410899000000001	59.497638000000002	59.481921999999997	Советская	0103000020E61000000100000005000000481B47ACC5B14E40889CBE9EAFBD4D40481B47ACC5B14E40999F1B9AB2BF4D40C47AA35698B44E40999F1B9AB2BF4D40C47AA35698B44E40889CBE9EAFBD4D40481B47ACC5B14E40889CBE9EAFBD4D40
18992	49971	61.448853	61.465381999999998	59.280898999999998	59.270130999999999	Теплоухова	0103000020E6100000010000000500000012DBDD0374B94E40615111A793A24D4012DBDD0374B94E40533D997FF4A34D40D3122BA391BB4E40533D997FF4A34D40D3122BA391BB4E40615111A793A24D4012DBDD0374B94E40615111A793A24D40
20406	18352	60.971335000000003	60.987721000000001	59.399974999999998	59.390945000000002	Советская	0103000020E61000000100000005000000E73A8DB4547C4E4072C45A7C0AB24D40E73A8DB4547C4E40DA1B7C6132B34D40454948A46D7E4E40DA1B7C6132B34D40454948A46D7E4E4072C45A7C0AB24D40E73A8DB4547C4E4072C45A7C0AB24D40
17921	49864	61.275773999999998	61.288511999999997	59.293106000000002	59.282282000000002	Новая	0103000020E61000000100000005000000268BFB8F4CA34E40EF1F0BD121A44D40268BFB8F4CA34E407521567F84A54D40744012F6EDA44E407521567F84A54D40744012F6EDA44E40EF1F0BD121A44D40268BFB8F4CA34E40EF1F0BD121A44D40
19964	17377	60.549737999999998	60.594392999999997	59.934807999999997	59.917212999999997	Вокзальная 	0103000020E6100000010000000500000029AF95D05D464E40A73B4F3C67F54D4029AF95D05D464E400305DEC9A7F74D4054FCDF11154C4E400305DEC9A7F74D4054FCDF11154C4E40A73B4F3C67F54D4029AF95D05D464E40A73B4F3C67F54D40
19279	17460	60.718198999999998	60.733829999999998	59.847448999999997	59.839362000000001	Октябрьская	0103000020E610000001000000050000008C82E0F1ED5B4E40A9C0C93670EB4D408C82E0F1ED5B4E409203763579EC4D406E693524EE5D4E409203763579EC4D406E693524EE5D4E40A9C0C93670EB4D408C82E0F1ED5B4E40A9C0C93670EB4D40
18964	17622	60.503177999999998	60.535572000000002	59.434120999999998	59.414053000000003	Ленина	0103000020E610000001000000050000008908FF2268404E40C5E74EB0FFB44D408908FF2268404E40DFC0E44691B74D40A053909F8D444E40DFC0E44691B74D40A053909F8D444E40C5E74EB0FFB44D408908FF2268404E40C5E74EB0FFB44D40
18313	17767	61.219099999999997	61.267904999999999	59.397239999999996	59.379624999999997	Садовая	0103000020E61000000100000005000000DC4603780B9C4E403BDF4F8D97B04D40DC4603780B9C4E40DE54A4C2D8B24D40AAB706B64AA24E40DE54A4C2D8B24D40AAB706B64AA24E403BDF4F8D97B04D40DC4603780B9C4E403BDF4F8D97B04D40
20214	50193	61.835783999999997	61.882657999999999	59.096943000000003	59.076943	Ворошилова	0103000020E61000000100000005000000914259F8FAEA4E40FC53AA44D9894D40914259F8FAEA4E40BF49D3A0688C4D40C1C6F5EFFAF04E40BF49D3A0688C4D40C1C6F5EFFAF04E40FC53AA44D9894D40914259F8FAEA4E40FC53AA44D9894D40
19291	18840	60.184187000000001	62.570794999999997	60.235996999999998	58.553196	Колхозная	0103000020E6100000010000000500000097AC8A7093174E4096236420CF464D4097AC8A7093174E40207A5226351E4E4033DC80CF0F494F40207A5226351E4E4033DC80CF0F494F4096236420CF464D4097AC8A7093174E4096236420CF464D40
19004	18783	60.570084999999999	60.585059999999999	59.73657	59.732289000000002	Набережная	0103000020E610000001000000050000005778978BF8484E403B1C5DA5BBDD4D405778978BF8484E407C9BFEEC47DE4D405019FF3EE34A4E407C9BFEEC47DE4D405019FF3EE34A4E403B1C5DA5BBDD4D405778978BF8484E403B1C5DA5BBDD4D40
18471	40380	61.777034	61.839503000000001	58.808472999999999	58.783392999999997	пер. Парковый	0103000020E61000000100000005000000A6F0A0D975E34E402975C93846644D40A6F0A0D975E34E407959130B7C674D406BF294D574EB4E407959130B7C674D406BF294D574EB4E402975C93846644D40A6F0A0D975E34E402975C93846644D40
18435	40380	61.777034	61.839503000000001	58.808472999999999	58.783392999999997	Пушкина	0103000020E61000000100000005000000A6F0A0D975E34E402975C93846644D40A6F0A0D975E34E407959130B7C674D406BF294D574EB4E407959130B7C674D406BF294D574EB4E402975C93846644D40A6F0A0D975E34E402975C93846644D40
18246	40380	61.777034	61.839503000000001	58.808472999999999	58.783392999999997	Ленина	0103000020E61000000100000005000000A6F0A0D975E34E402975C93846644D40A6F0A0D975E34E407959130B7C674D406BF294D574EB4E407959130B7C674D406BF294D574EB4E402975C93846644D40A6F0A0D975E34E402975C93846644D40
18324	17918	61.389968000000003	61.41142	59.556539000000001	59.534660000000002	Центральная	0103000020E61000000100000005000000473EAF78EAB14E405C3D27BD6FC44D40473EAF78EAB14E406AF981AB3CC74D40CD751A69A9B44E406AF981AB3CC74D40CD751A69A9B44E405C3D27BD6FC44D40473EAF78EAB14E405C3D27BD6FC44D40
20196	50183	60.446010000000001	60.487448999999998	60.051611999999999	60.026761	Зеленая	0103000020E6100000010000000500000030D80DDB16394E4075E789E76C034E4030D80DDB16394E40630AD6389B064E40E4BB94BA643E4E40630AD6389B064E40E4BB94BA643E4E4075E789E76C034E4030D80DDB16394E4075E789E76C034E40
19033	24729	61.217339000000003	61.243830000000003	57.477930000000001	57.470413999999998	Садовая	0103000020E610000001000000050000009B92ACC3D19B4E404FCAA48636BC4C409B92ACC3D19B4E407EE36BCF2CBD4C4050E449D2359F4E407EE36BCF2CBD4C4050E449D2359F4E404FCAA48636BC4C409B92ACC3D19B4E404FCAA48636BC4C40
18600	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Строителей	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
77082	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Спортивная	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
20323	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Пушкина	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
20307	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Пионерская	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
20059	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	П.Морозова	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
77074	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	О.Кошевого	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
18587	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Металлургов	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
19129	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Ленина	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
18876	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Калинина	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
20102	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Зеленая	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
77084	14450	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	Заводская	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
19943	46721	61.302041000000003	61.329169999999998	57.433611999999997	57.410818999999996	Мира	0103000020E610000001000000050000008C868C47A9A64E40A7C98CB795B44C408C868C47A9A64E409A93179980B74C408369183E22AA4E409A93179980B74C408369183E22AA4E40A7C98CB795B44C408C868C47A9A64E40A7C98CB795B44C40
18125	46721	61.302041000000003	61.329169999999998	57.433611999999997	57.410818999999996	Ленина	0103000020E610000001000000050000008C868C47A9A64E40A7C98CB795B44C408C868C47A9A64E409A93179980B74C408369183E22AA4E409A93179980B74C408369183E22AA4E40A7C98CB795B44C408C868C47A9A64E40A7C98CB795B44C40
19169	15401	61.211086999999999	61.233544999999999	57.270868999999998	57.261012999999998	Советская	0103000020E610000001000000050000002DCE18E6049B4E40596ABDDF68A14C402DCE18E6049B4E400740DCD5ABA24C40799274CDE49D4E400740DCD5ABA24C40799274CDE49D4E40596ABDDF68A14C402DCE18E6049B4E40596ABDDF68A14C40
18812	11394	63.067391999999998	63.089015000000003	57.015537000000002	57.005386999999999	Кирова	0103000020E610000001000000050000008A01124DA0884F406A696E85B0804C408A01124DA0884F406170CD1DFD814C403EEDF0D7648B4F406170CD1DFD814C403EEDF0D7648B4F406A696E85B0804C408A01124DA0884F406A696E85B0804C40
18019	11773	63.363737999999998	63.402239000000002	57.019207000000002	56.999867000000002	Павлика Морозова	0103000020E61000000100000005000000FE277FF78EAE4F40C1AC50A4FB7F4C40FE277FF78EAE4F40596DFE5F75824C407F164B917CB34F40596DFE5F75824C407F164B917CB34F40C1AC50A4FB7F4C40FE277FF78EAE4F40C1AC50A4FB7F4C40
19838	12485	63.112146000000003	63.135205999999997	56.739193999999998	56.728430000000003	Советская	0103000020E610000001000000050000004930D5CC5A8E4F4070B6B9313D5D4C404930D5CC5A8E4F4020B3B3E89D5E4C408A1C226E4E914F4020B3B3E89D5E4C408A1C226E4E914F4070B6B9313D5D4C404930D5CC5A8E4F4070B6B9313D5D4C40
18028	11994	63.227561999999999	63.245806999999999	56.925448000000003	56.914321000000001	Ленина	0103000020E61000000100000005000000FBE769C0209D4F40E485747808754C40FBE769C0209D4F4006137F1475764C405E10919A769F4F4006137F1475764C405E10919A769F4F40E485747808754C40FBE769C0209D4F40E485747808754C40
19350	12160	63.035781	63.081999000000003	56.860934	56.852544000000002	Ленина	0103000020E61000000100000005000000BA68C87894844F4055336B29206D4C40BA68C87894844F40DA01D715336E4C4001A777F17E8A4F40DA01D715336E4C4001A777F17E8A4F4055336B29206D4C40BA68C87894844F4055336B29206D4C40
18059	11229	62.998860000000001	63.015918999999997	57.072488999999997	57.057214999999999	Карла Маркса	0103000020E610000001000000050000002BA4FCA4DA7F4F409AEB34D252874C402BA4FCA4DA7F4F40ED28CE5147894C40483140A209824F40ED28CE5147894C40483140A209824F409AEB34D252874C402BA4FCA4DA7F4F409AEB34D252874C40
18062	12352	63.172252999999998	63.187542000000001	56.822749999999999	56.813127999999999	Ленина	0103000020E61000000100000005000000A6D1E4620C964F401FBB0B9414684C40A6D1E4620C964F405A643BDF4F694C402F50526001984F405A643BDF4F694C402F50526001984F401FBB0B9414684C40A6D1E4620C964F401FBB0B9414684C40
19043	11560	63.142904999999999	63.166862999999999	56.995308000000001	56.977378000000002	Ленина	0103000020E61000000100000005000000AAB706B64A924F403AEAE8B81A7D4C40AAB706B64A924F403DB9A640667F4C40CBF44BC45B954F403DB9A640667F4C40CBF44BC45B954F403AEAE8B81A7D4C40AAB706B64A924F403AEAE8B81A7D4C40
18047	11479	63.153649000000001	63.178441999999997	56.910477999999998	56.888289	Халтурина	0103000020E6100000010000000500000014083BC5AA934F40C2323674B3714C4014083BC5AA934F401EDD088B8A744C40CD1DFD2FD7964F401EDD088B8A744C40CD1DFD2FD7964F40C2323674B3714C4014083BC5AA934F40C2323674B3714C40
18771	11142	63.023096000000002	63.047989000000001	57.120280000000001	57.099829	Калинина	0103000020E610000001000000050000008F554ACFF4824F40A0185932C78C4C408F554ACFF4824F40732EC555658F4C40ACC8E88024864F40732EC555658F4C40ACC8E88024864F40A0185932C78C4C408F554ACFF4824F40A0185932C78C4C40
19363	12974	63.370564999999999	63.388019	56.757914	56.747273999999997	Школьный переулок	0103000020E61000000100000005000000680586AC6EAF4F405793A7ACA65F4C40680586AC6EAF4F401C97715303614C40029D499BAAB14F401C97715303614C40029D499BAAB14F405793A7ACA65F4C40680586AC6EAF4F405793A7ACA65F4C40
17986	10683	63.202821999999998	63.284793999999998	56.980139999999999	56.931789999999999	Куйбышева	0103000020E6100000010000000500000064744012F6994F40B35E0CE544774C4064744012F6994F402FC03E3A757D4C406B0C3A2174A44F402FC03E3A757D4C406B0C3A2174A44F40B35E0CE544774C4064744012F6994F40B35E0CE544774C40
19378	10683	63.202821999999998	63.284793999999998	56.980139999999999	56.931789999999999	Комарова	0103000020E6100000010000000500000064744012F6994F40B35E0CE544774C4064744012F6994F402FC03E3A757D4C406B0C3A2174A44F402FC03E3A757D4C406B0C3A2174A44F40B35E0CE544774C4064744012F6994F40B35E0CE544774C40
17920	10683	63.202821999999998	63.284793999999998	56.980139999999999	56.931789999999999	Бабкина	0103000020E6100000010000000500000064744012F6994F40B35E0CE544774C4064744012F6994F402FC03E3A757D4C406B0C3A2174A44F402FC03E3A757D4C406B0C3A2174A44F40B35E0CE544774C4064744012F6994F40B35E0CE544774C40
18024	11853	63.315103000000001	63.345044000000001	56.992013	56.976329	50 лет Октября	0103000020E610000001000000050000008DEF8B4B55A84F4075914259F87C4C408DEF8B4B55A84F407A1A3048FA7E4C402CD7DB662AAC4F407A1A3048FA7E4C402CD7DB662AAC4F4075914259F87C4C408DEF8B4B55A84F4075914259F87C4C40
18443	11667	63.257539000000001	63.291845000000002	57.111732000000003	57.091976000000003	Школьная	0103000020E61000000100000005000000E738B709F7A04F402A029CDEC58B4C40E738B709F7A04F4056F5F23B4D8E4C4025404D2D5BA54F4056F5F23B4D8E4C4025404D2D5BA54F402A029CDEC58B4C40E738B709F7A04F402A029CDEC58B4C40
18914	11329	63.007168999999998	63.036248000000001	57.037264	57.024954000000001	Буденного	0103000020E61000000100000005000000C345EEE9EA804F40C3F352B131834C40C345EEE9EA804F40B9A81611C5844C40D04543C6A3844F40B9A81611C5844C40D04543C6A3844F40C3F352B131834C40C345EEE9EA804F40C3F352B131834C40
18477	12641	63.009199000000002	63.026681000000004	56.735945000000001	56.724375999999999	Ленина	0103000020E61000000100000005000000F513CE6E2D814F40EF004F5AB85C4C40F513CE6E2D814F40CE531D72335E4C40593673486A834F40CE531D72335E4C40593673486A834F40EF004F5AB85C4C40F513CE6E2D814F40EF004F5AB85C4C40
18077	12925	63.213341999999997	63.230606999999999	56.624262000000002	56.611651999999999	Молодежная	0103000020E610000001000000050000007E6E68CA4E9B4F403944DC9C4A4E4C407E6E68CA4E9B4F405A1135D1E74F4C40459DB987849D4F405A1135D1E74F4C40459DB987849D4F403944DC9C4A4E4C407E6E68CA4E9B4F403944DC9C4A4E4C40
18372	12580	63.107897000000001	63.128622	56.760908999999998	56.748601999999998	Школьный переулок	0103000020E61000000100000005000000132BA391CF8D4F402FDCB930D25F4C40132BA391CF8D4F40B41D537765614C40E7C589AF76904F40B41D537765614C40E7C589AF76904F402FDCB930D25F4C40132BA391CF8D4F402FDCB930D25F4C40
18708	11609	63.218919999999997	63.231757000000002	57.025944000000003	57.012037999999997	Центральная	0103000020E610000001000000050000005C381092059C4F40952710768A814C405C381092059C4F4083C30B2252834C403ECF9F36AA9D4F4083C30B2252834C403ECF9F36AA9D4F40952710768A814C405C381092059C4F40952710768A814C40
20068	12259	63.015272000000003	63.036085999999997	56.841177000000002	56.828473000000002	Механизаторов	0103000020E61000000100000005000000B345D26EF4814F403C4F3C670B6A4C40B345D26EF4814F40DE921CB0AB6B4C40F6EB4E779E844F40DE921CB0AB6B4C40F6EB4E779E844F403C4F3C670B6A4C40B345D26EF4814F403C4F3C670B6A4C40
19084	12851	63.155085999999997	63.182879999999997	56.650759999999998	56.631917000000001	Ленина	0103000020E61000000100000005000000A208A9DBD9934F40AA6400A8E2504C40A208A9DBD9934F40C1C58A1A4C534C40D68BA19C68974F40C1C58A1A4C534C40D68BA19C68974F40AA6400A8E2504C40A208A9DBD9934F40AA6400A8E2504C40
78623	61341	60.531726999999997	60.584843999999997	57.664707	57.612054999999998	Гаражная	0103000020E6100000010000000500000039B35DA10F444E40382D78D157CE4C4039B35DA10F444E400D36751E15D54C4083A10E2BDC4A4E400D36751E15D54C4083A10E2BDC4A4E40382D78D157CE4C4039B35DA10F444E40382D78D157CE4C40
78602	49338	60.16234	60.189909	57.779330999999999	57.764049	Ленина	0103000020E61000000100000005000000946A9F8EC7144E4050C58D5BCCE14C40946A9F8EC7144E4026E1421EC1E34C40A81B28F04E184E4026E1421EC1E34C40A81B28F04E184E4050C58D5BCCE14C40946A9F8EC7144E4050C58D5BCCE14C40
18570	49338	60.16234	60.189909	57.779330999999999	57.764049	1 Мая	0103000020E61000000100000005000000946A9F8EC7144E4050C58D5BCCE14C40946A9F8EC7144E4026E1421EC1E34C40A81B28F04E184E4026E1421EC1E34C40A81B28F04E184E4050C58D5BCCE14C40946A9F8EC7144E4050C58D5BCCE14C40
19249	8117	59.840032999999998	59.897354	57.750588999999998	57.708089999999999	Юбилейная	0103000020E61000000100000005000000C7478B3386EB4D40F44F70B1A2DA4C40C7478B3386EB4D4061DEE34C13E04C40A777F17EDCF24D4061DEE34C13E04C40A777F17EDCF24D40F44F70B1A2DA4C40C7478B3386EB4D40F44F70B1A2DA4C40
19028	8117	59.840032999999998	59.897354	57.750588999999998	57.708089999999999	Кирова	0103000020E61000000100000005000000C7478B3386EB4D40F44F70B1A2DA4C40C7478B3386EB4D4061DEE34C13E04C40A777F17EDCF24D4061DEE34C13E04C40A777F17EDCF24D40F44F70B1A2DA4C40C7478B3386EB4D40F44F70B1A2DA4C40
19126	10196	59.016933999999999	59.034837000000003	57.623576	57.615430000000003	Советская	0103000020E610000001000000050000006118B0E42A824D40187D0569C6CE4C406118B0E42A824D4006499F56D1CF4C406BD8EF8975844D4006499F56D1CF4C406BD8EF8975844D40187D0569C6CE4C406118B0E42A824D40187D0569C6CE4C40
18649	8051	59.625515	59.685144999999999	57.666145999999998	57.635319000000003	Ленина	0103000020E61000000100000005000000271422E010D04D4083C30B2252D14C40271422E010D04D403C2EAA4544D54C404B02D4D4B2D74D403C2EAA4544D54C404B02D4D4B2D74D4083C30B2252D14C40271422E010D04D4083C30B2252D14C40
20010	8707	59.109181999999997	59.137065	57.540661	57.526780000000002	Гагарина	0103000020E61000000100000005000000EBA7FFACF98D4D40EC17EC866DC34C40EBA7FFACF98D4D40809C306134C54C408F368E588B914D40809C306134C54C408F368E588B914D40EC17EC866DC34C40EBA7FFACF98D4D40EC17EC866DC34C40
17805	22811	59.857703000000001	59.863909999999997	57.754714999999997	57.751382	Мичурина,	0103000020E610000001000000050000002E573F36C9ED4D40CB660E492DE04C402E573F36C9ED4D407B6649809AE04C40FB57569A94EE4D407B6649809AE04C40FB57569A94EE4D40CB660E492DE04C402E573F36C9ED4D40CB660E492DE04C40
20378	49538	59.488728999999999	59.531030000000001	57.901747	57.890478000000002	Мира	0103000020E61000000100000005000000ABCDFFAB8EBE4D405CE7DF2EFBF14C40ABCDFFAB8EBE4D40102219726CF34C40F29881CAF8C34D40102219726CF34C40F29881CAF8C34D405CE7DF2EFBF14C40ABCDFFAB8EBE4D405CE7DF2EFBF14C40
18106	1643	60.225445999999998	60.291347000000002	57.979889	57.955987	Юбилейная	0103000020E61000000100000005000000CB811E6ADB1C4E40593332C85DFA4C40CB811E6ADB1C4E40E65AB4006DFD4C40D464C6DB4A254E40E65AB4006DFD4C40D464C6DB4A254E40593332C85DFA4C40CB811E6ADB1C4E40593332C85DFA4C40
18973	1643	60.225445999999998	60.291347000000002	57.979889	57.955987	Школьная	0103000020E61000000100000005000000CB811E6ADB1C4E40593332C85DFA4C40CB811E6ADB1C4E40E65AB4006DFD4C40D464C6DB4A254E40E65AB4006DFD4C40D464C6DB4A254E40593332C85DFA4C40CB811E6ADB1C4E40593332C85DFA4C40
19364	9632	60.621343000000003	60.678341000000003	57.722492000000003	57.699221999999999	Почтовая	0103000020E610000001000000050000009D4CDC2A884F4E406552431B80D94C409D4CDC2A884F4E4092CF2B9E7ADC4C409A44BDE0D3564E4092CF2B9E7ADC4C409A44BDE0D3564E406552431B80D94C409D4CDC2A884F4E406552431B80D94C40
17799	9533	60.868648999999998	60.896380000000001	57.574700999999997	57.558916000000004	Советская	0103000020E61000000100000005000000FF59F3E32F6F4E40079B3A8F8AC74C40FF59F3E32F6F4E403FFD67CD8FC94C40ED647094BC724E403FFD67CD8FC94C40ED647094BC724E40079B3A8F8AC74C40FF59F3E32F6F4E40079B3A8F8AC74C40
19379	10396	60.266697000000001	60.306142000000001	57.759757	57.735976999999998	Пионерская	0103000020E610000001000000050000007D78962023224E40D9CD8C7E34DE4C407D78962023224E401BF4A5B73FE14C404DF73AA92F274E401BF4A5B73FE14C404DF73AA92F274E40D9CD8C7E34DE4C407D78962023224E40D9CD8C7E34DE4C40
18991	8501	60.809612000000001	60.828898000000002	57.633656999999999	57.622781000000003	Уральская	0103000020E610000001000000050000007E39B35DA1674E40FCC8AD49B7CF4C407E39B35DA1674E40D4F02DAC1BD14C4023DC6454196A4E40D4F02DAC1BD14C4023DC6454196A4E40FCC8AD49B7CF4C407E39B35DA1674E40FCC8AD49B7CF4C40
19994	22910	60.028894999999999	60.074637000000003	57.800972000000002	57.773159999999997	Юбилейная	0103000020E610000001000000050000004B02D4D4B2034E40A54929E8F6E24C404B02D4D4B2034E408081204086E64C40290989B48D094E408081204086E64C40290989B48D094E40A54929E8F6E24C404B02D4D4B2034E40A54929E8F6E24C40
78588	22910	60.028894999999999	60.074637000000003	57.800972000000002	57.773159999999997	Совхозная	0103000020E610000001000000050000004B02D4D4B2034E40A54929E8F6E24C404B02D4D4B2034E408081204086E64C40290989B48D094E408081204086E64C40290989B48D094E40A54929E8F6E24C404B02D4D4B2034E40A54929E8F6E24C40
19941	50114	61.002803	61.035393999999997	57.696008999999997	57.684193999999998	Декабристов	0103000020E6100000010000000500000054AA44D95B804E40490F43AB93D74C4054AA44D95B804E405F5CAAD216D94C40C03C64CA87844E405F5CAAD216D94C40C03C64CA87844E40490F43AB93D74C4054AA44D95B804E40490F43AB93D74C40
19345	8417	60.803099000000003	60.823886000000002	57.693705000000001	57.684348	Ленина	0103000020E61000000100000005000000A439B2F2CB664E40A08A1BB798D74C40A439B2F2CB664E402D095053CBD84C40EED0B01875694E402D095053CBD84C40EED0B01875694E40A08A1BB798D74C40A439B2F2CB664E40A08A1BB798D74C40
20257	49069	60.859135999999999	60.868074	57.520753999999997	57.514257000000001	Мира	0103000020E610000001000000050000007B681F2BF86D4E409A5E622CD3C14C407B681F2BF86D4E406EA12B11A8C24C400341800C1D6F4E406EA12B11A8C24C400341800C1D6F4E409A5E622CD3C14C407B681F2BF86D4E409A5E622CD3C14C40
20397	9004	59.876460000000002	59.889215999999998	58.131335999999997	58.109043999999997	Ленина	0103000020E6100000010000000500000047205ED72FF04D409AE95E27F50D4D4047205ED72FF04D40CB64389ECF104D403B8A73D4D1F14D40CB64389ECF104D403B8A73D4D1F14D409AE95E27F50D4D4047205ED72FF04D409AE95E27F50D4D40
18274	9399	60.075850000000003	60.091166000000001	57.747884999999997	57.737994999999998	Центральная	0103000020E6100000010000000500000068B3EA73B5094E4046CEC29E76DE4C4068B3EA73B5094E40A01518B2BADF4C40EA40D653AB0B4E40A01518B2BADF4C40EA40D653AB0B4E4046CEC29E76DE4C4068B3EA73B5094E4046CEC29E76DE4C40
18840	7901	59.913533000000001	59.944273000000003	58.069105	58.047583000000003	Привокзальная	0103000020E610000001000000050000008C683BA6EEF44D403C6C223317064D408C683BA6EEF44D40BB7EC16ED8084D4077BF0AF0DDF84D40BB7EC16ED8084D4077BF0AF0DDF84D403C6C223317064D408C683BA6EEF44D403C6C223317064D40
18631	7901	59.913533000000001	59.944273000000003	58.069105	58.047583000000003	Ленина	0103000020E610000001000000050000008C683BA6EEF44D403C6C223317064D408C683BA6EEF44D40BB7EC16ED8084D4077BF0AF0DDF84D40BB7EC16ED8084D4077BF0AF0DDF84D403C6C223317064D408C683BA6EEF44D403C6C223317064D40
18970	45566	60.451219999999999	60.483522999999998	57.729864999999997	57.703555000000001	Красногвардейская	0103000020E610000001000000050000008BA6B393C1394E40F9F719170EDA4C408BA6B393C1394E405DBF60376CDD4C4091EEE714E43D4E405DBF60376CDD4C4091EEE714E43D4E40F9F719170EDA4C408BA6B393C1394E40F9F719170EDA4C40
18357	8773	61.042077999999997	61.066099000000001	57.574444999999997	57.550117999999998	Ленина	0103000020E61000000100000005000000C7F0D8CF62854E40707841446AC64C40C7F0D8CF62854E40E42CEC6987C94C402FA699EE75884E40E42CEC6987C94C402FA699EE75884E40707841446AC64C40C7F0D8CF62854E40707841446AC64C40
19012	46109	60.107345000000002	60.127960999999999	57.891252999999999	57.883066999999997	Центральная	0103000020E61000000100000005000000CF31207BBD0D4E40A296E65608F14C40CF31207BBD0D4E401FBB0B9414F24C40EC14AB0661104E401FBB0B9414F24C40EC14AB0661104E40A296E65608F14C40CF31207BBD0D4E40A296E65608F14C40
19335	7760	59.896241000000003	59.915509	58.079613999999999	58.059235999999999	Уральская	0103000020E61000000100000005000000CC2A6C06B8F24D40785F950B95074D40CC2A6C06B8F24D40E126A3CA300A4D40CA181F662FF54D40E126A3CA300A4D40CA181F662FF54D40785F950B95074D40CC2A6C06B8F24D40785F950B95074D40
19330	7760	59.896241000000003	59.915509	58.079613999999999	58.059235999999999	49	0103000020E61000000100000005000000CC2A6C06B8F24D40785F950B95074D40CC2A6C06B8F24D40E126A3CA300A4D40CA181F662FF54D40E126A3CA300A4D40CA181F662FF54D40785F950B95074D40CC2A6C06B8F24D40785F950B95074D40
18638	6329	59.185367999999997	59.397523	57.718603999999999	57.663271999999999	Ленина	0103000020E61000000100000005000000CADC7C23BA974D401F2DCE18E6D44C40CADC7C23BA974D402C634337FBDB4C4033349E08E2B24D402C634337FBDB4C4033349E08E2B24D401F2DCE18E6D44C40CADC7C23BA974D401F2DCE18E6D44C40
19371	6805	59.467528999999999	59.531784999999999	57.662058999999999	57.639029000000001	Мамина-Сибиряка	0103000020E610000001000000050000003E7782FDD7BB4D400919C8B3CBD14C403E7782FDD7BB4D40E0826C59BED44C406EC0E78711C44D40E0826C59BED44C406EC0E78711C44D400919C8B3CBD14C403E7782FDD7BB4D400919C8B3CBD14C40
18305	45462	60.865945000000004	60.898032999999998	57.542033000000004	57.526035999999998	Ленина	0103000020E610000001000000050000003F912749D76E4E406342CC2555C34C403F912749D76E4E40282D5C5661C54C4048DDCEBEF2724E40282D5C5661C54C4048DDCEBEF2724E406342CC2555C34C403F912749D76E4E406342CC2555C34C40
18718	45479	60.582706000000002	60.604391	57.680773000000002	57.667257999999997	Новая	0103000020E610000001000000050000006C97361C964A4E4047FFCBB568D54C406C97361C964A4E40FA7FD59123D74C40957F2DAF5C4D4E40FA7FD59123D74C40957F2DAF5C4D4E4047FFCBB568D54C406C97361C964A4E4047FFCBB568D54C40
18697	9735	60.691726000000003	60.707590000000003	57.701169999999998	57.682538999999998	Совхозная	0103000020E610000001000000050000007EE5417A8A584E404D9F1D705DD74C407EE5417A8A584E40D97745F0BFD94C40037D224F925A4E40D97745F0BFD94C40037D224F925A4E404D9F1D705DD74C407EE5417A8A584E404D9F1D705DD74C40
18712	8315	60.869179000000003	60.888924000000003	57.635801000000001	57.620596999999997	Школьная	0103000020E610000001000000050000005CAFE941416F4E40737FF5B86FCF4C405CAFE941416F4E40CEE15AED61D14C409450FA42C8714E40CEE15AED61D14C409450FA42C8714E40737FF5B86FCF4C405CAFE941416F4E40737FF5B86FCF4C40
20023	45381	60.042352000000001	60.068393999999998	58.062783000000003	58.041804999999997	Ленина	0103000020E61000000100000005000000C97553CA6B054E4096E7C1DD59054D40C97553CA6B054E4055DFF94509084D400E9F7422C1084E4055DFF94509084D400E9F7422C1084E4096E7C1DD59054D40C97553CA6B054E4096E7C1DD59054D40
18908	9226	60.103364999999997	60.113947000000003	57.697268999999999	57.686787000000002	Привокзальная	0103000020E61000000100000005000000884677103B0D4E40B328ECA2E8D74C40884677103B0D4E40DFC14F1C40D94C40193DB7D0950E4E40DFC14F1C40D94C40193DB7D0950E4E40B328ECA2E8D74C40884677103B0D4E40B328ECA2E8D74C40
20212	50192	60.225445999999998	60.291347000000002	57.979889	57.955987	Птицеводов	0103000020E61000000100000005000000CB811E6ADB1C4E40593332C85DFA4C40CB811E6ADB1C4E40E65AB4006DFD4C40D464C6DB4A254E40E65AB4006DFD4C40D464C6DB4A254E40593332C85DFA4C40CB811E6ADB1C4E40593332C85DFA4C40
20125	50156	60.297635	60.337322	56.449095999999997	56.435755	Гагарина	0103000020E610000001000000050000008E9257E718264E40C408E1D1C6374C408E9257E718264E40D8614CFA7B394C40541C075E2D2B4E40D8614CFA7B394C40541C075E2D2B4E40C408E1D1C6374C408E9257E718264E40C408E1D1C6374C40
19855	50095	59.406694999999999	59.464582	57.035662000000002	57.009906000000001	Демьяна Бедного	0103000020E610000001000000050000002E39EE940EB44D4060048D9944814C402E39EE940EB44D40E0DA899290844C40B727486C77BB4D40E0DA899290844C40B727486C77BB4D4060048D9944814C402E39EE940EB44D4060048D9944814C40
18896	5504	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	Энгельса	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
18227	5504	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	Челюскинцев	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
18264	5504	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	Островского	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
19188	5504	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	Лермонтова	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
18211	5504	60.544590999999997	60.676391000000002	59.084516999999998	59.016613999999997	Клубный переулок	0103000020E6100000010000000500000014596B28B5454E40EF53556820824D4014596B28B5454E405F7AFB73D18A4D408527F4FA93564E405F7AFB73D18A4D408527F4FA93564E40EF53556820824D4014596B28B5454E40EF53556820824D40
18174	5504	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	Кирова	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
18935	5504	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	Гайдара	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
19087	5504	60.557912999999999	60.633299000000001	59.072526000000003	59.035148999999997	Гагарина	0103000020E61000000100000005000000B28174B169474E4059BE2EC37F844D40B28174B169474E400B0E2F8848894D4075CB0EF10F514E400B0E2F8848894D4075CB0EF10F514E4059BE2EC37F844D40B28174B169474E4059BE2EC37F844D40
19972	6410	60.461739000000001	60.561388999999998	59.203057000000001	59.169355000000003	Чкалова	0103000020E61000000100000005000000D52478431A3B4E400135B56CAD954D40D52478431A3B4E40A81C93C5FD994D40C5AA4198DB474E40A81C93C5FD994D40C5AA4198DB474E400135B56CAD954D40D52478431A3B4E400135B56CAD954D40
18657	6410	60.461739000000001	60.561388999999998	59.203057000000001	59.169355000000003	Чехова	0103000020E61000000100000005000000D52478431A3B4E400135B56CAD954D40D52478431A3B4E40A81C93C5FD994D40C5AA4198DB474E40A81C93C5FD994D40C5AA4198DB474E400135B56CAD954D40D52478431A3B4E400135B56CAD954D40
18636	6410	60.461739000000001	60.561388999999998	59.203057000000001	59.169355000000003	Советская	0103000020E61000000100000005000000D52478431A3B4E400135B56CAD954D40D52478431A3B4E40A81C93C5FD994D40C5AA4198DB474E40A81C93C5FD994D40C5AA4198DB474E400135B56CAD954D40D52478431A3B4E400135B56CAD954D40
17784	6410	60.461739000000001	60.561388999999998	59.203057000000001	59.169355000000003	Партсъезда	0103000020E61000000100000005000000D52478431A3B4E400135B56CAD954D40D52478431A3B4E40A81C93C5FD994D40C5AA4198DB474E40A81C93C5FD994D40C5AA4198DB474E400135B56CAD954D40D52478431A3B4E400135B56CAD954D40
17766	6410	60.461739000000001	60.561388999999998	59.203057000000001	59.169355000000003	Островского	0103000020E61000000100000005000000D52478431A3B4E400135B56CAD954D40D52478431A3B4E40A81C93C5FD994D40C5AA4198DB474E40A81C93C5FD994D40C5AA4198DB474E400135B56CAD954D40D52478431A3B4E400135B56CAD954D40
19060	6410	60.461739000000001	60.561388999999998	59.203057000000001	59.169355000000003	Кузнецова	0103000020E61000000100000005000000D52478431A3B4E400135B56CAD954D40D52478431A3B4E40A81C93C5FD994D40C5AA4198DB474E40A81C93C5FD994D40C5AA4198DB474E400135B56CAD954D40D52478431A3B4E400135B56CAD954D40
20153	50164	59.757837000000002	59.823917000000002	58.660030999999996	58.623361000000003	Карла Маркса	0103000020E61000000100000005000000715985CD00E14D400A4D124BCA4F4D40715985CD00E14D404FAC53E57B544D4029CFBC1C76E94D404FAC53E57B544D4029CFBC1C76E94D400A4D124BCA4F4D40715985CD00E14D400A4D124BCA4F4D40
78550	61322	60.803421999999998	60.803888999999998	56.903238999999999	56.901228000000003	Молодежная	0103000020E6100000010000000500000086713788D6664E40A81E69705B734C4086713788D6664E4062BCE6559D734C409C4EB2D5E5664E4062BCE6559D734C409C4EB2D5E5664E40A81E69705B734C4086713788D6664E40A81E69705B734C40
17827	49846	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	Пирогова 	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
18078	3689	59.006180999999998	59.026617000000002	56.433340999999999	56.423431000000001	Набережная	0103000020E61000000100000005000000A46DFC89CA804D40698EACFC32364C40A46DFC89CA804D400A82C7B777374C404242942F68834D400A82C7B777374C404242942F68834D40698EACFC32364C40A46DFC89CA804D40698EACFC32364C40
18545	3546	58.912109000000001	58.941215	56.453623	56.442686999999999	Рассветная	0103000020E6100000010000000500000092B1DAFCBF744D40A3AEB5F7A9384C4092B1DAFCBF744D4051DB8651103A4C4098C0ADBB79784D4051DB8651103A4C4098C0ADBB79784D40A3AEB5F7A9384C4092B1DAFCBF744D40A3AEB5F7A9384C40
19077	3369	59.003953000000003	59.031180999999997	56.468134999999997	56.450394000000003	Совхозная	0103000020E610000001000000050000004DDC2A8881804D404628B682A6394C404DDC2A8881804D40758E01D9EB3B4C40D7A02FBDFD834D40758E01D9EB3B4C40D7A02FBDFD834D404628B682A6394C404DDC2A8881804D404628B682A6394C40
20117	4098	59.047314999999998	59.107788999999997	56.266097000000002	56.255837999999997	Черемушки	0103000020E610000001000000050000001CCEFC6A0E864D407A89B14CBF204C401CCEFC6A0E864D4028486C770F224C402CEFAA07CC8D4D4028486C770F224C402CEFAA07CC8D4D407A89B14CBF204C401CCEFC6A0E864D407A89B14CBF204C40
18108	2514	58.755775	58.774272000000003	56.843668000000001	56.834322999999998	Клубный	0103000020E610000001000000050000003411363CBD604D407AA69718CB6A4C403411363CBD604D4043572250FD6B4C40B11A4B581B634D4043572250FD6B4C40B11A4B581B634D407AA69718CB6A4C403411363CBD604D407AA69718CB6A4C40
19885	2735	58.923175999999998	58.946389000000003	56.920079000000001	56.911588000000002	Советская	0103000020E61000000100000005000000DE3994A12A764D4089B663EAAE744C40DE3994A12A764D40425E0F26C5754C40A725564623794D40425E0F26C5754C40A725564623794D4089B663EAAE744C40DE3994A12A764D4089B663EAAE744C40
20388	50237	59.094099	59.132905999999998	56.331578	56.311421000000003	Ленина	0103000020E610000001000000050000000CCB9F6F0B8C4D40D124B1A4DC274C400CCB9F6F0B8C4D405B09DD25712A4C4099B8551003914D405B09DD25712A4C4099B8551003914D40D124B1A4DC274C400CCB9F6F0B8C4D40D124B1A4DC274C40
20121	4532	59.078639000000003	59.095958000000003	56.215563000000003	56.208855	Лесная	0103000020E610000001000000050000005798BED7108A4D40944DB9C2BB1A4C405798BED7108A4D40249D8191971B4C4011E50B5A488C4D40249D8191971B4C4011E50B5A488C4D40944DB9C2BB1A4C405798BED7108A4D40944DB9C2BB1A4C40
18095	3968	58.974550999999998	58.997152999999997	56.345224000000002	56.331763000000002	Мубаракшина	0103000020E610000001000000050000005DA45016BE7C4D40ED82C135772A4C405DA45016BE7C4D40ACE5CE4C302C4C40DC0DA2B5A27F4D40ACE5CE4C302C4C40DC0DA2B5A27F4D40ED82C135772A4C405DA45016BE7C4D40ED82C135772A4C40
20275	1471	59.519002	59.548681999999999	56.828724000000001	56.81268	Ленина	0103000020E61000000100000005000000804754A86EC24D40800EF3E505684C40804754A86EC24D4085B4C6A0136A4C40B2F336363BC64D4085B4C6A0136A4C40B2F336363BC64D40800EF3E505684C40804754A86EC24D40800EF3E505684C40
19821	2405	58.609439999999999	58.634053999999999	56.855890000000002	56.847512999999999	Мира	0103000020E61000000100000005000000E76F4221024E4D40A9F7544E7B6C4C40E76F4221024E4D409A7CB3CD8D6D4C40F1F274AE28514D409A7CB3CD8D6D4C40F1F274AE28514D40A9F7544E7B6C4C40E76F4221024E4D40A9F7544E7B6C4C40
18337	4361	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	городок Солнечный	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
17842	4361	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	Титова	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
20003	4361	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	Стахановцев	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
18975	4361	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	Пролетарская	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
18701	4361	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	Мякутина	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
18316	4361	59.277517000000003	59.348412000000003	56.684162000000001	56.633634999999998	Ленина	0103000020E61000000100000005000000C28A53AD85A34D40EC4CA1F31A514C40C28A53AD85A34D403E95D39E92574C4059C4B0C398AC4D403E95D39E92574C4059C4B0C398AC4D40EC4CA1F31A514C40C28A53AD85A34D40EC4CA1F31A514C40
18930	2865	58.887647999999999	58.905974000000001	56.768200999999998	56.758589999999998	Победы	0103000020E610000001000000050000000E2E1D739E714D404C89247A19614C400E2E1D739E714D4093E00D6954624C405E83BEF4F6734D4093E00D6954624C405E83BEF4F6734D404C89247A19614C400E2E1D739E714D404C89247A19614C40
17969	387	59.237012	59.259497000000003	56.413119000000002	56.398465999999999	Чкалова	0103000020E610000001000000050000003961C268569E4D40B24813EF00334C403961C268569E4D40992D5915E1344C407F349C3237A14D40992D5915E1344C407F349C3237A14D40B24813EF00334C403961C268569E4D40B24813EF00334C40
19130	3	59.068559999999998	59.154744000000001	56.469383000000001	56.405943000000001	Уральская	0103000020E6100000010000000500000029E8F692C6884D402385B2F0F5334C4029E8F692C6884D403126FDBD143C4C4049A0C1A6CE934D403126FDBD143C4C4049A0C1A6CE934D402385B2F0F5334C4029E8F692C6884D402385B2F0F5334C40
18252	3	59.068559999999998	59.154744000000001	56.469383000000001	56.405943000000001	Кирова	0103000020E6100000010000000500000029E8F692C6884D402385B2F0F5334C4029E8F692C6884D403126FDBD143C4C4049A0C1A6CE934D403126FDBD143C4C4049A0C1A6CE934D402385B2F0F5334C4029E8F692C6884D402385B2F0F5334C40
18663	3	59.068559999999998	59.154744000000001	56.469383000000001	56.405943000000001	Демьяна Бедного	0103000020E6100000010000000500000029E8F692C6884D402385B2F0F5334C4029E8F692C6884D403126FDBD143C4C4049A0C1A6CE934D403126FDBD143C4C4049A0C1A6CE934D402385B2F0F5334C4029E8F692C6884D402385B2F0F5334C40
18866	3	59.068559999999998	59.154744000000001	56.469383000000001	56.405943000000001	Грязнова,	0103000020E6100000010000000500000029E8F692C6884D402385B2F0F5334C4029E8F692C6884D403126FDBD143C4C4049A0C1A6CE934D403126FDBD143C4C4049A0C1A6CE934D402385B2F0F5334C4029E8F692C6884D402385B2F0F5334C40
18460	1582	59.518059000000001	59.530949999999997	56.771273999999998	56.765542000000003	Химмашевская	0103000020E610000001000000050000000133DFC14FC24D4073DBBE47FD614C400133DFC14FC24D40A7203F1BB9624C40D5E76A2BF6C34D40A7203F1BB9624C40D5E76A2BF6C34D4073DBBE47FD614C400133DFC14FC24D4073DBBE47FD614C40
19852	3880	59.010249999999999	59.041052999999998	56.331034000000002	56.315575000000003	Ленина	0103000020E610000001000000050000005A643BDF4F814D40B537F8C264284C405A643BDF4F814D409AEE75525F2A4C408B33863941854D409AEE75525F2A4C408B33863941854D40B537F8C264284C405A643BDF4F814D40B537F8C264284C40
18841	2634	58.741286000000002	58.765729	56.875649000000003	56.861407	 переулок Клубный	0103000020E61000000100000005000000C87DAB75E25E4D40D2C5A695426E4C40C87DAB75E25E4D4037E3344415704C40A54C6A6803624D4037E3344415704C40A54C6A6803624D40D2C5A695426E4C40C87DAB75E25E4D40D2C5A695426E4C40
18803	1706	58.459529000000003	58.501156999999999	56.836623000000003	56.825187999999997	Первомайская	0103000020E610000001000000050000002448A5D8D13A4D409C86A8C29F694C402448A5D8D13A4D406C0A6476166B4C40AB949EE925404D406C0A6476166B4C40AB949EE925404D409C86A8C29F694C402448A5D8D13A4D409C86A8C29F694C40
18009	2058	58.605387999999998	58.686542000000003	56.834766999999999	56.815981000000001	Красных Партизан	0103000020E6100000010000000500000007B29E5A7D4D4D402594BE1072684C4007B29E5A7D4D4D40D86322A5D96A4C404CAAB69BE0574D40D86322A5D96A4C404CAAB69BE0574D402594BE1072684C4007B29E5A7D4D4D402594BE1072684C40
19050	2058	58.605387999999998	58.686542000000003	56.834766999999999	56.815981000000001	Азина	0103000020E6100000010000000500000007B29E5A7D4D4D402594BE1072684C4007B29E5A7D4D4D40D86322A5D96A4C404CAAB69BE0574D40D86322A5D96A4C404CAAB69BE0574D402594BE1072684C4007B29E5A7D4D4D402594BE1072684C40
18820	2287	58.610329	58.622231999999997	56.780576000000003	56.766159000000002	Центральная	0103000020E610000001000000050000007366BB421F4E4D409E44847F11624C407366BB421F4E4D40710514EAE9634C402843554CA54F4D40710514EAE9634C402843554CA54F4D409E44847F11624C407366BB421F4E4D409E44847F11624C40
78587	14817	59.145195000000001	59.190415999999999	56.846843999999997	56.834018	Трактовая	0103000020E610000001000000050000007845F0BF95924D403E23111AC16A4C407845F0BF95924D402B685A62656C4C404C512E8D5F984D402B685A62656C4C404C512E8D5F984D403E23111AC16A4C407845F0BF95924D403E23111AC16A4C40
18760	1251	59.49729	59.537866999999999	56.799354999999998	56.779733	Калинина	0103000020E610000001000000050000005D50DF32A7BF4D40554E7B4ACE634C405D50DF32A7BF4D407172BF4351664C407F4C6BD3D8C44D407172BF4351664C407F4C6BD3D8C44D40554E7B4ACE634C405D50DF32A7BF4D40554E7B4ACE634C40
20020	1251	59.49729	59.537866999999999	56.799354999999998	56.779733	Азина	0103000020E610000001000000050000005D50DF32A7BF4D40554E7B4ACE634C405D50DF32A7BF4D407172BF4351664C407F4C6BD3D8C44D407172BF4351664C407F4C6BD3D8C44D40554E7B4ACE634C405D50DF32A7BF4D40554E7B4ACE634C40
17988	530	59.537723	59.581111999999997	56.666289999999996	56.627896	Пришкольная	0103000020E610000001000000050000004CA7751BD4C44D4005A568E55E504C404CA7751BD4C44D406FD39FFD48554C4015A8C5E061CA4D406FD39FFD48554C4015A8C5E061CA4D4005A568E55E504C404CA7751BD4C44D4005A568E55E504C40
77080	530	59.537723	59.581111999999997	56.666289999999996	56.627896	Ленина	0103000020E610000001000000050000004CA7751BD4C44D4005A568E55E504C404CA7751BD4C44D406FD39FFD48554C4015A8C5E061CA4D406FD39FFD48554C4015A8C5E061CA4D4005A568E55E504C404CA7751BD4C44D4005A568E55E504C40
19029	530	59.537723	59.581111999999997	56.666289999999996	56.627896	Володарского	0103000020E610000001000000050000004CA7751BD4C44D4005A568E55E504C404CA7751BD4C44D406FD39FFD48554C4015A8C5E061CA4D406FD39FFD48554C4015A8C5E061CA4D4005A568E55E504C404CA7751BD4C44D4005A568E55E504C40
9715	3094	58.797232999999999	58.820507999999997	56.762222000000001	56.748246999999999	Школьная	0103000020E610000001000000050000005F251FBB0B664D40412AC58EC65F4C405F251FBB0B664D405725917D90614C409D0DF96706694D405725917D90614C409D0DF96706694D40412AC58EC65F4C405F251FBB0B664D40412AC58EC65F4C40
18846	13108	59.032187	59.088925000000003	56.879314000000001	56.832053000000002	Чапаева	0103000020E610000001000000050000009D2D20B41E844D40F4C473B6806A4C409D2D20B41E844D401D75745C8D704C40FE65F7E4618B4D401D75745C8D704C40FE65F7E4618B4D40F4C473B6806A4C409D2D20B41E844D40F4C473B6806A4C40
18847	13108	59.032187	59.088925000000003	56.879314000000001	56.832053000000002	Революции	0103000020E610000001000000050000009D2D20B41E844D40F4C473B6806A4C409D2D20B41E844D401D75745C8D704C40FE65F7E4618B4D401D75745C8D704C40FE65F7E4618B4D40F4C473B6806A4C409D2D20B41E844D40F4C473B6806A4C40
19123	13108	59.032187	59.088925000000003	56.879314000000001	56.832053000000002	Октябрьская	0103000020E610000001000000050000009D2D20B41E844D40F4C473B6806A4C409D2D20B41E844D401D75745C8D704C40FE65F7E4618B4D401D75745C8D704C40FE65F7E4618B4D40F4C473B6806A4C409D2D20B41E844D40F4C473B6806A4C40
18140	13108	59.032187	59.088925000000003	56.879314000000001	56.832053000000002	Ленина	0103000020E610000001000000050000009D2D20B41E844D40F4C473B6806A4C409D2D20B41E844D401D75745C8D704C40FE65F7E4618B4D401D75745C8D704C40FE65F7E4618B4D40F4C473B6806A4C409D2D20B41E844D40F4C473B6806A4C40
18993	13108	59.032187	59.088925000000003	56.879314000000001	56.832053000000002	Дзержинского	0103000020E610000001000000050000009D2D20B41E844D40F4C473B6806A4C409D2D20B41E844D401D75745C8D704C40FE65F7E4618B4D401D75745C8D704C40FE65F7E4618B4D40F4C473B6806A4C409D2D20B41E844D40F4C473B6806A4C40
20264	1009	59.414088	59.456318000000003	56.704273999999998	56.675291999999999	Заводская	0103000020E6100000010000000500000041D5E8D500B54D400EA0DFF76F564C4041D5E8D500B54D4028B682A6255A4C40BF49D3A068BA4D4028B682A6255A4C40BF49D3A068BA4D400EA0DFF76F564C4041D5E8D500B54D400EA0DFF76F564C40
77081	1009	59.414088	59.456318000000003	56.704273999999998	56.675291999999999	Гагарина	0103000020E6100000010000000500000041D5E8D500B54D400EA0DFF76F564C4041D5E8D500B54D4028B682A6255A4C40BF49D3A068BA4D4028B682A6255A4C40BF49D3A068BA4D400EA0DFF76F564C4041D5E8D500B54D400EA0DFF76F564C40
18517	3263	59.203234999999999	59.224642000000003	56.449817000000003	56.435262999999999	Азина	0103000020E610000001000000050000008733BF9A039A4D405514AFB2B6374C408733BF9A039A4D40A9177C9A93394C406EA7AD11C19C4D40A9177C9A93394C406EA7AD11C19C4D405514AFB2B6374C408733BF9A039A4D405514AFB2B6374C40
19085	3586	59.010492999999997	59.044269	56.394924000000003	56.372174000000001	Мысф Джаиля	0103000020E6100000010000000500000020EBA9D557814D40F435CB65A32F4C4020EBA9D557814D40E833A0DE8C324C40029D499BAA854D40E833A0DE8C324C40029D499BAA854D40F435CB65A32F4C4020EBA9D557814D40F435CB65A32F4C40
20259	50205	59.537723	59.581111999999997	56.666289999999996	56.627896	Володарского	0103000020E610000001000000050000004CA7751BD4C44D4005A568E55E504C404CA7751BD4C44D406FD39FFD48554C4015A8C5E061CA4D406FD39FFD48554C4015A8C5E061CA4D4005A568E55E504C404CA7751BD4C44D4005A568E55E504C40
17902	49859	60.134312000000001	60.266112999999997	57.450477999999997	57.379356999999999	Советов	0103000020E61000000100000005000000EDBAB72231114E401C412AC58EB04C40EDBAB72231114E40A3C85A43A9B94C402D05A4FD0F224E40A3C85A43A9B94C402D05A4FD0F224E401C412AC58EB04C40EDBAB72231114E401C412AC58EB04C40
19067	11231	60.552962999999998	60.592407999999999	57.392014000000003	57.379536999999999	Ленина	0103000020E61000000100000005000000F372D87DC7464E409C4F1DAB94B04C40F372D87DC7464E407EC9C6832DB24C40C3F17C06D44B4E407EC9C6832DB24C40C3F17C06D44B4E409C4F1DAB94B04C40F372D87DC7464E409C4F1DAB94B04C40
18924	45901	60.137303000000003	60.169300999999997	57.486294999999998	57.458888000000002	Ленина	0103000020E6100000010000000500000044520B2593114E4070438CD7BCBA4C4044520B2593114E40AA9A20EA3EBE4C400D17B9A7AB154E40AA9A20EA3EBE4C400D17B9A7AB154E4070438CD7BCBA4C4044520B2593114E4070438CD7BCBA4C40
18953	30839	60.254137999999998	60.270991000000002	57.429605000000002	57.422432999999998	Ленина	0103000020E61000000100000005000000DE550F9887204E4026E0D74812B64C40DE550F9887204E405B99F04BFDB64C40534145D5AF224E405B99F04BFDB64C40534145D5AF224E4026E0D74812B64C40DE550F9887204E4026E0D74812B64C40
19854	46920	60.050795999999998	60.073945000000002	57.143653999999998	57.117142000000001	Ленина	0103000020E610000001000000050000004162BB7B80064E40787E5182FE8E4C404162BB7B80064E4044F8174163924C40F3599E0777094E4044F8174163924C40F3599E0777094E40787E5182FE8E4C404162BB7B80064E40787E5182FE8E4C40
19955	30262	60.118330999999998	60.145415	57.081753999999997	57.062677000000001	Центральная	0103000020E610000001000000050000002E8D5F78250F4E400F9BC8CC05884C402E8D5F78250F4E40992842EA768A4C4086AC6EF59C124E40992842EA768A4C4086AC6EF59C124E400F9BC8CC05884C402E8D5F78250F4E400F9BC8CC05884C40
20198	30262	60.118330999999998	60.145415	57.081753999999997	57.062677000000001	Лесная	0103000020E610000001000000050000002E8D5F78250F4E400F9BC8CC05884C402E8D5F78250F4E40992842EA768A4C4086AC6EF59C124E40992842EA768A4C4086AC6EF59C124E400F9BC8CC05884C402E8D5F78250F4E400F9BC8CC05884C40
19968	30884	60.274566	60.290968999999997	57.491427999999999	57.482937999999997	Промышленная	0103000020E61000000100000005000000F94B8BFA24234E4071FF91E9D0BD4C40F94B8BFA24234E405A2BDA1CE7BE4C402D93E1783E254E405A2BDA1CE7BE4C402D93E1783E254E4071FF91E9D0BD4C40F94B8BFA24234E4071FF91E9D0BD4C40
19965	30828	60.26773	60.283000999999999	57.473089999999999	57.461933000000002	Ленина	0103000020E610000001000000050000003C1405FA44224E40BAF8DB9E20BB4C403C1405FA44224E4046088F368EBC4C401EDE736039244E4046088F368EBC4C401EDE736039244E40BAF8DB9E20BB4C403C1405FA44224E40BAF8DB9E20BB4C40
19098	46961	59.927025999999998	59.945090999999998	57.074392000000003	57.061458999999999	Ленина	0103000020E610000001000000050000005645B8C9A8F64D40BE8575E3DD874C405645B8C9A8F64D40C28A53AD85894C40395FECBDF8F84D40C28A53AD85894C40395FECBDF8F84D40BE8575E3DD874C405645B8C9A8F64D40BE8575E3DD874C40
20392	46935	59.835838000000003	59.860576999999999	57.148614999999999	57.135790999999998	Восточная	0103000020E61000000100000005000000856055BDFCEA4D40AA0B789961914C40856055BDFCEA4D40F758FAD005934C404B581B6327EE4D40F758FAD005934C404B581B6327EE4D40AA0B789961914C40856055BDFCEA4D40AA0B789961914C40
17771	46094	60.548983	60.569949999999999	57.509863000000003	57.500816	КМаркса	0103000020E61000000100000005000000AD872F1345464E4022A81ABD1AC04C40AD872F1345464E406138D73043C14C40772D211FF4484E406138D73043C14C40772D211FF4484E4022A81ABD1AC04C40AD872F1345464E4022A81ABD1AC04C40
18091	17766	60.050859000000003	60.121772	57.263199	57.226635999999999	Чкалова	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
18074	17766	60.050859000000003	60.121772	57.263199	57.226635999999999	Фрунзе	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
17922	17766	60.050859000000003	60.121772	57.263199	57.226635999999999	Свердлова	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
17798	17766	60.050859000000003	60.121772	57.263199	57.226635999999999	Микрорайон 15	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
18114	17766	60.050859000000003	60.121772	57.263199	57.226635999999999	Ленина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
19846	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Юбилейная	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
18784	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Чурина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
77103	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Театральный проезд	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
18641	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Советская	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
19845	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Свердлова	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
20294	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	С.Дудина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
18800	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Победы	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
20018	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Первомайская	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
18786	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Мичурина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
19953	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Ленина	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
20075	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Крупской	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
18452	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Корнилова	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
77083	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Комсомольская	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
19095	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Загородное шоссе	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
19081	49928	60.050859000000003	60.121772	57.263199	57.226635999999999	Автозаводская	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
78513	30414	60.368637999999997	60.385894	57.592345999999999	57.578653000000003	Макаренко	0103000020E610000001000000050000000B08AD872F2F4E40BC5D2F4D11CA4C400B08AD872F2F4E404DF564FED1CB4C407FDC7EF964314E404DF564FED1CB4C407FDC7EF964314E40BC5D2F4D11CA4C400B08AD872F2F4E40BC5D2F4D11CA4C40
18273	30720	60.457597999999997	60.477530999999999	57.403207000000002	57.394176999999999	Победы	0103000020E61000000100000005000000855B3E92923A4E40EEEA556474B24C40855B3E92923A4E40574277499CB34C40C0E95DBC1F3D4E40574277499CB34C40C0E95DBC1F3D4E40EEEA556474B24C40855B3E92923A4E40EEEA556474B24C40
17776	46063	60.621226	60.650995999999999	57.481122999999997	57.466400999999998	Горького	0103000020E6100000010000000500000063B66455844F4E402DE92807B3BB4C4063B66455844F4E403C2D3F7095BD4C40D5E940D653534E403C2D3F7095BD4C40D5E940D653534E402DE92807B3BB4C4063B66455844F4E402DE92807B3BB4C40
19817	46118	60.724576999999996	60.748381999999999	57.46096	57.452773000000001	Трактористов	0103000020E6100000010000000500000086376BF0BE5C4E4083C13577F4B94C4086376BF0BE5C4E40D061BEBC00BB4C4021753BFBCA5F4E40D061BEBC00BB4C4021753BFBCA5F4E4083C13577F4B94C4086376BF0BE5C4E4083C13577F4B94C40
18367	45927	60.140644999999999	60.161585000000002	57.142305999999998	57.125024000000003	Советская	0103000020E6100000010000000500000047ACC5A700124E40899B53C900904C4047ACC5A700124E402503401537924C40184339D1AE144E402503401537924C40184339D1AE144E40899B53C900904C4047ACC5A700124E40899B53C900904C40
18300	31028	60.161512999999999	60.171636999999997	57.506971	57.500100000000003	Уральская	0103000020E610000001000000050000007E703E75AC144E40645DDC4603C04C407E703E75AC144E409D82FC6CE4C04C404BE48233F8154E409D82FC6CE4C04C404BE48233F8154E40645DDC4603C04C407E703E75AC144E40645DDC4603C04C40
18646	30512	60.364486999999997	60.384115999999999	57.572330999999998	57.560364999999997	Мира	0103000020E6100000010000000500000098689082A72E4E405969520ABAC74C4098689082A72E4E4055BE672442C94C4067EF8CB62A314E4055BE672442C94C4067EF8CB62A314E405969520ABAC74C4098689082A72E4E405969520ABAC74C40
18581	15145	60.114854999999999	60.163921000000002	57.281923999999997	57.253146000000001	Площадь Революции	0103000020E610000001000000050000001B649291B30E4E407E8E8F1667A04C401B649291B30E4E408FFAEB1516A44C405610035DFB144E408FFAEB1516A44C405610035DFB144E407E8E8F1667A04C401B649291B30E4E407E8E8F1667A04C40
18635	30411	60.270460999999997	60.314028999999998	57.548819000000002	57.527698000000001	Мартьянова	0103000020E61000000100000005000000F6EB4E779E224E401215AA9B8BC34C40F6EB4E779E224E40333674B33FC64C406F7F2E1A32284E40333674B33FC64C406F7F2E1A32284E401215AA9B8BC34C40F6EB4E779E224E401215AA9B8BC34C40
20014	30218	60.216031999999998	63.669227999999997	57.538646999999997	57.021956000000003	Ленина	0103000020E61000000100000005000000DA71C3EFA61B4E40BAF94674CF824C40DA71C3EFA61B4E40548B8862F2C44C40A3C85A43A9D54F40548B8862F2C44C40A3C85A43A9D54F40BAF94674CF824C40DA71C3EFA61B4E40BAF94674CF824C40
78414	30716	60.67897	60.710887	57.424754	57.399289000000003	Калинина	0103000020E61000000100000005000000897B2C7DE8564E408753E6E61BB34C40897B2C7DE8564E402F6CCD565EB64C4066136058FE5A4E402F6CCD565EB64C4066136058FE5A4E408753E6E61BB34C40897B2C7DE8564E408753E6E61BB34C40
20209	50190	60.050859000000003	60.121772	57.263199	57.226635999999999	Корнилова	0103000020E6100000010000000500000088DA368C82064E40520C9068029D4C4088DA368C82064E4082AB3C81B0A14C40C5C89239960F4E4082AB3C81B0A14C40C5C89239960F4E40520C9068029D4C4088DA368C82064E40520C9068029D4C40
20129	50159	57.930278000000001	57.970064000000001	56.451408999999998	56.429872000000003	Октября	0103000020E610000001000000050000001A18795913F74C40AABBB20B06374C401A18795913F74C405E0F26C5C7394C407383A10E2BFC4C405E0F26C5C7394C407383A10E2BFC4C40AABBB20B06374C401A18795913F74C40AABBB20B06374C40
18569	27942	57.872525000000003	57.894371999999997	56.691710999999998	56.679549000000002	Школьная	0103000020E61000000100000005000000A1F831E6AEEF4C40C7832D76FB564C40A1F831E6AEEF4C4048A46DFC89584C40A33A1DC87AF24C4048A46DFC89584C40A33A1DC87AF24C40C7832D76FB564C40A1F831E6AEEF4C40C7832D76FB564C40
19138	28326	57.734966	57.752231000000002	56.557138000000002	56.548434999999998	Набережная	0103000020E6100000010000000500000002D6AA5D13DE4C40AA7D3A1E33464C4002D6AA5D13DE4C40EFAD484C50474C40C904FC1A49E04C40EFAD484C50474C40C904FC1A49E04C40AA7D3A1E33464C4002D6AA5D13DE4C40AA7D3A1E33464C40
17983	27472	57.687652	57.704908000000003	56.793277000000003	56.777568000000002	Ленина	0103000020E61000000100000005000000B68311FB04D84C404435255987634C40B68311FB04D84C40A2D5C9198A654C402A58E36C3ADA4C40A2D5C9198A654C402A58E36C3ADA4C404435255987634C40B68311FB04D84C404435255987634C40
78549	61321	57.843859999999999	57.86815	56.294300999999997	56.284539000000002	Лесная	0103000020E610000001000000050000008733BF9A03EC4C40E1B721C66B244C408733BF9A03EC4C400D17B9A7AB254C40DE02098A1FEF4C400D17B9A7AB254C40DE02098A1FEF4C40E1B721C66B244C408733BF9A03EC4C40E1B721C66B244C40
78580	61332	57.984724	58.014360000000003	56.632922000000001	56.617570999999998	Октября	0103000020E610000001000000050000000CCB9F6F0BFE4C40A0FA07910C4F4C400CCB9F6F0BFE4C409F758D9603514C406F2F698CD6014D409F758D9603514C406F2F698CD6014D40A0FA07910C4F4C400CCB9F6F0BFE4C40A0FA07910C4F4C40
18717	29295	57.916614000000003	57.951092000000003	56.245635	56.228575999999997	Советская	0103000020E610000001000000050000002387889B53F54C40435376FA411D4C402387889B53F54C4061E0B9F7701F4C405EBEF561BDF94C4061E0B9F7701F4C405EBEF561BDF94C40435376FA411D4C402387889B53F54C40435376FA411D4C40
19912	28841	57.85463	57.873790999999997	56.457163999999999	56.442956000000002	Центральная	0103000020E610000001000000050000001A170E8464ED4C4093C83EC8B2384C401A170E8464ED4C404B749659843A4C4002452C62D8EF4C404B749659843A4C4002452C62D8EF4C4093C83EC8B2384C401A170E8464ED4C4093C83EC8B2384C40
18988	28891	57.966911000000003	58.022049000000003	56.309413999999997	56.287567000000003	Советская	0103000020E61000000100000005000000439259BDC3FB4C405534D6FECE244C40439259BDC3FB4C405776C1E09A274C406BF46A80D2024D405776C1E09A274C406BF46A80D2024D405534D6FECE244C40439259BDC3FB4C405534D6FECE244C40
20334	28891	57.966911000000003	58.022049000000003	56.309413999999997	56.287567000000003	Ленина	0103000020E61000000100000005000000439259BDC3FB4C405534D6FECE244C40439259BDC3FB4C405776C1E09A274C406BF46A80D2024D405776C1E09A274C406BF46A80D2024D405534D6FECE244C40439259BDC3FB4C405534D6FECE244C40
20122	28196	57.976486999999999	57.994579000000002	56.576574000000001	56.564796000000001	Новая	0103000020E610000001000000050000000DFCA886FDFC4C40B0743E3C4B484C400DFCA886FDFC4C40A9DC442DCD494C40EA245B5D4EFF4C40A9DC442DCD494C40EA245B5D4EFF4C40B0743E3C4B484C400DFCA886FDFC4C40B0743E3C4B484C40
20147	29277	57.976109999999998	57.995756	56.224601999999997	56.203082000000002	Ленина	0103000020E6100000010000000500000037A6272CF1FC4C4001344A97FE194C4037A6272CF1FC4C40DF4E22C2BF1C4C40DC65BFEE74FF4C40DF4E22C2BF1C4C40DC65BFEE74FF4C4001344A97FE194C4037A6272CF1FC4C4001344A97FE194C40
18359	29472	57.704639	57.731479999999998	56.256528000000003	56.231133	Труда	0103000020E610000001000000050000003A3E5A9C31DA4C40600322C4951D4C403A3E5A9C31DA4C401041D5E8D5204C40CBD6FA22A1DD4C401041D5E8D5204C40CBD6FA22A1DD4C40600322C4951D4C403A3E5A9C31DA4C40600322C4951D4C40
18173	28564	57.689951000000001	57.744838000000001	56.489749000000003	56.468572999999999	Советская	0103000020E61000000100000005000000D76B7A5050D84C40F1643733FA3B4C40D76B7A5050D84C40D61F6118B03E4C40B66801DA56DF4C40D61F6118B03E4C40B66801DA56DF4C40F1643733FA3B4C40D76B7A5050D84C40F1643733FA3B4C40
18873	28564	57.689951000000001	57.744838000000001	56.489749000000003	56.468572999999999	Горького	0103000020E61000000100000005000000D76B7A5050D84C40F1643733FA3B4C40D76B7A5050D84C40D61F6118B03E4C40B66801DA56DF4C40D61F6118B03E4C40B66801DA56DF4C40F1643733FA3B4C40D76B7A5050D84C40F1643733FA3B4C40
78541	61319	57.860371000000001	57.885055999999999	56.326242999999998	56.314587000000003	Школьная	0103000020E61000000100000005000000A2B60DA320EE4C40965F066344284C40A2B60DA320EE4C4043C6A354C2294C407590D78349F14C4043C6A354C2294C407590D78349F14C40965F066344284C40A2B60DA320EE4C40965F066344284C40
20324	28063	58.024276999999998	58.067386999999997	56.594161999999997	56.585205000000002	Ленина	0103000020E61000000100000005000000C2853C821B034D40543A58FFE74A4C40C2853C821B034D4052431B800D4C4C4078962023A0084D4052431B800D4C4C4078962023A0084D40543A58FFE74A4C40C2853C821B034D40543A58FFE74A4C40
18146	27799	57.772309	57.801395999999997	56.666181000000002	56.646306000000003	Первомайская	0103000020E6100000010000000500000007B47405DBE24C40B39AAE27BA524C4007B47405DBE24C40B91B446B45554C409692E52494E64C40B91B446B45554C409692E52494E64C40B39AAE27BA524C4007B47405DBE24C40B39AAE27BA524C40
18554	49296	57.785818999999996	57.829971999999998	56.744889999999998	56.725161	Виктора Прокудина	0103000020E61000000100000005000000A7C98CB795E44C40D6AA5D13D25C4C40A7C98CB795E44C40088F368E585F4C40404CC2853CEA4C40088F368E585F4C40404CC2853CEA4C40D6AA5D13D25C4C40A7C98CB795E44C40D6AA5D13D25C4C40
19002	45371	57.833402999999997	57.855699000000001	56.429718000000001	56.417028000000002	Сосновая	0103000020E61000000100000005000000B3B112F3ACEA4C4016C26A2C61354C40B3B112F3ACEA4C405340DAFF00374C40261C7A8B87ED4C405340DAFF00374C40261C7A8B87ED4C4016C26A2C61354C40B3B112F3ACEA4C4016C26A2C61354C40
18354	29158	57.925677999999998	57.964745999999998	56.306941999999999	56.298012	Садовая	0103000020E610000001000000050000003750E09D7CF64C4064E8D84125264C403750E09D7CF64C4069E21DE049274C40317903CC7CFB4C4069E21DE049274C40317903CC7CFB4C4064E8D84125264C403750E09D7CF64C4064E8D84125264C40
41465	55028	\N	\N	\N	\N	Уральская	\N
19110	27242	57.410378000000001	57.453173	56.875717999999999	56.850476	Октябрьская	0103000020E61000000100000005000000BB7F2C4487B44C403604C765DC6C4C40BB7F2C4487B44C405F42058717704C401137A79201BA4C405F42058717704C401137A79201BA4C403604C765DC6C4C40BB7F2C4487B44C403604C765DC6C4C40
18592	28661	57.858314	57.883673000000002	56.481364999999997	56.465384999999998	Советская	0103000020E6100000010000000500000077D9AF3BDDED4C40448655BC913B4C4077D9AF3BDDED4C4032384A5E9D3D4C40DAAD65321CF14C4032384A5E9D3D4C40DAAD65321CF14C40448655BC913B4C4077D9AF3BDDED4C40448655BC913B4C40
78502	28661	57.858314	57.883673000000002	56.481364999999997	56.465384999999998	Ленина	0103000020E6100000010000000500000077D9AF3BDDED4C40448655BC913B4C4077D9AF3BDDED4C4032384A5E9D3D4C40DAAD65321CF14C4032384A5E9D3D4C40DAAD65321CF14C40448655BC913B4C4077D9AF3BDDED4C40448655BC913B4C40
78534	61315	57.894426000000003	57.912132	56.337307000000003	56.328085000000002	Заречная	0103000020E610000001000000050000009758198D7CF24C4072A774B0FE294C409758198D7CF24C401FDB32E02C2B4C404AD1CABDC0F44C401FDB32E02C2B4C404AD1CABDC0F44C4072A774B0FE294C409758198D7CF24C4072A774B0FE294C40
19903	28555	57.822659000000002	57.847633000000002	56.46734	56.458621999999998	Советская	0103000020E610000001000000050000004A61DEE34CE94C40F19C2D20B43A4C404A61DEE34CE94C406B0E10CCD13B4C405401F73C7FEC4C406B0E10CCD13B4C405401F73C7FEC4C40F19C2D20B43A4C404A61DEE34CE94C40F19C2D20B43A4C40
19127	49345	57.876334	57.914521000000001	56.644632999999999	56.630659000000001	Гагарина	0103000020E61000000100000005000000BA2F67B62BF04C40CBF6216FB9504C40BA2F67B62BF04C4010768A5583524C40AB402D060FF54C4010768A5583524C40AB402D060FF54C40CBF6216FB9504C40BA2F67B62BF04C40CBF6216FB9504C40
19014	29558	57.800452999999997	57.828012999999999	56.601322000000003	56.573391000000001	Советская 	0103000020E61000000100000005000000177E703E75E64C400E6954E064494C40177E703E75E64C40C32E8A1EF84C4C40D8D47954FCE94C40C32E8A1EF84C4C40D8D47954FCE94C400E6954E064494C40177E703E75E64C400E6954E064494C40
18865	29558	57.800452999999997	57.828012999999999	56.601322000000003	56.573391000000001	Советская	0103000020E61000000100000005000000177E703E75E64C400E6954E064494C40177E703E75E64C40C32E8A1EF84C4C40D8D47954FCE94C40C32E8A1EF84C4C40D8D47954FCE94C400E6954E064494C40177E703E75E64C400E6954E064494C40
78511	27479	57.680205000000001	57.694569000000001	56.828142999999997	56.820118999999998	Молодёжная	0103000020E61000000100000005000000B0C91AF510D74C4003EACDA8F9684C40B0C91AF510D74C40A6B4FE96006A4C4060E811A3E7D84C40A6B4FE96006A4C4060E811A3E7D84C4003EACDA8F9684C40B0C91AF510D74C4003EACDA8F9684C40
18829	27205	57.392007	57.433132000000001	56.925021000000001	56.907947	Центральная	0103000020E61000000100000005000000CB660E492DB24C402BC0779B37744C40CB660E492DB24C407E8E8F1667764C40F06C8FDE70B74C407E8E8F1667764C40F06C8FDE70B74C402BC0779B37744C40CB660E492DB24C402BC0779B37744C40
78508	49495	57.848019000000001	57.866290999999997	56.524113999999997	56.516838999999997	Центральная	0103000020E610000001000000050000007DB1F7E28BEC4C400F26C5C727424C407DB1F7E28BEC4C4018B0E42A16434C40D9E89C9FE2EE4C4018B0E42A16434C40D9E89C9FE2EE4C400F26C5C727424C407DB1F7E28BEC4C400F26C5C727424C40
18141	49891	57.707199000000003	57.723377999999997	56.699807	56.686836999999997	Студенческая	0103000020E61000000100000005000000C861307F85DA4C4064575A46EA574C40C861307F85DA4C408541994693594C40AC527AA697DC4C408541994693594C40AC527AA697DC4C4064575A46EA574C40C861307F85DA4C4064575A46EA574C40
18588	49510	57.873423000000003	57.893526999999999	56.592759000000001	56.583654000000003	Заречная	0103000020E6100000010000000500000080492A53CCEF4C40FD169D2CB54A4C4080492A53CCEF4C4070B4E386DF4B4C40E78BBD175FF24C4070B4E386DF4B4C40E78BBD175FF24C40FD169D2CB54A4C4080492A53CCEF4C40FD169D2CB54A4C40
18584	28384	57.724707000000002	57.772919999999999	56.495052000000001	56.468283999999997	Новая	0103000020E610000001000000050000005517F032C3DC4C40BA9EE8BAF03B4C405517F032C3DC4C40E2E82ADD5D3F4C405036E50AEFE24C40E2E82ADD5D3F4C405036E50AEFE24C40BA9EE8BAF03B4C405517F032C3DC4C40BA9EE8BAF03B4C40
18214	45652	57.630859999999998	57.643742000000003	56.258833000000003	56.249460999999997	Трактовая	0103000020E61000000100000005000000622D3E05C0D04C4050508A56EE1F4C40622D3E05C0D04C401310937021214C40E4874A2366D24C401310937021214C40E4874A2366D24C4050508A56EE1F4C40622D3E05C0D04C4050508A56EE1F4C40
18606	45445	58.053679000000002	58.079738999999996	56.316878000000003	56.310388000000003	Заречная	0103000020E61000000100000005000000B2BD16F4DE064D40128942CBBA274C40B2BD16F4DE064D40346953758F284C409D9B36E3340A4D40346953758F284C409D9B36E3340A4D40128942CBBA274C40B2BD16F4DE064D40128942CBBA274C40
20108	27586	57.561599999999999	57.576844000000001	56.812339999999999	56.800379999999997	Кунгурская 	0103000020E6100000010000000500000080B74082E2C74C40AD2F12DA72664C4080B74082E2C74C40C79DD2C1FA674C4069723106D6C94C40C79DD2C1FA674C4069723106D6C94C40AD2F12DA72664C4080B74082E2C74C40AD2F12DA72664C40
20227	29024	58.001649	58.027242000000001	56.308680000000003	56.295499999999997	Советская	0103000020E610000001000000050000001A89D00836004D40E7FBA9F1D2254C401A89D00836004D40F37684D382274C40F08975AA7C034D40F37684D382274C40F08975AA7C034D40E7FBA9F1D2254C401A89D00836004D40E7FBA9F1D2254C40
19135	28277	58.010677000000001	58.020989	56.550975999999999	56.543278999999998	Нагорная	0103000020E61000000100000005000000E2E82ADD5D014D4042CD902A8A454C40E2E82ADD5D014D40C170AE6186464C40B2497EC4AF024D40C170AE6186464C40B2497EC4AF024D4042CD902A8A454C40E2E82ADD5D014D4042CD902A8A454C40
18147	27858	57.676521000000001	57.695934000000001	56.619611999999996	56.610214999999997	Центральная	0103000020E610000001000000050000005307793D98D64C40AA436E861B4E4C405307793D98D64C40C51A2E724F4F4C405516855D14D94C40C51A2E724F4F4C405516855D14D94C40AA436E861B4E4C405307793D98D64C40AA436E861B4E4C40
19117	27382	57.610343	57.621203000000001	56.856386999999998	56.852544000000002	Свободы	0103000020E61000000100000005000000D82B2CB81FCE4C4055336B29206D4C40D82B2CB81FCE4C401ADCD6169E6D4C40AB96749483CF4C401ADCD6169E6D4C40AB96749483CF4C4055336B29206D4C40D82B2CB81FCE4C4055336B29206D4C40
20105	27529	57.608097000000001	57.632711	56.761052999999997	56.743547999999997	Совхозная	0103000020E61000000100000005000000DAE55B1FD6CD4C40CB80B3942C5F4C40DAE55B1FD6CD4C40E7C2482F6A614C40E4688EACFCD04C40E7C2482F6A614C40E4688EACFCD04C40CB80B3942C5F4C40DAE55B1FD6CD4C40CB80B3942C5F4C40
18839	27377	57.53351	57.556516000000002	56.856299	56.842737999999997	Октября	0103000020E61000000100000005000000630B410E4AC44C40588CBAD6DE6B4C40630B410E4AC44C407B4CA4349B6D4C40B2D991EA3BC74C407B4CA4349B6D4C40B2D991EA3BC74C40588CBAD6DE6B4C40630B410E4AC44C40588CBAD6DE6B4C40
18887	29366	58.003616000000001	58.028624999999998	56.149135000000001	56.123955000000002	Советская	0103000020E6100000010000000500000005DF347D76004D407D96E7C1DD0F4C4005DF347D76004D4030D80DDB16134C408B6CE7FBA9034D4030D80DDB16134C408B6CE7FBA9034D407D96E7C1DD0F4C4005DF347D76004D407D96E7C1DD0F4C40
19895	28195	58.109267000000003	58.120092	56.582403999999997	56.572870000000002	Ленина	0103000020E610000001000000050000001AC40776FC0D4D40056EDDCD53494C401AC40776FC0D4D40A087DA368C4A4C407041B62C5F0F4D40A087DA368C4A4C407041B62C5F0F4D40056EDDCD53494C401AC40776FC0D4D40056EDDCD53494C40
18853	49281	57.817449000000003	57.833618999999999	56.719445999999998	56.708227000000001	Александровская	0103000020E61000000100000005000000EF92382BA2E84C407592AD2EA75A4C40EF92382BA2E84C40779E78CE165C4C4080290307B4EA4C40779E78CE165C4C4080290307B4EA4C407592AD2EA75A4C40EF92382BA2E84C407592AD2EA75A4C40
20346	50225	57.950499000000001	58.006329000000001	56.135427999999997	56.112226999999997	Мира	0103000020E61000000100000005000000BBF083F3A9F94C40355D4F745D0E4C40BBF083F3A9F94C40397B67B455114C4019028063CF004D40397B67B455114C4019028063CF004D40355D4F745D0E4C40BBF083F3A9F94C40355D4F745D0E4C40
20348	50227	57.772309	57.801395999999997	56.666181000000002	56.646306000000003	Первомайская	0103000020E6100000010000000500000007B47405DBE24C40B39AAE27BA524C4007B47405DBE24C40B91B446B45554C409692E52494E64C40B91B446B45554C409692E52494E64C40B39AAE27BA524C4007B47405DBE24C40B39AAE27BA524C40
20150	50162	60.274017999999998	60.301488999999997	59.709780000000002	59.688637	Клубная	0103000020E61000000100000005000000F641960513234E4064E8D84125D84D40F641960513234E406DAD2F12DADA4D40478D093197264E406DAD2F12DADA4D40478D093197264E4064E8D84125D84D40F641960513234E4064E8D84125D84D40
18314	49849	61.075018999999998	62.401910999999998	56.686262999999997	56.131089000000003	Трудовые резервы	0103000020E6100000010000000500000010CAFB389A894E40C4EE3B86C7104C4010CAFB389A894E4038BA4A77D7574C408A73D4D171334F4038BA4A77D7574C408A73D4D171334F40C4EE3B86C7104C4010CAFB389A894E40C4EE3B86C7104C40
18334	49849	61.878283000000003	62.010083999999999	56.389184	56.316004999999997	Железнодородная станция УАЗ	0103000020E61000000100000005000000FFD0CC936BF04E40AD2F12DA72284C40FFD0CC936BF04E40301004C8D0314C403F1BB96E4A014F40301004C8D0314C403F1BB96E4A014F40AD2F12DA72284C40FFD0CC936BF04E40AD2F12DA72284C40
17838	49849	61.075018999999998	62.401910999999998	56.686262999999997	56.131089000000003	2я Рабочая	0103000020E6100000010000000500000010CAFB389A894E40C4EE3B86C7104C4010CAFB389A894E4038BA4A77D7574C408A73D4D171334F4038BA4A77D7574C408A73D4D171334F40C4EE3B86C7104C4010CAFB389A894E40C4EE3B86C7104C40
19851	50093	59.459561000000001	59.500154999999999	58.720187000000003	58.683137000000002	4-й микрорайон	0103000020E610000001000000050000002FC214E5D2BA4D4002D8800871574D402FC214E5D2BA4D408F006E162F5C4D4027F73B1405C04D408F006E162F5C4D4027F73B1405C04D4002D8800871574D402FC214E5D2BA4D4002D8800871574D40
78452	61298	62.574244	62.590243000000001	56.796156000000003	56.780763	Кондратьева	0103000020E610000001000000050000004DF6CFD380494F40A376BF0AF0634C404DF6CFD380494F40D1419770E8654C40B2D826158D4B4F40D1419770E8654C40B2D826158D4B4F40A376BF0AF0634C404DF6CFD380494F40A376BF0AF0634C40
18375	26646	62.824137999999998	62.841231999999998	56.702069999999999	56.687099000000003	Нагорная	0103000020E6100000010000000500000007B29E5A7D694F40A20E2BDCF2574C4007B29E5A7D694F4059C0046EDD594C40A12C7C7DAD6B4F4059C0046EDD594C40A12C7C7DAD6B4F40A20E2BDCF2574C4007B29E5A7D694F40A20E2BDCF2574C40
18805	26466	62.720830999999997	62.740954000000002	56.796235000000003	56.77449	Народная	0103000020E61000000100000005000000B378B130445C4F401E8A027D22634C40B378B130445C4F401D774A07EB654C4092EBA694D75E4F401D774A07EB654C4092EBA694D75E4F401E8A027D22634C40B378B130445C4F401E8A027D22634C40
18129	48829	62.827227999999998	62.848931	56.830250999999997	56.821804	Школьная	0103000020E61000000100000005000000F12A6B9BE2694F406ADC9BDF30694C40F12A6B9BE2694F40533C2EAA456A4C40C1C760C5A96C4F40533C2EAA456A4C40C1C760C5A96C4F406ADC9BDF30694C40F12A6B9BE2694F406ADC9BDF30694C40
19083	26562	62.891817000000003	62.922862000000002	56.759675999999999	56.748443999999999	Советская	0103000020E610000001000000050000002882380F27724F4097715303CD5F4C402882380F27724F402EC72B103D614C404F5C8E5720764F402EC72B103D614C404F5C8E5720764F4097715303CD5F4C402882380F27724F4097715303CD5F4C40
18497	26931	62.577612999999999	62.649748000000002	56.845666999999999	56.814216999999999	Школьная	0103000020E610000001000000050000004A5F0839EF494F40726C3D4338684C404A5F0839EF494F403927F6D03E6C4C401A5245F12A534F403927F6D03E6C4C401A5245F12A534F40726C3D4338684C404A5F0839EF494F40726C3D4338684C40
18835	48806	62.888044000000001	62.951976999999999	56.851520000000001	56.839336000000003	пер.Школьный	0103000020E610000001000000050000005BB4006DAB714F40802DAF5C6F6B4C405BB4006DAB714F40E9F17B9BFE6C4C40A8C5E061DA794F40E9F17B9BFE6C4C40A8C5E061DA794F40802DAF5C6F6B4C405BB4006DAB714F40802DAF5C6F6B4C40
18614	49083	62.877228000000002	62.921362000000002	57.058506999999999	57.047831000000002	Новая	0103000020E610000001000000050000005891D10149704F40145E82531F864C405891D10149704F4025CB49287D874C407AE3A430EF754F4025CB49287D874C407AE3A430EF754F40145E82531F864C405891D10149704F40145E82531F864C40
18485	26655	62.676409999999997	62.694043999999998	56.647019	56.638323	Титова	0103000020E61000000100000005000000FB57569A94564F406EA46C91B4514C40FB57569A94564F400072C284D1524C4015FE0C6FD6584F400072C284D1524C4015FE0C6FD6584F406EA46C91B4514C40FB57569A94564F406EA46C91B4514C40
20193	26938	62.572358000000001	62.590522	56.857185000000001	56.843210999999997	Молодежная	0103000020E610000001000000050000004FCDE50643494F4050508A56EE6B4C404FCDE50643494F4096CFF23CB86D4C40C5C89239964B4F4096CFF23CB86D4C40C5C89239964B4F4050508A56EE6B4C404FCDE50643494F4050508A56EE6B4C40
20309	27193	62.678386000000003	62.722439000000001	57.099412999999998	57.08081	Ленина	0103000020E610000001000000050000003A083A5AD5564F404A9869FB578A4C403A083A5AD5564F400CE6AF90B98C4C406F2D93E1785C4F400CE6AF90B98C4C406F2D93E1785C4F404A9869FB578A4C403A083A5AD5564F404A9869FB578A4C40
18552	48987	62.455029000000003	62.496971000000002	56.832334000000003	56.811660000000003	Советская	0103000020E61000000100000005000000A5DDE8633E3A4F4056BC9179E4674C40A5DDE8633E3A4F40A8ACA6EB896A4C40BC07E8BE9C3F4F40A8ACA6EB896A4C40BC07E8BE9C3F4F4056BC9179E4674C40A5DDE8633E3A4F4056BC9179E4674C40
19108	48950	62.627747999999997	62.654876999999999	56.714739000000002	56.691177000000003	Бачурина	0103000020E610000001000000050000009010E50B5A504F40AB5FE97C78584C409010E50B5A504F407F164B917C5B4C4088F37002D3534F407F164B917C5B4C4088F37002D3534F40AB5FE97C78584C409010E50B5A504F40AB5FE97C78584C40
20088	27029	62.718063999999998	62.745454000000002	56.921764000000003	56.884673999999997	Мира	0103000020E61000000100000005000000AC376A85E95B4F408DCF64FF3C714C40AC376A85E95B4F40A950DD5CFC754C40115663096B5F4F40A950DD5CFC754C40115663096B5F4F408DCF64FF3C714C40AC376A85E95B4F408DCF64FF3C714C40
18524	48890	62.835016000000003	62.853917000000003	56.731447000000003	56.723773000000001	Комсомольская	0103000020E6100000010000000500000081D1E5CDE16A4F40295DFA97A45C4C4081D1E5CDE16A4F40F0E0270EA05D4C40CD3FFA264D6D4F40F0E0270EA05D4C40CD3FFA264D6D4F40295DFA97A45C4C4081D1E5CDE16A4F40295DFA97A45C4C40
17936	27107	62.691150999999998	62.714139000000003	57.016751999999997	57.003019999999999	Красных Партизан	0103000020E6100000010000000500000081CCCEA277584F40F19D98F562804C4081CCCEA277584F404012F6ED24824C402AE620E8685B4F404012F6ED24824C402AE620E8685B4F40F19D98F562804C4081CCCEA277584F40F19D98F562804C40
19842	26462	62.777569	62.799218000000003	56.808363999999997	56.802213000000002	Ленина	0103000020E6100000010000000500000014B1886187634F4089B663EAAE664C4014B1886187634F40C2A1B77878674C40F12F82C64C664F40C2A1B77878674C40F12F82C64C664F4089B663EAAE664C4014B1886187634F4089B663EAAE664C40
17968	49874	61.365138999999999	61.384399000000002	56.482557999999997	56.468026000000002	Ленина	0103000020E6100000010000000500000040BFEFDFBCAE4E40BFD6A546E83B4C4040BFEFDFBCAE4E402A36E675C43D4C40BCCE86FC33B14E402A36E675C43D4C40BCCE86FC33B14E40BFD6A546E83B4C4040BFEFDFBCAE4E40BFD6A546E83B4C40
19832	50090	61.902206	61.940581999999999	56.259808	56.246335999999999	Советская	0103000020E61000000100000005000000A320787C7BF34E40EAE923F0871F4C40A320787C7BF34E409D9E776341214C40679AB0FD64F84E409D9E776341214C40679AB0FD64F84E40EAE923F0871F4C40A320787C7BF34E40EAE923F0871F4C40
18338	22861	62.445515999999998	62.483927999999999	57.411172999999998	57.403595000000003	Ленина	0103000020E6100000010000000500000020EC14AB06394F4021EA3E00A9B34C4020EC14AB06394F40C5FF1D51A1B44C4031CF4A5AF13D4F40C5FF1D51A1B44C4031CF4A5AF13D4F4021EA3E00A9B34C4020EC14AB06394F4021EA3E00A9B34C40
18691	22996	62.403097000000002	62.432436000000003	57.402999000000001	57.391781000000002	Кирова	0103000020E61000000100000005000000D00EB8AE98334F40DB183BE125B24C40D00EB8AE98334F400DA9A27895B34C4079CE16105A374F400DA9A27895B34C4079CE16105A374F40DB183BE125B24C40D00EB8AE98334F40DB183BE125B24C40
18861	19213	63.360692	63.387551999999999	57.623904000000003	57.605117	Советская	0103000020E61000000100000005000000E4F6CB272BAE4F4077A04E7974CD4C40E4F6CB272BAE4F40FBEB1516DCCF4C40ECBFCE4D9BB14F40FBEB1516DCCF4C40ECBFCE4D9BB14F4077A04E7974CD4C40E4F6CB272BAE4F4077A04E7974CD4C40
18583	19315	63.489789000000002	63.514043999999998	57.647396000000001	57.643022000000002	Октябрьская	0103000020E610000001000000050000006478EC67B1BE4F40E44D7E8B4ED24C406478EC67B1BE4F40D6C743DFDDD24C403E5A9C31CCC14F40D6C743DFDDD24C403E5A9C31CCC14F40E44D7E8B4ED24C406478EC67B1BE4F40E44D7E8B4ED24C40
18302	22297	62.733893000000002	62.767301000000003	57.416791000000003	57.403483999999999	Пролетарская	0103000020E61000000100000005000000B5E1B034F05D4F40C93A1C5DA5B34C40B5E1B034F05D4F403222516859B54C4014984EEB36624F403222516859B54C4014984EEB36624F40C93A1C5DA5B34C40B5E1B034F05D4F40C93A1C5DA5B34C40
18429	20754	62.787467999999997	62.814534999999999	57.706738000000001	57.698852000000002	Школьная	0103000020E61000000100000005000000C1525DC0CB644F40425F7AFB73D94C40C1525DC0CB644F40946B0A6476DA4C404339D1AE42684F40946B0A6476DA4C404339D1AE42684F40425F7AFB73D94C40C1525DC0CB644F40425F7AFB73D94C40
18601	19887	62.141894000000001	63.632496000000003	58.037197999999997	57.134838000000002	Советская	0103000020E61000000100000005000000D3BF249529124F400821205F42914C40D3BF249529124F4001BD70E7C2044D40E86C01A1F5D04F4001BD70E7C2044D40E86C01A1F5D04F400821205F42914C40D3BF249529124F400821205F42914C40
18615	20537	62.972000000000001	62.998365999999997	57.694802000000003	57.685724	Советская	0103000020E6100000010000000500000023DBF97E6A7C4F40890AD5CDC5D74C4023DBF97E6A7C4F4003999D45EFD84C401BB80375CA7F4F4003999D45EFD84C401BB80375CA7F4F40890AD5CDC5D74C4023DBF97E6A7C4F40890AD5CDC5D74C40
18685	22810	62.520462000000002	62.545408000000002	57.278066000000003	57.250560999999998	Октябрьская	0103000020E61000000100000005000000C767B27F9E424F409753026212A04C40C767B27F9E424F409510ACAA97A34C40077DE9EDCF454F409510ACAA97A34C40077DE9EDCF454F409753026212A04C40C767B27F9E424F409753026212A04C40
18945	17588	63.138565999999997	63.145887000000002	57.641361000000003	57.638109	Гагарина	0103000020E61000000100000005000000342BDB87BC914F404224438EADD14C40342BDB87BC914F4006F7031E18D24C40AEF4DA6CAC924F4006F7031E18D24C40AEF4DA6CAC924F404224438EADD14C40342BDB87BC914F404224438EADD14C40
18752	20183	62.141894000000001	63.632496000000003	58.037197999999997	57.134838000000002	Береговая	0103000020E61000000100000005000000D3BF249529124F400821205F42914C40D3BF249529124F4001BD70E7C2044D40E86C01A1F5D04F4001BD70E7C2044D40E86C01A1F5D04F400821205F42914C40D3BF249529124F400821205F42914C40
18361	19001	63.072746000000002	63.086508000000002	57.646721999999997	57.641703	Центральная	0103000020E610000001000000050000001975ADBD4F894F405F5FEB5223D24C401975ADBD4F894F4046CD57C9C7D24C40D36BB3B1128B4F4046CD57C9C7D24C40D36BB3B1128B4F405F5FEB5223D24C401975ADBD4F894F405F5FEB5223D24C40
19114	18071	62.601821999999999	62.624423999999998	57.931323999999996	57.925499000000002	Центральная	0103000020E61000000100000005000000B401D880084D4F4088BD50C076F64C40B401D880084D4F406DFDF49F35F74C40336B2920ED4F4F406DFDF49F35F74C40336B2920ED4F4F4088BD50C076F64C40B401D880084D4F4088BD50C076F64C40
18617	20847	62.813186999999999	62.845455000000001	57.594912000000001	57.579078000000003	Центральная	0103000020E610000001000000050000002444F98216684F40A3EA573A1FCA4C402444F98216684F40BDFF8F1326CC4C40AE9E93DE376C4F40BDFF8F1326CC4C40AE9E93DE376C4F40A3EA573A1FCA4C402444F98216684F40A3EA573A1FCA4C40
17749	21717	62.638643999999999	62.681773	57.560127999999999	57.544922	Дорожная	0103000020E61000000100000005000000B0E42A16BF514F407A6F0C01C0C54C40B0E42A16BF514F4075C93846B2C74C40DD25715644574F4075C93846B2C74C40DD25715644574F407A6F0C01C0C54C40B0E42A16BF514F407A6F0C01C0C54C40
18355	22011	62.944772	62.972360000000002	57.426470000000002	57.404958000000001	Юбилейная	0103000020E610000001000000050000009816F549EE784F407520EBA9D5B34C409816F549EE784F40D15CA79196B64C4023F8DF4A767C4F40D15CA79196B64C4023F8DF4A767C4F407520EBA9D5B34C409816F549EE784F407520EBA9D5B34C40
18190	20047	63.062254000000003	63.080570999999999	57.397475	57.384329999999999	Прядеинская	0103000020E61000000100000005000000C90567F0F7874F40936FB6B931B14C40C90567F0F7874F4022FDF675E0B24C40C5008926508A4F4022FDF675E0B24C40C5008926508A4F40936FB6B931B14C40C90567F0F7874F40936FB6B931B14C40
20004	20233	63.003109000000002	63.025512999999997	57.685796000000003	57.67559	Ожиганова	0103000020E6100000010000000500000061A92EE065804F4098C0ADBB79D64C4061A92EE065804F4023DDCF29C8D74C40B94F8E0244834F4023DDCF29C8D74C40B94F8E0244834F4098C0ADBB79D64C4061A92EE065804F4098C0ADBB79D64C40
18609	20233	63.003109000000002	63.025512999999997	57.685796000000003	57.67559	Мира	0103000020E6100000010000000500000061A92EE065804F4098C0ADBB79D64C4061A92EE065804F4023DDCF29C8D74C40B94F8E0244834F4023DDCF29C8D74C40B94F8E0244834F4098C0ADBB79D64C4061A92EE065804F4098C0ADBB79D64C40
18330	22616	62.634475999999999	62.645066999999997	57.268655000000003	57.255536999999997	улица Школьная	0103000020E61000000100000005000000670C738236514F407FF5B86FB5A04C40670C738236514F4015747B4963A24C404A5D328E91524F4015747B4963A24C404A5D328E91524F407FF5B86FB5A04C40670C738236514F407FF5B86FB5A04C40
18289	21776	62.476292000000001	62.511012000000001	57.558360999999998	57.544075999999997	Молодежная	0103000020E6100000010000000500000058ACE122F73C4F40ED444948A4C54C4058ACE122F73C4F40512E8D5F78C74C4089EE59D768414F40512E8D5F78C74C4089EE59D768414F40ED444948A4C54C4058ACE122F73C4F40ED444948A4C54C40
17816	47006	63.231793000000003	63.242761000000002	57.513565999999997	57.505443	Торфянников	0103000020E610000001000000050000008B389D64AB9D4F40FE7E315BB2C04C408B389D64AB9D4F40342BDB87BCC14C4044DFDDCA129F4F40342BDB87BCC14C4044DFDDCA129F4F40FE7E315BB2C04C408B389D64AB9D4F40FE7E315BB2C04C40
20337	20161	63.097441000000003	63.112003000000001	57.570632000000003	57.554431000000001	Школьная	0103000020E6100000010000000500000010255AF2788C4F40BD715298F7C64C4010255AF2788C4F408A0629780AC94C40E606431D568E4F408A0629780AC94C40E606431D568E4F40BD715298F7C64C4010255AF2788C4F40BD715298F7C64C40
18136	18168	62.750970000000002	62.775089999999999	57.884607000000003	57.876792999999999	Центральная	0103000020E610000001000000050000007923F3C81F604F404D2EC6C03AF04C407923F3C81F604F4006685BCD3AF14C4073BA2C2636634F4006685BCD3AF14C4073BA2C2636634F404D2EC6C03AF04C407923F3C81F604F404D2EC6C03AF04C40
18871	19507	63.276223999999999	63.295223	57.569662000000001	57.561301	Комсомольская	0103000020E61000000100000005000000662FDB4E5BA34F40261B0FB6D8C74C40662FDB4E5BA34F4011E335AFEAC84C40750305DEC9A54F4011E335AFEAC84C40750305DEC9A54F40261B0FB6D8C74C40662FDB4E5BA34F40261B0FB6D8C74C40
17747	17273	63.306713000000002	63.326951999999999	57.646172999999997	57.641812999999999	Набережная	0103000020E610000001000000050000000821205F42A74F40E692AAED26D24C400821205F42A74F407347FFCBB5D24C404FAE2990D9A94F407347FFCBB5D24C404FAE2990D9A94F40E692AAED26D24C400821205F42A74F40E692AAED26D24C40
18610	20421	63.021075000000003	63.046156000000003	57.697716999999997	57.683996999999998	Новая	0103000020E61000000100000005000000B1E1E995B2824F40F3C7B4368DD74C40B1E1E995B2824F407E6E68CA4ED94C40D1419770E8854F407E6E68CA4ED94C40D1419770E8854F40F3C7B4368DD74C40B1E1E995B2824F40F3C7B4368DD74C40
17845	23089	63.356074999999997	63.381838999999999	57.856772999999997	57.837474999999998	переулок Школьный	0103000020E610000001000000050000002BF697DD93AD4F40DA1B7C6132EB4C402BF697DD93AD4F40438CD7BCAAED4C402EABB019E0B04F40438CD7BCAAED4C402EABB019E0B04F40DA1B7C6132EB4C402BF697DD93AD4F40DA1B7C6132EB4C40
18667	22553	62.791080000000001	62.804797000000001	57.301428000000001	57.287970999999999	Центральная	0103000020E610000001000000050000008542041C42654F402499D53BDCA44C408542041C42654F40A20C553195A64C409F758D9603674F40A20C553195A64C409F758D9603674F402499D53BDCA44C408542041C42654F402499D53BDCA44C40
18138	18359	62.896039000000002	62.913727000000002	57.830671000000002	57.823990000000002	Площадная	0103000020E610000001000000050000006478EC67B1724F40931D1B8178E94C406478EC67B1724F40295E656D53EA4C40713C9F01F5744F40295E656D53EA4C40713C9F01F5744F40931D1B8178E94C406478EC67B1724F40931D1B8178E94C40
18315	22454	62.738295000000001	62.762729	57.358007000000001	57.344847999999999	Советская	0103000020E6100000010000000500000071E65773805E4F40A60BB1FA23AC4C4071E65773805E4F409A5E622CD3AD4C40FB5A971AA1614F409A5E622CD3AD4C40FB5A971AA1614F40A60BB1FA23AC4C4071E65773805E4F40A60BB1FA23AC4C40
19118	18272	62.868136999999997	62.898249	57.832061000000003	57.816321000000002	Урицкого	0103000020E6100000010000000500000049B9FB1C1F6F4F40DE04DF347DE84C4049B9FB1C1F6F4F4077A38FF980EA4C401555BFD2F9724F4077A38FF980EA4C401555BFD2F9724F40DE04DF347DE84C4049B9FB1C1F6F4F40DE04DF347DE84C40
19929	20593	62.862253000000003	62.878540000000001	57.642690000000002	57.630130000000001	Центральная	0103000020E610000001000000050000005FF0694E5E6E4F403F1D8F19A8D04C405FF0694E5E6E4F40AEBB79AA43D24C402A1DACFF73704F40AEBB79AA43D24C402A1DACFF73704F403F1D8F19A8D04C405FF0694E5E6E4F403F1D8F19A8D04C40
18578	19112	63.237972999999997	63.253262999999997	57.649442999999998	57.638643999999999	Новая	0103000020E610000001000000050000005E2A36E6759E4F40B0E42A16BFD14C405E2A36E6759E4F40DDCEBEF220D34C40B72407EC6AA04F40DDCEBEF220D34C40B72407EC6AA04F40B0E42A16BFD14C405E2A36E6759E4F40B0E42A16BFD14C40
19259	22070	62.628979000000001	62.673929999999999	57.414746000000001	57.388928999999997	Ленина	0103000020E61000000100000005000000766F456282504F40A5BBEB6CC8B14C40766F456282504F40CB129D6516B54C408AE5965643564F40CB129D6516B54C408AE5965643564F40A5BBEB6CC8B14C40766F456282504F40A5BBEB6CC8B14C40
20052	50139	62.141894000000001	63.632496000000003	58.037197999999997	57.134838000000002	Пролетарская	0103000020E61000000100000005000000D3BF249529124F400821205F42914C40D3BF249529124F4001BD70E7C2044D40E86C01A1F5D04F4001BD70E7C2044D40E86C01A1F5D04F400821205F42914C40D3BF249529124F400821205F42914C40
18875	19570	63.213934999999999	63.251071000000003	57.548403999999998	57.538231000000003	переулок Знаменский	0103000020E61000000100000005000000213CDA38629B4F40C158DFC0E4C44C40213CDA38629B4F406F7F2E1A32C64C40ADFC321823A04F406F7F2E1A32C64C40ADFC321823A04F40C158DFC0E4C44C40213CDA38629B4F40C158DFC0E4C44C40
19059	21064	62.701481999999999	62.772483999999999	57.572307000000002	57.502223000000001	Школьная	0103000020E61000000100000005000000C85D8429CA594F404626E0D748C04C40C85D8429CA594F40CD22145B41C94C40755776C1E0624F40CD22145B41C94C40755776C1E0624F404626E0D748C04C40C85D8429CA594F404626E0D748C04C40
19882	21064	62.701481999999999	62.772483999999999	57.572307000000002	57.502223000000001	Студенческая	0103000020E61000000100000005000000C85D8429CA594F404626E0D748C04C40C85D8429CA594F40CD22145B41C94C40755776C1E0624F40CD22145B41C94C40755776C1E0624F404626E0D748C04C40C85D8429CA594F404626E0D748C04C40
18918	21064	62.701481999999999	62.772483999999999	57.572307000000002	57.502223000000001	Мира	0103000020E61000000100000005000000C85D8429CA594F404626E0D748C04C40C85D8429CA594F40CD22145B41C94C40755776C1E0624F40CD22145B41C94C40755776C1E0624F404626E0D748C04C40C85D8429CA594F404626E0D748C04C40
19888	21064	62.701481999999999	62.772483999999999	57.572307000000002	57.502223000000001	Коммунистическая	0103000020E61000000100000005000000C85D8429CA594F404626E0D748C04C40C85D8429CA594F40CD22145B41C94C40755776C1E0624F40CD22145B41C94C40755776C1E0624F404626E0D748C04C40C85D8429CA594F404626E0D748C04C40
20365	21064	62.701481999999999	62.772483999999999	57.572307000000002	57.502223000000001	Александра Матросова	0103000020E61000000100000005000000C85D8429CA594F404626E0D748C04C40C85D8429CA594F40CD22145B41C94C40755776C1E0624F40CD22145B41C94C40755776C1E0624F404626E0D748C04C40C85D8429CA594F404626E0D748C04C40
18563	18690	63.177174999999998	63.200783000000001	57.685766999999998	57.668356000000003	Центральная	0103000020E610000001000000050000009B559FABAD964F40EE0A7DB08CD54C409B559FABAD964F4088D68A36C7D74C40E04BE141B3994F4088D68A36C7D74C40E04BE141B3994F40EE0A7DB08CD54C409B559FABAD964F40EE0A7DB08CD54C40
18567	18793	63.343310000000002	63.353631999999998	57.702424999999998	57.691862999999998	Советская	0103000020E61000000100000005000000E4310395F1AB4F40FE277FF78ED84C40E4310395F1AB4F404772F90FE9D94C40D76839D043AD4F404772F90FE9D94C40D76839D043AD4F40FE277FF78ED84C40E4310395F1AB4F40FE277FF78ED84C40
17803	22344	62.567461999999999	62.591734000000002	57.324541000000004	57.294137999999997	Советская	0103000020E6100000010000000500000083DC4598A2484F4063416150A6A54C4083DC4598A2484F40079B3A8F8AA94C4034F790F0BD4B4F40079B3A8F8AA94C4034F790F0BD4B4F4063416150A6A54C4083DC4598A2484F4063416150A6A54C40
19892	18907	63.133975	63.147747000000003	57.652991999999998	57.647255999999999	Чайкина	0103000020E61000000100000005000000A5BDC11726914F40E411DC48D9D24C40A5BDC11726914F405A46EA3D95D34C40838AAA5FE9924F405A46EA3D95D34C40838AAA5FE9924F40E411DC48D9D24C40A5BDC11726914F40E411DC48D9D24C40
18850	18476	63.064310999999996	63.087003000000003	57.787767000000002	57.780746999999998	переулок Береговой	0103000020E61000000100000005000000F3E2C4573B884F409DB98784EFE34C40F3E2C4573B884F401CEF8E8CD5E44C40B3D30FEA228B4F401CEF8E8CD5E44C40B3D30FEA228B4F409DB98784EFE34C40F3E2C4573B884F409DB98784EFE34C40
19154	19722	63.155462999999997	63.169459000000003	57.505806	57.488607999999999	переулок Галишевский	0103000020E61000000100000005000000785E2A36E6934F403048FAB48ABE4C40785E2A36E6934F406F0F4240BEC04C40A6811FD5B0954F406F0F4240BEC04C40A6811FD5B0954F403048FAB48ABE4C40785E2A36E6934F403048FAB48ABE4C40
18293	21920	62.902417	62.921047999999999	57.491520000000001	57.477246999999998	Кирова	0103000020E610000001000000050000005E2D776682734F409B8E006E16BD4C405E2D776682734F403BAA9A20EABE4C40EA059FE6E4754F403BAA9A20EABE4C40EA059FE6E4754F409B8E006E16BD4C405E2D776682734F409B8E006E16BD4C40
78594	61336	63.181919000000001	63.195869000000002	57.525039999999997	57.514150999999998	Советская	0103000020E61000000100000005000000B1C22D1F49974F40541A31B3CFC14C40B1C22D1F49974F40C18BBE8234C34C406EA6423C12994F40C18BBE8234C34C406EA6423C12994F40541A31B3CFC14C40B1C22D1F49974F40541A31B3CFC14C40
18144	18595	63.050350999999999	63.070303000000003	57.752505999999997	57.741872000000001	Советская	0103000020E610000001000000050000001329CDE671864F40B8E864A9F5DE4C401329CDE671864F409A05DA1D52E04C40C5E74EB0FF884F409A05DA1D52E04C40C5E74EB0FF884F40B8E864A9F5DE4C401329CDE671864F40B8E864A9F5DE4C40
18329	22736	62.684511999999998	62.704014999999998	57.206029999999998	57.196049000000002	Центральная	0103000020E610000001000000050000001ADCD6169E574F40EEB4352218994C401ADCD6169E574F4058FFE7305F9A4C405C72DC291D5A4F4058FFE7305F9A4C405C72DC291D5A4F40EEB4352218994C401ADCD6169E574F40EEB4352218994C40
20189	50180	62.669843	62.689058000000003	57.925733000000001	57.920555999999998	Садовая	0103000020E610000001000000050000002E3A596ABD554F407B116DC7D4F54C402E3A596ABD554F40FBE93F6B7EF64C400A86730D33584F40FBE93F6B7EF64C400A86730D33584F407B116DC7D4F54C402E3A596ABD554F407B116DC7D4F54C40
20374	50234	62.693522000000002	62.734513	57.577606000000003	57.557187999999996	Жукова	0103000020E610000001000000050000003C873254C5584F40A0DCB6EF51C74C403C873254C5584F4098FC4FFEEEC94C4051BEA085045E4F4098FC4FFEEEC94C4051BEA085045E4F40A0DCB6EF51C74C403C873254C5584F40A0DCB6EF51C74C40
19819	50086	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	переулок Школьный	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
18799	17077	62.686300000000003	62.704256999999998	59.244863000000002	59.233972999999999	Молодежная	0103000020E61000000100000005000000569FABADD8574F40D192C7D3F29D4D40569FABADD8574F400F80B8AB579F4D40527DE717255A4F400F80B8AB579F4D40527DE717255A4F40D192C7D3F29D4D40569FABADD8574F40D192C7D3F29D4D40
20297	17576	62.560895000000002	62.579517000000003	59.608787	59.602131	Центральная	0103000020E61000000100000005000000B6BE4868CB474F403274ECA012CD4D40B6BE4868CB474F406F9D7FBBECCD4D40EF3CF19C2D4A4F406F9D7FBBECCD4D40EF3CF19C2D4A4F403274ECA012CD4D40B6BE4868CB474F403274ECA012CD4D40
77251	61112	62.324441	62.366849999999999	59.452590000000001	59.405338	Комсосмольская	0103000020E61000000100000005000000A33D5E4887294F40BCE9961DE2B34D40A33D5E4887294F40923F1878EEB94D40D044D8F0F42E4F40923F1878EEB94D40D044D8F0F42E4F40BCE9961DE2B34D40A33D5E4887294F40BCE9961DE2B34D40
78536	61112	62.324441	62.366849999999999	59.452590000000001	59.405338	Колхозная	0103000020E61000000100000005000000A33D5E4887294F40BCE9961DE2B34D40A33D5E4887294F40923F1878EEB94D40D044D8F0F42E4F40923F1878EEB94D40D044D8F0F42E4F40BCE9961DE2B34D40A33D5E4887294F40BCE9961DE2B34D40
18806	17169	62.976483000000002	63.007744000000002	59.220509999999997	59.204498999999998	Трудовая	0103000020E61000000100000005000000CC0C1B65FD7C4F404888F2052D9A4D40CC0C1B65FD7C4F407138F3AB399C4D40C05E61C1FD804F407138F3AB399C4D40C05E61C1FD804F404888F2052D9A4D40CC0C1B65FD7C4F404888F2052D9A4D40
78554	61326	61.347693	61.361536999999998	58.796104999999997	58.785189000000003	Центральная	0103000020E610000001000000050000002906483481AC4E40E816BA1281644D402906483481AC4E404E97C5C4E6654D40A0A52BD846AE4E404E97C5C4E6654D40A0A52BD846AE4E40E816BA1281644D402906483481AC4E40E816BA1281644D40
19856	46967	61.810532000000002	61.833888999999999	58.710307999999998	58.690756	Школьная	0103000020E61000000100000005000000452E3883BFE74E4005C24EB16A584D40452E3883BFE74E40280B5F5FEB5A4D4040BFEFDFBCEA4E40280B5F5FEB5A4D4040BFEFDFBCEA4E4005C24EB16A584D40452E3883BFE74E4005C24EB16A584D40
20031	50133	61.077390000000001	61.109504999999999	58.709485000000001	58.694842999999999	Сенянского	0103000020E61000000100000005000000CB845FEAE7894E40616D8C9DF0584D40CB845FEAE7894E4054008C67D05A4D40CEDF8442048E4E4054008C67D05A4D40CEDF8442048E4E40616D8C9DF0584D40CB845FEAE7894E40616D8C9DF0584D40
18065	14737	60.671298	60.758695000000003	58.896239999999999	58.853965000000002	Чапаева	0103000020E6100000010000000500000063EFC517ED554E40DE76A1B94E6D4D4063EFC517ED554E40FBAE08FEB7724D40C251F2EA1C614E40FBAE08FEB7724D40C251F2EA1C614E40DE76A1B94E6D4D4063EFC517ED554E40DE76A1B94E6D4D40
18409	14737	60.671298	60.758695000000003	58.896239999999999	58.853965000000002	Советская	0103000020E6100000010000000500000063EFC517ED554E40DE76A1B94E6D4D4063EFC517ED554E40FBAE08FEB7724D40C251F2EA1C614E40FBAE08FEB7724D40C251F2EA1C614E40DE76A1B94E6D4D4063EFC517ED554E40DE76A1B94E6D4D40
18036	14737	60.671298	60.758695000000003	58.896239999999999	58.853965000000002	Садовая	0103000020E6100000010000000500000063EFC517ED554E40DE76A1B94E6D4D4063EFC517ED554E40FBAE08FEB7724D40C251F2EA1C614E40FBAE08FEB7724D40C251F2EA1C614E40DE76A1B94E6D4D4063EFC517ED554E40DE76A1B94E6D4D40
18597	14737	60.671298	60.758695000000003	58.896239999999999	58.853965000000002	Крайняя	0103000020E6100000010000000500000063EFC517ED554E40DE76A1B94E6D4D4063EFC517ED554E40FBAE08FEB7724D40C251F2EA1C614E40FBAE08FEB7724D40C251F2EA1C614E40DE76A1B94E6D4D4063EFC517ED554E40DE76A1B94E6D4D40
19046	15968	61.589573999999999	61.604045999999997	58.762459	58.756489000000002	Центральная	0103000020E6100000010000000500000034492C2977CB4E405264ADA1D4604D4034492C2977CB4E403BC5AA4198614D40CAA31B6151CD4E403BC5AA4198614D40CAA31B6151CD4E405264ADA1D4604D4034492C2977CB4E405264ADA1D4604D40
18506	15818	61.154240999999999	61.170456000000001	58.805546	58.795144999999998	Ленина	0103000020E61000000100000005000000E659492BBE934E40F949B54FC7654D40E659492BBE934E4039B69E211C674D4018B49080D1954E4039B69E211C674D4018B49080D1954E40F949B54FC7654D40E659492BBE934E40F949B54FC7654D40
19061	16484	60.522303000000001	60.547690000000003	58.751924000000002	58.741912999999997	Клубная	0103000020E6100000010000000500000025CD1FD3DA424E4016BD5301F75E4D4025CD1FD3DA424E40EC89AE0B3F604D40522CB7B41A464E40EC89AE0B3F604D40522CB7B41A464E4016BD5301F75E4D4025CD1FD3DA424E4016BD5301F75E4D40
78420	16064	61.753003999999997	61.778686999999998	58.752082999999999	58.739283999999998	Центральная	0103000020E61000000100000005000000EBE0606F62E04E40603AADDBA05E4D40EBE0606F62E04E405470784144604D400169FF03ACE34E405470784144604D400169FF03ACE34E40603AADDBA05E4D40EBE0606F62E04E40603AADDBA05E4D40
18445	16255	61.784733000000003	61.814746	58.73715	58.702955000000003	Первое мая	0103000020E61000000100000005000000C68B852172E44E40A4C7EF6DFA594D40C68B852172E44E408A1F63EE5A5E4D40FE45D09849E84E408A1F63EE5A5E4D40FE45D09849E84E40A4C7EF6DFA594D40C68B852172E44E40A4C7EF6DFA594D40
20235	16564	60.384089000000003	60.408828	58.714728999999998	58.700276000000002	Клубная	0103000020E610000001000000050000006EE00ED429314E403C16DBA4A2594D406EE00ED429314E405B40683D7C5B4D4034D8D47954344E405B40683D7C5B4D4034D8D47954344E403C16DBA4A2594D406EE00ED429314E403C16DBA4A2594D40
19822	16166	61.910559999999997	61.926191000000003	58.747866999999999	58.733792000000001	Молодежная	0103000020E61000000100000005000000DB85E63A8DF44E40810871E5EC5D4D40DB85E63A8DF44E40FA60191BBA5F4D40BE6C3B6D8DF64E40FA60191BBA5F4D40BE6C3B6D8DF64E40810871E5EC5D4D40DB85E63A8DF44E40810871E5EC5D4D40
18421	14923	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	Совхозная	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
19031	14923	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	Мелиораторов	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
19034	14923	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	Куйбышева	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
19850	14923	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	Ершова	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
19359	14923	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	70 лет Октября	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
18434	14923	60.760931999999997	60.833570000000002	58.886569000000001	58.845283000000002	20 лет Победы	0103000020E610000001000000050000006C3D433866614E40B16EBC3B326C4D406C3D433866614E40DF52CE177B714D409F76F86BB26A4E40DF52CE177B714D409F76F86BB26A4E40B16EBC3B326C4D406C3D433866614E40B16EBC3B326C4D40
20236	50200	60.585177000000002	60.591312000000002	57.065486	57.060152000000002	Мира	0103000020E610000001000000050000008AAF7614E74A4E40FE648C0FB3874C408AAF7614E74A4E40452C62D861884C40BEDD921CB04B4E40452C62D861884C40BEDD921CB04B4E40FE648C0FB3874C408AAF7614E74A4E40FE648C0FB3874C40
19990	50125	60.558073999999998	60.600340000000003	57.164495000000002	57.153097000000002	Школьников	0103000020E61000000100000005000000BB5F05F86E474E40D00EB8AE98934C40BB5F05F86E474E4082AD122C0E954C40863DEDF0D74C4E4082AD122C0E954C40863DEDF0D74C4E40D00EB8AE98934C40BB5F05F86E474E40D00EB8AE98934C40
17970	14633	60.429112000000003	60.459718000000002	58.013463000000002	58.004317999999998	8 Марта	0103000020E610000001000000050000001C295B24ED364E405E64027E8D004D401C295B24ED364E40605AD427B9014D40F7B0170AD83A4E40605AD427B9014D40F7B0170AD83A4E405E64027E8D004D401C295B24ED364E405E64027E8D004D40
20145	16561	60.378788999999998	60.399754999999999	58.043447999999998	58.030397999999998	Свободы	0103000020E61000000100000005000000D28A6F287C304E4091EEE714E4034D40D28A6F287C304E40CE893DB48F054D40CCB4FD2B2B334E40CE893DB48F054D40CCB4FD2B2B334E4091EEE714E4034D40D28A6F287C304E4091EEE714E4034D40
18898	16561	60.378788999999998	60.399754999999999	58.043447999999998	58.030397999999998	Кузнецова	0103000020E61000000100000005000000D28A6F287C304E4091EEE714E4034D40D28A6F287C304E40CE893DB48F054D40CCB4FD2B2B334E40CE893DB48F054D40CCB4FD2B2B334E4091EEE714E4034D40D28A6F287C304E4091EEE714E4034D40
17912	16561	60.378788999999998	60.399754999999999	58.043447999999998	58.030397999999998	Карбышева	0103000020E61000000100000005000000D28A6F287C304E4091EEE714E4034D40D28A6F287C304E40CE893DB48F054D40CCB4FD2B2B334E40CE893DB48F054D40CCB4FD2B2B334E4091EEE714E4034D40D28A6F287C304E4091EEE714E4034D40
18353	14452	60.761533999999997	60.769779999999997	58.239525999999998	58.236541000000003	Центральная	0103000020E61000000100000005000000626534F279614E40E294B9F9461E4D40626534F279614E405645B8C9A81E4D40B48EAA2688624E405645B8C9A81E4D40B48EAA2688624E40E294B9F9461E4D40626534F279614E40E294B9F9461E4D40
17960	14529	60.452638999999998	60.471961999999998	57.951393000000003	57.932433000000003	Центральная	0103000020E6100000010000000500000073F22213F0394E40085BECF659F74C4073F22213F0394E405952EE3EC7F94C40357A3540693C4E405952EE3EC7F94C40357A3540693C4E40085BECF659F74C4073F22213F0394E40085BECF659F74C40
18255	14818	60.717247	60.729759999999999	58.01426	57.999091	Центральная	0103000020E61000000100000005000000BA13ECBFCE5B4E402D5DC136E2FF4C40BA13ECBFCE5B4E400BD28C45D3014D40E8F692C6685D4E400BD28C45D3014D40E8F692C6685D4E402D5DC136E2FF4C40BA13ECBFCE5B4E402D5DC136E2FF4C40
19918	5217	60.566473999999999	60.568143999999997	58.327407000000001	58.325980000000001	Привокзальная	0103000020E610000001000000050000006404543882484E4036936FB6B9294D406404543882484E40A1BDFA78E8294D4095B54DF1B8484E40A1BDFA78E8294D4095B54DF1B8484E4036936FB6B9294D406404543882484E4036936FB6B9294D40
17792	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Энгельса	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
19208	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Фрунзе	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
17755	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Труда	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
18143	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Спортивная	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
18684	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Сабурова	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
20192	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Рабочей молодежи	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
20356	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Народная стройка	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
9825	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Ленина	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
18349	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	Воронова	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
18622	12163	60.511738999999999	60.597915	58.074283999999999	58.018836	 Парковая	0103000020E610000001000000050000003B8BDEA980414E4065FED13769024D403B8BDEA980414E40DB4E5B2382094D40D8648D7A884C4E40DB4E5B2382094D40D8648D7A884C4E4065FED13769024D403B8BDEA980414E4065FED13769024D40
20035	14248	60.726624999999999	60.754365	58.319764999999997	58.295070000000003	Ленина	0103000020E610000001000000050000005EBA490C025D4E40EF0390DAC4254D405EBA490C025D4E40E5B33C0FEE284D409F1F46088F604E40E5B33C0FEE284D409F1F46088F604E40EF0390DAC4254D405EBA490C025D4E40EF0390DAC4254D40
18923	12003	62.220416	62.244121999999997	56.752516	56.744807000000002	Комсомольская	0103000020E61000000100000005000000F0C16B97361C4F407B6AF5D5555F4C40F0C16B97361C4F40BEDBBC7152604C40F71DC3633F1F4F40BEDBBC7152604C40F71DC3633F1F4F407B6AF5D5555F4C40F0C16B97361C4F407B6AF5D5555F4C40
18895	11608	61.901172000000003	61.93927	56.784565000000001	56.770490000000002	Ленина	0103000020E610000001000000050000001409A69A59F34E4091F2936A9F624C401409A69A59F34E400A4B3CA06C644C40950ED6FF39F84E400A4B3CA06C644C40950ED6FF39F84E4091F2936A9F624C401409A69A59F34E4091F2936A9F624C40
20301	11660	61.862985000000002	61.902025999999999	56.793858999999998	56.780540999999999	Ленина	0103000020E6100000010000000500000023F8DF4A76EE4E40F4177AC4E8634C4023F8DF4A76EE4E405051F52B9D654C402312859675F34E405051F52B9D654C402312859675F34E40F4177AC4E8634C4023F8DF4A76EE4E40F4177AC4E8634C40
18222	11561	62.072642999999999	62.082264000000002	56.799438000000002	56.792724999999997	30 Лет Победы	0103000020E6100000010000000500000044A4A65D4C094F405DDC460378654C4044A4A65D4C094F40FF9600FC53664C40AFD172A0870A4F40FF9600FC53664C40AFD172A0870A4F405DDC460378654C4044A4A65D4C094F405DDC460378654C40
18006	22607	61.822372000000001	61.851135999999997	56.674115	56.655307999999998	Ленина	0103000020E61000000100000005000000B492567C43E94E405167EE21E1534C40B492567C43E94E401C5F7B6649564C4060394206F2EC4E401C5F7B6649564C4060394206F2EC4E405167EE21E1534C40B492567C43E94E405167EE21E1534C40
20367	47628	62.43779	62.523220000000002	56.688453000000003	56.647627999999997	Ленина	0103000020E610000001000000050000000742B28009384F40A8FC6B79E5524C400742B28009384F40A3EA573A1F584C407B4E7ADFF8424F40A3EA573A1F584C407B4E7ADFF8424F40A8FC6B79E5524C400742B28009384F40A8FC6B79E5524C40
18894	11668	61.694730999999997	61.732595000000003	56.789150999999997	56.773887999999999	Ленина	0103000020E61000000100000005000000394206F2ECD84E40286211C30E634C40394206F2ECD84E40874D64E602654C40481B47ACC5DD4E40874D64E602654C40481B47ACC5DD4E40286211C30E634C40394206F2ECD84E40286211C30E634C40
20184	11996	62.380521999999999	62.417020999999998	56.605483999999997	56.576290999999998	Ильича	0103000020E610000001000000050000004AB4E4F1B4304F4054FD4AE7C3494C404AB4E4F1B4304F402920ED7F804D4C40635FB2F160354F402920ED7F804D4C40635FB2F160354F4054FD4AE7C3494C404AB4E4F1B4304F4054FD4AE7C3494C40
78582	46685	62.107354000000001	62.152225000000001	56.710619000000001	56.686911000000002	Степана Щипачева	0103000020E61000000100000005000000228C9FC6BD0D4F409F211CB3EC574C40228C9FC6BD0D4F4047753A90F55A4C401A51DA1B7C134F4047753A90F55A4C401A51DA1B7C134F409F211CB3EC574C40228C9FC6BD0D4F409F211CB3EC574C40
20176	50173	62.083691999999999	62.098227000000001	56.654693999999999	56.644573999999999	Вокзальная	0103000020E61000000100000005000000EA77616BB60A4F400BED9C6681524C40EA77616BB60A4F4097715303CD534C40C74ACCB3920C4F4097715303CD534C40C74ACCB3920C4F400BED9C6681524C40EA77616BB60A4F400BED9C6681524C40
78485	61305	60.858471000000002	61.741982	56.946765999999997	56.455024999999999	Свердлова	0103000020E610000001000000050000003FC8B260E26D4E4063EE5A423E3A4C403FC8B260E26D4E407C7BD7A02F794C403F1C2444F9DE4E407C7BD7A02F794C403F1C2444F9DE4E4063EE5A423E3A4C403FC8B260E26D4E4063EE5A423E3A4C40
19910	46982	61.233454999999999	61.274678000000002	56.584173999999997	56.559260999999999	Центральная	0103000020E61000000100000005000000390B7BDAE19D4E40D1764CDD95474C40390B7BDAE19D4E403596B036C64A4C40217711A628A34E403596B036C64A4C40217711A628A34E40D1764CDD95474C40390B7BDAE19D4E40D1764CDD95474C40
18815	8500	61.250118000000001	61.262650000000001	56.675103999999997	56.654842000000002	Ленина	0103000020E610000001000000050000000A12DBDD03A04E400C06D7DCD1534C400A12DBDD03A04E400BB3D0CE69564C40AF25E4839EA14E400BB3D0CE69564C40AF25E4839EA14E400C06D7DCD1534C400A12DBDD03A04E400C06D7DCD1534C40
78522	10603	61.452688999999999	61.475506000000003	56.599291000000001	56.584263	Калинина	0103000020E61000000100000005000000252191B6F1B94E40A5A14621C94A4C40252191B6F1B94E40C1E44691B54C4C40A1866F61DDBC4E40C1E44691B54C4C40A1866F61DDBC4E40A5A14621C94A4C40252191B6F1B94E40A5A14621C94A4C40
77065	47012	61.259425	61.280365000000003	56.701008000000002	56.689065999999997	Мира	0103000020E61000000100000005000000E561A1D634A14E408C648F5033584C40E561A1D634A14E40001E51A1BA594C40B6F81400E3A34E40001E51A1BA594C40B6F81400E3A34E408C648F5033584C40E561A1D634A14E408C648F5033584C40
20329	46991	61.418354999999998	61.452311000000002	56.562930999999999	56.548867000000001	Первомайская	0103000020E610000001000000050000001D8F19A88CB54E40446D1B4641464C401D8F19A88CB54E40C9737D1F0E484C407F4FAC53E5B94E40C9737D1F0E484C407F4FAC53E5B94E40446D1B4641464C401D8F19A88CB54E40446D1B4641464C40
18858	9798	61.389609	61.414295000000003	56.860495999999998	56.851343	Центральная	0103000020E61000000100000005000000179D2CB5DEB14E40DA56B3CEF86C4C40179D2CB5DEB14E405E2BA1BB246E4C40BBF2599E07B54E405E2BA1BB246E4C40BBF2599E07B54E40DA56B3CEF86C4C40179D2CB5DEB14E40DA56B3CEF86C4C40
19894	46750	61.027228000000001	61.051338999999999	56.723135999999997	56.706028000000003	Уральская	0103000020E610000001000000050000008BC404357C834E40B80721205F5A4C408BC404357C834E40B6476FB88F5C4C403201BF4692864E40B6476FB88F5C4C403201BF4692864E40B80721205F5A4C408BC404357C834E40B80721205F5A4C40
20098	22066	60.977085000000002	60.996865	56.711452999999999	56.675826000000001	Ленина	0103000020E61000000100000005000000C2340C1F117D4E40ACE4637781564C40C2340C1F117D4E400FD253E4105B4C4076C3B645997F4E400FD253E4105B4C4076C3B645997F4E40ACE4637781564C40C2340C1F117D4E40ACE4637781564C40
18544	46914	61.450946000000002	61.459865999999998	56.658959000000003	56.651339	Чапаева	0103000020E610000001000000050000008A213999B8B94E40FFCD8B135F534C408A213999B8B94E40D333BDC458544C406B459BE3DCBA4E40D333BDC458544C406B459BE3DCBA4E40FFCD8B135F534C408A213999B8B94E40FFCD8B135F534C40
18458	47322	61.631346000000001	61.668868000000003	56.682442000000002	56.667842999999998	Ленина	0103000020E61000000100000005000000EF3A1BF2CFD04E4067EE21E17B554C40EF3A1BF2CFD04E405BB56B425A574C40A4AB74779DD54E405BB56B425A574C40A4AB74779DD54E4067EE21E17B554C40EF3A1BF2CFD04E4067EE21E17B554C40
19132	9994	61.109847000000002	61.148249999999997	56.740541999999998	56.732236999999998	Ленина	0103000020E6100000010000000500000028486C770F8E4E40E8F527F1B95D4C4028486C770F8E4E403FA88B14CA5E4C40E5D022DBF9924E403FA88B14CA5E4C40E5D022DBF9924E40E8F527F1B95D4C4028486C770F8E4E40E8F527F1B95D4C40
20328	50221	61.505347999999998	61.512157000000002	56.869588999999998	56.865191000000003	Набережная	0103000020E61000000100000005000000AC8C463EAFC04E4093E52494BE6E4C40AC8C463EAFC04E400DFB3DB14E6F4C4070B54E5C8EC14E400DFB3DB14E6F4C4070B54E5C8EC14E4093E52494BE6E4C40AC8C463EAFC04E4093E52494BE6E4C40
18830	46867	61.280464000000002	61.310566000000001	56.631669000000002	56.611161000000003	8 Марта	0103000020E6100000010000000500000049DA8D3EE6A34E409BCB0D863A4E4C4049DA8D3EE6A34E40D272A087DA504C40F19F6EA0C0A74E40D272A087DA504C40F19F6EA0C0A74E409BCB0D863A4E4C4049DA8D3EE6A34E409BCB0D863A4E4C40
18950	49968	61.278064999999998	61.296067000000001	56.772266000000002	56.753661000000001	Юбилейная	0103000020E61000000100000005000000C49448A297A34E40A5A2B1F677604C40C49448A297A34E4008E8BE9CD9624C4061360186E5A54E4008E8BE9CD9624C4061360186E5A54E40A5A2B1F677604C40C49448A297A34E40A5A2B1F677604C40
19863	10684	61.479880999999999	61.515014000000001	56.643965000000001	56.622557999999998	Юбилейная	0103000020E61000000100000005000000637C98BD6CBD4E407CEE04FBAF4F4C40637C98BD6CBD4E406362F3716D524C40B77D8FFAEBC14E406362F3716D524C40B77D8FFAEBC14E407CEE04FBAF4F4C40637C98BD6CBD4E407CEE04FBAF4F4C40
19162	10684	61.479880999999999	61.515014000000001	56.643965000000001	56.622557999999998	Ударников	0103000020E61000000100000005000000637C98BD6CBD4E407CEE04FBAF4F4C40637C98BD6CBD4E406362F3716D524C40B77D8FFAEBC14E406362F3716D524C40B77D8FFAEBC14E407CEE04FBAF4F4C40637C98BD6CBD4E407CEE04FBAF4F4C40
18823	47971	60.943621999999998	60.981765000000003	56.747768000000001	56.730687000000003	Уральская	0103000020E610000001000000050000009FE40E9BC8784E40624ED026875D4C409FE40E9BC8784E40677FA0DCB65F4C40C1ADBB79AA7D4E40677FA0DCB65F4C40C1ADBB79AA7D4E40624ED026875D4C409FE40E9BC8784E40624ED026875D4C40
19140	10332	61.167887	61.204583	56.620809999999999	56.609859	Красноармейская	0103000020E6100000010000000500000037363B527D954E40EC1516DC0F4E4C4037363B527D954E40CF83BBB3764F4C40A62897C62F9A4E40CF83BBB3764F4C40A62897C62F9A4E40EC1516DC0F4E4C4037363B527D954E40EC1516DC0F4E4C40
77077	46937	61.319406000000001	61.35877	56.550454999999999	56.520544000000001	Школьная	0103000020E61000000100000005000000B612BA4BE2A84E408410902FA1424C40B612BA4BE2A84E40B875374F75464C409964E42CECAD4E40B875374F75464C409964E42CECAD4E408410902FA1424C40B612BA4BE2A84E408410902FA1424C40
19329	18065	61.593032000000001	61.610073	56.714036999999998	56.700445000000002	Кирова	0103000020E61000000100000005000000A1BDFA78E8CB4E40C8D2872EA8594C40A1BDFA78E8CB4E4025917D90655B4C4018963FDF16CE4E4025917D90655B4C4018963FDF16CE4E40C8D2872EA8594C40A1BDFA78E8CB4E40C8D2872EA8594C40
19907	10494	61.342123999999998	61.365633000000003	56.577233	56.553600000000003	Советская	0103000020E610000001000000050000009E961FB8CAAB4E406688635DDC464C409E961FB8CAAB4E4003965CC5E2494C4050ABE80FCDAE4E4003965CC5E2494C4050ABE80FCDAE4E406688635DDC464C409E961FB8CAAB4E406688635DDC464C40
18242	16360	61.303199999999997	61.379942999999997	56.821123999999998	56.765526999999999	Трактовая	0103000020E61000000100000005000000D712F241CFA64E403D9AEAC9FC614C40D712F241CFA64E40F8FA5A971A694C400CACE3F8A1B04E40F8FA5A971A694C400CACE3F8A1B04E403D9AEAC9FC614C40D712F241CFA64E403D9AEAC9FC614C40
18936	16360	61.303199999999997	61.379942999999997	56.821123999999998	56.765526999999999	Ленинградская	0103000020E61000000100000005000000D712F241CFA64E403D9AEAC9FC614C40D712F241CFA64E40F8FA5A971A694C400CACE3F8A1B04E40F8FA5A971A694C400CACE3F8A1B04E403D9AEAC9FC614C40D712F241CFA64E403D9AEAC9FC614C40
18499	16360	61.303199999999997	61.379942999999997	56.821123999999998	56.765526999999999	Ленина	0103000020E61000000100000005000000D712F241CFA64E403D9AEAC9FC614C40D712F241CFA64E40F8FA5A971A694C400CACE3F8A1B04E40F8FA5A971A694C400CACE3F8A1B04E403D9AEAC9FC614C40D712F241CFA64E403D9AEAC9FC614C40
18272	16360	61.303199999999997	61.379942999999997	56.821123999999998	56.765526999999999	Алещенкова	0103000020E61000000100000005000000D712F241CFA64E403D9AEAC9FC614C40D712F241CFA64E40F8FA5A971A694C400CACE3F8A1B04E40F8FA5A971A694C400CACE3F8A1B04E403D9AEAC9FC614C40D712F241CFA64E403D9AEAC9FC614C40
17765	16360	61.303199999999997	61.379942999999997	56.821123999999998	56.765526999999999	50 лет ВЛКСМ	0103000020E61000000100000005000000D712F241CFA64E403D9AEAC9FC614C40D712F241CFA64E40F8FA5A971A694C400CACE3F8A1B04E40F8FA5A971A694C400CACE3F8A1B04E403D9AEAC9FC614C40D712F241CFA64E403D9AEAC9FC614C40
20056	46780	61.142122999999998	61.172091000000002	56.716664999999999	56.710520000000002	 Ленина	0103000020E610000001000000050000003481221631924E40B493C151F25A4C403481221631924E400B98C0ADBB5B4C40CD77F01307964E400B98C0ADBB5B4C40CD77F01307964E40B493C151F25A4C403481221631924E40B493C151F25A4C40
18298	49911	61.249858000000003	61.290534000000001	56.778075999999999	56.754648000000003	Клубная	0103000020E610000001000000050000006E52D158FB9F4E40F4FE3F4E98604C406E52D158FB9F4E40B8E68EFE97634C402330D63730A54E40B8E68EFE97634C402330D63730A54E40F4FE3F4E98604C406E52D158FB9F4E40F4FE3F4E98604C40
18575	15011	61.028306000000001	61.065756999999998	56.768058000000003	56.736612000000001	Строителй	0103000020E61000000100000005000000EA23F0879F834E40ABEB504D495E4C40EA23F0879F834E4031B77BB94F624C40D53DB2B96A884E4031B77BB94F624C40D53DB2B96A884E40ABEB504D495E4C40EA23F0879F834E40ABEB504D495E4C40
20017	15011	61.028306000000001	61.065756999999998	56.768058000000003	56.736612000000001	Клубная	0103000020E61000000100000005000000EA23F0879F834E40ABEB504D495E4C40EA23F0879F834E4031B77BB94F624C40D53DB2B96A884E4031B77BB94F624C40D53DB2B96A884E40ABEB504D495E4C40EA23F0879F834E40ABEB504D495E4C40
17810	17457	61.495232999999999	61.565759999999997	56.726934	56.706457999999998	Советская	0103000020E61000000100000005000000327381CB63BF4E40B0FF3A376D5A4C40327381CB63BF4E40DC2C5E2C0C5D4C4046B1DCD26AC84E40DC2C5E2C0C5D4C4046B1DCD26AC84E40B0FF3A376D5A4C40327381CB63BF4E40B0FF3A376D5A4C40
18660	49947	61.289679999999997	61.312973999999997	56.786912000000001	56.774282999999997	8 марта	0103000020E610000001000000050000001327F73B14A54E40A46C91B41B634C401327F73B14A54E403C6A4C88B9644C40C83F33880FA84E403C6A4C88B9644C40C83F33880FA84E40A46C91B41B634C401327F73B14A54E40A46C91B41B634C40
18161	10193	61.229591999999997	61.271659999999997	56.646726999999998	56.625069000000003	Школьная	0103000020E610000001000000050000002CB64945639D4E40295FD04202504C402CB64945639D4E40583849F3C7524C40D0D03FC1C5A24E40583849F3C7524C40D0D03FC1C5A24E40295FD04202504C402CB64945639D4E40295FD04202504C40
19143	10393	61.354018000000003	61.367339999999999	56.689897000000002	56.683272000000002	Восточная	0103000020E6100000010000000500000001193A7650AD4E40E222F77475574C4001193A7650AD4E40E44D7E8B4E584C409E4143FF04AF4E40E44D7E8B4E584C409E4143FF04AF4E40E222F77475574C4001193A7650AD4E40E222F77475574C40
18549	9305	63.650579	63.67698	57.366253999999998	57.356195999999997	Советская	0103000020E61000000100000005000000713B342C46D34F40A67B9DD497AD4C40713B342C46D34F40BC033C69E1AE4C40E605D847A7D64F40BC033C69E1AE4C40E605D847A7D64F40A67B9DD497AD4C40713B342C46D34F40A67B9DD497AD4C40
19857	50096	63.462983000000001	63.474850000000004	57.568103000000001	57.557428999999999	Лаптева	0103000020E610000001000000050000004FCDE50643BB4F40C66B5ED559C74C404FCDE50643BB4F4037E15E99B7C84C40B84082E2C7BC4F4037E15E99B7C84C40B84082E2C7BC4F40C66B5ED559C74C404FCDE50643BB4F40C66B5ED559C74C40
78419	9219	63.588819000000001	63.610433	57.473244999999999	57.465293000000003	Мамарина	0103000020E61000000100000005000000B821C66B5ECB4F40640795B88EBB4C40B821C66B5ECB4F406DFFCA4A93BC4C4018B325AB22CE4F406DFFCA4A93BC4C4018B325AB22CE4F40640795B88EBB4C40B821C66B5ECB4F40640795B88EBB4C40
19956	9101	63.980924999999999	63.996285999999998	57.427118999999998	57.417271	Новая	0103000020E61000000100000005000000166A4DF38EFD4F40DC48D92269B54C40166A4DF38EFD4F400740DCD5ABB64C4038BBB54C86FF4F400740DCD5ABB64C4038BBB54C86FF4F40DC48D92269B54C40166A4DF38EFD4F40DC48D92269B54C40
78491	9066	64.020020000000002	64.042963	57.564058000000003	57.556584000000001	Советская	0103000020E610000001000000050000000551F701480150400ABDFE243EC74C400551F701480150400A86730D33C84C4009FCE1E7BF0250400A86730D33C84C4009FCE1E7BF0250400ABDFE243EC74C400551F701480150400ABDFE243EC74C40
20060	6126	63.588092000000003	63.616073999999998	57.649746	57.644333000000003	Кайгородова	0103000020E610000001000000050000000685419946CB4F40E65DF58079D24C400685419946CB4F40795A7EE02AD34C403CF54883DBCE4F40795A7EE02AD34C403CF54883DBCE4F40E65DF58079D24C400685419946CB4F40E65DF58079D24C40
19871	9014	63.403030000000001	63.422747999999999	57.376994000000003	57.368423999999997	Набережная	0103000020E6100000010000000500000048A7AE7C96B34F40DF87838428AF4C4048A7AE7C96B34F40E564E25641B04C408639419B1CB64F40E564E25641B04C408639419B1CB64F40DF87838428AF4C4048A7AE7C96B34F40DF87838428AF4C40
18732	8774	63.852511	63.867998	57.619802	57.612672000000003	Центральная	0103000020E61000000100000005000000793D98141FED4F4064963D096CCE4C40793D98141FED4F4069FF03AC55CF4C40287FF78E1AEF4F4069FF03AC55CF4C40287FF78E1AEF4F4064963D096CCE4C40793D98141FED4F4064963D096CCE4C40
19869	46314	63.461052000000002	63.502257999999998	57.424593999999999	57.395530999999998	Техническая	0103000020E61000000100000005000000B1E07EC003BB4F40EFC682C2A0B24C40B1E07EC003BB4F40F609A01859B64C40C2137AFD49C04F40F609A01859B64C40C2137AFD49C04F40EFC682C2A0B24C40B1E07EC003BB4F40EFC682C2A0B24C40
19868	47289	63.730412000000001	63.745054000000003	57.361516999999999	57.345809000000003	Аникина	0103000020E61000000100000005000000904DF2237EDD4F40CCD4247843AC4C40904DF2237EDD4F4059F9653046AE4C4083E0F1ED5DDF4F4059F9653046AE4C4083E0F1ED5DDF4F40CCD4247843AC4C40904DF2237EDD4F40CCD4247843AC4C40
78552	61324	62.936193000000003	64.174897999999999	57.801999000000002	57.236296000000003	Советская	0103000020E6100000010000000500000040DF162CD5774F407B1684F23E9E4C4040DF162CD5774F405D363AE7A7E64C40B1886187310B50405D363AE7A7E64C40B1886187310B50407B1684F23E9E4C4040DF162CD5774F407B1684F23E9E4C40
20063	48894	63.783332000000001	63.797964999999998	57.622207000000003	57.613602999999998	Набережная	0103000020E6100000010000000500000084F4143944E44F401EDD088B8ACE4C4084F4143944E44F40D02B9E7AA4CF4C40232D95B723E64F40D02B9E7AA4CF4C40232D95B723E64F401EDD088B8ACE4C4084F4143944E44F401EDD088B8ACE4C40
18208	48516	63.682639000000002	63.716191999999999	57.639308	57.626781000000001	Советская	0103000020E61000000100000005000000B1FCF9B660D74F4089601C5C3AD04C40B1FCF9B660D74F401C0934D8D4D14C4013D4F02DACDB4F401C0934D8D4D14C4013D4F02DACDB4F4089601C5C3AD04C40B1FCF9B660D74F4089601C5C3AD04C40
20249	48516	63.682639000000002	63.716191999999999	57.639308	57.626781000000001	Кузнецова	0103000020E61000000100000005000000B1FCF9B660D74F4089601C5C3AD04C40B1FCF9B660D74F401C0934D8D4D14C4013D4F02DACDB4F401C0934D8D4D14C4013D4F02DACDB4F4089601C5C3AD04C40B1FCF9B660D74F4089601C5C3AD04C40
20104	46408	64.065051999999994	64.089252999999999	57.529978999999997	57.522382	Дзержинского	0103000020E610000001000000050000008522DDCF290450407102D369DDC24C408522DDCF290450408C48145AD6C34C4079043752B60550408C48145AD6C34C4079043752B60550407102D369DDC24C408522DDCF290450407102D369DDC24C40
20400	46586	63.914558	63.947274	57.598022999999998	57.580531000000001	Советская	0103000020E61000000100000005000000C8258E3C10F54F4037A8FDD64ECA4C40C8258E3C10F54F40BEA085048CCC4C40F12C414640F94F40BEA085048CCC4C40F12C414640F94F4037A8FDD64ECA4C40C8258E3C10F54F4037A8FDD64ECA4C40
20127	47803	63.850166000000002	63.872273999999997	57.507764000000002	57.495683999999997	Советская	0103000020E61000000100000005000000E8154F3DD2EC4F404293C49272BF4C40E8154F3DD2EC4F40070B2769FEC04C405793A7ACA6EF4F40070B2769FEC04C405793A7ACA6EF4F404293C49272BF4C40E8154F3DD2EC4F404293C49272BF4C40
18128	46131	63.735523000000001	63.786233000000003	57.409185000000001	57.388114000000002	Октябрьская	0103000020E61000000100000005000000583A1F9E25DE4F40548F34B8ADB14C40583A1F9E25DE4F40C381902C60B44C409B046F48A3E44F40C381902C60B44C409B046F48A3E44F40548F34B8ADB14C40583A1F9E25DE4F40548F34B8ADB14C40
19106	46131	63.735523000000001	63.786233000000003	57.409185000000001	57.388114000000002	Кузнецова	0103000020E61000000100000005000000583A1F9E25DE4F40548F34B8ADB14C40583A1F9E25DE4F40C381902C60B44C409B046F48A3E44F40C381902C60B44C409B046F48A3E44F40548F34B8ADB14C40583A1F9E25DE4F40548F34B8ADB14C40
19861	8775	63.886763999999999	63.899107000000001	57.542782000000003	57.537810999999998	Советская	0103000020E6100000010000000500000094A2957B81F14F40EB36A8FDD6C44C4094A2957B81F14F40C26D6DE179C54C40664D2CF015F34F40C26D6DE179C54C40664D2CF015F34F40EB36A8FDD6C44C4094A2957B81F14F40EB36A8FDD6C44C40
18021	7279	58.081446	58.107954999999997	56.789698000000001	56.777498999999999	Дружбы	0103000020E61000000100000005000000EC3191D26C0A4D401BD6541685634C40EC3191D26C0A4D40BADBF5D214654C4047382D78D10D4D40BADBF5D214654C4047382D78D10D4D401BD6541685634C40EC3191D26C0A4D401BD6541685634C40
18808	8316	58.024124999999998	58.078463999999997	56.718449	56.693410999999998	Советская	0103000020E610000001000000050000000C022B8716034D40E4D70FB1C1584C400C022B8716034D40056C0723F65B4C40E8F4BC1B0B0A4D40056C0723F65B4C40E8F4BC1B0B0A4D40E4D70FB1C1584C400C022B8716034D40E4D70FB1C1584C40
20082	8316	58.024124999999998	58.078463999999997	56.718449	56.693410999999998	Железнодорожная	0103000020E610000001000000050000000C022B8716034D40E4D70FB1C1584C400C022B8716034D40056C0723F65B4C40E8F4BC1B0B0A4D40056C0723F65B4C40E8F4BC1B0B0A4D40E4D70FB1C1584C400C022B8716034D40E4D70FB1C1584C40
17890	7080	58.341517000000003	58.362816000000002	56.805146000000001	56.790180999999997	Трактовая	0103000020E6100000010000000500000097033DD4B62B4D40D575A8A624654C4097033DD4B62B4D40AB402D060F674C40973B33C1702E4D40AB402D060F674C40973B33C1702E4D40D575A8A624654C4097033DD4B62B4D40D575A8A624654C40
17896	7754	58.161109000000003	58.168258999999999	56.745990999999997	56.738200999999997	Мира	0103000020E61000000100000005000000AF0B3F389F144D40EF6FD05E7D5E4C40AF0B3F389F144D401F0E12A27C5F4C40FB20CB8289154D401F0E12A27C5F4C40FB20CB8289154D40EF6FD05E7D5E4C40AF0B3F389F144D40EF6FD05E7D5E4C40
17884	6926	57.571058999999998	58.565125999999999	57.095027999999999	56.549030999999999	Уральская	0103000020E61000000100000005000000118B187618C94C40BEBED6A546464C40118B187618C94C40261AA4E0298C4C40450F7C0C56484D40261AA4E0298C4C40450F7C0C56484D40BEBED6A546464C40118B187618C94C40BEBED6A546464C40
18416	5859	58.055377	58.082614	56.895408000000003	56.873750999999999	Трактовая	0103000020E61000000100000005000000ADF9F19716074D4074ECA012D76F4C40ADF9F19716074D40D449B6BA9C724C408B187618930A4D40D449B6BA9C724C408B187618930A4D4074ECA012D76F4C40ADF9F19716074D4074ECA012D76F4C40
19027	5715	57.571058999999998	58.565125999999999	57.095027999999999	56.549030999999999	Красных Партизан	0103000020E61000000100000005000000118B187618C94C40BEBED6A546464C40118B187618C94C40261AA4E0298C4C40450F7C0C56484D40261AA4E0298C4C40450F7C0C56484D40BEBED6A546464C40118B187618C94C40BEBED6A546464C40
18061	7019	58.188813000000003	58.195540999999999	56.787557999999997	56.778061000000001	Центральная	0103000020E61000000100000005000000A3073E062B184D4083A5BA8097634C40A3073E062B184D4001DA56B3CE644C407903CC7C07194D4001DA56B3CE644C407903CC7C07194D4083A5BA8097634C40A3073E062B184D4083A5BA8097634C40
19996	7639	58.187088000000003	58.212187	56.728834999999997	56.709812999999997	50 лет Октября	0103000020E61000000100000005000000AEBCE47FF2174D4048A30227DB5A4C40AEBCE47FF2174D400F971C774A5D4C4074D190F1281B4D400F971C774A5D4C4074D190F1281B4D4048A30227DB5A4C40AEBCE47FF2174D4048A30227DB5A4C40
18422	6074	58.052134000000002	58.074421000000001	56.834786000000001	56.824764000000002	Ленина	0103000020E610000001000000050000003D81B053AC064D408675E3DD91694C403D81B053AC064D404F948444DA6A4C405C9198A086094D404F948444DA6A4C405C9198A086094D408675E3DD91694C403D81B053AC064D408675E3DD91694C40
17887	6340	57.935012	57.949654000000002	57.014287000000003	57.007828000000003	Светлая	0103000020E610000001000000050000000CAF2479AEF74C401EFF058200814C400CAF2479AEF74C4005E10A28D4814C40FF4124438EF94C4005E10A28D4814C40FF4124438EF94C401EFF058200814C400CAF2479AEF74C401EFF058200814C40
20267	6495	57.942836	57.960811	56.983941000000002	56.975960999999998	Труда	0103000020E61000000100000005000000E8BE9CD9AEF84C40F295404AEC7C4C40E8BE9CD9AEF84C40C61858C7F17D4C408B51D7DAFBFA4C40C61858C7F17D4C408B51D7DAFBFA4C40F295404AEC7C4C40E8BE9CD9AEF84C40F295404AEC7C4C40
19011	5322	57.988182999999999	57.999384999999997	56.859448	56.853282	Центральная	0103000020E6100000010000000500000049BBD1C77CFE4C40FB213658386D4C4049BBD1C77CFE4C406A4E5E64026E4C40758E01D9EBFF4C406A4E5E64026E4C40758E01D9EBFF4C40FB213658386D4C4049BBD1C77CFE4C40FB213658386D4C40
19390	6618	58.215986999999998	58.242469	56.944257	56.925246999999999	Молодёжная	0103000020E610000001000000050000003AAE4676A51B4D406EDC627E6E764C403AAE4676A51B4D407102D369DD784C409CA56439091F4D407102D369DD784C409CA56439091F4D406EDC627E6E764C403AAE4676A51B4D406EDC627E6E764C40
18304	8042	58.382632999999998	58.398263999999998	56.624777000000002	56.618293999999999	Пролетарская	0103000020E6100000010000000500000068AF3E1EFA304D4011A8FE41244F4C4068AF3E1EFA304D40812557B1F84F4C404A969350FA324D40812557B1F84F4C404A969350FA324D4011A8FE41244F4C4068AF3E1EFA304D4011A8FE41244F4C40
18723	7559	58.266300999999999	58.282471000000001	56.589759999999998	56.569060999999998	Центральная	0103000020E6100000010000000500000030F2B22616224D40EB36A8FDD6484C4030F2B22616224D40963E74417D4B4C40C2887D0228244D40963E74417D4B4C40C2887D0228244D40EB36A8FDD6484C4030F2B22616224D40EB36A8FDD6484C40
18938	8262	58.473030999999999	58.507032000000002	56.635392000000003	56.620562	Советская	0103000020E61000000100000005000000417FA1478C3C4D40F7915B936E4F4C40417FA1478C3C4D40ED116A8654514C404303B16CE6404D40ED116A8654514C404303B16CE6404D40F7915B936E4F4C40417FA1478C3C4D40F7915B936E4F4C40
18915	7504	58.246017000000002	58.274349999999998	56.629699000000002	56.608541000000002	Ленина	0103000020E6100000010000000500000049A12C7C7D1F4D4038A3E6ABE44D4C4049A12C7C7D1F4D4076A911FA99504C402CD49AE61D234D4076A911FA99504C402CD49AE61D234D4038A3E6ABE44D4C4049A12C7C7D1F4D4038A3E6ABE44D4C40
17891	7219	57.952204999999999	57.969776000000003	56.752985000000002	56.738843000000003	Советская	0103000020E61000000100000005000000390B7BDAE1F94C4074F04C68925E4C40390B7BDAE1F94C4075B0FECF61604C400D39B69E21FC4C4075B0FECF61604C400D39B69E21FC4C4074F04C68925E4C40390B7BDAE1F94C4074F04C68925E4C40
20065	8111	58.355387	58.364334999999997	56.597026	56.587103999999997	Новая	0103000020E6100000010000000500000037363B527D2D4D40E6AC4F39264B4C4037363B527D2D4D404C6E14596B4C4C40E2E47E87A22E4D404C6E14596B4C4C40E2E47E87A22E4D40E6AC4F39264B4C4037363B527D2D4D40E6AC4F39264B4C40
78574	61330	57.995458999999997	58.017836000000003	56.923296999999998	56.913249	Школьная	0103000020E6100000010000000500000022C154336BFF4C40670DDE57E5744C4022C154336BFF4C4059BF99982E764C408258367348024D4059BF99982E764C408258367348024D40670DDE57E5744C4022C154336BFF4C40670DDE57E5744C40
18501	7816	58.274189	58.308253000000001	56.701872999999999	56.691014000000003	Свердлова	0103000020E6100000010000000500000023F609A018234D40018A912573584C4023F609A018234D40037976F9D6594C406BF294D574274D40037976F9D6594C406BF294D574274D40018A912573584C4023F609A018234D40018A912573584C40
78555	61325	57.817072000000003	57.851343	56.901518000000003	56.886808000000002	Центральная	0103000020E61000000100000005000000193DB7D095E84C4064EAAEEC82714C40193DB7D095E84C40AF601BF164734C40DA56B3CEF8EC4C40AF601BF164734C40DA56B3CEF8EC4C4064EAAEEC82714C40193DB7D095E84C4064EAAEEC82714C40
18747	5487	57.605195000000002	57.631425999999998	56.899856999999997	56.888976999999997	Трактовая	0103000020E61000000100000005000000F3599E0777CD4C40B6F292FFC9714C40F3599E0777CD4C40D009A1832E734C400BEC3191D2D04C40D009A1832E734C400BEC3191D2D04C40B6F292FFC9714C40F3599E0777CD4C40B6F292FFC9714C40
19381	6277	57.983179	58.004739000000001	57.018839999999997	57.005381999999997	Молодежная	0103000020E61000000100000005000000978E39CFD8FD4C4058FE7C5BB0804C40978E39CFD8FD4C40A6ED5F5969824C4004029D499B004D40A6ED5F5969824C4004029D499B004D4058FE7C5BB0804C40978E39CFD8FD4C4058FE7C5BB0804C40
18746	5432	57.697766999999999	57.718598999999998	56.891165000000001	56.875014999999998	Советская	0103000020E61000000100000005000000309DD66D50D94C403541D47D00704C40309DD66D50D94C40802BD9B111724C401AF8510DFBDB4C40802BD9B111724C401AF8510DFBDB4C403541D47D00704C40309DD66D50D94C403541D47D00704C40
20041	5111	57.874904999999998	57.920639000000001	56.818804	56.761975	Ленина 	0103000020E61000000100000005000000AE0D15E3FCEF4C404FAF946588614C40AE0D15E3FCEF4C40C0EAC891CE684C400936AE7FD7F54C40C0EAC891CE684C400936AE7FD7F54C404FAF946588614C40AE0D15E3FCEF4C404FAF946588614C40
17938	5111	57.874904999999998	57.920639000000001	56.818804	56.761975	Ленина	0103000020E61000000100000005000000AE0D15E3FCEF4C404FAF946588614C40AE0D15E3FCEF4C40C0EAC891CE684C400936AE7FD7F54C40C0EAC891CE684C400936AE7FD7F54C404FAF946588614C40AE0D15E3FCEF4C404FAF946588614C40
18191	6701	58.256393000000003	58.307003999999999	56.826566999999997	56.813201999999997	Советская	0103000020E6100000010000000500000030F65E7CD1204D405985CD0017684C4030F65E7CD1204D40F6798CF2CC694C40DFDE35E84B274D40F6798CF2CC694C40DFDE35E84B274D405985CD0017684C4030F65E7CD1204D405985CD0017684C40
20083	6798	58.317137000000002	58.353904999999997	56.861161000000003	56.844520000000003	Беляева	0103000020E6100000010000000500000000ADF9F197284D40B2683A3B196C4C4000ADF9F197284D409BCB0D863A6E4C40087250C24C2D4D409BCB0D863A6E4C40087250C24C2D4D40B2683A3B196C4C4000ADF9F197284D40B2683A3B196C4C40
20057	6130	58.066282000000001	58.073155	56.854660000000003	56.845303000000001	Гагарина	0103000020E610000001000000050000002028B7ED7B084D40F81A82E3326C4C402028B7ED7B084D408599B67F656D4C40FA449E245D094D408599B67F656D4C40FA449E245D094D40F81A82E3326C4C402028B7ED7B084D40F81A82E3326C4C40
20174	50172	58.014251999999999	58.043931999999998	56.730820000000001	56.715643	пер. Школьный	0103000020E6100000010000000500000088F37002D3014D40404E98309A5B4C4088F37002D3014D40A1A17F828B5D4C40BA9F53909F054D40A1A17F828B5D4C40BA9F53909F054D40404E98309A5B4C4088F37002D3014D40404E98309A5B4C40
20224	50195	58.400689	58.427261999999999	56.627786999999998	56.618022000000003	Ленина	0103000020E61000000100000005000000F86EF3C649334D40B11A4B581B4F4C40F86EF3C649334D404EED0C535B504C406A696E85B0364D404EED0C535B504C406A696E85B0364D40B11A4B581B4F4C40F86EF3C649334D40B11A4B581B4F4C40
20137	50160	61.659041000000002	61.689591999999998	57.098562999999999	57.080077000000003	Юбилейная	0103000020E6100000010000000500000090DC9A745BD44E40B61490F63F8A4C4090DC9A745BD44E403ECC5EB69D8C4C40A7CAF78C44D84E403ECC5EB69D8C4C40A7CAF78C44D84E40B61490F63F8A4C4090DC9A745BD44E40B61490F63F8A4C40
18705	4704	58.849829	58.893630999999999	56.168089999999999	56.146362000000003	Молодежная	0103000020E61000000100000005000000A0185932C76C4D4047B071FDBB124C40A0185932C76C4D406F641EF983154C408CD8278062724D406F641EF983154C408CD8278062724D4047B071FDBB124C40A0185932C76C4D4047B071FDBB124C40
19091	3984	58.447158999999999	58.456716999999998	56.398674999999997	56.394345999999999	Трактовая	0103000020E61000000100000005000000588E90813C394D407AA702EE79324C40588E90813C394D40CC5D4BC807334C407C43E1B3753A4D40CC5D4BC807334C407C43E1B3753A4D407AA702EE79324C40588E90813C394D407AA702EE79324C40
78572	61329	58.628646000000003	58.643692999999999	56.420881999999999	56.411844000000002	8-го Марта	0103000020E610000001000000050000007061DD7877504D40E486DF4DB7344C407061DD7877504D40CFBC1C76DF354C4002D53F8864524D40CFBC1C76DF354C4002D53F8864524D40E486DF4DB7344C407061DD7877504D40E486DF4DB7344C40
20001	4764	58.166265000000003	58.177925000000002	56.547507000000003	56.538246999999998	Школьная	0103000020E6100000010000000500000017BCE82B48154D40C6151747E5444C4017BCE82B48154D4061AA99B514464C400612143FC6164D4061AA99B514464C400612143FC6164D40C6151747E5444C4017BCE82B48154D40C6151747E5444C40
18662	3598	58.127242000000003	58.139226000000001	56.414209999999997	56.404055	Пролетарская	0103000020E61000000100000005000000BD56427749104D4084640113B8334C40BD56427749104D408CD651D504354C405F605628D2114D408CD651D504354C405F605628D2114D4084640113B8334C40BD56427749104D4084640113B8334C40
19327	4701	58.664138000000001	58.769035000000002	56.167268	56.137273999999998	Ленина	0103000020E61000000100000005000000F303577902554D40A94BC63192114C40F303577902554D406BD5AE0969154C405C3D27BD6F624D406BD5AE0969154C405C3D27BD6F624D40A94BC63192114C40F303577902554D40A94BC63192114C40
18585	4585	58.570793999999999	58.604418000000003	56.340096000000003	56.294989999999999	Ленина	0103000020E6100000010000000500000063601DC70F494D40D252793BC2254C4063601DC70F494D400EC00644882B4C408F8EAB915D4D4D400EC00644882B4C408F8EAB915D4D4D40D252793BC2254C4063601DC70F494D40D252793BC2254C40
18680	4206	58.075338000000002	58.107443000000004	56.262706999999999	56.252017000000002	Победы	0103000020E61000000100000005000000B212F3ACA4094D409D84D21742204C40B212F3ACA4094D4013B70A62A0214C40929735B1C00D4D4013B70A62A0214C40929735B1C00D4D409D84D21742204C40B212F3ACA4094D409D84D21742204C40
19318	4363	58.314442	58.339182000000001	56.443398999999999	56.422266	Советская	0103000020E61000000100000005000000923EADA23F284D403B1BF2CF0C364C40923EADA23F284D40200A664CC1384C4029B2D6506A2B4D40200A664CC1384C4029B2D6506A2B4D403B1BF2CF0C364C40923EADA23F284D403B1BF2CF0C364C40
18343	4590	58.641240000000003	58.672178000000002	56.260182999999998	56.254192000000003	Свердлова	0103000020E610000001000000050000008B71FE2614524D40D2730B5D89204C408B71FE2614524D40D2FC31AD4D214C409C8BBFED09564D40D2FC31AD4D214C409C8BBFED09564D40D2730B5D89204C408B71FE2614524D40D2730B5D89204C40
17800	49840	58.127152000000002	58.163319000000001	56.489342000000001	56.466290000000001	Школьная	0103000020E610000001000000050000007DCF488446104D40D6390664AF3B4C407DCF488446104D40954737C2A23E4C4060E811A3E7144D40954737C2A23E4C4060E811A3E7144D40D6390664AF3B4C407DCF488446104D40D6390664AF3B4C40
17835	4302	58.332031000000001	58.358485999999999	56.210832000000003	56.186154000000002	Ленина	0103000020E610000001000000050000000C21E7FD7F2A4D408202EFE4D3174C400C21E7FD7F2A4D40A379008BFC1A4C40740987DEE22D4D40A379008BFC1A4C40740987DEE22D4D408202EFE4D3174C400C21E7FD7F2A4D408202EFE4D3174C40
19981	4105	58.173335000000002	58.225715000000001	56.332540999999999	56.313592999999997	Ленина	0103000020E6100000010000000500000047205ED72F164D4094A0BFD023284C4047205ED72F164D4021CA17B4902A4C40BB9BA73AE41C4D4021CA17B4902A4C40BB9BA73AE41C4D4094A0BFD023284C4047205ED72F164D4094A0BFD023284C40
78505	61309	58.543017999999996	58.583227000000001	56.459845000000001	56.438786	Советская	0103000020E61000000100000005000000D591239D81454D40A9F8BF232A384C40D591239D81454D40541D7233DC3A4C407592AD2EA74A4D40541D7233DC3A4C407592AD2EA74A4D40A9F8BF232A384C40D591239D81454D40A9F8BF232A384C40
18666	3792	58.782913999999998	58.819574000000003	56.255482000000001	56.219427000000003	Юбилейная	0103000020E610000001000000050000004FCAA48636644D40016E162F161C4C404FCAA48636644D40BC5B59A2B3204C40725303CDE7684D40BC5B59A2B3204C40725303CDE7684D40016E162F161C4C404FCAA48636644D40016E162F161C4C40
20390	3736	58.556106999999997	58.572214000000002	56.376351	56.357813999999998	Трактовая	0103000020E61000000100000005000000D009A1832E474D40850662D9CC2D4C40D009A1832E474D40906802452C304C401C28F04E3E494D40906802452C304C401C28F04E3E494D40850662D9CC2D4C40D009A1832E474D40850662D9CC2D4C40
20255	3149	58.331968000000003	58.349969999999999	56.266967000000001	56.253726999999998	Заречная	0103000020E61000000100000005000000C6A86BED7D2A4D405C8E57207A204C40C6A86BED7D2A4D403D0E83F92B224C40624A24D1CB2C4D403D0E83F92B224C40624A24D1CB2C4D405C8E57207A204C40C6A86BED7D2A4D405C8E57207A204C40
18306	3646	58.443629000000001	58.462465999999999	56.227499999999999	56.214866999999998	Кирова	0103000020E610000001000000050000005247C7D5C8384D40ACFE08C3801B4C405247C7D5C8384D4085EB51B81E1D4C4087C1FC15323B4D4085EB51B81E1D4C4087C1FC15323B4D40ACFE08C3801B4C405247C7D5C8384D40ACFE08C3801B4C40
78518	4519	58.249960999999999	58.264631000000001	56.477139000000001	56.462451000000001	Школьная	0103000020E610000001000000050000004223D8B8FE1F4D4052802898313B4C404223D8B8FE1F4D40B55208E4123D4C40FF40B96DDF214D40B55208E4123D4C40FF40B96DDF214D4052802898313B4C404223D8B8FE1F4D4052802898313B4C40
19963	3375	58.146745000000003	58.166696000000002	56.169773999999997	56.155864000000001	Советская	0103000020E61000000100000005000000FFEC478AC8124D40D74FFF59F3134C40FFEC478AC8124D4005DB8827BB154C40E02F664B56154D4005DB8827BB154C40E02F664B56154D40D74FFF59F3134C40FFEC478AC8124D40D74FFF59F3134C40
18944	3073	58.252772999999998	58.261253000000004	56.336253999999997	56.330914	Культуры	0103000020E61000000100000005000000E9279CDD5A204D40EFE4D3635B2A4C40E9279CDD5A204D401893FE5E0A2B4C40AF7D01BD70214D401893FE5E0A2B4C40AF7D01BD70214D40EFE4D3635B2A4C40E9279CDD5A204D40EFE4D3635B2A4C40
18711	3220	58.470999999999997	58.490637999999997	56.502594000000002	56.491771999999997	Заречная	0103000020E610000001000000050000003F355EBA493C4D40548B8862F23E4C403F355EBA493C4D403A950C0055404C406116DA39CD3E4D403A950C0055404C406116DA39CD3E4D40548B8862F23E4C403F355EBA493C4D40548B8862F23E4C40
19308	4150	58.144965999999997	58.168663000000002	56.360157999999998	56.351174999999998	Советская	0103000020E610000001000000050000001684F23E8E124D401E166A4DF32C4C401684F23E8E124D4046B247A8192E4C40CB85CABF96154D4046B247A8192E4C40CB85CABF96154D401E166A4DF32C4C401684F23E8E124D401E166A4DF32C4C40
17801	3528	58.041381000000001	58.062393	56.481955999999997	56.478104000000002	Трактовая	0103000020E6100000010000000500000080D6FCF84B054D401C0B0A83323D4C4080D6FCF84B054D40340EF5BBB03D4C40EA3F6B7EFC074D40340EF5BBB03D4C40EA3F6B7EFC074D401C0B0A83323D4C4080D6FCF84B054D401C0B0A83323D4C40
78531	61312	58.226891999999999	58.250743	56.516944000000002	56.509365000000003	Советская	0103000020E61000000100000005000000ADDC0BCC0A1D4D40105D50DF32414C40ADDC0BCC0A1D4D4085EE92382B424C40B859BC5818204D4085EE92382B424C40B859BC5818204D40105D50DF32414C40ADDC0BCC0A1D4D40105D50DF32414C40
78512	4431	58.270136999999998	58.291463	56.428652999999997	56.414209999999997	Трактовая	0103000020E61000000100000005000000433866D993224D408CD651D504354C40433866D993224D40882AFC19DE364C403D7FDAA84E254D40882AFC19DE364C403D7FDAA84E254D408CD651D504354C40433866D993224D408CD651D504354C40
17764	3035	58.337484000000003	58.351506999999998	56.315905000000001	56.294984999999997	Советская	0103000020E610000001000000050000002E76FBAC322B4D40C0E78711C2254C402E76FBAC322B4D404AD235936F284C4054A86E2EFE2C4D404AD235936F284C4054A86E2EFE2C4D40C0E78711C2254C402E76FBAC322B4D40C0E78711C2254C40
19958	2907	58.201506000000002	58.225132000000002	56.529108999999998	56.522545000000001	Советская	0103000020E6100000010000000500000051F9D7F2CA194D401BD82AC1E2424C4051F9D7F2CA194D407782FDD7B9434C403CA41820D11C4D407782FDD7B9434C403CA41820D11C4D401BD82AC1E2424C4051F9D7F2CA194D401BD82AC1E2424C40
18671	3894	58.872520000000002	58.962665999999999	56.222841000000003	56.197052999999997	Трактовая	0103000020E610000001000000050000008F8D40BCAE6F4D40124A5F0839194C408F8D40BCAE6F4D409E9ACB0D861C4C404E7CB5A3387B4D409E9ACB0D861C4C404E7CB5A3387B4D40124A5F0839194C408F8D40BCAE6F4D40124A5F0839194C40
20379	2973	58.338742000000003	58.355665999999999	56.288606000000001	56.277433000000002	Юбилейная	0103000020E610000001000000050000000DE4D9E55B2B4D4064EAAEEC82234C400DE4D9E55B2B4D40F6B6990AF1244C404A26A776862D4D40F6B6990AF1244C404A26A776862D4D4064EAAEEC82234C400DE4D9E55B2B4D4064EAAEEC82234C40
19952	2973	58.338742000000003	58.355665999999999	56.288606000000001	56.277433000000002	Ленина	0103000020E610000001000000050000000DE4D9E55B2B4D4064EAAEEC82234C400DE4D9E55B2B4D40F6B6990AF1244C404A26A776862D4D40F6B6990AF1244C404A26A776862D4D4064EAAEEC82234C400DE4D9E55B2B4D4064EAAEEC82234C40
19966	3435	58.208854000000002	58.240574000000002	56.133792999999997	56.128104	Советская	0103000020E61000000100000005000000C4D155BABB1A4D404F3E3DB665104C40C4D155BABB1A4D4084B7072120114C404B22FB20CB1E4D4084B7072120114C404B22FB20CB1E4D404F3E3DB665104C40C4D155BABB1A4D404F3E3DB665104C40
18327	4044	58.520829999999997	58.530800999999997	56.464092000000001	56.452240000000003	Новая	0103000020E610000001000000050000004963B48EAA424D40B6F81400E3394C404963B48EAA424D40E92ADD5D673B4C4090D78349F1434D40E92ADD5D673B4C4090D78349F1434D40B6F81400E3394C404963B48EAA424D40B6F81400E3394C40
19296	3833	58.712153000000001	58.730362	56.324306	56.314940999999997	Школьная	0103000020E61000000100000005000000C85F5AD4275B4D40B39597FC4F284C40C85F5AD4275B4D40C3F2E7DB82294C40DE1E84807C5D4D40C3F2E7DB82294C40DE1E84807C5D4D40B39597FC4F284C40C85F5AD4275B4D40B39597FC4F284C40
18270	2518	58.495677000000001	58.563679999999998	56.439473	56.393065	Фрунзе	0103000020E6100000010000000500000090300C58723F4D40E31934F44F324C4090300C58723F4D40CD3CB9A640384C4063B48EAA26484D40CD3CB9A640384C4063B48EAA26484D40E31934F44F324C4090300C58723F4D40E31934F44F324C40
19254	2518	58.495677000000001	58.563679999999998	56.439473	56.393065	Лесная	0103000020E6100000010000000500000090300C58723F4D40E31934F44F324C4090300C58723F4D40CD3CB9A640384C4063B48EAA26484D40CD3CB9A640384C4063B48EAA26484D40E31934F44F324C4090300C58723F4D40E31934F44F324C40
18932	2518	58.495677000000001	58.563679999999998	56.439473	56.393065	Ленина	0103000020E6100000010000000500000090300C58723F4D40E31934F44F324C4090300C58723F4D40CD3CB9A640384C4063B48EAA26484D40CD3CB9A640384C4063B48EAA26484D40E31934F44F324C4090300C58723F4D40E31934F44F324C40
18268	2518	58.495677000000001	58.563679999999998	56.439473	56.393065	Королева	0103000020E6100000010000000500000090300C58723F4D40E31934F44F324C4090300C58723F4D40CD3CB9A640384C4063B48EAA26484D40CD3CB9A640384C4063B48EAA26484D40E31934F44F324C4090300C58723F4D40E31934F44F324C40
77070	2518	58.495677000000001	58.563679999999998	56.439473	56.393065	Дерябина	0103000020E6100000010000000500000090300C58723F4D40E31934F44F324C4090300C58723F4D40CD3CB9A640384C4063B48EAA26484D40CD3CB9A640384C4063B48EAA26484D40E31934F44F324C4090300C58723F4D40E31934F44F324C40
20221	4358	58.330719999999999	58.341805000000001	56.231943000000001	56.217309999999998	Эрыкана	0103000020E610000001000000050000000A117008552A4D40008C67D0D01B4C400A117008552A4D40A0C4E74EB01D4C40FD4D2844C02B4D40A0C4E74EB01D4C40FD4D2844C02B4D40008C67D0D01B4C400A117008552A4D40008C67D0D01B4C40
19393	2786	58.277638000000003	58.327378000000003	56.546078000000001	56.529952000000002	Советска	0103000020E610000001000000050000003D1059A489234D4093399677D5434C403D1059A489234D40558847E2E5454C4007B7B585E7294D40558847E2E5454C4007B7B585E7294D4093399677D5434C403D1059A489234D4093399677D5434C40
20204	50187	58.127152000000002	58.163319000000001	56.489342000000001	56.466290000000001	Школьная	0103000020E610000001000000050000007DCF488446104D40D6390664AF3B4C407DCF488446104D40954737C2A23E4C4060E811A3E7144D40954737C2A23E4C4060E811A3E7144D40D6390664AF3B4C407DCF488446104D40D6390664AF3B4C40
20383	50235	58.374583999999999	58.397249000000002	56.187345999999998	56.176439000000002	Юбилейная	0103000020E610000001000000050000006CCD565EF22F4D40965E9B8D95164C406CCD565EF22F4D40A98427F4FA174C4032AF230ED9324D40A98427F4FA174C4032AF230ED9324D40965E9B8D95164C406CCD565EF22F4D40965E9B8D95164C40
18197	1255	61.966892999999999	61.997318999999997	57.459207999999997	57.436078000000002	8 Марта	0103000020E610000001000000050000009CDD5A26C3FB4E40A7406667D1B74C409CDD5A26C3FB4E40E107E753C7BA4C40F7562426A8FF4E40E107E753C7BA4C40F7562426A8FF4E40A7406667D1B74C409CDD5A26C3FB4E40A7406667D1B74C40
77306	61125	62.241489999999999	62.275393000000001	57.375815000000003	57.366365999999999	Дача Черёмушки	0103000020E61000000100000005000000D027F224E91E4F40E42EC214E5AE4C40D027F224E91E4F40522CB7B41AB04C400F46EC1340234F40522CB7B41AB04C400F46EC1340234F40E42EC214E5AE4C40D027F224E91E4F40E42EC214E5AE4C40
18210	49898	61.635783000000004	61.738847	57.371034999999999	57.329089000000003	Красных Партизан	0103000020E61000000100000005000000282D5C5661D14E40973C9E961FAA4C40282D5C5661D14E40EF552B137EAF4C40B5DFDA8992DE4E40EF552B137EAF4C40B5DFDA8992DE4E40973C9E961FAA4C40282D5C5661D14E40973C9E961FAA4C40
18878	892	62.139539999999997	62.161450000000002	57.376086999999998	57.351224000000002	Школьная	0103000020E61000000100000005000000EE3D5C72DC114F4000C974E8F4AC4C40EE3D5C72DC114F40B2B96A9E23B04C4038F8C264AA144F40B2B96A9E23B04C4038F8C264AA144F4000C974E8F4AC4C40EE3D5C72DC114F4000C974E8F4AC4C40
18620	1935	61.798395999999997	61.817315000000001	57.505468	57.490566999999999	Школьная	0103000020E61000000100000005000000ECA012D731E64E4098BF42E6CABE4C40ECA012D731E64E405796E82CB3C04C40DFC325C79DE84E405796E82CB3C04C40DFC325C79DE84E4098BF42E6CABE4C40ECA012D731E64E4098BF42E6CABE4C40
19925	50109	61.920135999999999	61.956940000000003	57.398057000000001	57.383443	Ленина	0103000020E61000000100000005000000A6EF3504C7F54E40A87004A914B14C40A6EF3504C7F54E40D1782288F3B24C40FC1D8A027DFA4E40D1782288F3B24C40FC1D8A027DFA4E40A87004A914B14C40A6EF3504C7F54E40A87004A914B14C40
18892	1812	61.677115000000001	61.696607999999998	57.477876000000002	57.465282999999999	Школьная	0103000020E61000000100000005000000C6504EB4ABD64E404031B2648EBB4C40C6504EB4ABD64E408BC56F0A2BBD4C40E41071732AD94E408BC56F0A2BBD4C40E41071732AD94E404031B2648EBB4C40C6504EB4ABD64E404031B2648EBB4C40
19165	1003	62.222608000000001	62.255935000000001	57.547882000000001	57.538009000000002	Гагарина	0103000020E61000000100000005000000FBE93F6B7E1C4F4012FA997ADDC44C40FBE93F6B7E1C4F40960854FF20C64C406D73637AC2204F40960854FF20C64C406D73637AC2204F4012FA997ADDC44C40FBE93F6B7E1C4F4012FA997ADDC44C40
19141	449	62.279677999999997	62.353662999999997	57.393523000000002	57.360419999999998	Усиевича	0103000020E6100000010000000500000091B41B7DCC234F408369183E22AE4C4091B41B7DCC234F40A69C2FF65EB24C40126745D4442D4F40A69C2FF65EB24C40126745D4442D4F408369183E22AE4C4091B41B7DCC234F408369183E22AE4C40
19902	449	62.279677999999997	62.353662999999997	57.393523000000002	57.360419999999998	Некрасова	0103000020E6100000010000000500000091B41B7DCC234F408369183E22AE4C4091B41B7DCC234F40A69C2FF65EB24C40126745D4442D4F40A69C2FF65EB24C40126745D4442D4F408369183E22AE4C4091B41B7DCC234F408369183E22AE4C40
19906	449	62.279677999999997	62.353662999999997	57.393523000000002	57.360419999999998	Комсомольская	0103000020E6100000010000000500000091B41B7DCC234F408369183E22AE4C4091B41B7DCC234F40A69C2FF65EB24C40126745D4442D4F40A69C2FF65EB24C40126745D4442D4F408369183E22AE4C4091B41B7DCC234F408369183E22AE4C40
20322	14	61.974285999999999	62.008170999999997	57.295197999999999	57.257868999999999	Театральная	0103000020E61000000100000005000000AF795567B5FC4E407CD3F4D901A14C40AF795567B5FC4E401CEC4D0CC9A54C4047E350BF0B014F401CEC4D0CC9A54C4047E350BF0B014F407CD3F4D901A14C40AF795567B5FC4E407CD3F4D901A14C40
19128	14	61.974285999999999	62.008170999999997	57.295197999999999	57.257868999999999	Кутузова	0103000020E61000000100000005000000AF795567B5FC4E407CD3F4D901A14C40AF795567B5FC4E401CEC4D0CC9A54C4047E350BF0B014F401CEC4D0CC9A54C4047E350BF0B014F407CD3F4D901A14C40AF795567B5FC4E407CD3F4D901A14C40
18577	14	61.974285999999999	62.008170999999997	57.295197999999999	57.257868999999999	Комсомольская	0103000020E61000000100000005000000AF795567B5FC4E407CD3F4D901A14C40AF795567B5FC4E401CEC4D0CC9A54C4047E350BF0B014F401CEC4D0CC9A54C4047E350BF0B014F407CD3F4D901A14C40AF795567B5FC4E407CD3F4D901A14C40
18565	14	61.974285999999999	62.008170999999997	57.295197999999999	57.257868999999999	Грибоедова	0103000020E61000000100000005000000AF795567B5FC4E407CD3F4D901A14C40AF795567B5FC4E401CEC4D0CC9A54C4047E350BF0B014F401CEC4D0CC9A54C4047E350BF0B014F407CD3F4D901A14C40AF795567B5FC4E407CD3F4D901A14C40
18157	14	61.974285999999999	62.008170999999997	57.295197999999999	57.257868999999999	Белинского	0103000020E61000000100000005000000AF795567B5FC4E407CD3F4D901A14C40AF795567B5FC4E401CEC4D0CC9A54C4047E350BF0B014F401CEC4D0CC9A54C4047E350BF0B014F407CD3F4D901A14C40AF795567B5FC4E407CD3F4D901A14C40
18880	1130	62.143968999999998	62.157507000000003	57.596305999999998	57.580737999999997	Советская	0103000020E61000000100000005000000A45181936D124F40B0C56E9F55CA4C40A45181936D124F404C3448C153CC4C400FF27A3029144F404C3448C153CC4C400FF27A3029144F40B0C56E9F55CA4C40A45181936D124F40B0C56E9F55CA4C40
19880	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Чайковского	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
20251	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Станционная	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
19197	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Прилепского	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
77067	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Площадь Советов	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
18085	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Переулок Заводской	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
18813	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Октябрьская	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
18818	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Мира	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
18168	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Лесная	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
77062	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Кронштадтская	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
20092	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Красный Луч	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
77426	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Котовского	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
19872	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	Комсомольская	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
20086	2059	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	8 Марта	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
19933	50112	61.853158000000001	61.946384999999999	57.385629999999999	57.291710999999999	Школьный переулок	0103000020E610000001000000050000000F29064834ED4E4015713AC956A54C400F29064834ED4E40A12DE7525CB14C406536C82423F94E40A12DE7525CB14C406536C82423F94E4015713AC956A54C400F29064834ED4E4015713AC956A54C40
20349	50228	61.804307000000001	61.833646000000002	57.358894999999997	57.348649999999999	Советская	0103000020E61000000100000005000000D1782288F3E64E400DE02D90A0AC4C40D1782288F3E64E4055D97745F0AD4C407A3881E9B4EA4E4055D97745F0AD4C407A3881E9B4EA4E400DE02D90A0AC4C40D1782288F3E64E400DE02D90A0AC4C40
18068	29732	62.220865000000003	62.238607000000002	57.873959999999997	57.866731999999999	Центральная	0103000020E6100000010000000500000060EAE74D451C4F40C632FD12F1EE4C4060EAE74D451C4F408E01D9EBDDEF4C4060CC96AC8A1E4F408E01D9EBDDEF4C4060CC96AC8A1E4F40C632FD12F1EE4C4060EAE74D451C4F40C632FD12F1EE4C40
19357	20288	61.158921999999997	61.189230999999999	57.947265999999999	57.933489000000002	Клубная	0103000020E61000000100000005000000B54E5C8E57944E407F164B917CF74C40B54E5C8E57944E406E4E250340F94C40D731AEB838984E406E4E250340F94C40D731AEB838984E407F164B917CF74C40B54E5C8E57944E407F164B917CF74C40
78500	47956	62.068044	62.083736999999999	57.778775000000003	57.768307	Матвеева	0103000020E61000000100000005000000325871AAB5084F40D9243FE257E24C40325871AAB5084F40A1F831E6AEE34C408A3BDEE4B70A4F40A1F831E6AEE34C408A3BDEE4B70A4F40D9243FE257E24C40325871AAB5084F40D9243FE257E24C40
18404	19522	61.976694000000002	62.006858999999999	57.749619000000003	57.739364000000002	Мира	0103000020E6100000010000000500000087191A4F04FD4E407DEBC37AA3DE4C4087191A4F04FD4E40E9BAF083F3DF4C40755776C1E0004F40E9BAF083F3DF4C40755776C1E0004F407DEBC37AA3DE4C4087191A4F04FD4E407DEBC37AA3DE4C40
78498	19210	61.740194000000002	61.754593999999997	58.524816000000001	58.515093	Школьная	0103000020E6100000010000000500000004594FADBEDE4E4003B34291EE414D4004594FADBEDE4E407235B22B2D434D4000E1438996E04E407235B22B2D434D4000E1438996E04E4003B34291EE414D4004594FADBEDE4E4003B34291EE414D40
20347	50226	62.183953000000002	62.202835999999998	58.501505999999999	58.495294000000001	Центральная	0103000020E6100000010000000500000024809BC58B174F40D8F335CB653F4D4024809BC58B174F40B75F3E5931404D40C939B187F6194F40B75F3E5931404D40C939B187F6194F40D8F335CB653F4D4024809BC58B174F40D8F335CB653F4D40
19358	30324	61.785190999999998	61.804900000000004	57.881315000000001	57.865955999999997	Ленина	0103000020E61000000100000005000000880E812381E44E4032E36DA5D7EE4C40880E812381E44E40B43C0FEECEF04C40744694F606E74E40B43C0FEECEF04C40744694F606E74E4032E36DA5D7EE4C40880E812381E44E4032E36DA5D7EE4C40
20067	29977	61.928589000000002	61.946618000000001	58.164678000000002	58.155016000000003	Почтовая	0103000020E6100000010000000500000072361D01DCF64E40AA2D7590D7134D4072361D01DCF64E40732F302B14154D4008E753C72AF94E40732F302B14154D4008E753C72AF94E40AA2D7590D7134D4072361D01DCF64E40AA2D7590D7134D40
20315	9008	62.584476000000002	62.608263000000001	58.479677000000002	58.466199000000003	Кедровая	0103000020E6100000010000000500000001A60C1CD04A4F40C636A968AC3B4D4001A60C1CD04A4F405BD2510E663D4D40F52EDE8FDB4D4F405BD2510E663D4D40F52EDE8FDB4D4F40C636A968AC3B4D4001A60C1CD04A4F40C636A968AC3B4D40
20168	29787	61.771528000000004	61.788102000000002	57.610999	57.597332999999999	 Школьная	0103000020E6100000010000000500000062F9F36DC1E24E4029E9616875CC4C4062F9F36DC1E24E40C171193735CE4C40C3F4BD86E0E44E40C171193735CE4C40C3F4BD86E0E44E4029E9616875CC4C4062F9F36DC1E24E4029E9616875CC4C40
20126	50157	61.715203000000002	61.747613999999999	57.564979999999998	57.550320999999997	Ленина	0103000020E6100000010000000500000024809BC58BDB4E40A8A624EB70C64C4024809BC58BDB4E407172BF4351C84C401004C8D0B1DF4E407172BF4351C84C401004C8D0B1DF4E40A8A624EB70C64C4024809BC58BDB4E40A8A624EB70C64C40
78560	61327	62.213669000000003	62.231527999999997	57.963779000000002	57.956063999999998	Победы	0103000020E61000000100000005000000A3957B81591B4F4004711E4E60FA4C40A3957B81591B4F402AC93A1C5DFB4C40DC0DA2B5A21D4F402AC93A1C5DFB4C40DC0DA2B5A21D4F4004711E4E60FA4C40A3957B81591B4F4004711E4E60FA4C40
20287	30412	61.752079000000002	61.791882999999999	57.956111	57.941868999999997	Спиридоновская	0103000020E610000001000000050000001381EA1F44E04E40E00ED4298FF84C401381EA1F44E04E40452C62D861FA4C4012A1116C5CE54E40452C62D861FA4C4012A1116C5CE54E40E00ED4298FF84C401381EA1F44E04E40E00ED4298FF84C40
78408	19406	62.249324000000001	62.275312	57.926206000000001	57.913639000000003	Ленина	0103000020E61000000100000005000000D00D4DD9E91F4F40D2AC6C1FF2F44C40D00D4DD9E91F4F40F3AD0FEB8DF64C402219726C3D234F40F3AD0FEB8DF64C402219726C3D234F40D2AC6C1FF2F44C40D00D4DD9E91F4F40D2AC6C1FF2F44C40
78506	21925	62.388086000000001	62.408667000000001	58.440773	58.429245000000002	Лесников	0103000020E610000001000000050000008A0453CDAC314F405B7C0A80F1364D408A0453CDAC314F40DBFAE93F6B384D402BFA43334F344F40DBFAE93F6B384D402BFA43334F344F405B7C0A80F1364D408A0453CDAC314F405B7C0A80F1364D40
19100	49980	61.555518999999997	61.596338000000003	58.397340999999997	58.371203999999999	70 лет Октября	0103000020E610000001000000050000003FA7203F1BC74E407B12D89C832F4D403FA7203F1BC74E40122EE411DC324D4058AEB7CD54CC4E40122EE411DC324D4058AEB7CD54CC4E407B12D89C832F4D403FA7203F1BC74E407B12D89C832F4D40
18060	21345	62.35342	62.378096999999997	57.93627	57.928398999999999	Школьная	0103000020E610000001000000050000004CE0D6DD3C2D4F40CE5147C7D5F64C404CE0D6DD3C2D4F40EB1C03B2D7F74C409CDB847B65304F40EB1C03B2D7F74C409CDB847B65304F40CE5147C7D5F64C404CE0D6DD3C2D4F40CE5147C7D5F64C40
18481	30722	61.682899999999997	61.736196999999997	58.471400000000003	58.440114000000001	Профсоюзная	0103000020E610000001000000050000001D38674469D74E408141D2A755384D401D38674469D74E40CEAACFD5563C4D40E7340BB43BDE4E40CEAACFD5563C4D40E7340BB43BDE4E408141D2A755384D401D38674469D74E408141D2A755384D40
19086	30722	61.682899999999997	61.736196999999997	58.471400000000003	58.440114000000001	Победы	0103000020E610000001000000050000001D38674469D74E408141D2A755384D401D38674469D74E40CEAACFD5563C4D40E7340BB43BDE4E40CEAACFD5563C4D40E7340BB43BDE4E408141D2A755384D401D38674469D74E408141D2A755384D40
78480	61304	61.747767000000003	61.760621999999998	57.585881000000001	57.575797000000001	Центральная	0103000020E6100000010000000500000097033DD4B6DF4E40451152B7B3C94C4097033DD4B6DF4E40842C0B26FECA4C401E4FCB0F5CE14E40842C0B26FECA4C401E4FCB0F5CE14E40451152B7B3C94C4097033DD4B6DF4E40451152B7B3C94C40
78516	19729	61.747767000000003	61.760621999999998	57.585881000000001	57.575797000000001	Курортная	0103000020E6100000010000000500000097033DD4B6DF4E40451152B7B3C94C4097033DD4B6DF4E40842C0B26FECA4C401E4FCB0F5CE14E40842C0B26FECA4C401E4FCB0F5CE14E40451152B7B3C94C4097033DD4B6DF4E40451152B7B3C94C40
18202	46879	62.145406000000001	62.177475999999999	57.856394999999999	57.841897000000003	Молодежная	0103000020E610000001000000050000003352EFA99C124F40DECCE847C3EB4C403352EFA99C124F409DBAF2599EED4C4096E99788B7164F409DBAF2599EED4C4096E99788B7164F40DECCE847C3EB4C403352EFA99C124F40DECCE847C3EB4C40
18946	47067	61.844057999999997	61.882675999999996	57.711906999999997	57.702824	Красных орлов	0103000020E61000000100000005000000ADF6B0170AEC4E40056C0723F6D94C40ADF6B0170AEC4E409065C1C41FDB4C40677BF486FBF04E409065C1C41FDB4C40677BF486FBF04E40056C0723F6D94C40ADF6B0170AEC4E40056C0723F6D94C40
19859	49027	61.784778000000003	61.798440999999997	58.446891000000001	58.43985	Школьная	0103000020E61000000100000005000000664F029B73E44E40A3923A014D384D40664F029B73E44E4039F06AB933394D408C648F5033E64E4039F06AB933394D408C648F5033E64E40A3923A014D384D40664F029B73E44E40A3923A014D384D40
18736	14776	62.106186000000001	62.12276	57.819164000000001	57.806080000000001	Центральная	0103000020E6100000010000000500000083A5BA80970D4F40D7FA22A12DE74C4083A5BA80970D4F40C007AF5DDAE84C40E4A08499B60F4F40C007AF5DDAE84C40E4A08499B60F4F40D7FA22A12DE74C4083A5BA80970D4F40D7FA22A12DE74C40
78509	31165	61.872785999999998	61.896985999999998	58.464593999999998	58.457712000000001	Корелина	0103000020E610000001000000050000000D349F73B7EF4E404E7E8B4E963A4D400D349F73B7EF4E407BF5F1D0773B4D40247CEF6FD0F24E407BF5F1D0773B4D40247CEF6FD0F24E404E7E8B4E963A4D400D349F73B7EF4E404E7E8B4E963A4D40
20290	45812	60.902273000000001	63.221094000000001	59.101098	57.507396999999997	Школьная	0103000020E610000001000000050000002B8881AE7D734E40548B8862F2C04C402B8881AE7D734E4073D87DC7F08C4D40C1ABE5CE4C9C4F4073D87DC7F08C4D40C1ABE5CE4C9C4F40548B8862F2C04C402B8881AE7D734E40548B8862F2C04C40
18793	11671	61.734203000000001	61.755043999999998	57.652389999999997	57.641539000000002	Красных Партизан	0103000020E6100000010000000500000003D0285DFADD4E40E50D30F31DD24C4003D0285DFADD4E40641EF98381D34C4040852348A5E04E40641EF98381D34C4040852348A5E04E40E50D30F31DD24C4003D0285DFADD4E40E50D30F31DD24C40
18333	9796	61.694650000000003	61.717286999999999	58.236294999999998	58.221145	Мира	0103000020E610000001000000050000004D158C4AEAD84E404356B77A4E1C4D404D158C4AEAD84E40AA9A20EA3E1E4D40486C770FD0DB4E40AA9A20EA3E1E4D40486C770FD0DB4E404356B77A4E1C4D404D158C4AEAD84E404356B77A4E1C4D40
20312	47443	61.722569	61.738720999999998	57.873108000000002	57.861781000000001	Набережная	0103000020E610000001000000050000003D0D18247DDC4E4037A8FDD64EEE4C403D0D18247DDC4E4020F0C000C2EF4C4028EFE3688EDE4E4020F0C000C2EF4C4028EFE3688EDE4E4037A8FDD64EEE4C403D0D18247DDC4E4037A8FDD64EEE4C40
78503	29934	61.874366999999999	61.893627000000002	58.119155999999997	58.105701000000003	Клубная	0103000020E61000000100000005000000CFD90242EBEF4E40C713419C870D4D40CFD90242EBEF4E40A38FF980400F4D404BE9995E62F24E40A38FF980400F4D404BE9995E62F24E40C713419C870D4D40CFD90242EBEF4E40C713419C870D4D40
19973	47649	61.645620000000001	61.687894	57.575184	57.561041000000003	Ленина	0103000020E610000001000000050000005FD218ADA3D24E408A5B0531D0C74C405FD218ADA3D24E405B971AA19FC94C40AC8E1CE90CD84E405B971AA19FC94C40AC8E1CE90CD84E408A5B0531D0C74C405FD218ADA3D24E408A5B0531D0C74C40
18378	16063	62.488014999999997	62.521054999999997	57.948493999999997	57.938552999999999	60 лет Октября	0103000020E610000001000000050000008D7A8846773E4F400648348122F84C408D7A8846773E4F40E2395B4068F94C40693524EEB1424F40E2395B4068F94C40693524EEB1424F400648348122F84C408D7A8846773E4F400648348122F84C40
18632	2870	62.054380000000002	62.072417999999999	57.751309999999997	57.741261000000002	Советская	0103000020E610000001000000050000003BC780ECF5064F406F66F4A3E1DE4C403BC780ECF5064F40319413ED2AE04C4024D236FE44094F40319413ED2AE04C4024D236FE44094F406F66F4A3E1DE4C403BC780ECF5064F406F66F4A3E1DE4C40
19834	19942	61.640732999999997	61.706606000000001	58.012332999999998	57.968066	Октябрьская	0103000020E61000000100000005000000E63BF88903D24E404D2F3196E9FB4C40E63BF88903D24E40AED4B32094014D402594BE1072DA4E40AED4B32094014D402594BE1072DA4E404D2F3196E9FB4C40E63BF88903D24E404D2F3196E9FB4C40
9903	19942	61.640732999999997	61.706606000000001	58.012332999999998	57.968066	Ленина	0103000020E61000000100000005000000E63BF88903D24E404D2F3196E9FB4C40E63BF88903D24E40AED4B32094014D402594BE1072DA4E40AED4B32094014D402594BE1072DA4E404D2F3196E9FB4C40E63BF88903D24E404D2F3196E9FB4C40
78418	19942	61.640732999999997	61.706606000000001	58.012332999999998	57.968066	Красной Гвардии	0103000020E61000000100000005000000E63BF88903D24E404D2F3196E9FB4C40E63BF88903D24E40AED4B32094014D402594BE1072DA4E40AED4B32094014D402594BE1072DA4E404D2F3196E9FB4C40E63BF88903D24E404D2F3196E9FB4C40
18782	19942	61.640732999999997	61.706606000000001	58.012332999999998	57.968066	Бажова	0103000020E61000000100000005000000E63BF88903D24E404D2F3196E9FB4C40E63BF88903D24E40AED4B32094014D402594BE1072DA4E40AED4B32094014D402594BE1072DA4E404D2F3196E9FB4C40E63BF88903D24E404D2F3196E9FB4C40
19930	10502	62.148145999999997	62.166885000000001	57.824128999999999	57.809483999999998	Советская	0103000020E610000001000000050000004084B872F6124F405051F52B9DE74C404084B872F6124F40B4571F0F7DE94C40B398D87C5C154F40B4571F0F7DE94C40B398D87C5C154F405051F52B9DE74C404084B872F6124F405051F52B9DE74C40
19824	20293	61.706364000000001	61.725884000000001	58.146230000000003	58.126114000000001	Ленина	0103000020E610000001000000050000002F89B3226ADA4E40ACC8E88024104D402F89B3226ADA4E40D8D825AAB7124D40475854C4E9DC4E40D8D825AAB7124D40475854C4E9DC4E40ACC8E88024104D402F89B3226ADA4E40ACC8E88024104D40
20296	31025	61.783555999999997	61.794218999999998	58.428730999999999	58.422260999999999	Центральная	0103000020E61000000100000005000000D34A21904BE44E4029B000A60C364D40D34A21904BE44E4004E44BA8E0364D40506EDBF7A8E54E4004E44BA8E0364D40506EDBF7A8E54E4029B000A60C364D40D34A21904BE44E4029B000A60C364D40
20266	19834	62.454228999999998	62.468459000000003	58.525004000000003	58.518773000000003	Центральная	0103000020E6100000010000000500000088F2052D243A4F401F86562767424D4088F2052D243A4F407522C15433434D402942EA76F63B4F407522C15433434D402942EA76F63B4F401F86562767424D4088F2052D243A4F401F86562767424D40
20308	50216	62.160265000000003	62.187905999999998	57.992789999999999	57.985895999999997	Клубная	0103000020E61000000100000005000000C3D8429083144F40ECA012D731FE4C40C3D8429083144F40DEE522BE13FF4C40705CC64D0D184F40DEE522BE13FF4C40705CC64D0D184F40ECA012D731FE4C40C3D8429083144F40ECA012D731FE4C40
78417	4039	61.716541999999997	61.743338000000001	57.614624999999997	57.597512000000002	Школьная	0103000020E61000000100000005000000EF1AF4A5B7DB4E40D97BF1457BCC4C40EF1AF4A5B7DB4E40E9263108ACCE4C40E1EF17B325DF4E40E9263108ACCE4C40E1EF17B325DF4E40D97BF1457BCC4C40EF1AF4A5B7DB4E40D97BF1457BCC4C40
20238	50201	63.015757000000001	63.050935000000003	58.554271	58.547716999999999	Центральная	0103000020E610000001000000050000006FD74B5304824F404B3B35971B464D406FD74B5304824F40840F255AF2464D40639CBF0985864F40840F255AF2464D40639CBF0985864F404B3B35971B464D406FD74B5304824F404B3B35971B464D40
77183	61092	60.225445999999998	60.291347000000002	57.979889	57.955987	Ленина	0103000020E61000000100000005000000CB811E6ADB1C4E40593332C85DFA4C40CB811E6ADB1C4E40E65AB4006DFD4C40D464C6DB4A254E40E65AB4006DFD4C40D464C6DB4A254E40593332C85DFA4C40CB811E6ADB1C4E40593332C85DFA4C40
75683	60715	65.309398999999999	65.323887999999997	55.452292999999997	55.445430999999999	Отдыха	0103000020E61000000100000005000000919A7631CD535040F2CF0CE203B94B40919A7631CD535040D89AADBCE4B94B4047E4BB94BA545040D89AADBCE4B94B4047E4BB94BA545040F2CF0CE203B94B40919A7631CD535040F2CF0CE203B94B40
41071	54993	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Энергетиков	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
40688	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	площадь Победы	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
40912	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	Школьная	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
41441	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	Пролетарская	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
40701	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	Мира	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
41067	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	Маршала Жукова Г. К	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
41691	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	Ленина	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
40827	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	Калинина	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
41442	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	К. Маркса	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
41250	54952	62.716608999999998	62.782437999999999	55.225465999999997	55.197127000000002	1ое Мая	0103000020E610000001000000050000007782FDD7B95B4F404D1421753B994B407782FDD7B95B4F40122EE411DC9C4B40E692AAED26644F40122EE411DC9C4B40E692AAED26644F404D1421753B994B407782FDD7B95B4F404D1421753B994B40
40908	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	бульвар 50-тилетия Октября	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40685	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Советская	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40819	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Смолина	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40487	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Победы	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40821	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Морозова	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40700	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Магистральная	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40598	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Ленина	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40698	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Комсомольская	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40923	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Кирова	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40600	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Квартал Новостроек	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40813	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Гоголя	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40910	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Воронкова	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
41052	54925	63.235593000000001	63.341360999999999	55.254379	55.207926999999998	Бульвар 50летия Октября	0103000020E61000000100000005000000511553E9279E4F404A7A185A9D9A4B40511553E9279E4F4004E5B67D8FA04B409F909DB7B1AB4F4004E5B67D8FA04B409F909DB7B1AB4F404A7A185A9D9A4B40511553E9279E4F404A7A185A9D9A4B40
40730	54957	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Свердлова	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
41418	54957	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Кирова	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40653	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Энергетиков	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40414	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Щеткина	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40497	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Февральская	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40411	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Труда	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40738	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Тобольская	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40565	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Спартака	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40372	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Свердлова	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40499	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Розы Люксембург	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40734	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Проектная	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40561	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Первомайская	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40406	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Мичурина	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40837	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Михайловская	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40929	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Луначарского	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40649	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Ломоносова	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40417	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Ленина	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40657	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Красноармейская	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
75967	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Крайняя	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40737	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Кооперативная	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40751	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Карла Либкнехта	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
41285	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Демьяна Бедного	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40656	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Батуринская	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40739	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Архангельского	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40732	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	Автомобилистов	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40494	1010	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	4го Уральского полка	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
40472	54920	63.650317999999999	63.702168999999998	54.517440999999998	54.491579000000002	Свердлова	0103000020E610000001000000050000000400C79E3DD34F404033880FEC3E4B400400C79E3DD34F40054EB6813B424B40ECA17DACE0D94F40054EB6813B424B40ECA17DACE0D94F404033880FEC3E4B400400C79E3DD34F404033880FEC3E4B40
40505	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	Чапаева	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
40888	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	Строительная	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
41270	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	Первомайская	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
40469	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	Линейная	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
40503	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	Красная	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
40887	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	Кирова	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
40468	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	Карла Маркса	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
40977	54919	67.837239999999994	67.928724000000003	55.095146999999997	55.037221000000002	К.Маркса	0103000020E61000000100000005000000CBB9145795F55040BADC60A8C3844B40CBB9145795F5504000A8E2C62D8C4B40A9C0C93670FB504000A8E2C62D8C4B40A9C0C93670FB5040BADC60A8C3844B40CBB9145795F55040BADC60A8C3844B40
40922	54918	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	Ново-Северная	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
40464	54918	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	Лесная	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
40689	54918	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	Ленина	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
40463	54918	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	Демьяна Бедного	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
41014	54918	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	В.Ушаковой	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
40919	54918	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	2я Вокзальная	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
41555	55032	65.309685999999999	65.332601999999994	55.298302	55.279384999999998	Студенческий	0103000020E61000000100000005000000DC813AE5D153504019FF3EE3C2A34B40DC813AE5D15350406B2A8BC22EA64B406325E659495550406B2A8BC22EA64B406325E6594955504019FF3EE3C2A34B40DC813AE5D153504019FF3EE3C2A34B40
40879	54979	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	Кирова	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
40511	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	пр.Конституции	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40453	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	Студенческая	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40588	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	Пролетарская	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40586	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	Правды	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40898	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	Парковый переулок	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40673	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	Ленина	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40460	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	Колхозная	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40455	54914	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	XXII Партсъезда	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
81123	1331	65.249202999999994	65.260935000000003	55.473770999999999	55.470182999999999	улица Алексеева	0103000020E610000001000000050000002AC423F1F24F50404D11E0F42EBC4B402AC423F1F24F504088653387A4BC4B406FD8B628B350504088653387A4BC4B406FD8B628B35050404D11E0F42EBC4B402AC423F1F24F50404D11E0F42EBC4B40
41416	1331	65.249202999999994	65.260935000000003	55.473770999999999	55.470182999999999	улица Алексеева	0103000020E610000001000000050000002AC423F1F24F50404D11E0F42EBC4B402AC423F1F24F504088653387A4BC4B406FD8B628B350504088653387A4BC4B406FD8B628B35050404D11E0F42EBC4B402AC423F1F24F50404D11E0F42EBC4B40
40617	1331	65.314187000000004	65.343562000000006	55.485010000000003	55.449072000000001	проспект Машиностроителей	0103000020E610000001000000050000000475CAA31B54504050C6F8307BB94B400475CAA31B545040D21DC4CE14BE4B407F8978EBFC555040D21DC4CE14BE4B407F8978EBFC55504050C6F8307BB94B400475CAA31B54504050C6F8307BB94B40
75699	1331	65.217563999999996	65.271812999999995	55.426186000000001	55.400471000000003	проспект Конституции	0103000020E610000001000000050000005D328E91EC4D50408BFF3BA242B34B405D328E91EC4D5040AC014A438DB64B402B685A6265515040AC014A438DB64B402B685A62655150408BFF3BA242B34B405D328E91EC4D50408BFF3BA242B34B40
75628	1331	65.217563999999996	65.271812999999995	55.426186000000001	55.400471000000003	проспект Конституции	0103000020E610000001000000050000005D328E91EC4D50408BFF3BA242B34B405D328E91EC4D5040AC014A438DB64B402B685A6265515040AC014A438DB64B402B685A62655150408BFF3BA242B34B405D328E91EC4D50408BFF3BA242B34B40
75638	1331	65.318894	65.321669999999997	55.441647000000003	55.440330000000003	площадь Слосмана	0103000020E61000000100000005000000003961C2685450404EB9C2BB5CB84B40003961C26854504032B08EE387B84B40AD86C43D9654504032B08EE387B84B40AD86C43D965450404EB9C2BB5CB84B40003961C2685450404EB9C2BB5CB84B40
76013	1331	65.317087999999998	65.318211000000005	55.441091	55.440299000000003	пл.Собанина	0103000020E610000001000000050000000F7D772B4B54504013BBB6B75BB84B400F7D772B4B545040ACC77DAB75B84B408F8EAB915D545040ACC77DAB75B84B408F8EAB915D54504013BBB6B75BB84B400F7D772B4B54504013BBB6B75BB84B40
77038	1331	65.318894	65.321669999999997	55.441647000000003	55.440330000000003	пл.Слосмана	0103000020E61000000100000005000000003961C2685450404EB9C2BB5CB84B40003961C26854504032B08EE387B84B40AD86C43D9654504032B08EE387B84B40AD86C43D965450404EB9C2BB5CB84B40003961C2685450404EB9C2BB5CB84B40
75670	1331	65.427769999999995	65.448988	55.418205999999998	55.408746000000001	микрорайон Керамзитный	0103000020E610000001000000050000006F0D6C95605B5040772FF7C951B44B406F0D6C95605B5040D87E32C687B54B40F9122A38BC5C5040D87E32C687B54B40F9122A38BC5C5040772FF7C951B44B406F0D6C95605B5040772FF7C951B44B40
41794	1331	65.393839999999997	65.397829000000002	55.394069999999999	55.389145999999997	Яблоневая	0103000020E61000000100000005000000D3F6AFAC3459504042AF3F89CFB14B40D3F6AFAC34595040D82AC1E270B24B40A019C40776595040D82AC1E270B24B40A019C4077659504042AF3F89CFB14B40D3F6AFAC3459504042AF3F89CFB14B40
40635	1331	65.280203	65.285601999999997	55.435406	55.433292000000002	Электровозная	0103000020E610000001000000050000006E4F90D8EE51504029CFBC1C76B74B406E4F90D8EE515040B83D4162BBB74B40056B9C4D47525040B83D4162BBB74B40056B9C4D4752504029CFBC1C76B74B406E4F90D8EE51504029CFBC1C76B74B40
76002	1331	65.307233999999994	65.327122000000003	55.491064000000001	55.484678000000002	Школьная	0103000020E61000000100000005000000088ECBB8A95350409C8BBFED09BE4B40088ECBB8A9535040191F662FDBBE4B4056F31C91EF545040191F662FDBBE4B4056F31C91EF5450409C8BBFED09BE4B40088ECBB8A95350409C8BBFED09BE4B40
40534	1331	65.408203999999998	65.422559000000007	55.462257999999999	55.455494000000002	Центральная	0103000020E610000001000000050000002B86AB03205A50401AC39CA04DBA4B402B86AB03205A50403D2828452BBB4B405A68E7340B5B50403D2828452BBB4B405A68E7340B5B50401AC39CA04DBA4B402B86AB03205A50401AC39CA04DBA4B40
41083	1331	65.408203999999998	65.422559000000007	55.462257999999999	55.455494000000002	Центральная	0103000020E610000001000000050000002B86AB03205A50401AC39CA04DBA4B402B86AB03205A50403D2828452BBB4B405A68E7340B5B50403D2828452BBB4B405A68E7340B5B50401AC39CA04DBA4B402B86AB03205A50401AC39CA04DBA4B40
75684	1331	65.252329000000003	65.262489000000002	55.468780000000002	55.465636000000003	Фарафонова	0103000020E6100000010000000500000046B58828265050408EEBDFF599BB4B4046B58828265050406B82A8FB00BC4B40D3A3A99ECC5050406B82A8FB00BC4B40D3A3A99ECC5050408EEBDFF599BB4B4046B58828265050408EEBDFF599BB4B40
40520	1331	65.405563000000001	65.425523999999996	55.468437999999999	55.455723999999996	Урожайная	0103000020E61000000100000005000000EE5D83BEF45950404B00FE2955BA4B40EE5D83BEF4595040111AC1C6F5BB4B4070EA03C93B5B5040111AC1C6F5BB4B4070EA03C93B5B50404B00FE2955BA4B40EE5D83BEF45950404B00FE2955BA4B40
75712	1331	65.331155999999993	65.358716000000001	55.446835	55.433470999999997	Урицкого	0103000020E61000000100000005000000F277EFA831555040D8614CFA7BB74B40F277EFA831555040A5DAA7E331B94B405323F433F5565040A5DAA7E331B94B405323F433F5565040D8614CFA7BB74B40F277EFA831555040D8614CFA7BB74B40
40542	1331	65.331155999999993	65.358716000000001	55.446835	55.433470999999997	Урицкого	0103000020E61000000100000005000000F277EFA831555040D8614CFA7BB74B40F277EFA831555040A5DAA7E331B94B405323F433F5565040A5DAA7E331B94B405323F433F5565040D8614CFA7BB74B40F277EFA831555040D8614CFA7BB74B40
40350	1331	65.320142000000004	65.325684999999993	55.503450999999998	55.494853999999997	Тимирязева	0103000020E61000000100000005000000DE04DF347D545040BB25396057BF4B40DE04DF347D545040BA11161571C04B400EF3E505D8545040BA11161571C04B400EF3E505D8545040BB25396057BF4B40DE04DF347D545040BB25396057BF4B40
40392	1331	65.319108999999997	65.352608000000004	55.450837999999997	55.440600000000003	Станционная	0103000020E61000000100000005000000FEB627486C5450400E4FAF9465B84B40FEB627486C545040A3E5400FB5B94B40B613252191565040A3E5400FB5B94B40B6132521915650400E4FAF9465B84B40FEB627486C5450400E4FAF9465B84B40
75637	1331	65.319108999999997	65.352608000000004	55.450837999999997	55.440600000000003	Станционная	0103000020E61000000100000005000000FEB627486C5450400E4FAF9465B84B40FEB627486C545040A3E5400FB5B94B40B613252191565040A3E5400FB5B94B40B6132521915650400E4FAF9465B84B40FEB627486C5450400E4FAF9465B84B40
40391	1331	65.319108999999997	65.352608000000004	55.450837999999997	55.440600000000003	Станционная	0103000020E61000000100000005000000FEB627486C5450400E4FAF9465B84B40FEB627486C545040A3E5400FB5B94B40B613252191565040A3E5400FB5B94B40B6132521915650400E4FAF9465B84B40FEB627486C5450400E4FAF9465B84B40
75864	1331	65.398673000000002	65.400801999999999	55.451746999999997	55.447130999999999	Спортивная	0103000020E610000001000000050000001633C2DB835950408E03AF963BB94B401633C2DB8359504076887FD8D2B94B40F88A6EBDA659504076887FD8D2B94B40F88A6EBDA65950408E03AF963BB94B401633C2DB835950408E03AF963BB94B40
40388	1331	65.276708999999997	65.278999999999996	55.417827000000003	55.415731999999998	Солнечный бульвар	0103000020E610000001000000050000009160AA99B551504049F3C7B436B54B409160AA99B55150406231EA5A7BB54B4060E5D022DB5150406231EA5A7BB54B4060E5D022DB51504049F3C7B436B54B409160AA99B551504049F3C7B436B54B40
75624	1331	65.336158999999995	65.371364	55.447152000000003	55.430185999999999	Советская 	0103000020E6100000010000000500000063D009A1835550403999B85510B74B4063D009A183555040A62BD8463CB94B405ABA826DC4575040A62BD8463CB94B405ABA826DC45750403999B85510B74B4063D009A1835550403999B85510B74B40
40339	1331	65.336158999999995	65.371364	55.447152000000003	55.430185999999999	Советская	0103000020E6100000010000000500000063D009A1835550403999B85510B74B4063D009A183555040A62BD8463CB94B405ABA826DC4575040A62BD8463CB94B405ABA826DC45750403999B85510B74B4063D009A1835550403999B85510B74B40
40708	1331	65.336158999999995	65.371364	55.447152000000003	55.430185999999999	Советская	0103000020E6100000010000000500000063D009A1835550403999B85510B74B4063D009A183555040A62BD8463CB94B405ABA826DC4575040A62BD8463CB94B405ABA826DC45750403999B85510B74B4063D009A1835550403999B85510B74B40
40536	1331	65.336158999999995	65.371364	55.447152000000003	55.430185999999999	Советская	0103000020E6100000010000000500000063D009A1835550403999B85510B74B4063D009A183555040A62BD8463CB94B405ABA826DC4575040A62BD8463CB94B405ABA826DC45750403999B85510B74B4063D009A1835550403999B85510B74B40
40430	1331	65.453631999999999	65.455977000000004	55.453921999999999	55.451864	Сиреневая	0103000020E61000000100000005000000D21A834E085D5040B01EF7ADD6B94B40D21A834E085D5040AB77B81D1ABA4B409BAE27BA2E5D5040AB77B81D1ABA4B409BAE27BA2E5D5040B01EF7ADD6B94B40D21A834E085D5040B01EF7ADD6B94B40
41767	1331	65.253621999999993	65.259264000000002	55.445967000000003	55.443358000000003	Сады Зауралья	0103000020E61000000100000005000000F3E2C4573B505040C23577F4BFB84B40F3E2C4573B505040310C587215B94B40EE4108C897505040310C587215B94B40EE4108C897505040C23577F4BFB84B40F3E2C4573B505040C23577F4BFB84B40
75669	1331	65.311122999999995	65.363495	55.452855	55.430697000000002	Пушкина	0103000020E6100000010000000500000023827170E95350401FBE4C1421B74B4023827170E9535040406A1327F7B94B409C50888043575040406A1327F7B94B409C508880435750401FBE4C1421B74B4023827170E95350401FBE4C1421B74B40
75872	1331	65.366890999999995	65.392385000000004	55.462615	55.449036	Пугачева	0103000020E61000000100000005000000978C63247B575040035DFB027AB94B40978C63247B575040CCD1E3F736BB4B40399CF9D51C595040CCD1E3F736BB4B40399CF9D51C595040035DFB027AB94B40978C63247B575040035DFB027AB94B40
40348	1331	65.343562000000006	65.357467	55.449072000000001	55.438726000000003	Пролетарская	0103000020E610000001000000050000007F8978EBFC555040D4F36E2C28B84B407F8978EBFC55504050C6F8307BB94B408D9944BDE056504050C6F8307BB94B408D9944BDE0565040D4F36E2C28B84B407F8978EBFC555040D4F36E2C28B84B40
75657	1331	65.281460999999993	65.301179000000005	55.444628999999999	55.439675999999999	Правды	0103000020E610000001000000050000005D86FF7403525040056B9C4D47B84B405D86FF740352504035ED629AE9B84B407DCF48844653504035ED629AE9B84B407DCF488446535040056B9C4D47B84B405D86FF7403525040056B9C4D47B84B40
75630	1331	65.301879999999997	65.306298999999996	55.431749000000003	55.430568999999998	Победы	0103000020E6100000010000000500000041D47D0052535040F1D58EE21CB74B4041D47D0052535040558A1D8D43B74B400AF31E679A535040558A1D8D43B74B400AF31E679A535040F1D58EE21CB74B4041D47D0052535040F1D58EE21CB74B40
40353	1331	65.348609999999994	65.355051000000003	55.441871999999996	55.437525999999998	Пичугина	0103000020E61000000100000005000000BF4351A04F56504029931ADA00B84B40BF4351A04F5650405182FE428FB84B40605AD427B95650405182FE428FB84B40605AD427B956504029931ADA00B84B40BF4351A04F56504029931ADA00B84B40
40605	1331	65.309523999999996	65.320340000000002	55.503120000000003	55.500621000000002	Пирогова	0103000020E61000000100000005000000EF54C03DCF5350406D58535914C04B40EF54C03DCF53504055FB743C66C04B4071E657738054504055FB743C66C04B4071E65773805450406D58535914C04B40EF54C03DCF5350406D58535914C04B40
40633	1331	65.312803000000002	65.389268000000001	55.497413999999999	55.442449000000003	Омская	0103000020E61000000100000005000000CEC5DFF604545040EF92382BA2B84B40CEC5DFF60454504049490F43ABBF4B40475854C4E958504049490F43ABBF4B40475854C4E9585040EF92382BA2B84B40CEC5DFF604545040EF92382BA2B84B40
40612	1331	65.334964999999997	65.353515000000002	55.455835999999998	55.449489999999997	Некрасова	0103000020E610000001000000050000007F130A117055504084F068E388B94B407F130A1170555040732B84D558BA4B404FE960FD9F565040732B84D558BA4B404FE960FD9F56504084F068E388B94B407F130A117055504084F068E388B94B40
75702	1331	65.299453999999997	65.303335000000004	55.434227	55.428291000000002	Невежина	0103000020E61000000100000005000000022A1C412A535040E8154F3DD2B64B40022A1C412A535040250516C094B74B40DC2E34D769535040250516C094B74B40DC2E34D769535040E8154F3DD2B64B40022A1C412A535040E8154F3DD2B64B40
75627	1331	65.325666999999996	65.327661000000006	55.493057999999998	55.490468	Московская	0103000020E61000000100000005000000BB9866BAD754504005DEC9A7C7BE4B40BB9866BAD7545040FD8348861CBF4B402ECBD765F8545040FD8348861CBF4B402ECBD765F854504005DEC9A7C7BE4B40BB9866BAD754504005DEC9A7C7BE4B40
40382	1331	65.292204999999996	65.312911	55.465013999999996	55.445773000000003	Молодежи	0103000020E6100000010000000500000092AE997CB35250404C38F4160FB94B4092AE997CB35250405017299485BB4B40C1E3DBBB065450405017299485BB4B40C1E3DBBB065450404C38F4160FB94B4092AE997CB35250404C38F4160FB94B40
75625	1331	65.332008999999999	65.371247999999994	55.448515	55.430216999999999	Максима Горького	0103000020E61000000100000005000000923EADA23F5550407497C45911B74B40923EADA23F555040FA6184F068B94B4025ADF886C2575040FA6184F068B94B4025ADF886C25750407497C45911B74B40923EADA23F5550407497C45911B74B40
40752	1331	65.387094000000005	65.400550999999993	55.455734	55.447831000000001	Ломоносова	0103000020E61000000100000005000000959EE925C65850404791B58652B94B40959EE925C65850406FD6E07D55BA4B405358A9A0A25950406FD6E07D55BA4B405358A9A0A25950404791B58652B94B40959EE925C65850404791B58652B94B40
75933	1331	65.387094000000005	65.400550999999993	55.455734	55.447831000000001	Ломоносова	0103000020E61000000100000005000000959EE925C65850404791B58652B94B40959EE925C65850406FD6E07D55BA4B405358A9A0A25950406FD6E07D55BA4B405358A9A0A25950404791B58652B94B40959EE925C65850404791B58652B94B40
40345	1331	65.337605999999994	65.356452000000004	55.446033999999997	55.433408999999997	Ленина	0103000020E61000000100000005000000BC3B32569B555040626534F279B74B40BC3B32569B555040B87361A417B94B4001A60C1CD0565040B87361A417B94B4001A60C1CD0565040626534F279B74B40BC3B32569B555040626534F279B74B40
40393	1331	65.337605999999994	65.356452000000004	55.446033999999997	55.433408999999997	Ленина	0103000020E61000000100000005000000BC3B32569B555040626534F279B74B40BC3B32569B555040B87361A417B94B4001A60C1CD0565040B87361A417B94B4001A60C1CD0565040626534F279B74B40BC3B32569B555040626534F279B74B40
40396	1331	65.339860999999999	65.386600000000001	55.447147000000001	55.430283000000003	Куйбышева	0103000020E61000000100000005000000E50B5A48C05550402C836A8313B74B40E50B5A48C055504094C0E61C3CB94B408D28ED0DBE58504094C0E61C3CB94B408D28ED0DBE5850402C836A8313B74B40E50B5A48C05550402C836A8313B74B40
40529	1331	65.339860999999999	65.386600000000001	55.447147000000001	55.430283000000003	Куйбышева	0103000020E61000000100000005000000E50B5A48C05550402C836A8313B74B40E50B5A48C055504094C0E61C3CB94B408D28ED0DBE58504094C0E61C3CB94B408D28ED0DBE5850402C836A8313B74B40E50B5A48C05550402C836A8313B74B40
75671	1331	65.298484000000002	65.312946999999994	55.492778000000001	55.489758999999999	Кузнецова	0103000020E610000001000000050000004698A25C1A535040F9F5436CB0BE4B404698A25C1A5350401A18795913BF4B406798DA52075450401A18795913BF4B406798DA5207545040F9F5436CB0BE4B404698A25C1A535040F9F5436CB0BE4B40
40325	1331	65.356290999999999	65.369423999999995	55.448535999999997	55.439247000000002	Кравченко	0103000020E61000000100000005000000FC36C478CD565040DDEEE53E39B84B40FC36C478CD565040118AADA069B94B40E1968FA4A4575040118AADA069B94B40E1968FA4A4575040DDEEE53E39B84B40FC36C478CD565040DDEEE53E39B84B40
40559	1331	65.381586999999996	65.397019999999998	55.460470999999998	55.451695999999998	Котовского	0103000020E610000001000000050000000A65E1EB6B585040F4DDAD2CD1B94B400A65E1EB6B585040D2E0B6B6F0BA4B40E8F692C668595040D2E0B6B6F0BA4B40E8F692C668595040F4DDAD2CD1B94B400A65E1EB6B585040F4DDAD2CD1B94B40
75653	1331	65.374139999999997	65.393957	55.464044000000001	55.452589000000003	Космонавтов	0103000020E610000001000000050000000708E6E8F1575040C2C3B46FEEB94B400708E6E8F1575040D8F335CB65BB4B40F0C16B9736595040D8F335CB65BB4B40F0C16B9736595040C2C3B46FEEB94B400708E6E8F1575040C2C3B46FEEB94B40
40412	1331	65.217563999999996	65.271812999999995	55.426186000000001	55.400471000000003	Конституции проспект	0103000020E610000001000000050000005D328E91EC4D50408BFF3BA242B34B405D328E91EC4D5040AC014A438DB64B402B685A6265515040AC014A438DB64B402B685A62655150408BFF3BA242B34B405D328E91EC4D50408BFF3BA242B34B40
40731	1331	65.217563999999996	65.271812999999995	55.426186000000001	55.400471000000003	Конституции проспект	0103000020E610000001000000050000005D328E91EC4D50408BFF3BA242B34B405D328E91EC4D5040AC014A438DB64B402B685A6265515040AC014A438DB64B402B685A62655150408BFF3BA242B34B405D328E91EC4D50408BFF3BA242B34B40
75705	1331	65.271812999999995	65.353515000000002	55.449688999999999	55.426186000000001	Коли Мяготина	0103000020E610000001000000050000002B685A6265515040AC014A438DB64B402B685A62655150407B2FBE688FB94B404FE960FD9F5650407B2FBE688FB94B404FE960FD9F565040AC014A438DB64B402B685A6265515040AC014A438DB64B40
40327	1331	65.271812999999995	65.353515000000002	55.449688999999999	55.426186000000001	Коли Мяготина	0103000020E610000001000000050000002B685A6265515040AC014A438DB64B402B685A62655150407B2FBE688FB94B404FE960FD9F5650407B2FBE688FB94B404FE960FD9F565040AC014A438DB64B402B685A6265515040AC014A438DB64B40
75640	1331	65.271812999999995	65.353515000000002	55.449688999999999	55.426186000000001	Коли Мяготина	0103000020E610000001000000050000002B685A6265515040AC014A438DB64B402B685A62655150407B2FBE688FB94B404FE960FD9F5650407B2FBE688FB94B404FE960FD9F565040AC014A438DB64B402B685A6265515040AC014A438DB64B40
75663	1331	65.325523000000004	65.350631000000007	55.442504999999997	55.426110000000001	Кирова	0103000020E6100000010000000500000022C66B5ED5545040D13FC1C58AB64B4022C66B5ED554504082A8FB00A4B84B40AF7D01BD7056504082A8FB00A4B84B40AF7D01BD70565040D13FC1C58AB64B4022C66B5ED5545040D13FC1C58AB64B40
40342	1331	65.332710000000006	65.372927000000004	55.451425	55.432468999999998	Карла Маркса	0103000020E610000001000000050000005743E21E4B55504054C4E9245BB74B405743E21E4B55504064CC5D4BC8B94B40E8323509DE57504064CC5D4BC8B94B40E8323509DE57504054C4E9245BB74B405743E21E4B55504054C4E9245BB74B40
40334	1331	65.332710000000006	65.372927000000004	55.451425	55.432468999999998	Карла Маркса	0103000020E610000001000000050000005743E21E4B55504054C4E9245BB74B405743E21E4B55504064CC5D4BC8B94B40E8323509DE57504064CC5D4BC8B94B40E8323509DE57504054C4E9245BB74B405743E21E4B55504054C4E9245BB74B40
75664	1331	65.332710000000006	65.372927000000004	55.451425	55.432468999999998	Карла Маркса	0103000020E610000001000000050000005743E21E4B55504054C4E9245BB74B405743E21E4B55504064CC5D4BC8B94B40E8323509DE57504064CC5D4BC8B94B40E8323509DE57504054C4E9245BB74B405743E21E4B55504054C4E9245BB74B40
40479	1331	65.32105	65.327624999999998	55.433537000000001	55.426400999999998	Карельцева	0103000020E610000001000000050000005F984C158C545040A8FDD64E94B64B405F984C158C545040904DF2237EB74B408716D9CEF7545040904DF2237EB74B408716D9CEF7545040A8FDD64E94B64B405F984C158C545040A8FDD64E94B64B40
75633	1331	65.32105	65.327624999999998	55.433537000000001	55.426400999999998	Карельцева	0103000020E610000001000000050000005F984C158C545040A8FDD64E94B64B405F984C158C545040904DF2237EB74B408716D9CEF7545040904DF2237EB74B408716D9CEF7545040A8FDD64E94B64B405F984C158C545040A8FDD64E94B64B40
40352	1331	65.309218999999999	65.315166000000005	55.504322999999999	55.485010000000003	Карбышева	0103000020E6100000010000000500000051137D3ECA535040D21DC4CE14BE4B4051137D3ECA53504070CFF3A78DC04B40EAB303AE2B54504070CFF3A78DC04B40EAB303AE2B545040D21DC4CE14BE4B4051137D3ECA535040D21DC4CE14BE4B40
40477	1331	65.309218999999999	65.315166000000005	55.504322999999999	55.485010000000003	Карбышева	0103000020E6100000010000000500000051137D3ECA535040D21DC4CE14BE4B4051137D3ECA53504070CFF3A78DC04B40EAB303AE2B54504070CFF3A78DC04B40EAB303AE2B545040D21DC4CE14BE4B4051137D3ECA535040D21DC4CE14BE4B40
75666	1331	65.309218999999999	65.315166000000005	55.504322999999999	55.485010000000003	Карбышева	0103000020E6100000010000000500000051137D3ECA535040D21DC4CE14BE4B4051137D3ECA53504070CFF3A78DC04B40EAB303AE2B54504070CFF3A78DC04B40EAB303AE2B545040D21DC4CE14BE4B4051137D3ECA535040D21DC4CE14BE4B40
71735	1331	65.368678000000003	65.381568999999999	55.383555999999999	55.374927999999997	Интернатовская	0103000020E610000001000000050000004D309C6B98575040662D05A4FDAF4B404D309C6B98575040A017EE5C18B14B40B70A62A06B585040A017EE5C18B14B40B70A62A06B585040662D05A4FDAF4B404D309C6B98575040662D05A4FDAF4B40
40551	1331	65.313018999999997	65.319108999999997	55.441004	55.432766000000001	Зорге	0103000020E61000000100000005000000B401D880085450400E6954E064B74B40B401D88008545040DDB3AED172B84B40FEB627486C545040DDB3AED172B84B40FEB627486C5450400E6954E064B74B40B401D880085450400E6954E064B74B40
75659	1331	65.313018999999997	65.319108999999997	55.441004	55.432766000000001	Зорге	0103000020E61000000100000005000000B401D880085450400E6954E064B74B40B401D88008545040DDB3AED172B84B40FEB627486C545040DDB3AED172B84B40FEB627486C5450400E6954E064B74B40B401D880085450400E6954E064B74B40
40615	1331	65.325856000000002	65.366890999999995	55.46311	55.453038999999997	Дзержинского	0103000020E6100000010000000500000025CD1FD3DA5450400168942EFDB94B4025CD1FD3DA545040AC39403047BB4B40978C63247B575040AC39403047BB4B40978C63247B5750400168942EFDB94B4025CD1FD3DA5450400168942EFDB94B40
40344	1331	65.327624999999998	65.367384999999999	55.452798999999999	55.433537000000001	Гоголя	0103000020E610000001000000050000008716D9CEF7545040904DF2237EB74B408716D9CEF7545040AC545051F5B94B409F02603C83575040AC545051F5B94B409F02603C83575040904DF2237EB74B408716D9CEF7545040904DF2237EB74B40
40384	1331	65.327624999999998	65.367384999999999	55.452798999999999	55.433537000000001	Гоголя	0103000020E610000001000000050000008716D9CEF7545040904DF2237EB74B408716D9CEF7545040AC545051F5B94B409F02603C83575040AC545051F5B94B409F02603C83575040904DF2237EB74B408716D9CEF7545040904DF2237EB74B40
40395	1331	65.327624999999998	65.367384999999999	55.452798999999999	55.433537000000001	Гоголя	0103000020E610000001000000050000008716D9CEF7545040904DF2237EB74B408716D9CEF7545040AC545051F5B94B409F02603C83575040AC545051F5B94B409F02603C83575040904DF2237EB74B408716D9CEF7545040904DF2237EB74B40
40547	1331	65.236069000000001	65.242599999999996	55.404366000000003	55.398339	Глинки	0103000020E610000001000000050000005DA626C11B4F504055DCB8C5FCB24B405DA626C11B4F5040A3CEDC43C2B34B409D8026C2864F5040A3CEDC43C2B34B409D8026C2864F504055DCB8C5FCB24B405DA626C11B4F504055DCB8C5FCB24B40
40389	1331	65.290929000000006	65.304889000000003	55.426518000000002	55.421245999999996	Галкинская	0103000020E61000000100000005000000501DAB949E52504010C99063EBB54B40501DAB949E525040E2934E2498B64B4040FA264D83535040E2934E2498B64B4040FA264D8353504010C99063EBB54B40501DAB949E52504010C99063EBB54B40
75876	1331	65.374804999999995	65.389385000000004	55.455902999999999	55.447994000000001	Гайдара	0103000020E6100000010000000500000025581CCEFC575040F1660DDE57B94B4025581CCEFC575040FB928D075BBA4B40642310AFEB585040FB928D075BBA4B40642310AFEB585040F1660DDE57B94B4025581CCEFC575040F1660DDE57B94B40
40533	1331	65.386600000000001	65.418436	55.463498000000001	55.447147000000001	Гагарина	0103000020E610000001000000050000008D28ED0DBE58504094C0E61C3CB94B408D28ED0DBE58504076E107E753BB4B4005DEC9A7C75A504076E107E753BB4B4005DEC9A7C75A504094C0E61C3CB94B408D28ED0DBE58504094C0E61C3CB94B40
40528	1331	65.386600000000001	65.418436	55.463498000000001	55.447147000000001	Гагарина	0103000020E610000001000000050000008D28ED0DBE58504094C0E61C3CB94B408D28ED0DBE58504076E107E753BB4B4005DEC9A7C75A504076E107E753BB4B4005DEC9A7C75A504094C0E61C3CB94B408D28ED0DBE58504094C0E61C3CB94B40
75707	1331	65.320547000000005	65.326592000000005	55.436571000000001	55.433818000000002	Васильева	0103000020E610000001000000050000002E7590D7835450404435255987B74B402E7590D783545040E6B0FB8EE1B74B40A8C821E2E6545040E6B0FB8EE1B74B40A8C821E2E65450404435255987B74B402E7590D7835450404435255987B74B40
75661	1331	65.320547000000005	65.326592000000005	55.436571000000001	55.433818000000002	Васильева	0103000020E610000001000000050000002E7590D7835450404435255987B74B402E7590D783545040E6B0FB8EE1B74B40A8C821E2E6545040E6B0FB8EE1B74B40A8C821E2E65450404435255987B74B402E7590D7835450404435255987B74B40
40712	1331	65.376090000000005	65.395178999999999	55.463369999999998	55.451996999999999	Бородина	0103000020E610000001000000050000009296CADB11585040EF71A609DBB94B409296CADB1158504048F949B54FBB4B403944DC9C4A59504048F949B54FBB4B403944DC9C4A595040EF71A609DBB94B409296CADB11585040EF71A609DBB94B40
75701	1331	65.272568000000007	65.302823000000004	55.428117	55.422651000000002	Бажова	0103000020E61000000100000005000000EA7B0DC171515040944F8F6D19B64B40EA7B0DC1715150404AEEB089CCB64B40815EB873615350404AEEB089CCB64B40815EB87361535040944F8F6D19B64B40EA7B0DC171515040944F8F6D19B64B40
75672	1331	65.308204000000003	65.337425999999994	55.494593999999999	55.486213999999997	Анфиногенова	0103000020E61000000100000005000000C51F459DB9535040BD6DA6423CBE4B40C51F459DB95350401F662FDB4EBF4B407CB43863985550401F662FDB4EBF4B407CB4386398555040BD6DA6423CBE4B40C51F459DB9535040BD6DA6423CBE4B40
40541	1331	65.249202999999994	65.260935000000003	55.473770999999999	55.470182999999999	Алексеева	0103000020E610000001000000050000002AC423F1F24F50404D11E0F42EBC4B402AC423F1F24F504088653387A4BC4B406FD8B628B350504088653387A4BC4B406FD8B628B35050404D11E0F42EBC4B402AC423F1F24F50404D11E0F42EBC4B40
40540	1331	65.117329999999995	65.669937000000004	55.533313	55.290469999999999	9 Мая	0103000020E61000000100000005000000BD35B055824750400C3CF71E2EA54B40BD35B055824750400DC4B29943C44B405858703FE06A50400DC4B29943C44B405858703FE06A50400C3CF71E2EA54B40BD35B055824750400C3CF71E2EA54B40
40379	1331	65.277517000000003	65.291522000000001	55.472662999999997	55.463692000000002	6-й микрорайон	0103000020E6100000010000000500000061C5A9D6C25150405BB56B425ABB4B4061C5A9D6C2515040BE839F3880BC4B402104E44BA8525040BE839F3880BC4B402104E44BA85250405BB56B425ABB4B4061C5A9D6C25150405BB56B425ABB4B40
41427	1331	65.277517000000003	65.291522000000001	55.472662999999997	55.463692000000002	6-й микрорайон	0103000020E6100000010000000500000061C5A9D6C25150405BB56B425ABB4B4061C5A9D6C2515040BE839F3880BC4B402104E44BA8525040BE839F3880BC4B402104E44BA85250405BB56B425ABB4B4061C5A9D6C25150405BB56B425ABB4B40
75691	1331	65.277517000000003	65.291522000000001	55.472662999999997	55.463692000000002	6 микрорайон	0103000020E6100000010000000500000061C5A9D6C25150405BB56B425ABB4B4061C5A9D6C2515040BE839F3880BC4B402104E44BA8525040BE839F3880BC4B402104E44BA85250405BB56B425ABB4B4061C5A9D6C25150405BB56B425ABB4B40
75619	1331	65.266728999999998	65.281649999999999	55.468259000000003	55.460327999999997	5-й микрорайон	0103000020E6100000010000000500000044F98216125150406FB72407ECBA4B4044F9821612515040628731E9EFBB4B40C7BAB88D06525040628731E9EFBB4B40C7BAB88D065250406FB72407ECBA4B4044F98216125150406FB72407ECBA4B40
40377	1331	65.266728999999998	65.281649999999999	55.468259000000003	55.460327999999997	5-й микрорайон	0103000020E6100000010000000500000044F98216125150406FB72407ECBA4B4044F9821612515040628731E9EFBB4B40C7BAB88D06525040628731E9EFBB4B40C7BAB88D065250406FB72407ECBA4B4044F98216125150406FB72407ECBA4B40
75686	1331	65.253091999999995	65.270797999999999	55.464947000000002	55.455081	3-й микрорайон	0103000020E6100000010000000500000045B8C9A832505040F7031E1840BA4B4045B8C9A832505040C9AF1F6283BB4B409F7422C154515040C9AF1F6283BB4B409F7422C154515040F7031E1840BA4B4045B8C9A832505040F7031E1840BA4B40
40378	1331	65.253091999999995	65.270797999999999	55.464947000000002	55.455081	3-й микрорайон	0103000020E6100000010000000500000045B8C9A832505040F7031E1840BA4B4045B8C9A832505040C9AF1F6283BB4B409F7422C154515040C9AF1F6283BB4B409F7422C154515040F7031E1840BA4B4045B8C9A832505040F7031E1840BA4B40
40543	1331	65.253091999999995	65.270797999999999	55.464947000000002	55.455081	3-й микрорайон	0103000020E6100000010000000500000045B8C9A832505040F7031E1840BA4B4045B8C9A832505040C9AF1F6283BB4B409F7422C154515040C9AF1F6283BB4B409F7422C154515040F7031E1840BA4B4045B8C9A832505040F7031E1840BA4B40
75668	1331	65.241332999999997	65.262901999999997	55.479194	55.465406999999999	1-й микрорайон	0103000020E61000000100000005000000849CF7FF714F50402C2AE27492BB4B40849CF7FF714F50403F389F3A56BD4B406403E962D35050403F389F3A56BD4B406403E962D35050402C2AE27492BB4B40849CF7FF714F50402C2AE27492BB4B40
40368	1331	65.241332999999997	65.262901999999997	55.479194	55.465406999999999	1-й микрорайон	0103000020E61000000100000005000000849CF7FF714F50402C2AE27492BB4B40849CF7FF714F50403F389F3A56BD4B406403E962D35050403F389F3A56BD4B406403E962D35050402C2AE27492BB4B40849CF7FF714F50402C2AE27492BB4B40
40522	1331	65.241332999999997	65.262901999999997	55.479194	55.465406999999999	1-й микрорайон	0103000020E61000000100000005000000849CF7FF714F50402C2AE27492BB4B40849CF7FF714F50403F389F3A56BD4B406403E962D35050403F389F3A56BD4B406403E962D35050402C2AE27492BB4B40849CF7FF714F50402C2AE27492BB4B40
40651	1331	65.117329999999995	65.669937000000004	55.533313	55.290469999999999	1 Мая	0103000020E61000000100000005000000BD35B055824750400C3CF71E2EA54B40BD35B055824750400DC4B29943C44B405858703FE06A50400DC4B29943C44B405858703FE06A50400C3CF71E2EA54B40BD35B055824750400C3CF71E2EA54B40
41417	55024	65.309218999999999	65.315166000000005	55.504322999999999	55.485010000000003	Карбышева	0103000020E6100000010000000500000051137D3ECA535040D21DC4CE14BE4B4051137D3ECA53504070CFF3A78DC04B40EAB303AE2B54504070CFF3A78DC04B40EAB303AE2B545040D21DC4CE14BE4B4051137D3ECA535040D21DC4CE14BE4B40
40763	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Советская	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40856	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Островского	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40859	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Маяковского	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40579	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Матросова	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40577	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Ленина	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
41004	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Красноармейская	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
41398	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Комарова	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40962	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Гагарина	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40968	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	Боровая	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40787	54936	62.518396000000003	62.622430000000001	56.314197	56.268436000000001	30 лет Победы	0103000020E610000001000000050000004930D5CC5A424F40D788601C5C224C404930D5CC5A424F402BC0779B37284C404F0647C9AB4F4F402BC0779B37284C404F0647C9AB4F4F40D788601C5C224C404930D5CC5A424F40D788601C5C224C40
40957	54987	64.198228	64.225896000000006	55.871232999999997	55.856022000000003	Пушкина 	0103000020E61000000100000005000000B2497EC4AF0C50400954FF2092ED4B40B2497EC4AF0C504015191D9084EF4B4006137F14750E504015191D9084EF4B4006137F14750E50400954FF2092ED4B40B2497EC4AF0C50400954FF2092ED4B40
40963	54987	64.198228	64.225896000000006	55.871232999999997	55.856022000000003	Новая	0103000020E61000000100000005000000B2497EC4AF0C50400954FF2092ED4B40B2497EC4AF0C504015191D9084EF4B4006137F14750E504015191D9084EF4B4006137F14750E50400954FF2092ED4B40B2497EC4AF0C50400954FF2092ED4B40
40570	54933	62.890999000000001	62.975772999999997	56.278582999999998	56.248226000000003	Советская	0103000020E6100000010000000500000065E256410C724F402A029CDEC51F4C4065E256410C724F405C1C959BA8234C40EFA83121E67C4F405C1C959BA8234C40EFA83121E67C4F402A029CDEC51F4C4065E256410C724F402A029CDEC51F4C40
41320	54933	62.890999000000001	62.975772999999997	56.278582999999998	56.248226000000003	Гагарина	0103000020E6100000010000000500000065E256410C724F402A029CDEC51F4C4065E256410C724F405C1C959BA8234C40EFA83121E67C4F405C1C959BA8234C40EFA83121E67C4F402A029CDEC51F4C4065E256410C724F402A029CDEC51F4C40
41116	54933	62.890999000000001	62.975772999999997	56.278582999999998	56.248226000000003	8 Марта	0103000020E6100000010000000500000065E256410C724F402A029CDEC51F4C4065E256410C724F405C1C959BA8234C40EFA83121E67C4F405C1C959BA8234C40EFA83121E67C4F402A029CDEC51F4C4065E256410C724F402A029CDEC51F4C40
40661	54933	62.890999000000001	62.975772999999997	56.278582999999998	56.248226000000003	4-го Уральского полка	0103000020E6100000010000000500000065E256410C724F402A029CDEC51F4C4065E256410C724F405C1C959BA8234C40EFA83121E67C4F405C1C959BA8234C40EFA83121E67C4F402A029CDEC51F4C4065E256410C724F402A029CDEC51F4C40
40744	54961	65.092680000000001	65.151680999999996	55.437055999999998	55.424255000000002	Ленина	0103000020E61000000100000005000000923F1878EE4550400E15E3FC4DB64B40923F1878EE455040A2427573F1B74B402C9B3924B5495040A2427573F1B74B402C9B3924B54950400E15E3FC4DB64B40923F1878EE4550400E15E3FC4DB64B40
40748	52056	65.390992999999995	65.395995999999997	55.515039000000002	55.509635000000003	Лесная	0103000020E61000000100000005000000C1FD800706595040D0F23CB83BC14B40C1FD800706595040109546CCECC14B4032569BFF57595040109546CCECC14B4032569BFF57595040D0F23CB83BC14B40C1FD800706595040D0F23CB83BC14B40
75884	12223	64.507058999999998	64.541877999999997	55.285271000000002	55.271759000000003	Советская	0103000020E610000001000000050000001E8997A77320504064B2B8FFC8A24B401E8997A773205040A5BF97C283A44B40001B1021AE225040A5BF97C283A44B40001B1021AE22504064B2B8FFC8A24B401E8997A77320504064B2B8FFC8A24B40
40840	54976	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Труда	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
40924	54976	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Свободы	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
41105	54976	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Мичурина	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
41056	54976	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Мира	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
41031	54976	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Ленина	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
40917	54976	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Блюхера	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
41066	10234	64.424980000000005	64.490953000000005	55.387239000000001	55.360474000000004	Линейная	0103000020E61000000100000005000000105D50DF321B50407787140324AE4B40105D50DF321B50402D5E2C0C91B14B40E1B721C66B1F50402D5E2C0C91B14B40E1B721C66B1F50407787140324AE4B40105D50DF321B50407787140324AE4B40
41610	12472	64.283011000000002	64.302603000000005	55.575943000000002	55.564602000000001	Центральная	0103000020E61000000100000005000000215A2BDA1C125040CBA0DAE044C84B40215A2BDA1C12504019AE0E80B8C94B40FA2AF9D85D13504019AE0E80B8C94B40FA2AF9D85D135040CBA0DAE044C84B40215A2BDA1C125040CBA0DAE044C84B40
41268	13056	64.634225000000001	64.656323	55.482484999999997	55.467509	Школьная	0103000020E610000001000000050000008F53742497285040F7CABC55D7BB4B408F53742497285040C0E78711C2BD4B4035272F32012A5040C0E78711C2BD4B4035272F32012A5040F7CABC55D7BB4B408F53742497285040F7CABC55D7BB4B40
41264	12959	64.182937999999993	64.222464000000002	55.610168000000002	55.604188000000001	Центральная	0103000020E6100000010000000500000085CC9541B50B50405D514A0856CD4B4085CC9541B50B50406A882AFC19CE4B406422A5D93C0E50406A882AFC19CE4B406422A5D93C0E50405D514A0856CD4B4085CC9541B50B50405D514A0856CD4B40
41261	12895	64.310122000000007	64.328699	55.207048	55.195127999999997	Центральная	0103000020E610000001000000050000004AF1F109D913504056444DF4F9984B404AF1F109D9135040E259828C809A4B4096CE876709155040E259828C809A4B4096CE87670915504056444DF4F9984B404AF1F109D913504056444DF4F9984B40
41072	12878	64.307543999999993	64.335688000000005	55.161296	55.152439000000001	Школьная	0103000020E610000001000000050000002F8507CDAE13504046D1031F83934B402F8507CDAE135040E17CEA58A5944B40386A85E97B155040E17CEA58A5944B40386A85E97B15504046D1031F83934B402F8507CDAE13504046D1031F83934B40
41266	12173	64.219139999999996	64.233540000000005	55.493654999999997	55.486795000000001	2я Деревенская	0103000020E61000000100000005000000B54FC763060E50409C6D6E4C4FBE4B40B54FC763060E5040E140481630BF4B40B493C151F20E5040E140481630BF4B40B493C151F20E50409C6D6E4C4FBE4B40B54FC763060E50409C6D6E4C4FBE4B40
41254	12599	64.447536999999997	64.459089000000006	55.343890999999999	55.336087999999997	Центральная	0103000020E61000000100000005000000FFAF3A72A41C5040FD497CEE04AB4B40FFAF3A72A41C5040C231CB9E04AC4B40043DD4B6611D5040C231CB9E04AC4B40043DD4B6611D5040FD497CEE04AB4B40FFAF3A72A41C5040FD497CEE04AB4B40
41455	12977	64.116812999999993	64.134626999999995	55.651201	55.641508000000002	Набережная	0103000020E61000000100000005000000D9AF3BDD79075040AA0F24EF1CD24B40D9AF3BDD79075040AE0FEB8D5AD34B40268A90BA9D085040AE0FEB8D5AD34B40268A90BA9D085040AA0F24EF1CD24B40D9AF3BDD79075040AA0F24EF1CD24B40
9769	12565	64.369617000000005	64.389757000000003	55.297918000000003	55.282173999999998	Береговая	0103000020E61000000100000005000000ECC20FCEA717504008E412471EA44B40ECC20FCEA7175040E371512D22A64B40C61858C7F1185040E371512D22A64B40C61858C7F118504008E412471EA44B40ECC20FCEA717504008E412471EA44B40
41464	12819	64.229776000000001	64.250698	55.195663000000003	55.185794999999999	Центральная	0103000020E61000000100000005000000F75965A6B40E504052616C21C8974B40F75965A6B40E5040C504357C0B994B400CCB9F6F0B105040C504357C0B994B400CCB9F6F0B10504052616C21C8974B40F75965A6B40E504052616C21C8974B40
41519	12265	64.612449999999995	64.636111	55.173338999999999	55.167616000000002	Победа	0103000020E61000000100000005000000DA1B7C6132275040A724EB7074954B40DA1B7C6132275040880FECF82F964B400E68E90AB6285040880FECF82F964B400E68E90AB6285040A724EB7074954B40DA1B7C6132275040A724EB7074954B40
41309	11995	64.497636	64.506529	55.078854	55.068179999999998	Клиновая	0103000020E61000000100000005000000FC53AA44D91F5040E21E4B1FBA884B40FC53AA44D91F504053944BE3178A4B40705E9CF86A20504053944BE3178A4B40705E9CF86A205040E21E4B1FBA884B40FC53AA44D91F5040E21E4B1FBA884B40
40702	54954	64.486102000000002	64.506619000000001	55.339094000000003	55.330762999999997	Ленина	0103000020E610000001000000050000004B21904B1C1F504009DD257156AA4B404B21904B1C1F50408A22A46E67AB4B40102219726C2050408A22A46E67AB4B40102219726C20504009DD257156AA4B404B21904B1C1F504009DD257156AA4B40
41457	13109	64.760626999999999	64.785330000000002	55.432464000000003	55.428322000000001	Центральная	0103000020E61000000100000005000000185DDE1CAE30504023145B41D3B64B40185DDE1CAE3050404359F8FA5AB74B4055A4C2D8423250404359F8FA5AB74B4055A4C2D84232504023145B41D3B64B40185DDE1CAE30504023145B41D3B64B40
41505	13474	64.414901	64.420201000000006	55.362428999999999	55.358733999999998	Заводская	0103000020E61000000100000005000000F984ECBC8D1A50404CFBE6FEEAAD4B40F984ECBC8D1A50409D0FCF1264AE4B40C72FBC92E41A50409D0FCF1264AE4B40C72FBC92E41A50404CFBE6FEEAAD4B40F984ECBC8D1A50404CFBE6FEEAAD4B40
40943	12683	64.407929999999993	64.424880999999999	55.429844000000003	55.420121999999999	Школьная	0103000020E61000000100000005000000AA436E861B1A5040412AC58EC6B54B40AA436E861B1A5040E030D12005B74B4046EC1340311B5040E030D12005B74B4046EC1340311B5040412AC58EC6B54B40AA436E861B1A5040412AC58EC6B54B40
41453	12422	64.305316000000005	64.320640999999995	55.677442999999997	55.668666000000002	Верхняя	0103000020E6100000010000000500000084BC1E4C8A1350403CF9F4D896D54B4084BC1E4C8A135040BAF3C473B6D64B406E30D46185145040BAF3C473B6D64B406E30D461851450403CF9F4D896D54B4084BC1E4C8A1350403CF9F4D896D54B40
41070	12490	64.394994999999994	64.435463999999996	55.305050999999999	55.291003000000003	Ленина	0103000020E6100000010000000500000058C51B9947195040DA0418963FA54B4058C51B9947195040594E42E90BA74B4076A565A4DE1B5040594E42E90BA74B4076A565A4DE1B5040DA0418963FA54B4058C51B9947195040DA0418963FA54B40
41069	12321	64.318439999999995	64.342963999999995	55.565263999999999	55.553279000000003	Маюрова	0103000020E610000001000000050000003F6F2A52611450402448A5D8D1C64B403F6F2A526114504096CD1C925AC84B4024ED461FF315504096CD1C925AC84B4024ED461FF31550402448A5D8D1C64B403F6F2A52611450402448A5D8D1C64B40
40997	12132	64.166589000000002	64.196961000000002	55.450277	55.421112999999998	Советская	0103000020E61000000100000005000000E5B7E864A90A5040D175E107E7B54B40E5B7E864A90A50400C923EADA2B94B4099654F029B0C50400C923EADA2B94B4099654F029B0C5040D175E107E7B54B40E5B7E864A90A5040D175E107E7B54B40
41256	13137	64.733614000000003	64.774066000000005	55.403446000000002	55.389581	Центральная	0103000020E61000000100000005000000D1782288F32E50404D124BCADDB14B40D1782288F32E5040DCD9571EA4B34B4084BC1E4C8A315040DCD9571EA4B34B4084BC1E4C8A3150404D124BCADDB14B40D1782288F32E50404D124BCADDB14B40
41531	12090	64.657482000000002	64.664479999999998	55.246701999999999	55.239584000000001	Степная	0103000020E610000001000000050000005BED612F142A50408B5242B0AA9E4B405BED612F142A5040CCED5EEE939F4B4026361FD7862A5040CCED5EEE939F4B4026361FD7862A50408B5242B0AA9E4B405BED612F142A50408B5242B0AA9E4B40
41612	12722	64.596288999999999	64.608542	55.564816	55.560606	Школьная	0103000020E61000000100000005000000BB7D5699292650407FF8F9EFC1C74B40BB7D569929265040F72004E44BC84B40840F255AF2265040F72004E44BC84B40840F255AF22650407FF8F9EFC1C74B40BB7D5699292650407FF8F9EFC1C74B40
40491	54926	64.613788	64.648122000000001	55.275888000000002	55.264296000000002	Школьная	0103000020E6100000010000000500000058AB764D48275040583B8A73D4A14B4058AB764D48275040EFAD484C50A34B405C74B2D47A295040EFAD484C50A34B405C74B2D47A295040583B8A73D4A14B4058AB764D48275040583B8A73D4A14B40
41257	11943	64.484530000000007	64.527360999999999	55.130409999999998	55.117319000000002	Молодёжная	0103000020E6100000010000000500000094FB1D8A021F504087191A4F048F4B4094FB1D8A021F504022895E46B1904B40E50B5A48C021504022895E46B1904B40E50B5A48C021504087191A4F048F4B4094FB1D8A021F504087191A4F048F4B40
41258	12787	64.584135000000003	64.597213999999994	55.587722999999997	55.579185000000003	Баранова	0103000020E61000000100000005000000BC5CC47762255040B9AAECBB22CA4B40BC5CC47762255040B20DDC813ACB4B40A7AD11C138265040B20DDC813ACB4B40A7AD11C138265040B9AAECBB22CA4B40BC5CC47762255040B9AAECBB22CA4B40
41606	11824	64.118475000000004	64.136927	55.550203000000003	55.535595000000001	Ленина	0103000020E6100000010000000500000031992A1895075040587380608EC44B4031992A18950750409F94490D6DC64B401FBC7669C30850409F94490D6DC64B401FBC7669C3085040587380608EC44B4031992A1895075040587380608EC44B40
41446	11637	62.618693	62.637557000000001	55.578766999999999	55.568313000000003	Центральная	0103000020E61000000100000005000000CFA10C55314F4F402272FA7ABEC84B40CFA10C55314F4F4084807C0915CA4B40FE2AC0779B514F4084807C0915CA4B40FE2AC0779B514F402272FA7ABEC84B40CFA10C55314F4F402272FA7ABEC84B40
41248	10855	62.262349	62.267209000000001	55.353898000000001	55.344208000000002	Солнечная	0103000020E61000000100000005000000B491EBA694214F40C382FB010FAC4B40B491EBA694214F40560F98874CAD4B4033198EE733224F40560F98874CAD4B4033198EE733224F40C382FB010FAC4B40B491EBA694214F40C382FB010FAC4B40
41255	11706	62.609278000000003	62.622312999999998	55.615943999999999	55.606440999999997	Быкова	0103000020E610000001000000050000000E164ED2FC4D4F400DFAD2DB9FCD4B400E164ED2FC4D4F406E15C440D7CE4B401570CFF3A74F4F406E15C440D7CE4B401570CFF3A74F4F400DFAD2DB9FCD4B400E164ED2FC4D4F400DFAD2DB9FCD4B40
41608	11798	62.816789	62.841375999999997	55.706435999999997	55.697944999999997	 А. Усова	0103000020E61000000100000005000000C45DBD8A8C684F400FB4024356D94B40C45DBD8A8C684F40C85BAE7E6CDA4B40D4D17135B26B4F40C85BAE7E6CDA4B40D4D17135B26B4F400FB4024356D94B40C45DBD8A8C684F400FB4024356D94B40
41448	11393	62.689318	62.717570000000002	55.476388	55.469836000000001	Озёрная	0103000020E61000000100000005000000A6457D923B584F40E23D079623BC4B40A6457D923B584F407A1A3048FABC4B409D4B7155D95B4F407A1A3048FABC4B409D4B7155D95B4F40E23D079623BC4B40A6457D923B584F40E23D079623BC4B40
41649	10999	62.360264999999998	62.387987000000003	55.269559000000001	55.254451000000003	Центральная	0103000020E610000001000000050000005C72DC291D2E4F409EB7B1D991A04B405C72DC291D2E4F40D6ABC8E880A24B40F722DA8EA9314F40D6ABC8E880A24B40F722DA8EA9314F409EB7B1D991A04B405C72DC291D2E4F409EB7B1D991A04B40
41443	10999	62.360264999999998	62.387987000000003	55.269559000000001	55.254451000000003	Станционная	0103000020E610000001000000050000005C72DC291D2E4F409EB7B1D991A04B405C72DC291D2E4F40D6ABC8E880A24B40F722DA8EA9314F40D6ABC8E880A24B40F722DA8EA9314F409EB7B1D991A04B405C72DC291D2E4F409EB7B1D991A04B40
41249	11220	62.499262000000002	62.517183000000003	55.272257000000003	55.263865000000003	Петрушино	0103000020E610000001000000050000005A1135D1E73F4F408FC70C54C6A14B405A1135D1E73F4F40B58D3F51D9A24B400A86730D33424F40B58D3F51D9A24B400A86730D33424F408FC70C54C6A14B405A1135D1E73F4F408FC70C54C6A14B40
41607	11306	62.792445000000001	62.812837000000002	55.37238	55.359538000000001	Чапаева	0103000020E610000001000000050000007A7077D66E654F40AAD5575705AE4B407A7077D66E654F409DD7D825AAAF4B4048FDF50A0B684F409DD7D825AAAF4B4048FDF50A0B684F40AAD5575705AE4B407A7077D66E654F40AAD5575705AE4B40
40996	54994	62.688088	62.733047999999997	55.707101000000002	55.668512999999997	Павших Борцов	0103000020E610000001000000050000009162804413584F40B5F97FD591D54B409162804413584F4005FC1A4982DA4B40F8325184D45D4F4005FC1A4982DA4B40F8325184D45D4F40B5F97FD591D54B409162804413584F40B5F97FD591D54B40
41603	11576	62.741052000000003	62.776518000000003	55.574497999999998	55.562244999999997	Советская	0103000020E610000001000000050000005551BCCADA5E4F4075ABE7A4F7C74B405551BCCADA5E4F4007CF842689C94B40AF601BF164634F4007CF842689C94B40AF601BF164634F4075ABE7A4F7C74B405551BCCADA5E4F4075ABE7A4F7C74B40
41445	11549	62.617713999999999	62.629814000000003	55.468071000000002	55.458516000000003	Никитинская	0103000020E6100000010000000500000003249A40114F4F40AC58FCA6B0BA4B4003249A40114F4F405F9A22C0E9BB4B400F48C2BE9D504F405F9A22C0E9BB4B400F48C2BE9D504F40AC58FCA6B0BA4B4003249A40114F4F40AC58FCA6B0BA4B40
41496	11492	62.485841000000001	62.507750999999999	55.445574000000001	55.431002999999997	Центральная	0103000020E610000001000000050000002907B309303E4F402BBD361B2BB74B402907B309303E4F4055F99E9108B94B4072C119FCFD404F4055F99E9108B94B4072C119FCFD404F402BBD361B2BB74B402907B309303E4F402BBD361B2BB74B40
41602	11252	62.427360999999998	62.443530000000003	55.32497	55.321446000000002	Центральная	0103000020E61000000100000005000000FD4AE7C3B3364F400BB77C2425A94B40FD4AE7C3B3364F402F17F19D98A94B40BF654E97C5384F402F17F19D98A94B40BF654E97C5384F400BB77C2425A94B40FD4AE7C3B3364F400BB77C2425A94B40
41253	10790	62.446773	62.475887999999998	55.337905999999997	55.330266000000002	Цветочная	0103000020E610000001000000050000002FDE8FDB2F394F40897D022846AA4B402FDE8FDB2F394F40A38FF98040AB4B408847E2E5E93C4F40A38FF98040AB4B408847E2E5E93C4F40897D022846AA4B402FDE8FDB2F394F40897D022846AA4B40
41648	10783	62.322958	62.341876999999997	55.330522000000002	55.320171000000002	Солнечная	0103000020E61000000100000005000000A4FD0FB056294F405610035DFBA84B40A4FD0FB056294F40E44D7E8B4EAA4B40962023A0C22B4F40E44D7E8B4EAA4B40962023A0C22B4F405610035DFBA84B40A4FD0FB056294F405610035DFBA84B40
40993	54992	62.220218000000003	62.260966000000003	55.212051000000002	55.200353999999997	Железнодорожная	0103000020E61000000100000005000000CAFE791A301C4F40B7CF2A33A5994B40CAFE791A301C4F40C40AB77C249B4B4019AF795567214F40C40AB77C249B4B4019AF795567214F40B7CF2A33A5994B40CAFE791A301C4F40B7CF2A33A5994B40
41743	55045	62.800530000000002	62.842427000000001	55.326844999999999	55.321829999999999	Береговая	0103000020E61000000100000005000000C3BB5CC477664F40936FB6B931A94B40C3BB5CC477664F4039EE940ED6A94B403A22DFA5D46B4F4039EE940ED6A94B403A22DFA5D46B4F40936FB6B931A94B40C3BB5CC477664F40936FB6B931A94B40
41251	10700	62.351739999999999	62.390647000000001	55.333368999999998	55.324376000000001	Ленина	0103000020E61000000100000005000000F758FAD0052D4F40BCCD1B2785A94B40F758FAD0052D4F400740DCD5ABAA4B40E8A38CB800324F400740DCD5ABAA4B40E8A38CB800324F40BCCD1B2785A94B40F758FAD0052D4F40BCCD1B2785A94B40
41444	11048	62.502854999999997	62.533496999999997	55.212082000000002	55.206384999999997	Привокзальная	0103000020E61000000100000005000000A6D0798D5D404F4046B1DCD26A9A4B40A6D0798D5D404F40FF08C380259B4B40CEC133A149444F40FF08C380259B4B40CEC133A149444F4046B1DCD26A9A4B40A6D0798D5D404F4046B1DCD26A9A4B40
41752	55049	63.480015000000002	63.491478000000001	55.319806999999997	55.313530999999998	Центральная	0103000020E61000000100000005000000734BAB2171BD4F401EA4A7C821A84B40734BAB2171BD4F4014048F6FEFA84B400C5A48C0E8BE4F4014048F6FEFA84B400C5A48C0E8BE4F401EA4A7C821A84B40734BAB2171BD4F401EA4A7C821A84B40
41247	9234	63.473539000000002	63.498485000000002	55.241878	55.234107000000002	Центральная	0103000020E61000000100000005000000B6300BED9CBC4F40E161DA37F79D4B40B6300BED9CBC4F409ACFB9DBF59E4B40F645425BCEBF4F409ACFB9DBF59E4B40F645425BCEBF4F40E161DA37F79D4B40B6300BED9CBC4F40E161DA37F79D4B40
41654	9125	63.338109000000003	63.356020999999998	55.188139	55.176445000000001	Агеева	0103000020E61000000100000005000000DCBDDC2747AB4F407845F0BF95964B40DCBDDC2747AB4F40130D52F014984B4038D89B1892AD4F40130D52F014984B4038D89B1892AD4F407845F0BF95964B40DCBDDC2747AB4F407845F0BF95964B40
41686	8260	63.405391999999999	63.425991000000003	55.574381000000002	55.555045999999997	Центральная	0103000020E61000000100000005000000AF0793E2E3B34F4047E350BF0BC74B40AF0793E2E3B34F40CE380D5185C94B40F7B182DF86B64F40CE380D5185C94B40F7B182DF86B64F4047E350BF0BC74B40AF0793E2E3B34F4047E350BF0BC74B40
41440	9007	63.122233999999999	63.167158999999998	55.077643000000002	55.063107000000002	Центральная	0103000020E61000000100000005000000C93A1C5DA58F4F400893E2E313884B40C93A1C5DA58F4F40B5E1B034F0894B40B41D537765954F40B5E1B034F0894B40B41D537765954F400893E2E313884B40C93A1C5DA58F4F400893E2E313884B40
40825	8342	62.995204000000001	63.014139999999998	55.491722000000003	55.478831999999997	Советская	0103000020E61000000100000005000000986C3CD8627F4F409E23F25D4ABD4B40986C3CD8627F4F40A35C1ABFF0BE4B4060C8EA56CF814F40A35C1ABFF0BE4B4060C8EA56CF814F409E23F25D4ABD4B40986C3CD8627F4F409E23F25D4ABD4B40
41647	9088	63.334417000000002	63.357664999999997	55.108761000000001	55.094028999999999	Старая	0103000020E61000000100000005000000FC1C1F2DCEAA4F4013F06B24098C4B40FC1C1F2DCEAA4F40460A65E1EB8D4B4040F67AF7C7AD4F40460A65E1EB8D4B4040F67AF7C7AD4F4013F06B24098C4B40FC1C1F2DCEAA4F4013F06B24098C4B40
40992	9028	63.382880999999998	63.422621999999997	55.127218999999997	55.104337000000001	Зеленовка	0103000020E6100000010000000500000040A19E3E02B14F40A26131EA5A8D4B4040A19E3E02B14F40043752B648904B40F9484A7A18B64F40043752B648904B40F9484A7A18B64F40A26131EA5A8D4B4040A19E3E02B14F40A26131EA5A8D4B40
41434	8033	62.957473999999998	62.973779	55.717633999999997	55.700820999999998	Первая	0103000020E6100000010000000500000099620E828E7A4F40CDACA580B4D94B4099620E828E7A4F40B33F506EDBDB4B400B444FCAA47C4F40B33F506EDBDB4B400B444FCAA47C4F40CDACA580B4D94B4099620E828E7A4F40CDACA580B4D94B40
41136	9163	63.611933000000001	63.635846000000001	55.192681999999998	55.165343	Центральная	0103000020E61000000100000005000000ED2B0FD253CE4F40AFCF9CF529954B40ED2B0FD253CE4F409143C4CDA9984B406EA5D76663D14F409143C4CDA9984B406EA5D76663D14F40AFCF9CF529954B40ED2B0FD253CE4F40AFCF9CF529954B40
41590	8107	62.857663000000002	62.880372000000001	55.654649999999997	55.644821	Центральная	0103000020E61000000100000005000000A0FEB3E6C76D4F401363997E89D24B40A0FEB3E6C76D4F40C7293A92CBD34B4035289A07B0704F40C7293A92CBD34B4035289A07B0704F401363997E89D24B40A0FEB3E6C76D4F401363997E89D24B40
41318	8718	63.316360000000003	63.328290000000003	55.521352999999998	55.512183999999998	Центральная	0103000020E610000001000000050000009CE1067C7EA84F4069C4CC3E8FC14B409CE1067C7EA84F40F355F2B1BBC24B404BCD1E6805AA4F40F355F2B1BBC24B404BCD1E6805AA4F4069C4CC3E8FC14B409CE1067C7EA84F4069C4CC3E8FC14B40
41643	8938	63.214770000000001	63.237416000000003	55.207890999999996	55.193339999999999	Центральная	0103000020E61000000100000005000000BA1457957D9B4F401B81785DBF984B40BA1457957D9B4F40FD101B2C9C9A4B4009C6C1A5639E4F40FD101B2C9C9A4B4009C6C1A5639E4F401B81785DBF984B40BA1457957D9B4F401B81785DBF984B40
41599	9205	63.397576999999998	63.416657000000001	55.312055999999998	55.297718000000003	Советская	0103000020E6100000010000000500000026529ACDE3B24F401CB7989F1BA64B4026529ACDE3B24F40A2427573F1A74B4022533E0455B54F40A2427573F1A74B4022533E0455B54F401CB7989F1BA64B4026529ACDE3B24F401CB7989F1BA64B40
41316	8283	63.414617999999997	63.434669	55.638947999999999	55.631407000000003	Центральная	0103000020E610000001000000050000009D2ADF3312B54F4095BBCFF1D1D04B409D2ADF3312B54F401CEC4D0CC9D14B40E2CAD93BA3B74F401CEC4D0CC9D14B40E2CAD93BA3B74F4095BBCFF1D1D04B409D2ADF3312B54F4095BBCFF1D1D04B40
41065	8568	63.247864	63.291108999999999	55.402613000000002	55.388081999999997	Центральная	0103000020E6100000010000000500000089EDEE01BA9F4F404815C5ABACB14B4089EDEE01BA9F4F40E4F8A1D288B34B401F49490F43A54F40E4F8A1D288B34B401F49490F43A54F404815C5ABACB14B4089EDEE01BA9F4F404815C5ABACB14B40
41436	8640	63.223367000000003	63.239986000000002	55.438082999999999	55.428086999999998	Рабочая	0103000020E61000000100000005000000B900344A979C4F40DF6B088ECBB64B40B900344A979C4F407FF78E1A13B84B40BABF7ADCB79E4F407FF78E1A13B84B40BABF7ADCB79E4F40DF6B088ECBB64B40B900344A979C4F40DF6B088ECBB64B40
41642	8676	63.254601000000001	63.272460000000002	55.498601999999998	55.489254000000003	Озерная	0103000020E61000000100000005000000B343FCC396A04F40F6B704E09FBE4B40B343FCC396A04F402FDCB930D2BF4B40EDBB22F8DFA24F402FDCB930D2BF4B40EDBB22F8DFA24F40F6B704E09FBE4B40B343FCC396A04F40F6B704E09FBE4B40
41600	8472	63.073573000000003	63.093677	55.311728000000002	55.300516000000002	Шиловская	0103000020E610000001000000050000002F6F0ED76A894F405EF6EB4E77A64B402F6F0ED76A894F40AE9FFEB3E6A74B4096B1A19BFD8B4F40AE9FFEB3E6A74B4096B1A19BFD8B4F405EF6EB4E77A64B402F6F0ED76A894F405EF6EB4E77A64B40
40989	8411	63.198276999999997	63.227454000000002	55.402147999999997	55.393697000000003	Центральная	0103000020E610000001000000050000004546072461994F4044C4CDA964B24B404546072461994F406E13EE9579B34B4015AC71361D9D4F406E13EE9579B34B4015AC71361D9D4F4044C4CDA964B24B404546072461994F4044C4CDA964B24B40
41597	8786	63.185305	63.202966000000004	55.233603000000002	55.219509000000002	Набережная	0103000020E6100000010000000500000084640113B8974F40BE16F4DE189C4B4084640113B8974F40AE9FFEB3E69D4B40981936CAFA994F40AE9FFEB3E69D4B40981936CAFA994F40BE16F4DE189C4B4084640113B8974F40BE16F4DE189C4B40
41645	8767	63.198797999999996	63.234496999999998	55.270457	55.251603000000003	Парковое кольцо	0103000020E610000001000000050000004E417E3672994F40AA49F08634A04B404E417E3672994F40B5FCC0559EA24B404B0169FF039E4F40B5FCC0559EA24B404B0169FF039E4F40AA49F08634A04B404E417E3672994F40AA49F08634A04B40
41601	8519	63.000745999999999	63.025675	55.351241999999999	55.343885999999998	Длинная	0103000020E6100000010000000500000029CDE67118804F40B0C6D97404AC4B4029CDE67118804F40A67D737FF5AC4B4093A9825149834F40A67D737FF5AC4B4093A9825149834F40B0C6D97404AC4B4029CDE67118804F40B0C6D97404AC4B40
40991	8100	62.919260000000001	62.951725000000003	55.602891	55.587086999999997	Калинина	0103000020E61000000100000005000000AF42CA4FAA754F401074B4AA25CB4B40AF42CA4FAA754F40C00644882BCD4B408FE4F21FD2794F40C00644882BCD4B408FE4F21FD2794F401074B4AA25CB4B40AF42CA4FAA754F401074B4AA25CB4B40
41644	8422	63.212713000000001	63.252184999999997	55.390931000000002	55.383837999999997	Центральная	0103000020E610000001000000050000008F37F92D3A9B4F40247B849A21B14B408F37F92D3A9B4F400DFFE9060AB24B4058C51B9947A04F400DFFE9060AB24B4058C51B9947A04F40247B849A21B14B408F37F92D3A9B4F40247B849A21B14B40
41063	8183	63.199615000000001	63.260117000000001	55.598120999999999	55.576996000000001	Центральная	0103000020E610000001000000050000004165FCFB8C994F401FF64201DBC94B404165FCFB8C994F4081069B3A8FCC4B401B118C834BA14F4081069B3A8FCC4B401B118C834BA14F401FF64201DBC94B404165FCFB8C994F401FF64201DBC94B40
41437	8846	63.300730000000001	63.351601000000002	55.414056000000002	55.406951999999997	Молодежная	0103000020E610000001000000050000008A7615527EA64F405985CD0017B44B408A7615527EA64F40365B79C9FFB44B40D61EF64201AD4F40365B79C9FFB44B40D61EF64201AD4F405985CD0017B44B408A7615527EA64F405985CD0017B44B40
41438	8864	63.038663999999997	63.069153	55.186247000000002	55.172001999999999	Центральная	0103000020E610000001000000050000002AC423F1F2844F405D6C5A2904964B402AC423F1F2844F4033FD12F1D6974B40CCB56801DA884F4033FD12F1D6974B40CCB56801DA884F405D6C5A2904964B402AC423F1F2844F405D6C5A2904964B40
41595	7120	64.455864000000005	64.487386000000001	56.650210999999999	56.636704000000002	Школьная	0103000020E610000001000000050000001FDB32E02C1D5040BF9D44847F514C401FDB32E02C1D5040EE3F321D3A534C40CFA10C55311F5040EE3F321D3A534C40CFA10C55311F5040BF9D44847F514C401FDB32E02C1D5040BF9D44847F514C40
41604	7039	64.755758	64.778098999999997	56.502062000000002	56.492502999999999	Советская	0103000020E610000001000000050000002F6CCD565E30504048179B560A3F4C402F6CCD565E3050403D484F9143404C403883BF5FCC3150403D484F9143404C403883BF5FCC31504048179B560A3F4C402F6CCD565E30504048179B560A3F4C40
40810	54953	64.602594999999994	64.657185999999996	56.533620999999997	56.506413999999999	Элеваторная	0103000020E61000000100000005000000EB6E9EEA90265040471E882CD2404C40EB6E9EEA90265040BABA63B14D444C40E658DE550F2A5040BABA63B14D444C40E658DE550F2A5040471E882CD2404C40EB6E9EEA90265040471E882CD2404C40
40694	54953	64.602594999999994	64.657185999999996	56.533620999999997	56.506413999999999	Федосеева	0103000020E61000000100000005000000EB6E9EEA90265040471E882CD2404C40EB6E9EEA90265040BABA63B14D444C40E658DE550F2A5040BABA63B14D444C40E658DE550F2A5040471E882CD2404C40EB6E9EEA90265040471E882CD2404C40
40696	54953	64.602594999999994	64.657185999999996	56.533620999999997	56.506413999999999	30 лет Победы	0103000020E61000000100000005000000EB6E9EEA90265040471E882CD2404C40EB6E9EEA90265040BABA63B14D444C40E658DE550F2A5040BABA63B14D444C40E658DE550F2A5040471E882CD2404C40EB6E9EEA90265040471E882CD2404C40
41646	4576	64.814885000000004	64.831755000000001	56.382416999999997	56.373131000000001	Рабочая	0103000020E6100000010000000500000010406A1327345040D80FB1C1C22F4C4010406A13273450409B374E0AF3304C4035D252793B3550409B374E0AF3304C4035D252793B355040D80FB1C1C22F4C4010406A1327345040D80FB1C1C22F4C40
40907	6906	64.799972999999994	64.827146999999997	56.299655999999999	56.285069	А.И. Киселева	0103000020E61000000100000005000000B62BF4C1323350403D0D18247D244C40B62BF4C1323350406C06B8205B264C40027FF8F9EF3450406C06B8205B264C40027FF8F9EF3450403D0D18247D244C40B62BF4C1323350403D0D18247D244C40
41639	6833	64.634045	64.666141999999994	56.219512000000002	56.208874999999999	Мира	0103000020E610000001000000050000004FCC7A3194285040DBF97E6ABC1A4C404FCC7A31942850402F8A1EF8181C4C407D1F0E12A22A50402F8A1EF8181C4C407D1F0E12A22A5040DBF97E6ABC1A4C404FCC7A3194285040DBF97E6ABC1A4C40
41638	6758	64.594662999999997	64.612243000000007	56.204514000000003	56.193382	Велесова	0103000020E610000001000000050000000A4966F50E2650404AD1CABDC0184C400A4966F50E2650407EC9C6832D1A4C401E8D43FD2E2750407EC9C6832D1A4C401E8D43FD2E2750404AD1CABDC0184C400A4966F50E2650404AD1CABDC0184C40
41169	16685	64.454633999999999	64.475168999999994	56.104717000000001	56.098450999999997	Северная	0103000020E61000000100000005000000946934B9181D504016A1D80A9A0C4C40946934B9181D5040E92ADD5D670D4C40ACC43C2B691E5040E92ADD5D670D4C40ACC43C2B691E504016A1D80A9A0C4C40946934B9181D504016A1D80A9A0C4C40
41592	6735	64.682168000000004	64.704769999999996	56.225932999999998	56.220613999999998	Садовая	0103000020E610000001000000050000002D98F8A3A82B504016855D143D1C4C402D98F8A3A82B5040280B5F5FEB1C4C40EC4CA1F31A2D5040280B5F5FEB1C4C40EC4CA1F31A2D504016855D143D1C4C402D98F8A3A82B504016855D143D1C4C40
41061	6639	64.703430999999995	64.729707000000005	56.654313000000002	56.639575000000001	Школьная	0103000020E6100000010000000500000086FF7403052D50406B2BF697DD514C4086FF7403052D5040802C4487C0534C40632AFD84B32E5040802C4487C0534C40632AFD84B32E50406B2BF697DD514C4086FF7403052D50406B2BF697DD514C40
41637	5902	64.945616999999999	64.972863000000004	56.572270000000003	56.562618999999998	Центральная	0103000020E61000000100000005000000AA622AFD843C5040DA8D3EE603484C40AA622AFD843C5040B03DB32440494C40431F2C63433E5040B03DB32440494C40431F2C63433E5040DA8D3EE603484C40AA622AFD843C5040DA8D3EE603484C40
41433	7005	64.742255999999998	64.759710999999996	56.246955999999997	56.238667	Зеленая	0103000020E61000000100000005000000A0504F1F812F504035D1E7A38C1E4C40A0504F1F812F504086C613419C1F4C4055DAE21A9F30504086C613419C1F4C4055DAE21A9F30504035D1E7A38C1E4C40A0504F1F812F504035D1E7A38C1E4C40
41176	16755	64.488562999999999	64.504823000000002	56.117109999999997	56.105159	Центральная	0103000020E6100000010000000500000048C2BE9D441F5040A6F0A0D9750D4C4048C2BE9D441F50406C04E275FD0E4C4031D120054F2050406C04E275FD0E4C4031D120054F205040A6F0A0D9750D4C4048C2BE9D441F5040A6F0A0D9750D4C40
41244	6578	64.505694000000005	64.534287000000006	56.405802999999999	56.389543000000003	Центральная	0103000020E6100000010000000500000024F25D4A5D20504060B1868BDC314C4024F25D4A5D20504031CF4A5AF1334C4064EB19C23122504031CF4A5AF1334C4064EB19C23122504060B1868BDC314C4024F25D4A5D20504060B1868BDC314C40
40812	6543	64.988529	65.026428999999993	56.416904000000002	56.405858000000002	Школьная	0103000020E610000001000000050000007289230F443F5040F568AA27F3334C407289230F443F50402AC93A1C5D354C409FAA4203B14150402AC93A1C5D354C409FAA4203B1415040F568AA27F3334C407289230F443F5040F568AA27F3334C40
41542	54938	64.559314000000001	64.580163999999996	56.179726000000002	56.157913999999998	Мира	0103000020E610000001000000050000007A8CF2CCCB2350404FCAA48636144C407A8CF2CCCB235040D61EF64201174C4042942F6821255040D61EF64201174C4042942F68212550404FCAA48636144C407A8CF2CCCB2350404FCAA48636144C40
41428	54938	64.559314000000001	64.580163999999996	56.179726000000002	56.157913999999998	Ленина	0103000020E610000001000000050000007A8CF2CCCB2350404FCAA48636144C407A8CF2CCCB235040D61EF64201174C4042942F6821255040D61EF64201174C4042942F68212550404FCAA48636144C407A8CF2CCCB2350404FCAA48636144C40
40597	54938	64.559314000000001	64.580163999999996	56.179726000000002	56.157913999999998	Красных Уральцев	0103000020E610000001000000050000007A8CF2CCCB2350404FCAA48636144C407A8CF2CCCB235040D61EF64201174C4042942F6821255040D61EF64201174C4042942F68212550404FCAA48636144C407A8CF2CCCB2350404FCAA48636144C40
41636	6315	64.508343999999994	64.533199999999994	56.192158999999997	56.184044	И. Сташкова	0103000020E610000001000000050000008AC745B5882050403483F8C08E174C408AC745B588205040E75086AA98184C408A8EE4F21F225040E75086AA98184C408A8EE4F21F2250403483F8C08E174C408AC745B5882050403483F8C08E174C40
41593	55040	64.251219000000006	64.279641999999996	56.352293000000003	56.346437000000002	Центральная	0103000020E610000001000000050000009148DBF813105040EB8F300C582C4C409148DBF8131050400CCEE0EF172D4C40A2258FA7E51150400CCEE0EF172D4C40A2258FA7E5115040EB8F300C582C4C409148DBF813105040EB8F300C582C4C40
41246	55010	64.251219000000006	64.279641999999996	56.352293000000003	56.346437000000002	Газовик	0103000020E610000001000000050000009148DBF813105040EB8F300C582C4C409148DBF8131050400CCEE0EF172D4C40A2258FA7E51150400CCEE0EF172D4C40A2258FA7E5115040EB8F300C582C4C409148DBF813105040EB8F300C582C4C40
41699	6840	64.767354999999995	64.780631999999997	56.230677	56.222515000000001	Лесная	0103000020E61000000100000005000000035B25581C3150404AEF1B5F7B1C4C40035B25581C3150403E78EDD2861D4C40828DEBDFF53150403E78EDD2861D4C40828DEBDFF53150404AEF1B5F7B1C4C40035B25581C3150404AEF1B5F7B1C4C40
41242	6018	64.412807999999998	64.456394000000003	56.101880999999999	56.093032999999998	Центральная	0103000020E61000000100000005000000BDE13E726B1A504071395E81E80B4C40BDE13E726B1A5040B98AC56F0A0D4C40CD052E8F351D5040B98AC56F0A0D4C40CD052E8F351D504071395E81E80B4C40BDE13E726B1A504071395E81E80B4C40
41060	6003	64.861238	64.923545000000004	56.39038	56.379525999999998	Школьная	0103000020E61000000100000005000000A304FD851E375040A8FDD64E94304C40A304FD851E3750409981CAF8F7314C4099D87C5C1B3B50409981CAF8F7314C4099D87C5C1B3B5040A8FDD64E94304C40A304FD851E375040A8FDD64E94304C40
41588	6412	65.056999000000005	65.071416999999997	56.439492999999999	56.430678999999998	Береговая	0103000020E61000000100000005000000E73922DFA543504078094E7D20374C40E73922DFA543504014E97E4E41384C4038D89B189244504014E97E4E41384C4038D89B189244504078094E7D20374C40E73922DFA543504078094E7D20374C40
41432	5696	64.341607999999994	64.358343000000005	56.248866	56.239837999999999	Механизаторов	0103000020E610000001000000050000005303CDE7DC155040452BF702B31E4C405303CDE7DC1550400D8B51D7DA1F4C4009707A17EF1650400D8B51D7DA1F4C4009707A17EF165040452BF702B31E4C405303CDE7DC155040452BF702B31E4C40
41059	5934	64.779814999999999	64.805525000000003	56.364759999999997	56.345782999999997	Ленина	0103000020E61000000100000005000000897B2C7DE8315040A2410A9E422C4C40897B2C7DE8315040C971A774B02E4C4011C7BAB88D335040C971A774B02E4C4011C7BAB88D335040A2410A9E422C4C40897B2C7DE8315040A2410A9E422C4C40
41586	6672	64.644069999999999	64.665208000000007	56.690713000000002	56.675435	Свободная	0103000020E610000001000000050000006C9560713829504071C971A774564C406C9560713829504006F6984869584C40684293C4922A504006F6984869584C40684293C4922A504071C971A774564C406C9560713829504071C971A774564C40
40811	5784	64.859801000000004	64.894313999999994	56.599865000000001	56.585110999999998	Центральная	0103000020E610000001000000050000005C04C6FA06375040D2C3D0EAE44A4C405C04C6FA06375040ED815660C84C4C40B796C9703C395040ED815660C84C4C40B796C9703C395040D2C3D0EAE44A4C405C04C6FA06375040D2C3D0EAE44A4C40
41587	5716	64.524918	64.549683999999999	56.329087999999999	56.320283000000003	Школьная	0103000020E610000001000000050000003BC5AA41982150407E3B8908FF284C403BC5AA4198215040C6C03A8E1F2A4C409BC8CC052E235040C6C03A8E1F2A4C409BC8CC052E2350407E3B8908FF284C403BC5AA41982150407E3B8908FF284C40
41585	6461	65.075765000000004	65.087110999999993	56.395775999999998	56.385182999999998	Центральная	0103000020E610000001000000050000009D4B7155D9445040D2FC31AD4D314C409D4B7155D94450405645B8C9A8324C40CC07043A934550405645B8C9A8324C40CC07043A93455040D2FC31AD4D314C409D4B7155D9445040D2FC31AD4D314C40
41641	5823	64.924550999999994	64.948447000000002	56.588293	56.578606999999998	Центральная	0103000020E61000000100000005000000FB1EF5D72B3B50404B1E4FCB0F4A4C40FB1EF5D72B3B50409DBB5D2F4D4B4C4051BF0B5BB33C50409DBB5D2F4D4B4C4051BF0B5BB33C50404B1E4FCB0F4A4C40FB1EF5D72B3B50404B1E4FCB0F4A4C40
41589	5486	64.548480999999995	64.567982999999998	56.527470000000001	56.512444000000002	Центральная	0103000020E610000001000000050000008D5E0D501A2350400684D6C397414C408D5E0D501A23504081CF0F2384434C40C66B5ED55924504081CF0F2384434C40C66B5ED5592450400684D6C397414C408D5E0D501A2350400684D6C397414C40
41431	5605	64.459269000000006	64.486587	56.271256000000001	56.262697000000003	Заречная	0103000020E6100000010000000500000044C4CDA9641D5040F0E0270EA0214C4044C4CDA9641D5040016C4084B8224C4029EACC3D241F5040016C4084B8224C4029EACC3D241F5040F0E0270EA0214C4044C4CDA9641D5040F0E0270EA0214C40
41598	6943	64.754096000000004	64.766762	56.266846999999999	56.256037999999997	Пролетарская	0103000020E61000000100000005000000D882DE1B4330504041446ADAC5204C40D882DE1B433050409204E10A28224C403274ECA0123150409204E10A28224C403274ECA01231504041446ADAC5204C40D882DE1B4330504041446ADAC5204C40
40517	54928	64.835222999999999	64.867401000000001	56.284883999999998	56.264972	Поселковая	0103000020E610000001000000050000007D772B4B74355040882D3D9AEA214C407D772B4B74355040AB93331477244C4022E17B7F83375040AB93331477244C4022E17B7F83375040882D3D9AEA214C407D772B4B74355040882D3D9AEA214C40
40808	4618	64.355018999999999	64.375626999999994	56.104336000000004	56.093871999999998	Мира	0103000020E610000001000000050000005A9D9CA1B81650404B0169FF030C4C405A9D9CA1B8165040D2E5CDE15A0D4C40A71FD4450A185040D2E5CDE15A0D4C40A71FD4450A1850404B0169FF030C4C405A9D9CA1B81650404B0169FF030C4C40
41650	13687	63.855241999999997	63.870629999999998	56.028821999999998	56.021971000000001	Гусиная	0103000020E610000001000000050000003315E29178ED4F40EF3A1BF2CF024C403315E29178ED4F40E1B37570B0034C404F75C8CD70EF4F40E1B37570B0034C404F75C8CD70EF4F40EF3A1BF2CF024C403315E29178ED4F40EF3A1BF2CF024C40
40927	3621	63.912005999999998	63.933053999999998	56.019978000000002	56.012551000000002	Ленина	0103000020E61000000100000005000000BDE0D39CBCF44F401C446B459B014C40BDE0D39CBCF44F40DB519CA38E024C4074B33F506EF74F40DB519CA38E024C4074B33F506EF74F401C446B459B014C40BDE0D39CBCF44F401C446B459B014C40
41301	3541	63.807433000000003	63.825767999999997	56.017316999999998	56.009819	Советская	0103000020E61000000100000005000000085BECF659E74F4091F0BDBF41014C40085BECF659E74F401955867137024C40AA0A0DC4B2E94F401955867137024C40AA0A0DC4B2E94F4091F0BDBF41014C40085BECF659E74F4091F0BDBF41014C40
41492	2487	63.283248999999998	63.297486999999997	55.786074999999997	55.780926999999998	Кольцевая	0103000020E61000000100000005000000F6CFD38041A44F401DC87A6AF5E34B40F6CFD38041A44F40029A081B9EE44B4019FED30D14A64F40029A081B9EE44B4019FED30D14A64F401DC87A6AF5E34B40F6CFD38041A44F401DC87A6AF5E34B40
41421	4894	64.022733000000002	64.044723000000005	56.224342	56.217145000000002	Механизаторов	0103000020E610000001000000050000008FE21C7574015040B6BE4868CB1B4C408FE21C7574015040438F183DB71C4C404298DBBDDC025040438F183DB71C4C404298DBBDDC025040B6BE4868CB1B4C408FE21C7574015040B6BE4868CB1B4C40
41239	4719	64.252243000000007	64.266813999999997	56.162927000000003	56.150319000000003	Садовая	0103000020E6100000010000000500000047E9D2BF24105040D57B2AA73D134C4047E9D2BF241050405551BCCADA144C405B07077B131150405551BCCADA144C405B07077B13115040D57B2AA73D134C4047E9D2BF24105040D57B2AA73D134C40
41422	5041	63.708691000000002	63.725022000000003	56.401823	56.391306999999998	Советская	0103000020E610000001000000050000001AFCFD62B6DA4F4012D9075916324C401AFCFD62B6DA4F40EBE3A1EF6E334C40B5705985CDDC4F40EBE3A1EF6E334C40B5705985CDDC4F4012D9075916324C401AFCFD62B6DA4F4012D9075916324C40
40928	3760	63.366045999999997	63.391469000000001	56.136817999999998	56.130974000000002	Школьная	0103000020E61000000100000005000000726A6798DAAE4F402B508BC1C3104C40726A6798DAAE4F4087C0914083114C40EC32FCA71BB24F4087C0914083114C40EC32FCA71BB24F402B508BC1C3104C40726A6798DAAE4F402B508BC1C3104C40
41135	5157	63.620117	63.632451000000003	56.312455	56.301797999999998	Ленина	0103000020E61000000100000005000000C9586DFE5FCF4F40C5FF1D51A1264C40C9586DFE5FCF4F40603C8386FE274C4048A98427F4D04F40603C8386FE274C4048A98427F4D04F40C5FF1D51A1264C40C9586DFE5FCF4F40C5FF1D51A1264C40
41493	3732	64.014934999999994	64.053239000000005	56.045679	56.039475000000003	пер. Центральный	0103000020E610000001000000050000003524EEB1F40050403B014D840D054C403524EEB1F4005040978E39CFD8054C40CBF78C4468035040978E39CFD8054C40CBF78C44680350403B014D840D054C403524EEB1F40050403B014D840D054C40
41426	4681	64.291427999999996	64.308252999999993	56.124647000000003	56.118043999999998	Гизатуллина	0103000020E61000000100000005000000E048A0C1A612504098BED7101C0F4C40E048A0C1A6125040B345D26EF40F4C403579CA6ABA135040B345D26EF40F4C403579CA6ABA13504098BED7101C0F4C40E048A0C1A612504098BED7101C0F4C40
41504	2746	63.278308000000003	63.288234000000003	55.860787000000002	55.854945999999998	Зелёная	0103000020E610000001000000050000008B1BB7989FA34F404AECDADE6EED4B408B1BB7989FA34F4036E9B6442EEE4B4032CC09DAE4A44F4036E9B6442EEE4B4032CC09DAE4A44F404AECDADE6EED4B408B1BB7989FA34F404AECDADE6EED4B40
41651	13661	63.610298	63.620593	56.120215999999999	56.115769999999998	Садовая	0103000020E610000001000000050000003868AF3E1ECE4F40D0ED258DD10E4C403868AF3E1ECE4F405C3AE63C630F4C40329067976FCF4F405C3AE63C630F4C40329067976FCF4F40D0ED258DD10E4C403868AF3E1ECE4F40D0ED258DD10E4C40
41490	3304	63.330536000000002	63.368445000000001	56.008253000000003	55.995291999999999	Кирова	0103000020E610000001000000050000004913EF004FAA4F4037FC6EBA65FF4B404913EF004FAA4F40058C2E6F0E014C40F7AFAC3429AF4F40058C2E6F0E014C40F7AFAC3429AF4F4037FC6EBA65FF4B404913EF004FAA4F4037FC6EBA65FF4B40
40839	54973	63.702007000000002	63.751953	56.081471999999998	56.069012000000001	Северная	0103000020E610000001000000050000001348895DDBD94F400A849D62D5084C401348895DDBD94F4015C5ABAC6D0A4C408690F3FE3FE04F4015C5ABAC6D0A4C408690F3FE3FE04F400A849D62D5084C401348895DDBD94F400A849D62D5084C40
40818	54973	63.702007000000002	63.751953	56.081471999999998	56.069012000000001	Исетская	0103000020E610000001000000050000001348895DDBD94F400A849D62D5084C401348895DDBD94F4015C5ABAC6D0A4C408690F3FE3FE04F4015C5ABAC6D0A4C408690F3FE3FE04F400A849D62D5084C401348895DDBD94F400A849D62D5084C40
41672	2988	63.491182000000002	63.527554000000002	55.983434000000003	55.975440999999996	Рабочая	0103000020E610000001000000050000002331410DDFBE4F40B9162D40DBFC4B402331410DDFBE4F4022E3512AE1FD4B40DF6FB4E386C34F4022E3512AE1FD4B40DF6FB4E386C34F40B9162D40DBFC4B402331410DDFBE4F40B9162D40DBFC4B40
41131	2409	63.300747999999999	63.330733000000002	55.734541999999998	55.724514999999997	Рабочая	0103000020E61000000100000005000000302B14E97EA64F40103B53E8BCDC4B40302B14E97EA64F40EBC4E57805DE4B409F5A7D7555AA4F40EBC4E57805DE4B409F5A7D7555AA4F40103B53E8BCDC4B40302B14E97EA64F40103B53E8BCDC4B40
40485	54924	63.754244	63.786718	56.363892	56.334651999999998	Ленина	0103000020E61000000100000005000000249A40118BE04F403FC571E0D52A4C40249A40118BE04F4055A35703942E4C405796E82CB3E44F4055A35703942E4C405796E82CB3E44F403FC571E0D52A4C40249A40118BE04F403FC571E0D52A4C40
41132	2831	63.330221000000002	63.344647999999999	55.955952000000003	55.945483000000003	Будённого	0103000020E61000000100000005000000E9B985AE44AA4F4045F6419605F94B40E9B985AE44AA4F40DD4598A25CFA4B40DF50F86C1DAC4F40DD4598A25CFA4B40DF50F86C1DAC4F4045F6419605F94B40E9B985AE44AA4F4045F6419605F94B40
41302	3659	63.953670000000002	63.976407000000002	56.051837999999996	56.045312000000003	Макеева	0103000020E610000001000000050000009296CADB11FA4F40E50E9BC8CC054C409296CADB11FA4F405358A9A0A2064C40F14A92E7FAFC4F405358A9A0A2064C40F14A92E7FAFC4F40E50E9BC8CC054C409296CADB11FA4F40E50E9BC8CC054C40
41419	4807	64.173506000000003	64.206446999999997	56.201594999999998	56.186559000000003	Центральная	0103000020E610000001000000050000003AEAE8B81A0B504022E3512AE1174C403AEAE8B81A0B5040C0046EDDCD194C40DE567A6D360D5040C0046EDDCD194C40DE567A6D360D504022E3512AE1174C403AEAE8B81A0B504022E3512AE1174C40
40902	3853	63.500425	63.520448999999999	56.09693	56.092154999999998	Набережная	0103000020E61000000100000005000000E78C28ED0DC04F40D9942BBCCB0B4C40E78C28ED0DC04F402A00C633680C4C40321EA5129EC24F402A00C633680C4C40321EA5129EC24F40D9942BBCCB0B4C40E78C28ED0DC04F40D9942BBCCB0B4C40
41736	16643	64.371539999999996	64.390834999999996	56.105198999999999	56.089351999999998	Поселковая	0103000020E61000000100000005000000F949B54FC717504085EAE6E26F0B4C40F949B54FC717504034492C29770D4C4075C8CD700319504034492C29770D4C4075C8CD700319504085EAE6E26F0B4C40F949B54FC717504085EAE6E26F0B4C40
41675	2715	63.833494000000002	63.844498000000002	55.881914000000002	55.855865999999999	Трудовая	0103000020E61000000100000005000000C4B46FEEAFEA4F4011E15F048DED4B40C4B46FEEAFEA4F4039F1D58EE2F04B40CAC4AD8218EC4F4039F1D58EE2F04B40CAC4AD8218EC4F4011E15F048DED4B40C4B46FEEAFEA4F4011E15F048DED4B40
40990	4317	63.917530999999997	63.9542	56.088976000000002	56.078397000000002	Советская	0103000020E610000001000000050000007808E3A771F54F40618DB3E9080A4C407808E3A771F54F408010C990630B4C40EEEBC03923FA4F408010C990630B4C40EEEBC03923FA4F40618DB3E9080A4C407808E3A771F54F40618DB3E9080A4C40
41078	3962	63.422136999999999	63.446131000000001	56.247371000000001	56.232804000000002	Ленина	0103000020E610000001000000050000003DB7D09508B64F4062307F85CC1D4C403DB7D09508B64F404A7D59DAA91F4C40AB5D13D21AB94F404A7D59DAA91F4C40AB5D13D21AB94F4062307F85CC1D4C403DB7D09508B64F4062307F85CC1D4C40
41673	3182	63.671168000000002	63.692548000000002	55.988354000000001	55.980159999999998	Труда	0103000020E61000000100000005000000950F41D5E8D54F40766C04E275FD4B40950F41D5E8D54F40766F456282FE4B408274B169A5D84F40766F456282FE4B408274B169A5D84F40766C04E275FD4B40950F41D5E8D54F40766C04E275FD4B40
40946	3411	63.430706999999998	63.466414999999998	56.098385999999998	56.091743000000001	Набережная	0103000020E6100000010000000500000042942F6821B74F408751103CBE0B4C4042942F6821B74F402F3196E9970C4C4092AE997CB3BB4F402F3196E9970C4C4092AE997CB3BB4F408751103CBE0B4C4042942F6821B74F408751103CBE0B4C40
40603	54940	63.639305	63.658141999999998	56.023555000000002	56.014780999999999	Зелёная Роща	0103000020E61000000100000005000000AB9509BFD4D14F4014CD0358E4014C40AB9509BFD4D14F402254A9D903034C40E00F3FFF3DD44F402254A9D903034C40E00F3FFF3DD44F4014CD0358E4014C40AB9509BFD4D14F4014CD0358E4014C40
41045	55001	63.445574000000001	63.473871000000003	55.986893000000002	55.974685000000001	Ленина	0103000020E6100000010000000500000055F99E9108B94F406D73637AC2FC4B4055F99E9108B94F405FD3838252FE4B40ECC20FCEA7BC4F405FD3838252FE4B40ECC20FCEA7BC4F406D73637AC2FC4B4055F99E9108B94F406D73637AC2FC4B40
41652	13547	63.630842999999999	63.650336000000003	55.900717999999998	55.895100999999997	Новая	0103000020E610000001000000050000008CF4A276BFD04F40F6CE68AB92F24B408CF4A276BFD04F40927538BA4AF34B40ABB4C5353ED34F40927538BA4AF34B40ABB4C5353ED34F40F6CE68AB92F24B408CF4A276BFD04F40F6CE68AB92F24B40
41674	2639	63.778849000000001	63.789557000000002	55.769195000000003	55.755752999999999	Береговая	0103000020E61000000100000005000000DBC2F352B1E34F404C6DA983BCE04B40DBC2F352B1E34F40959F54FB74E24B40F8A92A3410E54F40959F54FB74E24B40F8A92A3410E54F404C6DA983BCE04B40DBC2F352B1E34F404C6DA983BCE04B40
41423	4423	64.096377000000004	64.114009999999993	56.073960999999997	56.066730999999997	Уральская	0103000020E610000001000000050000008BC56F0A2B0650408F5033A48A084C408BC56F0A2B065040F816D68D77094C40AF5A99F04B075040F816D68D77094C40AF5A99F04B0750408F5033A48A084C408BC56F0A2B0650408F5033A48A084C40
41305	3332	63.301322999999996	63.323718	56.130096000000002	56.121752000000001	Барыкина	0103000020E610000001000000050000002C4487C091A64F407E1CCD91950F4C402C4487C091A64F4093AB58FCA6104C40329067976FA94F4093AB58FCA6104C40329067976FA94F407E1CCD91950F4C402C4487C091A64F407E1CCD91950F4C40
41046	4232	63.605268000000002	63.616244999999999	56.136029999999998	56.131605999999998	Мира	0103000020E610000001000000050000005DA8FC6B79CD4F408BFA2477D8104C405DA8FC6B79CD4F402FA3586E69114C4069A9BC1DE1CE4F402FA3586E69114C4069A9BC1DE1CE4F408BFA2477D8104C405DA8FC6B79CD4F408BFA2477D8104C40
40684	54951	63.459498000000004	63.485657000000003	56.212238999999997	56.192729999999997	8 Марта	0103000020E61000000100000005000000E94999D4D0BA4F40A27A6B60AB184C40E94999D4D0BA4F40C6F7C5A52A1B4C40680932022ABE4F40C6F7C5A52A1B4C40680932022ABE4F40A27A6B60AB184C40E94999D4D0BA4F40A27A6B60AB184C40
41635	4953	63.858978999999998	63.874034999999999	56.253937000000001	56.237206999999998	Советская	0103000020E61000000100000005000000B3791C06F3ED4F40EEB089CC5C1E4C40B3791C06F3ED4F40471FF30181204C409947FE60E0EF4F40471FF30181204C409947FE60E0EF4F40EEB089CC5C1E4C40B3791C06F3ED4F40EEB089CC5C1E4C40
41581	4506	64.165349000000006	64.188984000000005	56.063836000000002	56.057810000000003	Молодёжная	0103000020E6100000010000000500000049DBF813950A5040DEB06D5166074C4049DBF813950A50405B272EC72B084C40E8DD5850180C50405B272EC72B084C40E8DD5850180C5040DEB06D5166074C4049DBF813950A5040DEB06D5166074C40
41583	4129	63.53678	63.55003	56.222430000000003	56.212719999999997	Молодёжная	0103000020E61000000100000005000000CD920035B5C44F40419AB1683A1B4C40CD920035B5C44F401CD31396781C4C40D1E80E6267C64F401CD31396781C4C40D1E80E6267C64F40419AB1683A1B4C40CD920035B5C44F40419AB1683A1B4C40
41429	5170	63.925786000000002	63.950481000000003	56.349139999999998	56.334192999999999	пер. Школьный	0103000020E610000001000000050000001E8CD82780F64F40ACC612D6C62A4C401E8CD82780F64F40DBDC989EB02C4C40153C855CA9F94F40DBDC989EB02C4C40153C855CA9F94F40ACC612D6C62A4C401E8CD82780F64F40ACC612D6C62A4C40
41697	3828	63.253667	63.283436999999999	56.164530999999997	56.158209999999997	Восточная	0103000020E610000001000000050000008789062978A04F4038F3AB3940144C408789062978A04F40CE16105A0F154C40F9BCE2A947A44F40CE16105A0F154C40F9BCE2A947A44F4038F3AB3940144C408789062978A04F4038F3AB3940144C40
41267	13748	63.893968000000001	63.911081000000003	56.081586999999999	56.072910999999998	Мира	0103000020E61000000100000005000000D4D51D8B6DF24F406342CC2555094C40D4D51D8B6DF24F40AE635C71710A4C40E5805D4D9EF44F40AE635C71710A4C40E5805D4D9EF44F406342CC2555094C40D4D51D8B6DF24F406342CC2555094C40
41684	3092	63.529899	63.542789999999997	55.926170999999997	55.917309000000003	Труда	0103000020E610000001000000050000007097FDBAD3C34F40CAA99D616AF54B407097FDBAD3C34F4076C075C58CF64B40444C89247AC54F4076C075C58CF64B40444C89247AC54F40CAA99D616AF54B407097FDBAD3C34F40CAA99D616AF54B40
41134	2867	63.418005000000001	63.428165	55.938299000000001	55.931567999999999	Советская	0103000020E610000001000000050000004148163081B54F400400C79E3DF74B404148163081B54F404C6F7F2E1AF84B405B25581CCEB64F404C6F7F2E1AF84B405B25581CCEB64F400400C79E3DF74B404148163081B54F400400C79E3DF74B40
41687	3057	63.554009999999998	63.581121000000003	55.977913999999998	55.969490999999998	Ленина	0103000020E6100000010000000500000017D4B7CCE9C64F401762F54718FC4B4017D4B7CCE9C64F40782634492CFD4B406902452C62CA4F40782634492CFD4B406902452C62CA4F401762F54718FC4B4017D4B7CCE9C64F401762F54718FC4B40
41594	55041	63.740177000000003	63.761386000000002	56.218190999999997	56.203257000000001	Капитана Быкова	0103000020E610000001000000050000002E20B41EBEDE4F406FD74B53041A4C402E20B41EBEDE4F4009A4C4AEED1B4C40EED0B01875E14F4009A4C4AEED1B4C40EED0B01875E14F406FD74B53041A4C402E20B41EBEDE4F406FD74B53041A4C40
41494	4191	63.553353999999999	63.575766999999999	56.189363999999998	56.179340000000003	Садовая	0103000020E610000001000000050000002E8ECA4DD4C64F40AD6EF59CF4164C402E8ECA4DD4C64F4016855D143D184C40DA8EA9BBB2C94F4016855D143D184C40DA8EA9BBB2C94F40AD6EF59CF4164C402E8ECA4DD4C64F40AD6EF59CF4164C40
40904	4417	64.011314999999996	64.038938000000002	56.082647000000001	56.068795999999999	Советская	0103000020E6100000010000000500000012BD8C62B90050403D0CAD4ECE084C4012BD8C62B9005040670E492D940A4C409624CFF57D025040670E492D940A4C409624CFF57D0250403D0CAD4ECE084C4012BD8C62B90050403D0CAD4ECE084C40
40925	3453	63.563504999999999	63.583897	56.075574000000003	56.068308999999999	Мира	0103000020E61000000100000005000000F5108DEE20C84F40E0826C59BE084C40F5108DEE20C84F40C636A968AC094C40C39D0B23BDCA4F40C636A968AC094C40C39D0B23BDCA4F40E0826C59BE084C40F5108DEE20C84F40E0826C59BE084C40
41420	4827	64.060794000000001	64.107623000000004	56.212825000000002	56.205015000000003	Центральная	0103000020E61000000100000005000000C172840CE4035040401878EE3D1A4C40C172840CE4035040B7627FD93D1B4C400953944BE3065040B7627FD93D1B4C400953944BE3065040401878EE3D1A4C40C172840CE4035040401878EE3D1A4C40
41133	2525	63.516199999999998	63.536951000000002	55.806655999999997	55.788570999999997	Ленина	0103000020E61000000100000005000000FC1873D712C24F4079C9FFE4EFE44B40FC1873D712C24F40A38FF98040E74B40FA4674CFBAC44F40A38FF98040E74B40FA4674CFBAC44F4079C9FFE4EFE44B40FC1873D712C24F4079C9FFE4EFE44B40
40527	54930	63.64076	63.678210999999997	55.870541000000003	55.850276999999998	Гагарина	0103000020E61000000100000005000000E04A766C04D24F403FC571E0D5EC4B40E04A766C04D24F40E06932E36DEF4B40CB64389ECFD64F40E06932E36DEF4B40CB64389ECFD64F403FC571E0D5EC4B40E04A766C04D24F403FC571E0D5EC4B40
41304	3519	63.810603999999998	63.832720999999999	56.050224	56.045966	Железнодорожная	0103000020E61000000100000005000000DE0033DFC1E74F402D5DC136E2054C40DE0033DFC1E74F40B6BC72BD6D064C40A1D80A9A96EA4F40B6BC72BD6D064C40A1D80A9A96EA4F402D5DC136E2054C40DE0033DFC1E74F402D5DC136E2054C40
41314	5244	64.241382999999999	64.255819000000002	56.483547000000002	56.468820999999998	Советская	0103000020E61000000100000005000000DDB3AED1720F5040C9569753023C4C40DDB3AED1720F50401A8A3BDEE43D4C4082ACA7565F1050401A8A3BDEE43D4C4082ACA7565F105040C9569753023C4C40DDB3AED1720F5040C9569753023C4C40
41415	4080	63.549760999999997	63.565489999999997	56.237727	56.229812000000003	Зелёная	0103000020E61000000100000005000000E1CE85915EC64F403B1DC87A6A1D4C40E1CE85915EC64F4027309DD66D1E4C40861BF0F961C84F4027309DD66D1E4C40861BF0F961C84F403B1DC87A6A1D4C40E1CE85915EC64F403B1DC87A6A1D4C40
41273	14367	68.007489000000007	68.023712000000003	55.413423000000002	55.407009000000002	Луговая	0103000020E610000001000000050000001B8524B37A005140BE16F4DE18B44B401B8524B37A00514005357C0BEBB44B407521567F8401514005357C0BEBB44B407521567F84015140BE16F4DE18B44B401B8524B37A005140BE16F4DE18B44B40
41489	2372	68.338454999999996	68.363068999999996	55.466825	55.460276999999998	Центральная	0103000020E61000000100000005000000BB0A293FA9155140ED0C535BEABA4B40BB0A293FA915514044FAEDEBC0BB4B40404CC2853C17514044FAEDEBC0BB4B40404CC2853C175140ED0C535BEABA4B40BB0A293FA9155140ED0C535BEABA4B40
41452	1822	68.169445999999994	68.176929000000001	55.426876	55.415956999999999	Садовая	0103000020E61000000100000005000000081C0934D80A514069C537143EB54B40081C0934D80A514041B96DDFA3B64B40B22D03CE520B514041B96DDFA3B64B40B22D03CE520B514069C537143EB54B40081C0934D80A514069C537143EB54B40
41043	54985	67.889296999999999	67.934050999999997	55.584206999999999	55.551746000000001	Энергетиков	0103000020E6100000010000000500000094DBF63DEAF8504073D9E89C9FC64B4094DBF63DEAF85040118C834BC7CA4B40F372D87DC7FB5040118C834BC7CA4B40F372D87DC7FB504073D9E89C9FC64B4094DBF63DEAF8504073D9E89C9FC64B40
40936	54985	67.889296999999999	67.934050999999997	55.584206999999999	55.551746000000001	Октябрьская	0103000020E6100000010000000500000094DBF63DEAF8504073D9E89C9FC64B4094DBF63DEAF85040118C834BC7CA4B40F372D87DC7FB5040118C834BC7CA4B40F372D87DC7FB504073D9E89C9FC64B4094DBF63DEAF8504073D9E89C9FC64B40
40986	54985	67.889296999999999	67.934050999999997	55.584206999999999	55.551746000000001	Береговая	0103000020E6100000010000000500000094DBF63DEAF8504073D9E89C9FC64B4094DBF63DEAF85040118C834BC7CA4B40F372D87DC7FB5040118C834BC7CA4B40F372D87DC7FB504073D9E89C9FC64B4094DBF63DEAF8504073D9E89C9FC64B40
41488	2256	67.693465000000003	67.715168000000006	55.559719999999999	55.548119999999997	Советская	0103000020E61000000100000005000000ECFA05BB61EC50404A24D1CB28C64B40ECFA05BB61EC50406475ABE7A4C74B4054C90050C5ED50406475ABE7A4C74B4054C90050C5ED50404A24D1CB28C64B40ECFA05BB61EC50404A24D1CB28C64B40
41579	2144	67.756275000000002	67.765105000000005	55.396023	55.388133000000003	Береговая	0103000020E6100000010000000500000013F241CF66F05040CBBF9657AEB14B4013F241CF66F050405EBBB4E1B0B24B406440F67AF7F050405EBBB4E1B0B24B406440F67AF7F05040CBBF9657AEB14B4013F241CF66F05040CBBF9657AEB14B40
41233	1897	67.843536999999998	67.851864000000006	55.468698000000003	55.461976999999997	Мира	0103000020E61000000100000005000000D2FD9C82FCF550408940F50F22BB4B40D2FD9C82FCF55040AED9CA4BFEBB4B40F22895F084F65040AED9CA4BFEBB4B40F22895F084F650408940F50F22BB4B40D2FD9C82FCF550408940F50F22BB4B40
41669	1934	68.026156	68.049852999999999	55.406118999999997	55.395456000000003	Красноармейская	0103000020E610000001000000050000000726378AAC015140E5805D4D9EB24B400726378AAC01514061A417B5FBB34B40E126A3CA3003514061A417B5FBB34B40E126A3CA30035140E5805D4D9EB24B400726378AAC015140E5805D4D9EB24B40
41547	14412	67.751379	67.762643999999995	55.449255999999998	55.439630000000001	Школьная	0103000020E61000000100000005000000ADF9F19716F05040952BBCCB45B84B40ADF9F19716F0504011C4793881B94B40669FC728CFF0504011C4793881B94B40669FC728CFF05040952BBCCB45B84B40ADF9F19716F05040952BBCCB45B84B40
41582	2184	67.724888000000007	67.746347999999998	55.683798000000003	55.676844000000003	Советская	0103000020E61000000100000005000000D350A39064EE5040363FFED2A2D64B40D350A39064EE5040FD885FB186D74B40D7DB662AC4EF5040FD885FB186D74B40D7DB662AC4EF5040363FFED2A2D64B40D350A39064EE5040363FFED2A2D64B40
41312	2296	67.577168999999998	67.595692	55.678843999999998	55.673645999999998	Зелёная	0103000020E61000000100000005000000F6D03E56F0E45040658A39083AD64B40F6D03E56F0E45040FC8A355CE4D64B40499F56D11FE65040FC8A355CE4D64B40499F56D11FE65040658A39083AD64B40F6D03E56F0E45040658A39083AD64B40
41619	1677	67.890600000000006	67.899062000000001	55.659312	55.651166000000003	Лесная	0103000020E6100000010000000500000054742497FFF850403222516859D34B4054742497FFF8504020EEEA5564D44B40E3C4573B8AF9504020EEEA5564D44B40E3C4573B8AF950403222516859D34B4054742497FFF850403222516859D34B40
41300	2057	67.724169000000003	67.746258999999995	55.452793999999997	55.444021999999997	Советская	0103000020E61000000100000005000000BBF1EEC858EE50402D5A80B6D5B84B40BBF1EEC858EE50409AE95E27F5B94B401FD61BB5C2EF50409AE95E27F5B94B401FD61BB5C2EF50402D5A80B6D5B84B40BBF1EEC858EE50402D5A80B6D5B84B40
41451	1584	67.897210999999999	67.918025	55.597129000000002	55.588537000000002	Центральная	0103000020E6100000010000000500000022A7AFE76BF9504034BE2F2E55CB4B4022A7AFE76BF95040213F1BB96ECC4B4044FAEDEBC0FA5040213F1BB96ECC4B4044FAEDEBC0FA504034BE2F2E55CB4B4022A7AFE76BF9504034BE2F2E55CB4B40
41640	2028	68.034806000000003	68.049385999999998	55.365233000000003	55.359788999999999	Центральная	0103000020E6100000010000000500000018EDF1423A025140F33AE2900DAE4B4018EDF1423A025140C23577F4BFAE4B4056B8E52329035140C23577F4BFAE4B4056B8E52329035140F33AE2900DAE4B4018EDF1423A025140F33AE2900DAE4B40
41568	29606	67.868510000000001	67.888847999999996	55.428806999999999	55.418134000000002	Пушкина	0103000020E61000000100000005000000EF8FF7AA95F750403FAC376A85B54B40EF8FF7AA95F75040DFA5D425E3B64B405CC7B8E2E2F85040DFA5D425E3B64B405CC7B8E2E2F850403FAC376A85B54B40EF8FF7AA95F750403FAC376A85B54B40
41516	25500	67.842063999999993	67.853958000000006	55.387371999999999	55.377941	Центральная	0103000020E61000000100000005000000E4486760E4F55040A568E55E60B04B40E4486760E4F550406CB1DB6795B14B40168A743FA7F650406CB1DB6795B14B40168A743FA7F65040A568E55E60B04B40E4486760E4F55040A568E55E60B04B40
41298	1788	68.161568000000003	68.171018000000004	55.519967000000001	55.504981000000001	Центральная	0103000020E6100000010000000500000021054F21570A5140FA0CA837A3C04B4021054F21570A5140E7FF55478EC24B40C0417BF5F10A5140E7FF55478EC24B40C0417BF5F10A5140FA0CA837A3C04B4021054F21570A5140FA0CA837A3C04B40
41402	1701	68.087124000000003	68.110282999999995	55.654761999999998	55.641199	Калинина	0103000020E6100000010000000500000097AC8A70930551402C9D0FCF12D24B4097AC8A7093055140EF54C03DCFD34B4081936DE00E075140EF54C03DCFD34B4081936DE00E0751402C9D0FCF12D24B4097AC8A70930551402C9D0FCF12D24B40
41128	975	63.485109000000001	63.503264000000001	54.323250999999999	54.311534000000002	Береговая	0103000020E6100000010000000500000065FF3C0D18BE4F40C9CB9A58E0274B4065FF3C0D18BE4F401CB3EC4960294B4088A06AF46AC04F401CB3EC4960294B4088A06AF46AC04F40C9CB9A58E0274B4065FF3C0D18BE4F40C9CB9A58E0274B40
40480	54923	63.650317999999999	63.702168999999998	54.517440999999998	54.491579000000002	8 Марта 	0103000020E610000001000000050000000400C79E3DD34F404033880FEC3E4B400400C79E3DD34F40054EB6813B424B40ECA17DACE0D94F40054EB6813B424B40ECA17DACE0D94F404033880FEC3E4B400400C79E3DD34F404033880FEC3E4B40
40987	54991	63.650317999999999	63.702168999999998	54.517440999999998	54.491579000000002	Кооперативная	0103000020E610000001000000050000000400C79E3DD34F404033880FEC3E4B400400C79E3DD34F40054EB6813B424B40ECA17DACE0D94F40054EB6813B424B40ECA17DACE0D94F404033880FEC3E4B400400C79E3DD34F404033880FEC3E4B40
41412	31930	63.518616000000002	63.536025000000002	54.455798999999999	54.450626999999997	Центральная	0103000020E610000001000000050000005797530262C24F40E8D84125AE394B405797530262C24F405646239F573A4B40516B9A779CC44F405646239F573A4B40516B9A779CC44F40E8D84125AE394B405797530262C24F40E8D84125AE394B40
40933	32001	63.887869000000002	63.920729000000001	54.274391999999999	54.261972	Киров	0103000020E61000000100000005000000ED10FFB0A5F14F40DE3B6A4C88214B40ED10FFB0A5F14F405B24ED461F234B4049BDA772DAF54F405B24ED461F234B4049BDA772DAF54F40DE3B6A4C88214B40ED10FFB0A5F14F40DE3B6A4C88214B40
41596	738	63.599096000000003	63.617736000000001	54.405636000000001	54.394723999999997	Школьный переулок	0103000020E610000001000000050000000C957F2DAFCC4F402079E75086324B400C957F2DAFCC4F40460A65E1EB334B40EBC726F911CF4F40460A65E1EB334B40EBC726F911CF4F402079E75086324B400C957F2DAFCC4F402079E75086324B40
41229	394	64.078967000000006	64.094373000000004	54.637042999999998	54.624327000000001	Центральная	0103000020E61000000100000005000000A69D9ACB0D055040418177F2E94F4B40A69D9ACB0D055040A79201A08A514B4007280D350A065040A79201A08A514B4007280D350A065040418177F2E94F4B40A69D9ACB0D055040418177F2E94F4B40
41231	354	64.001801999999998	64.022400000000005	54.656204000000002	54.643763999999997	Центральная	0103000020E6100000010000000500000050C422861D005040CB2BD7DB66524B4050C422861D00504090C01F7EFE534B408CDB68006F01504090C01F7EFE534B408CDB68006F015040CB2BD7DB66524B4050C422861D005040CB2BD7DB66524B40
41410	31958	63.499957999999999	63.514752999999999	54.406061000000001	54.392999000000003	Школьная	0103000020E61000000100000005000000D1AFAD9FFEBF4F402C2E8ECA4D324B40D1AFAD9FFEBF4F402D978DCEF9334B404A42226DE3C14F402D978DCEF9334B404A42226DE3C14F402C2E8ECA4D324B40D1AFAD9FFEBF4F402C2E8ECA4D324B40
41630	31622	63.341199000000003	63.352193999999997	54.311008999999999	54.300665000000002	Школьня	0103000020E61000000100000005000000C636A968ACAB4F40A306D3307C264B40C636A968ACAB4F407EE19524CF274B4078EC67B114AD4F407EE19524CF274B4078EC67B114AD4F40A306D3307C264B40C636A968ACAB4F40A306D3307C264B40
41668	1217	63.910128999999998	63.920540000000003	54.434925	54.428499000000002	Клубная	0103000020E610000001000000050000001212691B7FF44F4032AF230ED9364B401212691B7FF44F403D9B559FAB374B4076543541D4F54F403D9B559FAB374B4076543541D4F54F4032AF230ED9364B401212691B7FF44F4032AF230ED9364B40
41137	31875	64.103554000000003	64.114108999999999	54.345351999999998	54.339505000000003	Притобольная	0103000020E61000000100000005000000AED7F4A0A00650400CEA5BE6742B4B40AED7F4A0A0065040D9CD8C7E342C4B4079CBD58F4D075040D9CD8C7E342C4B4079CBD58F4D0750400CEA5BE6742B4B40AED7F4A0A00650400CEA5BE6742B4B40
41154	866	63.643616999999999	63.651980000000002	54.306381000000002	54.299928999999999	Лесная	0103000020E610000001000000050000002713B70A62D24F409D0FCF1264264B402713B70A62D24F40D28E1B7E37274B40B3D2A41474D34F40D28E1B7E37274B40B3D2A41474D34F409D0FCF1264264B402713B70A62D24F409D0FCF1264264B40
41413	54963	63.826495999999999	63.858116000000003	54.704279	54.686349	Школьная	0103000020E610000001000000050000002D23F59ECAE94F403752B648DA574B402D23F59ECAE94F403A2174D0255A4B405116BEBED6ED4F403A2174D0255A4B405116BEBED6ED4F403752B648DA574B402D23F59ECAE94F403752B648DA574B40
40760	54963	63.826495999999999	63.858116000000003	54.704279	54.686349	Советская	0103000020E610000001000000050000002D23F59ECAE94F403752B648DA574B402D23F59ECAE94F403A2174D0255A4B405116BEBED6ED4F403A2174D0255A4B405116BEBED6ED4F403752B648DA574B402D23F59ECAE94F403752B648DA574B40
41573	32147	64.000966000000005	64.008386999999999	54.339227000000001	54.333972000000003	Береговая	0103000020E610000001000000050000001C9AB2D30F005040CEE33098BF2A4B401C9AB2D30F005040C97553CA6B2B4B408AADA06989005040C97553CA6B2B4B408AADA06989005040CEE33098BF2A4B401C9AB2D30F005040CEE33098BF2A4B40
40985	32189	63.243048999999999	63.274535	54.623837000000002	54.610371000000001	Ленина	0103000020E61000000100000005000000AA29C93A1C9F4F40A2B60DA3204E4B40AA29C93A1C9F4F4073840CE4D94F4B40BE4D7FF623A34F4073840CE4D94F4B40BE4D7FF623A34F40A2B60DA3204E4B40AA29C93A1C9F4F40A2B60DA3204E4B40
41629	145	63.211373999999999	63.231262999999998	54.363827000000001	54.359319999999997	Школьная	0103000020E61000000100000005000000C39CA04D0E9B4F403C66A032FE2D4B40C39CA04D0E9B4F406E3315E2912E4B402EE3A6069A9D4F406E3315E2912E4B402EE3A6069A9D4F403C66A032FE2D4B40C39CA04D0E9B4F403C66A032FE2D4B40
41450	32437	63.306227	63.322397000000002	54.435229	54.430447999999998	Центральная	0103000020E610000001000000050000007B13437232A74F40765089EB18374B407B13437232A74F40A9A27895B5374B400DAA0D4E44A94F40A9A27895B5374B400DAA0D4E44A94F40765089EB18374B407B13437232A74F40765089EB18374B40
41591	32216	63.335971000000001	63.34693	54.590260000000001	54.579464999999999	Конторская	0103000020E61000000100000005000000C4B3041901AB4F409C16BCE82B4A4B40C4B3041901AB4F408811C2A38D4B4B402A00C63368AC4F408811C2A38D4B4B402A00C63368AC4F409C16BCE82B4A4B40C4B3041901AB4F409C16BCE82B4A4B40
40895	772	63.567304999999998	63.587893999999999	54.297870000000003	54.284343	Советская	0103000020E61000000100000005000000BBED42739DC84F405BECF65965244B40BBED42739DC84F40D23AAA9A20264B40DFC14F1C40CB4F40D23AAA9A20264B40DFC14F1C40CB4F405BECF65965244B40BBED42739DC84F405BECF65965244B40
40807	31605	63.657046000000001	63.680231999999997	54.575592999999998	54.563839000000002	Клубная	0103000020E61000000100000005000000DBFB54151AD44F40CC9A58E02B484B40DBFB54151AD44F403C670B08AD494B40A9D898D711D74F403C670B08AD494B40A9D898D711D74F40CC9A58E02B484B40DBFB54151AD44F40CC9A58E02B484B40
41237	1140	63.707872999999999	63.720503000000001	54.426195	54.421402	Школьная	0103000020E61000000100000005000000575C1C959BDA4F40083C3080F0354B40575C1C959BDA4F40FF5BC98E8D364B40BFD53A7139DC4F40FF5BC98E8D364B40BFD53A7139DC4F40083C3080F0354B40575C1C959BDA4F40083C3080F0354B40
41303	55016	63.554440999999997	63.570690999999997	54.227111999999998	54.222763999999998	Большая	0103000020E61000000100000005000000E04735ECF7C64F40F25CDF87831C4B40E04735ECF7C64F40BB438A01121D4B408E8F16670CC94F40BB438A01121D4B408E8F16670CC94F40F25CDF87831C4B40E04735ECF7C64F40F25CDF87831C4B40
41626	272	64.050464000000005	64.059608999999995	54.417824000000003	54.405301000000001	Советская	0103000020E6100000010000000500000006685BCD3A0350409F0436E7E0334B4006685BCD3A035040F1BDBF417B354B40066344A2D0035040F1BDBF417B354B40066344A2D00350409F0436E7E0334B4006685BCD3A0350409F0436E7E0334B40
41225	32377	63.209029999999998	63.220365999999999	54.424571	54.417493999999998	Центральная	0103000020E6100000010000000500000002F1BA7EC19A4F405B23827170354B4002F1BA7EC19A4F403EEAAF5758364B403E93FDF3349C4F403EEAAF5758364B403E93FDF3349C4F405B23827170354B4002F1BA7EC19A4F405B23827170354B40
41224	32056	63.734544	63.747767000000003	54.274265999999997	54.270311999999997	Речная	0103000020E610000001000000050000008CBCAC8905DE4F40B1DB679599224B408CBCAC8905DE4F40CE33F6251B234B4097033DD4B6DF4F40CE33F6251B234B4097033DD4B6DF4F40B1DB679599224B408CBCAC8905DE4F40B1DB679599224B40
40900	54982	63.814655999999999	63.837240000000001	54.438265999999999	54.425235999999998	Строителей	0103000020E61000000100000005000000BEBED6A546E84F407A8A1C226E364B40BEBED6A546E84F407079AC1919384B40977329AE2AEB4F407079AC1919384B40977329AE2AEB4F407A8A1C226E364B40BEBED6A546E84F407A8A1C226E364B40
41057	237	63.984267000000003	64.004254000000003	54.511802000000003	54.495213	Школьная	0103000020E610000001000000050000001AC40776FCFD4F40EBC6BB23633F4B401AC40776FCFD4F4082035ABA82414B4024B891B24500504082035ABA82414B4024B891B245005040EBC6BB23633F4B401AC40776FCFD4F40EBC6BB23633F4B40
41411	55023	63.249507999999999	63.282916	54.366219000000001	54.352981999999997	Подорожко	0103000020E61000000100000005000000910BCEE0EF9F4F40D009A1832E2D4B40910BCEE0EF9F4F404016A243E02E4B40F0C16B9736A44F404016A243E02E4B40F0C16B9736A44F40D009A1832E2D4B40910BCEE0EF9F4F40D009A1832E2D4B40
41633	55023	63.249507999999999	63.282916	54.366219000000001	54.352981999999997	Заречная	0103000020E61000000100000005000000910BCEE0EF9F4F40D009A1832E2D4B40910BCEE0EF9F4F404016A243E02E4B40F0C16B9736A44F404016A243E02E4B40F0C16B9736A44F40D009A1832E2D4B40910BCEE0EF9F4F40D009A1832E2D4B40
40981	31806	64.230693000000002	64.252934999999994	54.372366	54.357168999999999	Советская	0103000020E61000000100000005000000A29A92ACC30E50409012BBB6B72D4B40A29A92ACC30E5040381268B0A92F4B40E140481630105040381268B0A92F4B40E1404816301050409012BBB6B72D4B40A29A92ACC30E50409012BBB6B72D4B40
41227	31772	63.411932	63.428137999999997	54.674272999999999	54.669603000000002	Школьная	0103000020E6100000010000000500000083161230BAB44F40D926158DB5554B4083161230BAB44F40B4C9E1934E564B406116DA39CDB64F40B4C9E1934E564B406116DA39CDB64F40D926158DB5554B4083161230BAB44F40D926158DB5554B40
76558	60870	63.854469000000002	63.865222000000003	54.461131999999999	54.454867	Центральная	0103000020E6100000010000000500000011397D3D5FED4F40CB83F414393A4B4011397D3D5FED4F40CD91955F063B4B40CEE33098BFEE4F40CD91955F063B4B40CEE33098BFEE4F40CB83F414393A4B4011397D3D5FED4F40CB83F414393A4B40
41232	31724	63.583069999999999	63.602176999999998	54.684074000000003	54.673699999999997	пер. Школьный	0103000020E61000000100000005000000ADA3AA09A2CA4F4058A835CD3B564B40ADA3AA09A2CA4F409F05A1BC8F574B40A2B3CC2214CD4F409F05A1BC8F574B40A2B3CC2214CD4F4058A835CD3B564B40ADA3AA09A2CA4F4058A835CD3B564B40
41574	31566	63.728391000000002	63.748666	54.498339999999999	54.491562999999999	Центральная	0103000020E61000000100000005000000B2D991EA3BDD4F403A765089EB3E4B40B2D991EA3BDD4F40F224E99AC93F4B4046D09849D4DF4F40F224E99AC93F4B4046D09849D4DF4F403A765089EB3E4B40B2D991EA3BDD4F403A765089EB3E4B40
41634	615	63.866219000000001	63.887194999999998	54.705621000000001	54.698988	им. В. Пяткова	0103000020E610000001000000050000004016A243E0EE4F40F225547078594B404016A243E0EE4F40772FF7C9515A4B405D16139B8FF14F40772FF7C9515A4B405D16139B8FF14F40F225547078594B404016A243E0EE4F40F225547078594B40
41577	661	63.866380999999997	63.880763000000002	54.661791999999998	54.651176999999997	Школьная	0103000020E6100000010000000500000019709692E5EE4F40257497C459534B4019709692E5EE4F409160AA99B5544B4070438CD7BCF04F409160AA99B5544B4070438CD7BCF04F40257497C459534B4019709692E5EE4F40257497C459534B40
41670	31700	63.468077000000001	63.495296000000003	54.589466999999999	54.580382999999998	Школьная	0103000020E61000000100000005000000418177F2E9BB4F40C2137AFD494A4B40418177F2E9BB4F401E8997A7734B4B4079EBFCDB65BF4F401E8997A7734B4B4079EBFCDB65BF4F40C2137AFD494A4B40418177F2E9BB4F40C2137AFD494A4B40
41758	55054	63.395367	63.404421999999997	54.360878999999997	54.353712000000002	Лесная	0103000020E610000001000000050000007575C7629BB24F40F419506F462D4B407575C7629BB24F4016687748312E4B4036E49F19C4B34F4016687748312E4B4036E49F19C4B34F40F419506F462D4B407575C7629BB24F40F419506F462D4B40
41404	30699	62.685994999999998	62.722456999999999	54.982404000000002	54.972835000000003	Ленина	0103000020E61000000100000005000000191C25AFCE574F40BCB376DB857C4B40191C25AFCE574F40D4BA0D6ABF7D4B4015E29178795C4F40D4BA0D6ABF7D4B4015E29178795C4F40BCB376DB857C4B40191C25AFCE574F40BCB376DB857C4B40
40978	30969	62.597087999999999	62.614291000000001	54.929926999999999	54.918861	Колхозная	0103000020E61000000100000005000000C26A2C616D4C4F40F148BC3C9D754B40C26A2C616D4C4F406D5512D907774B40139D6516A14E4F406D5512D907774B40139D6516A14E4F40F148BC3C9D754B40C26A2C616D4C4F40F148BC3C9D754B40
41050	30289	62.54363	62.566122999999997	54.767487000000003	54.753461000000001	Ленина	0103000020E61000000100000005000000EF8FF7AA95454F40DEE7F86871604B40EF8FF7AA95454F40768D96033D624B40B741EDB776484F40768D96033D624B40B741EDB776484F40DEE7F86871604B40EF8FF7AA95454F40DEE7F86871604B40
41576	30383	62.597141999999998	62.604067999999998	54.816727	54.810237000000001	Центральная	0103000020E61000000100000005000000B58828266F4C4F402C8194D8B5674B40B58828266F4C4F404E61A5828A684B40B247A819524D4F404E61A5828A684B40B247A819524D4F402C8194D8B5674B40B58828266F4C4F402C8194D8B5674B40
40980	54921	62.506709000000001	62.563464000000003	55.002479999999998	54.976275999999999	Энергетиков	0103000020E6100000010000000500000060CB2BD7DB404F4052EFA99CF67C4B4060CB2BD7DB404F407172BF4351804B40973C9E961F484F407172BF4351804B40973C9E961F484F4052EFA99CF67C4B4060CB2BD7DB404F4052EFA99CF67C4B40
40474	54921	62.506709000000001	62.563464000000003	55.002479999999998	54.976275999999999	Чапаева	0103000020E6100000010000000500000060CB2BD7DB404F4052EFA99CF67C4B4060CB2BD7DB404F407172BF4351804B40973C9E961F484F407172BF4351804B40973C9E961F484F4052EFA99CF67C4B4060CB2BD7DB404F4052EFA99CF67C4B40
41235	54921	62.506709000000001	62.563464000000003	55.002479999999998	54.976275999999999	Ленина	0103000020E6100000010000000500000060CB2BD7DB404F4052EFA99CF67C4B4060CB2BD7DB404F407172BF4351804B40973C9E961F484F407172BF4351804B40973C9E961F484F4052EFA99CF67C4B4060CB2BD7DB404F4052EFA99CF67C4B40
41491	55031	62.230862999999999	62.260337	54.78519	54.769849999999998	Октябрьская	0103000020E61000000100000005000000A06D35EB8C1D4F40AD69DE718A624B40A06D35EB8C1D4F40B8921D1B81644B4029780AB952214F40B8921D1B81644B4029780AB952214F40AD69DE718A624B40A06D35EB8C1D4F40AD69DE718A624B40
41747	55047	62.230862999999999	62.260337	54.78519	54.769849999999998	Больничная улица	0103000020E61000000100000005000000A06D35EB8C1D4F40AD69DE718A624B40A06D35EB8C1D4F40B8921D1B81644B4029780AB952214F40B8921D1B81644B4029780AB952214F40AD69DE718A624B40A06D35EB8C1D4F40AD69DE718A624B40
41567	30163	62.153742999999999	62.174152999999997	54.750836999999997	54.741337999999999	Школьная	0103000020E61000000100000005000000957EC2D9AD134F401AA4E029E45E4B40957EC2D9AD134F4039D0436D1B604B4009C03FA54A164F4039D0436D1B604B4009C03FA54A164F401AA4E029E45E4B40957EC2D9AD134F401AA4E029E45E4B40
41625	29967	62.241382000000002	62.262107	54.853220999999998	54.849645000000002	Набережная	0103000020E61000000100000005000000EAEBF99AE51E4F40DF1AD82AC16C4B40EAEBF99AE51E4F4055A18158366D4B40BE86E0B88C214F4055A18158366D4B40BE86E0B88C214F40DF1AD82AC16C4B40EAEBF99AE51E4F40DF1AD82AC16C4B40
41306	30448	62.662683000000001	62.676364999999997	54.711269999999999	54.695528000000003	Школьная	0103000020E61000000100000005000000BE4EEACBD2544F40E5B9BE0F07594B40BE4EEACBD2544F401E5036E50A5B4B405B94D92093564F401E5036E50A5B4B405B94D92093564F40E5B9BE0F07594B40BE4EEACBD2544F40E5B9BE0F07594B40
41221	30630	62.773167000000001	62.782491999999998	54.932053000000003	54.925007000000001	Центральная	0103000020E6100000010000000500000058ACE122F7624F4019C91EA166764B4058ACE122F7624F40C19140834D774B40D9B0A6B228644F40C19140834D774B40D9B0A6B228644F4019C91EA166764B4058ACE122F7624F4019C91EA166764B40
41405	31064	62.469213000000003	62.502612999999997	54.918317000000002	54.908852000000003	Труда	0103000020E61000000100000005000000D5EDEC2B0F3C4F40BD73284355744B40D5EDEC2B0F3C4F40302E55698B754B40B0C56E9F55404F40302E55698B754B40B0C56E9F55404F40BD73284355744B40D5EDEC2B0F3C4F40BD73284355744B40
41571	29758	62.268062	62.300491999999998	55.017380000000003	55.003687999999997	Школьная	0103000020E6100000010000000500000072A609DB4F224F409EB12FD978804B4072A609DB4F224F4060CD018239824B40D55A988576264F4060CD018239824B40D55A988576264F409EB12FD978804B4072A609DB4F224F409EB12FD978804B40
41627	30789	62.700422000000003	62.705829000000001	54.935043	54.92792	Братьев Михолап	0103000020E6100000010000000500000010B3976DA7594F40F4A62215C6764B4010B3976DA7594F4047AD307DAF774B40C1C8CB9A585A4F4047AD307DAF774B40C1C8CB9A585A4F40F4A62215C6764B4010B3976DA7594F40F4A62215C6764B40
41403	29720	62.360885000000003	62.384754000000001	55.064915999999997	55.049514000000002	70 Лет Октября	0103000020E61000000100000005000000F94ECC7A312E4F40DA58897956864B40F94ECC7A312E4F405A7EE02A4F884B40AA807B9E3F314F405A7EE02A4F884B40AA807B9E3F314F40DA58897956864B40F94ECC7A312E4F40DA58897956864B40
40806	29866	62.279606000000001	62.303303	54.831214000000003	54.811166	Комсомольская	0103000020E61000000100000005000000F8E12021CA234F4046D09849D4674B40F8E12021CA234F401AFD6838656A4B40ACE3F8A1D2264F401AFD6838656A4B40ACE3F8A1D2264F4046D09849D4674B40F8E12021CA234F4046D09849D4674B40
41754	55050	62.734763999999998	62.756512000000001	54.993240999999998	54.982084	Школьная	0103000020E610000001000000050000009A232BBF0C5E4F4062F6B2EDB47D4B409A232BBF0C5E4F40EE056685227F4B400A849D62D5604F40EE056685227F4B400A849D62D5604F4062F6B2EDB47D4B409A232BBF0C5E4F4062F6B2EDB47D4B40
41503	30338	62.440494000000001	62.454562000000003	54.770287000000003	54.764251000000002	Центральная	0103000020E61000000100000005000000C80A7E1B62384F40B8770DFAD2614B40C80A7E1B62384F4059C4B0C398624B408F006E162F3A4F4059C4B0C398624B408F006E162F3A4F40B8770DFAD2614B40C80A7E1B62384F40B8770DFAD2614B40
41632	30557	62.756872000000001	62.768369999999997	54.812202999999997	54.80442	Школьная	0103000020E610000001000000050000000AA1832EE1604F40C91F0C3CF7664B400AA1832EE1604F40465B9544F6674B401F9DBAF259624F40465B9544F6674B401F9DBAF259624F40C91F0C3CF7664B400AA1832EE1604F40C91F0C3CF7664B40
41575	29678	61.963811999999997	62.888412000000002	55.149017999999998	54.625093	Центральная	0103000020E6100000010000000500000005BF0D315EFB4E40B1FA230C03504B4005BF0D315EFB4E40F641960513934B40DEAF027CB7714F40F641960513934B40DEAF027CB7714F40B1FA230C03504B4005BF0D315EFB4E40B1FA230C03504B40
41695	29893	62.146960999999997	62.169221	54.819263999999997	54.809764999999999	Школьная	0103000020E61000000100000005000000CB64389ECF124F4004392861A6674B40CB64389ECF124F4023658BA4DD684B40F165A208A9154F4023658BA4DD684B40F165A208A9154F4004392861A6674B40CB64389ECF124F4004392861A6674B40
41240	31082	62.381357999999999	62.403016000000001	54.884120000000003	54.874698000000002	Заречная	0103000020E61000000100000005000000B308C556D0304F4035F0A31AF66F4B40B308C556D0304F40A9DE1AD82A714B40E3E13D0796334F40A9DE1AD82A714B40E3E13D0796334F4035F0A31AF66F4B40B308C556D0304F4035F0A31AF66F4B40
41407	30913	62.724136999999999	62.734647000000002	55.063906000000003	55.048988000000001	Аптыкаевская	0103000020E610000001000000050000006A696E85B05C4F40BFF2203D45864B406A696E85B05C4F40540262122E884B40618DB3E9085E4F40540262122E884B40618DB3E9085E4F40BFF2203D45864B406A696E85B05C4F40BFF2203D45864B40
41215	30212	62.361756999999997	62.371071999999998	54.798499	54.790484999999997	Школьная	0103000020E61000000100000005000000AE0CAA0D4E2E4F40417DCB9C2E654B40AE0CAA0D4E2E4F40C171193735664B400C3B8C497F2F4F40C171193735664B400C3B8C497F2F4F40417DCB9C2E654B40AE0CAA0D4E2E4F40417DCB9C2E654B40
41570	29601	62.502459999999999	62.530002000000003	55.106622999999999	55.092958000000003	Школьная	0103000020E610000001000000050000002AC6F99B50404F4067F3380CE68B4B402AC6F99B50404F402E008DD2A58D4B404568041BD7434F402E008DD2A58D4B404568041BD7434F4067F3380CE68B4B402AC6F99B50404F4067F3380CE68B4B40
41223	30476	62.578645999999999	62.594437999999997	54.673403	54.662339000000003	Школьная	0103000020E6100000010000000500000009FB7612114A4F40C4EE3B86C7544B4009FB7612114A4F409F03CB1132564B40F4BF5C8B164C4F409F03CB1132564B40F4BF5C8B164C4F40C4EE3B86C7544B4009FB7612114A4F40C4EE3B86C7544B40
41217	30084	62.273955000000001	62.29768	54.713740999999999	54.702401000000002	Зелёная	0103000020E61000000100000005000000B0C91AF510234F40BFD6A546E8594B40B0C91AF510234F403C6876DD5B5B4B402E56D4601A264F403C6876DD5B5B4B402E56D4601A264F40BFD6A546E8594B40B0C91AF510234F40BFD6A546E8594B40
41219	30976	62.569277	62.586111000000002	54.870953	54.858283999999998	Школьная	0103000020E61000000100000005000000B8AE9811DE484F400C570740DC6D4B40B8AE9811DE484F4032AD4D637B6F4B40B6696CAF054B4F4032AD4D637B6F4B40B6696CAF054B4F400C570740DC6D4B40B8AE9811DE484F400C570740DC6D4B40
41538	29095	65.178173000000001	65.20205	54.781295999999998	54.771532999999998	Центральная	0103000020E61000000100000005000000EF01BA2F674B50407364E597C1624B40EF01BA2F674B5040703FE08101644B40098A1F63EE4C5040703FE08101644B40098A1F63EE4C50407364E597C1624B40EF01BA2F674B50407364E597C1624B40
40682	54950	65.076842999999997	65.111895000000004	54.920102999999997	54.895341000000002	Красноармейская	0103000020E610000001000000050000004CFBE6FEEA4450404CE2AC889A724B404CFBE6FEEA445040CAF962EFC5754B408065A54929475040CAF962EFC5754B408065A549294750404CE2AC889A724B404CFBE6FEEA4450404CE2AC889A724B40
41558	28057	66.184348999999997	66.233468999999999	54.886755999999998	54.876392000000003	Центральная	0103000020E610000001000000050000003883BF5FCC8B5040EF3CF19C2D704B403883BF5FCC8B504011C4793881714B404FE8F527F18E504011C4793881714B404FE8F527F18E5040EF3CF19C2D704B403883BF5FCC8B5040EF3CF19C2D704B40
41401	27894	66.205539999999999	66.219796000000002	54.766219999999997	54.755507999999999	Советская	0103000020E6100000010000000500000045813E91278D5040E5EE737CB4604B4045813E91278D504043C5387F13624B40AAF23D23118E504043C5387F13624B40AAF23D23118E5040E5EE737CB4604B4045813E91278D5040E5EE737CB4604B40
41209	27907	66.492407999999998	66.508415999999997	54.83614	54.831670000000003	Береговая	0103000020E610000001000000050000007B12D89C839F50403C889D29746A4B407B12D89C839F50405070B1A2066B4B40D73043E389A050405070B1A2066B4B40D73043E389A050403C889D29746A4B407B12D89C839F50403C889D29746A4B40
40975	27889	65.889019000000005	65.909724999999995	54.782967999999997	54.766286999999998	Садиковский	0103000020E6100000010000000500000073A1F2AFE5785040CB2C42B115624B4073A1F2AFE578504042E8A04B38644B40A1D634EF387A504042E8A04B38644B40A1D634EF387A5040CB2C42B115624B4073A1F2AFE5785040CB2C42B115624B40
41624	27798	66.574352000000005	66.605497	54.883364	54.862720000000003	Ленина	0103000020E610000001000000050000001A19E42EC2A4504075CDE49B6D6E4B401A19E42EC2A450405C3B511212714B40DF347D76C0A650405C3B511212714B40DF347D76C0A6504075CDE49B6D6E4B401A19E42EC2A4504075CDE49B6D6E4B40
40754	27643	65.769722000000002	65.782298999999995	55.055903000000001	55.049647999999998	Ленинская	0103000020E61000000100000005000000C040102043715040E9279CDD5A864B40C040102043715040C85F5AD427874B40622CD32F11725040C85F5AD427874B40622CD32F11725040E9279CDD5A864B40C040102043715040E9279CDD5A864B40
41399	27155	65.575317999999996	65.595207000000002	54.641289999999998	54.637132000000001	Центральная	0103000020E6100000010000000500000035B39602D2645040179E978A8D514B4035B39602D26450403CA06CCA15524B406BD619DF176650403CA06CCA15524B406BD619DF17665040179E978A8D514B4035B39602D2645040179E978A8D514B40
41524	27567	66.706260999999998	66.728925000000004	54.790433	54.784846999999999	Озерная	0103000020E610000001000000050000002D5C566133AD50408EAED2DD75644B402D5C566133AD5040EF5696E82C654B40280F0BB5A6AE5040EF5696E82C654B40280F0BB5A6AE50408EAED2DD75644B402D5C566133AD50408EAED2DD75644B40
40976	54948	65.947570999999996	66.019041000000001	54.806339999999999	54.781623000000003	Советская	0103000020E61000000100000005000000D5E8D500A57C50409566F3380C644B40D5E8D500A57C504073BA2C2636674B401F12BEF73781504073BA2C2636674B401F12BEF7378150409566F3380C644B40D5E8D500A57C50409566F3380C644B40
40745	54948	65.947570999999996	66.019041000000001	54.806339999999999	54.781623000000003	Победы	0103000020E61000000100000005000000D5E8D500A57C50409566F3380C644B40D5E8D500A57C504073BA2C2636674B401F12BEF73781504073BA2C2636674B401F12BEF7378150409566F3380C644B40D5E8D500A57C50409566F3380C644B40
40679	54948	65.947570999999996	66.019041000000001	54.806339999999999	54.781623000000003	Карла Маркса	0103000020E61000000100000005000000D5E8D500A57C50409566F3380C644B40D5E8D500A57C504073BA2C2636674B401F12BEF73781504073BA2C2636674B401F12BEF7378150409566F3380C644B40D5E8D500A57C50409566F3380C644B40
41207	27149	65.677160000000001	65.695314999999994	54.698493999999997	54.685614999999999	Ленина	0103000020E61000000100000005000000338AE596566B5040D252793BC2574B40338AE596566B5040E2395B4068594B40C45A7C0A806C5040E2395B4068594B40C45A7C0A806C5040D252793BC2574B40338AE596566B5040D252793BC2574B40
41206	27022	65.840204	65.868223	54.953121000000003	54.935628000000001	Молодежная	0103000020E61000000100000005000000FA7DFFE6C5755040679C86A8C2774B40FA7DFFE6C5755040BF1072DEFF794B40A4A833F790775040BF1072DEFF794B40A4A833F790775040679C86A8C2774B40FA7DFFE6C5755040679C86A8C2774B40
41501	26970	65.649203999999997	65.670512000000002	54.824606000000003	54.813884000000002	Советская	0103000020E61000000100000005000000AC1BEF8E8C6950406C5ED5592D684B40AC1BEF8E8C695040EE0A7DB08C694B40D6E429ABE96A5040EE0A7DB08C694B40D6E429ABE96A50406C5ED5592D684B40AC1BEF8E8C6950406C5ED5592D684B40
41211	27041	65.871834000000007	65.889773000000005	54.946989000000002	54.930843000000003	Школьная	0103000020E610000001000000050000009E62D520CC775040F35A09DD25774B409E62D520CC775040FC5580EF36794B4049F7730AF2785040FC5580EF36794B4049F7730AF2785040F35A09DD25774B409E62D520CC775040F35A09DD25774B40
41760	55055	65.670755	65.694264000000004	55.082689000000002	55.069060999999998	улица Победы	0103000020E61000000100000005000000392861A6ED6A5040EB36A8FDD6884B40392861A6ED6A5040965E9B8D958A4B4092B245D26E6C5040965E9B8D958A4B4092B245D26E6C5040EB36A8FDD6884B40392861A6ED6A5040EB36A8FDD6884B40
41409	28130	66.220963999999995	66.227225000000004	54.916139000000001	54.907438999999997	Веселая	0103000020E61000000100000005000000F9653046248E5040B60E0EF626744B40F9653046248E50408ACBF10A44754B405AF5B9DA8A8E50408ACBF10A44754B405AF5B9DA8A8E5040B60E0EF626744B40F9653046248E5040B60E0EF626744B40
41212	27091	65.910658999999995	65.924565000000001	54.887590000000003	54.877102000000001	Чуйкова	0103000020E61000000100000005000000B7B3AF3C487A5040CBA0DAE044704B40B7B3AF3C487A5040DA20938C9C714B40AE81AD122C7B5040DA20938C9C714B40AE81AD122C7B5040CBA0DAE044704B40B7B3AF3C487A5040CBA0DAE044704B40
41623	27417	66.009338999999997	66.025895000000006	54.828932000000002	54.826825999999997	Сиреневая	0103000020E61000000100000005000000F3E49A0299805040C2BD326FD5694B40F3E49A0299805040CF4D9B711A6A4B4051888043A8815040CF4D9B711A6A4B4051888043A8815040C2BD326FD5694B40F3E49A0299805040C2BD326FD5694B40
41621	26892	65.77328	65.796456000000006	54.642488	54.631321	Советская	0103000020E61000000100000005000000A8A9656B7D71504096236420CF504B40A8A9656B7D7150404609FA0B3D524B40FE2C9622F97250404609FA0B3D524B40FE2C9622F972504096236420CF504B40A8A9656B7D71504096236420CF504B40
41671	26885	66.067119000000005	66.086072999999999	54.893492999999999	54.882886999999997	Молодежная	0103000020E610000001000000050000002D7C7DAD4B8450402288F37002714B402D7C7DAD4B8450403B1A87FA5D724B4064045438828550403B1A87FA5D724B4064045438828550402288F37002714B402D7C7DAD4B8450402288F37002714B40
41400	26810	66.110004000000004	66.128752000000006	55.042447000000003	55.033703000000003	Школьная	0103000020E61000000100000005000000789B374E0A8750407863416150844B40789B374E0A8750401B683EE76E854B40DB5207793D8850401B683EE76E854B40DB5207793D8850407863416150844B40789B374E0A8750407863416150844B40
41023	26772	65.835155999999998	65.858179000000007	54.737516999999997	54.722467000000002	Ленина	0103000020E61000000100000005000000B9C326327375504039B874CC795C4B40B9C32632737550403C9F01F5665E4B404CC79C67EC7650403C9F01F5665E4B404CC79C67EC76504039B874CC795C4B40B9C326327375504039B874CC795C4B40
41522	26730	65.840860000000006	65.873638999999997	55.016506999999997	54.995151999999997	Школьная	0103000020E61000000100000005000000EF2076A6D075504045460724617F4B40EF2076A6D0755040D993C0E61C824B40A6608DB3E9775040D993C0E61C824B40A6608DB3E977504045460724617F4B40EF2076A6D075504045460724617F4B40
41203	26105	67.901398	67.910703999999996	55.286178999999997	55.275185	Озёрная	0103000020E6100000010000000500000082AB3C81B0F95040C5AC174339A34B4082AB3C81B0F95040A7E67283A1A44B4087156EF948FA5040A7E67283A1A44B4087156EF948FA5040C5AC174339A34B4082AB3C81B0F95040C5AC174339A34B40
41622	26344	68.047175999999993	68.073272000000003	55.153015000000003	55.142930999999997	Молодежная	0103000020E61000000100000005000000FD497CEE04035140D34A21904B924B40FD497CEE040351401366DAFE95934B409AED0A7DB00451401366DAFE95934B409AED0A7DB0045140D34A21904B924B40FD497CEE04035140D34A21904B924B40
41467	24746	67.716093000000001	67.739602000000005	54.970126999999998	54.964405999999997	Озёрная	0103000020E6100000010000000500000040F9BB77D4ED50407808E3A7717B4B4040F9BB77D4ED5040B9FB1C1F2D7C4B409983A0A355EF5040B9FB1C1F2D7C4B409983A0A355EF50407808E3A7717B4B4040F9BB77D4ED50407808E3A7717B4B40
41520	26680	67.782550000000001	67.796582000000001	55.155304000000001	55.147762	Центральная	0103000020E61000000100000005000000075F984C15F25040B8CB7EDDE9924B40075F984C15F2504010786000E1934B4044A51133FBF2504010786000E1934B4044A51133FBF25040B8CB7EDDE9924B40075F984C15F25040B8CB7EDDE9924B40
41521	26575	67.701566999999997	67.725758999999996	55.183621000000002	55.176116	Школьная	0103000020E61000000100000005000000FB3C4679E6EC5040B32616F88A964B40FB3C4679E6EC5040EEED96E480974B40C571E0D572EE5040EEED96E480974B40C571E0D572EE5040B32616F88A964B40FB3C4679E6EC5040B32616F88A964B40
41391	26012	67.561860999999993	67.574105000000003	55.144129999999997	55.136029999999998	Железнодорожная	0103000020E6100000010000000500000076F9D687F5E350402FA3586E69914B4076F9D687F5E35040AD2F12DA72924B4016DEE522BEE45040AD2F12DA72924B4016DEE522BEE450402FA3586E69914B4076F9D687F5E350402FA3586E69914B40
41614	26548	67.522677000000002	67.538730000000001	54.867103999999998	54.863	Школьная	0103000020E61000000100000005000000C5573B8A73E150405839B4C8766E4B40C5573B8A73E150408A1D8D43FD6E4B40F1D7648D7AE250408A1D8D43FD6E4B40F1D7648D7AE250405839B4C8766E4B40C5573B8A73E150405839B4C8766E4B40
41397	26451	67.944552999999999	67.971152000000004	55.107118	55.098072999999999	Набережная	0103000020E61000000100000005000000AD156D8E73FC504070CFF3A78D8C4B40AD156D8E73FC50400E68E90AB68D4B407BDCB75A27FE50400E68E90AB68D4B407BDCB75A27FE504070CFF3A78D8C4B40AD156D8E73FC504070CFF3A78D8C4B40
41202	25949	68.458605000000006	68.473849000000001	55.253152999999998	55.247539000000003	Московская	0103000020E610000001000000050000000E32C9C8591D514006BEA25BAF9F4B400E32C9C8591D514030F1475167A04B40828FC18A531E514030F1475167A04B40828FC18A531E514006BEA25BAF9F4B400E32C9C8591D514006BEA25BAF9F4B40
41618	26258	68.156214000000006	68.191410000000005	55.259315000000001	55.239922	Школьная	0103000020E610000001000000050000005A4B0169FF095140A3CB9BC3B59E4B405A4B0169FF0951405E2EE23B31A14B402788BA0F400C51405E2EE23B31A14B402788BA0F400C5140A3CB9BC3B59E4B405A4B0169FF095140A3CB9BC3B59E4B40
40892	54981	67.839387000000002	67.871150999999998	55.014453000000003	55.006186999999997	Озёрная	0103000020E61000000100000005000000016C4084B8F55040865451BCCA804B40016C4084B8F55040202A8D98D9814B402CB81FF0C0F75040202A8D98D9814B402CB81FF0C0F75040865451BCCA804B40016C4084B8F55040865451BCCA804B40
41188	25608	68.043717999999998	68.067729999999997	55.250520000000002	55.239471000000002	Молодежная	0103000020E61000000100000005000000C70F9546CC02514093AB58FCA69E4B40C70F9546CC025140397F130A11A04B4051BD35B055045140397F130A11A04B4051BD35B05504514093AB58FCA69E4B40C70F9546CC02514093AB58FCA69E4B40
41205	26065	67.823909	67.849806999999998	55.280928000000003	55.272953999999999	Центральная	0103000020E610000001000000050000005378D0ECBAF45040FCA71B28F0A24B405378D0ECBAF45040EE43DE72F5A34B405C3AE63C63F65040EE43DE72F5A34B405C3AE63C63F65040FCA71B28F0A24B405378D0ECBAF45040FCA71B28F0A24B40
41518	26624	67.655096999999998	67.669416999999996	55.231216000000003	55.228608000000001	Тополиная	0103000020E610000001000000050000004BADF71BEDE950404FCDE506439D4B404BADF71BEDE95040EE27637C989D4B40BB9866BAD7EA5040EE27637C989D4B40BB9866BAD7EA50404FCDE506439D4B404BADF71BEDE950404FCDE506439D4B40
41396	25917	67.773872999999995	67.796052000000003	55.086311000000002	55.072761999999997	Береговая	0103000020E6100000010000000500000079909E2287F150401E32E54350894B4079909E2287F150407D24253D0C8B4B40967A1684F2F250407D24253D0C8B4B40967A1684F2F250401E32E54350894B4079909E2287F150401E32E54350894B40
41609	25432	68.613393000000002	68.619664	55.260618000000001	55.248576	Новолебяжьевская	0103000020E610000001000000050000001AA6B6D44127514006499F56D19F4B401AA6B6D441275140DD5F3DEE5BA14B408CA03193A8275140DD5F3DEE5BA14B408CA03193A827514006499F56D19F4B401AA6B6D44127514006499F56D19F4B40
41394	25762	68.025813999999997	68.049045000000007	55.011705999999997	55.001787999999998	Береговая	0103000020E61000000100000005000000DA71C3EFA60151403BC3D4963A804B40DA71C3EFA60151405F950B957F814B4012C2A38D230351405F950B957F814B4012C2A38D230351403BC3D4963A804B40DA71C3EFA60151403BC3D4963A804B40
40890	13828	67.929191000000003	68.086997999999994	55.243166000000002	55.151451000000002	Мира	0103000020E61000000100000005000000342F87DD77FB504027F911BF62934B40342F87DD77FB5040E4BF4010209F4B4050340F6091055140E4BF4010209F4B4050340F609105514027F911BF62934B40342F87DD77FB504027F911BF62934B40
41395	26372	68.188597999999999	68.205063999999993	55.114868000000001	55.110202999999998	Школьная	0103000020E61000000100000005000000D38558FD110C5140E675C4211B8E4B40D38558FD110C5140B0AD9FFEB38E4B409065C1C41F0D5140B0AD9FFEB38E4B409065C1C41F0D5140E675C4211B8E4B40D38558FD110C5140E675C4211B8E4B40
41666	25702	68.045531999999994	68.059967999999998	55.086382999999998	55.079616999999999	Школьная	0103000020E61000000100000005000000F9BA0CFFE9025140529ACDE3308A4B40F9BA0CFFE902514016F71F990E8B4B409EB30584D603514016F71F990E8B4B409EB30584D6035140529ACDE3308A4B40F9BA0CFFE9025140529ACDE3308A4B40
41192	25603	68.113821999999999	68.144660999999999	55.312645000000003	55.302498999999997	Новая	0103000020E610000001000000050000002EE411DC480751404E098849B8A64B402EE411DC48075140042159C004A84B406D00362042095140042159C004A84B406D003620420951404E098849B8A64B402EE411DC480751404E098849B8A64B40
41693	25818	68.183801000000003	68.194481999999994	55.016480999999999	55.009967000000003	Привокзальная	0103000020E6100000010000000500000037FE4465C30B51400685419946814B4037FE4465C30B5140B000A60C1C824B40486AA164720C5140B000A60C1C824B40486AA164720C51400685419946814B4037FE4465C30B51400685419946814B40
41620	25746	68.209402999999995	68.225052000000005	55.076957999999998	55.072968000000003	Школьная	0103000020E61000000100000005000000CB2BD7DB660D5140C8D3F20357894B40CB2BD7DB660D514031957EC2D9894B4090F98040670E514031957EC2D9894B4090F98040670E5140C8D3F20357894B40CB2BD7DB660D5140C8D3F20357894B40
41392	26163	67.721770000000006	67.737544999999997	55.326712000000001	55.320856999999997	Плакуновская	0103000020E61000000100000005000000F94ECC7A31EE5040A9D898D711A94B40F94ECC7A31EE5040FA9AE5B2D1A94B400395F1EF33EF5040FA9AE5B2D1A94B400395F1EF33EF5040A9D898D711A94B40F94ECC7A31EE5040A9D898D711A94B40
41393	26295	68.132767999999999	68.142757000000003	55.228973000000003	55.226118	Приозёрная	0103000020E61000000100000005000000247D5A457F085140BA84436FF19C4B40247D5A457F0851406155BDFC4E9D4B409B9141EE220951406155BDFC4E9D4B409B9141EE22095140BA84436FF19C4B40247D5A457F085140BA84436FF19C4B40
41406	26474	67.581740999999994	67.609948000000003	54.914394999999999	54.907434000000002	С. Баева	0103000020E61000000100000005000000826F9A3E3BE55040A5A31CCC26744B40826F9A3E3BE550401E5036E50A754B40AE10566309E750401E5036E50A754B40AE10566309E75040A5A31CCC26744B40826F9A3E3BE55040A5A31CCC26744B40
41186	25394	68.554445999999999	68.577685000000002	55.296903	55.288542	Набережная	0103000020E610000001000000050000007959130B7C235140DFC2BAF1EEA44B407959130B7C235140CA8AE1EA00A64B40F29881CAF8245140CA8AE1EA00A64B40F29881CAF8245140DFC2BAF1EEA44B407959130B7C235140DFC2BAF1EEA44B40
41517	25514	67.403604999999999	67.441164000000001	54.989821999999997	54.980549000000003	Северная	0103000020E6100000010000000500000022E010AAD4D9504011902FA1827D4B4022E010AAD4D950403F6EBF7CB27E4B400B0BEE073CDC50403F6EBF7CB27E4B400B0BEE073CDC504011902FA1827D4B4022E010AAD4D9504011902FA1827D4B40
41611	24815	67.589988000000005	67.611305000000002	54.955148000000001	54.945914000000002	Советская	0103000020E610000001000000050000001442075DC2E550400E6ABFB513794B401442075DC2E550407F6B274A427A4B4067B8019F1FE750407F6B274A427A4B4067B8019F1FE750400E6ABFB513794B401442075DC2E550400E6ABFB513794B40
41002	25326	68.311982	68.338751000000002	55.316785000000003	55.301842999999998	Советская	0103000020E6100000010000000500000034BC5983F713514065C39ACAA2A64B4034BC5983F7135140836E2F698CA84B40309FAC18AE155140836E2F698CA84B40309FAC18AE15514065C39ACAA2A64B4034BC5983F713514065C39ACAA2A64B40
41563	23586	66.613932000000005	66.626293000000004	55.993428999999999	55.985492999999998	Молодежная	0103000020E61000000100000005000000F27D71A94AA75040EDB776A224FE4B40F27D71A94AA75040F1F274AE28FF4B40AE2D3C2F15A85040F1F274AE28FF4B40AE2D3C2F15A85040EDB776A224FE4B40F27D71A94AA75040EDB776A224FE4B40
41184	24668	67.293328000000002	67.309004000000002	55.718471000000001	55.707745000000003	Школьная	0103000020E6100000010000000500000012C0CDE2C5D250402A745E6397DA4B4012C0CDE2C5D25040ED0F94DBF6DB4B405395B6B8C6D35040ED0F94DBF6DB4B405395B6B8C6D350402A745E6397DA4B4012C0CDE2C5D250402A745E6397DA4B40
41616	24283	66.886921000000001	66.915254000000004	55.709353	55.697406999999998	70 лет Октября	0103000020E61000000100000005000000AE484C50C3B850403080F0A144D94B40AE484C50C3B85040E5284014CCDA4B402062838593BA5040E5284014CCDA4B402062838593BA50403080F0A144D94B40AE484C50C3B850403080F0A144D94B40
41213	23506	66.647053	66.662208000000007	55.939740999999998	55.920093000000001	Центральная	0103000020E61000000100000005000000D671FC5069A95040A723809BC5F54B40D671FC5069A95040ECDADE6E49F84B4093C9A99D61AA5040ECDADE6E49F84B4093C9A99D61AA5040A723809BC5F54B40D671FC5069A95040A723809BC5F54B40
41035	23822	66.838348999999994	66.854797000000005	55.584654999999998	55.562811000000004	Школьная	0103000020E6100000010000000500000098689082A7B550401F6ADB300AC84B4098689082A7B55040B0389CF9D5CA4B4003EE79FEB4B65040B0389CF9D5CA4B4003EE79FEB4B650401F6ADB300AC84B4098689082A7B550401F6ADB300AC84B40
41311	24355	66.870365000000007	66.877103000000005	55.736975000000001	55.728140000000003	Школьная	0103000020E6100000010000000500000051A5660FB4B75040697407B133DD4B4051A5660FB4B750401C7C613255DE4B404E0E9F7422B850401C7C613255DE4B404E0E9F7422B85040697407B133DD4B4051A5660FB4B75040697407B133DD4B40
41738	55044	66.625736000000003	66.649910000000006	55.645547000000001	55.628855999999999	40 лет Победы	0103000020E6100000010000000500000083FB010F0CA850405AF2785A7ED04B4083FB010F0CA85040F583BA48A1D24B40FAD51C2098A95040F583BA48A1D24B40FAD51C2098A950405AF2785A7ED04B4083FB010F0CA850405AF2785A7ED04B40
41385	23988	66.402728999999994	66.424503999999999	55.700719999999997	55.690517	Школьная	0103000020E61000000100000005000000A609DB4FC6995040802A6EDC62D84B40A609DB4FC699504099D36531B1D94B405B41D3122B9B504099D36531B1D94B405B41D3122B9B5040802A6EDC62D84B40A609DB4FC6995040802A6EDC62D84B40
41389	24469	67.113367999999994	67.134756999999993	55.662968999999997	55.651891999999997	Вострецова	0103000020E610000001000000050000006D1ADB6B41C750401343723271D34B406D1ADB6B41C7504083A10E2BDCD44B400DFAD2DB9FC8504083A10E2BDCD44B400DFAD2DB9FC850401343723271D34B406D1ADB6B41C750401343723271D34B40
41388	24568	67.048151000000004	67.064186000000007	55.843969999999999	55.830311000000002	Октябрьская	0103000020E610000001000000050000004391EEE714C3504029417FA147EA4B404391EEE714C350400E677E3507EC4B401CB7989F1BC450400E677E3507EC4B401CB7989F1BC4504029417FA147EA4B404391EEE714C3504029417FA147EA4B40
41197	23945	66.442757999999998	66.460229999999996	55.674970999999999	55.668132	Войкова	0103000020E61000000100000005000000B682A625569C50409EB4705985D54B40B682A625569C5040CC5F217365D64B40D6A88768749D5040CC5F217365D64B40D6A88768749D50409EB4705985D54B40B682A625569C50409EB4705985D54B40
41562	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	Советская	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
41383	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	Сабанина	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
41378	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	Октябрьская	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
41198	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	Механизаторов	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
41372	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	Лесная	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
40885	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	Куйбышева	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
40883	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	Береговая	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
40882	54980	66.748293000000004	66.795508999999996	55.828076000000003	55.791552000000003	40 лет Победы	0103000020E61000000100000005000000D9B45208E4AF5040AD8A709351E54B40D9B45208E4AF50401F4DF564FEE94B401DAB949EE9B250401F4DF564FEE94B401DAB949EE9B25040AD8A709351E54B40D9B45208E4AF5040AD8A709351E54B40
41564	23906	66.479759999999999	66.502657999999997	55.643926999999998	55.626472	Центральная	0103000020E61000000100000005000000747B4963B49E50400BEE073C30D04B40747B4963B49E504075012F336CD24B40A8C4758C2BA0504075012F336CD24B40A8C4758C2BA050400BEE073C30D04B40747B4963B49E50400BEE073C30D04B40
41605	24398	66.937020000000004	66.947772999999998	55.697629999999997	55.689943	Вторая Школьная	0103000020E61000000100000005000000ABECBB22F8BB5040548D5E0D50D84B40ABECBB22F8BB5040AF5A99F04BD94B4009C21550A8BC5040AF5A99F04BD94B4009C21550A8BC5040548D5E0D50D84B40ABECBB22F8BB5040548D5E0D50D84B40
41572	24085	66.358900000000006	66.371027999999995	55.781447999999997	55.769778000000002	2-я Береговая	0103000020E6100000010000000500000034A2B437F89650401497E31588E24B4034A2B437F896504026C3F17C06E44B409E7939ECBE97504026C3F17C06E44B409E7939ECBE9750401497E31588E24B4034A2B437F89650401497E31588E24B40
41617	24492	67.309164999999993	67.321202999999997	55.556930000000001	55.547075999999997	Школьная	0103000020E610000001000000050000005704FF5BC9D3504097361C9606C64B405704FF5BC9D35040A514747B49C74B40221807978ED45040A514747B49C74B40221807978ED4504097361C9606C64B405704FF5BC9D3504097361C9606C64B40
41379	23631	66.658991999999998	66.676373999999996	55.722577999999999	55.708109999999998	Дружбы	0103000020E61000000100000005000000D714C8EC2CAA50403BFC3559A3DA4B40D714C8EC2CAA50409067976F7DDC4B4057772CB649AB50409067976F7DDC4B4057772CB649AB50403BFC3559A3DA4B40D714C8EC2CAA50403BFC3559A3DA4B40
41182	24597	67.182269000000005	67.206308000000007	55.790579999999999	55.769599999999997	Победы	0103000020E61000000100000005000000C784984BAACB50403480B74082E24B40C784984BAACB5040936FB6B931E54B40CE39782634CD5040936FB6B931E54B40CE39782634CD50403480B74082E24B40C784984BAACB50403480B74082E24B40
41737	23398	66.734808999999998	66.748059999999995	55.852004999999998	55.841856999999997	переулок Школьный	0103000020E610000001000000050000009DF3531C07AF50404F745DF8C1EB4B409DF3531C07AF5040A583F57F0EED4B4087DC0C37E0AF5040A583F57F0EED4B4087DC0C37E0AF50404F745DF8C1EB4B409DF3531C07AF50404F745DF8C1EB4B40
41578	55039	66.706225000000003	66.713924000000006	55.881368999999999	55.870789000000002	Центральная	0103000020E6100000010000000500000087A757CA32AD5040B85B920376EF4B4087A757CA32AD5040A75A0BB3D0F04B4017F549EEB0AD5040A75A0BB3D0F04B4017F549EEB0AD5040B85B920376EF4B4087A757CA32AD5040B85B920376EF4B40
41381	23498	66.860114999999993	66.878692999999998	55.865025000000003	55.858508	А. Прокопьева	0103000020E6100000010000000500000023F3C81F0CB750405CAD1397E3ED4B4023F3C81F0CB75040789CA223B9EE4B40588E90813CB85040789CA223B9EE4B40588E90813CB850405CAD1397E3ED4B4023F3C81F0CB750405CAD1397E3ED4B40
41195	24074	66.370084000000006	66.388966999999994	55.732311000000003	55.713664000000001	Новая	0103000020E610000001000000050000007731CD74AF975040912A8A5759DB4B407731CD74AF97504023C0E95DBCDD4B40490ED8D5E498504023C0E95DBCDD4B40490ED8D5E4985040912A8A5759DB4B407731CD74AF975040912A8A5759DB4B40
41667	22781	63.558070000000001	63.580976999999997	55.608445000000003	55.593690000000002	Советская	0103000020E610000001000000050000007A7077D66EC74F402BFBAE08FECB4B407A7077D66EC74F4016359886E1CD4B40355D4F745DCA4F4016359886E1CD4B40355D4F745DCA4F402BFBAE08FECB4B407A7077D66EC74F402BFBAE08FECB4B40
41369	22348	63.324167000000003	64.345201000000003	55.854698999999997	54.957500000000003	Береговая	0103000020E61000000100000005000000A2B8E34D7EA94F40C3F5285C8F7A4B40A2B8E34D7EA94F404276DEC666ED4B40FA62EFC5171650404276DEC666ED4B40FA62EFC517165040C3F5285C8F7A4B40A2B8E34D7EA94F40C3F5285C8F7A4B40
41374	22506	63.814135	63.831426999999998	55.006957	54.992342999999998	Солнечная	0103000020E61000000100000005000000B5C35F9335E84F400FB56D18057F4B40B5C35F9335E84F4038BD8BF7E3804B4075012F336CEA4F4038BD8BF7E3804B4075012F336CEA4F400FB56D18057F4B40B5C35F9335E84F400FB56D18057F4B40
41734	21854	64.089370000000002	64.102018000000001	55.401192000000002	55.389958999999998	Школьная	0103000020E6100000010000000500000096CFF23CB8055040F3E32F2DEAB14B4096CFF23CB80550405BB56B425AB34B409D668176870650405BB56B425AB34B409D66817687065040F3E32F2DEAB14B4096CFF23CB8055040F3E32F2DEAB14B40
41310	21759	64.126075	64.142630999999994	55.350945000000003	55.347157000000003	Станционная	0103000020E61000000100000005000000F775E09C11085040EBC9FCA36FAC4B40F775E09C11085040EDD808C4EBAC4B405419C6DD20095040EDD808C4EBAC4B405419C6DD20095040EBC9FCA36FAC4B40F775E09C11085040EBC9FCA36FAC4B40
41194	22689	63.786062999999999	63.803426999999999	55.550621	55.534097000000003	Советская	0103000020E610000001000000050000003ECC5EB69DE44F4024F25D4A5DC44B403ECC5EB69DE44F40D3BEB9BF7AC64B4098DC28B2D6E64F40D3BEB9BF7AC64B4098DC28B2D6E64F4024F25D4A5DC44B403ECC5EB69DE44F4024F25D4A5DC44B40
41730	22599	63.821365999999998	63.838811999999997	55.350551000000003	55.339810999999997	Береговая	0103000020E61000000100000005000000EE05668522E94F4018E945ED7EAB4B40EE05668522E94F40414AECDADEAC4B4005BF0D315EEB4F40414AECDADEAC4B4005BF0D315EEB4F4018E945ED7EAB4B40EE05668522E94F4018E945ED7EAB4B40
41376	22518	63.887374999999999	63.909680000000002	55.784835000000001	55.767944	Луговая	0103000020E61000000100000005000000DD24068195F14F4068942EFD4BE24B40DD24068195F14F40CAE0287975E44B40A3E9EC6470F44F40CAE0287975E44B40A3E9EC6470F44F4068942EFD4BE24B40DD24068195F14F4068942EFD4BE24B40
41561	22416	63.775615000000002	63.793258000000002	55.048023000000001	55.033672000000003	Центральная	0103000020E61000000100000005000000BEA4315A47E34F403D65355D4F844B40BEA4315A47E34F40583A1F9E25864B402BA5677A89E54F40583A1F9E25864B402BA5677A89E54F403D65355D4F844B40BEA4315A47E34F403D65355D4F844B40
41387	22849	63.400227000000001	63.429934000000003	55.664704999999998	55.660699000000001	Озёрная	0103000020E61000000100000005000000F4FC69A33AB34F40FDBFEAC891D44B40F4FC69A33AB34F406C3EAE0D15D54B4020B8CA1308B74F406C3EAE0D15D54B4020B8CA1308B74F40FDBFEAC891D44B40F4FC69A33AB34F40FDBFEAC891D44B40
40974	21187	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	Победы	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
40801	54929	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	Строительная	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
41550	54929	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	Северная	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
40525	54929	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	Рабоче-крестьянская	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
40593	54929	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	Первомайская	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
40591	54929	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	Ленина	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
41196	54929	63.880619000000003	63.93777	55.361210999999997	55.324810999999997	Заводская	0103000020E610000001000000050000003D9E961FB8F04F40C630276893A94B403D9E961FB8F04F404CFA7B293CAE4B40C095ECD808F84F404CFA7B293CAE4B40C095ECD808F84F40C630276893A94B403D9E961FB8F04F40C630276893A94B40
41560	22611	63.769668000000003	63.778939000000001	55.25206	55.244217999999996	Южная	0103000020E610000001000000050000008D63247B84E24F40198C1189429F4B408D63247B84E24F409C50888043A04B401B4AED45B4E34F409C50888043A04B401B4AED45B4E34F40198C1189429F4B408D63247B84E24F40198C1189429F4B40
41559	22411	63.788415999999998	63.816775999999997	55.212955000000001	55.197209000000001	Новая	0103000020E6100000010000000500000052D2C3D0EAE44F400ABDFE243E994B4052D2C3D0EAE44F408542041C429B4B402F14B01D8CE84F408542041C429B4B402F14B01D8CE84F400ABDFE243E994B4052D2C3D0EAE44F400ABDFE243E994B40
41732	22085	63.567233000000002	63.589305000000003	55.474271000000002	55.465671999999998	Сиреневая	0103000020E61000000100000005000000221B48179BC84F40DA54DD239BBB4B40221B48179BC84F407A3881E9B4BC4B40452FA3586ECB4F407A3881E9B4BC4B40452FA3586ECB4F40DA54DD239BBB4B40221B48179BC84F40DA54DD239BBB4B40
41368	22277	64.088211000000001	64.098326	55.161358	55.152813999999999	Береговая	0103000020E610000001000000050000007009C03FA50550407B2FBE688F934B407009C03FA505504057790261A7944B402D9622F94A06504057790261A7944B402D9622F94A0650407B2FBE688F934B407009C03FA50550407B2FBE688F934B40
41193	22343	63.634408999999998	63.663603999999999	55.654527999999999	55.639871999999997	Центральная	0103000020E61000000100000005000000DFA4695034D14F4024D06053E7D14B40DFA4695034D14F407C28D192C7D34B4055BFD2F9F0D44F407C28D192C7D34B4055BFD2F9F0D44F4024D06053E7D14B40DFA4695034D14F4024D06053E7D14B40
41033	54998	64.013282000000004	64.037824000000001	55.264434999999999	55.248047	Мира	0103000020E6100000010000000500000008E8BE9CD90050407A6F0C01C09F4B4008E8BE9CD900504079758E01D9A14B4040C05AB56B02504079758E01D9A14B4040C05AB56B0250407A6F0C01C09F4B4008E8BE9CD90050407A6F0C01C09F4B40
41733	22171	63.940573000000001	63.965133000000002	55.111145	55.090314999999997	Ленина	0103000020E61000000100000005000000144031B264F84F404BAB21718F8B4B40144031B264F84F40950ED6FF398E4B402BA5677A89FB4F40950ED6FF398E4B402BA5677A89FB4F404BAB21718F8B4B40144031B264F84F404BAB21718F8B4B40
41010	54996	63.731400000000001	63.786045000000001	55.565722000000001	55.540837000000003	Кирова	0103000020E61000000100000005000000AF25E4839EDD4F40BFBB95253AC54B40AF25E4839EDD4F405950189469C84B409817601F9DE44F405950189469C84B409817601F9DE44F40BFBB95253AC54B40AF25E4839EDD4F40BFBB95253AC54B40
41370	21582	63.855519999999999	63.866947000000003	55.392403000000002	55.386758	Николаева	0103000020E610000001000000050000007689EAAD81ED4F40B2BB404981B14B407689EAAD81ED4F4018EDF1423AB24B40C32E8A1EF8EE4F4018EDF1423AB24B40C32E8A1EF8EE4F40B2BB404981B14B407689EAAD81ED4F40B2BB404981B14B40
40803	21984	63.850867000000001	63.877941999999997	55.712234000000002	55.688609	Советская	0103000020E61000000100000005000000711FB935E9EC4F409A5DF75624D84B40711FB935E9EC4F40B58CD47B2ADB4B4075E4486760F04F40B58CD47B2ADB4B4075E4486760F04F409A5DF75624D84B40711FB935E9EC4F409A5DF75624D84B40
41190	21893	63.709769000000001	63.726917	55.384507999999997	55.370804999999997	Центральная	0103000020E61000000100000005000000795BE9B5D9DA4F40BD18CA8976AF4B40795BE9B5D9DA4F407286E28E37B14B4006F4C29D0BDD4F407286E28E37B14B4006F4C29D0BDD4F40BD18CA8976AF4B40795BE9B5D9DA4F40BD18CA8976AF4B40
41756	55052	63.813766999999999	63.839261	55.568517	55.561715999999997	Школьная	0103000020E6100000010000000500000032C85D8429E84F40E9D1544FE6C74B4032C85D8429E84F402A1C412AC5C84B4075E789E76CEB4F402A1C412AC5C84B4075E789E76CEB4F40E9D1544FE6C74B4032C85D8429E84F40E9D1544FE6C74B40
40802	21793	64.060344999999998	64.082020999999997	55.370666	55.352808000000003	Садовая	0103000020E61000000100000005000000895E46B1DC03504033E202D028AD4B40895E46B1DC0350409CDEC5FB71AF4B40742502D53F0550409CDEC5FB71AF4B40742502D53F05504033E202D028AD4B40895E46B1DC03504033E202D028AD4B40
41027	21681	64.067387999999994	64.094616000000002	55.327463999999999	55.320883000000002	Советская	0103000020E610000001000000050000002409C21550045040D36BB3B112A94B402409C21550045040054F2157EAA94B406A6B44300E065040054F2157EAA94B406A6B44300E065040D36BB3B112A94B402409C21550045040D36BB3B112A94B40
41297	21965	63.544657999999998	63.579495000000001	55.380538999999999	55.369055000000003	Центральная	0103000020E610000001000000050000009CC0745AB7C54F4070B6B9313DAF4B409CC0745AB7C54F4020ED7F80B5B04B40079964E42CCA4F4020ED7F80B5B04B40079964E42CCA4F4070B6B9313DAF4B409CC0745AB7C54F4070B6B9313DAF4B40
41554	21965	63.544657999999998	63.579495000000001	55.380538999999999	55.369055000000003	Лесная	0103000020E610000001000000050000009CC0745AB7C54F4070B6B9313DAF4B409CC0745AB7C54F4020ED7F80B5B04B40079964E42CCA4F4020ED7F80B5B04B40079964E42CCA4F4070B6B9313DAF4B409CC0745AB7C54F4070B6B9313DAF4B40
41293	19404	67.304232999999996	67.310143999999994	55.144053	55.137059999999998	Яснозаринская	0103000020E610000001000000050000004B57B08D78D350407DCB9C2E8B914B404B57B08D78D3504002F2255470924B403D433866D9D3504002F2255470924B403D433866D9D350407DCB9C2E8B914B404B57B08D78D350407DCB9C2E8B914B40
41295	20098	67.266801000000001	67.280885999999995	55.074561000000003	55.064627999999999	Центральная	0103000020E610000001000000050000009162804413D15040F433F5BA45884B409162804413D150404E4700378B894B40DFF94509FAD150404E4700378B894B40DFF94509FAD15040F433F5BA45884B409162804413D15040F433F5BA45884B40
41125	19562	67.222020000000001	67.233104999999995	55.343291999999998	55.334747	Центральная	0103000020E61000000100000005000000B5C35F9335CE504091B75CFDD8AA4B40B5C35F9335CE50403D7D04FEF0AB4B402EE23B31EBCE50403D7D04FEF0AB4B402EE23B31EBCE504091B75CFDD8AA4B40B5C35F9335CE504091B75CFDD8AA4B40
41661	19759	67.297020000000003	67.325424999999996	55.514136000000001	55.502527999999998	Школьная	0103000020E6100000010000000500000082902C6002D3504082A966D652C04B4082902C6002D350401FD95C35CFC14B40401361C3D3D450401FD95C35CFC14B40401361C3D3D4504082A966D652C04B4082902C6002D3504082A966D652C04B40
41729	21021	66.853468000000007	66.873626000000002	55.054743000000002	55.045938999999997	Береговая	0103000020E61000000100000005000000AF0B3F389FB65040334E4354E1854B40AF0B3F389FB65040AC5791D101874B40DCBB067DE9B75040AC5791D101874B40DCBB067DE9B75040334E4354E1854B40AF0B3F389FB65040334E4354E1854B40
41021	19966	67.425280999999998	67.438261999999995	55.192470999999998	55.185847000000003	Мира	0103000020E610000001000000050000000DA7CCCD37DB5040A587A1D5C9974B400DA7CCCD37DB5040D636C5E3A2984B4017450F7C0CDC5040D636C5E3A2984B4017450F7C0CDC5040A587A1D5C9974B400DA7CCCD37DB5040A587A1D5C9974B40
41382	20201	67.207691999999994	67.230320000000006	54.980963000000003	54.968623000000001	Молодежная	0103000020E6100000010000000500000003E962D34ACD5040A393A5D6FB7B4B4003E962D34ACD504004CB1132907D4B4058E71890BDCE504004CB1132907D4B4058E71890BDCE5040A393A5D6FB7B4B4003E962D34ACD5040A393A5D6FB7B4B40
41725	20344	67.057637	67.083212000000003	55.082394999999998	55.073293	Школьная	0103000020E6100000010000000500000088821953B0C350404B033FAA61894B4088821953B0C350404D2D5BEB8B8A4B40A0A86C5853C550404D2D5BEB8B8A4B40A0A86C5853C550404B033FAA61894B4088821953B0C350404B033FAA61894B40
41745	55046	67.249239000000003	67.258869000000004	55.181555000000003	55.176203000000001	Пролетарская	0103000020E61000000100000005000000D1782288F3CF5040823AE5D18D964B40D1782288F3CF504070B6B9313D974B40B03C484F91D0504070B6B9313D974B40B03C484F91D05040823AE5D18D964B40D1782288F3CF5040823AE5D18D964B40
41552	20621	67.118722000000005	67.126429999999999	55.278123999999998	55.271790000000003	Центральная	0103000020E6100000010000000500000035D4282499C750409FB0C403CAA24B4035D4282499C75040C91D369199A34B40EECEDA6D17C85040C91D369199A34B40EECEDA6D17C850409FB0C403CAA24B4035D4282499C750409FB0C403CAA24B40
41553	20789	67.000217000000006	67.013727000000003	54.896101999999999	54.887765999999999	Дерибасовская	0103000020E61000000100000005000000CFF9298E03C050401840F850A2714B40CFF9298E03C05040AAF06778B3724B409F0436E7E0C05040AAF06778B3724B409F0436E7E0C050401840F850A2714B40CFF9298E03C050401840F850A2714B40
41126	20685	67.014167	67.028379000000001	55.208677000000002	55.204695000000001	Центральная	0103000020E61000000100000005000000AD6BB41CE8C05040CE531D72339A4B40AD6BB41CE8C05040B5368DEDB59A4B402A3927F6D0C15040B5368DEDB59A4B402A3927F6D0C15040CE531D72339A4B40AD6BB41CE8C05040CE531D72339A4B40
41292	19799	67.208265999999995	67.222154000000003	55.474826999999998	55.468657999999998	Центральная	0103000020E6100000010000000500000099B7EA3A54CD50401F813FFCFCBB4B4099B7EA3A54CD5040FF209221C7BC4B403D2B69C537CE5040FF209221C7BC4B403D2B69C537CE50401F813FFCFCBB4B4099B7EA3A54CD50401F813FFCFCBB4B40
41018	54997	67.505735000000001	67.522524000000004	55.270240999999999	55.257303999999998	Советская	0103000020E61000000100000005000000535C55F65DE05040A3906456EFA04B40535C55F65DE05040E884D04197A24B4002D8800871E15040E884D04197A24B4002D8800871E15040A3906456EFA04B40535C55F65DE05040A3906456EFA04B40
41181	21114	66.962146000000004	66.967922000000002	54.982812000000003	54.974747000000001	Центральная 	0103000020E610000001000000050000008BFED0CC93BD5040E36F7B82C47C4B408BFED0CC93BD5040E50E9BC8CC7D4B400DC51D6FF2BD5040E50E9BC8CC7D4B400DC51D6FF2BD5040E36F7B82C47C4B408BFED0CC93BD5040E36F7B82C47C4B40
41015	19461	67.362398999999996	67.384884	55.304015999999997	55.293315	Т.Дрязгова	0103000020E610000001000000050000009946938B31D750408F368E588BA54B409946938B31D75040F9BA0CFFE9A64B403C3080F0A1D85040F9BA0CFFE9A64B403C3080F0A1D850408F368E588BA54B409946938B31D750408F368E588BA54B40
41549	20937	66.829087999999999	66.839724000000004	54.810822999999999	54.800823999999999	Лесная	0103000020E6100000010000000500000063601DC70FB550400BED9C6681664B4063601DC70FB550401CEC4D0CC9674B40A56ABB09BEB550401CEC4D0CC9674B40A56ABB09BEB550400BED9C6681664B4063601DC70FB550400BED9C6681664B40
41728	21014	66.818091999999993	66.836040999999994	54.989156000000001	54.977744000000001	Молодежная	0103000020E61000000100000005000000A1478C9E5BB450401CEE23B7267D4B40A1478C9E5BB450403352EFA99C7E4B405E471CB281B550403352EFA99C7E4B405E471CB281B550401CEE23B7267D4B40A1478C9E5BB450401CEE23B7267D4B40
41016	19870	67.041017999999994	67.081451000000001	55.383443999999997	55.372038000000003	Советская	0103000020E610000001000000050000000723F609A0C25040446FF1F09EAF4B400723F609A0C2504078EC67B114B14B407F4E417E36C5504078EC67B114B14B407F4E417E36C55040446FF1F09EAF4B400723F609A0C25040446FF1F09EAF4B40
41183	20260	67.171713999999994	67.201393999999993	54.916837000000001	54.901558999999999	Школьная	0103000020E61000000100000005000000FB90B75CFDCA50400D350A4966734B40FB90B75CFDCA5040A26131EA5A754B4014E7A8A3E3CC5040A26131EA5A754B4014E7A8A3E3CC50400D350A4966734B40FB90B75CFDCA50400D350A4966734B40
41659	18962	67.190326999999996	67.276458000000005	55.233167000000002	55.190004999999999	Ленина	0103000020E61000000100000005000000EE224C512ECC5040CA89761552984B40EE224C512ECC5040D3C08F6AD89D4B40ED2DE57CB1D15040D3C08F6AD89D4B40ED2DE57CB1D15040CA89761552984B40EE224C512ECC5040CA89761552984B40
41694	55043	67.382368999999997	67.402041999999994	55.339590000000001	55.336457000000003	Центральная	0103000020E610000001000000050000004580D3BB78D8504051C1E10511AB4B404580D3BB78D850403A0664AF77AB4B4094675E0EBBD950403A0664AF77AB4B4094675E0EBBD9504051C1E10511AB4B404580D3BB78D8504051C1E10511AB4B40
41025	20576	66.943253999999996	66.972081000000003	55.263582999999997	55.250238000000003	Молодежная	0103000020E610000001000000050000008E7406465EBC5040B51B7DCC07A04B408E7406465EBC50400A647616BDA14B4008043A9336BE50400A647616BDA14B4008043A9336BE5040B51B7DCC07A04B408E7406465EBC5040B51B7DCC07A04B40
41731	20817	66.723392000000004	66.742785999999995	54.936621000000002	54.92895	Глинских	0103000020E61000000100000005000000098CF50D4CAE504042CF66D5E7764B40098CF50D4CAE504098DF6932E3774B404E7B4ACE89AF504098DF6932E3774B404E7B4ACE89AF504042CF66D5E7764B40098CF50D4CAE504042CF66D5E7764B40
41660	19629	67.397864999999996	67.431031000000004	55.405337000000003	55.389611000000002	Школьная	0103000020E6100000010000000500000046CEC29E76D95040B894F3C5DEB14B4046CEC29E76D95040EC6D3315E2B34B40FB230C0396DB5040EC6D3315E2B34B40FB230C0396DB5040B894F3C5DEB14B4046CEC29E76D95040B894F3C5DEB14B40
41548	20466	66.982204999999993	67.007465999999994	55.129519999999999	55.119053999999998	Центральная	0103000020E61000000100000005000000EE3D5C72DCBE50409F3A56293D8F4B40EE3D5C72DCBE5040C616821C94904B403E75AC527AC05040C616821C94904B403E75AC527AC050409F3A56293D8F4B40EE3D5C72DCBE50409F3A56293D8F4B40
9884	40343	67.301179000000005	67.315534	55.198216000000002	55.192892999999998	Восточная	0103000020E610000001000000050000007DCF488446D350404C50C3B7B0984B407DCF488446D35040A0C552245F994B40ABB184B531D45040A0C552245F994B40ABB184B531D450404C50C3B7B0984B407DCF488446D350404C50C3B7B0984B40
41546	20371	67.115425999999999	67.127354999999994	55.096167000000001	55.085811	Центральная	0103000020E61000000100000005000000EBC6BB2363C750408B51D7DAFB8A4B40EBC6BB2363C750402BFA43334F8C4B40DAFE959526C850402BFA43334F8C4B40DAFE959526C850408B51D7DAFB8A4B40EBC6BB2363C750408B51D7DAFB8A4B40
41692	20153	67.323952000000006	67.340534000000005	55.057022000000003	55.04842	Крестьянская	0103000020E61000000100000005000000535E2BA1BBD45040753C66A032864B40535E2BA1BBD450408693347F4C874B40454B1E4FCBD550408693347F4C874B40454B1E4FCBD55040753C66A032864B40535E2BA1BBD45040753C66A032864B40
41723	20891	66.726715999999996	66.734576000000004	54.863844999999998	54.854159000000003	Мира	0103000020E61000000100000005000000B75ED38382AE5040C34A0515556D4B40B75ED38382AE504014E81379926E4B404C1B0E4B03AF504014E81379926E4B404C1B0E4B03AF5040C34A0515556D4B40B75ED38382AE5040C34A0515556D4B40
40880	20729	66.928531000000007	66.967769000000004	54.926755999999997	54.913603000000002	Первомайская	0103000020E610000001000000050000009F94490D6DBB504085436FF1F0744B409F94490D6DBB504096AFCBF09F764B404A4563EDEFBD504096AFCBF09F764B404A4563EDEFBD504085436FF1F0744B409F94490D6DBB504085436FF1F0744B40
41365	20513	66.900773000000001	66.919458000000006	55.183985999999997	55.179858000000003	Центральная	0103000020E61000000100000005000000AB07CC43A6B9504045F6419605974B40AB07CC43A6B95040FF756EDA8C974B40EB025E66D8BA5040FF756EDA8C974B40EB025E66D8BA504045F6419605974B40AB07CC43A6B9504045F6419605974B40
41664	20015	67.479522000000003	67.500309000000001	55.040956000000001	55.025292	Школьная	0103000020E610000001000000050000009AED0A7DB0DE5040DB6CACC43C834B409AED0A7DB0DE50409949D40B3E854B403F390A1005E050409949D40B3E854B403F390A1005E05040DB6CACC43C834B409AED0A7DB0DE5040DB6CACC43C834B40
41665	19697	67.431236999999996	67.439520000000002	55.445144999999997	55.439599000000001	Центральная	0103000020E61000000100000005000000CFF4126399DB50405A2DB0C744B84B40CFF4126399DB50402C7DE882FAB84B40077C7E1821DC50402C7DE882FAB84B40077C7E1821DC50405A2DB0C744B84B40CFF4126399DB50405A2DB0C744B84B40
41487	18622	66.455730000000003	66.467336000000003	55.454402000000002	55.445977999999997	Широкая	0103000020E61000000100000005000000977329AE2A9D5040245E9ECE15B94B40977329AE2A9D5040569E40D829BA4B40950F41D5E89D5040569E40D829BA4B40950F41D5E89D5040245E9ECE15B94B40977329AE2A9D5040245E9ECE15B94B40
41361	18862	66.601732999999996	66.620822000000004	55.291649	55.282553999999998	Садовая	0103000020E6100000010000000500000022FB20CB82A650404FADBEBA2AA44B4022FB20CB82A650409F7422C154A54B40CAA8328CBBA750409F7422C154A54B40CAA8328CBBA750404FADBEBA2AA44B4022FB20CB82A650404FADBEBA2AA44B40
41289	18927	66.590387000000007	66.598661000000007	55.368436000000003	55.361666999999997	Сиреневая	0103000020E61000000100000005000000F33E8EE6C8A550406E85B01A4BAE4B40F33E8EE6C8A55040A4552DE928AF4B4001193A7650A65040A4552DE928AF4B4001193A7650A650406E85B01A4BAE4B40F33E8EE6C8A550406E85B01A4BAE4B40
41008	17395	66.513249000000002	66.547608999999994	55.165774999999996	55.156585	Ленина	0103000020E610000001000000050000001A6D5512D9A05040A7052FFA0A944B401A6D5512D9A0504048BF7D1D38954B40B27F9E060CA3504048BF7D1D38954B40B27F9E060CA35040A7052FFA0A944B401A6D5512D9A05040A7052FFA0A944B40
41362	18814	66.252332999999993	66.271764000000005	55.086238999999999	55.074849999999998	Центральная	0103000020E61000000100000005000000E6AC4F3926905040840D4FAF94894B40E6AC4F3926905040E3512AE1098B4B40BB0ED59464915040E3512AE1098B4B40BB0ED59464915040840D4FAF94894B40E6AC4F3926905040840D4FAF94894B40
41122	18160	66.604302000000004	66.621360999999993	55.441212999999998	55.430835000000002	Весенняя	0103000020E6100000010000000500000013BA4BE2ACA65040707CED9925B74B4013BA4BE2ACA65040F7C8E6AA79B84B40A180ED60C4A75040F7C8E6AA79B84B40A180ED60C4A75040707CED9925B74B4013BA4BE2ACA65040707CED9925B74B40
41179	18660	66.358056000000005	66.380649000000005	55.189957999999997	55.182279000000001	Центральная	0103000020E61000000100000005000000BE88B663EA965040B1DF13EB54974B40BE88B663EA96504089CE328B50984B4054909F8D5C98504089CE328B50984B4054909F8D5C985040B1DF13EB54974B40BE88B663EA965040B1DF13EB54974B40
41287	18511	66.372600000000006	66.402486999999994	55.479796	55.472060999999997	Центральная	0103000020E61000000100000005000000569FABADD8975040C85BAE7E6CBC4B40569FABADD8975040356090F469BD4B402B84D558C2995040356090F469BD4B402B84D558C2995040C85BAE7E6CBC4B40569FABADD8975040C85BAE7E6CBC4B40
41180	18413	66.247230999999999	66.267155000000002	55.244655000000002	55.234805000000001	Придорожная	0103000020E61000000100000005000000ACE3F8A1D28F5040F9F719170E9E4B40ACE3F8A1D28F5040C5E6E3DA509F4B40A0FD481119915040C5E6E3DA509F4B40A0FD481119915040F9F719170E9E4B40ACE3F8A1D28F5040F9F719170E9E4B40
41544	18034	66.635688999999999	66.656000000000006	55.051400999999998	55.045397999999999	Школьная	0103000020E61000000100000005000000535BEA20AFA85040E3A6069ACF854B40535BEA20AFA85040A8FDD64E94864B40448B6CE7FBA95040A8FDD64E94864B40448B6CE7FBA95040E3A6069ACF854B40535BEA20AFA85040E3A6069ACF854B40
41119	17837	66.779652999999996	66.795607000000004	55.217136000000004	55.20861	Школьная	0103000020E610000001000000050000009C4EB2D5E5B150402DCF83BBB39A4B409C4EB2D5E5B150406364C91CCB9B4B40FF5D9F39EBB250406364C91CCB9B4B40FF5D9F39EBB250402DCF83BBB39A4B409C4EB2D5E5B150402DCF83BBB39A4B40
41545	18242	66.889022999999995	66.905157000000003	55.375107	55.360776000000001	Садовая	0103000020E610000001000000050000001399B9C0E5B85040429770E82DAE4B401399B9C0E5B8504016C0948103B04B40B62FA017EEB9504016C0948103B04B40B62FA017EEB95040429770E82DAE4B401399B9C0E5B85040429770E82DAE4B40
41360	18112	66.598714999999999	66.610401999999993	55.487417000000001	55.471922999999997	Центральная	0103000020E61000000100000005000000FA27B85851A65040779D0DF967BC4B40FA27B85851A65040D94125AE63BE4B406EDA8CD310A75040D94125AE63BE4B406EDA8CD310A75040779D0DF967BC4B40FA27B85851A65040779D0DF967BC4B40
41364	54989	66.598526000000007	66.642066999999997	54.999650000000003	54.973610000000001	Комсомольская	0103000020E6100000010000000500000091F3FE3F4EA650407F87A2409F7C4B4091F3FE3F4EA6504024B9FC87F47F4B40D0B52FA017A9504024B9FC87F47F4B40D0B52FA017A950407F87A2409F7C4B4091F3FE3F4EA650407F87A2409F7C4B40
40971	54989	66.598526000000007	66.642066999999997	54.999650000000003	54.973610000000001	Карла Маркса	0103000020E6100000010000000500000091F3FE3F4EA650407F87A2409F7C4B4091F3FE3F4EA6504024B9FC87F47F4B40D0B52FA017A9504024B9FC87F47F4B40D0B52FA017A950407F87A2409F7C4B4091F3FE3F4EA650407F87A2409F7C4B40
41726	17802	66.753951999999998	66.787171999999998	55.143265	55.130589999999998	Молодежная	0103000020E610000001000000050000003EB0E3BF40B05040A297512CB7904B403EB0E3BF40B05040AAD4EC8156924B40EC14AB0661B25040AAD4EC8156924B40EC14AB0661B25040A297512CB7904B403EB0E3BF40B05040A297512CB7904B40
41486	18335	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	Кривина	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
40911	54947	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	Спортивная	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
40675	54947	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	Пушкина	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
40797	54947	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	Первомайская	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
40795	54947	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	Карла Маркса	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
40932	54947	66.465647000000004	66.520166000000003	55.288044999999997	55.253172999999997	Железнодорожная	0103000020E61000000100000005000000C11E1329CD9D5040779D0DF967A04B40C11E1329CD9D50405E6397A8DEA44B406F9F55664AA150405E6397A8DEA44B406F9F55664AA15040779D0DF967A04B40C11E1329CD9D5040779D0DF967A04B40
41657	17751	66.222679999999997	66.242524000000003	55.321615000000001	55.313935999999998	Советская	0103000020E610000001000000050000004A5E9D63408E5040BE840A0E2FA84B404A5E9D63408E5040977329AE2AA94B40B01F6283858F5040977329AE2AA94B40B01F6283858F5040BE840A0E2FA84B404A5E9D63408E5040BE840A0E2FA84B40
41121	18181	66.605174000000005	66.621324999999999	55.507778999999999	55.502146000000003	Озерная	0103000020E61000000100000005000000EE98BA2BBBA650409BE8F35146C04B40EE98BA2BBBA650403C4CFBE6FEC04B40FBCBEEC9C3A750403C4CFBE6FEC04B40FBCBEEC9C3A750409BE8F35146C04B40EE98BA2BBBA650409BE8F35146C04B40
41696	18530	66.445048999999997	66.452702000000002	55.515309000000002	55.504725999999998	Зеленая	0103000020E610000001000000050000008507CDAE7B9C50406FB88FDC9AC04B408507CDAE7B9C5040D02A33A5F5C14B405D35CF11F99C5040D02A33A5F5C14B405D35CF11F99C50406FB88FDC9AC04B408507CDAE7B9C50406FB88FDC9AC04B40
41178	17705	66.246646999999996	66.262384999999995	55.425491000000001	55.408670000000001	Озёрная	0103000020E6100000010000000500000004AA7F10C98F50409C6D6E4C4FB44B4004AA7F10C98F504005DF347D76B64B40807D74EACA90504005DF347D76B64B40807D74EACA9050409C6D6E4C4FB44B4004AA7F10C98F50409C6D6E4C4FB44B40
41359	17603	66.518854000000005	66.533226999999997	55.083373999999999	55.073092000000003	Центральная	0103000020E61000000100000005000000865968E734A15040B4CC22145B894B40865968E734A1504019ABCDFFAB8A4B400796236420A2504019ABCDFFAB8A4B400796236420A25040B4CC22145B894B40865968E734A15040B4CC22145B894B40
41724	17496	66.889624999999995	66.901518999999993	55.529043000000001	55.516491000000002	Центральная	0103000020E610000001000000050000000E2DB29DEFB85040D4D688601CC24B400E2DB29DEFB85040C09657AEB7C34B403F6EBF7CB2B95040C09657AEB7C34B403F6EBF7CB2B95040D4D688601CC24B400E2DB29DEFB85040D4D688601CC24B40
41722	18284	66.799667999999997	66.828980000000001	55.316108	55.285938000000002	Школьная	0103000020E6100000010000000500000018EAB0C22DB350408257CB9D99A44B4018EAB0C22DB350408200193A76A84B40704221020EB550408200193A76A84B40704221020EB550408257CB9D99A44B4018EAB0C22DB350408257CB9D99A44B40
41177	16892	66.502809999999997	66.531987999999998	55.299444999999999	55.291372000000003	Молодёжная	0103000020E610000001000000050000008386FE092EA050402D7C7DAD4BA54B408386FE092EA05040B1F9B83654A64B40537765170CA25040B1F9B83654A64B40537765170CA250402D7C7DAD4BA54B408386FE092EA050402D7C7DAD4BA54B40
41551	17319	66.272321000000005	66.300760999999994	55.567321	55.547871000000001	Молодежная	0103000020E61000000100000005000000E6400FB56D915040A2B60DA320C64B40E6400FB56D915040C1AA7AF99DC84B4062BA10AB3F935040C1AA7AF99DC84B4062BA10AB3F935040A2B60DA320C64B40E6400FB56D915040A2B60DA320C64B40
41727	18421	66.107121000000006	66.123506000000006	55.214655999999998	55.206128999999997	Центральная	0103000020E61000000100000005000000C0ED0912DB865040EBE0606F629A4B40C0ED0912DB865040F1F109D9799B4B4007B7B585E7875040F1F109D9799B4B4007B7B585E7875040EBE0606F629A4B40C0ED0912DB865040EBE0606F629A4B40
41740	17436	66.838528999999994	66.856064000000003	55.452441	55.439559000000003	Центральная	0103000020E61000000100000005000000D8EF8975AAB55040CCD4247843B84B40D8EF8975AAB550404D2F3196E9B94B401CD2A8C0C9B650404D2F3196E9B94B401CD2A8C0C9B65040CCD4247843B84B40D8EF8975AAB55040CCD4247843B84B40
41663	17904	66.582401000000004	66.602119000000002	55.154223999999999	55.148451999999999	Южная	0103000020E61000000100000005000000180AD80E46A550404D83A27900934B40180AD80E46A550401021AE9CBD934B403753211E89A650401021AE9CBD934B403753211E89A650404D83A27900934B40180AD80E46A550404D83A27900934B40
41284	17305	66.336335000000005	66.356008000000003	55.511909000000003	55.503037999999997	Центральная	0103000020E6100000010000000500000003603C83869550409752978C63C04B4003603C838695504098C3EE3B86C14B405247C7D5C896504098C3EE3B86C14B405247C7D5C89650409752978C63C04B4003603C83869550409752978C63C04B40
41271	17637	66.371216000000004	66.393107999999998	55.111947999999998	55.103296	Зеленая	0103000020E6100000010000000500000020F0C000C297504060E7A6CD388D4B4020F0C000C2975040226DE34F548E4B40F1F274AE28995040226DE34F548E4B40F1F274AE2899504060E7A6CD388D4B4020F0C000C297504060E7A6CD388D4B40
41352	15864	64.789722999999995	64.817229999999995	54.807409	54.799905000000003	Центральная	0103000020E61000000100000005000000897956D28A32504015747B4963664B40897956D28A3250407FBF982D59674B40D8D30E7F4D3450407FBF982D59674B40D8D30E7F4D34504015747B4963664B40897956D28A32504015747B4963664B40
41530	14902	64.910448000000002	64.925107999999994	54.882809999999999	54.873874999999998	Северная	0103000020E610000001000000050000005A2DB0C7443A504060E5D022DB6F4B405A2DB0C7443A5040774A07EBFF704B4026512FF8343B5040774A07EBFF704B4026512FF8343B504060E5D022DB6F4B405A2DB0C7443A504060E5D022DB6F4B40
41355	15040	64.154263999999998	64.169130999999993	54.546492999999998	54.539887	Школьная	0103000020E61000000100000005000000CFBC1C76DF0950408D4468041B454B40CFBC1C76DF095040183F8D7BF3454B40586FD40AD30A5040183F8D7BF3454B40586FD40AD30A50408D4468041B454B40CFBC1C76DF0950408D4468041B454B40
41718	15384	64.195325999999994	64.212761999999998	54.677708000000003	54.667197000000002	Школьная	0103000020E61000000100000005000000BE839F38800C5040A27E17B666554B40BE839F38800C5040691EC022BF564B4038F581E49D0D5040691EC022BF564B4038F581E49D0D5040A27E17B666554B40BE839F38800C5040A27E17B666554B40
41358	16445	64.319598999999997	64.334286000000006	54.445104000000001	54.441209000000001	Новая	0103000020E6100000010000000500000065355D4F74145040B6D9588979384B4065355D4F74145040CEA8F92AF9384B40AF601BF164155040CEA8F92AF9384B40AF601BF164155040B6D9588979384B4065355D4F74145040B6D9588979384B40
41163	14509	64.317632000000003	64.337089000000006	54.912775000000003	54.906570000000002	Полевая	0103000020E61000000100000005000000700A2B155414504072C45A7C0A744B40700A2B15541450409FCDAACFD5744B40D9B5BDDD921550409FCDAACFD5744B40D9B5BDDD9215504072C45A7C0A744B40700A2B155414504072C45A7C0A744B40
41160	14681	64.411865000000006	64.422500999999997	55.030137000000003	55.025312	Крестьянская	0103000020E610000001000000050000007E5704FF5B1A50402219726C3D834B407E5704FF5B1A504025B37A87DB834B40BF61A2410A1B504025B37A87DB834B40BF61A2410A1B50402219726C3D834B407E5704FF5B1A50402219726C3D834B40
41356	16086	64.793235999999993	64.810151000000005	55.080519000000002	55.074891000000001	Молодёжная	0103000020E61000000100000005000000A180ED60C4325040E3E13D0796894B40A180ED60C432504073DA53724E8A4B4097749483D933504073DA53724E8A4B4097749483D9335040E3E13D0796894B40A180ED60C4325040E3E13D0796894B40
41532	15182	65.000198999999995	65.009101000000001	55.069808999999999	55.062942	Школьная	0103000020E610000001000000050000007B9FAA4203405040BDC5C37B0E884B407B9FAA4203405040B5FB5580EF884B4019575C1C95405040B5FB5580EF884B4019575C1C95405040BDC5C37B0E884B407B9FAA4203405040BDC5C37B0E884B40
41715	14610	64.195856000000006	64.213930000000005	54.960932999999997	54.952267999999997	Новая	0103000020E610000001000000050000006DAE9AE7880C50407F83F6EAE3794B406DAE9AE7880C5040D65240DAFF7A4B4088687407B10D5040D65240DAFF7A4B4088687407B10D50407F83F6EAE3794B406DAE9AE7880C50407F83F6EAE3794B40
40877	54978	64.515207000000004	64.546674999999993	54.630555000000001	54.617243000000002	Школьная	0103000020E61000000100000005000000E6EAC726F9205040AC5791D1014F4B40E6EAC726F920504026AAB706B6504B409CA223B9FC22504026AAB706B6504B409CA223B9FC225040AC5791D1014F4B40E6EAC726F9205040AC5791D1014F4B40
40794	16170	64.627567999999997	64.650358999999995	54.981267000000003	54.969109000000003	Центральная	0103000020E610000001000000050000000801F9122A28504030A182C30B7C4B400801F9122A28504070D234289A7D4B4031EA5A7B9F29504070D234289A7D4B4031EA5A7B9F29504030A182C30B7C4B400801F9122A28504030A182C30B7C4B40
41536	14366	64.519806000000003	64.530334999999994	54.686739000000003	54.679057	Главная	0103000020E61000000100000005000000EF90628044215040588FFB56EB564B40EF90628044215040A2F14410E7574B40253B3602F1215040A2F14410E7574B40253B3602F1215040588FFB56EB564B40EF90628044215040588FFB56EB564B40
41007	15952	64.799640999999994	64.817848999999995	55.004064999999997	54.99194	Зеленая	0103000020E610000001000000050000009BE271512D33504010CCD1E3F77E4B409BE271512D3350407407B13385804B403E0455A3573450407407B13385804B403E0455A35734504010CCD1E3F77E4B409BE271512D33504010CCD1E3F77E4B40
41720	15701	64.525600999999995	64.543808999999996	54.760168	54.750427000000002	Школьная	0103000020E61000000100000005000000AC6F6072A32150408884EFFD0D604B40AC6F6072A32150409DBB5D2F4D614B404F9143C4CD2250409DBB5D2F4D614B404F9143C4CD2250408884EFFD0D604B40AC6F6072A32150408884EFFD0D604B40
41167	15903	64.139747	64.153878000000006	55.067869999999999	55.043880999999999	Центральная	0103000020E61000000100000005000000B4AD669DF108504038F581E49D854B40B4AD669DF10850409430D3F6AF884B40BB641C23D90950409430D3F6AF884B40BB641C23D909504038F581E49D854B40B4AD669DF108504038F581E49D854B40
41716	14971	64.345848000000004	64.359393999999995	54.560158000000001	54.555599999999998	Центральная	0103000020E61000000100000005000000C558A65F221650402CD49AE61D474B40C558A65F22165040E04BE141B3474B403B18B14F00175040E04BE141B3474B403B18B14F001750402CD49AE61D474B40C558A65F221650402CD49AE61D474B40
41537	15755	64.636210000000005	64.662845000000004	54.851246000000003	54.839779999999998	Центральная	0103000020E61000000100000005000000D8D825AAB7285040DDEA39E97D6B4B40D8D825AAB7285040E86C01A1F56C4B404C546F0D6C2A5040E86C01A1F56C4B404C546F0D6C2A5040DDEA39E97D6B4B40D8D825AAB7285040DDEA39E97D6B4B40
41750	55048	64.416984999999997	64.434835000000007	54.753737000000001	54.745255999999998	Центральная	0103000020E610000001000000050000000B7BDAE1AF1A5040EA92718C645F4B400B7BDAE1AF1A504080643A747A604B40FF092E56D41B504080643A747A604B40FF092E56D41B5040EA92718C645F4B400B7BDAE1AF1A5040EA92718C645F4B40
41074	55002	64.464039	64.503923999999998	54.867896000000002	54.853127999999998	Садовая	0103000020E610000001000000050000006344A2D0B21D5040A4A65D4C336D4B406344A2D0B21D5040242A5437176F4B40D9EA724A40205040242A5437176F4B40D9EA724A40205040A4A65D4C336D4B406344A2D0B21D5040A4A65D4C336D4B40
41744	15536	64.245020999999994	64.265916000000004	55.081287000000003	55.070422000000001	Радужная	0103000020E6100000010000000500000053758F6CAE0F50409F758D9603894B4053758F6CAE0F5040844BC79C678A4B40ECDE8AC404115040844BC79C678A4B40ECDE8AC4041150409F758D9603894B4053758F6CAE0F50409F758D9603894B40
41353	15673	64.520525000000006	64.549963000000005	54.859689000000003	54.854159000000003	Центральная	0103000020E6100000010000000500000007F0164850215040C34A0515556D4B4007F016485021504090DD054A0A6E4B40A5C002983223504090DD054A0A6E4B40A5C0029832235040C34A0515556D4B4007F0164850215040C34A0515556D4B40
41719	16045	64.911597999999998	64.931647999999996	54.961041000000002	54.948551000000002	Центральная	0103000020E610000001000000050000005646239F573A504047CB811E6A794B405646239F573A5040BD8E3864037B4B4090D8EE1EA03B5040BD8E3864037B4B4090D8EE1EA03B504047CB811E6A794B405646239F573A504047CB811E6A794B40
40741	13752	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	Югова	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
40742	13752	64.386452000000006	64.467506999999998	54.935886000000004	54.882804999999998	XXII партсъезда	0103000020E61000000100000005000000535E2BA1BB18504065DF15C1FF704B40535E2BA1BB1850406364C91CCB774B40ABE97AA2EB1D50406364C91CCB774B40ABE97AA2EB1D504065DF15C1FF704B40535E2BA1BB18504065DF15C1FF704B40
41341	14846	64.849334999999996	64.866564999999994	54.818589000000003	54.812182999999997	Южная	0103000020E61000000100000005000000481630815B365040FFAECF9CF5674B40481630815B365040C4EE3B86C7684B40EDB60BCD75375040C4EE3B86C7684B40EDB60BCD75375040FFAECF9CF5674B40481630815B365040FFAECF9CF5674B40
41349	16376	64.591725999999994	64.611524000000003	54.622695	54.616852000000002	Центральная	0103000020E61000000100000005000000588CBAD6DE255040713C9F01F54E4B40588CBAD6DE255040FD304278B44F4B40062E8F3523275040FD304278B44F4B40062E8F3523275040713C9F01F54E4B40588CBAD6DE255040713C9F01F54E4B40
40969	15415	64.034589999999994	64.068493000000004	54.820078000000002	54.801732000000001	Центральная	0103000020E6100000010000000500000031B1F9B8360250400E1478279F664B4031B1F9B836025040A515DF50F8684B4051C0763062045040A515DF50F8684B4051C07630620450400E1478279F664B4031B1F9B8360250400E1478279F664B40
41534	15237	64.264847000000003	64.285616000000005	54.768878999999998	54.755623	Школьная	0103000020E6100000010000000500000066DCD440F31050407E8D2441B8604B4066DCD440F310504064CA87A06A624B40B8CD54884712504064CA87A06A624B40B8CD5488471250407E8D2441B8604B4066DCD440F31050407E8D2441B8604B40
41484	15622	64.562287999999995	64.607310999999996	54.855657000000001	54.846285999999999	Центральная	0103000020E61000000100000005000000BABBCE86FC23504005888219536C4B40BABBCE86FC235040F7CB272B866D4B4011E0F42EDE265040F7CB272B866D4B4011E0F42EDE26504005888219536C4B40BABBCE86FC23504005888219536C4B40
41348	16336	64.542524999999998	64.555370999999994	54.558315	54.547668000000002	Центральная	0103000020E61000000100000005000000CB10C7BAB82250406A882AFC19464B40CB10C7BAB8225040E1EEACDD76474B406589CE328B235040E1EEACDD76474B406589CE328B2350406A882AFC19464B40CB10C7BAB82250406A882AFC19464B40
41539	15992	64.724991000000003	64.751401000000001	55.071998999999998	55.054237999999998	Центральная	0103000020E610000001000000050000003DB9A640662E5040A8195245F1864B403DB9A640662E50401F2C634337894B40A14B38F4163050401F2C634337894B40A14B38F416305040A8195245F1864B403DB9A640662E5040A8195245F1864B40
41717	15328	64.191158000000001	64.213355000000007	54.751071000000003	54.743546000000002	Лесная	0103000020E610000001000000050000009A97C3EE3B0C50402B89EC832C5F4B409A97C3EE3B0C5040ADFC321823604B400ADCBA9BA70D5040ADFC321823604B400ADCBA9BA70D50402B89EC832C5F4B409A97C3EE3B0C50402B89EC832C5F4B40
41307	15806	64.693737999999996	64.707222000000002	54.844346999999999	54.833443000000003	Центральная	0103000020E61000000100000005000000847F1134662C5040420A9E42AE6A4B40847F1134662C5040E4BCFF8F136C4B40C0401020432D5040E4BCFF8F136C4B40C0401020432D5040420A9E42AE6A4B40847F1134662C5040420A9E42AE6A4B40
41533	15115	64.905606000000006	64.921964000000003	55.029404	55.021323000000002	Школьная	0103000020E61000000100000005000000EE43DE72F539504089D349B6BA824B40EE43DE72F5395040902FA182C3834B40B8054B75013B5040902FA182C3834B40B8054B75013B504089D349B6BA824B40EE43DE72F539504089D349B6BA824B40
41346	15089	64.942383000000007	64.975818000000004	54.804389	54.775444	Мичурина	0103000020E610000001000000050000009C53C900503C504091F0BDBF41634B409C53C900503C50408E210038F6664B40483657CD733E50408E210038F6664B40483657CD733E504091F0BDBF41634B409C53C900503C504091F0BDBF41634B40
40970	54988	64.256573000000003	64.298794000000001	54.599424999999997	54.589696000000004	Торговый	0103000020E61000000100000005000000580229B16B105040804A95287B4B4B40580229B16B105040D0B359F5B94C4B406D8FDE701F135040D0B359F5B94C4B406D8FDE701F135040804A95287B4B4B40580229B16B105040804A95287B4B4B40
41714	14762	64.884557999999998	64.903710000000004	54.842314999999999	54.822972999999998	Клубный	0103000020E61000000100000005000000925A28999C385040D93EE42D57694B40925A28999C38504012F758FAD06B4B405DC47762D639504012F758FAD06B4B405DC47762D6395040D93EE42D57694B40925A28999C385040D93EE42D57694B40
41713	14664	64.529104000000004	64.553403000000003	55.017648000000001	55.007561000000003	Центральная	0103000020E61000000100000005000000B30B06D7DC215040CFDC43C2F7804B40B30B06D7DC2150407F6B274A42824B4088A06AF46A2350407F6B274A42824B4088A06AF46A235040CFDC43C2F7804B40B30B06D7DC215040CFDC43C2F7804B40
41712	14547	64.230585000000005	64.250815000000003	54.939340999999999	54.928825000000003	Новая	0103000020E61000000100000005000000AF7C96E7C10E5040865AD3BCE3764B40AF7C96E7C10E50405E656D533C784B4029965B5A0D1050405E656D533C784B4029965B5A0D105040865AD3BCE3764B40AF7C96E7C10E5040865AD3BCE3764B40
40876	14418	64.132624000000007	64.168574000000007	54.994419000000001	54.966881999999998	Октябрьская	0103000020E610000001000000050000008BAA5FE97C085040A88B14CAC27B4B408BAA5FE97C085040B1C22D1F497F4B402E3D9AEAC90A5040B1C22D1F497F4B402E3D9AEAC90A5040A88B14CAC27B4B408BAA5FE97C085040A88B14CAC27B4B40
41541	16272	64.415268999999995	64.425070000000005	54.557814	54.551554000000003	Центральная	0103000020E61000000100000005000000BA826DC4931A50402FFD4B5299464B40BA826DC4931A50401FA0FB7266474B40B020CD58341B50401FA0FB7266474B40B020CD58341B50402FFD4B5299464B40BA826DC4931A50402FFD4B5299464B40
41164	15254	64.343278999999995	64.366527000000005	54.776814999999999	54.765649000000003	Центральная	0103000020E61000000100000005000000D4997B48F8155040899B53C900624B40D4997B48F8155040680586AC6E634B407786A92D75175040680586AC6E634B407786A92D75175040899B53C900624B40D4997B48F8155040899B53C900624B40
41075	55003	64.261854999999997	64.284062000000006	54.908816000000002	54.896149000000001	Центральная	0103000020E61000000100000005000000D252793BC2105040EBABAB02B5724B40D252793BC2105040700A2B1554744B40540262122E125040700A2B1554744B40540262122E125040EBABAB02B5724B40D252793BC2105040EBABAB02B5724B40
41344	14260	64.460391999999999	64.469769999999997	54.673054	54.660598999999998	Школьная	0103000020E61000000100000005000000C3D50110771D504099620E828E544B40C3D50110771D504093382BA226564B4015A930B6101E504093382BA226564B4015A930B6101E504099620E828E544B40C3D50110771D504099620E828E544B40
41283	14229	64.144651999999994	64.167586	54.783527999999997	54.764297999999997	Центральная	0103000020E61000000100000005000000435376FA41095040F8325184D4614B40435376FA4109504009C03FA54A644B401E51A1BAB90A504009C03FA54A644B401E51A1BAB90A5040F8325184D4614B40435376FA41095040F8325184D4614B40
40447	12869	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	Садовая	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
40459	54917	64.847036000000003	64.873975999999999	55.197111999999997	55.183410000000002	Заречная	0103000020E6100000010000000500000038A27BD63536504033E197FA79974B4038A27BD63536504017D34CF73A994B404A5F0839EF37504017D34CF73A994B404A5F0839EF37504033E197FA79974B4038A27BD63536504033E197FA79974B40
41351	55021	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	Заречная	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
40873	13407	64.865432999999996	64.894557000000006	55.305363999999997	55.290588	Дорожная	0103000020E6100000010000000500000044F8174163375040164ED2FC31A54B4044F817416337504018B0E42A16A74B401BDA006C4039504018B0E42A16A74B401BDA006C40395040164ED2FC31A54B4044F8174163375040164ED2FC31A54B40
41336	13099	64.951365999999993	64.973105000000004	55.668407000000002	55.649026999999997	Заречная	0103000020E61000000100000005000000AF21382EE33C5040499C155113D34B40AF21382EE33C504070B54E5C8ED54B40BEA4315A473E504070B54E5C8ED54B40BEA4315A473E5040499C155113D34B40AF21382EE33C5040499C155113D34B40
41333	11819	65.204151999999993	65.221247000000005	55.211748	55.197496999999998	Центральный переулок	0103000020E610000001000000050000006EDA8CD3104D50407007EA9447994B406EDA8CD3104D5040287FF78E1A9B4B40A4552DE9284E5040287FF78E1A9B4B40A4552DE9284E50407007EA9447994B406EDA8CD3104D50407007EA9447994B40
40966	12957	64.948869000000002	64.971929000000003	55.439481999999998	55.428924000000002	Труда	0103000020E610000001000000050000000CCC0A45BA3C5040193C4CFBE6B64B400CCC0A45BA3C5040209738F240B84B402D42B115343E5040209738F240B84B402D42B115343E5040193C4CFBE6B64B400CCC0A45BA3C5040193C4CFBE6B64B40
40793	54970	65.038566000000003	65.068838999999997	55.606619000000002	55.592540999999997	Томина	0103000020E61000000100000005000000342F87DD7742504002452C62D8CB4B40342F87DD77425040ED10FFB0A5CD4B401E6CB1DB67445040ED10FFB0A5CD4B401E6CB1DB6744504002452C62D8CB4B40342F87DD7742504002452C62D8CB4B40
40789	11934	65.478883999999994	65.496958000000006	55.262633999999998	55.252716999999997	Фрунзе	0103000020E61000000100000005000000F8A41309A65E50405512D90759A04B40F8A41309A65E5040A968ACFD9DA14B40145FED28CE5F5040A968ACFD9DA14B40145FED28CE5F50405512D90759A04B40F8A41309A65E50405512D90759A04B40
40872	12218	65.568922000000001	65.582189999999997	55.303052999999998	55.297691999999998	1 микрорайон	0103000020E6100000010000000500000065FED13769645040F2237EC51AA64B4065FED1376964504033FAD170CAA64B40BA83D8994265504033FAD170CAA64B40BA83D89942655040F2237EC51AA64B4065FED13769645040F2237EC51AA64B40
41482	55029	65.114051000000003	65.140029999999996	55.259186999999997	55.243448999999998	Ленина	0103000020E61000000100000005000000DFC4909C4C475040389F3A56299F4B40DFC4909C4C4750403046240A2DA14B405E9D6340F64850403046240A2DA14B405E9D6340F6485040389F3A56299F4B40DFC4909C4C475040389F3A56299F4B40
41710	13669	65.042993999999993	65.050801000000007	55.343347999999999	55.340117999999997	Центральная	0103000020E6100000010000000500000026FBE769C0425040F56393FC88AB4B4026FBE769C0425040D192C7D3F2AB4B40AA66D65240435040D192C7D3F2AB4B40AA66D65240435040F56393FC88AB4B4026FBE769C0425040F56393FC88AB4B40
41708	12094	65.478353999999996	65.496661000000003	55.155138999999998	55.144427999999998	Центральная	0103000020E610000001000000050000004A7A185A9D5E50403750E09D7C924B404A7A185A9D5E5040C5AA4198DB934B40B70C384BC95F5040C5AA4198DB934B40B70C384BC95F50403750E09D7C924B404A7A185A9D5E50403750E09D7C924B40
40672	54946	65.054789	65.094144	55.575285999999998	55.560091999999997	Южная	0103000020E610000001000000050000008ECBB8A98143504028603B18B1C74B408ECBB8A9814350405FECBDF8A2C94B4056478E74064650405FECBDF8A2C94B4056478E740646504028603B18B1C74B408ECBB8A98143504028603B18B1C74B40
41149	11480	65.401521000000002	65.406902000000002	55.375960999999997	55.370435999999998	Центральная	0103000020E6100000010000000500000010EA2285B25950406AA164726AAF4B4010EA2285B259504025C9737D1FB04B4054ABAFAE0A5A504025C9737D1FB04B4054ABAFAE0A5A50406AA164726AAF4B4010EA2285B25950406AA164726AAF4B40
41343	13392	64.904060999999999	64.940200000000004	55.349229999999999	55.340434999999999	Школьный переулок	0103000020E61000000100000005000000B325AB22DC395040F6B4C35F93AB4B40B325AB22DC3950401B649291B3AC4B40C0EC9E3C2C3C50401B649291B3AC4B40C0EC9E3C2C3C5040F6B4C35F93AB4B40B325AB22DC395040F6B4C35F93AB4B40
40792	54969	65.587363999999994	65.608761999999999	55.600003000000001	55.583657000000002	Центральная	0103000020E6100000010000000500000041B62C5F976550406E8AC745B5CA4B4041B62C5F976550403E40F7E5CCCC4B400B43E4F4F56650403E40F7E5CCCC4B400B43E4F4F56650406E8AC745B5CA4B4041B62C5F976550406E8AC745B5CA4B40
41709	13259	64.792013999999995	64.822979000000004	55.202378000000003	55.196936999999998	Сиреневая	0103000020E6100000010000000500000058FE7C5BB0325040A92F4B3B35994B4058FE7C5BB032504007B7B585E7994B40DE921CB0AB34504007B7B585E7994B40DE921CB0AB345040A92F4B3B35994B4058FE7C5BB0325040A92F4B3B35994B40
41711	13686	64.966376999999994	64.981451000000007	55.278452000000001	55.271327999999997	Береговая	0103000020E61000000100000005000000D2A6EA1ED93D50409A3E3BE0BAA24B40D2A6EA1ED93D5040BEC0AC50A4A34B4019E8DA17D03E5040BEC0AC50A4A34B4019E8DA17D03E50409A3E3BE0BAA24B40D2A6EA1ED93D50409A3E3BE0BAA24B40
41156	12487	65.635334	65.650462000000005	55.582903999999999	55.576096	Центральная	0103000020E610000001000000050000005C02F04FA96850409FAD8383BDC94B405C02F04FA9685040925A28999CCA4B409C525E2BA1695040925A28999CCA4B409C525E2BA16950409FAD8383BDC94B405C02F04FA96850409FAD8383BDC94B40
41005	12004	65.472532999999999	65.493876999999998	55.203040999999999	55.184869999999997	Советская	0103000020E61000000100000005000000F8510DFB3D5E50407901F6D1A9974B40F8510DFB3D5E5040A25F5B3FFD994B40C8CF46AE9B5F5040A25F5B3FFD994B40C8CF46AE9B5F50407901F6D1A9974B40F8510DFB3D5E50407901F6D1A9974B40
40743	54960	65.075837000000007	65.115748999999994	55.217207999999999	55.201129999999999	В. Менщикова	0103000020E61000000100000005000000EAB46E83DA4450404B1FBAA0BE994B40EAB46E83DA445040FC36C478CD9B4B40DC627E6E68475040FC36C478CD9B4B40DC627E6E684750404B1FBAA0BE994B40EAB46E83DA4450404B1FBAA0BE994B40
40874	11989	65.657244000000006	65.688963999999999	55.286025000000002	55.261577000000003	Победы	0103000020E61000000100000005000000815F2349106A50406231EA5A7BA14B40815F2349106A5040516B9A779CA44B40C40776FC176C5040516B9A779CA44B40C40776FC176C50406231EA5A7BA14B40815F2349106A50406231EA5A7BA14B40
41151	12171	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	Приозерная	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
41161	12789	65.006863999999993	65.029915000000003	55.435702999999997	55.42989	Интернатовская	0103000020E6100000010000000500000043E1B375704050405070B1A206B74B4043E1B3757040504071E2AB1DC5B74B403BAA9A20EA41504071E2AB1DC5B74B403BAA9A20EA4150405070B1A206B74B4043E1B375704050405070B1A206B74B40
41526	12789	65.006863999999993	65.029915000000003	55.435702999999997	55.42989	Заречная	0103000020E6100000010000000500000043E1B375704050405070B1A206B74B4043E1B3757040504071E2AB1DC5B74B403BAA9A20EA41504071E2AB1DC5B74B403BAA9A20EA4150405070B1A206B74B4043E1B375704050405070B1A206B74B40
41335	12973	64.901455999999996	64.919161000000003	55.414624000000003	55.408695000000002	Советская	0103000020E610000001000000050000001CB28174B1395040F584251E50B44B401CB28174B13950408011346612B54B408EB0A888D33A50408011346612B54B408EB0A888D33A5040F584251E50B44B401CB28174B1395040F584251E50B44B40
40662	54942	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	Кирова	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
41158	12902	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	Школьный переулок	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
40583	54937	65.595844	65.616775000000004	55.485097000000003	55.477153000000001	Почтовая	0103000020E610000001000000050000002461DF4E226650401A18795913BD4B402461DF4E22665040A13193A817BE4B40637FD93D79675040A13193A817BE4B40637FD93D796750401A18795913BD4B402461DF4E226650401A18795913BD4B40
40791	12130	65.517573999999996	65.545143999999993	55.335816999999999	55.317352999999997	Центральная	0103000020E61000000100000005000000A2D0B2EE1F615040CC24EA059FA84B40A2D0B2EE1F6150406D382C0DFCAA4B4014E7A8A3E36250406D382C0DFCAA4B4014E7A8A3E3625040CC24EA059FA84B40A2D0B2EE1F615040CC24EA059FA84B40
40674	54915	65.315192999999994	65.325828999999999	55.350945000000003	55.331259000000003	Ленина	0103000020E6100000010000000500000066BB421F2C545040BAC0E5B166AA4B4066BB421F2C545040EDD808C4EBAC4B40A8C5E061DA545040EDD808C4EBAC4B40A8C5E061DA545040BAC0E5B166AA4B4066BB421F2C545040BAC0E5B166AA4B40
40592	54915	65.320195999999996	65.336033999999998	55.346384	55.340276000000003	Красина	0103000020E61000000100000005000000D7135D177E5450408ECEF9298EAB4B40D7135D177E545040C8ED974F56AC4B400516C09481555040C8ED974F56AC4B400516C094815550408ECEF9298EAB4B40D7135D177E5450408ECEF9298EAB4B40
40454	54915	65.331379999999996	65.338953000000004	55.352561999999999	55.338222999999999	Космонавтов	0103000020E610000001000000050000001AA3755435555040A4E029E44AAB4B401AA3755435555040FBE769C020AD4B406478EC67B1555040FBE769C020AD4B406478EC67B1555040A4E029E44AAB4B401AA3755435555040A4E029E44AAB4B40
40457	54916	65.511510999999999	65.535405999999995	55.285573999999997	55.270308	Ленина	0103000020E61000000100000005000000D522A298BC60504070ECD97399A24B40D522A298BC605040404B57B08DA44B404205871744625040404B57B08DA44B40420587174462504070ECD97399A24B40D522A298BC60504070ECD97399A24B40
40664	54945	64.920813999999993	64.967113999999995	55.616117000000003	55.601909999999997	Миронова	0103000020E61000000100000005000000BBECD79DEE3A504053910A630BCD4B40BBECD79DEE3A50403CC1FEEBDCCE4B403D601E32E53D50403CC1FEEBDCCE4B403D601E32E53D504053910A630BCD4B40BBECD79DEE3A504053910A630BCD4B40
41525	12425	65.594165000000004	65.601665999999994	55.458741000000003	55.454059999999998	Лесная	0103000020E6100000010000000500000062DBA2CC06665040FC3559A31EBA4B4062DBA2CC06665040CC2A6C06B8BA4B405E471CB281665040CC2A6C06B8BA4B405E471CB281665040FC3559A31EBA4B4062DBA2CC06665040FC3559A31EBA4B40
41152	12326	65.673225000000002	65.692628999999997	55.511017000000002	55.503354000000002	Озёрная	0103000020E6100000010000000500000060764F1E166B5040C82764E76DC04B4060764F1E166B50409B594B0169C14B40B7D09508546C50409B594B0169C14B40B7D09508546C5040C82764E76DC04B4060764F1E166B5040C82764E76DC04B40
41528	13531	64.969386	64.998446999999999	55.198447999999999	55.188586000000001	Октябрьская	0103000020E61000000100000005000000D1CC936B0A3E5040E23D079623984B40D1CC936B0A3E504072FA7ABE66994B4084F23E8EE63F504072FA7ABE66994B4084F23E8EE63F5040E23D079623984B40D1CC936B0A3E5040E23D079623984B40
41495	54949	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	Пушкина	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
40680	54949	64.622466000000003	65.771061000000003	55.76681	55.054248000000001	Гоголя	0103000020E61000000100000005000000CE37A27BD6275040CCEF3499F1864B40CE37A27BD6275040751F80D426E24B40268E3C1059715040751F80D426E24B40268E3C1059715040CCEF3499F1864B40CE37A27BD6275040CCEF3499F1864B40
40663	54943	65.386510000000001	65.389420999999999	55.511735000000002	55.509416000000002	Пичугина	0103000020E61000000100000005000000ED647094BC5850409207228B34C14B40ED647094BC585040FA9B508880C14B400AD80E46EC585040FA9B508880C14B400AD80E46EC5850409207228B34C14B40ED647094BC5850409207228B34C14B40
41527	13335	64.740324999999999	64.759000999999998	55.237135000000002	55.225147	Луговая	0103000020E6100000010000000500000051DA1B7C612F504071E5EC9DD19C4B4051DA1B7C612F504055DE8E705A9E4B406728EE789330504055DE8E705A9E4B406728EE789330504071E5EC9DD19C4B4051DA1B7C612F504071E5EC9DD19C4B40
41332	12597	65.472460999999996	65.480823999999998	55.54289	55.536394999999999	Совхозная	0103000020E61000000100000005000000ABE80FCD3C5E5040745E6397A8C44B40ABE80FCD3C5E5040A8A9656B7DC54B4071C806D2C55E5040A8A9656B7DC54B4071C806D2C55E5040745E6397A8C44B40ABE80FCD3C5E5040745E6397A8C44B40
40788	11800	65.229511000000002	65.259990999999999	55.253270999999998	55.232767000000003	Боброва	0103000020E61000000100000005000000A0C4E74EB04E5040454B1E4FCB9D4B40A0C4E74EB04E50403A03232F6BA04B4047904AB1A35050403A03232F6BA04B4047904AB1A3505040454B1E4FCB9D4B40A0C4E74EB04E5040454B1E4FCB9D4B40
41514	7440	64.519519000000003	64.531889000000007	56.003194999999998	55.988253	Горная	0103000020E61000000100000005000000A4A99ECC3F215040429605137FFE4B40A4A99ECC3F2150405F419AB168004C408A0629780A2250405F419AB168004C408A0629780A225040429605137FFE4B40A4A99ECC3F215040429605137FFE4B40
41707	7679	64.755560000000003	64.771576999999994	56.042788000000002	56.030422000000002	Центральная	0103000020E610000001000000050000009C8A54185B3050401A8A3BDEE4034C409C8A54185B305040A454C2137A054C4021567F8461315040A454C2137A054C4021567F84613150401A8A3BDEE4034C409C8A54185B3050401A8A3BDEE4034C40
41507	55033	64.857159999999993	64.892579999999995	55.905861000000002	55.890588000000001	Советская	0103000020E610000001000000050000001EDC9DB5DB365040E31A9FC9FEF14B401EDC9DB5DB36504066DCD440F3F34B401344DD072039504066DCD440F3F34B401344DD0720395040E31A9FC9FEF14B401EDC9DB5DB365040E31A9FC9FEF14B40
40450	54913	64.857159999999993	64.892579999999995	55.905861000000002	55.890588000000001	Советская 	0103000020E610000001000000050000001EDC9DB5DB365040E31A9FC9FEF14B401EDC9DB5DB36504066DCD440F3F34B401344DD072039504066DCD440F3F34B401344DD0720395040E31A9FC9FEF14B401EDC9DB5DB365040E31A9FC9FEF14B40
41331	8673	64.467623000000003	64.480236000000005	56.054090000000002	56.033580000000001	Советская	0103000020E61000000100000005000000E0F60489ED1D50405CE674594C044C40E0F60489ED1D50403485CE6BEC064C402997C62FBC1E50403485CE6BEC064C402997C62FBC1E50405CE674594C044C40E0F60489ED1D50405CE674594C044C40
41143	7672	64.711031000000006	64.721513999999999	55.970464	55.959071999999999	Центральная	0103000020E610000001000000050000004DDC2A88812D504031410DDFC2FA4B404DDC2A88812D504001F9122A38FC4B40CB660E492D2E504001F9122A38FC4B40CB660E492D2E504031410DDFC2FA4B404DDC2A88812D504031410DDFC2FA4B40
41329	8634	64.487710000000007	64.512054000000006	55.750042999999998	55.739311000000001	Школьная	0103000020E61000000100000005000000A9FB00A4361F50405A492BBEA1DE4B40A9FB00A4361F5040FFCBB56801E04B404EF2237EC5205040FFCBB56801E04B404EF2237EC52050405A492BBEA1DE4B40A9FB00A4361F50405A492BBEA1DE4B40
41263	55012	64.420291000000006	64.439874000000003	55.931663	55.913373999999997	Октябрьская	0103000020E6100000010000000500000067F3380CE61A504023827170E9F44B4067F3380CE61A504056F2B1BB40F74B40161747E5261C504056F2B1BB40F74B40161747E5261C504023827170E9F44B4067F3380CE61A504023827170E9F44B40
41690	8480	64.662871999999993	64.685096000000001	55.719658000000003	55.709175000000002	Школьная	0103000020E61000000100000005000000C85BAE7E6C2A50400612143FC6DA4B40C85BAE7E6C2A50400327DBC01DDC4B40B5A7E49CD82B50400327DBC01DDC4B40B5A7E49CD82B50400612143FC6DA4B40C85BAE7E6C2A50400612143FC6DA4B40
41327	8425	64.063030999999995	64.077269000000001	55.644531000000001	55.637529999999998	Советская	0103000020E6100000010000000500000096E82CB308045040041C42959AD14B4096E82CB3080450400C21E7FD7FD24B40A8FFACF9F10450400C21E7FD7FD24B40A8FFACF9F1045040041C42959AD14B4096E82CB308045040041C42959AD14B40
41326	8407	65.007339999999999	65.026653999999994	56.075111999999997	56.061669999999999	Молодежная	0103000020E61000000100000005000000F8FC304278405040799274CDE4074C40F8FC304278405040C1C41F459D094C40AF93FAB2B4415040C1C41F459D094C40AF93FAB2B4415040799274CDE4074C40F8FC304278405040799274CDE4074C40
41703	7541	64.974272999999997	64.993038999999996	55.786287999999999	55.774720000000002	Дачная	0103000020E610000001000000050000000D18247D5A3E504050C763062AE34B400D18247D5A3E50405E9ECE15A5E44B40C32973F38D3F50405E9ECE15A5E44B40C32973F38D3F504050C763062AE34B400D18247D5A3E504050C763062AE34B40
41013	8333	64.085290999999998	64.110938000000004	56.039257999999997	56.026181000000001	Советская 	0103000020E6100000010000000500000029E9616875055040676325E659034C4029E96168750550409D0DF96706054C408E78B29B190750409D0DF96706054C408E78B29B19075040676325E659034C4029E9616875055040676325E659034C40
40779	8276	64.175095999999996	64.190736000000001	55.743932999999998	55.736828000000003	Школьная	0103000020E61000000100000005000000446ADAC5340B50407863416150DE4B40446ADAC5340B504024B5503239DF4B40DF8AC404350C504024B5503239DF4B40DF8AC404350C50407863416150DE4B40446ADAC5340B50407863416150DE4B40
41325	8261	64.849667999999994	64.873231000000004	55.957126000000002	55.939540000000001	Центральная	0103000020E610000001000000050000004B1DE4F56036504055A4C2D842F84B404B1DE4F5603650405E13D21A83FA4B409EB64604E33750405E13D21A83FA4B409EB64604E337504055A4C2D842F84B404B1DE4F56036504055A4C2D842F84B40
41334	9023	64.308909	64.331169000000003	56.055135999999997	56.048172999999998	Исетская	0103000020E610000001000000050000002A1C412AC51350406DC669882A064C402A1C412AC5135040876A4AB20E074C40BD1C76DF31155040876A4AB20E074C40BD1C76DF311550406DC669882A064C402A1C412AC51350406DC669882A064C40
40769	7255	64.590073000000004	64.604095000000001	56.125700999999999	56.116627999999999	Клубная	0103000020E610000001000000050000002B508BC1C325504021E692AAED0E4C402B508BC1C325504089096AF816104C40562B137EA926504089096AF816104C40562B137EA926504021E692AAED0E4C402B508BC1C325504021E692AAED0E4C40
40776	8114	64.169939999999997	64.195982000000001	55.870863999999997	55.858635	Ленина	0103000020E610000001000000050000001092054CE00A5040B9196EC0E7ED4B401092054CE00A5040C2A1B77878EF4B40B32616F88A0C5040C2A1B77878EF4B40B32616F88A0C5040B9196EC0E7ED4B401092054CE00A5040B9196EC0E7ED4B40
40775	54967	64.792697000000004	64.832205000000002	55.670976000000003	55.628946999999997	Чкалова	0103000020E61000000100000005000000CAA8328CBB3250406AF5D55581D04B40CAA8328CBB3250405133A48AE2D54B4055A4C2D8423550405133A48AE2D54B4055A4C2D8423550406AF5D55581D04B40CAA8328CBB3250406AF5D55581D04B40
40861	54967	64.792697000000004	64.832205000000002	55.670976000000003	55.628946999999997	Ленина	0103000020E61000000100000005000000CAA8328CBB3250406AF5D55581D04B40CAA8328CBB3250405133A48AE2D54B4055A4C2D8423550405133A48AE2D54B4055A4C2D8423550406AF5D55581D04B40CAA8328CBB3250406AF5D55581D04B40
40862	54967	64.792697000000004	64.832205000000002	55.670976000000003	55.628946999999997	Заводская	0103000020E61000000100000005000000CAA8328CBB3250406AF5D55581D04B40CAA8328CBB3250405133A48AE2D54B4055A4C2D8423550405133A48AE2D54B4055A4C2D8423550406AF5D55581D04B40CAA8328CBB3250406AF5D55581D04B40
40958	54967	64.792697000000004	64.832205000000002	55.670976000000003	55.628946999999997	Гагарина	0103000020E61000000100000005000000CAA8328CBB3250406AF5D55581D04B40CAA8328CBB3250405133A48AE2D54B4055A4C2D8423550405133A48AE2D54B4055A4C2D8423550406AF5D55581D04B40CAA8328CBB3250406AF5D55581D04B40
41540	14900	64.439299000000005	64.457004999999995	55.928148	55.922550000000001	Зеленая	0103000020E61000000100000005000000988A8D791D1C504060764F1E16F64B40988A8D791D1C504085ECBC8DCDF64B40F146E6913F1D504085ECBC8DCDF64B40F146E6913F1D504060764F1E16F64B40988A8D791D1C504060764F1E16F64B40
41040	54968	64.401498000000004	64.463949	55.967838999999998	55.928471000000002	Щорса	0103000020E6100000010000000500000034DAAA24B219504068244223D8F64B4034DAAA24B21950408C65FA25E2FB4B40C3802557B11D50408C65FA25E2FB4B40C3802557B11D504068244223D8F64B4034DAAA24B219504068244223D8F64B40
40865	54968	64.401498000000004	64.463949	55.967838999999998	55.928471000000002	Ленина	0103000020E6100000010000000500000034DAAA24B219504068244223D8F64B4034DAAA24B21950408C65FA25E2FB4B40C3802557B11D50408C65FA25E2FB4B40C3802557B11D504068244223D8F64B4034DAAA24B219504068244223D8F64B40
41328	54968	64.401498000000004	64.463949	55.967838999999998	55.928471000000002	Крупской	0103000020E6100000010000000500000034DAAA24B219504068244223D8F64B4034DAAA24B21950408C65FA25E2FB4B40C3802557B11D50408C65FA25E2FB4B40C3802557B11D504068244223D8F64B4034DAAA24B219504068244223D8F64B40
40867	54968	64.401498000000004	64.463949	55.967838999999998	55.928471000000002	Калинина	0103000020E6100000010000000500000034DAAA24B219504068244223D8F64B4034DAAA24B21950408C65FA25E2FB4B40C3802557B11D50408C65FA25E2FB4B40C3802557B11D504068244223D8F64B4034DAAA24B219504068244223D8F64B40
40782	54968	64.401498000000004	64.463949	55.967838999999998	55.928471000000002	Горького	0103000020E6100000010000000500000034DAAA24B219504068244223D8F64B4034DAAA24B21950408C65FA25E2FB4B40C3802557B11D50408C65FA25E2FB4B40C3802557B11D504068244223D8F64B4034DAAA24B219504068244223D8F64B40
40870	54968	64.401498000000004	64.463949	55.967838999999998	55.928471000000002	Гагарина	0103000020E6100000010000000500000034DAAA24B219504068244223D8F64B4034DAAA24B21950408C65FA25E2FB4B40C3802557B11D50408C65FA25E2FB4B40C3802557B11D504068244223D8F64B4034DAAA24B219504068244223D8F64B40
41757	55053	64.091211000000001	64.107803000000004	55.780633000000002	55.773277	Вишневая	0103000020E610000001000000050000004582A966D6055040DFDFA0BDFAE24B404582A966D6055040D5963AC8EBE34B4049DA8D3EE6065040D5963AC8EBE34B4049DA8D3EE6065040DFDFA0BDFAE24B404582A966D6055040DFDFA0BDFAE24B40
41705	7749	64.321197999999995	64.346027000000007	55.885452999999998	55.864120999999997	Лабарешных	0103000020E6100000010000000500000099620E828E145040B66455849BEE4B4099620E828E14504092921E8656F14B401D226E4E2516504092921E8656F14B401D226E4E25165040B66455849BEE4B4099620E828E145040B66455849BEE4B40
40857	7556	64.744870000000006	64.762792000000005	55.915557999999997	55.901223000000002	Советская 	0103000020E61000000100000005000000617138F3AB2F504096B377465BF34B40617138F3AB2F5040ABCB290131F54B40A1698995D1305040ABCB290131F54B40A1698995D130504096B377465BF34B40617138F3AB2F504096B377465BF34B40
41506	7615	64.651292999999995	64.676490999999999	55.880031000000002	55.874738000000001	Лесная	0103000020E6100000010000000500000047C7D5C8AE295040C3482F6AF7EF4B4047C7D5C8AE295040AC3B16DBA4F04B407442E8A04B2B5040AC3B16DBA4F04B407442E8A04B2B5040C3482F6AF7EF4B4047C7D5C8AE295040C3482F6AF7EF4B40
40773	54966	64.239333999999999	64.268224000000004	55.834997000000001	55.807501000000002	Победы	0103000020E6100000010000000500000089B48D3F510F5040603E59315CE74B4089B48D3F510F50400AA1832EE1EA4B402600FF942A1150400AA1832EE1EA4B402600FF942A115040603E59315CE74B4089B48D3F510F5040603E59315CE74B40
41511	7175	64.884388000000001	64.901222000000004	55.773969999999998	55.759323999999999	Центральная	0103000020E61000000100000005000000643E20D099385040B188618731E14B40643E20D099385040E50AEF7211E34B40E31B0A9FAD395040E50AEF7211E34B40E31B0A9FAD395040B188618731E14B40643E20D099385040B188618731E14B40
41755	55051	64.375716999999995	64.383612999999997	55.902712000000001	55.897195000000004	Советская	0103000020E6100000010000000500000047E350BF0B1850403F912749D7F24B4047E350BF0B18504077DA1A118CF34B4082548A1D8D18504077DA1A118CF34B4082548A1D8D1850403F912749D7F24B4047E350BF0B1850403F912749D7F24B40
41513	7331	64.499180999999993	64.513851000000003	55.985604000000002	55.974367999999998	Комсомольская	0103000020E610000001000000050000003672DD94F21F50406C223317B8FC4B403672DD94F21F50404567994528FE4B4015014EEFE22050404567994528FE4B4015014EEFE22050406C223317B8FC4B403672DD94F21F50406C223317B8FC4B40
41706	7409	64.49239	64.503214999999997	55.965727999999999	55.959907999999999	Механизаторов	0103000020E6100000010000000500000028B85851831F50409A95ED43DEFA4B4028B85851831F50406E6AA0F99CFB4B40D3F6AFAC342050406E6AA0F99CFB4B40D3F6AFAC342050409A95ED43DEFA4B4028B85851831F50409A95ED43DEFA4B40
40771	7318	64.934782999999996	64.955983000000003	56.064942000000002	56.051557000000003	Советская	0103000020E61000000100000005000000D576137CD33B5040A070766B99064C40D576137CD33B50408411FB0450084C400C2252D32E3D50408411FB0450084C400C2252D32E3D5040A070766B99064C40D576137CD33B5040A070766B99064C40
41280	7155	64.856881000000001	64.863646000000003	55.745528999999998	55.733736	Советская	0103000020E6100000010000000500000015E46723D7365040EDF2AD0FEBDD4B4015E46723D73650401B9C887E6DDF4B408F54DFF9453750401B9C887E6DDF4B408F54DFF945375040EDF2AD0FEBDD4B4015E46723D7365040EDF2AD0FEBDD4B40
41324	7805	64.302790999999999	64.322851	55.845399999999998	55.834482000000001	Центральная	0103000020E610000001000000050000007BA180ED60135040E38C614ED0EA4B407BA180ED60135040EA04341136EC4B40C79E3D97A9145040EA04341136EC4B40C79E3D97A9145040E38C614ED0EA4B407BA180ED60135040E38C614ED0EA4B40
41510	7006	64.800539000000001	64.816511000000006	54.401318000000003	54.389927	Победы	0103000020E610000001000000050000000B0BEE073C335040E869C020E9314B400B0BEE073C335040E8A562635E334B40C1745AB741345040E8A562635E334B40C1745AB741345040E869C020E9314B400B0BEE073C335040E869C020E9314B40
41509	6947	64.732598999999993	64.746694000000005	54.47119	54.462429999999998	40лет Победы	0103000020E610000001000000050000004485EAE6E22E50403A58FFE7303B4B404485EAE6E22E5040E31934F44F3C4B40A587A1D5C92F5040E31934F44F3C4B40A587A1D5C92F50403A58FFE7303B4B404485EAE6E22E50403A58FFE7303B4B40
41515	6919	64.692633000000001	64.699918999999994	54.556471999999999	54.549089000000002	Центральная	0103000020E6100000010000000500000058C85C19542C5040F3CB608C48464B4058C85C19542C5040E29178793A474B4056B60F79CB2C5040E29178793A474B4056B60F79CB2C5040F3CB608C48464B4058C85C19542C5040F3CB608C48464B40
41500	6851	64.922988000000004	64.940308000000002	54.660494999999997	54.654657	Школьная	0103000020E610000001000000050000006EA6423C123B50407A8CF2CCCB534B406EA6423C123B5040F415A4198B544B40B30A9B012E3C5040F415A4198B544B40B30A9B012E3C50407A8CF2CCCB534B406EA6423C123B50407A8CF2CCCB534B40
40768	54965	64.377809999999997	64.409934000000007	54.384517000000002	54.363737999999998	Ленина	0103000020E610000001000000050000008386FE092E185040FE277FF78E2E4B408386FE092E185040C6E061DA37314B402FE1D05B3C1A5040C6E061DA37314B402FE1D05B3C1A5040FE277FF78E2E4B408386FE092E185040FE277FF78E2E4B40
41141	6767	65.079510999999997	65.088798999999995	54.449308000000002	54.442999999999998	Советская	0103000020E61000000100000005000000062B4EB51645504062105839B4384B40062B4EB51645504064EAAEEC82394B40B83A00E2AE45504064EAAEEC82394B40B83A00E2AE45504062105839B4384B40062B4EB51645504062105839B4384B40
41321	6836	64.632616999999996	64.649173000000005	54.409717999999998	54.400385	Школьная	0103000020E61000000100000005000000317903CC7C2850408C67D0D03F334B40317903CC7C285040904AB1A371344B408F1CE90C8C295040904AB1A371344B408F1CE90C8C2950408C67D0D03F334B40317903CC7C2850408C67D0D03F334B40
41322	6728	64.821578000000002	64.833471000000003	54.562914999999997	54.558450999999998	Южная	0103000020E610000001000000050000003D47E4BB9434504091B586527B474B403D47E4BB94345040C3B645990D484B4086CABF9657355040C3B645990D484B4086CABF965735504091B586527B474B403D47E4BB9434504091B586527B474B40
40854	6661	64.887298000000001	64.905102999999997	54.505597000000002	54.495564000000002	Ленина	0103000020E6100000010000000500000099F38C7DC9385040988922A46E3F4B4099F38C7DC938504055FA0967B7404B40BC202235ED39504055FA0967B7404B40BC202235ED395040988922A46E3F4B4099F38C7DC9385040988922A46E3F4B40
41483	6569	65.130804999999995	65.145940999999993	54.532490000000003	54.526679999999999	Центральная	0103000020E61000000100000005000000CF49EF1B5F48504088BA0F406A434B40CF49EF1B5F48504039B9DFA128444B405089EB185749504039B9DFA128444B405089EB185749504088BA0F406A434B40CF49EF1B5F48504088BA0F406A434B40
41127	6634	64.951186000000007	64.966196999999994	54.519359000000001	54.511352000000002	Школьная	0103000020E61000000100000005000000709A3E3BE03C5040425F7AFB73414B40709A3E3BE03C50400FF10F5B7A424B40921FF12BD63D50400FF10F5B7A424B40921FF12BD63D5040425F7AFB73414B40709A3E3BE03C5040425F7AFB73414B40
40951	7031	64.550079999999994	64.560410000000005	54.409261999999998	54.406227999999999	Школьная	0103000020E61000000100000005000000C18BBE8234235040185C7347FF334B40C18BBE82342350406EBF7CB262344B407D96E7C1DD2350406EBF7CB262344B407D96E7C1DD235040185C7347FF334B40C18BBE8234235040185C7347FF334B40
41701	6546	65.178954000000004	65.196551999999997	54.360295999999998	54.354146999999998	Центральная	0103000020E61000000100000005000000425F7AFB734B5040FE7C5BB0542D4B40425F7AFB734B50409770E82D1E2E4B40A8FDD64E944C50409770E82D1E2E4B40A8FDD64E944C5040FE7C5BB0542D4B40425F7AFB734B5040FE7C5BB0542D4B40
40574	54911	64.837118000000004	64.872099000000006	54.482322000000003	54.447904999999999	Октябрьская	0103000020E610000001000000050000002639605793355040815B77F354394B402639605793355040171230BABC3D4B40F5F75278D0375040171230BABC3D4B40F5F75278D0375040815B77F354394B402639605793355040815B77F354394B40
40444	54911	64.837118000000004	64.872099000000006	54.482322000000003	54.447904999999999	Кравченко	0103000020E610000001000000050000002639605793355040815B77F354394B402639605793355040171230BABC3D4B40F5F75278D0375040171230BABC3D4B40F5F75278D0375040815B77F354394B402639605793355040815B77F354394B40
40952	54911	64.837118000000004	64.872099000000006	54.482322000000003	54.447904999999999	Косаревой	0103000020E610000001000000050000002639605793355040815B77F354394B402639605793355040171230BABC3D4B40F5F75278D0375040171230BABC3D4B40F5F75278D0375040815B77F354394B402639605793355040815B77F354394B40
41704	6320	65.032618999999997	65.047387000000001	54.459184999999998	54.453009000000002	Школьная	0103000020E610000001000000050000009B8E006E1642504097E5EB32FC394B409B8E006E1642504029E8F692C63A4B405BD07B630843504029E8F692C63A4B405BD07B630843504097E5EB32FC394B409B8E006E1642504097E5EB32FC394B40
41702	6244	64.926231000000001	64.946299999999994	54.571250999999997	54.559103999999998	Школьная	0103000020E61000000100000005000000A662635E473B5040098849B890474B40A662635E473B50405567B5C01E494B401B0DE02D903C50405567B5C01E494B401B0DE02D903C5040098849B890474B40A662635E473B5040098849B890474B40
41139	6200	64.839921000000004	64.856738000000007	54.626829000000001	54.615459999999999	Школьная	0103000020E61000000100000005000000508E0244C135504082FFAD64C74E4B40508E0244C13550409A97C3EE3B504B4064CF9ECBD43650409A97C3EE3B504B4064CF9ECBD436504082FFAD64C74E4B40508E0244C135504082FFAD64C74E4B40
41478	3440	66.156177999999997	66.180413999999999	55.766658	55.755828999999999	Андреева	0103000020E61000000100000005000000B39602D2FE895040272F3201BFE04B40B39602D2FE895040BF9B6ED921E24B40656F29E78B8B5040BF9B6ED921E24B40656F29E78B8B5040272F3201BFE04B40B39602D2FE895040272F3201BFE04B40
41323	3623	65.923603999999997	65.939278999999999	55.931345999999998	55.920053000000003	Береговая	0103000020E610000001000000050000001B9DF3531C7B504019CBF44BC4F54B401B9DF3531C7B504055A1815836F74B4074B4AA251D7C504055A1815836F74B4074B4AA251D7C504019CBF44BC4F54B401B9DF3531C7B504019CBF44BC4F54B40
41683	3526	66.013310000000004	66.036702000000005	55.946173999999999	55.932067000000004	Центральная	0103000020E610000001000000050000006DAD2F12DA8050402657B1F84DF74B406DAD2F12DA805040AA29C93A1CF94B40A96C585359825040AA29C93A1CF94B40A96C5853598250402657B1F84DF74B406DAD2F12DA8050402657B1F84DF74B40
41315	3518	66.168727000000004	66.187141999999994	55.830638999999998	55.823732	Больничная	0103000020E61000000100000005000000F1BC546CCC8A50409755D80C70E94B40F1BC546CCC8A50401DE4F56052EA4B40506D7022FA8B50401DE4F56052EA4B40506D7022FA8B50409755D80C70E94B40F1BC546CCC8A50409755D80C70E94B40
41313	3412	66.264657999999997	66.285004999999998	55.928561999999999	55.914534000000003	Молодежная	0103000020E61000000100000005000000FCA71B28F0905040408A3A730FF54B40FCA71B28F090504078279F1EDBF64B40938C9C853D92504078279F1EDBF64B40938C9C853D925040408A3A730FF54B40FCA71B28F0905040408A3A730FF54B40
41681	3322	65.645773000000005	65.657270999999994	55.409564000000003	55.401778999999998	Школьная	0103000020E61000000100000005000000F3E84658546950401B9C887E6DB34B40F3E84658546950403ACFD8976CB44B40FD6662BA106A50403ACFD8976CB44B40FD6662BA106A50401B9C887E6DB34B40F3E84658546950401B9C887E6DB34B40
41476	3208	65.880943000000002	65.892306000000005	55.173771000000002	55.159990000000001	Центральная	0103000020E61000000100000005000000F8A8BF5E61785040F1D7648D7A944B40F8A8BF5E6178504022FFCC203E964B409301A08A1B79504022FFCC203E964B409301A08A1B795040F1D7648D7A944B40F8A8BF5E61785040F1D7648D7A944B40
41475	3193	65.803526000000005	65.818357000000006	55.148266	55.136122999999998	Садовая	0103000020E6100000010000000500000016DF50F86C735040E09D7C7A6C914B4016DF50F86C735040EB8D5A61FA924B40F9DC09F65F745040EB8D5A61FA924B40F9DC09F65F745040E09D7C7A6C914B4016DF50F86C735040E09D7C7A6C914B40
41103	3063	66.058216000000002	66.072310999999999	55.422497999999997	55.409953000000002	Пролетарская	0103000020E61000000100000005000000A7069ACFB9835040D4F2035779B44B40A7069ACFB98350400D501A6A14B64B40070951BEA08450400D501A6A14B64B40070951BEA0845040D4F2035779B44B40A7069ACFB9835040D4F2035779B44B40
40849	2946	65.798962000000003	65.819740999999993	55.446314999999998	55.435502999999997	Пионерская	0103000020E61000000100000005000000CB2F833122735040AA27F38FBEB74B40CB2F8331227350406C5B94D920B94B402E8CF4A2767450406C5B94D920B94B402E8CF4A276745040AA27F38FBEB74B40CB2F833122735040AA27F38FBEB74B40
41474	2853	66.161396999999994	66.182310000000001	55.969003000000001	55.958889999999997	Школьная	0103000020E610000001000000050000000A2B1554548A5040103B53E8BCFA4B400A2B1554548A5040EA5C514A08FC4B40F6EE8FF7AA8B5040EA5C514A08FC4B40F6EE8FF7AA8B5040103B53E8BCFA4B400A2B1554548A5040103B53E8BCFA4B40
41001	54995	66.116866999999999	66.153249000000002	55.749319	55.720762999999998	Гоголя	0103000020E61000000100000005000000D3BEB9BF7A8750405B9544F641DC4B40D3BEB9BF7A875040BEA25BAFE9DF4B4043C9E4D4CE895040BEA25BAFE9DF4B4043C9E4D4CE8950405B9544F641DC4B40D3BEB9BF7A8750405B9544F641DC4B40
41470	54995	66.116866999999999	66.153249000000002	55.749319	55.720762999999998	Больничная	0103000020E61000000100000005000000D3BEB9BF7A8750405B9544F641DC4B40D3BEB9BF7A875040BEA25BAFE9DF4B4043C9E4D4CE895040BEA25BAFE9DF4B4043C9E4D4CE8950405B9544F641DC4B40D3BEB9BF7A8750405B9544F641DC4B40
41473	2620	65.957892000000001	65.972211999999999	55.294832	55.284855999999998	Центральная	0103000020E6100000010000000500000067463F1A4E7D5040E108522976A44B4067463F1A4E7D50403AE8120EBDA54B40D731AEB8387E50403AE8120EBDA54B40D731AEB8387E5040E108522976A44B4067463F1A4E7D5040E108522976A44B40
41099	2600	65.986513000000002	66.004739999999998	55.515782999999999	55.498485000000002	Чапаева	0103000020E610000001000000050000000C056C07237F5040F645425BCEBF4B400C056C07237F5040986A662D05C24B40EA3E00A94D805040986A662D05C24B40EA3E00A94D805040F645425BCEBF4B400C056C07237F5040F645425BCEBF4B40
41319	2968	65.868590999999995	65.881302000000005	55.398420999999999	55.386952000000001	Озерная	0103000020E6100000010000000500000065A6B4FE96775040978FA4A487B14B4065A6B4FE9677504012859675FFB24B4090F980406778504012859675FFB24B4090F9804067785040978FA4A487B14B4065A6B4FE96775040978FA4A487B14B40
41679	2839	66.074853000000004	66.097446000000005	55.696061999999998	55.683239	Центральная	0103000020E610000001000000050000007BC03C64CA845040062D246074D74B407BC03C64CA84504082FE428F18D94B4011C8258E3C86504082FE428F18D94B4011C8258E3C865040062D246074D74B407BC03C64CA845040062D246074D74B40
41678	2510	65.966821999999993	65.998639999999995	55.082106000000003	55.071288000000003	Центральная	0103000020E6100000010000000500000069C36169E07D5040734C16F71F894B4069C36169E07D504017670C73828A4B408E1EBFB7E97F504017670C73828A4B408E1EBFB7E97F5040734C16F71F894B4069C36169E07D5040734C16F71F894B40
41317	2492	65.854595000000003	65.878877000000003	55.264265000000002	55.250644000000001	Новая	0103000020E61000000100000005000000CF143AAFB17650402578431A15A04B40CF143AAFB17650401D3D7E6FD3A14B40390D51853F7850401D3D7E6FD3A14B40390D51853F7850402578431A15A04B40CF143AAFB17650402578431A15A04B40
41012	2403	66.281312999999997	66.310633999999993	55.908323000000003	55.891506999999997	Гагарина	0103000020E6100000010000000500000023BC3D0801925040D993C0E61CF24B4023BC3D0801925040319A95ED43F44B40A4C16D6DE1935040319A95ED43F44B40A4C16D6DE1935040D993C0E61CF24B4023BC3D0801925040D993C0E61CF24B40
40759	54958	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Социалистическая	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
40842	54958	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Осипенко	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
40765	54958	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Механизаторов	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
40847	54958	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Матросова	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
41089	54958	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Космонавтов	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
40823	54958	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Комсомольская	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
40740	54958	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Кирова	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
41700	32139	65.828615999999997	65.850022999999993	55.360765999999998	55.345728999999999	Центральная	0103000020E610000001000000050000004F3C670B08755040AF230ED940AC4B404F3C670B087550401EC18D942DAE4B404276DEC6667650401EC18D942DAE4B404276DEC666765040AF230ED940AC4B404F3C670B08755040AF230ED940AC4B40
40950	1797	65.776010999999997	65.844363000000001	55.389252999999997	55.359369000000001	Комсомольская	0103000020E6100000010000000500000085950A2AAA7150401E19ABCDFFAD4B4085950A2AAA715040586FD40AD3B14B40F5BC1B0B0A765040586FD40AD3B14B40F5BC1B0B0A7650401E19ABCDFFAD4B4085950A2AAA7150401E19ABCDFFAD4B40
41680	3072	66.190134	66.217416	55.941122999999997	55.932738000000001	Молодежная	0103000020E61000000100000005000000E4F6CB272B8C504044DE72F563F74B40E4F6CB272B8C5040B741EDB776F84B402368CC24EA8D5040B741EDB776F84B402368CC24EA8D504044DE72F563F74B40E4F6CB272B8C504044DE72F563F74B40
41077	890	66.321736999999999	66.331906000000004	55.887281000000002	55.881630999999999	Школьная	0103000020E61000000100000005000000713AC95697945040E411DC48D9F04B40713AC956979450405CAE7E6C92F14B4028D6A9F23D9550405CAE7E6C92F14B4028D6A9F23D955040E411DC48D9F04B40713AC95697945040E411DC48D9F04B40
41282	31606	65.767054000000002	65.780296000000007	55.499611000000002	55.488227999999999	Школьная	0103000020E610000001000000050000000611A96917715040E97E4E417EBE4B400611A9691771504066DCD440F3BF4B40C74CA25EF071504066DCD440F3BF4B40C74CA25EF0715040E97E4E417EBE4B400611A96917715040E97E4E417EBE4B40
40446	54912	65.536663000000004	65.612194000000002	55.840299999999999	55.815199999999997	Советская	0103000020E610000001000000050000004A7EC4AF586250407FD93D7958E84B404A7EC4AF58625040166A4DF38EEB4B40AD33BE2F2E675040166A4DF38EEB4B40AD33BE2F2E6750407FD93D7958E84B404A7EC4AF586250407FD93D7958E84B40
40572	54934	65.536663000000004	65.612194000000002	55.840299999999999	55.815199999999997	Карла Маркса	0103000020E610000001000000050000004A7EC4AF586250407FD93D7958E84B404A7EC4AF58625040166A4DF38EEB4B40AD33BE2F2E675040166A4DF38EEB4B40AD33BE2F2E6750407FD93D7958E84B404A7EC4AF586250407FD93D7958E84B40
41091	31353	63.666955000000002	63.687139999999999	54.862046999999997	54.849266	Центральная	0103000020E61000000100000005000000AC730CC85ED54F4068CD8FBFB46C4B40AC730CC85ED54F40B54E5C8E576E4B4000E31934F4D74F40B54E5C8E576E4B4000E31934F4D74F4068CD8FBFB46C4B40AC730CC85ED54F4068CD8FBFB46C4B40
41682	31175	62.946263000000002	62.972512000000002	54.807693999999998	54.791409000000002	Шахты	0103000020E610000001000000050000001A355F251F794F404A61DEE34C654B401A355F251F794F407496598462674B40D97BF1457B7C4F407496598462674B40D97BF1457B7C4F404A61DEE34C654B401A355F251F794F404A61DEE34C654B40
41656	30211	62.850304999999999	62.865459999999999	54.987059000000002	54.977392000000002	Школьная	0103000020E61000000100000005000000095053CBD66C4F409FAF592E1B7D4B40095053CBD66C4F407A1C06F3577E4B4082FFAD64C76E4F407A1C06F3577E4B4082FFAD64C76E4F409FAF592E1B7D4B40095053CBD66C4F409FAF592E1B7D4B40
41114	31167	63.453972999999998	63.473241999999999	54.849908999999997	54.840443	Школьная	0103000020E610000001000000050000002D228AC91BBA4F407993DFA2936B4B402D228AC91BBA4F40BCC96FD1C96C4B40FC8BA03193BC4F40BCC96FD1C96C4B40FC8BA03193BC4F407993DFA2936B4B402D228AC91BBA4F407993DFA2936B4B40
41279	30917	63.847875999999999	63.871473999999999	54.886983999999998	54.875636	Школьная	0103000020E610000001000000050000001A88653387EC4F40A29927D714704B401A88653387EC4F40A20914B188714B403BA8C4758CEF4F40A20914B188714B403BA8C4758CEF4F40A29927D714704B401A88653387EC4F40A29927D714704B40
41471	30485	63.320689999999999	63.344630000000002	55.040275000000001	55.029063999999998	Центральная	0103000020E61000000100000005000000BE13B35E0CA94F40D7BE805EB8834B40BE13B35E0CA94F4057EC2FBB27854B40399CF9D51CAC4F4057EC2FBB27854B40399CF9D51CAC4F40D7BE805EB8834B40BE13B35E0CA94F40D7BE805EB8834B40
41288	55014	63.512974999999997	63.524365000000003	54.738005999999999	54.731538999999998	Аминева	0103000020E610000001000000050000003255302AA9C14F40D05FE811A35D4B403255302AA9C14F403A2009FB765E4B4062156F641EC34F403A2009FB765E4B4062156F641EC34F40D05FE811A35D4B403255302AA9C14F40D05FE811A35D4B40
41497	30701	63.145356999999997	63.168049000000003	54.915300999999999	54.896501000000001	Советская	0103000020E61000000100000005000000519FE40E9B924F4068EA758BC0724B40519FE40E9B924F40807F4A9528754B4011902FA182954F40807F4A9528754B4011902FA182954F4068EA758BC0724B40519FE40E9B924F4068EA758BC0724B40
41462	31465	63.680861	63.698953000000003	54.961238000000002	54.956150999999998	Центральная	0103000020E61000000100000005000000990F087426D74F40D384ED27637A4B40990F087426D74F4013D6C6D8097B4B407638BA4A77D94F4013D6C6D8097B4B407638BA4A77D94F40D384ED27637A4B40990F087426D74F40D384ED27637A4B40
41278	30627	63.909401000000003	63.925435999999998	54.949539000000001	54.936692999999998	Школьная	0103000020E6100000010000000500000090F9804067F44F4031B2648EE5774B4090F9804067F44F4066A3737E8A794B404145D5AF74F64F4066A3737E8A794B404145D5AF74F64F4031B2648EE5774B4090F9804067F44F4031B2648EE5774B40
41685	31089	63.161976000000003	63.175854999999999	54.746170999999997	54.737662999999998	Школьная	0103000020E61000000100000005000000535E2BA1BB944F40103CBEBD6B5E4B40535E2BA1BB944F409F1C0588825F4B4046EBA86A82964F409F1C0588825F4B4046EBA86A82964F40103CBEBD6B5E4B40535E2BA1BB944F40103CBEBD6B5E4B40
41117	30770	63.000818000000002	63.013537999999997	54.864409000000002	54.857010000000002	Школьная	0103000020E61000000100000005000000C39FE1CD1A804F40282CF180B26D4B40C39FE1CD1A804F401DAF40F4A46E4B406AA0F99CBB814F401DAF40F4A46E4B406AA0F99CBB814F40282CF180B26D4B40C39FE1CD1A804F40282CF180B26D4B40
41277	30554	63.532926000000003	63.552644000000001	54.812364000000002	54.801177000000003	Советская	0103000020E6100000010000000500000014984EEB36C44F4059A7CAF78C664B4014984EEB36C44F405039268BFB674B40522AE109BDC64F405039268BFB674B40522AE109BDC64F4059A7CAF78C664B4014984EEB36C44F4059A7CAF78C664B40
40930	54984	63.447738999999999	63.475847000000002	54.823355999999997	54.804352999999999	Советская	0103000020E610000001000000050000006612F5824FB94F4041B8020AF5664B406612F5824FB94F40917BBABA63694B402A73F38DE8BC4F40917BBABA63694B402A73F38DE8BC4F4041B8020AF5664B406612F5824FB94F4041B8020AF5664B40
41200	55008	63.410252	63.429845	54.933847999999998	54.926239000000002	Центральная	0103000020E610000001000000050000002E8F352383B44F40CFA3E2FF8E764B402E8F352383B44F40AEB7CD5488774B40B0AC342905B74F40AEB7CD5488774B40B0AC342905B74F40CFA3E2FF8E764B402E8F352383B44F40CFA3E2FF8E764B40
41688	30073	63.022709999999996	63.041494	55.000124999999997	54.988638999999999	Майлыкская	0103000020E6100000010000000500000065A54929E8824F406B4606B98B7E4B4065A54929E8824F40BC74931804804B40787DE6AC4F854F40BC74931804804B40787DE6AC4F854F406B4606B98B7E4B4065A54929E8824F406B4606B98B7E4B40
41097	30777	63.188746000000002	63.197539999999996	54.837135000000004	54.831099000000002	Почтовая	0103000020E610000001000000050000001BA034D428984F40815EB873616A4B401BA034D428984F4022AB5B3D276B4B406FD39FFD48994F4022AB5B3D276B4B406FD39FFD48994F40815EB873616A4B401BA034D428984F40815EB873616A4B40
41011	30342	63.233302000000002	63.250146000000001	54.805531000000002	54.795670000000001	Центральная	0103000020E61000000100000005000000B30B06D7DC9D4F404434BA83D8654B40B30B06D7DC9D4F400475CAA31B674B40D49CBCC804A04F400475CAA31B674B40D49CBCC804A04F404434BA83D8654B40B30B06D7DC9D4F404434BA83D8654B40
41677	30875	63.195456	63.216692000000002	54.915689	54.911366999999998	Малая	0103000020E610000001000000050000004BE7C3B304994F40AAD381ACA7744B404BE7C3B304994F404A27124C35754B4005A73E90BC9B4F404A27124C35754B4005A73E90BC9B4F40AAD381ACA7744B404BE7C3B304994F40AAD381ACA7744B40
41469	30153	63.000512999999998	63.010565	54.965915000000003	54.956564999999998	Кирпичная	0103000020E61000000100000005000000861C5BCF10804F40C6BFCFB8707A4B40861C5BCF10804F40A1DB4B1AA37B4B40BABDA4315A814F40A1DB4B1AA37B4B40BABDA4315A814F40C6BFCFB8707A4B40861C5BCF10804F40C6BFCFB8707A4B40
76546	30227	63.422038000000001	63.433850999999997	55.046208	55.034100000000002	пер. Советский	0103000020E61000000100000005000000AAD5575705B64F40956588635D844B40AAD5575705B64F402368CC24EA854B401F2BF86D88B74F402368CC24EA854B401F2BF86D88B74F40956588635D844B40AAD5575705B64F40956588635D844B40
41655	30227	63.422038000000001	63.433850999999997	55.046208	55.034100000000002	Российская	0103000020E61000000100000005000000AAD5575705B64F40956588635D844B40AAD5575705B64F402368CC24EA854B401F2BF86D88B74F402368CC24EA854B401F2BF86D88B74F40956588635D844B40AAD5575705B64F40956588635D844B40
41676	31373	63.786458000000003	63.812635	54.769455999999998	54.758910999999998	Центральная	0103000020E61000000100000005000000BBD6DEA7AAE44F408EC9E2FE23614B40BBD6DEA7AAE44F4001DBC1887D624B40E04A766C04E84F4001DBC1887D624B40E04A766C04E84F408EC9E2FE23614B40BBD6DEA7AAE44F408EC9E2FE23614B40
41092	31263	62.938313000000001	62.949291000000002	54.778849999999998	54.771850000000001	Береговая	0103000020E61000000100000005000000B134F0A31A784F4074B515FBCB624B40B134F0A31A784F40AB3E575BB1634B408EB1135E82794F40AB3E575BB1634B408EB1135E82794F4074B515FBCB624B40B134F0A31A784F4074B515FBCB624B40
41653	30066	62.901356999999997	62.935887999999998	54.907817000000001	54.897288000000003	Школьная	0103000020E61000000100000005000000A5828AAA5F734F40F08B4B55DA724B40A5828AAA5F734F405DE0F25833744B40035C902DCB774F405DE0F25833744B40035C902DCB774F40F08B4B55DA724B40A5828AAA5F734F40F08B4B55DA724B40
41499	31070	63.395206000000002	63.405599000000002	54.723511999999999	54.715192000000002	Комсомольская,	0103000020E610000001000000050000006C97361C96B24F40302E55698B5B4B406C97361C96B24F40BC218D0A9C5C4B40292504ABEAB34F40BC218D0A9C5C4B40292504ABEAB34F40302E55698B5B4B406C97361C96B24F40302E55698B5B4B40
41613	31255	62.825153	62.836525000000002	54.741109000000002	54.732486000000002	Молодёжная	0103000020E6100000010000000500000020990E9D9E694F409163EB19C25D4B4020990E9D9E694F40B9E2E2A8DC5E4B40A9A44E40136B4F40B9E2E2A8DC5E4B40A9A44E40136B4F409163EB19C25D4B4020990E9D9E694F409163EB19C25D4B40
40514	54927	63.555160000000001	63.601522000000003	54.962116000000002	54.928820000000002	Комсомола	0103000020E6100000010000000500000010069E7B0FC74F4074EFE192E3764B4010069E7B0FC74F40AB7AF99D267B4B408AE942ACFECC4F40AB7AF99D267B4B408AE942ACFECC4F4074EFE192E3764B4010069E7B0FC74F4074EFE192E3764B40
40753	54927	63.555160000000001	63.601522000000003	54.962116000000002	54.928820000000002	В.И.Ленина	0103000020E6100000010000000500000010069E7B0FC74F4074EFE192E3764B4010069E7B0FC74F40AB7AF99D267B4B408AE942ACFECC4F40AB7AF99D267B4B408AE942ACFECC4F4074EFE192E3764B4010069E7B0FC74F4074EFE192E3764B40
40706	54927	63.555160000000001	63.601522000000003	54.962116000000002	54.928820000000002	8 Марта	0103000020E6100000010000000500000010069E7B0FC74F4074EFE192E3764B4010069E7B0FC74F40AB7AF99D267B4B408AE942ACFECC4F40AB7AF99D267B4B408AE942ACFECC4F4074EFE192E3764B4010069E7B0FC74F4074EFE192E3764B40
41662	30452	63.310611000000002	63.330958000000003	54.934716999999999	54.926611000000001	Озерная	0103000020E610000001000000050000009163EB19C2A74F40938E72309B764B409163EB19C2A74F40F30181CEA4774B40BF2CEDD45CAA4F40F30181CEA4774B40BF2CEDD45CAA4F40938E72309B764B409163EB19C2A74F40938E72309B764B40
29909	155	85.053586999999993	85.073530000000005	56.496139999999997	56.490136999999997	улица Энтузиастов	0103000020E61000000100000005000000681F2BF86D4355409FC728CFBC3E4C40681F2BF86D435540641EF983813F4C4098512CB7B4445540641EF983813F4C4098512CB7B44455409FC728CFBC3E4C40681F2BF86D4355409FC728CFBC3E4C40
28962	155	84.999759999999995	85.011869000000004	56.477398000000001	56.477297999999998	улица Салтыкова-Щедрина	0103000020E6100000010000000500000055F65D11FC3F55401D39D219183D4C4055F65D11FC3F55408196AE601B3D4C4085B53176C24055408196AE601B3D4C4085B53176C24055401D39D219183D4C4055F65D11FC3F55401D39D219183D4C40
28741	155	84.947531999999995	84.951215000000005	56.509895999999998	56.488402999999998	улица Розы Люксембург	0103000020E6100000010000000500000076FA415DA43C5540572250FD833E4C4076FA415DA43C55403C2EAA4544414C40BD1DE1B4E03C55403C2EAA4544414C40BD1DE1B4E03C5540572250FD833E4C4076FA415DA43C5540572250FD833E4C40
28966	155	84.970474999999993	84.999786999999998	56.479297000000003	56.479018000000003	улица Лебедева	0103000020E610000001000000050000007AA52C431C3E554001193A76503D4C407AA52C431C3E55401409A69A593D4C40D2FD9C82FC3F55401409A69A593D4C40D2FD9C82FC3F554001193A76503D4C407AA52C431C3E554001193A76503D4C40
28986	155	84.952759999999998	84.955410000000001	56.484541	56.475419000000002	улица Крылова	0103000020E61000000100000005000000F73B1405FA3C5540D272A087DA3C4C40F73B1405FA3C55401B498270053E4C405E11FC6F253D55401B498270053E4C405E11FC6F253D5540D272A087DA3C4C40F73B1405FA3C5540D272A087DA3C4C40
28747	155	84.945017000000007	84.947478000000004	56.504148999999998	56.488486999999999	улица Карла Маркса	0103000020E61000000100000005000000804A95287B3C5540B5C2F4BD863E4C40804A95287B3C5540D2A755F487404C407DEBC37AA33C5540D2A755F487404C407DEBC37AA33C5540B5C2F4BD863E4C40804A95287B3C5540B5C2F4BD863E4C40
28718	155	84.979521000000005	84.988899000000004	56.517212000000001	56.513123999999998	улица Интернационалистов	0103000020E61000000100000005000000B22FD978B03E55407765170CAE414C40B22FD978B03E5540A48CB80034424C400403081F4A3F5540A48CB80034424C400403081F4A3F55407765170CAE414C40B22FD978B03E55407765170CAE414C40
28960	155	84.950029000000001	85.015732	56.476314000000002	56.476021000000003	проспект Фрунзе	0103000020E610000001000000050000001A506F46CD3C5540C89A9141EE3C4C401A506F46CD3C554040506EDBF73C4C400B60CAC00141554040506EDBF73C4C400B60CAC001415540C89A9141EE3C4C401A506F46CD3C5540C89A9141EE3C4C40
28742	155	84.935565999999994	84.951188000000002	56.526173999999997	56.455233999999997	проспект Ленина	0103000020E61000000100000005000000F84F3750E03B55407D03931B453A4C40F84F3750E03B5540B4006DAB59434C404016A243E03C5540B4006DAB59434C404016A243E03C55407D03931B453A4C40F84F3750E03B55407D03931B453A4C40
65464	155	84.935565999999994	84.951188000000002	56.526173999999997	56.455233999999997	проспект Ленина	0103000020E61000000100000005000000F84F3750E03B55407D03931B453A4C40F84F3750E03B5540B4006DAB59434C404016A243E03C5540B4006DAB59434C404016A243E03C55407D03931B453A4C40F84F3750E03B55407D03931B453A4C40
28785	155	84.950676000000001	84.989869999999996	56.466763	56.461064	проспект Кирова	0103000020E61000000100000005000000E54526E0D73C554075AE2825043B4C40E54526E0D73C5540CEFDD5E3BE3B4C40A852B3075A3F5540CEFDD5E3BE3B4C40A852B3075A3F554075AE2825043B4C40E54526E0D73C554075AE2825043B4C40
28983	155	84.956200999999993	84.962012999999999	56.480832999999997	56.479416000000001	Юрточный переулок	0103000020E61000000100000005000000C2D9AD65323D5540EE96E4805D3D4C40C2D9AD65323D554035EB8CEF8B3D4C40EB54F99E913D554035EB8CEF8B3D4C40EB54F99E913D5540EE96E4805D3D4C40C2D9AD65323D5540EE96E4805D3D4C40
74634	155	84.818489	85.124984999999995	56.632238000000001	56.406146999999997	Школьная 	0103000020E61000000100000005000000B0C8AF1F623455402B2FF99FFC334C40B0C8AF1F62345540ECA4BE2CED504C4065DF15C1FF475540ECA4BE2CED504C4065DF15C1FF4755402B2FF99FFC334C40B0C8AF1F623455402B2FF99FFC334C40
66465	155	84.818489	85.124984999999995	56.632238000000001	56.406146999999997	Школьная	0103000020E61000000100000005000000B0C8AF1F623455402B2FF99FFC334C40B0C8AF1F62345540ECA4BE2CED504C4065DF15C1FF475540ECA4BE2CED504C4065DF15C1FF4755402B2FF99FFC334C40B0C8AF1F623455402B2FF99FFC334C40
74319	155	84.818489	85.124984999999995	56.632238000000001	56.406146999999997	Школьная	0103000020E61000000100000005000000B0C8AF1F623455402B2FF99FFC334C40B0C8AF1F62345540ECA4BE2CED504C4065DF15C1FF475540ECA4BE2CED504C4065DF15C1FF4755402B2FF99FFC334C40B0C8AF1F623455402B2FF99FFC334C40
28730	155	84.956981999999996	84.957269999999994	56.524203	56.513283000000001	Шегарский переулок	0103000020E6100000010000000500000015376E313F3D5540E04BE141B3414C4015376E313F3D554088BB7A1519434C4048DC63E9433D554088BB7A1519434C4048DC63E9433D5540E04BE141B3414C4015376E313F3D5540E04BE141B3414C40
74368	155	84.987641999999994	84.999643000000006	56.484824000000003	56.484755	Челюскинцев	0103000020E61000000100000005000000FC89CA86353F554047C9AB730C3E4C40FC89CA86353F554070287CB60E3E4C40392BA226FA3F554070287CB60E3E4C40392BA226FA3F554047C9AB730C3E4C40FC89CA86353F554047C9AB730C3E4C40
65356	155	85.030850999999998	85.034165000000002	56.529837999999998	56.528657000000003	Центральная	0103000020E6100000010000000500000021037976F941554097E65608AB434C4021037976F9415540CA1649BBD1434C40BE6A65C22F425540CA1649BBD1434C40BE6A65C22F42554097E65608AB434C4021037976F941554097E65608AB434C40
9839	155	84.896390999999994	85.141262999999995	56.631020999999997	56.399949999999997	Хмельницкого	0103000020E61000000100000005000000705B5B785E3955408104C58F31334C40705B5B785E3955406B0BCF4BC5504C40A148F7730A4955406B0BCF4BC5504C40A148F7730A4955408104C58F31334C40705B5B785E3955408104C58F31334C40
74377	155	84.979215999999994	84.989958999999999	56.520429999999998	56.520384999999997	Ференца Мюнниха	0103000020E6100000010000000500000013EE9579AB3E55401B2AC6F99B424C4013EE9579AB3E5540BBED42739D424C406058FE7C5B3F5540BBED42739D424C406058FE7C5B3F55401B2AC6F99B424C4013EE9579AB3E55401B2AC6F99B424C40
28733	155	84.964455999999998	84.965022000000005	56.523876000000001	56.511628999999999	Ферганская улица	0103000020E61000000100000005000000959BA8A5B93D5540B4571F0F7D414C40959BA8A5B93D55406494675E0E434C40EA7AA2EBC23D55406494675E0E434C40EA7AA2EBC23D5540B4571F0F7D414C40959BA8A5B93D5540B4571F0F7D414C40
74356	155	84.964455999999998	84.965022000000005	56.523876000000001	56.511628999999999	Ферганская	0103000020E61000000100000005000000959BA8A5B93D5540B4571F0F7D414C40959BA8A5B93D55406494675E0E434C40EA7AA2EBC23D55406494675E0E434C40EA7AA2EBC23D5540B4571F0F7D414C40959BA8A5B93D5540B4571F0F7D414C40
65322	155	84.971715000000003	84.971750999999998	56.455159999999999	56.448214999999998	Федора Лыткина	0103000020E6100000010000000500000017821C94303E5540CF49EF1B5F394C4017821C94303E55404339D1AE423A4C40BD361B2B313E55404339D1AE423A4C40BD361B2B313E5540CF49EF1B5F394C4017821C94303E5540CF49EF1B5F394C40
74292	155	84.818489	85.124984999999995	56.632238000000001	56.406146999999997	Фабричная	0103000020E61000000100000005000000B0C8AF1F623455402B2FF99FFC334C40B0C8AF1F62345540ECA4BE2CED504C4065DF15C1FF475540ECA4BE2CED504C4065DF15C1FF4755402B2FF99FFC334C40B0C8AF1F623455402B2FF99FFC334C40
65298	155	84.938503999999995	84.970923999999997	56.45899	56.458889999999997	Учебная	0103000020E6100000010000000500000092CA1473103C5540103B53E8BC3A4C4092CA1473103C554074982F2FC03A4C40B2B96A9E233E554074982F2FC03A4C40B2B96A9E233E5540103B53E8BC3A4C4092CA1473103C5540103B53E8BC3A4C40
65344	155	84.950801999999996	84.986239999999995	56.464081999999998	56.460923999999999	Усова	0103000020E610000001000000050000002BBEA1F0D93C554083F8C08EFF3A4C402BBEA1F0D93C5540C554FA09673B4C407380608E1E3F5540C554FA09673B4C407380608E1E3F554083F8C08EFF3A4C402BBEA1F0D93C554083F8C08EFF3A4C40
65902	155	85.009416999999999	85.030932000000007	56.537736000000002	56.528443000000003	Угрюмова	0103000020E61000000100000005000000B1C1C2499A4055406B662D05A4434C40B1C1C2499A405540E1F08288D4444C40981936CAFA415540E1F08288D4444C40981936CAFA4155406B662D05A4434C40B1C1C2499A4055406B662D05A4434C40
74366	155	84.933958000000004	84.936832999999993	56.521625999999998	56.515636999999998	Трудовая	0103000020E610000001000000050000009B75C6F7C53B5540C4CDA96400424C409B75C6F7C53B5540245F09A4C4424C4011346612F53B5540245F09A4C4424C4011346612F53B5540C4CDA96400424C409B75C6F7C53B5540C4CDA96400424C40
74370	155	84.970258999999999	84.972881999999998	56.484411999999999	56.463828999999997	Тверская	0103000020E61000000100000005000000946934B9183E5540DBF7A8BF5E3B4C40946934B9183E55401DE56036013E4C407E37DDB2433E55401DE56036013E4C407E37DDB2433E5540DBF7A8BF5E3B4C40946934B9183E5540DBF7A8BF5E3B4C40
28744	155	84.939796999999999	84.945824999999999	56.499885999999996	56.499150999999998	Сухоозерный переулок	0103000020E6100000010000000500000040F850A2253C55400262122EE43F4C4040F850A2253C554037DDB243FC3F4C404FAF9465883C554037DDB243FC3F4C404FAF9465883C55400262122EE43F4C4040F850A2253C55400262122EE43F4C40
65434	155	85.018912	85.028479000000004	56.515379000000003	56.508648999999998	Суворова	0103000020E610000001000000050000002060ADDA35415540511212691B414C402060ADDA35415540C90567F0F7414C40DC679599D2415540C90567F0F7414C40DC679599D2415540511212691B414C402060ADDA35415540511212691B414C40
74301	155	84.975765999999993	84.989374999999995	56.572879999999998	56.567478999999999	Спутник	0103000020E610000001000000050000001EA33CF3723E55405915E126A3484C401EA33CF3723E55402844C02154494C40B81E85EB513F55402844C02154494C40B81E85EB513F55405915E126A3484C401EA33CF3723E55405915E126A3484C40
74584	155	84.896120999999994	84.917824999999993	56.523130999999999	56.498356000000001	Сплавная	0103000020E610000001000000050000009010E50B5A395540F8E12021CA3F4C409010E50B5A3955400B43E4F4F5424C40E09C11A5BD3A55400B43E4F4F5424C40E09C11A5BD3A5540F8E12021CA3F4C409010E50B5A395540F8E12021CA3F4C40
65953	155	84.957098999999999	84.958095999999998	56.496507999999999	56.495832	Соляная площадь	0103000020E6100000010000000500000032022A1C413D5540B727486C773F4C4032022A1C413D5540E719FB928D3F4C406B9BE271513D5540E719FB928D3F4C406B9BE271513D5540B727486C773F4C4032022A1C413D5540B727486C773F4C40
74410	155	84.952849999999998	84.953954999999993	56.476170000000003	56.455264	Советская	0103000020E6100000010000000500000097FF907EFB3C5540E8853B17463A4C4097FF907EFB3C55400DAB7823F33C4C40C3B645990D3D55400DAB7823F33C4C40C3B645990D3D5540E8853B17463A4C4097FF907EFB3C5540E8853B17463A4C40
9567	155	84.896390999999994	85.141262999999995	56.631020999999997	56.399949999999997	Смирнова	0103000020E61000000100000005000000705B5B785E3955408104C58F31334C40705B5B785E3955406B0BCF4BC5504C40A148F7730A4955406B0BCF4BC5504C40A148F7730A4955408104C58F31334C40705B5B785E3955408104C58F31334C40
74354	155	84.964905000000002	85.020034999999993	56.482641999999998	56.47963	Сибирская	0103000020E61000000100000005000000CDAFE600C13D55401A170E84643D4C40CDAFE600C13D554088D68A36C73D4C409F71E1404841554088D68A36C73D4C409F71E140484155401A170E84643D4C40CDAFE600C13D55401A170E84643D4C40
65257	155	85.022756999999999	85.047478999999996	56.520752000000002	56.513342999999999	Сергея Лазо	0103000020E6100000010000000500000053B0C6D974415540B5503239B5414C4053B0C6D974415540CEA96400A8424C40CB0F5CE509435540CEA96400A8424C40CB0F5CE509435540B5503239B5414C4053B0C6D974415540B5503239B5414C40
74365	155	84.995727000000002	85.008599000000004	56.486722999999998	56.485595000000004	Сергея Вицмана	0103000020E61000000100000005000000A12FBDFDB93F5540F20C1AFA273E4C40A12FBDFDB93F5540029B73F04C3E4C40D0F1D1E28C405540029B73F04C3E4C40D0F1D1E28C405540F20C1AFA273E4C40A12FBDFDB93F5540F20C1AFA273E4C40
66499	155	84.993866999999995	84.994146000000001	56.500045	56.497461999999999	Северный Городок	0103000020E61000000100000005000000B66455849B3F55405A80B6D5AC3F4C40B66455849B3F5540A0C37C7901404C40C05C8B16A03F5540A0C37C7901404C40C05C8B16A03F55405A80B6D5AC3F4C40B66455849B3F55405A80B6D5AC3F4C40
74843	155	84.958312000000006	84.959631999999999	56.490445000000001	56.487662	Свердлова	0103000020E6100000010000000500000052D7DAFB543D554040C05AB56B3E4C4052D7DAFB543D55404DBED9E6C63E4C407C0C569C6A3D55404DBED9E6C63E4C407C0C569C6A3D554040C05AB56B3E4C4052D7DAFB543D554040C05AB56B3E4C40
65254	155	84.955662000000004	84.999724000000001	56.500765999999999	56.494017999999997	Пушкина	0103000020E61000000100000005000000EB01F390293D554052D158FB3B3F4C40EB01F390293D55407079AC1919404C40AF415F7AFB3F55407079AC1919404C40AF415F7AFB3F554052D158FB3B3F4C40EB01F390293D554052D158FB3B3F4C40
74289	155	84.818489	85.124984999999995	56.632238000000001	56.406146999999997	Путевая	0103000020E61000000100000005000000B0C8AF1F623455402B2FF99FFC334C40B0C8AF1F62345540ECA4BE2CED504C4065DF15C1FF475540ECA4BE2CED504C4065DF15C1FF4755402B2FF99FFC334C40B0C8AF1F623455402B2FF99FFC334C40
65287	155	84.950873999999999	84.962632999999997	56.461536000000002	56.461461	Пирогова	0103000020E6100000010000000500000078279F1EDB3C554092B06F27113B4C4078279F1EDB3C55409DF6949C133B4C40394371C79B3D55409DF6949C133B4C40394371C79B3D554092B06F27113B4C4078279F1EDB3C554092B06F27113B4C40
65268	155	84.996436000000003	84.996526000000003	56.502578999999997	56.501148000000001	Переездный переулок	0103000020E61000000100000005000000A723809BC53F5540583A1F9E25404C40A723809BC53F55400454388254404C4047E7FC14C73F55400454388254404C4047E7FC14C73F5540583A1F9E25404C40A723809BC53F5540583A1F9E25404C40
74373	155	84.963037	84.964025000000007	56.530042000000002	56.510368	Первомайская	0103000020E61000000100000005000000A1F5F065A23D5540647616BD53414C40A1F5F065A23D5540D3C08F6AD8434C40B1E1E995B23D5540D3C08F6AD8434C40B1E1E995B23D5540647616BD53414C40A1F5F065A23D5540647616BD53414C40
28782	155	84.971445000000003	84.980473000000003	56.499572999999998	56.497188000000001	Партизанская улица	0103000020E610000001000000050000003737A6272C3E554059FB3BDBA33F4C403737A6272C3E5540787B1002F23F4C401B67D311C03E5540787B1002F23F4C401B67D311C03E554059FB3BDBA33F4C403737A6272C3E554059FB3BDBA33F4C40
65256	155	84.971445000000003	84.980473000000003	56.499572999999998	56.497188000000001	Партизанская	0103000020E610000001000000050000003737A6272C3E554059FB3BDBA33F4C403737A6272C3E5540787B1002F23F4C401B67D311C03E5540787B1002F23F4C401B67D311C03E554059FB3BDBA33F4C403737A6272C3E554059FB3BDBA33F4C40
74382	155	84.955662000000004	84.965875999999994	56.494017999999997	56.486375000000002	Октябрьская	0103000020E61000000100000005000000EB01F390293D5540C74B3789413E4C40EB01F390293D554052D158FB3B3F4C4071FF91E9D03D554052D158FB3B3F4C4071FF91E9D03D5540C74B3789413E4C40EB01F390293D5540C74B3789413E4C40
74302	155	84.955662000000004	84.965875999999994	56.494017999999997	56.486375000000002	Октябрьская	0103000020E61000000100000005000000EB01F390293D5540C74B3789413E4C40EB01F390293D554052D158FB3B3F4C4071FF91E9D03D554052D158FB3B3F4C4071FF91E9D03D5540C74B3789413E4C40EB01F390293D5540C74B3789413E4C40
65361	155	85.011205000000004	85.022756999999999	56.513342999999999	56.509340000000002	Новосибирская	0103000020E610000001000000050000004F232D95B7405540B745990D32414C404F232D95B7405540B5503239B5414C4053B0C6D974415540B5503239B5414C4053B0C6D974415540B745990D32414C404F232D95B7405540B745990D32414C40
74375	155	84.953244999999995	84.981397999999999	56.477919999999997	56.477362999999997	Никитина	0103000020E61000000100000005000000D50451F7013D554004A9143B1A3D4C40D50451F7013D55405A0D897B2C3D4C4007978E39CF3E55405A0D897B2C3D4C4007978E39CF3E554004A9143B1A3D4C40D50451F7013D554004A9143B1A3D4C40
74296	155	84.995806999999999	84.997218000000004	56.464663999999999	56.463937999999999	Нахимова	0103000020E610000001000000050000002F88484DBB3F554092AF0452623B4C402F88484DBB3F554074D0251C7A3B4C40E23E726BD23F554074D0251C7A3B4C40E23E726BD23F554092AF0452623B4C402F88484DBB3F554092AF0452623B4C40
74720	155	84.945070999999999	84.961895999999996	56.553168999999997	56.533368000000003	Мостовая	0103000020E610000001000000050000007959130B7C3C5540D15D126745444C407959130B7C3C55409C14E63DCE464C40CE893DB48F3D55409C14E63DCE464C40CE893DB48F3D5540D15D126745444C407959130B7C3C5540D15D126745444C40
65339	155	84.980258000000006	85.003900999999999	56.451872000000002	56.449314999999999	Мокрушина	0103000020E610000001000000050000001DE90C8CBC3E5540164D672783394C401DE90C8CBC3E554033FD12F1D6394C40FDDAFAE93F40554033FD12F1D6394C40FDDAFAE93F405540164D672783394C401DE90C8CBC3E5540164D672783394C40
65259	155	85.008589999999998	85.067188000000002	56.531342000000002	56.503250000000001	Мичурина	0103000020E61000000100000005000000A64412BD8C40554023DBF97E6A404C40A64412BD8C405540E17EC00303444C40C1ABE5CE4C445540E17EC00303444C40C1ABE5CE4C44554023DBF97E6A404C40A64412BD8C40554023DBF97E6A404C40
74446	155	85.052993999999998	85.058339000000004	56.541657000000001	56.538137999999996	МПС	0103000020E610000001000000050000009738F240644355400F5EBBB4E1444C409738F2406443554022533E0455454C40354580D3BB43554022533E0455454C40354580D3BB4355400F5EBBB4E1444C409738F240644355400F5EBBB4E1444C40
74466	155	84.935565999999994	84.951188000000002	56.526173999999997	56.455233999999997	Ленина проспект	0103000020E61000000100000005000000F84F3750E03B55407D03931B453A4C40F84F3750E03B5540B4006DAB59434C404016A243E03C5540B4006DAB59434C404016A243E03C55407D03931B453A4C40F84F3750E03B55407D03931B453A4C40
65454	155	84.970474999999993	84.999786999999998	56.479297000000003	56.479018000000003	Лебедева	0103000020E610000001000000050000007AA52C431C3E554001193A76503D4C407AA52C431C3E55401409A69A593D4C40D2FD9C82FC3F55401409A69A593D4C40D2FD9C82FC3F554001193A76503D4C407AA52C431C3E554001193A76503D4C40
74396	155	84.972406000000007	84.986034000000004	56.463146999999999	56.457841000000002	Косарева	0103000020E61000000100000005000000CA1B60E63B3E55404CE2AC889A3A4C40CA1B60E63B3E5540C91EA166483B4C409FAF592E1B3F5540C91EA166483B4C409FAF592E1B3F55404CE2AC889A3A4C40CA1B60E63B3E55404CE2AC889A3A4C40
28976	155	84.978632000000005	84.984470999999999	56.500492000000001	56.466518999999998	Комсомольский проспект	0103000020E610000001000000050000006CB41CE8A13E554037FB03E5B63B4C406CB41CE8A13E55406FF4311F10404C401137A792013F55406FF4311F10404C401137A792013F554037FB03E5B63B4C406CB41CE8A13E554037FB03E5B63B4C40
28724	155	84.974445000000003	84.978497000000004	56.531561000000004	56.529243000000001	Кольцевой проезд	0103000020E610000001000000050000000CB08F4E5D3E55408751103CBE434C400CB08F4E5D3E55401F6ADB300A444C40FC8EE1B19F3E55401F6ADB300A444C40FC8EE1B19F3E55408751103CBE434C400CB08F4E5D3E55408751103CBE434C40
65282	155	84.975532000000001	84.975990999999993	56.484158000000001	56.456383000000002	Киевская	0103000020E61000000100000005000000E50CC51D6F3E5540A6B915C26A3A4C40E50CC51D6F3E5540630CACE3F83D4C402E8CF4A2763E5540630CACE3F83D4C402E8CF4A2763E5540A6B915C26A3A4C40E50CC51D6F3E5540A6B915C26A3A4C40
66472	155	84.950568000000004	84.981308999999996	56.469397999999998	56.468971000000003	Карташова	0103000020E61000000100000005000000F2272A1BD63C5540DFE2E13D073C4C40F2272A1BD63C55406667D13B153C4C404F9143C4CD3E55406667D13B153C4C404F9143C4CD3E5540DFE2E13D073C4C40F2272A1BD63C5540DFE2E13D073C4C40
65372	155	84.945017000000007	84.947478000000004	56.504148999999998	56.488486999999999	Карла Маркса	0103000020E61000000100000005000000804A95287B3C5540B5C2F4BD863E4C40804A95287B3C5540D2A755F487404C407DEBC37AA33C5540D2A755F487404C407DEBC37AA33C5540B5C2F4BD863E4C40804A95287B3C5540B5C2F4BD863E4C40
74363	155	84.968247000000005	84.975037999999998	56.508749000000002	56.504868999999999	Карла Ильмера	0103000020E61000000100000005000000CFDC43C2F73D5540D2E1218C9F404C40CFDC43C2F73D5540B56FEEAF1E414C40DD96C805673E5540B56FEEAF1E414C40DD96C805673E5540D2E1218C9F404C40CFDC43C2F73D5540D2E1218C9F404C40
74336	155	85.015867	85.016846000000001	56.499563000000002	56.498848000000002	Калинина	0103000020E610000001000000050000007B8505F70341554067D65240DA3F4C407B8505F70341554055A52DAEF13F4C4061C43E011441554055A52DAEF13F4C4061C43E011441554067D65240DA3F4C407B8505F70341554067D65240DA3F4C40
29031	155	84.999669999999995	85.085117999999994	56.524303000000003	56.500691000000003	Иркутский тракт	0103000020E61000000100000005000000B532E197FA3F5540663387A416404C40B532E197FA3F5540EC18575C1C434C404293C49272455540EC18575C1C434C404293C49272455540663387A416404C40B532E197FA3F5540663387A416404C40
74360	155	84.979521000000005	84.988899000000004	56.517212000000001	56.513123999999998	Интернационалистов	0103000020E61000000100000005000000B22FD978B03E55407765170CAE414C40B22FD978B03E5540A48CB80034424C400403081F4A3F5540A48CB80034424C400403081F4A3F55407765170CAE414C40B22FD978B03E55407765170CAE414C40
65352	155	85.074175999999994	85.092691000000002	56.518273999999998	56.502400000000002	Ивановского	0103000020E610000001000000050000007A89B14CBF44554055C1A8A44E404C407A89B14CBF445540FD2E6CCD56424C408C683BA6EE455540FD2E6CCD56424C408C683BA6EE45554055C1A8A44E404C407A89B14CBF44554055C1A8A44E404C40
65277	155	85.010675000000006	85.061142000000004	56.522257000000003	56.506732	Ивана Черных	0103000020E61000000100000005000000A1F831E6AE40554018EB1B98DC404C40A1F831E6AE405540B58D3F51D9424C405F9A22C0E9435540B58D3F51D9424C405F9A22C0E943554018EB1B98DC404C40A1F831E6AE40554018EB1B98DC404C40
74378	155	84.975532000000001	84.993471999999997	56.471158000000003	56.470984000000001	Енисейская	0103000020E61000000100000005000000E50CC51D6F3E55403A782634493C4C40E50CC51D6F3E5540D89FC4E74E3C4C40785F950B953F5540D89FC4E74E3C4C40785F950B953F55403A782634493C4C40E50CC51D6F3E55403A782634493C4C40
65460	155	84.975470000000001	85.016585000000006	56.479371	56.455179999999999	Елизаровых	0103000020E61000000100000005000000AA0EB9196E3E55408AE59656433A4C40AA0EB9196E3E55404ED367075C3D4C40AB2688BA0F4155404ED367075C3D4C40AB2688BA0F4155408AE59656433A4C40AA0EB9196E3E55408AE59656433A4C40
66498	155	85.073466999999994	85.085289000000003	56.495508999999998	56.493749999999999	Демьяна Бедного	0103000020E610000001000000050000007495EEAEB344554033333333333F4C407495EEAEB3445540D4EFC2D66C3F4C40596DFE5F75455540D4EFC2D66C3F4C40596DFE5F7545554033333333333F4C407495EEAEB344554033333333333F4C40
65303	155	84.941485999999998	84.944810000000004	56.481509000000003	56.471485999999999	Горького	0103000020E6100000010000000500000014E97E4E413C5540CC423BA7593C4C4014E97E4E413C554066DD3F16A23D4C40C3BB5CC4773C554066DD3F16A23D4C40C3BB5CC4773C5540CC423BA7593C4C4014E97E4E413C5540CC423BA7593C4C40
65427	155	84.950398000000007	84.991720000000001	56.473807999999998	56.471606000000001	Герцена	0103000020E61000000100000005000000C40B2252D33C5540774CDD955D3C4C40C40B2252D33C5540A54A94BDA53C4C4081B22957783F5540A54A94BDA53C4C4081B22957783F5540774CDD955D3C4C40C40B2252D33C5540774CDD955D3C4C40
74298	155	84.999022999999994	85.002823000000006	56.429813000000003	56.421802999999997	Геологов	0103000020E61000000100000005000000EA3C2AFEEF3F5540662D05A4FD354C40EA3C2AFEEF3F5540A532C51C04374C404E2B85402E405540A532C51C04374C404E2B85402E405540662D05A4FD354C40EA3C2AFEEF3F5540662D05A4FD354C40
65261	155	84.978613999999993	84.997801999999993	56.506449000000003	56.500557000000001	Вокзальная	0103000020E61000000100000005000000185A9D9CA13E55405664744012404C40185A9D9CA13E5540C40B2252D3404C408978EBFCDB3F5540C40B2252D3404C408978EBFCDB3F55405664744012404C40185A9D9CA13E55405664744012404C40
74367	155	84.935907999999998	84.943166000000005	56.508524999999999	56.494807999999999	Войкова	0103000020E610000001000000050000002504ABEAE53B55404BE658DE553F4C402504ABEAE53B55406519E25817414C40BF2CEDD45C3C55406519E25817414C40BF2CEDD45C3C55404BE658DE553F4C402504ABEAE53B55404BE658DE553F4C40
74667	155	84.818489	85.124984999999995	56.632238000000001	56.406146999999997	Водозаборная улица	0103000020E61000000100000005000000B0C8AF1F623455402B2FF99FFC334C40B0C8AF1F62345540ECA4BE2CED504C4065DF15C1FF475540ECA4BE2CED504C4065DF15C1FF4755402B2FF99FFC334C40B0C8AF1F623455402B2FF99FFC334C40
66413	155	84.962399000000005	84.963217	56.473908000000002	56.451031	Вершинина	0103000020E6100000010000000500000000ADF9F1973D5540B83D4162BB394C4000ADF9F1973D554009A87004A93C4C40E17CEA58A53D554009A87004A93C4C40E17CEA58A53D5540B83D4162BB394C4000ADF9F1973D5540B83D4162BB394C40
66454	155	85.039376000000004	85.048052999999996	56.470502000000003	56.467688000000003	Вавилова	0103000020E61000000100000005000000D40FEA2285425540A75D4C33DD3B4C40D40FEA2285425540EF59D768393C4C4061DEE34C13435540EF59D768393C4C4061DEE34C13435540A75D4C33DD3B4C40D40FEA2285425540A75D4C33DD3B4C40
65475	155	85.031462000000005	85.038647999999995	56.505901999999999	56.500641000000002	Бирюкова	0103000020E610000001000000050000004644317903425540B404190115404C404644317903425540917D9065C1404C409203763579425540917D9065C1404C409203763579425540B404190115404C404644317903425540B404190115404C40
65271	155	85.030635000000004	85.039268000000007	56.521030000000003	56.511600000000001	Беринга	0103000020E610000001000000050000003BC780ECF54155401A51DA1B7C414C403BC780ECF5415540111E6D1CB1424C40E1F1ED5D83425540111E6D1CB1424C40E1F1ED5D834255401A51DA1B7C414C403BC780ECF54155401A51DA1B7C414C40
65963	155	84.961752000000004	84.967851999999993	56.499423999999998	56.494008000000001	Белозерская улица	0103000020E6100000010000000500000035B742588D3D55402FFB75A73B3F4C4035B742588D3D5540336B2920ED3F4C4090D78349F13D5540336B2920ED3F4C4090D78349F13D55402FFB75A73B3F4C4035B742588D3D55402FFB75A73B3F4C40
66462	155	84.957566	84.961303000000001	56.477809999999998	56.458939999999998	Белинского	0103000020E61000000100000005000000BD70E7C2483D5540C269C18BBE3A4C40BD70E7C2483D5540D3D9C9E0283D4C40FDA204FD853D5540D3D9C9E0283D4C40FDA204FD853D5540C269C18BBE3A4C40BD70E7C2483D5540C269C18BBE3A4C40
65924	155	85.044315999999995	85.059838999999997	56.524804000000003	56.517083	Бела Куна	0103000020E6100000010000000500000021ACC612D6425540A62897C62F424C4021ACC612D6425540AE6708C72C434C409F01F566D4435540AE6708C72C434C409F01F566D4435540A62897C62F424C4021ACC612D6425540A62897C62F424C40
74483	155	84.980571999999995	84.998242000000005	56.431102000000003	56.412222999999997	Басандайская	0103000020E61000000100000005000000E4D70FB1C13E55405AD427B9C3344C40E4D70FB1C13E5540BF9EAF592E374C4098DF6932E33F5540BF9EAF592E374C4098DF6932E33F55405AD427B9C3344C40E4D70FB1C13E55405AD427B9C3344C40
66501	155	84.963621000000003	84.969836999999998	56.494008000000001	56.491697000000002	Ачинская	0103000020E61000000100000005000000492F6AF7AB3D55404A4563EDEF3E4C40492F6AF7AB3D55402FFB75A73B3F4C40D95C35CF113E55402FFB75A73B3F4C40D95C35CF113E55404A4563EDEF3E4C40492F6AF7AB3D55404A4563EDEF3E4C40
65291	155	84.934866	84.950703000000004	56.463217	56.462246999999998	Аркадия Иванова	0103000020E610000001000000050000001C0934D8D43B554049D6E1E82A3B4C401C0934D8D43B5540C2F9D4B14A3B4C40624D6551D83C5540C2F9D4B14A3B4C40624D6551D83C554049D6E1E82A3B4C401C0934D8D43B554049D6E1E82A3B4C40
28963	155	84.957665000000006	85.016441999999998	56.484605000000002	56.479371	Алтайская улица	0103000020E6100000010000000500000087E123624A3D55404ED367075C3D4C4087E123624A3D5540323D6189073E4C40F911BF620D415540323D6189073E4C40F911BF620D4155404ED367075C3D4C4087E123624A3D55404ED367075C3D4C40
74369	155	84.957665000000006	85.016441999999998	56.484605000000002	56.479371	Алтайская	0103000020E6100000010000000500000087E123624A3D55404ED367075C3D4C4087E123624A3D5540323D6189073E4C40F911BF620D415540323D6189073E4C40F911BF620D4155404ED367075C3D4C4087E123624A3D55404ED367075C3D4C40
74350	155	84.944810000000004	84.953173000000007	56.481727999999997	56.481349999999999	Алексея Беленца	0103000020E61000000100000005000000C3BB5CC4773C5540FDF675E09C3D4C40C3BB5CC4773C5540A3C85A43A93D4C40899B53C9003D5540A3C85A43A93D4C40899B53C9003D5540FDF675E09C3D4C40C3BB5CC4773C5540FDF675E09C3D4C40
74380	155	84.973438999999999	84.984218999999996	56.512552999999997	56.501213	79-й Гвардейской Дивизии	0103000020E61000000100000005000000A96917D34C3E55403FAA61BF27404C40A96917D34C3E5540BC3B32569B414C408446B071FD3E5540BC3B32569B414C408446B071FD3E55403FAA61BF27404C40A96917D34C3E55403FAA61BF27404C40
9610	155	84.896390999999994	85.141262999999995	56.631020999999997	56.399949999999997	79 Гвардейской дивизии	0103000020E61000000100000005000000705B5B785E3955408104C58F31334C40705B5B785E3955406B0BCF4BC5504C40A148F7730A4955406B0BCF4BC5504C40A148F7730A4955408104C58F31334C40705B5B785E3955408104C58F31334C40
74372	155	84.935719000000006	84.953828999999999	56.525126999999998	56.524828999999997	5-й Армии	0103000020E61000000100000005000000BCCFF1D1E23B5540067FBF982D434C40BCCFF1D1E23B5540909F8D5C37434C407D3ECA880B3D5540909F8D5C37434C407D3ECA880B3D5540067FBF982D434C40BCCFF1D1E23B5540067FBF982D434C40
74529	155	84.935719000000006	84.953828999999999	56.525126999999998	56.524828999999997	 5-й Армии	0103000020E61000000100000005000000BCCFF1D1E23B5540067FBF982D434C40BCCFF1D1E23B5540909F8D5C37434C407D3ECA880B3D5540909F8D5C37434C407D3ECA880B3D5540067FBF982D434C40BCCFF1D1E23B5540067FBF982D434C40
74543	15359	82.962929000000003	82.979979	57.996600999999998	57.980499999999999	переулок Клубный	0103000020E61000000100000005000000AED7F4A0A0BD54402FDD240681FD4C40AED7F4A0A0BD544098141F9F90FF4C4013F1D6F9B7BE544098141F9F90FF4C4013F1D6F9B7BE54402FDD240681FD4C40AED7F4A0A0BD54402FDD240681FD4C40
66613	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	площадь Нефтяников	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
66616	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	Н. Мержи	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
66642	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	Молодежная	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
66611	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	Коммунальная	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
74318	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	Викулова	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
65995	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	Буровиков	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
65417	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	4 микрорайон	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
65389	56685	77.023043999999999	78.077702000000002	60.996195999999998	60.479858	3 микрорайон	0103000020E610000001000000050000009E978A8D79415340AB5CA8FC6B3D4E409E978A8D79415340F833BC59837F4E405D35CF11F9845340F833BC59837F4E405D35CF11F9845340AB5CA8FC6B3D4E409E978A8D79415340AB5CA8FC6B3D4E40
74381	60291	84.957863000000003	84.981362000000004	56.527813000000002	56.503090999999998	проспект Мира	0103000020E610000001000000050000001AC39CA04D3D5540BAF42F4965404C401AC39CA04D3D5540ABB35A608F434C4061E28FA2CE3E5540ABB35A608F434C4061E28FA2CE3E5540BAF42F4965404C401AC39CA04D3D5540BAF42F4965404C40
74314	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	проспект Коммунистический	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74306	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	просп. Коммунистический	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74342	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	пер.Чекист	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74532	60291	84.964492000000007	84.968785999999994	56.494858000000001	56.491151000000002	Школьный переулок	0103000020E610000001000000050000003C50A73CBA3D5540E8323509DE3E4C403C50A73CBA3D5540FD14C781573F4C40A6B4FE96003E5540FD14C781573F4C40A6B4FE96003E5540E8323509DE3E4C403C50A73CBA3D5540E8323509DE3E4C40
74348	60291	84.938772999999998	84.944415000000006	56.519263000000002	56.518293999999997	Чапаева	0103000020E610000001000000050000008A5759DB143C554044DB317557424C408A5759DB143C5540ED82C13577424C4085B69C4B713C5540ED82C13577424C4085B69C4B713C554044DB317557424C408A5759DB143C554044DB317557424C40
74450	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	Чайковского	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74324	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	Строителей	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74688	60291	76.038319000000001	76.129777000000004	57.458443000000003	57.450443999999997	Сосновая 	0103000020E6100000010000000500000030F488D173025340F7562426A8B94C4030F488D173025340420A9E42AEBA4C4079B130444E085340420A9E42AEBA4C4079B130444E085340F7562426A8B94C4030F488D173025340F7562426A8B94C40
74315	60291	76.647430999999997	77.702089000000001	60.935428999999999	60.418103000000002	Северная	0103000020E61000000100000005000000A9DA6E826F29534004AE2B6684354E40A9DA6E826F295340705D3123BC774E406878B306EF6C5340705D3123BC774E406878B306EF6C534004AE2B6684354E40A9DA6E826F29534004AE2B6684354E40
74344	60291	85.017870000000002	85.020681999999994	56.499076000000002	56.497973000000002	Победы	0103000020E61000000100000005000000176536C82441554040A54A94BD3F4C40176536C824415540F81BEDB8E13F4C406A6798DA52415540F81BEDB8E13F4C406A6798DA5241554040A54A94BD3F4C40176536C82441554040A54A94BD3F4C40
74329	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	Пионерская	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74852	60291	84.963037	84.964025000000007	56.530042000000002	56.510368	Первомайская	0103000020E61000000100000005000000A1F5F065A23D5540647616BD53414C40A1F5F065A23D5540D3C08F6AD8434C40B1E1E995B23D5540D3C08F6AD8434C40B1E1E995B23D5540647616BD53414C40A1F5F065A23D5540647616BD53414C40
74421	60291	85.026736	85.034704000000005	56.529913000000001	56.519813999999997	Парковая	0103000020E610000001000000050000000E68E90AB64155406000E14389424C400E68E90AB6415540D55C6E30D4434C409642209738425540D55C6E30D4434C4096422097384255406000E14389424C400E68E90AB64155406000E14389424C40
74331	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	Ленинградская	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74310	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	Курчатова	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74439	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	Крупской	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74343	60291	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	Коммунистический проспект	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74340	60291	85.015867	85.016846000000001	56.499563000000002	56.498848000000002	Калинина	0103000020E610000001000000050000007B8505F70341554067D65240DA3F4C407B8505F70341554055A52DAEF13F4C4061C43E011441554055A52DAEF13F4C4061C43E011441554067D65240DA3F4C407B8505F70341554067D65240DA3F4C40
74391	60291	84.941485999999998	84.944810000000004	56.481509000000003	56.471485999999999	Горького	0103000020E6100000010000000500000014E97E4E413C5540CC423BA7593C4C4014E97E4E413C554066DD3F16A23D4C40C3BB5CC4773C554066DD3F16A23D4C40C3BB5CC4773C5540CC423BA7593C4C4014E97E4E413C5540CC423BA7593C4C40
74418	13356	79.429990000000004	79.455044000000001	57.577697999999998	57.565859000000003	Горького	0103000020E61000000100000005000000DAE6C6F484DB5340DA9255116EC84C40DAE6C6F484DB5340787B1002F2C94C406D8FDE701FDD5340787B1002F2C94C406D8FDE701FDD5340DA9255116EC84C40DAE6C6F484DB5340DA9255116EC84C40
74526	60301	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Обская	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74491	13243	79.550974999999994	79.586134999999999	57.570343000000001	57.554550999999996	1 микрорайон	0103000020E61000000100000005000000787AA52C43E35340677BF486FBC64C40787AA52C43E353405340DAFF00C94C409F02603C83E553405340DAFF00C94C409F02603C83E55340677BF486FBC64C40787AA52C43E35340677BF486FBC64C40
66430	52317	85.006578000000005	85.02158	56.431843000000001	56.428279000000003	Совхозная	0103000020E61000000100000005000000E1B721C66B4055402448A5D8D1364C40E1B721C66B405540D600A5A146374C40DA8F149161415540D600A5A146374C40DA8F1491614155402448A5D8D1364C40E1B721C66B4055402448A5D8D1364C40
74358	52317	85.011537000000004	85.026196999999996	56.429842000000001	56.425441999999997	Зеленая	0103000020E610000001000000050000006A6CAF05BD405540232C2AE274364C406A6CAF05BD4055403F390A1005374C4036902E36AD4155403F390A1005374C4036902E36AD415540232C2AE274364C406A6CAF05BD405540232C2AE274364C40
74459	60302	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	просп. Коммунистический	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
74893	60370	85.030850999999998	85.034165000000002	56.529837999999998	56.528657000000003	Центральная	0103000020E6100000010000000500000021037976F941554097E65608AB434C4021037976F9415540CA1649BBD1434C40BE6A65C22F425540CA1649BBD1434C40BE6A65C22F42554097E65608AB434C4021037976F941554097E65608AB434C40
74376	60289	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	проспект Ленина	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74321	60289	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Тельмана	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74308	60289	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Ивана Буева	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74438	60289	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Гончарова	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74593	3346	83.697166999999993	83.710200999999998	56.874620999999998	56.860083000000003	Набережная	0103000020E610000001000000050000006D3656629EEC54403C6C2233176E4C406D3656629EEC544089B2B794F36F4C408925E5EE73ED544089B2B794F36F4C408925E5EE73ED54403C6C2233176E4C406D3656629EEC54403C6C2233176E4C40
74685	47717	83.535210000000006	83.579137000000003	56.824966000000003	56.818626999999999	Центральная	0103000020E61000000100000005000000809F71E140E25440B14F00C5C8684C40809F71E140E25440EE27637C98694C40D4B9A29410E55440EE27637C98694C40D4B9A29410E55440B14F00C5C8684C40809F71E140E25440B14F00C5C8684C40
74580	49299	83.058698000000007	84.503997999999996	57.085397999999998	56.3735	Центральная	0103000020E61000000100000005000000CD9541B5C1C354402B8716D9CE2F4C40CD9541B5C1C3544068925852EE8A4C40F6CFD3804120554068925852EE8A4C40F6CFD380412055402B8716D9CE2F4C40CD9541B5C1C354402B8716D9CE2F4C40
74500	47910	84.156484000000006	84.181861999999995	56.547969000000002	56.520256000000003	 Ленина	0103000020E610000001000000050000003A9677D5030A55401EC6A4BF97424C403A9677D5030A5540651C23D923464C40A69883A0A30B5540651C23D923464C40A69883A0A30B55401EC6A4BF97424C403A9677D5030A55401EC6A4BF97424C40
74595	3494	84.052756000000002	84.106682000000006	56.990806999999997	56.973184000000003	Новая	0103000020E61000000100000005000000BDAAB35A60035540C87E164B917C4C40BDAAB35A60035540EDD286C3D27E4C409A44BDE0D3065540EDD286C3D27E4C409A44BDE0D3065540C87E164B917C4C40BDAAB35A60035540C87E164B917C4C40
74412	4299	84.042227999999994	84.081627999999995	56.537571999999997	56.522430999999997	Сибирская	0103000020E610000001000000050000006EBE11DDB302554052B5DD04DF424C406EBE11DDB3025540669FC728CF444C40069CA56439055540669FC728CF444C40069CA5643905554052B5DD04DF424C406EBE11DDB302554052B5DD04DF424C40
74760	47937	83.712196000000006	83.741264999999999	56.952559000000001	56.932127999999999	Советская	0103000020E61000000100000005000000E415889E94ED5440CBD765F84F774C40E415889E94ED544057410C74ED794C40D82AC1E270EF544057410C74ED794C40D82AC1E270EF5440CBD765F84F774C40E415889E94ED5440CBD765F84F774C40
74441	46285	83.058698000000007	84.503997999999996	57.085397999999998	56.3735	Гончарова	0103000020E61000000100000005000000CD9541B5C1C354402B8716D9CE2F4C40CD9541B5C1C3544068925852EE8A4C40F6CFD3804120554068925852EE8A4C40F6CFD380412055402B8716D9CE2F4C40CD9541B5C1C354402B8716D9CE2F4C40
74482	48124	84.057805000000002	84.099450000000004	56.578085999999999	56.541949000000002	Школьная	0103000020E61000000100000005000000E622BE13B3035540CA8CB7955E454C40E622BE13B30355404223D8B8FE494C40956588635D0655404223D8B8FE494C40956588635D065540CA8CB7955E454C40E622BE13B3035540CA8CB7955E454C40
66411	48124	84.057805000000002	84.099450000000004	56.578085999999999	56.541949000000002	Чапаева	0103000020E61000000100000005000000E622BE13B3035540CA8CB7955E454C40E622BE13B30355404223D8B8FE494C40956588635D0655404223D8B8FE494C40956588635D065540CA8CB7955E454C40E622BE13B3035540CA8CB7955E454C40
74417	48124	84.057805000000002	84.099450000000004	56.578085999999999	56.541949000000002	Суворова	0103000020E61000000100000005000000E622BE13B3035540CA8CB7955E454C40E622BE13B30355404223D8B8FE494C40956588635D0655404223D8B8FE494C40956588635D065540CA8CB7955E454C40E622BE13B3035540CA8CB7955E454C40
74422	48124	84.057805000000002	84.099450000000004	56.578085999999999	56.541949000000002	Московская	0103000020E61000000100000005000000E622BE13B3035540CA8CB7955E454C40E622BE13B30355404223D8B8FE494C40956588635D0655404223D8B8FE494C40956588635D065540CA8CB7955E454C40E622BE13B3035540CA8CB7955E454C40
74403	48124	84.057805000000002	84.099450000000004	56.578085999999999	56.541949000000002	Коммунистическая	0103000020E61000000100000005000000E622BE13B3035540CA8CB7955E454C40E622BE13B30355404223D8B8FE494C40956588635D0655404223D8B8FE494C40956588635D065540CA8CB7955E454C40E622BE13B3035540CA8CB7955E454C40
74761	48124	84.057805000000002	84.099450000000004	56.578085999999999	56.541949000000002	Калинина	0103000020E61000000100000005000000E622BE13B3035540CA8CB7955E454C40E622BE13B30355404223D8B8FE494C40956588635D0655404223D8B8FE494C40956588635D065540CA8CB7955E454C40E622BE13B3035540CA8CB7955E454C40
74499	2761	83.553661000000005	83.575363999999993	56.713755999999997	56.695566999999997	Рабочая	0103000020E6100000010000000500000086048C2E6FE35440A296E65608594C4086048C2E6FE3544071A94A5B5C5B4C40EDD286C3D2E4544071A94A5B5C5B4C40EDD286C3D2E45440A296E65608594C4086048C2E6FE35440A296E65608594C40
74596	3765	84.371882999999997	84.391681000000005	56.867783000000003	56.842374	Школьная	0103000020E610000001000000050000000EBC5AEECC175540178046E9D26B4C400EBC5AEECC1755402C836A83136F4C40BC5D2F4D111955402C836A83136F4C40BC5D2F4D11195540178046E9D26B4C400EBC5AEECC175540178046E9D26B4C40
74495	47859	83.947608000000002	83.968987999999996	56.624578999999997	56.613812000000003	Юбилейная	0103000020E61000000100000005000000645B069CA5FC544039F24064914E4C40645B069CA5FC54405A626534F24F4C40DA8D3EE603FE54405A626534F24F4C40DA8D3EE603FE544039F24064914E4C40645B069CA5FC544039F24064914E4C40
74592	2811	83.575113000000002	83.594228999999999	56.646543999999999	56.636361999999998	Центральная 	0103000020E6100000010000000500000049A0C1A6CEE4544065355D4F74514C4049A0C1A6CEE4544067B62BF4C1524C406D5512D907E6544067B62BF4C1524C406D5512D907E6544065355D4F74514C4049A0C1A6CEE4544065355D4F74514C40
74737	47969	83.993279000000001	84.035597999999993	56.894945999999997	56.872855000000001	Гагарина	0103000020E610000001000000050000006E3315E291FF544036936FB6B96F4C406E3315E291FF5440CFD72C978D724C406473D53C47025540CFD72C978D724C406473D53C4702554036936FB6B96F4C406E3315E291FF544036936FB6B96F4C40
74608	2698	83.438793000000004	83.478283000000005	56.835520000000002	56.821040000000004	Кооперативная	0103000020E61000000100000005000000AE2D3C2F15DC54409B5AB6D617694C40AE2D3C2F15DC5440B493C151F26A4C40E6CE4C309CDE5440B493C151F26A4C40E6CE4C309CDE54409B5AB6D617694C40AE2D3C2F15DC54409B5AB6D617694C40
74602	48093	84.278835000000001	84.298005000000003	56.904674	56.891567999999999	Энергетическая	0103000020E61000000100000005000000BB7EC16ED81155407F1475E61E724C40BB7EC16ED811554050C58D5BCC734C40D94290831213554050C58D5BCC734C40D9429083121355407F1475E61E724C40BB7EC16ED81155407F1475E61E724C40
74501	60305	83.555870999999996	83.569650999999993	56.502639000000002	56.490732999999999	Цветочная	0103000020E61000000100000005000000DE72F56393E35440B308C556D03E4C40DE72F56393E35440DA58897956404C408EC8772975E45440DA58897956404C408EC8772975E45440B308C556D03E4C40DE72F56393E35440B308C556D03E4C40
74408	2888	83.839890999999994	83.882812999999999	56.561219999999999	56.543030999999999	пер. Кооперативный	0103000020E610000001000000050000001A4D2EC6C0F554406ADB300A82454C401A4D2EC6C0F5544039EE940ED6474C40F4DE180280F8544039EE940ED6474C40F4DE180280F854406ADB300A82454C401A4D2EC6C0F554406ADB300A82454C40
74606	47828	83.596779999999995	83.618950999999996	56.564895	56.547134999999997	Советская	0103000020E610000001000000050000000ABABDA431E654409CBF098508464C400ABABDA431E654404356B77A4E484C40E5B4A7E49CE754404356B77A4E484C40E5B4A7E49CE754409CBF098508464C400ABABDA431E654409CBF098508464C40
74745	2540	83.562950000000001	83.581913	56.78246	56.762044000000003	Школьный	0103000020E6100000010000000500000020D26F5F07E45440780E65A88A614C4020D26F5F07E45440CE3637A627644C40810706103EE55440CE3637A627644C40810706103EE55440780E65A88A614C4020D26F5F07E45440780E65A88A614C40
74589	349	82.597296999999998	82.617787000000007	57.778170000000003	57.771417	Светлая	0103000020E61000000100000005000000EE3F321D3AA654400A4AD1CABDE24C40EE3F321D3AA654403A5D16139BE34C4037397CD289A754403A5D16139BE34C4037397CD289A754400A4AD1CABDE24C40EE3F321D3AA654400A4AD1CABDE24C40
74735	1774	82.999651999999998	83.012946999999997	57.747227000000002	57.734391000000002	Трактовая	0103000020E6100000010000000500000062D8614CFABF544006BD378600DE4C4062D8614CFABF544017D86322A5DF4C403465A71FD4C0544017D86322A5DF4C403465A71FD4C0544006BD378600DE4C4062D8614CFABF544006BD378600DE4C40
74588	1726	82.581746999999993	82.604483000000002	57.936700000000002	57.923754000000002	Комсомольская	0103000020E61000000100000005000000F3E2C4573BA554404CC631923DF64C40F3E2C4573BA55440E4141DC9E5F74C403BFF76D9AFA65440E4141DC9E5F74C403BFF76D9AFA654404CC631923DF64C40F3E2C4573BA554404CC631923DF64C40
74508	1105	82.301940000000002	82.333973	57.622024000000003	57.601495	Центральная	0103000020E61000000100000005000000AC5626FC5293544090DAC4C9FDCC4C40AC5626FC52935440DFA9807B9ECF4C40CF2F4AD05F955440DFA9807B9ECF4C40CF2F4AD05F95544090DAC4C9FDCC4C40AC5626FC5293544090DAC4C9FDCC4C40
74661	2023	82.636257000000001	82.644970000000001	57.815727000000003	57.813042000000003	Трудовой	0103000020E6100000010000000500000078B6476FB8A854402123A0C211E84C4078B6476FB8A854406BBB09BE69E84C40AC39403047A954406BBB09BE69E84C40AC39403047A954402123A0C211E84C4078B6476FB8A854402123A0C211E84C40
74806	984	82.360518999999996	82.384324000000007	57.498837999999999	57.484045999999999	Центральная	0103000020E610000001000000050000008BA548BE129754403BE12538F5BD4C408BA548BE12975440430070ECD9BF4C4059C4B0C398985440430070ECD9BF4C4059C4B0C3989854403BE12538F5BD4C408BA548BE129754403BE12538F5BD4C40
74818	60342	82.613636999999997	82.745437999999993	58.064867999999997	57.994951	Мостовая	0103000020E6100000010000000500000065A71FD445A75440AE0FEB8D5AFF4C4065A71FD445A75440494739984D084D4085CC9541B5AF5440494739984D084D4085CC9541B5AF5440AE0FEB8D5AFF4C4065A71FD445A75440AE0FEB8D5AFF4C40
74591	1885	82.821956	82.836392000000004	57.703795999999997	57.691583999999999	Центральная	0103000020E6100000010000000500000010B056ED9AB45440EB3713D385D84C4010B056ED9AB454401E87C1FC15DA4C40B5A84F7287B554401E87C1FC15DA4C40B5A84F7287B55440EB3713D385D84C4010B056ED9AB45440EB3713D385D84C40
74811	1249	82.430372000000006	82.458076000000005	57.717517999999998	57.711176000000002	Береговая	0103000020E610000001000000050000004E4700378B9B54409DD9AED007DB4C404E4700378B9B54404A253CA1D7DB4C4048C5FF1D519D54404A253CA1D7DB4C4048C5FF1D519D54409DD9AED007DB4C404E4700378B9B54409DD9AED007DB4C40
74406	2135	82.605714000000006	82.673968000000002	57.805067999999999	57.766195000000003	Трактовая	0103000020E61000000100000005000000AE2EA704C4A65440EBAD81AD12E24C40AE2EA704C4A654402F87DD770CE74C403CA3AD4A22AB54402F87DD770CE74C403CA3AD4A22AB5440EBAD81AD12E24C40AE2EA704C4A65440EBAD81AD12E24C40
74401	2135	82.605714000000006	82.673968000000002	57.805067999999999	57.766195000000003	Советская	0103000020E61000000100000005000000AE2EA704C4A65440EBAD81AD12E24C40AE2EA704C4A654402F87DD770CE74C403CA3AD4A22AB54402F87DD770CE74C403CA3AD4A22AB5440EBAD81AD12E24C40AE2EA704C4A65440EBAD81AD12E24C40
74671	2135	82.605714000000006	82.673968000000002	57.805067999999999	57.766195000000003	Подлесная	0103000020E61000000100000005000000AE2EA704C4A65440EBAD81AD12E24C40AE2EA704C4A654402F87DD770CE74C403CA3AD4A22AB54402F87DD770CE74C403CA3AD4A22AB5440EBAD81AD12E24C40AE2EA704C4A65440EBAD81AD12E24C40
74400	2135	82.605714000000006	82.673968000000002	57.805067999999999	57.766195000000003	Ленинская	0103000020E61000000100000005000000AE2EA704C4A65440EBAD81AD12E24C40AE2EA704C4A654402F87DD770CE74C403CA3AD4A22AB54402F87DD770CE74C403CA3AD4A22AB5440EBAD81AD12E24C40AE2EA704C4A65440EBAD81AD12E24C40
74481	2135	82.605714000000006	82.673968000000002	57.805067999999999	57.766195000000003	Горная	0103000020E61000000100000005000000AE2EA704C4A65440EBAD81AD12E24C40AE2EA704C4A654402F87DD770CE74C403CA3AD4A22AB54402F87DD770CE74C403CA3AD4A22AB5440EBAD81AD12E24C40AE2EA704C4A65440EBAD81AD12E24C40
74814	1353	83.370431999999994	83.396932000000007	57.745483999999998	57.733435	Школьная	0103000020E6100000010000000500000014596B28B5D75440F25EB532E1DD4C4014596B28B5D754407BD80B056CDF4C4019AF795567D954407BD80B056CDF4C4019AF795567D95440F25EB532E1DD4C4014596B28B5D75440F25EB532E1DD4C40
74816	1126	82.333246000000003	82.346343000000005	57.624876999999998	57.616042	Больничная	0103000020E6100000010000000500000076E107E753955440317BD976DACE4C4076E107E753955440E48233F8FBCF4C40B58CD47B2A965440E48233F8FBCF4C40B58CD47B2A965440317BD976DACE4C4076E107E753955440317BD976DACE4C40
74819	1452	83.257476999999994	83.275075000000001	57.833857999999999	57.825643999999997	Обская	0103000020E61000000100000005000000389ECF807AD05440BE11DDB3AEE94C40389ECF807AD0544005C1E3DBBBEA4C409F3C2CD49AD1544005C1E3DBBBEA4C409F3C2CD49AD15440BE11DDB3AEE94C40389ECF807AD05440BE11DDB3AEE94C40
74617	998	82.302576999999999	82.332509000000002	57.570604000000003	57.554946999999999	Трактовая	0103000020E6100000010000000500000065E1EB6B5D935440B401D88008C74C4065E1EB6B5D935440C07B478D09C94C400B28D4D347955440C07B478D09C94C400B28D4D347955440B401D88008C74C4065E1EB6B5D935440B401D88008C74C40
74734	1959	82.646101999999999	82.669844999999995	57.812663000000001	57.801091999999997	Октябрьская	0103000020E6100000010000000500000055F833BC59A954402A8BC22E8AE64C4055F833BC59A95440AAD5575705E84C40E71890BDDEAA5440AAD5575705E84C40E71890BDDEAA54402A8BC22E8AE64C4055F833BC59A954402A8BC22E8AE64C40
74730	907	81.306794999999994	83.579792999999995	58.119697000000002	57.328097999999997	Трактовая	0103000020E61000000100000005000000E2E47E87A253544006F1811DFFA94C40E2E47E87A2535440F436363B520F4D40C85C19541BE55440F436363B520F4D40C85C19541BE5544006F1811DFFA94C40E2E47E87A253544006F1811DFFA94C40
74812	1341	82.444017000000002	82.470877000000002	57.707709999999999	57.696769000000003	Набережная	0103000020E610000001000000050000008E7747C66A9C5440EEEE01BA2FD94C408E7747C66A9C5440AD86C43D96DA4C4012DC48D9229E5440AD86C43D96DA4C4012DC48D9229E5440EEEE01BA2FD94C408E7747C66A9C5440EEEE01BA2FD94C40
74662	1463	83.162066999999993	83.187723000000005	57.883105	57.870614000000003	Пролетарская	0103000020E61000000100000005000000B130444E5FCA54404AB8904770EF4C40B130444E5FCA544090F7AA9509F14C40406D54A703CC544090F7AA9509F14C40406D54A703CC54404AB8904770EF4C40B130444E5FCA54404AB8904770EF4C40
74507	1572	83.135091000000003	83.159220000000005	57.804315000000003	57.781083000000002	Советская	0103000020E61000000100000005000000F9BEB854A5C85440153B1A87FAE34C40F9BEB854A5C8544054573ECBF3E64C40A03715A930CA544054573ECBF3E64C40A03715A930CA5440153B1A87FAE34C40F9BEB854A5C85440153B1A87FAE34C40
74705	1835	82.739455000000007	82.760278	57.727443000000001	57.708661999999997	Новая	0103000020E610000001000000050000004777103B53AF54407FF5B86FB5DA4C404777103B53AF5440215A2BDA1CDD4C4092770E65A8B05440215A2BDA1CDD4C4092770E65A8B054407FF5B86FB5DA4C404777103B53AF54407FF5B86FB5DA4C40
74659	51982	82.589014000000006	82.720815000000002	58.077024999999999	58.007131000000001	Советская	0103000020E61000000100000005000000B7B8C667B2A55440D6E429ABE9004D40B7B8C667B2A55440B9FC87F4DB094D40D7DD3CD521AE5440B9FC87F4DB094D40D7DD3CD521AE5440D6E429ABE9004D40B7B8C667B2A55440D6E429ABE9004D40
74663	2083	82.616799	82.635232000000002	57.761178000000001	57.751286	Энергетиков	0103000020E61000000100000005000000274D83A279A75440A9F8BF232AE04C40274D83A279A75440A437DC476EE14C40DA571EA4A7A85440A437DC476EE14C40DA571EA4A7A85440A9F8BF232AE04C40274D83A279A75440A9F8BF232AE04C40
74585	856	82.198687000000007	82.230506000000005	57.485061999999999	57.466304999999998	Центральная	0103000020E61000000100000005000000FCC8AD49B78C54400B7BDAE1AFBB4C40FCC8AD49B78C54402444F98216BE4C4009E23C9CC08E54402444F98216BE4C4009E23C9CC08E54400B7BDAE1AFBB4C40FCC8AD49B78C54400B7BDAE1AFBB4C40
74817	1229	82.429051000000001	82.455453000000006	57.687157999999997	57.669544999999999	Центральная	0103000020E610000001000000050000003B545392759B5440A4198BA6B3D54C403B545392759B5440A69718CBF4D74C405EF75624269D5440A69718CBF4D74C405EF75624269D5440A4198BA6B3D54C403B545392759B5440A4198BA6B3D54C40
74813	799	81.981590999999995	82.011505	57.552601000000003	57.540120000000002	Школьная	0103000020E6100000010000000500000011C30E63D27E544030F5F3A622C54C4011C30E63D27E5440535E2BA1BBC64C4064AF777FBC805440535E2BA1BBC64C4064AF777FBC80544030F5F3A622C54C4011C30E63D27E544030F5F3A622C54C40
74835	60353	84.323715000000007	86.176920999999993	57.102131999999997	56.147295	Октябрьская	0103000020E61000000100000005000000618E1EBFB7145540A2EE0390DA124C40618E1EBFB714554002F04FA9128D4C40703E75AC528B554002F04FA9128D4C40703E75AC528B5540A2EE0390DA124C40618E1EBFB7145540A2EE0390DA124C40
66410	46816	84.897631000000004	84.922145999999998	56.411441000000003	56.392741999999998	Береговая	0103000020E610000001000000050000000D384BC97239554000E2AE5E45324C400D384BC972395540E59D4319AA344C40C808A870043B5540E59D4319AA344C40C808A870043B554000E2AE5E45324C400D384BC97239554000E2AE5E45324C40
74587	46643	85.581885999999997	85.607578000000004	56.638496000000004	56.630243	Лесная	0103000020E610000001000000050000000400C79E3D65554037C478CDAB504C400400C79E3D6555403C50A73CBA514C4039F1D58EE26655403C50A73CBA514C4039F1D58EE266554037C478CDAB504C400400C79E3D65554037C478CDAB504C40
74657	31900	85.952063999999993	86.012322999999995	56.652031999999998	56.630960999999999	Школьная	0103000020E61000000100000005000000BBECD79DEE7C554096067E54C3504C40BBECD79DEE7C554005F9D9C875534C40457F68E6C980554005F9D9C875534C40457F68E6C980554096067E54C3504C40BBECD79DEE7C554096067E54C3504C40
74487	48060	85.097702999999996	85.107962000000001	56.429867000000002	56.424824999999998	Центральная	0103000020E61000000100000005000000266E15C440465540F8C264AA60364C40266E15C4404655409850C1E105374C407DCD72D9E84655409850C1E105374C407DCD72D9E8465540F8C264AA60364C40266E15C440465540F8C264AA60364C40
74444	46254	85.609689000000003	85.621735999999999	56.850206	56.839433999999997	Маяковского	0103000020E61000000100000005000000C8EE0225056755404293C492726B4C40C8EE022505675540766EDA8CD36C4C40BCAFCA85CA675540766EDA8CD36C4C40BCAFCA85CA6755404293C492726B4C40C8EE0225056755404293C492726B4C40
74411	32419	84.870564000000002	84.892904999999999	56.389578	56.370947000000001	Советская	0103000020E61000000100000005000000CC441152B737554050C6F8307B2F4C40CC441152B7375540DC9E20B1DD314C40D55B035B25395540DC9E20B1DD314C40D55B035B2539554050C6F8307B2F4C40CC441152B737554050C6F8307B2F4C40
74802	46591	85.448072999999994	85.481292999999994	56.483894999999997	56.472555	Лесная	0103000020E610000001000000050000001E4E603AAD5C5540D847A7AE7C3C4C401E4E603AAD5C554055D97745F03D4C40CCB22781CD5E554055D97745F03D4C40CCB22781CD5E5540D847A7AE7C3C4C401E4E603AAD5C5540D847A7AE7C3C4C40
74651	32087	86.114372000000003	86.121557999999993	56.715311999999997	56.698497000000003	Сибирская	0103000020E6100000010000000500000000E5EFDE5187554054AD855968594C4000E5EFDE51875540DA37F7578F5B4C404CA4349BC7875540DA37F7578F5B4C404CA4349BC787554054AD855968594C4000E5EFDE5187554054AD855968594C40
74751	31056	84.916262000000003	84.926511000000005	56.339821000000001	56.334158000000002	Парковая	0103000020E6100000010000000500000053245F09A43A554030D978B0C52A4C4053245F09A43A55403CBF28417F2B4C409818CBF44B3B55403CBF28417F2B4C409818CBF44B3B554030D978B0C52A4C4053245F09A43A554030D978B0C52A4C40
74416	31837	85.339179000000001	85.385326000000006	56.621825000000001	56.609952999999997	Иркутский  тракт	0103000020E610000001000000050000005C1FD61BB55555406D8C9DF0124E4C405C1FD61BB5555540E86A2BF6974F4C401B13622EA9585540E86A2BF6974F4C401B13622EA95855406D8C9DF0124E4C405C1FD61BB55555406D8C9DF0124E4C40
74290	60283	84.690676999999994	84.718444000000005	56.762473	56.733643999999998	проспект Ленина	0103000020E610000001000000050000005CC64D0D342C55400C74ED0BE85D4C405CC64D0D342C5540A08A1BB798614C407A008BFCFA2D5540A08A1BB798614C407A008BFCFA2D55400C74ED0BE85D4C405CC64D0D342C55400C74ED0BE85D4C40
74484	29586	84.503360000000001	84.533767999999995	56.514153	56.492522000000001	Коммунистическая	0103000020E610000001000000050000005587DC0C37205540BF47FDF50A3F4C405587DC0C37205540F511F8C3CF414C40AFE9414129225540F511F8C3CF414C40AFE9414129225540BF47FDF50A3F4C405587DC0C37205540BF47FDF50A3F4C40
74600	46795	85.924611999999996	85.951238000000004	56.458646000000002	56.451369	Новая	0103000020E610000001000000050000004E5FCFD72C7B5540D0B69A75C6394C404E5FCFD72C7B55407A3881E9B43A4C40992D5915E17C55407A3881E9B43A4C40992D5915E17C5540D0B69A75C6394C404E5FCFD72C7B5540D0B69A75C6394C40
74409	610	84.749003999999999	84.770805999999993	56.556804999999997	56.542416000000003	Школьная	0103000020E61000000100000005000000AF2479AEEF2F5540E06932E36D454C40AF2479AEEF2F5540E89FE06245474C40E063B0E254315540E89FE06245474C40E063B0E254315540E06932E36D454C40AF2479AEEF2F5540E06932E36D454C40
74650	32012	85.801282	85.831636000000003	56.652453000000001	56.643203	Молодежная	0103000020E61000000100000005000000E7374C344873554034D8D47954524C40E7374C3448735540AB96749483534C40488B338639755540AB96749483534C40488B33863975554034D8D47954524C40E7374C344873554034D8D47954524C40
74731	45909	85.237076999999999	85.258205000000004	56.389009999999999	56.377611999999999	Рабочая	0103000020E61000000100000005000000906802452C4F5540E0490B9755304C40906802452C4F554092E86514CB314C407AAA436E8650554092E86514CB314C407AAA436E86505540E0490B9755304C40906802452C4F5540E0490B9755304C40
74800	45923	85.257836999999995	85.285155000000003	56.329048	56.310806999999997	Новостройка	0103000020E61000000100000005000000B8ACC26680505540162F1686C8274C40B8ACC266805055403868AF3E1E2A4C409ED2C1FA3F5255403868AF3E1E2A4C409ED2C1FA3F525540162F1686C8274C40B8ACC26680505540162F1686C8274C40
74740	60332	84.799858	84.826600999999997	56.539870000000001	56.532941000000001	Гагарина	0103000020E610000001000000050000006ADC9BDF3033554049D9226937444C406ADC9BDF30335540B70BCD751A454C40D175E107E7345540B70BCD751A454C40D175E107E734554049D9226937444C406ADC9BDF3033554049D9226937444C40
74804	46696	85.958819000000005	85.988822999999996	56.697972999999998	56.686377	Лесная	0103000020E6100000010000000500000024F25D4A5D7D554001DD9733DB574C4024F25D4A5D7D5540D93EE42D57594C4016A243E0487F5540D93EE42D57594C4016A243E0487F554001DD9733DB574C4024F25D4A5D7D554001DD9733DB574C40
66444	6058	85.422596999999996	85.446807000000007	56.731951000000002	56.72081	Железнодорожная	0103000020E61000000100000005000000D09849D40B5B55409C508880435C4C40D09849D40B5B554023A30392B05D4C40EE27637C985C554023A30392B05D4C40EE27637C985C55409C508880435C4C40D09849D40B5B55409C508880435C4C40
74399	32353	85.984862000000007	86.029139000000001	56.500948999999999	56.477820000000001	Советская	0103000020E61000000100000005000000AF44A0FA077F5540F7AFAC34293D4C40AF44A0FA077F554061FBC9181F404C407102D369DD81554061FBC9181F404C407102D369DD815540F7AFAC34293D4C40AF44A0FA077F5540F7AFAC34293D4C40
74594	46543	85.134364000000005	85.159381999999994	56.5426	56.535646	Центральная	0103000020E61000000100000005000000A070766B99485540DA1D520C90444C40A070766B99485540A167B3EA73454C408C648F50334A5540A167B3EA73454C408C648F50334A5540DA1D520C90444C40A070766B99485540DA1D520C90444C40
74809	46730	85.879138999999995	85.906537	56.715331999999997	56.708252000000002	Советская	0103000020E61000000100000005000000D76839D043785540CEA96400A85A4C40D76839D04378554021E4BCFF8F5B4C404BE7C3B3047A554021E4BCFF8F5B4C404BE7C3B3047A5540CEA96400A85A4C40D76839D043785540CEA96400A85A4C40
66402	46667	84.529949999999999	84.572053999999994	56.572389000000001	56.554369000000001	Почтовая	0103000020E61000000100000005000000F9A067B3EA21554047753A90F5464C40F9A067B3EA2155408ACBF10A44494C40F16261889C2455408ACBF10A44494C40F16261889C24554047753A90F5464C40F9A067B3EA21554047753A90F5464C40
74447	45795	85.093939000000006	85.153902000000002	56.767263999999997	56.753290999999997	Советская	0103000020E610000001000000050000006A34B9180346554081AFE8D66B604C406A34B91803465540F6B2EDB435624C407F32C687D9495540F6B2EDB435624C407F32C687D949554081AFE8D66B604C406A34B9180346554081AFE8D66B604C40
74355	60296	84.624506999999994	84.664212000000006	56.702204000000002	56.679510000000001	Советская	0103000020E61000000100000005000000E04735ECF727554009A7052FFA564C40E04735ECF7275540698F17D2E1594C4017670C73822A5540698F17D2E1594C4017670C73822A554009A7052FFA564C40E04735ECF727554009A7052FFA564C40
74474	45862	85.108177999999995	85.137067000000002	56.447135000000003	56.436442	Трудовая	0103000020E6100000010000000500000063096B63EC465540E84CDA54DD374C4063096B63EC465540D0F23CB83B394C401897AAB4C5485540D0F23CB83B394C401897AAB4C5485540E84CDA54DD374C4063096B63EC465540E84CDA54DD374C40
74652	29900	85.351360999999997	85.392628999999999	56.371301000000003	56.350696999999997	Первомайская	0103000020E61000000100000005000000C005D9B27C56554014E7A8A3E32C4C40C005D9B27C5655406EFC89CA862F4C40849D62D5205955406EFC89CA862F4C40849D62D52059554014E7A8A3E32C4C40C005D9B27C56554014E7A8A3E32C4C40
74394	32280	86.122735000000006	86.148974999999993	56.603973000000003	56.579934999999999	Г.Николаевой	0103000020E61000000100000005000000C6C4E6E3DA8755402367614F3B4A4C40C6C4E6E3DA8755406155BDFC4E4D4C40FB3A70CE888955406155BDFC4E4D4C40FB3A70CE888955402367614F3B4A4C40C6C4E6E3DA8755402367614F3B4A4C40
74796	31640	85.223934999999997	85.240374000000003	56.488377999999997	56.483060000000002	Центральная 	0103000020E61000000100000005000000815B77F3544E5540BD00FBE8D43D4C40815B77F3544E5540FE0A992B833E4C40C233A149624F5540FE0A992B833E4C40C233A149624F5540BD00FBE8D43D4C40815B77F3544E5540BD00FBE8D43D4C40
74393	30656	85.047353000000001	85.080607999999998	56.367702000000001	56.345913000000003	Зеленая	0103000020E610000001000000050000008597E0D40743554071218FE0462C4C408597E0D4074355403F56F0DB102F4C40F1F274AE284555403F56F0DB102F4C40F1F274AE2845554071218FE0462C4C408597E0D40743554071218FE0462C4C40
74374	60297	85.046813999999998	85.120395000000002	56.393773000000003	56.364910000000002	Ленина	0103000020E61000000100000005000000ADBF2500FF425540DFFDF15EB52E4C40ADBF2500FF4255401F86562767324C4086E63A8DB44755401F86562767324C4086E63A8DB4475540DFFDF15EB52E4C40ADBF2500FF425540DFFDF15EB52E4C40
74655	45618	84.399154999999993	84.432042999999993	56.446314999999998	56.435147999999998	Центральная	0103000020E610000001000000050000003BC269C18B195540BC75FEEDB2374C403BC269C18B1955406C5B94D920394C40CEDDAE97A61B55406C5B94D920394C40CEDDAE97A61B5540BC75FEEDB2374C403BC269C18B195540BC75FEEDB2374C40
65582	222	84.837524000000002	84.872415000000004	56.229787000000002	56.203037000000002	Трактовая	0103000020E610000001000000050000005E6743FE993555406170CD1DFD194C405E6743FE99355540E20511A9691D4C408D62B9A5D5375540E20511A9691D4C408D62B9A5D53755406170CD1DFD194C405E6743FE993555406170CD1DFD194C40
74805	493	84.659729999999996	84.677507000000006	56.540053999999998	56.533949	Бодажкова	0103000020E610000001000000050000002A8C2D04392A5540AF5DDA7058444C402A8C2D04392A554078094E7D20454C40E9F351465C2B554078094E7D20454C40E9F351465C2B5540AF5DDA7058444C402A8C2D04392A5540AF5DDA7058444C40
74464	60303	84.323715000000007	86.176920999999993	57.102131999999997	56.147295	Гагарина	0103000020E61000000100000005000000618E1EBFB7145540A2EE0390DA124C40618E1EBFB714554002F04FA9128D4C40703E75AC528B554002F04FA9128D4C40703E75AC528B5540A2EE0390DA124C40618E1EBFB7145540A2EE0390DA124C40
66627	31521	85.091469000000004	85.166936000000007	56.615352000000001	56.589478	Новая	0103000020E6100000010000000500000043E6CAA0DA45554012DBDD03744B4C4043E6CAA0DA4555409CC3B5DAC34E4C409B215514AF4A55409CC3B5DAC34E4C409B215514AF4A554012DBDD03744B4C4043E6CAA0DA45554012DBDD03744B4C40
74581	31115	84.928335000000004	84.959174000000004	56.341413000000003	56.33325	Центральная	0103000020E61000000100000005000000DC2E34D7693B55402DB29DEFA72A4C40DC2E34D7693B5540F2B6D26BB32B4C401B4B581B633D5540F2B6D26BB32B4C401B4B581B633D55402DB29DEFA72A4C40DC2E34D7693B55402DB29DEFA72A4C40
74725	29748	84.492041	84.508506999999994	56.809531	56.804372000000001	Центральная	0103000020E61000000100000005000000A2D288997D1F5540B8E864A9F5664C40A2D288997D1F5540910C39B69E674C405FB2F1608B205540910C39B69E674C405FB2F1608B205540B8E864A9F5664C40A2D288997D1F5540B8E864A9F5664C40
66635	6401	84.854422	84.886589999999998	56.423375999999998	56.408571999999999	Мира	0103000020E61000000100000005000000E8BE9CD9AE365540D90759164C344C40E8BE9CD9AE365540A5F44C2F31364C407BBDFBE3BD385540A5F44C2F31364C407BBDFBE3BD385540D90759164C344C40E8BE9CD9AE365540D90759164C344C40
65570	62	84.848493000000005	84.881271999999996	56.363996999999998	56.332870999999997	Коммунистическая	0103000020E61000000100000005000000A37895B54D365540B66455849B2A4C40A37895B54D365540CA6B2574972E4C405AB8ACC266385540CA6B2574972E4C405AB8ACC266385540B66455849B2A4C40A37895B54D365540B66455849B2A4C40
74793	45562	84.441601000000006	84.462406000000001	56.492685999999999	56.485008000000001	Центральная	0103000020E610000001000000050000006138D730431C55403126FDBD143E4C406138D730431C55403999B855103F4C4059DE550F981D55403999B855103F4C4059DE550F981D55403126FDBD143E4C406138D730431C55403126FDBD143E4C40
74511	159	84.793507000000005	84.838144	56.303147000000003	56.291254000000002	Советская	0103000020E610000001000000050000006A8995D1C8325540236AA2CF47254C406A8995D1C8325540B5705985CD264C40AC55BB26A4355540B5705985CD264C40AC55BB26A4355540236AA2CF47254C406A8995D1C8325540236AA2CF47254C40
74503	293	84.866665999999995	84.894980000000004	56.289369999999998	56.271486000000003	Ленина 	0103000020E6100000010000000500000087A3AB747737554033A9A10DC0224C4087A3AB7477375540C5387F130A254C40BEA4315A47395540C5387F130A254C40BEA4315A4739554033A9A10DC0224C4087A3AB747737554033A9A10DC0224C40
66397	31208	85.581716	85.623784000000001	56.833022999999997	56.813502999999997	Гагарина	0103000020E61000000100000005000000D6E3BED53A6555405419C6DD20684C40D6E3BED53A6555406CE8667FA06A4C4028F1B913EC6755406CE8667FA06A4C4028F1B913EC6755405419C6DD20684C40D6E3BED53A6555405419C6DD20684C40
66446	546	84.720618000000002	84.756028999999998	56.536822999999998	56.511625000000002	Трактовая	0103000020E610000001000000050000002CBAF59A1E2E5540736891ED7C414C402CBAF59A1E2E5540CC5EB69DB6444C40F77475C762305540CC5EB69DB6444C40F77475C762305540736891ED7C414C402CBAF59A1E2E5540736891ED7C414C40
74597	49559	84.615030000000004	84.641997000000003	56.596648999999999	56.581636000000003	Совхозная	0103000020E61000000100000005000000C503CAA65C2755409016670C734A4C40C503CAA65C275540761893FE5E4C4C4054C8957A16295540761893FE5E4C4C4054C8957A162955409016670C734A4C40C503CAA65C2755409016670C734A4C40
74646	52199	85.256704999999997	85.280708000000004	57.102131999999997	57.092945	Почтовая	0103000020E610000001000000050000000FEECEDA6D505540D2A92B9FE58B4C400FEECEDA6D50554002F04FA9128D4C4070EEAF1EF751554002F04FA9128D4C4070EEAF1EF7515540D2A92B9FE58B4C400FEECEDA6D505540D2A92B9FE58B4C40
74461	47537	85.216892000000001	85.221877000000006	56.344076999999999	56.339416999999997	Уткина	0103000020E61000000100000005000000E6B0FB8EE14D55406C5A2904722B4C40E6B0FB8EE14D5540242713B70A2C4C4004AF963B334E5540242713B70A2C4C4004AF963B334E55406C5A2904722B4C40E6B0FB8EE14D55406C5A2904722B4C40
74442	46520	85.239564999999999	85.278345999999999	56.561056000000001	56.54851	Центральная	0103000020E610000001000000050000000A117008554F5540B5C35F9335464C400A117008554F5540BF9CD9AED0474C403CBEBD6BD0515540BF9CD9AED0474C403CBEBD6BD0515540B5C35F9335464C400A117008554F5540B5C35F9335464C40
74803	46120	84.912622999999996	84.947945000000004	56.245869999999996	56.212665000000001	Советская	0103000020E61000000100000005000000F4A44C6A683A55407E00529B381B4C40F4A44C6A683A5540A4880CAB781F4C40085A8121AB3C5540A4880CAB781F4C40085A8121AB3C55407E00529B381B4C40F4A44C6A683A55407E00529B381B4C40
74647	29676	84.333138000000005	84.361327000000003	56.437173999999999	56.424232000000003	Ветеранов	0103000020E6100000010000000500000083C30B225215554056F5F23B4D364C4083C30B2252155540AC545051F5374C405B0A48FB1F175540AC545051F5374C405B0A48FB1F17554056F5F23B4D364C4083C30B225215554056F5F23B4D364C40
74666	726	84.778343000000007	84.788332999999994	56.561706000000001	56.555306999999999	Школьная	0103000020E610000001000000050000008484285FD0315540B41EBE4C14474C408484285FD0315540C6FB71FBE5474C40E256410C74325540C6FB71FBE5474C40E256410C74325540B41EBE4C14474C408484285FD0315540B41EBE4C14474C40
65564	5981	85.110557999999997	85.192735999999996	56.377541999999998	56.350257999999997	Советская	0103000020E61000000100000005000000EA93DC6113475540C8940F41D52C4C40EA93DC6113475540E76ED74B53304C40C23060C9554C5540E76ED74B53304C40C23060C9554C5540C8940F41D52C4C40EA93DC6113475540C8940F41D52C4C40
65425	5981	85.110557999999997	85.192735999999996	56.377541999999998	56.350257999999997	Новостройка	0103000020E61000000100000005000000EA93DC6113475540C8940F41D52C4C40EA93DC6113475540E76ED74B53304C40C23060C9554C5540E76ED74B53304C40C23060C9554C5540C8940F41D52C4C40EA93DC6113475540C8940F41D52C4C40
74641	45548	84.617168000000007	84.638709000000006	56.489074000000002	56.480882999999999	Сибирская	0103000020E61000000100000005000000D10836AE7F275540E719FB928D3D4C40D10836AE7F27554076A911FA993E4C404CAAB69BE028554076A911FA993E4C404CAAB69BE0285540E719FB928D3D4C40D10836AE7F275540E719FB928D3D4C40
74810	46002	85.177941000000004	85.190929999999994	56.315914999999997	56.299999999999997	Мира	0103000020E6100000010000000500000086E7A562634B55406666666666264C4086E7A562634B55406DA818E76F284C40D1747632384C55406DA818E76F284C40D1747632384C55406666666666264C4086E7A562634B55406666666666264C40
74708	23476	84.960513000000006	84.982764000000003	56.270681000000003	56.253252000000003	Школьная	0103000020E610000001000000050000008198840B793D5540C4D2C08F6A204C408198840B793D55400553CDACA5224C40EAEBF99AE53E55400553CDACA5224C40EAEBF99AE53E5540C4D2C08F6A204C408198840B793D5540C4D2C08F6A204C40
74738	31608	85.259435999999994	85.269936999999999	56.445672999999999	56.439014999999998	Озерная	0103000020E61000000100000005000000ECD973999A5055400ABABDA431384C40ECD973999A505540E8DA17D00B394C40BEBED6A546515540E8DA17D00B394C40BEBED6A5465155400ABABDA431384C40ECD973999A5055400ABABDA431384C40
74498	31232	85.371474000000006	85.401072999999997	56.752791999999999	56.732379999999999	мкр.Казахстан	0103000020E610000001000000050000001E54E23AC65755404B1FBAA0BE5D4C401E54E23AC65755406058FE7C5B604C40C093162EAB5955406058FE7C5B604C40C093162EAB5955404B1FBAA0BE5D4C401E54E23AC65755404B1FBAA0BE5D4C40
74322	31232	85.371474000000006	85.401072999999997	56.752791999999999	56.732379999999999	Советская	0103000020E610000001000000050000001E54E23AC65755404B1FBAA0BE5D4C401E54E23AC65755406058FE7C5B604C40C093162EAB5955406058FE7C5B604C40C093162EAB5955404B1FBAA0BE5D4C401E54E23AC65755404B1FBAA0BE5D4C40
74440	31232	85.371474000000006	85.401072999999997	56.752791999999999	56.732379999999999	Пионерская	0103000020E610000001000000050000001E54E23AC65755404B1FBAA0BE5D4C401E54E23AC65755406058FE7C5B604C40C093162EAB5955406058FE7C5B604C40C093162EAB5955404B1FBAA0BE5D4C401E54E23AC65755404B1FBAA0BE5D4C40
74304	31232	85.371474000000006	85.401072999999997	56.752791999999999	56.732379999999999	Ленина	0103000020E610000001000000050000001E54E23AC65755404B1FBAA0BE5D4C401E54E23AC65755406058FE7C5B604C40C093162EAB5955406058FE7C5B604C40C093162EAB5955404B1FBAA0BE5D4C401E54E23AC65755404B1FBAA0BE5D4C40
74827	60348	84.545383000000001	84.567581000000004	56.376685000000002	56.36842	Школьная	0103000020E61000000100000005000000D732198EE72255409E98F562282F4C40D732198EE722554067F2CD3637304C402F35423F5324554067F2CD3637304C402F35423F532455409E98F562282F4C40D732198EE72255409E98F562282F4C40
74640	28892	88.113213000000002	88.124891000000005	57.063827000000003	57.057181	Садовая	0103000020E61000000100000005000000DA1EBDE13E075640EE79FEB451874C40DA1EBDE13E07564008CDAE7B2B884C402524D236FE07564008CDAE7B2B884C402524D236FE075640EE79FEB451874C40DA1EBDE13E075640EE79FEB451874C40
74654	60326	87.304351999999994	87.327510000000004	57.051482999999998	57.039653000000001	Щитовая	0103000020E61000000100000005000000389ECF807AD355401A18795913854C40389ECF807AD3554065A6B4FE96864C403BC780ECF5D4554065A6B4FE96864C403BC780ECF5D455401A18795913854C40389ECF807AD355401A18795913854C40
74642	28911	88.269924000000003	88.313869999999994	57.434522000000001	57.416010999999997	Советская	0103000020E61000000100000005000000F419506F461156405CE333D93FB54C40F419506F461156403EB2B96A9EB74C40834C3272161456403EB2B96A9EB74C40834C3272161456405CE333D93FB54C40F419506F461156405CE333D93FB54C40
66394	28977	88.125187999999994	88.204427999999993	57.316741	57.294814000000002	Садовая	0103000020E61000000100000005000000817687140308564094331477BCA54C408176871403085640B32616F88AA84C40BF982D59150D5640B32616F88AA84C40BF982D59150D564094331477BCA54C40817687140308564094331477BCA54C40
74586	28977	88.125187999999994	88.204427999999993	57.316741	57.294814000000002	Пушкина	0103000020E61000000100000005000000817687140308564094331477BCA54C408176871403085640B32616F88AA84C40BF982D59150D5640B32616F88AA84C40BF982D59150D564094331477BCA54C40817687140308564094331477BCA54C40
74645	28977	88.125187999999994	88.204427999999993	57.316741	57.294814000000002	Парковая	0103000020E61000000100000005000000817687140308564094331477BCA54C408176871403085640B32616F88AA84C40BF982D59150D5640B32616F88AA84C40BF982D59150D564094331477BCA54C40817687140308564094331477BCA54C40
66395	28977	88.125187999999994	88.204427999999993	57.316741	57.294814000000002	Октябрьская	0103000020E61000000100000005000000817687140308564094331477BCA54C408176871403085640B32616F88AA84C40BF982D59150D5640B32616F88AA84C40BF982D59150D564094331477BCA54C40817687140308564094331477BCA54C40
74726	28977	88.125187999999994	88.204427999999993	57.316741	57.294814000000002	Ленина	0103000020E61000000100000005000000817687140308564094331477BCA54C408176871403085640B32616F88AA84C40BF982D59150D5640B32616F88AA84C40BF982D59150D564094331477BCA54C40817687140308564094331477BCA54C40
74648	28778	88.274963999999997	88.284548999999998	57.081035	57.075071999999999	Лесная	0103000020E61000000100000005000000F3E49A0299115640336C94F59B894C40F3E49A02991156406A6AD95A5F8A4C400247020D361256406A6AD95A5F8A4C400247020D36125640336C94F59B894C40F3E49A0299115640336C94F59B894C40
74660	15157	88.634883000000002	88.640803000000005	57.477227999999997	57.474299999999999	Озерская	0103000020E6100000010000000500000054724EECA1285640143FC6DCB5BC4C4054724EECA1285640245E9ECE15BD4C40700B96EA02295640245E9ECE15BD4C40700B96EA02295640143FC6DCB5BC4C4054724EECA1285640143FC6DCB5BC4C40
74700	52803	88.499893	88.515891999999994	57.423766000000001	57.419049999999999	Новая	0103000020E61000000100000005000000F59F353FFE1F5640C4B12E6EA3B54C40F59F353FFE1F56401094DBF63DB64C402711E15F042156401094DBF63DB64C402711E15F04215640C4B12E6EA3B54C40F59F353FFE1F5640C4B12E6EA3B54C40
74795	52781	88.347843999999995	88.363878999999997	57.351457000000003	57.346513000000002	Куяновская	0103000020E6100000010000000500000007077B1343165640C651B9895AAC4C4007077B1343165640A379008BFCAC4C40E02C25CB49175640A379008BFCAC4C40E02C25CB49175640C651B9895AAC4C4007077B1343165640C651B9895AAC4C40
74431	47501	87.610838999999999	87.623407	57.231907	57.226913000000003	Ленинская	0103000020E61000000100000005000000C40776FC17E75540C504357C0B9D4C40C40776FC17E75540535BEA20AF9D4C403D4679E6E5E75540535BEA20AF9D4C403D4679E6E5E75540C504357C0B9D4C40C40776FC17E75540C504357C0B9D4C40
74703	47501	87.610838999999999	87.623407	57.231907	57.226913000000003	Коммунистическая	0103000020E61000000100000005000000C40776FC17E75540C504357C0B9D4C40C40776FC17E75540535BEA20AF9D4C403D4679E6E5E75540535BEA20AF9D4C403D4679E6E5E75540C504357C0B9D4C40C40776FC17E75540C504357C0B9D4C40
74566	52797	87.220457999999994	87.250174999999999	57.111477999999998	57.099369000000003	Советская	0103000020E610000001000000050000000F09DFFB1BCE55403D9E961FB88C4C400F09DFFB1BCE55409B1C3EE9448E4C40B7D100DE02D055409B1C3EE9448E4C40B7D100DE02D055403D9E961FB88C4C400F09DFFB1BCE55403D9E961FB88C4C40
74494	18749	88.735539000000003	88.782341000000002	57.505332000000003	57.488211	Чкалова	0103000020E61000000100000005000000AF7B2B12132F56401346B3B27DBE4C40AF7B2B12132F5640A7CF0EB8AEC04C407A54FCDF11325640A7CF0EB8AEC04C407A54FCDF113256401346B3B27DBE4C40AF7B2B12132F56401346B3B27DBE4C40
74794	18749	88.735539000000003	88.782341000000002	57.505332000000003	57.488211	Центральная	0103000020E61000000100000005000000AF7B2B12132F56401346B3B27DBE4C40AF7B2B12132F5640A7CF0EB8AEC04C407A54FCDF11325640A7CF0EB8AEC04C407A54FCDF113256401346B3B27DBE4C40AF7B2B12132F56401346B3B27DBE4C40
74722	52773	87.875698	87.894276000000005	57.246529000000002	57.241498	Байгалинская	0103000020E610000001000000050000000CCB9F6F0BF8554053060E68E99E4C400CCB9F6F0BF85540FF4124438E9F4C40416667D13BF95540FF4124438E9F4C40416667D13BF9554053060E68E99E4C400CCB9F6F0BF8554053060E68E99E4C40
74335	52691	85.777664999999999	85.802665000000005	57.718483999999997	57.701867	Комарова	0103000020E610000001000000050000009B8F6B43C5715540219221C7D6D94C409B8F6B43C57155408159A148F7DB4C40352905DD5E7355408159A148F7DB4C40352905DD5E735540219221C7D6D94C409B8F6B43C5715540219221C7D6D94C40
74799	52691	85.777664999999999	85.802665000000005	57.718483999999997	57.701867	Дорожная	0103000020E610000001000000050000009B8F6B43C5715540219221C7D6D94C409B8F6B43C57155408159A148F7DB4C40352905DD5E7355408159A148F7DB4C40352905DD5E735540219221C7D6D94C409B8F6B43C5715540219221C7D6D94C40
74836	60354	86.540756999999999	86.557744	56.938173999999997	56.929383000000001	Центральная	0103000020E6100000010000000500000051853FC39BA25540AC3AAB05F6764C4051853FC39BA255408FFAEB1516784C4093E2E313B2A355408FFAEB1516784C4093E2E313B2A35540AC3AAB05F6764C4051853FC39BA25540AC3AAB05F6764C40
74724	52757	86.380128999999997	86.414876000000007	57.138565	57.124192999999998	Шамского	0103000020E61000000100000005000000B7D095085498554031B2648EE58F4C40B7D095085498554064AF777FBC914C404DF910548D9A554064AF777FBC914C404DF910548D9A554031B2648EE58F4C40B7D095085498554031B2648EE58F4C40
74838	60356	86.335635999999994	86.352677	57.034348999999999	57.017541000000001	Советская	0103000020E610000001000000050000000ED76A0F7B95554069AB92C83E824C400ED76A0F7B9555403DD34B8C65844C404A438D42929655403DD34B8C65844C404A438D429296554069AB92C83E824C400ED76A0F7B95554069AB92C83E824C40
74544	60313	86.056421	86.102406000000002	57.283617	57.264927	Школьная	0103000020E61000000100000005000000B073D3669C835540E869C020E9A14C40B073D3669C83554079CBD58F4DA44C40823AE5D18D86554079CBD58F4DA44C40823AE5D18D865540E869C020E9A14C40B073D3669C835540E869C020E9A14C40
74311	52732	86.207274999999996	86.262387000000004	57.090738999999999	57.064689000000001	Ленинская  	0103000020E61000000100000005000000D1915CFE438D55409AB4A9BA47884C40D1915CFE438D554062BCE6559D8B4C4051F9D7F2CA90554062BCE6559D8B4C4051F9D7F2CA9055409AB4A9BA47884C40D1915CFE438D55409AB4A9BA47884C40
74327	52732	86.207274999999996	86.262387000000004	57.090738999999999	57.064689000000001	Ленинская	0103000020E61000000100000005000000D1915CFE438D55409AB4A9BA47884C40D1915CFE438D554062BCE6559D8B4C4051F9D7F2CA90554062BCE6559D8B4C4051F9D7F2CA9055409AB4A9BA47884C40D1915CFE438D55409AB4A9BA47884C40
76183	52732	86.207274999999996	86.262387000000004	57.090738999999999	57.064689000000001	Комсомольская 	0103000020E61000000100000005000000D1915CFE438D55409AB4A9BA47884C40D1915CFE438D554062BCE6559D8B4C4051F9D7F2CA90554062BCE6559D8B4C4051F9D7F2CA9055409AB4A9BA47884C40D1915CFE438D55409AB4A9BA47884C40
74334	52732	86.207274999999996	86.262387000000004	57.090738999999999	57.064689000000001	Больничная	0103000020E61000000100000005000000D1915CFE438D55409AB4A9BA47884C40D1915CFE438D554062BCE6559D8B4C4051F9D7F2CA90554062BCE6559D8B4C4051F9D7F2CA9055409AB4A9BA47884C40D1915CFE438D55409AB4A9BA47884C40
74534	60309	86.674470999999997	86.697226000000001	57.227950999999997	57.215071999999999	Ленина	0103000020E610000001000000050000006DC669882AAB55408524B37A879B4C406DC669882AAB5540950B957F2D9D4C40F0FACC599FAC5540950B957F2D9D4C40F0FACC599FAC55408524B37A879B4C406DC669882AAB55408524B37A879B4C40
74607	60321	\N	\N	\N	\N	Клубная	\N
74854	60362	86.485923999999997	86.527291000000005	57.139131999999996	57.134779999999999	Центральная улица	0103000020E61000000100000005000000DB15FA60199F5540D313967840914C40DB15FA60199F5540DDE9CE13CF914C40691EC022BFA15540DDE9CE13CF914C40691EC022BFA15540D313967840914C40DB15FA60199F5540D313967840914C40
74833	60350	86.814841999999999	86.833545000000001	57.026178999999999	57.014949000000001	Центральная	0103000020E61000000100000005000000105A0F5F26B45540D00D4DD9E9814C40105A0F5F26B45540C66B5ED559834C40A3AF20CD58B55540C66B5ED559834C40A3AF20CD58B55540D00D4DD9E9814C40105A0F5F26B45540D00D4DD9E9814C40
74826	60347	86.295005000000003	86.318325000000002	57.136229999999998	57.122067999999999	Центральная улица	0103000020E6100000010000000500000004CAA65CE1925540AEF199EC9F8F4C4004CAA65CE1925540F65D11FC6F914C40F31FD26F5F945540F65D11FC6F914C40F31FD26F5F945540AEF199EC9F8F4C4004CAA65CE1925540AEF199EC9F8F4C40
74822	60345	86.458461999999997	86.472448999999997	56.955558000000003	56.941060999999998	Центральная	0103000020E610000001000000050000005C1D0071579D55404145D5AF74784C405C1D0071579D554031B77BB94F7A4C40C901BB9A3C9E554031B77BB94F7A4C40C901BB9A3C9E55404145D5AF74784C405C1D0071579D55404145D5AF74784C40
74644	52748	86.313734999999994	86.34178	57.047291999999999	57.037063000000003	40 Лет Победы	0103000020E610000001000000050000001327F73B149455402272FA7ABE844C401327F73B1494554064AE0CAA0D864C40529B38B9DF95554064AE0CAA0D864C40529B38B9DF9555402272FA7ABE844C401327F73B149455402272FA7ABE844C40
74533	27416	85.984358	86.038931000000005	57.418259999999997	57.398474	Первомайская	0103000020E610000001000000050000009563B2B8FF7E554035272F3201B34C409563B2B8FF7E5540CB9C2E8B89B54C403DF372D87D825540CB9C2E8B89B54C403DF372D87D82554035272F3201B34C409563B2B8FF7E554035272F3201B34C40
74486	27416	85.984358	86.038931000000005	57.418259999999997	57.398474	Первомайская	0103000020E610000001000000050000009563B2B8FF7E554035272F3201B34C409563B2B8FF7E5540CB9C2E8B89B54C403DF372D87D825540CB9C2E8B89B54C403DF372D87D82554035272F3201B34C409563B2B8FF7E554035272F3201B34C40
74832	60351	86.419943000000004	86.437513999999993	56.991905000000003	56.985481	Центральная	0103000020E61000000100000005000000C9CB9A58E09A554029EACC3D247E4C40C9CB9A58E09A554094DE37BEF67E4C40B262B83A009C554094DE37BEF67E4C40B262B83A009C554029EACC3D247E4C40C9CB9A58E09A554029EACC3D247E4C40
74801	46332	86.167462	86.183605	57.182983	57.177537999999998	Светлая	0103000020E61000000100000005000000A85489B2B78A55400CE6AF90B9964C40A85489B2B78A5540AB5CA8FC6B974C4074982F2FC08B5540AB5CA8FC6B974C4074982F2FC08B55400CE6AF90B9964C40A85489B2B78A55400CE6AF90B9964C40
74840	60357	86.105254000000002	86.125564999999995	57.166989000000001	57.150319000000003	Советская	0103000020E610000001000000050000007CF1457BBC865540D57B2AA73D934C407CF1457BBC86554058E542E55F954C406C21C8410988554058E542E55F954C406C21C84109885540D57B2AA73D934C407CF1457BBC865540D57B2AA73D934C40
74888	60368	86.740138000000002	86.768362999999994	57.013185	56.993851999999997	Центральная	0103000020E61000000100000005000000B821C66B5EAF55403788D68A367F4C40B821C66B5EAF55401DE6CB0BB0814C40361D01DC2CB155401DE6CB0BB0814C40361D01DC2CB155403788D68A367F4C40B821C66B5EAF55403788D68A367F4C40
74537	60312	86.243144999999998	86.277101000000002	57.057391000000003	57.045495000000003	Зеленая	0103000020E61000000100000005000000E6CB0BB08F8F5540D690B8C7D2854C40E6CB0BB08F8F5540D90A9A9658874C40172CD505BC915540D90A9A9658874C40172CD505BC915540D690B8C7D2854C40E6CB0BB08F8F5540D690B8C7D2854C40
74837	60355	85.680421999999993	85.703526999999994	57.626278999999997	57.601196000000002	Советская улица	0103000020E61000000100000005000000A65EB7088C6B5540363E93FDF3CC4C40A65EB7088C6B5540F69507E929D04C4097361C96066D5540F69507E929D04C4097361C96066D5540363E93FDF3CC4C40A65EB7088C6B5540363E93FDF3CC4C40
74509	60307	81.037974000000006	82.092631999999995	59.204481000000001	58.659253999999997	Центральная	0103000020E610000001000000050000004B06802A6E425440EBE0606F62544D404B06802A6E425440A2D3F36E2C9A4D4009A4C4AEED855440A2D3F36E2C9A4D4009A4C4AEED855440EBE0606F62544D404B06802A6E425440EBE0606F62544D40
74546	52675	80.063912999999999	81.118571000000003	58.328153	57.768988999999998	Набережная	0103000020E6100000010000000500000083328D2617045440EBFD463B6EE24C4083328D2617045440CA8AE1EA002A4D4042D0D1AA96475440CA8AE1EA002A4D4042D0D1AA96475440EBFD463B6EE24C4083328D2617045440EBFD463B6EE24C40
74615	60323	80.905383	81.960041000000004	58.981596000000003	58.432811999999998	Молодёжная	0103000020E61000000100000005000000AED689CBF13954407EA8346266374D40AED689CBF139544035F10EF0A47D4D406D74CE4F717D544035F10EF0A47D4D406D74CE4F717D54407EA8346266374D40AED689CBF13954407EA8346266374D40
74601	52671	80.064991000000006	81.119648999999995	58.565317	58.009911000000002	Школьная	0103000020E6100000010000000500000033E202D028045440726F7EC344014D4033E202D028045440B96FB54E5C484D40F17F4754A8475440B96FB54E5C484D40F17F4754A8475440726F7EC344014D4033E202D028045440726F7EC344014D40
74749	52667	81.061851000000004	82.116508999999994	59.251018999999999	58.706536	Центральная	0103000020E61000000100000005000000658EE55DF54354402CB98AC56F5A4D40658EE55DF54354405AD6FD6321A04D40232C2AE2748754405AD6FD6321A04D40232C2AE2748754402CB98AC56F5A4D40658EE55DF54354402CB98AC56F5A4D40
74842	60358	80.056196	81.110854000000003	58.411892000000002	57.854053	Советская	0103000020E61000000100000005000000A08A1BB7980354407D06D49B51ED4C40A08A1BB798035440F5BD86E0B8344D405F28603B18475440F5BD86E0B8344D405F28603B184754407D06D49B51ED4C40A08A1BB7980354407D06D49B51ED4C40
74754	60334	79.600149000000002	79.615095999999994	57.498997000000003	57.489885000000001	Рабочая	0103000020E6100000010000000500000089EE59D768E6534086E63A8DB4BE4C4089EE59D768E65340ACE63922DFBF4C40A0F99CBB5DE75340ACE63922DFBF4C40A0F99CBB5DE7534086E63A8DB4BE4C4089EE59D768E6534086E63A8DB4BE4C40
74670	52663	80.831244999999996	81.885902999999999	58.977311	58.428457999999999	Центральная	0103000020E61000000100000005000000AA7D3A1E33355440D3DA34B6D7364D40AA7D3A1E33355440B282DF86187D4D40691B7FA2B2785440B282DF86187D4D40691B7FA2B2785440D3DA34B6D7364D40AA7D3A1E33355440D3DA34B6D7364D40
74573	52645	80.976941999999994	82.031600999999995	58.987822999999999	58.439138	Шишкова	0103000020E61000000100000005000000AF05BD37863E544026378AAC35384D40AF05BD37863E5440499EEBFB707E4D40566133C005825440499EEBFB707E4D40566133C00582544026378AAC35384D40AF05BD37863E544026378AAC35384D40
65285	52645	80.976941999999994	82.031600999999995	58.987822999999999	58.439138	Советская	0103000020E61000000100000005000000AF05BD37863E544026378AAC35384D40AF05BD37863E5440499EEBFB707E4D40566133C005825440499EEBFB707E4D40566133C00582544026378AAC35384D40AF05BD37863E544026378AAC35384D40
65281	52645	80.976941999999994	82.031600999999995	58.987822999999999	58.439138	Некрасова	0103000020E61000000100000005000000AF05BD37863E544026378AAC35384D40AF05BD37863E5440499EEBFB707E4D40566133C005825440499EEBFB707E4D40566133C00582544026378AAC35384D40AF05BD37863E544026378AAC35384D40
74612	60322	81.164968999999999	82.219627000000003	58.906899000000003	58.356923999999999	Лесная	0103000020E61000000100000005000000A5F622DA8E4A5440299485AFAF2D4D40A5F622DA8E4A544037E3344415744D406494675E0E8E544037E3344415744D406494675E0E8E5440299485AFAF2D4D40A5F622DA8E4A5440299485AFAF2D4D40
74792	60338	80.098381000000003	81.153039000000007	58.482382000000001	57.925660999999998	Совхозная	0103000020E610000001000000050000000F63D2DF4B0654406117450F7CF64C400F63D2DF4B065440EC1681B1BE3D4D40CE001764CB495440EC1681B1BE3D4D40CE001764CB4954406117450F7CF64C400F63D2DF4B0654406117450F7CF64C40
74603	52638	80.577489	81.632147000000003	58.951922000000003	58.402664999999999	Сибирская	0103000020E610000001000000050000002F336C94F5245440361FD7868A334D402F336C94F5245440E52B8194D8794D40EED0B01875685440E52B8194D8794D40EED0B01875685440361FD7868A334D402F336C94F5245440361FD7868A334D40
74485	52632	81.076081000000002	82.130739000000005	59.195362000000003	58.649988999999998	Куйбышева	0103000020E6100000010000000500000035B6D782DE4454403FE1ECD632534D4035B6D782DE445440CA703C9F01994D40F4531C075E885440CA703C9F01994D40F4531C075E8854403FE1ECD632534D4035B6D782DE4454403FE1ECD632534D40
74870	60366	81.050622000000004	82.105279999999993	58.932859000000001	58.383298000000003	Трудовая	0103000020E61000000100000005000000529D0E643D435440A54FABE80F314D40529D0E643D435440BF6378EC67774D40103B53E8BC865440BF6378EC67774D40103B53E8BC865440A54FABE80F314D40529D0E643D435440A54FABE80F314D40
74729	60331	79.421077999999994	79.440482000000003	57.565095999999997	57.552368999999999	Геологическая	0103000020E610000001000000050000002AC423F1F2DA534080290307B4C64C402AC423F1F2DA5340DA8CD31055C84C40821E6ADB30DC5340DA8CD31055C84C40821E6ADB30DC534080290307B4C64C402AC423F1F2DA534080290307B4C64C40
74683	60327	81.111384000000001	82.166042000000004	59.170918	58.625154999999999	Молодежная	0103000020E610000001000000050000000D535BEA2047544027F73B1405504D400D535BEA204754401C261AA4E0954D40CCF09F6EA08A54401C261AA4E0954D40CCF09F6EA08A544027F73B1405504D400D535BEA2047544027F73B1405504D40
74436	60300	80.970106000000001	82.024764000000005	58.947702999999997	58.398378000000001	Центральная	0103000020E61000000100000005000000D1E97937163E544013B9E00CFE324D40D1E97937163E544019A9F7544E794D409087BEBB9581544019A9F7544E794D409087BEBB9581544013B9E00CFE324D40D1E97937163E544013B9E00CFE324D40
74808	60340	79.550974999999994	79.586134999999999	57.570343000000001	57.554550999999996	Лесная	0103000020E61000000100000005000000787AA52C43E35340677BF486FBC64C40787AA52C43E353405340DAFF00C94C409F02603C83E553405340DAFF00C94C409F02603C83E55340677BF486FBC64C40787AA52C43E35340677BF486FBC64C40
74772	60337	80.790290999999996	81.844949	58.946227	58.396878999999998	60 Лет СССР	0103000020E61000000100000005000000AED4B320943254400EBC5AEECC324D40AED4B32094325440CDCB61F71D794D406D72F8A413765440CDCB61F71D794D406D72F8A4137654400EBC5AEECC324D40AED4B320943254400EBC5AEECC324D40
74564	52684	81.289026000000007	82.343683999999996	58.839615999999999	58.28857	Красноармейская	0103000020E61000000100000005000000666CE8667F525440A94D9CDCEF244D40666CE8667F52544063997E89786B4D40240A2DEBFE95544063997E89786B4D40240A2DEBFE955440A94D9CDCEF244D40666CE8667F525440A94D9CDCEF244D40
74574	60316	81.229647999999997	82.284306000000001	59.102525999999997	58.555669999999999	Советская	0103000020E61000000100000005000000E065868DB24E544025AFCE3120474D40E065868DB24E5440AE7E6C921F8D4D409F03CB1132925440AE7E6C921F8D4D409F03CB113292544025AFCE3120474D40E065868DB24E544025AFCE3120474D40
74787	25289	83.102194999999995	85.577196999999998	58.053598000000001	57.397998999999999	Зеленая	0103000020E6100000010000000500000024B4E55C8AC654409C6B98A1F1B24C4024B4E55C8AC65440C5909C4CDC064D405B96AFCBF0645540C5909C4CDC064D405B96AFCBF06455409C6B98A1F1B24C4024B4E55C8AC654409C6B98A1F1B24C40
12281	25534	83.472318999999999	83.513012000000003	57.631107999999998	57.609138000000002	Школьная	0103000020E61000000100000005000000E29178793ADE54401C60E63BF8CD4C40E29178793ADE54403A1F9E25C8D04C40289D4830D5E054403A1F9E25C8D04C40289D4830D5E054401C60E63BF8CD4C40E29178793ADE54401C60E63BF8CD4C40
74687	25534	83.472318999999999	83.513012000000003	57.631107999999998	57.609138000000002	Центральная	0103000020E61000000100000005000000E29178793ADE54401C60E63BF8CD4C40E29178793ADE54403A1F9E25C8D04C40289D4830D5E054403A1F9E25C8D04C40289D4830D5E054401C60E63BF8CD4C40E29178793ADE54401C60E63BF8CD4C40
74767	25534	83.472318999999999	83.513012000000003	57.631107999999998	57.609138000000002	Кнакиса	0103000020E61000000100000005000000E29178793ADE54401C60E63BF8CD4C40E29178793ADE54403A1F9E25C8D04C40289D4830D5E054403A1F9E25C8D04C40289D4830D5E054401C60E63BF8CD4C40E29178793ADE54401C60E63BF8CD4C40
74788	5854	83.900069000000002	83.933611999999997	57.799748999999998	57.781635000000001	Клубная	0103000020E610000001000000050000002EC901BB9AF9544059349D9D0CE44C402EC901BB9AF954401D01DC2C5EE64C40CDC98B4CC0FB54401D01DC2C5EE64C40CDC98B4CC0FB544059349D9D0CE44C402EC901BB9AF9544059349D9D0CE44C40
74468	26064	84.712254000000001	84.743803	57.875897999999999	57.861044	Комарова	0103000020E610000001000000050000007E1CCD91952D5540613596B036EE4C407E1CCD91952D5540DF50F86C1DF04C40ABEAE5779A2F5540DF50F86C1DF04C40ABEAE5779A2F5540613596B036EE4C407E1CCD91952D5540613596B036EE4C40
74741	48367	83.811746999999997	83.848676999999995	57.502107000000002	57.487369000000001	Центральная	0103000020E610000001000000050000001268B0A9F3F35440C80A7E1B62BE4C401268B0A9F3F35440DD0BCC0A45C04C4083F755B950F65440DD0BCC0A45C04C4083F755B950F65440C80A7E1B62BE4C401268B0A9F3F35440C80A7E1B62BE4C40
74739	5723	83.438676999999998	83.464342000000002	57.718493000000002	57.706940000000003	Школьная	0103000020E610000001000000050000007920B24813DC5440FC1D8A027DDA4C407920B24813DC5440D5B32094F7DB4C40310A82C7B7DD5440D5B32094F7DB4C40310A82C7B7DD5440FC1D8A027DDA4C407920B24813DC5440FC1D8A027DDA4C40
74427	52394	85.358502000000001	85.490302999999997	58.064487	57.994568999999998	Молодогвардейская	0103000020E610000001000000050000003D635FB2F1565540C64E78094EFF4C403D635FB2F156554032022A1C41084D405D88D51F615F554032022A1C41084D405D88D51F615F5540C64E78094EFF4C403D635FB2F1565540C64E78094EFF4C40
74489	25683	83.102194999999995	85.577196999999998	58.053598000000001	57.397998999999999	Свердлова	0103000020E6100000010000000500000024B4E55C8AC654409C6B98A1F1B24C4024B4E55C8AC65440C5909C4CDC064D405B96AFCBF0645540C5909C4CDC064D405B96AFCBF06455409C6B98A1F1B24C4024B4E55C8AC654409C6B98A1F1B24C40
74389	25683	83.102194999999995	85.577196999999998	58.053598000000001	57.397998999999999	Карла Маркса	0103000020E6100000010000000500000024B4E55C8AC654409C6B98A1F1B24C4024B4E55C8AC65440C5909C4CDC064D405B96AFCBF0645540C5909C4CDC064D405B96AFCBF06455409C6B98A1F1B24C4024B4E55C8AC654409C6B98A1F1B24C40
74432	24957	83.734474000000006	83.80386	57.609278000000003	57.568266999999999	Советская 	0103000020E61000000100000005000000CA703C9F01EF5440B1321AF9BCC84C40CA703C9F01EF54400E164ED2FCCD4C4001A4367172F354400E164ED2FCCD4C4001A4367172F35440B1321AF9BCC84C40CA703C9F01EF5440B1321AF9BCC84C40
74467	24957	83.734474000000006	83.80386	57.609278000000003	57.568266999999999	Комарова	0103000020E61000000100000005000000CA703C9F01EF5440B1321AF9BCC84C40CA703C9F01EF54400E164ED2FCCD4C4001A4367172F354400E164ED2FCCD4C4001A4367172F35440B1321AF9BCC84C40CA703C9F01EF5440B1321AF9BCC84C40
74472	24957	83.734474000000006	83.80386	57.609278000000003	57.568266999999999	Западная	0103000020E61000000100000005000000CA703C9F01EF5440B1321AF9BCC84C40CA703C9F01EF54400E164ED2FCCD4C4001A4367172F354400E164ED2FCCD4C4001A4367172F35440B1321AF9BCC84C40CA703C9F01EF5440B1321AF9BCC84C40
74448	24957	83.734474000000006	83.80386	57.609278000000003	57.568266999999999	Димтрова	0103000020E61000000100000005000000CA703C9F01EF5440B1321AF9BCC84C40CA703C9F01EF54400E164ED2FCCD4C4001A4367172F354400E164ED2FCCD4C4001A4367172F35440B1321AF9BCC84C40CA703C9F01EF5440B1321AF9BCC84C40
74465	24957	83.734474000000006	83.80386	57.609278000000003	57.568266999999999	Димитрова	0103000020E61000000100000005000000CA703C9F01EF5440B1321AF9BCC84C40CA703C9F01EF54400E164ED2FCCD4C4001A4367172F354400E164ED2FCCD4C4001A4367172F35440B1321AF9BCC84C40CA703C9F01EF5440B1321AF9BCC84C40
74469	24957	83.734474000000006	83.80386	57.609278000000003	57.568266999999999	Валикова	0103000020E61000000100000005000000CA703C9F01EF5440B1321AF9BCC84C40CA703C9F01EF54400E164ED2FCCD4C4001A4367172F354400E164ED2FCCD4C4001A4367172F35440B1321AF9BCC84C40CA703C9F01EF5440B1321AF9BCC84C40
74610	60311	83.541004000000001	83.608340999999996	57.723103000000002	57.704031000000001	Октябрьская улица	0103000020E6100000010000000500000055C03DCF9FE25440622F14B01DDA4C4055C03DCF9FE25440DB519CA38EDC4C4038F4160FEFE65440DB519CA38EDC4C4038F4160FEFE65440622F14B01DDA4C4055C03DCF9FE25440622F14B01DDA4C40
74523	60311	83.541004000000001	83.608340999999996	57.723103000000002	57.704031000000001	Октябрьская	0103000020E6100000010000000500000055C03DCF9FE25440622F14B01DDA4C4055C03DCF9FE25440DB519CA38EDC4C4038F4160FEFE65440DB519CA38EDC4C4038F4160FEFE65440622F14B01DDA4C4055C03DCF9FE25440622F14B01DDA4C40
74525	60311	83.541004000000001	83.608340999999996	57.723103000000002	57.704031000000001	Калинина	0103000020E6100000010000000500000055C03DCF9FE25440622F14B01DDA4C4055C03DCF9FE25440DB519CA38EDC4C4038F4160FEFE65440DB519CA38EDC4C4038F4160FEFE65440622F14B01DDA4C4055C03DCF9FE25440622F14B01DDA4C40
74547	60311	83.541004000000001	83.608340999999996	57.723103000000002	57.704031000000001	Вокзальный переулок	0103000020E6100000010000000500000055C03DCF9FE25440622F14B01DDA4C4055C03DCF9FE25440DB519CA38EDC4C4038F4160FEFE65440DB519CA38EDC4C4038F4160FEFE65440622F14B01DDA4C4055C03DCF9FE25440622F14B01DDA4C40
74770	48362	83.628373999999994	83.647463000000002	57.641750999999999	57.632928999999997	Школьная	0103000020E6100000010000000500000007EA944737E8544051D845D103D14C4007EA944737E85440709692E524D24C40AF97A60870E95440709692E524D24C40AF97A60870E9544051D845D103D14C4007EA944737E8544051D845D103D14C40
74782	48088	83.408582999999993	83.439493999999996	57.519627	57.506284999999998	Мира	0103000020E61000000100000005000000E6AC4F3926DA544049BA66F2CDC04C40E6AC4F3926DA54402E8F352383C24C40723271AB20DC54402E8F352383C24C40723271AB20DC544049BA66F2CDC04C40E6AC4F3926DA544049BA66F2CDC04C40
74721	5797	83.770370999999997	83.822687999999999	57.756804000000002	57.727020000000003	Центральная 	0103000020E610000001000000050000005BB22AC24DF15440DBC4C9FD0EDD4C405BB22AC24DF15440B2BD16F4DEE04C40F2B391EBA6F45440B2BD16F4DEE04C40F2B391EBA6F45440DBC4C9FD0EDD4C405BB22AC24DF15440DBC4C9FD0EDD4C40
74572	48388	83.595972000000003	83.613641999999999	57.542482	57.525016000000001	Луговая	0103000020E610000001000000050000003B55BE6724E6544039F06AB933C34C403B55BE6724E654409755D80C70C54C40EE5C18E945E754409755D80C70C54C40EE5C18E945E7544039F06AB933C34C403B55BE6724E6544039F06AB933C34C40
74789	25592	83.546689999999998	83.571995999999999	57.630279000000002	57.620837999999999	Центральная	0103000020E6100000010000000500000037C30DF8FCE25440990E9D9E77CF4C4037C30DF8FCE25440842D76FBACD04C40575C1C959BE45440842D76FBACD04C40575C1C959BE45440990E9D9E77CF4C4037C30DF8FCE25440990E9D9E77CF4C40
74639	24463	84.000878	84.021512999999999	57.142384	57.130803	Колхозная	0103000020E610000001000000050000004C5299620E005540FE9B1727BE904C404C5299620E005540A1BC8FA339924C4016DC0F7860015540A1BC8FA339924C4016DC0F7860015540FE9B1727BE904C404C5299620E005540FE9B1727BE904C40
74783	24089	83.672471999999999	83.697148999999996	57.239136000000002	57.225223	Центральная	0103000020E6100000010000000500000072DEFFC709EB54404CA7751BD49C4C4072DEFFC709EB5440ECA529029C9E4C401ADCD6169EEC5440ECA529029C9E4C401ADCD6169EEC54404CA7751BD49C4C4072DEFFC709EB54404CA7751BD49C4C40
74719	24507	83.908585000000002	83.949045999999996	57.195937000000001	57.186484999999998	Комсомольская	0103000020E61000000100000005000000B728B34126FA5440E71890BDDE974C40B728B34126FA5440C689AF7614994C4093196F2BBDFC5440C689AF7614994C4093196F2BBDFC5440E71890BDDE974C40B728B34126FA5440E71890BDDE974C40
74713	24319	83.886424000000005	83.913220999999993	57.124760000000002	57.116444000000001	Центральная	0103000020E61000000100000005000000EE98BA2BBBF8544060E811A3E78E4C40EE98BA2BBBF85440ABECBB22F88F4C404E417E3672FA5440ABECBB22F88F4C404E417E3672FA544060E811A3E78E4C40EE98BA2BBBF8544060E811A3E78E4C40
74748	24057	83.783899000000005	83.803509000000005	57.321401999999999	57.308588999999998	Школьная	0103000020E610000001000000050000007F17B6662BF25440E27327D87FA74C407F17B6662BF254403B6F63B323A94C40AB4203B16CF354403B6F63B323A94C40AB4203B16CF35440E27327D87FA74C407F17B6662BF25440E27327D87FA74C40
74557	5563	83.114394000000004	84.949597999999995	57.493000000000002	56.990296999999998	Светлая	0103000020E61000000100000005000000F436363B52C75440D829560DC27E4C40F436363B52C75440C976BE9F1ABF4C403596B036C63C5540C976BE9F1ABF4C403596B036C63C5540D829560DC27E4C40F436363B52C75440D829560DC27E4C40
74571	24663	84.354392000000004	84.372826000000003	57.203470000000003	57.184817000000002	перулок Центральный	0103000020E61000000100000005000000B37DC85BAE165540575F5D15A8974C40B37DC85BAE165540CBDB114E0B9A4C404E469561DC175540CBDB114E0B9A4C404E469561DC175540575F5D15A8974C40B37DC85BAE165540575F5D15A8974C40
74558	24171	83.472937999999999	83.499178000000001	57.373868999999999	57.356152000000002	Школьная	0103000020E6100000010000000500000048C2BE9D44DE5440D733846396AD4C4048C2BE9D44DE54407EFE7BF0DAAF4C407E384888F2DF54407EFE7BF0DAAF4C407E384888F2DF5440D733846396AD4C4048C2BE9D44DE5440D733846396AD4C40
74337	24171	83.472937999999999	83.499178000000001	57.373868999999999	57.356152000000002	Чулымская	0103000020E6100000010000000500000048C2BE9D44DE5440D733846396AD4C4048C2BE9D44DE54407EFE7BF0DAAF4C407E384888F2DF54407EFE7BF0DAAF4C407E384888F2DF5440D733846396AD4C4048C2BE9D44DE5440D733846396AD4C40
74636	24171	83.472937999999999	83.499178000000001	57.373868999999999	57.356152000000002	Рабочая	0103000020E6100000010000000500000048C2BE9D44DE5440D733846396AD4C4048C2BE9D44DE54407EFE7BF0DAAF4C407E384888F2DF54407EFE7BF0DAAF4C407E384888F2DF5440D733846396AD4C4048C2BE9D44DE5440D733846396AD4C40
74519	23689	83.897706999999997	83.947778999999997	57.360492000000001	57.323064000000002	проспект Ленина	0103000020E61000000100000005000000FA980F0874F95440EA4141295AA94C40FA980F0874F954401D3C139A24AE4C407A354069A8FC54401D3C139A24AE4C407A354069A8FC5440EA4141295AA94C40FA980F0874F95440EA4141295AA94C40
74502	23689	83.897706999999997	83.947778999999997	57.360492000000001	57.323064000000002	Октябрьская	0103000020E61000000100000005000000FA980F0874F95440EA4141295AA94C40FA980F0874F954401D3C139A24AE4C407A354069A8FC54401D3C139A24AE4C407A354069A8FC5440EA4141295AA94C40FA980F0874F95440EA4141295AA94C40
74463	23689	83.897706999999997	83.947778999999997	57.360492000000001	57.323064000000002	Ленина	0103000020E61000000100000005000000FA980F0874F95440EA4141295AA94C40FA980F0874F954401D3C139A24AE4C407A354069A8FC54401D3C139A24AE4C407A354069A8FC5440EA4141295AA94C40FA980F0874F95440EA4141295AA94C40
74779	23689	83.897706999999997	83.947778999999997	57.360492000000001	57.323064000000002	Коммунистическая	0103000020E61000000100000005000000FA980F0874F95440EA4141295AA94C40FA980F0874F954401D3C139A24AE4C407A354069A8FC54401D3C139A24AE4C407A354069A8FC5440EA4141295AA94C40FA980F0874F95440EA4141295AA94C40
74527	23689	83.897706999999997	83.947778999999997	57.360492000000001	57.323064000000002	Зеленая	0103000020E61000000100000005000000FA980F0874F95440EA4141295AA94C40FA980F0874F954401D3C139A24AE4C407A354069A8FC54401D3C139A24AE4C407A354069A8FC5440EA4141295AA94C40FA980F0874F95440EA4141295AA94C40
74513	23689	83.897706999999997	83.947778999999997	57.360492000000001	57.323064000000002	Заводская	0103000020E61000000100000005000000FA980F0874F95440EA4141295AA94C40FA980F0874F954401D3C139A24AE4C407A354069A8FC54401D3C139A24AE4C407A354069A8FC5440EA4141295AA94C40FA980F0874F95440EA4141295AA94C40
74505	24784	84.482223000000005	84.550863000000007	57.167008000000003	57.112352999999999	Школьная	0103000020E610000001000000050000004298DBBDDC1E5540C24D4695618E4C404298DBBDDC1E5540CF15A58460954C40E564E25641235540CF15A58460954C40E564E25641235540C24D4695618E4C404298DBBDDC1E5540C24D4695618E4C40
74443	24784	84.482223000000005	84.550863000000007	57.167008000000003	57.112352999999999	Советская	0103000020E610000001000000050000004298DBBDDC1E5540C24D4695618E4C404298DBBDDC1E5540CF15A58460954C40E564E25641235540CF15A58460954C40E564E25641235540C24D4695618E4C404298DBBDDC1E5540C24D4695618E4C40
74435	24784	84.482223000000005	84.550863000000007	57.167008000000003	57.112352999999999	Осиновский	0103000020E610000001000000050000004298DBBDDC1E5540C24D4695618E4C404298DBBDDC1E5540CF15A58460954C40E564E25641235540CF15A58460954C40E564E25641235540C24D4695618E4C404298DBBDDC1E5540C24D4695618E4C40
74575	24698	84.391565	84.401499999999999	57.074362999999998	57.058174999999999	Центральная	0103000020E610000001000000050000008750A5660F195540EF38454772874C408750A5660F19554027840EBA84894C4004560E2DB219554027840EBA84894C4004560E2DB2195540EF38454772874C408750A5660F195540EF38454772874C40
74786	24400	84.116590000000002	84.134844000000001	57.169297	57.149298000000002	Школьная	0103000020E610000001000000050000009A42E73576075540DAAD65321C934C409A42E73576075540CC272B86AB954C40F583BA48A1085540CC272B86AB954C40F583BA48A1085540DAAD65321C934C409A42E73576075540DAAD65321C934C40
74710	5530	83.931295000000006	83.948192000000006	57.409951	57.392242000000003	Центральная 	0103000020E610000001000000050000006AFB57569AFB54400F0F61FC34B24C406AFB57569AFB544033FB3C4679B44C400C957F2DAFFC544033FB3C4679B44C400C957F2DAFFC54400F0F61FC34B24C406AFB57569AFB54400F0F61FC34B24C40
74568	24558	83.951525000000004	83.971962000000005	57.305720999999998	57.287699000000003	Советская	0103000020E61000000100000005000000E4141DC9E5FC5440C40B2252D3A44C40E4141DC9E5FC5440A759A0DD21A74C401BBD1AA034FE5440A759A0DD21A74C401BBD1AA034FE5440C40B2252D3A44C40E4141DC9E5FC5440C40B2252D3A44C40
74712	24606	84.043530000000004	84.060948999999994	57.187455999999997	57.180889999999998	Центральная	0103000020E6100000010000000500000046990D32C902554033164D6727974C4046990D32C902554030B8E68EFE974C40546EA296E603554030B8E68EFE974C40546EA296E603554033164D6727974C4046990D32C902554033164D6727974C40
74490	24180	83.883289000000005	83.913777999999994	57.107460000000003	57.085824000000002	Советская	0103000020E61000000100000005000000A9FA95CE87F85440209BE447FC8A4C40A9FA95CE87F8544068D0D03FC18D4C407973B8567BFA544068D0D03FC18D4C407973B8567BFA5440209BE447FC8A4C40A9FA95CE87F85440209BE447FC8A4C40
74570	24180	83.883289000000005	83.913777999999994	57.107460000000003	57.085824000000002	Коммунистическая	0103000020E61000000100000005000000A9FA95CE87F85440209BE447FC8A4C40A9FA95CE87F8544068D0D03FC18D4C407973B8567BFA544068D0D03FC18D4C407973B8567BFA5440209BE447FC8A4C40A9FA95CE87F85440209BE447FC8A4C40
74728	24947	83.618465	83.645010999999997	57.085867999999998	57.079172	Центральная	0103000020E610000001000000050000001F2E39EE94E754402461DF4E228A4C401F2E39EE94E75440EFE2FDB8FD8A4C40DBA337DC47E95440EFE2FDB8FD8A4C40DBA337DC47E954402461DF4E228A4C401F2E39EE94E754402461DF4E228A4C40
74780	24348	83.648495999999994	83.666704999999993	57.179845999999998	57.168975000000003	Школьная	0103000020E610000001000000050000008EE55DF580E95440BA6B09F9A0954C408EE55DF580E954408028983105974C4019C5724BABEA54408028983105974C4019C5724BABEA5440BA6B09F9A0954C408EE55DF580E95440BA6B09F9A0954C40
74669	52297	83.288073999999995	84.342731999999998	58.719158999999998	58.166196999999997	Совхозная	0103000020E61000000100000005000000FC34EECD6FD25440BED87BF145154D40FC34EECD6FD25440E1CFF0660D5C4D40BBD23252EF155540E1CFF0660D5C4D40BBD23252EF155540BED87BF145154D40FC34EECD6FD25440BED87BF145154D40
74632	52289	82.557114999999996	83.611772999999999	58.557797000000001	58.002271999999998	Центральная	0103000020E610000001000000050000001B47ACC5A7A3544027D9EA724A004D401B47ACC5A7A35440496760E465474D40DAE4F04927E75440496760E465474D40DAE4F04927E7544027D9EA724A004D401B47ACC5A7A3544027D9EA724A004D40
66609	52271	82.299145999999993	83.353803999999997	58.336950999999999	57.777925000000003	Фестивальная	0103000020E61000000100000005000000ABAE433525935440D3DEE00B93E34C40ABAE43352593544060ADDA35212B4D406A4C88B9A4D6544060ADDA35212B4D406A4C88B9A4D65440D3DEE00B93E34C40ABAE433525935440D3DEE00B93E34C40
74424	52271	82.299145999999993	83.353803999999997	58.336950999999999	57.777925000000003	Магистральная	0103000020E61000000100000005000000ABAE433525935440D3DEE00B93E34C40ABAE43352593544060ADDA35212B4D406A4C88B9A4D6544060ADDA35212B4D406A4C88B9A4D65440D3DEE00B93E34C40ABAE433525935440D3DEE00B93E34C40
74690	52282	82.110732999999996	83.165391	58.545738999999998	57.990023000000001	Кооперативная	0103000020E61000000100000005000000A165DD3F16875440D7A4DB12B9FE4C40A165DD3F168754406C938AC6DA454D40600322C495CA54406C938AC6DA454D40600322C495CA5440D7A4DB12B9FE4C40A165DD3F16875440D7A4DB12B9FE4C40
65989	52253	82.319564	83.374223000000001	58.635292999999997	58.080998000000001	Советская	0103000020E61000000100000005000000A73E90BC739454404D8578245E0A4D40A73E90BC739454405930F14751514D404E9A0645F3D754405930F14751514D404E9A0645F3D754404D8578245E0A4D40A73E90BC739454404D8578245E0A4D40
74346	52253	82.319564	83.374223000000001	58.635292999999997	58.080998000000001	Свердлова	0103000020E61000000100000005000000A73E90BC739454404D8578245E0A4D40A73E90BC739454405930F14751514D404E9A0645F3D754405930F14751514D404E9A0645F3D754404D8578245E0A4D40A73E90BC739454404D8578245E0A4D40
74462	52253	82.319564	83.374223000000001	58.635292999999997	58.080998000000001	Мичурина	0103000020E61000000100000005000000A73E90BC739454404D8578245E0A4D40A73E90BC739454405930F14751514D404E9A0645F3D754405930F14751514D404E9A0645F3D754404D8578245E0A4D40A73E90BC739454404D8578245E0A4D40
65505	52253	82.319564	83.374223000000001	58.635292999999997	58.080998000000001	Лермонтова	0103000020E61000000100000005000000A73E90BC739454404D8578245E0A4D40A73E90BC739454405930F14751514D404E9A0645F3D754405930F14751514D404E9A0645F3D754404D8578245E0A4D40A73E90BC739454404D8578245E0A4D40
74830	52253	82.319564	83.374223000000001	58.635292999999997	58.080998000000001	Источная улица	0103000020E61000000100000005000000A73E90BC739454404D8578245E0A4D40A73E90BC739454405930F14751514D404E9A0645F3D754405930F14751514D404E9A0645F3D754404D8578245E0A4D40A73E90BC739454404D8578245E0A4D40
74616	52286	82.666027	83.720685000000003	58.360069000000003	57.801409	Братская	0103000020E6100000010000000500000031D0B52FA0AA54402BDCF29194E64C4031D0B52FA0AA5440D7A6B1BD162E4D40F06DFAB31FEE5440D7A6B1BD162E4D40F06DFAB31FEE54402BDCF29194E64C4031D0B52FA0AA54402BDCF29194E64C40
74622	52276	82.906621999999999	83.038422999999995	58.068072000000001	57.998161000000003	Центральная	0103000020E6100000010000000500000062F5471806BA5440439259BDC3FF4C4062F5471806BA5440FCE25295B6084D40821ABE8575C25440FCE25295B6084D40821ABE8575C25440439259BDC3FF4C4062F5471806BA5440439259BDC3FF4C40
74496	60306	82.384459000000007	83.439116999999996	58.505113000000001	57.948751999999999	Трактовая	0103000020E61000000100000005000000C9E9EBF99A985440DE019EB470F94C40C9E9EBF99A98544069E4F38AA7404D408787307E1ADC544069E4F38AA7404D408787307E1ADC5440DE019EB470F94C40C9E9EBF99A985440DE019EB470F94C40
74460	52108	82.467786000000004	83.522445000000005	58.673470999999999	58.119782999999998	Центральная	0103000020E61000000100000005000000B5E1B034F09D5440F2CEA10C550F4D40B5E1B034F09D5440F7E6374C34564D405C3D27BD6FE15440F7E6374C34564D405C3D27BD6FE15440F2CEA10C550F4D40B5E1B034F09D5440F2CEA10C550F4D40
74769	60336	82.500692000000001	83.555350000000004	58.504458999999997	57.948087999999998	пер.Школьный	0103000020E610000001000000050000009B5775560BA0544072DD94F25AF94C409B5775560BA054402096CD1C92404D405AF5B9DA8AE354402096CD1C92404D405AF5B9DA8AE3544072DD94F25AF94C409B5775560BA0544072DD94F25AF94C40
74781	52281	82.112063000000006	83.166720999999995	58.525503	57.969465	Береговая	0103000020E61000000100000005000000DE054A0A2C875440EECEDA6D17FC4C40DE054A0A2C8754409679ABAE43434D409CA38E8EABCA54409679ABAE43434D409CA38E8EABCA5440EECEDA6D17FC4C40DE054A0A2C875440EECEDA6D17FC4C40
74785	52272	82.293431999999996	83.348090999999997	58.398817000000001	57.840770999999997	Зеленая	0103000020E6100000010000000500000064E60297C79254406D3656629EEB4C4064E60297C79254405F0B7A6F0C334D400B42791F47D654405F0B7A6F0C334D400B42791F47D654406D3656629EEB4C4064E60297C79254406D3656629EEB4C40
74831	60349	82.560986999999997	83.615645000000001	58.666269	58.112467000000002	Юбилейная	0103000020E61000000100000005000000CB9E0436E7A354408B709351650E4D40CB9E0436E7A3544058AB764D48554D408A3C49BA66E7544058AB764D48554D408A3C49BA66E754408B709351650E4D40CB9E0436E7A354408B709351650E4D40
74763	52302	82.034610000000001	83.089268000000004	59.175848000000002	58.630164000000001	Лесная	0103000020E610000001000000050000005587DC0C37825440EB8EC536A9504D405587DC0C378254409488F02F82964D4014252191B6C554409488F02F82964D4014252191B6C55440EB8EC536A9504D405587DC0C37825440EB8EC536A9504D40
74821	60344	81.739783000000003	82.794441000000006	58.945442	58.396082	Школьная	0103000020E61000000100000005000000C1C8CB9A586F54406344A2D0B2324D40C1C8CB9A586F5440E621533E04794D408066101FD8B25440E621533E04794D408066101FD8B254406344A2D0B2324D40C1C8CB9A586F54406344A2D0B2324D40
65394	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	переулок Чапаева	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
65979	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	переулок Озерный	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74476	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	переулок Лазо	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
66422	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Толстого	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74449	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Портовая	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
66600	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Победы	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74428	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Науки	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74451	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Комсомольская	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74454	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Коммунистическая	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
65400	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Кирова	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74452	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Дорожная	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
66603	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Горького	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
65984	52207	82.388609000000002	83.443267000000006	58.593443000000001	58.038483999999997	Гоголя	0103000020E610000001000000050000009A7B48F8DE985440AAB5300BED044D409A7B48F8DE9854402385B2F0F54B4D4059198D7C5EDC54402385B2F0F54B4D4059198D7C5EDC5440AAB5300BED044D409A7B48F8DE985440AAB5300BED044D40
74506	52305	81.607290000000006	82.661947999999995	58.754458999999997	58.202058000000001	Кооперативный	0103000020E61000000100000005000000064CE0D6DD66544095F25A09DD194D40064CE0D6DD6654402096CD1C92604D40C4E9245B5DAA54402096CD1C92604D40C4E9245B5DAA544095F25A09DD194D40064CE0D6DD66544095F25A09DD194D40
74677	52306	81.903149999999997	82.957808999999997	58.716738999999997	58.163738000000002	Школьная	0103000020E610000001000000050000007958A835CD795440658EE55DF5144D407958A835CD7954404562821ABE5B4D4020B41EBE4CBD54404562821ABE5B4D4020B41EBE4CBD5440658EE55DF5144D407958A835CD795440658EE55DF5144D40
74673	52300	82.409296999999995	83.463954999999999	58.989224	58.440561000000002	Школьная	0103000020E6100000010000000500000075560BEC319A54405072874D64384D4075560BEC319A54408B355CE49E7E4D4034F44F70B1DD54408B355CE49E7E4D4034F44F70B1DD54405072874D64384D4075560BEC319A54405072874D64384D40
74776	52103	82.367005000000006	83.421662999999995	58.668548999999999	58.114781999999998	Волкова	0103000020E61000000100000005000000FC1D8A027D975440B115342DB10E4D40FC1D8A027D97544002637D0393554D40BABBCE86FCDA544002637D0393554D40BABBCE86FCDA5440B115342DB10E4D40FC1D8A027D975440B115342DB10E4D40
74407	52284	82.734029000000007	83.788686999999996	58.382237000000003	57.823928000000002	Советская	0103000020E610000001000000050000003354C554FAAE54401D21037976E94C403354C554FAAE54401C295B24ED304D40F1F109D979F254401C295B24ED304D40F1F109D979F254401D21037976E94C403354C554FAAE54401D21037976E94C40
74554	52299	82.823303999999993	83.877961999999997	58.696460999999999	58.143138	Мира	0103000020E610000001000000050000009FAA4203B1B454404D68925852124D409FAA4203B1B4544040F850A225594D405E48878730F8544040F850A225594D405E48878730F854404D68925852124D409FAA4203B1B454404D68925852124D40
74480	23441	83.507874000000001	83.541659999999993	55.845683000000001	55.825673999999999	Советская	0103000020E61000000100000005000000471FF30181E05440299485AFAFE94B40471FF30181E054403FE42D573FEC4B404963B48EAAE254403FE42D573FEC4B404963B48EAAE25440299485AFAFE94B40471FF30181E05440299485AFAFE94B40
74774	47190	83.311025999999998	83.346661999999995	56.291539	56.279857	Советская	0103000020E610000001000000050000002A8D98D9E7D354404147AB5AD2234C402A8D98D9E7D354401841632651254C400531D0B52FD654401841632651254C400531D0B52FD654404147AB5AD2234C402A8D98D9E7D354404147AB5AD2234C40
66388	23153	83.915440000000004	83.950419999999994	56.142620999999998	56.123061999999997	Фрунзе	0103000020E61000000100000005000000D15CA79196FA5440AFB0E07EC00F4C40D15CA79196FA5440855CA96741124C40B75D68AED3FC5440855CA96741124C40B75D68AED3FC5440AFB0E07EC00F4C40D15CA79196FA5440AFB0E07EC00F4C40
74775	22584	83.428499000000002	83.446455999999998	56.390081000000002	56.374251999999998	Зеленая	0103000020E6100000010000000500000099D711876CDB5440363B527DE72F4C4099D711876CDB54403FE5982CEE314C4097C62FBC92DC54403FE5982CEE314C4097C62FBC92DC5440363B527DE72F4C4099D711876CDB5440363B527DE72F4C40
74548	20607	83.752638000000005	83.771879999999996	56.190410999999997	56.177591	Школьная	0103000020E6100000010000000500000085EE92382BF054402F88484DBB164C4085EE92382BF054403AE63C635F184C40EF1B5F7B66F154403AE63C635F184C40EF1B5F7B66F154402F88484DBB164C4085EE92382BF054402F88484DBB164C40
74477	22400	83.430618999999993	83.456040999999999	56.328828000000001	56.295369999999998	Ульяновская	0103000020E610000001000000050000005182FE428FDB5440191C25AFCE254C405182FE428FDB54402A013109172A4C40A62897C62FDD54402A013109172A4C40A62897C62FDD5440191C25AFCE254C405182FE428FDB5440191C25AFCE254C40
74649	23082	83.904148000000006	83.923911000000004	56.364944000000001	56.351719000000003	Школьная	0103000020E610000001000000050000009BAF928FDDF95440E030D120052D4C409BAF928FDDF954408B6F287CB62E4C408A5A9A5B21FB54408B6F287CB62E4C408A5A9A5B21FB5440E030D120052D4C409BAF928FDDF95440E030D120052D4C40
74405	22627	83.445998000000003	83.473467999999997	56.417033000000004	56.398480999999997	Молодежная	0103000020E610000001000000050000003605323B8BDC5440E789E76C01334C403605323B8BDC5440282D5C5661354C40F6ECB94C4DDE5440282D5C5661354C40F6ECB94C4DDE5440E789E76C01334C403605323B8BDC5440E789E76C01334C40
74702	47569	83.478256000000002	83.510811000000004	55.963903999999999	55.949646999999999	Мира	0103000020E6100000010000000500000069C70DBF9BDE54404CDF6B088EF94B4069C70DBF9BDE5440E63DCE3461FB4B40F9DB9E20B1E05440E63DCE3461FB4B40F9DB9E20B1E054404CDF6B088EF94B4069C70DBF9BDE54404CDF6B088EF94B40
74773	47645	83.706841999999995	83.727700999999996	56.146577999999998	56.134444999999999	Молодёжная	0103000020E610000001000000050000001C5C3AE63CED54402C0E677E35114C401C5C3AE63CED544013286211C3124C400E1137A792EE544013286211C3124C400E1137A792EE54402C0E677E35114C401C5C3AE63CED54402C0E677E35114C40
74736	47426	83.849053999999995	83.877359999999996	56.330379999999998	56.314467	Садовая	0103000020E610000001000000050000006EA296E656F65440EB55647440284C406EA296E656F6544051A04FE4492A4C4063B48EAA26F8544051A04FE4492A4C4063B48EAA26F85440EB55647440284C406EA296E656F65440EB55647440284C40
74563	22719	83.466453000000001	83.492790999999997	56.453283999999996	56.443866999999997	Центральная	0103000020E61000000100000005000000C007AF5DDADD5440066344A2D0384C40C007AF5DDADD544068E6C935053A4C40D73043E389DF544068E6C935053A4C40D73043E389DF5440066344A2D0384C40C007AF5DDADD5440066344A2D0384C40
74778	22672	83.416927999999999	83.441461000000004	56.444653000000002	56.431812999999998	Комсомольская	0103000020E610000001000000050000005932C7F2AEDA54406B7EFCA545374C405932C7F2AEDA5440BE88B663EA384C40685DA3E540DC5440BE88B663EA384C40685DA3E540DC54406B7EFCA545374C405932C7F2AEDA54406B7EFCA545374C40
66417	5233	83.947086999999996	83.990036000000003	56.278243000000003	56.238106999999999	Ленина	0103000020E61000000100000005000000DFDDCA129DFC54406EF9484A7A1E4C40DFDDCA129DFC5440A4AB74779D234C403677F4BF5CFF5440A4AB74779D234C403677F4BF5CFF54406EF9484A7A1E4C40DFDDCA129DFC54406EF9484A7A1E4C40
65244	5233	83.947086999999996	83.990036000000003	56.278243000000003	56.238106999999999	Кирова	0103000020E61000000100000005000000DFDDCA129DFC54406EF9484A7A1E4C40DFDDCA129DFC5440A4AB74779D234C403677F4BF5CFF5440A4AB74779D234C403677F4BF5CFF54406EF9484A7A1E4C40DFDDCA129DFC54406EF9484A7A1E4C40
65429	5233	83.947086999999996	83.990036000000003	56.278243000000003	56.238106999999999	Гагарина	0103000020E61000000100000005000000DFDDCA129DFC54406EF9484A7A1E4C40DFDDCA129DFC5440A4AB74779D234C403677F4BF5CFF5440A4AB74779D234C403677F4BF5CFF54406EF9484A7A1E4C40DFDDCA129DFC54406EF9484A7A1E4C40
74824	22919	84.080235000000002	84.106196999999995	56.381529999999998	56.350732000000001	Карла Маркса	0103000020E61000000100000005000000A73FFB912205554091D442C9E42C4C40A73FFB9122055540B0389CF9D5304C40BB7B80EECB065540B0389CF9D5304C40BB7B80EECB06554091D442C9E42C4C40A73FFB912205554091D442C9E42C4C40
74746	52483	83.655520999999993	83.682784999999996	56.290998999999999	56.280307000000001	Школьная	0103000020E61000000100000005000000D6355A0EF4E9544081EB8A19E1234C40D6355A0EF4E9544098158A743F254C40C24CDBBFB2EB544098158A743F254C40C24CDBBFB2EB544081EB8A19E1234C40D6355A0EF4E9544081EB8A19E1234C40
74701	23390	83.591776999999993	83.608889000000005	55.878945000000002	55.868358999999998	Школьная	0103000020E610000001000000050000009961A3ACDFE55440F817416326EF4B409961A3ACDFE55440CAFD0E4581F04B403A799109F8E65440CAFD0E4581F04B403A799109F8E65440F817416326EF4B409961A3ACDFE55440F817416326EF4B40
74707	47541	83.719239000000002	83.742369999999994	55.951154000000002	55.939740999999998	Новая	0103000020E610000001000000050000007FC0030308EE5440ECDADE6E49F84B407FC0030308EE5440D4BA0D6ABFF94B4004E275FD82EF5440D4BA0D6ABFF94B4004E275FD82EF5440ECDADE6E49F84B407FC0030308EE5440ECDADE6E49F84B40
74698	22428	83.325757999999993	83.349554999999995	56.257323	56.244160000000001	Школьная	0103000020E61000000100000005000000431A1538D9D45440E57E87A2401F4C40431A1538D9D454401AC1C6F5EF204C40CF49EF1B5FD654401AC1C6F5EF204C40CF49EF1B5FD65440E57E87A2401F4C40431A1538D9D45440E57E87A2401F4C40
74560	23115	83.874656000000002	83.906259000000006	56.426687000000001	56.417217000000001	Школьная	0103000020E6100000010000000500000003D0285DFAF75440E92ADD5D67354C4003D0285DFAF754406E50FBAD9D364C402AADBF2500FA54406E50FBAD9D364C402AADBF2500FA5440E92ADD5D67354C4003D0285DFAF75440E92ADD5D67354C40
74637	52480	83.533682999999996	83.574718000000004	56.145881000000003	56.128495999999998	Гагарина	0103000020E6100000010000000500000098DBBDDC27E254405AD5928E72104C4098DBBDDC27E25440CC0D863AAC124C400B9B012EC8E45440CC0D863AAC124C400B9B012EC8E454405AD5928E72104C4098DBBDDC27E254405AD5928E72104C40
74635	23518	83.348414000000005	83.380053000000004	55.754410999999998	55.738444000000001	Советская	0103000020E61000000100000005000000FDDD3B6A4CD65440B6F63E5585DE4B40FDDD3B6A4CD654400F5F268A90E04B40CA6FD1C952D854400F5F268A90E04B40CA6FD1C952D85440B6F63E5585DE4B40FDDD3B6A4CD65440B6F63E5585DE4B40
74621	47421	83.860749999999996	83.877791000000002	56.294010999999998	56.280226999999996	Октябрьская	0103000020E610000001000000050000000C022B8716F75440643A747ADE234C400C022B8716F7544006D50627A2254C40486E4DBA2DF8544006D50627A2254C40486E4DBA2DF85440643A747ADE234C400C022B8716F75440643A747ADE234C40
74691	35509	83.072595000000007	84.267291999999998	56.496999000000002	55.670996000000002	Садовая	0103000020E610000001000000050000009AB67F65A5C4544098DF6932E3D54B409AB67F65A5C454408692C9A99D3F4C40E09EE74F1B1155408692C9A99D3F4C40E09EE74F1B11554098DF6932E3D54B409AB67F65A5C4544098DF6932E3D54B40
74848	60360	80.151373000000007	81.206030999999996	59.252211000000003	58.707746999999998	Береговая	0103000020E61000000100000005000000D61F6118B0095440CA6B2574975A4D40D61F6118B00954408258367348A04D4094BDA59C2F4D54408258367348A04D4094BDA59C2F4D5440CA6B2574975A4D40D61F6118B0095440CA6B2574975A4D40
74611	52422	79.491578000000004	80.546235999999993	59.698168000000003	59.160848999999999	Береговая	0103000020E61000000100000005000000B85B920376DF5340124C35B396944D40B85B920376DF53408F8EAB915DD94D4076F9D687F52254408F8EAB915DD94D4076F9D687F5225440124C35B396944D40B85B920376DF5340124C35B396944D40
74732	52126	79.775831999999994	80.830489999999998	59.643568000000002	59.105372000000003	Кедровая	0103000020E610000001000000050000002DCC423BA7F1534002F566D47C8D4D402DCC423BA7F153404660AC6F60D24D40EC6987BF263554404660AC6F60D24D40EC6987BF2635544002F566D47C8D4D402DCC423BA7F1534002F566D47C8D4D40
74704	60329	79.952369000000004	81.007026999999994	59.270963000000002	58.726799	Лесная	0103000020E610000001000000050000005A2E1B9DF3FC5340FCE1E7BF075D4D405A2E1B9DF3FC534089B663EAAEA24D4018CC5F217340544089B663EAAEA24D4018CC5F2173405440FCE1E7BF075D4D405A2E1B9DF3FC5340FCE1E7BF075D4D40
74714	52122	79.021812999999995	80.076470999999998	59.252656999999999	58.708199999999998	Центральная	0103000020E610000001000000050000002B685A6265C153407B832F4CA65A4D402B685A6265C15340800D881057A04D40EA059FE6E4045440800D881057A04D40EA059FE6E40454407B832F4CA65A4D402B685A6265C153407B832F4CA65A4D40
66438	52419	77.712896000000001	78.767554000000004	59.487222000000003	58.946519000000002	Студенческая	0103000020E61000000100000005000000C05C8B16A06D53407505DB8827794D40C05C8B16A06D534024F25D4A5DBE4D407FFACF9A1FB1534024F25D4A5DBE4D407FFACF9A1FB153407505DB8827794D40C05C8B16A06D53407505DB8827794D40
74623	52460	80.777075999999994	81.831733999999997	59.388947000000002	58.846670000000003	Школьная	0103000020E610000001000000050000006AA0F99CBB3154408E40BCAE5F6C4D406AA0F99CBB3154404C70EA03C9B14D40293E3E213B7554404C70EA03C9B14D40293E3E213B7554408E40BCAE5F6C4D406AA0F99CBB3154408E40BCAE5F6C4D40
74868	60365	80.281467000000006	81.336124999999996	59.328769000000001	58.785528999999997	Тополевая	0103000020E61000000100000005000000CFF9298E03125440A087DA368C644D40CFF9298E031254402578431A15AA4D408D976E12835554402578431A15AA4D408D976E1283555440A087DA368C644D40CFF9298E03125440A087DA368C644D40
74522	60310	80.391304000000005	81.445961999999994	59.270314999999997	58.726140000000001	Школьная	0103000020E61000000100000005000000D1B2EE1F0B195440A228D027F25C4D40D1B2EE1F0B195440224F92AE99A24D408F5033A48A5C5440224F92AE99A24D408F5033A48A5C5440A228D027F25C4D40D1B2EE1F0B195440A228D027F25C4D40
74604	52417	77.006136999999995	78.060794999999999	59.412849000000001	58.870955000000002	Центральная	0103000020E61000000100000005000000EA92718C64405340D3A414747B6F4D40EA92718C64405340D9976C3CD8B44D40A930B610E4835340D9976C3CD8B44D40A930B610E4835340D3A414747B6F4D40EA92718C64405340D3A414747B6F4D40
65590	52421	75.970515000000006	77.025172999999995	58.852117	58.301270000000002	Советская	0103000020E61000000100000005000000C251F2EA1CFE52400AA2EE0390264D40C251F2EA1CFE5240CDAE7B2B126D4D4080EF366F9C415340CDAE7B2B126D4D4080EF366F9C4153400AA2EE0390264D40C251F2EA1CFE52400AA2EE0390264D40
74555	52474	80.054542999999995	81.109200999999999	59.264194000000003	58.719920999999999	Центральная	0103000020E61000000100000005000000724EECA17D035440105A0F5F265C4D40724EECA17D03544054E6E61BD1A14D4031EC3026FD46544054E6E61BD1A14D4031EC3026FD465440105A0F5F265C4D40724EECA17D035440105A0F5F265C4D40
74613	52433	81.482361999999995	82.537019999999998	60.157243999999999	59.627315000000003	Кооперативная	0103000020E6100000010000000500000052B5DD04DF5E544027A5A0DB4BD04D4052B5DD04DF5E544001BF469220144E40115322895EA2544001BF469220144E40115322895EA2544027A5A0DB4BD04D4052B5DD04DF5E544027A5A0DB4BD04D40
74727	52438	77.954417000000007	79.009074999999996	59.263283000000001	58.718995999999997	Береговая	0103000020E61000000100000005000000C66F0A2B157D534037FA980F085C4D40C66F0A2B157D5340E04BE141B3A14D40840D4FAF94C05340E04BE141B3A14D40840D4FAF94C0534037FA980F085C4D40C66F0A2B157D534037FA980F085C4D40
74576	60317	81.196077000000002	82.250736000000003	60.188935000000001	59.659517000000001	Гагарина	0103000020E61000000100000005000000DC9F8B868C4C5440F913950D6BD44D40DC9F8B868C4C5440EE08A7052F184E4083FB010F0C905440EE08A7052F184E4083FB010F0C905440F913950D6BD44D40DC9F8B868C4C5440F913950D6BD44D40
74676	52466	80.066203000000002	81.120862000000002	59.422006000000003	58.880257999999998	Школьная	0103000020E610000001000000050000006AF981AB3C0454406C054D4BAC704D406AF981AB3C0454409F5BE84A04B64D401155F833BC4754409F5BE84A04B64D401155F833BC4754406C054D4BAC704D406AF981AB3C0454406C054D4BAC704D40
74577	60318	79.869642999999996	80.924301	60.035283	59.503388000000001	Лесная	0103000020E61000000100000005000000800C1D3BA8F7534074999A046FC04D40800C1D3BA8F75340698D412784044E403FAA61BF273B5440698D412784044E403FAA61BF273B544074999A046FC04D40800C1D3BA8F7534074999A046FC04D40
74520	60294	80.335014999999999	81.389673000000002	59.321378000000003	58.778019999999998	Энтузиастов	0103000020E61000000100000005000000D82AC1E27015544024D1CB2896634D40D82AC1E270155440B3D30FEA22A94D4097C80567F0585440B3D30FEA22A94D4097C80567F058544024D1CB2896634D40D82AC1E27015544024D1CB2896634D40
74531	60294	80.335014999999999	81.389673000000002	59.321378000000003	58.778019999999998	Советская	0103000020E61000000100000005000000D82AC1E27015544024D1CB2896634D40D82AC1E270155440B3D30FEA22A94D4097C80567F0585440B3D30FEA22A94D4097C80567F058544024D1CB2896634D40D82AC1E27015544024D1CB2896634D40
74347	60294	80.335014999999999	81.389673000000002	59.321378000000003	58.778019999999998	Октябрьская	0103000020E61000000100000005000000D82AC1E27015544024D1CB2896634D40D82AC1E270155440B3D30FEA22A94D4097C80567F0585440B3D30FEA22A94D4097C80567F058544024D1CB2896634D40D82AC1E27015544024D1CB2896634D40
74352	60294	80.335014999999999	81.389673000000002	59.321378000000003	58.778019999999998	М. Горького	0103000020E61000000100000005000000D82AC1E27015544024D1CB2896634D40D82AC1E270155440B3D30FEA22A94D4097C80567F0585440B3D30FEA22A94D4097C80567F058544024D1CB2896634D40D82AC1E27015544024D1CB2896634D40
74364	60294	80.335014999999999	81.389673000000002	59.321378000000003	58.778019999999998	Лугинецкая	0103000020E61000000100000005000000D82AC1E27015544024D1CB2896634D40D82AC1E270155440B3D30FEA22A94D4097C80567F0585440B3D30FEA22A94D4097C80567F058544024D1CB2896634D40D82AC1E27015544024D1CB2896634D40
74540	60294	80.335014999999999	81.389673000000002	59.321378000000003	58.778019999999998	Кирова	0103000020E61000000100000005000000D82AC1E27015544024D1CB2896634D40D82AC1E270155440B3D30FEA22A94D4097C80567F0585440B3D30FEA22A94D4097C80567F058544024D1CB2896634D40D82AC1E27015544024D1CB2896634D40
74625	52462	80.750485999999995	81.805143999999999	59.438732999999999	58.897253999999997	Заводская	0103000020E61000000100000005000000C6866EF607305440431A1538D9724D40C6866EF6073054408656276728B84D408524B37A877354408656276728B84D408524B37A87735440431A1538D9724D40C6866EF607305440431A1538D9724D40
74684	52427	79.139313000000001	80.193971000000005	59.653871000000002	59.115841000000003	Молодежная	0103000020E6100000010000000500000017BA1281EAC853409A44BDE0D38E4D4017BA1281EAC85340C366800BB2D34D40D65757056A0C5440C366800BB2D34D40D65757056A0C54409A44BDE0D38E4D4017BA1281EAC853409A44BDE0D38E4D40
74697	52471	80.216402000000002	81.271060000000006	59.299166	58.755453000000003	Центральная	0103000020E610000001000000050000007F32C687D90D5440225514AFB2604D407F32C687D90D54409E094D124BA64D403ED00A0C595154409E094D124BA64D403ED00A0C59515440225514AFB2604D407F32C687D90D5440225514AFB2604D40
74752	52477	79.722956999999994	80.777614999999997	59.196435000000001	58.65108	Советская	0103000020E6100000010000000500000083DA6FED44EE5340338AE59656534D4083DA6FED44EE5340176536C824994D404278B471C4315440176536C824994D404278B471C4315440338AE59656534D4083DA6FED44EE5340338AE59656534D40
74747	9043	87.023816999999994	87.039806999999996	56.678767999999998	56.664192999999997	Луговая	0103000020E61000000100000005000000AF05BD3786C15540B69DB64604554C40AF05BD3786C1554021C9ACDEE1564C40B8C9A8328CC2554021C9ACDEE1564C40B8C9A8328CC25540B69DB64604554C40AF05BD3786C15540B69DB64604554C40
74398	20705	86.923142999999996	86.964276999999996	56.960323000000002	56.942990999999999	Советская	0103000020E6100000010000000500000001A260C614BB55400FB6D8EDB3784C4001A260C614BB55405E4C33DDEB7A4C403DD2E0B6B6BD55405E4C33DDEB7A4C403DD2E0B6B6BD55400FB6D8EDB3784C4001A260C614BB55400FB6D8EDB3784C40
74682	20081	86.440837000000002	86.48075	56.875560999999998	56.866332	Чапаева	0103000020E61000000100000005000000797764AC369C554038BD8BF7E36E4C40797764AC369C55409753026212704C4054E3A59BC49E55409753026212704C4054E3A59BC49E554038BD8BF7E36E4C40797764AC369C554038BD8BF7E36E4C40
74758	46361	87.097190999999995	87.122138000000007	56.745631000000003	56.735210000000002	Лесная	0103000020E61000000100000005000000CB9D996038C6554099D87C5C1B5E4C40CB9D996038C6554020F12BD6705F4C4054E6E61BD1C7554020F12BD6705F4C4054E6E61BD1C7554099D87C5C1B5E4C40CB9D996038C6554099D87C5C1B5E4C40
74755	20467	86.925443000000001	86.941388000000003	56.739885000000001	56.725639999999999	Нагорная	0103000020E61000000100000005000000FAD346753ABB5540B05582C5E15C4C40FAD346753ABB554086E63A8DB45E4C40333674B33FBC554086E63A8DB45E4C40333674B33FBC5540B05582C5E15C4C40FAD346753ABB5540B05582C5E15C4C40
74420	46188	86.272465999999994	86.302092999999999	56.883114999999997	56.864865999999999	Боровая	0103000020E6100000010000000500000067D13B15709155400FB6D8EDB36E4C4067D13B1570915540B3CD8DE909714C406FD6E07D55935540B3CD8DE909714C406FD6E07D559355400FB6D8EDB36E4C4067D13B15709155400FB6D8EDB36E4C40
74715	20695	86.902148999999994	86.914223000000007	56.888092	56.883823999999997	Береговая	0103000020E610000001000000050000009FC728CFBCB95540BFB5132521714C409FC728CFBCB955406CEBA7FFAC714C4011902FA182BA55406CEBA7FFAC714C4011902FA182BA5540BFB5132521714C409FC728CFBCB95540BFB5132521714C40
74397	60298	86.557644999999994	86.583866999999998	56.848832000000002	56.834775999999998	Степная	0103000020E61000000100000005000000C971A774B0A355402BBEA1F0D96A4C40C971A774B0A355402EE6E786A66C4C40AC8DB1135EA555402EE6E786A66C4C40AC8DB1135EA555402BBEA1F0D96A4C40C971A774B0A355402BBEA1F0D96A4C40
74556	20490	86.975344000000007	87.009561000000005	56.781734999999998	56.762143000000002	Октябрьская	0103000020E6100000010000000500000064963D096CBE55400BF0DDE68D614C4064963D096CBE5540BC9179E40F644C404B94BDA59CC05540BC9179E40F644C404B94BDA59CC055400BF0DDE68D614C4064963D096CBE55400BF0DDE68D614C40
74681	20231	86.318002000000007	86.356071999999998	56.722315999999999	56.706913	Центральная	0103000020E6100000010000000500000002840F255A945540020F0C207C5A4C4002840F255A94554053B0C6D9745C4C405DC136E2C996554053B0C6D9745C4C405DC136E2C9965540020F0C207C5A4C4002840F255A945540020F0C207C5A4C40
74678	46087	86.819755999999998	86.847234999999998	56.826050000000002	56.812424	Школьная	0103000020E61000000100000005000000C9ACDEE176B45540253E7782FD674C40C9ACDEE176B455402F6EA301BC694C40B341261939B655402F6EA301BC694C40B341261939B65540253E7782FD674C40C9ACDEE176B45540253E7782FD674C40
74535	48566	86.811212999999995	86.838206999999997	56.896262999999998	56.882683	Чкалова	0103000020E61000000100000005000000C345EEE9EAB355401ADEACC1FB704C40C345EEE9EAB35540B3CEF8BEB8724C40CF11F92EA5B55540B3CEF8BEB8724C40CF11F92EA5B555401ADEACC1FB704C40C345EEE9EAB355401ADEACC1FB704C40
74430	6381	86.584325000000007	86.654008000000005	56.843122000000001	56.815725	Советская	0103000020E610000001000000050000000E4FAF9465A55540CAC342AD69684C400E4FAF9465A55540E144F46BEB6B4C40A2D45E44DBA95540E144F46BEB6B4C40A2D45E44DBA95540CAC342AD69684C400E4FAF9465A55540CAC342AD69684C40
74599	6381	86.584325000000007	86.654008000000005	56.843122000000001	56.815725	Свердлова	0103000020E610000001000000050000000E4FAF9465A55540CAC342AD69684C400E4FAF9465A55540E144F46BEB6B4C40A2D45E44DBA95540E144F46BEB6B4C40A2D45E44DBA95540CAC342AD69684C400E4FAF9465A55540CAC342AD69684C40
74395	6381	86.584325000000007	86.654008000000005	56.843122000000001	56.815725	Калинина	0103000020E610000001000000050000000E4FAF9465A55540CAC342AD69684C400E4FAF9465A55540E144F46BEB6B4C40A2D45E44DBA95540E144F46BEB6B4C40A2D45E44DBA95540CAC342AD69684C400E4FAF9465A55540CAC342AD69684C40
74429	6381	86.584325000000007	86.654008000000005	56.843122000000001	56.815725	Ефанова	0103000020E610000001000000050000000E4FAF9465A55540CAC342AD69684C400E4FAF9465A55540E144F46BEB6B4C40A2D45E44DBA95540E144F46BEB6B4C40A2D45E44DBA95540CAC342AD69684C400E4FAF9465A55540CAC342AD69684C40
74631	46223	86.436633	86.458731999999998	56.734853999999999	56.719366999999998	Новая	0103000020E61000000100000005000000AED689CBF19B55402B69C537145C4C40AED689CBF19B5540DAAA24B20F5E4C403C6876DD5B9D5540DAAA24B20F5E4C403C6876DD5B9D55402B69C537145C4C40AED689CBF19B55402B69C537145C4C40
74567	20348	86.399578000000005	86.430847999999997	56.601976000000001	56.590172000000003	Ленина	0103000020E61000000100000005000000DF8C9AAF92995540E9818FC18A4B4C40DF8C9AAF929955400B7DB08C0D4D4C4002637D03939B55400B7DB08C0D4D4C4002637D03939B5540E9818FC18A4B4C40DF8C9AAF92995540E9818FC18A4B4C40
74530	7647	86.887597	86.926871000000006	56.609636000000002	56.601159000000003	Мира	0103000020E61000000100000005000000C6C1A563CEB85540195932C7F24C4C40C6C1A563CEB855406D3B6D8D084E4C401827BEDA51BB55406D3B6D8D084E4C401827BEDA51BB5540195932C7F24C4C40C6C1A563CEB85540195932C7F24C4C40
74413	46081	86.706091999999998	86.748420999999993	56.811033999999999	56.795855000000003	Горького	0103000020E61000000100000005000000E7FD7F9C30AD5540D6AD9E93DE654C40E7FD7F9C30AD5540D7F84CF6CF674C40EFA83121E6AF5540D7F84CF6CF674C40EFA83121E6AF5540D6AD9E93DE654C40E7FD7F9C30AD5540D6AD9E93DE654C40
74478	20033	86.541106999999997	86.556872999999996	56.846651999999999	56.814655999999999	Луговая	0103000020E61000000100000005000000BF28417FA1A25540BEBED6A546684C40BF28417FA1A25540E78BBD175F6C4C40A0C1A6CEA3A35540E78BBD175F6C4C40A0C1A6CEA3A35540BEBED6A546684C40BF28417FA1A25540BEBED6A546684C40
74541	14094	87.049356000000003	87.082378000000006	56.602877999999997	56.587598999999997	Советская	0103000020E61000000100000005000000217711A628C35540C614AC71364B4C40217711A628C355402BBD361B2B4D4C403CFA5FAE45C555402BBD361B2B4D4C403CFA5FAE45C55540C614AC71364B4C40217711A628C35540C614AC71364B4C40
48704	55950	84.690676999999994	84.718444000000005	56.762473	56.733643999999998	проспект Ленина	0103000020E610000001000000050000005CC64D0D342C55400C74ED0BE85D4C405CC64D0D342C5540A08A1BB798614C407A008BFCFA2D5540A08A1BB798614C407A008BFCFA2D55400C74ED0BE85D4C405CC64D0D342C55400C74ED0BE85D4C40
74510	60308	84.715137999999996	85.769795999999999	58.531615000000002	57.975675000000003	Советская	0103000020E610000001000000050000001E882CD2C42D55402D431CEBE2FC4C401E882CD2C42D55401288D7F50B444D40DD257156447155401288D7F50B444D40DD257156447155402D431CEBE2FC4C401E882CD2C42D55402D431CEBE2FC4C40
74643	60324	83.943259999999995	84.997917999999999	59.011147000000001	58.462834000000001	пер. Школьный	0103000020E61000000100000005000000FFE7305F5EFC54400ABDFE243E3B4D40FFE7305F5EFC54406939D0436D814D40BE8575E3DD3F55406939D0436D814D40BE8575E3DD3F55400ABDFE243E3B4D40FFE7305F5EFC54400ABDFE243E3B4D40
74325	52384	86.244016000000002	87.298675000000003	58.912047999999999	58.362155000000001	Аптечный переулок	0103000020E61000000100000005000000D9EC48F59D8F55409C8A54185B2E4D40D9EC48F59D8F5540EC3026FDBD744D408048BF7D1DD35540EC3026FDBD744D408048BF7D1DD355409C8A54185B2E4D40D9EC48F59D8F55409C8A54185B2E4D40
74549	52401	84.077010999999999	85.131669000000002	58.653326999999997	58.099319000000001	Молодежная	0103000020E61000000100000005000000AA9B8BBFED0455408B6F287CB60C4D40AA9B8BBFED045540014C1938A0534D406939D0436D485540014C1938A0534D406939D0436D4855408B6F287CB60C4D40AA9B8BBFED0455408B6F287CB60C4D40
74797	60339	84.363690000000005	85.418347999999995	58.560295000000004	58.004809000000002	Новошкольная	0103000020E6100000010000000500000077F86BB246175540FDDCD0949D004D4077F86BB246175540618E1EBFB7474D403596B036C65A5540618E1EBFB7474D403596B036C65A5540FDDCD0949D004D4077F86BB246175540FDDCD0949D004D40
74784	52398	85.074625999999995	86.129283999999998	58.895319999999998	58.345160999999997	Центральная	0103000020E610000001000000050000009A5B21ACC6445540656D533C2E2C4D409A5B21ACC644554034BA83D899724D4059F965304688554034BA83D899724D4059F9653046885540656D533C2E2C4D409A5B21ACC6445540656D533C2E2C4D40
74689	52397	84.703593999999995	85.758252999999996	58.974429999999998	58.425531999999997	Таежная	0103000020E610000001000000050000005BEA20AF072D554063B323D577364D405BEA20AF072D5540E21E4B1FBA7C4D400246973787705540E21E4B1FBA7C4D40024697378770554063B323D577364D405BEA20AF072D554063B323D577364D40
66385	52387	85.329611999999997	86.384270000000001	58.815761000000002	58.264336	Центральная	0103000020E61000000100000005000000A017EE5C18555540E69315C3D5214D40A017EE5C18555540172D40DB6A684D405FB532E197985540172D40DB6A684D405FB532E197985540E69315C3D5214D40A017EE5C18555540E69315C3D5214D40
65592	52382	87.398927	88.453585000000004	59.020356999999997	58.472191000000002	Кирова	0103000020E61000000100000005000000739F1C0588D95540973B33C1703C4D40739F1C0588D95540519FE40E9B824D40323D6189071D5640519FE40E9B824D40323D6189071D5640973B33C1703C4D40739F1C0588D95540973B33C1703C4D40
74561	52388	85.542925999999994	86.597583999999998	59.032736	58.484768000000003	Центральная	0103000020E610000001000000050000007A89B14CBF625540DC12B9E00C3E4D407A89B14CBF62554070B378B130844D403927F6D03EA6554070B378B130844D403927F6D03EA65540DC12B9E00C3E4D407A89B14CBF625540DC12B9E00C3E4D40
66006	58563	84.523159000000007	85.577816999999996	58.719982000000002	58.167033000000004	Чкалова	0103000020E61000000100000005000000EBE6E26F7B215540282D5C5661154D40EBE6E26F7B215540B6DAC35E285C4D40A98427F4FA645540B6DAC35E285C4D40A98427F4FA645540282D5C5661154D40EBE6E26F7B215540282D5C5661154D40
65554	58563	84.523159000000007	85.577816999999996	58.719982000000002	58.167033000000004	Котовского	0103000020E61000000100000005000000EBE6E26F7B215540282D5C5661154D40EBE6E26F7B215540B6DAC35E285C4D40A98427F4FA645540B6DAC35E285C4D40A98427F4FA645540282D5C5661154D40EBE6E26F7B215540282D5C5661154D40
65537	58563	84.523159000000007	85.577816999999996	58.719982000000002	58.167033000000004	Гагарина	0103000020E61000000100000005000000EBE6E26F7B215540282D5C5661154D40EBE6E26F7B215540B6DAC35E285C4D40A98427F4FA645540B6DAC35E285C4D40A98427F4FA645540282D5C5661154D40EBE6E26F7B215540282D5C5661154D40
74404	58563	84.523159000000007	85.577816999999996	58.719982000000002	58.167033000000004	Вокзальная	0103000020E61000000100000005000000EBE6E26F7B215540282D5C5661154D40EBE6E26F7B215540B6DAC35E285C4D40A98427F4FA645540B6DAC35E285C4D40A98427F4FA645540282D5C5661154D40EBE6E26F7B215540282D5C5661154D40
74626	17499	82.325852999999995	82.337943999999993	57.049396999999999	57.039892999999999	Центральная	0103000020E610000001000000050000006C938AC6DA9454406F2BBD361B854C406C938AC6DA945440A0C211A452864C4048F8DEDFA0955440A0C211A452864C4048F8DEDFA09554406F2BBD361B854C406C938AC6DA9454406F2BBD361B854C40
74759	45415	81.980503999999996	82.002639000000002	57.005319	56.991836999999997	Центральная	0103000020E610000001000000050000003866D993C07E54403BFBCA83F47E4C403866D993C07E54401286014BAE804C406DACC43C2B8054401286014BAE804C406DACC43C2B8054403BFBCA83F47E4C403866D993C07E54403BFBCA83F47E4C40
74696	18300	81.914586	81.932337000000004	57.279496000000002	57.261446999999997	Центральная	0103000020E6100000010000000500000049D8B793887A54409351651877A14C4049D8B793887A544071AE6186C6A34C4073F6CE68AB7B544071AE6186C6A34C4073F6CE68AB7B54409351651877A14C4049D8B793887A54409351651877A14C40
74675	45366	82.172420000000002	82.185078000000004	57.116008999999998	57.107201000000003	Центральная	0103000020E61000000100000005000000494BE5ED088B54409C8C2AC3B88D4C40494BE5ED088B544055850662D98E4C40624D6551D88B544055850662D98E4C40624D6551D88B54409C8C2AC3B88D4C40494BE5ED088B54409C8C2AC3B88D4C40
74618	45469	81.914766	81.923246000000006	57.225738999999997	57.216017000000001	Центральная	0103000020E61000000100000005000000895FB1868B7A5440A530EF71A69B4C40895FB1868B7A54404337FB03E59C4C406C0A6476167B54404337FB03E59C4C406C0A6476167B5440A530EF71A69B4C40895FB1868B7A5440A530EF71A69B4C40
74633	17411	82.328817000000001	82.362459000000001	57.009808	57.000613000000001	Советская	0103000020E610000001000000050000009B5775560B955440EA79371614804C409B5775560B9554409D9E776341814C4004C93B87329754409D9E776341814C4004C93B8732975440EA79371614804C409B5775560B955440EA79371614804C40
74771	17401	82.500674000000004	82.515243999999996	56.959724999999999	56.944958999999997	Мира	0103000020E6100000010000000500000048FDF50A0BA05440CA87A06AF4784C4048FDF50A0BA05440A913D044D87A4C40745DF8C1F9A05440A913D044D87A4C40745DF8C1F9A05440CA87A06AF4784C4048FDF50A0BA05440CA87A06AF4784C40
74504	49428	83.070547000000005	83.085019000000003	56.863734000000001	56.844776000000003	Школьная	0103000020E610000001000000050000002E7590D783C454400D39B69E216C4C402E7590D783C45440BD38F1D58E6E4C40792288F370C55440BD38F1D58E6E4C40792288F370C554400D39B69E216C4C402E7590D783C454400D39B69E216C4C40
74679	49489	79.593097	83.247191999999998	57.936498999999998	56.242499000000002	Луговая	0103000020E61000000100000005000000C4961E4DF5E5534007280D350A1F4C40C4961E4DF5E553404CDE0033DFF74C404DF564FED1CF54404CDE0033DFF74C404DF564FED1CF544007280D350A1F4C40C4961E4DF5E5534007280D350A1F4C40
74638	18423	81.384058999999993	81.428651000000002	57.243544	57.215257000000001	Советская	0103000020E61000000100000005000000012F336C94585440179E978A8D9B4C40012F336C945854408A9125732C9F4C4074999A046F5B54408A9125732C9F4C4074999A046F5B5440179E978A8D9B4C40012F336C94585440179E978A8D9B4C40
74426	18423	81.384058999999993	81.428651000000002	57.243544	57.215257000000001	Новосибирская	0103000020E61000000100000005000000012F336C94585440179E978A8D9B4C40012F336C945854408A9125732C9F4C4074999A046F5B54408A9125732C9F4C4074999A046F5B5440179E978A8D9B4C40012F336C94585440179E978A8D9B4C40
74458	18423	81.384058999999993	81.428651000000002	57.243544	57.215257000000001	Кооперативная	0103000020E61000000100000005000000012F336C94585440179E978A8D9B4C40012F336C945854408A9125732C9F4C4074999A046F5B54408A9125732C9F4C4074999A046F5B5440179E978A8D9B4C40012F336C94585440179E978A8D9B4C40
74550	18124	81.785543000000004	81.804569000000001	57.062800000000003	57.049109000000001	Центральная	0103000020E6100000010000000500000083A62556467254403A78263449864C4083A62556467254402B1895D409884C400798F90E7E7354402B1895D409884C400798F90E7E7354403A78263449864C4083A62556467254403A78263449864C40
74790	18617	81.042169000000001	81.061160000000001	56.925851000000002	56.909509999999997	Ленина	0103000020E61000000100000005000000ECF99AE5B242544046B1DCD26A744C40ECF99AE5B242544005FC1A4982764C40B2F4A10BEA43544005FC1A4982764C40B2F4A10BEA43544046B1DCD26A744C40ECF99AE5B242544046B1DCD26A744C40
74628	18735	80.963998000000004	80.986266999999998	57.435442999999999	57.420164999999997	Совесткая	0103000020E6100000010000000500000034DAAA24B23D544040F67AF7C7B54C4034DAAA24B23D5440D522A298BCB74C40F0879FFF1E3F5440D522A298BCB74C40F0879FFF1E3F544040F67AF7C7B54C4034DAAA24B23D544040F67AF7C7B54C40
74551	18403	81.875887000000006	81.910373000000007	57.460543999999999	57.446216	Школьная 	0103000020E6100000010000000500000076FF58880E785440D9791B9B1DB94C4076FF58880E7854403C2F151BF3BA4C40558A1D8D437A54403C2F151BF3BA4C40558A1D8D437A5440D9791B9B1DB94C4076FF58880E785440D9791B9B1DB94C40
74553	45604	81.227796999999995	81.254206999999994	57.126337999999997	57.118505999999996	Центральная	0103000020E610000001000000050000001F48DE39944E54409C3061342B8F4C401F48DE39944E5440FB1EF5D72B904C4083DA6FED44505440FB1EF5D72B904C4083DA6FED445054409C3061342B8F4C401F48DE39944E54409C3061342B8F4C40
74695	18323	81.892630999999994	81.930503999999999	57.332607000000003	57.313974999999999	Больничный	0103000020E610000001000000050000005419C6DD207954407C61325530A84C405419C6DD20795440D9B5BDDD92AA4C400533A6608D7B5440D9B5BDDD92AA4C400533A6608D7B54407C61325530A84C405419C6DD207954407C61325530A84C40
12287	41054	82.011208999999994	82.039721	57.061694000000003	57.048257	Центральная	0103000020E61000000100000005000000EF1AF4A5B7805440CB660E492D864C40EF1AF4A5B7805440022EC896E5874C40B9FDF2C98A825440022EC896E5874C40B9FDF2C98A825440CB660E492D864C40EF1AF4A5B7805440CB660E492D864C40
74766	49417	82.917779999999993	82.933159000000003	57.028030999999999	57.01491	Школьная	0103000020E61000000100000005000000103B53E8BCBA544012312592E8814C40103B53E8BCBA54401823128596834C40F5BD86E0B8BB54401823128596834C40F5BD86E0B8BB544012312592E8814C40103B53E8BCBA544012312592E8814C40
74694	4867	81.951749000000007	81.977405000000005	56.934736000000001	56.915053	Центральная 	0103000020E610000001000000050000000C40A374E97C5440A88DEA7420754C400C40A374E97C54406A32E36DA5774C409A7CB3CD8D7E54406A32E36DA5774C409A7CB3CD8D7E5440A88DEA7420754C400C40A374E97C5440A88DEA7420754C40
74598	45452	81.745541000000003	81.760542999999998	56.985166999999997	56.974150999999999	Ленина	0103000020E61000000100000005000000F03499F1B66F5440CF2EDFFAB07C4C40F03499F1B66F5440990CC7F3197E4C40E90C8CBCAC705440990CC7F3197E4C40E90C8CBCAC705440CF2EDFFAB07C4C40F03499F1B66F5440CF2EDFFAB07C4C40
74497	4850	82.008667000000003	82.101417999999995	57.036504000000001	57.006191000000001	Целинная	0103000020E610000001000000050000007C6308008E805440C843DFDDCA804C407C6308008E8054402B16BF29AC844C40724EECA17D8654402B16BF29AC844C40724EECA17D865440C843DFDDCA804C407C6308008E805440C843DFDDCA804C40
74387	4850	82.008667000000003	82.101417999999995	57.036504000000001	57.006191000000001	Трактовый	0103000020E610000001000000050000007C6308008E805440C843DFDDCA804C407C6308008E8054402B16BF29AC844C40724EECA17D8654402B16BF29AC844C40724EECA17D865440C843DFDDCA804C407C6308008E805440C843DFDDCA804C40
74425	4850	82.008667000000003	82.101417999999995	57.036504000000001	57.006191000000001	Октябрьская	0103000020E610000001000000050000007C6308008E805440C843DFDDCA804C407C6308008E8054402B16BF29AC844C40724EECA17D8654402B16BF29AC844C40724EECA17D865440C843DFDDCA804C407C6308008E805440C843DFDDCA804C40
9660	4850	82.008667000000003	82.101417999999995	57.036504000000001	57.006191000000001	Ленина	0103000020E610000001000000050000007C6308008E805440C843DFDDCA804C407C6308008E8054402B16BF29AC844C40724EECA17D8654402B16BF29AC844C40724EECA17D865440C843DFDDCA804C407C6308008E805440C843DFDDCA804C40
74492	4850	82.008667000000003	82.101417999999995	57.036504000000001	57.006191000000001	Вицмана	0103000020E610000001000000050000007C6308008E805440C843DFDDCA804C407C6308008E8054402B16BF29AC844C40724EECA17D8654402B16BF29AC844C40724EECA17D865440C843DFDDCA804C407C6308008E805440C843DFDDCA804C40
74753	40332	86.040233999999998	86.082696999999996	57.058781000000003	57.041410999999997	Библиотечная	0103000020E61000000100000005000000FC8BA03193825540EA58A5F44C854C40FC8BA031938255402750C42286874C408C9E5BE84A8555402750C42286874C408C9E5BE84A855540EA58A5F44C854C40FC8BA03193825540EA58A5F44C854C40
74453	13072	86.064605	86.101104000000007	56.808093	56.797274999999999	Школьная	0103000020E610000001000000050000001E8A027D228455408E75711B0D664C401E8A027D22845540329067976F674C40AB5FE97C78865540329067976F674C40AB5FE97C788655408E75711B0D664C401E8A027D228455408E75711B0D664C40
74680	13166	85.825968000000003	85.846745999999996	56.809975000000001	56.801642000000001	Советская	0103000020E61000000100000005000000B9E2E2A8DC745540CE8C7E349C664C40B9E2E2A8DC745540EFC9C342AD674C403481221631765540EFC9C342AD674C403481221631765540CE8C7E349C664C40B9E2E2A8DC745540CE8C7E349C664C40
74536	12554	85.803492000000006	85.837951000000004	57.192673999999997	57.169862999999999	Школьная	0103000020E6100000010000000500000040A6B5696C73554075E61E12BE954C4040A6B5696C7355400E65A88AA9984C40A2293BFDA07555400E65A88AA9984C40A2293BFDA075554075E61E12BE954C4040A6B5696C73554075E61E12BE954C40
74668	52217	86.191886999999994	86.214453000000006	56.970210999999999	56.959474	Волкова	0103000020E61000000100000005000000C36169E0478C554060AE450BD07A4C40C36169E0478C5540179CC1DF2F7C4C40DD611399B98D5540179CC1DF2F7C4C40DD611399B98D554060AE450BD07A4C40C36169E0478C554060AE450BD07A4C40
74672	52221	86.048147999999998	86.106655000000003	56.937108000000002	56.927343999999998	Береговая	0103000020E610000001000000050000008A5759DB1483554027124C35B3764C408A5759DB14835540F568AA27F3774C401D3D7E6FD3865540F568AA27F3774C401D3D7E6FD386554027124C35B3764C408A5759DB1483554027124C35B3764C40
74620	7098	85.95899	85.976371999999998	56.939774999999997	56.930315999999998	имени Б.Н.Сидоренко	0103000020E610000001000000050000003ACC9717607D554007793D9814774C403ACC9717607D5540984C158C4A784C40BA2EFCE07C7E5540984C158C4A784C40BA2EFCE07C7E554007793D9814774C403ACC9717607D554007793D9814774C40
74750	60333	86.246270999999993	86.264408000000003	56.950605000000003	56.942784000000003	Советская	0103000020E6100000010000000500000001BD70E7C28F554096986725AD784C4001BD70E7C28F55400135B56CAD794C404033880FEC9055400135B56CAD794C404033880FEC90554096986725AD784C4001BD70E7C28F554096986725AD784C40
74653	60325	84.735699999999994	86.380695000000003	57.891899000000002	56.709896999999998	Береговая	0103000020E61000000100000005000000B3EA73B5152F5540A643A7E7DD5A4C40B3EA73B5152F5540E52A16BF29F24C400CB08F4E5D985540E52A16BF29F24C400CB08F4E5D985540A643A7E7DD5A4C40B3EA73B5152F5540A643A7E7DD5A4C40
74415	12351	85.831824999999995	85.894141000000005	57.312686999999997	57.289416000000003	Школьная	0103000020E61000000100000005000000B1BFEC9E3C75554036785F950BA54C40B1BFEC9E3C7555403271AB2006A84C40D1402C9B397955403271AB2006A84C40D1402C9B3979554036785F950BA54C40B1BFEC9E3C75554036785F950BA54C40
9704	12526	86.040233999999998	86.082696999999996	57.058781000000003	57.041410999999997	Школьная	0103000020E61000000100000005000000FC8BA03193825540EA58A5F44C854C40FC8BA031938255402750C42286874C408C9E5BE84A8555402750C42286874C408C9E5BE84A855540EA58A5F44C854C40FC8BA03193825540EA58A5F44C854C40
74542	12670	85.924835999999999	85.983676000000003	56.931451000000003	56.916758000000002	Советская	0103000020E61000000100000005000000768A5583307B5540562C7E5358754C40768A5583307B5540CB694FC939774C400C772E8CF47E5540CB694FC939774C400C772E8CF47E5540562C7E5358754C40768A5583307B5540562C7E5358754C40
74609	52214	85.778482999999994	85.807704999999999	56.880465000000001	56.869107	Центральная	0103000020E610000001000000050000007C5F5CAAD2715540C2DCEEE53E6F4C407C5F5CAAD2715540E622BE13B3704C4034F44F70B1735540E622BE13B3704C4034F44F70B1735540C2DCEEE53E6F4C407C5F5CAAD2715540C2DCEEE53E6F4C40
74744	12746	85.786208000000002	85.814649000000003	56.942686000000002	56.932054999999998	пер.Школьный	0103000020E61000000100000005000000A1F65B3B51725540618907944D774C40A1F65B3B51725540D33252EFA9784C40062E8F3523745540D33252EFA9784C40062E8F3523745540618907944D774C40A1F65B3B51725540618907944D774C40
74565	60315	85.769615999999999	85.792191000000003	57.280625000000001	57.266767000000002	Центральная	0103000020E610000001000000050000009D9E7763417155407653CA6B25A24C409D9E77634171554052B81E85EBA34C40E04BE141B372554052B81E85EBA34C40E04BE141B37255407653CA6B25A24C409D9E7763417155407653CA6B25A24C40
74390	12239	85.827889999999996	85.863822999999996	57.447958999999997	57.421889999999998	Больничный переулок	0103000020E61000000100000005000000DEAB5626FC7455403541D47D00B64C40DEAB5626FC745540747973B856B94C4016A243E048775540747973B856B94C4016A243E0487755403541D47D00B64C40DEAB5626FC7455403541D47D00B64C40
74614	52222	85.970488000000003	86.004031999999995	56.801350999999997	56.793813999999998	Центральная	0103000020E61000000100000005000000454AB3791C7E5540B08D78B29B654C40454AB3791C7E5540F6CE68AB92664C40CC086F0F42805540F6CE68AB92664C40CC086F0F42805540B08D78B29B654C40454AB3791C7E5540B08D78B29B654C40
74665	12179	85.729613999999998	85.763508000000002	57.506467999999998	57.478026	Береговая	0103000020E610000001000000050000000A2DEBFEB16E5540A051BAF42FBD4C400A2DEBFEB16E55403A3C84F1D3C04C40008FA850DD7055403A3C84F1D3C04C40008FA850DD705540A051BAF42FBD4C400A2DEBFEB16E5540A051BAF42FBD4C40
74765	12630	85.899342000000004	85.939639999999997	57.098768	57.079988	Партизанская	0103000020E61000000100000005000000D57ABFD18E7955404609FA0B3D8A4C40D57ABFD18E79554017F2086EA48C4C40DC80CF0F237C554017F2086EA48C4C40DC80CF0F237C55404609FA0B3D8A4C40D57ABFD18E7955404609FA0B3D8A4C40
74756	60335	85.884071000000006	85.900419999999997	56.905509000000002	56.894030999999998	Новая	0103000020E61000000100000005000000E415889E947855401A4E999B6F724C40E415889E94785540E99D0AB8E7734C40842A357BA0795540E99D0AB8E7734C40842A357BA07955401A4E999B6F724C40E415889E947855401A4E999B6F724C40
74590	47875	86.246037999999999	86.258497000000006	56.985804999999999	56.979272000000002	Советская	0103000020E61000000100000005000000B0E42A16BF8F5540BBF1EEC8587D4C40B0E42A16BF8F5540DC9DB5DB2E7E4C404E4700378B905540DC9DB5DB2E7E4C404E4700378B905540BBF1EEC8587D4C40B0E42A16BF8F5540BBF1EEC8587D4C40
74539	12329	85.857229000000004	85.869714999999999	57.378129999999999	57.367395000000002	Центральная	0103000020E61000000100000005000000B30B06D7DC76554062DBA2CC06AF4C40B30B06D7DC76554078D1579066B04C40CD751A69A977554078D1579066B04C40CD751A69A977554062DBA2CC06AF4C40B30B06D7DC76554062DBA2CC06AF4C40
74743	12975	86.187252000000001	86.210032999999996	56.900063000000003	56.881286000000003	Центральная	0103000020E610000001000000050000001407D0EFFB8B55401A36CAFACD704C401407D0EFFB8B55407AABAE4335734C402B85402E718D55407AABAE4335734C402B85402E718D55401A36CAFACD704C401407D0EFFB8B55401A36CAFACD704C40
74473	2998	85.138334	85.209453999999994	57.766871999999999	57.741928999999999	Рабочая	0103000020E61000000100000005000000317BD976DA4855401C7A8B87F7DE4C40317BD976DA485540EB1B98DC28E24C400C01C0B1674D5540EB1B98DC28E24C400C01C0B1674D55401C7A8B87F7DE4C40317BD976DA4855401C7A8B87F7DE4C40
74619	2998	85.138334	85.209453999999994	57.766871999999999	57.741928999999999	Новая	0103000020E61000000100000005000000317BD976DA4855401C7A8B87F7DE4C40317BD976DA485540EB1B98DC28E24C400C01C0B1674D5540EB1B98DC28E24C400C01C0B1674D55401C7A8B87F7DE4C40317BD976DA4855401C7A8B87F7DE4C40
74825	2998	85.138334	85.209453999999994	57.766871999999999	57.741928999999999	Железнодорожная	0103000020E61000000100000005000000317BD976DA4855401C7A8B87F7DE4C40317BD976DA485540EB1B98DC28E24C400C01C0B1674D5540EB1B98DC28E24C400C01C0B1674D55401C7A8B87F7DE4C40317BD976DA4855401C7A8B87F7DE4C40
74518	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	проспект Ленина	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74517	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Советская	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74419	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Свободы	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74326	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Павлика Морозова	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74493	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Мирная	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74515	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Кирова	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74330	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Ивана Буева	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74434	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Гончарова	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
65500	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	В.В.Липатова	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
65502	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	Боровая	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74313	11644	86.085491000000005	86.206699999999998	57.026698000000003	56.960450999999999	370 Стрелковой дивизии	0103000020E610000001000000050000008D463EAF788555408B34F10EF07A4C408D463EAF788555402F6F0ED76A834C405305A3923A8D55402F6F0ED76A834C405305A3923A8D55408B34F10EF07A4C408D463EAF788555408B34F10EF07A4C40
74552	60314	76.647430999999997	77.702089000000001	60.935428999999999	60.418103000000002	Дорожная 	0103000020E61000000100000005000000A9DA6E826F29534004AE2B6684354E40A9DA6E826F295340705D3123BC774E406878B306EF6C5340705D3123BC774E406878B306EF6C534004AE2B6684354E40A9DA6E826F29534004AE2B6684354E40
74717	60330	78.878630999999999	79.933289000000002	59.750608	59.214131999999999	Школьная	0103000020E610000001000000050000001D90847D3BB85340778368AD689B4D401D90847D3BB85340D80E46EC13E04D40DC2DC901BBFB5340D80E46EC13E04D40DC2DC901BBFB5340778368AD689B4D401D90847D3BB85340778368AD689B4D40
74629	38396	78.69144	79.746098000000003	60.032169000000003	59.500222999999998	Школьный	0103000020E610000001000000050000005CC98E8D40AC53407FDAA84E07C04D405CC98E8D40AC5340F778211D1E044E401B67D311C0EF5340F778211D1E044E401B67D311C0EF53407FDAA84E07C04D405CC98E8D40AC53407FDAA84E07C04D40
74578	52338	78.420552999999998	79.475211000000002	60.401085000000002	59.875095000000002	Молодежная	0103000020E61000000100000005000000054F2157EA9A534052F2EA1C03F04D40054F2157EA9A534045F5D6C056334E40C4EC65DB69DE534045F5D6C056334E40C4EC65DB69DE534052F2EA1C03F04D40054F2157EA9A534052F2EA1C03F04D40
74762	52342	77.880234000000002	78.934892000000005	60.587752999999999	60.064784000000003	Центральная	0103000020E61000000100000005000000F2B4FCC055785340ECA694D74A084E40F2B4FCC0557853401D90847D3B4B4E40B1524145D5BB53401D90847D3B4B4E40B1524145D5BB5340ECA694D74A084E40F2B4FCC055785340ECA694D74A084E40
74692	60328	77.153614000000005	78.208271999999994	60.793767000000003	60.274140000000003	Обская	0103000020E610000001000000050000004C8DD0CFD44953404243FF0417234E404C8DD0CFD449534070D234289A654E400A2B1554548D534070D234289A654E400A2B1554548D53404243FF0417234E404C8DD0CFD44953404243FF0417234E40
65408	38490	77.334030999999996	78.388689999999997	60.694063999999997	60.172817999999999	переулок Солнечный	0103000020E6100000010000000500000069368FC3605553407F1475E61E164E4069368FC3605553405CAAD216D7584E401092054CE09853405CAAD216D7584E401092054CE09853407F1475E61E164E4069368FC3605553407F1475E61E164E40
74333	38490	77.334030999999996	78.388689999999997	60.694063999999997	60.172817999999999	Пушкина	0103000020E6100000010000000500000069368FC3605553407F1475E61E164E4069368FC3605553405CAAD216D7584E401092054CE09853405CAAD216D7584E401092054CE09853407F1475E61E164E4069368FC3605553407F1475E61E164E40
74699	38490	77.334030999999996	78.388689999999997	60.694063999999997	60.172817999999999	Партизанская	0103000020E6100000010000000500000069368FC3605553407F1475E61E164E4069368FC3605553405CAAD216D7584E401092054CE09853405CAAD216D7584E401092054CE09853407F1475E61E164E4069368FC3605553407F1475E61E164E40
71977	59567	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Советская	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72126	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	переулок Клубный	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71982	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Юбилейная	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71981	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Чапаева	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71942	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Чайковского	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71995	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Фрунзе	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71941	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Советская	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71945	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Пушкина	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71739	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Парковая	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72024	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Октябрьская	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72006	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Мира	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72225	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Максима Горького	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72247	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Ленина	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71943	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Космонавтов	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71740	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Комсомольская	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71738	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Кирова	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71983	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Калинина	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72240	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Дружбы	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72227	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Дзержинского	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72025	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Горная	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72015	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	Бограда	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
9954	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	30 лет Победы	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
71944	12532	91.154872999999995	91.367180000000005	53.852015999999999	53.774132000000002	 Космонавтов	0103000020E6100000010000000500000023827170E9C95640BF64E3C116E34A4023827170E9C9564099D53BDC0EED4A40B3EF8AE07FD7564099D53BDC0EED4A40B3EF8AE07FD75640BF64E3C116E34A4023827170E9C95640BF64E3C116E34A40
72023	12183	90.179635000000005	90.286022000000003	54.026451000000002	53.985773999999999	Кирова	0103000020E61000000100000005000000E38DCC237F8B5640A19FA9D72DFE4A40E38DCC237F8B564027F911BF62034B40F0FB372F4E92564027F911BF62034B40F0FB372F4E925640A19FA9D72DFE4A40E38DCC237F8B5640A19FA9D72DFE4A40
72005	12183	90.179635000000005	90.286022000000003	54.026451000000002	53.985773999999999	Геологов	0103000020E61000000100000005000000E38DCC237F8B5640A19FA9D72DFE4A40E38DCC237F8B564027F911BF62034B40F0FB372F4E92564027F911BF62034B40F0FB372F4E925640A19FA9D72DFE4A40E38DCC237F8B5640A19FA9D72DFE4A40
72168	12183	90.179635000000005	90.286022000000003	54.026451000000002	53.985773999999999	Боградская	0103000020E61000000100000005000000E38DCC237F8B5640A19FA9D72DFE4A40E38DCC237F8B564027F911BF62034B40F0FB372F4E92564027F911BF62034B40F0FB372F4E925640A19FA9D72DFE4A40E38DCC237F8B5640A19FA9D72DFE4A40
72022	12183	90.179635000000005	90.286022000000003	54.026451000000002	53.985773999999999	50 лет Октября	0103000020E61000000100000005000000E38DCC237F8B5640A19FA9D72DFE4A40E38DCC237F8B564027F911BF62034B40F0FB372F4E92564027F911BF62034B40F0FB372F4E925640A19FA9D72DFE4A40E38DCC237F8B5640A19FA9D72DFE4A40
73487	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	микрорайон Заводской	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
72021	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Школьная	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
73491	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Центральный мкр	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
73492	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Центральный микрорайон	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
71967	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Советский мкр	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
71972	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Ленинградский мкр	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
73493	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Ленинградский микрорайон	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
72020	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Комсомольский мкр	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
72002	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Интернациональный мкр	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
71974	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Заводской мкр	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
73489	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Заводской микрорайон	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
71975	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Заводской	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
73485	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Енисейский микрорайон	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
72003	11092	91.367386999999994	91.443006999999994	53.130985000000003	53.048766000000001	Геологов	0103000020E610000001000000050000006F7EC34483D756401094DBF63D864A406F7EC34483D756401FA2D11DC4904A408A39083A5ADC56401FA2D11DC4904A408A39083A5ADC56401094DBF63D864A406F7EC34483D756401094DBF63D864A40
71984	14315	91.534769999999995	91.559760999999995	53.681395999999999	53.651488999999998	Октябрьская	0103000020E610000001000000050000007138F3AB39E25640145AD6FD63D34A407138F3AB39E2564007D0EFFB37D74A40E124CD1FD3E3564007D0EFFB37D74A40E124CD1FD3E35640145AD6FD63D34A407138F3AB39E25640145AD6FD63D34A40
72031	14315	91.534769999999995	91.559760999999995	53.681395999999999	53.651488999999998	Зеленая	0103000020E610000001000000050000007138F3AB39E25640145AD6FD63D34A407138F3AB39E2564007D0EFFB37D74A40E124CD1FD3E3564007D0EFFB37D74A40E124CD1FD3E35640145AD6FD63D34A407138F3AB39E25640145AD6FD63D34A40
5238	7985	91.443635999999998	91.444984000000005	53.701503000000002	53.699098999999997	улица Ширинская	0103000020E6100000010000000500000002D53F8864DC564049D576137CD94A4002D53F8864DC5640E085ADD9CAD94A4092CF2B9E7ADC5640E085ADD9CAD94A4092CF2B9E7ADC564049D576137CD94A4002D53F8864DC564049D576137CD94A40
4497	7985	91.353696999999997	91.400238000000002	53.685017000000002	53.668531000000002	улица Центральная	0103000020E610000001000000050000005FECBDF8A2D656405CAE7E6C92D54A405FECBDF8A2D656401E1A16A3AED74A407427D87F9DD956401E1A16A3AED74A407427D87F9DD956405CAE7E6C92D54A405FECBDF8A2D656405CAE7E6C92D54A40
2276	7985	91.419741000000002	91.458888999999999	53.733201999999999	53.728119999999997	улица Тельмана	0103000020E6100000010000000500000095F25A09DDDA564021C8410933DD4A4095F25A09DDDA56404FAE2990D9DD4A40A0DFF76F5EDD56404FAE2990D9DD4A40A0DFF76F5EDD564021C8410933DD4A4095F25A09DDDA564021C8410933DD4A40
2369	7985	91.362499999999997	91.461917	53.723298999999997	53.712685	улица Советская	0103000020E610000001000000050000003333333333D75640C5AC174339DB4A403333333333D75640601DC70F95DC4A40DA1D520C90DD5640601DC70F95DC4A40DA1D520C90DD5640C5AC174339DB4A403333333333D75640C5AC174339DB4A40
2525	7985	91.440230999999997	91.483718999999994	53.715797000000002	53.710425000000001	улица Павших Коммунаров	0103000020E61000000100000005000000DDEBA4BE2CDC564062A1D634EFDA4A40DDEBA4BE2CDC564097C9703C9FDB4A400B5D8940F5DE564097C9703C9FDB4A400B5D8940F5DE564062A1D634EFDA4A40DDEBA4BE2CDC564062A1D634EFDA4A40
4498	7985	91.470909000000006	91.476667000000006	53.713031000000001	53.707988999999998	улица Нагорная	0103000020E610000001000000050000001899805F23DE5640C07630629FDA4A401899805F23DE564060048D9944DB4A4047054EB681DE564060048D9944DB4A4047054EB681DE5640C07630629FDA4A401899805F23DE5640C07630629FDA4A40
4663	7985	91.473622000000006	91.484779000000003	53.710312999999999	53.707940999999998	улица Набережная	0103000020E61000000100000005000000A22AA6D24FDE5640AF3F89CF9DDA4A40A22AA6D24FDE56403A765089EBDA4A4068B27F9E06DF56403A765089EBDA4A4068B27F9E06DF5640AF3F89CF9DDA4A40A22AA6D24FDE5640AF3F89CF9DDA4A40
2805	7985	91.497130999999996	91.499483999999995	53.703932999999999	53.701523999999999	улица Молодежная	0103000020E61000000100000005000000FAB48AFED0DF5640F7ADD689CBD94A40FAB48AFED0DF56409FC9FE791ADA4A400438BD8BF7DF56409FC9FE791ADA4A400438BD8BF7DF5640F7ADD689CBD94A40FAB48AFED0DF5640F7ADD689CBD94A40
72296	7985	91.426173000000006	91.436188999999999	53.715429	53.691448000000001	улица Мира	0103000020E610000001000000050000000C5C1E6B46DB56403B71395E81D84A400C5C1E6B46DB564014CE6E2D93DB4A40FF774485EADB564014CE6E2D93DB4A40FF774485EADB56403B71395E81D84A400C5C1E6B46DB56403B71395E81D84A40
6552	7985	91.393653999999998	91.406454999999994	53.692605	53.685268000000001	улица Кадышева	0103000020E6100000010000000500000022FC8BA031D95640677FA0DCB6D74A4022FC8BA031D95640E605D847A7D84A40EC12D55B03DA5640E605D847A7D84A40EC12D55B03DA5640677FA0DCB6D74A4022FC8BA031D95640677FA0DCB6D74A40
71741	7985	91.454190999999994	91.463245999999998	53.748002	53.719324	улица Жукова	0103000020E61000000100000005000000CDC8207711DD56402C9D0FCF12DC4A40CDC8207711DD5640DAAB8F87BEDF4A402E008DD2A5DD5640DAAB8F87BEDF4A402E008DD2A5DD56402C9D0FCF12DC4A40CDC8207711DD56402C9D0FCF12DC4A40
71994	7985	91.429946000000001	91.434635	53.733063000000001	53.716537000000002	Ярыгина	0103000020E61000000100000005000000F2423A3C84DB5640DEAF027CB7DB4A40F2423A3C84DB56402E742502D5DD4A409BAC510FD1DB56402E742502D5DD4A409BAC510FD1DB5640DEAF027CB7DB4A40F2423A3C84DB5640DEAF027CB7DB4A40
72066	7985	91.440096999999994	91.445207999999994	53.735273999999997	53.717571	Щетинкина	0103000020E6100000010000000500000055849B8C2ADC56406DC7D45DD9DB4A4055849B8C2ADC5640AFCC5B751DDE4A40B9FAB1497EDC5640AFCC5B751DDE4A40B9FAB1497EDC56406DC7D45DD9DB4A4055849B8C2ADC56406DC7D45DD9DB4A40
73524	7985	91.424259000000006	91.425956999999997	53.707675000000002	53.702179999999998	Школьная	0103000020E610000001000000050000002882380F27DB5640E0F3C308E1D94A402882380F27DB564031992A1895DA4A40252026E142DB564031992A1895DA4A40252026E142DB5640E0F3C308E1D94A402882380F27DB5640E0F3C308E1D94A40
72109	7985	91.416103000000007	91.419461999999996	53.725637999999996	53.714911999999998	Чернышевского	0103000020E610000001000000050000001F317A6EA1DA56404CC2853C82DB4A401F317A6EA1DA56400F5EBBB4E1DC4A408BFA2477D8DA56400F5EBBB4E1DC4A408BFA2477D8DA56404CC2853C82DB4A401F317A6EA1DA56404CC2853C82DB4A40
72072	7985	91.423523000000003	91.438604999999995	53.702824999999997	53.699748999999997	Челюскинцев	0103000020E61000000100000005000000A58636001BDB564050340F6091D94A40A58636001BDB5640D5E76A2BF6D94A402CB7B41A12DC5640D5E76A2BF6D94A402CB7B41A12DC564050340F6091D94A40A58636001BDB564050340F6091D94A40
72108	7985	91.412761000000003	91.440455999999998	53.713740000000001	53.708384000000002	Хлебная	0103000020E610000001000000050000001D041DAD6ADA56403D81B053ACDA4A401D041DAD6ADA56406CEC12D55BDB4A40EDD45C6E30DC56406CEC12D55BDB4A40EDD45C6E30DC56403D81B053ACDA4A401D041DAD6ADA56403D81B053ACDA4A40
72052	7985	91.406993999999997	91.467934999999997	53.722276000000001	53.716051999999998	Хакасская	0103000020E61000000100000005000000C4EA8F300CDA5640211E8997A7DB4A40C4EA8F300CDA5640C5573B8A73DC4A40D769A4A5F2DD5640C5573B8A73DC4A40D769A4A5F2DD5640211E8997A7DB4A40C4EA8F300CDA5640211E8997A7DB4A40
72098	7985	91.419741000000002	91.458888999999999	53.733201999999999	53.728119999999997	Тельмана	0103000020E6100000010000000500000095F25A09DDDA564021C8410933DD4A4095F25A09DDDA56404FAE2990D9DD4A40A0DFF76F5EDD56404FAE2990D9DD4A40A0DFF76F5EDD564021C8410933DD4A4095F25A09DDDA564021C8410933DD4A40
72074	7985	91.400732000000005	91.408180000000002	53.702669999999998	53.695154000000002	Стофато	0103000020E610000001000000050000007C9DD497A5D9564080D767CEFAD84A407C9DD497A5D95640AEF02E17F1D94A4067B8019F1FDA5640AEF02E17F1D94A4067B8019F1FDA564080D767CEFAD84A407C9DD497A5D9564080D767CEFAD84A40
72100	7985	91.362499999999997	91.461917	53.723298999999997	53.712685	Советская	0103000020E610000001000000050000003333333333D75640C5AC174339DB4A403333333333D75640601DC70F95DC4A40DA1D520C90DD5640601DC70F95DC4A40DA1D520C90DD5640C5AC174339DB4A403333333333D75640C5AC174339DB4A40
2869	7985	91.423261999999994	91.443645000000004	53.746974000000002	53.746425000000002	Северный проезд	0103000020E61000000100000005000000EEE87FB916DB56405AF5B9DA8ADF4A40EEE87FB916DB56402D7B12D89CDF4A402C82FFAD64DC56402D7B12D89CDF4A402C82FFAD64DC56405AF5B9DA8ADF4A40EEE87FB916DB56405AF5B9DA8ADF4A40
72090	7985	91.503814000000006	91.506392000000005	53.712898000000003	53.709125	Рыбацкая	0103000020E610000001000000050000001651137D3EE0564054E3A59BC4DA4A401651137D3EE0564021B1DD3D40DB4A4030BDFDB968E0564021B1DD3D40DB4A4030BDFDB968E0564054E3A59BC4DA4A401651137D3EE0564054E3A59BC4DA4A40
72067	7985	91.399294999999995	91.480557000000005	53.719611999999998	53.710174000000002	Пушкина	0103000020E61000000100000005000000349D9D0C8ED95640193C4CFBE6DA4A40349D9D0C8ED9564092E7FA3E1CDC4A404AB72572C1DE564092E7FA3E1CDC4A404AB72572C1DE5640193C4CFBE6DA4A40349D9D0C8ED95640193C4CFBE6DA4A40
72103	7985	91.388417000000004	91.406473000000005	53.704706000000002	53.698331000000003	Пирятинская	0103000020E61000000100000005000000780DFAD2DBD85640396403E962D94A40780DFAD2DBD85640C2A563CE33DA4A40406D54A703DA5640C2A563CE33DA4A40406D54A703DA5640396403E962D94A40780DFAD2DBD85640396403E962D94A40
72062	7985	91.440230999999997	91.483718999999994	53.715797000000002	53.710425000000001	Павших Коммунаров	0103000020E61000000100000005000000DDEBA4BE2CDC564062A1D634EFDA4A40DDEBA4BE2CDC564097C9703C9FDB4A400B5D8940F5DE564097C9703C9FDB4A400B5D8940F5DE564062A1D634EFDA4A40DDEBA4BE2CDC564062A1D634EFDA4A40
72120	7985	91.464449999999999	91.467352000000005	53.719408999999999	53.709498000000004	Островского	0103000020E6100000010000000500000024287E8CB9DD5640E94999D4D0DA4A4024287E8CB9DD56405AB9179815DC4A4018EE5C18E9DD56405AB9179815DC4A4018EE5C18E9DD5640E94999D4D0DA4A4024287E8CB9DD5640E94999D4D0DA4A40
72088	7985	91.497130999999996	91.499483999999995	53.703932999999999	53.701523999999999	Молодежная	0103000020E61000000100000005000000FAB48AFED0DF5640F7ADD689CBD94A40FAB48AFED0DF56409FC9FE791ADA4A400438BD8BF7DF56409FC9FE791ADA4A400438BD8BF7DF5640F7ADD689CBD94A40FAB48AFED0DF5640F7ADD689CBD94A40
72056	7985	91.421357999999998	91.427475000000001	53.739331999999997	53.736589000000002	Лермонтова	0103000020E610000001000000050000001C7A8B87F7DA5640F3CB608C48DE4A401C7A8B87F7DA56407171546EA2DE4A40E3361AC05BDB56407171546EA2DE4A40E3361AC05BDB5640F3CB608C48DE4A401C7A8B87F7DA5640F3CB608C48DE4A40
2206	7985	91.417809000000005	91.470935999999995	53.725695999999999	53.719841000000002	Ленина проспект	0103000020E610000001000000050000005EBEF561BDDA5640F4A8F8BF23DC4A405EBEF561BDDA5640446B459BE3DC4A4094A0BFD023DE5640446B459BE3DC4A4094A0BFD023DE5640F4A8F8BF23DC4A405EBEF561BDDA5640F4A8F8BF23DC4A40
72051	7985	91.404765999999995	91.469418000000005	53.738123000000002	53.731290000000001	Крылова	0103000020E610000001000000050000001822A7AFE7D9564028F224E99ADD4A401822A7AFE7D9564074B680D07ADE4A40D789CBF10ADE564074B680D07ADE4A40D789CBF10ADE564028F224E99ADD4A401822A7AFE7D9564028F224E99ADD4A40
72050	7985	91.438309000000004	91.440285000000003	53.746451999999998	53.736243000000002	Комарова	0103000020E61000000100000005000000B82231410DDC56405874EB353DDE4A40B82231410DDC5640530438BD8BDF4A40D7FA22A12DDC5640530438BD8BDF4A40D7FA22A12DDC56405874EB353DDE4A40B82231410DDC56405874EB353DDE4A40
72107	7985	91.353751000000003	91.397463000000002	53.685288999999997	53.669592999999999	Зоотехническая	0103000020E6100000010000000500000059FB3BDBA3D65640B5503239B5D54A4059FB3BDBA3D656407EA7C98CB7D74A40AF97A60870D956407EA7C98CB7D74A40AF97A60870D95640B5503239B5D54A4059FB3BDBA3D65640B5503239B5D54A40
72118	7985	91.468959999999996	91.473782999999997	53.736136999999999	53.73171	Зеленая	0103000020E6100000010000000500000075C8CD7003DE5640FD135CACA8DD4A4075C8CD7003DE56401230BABC39DE4A40A699EE7552DE56401230BABC39DE4A40A699EE7552DE5640FD135CACA8DD4A4075C8CD7003DE5640FD135CACA8DD4A40
71998	7985	91.454190999999994	91.463245999999998	53.748002	53.719324	Жукова	0103000020E61000000100000005000000CDC8207711DD56402C9D0FCF12DC4A40CDC8207711DD5640DAAB8F87BEDF4A402E008DD2A5DD5640DAAB8F87BEDF4A402E008DD2A5DD56402C9D0FCF12DC4A40CDC8207711DD56402C9D0FCF12DC4A40
2870	7985	91.399259000000001	91.440078999999997	53.753335999999997	53.735300000000002	Дружбы Народов проспект	0103000020E610000001000000050000008EE89E758DD95640D95F764F1EDE4A408EE89E758DD95640217365506DE04A40022A1C412ADC5640217365506DE04A40022A1C412ADC5640D95F764F1EDE4A408EE89E758DD95640D95F764F1EDE4A40
72059	7985	91.406473000000005	91.440267000000006	53.711033	53.704695000000001	Гагарина	0103000020E61000000100000005000000406D54A703DA5640CE531D7233DA4A40406D54A703DA56403AB01C2103DB4A4084A0A3552DDC56403AB01C2103DB4A4084A0A3552DDC5640CE531D7233DA4A40406D54A703DA5640CE531D7233DA4A40
72053	7985	91.444075999999995	91.449860999999999	53.735560999999997	53.716372	Вяткина	0103000020E61000000100000005000000103CBEBD6BDC564093E2E313B2DB4A40103CBEBD6BDC5640459BE3DC26DE4A40BCAFCA85CADC5640459BE3DC26DE4A40BCAFCA85CADC564093E2E313B2DB4A40103CBEBD6BDC564093E2E313B2DB4A40
2677	7985	91.45129	91.457505999999995	53.737510999999998	53.736989000000001	Весенний проезд	0103000020E61000000100000005000000C2C073EFE1DC56408141D2A755DE4A40C2C073EFE1DC56405AB8ACC266DE4A4052EE3EC747DD56405AB8ACC266DE4A4052EE3EC747DD56408141D2A755DE4A40C2C073EFE1DC56408141D2A755DE4A40
72055	7985	91.396061000000003	91.470315999999997	53.729201000000003	53.722349999999999	Богдана Хмельницкого	0103000020E61000000100000005000000268E3C1059D95640FF21FDF675DC4A40268E3C1059D95640F29A577556DD4A4046B247A819DE5640F29A577556DD4A4046B247A819DE5640FF21FDF675DC4A40268E3C1059D95640FF21FDF675DC4A40
72060	7985	91.415392999999995	91.427152000000007	53.711635000000001	53.686371999999999	Белоярская	0103000020E61000000100000005000000307F85CC95DA5640EF71A609DBD74A40307F85CC95DA564030D80DDB16DB4A40F29A577556DB564030D80DDB16DB4A40F29A577556DB5640EF71A609DBD74A40307F85CC95DA5640EF71A609DBD74A40
72070	7985	91.370666	91.449986999999993	53.706518000000003	53.679550999999996	Аскизская	0103000020E610000001000000050000004EEFE2FDB8D75640677BF486FBD64A404EEFE2FDB8D7564086048C2E6FDA4A4002284696CCDC564086048C2E6FDA4A4002284696CCDC5640677BF486FBD64A404EEFE2FDB8D75640677BF486FBD64A40
71737	10580	90.054570999999996	90.153413	52.664084000000003	52.595984000000001	Энтузиастов	0103000020E61000000100000005000000D7135D177E8356403A782634494C4A40D7135D177E83564000E65AB400554A400072C284D189564000E65AB400554A400072C284D18956403A782634494C4A40D7135D177E8356403A782634494C4A40
72167	10580	90.054570999999996	90.153413	52.664084000000003	52.595984000000001	ТЭЦ	0103000020E61000000100000005000000D7135D177E8356403A782634494C4A40D7135D177E83564000E65AB400554A400072C284D189564000E65AB400554A400072C284D18956403A782634494C4A40D7135D177E8356403A782634494C4A40
71939	10580	90.054570999999996	90.153413	52.664084000000003	52.595984000000001	Ленина	0103000020E61000000100000005000000D7135D177E8356403A782634494C4A40D7135D177E83564000E65AB400554A400072C284D189564000E65AB400554A400072C284D18956403A782634494C4A40D7135D177E8356403A782634494C4A40
72125	10580	90.054570999999996	90.153413	52.664084000000003	52.595984000000001	Кулакова	0103000020E61000000100000005000000D7135D177E8356403A782634494C4A40D7135D177E83564000E65AB400554A400072C284D189564000E65AB400554A400072C284D18956403A782634494C4A40D7135D177E8356403A782634494C4A40
72124	10580	90.054570999999996	90.153413	52.664084000000003	52.595984000000001	Геологическая	0103000020E61000000100000005000000D7135D177E8356403A782634494C4A40D7135D177E83564000E65AB400554A400072C284D189564000E65AB400554A400072C284D18956403A782634494C4A40D7135D177E8356403A782634494C4A40
72166	10580	90.054570999999996	90.153413	52.664084000000003	52.595984000000001	Вокзальная	0103000020E61000000100000005000000D7135D177E8356403A782634494C4A40D7135D177E83564000E65AB400554A400072C284D189564000E65AB400554A400072C284D18956403A782634494C4A40D7135D177E8356403A782634494C4A40
72205	22671	89.940638000000007	89.999701999999999	54.509433999999999	54.467804000000001	Щетинина	0103000020E61000000100000005000000FED7B969337C564010786000E13B4B40FED7B969337C564038BC202235414B40BBEF181EFB7F564038BC202235414B40BBEF181EFB7F564010786000E13B4B40FED7B969337C564010786000E13B4B40
72013	22671	89.940638000000007	89.999701999999999	54.509433999999999	54.467804000000001	Школьная	0103000020E61000000100000005000000FED7B969337C564010786000E13B4B40FED7B969337C564038BC202235414B40BBEF181EFB7F564038BC202235414B40BBEF181EFB7F564010786000E13B4B40FED7B969337C564010786000E13B4B40
71958	22671	89.940638000000007	89.999701999999999	54.509433999999999	54.467804000000001	Рабочая	0103000020E61000000100000005000000FED7B969337C564010786000E13B4B40FED7B969337C564038BC202235414B40BBEF181EFB7F564038BC202235414B40BBEF181EFB7F564010786000E13B4B40FED7B969337C564010786000E13B4B40
71996	22671	89.940638000000007	89.999701999999999	54.509433999999999	54.467804000000001	Октябрьская	0103000020E61000000100000005000000FED7B969337C564010786000E13B4B40FED7B969337C564038BC202235414B40BBEF181EFB7F564038BC202235414B40BBEF181EFB7F564010786000E13B4B40FED7B969337C564010786000E13B4B40
72268	22671	89.940638000000007	89.999701999999999	54.509433999999999	54.467804000000001	Гаражная	0103000020E61000000100000005000000FED7B969337C564010786000E13B4B40FED7B969337C564038BC202235414B40BBEF181EFB7F564038BC202235414B40BBEF181EFB7F564010786000E13B4B40FED7B969337C564010786000E13B4B40
72294	59591	89.416775999999999	89.440383999999995	54.696995999999999	54.675345	Центральная	0103000020E610000001000000050000007E703E75AC5A5640314278B471564B407E703E75AC5A5640AEB8382A37594B40A06B5F402F5C5640AEB8382A37594B40A06B5F402F5C5640314278B471564B407E703E75AC5A5640314278B471564B40
72163	25545	89.900914	89.931833999999995	54.587615	54.568302000000003	Ленина	0103000020E610000001000000050000008CA03193A87956402E20B41EBE484B408CA03193A8795640CCD1E3F7364B4B4041D3122BA37B5640CCD1E3F7364B4B4041D3122BA37B56402E20B41EBE484B408CA03193A87956402E20B41EBE484B40
72210	25640	89.794769000000002	89.823128999999994	54.635907000000003	54.621304000000002	Гагарина	0103000020E61000000100000005000000FAB7CB7EDD725640DF6FB4E3864F4B40FAB7CB7EDD72564014268C6665514B40E8D84125AE74564014268C6665514B40E8D84125AE745640DF6FB4E3864F4B40FAB7CB7EDD725640DF6FB4E3864F4B40
71965	24709	89.905153999999996	89.965952000000001	54.346390999999997	54.306086999999998	Первомайская	0103000020E61000000100000005000000FDF50A0BEE795640895DDBDB2D274B40FDF50A0BEE7956407A50508A562C4B405F605628D27D56407A50508A562C4B405F605628D27D5640895DDBDB2D274B40FDF50A0BEE795640895DDBDB2D274B40
72411	24709	89.905153999999996	89.965952000000001	54.346390999999997	54.306086999999998	Орджоникидзе	0103000020E61000000100000005000000FDF50A0BEE795640895DDBDB2D274B40FDF50A0BEE7956407A50508A562C4B405F605628D27D56407A50508A562C4B405F605628D27D5640895DDBDB2D274B40FDF50A0BEE795640895DDBDB2D274B40
72046	24709	89.905153999999996	89.965952000000001	54.346390999999997	54.306086999999998	Микрорайон	0103000020E61000000100000005000000FDF50A0BEE795640895DDBDB2D274B40FDF50A0BEE7956407A50508A562C4B405F605628D27D56407A50508A562C4B405F605628D27D5640895DDBDB2D274B40FDF50A0BEE795640895DDBDB2D274B40
73535	60022	89.651892000000004	89.663938999999999	54.546796000000001	54.538069	Школьная	0103000020E610000001000000050000008A213999B8695640E7FEEA71DF444B408A213999B8695640B4CA4C69FD454B407EE200FA7D6A5640B4CA4C69FD454B407EE200FA7D6A5640E7FEEA71DF444B408A213999B8695640E7FEEA71DF444B40
72340	25274	89.419928999999996	89.432640000000006	54.733826999999998	54.726013000000002	Нижняя	0103000020E610000001000000050000001669E21DE05A564045BC75FEED5C4B401669E21DE05A5640FDF50A0BEE5D4B4041BCAE5FB05B5640FDF50A0BEE5D4B4041BCAE5FB05B564045BC75FEED5C4B401669E21DE05A564045BC75FEED5C4B40
72341	25766	90.375924999999995	90.403073000000006	54.391311000000002	54.377961999999997	Ленина	0103000020E61000000100000005000000EC2FBB270F985640BC900E0F61304B40EC2FBB270F98564054C8957A16324B40A439B2F2CB99564054C8957A16324B40A439B2F2CB995640BC900E0F61304B40EC2FBB270F985640BC900E0F61304B40
73518	25585	89.864119000000002	89.894339000000002	54.736305999999999	54.722363000000001	Карла Маркса	0103000020E610000001000000050000008B36C7B94D775640946B0A64765C4B408B36C7B94D7756409EEC66463F5E4B406422A5D93C7956409EEC66463F5E4B406422A5D93C795640946B0A64765C4B408B36C7B94D775640946B0A64765C4B40
72209	33142	89.935633999999993	89.953591000000003	54.445596999999999	54.435192000000001	Победы	0103000020E61000000100000005000000A4C16D6DE17B56408CBD175FB4374B40A4C16D6DE17B56400D198F5209394B40A3B08BA2077D56400D198F5209394B40A3B08BA2077D56408CBD175FB4374B40A4C16D6DE17B56408CBD175FB4374B40
72335	59595	89.726965000000007	89.734385000000003	54.547580000000004	54.536313999999997	Таежная	0103000020E610000001000000050000008C153598866E56408731E9EFA5444B408C153598866E5640CBF8F71917464B40126BF129006F5640CBF8F71917464B40126BF129006F56408731E9EFA5444B408C153598866E56408731E9EFA5444B40
71966	24879	89.266084000000006	89.319596000000004	54.353606999999997	54.334676000000002	50 лет ВЛКСМ	0103000020E610000001000000050000004A7F2F8507515640C860C5A9D62A4B404A7F2F85075156407E5182FE422D4B40ADFBC742745456407E5182FE422D4B40ADFBC74274545640C860C5A9D62A4B404A7F2F8507515640C860C5A9D62A4B40
71999	24670	90.134439999999998	90.153655000000001	54.486553000000001	54.479157000000001	Микрорайон	0103000020E610000001000000050000008DD13AAA9A88564022533E04553D4B408DD13AAA9A885640A662635E473E4B407BF7C77BD5895640A662635E473E4B407BF7C77BD589564022533E04553D4B408DD13AAA9A88564022533E04553D4B40
72339	25037	89.439188999999999	89.451909000000001	54.475982000000002	54.460075000000003	Трактовая	0103000020E61000000100000005000000D4F02DAC1B5C5640865AD3BCE33A4B40D4F02DAC1B5C56400ABE69FAEC3C4B4028F1B913EC5C56400ABE69FAEC3C4B4028F1B913EC5C5640865AD3BCE33A4B40D4F02DAC1B5C5640865AD3BCE33A4B40
72148	25340	90.382187000000002	90.416438999999997	54.818579	54.801670000000001	50 лет ВЛКСМ	0103000020E61000000100000005000000357D76C0759856409817601F9D664B40357D76C075985640A0185932C7684B40DA71C3EFA69A5640A0185932C7684B40DA71C3EFA69A56409817601F9D664B40357D76C0759856409817601F9D664B40
73551	60031	90.500324000000006	90.515865000000005	54.390723999999999	54.384763	Мира	0103000020E61000000100000005000000DA59F44E05A05640FDDAFAE93F314B40DA59F44E05A0564093E1783E03324B40AB09A2EE03A1564093E1783E03324B40AB09A2EE03A15640FDDAFAE93F314B40DA59F44E05A05640FDDAFAE93F314B40
73523	20932	89.158268000000007	89.186098000000001	54.625791	54.613624000000002	Целинная	0103000020E6100000010000000500000037001B10214A56403605323B8B4E4B4037001B10214A5640C99063EB19504B4077F69507E94B5640C99063EB19504B4077F69507E94B56403605323B8B4E4B4037001B10214A56403605323B8B4E4B40
72375	25434	90.507007999999999	90.527417	54.708716000000003	54.700268000000001	Гагарина	0103000020E61000000100000005000000DDB3AED172A05640B937BF61A2594B40DDB3AED172A056407313B534B75A4B40AF963B33C1A156407313B534B75A4B40AF963B33C1A15640B937BF61A2594B40DDB3AED172A05640B937BF61A2594B40
73510	25749	90.389221000000006	90.412477999999993	54.467903999999997	54.460959000000003	Октябрьская	0103000020E61000000100000005000000A77A32FFE898564000E65AB4003B4B40A77A32FFE898564073D53C47E43B4B407214200A669A564073D53C47E43B4B407214200A669A564000E65AB4003B4B40A77A32FFE898564000E65AB4003B4B40
72211	25672	90.346434000000002	90.380615000000006	54.469760999999998	54.456353999999997	Ленина	0103000020E610000001000000050000003D0E83F92B9656400BB3D0CE693A4B403D0E83F92B965640D7F7E120213C4B407E5704FF5B985640D7F7E120213C4B407E5704FF5B9856400BB3D0CE693A4B403D0E83F92B9656400BB3D0CE693A4B40
72409	25869	89.464197999999996	89.494731999999999	54.148600999999999	54.131152999999998	Школьная	0103000020E610000001000000050000009737876BB55D5640DAE21A9FC9104B409737876BB55D56409293895B05134B40381268B0A95F56409293895B05134B40381268B0A95F5640DAE21A9FC9104B409737876BB55D5640DAE21A9FC9104B40
72407	25237	89.473845999999995	89.487814999999998	54.560628000000001	54.551856999999998	Новая	0103000020E61000000100000005000000C9552C7E535E5640CA880B40A3464B40C9552C7E535E5640679C86A8C2474B40E3DF675C385F5640679C86A8C2474B40E3DF675C385F5640CA880B40A3464B40C9552C7E535E5640CA880B40A3464B40
72091	59582	90.369152	90.400898999999995	53.710095000000003	53.696165999999998	Ленина	0103000020E6100000010000000500000031D0B52FA0975640274BADF71BD94A4031D0B52FA0975640CD069964E4DA4A40F17F4754A8995640CD069964E4DA4A40F17F4754A8995640274BADF71BD94A4031D0B52FA0975640274BADF71BD94A40
71964	23894	90.202892000000006	90.254086999999998	53.849769000000002	53.819104000000003	Ленина	0103000020E61000000100000005000000AF27BA2EFC8C5640EB025E66D8E84A40AF27BA2EFC8C5640CB13083BC5EC4A40AED51EF642905640CB13083BC5EC4A40AED51EF642905640EB025E66D8E84A40AF27BA2EFC8C5640EB025E66D8E84A40
72011	22714	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Спортивная	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
72214	22714	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Подгорный квартал	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
71960	22714	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Октябрьская	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
71989	22714	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Мира	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
71961	22714	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Кирова	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
72374	22714	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Заречная	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
73507	22714	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Добровольского	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
73514	60006	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	Волкова	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
73488	60006	91.358152000000004	91.413533000000001	53.867781999999998	53.777653999999998	30 лет Победы	0103000020E61000000100000005000000CFBF5DF6EBD6564042CD902A8AE34A40CFBF5DF6EBD656405B07077B13EF4A4046B41D5377DA56405B07077B13EF4A4046B41D5377DA564042CD902A8AE34A40CFBF5DF6EBD6564042CD902A8AE34A40
71962	23244	91.324555000000004	91.346393000000006	53.795873999999998	53.780963999999997	Ленина	0103000020E6100000010000000500000036B05582C5D456403AADDBA0F6E34A4036B05582C5D456404CDE0033DFE54A400EA48B4D2BD656404CDE0033DFE54A400EA48B4D2BD656403AADDBA0F6E34A4036B05582C5D456403AADDBA0F6E34A40
72196	23537	91.288146999999995	91.329010999999994	53.684538000000003	53.672078999999997	Вокзальная	0103000020E61000000100000005000000315C1D0071D2564008AA46AF06D64A40315C1D0071D25640446FF1F09ED74A408D4127840ED55640446FF1F09ED74A408D4127840ED5564008AA46AF06D64A40315C1D0071D2564008AA46AF06D64A40
72235	20346	90.196702999999999	90.236829999999998	54.177678999999998	54.153758000000003	Линейная	0103000020E610000001000000050000009B012EC8968C5640CBBF9657AE134B409B012EC8968C5640CE177B2FBE164B408C2D0439288F5640CE177B2FBE164B408C2D0439288F5640CBBF9657AE134B409B012EC8968C5640CBBF9657AE134B40
72264	24167	91.176558	91.196932000000004	53.696305000000002	53.684697	10-й Пятилетки	0103000020E6100000010000000500000038F6ECB94CCB5640AC55BB26A4D74A4038F6ECB94CCB56404985B18520D94A404CE2AC889ACC56404985B18520D94A404CE2AC889ACC5640AC55BB26A4D74A4038F6ECB94CCB5640AC55BB26A4D74A40
72288	59590	91.273944	91.29898	53.626210999999998	53.610925000000002	Майская	0103000020E61000000100000005000000DE3B6A4C88D1564087A757CA32CE4A40DE3B6A4C88D156409EB29AAE27D04A401E8A027D22D356409EB29AAE27D04A401E8A027D22D3564087A757CA32CE4A40DE3B6A4C88D1564087A757CA32CE4A40
72204	23210	91.346958999999998	91.357865000000004	53.794528999999997	53.780591000000001	Школьная	0103000020E610000001000000050000006283859334D65640A646E867EAE34A406283859334D656409E5C5320B3E54A4084D89942E7D656409E5C5320B3E54A4084D89942E7D65640A646E867EAE34A406283859334D65640A646E867EAE34A40
72044	59579	91.152034	91.187184999999999	53.531509999999997	53.514550999999997	30 лет Победы	0103000020E610000001000000050000005378D0ECBAC95640E28FA2CEDCC14A405378D0ECBAC956409CBF098508C44A405053CBD6FACB56409CBF098508C44A405053CBD6FACB5640E28FA2CEDCC14A405378D0ECBAC95640E28FA2CEDCC14A40
73569	60038	91.400220000000004	91.414682999999997	53.929212999999997	53.923450000000003	Школьная	0103000020E6100000010000000500000021CD58349DD95640E0BE0E9C33F64A4021CD58349DD956404F029B73F0F64A4042CD902A8ADA56404F029B73F0F64A4042CD902A8ADA5640E0BE0E9C33F64A4021CD58349DD95640E0BE0E9C33F64A40
72176	24020	91.091900999999993	91.121409999999997	53.935065999999999	53.919457999999999	Советская	0103000020E610000001000000050000000F5EBBB4E1C55640D505BCCCB0F54A400F5EBBB4E1C55640FFCC203EB0F74A4012DA722EC5C75640FFCC203EB0F74A4012DA722EC5C75640D505BCCCB0F54A400F5EBBB4E1C55640D505BCCCB0F54A40
72337	24266	91.115534999999994	91.124015	53.793534000000001	53.788756999999997	Урожайная	0103000020E61000000100000005000000C6A2E9EC64C75640DBBE47FDF5E44A40C6A2E9EC64C75640CD21A98592E54A40A94D9CDCEFC75640CD21A98592E54A40A94D9CDCEFC75640DBBE47FDF5E44A40C6A2E9EC64C75640DBBE47FDF5E44A40
73516	23971	91.180484000000007	91.191281000000004	53.907307000000003	53.901736999999997	Школьная	0103000020E61000000100000005000000E25CC30C8DCB5640EC4B361E6CF34A40E25CC30C8DCB56404837C2A222F44A4028D6A9F23DCC56404837C2A222F44A4028D6A9F23DCC5640EC4B361E6CF34A40E25CC30C8DCB5640EC4B361E6CF34A40
73521	23757	90.721722999999997	90.748106000000007	53.632393999999998	53.609113999999998	Школьная	0103000020E610000001000000050000005871AAB530AE564093C49272F7CD4A405871AAB530AE5640E3175E49F2D04A4040FCFCF7E0AF5640E3175E49F2D04A4040FCFCF7E0AF564093C49272F7CD4A405871AAB530AE564093C49272F7CD4A40
71990	23325	91.376846	91.406688000000003	53.772210999999999	53.730170999999999	Школьная	0103000020E610000001000000050000003868AF3E1ED856406ABE4A3E76DD4A403868AF3E1ED85640444E5FCFD7E24A403EEB1A2D07DA5640444E5FCFD7E24A403EEB1A2D07DA56406ABE4A3E76DD4A403868AF3E1ED856406ABE4A3E76DD4A40
72238	23325	91.376846	91.406688000000003	53.772210999999999	53.730170999999999	Советская	0103000020E610000001000000050000003868AF3E1ED856406ABE4A3E76DD4A403868AF3E1ED85640444E5FCFD7E24A403EEB1A2D07DA5640444E5FCFD7E24A403EEB1A2D07DA56406ABE4A3E76DD4A403868AF3E1ED856406ABE4A3E76DD4A40
72405	23692	90.929952	90.942887999999996	53.519396	53.512397999999997	Ленина	0103000020E6100000010000000500000063B6645584BB56409544F64196C14A4063B6645584BB56402CD670917BC24A409DF2E84658BC56402CD670917BC24A409DF2E84658BC56409544F64196C14A4063B6645584BB56409544F64196C14A40
71963	23294	91.289692000000002	91.321914000000007	53.779516999999998	53.768560000000001	Хакасская	0103000020E610000001000000050000006C7A50508AD25640C381902C60E24A406C7A50508AD2564088D68A36C7E34A40F9872D3D9AD4564088D68A36C7E34A40F9872D3D9AD45640C381902C60E24A406C7A50508AD25640C381902C60E24A40
72201	59586	91.016092	91.046554	53.450712000000003	53.436821000000002	Механизаторская	0103000020E610000001000000050000008B6EBDA607C156405F9A22C0E9B74A408B6EBDA607C1564017F549EEB0B94A40DFDFA0BDFAC2564017F549EEB0B94A40DFDFA0BDFAC256405F9A22C0E9B74A408B6EBDA607C156405F9A22C0E9B74A40
72202	23722	90.682889000000003	90.724517000000006	53.632368	53.616335999999997	Мира	0103000020E6100000010000000500000015731074B4AB564079AC1919E4CE4A4015731074B4AB5640BA84436FF1D04A4059198D7C5EAE5640BA84436FF1D04A4059198D7C5EAE564079AC1919E4CE4A4015731074B4AB564079AC1919E4CE4A40
72174	24086	90.954970000000003	90.996077	53.992252999999998	53.962806	30 лет Победы	0103000020E6100000010000000500000050AA7D3A1EBD564040321D3A3DFB4A4050AA7D3A1EBD5640CF2D742502FF4A400FD3BEB9BFBF5640CF2D742502FF4A400FD3BEB9BFBF564040321D3A3DFB4A4050AA7D3A1EBD564040321D3A3DFB4A40
72400	22376	90.032894999999996	90.054912000000002	52.821084999999997	52.807384999999996	Центральная	0103000020E61000000100000005000000EC4CA1F31A825640F623456458674A40EC4CA1F31A8256403A1E335019694A401C0A9FAD838356403A1E335019694A401C0A9FAD83835640F623456458674A40EC4CA1F31A825640F623456458674A40
72347	22578	89.869877000000002	89.879453999999996	52.902729000000001	52.898411000000003	Хакасская	0103000020E61000000100000005000000BAA29410AC775640EFAEB321FF724A40BAA29410AC7756404D13B69F8C734A4087156EF9487856404D13B69F8C734A4087156EF948785640EFAEB321FF724A40BAA29410AC775640EFAEB321FF724A40
72327	22126	90.260052000000002	90.270724000000001	52.718933999999997	52.705660000000002	Школьная	0103000020E610000001000000050000009AD024B1A4905640350C1F11535A4A409AD024B1A4905640C1FD8007065C4A40828FC18A53915640C1FD8007065C4A40828FC18A53915640350C1F11535A4A409AD024B1A4905640350C1F11535A4A40
72042	21762	89.864164000000002	89.915205999999998	52.809883999999997	52.778078000000001	Ленина	0103000020E610000001000000050000005B9885764E77564059DE550F98634A405B9885764E775640DEC66647AA674A4097C62FBC927A5640DEC66647AA674A4097C62FBC927A564059DE550F98634A405B9885764E77564059DE550F98634A40
72043	21762	89.864164000000002	89.915205999999998	52.809883999999997	52.778078000000001	Карла Маркса	0103000020E610000001000000050000005B9885764E77564059DE550F98634A405B9885764E775640DEC66647AA674A4097C62FBC927A5640DEC66647AA674A4097C62FBC927A564059DE550F98634A405B9885764E77564059DE550F98634A40
72401	22404	90.080540999999997	90.089856999999995	52.863771999999997	52.859374000000003	Мирная	0103000020E610000001000000050000002D3F70952785564030849CF7FF6D4A402D3F709527855640AA99B514906E4A4044149337C0855640AA99B514906E4A4044149337C085564030849CF7FF6D4A402D3F70952785564030849CF7FF6D4A40
73513	21552	89.445432999999994	89.460802999999999	52.642766999999999	52.618991000000001	Центральная	0103000020E61000000100000005000000C9E369F9815C564059C2DA183B4F4A40C9E369F9815C564059F9653046524A4084B9DDCB7D5D564059F9653046524A4084B9DDCB7D5D564059C2DA183B4F4A40C9E369F9815C564059C2DA183B4F4A40
73525	60012	89.820307999999997	89.840440000000001	52.789766	52.775637000000003	Мира	0103000020E610000001000000050000006B2920ED7F745640A648BE1248634A406B2920ED7F74564012BF620D17654A400490DAC4C975564012BF620D17654A400490DAC4C9755640A648BE1248634A406B2920ED7F745640A648BE1248634A40
72330	22427	89.951920999999999	89.969149999999999	52.830264	52.823610000000002	Советская	0103000020E610000001000000050000000AD80E46EC7C56404C546F0D6C694A400AD80E46EC7C5640E8853B17466A4A40C7BAB88D067E5640E8853B17466A4A40C7BAB88D067E56404C546F0D6C694A400AD80E46EC7C56404C546F0D6C694A40
72299	21650	89.754219000000006	89.771090000000001	52.759177000000001	52.751503	Советская	0103000020E6100000010000000500000066C1C41F4570564046EC134031604A4066C1C41F457056400D7041B62C614A407311DF89597156400D7041B62C614A407311DF895971564046EC134031604A4066C1C41F4570564046EC134031604A40
72259	21509	89.442458999999999	89.480080999999998	52.666049999999998	52.646608999999998	Клубная	0103000020E6100000010000000500000089B48D3F515C56404E266E15C4524A4089B48D3F515C56401AC05B2041554A40959BA8A5B95E56401AC05B2041554A40959BA8A5B95E56404E266E15C4524A4089B48D3F515C56404E266E15C4524A40
72193	22035	90.303646999999998	90.323311000000004	52.731471999999997	52.701681999999998	Советская	0103000020E61000000100000005000000D3A1D3F36E9356408F183DB7D0594A40D3A1D3F36E93564048F8DEDFA05D4A40F9DB9E20B194564048F8DEDFA05D4A40F9DB9E20B19456408F183DB7D0594A40D3A1D3F36E9356408F183DB7D0594A40
72397	22192	89.826794000000007	89.83399	52.758527999999998	52.749361	Центральная	0103000020E61000000100000005000000DCA16131EA745640EDF2AD0FEB5F4A40DCA16131EA745640D68C0C7217614A403ACC971760755640D68C0C7217614A403ACC971760755640EDF2AD0FEB5F4A40DCA16131EA745640EDF2AD0FEB5F4A40
72364	21900	89.547157999999996	89.562690000000003	52.788426000000001	52.781221000000002	Луговая	0103000020E61000000100000005000000AAEFFCA20463564066F9BA0CFF634A40AAEFFCA20463564076A8A624EB644A4052F2EA1C0364564076A8A624EB644A4052F2EA1C0364564066F9BA0CFF634A40AAEFFCA20463564066F9BA0CFF634A40
73517	22615	89.817460999999994	89.830037000000004	52.335379000000003	52.326892999999998	Набережная	0103000020E610000001000000050000005930F147517456404A253CA1D7294A405930F14751745640F261F6B2ED2A4A40145E82531F755640F261F6B2ED2A4A40145E82531F7556404A253CA1D7294A405930F147517456404A253CA1D7294A40
72260	22477	89.918593000000001	89.937988000000004	52.855105000000002	52.846159	Юбилейная	0103000020E6100000010000000500000069554B3ACA7A5640A81B28F04E6C4A4069554B3ACA7A5640B3D2A414746D4A409702D2FE077C5640B3D2A414746D4A409702D2FE077C5640A81B28F04E6C4A4069554B3ACA7A5640A81B28F04E6C4A40
72398	22266	89.688632999999996	89.708010000000002	52.684997000000003	52.676910999999997	Школьная	0103000020E61000000100000005000000917C2590126C5640BDA60705A5564A40917C2590126C5640D76D50FBAD574A406CCF2C09506D5640D76D50FBAD574A406CCF2C09506D5640BDA60705A5564A40917C2590126C5640BDA60705A5564A40
73511	22549	89.834689999999995	89.850582000000003	52.877034999999999	52.870632000000001	Молодежная	0103000020E6100000010000000500000016139B8F6B755640F06C8FDE706F4A4016139B8F6B7556404339D1AE42704A403E247CEF6F7656404339D1AE42704A403E247CEF6F765640F06C8FDE706F4A4016139B8F6B755640F06C8FDE706F4A40
72361	21710	89.705799999999996	89.724987999999996	52.778120999999999	52.769432000000002	Октябрьская	0103000020E610000001000000050000001361C3D32B6D5640793F6EBF7C624A401361C3D32B6D564058AA0B7899634A40847F1134666E564058AA0B7899634A40847F1134666E5640793F6EBF7C624A401361C3D32B6D5640793F6EBF7C624A40
72324	21951	89.432479000000001	89.455098000000007	52.816813000000003	52.806013	Школьная	0103000020E610000001000000050000003C4D66BCAD5B56404F93196F2B674A403C4D66BCAD5B56404DF910548D684A40679E5C53205D56404DF910548D684A40679E5C53205D56404F93196F2B674A403C4D66BCAD5B56404F93196F2B674A40
73508	22331	89.984673000000001	89.999315999999993	52.817743	52.808779000000001	Кунучакова	0103000020E610000001000000050000004510E7E1047F56408658FD1186674A404510E7E1047F564037C478CDAB684A40A69718CBF47F564037C478CDAB684A40A69718CBF47F56408658FD1186674A404510E7E1047F56408658FD1186674A40
72365	22106	90.363761999999994	90.384755999999996	52.716523000000002	52.712130999999999	Сосновая	0103000020E61000000100000005000000C36169E047975640E0BBCD1B275B4A40C36169E04797564079EA9106B75B4A40253CA1D79F98564079EA9106B75B4A40253CA1D79F985640E0BBCD1B275B4A40C36169E047975640E0BBCD1B275B4A40
72402	22236	89.778366000000005	89.802908000000002	52.748542999999998	52.734209999999997	Советская	0103000020E610000001000000050000006094A0BFD0715640B532E197FA5D4A406094A0BFD07156402A53CC41D05F4A40986C3CD8627356402A53CC41D05F4A40986C3CD862735640B532E197FA5D4A406094A0BFD0715640B532E197FA5D4A40
72140	22010	90.267022999999995	90.300314	52.703733999999997	52.686788	Титова	0103000020E61000000100000005000000E811A3E71691564083A44FABE8574A40E811A3E716915640A88AA9F4135A4A40FB21365838935640A88AA9F4135A4A40FB2136583893564083A44FABE8574A40E811A3E71691564083A44FABE8574A40
72362	21843	89.471879000000001	89.493078999999994	52.813046	52.801990000000004	Советская	0103000020E61000000100000005000000D42AFA43335E56400ADCBA9BA7664A40D42AFA43335E564062122EE411684A400AD6389B8E5F564062122EE411684A400AD6389B8E5F56400ADCBA9BA7664A40D42AFA43335E56400ADCBA9BA7664A40
72145	20707	89.544139000000001	89.573414999999997	54.913576999999997	54.898654999999998	Советская	0103000020E610000001000000050000009A5E622CD362564085B1852007734B409A5E622CD36256405BB05417F0744B404B02D4D4B26456405BB05417F0744B404B02D4D4B264564085B1852007734B409A5E622CD362564085B1852007734B40
72257	21360	89.209975	89.267179999999996	54.871952999999998	54.858238	Центральная	0103000020E61000000100000005000000917EFB3A704D56409C1727BEDA6D4B40917EFB3A704D56401553E9279C6F4B404C89247A195156401553E9279C6F4B404C89247A195156409C1727BEDA6D4B40917EFB3A704D56409C1727BEDA6D4B40
72336	21464	88.683149	88.708912999999995	54.665359000000002	54.650599	Заводская	0103000020E61000000100000005000000E35295B6B82B5640B8E7F9D346534B40E35295B6B82B5640B58CD47B2A554B4064ADA1D45E2D5640B58CD47B2A554B4064ADA1D45E2D5640B8E7F9D346534B40E35295B6B82B5640B8E7F9D346534B40
72329	33154	88.366187999999994	90.542725000000004	55.434896000000002	54.281205	Центральная	0103000020E61000000100000005000000020CCB9F6F175640603C8386FE234B40020CCB9F6F175640A39410ACAAB74B402F6EA301BCA25640A39410ACAAB74B402F6EA301BCA25640603C8386FE234B40020CCB9F6F175640603C8386FE234B40
72360	21434	88.937147999999993	89.002958000000007	54.787084999999998	54.761929000000002	пер. Школьный	0103000020E61000000100000005000000C1E09A3BFA3B5640DF6FB4E386614B40C1E09A3BFA3B564009168733BF644B40BE50C0763040564009168733BF644B40BE50C07630405640DF6FB4E386614B40C1E09A3BFA3B5640DF6FB4E386614B40
72237	20998	90.102541000000002	90.137835999999993	55.089939000000001	55.070056000000001	Ленина	0103000020E61000000100000005000000F25F200890865640BD715298F7884B40F25F20089086564046D1031F838B4B40880D164ED288564046D1031F838B4B40880D164ED2885640BD715298F7884B40F25F200890865640BD715298F7884B40
72393	21202	90.396271999999996	90.417877000000004	55.043365000000001	55.034657000000003	Школьная	0103000020E6100000010000000500000083143C855C995640EBC9FCA36F844B4083143C855C9956404165FCFB8C854B400A302C7FBE9A56404165FCFB8C854B400A302C7FBE9A5640EBC9FCA36F844B4083143C855C995640EBC9FCA36F844B40
9970	20690	89.830620999999994	89.844662	54.956017000000003	54.949420000000003	Песочная	0103000020E61000000100000005000000BB97FBE4287556408C15359886794B40BB97FBE428755640C4B5DAC35E7A4B40228B34F10E765640C4B5DAC35E7A4B40228B34F10E7656408C15359886794B40BB97FBE4287556408C15359886794B40
72404	20912	89.497013999999993	89.505683000000005	55.036881000000001	55.023769000000001	Центральная	0103000020E61000000100000005000000DDE9CE13CF5F56404ED4D2DC0A834B40DDE9CE13CF5F5640016C4084B8844B402AC93A1C5D605640016C4084B8844B402AC93A1C5D6056404ED4D2DC0A834B40DDE9CE13CF5F56404ED4D2DC0A834B40
72192	20583	89.840197000000003	89.858604	55.048600999999998	55.030771999999999	Механизаторов	0103000020E61000000100000005000000A14CA3C9C5755640F6D03E56F0834B40A14CA3C9C5755640C5C6BC8E38864B40BF0D315EF3765640C5C6BC8E38864B40BF0D315EF3765640F6D03E56F0834B40A14CA3C9C5755640F6D03E56F0834B40
71988	20392	89.800977000000003	89.836253999999997	55.002474999999997	54.981566999999998	Партизанская	0103000020E6100000010000000500000049F60835437356409AEAC9FCA37D4B4049F60835437356405F07CE1951804B408C497F2F857556405F07CE1951804B408C497F2F857556409AEAC9FCA37D4B4049F60835437356409AEAC9FCA37D4B40
72333	20392	89.800977000000003	89.836253999999997	55.002474999999997	54.981566999999998	Залинейная	0103000020E6100000010000000500000049F60835437356409AEAC9FCA37D4B4049F60835437356405F07CE1951804B408C497F2F857556405F07CE1951804B408C497F2F857556409AEAC9FCA37D4B4049F60835437356409AEAC9FCA37D4B40
72392	21105	90.217956999999998	90.225313999999997	55.102431000000003	55.096209000000002	Центральная	0103000020E61000000100000005000000CBBBEA01F38D56405A4A9693508C4B40CBBBEA01F38D56405D8C81751C8D4B402E55698B6B8E56405D8C81751C8D4B402E55698B6B8E56405A4A9693508C4B40CBBBEA01F38D56405A4A9693508C4B40
72394	21267	89.790125000000003	89.808801000000003	54.902434	54.884441000000002	Залинейная	0103000020E6100000010000000500000021B0726891725640EB1ED95C35714B4021B0726891725640346612F582734B4037FE4465C3735640346612F582734B4037FE4465C3735640EB1ED95C35714B4021B0726891725640EB1ED95C35714B40
72334	21151	90.198049999999995	90.221226999999999	54.963878999999999	54.950319	Центральная	0103000020E61000000100000005000000423EE8D9AC8C56403BE2900DA4794B40423EE8D9AC8C56408D261763607B4B40807F4A95288E56408D261763607B4B40807F4A95288E56403BE2900DA4794B40423EE8D9AC8C56403BE2900DA4794B40
72396	21332	89.770685999999998	89.778464999999997	54.803164000000002	54.790272000000002	Мира	0103000020E610000001000000050000000B5F5FEB52715640E67805A227654B400B5F5FEB527156408BA9F413CE664B402905DD5ED27156408BA9F413CE664B402905DD5ED2715640E67805A227654B400B5F5FEB52715640E67805A227654B40
72256	21226	89.747005999999999	89.779166000000004	54.708539000000002	54.692900000000002	Центральная	0103000020E610000001000000050000009CFA40F2CE6F5640FFB27BF2B0584B409CFA40F2CE6F56406478EC67B15A4B40EE0912DBDD7156406478EC67B15A4B40EE0912DBDD715640FFB27BF2B0584B409CFA40F2CE6F5640FFB27BF2B0584B40
73505	21058	90.172923999999995	90.186965000000001	55.054862	55.046222999999998	Новая	0103000020E61000000100000005000000622CD32F118B564058A9A0A2EA854B40622CD32F118B564086E5CFB705874B40C91F0C3CF78B564086E5CFB705874B40C91F0C3CF78B564058A9A0A2EA854B40622CD32F118B564058A9A0A2EA854B40
72358	20595	89.861001999999999	89.871898999999999	55.023181000000001	55.014355000000002	Молодежная	0103000020E6100000010000000500000099F221A81A7756405DC47762D6814B4099F221A81A775640BD715298F7824B40919A7631CD775640BD715298F7824B40919A7631CD7756405DC47762D6814B4099F221A81A7756405DC47762D6814B40
73500	19391	90.992574000000005	91.004035999999999	54.468646999999997	54.458824	Трактовая	0103000020E610000001000000050000000937195586BF5640594FADBEBA3A4B400937195586BF56402B2FF99FFC3B4B406D00362042C056402B2FF99FFC3B4B406D00362042C05640594FADBEBA3A4B400937195586BF5640594FADBEBA3A4B40
72309	19336	91.153570000000002	91.174931999999998	54.45046	54.440738000000003	Молодежная	0103000020E6100000010000000500000064E94317D4C956405F0D501A6A384B4064E94317D4C95640FD135CACA8394B4087C1FC1532CB5640FD135CACA8394B4087C1FC1532CB56405F0D501A6A384B4064E94317D4C956405F0D501A6A384B40
72301	19425	91.063890999999998	91.112983999999997	54.288452999999997	54.277168000000003	Молодежная	0103000020E610000001000000050000008FE046CA16C45640B6BFB33D7A234B408FE046CA16C456406FB72407EC244B40293E3E213BC756406FB72407EC244B40293E3E213BC75640B6BFB33D7A234B408FE046CA16C45640B6BFB33D7A234B40
72379	19641	91.067888999999994	91.082539999999995	54.062528	54.052745000000002	Школьная	0103000020E6100000010000000500000085B01A4B58C4564086032159C0064B4085B01A4B58C45640CA8AE1EA00084B402827DA5548C55640CA8AE1EA00084B402827DA5548C5564086032159C0064B4085B01A4B58C4564086032159C0064B40
72383	19711	90.952203999999995	90.964133000000004	54.148769999999999	54.143444000000002	Школьная	0103000020E61000000100000005000000B4C70BE9F0BC56405A677C5F5C124B40B4C70BE9F0BC56401E5036E50A134B40A4FFE55AB4BD56401E5036E50A134B40A4FFE55AB4BD56405A677C5F5C124B40B4C70BE9F0BC56405A677C5F5C124B40
72234	19740	91.424484000000007	91.447192999999999	54.119132999999998	54.106544999999997	Школьная	0103000020E61000000100000005000000386BF0BE2ADB5640B2463D44A30D4B40386BF0BE2ADB5640EB6F09C03F0F4B40028063CF9EDC5640EB6F09C03F0F4B40028063CF9EDC5640B2463D44A30D4B40386BF0BE2ADB5640B2463D44A30D4B40
72190	18949	90.72466	90.765057999999996	54.781888000000002	54.766812000000002	Зеленая	0103000020E610000001000000050000000A2E56D460AE5640161747E526624B400A2E56D460AE56404391EEE714644B40C362D4B5F6B056404391EEE714644B40C362D4B5F6B05640161747E526624B400A2E56D460AE5640161747E526624B40
72297	20242	90.469817000000006	90.493550999999997	54.233868999999999	54.217094000000003	Зеленая	0103000020E61000000100000005000000B686527B119E5640341477BCC91B4B40B686527B119E56402C465D6BEF1D4B401EFAEE56969F56402C465D6BEF1D4B401EFAEE56969F5640341477BCC91B4B40B686527B119E5640341477BCC91B4B40
72378	19607	91.121994000000001	91.132881999999995	54.221747999999998	54.214151000000001	Зеленая	0103000020E61000000100000005000000BA13ECBFCEC75640EEB3CA4C691B4B40BA13ECBFCEC7564009FA0B3D621C4B40880E812381C8564009FA0B3D621C4B40880E812381C85640EEB3CA4C691B4B40BA13ECBFCEC75640EEB3CA4C691B4B40
72215	19067	90.767762000000005	90.799830999999998	54.592086000000002	54.577832000000001	Школьная	0103000020E6100000010000000500000024473A0323B15640884A2366F6494B4024473A0323B15640B1355B79C94B4B40EDD45C6E30B35640B1355B79C94B4B40EDD45C6E30B35640884A2366F6494B4024473A0323B15640884A2366F6494B40
72325	19819	91.263002999999998	91.278381999999993	54.096836000000003	54.089142000000002	Торговая	0103000020E61000000100000005000000FEEF880AD5D056409B594B01690B4B40FEEF880AD5D05640A9893E1F650C4B40E272BC02D1D15640A9893E1F650C4B40E272BC02D1D156409B594B01690B4B40FEEF880AD5D056409B594B01690B4B40
72391	59597	90.602112000000005	90.612900999999994	54.312337999999997	54.305382999999999	Подгорная	0103000020E61000000100000005000000DE21C50089A656408FE046CA16274B40DE21C50089A6564026A60BB1FA274B40E2AB1DC539A7564026A60BB1FA274B40E2AB1DC539A756408FE046CA16274B40DE21C50089A656408FE046CA16274B40
71957	19311	90.960127	91.016217999999995	54.374673999999999	54.345357	Дзержинского	0103000020E610000001000000050000006C4084B872BD5640EB387EA8342C4B406C4084B872BD5640AC545051F52F4B40D1E638B709C15640AC545051F52F4B40D1E638B709C15640EB387EA8342C4B406C4084B872BD5640EB387EA8342C4B40
73506	19138	90.701852000000002	90.716476999999998	54.586801000000001	54.582768000000002	Степная	0103000020E6100000010000000500000076A8A624EBAC5640E2934E24984A4B4076A8A624EBAC56404B21904B1C4B4B4084D558C2DAAD56404B21904B1C4B4B4084D558C2DAAD5640E2934E24984A4B4076A8A624EBAC5640E2934E24984A4B40
72357	20135	90.745491999999999	90.767492000000004	54.326611	54.313713999999997	Школьная	0103000020E610000001000000050000007FDB1324B6AF56400F26C5C727284B407FDB1324B6AF5640C6C1A563CE294B4044FCC3961EB15640C6C1A563CE294B4044FCC3961EB156400F26C5C727284B407FDB1324B6AF56400F26C5C727284B40
73501	19231	90.793974000000006	90.800460000000001	54.542138000000001	54.535806999999998	Горная	0103000020E61000000100000005000000F5F75278D0B25640E3FBE25295444B40F5F75278D0B256409DF529C764454B40657094BC3AB356409DF529C764454B40657094BC3AB35640E3FBE25295444B40F5F75278D0B25640E3FBE25295444B40
72158	19541	91.110028999999997	91.138451000000003	54.106081000000003	54.089607000000001	Пушкина	0103000020E61000000100000005000000242713B70AC75640103FFF3D780B4B40242713B70AC756400EDDEC0F940D4B404E469561DCC856400EDDEC0F940D4B404E469561DCC85640103FFF3D780B4B40242713B70AC75640103FFF3D780B4B40
72191	20089	90.605543999999995	90.632682000000003	54.263570999999999	54.236289999999997	Зеленая	0103000020E610000001000000050000007F129F3BC1A65640982F2FC03E1E4B407F129F3BC1A656404696CCB1BC214B4025B1A4DC7DA856404696CCB1BC214B4025B1A4DC7DA85640982F2FC03E1E4B407F129F3BC1A65640982F2FC03E1E4B40
72161	19861	90.819773999999995	90.870232000000001	54.244472000000002	54.209817999999999	Партизанская	0103000020E610000001000000050000001C075E2D77B456405A0EF450DB1A4B401C075E2D77B45640D464C6DB4A1F4B40B1FB8EE1B1B75640D464C6DB4A1F4B40B1FB8EE1B1B756405A0EF450DB1A4B401C075E2D77B456405A0EF450DB1A4B40
71971	19861	90.819773999999995	90.870232000000001	54.244472000000002	54.209817999999999	Новая	0103000020E610000001000000050000001C075E2D77B456405A0EF450DB1A4B401C075E2D77B45640D464C6DB4A1F4B40B1FB8EE1B1B75640D464C6DB4A1F4B40B1FB8EE1B1B756405A0EF450DB1A4B401C075E2D77B456405A0EF450DB1A4B40
72009	19861	90.819773999999995	90.870232000000001	54.244472000000002	54.209817999999999	50 лет Октября	0103000020E610000001000000050000001C075E2D77B456405A0EF450DB1A4B401C075E2D77B45640D464C6DB4A1F4B40B1FB8EE1B1B75640D464C6DB4A1F4B40B1FB8EE1B1B756405A0EF450DB1A4B401C075E2D77B456405A0EF450DB1A4B40
73502	20041	90.727778000000001	90.746821999999995	54.150115	54.145311	Центральная	0103000020E61000000100000005000000E42F2DEA93AE5640E15F048D99124B40E42F2DEA93AE5640CCD1E3F736134B40BB7B80EECBAF5640CCD1E3F736134B40BB7B80EECBAF5640E15F048D99124B40E42F2DEA93AE5640E15F048D99124B40
72331	19043	90.676394000000002	90.694809000000006	54.838743000000001	54.832307999999998	Центральная	0103000020E610000001000000050000007B4D0F0A4AAB56407E198C11896A4B407B4D0F0A4AAB5640DD5F3DEE5B6B4B40DBFD2AC077AC5640DD5F3DEE5B6B4B40DBFD2AC077AC56407E198C11896A4B407B4D0F0A4AAB56407E198C11896A4B40
72355	19490	91.301063999999997	91.319192000000001	54.280147999999997	54.268782000000002	Новая	0103000020E610000001000000050000003080F0A144D3564072E0D57267224B403080F0A144D356401805C1E3DB234B40454948A46DD456401805C1E3DB234B40454948A46DD4564072E0D57267224B403080F0A144D3564072E0D57267224B40
72139	59583	91.244856999999996	91.274690000000007	53.117713000000002	53.095236	Садовая	0103000020E6100000010000000500000096CCB1BCABCF564070B378B1308C4A4096CCB1BCABCF564033A83638118F4A4073A25D8594D1564033A83638118F4A4073A25D8594D1564070B378B1308C4A4096CCB1BCABCF564070B378B1308C4A40
73531	60018	90.933411000000007	90.952078	53.354111000000003	53.337656000000003	Школьная	0103000020E6100000010000000500000082AE7D01BDBB56402BA6D24F38AB4A4082AE7D01BDBB5640B2135E8253AD4A406E4F90D8EEBC5640B2135E8253AD4A406E4F90D8EEBC56402BA6D24F38AB4A4082AE7D01BDBB56402BA6D24F38AB4A40
73534	60021	90.796623999999994	90.815723000000006	53.246395999999997	53.233468000000002	Набережная	0103000020E610000001000000050000005BCD3AE3FBB25640CE548847E29D4A405BCD3AE3FBB25640BFEE74E7899F4A4015E63DCE34B45640BFEE74E7899F4A4015E63DCE34B45640CE548847E29D4A405BCD3AE3FBB25640CE548847E29D4A40
73499	18404	90.767762000000005	90.800775000000002	53.087670000000003	53.065646999999998	Кооперативная	0103000020E6100000010000000500000024473A0323B156404E0AF31E67884A4024473A0323B15640906B43C5388B4A40151DC9E53FB35640906B43C5388B4A40151DC9E53FB356404E0AF31E67884A4024473A0323B156404E0AF31E67884A40
73503	17939	90.618380999999999	90.658867999999998	53.041285000000002	53.025716000000003	Чебодаева	0103000020E61000000100000005000000F0DDE68D93A75640F27D71A94A834A40F0DDE68D93A756405E68AED348854A406118B0E42AAA56405E68AED348854A406118B0E42AAA5640F27D71A94A834A40F0DDE68D93A75640F27D71A94A834A40
72040	17826	90.697495000000004	90.728702999999996	52.965429999999998	52.918641000000001	Ленина	0103000020E61000000100000005000000E88711C2A3AC5640E3E13D0796754A40E88711C2A3AC5640E449D235937B4A40D05FE811A3AE5640E449D235937B4A40D05FE811A3AE5640E3E13D0796754A40E88711C2A3AC5640E3E13D0796754A40
72254	18524	91.154909000000004	91.193023999999994	53.100605000000002	53.076889999999999	Молодежная	0103000020E61000000100000005000000CA367007EAC95640D9B11188D7894A40CA367007EAC956403468E89FE08C4A40F5D555815ACC56403468E89FE08C4A40F5D555815ACC5640D9B11188D7894A40CA367007EAC95640D9B11188D7894A40
72186	18415	91.032674999999998	91.070340999999999	53.159114000000002	53.144700999999998	пер. Гаражный	0103000020E610000001000000050000006519E25817C256406859F78F85924A406519E25817C25640FA2AF9D85D944A4059A4897780C45640FA2AF9D85D944A4059A4897780C456406859F78F85924A406519E25817C256406859F78F85924A40
72359	18823	91.282415	91.304990000000004	53.202815000000001	53.184455999999997	Мира	0103000020E6100000010000000500000097395D1613D2564086C613419C974A4097395D1613D25640B21188D7F5994A40DAE6C6F484D35640B21188D7F5994A40DAE6C6F484D3564086C613419C974A4097395D1613D2564086C613419C974A40
72255	18738	91.492243999999999	91.524044000000004	53.170693999999997	53.158444000000003	Ленина	0103000020E61000000100000005000000BE69FAEC80DF5640AC1F9BE447944A40BE69FAEC80DF5640CCCF0D4DD9954A40906AD8EF89E15640CCCF0D4DD9954A40906AD8EF89E15640AC1F9BE447944A40BE69FAEC80DF5640AC1F9BE447944A40
73568	60037	90.419871000000001	90.435806999999997	53.013869	53.004939999999998	Школьная	0103000020E610000001000000050000007C629D2ADF9A56409B38B9DFA1804A407C629D2ADF9A5640D0B69A75C6814A408B170B43E49B5640D0B69A75C6814A408B170B43E49B56409B38B9DFA1804A407C629D2ADF9A56409B38B9DFA1804A40
72354	17633	90.426231000000001	90.471514999999997	52.844805000000001	52.837961999999997	Школьная	0103000020E61000000100000005000000A662635E479B564037A5BC56426B4A40A662635E479B5640A73FFB91226C4A40B324404D2D9E5640A73FFB91226C4A40B324404D2D9E564037A5BC56426B4A40A662635E479B564037A5BC56426B4A40
71991	59569	91.452520000000007	91.497911999999999	53.015163999999999	52.985655999999999	Советская	0103000020E610000001000000050000004D327216F6DC5640978DCEF9297E4A404D327216F6DC5640CC09DAE4F0814A404D124BCADDDF5640CC09DAE4F0814A404D124BCADDDF5640978DCEF9297E4A404D327216F6DC5640978DCEF9297E4A40
72004	59569	91.452520000000007	91.497911999999999	53.015163999999999	52.985655999999999	Победы	0103000020E610000001000000050000004D327216F6DC5640978DCEF9297E4A404D327216F6DC5640CC09DAE4F0814A404D124BCADDDF5640CC09DAE4F0814A404D124BCADDDF5640978DCEF9297E4A404D327216F6DC5640978DCEF9297E4A40
73504	18198	90.766486	90.793687000000006	53.205258000000001	53.187899000000002	Октябрьская	0103000020E61000000100000005000000E1B54B1B0EB15640BEF90D130D984A40E1B54B1B0EB15640069FE6E4459A4A40AA108FC4CBB25640069FE6E4459A4A40AA108FC4CBB25640BEF90D130D984A40E1B54B1B0EB15640BEF90D130D984A40
73512	17621	91.05153	91.087363999999994	53.027070000000002	53.018241000000003	Школьная	0103000020E61000000100000005000000D3307C444CC35640223999B855824A40D3307C444CC35640F3599E0777834A4041B62C5F97C55640F3599E0777834A4041B62C5F97C55640223999B855824A40D3307C444CC35640223999B855824A40
72371	17621	91.05153	91.087363999999994	53.027070000000002	53.018241000000003	Ленина	0103000020E61000000100000005000000D3307C444CC35640223999B855824A40D3307C444CC35640F3599E0777834A4041B62C5F97C55640F3599E0777834A4041B62C5F97C55640223999B855824A40D3307C444CC35640223999B855824A40
73528	60015	90.640776000000002	90.662954999999997	53.168501999999997	53.157255999999997	Школьная	0103000020E61000000100000005000000F303577902A95640C58CF0F620944A40F303577902A95640C1A7397991954A400FEECEDA6DAA5640C1A7397991954A400FEECEDA6DAA5640C58CF0F620944A40F303577902A95640C58CF0F620944A40
71956	18521	91.206202000000005	91.238533000000004	53.289098000000003	53.272326999999997	Октябрьская	0103000020E61000000100000005000000AB97DF6932CD5640AD68739CDBA24A40AB97DF6932CD564065ABCB2901A54A401381EA1F44CF564065ABCB2901A54A401381EA1F44CF5640AD68739CDBA24A40AB97DF6932CD5640AD68739CDBA24A40
72332	18640	91.255905999999996	91.298575999999997	53.082191000000002	53.058059999999998	Гагарина	0103000020E6100000010000000500000069368FC360D05640569A94826E874A4069368FC360D056404583143C858A4A40B6D782DE1BD356404583143C858A4A40B6D782DE1BD35640569A94826E874A4069368FC360D05640569A94826E874A40
72380	18940	91.375722999999994	91.408340999999993	53.274034	53.266285000000003	Молодежная	0103000020E61000000100000005000000B8567BD80BD856402B357BA015A24A40B8567BD80BD85640FCFECD8B13A34A406B274A4222DA5640FCFECD8B13A34A406B274A4222DA56402B357BA015A24A40B8567BD80BD856402B357BA015A24A40
72377	18128	90.982657000000003	90.994038000000003	53.003694000000003	52.989201000000001	Щетинкина	0103000020E61000000100000005000000DF8B2FDAE3BE5640D3156C239E7E4A40DF8B2FDAE3BE56408198840B79804A40CD3E8F519EBF56408198840B79804A40CD3E8F519EBF5640D3156C239E7E4A40DF8B2FDAE3BE5640D3156C239E7E4A40
73532	60019	90.819018999999997	90.839887000000004	53.000230999999999	52.982261999999999	Ленина	0103000020E610000001000000050000005EF3AACE6AB45640410DDFC2BA7D4A405EF3AACE6AB4564002B9C49107804A407A5567B5C0B5564002B9C49107804A407A5567B5C0B55640410DDFC2BA7D4A405EF3AACE6AB45640410DDFC2BA7D4A40
72039	17719	90.459325000000007	90.520779000000005	52.942058000000003	52.913634999999999	50 лет Октября	0103000020E610000001000000050000000E4FAF94659D564090BDDEFDF1744A400E4FAF94659D5640B477465B95784A40645C717154A15640B477465B95784A40645C717154A1564090BDDEFDF1744A400E4FAF94659D564090BDDEFDF1744A40
72308	17537	90.277981999999994	90.291725999999997	52.879905000000001	52.860874000000003	Октябрьская	0103000020E610000001000000050000001BB80375CA91564005FD851E316E4A401BB80375CA9156401F4B1FBAA0704A40255987A3AB9256401F4B1FBAA0704A40255987A3AB92564005FD851E316E4A401BB80375CA91564005FD851E316E4A40
73526	60013	91.267628999999999	91.281965999999997	52.981285999999997	52.970804999999999	Центральная	0103000020E61000000100000005000000849D62D520D156408AE59656437C4A40849D62D520D15640E60297C79A7D4A405F251FBB0BD25640E60297C79A7D4A405F251FBB0BD256408AE59656437C4A40849D62D520D156408AE59656437C4A40
71954	18008	90.880787999999995	90.960386999999997	53.064570000000003	53.033265999999998	Площадь Советов	0103000020E6100000010000000500000064ADA1D45EB85640CC086F0F42844A4064ADA1D45EB85640C0266BD443884A403A2009FB76BD5640C0266BD443884A403A2009FB76BD5640CC086F0F42844A4064ADA1D45EB85640CC086F0F42844A40
72251	18008	90.880787999999995	90.960386999999997	53.064570000000003	53.033265999999998	Павших партизан	0103000020E6100000010000000500000064ADA1D45EB85640CC086F0F42844A4064ADA1D45EB85640C0266BD443884A403A2009FB76BD5640C0266BD443884A403A2009FB76BD5640CC086F0F42844A4064ADA1D45EB85640CC086F0F42844A40
72188	18008	90.880787999999995	90.960386999999997	53.064570000000003	53.033265999999998	Лесная	0103000020E6100000010000000500000064ADA1D45EB85640CC086F0F42844A4064ADA1D45EB85640C0266BD443884A403A2009FB76BD5640C0266BD443884A403A2009FB76BD5640CC086F0F42844A4064ADA1D45EB85640CC086F0F42844A40
72351	17102	89.341165000000004	89.354685000000003	53.328251000000002	53.316267000000003	Центральная	0103000020E610000001000000050000008D62B9A5D5555640EBE6E26F7BA84A408D62B9A5D55556408DF0F62004AA4A406FD8B628B35656408DF0F62004AA4A406FD8B628B3565640EBE6E26F7BA84A408D62B9A5D5555640EBE6E26F7BA84A40
72150	16131	89.851696000000004	89.884161000000006	52.969628	52.95552	Тейская	0103000020E610000001000000050000009488F02F827656404356B77A4E7A4A409488F02F8276564098A432C51C7C4A4084D904189678564098A432C51C7C4A4084D90418967856404356B77A4E7A4A409488F02F827656404356B77A4E7A4A40
73529	60016	89.906510999999995	89.921961999999994	53.140146999999999	53.130536999999997	Школьная	0103000020E61000000100000005000000B69DB646047A56407FF5B86FB5904A40B69DB646047A5640F6D03E56F0914A40E789E76C017B5640F6D03E56F0914A40E789E76C017B56407FF5B86FB5904A40B69DB646047A56407FF5B86FB5904A40
71969	16404	90.685602000000003	90.724902999999998	53.357056	53.344973000000003	Мира	0103000020E610000001000000050000009F0436E7E0AB56406380441328AC4A409F0436E7E0AB5640986BD102B4AD4A406D718DCF64AE5640986BD102B4AD4A406D718DCF64AE56406380441328AC4A409F0436E7E0AB56406380441328AC4A40
72187	59585	90.237199000000004	90.258785000000003	52.965499999999999	52.943849	Советская	0103000020E6100000010000000500000036E9B6442E8F564060AE450BD0784A4036E9B6442E8F5640DD240681957B4A4081ECF5EE8F905640DD240681957B4A4081ECF5EE8F90564060AE450BD0784A4036E9B6442E8F564060AE450BD0784A40
73522	60011	90.374658999999994	90.397161999999994	53.167180000000002	53.155544999999996	Школьная	0103000020E61000000100000005000000BB09BE69FA975640350708E6E8934A40BB09BE69FA975640CC457C2766954A40B14D2A1A6B995640CC457C2766954A40B14D2A1A6B995640350708E6E8934A40BB09BE69FA975640350708E6E8934A40
72159	16432	90.595707000000004	90.617149999999995	53.393236000000002	53.382323999999997	Победы	0103000020E61000000100000005000000E4BF401020A65640EA3C2AFEEFB04A40E4BF401020A6564010CEA78E55B24A407DAEB6627FA7564010CEA78E55B24A407DAEB6627FA75640EA3C2AFEEFB04A40E4BF401020A65640EA3C2AFEEFB04A40
72242	15934	90.175968999999995	90.198858999999999	52.963183999999998	52.949747000000002	Первомайская	0103000020E6100000010000000500000007077B13438B5640B03C484F91794A4007077B13438B5640E603029D497B4A40FA60191BBA8C5640E603029D497B4A40FA60191BBA8C5640B03C484F91794A4007077B13438B5640B03C484F91794A40
72367	16102	90.029634000000001	90.049261999999999	52.941971000000002	52.926470000000002	Школьная	0103000020E6100000010000000500000061360186E5815640D15CA79196764A4061360186E5815640E563778192784A40E0BBCD1B27835640E563778192784A40E0BBCD1B27835640D15CA79196764A4061360186E5815640D15CA79196764A40
72306	17391	90.336346000000006	90.353808999999998	53.226832000000002	53.205711000000001	Школьная	0103000020E61000000100000005000000FD885FB186955640B7B6F0BC549A4A40FD885FB186955640D8D7BAD4089D4A40F30181CEA4965640D8D7BAD4089D4A40F30181CEA4965640B7B6F0BC549A4A40FD885FB186955640B7B6F0BC549A4A40
72328	17202	89.063873000000001	89.080160000000006	53.353642999999998	53.343651000000001	Октябрьская	0103000020E610000001000000050000003C86C77E164456406D1E87C1FCAB4A403C86C77E16445640CBBA7F2C44AD4A40A29C685721455640CBBA7F2C44AD4A40A29C6857214556406D1E87C1FCAB4A403C86C77E164456406D1E87C1FCAB4A40
72352	15549	90.561508000000003	90.579734999999999	53.161980999999997	53.152008000000002	Степная	0103000020E61000000100000005000000501C40BFEFA356407D5D86FF74934A40501C40BFEFA3564064C91CCBBB944A402E56D4601AA5564064C91CCBBB944A402E56D4601AA556407D5D86FF74934A40501C40BFEFA356407D5D86FF74934A40
72142	16623	89.945040000000006	89.967381000000003	53.122149999999998	53.103119	Превомайская	0103000020E610000001000000050000005C5A0D897B7C5640514CDE00338D4A405C5A0D897B7C56406B9A779CA28F4A406571FF91E97D56406B9A779CA28F4A406571FF91E97D5640514CDE00338D4A405C5A0D897B7C5640514CDE00338D4A40
72276	59589	90.704600999999997	90.723680999999999	53.248524000000003	53.232669999999999	Школьная	0103000020E61000000100000005000000A6EECA2E18AD564052616C21C89D4A40A6EECA2E18AD5640B4226AA2CF9F4A4024EF1CCA50AE5640B4226AA2CF9F4A4024EF1CCA50AE564052616C21C89D4A40A6EECA2E18AD564052616C21C89D4A40
73498	16510	90.383776999999995	90.396856	53.569716999999997	53.559866999999997	Баланкульская	0103000020E610000001000000050000003FFD67CD8F985640088ECBB8A9C74A403FFD67CD8F985640D47C957CECC84A402B4EB51666995640D47C957CECC84A402B4EB51666995640088ECBB8A9C74A403FFD67CD8F985640088ECBB8A9C74A40
72349	16609	90.024045999999998	90.066266999999996	53.233198000000002	53.212263999999998	Новая	0103000020E6100000010000000500000060E63BF8898156401F0F7D772B9B4A4060E63BF8898156400EBF9B6ED99D4A407573F1B73D8456400EBF9B6ED99D4A407573F1B73D8456401F0F7D772B9B4A4060E63BF8898156401F0F7D772B9B4A40
72348	59596	89.897212999999994	89.926516000000007	52.988636999999997	52.985405999999998	Чахсы-Хоных	0103000020E61000000100000005000000F22213F06B7956401EA4A7C8217E4A40F22213F06B795640CA4E3FA88B7E4A4021CEC3094C7B5640CA4E3FA88B7E4A4021CEC3094C7B56401EA4A7C8217E4A40F22213F06B7956401EA4A7C8217E4A40
71970	17000	89.550759999999997	89.570414999999997	53.279482999999999	53.256535999999997	Советская	0103000020E610000001000000050000007AFCDEA63F635640921FF12BD6A04A407AFCDEA63F635640DC645419C6A34A407689EAAD81645640DC645419C6A34A407689EAAD81645640921FF12BD6A04A407AFCDEA63F635640921FF12BD6A04A40
72295	16207	89.721602000000004	89.737654000000006	52.996887000000001	52.987250000000003	Тейская	0103000020E610000001000000050000009BAE27BA2E6E5640EE7C3F355E7E4A409BAE27BA2E6E56405E6743FE997F4A40DF701FB9356F56405E6743FE997F4A40DF701FB9356F5640EE7C3F355E7E4A409BAE27BA2E6E5640EE7C3F355E7E4A40
72290	17425	90.290387999999993	90.303826999999998	53.253852999999999	53.235951999999997	Солнечная	0103000020E61000000100000005000000A7C98CB79592564080B6D5AC339E4A40A7C98CB795925640E97E4E417EA04A401329CDE671935640E97E4E417EA04A401329CDE67193564080B6D5AC339E4A40A7C98CB79592564080B6D5AC339E4A40
72169	16529	90.147187000000002	90.219672000000003	53.175286999999997	53.153908999999999	Мира	0103000020E610000001000000050000005ED905836B895640B0C7444AB3934A405ED905836B895640FC34EECD6F964A4034F6251B0F8E5640FC34EECD6F964A4034F6251B0F8E5640B0C7444AB3934A405ED905836B895640B0C7444AB3934A40
71952	16935	89.509311999999994	89.537923000000006	53.467267999999997	53.437061999999997	Железнодорожная	0103000020E6100000010000000500000076DD5B91986056408429CAA5F1B74A4076DD5B9198605640D13B1570CFBB4A400A3197546D625640D13B1570CFBB4A400A3197546D6256408429CAA5F1B74A4076DD5B91986056408429CAA5F1B74A40
72153	16840	89.861639999999994	89.914416000000003	53.377161999999998	53.311114000000003	Советская	0103000020E610000001000000050000003A3B191C25775640F4A96395D2A74A403A3B191C25775640A0A52BD846B04A401BBCAFCA857A5640A0A52BD846B04A401BBCAFCA857A5640F4A96395D2A74A403A3B191C25775640F4A96395D2A74A40
71951	16840	89.861639999999994	89.914416000000003	53.377161999999998	53.311114000000003	Богдана Ховруна	0103000020E610000001000000050000003A3B191C25775640F4A96395D2A74A403A3B191C25775640A0A52BD846B04A401BBCAFCA857A5640A0A52BD846B04A401BBCAFCA857A5640F4A96395D2A74A403A3B191C25775640F4A96395D2A74A40
72305	15716	90.374767000000006	90.425332999999995	53.050629000000001	53.012466000000003	Щорса	0103000020E61000000100000005000000AF27BA2EFC975640EE27637C98814A40AF27BA2EFC975640569DD5027B864A40363AE7A7389B5640569DD5027B864A40363AE7A7389B5640EE27637C98814A40AF27BA2EFC975640EE27637C98814A40
71950	15716	90.374767000000006	90.425332999999995	53.050629000000001	53.012466000000003	Ленина	0103000020E61000000100000005000000AF27BA2EFC975640EE27637C98814A40AF27BA2EFC975640569DD5027B864A40363AE7A7389B5640569DD5027B864A40363AE7A7389B5640EE27637C98814A40AF27BA2EFC975640EE27637C98814A40
71986	15716	90.374767000000006	90.425332999999995	53.050629000000001	53.012466000000003	Абаканская	0103000020E61000000100000005000000AF27BA2EFC975640EE27637C98814A40AF27BA2EFC975640569DD5027B864A40363AE7A7389B5640569DD5027B864A40363AE7A7389B5640EE27637C98814A40AF27BA2EFC975640EE27637C98814A40
71987	17124	89.114017000000004	89.163882999999998	53.429186999999999	53.407646	переулок Почтовый	0103000020E61000000100000005000000098CF50D4C475640302C7FBE2DB44A40098CF50D4C475640266F8099EFB64A40B4571F0F7D4A5640266F8099EFB64A40B4571F0F7D4A5640302C7FBE2DB44A40098CF50D4C475640302C7FBE2DB44A40
73495	60008	90.397153000000003	90.465199999999996	53.146363999999998	53.122717999999999	Советская	0103000020E6100000010000000500000088A06AF46A995640B5503239B58F4A4088A06AF46A995640E7A7380EBC924A40598638D6C59D5640E7A7380EBC924A40598638D6C59D5640B5503239B58F4A4088A06AF46A995640B5503239B58F4A40
73494	60008	90.397153000000003	90.465199999999996	53.146363999999998	53.122717999999999	Октябрьская	0103000020E6100000010000000500000088A06AF46A995640B5503239B58F4A4088A06AF46A995640E7A7380EBC924A40598638D6C59D5640E7A7380EBC924A40598638D6C59D5640B5503239B58F4A4088A06AF46A995640B5503239B58F4A40
72353	17236	90.397153000000003	90.465199999999996	53.146363999999998	53.122717999999999	Нагорная	0103000020E6100000010000000500000088A06AF46A995640B5503239B58F4A4088A06AF46A995640E7A7380EBC924A40598638D6C59D5640E7A7380EBC924A40598638D6C59D5640B5503239B58F4A4088A06AF46A995640B5503239B58F4A40
71985	15443	90.503118000000001	90.560564999999997	53.155448	53.105649	Советская	0103000020E61000000100000005000000DA01D71533A0564074ED0BE8858D4A40DA01D71533A05640431D56B8E5934A401092054CE0A35640431D56B8E5934A401092054CE0A3564074ED0BE8858D4A40DA01D71533A0564074ED0BE8858D4A40
71949	15443	90.503118000000001	90.560564999999997	53.155448	53.105649	Промышленная	0103000020E61000000100000005000000DA01D71533A0564074ED0BE8858D4A40DA01D71533A05640431D56B8E5934A401092054CE0A35640431D56B8E5934A401092054CE0A3564074ED0BE8858D4A40DA01D71533A0564074ED0BE8858D4A40
72034	15443	90.503118000000001	90.560564999999997	53.155448	53.105649	Горького	0103000020E61000000100000005000000DA01D71533A0564074ED0BE8858D4A40DA01D71533A05640431D56B8E5934A401092054CE0A35640431D56B8E5934A401092054CE0A3564074ED0BE8858D4A40DA01D71533A0564074ED0BE8858D4A40
73527	60014	88.756693999999996	90.955995000000001	53.807381999999997	52.790294000000003	Школьная	0103000020E6100000010000000500000015C5ABAC6D305640CE1C925A28654A4015C5ABAC6D30564085B01A4B58E74A40EE08A7052FBD564085B01A4B58E74A40EE08A7052FBD5640CE1C925A28654A4015C5ABAC6D305640CE1C925A28654A40
72307	59592	90.999392	91.936092000000002	53.735050000000001	53.139223999999999	пер. Проспектный	0103000020E6100000010000000500000094F8DC09F6BF5640BE688F17D2914A4094F8DC09F6BF564060764F1E16DE4A4006836BEEE8FB564060764F1E16DE4A4006836BEEE8FB5640BE688F17D2914A4094F8DC09F6BF5640BE688F17D2914A40
72414	14960	91.357298999999998	91.387778999999995	53.38908	53.376038999999999	Алтайская	0103000020E610000001000000050000002FF99FFCDDD65640A182C30B22B04A402FF99FFCDDD656408BC3995FCDB14A40D6C4025FD1D856408BC3995FCDB14A40D6C4025FD1D85640A182C30B22B04A402FF99FFCDDD65640A182C30B22B04A40
73537	60024	91.173602000000002	91.188353000000006	53.477241999999997	53.464947000000002	Мира	0103000020E610000001000000050000004B21904B1CCB5640C9AF1F6283BB4A404B21904B1CCB564089230F4416BD4A40A0C6BDF90DCC564089230F4416BD4A40A0C6BDF90DCC5640C9AF1F6283BB4A404B21904B1CCB5640C9AF1F6283BB4A40
72151	15367	91.625265999999996	91.685597000000001	53.180236000000001	53.159503000000001	Советская	0103000020E610000001000000050000003F53AF5B04E85640944E24986A944A403F53AF5B04E85640EBC726F911974A40164F3DD2E0EB5640EBC726F911974A40164F3DD2E0EB5640944E24986A944A403F53AF5B04E85640944E24986A944A40
72230	15130	91.588040000000007	91.610938000000004	53.384929	53.372494000000003	Щетинкина	0103000020E610000001000000050000005A2F8672A2E5564066FA25E2ADAF4A405A2F8672A2E5564018247D5A45B14A408E78B29B19E7564018247D5A45B14A408E78B29B19E7564066FA25E2ADAF4A405A2F8672A2E5564066FA25E2ADAF4A40
72232	15342	91.549475999999999	91.585713999999996	53.258479999999999	53.246761999999997	Новая	0103000020E61000000100000005000000F67B629D2AE35640A1F2AFE5959F4A40F67B629D2AE35640C55565DF15A14A40CCB392567CE55640C55565DF15A14A40CCB392567CE55640A1F2AFE5959F4A40F67B629D2AE35640A1F2AFE5959F4A40
73497	15045	91.547724000000002	91.572400999999999	53.420205000000003	53.409176000000002	Центральная	0103000020E61000000100000005000000FFCEF6E80DE35640702711E15FB44A40FFCEF6E80DE35640CF4E0647C9B54A40A7CCCD37A2E45640CF4E0647C9B54A40A7CCCD37A2E45640702711E15FB44A40FFCEF6E80DE35640702711E15FB44A40
72326	14979	91.635247000000007	91.662942000000001	53.511809	53.503808999999997	Молодежная	0103000020E61000000100000005000000757808E3A7E85640193735D07CC04A40757808E3A7E85640346612F582C14A40454948A46DEA5640346612F582C14A40454948A46DEA5640193735D07CC04A40757808E3A7E85640193735D07CC04A40
72372	14873	91.354442000000006	91.38494	53.437233999999997	53.423827000000003	Строителей	0103000020E610000001000000050000000C957F2DAFD65640B61490F63FB64A400C957F2DAFD656408159A148F7B74A4006BB61DBA2D856408159A148F7B74A4006BB61DBA2D85640B61490F63FB64A400C957F2DAFD65640B61490F63FB64A40
72147	15264	91.852791999999994	91.910696999999999	53.359931000000003	53.328181000000001	Ленина	0103000020E610000001000000050000009692E52494F656409415C3D501AA4A409692E52494F6564086E8103812AE4A402EE411DC48FA564086E8103812AE4A402EE411DC48FA56409415C3D501AA4A409692E52494F656409415C3D501AA4A40
71940	14771	91.268662000000006	91.304631000000001	53.558523999999998	53.546247000000001	Ленина	0103000020E6100000010000000500000064EB19C231D15640E144F46BEBC54A4064EB19C231D15640FB03E5B67DC74A40429605137FD35640FB03E5B67DC74A40429605137FD35640E144F46BEBC54A4064EB19C231D15640E144F46BEBC54A40
73515	15068	91.553535999999994	91.571089000000001	53.330466999999999	53.322808000000002	Комсомольская	0103000020E61000000100000005000000274A42226DE356408F71C5C551A94A40274A42226DE3564020B41EBE4CAA4A40BE86E0B88CE4564020B41EBE4CAA4A40BE86E0B88CE456408F71C5C551A94A40274A42226DE356408F71C5C551A94A40
72413	15147	91.647536000000002	91.662510999999995	53.413201000000001	53.405664999999999	пер. Березовый	0103000020E61000000100000005000000E4BED53A71E95640E010AAD4ECB34A40E4BED53A71E9564056D636C5E3B44A40608F899466EA564056D636C5E3B44A40608F899466EA5640E010AAD4ECB34A40E4BED53A71E95640E010AAD4ECB34A40
72016	14482	91.345989000000003	91.411979000000002	53.620581999999999	53.579597999999997	переулок Садовый	0103000020E61000000100000005000000A6F10BAF24D65640DB696B4430CA4A40A6F10BAF24D656403E3E213B6FCF4A40E2E82ADD5DDA56403E3E213B6FCF4A40E2E82ADD5DDA5640DB696B4430CA4A40A6F10BAF24D65640DB696B4430CA4A40
71948	14482	91.345989000000003	91.411979000000002	53.620581999999999	53.579597999999997	Советская	0103000020E61000000100000005000000A6F10BAF24D65640DB696B4430CA4A40A6F10BAF24D656403E3E213B6FCF4A40E2E82ADD5DDA56403E3E213B6FCF4A40E2E82ADD5DDA5640DB696B4430CA4A40A6F10BAF24D65640DB696B4430CA4A40
71946	14482	91.345989000000003	91.411979000000002	53.620581999999999	53.579597999999997	Октябрьская	0103000020E61000000100000005000000A6F10BAF24D65640DB696B4430CA4A40A6F10BAF24D656403E3E213B6FCF4A40E2E82ADD5DDA56403E3E213B6FCF4A40E2E82ADD5DDA5640DB696B4430CA4A40A6F10BAF24D65640DB696B4430CA4A40
72032	14482	91.345989000000003	91.411979000000002	53.620581999999999	53.579597999999997	Кирова	0103000020E61000000100000005000000A6F10BAF24D65640DB696B4430CA4A40A6F10BAF24D656403E3E213B6FCF4A40E2E82ADD5DDA56403E3E213B6FCF4A40E2E82ADD5DDA5640DB696B4430CA4A40A6F10BAF24D65640DB696B4430CA4A40
72008	14482	91.345989000000003	91.411979000000002	53.620581999999999	53.579597999999997	Аткниных	0103000020E61000000100000005000000A6F10BAF24D65640DB696B4430CA4A40A6F10BAF24D656403E3E213B6FCF4A40E2E82ADD5DDA56403E3E213B6FCF4A40E2E82ADD5DDA5640DB696B4430CA4A40A6F10BAF24D65640DB696B4430CA4A40
72137	59584	91.046688000000003	91.081282999999999	53.42615	53.399850999999998	Ленина	0103000020E610000001000000050000006747AAEFFCC25640EE224C512EB34A406747AAEFFCC256405F984C158CB64A4021AE9CBD33C556405F984C158CB64A4021AE9CBD33C55640EE224C512EB34A406747AAEFFCC25640EE224C512EB34A40
73530	60017	91.793844000000007	91.819806	53.452143999999997	53.434863	Школьный переулок	0103000020E610000001000000050000000E881057CEF25640C79E3D97A9B74A400E881057CEF25640938AC6DADFB94A4022C495B377F45640938AC6DADFB94A4022C495B377F45640C79E3D97A9B74A400E881057CEF25640C79E3D97A9B74A40
73349	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Юбилейная	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72425	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Эрзинская	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72444	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Щетинкина-Кравченко	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72424	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Советская	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
73354	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Салчака Тока	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72423	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Ровенская	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72422	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Рабочая	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
73342	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Правобережная	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72441	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Оюна Курседи	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
73350	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Московская	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
73353	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Лопсанчапа	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72431	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Лермонтова	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72428	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Ленина	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72443	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Красноармейская	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72432	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Кочетова	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72438	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Колхозная	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72445	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Кечил-оола	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72433	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Калинина	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
73341	28323	94.320858999999999	94.550315999999995	51.777394000000001	51.670231999999999	Интернациональная	0103000020E6100000010000000500000025E82FF488945740C85D8429CAD5494025E82FF488945740A60D87A581E34940CB9D996038A35740A60D87A581E34940CB9D996038A35740C85D8429CAD5494025E82FF488945740C85D8429CAD54940
72421	29675	90.486517000000006	90.622477000000003	51.202716000000002	51.161861000000002	Юбилейная	0103000020E61000000100000005000000ADFC3218239F5640BABF7ADCB7944940ADFC3218239F56401F300F99F2994940C860C5A9D6A756401F300F99F2994940C860C5A9D6A75640BABF7ADCB7944940ADFC3218239F5640BABF7ADCB7944940
73362	29675	90.486517000000006	90.622477000000003	51.202716000000002	51.161861000000002	Центральная	0103000020E61000000100000005000000ADFC3218239F5640BABF7ADCB7944940ADFC3218239F56401F300F99F2994940C860C5A9D6A756401F300F99F2994940C860C5A9D6A75640BABF7ADCB7944940ADFC3218239F5640BABF7ADCB7944940
72429	29675	90.486517000000006	90.622477000000003	51.202716000000002	51.161861000000002	Ленина	0103000020E61000000100000005000000ADFC3218239F5640BABF7ADCB7944940ADFC3218239F56401F300F99F2994940C860C5A9D6A756401F300F99F2994940C860C5A9D6A75640BABF7ADCB7944940ADFC3218239F5640BABF7ADCB7944940
73337	29675	90.486517000000006	90.622477000000003	51.202716000000002	51.161861000000002	Данзырык-калдар-оола	0103000020E61000000100000005000000ADFC3218239F5640BABF7ADCB7944940ADFC3218239F56401F300F99F2994940C860C5A9D6A756401F300F99F2994940C860C5A9D6A75640BABF7ADCB7944940ADFC3218239F5640BABF7ADCB7944940
73474	5045	95.147282000000004	95.177367000000004	50.265552999999997	50.252578	С. Тока	0103000020E6100000010000000500000087527B116DC9574034D8D4795420494087527B116DC95740662D05A4FD214940F0181EFB59CB5740662D05A4FD214940F0181EFB59CB574034D8D4795420494087527B116DC9574034D8D47954204940
73391	59933	95.556985999999995	95.580324000000005	50.203854999999997	50.193482000000003	Чаа Суур	0103000020E610000001000000050000001C959BA8A5E35740AE2EA704C41849401C959BA8A5E357402310AFEB171A49405F45460724E557402310AFEB171A49405F45460724E55740AE2EA704C41849401C959BA8A5E35740AE2EA704C4184940
73414	59953	95.362689000000003	95.381545000000003	50.318537999999997	50.308793999999999	Дажимба Данил	0103000020E610000001000000050000009D67EC4B36D75740BB99D18F862749409D67EC4B36D7574041446ADAC5284940F33CB83B6BD8574041446ADAC5284940F33CB83B6BD85740BB99D18F862749409D67EC4B36D75740BB99D18F86274940
73477	5130	95.206337000000005	95.222847999999999	50.271465999999997	50.265161999999997	Галина Доваадор	0103000020E610000001000000050000001BBD1AA034CD57402B1213D4F02149401BBD1AA034CD5740EBFCDB65BF224940A8FE412443CE5740EBFCDB65BF224940A8FE412443CE57402B1213D4F02149401BBD1AA034CD57402B1213D4F0214940
73473	59995	95.095035999999993	95.117116999999993	50.303046999999999	50.294817999999999	Ленина	0103000020E6100000010000000500000054FCDF1115C65740D522A298BC25494054FCDF1115C6574051137D3ECA2649408F334DD87EC7574051137D3ECA2649408F334DD87EC75740D522A298BC25494054FCDF1115C65740D522A298BC254940
73567	60036	93.948193000000003	93.97287	51.371813000000003	51.354559999999999	Школьная	0103000020E61000000100000005000000F452B131AF7C5740213CDA3862AD4940F452B131AF7C5740249D819197AF49409C508880437E5740249D819197AF49409C508880437E5740213CDA3862AD4940F452B131AF7C5740213CDA3862AD4940
73427	59963	92.668902000000003	92.679232999999996	51.616410000000002	51.609513999999997	Маадыр-оола	0103000020E61000000100000005000000A88E554ACF2A5740213A048E04CE4940A88E554ACF2A5740B476DB85E6CE49404B57B08D782B5740B476DB85E6CE49404B57B08D782B5740213A048E04CE4940A88E554ACF2A5740213A048E04CE4940
73453	59981	91.960706000000002	91.968521999999993	51.609631999999998	51.601520999999998	Даваа Самбуу	0103000020E610000001000000050000008BC404357CFD5640B96DDFA3FECC49408BC404357CFD56402B4CDF6B08CE494037DDB243FCFD56402B4CDF6B08CE494037DDB243FCFD5640B96DDFA3FECC49408BC404357CFD5640B96DDFA3FECC4940
73480	3725	92.901638000000005	92.941658000000004	51.544283999999998	51.512861000000001	Саяно-Шушенская	0103000020E610000001000000050000002DB5DE6FB43957406A32E36DA5C149402DB5DE6FB439574037DE1D19ABC549401381EA1F443C574037DE1D19ABC549401381EA1F443C57406A32E36DA5C149402DB5DE6FB43957406A32E36DA5C14940
73347	3725	92.901638000000005	92.941658000000004	51.544283999999998	51.512861000000001	Октябрьская	0103000020E610000001000000050000002DB5DE6FB43957406A32E36DA5C149402DB5DE6FB439574037DE1D19ABC549401381EA1F443C574037DE1D19ABC549401381EA1F443C57406A32E36DA5C149402DB5DE6FB43957406A32E36DA5C14940
73467	3725	92.901638000000005	92.941658000000004	51.544283999999998	51.512861000000001	Дружба	0103000020E610000001000000050000002DB5DE6FB43957406A32E36DA5C149402DB5DE6FB439574037DE1D19ABC549401381EA1F443C574037DE1D19ABC549401381EA1F443C57406A32E36DA5C149402DB5DE6FB43957406A32E36DA5C14940
73389	4045	92.875191000000001	92.893013999999994	51.387036000000002	51.366442999999997	Школьная	0103000020E610000001000000050000003AB01C21033857408F6CAE9AE7AE49403AB01C2103385740F52F49658AB14940B037312427395740F52F49658AB14940B0373124273957408F6CAE9AE7AE49403AB01C21033857408F6CAE9AE7AE4940
73471	4397	92.325449000000006	92.347907000000006	51.521889999999999	51.507727000000003	Школьная	0103000020E6100000010000000500000005E10A28D4145740EA25C632FDC0494005E10A28D4145740020EA14ACDC249402BC3B81B44165740020EA14ACDC249402BC3B81B44165740EA25C632FDC0494005E10A28D4145740EA25C632FDC04940
73541	60026	93.115994000000001	93.151764999999997	51.568089000000001	51.559640000000002	Кускелдей	0103000020E61000000100000005000000102219726C47574048C49448A2C74940102219726C475740D21BEE23B7C849405BEB8B84B6495740D21BEE23B7C849405BEB8B84B649574048C49448A2C74940102219726C47574048C49448A2C74940
73388	59932	92.814195999999995	92.832718999999997	51.342678999999997	51.316132000000003	Советская	0103000020E610000001000000050000002D228AC91B3457400B9C6C0377A849402D228AC91B3457405303CDE7DCAB494080F0A1444B3557405303CDE7DCAB494080F0A1444B3557400B9C6C0377A849402D228AC91B3457400B9C6C0377A84940
73466	59991	92.461787000000001	92.477892999999995	51.321930000000002	51.316515000000003	Школьная	0103000020E61000000100000005000000F3AD0FEB8D1D5740C3D8429083A84940F3AD0FEB8D1D5740F7CC920035A94940307F85CC951E5740F7CC920035A94940307F85CC951E5740C3D8429083A84940F3AD0FEB8D1D5740C3D8429083A84940
73470	59993	93.329155	93.347768000000002	51.569280999999997	51.560357000000003	Барык	0103000020E61000000100000005000000271422E010555740D78A36C7B9C74940271422E010555740F99D2633DEC849401AA6B6D441565740F99D2633DEC849401AA6B6D441565740D78A36C7B9C74940271422E010555740D78A36C7B9C74940
73463	59988	92.700280000000006	92.712399000000005	51.412356000000003	51.398164000000001	Гагарина	0103000020E61000000100000005000000BF823463D12C5740E738B709F7B24940BF823463D12C57409A27D714C8B4494000ADF9F1972D57409A27D714C8B4494000ADF9F1972D5740E738B709F7B24940BF823463D12C5740E738B709F7B24940
73476	59997	92.584361999999999	92.604097999999993	51.432321999999999	51.414777000000001	Кочетова	0103000020E610000001000000050000009CC1DF2F662557400611A96917B549409CC1DF2F66255740B0ABC95356B749400E65A88AA9265740B0ABC95356B749400E65A88AA92657400611A96917B549409CC1DF2F662557400611A96917B54940
73452	59980	93.046768999999998	93.066775000000007	51.452353000000002	51.423887999999998	Айлыг-Кыйыг	0103000020E61000000100000005000000DD5D6743FE4257405B9544F641B64940DD5D6743FE425740AE9FFEB3E6B94940304CA60A46445740AE9FFEB3E6B94940304CA60A464457405B9544F641B64940DD5D6743FE4257405B9544F641B64940
73412	59951	92.190370000000001	92.234269999999995	51.411059000000002	51.375776999999999	Ленина 	0103000020E61000000100000005000000EE08A7052F0C574064CBF27519B04940EE08A7052F0C5740FDDCD0949DB44940C51B9947FE0E5740FDDCD0949DB44940C51B9947FE0E574064CBF27519B04940EE08A7052F0C574064CBF27519B04940
73447	59975	95.710543999999999	95.743331999999995	52.716712999999999	52.707051	Промышленная	0103000020E610000001000000050000009E978A8D79ED574053CDACA5805A4A409E978A8D79ED57401CCF6740BD5B4A407F8461C092EF57401CCF6740BD5B4A407F8461C092EF574053CDACA5805A4A409E978A8D79ED574053CDACA5805A4A40
72437	3402	96.111058	96.129123000000007	52.473410000000001	52.458092000000001	Советская	0103000020E61000000100000005000000637D03931B075840954737C2A23A4A40637D03931B075840B8CCE9B2983C4A40558A1D8D43085840B8CCE9B2983C4A40558A1D8D43085840954737C2A23A4A40637D03931B075840954737C2A23A4A40
73429	3402	96.111058	96.129123000000007	52.473410000000001	52.458092000000001	Енисейская	0103000020E61000000100000005000000637D03931B075840954737C2A23A4A40637D03931B075840B8CCE9B2983C4A40558A1D8D43085840B8CCE9B2983C4A40558A1D8D43085840954737C2A23A4A40637D03931B075840954737C2A23A4A40
73424	59960	95.492181000000002	95.516830999999996	52.669364999999999	52.663362999999997	Школьная 	0103000020E610000001000000050000009BADBCE47FDF57402F302B14E9544A409BADBCE47FDF5740240B98C0AD554A40C6A354C213E15740240B98C0AD554A40C6A354C213E157402F302B14E9544A409BADBCE47FDF57402F302B14E9544A40
73403	59944	94.475998000000004	99.269695999999996	53.726095999999998	51.593497999999997	Советская	0103000020E6100000010000000500000088BD50C0769E5740E61E12BEF7CB494088BD50C0769E5740D2E0B6B6F0DC4A402BF702B342D15840D2E0B6B6F0DC4A402BF702B342D15840E61E12BEF7CB494088BD50C0769E5740E61E12BEF7CB4940
73436	59968	96.233847999999995	96.252011999999993	52.453119999999998	52.444788000000003	Анчы	0103000020E610000001000000050000000A0F9A5DF70E58409ED32CD0EE384A400A0F9A5DF70E5840EE940ED6FF394A40C58CF0F620105840EE940ED6FF394A40C58CF0F6201058409ED32CD0EE384A400A0F9A5DF70E58409ED32CD0EE384A40
73699	60061	93.115094999999997	95.612493000000001	50.995496000000003	50.143520000000002	Ленина	0103000020E61000000100000005000000B83B6BB75D475740352905DD5E124940B83B6BB75D47574040A6B5696C7F4940DA01D71533E7574040A6B5696C7F4940DA01D71533E75740352905DD5E124940B83B6BB75D475740352905DD5E124940
73419	59956	95.322183999999993	95.338345000000004	50.657606999999999	50.643649000000003	Набережная	0103000020E61000000100000005000000D8D2A3A99ED45740338D261763524940D8D2A3A99ED45740724F57772C544940F870C971A7D55740724F57772C544940F870C971A7D55740338D261763524940D8D2A3A99ED45740338D261763524940
73355	3012	94.990104000000002	95.020331999999996	50.609586999999998	50.589821999999998	Кунаа	0103000020E61000000100000005000000E2E82ADD5DBF57400C3B8C497F4B4940E2E82ADD5DBF57408B8862F2064E4940FCC3961E4DC157408B8862F2064E4940FCC3961E4DC157400C3B8C497F4B4940E2E82ADD5DBF57400C3B8C497F4B4940
73716	60066	93.732444999999998	93.754328000000001	50.660181999999999	50.65249	Чооду Кежик-оола	0103000020E610000001000000050000009947FE60E06E5740C87BD5CA845349409947FE60E06E574035B401D880544940419DF2E84670574035B401D880544940419DF2E846705740C87BD5CA845349409947FE60E06E5740C87BD5CA84534940
73411	59950	93.115094999999997	95.612493000000001	50.995496000000003	50.143520000000002	Артына С.А	0103000020E61000000100000005000000B83B6BB75D475740352905DD5E124940B83B6BB75D47574040A6B5696C7F4940DA01D71533E7574040A6B5696C7F4940DA01D71533E75740352905DD5E124940B83B6BB75D475740352905DD5E124940
73399	59940	94.783535999999998	94.799741999999995	50.634062999999998	50.619	Ленина	0103000020E6100000010000000500000046CF2D7425B25740AC1C5A643B4F494046CF2D7425B25740444DF4F92851494035CF11F92EB35740444DF4F92851494035CF11F92EB35740AC1C5A643B4F494046CF2D7425B25740AC1C5A643B4F4940
73390	3355	94.607116000000005	94.626861000000005	50.520530000000001	50.512213000000003	Дружбы	0103000020E61000000100000005000000373811FDDAA6574004CB113290414940373811FDDAA657401F4B1FBAA0424940D388997D1EA857401F4B1FBAA0424940D388997D1EA8574004CB113290414940373811FDDAA6574004CB113290414940
73479	59999	97.514584999999997	97.533171999999993	50.603949999999998	50.592697999999999	Комсомольская	0103000020E61000000100000005000000C780ECF5EE605840CA332F87DD4B4940C780ECF5EE605840A835CD3B4E4D494025C9737D1F625840A835CD3B4E4D494025C9737D1F625840CA332F87DD4B4940C780ECF5EE605840CA332F87DD4B4940
73468	59992	93.466992000000005	95.468896999999998	51.592194999999997	50.731695999999999	Школьная	0103000020E6100000010000000500000098DF6932E35D5740984EEB36A85D494098DF6932E35D574067EDB60BCDCB4940520C906802DE574067EDB60BCDCB4940520C906802DE5740984EEB36A85D494098DF6932E35D5740984EEB36A85D4940
73370	4687	93.699969999999993	93.728375	51.139651999999998	51.124889000000003	Мира	0103000020E61000000100000005000000978BF84ECC6C5740A950DD5CFC8F4940978BF84ECC6C57401669E21DE0914940560E2DB29D6E57401669E21DE0914940560E2DB29D6E5740A950DD5CFC8F4940978BF84ECC6C5740A950DD5CFC8F4940
73444	59973	93.466992000000005	95.468896999999998	51.592194999999997	50.731695999999999	Туметея	0103000020E6100000010000000500000098DF6932E35D5740984EEB36A85D494098DF6932E35D574067EDB60BCDCB4940520C906802DE574067EDB60BCDCB4940520C906802DE5740984EEB36A85D494098DF6932E35D5740984EEB36A85D4940
73462	59973	93.466992000000005	95.468896999999998	51.592194999999997	50.731695999999999	Маады Парынмаа	0103000020E6100000010000000500000098DF6932E35D5740984EEB36A85D494098DF6932E35D574067EDB60BCDCB4940520C906802DE574067EDB60BCDCB4940520C906802DE5740984EEB36A85D494098DF6932E35D5740984EEB36A85D4940
73461	59987	94.240226000000007	94.254321000000004	51.24174	51.230806000000001	Оюн Сенгиижик	0103000020E610000001000000050000008869DFDC5F8F57403CDC0E0D8B9D49408869DFDC5F8F574049111956F19E4940E86B96CB4690574049111956F19E4940E86B96CB469057403CDC0E0D8B9D49408869DFDC5F8F57403CDC0E0D8B9D4940
73443	59972	94.511921999999998	94.532673000000003	51.154111	51.121254	Красных Партизан	0103000020E6100000010000000500000096067E54C3A057402D414640858F494096067E54C3A05740187AC4E8B9934940959D7E5017A25740187AC4E8B9934940959D7E5017A257402D414640858F494096067E54C3A057402D414640858F4940
73441	59971	95.218276000000003	95.236997000000002	51.008482000000001	50.999861000000003	Санаторная	0103000020E610000001000000050000001C60E63BF8CD5740DFC5FB71FB7F49401C60E63BF8CD5740664D2CF015814940021077F52ACF5740664D2CF015814940021077F52ACF5740DFC5FB71FB7F49401C60E63BF8CD5740DFC5FB71FB7F4940
73475	59996	93.666714999999996	93.701345000000003	51.132677999999999	51.113326999999998	Терешкова	0103000020E610000001000000050000002B306475AB6A57407C60C77F818E49402B306475AB6A57400873BB97FB904940A48D23D6E26C57400873BB97FB904940A48D23D6E26C57407C60C77F818E49402B306475AB6A57407C60C77F818E4940
73380	32656	93.466992000000005	95.468896999999998	51.592194999999997	50.731695999999999	Ленина	0103000020E6100000010000000500000098DF6932E35D5740984EEB36A85D494098DF6932E35D574067EDB60BCDCB4940520C906802DE574067EDB60BCDCB4940520C906802DE5740984EEB36A85D494098DF6932E35D5740984EEB36A85D4940
73425	59961	93.466992000000005	95.468896999999998	51.592194999999997	50.731695999999999	Школьная	0103000020E6100000010000000500000098DF6932E35D5740984EEB36A85D494098DF6932E35D574067EDB60BCDCB4940520C906802DE574067EDB60BCDCB4940520C906802DE5740984EEB36A85D494098DF6932E35D5740984EEB36A85D4940
73404	32675	94.050196999999997	94.073723999999999	51.351802999999997	51.336371	Ленина	0103000020E61000000100000005000000DE567A6D36835740522976340EAB4940DE567A6D368357403DD175E107AD49408A3BDEE4B78457403DD175E107AD49408A3BDEE4B7845740522976340EAB4940DE567A6D36835740522976340EAB4940
73396	59937	94.489553999999998	94.514159000000006	51.154370999999998	51.137397	Шоссейная	0103000020E6100000010000000500000010E84CDA549F5740C5C892399691494010E84CDA549F5740B439CE6DC29349406C7C26FBE7A05740B439CE6DC29349406C7C26FBE7A05740C5C892399691494010E84CDA549F5740C5C8923996914940
73445	2691	95.285343999999995	95.326010999999994	51.016261999999998	50.994782000000001	Горького 	0103000020E6100000010000000500000007077B1343D2574022533E04557F494007077B1343D2574072158BDF14824940B8C83D5DDDD4574072158BDF14824940B8C83D5DDDD4574022533E04557F494007077B1343D2574022533E04557F4940
73343	59910	95.154109000000005	95.198549	51.011032	50.984684000000001	Советская	0103000020E610000001000000050000003CC1FEEBDCC957407E7214200A7E49403CC1FEEBDCC95740D09A1F7F69814940D369DD06B5CC5740D09A1F7F69814940D369DD06B5CC57407E7214200A7E49403CC1FEEBDCC957407E7214200A7E4940
73345	2302	94.447252000000006	94.480642000000003	51.168255000000002	51.150664999999996	Советская	0103000020E610000001000000050000008544DAC69F9C57406FD39FFD489349408544DAC69F9C5740BA313D618995494061C5A9D6C29E5740BA313D618995494061C5A9D6C29E57406FD39FFD489349408544DAC69F9C57406FD39FFD48934940
73356	2095	91.252915000000002	91.296537000000001	51.409923999999997	51.392268999999999	Чолгаалчылар	0103000020E61000000100000005000000BE6A65C22FD05640081EDFDE35B24940BE6A65C22FD0564039ECBE6378B4494074435376FAD2564039ECBE6378B4494074435376FAD25640081EDFDE35B24940BE6A65C22FD05640081EDFDE35B24940
73454	59982	91.376514	91.403760000000005	51.485185999999999	51.473894000000001	Ыймажап	0103000020E610000001000000050000001D1F2DCE18D85640A4E2FF8EA8BC49401D1F2DCE18D85640103D29931ABE4940B6DB2E34D7D95640103D29931ABE4940B6DB2E34D7D95640A4E2FF8EA8BC49401D1F2DCE18D85640A4E2FF8EA8BC4940
73408	59947	91.295700999999994	91.333206000000004	51.426948000000003	51.408271999999997	Арат	0103000020E610000001000000050000003F19E3C3ECD25640AEEFC34142B449403F19E3C3ECD25640DB8B683BA6B649402F35423F53D55640DB8B683BA6B649402F35423F53D55640AEEFC34142B449403F19E3C3ECD25640AEEFC34142B44940
73420	59957	91.458072000000001	91.492988999999994	51.573065999999997	51.560872000000003	Мурзууна	0103000020E61000000100000005000000A7CD380D51DD5640FE9E58A7CAC74940A7CD380D51DD56408A39083A5AC949406A12BC218DDF56408A39083A5AC949406A12BC218DDF5640FE9E58A7CAC74940A7CD380D51DD5640FE9E58A7CAC74940
73416	59954	91.129136000000003	91.163910000000001	51.407429	51.400928999999998	Найырал	0103000020E610000001000000050000001F2FA4C343C856404D8237A451B349401F2FA4C343C8564093382BA226B44940315F5E807DCA564093382BA226B44940315F5E807DCA56404D8237A451B349401F2FA4C343C856404D8237A451B34940
73482	60001	91.425139999999999	91.437895999999995	51.469805000000001	51.435746999999999	Самбуу	0103000020E610000001000000050000002C0E677E35DB5640412AC58EC6B749402C0E677E35DB5640A73FFB9122BC494026C3F17C06DC5640A73FFB9122BC494026C3F17C06DC5640412AC58EC6B749402C0E677E35DB5640412AC58EC6B74940
73367	32570	90.957279	90.983923000000004	51.302061999999999	51.291091000000002	Самбажык	0103000020E610000001000000050000007289230F44BD564079944A7842A549407289230F44BD5640A3AEB5F7A9A6494010B22C98F8BE5640A3AEB5F7A9A6494010B22C98F8BE564079944A7842A549407289230F44BD564079944A7842A54940
73459	59985	91.115921999999998	91.135594999999995	51.344068	51.332016000000003	Найырал	0103000020E61000000100000005000000C3B81B446BC75640D7DF12807FAA4940C3B81B446BC75640D1CC936B0AAC494012A0A696ADC85640D1CC936B0AAC494012A0A696ADC85640D7DF12807FAA4940C3B81B446BC75640D7DF12807FAA4940
73410	59949	94.204239999999999	94.217884999999995	51.658529000000001	51.647018000000003	Школьная	0103000020E610000001000000050000003E22A644128D574030F65E7CD1D249403E22A644128D5740DA3BA3AD4AD449407E52EDD3F18D5740DA3BA3AD4AD449407E52EDD3F18D574030F65E7CD1D249403E22A644128D574030F65E7CD1D24940
73439	1790	93.705934999999997	93.728672000000003	52.243848	52.229337999999998	Первомайская	0103000020E610000001000000050000008386FE092E6D574072DD94F25A1D4A408386FE092E6D5740F6984869361F4A40B360E28FA26E5740F6984869361F4A40B360E28FA26E574072DD94F25A1D4A408386FE092E6D574072DD94F25A1D4A40
73483	60002	92.886707999999999	95.072794000000002	52.914459999999998	51.552097000000003	Новая	0103000020E610000001000000050000008046E9D2BF385740209C4F1DABC649408046E9D2BF38574005C078060D754A4015562AA8A8C4574005C078060D754A4015562AA8A8C45740209C4F1DABC649408046E9D2BF385740209C4F1DABC64940
73392	59934	94.013437999999994	94.046126999999998	52.081142	52.073686000000002	Беспалова 	0103000020E6100000010000000500000083A10E2BDC8057402716F88A6E094A4083A10E2BDC805740802A6EDC620A4A409B1DA9BEF3825740802A6EDC620A4A409B1DA9BEF38257402716F88A6E094A4083A10E2BDC8057402716F88A6E094A40
72434	1113	93.901696000000001	93.932023000000001	52.162205	52.128028999999998	Советская	0103000020E61000000100000005000000C7BB2363B579574044F8174163104A40C7BB2363B5795740B41F2922C3144A40AB07CC43A67B5740B41F2922C3144A40AB07CC43A67B574044F8174163104A40C7BB2363B579574044F8174163104A40
72436	1113	93.901696000000001	93.932023000000001	52.162205	52.128028999999998	Комсомольская	0103000020E61000000100000005000000C7BB2363B579574044F8174163104A40C7BB2363B5795740B41F2922C3144A40AB07CC43A67B5740B41F2922C3144A40AB07CC43A67B574044F8174163104A40C7BB2363B579574044F8174163104A40
73366	1113	93.901696000000001	93.932023000000001	52.162205	52.128028999999998	30 лет Тувы	0103000020E61000000100000005000000C7BB2363B579574044F8174163104A40C7BB2363B5795740B41F2922C3144A40AB07CC43A67B5740B41F2922C3144A40AB07CC43A67B574044F8174163104A40C7BB2363B579574044F8174163104A40
73451	59979	93.403176000000002	93.416066999999998	52.071255999999998	52.063217000000002	Школьный	0103000020E610000001000000050000000EA2B5A2CD5957408FC6A17E17084A400EA2B5A2CD59574067D2A6EA1E094A40787C7BD7A05A574067D2A6EA1E094A40787C7BD7A05A57408FC6A17E17084A400EA2B5A2CD5957408FC6A17E17084A40
73448	59976	94.158479999999997	94.180335999999997	52.064861999999998	52.060155999999999	Зеленая	0103000020E610000001000000050000007C444C89248A57403F541A31B3074A407C444C89248A57406760E4654D084A40A79201A08A8B57406760E4654D084A40A79201A08A8B57403F541A31B3074A407C444C89248A57403F541A31B3074A40
73413	59952	92.886707999999999	95.072794000000002	52.914459999999998	51.552097000000003	Мандараа	0103000020E610000001000000050000008046E9D2BF385740209C4F1DABC649408046E9D2BF38574005C078060D754A4015562AA8A8C4574005C078060D754A4015562AA8A8C45740209C4F1DABC649408046E9D2BF385740209C4F1DABC64940
73469	1886	93.936819999999997	93.948705000000004	52.156658	52.141472999999998	Площадь Победы	0103000020E61000000100000005000000478FDFDBF47B57402D228AC91B124A40478FDFDBF47B574011548D5E0D144A404F232D95B77C574011548D5E0D144A404F232D95B77C57402D228AC91B124A40478FDFDBF47B57402D228AC91B124A40
73377	59922	93.593762999999996	93.616759999999999	52.065316000000003	52.054268999999998	Советская	0103000020E61000000100000005000000CAA4863600665740E3175E49F2064A40CAA4863600665740E9F351465C084A40C85EEFFE78675740E9F351465C084A40C85EEFFE78675740E3175E49F2064A40CAA4863600665740E3175E49F2064A40
73433	789	90.644790999999998	93.384041999999994	51.117097999999999	50.314978000000004	Мезил-оола	0103000020E610000001000000050000005470784144A95640D17AF832512849405470784144A95640A8363811FD8E49409692E52494585740A8363811FD8E49409692E52494585740D17AF832512849405470784144A95640D17AF83251284940
73346	914	92.069654	92.089183000000006	50.738480000000003	50.727699999999999	Школьный переулок	0103000020E6100000010000000500000047020D36750457404CA60A46255D494047020D367504574003603C83865E4940FD169D2CB505574003603C83865E4940FD169D2CB50557404CA60A46255D494047020D36750457404CA60A46255D4940
73422	988	90.644790999999998	93.384041999999994	51.117097999999999	50.314978000000004	Дамдын	0103000020E610000001000000050000005470784144A95640D17AF832512849405470784144A95640A8363811FD8E49409692E52494585740A8363811FD8E49409692E52494585740D17AF832512849405470784144A95640D17AF83251284940
73435	1015	91.310873999999998	91.339431000000005	50.497100000000003	50.491106000000002	Чанчы-Хоо	0103000020E610000001000000050000004FCB0F5CE5D35640486FB88FDC3E49404FCB0F5CE5D35640BA6B09F9A03F4940E90FCD3CB9D55640BA6B09F9A03F4940E90FCD3CB9D55640486FB88FDC3E49404FCB0F5CE5D35640486FB88FDC3E4940
73456	849	92.675010999999998	92.685045000000002	50.819856999999999	50.807524000000001	Мунзук Севен-оола	0103000020E610000001000000050000002D5C5661332B5740185E49F25C6749402D5C5661332B5740C632FD12F168494074D2FBC6D72B5740C632FD12F168494074D2FBC6D72B5740185E49F25C6749402D5C5661332B5740185E49F25C674940
73418	730	93.230941999999999	93.243779000000004	50.700808000000002	50.694892000000003	Ирбитей	0103000020E610000001000000050000007651F4C0C74E574043209738F25849407651F4C0C74E574039639813B4594940E71C3C139A4F574039639813B4594940E71C3C139A4F574043209738F25849407651F4C0C74E574043209738F2584940
73365	542	90.430713999999995	90.457042999999999	50.384590000000003	50.376531	Саны-Шири	0103000020E610000001000000050000007AFB73D1909B56401077F52A323049407AFB73D1909B5640302FC03E3A31494068774831409D5640302FC03E3A31494068774831409D56401077F52A323049407AFB73D1909B56401077F52A32304940
73358	542	90.430713999999995	90.457042999999999	50.384590000000003	50.376531	Кошкар-оола	0103000020E610000001000000050000007AFB73D1909B56401077F52A323049407AFB73D1909B5640302FC03E3A31494068774831409D5640302FC03E3A31494068774831409D56401077F52A323049407AFB73D1909B56401077F52A32304940
73423	59959	89.866607999999999	89.870622999999995	50.048026	50.044504000000003	Кечил	0103000020E61000000100000005000000ED9C66817677564046459C4EB2054940ED9C668176775640C9AD49B7250649404E098849B8775640C9AD49B7250649404E098849B877564046459C4EB2054940ED9C66817677564046459C4EB2054940
73432	59967	95.077743999999996	95.097577999999999	51.248128000000001	51.235464	40 лет Сов. Тувы	0103000020E61000000100000005000000745DF8C1F9C4574053B131AF239E4940745DF8C1F9C45740679C86A8C29F4940C8B3CBB73EC65740679C86A8C29F4940C8B3CBB73EC6574053B131AF239E4940745DF8C1F9C4574053B131AF239E4940
73409	59948	94.574264999999997	94.607988000000006	51.893028000000001	51.880015	Школьная	0103000020E61000000100000005000000328FFCC1C0A45740A67EDE54A4F04940328FFCC1C0A45740C634D3BD4EF2494012178046E9A65740C634D3BD4EF2494012178046E9A65740A67EDE54A4F04940328FFCC1C0A45740A67EDE54A4F04940
73375	59921	94.795249999999996	94.815174999999996	51.337918999999999	51.322172000000002	Кужугет Серена	0103000020E6100000010000000500000037894160E5B25740EDD79DEE3CA9494037894160E5B2574038D906EE40AB49401361C3D32BB4574038D906EE40AB49401361C3D32BB45740EDD79DEE3CA9494037894160E5B25740EDD79DEE3CA94940
73395	59936	94.068612000000002	94.109836000000001	51.568821999999997	51.559936999999998	Горная	0103000020E610000001000000050000003E079623648457400169FF03ACC749403E07962364845740669FC728CFC849401AFB928D07875740669FC728CFC849401AFB928D078757400169FF03ACC749403E079623648457400169FF03ACC74940
73478	59998	93.518806999999995	93.527557000000002	51.715381000000001	51.698152	Энтузиастов	0103000020E61000000100000005000000E57B46223461574089D1730B5DD94940E57B4622346157400397C79A91DB4940A8716F7EC36157400397C79A91DB4940A8716F7EC361574089D1730B5DD94940E57B46223461574089D1730B5DD94940
73352	33070	94.247152	94.281576000000001	51.652774000000001	51.633519999999997	Фрунзе	0103000020E6100000010000000500000006499F56D18F574053AEF02E17D1494006499F56D18F5740EDD632198ED34940AAD5575705925740EDD632198ED34940AAD557570592574053AEF02E17D1494006499F56D18F574053AEF02E17D14940
73406	33070	94.247152	94.281576000000001	51.652774000000001	51.633519999999997	Геологов	0103000020E6100000010000000500000006499F56D18F574053AEF02E17D1494006499F56D18F5740EDD632198ED34940AAD5575705925740EDD632198ED34940AAD557570592574053AEF02E17D1494006499F56D18F574053AEF02E17D14940
73381	59925	97.514584999999997	97.533171999999993	50.603949999999998	50.592697999999999	Дружба	0103000020E61000000100000005000000C780ECF5EE605840CA332F87DD4B4940C780ECF5EE605840A835CD3B4E4D494025C9737D1F625840A835CD3B4E4D494025C9737D1F625840CA332F87DD4B4940C780ECF5EE605840CA332F87DD4B4940
73372	59919	94.448437999999996	94.469044999999994	51.897824	51.883740000000003	Механизаторская	0103000020E6100000010000000500000027124C35B39C574062156F641EF1494027124C35B39C57402EC896E5EBF249408CD651D5049E57402EC896E5EBF249408CD651D5049E574062156F641EF1494027124C35B39C574062156F641EF14940
72442	32233	94.544881000000004	94.618471	51.704923000000001	51.673488999999996	пер.Чооду Кидиспея	0103000020E610000001000000050000008ECD8E54DFA257409D9B36E334D649408ECD8E54DFA257405F99B7EA3ADA494090A1630795A757405F99B7EA3ADA494090A1630795A757409D9B36E334D649408ECD8E54DFA257409D9B36E334D64940
72426	32233	94.544881000000004	94.618471	51.704923000000001	51.673488999999996	Таежная	0103000020E610000001000000050000008ECD8E54DFA257409D9B36E334D649408ECD8E54DFA257405F99B7EA3ADA494090A1630795A757405F99B7EA3ADA494090A1630795A757409D9B36E334D649408ECD8E54DFA257409D9B36E334D64940
73357	32233	94.544881000000004	94.618471	51.704923000000001	51.673488999999996	Народная	0103000020E610000001000000050000008ECD8E54DFA257409D9B36E334D649408ECD8E54DFA257405F99B7EA3ADA494090A1630795A757405F99B7EA3ADA494090A1630795A757409D9B36E334D649408ECD8E54DFA257409D9B36E334D64940
73398	59939	93.527422000000001	93.573362000000003	51.590141000000003	51.574185	Базыр Тулуш	0103000020E61000000100000005000000384C3448C1615740486DE2E47EC94940384C3448C1615740AE8383BD89CB49403AB187F6B1645740AE8383BD89CB49403AB187F6B1645740486DE2E47EC94940384C3448C1615740486DE2E47EC94940
73457	59984	95.923022000000003	95.938823999999997	51.340141000000003	51.334226999999998	Центральная	0103000020E6100000010000000500000044DFDDCA12FB5740583849F3C7AA494044DFDDCA12FB5740AE8383BD89AB4940CB2C42B115FC5740AE8383BD89AB4940CB2C42B115FC5740583849F3C7AA494044DFDDCA12FB5740583849F3C7AA4940
73455	59983	96.243002000000004	96.253647000000001	51.340113000000002	51.329887999999997	Набережная	0103000020E6100000010000000500000035B742588D0F5840E2AB1DC539AA494035B742588D0F5840E4F8A1D288AB4940A06EA0C03B105840E4F8A1D288AB4940A06EA0C03B105840E2AB1DC539AA494035B742588D0F5840E2AB1DC539AA4940
73431	59966	94.658795999999995	98.950497999999996	52.290871000000003	50.464995999999999	Красных партизан	0103000020E6100000010000000500000014AFB2B629AA5740AA622AFD843B494014AFB2B629AA57406B2DCC423B254A40753A90F5D4BC58406B2DCC423B254A40753A90F5D4BC5840AA622AFD843B494014AFB2B629AA5740AA622AFD843B4940
73400	59941	94.843005000000005	94.868714999999995	51.660853000000003	51.646034	Валентина Хажики	0103000020E6100000010000000500000054573ECBF3B55740520DFB3DB1D2494054573ECBF3B55740543BC3D496D44940DBA2CC0699B75740543BC3D496D44940DBA2CC0699B75740520DFB3DB1D2494054573ECBF3B55740520DFB3DB1D24940
73450	59978	95.937349999999995	95.947888000000006	51.322279000000002	51.312421999999998	Центральная	0103000020E61000000100000005000000F5B9DA8AFDFB57408446B071FDA74940F5B9DA8AFDFB57400398327040A9494056116E32AAFC57400398327040A9494056116E32AAFC57408446B071FDA74940F5B9DA8AFDFB57408446B071FDA74940
73361	59916	94.658795999999995	98.950497999999996	52.290871000000003	50.464995999999999	Енисейская	0103000020E6100000010000000500000014AFB2B629AA5740AA622AFD843B494014AFB2B629AA57406B2DCC423B254A40753A90F5D4BC58406B2DCC423B254A40753A90F5D4BC5840AA622AFD843B494014AFB2B629AA5740AA622AFD843B4940
73379	59924	94.658795999999995	98.950497999999996	52.290871000000003	50.464995999999999	Центральная	0103000020E6100000010000000500000014AFB2B629AA5740AA622AFD843B494014AFB2B629AA57406B2DCC423B254A40753A90F5D4BC58406B2DCC423B254A40753A90F5D4BC5840AA622AFD843B494014AFB2B629AA5740AA622AFD843B4940
73484	60003	95.469014000000001	95.505018000000007	51.517710000000001	51.505456000000002	Центральная	0103000020E610000001000000050000006FD74B5304DE574093C83EC8B2C049406FD74B5304DE5740F5673F5244C249400C79043752E05740F5673F5244C249400C79043752E0574093C83EC8B2C049406FD74B5304DE574093C83EC8B2C04940
73376	33020	95.462644999999995	95.499403999999998	51.127664000000003	51.106828999999998	Мира	0103000020E610000001000000050000001B2AC6F99BDD5740D7A19A92AC8D49401B2AC6F99BDD57403370404B5790494076DF313CF6DF57403370404B5790494076DF313CF6DF5740D7A19A92AC8D49401B2AC6F99BDD5740D7A19A92AC8D4940
73393	59935	94.658795999999995	98.950497999999996	52.290871000000003	50.464995999999999	Магистральная	0103000020E6100000010000000500000014AFB2B629AA5740AA622AFD843B494014AFB2B629AA57406B2DCC423B254A40753A90F5D4BC58406B2DCC423B254A40753A90F5D4BC5840AA622AFD843B494014AFB2B629AA5740AA622AFD843B4940
73386	59930	94.658795999999995	98.950497999999996	52.290871000000003	50.464995999999999	Енисейская	0103000020E6100000010000000500000014AFB2B629AA5740AA622AFD843B494014AFB2B629AA57406B2DCC423B254A40753A90F5D4BC58406B2DCC423B254A40753A90F5D4BC5840AA622AFD843B494014AFB2B629AA5740AA622AFD843B4940
73437	59969	95.545613000000003	95.564406000000005	51.251167000000002	51.237623999999997	Ленина	0103000020E6100000010000000500000070D1C952EBE25740525F96766A9E494070D1C952EBE25740CF6A813D26A04940A3EA573A1FE45740CF6A813D26A04940A3EA573A1FE45740525F96766A9E494070D1C952EBE25740525F96766A9E4940
73460	59986	95.340106000000006	95.363561000000004	51.545673000000001	51.531320999999998	Гагарина	0103000020E6100000010000000500000019CBF44BC4D55740C956975302C4494019CBF44BC4D55740B5A7E49CD8C5494078465B9544D75740B5A7E49CD8C5494078465B9544D75740C956975302C4494019CBF44BC4D55740C956975302C44940
73472	59994	95.588059000000001	95.598713000000004	51.324412000000002	51.317219000000001	Юбилейная	0103000020E61000000100000005000000954737C2A2E55740BD55D7A19AA84940954737C2A2E557400937195586A949402AAC545051E657400937195586A949402AAC545051E65740BD55D7A19AA84940954737C2A2E55740BD55D7A19AA84940
73348	59912	95.530574999999999	95.585130000000007	51.505524000000001	51.476115999999998	пер.Первомайский	0103000020E61000000100000005000000D044D8F0F4E15740198D7C5EF1BC4940D044D8F0F4E15740EBABAB02B5C04940257A19C572E55740EBABAB02B5C04940257A19C572E55740198D7C5EF1BC4940D044D8F0F4E15740198D7C5EF1BC4940
73543	60027	91.580584000000002	91.604281999999998	51.588344999999997	51.573838000000002	Ленина	0103000020E610000001000000050000002D25CB4928E55640DD99098673C949402D25CB4928E55640EFE192E34ECB4940EFE3688EACE65640EFE192E34ECB4940EFE3688EACE65640DD99098673C949402D25CB4928E55640DD99098673C94940
73465	59990	91.099356999999998	91.113083000000003	50.871043	50.867421999999998	Ленина	0103000020E610000001000000050000003C6876DD5BC656405BEA20AF076F49403C6876DD5BC65640723447567E6F4940F3AE7AC03CC75640723447567E6F4940F3AE7AC03CC756405BEA20AF076F49403C6876DD5BC656405BEA20AF076F4940
73371	59918	91.283654999999996	91.299861000000007	51.166328999999998	51.148116999999999	Найырал	0103000020E6100000010000000500000033164D6727D25640A67D737FF592494033164D6727D256402DB0C7444A954940231631EC30D356402DB0C7444A954940231631EC30D35640A67D737FF592494033164D6727D25640A67D737FF5924940
73440	59970	91.000955000000005	91.010324999999995	51.073858999999999	51.057789	Ийистер	0103000020E6100000010000000500000022718FA50FC05640C68844A16587494022718FA50FC05640F4C13236748949403255302AA9C05640F4C13236748949403255302AA9C05640C68844A16587494022718FA50FC05640C68844A165874940
73397	59938	91.047460999999998	91.059364000000002	51.179549000000002	51.162647	Ленина	0103000020E6100000010000000500000078B5DC9909C3564071E5EC9DD194494078B5DC9909C35640C7832D76FB964940D3A3A99ECCC35640C7832D76FB964940D3A3A99ECCC3564071E5EC9DD194494078B5DC9909C3564071E5EC9DD1944940
72430	30824	91.526478999999995	91.608575999999999	51.308228	51.274309000000002	Сельская	0103000020E61000000100000005000000F8C1F9D4B1E15640CEFFAB8E1CA34940F8C1F9D4B1E1564012DBDD0374A749405A48C0E8F2E6564012DBDD0374A749405A48C0E8F2E65640CEFFAB8E1CA34940F8C1F9D4B1E15640CEFFAB8E1CA34940
72427	30824	91.526478999999995	91.608575999999999	51.308228	51.274309000000002	Победы	0103000020E61000000100000005000000F8C1F9D4B1E15640CEFFAB8E1CA34940F8C1F9D4B1E1564012DBDD0374A749405A48C0E8F2E6564012DBDD0374A749405A48C0E8F2E65640CEFFAB8E1CA34940F8C1F9D4B1E15640CEFFAB8E1CA34940
73360	30824	91.526478999999995	91.608575999999999	51.308228	51.274309000000002	Ленина	0103000020E61000000100000005000000F8C1F9D4B1E15640CEFFAB8E1CA34940F8C1F9D4B1E1564012DBDD0374A749405A48C0E8F2E6564012DBDD0374A749405A48C0E8F2E65640CEFFAB8E1CA34940F8C1F9D4B1E15640CEFFAB8E1CA34940
73421	59958	91.039439000000002	91.057540000000003	51.286022000000003	51.277098000000002	Ховалыг Оюу	0103000020E61000000100000005000000F7CB272B86C25640BDE47FF277A34940F7CB272B86C25640E0F76F5E9CA449408F8D40BCAEC35640E0F76F5E9CA449408F8D40BCAEC35640BDE47FF277A34940F7CB272B86C25640BDE47FF277A34940
73430	59965	91.609806000000006	91.629165	51.132559000000001	51.120337999999997	Октябрьская	0103000020E61000000100000005000000E5B9BE0F07E75640A73B4F3C678F4940E5B9BE0F07E756402EE57CB1F79049406CB2463D44E856402EE57CB1F79049406CB2463D44E85640A73B4F3C678F4940E5B9BE0F07E75640A73B4F3C678F4940
73449	59977	91.547597999999994	91.569875999999994	51.301527	51.290629000000003	Данзы-Белек	0103000020E61000000100000005000000B8567BD80BE356407522C15433A54940B8567BD80BE3564035EECD6F98A649409EB12FD978E4564035EECD6F98A649409EB12FD978E456407522C15433A54940B8567BD80BE356407522C15433A54940
73368	59917	91.441264000000004	91.461664999999996	51.371498000000003	51.360942999999999	Садовая	0103000020E61000000100000005000000BD395CAB3DDC56402D5C566133AE4940BD395CAB3DDC5640C443183F8DAF49404D2D5BEB8BDD5640C443183F8DAF49404D2D5BEB8BDD56402D5C566133AE4940BD395CAB3DDC56402D5C566133AE4940
73382	59926	91.719149000000002	91.746431000000001	51.236485000000002	51.224623999999999	Карла Маркса	0103000020E61000000100000005000000DFFC868906EE5640C7F2AE7AC09C4940DFFC868906EE56404E7FF623459E49401E6E8786C5EF56404E7FF623459E49401E6E8786C5EF5640C7F2AE7AC09C4940DFFC868906EE5640C7F2AE7AC09C4940
73364	30767	90.392571000000004	90.417652000000004	50.941234999999999	50.927242999999997	Самбу	0103000020E61000000100000005000000EA961DE21F995640F3380CE6AF764940EA961DE21F995640DF6C73637A784940FA4674CFBA9A5640DF6C73637A784940FA4674CFBA9A5640F3380CE6AF764940EA961DE21F995640F3380CE6AF764940
73363	30668	89.653993999999997	91.132396999999997	51.811394999999997	50.537295	Октябрьская	0103000020E61000000100000005000000EF71A609DB695640F4A62215C6444940EF71A609DB695640A79196CADBE74940AA45443179C85640A79196CADBE74940AA45443179C85640F4A62215C6444940EF71A609DB695640F4A62215C6444940
73434	30671	90.291475000000005	90.318378999999993	51.258986	51.249831	Чургуй-оол	0103000020E610000001000000050000008126C286A792564074435376FA9F49408126C286A7925640990F087426A14940EC2E505260945640990F087426A14940EC2E50526094564074435376FA9F49408126C286A792564074435376FA9F4940
73338	30265	89.653993999999997	91.132396999999997	51.811394999999997	50.537295	Чургуй-оол	0103000020E61000000100000005000000EF71A609DB695640F4A62215C6444940EF71A609DB695640A79196CADBE74940AA45443179C85640A79196CADBE74940AA45443179C85640F4A62215C6444940EF71A609DB695640F4A62215C6444940
73339	30265	89.653993999999997	91.132396999999997	51.811394999999997	50.537295	Авиация	0103000020E61000000100000005000000EF71A609DB695640F4A62215C6444940EF71A609DB695640A79196CADBE74940AA45443179C85640A79196CADBE74940AA45443179C85640F4A62215C6444940EF71A609DB695640F4A62215C6444940
73442	30589	90.695762000000002	90.719082	51.222610000000003	51.209493000000002	Набережная	0103000020E610000001000000050000002CF3565D87AC5640D7DEA7AAD09A49402CF3565D87AC56409CE1067C7E9C49401B49827005AE56409CE1067C7E9C49401B49827005AE5640D7DEA7AAD09A49402CF3565D87AC5640D7DEA7AAD09A4940
73446	59974	90.629277000000002	90.643561000000005	51.108752000000003	51.096761999999998	Ленина	0103000020E6100000010000000500000000C8091346A856406EBF7CB2628C494000C8091346A85640F3AFE595EB8D4940CAFE791A30A95640F3AFE595EB8D4940CAFE791A30A956406EBF7CB2628C494000C8091346A856406EBF7CB2628C4940
73415	30513	90.523240000000001	90.548356999999996	51.143149999999999	51.129551999999997	Октябрьская	0103000020E6100000010000000500000061FD9FC37CA15640D190F1289590494061FD9FC37CA1564011363CBD529249401762F54718A3564011363CBD529249401762F54718A35640D190F1289590494061FD9FC37CA15640D190F12895904940
73458	30450	90.837003999999993	90.851044000000002	51.000258000000002	50.986781999999998	М. Чыргала	0103000020E61000000100000005000000C1A7397991B55640072461DF4E7E4940C1A7397991B55640FCC742740880494040DD408177B65640FCC742740880494040DD408177B65640072461DF4E7E4940C1A7397991B55640072461DF4E7E4940
73374	30407	89.653993999999997	91.132396999999997	51.811394999999997	50.537295	Культура	0103000020E61000000100000005000000EF71A609DB695640F4A62215C6444940EF71A609DB695640A79196CADBE74940AA45443179C85640A79196CADBE74940AA45443179C85640F4A62215C6444940EF71A609DB695640F4A62215C6444940
73384	59928	90.333408000000006	90.347196999999994	50.897620000000003	50.878028	Нордуп	0103000020E61000000100000005000000630E828E56955640747CB43863704940630E828E56955640261E5036E57249403C11C47938965640261E5036E57249403C11C47938965640747CB43863704940630E828E56955640747CB43863704940
73428	59964	90.182661999999993	90.196999000000005	51.023090000000003	51.014170999999997	Чудурукпай	0103000020E61000000100000005000000340EF5BBB08B56409BC6F65AD0814940340EF5BBB08B5640AD6EF59CF48249401096B1A19B8C5640AD6EF59CF48249401096B1A19B8C56409BC6F65AD0814940340EF5BBB08B56409BC6F65AD0814940
73336	29972	88.800693999999993	90.571191999999996	51.657299999999999	50.488900000000001	Ленина	0103000020E610000001000000050000009E060C923E335640D8817346943E49409E060C923E33564095D4096822D4494028EFE3688EA4564095D4096822D4494028EFE3688EA45640D8817346943E49409E060C923E335640D8817346943E4940
73402	59943	90.101301000000007	90.113752000000005	51.046154000000001	51.034905999999999	Ховалыг Сайын-оол	0103000020E61000000100000005000000568330B77B8656409337C0CC77844940568330B77B865640304AD05FE8854940B2F677B647875640304AD05FE8854940B2F677B6478756409337C0CC77844940568330B77B8656409337C0CC77844940
73383	59927	88.800693999999993	90.571191999999996	51.657299999999999	50.488900000000001	Монгуш Эдуард	0103000020E610000001000000050000009E060C923E335640D8817346943E49409E060C923E33564095D4096822D4494028EFE3688EA4564095D4096822D4494028EFE3688EA45640D8817346943E49409E060C923E335640D8817346943E4940
73438	2020	90.218378999999999	90.232293999999996	51.010832999999998	51.002706000000003	Хараар-Тей	0103000020E6100000010000000500000086C8E9EBF98D564062C092AB5880494086C8E9EBF98D5640D95BCAF962814940A643A7E7DD8E5640D95BCAF962814940A643A7E7DD8E564062C092AB5880494086C8E9EBF98D564062C092AB58804940
73373	59920	88.800693999999993	90.571191999999996	51.657299999999999	50.488900000000001	Мира	0103000020E610000001000000050000009E060C923E335640D8817346943E49409E060C923E33564095D4096822D4494028EFE3688EA4564095D4096822D4494028EFE3688EA45640D8817346943E49409E060C923E335640D8817346943E4940
73378	59923	88.791809000000001	99.273622000000003	53.729601000000002	49.743535000000001	Коп-Соок	0103000020E610000001000000050000006CEBA7FFAC3256403737A6272CDF48406CEBA7FFAC3256408010C99063DD4A40D55DD90583D158408010C99063DD4A40D55DD90583D158403737A6272CDF48406CEBA7FFAC3256403737A6272CDF4840
74820	24699	107.425985	107.803062	51.912405	51.737639999999999	проспект 50-летия Октября	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76050	24699	107.425985	107.803062	51.912405	51.737639999999999	микрорайон Новый Зеленый	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76513	24699	107.425985	107.803062	51.912405	51.737639999999999	Энергетик	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76599	24699	107.425985	107.803062	51.912405	51.737639999999999	Шумяцкого	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74433	24699	107.425985	107.803062	51.912405	51.737639999999999	Шукшина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75682	24699	107.425985	107.803062	51.912405	51.737639999999999	Шаляпина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76492	24699	107.425985	107.803062	51.912405	51.737639999999999	Чкалова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74339	24699	107.425985	107.803062	51.912405	51.737639999999999	Чкалова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74445	24699	107.425985	107.803062	51.912405	51.737639999999999	Чертенкова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76531	24699	107.425985	107.803062	51.912405	51.737639999999999	Чайковского	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76422	24699	107.425985	107.803062	51.912405	51.737639999999999	Цыбикова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74757	24699	107.425985	107.803062	51.912405	51.737639999999999	Цивилева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74516	24699	107.425985	107.803062	51.912405	51.737639999999999	Хоца Намсараева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74872	24699	107.425985	107.803062	51.912405	51.737639999999999	Туполева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76595	24699	107.425985	107.803062	51.912405	51.737639999999999	Трубачеева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74846	24699	107.425985	107.803062	51.912405	51.737639999999999	Трактовая	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76570	24699	107.425985	107.803062	51.912405	51.737639999999999	Толстихина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
71478	24699	107.425985	107.803062	51.912405	51.737639999999999	Тобольская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76480	24699	107.425985	107.803062	51.912405	51.737639999999999	Терешковой	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76056	24699	107.425985	107.803062	51.912405	51.737639999999999	Талалихина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75797	24699	107.425985	107.803062	51.912405	51.737639999999999	Сухэ-Батора	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76494	24699	107.425985	107.803062	51.912405	51.737639999999999	Столичная	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76603	24699	107.425985	107.803062	51.912405	51.737639999999999	Сперанского	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76604	24699	107.425985	107.803062	51.912405	51.737639999999999	Совхозная	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76486	24699	107.425985	107.803062	51.912405	51.737639999999999	Советская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74882	24699	107.425985	107.803062	51.912405	51.737639999999999	Смолина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
71487	24699	107.425985	107.803062	51.912405	51.737639999999999	Северная	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76489	24699	107.425985	107.803062	51.912405	51.737639999999999	Севастопольская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76566	24699	107.425985	107.803062	51.912405	51.737639999999999	Сахалинская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74359	24699	107.425985	107.803062	51.912405	51.737639999999999	Родины	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76506	24699	107.425985	107.803062	51.912405	51.737639999999999	Ринчино	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74528	24699	107.425985	107.803062	51.912405	51.737639999999999	Революции 1905 года	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76481	24699	107.425985	107.803062	51.912405	51.737639999999999	Раздольная	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76568	24699	107.425985	107.803062	51.912405	51.737639999999999	Радикальцева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76591	24699	107.425985	107.803062	51.912405	51.737639999999999	Пушкина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76538	24699	107.425985	107.803062	51.912405	51.737639999999999	Пушкина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76462	24699	107.425985	107.803062	51.912405	51.737639999999999	Пушкина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76555	24699	107.425985	107.803062	51.912405	51.737639999999999	Пугачева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76561	24699	107.425985	107.803062	51.912405	51.737639999999999	Покровская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76557	24699	107.425985	107.803062	51.912405	51.737639999999999	Пищевая	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74884	24699	107.425985	107.803062	51.912405	51.737639999999999	Партизанская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76559	24699	107.425985	107.803062	51.912405	51.737639999999999	Павлова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74414	24699	107.425985	107.803062	51.912405	51.737639999999999	Оцимика	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75680	24699	107.425985	107.803062	51.912405	51.737639999999999	Октябрьская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76600	24699	107.425985	107.803062	51.912405	51.737639999999999	Новая	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76619	24699	107.425985	107.803062	51.912405	51.737639999999999	Н.Нищенко	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74878	24699	107.425985	107.803062	51.912405	51.737639999999999	Мокрова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76569	24699	107.425985	107.803062	51.912405	51.737639999999999	Микрорайон Вагжанова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75976	24699	107.425985	107.803062	51.912405	51.737639999999999	Микрорайон Аэропорт	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74362	24699	107.425985	107.803062	51.912405	51.737639999999999	Магистральная	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74456	24699	107.425985	107.803062	51.912405	51.737639999999999	Лысогорская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74624	24699	107.425985	107.803062	51.912405	51.737639999999999	Лимонова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76565	24699	107.425985	107.803062	51.912405	51.737639999999999	Ленина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76607	24699	107.425985	107.803062	51.912405	51.737639999999999	Куйбышева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76483	24699	107.425985	107.803062	51.912405	51.737639999999999	Крылова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76501	24699	107.425985	107.803062	51.912405	51.737639999999999	Краснофлотская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74388	24699	107.425985	107.803062	51.912405	51.737639999999999	Краснодонская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76490	24699	107.425985	107.803062	51.912405	51.737639999999999	Красноармейская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76503	24699	107.425985	107.803062	51.912405	51.737639999999999	Комсомольская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74371	24699	107.425985	107.803062	51.912405	51.737639999999999	Ключевская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
71484	24699	107.425985	107.803062	51.912405	51.737639999999999	Карла Маркса	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76497	24699	107.425985	107.803062	51.912405	51.737639999999999	Калашникова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74538	24699	107.425985	107.803062	51.912405	51.737639999999999	Кабанская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76601	24699	107.425985	107.803062	51.912405	51.737639999999999	Зеленхоз	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74850	24699	107.425985	107.803062	51.912405	51.737639999999999	Жердева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76606	24699	107.425985	107.803062	51.912405	51.737639999999999	Ербанова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76572	24699	107.425985	107.803062	51.912405	51.737639999999999	Дорожная	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76627	24699	107.425985	107.803062	51.912405	51.737639999999999	Добролюбова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76500	24699	107.425985	107.803062	51.912405	51.737639999999999	Дзержинского	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76430	24699	107.425985	107.803062	51.912405	51.737639999999999	Гурульбинская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74479	24699	107.425985	107.803062	51.912405	51.737639999999999	Горхонская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74379	24699	107.425985	107.803062	51.912405	51.737639999999999	Геологическая	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76502	24699	107.425985	107.803062	51.912405	51.737639999999999	Гвардейская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76597	24699	107.425985	107.803062	51.912405	51.737639999999999	Гармаева	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76061	24699	107.425985	107.803062	51.912405	51.737639999999999	Гагарина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76556	24699	107.425985	107.803062	51.912405	51.737639999999999	Гагарина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76253	24699	107.425985	107.803062	51.912405	51.737639999999999	Воронежская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76083	24699	107.654158	107.67954400000001	51.893467000000001	51.829020999999997	Верхняя Березовка	0103000020E61000000100000005000000AC1A84B9DDE95A403E59315C1DEA4940AC1A84B9DDE95A4012876C205DF249405B0C1EA67DEB5A4012876C205DF249405B0C1EA67DEB5A403E59315C1DEA4940AC1A84B9DDE95A403E59315C1DEA4940
74841	24699	107.425985	107.803062	51.912405	51.737639999999999	Буйко	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74889	24699	107.425985	107.803062	51.912405	51.737639999999999	Батарейная	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76659	24699	107.425985	107.803062	51.912405	51.737639999999999	Баргузинская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74521	24699	107.425985	107.803062	51.912405	51.737639999999999	Балтахинова	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76059	24699	107.425985	107.803062	51.912405	51.737639999999999	Бабушкина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76594	24699	107.425985	107.803062	51.912405	51.737639999999999	Бабушкина	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75899	24699	107.425985	107.803062	51.912405	51.737639999999999	113 квартал	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76527	59464	107.425985	107.803062	51.912405	51.737639999999999	проспект 50-летия Октября	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
71482	59464	107.425985	107.803062	51.912405	51.737639999999999	Строителей	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75648	59464	107.425985	107.803062	51.912405	51.737639999999999	Революции 1905 года	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
76578	60864	109.254003	109.366185	55.650652999999998	55.602891	проспект Ленинградский	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
76493	60864	109.254003	109.366185	55.650652999999998	55.602891	проспект 60 лет СССР	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
76544	60864	109.254003	109.366185	55.650652999999998	55.602891	Космонавтов	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
76545	60864	109.254003	109.366185	55.650652999999998	55.602891	60 лет ВЛКСМ	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
76920	60876	106.416549	106.486851	50.379559	50.321345000000001	Цыбиктарова	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
76586	60876	106.416549	106.486851	50.379559	50.321345000000001	Крупской	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
76808	60947	106.558384	106.62384400000001	52.009162000000003	51.972670000000001	Вокзальная	0103000020E6100000010000000500000005A73E90BCA35A4071E6577380FC494005A73E90BCA35A40D82E6D382C014A409373620FEDA75A40D82E6D382C014A409373620FEDA75A4071E6577380FC494005A73E90BCA35A4071E6577380FC4940
76520	60867	105.841402	105.89354899999999	51.721324000000003	51.703332000000003	3 Интернационала	0103000020E610000001000000050000007F32C687D9755A407A1D71C806DA49407F32C687D9755A40F3E8465854DC4940E71725E82F795A40F3E8465854DC4940E71725E82F795A407A1D71C806DA49407F32C687D9755A407A1D71C806DA4940
75679	60713	107.425985	107.803062	51.912405	51.737639999999999	Комсомольская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
74948	60394	107.425985	107.803062	51.912405	51.737639999999999	микрорайон Сокол	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75993	60394	107.51133400000001	107.74473500000001	51.895918000000002	51.778264	Ясная	0103000020E610000001000000050000004ED53DB2B9E05A40BBD39D279EE349404ED53DB2B9E05A40E9F2E670ADF24940F14BFDBCA9EF5A40E9F2E670ADF24940F14BFDBCA9EF5A40BBD39D279EE349404ED53DB2B9E05A40BBD39D279EE34940
75798	60394	107.51133400000001	107.74473500000001	51.895918000000002	51.778264	Чертенкова	0103000020E610000001000000050000004ED53DB2B9E05A40BBD39D279EE349404ED53DB2B9E05A40E9F2E670ADF24940F14BFDBCA9EF5A40E9F2E670ADF24940F14BFDBCA9EF5A40BBD39D279EE349404ED53DB2B9E05A40BBD39D279EE34940
75996	60394	107.51133400000001	107.74473500000001	51.895918000000002	51.778264	Тарбагатайская	0103000020E610000001000000050000004ED53DB2B9E05A40BBD39D279EE349404ED53DB2B9E05A40E9F2E670ADF24940F14BFDBCA9EF5A40E9F2E670ADF24940F14BFDBCA9EF5A40BBD39D279EE349404ED53DB2B9E05A40BBD39D279EE34940
75812	60394	107.51133400000001	107.74473500000001	51.895918000000002	51.778264	Радикальцева	0103000020E610000001000000050000004ED53DB2B9E05A40BBD39D279EE349404ED53DB2B9E05A40E9F2E670ADF24940F14BFDBCA9EF5A40E9F2E670ADF24940F14BFDBCA9EF5A40BBD39D279EE349404ED53DB2B9E05A40BBD39D279EE34940
75676	60394	107.425985	107.803062	51.912405	51.737639999999999	Комсомольская	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75187	60394	107.425985	107.803062	51.912405	51.737639999999999	Буйко	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
75815	52913	109.73294	109.798553	52.177185000000001	52.137073000000001	Хоринская	0103000020E61000000100000005000000897B2C7DE86E5B401215AA9B8B114A40897B2C7DE86E5B40BF2B82FFAD164A40DAC70A7E1B735B40BF2B82FFAD164A40DAC70A7E1B735B401215AA9B8B114A40897B2C7DE86E5B401215AA9B8B114A40
74583	52913	109.73294	109.798553	52.177185000000001	52.137073000000001	Театральная	0103000020E61000000100000005000000897B2C7DE86E5B401215AA9B8B114A40897B2C7DE86E5B40BF2B82FFAD164A40DAC70A7E1B735B40BF2B82FFAD164A40DAC70A7E1B735B401215AA9B8B114A40897B2C7DE86E5B401215AA9B8B114A40
74172	52913	109.73294	109.798553	52.177185000000001	52.137073000000001	Ленина	0103000020E61000000100000005000000897B2C7DE86E5B401215AA9B8B114A40897B2C7DE86E5B40BF2B82FFAD164A40DAC70A7E1B735B40BF2B82FFAD164A40DAC70A7E1B735B401215AA9B8B114A40897B2C7DE86E5B401215AA9B8B114A40
76752	52856	108.856472	108.88232499999999	52.299650999999997	52.265988	Центральная	0103000020E61000000100000005000000247CEF6FD0365B40719010E50B224A40247CEF6FD0365B405A9BC6F65A264A405DDC460378385B405A9BC6F65A264A405DDC460378385B40719010E50B224A40247CEF6FD0365B40719010E50B224A40
76878	52878	109.117001	109.134051	52.015309000000002	52.004721000000004	Школьная	0103000020E610000001000000050000005B26C3F17C475B405E4D9EB29A004A405B26C3F17C475B40D02A33A5F5014A40C03FA54A94485B40D02A33A5F5014A40C03FA54A94485B405E4D9EB29A004A405B26C3F17C475B405E4D9EB29A004A40
76580	32815	109.19329500000001	109.233881	52.145097999999997	52.135531	Ленина	0103000020E61000000100000005000000BEDEFDF15E4C5B400E4C6E1459114A40BEDEFDF15E4C5B40855B3E9292124A40F88903E8F74E5B40855B3E9292124A40F88903E8F74E5B400E4C6E1459114A40BEDEFDF15E4C5B400E4C6E1459114A40
76280	60801	108.90746	108.93633199999999	52.405765000000002	52.381656	Центральная	0103000020E61000000100000005000000679B1BD3133A5B403D29931ADA304A40679B1BD3133A5B40446E861BF0334A40B08C0DDDEC3B5B40446E861BF0334A40B08C0DDDEC3B5B403D29931ADA304A40679B1BD3133A5B403D29931ADA304A40
76761	52847	109.28098900000001	109.307794	52.565137	52.552664999999998	Школьная	0103000020E610000001000000050000004A6249B9FB515B4069520ABABD464A404A6249B9FB515B403961C26856484A40ECF99AE5B2535B403961C26856484A40ECF99AE5B2535B4069520ABABD464A404A6249B9FB515B4069520ABABD464A40
76763	60918	109.182515	109.212339	52.114697	52.109437	Тарбагатайская	0103000020E61000000100000005000000E2016553AE4B5B4076FC1708020E4A40E2016553AE4B5B4083F92B64AE0E4A40952A51F6964D5B4083F92B64AE0E4A40952A51F6964D5B4076FC1708020E4A40E2016553AE4B5B4076FC1708020E4A40
76887	60985	109.39035800000001	109.428124	52.127961999999997	52.118141999999999	Ленина	0103000020E61000000100000005000000D9EE1EA0FB585B405B24ED461F0F4A40D9EE1EA0FB585B40BC900E0F61104A407EA83462665B5B40BC900E0F61104A407EA83462665B5B405B24ED461F0F4A40D9EE1EA0FB585B405B24ED461F0F4A40
76930	52905	110.009334	110.034882	52.262768999999999	52.247751999999998	Школьная	0103000020E610000001000000050000006A2FA2ED98805B4061C26856B61F4A406A2FA2ED98805B4089B3226AA2214A40054EB6813B825B4089B3226AA2214A40054EB6813B825B4061C26856B61F4A406A2FA2ED98805B4061C26856B61F4A40
76989	52851	109.19840600000001	109.217478	52.502473999999999	52.493439000000002	Центральная	0103000020E61000000100000005000000225514AFB24C5B4015C95702293F4A40225514AFB24C5B408F8B6A1151404A405E66D828EB4D5B408F8B6A1151404A405E66D828EB4D5B4015C95702293F4A40225514AFB24C5B4015C95702293F4A40
76758	60917	109.305063	109.314909	52.081767999999997	52.071013000000001	Магистральная	0103000020E610000001000000050000000F0EF62686535B40A14B38F416094A400F0EF62686535B40FEEDB25F770A4A40D40D147827545B40FEEDB25F770A4A40D40D147827545B40A14B38F416094A400F0EF62686535B40A14B38F416094A40
76951	52842	109.512017	109.52161099999999	52.656098	52.646379000000003	Школьная	0103000020E61000000100000005000000BF7FF3E2C4605B401DE90C8CBC524A40BF7FF3E2C4605B404A7CEE04FB534A40F78E1A1362615B404A7CEE04FB534A40F78E1A1362615B401DE90C8CBC524A40BF7FF3E2C4605B401DE90C8CBC524A40
76983	52893	109.99456499999999	110.010465	52.514319	52.500435000000003	Школьная	0103000020E61000000100000005000000C22FF5F3A67F5B400B630B410E404A40C22FF5F3A67F5B40105B7A34D5414A402B306475AB805B40105B7A34D5414A402B306475AB805B400B630B410E404A40C22FF5F3A67F5B400B630B410E404A40
76837	60958	109.606763	109.62320200000001	52.172860999999997	52.160592000000001	Школьная	0103000020E61000000100000005000000105B7A34D5665B40E7FF55478E144A40105B7A34D5665B407EE02A4F20164A405133A48AE2675B407EE02A4F20164A405133A48AE2675B40E7FF55478E144A40105B7A34D5665B40E7FF55478E144A40
76747	52887	109.60484	109.631924	52.135851000000002	52.127791000000002	Кульская	0103000020E6100000010000000500000002D4D4B2B5665B4090DC9A745B104A4002D4D4B2B5665B408010C99063114A40AE635C7171685B408010C99063114A40AE635C7171685B4090DC9A745B104A4002D4D4B2B5665B4090DC9A745B104A40
76751	52901	110.039903	110.065775	52.172401999999998	52.162824000000001	Школьная	0103000020E61000000100000005000000C90050C58D825B408080B56AD7144A40C90050C58D825B40EBE1CB4411164A403E7958A835845B40EBE1CB4411164A403E7958A835845B408080B56AD7144A40C90050C58D825B408080B56AD7144A40
76892	60988	108.723027	108.733636	52.005636000000003	51.995938000000002	Советская	0103000020E6100000010000000500000000C80913462E5B40FD6B79E57AFF494000C80913462E5B4013D731AEB8004A40C5CA68E4F32E5B4013D731AEB8004A40C5CA68E4F32E5B40FD6B79E57AFF494000C80913462E5B40FD6B79E57AFF4940
76654	32838	108.90415400000001	108.964871	52.050409000000002	52.033296999999997	Комсомольская	0103000020E610000001000000050000000C23BDA8DD395B4007077B1343044A400C23BDA8DD395B40483657CD73064A40F7764B72C03D5B40483657CD73064A40F7764B72C03D5B4007077B1343044A400C23BDA8DD395B4007077B1343044A40
76743	52896	110.10488700000001	110.121309	52.287168999999999	52.277940999999998	Школьная	0103000020E61000000100000005000000A3B1F677B6865B40D89B189293234A40A3B1F677B6865B4067B62BF4C1244A4078EDD286C3875B4067B62BF4C1244A4078EDD286C3875B40D89B189293234A40A3B1F677B6865B40D89B189293234A40
76832	52871	109.324359	109.344014	52.178074000000002	52.168525000000002	Клубная	0103000020E61000000100000005000000734A404CC2545B407AC7293A92154A40734A404CC2545B404B22FB20CB164A406FD74B5304565B404B22FB20CB164A406FD74B5304565B407AC7293A92154A40734A404CC2545B407AC7293A92154A40
76863	52861	109.007434	109.026792	52.154260000000001	52.142632999999996	Балбарова	0103000020E6100000010000000500000039B874CC79405B40492A53CC41124A4039B874CC79405B405D8AABCABE134A40D8F2CAF5B6415B405D8AABCABE134A40D8F2CAF5B6415B40492A53CC41124A4039B874CC79405B40492A53CC41124A40
76982	52907	110.252517	110.27323199999999	52.371628000000001	52.361823000000001	Центральная	0103000020E61000000100000005000000C72B103D29905B4066F84F37502E4A40C72B103D29905B4092239D81912F4A401F0E12A27C915B4092239D81912F4A401F0E12A27C915B4066F84F37502E4A40C72B103D29905B4066F84F37502E4A40
76850	52907	110.252517	110.27323199999999	52.371628000000001	52.361823000000001	Харитонова	0103000020E61000000100000005000000C72B103D29905B4066F84F37502E4A40C72B103D29905B4092239D81912F4A401F0E12A27C915B4092239D81912F4A401F0E12A27C915B4066F84F37502E4A40C72B103D29905B4066F84F37502E4A40
76750	52892	109.82511599999999	109.85351199999999	52.202117999999999	52.189515999999998	Строительная	0103000020E6100000010000000500000001DA56B3CE745B40CC086F0F42184A4001DA56B3CE745B406AF7AB00DF194A4096AFCBF09F765B406AF7AB00DF194A4096AFCBF09F765B40CC086F0F42184A4001DA56B3CE745B40CC086F0F42184A40
76981	52909	110.38029299999999	110.390165	52.403495999999997	52.393577000000001	Интернациональная	0103000020E61000000100000005000000747973B856985B4099BA2BBB60324A40747973B856985B408D08C6C1A5334A40CEC29E76F8985B408D08C6C1A5334A40CEC29E76F8985B4099BA2BBB60324A40747973B856985B4099BA2BBB60324A40
76855	52891	109.863169	109.872817	52.319020999999999	52.309106	Коммунистическая	0103000020E61000000100000005000000F27A30293E775B40AA7F10C990274A40F27A30293E775B405DDE1CAED5284A402499D53BDC775B405DDE1CAED5284A402499D53BDC775B40AA7F10C990274A40F27A30293E775B40AA7F10C990274A40
77111	61057	103.12988199999999	103.140519	51.803555000000003	51.793790999999999	Гагарина	0103000020E61000000100000005000000B39597FC4FC85940F86D88F19AE54940B39597FC4FC85940C6C4E6E3DAE64940DD5D6743FEC85940C6C4E6E3DAE64940DD5D6743FEC85940F86D88F19AE54940B39597FC4FC85940F86D88F19AE54940
76708	22977	102.00273	102.02544	51.685411999999999	51.667299999999997	Октябрьская	0103000020E61000000100000005000000F52D73BA2C805940764F1E166AD54940F52D73BA2C8059409A249694BBD74940A80018CFA08159409A249694BBD74940A80018CFA0815940764F1E166AD54940F52D73BA2C805940764F1E166AD54940
76769	21711	102.854118	102.86291199999999	51.756036000000002	51.745514999999997	Советская	0103000020E61000000100000005000000323B8BDEA9B65940B6D617096DDF4940323B8BDEA9B65940A14CA3C9C5E04940DCD440F339B75940A14CA3C9C5E04940DCD440F339B75940B6D617096DDF4940323B8BDEA9B65940B6D617096DDF4940
76626	22913	102.07927599999999	102.101338	51.682150999999998	51.674187000000003	Школьная	0103000020E61000000100000005000000E4D6A4DB12855940B63176C24BD64940E4D6A4DB1285594083F755B950D74940E4F560527C86594083F755B950D74940E4F560527C865940B63176C24BD64940E4D6A4DB12855940B63176C24BD64940
76871	60977	100.667627	103.809889	51.975898999999998	51.043095999999998	Квартал 10	0103000020E610000001000000050000004DBB9866BA2A5940514B732B848549404DBB9866BA2A59407C992842EAFC4940F818AC38D5F359407C992842EAFC4940F818AC38D5F35940514B732B848549404DBB9866BA2A5940514B732B84854940
76739	22646	102.27035600000001	102.29285900000001	51.678319999999999	51.658982000000002	Ербанова	0103000020E61000000100000005000000C19140834D9159408B53AD8559D44940C19140834D915940821C9430D3D64940B7D5AC33BE925940821C9430D3D64940B7D5AC33BE9259408B53AD8559D44940C19140834D9159408B53AD8559D44940
76829	22205	102.306675	102.318371	51.809981000000001	51.804568000000003	пер. Лесной	0103000020E610000001000000050000000DE02D90A09359403EB48F15FCE649400DE02D90A0935940D1B01875ADE74940AB3FC23060945940D1B01875ADE74940AB3FC230609459403EB48F15FCE649400DE02D90A09359403EB48F15FCE64940
76759	23021	101.605918	101.695893	51.643939000000003	51.628494000000003	Центральная	0103000020E61000000100000005000000B2834A5CC7665940BADDCB7D72D04940B2834A5CC76659403ACFD8976CD24940FB20CB82896C59403ACFD8976CD24940FB20CB82896C5940BADDCB7D72D04940B2834A5CC7665940BADDCB7D72D04940
76577	21977	102.516198	102.56118600000001	51.775689	51.731856000000001	Горького	0103000020E61000000100000005000000AE10566309A15940D1B01875ADDD4940AE10566309A15940F86EF3C649E34940473EAF78EAA35940F86EF3C649E34940473EAF78EAA35940D1B01875ADDD4940AE10566309A15940D1B01875ADDD4940
76576	21576	102.98753499999999	103.030924	51.797389000000003	51.780777	Трактовая	0103000020E61000000100000005000000F12900C633BF5940083C3080F0E34940F12900C633BF59405798BED710E64940562AA8A8FAC159405798BED710E64940562AA8A8FAC15940083C3080F0E34940F12900C633BF5940083C3080F0E34940
76840	60961	100.667627	103.809889	51.975898999999998	51.043095999999998	Кооперативная	0103000020E610000001000000050000004DBB9866BA2A5940514B732B848549404DBB9866BA2A59407C992842EAFC4940F818AC38D5F359407C992842EAFC4940F818AC38D5F35940514B732B848549404DBB9866BA2A5940514B732B84854940
76980	61006	100.667627	103.809889	51.975898999999998	51.043095999999998	Траковая	0103000020E610000001000000050000004DBB9866BA2A5940514B732B848549404DBB9866BA2A59407C992842EAFC4940F818AC38D5F359407C992842EAFC4940F818AC38D5F35940514B732B848549404DBB9866BA2A5940514B732B84854940
76839	22194	102.46865099999999	102.493498	51.825453000000003	51.810783000000001	Каменушка	0103000020E61000000100000005000000368FC360FE9D59408E93C2BCC7E74940368FC360FE9D59404BB1A371A8E949400DA9A278959F59404BB1A371A8E949400DA9A278959F59408E93C2BCC7E74940368FC360FE9D59408E93C2BCC7E74940
76830	22299	102.37298	102.40858900000001	51.883256000000003	51.874594000000002	Балданова	0103000020E61000000100000005000000F98381E7DE97594090A339B2F2EF4940F98381E7DE97594076FF58880EF1494058207A52269A594076FF58880EF1494058207A52269A594090A339B2F2EF4940F98381E7DE97594090A339B2F2EF4940
76993	61014	102.49248299999999	102.50264300000001	51.789619000000002	51.777549999999998	Молодежная	0103000020E6100000010000000500000080B56AD7849F59409D8026C286E3494080B56AD7849F59406EA6423C12E549400EA48B4D2BA059406EA6423C12E549400EA48B4D2BA059409D8026C286E3494080B56AD7849F59409D8026C286E34940
76741	22529	102.403559	102.439536	51.686138	51.668495	Школьная	0103000020E610000001000000050000006AC020E9D39959400F45813E91D549406AC020E9D39959407C45B75ED3D749408A5A9A5B219C59407C45B75ED3D749408A5A9A5B219C59400F45813E91D549406AC020E9D39959400F45813E91D54940
76748	22660	102.189724	102.207178	51.696610999999997	51.679895000000002	Калинина	0103000020E610000001000000050000000BD12170248C594062DBA2CC06D749400BD12170248C594055849B8C2AD94940D89C8367428D594055849B8C2AD94940D89C8367428D594062DBA2CC06D749400BD12170248C594062DBA2CC06D74940
76805	60944	101.665323	101.68456500000001	51.696644999999997	51.670841000000003	Центральная	0103000020E61000000100000005000000B491EBA6946A594071E82D1EDED54940B491EBA6946A594001F6D1A92BD949401FBFB7E9CF6B594001F6D1A92BD949401FBFB7E9CF6B594071E82D1EDED54940B491EBA6946A594071E82D1EDED54940
77009	49341	102.562866	102.584093	51.736251000000003	51.723833999999997	Трактовая	0103000020E61000000100000005000000F1811DFF05A45940CEDDAE97A6DC4940F1811DFF05A45940DB5207793DDE4940A4349BC761A55940DB5207793DDE4940A4349BC761A55940CEDDAE97A6DC4940F1811DFF05A45940CEDDAE97A6DC4940
76509	23169	100.976091	101.01008299999999	51.680028999999998	51.669578999999999	Ленина	0103000020E61000000100000005000000E0BA6246783E5940508BC1C3B4D54940E0BA6246783E594071AAB5300BD74940B7CF2A33A540594071AAB5300BD74940B7CF2A33A5405940508BC1C3B4D54940E0BA6246783E5940508BC1C3B4D54940
76740	22568	102.35529200000001	102.365982	51.690297000000001	51.684277999999999	Тулаева	0103000020E61000000100000005000000F321A81ABD965940A7AFE76B96D74940F321A81ABD96594072C3EFA65BD849402E3BC43F6C97594072C3EFA65BD849402E3BC43F6C975940A7AFE76B96D74940F321A81ABD965940A7AFE76B96D74940
76534	22716	102.10024199999999	102.164885	51.694741	51.671249000000003	Чапаева	0103000020E61000000100000005000000E1EB6B5D6A865940823CBB7CEBD54940E1EB6B5D6A8659405D18E945EDD8494076A6D0798D8A59405D18E945EDD8494076A6D0798D8A5940823CBB7CEBD54940E1EB6B5D6A865940823CBB7CEBD54940
76623	22716	102.10024199999999	102.164885	51.694741	51.671249000000003	Ленина	0103000020E61000000100000005000000E1EB6B5D6A865940823CBB7CEBD54940E1EB6B5D6A8659405D18E945EDD8494076A6D0798D8A59405D18E945EDD8494076A6D0798D8A5940823CBB7CEBD54940E1EB6B5D6A865940823CBB7CEBD54940
76533	21646	102.85539300000001	102.899051	51.757904000000003	51.726328000000002	Индиры Ганди	0103000020E610000001000000050000008D0E48C2BEB65940A515DF50F8DC49408D0E48C2BEB65940F9C08EFF02E14940E99B340D8AB95940F9C08EFF02E14940E99B340D8AB95940A515DF50F8DC49408D0E48C2BEB65940A515DF50F8DC4940
76881	22436	102.620969	102.65341600000001	51.705911	51.684227999999997	Школьная	0103000020E610000001000000050000001CB5C2F4BDA75940F58079C894D749401CB5C2F4BDA759407E71A94A5BDA4940B9AB5791D1A959407E71A94A5BDA4940B9AB5791D1A95940F58079C894D749401CB5C2F4BDA75940F58079C894D74940
76647	22489	102.444378	102.47040200000001	51.693981999999998	51.673422000000002	Советская	0103000020E61000000100000005000000F6436CB0709C594016342DB132D64940F6436CB0709C59409F01F566D4D84940467EFD101B9E59409F01F566D4D84940467EFD101B9E594016342DB132D64940F6436CB0709C594016342DB132D64940
76807	21827	102.748655	102.780141	51.770228000000003	51.742095999999997	Школьная	0103000020E61000000100000005000000293FA9F6E9AF5940073F7100FDDE4940293FA9F6E9AF5940543BC3D496E24940335184D4EDB15940543BC3D496E24940335184D4EDB15940073F7100FDDE4940293FA9F6E9AF5940073F7100FDDE4940
76736	21827	102.748655	102.780141	51.770228000000003	51.742095999999997	Комсомольская	0103000020E61000000100000005000000293FA9F6E9AF5940073F7100FDDE4940293FA9F6E9AF5940543BC3D496E24940335184D4EDB15940543BC3D496E24940335184D4EDB15940073F7100FDDE4940293FA9F6E9AF5940073F7100FDDE4940
76738	21733	102.975363	103.021384	51.822808999999999	51.800046000000002	Ленина	0103000020E610000001000000050000009FAEEE586CBE5940D7A546E867E649409FAEEE586CBE59405FED28CE51E94940172AFF5A5EC159405FED28CE51E94940172AFF5A5EC15940D7A546E867E649409FAEEE586CBE5940D7A546E867E64940
76842	21810	102.88220800000001	102.9079	51.794286999999997	51.78866	Истомина	0103000020E6100000010000000500000041118B1876B85940E9D495CFF2E4494041118B1876B85940A8514832ABE5494075029A081BBA5940A8514832ABE5494075029A081BBA5940E9D495CFF2E4494041118B1876B85940E9D495CFF2E44940
76848	22083	102.532	102.54622000000001	51.799003999999996	51.782749000000003	Ленина	0103000020E61000000100000005000000355EBA490CA2594005FD851E31E44940355EBA490CA25940C4AF58C345E64940F41ABB44F5A25940C4AF58C345E64940F41ABB44F5A2594005FD851E31E44940355EBA490CA2594005FD851E31E44940
76735	21892	102.668481	102.697209	51.796543	51.779395000000001	Ленина	0103000020E61000000100000005000000D53F8864C8AA59403DD52137C3E34940D53F8864C8AA5940CA6DFB1EF5E54940855E7F129FAC5940CA6DFB1EF5E54940855E7F129FAC59403DD52137C3E34940D53F8864C8AA59403DD52137C3E34940
76664	22355	102.422836	102.45187900000001	51.919265000000003	51.899247000000003	Трактовая	0103000020E6100000010000000500000093E4B9BE0F9B5940580394861AF3494093E4B9BE0F9B5940C1ADBB79AAF54940F3AFE595EB9C5940C1ADBB79AAF54940F3AFE595EB9C5940580394861AF3494093E4B9BE0F9B5940580394861AF34940
76879	21252	106.98518199999999	107.007209	51.239145999999998	51.215676999999999	Калинина	0103000020E61000000100000005000000E7A6CD380DBF5A40ECBFCE4D9B9B4940E7A6CD380DBF5A400F7C0C569C9E494029CFBC1C76C05A400F7C0C569C9E494029CFBC1C76C05A40ECBFCE4D9B9B4940E7A6CD380DBF5A40ECBFCE4D9B9B4940
76706	60907	107.305306	107.329363	51.281739999999999	51.266972000000003	Антонова	0103000020E6100000010000000500000072512D228AD35A404F7974232CA2494072512D228AD35A40CEFC6A0E10A44940CC608C4814D55A40CEFC6A0E10A44940CC608C4814D55A404F7974232CA2494072512D228AD35A404F7974232CA24940
71708	20832	107.327449	107.397203	51.494478000000001	51.466740999999999	Рокоссовского	0103000020E61000000100000005000000E886A6ECF4D45A40E659492BBEBB4940E886A6ECF4D45A40B64B1B0E4BBF4940E1B721C66BD95A40B64B1B0E4BBF4940E1B721C66BD95A40E659492BBEBB4940E886A6ECF4D45A40E659492BBEBB4940
75977	20832	107.327449	107.397203	51.494478000000001	51.466740999999999	Ленина	0103000020E61000000100000005000000E886A6ECF4D45A40E659492BBEBB4940E886A6ECF4D45A40B64B1B0E4BBF4940E1B721C66BD95A40B64B1B0E4BBF4940E1B721C66BD95A40E659492BBEBB4940E886A6ECF4D45A40E659492BBEBB4940
76742	20758	107.441868	107.49017000000001	51.506129000000001	51.489381000000002	Кирова	0103000020E610000001000000050000008849B89047DC5A4053245F09A4BE49408849B89047DC5A405247C7D5C8C04940BEDEFDF15EDF5A405247C7D5C8C04940BEDEFDF15EDF5A4053245F09A4BE49408849B89047DC5A4053245F09A4BE4940
76651	21491	107.77579799999999	107.809162	51.666964999999998	51.640785999999999	Октябрьская	0103000020E610000001000000050000005793A7ACA6F15A4009DE904605D249405793A7ACA6F15A40CF49EF1B5FD549409FCA694FC9F35A40CF49EF1B5FD549409FCA694FC9F35A4009DE904605D249405793A7ACA6F15A4009DE904605D24940
76737	21008	107.17900299999999	107.21781	51.436095999999999	51.416063999999999	Калинина	0103000020E61000000100000005000000B2B8FFC874CB5A407F85CC9541B54940B2B8FFC874CB5A404DF564FED1B7494079AF5A99F0CD5A404DF564FED1B7494079AF5A99F0CD5A407F85CC9541B54940B2B8FFC874CB5A407F85CC9541B54940
76827	20545	107.64799499999999	107.684673	51.550899000000001	51.541842000000003	Ленина	0103000020E610000001000000050000002D3E05C078E95A40B4CC22145BC549402D3E05C078E95A401633C2DB83C6494012DDB3AED1EB5A401633C2DB83C6494012DDB3AED1EB5A40B4CC22145BC549402D3E05C078E95A40B4CC22145BC54940
76529	20526	107.717237	107.788348	51.535629	51.519851000000003	Ленина	0103000020E61000000100000005000000CB9E0436E7ED5A407EE5417A8AC24940CB9E0436E7ED5A4004E5B67D8FC449407D772B4B74F25A4004E5B67D8FC449407D772B4B74F25A407EE5417A8AC24940CB9E0436E7ED5A407EE5417A8AC24940
76859	20646	107.424063	107.47383000000001	51.423696999999997	51.411126000000003	Ленина	0103000020E61000000100000005000000651C23D923DB5A408544DAC69FB44940651C23D923DB5A40E7340BB43BB649404777103B53DE5A40E7340BB43BB649404777103B53DE5A408544DAC69FB44940651C23D923DB5A408544DAC69FB44940
76660	21028	107.207713	107.226955	51.330007000000002	51.298305999999997	Советская	0103000020E610000001000000050000000F7D772B4BCD5A40AC1919E42EA649400F7D772B4BCD5A40BD395CAB3DAA49407AAA436E86CE5A40BD395CAB3DAA49407AAA436E86CE5A40AC1919E42EA649400F7D772B4BCD5A40AC1919E42EA64940
76836	20746	107.37383800000001	107.393619	51.432147999999998	51.419910999999999	Молодежная	0103000020E61000000100000005000000220038F6ECD75A40861DC6A4BFB54940220038F6ECD75A4012842BA050B749406405BF0D31D95A4012842BA050B749406405BF0D31D95A40861DC6A4BFB54940220038F6ECD75A40861DC6A4BFB54940
76583	20633	107.57806100000001	107.636595	51.446424999999998	51.419125000000001	Ленина	0103000020E61000000100000005000000F58590F3FEE45A40CFF753E3A5B54940F58590F3FEE45A40F38E537424B949400473F4F8BDE85A40F38E537424B949400473F4F8BDE85A40CFF753E3A5B54940F58590F3FEE45A40CFF753E3A5B54940
76828	21093	107.25586300000001	107.27363099999999	51.265439000000001	51.251133000000003	Ленина	0103000020E610000001000000050000006A50340F60D05A4023F94A2025A049406A50340F60D05A409E0AB8E7F9A14940FE0A992B83D15A409E0AB8E7F9A14940FE0A992B83D15A4023F94A2025A049406A50340F60D05A4023F94A2025A04940
76867	21188	107.183252	107.20265499999999	51.248291999999999	51.224359	Ленина	0103000020E610000001000000050000004DBB9866BACB5A4019C8B3CBB79C49404DBB9866BACB5A40E1ED4108C89F4940BC57AD4CF8CC5A40E1ED4108C89F4940BC57AD4CF8CC5A4019C8B3CBB79C49404DBB9866BACB5A4019C8B3CBB79C4940
76988	61011	105.2717	107.09119200000001	51.5961	50.600594000000001	Солнечная	0103000020E61000000100000005000000AF94658863515A404016A243E04C4940AF94658863515A40A3923A014DCC49400A6AF816D6C55A40A3923A014DCC49400A6AF816D6C55A404016A243E04C4940AF94658863515A404016A243E04C4940
76978	20127	105.2717	107.09119200000001	51.5961	50.600594000000001	Садовая	0103000020E61000000100000005000000AF94658863515A404016A243E04C4940AF94658863515A40A3923A014DCC49400A6AF816D6C55A40A3923A014DCC49400A6AF816D6C55A404016A243E04C4940AF94658863515A404016A243E04C4940
76826	20250	106.714403	106.738649	51.472408000000001	51.450325999999997	Е.Волковой	0103000020E61000000100000005000000844A5CC7B8AD5A40ED444948A4B94940844A5CC7B8AD5A40342F87DD77BC4940478E740646AF5A40342F87DD77BC4940478E740646AF5A40ED444948A4B94940844A5CC7B8AD5A40ED444948A4B94940
76792	60932	106.221542	106.244997	50.932681000000002	50.904732000000003	Фрунзе	0103000020E61000000100000005000000302C7FBE2D8E5A4085D21742CE734940302C7FBE2D8E5A40E04C4C17627749408FA7E507AE8F5A40E04C4C17627749408FA7E507AE8F5A4085D21742CE734940302C7FBE2D8E5A4085D21742CE734940
76849	60966	106.433958	106.454035	50.814075000000003	50.797989000000001	переулок Школьный	0103000020E610000001000000050000009B75C6F7C59B5A40ACC8E880246649409B75C6F7C59B5A40E0BE0E9C33684940520FD1E80E9D5A40E0BE0E9C33684940520FD1E80E9D5A40ACC8E880246649409B75C6F7C59B5A40ACC8E88024664940
76885	60983	105.2717	107.09119200000001	51.5961	50.600594000000001	Солнечная	0103000020E61000000100000005000000AF94658863515A404016A243E04C4940AF94658863515A40A3923A014DCC49400A6AF816D6C55A40A3923A014DCC49400A6AF816D6C55A404016A243E04C4940AF94658863515A404016A243E04C4940
76891	60987	106.653839	106.677509	51.416933999999998	51.400360999999997	Ленина	0103000020E610000001000000050000005C76887FD8A95A4003CC7C073FB349405C76887FD8A95A40944BE3175EB54940B96FB54E5CAB5A40944BE3175EB54940B96FB54E5CAB5A4003CC7C073FB349405C76887FD8A95A4003CC7C073FB34940
76937	46986	106.305903	106.312658	50.751721000000003	50.743501999999999	Дэбэн	0103000020E61000000100000005000000E42F2DEA93935A405B41D3122B5F4940E42F2DEA93935A40B45BCB64386049404C35B39602945A40B45BCB64386049404C35B39602945A405B41D3122B5F4940E42F2DEA93935A405B41D3122B5F4940
75729	18497	106.43933	106.559569	51.333309999999997	51.260812000000001	Пушкина	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
74869	18497	106.43933	106.559569	51.333309999999997	51.260812000000001	Ленина	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
71704	18497	106.43933	106.559569	51.333309999999997	51.260812000000001	Красноармейская	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
75795	18497	106.43933	106.559569	51.333309999999997	51.260812000000001	Комсомольская	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
75969	18497	106.43933	106.559569	51.333309999999997	51.260812000000001	Колхозная	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
71700	18497	106.43933	106.559569	51.333309999999997	51.260812000000001	Ключевская	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
75974	18497	106.43933	106.559569	51.333309999999997	51.260812000000001	Водная	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
75180	60528	106.43933	106.559569	51.333309999999997	51.260812000000001	6 микрорайон	0103000020E61000000100000005000000B58993FB1D9C5A40C233A14962A14940B58993FB1D9C5A4002B7EEE6A9AA4940BFB67EFACFA35A4002B7EEE6A9AA4940BFB67EFACFA35A40C233A14962A14940B58993FB1D9C5A40C233A14962A14940
77056	61052	109.749568	109.76734500000001	55.884292000000002	55.874747999999997	Ленина	0103000020E6100000010000000500000033880FECF86F5B40E61E12BEF7EF4B4033880FECF86F5B40A60EF27A30F14B40F2EF332E1C715B40A60EF27A30F14B40F2EF332E1C715B40E61E12BEF7EF4B4033880FECF86F5B40E61E12BEF7EF4B40
76775	17532	111.612341	111.624343	56.136301000000003	56.123427999999997	Набережная	0103000020E61000000100000005000000FF3F4E9830E75B4091B41B7DCC0F4C40FF3F4E9830E75B40C0B4A84F72114C40239F573CF5E75B40C0B4A84F72114C40239F573CF5E75B4091B41B7DCC0F4C40FF3F4E9830E75B4091B41B7DCC0F4C40
76184	17925	109.254003	109.366185	55.650652999999998	55.602891	проспект Пролетарский	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
74316	17925	109.254003	109.366185	55.650652999999998	55.602891	проспект 60 лет СССР	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
71689	17925	109.254003	109.366185	55.650652999999998	55.602891	пр-т Ленинградский	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
76405	17925	109.254003	109.366185	55.650652999999998	55.602891	переулок Пионерский	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
71693	17925	109.254003	109.366185	55.650652999999998	55.602891	Пер. Школьный	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
75954	17925	109.254003	109.366185	55.650652999999998	55.602891	Мира	0103000020E610000001000000050000007F85CC9541505B40C00644882BCD4B407F85CC9541505B40AB05F69848D34B404AD235936F575B40AB05F69848D34B404AD235936F575B40C00644882BCD4B407F85CC9541505B40C00644882BCD4B40
76563	17605	111.706368	111.75652100000001	56.149811999999997	56.128731000000002	Лесоводов	0103000020E6100000010000000500000038BC202235ED5B409E7DE5417A104C4038BC202235ED5B403046240A2D134C402F6F0ED76AF05B403046240A2D134C402F6F0ED76AF05B409E7DE5417A104C4038BC202235ED5B409E7DE5417A104C40
76573	17605	111.706368	111.75652100000001	56.149811999999997	56.128731000000002	Добровольцев	0103000020E6100000010000000500000038BC202235ED5B409E7DE5417A104C4038BC202235ED5B403046240A2D134C402F6F0ED76AF05B403046240A2D134C402F6F0ED76AF05B409E7DE5417A104C4038BC202235ED5B409E7DE5417A104C40
76977	17605	111.706368	111.75652100000001	56.149811999999997	56.128731000000002	Байкальская	0103000020E6100000010000000500000038BC202235ED5B409E7DE5417A104C4038BC202235ED5B403046240A2D134C402F6F0ED76AF05B403046240A2D134C402F6F0ED76AF05B409E7DE5417A104C4038BC202235ED5B409E7DE5417A104C40
76655	17605	111.706368	111.75652100000001	56.149811999999997	56.128731000000002	70 лет Октября	0103000020E6100000010000000500000038BC202235ED5B409E7DE5417A104C4038BC202235ED5B403046240A2D134C402F6F0ED76AF05B403046240A2D134C402F6F0ED76AF05B409E7DE5417A104C4038BC202235ED5B409E7DE5417A104C40
76793	60933	111.706368	111.75652100000001	56.149811999999997	56.128731000000002	Восточная	0103000020E6100000010000000500000038BC202235ED5B409E7DE5417A104C4038BC202235ED5B403046240A2D134C402F6F0ED76AF05B403046240A2D134C402F6F0ED76AF05B409E7DE5417A104C4038BC202235ED5B409E7DE5417A104C40
76657	16975	109.538589	109.61376	55.818483000000001	55.761583000000002	Рабочая	0103000020E61000000100000005000000103FFF3D78625B4044183F8D7BE14B40103FFF3D78625B407EAA0A0DC4E84B40F3E505D847675B407EAA0A0DC4E84B40F3E505D847675B4044183F8D7BE14B40103FFF3D78625B4044183F8D7BE14B40
71504	16975	109.538589	109.61376	55.818483000000001	55.761583000000002	Победы	0103000020E61000000100000005000000103FFF3D78625B4044183F8D7BE14B40103FFF3D78625B407EAA0A0DC4E84B40F3E505D847675B407EAA0A0DC4E84B40F3E505D847675B4044183F8D7BE14B40103FFF3D78625B4044183F8D7BE14B40
76574	16975	109.538589	109.61376	55.818483000000001	55.761583000000002	Озерная	0103000020E61000000100000005000000103FFF3D78625B4044183F8D7BE14B40103FFF3D78625B407EAA0A0DC4E84B40F3E505D847675B407EAA0A0DC4E84B40F3E505D847675B4044183F8D7BE14B40103FFF3D78625B4044183F8D7BE14B40
74867	16975	109.538589	109.61376	55.818483000000001	55.761583000000002	Кооперативная	0103000020E61000000100000005000000103FFF3D78625B4044183F8D7BE14B40103FFF3D78625B407EAA0A0DC4E84B40F3E505D847675B407EAA0A0DC4E84B40F3E505D847675B4044183F8D7BE14B40103FFF3D78625B4044183F8D7BE14B40
76755	17829	111.191427	111.225437	55.891753999999999	55.879662000000003	Юбилейная	0103000020E610000001000000050000009224085740CC5B4059C4B0C398F04B409224085740CC5B40E109BDFE24F24B40BC934F8F6DCE5B40E109BDFE24F24B40BC934F8F6DCE5B4059C4B0C398F04B409224085740CC5B4059C4B0C398F04B40
76515	17318	110.08641799999999	110.114329	55.946455999999998	55.924526999999998	Центральная	0103000020E6100000010000000500000049F25CDF87855B406EA296E656F64B4049F25CDF87855B402E8D5F7825F94B4000FF942A51875B402E8D5F7825F94B4000FF942A51875B406EA296E656F64B4049F25CDF87855B406EA296E656F64B40
76553	17318	110.08641799999999	110.114329	55.946455999999998	55.924526999999998	Мелиораторов	0103000020E6100000010000000500000049F25CDF87855B406EA296E656F64B4049F25CDF87855B402E8D5F7825F94B4000FF942A51875B402E8D5F7825F94B4000FF942A51875B406EA296E656F64B4049F25CDF87855B406EA296E656F64B40
76517	17423	110.120985	110.156307	55.852890000000002	55.843530000000001	Советская 	0103000020E610000001000000050000009F93DE37BE875B40F29881CAF8EB4B409F93DE37BE875B40F08AE07F2BED4B40B24813EF008A5B40F08AE07F2BED4B40B24813EF008A5B40F29881CAF8EB4B409F93DE37BE875B40F29881CAF8EB4B40
76650	17238	109.168852	109.20226	55.359732000000001	55.353417	Победы	0103000020E610000001000000050000004F779E78CE4A5B40DB6CACC43CAD4B404F779E78CE4A5B408FA9BBB20BAE4B407E52EDD3F14C5B408FA9BBB20BAE4B407E52EDD3F14C5B40DB6CACC43CAD4B404F779E78CE4A5B40DB6CACC43CAD4B40
76560	17484	110.89988700000001	110.916641	56.012410000000003	56.005490000000002	Космонавтов	0103000020E610000001000000050000001EC6A4BF97B95B403F3A75E5B3004C401EC6A4BF97B95B405A12A0A696014C400E4B033FAABA5B405A12A0A696014C400E4B033FAABA5B403F3A75E5B3004C401EC6A4BF97B95B403F3A75E5B3004C40
74154	60261	109.538589	109.61376	55.818483000000001	55.761583000000002	Победы	0103000020E61000000100000005000000103FFF3D78625B4044183F8D7BE14B40103FFF3D78625B407EAA0A0DC4E84B40F3E505D847675B407EAA0A0DC4E84B40F3E505D847675B4044183F8D7BE14B40103FFF3D78625B4044183F8D7BE14B40
76845	16796	107.099322	107.13097	52.127172000000002	52.117826999999998	40 лет Октября	0103000020E610000001000000050000007E71A94A5BC65A40FBCA83F4140F4A407E71A94A5BC65A40C47B0E2C47104A4075B0FECF61C85A40C47B0E2C47104A4075B0FECF61C85A40FBCA83F4140F4A407E71A94A5BC65A40FBCA83F4140F4A40
76727	15847	107.67198	107.683532	52.228223	52.222585000000002	Мелиораторов	0103000020E610000001000000050000003BE466B801EB5A4043CA4FAA7D1C4A403BE466B801EB5A40F6984869361D4A403F7100FDBEEB5A40F6984869361D4A403F7100FDBEEB5A4043CA4FAA7D1C4A403BE466B801EB5A4043CA4FAA7D1C4A40
75675	16041	107.60908000000001	107.666213	52.214078000000001	52.178874999999998	Профсоюзная	0103000020E610000001000000050000007429AE2AFBE65A4037894160E5164A407429AE2AFBE65A4084656CE8661B4A40E2CAD93BA3EA5A4084656CE8661B4A40E2CAD93BA3EA5A4037894160E5164A407429AE2AFBE65A4037894160E5164A40
76518	16041	107.60908000000001	107.666213	52.214078000000001	52.178874999999998	Ленина	0103000020E610000001000000050000007429AE2AFBE65A4037894160E5164A407429AE2AFBE65A4084656CE8661B4A40E2CAD93BA3EA5A4084656CE8661B4A40E2CAD93BA3EA5A4037894160E5164A407429AE2AFBE65A4037894160E5164A40
71684	16041	107.60908000000001	107.666213	52.214078000000001	52.178874999999998	50 лет Октября	0103000020E610000001000000050000007429AE2AFBE65A4037894160E5164A407429AE2AFBE65A4084656CE8661B4A40E2CAD93BA3EA5A4084656CE8661B4A40E2CAD93BA3EA5A4037894160E5164A407429AE2AFBE65A4037894160E5164A40
76726	16041	107.60908000000001	107.666213	52.214078000000001	52.178874999999998	16 квартал	0103000020E610000001000000050000007429AE2AFBE65A4037894160E5164A407429AE2AFBE65A4084656CE8661B4A40E2CAD93BA3EA5A4084656CE8661B4A40E2CAD93BA3EA5A4037894160E5164A407429AE2AFBE65A4037894160E5164A40
75714	15360	108.21208300000001	108.247648	52.958796	52.931057000000003	Школьная	0103000020E61000000100000005000000684293C4920D5B401FDB32E02C774A40684293C4920D5B408FC4CBD3B97A4A40DE3AFF76D90F5B408FC4CBD3B97A4A40DE3AFF76D90F5B401FDB32E02C774A40684293C4920D5B401FDB32E02C774A40
76744	46156	107.159285	107.202009	52.122345000000003	52.116301	60 лет Октября	0103000020E61000000100000005000000936FB6B931CA5A40FDBE7FF3E20E4A40936FB6B931CA5A4021EA3E00A90F4A40DA1F28B7EDCC5A4021EA3E00A90F4A40DA1F28B7EDCC5A40FDBE7FF3E20E4A40936FB6B931CA5A40FDBE7FF3E20E4A40
75722	16467	107.42086500000001	107.452629	52.147562999999998	52.133419000000004	Школьная	0103000020E61000000100000005000000FDC1C073EFDA5A4020D5B0DF13114A40FDC1C073EFDA5A40C18C2958E3124A40280EA0DFF7DC5A40C18C2958E3124A40280EA0DFF7DC5A4020D5B0DF13114A40FDC1C073EFDA5A4020D5B0DF13114A40
74866	46239	107.123559	107.153994	52.120747000000001	52.111572000000002	Лазо	0103000020E6100000010000000500000018080264E8C75A401D93C5FD470E4A4018080264E8C75A40890B40A3740F4A40EF71A609DBC95A40890B40A3740F4A40EF71A609DBC95A401D93C5FD470E4A4018080264E8C75A401D93C5FD470E4A40
76902	46239	107.123559	107.153994	52.120747000000001	52.111572000000002	Гагарина	0103000020E6100000010000000500000018080264E8C75A401D93C5FD470E4A4018080264E8C75A40890B40A3740F4A40EF71A609DBC95A40890B40A3740F4A40EF71A609DBC95A401D93C5FD470E4A4018080264E8C75A401D93C5FD470E4A40
76656	16450	107.458882	107.48612799999999	52.106633000000002	52.084158000000002	Юбилейная	0103000020E6100000010000000500000047AE9B525EDD5A4030D978B0C50A4A4047AE9B525EDD5A4052D66F26A60D4A40DF6A9DB81CDF5A4052D66F26A60D4A40DF6A9DB81CDF5A4030D978B0C50A4A4047AE9B525EDD5A4030D978B0C50A4A40
76729	45553	108.390066	108.405293	52.926144000000001	52.916539999999998	Набережная	0103000020E61000000100000005000000055262D7F6185B40E8BCC62E51754A40055262D7F6185B407DB1F7E28B764A400E130D52F0195B407DB1F7E28B764A400E130D52F0195B40E8BCC62E51754A40055262D7F6185B40E8BCC62E51754A40
76778	47088	107.27965	107.30465	52.157310000000003	52.146734000000002	Подгорная	0103000020E61000000100000005000000E4141DC9E5D15A400B9B012EC8124A40E4141DC9E5D15A40B9AAECBB22144A407DAEB6627FD35A40B9AAECBB22144A407DAEB6627FD35A400B9B012EC8124A40E4141DC9E5D15A400B9B012EC8124A40
76771	15579	107.873104	107.88979500000001	52.377313000000001	52.358457000000001	Комсомольская	0103000020E610000001000000050000006F8099EFE0F75A40DA0242EBE12D4A406F8099EFE0F75A4086ADD9CA4B304A403D49BA66F2F85A4086ADD9CA4B304A403D49BA66F2F85A40DA0242EBE12D4A406F8099EFE0F75A40DA0242EBE12D4A40
76658	16960	107.019327	107.048334	52.096786000000002	52.083129	Молодежная	0103000020E61000000100000005000000823B50A73CC15A40B22C98F8A30A4A40823B50A73CC15A40F75AD07B630C4A403B527DE717C35A40F75AD07B630C4A403B527DE717C35A40B22C98F8A30A4A40823B50A73CC15A40B22C98F8A30A4A40
76698	45959	107.527118	107.538814	52.171154000000001	52.164509000000002	Заводская	0103000020E6100000010000000500000082C8224DBCE15A40E77283A10E154A4082C8224DBCE15A40304AD05FE8154A402028B7ED7BE25A40304AD05FE8154A402028B7ED7BE25A40E77283A10E154A4082C8224DBCE15A40E77283A10E154A40
76776	10649	108.06800200000001	108.082735	52.764245000000003	52.756953000000003	Озерная	0103000020E6100000010000000500000002840F255A045B40F7CDFDD5E3604A4002840F255A045B40D690B8C7D2614A4003CFBD874B055B40D690B8C7D2614A4003CFBD874B055B40F7CDFDD5E3604A4002840F255A045B40F7CDFDD5E3604A40
76645	16145	107.475375	107.515449	52.171855999999998	52.159222	Коммунистическая	0103000020E610000001000000050000008195438B6CDE5A40E066F16261144A408195438B6CDE5A4089CF9D60FF154A406170CD1DFDE05A4089CF9D60FF154A406170CD1DFDE05A40E066F16261144A408195438B6CDE5A40E066F16261144A40
76773	10714	108.01221700000001	108.034567	52.503264000000001	52.488833	Трактовая	0103000020E6100000010000000500000023DDCF29C8005B40501A6A14923E4A4023DDCF29C8005B4088A06AF46A404A4055A1815836025B4088A06AF46A404A4055A1815836025B40501A6A14923E4A4023DDCF29C8005B40501A6A14923E4A40
76705	15775	107.69666599999999	107.718693	52.262703000000002	52.243505999999996	Чкалова	0103000020E610000001000000050000000C8FFD2C96EC5A409C3061342B1F4A400C8FFD2C96EC5A40D2C77C40A0214A404EB7EC10FFED5A40D2C77C40A0214A404EB7EC10FFED5A409C3061342B1F4A400C8FFD2C96EC5A409C3061342B1F4A40
76524	16223	107.484053	107.504408	52.161791000000001	52.145927	Советская	0103000020E61000000100000005000000F7216FB9FADE5A403C4D66BCAD124A40F7216FB9FADE5A40C1E44691B5144A40CFF57D3848E05A40C1E44691B5144A40CFF57D3848E05A403C4D66BCAD124A40F7216FB9FADE5A403C4D66BCAD124A40
76821	45613	108.19643499999999	108.23066900000001	52.873361000000003	52.859541999999998	Братьев Ильиных	0103000020E610000001000000050000008B321B64920C5B40EBC4E578056E4A408B321B64920C5B400A4D124BCA6F4A40DECCE847C30E5B400A4D124BCA6F4A40DECCE847C30E5B40EBC4E578056E4A408B321B64920C5B40EBC4E578056E4A40
76646	15868	107.65316900000001	107.688446	52.202074000000003	52.178891999999998	Братьев Седуновых	0103000020E61000000100000005000000B5705985CDE95A400DC2DCEEE5164A40B5705985CDE95A409BAF928FDD194A40F8C3CF7F0FEC5A409BAF928FDD194A40F8C3CF7F0FEC5A400DC2DCEEE5164A40B5705985CDE95A400DC2DCEEE5164A40
76733	33021	107.220146	107.305836	52.128813999999998	52.116067999999999	Павлова	0103000020E6100000010000000500000018963FDF16CE5A405A0EF450DB0E4A4018963FDF16CE5A402BA226FA7C104A40207C28D192D35A402BA226FA7C104A40207C28D192D35A405A0EF450DB0E4A4018963FDF16CE5A405A0EF450DB0E4A40
71493	33021	107.220146	107.305836	52.128813999999998	52.116067999999999	Октябрьская	0103000020E6100000010000000500000018963FDF16CE5A405A0EF450DB0E4A4018963FDF16CE5A402BA226FA7C104A40207C28D192D35A402BA226FA7C104A40207C28D192D35A405A0EF450DB0E4A4018963FDF16CE5A405A0EF450DB0E4A40
76649	33021	107.220146	107.305836	52.128813999999998	52.116067999999999	Коммунистическая	0103000020E6100000010000000500000018963FDF16CE5A405A0EF450DB0E4A4018963FDF16CE5A402BA226FA7C104A40207C28D192D35A402BA226FA7C104A40207C28D192D35A405A0EF450DB0E4A4018963FDF16CE5A405A0EF450DB0E4A40
76802	15763	107.75626	107.793944	52.270358999999999	52.259743	Партизанская	0103000020E6100000010000000500000078D1579066F05A40B62E35423F214A4078D1579066F05A40F296AB1F9B224A40BFB67EFACFF25A40F296AB1F9B224A40BFB67EFACFF25A40B62E35423F214A4078D1579066F05A40B62E35423F214A40
76970	15202	108.649733	108.661959	52.989547999999999	52.984234999999998	Набережная	0103000020E610000001000000050000007288B83995295B400E4A9869FB7D4A407288B83995295B403EE94482A97E4A40BE1248895D2A5B403EE94482A97E4A40BE1248895D2A5B400E4A9869FB7D4A407288B83995295B400E4A9869FB7D4A40
76933	10737	107.915019	107.932599	52.405182000000003	52.397666000000001	Центральная	0103000020E61000000100000005000000FE0DDAAB8FFA5A40965D30B8E6324A40FE0DDAAB8FFA5A40C576F700DD334A401152B7B3AFFB5A40C576F700DD334A401152B7B3AFFB5A40965D30B8E6324A40FE0DDAAB8FFA5A40965D30B8E6324A40
76550	15497	107.95943200000001	107.98369599999999	52.806710000000002	52.790964000000002	Пионерская	0103000020E6100000010000000500000019AF795567FD5A401C28F04E3E654A4019AF795567FD5A4097ADF54542674A402F4D11E0F4FE5A4097ADF54542674A402F4D11E0F4FE5A401C28F04E3E654A4019AF795567FD5A401C28F04E3E654A40
76841	45925	107.50233299999999	107.521809	52.092835000000001	52.088962000000002	Октябрьская	0103000020E61000000100000005000000E6AC4F3926E05A401B4B581B630B4A40E6AC4F3926E05A404B766C04E20B4A408B70935165E15A404B766C04E20B4A408B70935165E15A401B4B581B630B4A40E6AC4F3926E05A401B4B581B630B4A40
76799	45693	107.85330500000001	107.86219800000001	52.337938000000001	52.332048999999998	Монастырская	0103000020E61000000100000005000000DA20938C9CF65A40B2D5E594802A4A40DA20938C9CF65A40AF09698D412B4A404E2B85402EF75A40AF09698D412B4A404E2B85402EF75A40B2D5E594802A4A40DA20938C9CF65A40B2D5E594802A4A40
77063	61054	106.95649899999999	110.718994	53.385196999999998	51.905399000000003	Центральная	0103000020E6100000010000000500000007EA944737BD5A40626A4B1DE4F3494007EA944737BD5A4037C2A2224EB14A404B0169FF03AE5B4037C2A2224EB14A404B0169FF03AE5B40626A4B1DE4F3494007EA944737BD5A40626A4B1DE4F34940
76720	15063	99.711468999999994	99.720586999999995	52.608252	52.600332000000002	Набережная	0103000020E610000001000000050000008AC745B588ED5840035FD1ADD74C4A408AC745B588ED584001DD9733DB4D4A400EBBEF181EEE584001DD9733DB4D4A400EBBEF181EEE5840035FD1ADD74C4A408AC745B588ED5840035FD1ADD74C4A40
76917	14759	100.16369899999999	100.184585	52.329529000000001	52.319957000000002	Школьный переулок	0103000020E61000000100000005000000D3D85E0B7A0A59402A90D959F4284A40D3D85E0B7A0A5940B30A9B012E2A4A4042959A3DD00B5940B30A9B012E2A4A4042959A3DD00B59402A90D959F4284A40D3D85E0B7A0A59402A90D959F4284A40
77022	14759	100.16369899999999	100.184585	52.329529000000001	52.319957000000002	Центральная	0103000020E61000000100000005000000D3D85E0B7A0A59402A90D959F4284A40D3D85E0B7A0A5940B30A9B012E2A4A4042959A3DD00B5940B30A9B012E2A4A4042959A3DD00B59402A90D959F4284A40D3D85E0B7A0A59402A90D959F4284A40
76728	15118	99.669472999999996	99.682562000000004	52.694412999999997	52.678691000000001	Лесная	0103000020E61000000100000005000000852348A5D8EA5840768BC058DF564A40852348A5D8EA584068757286E2584A4083DF8618AFEB584068757286E2584A4083DF8618AFEB5840768BC058DF564A40852348A5D8EA5840768BC058DF564A40
76732	14976	99.814927999999995	99.837655999999996	52.527925000000003	52.502946000000001	Школьная	0103000020E610000001000000050000000F26C5C727F45840B7D3D68860404A400F26C5C727F45840D3DEE00B93434A401553E9279CF55840D3DEE00B93434A401553E9279CF55840B7D3D68860404A400F26C5C727F45840B7D3D68860404A40
76824	14976	99.814927999999995	99.837655999999996	52.527925000000003	52.502946000000001	Советская	0103000020E610000001000000050000000F26C5C727F45840B7D3D68860404A400F26C5C727F45840D3DEE00B93434A401553E9279CF55840D3DEE00B93434A401553E9279CF55840B7D3D68860404A400F26C5C727F45840B7D3D68860404A40
76819	14976	99.814927999999995	99.837655999999996	52.527925000000003	52.502946000000001	Молодежная	0103000020E610000001000000050000000F26C5C727F45840B7D3D68860404A400F26C5C727F45840D3DEE00B93434A401553E9279CF55840D3DEE00B93434A401553E9279CF55840B7D3D68860404A400F26C5C727F45840B7D3D68860404A40
77014	61031	108.229771	108.24750400000001	51.344783	51.338318000000001	Октябрьская	0103000020E610000001000000050000006EA46C91B40E5B40F6D214014EAB49406EA46C91B40E5B40BF9B6ED921AC49404568041BD70F5B40BF9B6ED921AC49404568041BD70F5B40F6D214014EAB49406EA46C91B40E5B40F6D214014EAB4940
71681	14648	107.62338099999999	107.658694	51.044941999999999	51.008668999999998	И.Калашникова	0103000020E61000000100000005000000A8FC6B79E5E75A4098BED7101C814940A8FC6B79E5E75A40C11BD2A8C08549409204E10A28EA5A40C11BD2A8C08549409204E10A28EA5A4098BED7101C814940A8FC6B79E5E75A4098BED7101C814940
76624	60886	107.230665	107.259114	51.083976999999997	51.071012000000003	Школьная	0103000020E610000001000000050000003DD52137C3CE5A40D1CFD4EB168949403DD52137C3CE5A40DF4E22C2BF8A4940E3FBE25295D05A40DF4E22C2BF8A4940E3FBE25295D05A40D1CFD4EB168949403DD52137C3CE5A40D1CFD4EB16894940
75721	14323	108.184226	108.269513	51.142263	51.122627000000001	Школьная	0103000020E61000000100000005000000AA44D95BCA0B5B40A54DD53DB28F4940AA44D95BCA0B5B4026378AAC35924940333674B33F115B4026378AAC35924940333674B33F115B40A54DD53DB28F4940AA44D95BCA0B5B40A54DD53DB28F4940
76731	14348	107.652828	107.662476	51.258304000000003	51.242224999999998	Арсаланова	0103000020E61000000100000005000000707A17EFC7E95A4005A3923A019F4940707A17EFC7E95A408736001B10A14940A298BC0166EA5A408736001B10A14940A298BC0166EA5A4005A3923A019F4940707A17EFC7E95A4005A3923A019F4940
76616	14280	107.966538	108.01179500000001	51.105635999999997	51.086103999999999	Ленина	0103000020E61000000100000005000000D71533C2DBFD5A400307B474058B4940D71533C2DBFD5A40DFA3FE7A858D494068D0D03FC1005B40DFA3FE7A858D494068D0D03FC1005B400307B474058B4940D71533C2DBFD5A400307B474058B4940
76548	14213	108.09653299999999	108.12835099999999	51.222541999999997	51.207219000000002	Комсомольская	0103000020E61000000100000005000000067FBF982D065B400F0EF626869A4940067FBF982D065B4043FE99417C9C49402BDA1CE736085B4043FE99417C9C49402BDA1CE736085B400F0EF626869A4940067FBF982D065B400F0EF626869A4940
77027	61038	107.496961	107.532957	51.045712000000002	51.031920999999997	 Ленина	0103000020E61000000100000005000000CC988235CEDF5A401E87C1FC15844940CC988235CEDF5A4073840CE4D9854940274BADF71BE25A4073840CE4D9854940274BADF71BE25A401E87C1FC15844940CC988235CEDF5A401E87C1FC15844940
76972	49423	108.208265	108.221084	51.222565000000003	51.215581	Пионерская	0103000020E61000000100000005000000B1F9B836540D5B40CA518028989B4940B1F9B836540D5B40FC1D8A027D9C4940CF6A813D260E5B40FC1D8A027D9C4940CF6A813D260E5B40CA518028989B4940B1F9B836540D5B40CA518028989B4940
74716	14070	108.42111199999999	108.471615	51.350391000000002	51.334361999999999	Молодежная	0103000020E6100000010000000500000000FDBE7FF31A5B403883BF5FCCAA494000FDBE7FF31A5B4008E8BE9CD9AC49406553AEF02E1E5B4008E8BE9CD9AC49406553AEF02E1E5B403883BF5FCCAA494000FDBE7FF31A5B403883BF5FCCAA4940
76644	13995	107.08326	107.106464	50.933992000000003	50.903187000000003	Ленина	0103000020E610000001000000050000002844C02154C55A401096B1A19B7349402844C02154C55A40E25CC30C8D774940E38C614ED0C65A40E25CC30C8D774940E38C614ED0C65A401096B1A19B7349402844C02154C55A401096B1A19B734940
76547	13895	107.732383	107.772367	51.041685999999999	51.017434999999999	Солнечная	0103000020E610000001000000050000005E49F25CDFEE5A402367614F3B8249405E49F25CDFEE5A40BC5983F7558549409E60FF756EF15A40BC5983F7558549409E60FF756EF15A402367614F3B8249405E49F25CDFEE5A402367614F3B824940
76686	13895	107.732383	107.772367	51.041685999999999	51.017434999999999	Партизанская	0103000020E610000001000000050000005E49F25CDFEE5A402367614F3B8249405E49F25CDFEE5A40BC5983F7558549409E60FF756EF15A40BC5983F7558549409E60FF756EF15A402367614F3B8249405E49F25CDFEE5A402367614F3B824940
76823	49427	108.119674	108.12449700000001	51.282325999999998	51.269795000000002	Манзанова	0103000020E610000001000000050000009E0B23BDA8075B40EACF7EA488A249409E0B23BDA8075B40BE67244223A44940CFDC43C2F7075B40BE67244223A44940CFDC43C2F7075B40EACF7EA488A249409E0B23BDA8075B40EACF7EA488A24940
75960	60757	108.30006400000001	108.34253699999999	51.199486999999998	51.176861000000002	Ленина	0103000020E610000001000000050000003FADA23F34135B400C789961A39649403FADA23F34135B40137D3ECA88994940E02A4F20EC155B40137D3ECA88994940E02A4F20EC155B400C789961A39649403FADA23F34135B400C789961A3964940
77030	61039	107.90019700000001	107.90733	51.267355000000002	51.256025999999999	Ленина	0103000020E6100000010000000500000045BDE0D39CF95A407D76C075C5A0494045BDE0D39CF95A4007B64AB038A24940802BD9B111FA5A4007B64AB038A24940802BD9B111FA5A407D76C075C5A0494045BDE0D39CF95A407D76C075C5A04940
71682	13613	107.79405199999999	107.857671	51.059584000000001	51.033445	Доржиева	0103000020E61000000100000005000000B2D47ABFD1F25A407C9BFEEC47844940B2D47ABFD1F25A40B4AED172A087494091EEE714E4F65A40B4AED172A087494091EEE714E4F65A407C9BFEEC47844940B2D47ABFD1F25A407C9BFEEC47844940
74865	13613	107.79405199999999	107.857671	51.059584000000001	51.033445	30 лет Победы	0103000020E61000000100000005000000B2D47ABFD1F25A407C9BFEEC47844940B2D47ABFD1F25A40B4AED172A087494091EEE714E4F65A40B4AED172A087494091EEE714E4F65A407C9BFEEC47844940B2D47ABFD1F25A407C9BFEEC47844940
76617	60883	108.339707	108.364509	51.358322000000001	51.334395999999998	Ленина	0103000020E610000001000000050000003ACE6DC2BD155B40E4F4F57CCDAA49403ACE6DC2BD155B40FAB7CB7EDDAD494040868E1D54175B40FAB7CB7EDDAD494040868E1D54175B40E4F4F57CCDAA49403ACE6DC2BD155B40E4F4F57CCDAA4940
76973	49230	107.76485700000001	107.788599	51.303615999999998	51.272184000000003	Солнечная	0103000020E610000001000000050000007847C66AF3F05A404B3FE1ECD6A249407847C66AF3F05A406B459BE3DCA6494022AAF06778F25A406B459BE3DCA6494022AAF06778F25A404B3FE1ECD6A249407847C66AF3F05A404B3FE1ECD6A24940
77000	61020	107.426785	107.43858899999999	51.074176000000001	51.067124	50 Лет Октября	0103000020E61000000100000005000000185B087250DB5A406B63EC8497884940185B087250DB5A40F51263997E894940A9D898D711DC5A40F51263997E894940A9D898D711DC5A406B63EC8497884940185B087250DB5A406B63EC8497884940
76820	14439	107.3596	107.391023	51.047263999999998	51.030504999999998	Гагарина	0103000020E6100000010000000500000010E9B7AF03D75A40A7AE7C96E783494010E9B7AF03D75A409A232BBF0C864940F73E558506D95A409A232BBF0C864940F73E558506D95A40A7AE7C96E783494010E9B7AF03D75A40A7AE7C96E7834940
76909	13495	107.785653	107.796972	51.241954999999997	51.227849999999997	Лодоева	0103000020E610000001000000050000004640852348F25A40613255302A9D49404640852348F25A40450DA661F89E4940F9F4D89601F35A40450DA661F89E4940F9F4D89601F35A40613255302A9D49404640852348F25A40613255302A9D4940
76967	13764	107.897673	107.908039	51.318260000000002	51.306184000000002	Заречная	0103000020E610000001000000050000002460747973F95A407C478D0931A749402460747973F95A40FFCF61BEBCA84940861F9C4F1DFA5A40FFCF61BEBCA84940861F9C4F1DFA5A407C478D0931A749402460747973F95A407C478D0931A74940
77002	61022	108.015927	108.03752299999999	51.228825999999998	51.219152000000001	Советская	0103000020E61000000100000005000000E607AEF204015B402F6D382C0D9C4940E607AEF204015B40BC3C9D2B4A9D49404276DEC666025B40BC3C9D2B4A9D49404276DEC666025B402F6D382C0D9C4940E607AEF204015B402F6D382C0D9C4940
76723	13363	107.55493	107.56447	51.308335	51.287255000000002	Ленина	0103000020E610000001000000050000006F641EF983E35A40664E97C5C4A449406F641EF983E35A40289B728577A74940AE64C74620E45A40289B728577A74940AE64C74620E45A40664E97C5C4A449406F641EF983E35A40664E97C5C4A44940
77012	61029	107.14278299999999	107.162474	51.078488	51.071120000000001	Балтинская	0103000020E610000001000000050000002FDB4E5B23C95A40B70BCD751A8949402FDB4E5B23C95A40719010E50B8A4940D21C59F965CA5A40719010E50B8A4940D21C59F965CA5A40B70BCD751A8949402FDB4E5B23C95A40B70BCD751A894940
77091	61058	115.724245	115.728413	56.226123999999999	56.222985999999999	Первомайская	0103000020E61000000100000005000000A852B3075AEE5C40A1BB24CE8A1C4C40A852B3075AEE5C409C6B98A1F11C4C40CD3E8F519EEE5C409C6B98A1F11C4C40CD3E8F519EEE5C40A1BB24CE8A1C4C40A852B3075AEE5C40A1BB24CE8A1C4C40
76975	61003	107.15155900000001	107.17728700000001	50.223689999999998	50.214019	Школьная	0103000020E61000000100000005000000871A8524B3C95A407FDC7EF9641B4940871A8524B3C95A409B38B9DFA11C494062C092AB58CB5A409B38B9DFA11C494062C092AB58CB5A407FDC7EF9641B4940871A8524B3C95A407FDC7EF9641B4940
76906	11502	107.33784300000001	107.354542	50.020541999999999	50.014870000000002	Октябрьская	0103000020E61000000100000005000000AF0B3F389FD55A4084D89942E7014940AF0B3F389FD55A40E318C91EA1024940BDC3EDD0B0D65A40E318C91EA1024940BDC3EDD0B0D65A4084D89942E7014940AF0B3F389FD55A4084D89942E7014940
76907	11242	107.305099	107.354381	50.271828999999997	50.265903999999999	Степанова	0103000020E61000000100000005000000B5C2F4BD86D35A4013F06B2409224940B5C2F4BD86D35A405C8DEC4ACB224940B954A52DAED65A405C8DEC4ACB224940B954A52DAED65A4013F06B2409224940B5C2F4BD86D35A4013F06B2409224940
76608	12217	106.906193	106.92023399999999	50.277442000000001	50.266070999999997	Нагорная	0103000020E610000001000000050000004EB7EC10FFB95A40FEB4519D0E2249404EB7EC10FFB95A40B7442E3883234940B4AA251DE5BA5A40B7442E3883234940B4AA251DE5BA5A40FEB4519D0E2249404EB7EC10FFB95A40FEB4519D0E224940
77001	61021	107.31416299999999	107.330054	50.028407000000001	50.020316000000001	Советская	0103000020E610000001000000050000003FA7203F1BD45A40F3CAF5B6990249403FA7203F1BD45A401EFD2FD7A20349407FFACF9A1FD55A401EFD2FD7A20349407FFACF9A1FD55A40F3CAF5B6990249403FA7203F1BD45A40F3CAF5B699024940
75857	12561	106.13010300000001	106.163915	50.488377999999997	50.467398000000003	Школьная	0103000020E610000001000000050000002387889B53885A40A01B9AB2D33B49402387889B53885A40FE0A992B833E4940BA1457957D8A5A40FE0A992B833E4940BA1457957D8A5A40A01B9AB2D33B49402387889B53885A40A01B9AB2D33B4940
77032	61008	107.10993999999999	107.134141	50.224071000000002	50.220336000000003	Клубная	0103000020E610000001000000050000006C21C84109C75A40D41055F8331C49406C21C84109C75A40B37DC85BAE1C4940600322C495C85A40B37DC85BAE1C4940600322C495C85A40D41055F8331C49406C21C84109C75A40D41055F8331C4940
76838	60960	106.869237	106.884867	50.438612999999997	50.430207000000003	Молодежная	0103000020E6100000010000000500000048DE3994A1B75A4051C1E1051137494048DE3994A1B75A40DB4C857824384940D19332A9A1B85A40DB4C857824384940D19332A9A1B85A4051C1E1051137494048DE3994A1B75A4051C1E10511374940
77104	61061	106.63520800000001	106.639852	50.724494999999997	50.717104999999997	Набережная	0103000020E61000000100000005000000168A743FA7A85A402766BD18CA5B4940168A743FA7A85A40C98E8D40BC5C4940EF91CD55F3A85A40C98E8D40BC5C4940EF91CD55F3A85A402766BD18CA5B4940168A743FA7A85A402766BD18CA5B4940
76804	11136	107.424818	107.43509400000001	50.182597999999999	50.173507000000001	Лесная	0103000020E610000001000000050000002330D63730DB5A404450357A351649402330D63730DB5A4052280B5F5F174940E52B8194D8DB5A4052280B5F5F174940E52B8194D8DB5A404450357A351649402330D63730DB5A404450357A35164940
74861	12515	106.269153	106.290308	50.533351000000003	50.511251000000001	Школьная	0103000020E61000000100000005000000B32781CD39915A400E863AAC70414940B32781CD39915A40FB2477D8444449401971016894925A40FB2477D8444449401971016894925A400E863AAC70414940B32781CD39915A400E863AAC70414940
76652	11886	106.80521400000001	106.82702500000001	50.428147000000003	50.410044999999997	площадь Победы	0103000020E6100000010000000500000002124DA088B35A40B471C45A7C34494002124DA088B35A40B5705985CD3649405DFE43FAEDB45A40B5705985CD3649405DFE43FAEDB45A40B471C45A7C34494002124DA088B35A40B471C45A7C344940
76613	60881	107.66738100000001	107.68225700000001	49.997709	49.986075	Центральная	0103000020E61000000100000005000000323ECC5EB6EA5A409C33A2B437FE4840323ECC5EB6EA5A4062F6B2EDB4FF4840E59D4319AAEB5A4062F6B2EDB4FF4840E59D4319AAEB5A409C33A2B437FE4840323ECC5EB6EA5A409C33A2B437FE4840
76816	11808	107.146708	107.165357	50.312187999999999	50.297142999999998	Школьная	0103000020E61000000100000005000000F183F3A963C95A401F9E25C808264940F183F3A963C95A40111AC1C6F52749408ACA863595CA5A40111AC1C6F52749408ACA863595CA5A401F9E25C808264940F183F3A963C95A401F9E25C808264940
76795	10896	107.637359	107.646827	50.179997	50.168509999999998	Набережная	0103000020E61000000100000005000000EC33677DCAE85A40448655BC91154940EC33677DCAE85A40663046240A174940DECA129D65E95A40663046240A174940DECA129D65E95A40448655BC91154940EC33677DCAE85A40448655BC91154940
76718	11343	107.218861	107.26704700000001	50.295917000000003	50.261372000000001	Партизанская	0103000020E61000000100000005000000AC5791D101CE5A40890B40A374214940AC5791D101CE5A404CAAB69BE0254940ADDF4C4C17D15A404CAAB69BE0254940ADDF4C4C17D15A40890B40A374214940AC5791D101CE5A40890B40A374214940
76874	11213	107.370955	107.418386	50.269157999999997	50.246288	Школьная	0103000020E6100000010000000500000069520ABABDD75A40D9B27C5D861F494069520ABABDD75A4077BAF3C473224940ACC612D6C6DA5A4077BAF3C473224940ACC612D6C6DA5A40D9B27C5D861F494069520ABABDD75A40D9B27C5D861F4940
77004	61012	106.41962100000001	106.428496	50.564681999999998	50.558329999999998	Школьная	0103000020E61000000100000005000000C0ED0912DB9A5A401630815B77474940C0ED0912DB9A5A40E751F17F47484940E09D7C7A6C9B5A40E751F17F47484940E09D7C7A6C9B5A401630815B77474940C0ED0912DB9A5A401630815B77474940
76825	48420	107.32983900000001	107.354632	50.158163999999999	50.155642	Дорожная	0103000020E61000000100000005000000817C09151CD55A4028F1B913EC134940817C09151CD55A40C8B3CBB73E1449405D876A4AB2D65A40C8B3CBB73E1449405D876A4AB2D65A4028F1B913EC134940817C09151CD55A4028F1B913EC134940
76971	11821	107.032505	107.042647	50.313786999999998	50.304307000000001	Кооперативная	0103000020E6100000010000000500000037FDD98F14C25A40D1782288F326494037FDD98F14C25A407974232C2A28494071917BBABAC25A407974232C2A28494071917BBABAC25A40D1782288F326494037FDD98F14C25A40D1782288F3264940
76956	48354	107.445425	107.45390500000001	50.118817	50.113652999999999	Рабочая	0103000020E6100000010000000500000088F4DBD781DC5A40D00B772E8C0E494088F4DBD781DC5A40BB9A3C65350F49406B9F8EC70CDD5A40BB9A3C65350F49406B9F8EC70CDD5A40D00B772E8C0E494088F4DBD781DC5A40D00B772E8C0E4940
76725	48588	107.068375	107.084778	50.223131000000002	50.217143	Дорожная	0103000020E610000001000000050000004C37894160C45A4015C78157CB1B49404C37894160C45A40A5DC7D8E8F1C4940E65AB4006DC55A40A5DC7D8E8F1C4940E65AB4006DC55A4015C78157CB1B49404C37894160C45A4015C78157CB1B4940
76940	12393	106.700785	106.714574	50.796463000000003	50.777881999999998	Баннова	0103000020E61000000100000005000000C02154A9D9AC5A40D3122BA391634940C02154A9D9AC5A40AEBCE47FF26549409A249694BBAD5A40AEBCE47FF26549409A249694BBAD5A40D3122BA391634940C02154A9D9AC5A40D3122BA391634940
71667	12616	106.090433	106.131468	50.416685999999999	50.371389999999998	Железнодорожная	0103000020E61000000100000005000000AB5E7EA7C9855A40DD0720B5892F4940AB5E7EA7C9855A40BC5983F7553549401D1EC2F869885A40BC5983F7553549401D1EC2F869885A40DD0720B5892F4940AB5E7EA7C9855A40DD0720B5892F4940
77033	61041	106.971025	106.978391	50.27834	50.272514000000001	Школьная	0103000020E610000001000000050000004CA60A4625BE5A40E0D91EBDE12249404CA60A4625BE5A40969526A5A0234940D9EC48F59DBE5A40969526A5A0234940D9EC48F59DBE5A40E0D91EBDE12249404CA60A4625BE5A40E0D91EBDE1224940
76965	10854	107.671621	107.70275599999999	50.202280999999999	50.180503999999999	Школьная	0103000020E61000000100000005000000A393A5D6FBEA5A400A664CC11A174940A393A5D6FBEA5A4014CD0358E419494056444DF4F9EC5A4014CD0358E419494056444DF4F9EC5A400A664CC11A174940A393A5D6FBEA5A400A664CC11A174940
75863	60525	106.416549	106.486851	50.379559	50.321345000000001	Юбилейная	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
75860	60525	106.416549	106.486851	50.379559	50.321345000000001	Советская	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
75171	60525	106.416549	106.486851	50.379559	50.321345000000001	Крупской	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
75867	12692	106.416549	106.486851	50.379559	50.321345000000001	Сухэ-Батора	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
71672	12692	106.416549	106.486851	50.379559	50.321345000000001	Пограничная	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
71675	12692	106.416549	106.486851	50.379559	50.321345000000001	Горнозелентуйская	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
71677	12692	106.416549	106.486851	50.379559	50.321345000000001	Гармаева	0103000020E610000001000000050000009E0B23BDA89A5A40D7DD3CD5212949409E0B23BDA89A5A4084F3A9639530494098C11891289F5A4084F3A9639530494098C11891289F5A40D7DD3CD5212949409E0B23BDA89A5A40D7DD3CD521294940
76817	60950	106.84999500000001	106.85815100000001	50.332000999999998	50.323335	Озерная	0103000020E61000000100000005000000DEB06D5166B65A407A53910A63294940DEB06D5166B65A40A19E3E027F2A4940E7012CF2EBB65A40A19E3E027F2A4940E7012CF2EBB65A407A53910A63294940DEB06D5166B65A407A53910A63294940
75715	11057	107.37517699999999	107.40734500000001	50.16581	50.152951999999999	Ломоносова	0103000020E61000000100000005000000874D64E602D85A40CCED5EEE93134940874D64E602D85A40C5AC1743391549401B4CC3F011DA5A40C5AC1743391549401B4CC3F011DA5A40CCED5EEE93134940874D64E602D85A40CCED5EEE93134940
76822	12061	106.696518	106.717251	50.346080999999998	50.331127000000002	Заречная	0103000020E61000000100000005000000D2C43BC093AC5A404BE9995E622A4940D2C43BC093AC5A402C62D8614C2C49407E01BD70E7AD5A402C62D8614C2C49407E01BD70E7AD5A404BE9995E622A4940D2C43BC093AC5A404BE9995E622A4940
76730	12403	106.484596	106.492268	50.655842	50.650039999999997	Трактовая	0103000020E610000001000000050000006FF1F09E039F5A40C18BBE82345349406FF1F09E039F5A40EFAB72A1F25349408237A451819F5A40EFAB72A1F25349408237A451819F5A40C18BBE82345349406FF1F09E039F5A40C18BBE8234534940
76789	60925	107.22833799999999	107.24421100000001	50.187553000000001	50.181438999999997	Луговая	0103000020E61000000100000005000000C79BFC169DCE5A40069CA56439174940C79BFC169DCE5A4023A298BC01184940B4942C27A1CF5A4023A298BC01184940B4942C27A1CF5A40069CA56439174940C79BFC169DCE5A40069CA56439174940
76815	12050	106.878112	106.89626699999999	50.322944	50.314708000000003	Школьная	0103000020E61000000100000005000000698EACFC32B85A4011E50B5A48284940698EACFC32B85A403F389F3A56294940FA5E43705CB95A403F389F3A56294940FA5E43705CB95A4011E50B5A48284940698EACFC32B85A4011E50B5A48284940
76905	10952	107.53733200000001	107.571018	50.154083	50.143282999999997	Жарникова	0103000020E6100000010000000500000009C6C1A563E25A405089EB185712494009C6C1A563E25A404EEFE2FDB813494059DB148F8BE45A404EEFE2FDB813494059DB148F8BE45A405089EB185712494009C6C1A563E25A405089EB1857124940
76914	60991	106.626296	106.64022900000001	50.405785000000002	50.400848000000003	Центральная	0103000020E610000001000000050000006667D13B15A85A406155BDFC4E3349406667D13B15A85A408B1A4CC3F0334940DA3C0E83F9A85A408B1A4CC3F0334940DA3C0E83F9A85A406155BDFC4E3349406667D13B15A85A406155BDFC4E334940
76663	33064	106.76691	106.786017	50.617463000000001	50.603624000000003	Цыбиктарова	0103000020E610000001000000050000006C3EAE0D15B15A40558A1D8D434D49406C3EAE0D15B15A40BABE0F07094F494067463F1A4EB25A40BABE0F07094F494067463F1A4EB25A40558A1D8D434D49406C3EAE0D15B15A40558A1D8D434D4940
76642	11591	107.032155	107.06737800000001	50.20702	50.197299000000001	Евдокимова	0103000020E61000000100000005000000C959D8D30EC25A404A44F81741194940C959D8D30EC25A4018CFA0A17F1A4940139ED0EB4FC45A4018CFA0A17F1A4940139ED0EB4FC45A404A44F81741194940C959D8D30EC25A404A44F81741194940
76900	11038	107.429237	107.451498	50.144623000000003	50.122830999999998	Школьная	0103000020E61000000100000005000000EC4E779E78DB5A40ADF71BEDB80F4940EC4E779E78DB5A40ED9FA70183124940670DDE57E5DC5A40ED9FA70183124940670DDE57E5DC5A40ADF71BEDB80F4940EC4E779E78DB5A40ADF71BEDB80F4940
76911	11425	107.56737099999999	107.586631	49.994739000000003	49.979118	Заринская	0103000020E61000000100000005000000B96C74CE4FE45A40647616BD53FD4840B96C74CE4FE45A402387889B53FF484077F4BF5C8BE55A402387889B53FF484077F4BF5C8BE55A40647616BD53FD4840B96C74CE4FE45A40647616BD53FD4840
76475	60857	109.942993	112.01459800000001	55.543399000000001	53.922097999999998	Ленина	0103000020E61000000100000005000000D8D64FFF597C5B407FDAA84E07F64A40D8D64FFF597C5B40EDD632198EC54B409225732CEF005C40EDD632198EC54B409225732CEF005C407FDAA84E07F64A40D8D64FFF597C5B407FDAA84E07F64A40
76818	60951	110.089814	110.103477	54.045588000000002	54.024673999999997	Ленина	0103000020E61000000100000005000000452E3883BF855B40DF87838428034B40452E3883BF855B40878BDCD3D5054B40D8B8FE5D9F865B40878BDCD3D5054B40D8B8FE5D9F865B40DF87838428034B40452E3883BF855B40DF87838428034B40
76811	10514	110.463396	110.490346	54.471043000000002	54.463759000000003	Рабочая	0103000020E610000001000000050000003946B247A89D5B40E31C75745C3B4B403946B247A89D5B403F0114234B3C4B405D6E30D4619F5B403F0114234B3C4B405D6E30D4619F5B40E31C75745C3B4B403946B247A89D5B40E31C75745C3B4B40
76964	10394	110.216593	110.226968	54.237937000000002	54.228006000000001	бр.Данжуровых	0103000020E61000000100000005000000B9E2E2A8DC8D5B4059A5F44C2F1D4B40B9E2E2A8DC8D5B4012C138B8741E4B40444FCAA4868E5B4012C138B8741E4B40444FCAA4868E5B4059A5F44C2F1D4B40B9E2E2A8DC8D5B4059A5F44C2F1D4B40
76643	60890	111.057919	111.07736800000001	54.869627000000001	54.854004000000003	Ленина	0103000020E610000001000000050000004AB4E4F1B4C35B409C53C900506D4B404AB4E4F1B4C35B40FB5B02F04F6F4B407270E998F3C45B40FB5B02F04F6F4B407270E998F3C45B409C53C900506D4B404AB4E4F1B4C35B409C53C900506D4B40
76919	60992	110.378388	110.420322	54.426094999999997	54.403199000000001	Набережная	0103000020E61000000100000005000000BA4C4D8237985B40D4635B069C334B40BA4C4D8237985B409BFEEC478A364B4084F23E8EE69A5B409BFEEC478A364B4084F23E8EE69A5B40D4635B069C334B40BA4C4D8237985B40D4635B069C334B40
76612	32779	110.45184399999999	110.467474	54.393943	54.371122999999997	Трактовая	0103000020E6100000010000000500000034B91803EB9C5B408EE55DF5802F4B4034B91803EB9C5B407BBE66B96C324B40BD6E1118EB9D5B407BBE66B96C324B40BD6E1118EB9D5B408EE55DF5802F4B4034B91803EB9C5B408EE55DF5802F4B40
76575	32846	110.78767000000001	110.808628	54.602663	54.585355999999997	Ленина	0103000020E6100000010000000500000095826E2F69B25B40394206F2EC4A4B4095826E2F69B25B402FC1A90F244D4B4050A8A78FC0B35B402FC1A90F244D4B4050A8A78FC0B35B40394206F2EC4A4B4095826E2F69B25B40394206F2EC4A4B40
76991	60287	110.283913	110.33712	54.343057999999999	54.312967999999998	заимка Ехэ-Нуга	0103000020E61000000100000005000000317A6EA12B925B40E658DE550F284B40317A6EA12B925B40CA501553E92B4B40F6B4C35F93955B40CA501553E92B4B40F6B4C35F93955B40E658DE550F284B40317A6EA12B925B40E658DE550F284B40
76721	60287	110.283913	110.33712	54.343057999999999	54.312967999999998	Набережная	0103000020E61000000100000005000000317A6EA12B925B40E658DE550F284B40317A6EA12B925B40CA501553E92B4B40F6B4C35F93955B40CA501553E92B4B40F6B4C35F93955B40E658DE550F284B40317A6EA12B925B40E658DE550F284B40
74295	60287	110.283913	110.33712	54.343057999999999	54.312967999999998	Балдакова	0103000020E61000000100000005000000317A6EA12B925B40E658DE550F284B40317A6EA12B925B40CA501553E92B4B40F6B4C35F93955B40CA501553E92B4B40F6B4C35F93955B40E658DE550F284B40317A6EA12B925B40E658DE550F284B40
76585	60875	110.283913	110.33712	54.343057999999999	54.312967999999998	Ленина	0103000020E61000000100000005000000317A6EA12B925B40E658DE550F284B40317A6EA12B925B40CA501553E92B4B40F6B4C35F93955B40CA501553E92B4B40F6B4C35F93955B40E658DE550F284B40317A6EA12B925B40E658DE550F284B40
76621	60885	109.942993	112.01459800000001	55.543399000000001	53.922097999999998	Ленина	0103000020E61000000100000005000000D8D64FFF597C5B407FDAA84E07F64A40D8D64FFF597C5B40EDD632198EC54B409225732CEF005C40EDD632198EC54B409225732CEF005C407FDAA84E07F64A40D8D64FFF597C5B407FDAA84E07F64A40
76641	60889	109.942993	112.01459800000001	55.543399000000001	53.922097999999998	Комсомольская	0103000020E61000000100000005000000D8D64FFF597C5B407FDAA84E07F64A40D8D64FFF597C5B40EDD632198EC54B409225732CEF005C40EDD632198EC54B409225732CEF005C407FDAA84E07F64A40D8D64FFF597C5B407FDAA84E07F64A40
74303	60288	110.667089	110.695853	54.251058	54.228554000000003	Хышиктуева	0103000020E610000001000000050000005EA10F96B1AA5B405CAFE941411D4B405EA10F96B1AA5B4018B325AB22204B40B47405DB88AC5B4018B325AB22204B40B47405DB88AC5B405CAFE941411D4B405EA10F96B1AA5B405CAFE941411D4B40
76770	60288	110.667089	110.695853	54.251058	54.228554000000003	Верхняя Аргада	0103000020E610000001000000050000005EA10F96B1AA5B405CAFE941411D4B405EA10F96B1AA5B4018B325AB22204B40B47405DB88AC5B4018B325AB22204B40B47405DB88AC5B405CAFE941411D4B405EA10F96B1AA5B405CAFE941411D4B40
76632	10418	110.80254600000001	110.83894600000001	54.697432999999997	54.680664999999998	Ленина	0103000020E6100000010000000500000048E2E5E95CB35B401344DD0720574B4048E2E5E95CB35B4059130B7C45594B400B47904AB1B55B4059130B7C45594B400B47904AB1B55B401344DD0720574B4048E2E5E95CB35B401344DD0720574B40
76673	60896	109.06849200000001	111.804383	52.185198	51.359200000000001	Советская	0103000020E610000001000000050000006902452C62445B40925CFE43FAAD49406902452C62445B406EA46C91B4174A40569DD5027BF35B406EA46C91B4174A40569DD5027BF35B40925CFE43FAAD49406902452C62445B40925CFE43FAAD4940
77005	61024	109.648067	109.673723	51.699340999999997	51.681418999999998	Школьная	0103000020E610000001000000050000007AA702EE79695B40BFEFDFBC38D749407AA702EE79695B403FE0810184D9494008E412471E6B5B403FE0810184D9494008E412471E6B5B40BFEFDFBC38D749407AA702EE79695B40BFEFDFBC38D74940
76984	61007	110.49472900000001	110.524473	51.975461000000003	51.954901999999997	Центральная	0103000020E6100000010000000500000080D8D2A3A99F5B4047718E3A3AFA494080D8D2A3A99F5B4001C3F2E7DBFC4940A4A833F790A15B4001C3F2E7DBFC4940A4A833F790A15B4047718E3A3AFA494080D8D2A3A99F5B4047718E3A3AFA4940
76611	9715	110.812472	110.840024	51.952648000000003	51.937869999999997	Клубная	0103000020E610000001000000050000009B3A8F8AFFB35B4023F3C81F0CF849409B3A8F8AFFB35B40C74CA25EF0F94940BAF605F4C2B55B40C74CA25EF0F94940BAF605F4C2B55B4023F3C81F0CF849409B3A8F8AFFB35B4023F3C81F0CF84940
77008	61026	109.83663199999999	109.863079	51.824078	51.809573999999998	Центральная	0103000020E610000001000000050000005FB2F1608B755B4090D8EE1EA0E749405FB2F1608B755B4032AD4D637BE9494052B7B3AF3C775B4032AD4D637BE9494052B7B3AF3C775B4090D8EE1EA0E749405FB2F1608B755B4090D8EE1EA0E74940
77036	61042	109.766007	109.786767	51.990892000000002	51.974828000000002	Центральная улица	0103000020E610000001000000050000007460394206715B40D09CF529C7FC49407460394206715B401CEF8E8CD5FE49409CA4F9635A725B401CEF8E8CD5FE49409CA4F9635A725B40D09CF529C7FC49407460394206715B40D09CF529C7FC4940
77050	61042	109.766007	109.786767	51.990892000000002	51.974828000000002	Центральная	0103000020E610000001000000050000007460394206715B40D09CF529C7FC49407460394206715B401CEF8E8CD5FE49409CA4F9635A725B401CEF8E8CD5FE49409CA4F9635A725B40D09CF529C7FC49407460394206715B40D09CF529C7FC4940
77043	61044	110.118398	110.137793	51.918843000000003	51.911448999999998	Советская	0103000020E610000001000000050000005B7A34D593875B40677C5F5CAAF449405B7A34D593875B404B94BDA59CF549408927BB99D1885B404B94BDA59CF549408927BB99D1885B40677C5F5CAAF449405B7A34D593875B40677C5F5CAAF44940
76814	9339	110.15031500000001	110.188979	51.755974999999999	51.744214999999997	Профсоюзная	0103000020E610000001000000050000004A46CEC29E895B40A818E76F42DF49404A46CEC29E895B40FBCBEEC9C3E049405F28603B188C5B40FBCBEEC9C3E049405F28603B188C5B40A818E76F42DF49404A46CEC29E895B40A818E76F42DF4940
75710	8908	109.582553	109.617848	51.631647000000001	51.604995000000002	Строитетелей	0103000020E61000000100000005000000F3CB608C48655B402C9FE57970CD4940F3CB608C48655B40EACE13CFD9D04940897956D28A675B40EACE13CFD9D04940897956D28A675B402C9FE57970CD4940F3CB608C48655B402C9FE57970CD4940
76901	8908	109.582553	109.617848	51.631647000000001	51.604995000000002	Мира	0103000020E61000000100000005000000F3CB608C48655B402C9FE57970CD4940F3CB608C48655B40EACE13CFD9D04940897956D28A675B40EACE13CFD9D04940897956D28A675B402C9FE57970CD4940F3CB608C48655B402C9FE57970CD4940
76712	47765	110.445798	110.48565600000001	51.901676000000002	51.886074000000001	Школьная	0103000020E61000000100000005000000D2A755F4879C5B40FFEA71DF6AF14940D2A755F4879C5B4047CB811E6AF34940CC46E7FC149F5B4047CB811E6AF34940CC46E7FC149F5B40FFEA71DF6AF14940D2A755F4879C5B40FFEA71DF6AF14940
76963	9026	109.723777	109.744331	51.757575000000003	51.739525	Школьная	0103000020E610000001000000050000003526C45C526E5B4086C954C1A8DE49403526C45C526E5B4034A2B437F8E0494089997D1EA36F5B4034A2B437F8E0494089997D1EA36F5B4086C954C1A8DE49403526C45C526E5B4086C954C1A8DE4940
76996	61017	109.443916	109.460804	51.569392999999998	51.559103	Номтоева	0103000020E61000000100000005000000F48AA71E695C5B40390CE6AF90C74940F48AA71E695C5B4021C9ACDEE1C849406C770FD07D5D5B4021C9ACDEE1C849406C770FD07D5D5B40390CE6AF90C74940F48AA71E695C5B40390CE6AF90C74940
76717	60911	111.01012900000001	111.02117800000001	52.051926000000002	52.045164	Раднаева	0103000020E6100000010000000500000070EF1AF4A5C05B40707A17EFC7054A4070EF1AF4A5C05B40F3E7DB82A5064A404359F8FA5AC15B40F3E7DB82A5064A404359F8FA5AC15B40707A17EFC7054A4070EF1AF4A5C05B40707A17EFC7054A40
76704	60906	109.894762	109.908686	51.921881999999997	51.919803999999999	Школьная	0103000020E6100000010000000500000007EDD5C743795B40705D3123BCF5494007EDD5C743795B40B262B83A00F64940511553E9277A5B40B262B83A00F64940511553E9277A5B40705D3123BCF5494007EDD5C743795B40705D3123BCF54940
77003	61023	109.06849200000001	111.804383	52.185198	51.359200000000001	Центральная 	0103000020E610000001000000050000006902452C62445B40925CFE43FAAD49406902452C62445B406EA46C91B4174A40569DD5027BF35B406EA46C91B4174A40569DD5027BF35B40925CFE43FAAD49406902452C62445B40925CFE43FAAD4940
71646	9123	109.87654499999999	109.94776299999999	51.860902000000003	51.818010000000001	проспект Ленина	0103000020E610000001000000050000003A1E335019785B4086E63A8DB4E849403A1E335019785B40CF87670932EE4940F7562426A87C5B40CF87670932EE4940F7562426A87C5B4086E63A8DB4E849403A1E335019785B4086E63A8DB4E84940
71651	9123	109.87654499999999	109.94776299999999	51.860902000000003	51.818010000000001	Советская	0103000020E610000001000000050000003A1E335019785B4086E63A8DB4E849403A1E335019785B40CF87670932EE4940F7562426A87C5B40CF87670932EE4940F7562426A87C5B4086E63A8DB4E849403A1E335019785B4086E63A8DB4E84940
76942	9366	110.02403	110.03636400000001	51.923253000000003	51.915304999999996	Центральная	0103000020E61000000100000005000000DD0720B589815B40C16ED8B628F54940DD0720B589815B408A7780272DF649401DB0ABC953825B408A7780272DF649401DB0ABC953825B40C16ED8B628F54940DD0720B589815B40C16ED8B628F54940
76618	60884	110.70913899999999	110.74967100000001	51.986266000000001	51.969752	Дарижапова	0103000020E610000001000000050000005C548B8862AD5B40849D62D520FC49405C548B8862AD5B401094DBF63DFE49409EF0129CFAAF5B401094DBF63DFE49409EF0129CFAAF5B40849D62D520FC49405C548B8862AD5B40849D62D520FC4940
77007	61025	110.547523	110.571302	51.973719000000003	51.960385000000002	Центральная	0103000020E61000000100000005000000B3B3E89D0AA35B40D4484BE5EDFA4940B3B3E89D0AA35B40363FFED2A2FC4940EC88433690A45B40363FFED2A2FC4940EC88433690A45B40D4484BE5EDFA4940B3B3E89D0AA35B40D4484BE5EDFA4940
77024	61036	110.027731	110.071883	51.794469999999997	51.785808000000003	Рабочая	0103000020E6100000010000000500000077853E58C6815B40B477465B95E4494077853E58C6815B4099D36531B1E54940DB8827BB99845B4099D36531B1E54940DB8827BB99845B40B477465B95E4494077853E58C6815B40B477465B95E44940
76710	7376	106.45832900000001	106.480886	52.190497999999998	52.175820999999999	Советская	0103000020E61000000100000005000000BD732843559D5A409A79724D81164A40BD732843559D5A4009FA0B3D62184A40ACC612D6C69E5A4009FA0B3D62184A40ACC612D6C69E5A409A79724D81164A40BD732843559D5A409A79724D81164A40
76893	5888	106.714313	106.75214099999999	52.123190999999998	52.100586	Почтовая	0103000020E61000000100000005000000E486DF4DB7AD5A40BD378600E00C4A40E486DF4DB7AD5A40AD1402B9C40F4A40C43E011423B05A40AD1402B9C40F4A40C43E011423B05A40BD378600E00C4A40E486DF4DB7AD5A40BD378600E00C4A40
76714	5952	106.70197899999999	106.722892	52.120646999999998	52.107711000000002	Братьев Мункоевых	0103000020E61000000100000005000000A4DE5339EDAC5A40B1355B79C90D4A40A4DE5339EDAC5A4025AE635C710F4A4090A2CEDC43AE5A4025AE635C710F4A4090A2CEDC43AE5A40B1355B79C90D4A40A4DE5339EDAC5A40B1355B79C90D4A40
76895	6006	106.74317600000001	106.764745	52.064534999999999	52.046875	Школьная	0103000020E6100000010000000500000004CB113290AF5A400000000000064A4004CB113290AF5A404339D1AE42084A40E4310395F1B05A404339D1AE42084A40E4310395F1B05A400000000000064A4004CB113290AF5A400000000000064A40
75698	6154	106.889709	106.913946	52.062437000000003	52.045274999999997	Шашина	0103000020E610000001000000050000003D7D04FEF0B85A40C7293A92CB054A403D7D04FEF0B85A40BA8784EFFD074A40D7135D177EBA5A40BA8784EFFD074A40D7135D177EBA5A40C7293A92CB054A403D7D04FEF0B85A40C7293A92CB054A40
76537	7801	106.550766	106.57719400000001	51.989117	51.971387999999997	Советская	0103000020E61000000100000005000000EB6F09C03FA35A4009DD257156FC4940EB6F09C03FA35A407575C7629BFE4940A35C1ABFF0A45A407575C7629BFE4940A35C1ABFF0A45A4009DD257156FC4940EB6F09C03FA35A4009DD257156FC4940
76682	7359	106.476089	106.507925	52.175291000000001	52.160161000000002	Школьная	0103000020E61000000100000005000000103FFF3D789E5A401E8CD82780144A40103FFF3D789E5A403E247CEF6F164A4088F4DBD781A05A403E247CEF6F164A4088F4DBD781A05A401E8CD82780144A40103FFF3D789E5A401E8CD82780144A40
76959	6082	106.949618	106.970782	52.078628999999999	52.069667000000003	Терешковой	0103000020E61000000100000005000000596C938AC6BC5A40234E27D9EA084A40596C938AC6BC5A4033C2DB83100A4A40E962D34A21BE5A4033C2DB83100A4A40E962D34A21BE5A40234E27D9EA084A40596C938AC6BC5A40234E27D9EA084A40
76702	8657	105.09348300000001	105.13986300000001	51.564382999999999	51.544772000000002	Центральная	0103000020E61000000100000005000000D9EE1EA0FB455A4065E3C116BBC54940D9EE1EA0FB455A408DB5BFB33DC84940E9BAF083F3485A408DB5BFB33DC84940E9BAF083F3485A4065E3C116BBC54940D9EE1EA0FB455A4065E3C116BBC54940
76833	5026	107.092207	107.137474	52.554834	52.535210999999997	Школьная	0103000020E61000000100000005000000965D30B8E6C55A40CFBA46CB81444A40965D30B8E6C55A40BC5AEECC04474A403883BF5FCCC85A40BC5AEECC04474A403883BF5FCCC85A40CFBA46CB81444A40965D30B8E6C55A40CFBA46CB81444A40
76809	7549	106.386707	106.403254	52.178207	52.166347999999999	Трактовая	0103000020E610000001000000050000009888B7CEBF985A40A4E029E44A154A409888B7CEBF985A408A75AA7CCF164A40CC7EDDE9CE995A408A75AA7CCF164A40CC7EDDE9CE995A40A4E029E44A154A409888B7CEBF985A40A4E029E44A154A40
76161	6266	106.835649	106.890131	52.029519000000001	51.987675000000003	микрорайон Солнечный	0103000020E61000000100000005000000D97BF1457BB55A40D50968226CFE4940D97BF1457BB55A4029CE5147C7034A40F88903E8F7B85A4029CE5147C7034A40F88903E8F7B85A40D50968226CFE4940D97BF1457BB55A40D50968226CFE4940
76158	6266	106.835649	106.890131	52.029519000000001	51.987675000000003	микрорайон Березовый	0103000020E61000000100000005000000D97BF1457BB55A40D50968226CFE4940D97BF1457BB55A4029CE5147C7034A40F88903E8F7B85A4029CE5147C7034A40F88903E8F7B85A40D50968226CFE4940D97BF1457BB55A40D50968226CFE4940
76922	6266	106.835649	106.890131	52.029519000000001	51.987675000000003	Мостовая	0103000020E61000000100000005000000D97BF1457BB55A40D50968226CFE4940D97BF1457BB55A4029CE5147C7034A40F88903E8F7B85A4029CE5147C7034A40F88903E8F7B85A40D50968226CFE4940D97BF1457BB55A40D50968226CFE4940
76810	5756	106.656758	106.674464	52.118363000000002	52.10275	Братьев Голубевых	0103000020E61000000100000005000000BAD8B45208AA5A40FED478E9260D4A40BAD8B45208AA5A403A07CF84260F4A4014950D6B2AAB5A403A07CF84260F4A4014950D6B2AAB5A40FED478E9260D4A40BAD8B45208AA5A40FED478E9260D4A40
76757	7475	106.405418	106.43351800000001	52.181171999999997	52.168033000000001	Трактовая	0103000020E610000001000000050000006CCD565EF2995A400BD3F71A82154A406CCD565EF2995A40B779E3A430174A408D0E48C2BE9B5A40B779E3A430174A408D0E48C2BE9B5A400BD3F71A82154A406CCD565EF2995A400BD3F71A82154A40
76640	8152	106.175405	106.195581	52.029601999999997	52.006528000000003	Набережная	0103000020E6100000010000000500000083A3E4D5398B5A401041D5E8D5004A4083A3E4D5398B5A40B6F292FFC9034A4004AE2B66848C5A40B6F292FFC9034A4004AE2B66848C5A401041D5E8D5004A4083A3E4D5398B5A401041D5E8D5004A40
76666	7997	106.33150500000001	106.361931	51.977308000000001	51.963171000000003	Центральная	0103000020E61000000100000005000000795DBF6037955A4052BAF42F49FB4940795DBF6037955A40410FB56D18FD4940261AA4E029975A40410FB56D18FD4940261AA4E029975A4052BAF42F49FB4940795DBF6037955A4052BAF42F49FB4940
76962	8639	105.243852	105.26463	51.581439000000003	51.576580999999997	Табельная	0103000020E610000001000000050000001C446B459B4F5A405B3FFD67CDC949401C446B459B4F5A403ACFD8976CCA494097E2AAB2EF505A403ACFD8976CCA494097E2AAB2EF505A405B3FFD67CDC949401C446B459B4F5A405B3FFD67CDC94940
76957	5201	106.803183	106.869713	52.347340000000003	52.316147999999998	Рабочая	0103000020E61000000100000005000000016DAB5967B35A401059A48977284A40016DAB5967B35A40DC4B1AA3752C4A40FDF9B660A9B75A40DC4B1AA3752C4A40FDF9B660A9B75A401059A48977284A40016DAB5967B35A401059A48977284A40
76639	5201	106.803183	106.869713	52.347340000000003	52.316147999999998	Октябрьская	0103000020E61000000100000005000000016DAB5967B35A401059A48977284A40016DAB5967B35A40DC4B1AA3752C4A40FDF9B660A9B75A40DC4B1AA3752C4A40FDF9B660A9B75A401059A48977284A40016DAB5967B35A401059A48977284A40
76709	6779	106.697712	106.71256099999999	52.032577000000003	52.021510999999997	Трактовая	0103000020E61000000100000005000000B6813B50A7AC5A408BC058DFC0024A40B6813B50A7AC5A4008CDAE7B2B044A40ECD973999AAD5A4008CDAE7B2B044A40ECD973999AAD5A408BC058DFC0024A40B6813B50A7AC5A408BC058DFC0024A40
76806	60945	106.95918500000001	106.99974400000001	52.499217999999999	52.479691000000003	Лесная	0103000020E6100000010000000500000015747B4963BD5A40C097C283663D4A4015747B4963BD5A408AC91B60E63F4A40D31742CEFBBF5A408AC91B60E63F4A40D31742CEFBBF5A40C097C283663D4A4015747B4963BD5A40C097C283663D4A40
76899	6062	106.863829	106.887445	52.073436999999998	52.067053999999999	Школьная	0103000020E6100000010000000500000087156EF948B75A407288B83995084A4087156EF948B75A407EA8346266094A40EBFF1CE6CBB85A407EA8346266094A40EBFF1CE6CBB85A407288B83995084A4087156EF948B75A407288B83995084A40
76812	8566	105.580478	105.596638	51.656025999999997	51.648963000000002	Табельная	0103000020E610000001000000050000000A83328D26655A4033A8363811D349400A83328D26655A40B0A9F3A8F8D34940416326512F665A40B0A9F3A8F8D34940416326512F665A4033A8363811D349400A83328D26655A4033A8363811D34940
76960	8299	105.976877	105.98393799999999	51.779696000000001	51.774797999999997	Железнодорожная	0103000020E61000000100000005000000BCCD1B27857E5A40CB80B3942CE34940BCCD1B27857E5A4038691A14CDE34940AAD216D7F87E5A4038691A14CDE34940AAD216D7F87E5A40CB80B3942CE34940BCCD1B27857E5A40CB80B3942CE34940
76936	7301	106.53533299999999	106.551574	52.132424	52.121858000000003	Тупышева	0103000020E610000001000000050000000DDE57E542A25A40C460FE0A990F4A400DDE57E542A25A404E9A0645F3104A40BBD408FD4CA35A404E9A0645F3104A40BBD408FD4CA35A40C460FE0A990F4A400DDE57E542A25A40C460FE0A990F4A40
76665	60894	106.63422799999999	106.67329599999999	52.252830000000003	52.207146000000002	Нелюбина	0103000020E61000000100000005000000478D093197A85A40A5BF97C2831A4A40478D093197A85A404EB9C2BB5C204A40C4211B4817AB5A404EB9C2BB5C204A40C4211B4817AB5A40A5BF97C2831A4A40478D093197A85A40A5BF97C2831A4A40
76928	60894	106.63422799999999	106.67329599999999	52.252830000000003	52.207146000000002	Куйбышева	0103000020E61000000100000005000000478D093197A85A40A5BF97C2831A4A40478D093197A85A404EB9C2BB5C204A40C4211B4817AB5A404EB9C2BB5C204A40C4211B4817AB5A40A5BF97C2831A4A40478D093197A85A40A5BF97C2831A4A40
76939	60894	106.63422799999999	106.67329599999999	52.252830000000003	52.207146000000002	Боброва	0103000020E61000000100000005000000478D093197A85A40A5BF97C2831A4A40478D093197A85A404EB9C2BB5C204A40C4211B4817AB5A404EB9C2BB5C204A40C4211B4817AB5A40A5BF97C2831A4A40478D093197A85A40A5BF97C2831A4A40
76872	5642	106.571715	106.59823299999999	52.192065999999997	52.169359	Карачовых	0103000020E610000001000000050000007DE882FA96A45A404224438EAD154A407DE882FA96A45A403656629E95184A40D498107349A65A403656629E95184A40D498107349A65A404224438EAD154A407DE882FA96A45A404224438EAD154A40
76638	8488	105.75015999999999	105.778143	51.694690999999999	51.681145999999998	Парижской Коммуны	0103000020E610000001000000050000001CB1169F02705A408EE6C8CA2FD749401CB1169F02705A40ABE97AA2EBD8494020274C18CD715A40ABE97AA2EBD8494020274C18CD715A408EE6C8CA2FD749401CB1169F02705A408EE6C8CA2FD74940
76896	7189	106.592151	106.60443100000001	52.087612	52.081873000000002	Трактовая	0103000020E61000000100000005000000CCD24ECDE5A55A4074B680D07A0A4A40CCD24ECDE5A55A405B5EB9DE360B4A40126C5CFFAEA65A405B5EB9DE360B4A40126C5CFFAEA65A4074B680D07A0A4A40CCD24ECDE5A55A4074B680D07A0A4A40
74839	7618	106.558384	106.62384400000001	52.009162000000003	51.972670000000001	Луговая	0103000020E6100000010000000500000005A73E90BCA35A4071E6577380FC494005A73E90BCA35A40D82E6D382C014A409373620FEDA75A40D82E6D382C014A409373620FEDA75A4071E6577380FC494005A73E90BCA35A4071E6577380FC4940
75709	7618	106.558384	106.62384400000001	52.009162000000003	51.972670000000001	Комсомольская	0103000020E6100000010000000500000005A73E90BCA35A4071E6577380FC494005A73E90BCA35A40D82E6D382C014A409373620FEDA75A40D82E6D382C014A409373620FEDA75A4071E6577380FC494005A73E90BCA35A4071E6577380FC4940
75853	60736	106.558384	106.62384400000001	52.009162000000003	51.972670000000001	Прибайкальская	0103000020E6100000010000000500000005A73E90BCA35A4071E6577380FC494005A73E90BCA35A40D82E6D382C014A409373620FEDA75A40D82E6D382C014A409373620FEDA75A4071E6577380FC494005A73E90BCA35A4071E6577380FC4940
76539	6895	106.630779	106.676575	52.068223000000003	52.042377000000002	переулок Октябрьский	0103000020E610000001000000050000003B00E2AE5EA85A40228D0A9C6C054A403B00E2AE5EA85A40E2EA0088BB084A40A3923A014DAB5A40E2EA0088BB084A40A3923A014DAB5A40228D0A9C6C054A403B00E2AE5EA85A40228D0A9C6C054A40
76567	6895	106.630779	106.676575	52.068223000000003	52.042377000000002	Совхозная	0103000020E610000001000000050000003B00E2AE5EA85A40228D0A9C6C054A403B00E2AE5EA85A40E2EA0088BB084A40A3923A014DAB5A40E2EA0088BB084A40A3923A014DAB5A40228D0A9C6C054A403B00E2AE5EA85A40228D0A9C6C054A40
76679	6895	106.630779	106.676575	52.068223000000003	52.042377000000002	Маяковского	0103000020E610000001000000050000003B00E2AE5EA85A40228D0A9C6C054A403B00E2AE5EA85A40E2EA0088BB084A40A3923A014DAB5A40E2EA0088BB084A40A3923A014DAB5A40228D0A9C6C054A403B00E2AE5EA85A40228D0A9C6C054A40
71633	6895	106.630779	106.676575	52.068223000000003	52.042377000000002	8 марта	0103000020E610000001000000050000003B00E2AE5EA85A40228D0A9C6C054A403B00E2AE5EA85A40E2EA0088BB084A40A3923A014DAB5A40E2EA0088BB084A40A3923A014DAB5A40228D0A9C6C054A403B00E2AE5EA85A40228D0A9C6C054A40
75706	6895	106.630779	106.676575	52.068223000000003	52.042377000000002	1 мая	0103000020E610000001000000050000003B00E2AE5EA85A40228D0A9C6C054A403B00E2AE5EA85A40E2EA0088BB084A40A3923A014DAB5A40E2EA0088BB084A40A3923A014DAB5A40228D0A9C6C054A403B00E2AE5EA85A40228D0A9C6C054A40
76903	7576	106.28285200000001	106.309748	52.142031000000003	52.123904000000003	Лесная	0103000020E61000000100000005000000ED66463F1A925A40FBEB1516DC0F4A40ED66463F1A925A40540262122E124A40178046E9D2935A40540262122E124A40178046E9D2935A40FBEB1516DC0F4A40ED66463F1A925A40FBEB1516DC0F4A40
76711	8174	106.248582	106.266817	52.109226999999997	52.088729000000001	Трактовая	0103000020E61000000100000005000000F4177AC4E88F5A40789ACC785B0B4A40F4177AC4E88F5A408B6B7C26FB0D4A4014419C8713915A408B6B7C26FB0D4A4014419C8713915A40789ACC785B0B4A40F4177AC4E88F5A40789ACC785B0B4A40
76875	5002	107.14204599999999	107.160354	52.557588000000003	52.542014000000002	Речная	0103000020E61000000100000005000000C4211B4817C95A40B1FCF9B660454A40C4211B4817C95A402F52280B5F474A4019726C3D43CA5A402F52280B5F474A4019726C3D43CA5A40B1FCF9B660454A40C4211B4817C95A40B1FCF9B660454A40
76876	6867	106.57467	106.59826	52.025134999999999	52.011960999999999	Клубная	0103000020E6100000010000000500000082FFAD64C7A45A40EAE923F087014A4082FFAD64C7A45A40137EA99F37034A4051A04FE449A65A40137EA99F37034A4051A04FE449A65A40EAE923F087014A4082FFAD64C7A45A40EAE923F087014A40
76932	5669	106.598341	106.615076	52.152481000000002	52.138261	Коневой Н.Е	0103000020E61000000100000005000000C8B60C384BA65A40F8A75489B2114A40C8B60C384BA65A407521567F84134A407D23BA675DA75A407521567F84134A407D23BA675DA75A40F8A75489B2114A40C8B60C384BA65A40F8A75489B2114A40
76894	6811	106.669532	106.698108	52.009405999999998	51.996581999999997	Клубная	0103000020E6100000010000000500000008E8BE9CD9AA5A4021E4BCFF8FFF494008E8BE9CD9AA5A406E313F3734014A40DD442DCDADAC5A406E313F3734014A40DD442DCDADAC5A4021E4BCFF8FFF494008E8BE9CD9AA5A4021E4BCFF8FFF4940
76813	60948	106.874977	106.882846	52.379336000000002	52.370753999999998	Центральная	0103000020E6100000010000000500000024F0879FFFB75A403B6EF8DD742F4A4024F0879FFFB75A40051901158E304A40E259828C80B85A40051901158E304A40E259828C80B85A403B6EF8DD742F4A4024F0879FFFB75A403B6EF8DD742F4A40
76968	5312	106.750991	106.77936	52.308653999999997	52.298318000000002	Подгорная	0103000020E61000000100000005000000C8258E3C10B05A4071E7C2482F264A40C8258E3C10B05A40C9E369F981274A40E0F3C308E1B15A40C9E369F981274A40E0F3C308E1B15A4071E7C2482F264A40C8258E3C10B05A4071E7C2482F264A40
75711	8812	104.631282	104.656614	51.475140000000003	51.446066000000002	Школьная	0103000020E610000001000000050000006C239EEC66285A40C4EDD0B018B949406C239EEC66285A40BF823463D1BC49402106BAF6052A5A40BF823463D1BC49402106BAF6052A5A40C4EDD0B018B949406C239EEC66285A40C4EDD0B018B94940
71639	8812	104.631282	104.656614	51.475140000000003	51.446066000000002	Октябрьская	0103000020E610000001000000050000006C239EEC66285A40C4EDD0B018B949406C239EEC66285A40BF823463D1BC49402106BAF6052A5A40BF823463D1BC49402106BAF6052A5A40C4EDD0B018B949406C239EEC66285A40C4EDD0B018B94940
76541	8812	104.631282	104.656614	51.475140000000003	51.446066000000002	Красных Партизан	0103000020E610000001000000050000006C239EEC66285A40C4EDD0B018B949406C239EEC66285A40BF823463D1BC49402106BAF6052A5A40BF823463D1BC49402106BAF6052A5A40C4EDD0B018B949406C239EEC66285A40C4EDD0B018B94940
76966	5769	106.69661600000001	106.72945	52.171005000000001	52.147148999999999	Трактовая	0103000020E61000000100000005000000B477465B95AC5A40CE5147C7D5124A40B477465B95AC5A40EB39E97DE3154A404D840D4FAFAE5A40EB39E97DE3154A404D840D4FAFAE5A40CE5147C7D5124A40B477465B95AC5A40CE5147C7D5124A40
76681	6215	106.835307	106.89088599999999	52.047727999999999	52.018452000000003	Истомина	0103000020E61000000100000005000000ACC77DAB75B55A40DD4598A25C024A40ACC77DAB75B55A403F8D7BF31B064A40B69DB64604B95A403F8D7BF31B064A40B69DB64604B95A40DD4598A25C024A40ACC77DAB75B55A40DD4598A25C024A40
76715	7452	106.459281	106.47938600000001	52.158548000000003	52.149436000000001	Молодежная	0103000020E6100000010000000500000026AB22DC649D5A402B6C06B820134A4026AB22DC649D5A40516C054D4B144A40420A9E42AE9E5A40516C054D4B144A40420A9E42AE9E5A402B6C06B820134A4026AB22DC649D5A402B6C06B820134A40
76540	7274	106.53854	106.563782	52.116045999999997	52.099524000000002	Ленина	0103000020E610000001000000050000009FE5797077A25A406495D233BD0C4A409FE5797077A25A40726A6798DA0E4A40B404190115A45A40726A6798DA0E4A40B404190115A45A406495D233BD0C4A409FE5797077A25A406495D233BD0C4A40
76713	7909	106.295168	106.332628	51.977713000000001	51.967005	Вагжанова	0103000020E61000000100000005000000D9B45208E4925A40C408E1D1C6FB4940D9B45208E4925A40E1EF17B325FD4940F86EF3C649955A40E1EF17B325FD4940F86EF3C649955A40C408E1D1C6FB4940D9B45208E4925A40C408E1D1C6FB4940
76707	6721	106.728273	106.74668800000001	52.030338999999998	52.020246999999998	Селенгинская	0103000020E61000000100000005000000D4635B069CAE5A40CA6B257497024A40D4635B069CAE5A408C65FA25E2034A40341477BCC9AF5A408C65FA25E2034A40341477BCC9AF5A40CA6B257497024A40D4635B069CAE5A40CA6B257497024A40
76884	60982	106.192437	106.200863	51.939413000000002	51.933788999999997	Вокзальная	0103000020E61000000100000005000000956247E3508C5A40A92EE06586F74940956247E3508C5A40F83768AF3EF849407EFE7BF0DA8C5A40F83768AF3EF849407EFE7BF0DA8C5A40A92EE06586F74940956247E3508C5A40A92EE06586F74940
74858	8338	105.841402	105.89354899999999	51.721324000000003	51.703332000000003	Комсомольская	0103000020E610000001000000050000007F32C687D9755A407A1D71C806DA49407F32C687D9755A40F3E8465854DC4940E71725E82F795A40F3E8465854DC4940E71725E82F795A407A1D71C806DA49407F32C687D9755A407A1D71C806DA4940
74911	8338	105.841402	105.89354899999999	51.721324000000003	51.703332000000003	3 Интернационала	0103000020E610000001000000050000007F32C687D9755A407A1D71C806DA49407F32C687D9755A40F3E8465854DC4940E71725E82F795A40F3E8465854DC4940E71725E82F795A407A1D71C806DA49407F32C687D9755A407A1D71C806DA4940
76610	60880	106.977942	107.004244	51.642938000000001	51.618831999999998	Ленина	0103000020E61000000100000005000000A1D80A9A96BE5A40F0DB10E335CF4940A1D80A9A96BE5A4086ADD9CA4BD24940124DA08845C05A4086ADD9CA4BD24940124DA08845C05A40F0DB10E335CF4940A1D80A9A96BE5A40F0DB10E335CF4940
76689	60899	107.421925	107.44225400000001	51.795088999999997	51.787151000000001	Иркутский переулок	0103000020E610000001000000050000005917B7D100DB5A40C1012D5DC1E449405917B7D100DB5A406534F279C5E549409DA1B8E34DDC5A406534F279C5E549409DA1B8E34DDC5A40C1012D5DC1E449405917B7D100DB5A40C1012D5DC1E44940
76719	4821	107.042153	107.093025	51.526620000000001	51.508932000000001	Ранжурова	0103000020E61000000100000005000000691B7FA2B2C25A40A6F10BAF24C14940691B7FA2B2C25A40B3B5BE4868C34940772D211FF4C55A40B3B5BE4868C34940772D211FF4C55A40A6F10BAF24C14940691B7FA2B2C25A40A6F10BAF24C14940
75695	4821	107.042153	107.093025	51.526620000000001	51.508932000000001	Абидуева	0103000020E61000000100000005000000691B7FA2B2C25A40A6F10BAF24C14940691B7FA2B2C25A40B3B5BE4868C34940772D211FF4C55A40B3B5BE4868C34940772D211FF4C55A40A6F10BAF24C14940691B7FA2B2C25A40A6F10BAF24C14940
71581	4063	107.463059	107.472922	51.781132999999997	51.771047000000003	Советская	0103000020E61000000100000005000000954737C2A2DD5A40E75608ABB1E24940954737C2A2DD5A40C669882AFCE34940C5E3A25A44DE5A40C669882AFCE34940C5E3A25A44DE5A40E75608ABB1E24940954737C2A2DD5A40E75608ABB1E24940
74807	45473	107.454848	107.48947800000001	51.914344	51.866847999999997	Трактовая	0103000020E61000000100000005000000AA29C93A1CDD5A402F4D11E0F4EE4940AA29C93A1CDD5A409CA5643909F549402387889B53DF5A409CA5643909F549402387889B53DF5A402F4D11E0F4EE4940AA29C93A1CDD5A402F4D11E0F4EE4940
74798	45473	107.454848	107.48947800000001	51.914344	51.866847999999997	Партизанская	0103000020E61000000100000005000000AA29C93A1CDD5A402F4D11E0F4EE4940AA29C93A1CDD5A409CA5643909F549402387889B53DF5A409CA5643909F549402387889B53DF5A402F4D11E0F4EE4940AA29C93A1CDD5A402F4D11E0F4EE4940
76670	21262	107.382561	107.405809	51.621901999999999	51.609403	Бабушкина	0103000020E6100000010000000500000067EE21E17BD85A40CA8AE1EA00CE494067EE21E17BD85A4093A8177C9ACF49400ADB4FC6F8D95A4093A8177C9ACF49400ADB4FC6F8D95A40CA8AE1EA00CE494067EE21E17BD85A40CA8AE1EA00CE4940
76834	52463	107.421395	107.42921	51.656382999999998	51.647162999999999	Ленина	0103000020E61000000100000005000000ABECBB22F8DA5A403317B83CD6D24940ABECBB22F8DA5A403F53AF5B04D449406F47382D78DB5A403F53AF5B04D449406F47382D78DB5A403317B83CD6D24940ABECBB22F8DA5A403317B83CD6D24940
76631	26360	107.529426	107.54277500000001	51.812615000000001	51.802568999999998	Советская	0103000020E61000000100000005000000BCE9961DE2E15A4047E4BB94BAE64940BCE9961DE2E15A40999EB0C403E8494088855AD3BCE25A40999EB0C403E8494088855AD3BCE25A4047E4BB94BAE64940BCE9961DE2E15A4047E4BB94BAE64940
76762	3808	107.46375999999999	107.480091	51.964002999999998	51.955984000000001	Школьная	0103000020E61000000100000005000000594C6C3EAEDD5A40E8BF07AF5DFA4940594C6C3EAEDD5A40791F477364FB4940A7069ACFB9DE5A40791F477364FB4940A7069ACFB9DE5A40E8BF07AF5DFA4940594C6C3EAEDD5A40E8BF07AF5DFA4940
76637	4780	107.04321299999999	107.060928	51.536777999999998	51.526373	Почтовая	0103000020E61000000100000005000000C5707500C4C25A40AB3FC23060C34940C5707500C4C25A402C9B3924B5C4494049DA8D3EE6C35A402C9B3924B5C4494049DA8D3EE6C35A40AB3FC23060C34940C5707500C4C25A40AB3FC23060C34940
71587	4141	107.40452500000001	107.43376499999999	51.775103999999999	51.768532999999998	Коммунистическая	0103000020E61000000100000005000000865AD3BCE3D95A40C972124A5FE24940865AD3BCE3D95A40D87F9D9B36E34940904946CEC2DB5A40D87F9D9B36E34940904946CEC2DB5A40C972124A5FE24940865AD3BCE3D95A40C972124A5FE24940
71711	21329	107.49782399999999	107.52772899999999	51.743870000000001	51.727366000000004	Ленина	0103000020E610000001000000050000007DCA3159DCDF5A40761C3F541ADD49407DCA3159DCDF5A40DE3CD52137DF4940A609DB4FC6E15A40DE3CD52137DF4940A609DB4FC6E15A40761C3F541ADD49407DCA3159DCDF5A40761C3F541ADD4940
76753	4260	107.27031599999999	107.297068	51.795439999999999	51.785992	Партизанская	0103000020E6100000010000000500000079E57ADB4CD15A407575C7629BE4494079E57ADB4CD15A4012F758FAD0E549400A2C802903D35A4012F758FAD0E549400A2C802903D35A407575C7629BE4494079E57ADB4CD15A407575C7629BE44940
76703	45685	107.363867	107.379794	51.658349999999999	51.644710000000003	Центральная	0103000020E61000000100000005000000FE45D09849D75A40BCB376DB85D24940FE45D09849D75A402AA913D044D44940E44D7E8B4ED85A402AA913D044D44940E44D7E8B4ED85A40BCB376DB85D24940FE45D09849D75A40BCB376DB85D24940
76868	4928	107.006912	107.032191	51.427796000000001	51.412934999999997	Проточная	0103000020E61000000100000005000000CC7C073F71C05A40D72FD80DDBB44940CC7C073F71C05A4008AEF204C2B649406F0ED76A0FC25A4008AEF204C2B649406F0ED76A0FC25A40D72FD80DDBB44940CC7C073F71C05A40D72FD80DDBB44940
76536	4688	107.08225400000001	107.14420200000001	51.763066000000002	51.751342000000001	Школьная	0103000020E61000000100000005000000C6FD47A643C55A403D0E83F92BE04940C6FD47A643C55A4043588D25ACE149402481069B3AC95A4043588D25ACE149402481069B3AC95A403D0E83F92BE04940C6FD47A643C55A403D0E83F92BE04940
75692	3615	107.257075	107.303096	51.761611000000002	51.734768000000003	Первомайская	0103000020E61000000100000005000000A167B3EA73D05A40DC12B9E00CDE4940A167B3EA73D05A400EA320787CE1494019E3C3EC65D35A400EA320787CE1494019E3C3EC65D35A40DC12B9E00CDE4940A167B3EA73D05A40DC12B9E00CDE4940
71591	3615	107.257075	107.303096	51.761611000000002	51.734768000000003	Ленина	0103000020E61000000100000005000000A167B3EA73D05A40DC12B9E00CDE4940A167B3EA73D05A400EA320787CE1494019E3C3EC65D35A400EA320787CE1494019E3C3EC65D35A40DC12B9E00CDE4940A167B3EA73D05A40DC12B9E00CDE4940
75690	4010	107.39609900000001	107.422186	51.834097	51.811624000000002	Луговая	0103000020E610000001000000050000009DBE9EAF59D95A400953944BE3E749409DBE9EAF59D95A408A58C4B0C3EA49400FB56D1805DB5A408A58C4B0C3EA49400FB56D1805DB5A400953944BE3E749409DBE9EAF59D95A400953944BE3E74940
76889	4900	107.21462099999999	107.266858	51.522686	51.515070000000001	Набережная	0103000020E610000001000000050000003A02B859BCCD5A404B9352D0EDC149403A02B859BCCD5A40DD09F65FE7C2494043AB933314D15A40DD09F65FE7C2494043AB933314D15A404B9352D0EDC149403A02B859BCCD5A404B9352D0EDC14940
76749	21352	107.46504400000001	107.48697199999999	51.717312	51.707680000000003	Школьная	0103000020E61000000100000005000000DECCE847C3DD5A4043041C4295DA4940DECCE847C3DD5A40A1832EE1D0DB494055849B8C2ADF5A40A1832EE1D0DB494055849B8C2ADF5A4043041C4295DA4940DECCE847C3DD5A4043041C4295DA4940
76609	4592	107.18705199999999	107.204362	51.758583999999999	51.744259999999997	Центральная	0103000020E61000000100000005000000B0A9F3A8F8CB5A4048DC63E943DF4940B0A9F3A8F8CB5A406AA2CF4719E14940E4A25A4414CD5A406AA2CF4719E14940E4A25A4414CD5A4048DC63E943DF4940B0A9F3A8F8CB5A4048DC63E943DF4940
76835	21468	107.538949	107.568315	51.648426000000001	51.631636	Ленина	0103000020E61000000100000005000000904DF2237EE25A40F67CCD72D9D04940904DF2237EE25A4024F0879FFFD24940E1B4E0455FE45A4024F0879FFFD24940E1B4E0455FE45A40F67CCD72D9D04940904DF2237EE25A40F67CCD72D9D04940
76797	60937	107.644294	109.384996	52.358798	51.399799000000002	Цыдыпова	0103000020E6100000010000000500000094C0E61C3CE95A409CFC169D2CB3494094C0E61C3CE95A4063EFC517ED2D4A40D04543C6A3585B4063EFC517ED2D4A40D04543C6A3585B409CFC169D2CB3494094C0E61C3CE95A409CFC169D2CB34940
75835	1286	107.807626	107.83489899999999	51.897035000000002	51.880220999999999	Гагарина	0103000020E610000001000000050000008E59F624B0F35A404F20EC14ABF049408E59F624B0F35A40062FFA0AD2F24940A31D37FC6EF55A40062FFA0AD2F24940A31D37FC6EF55A404F20EC14ABF049408E59F624B0F35A404F20EC14ABF04940
77021	61035	108.491962	108.509857	51.741459999999996	51.732464	Центральная	0103000020E61000000100000005000000FC372F4E7C1F5B40A9BF5E61C1DD4940FC372F4E7C1F5B4065A54929E8DE4940BF28417FA1205B4065A54929E8DE4940BF28417FA1205B40A9BF5E61C1DD4940FC372F4E7C1F5B40A9BF5E61C1DD4940
76526	1025	108.308077	108.329134	51.483116000000003	51.467111000000003	Советская	0103000020E6100000010000000500000096E99788B7135B400A4D124BCABB494096E99788B7135B405116BEBED6BD49401B800D8810155B405116BEBED6BD49401B800D8810155B400A4D124BCABB494096E99788B7135B400A4D124BCABB4940
76615	60882	108.354799	108.37201899999999	51.761175999999999	51.753711000000003	переулок Связи	0103000020E61000000100000005000000D369DD06B5165B4057D11F9A79E04940D369DD06B5165B40034015376EE14940669FC728CF175B40034015376EE14940669FC728CF175B4057D11F9A79E04940D369DD06B5165B4057D11F9A79E04940
76590	475	108.355158	108.40198700000001	51.762931999999999	51.750410000000002	Клубная	0103000020E610000001000000050000006BBA9EE8BA165B40B24B546F0DE049406BBA9EE8BA165B4033897AC1A7E14940B39AAE27BA195B4033897AC1A7E14940B39AAE27BA195B40B24B546F0DE049406BBA9EE8BA165B40B24B546F0DE04940
76690	862	109.30466800000001	109.322796	51.765495999999999	51.758454999999998	Центральная	0103000020E61000000100000005000000D10836AE7F535B406C3EAE0D15E14940D10836AE7F535B40029CDEC5FBE14940E5D18DB0A8545B40029CDEC5FBE14940E5D18DB0A8545B406C3EAE0D15E14940D10836AE7F535B406C3EAE0D15E14940
76629	32483	108.12642	108.14824	51.947330000000001	51.925196999999997	Победы	0103000020E61000000100000005000000DC63E94317085B40BCADF4DA6CF64940DC63E94317085B408542041C42F9494061FD9FC37C095B408542041C42F9494061FD9FC37C095B40BCADF4DA6CF64940DC63E94317085B40BCADF4DA6CF64940
75837	1594	108.546688	108.58573699999999	52.120448000000003	52.079735999999997	Школьная	0103000020E610000001000000050000006747AAEFFC225B402C280CCA340A4A406747AAEFFC225B402F6F0ED76A0F4A40A8C30AB77C255B402F6F0ED76A0F4A40A8C30AB77C255B402C280CCA340A4A406747AAEFFC225B402C280CCA340A4A40
76913	688	108.881238	108.910928	51.688561	51.679358999999998	Ленина	0103000020E61000000100000005000000847F113466385B40239F573CF5D64940847F113466385B40892650C422D84940AF40F4A44C3A5B40892650C422D84940AF40F4A44C3A5B40239F573CF5D64940847F113466385B40239F573CF5D64940
75832	531	108.387156	108.406452	51.691799000000003	51.680413999999999	Спортивная	0103000020E61000000100000005000000D09CF529C7185B40CADE52CE17D74940D09CF529C7185B40E833A0DE8CD8494034D93F4F031A5B40E833A0DE8CD8494034D93F4F031A5B40CADE52CE17D74940D09CF529C7185B40CADE52CE17D74940
76675	1292	108.03871700000001	108.06215400000001	51.949506	51.932045000000002	Клубная	0103000020E610000001000000050000002733DE567A025B403EB324404DF749402733DE567A025B408AADA06989F949403354C554FA035B408AADA06989F949403354C554FA035B403EB324404DF749402733DE567A025B403EB324404DF74940
76961	1511	108.501305	108.528676	52.009971	52.003069000000004	Школьная	0103000020E610000001000000050000009014916115205B40D350A39064004A409014916115205B404774CFBA46014A40878BDCD3D5215B404774CFBA46014A40878BDCD3D5215B40D350A39064004A409014916115205B40D350A39064004A40
76880	898	108.111768	108.141161	51.594712000000001	51.567025000000001	Центральная	0103000020E61000000100000005000000512FF83427075B40D881734694C84940512FF83427075B40F644D7851FCC49401F9E25C808095B40F644D7851FCC49401F9E25C808095B40D881734694C84940512FF83427075B40D881734694C84940
76635	1411	108.385368	108.409677	52.044859000000002	52.017726000000003	Школьная	0103000020E61000000100000005000000323B8BDEA9185B40FB2477D844024A40323B8BDEA9185B4034F790F0BD054A40193BE125381A5B4034F790F0BD054A40193BE125381A5B40FB2477D844024A40323B8BDEA9185B40FB2477D844024A40
76794	60934	108.011741	108.022368	51.982627999999998	51.973757999999997	Харза	0103000020E610000001000000050000006EC1525DC0005B40F31B261AA4FC49406EC1525DC0005B4023111AC1C6FD4940861E317A6E015B4023111AC1C6FD4940861E317A6E015B40F31B261AA4FC49406EC1525DC0005B40F31B261AA4FC4940
76588	60877	108.001015	108.098123	51.941662000000001	51.902431	Серова	0103000020E610000001000000050000008CF337A110005B40C3F2E7DB82F349408CF337A110005B4067F1626188F8494011FFB0A547065B4067F1626188F8494011FFB0A547065B40C3F2E7DB82F349408CF337A110005B40C3F2E7DB82F34940
74723	32193	108.001015	108.098123	51.941662000000001	51.902431	Школьная	0103000020E610000001000000050000008CF337A110005B40C3F2E7DB82F349408CF337A110005B4067F1626188F8494011FFB0A547065B4067F1626188F8494011FFB0A547065B40C3F2E7DB82F349408CF337A110005B40C3F2E7DB82F34940
75829	32193	108.001015	108.098123	51.941662000000001	51.902431	Серова	0103000020E610000001000000050000008CF337A110005B40C3F2E7DB82F349408CF337A110005B4067F1626188F8494011FFB0A547065B4067F1626188F8494011FFB0A547065B40C3F2E7DB82F349408CF337A110005B40C3F2E7DB82F34940
76521	32193	108.001015	108.098123	51.941662000000001	51.902431	Промышленная	0103000020E610000001000000050000008CF337A110005B40C3F2E7DB82F349408CF337A110005B4067F1626188F8494011FFB0A547065B4067F1626188F8494011FFB0A547065B40C3F2E7DB82F349408CF337A110005B40C3F2E7DB82F34940
76653	32193	108.001015	108.098123	51.941662000000001	51.902431	40 Лет ЛПК	0103000020E610000001000000050000008CF337A110005B40C3F2E7DB82F349408CF337A110005B4067F1626188F8494011FFB0A547065B4067F1626188F8494011FFB0A547065B40C3F2E7DB82F349408CF337A110005B40C3F2E7DB82F34940
75687	169	108.68383300000001	108.762688	51.690838999999997	51.670544999999997	Полевая	0103000020E610000001000000050000003DBB7CEBC32B5B4087BF266BD4D549403DBB7CEBC32B5B4092E68F696DD849404E4354E1CF305B4092E68F696DD849404E4354E1CF305B4087BF266BD4D549403DBB7CEBC32B5B4087BF266BD4D54940
71570	169	108.68383300000001	108.762688	51.690838999999997	51.670544999999997	Ленина	0103000020E610000001000000050000003DBB7CEBC32B5B4087BF266BD4D549403DBB7CEBC32B5B4092E68F696DD849404E4354E1CF305B4092E68F696DD849404E4354E1CF305B4087BF266BD4D549403DBB7CEBC32B5B4087BF266BD4D54940
76696	1560	108.503497	108.520448	52.050553000000001	52.032910000000001	Советская	0103000020E6100000010000000500000095287B4B39205B400EDB166536044A4095287B4B39205B407BDB4C8578064A4031D120054F215B407BDB4C8578064A4031D120054F215B400EDB166536044A4095287B4B39205B400EDB166536044A40
75685	29982	108.237398	108.29409	51.732965999999998	51.696745	Октябрьская	0103000020E61000000100000005000000B1886187310F5B406553AEF02ED94940B1886187310F5B403B8A73D4D1DD49402905DD5ED2125B403B8A73D4D1DD49402905DD5ED2125B406553AEF02ED94940B1886187310F5B406553AEF02ED94940
76598	30	107.889363	107.978386	51.896079	51.877262999999999	Новая	0103000020E6100000010000000500000070D1C952EBF85A40D47E6B274AF0494070D1C952EBF85A40F2D077B7B2F24940503750E09DFE5A40F2D077B7B2F24940503750E09DFE5A40D47E6B274AF0494070D1C952EBF85A40D47E6B274AF04940
76890	1393	108.278577	108.296767	52.011339999999997	52.000652000000002	Раднаева	0103000020E61000000100000005000000BD1AA034D4115B40A8565F5D15004A40BD1AA034D4115B407D91D09673014A400DE2033BFE125B407D91D09673014A400DE2033BFE125B40A8565F5D15004A40BD1AA034D4115B40A8565F5D15004A40
77015	52879	109.070459	109.086378	51.717641	51.70984	Школьная	0103000020E610000001000000050000005E2D776682445B4042B28009DCDA49405E2D776682445B4066A208A9DBDB49400246973787455B4066A208A9DBDB49400246973787455B4042B28009DCDA49405E2D776682445B4042B28009DCDA4940
76877	699	108.80401000000001	108.816847	51.761521000000002	51.747070000000001	Афанасьева	0103000020E610000001000000050000000CEA5BE674335B404FE960FD9FDF49400CEA5BE674335B40CE1B278579E149407CB5A33847345B40CE1B278579E149407CB5A33847345B404FE960FD9FDF49400CEA5BE674335B404FE960FD9FDF4940
76695	1191	108.877106	108.88850600000001	51.460911000000003	51.452330000000003	Железнодорожная	0103000020E610000001000000050000000648348122385B40F67F0EF3E5B949400648348122385B40EFAEB321FFBA494030134548DD385B40EFAEB321FFBA494030134548DD385B40F67F0EF3E5B949400648348122385B40F67F0EF3E5B94940
75689	417	108.492519	108.557216	51.732591999999997	51.712217000000003	Трактовая	0103000020E61000000100000005000000276A696E851F5B40DF5339ED29DB4940276A696E851F5B40D6A71C93C5DD4940B5334C6DA9235B40D6A71C93C5DD4940B5334C6DA9235B40DF5339ED29DB4940276A696E851F5B40DF5339ED29DB4940
76593	32098	108.250738	108.301142	51.849499000000002	51.817864999999998	пер.Молодежный	0103000020E61000000100000005000000537765170C105B4082C5E1CCAFE84940537765170C105B400B7E1B62BCEC4940EE5C18E945135B400B7E1B62BCEC4940EE5C18E945135B4082C5E1CCAFE84940537765170C105B4082C5E1CCAFE84940
74764	32098	108.250738	108.301142	51.849499000000002	51.817864999999998	Ленина	0103000020E61000000100000005000000537765170C105B4082C5E1CCAFE84940537765170C105B400B7E1B62BCEC4940EE5C18E945135B400B7E1B62BCEC4940EE5C18E945135B4082C5E1CCAFE84940537765170C105B4082C5E1CCAFE84940
76764	48986	108.77083500000001	108.79654499999999	51.569679000000001	51.549404000000003	Лесная	0103000020E610000001000000050000002EE7525C55315B405325CADE52C649402EE7525C55315B40E71BD13DEBC84940B532E197FA325B40E71BD13DEBC84940B532E197FA325B405325CADE52C649402EE7525C55315B405325CADE52C64940
74978	48986	108.77083500000001	108.79654499999999	51.569679000000001	51.549404000000003	Железнодорожная	0103000020E610000001000000050000002EE7525C55315B405325CADE52C649402EE7525C55315B40E71BD13DEBC84940B532E197FA325B40E71BD13DEBC84940B532E197FA325B405325CADE52C649402EE7525C55315B405325CADE52C64940
76954	967	108.034226	108.05566899999999	51.540733000000003	51.535232000000001	Гаражная	0103000020E6100000010000000500000011AB3FC230025B40E7E26F7B82C4494011AB3FC230025B401A6F2BBD36C54940AA99B51490035B401A6F2BBD36C54940AA99B51490035B40E7E26F7B82C4494011AB3FC230025B40E7E26F7B82C44940
76931	31035	110.726558	110.744919	52.431891999999998	52.417465	Гомбоева	0103000020E610000001000000050000006B2920ED7FAE5B40C11C3D7E6F354A406B2920ED7FAE5B40B7B3AF3C48374A40D1CABDC0ACAF5B40B7B3AF3C48374A40D1CABDC0ACAF5B40C11C3D7E6F354A406B2920ED7FAE5B40C11C3D7E6F354A40
76782	31716	111.698508	111.71160500000001	52.685723000000003	52.669420000000002	Школьная	0103000020E61000000100000005000000A4FFE55AB4EC5B40E8A4F78DAF554A40A4FFE55AB4EC5B40B98E71C5C5574A40E3AAB2EF8AED5B40B98E71C5C5574A40E3AAB2EF8AED5B40E8A4F78DAF554A40A4FFE55AB4EC5B40E8A4F78DAF554A40
76791	60930	112.852349	112.87848099999999	52.611691	52.600217000000001	переулок Школьный	0103000020E61000000100000005000000D0F1D1E28C365C406AC020E9D34C4A40D0F1D1E28C365C40F72004E44B4E4A40124A5F0839385C40F72004E44B4E4A40124A5F0839385C406AC020E9D34C4A40D0F1D1E28C365C406AC020E9D34C4A40
76786	31825	111.81643	111.82711999999999	52.822929999999999	52.815320999999997	Бадмаева	0103000020E610000001000000050000004A5E9D6340F45B40FA5E43705C684A404A5E9D6340F45B40DA722EC555694A408577B988EFF45B40DA722EC555694A408577B988EFF45B40FA5E43705C684A404A5E9D6340F45B40FA5E43705C684A40
76886	60984	110.892216	110.899573	52.363472999999999	52.360300000000002	Хангирская	0103000020E61000000100000005000000F33D23111AB95B40D95F764F1E2E4A40F33D23111AB95B4050FD8348862E4A4056D7A19A92B95B4050FD8348862E4A4056D7A19A92B95B40D95F764F1E2E4A40F33D23111AB95B40D95F764F1E2E4A40
76614	30893	110.600605	110.618903	52.339517000000001	52.326715999999998	Дамдинова	0103000020E610000001000000050000001A34F44F70A65B403B8A73D4D1294A401A34F44F70A65B40D0B7054B752B4A405D19541B9CA75B40D0B7054B752B4A405D19541B9CA75B403B8A73D4D1294A401A34F44F70A65B403B8A73D4D1294A40
76476	30822	110.52502	110.55592300000001	52.234279999999998	52.212251000000002	Ленина	0103000020E61000000100000005000000BD6F7CED99A15B408BC56F0A2B1B4A40BD6F7CED99A15B40AE0D15E3FC1D4A400806103E94A35B40AE0D15E3FC1D4A400806103E94A35B408BC56F0A2B1B4A40BD6F7CED99A15B408BC56F0A2B1B4A40
76870	60976	110.272792	114.369738	53.757697	52.013696000000003	Центральная	0103000020E6100000010000000500000011A7936C75915B40030B60CAC0014A4011A7936C75915B407FA31D37FCE04A40A98592C9A9975C407FA31D37FCE04A40A98592C9A9975C40030B60CAC0014A4011A7936C75915B40030B60CAC0014A40
76801	31298	111.397428	111.41762199999999	52.531874999999999	52.519157999999997	Центральная	0103000020E61000000100000005000000F1A0D9756FD95B4077BAF3C473424A40F1A0D9756FD95B40AE47E17A14444A40C405A051BADA5B40AE47E17A14444A40C405A051BADA5B4077BAF3C473424A40F1A0D9756FD95B4077BAF3C473424A40
76953	31696	111.57631000000001	111.59011700000001	52.692627999999999	52.681213999999997	Ленина	0103000020E61000000100000005000000E6965643E2E45B40E6C9350532574A40E6965643E2E45B409E25C808A8584A4013F4177AC4E55B409E25C808A8584A4013F4177AC4E55B40E6C9350532574A40E6965643E2E45B40E6C9350532574A40
76800	30859	110.537148	110.561061	52.312811000000004	52.300927999999999	Почтовая	0103000020E61000000100000005000000284701A260A25B40B03907CF84264A40284701A260A25B401F6ADB300A284A40E883656CE8A35B401F6ADB300A284A40E883656CE8A35B40B03907CF84264A40284701A260A25B40B03907CF84264A40
76602	31944	113.278465	113.29771599999999	52.745834000000002	52.729635000000002	Ланцева	0103000020E610000001000000050000002905DD5ED2515C402C82FFAD645D4A402905DD5ED2515C40581F0F7D775F4A40BDDF68C70D535C40581F0F7D775F4A40BDDF68C70D535C402C82FFAD645D4A402905DD5ED2515C402C82FFAD645D4A40
76662	31453	111.502073	111.576454	52.547671000000001	52.50658	Перовмайская	0103000020E6100000010000000500000018CDCAF621E05B4062670A9DD7404A4018CDCAF621E05B40DBFB54151A464A407F69519FE4E45B40DBFB54151A464A407F69519FE4E45B4062670A9DD7404A4018CDCAF621E05B4062670A9DD7404A40
76522	31453	111.502073	111.576454	52.547671000000001	52.50658	Первомайская	0103000020E6100000010000000500000018CDCAF621E05B4062670A9DD7404A4018CDCAF621E05B40DBFB54151A464A407F69519FE4E45B40DBFB54151A464A407F69519FE4E45B4062670A9DD7404A4018CDCAF621E05B4062670A9DD7404A40
76525	31453	111.502073	111.576454	52.547671000000001	52.50658	Заречная	0103000020E6100000010000000500000018CDCAF621E05B4062670A9DD7404A4018CDCAF621E05B40DBFB54151A464A407F69519FE4E45B40DBFB54151A464A407F69519FE4E45B4062670A9DD7404A4018CDCAF621E05B4062670A9DD7404A40
76678	60898	112.75182700000001	112.793042	53.223618999999999	53.203159999999997	Первомайская	0103000020E61000000100000005000000FD4FFEEE1D305C407CED9925019A4A40FD4FFEEE1D305C40D2E1218C9F9C4A40AF963B33C1325C40D2E1218C9F9C4A40AF963B33C1325C407CED9925019A4A40FD4FFEEE1D305C407CED9925019A4A40
76924	31017	110.69619400000001	110.72603599999999	52.387889000000001	52.379413	Школьная	0103000020E61000000100000005000000F96A47718EAC5B40B056ED9A90304A40F96A47718EAC5B4034BDC458A6314A40FEEDB25F77AE5B4034BDC458A6314A40FEEDB25F77AE5B40B056ED9A90304A40F96A47718EAC5B40B056ED9A90304A40
76950	31852	111.690117	111.70284700000001	52.935133	52.924982	Комсомольская	0103000020E61000000100000005000000795A7EE02AEC5B40C0B167CF65764A40795A7EE02AEC5B4087342A70B2774A40DFC5FB71FBEC5B4087342A70B2774A40DFC5FB71FBEC5B40C0B167CF65764A40795A7EE02AEC5B40C0B167CF65764A40
76589	31117	110.77868700000001	110.80127	52.418349999999997	52.406281	Цырендылыкова	0103000020E6100000010000000500000081B4FF01D6B15B403BFE0B0401344A4081B4FF01D6B15B400B24287E8C354A400551F70148B35B400B24287E8C354A400551F70148B35B403BFE0B0401344A4081B4FF01D6B15B403BFE0B0401344A40
76796	60936	111.076505	111.117361	52.487527999999998	52.474632999999997	Советская	0103000020E61000000100000005000000C03E3A75E5C45B401A4D2EC6C03C4A40C03E3A75E5C45B4030F14751673E4A40DB34B6D782C75B4030F14751673E4A40DB34B6D782C75B401A4D2EC6C03C4A40C03E3A75E5C45B401A4D2EC6C03C4A40
76514	31928	111.982429	112.01806500000001	52.920155999999999	52.902799999999999	Клубная	0103000020E610000001000000050000001669E21DE0FE5B40166A4DF38E734A401669E21DE0FE5B40ED9BFBABC7754A40F20C1AFA27015C40ED9BFBABC7754A40F20C1AFA27015C40166A4DF38E734A401669E21DE0FE5B40166A4DF38E734A40
76865	31652	111.70540699999999	111.72132499999999	52.567267000000001	52.556767000000001	Сампилова	0103000020E61000000100000005000000A5D7666325ED5B40FB3E1C2444474A40A5D7666325ED5B40CE8C7E349C484A40613255302AEE5B40CE8C7E349C484A40613255302AEE5B40FB3E1C2444474A40A5D7666325ED5B40FB3E1C2444474A40
76592	31779	111.711246	111.73933599999999	52.790692	52.769623000000003	Ленина	0103000020E610000001000000050000004B5AF10D85ED5B40ED9FA70183624A404B5AF10D85ED5B40BB9A3C6535654A405930F14751EF5B40BB9A3C6535654A405930F14751EF5B40ED9FA70183624A404B5AF10D85ED5B40ED9FA70183624A40
76866	31242	111.22371200000001	111.250105	52.537019000000001	52.526583000000002	Школьная	0103000020E6100000010000000500000042EE224C51CE5B4096D05D1267434A4042EE224C51CE5B40522AE109BD444A403BE466B801D05B40522AE109BD444A403BE466B801D05B4096D05D1267434A4042EE224C51CE5B4096D05D1267434A40
76803	31391	111.43961299999999	111.449001	52.576549	52.571781999999999	Орлова	0103000020E610000001000000050000005F79909E22DC5B4082380F2730494A405F79909E22DC5B4050C58D5BCC494A40C3B7B06EBCDC5B4050C58D5BCC494A40C3B7B06EBCDC5B4082380F2730494A405F79909E22DC5B4082380F2730494A40
76699	60904	105.29101300000001	105.311971	50.737077999999997	50.721826	Шарапова	0103000020E610000001000000050000007F6DFDF49F525A4085B35BCB645C49407F6DFDF49F525A40F04C6892585E49403A933655F7535A40F04C6892585E49403A933655F7535A4085B35BCB645C49407F6DFDF49F525A4085B35BCB645C4940
76854	30655	106.024012	106.03871700000001	50.440126999999997	50.430483000000002	Набережная	0103000020E610000001000000050000008AADA06989815A40F33D23111A3749408AADA06989815A40158BDF14563849402733DE567A825A40158BDF14563849402733DE567A825A40F33D23111A3749408AADA06989815A40F33D23111A374940
76941	29311	104.685064	104.693786	50.497391999999998	50.482686999999999	Центральная	0103000020E61000000100000005000000AFEAAC16D82B5A40289A07B0C83D4940AFEAAC16D82B5A4061A5828AAA3F49400D1B65FD662C5A4061A5828AAA3F49400D1B65FD662C5A40289A07B0C83D4940AFEAAC16D82B5A40289A07B0C83D4940
76766	60914	106.192994	106.199803	50.578010999999996	50.571032000000002	Ульянова	0103000020E61000000100000005000000C09481035A8C5A40187C9A9317494940C09481035A8C5A4037DDB243FC49494022A98592C98C5A4037DDB243FC49494022A98592C98C5A40187C9A9317494940C09481035A8C5A40187C9A9317494940
76724	60914	106.192994	106.199803	50.578010999999996	50.571032000000002	Патархеева	0103000020E61000000100000005000000C09481035A8C5A40187C9A9317494940C09481035A8C5A4037DDB243FC49494022A98592C98C5A4037DDB243FC49494022A98592C98C5A40187C9A9317494940C09481035A8C5A40187C9A9317494940
76944	60995	104.812175	104.824788	50.764204999999997	50.749566000000002	Центральная	0103000020E610000001000000050000003EE8D9ACFA335A40C61858C7F15F49403EE8D9ACFA335A4047382D78D161494087889B53C9345A4047382D78D161494087889B53C9345A40C61858C7F15F49403EE8D9ACFA335A40C61858C7F15F4940
76693	60902	105.10914099999999	105.13008000000001	50.486963000000003	50.481012999999997	Ленина	0103000020E61000000100000005000000C669882AFC465A40B5F97FD5913D4940C669882AFC465A4058AEB7CD543E49404777103B53485A4058AEB7CD543E49404777103B53485A40B5F97FD5913D4940C669882AFC465A40B5F97FD5913D4940
76857	60970	105.558891	105.56472100000001	50.529027999999997	50.522545999999998	Советская	0103000020E61000000100000005000000D7C1C1DEC4635A40EB538EC9E2424940D7C1C1DEC4635A408A558330B743494053978C6324645A408A558330B743494053978C6324645A40EB538EC9E2424940D7C1C1DEC4635A40EB538EC9E2424940
76701	60905	104.969506	104.982775	50.517201999999997	50.504795000000001	Советская	0103000020E61000000100000005000000A6D1E4620C3E5A409817601F9D404940A6D1E4620C3E5A4080B6D5AC33424940E4141DC9E53E5A4080B6D5AC33424940E4141DC9E53E5A409817601F9D404940A6D1E4620C3E5A409817601F9D404940
74979	29818	105.280719	105.351856	50.616576999999999	50.601709	Терешковой	0103000020E610000001000000050000006A17D34CF7515A40BC5AEECC044D49406A17D34CF7515A409F3BC1FEEB4E4940B03907CF84565A409F3BC1FEEB4E4940B03907CF84565A40BC5AEECC044D49406A17D34CF7515A40BC5AEECC044D4940
71565	29818	105.280719	105.351856	50.616576999999999	50.601709	Свердлова	0103000020E610000001000000050000006A17D34CF7515A40BC5AEECC044D49406A17D34CF7515A409F3BC1FEEB4E4940B03907CF84565A409F3BC1FEEB4E4940B03907CF84565A40BC5AEECC044D49406A17D34CF7515A40BC5AEECC044D4940
74733	29818	105.280719	105.351856	50.616576999999999	50.601709	Балтахинова	0103000020E610000001000000050000006A17D34CF7515A40BC5AEECC044D49406A17D34CF7515A409F3BC1FEEB4E4940B03907CF84565A409F3BC1FEEB4E4940B03907CF84565A40BC5AEECC044D49406A17D34CF7515A40BC5AEECC044D4940
76692	29338	104.974833	105.00459499999999	50.544142000000001	50.527819999999998	Центральная	0103000020E61000000100000005000000F183F3A9633E5A405D16139B8F434940F183F3A9633E5A40A530EF71A645494068AED3484B405A40A530EF71A645494068AED3484B405A405D16139B8F434940F183F3A9633E5A405D16139B8F434940
76861	60973	105.747663	105.764974	50.526662999999999	50.519458999999998	Школьная	0103000020E61000000100000005000000795BE9B5D96F5A40724EECA17D424940795BE9B5D96F5A40B28174B16943494094128255F5705A40B28174B16943494094128255F5705A40724EECA17D424940795BE9B5D96F5A40724EECA17D424940
76512	29274	104.80506099999999	104.84367	50.540146	50.520415	А-Мельникова	0103000020E610000001000000050000003E92921E86335A4086AC6EF59C4249403E92921E86335A4059880E812345494072A774B0FE355A4059880E812345494072A774B0FE355A4086AC6EF59C4249403E92921E86335A4086AC6EF59C424940
76788	60928	105.11542	105.136889	50.569665000000001	50.552864999999997	Яковлева	0103000020E610000001000000050000007A53910A63475A40300DC347C44649407A53910A63475A40825660C8EA484940A88B14CAC2485A40825660C8EA484940A88B14CAC2485A40300DC347C44649407A53910A63475A40300DC347C4464940
76882	60980	104.545097	104.57856	50.545332999999999	50.522722999999999	Центральная	0103000020E61000000100000005000000740987DEE2225A40FAEE5696E8424940740987DEE2225A40FC36C478CD45494085B1852007255A40FC36C478CD45494085B1852007255A40FAEE5696E8424940740987DEE2225A40FAEE5696E8424940
76969	60980	104.545097	104.57856	50.545332999999999	50.522722999999999	Вампилова	0103000020E61000000100000005000000740987DEE2225A40FAEE5696E8424940740987DEE2225A40FC36C478CD45494085B1852007255A40FC36C478CD45494085B1852007255A40FAEE5696E8424940740987DEE2225A40FAEE5696E8424940
76860	60972	105.73570599999999	105.758578	50.837891999999997	50.820909999999998	Школьная	0103000020E61000000100000005000000245E9ECE156F5A40CC7A319413694940245E9ECE156F5A403ECA880B406B4940C45DBD8A8C705A403ECA880B406B4940C45DBD8A8C705A40CC7A319413694940245E9ECE156F5A40CC7A319413694940
76798	30549	105.814049	105.847475	50.525047999999998	50.509830000000001	Ленина	0103000020E61000000100000005000000DB15FA6019745A408542041C42414940DB15FA6019745A40446ADAC5344349405E4BC8073D765A40446ADAC5344349405E4BC8073D765A408542041C42414940DB15FA6019745A408542041C42414940
76676	30076	105.404956	105.44294499999999	50.744875999999998	50.727117999999997	Ленина	0103000020E610000001000000050000006A1492CCEA595A409D2ADF33125D49406A1492CCEA595A40A3C9C518585F49404F3BFC35595C5A40A3C9C518585F49404F3BFC35595C5A409D2ADF33125D49406A1492CCEA595A409D2ADF33125D4940
76630	60887	106.047332	106.08886099999999	50.658200999999998	50.646743999999998	Ленина	0103000020E610000001000000050000007903CC7C07835A402E71E481C85249407903CC7C07835A40E5982CEE3F544940F3380CE6AF855A40E5982CEE3F544940F3380CE6AF855A402E71E481C85249407903CC7C07835A402E71E481C8524940
76898	60989	105.452432	105.460876	50.639690000000002	50.629955000000002	Центральная	0103000020E610000001000000050000007DEA58A5F45C5A40D1798D5DA25049407DEA58A5F45C5A4004CAA65CE1514940B9E00CFE7E5D5A4004CAA65CE1514940B9E00CFE7E5D5A40D1798D5DA25049407DEA58A5F45C5A40D1798D5DA2504940
74742	30413	106.165514	106.198914	50.693899000000002	50.668557999999997	Торговая	0103000020E61000000100000005000000EE4108C8978A5A4055BDFC4E93554940EE4108C8978A5A4012DDB3AED1584940DC2DC901BB8C5A4012DDB3AED1584940DC2DC901BB8C5A4055BDFC4E93554940EE4108C8978A5A4055BDFC4E93554940
76677	60897	105.21426099999999	105.232928	50.654597000000003	50.631239999999998	Ч.Раднаева	0103000020E61000000100000005000000BAF3C473B64D5A40A9F6E978CC504940BAF3C473B64D5A40A587A1D5C9534940A794D74AE84E5A40A587A1D5C9534940A794D74AE84E5A40A9F6E978CC504940BAF3C473B64D5A40A9F6E978CC504940
76785	60926	104.810918	104.819317	50.666713999999999	50.646253000000002	Гармаева	0103000020E61000000100000005000000376F9C14E6335A4090F8156BB8524940376F9C14E6335A4086E464E256554940A30392B06F345A4086E464E256554940A30392B06F345A4090F8156BB8524940376F9C14E6335A4090F8156BB8524940
76946	29607	105.044094	105.07344999999999	50.619577999999997	50.606310999999998	Набережная	0103000020E61000000100000005000000CAFCA36FD2425A403F1A4E999B4D4940CAFCA36FD2425A4019A9F7544E4F494009F9A067B3445A4019A9F7544E4F494009F9A067B3445A403F1A4E999B4D4940CAFCA36FD2425A403F1A4E999B4D4940
76697	29746	105.258162	105.27342400000001	50.602052	50.589638999999998	переулок Клубный	0103000020E610000001000000050000007AC4E8B985505A401BB96E4A794B49407AC4E8B985505A40E63E390A104D4940427C60C77F515A40E63E390A104D4940427C60C77F515A401BB96E4A794B49407AC4E8B985505A401BB96E4A794B4940
76853	30570	105.641204	105.66279900000001	50.482061999999999	50.463448	Ленина	0103000020E610000001000000050000001F84807C09695A40C4B29943523B49401F84807C09695A407A522635B43D494094347F4C6B6A5A407A522635B43D494094347F4C6B6A5A40C4B29943523B49401F84807C09695A40C4B29943523B4940
76921	60993	105.82270800000001	105.844088	50.754717999999997	50.738480000000003	Советская	0103000020E61000000100000005000000168A743FA7745A4003603C83865E4940168A743FA7745A40ECD973999A6049408CBCAC8905765A40ECD973999A6049408CBCAC8905765A4003603C83865E4940168A743FA7745A4003603C83865E4940
76625	30176	105.68628099999999	105.722313	50.654733999999998	50.642665999999998	Школьная	0103000020E610000001000000050000006FB72407EC6B5A40252026E1425249406FB72407EC6B5A4025CADE52CE534940711E4E603A6E5A4025CADE52CE534940711E4E603A6E5A40252026E1425249406FB72407EC6B5A40252026E142524940
76873	29134	104.58951	104.598547	50.612490000000001	50.598399000000001	Центральная	0103000020E610000001000000050000008FAA2688BA255A40C47AA356984C49408FAA2688BA255A4043908312664E49409C8713984E265A4043908312664E49409C8713984E265A40C47AA356984C49408FAA2688BA255A40C47AA356984C4940
76925	60994	104.600146	104.628012	50.683135999999998	50.658537000000003	Центральная	0103000020E61000000100000005000000D0B4C4CA68265A405D1ABFF04A544940D0B4C4CA68265A40315C1D0071574940B75F3E5931285A40315C1D0071574940B75F3E5931285A405D1ABFF04A544940D0B4C4CA68265A405D1ABFF04A544940
76634	60888	107.856611	107.88708200000001	50.807422000000003	50.785485000000001	Елаева	0103000020E610000001000000050000003599F1B6D2F65A40D13FC1C58A6449403599F1B6D2F65A401409A69A59674940B3B794F3C5F85A401409A69A59674940B3B794F3C5F85A40D13FC1C58A6449403599F1B6D2F65A40D13FC1C58A644940
76694	60903	108.14222100000001	108.15578600000001	50.839326	50.822071000000001	Токтохоева	0103000020E610000001000000050000007CF31B261A095B40B9FE5D9F396949407CF31B261A095B405C57CC086F6B49402ECBD765F8095B405C57CC086F6B49402ECBD765F8095B40B9FE5D9F396949407CF31B261A095B40B9FE5D9F39694940
77006	61019	107.29526300000001	107.304497	50.622292000000002	50.610770000000002	Центральная	0103000020E61000000100000005000000022EC896E5D25A4060B01BB62D4E4940022EC896E5D25A40FE47A643A74F4940BA2EFCE07CD35A40FE47A643A74F4940BA2EFCE07CD35A4060B01BB62D4E4940022EC896E5D25A4060B01BB62D4E4940
76687	28819	108.007411	108.028881	50.714281999999997	50.695667999999998	Ленина	0103000020E610000001000000050000005DA8FC6B79005B40D66F26A60B5949405DA8FC6B79005B408C0FB3976D5B4940739EB12FD9015B408C0FB3976D5B4940739EB12FD9015B40D66F26A60B5949405DA8FC6B79005B40D66F26A60B594940
76777	28174	107.061817	107.10849399999999	50.482664	50.454099999999997	Смородникова	0103000020E610000001000000050000008F554ACFF4C35A408A8EE4F21F3A49408F554ACFF4C35A40707A17EFC73D4940FB73D190F1C65A40707A17EFC73D4940FB73D190F1C65A408A8EE4F21F3A49408F554ACFF4C35A408A8EE4F21F3A4940
76691	27842	107.49802099999999	107.50595300000001	50.558129999999998	50.538881000000003	Комсомольская	0103000020E6100000010000000500000028EE7893DFDF5A40C8B7770DFA44494028EE7893DFDF5A404F75C8CD704749400A14B18861E05A404F75C8CD704749400A14B18861E05A40C8B7770DFA44494028EE7893DFDF5A40C8B7770DFA444940
76948	28073	107.070154	107.091767	50.567599999999999	50.554473000000002	Заречная	0103000020E61000000100000005000000C0EB33677DC45A40ECC1A4F8F8464940C0EB33677DC45A40D49AE61DA748494088F6B182DFC55A40D49AE61DA748494088F6B182DFC55A40ECC1A4F8F8464940C0EB33677DC45A40ECC1A4F8F8464940
77023	61030	106.91479	106.922839	50.644688000000002	50.630240999999998	Центральная	0103000020E610000001000000050000004D2D5BEB8BBA5A4096CCB1BCAB5049404D2D5BEB8BBA5A40D40FEA22855249404B1E4FCB0FBB5A40D40FEA22855249404B1E4FCB0FBB5A4096CCB1BCAB5049404D2D5BEB8BBA5A4096CCB1BCAB504940
76938	47204	107.90291000000001	107.91202800000001	50.634611	50.600434	Гагарина	0103000020E61000000100000005000000CF4E0647C9F95A4007B47405DB4C4940CF4E0647C9F95A404757E9EE3A5149405342B0AA5EFA5A404757E9EE3A5149405342B0AA5EFA5A4007B47405DB4C4940CF4E0647C9F95A4007B47405DB4C4940
76674	27584	107.509394	107.530495	50.639564	50.620891999999998	Набережная	0103000020E61000000100000005000000D5B14AE999E05A408C2C9963794F4940D5B14AE999E05A4077D9AF3BDD51494042EC4CA1F3E15A4077D9AF3BDD51494042EC4CA1F3E15A408C2C9963794F4940D5B14AE999E05A408C2C9963794F4940
76571	33056	108.136292	108.160736	50.820261000000002	50.799765000000001	Центральная	0103000020E6100000010000000500000036AD1402B9085B4023BE13B35E66494036AD1402B9085B409697FC4FFE6849408DD2A57F490A5B409697FC4FFE6849408DD2A57F490A5B4023BE13B35E66494036AD1402B9085B4023BE13B35E664940
76976	61004	107.888321	107.903206	50.620418000000001	50.607031999999997	Ленина	0103000020E6100000010000000500000067D65240DAF85A400FD07D39B34D494067D65240DAF85A40C4EC65DB694F494043E38920CEF95A40C4EC65DB694F494043E38920CEF95A400FD07D39B34D494067D65240DAF85A400FD07D39B34D4940
76765	45991	107.433549	107.471386	50.722076999999999	50.701115999999999	Первомайская	0103000020E61000000100000005000000AA0D4E44BFDB5A40E659492BBE594940AA0D4E44BFDB5A40CE18E6046D5C4940B4722F302BDE5A40CE18E6046D5C4940B4722F302BDE5A40E659492BBE594940AA0D4E44BFDB5A40E659492BBE594940
76511	28374	107.512134	107.533406	50.725988999999998	50.684409000000002	Гагарина	0103000020E61000000100000005000000DC4AAFCDC6E05A40460BD0B69A574940DC4AAFCDC6E05A40BC202235ED5C49405F5FEB5223E25A40BC202235ED5C49405F5FEB5223E25A40460BD0B69A574940DC4AAFCDC6E05A40460BD0B69A574940
76584	28051	107.09059000000001	107.11536599999999	50.615177000000003	50.583295999999997	Центральная	0103000020E610000001000000050000000FD6FF39CCC55A409DF17D71A94A49400FD6FF39CCC55A402E20B41EBE4E49408044132862C75A402E20B41EBE4E49408044132862C75A409DF17D71A94A49400FD6FF39CCC55A409DF17D71A94A4940
76949	28483	107.667345	107.69848	50.738669000000002	50.712702	Иванова	0103000020E610000001000000050000008B89CDC7B5EA5A409BE5B2D1395B49408B89CDC7B5EA5A40D6C8AEB48C5E49403F3A75E5B3EC5A40D6C8AEB48C5E49403F3A75E5B3EC5A409BE5B2D1395B49408B89CDC7B5EA5A409BE5B2D1395B4940
76869	28363	107.153248	107.17434900000001	50.687998999999998	50.664532999999999	Лесная	0103000020E610000001000000050000005B0BB3D0CEC95A406F0ED76A0F5549405B0BB3D0CEC95A402157EA5910584940C845B58828CB5A402157EA5910584940C845B58828CB5A406F0ED76A0F5549405B0BB3D0CEC95A406F0ED76A0F554940
76783	28539	107.702568	107.728053	50.690612000000002	50.667935999999997	Новая	0103000020E61000000100000005000000D5CDC5DFF6EC5A4018E945ED7E554940D5CDC5DFF6EC5A40D21C59F9655849404D309C6B98EE5A40D21C59F9655849404D309C6B98EE5A4018E945ED7E554940D5CDC5DFF6EC5A4018E945ED7E554940
76862	28625	107.78992	107.861282	50.622703999999999	50.587871999999997	Школьная	0103000020E61000000100000005000000349D9D0C8EF25A40F71DC3633F4B4940349D9D0C8EF25A40508BC1C3B44F49408BA8893E1FF75A40508BC1C3B44F49408BA8893E1FF75A40F71DC3633F4B4940349D9D0C8EF25A40F71DC3633F4B4940
74686	28625	107.78992	107.861282	50.622703999999999	50.587871999999997	Советская	0103000020E61000000100000005000000349D9D0C8EF25A40F71DC3633F4B4940349D9D0C8EF25A40508BC1C3B44F49408BA8893E1FF75A40508BC1C3B44F49408BA8893E1FF75A40F71DC3633F4B4940349D9D0C8EF25A40F71DC3633F4B4940
76552	32946	107.339011	107.36127999999999	50.556282000000003	50.519350000000003	Логовского	0103000020E61000000100000005000000FE7E315BB2D55A40BC96900F7A424940FE7E315BB2D55A403FADA23F34474940BA2C26361FD75A403FADA23F34474940BA2C26361FD75A40BC96900F7A424940FE7E315BB2D55A40BC96900F7A424940
77011	61028	107.448362	107.46489200000001	50.594625000000001	50.577891000000001	Центральная	0103000020E610000001000000050000003AB187F6B1DC5A408DD31055F84949403AB187F6B1DC5A40273108AC1C4C4940030B60CAC0DD5A40273108AC1C4C4940030B60CAC0DD5A408DD31055F84949403AB187F6B1DC5A408DD31055F8494940
76995	61016	107.941654	107.952838	50.807609999999997	50.797128999999998	Школьная	0103000020E610000001000000050000007289230F44FC5A40BAD8B452086649407289230F44FC5A4016F6B4C35F674940B5183C4CFBFC5A4016F6B4C35F674940B5183C4CFBFC5A40BAD8B452086649407289230F44FC5A40BAD8B45208664940
77017	61033	107.74126699999999	107.758129	50.741774999999997	50.735408	Центральная	0103000020E61000000100000005000000A8A624EB70EF5A40BF9B6ED9215E4940A8A624EB70EF5A40C5FEB27BF25E49408C497F2F85F05A40C5FEB27BF25E49408C497F2F85F05A40BF9B6ED9215E4940A8A624EB70EF5A40BF9B6ED9215E4940
76685	28296	107.23698	107.262744	50.678027999999998	50.667130999999998	Дружбы	0103000020E61000000100000005000000977329AE2ACF5A40EA92718C64554940977329AE2ACF5A40DAE21A9FC956494018CE35CCD0D05A40DAE21A9FC956494018CE35CCD0D05A40EA92718C64554940977329AE2ACF5A40EA92718C64554940
76688	28759	107.944529	107.985196	50.650050999999998	50.631863000000003	Трактовая	0103000020E61000000100000005000000E947C32973FC5A40B74604E3E0504940E947C32973FC5A40B5DD04DF345349409A0986730DFF5A40B5DD04DF345349409A0986730DFF5A40B74604E3E0504940E947C32973FC5A40B74604E3E0504940
71562	27404	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	Соломенникова	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
74693	27404	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	Советская	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
74711	27404	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	Рабочая	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
76551	27404	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	Краснопартизанская	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
76582	27404	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	Коммунинстическая	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
76581	27404	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	Кирова	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
76628	27404	107.557104	107.63133999999999	50.643830999999999	50.549877000000002	Калинина	0103000020E61000000100000005000000211E8997A7E35A404BE9995E62464940211E8997A7E35A405393E00D69524940062AE3DF67E85A405393E00D69524940062AE3DF67E85A404BE9995E62464940211E8997A7E35A404BE9995E62464940
76858	60971	107.08617099999999	107.10965299999999	50.786059999999999	50.765664000000001	Молодежная	0103000020E6100000010000000500000045B75ED383C55A40BEDC27470162494045B75ED383C55A40CD58349D9D644940213A048E04C75A40CD58349D9D644940213A048E04C75A40BEDC27470162494045B75ED383C55A40BEDC274701624940
76851	27927	107.427324	107.43663100000001	50.598547000000003	50.584291	Назимова	0103000020E61000000100000005000000F032C34659DB5A406F2C280CCA4A4940F032C34659DB5A40390F27309D4C4940DE5A26C3F1DB5A40390F27309D4C4940DE5A26C3F1DB5A406F2C280CCA4A4940F032C34659DB5A406F2C280CCA4A4940
76897	60967	113.34584700000001	113.359331	54.926425000000002	54.914985000000001	Центральная	0103000020E61000000100000005000000DD9A745B22565C4050AA7D3A1E754B40DD9A745B22565C4031992A1895764B40185C7347FF565C4031992A1895764B40185C7347FF565C4050AA7D3A1E754B40DD9A745B22565C4050AA7D3A1E754B40
76947	60996	111.92886300000001	111.958669	53.669161000000003	53.656019000000001	Северная	0103000020E61000000100000005000000BADDCB7D72FB5B40FE463B6EF8D34A40BADDCB7D72FB5B401C615111A7D54A4019AC38D55AFD5B401C615111A7D54A4019AC38D55AFD5B40FE463B6EF8D34A40BADDCB7D72FB5B40FE463B6EF8D34A40
76883	60981	113.626167	113.64354	55.491976999999999	55.469382000000003	Советская	0103000020E6100000010000000500000067B5C01E13685C4061AA99B514BC4B4067B5C01E13685C402DB1321AF9BE4B40BE6A65C22F695C402DB1321AF9BE4B40BE6A65C22F695C4061AA99B514BC4B4067B5C01E13685C4061AA99B514BC4B40
76935	46427	113.260426	113.286666	54.357883000000001	54.345393999999999	Геологическая	0103000020E61000000100000005000000CC41D0D1AA505C40081EDFDE352C4B40CC41D0D1AA505C40AE65321CCF2D4B4002B859BC58525C40AE65321CCF2D4B4002B859BC58525C40081EDFDE352C4B40CC41D0D1AA505C40081EDFDE352C4B40
77054	61051	114.287623	114.304035	54.296903	54.283602000000002	Центральная	0103000020E61000000100000005000000F4A44C6A68925C40448A01124D244B40F4A44C6A68925C40CA8AE1EA00264B40B875374F75935C40CA8AE1EA00264B40B875374F75935C40448A01124D244B40F4A44C6A68925C40448A01124D244B40
76992	61013	113.813366	113.829464	53.973219	53.95825	Школьная	0103000020E610000001000000050000006A6B44300E745C402DB29DEFA7FA4A406A6B44300E745C40446CB07092FC4A40664D2CF015755C40446CB07092FC4A40664D2CF015755C402DB29DEFA7FA4A406A6B44300E745C402DB29DEFA7FA4A40
75824	26962	113.53301999999999	113.56172100000001	54.403136000000003	54.389225000000003	Центральная	0103000020E610000001000000050000004A07EBFF1C625C408FE4F21FD2314B404A07EBFF1C625C408EEBDFF599334B407E1EA33CF3635C408EEBDFF599334B407E1EA33CF3635C408FE4F21FD2314B404A07EBFF1C625C408FE4F21FD2314B40
76754	60916	112.349678	112.374526	54.323293	54.312984	Красноармейская	0103000020E610000001000000050000005D88D51F61165C40EC1516DC0F284B405D88D51F61165C404B033FAA61294B401C60E63BF8175C404B033FAA61294B401C60E63BF8175C40EC1516DC0F284B405D88D51F61165C40EC1516DC0F284B40
74664	24438	113.56739899999999	113.60009700000001	54.460341999999997	54.424733000000003	Ленина	0103000020E610000001000000050000001E32E54350645C401844A4A65D364B401E32E54350645C40D47C957CEC3A4B40605B3FFD67665C40D47C957CEC3A4B40605B3FFD67665C401844A4A65D364B401E32E54350645C401844A4A65D364B40
77018	61034	108.420699	111.218897	54.154797000000002	53.030394999999999	Кооперативная	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
76784	60924	108.420699	111.218897	54.154797000000002	53.030394999999999	Центральная	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
76669	26386	110.22362699999999	110.245402	53.730933	53.722718	Калинина	0103000020E610000001000000050000002AE09EE74F8E5B40821DFF0582DC4A402AE09EE74F8E5B40994869368FDD4A40DF1797AAB48F5B40994869368FDD4A40DF1797AAB48F5B40821DFF0582DC4A402AE09EE74F8E5B40821DFF0582DC4A40
76768	60919	109.64221000000001	109.65337599999999	53.570813999999999	53.561492999999999	Лесная	0103000020E6100000010000000500000082CAF8F719695B406AF7AB00DFC74A4082CAF8F719695B40AA0CE36E10C94A4071FF91E9D0695B40AA0CE36E10C94A4071FF91E9D0695B406AF7AB00DFC74A4082CAF8F719695B406AF7AB00DFC74A40
76661	26041	109.76301599999999	109.788932	53.511381	53.489946000000003	Профсоюзная	0103000020E61000000100000005000000C8940F41D5705B402C67EF8CB6BE4A40C8940F41D5705B40DC65BFEE74C14A4025B1A4DC7D725B40DC65BFEE74C14A4025B1A4DC7D725B402C67EF8CB6BE4A40C8940F41D5705B402C67EF8CB6BE4A40
76622	26832	110.081127	110.12492	53.926228999999999	53.907429	Очирова	0103000020E61000000100000005000000A5F44C2F31855B4093382BA226F44A40A5F44C2F31855B40ABCDFFAB8EF64A4072A774B0FE875B40ABCDFFAB8EF64A4072A774B0FE875B4093382BA226F44A40A5F44C2F31855B4093382BA226F44A40
76683	26642	110.11629600000001	110.12761500000001	53.805754999999998	53.801650000000002	Центральная	0103000020E61000000100000005000000F629C76471875B40516B9A779CE64A40F629C76471875B4053CBD6FA22E74A40A9DE1AD82A885B4053CBD6FA22E74A40A9DE1AD82A885B40516B9A779CE64A40F629C76471875B40516B9A779CE64A40
74658	25547	109.00227700000001	109.054362	53.423070000000003	53.394181000000003	Щербакова	0103000020E610000001000000050000001D226E4E25405B4030DAE38574B24A401D226E4E25405B4099F5622827B64A404A09C1AA7A435B4099F5622827B64A404A09C1AA7A435B4030DAE38574B24A401D226E4E25405B4030DAE38574B24A40
76667	25547	109.00227700000001	109.054362	53.423070000000003	53.394181000000003	Производственная	0103000020E610000001000000050000001D226E4E25405B4030DAE38574B24A401D226E4E25405B4099F5622827B64A404A09C1AA7A435B4099F5622827B64A404A09C1AA7A435B4030DAE38574B24A401D226E4E25405B4030DAE38574B24A40
71556	25547	109.00227700000001	109.054362	53.423070000000003	53.394181000000003	Оцимика	0103000020E610000001000000050000001D226E4E25405B4030DAE38574B24A401D226E4E25405B4099F5622827B64A404A09C1AA7A435B4099F5622827B64A404A09C1AA7A435B4030DAE38574B24A401D226E4E25405B4030DAE38574B24A40
75821	25547	109.00227700000001	109.054362	53.423070000000003	53.394181000000003	Ленина	0103000020E610000001000000050000001D226E4E25405B4030DAE38574B24A401D226E4E25405B4099F5622827B64A404A09C1AA7A435B4099F5622827B64A404A09C1AA7A435B4030DAE38574B24A401D226E4E25405B4030DAE38574B24A40
74894	25547	109.00227700000001	109.054362	53.423070000000003	53.394181000000003	Ватутина	0103000020E610000001000000050000001D226E4E25405B4030DAE38574B24A401D226E4E25405B4099F5622827B64A404A09C1AA7A435B4099F5622827B64A404A09C1AA7A435B4030DAE38574B24A401D226E4E25405B4030DAE38574B24A40
76912	26106	109.81679800000001	109.865055	53.560347999999998	53.527811	переулок Школьный	0103000020E610000001000000050000000C5C1E6B46745B400ABC934F8FC34A400C5C1E6B46745B408330B77BB9C74A40718FA50F5D775B408330B77BB9C74A40718FA50F5D775B400ABC934F8FC34A400C5C1E6B46745B400ABC934F8FC34A40
76684	26106	109.81679800000001	109.865055	53.560347999999998	53.527811	Советская	0103000020E610000001000000050000000C5C1E6B46745B400ABC934F8FC34A400C5C1E6B46745B408330B77BB9C74A40718FA50F5D775B408330B77BB9C74A40718FA50F5D775B400ABC934F8FC34A400C5C1E6B46745B400ABC934F8FC34A40
76700	26520	110.333904	110.354511	53.836998000000001	53.818418999999999	Караликская	0103000020E610000001000000050000003B00E2AE5E955B4067B62BF4C1E84A403B00E2AE5E955B40A1681EC022EB4A40A0C4E74EB0965B40A1681EC022EB4A40A0C4E74EB0965B4067B62BF4C1E84A403B00E2AE5E955B4067B62BF4C1E84A40
76672	26675	109.890918	109.928386	53.836376000000001	53.818418999999999	Очирова	0103000020E61000000100000005000000BC5AEECC04795B4067B62BF4C1E84A40BC5AEECC04795B406494675E0EEB4A401D041DAD6A7B5B406494675E0EEB4A401D041DAD6A7B5B4067B62BF4C1E84A40BC5AEECC04795B4067B62BF4C1E84A40
76774	26746	109.937468	109.963466	53.874583000000001	53.867485000000002	Цыденжапова	0103000020E61000000100000005000000FA42C879FF7B5B40A2629CBF09EF4A40FA42C879FF7B5B409C51F355F2EF4A40B5334C6DA97D5B409C51F355F2EF4A40B5334C6DA97D5B40A2629CBF09EF4A40FA42C879FF7B5B40A2629CBF09EF4A40
76923	26235	110.000979	110.019431	53.663975000000001	53.650554999999997	Кабашова	0103000020E61000000100000005000000E63E390A10805B40E89FE06245D34A40E63E390A10805B40492EFF21FDD44A40D461855B3E815B40492EFF21FDD44A40D461855B3E815B40E89FE06245D34A40E63E390A10805B40E89FE06245D34A40
76929	26588	110.19102700000001	110.20172599999999	53.859175	53.850852000000003	Колхозная	0103000020E61000000100000005000000CB694FC9398C5B403CDEE4B7E8EC4A40CB694FC9398C5B4039454772F9ED4A402F302B14E98C5B4039454772F9ED4A402F302B14E98C5B403CDEE4B7E8EC4A40CB694FC9398C5B403CDEE4B7E8EC4A40
76780	52412	109.697879	109.72221399999999	53.651077999999998	53.640808	Школьная	0103000020E610000001000000050000002C64AE0CAA6C5B40F1811DFF05D24A402C64AE0CAA6C5B4092921E8656D34A40A7AD11C1386E5B4092921E8656D34A40A7AD11C1386E5B40F1811DFF05D24A402C64AE0CAA6C5B40F1811DFF05D24A40
76844	26111	109.832159	109.854859	53.532912000000003	53.523085000000002	Комсомольская	0103000020E610000001000000050000009D84D21742755B409B030473F4C24A409D84D21742755B40AFD2DD7536C44A403EEC8502B6765B40AFD2DD7536C44A403EEC8502B6765B409B030473F4C24A409D84D21742755B409B030473F4C24A40
76843	25723	108.710235	108.753309	53.272074000000003	53.261701000000002	Клубная	0103000020E610000001000000050000005F5E807D742D5B404E2A1A6B7FA14A405F5E807D742D5B40C40B2252D3A24A4014B2F33636305B40C40B2252D3A24A4014B2F33636305B404E2A1A6B7FA14A405F5E807D742D5B404E2A1A6B7FA14A40
76915	25923	108.420699	111.218897	54.154797000000002	53.030394999999999	Набережная	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
76760	25854	108.420699	111.218897	54.154797000000002	53.030394999999999	Нагорная	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
76926	26448	110.21096	110.242761	53.748843000000001	53.733420000000002	Центральная	0103000020E61000000100000005000000E8305F5E808D5B40BD1DE1B4E0DD4A40E8305F5E808D5B40556B6116DADF4A40A2EF6E65898F5B40556B6116DADF4A40A2EF6E65898F5B40BD1DE1B4E0DD4A40E8305F5E808D5B40BD1DE1B4E0DD4A40
76847	25989	109.35554	109.374925	53.511617000000001	53.50338	Набережная	0103000020E61000000100000005000000DF1AD82AC1565B40F1BA7EC16EC04A40DF1AD82AC1565B40F08975AA7CC14A40FB5C6DC5FE575B40F08975AA7CC14A40FB5C6DC5FE575B40F1BA7EC16EC04A40DF1AD82AC1565B40F1BA7EC16EC04A40
76918	26211	109.878674	109.895212	53.604129	53.592699000000003	Бр.Чирковых	0103000020E610000001000000050000001D76DF313C785B409BAF928FDDCB4A401D76DF313C785B4058C85C1954CD4A4027BF45274B795B4058C85C1954CD4A4027BF45274B795B409BAF928FDDCB4A401D76DF313C785B409BAF928FDDCB4A40
76945	25556	109.25403	109.27096299999999	53.439321	53.424926999999997	Баргузинская	0103000020E61000000100000005000000FC8C0B0742505B40FC17080264B64A40FC8C0B0742505B4017B9A7AB3BB84A4044DB317557515B4017B9A7AB3BB84A4044DB317557515B40FC17080264B64A40FC8C0B0742505B40FC17080264B64A40
76927	26849	110.160664	110.186904	53.905619999999999	53.897207000000002	Энгельса	0103000020E610000001000000050000004069A851488A5B40035FD1ADD7F24A404069A851488A5B40404D2D5BEBF34A4076DF313CF68B5B40404D2D5BEBF34A4076DF313CF68B5B40035FD1ADD7F24A404069A851488A5B40035FD1ADD7F24A40
76779	26294	110.083732	110.10202200000001	53.710504999999998	53.702019999999997	Ленина	0103000020E610000001000000050000003C6876DD5B855B40A79196CADBD94A403C6876DD5B855B407E52EDD3F1DA4A403E5E488787865B407E52EDD3F1DA4A403E5E488787865B40A79196CADBD94A403C6876DD5B855B40A79196CADBD94A40
74900	26489	108.420699	111.218897	54.154797000000002	53.030394999999999	Ленина	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
76916	25173	109.58647000000001	109.66059	53.630231999999999	53.600351000000003	м-н Старый Аэропорт	0103000020E61000000100000005000000738577B988655B407A8F334DD8CC4A40738577B988655B4043723271ABD04A402384471B476A5B4043723271ABD04A402384471B476A5B407A8F334DD8CC4A40738577B988655B407A8F334DD8CC4A40
76620	25173	109.58647000000001	109.66059	53.630231999999999	53.600351000000003	Очирова	0103000020E61000000100000005000000738577B988655B407A8F334DD8CC4A40738577B988655B4043723271ABD04A402384471B476A5B4043723271ABD04A402384471B476A5B407A8F334DD8CC4A40738577B988655B407A8F334DD8CC4A40
74168	25173	109.58647000000001	109.66059	53.630231999999999	53.600351000000003	Калинина	0103000020E61000000100000005000000738577B988655B407A8F334DD8CC4A40738577B988655B4043723271ABD04A402384471B476A5B4043723271ABD04A402384471B476A5B407A8F334DD8CC4A40738577B988655B407A8F334DD8CC4A40
74706	25173	109.58647000000001	109.66059	53.630231999999999	53.600351000000003	Дзержинского	0103000020E61000000100000005000000738577B988655B407A8F334DD8CC4A40738577B988655B4043723271ABD04A402384471B476A5B4043723271ABD04A402384471B476A5B407A8F334DD8CC4A40738577B988655B407A8F334DD8CC4A40
76508	25173	109.58647000000001	109.66059	53.630231999999999	53.600351000000003	Братьев Козулиных	0103000020E61000000100000005000000738577B988655B407A8F334DD8CC4A40738577B988655B4043723271ABD04A402384471B476A5B4043723271ABD04A402384471B476A5B407A8F334DD8CC4A40738577B988655B407A8F334DD8CC4A40
76958	25975	109.291741	109.31349899999999	53.485895999999997	53.476390000000002	Советская	0103000020E61000000100000005000000C07971E2AB525B401B12F758FABC4A40C07971E2AB525B40ECA012D731BE4A4009151C5E10545B40ECA012D731BE4A4009151C5E10545B401B12F758FABC4A40C07971E2AB525B401B12F758FABC4A40
70195	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	проспект Коммунистический	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70221	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Чорос-Гуркина	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70147	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Социалистическая	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70369	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	П.Сухова	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70366	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	П.Кучияк	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70407	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Льва Толстого	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70316	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Ленкина	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70154	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Ленина	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70197	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Заводская	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70140	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Больничная	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
70336	12949	85.881536999999994	86.006681999999998	51.978394999999999	51.912126999999998	Барнаульская	0103000020E61000000100000005000000B14D2A1A6B7855403866D993C0F44940B14D2A1A6B785540F3C81F0C3CFD494033DE567A6D805540F3C81F0C3CFD494033DE567A6D8055403866D993C0F44940B14D2A1A6B7855403866D993C0F44940
74277	32526	85.286879999999996	85.303076000000004	51.208658	51.201542000000003	Песчаная	0103000020E610000001000000050000001878EE3D5C5255409E62D520CC9949401878EE3D5C5255403E062B4EB59A4940F60CE198655355403E062B4EB59A4940F60CE198655355409E62D520CC9949401878EE3D5C5255409E62D520CC994940
70375	5733	85.654443000000001	85.695639999999997	51.320101000000001	51.270493999999999	Советская	0103000020E610000001000000050000002786E464E2695540D2E1218C9FA249402786E464E26955405D35CF11F9A849408672A25D856C55405D35CF11F9A849408672A25D856C5540D2E1218C9FA249402786E464E2695540D2E1218C9FA24940
70277	5381	85.548091999999997	85.586189000000005	51.582597999999997	51.55077	Октябрьская	0103000020E61000000100000005000000C0CC77F01363554018CFA0A17FC64940C0CC77F013635540855B3E9292CA49409911DE1E84655540855B3E9292CA49409911DE1E8465554018CFA0A17FC64940C0CC77F01363554018CFA0A17FC64940
74203	60267	85.436260000000004	85.467000999999996	51.526815999999997	51.507334	Советская	0103000020E61000000100000005000000642310AFEB5B55400E130D52F0C04940642310AFEB5B55403881E9B46EC34940C18C2958E35D55403881E9B46EC34940C18C2958E35D55400E130D52F0C04940642310AFEB5B55400E130D52F0C04940
71726	5941	85.581051000000002	85.588892999999999	51.130864000000003	51.120440000000002	Центральная	0103000020E61000000100000005000000B89388F02F655540AC90F2936A8F4940B89388F02F655540A41CCC26C0904940F9F5436CB0655540A41CCC26C0904940F9F5436CB0655540AC90F2936A8F4940B89388F02F655540AC90F2936A8F4940
74159	5785	85.612842000000001	85.640536999999995	51.423152000000002	51.411143000000003	Трактовая	0103000020E6100000010000000500000060E7A6CD386755405B7D7555A0B4494060E7A6CD38675540569E40D829B6494030B8E68EFE685540569E40D829B6494030B8E68EFE6855405B7D7555A0B4494060E7A6CD386755405B7D7555A0B44940
74177	5242	85.341847000000001	85.35472	51.415754999999997	51.400888999999999	Заречная	0103000020E61000000100000005000000164F3DD2E0555540BF29AC5450B34940164F3DD2E05555400113B87537B549402DCF83BBB35655400113B87537B549402DCF83BBB3565540BF29AC5450B34940164F3DD2E0555540BF29AC5450B34940
71013	5195	84.954960999999997	84.982926000000006	51.424421000000002	51.397320999999998	Центральная	0103000020E6100000010000000500000026FDBD141E3D5540CB811E6ADBB2494026FDBD141E3D5540295E656D53B64940D7187442E83E5540295E656D53B64940D7187442E83E5540CB811E6ADBB2494026FDBD141E3D5540CB811E6ADBB24940
74222	6119	85.542962000000003	85.563309000000004	51.352393999999997	51.338391000000001	Школьная	0103000020E61000000100000005000000213EB0E3BF6255406021736550AB4940213EB0E3BF6255403FA7203F1BAD4940B82231410D6455403FA7203F1BAD4940B82231410D6455406021736550AB4940213EB0E3BF6255406021736550AB4940
74253	5988	85.614791999999994	85.625193999999993	51.208393000000001	51.200718000000002	Центральная	0103000020E61000000100000005000000EA758BC058675540F9DB9E20B1994940EA758BC05867554090DB2F9FAC9A4940F2E9B12D0368554090DB2F9FAC9A4940F2E9B12D03685540F9DB9E20B1994940EA758BC058675540F9DB9E20B1994940
74221	4787	85.986379999999997	86.021287999999998	51.119314000000003	51.111297	Телесова	0103000020E610000001000000050000006C5B94D9207F55404B92E7FA3E8E49406C5B94D9207F55403CFA5FAE458F494006F357C85C8155403CFA5FAE458F494006F357C85C8155404B92E7FA3E8E49406C5B94D9207F55404B92E7FA3E8E4940
74259	5388	85.651595999999998	85.696259999999995	51.633150999999998	51.618614000000001	Центральная	0103000020E61000000100000005000000158DB5BFB3695540836C59BE2ECF4940158DB5BFB369554000378B170BD14940D4601A868F6C554000378B170BD14940D4601A868F6C5540836C59BE2ECF4940158DB5BFB3695540836C59BE2ECF4940
71326	5624	85.749063000000007	85.755709999999993	51.511505	51.503847	Центральная	0103000020E6100000010000000500000032E9EFA5F06F55400798F90E7EC0494032E9EFA5F06F5540C85EEFFE78C14940A6D0798D5D705540C85EEFFE78C14940A6D0798D5D7055400798F90E7EC0494032E9EFA5F06F55400798F90E7EC04940
70847	5139	85.083779000000007	85.121894999999995	51.456735999999999	51.429986	Центральная	0103000020E61000000100000005000000DD4598A25C45554072DEFFC709B74940DD4598A25C455540F373435376BA4940F0A2AF20CD475540F373435376BA4940F0A2AF20CD47554072DEFFC709B74940DD4598A25C45554072DEFFC709B74940
74250	5844	85.597444999999993	85.618268	51.277340000000002	51.264722999999996	Школьная	0103000020E61000000100000005000000280AF4893C665540DFBF7971E2A14940280AF4893C665540B3EF8AE07FA34940740AF2B391675540B3EF8AE07FA34940740AF2B391675540DFBF7971E2A14940280AF4893C665540DFBF7971E2A14940
74165	6133	85.448783000000006	85.464817999999994	51.376294000000001	51.367820999999999	Центральная	0103000020E610000001000000050000000D0055DCB85C554019E42EC214AF49400D0055DCB85C55402CD7DB662AB04940E525FF93BF5D55402CD7DB662AB04940E525FF93BF5D554019E42EC214AF49400D0055DCB85C554019E42EC214AF4940
74190	60265	85.887681999999998	85.908630000000002	51.235886999999998	51.230455999999997	Центральная	0103000020E61000000100000005000000DDCF29C8CF7855405F950B957F9D4940DDCF29C8CF7855409946938B319E4940878A71FE267A55409946938B319E4940878A71FE267A55405F950B957F9D4940DDCF29C8CF7855405F950B957F9D4940
74233	4893	85.240966999999998	85.253722999999994	51.125323999999999	51.115361999999998	Центральная	0103000020E61000000100000005000000931ADA006C4F5540BF99982EC48E4940931ADA006C4F5540B3B3E89D0A9049408DCF64FF3C505540B3B3E89D0A9049408DCF64FF3C505540BF99982EC48E4940931ADA006C4F5540BF99982EC48E4940
70499	5076	85.185873000000001	85.221365000000006	51.281908999999999	51.270820999999998	Партизанская	0103000020E61000000100000005000000670DDE57E54B5540F6083543AAA24940670DDE57E54B55405AB9179815A44940A9DE1AD82A4E55405AB9179815A44940A9DE1AD82A4E5540F6083543AAA24940670DDE57E54B5540F6083543AAA24940
74235	5542	85.653634999999994	85.677242000000007	51.525320000000001	51.513461	Молодежная	0103000020E610000001000000050000005721E527D5695540BF620D17B9C149405721E527D5695540A5F78DAF3DC34940925ED4EE576B5540A5F78DAF3DC34940925ED4EE576B5540BF620D17B9C149405721E527D5695540BF620D17B9C14940
71177	4125	86.771534000000003	86.802014	51.831530999999998	51.816267000000003	Тихоновского	0103000020E61000000100000005000000227024D060B15540EBE6E26F7BE84940227024D060B155401A4E999B6FEA4940C93B873254B355401A4E999B6FEA4940C93B873254B35540EBE6E26F7BE84940227024D060B15540EBE6E26F7BE84940
70773	3898	86.531468000000004	86.562765999999996	52.029390999999997	51.993170999999997	Социалистическая	0103000020E61000000100000005000000B7B75B9203A25540F52A323A20FF4940B7B75B9203A25540FBE59315C3034A403F53AF5B04A45540FBE59315C3034A403F53AF5B04A45540F52A323A20FF4940B7B75B9203A25540F52A323A20FF4940
70516	3898	86.531468000000004	86.562765999999996	52.029390999999997	51.993170999999997	Ленина	0103000020E61000000100000005000000B7B75B9203A25540F52A323A20FF4940B7B75B9203A25540FBE59315C3034A403F53AF5B04A45540FBE59315C3034A403F53AF5B04A45540F52A323A20FF4940B7B75B9203A25540F52A323A20FF4940
71219	4286	86.164299999999997	87.167295999999993	52.135398000000002	51.148997999999999	Заречная	0103000020E61000000100000005000000E6AE25E4838A5540AF95D05D12934940E6AE25E4838A5540CFF8BEB854114A401A3048FAB4CA5540CFF8BEB854114A401A3048FAB4CA5540AF95D05D12934940E6AE25E4838A5540AF95D05D12934940
74228	60274	86.912694999999999	86.926691000000005	51.666634999999999	51.647056999999997	Центральная	0103000020E61000000100000005000000410E4A9869BA5540EDD286C3D2D24940410E4A9869BA55403AAFB14B54D54940D89FC4E74EBB55403AAFB14B54D54940D89FC4E74EBB5540EDD286C3D2D24940410E4A9869BA5540EDD286C3D2D24940
74189	4509	86.451824000000002	86.475036000000003	52.011806	51.999110000000002	Центральная	0103000020E6100000010000000500000011E335AFEA9C5540A48D23D6E2FF494011E335AFEA9C5540C3F2E7DB82014A400D1B65FD669E5540C3F2E7DB82014A400D1B65FD669E5540A48D23D6E2FF494011E335AFEA9C5540A48D23D6E2FF4940
71209	1181	86.603872999999993	86.624245999999999	52.040300000000002	52.029778999999998	Совхозная	0103000020E61000000100000005000000FE7BF0DAA5A65540C58D5BCCCF034A40FE7BF0DAA5A65540B003E78C28054A402AAA7EA5F3A75540B003E78C28054A402AAA7EA5F3A75540C58D5BCCCF034A40FE7BF0DAA5A65540C58D5BCCCF034A40
70681	4543	86.713530000000006	86.751105999999993	51.902065	51.862803999999997	Школьная	0103000020E61000000100000005000000C1ADBB79AAAD5540D26D895C70EE4940C1ADBB79AAAD5540E1EEACDD76F349401475E61E12B05540E1EEACDD76F349401475E61E12B05540D26D895C70EE4940C1ADBB79AAAD5540D26D895C70EE4940
70861	4364	86.315665999999993	86.363528000000002	51.950127999999999	51.914420999999997	Трактовая	0103000020E61000000100000005000000629D2ADF3394554047E350BF0BF54940629D2ADF33945540C78157CB9DF949408ACBF10A44975540C78157CB9DF949408ACBF10A4497554047E350BF0BF54940629D2ADF3394554047E350BF0BF54940
71717	3985	86.482618000000002	86.498661999999996	52.062840999999999	52.057237000000001	Дружная	0103000020E61000000100000005000000809D9B36E39E5540828FC18A53074A40809D9B36E39E554089EC832C0B084A4082700514EA9F554089EC832C0B084A4082700514EA9F5540828FC18A53074A40809D9B36E39E5540828FC18A53074A40
70786	4644	86.676626999999996	86.711149000000006	51.776586000000002	51.754435999999998	Тартыкова	0103000020E61000000100000005000000CC2555DB4DAB55406876DD5B91E04940CC2555DB4DAB55400744882B67E349405265187783AD55400744882B67E349405265187783AD55406876DD5B91E04940CC2555DB4DAB55406876DD5B91E04940
74249	3868	86.528593999999998	86.537981000000002	52.032544000000001	52.024177000000002	Зеленая	0103000020E6100000010000000500000028B7ED7BD4A155405F28603B18034A4028B7ED7BD4A155402CD7DB662A044A40A437DC476EA255402CD7DB662A044A40A437DC476EA255405F28603B18034A4028B7ED7BD4A155405F28603B18034A40
70470	3478	85.982714999999999	86.046404999999993	51.482196000000002	51.442743	Советская	0103000020E61000000100000005000000799274CDE47E554037C478CDABB84940799274CDE47E55408A213999B8BD4940BC57AD4CF88255408A213999B8BD4940BC57AD4CF882554037C478CDABB84940799274CDE47E554037C478CDABB84940
71189	3036	86.244078999999999	86.274298999999999	51.113016000000002	51.101818999999999	Центральная	0103000020E61000000100000005000000FCA886FD9E8F5540438EAD67088D4940FCA886FD9E8F55405EF6EB4E778E4940D594641D8E9155405EF6EB4E778E4940D594641D8E915540438EAD67088D4940FCA886FD9E8F5540438EAD67088D4940
70747	1529	85.819490999999999	85.843044000000006	51.598002000000001	51.579911000000003	Кучияк	0103000020E610000001000000050000007217618A727455409BCB0D863ACA49407217618A72745540A7785C548BCC4940B345D26EF4755540A7785C548BCC4940B345D26EF47555409BCB0D863ACA49407217618A727455409BCB0D863ACA4940
70507	3254	85.983639999999994	86.041132000000005	51.423881999999999	51.387940999999998	Советская	0103000020E6100000010000000500000065C22FF5F37E554086E3F90CA8B1494065C22FF5F37E554079AEEFC341B649406CB41CE8A182554079AEEFC341B649406CB41CE8A182554086E3F90CA8B1494065C22FF5F37E554086E3F90CA8B14940
70855	3254	85.983639999999994	86.041132000000005	51.423881999999999	51.387940999999998	Пчелкина	0103000020E6100000010000000500000065C22FF5F37E554086E3F90CA8B1494065C22FF5F37E554079AEEFC341B649406CB41CE8A182554079AEEFC341B649406CB41CE8A182554086E3F90CA8B1494065C22FF5F37E554086E3F90CA8B14940
71652	3254	85.983639999999994	86.041132000000005	51.423881999999999	51.387940999999998	Курортная	0103000020E6100000010000000500000065C22FF5F37E554086E3F90CA8B1494065C22FF5F37E554079AEEFC341B649406CB41CE8A182554079AEEFC341B649406CB41CE8A182554086E3F90CA8B1494065C22FF5F37E554086E3F90CA8B14940
74257	2183	85.755844999999994	85.773343999999994	51.658434	51.635576999999998	Зеленая	0103000020E6100000010000000500000016F6B4C35F7055407E8B4E965AD1494016F6B4C35F7055408849B89047D44940B323D5777E7155408849B89047D44940B323D5777E7155407E8B4E965AD1494016F6B4C35F7055407E8B4E965AD14940
71509	3703	85.926192999999998	85.956070999999994	51.532302000000001	51.517648000000001	Новые Черемушки	0103000020E610000001000000050000002F3201BF467B55407F6B274A42C249402F3201BF467B554036CCD07822C44940DB696B44307D554036CCD07822C44940DB696B44307D55407F6B274A42C249402F3201BF467B55407F6B274A42C24940
74158	46162	85.903142000000003	85.911254	51.549174000000001	51.542878000000002	Сосновая	0103000020E6100000010000000500000038691A14CD795540E4DBBB067DC5494038691A14CD79554021E868554BC6494059164CFC517A554021E868554BC6494059164CFC517A5540E4DBBB067DC5494038691A14CD795540E4DBBB067DC54940
71724	3137	86.056438999999997	86.061452000000003	51.341227000000003	51.338290000000001	Энергетиков	0103000020E6100000010000000500000003CE52B29C8355402C4833164DAB494003CE52B29C83554090C18A53ADAB494086915ED4EE83554090C18A53ADAB494086915ED4EE8355402C4833164DAB494003CE52B29C8355402C4833164DAB4940
71428	10025	86.102037999999993	86.120911000000007	51.059556000000001	51.047438999999997	Центральная	0103000020E61000000100000005000000C03C64CA8786554008C72C7B12864940C03C64CA87865540EA23F0879F87494082AE7D01BD875540EA23F0879F87494082AE7D01BD87554008C72C7B12864940C03C64CA8786554008C72C7B12864940
74239	2812	86.227307999999994	86.238230999999999	51.034537999999998	51.019168999999998	Центральная	0103000020E61000000100000005000000A087DA368C8E55406B0C3A2174824940A087DA368C8E5540103CBEBD6B8449402D793C2D3F8F5540103CBEBD6B8449402D793C2D3F8F55406B0C3A2174824940A087DA368C8E55406B0C3A2174824940
71203	45884	86.084637000000001	86.095534000000001	51.223112	51.211502000000003	Катунская	0103000020E6100000010000000500000005C24EB16A855540F1845E7F129B494005C24EB16A8555402EAC1BEF8E9C4940FD69A33A1D8655402EAC1BEF8E9C4940FD69A33A1D865540F1845E7F129B494005C24EB16A855540F1845E7F129B4940
71110	1482	85.982759000000001	86.003645000000006	51.638376999999998	51.623086999999998	Центральная	0103000020E6100000010000000500000061360186E57E554008C89750C1CF494061360186E57E554061C26856B6D14940D0F23CB83B80554061C26856B6D14940D0F23CB83B80554008C89750C1CF494061360186E57E554008C89750C1CF4940
74217	3613	85.971583999999993	85.978789000000006	51.442310999999997	51.427841000000001	Центральная	0103000020E610000001000000050000004754A86E2E7E5540A8716F7EC3B649404754A86E2E7E55409DD497A59DB84940D02B9E7AA47E55409DD497A59DB84940D02B9E7AA47E5540A8716F7EC3B649404754A86E2E7E5540A8716F7EC3B64940
71175	3783	85.894553999999999	85.903232000000003	51.540447	51.530279	Озерная	0103000020E6100000010000000500000062A06B5F40795540B760A92EE0C3494062A06B5F40795540541C075E2DC54940D82C978DCE795540541C075E2DC54940D82C978DCE795540B760A92EE0C3494062A06B5F40795540B760A92EE0C34940
71476	3662	85.936639999999997	85.954705000000004	51.506925000000003	51.496110000000002	Центральная	0103000020E610000001000000050000000708E6E8F17B5540FA9B508880BF49400708E6E8F17B55402D431CEBE2C04940F91400E3197D55402D431CEBE2C04940F91400E3197D5540FA9B508880BF49400708E6E8F17B5540FA9B508880BF4940
74153	32949	85.943988000000004	85.970748999999998	50.274948999999999	50.258153	Центральная	0103000020E6100000010000000500000041F4A44C6A7C5540A12E52280B21494041F4A44C6A7C5540B188618731234940FBE769C0207E5540B188618731234940FBE769C0207E5540A12E52280B21494041F4A44C6A7C5540A12E52280B214940
70457	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	переулок Школьный	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
74288	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	Школьная	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
70463	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	Центральная	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
70265	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	Харитошкина	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
70871	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	Советская	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
70435	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	Набережная	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
74219	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	Клубный переулок	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
74243	32782	85.586000999999996	85.645809999999997	50.276353999999998	50.258712000000003	Заря Алтая	0103000020E61000000100000005000000179B560A81655540988A8D791D214940179B560A81655540340F60915F234940815B77F354695540340F60915F234940815B77F354695540988A8D791D214940179B560A81655540988A8D791D214940
71468	59425	85.792236000000003	85.806178000000003	50.206252999999997	50.198689000000002	Центральная	0103000020E61000000100000005000000B0AD9FFEB3725540988922A46E194940B0AD9FFEB3725540D7D9907F661A49404D309C6B98735540D7D9907F661A49404D309C6B98735540988922A46E194940B0AD9FFEB3725540988922A46E194940
74212	60270	85.014160000000004	85.027257000000006	50.510551999999997	50.497982	Центральная	0103000020E61000000100000005000000543A58FFE740554093FFC9DFBD3F4940543A58FFE7405540257497C45941494093E52494BE415540257497C45941494093E52494BE41554093FFC9DFBD3F4940543A58FFE740554093FFC9DFBD3F4940
74122	60250	85.506930999999994	85.536323999999993	50.239485000000002	50.226168000000001	Скосырева	0103000020E610000001000000050000000795B88E716055406CB3B112F31C49400795B88E71605540F870C971A71E4940D503E62153625540F870C971A71E4940D503E621536255406CB3B112F31C49400795B88E716055406CB3B112F31C4940
74263	60250	85.506930999999994	85.536323999999993	50.239485000000002	50.226168000000001	Садовая	0103000020E610000001000000050000000795B88E716055406CB3B112F31C49400795B88E71605540F870C971A71E4940D503E62153625540F870C971A71E4940D503E621536255406CB3B112F31C49400795B88E716055406CB3B112F31C4940
74232	60250	85.506930999999994	85.536323999999993	50.239485000000002	50.226168000000001	Новая	0103000020E610000001000000050000000795B88E716055406CB3B112F31C49400795B88E71605540F870C971A71E4940D503E62153625540F870C971A71E4940D503E621536255406CB3B112F31C49400795B88E716055406CB3B112F31C4940
74139	60255	86.168693000000005	86.189353999999994	50.179217999999999	50.147815000000001	Сухова	0103000020E610000001000000050000001B84B9DDCB8A5540DB6D179AEB1249401B84B9DDCB8A5540616D8C9DF016494079573D601E8C5540616D8C9DF016494079573D601E8C5540DB6D179AEB1249401B84B9DDCB8A5540DB6D179AEB124940
74160	60255	86.168693000000005	86.189353999999994	50.179217999999999	50.147815000000001	Ленина	0103000020E610000001000000050000001B84B9DDCB8A5540DB6D179AEB1249401B84B9DDCB8A5540616D8C9DF016494079573D601E8C5540616D8C9DF016494079573D601E8C5540DB6D179AEB1249401B84B9DDCB8A5540DB6D179AEB124940
71683	59494	85.733118000000005	85.742836999999994	50.331961	50.313482	Заречная	0103000020E61000000100000005000000F986C267EB6E55403DF19C2D20284940F986C267EB6E55401346B3B27D2A49408F5033A48A6F55401346B3B27D2A49408F5033A48A6F55403DF19C2D20284940F986C267EB6E55403DF19C2D20284940
74215	60252	84.610736000000003	84.630219999999994	50.400612000000002	50.391539999999999	Школьная	0103000020E610000001000000050000005A9F724C16275540B58993FB1D3249405A9F724C162755404D310741473349403F524486552855404D310741473349403F52448655285540B58993FB1D3249405A9F724C16275540B58993FB1D324940
74127	60252	84.610736000000003	84.630219999999994	50.400612000000002	50.391539999999999	Зеленая	0103000020E610000001000000050000005A9F724C16275540B58993FB1D3249405A9F724C162755404D310741473349403F524486552855404D310741473349403F52448655285540B58993FB1D3249405A9F724C16275540B58993FB1D324940
74155	60259	85.824197999999996	85.850967999999995	50.227032999999999	50.215643999999998	Центральная	0103000020E610000001000000050000006EDBF7A8BF74554010CAFB389A1B49406EDBF7A8BF7455406F0ED76A0F1D4940527C7C42767655406F0ED76A0F1D4940527C7C427676554010CAFB389A1B49406EDBF7A8BF74554010CAFB389A1B4940
74152	60259	85.824197999999996	85.850967999999995	50.227032999999999	50.215643999999998	Первомайская	0103000020E610000001000000050000006EDBF7A8BF74554010CAFB389A1B49406EDBF7A8BF7455406F0ED76A0F1D4940527C7C42767655406F0ED76A0F1D4940527C7C427676554010CAFB389A1B49406EDBF7A8BF74554010CAFB389A1B4940
74120	32898	85.729650000000007	85.750608	50.219580999999998	50.207568000000002	Школьная	0103000020E61000000100000005000000B1E1E995B26E55401BD99596911A4940B1E1E995B26E554057E9EE3A1B1C49406C0723F60970554057E9EE3A1B1C49406C0723F6097055401BD99596911A4940B1E1E995B26E55401BD99596911A4940
74163	32898	85.729650000000007	85.750608	50.219580999999998	50.207568000000002	Центральная	0103000020E61000000100000005000000B1E1E995B26E55401BD99596911A4940B1E1E995B26E554057E9EE3A1B1C49406C0723F60970554057E9EE3A1B1C49406C0723F6097055401BD99596911A4940B1E1E995B26E55401BD99596911A4940
74147	60257	85.101062999999996	85.149033000000003	50.408047000000003	50.393836999999998	переулок Новый	0103000020E610000001000000050000007BF5F1D077465540357A3540693249407BF5F1D0774655408F1D54E23A3449409641B5C1894955408F1D54E23A3449409641B5C189495540357A3540693249407BF5F1D077465540357A354069324940
74145	60257	85.101062999999996	85.149033000000003	50.408047000000003	50.393836999999998	Советская	0103000020E610000001000000050000007BF5F1D077465540357A3540693249407BF5F1D0774655408F1D54E23A3449409641B5C1894955408F1D54E23A3449409641B5C189495540357A3540693249407BF5F1D077465540357A354069324940
70240	406	84.861194999999995	84.883249000000006	51.044896999999999	51.024023999999997	Кудачина	0103000020E61000000100000005000000A31EA2D11D375540D828EB3713834940A31EA2D11D3755402158552FBF854940624ED026873855402158552FBF854940624ED02687385540D828EB3713834940A31EA2D11D375540D828EB3713834940
70423	228	85.058959000000002	85.090992999999997	50.916437000000002	50.901823999999998	Ленинская	0103000020E610000001000000050000008333F8FBC5435540BB5F05F86E7349408333F8FBC543554014ECBFCE4D7549408ECA4DD4D245554014ECBFCE4D7549408ECA4DD4D2455540BB5F05F86E7349408333F8FBC5435540BB5F05F86E734940
71643	680	84.718299999999999	84.749588000000003	51.363771999999997	51.342981999999999	Центральная	0103000020E61000000100000005000000E02D90A0F82D5540EF8E8CD5E6AB4940E02D90A0F82D5540AA99B51490AE4940575EF23FF92F5540AA99B51490AE4940575EF23FF92F5540EF8E8CD5E6AB4940E02D90A0F82D5540EF8E8CD5E6AB4940
71101	566	84.744549000000006	84.764446000000007	51.244086000000003	51.224325	Центральная	0103000020E610000001000000050000004051D9B0A62F55406D567DAEB69C49404051D9B0A62F5540ABB4C5353E9F4940B763EAAEEC305540ABB4C5353E9F4940B763EAAEEC3055406D567DAEB69C49404051D9B0A62F55406D567DAEB69C4940
71628	32186	84.274218000000005	84.300843999999998	51.035778999999998	51.027973000000003	Зеленая	0103000020E610000001000000050000005F7EA7C98C115540E415889E948349405F7EA7C98C1155401971016894844940A94C3107411355401971016894844940A94C310741135540E415889E948349405F7EA7C98C115540E415889E94834940
70087	49276	84.733750999999998	84.786994000000007	50.942982999999998	50.917681000000002	Первомайская	0103000020E61000000100000005000000111AC1C6F52E55408E942D9276754940111AC1C6F52E55408CD7BCAAB37849407D09151C5E3255408CD7BCAAB37849407D09151C5E3255408E942D9276754940111AC1C6F52E55408E942D9276754940
71050	32300	84.475997000000007	84.493073999999993	50.998669999999997	50.987138999999999	Мира	0103000020E61000000100000005000000A0FF1EBC761E554096CD1C925A7E4940A0FF1EBC761E554087BF266BD47F4940812040868E1F554087BF266BD47F4940812040868E1F554096CD1C925A7E4940A0FF1EBC761E554096CD1C925A7E4940
71106	785	84.759101000000001	84.778199999999998	51.320647000000001	51.312736999999998	Елеусова	0103000020E6100000010000000500000019575C1C95305540E49F19C407A8494019575C1C95305540BF47FDF50AA94940D26F5F07CE315540BF47FDF50AA94940D26F5F07CE315540E49F19C407A8494019575C1C95305540E49F19C407A84940
71044	49209	84.300341000000003	84.319044000000005	51.039980999999997	51.033999999999999	Партизанская	0103000020E61000000100000005000000782975C9381355403108AC1C5A844940782975C9381355400EBBEF181E8549400B7F86376B1455400EBBEF181E8549400B7F86376B1455403108AC1C5A844940782975C9381355403108AC1C5A844940
71031	32201	84.384665999999996	84.397250999999997	51.068035000000002	51.06156	Волонковская	0103000020E610000001000000050000008578245E9E185540F25EB532E18749408578245E9E185540DFFDF15EB58849406953758F6C195540DFFDF15EB58849406953758F6C195540F25EB532E18749408578245E9E185540F25EB532E1874940
74240	325	84.995484000000005	85.006201000000004	50.915336000000003	50.909021000000003	Школьная	0103000020E610000001000000050000003EEC8502B63F55404930D5CC5A7449403EEC8502B63F5540FD6CE4BA29754940F60CE19865405540FD6CE4BA29754940F60CE198654055404930D5CC5A7449403EEC8502B63F55404930D5CC5A744940
71348	35	84.793802999999997	84.826852000000002	50.804563999999999	50.790382000000001	Казакова	0103000020E61000000100000005000000DE1D19ABCD3255406DACC43C2B654940DE1D19ABCD325540FCC401F4FB66494076A8A624EB345540FCC401F4FB66494076A8A624EB3455406DACC43C2B654940DE1D19ABCD3255406DACC43C2B654940
70768	167	84.932475999999994	84.956821000000005	50.811469000000002	50.794482000000002	Победы	0103000020E610000001000000050000008313D1AFAD3B55405EA10F96B16549408313D1AFAD3B5540E25B5837DE67494011C8258E3C3D5540E25B5837DE67494011C8258E3C3D55405EA10F96B16549408313D1AFAD3B55405EA10F96B1654940
71450	59447	84.026551999999995	84.049783000000005	51.103198999999996	51.087569000000002	Набережная	0103000020E610000001000000050000002DE92807B30155405C920376358B49402DE92807B30155406DFDF49F358D4940653909A52F0355406DFDF49F358D4940653909A52F0355405C920376358B49402DE92807B30155405C920376358B4940
71341	32380	84.679331000000005	84.692222000000001	50.983232000000001	50.962491	Молодежная	0103000020E610000001000000050000002D0ABB287A2B5540E0D8B3E7327B49402D0ABB287A2B5540BA30D28BDA7D494097E4805D4D2C5540BA30D28BDA7D494097E4805D4D2C5540E0D8B3E7327B49402D0ABB287A2B5540E0D8B3E7327B4940
71095	469	84.749021999999997	84.762765999999999	51.186149	51.174748999999998	Тан-Чолмон	0103000020E61000000100000005000000027FF8F9EF2F55401D01DC2C5E964940027FF8F9EF2F55407097FDBAD39749400C207C28D13055407097FDBAD39749400C207C28D13055401D01DC2C5E964940027FF8F9EF2F55401D01DC2C5E964940
74207	32333	84.587361000000001	84.596999999999994	50.956279000000002	50.946075999999998	Центральная	0103000020E61000000100000005000000897C975297255540E7C3B30419794940897C975297255540016DAB59677A494091ED7C3F35265540016DAB59677A494091ED7C3F35265540E7C3B30419794940897C975297255540E7C3B30419794940
71332	49172	84.196262000000004	84.219744000000006	51.049624999999999	51.045169000000001	Центральная	0103000020E61000000100000005000000A5DC7D8E8F0C554082E50819C8854940A5DC7D8E8F0C55403108AC1C5A864940815F2349100E55403108AC1C5A864940815F2349100E554082E50819C8854940A5DC7D8E8F0C554082E50819C8854940
71353	279	85.228318000000002	85.238540999999998	50.930717000000001	50.923206	Нагорная	0103000020E61000000100000005000000A4C519C39C4E554049BC3C9D2B764940A4C519C39C4E5540666A12BC2177494054707841444F5540666A12BC2177494054707841444F554049BC3C9D2B764940A4C519C39C4E554049BC3C9D2B764940
71636	572	84.664113	84.679888000000005	51.196942	51.187865000000002	Чапаева	0103000020E610000001000000050000004DF6CFD3802A55401288D7F50B9849404DF6CFD3802A5540BB9A3C6535994940583CF548832B5540BB9A3C6535994940583CF548832B55401288D7F50B9849404DF6CFD3802A55401288D7F50B984940
74208	897	84.973179000000002	84.996319	51.151184999999998	51.136408000000003	Ануйская	0103000020E61000000100000005000000DB899290483E5540D6743DD175914940DB899290483E5540A852B3075A9349408A58C4B0C33F5540A852B3075A9349408A58C4B0C33F5540D6743DD175914940DB899290483E5540D6743DD175914940
70853	32702	84.875558999999996	84.924301999999997	51.243606999999997	51.223896000000003	Советская	0103000020E61000000100000005000000FBAD9D280938554045DAC69FA89C4940FBAD9D2809385540D009A1832E9F4940276893C3273B5540D009A1832E9F4940276893C3273B554045DAC69FA89C4940FBAD9D280938554045DAC69FA89C4940
74276	31274	88.770465000000002	88.781217999999996	50.618509000000003	50.613765000000001	Набережная	0103000020E610000001000000050000009C6D6E4C4F315640F836FDD98F4E49409C6D6E4C4F3156400EA48B4D2B4F4940FA42C879FF3156400EA48B4D2B4F4940FA42C879FF315640F836FDD98F4E49409C6D6E4C4F315640F836FDD98F4E4940
74262	31867	87.495863999999997	87.537194999999997	50.322754000000003	50.314570000000003	Кокышева	0103000020E61000000100000005000000E1D05B3CBCDF5540C0266BD443284940E1D05B3CBCDF55409C53C90050294940C824236761E255409C53C90050294940C824236761E25540C0266BD443284940E1D05B3CBCDF5540C0266BD443284940
74241	32053	87.909824999999998	87.928905999999998	50.626618000000001	50.620131999999998	Набережная	0103000020E610000001000000050000005305A3923AFA5540FE99417C604F49405305A3923AFA5540DF8AC40435504940B9C3263273FB5540DF8AC40435504940B9C3263273FB5540FE99417C604F49405305A3923AFA5540FE99417C604F4940
74229	31936	87.941563000000002	87.970183000000006	50.640033000000003	50.622560999999997	А.В.Санаа	0103000020E61000000100000005000000EA07759142FC5540ED612F14B04F4940EA07759142FC55402EAEF199EC514940A708707A17FE55402EAEF199EC514940A708707A17FE5540ED612F14B04F4940EA07759142FC5540ED612F14B04F4940
74254	31194	88.258992000000006	88.271101000000002	50.523083999999997	50.516222999999997	Школьная 13	0103000020E610000001000000050000003E7B2E5393105640B4386398134249403E7B2E5393105640CA87A06AF44249406D3A02B859115640CA87A06AF44249406D3A02B859115640B4386398134249403E7B2E5393105640B438639813424940
74238	31515	87.876327000000003	87.888229999999993	50.837688	50.832517000000003	Куюкова	0103000020E610000001000000050000008466D7BD15F85540992EC4EA8F6A49408466D7BD15F855403620425C396B4940DE54A4C2D8F855403620425C396B4940DE54A4C2D8F85540992EC4EA8F6A49408466D7BD15F85540992EC4EA8F6A4940
74268	31678	87.890942999999993	87.905118000000002	51.100546000000001	51.092418000000002	Южная	0103000020E6100000010000000500000068E6C93505F95540E7C75F5AD48B494068E6C93505F955402FDFFAB0DE8C494057410C74EDF955402FDFFAB0DE8C494057410C74EDF95540E7C75F5AD48B494068E6C93505F95540E7C75F5AD48B4940
74252	31112	87.821529999999996	87.829533999999995	50.681229999999999	50.668351999999999	Набережная	0103000020E61000000100000005000000B4AB90F293F45540AC1BEF8E8C554940B4AB90F293F45540EC866D8B32574940E23AC61517F55540EC866D8B32574940E23AC61517F55540AC1BEF8E8C554940B4AB90F293F45540AC1BEF8E8C554940
74230	31592	87.709259000000003	87.723855999999998	51.294673000000003	51.278129	Центральная	0103000020E610000001000000050000003259DC7F64ED5540DB8827BB99A349403259DC7F64ED5540D20149D8B7A54940DBC01DA853EE5540D20149D8B7A54940DBC01DA853EE5540DB8827BB99A349403259DC7F64ED5540DB8827BB99A34940
74264	31370	88.032122000000001	88.046719999999993	50.765732	50.744967000000003	Центральная	0103000020E61000000100000005000000DBDE6E490E025640B4CC22145B5F4940DBDE6E490E02564016C09481036249406C04E275FD02564016C09481036249406C04E275FD025640B4CC22145B5F4940DBDE6E490E025640B4CC22145B5F4940
74242	31793	87.581141000000002	87.650148999999999	50.335290000000001	50.307499999999997	Ст.Мохова	0103000020E610000001000000050000005857056A31E555408FC2F5285C2749405857056A31E55540825660C8EA2A4940BC218D0A9CE95540825660C8EA2A4940BC218D0A9CE955408FC2F5285C2749405857056A31E555408FC2F5285C274940
74170	12409	87.599969999999999	87.616372999999996	51.772646000000002	51.767831000000001	Школьная	0103000020E61000000100000005000000312592E865E6554070ED444948E24940312592E865E655404FB16A10E6E24940CB48BDA772E755404FB16A10E6E24940CB48BDA772E7554070ED444948E24940312592E865E6554070ED444948E24940
71256	11801	87.084722999999997	87.104162000000002	51.865456999999999	51.852826	Центральная	0103000020E61000000100000005000000048E041A6CC55540D996016729ED4940048E041A6CC55540118C834BC7EE49401ADF1797AAC65540118C834BC7EE49401ADF1797AAC65540D996016729ED4940048E041A6CC55540D996016729ED4940
74206	31050	86.934416999999996	86.949867999999995	52.359507999999998	52.349491	Береговая	0103000020E61000000100000005000000E4F4F57CCDBB5540889FFF1EBC2C4A40E4F4F57CCDBB55403F53AF5B042E4A4015E126A3CABC55403F53AF5B042E4A4015E126A3CABC5540889FFF1EBC2C4A40E4F4F57CCDBB5540889FFF1EBC2C4A40
70388	13312	87.090804000000006	87.149356999999995	52.276795	52.243147999999998	Советская	0103000020E61000000100000005000000259694BBCFC555403D0B42791F1F4A40259694BBCFC555402159C0046E234A406F9BA9108FC955402159C0046E234A406F9BA9108FC955403D0B42791F1F4A40259694BBCFC555403D0B42791F1F4A40
71251	11733	87.119846999999993	87.128012999999996	52.011856000000002	51.998632999999998	Строительная	0103000020E610000001000000050000008461C092ABC755406ADAC534D3FF49408461C092ABC755407521567F84014A409F1D705D31C855407521567F84014A409F1D705D31C855406ADAC534D3FF49408461C092ABC755406ADAC534D3FF4940
71616	18964	87.105284999999995	87.117232999999999	52.125906000000001	52.117136000000002	Береговая	0103000020E6100000010000000500000099F04BFDBCC655409697FC4FFE0E4A4099F04BFDBCC65540622F14B01D104A40C440D7BE80C75540622F14B01D104A40C440D7BE80C755409697FC4FFE0E4A4099F04BFDBCC655409697FC4FFE0E4A40
74287	60281	87.097172999999998	87.110837000000004	52.19041	52.183540999999998	Боровая	0103000020E6100000010000000500000078431A1538C65540D13C80457E174A4078431A1538C655406A6AD95A5F184A40F48B12F417C755406A6AD95A5F184A40F48B12F417C75540D13C80457E174A4078431A1538C65540D13C80457E174A40
74166	30965	86.740947000000006	86.760422000000005	52.472768000000002	52.458333000000003	Центральная	0103000020E610000001000000050000007044F7AC6BAF5540BBD6DEA7AA3A4A407044F7AC6BAF5540344C6DA9833C4A402C4A09C1AAB05540344C6DA9833C4A402C4A09C1AAB05540BBD6DEA7AA3A4A407044F7AC6BAF5540BBD6DEA7AA3A4A40
74226	48728	88.117335999999995	88.163589999999999	52.336506999999997	52.328324000000002	Центральная	0103000020E610000001000000050000002EA9DA6E82075640F73E5585062A4A402EA9DA6E8207564002F04FA9122B4A40F8FC3042780A564002F04FA9122B4A40F8FC3042780A5640F73E5585062A4A402EA9DA6E82075640F73E5585062A4A40
71599	11703	87.079728000000003	87.107045999999997	51.931690000000003	51.90072	Центральная	0103000020E61000000100000005000000D52478431AC55540336DFFCA4AF34940D52478431AC555405001309E41F74940BA4A77D7D9C655405001309E41F74940BA4A77D7D9C65540336DFFCA4AF34940D52478431AC55540336DFFCA4AF34940
74184	13444	87.351737999999997	87.375390999999993	52.380775999999997	52.372127999999996	Центральная	0103000020E61000000100000005000000ABB019E082D6554083F6EAE3A12F4A40ABB019E082D65540048D9944BD304A409D0DF96706D85540048D9944BD304A409D0DF96706D8554083F6EAE3A12F4A40ABB019E082D6554083F6EAE3A12F4A40
71625	30918	86.720895999999996	86.731002000000004	52.463403	52.452840000000002	Береговая	0103000020E610000001000000050000004DF4F92823AE55400B293FA9F6394A404DF4F92823AE554024EF1CCA503B4A40E1D39CBCC8AE554024EF1CCA503B4A40E1D39CBCC8AE55400B293FA9F6394A404DF4F92823AE55400B293FA9F6394A40
70275	12455	87.239332000000005	87.279342999999997	51.788170000000001	51.776586000000002	Школьная	0103000020E61000000100000005000000B9382A3751CF55400744882B67E34940B9382A3751CF55401BD82AC1E2E44940755776C1E0D155401BD82AC1E2E44940755776C1E0D155400744882B67E34940B9382A3751CF55400744882B67E34940
74200	48766	86.896472000000003	86.930993999999998	52.45234	52.426934000000003	Морозова	0103000020E61000000100000005000000E77118CC5FB9554076C6F7C5A5364A40E77118CC5FB955401956F146E6394A406CB1DB6795BB55401956F146E6394A406CB1DB6795BB554076C6F7C5A5364A40E77118CC5FB9554076C6F7C5A5364A40
71274	10991	87.081299999999999	87.099428000000003	52.04251	52.027219000000002	Школьная	0103000020E610000001000000050000008C4AEA0434C55540386A85E97B034A408C4AEA0434C5554061E0B9F770054A40A11342075DC6554061E0B9F770054A40A11342075DC65540386A85E97B034A408C4AEA0434C55540386A85E97B034A40
74225	30653	87.648173	87.666067999999996	51.939574	51.921731999999999	Центральная	0103000020E610000001000000050000009D499BAA7BE955409DD66D50FBF549409D499BAA7BE955400116F9F543F84940603AADDBA0EA55400116F9F543F84940603AADDBA0EA55409DD66D50FBF549409D499BAA7BE955409DD66D50FBF54940
71293	12838	87.241335000000007	87.289295999999993	51.797395000000002	51.786465	Бийская	0103000020E6100000010000000500000055185B0872CF55406D3997E2AAE4494055185B0872CF5540397F130A11E6494045B75ED383D25540397F130A11E6494045B75ED383D255406D3997E2AAE4494055185B0872CF55406D3997E2AAE44940
74279	60279	85.239097999999998	87.500597999999997	51.296498	50.192697000000003	Садовая	0103000020E610000001000000050000007FA2B2614D4F5540C784984BAA1849407FA2B2614D4F55402AAA7EA5F3A549405A9C31CC09E055402AAA7EA5F3A549405A9C31CC09E05540C784984BAA1849407FA2B2614D4F5540C784984BAA184940
74183	13010	85.728257999999997	85.748254000000003	50.852024999999998	50.846026000000002	Трактовая	0103000020E61000000100000005000000394371C79B6E554069C878944A6C4940394371C79B6E5540EC2FBB270F6D49407AC6BE64E36F5540EC2FBB270F6D49407AC6BE64E36F554069C878944A6C4940394371C79B6E554069C878944A6C4940
70753	12281	86.041212999999999	86.073390000000003	50.795296	50.776685999999998	Победы	0103000020E61000000100000005000000E2CAD93BA38255406AA164726A634940E2CAD93BA3825540DF516342CC6549409F76F86BB2845540DF516342CC6549409F76F86BB28455406AA164726A634940E2CAD93BA38255406AA164726A634940
71648	45507	86.281915999999995	86.293414999999996	50.698846000000003	50.669643000000001	Центральная	0103000020E61000000100000005000000060E68E90A925540677FA0DCB6554940060E68E90A925540607825C973594940F949B54FC7925540607825C973594940F949B54FC7925540677FA0DCB6554940060E68E90A925540677FA0DCB6554940
71658	12086	86.200502	86.217256000000006	50.717697999999999	50.699838	Советская	0103000020E6100000010000000500000016325706D58C5540C03FA54A9459494016325706D58C5540CA332F87DD5B494007B7B585E78D5540CA332F87DD5B494007B7B585E78D5540C03FA54A9459494016325706D58C5540C03FA54A94594940
74234	60275	85.866562000000002	85.894069000000002	50.841993000000002	50.835628	Семенова	0103000020E61000000100000005000000357D76C0757755409ACFB9DBF56A4940357D76C075775540003B376DC66B494084D72E6D38795540003B376DC66B494084D72E6D387955409ACFB9DBF56A4940357D76C0757755409ACFB9DBF56A4940
71301	13020	85.638193000000001	85.665726000000006	50.842413999999998	50.835748000000002	Центральная	0103000020E6100000010000000500000050E27327D868554045D95BCAF96A494050E27327D8685540A5D8D138D46B4940348639419B6A5540A5D8D138D46B4940348639419B6A554045D95BCAF96A494050E27327D868554045D95BCAF96A4940
71408	12892	85.762439000000001	85.775769999999994	50.843302000000001	50.839092999999998	Яш-Корбо	0103000020E610000001000000050000007A8CF2CCCB705540B9A64066676B49407A8CF2CCCB7055406153E751F16B4940F2CD3637A67155406153E751F16B4940F2CD3637A6715540B9A64066676B49407A8CF2CCCB705540B9A64066676B4940
70383	12168	86.105423999999999	86.164803000000006	50.763339000000002	50.732129999999998	Советская	0103000020E61000000100000005000000AA0D4E44BF865540D235936FB65D4940AA0D4E44BF8655407461A417B561494018D2E1218C8A55407461A417B561494018D2E1218C8A5540D235936FB65D4940AA0D4E44BF865540D235936FB65D4940
74224	45966	85.574224000000001	85.583727999999994	50.913184000000001	50.906191999999997	Центральная	0103000020E6100000010000000500000003250516C0645540CBF27519FE73494003250516C0645540809D9B36E37449409B70AFCC5B655540809D9B36E37449409B70AFCC5B655540CBF27519FE73494003250516C0645540CBF27519FE734940
74161	45966	85.574224000000001	85.583727999999994	50.913184000000001	50.906191999999997	Казакова	0103000020E6100000010000000500000003250516C0645540CBF27519FE73494003250516C0645540809D9B36E37449409B70AFCC5B655540809D9B36E37449409B70AFCC5B655540CBF27519FE73494003250516C0645540CBF27519FE734940
71603	12369	85.970983000000004	85.985472000000001	50.861753999999998	50.84722	Талду	0103000020E61000000100000005000000357EE195247E5540314278B4716C4940357EE195247E55403D997FF44D6E4940EBC726F9117F55403D997FF44D6E4940EBC726F9117F5540314278B4716C4940357EE195247E5540314278B4716C4940
74180	45805	85.829453000000001	85.835553000000004	50.855642000000003	50.851484999999997	Новая	0103000020E610000001000000050000006C2409C2157555406C04E275FD6C49406C2409C215755540C28A53AD856D4940C8444AB379755540C28A53AD856D4940C8444AB3797555406C04E275FD6C49406C2409C2157555406C04E275FD6C4940
74246	49547	86.659514000000001	86.690128999999999	50.453229	50.445754999999998	Подгорная	0103000020E610000001000000050000004450357A35AA5540A583F57F0E3949404450357A35AA5540A54C6A68033A49405B41D3122BAC5540A54C6A68033A49405B41D3122BAC5540A583F57F0E3949404450357A35AA5540A583F57F0E394940
71266	11960	86.416385000000005	86.426276000000001	50.631669000000002	50.617257000000002	Трактовая	0103000020E61000000100000005000000E162450DA69A5540111D0247024F4940E162450DA69A5540D272A087DA50494076C4211B489B5540D272A087DA50494076C4211B489B5540111D0247024F4940E162450DA69A5540111D0247024F4940
74191	12655	85.780485999999996	85.791534999999996	50.692414999999997	50.682257	Этенова	0103000020E61000000100000005000000183F8D7BF3715540C93B873254574940183F8D7BF37155404221020EA1584940EBA86A82A87255404221020EA1584940EBA86A82A8725540C93B873254574940183F8D7BF3715540C93B873254574940
71457	13229	85.574591999999996	85.582605000000001	50.688015999999998	50.676470000000002	Меес-Дьяны	0103000020E61000000100000005000000C422861DC6645540D15CA79196564940C422861DC6645540F78F85E8105849401C5F7B6649655540F78F85E8105849401C5F7B6649655540D15CA79196564940C422861DC6645540D15CA79196564940
70883	724	85.937089	85.957948000000002	50.816397000000002	50.812401999999999	Чорос-Гуркина	0103000020E610000001000000050000003F1C2444F97B55403D9AEAC9FC6749403F1C2444F97B5540B9C667B27F68494031D120054F7D5540B9C667B27F68494031D120054F7D55403D9AEAC9FC6749403F1C2444F97B55403D9AEAC9FC674940
74258	724	85.937089	85.957948000000002	50.816397000000002	50.812401999999999	Центральная 11	0103000020E610000001000000050000003F1C2444F97B55403D9AEAC9FC6749403F1C2444F97B5540B9C667B27F68494031D120054F7D5540B9C667B27F68494031D120054F7D55403D9AEAC9FC6749403F1C2444F97B55403D9AEAC9FC674940
74293	60285	85.576442	85.584581	50.818917999999996	50.811525000000003	Подгорная	0103000020E610000001000000050000009D82FC6CE464554076711B0DE06749409D82FC6CE4645540880D164ED26849403B376DC669655540880D164ED26849403B376DC66965554076711B0DE06749409D82FC6CE464554076711B0DE0674940
71669	11300	86.973359000000002	86.979836000000006	50.403568999999997	50.395341000000002	Центральная	0103000020E610000001000000050000001B118C834BBE55404CE2AC889A3249401B118C834BBE5540F7562426A833494062DC0DA2B5BE5540F7562426A833494062DC0DA2B5BE55404CE2AC889A3249401B118C834BBE55404CE2AC889A324940
71285	49562	86.619827000000001	86.641710000000003	50.458803000000003	50.443420000000003	Подгорная	0103000020E61000000100000005000000618BDD3EABA7554038328FFCC1384940618BDD3EABA755404227840EBA3A494009E1D1C611A955404227840EBA3A494009E1D1C611A9554038328FFCC1384940618BDD3EABA7554038328FFCC1384940
71605	11368	86.690066000000002	86.697935000000001	50.325814000000001	50.319820999999997	Центральная	0103000020E610000001000000050000003885950A2AAC554079C9FFE4EF2849403885950A2AAC55401B4AED45B4294940F6EE8FF7AAAC55401B4AED45B4294940F6EE8FF7AAAC554079C9FFE4EF2849403885950A2AAC554079C9FFE4EF284940
70475	13167	85.552870999999996	85.567072999999993	50.777962000000002	50.763213999999998	Почтовая	0103000020E6100000010000000500000009FA0B3D62635540B7EC10FFB061494009FA0B3D62635540F0C3414294634940745C8DEC4A645540F0C3414294634940745C8DEC4A645540B7EC10FFB061494009FA0B3D62635540B7EC10FFB0614940
74175	12618	85.814971999999997	85.828474	50.745628000000004	50.738343999999998	60-лет Победы	0103000020E61000000100000005000000F7C95180287455405299620E825E4940F7C9518028745540AF7D01BD705F494086E5CFB705755540AF7D01BD705F494086E5CFB7057555405299620E825E4940F7C95180287455405299620E825E4940
71261	11918	86.411120999999994	86.423680000000004	50.490338000000001	50.486946000000003	Центральная	0103000020E61000000100000005000000B96C74CE4F9A554082751C3F543E4940B96C74CE4F9A554037FE4465C33E494009FEB7921D9B554037FE4465C33E494009FEB7921D9B554082751C3F543E4940B96C74CE4F9A554082751C3F543E4940
74164	12559	85.902917000000002	85.916967	50.794817999999999	50.783543000000002	Сетерлинская	0103000020E6100000010000000500000028806264C97955403F0114234B64494028806264C9795540D522A298BC654940B8205B96AF7A5540D522A298BC654940B8205B96AF7A55403F0114234B64494028806264C97955403F0114234B644940
70829	30185	85.732471000000004	85.766733000000002	51.729073	51.719360000000002	Кошурникова	0103000020E610000001000000050000002E910BCEE06E554079060DFD13DC49402E910BCEE06E5540C4B2994352DD4940E5F0492712715540C4B2994352DD4940E5F049271271554079060DFD13DC49402E910BCEE06E554079060DFD13DC4940
71657	30601	86.205003000000005	86.227568000000005	51.689024000000003	51.67794	переулок Школьный	0103000020E610000001000000050000003E25E7C41E8D55403B53E8BCC6D649403E25E7C41E8D55405E143DF031D849406F675F79908E55405E143DF031D849406F675F79908E55403B53E8BCC6D649403E25E7C41E8D55403B53E8BCC6D64940
70237	30034	85.829335999999998	85.872698	51.895539999999997	51.878391000000001	Трактовая	0103000020E610000001000000050000004F594DD713755540E50CC51D6FF049404F594DD7137555404221020EA1F249403752B648DA7755404221020EA1F249403752B648DA775540E50CC51D6FF049404F594DD713755540E50CC51D6FF04940
70810	30101	85.761827999999994	85.792676	51.839289000000001	51.813389000000001	Советская	0103000020E61000000100000005000000554B3ACAC17055408CF678211DE84940554B3ACAC17055403F726BD26DEB4940BE141E34BB7255403F726BD26DEB4940BE141E34BB7255408CF678211DE84940554B3ACAC17055408CF678211DE84940
70837	30101	85.761827999999994	85.792676	51.839289000000001	51.813389000000001	Дружбы	0103000020E61000000100000005000000554B3ACAC17055408CF678211DE84940554B3ACAC17055403F726BD26DEB4940BE141E34BB7255403F726BD26DEB4940BE141E34BB7255408CF678211DE84940554B3ACAC17055408CF678211DE84940
70101	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	Советская	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
70272	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	Подгорная	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
74265	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	Мира	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
70819	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	Механизаторов	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
70409	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	Ленина	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
70832	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	Зональная	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
70929	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	Гидростроителей	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
70488	6509	85.863947999999993	85.926246000000006	52.036715999999998	51.977823999999998	50 лет Победы	0103000020E61000000100000005000000745C8DEC4A775540389F3A5629FD4940745C8DEC4A775540B69E211CB3044A4041834D9D477B5540B69E211CB3044A4041834D9D477B5540389F3A5629FD4940745C8DEC4A775540389F3A5629FD4940
70325	30379	85.981592000000006	86.014757000000003	51.909709999999997	51.870468000000002	Советская	0103000020E61000000100000005000000FA804067D27E5540761BD47E6BEF4940FA804067D27E55400D6C956071F44940C61858C7F18055400D6C956071F44940C61858C7F1805540761BD47E6BEF4940FA804067D27E5540761BD47E6BEF4940
71322	48410	85.832363999999998	85.849620000000002	51.935381999999997	51.922364999999999	Школьная	0103000020E610000001000000050000008997A77345755540CEFC6A0E10F649408997A773457555402FA2ED98BAF74940C381902C607655402FA2ED98BAF74940C381902C60765540CEFC6A0E10F649408997A77345755540CEFC6A0E10F64940
71664	30215	86.029903000000004	86.073750000000004	52.058677000000003	52.038738000000002	Заречная	0103000020E6100000010000000500000059C345EEE9815540658EE55DF5044A4059C345EEE981554082035ABA82074A401F85EB51B884554082035ABA82074A401F85EB51B8845540658EE55DF5044A4059C345EEE9815540658EE55DF5044A40
70844	59414	85.992649999999998	86.009179000000003	51.979681999999997	51.968237000000002	Центральная	0103000020E61000000100000005000000F697DD93877F55407AE3A430EFFB4940F697DD93877F55406C3D433866FD4940D7338463968055406C3D433866FD4940D7338463968055407AE3A430EFFB4940F697DD93877F55407AE3A430EFFB4940
74236	28909	88.355147000000002	88.369754	50.104576999999999	50.099648000000002	Центральная	0103000020E6100000010000000500000071917BBABA165640508E0244C10C494071917BBABA165640F77475C7620D49402C64AE0CAA175640F77475C7620D49402C64AE0CAA175640508E0244C10C494071917BBABA165640508E0244C10C4940
74271	29312	88.739086999999998	88.755059000000003	50.013567000000002	50.007865000000002	Центральная	0103000020E6100000010000000500000085798F334D2F56403BE466B80101494085798F334D2F564005A73E90BC0149403BE3FBE25230564005A73E90BC0149403BE3FBE2523056403BE466B80101494085798F334D2F56403BE466B801014940
74273	32886	88.782241999999997	88.802293000000006	49.921391999999997	49.907772000000001	Советская	0103000020E61000000100000005000000B0E3BF4010325640BD1C76DF31F44840B0E3BF4010325640E4654D2CF0F54840D333BDC458335640E4654D2CF0F54840D333BDC458335640BD1C76DF31F44840B0E3BF4010325640BD1C76DF31F44840
74244	29486	89.188254000000001	89.199959000000007	49.719714000000003	49.711292	Пограничная	0103000020E61000000100000005000000D655815A0C4C564006F4C29D0BDB4840D655815A0C4C5640973C9E961FDC48409E62D520CC4C5640973C9E961FDC48409E62D520CC4C564006F4C29D0BDB4840D655815A0C4C564006F4C29D0BDB4840
74270	28949	88.494979000000001	88.509378999999996	50.038902999999998	50.030797	Кокышева	0103000020E610000001000000050000003C4D66BCAD1F56404FE8F527F10349403C4D66BCAD1F5640AF5B04C6FA0449403A9160AA99205640AF5B04C6FA0449403A9160AA992056404FE8F527F10349403C4D66BCAD1F56404FE8F527F1034940
74269	29004	88.526375000000002	88.539822999999998	49.996046999999997	49.982841999999998	Бухарова	0103000020E61000000100000005000000A69BC420B02156404F9143C4CDFD4840A69BC420B0215640B323D5777EFF48403BA8C4758C225640B323D5777EFF48403BA8C4758C2256404F9143C4CDFD4840A69BC420B02156404F9143C4CDFD4840
74274	28856	87.932210999999995	87.947024999999996	50.221044999999997	50.209021	Белеекова	0103000020E610000001000000050000002C7E5358A9FB5540AF963B33C11A49402C7E5358A9FB5540DFF8DA334B1C4940A4DFBE0E9CFC5540DFF8DA334B1C4940A4DFBE0E9CFC5540AF963B33C11A49402C7E5358A9FB5540AF963B33C11A4940
74248	32738	87.923407999999995	87.936721000000006	50.235652999999999	50.229736000000003	Зеленая	0103000020E610000001000000050000005837DE1D19FB5540605B3FFD671D49405837DE1D19FB5540261AA4E0291E49407E1EA33CF3FB5540261AA4E0291E49407E1EA33CF3FB5540605B3FFD671D49405837DE1D19FB5540605B3FFD671D4940
74260	29091	88.642042000000004	88.680840000000003	50.009613000000002	49.983080000000001	Советская	0103000020E61000000100000005000000242A54371729564004ADC090D5FD4840242A543717295640E84EB0FF3A014940C173EFE1922B5640E84EB0FF3A014940C173EFE1922B564004ADC090D5FD4840242A54371729564004ADC090D5FD4840
74247	29091	88.642042000000004	88.680840000000003	50.009613000000002	49.983080000000001	Новочуйская	0103000020E61000000100000005000000242A54371729564004ADC090D5FD4840242A543717295640E84EB0FF3A014940C173EFE1922B5640E84EB0FF3A014940C173EFE1922B564004ADC090D5FD4840242A54371729564004ADC090D5FD4840
74275	29091	88.642042000000004	88.680840000000003	50.009613000000002	49.983080000000001	Молодежная	0103000020E61000000100000005000000242A54371729564004ADC090D5FD4840242A543717295640E84EB0FF3A014940C173EFE1922B5640E84EB0FF3A014940C173EFE1922B564004ADC090D5FD4840242A54371729564004ADC090D5FD4840
74261	29091	88.642042000000004	88.680840000000003	50.009613000000002	49.983080000000001	Восточная	0103000020E61000000100000005000000242A54371729564004ADC090D5FD4840242A543717295640E84EB0FF3A014940C173EFE1922B5640E84EB0FF3A014940C173EFE1922B564004ADC090D5FD4840242A54371729564004ADC090D5FD4840
74256	29091	88.642042000000004	88.680840000000003	50.009613000000002	49.983080000000001	Абая	0103000020E61000000100000005000000242A54371729564004ADC090D5FD4840242A543717295640E84EB0FF3A014940C173EFE1922B5640E84EB0FF3A014940C173EFE1922B564004ADC090D5FD4840242A54371729564004ADC090D5FD4840
74251	29429	88.991135999999997	89.004935000000003	49.920904999999998	49.906432000000002	Молодежная	0103000020E61000000100000005000000D978B0C56E3F56402106BAF605F44840D978B0C56E3F564087DC0C37E0F54840C5E6E3DA5040564087DC0C37E0F54840C5E6E3DA504056402106BAF605F44840D978B0C56E3F56402106BAF605F44840
74267	29384	88.911618000000004	88.926332000000002	49.849663999999997	49.840561000000001	Абая	0103000020E610000001000000050000007A1C06F3573A564083A5BA8097EB48407A1C06F3573A5640554B3ACAC1EC4840404F0306493B5640554B3ACAC1EC4840404F0306493B564083A5BA8097EB48407A1C06F3573A564083A5BA8097EB4840
74255	32924	86.601590999999999	89.719194000000002	50.368195	49.070692999999999	Центральная	0103000020E6100000010000000500000059A4897780A655402F87DD770C89484059A4897780A655407EC68503212F4940AF5E4546076E56407EC68503212F4940AF5E4546076E56402F87DD770C89484059A4897780A655402F87DD770C894840
74266	29041	88.162108000000003	88.190342000000001	49.979025	49.972861000000002	Школьная	0103000020E61000000100000005000000E19A3BFA5F0A5640E54691B586FC4840E19A3BFA5F0A5640B37BF2B050FD4840894336902E0C5640B37BF2B050FD4840894336902E0C5640E54691B586FC4840E19A3BFA5F0A5640E54691B586FC4840
73563	60029	73.179655999999994	73.184523999999996	54.955500000000001	54.953364000000001	Новая	0103000020E61000000100000005000000EE21E17B7F4B52408597E0D4077A4B40EE21E17B7F4B5240FCA9F1D24D7A4B40EF54C03DCF4B5240FCA9F1D24D7A4B40EF54C03DCF4B52408597E0D4077A4B40EE21E17B7F4B52408597E0D4077A4B40
6651	41	73.303478999999996	73.308886999999999	55.037416999999998	55.032190999999997	улица космонавта Волкова	0103000020E6100000010000000500000075012F336C535240DE1CAED51E844B4075012F336C5352403FA88B14CA844B4036CAFACDC45352403FA88B14CA844B4036CAFACDC4535240DE1CAED51E844B4075012F336C535240DE1CAED51E844B40
6358	41	73.239726000000005	73.304899000000006	55.047466	55.035688999999998	улица Энтузиастов	0103000020E610000001000000050000000F80B8AB574F5240D9E9077591844B400F80B8AB574F524002D6AA5D13864B40526518778353524002D6AA5D13864B405265187783535240D9E9077591844B400F80B8AB574F5240D9E9077591844B40
6525	41	73.276251000000002	73.280608000000001	55.046464999999998	55.030709999999999	улица Энергетиков	0103000020E61000000100000005000000309FAC18AE51524080D4264EEE834B40309FAC18AE5152404EB4AB90F2854B40BEBF417BF55152404EB4AB90F2854B40BEBF417BF551524080D4264EEE834B40309FAC18AE51524080D4264EEE834B40
5586	41	73.405401999999995	73.405510000000007	54.927836999999997	54.926636999999999	улица Шота Руставели	0103000020E61000000100000005000000E9EE3A1BF2595240BC218D0A9C764B40E9EE3A1BF25952406682E15CC3764B40DD0C37E0F35952406682E15CC3764B40DD0C37E0F3595240BC218D0A9C764B40E9EE3A1BF2595240BC218D0A9C764B40
7481	41	73.375326999999999	73.381848000000005	54.974741999999999	54.974251000000002	улица Чокана Валиханова	0103000020E610000001000000050000009293895B05585240338CBB41B47C4B409293895B05585240D1048A58C47C4B40C102983270585240D1048A58C47C4B40C102983270585240338CBB41B47C4B409293895B05585240338CBB41B47C4B40
7258	41	73.374032999999997	73.397981999999999	54.979897999999999	54.978265999999998	улица Чкалова	0103000020E61000000100000005000000FCA71B28F0575240F564FED1377D4B40FCA71B28F057524039B5334C6D7D4B4063997E897859524039B5334C6D7D4B4063997E8978595240F564FED1377D4B40FCA71B28F0575240F564FED1377D4B40
5432	41	73.368696999999997	73.381434999999996	54.933397999999997	54.930781000000003	улица Чайковского	0103000020E6100000010000000500000088484DBB985752407D5EF1D423774B4088484DBB985752406E13EE9579774B402FA3586E695852406E13EE9579774B402FA3586E695852407D5EF1D423774B4088484DBB985752407D5EF1D423774B40
7391	41	73.379441	73.388711999999998	54.963569	54.961765	улица Циолковского	0103000020E61000000100000005000000BD70E7C248585240FEB7921D1B7B4B40BD70E7C2485852403F389F3A567B4B4004E44BA8E05852403F389F3A567B4B4004E44BA8E0585240FEB7921D1B7B4B40BD70E7C248585240FEB7921D1B7B4B40
30166	41	73.413432999999998	73.421626000000003	55.069994000000001	55.066477999999996	улица Центральная	0103000020E610000001000000050000009485AFAF755A5240A5F3E15982884B409485AFAF755A524047753A90F5884B402C499EEBFB5A524047753A90F5884B402C499EEBFB5A5240A5F3E15982884B409485AFAF755A5240A5F3E15982884B40
15442	41	73.413432999999998	73.421626000000003	55.069994000000001	55.066477999999996	улица Центральная	0103000020E610000001000000050000009485AFAF755A5240A5F3E15982884B409485AFAF755A524047753A90F5884B402C499EEBFB5A524047753A90F5884B402C499EEBFB5A5240A5F3E15982884B409485AFAF755A5240A5F3E15982884B40
5085	41	73.410684000000003	73.411116000000007	54.942666000000003	54.940303	улица Хасан Озеро	0103000020E61000000100000005000000643F8BA5485A524054AA44D95B784B40643F8BA5485A52408C868C47A9784B4031B77BB94F5A52408C868C47A9784B4031B77BB94F5A524054AA44D95B784B40643F8BA5485A524054AA44D95B784B40
6321	41	73.255949999999999	73.287515999999997	55.033388000000002	55.030833999999999	улица ХХ Партсъезда	0103000020E6100000010000000500000051DA1B7C615052406CCD565EF2834B4051DA1B7C61505240180AD80E46844B40E94482A966525240180AD80E46844B40E94482A9665252406CCD565EF2834B4051DA1B7C615052406CCD565EF2834B40
6339	41	73.272047000000001	73.275030000000001	55.039935	55.030622000000001	улица ХIХ Партсъезда	0103000020E6100000010000000500000065FED13769515240E144F46BEB834B4065FED137695152409E7B0F971C854B40CFDA6D179A5152409E7B0F971C854B40CFDA6D179A515240E144F46BEB834B4065FED13769515240E144F46BEB834B40
4744	41	73.263593999999998	73.264232000000007	54.998756999999998	54.993794000000001	улица Фугенфирова	0103000020E61000000100000005000000FF5A5EB9DE505240037B4CA4347F4B40FF5A5EB9DE50524056D3F544D77F4B40A1A3552DE950524056D3F544D77F4B40A1A3552DE9505240037B4CA4347F4B40FF5A5EB9DE505240037B4CA4347F4B40
6831	41	73.353947000000005	73.376800000000003	54.995901000000003	54.991588999999998	улица Фрунзе	0103000020E610000001000000050000001C615111A756524063096B63EC7E4B401C615111A7565240E08618AF797F4B408048BF7D1D585240E08618AF797F4B408048BF7D1D58524063096B63EC7E4B401C615111A756524063096B63EC7E4B40
15479	41	73.375963999999996	73.384094000000005	54.946483000000001	54.9452	улица Федора Крылова	0103000020E610000001000000050000004B1E4FCB0F585240F0164850FC784B404B1E4FCB0F585240289CDD5A26794B40C02500FF94585240289CDD5A26794B40C02500FF94585240F0164850FC784B404B1E4FCB0F585240F0164850FC784B40
5157	41	73.437139999999999	73.443337999999997	54.916589000000002	54.916531999999997	улица Усадебная	0103000020E6100000010000000500000080F10C1AFA5B524065DEAAEB50754B4080F10C1AFA5B5240CA6FD1C952754B40BDC458A65F5C5240CA6FD1C952754B40BDC458A65F5C524065DEAAEB50754B4080F10C1AFA5B524065DEAAEB50754B40
6368	41	73.303291000000002	73.307252000000005	55.051519999999996	55.042338999999998	улица Тимофея Белозерова	0103000020E61000000100000005000000F48AA71E69535240342C465D6B854B40F48AA71E69535240828B153598864B405CE84A04AA535240828B153598864B405CE84A04AA535240342C465D6B854B40F48AA71E69535240342C465D6B854B40
4014	41	73.368364999999997	73.369488000000004	55.031886	54.987791999999999	улица Тарская	0103000020E610000001000000050000006DFFCA4A935752400EA0DFF76F7E4B406DFFCA4A93575240A29927D714844B40ED10FFB0A5575240A29927D714844B40ED10FFB0A55752400EA0DFF76F7E4B406DFFCA4A935752400EA0DFF76F7E4B40
4407	41	73.328192000000001	73.341766000000007	54.947904999999999	54.939211999999998	улица Суровцева	0103000020E61000000100000005000000C4B304190155524060014C1938784B40C4B3041901555240815B77F354794B40A038807EDF555240815B77F354794B40A038807EDF55524060014C1938784B40C4B304190155524060014C1938784B40
5624	41	73.409400000000005	73.424634999999995	54.928674999999998	54.922238999999998	улица Спортивная	0103000020E61000000100000005000000E0BE0E9C335A5240410C74ED0B764B40E0BE0E9C335A524070CE88D2DE764B402A6F47382D5B524070CE88D2DE764B402A6F47382D5B5240410C74ED0B764B40E0BE0E9C335A5240410C74ED0B764B40
6766	41	73.330258000000001	73.336905999999999	55.033454999999996	55.029141000000003	улица Сибниисхоз	0103000020E61000000100000005000000834F73F22255524083FC6CE4BA834B40834F73F2225552409F71E14048844B40E0F42EDE8F5552409F71E14048844B40E0F42EDE8F55524083FC6CE4BA834B40834F73F22255524083FC6CE4BA834B40
4453	41	73.309965000000005	73.324599000000006	54.948866000000002	54.940069999999999	улица Седова	0103000020E61000000100000005000000E6797077D6535240B1F9B83654784B40E6797077D6535240A724EB7074794B401E54E23AC6545240A724EB7074794B401E54E23AC6545240B1F9B83654784B40E6797077D6535240B1F9B83654784B40
5796	41	73.412651999999994	73.432997999999998	54.950308999999997	54.932409999999997	улица Свободы	0103000020E610000001000000050000004128EFE3685A52404F3BFC3559774B404128EFE3685A5240170CAEB9A3794B40F04E3E3DB65B5240170CAEB9A3794B40F04E3E3DB65B52404F3BFC3559774B404128EFE3685A52404F3BFC3559774B40
6404	41	73.299087	73.305087	55.051288	55.047812	улица Светлая	0103000020E6100000010000000500000029EACC3D245352409D2D20B41E864B4029EACC3D24535240B056ED9A90864B40D3DB9F8B86535240B056ED9A90864B40D3DB9F8B865352409D2D20B41E864B4029EACC3D245352409D2D20B41E864B40
30162	41	73.293408999999997	73.293715000000006	54.977319999999999	54.97392	улица Садовая	0103000020E6100000010000000500000088D68A36C7525240CD751A69A97C4B4088D68A36C752524005DD5ED2187D4B400FD6FF39CC52524005DD5ED2187D4B400FD6FF39CC525240CD751A69A97C4B4088D68A36C7525240CD751A69A97C4B40
5874	41	73.470746000000005	73.477923000000004	54.981293000000001	54.980854000000001	улица Романенко	0103000020E6100000010000000500000043AED4B3205E52404D13B69F8C7D4B4043AED4B3205E524099654F029B7D4B4066C0594A965E524099654F029B7D4B4066C0594A965E52404D13B69F8C7D4B4043AED4B3205E52404D13B69F8C7D4B40
4883	41	73.364951000000005	73.382531	54.996867000000002	54.994894000000002	улица Рабиновича	0103000020E610000001000000050000001F69705B5B5752404A7EC4AF587F4B401F69705B5B57524017BB7D56997F4B4032AD4D637B58524017BB7D56997F4B4032AD4D637B5852404A7EC4AF587F4B401F69705B5B5752404A7EC4AF587F4B40
4718	41	73.274940000000001	73.282638000000006	54.994956000000002	54.989764999999998	улица Путилова	0103000020E610000001000000050000002F17F19D98515240DBDC989EB07E4B402F17F19D98515240C07ADCB75A7F4B40D7A6B1BD16525240C07ADCB75A7F4B40D7A6B1BD16525240DBDC989EB07E4B402F17F19D98515240DBDC989EB07E4B40
7903	41	73.441531999999995	73.44332	54.964385	54.959377000000003	улица Промышленная	0103000020E61000000100000005000000CC086F0F425C52406EC493DDCC7A4B40CC086F0F425C524061E0B9F7707B4B406A6AD95A5F5C524061E0B9F7707B4B406A6AD95A5F5C52406EC493DDCC7A4B40CC086F0F425C52406EC493DDCC7A4B40
3638	41	73.380725999999996	73.392951999999994	54.981504999999999	54.980688999999998	улица Почтовая	0103000020E6100000010000000500000029AF95D05D58524002469737877D4B4029AF95D05D58524024EEB1F4A17D4B40753925202659524024EEB1F4A17D4B40753925202659524002469737877D4B4029AF95D05D58524002469737877D4B40
15762	41	73.369011	73.395673000000002	54.835222000000002	54.833739000000001	улица Поморцева	0103000020E61000000100000005000000503750E09D5752402B33A5F5B76A4B40503750E09D5752402A73F38DE86A4B4041BAD8B4525952402A73F38DE86A4B4041BAD8B4525952402B33A5F5B76A4B40503750E09D5752402B33A5F5B76A4B40
5696	41	73.390122000000005	73.410792000000001	54.971052	54.969290000000001	улица Плеханова	0103000020E61000000100000005000000CFDC43C2F7585240802BD9B1117C4B40CFDC43C2F7585240925B936E4B7C4B40575D876A4A5A5240925B936E4B7C4B40575D876A4A5A5240802BD9B1117C4B40CFDC43C2F7585240802BD9B1117C4B40
5919	41	73.456659999999999	73.469255000000004	54.980606000000002	54.972659	улица Петра Осминина	0103000020E610000001000000050000000C59DDEA395D52407D941117807C4B400C59DDEA395D52407521567F847D4B40029F1F46085E52407521567F847D4B40029F1F46085E52407D941117807C4B400C59DDEA395D52407D941117807C4B40
4553	41	73.278002999999998	73.299589999999995	55.001845000000003	54.987425000000002	улица Перелета	0103000020E61000000100000005000000274C18CDCA5152405C2041F1637E4B40274C18CDCA515240A054FB743C804B405A0D897B2C535240A054FB743C804B405A0D897B2C5352405C2041F1637E4B40274C18CDCA5152405C2041F1637E4B40
15373	41	73.415938999999995	73.419927999999999	55.067354999999999	55.065128000000001	улица Первомайская	0103000020E6100000010000000500000061889CBE9E5A5240E606431D56884B4061889CBE9E5A52406D1CB1169F884B402EABB019E05A52406D1CB1169F884B402EABB019E05A5240E606431D56884B4061889CBE9E5A5240E606431D56884B40
5854	41	73.439323000000002	73.448926	54.974592000000001	54.969056999999999	улица Пархоменко	0103000020E610000001000000050000005C5837DE1D5C5240DD7A4D0F0A7C4B405C5837DE1D5C5240BC783F6EBF7C4B40BE141E34BB5C5240BC783F6EBF7C4B40BE141E34BB5C5240DD7A4D0F0A7C4B405C5837DE1D5C5240DD7A4D0F0A7C4B40
7115	41	73.386842999999999	73.447461000000004	54.994574	54.987152000000002	улица Омская	0103000020E61000000100000005000000F06B2409C25852402B172AFF5A7E4B40F06B2409C2585240D8B969334E7F4B40124F7633A35C5240D8B969334E7F4B40124F7633A35C52402B172AFF5A7E4B40F06B2409C25852402B172AFF5A7E4B40
5889	41	73.469218999999995	73.469255000000004	54.975935	54.972659	улица Олимпийская	0103000020E610000001000000050000005BEA20AF075E52407D941117807C4B405BEA20AF075E5240C9022670EB7C4B40029F1F46085E5240C9022670EB7C4B40029F1F46085E52407D941117807C4B405BEA20AF075E52407D941117807C4B40
1904	41	73.347362000000004	73.386240999999998	55.000470999999997	54.995131999999998	улица Октябрьская	0103000020E61000000100000005000000E277D32D3B565240FE99417C607F4B40E277D32D3B56524057CC086F0F804B40F5D72B2CB858524057CC086F0F804B40F5D72B2CB8585240FE99417C607F4B40E277D32D3B565240FE99417C607F4B40
4343	41	73.268220999999997	73.274400999999997	54.930475999999999	54.928634000000002	улица Новостройка	0103000020E610000001000000050000006DC669882A51524012FA997ADD764B406DC669882A51524040DB6AD619774B40573F36C98F51524040DB6AD619774B40573F36C98F51524012FA997ADD764B406DC669882A51524012FA997ADD764B40
4576	41	73.267080000000007	73.283186000000001	54.984960999999998	54.974105999999999	улица Новороссийская	0103000020E610000001000000050000009B5AB6D6175152402F6B6281AF7C4B409B5AB6D617515240F06AB933137E4B40D82B2CB81F525240F06AB933137E4B40D82B2CB81F5252402F6B6281AF7C4B409B5AB6D6175152402F6B6281AF7C4B40
5049	41	73.436708999999993	73.456722999999997	54.911838000000003	54.911485999999996	улица Моторная	0103000020E610000001000000050000009B374E0AF35B52408461C092AB744B409B374E0AF35B524002A08A1BB7744B402F151BF33A5D524002A08A1BB7744B402F151BF33A5D52408461C092AB744B409B374E0AF35B52408461C092AB744B40
5216	41	73.448108000000005	73.469740000000002	54.925519999999999	54.923797	улица Молодогвардейская	0103000020E61000000100000005000000DD442DCDAD5C52404B92E7FA3E764B40DD442DCDAD5C52409FE5797077764B40E0675C38105E52409FE5797077764B40E0675C38105E52404B92E7FA3E764B40DD442DCDAD5C52404B92E7FA3E764B40
5200	41	73.446725000000001	73.456740999999994	54.906140000000001	54.904767999999997	улица Молодова	0103000020E610000001000000050000008F537424975C5240D13B1570CF734B408F537424975C524079CC4065FC734B40826F9A3E3B5D524079CC4065FC734B40826F9A3E3B5D5240D13B1570CF734B408F537424975C5240D13B1570CF734B40
4917	41	73.305769999999995	73.315436000000005	54.921339000000003	54.919280000000001	улица Менжинского	0103000020E61000000100000005000000448655BC91535240F6EE8FF7AA754B40448655BC91535240C2C3B46FEE754B40CAFE791A30545240C2C3B46FEE754B40CAFE791A30545240F6EE8FF7AA754B40448655BC91535240F6EE8FF7AA754B40
4292	41	73.304360000000003	73.325918999999999	54.934257000000002	54.894171	улица Мельничная	0103000020E610000001000000050000007A8D5DA27A5352400C04013274724B407A8D5DA27A5352409087BEBB95774B4048895DDBDB5452409087BEBB95774B4048895DDBDB5452400C04013274724B407A8D5DA27A5352400C04013274724B40
5665	41	73.382298000000006	73.439565000000002	54.977429000000001	54.972752	улица Масленникова	0103000020E61000000100000005000000E1D40792775852402E8F3523837C4B40E1D4079277585240BC94BA641C7D4B40D7DD3CD5215C5240BC94BA641C7D4B40D7DD3CD5215C52402E8F3523837C4B40E1D40792775852402E8F3523837C4B40
6291	41	73.254341999999994	73.260666000000001	55.040621000000002	55.028945	улица Мамина-Сибиряка	0103000020E61000000100000005000000F3FFAA2347505240FD304278B4834B40F3FFAA2347505240F243A51133854B40774B72C0AE505240F243A51133854B40774B72C0AE505240FD304278B4834B40F3FFAA2347505240FD304278B4834B40
3885	41	73.249571000000003	73.289743999999999	55.036802999999999	55.030833999999999	улица Магистральная	0103000020E61000000100000005000000ECC1A4F8F84F52406CCD565EF2834B40ECC1A4F8F84F524085B2F0F5B5844B40950D6B2A8B52524085B2F0F5B5844B40950D6B2A8B5252406CCD565EF2834B40ECC1A4F8F84F52406CCD565EF2834B40
5003	41	73.379054999999994	73.383833999999993	54.941420000000001	54.929895999999999	улица Лобкова	0103000020E61000000100000005000000A818E76F42585240325706D506774B40A818E76F4258524071E6577380784B40F1457BBC9058524071E6577380784B40F1457BBC90585240325706D506774B40A818E76F42585240325706D506774B40
7362	41	73.372316999999995	73.438873000000001	54.985410999999999	54.980967999999997	улица Лермонтова	0103000020E61000000100000005000000ABAFAE0AD45752401536035C907D4B40ABAFAE0AD4575240300F99F2217E4B403C86C77E165C5240300F99F2217E4B403C86C77E165C52401536035C907D4B40ABAFAE0AD45752401536035C907D4B40
65	41	73.278227999999999	73.378991999999997	54.989398000000001	54.905802999999999	улица Ленина	0103000020E610000001000000050000003735D07CCE51524031CF4A5AF1734B403735D07CCE515240295DFA97A47E4B40855CA96741585240295DFA97A47E4B40855CA9674158524031CF4A5AF1734B403735D07CCE51524031CF4A5AF1734B40
7286	41	73.394784000000001	73.400290999999996	54.992255	54.965795999999997	улица Куйбышева	0103000020E61000000100000005000000FB3E1C2444595240C64D0D349F7B4B40FB3E1C244459524070253B36027F4B408578245E9E59524070253B36027F4B408578245E9E595240C64D0D349F7B4B40FB3E1C2444595240C64D0D349F7B4B40
6336	41	73.248052999999999	73.258375000000001	55.038964999999997	55.036029999999997	улица Круговая	0103000020E610000001000000050000002EABB019E04F524062D68BA19C844B402EABB019E04F524025581CCEFC844B40A8C64B378950524025581CCEFC844B40A8C64B378950524062D68BA19C844B402EABB019E04F524062D68BA19C844B40
290	41	73.303156000000001	73.364115999999996	55.022551	54.991072000000003	улица Красный Путь	0103000020E6100000010000000500000084656CE8665352409CFD8172DB7E4B4084656CE866535240FDBE7FF3E2824B40D2FC31AD4D575240FDBE7FF3E2824B40D2FC31AD4D5752409CFD8172DB7E4B4084656CE8665352409CFD8172DB7E4B40
7028	41	73.451584999999994	73.474815000000007	55.036112000000003	55.034590000000001	улица Краснознаменная	0103000020E610000001000000050000004E97C5C4E65C52406362F3716D844B404E97C5C4E65C5240207F69519F844B409E29745E635E5240207F69519F844B409E29745E635E52406362F3716D844B404E97C5C4E65C52406362F3716D844B40
15780	41	73.415831999999995	73.422443000000001	55.069761999999997	55.066071000000001	улица Комсомольская	0103000020E610000001000000050000005628D2FD9C5A5240651BB80375884B405628D2FD9C5A5240744012F6ED884B40255B5D4E095B5240744012F6ED884B40255B5D4E095B5240651BB80375884B405628D2FD9C5A5240651BB80375884B40
6392	41	73.299940000000007	73.317573999999993	55.056373000000001	55.052700999999999	улица Коммунальная	0103000020E61000000100000005000000C9B08A3732535240B6BB07E8BE864B40C9B08A37325352404FB0FF3A37874B40D503E621535452404FB0FF3A37874B40D503E62153545240B6BB07E8BE864B40C9B08A3732535240B6BB07E8BE864B40
6147	41	73.416002000000006	73.438343000000003	54.950733	54.931552000000003	улица Кирова	0103000020E610000001000000050000008544DAC69F5A5240FF428F183D774B408544DAC69F5A52402E1D739EB1794B408E5BCCCF0D5C52402E1D739EB1794B408E5BCCCF0D5C5240FF428F183D774B408544DAC69F5A5240FF428F183D774B40
5707	41	73.401556999999997	73.423854000000006	54.964917999999997	54.963433999999999	улица Ипподромная	0103000020E61000000100000005000000B69E211CB35952405FED28CE517B4B40B69E211CB35952402EA9DA6E827B4B40D811876C205B52402EA9DA6E827B4B40D811876C205B52405FED28CE517B4B40B69E211CB35952405FED28CE517B4B40
7293	41	73.386662999999999	73.424437999999995	54.988309000000001	54.986185999999996	улица Звездова	0103000020E61000000100000005000000B0E42A16BF585240F3E2C4573B7E4B40B0E42A16BF585240D6ABC8E8807E4B407F4B00FE295B5240D6ABC8E8807E4B407F4B00FE295B5240F3E2C4573B7E4B40B0E42A16BF585240F3E2C4573B7E4B40
4817	41	73.244980999999996	73.245394000000005	54.998199	54.994878999999997	улица Звездная	0103000020E610000001000000050000000CC9C9C4AD4F5240143DF031587F4B400CC9C9C4AD4F524030F31DFCC47F4B409E280989B44F524030F31DFCC47F4B409E280989B44F5240143DF031587F4B400CC9C9C4AD4F5240143DF031587F4B40
6676	41	73.302833000000007	73.320772000000005	55.063791999999999	55.018649000000003	улица Заозерная	0103000020E6100000010000000500000093C9A99D61535240338D261763824B4093C9A99D615352408BDF14562A884B403E5E4887875452408BDF14562A884B403E5E488787545240338D261763824B4093C9A99D61535240338D261763824B40
7023	41	73.421679999999995	73.467924999999994	55.038795	55.032984999999996	улица Завертяева	0103000020E6100000010000000500000025581CCEFC5A524018213CDA38844B4025581CCEFC5A5240C91F0C3CF7844B40C5FEB27BF25D5240C91F0C3CF7844B40C5FEB27BF25D524018213CDA38844B4025581CCEFC5A524018213CDA38844B40
5871	41	73.467924999999994	73.476305999999994	54.981282999999998	54.976771999999997	улица Ермолаева	0103000020E61000000100000005000000C5FEB27BF25D524002D369DD067D4B40C5FEB27BF25D5240758F6CAE9A7D4B40DE3829CC7B5E5240758F6CAE9A7D4B40DE3829CC7B5E524002D369DD067D4B40C5FEB27BF25D524002D369DD067D4B40
7173	41	73.369011	73.369163999999998	54.984977000000001	54.983798999999998	улица Достоевского	0103000020E61000000100000005000000503750E09D575240336B2920ED7D4B40503750E09D575240F627F1B9137E4B4013B70A62A0575240F627F1B9137E4B4013B70A62A0575240336B2920ED7D4B40503750E09D575240336B2920ED7D4B40
5409	41	73.349698000000004	73.358196000000007	55.022660000000002	55.007747000000002	улица Долгирева	0103000020E61000000100000005000000815EB8736156524031D28BDAFD804B40815EB87361565240B476DB85E6824B40B763EAAEEC565240B476DB85E6824B40B763EAAEEC56524031D28BDAFD804B40815EB8736156524031D28BDAFD804B40
5037	41	73.396328999999994	73.411582999999993	54.941358000000001	54.941167	улица Добролюбова	0103000020E61000000100000005000000355D4F745D5952408789062978784B40355D4F745D595240FBE93F6B7E784B40BB253960575A5240FBE93F6B7E784B40BB253960575A52408789062978784B40355D4F745D5952408789062978784B40
4511	41	73.299796000000001	73.321545	54.990690000000001	54.976762000000001	улица Дмитриева	0103000020E610000001000000050000002FDE8FDB2F535240DFFC8689067D4B402FDE8FDB2F535240B43C0FEECE7E4B404FCC7A3194545240B43C0FEECE7E4B404FCC7A3194545240DFFC8689067D4B402FDE8FDB2F535240DFFC8689067D4B40
4766	41	73.222989999999996	73.270169999999993	54.995807999999997	54.991396999999999	улица Дианова	0103000020E610000001000000050000007155D977454E52401F2DCE18E67E4B407155D977454E52402E8CF4A2767F4B400F971C774A5152402E8CF4A2767F4B400F971C774A5152401F2DCE18E67E4B407155D977454E52401F2DCE18E67E4B40
7265	41	73.391414999999995	73.396195000000006	54.988391	54.965926000000003	улица Декабристов	0103000020E610000001000000050000007C0A80F10C595240952D9276A37B4B407C0A80F10C5952409354A698837E4B40AEF545425B5952409354A698837E4B40AEF545425B595240952D9276A37B4B407C0A80F10C595240952D9276A37B4B40
5614	41	73.394397999999995	73.416415999999998	54.920060999999997	54.917085999999998	улица Гуртьева	0103000020E61000000100000005000000E6E61BD13D5952404ACFF41263754B40E6E61BD13D5952409BA9108FC4754B40FE614B8FA65A52409BA9108FC4754B40FE614B8FA65A52404ACFF41263754B40E6E61BD13D5952404ACFF41263754B40
6330	41	73.269721000000004	73.272586000000004	55.037788999999997	55.033057999999997	улица Грозненская	0103000020E61000000100000005000000D882DE1B43515240826F9A3E3B844B40D882DE1B4351524003931B45D6844B403DD68C0C7251524003931B45D6844B403DD68C0C72515240826F9A3E3B844B40D882DE1B43515240826F9A3E3B844B40
6	41	73.373395000000002	73.380447000000004	54.991061999999999	54.982714000000001	улица Гагарина	0103000020E610000001000000050000005B5F24B4E557524022A98592C97D4B405B5F24B4E557524078279F1EDB7E4B4020B75F3E5958524078279F1EDB7E4B4020B75F3E5958524022A98592C97D4B405B5F24B4E557524022A98592C97D4B40
7163	41	73.352213000000006	73.384606000000005	54.999654999999997	54.974767999999997	улица Волочаевская	0103000020E61000000100000005000000780E65A88A565240FA97A432C57C4B40780E65A88A5652403524EEB1F47F4B401BF67B629D5852403524EEB1F47F4B401BF67B629D585240FA97A432C57C4B40780E65A88A565240FA97A432C57C4B40
4398	41	73.321634000000003	73.348844	54.948329000000001	54.934728	улица Володарского	0103000020E6100000010000000500000007D2C5A695545240E753C72AA5774B4007D2C5A695545240986C3CD862794B40F9D9C87553565240986C3CD862794B40F9D9C87553565240E753C72AA5774B4007D2C5A695545240E753C72AA5774B40
5235	41	73.466048000000001	73.477474000000001	54.927863000000002	54.926957999999999	улица Волго-Донская	0103000020E610000001000000050000007097FDBAD35D5240FE614B8FA6764B407097FDBAD35D52409015FC36C4764B402EAC1BEF8E5E52409015FC36C4764B402EAC1BEF8E5E5240FE614B8FA6764B407097FDBAD35D5240FE614B8FA6764B40
5940	41	73.464143000000007	73.469218999999995	54.979056	54.975935	улица Василия Товстухо	0103000020E61000000100000005000000B66AD784B45D5240C9022670EB7C4B40B66AD784B45D5240EE79FEB4517D4B405BEA20AF075E5240EE79FEB4517D4B405BEA20AF075E5240C9022670EB7C4B40B66AD784B45D5240C9022670EB7C4B40
15586	41	73.482153999999994	73.495620000000002	54.892338000000002	54.881084999999999	улица Василия Маргелова	0103000020E61000000100000005000000AD68739CDB5E524082FFAD64C7704B40AD68739CDB5E5240317DAF2138724B4096CFF23CB85F5240317DAF2138724B4096CFF23CB85F524082FFAD64C7704B40AD68739CDB5E524082FFAD64C7704B40
3997	41	73.388666999999998	73.412938999999994	54.96743	54.963569	улица Бульварная	0103000020E6100000010000000500000034828DEBDF5852403F389F3A567B4B4034828DEBDF585240AB9509BFD47B4B408C0FB3976D5A5240AB9509BFD47B4B408C0FB3976D5A52403F389F3A567B4B4034828DEBDF5852403F389F3A567B4B40
7193	41	73.364439000000004	73.376863	54.995989000000002	54.994078000000002	улица Булатова	0103000020E61000000100000005000000C498F4F75257524028D6A9F23D7F4B40C498F4F7525752407F164B917C7F4B40A304FD851E5852407F164B917C7F4B40A304FD851E58524028D6A9F23D7F4B40C498F4F75257524028D6A9F23D7F4B40
6376	41	73.306803000000002	73.326871999999995	55.052185000000001	55.049235000000003	улица Бородина	0103000020E6100000010000000500000024D40CA9A2535240C7681D554D864B4024D40CA9A2535240BF2B82FFAD864B40997E8978EB545240BF2B82FFAD864B40997E8978EB545240C7681D554D864B4024D40CA9A2535240C7681D554D864B40
5729	41	73.408591000000001	73.416110000000003	54.992440999999999	54.950479999999999	улица Богдана Хмельницкого	0103000020E61000000100000005000000289CDD5A265A524044C02154A9794B40289CDD5A265A5240D21A834E087F4B407862D68BA15A5240D21A834E087F4B407862D68BA15A524044C02154A9794B40289CDD5A265A524044C02154A9794B40
4356	41	73.325111000000007	73.337192999999999	54.933078000000002	54.930025999999998	улица Бетховена	0103000020E6100000010000000500000079245E9ECE54524000378B170B774B4079245E9ECE545240FD4E93196F774B402BDCF29194555240FD4E93196F774B402BDCF2919455524000378B170B774B4079245E9ECE54524000378B170B774B40
5250	41	73.472065999999998	73.474770000000007	54.931142999999999	54.921509999999998	улица Батумская	0103000020E610000001000000050000006DE34F54365E5240EE77280AF4754B406DE34F54365E52401D739EB12F774B40CEC7B5A1625E52401D739EB12F774B40CEC7B5A1625E5240EE77280AF4754B406DE34F54365E5240EE77280AF4754B40
6661	41	73.324078	73.327490999999995	55.050168999999997	55.042571000000002	улица Бархатовой	0103000020E6100000010000000500000099D6A6B1BD54524007616EF772854B4099D6A6B1BD545240F22213F06B864B40FFAECF9CF5545240F22213F06B864B40FFAECF9CF554524007616EF772854B4099D6A6B1BD54524007616EF772854B40
6992	41	73.400622999999996	73.424976999999998	55.024915	55.003760999999997	улица Барнаульская	0103000020E61000000100000005000000A0C1A6CEA359524008008E3D7B804B40A0C1A6CEA359524005172B6A30834B405723BBD2325B524005172B6A30834B405723BBD2325B524008008E3D7B804B40A0C1A6CEA359524008008E3D7B804B40
6938	41	73.406902000000002	73.427527999999995	55.033088999999997	55.020837999999998	улица Багратиона	0103000020E6100000010000000500000054ABAFAE0A5A5240CC41D0D1AA824B4054ABAFAE0A5A5240BD6DA6423C844B40F487669E5C5B5240BD6DA6423C844B40F487669E5C5B5240CC41D0D1AA824B4054ABAFAE0A5A5240CC41D0D1AA824B40
5008	41	73.393535999999997	73.409723	54.944709000000003	54.944310999999999	улица Артема Избышева	0103000020E610000001000000050000001D739EB12F5952406420CF2EDF784B401D739EB12F595240529E7939EC784B40D15AD1E6385A5240529E7939EC784B40D15AD1E6385A52406420CF2EDF784B401D739EB12F5952406420CF2EDF784B40
7251	41	73.405753000000004	73.419173000000001	55.012042000000001	55.011370999999997	улица Арсеньева	0103000020E6100000010000000500000040506EDBF7595240B88FDC9A74814B4040506EDBF7595240D7169E978A814B407097FDBAD35A5240D7169E978A814B407097FDBAD35A5240B88FDC9A74814B4040506EDBF7595240B88FDC9A74814B40
6554	41	73.258787999999996	73.293284	55.026457999999998	55.024208000000002	улица Андрианова	0103000020E6100000010000000500000039268BFB8F5052409A266C3F19834B4039268BFB8F505240D95BCAF962834B402A1C412AC5525240D95BCAF962834B402A1C412AC55252409A266C3F19834B4039268BFB8F5052409A266C3F19834B40
4928	41	73.389655000000005	73.390984000000003	54.952558000000003	54.949466000000001	улица Ангарская	0103000020E61000000100000005000000446E861BF0585240FC54151A88794B40446E861BF058524087C5A86BED794B409850C1E10559524087C5A86BED794B409850C1E105595240FC54151A88794B40446E861BF0585240FC54151A88794B40
5103	41	73.400749000000005	73.4298	54.925375000000003	54.924686999999999	улица Алексея Полторацкого	0103000020E61000000100000005000000E73922DFA5595240A704C4245C764B40E73922DFA55952409CC420B072764B4088F4DBD7815B52409CC420B072764B4088F4DBD7815B5240A704C4245C764B40E73922DFA5595240A704C4245C764B40
4438	41	73.319846999999996	73.327490999999995	54.950282999999999	54.949491999999999	улица Авиагородок	0103000020E61000000100000005000000512E8D5F7854524025E82FF488794B40512E8D5F78545240EE7893DFA2794B40FFAECF9CF5545240EE7893DFA2794B40FFAECF9CF554524025E82FF488794B40512E8D5F7854524025E82FF488794B40
4622	41	73.300855999999996	73.338891000000004	54.990606999999997	54.977634999999999	улица 70 Лет Октября	0103000020E610000001000000050000008B338639415352406536C824237D4B408B338639415352402618CE35CC7E4B40297AE063B05552402618CE35CC7E4B40297AE063B05552406536C824237D4B408B338639415352406536C824237D4B40
6022	41	73.450784999999996	73.451269999999994	54.954450000000001	54.950650000000003	улица 6-я Шинная	0103000020E61000000100000005000000C02154A9D95C5240A1F831E6AE794B40C02154A9D95C524067D5E76A2B7A4B409EEA909BE15C524067D5E76A2B7A4B409EEA909BE15C5240A1F831E6AE794B40C02154A9D95C5240A1F831E6AE794B40
5205	41	73.450596000000004	73.505285999999998	54.926828999999998	54.922001000000002	улица 6-я Станционная	0103000020E6100000010000000500000057ED9A90D65C52408DF0F62004764B4057ED9A90D65C524000FE2955A2764B401B48179B5660524000FE2955A2764B401B48179B566052408DF0F62004764B4057ED9A90D65C52408DF0F62004764B40
7228	41	73.386115000000004	73.398988000000003	55.005454	55.000982999999998	улица 6-я Ремесленная	0103000020E61000000100000005000000AF5FB01BB65852400D6D003620804B40AF5FB01BB6585240F2D077B7B2804B40C6DFF60489595240F2D077B7B2804B40C6DFF604895952400D6D003620804B40AF5FB01BB65852400D6D003620804B40
6259	41	73.239726000000005	73.291442000000004	55.039636000000002	55.031911999999998	улица 50 Лет Профсоюзов	0103000020E610000001000000050000000F80B8AB574F5240CB2C42B115844B400F80B8AB574F524044DFDDCA12854B4093AB58FCA652524044DFDDCA12854B4093AB58FCA6525240CB2C42B115844B400F80B8AB574F5240CB2C42B115844B40
5885	41	72.950593999999995	74.005251999999999	55.279057000000002	54.672435	улица 50 Лет ВЛКСМ	0103000020E6100000010000000500000086713788D63C5240C7D79E5912564B4086713788D63C5240255CC823B8A34B40450F7C0C56805240255CC823B8A34B40450F7C0C56805240C7D79E5912564B4086713788D63C5240C7D79E5912564B40
6182	41	73.419578000000001	73.423297000000005	54.948846000000003	54.947439000000003	улица 5-я Рабочая	0103000020E61000000100000005000000C007AF5DDA5A52403CFA5FAE45794B40C007AF5DDA5A5240607825C973794B40ADDF4C4C175B5240607825C973794B40ADDF4C4C175B52403CFA5FAE45794B40C007AF5DDA5A52403CFA5FAE45794B40
5997	41	73.441531999999995	73.475578999999996	54.961170000000003	54.954206999999997	улица 5-я Кордная	0103000020E61000000100000005000000CC086F0F425C5240A04E7974237A4B40CC086F0F425C5240BBF2599E077B4B4085EAE6E26F5E5240BBF2599E077B4B4085EAE6E26F5E5240A04E7974237A4B40CC086F0F425C5240A04E7974237A4B40
7202	41	73.351324000000005	73.391281000000006	55.003497000000003	54.998503999999997	улица 5 Армии	0103000020E610000001000000050000003293A8177C5652406C76A4FACE7F4B403293A8177C5652402B51F69672804B40F5A276BF0A5952402B51F69672804B40F5A276BF0A5952406C76A4FACE7F4B403293A8177C5652406C76A4FACE7F4B40
16470	41	73.499752000000001	73.501656999999994	55.031505000000003	55.028987000000001	улица 40 Лет Ракетных Войск	0103000020E610000001000000050000001407D0EFFB5F52402C8194D8B5834B401407D0EFFB5F52408B54185B08844B40CE33F6251B6052408B54185B08844B40CE33F6251B6052402C8194D8B5834B401407D0EFFB5F52402C8194D8B5834B40
6904	41	73.412938999999994	73.420637999999997	55.02749	55.007747000000002	улица 4-я Челюскинцев	0103000020E610000001000000050000008C0FB3976D5A524031D28BDAFD804B408C0FB3976D5A5240C87BD5CA84834B401C5DA5BBEB5A5240C87BD5CA84834B401C5DA5BBEB5A524031D28BDAFD804B408C0FB3976D5A524031D28BDAFD804B40
6194	41	73.403902000000002	73.437049999999999	54.953265999999999	54.949041999999999	улица 4-я Транспортная	0103000020E610000001000000050000007F32C687D9595240E54350357A794B407F32C687D9595240C231CB9E047A4B40E02D90A0F85B5240C231CB9E047A4B40E02D90A0F85B5240E54350357A794B407F32C687D9595240E54350357A794B40
6607	41	73.287515999999997	73.303201000000001	55.032960000000003	55.024935999999997	улица 4-я Поселковая	0103000020E61000000100000005000000E94482A9665252401C3F541A31834B40E94482A966525240C009850838844B4054C72AA567535240C009850838844B4054C72AA5675352401C3F541A31834B40E94482A9665252401C3F541A31834B40
5476	41	73.357962000000001	73.410595000000001	54.965454999999999	54.917862	улица 4-я Марьяновская	0103000020E610000001000000050000007DCD72D9E8565240DE1E84807C754B407DCD72D9E85652403D618907947B4B40AC394030475A52403D618907947B4B40AC394030475A5240DE1E84807C754B407DCD72D9E8565240DE1E84807C754B40
1834	41	73.373583999999994	73.377384000000006	55.032314999999997	55.032232	улица 35-я Северная	0103000020E61000000100000005000000C493DDCCE85752403DF19C2D20844B40C493DDCCE8575240CA15DEE522844B402882380F27585240CA15DEE522844B402882380F275852403DF19C2D20844B40C493DDCCE85752403DF19C2D20844B40
6909	41	73.373448999999994	73.412938999999994	55.030813000000002	55.02749	улица 33-я Северная	0103000020E61000000100000005000000546EA296E6575240C87BD5CA84834B40546EA296E657524055A52DAEF1834B408C0FB3976D5A524055A52DAEF1834B408C0FB3976D5A5240C87BD5CA84834B40546EA296E6575240C87BD5CA84834B40
2142	41	73.365212	73.403605999999996	55.028604999999999	55.027979999999999	улица 30-я Северная	0103000020E61000000100000005000000D50627A25F575240967840D994834B40D50627A25F57524044C02154A9834B400A9E42AED459524044C02154A9834B400A9E42AED4595240967840D994834B40D50627A25F575240967840D994834B40
6235	41	73.434821999999997	73.437257000000002	54.931800000000003	54.930869000000001	улица 30-я Рабочая	0103000020E610000001000000050000003465A71FD45B52401CEE23B726774B403465A71FD45B5240D734EF3845774B409DBCC804FC5B5240D734EF3845774B409DBCC804FC5B52401CEE23B726774B403465A71FD45B52401CEE23B726774B40
5749	41	73.402446999999995	73.434166000000005	54.958353000000002	54.956187	улица 3-я Транспортная	0103000020E61000000100000005000000E4D70FB1C159524020EEEA55647A4B40E4D70FB1C15952400283A44FAB7A4B4040C23060C95B52400283A44FAB7A4B4040C23060C95B524020EEEA55647A4B40E4D70FB1C159524020EEEA55647A4B40
5305	41	73.477474000000001	73.497658999999999	54.928913000000001	54.926988999999999	улица 3-я Станционная	0103000020E610000001000000050000002EAC1BEF8E5E524039605793A7764B402EAC1BEF8E5E524025EA059FE6764B40D86322A5D95F524025EA059FE6764B40D86322A5D95F524039605793A7764B402EAC1BEF8E5E524039605793A7764B40
4640	41	73.338217	73.361969000000002	54.990023000000001	54.970064999999998	улица 3-я Островская	0103000020E61000000100000005000000E17CEA58A555524043FF04172B7C4B40E17CEA58A5555240D7A4DB12B97E4B409D4A06802A575240D7A4DB12B97E4B409D4A06802A57524043FF04172B7C4B40E17CEA58A555524043FF04172B7C4B40
15641	41	73.484911999999994	73.488388999999998	54.929850000000002	54.916755000000002	улица 3-я Ленинградская	0103000020E61000000100000005000000075C57CC085F5240E5B8533A58754B40075C57CC085F5240C217265305774B4079AEEFC3415F5240C217265305774B4079AEEFC3415F5240E5B8533A58754B40075C57CC085F5240E5B8533A58754B40
6009	41	73.442745000000002	73.448404999999994	54.962710999999999	54.962085000000002	улица 3-я Кордная	0103000020E61000000100000005000000ECDD1FEF555C5240707CED99257B4B40ECDD1FEF555C5240EE3F321D3A7B4B403997E2AAB25C5240EE3F321D3A7B4B403997E2AAB25C5240707CED99257B4B40ECDD1FEF555C5240707CED99257B4B40
6925	41	73.359821999999994	73.408178000000007	55.026178999999999	55.023516000000001	улица 27-я Северная	0103000020E610000001000000050000006798DA52075752406477819202834B406798DA5207575240C66B5ED559834B40973C9E961F5A5240C66B5ED559834B40973C9E961F5A52406477819202834B406798DA52075752406477819202834B40
5384	41	73.369416000000001	73.372846999999993	54.942836999999997	54.935628000000001	улица 25 Лет Октября	0103000020E61000000100000005000000A0A70183A4575240679C86A8C2774B40A0A70183A4575240B83A00E2AE784B4059DAA9B9DC575240B83A00E2AE784B4059DAA9B9DC575240679C86A8C2774B40A0A70183A4575240679C86A8C2774B40
2558	41	73.346221	73.408043000000006	55.027979999999999	55.022660000000002	улица 24-я Северная	0103000020E610000001000000050000000F0C207C28565240B476DB85E6824B400F0C207C28565240967840D994834B40271763601D5A5240967840D994834B40271763601D5A5240B476DB85E6824B400F0C207C28565240B476DB85E6824B40
6934	41	73.408043000000006	73.430392999999995	55.059610999999997	55.023387	улица 21-я Амурская	0103000020E61000000100000005000000271763601D5A524066136058FE824B40271763601D5A5240ADBD4F55A1874B4059DB148F8B5B5240ADBD4F55A1874B4059DB148F8B5B524066136058FE824B40271763601D5A524066136058FE824B40
4382	41	73.320430999999999	73.332046000000005	54.945794999999997	54.939838000000002	улица 20 Лет Октября	0103000020E61000000100000005000000F96706F181545240DFC4909C4C784B40F96706F18154524033DC80CF0F794B4021B1DD3D4055524033DC80CF0F794B4021B1DD3D40555240DFC4909C4C784B40F96706F181545240DFC4909C4C784B40
4838	41	73.188252000000006	73.222989999999996	55.007787999999998	54.995807999999997	улица 2-я Солнечная	0103000020E6100000010000000500000006DA1D520C4C52402E8CF4A2767F4B4006DA1D520C4C52408FA67A32FF804B407155D977454E52408FA67A32FF804B407155D977454E52402E8CF4A2767F4B4006DA1D520C4C52402E8CF4A2767F4B40
7128	41	73.431129999999996	73.454351000000003	54.999630000000003	54.994743999999997	улица 2-я Производственная	0103000020E61000000100000005000000C49448A2975B524034F279C5537F4B40C49448A2975B5240DD0C37E0F37F4B40EA793716145D5240DD0C37E0F37F4B40EA793716145D524034F279C5537F4B40C49448A2975B524034F279C5537F4B40
6712	41	73.299293000000006	73.304045000000002	55.029032999999998	55.025126999999998	улица 2-я Поселковая	0103000020E61000000100000005000000FEBAD39D27535240909F8D5C37834B40FEBAD39D275352409CC0745AB7834B40CAE02879755352409CC0745AB7834B40CAE0287975535240909F8D5C37834B40FEBAD39D27535240909F8D5C37834B40
5256	41	73.480941999999999	73.482352000000006	54.929347999999997	54.923372999999998	улица 2-я Ленинградская	0103000020E610000001000000050000007651F4C0C75E52403481221631764B407651F4C0C75E52402F4D11E0F4764B40414AECDADE5E52402F4D11E0F4764B40414AECDADE5E52403481221631764B407651F4C0C75E52403481221631764B40
5506	41	73.358196000000007	73.380600000000001	54.905482999999997	54.905332000000001	улица 19-я Марьяновская	0103000020E61000000100000005000000B763EAAEEC565240DA0242EBE1734B40B763EAAEEC565240BF0AF0DDE6734B40E3361AC05B585240BF0AF0DDE6734B40E3361AC05B585240DA0242EBE1734B40B763EAAEEC565240DA0242EBE1734B40
3108	41	73.356551999999994	73.368814	55.018732	55.018473999999998	улица 18-я Северная	0103000020E61000000100000005000000B2D47ABFD1565240C4E9245B5D824B40B2D47ABFD1565240C0B167CF65824B40A51309A69A575240C0B167CF65824B40A51309A69A575240C4E9245B5D824B40B2D47ABFD1565240C4E9245B5D824B40
6196	41	73.421239999999997	73.433160000000001	54.941409999999998	54.937095999999997	улица 17-я Рабочая	0103000020E6100000010000000500000017F19D98F55A5240309B00C3F2774B4017F19D98F55A52404D10751F80784B40DD7BB8E4B85B52404D10751F80784B40DD7BB8E4B85B5240309B00C3F2774B4017F19D98F55A5240309B00C3F2774B40
5534	41	73.377724999999998	73.385514000000001	54.911315999999999	54.907625000000003	улица 13-я Комсомольская	0103000020E610000001000000050000006C787AA52C5852401904560E2D744B406C787AA52C5852402829B000A6744B409C89E942AC5852402829B000A6744B409C89E942AC5852401904560E2D744B406C787AA52C5852401904560E2D744B40
4424	41	73.317618999999993	73.350155999999998	54.957344999999997	54.935498000000003	улица 12 Декабря	0103000020E61000000100000005000000A565A4DE5354524099BC0166BE774B40A565A4DE535452409BFEEC478A7A4B40E21FB6F4685652409BFEEC478A7A4B40E21FB6F46856524099BC0166BE774B40A565A4DE5354524099BC0166BE774B40
5137	41	73.412633999999997	73.431471000000002	54.922063999999999	54.919212999999999	улица 10-я Чередовая	0103000020E61000000100000005000000EECD6F98685A52406E8786C5A8754B40EECD6F98685A5240D368723106764B40098B8A389D5B5240D368723106764B40098B8A389D5B52406E8786C5A8754B40EECD6F98685A52406E8786C5A8754B40
5461	41	73.352446999999998	73.379136000000003	54.933568999999999	54.921748000000001	улица 1-я Красной Звезды	0103000020E61000000100000005000000B1A4DC7D8E565240A393A5D6FB754B40B1A4DC7D8E5652409BC761307F774B401F2FA4C3435852409BC761307F774B401F2FA4C343585240A393A5D6FB754B40B1A4DC7D8E565240A393A5D6FB754B40
5481	41	73.365606999999997	73.368022999999994	54.917453000000002	54.905394999999999	улица 1-го Мая	0103000020E61000000100000005000000130CE71A66575240207BBDFBE3734B40130CE71A66575240FD4E93196F754B40404B57B08D575240FD4E93196F754B40404B57B08D575240207BBDFBE3734B40130CE71A66575240207BBDFBE3734B40
73539	41	73.389870000000002	73.393473	54.943441999999997	54.938462000000001	академика Павлова	0103000020E6100000010000000500000042EC4CA1F3585240F644D7851F784B4042EC4CA1F35852401FD61BB5C2784B40FAB660A92E5952401FD61BB5C2784B40FAB660A92E595240F644D7851F784B4042EC4CA1F3585240F644D7851F784B40
29960	41	73.305841999999998	73.311240999999995	54.887155	54.886896	Я.М.Сметнева	0103000020E6100000010000000500000091EF52EA92535240037AE1CE85714B4091EF52EA92535240CFBD874B8E714B40280B5F5FEB535240CFBD874B8E714B40280B5F5FEB535240037AE1CE85714B4091EF52EA92535240037AE1CE85714B40
73589	41	73.239726000000005	73.304899000000006	55.047466	55.035688999999998	Энтузиастов	0103000020E610000001000000050000000F80B8AB574F5240D9E9077591844B400F80B8AB574F524002D6AA5D13864B40526518778353524002D6AA5D13864B405265187783535240D9E9077591844B400F80B8AB574F5240D9E9077591844B40
71488	41	73.283006999999998	73.283069999999995	55.035859000000002	55.034641999999998	Школьный переулок	0103000020E61000000100000005000000806264C91C525240B58828266F844B40806264C91C5252403622180797844B40A31EA2D11D5252403622180797844B40A31EA2D11D525240B58828266F844B40806264C91C525240B58828266F844B40
73661	41	73.374032999999997	73.397981999999999	54.979897999999999	54.978265999999998	Чкалова	0103000020E61000000100000005000000FCA71B28F0575240F564FED1377D4B40FCA71B28F057524039B5334C6D7D4B4063997E897859524039B5334C6D7D4B4063997E8978595240F564FED1377D4B40FCA71B28F0575240F564FED1377D4B40
73646	41	73.397397999999995	73.431929999999994	54.950111999999997	54.930433999999998	Харьковская	0103000020E61000000100000005000000BB5F05F86E595240118B187618774B40BB5F05F86E595240C1C41F459D794B40520ABABDA45B5240C1C41F459D794B40520ABABDA45B5240118B187618774B40BB5F05F86E595240118B187618774B40
29545	41	73.408034000000001	73.449697999999998	55.020698000000003	55.01867	ХХII Партсъезда	0103000020E61000000100000005000000FD69A33A1D5A52404AB54FC763824B40FD69A33A1D5A5240DB8B683BA6824B40E7C41EDAC75C5240DB8B683BA6824B40E7C41EDAC75C52404AB54FC763824B40FD69A33A1D5A52404AB54FC763824B40
73594	41	73.315192999999994	73.317340000000002	55.028109000000001	55.017318000000003	Физкультурная	0103000020E6100000010000000500000066BB421F2C545240EAD0E97937824B4066BB421F2C54524094DC611399834B409C6D6E4C4F54524094DC611399834B409C6D6E4C4F545240EAD0E97937824B4066BB421F2C545240EAD0E97937824B40
4666	41	73.294514000000007	73.305841999999998	54.994145000000003	54.987321999999999	Туполева бульвар	0103000020E61000000100000005000000B58D3F51D9525240874F3A91607E4B40B58D3F51D9525240B03DB324407F4B4091EF52EA92535240B03DB324407F4B4091EF52EA92535240874F3A91607E4B40B58D3F51D9525240874F3A91607E4B40
73626	41	73.301072000000005	73.315562	54.918509	54.916015000000002	Талалихина	0103000020E61000000100000005000000726F7EC3445352409ED2C1FA3F754B40726F7EC344535240740AF2B391754B401077F52A32545240740AF2B391754B401077F52A325452409ED2C1FA3F754B40726F7EC3445352409ED2C1FA3F754B40
29565	41	73.096705	73.660702999999998	55.141351	54.824320999999998	Т.К. Щербанева	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
7406	41	73.381651000000005	73.382271000000003	54.961914999999998	54.956316000000001	Спортивный проезд	0103000020E6100000010000000500000016DF50F86C5852401E520C90687A4B4016DF50F86C5852401344DD07207B4B4064CDC820775852401344DD07207B4B4064CDC820775852401E520C90687A4B4016DF50F86C5852401E520C90687A4B40
5161	41	73.456345999999996	73.456740999999994	54.916967	54.909177999999997	Сибирский проспект	0103000020E61000000100000005000000446ADAC5345D5240101FD8F15F744B40446ADAC5345D52407041B62C5F754B40826F9A3E3B5D52407041B62C5F754B40826F9A3E3B5D5240101FD8F15F744B40446ADAC5345D5240101FD8F15F744B40
73655	41	73.313630000000003	73.314807000000002	55.026566000000003	55.022685000000003	Сибаковская	0103000020E61000000100000005000000D9429083125452400D8E9257E7824B40D942908312545240C097C28366834B40526342CC25545240C097C28366834B40526342CC255452400D8E9257E7824B40D9429083125452400D8E9257E7824B40
73650	41	73.303291000000002	73.326314999999994	55.042338999999998	55.039228000000001	Сергея Тюленина	0103000020E61000000100000005000000F48AA71E69535240338B506C05854B40F48AA71E69535240342C465D6B854B406E4C4F58E2545240342C465D6B854B406E4C4F58E2545240338B506C05854B40F48AA71E69535240338B506C05854B40
73680	41	73.412651999999994	73.435963000000001	54.950308999999997	54.931319000000002	Свободы	0103000020E610000001000000050000004128EFE3685A52405C92037635774B404128EFE3685A5240170CAEB9A3794B4007D15AD1E65B5240170CAEB9A3794B4007D15AD1E65B52405C92037635774B404128EFE3685A52405C92037635774B40
73608	41	73.359768000000003	73.36054	55.026803999999998	54.999763999999999	Сазонова	0103000020E610000001000000050000006E895C7006575240ECDB4944F87F4B406E895C700657524074B33F506E834B4097395D161357524074B33F506E834B4097395D1613575240ECDB4944F87F4B406E895C7006575240ECDB4944F87F4B40
29615	41	73.096705	73.660702999999998	55.141351	54.824320999999998	Российская	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
73625	41	73.274940000000001	73.282638000000006	54.994956000000002	54.989764999999998	Путилова	0103000020E610000001000000050000002F17F19D98515240DBDC989EB07E4B402F17F19D98515240C07ADCB75A7F4B40D7A6B1BD16525240C07ADCB75A7F4B40D7A6B1BD16525240DBDC989EB07E4B402F17F19D98515240DBDC989EB07E4B40
73671	41	73.403919999999999	73.416712000000004	54.936594999999997	54.936362000000003	Правды	0103000020E61000000100000005000000D28C45D3D9595240CC9BC3B5DA774B40D28C45D3D95952406E4C4F58E2774B4073F6CE68AB5A52406E4C4F58E2774B4073F6CE68AB5A5240CC9BC3B5DA774B40D28C45D3D9595240CC9BC3B5DA774B40
30106	41	73.521950000000004	73.526037000000002	54.942335	54.941052999999997	Полевая	0103000020E610000001000000050000006C09F9A067615240BE66B96C74784B406C09F9A0676152402670EB6E9E784B401ADF1797AA6152402670EB6E9E784B401ADF1797AA615240BE66B96C74784B406C09F9A067615240BE66B96C74784B40
5223	41	73.379531	73.387247000000002	54.956161000000002	54.955711999999998	Победы бульвар	0103000020E610000001000000050000005D34643C4A585240873254C5547A4B405D34643C4A585240F75AD07B637A4B40581EA4A7C8585240F75AD07B637A4B40581EA4A7C8585240873254C5547A4B405D34643C4A585240873254C5547A4B40
73579	41	73.456659999999999	73.469255000000004	54.980606000000002	54.972659	Петра Осминина	0103000020E610000001000000050000000C59DDEA395D52407D941117807C4B400C59DDEA395D52407521567F847D4B40029F1F46085E52407521567F847D4B40029F1F46085E52407D941117807C4B400C59DDEA395D52407D941117807C4B40
73620	41	73.364115999999996	73.365364	55.030147999999997	54.990721000000001	Орджоникидзе	0103000020E61000000100000005000000D2FC31AD4D575240EF3A1BF2CF7E4B40D2FC31AD4D5752401805C1E3DB834B40B0C8AF1F625752401805C1E3DB834B40B0C8AF1F62575240EF3A1BF2CF7E4B40D2FC31AD4D575240EF3A1BF2CF7E4B40
5285	41	73.483439000000004	73.488783999999995	54.915554	54.914602000000002	Омская Птицефабрика поселок	0103000020E610000001000000050000001AA721AAF05E5240986DA7AD11754B401AA721AAF05E52406ADC9BDF30754B40B7B3AF3C485F52406ADC9BDF30754B40B7B3AF3C485F5240986DA7AD11754B401AA721AAF05E5240986DA7AD11754B40
73660	41	73.386842999999999	73.447461000000004	54.994574	54.987152000000002	Омская	0103000020E61000000100000005000000F06B2409C25852402B172AFF5A7E4B40F06B2409C2585240D8B969334E7F4B40124F7633A35C5240D8B969334E7F4B40124F7633A35C52402B172AFF5A7E4B40F06B2409C25852402B172AFF5A7E4B40
73709	41	73.549627000000001	73.556192999999993	54.966236000000002	54.959314999999997	Ноябрьская	0103000020E61000000100000005000000E97FB9162D635240F7C77BD5CA7A4B40E97FB9162D635240E31B0A9FAD7B4B40E75086AA98635240E31B0A9FAD7B4B40E75086AA98635240F7C77BD5CA7A4B40E97FB9162D635240F7C77BD5CA7A4B40
76419	41	73.413469000000006	73.417224000000004	55.071947999999999	55.069850000000002	Новая	0103000020E610000001000000050000003B3AAE46765A524014D044D8F0884B403B3AAE46765A52409D81919735894B40CEC64ACCB35A52409D81919735894B40CEC64ACCB35A524014D044D8F0884B403B3AAE46765A524014D044D8F0884B40
73638	41	73.437571000000005	73.438423999999998	54.976075000000002	54.972467999999999	Николая Кузнецова	0103000020E6100000010000000500000065ABCB29015C52400934D8D4797C4B4065ABCB29015C5240BBB88D06F07C4B40047289230F5C5240BBB88D06F07C4B40047289230F5C52400934D8D4797C4B4065ABCB29015C52400934D8D4797C4B40
6255	41	73.190524999999994	73.365212	55.046005999999998	55.021327999999997	Мира проспект	0103000020E610000001000000050000008104C58F314C52409A3E3BE0BA824B408104C58F314C5240BBB54C86E3854B40D50627A25F575240BBB54C86E3854B40D50627A25F5752409A3E3BE0BA824B408104C58F314C52409A3E3BE0BA824B40
6622	41	73.304899000000006	73.335324999999997	55.046908999999999	55.040404000000002	Менделеева проспект	0103000020E610000001000000050000005265187783535240555051F52B854B405265187783535240AC71361D01864B40FF21FDF675555240AC71361D01864B40FF21FDF675555240555051F52B854B405265187783535240555051F52B854B40
30107	41	73.304360000000003	73.325918999999999	54.934257000000002	54.894171	Мельничная	0103000020E610000001000000050000007A8D5DA27A5352400C04013274724B407A8D5DA27A5352409087BEBB95774B4048895DDBDB5452409087BEBB95774B4048895DDBDB5452400C04013274724B407A8D5DA27A5352400C04013274724B40
73652	41	73.249571000000003	73.289743999999999	55.036802999999999	55.030833999999999	Магистральная	0103000020E61000000100000005000000ECC1A4F8F84F52406CCD565EF2834B40ECC1A4F8F84F524085B2F0F5B5844B40950D6B2A8B52524085B2F0F5B5844B40950D6B2A8B5252406CCD565EF2834B40ECC1A4F8F84F52406CCD565EF2834B40
73629	41	73.379054999999994	73.383833999999993	54.941420000000001	54.929895999999999	Лобкова	0103000020E61000000100000005000000A818E76F42585240325706D506774B40A818E76F4258524071E6577380784B40F1457BBC9058524071E6577380784B40F1457BBC90585240325706D506774B40A818E76F42585240325706D506774B40
4588	41	73.255671000000007	73.256371999999999	54.994191999999998	54.98912	Лесной проезд	0103000020E6100000010000000500000048E2E5E95C505240E6E8F17B9B7E4B4048E2E5E95C505240F0F8F6AE417F4B400CE71A6668505240F0F8F6AE417F4B400CE71A6668505240E6E8F17B9B7E4B4048E2E5E95C505240E6E8F17B9B7E4B40
73604	41	73.366073999999998	73.379441	54.989398000000001	54.970370000000003	Ленина	0103000020E610000001000000050000009E7AA4C16D57524080828B15357C4B409E7AA4C16D575240295DFA97A47E4B40BD70E7C248585240295DFA97A47E4B40BD70E7C24858524080828B15357C4B409E7AA4C16D57524080828B15357C4B40
73633	41	73.405573000000004	73.406822000000005	54.928825000000003	54.920847999999999	Крыловская	0103000020E6100000010000000500000000C974E8F4595240234BE658DE754B4000C974E8F4595240865AD3BCE3764B40C652245F095A5240865AD3BCE3764B40C652245F095A5240234BE658DE754B4000C974E8F4595240234BE658DE754B40
30092	41	73.381174999999999	73.438748000000004	54.981225999999999	54.977775000000001	Красных Зорь	0103000020E6100000010000000500000061C3D32B6558524057EC2FBB277D4B4061C3D32B6558524011FE45D0987D4B40DECB7D72145C524011FE45D0987D4B40DECB7D72145C524057EC2FBB277D4B4061C3D32B6558524057EC2FBB277D4B40
73595	41	73.303156000000001	73.364115999999996	55.022551	54.991072000000003	Красный Путь	0103000020E6100000010000000500000084656CE8665352409CFD8172DB7E4B4084656CE866535240FDBE7FF3E2824B40D2FC31AD4D575240FDBE7FF3E2824B40D2FC31AD4D5752409CFD8172DB7E4B4084656CE8665352409CFD8172DB7E4B40
29418	41	73.096705	73.660702999999998	55.141351	54.824320999999998	Красноярова	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
73636	41	73.451584999999994	73.474815000000007	55.036112000000003	55.034590000000001	Краснознаменная	0103000020E610000001000000050000004E97C5C4E65C52406362F3716D844B404E97C5C4E65C5240207F69519F844B409E29745E635E5240207F69519F844B409E29745E635E52406362F3716D844B404E97C5C4E65C52406362F3716D844B40
5837	41	73.435855000000004	73.481508000000005	54.985596999999999	54.898142	Космический проспект	0103000020E6100000010000000500000014B35E0CE55B5240FF942A51F6724B4014B35E0CE55B52409204E10A287E4B40CB30EE06D15E52409204E10A287E4B40CB30EE06D15E5240FF942A51F6724B4014B35E0CE55B5240FF942A51F6724B40
6448	41	73.293211999999997	73.349141000000003	55.041854000000001	55.026133000000002	Королева проспект	0103000020E61000000100000005000000DDB243FCC3525240562C7E5358834B40DDB243FCC3525240789ACC785B854B40562C7E5358565240789ACC785B854B40562C7E5358565240562C7E5358834B40DDB243FCC3525240562C7E5358834B40
73584	41	73.234470999999999	73.235197999999997	55.000905000000003	54.995519000000002	Комкова	0103000020E610000001000000050000001137A792014F5240F8C5A52A6D7F4B401137A792014F524092B3B0A71D804B406A85E97B0D4F524092B3B0A71D804B406A85E97B0D4F5240F8C5A52A6D7F4B401137A792014F5240F8C5A52A6D7F4B40
4537	41	73.277266999999995	73.302428000000006	54.998969000000002	54.986908999999997	Комарова проспект	0103000020E61000000100000005000000A45016BEBE5152406490BB08537E4B40A45016BEBE515240E25B5837DE7F4B404359F8FA5A535240E25B5837DE7F4B404359F8FA5A5352406490BB08537E4B40A45016BEBE5152406490BB08537E4B40
73623	41	73.297343999999995	73.302679999999995	54.947966999999998	54.942945999999999	Ключевая	0103000020E610000001000000050000005BEA20AF075352406FF25B74B2784B405BEA20AF07535240F7578FFB56794B40CF49EF1B5F535240F7578FFB56794B40CF49EF1B5F5352406FF25B74B2784B405BEA20AF075352406FF25B74B2784B40
7415	41	73.380187000000006	73.388191000000006	54.982785999999997	54.941420000000001	Карла Маркса проспект	0103000020E6100000010000000500000052D7DAFB5458524071E6577380784B4052D7DAFB54585240BB7B80EECB7D4B408066101FD8585240BB7B80EECB7D4B408066101FD858524071E6577380784B4052D7DAFB5458524071E6577380784B40
6046	41	73.451953000000003	73.457262	54.956870000000002	54.956156	Камерный переулок	0103000020E61000000100000005000000109546CCEC5C5240E5EFDE51637A4B40109546CCEC5C5240034356B77A7A4B4007EDD5C7435D5240034356B77A7A4B4007EDD5C7435D5240E5EFDE51637A4B40109546CCEC5C5240E5EFDE51637A4B40
7926	41	73.372164999999995	73.379630000000006	54.979449000000002	54.942836999999997	Иртышская набережная	0103000020E61000000100000005000000D0ED258DD1575240B83A00E2AE784B40D0ED258DD1575240CA8CB7955E7D4B4027A5A0DB4B585240CA8CB7955E7D4B4027A5A0DB4B585240B83A00E2AE784B40D0ED258DD1575240B83A00E2AE784B40
73632	41	73.401189000000002	73.423854000000006	54.965119000000001	54.963433999999999	Ипподромная	0103000020E61000000100000005000000F5A0A014AD5952405FED28CE517B4B40F5A0A014AD595240C6DFF604897B4B40D811876C205B5240C6DFF604897B4B40D811876C205B52405FED28CE517B4B40F5A0A014AD5952405FED28CE517B4B40
73659	41	73.426458999999994	73.431929999999994	54.989702999999999	54.989187000000001	Иванишко	0103000020E610000001000000050000006E85B01A4B5B52406E50FBAD9D7E4B406E85B01A4B5B524065E08096AE7E4B40520ABABDA45B524065E08096AE7E4B40520ABABDA45B52406E50FBAD9D7E4B406E85B01A4B5B52406E50FBAD9D7E4B40
4678	41	73.284794000000005	73.293373000000003	55.004897	54.998503999999997	Заречный бульвар	0103000020E6100000010000000500000036069D103A5252406C76A4FACE7F4B4036069D103A5252409C6C0377A0804B40E2218C9FC65252409C6C0377A0804B40E2218C9FC65252406C76A4FACE7F4B4036069D103A5252406C76A4FACE7F4B40
16466	41	73.511915000000002	73.517583999999999	55.065421999999998	55.063513999999998	Загородный микрорайон	0103000020E610000001000000050000003DD52137C3605240486B0C3A21884B403DD52137C36052402E3883BF5F884B40B43BA418206152402E3883BF5F884B40B43BA41820615240486B0C3A21884B403DD52137C3605240486B0C3A21884B40
73587	41	73.349698000000004	73.358196000000007	55.022660000000002	55.007747000000002	Долгирева	0103000020E61000000100000005000000815EB8736156524031D28BDAFD804B40815EB87361565240B476DB85E6824B40B763EAAEEC565240B476DB85E6824B40B763EAAEEC56524031D28BDAFD804B40815EB8736156524031D28BDAFD804B40
73542	41	73.299796000000001	73.321545	54.990690000000001	54.976762000000001	Дмитриева	0103000020E610000001000000050000002FDE8FDB2F535240DFFC8689067D4B402FDE8FDB2F535240B43C0FEECE7E4B404FCC7A3194545240B43C0FEECE7E4B404FCC7A3194545240DFFC8689067D4B402FDE8FDB2F535240DFFC8689067D4B40
73603	41	73.391414999999995	73.396195000000006	54.988391	54.965926000000003	Декабристов	0103000020E610000001000000050000007C0A80F10C595240952D9276A37B4B407C0A80F10C5952409354A698837E4B40AEF545425B5952409354A698837E4B40AEF545425B595240952D9276A37B4B407C0A80F10C595240952D9276A37B4B40
5321	41	73.506129999999999	73.507433000000006	54.935156999999997	54.931055000000001	Дальний поселок	0103000020E610000001000000050000009161156F646052407EE36BCF2C774B409161156F646052400FD07D39B3774B4051FA42C8796052400FD07D39B3774B4051FA42C8796052407EE36BCF2C774B409161156F646052407EE36BCF2C774B40
29721	41	73.096705	73.660702999999998	55.141351	54.824320999999998	Гуртьевской дивизии	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
73677	41	73.394397999999995	73.416415999999998	54.920060999999997	54.917085999999998	Гуртьева	0103000020E61000000100000005000000E6E61BD13D5952404ACFF41263754B40E6E61BD13D5952409BA9108FC4754B40FE614B8FA65A52409BA9108FC4754B40FE614B8FA65A52404ACFF41263754B40E6E61BD13D5952404ACFF41263754B40
5336	41	73.165183999999996	73.179807999999994	54.954951999999999	54.948183999999998	Входной микрорайон	0103000020E61000000100000005000000A374E95F924A5240944BE3175E794B40A374E95F924A5240F99FFCDD3B7A4B40C9E369F9814B5240F99FFCDD3B7A4B40C9E369F9814B5240944BE3175E794B40A374E95F924A5240944BE3175E794B40
29412	41	73.377339000000006	73.381759000000002	54.954915	54.943286999999998	Всеволода Иванова	0103000020E6100000010000000500000058207A5226585240F8DEDFA0BD784B4058207A5226585240DCBA9BA73A7A4B4009FD4CBD6E585240DCBA9BA73A7A4B4009FD4CBD6E585240F8DEDFA0BD784B4058207A5226585240F8DEDFA0BD784B40
73592	41	73.208895999999996	73.304637999999997	54.998410999999997	54.970587000000002	Волгоградская	0103000020E61000000100000005000000F910548D5E4D52401D76DF313C7C4B40F910548D5E4D5240BB7B80EECB7F4B409BC761307F535240BB7B80EECB7F4B409BC761307F5352401D76DF313C7C4B40F910548D5E4D52401D76DF313C7C4B40
73540	41	73.270169999999993	73.304297000000005	54.991804999999999	54.973843000000002	Ватутина	0103000020E610000001000000050000000F971C774A51524022382EE3A67C4B400F971C774A51524030815B77F37E4B4057D11F9A7953524030815B77F37E4B4057D11F9A7953524022382EE3A67C4B400F971C774A51524022382EE3A67C4B40
29361	41	73.096705	73.660702999999998	55.141351	54.824320999999998	В.Иванова	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
73654	41	73.289743999999999	73.303478999999996	55.036777999999998	55.032190999999997	Блюхера	0103000020E61000000100000005000000950D6B2A8B525240DE1CAED51E844B40950D6B2A8B5252402C9B3924B5844B4075012F336C5352402C9B3924B5844B4075012F336C535240DE1CAED51E844B40950D6B2A8B525240DE1CAED51E844B40
7575	41	73.448018000000005	73.453866000000005	54.998086000000001	54.989786000000002	Биофабрика поселок	0103000020E610000001000000050000003D81B053AC5C5240F304C24EB17E4B403D81B053AC5C5240384C3448C17F4B400CB1FA230C5D5240384C3448C17F4B400CB1FA230C5D5240F304C24EB17E4B403D81B053AC5C5240F304C24EB17E4B40
29359	41	73.096705	73.660702999999998	55.141351	54.824320999999998	75 Гвардейской бригады	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
73668	41	73.390320000000003	73.402168000000003	55.004742	54.999004999999997	7-я Ремесленная	0103000020E6100000010000000500000062BEBC00FB5852402EC55565DF7F4B4062BEBC00FB5852407575C7629B804B40DBDFD91EBD5952407575C7629B804B40DBDFD91EBD5952402EC55565DF7F4B4062BEBC00FB5852402EC55565DF7F4B40
73698	41	73.096705	73.660702999999998	55.141351	54.824320999999998	50 лет ВЛКСМ	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
7272	41	73.404486000000006	73.406435000000002	54.973052000000003	54.961703	5-я линия	0103000020E61000000100000005000000276C3F19E359524088BB7A15197B4B40276C3F19E359524059A7CAF78C7C4B40C93CF207035A524059A7CAF78C7C4B40C93CF207035A524088BB7A15197B4B40276C3F19E359524088BB7A15197B4B40
73644	41	73.441531999999995	73.475578999999996	54.961170000000003	54.954206999999997	5-я Кордная	0103000020E61000000100000005000000CC086F0F425C5240A04E7974237A4B40CC086F0F425C5240BBF2599E077B4B4085EAE6E26F5E5240BBF2599E077B4B4085EAE6E26F5E5240A04E7974237A4B40CC086F0F425C5240A04E7974237A4B40
73637	41	73.402446999999995	73.434166000000005	54.958353000000002	54.956187	3-я Транспортная	0103000020E61000000100000005000000E4D70FB1C159524020EEEA55647A4B40E4D70FB1C15952400283A44FAB7A4B4040C23060C95B52400283A44FAB7A4B4040C23060C95B524020EEEA55647A4B40E4D70FB1C159524020EEEA55647A4B40
73705	41	73.437049999999999	73.502115000000003	54.965744999999998	54.949978000000002	3-я Молодежная	0103000020E61000000100000005000000E02D90A0F85B5240B2F50CE198794B40E02D90A0F85B524044A33B889D7B4B4030F5F3A62260524044A33B889D7B4B4030F5F3A622605240B2F50CE198794B40E02D90A0F85B5240B2F50CE198794B40
73599	41	73.346221	73.408043000000006	55.027979999999999	55.022660000000002	24-я Северная	0103000020E610000001000000050000000F0C207C28565240B476DB85E6824B400F0C207C28565240967840D994834B40271763601D5A5240967840D994834B40271763601D5A5240B476DB85E6824B400F0C207C28565240B476DB85E6824B40
73647	41	73.426045999999999	73.438343000000003	54.938761999999997	54.934148	22-я Рабочая	0103000020E61000000100000005000000DD257156445B5240D9CF622992774B40DD257156445B5240205D6C5A29784B408E5BCCCF0D5C5240205D6C5A29784B408E5BCCCF0D5C5240D9CF622992774B40DD257156445B5240D9CF622992774B40
73630	41	73.096705	73.660702999999998	55.141351	54.824320999999998	22 Апреля	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
73657	41	73.408043000000006	73.428865999999999	55.059610999999997	55.023387	21-я Амурская	0103000020E61000000100000005000000271763601D5A524066136058FE824B40271763601D5A5240ADBD4F55A1874B407217618A725B5240ADBD4F55A1874B407217618A725B524066136058FE824B40271763601D5A524066136058FE824B40
30087	41	73.351072000000002	73.358879000000002	54.908143000000003	54.906962999999998	2-я Электровозная	0103000020E61000000100000005000000A5A2B1F6775652404DD7135D17744B40A5A2B1F677565240B18BA2073E744B40280EA0DFF7565240B18BA2073E744B40280EA0DFF75652404DD7135D17744B40A5A2B1F6775652404DD7135D17744B40
15859	41	73.386662999999999	73.404953000000006	54.957816000000001	54.947124000000002	16-й Военный городок	0103000020E61000000100000005000000B0E42A16BF585240DCA0F65B3B794B40B0E42A16BF585240F3CAF5B6997A4B40B2DAFCBFEA595240F3CAF5B6997A4B40B2DAFCBFEA595240DCA0F65B3B794B40B0E42A16BF585240DCA0F65B3B794B40
7320	41	73.414332000000002	73.417295999999993	54.995989000000002	54.976762000000001	14-я линия	0103000020E61000000100000005000000EC6B5D6A845A5240DFFC8689067D4B40EC6B5D6A845A52407F164B917C7F4B401A3048FAB45A52407F164B917C7F4B401A3048FAB45A5240DFFC8689067D4B40EC6B5D6A845A5240DFFC8689067D4B40
15771	41	73.399680000000004	73.412310000000005	54.845871000000002	54.842630999999997	14-й Военный городок	0103000020E6100000010000000500000061376C5B9459524042CC2555DB6B4B4061376C5B9459524042D13C80456C4B4015747B49635A524042D13C80456C4B4015747B49635A524042CC2555DB6B4B4061376C5B9459524042CC2555DB6B4B40
73658	41	73.096705	73.660702999999998	55.141351	54.824320999999998	10 Лет Октября	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
30118	41	73.46302	73.474374999999995	55.010271000000003	55.003816999999998	1-я Учхозная	0103000020E610000001000000050000003659A31EA25D52409C1551137D804B403659A31EA25D5240728C648F50814B408FC2F5285C5E5240728C648F50814B408FC2F5285C5E52409C1551137D804B403659A31EA25D52409C1551137D804B40
73612	41	73.354719000000003	73.373755000000003	55.00421	55.003672999999999	1-я Северная	0103000020E61000000100000005000000451152B7B356524069705B5B78804B40451152B7B356524078280AF489804B40DB6D179AEB57524078280AF489804B40DB6D179AEB57524069705B5B78804B40451152B7B356524069705B5B78804B40
76470	41	73.521491999999995	73.525740999999996	54.942588999999998	54.942289000000002	1-я Полевая	0103000020E610000001000000050000000A48FB1F60615240B6300BED9C784B400A48FB1F60615240E048A0C1A6784B40A54A94BDA5615240E048A0C1A6784B40A54A94BDA5615240B6300BED9C784B400A48FB1F60615240B6300BED9C784B40
29487	41	73.096705	73.660702999999998	55.141351	54.824320999999998	1-я Осенняя	0103000020E6100000010000000500000005172B6A30465240F833BC5983694B4005172B6A30465240E22021CA17924B409F573CF5486A5240E22021CA17924B409F573CF5486A5240F833BC5983694B4005172B6A30465240F833BC5983694B40
6884	41	73.404889999999995	73.410270999999995	55.009425	55.007565999999997	1-й Челюскинцев проезд	0103000020E610000001000000050000008E1EBFB7E9595240E04735ECF7804B408E1EBFB7E9595240E561A1D634814B40D2DF4BE1415A5240E561A1D634814B40D2DF4BE1415A5240E04735ECF7804B408E1EBFB7E9595240E04735ECF7804B40
29095	13096	73.524338999999998	73.553084999999996	55.026014000000004	55.011319	Интернациональная	0103000020E610000001000000050000001C412AC58E6152406669A7E672814B401C412AC58E6152407C9E3F6D54834B401FBAA0BE656352407C9E3F6D54834B401FBAA0BE656352406669A7E672814B401C412AC58E6152406669A7E672814B40
29184	48683	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	Зеленая	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
1990	7329	73.217690000000005	73.249966999999998	54.928572000000003	54.926208000000003	улица Молодежная	0103000020E61000000100000005000000A4AA09A2EE4D524094A5D6FB8D764B40A4AA09A2EE4D52409CFD8172DB764B4012859675FF4F52409CFD8172DB764B4012859675FF4F524094A5D6FB8D764B40A4AA09A2EE4D524094A5D6FB8D764B40
29343	46330	72.568890999999994	72.578287000000003	54.401437999999999	54.387751999999999	Центральная	0103000020E6100000010000000500000047FFCBB568245240B37A87DBA1314B4047FFCBB56824524092AF045262334B40ED2C7AA70225524092AF045262334B40ED2C7AA702255240B37A87DBA1314B4047FFCBB568245240B37A87DBA1314B40
29873	32275	72.360590000000002	72.425421	54.641596999999997	54.616706000000001	площадь Гуртьева	0103000020E61000000100000005000000F05014E8131752409D9FE238F04E4B40F05014E813175240191BBAD91F524B40068200193A1B5240191BBAD91F524B40068200193A1B52409D9FE238F04E4B40F05014E8131752409D9FE238F04E4B40
29079	32275	72.360590000000002	72.425421	54.641596999999997	54.616706000000001	Чапаева	0103000020E61000000100000005000000F05014E8131752409D9FE238F04E4B40F05014E813175240191BBAD91F524B40068200193A1B5240191BBAD91F524B40068200193A1B52409D9FE238F04E4B40F05014E8131752409D9FE238F04E4B40
29609	32275	72.360590000000002	72.425421	54.641596999999997	54.616706000000001	Гуртьева	0103000020E61000000100000005000000F05014E8131752409D9FE238F04E4B40F05014E813175240191BBAD91F524B40068200193A1B5240191BBAD91F524B40068200193A1B52409D9FE238F04E4B40F05014E8131752409D9FE238F04E4B40
76465	60850	72.378941999999995	72.388347999999993	54.380583999999999	54.374468999999998	Джамбула	0103000020E610000001000000050000002C45F29540185240D32EA699EE2F4B402C45F29540185240C0B0FCF9B6304B40E3DD91B1DA185240C0B0FCF9B6304B40E3DD91B1DA185240D32EA699EE2F4B402C45F29540185240D32EA699EE2F4B40
76466	60851	72.568540999999996	72.580281999999997	54.332329000000001	54.323965000000001	Школьная	0103000020E61000000100000005000000D95BCAF9622452403A0664AF77294B40D95BCAF9622452409641B5C1892A4B40471D1D57232552409641B5C1892A4B40471D1D57232552403A0664AF77294B40D95BCAF9622452403A0664AF77294B40
29895	46150	72.545812999999995	72.558622999999997	54.647264999999997	54.637022000000002	Советская	0103000020E61000000100000005000000D32EA699EE225240906AD8EF89514B40D32EA699EE225240376C5B94D9524B40C7F2AE7AC0235240376C5B94D9524B40C7F2AE7AC0235240906AD8EF89514B40D32EA699EE225240906AD8EF89514B40
29759	973	72.665899999999993	72.678377999999995	54.596525	54.588616999999999	Фермерская	0103000020E61000000100000005000000029A081B9E2A5240506F46CD574B4B40029A081B9E2A52408A1F63EE5A4C4B40DB148F8B6A2B52408A1F63EE5A4C4B40DB148F8B6A2B5240506F46CD574B4B40029A081B9E2A5240506F46CD574B4B40
29340	1018	72.272869	72.299961999999994	54.451439000000001	54.440292999999997	Северная	0103000020E61000000100000005000000E7C589AF7611524030D461855B384B40E7C589AF76115240C991CEC0C8394B40BC02D19332135240C991CEC0C8394B40BC02D1933213524030D461855B384B40E7C589AF7611524030D461855B384B40
29208	46402	72.563159999999996	72.576634999999996	54.301143000000003	54.289861000000002	Центральная	0103000020E61000000100000005000000959A3DD00A24524064B14D2A1A254B40959A3DD00A245240AD3594DA8B264B40A7AE7C96E7245240AD3594DA8B264B40A7AE7C96E724524064B14D2A1A254B40959A3DD00A24524064B14D2A1A254B40
29626	46261	72.115853000000001	72.138795999999999	54.479827	54.469138000000001	Зеленая	0103000020E610000001000000050000002F89B3226A075240CAA7C7B60C3C4B402F89B3226A075240705E9CF86A3D4B4033349E08E2085240705E9CF86A3D4B4033349E08E2085240CAA7C7B60C3C4B402F89B3226A075240CAA7C7B60C3C4B40
29329	45866	72.081474	72.114459999999994	54.561359000000003	54.550144000000003	Центральная	0103000020E610000001000000050000005B5EB9DE360552409A0B5C1E6B464B405B5EB9DE360552405B28999CDA474B40CF2C0950530752405B28999CDA474B40CF2C0950530752409A0B5C1E6B464B405B5EB9DE360552409A0B5C1E6B464B40
29886	46039	72.272105999999994	72.298292000000004	54.342114000000002	54.330790999999998	Центральная	0103000020E61000000100000005000000E7C2482F6A115240D367075C572A4B40E7C2482F6A1152407BC03C64CA2B4B40242A5437171352407BC03C64CA2B4B40242A543717135240D367075C572A4B40E7C2482F6A115240D367075C572A4B40
29427	52999	72.160004999999998	72.193879999999993	54.532969999999999	54.514149000000003	Ленина	0103000020E61000000100000005000000938C9C853D0A5240B4226AA2CF414B40938C9C853D0A5240E3DF675C38444B404DD6A887680C5240E3DF675C38444B404DD6A887680C5240B4226AA2CF414B40938C9C853D0A5240B4226AA2CF414B40
29880	45928	72.508695000000003	72.534530000000004	54.475914000000003	54.458955000000003	Молодежная	0103000020E61000000100000005000000E12879758E205240F8AA9509BF3A4B40E12879758E205240B2DAFCBFEA3C4B40C72E51BD35225240B2DAFCBFEA3C4B40C72E51BD35225240F8AA9509BF3A4B40E12879758E205240F8AA9509BF3A4B40
76543	30437	72.490046000000007	72.506457999999995	54.378607000000002	54.371983	Школьная	0103000020E6100000010000000500000048E2E5E95C1F524080D591239D2F4B4048E2E5E95C1F5240B284B53176304B400BB3D0CE69205240B284B53176304B400BB3D0CE6920524080D591239D2F4B4048E2E5E95C1F524080D591239D2F4B40
28675	28239	72.416410999999997	72.431134	54.310924999999997	54.305135999999997	30 лет Целины	0103000020E6100000010000000500000075AC527AA61A5240876A4AB20E274B4075AC527AA61A52402041F163CC274B40658C0FB3971B52402041F163CC274B40658C0FB3971B5240876A4AB20E274B4075AC527AA61A5240876A4AB20E274B40
29504	46234	72.171601999999993	72.179210999999995	54.444904999999999	54.427604000000002	Победы	0103000020E61000000100000005000000677BF486FB0A5240C4D155BABB364B40677BF486FB0A5240D769A4A5F2384B4057056A31780B5240D769A4A5F2384B4057056A31780B5240C4D155BABB364B40677BF486FB0A5240C4D155BABB364B40
30062	53094	72.655938000000006	72.686822000000006	54.393906000000001	54.376393999999998	Ленина	0103000020E61000000100000005000000098D60E3FA2952408F34B8AD2D304B40098D60E3FA2952405ED905836B324B40180B43E4F42B52405ED905836B324B40180B43E4F42B52408F34B8AD2D304B40098D60E3FA2952408F34B8AD2D304B40
76418	60823	72.708884999999995	72.736112000000006	54.510035000000002	54.499982000000003	Центральная	0103000020E61000000100000005000000FFE7305F5E2D52405A4B0169FF3F4B40FFE7305F5E2D52405E68AED348414B405D8C81751C2F52405E68AED348414B405D8C81751C2F52405A4B0169FF3F4B40FFE7305F5E2D52405A4B0169FF3F4B40
29210	1451	72.573274999999995	72.592005	54.367147000000003	54.361088000000002	Школьная	0103000020E610000001000000050000005227A089B0245240317DAF21382E4B405227A089B02452408AE942ACFE2E4B406284F068E32552408AE942ACFE2E4B406284F068E3255240317DAF21382E4B405227A089B0245240317DAF21382E4B40
74003	60189	72.682699	72.694277999999997	54.412542999999999	54.405678000000002	Центральная	0103000020E61000000100000005000000C3802557B12B5240755AB741ED334B40C3802557B12B5240CC988235CE344B404415FE0C6F2C5240CC988235CE344B404415FE0C6F2C5240755AB741ED334B40C3802557B12B5240755AB741ED334B40
30113	53109	72.710942000000003	72.719188000000003	54.725513999999997	54.714458	Мира	0103000020E6100000010000000500000095D6DF12802D5240CB2E185C735B4B4095D6DF12802D524023658BA4DD5C4B403EEB1A2D072E524023658BA4DD5C4B403EEB1A2D072E5240CB2E185C735B4B4095D6DF12802D5240CB2E185C735B4B40
29828	28789	72.619016999999999	72.672978999999998	54.681247999999997	54.668467999999997	Школьная	0103000020E61000000100000005000000C1AA7AF99D2752401536035C90554B40C1AA7AF99D275240923B6C2233574B4044F98216122B5240923B6C2233574B4044F98216122B52401536035C90554B40C1AA7AF99D2752401536035C90554B40
29877	45912	72.068808000000004	72.084241000000006	54.504353000000002	54.494109999999999	Школьная	0103000020E61000000100000005000000016DAB5967045240335019FF3E3F4B40016DAB5967045240DB519CA38E404B40DFFE5C3464055240DB519CA38E404B40DFFE5C3464055240335019FF3E3F4B40016DAB5967045240335019FF3E3F4B40
29584	45974	72.434656000000004	72.473876000000004	54.354913000000003	54.337184999999998	Школьная	0103000020E61000000100000005000000A7406667D11B5240D3D9C9E0282B4B40A7406667D11B52406FF607CA6D2D4B40FF9600FC531E52406FF607CA6D2D4B40FF9600FC531E5240D3D9C9E0282B4B40A7406667D11B5240D3D9C9E0282B4B40
29494	45947	72.434242999999995	72.457571999999999	54.500782000000001	54.493352000000002	Центральная	0103000020E6100000010000000500000015E126A3CA1B524046B58828263F4B4015E126A3CA1B52407636E49F19404B402EE411DC481D52407636E49F19404B402EE411DC481D524046B58828263F4B4015E126A3CA1B524046B58828263F4B40
29097	47257	72.511640999999997	72.521585999999999	54.775084999999997	54.766012000000003	Школьная	0103000020E61000000100000005000000BC92E4B9BE205240FA2B64AE0C624B40BC92E4B9BE205240614F3BFC35634B404B033FAA61215240614F3BFC35634B404B033FAA61215240FA2B64AE0C624B40BC92E4B9BE205240FA2B64AE0C624B40
29614	45821	72.230451000000002	72.245604999999998	54.595283000000002	54.582298000000002	Мира	0103000020E6100000010000000500000027158DB5BF0E52405B43A9BD884A4B4027158DB5BF0E5240B16EBC3B324C4B40FBAE08FEB70F5240B16EBC3B324C4B40FBAE08FEB70F52405B43A9BD884A4B4027158DB5BF0E52405B43A9BD884A4B40
29084	46108	72.57199	72.602919	54.633020000000002	54.615746000000001	Советская	0103000020E61000000100000005000000E6E8F17B9B2452404852D2C3D04E4B40E6E8F17B9B24524062DBA2CC06514B40C5C892399626524062DBA2CC06514B40C5C89239962652404852D2C3D04E4B40E6E8F17B9B2452404852D2C3D04E4B40
30127	53114	72.813547	72.827157	54.729813	54.721708	Пролетарская	0103000020E6100000010000000500000092B06F27113452407BA180ED605C4B4092B06F27113452400B992B836A5D4B4014EAE923F03452400B992B836A5D4B4014EAE923F03452407BA180ED605C4B4092B06F27113452407BA180ED605C4B40
76459	60846	72.242739999999998	72.260383000000004	54.657010999999997	54.645550999999998	Лесная	0103000020E61000000100000005000000965B5A0D890F52403673486AA1524B40965B5A0D890F52405E0EBBEF18544B40CD5B751DAA1052405E0EBBEF18544B40CD5B751DAA1052403673486AA1524B40965B5A0D890F52403673486AA1524B40
29193	32397	72.192083999999994	72.222159000000005	54.641404000000001	54.628788	Победы	0103000020E610000001000000050000006E85B01A4B0C5240020F0C207C504B406E85B01A4B0C524005C3B98619524B40C6E061DA370E524005C3B98619524B40C6E061DA370E5240020F0C207C504B406E85B01A4B0C5240020F0C207C504B40
29493	46053	72.694646000000006	72.727884000000003	54.670794999999998	54.654609999999998	Ленина	0103000020E6100000010000000500000006137F14752C524039D1AE42CA534B4006137F14752C524000A94D9CDC554B4007D2C5A6952E524000A94D9CDC554B4007D2C5A6952E524039D1AE42CA534B4006137F14752C524039D1AE42CA534B40
76343	60807	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	Центральная	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
30102	52986	74.772610999999998	74.826959000000002	54.167523000000003	54.138078999999998	Транспортная	0103000020E61000000100000005000000E961687572B15240D7A19A92AC114B40E961687572B15240F629C76471154B40810871E5ECB45240F629C76471154B40810871E5ECB45240D7A19A92AC114B40E961687572B15240D7A19A92AC114B40
30144	52986	74.772610999999998	74.826959000000002	54.167523000000003	54.138078999999998	Красноармейская	0103000020E61000000100000005000000E961687572B15240D7A19A92AC114B40E961687572B15240F629C76471154B40810871E5ECB45240F629C76471154B40810871E5ECB45240D7A19A92AC114B40E961687572B15240D7A19A92AC114B40
30117	52986	74.772610999999998	74.826959000000002	54.167523000000003	54.138078999999998	Зеленая	0103000020E61000000100000005000000E961687572B15240D7A19A92AC114B40E961687572B15240F629C76471154B40810871E5ECB45240F629C76471154B40810871E5ECB45240D7A19A92AC114B40E961687572B15240D7A19A92AC114B40
30121	52986	74.772610999999998	74.826959000000002	54.167523000000003	54.138078999999998	Береговая	0103000020E61000000100000005000000E961687572B15240D7A19A92AC114B40E961687572B15240F629C76471154B40810871E5ECB45240F629C76471154B40810871E5ECB45240D7A19A92AC114B40E961687572B15240D7A19A92AC114B40
30151	52986	74.772610999999998	74.826959000000002	54.167523000000003	54.138078999999998	4 Восточная	0103000020E61000000100000005000000E961687572B15240D7A19A92AC114B40E961687572B15240F629C76471154B40810871E5ECB45240F629C76471154B40810871E5ECB45240D7A19A92AC114B40E961687572B15240D7A19A92AC114B40
29325	52986	74.772610999999998	74.826959000000002	54.167523000000003	54.138078999999998	20 Лет Победы	0103000020E61000000100000005000000E961687572B15240D7A19A92AC114B40E961687572B15240F629C76471154B40810871E5ECB45240F629C76471154B40810871E5ECB45240D7A19A92AC114B40E961687572B15240D7A19A92AC114B40
30003	30998	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	Школьная	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
30155	53126	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	Привокзальная	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
29830	31762	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	Центральная	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
29465	31197	75.332054999999997	75.341721000000007	54.407862999999999	54.397036	Школьная 	0103000020E610000001000000050000004A5E9D6340D55240D6AA5D13D2324B404A5E9D6340D55240CD1FD3DA34344B40D0D6C1C1DED55240CD1FD3DA34344B40D0D6C1C1DED55240D6AA5D13D2324B404A5E9D6340D55240D6AA5D13D2324B40
29251	31584	74.583703999999997	74.623895000000005	54.386539999999997	54.361603000000002	Октябрьская	0103000020E61000000100000005000000D7A205685BA552405891D101492E4B40D7A205685BA55240444C89247A314B40D4484BE5EDA75240444C89247A314B40D4484BE5EDA752405891D101492E4B40D7A205685BA552405891D101492E4B40
29432	31747	74.754681000000005	74.772979000000007	54.510829999999999	54.499761999999997	Центральная	0103000020E61000000100000005000000687A89B14CB052404BE48233F83F4B40687A89B14CB0524068E89FE062414B40AB5FE97C78B1524068E89FE062414B40AB5FE97C78B152404BE48233F83F4B40687A89B14CB052404BE48233F83F4B40
29062	30565	74.795706999999993	74.812415999999999	54.253757	54.244204000000003	Транспортная	0103000020E61000000100000005000000B08C0DDDECB25240B5C6A013421F4B40B08C0DDDECB25240C710001C7B204B40D1AFAD9FFEB35240C710001C7B204B40D1AFAD9FFEB35240B5C6A013421F4B40B08C0DDDECB25240B5C6A013421F4B40
29645	52437	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	Школьная	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
28686	31684	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	Зеленая	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
29570	31437	75.095843000000002	75.108321000000004	54.320405000000001	54.307367999999997	1 Переулок	0103000020E610000001000000050000003CA3AD4A22C6524020EBA9D557274B403CA3AD4A22C65240C93CF20703294B40151E34BBEEC65240C93CF20703294B40151E34BBEEC6524020EBA9D557274B403CA3AD4A22C6524020EBA9D557274B40
29982	31364	75.284632999999999	75.298584000000005	54.106872000000003	54.100653999999999	Восточная	0103000020E610000001000000050000003197546D37D25240151BF33AE20C4B403197546D37D25240D76D50FBAD0D4B40F8C610001CD35240D76D50FBAD0D4B40F8C610001CD35240151BF33AE20C4B403197546D37D25240151BF33AE20C4B40
29736	30446	75.251897999999997	75.258869000000004	54.071109	54.062950999999998	Лесная	0103000020E6100000010000000500000061FBC9181FD05240102043C70E084B4061FBC9181FD05240C3B986191A094B40B03C484F91D05240C3B986191A094B40B03C484F91D05240102043C70E084B4061FBC9181FD05240102043C70E084B40
29754	31985	75.048951000000002	75.061059999999998	53.888499000000003	53.879593999999997	Центральная	0103000020E61000000100000005000000D106600322C3524000E1438996F04A40D106600322C35240ADC3D155BAF14A4000C63368E8C35240ADC3D155BAF14A4000C63368E8C3524000E1438996F04A40D106600322C3524000E1438996F04A40
29149	31413	75.005257	75.030103999999994	54.267240999999999	54.253630999999999	Мельникова	0103000020E61000000100000005000000CEC4742156C052403A2009FB76204B40CEC4742156C052403E93FDF334224B40A4DE5339EDC152403E93FDF334224B40A4DE5339EDC152403A2009FB76204B40CEC4742156C052403A2009FB76204B40
74076	60230	75.115264999999994	75.132493999999994	53.911338000000001	53.897832999999999	еленая	0103000020E61000000100000005000000E657738060C7524081221631ECF24A40E657738060C7524010CD3CB9A6F44A40A33A1DC87AC8524010CD3CB9A6F44A40A33A1DC87AC8524081221631ECF24A40E657738060C7524081221631ECF24A40
73979	60181	75.066890000000001	75.083445999999995	53.926774999999999	53.911518999999998	Центральная	0103000020E610000001000000050000007C9BFEEC47C45240605793A7ACF44A407C9BFEEC47C452400DE02D90A0F64A40D93EE42D57C552400DE02D90A0F64A40D93EE42D57C55240605793A7ACF44A407C9BFEEC47C45240605793A7ACF44A40
30014	31257	75.531418000000002	75.551845999999998	54.190688000000002	54.178353999999999	Школьная,	0103000020E610000001000000050000005EA0A4C002E252402E8ECA4DD4164B405EA0A4C002E25240ADDEE17668184B406B9BE27151E35240ADDEE17668184B406B9BE27151E352402E8ECA4DD4164B405EA0A4C002E252402E8ECA4DD4164B40
29523	26047	74.929312999999993	74.945922999999993	53.998150000000003	53.988621999999999	Школьная	0103000020E61000000100000005000000D9AF3BDD79BB5240950D6B2A8BFE4A40D9AF3BDD79BB52404F401361C3FF4A4030629F008ABC52404F401361C3FF4A4030629F008ABC5240950D6B2A8BFE4A40D9AF3BDD79BB5240950D6B2A8BFE4A40
30030	32183	74.926186999999999	74.943201000000002	54.446544000000003	54.440890000000003	Советская	0103000020E61000000100000005000000BEBED6A546BB5240159161156F384B40BEBED6A546BB5240CE1C925A28394B407D23BA675DBC5240CE1C925A28394B407D23BA675DBC5240159161156F384B40BEBED6A546BB5240159161156F384B40
29458	31080	74.956721000000002	74.973204999999993	54.147689	54.140796000000002	Российская	0103000020E610000001000000050000005F99B7EA3ABD52402DB4739A05124B405F99B7EA3ABD52404E7D2079E7124B406FD39FFD48BE52404E7D2079E7124B406FD39FFD48BE52402DB4739A05124B405F99B7EA3ABD52402DB4739A05124B40
29472	32055	75.308672000000001	75.335361000000006	53.980172000000003	53.96895	Молодежная	0103000020E61000000100000005000000384C3448C1D35240C7BAB88D06FC4A40384C3448C1D352403B3AAE4676FD4A40A6D6FB8D76D552403B3AAE4676FD4A40A6D6FB8D76D55240C7BAB88D06FC4A40384C3448C1D35240C7BAB88D06FC4A40
29049	30853	74.480542	74.497179000000003	54.467930000000003	54.464021000000002	Октябрьская	0103000020E61000000100000005000000AF963B33C19E524020D4450A653B4B40AF963B33C19E52409D685721E53B4B408350DEC7D19F52409D685721E53B4B408350DEC7D19F524020D4450A653B4B40AF963B33C19E524020D4450A653B4B40
29301	30946	74.997639000000007	75.030455000000003	54.139519	54.128388000000001	Победы	0103000020E61000000100000005000000B58D3F51D9BF524074999A046F104B40B58D3F51D9BF5240D71533C2DB114B40FB3F87F9F2C15240D71533C2DB114B40FB3F87F9F2C1524074999A046F104B40B58D3F51D9BF524074999A046F104B40
29453	30902	74.446882000000002	74.463115000000002	54.584958999999998	54.572921000000001	Школьная	0103000020E61000000100000005000000F3CAF5B6999C52408718AF7955494B40F3CAF5B6999C52401C40BFEFDF4A4B405FD218ADA39D52401C40BFEFDF4A4B405FD218ADA39D52408718AF7955494B40F3CAF5B6999C52408718AF7955494B40
29981	31277	75.408088000000006	75.414664000000002	54.143338	54.134329000000001	Школьная	0103000020E61000000100000005000000F778211D1EDA5240C3F352B131114B40F778211D1EDA524014234BE658124B4007B5DFDA89DA524014234BE658124B4007B5DFDA89DA5240C3F352B131114B40F778211D1EDA5240C3F352B131114B40
29173	30714	74.349818999999997	74.394994999999994	54.504452000000001	54.478330999999997	Ленина	0103000020E610000001000000050000003E213B6F63965240DCD440F3393D4B403E213B6F639652406E3315E291404B4058C51B99479952406E3315E291404B4058C51B9947995240DCD440F3393D4B403E213B6F63965240DCD440F3393D4B40
28693	32219	74.788763000000003	74.799066999999994	54.438454999999998	54.424964000000003	Кооперативная	0103000020E61000000100000005000000DF52CE177BB252401AFD683865364B40DF52CE177BB2524043E21E4B1F384B400514EAE923B3524043E21E4B1F384B400514EAE923B352401AFD683865364B40DF52CE177BB252401AFD683865364B40
73725	60069	74.667167000000006	74.692409999999995	54.266137000000001	54.24897	Центральная	0103000020E610000001000000050000001C7E37DDB2AA5240B2D7BB3FDE1F4B401C7E37DDB2AA5240B6A0F7C610224B40185B087250AC5240B6A0F7C610224B40185B087250AC5240B2D7BB3FDE1F4B401C7E37DDB2AA5240B2D7BB3FDE1F4B40
30009	31159	75.565464000000006	75.580071000000004	54.383819000000003	54.374364999999997	Почтовая	0103000020E610000001000000050000002FC4EA8F30E452402EE23B31EB2F4B402FC4EA8F30E45240AE4A22FB20314B40EA961DE21FE55240AE4A22FB20314B40EA961DE21FE552402EE23B31EB2F4B402FC4EA8F30E452402EE23B31EB2F4B40
29069	30654	74.645949000000002	74.655182999999994	54.322195000000001	54.303933000000001	Школьная	0103000020E610000001000000050000009278793A57A952406C96CB46E7264B409278793A57A95240A5F78DAF3D294B404A79AD84EEA95240A5F78DAF3D294B404A79AD84EEA952406C96CB46E7264B409278793A57A952406C96CB46E7264B40
29729	30804	74.272321000000005	74.294248999999994	54.547418	54.536110000000001	Мира	0103000020E61000000100000005000000E6400FB56D9152407F87A2409F444B40E6400FB56D915240F19E03CB11464B405DF8C1F9D4925240F19E03CB11464B405DF8C1F9D49252407F87A2409F444B40E6400FB56D9152407F87A2409F444B40
29944	50013	74.997782999999998	75.008804999999995	54.447485999999998	54.438077999999997	Советская 	0103000020E610000001000000050000004E603AADDBBF52406D8C9DF012384B404E603AADDBBF52407CB5A33847394B40A4C2D84290C052407CB5A33847394B40A4C2D84290C052406D8C9DF012384B404E603AADDBBF52406D8C9DF012384B40
29045	30739	74.417642000000001	74.440190000000001	54.423910999999997	54.410462000000003	Октябрьская	0103000020E61000000100000005000000E8DB82A5BA9A52401920D1048A344B40E8DB82A5BA9A524013B534B742364B40AE81AD122C9C524013B534B742364B40AE81AD122C9C52401920D1048A344B40E8DB82A5BA9A52401920D1048A344B40
29313	36928	129.37662499999999	129.42210700000001	61.666846	61.650632999999999	Зеленая	0103000020E61000000100000005000000643BDF4F0D2C6040645930F147D34E40643BDF4F0D2C6040F5BBB0355BD54E40350D8AE6812D6040F5BBB0355BD54E40350D8AE6812D6040645930F147D34E40643BDF4F0D2C6040645930F147D34E40
30094	53101	71.450425999999993	71.468103999999997	57.656844999999997	57.647010999999999	Октябрьская	0103000020E6100000010000000500000028D192C7D3DC51407D93A641D1D24C4028D192C7D3DC514043C5387F13D44C401DC87A6AF5DD514043C5387F13D44C401DC87A6AF5DD51407D93A641D1D24C4028D192C7D3DC51407D93A641D1D24C40
76423	60825	71.179269000000005	71.194773999999995	57.661934000000002	57.659039999999997	Магистральная	0103000020E61000000100000005000000F20BAF2479CB5140BF60376C5BD44C40F20BAF2479CB5140240ED940BAD44C401C075E2D77CC5140240ED940BAD44C401C075E2D77CC5140BF60376C5BD44C40F20BAF2479CB5140BF60376C5BD44C40
76458	60845	71.375829999999993	71.393967000000004	57.697971000000003	57.686045999999997	Центральная	0103000020E61000000100000005000000C3B645990DD851409BC6F65AD0D74C40C3B645990DD8514039471D1D57D94C40022D5DC136D9514039471D1D57D94C40022D5DC136D951409BC6F65AD0D74C40C3B645990DD851409BC6F65AD0D74C40
73865	60131	71.314770999999993	71.338522999999995	57.741449000000003	57.732315	Советская	0103000020E61000000100000005000000ABAE433525D4514064AF777FBCDD4C40ABAE433525D45140725303CDE7DE4C40677C5F5CAAD55140725303CDE7DE4C40677C5F5CAAD5514064AF777FBCDD4C40ABAE433525D4514064AF777FBCDD4C40
29993	52408	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	Школьная 	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
30105	52408	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	Советская 	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
30134	52408	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	Садовая 	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
76460	52408	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	Карбышева	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
30149	52408	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	Горького	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
29294	52408	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	Агалакова 	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
29652	52408	71.141540000000006	71.197109999999995	57.720075000000001	57.66968	40 лет Октября	0103000020E61000000100000005000000DBC4C9FD0EC9514084640113B8D54C40DBC4C9FD0EC9514067D5E76A2BDC4C40BBED42739DCC514067D5E76A2BDC4C40BBED42739DCC514084640113B8D54C40DBC4C9FD0EC9514084640113B8D54C40
74069	60228	70.909873000000005	70.942096000000006	57.505350999999997	57.497231999999997	Центральная	0103000020E61000000100000005000000DCA0F65B3BBA51402843554CA5BF4C40DCA0F65B3BBA51401D007157AFC04C40516C054D4BBC51401D007157AFC04C40516C054D4BBC51402843554CA5BF4C40DCA0F65B3BBA51402843554CA5BF4C40
30096	53103	70.881243999999995	70.944305999999997	57.805748999999999	57.792650999999999	Советская	0103000020E61000000100000005000000F5F23B4D66B851402312859675E54C40F5F23B4D66B8514071E481C822E74C40A9DA6E826FBC514071E481C822E74C40A9DA6E826FBC51402312859675E54C40F5F23B4D66B851402312859675E54C40
29399	52391	70.687055000000001	70.705748999999997	57.770668999999998	57.762109000000002	Школьная	0103000020E6100000010000000500000069E388B5F8AB51405F7EA7C98CE14C4069E388B5F8AB514040852348A5E24C40D28BDAFD2AAD514040852348A5E24C40D28BDAFD2AAD51405F7EA7C98CE14C4069E388B5F8AB51405F7EA7C98CE14C40
76447	60835	70.814948000000001	70.842509000000007	57.799264999999998	57.791547000000001	Центральная	0103000020E6100000010000000500000033FCA71B28B451409B1F7F6951E54C4033FCA71B28B4514031EBC5504EE64C407C65DEAAEBB5514031EBC5504EE64C407C65DEAAEBB551409B1F7F6951E54C4033FCA71B28B451409B1F7F6951E54C40
29280	52403	70.822035999999997	70.870266999999998	57.458849000000001	57.451484999999998	Школьная	0103000020E610000001000000050000009E08E23C9CB4514039D1AE42CAB94C409E08E23C9CB45140B2666490BBBA4C406FF25B74B2B75140B2666490BBBA4C406FF25B74B2B7514039D1AE42CAB94C409E08E23C9CB4514039D1AE42CAB94C40
29356	52993	71.163664999999995	71.179412999999997	57.747543999999998	57.733910999999999	Советская	0103000020E61000000100000005000000FD9FC37C79CA51405B96AFCBF0DD4C40FD9FC37C79CA514017299485AFDF4C408BDEA9807BCB514017299485AFDF4C408BDEA9807BCB51405B96AFCBF0DD4C40FD9FC37C79CA51405B96AFCBF0DD4C40
30147	53125	70.441248999999999	70.470849000000001	57.953428000000002	57.93065	Лесная	0103000020E610000001000000050000002219726C3D9C5140DE02098A1FF74C402219726C3D9C51409C8BBFED09FA4C40AD16D863229E51409C8BBFED09FA4C40AD16D863229E5140DE02098A1FF74C402219726C3D9C5140DE02098A1FF74C40
29715	30014	71.229197999999997	71.249561999999997	57.683996999999998	57.677424000000002	Центральная	0103000020E61000000100000005000000C093162EABCE514044C362D4B5D64C40C093162EABCE5140F3C7B4368DD74C40C214E5D2F8CF5140F3C7B4368DD74C40C214E5D2F8CF514044C362D4B5D64C40C093162EABCE514044C362D4B5D64C40
28687	51912	70.682671999999997	70.697961000000006	57.297187000000001	57.286760000000001	Школьная	0103000020E610000001000000050000004679E6E5B0AB514086E63A8DB4A44C404679E6E5B0AB5140EFE53E390AA64C408B389D64ABAC5140EFE53E390AA64C408B389D64ABAC514086E63A8DB4A44C404679E6E5B0AB514086E63A8DB4A44C40
29282	52413	71.534571	71.560271999999998	57.621608999999999	57.613405	 Гаражная	0103000020E61000000100000005000000F698486936E25140F819170E84CE4C40F698486936E251401BF33AE290CF4C405437177FDBE351401BF33AE290CF4C405437177FDBE35140F819170E84CE4C40F698486936E25140F819170E84CE4C40
29176	30336	70.908382000000003	70.917778999999996	57.754057000000003	57.748672999999997	Колеватова	0103000020E610000001000000050000009B9141EE22BA5140F8325184D4DF4C409B9141EE22BA5140F22895F084E04C40287D21E4BCBA5140F22895F084E04C40287D21E4BCBA5140F8325184D4DF4C409B9141EE22BA5140F8325184D4DF4C40
30142	53122	70.545435999999995	70.583408000000006	57.823717000000002	57.808947000000003	Советская	0103000020E61000000100000005000000E883656CE8A25140429946938BE74C40E883656CE8A251406214048F6FE94C40630E828E56A551406214048F6FE94C40630E828E56A55140429946938BE74C40E883656CE8A25140429946938BE74C40
74067	60226	70.849982999999995	70.863151999999999	57.795692000000003	57.787109999999998	 Центральная	0103000020E61000000100000005000000FBC9181F66B65140622D3E05C0E44C40FBC9181F66B651402CD8463CD9E54C4087DEE2E13DB751402CD8463CD9E54C4087DEE2E13DB75140622D3E05C0E44C40FBC9181F66B65140622D3E05C0E44C40
29274	52389	70.831388000000004	70.845158999999995	57.734400999999998	57.726312999999998	Школьная	0103000020E610000001000000050000005C92037635B551406FD40AD3F7DC4C405C92037635B5514029931ADA00DE4C40E23AC61517B6514029931ADA00DE4C40E23AC61517B651406FD40AD3F7DC4C405C92037635B551406FD40AD3F7DC4C40
76452	60840	71.188170999999997	71.208850999999996	57.504897	57.491219999999998	Центральная	0103000020E610000001000000050000008FC360FE0ACC51401092054CE0BE4C408FC360FE0ACC51409C6C0377A0C04C4029AF95D05DCD51409C6C0377A0C04C4029AF95D05DCD51401092054CE0BE4C408FC360FE0ACC51401092054CE0BE4C40
29608	52381	70.602928000000006	70.635347999999993	57.881210000000003	57.864615999999998	Школьная	0103000020E61000000100000005000000EF75525F96A6514096CCB1BCABEE4C40EF75525F96A651403F74417DCBF04C400E65A88AA9A851403F74417DCBF04C400E65A88AA9A8514096CCB1BCABEE4C40EF75525F96A6514096CCB1BCABEE4C40
76456	60843	71.184875000000005	71.196607	57.642178999999999	57.628332	Центральная	0103000020E6100000010000000500000046B6F3FDD4CB5140E083D72E6DD04C4046B6F3FDD4CB5140C896E5EB32D24C408ACA863595CC5140C896E5EB32D24C408ACA863595CC5140E083D72E6DD04C4046B6F3FDD4CB5140E083D72E6DD04C40
30120	16296	71.478533999999996	71.526045999999994	57.700279999999999	57.677703000000001	Советская	0103000020E610000001000000050000008A01124DA0DE514057B3CEF8BED64C408A01124DA0DE51407D0569C6A2D94C40438CD7BCAAE151407D0569C6A2D94C40438CD7BCAAE1514057B3CEF8BED64C408A01124DA0DE514057B3CEF8BED64C40
29930	26358	71.841031000000001	71.868313000000001	55.998745	55.983006000000003	Ленина	0103000020E6100000010000000500000005FBAF73D3F55140CAE2FE23D3FD4B4005FBAF73D3F5514092054CE0D6FF4B40446CB07092F7514092054CE0D6FF4B40446CB07092F75140CAE2FE23D3FD4B4005FBAF73D3F55140CAE2FE23D3FD4B40
76420	60824	72.647422000000006	72.651904000000002	55.925758000000002	55.923406999999997	Солнечная	0103000020E61000000100000005000000802DAF5C6F295240E0F2583332F64B40802DAF5C6F2952405401F73C7FF64B406C088ECBB82952405401F73C7FF64B406C088ECBB8295240E0F2583332F64B40802DAF5C6F295240E0F2583332F64B40
30083	26858	72.058423000000005	72.067504999999997	55.727283	55.719692999999999	Центральная	0103000020E610000001000000050000006495D233BD0352407F1475E61EDC4B406495D233BD035240E8F7FD9B17DD4B4041D47D0052045240E8F7FD9B17DD4B4041D47D00520452407F1475E61EDC4B406495D233BD0352407F1475E61EDC4B40
30072	26318	72.160813000000005	72.174251999999996	55.940714	55.931713999999999	Центральная	0103000020E6100000010000000500000063F19BC24A0A5240D89C836742F74B4063F19BC24A0A5240D671FC5069F84B40CE50DCF1260B5240D671FC5069F84B40CE50DCF1260B5240D89C836742F74B4063F19BC24A0A5240D89C836742F74B40
29823	28309	72.180289000000002	72.206402999999995	56.232999	56.218525999999997	Школьная	0103000020E6100000010000000500000007B5DFDA890B5240B0A9F3A8F81B4C4007B5DFDA890B5240178046E9D21D4C40F6B2EDB4350D5240178046E9D21D4C40F6B2EDB4350D5240B0A9F3A8F81B4C4007B5DFDA890B5240B0A9F3A8F81B4C40
71518	59474	71.730197000000004	73.276996999999994	56.489198000000002	55.457199000000003	Калинина	0103000020E61000000100000005000000CAA8328CBBEE5140C861307F85BA4B40CAA8328CBBEE514062A2410A9E3E4C40C405A051BA51524062A2410A9E3E4C40C405A051BA515240C861307F85BA4B40CAA8328CBBEE5140C861307F85BA4B40
73674	25792	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	Первомайская	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
76446	25792	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	Ленина	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
29781	25792	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	Калинина	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
29190	25792	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	30 лет Победы	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
12185	25792	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	2-ая Береговая	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
29748	25792	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	2-Магистральная	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
29601	25792	72.162682000000004	72.221072000000007	55.889997000000001	55.848185000000001	1-Кооперативная	0103000020E610000001000000050000007769C361690A524098FA795391EC4B407769C361690A5240E144F46BEBF14B40ED832C0B260E5240E144F46BEBF14B40ED832C0B260E524098FA795391EC4B407769C361690A524098FA795391EC4B40
29415	28178	72.216707	72.247510000000005	55.706116999999999	55.697392000000001	Школьная	0103000020E610000001000000050000001D740987DE0D5240FB3E1C2444D94B401D740987DE0D52402713B70A62DA4B40B6DB2E34D70F52402713B70A62DA4B40B6DB2E34D70F5240FB3E1C2444D94B401D740987DE0D5240FB3E1C2444D94B40
28667	27909	72.059518999999995	72.079884000000007	56.101408999999997	56.094289000000003	Новая	0103000020E61000000100000005000000669FC728CF035240B0AF75A9110C4C40669FC728CF035240914259F8FA0C4C4051DEC7D11C055240914259F8FA0C4C4051DEC7D11C055240B0AF75A9110C4C40669FC728CF035240B0AF75A9110C4C40
29380	28096	72.587593999999996	72.645149000000004	56.209640999999998	56.187210999999998	Советская	0103000020E61000000100000005000000DA54DD239B255240C939B187F6174C40DA54DD239B2552404B732B84D51A4C400403081F4A2952404B732B84D51A4C400403081F4A295240C939B187F6174C40DA54DD239B255240C939B187F6174C40
29693	28451	72.216247999999993	72.232741000000004	56.130702999999997	56.119624000000002	Центральная	0103000020E61000000100000005000000D3F4D901D70D52408AE8D7D64F0F4C40D3F4D901D70D52409A3E3BE0BA104C400EDC813AE50E52409A3E3BE0BA104C400EDC813AE50E52408AE8D7D64F0F4C40D3F4D901D70D52408AE8D7D64F0F4C40
29309	27062	72.405910000000006	72.431880000000007	56.270811000000002	56.263776999999997	Юбилейная	0103000020E61000000100000005000000A4C7EF6DFA195240EF37DA71C3214C40A4C7EF6DFA195240D33252EFA9224C40FAF202ECA31B5240D33252EFA9224C40FAF202ECA31B5240EF37DA71C3214C40A4C7EF6DFA195240EF37DA71C3214C40
29936	28006	72.369708000000003	72.401866999999996	55.897689999999997	55.883701000000002	Центральная	0103000020E610000001000000050000007444BE4BA9175240A438471D1DF14B407444BE4BA91752401EF98381E7F24B40DD955D30B81952401EF98381E7F24B40DD955D30B8195240A438471D1DF14B407444BE4BA9175240A438471D1DF14B40
29122	26710	72.576984999999993	72.594745000000003	56.109647000000002	56.105400000000003	Почтовая	0103000020E6100000010000000500000015527E52ED245240CC7F48BF7D0D4C4015527E52ED245240618DB3E9080E4C40691D554D10265240618DB3E9080E4C40691D554D10265240CC7F48BF7D0D4C4015527E52ED245240CC7F48BF7D0D4C40
29949	27240	72.789769000000007	72.814184999999995	55.946430999999997	55.935864000000002	Центральная	0103000020E61000000100000005000000429946938B3252407BC03C64CAF74B40429946938B325240D575A8A624F94B4033F9669B1B345240D575A8A624F94B4033F9669B1B3452407BC03C64CAF74B40429946938B3252407BC03C64CAF74B40
29692	28394	72.131366999999997	72.155828	56.353006000000001	56.343373999999997	Береговая	0103000020E610000001000000050000008331225168085240FA25E2ADF32B4C40833122516808524059A5F44C2F2D4C4045F30016F909524059A5F44C2F2D4C4045F30016F9095240FA25E2ADF32B4C408331225168085240FA25E2ADF32B4C40
29659	52378	72.182804000000004	72.207068000000007	55.765149000000001	55.757241999999998	Центральная	0103000020E61000000100000005000000FE648C0FB30B52402D944C4EEDE04B40FE648C0FB30B524097C80567F0E14B401503249A400D524097C80567F0E14B401503249A400D52402D944C4EEDE04B40FE648C0FB30B52402D944C4EEDE04B40
29130	27628	72.728306000000003	72.738628000000006	55.904280999999997	55.893596000000002	Центральная	0103000020E61000000100000005000000C2DEC4909C2E524010EB8D5A61F24B40C2DEC4909C2E524074B2D47ABFF34B403CFA5FAE452F524074B2D47ABFF34B403CFA5FAE452F524010EB8D5A61F24B40C2DEC4909C2E524010EB8D5A61F24B40
29815	27968	72.206906000000004	72.229382000000001	55.826492999999999	55.810299000000001	Ленина	0103000020E6100000010000000500000028D6A9F23D0D5240A27DACE0B7E74B4028D6A9F23D0D5240BCAFCA85CAE94B40A112D731AE0E5240BCAFCA85CAE94B40A112D731AE0E5240A27DACE0B7E74B4028D6A9F23D0D5240A27DACE0B7E74B40
28695	27968	72.206906000000004	72.229382000000001	55.826492999999999	55.810299000000001	Зеленая	0103000020E6100000010000000500000028D6A9F23D0D5240A27DACE0B7E74B4028D6A9F23D0D5240BCAFCA85CAE94B40A112D731AE0E5240BCAFCA85CAE94B40A112D731AE0E5240A27DACE0B7E74B4028D6A9F23D0D5240A27DACE0B7E74B40
29657	26565	72.659189999999995	72.665649000000002	55.551226999999997	55.547671999999999	Школьная	0103000020E610000001000000050000006AF6402B302A5240AB77B81D1AC64B406AF6402B302A52400AD6389B8EC64B405E6743FE992A52400AD6389B8EC64B405E6743FE992A5240AB77B81D1AC64B406AF6402B302A5240AB77B81D1AC64B40
29407	27786	72.326436000000001	72.352478000000005	55.999822999999999	55.984485999999997	Ленина	0103000020E610000001000000050000002C0FD253E414524057AF22A303FE4B402C0FD253E4145240F1643733FAFF4B40CFA3E2FF8E165240F1643733FAFF4B40CFA3E2FF8E16524057AF22A303FE4B402C0FD253E414524057AF22A303FE4B40
29681	27870	72.078034000000002	72.099305999999999	56.087484000000003	56.083320000000001	Центральная	0103000020E61000000100000005000000787E5182FE045240268DD13AAA0A4C40787E5182FE0452402E76FBAC320B4C40FB928D075B0652402E76FBAC320B4C40FB928D075B065240268DD13AAA0A4C40787E5182FE045240268DD13AAA0A4C40
29789	27532	72.691287000000003	72.725269999999995	55.774720000000002	55.753270999999998	Юбилейная	0103000020E610000001000000050000009949D40B3E2C52403A03232F6BE04B409949D40B3E2C524050C763062AE34B4046B1DCD26A2E524050C763062AE34B4046B1DCD26A2E52403A03232F6BE04B409949D40B3E2C52403A03232F6BE04B40
29405	27405	72.513814999999994	72.546989999999994	55.648747999999998	55.637163999999999	Ленина	0103000020E610000001000000050000006E4C4F58E2205240221807978ED14B406E4C4F58E220524036ACA92C0AD34B404C4F58E20123524036ACA92C0AD34B404C4F58E201235240221807978ED14B406E4C4F58E2205240221807978ED14B40
29379	26510	72.686705000000003	72.717687999999995	55.647416999999997	55.637824999999999	Молодежная	0103000020E61000000100000005000000FB3F87F9F22B52401DC9E53FA4D14B40FB3F87F9F22B5240EDEF6C8FDED24B40D32EA699EE2D5240EDEF6C8FDED24B40D32EA699EE2D52401DC9E53FA4D14B40FB3F87F9F22B52401DC9E53FA4D14B40
29433	32502	72.135947999999999	72.157148000000007	56.194268000000001	56.184970999999997	Луговая	0103000020E61000000100000005000000397D3D5FB3085240ADDA3521AD174C40397D3D5FB3085240655419C6DD184C4070287CB60E0A5240655419C6DD184C4070287CB60E0A5240ADDA3521AD174C40397D3D5FB3085240ADDA3521AD174C40
29386	26828	71.915447999999998	71.930960999999996	55.663263000000001	55.657224999999997	Центральная	0103000020E61000000100000005000000124C35B396FA51408A8EE4F21FD44B40124C35B396FA5140CCD24ECDE5D44B407E3672DD94FB5140CCD24ECDE5D44B407E3672DD94FB51408A8EE4F21FD44B40124C35B396FA51408A8EE4F21FD44B40
29108	26256	71.730197000000004	73.276996999999994	56.489198000000002	55.457199000000003	Центральная	0103000020E61000000100000005000000CAA8328CBBEE5140C861307F85BA4B40CAA8328CBBEE514062A2410A9E3E4C40C405A051BA51524062A2410A9E3E4C40C405A051BA515240C861307F85BA4B40CAA8328CBBEE5140C861307F85BA4B40
29123	26980	72.314820999999995	72.324198999999993	56.206231000000002	56.194057999999998	Ленина	0103000020E6100000010000000500000004C6FA06261452407AC37DE4D6184C4004C6FA0626145240F03504C7651A4C40569929ADBF145240F03504C7651A4C40569929ADBF1452407AC37DE4D6184C4004C6FA06261452407AC37DE4D6184C40
29262	28053	72.313885999999997	72.329920999999999	55.861868000000001	55.856229999999996	Центральная	0103000020E61000000100000005000000062B4EB51614524052EDD3F198ED4B40062B4EB51614524006BCCCB051EE4B40DF50F86C1D15524006BCCCB051EE4B40DF50F86C1D15524052EDD3F198ED4B40062B4EB51614524052EDD3F198ED4B40
29668	27257	72.005566999999999	72.036738	55.869996	55.853960999999998	Ленина	0103000020E61000000100000005000000F5BBB0355B0052409C8713984EED4B40F5BBB0355B0052404ED367075CEF4B404F2157EA590252404ED367075CEF4B404F2157EA590252409C8713984EED4B40F5BBB0355B0052409C8713984EED4B40
29677	27825	72.371827999999994	72.386937000000003	56.019278999999997	56.014881000000003	Центральная	0103000020E610000001000000050000002CEFAA07CC175240782AE09EE7014C402CEFAA07CC175240F23FF9BB77024C4031276893C3185240F23FF9BB77024C4031276893C3185240782AE09EE7014C402CEFAA07CC175240782AE09EE7014C40
29699	27102	72.860826000000003	72.891116999999994	56.011746000000002	55.998759999999997	Школьная	0103000020E61000000100000005000000FA62EFC517375240C746205ED7FF4B40FA62EFC517375240EEED96E480014C4037FA980F08395240EEED96E480014C4037FA980F08395240C746205ED7FF4B40FA62EFC517375240C746205ED7FF4B40
29541	3060	72.051362999999995	72.076075000000003	55.583199999999998	55.578783000000001	Центральная	0103000020E610000001000000050000005D4E0988490352408A3DB48F15CA4B405D4E0988490352407B832F4CA6CA4B40C442AD69DE0452407B832F4CA6CA4B40C442AD69DE0452408A3DB48F15CA4B405D4E0988490352408A3DB48F15CA4B40
29675	3176	71.931122999999999	71.945757	55.847543000000002	55.842534000000001	Центральная	0103000020E610000001000000050000006B63EC8497FB514050E27327D8EB4B406B63EC8497FB5140147AFD497CEC4B40A33D5E4887FC5140147AFD497CEC4B40A33D5E4887FC514050E27327D8EB4B406B63EC8497FB514050E27327D8EB4B40
29954	27525	72.478538999999998	72.498148999999998	55.765918999999997	55.754015000000003	Заозерная	0103000020E6100000010000000500000013B70A62A01E5240C3D8429083E04B4013B70A62A01E5240483140A209E24B403FE257ACE11F5240483140A209E24B403FE257ACE11F5240C3D8429083E04B4013B70A62A01E5240C3D8429083E04B40
29411	28122	72.733048999999994	72.745993999999996	56.194679000000001	56.183458000000002	Школьная	0103000020E6100000010000000500000064575A46EA2E524044183F8D7B174C4064575A46EA2E5240E71BD13DEB184C40C8409E5DBE2F5240E71BD13DEB184C40C8409E5DBE2F524044183F8D7B174C4064575A46EA2E524044183F8D7B174C40
29847	3119	72.422780000000003	72.451813999999999	56.124115000000003	56.109560999999999	Аптечная	0103000020E61000000100000005000000C959D8D30E1B524062F54718060E4C40C959D8D30E1B5240B6F81400E30F4C40FF774485EA1C5240B6F81400E30F4C40FF774485EA1C524062F54718060E4C40C959D8D30E1B524062F54718060E4C40
29680	27751	72.389955999999998	72.408721	55.643571000000001	55.636254999999998	Центральная	0103000020E6100000010000000500000041B8020AF51852404F75C8CD70D14B4041B8020AF5185240B7D3D68860D24B400F0C207C281A5240B7D3D68860D24B400F0C207C281A52404F75C8CD70D14B4041B8020AF51852404F75C8CD70D14B40
29376	26213	72.172302999999999	72.191787000000005	55.990957000000002	55.985790000000001	Центральная	0103000020E610000001000000050000002C802903070B5240A75CE15D2EFE4B402C802903070B5240035FD1ADD7FE4B401233FB3C460C5240035FD1ADD7FE4B401233FB3C460C5240A75CE15D2EFE4B402C802903070B5240A75CE15D2EFE4B40
29549	27461	72.566824999999994	72.583156000000002	55.670980999999998	55.665731000000001	Лесная	0103000020E6100000010000000500000088635DDC46245240797764AC36D54B4088635DDC46245240629E95B4E2D54B40D61D8B6D52255240629E95B4E2D54B40D61D8B6D52255240797764AC36D54B4088635DDC46245240797764AC36D54B40
29934	27178	71.730197000000004	73.276996999999994	56.489198000000002	55.457199000000003	Зеленая	0103000020E61000000100000005000000CAA8328CBBEE5140C861307F85BA4B40CAA8328CBBEE514062A2410A9E3E4C40C405A051BA51524062A2410A9E3E4C40C405A051BA515240C861307F85BA4B40CAA8328CBBEE5140C861307F85BA4B40
30074	2529	72.621837999999997	72.639660000000006	55.592953000000001	55.588293	Мира	0103000020E610000001000000050000003E5A9C31CC2752409DBB5D2F4DCB4B403E5A9C31CC275240558847E2E5CB4B40CD237F30F0285240558847E2E5CB4B40CD237F30F02852409DBB5D2F4DCB4B403E5A9C31CC2752409DBB5D2F4DCB4B40
29670	27325	72.147589999999994	72.163831999999999	55.862777000000001	55.851252000000002	Центральная	0103000020E61000000100000005000000DDCD531D72095240CA5356D3F5EC4B40DDCD531D72095240D95E0B7A6FEE4B40738236397C0A5240D95E0B7A6FEE4B40738236397C0A5240CA5356D3F5EC4B40DDCD531D72095240CA5356D3F5EC4B40
29792	26625	72.606961999999996	72.619844000000001	55.997990000000001	55.989260000000002	Озерная	0103000020E610000001000000050000008BFA2477D8265240D89E5912A0FE4B408BFA2477D826524016DEE522BEFF4B40CC272B86AB27524016DEE522BEFF4B40CC272B86AB275240D89E5912A0FE4B408BFA2477D8265240D89E5912A0FE4B40
29940	2618	72.005296999999999	72.029740000000004	55.702692999999996	55.682270000000003	Березовая	0103000020E6100000010000000500000015713AC9560052405E85949F54D74B4015713AC95600524066101FD8F1D94B4084D89942E701524066101FD8F1D94B4084D89942E70152405E85949F54D74B4015713AC9560052405E85949F54D74B40
29491	2613	72.649694999999994	72.685888000000006	56.057850000000002	56.047680999999997	Озерная	0103000020E61000000100000005000000FB57569A94295240FED137691A064C40FB57569A942952406C09F9A067074C40022EC896E52B52406C09F9A067074C40022EC896E52B5240FED137691A064C40FB57569A94295240FED137691A064C40
29529	26370	72.687647999999996	72.721829	55.588903000000002	55.573062	Мира	0103000020E610000001000000050000003ACAC16C022C5240494A7A185AC94B403ACAC16C022C524016C26A2C61CB4B407B134372322E524016C26A2C61CB4B407B134372322E5240494A7A185AC94B403ACAC16C022C5240494A7A185AC94B40
29925	26182	72.002493999999999	72.044284000000005	55.961264	55.945982000000001	Ленина	0103000020E61000000100000005000000EB1B98DC28005240664D2CF015F94B40EB1B98DC280052403C69E1B20AFB4B401CEF8E8CD50252403C69E1B20AFB4B401CEF8E8CD5025240664D2CF015F94B40EB1B98DC28005240664D2CF015F94B40
29763	24600	73.251780999999994	73.270636999999994	57.594347999999997	57.586219	Федоровская	0103000020E6100000010000000500000044300E2E1D5052409CA5643909CB4C4044300E2E1D505240B438639813CC4C409A05DA1D52515240B438639813CC4C409A05DA1D525152409CA5643909CB4C4044300E2E1D5052409CA5643909CB4C40
30053	25581	71.743735000000001	71.771024999999995	57.585158	57.568171	Победы	0103000020E61000000100000005000000FF78AF5A99EF51408FC4CBD3B9C84C40FF78AF5A99EF5140137F1475E6CA4C407FD93D7958F15140137F1475E6CA4C407FD93D7958F151408FC4CBD3B9C84C40FF78AF5A99EF51408FC4CBD3B9C84C40
29358	25468	72.244383999999997	72.275205	57.517417999999999	57.510665000000003	Советская	0103000020E610000001000000050000009AEAC9FCA30F52401E1B81785DC14C409AEAC9FCA30F52404D2EC6C03AC24C4086AC6EF59C1152404D2EC6C03AC24C4086AC6EF59C1152401E1B81785DC14C409AEAC9FCA30F52401E1B81785DC14C40
29780	25681	71.619784999999993	71.635703000000007	57.615174000000003	57.602637999999999	переулок Клубный	0103000020E610000001000000050000004963B48EAAE75140D6A9F23D23CD4C404963B48EAAE75140BDAC8905BECE4C4006BEA25BAFE85140BDAC8905BECE4C4006BEA25BAFE85140D6A9F23D23CD4C404963B48EAAE75140D6A9F23D23CD4C40
29083	24013	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	Советская	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
29085	24013	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	Парковая	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
29336	24013	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	Павлика Морозова	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
29891	24013	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	Максима Горького	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
29758	24013	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	Карбышева	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
9899	24013	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	Гуртьева	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
29892	24013	72.377369999999999	72.418746999999996	57.535747999999998	57.483184000000001	Гагарина	0103000020E61000000100000005000000751F80D426185240A9F92AF9D8BD4C40751F80D426185240DE72F56393C44C40149337C0CC1A5240DE72F56393C44C40149337C0CC1A5240A9F92AF9D8BD4C40751F80D426185240A9F92AF9D8BD4C40
29346	24769	72.794548000000006	72.806557999999995	57.413480999999997	57.401622000000003	Береговая	0103000020E610000001000000050000008BC6DADFD932524054AD855968B34C408BC6DADFD9325240394206F2ECB44C40F01472A59E335240394206F2ECB44C40F01472A59E33524054AD855968B34C408BC6DADFD932524054AD855968B34C40
29634	25125	73.194190000000006	73.214851999999993	57.333359999999999	57.323273	Школьная	0103000020E6100000010000000500000075CDE49B6D4C52400457790261A94C4075CDE49B6D4C5240B4E55C8AABAA4C40BB5E9A22C04D5240B4E55C8AABAA4C40BB5E9A22C04D52400457790261A94C4075CDE49B6D4C52400457790261A94C40
30054	25632	71.695719999999994	71.714988000000005	57.595413999999998	57.586421999999999	Молодежная	0103000020E6100000010000000500000014CB2DAD86EC5140D4D347E00FCB4C4014CB2DAD86EC51404FCAA48636CC4C401442075DC2ED51404FCAA48636CC4C401442075DC2ED5140D4D347E00FCB4C4014CB2DAD86EC5140D4D347E00FCB4C40
29776	25218	71.865232000000006	71.872480999999993	57.496985000000002	57.488129000000001	Центральная	0103000020E61000000100000005000000F9DC09F65FF75140569DD5027BBE4C40F9DC09F65FF7514021CD58349DBF4C4068588CBAD6F7514021CD58349DBF4C4068588CBAD6F75140569DD5027BBE4C40F9DC09F65FF75140569DD5027BBE4C40
30048	25445	72.049907000000005	72.094939999999994	57.531041999999999	57.521943	Школьная	0103000020E61000000100000005000000DB3521AD3103524025B03907CFC24C40DB3521AD31035240B6662B2FF9C34C4043C5387F13065240B6662B2FF9C34C4043C5387F1306524025B03907CFC24C40DB3521AD3103524025B03907CFC24C40
30047	25322	72.681773000000007	72.696533000000002	57.432952999999998	57.423372999999998	Школьная	0103000020E61000000100000005000000EF92382BA22B52403481221631B64C40EF92382BA22B524040DAFF006BB74C406DE525FF932C524040DAFF006BB74C406DE525FF932C52403481221631B64C40EF92382BA22B52403481221631B64C40
29205	24690	72.935781000000006	72.948365999999993	57.400807	57.391733000000002	Школьная	0103000020E61000000100000005000000F7CDFDD5E33B5240CAE1934E24B24C40F7CDFDD5E33B52400281CEA44DB34C40DAA84E07B23C52400281CEA44DB34C40DAA84E07B23C5240CAE1934E24B24C40F7CDFDD5E33B5240CAE1934E24B24C40
29624	24501	72.448291999999995	72.460599000000002	57.528118999999997	57.511834999999998	Школьная	0103000020E61000000100000005000000BDC3EDD0B01C52405DF92CCF83C14C40BDC3EDD0B01C5240B7B2446799C34C4080643A747A1D5240B7B2446799C34C4080643A747A1D52405DF92CCF83C14C40BDC3EDD0B01C52405DF92CCF83C14C40
29638	25301	72.195363	72.235552999999996	57.586281999999997	57.579194000000001	Гагарина	0103000020E610000001000000050000004DF6CFD3800C52400C056C0723CA4C404DF6CFD3800C5240E21DE0490BCB4C4061DEE34C130F5240E21DE0490BCB4C4061DEE34C130F52400C056C0723CA4C404DF6CFD3800C52400C056C0723CA4C40
30042	25202	71.853319999999997	71.879334999999998	57.538265000000003	57.530506000000003	Береговая	0103000020E6100000010000000500000074417DCB9CF65140782AE09EE7C34C4074417DCB9CF651406DCA15DEE5C44C409ACE4E0647F851406DCA15DEE5C44C409ACE4E0647F85140782AE09EE7C34C4074417DCB9CF65140782AE09EE7C34C40
29771	25135	71.82938	71.854021000000003	57.555947000000003	57.543956000000001	Переулок Набережный	0103000020E6100000010000000500000037FDD98F14F55140433BA759A0C54C4037FDD98F14F5514098A7734529C74C403946B247A8F6514098A7734529C74C403946B247A8F65140433BA759A0C54C4037FDD98F14F55140433BA759A0C54C40
29775	53037	71.680062000000007	71.706562000000005	57.663300999999997	57.651124000000003	Кайсинская	0103000020E610000001000000050000002750C42286EB514003D2FE0758D34C402750C42286EB5140B933130CE7D44C402BA6D24F38ED5140B933130CE7D44C402BA6D24F38ED514003D2FE0758D34C402750C42286EB514003D2FE0758D34C40
30095	53102	73.099947999999998	73.116747000000004	57.391863999999998	57.379778999999999	Береговая	0103000020E610000001000000050000003DD34B8C65465240925A28999CB04C403DD34B8C65465240683D7C9928B24C40FEB968C878475240683D7C9928B24C40FEB968C878475240925A28999CB04C403DD34B8C65465240925A28999CB04C40
29641	25016	72.655264000000003	72.679571999999993	57.510182	57.493009999999998	Клубная	0103000020E61000000100000005000000C18F6AD8EF295240EC4CA1F31ABF4C40C18F6AD8EF2952400281CEA44DC14C40BFD18E1B7E2B52400281CEA44DC14C40BFD18E1B7E2B5240EC4CA1F31ABF4C40C18F6AD8EF295240EC4CA1F31ABF4C40
29630	24990	72.903081999999998	72.923573000000005	57.639437999999998	57.629604999999998	Северная	0103000020E61000000100000005000000CDE67118CC395240F4328AE596D04C40CDE67118CC395240EAE8B81AD9D14C40FE9DEDD11B3B5240EAE8B81AD9D14C40FE9DEDD11B3B5240F4328AE596D04C40CDE67118CC395240F4328AE596D04C40
29766	24908	72.644133999999994	72.686758999999995	57.611992000000001	57.595534000000001	Школьная	0103000020E61000000100000005000000770FD07D39295240FAD346753ACC4C40770FD07D39295240F2B4FCC055CE4C40F44E05DCF32B5240F2B4FCC055CE4C40F44E05DCF32B5240FAD346753ACC4C40770FD07D39295240FAD346753ACC4C40
29996	10889	72.944395999999998	72.976538000000005	57.471701000000003	57.457265999999997	Школьная	0103000020E61000000100000005000000499EEBFB703C52404FC939B187BA4C40499EEBFB703C5240C93EC8B260BC4C4048533D997F3E5240C93EC8B260BC4C4048533D997F3E52404FC939B187BA4C40499EEBFB703C52404FC939B187BA4C40
29629	24789	72.358658000000005	72.405523000000002	57.597000000000001	57.575304000000003	Гагарина	0103000020E61000000100000005000000B91CAF40F416524006A1BC8FA3C94C40B91CAF40F416524023DBF97E6ACC4C40A7B1BD16F419524023DBF97E6ACC4C40A7B1BD16F419524006A1BC8FA3C94C40B91CAF40F416524006A1BC8FA3C94C40
29505	24675	72.982422	73.006316999999996	57.405554000000002	57.395327000000002	Зеленая	0103000020E61000000100000005000000BD378600E03E5240E71C3C139AB24C40BD378600E03E524089618731E9B34C402A1A6B7F6740524089618731E9B34C402A1A6B7F67405240E71C3C139AB24C40BD378600E03E5240E71C3C139AB24C40
29357	25400	72.531377000000006	72.549002000000002	57.469262000000001	57.452047	Школьная	0103000020E610000001000000050000002F36AD1402225240A1A014ADDCB94C402F36AD1402225240B6A0F7C610BC4C4012DC48D922235240B6A0F7C610BC4C4012DC48D922235240A1A014ADDCB94C402F36AD1402225240A1A014ADDCB94C40
29500	24548	73.040812000000003	73.058014999999997	57.583233	57.577683999999998	Молодежная	0103000020E610000001000000050000003352EFA99C42524013B69F8CF1C94C403352EFA99C42524057790261A7CA4C405BEB8B84B643524057790261A7CA4C405BEB8B84B643524013B69F8CF1C94C403352EFA99C42524013B69F8CF1C94C40
76445	60834	73.533097999999995	75.847696999999997	58.574581000000002	56.506697000000003	Комсомольская	0103000020E6100000010000000500000008E412471E6252409CFD8172DB404C4008E412471E62524095F3C5DE8B494D40B5FAEAAA40F6524095F3C5DE8B494D40B5FAEAAA40F652409CFD8172DB404C4008E412471E6252409CFD8172DB404C40
29802	23494	74.506727999999995	74.530246000000005	56.705810999999997	56.687618000000001	Победы	0103000020E61000000100000005000000EBFD463B6EA052400A12DBDD03584C40EBFD463B6EA052401A14CD03585A4C406E35EB8CEFA152401A14CD03585A4C406E35EB8CEFA152400A12DBDD03584C40EBFD463B6EA052400A12DBDD03584C40
29306	22356	74.261003000000002	74.280450999999999	56.923546999999999	56.909210000000002	Первомайская	0103000020E610000001000000050000001B4AED45B49052401C9947FE60744C401B4AED45B4905240D2A8C0C936764C405A48C0E8F2915240D2A8C0C936764C405A48C0E8F29152401C9947FE60744C401B4AED45B49052401C9947FE60744C40
76425	60826	74.501455000000007	74.517058000000006	56.830325000000002	56.820990999999999	Коммуны	0103000020E610000001000000050000009B5AB6D617A05240B9A7AB3B16694C409B5AB6D617A052408E06F016486A4C40A708707A17A152408E06F016486A4C40A708707A17A15240B9A7AB3B16694C409B5AB6D617A05240B9A7AB3B16694C40
29319	23218	74.634585000000001	74.665011000000007	56.679920000000003	56.671478999999998	Зеленая	0103000020E610000001000000050000000F62670A9DA85240B3791C06F3554C400F62670A9DA85240BBF2599E07574C40BD1E4C8A8FAA5240BBF2599E07574C40BD1E4C8A8FAA5240B3791C06F3554C400F62670A9DA85240B3791C06F3554C40
29177	22159	74.184583000000003	74.207076999999998	57.210641000000003	57.201749	Центральная	0103000020E6100000010000000500000072193735D08B5240178046E9D2994C4072193735D08B52402F19C748F69A4C403EB0E3BF408D52402F19C748F69A4C403EB0E3BF408D5240178046E9D2994C4072193735D08B5240178046E9D2994C40
76434	60829	73.818897000000007	73.836404999999999	56.947173999999997	56.938488	Центральная	0103000020E61000000100000005000000B972F6CE687452401FD8F15F20784C40B972F6CE687452408DCF64FF3C794C407F4DD6A8877552408DCF64FF3C794C407F4DD6A8877552401FD8F15F20784C40B972F6CE687452401FD8F15F20784C40
29976	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Школьная	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29169	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Чкалова	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29720	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Транспортная	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29426	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Советская	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29244	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Сельскохозяйственная	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29768	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Радищева	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29590	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Нерпинская	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
28893	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Немчиновская	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
28688	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Лихачева	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29856	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Ленина	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29850	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Калинина	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29989	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Избышева	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
28694	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Елецкого	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29120	6562	74.329930000000004	74.41713	56.953471999999998	56.862642000000001	Александровская	0103000020E6100000010000000500000009FEB7921D955240F913950D6B6E4C4009FEB7921D9552406BD3D85E0B7A4C408D0B0742B29A52406BD3D85E0B7A4C408D0B0742B29A5240F913950D6B6E4C4009FEB7921D955240F913950D6B6E4C40
29468	22853	73.815914000000006	73.839702000000003	56.983832999999997	56.974905999999997	Зеленый переулок	0103000020E610000001000000050000004F965AEF377452404B5645B8C97C4C404F965AEF37745240DFDC5F3DEE7D4C40B11875ADBD755240DFDC5F3DEE7D4C40B11875ADBD7552404B5645B8C97C4C404F965AEF377452404B5645B8C97C4C40
29490	53008	74.595742000000001	74.605462000000003	57.013331999999998	57.006573000000003	Черемуховая	0103000020E61000000100000005000000A2B60DA320A65240B0045262D7804C40A2B60DA320A65240C1FEEBDCB4814C40213EB0E3BFA65240C1FEEBDCB4814C40213EB0E3BFA65240B0045262D7804C40A2B60DA320A65240B0045262D7804C40
29299	46381	74.207426999999996	74.220965000000007	57.002156999999997	56.995660999999998	Молодежная	0103000020E61000000100000005000000AC53E57B468D52408A73D4D1717F4C40AC53E57B468D52408E3A3AAE46804C40E223624A248E52408E3A3AAE46804C40E223624A248E52408A73D4D1717F4C40AC53E57B468D52408A73D4D1717F4C40
76474	60856	74.100447000000003	74.111119000000002	57.037685000000003	57.028300000000002	Школьная	0103000020E61000000100000005000000CEFE40B96D865240083D9B559F834C40CEFE40B96D8652405F46B1DCD2844C40B6BDDD921C8752405F46B1DCD2844C40B6BDDD921C875240083D9B559F834C40CEFE40B96D865240083D9B559F834C40
9741	40295	74.345416999999998	74.364884000000004	56.977148	56.968592000000001	Комсомольская	0103000020E61000000100000005000000E09EE74F1B965240689599D2FA7B4C40E09EE74F1B96524008AD872F137D4C405BB56B425A97524008AD872F137D4C405BB56B425A975240689599D2FA7B4C40E09EE74F1B965240689599D2FA7B4C40
30007	7130	74.099772999999999	74.133225999999993	57.138764999999999	57.129392000000003	Интернациональная	0103000020E6100000010000000500000086014BAE62865240992EC4EA8F904C4086014BAE628652402B6A300DC3914C40853E58C6868852402B6A300DC3914C40853E58C686885240992EC4EA8F904C4086014BAE62865240992EC4EA8F904C40
29175	22056	74.126784999999998	74.180693000000005	57.12838	57.108021999999998	Советская	0103000020E61000000100000005000000E527D53E1D885240CF9F36AAD38D4C40E527D53E1D885240F1BA7EC16E904C406F675F79908B5240F1BA7EC16E904C406F675F79908B5240CF9F36AAD38D4C40E527D53E1D885240CF9F36AAD38D4C40
29521	21662	74.474891999999997	74.491923999999997	57.470821000000001	57.462291999999998	Рабочая	0103000020E6100000010000000500000073486AA1649E5240E9995E622CBB4C4073486AA1649E524090A2CEDC43BC4C408507CDAE7B9F524090A2CEDC43BC4C408507CDAE7B9F5240E9995E622CBB4C4073486AA1649E5240E9995E622CBB4C40
29737	53034	74.163696999999999	74.187610000000006	56.960146999999999	56.952750000000002	Зеленая	0103000020E61000000100000005000000035DFB027A8A5240CBA145B6F3794C40035DFB027A8A52401F2DCE18E67A4C40C4995FCD018C52401F2DCE18E67A4C40C4995FCD018C5240CBA145B6F3794C40035DFB027A8A5240CBA145B6F3794C40
29203	40456	75.097369999999998	75.111474000000001	57.413214000000004	57.406906999999997	 Таежная	0103000020E610000001000000050000002367614F3BC65240B9C1508715B44C402367614F3BC65240EB1F4432E4B44C40AD16D86322C75240EB1F4432E4B44C40AD16D86322C75240B9C1508715B44C402367614F3BC65240B9C1508715B44C40
29573	53018	74.061181000000005	74.085076999999998	56.668981000000002	56.657722	Блочная	0103000020E61000000100000005000000BE88B663EA8352400BEE073C30544C40BE88B663EA8352409C525E2BA1554C401329CDE6718552409C525E2BA1554C401329CDE6718552400BEE073C30544C40BE88B663EA8352400BEE073C30544C40
29159	23866	74.760062000000005	74.767005999999995	57.054479000000001	57.041460000000001	Таежная	0103000020E61000000100000005000000AC3B16DBA4B05240CC0BB08F4E854C40AC3B16DBA4B05240CEA8F92AF9864C407D7555A016B15240CEA8F92AF9864C407D7555A016B15240CC0BB08F4E854C40AC3B16DBA4B05240CC0BB08F4E854C40
29307	46166	74.454886000000002	74.464596999999998	56.952367000000002	56.948421000000003	2 Кордон	0103000020E61000000100000005000000215A2BDA1C9D524079EBFCDB65794C40215A2BDA1C9D524013656F29E7794C4076340EF5BB9D524013656F29E7794C4076340EF5BB9D524079EBFCDB65794C40215A2BDA1C9D524079EBFCDB65794C40
29139	46825	74.871013000000005	74.911347000000006	56.735506000000001	56.718691	Центральная	0103000020E6100000010000000500000004594FADBEB75240FB761211FE5B4C4004594FADBEB752408201840F255E4C40B2135E8253BA52408201840F255E4C40B2135E8253BA5240FB761211FE5B4C4004594FADBEB75240FB761211FE5B4C40
76424	21784	74.838053000000002	74.867294000000001	57.094211000000001	57.088997999999997	Центральная	0103000020E6100000010000000500000024D40CA9A2B5524067B45549648B4C4024D40CA9A2B5524034F6251B0F8C4C401781B1BE81B7524034F6251B0F8C4C401781B1BE81B7524067B45549648B4C4024D40CA9A2B5524067B45549648B4C40
29064	46453	74.569429999999997	74.611840000000001	56.828118000000003	56.795366999999999	Центральная	0103000020E610000001000000050000001FD7868A71A45240A8A8FA95CE654C401FD7868A71A452404E9D47C5FF694C409E98F56228A752404E9D47C5FF694C409E98F56228A75240A8A8FA95CE654C401FD7868A71A45240A8A8FA95CE654C40
29314	46453	74.569429999999997	74.611840000000001	56.828118000000003	56.795366999999999	Советская	0103000020E610000001000000050000001FD7868A71A45240A8A8FA95CE654C401FD7868A71A452404E9D47C5FF694C409E98F56228A752404E9D47C5FF694C409E98F56228A75240A8A8FA95CE654C401FD7868A71A45240A8A8FA95CE654C40
29950	23317	74.795356999999996	74.813799000000003	56.724004999999998	56.716275000000003	Центральная	0103000020E6100000010000000500000042E90B21E7B25240A1F831E6AE5B4C4042E90B21E7B25240FB912232AC5C4C401FA1664815B45240FB912232AC5C4C401FA1664815B45240A1F831E6AE5B4C4042E90B21E7B25240A1F831E6AE5B4C40
29878	21871	74.505065999999999	74.526786999999999	57.126382	57.110602999999998	Разгуляевой	0103000020E610000001000000050000009414580053A0524074EB353D288E4C409414580053A05240CB660E492D904C404F3DD2E0B6A15240CB660E492D904C404F3DD2E0B6A1524074EB353D288E4C409414580053A0524074EB353D288E4C40
29056	46260	74.221727999999999	74.237503000000004	56.875771999999998	56.868521000000001	Школьная	0103000020E61000000100000005000000E126A3CA308E5240D27135B22B6F4C40E126A3CA308E52405260014C19704C40EC6CC83F338F52405260014C19704C40EC6CC83F338F5240D27135B22B6F4C40E126A3CA308E5240D27135B22B6F4C40
29714	46282	73.867611999999994	73.896332000000001	56.903537999999998	56.886533	Тарская	0103000020E610000001000000050000007F677BF48677524092E9D0E979714C407F677BF486775240BC581822A7734C40EE96E4805D795240BC581822A7734C40EE96E4805D79524092E9D0E979714C407F677BF48677524092E9D0E979714C40
29347	15387	75.090183999999994	75.120914999999997	57.345931	57.337401999999997	Лесная	0103000020E61000000100000005000000D6A71C93C5C5524070CD1DFD2FAB4C40D6A71C93C5C5524017D68D7747AC4C4022A64412BDC7524017D68D7747AC4C4022A64412BDC7524070CD1DFD2FAB4C40D6A71C93C5C5524070CD1DFD2FAB4C40
29872	21769	74.825603000000001	74.841710000000006	57.181158000000003	57.168506000000001	Мира	0103000020E61000000100000005000000B01EF7ADD6B452400397C79A91954C40B01EF7ADD6B4524053B4722F30974C40D6AD9E93DEB5524053B4722F30974C40D6AD9E93DEB552400397C79A91954C40B01EF7ADD6B452400397C79A91954C40
30019	47022	74.322483000000005	74.337737000000004	57.088709000000001	57.074299000000003	переулок Школьный	0103000020E6100000010000000500000006A1BC8FA394524011902FA182894C4006A1BC8FA394524031EE06D15A8B4C408C69A67B9D95524031EE06D15A8B4C408C69A67B9D95524011902FA182894C4006A1BC8FA394524011902FA182894C40
30032	46630	74.512055000000004	74.519682000000003	56.756878	56.743547999999997	Сельскохозяйственная	0103000020E6100000010000000500000036B05582C5A05240CB80B3942C5F4C4036B05582C5A05240EC87D860E1604C4079944A7842A15240EC87D860E1604C4079944A7842A15240CB80B3942C5F4C4036B05582C5A05240CB80B3942C5F4C40
29871	46442	73.991866999999999	74.002566000000002	56.811793000000002	56.798310000000001	Центральная	0103000020E61000000100000005000000D3BEB9BF7A7F5240EE08A7052F664C40D3BEB9BF7A7F5240950F41D5E8674C403885950A2A805240950F41D5E8674C403885950A2A805240EE08A7052F664C40D3BEB9BF7A7F5240EE08A7052F664C40
29070	23509	74.300223000000003	74.320021999999994	56.695051999999997	56.682040999999998	Хуторская	0103000020E6100000010000000500000073A087DA36935240FCC3961E4D574C4073A087DA369352407B82C476F7584C4008008E3D7B9452407B82C476F7584C4008008E3D7B945240FCC3961E4D574C4073A087DA36935240FCC3961E4D574C40
29057	22771	73.767217000000002	73.789790999999994	56.891607	56.878473	Школьная	0103000020E61000000100000005000000DBFB54151A715240A2B5A2CD71704C40DBFB54151A7152403DF19C2D20724C4035EB8CEF8B7252403DF19C2D20724C4035EB8CEF8B725240A2B5A2CD71704C40DBFB54151A715240A2B5A2CD71704C40
29582	23243	74.610905000000002	74.621442999999999	56.722611999999998	56.715938999999999	Садовая	0103000020E61000000100000005000000A0FD481119A7524029779FE3A35B4C40A0FD481119A752403CD9CD8C7E5C4C400055DCB8C5A752403CD9CD8C7E5C4C400055DCB8C5A7524029779FE3A35B4C40A0FD481119A7524029779FE3A35B4C40
29216	13234	74.657330000000002	74.667929999999998	57.333427999999998	57.329143000000002	Центральная	0103000020E61000000100000005000000802BD9B111AA52408A5A9A5B21AA4C40802BD9B111AA52400CC9C9C4ADAA4C401B81785DBFAA52400CC9C9C4ADAA4C401B81785DBFAA52408A5A9A5B21AA4C40802BD9B111AA52408A5A9A5B21AA4C40
29633	10900	74.358999999999995	74.371576000000005	57.082966999999996	57.073721999999997	Центральная	0103000020E61000000100000005000000E5D022DBF9965240737FF5B86F894C40E5D022DBF9965240D8D2A3A99E8A4C40A0FEB3E6C7975240D8D2A3A99E8A4C40A0FEB3E6C7975240737FF5B86F894C40E5D022DBF9965240737FF5B86F894C40
29557	20492	74.548858999999993	74.575422000000003	57.360841999999998	57.351039	Центральная	0103000020E6100000010000000500000060C77F8120A352406E4F90D8EEAC4C4060C77F8120A35240F982161230AE4C4088D9CBB6D3A45240F982161230AE4C4088D9CBB6D3A452406E4F90D8EEAC4C4060C77F8120A352406E4F90D8EEAC4C40
29516	53010	74.921200999999996	74.938719000000006	56.731709000000002	56.721722999999997	Молодежная	0103000020E61000000100000005000000B8020AF5F4BA5240B0E2546B615C4C40B8020AF5F4BA52402D98F8A3A85D4C409148DBF813BC52402D98F8A3A85D4C409148DBF813BC5240B0E2546B615C4C40B8020AF5F4BA5240B0E2546B615C4C40
29476	46583	74.507302999999993	74.519834000000003	56.805259	56.782322000000001	Советская	0103000020E61000000100000005000000698A00A777A052407D78962023644C40698A00A777A05240A3E716BA12674C405456D3F544A15240A3E716BA12674C405456D3F544A152407D78962023644C40698A00A777A052407D78962023644C40
29197	46769	74.711821999999998	74.735878999999997	57.049450999999998	57.035646999999997	Центральная	0103000020E61000000100000005000000B1A4DC7D8EAD5240AA99B51490844C40B1A4DC7D8EAD524093E00D6954864C400BB43BA418AF524093E00D6954864C400BB43BA418AF5240AA99B51490844C40B1A4DC7D8EAD5240AA99B51490844C40
30140	53121	74.541618	74.605425999999994	56.897255999999999	56.871994999999998	Советская	0103000020E61000000100000005000000323B8BDEA9A2524044A33B889D6F4C40323B8BDEA9A25240E411DC48D9724C407A89B14CBFA65240E411DC48D9724C407A89B14CBFA6524044A33B889D6F4C40323B8BDEA9A2524044A33B889D6F4C40
29312	45802	74.878460000000004	74.906324999999995	57.171219999999998	57.161785999999999	пер.Первый	0103000020E6100000010000000500000007B64AB038B85240AF795567B5944C4007B64AB038B85240E7357689EA954C4005A3923A01BA5240E7357689EA954C4005A3923A01BA5240AF795567B5944C4007B64AB038B85240AF795567B5944C40
29460	46079	74.294447000000005	74.307122000000007	57.306139000000002	57.294921000000002	Школьная	0103000020E61000000100000005000000F1D93A38D8925240AAF3A8F8BFA54C40F1D93A38D8925240DC8310902FA74C40757808E3A7935240DC8310902FA74C40757808E3A7935240AAF3A8F8BFA54C40F1D93A38D8925240AAF3A8F8BFA54C40
28755	22952	73.951837999999995	73.979471000000004	56.863286000000002	56.852238	Свободы	0103000020E61000000100000005000000C345EEE9EA7C524048348122166D4C40C345EEE9EA7C52401E8CD827806E4C40591822A7AF7E52401E8CD827806E4C40591822A7AF7E524048348122166D4C40C345EEE9EA7C524048348122166D4C40
29794	22948	73.973685000000003	74.017398	56.764234999999999	56.747841999999999	Школьная	0103000020E61000000100000005000000C5E6E3DA507E5240A1496249B95F4C40C5E6E3DA507E5240B2BAD573D2614C400341800C1D815240B2BAD573D2614C400341800C1D815240A1496249B95F4C40C5E6E3DA507E5240A1496249B95F4C40
29753	22606	74.096969999999999	74.116750999999994	56.715539	56.708705999999999	Центральная	0103000020E610000001000000050000005CACA8C1348652404F3DD2E0B65A4C405CACA8C1348652409B012EC8965B4C409EB12FD9788752409B012EC8965B4C409EB12FD9788752404F3DD2E0B65A4C405CACA8C1348652404F3DD2E0B65A4C40
29706	45890	74.675638000000006	74.704222000000001	57.153776000000001	57.144767000000002	Центральная	0103000020E61000000100000005000000D57B2AA73DAB524020459DB987924C40D57B2AA73DAB5240717495EEAE934C40EBC726F911AD5240717495EEAE934C40EBC726F911AD524020459DB987924C40D57B2AA73DAB524020459DB987924C40
29599	45937	74.501283999999998	74.524271999999996	57.065266000000001	57.053182	Центральная	0103000020E6100000010000000500000084807C0915A05240315EF3AACE864C4084807C0915A0524037C5E3A25A884C40588D25AC8DA1524037C5E3A25A884C40588D25AC8DA15240315EF3AACE864C4084807C0915A05240315EF3AACE864C40
29752	22290	74.258954000000003	74.293468000000004	57.265428	57.244961000000004	Восточная	0103000020E61000000100000005000000C74ACCB392905240D2E5CDE15A9F4C40C74ACCB392905240AAB8718BF9A14C400B9B012EC8925240AAB8718BF9A14C400B9B012EC8925240D2E5CDE15A9F4C40C74ACCB392905240D2E5CDE15A9F4C40
29466	23138	74.628764000000004	74.647825999999995	56.808447000000001	56.800305999999999	Горская	0103000020E61000000100000005000000BD395CAB3DA852407365506D70664C40BD395CAB3DA8524050C6F8307B674C40E7DF2EFB75A9524050C6F8307B674C40E7DF2EFB75A952407365506D70664C40BD395CAB3DA852407365506D70664C40
29970	53085	73.632424	73.764224999999996	54.608170000000001	54.531590999999999	Тополиная	0103000020E61000000100000005000000274D83A27968524089EC832C0B444B40274D83A2796852404434BA83D84D4B404772F90FE97052404434BA83D84D4B404772F90FE970524089EC832C0B444B40274D83A27968524089EC832C0B444B40
29419	19366	74.034132999999997	74.043870999999996	54.347639999999998	54.342506999999998	Лесная	0103000020E61000000100000005000000B8AD2D3C2F82524056D3F544D72B4B40B8AD2D3C2F8252400664AF777F2C4B408A8F4FC8CE8252400664AF777F2C4B408A8F4FC8CE82524056D3F544D72B4B40B8AD2D3C2F82524056D3F544D72B4B40
29406	18604	73.477626999999998	73.486682000000002	54.594442999999998	54.578656000000002	Центральная	0103000020E61000000100000005000000F12BD670915E52402DD15966114A4B40F12BD670915E5240062B4EB5164C4B40526342CC255F5240062B4EB5164C4B40526342CC255F52402DD15966114A4B40F12BD670915E52402DD15966114A4B40
29289	20159	73.607335000000006	73.637203999999997	54.700367	54.681252999999998	Мира	0103000020E61000000100000005000000D6AD9E93DE665240A4A65D4C33574B40D6AD9E93DE6652404C1938A0A5594B40583849F3C76852404C1938A0A5594B40583849F3C7685240A4A65D4C33574B40D6AD9E93DE665240A4A65D4C33574B40
29270	19345	74.062016999999997	74.079839000000007	54.415204000000003	54.404409999999999	Почтовая	0103000020E61000000100000005000000F2B22616F88352407216F6B4C3334B40F2B22616F88352408E95986725354B40817C09151C8552408E95986725354B40817C09151C8552407216F6B4C3334B40F2B22616F88352407216F6B4C3334B40
29255	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	площадь Победы	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29256	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Пролетарская	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29733	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Пионерская	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29258	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Пансионатная	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29128	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Лермонтова	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29673	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Ленина	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29401	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Клименко	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
74059	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Зеленая	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29800	18055	73.596079000000003	73.689171000000002	54.596764999999998	54.573186999999997	Гагарина	0103000020E6100000010000000500000046B588282666524005BF0D315E494B4046B5882826665240DF32A7CB624C4B408196AE601B6C5240DF32A7CB624C4B408196AE601B6C524005BF0D315E494B4046B588282666524005BF0D315E494B40
29278	19876	73.140497999999994	73.180940000000007	54.613211999999997	54.588856999999997	Улыбина	0103000020E61000000100000005000000D1C952EBFD485240A5828AAA5F4B4B40D1C952EBFD485240E3C116BB7D4E4B4073A25D85944B5240E3C116BB7D4E4B4073A25D85944B5240A5828AAA5F4B4B40D1C952EBFD485240A5828AAA5F4B4B40
29825	19576	74.097104999999999	74.109115000000003	54.499307999999999	54.493608000000002	Сосновка	0103000020E61000000100000005000000CCD1E3F736865240A185048C2E3F4B40CCD1E3F736865240CA501553E93F4B4032207BBDFB865240CA501553E93F4B4032207BBDFB865240A185048C2E3F4B40CCD1E3F736865240A185048C2E3F4B40
28669	18925	73.956913999999998	73.974153000000001	54.587338000000003	54.577857999999999	Березовая	0103000020E6100000010000000500000069C537143E7D5240B1DD3D40F7494B4069C537143E7D52405AD93EE42D4B4B403813D385587E52405AD93EE42D4B4B403813D385587E5240B1DD3D40F7494B4069C537143E7D5240B1DD3D40F7494B40
29209	52980	73.234965000000003	73.255339000000006	54.646984000000003	54.63832	переулок Сосновский	0103000020E6100000010000000500000019ADA3AA094F5240FD304278B4514B4019ADA3AA094F52408484285FD0524B402D996379575052408484285FD0524B402D99637957505240FD304278B4514B4019ADA3AA094F5240FD304278B4514B40
29697	19662	74.326822000000007	74.367022000000006	54.483195000000002	54.447904999999999	Совхозная	0103000020E610000001000000050000004167D2A6EA945240815B77F354394B404167D2A6EA9452409D4B7155D93D4B4067BAD7497D9752409D4B7155D93D4B4067BAD7497D975240815B77F354394B404167D2A6EA945240815B77F354394B40
29563	19567	74.062026000000003	74.109699000000006	54.543301999999997	54.524552999999997	Ленина	0103000020E610000001000000050000001C60E63BF883524064027E8D24434B401C60E63BF8835240FAEC80EB8A454B40DA59F44E05875240FAEC80EB8A454B40DA59F44E0587524064027E8D24434B401C60E63BF883524064027E8D24434B40
29277	19779	74.299531000000002	74.315961999999999	54.509152	54.498967999999998	 Зеленая	0103000020E61000000100000005000000D84812842B93524011E0F42EDE3F4B40D84812842B935240B4588AE42B414B40D731AEB838945240B4588AE42B414B40D731AEB83894524011E0F42EDE3F4B40D84812842B93524011E0F42EDE3F4B40
28668	18818	73.639709999999994	73.652959999999993	54.483891	54.476233000000001	Карбышева	0103000020E61000000100000005000000253B3602F16852405323F433F53C4B40253B3602F168524014EAE923F03D4B402766BD18CA69524014EAE923F03D4B402766BD18CA6952405323F433F53C4B40253B3602F16852405323F433F53C4B40
29555	19135	74.112718000000001	74.140502999999995	54.372155999999997	54.337054000000002	Школьная	0103000020E61000000100000005000000EAEA8EC536875240357EE195242B4B40EAEA8EC5368752404D81CCCEA22F4B405A7F4B00FE8852404D81CCCEA22F4B405A7F4B00FE885240357EE195242B4B40EAEA8EC536875240357EE195242B4B40
29558	19135	74.112718000000001	74.140502999999995	54.372155999999997	54.337054000000002	Майская	0103000020E61000000100000005000000EAEA8EC536875240357EE195242B4B40EAEA8EC5368752404D81CCCEA22F4B405A7F4B00FE8852404D81CCCEA22F4B405A7F4B00FE885240357EE195242B4B40EAEA8EC536875240357EE195242B4B40
28665	18662	73.505358000000001	73.527294999999995	54.669550000000001	54.643149999999999	Садовая	0103000020E6100000010000000500000068B114C95760524011363CBD52524B4068B114C957605240B6847CD0B3554B4009168733BF615240B6847CD0B3554B4009168733BF61524011363CBD52524B4068B114C95760524011363CBD52524B40
29959	18734	73.414664000000002	73.433654000000004	54.599966999999999	54.579726000000001	Центральная	0103000020E6100000010000000500000007B5DFDA895A524009522976344A4B4007B5DFDA895A5240F1D6F9B7CB4C4B40E5F1B4FCC05B5240F1D6F9B7CB4C4B40E5F1B4FCC05B524009522976344A4B4007B5DFDA895A524009522976344A4B40
29843	20310	73.285019000000005	73.311501000000007	54.468426999999998	54.446717	Пушкина	0103000020E6100000010000000500000046EF54C03D5252409BC8CC052E394B4046EF54C03D5252401DC87A6AF53B4B40F7EAE3A1EF5352401DC87A6AF53B4B40F7EAE3A1EF5352409BC8CC052E394B4046EF54C03D5252409BC8CC052E394B40
29266	20636	73.301494000000005	73.314942000000002	54.531303999999999	54.524887999999997	Центральная	0103000020E610000001000000050000002D7C7DAD4B5352400B08AD872F434B402D7C7DAD4B535240F31DFCC401444B40C2887D0228545240F31DFCC401444B40C2887D02285452400B08AD872F434B402D7C7DAD4B5352400B08AD872F434B40
29137	18991	73.567341999999996	73.596438000000006	54.443931999999997	54.421045999999997	Лизы Чайкиной	0103000020E610000001000000050000006CE9D1544F645240490ED8D5E4354B406CE9D1544F645240EDD286C3D2384B40DE054A0A2C665240EDD286C3D2384B40DE054A0A2C665240490ED8D5E4354B406CE9D1544F645240490ED8D5E4354B40
29963	18836	73.890249999999995	73.912896000000003	54.629106	54.613608999999997	Ленина	0103000020E61000000100000005000000E5D022DBF978524000C45DBD8A4E4B40E5D022DBF9785240D3DB9F8B86504B408D2958E36C7A5240D3DB9F8B86504B408D2958E36C7A524000C45DBD8A4E4B40E5D022DBF978524000C45DBD8A4E4B40
30063	20195	73.553381999999999	73.576693000000006	54.706994999999999	54.698728000000003	Тупик	0103000020E610000001000000050000007C0C569C6A63524056664AEB6F594B407C0C569C6A635240BFB7E9CF7E5A4B4042B5C189E8645240BFB7E9CF7E5A4B4042B5C189E864524056664AEB6F594B407C0C569C6A63524056664AEB6F594B40
29840	19986	72.947010000000006	72.956064999999995	54.558216000000002	54.551819999999999	Школьная	0103000020E610000001000000050000000ABFD4CF9B3C5240ADA3AA09A2464B400ABFD4CF9B3C52404E0D349F73474B406AF6402B303D52404E0D349F73474B406AF6402B303D5240ADA3AA09A2464B400ABFD4CF9B3C5240ADA3AA09A2464B40
29439	20483	73.165507000000005	73.181550999999999	54.455370000000002	54.444602000000003	переулок Зеленый	0103000020E610000001000000050000009510ACAA974A52403CDEE4B7E8384B409510ACAA974A52402ECA6C90493A4B4097E315889E4B52402ECA6C90493A4B4097E315889E4B52403CDEE4B7E8384B409510ACAA974A52403CDEE4B7E8384B40
29719	18566	73.748234999999994	73.782550999999998	54.654449	54.644108000000003	Школьная	0103000020E610000001000000050000003EAE0D15E36F5240C68B852172524B403EAE0D15E36F524030F31DFCC4534B40EF1CCA501572524030F31DFCC4534B40EF1CCA5015725240C68B852172524B403EAE0D15E36F5240C68B852172524B40
29133	18747	73.725795000000005	73.747032000000004	54.51811	54.505299000000001	Первомайская	0103000020E610000001000000050000006C26DF6C736E5240CBD93BA3AD404B406C26DF6C736E524083DDB06D51424B4031444E5FCF6F524083DDB06D51424B4031444E5FCF6F5240CBD93BA3AD404B406C26DF6C736E5240CBD93BA3AD404B40
28696	20273	73.517628999999999	73.533501999999999	54.764406999999999	54.758496000000001	Камышинская	0103000020E61000000100000005000000849D62D520615240CB129D6516614B40849D62D520615240AFEAAC16D8614B40709692E524625240AFEAAC16D8614B40709692E524625240CB129D6516614B40849D62D520615240CB129D6516614B40
29846	53044	73.243795000000006	73.258257999999998	54.528733000000003	54.515351000000003	Школьная	0103000020E610000001000000050000006AFB57569A4F5240FF7A8505F7414B406AFB57569A4F524072A8DF85AD434B408BFB8F4C8750524072A8DF85AD434B408BFB8F4C87505240FF7A8505F7414B406AFB57569A4F5240FF7A8505F7414B40
29560	19455	74.075896	74.102890000000002	54.362589	54.344679999999997	Энергетиков	0103000020E610000001000000050000006C79E57ADB845240EACA67791E2C4B406C79E57ADB845240D671FC50692E4B407845F0BF95865240D671FC50692E4B407845F0BF95865240EACA67791E2C4B406C79E57ADB845240EACA67791E2C4B40
29562	19455	74.075896	74.102890000000002	54.362589	54.344679999999997	Солнечная	0103000020E610000001000000050000006C79E57ADB845240EACA67791E2C4B406C79E57ADB845240D671FC50692E4B407845F0BF95865240D671FC50692E4B407845F0BF95865240EACA67791E2C4B406C79E57ADB845240EACA67791E2C4B40
29987	19974	73.120797999999994	73.141036999999997	54.561354000000001	54.548884999999999	Одесская	0103000020E6100000010000000500000005DB8827BB475240EA211ADD41464B4005DB8827BB47524049BDA772DA474B40A9A10DC00649524049BDA772DA474B40A9A10DC006495240EA211ADD41464B4005DB8827BB475240EA211ADD41464B40
29408	19019	73.542745999999994	73.561215000000004	54.527923000000001	54.513019999999997	Центральная	0103000020E610000001000000050000003A02B859BC625240D218ADA3AA414B403A02B859BC62524032E719FB92434B4094C151F2EA63524032E719FB92434B4094C151F2EA635240D218ADA3AA414B403A02B859BC625240D218ADA3AA414B40
29140	19096	73.399940000000001	73.414116000000007	54.485858	54.475678000000002	Центральная	0103000020E610000001000000050000002F17F19D985952409EB64604E33C4B402F17F19D98595240FF3F4E98303E4B40063065E0805A5240FF3F4E98303E4B40063065E0805A52409EB64604E33C4B402F17F19D985952409EB64604E33C4B40
29567	19676	74.350905999999995	74.370964999999998	54.434941000000002	54.415109999999999	Школьная	0103000020E61000000100000005000000177E703E759652400C1F115322354B40177E703E7596524043588D25AC374B407BBDFBE3BD97524043588D25AC374B407BBDFBE3BD9752400C1F115322354B40177E703E759652400C1F115322354B40
29568	19775	74.253519999999995	74.269546000000005	54.397213999999998	54.387757000000001	Лесная	0103000020E610000001000000050000007138F3AB39905240C5E57805A2314B407138F3AB39905240B5C189E8D7324B4021B1DD3D40915240B5C189E8D7324B4021B1DD3D40915240C5E57805A2314B407138F3AB39905240C5E57805A2314B40
29844	20405	73.263486	73.280662000000007	54.396563999999998	54.384894000000003	переулок Зеленый	0103000020E610000001000000050000000C3D62F4DC5052409C36E33444314B400C3D62F4DC505240AE62F19BC2324B40B8CEBF5DF6515240AE62F19BC2324B40B8CEBF5DF65152409C36E33444314B400C3D62F4DC5052409C36E33444314B40
29072	34423	54.052745000000002	54.094813000000002	58.479249000000003	58.469192999999997	Интернатовская	0103000020E6100000010000000500000086032159C0064B408D4127840E3C4D4086032159C0064B4003D2FE07583D4D402A1E17D5220C4B4003D2FE07583D4D402A1E17D5220C4B408D4127840E3C4D4086032159C0064B408D4127840E3C4D40
29935	17213	75.250641000000002	75.28819	56.827384000000002	56.813448999999999	Хмелевская	0103000020E610000001000000050000005A828C800AD0524061FBC9181F684C405A828C800AD05240E99D0AB8E7694C40314278B471D25240E99D0AB8E7694C40314278B471D2524061FBC9181F684C405A828C800AD0524061FBC9181F684C40
29248	17450	74.963620000000006	74.986069000000001	57.008660999999996	56.996676000000001	Заречная	0103000020E61000000100000005000000617138F3ABBD5240A35A4414937F4C40617138F3ABBD524015E0BBCD1B814C405DA626C11BBF524015E0BBCD1B814C405DA626C11BBF5240A35A4414937F4C40617138F3ABBD5240A35A4414937F4C40
29247	17522	74.891493999999994	74.914195000000007	57.058408999999997	57.044908	Школьная	0103000020E6100000010000000500000022A5D93C0EB9524015AA9B8BBF854C4022A5D93C0EB95240626534F279874C40ACCABE2B82BA5240626534F279874C40ACCABE2B82BA524015AA9B8BBF854C4022A5D93C0EB9524015AA9B8BBF854C40
29931	16984	75.379953	75.394514999999998	56.888632999999999	56.875830999999998	Центральная	0103000020E610000001000000050000001841632651D8524057E9EE3A1B704C401841632651D85240BC92E4B9BE714C4003B2D7BB3FD95240BC92E4B9BE714C4003B2D7BB3FD9524057E9EE3A1B704C401841632651D8524057E9EE3A1B704C40
29663	17511	75.113709999999998	75.129268999999994	56.980263000000001	56.971212000000001	Ишимская	0103000020E610000001000000050000009ACE4E0647C75240CBBDC0AC507C4C409ACE4E0647C752404B3D0B42797D4C40BED87BF145C852404B3D0B42797D4C40BED87BF145C85240CBBDC0AC507C4C409ACE4E0647C75240CBBDC0AC507C4C40
29544	17627	75.276773000000006	75.344127999999998	56.960883000000003	56.937314000000001	Советская	0103000020E610000001000000050000009DDA19A6B6D152409E0AB8E7F9774C409DDA19A6B6D152402524D236FE7A4C40D368723106D652402524D236FE7A4C40D368723106D652409E0AB8E7F9774C409DDA19A6B6D152409E0AB8E7F9774C40
29124	17627	75.276773000000006	75.344127999999998	56.960883000000003	56.937314000000001	Пролетарская	0103000020E610000001000000050000009DDA19A6B6D152409E0AB8E7F9774C409DDA19A6B6D152402524D236FE7A4C40D368723106D652402524D236FE7A4C40D368723106D652409E0AB8E7F9774C409DDA19A6B6D152409E0AB8E7F9774C40
29381	17627	75.276773000000006	75.344127999999998	56.960883000000003	56.937314000000001	Кропотова	0103000020E610000001000000050000009DDA19A6B6D152409E0AB8E7F9774C409DDA19A6B6D152402524D236FE7A4C40D368723106D652402524D236FE7A4C40D368723106D652409E0AB8E7F9774C409DDA19A6B6D152409E0AB8E7F9774C40
29943	17627	75.276773000000006	75.344127999999998	56.960883000000003	56.937314000000001	Избышева	0103000020E610000001000000050000009DDA19A6B6D152409E0AB8E7F9774C409DDA19A6B6D152402524D236FE7A4C40D368723106D652402524D236FE7A4C40D368723106D652409E0AB8E7F9774C409DDA19A6B6D152409E0AB8E7F9774C40
29390	17627	75.276773000000006	75.344127999999998	56.960883000000003	56.937314000000001	Горького	0103000020E610000001000000050000009DDA19A6B6D152409E0AB8E7F9774C409DDA19A6B6D152402524D236FE7A4C40D368723106D652402524D236FE7A4C40D368723106D652409E0AB8E7F9774C409DDA19A6B6D152409E0AB8E7F9774C40
29922	16509	75.938857999999996	75.952414000000005	57.087187999999998	57.072825999999999	Школьная	0103000020E61000000100000005000000A165DD3F16FC52403526C45C52894C40A165DD3F16FC5240444DF4F9288B4C402A90D959F4FC5240444DF4F9288B4C402A90D959F4FC52403526C45C52894C40A165DD3F16FC52403526C45C52894C40
29920	16606	75.923047999999994	75.945541000000006	56.949210999999998	56.931322999999999	Советская	0103000020E61000000100000005000000D828EB3713FB52409D81919735774C40D828EB3713FB52407100FDBE7F794C40BD0166BE83FC52407100FDBE7F794C40BD0166BE83FC52409D81919735774C40D828EB3713FB52409D81919735774C40
29384	17352	75.137497999999994	75.149032000000005	56.799033999999999	56.792645999999998	Павловская	0103000020E61000000100000005000000FC5069C4CCC8524011A7936C75654C40FC5069C4CCC852402F3201BF46664C40AE8383BD89C952402F3201BF46664C40AE8383BD89C9524011A7936C75654C40FC5069C4CCC8524011A7936C75654C40
29928	17052	75.191720000000004	75.206541999999999	57.038601	57.026321000000003	З.Максименко	0103000020E610000001000000050000004E7FF62345CC524059198D7C5E834C404E7FF62345CC5240E44BA8E0F0844C4007D0EFFB37CD5240E44BA8E0F0844C4007D0EFFB37CD524059198D7C5E834C404E7FF62345CC524059198D7C5E834C40
29374	16839	75.674465999999995	75.686466999999993	56.867483	56.854182999999999	Александровская	0103000020E61000000100000005000000E41071732AEB52404BE658DE556D4C40E41071732AEB5240016BD5AE096F4C4020B24813EFEB5240016BD5AE096F4C4020B24813EFEB52404BE658DE556D4C40E41071732AEB52404BE658DE556D4C40
29286	17295	75.141585000000006	75.158968000000002	56.845061999999999	56.836992000000002	Михайловская	0103000020E61000000100000005000000AB2688BA0FC95240BF81C98D226B4C40AB2688BA0FC95240D28BDAFD2A6C4C4013471E882CCA5240D28BDAFD2A6C4C4013471E882CCA5240BF81C98D226B4C40AB2688BA0FC95240BF81C98D226B4C40
73744	17295	75.141585000000006	75.158968000000002	56.845061999999999	56.836992000000002	Верхняя	0103000020E61000000100000005000000AB2688BA0FC95240BF81C98D226B4C40AB2688BA0FC95240D28BDAFD2A6C4C4013471E882CCA5240D28BDAFD2A6C4C4013471E882CCA5240BF81C98D226B4C40AB2688BA0FC95240BF81C98D226B4C40
29654	17111	75.139807000000005	75.163889999999995	57.059266000000001	57.050024000000001	Лилейская	0103000020E610000001000000050000001F300F99F2C85240EF01BA2F67864C401F300F99F2C85240E3E13D0796874C400D897B2C7DCA5240E3E13D0796874C400D897B2C7DCA5240EF01BA2F67864C401F300F99F2C85240EF01BA2F67864C40
29785	16759	75.831778999999997	75.854821000000001	56.929088	56.912080000000003	Центральная	0103000020E61000000100000005000000F99FFCDD3BF55240F8AA9509BF744C40F99FFCDD3BF55240938D075BEC764C40C7BB2363B5F65240938D075BEC764C40C7BB2363B5F65240F8AA9509BF744C40F99FFCDD3BF55240F8AA9509BF744C40
29382	17388	75.054485	75.081002999999995	56.947752999999999	56.933306999999999	Центральная	0103000020E61000000100000005000000D847A7AE7CC352405E10919A76774C40D847A7AE7CC35240CBD765F84F794C402FF834272FC55240CBD765F84F794C402FF834272FC552405E10919A76774C40D847A7AE7CC352405E10919A76774C40
76428	17134	75.120654000000002	75.138521999999995	57.014958999999998	57.003377	Центральная	0103000020E610000001000000050000006C088ECBB8C75240804754A86E804C406C088ECBB8C75240F3E32F2DEA814C40B2F1608BDDC85240F3E32F2DEA814C40B2F1608BDDC85240804754A86E804C406C088ECBB8C75240804754A86E804C40
29230	16700	75.711466999999999	75.752161000000001	56.945597999999997	56.922128000000001	Советская	0103000020E61000000100000005000000BA4BE2AC88ED5240EA5C514A08764C40BA4BE2AC88ED5240DD94F25A09794C40E814E46723F05240DD94F25A09794C40E814E46723F05240EA5C514A08764C40BA4BE2AC88ED5240EA5C514A08764C40
29924	16438	76.142353	76.165889000000007	56.926107000000002	56.917243999999997	Центральная	0103000020E6100000010000000500000033DFC14F1C095340E2395B4068754C4033DFC14F1C09534060CC96AC8A764C400971E5EC9D0A534060CC96AC8A764C400971E5EC9D0A5340E2395B4068754C4033DFC14F1C095340E2395B4068754C40
29649	16911	75.447586999999999	75.473899000000003	56.932585000000003	56.921376000000002	Кропотова	0103000020E6100000010000000500000058C7F143A5DC5240DFA815A6EF754C4058C7F143A5DC5240BEDEFDF15E774C40DBA6785C54DE5240BEDEFDF15E774C40DBA6785C54DE5240DFA815A6EF754C4058C7F143A5DC5240DFA815A6EF754C40
29798	17997	75.323063000000005	75.343203000000003	56.975264000000003	56.965079000000003	Набережная	0103000020E610000001000000050000000DE36E10ADD4524038876BB5877B4C400DE36E10ADD45240AB7B6473D57C4C40E738B709F7D55240AB7B6473D57C4C40E738B709F7D5524038876BB5877B4C400DE36E10ADD4524038876BB5877B4C40
29932	17200	75.258627000000004	75.290571	56.889906000000003	56.874625999999999	Новая	0103000020E6100000010000000500000035B742588DD052409B1DA9BEF36F4C4035B742588DD05240D1419770E8714C40A08A1BB798D25240D1419770E8714C40A08A1BB798D252409B1DA9BEF36F4C4035B742588DD052409B1DA9BEF36F4C40
29793	17609	74.881352000000007	74.899786000000006	57.029798999999997	57.023606999999998	Зеленая	0103000020E61000000100000005000000E910381268B85240747ADE8D05834C40E910381268B852400C3A2174D0834C4084D9041896B952400C3A2174D0834C4084D9041896B95240747ADE8D05834C40E910381268B85240747ADE8D05834C40
29106	16964	75.376548999999997	75.409632999999999	56.946883999999997	56.938763000000002	Озерная	0103000020E61000000100000005000000DB15FA6019D85240F1D8CF6229784C40DB15FA6019D85240868DB27E33794C403197546D37DA5240868DB27E33794C403197546D37DA5240F1D8CF6229784C40DB15FA6019D85240F1D8CF6229784C40
76469	60853	72.765199999999993	74.078194999999994	56.131596000000002	55.349198999999999	Кирова	0103000020E610000001000000050000008CB96B09F9305240E065868DB2AC4B408CB96B09F930524068244223D8104C407CED99250185524068244223D8104C407CED992501855240E065868DB2AC4B408CB96B09F9305240E065868DB2AC4B40
29078	52968	73.452760999999995	73.485128000000003	56.020229999999998	56.008319	Кооперативная	0103000020E61000000100000005000000DFF94509FA5C5240BC77D49810014C40DFF94509FA5C5240F4328AE596024C40EE974F560C5F5240F4328AE596024C40EE974F560C5F5240BC77D49810014C40DFF94509FA5C5240BC77D49810014C40
29414	14581	73.980513000000002	74.002216000000004	55.745220000000003	55.738014	Зеленая	0103000020E61000000100000005000000621399B9C07E5240BDFE243E77DE4B40621399B9C07E52409E29745E63DF4B40CAE1934E248052409E29745E63DF4B40CAE1934E24805240BDFE243E77DE4B40621399B9C07E5240BDFE243E77DE4B40
29915	53079	73.594920000000002	73.646096999999997	55.884141	55.869076	Центральная	0103000020E6100000010000000500000020EF552B1366524087DEE2E13DEF4B4020EF552B13665240C00644882BF14B40CC423BA759695240C00644882BF14B40CC423BA75969524087DEE2E13DEF4B4020EF552B1366524087DEE2E13DEF4B40
29842	14423	73.278353999999993	73.305851000000004	55.660988000000003	55.654192999999999	Заозерная	0103000020E610000001000000050000007DAD4B8DD0515240D522A298BCD34B407DAD4B8DD0515240348639419BD44B40BB9C121093535240348639419BD44B40BB9C121093535240D522A298BCD34B407DAD4B8DD0515240D522A298BCD34B40
29512	2425	73.325469999999996	73.359741	55.498815999999998	55.485663000000002	Подгорная	0103000020E6100000010000000500000010751F80D45452404AF086342ABE4B4010751F80D45452405B5CE333D9BF4B40F1811DFF055752405B5CE333D9BF4B40F1811DFF055752404AF086342ABE4B4010751F80D45452404AF086342ABE4B40
29348	15321	73.019001000000003	73.041179999999997	55.476934	55.470382000000001	Центральная	0103000020E61000000100000005000000D865F84F374152404450357A35BC4B40D865F84F37415240DC2C5E2C0CBD4B40F44F70B1A2425240DC2C5E2C0CBD4B40F44F70B1A24252404450357A35BC4B40D865F84F374152404450357A35BC4B40
29749	1926	73.472497000000004	73.520944	55.628256	55.593853000000003	Худенко	0103000020E61000000100000005000000529D0E643D5E5240D5D0066003CC4B40529D0E643D5E524005C24EB16AD04B4009C380255761524005C24EB16AD04B4009C3802557615240D5D0066003CC4B40529D0E643D5E5240D5D0066003CC4B40
29884	1926	73.472497000000004	73.520944	55.628256	55.593853000000003	Трактовая	0103000020E61000000100000005000000529D0E643D5E5240D5D0066003CC4B40529D0E643D5E524005C24EB16AD04B4009C380255761524005C24EB16AD04B4009C3802557615240D5D0066003CC4B40529D0E643D5E5240D5D0066003CC4B40
29214	1926	73.472497000000004	73.520944	55.628256	55.593853000000003	Октябрьская	0103000020E61000000100000005000000529D0E643D5E5240D5D0066003CC4B40529D0E643D5E524005C24EB16AD04B4009C380255761524005C24EB16AD04B4009C3802557615240D5D0066003CC4B40529D0E643D5E5240D5D0066003CC4B40
74024	60198	73.028908999999999	73.064581000000004	55.545126000000003	55.534184000000003	Центральная	0103000020E61000000100000005000000D86322A5D9415240F3052D2460C44B40D86322A5D9415240831953B0C6C54B405ABC581822445240831953B0C6C54B405ABC581822445240F3052D2460C44B40D86322A5D9415240F3052D2460C44B40
29528	15705	72.952184000000003	72.973780000000005	55.849316999999999	55.842095	Центральная	0103000020E6100000010000000500000091F12895F03C52400490DAC4C9EB4B4091F12895F03C5240EA77616BB6EC4B40EE5F5969523E5240EA77616BB6EC4B40EE5F5969523E52400490DAC4C9EB4B4091F12895F03C52400490DAC4C9EB4B40
29604	15032	72.805597000000006	72.812820000000002	55.580064999999998	55.568868000000002	Центральная 	0103000020E610000001000000050000005E30B8E68E335240D7DEA7AAD0C84B405E30B8E68E335240F146E6913FCA4B4039622D3E05345240F146E6913FCA4B4039622D3E05345240D7DEA7AAD0C84B405E30B8E68E335240D7DEA7AAD0C84B40
29501	15032	72.805597000000006	72.812820000000002	55.580064999999998	55.568868000000002	Центральная	0103000020E610000001000000050000005E30B8E68E335240D7DEA7AAD0C84B405E30B8E68E335240F146E6913FCA4B4039622D3E05345240F146E6913FCA4B4039622D3E05345240D7DEA7AAD0C84B405E30B8E68E335240D7DEA7AAD0C84B40
29683	15932	73.571267000000006	73.590276000000003	55.916198999999999	55.903201000000003	Центральная	0103000020E610000001000000050000002E9276A38F645240755B22179CF34B402E9276A38F6452405FD0420246F54B4047E7FC14C76552405FD0420246F54B4047E7FC14C7655240755B22179CF34B402E9276A38F645240755B22179CF34B40
29067	52966	72.765199999999993	74.078194999999994	56.131596000000002	55.349198999999999	Юбилейная	0103000020E610000001000000050000008CB96B09F9305240E065868DB2AC4B408CB96B09F930524068244223D8104C407CED99250185524068244223D8104C407CED992501855240E065868DB2AC4B408CB96B09F9305240E065868DB2AC4B40
29341	15159	73.181900999999996	73.197154999999995	55.581775	55.575280999999997	Зеленая	0103000020E6100000010000000500000005871744A44B52404D81CCCEA2C94B4005871744A44B5240B1506B9A77CA4B408B4F01309E4C5240B1506B9A77CA4B408B4F01309E4C52404D81CCCEA2C94B4005871744A44B52404D81CCCEA2C94B40
29497	14875	72.829277000000005	72.850333000000006	55.624535000000002	55.616563999999997	Зеленая	0103000020E61000000100000005000000CD94D6DF123552400AF2B391EBCE4B40CD94D6DF123552408B1A4CC3F0CF4B406A6D1ADB6B3652408B1A4CC3F0CF4B406A6D1ADB6B3652400AF2B391EBCE4B40CD94D6DF123552400AF2B391EBCE4B40
29091	15233	73.235234000000005	73.284435000000002	55.457684	55.430922000000002	Центральная	0103000020E61000000100000005000000113AE8120E4F52403F90BC7328B74B40113AE8120E4F524084F3A96395BA4B409EB5DB2E3452524084F3A96395BA4B409EB5DB2E345252403F90BC7328B74B40113AE8120E4F52403F90BC7328B74B40
29893	14865	72.952768000000006	72.985394999999997	55.674031999999997	55.661490999999998	Центральная	0103000020E61000000100000005000000392BA226FA3C524096CCB1BCABD44B40392BA226FA3C52408E3A3AAE46D64B4015A930B6103F52408E3A3AAE46D64B4015A930B6103F524096CCB1BCABD44B40392BA226FA3C524096CCB1BCABD44B40
29098	2032	73.605421000000007	73.623495000000005	55.648859999999999	55.638469999999998	Цветочная	0103000020E61000000100000005000000F2D3B837BF66524012BD8C62B9D14B40F2D3B837BF6652405ED72FD80DD34B400D8E9257E76752405ED72FD80DD34B400D8E9257E767524012BD8C62B9D14B40F2D3B837BF66524012BD8C62B9D14B40
30043	15926	73.441064999999995	73.466594999999998	55.815038000000001	55.806241	Новая	0103000020E61000000100000005000000419AB1683A5C5240E0D8B3E732E74B40419AB1683A5C5240A67F492A53E84B40895E46B1DC5D5240A67F492A53E84B40895E46B1DC5D5240E0D8B3E732E74B40419AB1683A5C5240E0D8B3E732E74B40
29709	16148	72.765199999999993	74.078194999999994	56.131596000000002	55.349198999999999	 Калмакульская	0103000020E610000001000000050000008CB96B09F9305240E065868DB2AC4B408CB96B09F930524068244223D8104C407CED99250185524068244223D8104C407CED992501855240E065868DB2AC4B408CB96B09F9305240E065868DB2AC4B40
29103	16352	73.399580999999998	73.422955000000002	55.535885	55.520986000000001	Светлая	0103000020E6100000010000000500000097C62FBC9259524041D653ABAFC24B4097C62FBC925952405FB532E197C44B40802BD9B1115B52405FB532E197C44B40802BD9B1115B524041D653ABAFC24B4097C62FBC9259524041D653ABAFC24B40
30041	15841	73.716255000000004	73.741461999999999	55.836216	55.826984000000003	Центральная	0103000020E610000001000000050000002D26361FD76D52405B28999CDAE94B402D26361FD76D52402B323A2009EB4B40834E081D746F52402B323A2009EB4B40834E081D746F52405B28999CDAE94B402D26361FD76D52405B28999CDAE94B40
29509	15798	73.479512999999997	73.502232000000006	55.780137000000003	55.770563000000003	Центральная	0103000020E6100000010000000500000070404B57B05E5240FB40F2CEA1E24B4070404B57B05E524025B37A87DBE34B404DC0AF912460524025B37A87DBE34B404DC0AF9124605240FB40F2CEA1E24B4070404B57B05E5240FB40F2CEA1E24B40
30033	14659	73.682011000000003	73.696133000000003	55.683559000000002	55.670752	Карбышева	0103000020E61000000100000005000000C9207711A66B524001DD9733DBD54B40C9207711A66B524078F17EDC7ED74B40A62A6D718D6C524078F17EDC7ED74B40A62A6D718D6C524001DD9733DBD54B40C9207711A66B524001DD9733DBD54B40
30027	14365	73.584615999999997	73.612347	55.607742999999999	55.599387	Садовая	0103000020E61000000100000005000000F92D3A596A655240E35295B6B8CC4B40F92D3A596A655240BCAFCA85CACD4B4070B378B130675240BCAFCA85CACD4B4070B378B130675240E35295B6B8CC4B40F92D3A596A655240E35295B6B8CC4B40
29092	2267	73.163109000000006	73.181164999999993	55.712513000000001	55.704636000000001	Центральная	0103000020E61000000100000005000000BB2BBB60704A5240C9CA2F8331DA4B40BB2BBB60704A5240C87C40A033DB4B40828B1535984B5240C87C40A033DB4B40828B1535984B5240C9CA2F8331DA4B40BB2BBB60704A5240C9CA2F8331DA4B40
29916	16046	73.760110999999995	73.775193999999999	56.013658	56.005006999999999	Центральная	0103000020E610000001000000050000001C959BA8A570524023A0C211A4004C401C959BA8A570524015AA9B8BBF014C408C834BC79C71524015AA9B8BBF014C408C834BC79C71524023A0C211A4004C401C959BA8A570524023A0C211A4004C40
29637	53026	73.080220999999995	73.091791000000001	55.863232000000004	55.853208000000002	Центральная	0103000020E61000000100000005000000F4DC425722455240C15774EB35ED4B40F4DC4257224552402B6EDC627EEE4B404CC45BE7DF4552402B6EDC627EEE4B404CC45BE7DF455240C15774EB35ED4B40F4DC425722455240C15774EB35ED4B40
29204	15279	73.134739999999994	73.174256999999997	55.402239999999999	55.384774	Почтовая	0103000020E61000000100000005000000A25D85949F485240F12C414640B14B40A25D85949F4852404F92AE997CB34B405706D506274B52404F92AE997CB34B405706D506274B5240F12C414640B14B40A25D85949F485240F12C414640B14B40
29881	53048	73.158580999999998	73.170062000000001	55.737527	55.728164999999997	Центральная	0103000020E610000001000000050000001631EC30264A5240C18BBE8234DD4B401631EC30264A52406075E44867DE4B40B612BA4BE24A52406075E44867DE4B40B612BA4BE24A5240C18BBE8234DD4B401631EC30264A5240C18BBE8234DD4B40
29774	16098	73.297182000000006	73.322146000000004	55.949661999999996	55.940854999999999	Молодежная	0103000020E610000001000000050000006FBDA6070553524098A3C7EF6DF84B406FBDA60705535240812040868EF94B4062A2410A9E545240812040868EF94B4062A2410A9E54524098A3C7EF6DF84B406FBDA6070553524098A3C7EF6DF84B40
29283	52984	73.059470000000005	73.112640999999996	55.646242999999998	55.626995000000001	Саргатская	0103000020E61000000100000005000000F645425BCE435240B5E0455F41D04B40F645425BCE4352406C223317B8D24B4014CC9882354752406C223317B8D24B4014CC988235475240B5E0455F41D04B40F645425BCE435240B5E0455F41D04B40
29883	49168	73.799547000000004	73.856869000000003	55.723424999999999	55.703591000000003	1 Мая	0103000020E610000001000000050000005B272EC72B735240466117450FDA4B405B272EC72B735240ED0DBE3099DC4B4033FD12F1D6765240ED0DBE3099DC4B4033FD12F1D6765240466117450FDA4B405B272EC72B735240466117450FDA4B40
29101	16219	73.276268999999999	73.290120999999999	55.575149000000003	55.562967999999998	Центральная	0103000020E6100000010000000500000083F92B64AE515240E658DE550FC84B4083F92B64AE515240DFA9807B9EC94B4080B8AB5791525240DFA9807B9EC94B4080B8AB5791525240E658DE550FC84B4083F92B64AE515240E658DE550FC84B40
9830	40328	73.257853999999995	73.282377999999994	55.862484000000002	55.854810000000001	Центральная	0103000020E61000000100000005000000234910AE805052409A25016A6AED4B40234910AE8050524061A92EE065EE4B4008C72C7B1252524061A92EE065EE4B4008C72C7B125252409A25016A6AED4B40234910AE805052409A25016A6AED4B40
29179	52855	73.446805999999995	73.459417999999999	53.577454000000003	53.566766000000001	Мартыненко	0103000020E61000000100000005000000056A3178985C52400C3ECDC98BC84A40056A3178985C5240E2783E03EAC94A40664CC11A675D5240E2783E03EAC94A40664CC11A675D52400C3ECDC98BC84A40056A3178985C52400C3ECDC98BC84A40
29607	52844	74.038821999999996	74.077152999999996	53.673806999999996	53.657172000000003	Кооперативная	0103000020E610000001000000050000006117450F7C82524068EC4B361ED44A406117450F7C8252406E68CA4E3FD64A4073F22213F08452406E68CA4E3FD64A4073F22213F084524068EC4B361ED44A406117450F7C82524068EC4B361ED44A40
29435	52866	73.461806999999993	73.489879999999999	53.780543000000002	53.769432999999999	25лет Совхоза	0103000020E610000001000000050000001684F23E8E5D524049BBD1C77CE24A401684F23E8E5D5240950F41D5E8E34A40BABDA4315A5F5240950F41D5E8E34A40BABDA4315A5F524049BBD1C77CE24A401684F23E8E5D524049BBD1C77CE24A40
29192	52868	73.547281999999996	73.556821999999997	53.779240000000001	53.771498000000001	Школьная	0103000020E6100000010000000500000020EC14AB06635240F7764B72C0E24A4020EC14AB0663524016DEE522BEE34A405FECBDF8A263524016DEE522BEE34A405FECBDF8A2635240F7764B72C0E24A4020EC14AB06635240F7764B72C0E24A40
73914	60147	73.708179000000001	73.719506999999993	53.741058000000002	53.730288000000002	Магистральная	0103000020E61000000100000005000000B22D03CE526D5240A454C2137ADD4A40B22D03CE526D5240373811FDDADE4A408E8F16670C6E5240373811FDDADE4A408E8F16670C6E5240A454C2137ADD4A40B22D03CE526D5240A454C2137ADD4A40
29462	12969	74.396620999999996	74.409216000000001	53.791092999999996	53.785406000000002	Вторая	0103000020E6100000010000000500000009FA0B3D62995240850A0E2F88E44A4009FA0B3D62995240198C118942E54A40FF3F4E98309A5240198C118942E54A40FF3F4E98309A5240850A0E2F88E44A4009FA0B3D62995240850A0E2F88E44A40
30132	53116	73.450821000000005	73.472928999999993	53.844478000000002	53.829155	Зеленая	0103000020E6100000010000000500000067D65240DA5C52404E2844C021EA4A4067D65240DA5C52408318E8DA17EC4A401E15FF77445E52408318E8DA17EC4A401E15FF77445E52404E2844C021EA4A4067D65240DA5C52404E2844C021EA4A40
30115	53110	73.874816999999993	73.903831999999994	53.777206999999997	53.766649000000001	Титова	0103000020E61000000100000005000000073F7100FD7752406C41EF8D21E24A40073F7100FD775240739CDB847BE34A4002452C62D8795240739CDB847BE34A4002452C62D87952406C41EF8D21E24A40073F7100FD7752406C41EF8D21E24A40
30156	53099	73.855430999999996	73.915520000000001	53.791912000000004	53.765894000000003	Северная	0103000020E61000000100000005000000033FAA61BF765240F01989D008E24A40033FAA61BF765240ADA7565F5DE54A405FB532E1977A5240ADA7565F5DE54A405FB532E1977A5240F01989D008E24A40033FAA61BF765240F01989D008E24A40
30089	53099	73.855430999999996	73.915520000000001	53.791912000000004	53.765894000000003	Ленина	0103000020E61000000100000005000000033FAA61BF765240F01989D008E24A40033FAA61BF765240ADA7565F5DE54A405FB532E1977A5240ADA7565F5DE54A405FB532E1977A5240F01989D008E24A40033FAA61BF765240F01989D008E24A40
30137	53119	74.037752999999995	74.049216000000001	53.781346999999997	53.771172999999997	Тельмана	0103000020E61000000100000005000000DB148F8B6A8252407347FFCBB5E24A40DB148F8B6A825240F2E9B12D03E44A40289CDD5A26835240F2E9B12D03E44A40289CDD5A268352407347FFCBB5E24A40DB148F8B6A8252407347FFCBB5E24A40
30114	49460	74.033432000000005	74.054974000000001	53.856296	53.84442	Степная	0103000020E61000000100000005000000F4A8F8BF238252404E0B5EF415EC4A40F4A8F8BF238252400AD9791B9BED4A405708ABB1848352400AD9791B9BED4A405708ABB1848352404E0B5EF415EC4A40F4A8F8BF238252404E0B5EF415EC4A40
76487	60863	73.726065000000006	73.732416000000001	53.838729999999998	53.834207999999997	Центральная	0103000020E610000001000000050000004C7155D9776E5240E107E753C7EA4A404C7155D9776E5240481630815BEB4A404CC45BE7DF6E5240481630815BEB4A404CC45BE7DF6E5240E107E753C7EA4A404C7155D9776E5240E107E753C7EA4A40
29436	46104	73.782308	73.795773999999994	53.928370999999999	53.923318000000002	Главная	0103000020E610000001000000050000008CD992551172524071E7C2482FF64A408CD992551172524004C765DCD4F64A40744012F6ED72524004C765DCD4F64A40744012F6ED72524071E7C2482FF64A408CD992551172524071E7C2482FF64A40
28689	51913	73.798648999999997	73.814621000000002	53.733777000000003	53.720565999999998	Школьная	0103000020E61000000100000005000000EBFEB1101D735240054EB6813BDC4A40EBFEB1101D7352404CC79C67ECDD4A40A1681EC0227452404CC79C67ECDD4A40A1681EC022745240054EB6813BDC4A40EBFEB1101D735240054EB6813BDC4A40
73894	60140	74.444528000000005	74.466527999999997	53.867023000000003	53.861776999999996	Сибирская	0103000020E61000000100000005000000018A9125739C5240F5B86FB54EEE4A40018A9125739C52409EF0129CFAEE4A40C5AA4198DB9D52409EF0129CFAEE4A40C5AA4198DB9D5240F5B86FB54EEE4A40018A9125739C5240F5B86FB54EEE4A40
29985	52850	73.566838000000004	73.583646000000002	53.591721	53.583478999999997	Школьная	0103000020E610000001000000050000005308E412476452408E739B70AFCA4A405308E412476452409FAD8383BDCB4A403D9CC0745A6552409FAD8383BDCB4A403D9CC0745A6552408E739B70AFCA4A405308E412476452408E739B70AFCA4A40
76403	60813	74.238472999999999	74.279624999999996	53.655026999999997	53.635672	Ленина	0103000020E61000000100000005000000A8FE4124438F5240D07D39B35DD14A40A8FE4124438F52409D7FBBECD7D34A4037894160E59152409D7FBBECD7D34A4037894160E5915240D07D39B35DD14A40A8FE4124438F5240D07D39B35DD14A40
30122	53112	74.038634000000002	74.058001000000004	53.815181000000003	53.808391999999998	Степная	0103000020E61000000100000005000000E0A0BDFA788252408C2C996379E74A40E0A0BDFA7882524009A9DBD957E84A40A988D349B683524009A9DBD957E84A40A988D349B68352408C2C996379E74A40E0A0BDFA788252408C2C996379E74A40
29991	53086	73.932497999999995	73.946924999999993	53.934091000000002	53.928572000000003	Школьная	0103000020E610000001000000050000007765170CAE7B52409CFD8172DBF64A407765170CAE7B5240753E3C4B90F74A40F2B0506B9A7C5240753E3C4B90F74A40F2B0506B9A7C52409CFD8172DBF64A407765170CAE7B52409CFD8172DBF64A40
76451	60839	74.231071	74.243485000000007	53.913454000000002	53.906171999999998	Молодежная	0103000020E61000000100000005000000750305DEC98E52408446B071FDF34A40750305DEC98E52404033880FECF44A4043041C42958F52404033880FECF44A4043041C42958F52408446B071FDF34A40750305DEC98E52408446B071FDF34A40
30116	53111	73.747857999999994	73.781481999999997	53.964860999999999	53.943435000000001	Набережная	0103000020E610000001000000050000005303CDE7DC6F52406D73637AC2F84A405303CDE7DC6F5240CA17B49080FB4A40691A14CD03725240CA17B49080FB4A40691A14CD037252406D73637AC2F84A405303CDE7DC6F52406D73637AC2F84A40
29951	53082	73.744964999999993	73.756140000000002	53.809493000000003	53.800925999999997	60 лет Победы	0103000020E6100000010000000500000089EAAD81AD6F52400F4240BE84E64A4089EAAD81AD6F5240A4AB74779DE74A40A3CC069964705240A4AB74779DE74A40A3CC0699647052400F4240BE84E64A4089EAAD81AD6F52400F4240BE84E64A40
29718	46185	71.542952	71.557792000000006	54.292656999999998	54.277330999999997	Труда	0103000020E610000001000000050000000FD3BEB9BFE251405F950B957F234B400FD3BEB9BFE2514005F9D9C875254B401C7E37DDB2E3514005F9D9C875254B401C7E37DDB2E351405F950B957F234B400FD3BEB9BFE251405F950B957F234B40
29992	45543	71.841425999999998	71.863524999999996	54.465648000000002	54.451821000000002	Юбилейная	0103000020E61000000100000005000000430070ECD9F55140B1524145D5394B40430070ECD9F5514052B9895A9A3B4B40D1915CFE43F7514052B9895A9A3B4B40D1915CFE43F75140B1524145D5394B40430070ECD9F55140B1524145D5394B40
29300	46509	71.528156999999993	71.549456000000006	54.582439000000001	54.569110999999999	Марии Долиной	0103000020E61000000100000005000000D2890453CDE151409D6516A1D8484B40D2890453CDE151401D75745C8D4A4B40D3A57F492AE351401D75745C8D4A4B40D3A57F492AE351409D6516A1D8484B40D2890453CDE151409D6516A1D8484B40
29044	11812	71.563558999999998	71.577798000000001	54.545940000000002	54.532349000000004	Центральная	0103000020E610000001000000050000007497C45911E451407787140324444B407497C45911E4514004CAA65CE1454B406E6C76A4FAE4514004CAA65CE1454B406E6C76A4FAE451407787140324444B407497C45911E451407787140324444B40
29999	45678	71.571060000000003	71.591722000000004	54.443705999999999	54.440182999999998	Озерная	0103000020E6100000010000000500000071033E3F8CE45140A9A0A2EA57384B4071033E3F8CE45140FD84B35BCB384B40B894F3C5DEE55140FD84B35BCB384B40B894F3C5DEE55140A9A0A2EA57384B4071033E3F8CE45140A9A0A2EA57384B40
29727	11983	71.233796999999996	71.256164999999996	54.254035999999999	54.245902999999998	Школьная	0103000020E61000000100000005000000C939B187F6CE5140807EDFBF791F4B40C939B187F6CE5140DA006C4084204B404F58E20165D05140DA006C4084204B404F58E20165D05140807EDFBF791F4B40C939B187F6CE5140807EDFBF791F4B40
29339	52990	71.265382000000002	71.305859999999996	54.484833000000002	54.476101999999997	Победы	0103000020E610000001000000050000009DBCC804FCD05140B4C70BE9F03C4B409DBCC804FCD05140C382FB010F3E4B40E449D23593D35140C382FB010F3E4B40E449D23593D35140B4C70BE9F03C4B409DBCC804FCD05140B4C70BE9F03C4B40
29178	12610	71.405356999999995	71.418688000000003	54.501832999999998	54.491501	 Юбилейная	0103000020E61000000100000005000000198D7C5EF1D95140C4793881E93E4B40198D7C5EF1D95140DB8651103C404B4092CEC0C8CBDA5140DB8651103C404B4092CEC0C8CBDA5140C4793881E93E4B40198D7C5EF1D95140C4793881E93E4B40
29293	11170	71.367582999999996	71.390382000000002	54.390445999999997	54.381968000000001	Школьная	0103000020E6100000010000000500000032E4D87A86D751402C0FD253E4304B4032E4D87A86D75140506D7022FA314B409DBCC804FCD85140506D7022FA314B409DBCC804FCD851402C0FD253E4304B4032E4D87A86D751402C0FD253E4304B40
29746	46708	71.734077999999997	71.787796999999998	54.385586000000004	54.346155000000003	Пушкина	0103000020E61000000100000005000000A3AD4A22FBEE5140672C9ACE4E2C4B40A3AD4A22FBEE5140D2E5CDE15A314B40C3B81B446BF25140D2E5CDE15A314B40C3B81B446BF25140672C9ACE4E2C4B40A3AD4A22FBEE5140672C9ACE4E2C4B40
29315	46708	71.734077999999997	71.787796999999998	54.385586000000004	54.346155000000003	Победы	0103000020E61000000100000005000000A3AD4A22FBEE5140672C9ACE4E2C4B40A3AD4A22FBEE5140D2E5CDE15A314B40C3B81B446BF25140D2E5CDE15A314B40C3B81B446BF25140672C9ACE4E2C4B40A3AD4A22FBEE5140672C9ACE4E2C4B40
29295	46452	71.708044999999998	71.738919999999993	54.494272000000002	54.482844999999998	Центральная	0103000020E610000001000000050000002AC6F99B50ED5140C0046EDDCD3D4B402AC6F99B50ED51400DAA0D4E443F4B400F971C774AEF51400DAA0D4E443F4B400F971C774AEF5140C0046EDDCD3D4B402AC6F99B50ED5140C0046EDDCD3D4B40
28913	46561	71.661934000000002	71.692691999999994	54.277414999999998	54.256785999999998	Победы	0103000020E6100000010000000500000012876C205DEA51400B09185DDE204B4012876C205DEA5140BD35B05582234B40DA8CD31055EC5140BD35B05582234B40DA8CD31055EC51400B09185DDE204B4012876C205DEA51400B09185DDE204B40
29619	12547	71.246741999999998	71.267968999999994	54.520555999999999	54.512633000000001	Школьная	0103000020E610000001000000050000002D23F59ECACF5140D9EC48F59D414B402D23F59ECACF514048DE3994A1424B40E0D5726726D1514048DE3994A1424B40E0D5726726D15140D9EC48F59D414B402D23F59ECACF5140D9EC48F59D414B40
29820	11124	71.557658000000004	71.579954000000001	54.354199999999999	54.340921999999999	Горького	0103000020E6100000010000000500000094162EABB0E35140533E0455A32B4B4094162EABB0E35140211FF46C562D4B40CDCB61F71DE55140211FF46C562D4B40CDCB61F71DE55140533E0455A32B4B4094162EABB0E35140533E0455A32B4B40
29442	46310	71.975446000000005	72.006733999999994	54.464508000000002	54.454479999999997	Центральная	0103000020E61000000100000005000000E6400FB56DFE5140D15790662C3A4B40E6400FB56DFE51407D5D86FF743B4B405C7171546E0052407D5D86FF743B4B405C7171546E005240D15790662C3A4B40E6400FB56DFE5140D15790662C3A4B40
29145	46525	71.104519999999994	71.124041000000005	54.240488999999997	54.229948	Ленина	0103000020E61000000100000005000000C971A774B0C65140EBE3A1EF6E1D4B40C971A774B0C651401C06F357C81E4B403E97A949F0C751401C06F357C81E4B403E97A949F0C75140EBE3A1EF6E1D4B40C971A774B0C65140EBE3A1EF6E1D4B40
29520	12516	71.228048000000001	71.252274999999997	54.443680000000001	54.436228999999997	Центральная	0103000020E61000000100000005000000C47AA35698CE51408C48145AD6374B40C47AA35698CE5140D4F19881CA384B404CA60A4625D05140D4F19881CA384B404CA60A4625D051408C48145AD6374B40C47AA35698CE51408C48145AD6374B40
30023	12464	71.440867999999995	71.458905999999999	54.476531000000001	54.468682999999999	Почтовая	0103000020E6100000010000000500000096766A2E37DC51407898F6CDFD3B4B4096766A2E37DC5140DD43C2F7FE3C4B400B7C45B75EDD5140DD43C2F7FE3C4B400B7C45B75EDD51407898F6CDFD3B4B4096766A2E37DC51407898F6CDFD3B4B40
29734	46633	71.486592000000002	71.503461999999999	54.235900000000001	54.225442999999999	Школьная	0103000020E61000000100000005000000B29FC55224DF51405A0EF450DB1C4B40B29FC55224DF51402E90A0F8311E4B40D731AEB838E051402E90A0F8311E4B40D731AEB838E051405A0EF450DB1C4B40B29FC55224DF51405A0EF450DB1C4B40
29586	1916	71.944794999999999	71.968349000000003	54.422434000000003	54.408203999999998	Школьный переулок	0103000020E61000000100000005000000289B728577FC5140560C570740344B40289B728577FC5140F75B3B5112364B405187156EF9FD5140F75B3B5112364B405187156EF9FD5140560C570740344B40289B728577FC5140560C570740344B40
29119	46416	71.667233999999993	71.695863000000003	54.577455999999998	54.560132000000003	Ленина	0103000020E61000000100000005000000DF313CF6B3EA5140B7B8C667B2474B40DF313CF6B3EA514082700514EA494B40C6DFF60489EC514082700514EA494B40C6DFF60489EC5140B7B8C667B2474B40DF313CF6B3EA5140B7B8C667B2474B40
29995	11624	71.936531000000002	71.961440999999994	54.315463000000001	54.303674999999998	Школьная	0103000020E610000001000000050000002C2CB81FF0FB514070CE88D2DE264B402C2CB81FF0FB51408D0C721761284B402502D53F88FD51408D0C721761284B402502D53F88FD514070CE88D2DE264B402C2CB81FF0FB514070CE88D2DE264B40
29855	46372	72.014622000000003	72.037394000000006	54.383017000000002	54.377737000000003	Школьная	0103000020E6100000010000000500000056F31C91EF0052409DBE9EAF59304B4056F31C91EF005240F16778B306314B4044C4CDA964025240F16778B306314B4044C4CDA9640252409DBE9EAF59304B4056F31C91EF0052409DBE9EAF59304B40
28699	46325	72.027117000000004	72.066130999999999	54.293917999999998	54.266705000000002	50 лет Октября	0103000020E610000001000000050000009A0AF148BC0152400057B26323224B409A0AF148BC01524055DAE21A9F254B401D90847D3B04524055DAE21A9F254B401D90847D3B0452400057B26323224B409A0AF148BC0152400057B26323224B40
29265	46071	71.419308000000001	71.432855000000004	54.223269000000002	54.214945999999998	Мира	0103000020E61000000100000005000000E0BC38F1D5DA5140F833BC59831B4B40E0BC38F1D5DA5140F69A1E14941C4B403F3A75E5B3DB5140F69A1E14941C4B403F3A75E5B3DB5140F833BC59831B4B40E0BC38F1D5DA5140F833BC59831B4B40
29821	10955	71.365409	71.390112999999999	54.219473999999998	54.212819000000003	Центральная	0103000020E61000000100000005000000802A6EDC62D75140D57B2AA73D1B4B40802A6EDC62D7514041295AB9171C4B40A52F849CF7D8514041295AB9171C4B40A52F849CF7D85140D57B2AA73D1B4B40802A6EDC62D75140D57B2AA73D1B4B40
29971	11557	71.945639999999997	71.970910000000003	54.357663000000002	54.351334999999999	Центральная	0103000020E610000001000000050000008672A25D85FC51405778978BF82C4B408672A25D85FC5140A0FEB3E6C72D4B400057B26323FE5140A0FEB3E6C72D4B400057B26323FE51405778978BF82C4B408672A25D85FC51405778978BF82C4B40
29726	46616	71.760039000000006	71.786557000000002	54.307206000000001	54.288426999999999	Центральная	0103000020E61000000100000005000000D02B9E7AA4F0514046240A2DEB244B40D02B9E7AA4F051404791B58652274B4027DC2BF356F251404791B58652274B4027DC2BF356F2514046240A2DEB244B40D02B9E7AA4F0514046240A2DEB244B40
29263	46111	71.480976999999996	71.520970000000005	54.339269000000002	54.317746999999997	Ленина	0103000020E610000001000000050000003448C153C8DE514078B306EFAB284B403448C153C8DE5140F8C5A52A6D2B4B409E0C8E9257E15140F8C5A52A6D2B4B409E0C8E9257E1514078B306EFAB284B403448C153C8DE514078B306EFAB284B40
29811	45987	71.341137000000003	71.373583999999994	54.295358	54.274943999999998	Садовая	0103000020E61000000100000005000000289D4830D5D551409F1D705D31234B40289D4830D5D55140554E7B4ACE254B40C493DDCCE8D75140554E7B4ACE254B40C493DDCCE8D751409F1D705D31234B40289D4830D5D551409F1D705D31234B40
29592	53021	71.231281999999993	71.25197	54.314248999999997	54.308571000000001	Садовая	0103000020E61000000100000005000000D2890453CDCE51403CBF28417F274B40D2890453CDCE51407DE6AC4F39284B40AE64C74620D051407DE6AC4F39284B40AE64C74620D051403CBF28417F274B40D2890453CDCE51403CBF28417F274B40
29055	52963	71.000108999999995	72.218584000000007	54.685896	54.094582000000003	Лесная	0103000020E61000000100000005000000DBDB2DC901C05140286552431B0C4B40DBDB2DC901C05140863AAC70CB574B4073DBBE47FD0D5240863AAC70CB574B4073DBBE47FD0D5240286552431B0C4B40DBDB2DC901C05140286552431B0C4B40
29848	11261	71.000108999999995	72.218584000000007	54.685896	54.094582000000003	Школьная	0103000020E61000000100000005000000DBDB2DC901C05140286552431B0C4B40DBDB2DC901C05140863AAC70CB574B4073DBBE47FD0D5240863AAC70CB574B4073DBBE47FD0D5240286552431B0C4B40DBDB2DC901C05140286552431B0C4B40
29576	53019	71.000108999999995	72.218584000000007	54.685896	54.094582000000003	Ленина	0103000020E61000000100000005000000DBDB2DC901C05140286552431B0C4B40DBDB2DC901C05140863AAC70CB574B4073DBBE47FD0D5240863AAC70CB574B4073DBBE47FD0D5240286552431B0C4B40DBDB2DC901C05140286552431B0C4B40
29428	11757	71.579451000000006	71.595099000000005	54.521647999999999	54.512931000000002	Центральная	0103000020E610000001000000050000009CA8A5B915E55140630D17B9A7414B409CA8A5B915E551400C03965CC5424B4078B81D1A16E651400C03965CC5424B4078B81D1A16E65140630D17B9A7414B409CA8A5B915E55140630D17B9A7414B40
29259	10851	71.335378000000006	71.352635000000006	54.240841000000003	54.227705999999998	Труда	0103000020E61000000100000005000000117349D576D551402E8D5F78251D4B40117349D576D551409A44BDE0D31E4B40331B649291D651409A44BDE0D31E4B40331B649291D651402E8D5F78251D4B40117349D576D551402E8D5F78251D4B40
29858	46588	71.615662	71.628499000000005	54.224716999999998	54.220489999999998	Солнечная	0103000020E61000000100000005000000F5D8960167E751402A8C2D04391C4B40F5D8960167E7514078EDD286C31C4B4066A4DE5339E8514078EDD286C31C4B4066A4DE5339E851402A8C2D04391C4B40F5D8960167E751402A8C2D04391C4B40
29554	9818	73.554343000000003	73.572991999999999	54.316482000000001	54.306117999999998	Центральная	0103000020E610000001000000050000000FF10F5B7A635240C45BE7DF2E274B400FF10F5B7A635240E7E26F7B82284B40A837A3E6AB645240E7E26F7B82284B40A837A3E6AB645240C45BE7DF2E274B400FF10F5B7A635240C45BE7DF2E274B40
29142	10135	73.676586	73.700920999999994	54.339500000000001	54.329251999999997	Центральная	0103000020E610000001000000050000009DBB5D2F4D6B52404012F6ED242A4B409DBB5D2F4D6B5240FA7E6ABC742B4B401805C1E3DB6C5240FA7E6ABC742B4B401805C1E3DB6C52404012F6ED242A4B409DBB5D2F4D6B52404012F6ED242A4B40
29965	9340	73.501898999999995	73.522552000000005	54.116889999999998	54.103794999999998	Советская	0103000020E6100000010000000500000049B9FB1C1F605240813E9127490D4B4049B9FB1C1F6052405E9D6340F60E4B40679DF17D716152405E9D6340F60E4B40679DF17D71615240813E9127490D4B4049B9FB1C1F605240813E9127490D4B40
29961	9554	73.376827000000006	73.410217000000003	54.033262999999998	54.015405999999999	Новая	0103000020E61000000100000005000000FD4FFEEE1D585240C214E5D2F8014B40FD4FFEEE1D5852405B9544F641044B40D9D0CDFE405A52405B9544F641044B40D9D0CDFE405A5240C214E5D2F8014B40FD4FFEEE1D585240C214E5D2F8014B40
29559	10325	74.010363999999996	74.032480000000007	54.015787000000003	53.998874999999998	Центральная	0103000020E610000001000000050000009143C4CDA980524060E5D022DBFF4A409143C4CDA9805240DA59F44E05024B408B71FE2614825240DA59F44E05024B408B71FE261482524060E5D022DBFF4A409143C4CDA980524060E5D022DBFF4A40
29153	9719	73.513101000000006	73.540141000000006	54.276389999999999	54.263033999999998	20 Лет Победы	0103000020E61000000100000005000000E0A293A5D660524037DE1D19AB214B40E0A293A5D660524081785DBF60234B40A48E8EAB9162524081785DBF60234B40A48E8EAB9162524037DE1D19AB214B40E0A293A5D660524037DE1D19AB214B40
29421	10613	73.912654000000003	73.924942999999999	54.400221999999999	54.391331999999998	Центральная	0103000020E6100000010000000500000012A452EC687A52406BF0BE2A17324B4012A452EC687A5240E29178793A334B4081EA1F44327B5240E29178793A334B4081EA1F44327B52406BF0BE2A17324B4012A452EC687A52406BF0BE2A17324B40
29170	10464	73.811081000000001	73.849511000000007	54.366695999999997	54.353516999999997	Школьная	0103000020E610000001000000050000000C5A48C0E87352403ECA880B402D4B400C5A48C0E873524079C9FFE4EF2E4B40E8A562635E76524079C9FFE4EF2E4B40E8A562635E7652403ECA880B402D4B400C5A48C0E87352403ECA880B402D4B40
29975	10426	73.873613000000006	73.881445999999997	54.049156000000004	54.043711000000002	Школьная	0103000020E6100000010000000500000012178046E9775240DCBC715298054B4012178046E97752407B336ABE4A064B4029CC7B9C697852407B336ABE4A064B4029CC7B9C69785240DCBC715298054B4012178046E9775240DCBC715298054B40
29968	9952	73.747776999999999	73.756185000000002	54.268802999999998	54.258270000000003	Клубная	0103000020E61000000100000005000000DDEC0F94DB6F5240DBC4C9FD0E214B40DDEC0F94DB6F52408908FF2268224B40732EC555657052408908FF2268224B40732EC55565705240DBC4C9FD0E214B40DDEC0F94DB6F5240DBC4C9FD0E214B40
29704	10351	73.959995000000006	73.975742999999994	54.087885	54.079799000000001	Школьная	0103000020E61000000100000005000000B554DE8E707D524073A087DA360A4B40B554DE8E707D52408C67D0D03F0B4B404293C492727E52408C67D0D03F0B4B404293C492727E524073A087DA360A4B40B554DE8E707D524073A087DA360A4B40
29131	10717	74.041624999999996	74.074836000000005	54.221232000000001	54.202466000000001	Центральная	0103000020E610000001000000050000008B6CE7FBA9825240A646E867EA194B408B6CE7FBA9825240126A8654511C4B401024EF1CCA845240126A8654511C4B401024EF1CCA845240A646E867EA194B408B6CE7FBA9825240A646E867EA194B40
28684	9131	73.543347999999995	73.583853000000005	54.218631000000002	54.187801	Пролетарская	0103000020E610000001000000050000003596B036C6625240FB93F8DC09184B403596B036C66252402672C119FC1B4B40FA2AF9D85D6552402672C119FC1B4B40FA2AF9D85D655240FB93F8DC09184B403596B036C6625240FB93F8DC09184B40
29404	9131	73.543347999999995	73.583853000000005	54.218631000000002	54.187801	Ленина	0103000020E610000001000000050000003596B036C6625240FB93F8DC09184B403596B036C66252402672C119FC1B4B40FA2AF9D85D6552402672C119FC1B4B40FA2AF9D85D655240FB93F8DC09184B403596B036C6625240FB93F8DC09184B40
29150	9131	73.543347999999995	73.583853000000005	54.218631000000002	54.187801	Зеленая	0103000020E610000001000000050000003596B036C6625240FB93F8DC09184B403596B036C66252402672C119FC1B4B40FA2AF9D85D6552402672C119FC1B4B40FA2AF9D85D655240FB93F8DC09184B403596B036C6625240FB93F8DC09184B40
29146	10644	74.189721000000006	74.232417999999996	54.252442000000002	54.239910000000002	Центральная	0103000020E6100000010000000500000053978C63248C5240DFFDF15EB51E4B4053978C63248C52408411FB0450204B401C40BFEFDF8E52408411FB0450204B401C40BFEFDF8E5240DFFDF15EB51E4B4053978C63248C5240DFFDF15EB51E4B40
29424	9389	73.432882000000006	73.440329000000006	54.176825999999998	54.160480999999997	Центральная	0103000020E61000000100000005000000BC41B456B45B52408F5033A48A144B40BC41B456B45B52408F8AFF3BA2164B40BF9EAF592E5C52408F8AFF3BA2164B40BF9EAF592E5C52408F5033A48A144B40BC41B456B45B52408F5033A48A144B40
73852	10230	73.653184999999993	73.677214000000006	54.098979999999997	54.080871000000002	Зеленая	0103000020E61000000100000005000000374F75C8CD695240F0181EFB590A4B40374F75C8CD695240A27A6B60AB0C4B402D996379576B5240A27A6B60AB0C4B402D996379576B5240F0181EFB590A4B40374F75C8CD695240F0181EFB590A4B40
29429	9923	73.719641999999993	73.740167999999997	54.282797000000002	54.272036	пер.Советский	0103000020E61000000100000005000000FEB4519D0E6E5240D6AA5D13D2224B40FEB4519D0E6E524016342DB132244B40ED629AE95E6F524016342DB132244B40ED629AE95E6F5240D6AA5D13D2224B40FEB4519D0E6E5240D6AA5D13D2224B40
29700	9457	73.359570000000005	73.369065000000006	54.227490000000003	54.221226999999999	Школьная	0103000020E61000000100000005000000DBA7E3310357524000FF942A511C4B40DBA7E3310357524062156F641E1D4B404A46CEC29E57524062156F641E1D4B404A46CEC29E57524000FF942A511C4B40DBA7E3310357524000FF942A511C4B40
29978	10542	74.011307000000002	74.035291999999998	54.255088000000001	54.245623999999999	Зеленая	0103000020E61000000100000005000000D1CDFE40B98052406D8E739B701F4B40D1CDFE40B980524010CD3CB9A6204B40DE7360394282524010CD3CB9A6204B40DE736039428252406D8E739B701F4B40D1CDFE40B98052406D8E739B701F4B40
29409	9852	73.319056000000003	73.327635000000001	54.278319000000003	54.268923999999998	Советская	0103000020E61000000100000005000000ED65DB696B545240048E041A6C224B40ED65DB696B5452407F6DFDF49F234B409981CAF8F75452407F6DFDF49F234B409981CAF8F7545240048E041A6C224B40ED65DB696B545240048E041A6C224B40
29574	10072	73.834401999999997	73.856949	54.204625	54.194513000000001	Магистральная	0103000020E61000000100000005000000E36DA5D766755240CCD24ECDE5184B40E36DA5D766755240D578E926311A4B40C1559E40D8765240D578E926311A4B40C1559E40D8765240CCD24ECDE5184B40E36DA5D766755240CCD24ECDE5184B40
29839	10784	74.206267999999994	74.220246000000003	54.212376999999996	54.201143999999999	Колхозная	0103000020E61000000100000005000000868DB27E338D5240B0E42A16BF194B40868DB27E338D524017B6662B2F1B4B40CAC4AD82188E524017B6662B2F1B4B40CAC4AD82188E5240B0E42A16BF194B40868DB27E338D5240B0E42A16BF194B40
29809	9623	73.244613000000001	73.264250000000004	53.975988999999998	53.962372000000002	Центральная	0103000020E610000001000000050000004BCB48BDA74F5240064B75012FFB4A404BCB48BDA74F5240BC202235EDFC4A40F4FDD478E9505240BC202235EDFC4A40F4FDD478E9505240064B75012FFB4A404BCB48BDA74F5240064B75012FFB4A40
29154	9762	73.572866000000005	73.591470000000001	54.271951999999999	54.263713000000003	Школьная	0103000020E6100000010000000500000062BF27D6A9645240D943FB58C1214B4062BF27D6A9645240780AB952CF224B402BA4FCA4DA655240780AB952CF224B402BA4FCA4DA655240D943FB58C1214B4062BF27D6A9645240D943FB58C1214B40
29822	10119	73.733457999999999	73.754191000000006	54.192284999999998	54.179966	Центральная	0103000020E6100000010000000500000055BFD2F9F06E52402B323A2009174B4055BFD2F9F06E524074417DCB9C184B4001FC53AA4470524074417DCB9C184B4001FC53AA447052402B323A2009174B4055BFD2F9F06E52402B323A2009174B40
29831	9493	73.384255999999993	73.406777000000005	54.088751999999999	54.070543999999998	Степная	0103000020E61000000100000005000000AC527AA697585240EA76F69507094B40AC527AA69758524030BABC395C0B4B40F6F065A2085A524030BABC395C0B4B40F6F065A2085A5240EA76F69507094B40AC527AA697585240EA76F69507094B40
29281	9394	73.431506999999996	73.441316999999998	54.202998000000001	54.196277000000002	Центральная	0103000020E61000000100000005000000AF3F89CF9D5B52407FFACF9A1F194B40AF3F89CF9D5B5240A393A5D6FB194B40CE8AA8893E5C5240A393A5D6FB194B40CE8AA8893E5C52407FFACF9A1F194B40AF3F89CF9D5B52407FFACF9A1F194B40
29813	9643	73.522057000000004	73.538820000000001	54.052686999999999	54.035336000000001	Центральная	0103000020E610000001000000050000007769C361696152408C2FDAE385044B407769C3616961524051F69672BE064B40919BE1067C62524051F69672BE064B40919BE1067C6252408C2FDAE385044B407769C361696152408C2FDAE385044B40
29398	8923	73.626478000000006	73.643895999999998	54.738821999999999	54.727994000000002	Музейная	0103000020E61000000100000005000000776A2E371868524095D74AE82E5D4B40776A2E37186852405CC823B8915E4B409D819197356952405CC823B8915E4B409D8191973569524095D74AE82E5D4B40776A2E371868524095D74AE82E5D4B40
28680	7922	73.009693999999996	73.033705999999995	55.250633000000001	55.234343000000003	50 лет Октября	0103000020E61000000100000005000000EA3D95D39E405240F58590F3FE9D4B40EA3D95D39E4052403126FDBD14A04B4074EB353D284252403126FDBD14A04B4074EB353D28425240F58590F3FE9D4B40EA3D95D39E405240F58590F3FE9D4B40
76394	53098	73.024102999999997	73.031576999999999	55.288480999999997	55.280605000000001	Поселковая	0103000020E61000000100000005000000122F4FE78A4152400B0C59DDEAA34B40122F4FE78A415240394206F2ECA44B409293895B05425240394206F2ECA44B409293895B054252400B0C59DDEAA34B40122F4FE78A4152400B0C59DDEAA34B40
30088	53098	73.024102999999997	73.031576999999999	55.288480999999997	55.280605000000001	Пионерская	0103000020E61000000100000005000000122F4FE78A4152400B0C59DDEAA34B40122F4FE78A415240394206F2ECA44B409293895B05425240394206F2ECA44B409293895B054252400B0C59DDEAA34B40122F4FE78A4152400B0C59DDEAA34B40
29395	49445	73.578579000000005	73.585667000000001	55.114502000000002	55.107695	Хвойная	0103000020E61000000100000005000000C1C9367007655240AB7823F3C88D4B40C1C9367007655240CEA96400A88E4B402CD670917B655240CEA96400A88E4B402CD670917B655240AB7823F3C88D4B40C1C9367007655240AB7823F3C88D4B40
30060	45468	73.189734999999999	73.209676999999999	55.169431000000003	55.147782999999997	Центральная	0103000020E6100000010000000500000005FA449E244C5240CFF3A78DEA924B4005FA449E244C5240DCF63DEAAF954B404C6E14596B4D5240DCF63DEAAF954B404C6E14596B4D5240CFF3A78DEA924B4005FA449E244C5240CFF3A78DEA924B40
29927	8444	73.650328000000002	73.667692000000002	55.332360000000001	55.325242000000003	Центральная	0103000020E6100000010000000500000014EB54F99E69524090A4A487A1A94B4014EB54F99E695240D13FC1C58AAA4B4041F33977BB6A5240D13FC1C58AAA4B4041F33977BB6A524090A4A487A1A94B4014EB54F99E69524090A4A487A1A94B40
29126	8899	73.589431000000005	73.618384000000006	54.782749000000003	54.746524000000001	Степная	0103000020E61000000100000005000000E90FCD3CB9655240EDD632198E5F4B40E90FCD3CB965524005FD851E31644B40A9177C9A9367524005FD851E31644B40A9177C9A93675240EDD632198E5F4B40E90FCD3CB9655240EDD632198E5F4B40
9775	40308	73.659868000000003	73.682775000000007	54.974725999999997	54.961930000000002	Школьная	0103000020E6100000010000000500000053EBFD463B6A52404985B185207B4B4053EBFD463B6A5240CB4752D2C37C4B40B1E1E995B26B5240CB4752D2C37C4B40B1E1E995B26B52404985B185207B4B4053EBFD463B6A52404985B185207B4B40
29239	49308	73.705449000000002	73.713587000000004	55.246661000000003	55.237371000000003	Центральная	0103000020E61000000100000005000000BDFF8F13266D52406902452C629E4B40BDFF8F13266D52406E197096929F4B4073F6CE68AB6D52406E197096929F4B4073F6CE68AB6D52406902452C629E4B40BDFF8F13266D52406902452C629E4B40
29388	46928	73.290633	73.318669999999997	54.892648999999999	54.847814999999997	Октябрьская	0103000020E61000000100000005000000DB8827BB995252407407B133856C4B40DB8827BB995252404FE78A5242724B40D80DDB16655452404FE78A5242724B40D80DDB16655452407407B133856C4B40DB8827BB995252407407B133856C4B40
29603	46928	73.290633	73.318669999999997	54.892648999999999	54.847814999999997	Бульвар Школьный	0103000020E61000000100000005000000DB8827BB995252407407B133856C4B40DB8827BB995252404FE78A5242724B40D80DDB16655452404FE78A5242724B40D80DDB16655452407407B133856C4B40DB8827BB995252407407B133856C4B40
29402	52994	73.659131000000002	73.695289000000002	54.722878000000001	54.700454999999998	Парковая	0103000020E61000000100000005000000E831CA332F6A5240EBA86A82A8594B40E831CA332F6A5240BB7F2C44875C4B4030116F9D7F6C5240BB7F2C44875C4B4030116F9D7F6C5240EBA86A82A8594B40E831CA332F6A5240EBA86A82A8594B40
29764	48717	73.789935	73.812016	54.681846999999998	54.670414999999998	Центральная	0103000020E61000000100000005000000CFBD874B8E725240B9DFA128D0554B40CFBD874B8E72524017F032C346574B400AF5F411F873524017F032C346574B400AF5F411F8735240B9DFA128D0554B40CFBD874B8E725240B9DFA128D0554B40
30055	49060	73.170107000000002	73.184676999999994	54.931308000000001	54.906756000000001	Школьная	0103000020E6100000010000000500000086747808E34A5240D4B9A29410744B4086747808E34A52406840BD1935774B40B2D47ABFD14B52406840BD1935774B40B2D47ABFD14B5240D4B9A29410744B4086747808E34A5240D4B9A29410744B40
29365	49090	73.505205000000004	73.538343999999995	54.904255999999997	54.893731000000002	Центральная	0103000020E61000000100000005000000A5315A4755605240F03504C765724B40A5315A47556052401B9B1DA9BE734B40DC7F643A746252401B9B1DA9BE734B40DC7F643A74625240F03504C765724B40A5315A4755605240F03504C765724B40
29317	45977	72.926196000000004	72.946066999999999	54.944352000000002	54.929198	Центральная	0103000020E61000000100000005000000E86B96CB463B52401AC1C6F5EF764B40E86B96CB463B5240C3F4BD86E0784B40CA349A5C8C3C5240C3F4BD86E0784B40CA349A5C8C3C52401AC1C6F5EF764B40E86B96CB463B52401AC1C6F5EF764B40
29447	48834	73.457432999999995	73.485872999999998	55.101745999999999	55.082318000000001	Крылова	0103000020E610000001000000050000001DC70F95465D5240A2EF6E65898A4B401DC70F95465D5240D93F4F03068D4B409A40118B185F5240D93F4F03068D4B409A40118B185F5240A2EF6E65898A4B401DC70F95465D5240A2EF6E65898A4B40
28679	7768	73.244450999999998	73.262184000000005	54.799101	54.793531999999999	Мира	0103000020E610000001000000050000005E9ECE15A54F52402C2AE27492654B405E9ECE15A54F5240B7990AF148664B403562669FC7505240B7990AF148664B403562669FC75052402C2AE27492654B405E9ECE15A54F52402C2AE27492654B40
29724	2265	74.128069999999994	74.161693999999997	54.560068999999999	54.554268999999998	Центральная	0103000020E610000001000000050000005166834C32885240E3175E49F2464B405166834C3288524070404B57B0474B40677DCA31598A524070404B57B0474B40677DCA31598A5240E3175E49F2464B405166834C32885240E3175E49F2464B40
29403	52995	73.432388000000003	73.453847999999994	55.386594000000002	55.368630000000003	Центральная	0103000020E61000000100000005000000B4CBB73EAC5B5240892991442FAF4B40B4CBB73EAC5B5240386A85E97BB14B40B8567BD80B5D5240386A85E97BB14B40B8567BD80B5D5240892991442FAF4B40B4CBB73EAC5B5240892991442FAF4B40
29168	8684	73.539449000000005	73.558879000000005	55.148091999999998	55.139071999999999	Зеленая	0103000020E61000000100000005000000093719558662524008E57D1CCD914B4009371955866252404D66BCADF4924B40F5DA6CACC46352404D66BCADF4924B40F5DA6CACC463524008E57D1CCD914B40093719558662524008E57D1CCD914B40
29240	40405	73.025863999999999	73.063980000000001	54.964716000000003	54.954335999999998	Школьная	0103000020E6100000010000000500000033897AC1A74152409EB29AAE277A4B4033897AC1A7415240C7F65AD07B7B4B4047E6913F18445240C7F65AD07B7B4B4047E6913F184452409EB29AAE277A4B4033897AC1A74152409EB29AAE277A4B40
28681	40405	73.025863999999999	73.063980000000001	54.964716000000003	54.954335999999998	Полевая	0103000020E6100000010000000500000033897AC1A74152409EB29AAE277A4B4033897AC1A7415240C7F65AD07B7B4B4047E6913F18445240C7F65AD07B7B4B4047E6913F184452409EB29AAE277A4B4033897AC1A74152409EB29AAE277A4B40
29080	49247	73.337418	73.363253	55.110366999999997	55.095481999999997	Ленина	0103000020E610000001000000050000003BC5AA4198555240A7AD11C1388C4B403BC5AA419855524060C77F81208E4B4021CB82893F57524060C77F81208E4B4021CB82893F575240A7AD11C1388C4B403BC5AA4198555240A7AD11C1388C4B40
29525	46636	73.140129999999999	73.177229999999994	55.275734	55.263249999999999	Ленина	0103000020E6100000010000000500000010CCD1E3F748524004560E2DB2A14B4010CCD1E3F7485240983270404BA34B40AF777FBC574B5240983270404BA34B40AF777FBC574B524004560E2DB2A14B4010CCD1E3F748524004560E2DB2A14B40
29705	7642	73.289996000000002	73.478425999999999	54.853397000000001	54.833053999999997	Титова	0103000020E6100000010000000500000022FE614B8F525240A7E67283A16A4B4022FE614B8F52524094C0E61C3C6D4B4097E315889E5E524094C0E61C3C6D4B4097E315889E5E5240A7E67283A16A4B4022FE614B8F525240A7E67283A16A4B40
29613	7642	73.289996000000002	73.478425999999999	54.853397000000001	54.833053999999997	Гагарина	0103000020E6100000010000000500000022FE614B8F525240A7E67283A16A4B4022FE614B8F52524094C0E61C3C6D4B4097E315889E5E524094C0E61C3C6D4B4097E315889E5E5240A7E67283A16A4B4022FE614B8F525240A7E67283A16A4B40
29148	46133	73.542377000000002	73.573531000000003	55.373854000000001	55.359347999999997	Центральная	0103000020E610000001000000050000009146054EB662524006F1811DFFAD4B409146054EB662524049BDA772DAAF4B40800F5EBBB464524049BDA772DAAF4B40800F5EBBB464524006F1811DFFAD4B409146054EB662524006F1811DFFAD4B40
28673	46133	73.542377000000002	73.573531000000003	55.373854000000001	55.359347999999997	Победы	0103000020E610000001000000050000009146054EB662524006F1811DFFAD4B409146054EB662524049BDA772DAAF4B40800F5EBBB464524049BDA772DAAF4B40800F5EBBB464524006F1811DFFAD4B409146054EB662524006F1811DFFAD4B40
29425	48732	73.868825000000001	73.877753999999996	54.796205	54.787244999999999	Центральная	0103000020E610000001000000050000009F3C2CD49A7752404278B471C4644B409F3C2CD49A775240B2F4A10BEA654B40B9FB1C1F2D785240B2F4A10BEA654B40B9FB1C1F2D7852404278B471C4644B409F3C2CD49A7752404278B471C4644B40
28666	6855	73.223916000000003	73.247550000000004	55.390787000000003	55.372472000000002	Зеленая	0103000020E610000001000000050000004643C6A3544E52407E569929ADAF4B404643C6A3544E5240DA59F44E05B24B40FD87F4DBD74F5240DA59F44E05B24B40FD87F4DBD74F52407E569929ADAF4B404643C6A3544E52407E569929ADAF4B40
29666	49475	73.778211999999996	73.788398999999998	54.757024999999999	54.745162999999998	Лесная	0103000020E61000000100000005000000B456B439CE71524039984D80615F4B40B456B439CE71524090A0F831E6604B40BE4C14217572524090A0F831E6604B40BE4C14217572524039984D80615F4B40B456B439CE71524039984D80615F4B40
29368	49119	73.231703999999993	73.269891000000001	55.202146999999997	55.189582999999999	Центральная	0103000020E610000001000000050000008D96033DD44E52405470784144984B408D96033DD44E524004FEF0F3DF994B40069FE6E44551524004FEF0F3DF994B40069FE6E4455152405470784144984B408D96033DD44E52405470784144984B40
28683	41365	73.536781000000005	73.570036000000002	54.930050999999999	54.917395999999997	60 лет Победы	0103000020E610000001000000050000004F07B29E5A62524098BD6C3B6D754B404F07B29E5A625240594E42E90B774B40BB6246787B645240594E42E90B774B40BB6246787B64524098BD6C3B6D754B404F07B29E5A62524098BD6C3B6D754B40
29387	48546	73.030544000000006	73.048554999999993	55.027371000000002	55.020161999999999	Школьная	0103000020E61000000100000005000000B345D26EF44152409C4F1DAB94824B40B345D26EF4415240EEED96E480834B40AA436E861B435240EEED96E480834B40AA436E861B4352409C4F1DAB94824B40B345D26EF44152409C4F1DAB94824B40
30004	24765	73.007547000000002	73.047764999999998	54.953648999999999	54.934407	Северная	0103000020E61000000100000005000000B58B69A67B405240A51309A69A774B40B58B69A67B4052407A6EA12B117A4B402E39EE940E4352407A6EA12B117A4B402E39EE940E435240A51309A69A774B40B58B69A67B405240A51309A69A774B40
29215	24765	73.007547000000002	73.047764999999998	54.953648999999999	54.934407	Майорова	0103000020E61000000100000005000000B58B69A67B405240A51309A69A774B40B58B69A67B4052407A6EA12B117A4B402E39EE940E4352407A6EA12B117A4B402E39EE940E435240A51309A69A774B40B58B69A67B405240A51309A69A774B40
29360	24765	73.007547000000002	73.047764999999998	54.953648999999999	54.934407	Комсомольская	0103000020E61000000100000005000000B58B69A67B405240A51309A69A774B40B58B69A67B4052407A6EA12B117A4B402E39EE940E4352407A6EA12B117A4B402E39EE940E435240A51309A69A774B40B58B69A67B405240A51309A69A774B40
29635	24765	73.007547000000002	73.047764999999998	54.953648999999999	54.934407	30 лет Победы	0103000020E61000000100000005000000B58B69A67B405240A51309A69A774B40B58B69A67B4052407A6EA12B117A4B402E39EE940E4352407A6EA12B117A4B402E39EE940E435240A51309A69A774B40B58B69A67B405240A51309A69A774B40
29890	46284	73.072558000000001	73.117617999999993	55.336661999999997	55.309590999999998	Мичурина	0103000020E610000001000000050000000B444FCAA444524066118AADA0A74B400B444FCAA444524029E78BBD17AB4B40F0DAA50D8747524029E78BBD17AB4B40F0DAA50D8747524066118AADA0A74B400B444FCAA444524066118AADA0A74B40
29089	46284	73.072558000000001	73.117617999999993	55.336661999999997	55.309590999999998	 Ленина	0103000020E610000001000000050000000B444FCAA444524066118AADA0A74B400B444FCAA444524029E78BBD17AB4B40F0DAA50D8747524029E78BBD17AB4B40F0DAA50D8747524066118AADA0A74B400B444FCAA444524066118AADA0A74B40
29385	2956	74.287440000000004	74.302189999999996	54.650506	54.639862000000001	Центральная	0103000020E61000000100000005000000FCE3BD6A6592524001FA7DFFE6514B40FCE3BD6A6592524007EDD5C743534B4068CBB9145793524007EDD5C743534B4068CBB9145793524001FA7DFFE6514B40FCE3BD6A6592524001FA7DFFE6514B40
29579	48835	73.098519999999994	73.136949999999999	55.126776	55.110944000000003	Школьная	0103000020E610000001000000050000001F80D4264E465240FED7B969338E4B401F80D4264E46524077F52A323A904B40FBCBEEC9C348524077F52A323A904B40FBCBEEC9C3485240FED7B969338E4B401F80D4264E465240FED7B969338E4B40
30104	53105	74.037142000000003	74.054516000000007	54.649369999999998	54.640174999999999	Центральная	0103000020E61000000100000005000000B7D3D68860825240C05B2041F1514B40B7D3D688608252407380608E1E534B40F646AD307D8352407380608E1E534B40F646AD307D835240C05B2041F1514B40B7D3D68860825240C05B2041F1514B40
29495	49226	73.206631999999999	73.228703999999993	55.163986000000001	55.146126000000002	Березовая	0103000020E61000000100000005000000A7936C75394D5240338CBB41B4924B40A7936C75394D52403D80457EFD944B40B81D1A16A34E52403D80457EFD944B40B81D1A16A34E5240338CBB41B4924B40A7936C75394D5240338CBB41B4924B40
29616	8555	73.490536000000006	73.514708999999996	55.315980000000003	55.310738999999998	Центральная	0103000020E61000000100000005000000AF601BF1645F5240BE4BA94BC6A74B40AF601BF1645F524055185B0872A84B403D7D04FEF060524055185B0872A84B403D7D04FEF0605240BE4BA94BC6A74B40AF601BF1645F5240BE4BA94BC6A74B40
29546	49340	73.600858000000002	73.619983000000005	55.204484999999998	55.196947000000002	Гагарина	0103000020E610000001000000050000008FE21C7574665240CD052E8F35994B408FE21C7574665240E3C281902C9A4B40DD442DCDAD675240E3C281902C9A4B40DD442DCDAD675240CD052E8F35994B408FE21C7574665240CD052E8F35994B40
29196	46364	73.742943999999994	73.764944	54.863351999999999	54.846690000000002	Советская	0103000020E610000001000000050000009AB0FD648C6F5240D5EC8156606C4B409AB0FD648C6F5240D5777E51826E4B405FD1ADD7F4705240D5777E51826E4B405FD1ADD7F4705240D5EC8156606C4B409AB0FD648C6F5240D5EC8156606C4B40
30069	49173	73.316325000000006	73.334650999999994	54.768442999999998	54.764375999999999	Школьная	0103000020E61000000100000005000000107A36AB3E54524074ECA012D7614B40107A36AB3E54524089EB18575C624B40B72407EC6A55524089EB18575C624B40B72407EC6A55524074ECA012D7614B40107A36AB3E54524074ECA012D7614B40
29199	14811	73.574078999999998	73.606346000000002	54.826686000000002	54.801223999999998	Ленина	0103000020E610000001000000050000008194D8B5BD64524099620E828E664B408194D8B5BD645240D107CBD8D0694B40DE03745FCE665240D107CBD8D0694B40DE03745FCE66524099620E828E664B408194D8B5BD64524099620E828E664B40
29770	48830	73.117169000000004	73.141925999999998	55.031571999999997	55.015289000000003	Кленовая	0103000020E61000000100000005000000B9C667B27F475240897E6DFDF4814B40B9C667B27F47524012BC218D0A844B40EF1CCA501549524012BC218D0A844B40EF1CCA5015495240897E6DFDF4814B40B9C667B27F475240897E6DFDF4814B40
76450	60838	73.814396000000002	73.833305999999993	55.255585000000004	55.243377000000002	Школьная	0103000020E61000000100000005000000917F66101F7452409FCC3FFA269F4B40917F66101F745240912C6002B7A04B40E063B0E254755240912C6002B7A04B40E063B0E2547552409FCC3FFA269F4B40917F66101F7452409FCC3FFA269F4B40
73930	49135	73.337498999999994	73.352104999999995	55.255144000000001	55.250320000000002	Школьная	0103000020E61000000100000005000000B1DB67959955524072C45A7C0AA04B40B1DB679599555240A4E2FF8EA8A04B4084F068E388565240A4E2FF8EA8A04B4084F068E38856524072C45A7C0AA04B40B1DB67959955524072C45A7C0AA04B40
29707	48860	73.142285999999999	73.161465000000007	55.042937000000002	55.024909999999998	Лесная	0103000020E610000001000000050000006F2BBD361B495240F3AB394030834B406F2BBD361B495240E964A9F57E854B40B79C4B71554A5240E964A9F57E854B40B79C4B71554A5240F3AB394030834B406F2BBD361B495240F3AB394030834B40
29253	8854	73.217843000000002	73.232566000000006	54.896034999999998	54.887222000000001	Школьная	0103000020E61000000100000005000000672AC423F14D52405725917D90714B40672AC423F14D524022895E46B1724B40570A815CE24E524022895E46B1724B40570A815CE24E52405725917D90714B40672AC423F14D52405725917D90714B40
29937	49291	73.667737000000002	73.687869000000006	55.308280000000003	55.290429000000003	Центральная	0103000020E610000001000000050000001155F833BC6A5240AE6708C72CA54B401155F833BC6A5240650113B875A74B40AABBB20B066C5240650113B875A74B40AABBB20B066C5240AE6708C72CA54B401155F833BC6A5240AE6708C72CA54B40
30045	53092	73.704639999999998	73.739637999999999	55.040477000000003	55.029657	Ленина	0103000020E6100000010000000500000005DD5ED2186D52407A8CF2CCCB834B4005DD5ED2186D5240BF9EAF592E854B403F389F3A566F5240BF9EAF592E854B403F389F3A566F52407A8CF2CCCB834B4005DD5ED2186D52407A8CF2CCCB834B40
29808	8038	73.392600999999999	73.400632000000002	55.188684000000002	55.182603	Центральная	0103000020E610000001000000050000001FD8F15F205952406493FC885F974B401FD8F15F20595240A5A31CCC26984B40CA6E66F4A3595240A5A31CCC26984B40CA6E66F4A35952406493FC885F974B401FD8F15F205952406493FC885F974B40
29933	30711	73.966139999999996	74.019131000000002	54.616304	54.589905000000002	Центральная	0103000020E61000000100000005000000E0D6DD3CD57D52409A5FCD01824B4B40E0D6DD3CD57D52406E32AA0CE34E4B40BFD53A71398152406E32AA0CE34E4B40BFD53A71398152409A5FCD01824B4B40E0D6DD3CD57D52409A5FCD01824B4B40
29947	6358	73.835435000000004	73.902341000000007	54.664672000000003	54.648401	Школьная	0103000020E61000000100000005000000C3BB5CC477755240CBD8D0CDFE524B40C3BB5CC4777552409148DBF813554B40C23577F4BF7952409148DBF813554B40C23577F4BF795240CBD8D0CDFE524B40C3BB5CC477755240CBD8D0CDFE524B40
29833	48678	73.705961000000002	73.715329999999994	55.096089999999997	55.089181000000004	Центральная	0103000020E6100000010000000500000018D00B772E6D5240593673486A8B4B4018D00B772E6D52407FBC57AD4C8C4B4040F67AF7C76D52407FBC57AD4C8C4B4040F67AF7C76D5240593673486A8B4B4018D00B772E6D5240593673486A8B4B40
30002	53087	73.601037000000005	73.635954999999996	55.047497	55.036917000000003	Школьная	0103000020E61000000100000005000000E7ABE463776652404ED53DB2B9844B40E7ABE463776652403DD4B66114864B4092AE997CB36852403DD4B66114864B4092AE997CB36852404ED53DB2B9844B40E7ABE463776652404ED53DB2B9844B40
29514	4932	75.535855999999995	75.550928999999996	54.768639999999998	54.756849000000003	Школьная	0103000020E6100000010000000500000062D7F6764BE252405281936DE0604B4062D7F6764BE25240DF32A7CB62624B40C05AB56B42E35240DF32A7CB62624B40C05AB56B42E352405281936DE0604B4062D7F6764BE252405281936DE0604B40
29220	4848	75.536816999999999	75.577635999999998	54.692146000000001	54.6708	Дзержинского	0103000020E61000000100000005000000F5BBB0355BE2524012143FC6DC554B40F5BBB0355BE252405307793D98584B40813FFCFCF7E452405307793D98584B40813FFCFCF7E4524012143FC6DC554B40F5BBB0355BE2524012143FC6DC554B40
30040	4536	74.979304999999997	74.996947000000006	54.753481999999998	54.743192999999998	Стрельникова	0103000020E61000000100000005000000CBF3E0EEACBE5240DDCEBEF2205F4B40CBF3E0EEACBE5240F50F221972604B401A36CAFACDBF5240F50F221972604B401A36CAFACDBF5240DDCEBEF2205F4B40CBF3E0EEACBE5240DDCEBEF2205F4B40
29250	6160	75.021030999999994	75.027283999999995	54.996308999999997	54.985674000000003	Зеленая	0103000020E61000000100000005000000F04C689258C152403E42CD902A7E4B40F04C689258C15240F0DAA50D877F4B400FED6305BFC15240F0DAA50D877F4B400FED6305BFC152403E42CD902A7E4B40F04C689258C152403E42CD902A7E4B40
29653	5628	74.853954000000002	74.889105000000001	54.822136999999998	54.808000999999997	Центральная	0103000020E610000001000000050000007592AD2EA7B652405111A7936C674B407592AD2EA7B6524070EA03C93B694B40726DA818E7B8524070EA03C93B694B40726DA818E7B852405111A7936C674B407592AD2EA7B652405111A7936C674B40
29373	5410	74.991405	75.014249000000007	54.619509999999998	54.610323999999999	Школьная	0103000020E61000000100000005000000D105F52D73BF524061FBC9181F4E4B40D105F52D73BF5240C1C58A1A4C4F4B400C40A374E9C05240C1C58A1A4C4F4B400C40A374E9C0524061FBC9181F4E4B40D105F52D73BF524061FBC9181F4E4B40
29355	4725	75.286914999999993	75.304225000000002	54.812291000000002	54.801575999999997	Центральная	0103000020E61000000100000005000000D66EBBD05CD2524016A1D80A9A664B40D66EBBD05CD25240E6EAC726F9674B400A68226C78D35240E6EAC726F9674B400A68226C78D3524016A1D80A9A664B40D66EBBD05CD2524016A1D80A9A664B40
29041	5742	74.648679999999999	74.65822	54.847188000000003	54.834361000000001	Школьная	0103000020E610000001000000050000006F641EF983A9524068075C57CC6A4B406F641EF983A9524026C808A8706C4B40AE64C74620AA524026C808A8706C4B40AE64C74620AA524068075C57CC6A4B406F641EF983A9524068075C57CC6A4B40
29678	5166	75.282647999999995	75.297720999999996	54.735895999999997	54.724739	Центральная	0103000020E61000000100000005000000E811A3E716D2524060915F3FC45C4B40E811A3E716D25240ECA012D7315E4B40469561DC0DD35240ECA012D7315E4B40469561DC0DD3524060915F3FC45C4B40E811A3E716D2524060915F3FC45C4B40
29788	5828	74.886823000000007	74.903486999999998	54.787239999999997	54.780495999999999	Школьная	0103000020E61000000100000005000000CD9541B5C1B852405454FD4AE7634B40CD9541B5C1B85240300DC347C4644B401D5723BBD2B95240300DC347C4644B401D5723BBD2B952405454FD4AE7634B40CD9541B5C1B852405454FD4AE7634B40
29875	4321	75.052121999999997	75.110809000000003	54.859808000000001	54.824472	Пролетарская	0103000020E61000000100000005000000BC5983F755C35240DE3B6A4C88694B40BC5983F755C352406A6B44300E6E4B408FC6A17E17C752406A6B44300E6E4B408FC6A17E17C75240DE3B6A4C88694B40BC5983F755C35240DE3B6A4C88694B40
29093	4321	75.052121999999997	75.110809000000003	54.859808000000001	54.824472	Маяковского	0103000020E61000000100000005000000BC5983F755C35240DE3B6A4C88694B40BC5983F755C352406A6B44300E6E4B408FC6A17E17C752406A6B44300E6E4B408FC6A17E17C75240DE3B6A4C88694B40BC5983F755C35240DE3B6A4C88694B40
30020	4321	75.052121999999997	75.110809000000003	54.859808000000001	54.824472	Коммунистическая	0103000020E61000000100000005000000BC5983F755C35240DE3B6A4C88694B40BC5983F755C352406A6B44300E6E4B408FC6A17E17C752406A6B44300E6E4B408FC6A17E17C75240DE3B6A4C88694B40BC5983F755C35240DE3B6A4C88694B40
29451	6125	74.975127000000001	75.003110000000007	54.958953000000001	54.943539999999999	Почтовая	0103000020E61000000100000005000000959C137B68BE5240E23B31EBC5784B40959C137B68BE524057B3CEF8BE7A4B40991249F432C0524057B3CEF8BE7A4B40991249F432C05240E23B31EBC5784B40959C137B68BE5240E23B31EBC5784B40
29912	4524	75.186456000000007	75.199112999999997	54.733291000000001	54.724795999999998	Школьная 	0103000020E61000000100000005000000278925E5EECB5240C422861DC65C4B40278925E5EECB5240BFB9BF7ADC5D4B4057CD7344BECC5240BFB9BF7ADC5D4B4057CD7344BECC5240C422861DC65C4B40278925E5EECB5240C422861DC65C4B40
29651	5445	75.042141999999998	75.070564000000005	54.568192000000003	54.551777999999999	Лесная	0103000020E610000001000000050000006FF25B74B2C252407E5358A9A0464B406FF25B74B2C25240A7ECF483BA484B409911DE1E84C45240A7ECF483BA484B409911DE1E84C452407E5358A9A0464B406FF25B74B2C252407E5358A9A0464B40
29113	5559	75.299301999999997	75.316703000000004	54.575029000000001	54.564047000000002	Школьная	0103000020E61000000100000005000000276893C327D3524016342DB132484B40276893C327D3524034A0DE8C9A494B40E3E2A8DC44D4524034A0DE8C9A494B40E3E2A8DC44D4524016342DB132484B40276893C327D3524016342DB132484B40
29231	5209	75.100864999999999	75.123205999999996	54.674908000000002	54.656869999999998	Ленина	0103000020E61000000100000005000000E813799274C652409CDCEF5014544B40E813799274C6524086E7A56263564B40F12A6B9BE2C7524086E7A56263564B40F12A6B9BE2C752409CDCEF5014544B40E813799274C652409CDCEF5014544B40
29363	5062	75.478785999999999	75.494838999999999	54.543464	54.535676000000002	Первомайская	0103000020E6100000010000000500000017F2086EA4DE524045A0FA0791444B4017F2086EA4DE5240D446753A90454B4043723271ABDF5240D446753A90454B4043723271ABDF524045A0FA0791444B4017F2086EA4DE524045A0FA0791444B40
30044	4700	75.455160000000006	75.479433	54.838259999999998	54.827567999999999	Ленина	0103000020E61000000100000005000000A29C685721DD5240AA9B8BBFED694B40A29C685721DD5240C1C58A1A4C6B4B40E2E7BF07AFDE5240C1C58A1A4C6B4B40E2E7BF07AFDE5240AA9B8BBFED694B40A29C685721DD5240AA9B8BBFED694B40
29589	4998	75.419425000000004	75.449977000000004	54.633578	54.618873999999998	Центральная	0103000020E61000000100000005000000FD87F4DBD7DA52401F2C6343374F4B40FD87F4DBD7DA524088BB7A1519514B40F1BC546CCCDC524088BB7A1519514B40F1BC546CCCDC52401F2C6343374F4B40FD87F4DBD7DA52401F2C6343374F4B40
29838	5680	74.657250000000005	74.671254000000005	54.757275	54.749600000000001	Школьная	0103000020E61000000100000005000000F2D24D6210AA5240728A8EE4F25F4B40F2D24D6210AA5240098A1F63EE604B40CA5356D3F5AA5240098A1F63EE604B40CA5356D3F5AA5240728A8EE4F25F4B40F2D24D6210AA5240728A8EE4F25F4B40
29783	5339	75.066305999999997	75.090264000000005	54.707295999999999	54.702145999999999	Центральная	0103000020E61000000100000005000000D461855B3EC4524034828DEBDF594B40D461855B3EC45240BA4BE2AC885A4B406500A8E2C6C55240BA4BE2AC885A4B406500A8E2C6C5524034828DEBDF594B40D461855B3EC4524034828DEBDF594B40
29290	5310	75.170636999999999	75.186222000000001	54.651594000000003	54.646458000000003	Зеленая	0103000020E61000000100000005000000349F73B7EBCA5240691EC022BF524B40349F73B7EBCA52408A22A46E67534B40EDF2AD0FEBCB52408A22A46E67534B40EDF2AD0FEBCB5240691EC022BF524B40349F73B7EBCA5240691EC022BF524B40
29107	5228	74.866099000000006	74.887621999999993	54.695481000000001	54.689163999999998	Целинная	0103000020E610000001000000050000004B06802A6EB752404FCAA48636584B404B06802A6EB75240A4FE7A8505594B40724D81CCCEB85240A4FE7A8505594B40724D81CCCEB852404FCAA48636584B404B06802A6EB752404FCAA48636584B40
29725	5915	74.886131000000006	74.921705000000003	54.906506999999998	54.887616000000001	Садовая	0103000020E61000000100000005000000323ECC5EB6B8524003B4AD669D714B40323ECC5EB6B852402B4CDF6B08744B40D2E3F736FDBA52402B4CDF6B08744B40D2E3F736FDBA524003B4AD669D714B40323ECC5EB6B8524003B4AD669D714B40
30035	6057	74.756018999999995	74.780382000000003	54.882297000000001	54.867880999999997	Центральная	0103000020E61000000100000005000000E509849D62B05240EEE87FB9166F4B40E509849D62B05240F12DAC1BEF704B40C61858C7F1B15240F12DAC1BEF704B40C61858C7F1B15240EEE87FB9166F4B40E509849D62B05240EEE87FB9166F4B40
29711	5803	74.952552999999995	74.962316999999999	54.801462000000001	54.794756999999997	Зеленая	0103000020E610000001000000050000003AADDBA0F6BC52402FA2ED98BA654B403AADDBA0F6BC52404E7E8B4E96664B40A1D80A9A96BD52404E7E8B4E96664B40A1D80A9A96BD52402FA2ED98BA654B403AADDBA0F6BC52402FA2ED98BA654B40
29939	5974	74.921443999999994	74.931540999999996	54.864601	54.855009000000003	Центральная	0103000020E610000001000000050000001B4641F0F8BA5240916456EF706D4B401B4641F0F8BA5240618BDD3EAB6E4B408578245E9EBB5240618BDD3EAB6E4B408578245E9EBB5240916456EF706D4B401B4641F0F8BA5240916456EF706D4B40
29223	5529	75.075038000000006	75.085314999999994	54.538125999999998	54.531689999999998	Школьная	0103000020E6100000010000000500000044FD2E6CCDC452401CCEFC6A0E444B4044FD2E6CCDC452404B901150E1444B40EDB60BCD75C552404B901150E1444B40EDB60BCD75C552401CCEFC6A0E444B4044FD2E6CCDC452401CCEFC6A0E444B40
30052	4910	75.439413000000002	75.452717000000007	54.776040999999999	54.763263999999999	Первомайская	0103000020E61000000100000005000000FC1BB4571FDC5240691B7FA2B2614B40FC1BB4571FDC524075ADBD4F55634B40F855B950F9DC524075ADBD4F55634B40F855B950F9DC5240691B7FA2B2614B40FC1BB4571FDC5240691B7FA2B2614B40
29486	47874	72.490971000000002	72.509062999999998	54.083491000000002	54.069111999999997	Почтовая	0103000020E610000001000000050000003412A1116C1F52406DE179A9D8084B403412A1116C1F5240534145D5AF0A4B40A226FA7C94205240534145D5AF0A4B40A226FA7C942052406DE179A9D8084B403412A1116C1F52406DE179A9D8084B40
30012	47794	72.899507	72.911615999999995	54.316077	54.309984	Школьная	0103000020E610000001000000050000007AE1CE85913952404224438EAD274B407AE1CE859139524047020D3675284B40A9A0A2EA573A524047020D3675284B40A9A0A2EA573A52404224438EAD274B407AE1CE85913952404224438EAD274B40
29942	3194	72.921947000000003	72.942751999999999	54.119635000000002	54.110362000000002	Школьная	0103000020E610000001000000050000004D69FD2D013B52404F5C8E57200E4B404D69FD2D013B52407E3A1E33500F4B40450F7C0C563C52407E3A1E33500F4B40450F7C0C563C52404F5C8E57200E4B404D69FD2D013B52404F5C8E57200E4B40
29751	3715	73.077894000000001	73.101583000000005	54.368395999999997	54.364109999999997	Центральная	0103000020E610000001000000050000007FA31D37FC445240C2120F289B2E4B407FA31D37FC44524015FDA199272F4B4018B5FB558046524015FDA199272F4B4018B5FB5580465240C2120F289B2E4B407FA31D37FC445240C2120F289B2E4B40
30028	47899	72.658004000000005	72.692751000000001	54.203555999999999	54.189628999999996	Октябрьская	0103000020E61000000100000005000000C828CFBC1C2A5240C4AF58C345184B40C828CFBC1C2A5240C9737D1F0E1A4B405D514A08562C5240C9737D1F0E1A4B405D514A08562C5240C4AF58C345184B40C828CFBC1C2A5240C4AF58C345184B40
29534	47811	72.477793000000005	72.499010999999996	53.989410999999997	53.976523999999998	Мира	0103000020E610000001000000050000007F501729941E52402AE109BDFEFC4A407F501729941E5240BDA60705A5FE4A400856D5CBEF1F5240BDA60705A5FE4A400856D5CBEF1F52402AE109BDFEFC4A407F501729941E52402AE109BDFEFC4A40
29322	47570	72.941404000000006	72.991557	54.220232000000003	54.200491	Ленина	0103000020E61000000100000005000000B61490F63F3C5240381268B0A9194B40B61490F63F3C52402FC4EA8F301C4B40ACC77DAB753F52402FC4EA8F301C4B40ACC77DAB753F5240381268B0A9194B40B61490F63F3C5240381268B0A9194B40
30029	47722	73.038934999999995	73.068219999999997	54.324221999999999	54.306711999999997	Центральный	0103000020E61000000100000005000000DDEA39E97D42524037A5BC5642274B40DDEA39E97D4252406552431B80294B40B83B6BB75D4452406552431B80294B40B83B6BB75D44524037A5BC5642274B40DDEA39E97D42524037A5BC5642274B40
29456	47684	72.559809000000001	72.594375999999997	54.176240999999997	54.147419999999997	Ленина	0103000020E610000001000000050000006AC020E9D32352405E6397A8DE124B406AC020E9D32352406F9BA9108F164B40BF61A2410A2652406F9BA9108F164B40BF61A2410A2652405E6397A8DE124B406AC020E9D32352405E6397A8DE124B40
29622	3935	72.670302000000007	72.700530000000001	53.975459000000001	53.963866000000003	Центральная	0103000020E61000000100000005000000611C5C3AE62A5240F9DC09F65FFB4A40611C5C3AE62A524060CB2BD7DBFC4A407BF7C77BD52C524060CB2BD7DBFC4A407BF7C77BD52C5240F9DC09F65FFB4A40611C5C3AE62A5240F9DC09F65FFB4A40
29879	47740	73.188827000000003	73.212399000000005	54.256107999999998	54.240898999999999	Школьный	0103000020E610000001000000050000008466D7BD154C5240CE5147C7D51E4B408466D7BD154C52403A1F9E25C8204B4000ADF9F1974D52403A1F9E25C8204B4000ADF9F1974D5240CE5147C7D51E4B408466D7BD154C5240CE5147C7D51E4B40
29046	47660	73.248088999999993	73.279332999999994	54.117339000000001	54.098790000000001	Романенко	0103000020E61000000100000005000000D45FAFB0E04F5240FF959526A50C4B40D45FAFB0E04F5240CEC5DFF6040F4B4063EC8497E0515240CEC5DFF6040F4B4063EC8497E0515240FF959526A50C4B40D45FAFB0E04F5240FF959526A50C4B40
29316	3343	73.148528999999996	73.175757000000004	54.135705999999999	54.117977000000003	Школьный	0103000020E610000001000000050000007C60C77F814952401157CEDE190F4B407C60C77F814952407CEF6FD05E114B40C2C2499A3F4B52407CEF6FD05E114B40C2C2499A3F4B52401157CEDE190F4B407C60C77F814952401157CEDE190F4B40
29235	3524	72.488069999999993	72.510643999999999	54.193885999999999	54.184925	Центральная	0103000020E61000000100000005000000280AF4893C1F52403D9B559FAB174B40280AF4893C1F52407D93A641D1184B4083F92B64AE2052407D93A641D1184B4083F92B64AE2052403D9B559FAB174B40280AF4893C1F52403D9B559FAB174B40
29618	47826	72.409143999999998	72.420382000000004	54.090916999999997	54.082968000000001	Бобровицкая	0103000020E61000000100000005000000B2D6506A2F1A5240A94E07B29E0A4B40B2D6506A2F1A524041D3122BA30B4B40EF74E789E71A524041D3122BA30B4B40EF74E789E71A5240A94E07B29E0A4B40B2D6506A2F1A5240A94E07B29E0A4B40
30000	47624	73.165103000000002	73.195080000000004	54.080105000000003	54.063837999999997	Центральная	0103000020E610000001000000050000002D5E2C0C914A5240FB1EF5D72B084B402D5E2C0C914A5240809F71E1400A4B40A306D3307C4C5240809F71E1400A4B40A306D3307C4C5240FB1EF5D72B084B402D5E2C0C914A5240FB1EF5D72B084B40
29174	47612	72.767527000000001	72.796982	54.175255	54.161915	Ленина	0103000020E6100000010000000500000002F390291F315240ADDD76A1B9144B4002F390291F315240F1BA7EC16E164B400B60CAC001335240F1BA7EC16E164B400B60CAC001335240ADDD76A1B9144B4002F390291F315240ADDD76A1B9144B40
30038	53091	74.494645000000006	74.531135000000006	53.785699000000001	53.769545000000001	Школьная	0103000020E6100000010000000500000051888043A89F524071E6577380E24A4051888043A89F5240FDBFEAC891E44A40B4B0A71DFEA15240FDBFEAC891E44A40B4B0A71DFEA1524071E6577380E24A4051888043A89F524071E6577380E24A40
29998	40474	74.513259000000005	74.546119000000004	54.186331000000003	54.169989999999999	Центральная	0103000020E610000001000000050000002CD8463CD9A05240D252793BC2154B402CD8463CD9A05240919DB7B1D9174B405A2E1B9DF3A25240919DB7B1D9174B405A2E1B9DF3A25240D252793BC2154B402CD8463CD9A05240D252793BC2154B40
29739	40474	74.513259000000005	74.546119000000004	54.186331000000003	54.169989999999999	Рассохина	0103000020E610000001000000050000002CD8463CD9A05240D252793BC2154B402CD8463CD9A05240919DB7B1D9174B405A2E1B9DF3A25240919DB7B1D9174B405A2E1B9DF3A25240D252793BC2154B402CD8463CD9A05240D252793BC2154B40
29660	2155	74.844476	74.856559000000004	54.014341999999999	54.005288999999998	Центральная	0103000020E61000000100000005000000719010E50BB65240A703594FAD004B40719010E50BB65240C87A6AF5D5014B400C06D7DCD1B65240C87A6AF5D5014B400C06D7DCD1B65240A703594FAD004B40719010E50BB65240A703594FAD004B40
79182	61442	74.544538000000003	74.565864000000005	54.130003000000002	54.116278000000001	Центральная	0103000020E61000000100000005000000795BE9B5D9A25240459F8F32E20E4B40795BE9B5D9A25240E2B034F0A3104B40F67EA31D37A45240E2B034F0A3104B40F67EA31D37A45240459F8F32E20E4B40795BE9B5D9A25240459F8F32E20E4B40
29723	1963	74.613653999999997	74.623410000000007	54.244840000000003	54.236932000000003	Береговая	0103000020E61000000100000005000000D0436D1B46A752401DB0ABC9531E4B40D0436D1B46A752405760C8EA561F4B40F67F0EF3E5A752405760C8EA561F4B40F67F0EF3E5A752401DB0ABC9531E4B40D0436D1B46A752401DB0ABC9531E4B40
79203	46354	74.477586000000002	74.497574	54.055605	54.045408000000002	Центральная	0103000020E61000000100000005000000C2C1DEC4909E5240077DE9EDCF054B40C2C1DEC4909E52403E3F8C101E074B40C1559E40D89F52403E3F8C101E074B40C1559E40D89F5240077DE9EDCF054B40C2C1DEC4909E5240077DE9EDCF054B40
29926	46354	74.477586000000002	74.497574	54.055605	54.045408000000002	Новая	0103000020E61000000100000005000000C2C1DEC4909E5240077DE9EDCF054B40C2C1DEC4909E52403E3F8C101E074B40C1559E40D89F52403E3F8C101E074B40C1559E40D89F5240077DE9EDCF054B40C2C1DEC4909E5240077DE9EDCF054B40
79192	46354	74.477586000000002	74.497574	54.055605	54.045408000000002	Зеленая	0103000020E61000000100000005000000C2C1DEC4909E5240077DE9EDCF054B40C2C1DEC4909E52403E3F8C101E074B40C1559E40D89F52403E3F8C101E074B40C1559E40D89F5240077DE9EDCF054B40C2C1DEC4909E5240077DE9EDCF054B40
29246	2997	74.667320000000004	74.683588	53.888727000000003	53.87764	Школьная	0103000020E61000000100000005000000DFFDF15EB5AA5240AAD4EC8156F04A40DFFDF15EB5AA52403E096CCEC1F14A4009FCE1E7BFAB52403E096CCEC1F14A4009FCE1E7BFAB5240AAD4EC8156F04A40DFFDF15EB5AA5240AAD4EC8156F04A40
30010	2859	74.591420999999997	74.599973000000006	53.766697000000001	53.761209999999998	Школьная	0103000020E61000000100000005000000BA4A77D7D9A55240AFB14B546FE14A40BA4A77D7D9A552407D78962023E24A40EA5E27F565A652407D78962023E24A40EA5E27F565A65240AFB14B546FE14A40BA4A77D7D9A55240AFB14B546FE14A40
29819	53042	74.660653999999994	74.679599999999994	54.119508000000003	54.105331	Школьная	0103000020E610000001000000050000002EFEB62748AA5240A320787C7B0D4B402EFEB62748AA524021CEC3094C0F4B402497FF907EAB524021CEC3094C0F4B402497FF907EAB5240A320787C7B0D4B402EFEB62748AA5240A320787C7B0D4B40
29166	1765	74.402640000000005	74.417911000000004	54.392538000000002	54.386451000000001	Новоивановская	0103000020E61000000100000005000000EF0390DAC4995240D540F33977314B40EF0390DAC4995240F83768AF3E324B40E068C70DBF9A5240F83768AF3E324B40E068C70DBF9A5240D540F33977314B40EF0390DAC4995240D540F33977314B40
29076	52967	74.672072	74.719888999999995	54.183692000000001	54.151364999999998	Школьная	0103000020E61000000100000005000000AB23473A03AB52402861A6ED5F134B40AB23473A03AB5240B7442E3883174B4002F04FA912AE5240B7442E3883174B4002F04FA912AE52402861A6ED5F134B40AB23473A03AB52402861A6ED5F134B40
79244	52967	74.672072	74.719888999999995	54.183692000000001	54.151364999999998	Красный Путь	0103000020E61000000100000005000000AB23473A03AB52402861A6ED5F134B40AB23473A03AB5240B7442E3883174B4002F04FA912AE5240B7442E3883174B4002F04FA912AE52402861A6ED5F134B40AB23473A03AB52402861A6ED5F134B40
30091	52967	74.672072	74.719888999999995	54.183692000000001	54.151364999999998	Красноармейская	0103000020E61000000100000005000000AB23473A03AB52402861A6ED5F134B40AB23473A03AB5240B7442E3883174B4002F04FA912AE5240B7442E3883174B4002F04FA912AE52402861A6ED5F134B40AB23473A03AB52402861A6ED5F134B40
28698	1909	74.405541999999997	74.413932000000003	54.236373999999998	54.227696000000002	Гагарина	0103000020E61000000100000005000000E2C96E66F49952400BB77C24251D4B40E2C96E66F4995240F6CFD380411E4B4025B1A4DC7D9A5240F6CFD380411E4B4025B1A4DC7D9A52400BB77C24251D4B40E2C96E66F49952400BB77C24251D4B40
29288	2417	74.566249999999997	74.575772000000001	53.934493000000003	53.930576000000002	Нижняя	0103000020E610000001000000050000000AD7A3703DA45240A438471D1DF74A400AD7A3703DA45240A4AB74779DF74A40F67CCD72D9A45240A4AB74779DF74A40F67CCD72D9A45240A438471D1DF74A400AD7A3703DA45240A438471D1DF74A40
29851	2612	74.445481000000001	74.465432000000007	54.152588000000002	54.142161999999999	Ветеранов	0103000020E61000000100000005000000527FBDC2829C5240F25D4A5D32124B40527FBDC2829C52408BE1EA0088134B40C3A04CA3C99D52408BE1EA0088134B40C3A04CA3C99D5240F25D4A5D32124B40527FBDC2829C5240F25D4A5D32124B40
29696	2645	74.439013000000003	74.448741999999996	54.161808999999998	54.157186000000003	Школьная	0103000020E610000001000000050000003561FBC9189C5240CDB1BCAB1E144B403561FBC9189C524067994528B6144B40DD955D30B89C524067994528B6144B40DD955D30B89C5240CDB1BCAB1E144B403561FBC9189C5240CDB1BCAB1E144B40
29434	1118	74.717310999999995	74.728369000000001	54.146951000000001	54.127254000000001	Мельничная	0103000020E61000000100000005000000E883656CE8AD52408124ECDB49104B40E883656CE8AD5240A88E554ACF124B40E59A02999DAE5240A88E554ACF124B40E59A02999DAE52408124ECDB49104B40E883656CE8AD52408124ECDB49104B40
30123	53113	74.987415999999996	75.000720000000001	53.859684999999999	53.848737999999997	Береговая	0103000020E6100000010000000500000004E3E0D231BF5240AC6F6072A3EC4A4004E3E0D231BF52404EEE77280AEE4A40001DE6CB0BC052404EEE77280AEE4A40001DE6CB0BC05240AC6F6072A3EC4A4004E3E0D231BF5240AC6F6072A3EC4A40
29043	2361	74.547341000000003	74.560563999999999	54.073618000000003	54.062232000000002	переулок Школьный	0103000020E61000000100000005000000A3B08BA207A35240E161DA37F7074B40A3B08BA207A35240CF328B506C094B4028D4D347E0A35240CF328B506C094B4028D4D347E0A35240E161DA37F7074B40A3B08BA207A35240E161DA37F7074B40
76449	60837	74.630273000000003	74.640998999999994	54.221663999999997	54.213793000000003	Центральная	0103000020E6100000010000000500000051A3906456A852408F8EAB915D1B4B4051A3906456A85240AB59677C5F1C4B403271AB2006A95240AB59677C5F1C4B403271AB2006A952408F8EAB915D1B4B4051A3906456A852408F8EAB915D1B4B40
76478	60858	74.507966999999994	74.520436000000004	54.368391000000003	54.362867000000001	Верхняя	0103000020E610000001000000050000009F1C058882A0524019E6046D722E4B409F1C058882A052400492B06F272F4B404FEACBD24EA152400492B06F272F4B404FEACBD24EA1524019E6046D722E4B409F1C058882A0524019E6046D722E4B40
30139	53120	74.082795000000004	75.026797999999999	54.402496999999997	53.668995000000002	Парковая	0103000020E610000001000000050000006E5166834C8552400118CFA0A1D54A406E5166834C8552407ADE8D0585334B404966F50EB7C152407ADE8D0585334B404966F50EB7C152400118CFA0A1D54A406E5166834C8552400118CFA0A1D54A40
29580	2310	74.661265	74.688761999999997	53.993645999999998	53.979329999999997	Центральная	0103000020E61000000100000005000000533F6F2A52AA5240EFFE78AF5AFD4A40533F6F2A52AA52408EE6C8CA2FFF4A40902E36AD14AC52408EE6C8CA2FFF4A40902E36AD14AC5240EFFE78AF5AFD4A40533F6F2A52AA5240EFFE78AF5AFD4A40
79224	61475	74.889562999999995	74.926384999999996	53.921408999999997	53.909492999999998	Ленина	0103000020E61000000100000005000000D32EA699EEB85240707841446AF44A40D32EA699EEB85240BA9EE8BAF0F54A4051A04FE449BB5240BA9EE8BAF0F54A4051A04FE449BB5240707841446AF44A40D32EA699EEB85240707841446AF44A40
79229	61475	74.889562999999995	74.926384999999996	53.921408999999997	53.909492999999998	Гагарина	0103000020E61000000100000005000000D32EA699EEB85240707841446AF44A40D32EA699EEB85240BA9EE8BAF0F54A4051A04FE449BB5240BA9EE8BAF0F54A4051A04FE449BB5240707841446AF44A40D32EA699EEB85240707841446AF44A40
30080	2075	74.777884	74.797207	54.095585	54.083115999999997	Школьная	0103000020E610000001000000050000003A05F9D9C8B152401DE38A8BA30A4B403A05F9D9C8B152407C7E18213C0C4B401B49827005B352407C7E18213C0C4B401B49827005B352401DE38A8BA30A4B403A05F9D9C8B152401DE38A8BA30A4B40
79236	61485	74.227503999999996	74.253026000000006	54.129416999999997	54.108429999999998	Ленина	0103000020E6100000010000000500000063EDEF6C8F8E5240E0F3C308E10D4B4063EDEF6C8F8E5240F1457BBC90104B406AC2F69331905240F1457BBC90104B406AC2F69331905240E0F3C308E10D4B4063EDEF6C8F8E5240E0F3C308E10D4B40
29164	1573	74.903683999999998	74.921130000000005	53.950149000000003	53.943593999999997	Победы	0103000020E61000000100000005000000C87A6AF5D5B95240D5592DB0C7F84A40C87A6AF5D5B95240DFA9807B9EF94A4054573ECBF3BA5240DFA9807B9EF94A4054573ECBF3BA5240D5592DB0C7F84A40C87A6AF5D5B95240D5592DB0C7F84A40
29805	53039	74.940443000000002	74.954897000000003	53.94556	53.936264000000001	Школьная	0103000020E610000001000000050000002330D63730BC52400936AE7FD7F74A402330D63730BC5240F0332E1C08F94A401B834E081DBD5240F0332E1C08F94A401B834E081DBD52400936AE7FD7F74A402330D63730BC52400936AE7FD7F74A40
29161	1453	74.843209999999999	74.869512	53.978107000000001	53.964146	Центральная	0103000020E61000000100000005000000406A1327F7B55240DC48D92269FB4A40406A1327F7B552408D7E349C32FD4A40B1DEA815A6B752408D7E349C32FD4A40B1DEA815A6B75240DC48D92269FB4A40406A1327F7B55240DC48D92269FB4A40
29143	528	74.598994000000005	74.615405999999993	55.881166999999998	55.874299000000001	Молодежная	0103000020E610000001000000050000000420EEEA55A6524077F69507E9EF4B400420EEEA55A652403FA88B14CAF04B40C7F0D8CF62A752403FA88B14CAF04B40C7F0D8CF62A7524077F69507E9EF4B400420EEEA55A6524077F69507E9EF4B40
29708	31446	74.897880999999998	74.930535000000006	55.599356999999998	55.579205000000002	К. Маркса	0103000020E61000000100000005000000C9ACDEE176B952400057B26323CA4B40C9ACDEE176B9524078D0ECBAB7CC4B402332ACE28DBB524078D0ECBAB7CC4B402332ACE28DBB52400057B26323CA4B40C9ACDEE176B952400057B26323CA4B40
29812	32171	75.118983999999998	75.144863999999998	55.504063000000002	55.489116000000003	Центральная	0103000020E61000000100000005000000D32F116F9DC75240A5F9635A9BBE4B40D32F116F9DC75240D40FEA2285C04B408997A77345C95240D40FEA2285C04B408997A77345C95240A5F9635A9BBE4B40D32F116F9DC75240A5F9635A9BBE4B40
29964	32171	75.118983999999998	75.144863999999998	55.504063000000002	55.489116000000003	70 лет Октября	0103000020E61000000100000005000000D32F116F9DC75240A5F9635A9BBE4B40D32F116F9DC75240D40FEA2285C04B408997A77345C95240D40FEA2285C04B408997A77345C95240A5F9635A9BBE4B40D32F116F9DC75240A5F9635A9BBE4B40
29254	31498	74.974318999999994	74.989868999999999	55.648564999999998	55.645522	Советская	0103000020E61000000100000005000000C537143E5BBE52409C6C0377A0D24B40C537143E5BBE5240452A8C2D04D34B40C09481035ABF5240452A8C2D04D34B40C09481035ABF52409C6C0377A0D24B40C537143E5BBE52409C6C0377A0D24B40
30099	53104	74.554553999999996	74.58569	55.864040000000003	55.852637000000001	Пролетарская	0103000020E610000001000000050000006C770FD07DA35240062E8F3523ED4B406C770FD07DA35240CA37DBDC98EE4B4008E6E8F17BA55240CA37DBDC98EE4B4008E6E8F17BA55240062E8F3523ED4B406C770FD07DA35240062E8F3523ED4B40
29571	53016	74.978190999999995	75.012703999999999	55.317348000000003	55.308002999999999	Школьная	0103000020E61000000100000005000000758F6CAE9ABE5240F2086EA46CA74B40758F6CAE9ABE5240BBB9F8DB9EA84B40D1217024D0C05240BBB9F8DB9EA84B40D1217024D0C05240F2086EA46CA74B40758F6CAE9ABE5240F2086EA46CA74B40
29655	30742	74.826078999999993	74.842060000000004	55.488166999999997	55.471984999999997	Центральная	0103000020E61000000100000005000000643A747ADEB45240ED9925016ABC4B40643A747ADEB4524043FE99417CBE4B404451A04FE4B5524043FE99417CBE4B404451A04FE4B55240ED9925016ABC4B40643A747ADEB45240ED9925016ABC4B40
76448	60836	74.377200000000002	75.368527	55.988500000000002	55.186895	Центральная	0103000020E610000001000000050000004703780B249852409964E42CEC974B404703780B249852404A0C022B87FE4B405A2C45F295D752404A0C022B87FE4B405A2C45F295D752409964E42CEC974B404703780B249852409964E42CEC974B40
29684	32396	74.544376	74.571316999999993	55.726725000000002	55.714596999999998	Зеленая	0103000020E610000001000000050000008C2E6F0ED7A25240EC681CEA77DB4B408C2E6F0ED7A25240C217265305DD4B4086A92D7590A45240C217265305DD4B4086A92D7590A45240EC681CEA77DB4B408C2E6F0ED7A25240EC681CEA77DB4B40
29962	32268	75.17971	75.207628999999997	55.531193000000002	55.524926000000001	Новая	0103000020E61000000100000005000000E8305F5E80CB5240F96871C630C34B40E8305F5E80CB52409C6ED921FEC34B40E02C25CB49CD52409C6ED921FEC34B40E02C25CB49CD5240F96871C630C34B40E8305F5E80CB5240F96871C630C34B40
30082	31087	74.538510000000002	74.550484999999995	55.556457000000002	55.550198000000002	Интернациональная	0103000020E610000001000000050000006AA4A5F276A252408D2958E36CC64B406AA4A5F276A25240AD50A4FB39C74B4011FC6F253BA35240AD50A4FB39C74B4011FC6F253BA352408D2958E36CC64B406AA4A5F276A252408D2958E36CC64B40
29279	52983	75.066468	75.081883000000005	55.882631000000003	55.870894999999997	Школьная	0103000020E61000000100000005000000C18EFF0241C45240FD9FC37C79EF4B40C18EFF0241C45240C8B7770DFAF04B404CC631923DC55240C8B7770DFAF04B404CC631923DC55240FD9FC37C79EF4B40C18EFF0241C45240FD9FC37C79EF4B40
29713	425	74.670041999999995	74.692580000000007	55.944716999999997	55.934128999999999	Нииз	0103000020E61000000100000005000000923CD7F7E1AA5240629F008A91F74B40923CD7F7E1AA5240D47C957CECF84B404777103B53AC5240D47C957CECF84B404777103B53AC5240629F008A91F74B40923CD7F7E1AA5240629F008A91F74B40
29114	30651	74.817473000000007	74.820141000000007	55.371837999999997	55.360126000000001	Центральная	0103000020E610000001000000050000003C17467A51B452403B38D89B18AE4B403C17467A51B452407CB4386398AF4B40F646AD307DB452407CB4386398AF4B40F646AD307DB452403B38D89B18AE4B403C17467A51B452403B38D89B18AE4B40
29835	30432	74.805355000000006	74.822350999999998	55.410780000000003	55.402715000000001	Центральная	0103000020E61000000100000005000000E3AAB2EF8AB35240E84D452A8CB34B40E3AAB2EF8AB35240EAEC647094B44B404EB51666A1B45240EAEC647094B44B404EB51666A1B45240E84D452A8CB34B40E3AAB2EF8AB35240E84D452A8CB34B40
29308	31978	75.061544999999995	75.079898	55.303820999999999	55.292940000000002	Победы	0103000020E61000000100000005000000DE8E705AF0C352405AD8D30E7FA54B40DE8E705AF0C35240446B459BE3A64B400341800C1DC55240446B459BE3A64B400341800C1DC552405AD8D30E7FA54B40DE8E705AF0C352405AD8D30E7FA54B40
29138	32408	74.624380000000002	74.638951000000006	55.793489999999998	55.779513999999999	Школьная	0103000020E61000000100000005000000B21188D7F5A752401763601DC7E34B40B21188D7F5A75240FDD98F1491E54B40C72FBC92E4A85240FDD98F1491E54B40C72FBC92E4A852401763601DC7E34B40B21188D7F5A752401763601DC7E34B40
29273	800	75.015749	75.026510999999999	55.819014000000003	55.815579999999997	Школьная	0103000020E6100000010000000500000076FC170802C15240C6A2E9EC64E84B4076FC170802C15240AB7B6473D5E84B40FE7E315BB2C15240AB7B6473D5E84B40FE7E315BB2C15240C6A2E9EC64E84B4076FC170802C15240C6A2E9EC64E84B40
29750	30945	74.483973000000006	74.503799000000001	55.496673999999999	55.481907999999997	Советская	0103000020E6100000010000000500000069C9E369F99E524023D74D29AFBD4B4069C9E369F99E524002637D0393BF4B407B30293E3EA0524002637D0393BF4B407B30293E3EA0524023D74D29AFBD4B4069C9E369F99E524023D74D29AFBD4B40
76412	118	74.684055000000001	74.698562999999993	55.806306999999997	55.795611000000001	Школьная	0103000020E61000000100000005000000946A9F8EC7AB52403FABCC94D6E54B40946A9F8EC7AB524097C4591135E74B4085CC9541B5AC524097C4591135E74B4085CC9541B5AC52403FABCC94D6E54B40946A9F8EC7AB52403FABCC94D6E54B40
29268	118	74.684055000000001	74.698562999999993	55.806306999999997	55.795611000000001	Рабочая	0103000020E61000000100000005000000946A9F8EC7AB52403FABCC94D6E54B40946A9F8EC7AB524097C4591135E74B4085CC9541B5AC524097C4591135E74B4085CC9541B5AC52403FABCC94D6E54B40946A9F8EC7AB52403FABCC94D6E54B40
29400	31582	74.854366999999996	74.871191999999994	55.686660000000003	55.682107999999999	Зеленая	0103000020E6100000010000000500000006F2ECF2ADB65240842BA0504FD74B4006F2ECF2ADB6524056BC9179E4D74B405B22179CC1B7524056BC9179E4D74B405B22179CC1B75240842BA0504FD74B4006F2ECF2ADB65240842BA0504FD74B40
29566	740	75.066423	75.086248999999995	55.798636999999999	55.782789999999999	Советская	0103000020E61000000100000005000000F12C414640C4524063D1747632E44B40F12C414640C452401230BABC39E64B400394861A85C552401230BABC39E64B400394861A85C5524063D1747632E44B40F12C414640C4524063D1747632E44B40
29860	31267	74.492597000000004	74.505623	55.569209000000001	55.560693000000001	Школьная	0103000020E61000000100000005000000E54691B5869F52404E0CC9C9C4C74B40E54691B5869F524060CB2BD7DBC84B40BF4692205CA0524060CB2BD7DBC84B40BF4692205CA052404E0CC9C9C4C74B40E54691B5869F52404E0CC9C9C4C74B40
29267	258	74.831773999999996	74.856719999999996	55.809403000000003	55.806322000000002	Зеленая	0103000020E6100000010000000500000070EA03C93BB55240CD052E8F35E74B4070EA03C93BB5524064247B849AE74B4010751F80D4B6524064247B849AE74B4010751F80D4B65240CD052E8F35E74B4070EA03C93BB55240CD052E8F35E74B40
29105	30099	74.377200000000002	75.368527	55.988500000000002	55.186895	Юбилейная	0103000020E610000001000000050000004703780B249852409964E42CEC974B404703780B249852404A0C022B87FE4B405A2C45F295D752404A0C022B87FE4B405A2C45F295D752409964E42CEC974B404703780B249852409964E42CEC974B40
30064	30099	74.377200000000002	75.368527	55.988500000000002	55.186895	Школьная	0103000020E610000001000000050000004703780B249852409964E42CEC974B404703780B249852404A0C022B87FE4B405A2C45F295D752404A0C022B87FE4B405A2C45F295D752409964E42CEC974B404703780B249852409964E42CEC974B40
30066	30099	74.377200000000002	75.368527	55.988500000000002	55.186895	Транспортная	0103000020E610000001000000050000004703780B249852409964E42CEC974B404703780B249852404A0C022B87FE4B405A2C45F295D752404A0C022B87FE4B405A2C45F295D752409964E42CEC974B404703780B249852409964E42CEC974B40
29832	30099	74.377200000000002	75.368527	55.988500000000002	55.186895	Романенко	0103000020E610000001000000050000004703780B249852409964E42CEC974B404703780B249852404A0C022B87FE4B405A2C45F295D752404A0C022B87FE4B405A2C45F295D752409964E42CEC974B404703780B249852409964E42CEC974B40
29229	30099	74.377200000000002	75.368527	55.988500000000002	55.186895	Ленина	0103000020E610000001000000050000004703780B249852409964E42CEC974B404703780B249852404A0C022B87FE4B405A2C45F295D752404A0C022B87FE4B405A2C45F295D752409964E42CEC974B404703780B249852409964E42CEC974B40
29551	31972	75.208877999999999	75.219289000000003	55.260371999999997	55.254537999999997	Центральная	0103000020E61000000100000005000000A6B6D4415ECD52406CCB80B394A04B40A6B6D4415ECD5240A565A4DE53A14B40D8D7BAD408CE5240A565A4DE53A14B40D8D7BAD408CE52406CCB80B394A04B40A6B6D4415ECD52406CCB80B394A04B40
29389	31162	74.666071000000002	74.679860000000005	55.509146000000001	55.502344999999998	Зеленая	0103000020E61000000100000005000000197442E8A0AA5240912749D74CC04B40197442E8A0AA5240D27135B22BC14B40F37684D382AB5240D27135B22BC14B40F37684D382AB5240912749D74CC04B40197442E8A0AA5240912749D74CC04B40
28663	31835	75.025899999999993	75.042823999999996	55.232356000000003	55.221065000000003	Центральная	0103000020E61000000100000005000000D93D7958A8C1524027A5A0DB4B9C4B40D93D7958A8C15240C38366D7BD9D4B40F8DEDFA0BDC25240C38366D7BD9D4B40F8DEDFA0BDC2524027A5A0DB4B9C4B40D93D7958A8C1524027A5A0DB4B9C4B40
29837	31835	75.025899999999993	75.042823999999996	55.232356000000003	55.221065000000003	Калачинская	0103000020E61000000100000005000000D93D7958A8C1524027A5A0DB4B9C4B40D93D7958A8C15240C38366D7BD9D4B40F8DEDFA0BDC25240C38366D7BD9D4B40F8DEDFA0BDC2524027A5A0DB4B9C4B40D93D7958A8C1524027A5A0DB4B9C4B40
29048	31362	74.544053000000005	74.558066999999994	55.593837999999998	55.584415999999997	Колупаева	0103000020E610000001000000050000009B92ACC3D1A252402BA1BB24CECA4B409B92ACC3D1A252409F8F32E202CC4B40847EA65EB7A352409F8F32E202CC4B40847EA65EB7A352402BA1BB24CECA4B409B92ACC3D1A252402BA1BB24CECA4B40
29526	30481	74.723545000000001	74.752443999999997	55.389862000000001	55.382277999999999	Школьная	0103000020E61000000100000005000000CC0BB08F4EAE52407AFD497CEEB04B40CC0BB08F4EAE524001FA7DFFE6B14B409204E10A28B0524001FA7DFFE6B14B409204E10A28B052407AFD497CEEB04B40CC0BB08F4EAE52407AFD497CEEB04B40
29810	32123	75.066063999999997	75.084918999999999	55.467657000000003	55.456878000000003	Школьная	0103000020E6100000010000000500000059DC7F643AC45240862172FA7ABA4B4059DC7F643AC452406C5F402FDCBB4B40C7F319506FC552406C5F402FDCBB4B40C7F319506FC55240862172FA7ABA4B4059DC7F643AC45240862172FA7ABA4B40
76463	60848	74.806872999999996	74.828108999999998	55.444184999999997	55.438051999999999	Центральная	0103000020E61000000100000005000000A0C1A6CEA3B3524044F9821612B84B40A0C1A6CEA3B35240D72FD80DDBB84B407D21E4BCFFB45240D72FD80DDBB84B407D21E4BCFFB4524044F9821612B84B40A0C1A6CEA3B3524044F9821612B84B40
29118	31680	74.880067999999994	74.897468000000003	55.260396999999998	55.257314000000001	Школьная	0103000020E610000001000000050000006490BB0853B85240C76647AAEFA04B406490BB0853B85240FE7C5BB054A14B40384D9F1D70B95240FE7C5BB054A14B40384D9F1D70B95240C76647AAEFA04B406490BB0853B85240C76647AAEFA04B40
29539	30898	74.742940000000004	74.764661000000004	55.496006000000001	55.489983000000002	Центральная	0103000020E61000000100000005000000FAB836548CAF5240494C50C3B7BE4B40FAB836548CAF5240554FE61F7DBF4B40B5E1B034F0B05240554FE61F7DBF4B40B5E1B034F0B05240494C50C3B7BE4B40FAB836548CAF5240494C50C3B7BE4B40
29695	53031	75.077589000000003	75.092958999999993	55.608246000000001	55.598089999999999	Трудовая	0103000020E61000000100000005000000E161DA37F7C4524046088F368ECC4B40E161DA37F7C452401FF64201DBCD4B409B374E0AF3C552401FF64201DBCD4B409B374E0AF3C5524046088F368ECC4B40E161DA37F7C4524046088F368ECC4B40
29679	53028	75.019917000000007	75.039841999999993	55.293781000000003	55.274830999999999	Административный переулок	0103000020E610000001000000050000009BE8F35146C15240A77686A92DA34B409BE8F35146C15240D597A59D9AA54B4076C075C58CC25240D597A59D9AA54B4076C075C58CC25240A77686A92DA34B409BE8F35146C15240A77686A92DA34B40
29276	843	74.903873000000004	74.914213000000004	55.780335000000001	55.774020999999998	Школьная	0103000020E6100000010000000500000032AF230ED9B9524067B5C01E13E34B4032AF230ED9B952404B766C04E2E34B40FF243E7782BA52404B766C04E2E34B40FF243E7782BA524067B5C01E13E34B4032AF230ED9B9524067B5C01E13E34B40
29234	30334	74.974247000000005	74.984640999999996	55.448841999999999	55.441136999999998	Южная	0103000020E6100000010000000500000079CE16105ABE52401C075E2D77B84B4079CE16105ABE52401E8997A773B94B403F53AF5B04BF52401E8997A773B94B403F53AF5B04BF52401C075E2D77B84B4079CE16105ABE52401C075E2D77B84B40
29578	31410	74.976258999999999	74.981425000000002	55.529986000000001	55.521287000000001	Трудовая	0103000020E610000001000000050000003E5B07077BBE52403C6A4C88B9C24B403E5B07077BBE52403FABCC94D6C34B40849ECDAACFBE52403FABCC94D6C34B40849ECDAACFBE52403C6A4C88B9C24B403E5B07077BBE52403C6A4C88B9C24B40
29275	370	74.705237999999994	74.717885999999993	55.883797000000001	55.875359000000003	Заовражная	0103000020E610000001000000050000005F79909E22AD524030A182C30BF04B405F79909E22AD5240C6A6954220F14B4066101FD8F1AD5240C6A6954220F14B4066101FD8F1AD524030A182C30BF04B405F79909E22AD524030A182C30BF04B40
29974	631	74.504446000000002	74.522025999999997	55.837308	55.825355000000002	Сибирская	0103000020E610000001000000050000004626E0D748A05240884B8E3BA5E94B404626E0D748A05240EF5696E82CEB4B40596ABDDF68A15240EF5696E82CEB4B40596ABDDF68A15240884B8E3BA5E94B404626E0D748A05240884B8E3BA5E94B40
29115	30811	74.849705	74.863566000000006	55.538677	55.529868	Центральная	0103000020E61000000100000005000000DA8F149161B652403599F1B6D2C34B40DA8F149161B65240BF0D315EF3C44B4001FC53AA44B75240BF0D315EF3C44B4001FC53AA44B752403599F1B6D2C34B40DA8F149161B652403599F1B6D2C34B40
29787	30572	74.943353999999999	74.967465000000004	55.352930999999998	55.338633000000002	Петра Ильичева	0103000020E6100000010000000500000040A374E95FBC5240562C7E5358AB4B4040A374E95FBC52404E5FCFD72CAD4B4094C151F2EABD52404E5FCFD72CAD4B4094C151F2EABD5240562C7E5358AB4B4040A374E95FBC5240562C7E5358AB4B40
29885	28307	71.139070000000004	71.155590000000004	55.891719000000002	55.881379000000003	Школьная	0103000020E61000000100000005000000B476DB85E6C85140CB30EE06D1F04B40B476DB85E6C85140651C23D923F24B406B65C22FF5C95140651C23D923F24B406B65C22FF5C95140CB30EE06D1F04B40B476DB85E6C85140CB30EE06D1F04B40
29094	29164	71.704909000000001	71.723575999999994	55.681832999999997	55.669457999999999	Школьная	0103000020E61000000100000005000000FD69A33A1DED5140D505BCCCB0D54B40FD69A33A1DED5140B22AC24D46D74B40E90AB6114FEE5140B22AC24D46D74B40E90AB6114FEE5140D505BCCCB0D54B40FD69A33A1DED5140D505BCCCB0D54B40
29983	29877	71.759050999999999	71.795090999999999	55.422201000000001	55.413176999999997	Центральная	0103000020E61000000100000005000000C03FA54A94F05140CD3AE3FBE2B44B40C03FA54A94F0514054ABAFAE0AB64B4003965CC5E2F2514054ABAFAE0AB64B4003965CC5E2F25140CD3AE3FBE2B44B40C03FA54A94F05140CD3AE3FBE2B44B40
29226	29921	71.502302999999998	71.5261	55.475470000000001	55.469056000000002	Центральная	0103000020E61000000100000005000000B16B7BBB25E051400DFFE9060ABC4B40B16B7BBB25E05140541D7233DCBC4B403D9B559FABE15140541D7233DCBC4B403D9B559FABE151400DFFE9060ABC4B40B16B7BBB25E051400DFFE9060ABC4B40
29919	29661	71.627762000000004	71.646663000000004	55.325794999999999	55.312685999999999	Школьная	0103000020E61000000100000005000000FBEAAA402DE8514062F5471806A84B40FBEAAA402DE85140A4198BA6B3A94B40212235ED62E95140A4198BA6B3A94B40212235ED62E9514062F5471806A84B40FBEAAA402DE8514062F5471806A84B40
29334	28458	70.575916000000007	70.592256000000006	55.455663000000001	55.443868999999999	Зелёная	0103000020E61000000100000005000000904FC8CEDBA45140A75A0BB3D0B84B40904FC8CEDBA45140A67F492A53BA4B4007B7B585E7A55140A67F492A53BA4B4007B7B585E7A55140A75A0BB3D0B84B40904FC8CEDBA45140A75A0BB3D0B84B40
30039	29341	71.096265000000002	71.101788999999997	55.543807000000001	55.538314999999997	Школьная	0103000020E61000000100000005000000F7AFAC3429C651401EF98381E7C44B40F7AFAC3429C65140FE2AC0779BC54B40EC8502B683C65140FE2AC0779BC54B40EC8502B683C651401EF98381E7C44B40F7AFAC3429C651401EF98381E7C44B40
29342	28818	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	Центральная	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
29287	28238	71.277904000000007	71.289959999999994	55.476255000000002	55.469177999999999	Центральная	0103000020E610000001000000050000005EDBDB2DC9D15140580053060EBC4B405EDBDB2DC9D151403BC780ECF5BC4B407B4963B48ED251403BC780ECF5BC4B407B4963B48ED25140580053060EBC4B405EDBDB2DC9D15140580053060EBC4B40
29917	29516	71.404674	71.426692000000003	55.746988000000002	55.735717999999999	Школьная	0103000020E61000000100000005000000A8E2C62DE6D951400D8AE6012CDE4B40A8E2C62DE6D951409240834D9DDF4B40C05DF6EB4EDB51409240834D9DDF4B40C05DF6EB4EDB51400D8AE6012CDE4B40A8E2C62DE6D951400D8AE6012CDE4B40
29777	29710	71.625849000000002	71.644425999999996	55.405183999999998	55.393160000000002	Школьная	0103000020E61000000100000005000000FFCEF6E80DE85140350C1F1153B24B40FFCEF6E80DE85140656EBE11DDB34B404BAC8C463EE95140656EBE11DDB34B404BAC8C463EE95140350C1F1153B24B40FFCEF6E80DE85140350C1F1153B24B40
29632	29256	70.976690000000005	70.985476000000006	55.453110000000002	55.446523999999997	Южная	0103000020E610000001000000050000002315C61682BE51408670CCB227B94B402315C61682BE5140CBBE2B82FFB94B408CBFED0912BF5140CBBE2B82FFB94B408CBFED0912BF51408670CCB227B94B402315C61682BE51408670CCB227B94B40
29151	30001	71.882390000000001	71.896384999999995	55.389049	55.375393000000003	Северная	0103000020E610000001000000050000005114E81379F85140DC12B9E00CB04B405114E81379F8514050C58D5BCCB14B40FFE7305F5EF9514050C58D5BCCB14B40FFE7305F5EF95140DC12B9E00CB04B405114E81379F85140DC12B9E00CB04B40
29482	28046	71.042733999999996	71.059533000000002	55.769150000000003	55.760539999999999	Школьная	0103000020E61000000100000005000000581B6327BCC2514061A6ED5F59E14B40581B6327BCC25140F5DBD78173E24B4019028063CFC35140F5DBD78173E24B4019028063CFC3514061A6ED5F59E14B40581B6327BCC2514061A6ED5F59E14B40
29071	28003	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	Школьная	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
29349	29237	70.989428000000004	71.010717999999997	55.529527000000002	55.516393999999998	Зелёная	0103000020E61000000100000005000000CA6FD1C952BF5140E1ECD63219C24B40CA6FD1C952BF5140ACAC6D8AC7C34B40A0DE8C9AAFC05140ACAC6D8AC7C34B40A0DE8C9AAFC05140E1ECD63219C24B40CA6FD1C952BF5140E1ECD63219C24B40
29757	28554	70.542165999999995	70.555982	55.325333999999998	55.308244000000002	Центральная	0103000020E6100000010000000500000033C005D9B2A251401898158A74A74B4033C005D9B2A251407023658BA4A94B408ACA863595A351407023658BA4A94B408ACA863595A351401898158A74A74B4033C005D9B2A251401898158A74A74B40
29217	29596	71.334130000000002	71.341764999999995	55.849226000000002	55.844399000000003	Зеленая	0103000020E6100000010000000500000033A7CB6262D5514037E3344415EC4B4033A7CB6262D55140DA740470B3EC4B40B77A4E7ADFD55140DA740470B3EC4B40B77A4E7ADFD5514037E3344415EC4B4033A7CB6262D5514037E3344415EC4B40
29755	28172	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	Центральная	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
30031	28127	71.292986999999997	71.306506999999996	55.327858999999997	55.31785	Зелёная	0103000020E61000000100000005000000CDC98B4CC0D251404D840D4FAFA84B40CDC98B4CC0D251408159A148F7A94B40AF3F89CF9DD351408159A148F7A94B40AF3F89CF9DD351404D840D4FAFA84B40CDC98B4CC0D251404D840D4FAFA84B40
29211	29157	71.814826999999994	71.832587000000004	55.643754000000001	55.632413	Школьная	0103000020E610000001000000050000007539252026F451405A48C0E8F2D04B407539252026F45140A855F48766D24B40C904FC1A49F55140A855F48766D24B40C904FC1A49F551405A48C0E8F2D04B407539252026F451405A48C0E8F2D04B40
29745	27322	71.308769999999996	71.386465999999999	55.601671000000003	55.552587000000003	переулок Транспортный	0103000020E6100000010000000500000019FF3EE3C2D35140EE98BA2BBBC64B4019FF3EE3C2D35140CFF9298E03CD4B4005C1E3DBBBD85140CFF9298E03CD4B4005C1E3DBBBD85140EE98BA2BBBC64B4019FF3EE3C2D35140EE98BA2BBBC64B40
30018	27322	71.308769999999996	71.386465999999999	55.601671000000003	55.552587000000003	Чкалова	0103000020E6100000010000000500000019FF3EE3C2D35140EE98BA2BBBC64B4019FF3EE3C2D35140CFF9298E03CD4B4005C1E3DBBBD85140CFF9298E03CD4B4005C1E3DBBBD85140EE98BA2BBBC64B4019FF3EE3C2D35140EE98BA2BBBC64B40
29606	27322	71.308769999999996	71.386465999999999	55.601671000000003	55.552587000000003	Пролетарская	0103000020E6100000010000000500000019FF3EE3C2D35140EE98BA2BBBC64B4019FF3EE3C2D35140CFF9298E03CD4B4005C1E3DBBBD85140CFF9298E03CD4B4005C1E3DBBBD85140EE98BA2BBBC64B4019FF3EE3C2D35140EE98BA2BBBC64B40
29061	27322	71.308769999999996	71.386465999999999	55.601671000000003	55.552587000000003	Красная	0103000020E6100000010000000500000019FF3EE3C2D35140EE98BA2BBBC64B4019FF3EE3C2D35140CFF9298E03CD4B4005C1E3DBBBD85140CFF9298E03CD4B4005C1E3DBBBD85140EE98BA2BBBC64B4019FF3EE3C2D35140EE98BA2BBBC64B40
29318	27322	71.308769999999996	71.386465999999999	55.601671000000003	55.552587000000003	Кирова	0103000020E6100000010000000500000019FF3EE3C2D35140EE98BA2BBBC64B4019FF3EE3C2D35140CFF9298E03CD4B4005C1E3DBBBD85140CFF9298E03CD4B4005C1E3DBBBD85140EE98BA2BBBC64B4019FF3EE3C2D35140EE98BA2BBBC64B40
29744	27322	71.308769999999996	71.386465999999999	55.601671000000003	55.552587000000003	Вокзальная	0103000020E6100000010000000500000019FF3EE3C2D35140EE98BA2BBBC64B4019FF3EE3C2D35140CFF9298E03CD4B4005C1E3DBBBD85140CFF9298E03CD4B4005C1E3DBBBD85140EE98BA2BBBC64B4019FF3EE3C2D35140EE98BA2BBBC64B40
29897	29011	71.398394999999994	71.420439999999999	55.677442999999997	55.668416999999998	Колхозная	0103000020E61000000100000005000000F4F8BD4D7FD95140938B31B08ED54B40F4F8BD4D7FD95140BAF3C473B6D64B40897B2C7DE8DA5140BAF3C473B6D64B40897B2C7DE8DA5140938B31B08ED54B40F4F8BD4D7FD95140938B31B08ED54B40
29485	29419	71.220978000000002	71.229709999999997	55.588766	55.581459000000002	Новая	0103000020E61000000100000005000000ACC8E88024CE5140817B9E3F6DCA4B40ACC8E88024CE5140957F2DAF5CCB4B401B649291B3CE5140957F2DAF5CCB4B401B649291B3CE5140817B9E3F6DCA4B40ACC8E88024CE5140817B9E3F6DCA4B40
29354	29419	71.220978000000002	71.229709999999997	55.588766	55.581459000000002	Зелёная	0103000020E61000000100000005000000ACC8E88024CE5140817B9E3F6DCA4B40ACC8E88024CE5140957F2DAF5CCB4B401B649291B3CE5140957F2DAF5CCB4B401B649291B3CE5140817B9E3F6DCA4B40ACC8E88024CE5140817B9E3F6DCA4B40
29874	27781	71.829847000000001	71.847031999999999	55.513590999999998	55.501151	Озёрная	0103000020E61000000100000005000000C26B97361CF55140C9AD49B725C04B40C26B97361CF551408D429259BDC14B4097AAB4C535F651408D429259BDC14B4097AAB4C535F65140C9AD49B725C04B40C26B97361CF55140C9AD49B725C04B40
29506	28885	70.751886999999996	70.788303999999997	55.789192999999997	55.768541999999997	Кирова	0103000020E6100000010000000500000067D2A6EA1EB051401CCD91955FE24B4067D2A6EA1EB05140B69DB64604E54B4095D39E9273B25140B69DB64604E54B4095D39E9273B251401CCD91955FE24B4067D2A6EA1EB051401CCD91955FE24B40
29503	28787	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	Ленина	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
29225	29948	71.930673999999996	71.950355999999999	55.446514000000001	55.439089000000003	Зелёная	0103000020E61000000100000005000000334FAE2990FB514045847F1134B84B40334FAE2990FB5140639AE95E27B94B40ACE3F8A1D2FC5140639AE95E27B94B40ACE3F8A1D2FC514045847F1134B84B40334FAE2990FB514045847F1134B84B40
29088	28708	70.993533999999997	71.020384000000007	55.240251000000001	55.224967999999997	Центральная	0103000020E61000000100000005000000B35DA10F96BF5140C1525DC0CB9C4B40B35DA10F96BF514068EA758BC09E4B402657B1F84DC1514068EA758BC09E4B402657B1F84DC15140C1525DC0CB9C4B40B35DA10F96BF5140C1525DC0CB9C4B40
29762	53036	71.627520000000004	71.759320000000002	55.491247999999999	55.416345999999997	остановочный пункт Кочковатский	0103000020E610000001000000050000008065A54929E8514003E962D34AB54B408065A54929E85140DA1CE736E1BE4B40B8CCE9B298F05140DA1CE736E1BE4B40B8CCE9B298F0514003E962D34AB54B408065A54929E8514003E962D34AB54B40
29612	27828	71.645117999999997	71.653677999999999	55.516063000000003	55.503104	Южная	0103000020E61000000100000005000000E603029D49E951404F3E3DB665C04B40E603029D49E951407CD6355A0EC24B40570740DCD5E951407CD6355A0EC24B40570740DCD5E951404F3E3DB665C04B40E603029D49E951404F3E3DB665C04B40
29507	28962	70.803711000000007	70.813556000000005	55.770076000000003	55.760596	Зелёная	0103000020E61000000100000005000000DF1B430070B35140F5BBB0355BE14B40DF1B430070B351409EB7B1D991E24B40BC5D2F4D11B451409EB7B1D991E24B40BC5D2F4D11B45140F5BBB0355BE14B40DF1B430070B35140F5BBB0355BE14B40
29569	29795	71.700210999999996	71.728086000000005	55.234492000000003	55.224254000000002	Школьная	0103000020E610000001000000050000002A53CC41D0EC5140A4FFE55AB49C4B402A53CC41D0EC51403A9677D5039E4B403BAB05F698EE51403A9677D5039E4B403BAB05F698EE5140A4FFE55AB49C4B402A53CC41D0EC5140A4FFE55AB49C4B40
30034	28576	70.970877999999999	71.001959999999997	55.355234000000003	55.334183000000003	Советская	0103000020E61000000100000005000000FA997ADD22BE514089F02F82C6AA4B40FA997ADD22BE5140B136C64E78AD4B409CF9D51C20C05140B136C64E78AD4B409CF9D51C20C0514089F02F82C6AA4B40FA997ADD22BE514089F02F82C6AA4B40
29200	28403	70.623436999999996	70.638771000000006	55.350273999999999	55.339390999999999	Центральная	0103000020E6100000010000000500000072874D64E6A7514043C70E2A71AB4B4072874D64E6A75140CE5147C7D5AC4B4087A8C29FE1A85140CE5147C7D5AC4B4087A8C29FE1A8514043C70E2A71AB4B4072874D64E6A7514043C70E2A71AB4B40
29212	29107	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	Абая	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
29756	28372	70.932691000000005	70.959191000000004	55.837888999999997	55.825415999999997	Центральная	0103000020E6100000010000000500000082919735B1BB51402DCC423BA7E94B4082919735B1BB5140CD565EF23FEB4B4086E7A56263BD5140CD565EF23FEB4B4086E7A56263BD51402DCC423BA7E94B4082919735B1BB51402DCC423BA7E94B40
29310	52985	71.551368999999994	71.562571000000005	55.770856000000002	55.759117000000003	Отобая	0103000020E61000000100000005000000CEC133A149E35140386BF0BE2AE14B40CEC133A149E3514073F6CE68ABE24B4065ABCB2901E4514073F6CE68ABE24B4065ABCB2901E45140386BF0BE2AE14B40CEC133A149E35140386BF0BE2AE14B40
29074	27912	70.825395999999998	70.837693999999999	55.467059999999996	55.458306999999998	Центральная	0103000020E61000000100000005000000F38FBE49D3B451409143C4CDA9BA4B40F38FBE49D3B4514087A2409FC8BB4B408C834BC79CB5514087A2409FC8BB4B408C834BC79CB551409143C4CDA9BA4B40F38FBE49D3B451409143C4CDA9BA4B40
29499	28636	70.860861	70.879707999999994	55.349511999999997	55.329610000000002	Центральная	0103000020E61000000100000005000000B859BC5818B75140A03715A930AA4B40B859BC5818B751409FC728CFBCAC4B40E481C8224DB851409FC728CFBCAC4B40E481C8224DB85140A03715A930AA4B40B859BC5818B75140A03715A930AA4B40
29081	28249	70.966333000000006	70.989391999999995	55.929620999999997	55.915830999999997	Горького	0103000020E61000000100000005000000EB025E66D8BD5140DCD440F339F54B40EB025E66D8BD5140605628D2FDF64B4023BBD23252BF5140605628D2FDF64B4023BBD23252BF5140DCD440F339F54B40EB025E66D8BD5140DCD440F339F54B40
29195	28092	71.317160999999999	71.349491	55.393819000000001	55.383279999999999	Бондаренко	0103000020E6100000010000000500000044A4A65D4CD45140FE9AAC510FB14B4044A4A65D4CD451408FC536A968B24B40C4CF7F0F5ED651408FC536A968B24B40C4CF7F0F5ED65140FE9AAC510FB14B4044A4A65D4CD45140FE9AAC510FB14B40
29760	28691	71.178515000000004	71.209309000000005	55.333419999999997	55.323228999999998	Центральная	0103000020E610000001000000050000001CB62DCA6CCB5140340F60915FA94B401CB62DCA6CCB514089EAAD81ADAA4B408B70935165CD514089EAAD81ADAA4B408B70935165CD5140340F60915FA94B401CB62DCA6CCB5140340F60915FA94B40
29703	17761	71.948442999999997	71.962204999999997	55.331417999999999	55.325220999999999	Центральная	0103000020E61000000100000005000000B0C7444AB3FC5140787C7BD7A0A94B40B0C7444AB3FC514022A7AFE76BAA4B400DC347C494FD514022A7AFE76BAA4B400DC347C494FD5140787C7BD7A0A94B40B0C7444AB3FC5140787C7BD7A0A94B40
29640	29788	71.825507999999999	71.855934000000005	55.321430999999997	55.314003	Слободская	0103000020E6100000010000000500000087A5811FD5F4514046EC134031A84B4087A5811FD5F45140D575A8A624A94B403562669FC7F65140D575A8A624A94B403562669FC7F6514046EC134031A84B4087A5811FD5F4514046EC134031A84B40
29914	29411	71.255886000000004	71.268867	55.527509000000002	55.523207999999997	Центральная	0103000020E610000001000000050000004660AC6F60D05140B680D07AF8C24B404660AC6F60D051403FAC376A85C34B4050FEEE1D35D151403FAC376A85C34B4050FEEE1D35D15140B680D07AF8C24B404660AC6F60D05140B680D07AF8C24B40
29898	28937	70.570041000000003	70.581952000000001	55.695290999999997	55.688308999999997	Озерная	0103000020E6100000010000000500000044183F8D7BA451406F4562821AD84B4044183F8D7BA45140001AA54BFFD84B40E0F599B33EA55140001AA54BFFD84B40E0F599B33EA551406F4562821AD84B4044183F8D7BA451406F4562821AD84B40
29480	27861	70.794099000000003	70.819117000000006	55.535482999999999	55.518172999999997	Советская	0103000020E6100000010000000500000053B29C84D2B25140C9552C7E53C24B4053B29C84D2B251403048FAB48AC44B4040A6B5696CB451403048FAB48AC44B4040A6B5696CB45140C9552C7E53C24B4053B29C84D2B25140C9552C7E53C24B40
29765	29036	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	Центральная	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
29478	27702	71.752125000000007	71.766587999999999	55.485177999999998	55.477061999999997	Молодёжная	0103000020E610000001000000050000004260E5D022F0514009151C5E10BD4B404260E5D022F051408D5E0D501ABE4B4063601DC70FF151408D5E0D501ABE4B4063601DC70FF1514009151C5E10BD4B404260E5D022F0514009151C5E10BD4B40
29213	29327	71.052408999999997	71.071057999999994	55.528956000000001	55.522163999999997	Центральная	0103000020E61000000100000005000000074147AB5AC3514003931B45D6C24B40074147AB5AC35140F18288D4B4C34B40A087DA368CC45140F18288D4B4C34B40A087DA368CC4514003931B45D6C24B40074147AB5AC3514003931B45D6C24B40
29639	29503	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	Школьная	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
29728	26255	76.026578000000001	76.045668000000006	56.451593000000003	56.437556999999998	Центральная	0103000020E61000000100000005000000C2323674B3015340649126DE01384C40C2323674B3015340200DA7CCCD394C40529E7939EC025340200DA7CCCD394C40529E7939EC025340649126DE01384C40C2323674B3015340649126DE01384C40
29743	26118	75.384075999999993	75.392645999999999	56.35924	56.350611999999998	Новостройка	0103000020E610000001000000050000006CCB80B394D85240E6CAA0DAE02C4C406CCB80B394D8524020B58993FB2D4C40EF39B01C21D9524020B58993FB2D4C40EF39B01C21D95240E6CAA0DAE02C4C406CCB80B394D85240E6CAA0DAE02C4C40
29867	48587	75.681257000000002	75.695873000000006	56.372053999999999	56.359808000000001	Школьная	0103000020E61000000100000005000000F3CAF5B699EB52406A6B44300E2E4C40F3CAF5B699EB5240492C29779F2F4C40D84AE82E89EC5240492C29779F2F4C40D84AE82E89EC52406A6B44300E2E4C40F3CAF5B699EB52406A6B44300E2E4C40
30075	48587	75.681257000000002	75.695873000000006	56.372053999999999	56.359808000000001	Ушаковская	0103000020E61000000100000005000000F3CAF5B699EB52406A6B44300E2E4C40F3CAF5B699EB5240492C29779F2F4C40D84AE82E89EC5240492C29779F2F4C40D84AE82E89EC52406A6B44300E2E4C40F3CAF5B699EB52406A6B44300E2E4C40
29824	25294	75.513819999999996	75.542997	56.508102999999998	56.494132	Молодежная	0103000020E61000000100000005000000F701486DE2E052401BF4A5B73F3F4C40F701486DE2E05240EFFFE38409414C40DF347D76C0E25240EFFFE38409414C40DF347D76C0E252401BF4A5B73F3F4C40F701486DE2E052401BF4A5B73F3F4C40
28697	14212	74.797297	74.812802000000005	56.377217999999999	56.369610999999999	Мира 	0103000020E61000000100000005000000BB0CFFE906B35240F59ECA694F2F4C40BB0CFFE906B3524034BBEEAD48304C40E607AEF204B4524034BBEEAD48304C40E607AEF204B45240F59ECA694F2F4C40BB0CFFE906B35240F59ECA694F2F4C40
29053	48627	75.557703000000004	75.580034999999995	56.350456999999999	56.339956000000001	Центральная	0103000020E610000001000000050000006478EC67B1E352401C0A9FAD832B4C406478EC67B1E35240BFD364C6DB2C4C4043E21E4B1FE55240BFD364C6DB2C4C4043E21E4B1FE552401C0A9FAD832B4C406478EC67B1E352401C0A9FAD832B4C40
29527	48530	75.193652	75.223016999999999	56.575890000000001	56.568123999999997	Центральная	0103000020E6100000010000000500000085B35BCB64CC52404E098849B8484C4085B35BCB64CC5240F60B76C3B6494C40EE5C18E945CE5240F60B76C3B6494C40EE5C18E945CE52404E098849B8484C4085B35BCB64CC52404E098849B8484C40
29051	48437	74.933651999999995	74.951879000000005	56.584308	56.572111	Зеленая	0103000020E61000000100000005000000147651F4C0BB52404757E9EE3A494C40147651F4C0BB52404565C39ACA4A4C40F3AFE595EBBC52404565C39ACA4A4C40F3AFE595EBBC52404757E9EE3A494C40147651F4C0BB52404757E9EE3A494C40
29738	48793	75.470405	75.485128000000003	56.380656999999999	56.372931000000001	Школьная	0103000020E61000000100000005000000FEB7921D1BDE52401155F833BC2F4C40FEB7921D1BDE52402AFF5A5EB9304C40EE974F560CDF52402AFF5A5EB9304C40EE974F560CDF52401155F833BC2F4C40FEB7921D1BDE52401155F833BC2F4C40
29587	47925	74.893236999999999	74.917841999999993	56.446275	56.438338000000002	Центральная	0103000020E61000000100000005000000F0A485CB2AB952400A4CA7751B384C40F0A485CB2AB95240DE02098A1F394C404B395FECBDBA5240DE02098A1F394C404B395FECBDBA52400A4CA7751B384C40F0A485CB2AB952400A4CA7751B384C40
29167	48140	74.898302999999999	74.933338000000006	56.212629999999997	56.193100999999999	Центральная	0103000020E6100000010000000500000084B9DDCB7DB9524096E99788B7184C4084B9DDCB7DB952400113B875371B4C404D874ECFBBBB52400113B875371B4C404D874ECFBBBB524096E99788B7184C4084B9DDCB7DB9524096E99788B7184C40
29481	26174	75.839262000000005	75.873497	56.401121000000003	56.385741000000003	Трактовая	0103000020E61000000100000005000000A3B1F677B6F55240F9DC09F65F314C40A3B1F677B6F55240925ED4EE57334C40DD09F65FE7F75240925ED4EE57334C40DD09F65FE7F75240F9DC09F65F314C40A3B1F677B6F55240F9DC09F65F314C40
73883	60136	75.421599000000001	75.453579000000005	56.356053000000003	56.340998999999996	Тарская	0103000020E61000000100000005000000AF415F7AFBDA5240FE7BF0DAA52B4C40AF415F7AFBDA524044520B25932D4C40C1C9367007DD524044520B25932D4C40C1C9367007DD5240FE7BF0DAA52B4C40AF415F7AFBDA5240FE7BF0DAA52B4C40
29182	48657	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	Лисина	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
29311	48657	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	Ленина	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
29870	48657	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	Кооперативная	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
29448	25791	74.908302000000006	74.933329000000001	56.046759999999999	56.03105	Юбилейная	0103000020E610000001000000050000000D39B69E21BA524039454772F9034C400D39B69E21BA524067614F3BFC054C4023DA8EA9BBBB524067614F3BFC054C4023DA8EA9BBBB524039454772F9034C400D39B69E21BA524039454772F9034C40
29042	52962	75.91525	75.947563000000002	56.552954999999997	56.542054	Солнечная	0103000020E610000001000000050000007F6ABC7493FA52403F55850662454C407F6ABC7493FA52407094BC3AC7464C4094F947DFA4FC52407094BC3AC7464C4094F947DFA4FC52403F55850662454C407F6ABC7493FA52403F55850662454C40
29849	25010	75.074993000000006	75.108194999999995	56.412362000000002	56.389547999999998	Центральная	0103000020E61000000100000005000000749B70AFCCC45240711C78B5DC314C40749B70AFCCC452407C0E2C47C8344C40CEA5B8AAECC652407C0E2C47C8344C40CEA5B8AAECC65240711C78B5DC314C40749B70AFCCC45240711C78B5DC314C40
29063	26053	75.553166000000004	75.573297999999994	56.308805	56.294320999999997	Центральная	0103000020E6100000010000000500000096D05D1267E3524054C37E4FAC254C4096D05D1267E35240AFEB17EC86274C402E3718EAB0E45240AFEB17EC86274C402E3718EAB0E4524054C37E4FAC254C4096D05D1267E3524054C37E4FAC254C40
29446	48054	75.806867999999994	75.830539000000002	56.449767000000001	56.433878999999997	Береговая	0103000020E61000000100000005000000170CAEB9A3F35240E9B5D95889374C40170CAEB9A3F35240F7E80DF791394C405DC30C8D27F55240F7E80DF791394C405DC30C8D27F55240E9B5D95889374C40170CAEB9A3F35240E9B5D95889374C40
29857	48119	74.936104999999998	74.958410000000001	56.179831	56.166916999999998	40 лет Победы	0103000020E61000000100000005000000D027F224E9BB5240BE1248895D154C40D027F224E9BB52404BE7C3B304174C40338AE59656BD52404BE7C3B304174C40338AE59656BD5240BE1248895D154C40D027F224E9BB5240BE1248895D154C40
29383	48232	75.022746999999995	75.033975999999996	55.930070000000001	55.921042	Копьевская	0103000020E610000001000000050000004145D5AF74C15240081F4AB4E4F54B404145D5AF74C15240D07EA4880CF74B405436ACA92CC25240D07EA4880CF74B405436ACA92CC25240081F4AB4E4F54B404145D5AF74C15240081F4AB4E4F54B40
29172	47988	75.557056000000003	75.594605999999999	56.464122000000003	56.454631999999997	Ленина	0103000020E61000000100000005000000998235CEA6E3524087DBA161313A4C40998235CEA6E3524054AD8559683B4C40580053060EE6524054AD8559683B4C40580053060EE6524087DBA161313A4C40998235CEA6E3524087DBA161313A4C40
30109	53106	75.135818	75.167951000000002	56.391511000000001	56.382890000000003	улица Центральная	0103000020E61000000100000005000000520DFB3DB1C8524094FB1D8A02314C40520DFB3DB1C852401B834E081D324C4027158DB5BFCA52401B834E081D324C4027158DB5BFCA524094FB1D8A02314C40520DFB3DB1C8524094FB1D8A02314C40
28671	48094	74.748204000000001	74.768946	56.048293999999999	56.032111999999998	Центральная	0103000020E6100000010000000500000021AF0793E2AF524092E7FA3E1C044C4021AF0793E2AF5240E84B6F7F2E064C40F698486936B15240E84B6F7F2E064C40F698486936B1524092E7FA3E1C044C4021AF0793E2AF524092E7FA3E1C044C40
29977	25313	75.899844000000002	75.927781999999993	56.599707000000002	56.580227999999998	Центральная	0103000020E610000001000000050000001EE0490B97F952409B1C3EE9444A4C401EE0490B97F952405517F032C34C4C4051F4C0C760FB52405517F032C34C4C4051F4C0C760FB52409B1C3EE9444A4C401EE0490B97F952409B1C3EE9444A4C40
29602	26640	75.174086000000003	75.191468999999998	56.654259000000003	56.649082999999997	Старая	0103000020E61000000100000005000000412C9B3924CB5240DDB1D82615534C40412C9B3924CB52408D0E48C2BE534C40A94C310741CC52408D0E48C2BE534C40A94C310741CC5240DDB1D82615534C40412C9B3924CB5240DDB1D82615534C40
28690	25464	74.838313999999997	74.861418999999998	55.976725000000002	55.953567999999997	Зеленая	0103000020E61000000100000005000000DA71C3EFA6B552408D4127840EFA4B40DA71C3EFA6B55240C217265305FD4B40CB49287D21B75240C217265305FD4B40CB49287D21B752408D4127840EFA4B40DA71C3EFA6B552408D4127840EFA4B40
9725	26512	74.85284	74.866144000000006	56.496324000000001	56.487220000000001	Молодежная	0103000020E610000001000000050000001F2E39EE94B6524083FA96395D3E4C401F2E39EE94B65240261C7A8B873F4C401B683EE76EB75240261C7A8B873F4C401B683EE76EB7524083FA96395D3E4C401F2E39EE94B6524083FA96395D3E4C40
29600	26716	75.087462000000002	75.099023000000003	56.575482999999998	56.557107999999999	Песчаная	0103000020E61000000100000005000000236937FA98C55240842BA0504F474C40236937FA98C55240B5334C6DA9494C4051A3906456C65240B5334C6DA9494C4051A3906456C65240842BA0504F474C40236937FA98C55240842BA0504F474C40
29997	48205	74.967536999999993	74.977697000000006	56.020149000000004	56.009445999999997	Центральная	0103000020E61000000100000005000000E02A4F20ECBD5240FC89CA8635014C40E02A4F20ECBD52400806103E94024C406E19709692BE52400806103E94024C406E19709692BE5240FC89CA8635014C40E02A4F20ECBD5240FC89CA8635014C40
29869	26000	75.398656000000003	75.425498000000005	56.301833000000002	56.282429999999998	Центральная	0103000020E61000000100000005000000AB96749483D9524063B48EAA26244C40AB96749483D9524042EDB776A2264C40DCA0F65B3BDB524042EDB776A2264C40DCA0F65B3BDB524063B48EAA26244C40AB96749483D9524063B48EAA26244C40
29994	47954	75.125361999999996	75.163459000000003	56.310732000000002	56.297203000000003	Центральная	0103000020E61000000100000005000000508A56EE05C85240F5A276BF0A264C40508A56EE05C852400CE9F010C6274C4029CFBC1C76CA52400CE9F010C6274C4029CFBC1C76CA5240F5A276BF0A264C40508A56EE05C85240F5A276BF0A264C40
29241	26315	76.077127000000004	76.091984999999994	56.444906000000003	56.436521999999997	Центральная	0103000020E61000000100000005000000DFA815A6EF04534004FEF0F3DF374C40DFA815A6EF045340A8E507AEF2384C403EAE0D15E3055340A8E507AEF2384C403EAE0D15E305534004FEF0F3DF374C40DFA815A6EF04534004FEF0F3DF374C40
29449	25678	74.988996999999998	75.021732	56.144185999999998	56.137269000000003	Центральная	0103000020E61000000100000005000000E5B512BA4BBF524098E0D40792114C40E5B512BA4BBF52404145D5AF74124C40B5519D0E64C152404145D5AF74124C40B5519D0E64C1524098E0D40792114C40E5B512BA4BBF524098E0D40792114C40
29452	1780	75.917433000000003	75.943933000000001	56.415588999999997	56.403995000000002	Центральная	0103000020E610000001000000050000005BD1E638B7FA5240AF5FB01BB6334C405BD1E638B7FA5240E6C9350532354C405F27F56569FC5240E6C9350532354C405F27F56569FC5240AF5FB01BB6334C405BD1E638B7FA5240AF5FB01BB6334C40
29722	24985	75.038989000000001	75.069837000000007	56.421081000000001	56.406998999999999	Центральная	0103000020E61000000100000005000000D7F9B7CB7EC252409A40118B18344C40D7F9B7CB7EC25240C6FB71FBE5354C4040C39B3578C45240C6FB71FBE5354C4040C39B3578C452409A40118B18344C40D7F9B7CB7EC252409A40118B18344C40
29852	24902	74.737630999999993	74.772872000000007	56.171483000000002	56.135728999999998	Боровая	0103000020E610000001000000050000000261A75835AF5240340F60915F114C400261A75835AF5240F568AA27F3154C40A0FF1EBC76B15240F568AA27F3154C40A0FF1EBC76B15240340F60915F114C400261A75835AF5240340F60915F114C40
29610	53023	75.196526000000006	75.271095000000003	56.387937999999998	56.355904000000002	Нахимова	0103000020E6100000010000000500000014B4C9E193CC5240FF4124438E2D4C4014B4C9E193CC52401570CFF3A7314C40FCC6D79E59D152401570CFF3A7314C40FCC6D79E59D15240FF4124438E2D4C4014B4C9E193CC5240FF4124438E2D4C40
79363	61540	71.685191000000003	71.694929000000002	54.797818999999997	54.789710999999997	Центральная	0103000020E61000000100000005000000DE205A2BDAEB51404E25034015654B40DE205A2BDAEB51404F90D8EE1E664B40B0027CB779EC51404F90D8EE1E664B40B0027CB779EC51404E25034015654B40DE205A2BDAEB51404E25034015654B40
29882	49335	72.102108000000001	72.134106000000003	54.919839000000003	54.905783	Ленина	0103000020E610000001000000050000003D2AFEEF88065240EA2285B2F0734B403D2AFEEF88065240ED4ACB48BD754B40A20C553195085240ED4ACB48BD754B40A20C553195085240EA2285B2F0734B403D2AFEEF88065240EA2285B2F0734B40
28676	24073	72.012493000000006	72.027772999999996	55.008814999999998	55.002305	Центральная	0103000020E61000000100000005000000749B70AFCC00524003CFBD874B804B40749B70AFCC0052406C5B94D920814B408EAD6708C70152406C5B94D920814B408EAD6708C701524003CFBD874B804B40749B70AFCC00524003CFBD874B804B40
29682	47223	71.775310000000005	71.805880000000002	54.824928	54.808208	Центральная	0103000020E61000000100000005000000C190D5AD9EF15140CB2E185C73674B40C190D5AD9EF1514000C79E3D97694B400820B58993F3514000C79E3D97694B400820B58993F35140CB2E185C73674B40C190D5AD9EF15140CB2E185C73674B40
28670	24677	71.934627000000006	71.959509999999995	55.105356999999998	55.089247999999998	Центральная	0103000020E610000001000000050000005ABDC3EDD0FB5140E09D7C7A6C8B4B405ABDC3EDD0FB5140CCB392567C8D4B40D68BA19C68FD5140CCB392567C8D4B40D68BA19C68FD5140E09D7C7A6C8B4B405ABDC3EDD0FB5140E09D7C7A6C8B4B40
29827	47575	72.102405000000005	72.132210999999998	54.721245000000003	54.710375999999997	Школьная	0103000020E610000001000000050000009A7CB3CD8D06524080EECB99ED5A4B409A7CB3CD8D065240A7B393C1515C4B40F94A202576085240A7B393C1515C4B40F94A20257608524080EECB99ED5A4B409A7CB3CD8D06524080EECB99ED5A4B40
29483	46229	72.013093999999995	72.028616999999997	54.845979999999997	54.833562999999998	Западная	0103000020E6100000010000000500000086713788D6005240EC134031B26A4B4086713788D6005240F8889812496C4B4004C765DCD4015240F8889812496C4B4004C765DCD4015240EC134031B26A4B4086713788D6005240EC134031B26A4B40
29420	47464	72.213534999999993	72.227001000000001	55.035874999999997	55.022044999999999	Центральная	0103000020E610000001000000050000004963B48EAA0D52402905DD5ED2824B404963B48EAA0D52403BDF4F8D97844B4032CA332F870E52403BDF4F8D97844B4032CA332F870E52402905DD5ED2824B404963B48EAA0D52402905DD5ED2824B40
29332	47560	72.000698	72.021547999999996	54.620584000000001	54.610647	Школьная	0103000020E610000001000000050000000CCB9F6F0B00524044334FAE294E4B400CCB9F6F0B005240DF35E84B6F4F4B40D4D2DC0A61015240DF35E84B6F4F4B40D4D2DC0A6101524044334FAE294E4B400CCB9F6F0B00524044334FAE294E4B40
29688	24782	72.109097000000006	72.131941999999995	54.996521000000001	54.982408999999997	Центральная	0103000020E61000000100000005000000DFC5FB71FB065240E525FF93BF7D4B40DFC5FB71FB0652407C6308008E7F4B4001BEDBBC710852407C6308008E7F4B4001BEDBBC71085240E525FF93BF7D4B40DFC5FB71FB065240E525FF93BF7D4B40
29888	24782	72.109097000000006	72.131941999999995	54.996521000000001	54.982408999999997	Гагарина	0103000020E61000000100000005000000DFC5FB71FB065240E525FF93BF7D4B40DFC5FB71FB0652407C6308008E7F4B4001BEDBBC710852407C6308008E7F4B4001BEDBBC71085240E525FF93BF7D4B40DFC5FB71FB065240E525FF93BF7D4B40
29701	23683	71.943897000000007	71.960345000000004	54.912909999999997	54.903717	Центральная	0103000020E61000000100000005000000B972F6CE68FC51406CEBA7FFAC734B40B972F6CE68FC51407E18213CDA744B4023F8DF4A76FD51407E18213CDA744B4023F8DF4A76FD51406CEBA7FFAC734B40B972F6CE68FC51406CEBA7FFAC734B40
29583	24496	71.737159000000005	71.750507999999996	54.870905999999998	54.858383000000003	40 лет Победы	0103000020E61000000100000005000000EF3CF19C2DEF5140A038807EDF6D4B40EF3CF19C2DEF5140F1F109D9796F4B40BAD8B45208F05140F1F109D9796F4B40BAD8B45208F05140A038807EDF6D4B40EF3CF19C2DEF5140A038807EDF6D4B40
29438	47809	72.111549999999994	72.133737999999994	54.948509999999999	54.943441999999997	Центральная	0103000020E610000001000000050000009A779CA2230752401FD61BB5C2784B409A779CA223075240E8F692C668794B40E00ED4298F085240E8F692C668794B40E00ED4298F0852401FD61BB5C2784B409A779CA2230752401FD61BB5C2784B40
29144	24088	71.925804999999997	71.960543000000001	54.674683999999999	54.655875999999999	Центральная	0103000020E610000001000000050000004A5E9D6340FB51409B1DA9BEF3534B404A5E9D6340FB51403691990B5C564B40B6D9588979FD51403691990B5C564B40B6D9588979FD51409B1DA9BEF3534B404A5E9D6340FB51409B1DA9BEF3534B40
29685	53030	71.668941000000004	71.690482000000003	54.863782	54.852634999999999	Центральная	0103000020E61000000100000005000000077DE9EDCFEA51406536C824236D4B40077DE9EDCFEA5140CE6F9868906E4B40821E6ADB30EC5140CE6F9868906E4B40821E6ADB30EC51406536C824236D4B40077DE9EDCFEA51406536C824236D4B40
29257	22852	71.892621000000005	71.954093	54.959330000000001	54.922094999999999	Пролетарская	0103000020E6100000010000000500000043AED4B320F951400E677E3507764B4043AED4B320F951402D095053CB7A4B40EC1516DC0FFD51402D095053CB7A4B40EC1516DC0FFD51400E677E3507764B4043AED4B320F951400E677E3507764B40
29671	22852	71.892621000000005	71.954093	54.959330000000001	54.922094999999999	Пионерская	0103000020E6100000010000000500000043AED4B320F951400E677E3507764B4043AED4B320F951402D095053CB7A4B40EC1516DC0FFD51402D095053CB7A4B40EC1516DC0FFD51400E677E3507764B4043AED4B320F951400E677E3507764B40
29552	22852	71.892621000000005	71.954093	54.959330000000001	54.922094999999999	Механизаторов	0103000020E6100000010000000500000043AED4B320F951400E677E3507764B4043AED4B320F951402D095053CB7A4B40EC1516DC0FFD51402D095053CB7A4B40EC1516DC0FFD51400E677E3507764B4043AED4B320F951400E677E3507764B40
28691	22852	71.892621000000005	71.954093	54.959330000000001	54.922094999999999	Комсомольская	0103000020E6100000010000000500000043AED4B320F951400E677E3507764B4043AED4B320F951402D095053CB7A4B40EC1516DC0FFD51402D095053CB7A4B40EC1516DC0FFD51400E677E3507764B4043AED4B320F951400E677E3507764B40
29958	22852	71.892621000000005	71.954093	54.959330000000001	54.922094999999999	1 Северная	0103000020E6100000010000000500000043AED4B320F951400E677E3507764B4043AED4B320F951402D095053CB7A4B40EC1516DC0FFD51402D095053CB7A4B40EC1516DC0FFD51400E677E3507764B4043AED4B320F951400E677E3507764B40
29611	47504	72.043852999999999	72.067019999999999	55.065179000000001	55.054006000000001	Литау	0103000020E610000001000000050000003735D07CCE025240D6E429ABE9864B403735D07CCE02524068B114C957884B40630B410E4A04524068B114C957884B40630B410E4A045240D6E429ABE9864B403735D07CCE025240D6E429ABE9864B40
29689	47404	71.758304999999993	71.774052999999995	55.121155000000002	55.111361000000002	Мира	0103000020E610000001000000050000002BD9B11188F051406286C613418E4B402BD9B11188F051409A5FCD01828F4B40B91798158AF151409A5FCD01828F4B40B91798158AF151406286C613418E4B402BD9B11188F051406286C613418E4B40
29291	47170	71.926154999999994	71.936943999999997	54.876137999999997	54.866554000000001	Молодежная	0103000020E61000000100000005000000B8019F1F46FB5140E71BD13DEB6E4B40B8019F1F46FB514034643C4A25704B40BD8BF7E3F6FB514034643C4A25704B40BD8BF7E3F6FB5140E71BD13DEB6E4B40B8019F1F46FB5140E71BD13DEB6E4B40
29966	47749	72.041724000000002	72.068601000000001	55.099376999999997	55.083244999999998	Школьная	0103000020E6100000010000000500000055DD239BAB0252401B47ACC5A78A4B4055DD239BAB025240BF7CB262B88C4B4044DE72F563045240BF7CB262B88C4B4044DE72F5630452401B47ACC5A78A4B4055DD239BAB0252401B47ACC5A78A4B40
29967	47310	71.763982999999996	71.784841	54.923113999999998	54.916237000000002	Центральная	0103000020E61000000100000005000000CCECF318E5F051404D31074147754B40CCECF318E5F05140683D7C9928764B40D6E3BED53AF25140683D7C9928764B40D6E3BED53AF251404D31074147754B40CCECF318E5F051404D31074147754B40
29690	26062	71.943348999999998	71.959069999999997	54.936393000000002	54.920909999999999	Центральная	0103000020E61000000100000005000000B7ED7BD45FFC51409947FE60E0754B40B7ED7BD45FFC5140079ACFB9DB774B40C824236761FD5140079ACFB9DB774B40C824236761FD51409947FE60E0754B40B7ED7BD45FFC51409947FE60E0754B40
76472	60854	71.837374999999994	71.851128000000003	54.715274999999998	54.709330000000001	Школьная	0103000020E610000001000000050000003BDF4F8D97F551402D095053CB5A4B403BDF4F8D97F55140BD5296218E5B4B406F2D93E178F65140BD5296218E5B4B406F2D93E178F651402D095053CB5A4B403BDF4F8D97F551402D095053CB5A4B40
74044	33161	71.845378999999994	71.862896000000006	54.814087000000001	54.802852999999999	Центральная	0103000020E61000000100000005000000696E85B01AF651406C3F19E3C3664B40696E85B01AF65140A48CB80034684B405AF624B039F75140A48CB80034684B405AF624B039F751406C3F19E3C3664B40696E85B01AF651406C3F19E3C3664B40
29271	47488	72.017775	72.038129999999995	55.058812000000003	55.040647	Школьная	0103000020E61000000100000005000000EEEBC039230152401BD7BFEB33854B40EEEBC03923015240624ED02687874B40C6BFCFB870025240624ED02687874B40C6BFCFB8700252401BD7BFEB33854B40EEEBC039230152401BD7BFEB33854B40
30078	23315	71.975751000000002	71.984160000000003	54.803418999999998	54.795613000000003	Акжигита	0103000020E61000000100000005000000848252B472FE5140E0A293A5D6654B40848252B472FE514015FE0C6FD6664B400282397AFCFE514015FE0C6FD6664B400282397AFCFE5140E0A293A5D6654B40848252B472FE5140E0A293A5D6654B40
30011	53088	72.149117000000004	72.185760000000002	55.085121000000001	55.069602000000003	Школьная	0103000020E61000000100000005000000C59107228B0952403CDEE4B7E8884B40C59107228B095240F699B33EE58A4B40EB39E97DE30B5240F699B33EE58A4B40EB39E97DE30B52403CDEE4B7E8884B40C59107228B0952403CDEE4B7E8884B40
29232	48826	71.654882000000001	71.678481000000005	54.974457999999998	54.960075000000003	Школьная	0103000020E610000001000000050000004D2F3196E9E95140865AD3BCE37A4B404D2F3196E9E95140ACA92C0ABB7C4B40467D923B6CEB5140ACA92C0ABB7C4B40467D923B6CEB5140865AD3BCE37A4B404D2F3196E9E95140865AD3BCE37A4B40
73949	60167	71.951946000000007	71.969669999999994	54.739097000000001	54.732926999999997	Центральная	0103000020E61000000100000005000000B763EAAEECFC51407DAD4B8DD05D4B40B763EAAEECFC51402EC901BB9A5E4B40637AC2120FFE51402EC901BB9A5E4B40637AC2120FFE51407DAD4B8DD05D4B40B763EAAEECFC51407DAD4B8DD05D4B40
79283	61518	71.805987999999999	71.840087999999994	54.922203000000003	54.905379000000003	Центральная	0103000020E61000000100000005000000FB3DB14E95F351401BBE8575E3734B40FB3DB14E95F35140F5A276BF0A764B40C5707500C4F55140F5A276BF0A764B40C5707500C4F551401BBE8575E3734B40FB3DB14E95F351401BBE8575E3734B40
29585	47661	71.808161999999996	71.825445000000002	54.880862	54.867632	Центральная	0103000020E61000000100000005000000ADF71BEDB8F35140467BBC900E6F4B40ADF71BEDB8F3514003250516C0704B4064E94317D4F4514003250516C0704B4064E94317D4F45140467BBC900E6F4B40ADF71BEDB8F35140467BBC900E6F4B40
73729	23500	71.900446000000002	71.925724000000002	54.925348999999997	54.918591999999997	Центральная	0103000020E61000000100000005000000197442E8A0F95140012F336C94754B40197442E8A0F95140723106D671764B40D447E00F3FFB5140723106D671764B40D447E00F3FFB5140012F336C94754B40197442E8A0F95140012F336C94754B40
29470	47642	71.872013999999993	71.891560999999996	54.590389999999999	54.576151000000003	Школьная	0103000020E61000000100000005000000DDE9CE13CFF751406347E350BF494B40DDE9CE13CFF7514056F146E6914B4B40E658DE550FF9514056F146E6914B4B40E658DE550FF951406347E350BF494B40DDE9CE13CFF751406347E350BF494B40
29556	47390	71.788965000000005	71.805107000000007	54.972152999999999	54.962767999999997	Фрайгонгова	0103000020E61000000100000005000000132C0E677EF2514052D158FB3B7B4B40132C0E677EF25140A9DA6E826F7C4B40F7B182DF86F35140A9DA6E826F7C4B40F7B182DF86F3514052D158FB3B7B4B40132C0E677EF2514052D158FB3B7B4B40
29413	52996	71.901892000000004	71.936593999999999	54.851889	54.833967000000001	Центральная	0103000020E610000001000000050000008A213999B8F95140BC783F6EBF6A4B408A213999B8F951403C69E1B20A6D4B404FE8F527F1FB51403C69E1B20A6D4B404FE8F527F1FB5140BC783F6EBF6A4B408A213999B8F95140BC783F6EBF6A4B40
29391	46734	72.553503000000006	72.562881000000004	54.851717999999998	54.846165999999997	переулок Школьный	0103000020E610000001000000050000003ACFD8976C2352405A7EE02A4F6C4B403ACFD8976C2352400FB56D18056D4B408CA2073E062452400FB56D18056D4B408CA2073E062452405A7EE02A4F6C4B403ACFD8976C2352405A7EE02A4F6C4B40
29238	21770	72.509791000000007	72.529311000000007	54.888517	54.882156999999999	Центральная	0103000020E61000000100000005000000E4326E6AA0205240FF774485EA704B40E4326E6AA02052405378D0ECBA714B40709A3E3BE02152405378D0ECBA714B40709A3E3BE0215240FF774485EA704B40E4326E6AA0205240FF774485EA704B40
29077	49350	72.415476999999996	72.434117000000001	54.879738000000003	54.870947999999999	Школьная	0103000020E610000001000000050000005FCFD72C971A524020425C397B6F4B405FCFD72C971A5240348639419B704B40CF68AB92C81B5240348639419B704B40CF68AB92C81B524020425C397B6F4B405FCFD72C971A524020425C397B6F4B40
29656	21863	72.640810000000002	72.662091000000004	54.924075999999999	54.905259999999998	Зеленая	0103000020E61000000100000005000000C93CF207032952404030478FDF734B40C93CF207032952405E82531F48764B4076FEEDB25F2A52405E82531F48764B4076FEEDB25F2A52404030478FDF734B40C93CF207032952404030478FDF734B40
29550	53013	72.813359000000005	72.841690999999997	55.038711999999997	55.028067999999998	Молодежная	0103000020E61000000100000005000000113AE8120E345240350873BB97834B40113AE8120E3452403BFBCA83F4844B409A95ED43DE3552403BFBCA83F4844B409A95ED43DE355240350873BB97834B40113AE8120E345240350873BB97834B40
29581	22508	72.340962000000005	72.363742999999999	54.942289000000002	54.934525999999998	Зеленая	0103000020E6100000010000000500000071CB4752D21552407FA1478C9E774B4071CB4752D2155240B6300BED9C784B408849B89047175240B6300BED9C784B408849B890471752407FA1478C9E774B4071CB4752D21552407FA1478C9E774B40
30086	22350	72.290377000000007	72.330245000000005	54.957861999999999	54.943317999999998	1-я Советская	0103000020E61000000100000005000000AEA069899512524033DDEBA4BE784B40AEA0698995125240630AD6389B7A4B40B9AAECBB22155240630AD6389B7A4B40B9AAECBB2215524033DDEBA4BE784B40AEA069899512524033DDEBA4BE784B40
79339	61531	72.708866999999998	72.715128000000007	54.970427000000001	54.960819000000001	Центральная	0103000020E61000000100000005000000AC8DB1135E2D52400E30F31DFC7A4B40AC8DB1135E2D5240E413B2F3367C4B400D1D3BA8C42D5240E413B2F3367C4B400D1D3BA8C42D52400E30F31DFC7A4B40AC8DB1135E2D52400E30F31DFC7A4B40
29443	21780	72.455515000000005	72.469519000000005	54.952567999999999	54.948168000000003	Южная	0103000020E6100000010000000500000099F56228271D52408F8EAB915D794B4099F56228271D5240AA9B8BBFED794B4071766B990C1E5240AA9B8BBFED794B4071766B990C1E52408F8EAB915D794B4099F56228271D52408F8EAB915D794B40
79324	53022	72.443684000000005	72.479994000000005	55.033181999999996	55.022660000000002	50 лет Октября	0103000020E610000001000000050000008B709351651C5240B476DB85E6824B408B709351651C52406E68CA4E3F844B40AE11C138B81E52406E68CA4E3F844B40AE11C138B81E5240B476DB85E6824B408B709351651C5240B476DB85E6824B40
29547	22613	72.770751000000004	72.789544000000006	54.986423000000002	54.975195999999997	Молодежная	0103000020E61000000100000005000000FF9600FC533152405298F738D37C4B40FF9600FC53315240D882DE1B437E4B4032B08EE387325240D882DE1B437E4B4032B08EE3873252405298F738D37C4B40FF9600FC533152405298F738D37C4B40
29104	21476	72.281879000000004	72.296863000000002	54.852822000000003	54.845191999999997	Школьная	0103000020E61000000100000005000000789B374E0A125240A06B5F402F6C4B40789B374E0A12524098A77345296D4B401E19ABCDFF12524098A77345296D4B401E19ABCDFF125240A06B5F402F6C4B40789B374E0A125240A06B5F402F6C4B40
29369	21383	72.307705999999996	72.343243000000001	54.897060000000003	54.878216000000002	Мира	0103000020E610000001000000050000001CB28174B11352407769C36169704B401CB28174B11352405F46B1DCD2724B402EE57CB1F71552405F46B1DCD2724B402EE57CB1F71552407769C36169704B401CB28174B11352407769C36169704B40
29459	53003	72.703053999999995	72.719835000000003	54.808332999999998	54.803122999999999	Пономаренко	0103000020E610000001000000050000009B5434D6FE2C52402CD505BCCC664B409B5434D6FE2C524087A3AB7477674B4009E1D1C6112E524087A3AB7477674B4009E1D1C6112E52402CD505BCCC664B409B5434D6FE2C52402CD505BCCC664B40
29929	21671	72.519025999999997	72.538663	54.926456000000002	54.917628999999998	Школьная	0103000020E6100000010000000500000084F1D3B8372152403B6EF8DD74754B4084F1D3B8372152406C97361C96764B402D246074792252406C97361C96764B402D246074792252403B6EF8DD74754B4084F1D3B8372152403B6EF8DD74754B40
29515	21121	72.618694000000005	72.666942000000006	54.971243000000001	54.951436000000001	Южная	0103000020E61000000100000005000000D00EB8AE98275240581EA4A7C8794B40D00EB8AE9827524006BCCCB0517C4B400C957F2DAF2A524006BCCCB0517C4B400C957F2DAF2A5240581EA4A7C8794B40D00EB8AE98275240581EA4A7C8794B40
29782	21121	72.618694000000005	72.666942000000006	54.971243000000001	54.951436000000001	Садовая	0103000020E61000000100000005000000D00EB8AE98275240581EA4A7C8794B40D00EB8AE9827524006BCCCB0517C4B400C957F2DAF2A524006BCCCB0517C4B400C957F2DAF2A5240581EA4A7C8794B40D00EB8AE98275240581EA4A7C8794B40
29378	21121	72.618694000000005	72.666942000000006	54.971243000000001	54.951436000000001	Победы	0103000020E61000000100000005000000D00EB8AE98275240581EA4A7C8794B40D00EB8AE9827524006BCCCB0517C4B400C957F2DAF2A524006BCCCB0517C4B400C957F2DAF2A5240581EA4A7C8794B40D00EB8AE98275240581EA4A7C8794B40
30058	21121	72.618694000000005	72.666942000000006	54.971243000000001	54.951436000000001	Ленина	0103000020E61000000100000005000000D00EB8AE98275240581EA4A7C8794B40D00EB8AE9827524006BCCCB0517C4B400C957F2DAF2A524006BCCCB0517C4B400C957F2DAF2A5240581EA4A7C8794B40D00EB8AE98275240581EA4A7C8794B40
28661	22774	72.690315999999996	72.706935000000001	55.056609999999999	55.050049999999999	Центральная	0103000020E61000000100000005000000F4F928232E2C52401895D40968864B40F4F928232E2C5240335019FF3E874B4075594C6C3E2D5240335019FF3E874B4075594C6C3E2D52401895D40968864B40F4F928232E2C52401895D40968864B40
30068	21567	72.176434999999998	72.190323000000006	54.847560999999999	54.841838000000003	Школьная	0103000020E61000000100000005000000AAB706B64A0B5240D943FB58C16B4B40AAB706B64A0B5240BA2EFCE07C6C4B404E2B85402E0C5240BA2EFCE07C6C4B404E2B85402E0C5240D943FB58C16B4B40AAB706B64A0B5240D943FB58C16B4B40
29112	21875	72.840496999999999	72.865127999999999	54.952190999999999	54.938333	Октябрьская	0103000020E61000000100000005000000B6D8EDB3CA355240F8E0B54B1B784B40B6D8EDB3CA355240D4450A65E1794B40A6B6D4415E375240D4450A65E1794B40A6B6D4415E375240F8E0B54B1B784B40B6D8EDB3CA355240F8E0B54B1B784B40
29532	46607	72.835573999999994	72.843532999999994	54.858797000000003	54.851112000000001	Школьная	0103000020E61000000100000005000000D3D85E0B7A355240D89DEE3CF16C4B40D3D85E0B7A3552409373620FED6D4B403106D671FC3552409373620FED6D4B403106D671FC355240D89DEE3CF16C4B40D3D85E0B7A355240D89DEE3CF16C4B40
79313	61528	72.302047000000002	72.319087999999994	54.996721999999998	54.989232999999999	Центральная	0103000020E61000000100000005000000B7B6F0BC54135240DE8FDB2F9F7E4B40B7B6F0BC54135240139A2496947F4B40F22213F06B145240139A2496947F4B40F22213F06B145240DE8FDB2F9F7E4B40B7B6F0BC54135240DE8FDB2F9F7E4B40
29796	46785	72.365979999999993	72.391294000000002	54.990431999999998	54.977708	Ленина	0103000020E610000001000000050000005DBF60376C175240CF842689257D4B405DBF60376C175240B874CC79C67E4B40BF47FDF50A195240B874CC79C67E4B40BF47FDF50A195240CF842689257D4B405DBF60376C175240CF842689257D4B40
76414	60819	72.150007000000002	72.166499999999999	54.767055999999997	54.760396999999998	Центральная	0103000020E61000000100000005000000F3CAF5B699095240FE7C5BB054614B40F3CAF5B699095240AC1919E42E624B402DB29DEFA70A5240AC1919E42E624B402DB29DEFA70A5240FE7C5BB054614B40F3CAF5B699095240FE7C5BB054614B40
30073	46587	72.849694999999997	72.858777000000003	54.923662	54.914923000000002	Школьная	0103000020E61000000100000005000000C824236761365240DAAD65321C754B40C8242367613652406B47718E3A764B40A663CE33F63652406B47718E3A764B40A663CE33F6365240DAAD65321C754B40C824236761365240DAAD65321C754B40
29533	46641	72.739992999999998	72.757581999999999	54.913618999999997	54.907210999999997	Школьная	0103000020E610000001000000050000003691990B5C2F524025C9737D1F744B403691990B5C2F52408A00A777F1744B40738236397C3052408A00A777F1744B40738236397C30524025C9737D1F744B403691990B5C2F524025C9737D1F744B40
29791	22291	72.542445000000001	72.552065999999996	54.798717000000003	54.792332999999999	Школьная	0103000020E610000001000000050000003DB83B6BB72252405245F12A6B654B403DB83B6BB72252402FE1D05B3C664B40F2CEA10C552352402FE1D05B3C664B40F2CEA10C552352405245F12A6B654B403DB83B6BB72252405245F12A6B654B40
29946	53081	72.638484000000005	72.665746999999996	54.809593999999997	54.796194999999997	пер. Центральный	0103000020E610000001000000050000003CC1FEEBDC2852408E1EBFB7E9654B403CC1FEEBDC285240D784B4C6A0674B403F1A4E999B2A5240D784B4C6A0674B403F1A4E999B2A52408E1EBFB7E9654B403CC1FEEBDC2852408E1EBFB7E9654B40
79335	61530	72.624613999999994	72.633218999999997	55.052571999999998	55.040466000000002	Центральная	0103000020E61000000100000005000000EBA7FFACF9275240CB4C69FD2D854B40EBA7FFACF9275240B857E6ADBA864B402C0DFCA886285240B857E6ADBA864B402C0DFCA886285240CB4C69FD2D854B40EBA7FFACF9275240CB4C69FD2D854B40
29127	52973	72.701167999999996	72.712414999999993	54.952863000000001	54.941155999999999	Новая	0103000020E610000001000000050000001C40BFEFDF2C52409337C0CC77784B401C40BFEFDF2C5240C3482F6AF7794B40828B1535982D5240C3482F6AF7794B40828B1535982D52409337C0CC77784B401C40BFEFDF2C52409337C0CC77784B40
29644	21116	72.311154999999999	72.325222999999994	55.058414999999997	55.050818999999997	Пикетинская	0103000020E61000000100000005000000293FA9F6E9135240F981AB3C81864B40293FA9F6E9135240444C89247A874B400C3A2174D0145240444C89247A874B400C3A2174D0145240F981AB3C81864B40293FA9F6E9135240F981AB3C81864B40
29054	17709	72.122185999999999	72.139037999999999	55.438803	55.425665000000002	Центральная	0103000020E61000000100000005000000DC813AE5D1075240A306D3307CB64B40DC813AE5D10752407F315BB22AB84B40AEB9A3FFE50852407F315BB22AB84B40AEB9A3FFE5085240A306D3307CB64B40DC813AE5D1075240A306D3307CB64B40
29767	20166	72.209484000000003	72.222752	55.193170000000002	55.189197999999998	Центральная	0103000020E610000001000000050000004242942F680D5240FB3BDBA337984B404242942F680D5240BF4868CBB9984B4097C79A91410E5240BF4868CBB9984B4097C79A91410E5240FB3BDBA337984B404242942F680D5240FB3BDBA337984B40
29218	20957	72.440404999999998	72.458003000000005	55.212744999999998	55.199469999999998	Пролетарская	0103000020E61000000100000005000000ACFF73982F1C52403D44A33B88994B40ACFF73982F1C52409AB1683A3B9B4B40139ED0EB4F1D52409AB1683A3B9B4B40139ED0EB4F1D52403D44A33B88994B40ACFF73982F1C52403D44A33B88994B40
29513	21016	72.575942999999995	72.600825999999998	55.156568999999998	55.150432000000002	Колхозная	0103000020E610000001000000050000000C570740DC245240CD22145B41934B400C570740DC245240A148F7730A944B408925E5EE73265240A148F7730A944B408925E5EE73265240CD22145B41934B400C570740DC245240CD22145B41934B40
29918	20843	72.488618000000002	72.512709999999998	55.133951000000003	55.118673000000001	Школьная	0103000020E610000001000000050000002A8F6E84451F524088F546AD308F4B402A8F6E84451F52401D226E4E25914B4042959A3DD02052401D226E4E25914B4042959A3DD020524088F546AD308F4B402A8F6E84451F524088F546AD308F4B40
29980	18821	72.862837999999996	72.883938999999998	55.101215000000003	55.097619999999999	Центральная	0103000020E61000000100000005000000BFEFDFBC38375240BFB7E9CF7E8C4B40BFEFDFBC38375240AD6EF59CF48C4B402C2AE27492385240AD6EF59CF48C4B402C2AE27492385240BFB7E9CF7E8C4B40BFEFDFBC38375240BFB7E9CF7E8C4B40
29156	18525	72.640127000000007	72.668926999999996	55.219309000000003	55.214275000000001	 Школьная	0103000020E6100000010000000500000058923CD7F7285240DAACFA5C6D9B4B4058923CD7F7285240F75B3B51129C4B40541A31B3CF2A5240F75B3B51129C4B40541A31B3CF2A5240DAACFA5C6D9B4B4058923CD7F7285240DAACFA5C6D9B4B40
30024	18740	72.928315999999995	72.941800000000001	55.083950999999999	55.077081999999997	Школьная	0103000020E61000000100000005000000A0168387693B52401D8EAED2DD894B40A0168387693B5240B6BB07E8BE8A4B40DCD78173463C5240B6BB07E8BE8A4B40DCD78173463C52401D8EAED2DD894B40A0168387693B52401D8EAED2DD894B40
29642	21026	72.281869999999998	72.307822999999999	55.078859999999999	55.064157999999999	Центральная	0103000020E610000001000000050000004EEE77280A1252406DE34F5436884B404EEE77280A125240357BA015188A4B40397D3D5FB3135240357BA015188A4B40397D3D5FB31352406DE34F5436884B404EEE77280A1252406DE34F5436884B40
29353	20637	72.893884	72.928315999999995	55.380293000000002	55.367981	Советская	0103000020E61000000100000005000000BB9A3C653539524052465C001AAF4B40BB9A3C6535395240E9F2E670ADB04B40A0168387693B5240E9F2E670ADB04B40A0168387693B524052465C001AAF4B40BB9A3C653539524052465C001AAF4B40
29186	18053	72.617300999999998	72.640882000000005	55.531900999999998	55.518836	Вторая	0103000020E6100000010000000500000070B20DDC8127524065FED13769C24B4070B20DDC81275240D7DAFB5415C44B4016A6EF3504295240D7DAFB5415C44B4016A6EF350429524065FED13769C24B4070B20DDC8127524065FED13769C24B40
29498	20491	72.755606	72.778360000000006	55.462992999999997	55.450491	Молодежная	0103000020E6100000010000000500000054AA44D95B305240381268B0A9B94B4054AA44D95B30524072A3C85A43BB4B40EF2076A6D031524072A3C85A43BB4B40EF2076A6D0315240381268B0A9B94B4054AA44D95B305240381268B0A9B94B40
29742	18208	72.405416000000002	72.416060999999999	55.378993999999999	55.368779000000004	Молодёжная	0103000020E610000001000000050000009C51F355F2195240CE39782634AF4B409C51F355F2195240ABB019E082B04B40070951BEA01A5240ABB019E082B04B40070951BEA01A5240CE39782634AF4B409C51F355F2195240CE39782634AF4B40
29836	19880	72.528422000000006	72.542247000000003	55.270364000000001	55.256411	Школьная	0103000020E610000001000000050000002A1F82AAD1215240D6AA5D13D2A04B402A1F82AAD121524004029D499BA24B40AAD6C22CB422524004029D499BA24B40AAD6C22CB4225240D6AA5D13D2A04B402A1F82AAD1215240D6AA5D13D2A04B40
29631	20408	72.772270000000006	72.812962999999996	55.200169000000002	55.186740999999998	Никифорова	0103000020E61000000100000005000000A56B26DF6C31524042E90B21E7974B40A56B26DF6C315240265646239F994B40EA76F69507345240265646239F994B40EA76F6950734524042E90B21E7974B40A56B26DF6C31524042E90B21E7974B40
30036	20330	72.515440999999996	72.521001999999996	55.111618999999997	55.098047999999999	Южная	0103000020E610000001000000050000001F813FFCFC20524017B83CD68C8C4B401F813FFCFC2052405D4E0988498E4B40A3C9C518582152405D4E0988498E4B40A3C9C5185821524017B83CD68C8C4B401F813FFCFC20524017B83CD68C8C4B40
29508	20198	72.595616000000007	72.614687000000004	55.103800999999997	55.093715000000003	Зеленая	0103000020E610000001000000050000005C3E92921E265240841266DAFE8B4B405C3E92921E2652406325E659498D4B40B0912408572752406325E659498D4B40B091240857275240841266DAFE8B4B405C3E92921E265240841266DAFE8B4B40
29894	19973	72.343962000000005	72.361236000000005	55.219000000000001	55.205697000000001	Октябрьская	0103000020E61000000100000005000000464431790316524052F17F47549A4B40464431790316524079E92631089C4B40D388997D1E17524079E92631089C4B40D388997D1E17524052F17F47549A4B40464431790316524052F17F47549A4B40
29841	19973	72.343962000000005	72.361236000000005	55.219000000000001	55.205697000000001	Клубная	0103000020E61000000100000005000000464431790316524052F17F47549A4B40464431790316524079E92631089C4B40D388997D1E17524079E92631089C4B40D388997D1E17524052F17F47549A4B40464431790316524052F17F47549A4B40
29473	18388	72.529087000000004	72.552819999999997	55.220382000000001	55.213926000000001	Школьная	0103000020E61000000100000005000000486FB88FDC215240CEE15AED619B4B40486FB88FDC2152404450357A359C4B40C8242367612352404450357A359C4B40C824236761235240CEE15AED619B4B40486FB88FDC215240CEE15AED619B4B40
29206	19665	71.946591999999995	73.199400999999995	55.589295	55.019495999999997	Ленина	0103000020E61000000100000005000000EFA99CF694FC51408F334DD87E824B40EFA99CF694FC51402159C0046ECB4B408A7269FCC24C52402159C0046ECB4B408A7269FCC24C52408F334DD87E824B40EFA99CF694FC51408F334DD87E824B40
29285	19781	72.441699	72.459377000000003	55.271272000000003	55.251638999999997	Куйбышева	0103000020E6100000010000000500000042EBE1CB441C5240F6B2EDB435A04B4042EBE1CB441C52400729780AB9A24B4037E2C96E661D52400729780AB9A24B4037E2C96E661D5240F6B2EDB435A04B4042EBE1CB441C5240F6B2EDB435A04B40
29086	19684	73.010620000000003	73.048169000000001	55.357551999999998	55.342666999999999	Советская	0103000020E61000000100000005000000BF2B82FFAD4052408F352383DCAB4B40BF2B82FFAD405240484F9143C4AD4B4096EB6D3315435240484F9143C4AD4B4096EB6D33154352408F352383DCAB4B40BF2B82FFAD4052408F352383DCAB4B40
29059	18199	72.304642999999999	72.322141999999999	55.354522000000003	55.339083000000002	Центральная	0103000020E61000000100000005000000247D5A457F13524096D05D1267AB4B40247D5A457F13524034DB15FA60AD4B40C1AA7AF99D14524034DB15FA60AD4B40C1AA7AF99D14524096D05D1267AB4B40247D5A457F13524096D05D1267AB4B40
29803	18663	72.774731000000003	72.781343000000007	55.272554	55.259084000000001	Центральная	0103000020E61000000100000005000000A20C5531953152405C751DAA29A14B40A20C5531953152406E32AA0CE3A24B4059FD1186013252406E32AA0CE3A24B4059FD1186013252405C751DAA29A14B40A20C5531953152405C751DAA29A14B40
30126	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Ремесленная	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
78980	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Почтовая	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
79040	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Победы бульвар	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
79123	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Октябрьская	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
29829	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Мопра	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
79085	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Матросова	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
29496	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Максима Горького	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
79113	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	Ленина	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
79143	53009	72.673238999999995	72.730892999999995	55.166161000000002	55.142297999999997	70 Лет Октября	0103000020E6100000010000000500000012D90759162B5240A22424D236924B4012D90759162B5240726F7EC344954B4005F86EF3C62E5240726F7EC344954B4005F86EF3C62E5240A22424D236924B4012D90759162B5240A22424D236924B40
29702	19500	72.982763000000006	73.033212000000006	55.210622999999998	55.194105999999998	Старожильская	0103000020E61000000100000005000000022EC896E53E52408BFA2477D8984B40022EC896E53E52408864C8B1F59A4B406D753925204252408864C8B1F59A4B406D753925204252408BFA2477D8984B40022EC896E53E52408BFA2477D8984B40
29623	19500	72.982763000000006	73.033212000000006	55.210622999999998	55.194105999999998	Мира	0103000020E61000000100000005000000022EC896E53E52408BFA2477D8984B40022EC896E53E52408864C8B1F59A4B406D753925204252408864C8B1F59A4B406D753925204252408BFA2477D8984B40022EC896E53E52408BFA2477D8984B40
29510	20875	72.386982000000003	72.400744000000003	55.122492999999999	55.111449	Пролетарская	0103000020E6100000010000000500000001892650C41852400116F9F5438E4B4001892650C4185240957EC2D9AD8F4B405E8429CAA5195240957EC2D9AD8F4B405E8429CAA51952400116F9F5438E4B4001892650C41852400116F9F5438E4B40
78914	53123	72.909486999999999	72.985476000000006	55.249084000000003	55.199933000000001	улица Октябрьская	0103000020E61000000100000005000000C748F608353A52401232906797994B40C748F608353A52407BFA08FCE19F4B408CBFED09123F52407BFA08FCE19F4B408CBFED09123F52401232906797994B40C748F608353A52401232906797994B40
78933	53123	72.909486999999999	72.985476000000006	55.249084000000003	55.199933000000001	Первомайская	0103000020E61000000100000005000000C748F608353A52401232906797994B40C748F608353A52407BFA08FCE19F4B408CBFED09123F52407BFA08FCE19F4B408CBFED09123F52401232906797994B40C748F608353A52401232906797994B40
30143	53123	72.909486999999999	72.985476000000006	55.249084000000003	55.199933000000001	Октябрьская	0103000020E61000000100000005000000C748F608353A52401232906797994B40C748F608353A52407BFA08FCE19F4B408CBFED09123F52407BFA08FCE19F4B408CBFED09123F52401232906797994B40C748F608353A52401232906797994B40
30037	20275	72.669134	72.687540999999996	55.090381999999998	55.087114999999997	Солнечная 	0103000020E6100000010000000500000011A96917D32A5240DAFE9595268B4B4011A96917D32A5240D3122BA3918B4B402F6AF7AB002C5240D3122BA3918B4B402F6AF7AB002C5240DAFE9595268B4B4011A96917D32A5240DAFE9595268B4B40
29338	19581	73.064877999999993	73.092528000000001	55.226954999999997	55.21407	Западная	0103000020E61000000100000005000000B60E0EF626445240018750A5669B4B40B60E0EF626445240F35487DC0C9D4B40B77D8FFAEB455240F35487DC0C9D4B40B77D8FFAEB455240018750A5669B4B40B60E0EF626445240018750A5669B4B40
29188	18599	72.681944000000001	72.714472000000001	55.279871999999997	55.269046000000003	Новая	0103000020E61000000100000005000000056D72F8A42B5240508F6D1970A24B40056D72F8A42B524076887FD8D2A34B40187AC4E8B92D524076887FD8D2A34B40187AC4E8B92D5240508F6D1970A24B40056D72F8A42B5240508F6D1970A24B40
30016	18132	72.369850999999997	72.389605000000003	55.427979000000001	55.420386999999998	Центральная	0103000020E61000000100000005000000255987A3AB175240EF54C03DCFB54B40255987A3AB175240F92F1004C8B64B40EB56CF49EF185240F92F1004C8B64B40EB56CF49EF185240EF54C03DCFB54B40255987A3AB175240EF54C03DCFB54B40
29284	19890	72.509727999999996	72.531692000000007	55.313316	55.309766000000003	Труда	0103000020E61000000100000005000000C07630629F205240D5B48B69A6A74B40C07630629F20524022A81ABD1AA84B40DFE2E13D0722524022A81ABD1AA84B40DFE2E13D07225240D5B48B69A6A74B40C07630629F205240D5B48B69A6A74B40
29191	18727	72.931352000000004	72.956793000000005	55.122425999999997	55.109569	Зелёная	0103000020E610000001000000050000001C446B459B3B5240E5D3635B068E4B401C446B459B3B52400D17B9A7AB8F4B40AC02B5183C3D52400D17B9A7AB8F4B40AC02B5183C3D5240E5D3635B068E4B401C446B459B3B5240E5D3635B068E4B40
29066	18571	72.738007999999994	72.765236000000002	55.278334000000001	55.259228	Школьная	0103000020E61000000100000005000000ED0BE8853B2F52408F1A13622EA14B40ED0BE8853B2F5240B4AED172A0A34B40336E6AA0F9305240B4AED172A0A34B40336E6AA0F93052408F1A13622EA14B40ED0BE8853B2F52408F1A13622EA14B40
29471	18294	72.637917999999999	72.666573999999997	55.238249000000003	55.230353999999998	Ленина	0103000020E61000000100000005000000E7E104A6D32852405B40683D7C9D4B40E7E104A6D328524001A777F17E9E4B404A97FE25A92A524001A777F17E9E4B404A97FE25A92A52405B40683D7C9D4B40E7E104A6D32852405B40683D7C9D4B40
29741	18113	72.295991999999998	72.324288999999993	55.381480000000003	55.372401000000004	Октябрьская	0103000020E610000001000000050000002BF86D88F1125240B5FF01D6AAAF4B402BF86D88F1125240FF092E56D4B04B40F65CA626C1145240FF092E56D4B04B40F65CA626C1145240B5FF01D6AAAF4B402BF86D88F1125240B5FF01D6AAAF4B40
29772	20577	72.788411999999994	72.802237000000005	55.426467000000002	55.415436	Центральная	0103000020E6100000010000000500000088F19A577532524060CAC0012DB54B4088F19A577532524060E97C7896B64B4009A9DBD95733524060E97C7896B64B4009A9DBD95733524060CAC0012DB54B4088F19A577532524060CAC0012DB54B40
29344	20111	72.185795999999996	72.206798000000006	55.280523000000002	55.277056999999999	Борятинская	0103000020E6100000010000000500000091EEE714E40B52405E10919A76A34B4091EEE714E40B52404E637B2DE8A34B4035B8AD2D3C0D52404E637B2DE8A34B4035B8AD2D3C0D52405E10919A76A34B4091EEE714E40B52405E10919A76A34B40
29155	17849	72.600151999999994	72.635859999999994	55.401048000000003	55.393380000000001	Школьная	0103000020E610000001000000050000004128EFE36826524043739D465AB24B404128EFE3682652402810768A55B34B40693524EEB12852402810768A55B34B40693524EEB128524043739D465AB24B404128EFE36826524043739D465AB24B40
29710	17992	72.522754000000006	72.552819999999997	55.436300000000003	55.424101999999998	Центральная	0103000020E610000001000000050000009B7631CD7421524087156EF948B64B409B7631CD74215240569FABADD8B74B40C824236761235240569FABADD8B74B40C82423676123524087156EF948B64B409B7631CD7421524087156EF948B64B40
29467	17786	72.642354999999995	72.672853000000003	55.319653000000002	55.301760999999999	Школьная	0103000020E61000000100000005000000035B25581C295240A81ABD1AA0A64B40035B25581C295240BE88B663EAA84B40FE800706102B5240BE88B663EAA84B40FE800706102B5240A81ABD1AA0A64B40035B25581C295240A81ABD1AA0A64B40
30017	18347	72.710717000000002	72.713592000000006	55.243803	55.229219000000001	Центральная	0103000020E6100000010000000500000085ED27637C2D5240984F560C579D4B4085ED27637C2D524056D5CBEF349F4B40FCABC77DAB2D524056D5CBEF349F4B40FCABC77DAB2D5240984F560C579D4B4085ED27637C2D5240984F560C579D4B40
29769	20480	72.735268000000005	72.749210000000005	55.233674999999998	55.222000000000001	Труда	0103000020E61000000100000005000000E77283A10E2F524023DBF97E6A9C4B40E77283A10E2F52404772F90FE99D4B4084F57F0EF32F52404772F90FE99D4B4084F57F0EF32F524023DBF97E6A9C4B40E77283A10E2F524023DBF97E6A9C4B40
30050	18456	72.609234000000001	72.621757000000002	55.233443999999999	55.218009000000002	Школьная	0103000020E610000001000000050000001F679AB0FD265240E99D0AB8E79B4B401F679AB0FD26524045B9347EE19D4B40C843DFDDCA27524045B9347EE19D4B40C843DFDDCA275240E99D0AB8E79B4B401F679AB0FD265240E99D0AB8E79B4B40
29868	17955	72.587468000000001	72.609594000000001	55.267487000000003	55.262141999999997	Центральная	0103000020E6100000010000000500000094DC6113992552403A747ADE8DA14B4094DC611399255240768D96033DA24B409F758D9603275240768D96033DA24B409F758D96032752403A747ADE8DA14B4094DC6113992552403A747ADE8DA14B40
29181	17630	72.046862000000004	72.093052999999998	55.356594999999999	55.343204999999998	переулок Школьный	0103000020E61000000100000005000000365B79C9FF0252406E693524EEAB4B40365B79C9FF0252406475ABE7A4AD4B40DCF29194F40552406475ABE7A4AD4B40DCF29194F40552406E693524EEAB4B40365B79C9FF0252406E693524EEAB4B40
29304	17630	72.046862000000004	72.093052999999998	55.356594999999999	55.343204999999998	Центральная	0103000020E61000000100000005000000365B79C9FF0252406E693524EEAB4B40365B79C9FF0252406475ABE7A4AD4B40DCF29194F40552406475ABE7A4AD4B40DCF29194F40552406E693524EEAB4B40365B79C9FF0252406E693524EEAB4B40
30076	17630	72.046862000000004	72.093052999999998	55.356594999999999	55.343204999999998	Зеленая	0103000020E61000000100000005000000365B79C9FF0252406E693524EEAB4B40365B79C9FF0252406475ABE7A4AD4B40DCF29194F40552406475ABE7A4AD4B40DCF29194F40552406E693524EEAB4B40365B79C9FF0252406E693524EEAB4B40
29430	19777	72.982853000000006	73.004510999999994	55.328851999999998	55.311988999999997	Центральная	0103000020E61000000100000005000000A2F14410E73E52401ADB6B41EFA74B40A2F14410E73E5240B29C84D217AA4B40395E81E849405240B29C84D217AA4B40395E81E8494052401ADB6B41EFA74B40A2F14410E73E52401ADB6B41EFA74B40
29461	53004	71.716570000000004	71.735641000000001	56.200327999999999	56.193452000000001	Новая	0103000020E61000000100000005000000DDD26A48DCED514043ACFE08C3184C40DDD26A48DCED51408E3C1059A4194C403126FDBD14EF51408E3C1059A4194C403126FDBD14EF514043ACFE08C3184C40DDD26A48DCED514043ACFE08C3184C40
29698	16440	71.377015	71.415248000000005	56.050375000000003	56.036256000000002	Центральная	0103000020E610000001000000050000007EC6850321D8514053245F09A4044C407EC6850321D851409CC420B072064C40AFEE586C93DA51409CC420B072064C40AFEE586C93DA514053245F09A4044C407EC6850321D8514053245F09A4044C40
29189	49070	71.210386999999997	71.229367999999994	56.188046999999997	56.179786	Центральная	0103000020E610000001000000050000003A2009FB76CD5140AB23473A03174C403A2009FB76CD5140328E91EC11184C40EEAF1EF7ADCE5140328E91EC11184C40EEAF1EF7ADCE5140AB23473A03174C403A2009FB76CD5140AB23473A03174C40
29595	49144	71.519972999999993	71.559364000000002	56.264266999999997	56.249316	Центральная	0103000020E610000001000000050000006473D53C47E151404D2F3196E91F4C406473D53C47E15140BD344580D3214C40D3A3A99ECCE35140BD344580D3214C40D3A3A99ECCE351404D2F3196E91F4C406473D53C47E151404D2F3196E91F4C40
29591	48862	71.627240999999998	71.651692999999995	55.961455000000001	55.954168000000003	Зелёная	0103000020E61000000100000005000000766D6FB724E85140E371512D22FA4B40766D6FB724E85140B0C91AF510FB4B400E828E56B5E95140B0C91AF510FB4B400E828E56B5E95140E371512D22FA4B40766D6FB724E85140E371512D22FA4B40
30046	16202	71.580888000000002	71.600066999999996	55.909030000000001	55.898648999999999	Лермонтова	0103000020E61000000100000005000000E3A8DC442DE55140A3CA30EE06F34B40E3A8DC442DE551409C8A54185BF44B402A1A6B7F67E651409C8A54185BF44B402A1A6B7F67E65140A3CA30EE06F34B40E3A8DC442DE55140A3CA30EE06F34B40
29305	17351	71.977620000000002	72.001165	56.227634999999999	56.217941000000003	Заречная	0103000020E6100000010000000500000098FA795391FE514091BA9D7DE51B4C4098FA795391FE51406536C824231D4C4097395D16130052406536C824231D4C4097395D161300524091BA9D7DE51B4C4098FA795391FE514091BA9D7DE51B4C40
29866	17528	71.663820000000001	71.680313999999996	56.084626	56.075011000000003	Школьная	0103000020E61000000100000005000000919BE1067CEA51408EEBDFF599094C40919BE1067CEA514016325706D50A4C40B340BB438AEB514016325706D50A4C40B340BB438AEB51408EEBDFF599094C40919BE1067CEA51408EEBDFF599094C40
29303	17049	71.180256999999997	71.213162999999994	56.458844999999997	56.432371000000003	Зелёная	0103000020E6100000010000000500000001F8A75489CB5140925ED4EE57374C4001F8A75489CB51407077D66EBB3A4C40E76D6C76A4CD51407077D66EBB3A4C40E76D6C76A4CD5140925ED4EE57374C4001F8A75489CB5140925ED4EE57374C40
29183	16766	71.022711000000001	71.033625000000001	56.291468999999999	56.285522999999998	Стахановская	0103000020E610000001000000050000009B90D61874C15140BEA085048C244C409B90D61874C151401F662FDB4E254C40FED478E926C251401F662FDB4E254C40FED478E926C25140BEA085048C244C409B90D61874C15140BEA085048C244C40
29598	17216	71.652124000000001	71.661484999999999	56.248680999999998	56.241883999999999	Светлая	0103000020E61000000100000005000000F33B4D66BCE951407CB60E0EF61E4C40F33B4D66BCE951407B116DC7D41F4C40DA722EC555EA51407B116DC7D41F4C40DA722EC555EA51407CB60E0EF61E4C40F33B4D66BCE951407CB60E0EF61E4C40
29147	48781	71.441173000000006	71.459310000000002	55.832399000000002	55.822083999999997	Школьная	0103000020E6100000010000000500000035B8AD2D3CDC51404D486B0C3AE94B4035B8AD2D3CDC51408F1CE90C8CEA4B40732EC55565DD51408F1CE90C8CEA4B40732EC55565DD51404D486B0C3AE94B4035B8AD2D3CDC51404D486B0C3AE94B40
29180	17618	71.769157000000007	71.796789000000004	56.054552999999999	56.039665999999997	Центральная	0103000020E61000000100000005000000541F48DE39F15140AE6186C613054C40541F48DE39F151400873BB97FB064C4001344A97FEF251400873BB97FB064C4001344A97FEF25140AE6186C613054C40541F48DE39F15140AE6186C613054C40
29171	48883	70.984622000000002	71.013180000000006	56.005223999999998	55.988827000000001	Зелёная	0103000020E61000000100000005000000043BFE0B04BF51406E3315E291FE4B40043BFE0B04BF5140C093162EAB004C40863DEDF0D7C05140C093162EAB004C40863DEDF0D7C051406E3315E291FE4B40043BFE0B04BF51406E3315E291FE4B40
29237	52981	70.949506999999997	70.988341000000005	56.360118	56.345194999999997	Зелёная	0103000020E61000000100000005000000AD1402B9C4BC514011DF89592F2C4C40AD1402B9C4BC5140B859BC58182E4C40F1129CFA40BF5140B859BC58182E4C40F1129CFA40BF514011DF89592F2C4C40AD1402B9C4BC514011DF89592F2C4C40
29605	49047	71.032296000000002	71.056855999999996	56.243690000000001	56.236700999999996	Новая	0103000020E61000000100000005000000AAF23D2311C251401AF7E6374C1E4C40AAF23D2311C251405E2EE23B311F4C4035255987A3C351405E2EE23B311F4C4035255987A3C351401AF7E6374C1E4C40AAF23D2311C251401AF7E6374C1E4C40
28851	16085	71.774833999999998	71.794786000000002	55.869737999999998	55.851571	Советская	0103000020E610000001000000050000000C7558E196F151406B9C4D4700ED4B400C7558E196F15140520B259353EF4B40655419C6DDF25140520B259353EF4B40655419C6DDF251406B9C4D4700ED4B400C7558E196F151406B9C4D4700ED4B40
29261	48669	71.223781000000002	71.256381000000005	56.021286000000003	56.008665999999998	Центральная	0103000020E61000000100000005000000D61D8B6D52CE5140274BADF71B014C40D61D8B6D52CE51406CEEE87FB9024C403694DA8B68D051406CEEE87FB9024C403694DA8B68D05140274BADF71B014C40D61D8B6D52CE5140274BADF71B014C40
29732	53033	71.784761000000003	71.831500000000005	56.270930999999997	56.257708000000001	50 лет Октября	0103000020E61000000100000005000000488B338639F2514073F56393FC204C40488B338639F251407D3CF4DDAD224C40F0A7C64B37F551407D3CF4DDAD224C40F0A7C64B37F5514073F56393FC204C40488B338639F2514073F56393FC204C40
28664	27705	71.225964000000005	71.24879	56.497725000000003	56.490281000000003	Молодежная	0103000020E61000000100000005000000B284B53176CE5140D36C1E87C13E4C40B284B53176CE514068B3EA73B53F4C409964E42CECCF514068B3EA73B53F4C409964E42CECCF5140D36C1E87C13E4C40B284B53176CE5140D36C1E87C13E4C40
29296	9605	71.466452000000004	71.545387000000005	56.019244	55.989426000000002	переулок Больничный	0103000020E61000000100000005000000D8497D59DADD5140F3E7DB82A5FE4B40D8497D59DADD514076525F9676024C40782AE09EE7E2514076525F9676024C40782AE09EE7E25140F3E7DB82A5FE4B40D8497D59DADD5140F3E7DB82A5FE4B40
29747	9605	71.466452000000004	71.545387000000005	56.019244	55.989426000000002	Ленина	0103000020E61000000100000005000000D8497D59DADD5140F3E7DB82A5FE4B40D8497D59DADD514076525F9676024C40782AE09EE7E2514076525F9676024C40782AE09EE7E25140F3E7DB82A5FE4B40D8497D59DADD5140F3E7DB82A5FE4B40
29854	9605	71.466452000000004	71.545387000000005	56.019244	55.989426000000002	Красный Путь	0103000020E61000000100000005000000D8497D59DADD5140F3E7DB82A5FE4B40D8497D59DADD514076525F9676024C40782AE09EE7E2514076525F9676024C40782AE09EE7E25140F3E7DB82A5FE4B40D8497D59DADD5140F3E7DB82A5FE4B40
29972	9605	71.466452000000004	71.545387000000005	56.019244	55.989426000000002	Заречная	0103000020E61000000100000005000000D8497D59DADD5140F3E7DB82A5FE4B40D8497D59DADD514076525F9676024C40782AE09EE7E2514076525F9676024C40782AE09EE7E25140F3E7DB82A5FE4B40D8497D59DADD5140F3E7DB82A5FE4B40
29068	9605	71.466452000000004	71.545387000000005	56.019244	55.989426000000002	Вишневского	0103000020E61000000100000005000000D8497D59DADD5140F3E7DB82A5FE4B40D8497D59DADD514076525F9676024C40782AE09EE7E2514076525F9676024C40782AE09EE7E25140F3E7DB82A5FE4B40D8497D59DADD5140F3E7DB82A5FE4B40
29672	49102	71.080759999999998	71.104106999999999	56.391531000000001	56.382192000000003	Зелёная	0103000020E61000000100000005000000CCB4FD2B2BC551407C65DEAAEB304C40CCB4FD2B2BC55140622F14B01D324C40381268B0A9C65140622F14B01D324C40381268B0A9C651407C65DEAAEB304C40CCB4FD2B2BC551407C65DEAAEB304C40
76438	60830	71.488990000000001	71.520099000000002	56.094102999999997	56.088121999999998	Набережная	0103000020E610000001000000050000008C84B69C4BDF51407007EA94470B4C408C84B69C4BDF51404DBA2D910B0C4C40ABEB504D49E151404DBA2D910B0C4C40ABEB504D49E151407007EA94470B4C408C84B69C4BDF51407007EA94470B4C40
30006	17381	71.821635999999998	71.838785000000001	56.306657999999999	56.299565999999999	Школьная	0103000020E61000000100000005000000D74D29AF95F451402C7FBE2D58264C40D74D29AF95F451404487C09140274C4006D847A7AEF551404487C09140274C4006D847A7AEF551402C7FBE2D58264C40D74D29AF95F451402C7FBE2D58264C40
29990	16347	70.926196000000004	70.950055000000006	56.011293000000002	55.998952000000003	Викуловская	0103000020E61000000100000005000000E86B96CB46BB51400C23BDA8DDFF4B40E86B96CB46BB51403DD68C0C72014C40AF997CB3CDBC51403DD68C0C72014C40AF997CB3CDBC51400C23BDA8DDFF4B40E86B96CB46BB51400C23BDA8DDFF4B40
29862	17505	71.611052999999998	71.639017999999993	56.103541999999997	56.090527999999999	Ленина	0103000020E61000000100000005000000DAC70A7E1BE75140A7AFE76B960B4C40DAC70A7E1BE7514097E13FDD400D4C408AE3C0ABE5E8514097E13FDD400D4C408AE3C0ABE5E85140A7AFE76B960B4C40DAC70A7E1BE75140A7AFE76B960B4C40
30025	40470	71.274895000000001	71.295411999999999	56.371724999999998	56.364739999999998	Центральная	0103000020E610000001000000050000005FB532E197D1514082C5E1CCAF2E4C405FB532E197D15140840D4FAF942F4C4024B6BB07E8D25140840D4FAF942F4C4024B6BB07E8D2514082C5E1CCAF2E4C405FB532E197D1514082C5E1CCAF2E4C40
28843	15921	71.629092	71.642691999999997	56.056176000000001	56.045735000000001	Зелёная	0103000020E61000000100000005000000378B170B43E851402BA4FCA4DA054C40378B170B43E85140F96871C630074C40A759A0DD21E95140F96871C630074C40A759A0DD21E951402BA4FCA4DA054C40378B170B43E851402BA4FCA4DA054C40
29863	48980	70.852272999999997	70.882744000000002	56.285612999999998	56.276114	Центральная	0103000020E61000000100000005000000E2900DA48BB65140DFFB1BB457234C40E2900DA48BB65140FE277FF78E244C4060AFB0E07EB85140FE277FF78E244C4060AFB0E07EB85140DFFB1BB457234C40E2900DA48BB65140DFFB1BB457234C40
76435	17440	71.861260999999999	71.889396000000005	56.396379000000003	56.387141	Северная	0103000020E610000001000000050000007F1475E61EF751406AF816D68D314C407F1475E61EF751401DE90C8CBC324C405E4C33DDEBF851401DE90C8CBC324C405E4C33DDEBF851406AF816D68D314C407F1475E61EF751406AF816D68D314C40
29921	16684	70.930490000000006	70.948087999999998	56.270561000000001	56.263857000000002	Школьная	0103000020E6100000010000000500000053D0ED258DBB51400CE9F010C6214C4053D0ED258DBB51405A492BBEA1224C40B96E4A79ADBC51405A492BBEA1224C40B96E4A79ADBC51400CE9F010C6214C4053D0ED258DBB51400CE9F010C6214C40
29050	52775	71.577878999999996	71.593508999999997	56.277797999999997	56.269635999999998	Новая	0103000020E61000000100000005000000E48233F8FBE4514081E9B46E83224C40E48233F8FBE45140757286E28E234C406D382C0DFCE55140757286E28E234C406D382C0DFCE5514081E9B46E83224C40E48233F8FBE4514081E9B46E83224C40
29450	52745	71.167446999999996	71.190641999999997	56.008977999999999	56.003366	Верх-Яманская	0103000020E610000001000000050000000D349F73B7CA51408CF50D4C6E004C400D349F73B7CA51401631EC3026014C409ECF807A33CC51401631EC3026014C409ECF807A33CC51408CF50D4C6E004C400D349F73B7CA51408CF50D4C6E004C40
29489	53007	74.264945999999995	74.286406999999997	54.773237000000002	54.758853999999999	Новая	0103000020E610000001000000050000002F4D11E0F49052402A38BC2022614B402F4D11E0F49052405187156EF9624B401C96067E549252405187156EF9624B401C96067E549252402A38BC2022614B402F4D11E0F49052402A38BC2022614B40
29538	13946	74.066490000000002	74.127818000000005	55.014767999999997	54.991222	Юбилейная	0103000020E61000000100000005000000B5E0455F41845240B189CC5CE07E4B40B5E0455F418452407F83F6EAE3814B40C5758C2B2E8852407F83F6EAE3814B40C5758C2B2E885240B189CC5CE07E4B40B5E0455F41845240B189CC5CE07E4B40
29117	13946	74.066490000000002	74.127818000000005	55.014767999999997	54.991222	Энергетиков	0103000020E61000000100000005000000B5E0455F41845240B189CC5CE07E4B40B5E0455F418452407F83F6EAE3814B40C5758C2B2E8852407F83F6EAE3814B40C5758C2B2E885240B189CC5CE07E4B40B5E0455F41845240B189CC5CE07E4B40
29152	13946	74.066490000000002	74.127818000000005	55.014767999999997	54.991222	Ленина	0103000020E61000000100000005000000B5E0455F41845240B189CC5CE07E4B40B5E0455F418452407F83F6EAE3814B40C5758C2B2E8852407F83F6EAE3814B40C5758C2B2E885240B189CC5CE07E4B40B5E0455F41845240B189CC5CE07E4B40
29136	13946	74.066490000000002	74.127818000000005	55.014767999999997	54.991222	Кирова	0103000020E61000000100000005000000B5E0455F41845240B189CC5CE07E4B40B5E0455F418452407F83F6EAE3814B40C5758C2B2E8852407F83F6EAE3814B40C5758C2B2E885240B189CC5CE07E4B40B5E0455F41845240B189CC5CE07E4B40
29260	13946	74.066490000000002	74.127818000000005	55.014767999999997	54.991222	Базарный переулок	0103000020E61000000100000005000000B5E0455F41845240B189CC5CE07E4B40B5E0455F418452407F83F6EAE3814B40C5758C2B2E8852407F83F6EAE3814B40C5758C2B2E885240B189CC5CE07E4B40B5E0455F41845240B189CC5CE07E4B40
77393	61158	72.748194999999996	74.187494000000001	56.797896000000001	56.046695	Ленина	0103000020E61000000100000005000000F701486DE22F524080F10C1AFA054C40F701486DE22F5240FBCDC47421664C408F8CD5E6FF8B5240FBCDC47421664C408F8CD5E6FF8B524080F10C1AFA054C40F701486DE22F524080F10C1AFA054C40
29658	13849	73.724466000000007	73.740347999999997	56.625658000000001	56.616287999999997	Центральная	0103000020E610000001000000050000001844A4A65D6E524068757286E24E4C401844A4A65D6E52408A3DB48F15504C402DEA93DC616F52408A3DB48F15504C402DEA93DC616F524068757286E24E4C401844A4A65D6E524068757286E24E4C40
29553	13801	73.139949999999999	73.167304000000001	56.244425	56.232033000000001	Центральная	0103000020E61000000100000005000000D044D8F0F4485240E04BE141B31D4C40D044D8F0F448524093A98251491F4C405C1FD61BB54A524093A98251491F4C405C1FD61BB54A5240E04BE141B31D4C40D044D8F0F4485240E04BE141B31D4C40
30077	13720	73.247910000000005	73.277400999999998	56.354900999999998	56.346836000000003	Почтовая	0103000020E610000001000000050000007D96E7C1DD4F5240A9893E1F652C4C407D96E7C1DD4F5240AA285E656D2D4C402CB81FF0C0515240AA285E656D2D4C402CB81FF0C0515240A9893E1F652C4C407D96E7C1DD4F5240A9893E1F652C4C40
29938	53080	73.394154999999998	73.441928000000004	56.378374999999998	56.357779000000001	К.Строкина	0103000020E6100000010000000500000083A3E4D5395952400919C8B3CB2D4C4083A3E4D539595240DF4F8D976E304C40F3CB608C485C5240DF4F8D976E304C40F3CB608C485C52400919C8B3CB2D4C4083A3E4D5395952400919C8B3CB2D4C40
29543	53011	73.721177999999995	73.737914000000004	56.198554999999999	56.187891999999998	Саргатская	0103000020E610000001000000050000000F26C5C7276E52400B9755D80C184C400F26C5C7276E524088BA0F406A194C40AD50A4FB396F524088BA0F406A194C40AD50A4FB396F52400B9755D80C184C400F26C5C7276E52400B9755D80C184C40
29243	52982	74.028114000000002	74.046081000000001	56.360182999999999	56.351894000000001	Рабочая	0103000020E61000000100000005000000D3A3A99ECC8152404ED4D2DC0A2D4C40D3A3A99ECC8152409FC9FE791A2E4C40E3FDB8FDF28252409FC9FE791A2E4C40E3FDB8FDF28252404ED4D2DC0A2D4C40D3A3A99ECC8152404ED4D2DC0A2D4C40
29662	52589	73.346670000000003	73.374527	56.33032	56.317967000000003	Центральная	0103000020E6100000010000000500000047205ED72F565240871A8524B3284C4047205ED72F5652407C9BFEEC472A4C40041E1840F85752407C9BFEEC472A4C40041E1840F8575240871A8524B3284C4047205ED72F565240871A8524B3284C40
30111	53107	73.314969000000005	73.335936000000004	56.41666	56.408766999999997	К. Остапова	0103000020E610000001000000050000003F90BC73285452408E57207A52344C403F90BC732854524093C6681D55354C402463B5F97F55524093C6681D55354C402463B5F97F5552408E57207A52344C403F90BC73285452408E57207A52344C40
30079	13441	73.759508999999994	73.800507999999994	56.5	56.488079999999997	Центральная	0103000020E610000001000000050000002101A3CB9B70524074EACA67793E4C402101A3CB9B7052400000000000404C40ED0BE8853B7352400000000000404C40ED0BE8853B73524074EACA67793E4C402101A3CB9B70524074EACA67793E4C40
29422	52998	73.062640999999999	73.095141999999996	56.223255999999999	56.215367999999998	Николаевская	0103000020E61000000100000005000000E198654F024452406E4DBA2D911B4C40E198654F02445240615111A7931C4C40779E78CE16465240615111A7931C4C40779E78CE164652406E4DBA2D911B4C40E198654F024452406E4DBA2D911B4C40
29667	13241	72.961706000000007	72.981065000000001	56.095920999999997	56.082315999999999	Б.Зеленая	0103000020E610000001000000050000007D9752978C3D524001F8A754890A4C407D9752978C3D5240F3FFAA23470C4C400490DAC4C93E5240F3FFAA23470C4C400490DAC4C93E524001F8A754890A4C407D9752978C3D524001F8A754890A4C40
29795	13153	73.813057999999998	73.836844999999997	56.298096999999999	56.285124000000003	Центральная	0103000020E6100000010000000500000013F06B240974524001A777F17E244C4013F06B24097452409204E10A28264C408DB454DE8E7552409204E10A28264C408DB454DE8E75524001A777F17E244C4013F06B240974524001A777F17E244C40
29665	13097	72.936940000000007	72.986311000000001	56.216174000000002	56.188623	Советская	0103000020E610000001000000050000001D9430D3F63B5240FF2268CC24184C401D9430D3F63B52406D1FF296AB1B4C40D82B2CB81F3F52406D1FF296AB1B4C40D82B2CB81F3F5240FF2268CC24184C401D9430D3F63B5240FF2268CC24184C40
30026	13038	73.310989000000006	73.340220000000002	56.277132999999999	56.257252999999999	Ленина	0103000020E610000001000000050000009C1A683EE753524021E692AAED204C409C1A683EE753524039D2191879234C407D5C1B2AC655524039D2191879234C407D5C1B2AC655524021E692AAED204C409C1A683EE753524021E692AAED204C40
30101	13012	73.951794000000007	73.971717999999996	56.579127	56.563502	Центральная	0103000020E61000000100000005000000DCA16131EA7C5240849D62D520484C40DCA16131EA7C5240849D62D5204A4C40CFBBB1A0307E5240849D62D5204A4C40CFBBB1A0307E5240849D62D520484C40DCA16131EA7C5240849D62D520484C40
29417	52987	73.576406000000006	73.649304000000001	56.477159	56.447538000000002	Свердлова	0103000020E61000000100000005000000F7CDFDD5E3645240CFDBD8EC48394C40F7CDFDD5E3645240FCFECD8B133D4C405E4A5D328E695240FCFECD8B133D4C405E4A5D328E695240CFDBD8EC48394C40F7CDFDD5E3645240CFDBD8EC48394C40
29575	52987	73.576406000000006	73.649304000000001	56.477159	56.447538000000002	Ленина	0103000020E61000000100000005000000F7CDFDD5E3645240CFDBD8EC48394C40F7CDFDD5E3645240FCFECD8B133D4C405E4A5D328E695240FCFECD8B133D4C405E4A5D328E695240CFDBD8EC48394C40F7CDFDD5E3645240CFDBD8EC48394C40
29327	52987	73.576406000000006	73.649304000000001	56.477159	56.447538000000002	Кирова	0103000020E61000000100000005000000F7CDFDD5E3645240CFDBD8EC48394C40F7CDFDD5E3645240FCFECD8B133D4C405E4A5D328E695240FCFECD8B133D4C405E4A5D328E695240CFDBD8EC48394C40F7CDFDD5E3645240CFDBD8EC48394C40
29109	12858	73.560918999999998	73.574518999999995	56.532991000000003	56.526969000000001	Коготовская	0103000020E610000001000000050000001F2DCE18E6635240BF805EB873434C401F2DCE18E6635240FB07910C39444C408FFB56EBC4645240FB07910C39444C408FFB56EBC4645240BF805EB873434C401F2DCE18E6635240BF805EB873434C40
29297	52561	73.936521999999997	73.952754999999996	56.216023999999997	56.201053999999999	Центральная	0103000020E61000000100000005000000027FF8F9EF7B5240705D3123BC194C40027FF8F9EF7B52405793A7ACA61B4C406E861BF0F97C52405793A7ACA61B4C406E861BF0F97C5240705D3123BC194C40027FF8F9EF7B5240705D3123BC194C40
76457	60844	72.748194999999996	74.187494000000001	56.797896000000001	56.046695	Хуторская	0103000020E61000000100000005000000F701486DE22F524080F10C1AFA054C40F701486DE22F5240FBCDC47421664C408F8CD5E6FF8B5240FBCDC47421664C408F8CD5E6FF8B524080F10C1AFA054C40F701486DE22F524080F10C1AFA054C40
30112	53108	72.748194999999996	74.187494000000001	56.797896000000001	56.046695	Дубравинская	0103000020E61000000100000005000000F701486DE22F524080F10C1AFA054C40F701486DE22F5240FBCDC47421664C408F8CD5E6FF8B5240FBCDC47421664C408F8CD5E6FF8B524080F10C1AFA054C40F701486DE22F524080F10C1AFA054C40
30084	53097	73.629496000000003	73.658449000000005	56.147444999999998	56.136045000000003	Обоянская	0103000020E610000001000000050000009F3D97A94968524065E42CEC69114C409F3D97A949685240B77A4E7ADF124C405F454607246A5240B77A4E7ADF124C405F454607246A524065E42CEC69114C409F3D97A94968524065E42CEC69114C40
29535	52548	73.831303000000005	73.853167999999997	56.521835000000003	56.506379000000003	Луговая	0103000020E6100000010000000500000045847F1134755240CB30EE06D1404C4045847F11347552403F74417DCB424C40997FF44D9A7652403F74417DCB424C40997FF44D9A765240CB30EE06D1404C4045847F1134755240CB30EE06D1404C40
29163	52976	73.889189999999999	73.912169000000006	56.538009000000002	56.523904999999999	 Выселки	0103000020E61000000100000005000000897B2C7DE8785240FE9AAC510F434C40897B2C7DE878524012FA997ADD444C4034DB15FA607A524012FA997ADD444C4034DB15FA607A5240FE9AAC510F434C40897B2C7DE8785240FE9AAC510F434C40
76441	60833	73.272461000000007	73.286313000000007	56.224322000000001	56.207667999999998	2-я Заимка	0103000020E61000000100000005000000DF1B4300705152407E3672DD941A4C40DF1B430070515240FCE25295B61C4C40DCDAC2F352525240FCE25295B61C4C40DCDAC2F3525252407E3672DD941A4C40DF1B4300705152407E3672DD941A4C40
29370	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Черепова	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
28662	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Строительная	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
29377	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Смирнова	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
29786	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Семашко	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
29518	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Пионерская	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
30138	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Первомайская	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
30065	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Осминина	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
29519	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Новоселов	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
29625	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Крупской	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
29364	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Красноармейская	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
30061	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Комбинатовская	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
29227	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Калинина	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
30056	6671	74.509889999999999	74.641690999999994	55.080849000000001	55.005164999999998	Калачинская	0103000020E61000000100000005000000ADA3AA09A2A05240BB0A293FA9804B40ADA3AA09A2A0524008759142598A4B40CDC8207711A9524008759142598A4B40CDC8207711A95240BB0A293FA9804B40ADA3AA09A2A05240BB0A293FA9804B40
29372	6671	74.554868999999997	74.619466000000003	55.070881	55.011355000000002	Заводская	0103000020E610000001000000050000001C2444F982A35240B3D2A41474814B401C2444F982A352403274ECA012894B40F9BEB854A5A752403274ECA012894B40F9BEB854A5A75240B3D2A41474814B401C2444F982A35240B3D2A41474814B40
76409	60816	75.041359999999997	75.048582999999994	55.110058000000002	55.106824000000003	Лесная	0103000020E6100000010000000500000034D769A4A5C25240C636A968AC8D4B4034D769A4A5C25240E3546B61168E4B400F09DFFB1BC35240E3546B61168E4B400F09DFFB1BC35240C636A968AC8D4B4034D769A4A5C25240C636A968AC8D4B40
78664	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	улица Строителей	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
78646	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	улица Пушкина	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
78845	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	улица Партизанская	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
30103	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	улица Ленина	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
78887	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	улица Крупской	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
78811	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	улица Деповская	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
30161	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	Тельмана	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
30129	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	Степная	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
78712	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	Степная	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
78748	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	Партизанская	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
30141	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	Октябрьская 	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
30119	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	Ленинградская	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
29135	52974	71.237498000000002	71.309883999999997	54.942072000000003	54.872791999999997	Ленина	0103000020E6100000010000000500000063B7CF2A33CF5140EF1AF4A5B76F4B4063B7CF2A33CF5140193DB7D095784B406F63B323D5D35140193DB7D095784B406F63B323D5D35140EF1AF4A5B76F4B4063B7CF2A33CF5140EF1AF4A5B76F4B40
29661	7779	71.530331000000004	71.554765000000003	54.790686999999998	54.776519	Ленина	0103000020E6100000010000000500000085436FF1F0E151407FDC7EF964634B4085436FF1F0E15140A92F4B3B35654B40CAFD0E4581E35140A92F4B3B35654B40CAFD0E4581E351407FDC7EF964634B4085436FF1F0E151407FDC7EF964634B40
29165	6648	73.646133000000006	73.667468	57.024915	57.013396	Зелёная 	0103000020E6100000010000000500000073F7393E5A695240D8F2CAF5B6814C4073F7393E5A69524005172B6A30834C4019C8B3CBB76A524005172B6A30834C4019C8B3CBB76A5240D8F2CAF5B6814C4073F7393E5A695240D8F2CAF5B6814C40
29730	6418	73.359533999999996	73.407549000000003	57.333038999999999	57.316532000000002	Советская	0103000020E6100000010000000500000034F3E49A025752409911DE1E84A84C4034F3E49A0257524072A59E05A1AA4C401FA16648155A524072A59E05A1AA4C401FA16648155A52409911DE1E84A84C4034F3E49A025752409911DE1E84A84C40
29160	6328	73.717675	73.726864000000006	57.25226	57.242443000000002	Зелёная	0103000020E61000000100000005000000098A1F63EE6D524073124A5F089F4C40098A1F63EE6D5240630B410E4AA04C40F22895F0846E5240630B410E4AA04C40F22895F0846E524073124A5F089F4C40098A1F63EE6D524073124A5F089F4C40
28770	2760	73.363217000000006	73.380257999999998	57.255498000000003	57.248150000000003	Зелёная	0103000020E610000001000000050000007B1684F23E5752404F401361C39F4C407B1684F23E575240C2189128B4A04C40B682A62556585240C2189128B4A04C40B682A625565852404F401361C39F4C407B1684F23E5752404F401361C39F4C40
29628	6591	73.788983000000002	73.802835000000002	57.158417999999998	57.132249000000002	Солдатская 	0103000020E6100000010000000500000066868DB27E725240E0F60489ED904C4066868DB27E725240828C800A47944C4063450DA661735240828C800A47944C4063450DA661735240E0F60489ED904C4066868DB27E725240E0F60489ED904C40
29686	6480	73.738281999999998	73.754954999999995	57.143717000000002	57.135019	Школьная	0103000020E610000001000000050000006E4E2503406F524058AB764D48914C406E4E2503406F52408B70935165924C40E8BCC62E517052408B70935165924C40E8BCC62E5170524058AB764D48914C406E4E2503406F524058AB764D48914C40
29162	6504	73.670271	73.688092999999995	57.142207999999997	57.133924999999998	Школьная	0103000020E61000000100000005000000431D56B8E56A5240F38E537424914C40431D56B8E56A5240629D2ADF33924C40D1E638B7096C5240629D2ADF33924C40D1E638B7096C5240F38E537424914C40431D56B8E56A5240F38E537424914C40
29292	6365	73.499824000000004	73.523261000000005	57.361215999999999	57.350864999999999	Школьная	0103000020E610000001000000050000006170CD1DFD5F5240D027F224E9AC4C406170CD1DFD5F52405E656D533CAE4C406D91B41B7D6152405E656D533CAE4C406D91B41B7D615240D027F224E9AC4C406170CD1DFD5F5240D027F224E9AC4C40
29865	6793	73.659608000000006	73.672903000000005	57.067106000000003	57.054763000000001	Центральная	0103000020E61000000100000005000000850B7904376A5240F303577902874C40850B7904376A5240C5AEEDED96884C405798BED7106B5240C5AEEDED96884C405798BED7106B5240F303577902874C40850B7904376A5240F303577902874C40
29157	6046	74.037734999999998	74.063175999999999	57.106116	57.091746000000001	Центральная	0103000020E6100000010000000500000088BA0F406A825240F8C43A55BE8B4C4088BA0F406A8252408ACA8635958D4C40187959130B8452408ACA8635958D4C40187959130B845240F8C43A55BE8B4C4088BA0F406A825240F8C43A55BE8B4C40
29269	6929	73.553004000000001	73.568213	57.219351000000003	57.210465999999997	Зелёная	0103000020E61000000100000005000000A9A3E36A64635240C075C58CF09A4C40A9A3E36A6463524026AC8DB1139C4C405F0A0F9A5D64524026AC8DB1139C4C405F0A0F9A5D645240C075C58CF09A4C40A9A3E36A64635240C075C58CF09A4C40
29441	6749	73.548970999999995	73.571195000000003	56.937840000000001	56.927914000000001	Новая	0103000020E61000000100000005000000F4DC42572263524012C0CDE2C5764C40F4DC425722635240B97020240B784C40E12879758E645240B97020240B784C40E12879758E64524012C0CDE2C5764C40F4DC42572263524012C0CDE2C5764C40
29423	5979	74.108504999999994	74.127287999999993	56.985408	56.974935000000002	Молодежная 	0103000020E61000000100000005000000F59CF4BEF1865240E65C8AABCA7C4C40F59CF4BEF1865240BF9B6ED9217E4C40164B917C25885240BF9B6ED9217E4C40164B917C25885240E65C8AABCA7C4C40F59CF4BEF1865240E65C8AABCA7C4C40
29588	6858	73.655071000000007	73.676747000000006	57.160449	57.147961000000002	Центральная	0103000020E61000000100000005000000B763EAAEEC695240AF0AD462F0924C40B763EAAEEC69524084D6C39789944C40A22AA6D24F6B524084D6C39789944C40A22AA6D24F6B5240AF0AD462F0924C40B763EAAEEC695240AF0AD462F0924C40
29564	5800	73.889531000000005	73.916921000000002	57.122624999999999	57.115901000000001	Новая 	0103000020E61000000100000005000000CE716E13EE7852406F490ED8D58E4C40CE716E13EE78524004560E2DB28F4C4000016BD5AE7A524004560E2DB28F4C4000016BD5AE7A52406F490ED8D58E4C40CE716E13EE7852406F490ED8D58E4C40
28692	6274	73.832397999999998	73.858880999999997	57.202981999999999	57.191358000000001	Тавлетова	0103000020E610000001000000050000005FD0420246755240FBE93F6B7E984C405FD04202467552409DD66D50FB994C40F88903E8F77652409DD66D50FB994C40F88903E8F7765240FBE93F6B7E984C405FD0420246755240FBE93F6B7E984C40
29826	5821	73.796969000000004	73.847328000000005	57.135326999999997	57.114322999999999	Новостроевская	0103000020E6100000010000000500000041BB438A017352401E17D522A28E4C4041BB438A0173524005A2276552914C400C3F389F3A76524005A2276552914C400C3F389F3A7652401E17D522A28E4C4041BB438A017352401E17D522A28E4C40
30090	5821	73.796969000000004	73.847328000000005	57.135326999999997	57.114322999999999	Ленина	0103000020E6100000010000000500000041BB438A017352401E17D522A28E4C4041BB438A0173524005A2276552914C400C3F389F3A76524005A2276552914C400C3F389F3A7652401E17D522A28E4C4041BB438A017352401E17D522A28E4C40
30169	5821	73.796969000000004	73.847328000000005	57.135326999999997	57.114322999999999	Гагарина	0103000020E6100000010000000500000041BB438A017352401E17D522A28E4C4041BB438A0173524005A2276552914C400C3F389F3A76524005A2276552914C400C3F389F3A7652401E17D522A28E4C4041BB438A017352401E17D522A28E4C40
29158	6120	73.419775000000001	73.454262	57.156582999999998	57.141143999999997	Школьная	0103000020E610000001000000050000006B2BF697DD5A52406803B00111924C406B2BF697DD5A5240060E68E90A944C403274ECA0125D5240060E68E90A944C403274ECA0125D52406803B00111924C406B2BF697DD5A52406803B00111924C40
29694	5901	74.082166000000001	74.092181999999994	57.056083999999998	57.045651999999997	Школьная	0103000020E61000000100000005000000F6B52E35428552409D7FBBECD7854C40F6B52E354285524018EAB0C22D874C40E9D1544FE685524018EAB0C22D874C40E9D1544FE68552409D7FBBECD7854C40F6B52E35428552409D7FBBECD7854C40
29717	6211	73.277608000000001	73.296651999999995	57.140855999999999	57.128194999999998	Вятка 	0103000020E61000000100000005000000E9465854C45152405F419AB168904C40E9465854C451524002B9C49107924C40C092AB58FC52524002B9C49107924C40C092AB58FC5252405F419AB168904C40E9465854C45152405F419AB168904C40
29536	37138	33.366286000000002	33.379365999999997	54.813101000000003	54.803579999999997	Мясниковская	0103000020E61000000100000005000000C87DAB75E2AE40401EDC9DB5DB664B40C87DAB75E2AE404026AC8DB113684B406F9BA9108FB0404026AC8DB113684B406F9BA9108FB040401EDC9DB5DB664B40C87DAB75E2AE40401EDC9DB5DB664B40
76455	60842	73.386393999999996	74.631997999999996	55.759495999999999	55.163795	Центральная	0103000020E61000000100000005000000B857E6ADBA585240C91F0C3CF7944B40B857E6ADBA585240AEB8382A37E14B40CB48BDA772A85240AEB8382A37E14B40CB48BDA772A85240C91F0C3CF7944B40B857E6ADBA585240C91F0C3CF7944B40
29973	5524	74.433415999999994	74.467444	55.404375999999999	55.395803000000001	Центральная	0103000020E610000001000000050000000A647616BD9B5240505436ACA9B24B400A647616BD9B5240C6A4BF97C2B34B40882D3D9AEA9D5240C6A4BF97C2B34B40882D3D9AEA9D5240505436ACA9B24B400A647616BD9B5240505436ACA9B24B40
29691	5447	73.627358000000001	73.647964999999999	55.420653000000001	55.416094999999999	переулок Зеленый	0103000020E6100000010000000500000093382BA226685240BA83D89942B54B4093382BA2266852406EFB1EF5D7B54B40F8FC3042786952406EFB1EF5D7B54B40F8FC304278695240BA83D89942B54B4093382BA226685240BA83D89942B54B40
29141	5405	74.530219000000002	74.550521000000003	55.302104999999997	55.292771000000002	Центральная	0103000020E61000000100000005000000F12DAC1BEFA15240CE1B278579A54B40F12DAC1BEFA15240A27A6B60ABA64B40B8B06EBC3BA35240A27A6B60ABA64B40B8B06EBC3BA35240CE1B278579A54B40F12DAC1BEFA15240CE1B278579A54B40
29245	48916	74.228590999999994	74.247401999999994	55.191586999999998	55.180675999999998	Производственная	0103000020E610000001000000050000003C4A253CA18E52400796236420974B403C4A253CA18E52405CAB3DEC85984B40C2BD326FD58F52405CAB3DEC85984B40C2BD326FD58F52400796236420974B403C4A253CA18E52400796236420974B40
29082	1703	74.165880000000001	74.181186999999994	55.615608999999999	55.606710999999997	Клубная	0103000020E61000000100000005000000DFC325C79D8A5240CD8FBFB4A8CD4B40DFC325C79D8A5240C70F9546CCCE4B4076DD5B91988B5240C70F9546CCCE4B4076DD5B91988B5240CD8FBFB4A8CD4B40DFC325C79D8A5240CD8FBFB4A8CD4B40
29988	5297	73.910156999999998	73.942809999999994	55.432423	55.411532000000001	Кирова	0103000020E610000001000000050000006E4E2503407A5240F5A0A014ADB44B406E4E2503407A5240E48409A359B74B40DF15C1FF567C5240E48409A359B74B40DF15C1FF567C5240F5A0A014ADB44B406E4E2503407A5240F5A0A014ADB44B40
29264	48879	74.137214999999998	74.172545999999997	55.217717	55.207833999999998	Озерная	0103000020E6100000010000000500000052616C21C8885240997FF44D9A9A4B4052616C21C888524041649126DE9B4B408FC360FE0A8B524041649126DE9B4B408FC360FE0A8B5240997FF44D9A9A4B4052616C21C8885240997FF44D9A9A4B40
28672	48848	74.399935999999997	74.420704999999998	55.443322000000002	55.431994000000003	Луговая	0103000020E610000001000000050000008E1F2A8D98995240BC0853944BB74B408E1F2A8D9899524075CC79C6BEB84B40E010AAD4EC9A524075CC79C6BEB84B40E010AAD4EC9A5240BC0853944BB74B408E1F2A8D98995240BC0853944BB74B40
29816	48843	74.233388000000005	74.254857999999999	55.717320000000001	55.705879000000003	Большая	0103000020E61000000100000005000000D9D138D4EF8E524073F7393E5ADA4B40D9D138D4EF8E524024624A24D1DB4B40EFC7ED974F90524024624A24D1DB4B40EFC7ED974F90524073F7393E5ADA4B40D9D138D4EF8E524073F7393E5ADA4B40
29818	48822	74.317165000000003	74.345614999999995	55.713988000000001	55.701571999999999	Красноярова	0103000020E61000000100000005000000E59B6D6E4C94524008E57D1CCDD94B40E59B6D6E4C94524044DE72F563DB4B407380608E1E96524044DE72F563DB4B407380608E1E96524008E57D1CCDD94B40E59B6D6E4C94524008E57D1CCDD94B40
73903	60144	74.137771999999998	74.153177999999997	55.709510000000002	55.694159999999997	Центральная	0103000020E610000001000000050000007D93A641D18852407E18213CDAD84B407D93A641D1885240AD174339D1DA4B40DE1D19ABCD895240AD174339D1DA4B40DE1D19ABCD8952407E18213CDAD84B407D93A641D18852407E18213CDAD84B40
29134	48774	74.223022	74.250483000000003	55.461787999999999	55.451889999999999	В. Гулака	0103000020E61000000100000005000000771211FE458E5240D9B11188D7B94B40771211FE458E5240B6D782DE1BBB4B400E4DD9E907905240B6D782DE1BBB4B400E4DD9E907905240D9B11188D7B94B40771211FE458E5240D9B11188D7B94B40
29676	4847	73.386393999999996	74.631997999999996	55.759495999999999	55.163795	Центральная	0103000020E61000000100000005000000B857E6ADBA585240C91F0C3CF7944B40B857E6ADBA585240AEB8382A37E14B40CB48BDA772A85240AEB8382A37E14B40CB48BDA772A85240C91F0C3CF7944B40B857E6ADBA585240C91F0C3CF7944B40
29807	48713	73.547120000000007	73.570531000000003	55.407376999999997	55.402608000000001	Центральная	0103000020E6100000010000000500000034BF9A0304635240D28DB0A888B34B4034BF9A03046352404012F6ED24B44B40AB967494836452404012F6ED24B44B40AB96749483645240D28DB0A888B34B4034BF9A0304635240D28DB0A888B34B40
30160	53131	74.256339999999994	74.266814999999994	55.247334000000002	55.237319999999997	Центральная	0103000020E61000000100000005000000062AE3DF67905240E6577380609E4B40062AE3DF679052402D98F8A3A89F4B4043C5387F139152402D98F8A3A89F4B4043C5387F13915240E6577380609E4B40062AE3DF67905240E6577380609E4B40
29864	47864	74.023173999999997	74.060642000000001	55.718288000000001	55.698847999999998	Центральная	0103000020E610000001000000050000008507CDAE7B8152400070ECD973D94B408507CDAE7B815240FC8D76DCF0DB4B40E6B0FB8EE1835240FC8D76DCF0DB4B40E6B0FB8EE18352400070ECD973D94B408507CDAE7B8152400070ECD973D94B40
29913	4549	73.738946999999996	73.762580999999997	55.592056999999997	55.581719	Новая	0103000020E610000001000000050000008C9E5BE84A6F52401D3BA8C475CA4B408C9E5BE84A6F5240162F1686C8CB4B4043E38920CE705240162F1686C8CB4B4043E38920CE7052401D3BA8C475CA4B408C9E5BE84A6F52401D3BA8C475CA4B40
29814	53041	73.629514	73.634202999999999	55.463946999999997	55.452227000000001	Центральная	0103000020E61000000100000005000000F29716F54968524021AF0793E2B94B40F29716F549685240E509849D62BB4B409B012EC896685240E509849D62BB4B409B012EC89668524021AF0793E2B94B40F29716F54968524021AF0793E2B94B40
29957	4456	73.427366000000006	73.461763000000005	55.472009999999997	55.46116	Советская	0103000020E61000000100000005000000085BECF6595B5240971C774A07BB4B40085BECF6595B524046B1DCD26ABC4B402FE065868D5D524046B1DCD26ABC4B402FE065868D5D5240971C774A07BB4B40085BECF6595B5240971C774A07BB4B40
29801	48600	73.796214000000006	73.808691999999994	55.604427000000001	55.592804999999998	Центральная	0103000020E6100000010000000500000083A7902BF5725240E0F3C308E1CB4B4083A7902BF5725240E2E82ADD5DCD4B405B22179CC1735240E2E82ADD5DCD4B405B22179CC1735240E0F3C308E1CB4B4083A7902BF5725240E0F3C308E1CB4B40
29437	48580	74.226147999999995	74.259654999999995	55.278148999999999	55.262906000000001	Центральная	0103000020E6100000010000000500000092037635798E52400AF65FE7A6A14B4092037635798E52402235ED629AA34B408B4F01309E9052402235ED629AA34B408B4F01309E9052400AF65FE7A6A14B4092037635798E52400AF65FE7A6A14B40
76442	60831	74.377917999999994	74.396163000000001	55.271451999999996	55.259709999999998	Центральная	0103000020E6100000010000000500000076A4FACE2F985240DA38622D3EA14B4076A4FACE2F98524086376BF0BEA24B40A8380EBC5A99524086376BF0BEA24B40A8380EBC5A995240DA38622D3EA14B4076A4FACE2F985240DA38622D3EA14B40
28678	4249	74.328457	74.343036999999995	55.312373999999998	55.307777000000002	Школьная	0103000020E610000001000000050000001B4982700595524002BB9A3C65A74B401B49827005955240730F09DFFBA74B4059147651F4955240730F09DFFBA74B4059147651F495524002BB9A3C65A74B401B4982700595524002BB9A3C65A74B40
29669	4163	74.563294999999997	74.575789999999998	55.258802000000003	55.250540999999998	Центральная	0103000020E6100000010000000500000005C078060DA4524050A73CBA11A04B4005C078060DA45240D811876C20A14B4049D74CBED9A45240D811876C20A14B4049D74CBED9A4524050A73CBA11A04B4005C078060DA4524050A73CBA11A04B40
29712	46191	74.406852999999998	74.432858999999993	55.749688999999996	55.741996999999998	Новая	0103000020E61000000100000005000000E3512AE1099A5240745DF8C1F9DE4B40E3512AE1099A5240E19524CFF5DF4B40DF313CF6B39B5240E19524CFF5DF4B40DF313CF6B39B5240745DF8C1F9DE4B40E3512AE1099A5240745DF8C1F9DE4B40
29110	48136	74.147294000000002	74.175060999999999	55.309156000000002	55.300716000000001	2-я Малая	0103000020E610000001000000050000006939D0436D89524025B1A4DC7DA64B406939D0436D8952405CAE7E6C92A74B4086730D33348B52405CAE7E6C92A74B4086730D33348B524025B1A4DC7DA64B406939D0436D89524025B1A4DC7DA64B40
29956	48142	73.660362000000006	73.684832	55.514901000000002	55.507423000000003	Школьная	0103000020E610000001000000050000005B61FA5E436A52407E1EA33CF3C04B405B61FA5E436A5240BFD6A546E8C14B4046D09849D46B5240BFD6A546E8C14B4046D09849D46B52407E1EA33CF3C04B405B61FA5E436A52407E1EA33CF3C04B40
29952	48494	73.776757000000003	73.803364999999999	55.426808999999999	55.413089999999997	Ленина	0103000020E610000001000000050000001AFCFD62B6715240FE261422E0B44B401AFCFD62B6715240B95164ADA1B64B40117008556A735240B95164ADA1B64B40117008556A735240FE261422E0B44B401AFCFD62B6715240FE261422E0B44B40
29397	3924	74.341697999999994	74.396800999999996	55.382488000000002	55.354497000000002	Павлика Морозова	0103000020E61000000100000005000000F3C64961DE955240DBC35E2860AD4B40F3C64961DE955240658EE55DF5B04B404981053065995240658EE55DF5B04B404981053065995240DBC35E2860AD4B40F3C64961DE955240DBC35E2860AD4B40
29799	3924	74.341697999999994	74.396800999999996	55.382488000000002	55.354497000000002	Маяковского	0103000020E61000000100000005000000F3C64961DE955240DBC35E2860AD4B40F3C64961DE955240658EE55DF5B04B404981053065995240658EE55DF5B04B404981053065995240DBC35E2860AD4B40F3C64961DE955240DBC35E2860AD4B40
29948	3924	74.341697999999994	74.396800999999996	55.382488000000002	55.354497000000002	Ленина	0103000020E61000000100000005000000F3C64961DE955240DBC35E2860AD4B40F3C64961DE955240658EE55DF5B04B404981053065995240658EE55DF5B04B404981053065995240DBC35E2860AD4B40F3C64961DE955240DBC35E2860AD4B40
29396	3924	74.341697999999994	74.396800999999996	55.382488000000002	55.354497000000002	Кирова	0103000020E61000000100000005000000F3C64961DE955240DBC35E2860AD4B40F3C64961DE955240658EE55DF5B04B404981053065995240658EE55DF5B04B404981053065995240DBC35E2860AD4B40F3C64961DE955240DBC35E2860AD4B40
29731	53032	73.864611999999994	73.898200000000003	55.588709999999999	55.576456999999998	Центральная	0103000020E61000000100000005000000AAEE91CD557752406F46CD57C9C94B40AAEE91CD55775240016A6AD95ACB4B401A51DA1B7C795240016A6AD95ACB4B401A51DA1B7C7952406F46CD57C9C94B40AAEE91CD557752406F46CD57C9C94B40
29664	48386	74.447627999999995	74.460661999999999	55.311031	55.301397000000001	Зеленая	0103000020E610000001000000050000008731E9EFA59C5240670E492D94A64B408731E9EFA59C5240668522DDCFA74B40A320787C7B9D5240668522DDCFA74B40A320787C7B9D5240670E492D94A64B408731E9EFA59C5240670E492D94A64B40
30081	48335	73.948190999999994	73.975536000000005	55.711132999999997	55.697823	Центральная 	0103000020E6100000010000000500000023D74D29AF7C5240C4B2994352D94B4023D74D29AF7C52409D0DF96706DB4B4086048C2E6F7E52409D0DF96706DB4B4086048C2E6F7E5240C4B2994352D94B4023D74D29AF7C5240C4B2994352D94B40
76411	60818	74.026838999999995	74.045586999999998	55.360326000000001	55.350161999999997	Школьная	0103000020E6100000010000000500000078D0ECBAB7815240A626C11BD2AC4B4078D0ECBAB781524002F390291FAE4B40DB87BCE5EA82524002F390291FAE4B40DB87BCE5EA825240A626C11BD2AC4B4078D0ECBAB7815240A626C11BD2AC4B40
29242	3442	74.419960000000003	74.459835999999996	55.369959999999999	55.353437	30 лет Победы	0103000020E610000001000000050000003468E89FE09A52402219726C3DAD4B403468E89FE09A5240016A6AD95AAF4B408061F9F36D9D5240016A6AD95AAF4B408061F9F36D9D52402219726C3DAD4B403468E89FE09A52402219726C3DAD4B40
29790	48250	74.059590999999998	74.080926000000005	55.545676	55.528477000000002	Юбилейная	0103000020E61000000100000005000000B308C556D083524017D86322A5C34B40B308C556D0835240261B0FB6D8C54B405AD93EE42D855240261B0FB6D8C54B405AD93EE42D85524017D86322A5C34B40B308C556D083524017D86322A5C34B40
29531	3307	73.989486999999997	74.008846000000005	55.453283999999996	55.448163000000001	Центральная	0103000020E610000001000000050000004C3448C1537F52407D23BA675DB94B404C3448C1537F524068E6C93505BA4B40D42CD0EE9080524068E6C93505BA4B40D42CD0EE908052407D23BA675DB94B404C3448C1537F52407D23BA675DB94B40
29375	3191	73.853759999999994	73.867585000000005	55.531824999999998	55.516119000000003	Новая	0103000020E6100000010000000500000082A8FB00A476524010ECF82F10C24B4082A8FB00A4765240FC1873D712C44B4003603C8386775240FC1873D712C44B4003603C838677524010ECF82F10C24B4082A8FB00A476524010ECF82F10C24B40
29236	3108	72.509719000000004	72.528467000000006	56.554096000000001	56.545642000000001	Иванова	0103000020E6100000010000000500000097C9703C9F2052407AA9D898D7454C4097C9703C9F205240166C239EEC464C40FA804067D2215240166C239EEC464C40FA804067D22152407AA9D898D7454C4097C9703C9F2052407AA9D898D7454C40
29650	2961	73.061716000000004	73.080130999999994	57.099032000000001	57.087085999999999	Молодёжная	0103000020E61000000100000005000000F568AA27F343524040F850A2258B4C40F568AA27F3435240F5A0A014AD8C4C405419C6DD20455240F5A0A014AD8C4C405419C6DD2045524040F850A2258B4C40F568AA27F343524040F850A2258B4C40
29784	3011	73.075441999999995	73.091172	57.148493000000002	57.139234000000002	Школьная	0103000020E61000000100000005000000ABAFAE0AD4445240E23E726BD2914C40ABAFAE0AD4445240AC5791D101934C40E69315C3D5455240AC5791D101934C40E69315C3D5455240E23E726BD2914C40ABAFAE0AD4445240E23E726BD2914C40
29984	2693	72.152917000000002	72.171916999999993	56.788908999999997	56.774608000000001	Ямщицкая	0103000020E6100000010000000500000028806264C9095240289CDD5A26634C4028806264C9095240914259F8FA644C40172829B0000B5240914259F8FA644C40172829B0000B5240289CDD5A26634C4028806264C9095240289CDD5A26634C40
29923	2842	72.866629000000003	72.898500999999996	57.043258000000002	57.031097000000003	Калинина	0103000020E61000000100000005000000F9307BD9763752407A008BFCFA834C40F9307BD9763752402BA5677A89854C40179B560A813952402BA5677A89854C40179B560A813952407A008BFCFA834C40F9307BD9763752407A008BFCFA834C40
29228	2722	72.944188999999994	72.978037999999998	57.074655999999997	57.064224000000003	Центральная	0103000020E610000001000000050000008C0FB3976D3C524025CFF57D38884C408C0FB3976D3C52409F39EB538E894C40B20FB22C983E52409F39EB538E894C40B20FB22C983E524025CFF57D38884C408C0FB3976D3C524025CFF57D38884C40
29222	2260	72.609871999999996	72.630640999999997	56.996617000000001	56.981620999999997	Молодёжная	0103000020E61000000100000005000000C0AF9124082752408D08C6C1A57D4C40C0AF9124082752409ED15625917F4C4012A1116C5C2852409ED15625917F4C4012A1116C5C2852408D08C6C1A57D4C40C0AF9124082752408D08C6C1A57D4C40
29648	2607	72.361307999999994	72.395705000000007	56.867108999999999	56.849251000000002	Школьная	0103000020E610000001000000050000001FF296AB1F175240338CBB41B46C4C401FF296AB1F1752409C887E6DFD6E4C404777103B531952409C887E6DFD6E4C404777103B53195240338CBB41B46C4C401FF296AB1F175240338CBB41B46C4C40
29102	2163	72.431466999999998	72.450402999999994	56.930796999999998	56.919533999999999	Клементьева	0103000020E610000001000000050000006893C3279D1B5240B0C7444AB3754C406893C3279D1B5240821B295B24774C404CC11A67D31C5240821B295B24774C404CC11A67D31C5240B0C7444AB3754C406893C3279D1B5240B0C7444AB3754C40
29647	2516	71.891597000000004	71.925687999999994	57.238712	57.230201999999998	Школьная	0103000020E610000001000000050000008D0DDDEC0FF95140A5BC5642779D4C408D0DDDEC0FF95140D594641D8E9E4C402D93E1783EFB5140D594641D8E9E4C402D93E1783EFB5140A5BC5642779D4C408D0DDDEC0FF95140A5BC5642779D4C40
29233	2652	72.432608000000002	72.445310000000006	56.848281	56.840409000000001	Школьный переулок	0103000020E610000001000000050000003BFF76D9AF1B5240CD21A985926B4C403BFF76D9AF1B5240BA68C878946C4C403CA583F57F1C5240BA68C878946C4C403CA583F57F1C5240CD21A985926B4C403BFF76D9AF1B5240CD21A985926B4C40
29099	2152	72.761426999999998	72.778296999999995	56.780619999999999	56.768956000000003	Кольцевая	0103000020E61000000100000005000000A6D24F38BB305240100874266D624C40A6D24F38BB305240404D2D5BEB634C40CB64389ECF315240404D2D5BEB634C40CB64389ECF315240100874266D624C40A6D24F38BB305240100874266D624C40
29517	2366	72.597618999999995	72.654032999999998	56.968223999999999	56.935462999999999	Карла Маркса	0103000020E61000000100000005000000F71DC3633F2652401CCF6740BD774C40F71DC3633F265240E59997C3EE7B4C404E603AADDB295240E59997C3EE7B4C404E603AADDB2952401CCF6740BD774C40F71DC3633F2652401CCF6740BD774C40
30059	2366	72.597618999999995	72.654032999999998	56.968223999999999	56.935462999999999	Калинина	0103000020E61000000100000005000000F71DC3633F2652401CCF6740BD774C40F71DC3633F265240E59997C3EE7B4C404E603AADDB295240E59997C3EE7B4C404E603AADDB2952401CCF6740BD774C40F71DC3633F2652401CCF6740BD774C40
29522	2366	72.597618999999995	72.654032999999998	56.968223999999999	56.935462999999999	Избышева	0103000020E61000000100000005000000F71DC3633F2652401CCF6740BD774C40F71DC3633F265240E59997C3EE7B4C404E603AADDB295240E59997C3EE7B4C404E603AADDB2952401CCF6740BD774C40F71DC3633F2652401CCF6740BD774C40
29646	2309	72.810134000000005	72.855093999999994	56.633203999999999	56.616377	П.Сидельникова	0103000020E610000001000000050000002CD8463CD9335240D8800871E54E4C402CD8463CD933524023D923D40C514C405F402FDCB936524023D923D40C514C405F402FDCB9365240D8800871E54E4C402CD8463CD9335240D8800871E54E4C40
29524	2862	72.768388999999999	72.799272999999999	57.013061999999998	57.003352999999997	Центральная	0103000020E61000000100000005000000CB660E492D315240F7AB00DF6D804C40CB660E492D3152400169FF03AC814C40DAE4F049273352400169FF03AC814C40DAE4F04927335240F7AB00DF6D804C40CB660E492D315240F7AB00DF6D804C40
29362	2074	72.614984000000007	72.640728999999993	56.935437999999998	56.922480999999998	Березовая	0103000020E610000001000000050000000DE4D9E55B27524037177FDB13764C400DE4D9E55B275240C3B7B06EBC774C40522635B401295240C3B7B06EBC774C40522635B40129524037177FDB13764C400DE4D9E55B27524037177FDB13764C40
29907	972	73.765887000000006	73.787698000000006	56.119222999999998	56.109721999999998	Школьная	0103000020E610000001000000050000009F5BE84A047152406BD3D85E0B0E4C409F5BE84A047152402BF702B3420F4C40FA47DFA4697252402BF702B3420F4C40FA47DFA4697252406BD3D85E0B0E4C409F5BE84A047152406BD3D85E0B0E4C40
29484	32392	74.384027000000003	74.403233	56.409255000000002	56.399776000000003	Южная	0103000020E61000000100000005000000FC71FBE593985240E4DC26DC2B334C40FC71FBE593985240BC5CC47762344C40C0EAC891CE995240BC5CC47762344C40C0EAC891CE995240E4DC26DC2B334C40FC71FBE593985240E4DC26DC2B334C40
29326	32101	74.647520999999998	74.661282999999997	56.531700000000001	56.525329999999997	Дорожная	0103000020E61000000100000005000000499EEBFB70A95240C8CD70033E434C40499EEBFB70A9524040A4DFBE0E444C40A699EE7552AA524040A4DFBE0E444C40A699EE7552AA5240C8CD70033E434C40499EEBFB70A95240C8CD70033E434C40
29889	53052	74.550421999999998	74.581413999999995	56.023499999999999	56.005218999999997	Школьная	0103000020E61000000100000005000000EE3F321D3AA35240AE282504AB004C40EE3F321D3AA352405EBA490C02034C40F0DB10E335A552405EBA490C02034C40F0DB10E335A55240AE282504AB004C40EE3F321D3AA35240AE282504AB004C40
29896	1135	73.933306000000002	73.958459000000005	55.843631000000002	55.834921999999999	Центральная	0103000020E6100000010000000500000047CA1649BB7B5240FF5A5EB9DEEA4B4047CA1649BB7B52402672C119FCEB4B40A4E36A64577D52402672C119FCEB4B40A4E36A64577D5240FF5A5EB9DEEA4B4047CA1649BB7B5240FF5A5EB9DEEA4B40
29492	249	74.165772000000004	74.181601000000001	56.326222999999999	56.318995000000001	Приозерная	0103000020E61000000100000005000000ECA529029C8A5240344B02D4D4284C40ECA529029C8A5240FC19DEACC1294C40F0FACC599F8B5240FC19DEACC1294C40F0FACC599F8B5240344B02D4D4284C40ECA529029C8A5240344B02D4D4284C40
29876	32225	74.748859999999993	74.760402999999997	56.586359999999999	56.580053999999997	Береговая	0103000020E6100000010000000500000015527E52EDAF5240FDF49F353F4A4C4015527E52EDAF52405ED72FD80D4B4C40F0315871AAB052405ED72FD80D4B4C40F0315871AAB05240FDF49F353F4A4C4015527E52EDAF5240FDF49F353F4A4C40
76468	60852	73.865313	73.889989	55.976180999999997	55.960614	Центральная	0103000020E610000001000000050000006FF3C64961775240350A4966F5FA4B406FF3C6496177524000FDBE7FF3FC4B402F336C94F578524000FDBE7FF3FC4B402F336C94F5785240350A4966F5FA4B406FF3C64961775240350A4966F5FA4B40
29761	871	73.999791000000002	74.012259	56.013190000000002	56.003346000000001	Школьная	0103000020E6100000010000000500000073F56393FC7F5240454948A46D004C4073F56393FC7F52402F51BD35B0014C403A05F9D9C88052402F51BD35B0014C403A05F9D9C8805240454948A46D004C4073F56393FC7F5240454948A46D004C40
29198	143	74.313041999999996	74.336713000000003	56.372472999999999	56.366948999999998	Казанская	0103000020E61000000100000005000000901150E1089452406326512FF82E4C40901150E1089452404ED2FC31AD2F4C40D6C8AEB48C9552404ED2FC31AD2F4C40D6C8AEB48C9552406326512FF82E4C40901150E1089452406326512FF82E4C40
29207	1075	74.017083	74.041859000000002	55.853648	55.844884999999998	Центральная	0103000020E6100000010000000500000053944BE317815240C3F0113125EC4B4053944BE317815240DD25715644ED4B40C5025FD1AD825240DD25715644ED4B40C5025FD1AD825240C3F0113125EC4B4053944BE317815240C3F0113125EC4B40
30022	32044	74.626249000000001	74.637683999999993	56.555996999999998	56.547601999999998	Иртышская	0103000020E61000000100000005000000C689AF7614A85240B29C84D217464C40C689AF7614A8524049D6E1E82A474C40AD4B8DD0CFA8524049D6E1E82A474C40AD4B8DD0CFA85240B29C84D217464C40C689AF7614A85240B29C84D217464C40
29202	52979	74.664974999999998	74.693380000000005	56.257142999999999	56.230891999999997	Школьная	0103000020E61000000100000005000000166A4DF38EAA52403A747ADE8D1D4C40166A4DF38EAA52409AB2D30FEA204C40D5EC815660AC52409AB2D30FEA204C40D5EC815660AC52403A747ADE8D1D4C40166A4DF38EAA52403A747ADE8D1D4C40
29337	517	74.108981	74.126219000000006	56.087795	56.07799	Лесная	0103000020E61000000100000005000000AAB8718BF986524020B58993FB094C40AAB8718BF98652404CE0D6DD3C0B4C409148DBF8138852404CE0D6DD3C0B4C409148DBF81388524020B58993FB094C40AAB8718BF986524020B58993FB094C40
29477	32011	74.563843000000006	74.577308000000002	56.616931999999998	56.606330999999997	Береговая	0103000020E610000001000000050000000745F30016A4524086C613419C4D4C400745F30016A452408DEDB5A0F74E4C4007EE409DF2A452408DEDB5A0F74E4C4007EE409DF2A4524086C613419C4D4C400745F30016A4524086C613419C4D4C40
29096	1621	74.368961999999996	74.391923000000006	55.991284	55.979726999999997	Рязанская	0103000020E61000000100000005000000DFDDCA129D9752400C01C0B167FD4B40DFDDCA129D9752402786E464E2FE4B4037E33444159952402786E464E2FE4B4037E33444159952400C01C0B167FD4B40DFDDCA129D9752400C01C0B167FD4B40
29090	1277	73.900148999999999	73.916049999999998	55.889386000000002	55.885266999999999	Центральная	0103000020E61000000100000005000000BC218D0A9C795240309DD66D50F14B40BC218D0A9C79524098C28366D7F14B400DE02D90A07A524098C28366D7F14B400DE02D90A07A5240309DD66D50F14B40BC218D0A9C795240309DD66D50F14B40
29911	1490	74.371756000000005	74.388706999999997	55.807429999999997	55.798222000000003	Зеленая	0103000020E61000000100000005000000E085ADD9CA9752404F7974232CE64B40E085ADD9CA97524096E7C1DD59E74B407B2E5393E098524096E7C1DD59E74B407B2E5393E09852404F7974232CE64B40E085ADD9CA9752404F7974232CE64B40
30093	53100	74.442803999999995	74.477172999999993	56.523563000000003	56.509448999999996	Школьный переулок	0103000020E610000001000000050000006EA296E6569C52406DFDF49F35414C406EA296E6569C5240A532C51C04434C4030629F008A9E5240A532C51C04434C4030629F008A9E52406DFDF49F35414C406EA296E6569C52406DFDF49F35414C40
29469	31633	74.463339000000005	74.480551000000006	56.119965999999998	56.110370000000003	Центральная	0103000020E6100000010000000500000087FD9E58A79D5240D23AAA9A200E4C4087FD9E58A79D5240E350BF0B5B0F4C40D943FB58C19E5240E350BF0B5B0F4C40D943FB58C19E5240D23AAA9A200E4C4087FD9E58A79D5240D23AAA9A200E4C40
30154	53128	74.600898000000001	74.629571999999996	56.590339999999998	56.572423999999998	Советская	0103000020E61000000100000005000000D68EE21C75A6524006B98B3045494C40D68EE21C75A65240A4C2D842904B4C408C9E5BE84AA85240A4C2D842904B4C408C9E5BE84AA8524006B98B3045494C40D68EE21C75A6524006B98B3045494C40
29351	1711	74.217578000000003	74.235904000000005	55.935586999999998	55.929364	Луговая	0103000020E61000000100000005000000109546CCEC8D5240350A4966F5F64B40109546CCEC8D524008C89750C1F74B40B83F170D198F524008C89750C1F74B40B83F170D198F5240350A4966F5F64B40109546CCEC8D5240350A4966F5F64B40
30159	53130	74.444761999999997	74.469303999999994	55.925884000000003	55.913913999999998	Чехова	0103000020E610000001000000050000003A2009FB769C5240A3AD4A22FBF44B403A2009FB769C5240E1F1ED5D83F64B4072F8A413099E5240E1F1ED5D83F64B4072F8A413099E5240A3AD4A22FBF44B403A2009FB769C5240A3AD4A22FBF44B40
29910	1367	74.311595999999994	74.335122999999996	55.84496	55.839678999999997	Победы	0103000020E610000001000000050000001F645930F1935240A911FA997AEB4B401F645930F1935240CE3637A627EC4B40CB48BDA772955240CE3637A627EC4B40CB48BDA772955240A911FA997AEB4B401F645930F1935240A911FA997AEB4B40
29887	53050	74.302306999999999	74.333892000000006	56.127150999999998	56.114615999999998	Советов	0103000020E61000000100000005000000859675FF5893524096CCB1BCAB0E4C40859675FF58935240AC53E57B46104C4059198D7C5E955240AC53E57B46104C4059198D7C5E95524096CCB1BCAB0E4C40859675FF5893524096CCB1BCAB0E4C40
29620	742	74.152970999999994	74.171413999999999	56.223095999999998	56.217309999999998	Школьная	0103000020E61000000100000005000000218FE046CA895240008C67D0D01B4C40218FE046CA89524028EFE3688E1C4C40E6046D72F88A524028EFE3688E1C4C40E6046D72F88A5240008C67D0D01B4C40218FE046CA895240008C67D0D01B4C40
29740	31588	74.476607000000001	74.497224000000003	56.180638000000002	56.167569	Школьная	0103000020E61000000100000005000000DC82A5BA809E52406669A7E672154C40DC82A5BA809E52401A355F251F174C4053B29C84D29F52401A355F251F174C4053B29C84D29F52406669A7E672154C40DC82A5BA809E52406669A7E672154C40
29058	52964	74.604240000000004	74.627155999999999	56.160164999999999	56.137951999999999	Советов	0103000020E61000000100000005000000D8BB3FDEABA652407A354069A8114C40D8BB3FDEABA652405F7B664980144C405F5FEB5223A852405F7B664980144C405F5FEB5223A852407A354069A8114C40D8BB3FDEABA652407A354069A8114C40
29194	32295	74.298579000000004	74.315629000000001	56.503866000000002	56.493616000000003	Центральная	0103000020E610000001000000050000006F1118EB1B935240246420CF2E3F4C406F1118EB1B9352407EC85BAE7E404C40D42AFA43339452407EC85BAE7E404C40D42AFA4333945240246420CF2E3F4C406F1118EB1B935240246420CF2E3F4C40
29073	32449	74.407535999999993	74.424396999999999	56.455666999999998	56.445981000000003	 Центральная	0103000020E6100000010000000500000054FCDF11159A524096D1C8E715394C4054FCDF11159A5240E76ED74B533A4C4050E10852299B5240E76ED74B533A4C4050E10852299B524096D1C8E715394C4054FCDF11159A524096D1C8E715394C40
30021	31908	74.658901999999998	74.672521000000003	56.460492000000002	56.444001	Новая	0103000020E6100000010000000500000037514B732BAA524016325706D5384C4037514B732BAA5240EA08E066F13A4C40E33785950AAB5240EA08E066F13A4C40E33785950AAB524016325706D5384C4037514B732BAA524016325706D5384C40
29511	1966	74.560196000000005	74.584925999999996	56.048515000000002	56.034444999999998	Кирсановская	0103000020E6100000010000000500000067D65240DAA352405F419AB168044C4067D65240DAA35240C72E51BD35064C402025766D6FA55240C72E51BD35064C402025766D6FA552405F419AB168044C4067D65240DAA352405F419AB168044C40
29333	362	74.087969000000001	74.103339000000005	56.318835	56.313268999999998	Лесная	0103000020E61000000100000005000000F583BA48A1855240E1ECD63219284C40F583BA48A1855240FBE8D495CF284C40B0592E1B9D865240FBE8D495CF284C40B0592E1B9D865240E1ECD63219284C40F583BA48A1855240E1ECD63219284C40
29331	52989	74.183064999999999	74.232525999999993	55.860028999999997	55.839421000000002	Школьная	0103000020E61000000100000005000000B4024356B78B5240AE49B72572EB4B40B4024356B78B5240484E266E15EE4B400F5EBBB4E18E5240484E266E15EE4B400F5EBBB4E18E5240AE49B72572EB4B40B4024356B78B5240AE49B72572EB4B40
29335	496	74.215781000000007	74.227513000000002	56.124395999999997	56.116709	Зеленая	0103000020E6100000010000000500000049861C5BCF8D52400E130D52F00E4C4049861C5BCF8D524069E04735EC0F4C408D9AAF928F8E524069E04735EC0F4C408D9AAF928F8E52400E130D52F00E4C4049861C5BCF8D52400E130D52F00E4C40
29219	2025	74.636444999999995	74.652623000000006	56.018327999999997	56.008856999999999	Гущинская	0103000020E61000000100000005000000F92CCF83BBA852409BABE63922014C40F92CCF83BBA85240F04C689258024C4084674293C4A95240F04C689258024C4084674293C4A952409BABE63922014C40F92CCF83BBA852409BABE63922014C40
29321	31820	74.545769000000007	74.566196000000005	56.283695000000002	56.274723999999999	Центральная	0103000020E61000000100000005000000EC8A19E1EDA2524091B6F1272A234C40EC8A19E1EDA25240F584251E50244C4011C8258E3CA45240F584251E50244C4011C8258E3CA4524091B6F1272A234C40EC8A19E1EDA2524091B6F1272A234C40
29621	52965	74.598590000000002	74.649721999999997	56.128354999999999	56.075167	Трудовая	0103000020E610000001000000050000009C6D6E4C4FA65240855E7F129F094C409C6D6E4C4FA6524098A3C7EF6D104C40785F950B95A9524098A3C7EF6D104C40785F950B95A95240855E7F129F094C409C6D6E4C4FA65240855E7F129F094C40
29065	52965	74.598590000000002	74.649721999999997	56.128354999999999	56.075167	О.Бронского	0103000020E610000001000000050000009C6D6E4C4FA65240855E7F129F094C409C6D6E4C4FA6524098A3C7EF6D104C40785F950B95A9524098A3C7EF6D104C40785F950B95A95240855E7F129F094C409C6D6E4C4FA65240855E7F129F094C40
30145	52965	74.598590000000002	74.649721999999997	56.128354999999999	56.075167	Коммунистическая	0103000020E610000001000000050000009C6D6E4C4FA65240855E7F129F094C409C6D6E4C4FA6524098A3C7EF6D104C40785F950B95A9524098A3C7EF6D104C40785F950B95A95240855E7F129F094C409C6D6E4C4FA65240855E7F129F094C40
30124	52965	74.598590000000002	74.649721999999997	56.128354999999999	56.075167	Дорожная	0103000020E610000001000000050000009C6D6E4C4FA65240855E7F129F094C409C6D6E4C4FA6524098A3C7EF6D104C40785F950B95A9524098A3C7EF6D104C40785F950B95A95240855E7F129F094C409C6D6E4C4FA65240855E7F129F094C40
30125	52965	74.598590000000002	74.649721999999997	56.128354999999999	56.075167	Гагарина	0103000020E610000001000000050000009C6D6E4C4FA65240855E7F129F094C409C6D6E4C4FA6524098A3C7EF6D104C40785F950B95A9524098A3C7EF6D104C40785F950B95A95240855E7F129F094C409C6D6E4C4FA65240855E7F129F094C40
30128	52965	74.598590000000002	74.649721999999997	56.128354999999999	56.075167	50 лет ВЛКСМ	0103000020E610000001000000050000009C6D6E4C4FA65240855E7F129F094C409C6D6E4C4FA6524098A3C7EF6D104C40785F950B95A9524098A3C7EF6D104C40785F950B95A95240855E7F129F094C409C6D6E4C4FA65240855E7F129F094C40
76391	60811	74.535473999999994	74.550458000000006	55.933019999999999	55.925269	Молодежная	0103000020E61000000100000005000000EE76BD3445A252405680EF366FF64B40EE76BD3445A25240C84109336DF74B4095F430B43AA35240C84109336DF74B4095F430B43AA352405680EF366FF64B40EE76BD3445A252405680EF366FF64B40
29328	32156	74.567265000000006	74.578647000000004	56.625534000000002	56.620953999999998	Береговая	0103000020E6100000010000000500000097CADB114EA452400229B16B7B4F4C4097CADB114EA452409E44847F11504C406D3B6D8D08A552409E44847F11504C406D3B6D8D08A552400229B16B7B4F4C4097CADB114EA452400229B16B7B4F4C40
29627	918	73.861144999999993	73.868672000000004	55.922322999999999	55.914977999999998	Школьный переулок	0103000020E610000001000000050000004A07EBFF1C7752409D47C5FF1DF54B404A07EBFF1C7752409FAC18AE0EF64B40DCBC7152987752409FAC18AE0EF64B40DCBC7152987752409D47C5FF1DF54B404A07EBFF1C7752409D47C5FF1DF54B40
29185	31494	74.552389000000005	74.560563999999999	56.136346000000003	56.129322999999999	Центральная	0103000020E61000000100000005000000E46A64575AA3524070CFF3A78D104C40E46A64575AA35240607825C973114C4028D4D347E0A35240607825C973114C4028D4D347E0A3524070CFF3A78D104C40E46A64575AA3524070CFF3A78D104C40
29367	25582	72.907493000000002	72.920195000000007	54.679015	54.668905000000002	1 Мая	0103000020E610000001000000050000005516855D143A5240C190D5AD9E554B405516855D143A5240293FA9F6E9564B4056BC9179E43A5240293FA9F6E9564B4056BC9179E43A5240C190D5AD9E554B405516855D143A5240C190D5AD9E554B40
79296	61522	73.019486000000001	73.036580999999998	54.637835000000003	54.627543000000003	Школьная	0103000020E61000000100000005000000B62E35423F415240B8EA3A5453504B40B62E35423F415240419FC893A4514B40EBA9D55757425240419FC893A4514B40EBA9D55757425240B8EA3A5453504B40B62E35423F415240B8EA3A5453504B40
29455	30801	72.853872999999993	72.904456999999994	54.498058	54.479162000000002	Кирова	0103000020E61000000100000005000000FE7BF0DAA536524034BE2F2E553D4B40FE7BF0DAA53652406EC1525DC03F4B40D9E89C9FE23952406EC1525DC03F4B40D9E89C9FE239524034BE2F2E553D4B40FE7BF0DAA536524034BE2F2E553D4B40
74030	60201	73.019898999999995	73.034946000000005	54.838617999999997	54.835507	Березовая	0103000020E61000000100000005000000478E7406464152401F4AB4E4F16A4B40478E74064641524020EBA9D5576B4B4011C8258E3C42524020EBA9D5576B4B4011C8258E3C4252401F4AB4E4F16A4B40478E7406464152401F4AB4E4F16A4B40
29249	46235	72.889347000000001	72.913241999999997	54.616470999999997	54.603560000000002	Колхозная	0103000020E61000000100000005000000EDF2AD0FEB3852403E963E74414D4B40EDF2AD0FEB38524059F78F85E84E4B405AD5928E723A524059F78F85E84E4B405AD5928E723A52403E963E74414D4B40EDF2AD0FEB3852403E963E74414D4B40
79260	61502	73.131694999999993	73.164356999999995	54.824969000000003	54.806365999999997	Школьная 	0103000020E61000000100000005000000FD82DDB06D4852409C4D470037674B40FD82DDB06D4852405F9B8D9598694B4098F738D3844A52405F9B8D9598694B4098F738D3844A52409C4D470037674B40FD82DDB06D4852409C4D470037674B40
29298	30488	73.002606999999998	73.023258999999996	54.436591	54.430872000000001	Школьная	0103000020E6100000010000000500000067EF8CB62A4052408D614ED026374B4067EF8CB62A4052402D5DC136E2374B409C1551137D4152402D5DC136E2374B409C1551137D4152408D614ED026374B4067EF8CB62A4052408D614ED026374B40
76427	60827	72.906801000000002	72.921165000000002	54.772671000000003	54.764901000000002	Школьная	0103000020E61000000100000005000000BABE0F07093A5240BFD6A546E8614B40BABE0F07093A5240A8C821E2E6624B40124E0B5EF43A5240A8C821E2E6624B40124E0B5EF43A5240BFD6A546E8614B40BABE0F07093A5240BFD6A546E8614B40
29986	7481	72.849012999999999	72.866431000000006	54.684443999999999	54.670160000000003	Российская	0103000020E610000001000000050000003F389F3A563652402F8B89CDC7554B403F389F3A56365240C2F869DC9B574B40664F029B73375240C2F869DC9B574B40664F029B733752402F8B89CDC7554B403F389F3A563652402F8B89CDC7554B40
30175	53134	72.936139999999995	72.954322000000005	54.477347000000002	54.469729999999998	Центральная	0103000020E610000001000000050000008E1EBFB7E93B52409CF9D51C203C4B408E1EBFB7E93B5240FFEBDCB4193D4B409DF6949C133D5240FFEBDCB4193D4B409DF6949C133D52409CF9D51C203C4B408E1EBFB7E93B52409CF9D51C203C4B40
29121	46237	73.049228999999997	73.076745000000003	54.437277000000002	54.426326000000003	Центральная	0103000020E61000000100000005000000F2406491264352409EB7B1D991364B40F240649126435240812557B1F8374B406B48DC63E9445240812557B1F8374B406B48DC63E94452409EB7B1D991364B40F2406491264352409EB7B1D991364B40
30015	30168	72.980013999999997	73.009271999999996	54.694716999999997	54.682580000000002	Карла Маркса	0103000020E61000000100000005000000D1E7A38CB83E5240AC730CC85E574B40D1E7A38CB83E5240D47C957CEC584B402F3196E997405240D47C957CEC584B402F3196E997405240AC730CC85E574B40D1E7A38CB83E5240AC730CC85E574B40
29597	46380	73.089222000000007	73.119082000000006	54.869875	54.858812999999998	Школьная	0103000020E610000001000000050000005C0531D0B545524098309A95ED6D4B405C0531D0B5455240D34D6210586F4B40B5E21B0A9F475240D34D6210586F4B40B5E21B0A9F47524098309A95ED6D4B405C0531D0B545524098309A95ED6D4B40
29969	45992	73.133337999999995	73.157906999999994	54.686359000000003	54.670273999999999	Центральная	0103000020E6100000010000000500000019541B9C88485240F7ADD689CB554B4019541B9C884852405B28999CDA574B40CE33F6251B4A52405B28999CDA574B40CE33F6251B4A5240F7ADD689CB554B4019541B9C88485240F7ADD689CB554B40
29596	46363	73.136724999999998	73.148493000000002	54.763658999999997	54.758302999999998	Ленина	0103000020E61000000100000005000000EBE2361AC0485240B6BA9C1210614B40EBE2361AC0485240E525FF93BF614B40D6ABC8E880495240E525FF93BF614B40D6ABC8E880495240B6BA9C1210614B40EBE2361AC0485240B6BA9C1210614B40
29047	46341	73.056558999999993	73.094289000000003	54.907640999999998	54.894694000000001	Ворошилова	0103000020E61000000100000005000000D8D2A3A99E435240B6F63E5585724B40D8D2A3A99E4352401EC18D942D744B40D8D7BAD4084652401EC18D942D744B40D8D7BAD408465240B6F63E5585724B40D8D2A3A99E435240B6F63E5585724B40
29060	46266	73.103829000000005	73.122172000000006	54.51164	54.503213000000002	Центральная	0103000020E6100000010000000500000017D86322A546524006F6984869404B4017D86322A5465240A8A9656B7D414B402A1F82AAD1475240A8A9656B7D414B402A1F82AAD147524006F6984869404B4017D86322A546524006F6984869404B40
29475	30341	73.362795000000006	73.376423000000003	54.753684999999997	54.744866000000002	Центральная	0103000020E61000000100000005000000C00985083857524080F3E2C4575F4B40C0098508385752402D3E05C078604B40959D7E50175852402D3E05C078604B40959D7E501758524080F3E2C4575F4B40C00985083857524080F3E2C4575F4B40
29187	30300	73.317717999999999	73.335801000000004	54.743358999999998	54.740101000000003	Центральная	0103000020E610000001000000050000006FD6E07D55545240535E2BA1BB5E4B406FD6E07D55545240F8174163265F4B40B43D7AC37D555240F8174163265F4B40B43D7AC37D555240535E2BA1BB5E4B406FD6E07D55545240535E2BA1BB5E4B40
29540	30244	73.353443999999996	73.387867	54.696111000000002	54.685589	Школьная	0103000020E61000000100000005000000EA3D95D39E565240A9BF5E61C1574B40EA3D95D39E56524064B14D2A1A594B40A60C1CD0D258524064B14D2A1A594B40A60C1CD0D2585240A9BF5E61C1574B40EA3D95D39E565240A9BF5E61C1574B40
28677	51911	72.703692000000004	73.500094000000004	54.916195999999999	54.321696000000003	Школьная	0103000020E610000001000000050000003D9D2B4A092D524084A0A3552D294B403D9D2B4A092D5240EE5C18E945754B4041BB438A01605240EE5C18E945754B4041BB438A0160524084A0A3552D294B403D9D2B4A092D524084A0A3552D294B40
29464	53005	73.049732000000006	73.092006999999995	54.802743999999997	54.787199000000001	Школьная	0103000020E61000000100000005000000246420CF2E435240D238D4EFC2644B40246420CF2E435240B587BD50C0664B4032005471E3455240B587BD50C0664B4032005471E3455240D238D4EFC2644B40246420CF2E435240D238D4EFC2644B40
30135	53117	73.089420000000004	73.112803	54.643155	54.631940999999998	Совхозная	0103000020E61000000100000005000000EFE6A90EB945524032005471E3504B40EFE6A90EB945524023A12DE752524B4001F9122A3847524023A12DE752524B4001F9122A3847524032005471E3504B40EFE6A90EB945524032005471E3504B40
29125	46941	72.739113000000003	72.770247999999995	54.567425	54.550071000000003	Советская	0103000020E610000001000000050000001AC39CA04D2F524030BDFDB968464B401AC39CA04D2F524066F7E461A1484B40CD7344BE4B31524066F7E461A1484B40CD7344BE4B31524030BDFDB968464B401AC39CA04D2F524030BDFDB968464B40
30008	46051	72.999525000000006	73.048007999999996	54.72437	54.690424	Советская	0103000020E6100000010000000500000034A2B437F83F5240CF2F4AD05F584B4034A2B437F83F52400D1AFA27B85C4B40917C2590124352400D1AFA27B85C4B40917C259012435240CF2F4AD05F584B4034A2B437F83F5240CF2F4AD05F584B40
29224	46051	72.999525000000006	73.048007999999996	54.72437	54.690424	Бульвар Дружбы	0103000020E6100000010000000500000034A2B437F83F5240CF2F4AD05F584B4034A2B437F83F52400D1AFA27B85C4B40917C2590124352400D1AFA27B85C4B40917C259012435240CF2F4AD05F584B4034A2B437F83F5240CF2F4AD05F584B40
29861	46051	72.999525000000006	73.048007999999996	54.72437	54.690424	40 лет Октября	0103000020E6100000010000000500000034A2B437F83F5240CF2F4AD05F584B4034A2B437F83F52400D1AFA27B85C4B40917C2590124352400D1AFA27B85C4B40917C259012435240CF2F4AD05F584B4034A2B437F83F5240CF2F4AD05F584B40
29593	46051	72.999525000000006	73.048007999999996	54.72437	54.690424	1 Мая	0103000020E6100000010000000500000034A2B437F83F5240CF2F4AD05F584B4034A2B437F83F52400D1AFA27B85C4B40917C2590124352400D1AFA27B85C4B40917C259012435240CF2F4AD05F584B4034A2B437F83F5240CF2F4AD05F584B40
68860	59179	83.043291999999994	83.147532999999996	54.976591999999997	54.957918999999997	Первомайская 	0103000020E610000001000000050000006B0BCF4BC5C25440C79BFC169D7A4B406B0BCF4BC5C2544082C476F7007D4B402B85402E71C9544082C476F7007D4B402B85402E71C95440C79BFC169D7A4B406B0BCF4BC5C25440C79BFC169D7A4B40
68980	59197	83.027096	83.041514000000006	55.033264000000003	55.028382999999998	Центральная	0103000020E610000001000000050000008E76DCF0BBC154409561DC0DA2834B408E76DCF0BBC154402C11A8FE41844B40E014562AA8C254402C11A8FE41844B40E014562AA8C254409561DC0DA2834B408E76DCF0BBC154409561DC0DA2834B40
13905	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Школьный	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
13740	5332	75.890259	76.022059999999996	55.251638999999997	55.176279999999998	Татарская	0103000020E610000001000000050000000F7EE200FAF852402D78D15790964B400F7EE200FAF85240F6B2EDB435A04B402FA3586E69015340F6B2EDB435A04B402FA3586E690153402D78D15790964B400F7EE200FAF852402D78D15790964B40
13477	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Пушкина	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
15938	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Никишиной	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
13875	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Мичурина	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
13483	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Ленина	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
14153	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Комиссаровская	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
13559	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Интернациональная	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
15976	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Зеленая 	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
14159	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Закриевского	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
13872	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	Аэродромная	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
13744	5332	75.906986000000003	76.020829000000006	55.241267000000001	55.19482	А. Матросова	0103000020E6100000010000000500000083FB010F0CFA5240A94D9CDCEF984B4083FB010F0CFA5240514D49D6E19E4B40BD73284355015340514D49D6E19E4B40BD73284355015340A94D9CDCEF984B4083FB010F0CFA5240A94D9CDCEF984B40
13649	15154	82.673168000000004	82.726528000000002	55.006341999999997	54.992595999999999	Шевченко	0103000020E61000000100000005000000AE2D3C2F15AB5440F911BF620D7F4B40AE2D3C2F15AB5440AD4B8DD0CF804B4036E84B6F7FAE5440AD4B8DD0CF804B4036E84B6F7FAE5440F911BF620D7F4B40AE2D3C2F15AB5440F911BF620D7F4B40
16514	15154	82.673168000000004	82.726528000000002	55.006341999999997	54.992595999999999	ЖКО Аэропорта	0103000020E61000000100000005000000AE2D3C2F15AB5440F911BF620D7F4B40AE2D3C2F15AB5440AD4B8DD0CF804B4036E84B6F7FAE5440AD4B8DD0CF804B4036E84B6F7FAE5440F911BF620D7F4B40AE2D3C2F15AB5440F911BF620D7F4B40
13947	15154	82.673168000000004	82.726528000000002	55.006341999999997	54.992595999999999	Геодезическая	0103000020E61000000100000005000000AE2D3C2F15AB5440F911BF620D7F4B40AE2D3C2F15AB5440AD4B8DD0CF804B4036E84B6F7FAE5440AD4B8DD0CF804B4036E84B6F7FAE5440F911BF620D7F4B40AE2D3C2F15AB5440F911BF620D7F4B40
16253	65	82.861491000000001	82.917950000000005	54.990943000000001	54.967025999999997	улица Немировича-Данченко	0103000020E6100000010000000500000018B325AB22B75440DB300A82C77B4B4018B325AB22B754409E996038D77E4B403F575BB1BFBA54409E996038D77E4B403F575BB1BFBA5440DB300A82C77B4B4018B325AB22B75440DB300A82C77B4B40
14339	65	83.032396000000006	83.039276999999998	54.988686000000001	54.984000000000002	улица Ключ-Камышенское Плато	0103000020E610000001000000050000005C21ACC612C25440CBA145B6F37D4B405C21ACC612C25440AC014A438D7E4B400A9FAD8383C25440AC014A438D7E4B400A9FAD8383C25440CBA145B6F37D4B405C21ACC612C25440CBA145B6F37D4B40
2476	65	83.036708000000004	83.054288	55.007778000000002	54.988660000000003	улица Кирова	0103000020E610000001000000050000001AE0826C59C25440836E2F698C7E4B401AE0826C59C254406CD097DEFE804B402D24607479C354406CD097DEFE804B402D24607479C35440836E2F698C7E4B401AE0826C59C25440836E2F698C7E4B40
13602	65	83.075693999999999	83.080402000000007	55.049621999999999	55.047553999999998	улица Гусинобродский Тракт	0103000020E6100000010000000500000038A0A52BD8C45440A165DD3F16864B4038A0A52BD8C45440C09481035A864B401D226E4E25C55440C09481035A864B401D226E4E25C55440A165DD3F16864B4038A0A52BD8C45440A165DD3F16864B40
15698	65	82.914006999999998	82.981937000000002	55.055639999999997	55.040816999999997	улица Гоголя	0103000020E610000001000000050000002A5437177FBA5440770FD07D39854B402A5437177FBA5440BA2C26361F874B40DF6E490ED8BE5440BA2C26361F874B40DF6E490ED8BE5440770FD07D39854B402A5437177FBA5440770FD07D39854B40
2852	65	83.011724999999998	83.024642999999998	55.035978	55.024785999999999	улица Владимира Высоцкого	0103000020E61000000100000005000000EBE2361AC0C0544007B309302C834B40EBE2361AC0C0544010B056ED9A844B40D2C43BC093C1544010B056ED9A844B40D2C43BC093C1544007B309302C834B40EBE2361AC0C0544007B309302C834B40
13577	65	82.845178000000004	82.853784000000005	54.970675	54.964545999999999	улица 9-й Гвардейской Дивизии	0103000020E610000001000000050000001E53776517B654406ABE4A3E767B4B401E53776517B65440BC0512143F7C4B404776A565A4B65440BC0512143F7C4B404776A565A4B654406ABE4A3E767B4B401E53776517B654406ABE4A3E767B4B40
1427	65	82.896427000000003	82.912622999999996	54.992657999999999	54.983075999999997	проспект Карла Маркса	0103000020E6100000010000000500000017105A0F5FB95440C2BD326FD57D4B4017105A0F5FB954406F0ED76A0F7F4B40F4A44C6A68BA54406F0ED76A0F7F4B40F4A44C6A68BA5440C2BD326FD57D4B4017105A0F5FB95440C2BD326FD57D4B40
7755	65	82.904251000000002	82.913197999999994	55.035947	55.026907000000001	проспект Димитрова	0103000020E610000001000000050000000518963FDFB95440498446B071834B400518963FDFB95440D5B14AE999844B40723106D671BA5440D5B14AE999844B40723106D671BA5440498446B071834B400518963FDFB95440498446B071834B40
75544	65	82.904251000000002	82.913197999999994	55.035947	55.026907000000001	проспект Димитрова	0103000020E610000001000000050000000518963FDFB95440498446B071834B400518963FDFB95440D5B14AE999844B40723106D671BA5440D5B14AE999844B40723106D671BA5440498446B071834B400518963FDFB95440498446B071834B40
7429	65	82.950998999999996	83.016720000000007	55.072721000000001	55.043622999999997	проспект Дзержинского	0103000020E61000000100000005000000D6E1E82ADDBC54403C2D3F7095854B40D6E1E82ADDBC5440C05DF6EB4E894B401B4CC3F011C15440C05DF6EB4E894B401B4CC3F011C154403C2D3F7095854B40D6E1E82ADDBC54403C2D3F7095854B40
68012	65	82.933886000000001	82.965057999999999	55.01388	55.002191000000003	Якушева	0103000020E610000001000000050000004E0CC9C9C4BB54403BAC70CB47804B404E0CC9C9C4BB5440C408E1D1C6814B40902FA182C3BD5440C408E1D1C6814B40902FA182C3BD54403BAC70CB47804B404E0CC9C9C4BB54403BAC70CB47804B40
68315	65	82.919692999999995	82.936014999999998	55.034095000000001	55.032680999999997	Ядринцевская 	0103000020E610000001000000050000000C570740DCBA5440AC1919E42E844B400C570740DCBA544083FA96395D844B40306475ABE7BB544083FA96395D844B40306475ABE7BB5440AC1919E42E844B400C570740DCBA5440AC1919E42E844B40
68132	65	82.941817999999998	82.986501000000004	54.867342000000001	54.859589999999997	Энгельса	0103000020E610000001000000050000002F3201BF46BC5440FCFB8C0B076E4B402F3201BF46BC54403F390A10056F4B402A1E17D522BF54403F390A10056F4B402A1E17D522BF5440FCFB8C0B076E4B402F3201BF46BC5440FCFB8C0B076E4B40
68210	65	83.091693000000006	83.096948999999995	54.891348999999998	54.885109	Экваторная 	0103000020E610000001000000050000006B11514CDEC55440983270404B714B406B11514CDEC5544041295AB917724B405018946934C6544041295AB917724B405018946934C65440983270404B714B406B11514CDEC55440983270404B714B40
68206	65	83.098699999999994	83.099590000000006	54.977201000000001	54.968809	Эйхе	0103000020E610000001000000050000005F07CE1951C654400589EDEE017C4B405F07CE1951C654402B4F20EC147D4B408E40BCAE5FC654402B4F20EC147D4B408E40BCAE5FC654400589EDEE017C4B405F07CE1951C654400589EDEE017C4B40
68126	65	83.079008999999999	83.084200999999993	54.981411999999999	54.972586999999997	Шмидта	0103000020E61000000100000005000000BDC5C37B0EC55440E3C116BB7D7C4B40BDC5C37B0EC5544073F38DE89E7D4B409752978C63C5544073F38DE89E7D4B409752978C63C55440E3C116BB7D7C4B40BDC5C37B0EC55440E3C116BB7D7C4B40
68398	65	82.876717999999997	82.877796000000004	55.004472999999997	54.997802	Школьная	0103000020E610000001000000050000002174D0251CB8544013F1D6F9B77F4B402174D0251CB85440855B3E9292804B40D12346CF2DB85440855B3E9292804B40D12346CF2DB8544013F1D6F9B77F4B402174D0251CB8544013F1D6F9B77F4B40
1569	65	82.906227000000001	82.909137999999999	55.009791	55.008871999999997	Чулымская улица	0103000020E6100000010000000500000024F0879FFFB95440D0ECBAB722814B4024F0879FFFB95440C765DCD440814B40416326512FBA5440C765DCD440814B40416326512FBA5440D0ECBAB722814B4024F0879FFFB95440D0ECBAB722814B40
67970	65	82.952984999999998	82.961132000000006	54.965305000000001	54.958373999999999	Чигорина	0103000020E610000001000000050000000725CCB4FDBC544019ABCDFFAB7A4B400725CCB4FDBC544028D53E1D8F7B4B40E7C8CA2F83BD544028D53E1D8F7B4B40E7C8CA2F83BD544019ABCDFFAB7A4B400725CCB4FDBC544019ABCDFFAB7A4B40
68195	65	82.943309999999997	82.990686999999994	55.021498000000001	55.001767999999998	Чехова	0103000020E6100000010000000500000058FFE7305FBC5440F4160FEF39804B4058FFE7305FBC5440F7764B72C0824B40A164726A67BF5440F7764B72C0824B40A164726A67BF5440F4160FEF39804B4058FFE7305FBC5440F4160FEF39804B40
68087	65	82.957018000000005	82.971175000000002	54.954776000000003	54.952790999999998	Чемская	0103000020E61000000100000005000000BCEB6CC83FBD54402976340EF5794B40BCEB6CC83FBD5440BB809719367A4B4057EC2FBB27BE5440BB809719367A4B4057EC2FBB27BE54402976340EF5794B40BCEB6CC83FBD54402976340EF5794B40
68041	65	82.910089999999997	82.934066000000001	55.026947999999997	55.024776000000003	Чаплыгина	0103000020E61000000100000005000000AA9A20EA3EBA5440E4DC26DC2B834B40AA9A20EA3EBA5440A758350873834B408E93C2BCC7BB5440A758350873834B408E93C2BCC7BB5440E4DC26DC2B834B40AA9A20EA3EBA5440E4DC26DC2B834B40
3131	65	83.070860999999994	83.073215000000005	54.937707000000003	54.911171000000003	Центральная улица	0103000020E61000000100000005000000F56393FC88C4544025085740A1744B40F56393FC88C454407A1D71C806784B40E8A4F78DAFC454407A1D71C806784B40E8A4F78DAFC4544025085740A1744B40F56393FC88C4544025085740A1744B40
14083	65	83.070860999999994	83.073215000000005	54.937707000000003	54.911171000000003	Центральная	0103000020E61000000100000005000000F56393FC88C4544025085740A1744B40F56393FC88C454407A1D71C806784B40E8A4F78DAFC454407A1D71C806784B40E8A4F78DAFC4544025085740A1744B40F56393FC88C4544025085740A1744B40
68181	65	82.829808	82.841224999999994	54.9587	54.943592000000002	Хилокская 	0103000020E61000000100000005000000637D03931BB554403562669FC7784B40637D03931BB554406D567DAEB67A4B40F7E461A1D6B554406D567DAEB67A4B40F7E461A1D6B554403562669FC7784B40637D03931BB554403562669FC7784B40
68180	65	82.822873000000001	82.824012999999994	54.993049999999997	54.985306999999999	Халтурина	0103000020E61000000100000005000000BBF083F3A9B454408BC22E8A1E7E4B40BBF083F3A9B454407AA52C431C7F4B40A59E05A1BCB454407AA52C431C7F4B40A59E05A1BCB454408BC22E8A1E7E4B40BBF083F3A9B454408BC22E8A1E7E4B40
16662	65	82.913953000000006	82.962622999999994	55.041311999999998	55.036054999999998	Фрунзе	0103000020E610000001000000050000003145B9347EBA5440BBED42739D844B403145B9347EBA544057772CB649854B4027D87F9D9BBD544057772CB649854B4027D87F9D9BBD5440BBED42739D844B403145B9347EBA5440BBED42739D844B40
16659	65	82.985809000000003	82.999454	55.173771000000002	55.166331	Флотская	0103000020E610000001000000050000008FC6A17E17BF5440CEA78E554A954B408FC6A17E17BF544022FFCC203E964B40CFF6E80DF7BF544022FFCC203E964B40CFF6E80DF7BF5440CEA78E554A954B408FC6A17E17BF5440CEA78E554A954B40
67990	65	82.826717000000002	82.827687999999995	54.993293000000001	54.985478000000001	Филатова	0103000020E6100000010000000500000006836BEEE8B45440B876A224247E4B4006836BEEE8B45440412C9B39247F4B40AAD216D7F8B45440412C9B39247F4B40AAD216D7F8B45440B876A224247E4B4006836BEEE8B45440B876A224247E4B40
68022	65	83.085648000000006	83.091918000000007	54.981985999999999	54.971373	Физкультурная 	0103000020E61000000100000005000000F1BDBF417BC55440D49B51F3557C4B40F1BDBF417BC554409F909DB7B17D4B407BFA08FCE1C554409F909DB7B17D4B407BFA08FCE1C55440D49B51F3557C4B40F1BDBF417BC55440D49B51F3557C4B40
68295	65	82.96557	82.980643999999998	55.039893999999997	55.031654000000003	Федосеева	0103000020E61000000100000005000000EBFF1CE6CBBD5440D064FF3C0D844B40EBFF1CE6CBBD54403FA7203F1B854B4031410DDFC2BE54403FA7203F1B854B4031410DDFC2BE5440D064FF3C0D844B40EBFF1CE6CBBD5440D064FF3C0D844B40
68228	65	82.903137000000001	82.924616	55.024079	55.013244999999998	Фабричная 	0103000020E61000000100000005000000AFB321FFCCB95440F2EA1C03B2814B40AFB321FFCCB954409CC24A0515834B40EF5696E82CBB54409CC24A0515834B40EF5696E82CBB5440F2EA1C03B2814B40AFB321FFCCB95440F2EA1C03B2814B40
67962	65	82.952445999999995	82.978497000000004	55.091267999999999	55.072040999999999	Учительская	0103000020E610000001000000050000002F4D11E0F4BC54404E7CB5A338894B402F4D11E0F4BC5440EE9579ABAE8B4B40FC8EE1B19FBE5440EE9579ABAE8B4B40FC8EE1B19FBE54404E7CB5A338894B402F4D11E0F4BC54404E7CB5A338894B40
68209	65	83.098699999999994	83.108689999999996	54.835299999999997	54.833506	Ученых	0103000020E610000001000000050000005F07CE1951C6544088821953B06A4B405F07CE1951C65440A52C431CEB6A4B40BED9E6C6F4C65440A52C431CEB6A4B40BED9E6C6F4C6544088821953B06A4B405F07CE1951C6544088821953B06A4B40
68130	65	83.117457000000002	83.128981999999993	54.941761	54.939340999999999	Ученическая 	0103000020E61000000100000005000000EC6B5D6A84C754405E656D533C784B40EC6B5D6A84C75440FAD2DB9F8B784B4073F1B73D41C85440FAD2DB9F8B784B4073F1B73D41C854405E656D533C784B40EC6B5D6A84C754405E656D533C784B40
68122	65	82.950838000000005	82.958869000000007	54.968732000000003	54.964002999999998	Урманова	0103000020E61000000100000005000000D272A087DABC5440791F4773647B4B40D272A087DABC54405A4B0169FF7B4B407D09151C5EBD54405A4B0169FF7B4B407D09151C5EBD5440791F4773647B4B40D272A087DABC5440791F4773647B4B40
67778	65	83.078883000000005	83.080787999999998	54.923999000000002	54.921256	Узорная	0103000020E61000000100000005000000774D486B0CC55440349F73B7EB754B40774D486B0CC55440B344679945764B40317A6EA12BC55440B344679945764B40317A6EA12BC55440349F73B7EB754B40774D486B0CC55440349F73B7EB754B40
68290	65	82.848231999999996	82.868785000000003	54.965966999999999	54.960121000000001	Ударная 	0103000020E61000000100000005000000ECDADE6E49B65440F699B33EE57A4B40ECDADE6E49B65440F30181CEA47B4B405890662C9AB75440F30181CEA47B4B405890662C9AB75440F699B33EE57A4B40ECDADE6E49B65440F699B33EE57A4B40
68102	65	82.944136	82.987965000000003	55.022328999999999	55.005986	Тургенева	0103000020E610000001000000050000007BBE66B96CBC5440EF1D3526C4804B407BBE66B96CBC54404E603AADDB824B40EE258DD13ABF54404E603AADDB824B40EE258DD13ABF5440EF1D3526C4804B407BBE66B96CBC5440EF1D3526C4804B40
68317	65	82.835350000000005	82.930499999999995	54.983665000000002	54.947671999999997	Тульская 	0103000020E61000000100000005000000ACADD85F76B55440DEAAEB504D794B40ACADD85F76B55440249C16BCE87D4B40643BDF4F8DBB5440249C16BCE87D4B40643BDF4F8DBB5440DEAAEB504D794B40ACADD85F76B55440DEAAEB504D794B40
68217	65	83.041602999999995	83.047235999999998	54.850655000000003	54.845875999999997	Тружеников	0103000020E61000000100000005000000971AA19FA9C25440533C2EAA456C4B40971AA19FA9C25440E6965643E26C4B4068CC24EA05C35440E6965643E26C4B4068CC24EA05C35440533C2EAA456C4B40971AA19FA9C25440533C2EAA456C4B40
68198	65	82.941657000000006	82.948860999999994	55.033295000000003	55.027841000000002	Тополевая	0103000020E610000001000000050000002BC3B81B44BC5440753E3C4B90834B402BC3B81B44BC5440670FB40243844B40CADC7C23BABC5440670FB40243844B40CADC7C23BABC5440753E3C4B90834B402BC3B81B44BC5440753E3C4B90834B40
68002	65	82.817896000000005	82.871148000000005	54.981856000000001	54.979325000000003	Титова	0103000020E61000000100000005000000DFE1766858B45440DE9387855A7D4B40DFE1766858B45440D1B01875AD7D4B40747E8AE3C0B75440D1B01875AD7D4B40747E8AE3C0B75440DE9387855A7D4B40DFE1766858B45440DE9387855A7D4B40
16645	65	82.871461999999994	82.905814000000007	55.057765000000003	55.047573999999997	Тимирязева	0103000020E610000001000000050000003B6D8D08C6B75440E811A3E716864B403B6D8D08C6B754403EEDF0D764874B40939048DBF8B954403EEDF0D764874B40939048DBF8B95440E811A3E716864B403B6D8D08C6B75440E811A3E716864B40
68050	65	82.958725000000001	82.975989999999996	55.080947000000002	55.068896000000002	Театральная	0103000020E61000000100000005000000E3361AC05BBD5440A1698995D1884B40E3361AC05BBD5440CBDAA6785C8A4B4046CEC29E76BE5440CBDAA6785C8A4B4046CEC29E76BE5440A1698995D1884B40E3361AC05BBD5440A1698995D1884B40
68065	65	82.925612999999998	82.935952	55.062570000000001	55.059533999999999	Танковая 	0103000020E6100000010000000500000028F04E3E3DBB5440028063CF9E874B4028F04E3E3DBB5440F9DA334B02884B400DA837A3E6BB5440F9DA334B02884B400DA837A3E6BB5440028063CF9E874B4028F04E3E3DBB5440028063CF9E874B40
67815	65	82.957673999999997	82.967455999999999	55.102919999999997	55.097208000000002	Столетова	0103000020E61000000100000005000000B08EE3874ABD54406D74CE4F718C4B40B08EE3874ABD54405A0D897B2C8D4B406A1492CCEABD54405A0D897B2C8D4B406A1492CCEABD54406D74CE4F718C4B40B08EE3874ABD54406D74CE4F718C4B40
68286	65	82.819872000000004	82.885153000000003	54.978813000000002	54.975641000000003	Степная 	0103000020E61000000100000005000000FEB968C878B4544081D1E5CDE17C4B40FEB968C878B4544028F38FBE497D4B4034BDC458A6B8544028F38FBE497D4B4034BDC458A6B8544081D1E5CDE17C4B40FEB968C878B4544081D1E5CDE17C4B40
68411	65	82.773877999999996	82.869530999999995	54.997610000000002	54.995823999999999	Станционная 	0103000020E610000001000000050000000246973787B1544034492C29777F4B400246973787B15440CF143AAFB17F4B40ECF65965A6B75440CF143AAFB17F4B40ECF65965A6B7544034492C29777F4B400246973787B1544034492C29777F4B40
67982	65	82.773877999999996	82.869530999999995	54.997610000000002	54.995823999999999	Станционная	0103000020E610000001000000050000000246973787B1544034492C29777F4B400246973787B15440CF143AAFB17F4B40ECF65965A6B75440CF143AAFB17F4B40ECF65965A6B7544034492C29777F4B400246973787B1544034492C29777F4B40
16646	65	82.869647999999998	82.874219999999994	54.996324999999999	54.965935999999999	Станиславского	0103000020E6100000010000000500000009C21550A8B75440B80375CAA37B4B4009C21550A8B75440F697DD93877F4B4095607138F3B75440F697DD93877F4B4095607138F3B75440B80375CAA37B4B4009C21550A8B75440B80375CAA37B4B40
68069	65	82.884668000000005	82.901313000000002	55.056569000000003	55.050437000000002	Союза Молодежи	0103000020E6100000010000000500000056F487669EB8544012C138B874864B4056F487669EB85440D57B2AA73D874B406B9DB81CAFB95440D57B2AA73D874B406B9DB81CAFB9544012C138B874864B4056F487669EB8544012C138B874864B40
68099	65	82.946839999999995	82.988315	55.172938000000002	55.156883000000001	Солидарности	0103000020E61000000100000005000000DBA2CC0699BC54403126FDBD14944B40DBA2CC0699BC54402A1E17D522964B405CC98E8D40BF54402A1E17D522964B405CC98E8D40BF54403126FDBD14944B40DBA2CC0699BC54403126FDBD14944B40
16657	65	82.911463999999995	82.923349000000002	55.048152000000002	55.018509999999999	Советская	0103000020E61000000100000005000000CEDE196D55BA5440115322895E824B40CEDE196D55BA5440569E40D829864B40D672672618BB5440569E40D829864B40D672672618BB5440115322895E824B40CEDE196D55BA5440115322895E824B40
68263	65	82.898053000000004	82.901833999999994	54.963495999999999	54.942734000000002	Сибиряков-Гвардейцев	0103000020E61000000100000005000000C8444AB379B95440E469F981AB784B40C8444AB379B95440D5E940D6537B4B40EF1AF4A5B7B95440D5E940D6537B4B40EF1AF4A5B7B95440E469F981AB784B40C8444AB379B95440E469F981AB784B40
67827	65	82.902552999999997	82.914203999999998	55.037902000000003	55.034244000000001	Сибирская	0103000020E61000000100000005000000077AA86DC3B95440C80A7E1B62844B40077AA86DC3B95440FC3905F9D9844B40D5777E5182BA5440FC3905F9D9844B40D5777E5182BA5440C80A7E1B62844B40077AA86DC3B95440C80A7E1B62844B40
67812	65	82.902552999999997	82.914203999999998	55.037902000000003	55.034244000000001	Сибирская	0103000020E61000000100000005000000077AA86DC3B95440C80A7E1B62844B40077AA86DC3B95440FC3905F9D9844B40D5777E5182BA5440FC3905F9D9844B40D5777E5182BA5440C80A7E1B62844B40077AA86DC3B95440C80A7E1B62844B40
68038	65	82.924785999999997	82.928010999999998	55.029327000000002	55.015934000000001	Серебренниковская 	0103000020E610000001000000050000001D739EB12FBB54407E7214200A824B401D739EB12FBB5440E5F1B4FCC0834B4002D53F8864BB5440E5F1B4FCC0834B4002D53F8864BB54407E7214200A824B401D739EB12FBB54407E7214200A824B40
68039	65	82.924785999999997	82.928010999999998	55.029327000000002	55.015934000000001	Серебренниковская	0103000020E610000001000000050000001D739EB12FBB54407E7214200A824B401D739EB12FBB5440E5F1B4FCC0834B4002D53F8864BB5440E5F1B4FCC0834B4002D53F8864BB54407E7214200A824B401D739EB12FBB54407E7214200A824B40
68057	65	82.942994999999996	82.947181	55.053516000000002	55.037975000000003	Селезнева	0103000020E61000000100000005000000A852B3075ABC54406688635DDC844B40A852B3075ABC544008E8BE9CD9864B4020990E9D9EBC544008E8BE9CD9864B4020990E9D9EBC54406688635DDC844B40A852B3075ABC54406688635DDC844B40
68075	65	82.890803000000005	82.930554000000001	55.078297999999997	55.065441999999997	Северная	0103000020E61000000100000005000000700B96EA02B9544075E4486760884B40700B96EA02B95440CDAB3AAB058A4B405E4A5D328EBB5440CDAB3AAB058A4B405E4A5D328EBB544075E4486760884B40700B96EA02B9544075E4486760884B40
68093	65	82.832350000000005	82.843874999999997	54.993577000000002	54.959966000000001	Связистов	0103000020E61000000100000005000000D734EF3845B55440CFA2772AE07A4B40D734EF3845B554406687F8872D7F4B405EBA490C02B654406687F8872D7F4B405EBA490C02B65440CFA2772AE07A4B40D734EF3845B55440CFA2772AE07A4B40
68233	65	82.879170000000002	82.887938000000005	55.038795	55.035384999999998	Саратовская	0103000020E61000000100000005000000F5673F5244B854406DE2E47E87844B40F5673F5244B85440C91F0C3CF7844B400BB8E7F9D3B85440C91F0C3CF7844B400BB8E7F9D3B854406DE2E47E87844B40F5673F5244B854406DE2E47E87844B40
68107	65	82.933042	82.973996	55.020564	55.003027000000003	Садовая	0103000020E61000000100000005000000D8F2CAF5B6BB5440A400513063804B40D8F2CAF5B6BB5440CBBC55D7A1824B40D49B51F355BE5440CBBC55D7A1824B40D49B51F355BE5440A400513063804B40D8F2CAF5B6BB5440A400513063804B40
67972	65	82.955167000000003	82.975729999999999	54.970778000000003	54.954729	Саввы Кожевникова	0103000020E61000000100000005000000FBCDC47421BD54407AC5538F347A4B40FBCDC47421BD544091D61874427C4B4078EE3D5C72BE544091D61874427C4B4078EE3D5C72BE54407AC5538F347A4B40FBCDC47421BD54407AC5538F347A4B40
68309	65	83.039931999999993	83.064464999999998	54.84937	54.844425000000001	Русская 	0103000020E610000001000000050000001684F23E8EC2544060764F1E166C4B401684F23E8EC254400D1AFA27B86C4B4025AFCE3120C454400D1AFA27B86C4B4025AFCE3120C4544060764F1E166C4B401684F23E8EC2544060764F1E166C4B40
68208	65	83.039931999999993	83.064464999999998	54.84937	54.844425000000001	Русская	0103000020E610000001000000050000001684F23E8EC2544060764F1E166C4B401684F23E8EC254400D1AFA27B86C4B4025AFCE3120C454400D1AFA27B86C4B4025AFCE3120C4544060764F1E166C4B401684F23E8EC2544060764F1E166C4B40
68134	65	83.080357000000006	83.097945999999993	54.869585000000001	54.859119	Российская 	0103000020E610000001000000050000004DC0AF9124C55440A52F849CF76D4B404DC0AF9124C55440CC0BB08F4E6F4B4089B14CBF44C65440CC0BB08F4E6F4B4089B14CBF44C65440A52F849CF76D4B404DC0AF9124C55440A52F849CF76D4B40
68040	65	82.915218999999993	82.946409000000003	55.036968999999999	55.034198000000004	Романова	0103000020E61000000100000005000000616BB6F292BA544058CB9D9960844B40616BB6F292BA5440A0FB7266BB844B40F7E80DF791BC5440A0FB7266BB844B40F7E80DF791BC544058CB9D9960844B40616BB6F292BA544058CB9D9960844B40
67838	65	82.948682000000005	82.952175999999994	55.113323000000001	55.108770999999997	Родники	0103000020E610000001000000050000007313B534B7BC544069E04735EC8D4B407313B534B7BC54403B71395E818E4B404F029B73F0BC54403B71395E818E4B404F029B73F0BC544069E04735EC8D4B407313B534B7BC544069E04735EC8D4B40
68285	65	82.883714999999995	82.886913000000007	54.988287999999997	54.9679	Римского-Корсакова	0103000020E6100000010000000500000004FF5BC98EB8544032E6AE25E47B4B4004FF5BC98EB85440BE839F38807E4B406D59BE2EC3B85440BE839F38807E4B406D59BE2EC3B8544032E6AE25E47B4B4004FF5BC98EB8544032E6AE25E47B4B40
68225	65	82.961787999999999	82.982916000000003	55.075293000000002	55.063513999999998	Республиканская 	0103000020E61000000100000005000000DB6B41EF8DBD5440486B0C3A21884B40DB6B41EF8DBD5440124F7633A3894B40C5AD8218E8BE5440124F7633A3894B40C5AD8218E8BE5440486B0C3A21884B40DB6B41EF8DBD5440486B0C3A21884B40
68296	65	82.992977999999994	82.994657000000004	55.027071999999997	55.021265999999997	Радиотехническая	0103000020E6100000010000000500000070E998F38CBF5440244223D8B8824B4070E998F38CBF54409351651877834B40336FD575A8BF54409351651877834B40336FD575A8BF5440244223D8B8824B4070E998F38CBF5440244223D8B8824B40
68152	65	82.959569000000002	82.975864999999999	55.059233999999996	55.052509999999998	Промышленная	0103000020E610000001000000050000005950189469BD5440425BCEA5B8864B405950189469BD5440D767CEFA94874B40E813799274BE5440D767CEFA94874B40E813799274BE5440425BCEA5B8864B405950189469BD5440425BCEA5B8864B40
68848	65	83.111618000000007	83.119838000000001	54.952382	54.951161999999997	Приозерная 	0103000020E6100000010000000500000047E9D2BF24C75440569929ADBF794B4047E9D2BF24C7544048A643A7E7794B405BB4006DABC7544048A643A7E7794B405BB4006DABC75440569929ADBF794B4047E9D2BF24C75440569929ADBF794B40
68028	65	82.981335000000001	82.990470999999999	54.868569999999998	54.855144000000003	Приморская	0103000020E61000000100000005000000E4DA5031CEBE544071AFCC5B756D4B40E4DA5031CEBE5440B324404D2D6F4B40BB287AE063BF5440B324404D2D6F4B40BB287AE063BF544071AFCC5B756D4B40E4DA5031CEBE544071AFCC5B756D4B40
3179	65	83.067420999999996	83.074374000000006	54.937893000000003	54.936982999999998	Прибрежный переулок	0103000020E6100000010000000500000012842BA050C4544038F4160FEF774B4012842BA050C45440DC12B9E00C784B400E6B2A8BC2C45440DC12B9E00C784B400E6B2A8BC2C4544038F4160FEF774B4012842BA050C4544038F4160FEF774B40
67776	65	82.801978000000005	82.803235000000001	54.992074000000002	54.984037000000001	Порт-Артурская 	0103000020E610000001000000050000002387889B53B35440E886A6ECF47D4B402387889B53B35440209BE447FC7E4B402A00C63368B35440209BE447FC7E4B402A00C63368B35440E886A6ECF47D4B402387889B53B35440E886A6ECF47D4B40
68221	65	83.030023999999997	83.058025000000001	55.076334000000003	55.068406000000003	Полякова	0103000020E610000001000000050000001686C8E9EBC15440D36C1E87C1884B401686C8E9EBC1544054C90050C5894B406D567DAEB6C3544054C90050C5894B406D567DAEB6C35440D36C1E87C1884B401686C8E9EBC15440D36C1E87C1884B40
68311	65	83.096185000000006	83.109857000000005	54.867420000000003	54.865409	Полевая 	0103000020E61000000100000005000000695721E527C654400055DCB8C56E4B40695721E527C65440BBF2599E076F4B40268FA7E507C75440BBF2599E076F4B40268FA7E507C754400055DCB8C56E4B40695721E527C654400055DCB8C56E4B40
68095	65	82.830759999999998	82.883994000000001	54.986418	54.983840000000001	Плахотного	0103000020E61000000100000005000000CCB4FD2B2BB55440923F1878EE7D4B40CCB4FD2B2BB55440C617EDF1427E4B400EF7915B93B85440C617EDF1427E4B400EF7915B93B85440923F1878EE7D4B40CCB4FD2B2BB55440923F1878EE7D4B40
67980	65	82.875370000000004	82.894855000000007	54.997346999999998	54.992327000000003	Планировочная	0103000020E610000001000000050000009279E40F06B854400AF83592047F4B409279E40F06B85440C1E10511A97F4B4060EAE74D45B95440C1E10511A97F4B4060EAE74D45B954400AF83592047F4B409279E40F06B854400AF83592047F4B40
16647	65	83.103767000000005	83.120484000000005	54.959868	54.952086999999999	Пихтовая	0103000020E61000000100000005000000DCD9571EA4C654402FF99FFCDD794B40DCD9571EA4C654400C3D62F4DC7A4B403EEC8502B6C754400C3D62F4DC7A4B403EEC8502B6C754402FF99FFCDD794B40DCD9571EA4C654402FF99FFCDD794B40
75541	65	83.091432999999995	83.097190999999995	54.857201000000003	54.842376999999999	Пирогова	0103000020E610000001000000050000009C31CC09DAC5544088F37002D36B4B409C31CC09DAC554409C8C2AC3B86D4B40CB9D996038C654409C8C2AC3B86D4B40CB9D996038C6544088F37002D36B4B409C31CC09DAC5544088F37002D36B4B40
68089	65	82.835466999999994	82.896947999999995	54.948855999999999	54.942112999999999	Петухова	0103000020E61000000100000005000000C878944A78B554407711A62897784B40C878944A78B55440834E081D74794B409B8D959867B95440834E081D74794B409B8D959867B954407711A62897784B40C878944A78B554407711A62897784B40
2964	65	83.043291999999994	83.147532999999996	54.976591999999997	54.957918999999997	Первомайская улица	0103000020E610000001000000050000006B0BCF4BC5C25440C79BFC169D7A4B406B0BCF4BC5C2544082C476F7007D4B402B85402E71C9544082C476F7007D4B402B85402E71C95440C79BFC169D7A4B406B0BCF4BC5C25440C79BFC169D7A4B40
68042	65	83.043291999999994	83.147532999999996	54.976591999999997	54.957918999999997	Первомайская 	0103000020E610000001000000050000006B0BCF4BC5C25440C79BFC169D7A4B406B0BCF4BC5C2544082C476F7007D4B402B85402E71C9544082C476F7007D4B402B85402E71C95440C79BFC169D7A4B406B0BCF4BC5C25440C79BFC169D7A4B40
16641	65	83.043291999999994	83.147532999999996	54.976591999999997	54.957918999999997	Первомайская	0103000020E610000001000000050000006B0BCF4BC5C25440C79BFC169D7A4B406B0BCF4BC5C2544082C476F7007D4B402B85402E71C9544082C476F7007D4B402B85402E71C95440C79BFC169D7A4B406B0BCF4BC5C25440C79BFC169D7A4B40
68188	65	82.817447000000001	82.885458	54.989238	54.985053999999998	Пархоменко	0103000020E61000000100000005000000A7CD380D51B45440A165DD3F167E4B40A7CD380D51B45440F0FACC599F7E4B40D2FE0758ABB85440F0FACC599F7E4B40D2FE0758ABB85440A165DD3F167E4B40A7CD380D51B45440A165DD3F167E4B40
68205	65	82.968202000000005	82.993731999999994	55.030296999999997	55.017777000000002	Панфиловцев	0103000020E61000000100000005000000FF7A8505F7BD54407DCF488446824B40FF7A8505F7BD54405D15A8C5E0834B40463F1A4E99BF54405D15A8C5E0834B40463F1A4E99BF54407DCF488446824B40FF7A8505F7BD54407DCF488446824B40
67976	65	82.878423999999995	82.879385999999997	54.947088000000001	54.943240000000003	Палласа	0103000020E6100000010000000500000060014C1938B85440B8239C16BC784B4060014C1938B854408F37F92D3A794B40DBA337DC47B854408F37F92D3A794B40DBA337DC47B85440B8239C16BC784B4060014C1938B85440B8239C16BC784B40
67901	65	82.898743999999994	82.914546000000001	55.121442999999999	55.118282000000001	Охотская	0103000020E610000001000000050000007ADE8D0585B954404DDA54DD238F4B407ADE8D0585B9544000AAB8718B8F4B40022CF2EB87BA544000AAB8718B8F4B40022CF2EB87BA54404DDA54DD238F4B407ADE8D0585B954404DDA54DD238F4B40
68062	65	82.909397999999996	82.935987999999995	55.025823000000003	55.023505999999998	Октябрьская	0103000020E610000001000000050000000F43AB9333BA544040A19E3E02834B400F43AB9333BA5440083E062B4E834B40B35C363AE7BB5440083E062B4E834B40B35C363AE7BB544040A19E3E02834B400F43AB9333BA544040A19E3E02834B40
68027	65	83.077725000000001	83.129548	54.943534999999997	54.924852000000001	Одоевского	0103000020E6100000010000000500000039454772F9C45440F2D1E28C61764B4039454772F9C45440D0D03FC1C5784B40C8D0B1834AC85440D0D03FC1C5784B40C8D0B1834AC85440F2D1E28C61764B4039454772F9C45440F2D1E28C61764B40
67966	65	82.941091	82.980275000000006	55.099232000000001	55.089387000000002	Объединения	0103000020E61000000100000005000000D6E3BED53ABC544002D88008718B4B40D6E3BED53ABC5440BC5B59A2B38C4B4088855AD3BCBE5440BC5B59A2B38C4B4088855AD3BCBE544002D88008718B4B40D6E3BED53ABC544002D88008718B4B40
67840	65	82.958509000000006	82.971588999999994	55.176918000000001	55.170357000000003	Новоуральская	0103000020E61000000100000005000000FDFA213658BD544085D21742CE954B40FDFA213658BD54407009C03FA5964B40D009A1832EBE54407009C03FA5964B40D009A1832EBE544085D21742CE954B40FDFA213658BD544085D21742CE954B40
68322	65	82.970151000000001	82.981228000000002	54.852800999999999	54.847772999999997	Новоморская	0103000020E61000000100000005000000A14B38F416BE544045B75ED3836C4B40A14B38F416BE5440807F4A95286D4B40D97A8670CCBE5440807F4A95286D4B40D97A8670CCBE544045B75ED3836C4B40A14B38F416BE544045B75ED3836C4B40
68115	65	82.896759000000003	82.909874000000002	54.986427999999997	54.978633000000002	Новогодняя	0103000020E610000001000000050000003259DC7F64B95440A8E49CD8437D4B403259DC7F64B95440E9EDCF45437E4B40C45E28603BBA5440E9EDCF45437E4B40C45E28603BBA5440A8E49CD8437D4B403259DC7F64B95440A8E49CD8437D4B40
68255	65	82.944900000000004	82.983086999999998	55.087538000000002	55.074128000000002	Новая Заря	0103000020E61000000100000005000000637FD93D79BC5440E4DBBB067D894B40637FD93D79BC54402194F771348B4B40DB87BCE5EABE54402194F771348B4B40DB87BCE5EABE5440E4DBBB067D894B40637FD93D79BC5440E4DBBB067D894B40
68293	65	82.958123000000001	82.994774000000007	55.033073000000002	55.010834000000003	Никитина	0103000020E61000000100000005000000E8A221E351BD5440AAD72D0263814B40E8A221E351BD5440B8B06EBC3B844B40503A9160AABF5440B8B06EBC3B844B40503A9160AABF5440AAD72D0263814B40E8A221E351BD5440AAD72D0263814B40
68288	65	82.861491000000001	82.917950000000005	54.990943000000001	54.967025999999997	Немировича-Данченко	0103000020E6100000010000000500000018B325AB22B75440DB300A82C77B4B4018B325AB22B754409E996038D77E4B403F575BB1BFBA54409E996038D77E4B403F575BB1BFBA5440DB300A82C77B4B4018B325AB22B75440DB300A82C77B4B40
16635	65	82.861491000000001	82.917950000000005	54.990943000000001	54.967025999999997	Немировича-Данченко	0103000020E6100000010000000500000018B325AB22B75440DB300A82C77B4B4018B325AB22B754409E996038D77E4B403F575BB1BFBA54409E996038D77E4B403F575BB1BFBA5440DB300A82C77B4B4018B325AB22B75440DB300A82C77B4B40
16636	65	82.870159999999998	82.913773000000006	54.992863999999997	54.971052	Немировича-Данченко	0103000020E61000000100000005000000649291B3B0B75440925B936E4B7C4B40649291B3B0B7544018B0E42A167F4B40F1BDBF417BBA544018B0E42A167F4B40F1BDBF417BBA5440925B936E4B7C4B40649291B3B0B75440925B936E4B7C4B40
68141	65	82.920411999999999	82.944665999999998	55.047234000000003	55.045077999999997	Некрасова	0103000020E6100000010000000500000024B6BB07E8BA544071E2AB1DC5854B4024B6BB07E8BA544030A182C30B864B4029E9616875BC544030A182C30B864B4029E9616875BC544071E2AB1DC5854B4024B6BB07E8BA544071E2AB1DC5854B40
68273	65	82.802049999999994	82.832350000000005	54.993592	54.992074000000002	Невельского	0103000020E610000001000000050000006FF085C954B35440209BE447FC7E4B406FF085C954B354409BC8CC052E7F4B40D734EF3845B554409BC8CC052E7F4B40D734EF3845B55440209BE447FC7E4B406FF085C954B35440209BE447FC7E4B40
68250	65	82.935610999999994	82.970645000000005	55.081715000000003	55.062683999999997	Народная 	0103000020E61000000100000005000000C8B1F50CE1BB5440C1FD800706884B40C8B1F50CE1BB5440DC4B1AA3758A4B40A9C1340C1FBE5440DC4B1AA3758A4B40A9C1340C1FBE5440C1FD800706884B40C8B1F50CE1BB5440C1FD800706884B40
68164	65	82.935610999999994	82.970645000000005	55.081715000000003	55.062683999999997	Народная	0103000020E61000000100000005000000C8B1F50CE1BB5440C1FD800706884B40C8B1F50CE1BB5440DC4B1AA3758A4B40A9C1340C1FBE5440DC4B1AA3758A4B40A9C1340C1FBE5440C1FD800706884B40C8B1F50CE1BB5440C1FD800706884B40
68007	65	82.878891999999993	82.886095999999995	55.019061999999998	55.012996999999999	Моторная	0103000020E61000000100000005000000D32D3BC43FB854401AF9BCE2A9814B40D32D3BC43FB85440554CA59F70824B407347FFCBB5B85440554CA59F70824B407347FFCBB5B854401AF9BCE2A9814B40D32D3BC43FB854401AF9BCE2A9814B40
3447	65	83.088136000000006	83.111322000000001	54.840904999999999	54.830632999999999	Морской проспект	0103000020E610000001000000050000006B662D05A4C554403BFDA02E526A4B406B662D05A4C554407D0569C6A26B4B40D2544FE61FC754407D0569C6A26B4B40D2544FE61FC754403BFDA02E526A4B406B662D05A4C554403BFDA02E526A4B40
68304	65	82.943624	82.986680000000007	54.865430000000003	54.856445000000001	Молодости	0103000020E6100000010000000500000020EEEA5564BC54404FE960FD9F6D4B4020EEEA5564BC5440187D0569C66E4B4082E7DEC325BF5440187D0569C66E4B4082E7DEC325BF54404FE960FD9F6D4B4020EEEA5564BC54404FE960FD9F6D4B40
68177	65	82.902203	82.933276000000006	54.964370000000002	54.962446999999997	Мира	0103000020E6100000010000000500000099D6A6B1BDB9544010919A76317B4B4099D6A6B1BDB954402C9FE579707B4B40128942CBBABB54402C9FE579707B4B40128942CBBABB544010919A76317B4B4099D6A6B1BDB9544010919A76317B4B40
68257	65	82.956936999999996	82.973968999999997	55.101674000000003	55.096651999999999	Макаренко	0103000020E6100000010000000500000045D5AF743EBD5440E78BBD175F8C4B4045D5AF743EBD5440406D54A7038D4B405794128255BE5440406D54A7038D4B405794128255BE5440E78BBD175F8C4B4045D5AF743EBD5440E78BBD175F8C4B40
68306	65	82.970448000000005	82.994011	55.175452	55.153416	Магистральная	0103000020E61000000100000005000000FE9DEDD11BBE54407157AF22A3934B40FE9DEDD11BBE544047020D3675964B40503750E09DBF544047020D3675964B40503750E09DBF54407157AF22A3934B40FE9DEDD11BBE54407157AF22A3934B40
67897	65	82.934713000000002	82.939662999999996	55.076968000000001	55.074050999999997	Магаданская 	0103000020E6100000010000000500000059897956D2BB5440389ECF807A894B4059897956D2BB5440556B6116DA894B40B890477023BC5440556B6116DA894B40B890477023BC5440389ECF807A894B4059897956D2BB5440389ECF807A894B40
68045	65	83.085549	83.088476999999997	54.861973999999996	54.859507000000001	Лыкова	0103000020E61000000100000005000000274D83A279C554406FD74B53046E4B40274D83A279C554404B00FE29556E4B40AF5C6F9BA9C554404B00FE29556E4B40AF5C6F9BA9C554406FD74B53046E4B40274D83A279C554406FD74B53046E4B40
68060	65	83.003093000000007	83.016064	55.047420000000002	55.039785000000002	Липецкая	0103000020E610000001000000050000002E76FBAC32C0544089EFC4AC17854B402E76FBAC32C054409296CADB11864B4026A94C3107C154409296CADB11864B4026A94C3107C1544089EFC4AC17854B402E76FBAC32C0544089EFC4AC17854B40
67830	65	82.902185000000003	82.937893000000003	55.054046999999997	55.047286	Линейная 	0103000020E61000000100000005000000467C2766BDB9544082C7B7770D864B40467C2766BDB9544034B91803EB864B406E895C7006BC544034B91803EB864B406E895C7006BC544082C7B7770D864B40467C2766BDB9544082C7B7770D864B40
68138	65	83.074509000000006	83.091693000000006	54.891348999999998	54.88832	Лесосечная	0103000020E610000001000000050000007E9065C1C4C45440FD304278B4714B407E9065C1C4C4544041295AB917724B406B11514CDEC5544041295AB917724B406B11514CDEC55440FD304278B4714B407E9065C1C4C45440FD304278B4714B40
75579	65	83.091944999999996	83.093957000000003	54.812109999999997	54.811549999999997	Лесная 	0103000020E61000000100000005000000F701486DE2C55440CE88D2DEE0674B40F701486DE2C5544095607138F3674B40BD8E386403C6544095607138F3674B40BD8E386403C65440CE88D2DEE0674B40F701486DE2C55440CE88D2DEE0674B40
68016	65	82.938540000000003	82.988090999999997	55.021152999999998	55.000667999999997	Ленинградская 	0103000020E61000000100000005000000397F130A11BC5440AD1397E315804B40397F130A11BC54402C9B3924B5824B40349E08E23CBF54402C9B3924B5824B40349E08E23CBF5440AD1397E315804B40397F130A11BC5440AD1397E315804B40
16595	65	82.920726000000002	82.923996000000002	55.080528999999999	55.078797999999999	Лебедевская	0103000020E61000000100000005000000ECA4BE2CEDBA5440BF7E880D168A4B40ECA4BE2CEDBA544096B036C64E8A4B40A1681EC022BB544096B036C64E8A4B40A1681EC022BB5440BF7E880D168A4B40ECA4BE2CEDBA5440BF7E880D168A4B40
68020	65	83.002778000000006	83.025936999999999	55.036555999999997	55.032212000000001	Лазурная 	0103000020E610000001000000050000007EC9C6832DC05440F644D7851F844B407EC9C6832DC054407D3CF4DDAD844B4068B0A9F3A8C154407D3CF4DDAD844B4068B0A9F3A8C15440F644D7851F844B407EC9C6832DC05440F644D7851F844B40
68298	65	83.002778000000006	83.025936999999999	55.036555999999997	55.032212000000001	Лазурная	0103000020E610000001000000050000007EC9C6832DC05440F644D7851F844B407EC9C6832DC054407D3CF4DDAD844B4068B0A9F3A8C154407D3CF4DDAD844B4068B0A9F3A8C15440F644D7851F844B407EC9C6832DC05440F644D7851F844B40
68305	65	82.958347000000003	82.977158000000003	55.109219000000003	55.103116	Курчатова	0103000020E6100000010000000500000010CEA78E55BD5440E0D8B3E7328D4B4010CEA78E55BD5440098D60E3FA8D4B409641B5C189BE5440098D60E3FA8D4B409641B5C189BE5440E0D8B3E7328D4B4010CEA78E55BD5440E0D8B3E7328D4B40
68183	65	82.840892999999994	82.843057999999999	54.976638000000001	54.970840000000003	Курганская 	0103000020E61000000100000005000000DC9BDF30D1B5544007D3307C447C4B40DC9BDF30D1B55440F3035779027D4B4065A88AA9F4B55440F3035779027D4B4065A88AA9F4B5544007D3307C447C4B40DC9BDF30D1B5544007D3307C447C4B40
68052	65	82.989151000000007	82.996014000000002	55.046950000000002	55.034807000000001	Куприна	0103000020E6100000010000000500000091F3FE3F4EBF54400056478E74844B4091F3FE3F4EBF54400B46257502864B40EC1681B1BEBF54400B46257502864B40EC1681B1BEBF54400056478E74844B4091F3FE3F4EBF54400056478E74844B40
68237	65	82.895680999999996	82.918660000000003	55.129911	55.118220000000001	Кубовая 	0103000020E6100000010000000500000082A966D652B95440D7DD3CD5218F4B4082A966D652B95440013274ECA0904B402D095053CBBA5440013274ECA0904B402D095053CBBA5440D7DD3CD5218F4B4082A966D652B95440D7DD3CD5218F4B40
68244	65	82.895680999999996	82.918660000000003	55.129911	55.118220000000001	Кубовая	0103000020E6100000010000000500000082A966D652B95440D7DD3CD5218F4B4082A966D652B95440013274ECA0904B402D095053CBBA5440013274ECA0904B402D095053CBBA5440D7DD3CD5218F4B4082A966D652B95440D7DD3CD5218F4B40
68230	65	82.890569999999997	82.893714000000003	55.029853000000003	55.026725999999996	Кубановская 	0103000020E610000001000000050000001E335019FFB85440F8F9EFC16B834B401E335019FFB8544000581D39D2834B408D7E349C32B9544000581D39D2834B408D7E349C32B95440F8F9EFC16B834B401E335019FFB85440F8F9EFC16B834B40
68212	65	82.913719	82.953056000000004	55.043216000000001	55.039738999999997	Крылова	0103000020E61000000100000005000000F7AE415F7ABA544018B0E42A16854B40F7AE415F7ABA5440FC54151A88854B406CD097DEFEBC5440FC54151A88854B406CD097DEFEBC544018B0E42A16854B40F7AE415F7ABA544018B0E42A16854B40
67832	65	82.906075000000001	82.962776000000005	55.062607	55.049674000000003	Кропоткина	0103000020E61000000100000005000000492EFF21FDB9544013BBB6B75B864B40492EFF21FDB9544016C0948103884B40EB573A1F9EBD544016C0948103884B40EB573A1F9EBD544013BBB6B75B864B40492EFF21FDB9544013BBB6B75B864B40
69028	65	82.963621000000003	82.973456999999996	55.113869000000001	55.109178	Красных Зорь	0103000020E61000000100000005000000492F6AF7ABBD5440AAB8718BF98D4B40492F6AF7ABBD54409D836742938E4B40FCC3961E4DBE54409D836742938E4B40FCC3961E4DBE5440AAB8718BF98D4B40492F6AF7ABBD5440AAB8718BF98D4B40
29	65	82.908096	82.924203000000006	55.074587000000001	55.014952999999998	Красный проспект	0103000020E610000001000000050000003868AF3E1EBA544011FDDAFAE9814B403868AF3E1EBA544077DA1A118C894B405EF7562426BB544077DA1A118C894B405EF7562426BB544011FDDAFAE9814B403868AF3E1EBA544011FDDAFAE9814B40
68031	65	82.970716999999993	82.975477999999995	54.851962	54.849417000000003	Красноуфимская	0103000020E61000000100000005000000F52A323A20BE54404ED53DB2B96C4B40F52A323A20BE5440A6B73F170D6D4B40EBFD463B6EBE5440A6B73F170D6D4B40EBFD463B6EBE54404ED53DB2B96C4B40F52A323A20BE54404ED53DB2B96C4B40
68084	65	82.954376999999994	82.960071999999997	55.111283999999998	55.103878000000002	Кочубея	0103000020E610000001000000050000007EC3448314BD54400F63D2DF4B8D4B407EC3448314BD5440B648DA8D3E8E4B408A73D4D171BD5440B648DA8D3E8E4B408A73D4D171BD54400F63D2DF4B8D4B407EC3448314BD54400F63D2DF4B8D4B40
67985	65	82.862056999999993	82.905652000000003	54.992905999999998	54.987239000000002	Котовского	0103000020E610000001000000050000006C921FF12BB75440FA2AF9D85D7E4B406C921FF12BB754404700378B177F4B40A663CE33F6B954404700378B177F4B40A663CE33F6B95440FA2AF9D85D7E4B406C921FF12BB75440FA2AF9D85D7E4B40
1466	65	82.894576000000001	82.906002999999998	54.990628000000001	54.98413	Космическая улица	0103000020E6100000010000000500000056F2B1BB40B954409981CAF8F77D4B4056F2B1BB40B954403E40F7E5CC7E4B40FCC401F4FBB954403E40F7E5CC7E4B40FCC401F4FBB954409981CAF8F77D4B4056F2B1BB40B954409981CAF8F77D4B40
68176	65	82.894576000000001	82.906002999999998	54.990628000000001	54.98413	Космическая	0103000020E6100000010000000500000056F2B1BB40B954409981CAF8F77D4B4056F2B1BB40B954403E40F7E5CC7E4B40FCC401F4FBB954403E40F7E5CC7E4B40FCC401F4FBB954409981CAF8F77D4B4056F2B1BB40B954409981CAF8F77D4B40
7757	65	82.900361000000004	82.906497000000002	55.032341000000002	55.030343999999999	Комсомольский проспект	0103000020E610000001000000050000000266BE839FB954409ED0EB4FE2834B400266BE839FB95440F4A8F8BF23844B40043BFE0B04BA5440F4A8F8BF23844B40043BFE0B04BA54409ED0EB4FE2834B400266BE839FB954409ED0EB4FE2834B40
68116	65	82.959219000000004	82.984408000000002	55.026716	55.002470000000002	Коммунстроевская 	0103000020E61000000100000005000000EBAC16D863BD54404E9CDCEF50804B40EBAC16D863BD5440D5230D6E6B834B40EE7A698A00BF5440D5230D6E6B834B40EE7A698A00BF54404E9CDCEF50804B40EBAC16D863BD54404E9CDCEF50804B40
68215	65	82.910691999999997	82.933661999999998	55.024399000000003	55.022474000000003	Коммунистическая	0103000020E61000000100000005000000A52E19C748BA54405281936DE0824B40A52E19C748BA54400E87A5811F834B4026E1421EC1BB54400E87A5811F834B4026E1421EC1BB54405281936DE0824B40A52E19C748BA54405281936DE0824B40
68858	65	82.981829000000005	82.987300000000005	54.948141999999997	54.947009999999999	Колхозная 	0103000020E61000000100000005000000EC504D49D6BE5440137EA99F37794B40EC504D49D6BE544065FB90B75C794B40D0D556EC2FBF544065FB90B75C794B40D0D556EC2FBF5440137EA99F37794B40EC504D49D6BE5440137EA99F37794B40
67984	65	82.790569000000005	82.803270999999995	55.021849000000003	55.010415999999999	Клубная	0103000020E61000000100000005000000D00EB8AE98B2544075ADBD4F55814B40D00EB8AE98B25440A439B2F2CB824B40D0B4C4CA68B35440A439B2F2CB824B40D0B4C4CA68B3544075ADBD4F55814B40D00EB8AE98B2544075ADBD4F55814B40
68194	65	83.036708000000004	83.054288	55.007778000000002	54.988660000000003	Кирова	0103000020E610000001000000050000001AE0826C59C25440836E2F698C7E4B401AE0826C59C254406CD097DEFE804B402D24607479C354406CD097DEFE804B402D24607479C35440836E2F698C7E4B401AE0826C59C25440836E2F698C7E4B40
67987	65	82.834721000000002	82.851716999999994	54.990901999999998	54.990482999999998	Киевская 	0103000020E610000001000000050000003412A1116CB554403A1F9E25C87E4B403412A1116CB554403FC571E0D57E4B409F1C058882B654403FC571E0D57E4B409F1C058882B654403A1F9E25C87E4B403412A1116CB554403A1F9E25C87E4B40
68178	65	82.834721000000002	82.851716999999994	54.990901999999998	54.990482999999998	Киевская	0103000020E610000001000000050000003412A1116CB554403A1F9E25C87E4B403412A1116CB554403FC571E0D57E4B409F1C058882B654403FC571E0D57E4B409F1C058882B654403A1F9E25C87E4B403412A1116CB554403A1F9E25C87E4B40
68267	65	82.896427000000003	82.912622999999996	54.992657999999999	54.983075999999997	Карла Маркса	0103000020E6100000010000000500000017105A0F5FB95440C2BD326FD57D4B4017105A0F5FB954406F0ED76A0F7F4B40F4A44C6A68BA54406F0ED76A0F7F4B40F4A44C6A68BA5440C2BD326FD57D4B4017105A0F5FB95440C2BD326FD57D4B40
68213	65	82.923089000000004	82.929997	55.049163	55.024088999999996	Каменская 	0103000020E610000001000000050000000893E2E313BB5440BF982D5915834B400893E2E313BB54402D9622F94A864B403318231285BB54402D9622F94A864B403318231285BB5440BF982D5915834B400893E2E313BB5440BF982D5915834B40
68247	65	82.965102999999999	82.971318999999994	55.058368000000002	55.054042000000003	Индустриальная	0103000020E6100000010000000500000060915F3FC4BD5440234E27D9EA864B4060915F3FC4BD54400491459A78874B40F0BE2A172ABE54400491459A78874B40F0BE2A172ABE5440234E27D9EA864B4060915F3FC4BD5440234E27D9EA864B40
68192	65	83.092268000000004	83.100515000000001	54.842376999999999	54.836109	Ильича	0103000020E61000000100000005000000E99D0AB8E7C554401572A59E056B4B40E99D0AB8E7C5544088F37002D36B4B407A7077D66EC6544088F37002D36B4B407A7077D66EC654401572A59E056B4B40E99D0AB8E7C554401572A59E056B4B40
68033	65	83.080447000000007	83.115454	54.876776	54.866	Иванова	0103000020E61000000100000005000000ED832C0B26C55440022B8716D96E4B40ED832C0B26C5544077F52A323A704B40508C2C9963C7544077F52A323A704B40508C2C9963C75440022B8716D96E4B40ED832C0B26C55440022B8716D96E4B40
67975	65	82.896561000000005	82.929430999999994	54.936124	54.926906000000002	Зорге	0103000020E610000001000000050000009F77634161B95440AC3B16DBA4764B409F77634161B95440178046E9D2774B40DE3829CC7BBB5440178046E9D2774B40DE3829CC7BBB5440AC3B16DBA4764B409F77634161B95440AC3B16DBA4764B40
68025	65	83.065786000000003	83.071462999999994	54.954528000000003	54.945923999999998	Звездная	0103000020E6100000010000000500000038A27BD635C454403140A20914794B4038A27BD635C45440E38E37F92D7A4B40F0F78BD992C45440E38E37F92D7A4B40F0F78BD992C454403140A20914794B4038A27BD635C454403140A20914794B40
67992	65	82.790865999999994	82.834721000000002	54.990504000000001	54.987596000000003	Забалуева	0103000020E610000001000000050000002C616D8C9DB2544089D4B48B697E4B402C616D8C9DB254405247C7D5C87E4B403412A1116CB554405247C7D5C87E4B403412A1116CB5544089D4B48B697E4B402C616D8C9DB2544089D4B48B697E4B40
68240	65	82.891064	82.897261999999998	55.081251000000002	55.056171999999997	Жуковского	0103000020E6100000010000000500000026A94C3107B95440B779E3A430874B4026A94C3107B9544037E2C96E668A4B40637C98BD6CB9544037E2C96E668A4B40637C98BD6CB95440B779E3A430874B4026A94C3107B95440B779E3A430874B40
68323	65	83.085369	83.094837999999996	54.840702	54.833589000000003	Жемчужная	0103000020E61000000100000005000000E7C589AF76C5544016A75A0BB36A4B40E7C589AF76C5544045D7851F9C6B4B40C11A67D311C6544045D7851F9C6B4B40C11A67D311C6544016A75A0BB36A4B40E7C589AF76C5544016A75A0BB36A4B40
67809	65	82.986204000000001	82.996309999999994	55.053449000000001	55.033073000000002	Есенина	0103000020E61000000100000005000000CDCB61F71DBF5440B8B06EBC3B844B40CDCB61F71DBF54408080B56AD7864B4060AB048BC3BF54408080B56AD7864B4060AB048BC3BF5440B8B06EBC3B844B40CDCB61F71DBF5440B8B06EBC3B844B40
68158	65	82.885395000000003	82.906199999999998	55.075757000000003	55.073644000000002	Ереванская	0103000020E61000000100000005000000AF42CA4FAAB85440F8C5A52A6D894B40AF42CA4FAAB85440B7B8C667B2894B40A7E8482EFFB95440B7B8C667B2894B40A7E8482EFFB95440F8C5A52A6D894B40AF42CA4FAAB85440F8C5A52A6D894B40
67836	65	82.880814000000001	82.900711999999999	55.052602999999998	55.044691	Ельцовская 	0103000020E61000000100000005000000F9F6AE415FB8544078B6476FB8854B40F9F6AE415FB85440F355F2B1BB864B4058C7F143A5B95440F355F2B1BB864B4058C7F143A5B9544078B6476FB8854B40F9F6AE415FB8544078B6476FB8854B40
67835	65	82.880814000000001	82.900711999999999	55.052602999999998	55.044691	Ельцовская	0103000020E61000000100000005000000F9F6AE415FB8544078B6476FB8854B40F9F6AE415FB85440F355F2B1BB864B4058C7F143A5B95440F355F2B1BB864B4058C7F143A5B9544078B6476FB8854B40F9F6AE415FB8544078B6476FB8854B40
68058	65	82.880059000000003	82.934650000000005	55.065967999999998	55.045108999999997	Дуси Ковальчук	0103000020E610000001000000050000003BE3FBE252B85440ACE0B721C6854B403BE3FBE252B85440904AB1A371884B4036CD3B4ED1BB5440904AB1A371884B4036CD3B4ED1BB5440ACE0B721C6854B403BE3FBE252B85440ACE0B721C6854B40
68143	65	82.912218999999993	82.944415000000006	55.048167999999997	55.045284000000002	Достоевского	0103000020E610000001000000050000008CF2CCCB61BA54401B84B9DDCB854B408CF2CCCB61BA54405B5B785E2A864B4085B69C4B71BC54405B5B785E2A864B4085B69C4B71BC54401B84B9DDCB854B408CF2CCCB61BA54401B84B9DDCB854B40
15634	65	82.994630000000001	83.003783999999996	55.047471000000002	55.035834000000001	Доватора улица	0103000020E61000000100000005000000B6679604A8BF5440DD0A613596844B40B6679604A8BF544014419C8713864B40E00F3FFF3DC0544014419C8713864B40E00F3FFF3DC05440DD0A613596844B40B6679604A8BF5440DD0A613596844B40
16639	65	82.994630000000001	83.003783999999996	55.047471000000002	55.035834000000001	Доватора	0103000020E61000000100000005000000B6679604A8BF5440DD0A613596844B40B6679604A8BF544014419C8713864B40E00F3FFF3DC0544014419C8713864B40E00F3FFF3DC05440DD0A613596844B40B6679604A8BF5440DD0A613596844B40
68010	65	82.945348999999993	82.985827	55.032370999999998	55.004396	Добролюбова	0103000020E610000001000000050000009A93179980BC5440DA1D520C90804B409A93179980BC54405E2BA1BB24844B40E22021CA17BF54405E2BA1BB24844B40E22021CA17BF5440DA1D520C90804B409A93179980BC5440DA1D520C90804B40
67895	65	82.892150999999998	82.910017999999994	55.067757	55.061787000000002	Дмитрия Донского	0103000020E61000000100000005000000FF05820019B95440B328ECA2E8874B40FF05820019B954409C89E942AC884B405D3123BC3DBA54409C89E942AC884B405D3123BC3DBA5440B328ECA2E8874B40FF05820019B95440B328ECA2E8874B40
3617	65	83.104944000000003	83.107432000000003	54.842967999999999	54.839168000000001	Детский проезд	0103000020E6100000010000000500000055FA0967B7C65440C4EC65DB696B4B4055FA0967B7C654408AC91B60E66B4B40CFA2772AE0C654408AC91B60E66B4B40CFA2772AE0C65440C4EC65DB696B4B4055FA0967B7C65440C4EC65DB696B4B40
68149	65	82.914006999999998	82.981937000000002	55.055639999999997	55.040816999999997	Гоголя	0103000020E610000001000000050000002A5437177FBA5440770FD07D39854B402A5437177FBA5440BA2C26361F874B40DF6E490ED8BE5440BA2C26361F874B40DF6E490ED8BE5440770FD07D39854B402A5437177FBA5440770FD07D39854B40
16640	65	82.914006999999998	82.981937000000002	55.055639999999997	55.040816999999997	Гоголя	0103000020E610000001000000050000002A5437177FBA5440770FD07D39854B402A5437177FBA5440BA2C26361F874B40DF6E490ED8BE5440BA2C26361F874B40DF6E490ED8BE5440770FD07D39854B402A5437177FBA5440770FD07D39854B40
68055	65	82.914006999999998	82.981937000000002	55.055639999999997	55.040816999999997	Гоголя	0103000020E610000001000000050000002A5437177FBA5440770FD07D39854B402A5437177FBA5440BA2C26361F874B40DF6E490ED8BE5440BA2C26361F874B40DF6E490ED8BE5440770FD07D39854B402A5437177FBA5440770FD07D39854B40
16648	65	82.976322999999994	82.978038999999995	54.865693999999998	54.856445000000001	Гидромонтажная	0103000020E6100000010000000500000049D576137CBE54404FE960FD9F6D4B4049D576137CBE5440F52B9D0FCF6E4B409ACDE33098BE5440F52B9D0FCF6E4B409ACDE33098BE54404FE960FD9F6D4B4049D576137CBE54404FE960FD9F6D4B40
68124	65	83.058132000000001	83.103875000000002	54.978482999999997	54.971868999999998	Героев Революции	0103000020E6100000010000000500000078B6476FB8C35440847F1134667C4B4078B6476FB8C35440925852EE3E7D4B40CFF753E3A5C65440925852EE3E7D4B40CFF753E3A5C65440847F1134667C4B4078B6476FB8C35440847F1134667C4B40
15437	65	83.099616999999995	83.100685999999996	54.868698999999999	54.865425000000002	Вяземская	0103000020E610000001000000050000000A48FB1F60C654400612143FC66E4B400A48FB1F60C65440B1886187316F4B40904AB1A371C65440B1886187316F4B40904AB1A371C654400612143FC66E4B400A48FB1F60C654400612143FC66E4B40
68175	65	82.884092999999993	82.895563999999993	54.998013	54.985745999999999	Выставочная 	0103000020E61000000100000005000000D767CEFA94B85440D714C8EC2C7E4B40D767CEFA94B85440CEFDD5E3BE7F4B4065DEAAEB50B95440CEFDD5E3BE7F4B4065DEAAEB50B95440D714C8EC2C7E4B40D767CEFA94B85440D714C8EC2C7E4B40
68283	65	82.884092999999993	82.895563999999993	54.998013	54.985745999999999	Выставочная	0103000020E61000000100000005000000D767CEFA94B85440D714C8EC2C7E4B40D767CEFA94B85440CEFDD5E3BE7F4B4065DEAAEB50B95440CEFDD5E3BE7F4B4065DEAAEB50B95440D714C8EC2C7E4B40D767CEFA94B85440D714C8EC2C7E4B40
68193	65	82.984318000000002	83.048456999999999	55.009579000000002	54.987487000000002	Выборная 	0103000020E610000001000000050000004EB7EC10FFBE5440D21C59F9657E4B404EB7EC10FFBE54403CDD79E239814B40C99063EB19C354403CDD79E239814B40C99063EB19C35440D21C59F9657E4B404EB7EC10FFBE5440D21C59F9657E4B40
68005	65	82.984318000000002	83.048456999999999	55.009579000000002	54.987487000000002	Выборная	0103000020E610000001000000050000004EB7EC10FFBE5440D21C59F9657E4B404EB7EC10FFBE54403CDD79E239814B40C99063EB19C354403CDD79E239814B40C99063EB19C35440D21C59F9657E4B404EB7EC10FFBE5440D21C59F9657E4B40
16628	65	82.982772999999995	83.020591999999994	55.05959	55.040533000000003	Волочаевская	0103000020E610000001000000050000001399B9C0E5BE544053B4722F30854B401399B9C0E5BE5440969526A5A0874B40CAA31B6151C15440969526A5A0874B40CAA31B6151C1544053B4722F30854B401399B9C0E5BE544053B4722F30854B40
7880	65	82.900217999999995	82.916027999999997	55.034728999999999	55.031328999999999	Вокзальная магистраль	0103000020E610000001000000050000005051F52B9DB954404C35B39602844B405051F52B9DB95440849CF7FF71844B40198EE733A0BA5440849CF7FF71844B40198EE733A0BA54404C35B39602844B405051F52B9DB954404C35B39602844B40
68014	65	82.957144	82.990992000000006	55.026783000000002	55.013311999999999	Воинская 	0103000020E610000001000000050000000264E8D841BD54407A522635B4814B400264E8D841BD54405D8B16A06D834B4040A6B5696CBF54405D8B16A06D834B4040A6B5696CBF54407A522635B4814B400264E8D841BD54407A522635B4814B40
14032	65	82.946579999999997	82.961625999999995	55.031897000000001	55.027541999999997	Военный Городок	0103000020E610000001000000050000000DC347C494BC54401AA20A7F86834B400DC347C494BC544096EB6D3315844B40EE3EC7478BBD544096EB6D3315844B40EE3EC7478BBD54401AA20A7F86834B400DC347C494BC54401AA20A7F86834B40
67789	65	82.880454999999998	82.893804000000003	55.045108999999997	55.029977000000002	Владимировская 	0103000020E6100000010000000500000061A6ED5F59B85440EC504D49D6834B4061A6ED5F59B85440ACE0B721C6854B402D42B11534B95440ACE0B721C6854B402D42B11534B95440EC504D49D6834B4061A6ED5F59B85440EC504D49D6834B40
68297	65	83.011724999999998	83.024642999999998	55.035978	55.024785999999999	Владимира Высоцкого	0103000020E61000000100000005000000EBE2361AC0C0544007B309302C834B40EBE2361AC0C0544010B056ED9A844B40D2C43BC093C1544010B056ED9A844B40D2C43BC093C1544007B309302C834B40EBE2361AC0C0544007B309302C834B40
68191	65	83.003649999999993	83.019011000000006	55.004401000000001	54.998938000000003	Вилюйская	0103000020E6100000010000000500000058A835CD3BC05440A75D4C33DD7F4B4058A835CD3BC05440EC88433690804B40EAD0E97937C15440EC88433690804B40EAD0E97937C15440A75D4C33DD7F4B4058A835CD3BC05440A75D4C33DD7F4B40
16661	65	82.969909000000001	82.976898000000006	54.855491000000001	54.85107	Ветлужская	0103000020E6100000010000000500000026C632FD12BE5440A94D9CDCEF6C4B4026C632FD12BE5440DC82A5BA806D4B40C861307F85BE5440DC82A5BA806D4B40C861307F85BE5440A94D9CDCEF6C4B4026C632FD12BE5440A94D9CDCEF6C4B40
68006	65	82.854889	82.903064999999998	54.979387000000003	54.973869000000001	Вертковская 	0103000020E61000000100000005000000732D5A80B6B654404BCB48BDA77C4B40732D5A80B6B6544054909F8D5C7D4B40624A24D1CBB9544054909F8D5C7D4B40624A24D1CBB954404BCB48BDA77C4B40732D5A80B6B654404BCB48BDA77C4B40
67989	65	82.854889	82.903064999999998	54.979387000000003	54.973869000000001	Вертковская	0103000020E61000000100000005000000732D5A80B6B654404BCB48BDA77C4B40732D5A80B6B6544054909F8D5C7D4B40624A24D1CBB9544054909F8D5C7D4B40624A24D1CBB954404BCB48BDA77C4B40732D5A80B6B654404BCB48BDA77C4B40
68310	65	82.875370000000004	82.933276000000006	54.994847999999998	54.962446999999997	Ватутина	0103000020E610000001000000050000009279E40F06B8544010919A76317B4B409279E40F06B85440D93EE42D577F4B40128942CBBABB5440D93EE42D577F4B40128942CBBABB544010919A76317B4B409279E40F06B8544010919A76317B4B40
68086	65	82.901196999999996	82.935153	54.967424000000001	54.964840000000002	Бурденко	0103000020E6100000010000000500000036902E36ADB95440B3EF8AE07F7B4B4036902E36ADB95440C9AEB48CD47B4B4067F0F78BD9BB5440C9AEB48CD47B4B4067F0F78BD9BB5440B3EF8AE07F7B4B4036902E36ADB95440B3EF8AE07F7B4B40
68186	65	82.983923000000004	82.989024999999998	54.988380999999997	54.983654000000001	Бугурусланская	0103000020E6100000010000000500000010B22C98F8BE5440304AD05FE87D4B4010B22C98F8BE54406F7EC344837E4B404A7B832F4CBF54406F7EC344837E4B404A7B832F4CBF5440304AD05FE87D4B4010B22C98F8BE5440304AD05FE87D4B40
16650	65	82.86336	82.874651	54.933723999999998	54.931603000000003	Бородина	0103000020E610000001000000050000002C2B4D4A41B7544081ED60C43E774B402C2B4D4A41B75440C2BE9D4484774B407A1A3048FAB75440C2BE9D4484774B407A1A3048FAB7544081ED60C43E774B402C2B4D4A41B7544081ED60C43E774B40
68312	65	83.092097999999993	83.099203000000003	54.812105000000003	54.810273000000002	Боровая партия	0103000020E61000000100000005000000BA8102EFE4C5544079EA9106B7674B40BA8102EFE4C5544084F57F0EF3674B40912A8A5759C6544084F57F0EF3674B40912A8A5759C6544079EA9106B7674B40BA8102EFE4C5544079EA9106B7674B40
68201	65	82.948762000000002	82.998052999999999	55.045361999999997	55.014736999999997	Бориса Богаткова	0103000020E61000000100000005000000016C4084B8BC54404485EAE6E2814B40016C4084B8BC5440963D096CCE854B402EABB019E0BF5440963D096CCE854B402EABB019E0BF54404485EAE6E2814B40016C4084B8BC54404485EAE6E2814B40
68104	65	82.924616	82.997200000000007	55.013244999999998	54.985509	Большевистская	0103000020E61000000100000005000000EF5696E82CBB5440F374AE28257E4B40EF5696E82CBB5440F2EA1C03B2814B408FE4F21FD2BF5440F2EA1C03B2814B408FE4F21FD2BF5440F374AE28257E4B40EF5696E82CBB5440F374AE28257E4B40
67909	65	82.934650000000005	82.986258000000007	55.109085	55.065679000000003	Богдана Хмельницкого	0103000020E6100000010000000500000036CD3B4ED1BB54405A84622B68884B4036CD3B4ED1BB5440F9BD4D7FF68D4B40C7DADFD91EBF5440F9BD4D7FF68D4B40C7DADFD91EBF54405A84622B68884B4036CD3B4ED1BB54405A84622B68884B40
16655	65	82.943184000000002	82.973097999999993	54.868492000000003	54.861803000000002	Бердышева	0103000020E6100000010000000500000012876C205DBC54401F4C8A8F4F6E4B4012876C205DBC5440386BF0BE2A6F4B406473D53C47BE5440386BF0BE2A6F4B406473D53C47BE54401F4C8A8F4F6E4B4012876C205DBC54401F4C8A8F4F6E4B40
68110	65	82.940830000000005	82.988252000000003	55.024827000000002	55.006549	Белинского	0103000020E610000001000000050000002046088F36BC54402769FE98D6804B402046088F36BC54406687F8872D834B40390D51853FBF54406687F8872D834B40390D51853FBF54402769FE98D6804B402046088F36BC54402769FE98D6804B40
68030	65	82.944503999999995	82.990408000000002	54.871026000000001	54.86356	Барьерная	0103000020E610000001000000050000003CBCE7C072BC54401F115322896E4B403CBCE7C072BC54409CFBABC77D6F4B40986C3CD862BF54409CFBABC77D6F4B40986C3CD862BF54401F115322896E4B403CBCE7C072BC54401F115322896E4B40
68407	65	82.944540000000003	82.962129000000004	55.082725000000003	55.073644000000002	Александра Невского	0103000020E61000000100000005000000E370E65773BC5440F8C5A52A6D894B40E370E65773BC5440E3C798BB968A4B402062838593BD5440E3C798BB968A4B402062838593BD5440F8C5A52A6D894B40E370E65773BC5440F8C5A52A6D894B40
68300	65	83.059066999999999	83.064572999999996	54.977429000000001	54.963000000000001	Аксенова	0103000020E610000001000000050000007651F4C0C7C3544025068195437B4B407651F4C0C7C35440BC94BA641C7D4B4018CDCAF621C45440BC94BA641C7D4B4018CDCAF621C4544025068195437B4B407651F4C0C7C3544025068195437B4B40
68035	65	83.108689999999996	83.115598000000006	54.837668999999998	54.833506	Академическая	0103000020E61000000100000005000000BED9E6C6F4C6544088821953B06A4B40BED9E6C6F4C65440BFEFDFBC386B4B40EA5E27F565C75440BFEFDFBC386B4B40EA5E27F565C7544088821953B06A4B40BED9E6C6F4C6544088821953B06A4B40
68154	65	82.972676000000007	82.988127000000006	55.043937999999997	55.034847999999997	Адриена Лежена	0103000020E61000000100000005000000AA66D65240BE54405E2A36E675844B40AA66D65240BE54409C86A8C29F854B40DB5207793DBF54409C86A8C29F854B40DB5207793DBF54405E2A36E675844B40AA66D65240BE54405E2A36E675844B40
67811	65	82.963558000000006	82.975702999999996	55.073751999999999	55.068086999999998	Авиастроителей 	0103000020E6100000010000000500000026732CEFAABD544031242713B7884B4026732CEFAABD5440DE019EB470894B40FBE6FEEA71BE5440DE019EB470894B40FBE6FEEA71BE544031242713B7884B4026732CEFAABD544031242713B7884B40
68048	65	82.963558000000006	82.975702999999996	55.073751999999999	55.068086999999998	Авиастроителей	0103000020E6100000010000000500000026732CEFAABD544031242713B7884B4026732CEFAABD5440DE019EB470894B40FBE6FEEA71BE5440DE019EB470894B40FBE6FEEA71BE544031242713B7884B4026732CEFAABD544031242713B7884B40
14418	65	82.845178000000004	82.853784000000005	54.970675	54.964545999999999	9-й Гвардейской Дивизии	0103000020E610000001000000050000001E53776517B654406ABE4A3E767B4B401E53776517B65440BC0512143F7C4B404776A565A4B65440BC0512143F7C4B404776A565A4B654406ABE4A3E767B4B401E53776517B654406ABE4A3E767B4B40
7379	65	83.003793000000002	83.011769999999999	55.050870000000003	55.046532999999997	3-й Почтовый переулок	0103000020E610000001000000050000000ABDFE243EC05440A69718CBF4854B400ABDFE243EC054407C2C7DE882864B40BB44F5D6C0C054407C2C7DE882864B40BB44F5D6C0C05440A69718CBF4854B400ABDFE243EC05440A69718CBF4854B40
3931	65	82.876717999999997	82.877796000000004	55.004472999999997	54.997802	2-я Школьная улица	0103000020E610000001000000050000002174D0251CB8544013F1D6F9B77F4B402174D0251CB85440855B3E9292804B40D12346CF2DB85440855B3E9292804B40D12346CF2DB8544013F1D6F9B77F4B402174D0251CB8544013F1D6F9B77F4B40
68403	65	82.876717999999997	82.877796000000004	55.004472999999997	54.997802	2-я Школьная	0103000020E610000001000000050000002174D0251CB8544013F1D6F9B77F4B402174D0251CB85440855B3E9292804B40D12346CF2DB85440855B3E9292804B40D12346CF2DB8544013F1D6F9B77F4B402174D0251CB8544013F1D6F9B77F4B40
67844	65	82.893777	82.896094000000005	55.055475000000001	55.054304999999999	2-я Союза Молодежи	0103000020E61000000100000005000000B03A72A433B9544030815B77F3864B40B03A72A433B95440705F07CE19874B401409A69A59B95440705F07CE19874B401409A69A59B9544030815B77F3864B40B03A72A433B9544030815B77F3864B40
16653	65	82.840102000000002	82.863502999999994	55.029167000000001	55.025410000000001	2-я Портовая	0103000020E6100000010000000500000078D32D3BC4B55440E57E87A240834B4078D32D3BC4B55440AC8F87BEBB834B40DD3F16A243B75440AC8F87BEBB834B40DD3F16A243B75440E57E87A240834B4078D32D3BC4B55440E57E87A240834B40
68056	65	82.892455999999996	82.912147000000004	55.045475000000003	55.039057999999997	1905 года	0103000020E610000001000000050000009D47C5FF1DB95440D65240DAFF844B409D47C5FF1DB954408FE4F21FD2854B404089CF9D60BA54408FE4F21FD2854B404089CF9D60BA5440D65240DAFF844B409D47C5FF1DB95440D65240DAFF844B40
1150	65	82.945205000000001	82.947396999999995	54.951193000000004	54.939293999999997	15-й Бронный переулок	0103000020E6100000010000000500000001C11C3D7EBC54401DAA29C93A784B4001C11C3D7EBC5440929735B1C0794B4006D50627A2BC5440929735B1C0794B4006D50627A2BC54401DAA29C93A784B4001C11C3D7EBC54401DAA29C93A784B40
68079	65	82.909927999999994	82.916692999999995	55.077463000000002	55.074412000000002	1-я Шевцовой	0103000020E61000000100000005000000BD6DA6423CBA54400937195586894B40BD6DA6423CBA544035D3BD4EEA894B4037DE1D19ABBA544035D3BD4EEA894B4037DE1D19ABBA54400937195586894B40BD6DA6423CBA54400937195586894B40
68129	65	83.050470000000004	83.054602000000003	54.965707999999999	54.963712999999998	1-я Механическая 	0103000020E6100000010000000500000077DB85E63AC3544072DD94F25A7B4B4077DB85E63AC3544027BEDA519C7B4B40F51263997EC3544027BEDA519C7B4B40F51263997EC3544072DD94F25A7B4B4077DB85E63AC3544072DD94F25A7B4B40
2087	65	82.877489999999995	82.877956999999995	54.982171999999998	54.979267999999998	1-й переулок Серафимовича	0103000020E610000001000000050000004A24D1CB28B85440790261A7587D4B404A24D1CB28B854400186E5CFB77D4B40D5928E7230B854400186E5CFB77D4B40D5928E7230B85440790261A7587D4B404A24D1CB28B85440790261A7587D4B40
954	65	82.887227999999993	82.887829999999994	54.964427000000001	54.961238000000002	1-й Чукотский переулок	0103000020E610000001000000050000001C06F357C8B8544013D6C6D8097B4B401C06F357C8B8544090300C58727B4B40179AEB34D2B8544090300C58727B4B40179AEB34D2B8544013D6C6D8097B4B401C06F357C8B8544013D6C6D8097B4B40
2164	65	82.860332	82.860808000000006	54.985266000000003	54.981375999999997	1-й Петропавловский переулок	0103000020E61000000100000005000000F2ECF2AD0FB75440268A90BA9D7D4B40F2ECF2AD0FB754402DEE3F321D7E4B40A708707A17B754402DEE3F321D7E4B40A708707A17B75440268A90BA9D7D4B40F2ECF2AD0FB75440268A90BA9D7D4B40
68235	65	82.907286999999997	82.934945999999997	55.029229000000001	55.026752000000002	 Щетинкина	0103000020E6100000010000000500000080457EFD10BA5440228D0A9C6C834B4080457EFD10BA5440228C9FC6BD834B40AA61BF27D6BB5440228C9FC6BD834B40AA61BF27D6BB5440228D0A9C6C834B4080457EFD10BA5440228D0A9C6C834B40
68059	65	82.913953000000006	82.962622999999994	55.041311999999998	55.036054999999998	 Фрунзе	0103000020E610000001000000050000003145B9347EBA5440BBED42739D844B403145B9347EBA544057772CB649854B4027D87F9D9BBD544057772CB649854B4027D87F9D9BBD5440BBED42739D844B403145B9347EBA5440BBED42739D844B40
68082	65	82.936167999999995	82.939079000000007	55.103245000000001	55.084266	 Фадеева	0103000020E61000000100000005000000F3E32F2DEABB54401615713AC98A4B40F3E32F2DEABB5440DE3CD521378D4B401157CEDE19BC5440DE3CD521378D4B401157CEDE19BC54401615713AC98A4B40F3E32F2DEABB54401615713AC98A4B40
68135	65	83.041602999999995	83.047235999999998	54.850655000000003	54.845875999999997	 Тружеников	0103000020E61000000100000005000000971AA19FA9C25440533C2EAA456C4B40971AA19FA9C25440E6965643E26C4B4068CC24EA05C35440E6965643E26C4B4068CC24EA05C35440533C2EAA456C4B40971AA19FA9C25440533C2EAA456C4B40
68003	65	82.817896000000005	82.871148000000005	54.981856000000001	54.979325000000003	 Титова	0103000020E61000000100000005000000DFE1766858B45440DE9387855A7D4B40DFE1766858B45440D1B01875AD7D4B40747E8AE3C0B75440D1B01875AD7D4B40747E8AE3C0B75440DE9387855A7D4B40DFE1766858B45440DE9387855A7D4B40
67791	65	82.898053000000004	82.901833999999994	54.963495999999999	54.942734000000002	 Сибиряков-Гвардейцев	0103000020E61000000100000005000000C8444AB379B95440E469F981AB784B40C8444AB379B95440D5E940D6537B4B40EF1AF4A5B7B95440D5E940D6537B4B40EF1AF4A5B7B95440E469F981AB784B40C8444AB379B95440E469F981AB784B40
67902	65	82.879745	82.882538999999994	54.986206000000003	54.967243000000003	 Серафимовича	0103000020E6100000010000000500000073F4F8BD4DB8544079245E9ECE7B4B4073F4F8BD4DB854403B8F8AFF3B7E4B40739CDB847BB854403B8F8AFF3B7E4B40739CDB847BB8544079245E9ECE7B4B4073F4F8BD4DB8544079245E9ECE7B4B40
68302	65	83.116288999999995	83.119495999999998	54.940897999999997	54.936176000000003	 Пришвина	0103000020E610000001000000050000009CF86A4771C754406AA67B9DD4774B409CF86A4771C75440976F7D586F784B402E008DD2A5C75440976F7D586F784B402E008DD2A5C754406AA67B9DD4774B409CF86A4771C754406AA67B9DD4774B40
68173	65	82.835466999999994	82.896947999999995	54.948855999999999	54.942112999999999	 Петухова	0103000020E61000000100000005000000C878944A78B554407711A62897784B40C878944A78B55440834E081D74794B409B8D959867B95440834E081D74794B409B8D959867B954407711A62897784B40C878944A78B554407711A62897784B40
68248	65	82.960279	82.976431000000005	55.078761999999998	55.070680000000003	 Олеко Дундича	0103000020E6100000010000000500000047020D3675BD54409B3DD00A0C894B4047020D3675BD544072158BDF148A4B403DF372D87DBE544072158BDF148A4B403DF372D87DBE54409B3DD00A0C894B4047020D3675BD54409B3DD00A0C894B40
68199	65	82.958123000000001	82.994774000000007	55.033073000000002	55.010834000000003	 Никитина	0103000020E61000000100000005000000E8A221E351BD5440AAD72D0263814B40E8A221E351BD5440B8B06EBC3B844B40503A9160AABF5440B8B06EBC3B844B40503A9160AABF5440AAD72D0263814B40E8A221E351BD5440AAD72D0263814B40
68144	65	82.905490999999998	82.935080999999997	55.028300000000002	55.025765999999997	 Максима Горького	0103000020E61000000100000005000000A1F48590F3B95440A3ACDF4C4C834B40A1F48590F3B95440083D9B559F834B401A87FA5DD8BB5440083D9B559F834B401A87FA5DD8BB5440A3ACDF4C4C834B40A1F48590F3B95440A3ACDF4C4C834B40
67793	65	82.945015999999995	82.966854999999995	55.042406	55.039738999999997	 Ломоносова	0103000020E61000000100000005000000978C63247BBC544018B0E42A16854B40978C63247BBC5440BC934F8F6D854B40573ECBF3E0BD5440BC934F8F6D854B40573ECBF3E0BD544018B0E42A16854B40978C63247BBC544018B0E42A16854B40
68139	65	82.913719	82.953056000000004	55.043216000000001	55.039738999999997	 Крылова	0103000020E61000000100000005000000F7AE415F7ABA544018B0E42A16854B40F7AE415F7ABA5440FC54151A88854B406CD097DEFEBC5440FC54151A88854B406CD097DEFEBC544018B0E42A16854B40F7AE415F7ABA544018B0E42A16854B40
68162	65	82.906075000000001	82.962776000000005	55.062607	55.049674000000003	 Кропоткина	0103000020E61000000100000005000000492EFF21FDB9544013BBB6B75B864B40492EFF21FDB9544016C0948103884B40EB573A1F9EBD544016C0948103884B40EB573A1F9EBD544013BBB6B75B864B40492EFF21FDB9544013BBB6B75B864B40
68167	65	82.963621000000003	82.973456999999996	55.113869000000001	55.109178	 Красных Зорь	0103000020E61000000100000005000000492F6AF7ABBD5440AAB8718BF98D4B40492F6AF7ABBD54409D836742938E4B40FCC3961E4DBE54409D836742938E4B40FCC3961E4DBE5440AAB8718BF98D4B40492F6AF7ABBD5440AAB8718BF98D4B40
67907	65	82.896561000000005	82.929430999999994	54.936124	54.926906000000002	 Зорге	0103000020E610000001000000050000009F77634161B95440AC3B16DBA4764B409F77634161B95440178046E9D2774B40DE3829CC7BBB5440178046E9D2774B40DE3829CC7BBB5440AC3B16DBA4764B409F77634161B95440AC3B16DBA4764B40
68223	65	82.919225999999995	82.929502999999997	55.072158999999999	55.065967999999998	 Залесского	0103000020E6100000010000000500000081E84999D4BA5440904AB1A371884B4081E84999D4BA5440588E90813C894B402BA226FA7CBB5440588E90813C894B402BA226FA7CBB5440904AB1A371884B4081E84999D4BA5440904AB1A371884B40
67834	65	82.880059000000003	82.934650000000005	55.065967999999998	55.045108999999997	 Дуси Ковальчук	0103000020E610000001000000050000003BE3FBE252B85440ACE0B721C6854B403BE3FBE252B85440904AB1A371884B4036CD3B4ED1BB5440904AB1A371884B4036CD3B4ED1BB5440ACE0B721C6854B403BE3FBE252B85440ACE0B721C6854B40
68037	65	82.912218999999993	82.944415000000006	55.048167999999997	55.045284000000002	 Достоевского	0103000020E610000001000000050000008CF2CCCB61BA54401B84B9DDCB854B408CF2CCCB61BA54405B5B785E2A864B4085B69C4B71BC54405B5B785E2A864B4085B69C4B71BC54401B84B9DDCB854B408CF2CCCB61BA54401B84B9DDCB854B40
68018	65	82.945348999999993	82.985827	55.032370999999998	55.004396	 Добролюбова	0103000020E610000001000000050000009A93179980BC5440DA1D520C90804B409A93179980BC54405E2BA1BB24844B40E22021CA17BF54405E2BA1BB24844B40E22021CA17BF5440DA1D520C90804B409A93179980BC5440DA1D520C90804B40
68155	65	82.892994999999999	82.904449	55.043514999999999	55.028295	 Дмитрия Шамшурина	0103000020E61000000100000005000000751F80D426B95440F6D1A92B9F834B40751F80D426B9544056F146E691854B4098F90E7EE2B9544056F146E691854B4098F90E7EE2B95440F6D1A92B9F834B40751F80D426B95440F6D1A92B9F834B40
68112	65	82.934713000000002	82.981999999999999	55.014479000000001	54.994914999999999	 Декабристов	0103000020E6100000010000000500000059897956D2BB544061A6ED5F597F4B4059897956D2BB544049BDA772DA814B40022B8716D9BE544049BDA772DA814B40022B8716D9BE544061A6ED5F597F4B4059897956D2BB544061A6ED5F597F4B40
68168	65	82.980401000000001	82.985027000000002	54.955478999999997	54.954878999999998	 Водозабор	0103000020E61000000100000005000000CEFDD5E3BEBE54408F519E79397A4B40CEFDD5E3BEBE5440E481C8224D7A4B4054ABAFAE0ABF5440E481C8224D7A4B4054ABAFAE0ABF54408F519E79397A4B40CEFDD5E3BEBE54408F519E79397A4B40
68294	65	82.948762000000002	82.998052999999999	55.045361999999997	55.014736999999997	 Бориса Богаткова	0103000020E61000000100000005000000016C4084B8BC54404485EAE6E2814B40016C4084B8BC5440963D096CCE854B402EABB019E0BF5440963D096CCE854B402EABB019E0BF54404485EAE6E2814B40016C4084B8BC54404485EAE6E2814B40
68166	65	82.934650000000005	82.986258000000007	55.109085	55.065679000000003	 Богдана Хмельницкого	0103000020E6100000010000000500000036CD3B4ED1BB54405A84622B68884B4036CD3B4ED1BB5440F9BD4D7FF68D4B40C7DADFD91EBF5440F9BD4D7FF68D4B40C7DADFD91EBF54405A84622B68884B4036CD3B4ED1BB54405A84622B68884B40
68071	65	82.900234999999995	82.912739999999999	55.081761	55.074587000000001	 Аэропорт	0103000020E61000000100000005000000BBED42739DB9544077DA1A118C894B40BBED42739DB954404C8BFA24778A4B40117008556ABA54404C8BFA24778A4B40117008556ABA544077DA1A118C894B40BBED42739DB9544077DA1A118C894B40
68319	65	82.938477000000006	82.956397999999993	54.970095999999998	54.959510999999999	 Аникина	0103000020E6100000010000000500000016C3D50110BC54407D93A641D17A4B4016C3D50110BC54407EFD101B2C7C4B406DFDF49F35BD54407EFD101B2C7C4B406DFDF49F35BD54407D93A641D17A4B4016C3D50110BC54407D93A641D17A4B40
14187	13294	83.100003000000001	83.132540000000006	54.984191000000003	54.969838000000003	улица Андреева	0103000020E610000001000000050000001FA0FB7266C654408335CEA6237C4B401FA0FB7266C654403F027FF8F97D4B405C5A0D897BC854403F027FF8F97D4B405C5A0D897BC854408335CEA6237C4B401FA0FB7266C654408335CEA6237C4B40
69025	59203	75.264662999999999	75.276898000000003	55.704169	55.697980000000001	Центральная	0103000020E61000000100000005000000855D143DF0D052408CA19C6857D94B40855D143DF0D05240B3EDB43522DA4B40FB9463B2B8D15240B3EDB43522DA4B40FB9463B2B8D152408CA19C6857D94B40855D143DF0D052408CA19C6857D94B40
67828	59110	77.252302999999998	77.344882999999996	54.387348000000003	54.326721999999997	Р.Люксембург	0103000020E61000000100000005000000B16B7BBB255053401D71C806D2294B40B16B7BBB25505340E415889E94314B40917C259012565340E415889E94314B40917C2590125653401D71C806D2294B40B16B7BBB255053401D71C806D2294B40
13665	14082	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	квартал 5	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
13438	14082	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	Партизанская	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
13813	14082	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	Интернатская	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
16606	14082	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	Закраевского	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
13818	14082	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	Володарского	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
16532	14082	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	 Молодежная	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
13411	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	проспект Юбилейный	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13407	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	микрорайон Южный	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13413	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	микрорайон Подгорный	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13397	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	микрорайон Индустриальный	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13923	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Элеваторная	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
14120	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Школьная	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13626	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Пушкина	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13643	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Прорабская	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13796	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Нагорная	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13630	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Литейная	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
14068	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Комсомольская	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13845	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Кирова	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13617	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Заводская	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13935	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	Дачная	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
13932	26706	83.265589000000006	83.337013999999996	54.664062000000001	54.586342000000002	 Советская	0103000020E610000001000000050000005A4B0169FFD05440B82231410D4B4B405A4B0169FFD054401842CEFBFF544B40D3122BA391D554401842CEFBFF544B40D3122BA391D55440B82231410D4B4B405A4B0169FFD05440B82231410D4B4B40
16367	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Школьная	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13766	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Пушкина	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13897	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Попова	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
14103	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Парижской Коммуны	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13903	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Островского	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
16582	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Озерная	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13919	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Микрорайон	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13931	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	М.Горького	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13950	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Лунная	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13605	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Ленина	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13607	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Кутузова	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
13910	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Комсомольская	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
14060	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Кольцова	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
14057	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	Вокзальная	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
14114	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	 Рогачева	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
14059	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	 Котовского	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
14107	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	 К. Маркса	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
14095	25298	83.038747000000001	83.130599000000004	54.821728	54.730812	 Боровая	0103000020E610000001000000050000005C74B2D47AC254401EC3633F8B5D4B405C74B2D47AC254408F1A13622E694B40FB78E8BB5BC854408F1A13622E694B40FB78E8BB5BC854401EC3633F8B5D4B405C74B2D47AC254401EC3633F8B5D4B40
15628	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	переулок Халтурина	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13619	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	переулок Гутова	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13618	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Ульяновская	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13623	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Сельская	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
67767	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Мира	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13787	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Луначарского	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13777	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Ленина	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
14118	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Коммунистическая	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13408	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Карла Маркса	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13769	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Калинина	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
16381	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Ермака	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
14124	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Деповская	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
16411	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	Барабинская	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13781	16965	78.285355999999993	78.395911999999996	55.373286	55.316097999999997	 Пролетарская	0103000020E61000000100000005000000E9EDCF45439253405E2A36E675A84B40E9EDCF4543925340FF06EDD5C7AF4B400306499F56995340FF06EDD5C7AF4B400306499F569953405E2A36E675A84B40E9EDCF45439253405E2A36E675A84B40
13700	41268	82.937740000000005	82.945635999999993	55.136648000000001	55.129086999999998	переулок Школьный	0103000020E61000000100000005000000AB09A2EE03BC54405CAB3DEC85904B40AB09A2EE03BC54402B8881AE7D914B40E57ADB4C85BC54402B8881AE7D914B40E57ADB4C85BC54405CAB3DEC85904B40AB09A2EE03BC54405CAB3DEC85904B40
14171	41268	82.937740000000005	82.945635999999993	55.136648000000001	55.129086999999998	в/ч 12202	0103000020E61000000100000005000000AB09A2EE03BC54405CAB3DEC85904B40AB09A2EE03BC54402B8881AE7D914B40E57ADB4C85BC54402B8881AE7D914B40E57ADB4C85BC54405CAB3DEC85904B40AB09A2EE03BC54405CAB3DEC85904B40
13847	41268	82.937740000000005	82.945635999999993	55.136648000000001	55.129086999999998	Луговая	0103000020E61000000100000005000000AB09A2EE03BC54405CAB3DEC85904B40AB09A2EE03BC54402B8881AE7D914B40E57ADB4C85BC54402B8881AE7D914B40E57ADB4C85BC54405CAB3DEC85904B40AB09A2EE03BC54405CAB3DEC85904B40
14144	40313	78.250960000000006	78.398131000000006	55.471428000000003	55.424689000000001	Карла Либкнехта	0103000020E61000000100000005000000AB2688BA0F90534048FC8A355CB64B40AB2688BA0F9053409835B1C057BC4B40862172FA7A9953409835B1C057BC4B40862172FA7A99534048FC8A355CB64B40AB2688BA0F90534048FC8A355CB64B40
13692	25214	83.116658000000001	83.124697999999995	54.742745999999997	54.736503999999996	Солнечная	0103000020E6100000010000000500000046B41D5377C75440C4AF58C3455E4B4046B41D5377C754400E9E094D125F4B401AF8510DFBC754400E9E094D125F4B401AF8510DFBC75440C4AF58C3455E4B4046B41D5377C75440C4AF58C3455E4B40
13714	28664	83.124499999999998	83.152321000000001	54.762127	54.733193	Жемчужная	0103000020E610000001000000050000008716D9CEF7C75440FC53AA44D95D4B408716D9CEF7C754400533A6608D614B409E5F94A0BFC954400533A6608D614B409E5F94A0BFC95440FC53AA44D95D4B408716D9CEF7C75440FC53AA44D95D4B40
13832	41301	78.292587999999995	78.387197999999998	55.367203000000003	55.336872	Некрасова	0103000020E61000000100000005000000EECC04C3B99253401478279F1EAB4B40EECC04C3B99253401EFF058200AF4B40E7C41EDAC79853401EFF058200AF4B40E7C41EDAC79853401478279F1EAB4B40EECC04C3B99253401478279F1EAB4B40
68390	15860	80.926851999999997	80.990480000000005	55.111638999999997	55.058425	Элеваторная	0103000020E61000000100000005000000DC0E0D8B513B544068226C787A874B40DC0E0D8B513B5440A4FACE2F4A8E4B40E5D53906643F5440A4FACE2F4A8E4B40E5D53906643F544068226C787A874B40DC0E0D8B513B544068226C787A874B40
13570	15860	80.926851999999997	80.990480000000005	55.111638999999997	55.058425	Трудовая	0103000020E61000000100000005000000DC0E0D8B513B544068226C787A874B40DC0E0D8B513B5440A4FACE2F4A8E4B40E5D53906643F5440A4FACE2F4A8E4B40E5D53906643F544068226C787A874B40DC0E0D8B513B544068226C787A874B40
14035	15860	80.926851999999997	80.990480000000005	55.111638999999997	55.058425	Трактовая	0103000020E61000000100000005000000DC0E0D8B513B544068226C787A874B40DC0E0D8B513B5440A4FACE2F4A8E4B40E5D53906643F5440A4FACE2F4A8E4B40E5D53906643F544068226C787A874B40DC0E0D8B513B544068226C787A874B40
16573	15860	80.926851999999997	80.990480000000005	55.111638999999997	55.058425	Северная	0103000020E61000000100000005000000DC0E0D8B513B544068226C787A874B40DC0E0D8B513B5440A4FACE2F4A8E4B40E5D53906643F5440A4FACE2F4A8E4B40E5D53906643F544068226C787A874B40DC0E0D8B513B544068226C787A874B40
14271	15860	80.926851999999997	80.990480000000005	55.111638999999997	55.058425	Нефтянников	0103000020E61000000100000005000000DC0E0D8B513B544068226C787A874B40DC0E0D8B513B5440A4FACE2F4A8E4B40E5D53906643F5440A4FACE2F4A8E4B40E5D53906643F544068226C787A874B40DC0E0D8B513B544068226C787A874B40
14021	15860	80.926851999999997	80.990480000000005	55.111638999999997	55.058425	Льва Толстого	0103000020E61000000100000005000000DC0E0D8B513B544068226C787A874B40DC0E0D8B513B5440A4FACE2F4A8E4B40E5D53906643F5440A4FACE2F4A8E4B40E5D53906643F544068226C787A874B40DC0E0D8B513B544068226C787A874B40
14670	42883	81.319766999999999	81.351260999999994	54.782302999999999	54.761592	Больничная	0103000020E61000000100000005000000C3D50110775454409772BED87B614B40C3D50110775454400648348122644B400ED76A0F7B5654400648348122644B400ED76A0F7B5654409772BED87B614B40C3D50110775454409772BED87B614B40
14036	24689	81.016693000000004	81.055491000000004	54.687539999999998	54.662188	Гриценко	0103000020E610000001000000050000009E44847F11415440DEE68D93C2544B409E44847F114154408E588B4F01584B403B8E1F2A8D4354408E588B4F01584B403B8E1F2A8D435440DEE68D93C2544B409E44847F11415440DEE68D93C2544B40
13751	24853	80.685025999999993	80.717247999999998	54.880457999999997	54.86815	Советская	0103000020E6100000010000000500000038BA4A77D72B5440DE02098A1F6F4B4038BA4A77D72B544033C005D9B2704B40C5C72764E72D544033C005D9B2704B40C5C72764E72D5440DE02098A1F6F4B4038BA4A77D72B5440DE02098A1F6F4B40
13588	25124	81.420197999999999	81.440068999999994	55.147005999999998	55.140796000000002	Трактовая	0103000020E610000001000000050000000EF62686E45A54402DB4739A05924B400EF62686E45A54406B28B517D1924B40F0BE2A172A5C54406B28B517D1924B40F0BE2A172A5C54402DB4739A05924B400EF62686E45A54402DB4739A05924B40
14088	41370	81.464260999999993	81.487050999999994	54.828066	54.814875000000001	Молодежная	0103000020E61000000100000005000000BAF3C473B65D5440FCA9F1D24D684B40BAF3C473B65D5440FB761211FE694B40FB1EF5D72B5F5440FB761211FE694B40FB1EF5D72B5F5440FCA9F1D24D684B40BAF3C473B65D5440FCA9F1D24D684B40
16579	24904	80.605911000000006	80.644350000000003	55.160710000000002	55.130873000000001	Лесная	0103000020E610000001000000050000005952EE3EC7265440F7764B72C0904B405952EE3EC7265440F111312592944B405E4BC8073D295440F111312592944B405E4BC8073D295440F7764B72C0904B405952EE3EC7265440F7764B72C0904B40
13741	41280	80.672754999999995	80.702202	55.001916999999999	54.985374	Центральная 	0103000020E610000001000000050000001CCEFC6A0E2B5440132A38BC207E4B401CCEFC6A0E2B54403927F6D03E804B40E44BA8E0F02C54403927F6D03E804B40E44BA8E0F02C5440132A38BC207E4B401CCEFC6A0E2B5440132A38BC207E4B40
16578	48934	80.724857	80.748564000000002	54.656902000000002	54.637517000000003	Центральная	0103000020E61000000100000005000000B5519D0E642E544070D234289A514B40B5519D0E642E5440A8565F5D15544B40A1BDFA78E82F5440A8565F5D15544B40A1BDFA78E82F544070D234289A514B40B5519D0E642E544070D234289A514B40
14330	24220	81.455950999999999	81.486575000000002	54.611694999999997	54.598287999999997	Центральная	0103000020E6100000010000000500000006651A4D2E5D54406CCB80B3944C4B4006651A4D2E5D5440381092054C4E4B404703780B245F5440381092054C4E4B404703780B245F54406CCB80B3944C4B4006651A4D2E5D54406CCB80B3944C4B40
14148	41378	81.126008999999996	81.154629	54.520885	54.502293000000002	Алексеевская	0103000020E610000001000000050000001B800D88104854403F0114234B404B401B800D88104854400DFD135CAC424B40D8800871E54954400DFD135CAC424B40D8800871E54954403F0114234B404B401B800D88104854403F0114234B404B40
16560	23246	75.948729999999998	75.958702000000002	54.714599	54.707920000000001	Шевченко	0103000020E61000000100000005000000FBAE08FEB7FC52409817601F9D5A4B40FBAE08FEB7FC52408D60E3FA775B4B400727A25F5BFD52408D60E3FA775B4B400727A25F5BFD52409817601F9D5A4B40FBAE08FEB7FC52409817601F9D5A4B40
68449	23399	76.504078000000007	76.534188999999998	54.713828999999997	54.704321	Озерная	0103000020E6100000010000000500000085285FD0422053406971C630275A4B4085285FD042205340DBF7A8BF5E5B4B4082380F2730225340DBF7A8BF5E5B4B4082380F27302253406971C630275A4B4085285FD0422053406971C630275A4B40
13828	41299	76.733785999999995	76.753997999999996	54.761181000000001	54.753704999999997	Октябрьская	0103000020E61000000100000005000000CF108E59F62E534074EACA6779604B40CF108E59F62E534015AB06616E614B40F6CFD3804130534015AB06616E614B40F6CFD3804130534074EACA6779604B40CF108E59F62E534074EACA6779604B40
68347	41306	76.830157	76.865191999999993	54.528722999999999	54.514290000000003	Школьная	0103000020E61000000100000005000000E962D34A2135534076543541D4414B40E962D34A213553404ED2FC31AD434B40B130444E5F3753404ED2FC31AD434B40B130444E5F37534076543541D4414B40E962D34A2135534076543541D4414B40
13977	20954	76.544321999999994	76.607043000000004	54.719940000000001	54.695768000000001	Энергетиков	0103000020E61000000100000005000000921FF12BD62253403ACD02ED0E594B40921FF12BD6225340878A71FE265C4B400211E2CAD9265340878A71FE265C4B400211E2CAD92653403ACD02ED0E594B40921FF12BD62253403ACD02ED0E594B40
67761	20954	76.544321999999994	76.607043000000004	54.719940000000001	54.695768000000001	Покрышкина	0103000020E61000000100000005000000921FF12BD62253403ACD02ED0E594B40921FF12BD6225340878A71FE265C4B400211E2CAD9265340878A71FE265C4B400211E2CAD92653403ACD02ED0E594B40921FF12BD62253403ACD02ED0E594B40
16611	20954	76.544321999999994	76.607043000000004	54.719940000000001	54.695768000000001	50 лет Октября	0103000020E61000000100000005000000921FF12BD62253403ACD02ED0E594B40921FF12BD6225340878A71FE265C4B400211E2CAD9265340878A71FE265C4B400211E2CAD92653403ACD02ED0E594B40921FF12BD62253403ACD02ED0E594B40
16555	22685	76.901608999999993	76.915210000000002	54.650343999999997	54.643728000000003	Лесная	0103000020E61000000100000005000000DF313CF6B33953407FC2D9AD65524B40DF313CF6B33953402D93E1783E534B4038BEF6CC923A53402D93E1783E534B4038BEF6CC923A53407FC2D9AD65524B40DF313CF6B33953407FC2D9AD65524B40
14181	22419	76.094204000000005	76.116400999999996	54.430207000000003	54.421883999999999	Цветнополье	0103000020E61000000100000005000000C1C9367007065340535A7F4B00364B40C1C936700706534051C1E10511374B40300E2E1D7307534051C1E10511374B40300E2E1D73075340535A7F4B00364B40C1C9367007065340535A7F4B00364B40
68652	41237	76.704699000000005	76.736652000000007	54.954366999999998	54.944325999999997	60 лет Октября	0103000020E6100000010000000500000088A1D5C9192D53409961A3ACDF784B4088A1D5C9192D5340D9B0A6B2287A4B401D226E4E252F5340D9B0A6B2287A4B401D226E4E252F53409961A3ACDF784B4088A1D5C9192D53409961A3ACDF784B40
13693	19888	76.301822000000001	76.316311999999996	54.905783	54.898969999999998	Центральная	0103000020E61000000100000005000000A7CD380D51135340E50AEF7211734B40A7CD380D51135340EA2285B2F0734B4045D5AF743E145340EA2285B2F0734B4045D5AF743E145340E50AEF7211734B40A7CD380D51135340E50AEF7211734B40
68559	21570	76.316609	76.355326000000005	54.912692	54.896853	Школьная	0103000020E61000000100000005000000A227655243145340E5284014CC724B40A22765524314534011A96917D3744B40C95A43A9BD16534011A96917D3744B40C95A43A9BD165340E5284014CC724B40A227655243145340E5284014CC724B40
68727	49311	76.027907999999996	76.065089	54.656516000000003	54.642467000000003	Школьная	0103000020E61000000100000005000000FED2A23EC90153402FE1D05B3C524B40FED2A23EC90153407FA65EB708544B4014950D6B2A0453407FA65EB708544B4014950D6B2A0453402FE1D05B3C524B40FED2A23EC90153402FE1D05B3C524B40
14185	22943	75.888982999999996	75.918268999999995	54.566443	54.555689000000001	Первомайская	0103000020E61000000100000005000000CCECF318E5F852409CDF30D120474B40CCECF318E5F852402906483481484B408FFB56EBC4FA52402906483481484B408FFB56EBC4FA52409CDF30D120474B40CCECF318E5F852409CDF30D120474B40
68695	59167	76.458641	76.487296999999998	54.832872999999999	54.823605000000001	Покровская	0103000020E61000000100000005000000B4E6C75F5A1D53403AE97DE36B694B40B4E6C75F5A1D5340575C1C959B6A4B40179CC1DF2F1F5340575C1C959B6A4B40179CC1DF2F1F53403AE97DE36B694B40B4E6C75F5A1D53403AE97DE36B694B40
13503	41218	76.204076999999998	76.240960999999999	54.496814000000001	54.486606000000002	Проселочная	0103000020E610000001000000050000006937FA980F0D5340C904FC1A493E4B406937FA980F0D5340F418E599973F4B4022A7AFE76B0F5340F418E599973F4B4022A7AFE76B0F5340C904FC1A493E4B406937FA980F0D5340C904FC1A493E4B40
15921	47305	76.617076999999995	76.626751999999996	54.750275999999999	54.744231999999997	Кирова	0103000020E61000000100000005000000488787307E2753407E5182FE425F4B40488787307E275340A27C410B09604B40F7AC6BB41C285340A27C410B09604B40F7AC6BB41C2853407E5182FE425F4B40488787307E2753407E5182FE425F4B40
68555	49677	76.158460000000005	76.188590000000005	54.786622999999999	54.774244000000003	Черниговка	0103000020E61000000100000005000000596E6935240A5340E78F696D1A634B40596E6935240A534005A4FD0FB0644B409296CADB110C534005A4FD0FB0644B409296CADB110C5340E78F696D1A634B40596E6935240A5340E78F696D1A634B40
13716	22772	76.640478000000002	76.660186999999993	54.543484999999997	54.533549999999998	Центральная	0103000020E61000000100000005000000AEF36F97FD285340F163CC5D4B444B40AEF36F97FD285340EB6E9EEA90454B40A38FF980402A5340EB6E9EEA90454B40A38FF980402A5340F163CC5D4B444B40AEF36F97FD285340F163CC5D4B444B40
68445	49678	77.049086000000003	77.066126999999994	54.654812999999997	54.637413000000002	Школьная	0103000020E61000000100000005000000412C9B3924435340CB85CABF96514B40412C9B392443534071FF91E9D0534B407C98BD6C3B44534071FF91E9D0534B407C98BD6C3B445340CB85CABF96514B40412C9B3924435340CB85CABF96514B40
68651	47827	76.688996000000003	76.711849000000001	54.848669999999998	54.832017	Молодежная	0103000020E61000000100000005000000CAC4AD82182C5340A75B76887F6A4B40CAC4AD82182C5340548CF337A16C4B402EAC1BEF8E2D5340548CF337A16C4B402EAC1BEF8E2D5340A75B76887F6A4B40CAC4AD82182C5340A75B76887F6A4B40
14001	41346	76.164254	76.213921999999997	54.343792999999998	54.326590000000003	Молодежная	0103000020E610000001000000050000002E8F3523830A5340AF997CB3CD294B402E8F3523830A5340FFCBB568012C4B404679E6E5B00D5340FFCBB568012C4B404679E6E5B00D5340AF997CB3CD294B402E8F3523830A5340AF997CB3CD294B40
68685	45822	76.596442999999994	76.612199000000004	54.791849999999997	54.783419000000002	Самарская	0103000020E6100000010000000500000066BB421F2C2653405308E41247644B4066BB421F2C26534036AB3E575B654B4036E9B6442E27534036AB3E575B654B4036E9B6442E2753405308E41247644B4066BB421F2C2653405308E41247644B40
13697	21783	76.359251999999998	76.394969000000003	54.927774999999997	54.913266999999998	Центральная	0103000020E6100000010000000500000072C119FCFD1653400DC2DCEEE5744B4072C119FCFD165340F085C954C1764B40C47B0E2C47195340F085C954C1764B40C47B0E2C471953400DC2DCEEE5744B4072C119FCFD1653400DC2DCEEE5744B40
13707	41272	76.134664000000001	76.154776999999996	54.520477	54.506585000000001	Швачко	0103000020E61000000100000005000000B5FCC0559E08534074D2FBC6D7404B40B5FCC0559E085340FCA886FD9E424B40124BCADDE7095340FCA886FD9E424B40124BCADDE709534074D2FBC6D7404B40B5FCC0559E08534074D2FBC6D7404B40
75581	60698	76.238770000000002	76.258837999999997	54.603143000000003	54.595815000000002	Озерная	0103000020E610000001000000050000000551F701480F5340AEBB79AA434C4B400551F701480F5340DAE731CA334D4B40923D42CD90105340DAE731CA334D4B40923D42CD90105340AEBB79AA434C4B400551F701480F5340AEBB79AA434C4B40
68448	23224	75.892342999999997	75.908036999999993	54.734777999999999	54.719945000000003	Центральная	0103000020E610000001000000050000002174D0251CF9524099F56228275C4B402174D0251CF95240FFE89B340D5E4B40B5A338471DFA5240FFE89B340D5E4B40B5A338471DFA524099F56228275C4B402174D0251CF9524099F56228275C4B40
68368	41208	76.556736999999998	76.583453000000006	54.631816000000001	54.612248000000001	Центральная	0103000020E6100000010000000500000048DE3994A12353404D8578245E4E4B4048DE3994A1235340768BC058DF504B403370404B57255340768BC058DF504B403370404B572553404D8578245E4E4B4048DE3994A12353404D8578245E4E4B40
68649	49676	76.457824000000002	76.498570999999998	54.754235000000001	54.742299000000003	Центральная	0103000020E61000000100000005000000BBD408FD4C1D5340406D54A7035F4B40BBD408FD4C1D5340D13FC1C58A604B40FAEE5696E81F5340D13FC1C58A604B40FAEE5696E81F5340406D54A7035F4B40BBD408FD4C1D5340406D54A7035F4B40
13991	41342	75.689396000000002	77.223196999999999	55.061698999999997	54.122996000000001	Заречная	0103000020E61000000100000005000000917F66101FEC5240F8C43A55BE0F4B40917F66101FEC52401399B9C0E5874B402EE411DC484E53401399B9C0E5874B402EE411DC484E5340F8C43A55BE0F4B40917F66101FEC5240F8C43A55BE0F4B40
68725	41277	76.246781999999996	76.272897	54.405275000000003	54.386251999999999	Молодежная	0103000020E6100000010000000500000074CFBA46CB0F5340DE019EB470314B4074CFBA46CB0F534076711B0DE0334B404C8BFA247711534076711B0DE0334B404C8BFA2477115340DE019EB470314B4074CFBA46CB0F5340DE019EB470314B40
13531	22889	76.658372999999997	76.671766000000005	54.397570000000002	54.393062	Озерная	0103000020E6100000010000000500000071E481C8222A534072A609DB4F324B4071E481C8222A534074EFE192E3324B402524D236FE2A534074EFE192E3324B402524D236FE2A534072A609DB4F324B4071E481C8222A534072A609DB4F324B40
14133	19875	83.268994000000006	83.296661999999998	54.157649999999997	54.134054999999996	Новая	0103000020E610000001000000050000007F349C3237D15440C16ED8B628114B407F349C3237D15440711B0DE02D144B40D2FD9C82FCD25440711B0DE02D144B40D2FD9C82FCD25440C16ED8B628114B407F349C3237D15440C16ED8B628114B40
14031	19875	83.268994000000006	83.296661999999998	54.157649999999997	54.134054999999996	Ливенская	0103000020E610000001000000050000007F349C3237D15440C16ED8B628114B407F349C3237D15440711B0DE02D144B40D2FD9C82FCD25440711B0DE02D144B40D2FD9C82FCD25440C16ED8B628114B407F349C3237D15440C16ED8B628114B40
16605	19985	82.845096999999996	82.885997000000003	54.084215	54.066332000000003	Советская	0103000020E61000000100000005000000A73CBA1116B65440D25625917D084B40A73CBA1116B65440946A9F8EC70A4B40AAD6C22CB4B85440946A9F8EC70A4B40AAD6C22CB4B85440D25625917D084B40A73CBA1116B65440D25625917D084B40
13409	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Юбилейная	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13391	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Цыцаркина	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13790	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Свободная	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13398	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Пролетарская	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13924	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Партизанская	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13417	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Мичурина	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13387	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Линейная	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13615	17523	83.334113000000002	83.410847000000004	54.241987999999999	54.199742999999998	Богдана Хмельницкого	0103000020E61000000100000005000000C80A7E1B62D554406E4DBA2D91194B40C80A7E1B62D5544021037976F91E4B40392A37514BDA544021037976F91E4B40392A37514BDA54406E4DBA2D91194B40C80A7E1B62D554406E4DBA2D91194B40
13833	20638	82.947927000000007	82.968975	54.065963000000004	54.052143000000001	Центральная	0103000020E61000000100000005000000B5FF01D6AABC544090DB2F9FAC064B40B5FF01D6AABC54407FDFBF7971084B4010E9B7AF03BE54407FDFBF7971084B4010E9B7AF03BE544090DB2F9FAC064B40B5FF01D6AABC544090DB2F9FAC064B40
13424	18988	83.71163	83.741876000000005	54.193469999999998	54.184314000000001	Заречная	0103000020E610000001000000050000008F368E588BED5440F418E59997174B408F368E588BED5440E960FD9FC3184B40FD6B79E57AEF5440E960FD9FC3184B40FD6B79E57AEF5440F418E59997174B408F368E588BED5440F418E59997174B40
13690	20197	83.026610000000005	83.045681999999999	54.261941	54.254866999999997	Молодёжная	0103000020E61000000100000005000000C8EF6DFAB3C1544031EA5A7B9F204B40C8EF6DFAB3C15440A33D5E4887214B4004013274ECC25440A33D5E4887214B4004013274ECC2544031EA5A7B9F204B40C8EF6DFAB3C1544031EA5A7B9F204B40
13951	19185	83.454252999999994	83.473262000000005	54.210039000000002	54.179239000000003	Школьная	0103000020E6100000010000000500000008C72C7B12DD54407995B54DF1164B4008C72C7B12DD544039F1D58EE21A4B40221CB3EC49DE544039F1D58EE21A4B40221CB3EC49DE54407995B54DF1164B4008C72C7B12DD54407995B54DF1164B40
67765	19671	83.394614000000004	83.417665	54.242041	54.231012	переулок Школьный	0103000020E61000000100000005000000CD22145B41D95440E57D1CCD911D4B40CD22145B41D9544044A51133FB1E4B40C4EBFA05BBDA544044A51133FB1E4B40C4EBFA05BBDA5440E57D1CCD911D4B40CD22145B41D95440E57D1CCD911D4B40
14142	19355	83.360001999999994	83.375274000000005	54.125075000000002	54.116647999999998	Центральная	0103000020E61000000100000005000000A71FD4450AD7544068925852EE0E4B40A71FD4450AD754400B46257502104B4081423D7D04D854400B46257502104B4081423D7D04D8544068925852EE0E4B40A71FD4450AD7544068925852EE0E4B40
13662	19782	83.317565999999999	83.332657999999995	54.198794999999997	54.187032000000002	Молодежная	0103000020E610000001000000050000009414580053D454401AA721AAF0174B409414580053D45440DDCD531D72194B402DB0C7444AD55440DDCD531D72194B402DB0C7444AD554401AA721AAF0174B409414580053D454401AA721AAF0174B40
16617	49607	83.722463000000005	83.754757999999995	54.302329999999998	54.279159999999997	Кооперативная	0103000020E610000001000000050000007C6473D53CEE5440F92CCF83BB234B407C6473D53CEE5440C24CDBBFB2264B403D997FF44DF05440C24CDBBFB2264B403D997FF44DF05440F92CCF83BB234B407C6473D53CEE5440F92CCF83BB234B40
75573	60692	83.678967	83.696745000000007	54.240499	54.231490000000001	Центральная	0103000020E610000001000000050000000C04013274EB5440EFACDD76A11D4B400C04013274EB544040DCD5ABC81E4B40B329577897EC544040DCD5ABC81E4B40B329577897EC5440EFACDD76A11D4B400C04013274EB5440EFACDD76A11D4B40
75466	60617	83.049274999999994	83.073260000000005	54.100749	54.087516000000001	Центральная 	0103000020E61000000100000005000000AA60545227C3544039F06AB9330B4B40AA60545227C35440670DDE57E50C4B40B806B64AB0C45440670DDE57E50C4B40B806B64AB0C4544039F06AB9330B4B40AA60545227C3544039F06AB9330B4B40
68676	59165	82.637793000000002	84.011495999999994	54.481395999999997	53.934466999999998	Романова	0103000020E610000001000000050000008927BB99D1A854407A185A9D9CF74A408927BB99D1A854406D3656629E3D4B403A02B859BC0055406D3656629E3D4B403A02B859BC0055407A185A9D9CF74A408927BB99D1A854407A185A9D9CF74A40
13431	19686	83.345332999999997	83.371177000000003	54.194555000000001	54.183090999999997	Шоссейная	0103000020E61000000100000005000000B14E95EF19D654409198A0866F174B40B14E95EF19D65440FB22A12DE7184B40C1012D5DC1D75440FB22A12DE7184B40C1012D5DC1D754409198A0866F174B40B14E95EF19D654409198A0866F174B40
13802	19686	83.345332999999997	83.371177000000003	54.194555000000001	54.183090999999997	Клубная	0103000020E61000000100000005000000B14E95EF19D654409198A0866F174B40B14E95EF19D65440FB22A12DE7184B40C1012D5DC1D75440FB22A12DE7184B40C1012D5DC1D754409198A0866F174B40B14E95EF19D654409198A0866F174B40
13939	18754	83.618860999999995	83.634553999999994	54.306150000000002	54.297097000000001	Центральная	0103000020E6100000010000000500000045F12A6B9BE75440AF5E454607264B4045F12A6B9BE75440D0D556EC2F274B40F16261889CE85440D0D556EC2F274B40F16261889CE85440AF5E454607264B4045F12A6B9BE75440AF5E454607264B40
13414	18842	83.708736999999999	83.724538999999993	54.158208000000002	54.142299000000001	Школьная	0103000020E61000000100000005000000C51D6FF25BED544073A087DA36124B40C51D6FF25BED544098FBE42840144B404C6BD3D85EEE544098FBE42840144B404C6BD3D85EEE544073A087DA36124B40C51D6FF25BED544073A087DA36124B40
14132	19117	83.132988999999995	83.156317999999999	54.186584000000003	54.175271000000002	Школьная	0103000020E61000000100000005000000936E4BE482C85440F777B6476F164B40936E4BE482C854407BFA08FCE1174B40AC71361D01CA54407BFA08FCE1174B40AC71361D01CA5440F777B6476F164B40936E4BE482C85440F777B6476F164B40
16609	20573	82.977678999999995	83.014887000000002	54.179735000000001	54.166195000000002	Гагарина	0103000020E610000001000000050000001ABFF04A92BE54401EE1B4E045154B401ABFF04A92BE54402979758E01174B40AD889AE8F3C054402979758E01174B40AD889AE8F3C054401EE1B4E045154B401ABFF04A92BE54401EE1B4E045154B40
13667	19976	83.114644999999996	83.134929	54.165056999999997	54.145088999999999	Широкая	0103000020E610000001000000050000009869FB5756C754403201BF4692124B409869FB5756C75440E97C789620154B400C923EADA2C85440E97C789620154B400C923EADA2C854403201BF4692124B409869FB5756C754403201BF4692124B40
13945	19029	83.399743999999998	83.421527999999995	54.191257	54.180408999999997	Центральная	0103000020E610000001000000050000006CB1DB6795D95440B87361A417174B406CB1DB6795D95440C710001C7B184B404A969350FADA5440C710001C7B184B404A969350FADA5440B87361A417174B406CB1DB6795D95440B87361A417174B40
14146	20888	83.215832000000006	83.233132999999995	54.225864000000001	54.218004999999998	Центральная	0103000020E610000001000000050000008A5B0531D0CD5440A7AE7C96E71B4B408A5B0531D0CD544000AC8E1CE91C4B4093A7ACA6EBCE544000AC8E1CE91C4B4093A7ACA6EBCE5440A7AE7C96E71B4B408A5B0531D0CD5440A7AE7C96E71B4B40
13653	19258	83.532370999999998	83.551811000000001	54.238405	54.222831999999997	Ленина	0103000020E61000000100000005000000AF95D05D12E254404A404CC2851C4B40AF95D05D12E25440F819170E841E4B40ADA415DF50E35440F819170E841E4B40ADA415DF50E354404A404CC2851C4B40AF95D05D12E254404A404CC2851C4B40
13955	19459	83.290796	83.301782000000003	54.103715999999999	54.095399999999998	Южная	0103000020E61000000100000005000000B073D3669CD25440EA043411360C4B40B073D3669CD254403509DE90460D4B406021736550D354403509DE90460D4B406021736550D35440EA043411360C4B40B073D3669CD25440EA043411360C4B40
13976	20841	83.237561999999997	83.255788999999993	54.290622999999997	54.283622999999999	Мира	0103000020E610000001000000050000006E313F3734CF54405BB22AC24D244B406E313F3734CF5440923B6C2233254B404C6BD3D85ED05440923B6C2233254B404C6BD3D85ED054405BB22AC24D244B406E313F3734CF54405BB22AC24D244B40
68344	20316	82.891880999999998	82.920366999999999	54.311844000000001	54.281179000000002	Торговая	0103000020E610000001000000050000001FBB0B9414B9544037A968ACFD234B401FBB0B9414B9544017BA1281EA274B405454FD4AE7BA544017BA1281EA274B405454FD4AE7BA544037A968ACFD234B401FBB0B9414B9544037A968ACFD234B40
68444	18832	83.883872999999994	83.910704999999993	54.214514000000001	54.193111999999999	Советская	0103000020E6100000010000000500000050340F6091F854408A3BDEE4B7184B4050340F6091F854405F44DB31751B4B406FD39FFD48FA54405F44DB31751B4B406FD39FFD48FA54408A3BDEE4B7184B4050340F6091F854408A3BDEE4B7184B40
14138	19571	83.452923999999996	83.483960999999994	54.255870999999999	54.245891999999998	Школьная	0103000020E61000000100000005000000B4E4F1B4FCDC54408C2C9963791F4B40B4E4F1B4FCDC5440567F8461C0204B4086E28E37F9DE5440567F8461C0204B4086E28E37F9DE54408C2C9963791F4B40B4E4F1B4FCDC54408C2C9963791F4B40
67933	59122	83.471958999999998	83.488425000000007	54.128067000000001	54.119233000000001	Вокзальная	0103000020E610000001000000050000006283859334DE54404FCDE506430F4B406283859334DE54403259DC7F64104B402063EE5A42DF54403259DC7F64104B402063EE5A42DF54404FCDE506430F4B406283859334DE54404FCDE506430F4B40
15823	19765	83.295845	83.304728999999995	54.176456999999999	54.171787000000002	Шоссейная	0103000020E61000000100000005000000D9EBDD1FEFD254406170CD1DFD154B40D9EBDD1FEFD254403C139A2496164B40234910AE80D354403C139A2496164B40234910AE80D354406170CD1DFD154B40D9EBDD1FEFD254406170CD1DFD154B40
75545	60677	76.202692999999996	77.848091999999994	55.608795000000001	54.722195999999997	Школьная	0103000020E6100000010000000500000033880FECF80C5340A8A624EB705C4B4033880FECF80C5340F27B9BFEECCD4B40F3FFAA2347765340F27B9BFEECCD4B40F3FFAA2347765340A8A624EB705C4B4033880FECF80C5340A8A624EB705C4B40
14514	15138	76.857951	76.877301000000003	55.061163000000001	55.052995000000003	Центральная	0103000020E6100000010000000500000083A44FABE8365340FFEC478AC8864B4083A44FABE8365340D55C6E30D4874B40E1EF17B325385340D55C6E30D4874B40E1EF17B325385340FFEC478AC8864B4083A44FABE8365340FFEC478AC8864B40
13921	41324	76.552991000000006	76.575655999999995	55.355316000000002	55.346255999999997	2-ой переулок	0103000020E61000000100000005000000DFFE5C34642353409A05DA1D52AC4B40DFFE5C34642353406EDFA3FE7AAD4B40C16F438CD72453406EDFA3FE7AAD4B40C16F438CD72453409A05DA1D52AC4B40DFFE5C34642353409A05DA1D52AC4B40
16067	47886	76.946561000000003	76.965892999999994	55.039605000000002	55.027861999999999	Заводская	0103000020E61000000100000005000000D2AA9674943C53408C6665FB90834B40D2AA9674943C534009E1D1C611854B40DC9BDF30D13D534009E1D1C611854B40DC9BDF30D13D53408C6665FB90834B40D2AA9674943C53408C6665FB90834B40
13572	14422	76.728729000000001	76.800486000000006	55.322029999999998	55.295406	Пионерская	0103000020E6100000010000000500000065A9F57EA32E5340668522DDCFA54B4065A9F57EA32E53405A2A6F4738A94B40FAB9A1293B3353405A2A6F4738A94B40FAB9A1293B335340668522DDCFA54B4065A9F57EA32E5340668522DDCFA54B40
16565	14422	76.728729000000001	76.800486000000006	55.322029999999998	55.295406	Маяковского	0103000020E6100000010000000500000065A9F57EA32E5340668522DDCFA54B4065A9F57EA32E53405A2A6F4738A94B40FAB9A1293B3353405A2A6F4738A94B40FAB9A1293B335340668522DDCFA54B4065A9F57EA32E5340668522DDCFA54B40
14293	14422	76.728729000000001	76.800486000000006	55.322029999999998	55.295406	Ленина	0103000020E6100000010000000500000065A9F57EA32E5340668522DDCFA54B4065A9F57EA32E53405A2A6F4738A94B40FAB9A1293B3353405A2A6F4738A94B40FAB9A1293B335340668522DDCFA54B4065A9F57EA32E5340668522DDCFA54B40
14029	14422	76.728729000000001	76.800486000000006	55.322029999999998	55.295406	Зеленая	0103000020E6100000010000000500000065A9F57EA32E5340668522DDCFA54B4065A9F57EA32E53405A2A6F4738A94B40FAB9A1293B3353405A2A6F4738A94B40FAB9A1293B335340668522DDCFA54B4065A9F57EA32E5340668522DDCFA54B40
13728	14422	76.728729000000001	76.800486000000006	55.322029999999998	55.295406	Бр.Желтиковых	0103000020E6100000010000000500000065A9F57EA32E5340668522DDCFA54B4065A9F57EA32E53405A2A6F4738A94B40FAB9A1293B3353405A2A6F4738A94B40FAB9A1293B335340668522DDCFA54B4065A9F57EA32E5340668522DDCFA54B40
16638	49617	77.499680999999995	77.518383999999998	55.311236000000001	55.298352999999999	Школьная	0103000020E61000000100000005000000AF5B04C6FA5F5340EDD45C6E30A64B40AF5B04C6FA5F53403FABCC94D6A74B4042B115342D6153403FABCC94D6A74B4042B115342D615340EDD45C6E30A64B40AF5B04C6FA5F5340EDD45C6E30A64B40
16345	16353	76.964527000000004	76.985234000000005	55.317337999999999	55.303437000000002	Центральная	0103000020E61000000100000005000000FA4674CFBA3D5340BCB20B06D7A64B40FA4674CFBA3D534097E315889EA84B40113AE8120E3F534097E315889EA84B40113AE8120E3F5340BCB20B06D7A64B40FA4674CFBA3D5340BCB20B06D7A64B40
16583	17357	77.385379	77.395224999999996	55.335498999999999	55.324975000000002	Центральная	0103000020E610000001000000050000002C64AE0CAA5853404182E2C798A94B402C64AE0CAA5853409C6B98A1F1AA4B40F163CC5D4B5953409C6B98A1F1AA4B40F163CC5D4B5953404182E2C798A94B402C64AE0CAA5853404182E2C798A94B40
16316	15662	76.880139999999997	76.891512000000006	55.466085	55.462665999999999	Тайская	0103000020E61000000100000005000000B1F9B836543853404E7CB5A338BB4B40B1F9B83654385340FD135CACA8BB4B4076FF58880E395340FD135CACA8BB4B4076FF58880E3953404E7CB5A338BB4B40B1F9B836543853404E7CB5A338BB4B40
13612	41251	77.270251000000002	77.310863999999995	54.960912	54.950847000000003	Береговая	0103000020E6100000010000000500000086ADD9CA4B515340F73FC05AB5794B4086ADD9CA4B515340BF2A172AFF7A4B403D601E32E5535340BF2A172AFF7A4B403D601E32E5535340F73FC05AB5794B4086ADD9CA4B515340F73FC05AB5794B40
13913	16824	77.020195999999999	77.063215999999997	55.500886000000001	55.488850999999997	Центральная	0103000020E61000000100000005000000A4E029E44A415340F6CE68AB92BE4B40A4E029E44A4153401B834E081DC04B405F251FBB0B4453401B834E081DC04B405F251FBB0B445340F6CE68AB92BE4B40A4E029E44A415340F6CE68AB92BE4B40
14173	29991	77.032843999999997	77.058698000000007	55.504939999999998	55.495460999999999	Советская	0103000020E61000000100000005000000AB77B81D1A425340C3B81B446BBF4B40AB77B81D1A4253409B38B9DFA1C04B40CD9541B5C14353409B38B9DFA1C04B40CD9541B5C1435340C3B81B446BBF4B40AB77B81D1A425340C3B81B446BBF4B40
16528	49593	76.832061999999993	76.847279	55.381960999999997	55.372768999999998	Центральная	0103000020E61000000100000005000000A38FF9804035534037FB03E5B6AF4B40A38FF9804035534079AC1919E4B04B409BE5B2D13936534079AC1919E4B04B409BE5B2D13936534037FB03E5B6AF4B40A38FF9804035534037FB03E5B6AF4B40
68722	17196	77.643735000000007	77.656283999999999	55.413004000000001	55.403905999999999	Восточная	0103000020E61000000100000005000000991249F4326953403F541A31B3B34B40991249F432695340008FA850DDB44B40D6389B8E006A5340008FA850DDB44B40D6389B8E006A53403F541A31B3B34B40991249F4326953403F541A31B3B34B40
13754	41285	76.463707999999997	76.480739999999997	55.128959000000002	55.122297000000003	 Школьная	0103000020E6100000010000000500000030B95164AD1D534010B3976DA78F4B4030B95164AD1D53402FC37FBA81904B404278B471C41E53402FC37FBA81904B404278B471C41E534010B3976DA78F4B4030B95164AD1D534010B3976DA78F4B40
68674	49675	77.212795	77.245295999999996	55.566588000000003	55.553452	Московская	0103000020E610000001000000050000002670EB6E9E4D5340F1F3DF83D7C64B402670EB6E9E4D53402D27A1F485C84B40BC75FEEDB24F53402D27A1F485C84B40BC75FEEDB24F5340F1F3DF83D7C64B402670EB6E9E4D5340F1F3DF83D7C64B40
68424	41252	77.425748999999996	77.455133000000004	55.450510999999999	55.442484999999998	Центральная	0103000020E6100000010000000500000080D3BB783F5B53403BFC3559A3B84B4080D3BB783F5B53407FBE2D58AAB94B40259529E6205D53407FBE2D58AAB94B40259529E6205D53403BFC3559A3B84B4080D3BB783F5B53403BFC3559A3B84B40
13889	15690	76.632789000000002	76.653755000000004	55.032041	55.019613999999997	Центральная	0103000020E6100000010000000500000030116F9D7F285340994528B682824B4030116F9D7F285340C99063EB19844B402D26361FD7295340C99063EB19844B402D26361FD7295340994528B682824B4030116F9D7F285340994528B682824B40
68388	16373	77.219918000000007	77.237418000000005	55.124778999999997	55.113909999999997	Школьная	0103000020E610000001000000050000005073F222134E5340FB57569A948E4B405073F222134E5340211D1EC2F88F4B40D55E44DB314F5340211D1EC2F88F4B40D55E44DB314F5340FB57569A948E4B405073F222134E5340FB57569A948E4B40
14115	16906	77.216899999999995	77.250883000000002	55.504058000000001	55.490395999999997	Широкая	0103000020E6100000010000000500000027A089B0E14D53406B0BCF4BC5BE4B4027A089B0E14D5340C2A4F8F884C04B40D50792770E505340C2A4F8F884C04B40D50792770E5053406B0BCF4BC5BE4B4027A089B0E14D53406B0BCF4BC5BE4B40
13927	16906	77.216899999999995	77.250883000000002	55.504058000000001	55.490395999999997	Гагарина	0103000020E6100000010000000500000027A089B0E14D53406B0BCF4BC5BE4B4027A089B0E14D5340C2A4F8F884C04B40D50792770E505340C2A4F8F884C04B40D50792770E5053406B0BCF4BC5BE4B4027A089B0E14D53406B0BCF4BC5BE4B40
13386	17500	76.535043000000002	76.568091999999993	55.447263999999997	55.441831000000001	Центральная	0103000020E610000001000000050000000ABDFE243E225340F3AD0FEB8DB84B400ABDFE243E225340CD565EF23FB94B40A1478C9E5B245340CD565EF23FB94B40A1478C9E5B245340F3AD0FEB8DB84B400ABDFE243E225340F3AD0FEB8DB84B40
75553	60681	76.202692999999996	77.848091999999994	55.608795000000001	54.722195999999997	Школьная	0103000020E6100000010000000500000033880FECF80C5340A8A624EB705C4B4033880FECF80C5340F27B9BFEECCD4B40F3FFAA2347765340F27B9BFEECCD4B40F3FFAA2347765340A8A624EB705C4B4033880FECF80C5340A8A624EB705C4B40
13596	16293	76.954223999999996	76.972054999999997	55.371603	55.361953	Гагарина	0103000020E61000000100000005000000BB438A01123D534034D8D47954AE4B40BB438A01123D5340390CE6AF90AF4B4073BA2C26363E5340390CE6AF90AF4B4073BA2C26363E534034D8D47954AE4B40BB438A01123D534034D8D47954AE4B40
13745	15031	77.023098000000005	77.044045999999994	55.132392000000003	55.123944999999999	Абрамовская	0103000020E6100000010000000500000098A608707A41534059C0046EDD8F4B4098A608707A41534043209738F2904B40416150A6D142534043209738F2904B40416150A6D142534059C0046EDD8F4B4098A608707A41534059C0046EDD8F4B40
13587	41245	77.081344000000001	77.107701000000006	55.349102000000002	55.336886999999997	Центральная	0103000020E6100000010000000500000074EE76BD3445534049B9FB1C1FAB4B4074EE76BD34455340EE7BD45FAFAC4B40C72FBC92E4465340EE7BD45FAFAC4B40C72FBC92E446534049B9FB1C1FAB4B4074EE76BD3445534049B9FB1C1FAB4B40
13926	41325	76.674353999999994	76.687207999999998	55.337240000000001	55.332186	Зеленая	0103000020E6100000010000000500000050FBAD9D282B53403318231285AA4B4050FBAD9D282B5340977329AE2AAB4B402C634337FB2B5340977329AE2AAB4B402C634337FB2B53403318231285AA4B4050FBAD9D282B53403318231285AA4B40
14085	2743	76.808741999999995	76.831684999999993	55.299290999999997	55.292161	Школьная	0103000020E61000000100000005000000B439CE6DC233534055151A8865A54B40B439CE6DC23353405A7EE02A4FA64B40B8E4B8533A3553405A7EE02A4FA64B40B8E4B8533A35534055151A8865A54B40B439CE6DC233534055151A8865A54B40
13836	2743	76.808741999999995	76.831684999999993	55.299290999999997	55.292161	 Школьная	0103000020E61000000100000005000000B439CE6DC233534055151A8865A54B40B439CE6DC23353405A7EE02A4FA64B40B8E4B8533A3553405A7EE02A4FA64B40B8E4B8533A35534055151A8865A54B40B439CE6DC233534055151A8865A54B40
14175	16688	77.207718999999997	77.225317000000004	55.40457	55.398584	Школьная	0103000020E6100000010000000500000080F0A1444B4D5340BC5AEECC04B34B4080F0A1444B4D5340AB7823F3C8B34B40E78EFE976B4E5340AB7823F3C8B34B40E78EFE976B4E5340BC5AEECC04B34B4080F0A1444B4D5340BC5AEECC04B34B40
16642	49618	76.711264999999997	76.728064000000003	55.489896000000002	55.481862	Школьная	0103000020E610000001000000050000008672A25D852D5340B3976DA7ADBD4B408672A25D852D53407A3881E9B4BE4B404759BF99982E53407A3881E9B4BE4B404759BF99982E5340B3976DA7ADBD4B408672A25D852D5340B3976DA7ADBD4B40
13798	40418	76.798760999999999	76.826367000000005	55.540576999999999	55.531768999999997	Школьная	0103000020E610000001000000050000007F1475E61E3353406803B00111C44B407F1475E61E33534022FC8BA031C54B4098DF6932E334534022FC8BA031C54B4098DF6932E33453406803B00111C44B407F1475E61E3353406803B00111C44B40
16226	48553	77.177976000000001	77.191702000000006	55.295273000000002	55.284359000000002	Северная	0103000020E6100000010000000500000044DE72F5634B534061A92EE065A44B4044DE72F5634B534027327381CBA54B40FB2477D8444C534027327381CBA54B40FB2477D8444C534061A92EE065A44B4044DE72F5634B534061A92EE065A44B40
16631	48553	77.177976000000001	77.191702000000006	55.295273000000002	55.284359000000002	Кооперативная	0103000020E6100000010000000500000044DE72F5634B534061A92EE065A44B4044DE72F5634B534027327381CBA54B40FB2477D8444C534027327381CBA54B40FB2477D8444C534061A92EE065A44B4044DE72F5634B534061A92EE065A44B40
16577	15149	76.609926000000002	76.629284999999996	55.178593999999997	55.164526000000002	Центральная	0103000020E61000000100000005000000BABE0F0709275340BDAB1E300F954B40BABE0F070927534083A10E2BDC964B4041B797344628534083A10E2BDC964B4041B7973446285340BDAB1E300F954B40BABE0F0709275340BDAB1E300F954B40
14089	15004	76.986491000000001	77.011427999999995	54.952185999999998	54.94444	Центральная	0103000020E6100000010000000500000018B325AB223F53406284F068E3784B4018B325AB223F5340C2DA183BE1794B408E90813CBB405340C2DA183BE1794B408E90813CBB4053406284F068E3784B4018B325AB223F53406284F068E3784B40
14116	16213	76.810367999999997	76.819745999999995	55.265968000000001	55.257950000000001	Молодежная	0103000020E61000000100000005000000656EBE11DD33534069006F8104A14B40656EBE11DD3353402AE44A3D0BA24B40B741EDB7763453402AE44A3D0BA24B40B741EDB77634534069006F8104A14B40656EBE11DD33534069006F8104A14B40
75580	60697	77.297263000000001	77.305654000000004	55.173673000000001	55.168726999999997	Центральная	0103000020E61000000100000005000000E5D3635B06535340E179A9D898954B40E5D3635B065353405F99B7EA3A964B401079CBD58F5353405F99B7EA3A964B401079CBD58F535340E179A9D898954B40E5D3635B06535340E179A9D898954B40
14023	14197	76.078214000000003	76.113320000000002	55.851762999999998	55.839441000000001	Центральная	0103000020E61000000100000005000000B8054B7501055340F5F57CCD72EB4B40B8054B7501055340AF78EA9106ED4B40E57E87A240075340AF78EA9106ED4B40E57E87A240075340F5F57CCD72EB4B40B8054B7501055340F5F57CCD72EB4B40
68644	49674	75.664143999999993	75.692207999999994	55.998719999999999	55.985272000000002	Школьная	0103000020E610000001000000050000006AF5D55581EA52400FD594641DFE4B406AF5D55581EA524039EE940ED6FF4B40E481C8224DEC524039EE940ED6FF4B40E481C8224DEC52400FD594641DFE4B406AF5D55581EA52400FD594641DFE4B40
13468	11887	76.231233000000003	76.251677999999998	55.996066999999996	55.987592999999997	Крестьянская	0103000020E6100000010000000500000062307F85CC0E534017618A7269FE4B4062307F85CC0E5340FACF9A1F7FFF4B40DAC70A7E1B105340FACF9A1F7FFF4B40DAC70A7E1B10534017618A7269FE4B4062307F85CC0E534017618A7269FE4B40
13547	41233	75.655771999999999	75.688272999999995	55.553468000000002	55.544856000000003	Кооперативная	0103000020E610000001000000050000007B681F2BF8E95240C38366D7BDC54B407B681F2BF8E95240F7B0170AD8C64B40116E32AA0CEC5240F7B0170AD8C64B40116E32AA0CEC5240C38366D7BDC54B407B681F2BF8E95240C38366D7BDC54B40
14297	13573	76.207408999999998	76.228475000000003	56.103402000000003	56.097518000000001	Есенина	0103000020E6100000010000000500000059F96530460D5340BB6246787B0C4C4059F96530460D5340A62BD8463C0D4C40083D9B559F0E5340A62BD8463C0D4C40083D9B559F0E5340BB6246787B0C4C4059F96530460D5340BB6246787B0C4C40
13743	41282	76.00421	76.025661999999997	56.020505999999997	56.013672999999997	Большая	0103000020E610000001000000050000003C1405FA440053404AEB6F09C0014C403C1405FA4400534096AFCBF09F024C40FFAF3A72A401534096AFCBF09F024C40FFAF3A72A40153404AEB6F09C0014C403C1405FA440053404AEB6F09C0014C40
14193	13667	75.671132999999998	75.720512999999997	55.581316999999999	55.551088999999997	Дзержинского	0103000020E610000001000000050000000C91D3D7F3EA5240B91798158AC64B400C91D3D7F3EA5240EECD6F9868CA4B40F1D58EE21CEE5240EECD6F9868CA4B40F1D58EE21CEE5240B91798158AC64B400C91D3D7F3EA5240B91798158AC64B40
13529	13667	75.671132999999998	75.720512999999997	55.581316999999999	55.551088999999997	 Комсомольская	0103000020E610000001000000050000000C91D3D7F3EA5240B91798158AC64B400C91D3D7F3EA5240EECD6F9868CA4B40F1D58EE21CEE5240EECD6F9868CA4B40F1D58EE21CEE5240B91798158AC64B400C91D3D7F3EA5240B91798158AC64B40
68641	13438	76.036621999999994	76.070218999999994	56.034560999999997	56.026533000000001	Центральная	0103000020E610000001000000050000001A14CD0358025340E4A1EF6E65034C401A14CD0358025340C85BAE7E6C044C40B323D5777E045340C85BAE7E6C044C40B323D5777E045340E4A1EF6E65034C401A14CD0358025340E4A1EF6E65034C40
14053	13049	75.849512000000004	75.866749999999996	55.911709000000002	55.903695999999997	Старосилишинская	0103000020E61000000100000005000000D06394675EF6524054C37E4FACF34B40D06394675EF65240043C69E1B2F44B40B6F3FDD478F75240043C69E1B2F44B40B6F3FDD478F7524054C37E4FACF34B40D06394675EF6524054C37E4FACF34B40
16557	13325	75.289159999999995	75.307917000000003	55.849336999999998	55.842191	Центральная	0103000020E61000000100000005000000EDD3F19881D2524026FE28EACCEB4B40EDD3F19881D2524031242713B7EC4B407A3881E9B4D3524031242713B7EC4B407A3881E9B4D3524026FE28EACCEB4B40EDD3F19881D2524026FE28EACCEB4B40
13526	41226	75.540544999999995	75.559742	55.652495999999999	55.641396999999998	Центральная	0103000020E610000001000000050000000B410E4A98E252405260014C19D24B400B410E4A98E25240AA622AFD84D34B40A60C1CD0D2E35240AA622AFD84D34B40A60C1CD0D2E352405260014C19D24B400B410E4A98E252405260014C19D24B40
68442	49672	76.123227999999997	76.149970999999994	55.946033	55.931244999999997	Школьная	0103000020E61000000100000005000000E57CB1F7E207534021C8410933F74B40E57CB1F7E2075340E8F7FD9B17F94B404C16F71F99095340E8F7FD9B17F94B404C16F71F9909534021C8410933F74B40E57CB1F7E207534021C8410933F74B40
16072	41345	75.969606999999996	76.000778999999994	55.721218999999998	55.711959999999998	Центральная	0103000020E6100000010000000500000040BE840A0EFE5240B3075A8121DB4B4040BE840A0EFE52407D2079E750DC4B4082E15CC30C0053407D2079E750DC4B4082E15CC30C005340B3075A8121DB4B4040BE840A0EFE5240B3075A8121DB4B40
13997	41345	75.969606999999996	76.000778999999994	55.721218999999998	55.711959999999998	Центральная	0103000020E6100000010000000500000040BE840A0EFE5240B3075A8121DB4B4040BE840A0EFE52407D2079E750DC4B4082E15CC30C0053407D2079E750DC4B4082E15CC30C005340B3075A8121DB4B4040BE840A0EFE5240B3075A8121DB4B40
68984	46038	75.559094999999999	75.580806999999993	55.498663000000001	55.495435000000001	Луговая	0103000020E61000000100000005000000DB166536C8E352409A25016A6ABF4B40DB166536C8E35240D55C6E30D4BF4B406C921FF12BE55240D55C6E30D4BF4B406C921FF12BE552409A25016A6ABF4B40DB166536C8E352409A25016A6ABF4B40
13470	41203	76.131529	76.142937000000003	56.000104	55.992583000000003	Школьная	0103000020E61000000100000005000000705E9CF86A08534065C8B1F50CFF4B40705E9CF86A085340A54C6A6803004C40DB183BE125095340A54C6A6803004C40DB183BE12509534065C8B1F50CFF4B40705E9CF86A08534065C8B1F50CFF4B40
68646	40417	75.738146999999998	75.752690999999999	56.066780999999999	56.056381999999999	Степная	0103000020E61000000100000005000000FE28EACC3DEF5240A20A7F8637074C40FE28EACC3DEF5240417FA1478C084C40963FDF162CF05240417FA1478C084C40963FDF162CF05240A20A7F8637074C40FE28EACC3DEF5240A20A7F8637074C40
16541	12657	75.73751	75.762698	55.677616	55.668025999999998	Береговая	0103000020E61000000100000005000000459E245D33EF524058703FE081D54B40459E245D33EF5240889FFF1EBCD64B4060AE450BD0F05240889FFF1EBCD64B4060AE450BD0F0524058703FE081D54B40459E245D33EF524058703FE081D54B40
13837	41302	75.477771000000004	75.507549999999995	55.525170000000003	55.504429999999999	Школьная	0103000020E610000001000000050000008BFED0CC93DE5240868F882991C04B408BFED0CC93DE5240906B43C538C34B406DC5FEB27BE05240906B43C538C34B406DC5FEB27BE05240868F882991C04B408BFED0CC93DE5240868F882991C04B40
68684	48479	76.010445000000004	76.048399000000003	55.629679000000003	55.617663	Школьная	0103000020E61000000100000005000000085A8121AB0053408179C8940FCF4B40085A8121AB0053402FFD4B5299D04B402F8A1EF8180353402FFD4B5299D04B402F8A1EF8180353408179C8940FCF4B40085A8121AB0053408179C8940FCF4B40
68366	49673	75.277878000000001	75.308949999999996	55.633983000000001	55.617199999999997	Гагарина	0103000020E61000000100000005000000C991CEC0C8D15240AC8BDB6800CF4B40C991CEC0C8D15240289CDD5A26D14B40598638D6C5D35240289CDD5A26D14B40598638D6C5D35240AC8BDB6800CF4B40C991CEC0C8D15240AC8BDB6800CF4B40
13989	11705	76.252414999999999	76.267525000000006	55.950589999999998	55.945709999999998	Озерная	0103000020E6100000010000000500000045813E912710534005C078060DF94B4045813E9127105340CBF3E0EEACF94B4032772D211F115340CBF3E0EEACF94B4032772D211F11534005C078060DF94B4045813E912710534005C078060DF94B40
13669	11705	76.252414999999999	76.267525000000006	55.950589999999998	55.945709999999998	Кооперативная	0103000020E6100000010000000500000045813E912710534005C078060DF94B4045813E9127105340CBF3E0EEACF94B4032772D211F115340CBF3E0EEACF94B4032772D211F11534005C078060DF94B4045813E912710534005C078060DF94B40
13530	41230	75.400425999999996	75.410180999999994	55.713380000000001	55.705975000000002	Зелёная 	0103000020E61000000100000005000000F59D5F94A0D95240956588635DDA4B40F59D5F94A0D952406CCF2C0950DB4B40321CCF6740DA52406CCF2C0950DB4B40321CCF6740DA5240956588635DDA4B40F59D5F94A0D95240956588635DDA4B40
68638	40414	75.995739	76.021045000000001	55.509013000000003	55.500835000000002	Школьная	0103000020E6100000010000000500000083161230BAFF524099D87C5C1BC04B4083161230BAFF5240931E865627C14B40A3AF20CD58015340931E865627C14B40A3AF20CD5801534099D87C5C1BC04B4083161230BAFF524099D87C5C1BC04B40
14302	40415	75.834176999999997	75.849960999999993	55.521639	55.513233999999997	Школьная	0103000020E61000000100000005000000D384ED2763F55240FE98D6A6B1C14B40D384ED2763F55240B9A81611C5C24B400778D2C265F65240B9A81611C5C24B400778D2C265F65240FE98D6A6B1C14B40D384ED2763F55240FE98D6A6B1C14B40
68720	40415	75.834176999999997	75.849960999999993	55.521639	55.513233999999997	Зеленая	0103000020E61000000100000005000000D384ED2763F55240FE98D6A6B1C14B40D384ED2763F55240B9A81611C5C24B400778D2C265F65240B9A81611C5C24B400778D2C265F65240FE98D6A6B1C14B40D384ED2763F55240FE98D6A6B1C14B40
13805	41293	80.052404999999993	80.096880999999996	55.545726999999999	55.537658	Руднева	0103000020E610000001000000050000006649809A5A035440653733FAD1C44B406649809A5A035440A8C5E061DAC54B40A4A65D4C33065440A8C5E061DAC54B40A4A65D4C33065440653733FAD1C44B406649809A5A035440653733FAD1C44B40
13885	9646	79.620054999999994	79.723783999999995	55.318187999999999	55.280098000000002	Элеваторная	0103000020E6100000010000000500000029AE2AFBAEE7534067D65240DAA34B4029AE2AFBAEE7534065FD6662BAA84B408E57207A52EE534065FD6662BAA84B408E57207A52EE534067D65240DAA34B4029AE2AFBAEE7534067D65240DAA34B40
13824	9646	79.620054999999994	79.723783999999995	55.318187999999999	55.280098000000002	Матросова	0103000020E6100000010000000500000029AE2AFBAEE7534067D65240DAA34B4029AE2AFBAEE7534065FD6662BAA84B408E57207A52EE534065FD6662BAA84B408E57207A52EE534067D65240DAA34B4029AE2AFBAEE7534067D65240DAA34B40
13656	41258	79.716283000000004	79.741409000000004	55.514727999999998	55.505893	Центральная	0103000020E6100000010000000500000092EBA694D7ED53403E23111AC1C04B4092EBA694D7ED5340F12A6B9BE2C14B4072FDBB3E73EF5340F12A6B9BE2C14B4072FDBB3E73EF53403E23111AC1C04B4092EBA694D7ED53403E23111AC1C04B40
13418	9925	79.966876999999997	79.994814000000005	55.709277	55.697752000000001	Центральная	0103000020E610000001000000050000004B901150E1FD5340FB5B02F04FD94B404B901150E1FD53400A67B796C9DA4B4097E65608ABFF53400A67B796C9DA4B4097E65608ABFF5340FB5B02F04FD94B404B901150E1FD5340FB5B02F04FD94B40
13975	41336	78.999903000000003	79.024876000000006	55.189917000000001	55.180691000000003	Центральная	0103000020E61000000100000005000000070B2769FEBF53403DD7F7E120974B40070B2769FEBF53402BFA43334F984B40249D819197C153402BFA43334F984B40249D819197C153403DD7F7E120974B40070B2769FEBF53403DD7F7E120974B40
13967	41332	79.792378999999997	79.799897999999999	55.254359000000001	55.243032999999997	Московская	0103000020E6100000010000000500000061C26856B6F25340A46C91B41B9F4B4061C26856B6F25340BD38F1D58EA04B40B188618731F35340BD38F1D58EA04B40B188618731F35340A46C91B41B9F4B4061C26856B6F25340A46C91B41B9F4B40
13458	10948	79.427087999999998	79.449330000000003	55.443674999999999	55.438358000000001	Озерная	0103000020E61000000100000005000000E620E86855DB534051F86C1D1CB84B40E620E86855DB5340C286A757CAB84B4026C79DD2C1DC5340C286A757CAB84B4026C79DD2C1DC534051F86C1D1CB84B40E620E86855DB534051F86C1D1CB84B40
13963	10459	79.280061000000003	79.316218000000006	55.087594000000003	55.071854999999999	Школьная	0103000020E61000000100000005000000A5F8F884ECD15340EC866D8B32894B40A5F8F884ECD15340B5A9BA47368B4B40051A6CEA3CD45340B5A9BA47368B4B40051A6CEA3CD45340EC866D8B32894B40A5F8F884ECD15340EC866D8B32894B40
13941	41327	79.758359999999996	79.786278999999993	55.406446000000003	55.397990999999998	Цветочная	0103000020E610000001000000050000000DA661F888F05340198D7C5EF1B24B400DA661F888F0534086CB2A6C06B44B4005A2276552F2534086CB2A6C06B44B4005A2276552F25340198D7C5EF1B24B400DA661F888F05340198D7C5EF1B24B40
13670	41260	79.267600999999999	79.288244000000006	55.436489000000002	55.429153999999997	Центральная	0103000020E610000001000000050000001FD8F15F20D153404A79AD84EEB64B401FD8F15F20D1534029081EDFDEB74B402B51F69672D2534029081EDFDEB74B402B51F69672D253404A79AD84EEB64B401FD8F15F20D153404A79AD84EEB64B40
16610	11290	79.019073000000006	79.057879999999997	55.348826000000003	55.332289000000003	Трудовая	0103000020E6100000010000000500000025CFF57D38C1534008E9297288AA4B4025CFF57D38C153404CFF9254A6AC4B40EBC5504EB4C353404CFF9254A6AC4B40EBC5504EB4C3534008E9297288AA4B4025CFF57D38C1534008E9297288AA4B40
13820	11290	79.019073000000006	79.057879999999997	55.348826000000003	55.332289000000003	Ленинская	0103000020E6100000010000000500000025CFF57D38C1534008E9297288AA4B4025CFF57D38C153404CFF9254A6AC4B40EBC5504EB4C353404CFF9254A6AC4B40EBC5504EB4C3534008E9297288AA4B4025CFF57D38C1534008E9297288AA4B40
16460	11177	79.322999999999993	79.348477000000003	55.326588999999998	55.320504	Центральная	0103000020E61000000100000005000000E9263108ACD453405C1E6B4606A94B40E9263108ACD45340DE1D19ABCDA94B40209A79724DD65340DE1D19ABCDA94B40209A79724DD653405C1E6B4606A94B40E9263108ACD453405C1E6B4606A94B40
13960	41330	79.448009999999996	79.468006000000003	55.132268000000003	55.117206000000003	Школьная	0103000020E61000000100000005000000FB912232ACDC53408F72309B008F4B40FB912232ACDC534057276728EE904B403C1570CFF3DD534057276728EE904B403C1570CFF3DD53408F72309B008F4B40FB912232ACDC53408F72309B008F4B40
13490	41215	79.668060999999994	79.683601999999993	55.151702999999998	55.139828000000001	Центральная	0103000020E61000000100000005000000EAAEEC82C1EA5340558847E2E5914B40EAAEEC82C1EA534040DAFF006B934B40BB5E9A22C0EB534040DAFF006B934B40BB5E9A22C0EB5340558847E2E5914B40EAAEEC82C1EA5340558847E2E5914B40
13821	41297	79.893322999999995	79.919409999999999	55.321548999999997	55.313982000000003	Центральная	0103000020E61000000100000005000000EF703B342CF953402FC4EA8F30A84B40EF703B342CF95340DF87838428A94B4062670A9DD7FA5340DF87838428A94B4062670A9DD7FA53402FC4EA8F30A84B40EF703B342CF953402FC4EA8F30A84B40
13817	41295	79.586646999999999	79.611333000000002	55.378456999999997	55.369694000000003	Школьная	0103000020E61000000100000005000000FAD2DB9F8BE5534083C30B2252AF4B40FAD2DB9F8BE553409CF86A4771B04B40CC7D721420E753409CF86A4771B04B40CC7D721420E7534083C30B2252AF4B40FAD2DB9F8BE5534083C30B2252AF4B40
13974	41335	79.302698000000007	79.321292999999997	55.278072000000002	55.264223999999999	Школьная	0103000020E6100000010000000500000023A46E675FD35340BE688F17D2A14B4023A46E675FD3534077F700DD97A34B40C2DB831090D4534077F700DD97A34B40C2DB831090D45340BE688F17D2A14B4023A46E675FD35340BE688F17D2A14B40
13420	10113	79.566407999999996	79.591857000000005	55.243397000000002	55.235830999999997	Центральная	0103000020E61000000100000005000000560C570740E453400531D0B52F9E4B40560C570740E45340E67805A2279F4B4028BA2EFCE0E55340E67805A2279F4B4028BA2EFCE0E553400531D0B52F9E4B40560C570740E453400531D0B52F9E4B40
16537	48132	79.151843999999997	79.185316	55.268194999999999	55.247594999999997	Школьная	0103000020E610000001000000050000000186E5CFB7C9534099D36531B19F4B400186E5CFB7C95340B1F9B83654A24B403CDBA337DCCB5340B1F9B83654A24B403CDBA337DCCB534099D36531B19F4B400186E5CFB7C9534099D36531B19F4B40
13819	41296	83.798856000000001	83.930656999999997	55.218460999999998	55.143039000000002	Путейская	0103000020E61000000100000005000000A88DEA7420F35440BA86191A4F924B40A88DEA7420F35440C939B187F69B4B40C8B260E28FFB5440C939B187F69B4B40C8B260E28FFB5440BA86191A4F924B40A88DEA7420F35440BA86191A4F924B40
13644	41255	83.696995999999999	83.828796999999994	55.185363000000002	55.109878000000002	Железнодорожная	0103000020E61000000100000005000000575C1C959BEC54406346787B108E4B40575C1C959BEC5440B9718BF9B9974B40778192020BF55440B9718BF9B9974B40778192020BF554406346787B108E4B40575C1C959BEC54406346787B108E4B40
13808	41294	84.780212000000006	84.827687999999995	54.855910999999999	54.846606999999999	Центральная	0103000020E6100000010000000500000098FC4FFEEE31554047C8409E5D6C4B4098FC4FFEEE315540B1A4DC7D8E6D4B40AAD216D7F8345540B1A4DC7D8E6D4B40AAD216D7F834554047C8409E5D6C4B4098FC4FFEEE31554047C8409E5D6C4B40
67757	9629	84.740191999999993	84.772738000000004	55.103532999999999	55.088006	Долгих	0103000020E61000000100000005000000B130444E5F2F554007EDD5C7438B4B40B130444E5F2F55404487C091408D4B401898158A743155404487C091408D4B401898158A7431554007EDD5C7438B4B40B130444E5F2F554007EDD5C7438B4B40
9633	40240	83.830907999999994	83.869490999999996	55.016486999999998	54.989010999999998	Мира	0103000020E61000000100000005000000067FBF982DF554402F3196E9977E4B40067FBF982DF5544092E7FA3E1C824B40A54A94BDA5F7544092E7FA3E1C824B40A54A94BDA5F754402F3196E9977E4B40067FBF982DF554402F3196E9977E4B40
14087	6267	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	Школьная	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
68606	6267	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	Челюскинцев	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
14098	6267	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	Центральная	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
14041	6267	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	Трактовая	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
13904	6267	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	Свердлова	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
14100	6267	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	Никитина	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
13888	6267	84.337360000000004	84.434467999999995	55.267522999999997	55.217711000000001	Дзержинского	0103000020E61000000100000005000000A1BE654E971555405F7D3CF4DD9B4B40A1BE654E97155540C2F693313EA24B4025CADE52CE1B5540C2F693313EA24B4025CADE52CE1B55405F7D3CF4DD9B4B40A1BE654E971555405F7D3CF4DD9B4B40
15666	46241	84.504159000000001	84.530587999999995	55.311677000000003	55.299464999999998	переулок Клубный	0103000020E61000000100000005000000FB3E1C2444205540F8A57EDE54A64B40FB3E1C24442055402CF52C08E5A74B409AE95E27F52155402CF52C08E5A74B409AE95E27F5215540F8A57EDE54A64B40FB3E1C2444205540F8A57EDE54A64B40
13403	9062	84.946669999999997	84.976367999999994	54.855863999999997	54.841541999999997	Школьная	0103000020E61000000100000005000000AD86C43D963C5540EF1AF4A5B76B4B40AD86C43D963C554070E998F38C6D4B40193735D07C3E554070E998F38C6D4B40193735D07C3E5540EF1AF4A5B76B4B40AD86C43D963C5540EF1AF4A5B76B4B40
13922	8546	84.593442999999994	84.624363000000002	54.751980000000003	54.737237	Центральная	0103000020E61000000100000005000000914259F8FA255540593332C85D5E4B40914259F8FA255540809F71E140604B4047753A90F5275540809F71E140604B4047753A90F5275540593332C85D5E4B40914259F8FA255540593332C85D5E4B40
13771	41288	84.754582999999997	84.769091000000003	54.980274999999999	54.970224999999999	Лесная	0103000020E6100000010000000500000086C77E164B3055407C613255307C4B4086C77E164B3055400F0BB5A6797D4B40782975C9383155400F0BB5A6797D4B40782975C9383155407C613255307C4B4086C77E164B3055407C613255307C4B40
13761	7913	84.761401000000006	84.777929999999998	55.159058999999999	55.151209000000001	Крестьянская	0103000020E61000000100000005000000128942CBBA30554031EE06D15A934B40128942CBBA3055403691990B5C944B40F224E99AC93155403691990B5C944B40F224E99AC931554031EE06D15A934B40128942CBBA30554031EE06D15A934B40
68636	9333	84.465828000000002	84.495275000000007	55.287270999999997	55.273093000000003	Школьная	0103000020E61000000100000005000000E9633E20D01D55401EE21FB6F4A24B40E9633E20D01D55406B0BCF4BC5A44B40B1E1E995B21F55406B0BCF4BC5A44B40B1E1E995B21F55401EE21FB6F4A24B40E9633E20D01D55401EE21FB6F4A24B40
68386	9003	83.443922999999998	83.473620999999994	55.071561000000003	55.050514	Центральная	0103000020E610000001000000050000004DBC033C69DC5440BDFE243E77864B404DBC033C69DC5440A4552DE928894B40B96C74CE4FDE5440A4552DE928894B40B96C74CE4FDE5440BDFE243E77864B404DBC033C69DC5440BDFE243E77864B40
14043	7211	84.407545999999996	84.433732000000006	55.064267000000001	55.050772000000002	Клубная	0103000020E610000001000000050000006667D13B151A5540B9C667B27F864B406667D13B151A5540249BABE639884B40A3CEDC43C21B5540249BABE639884B40A3CEDC43C21B5540B9C667B27F864B406667D13B151A5540B9C667B27F864B40
14091	41371	84.371055999999996	84.387872999999999	55.214548000000001	55.202209000000003	Весенняя	0103000020E61000000100000005000000033FAA61BF1755407BFA08FCE1994B40033FAA61BF1755400BB6114F769B4B40178046E9D21855400BB6114F769B4B40178046E9D21855407BFA08FCE1994B40033FAA61BF1755407BFA08FCE1994B40
16592	9397	83.884663000000003	83.901910999999998	54.951591000000001	54.945407000000003	Центральная	0103000020E61000000100000005000000CD3E8F519EF854406A34B91803794B40CD3E8F519EF854407F15E0BBCD794B40C539EAE8B8F954407F15E0BBCD794B40C539EAE8B8F954406A34B91803794B40CD3E8F519EF854406A34B91803794B40
14013	41355	84.738009000000005	84.754592000000002	54.729039	54.715300999999997	Школьная	0103000020E61000000100000005000000D6C9198A3B2F5540E6E5B0FB8E5B4B40D6C9198A3B2F554018416326515D4B40B0743E3C4B30554018416326515D4B40B0743E3C4B305540E6E5B0FB8E5B4B40D6C9198A3B2F5540E6E5B0FB8E5B4B40
13393	9049	83.619184000000004	83.642819000000003	55.123475999999997	55.114657000000001	Центральная	0103000020E61000000100000005000000378DEDB5A0E75440F5A0A014AD8E4B40378DEDB5A0E75440A2EBC20FCE8F4B40D68F4DF223E95440A2EBC20FCE8F4B40D68F4DF223E95440F5A0A014AD8E4B40378DEDB5A0E75440F5A0A014AD8E4B40
68365	8855	83.634221999999994	83.662357	55.006141	54.995545	Центральная	0103000020E61000000100000005000000D619DF1797E854402159C0046E7F4B40D619DF1797E854401615713AC9804B40B5519D0E64EA54401615713AC9804B40B5519D0E64EA54402159C0046E7F4B40D619DF1797E854402159C0046E7F4B40
13399	41185	84.320858000000001	84.355901000000003	54.926124999999999	54.907888999999997	Центральная	0103000020E610000001000000050000003D2AFEEF88145540F6B2EDB435744B403D2AFEEF88145540068195438B764B4047E7FC14C7165540068195438B764B4047E7FC14C7165540F6B2EDB435744B403D2AFEEF88145540F6B2EDB435744B40
16626	49610	84.782961	84.804592	55.265183999999998	55.253655999999999	Новая	0103000020E61000000100000005000000C84274081C3255409337C0CC77A04B40C84274081C32554013B69F8CF1A14B40E3A7716F7E33554013B69F8CF1A14B40E3A7716F7E3355409337C0CC77A04B40C84274081C3255409337C0CC77A04B40
13920	8356	84.768641000000002	84.802166999999997	55.064241000000003	55.044685999999999	Суворова	0103000020E610000001000000050000005857056A31315540664B5645B8854B405857056A31315540FB07910C39884B408CBB41B456335540FB07910C39884B408CBB41B456335540664B5645B8854B405857056A31315540664B5645B8854B40
68382	8550	84.244394	84.271837000000005	55.169874	55.151049999999998	Лесная	0103000020E61000000100000005000000AC55BB26A40F5540C8073D9B55934B40AC55BB26A40F55406938656EBE954B40F03504C7651155406938656EBE954B40F03504C765115540C8073D9B55934B40AC55BB26A40F5540C8073D9B55934B40
13604	7777	84.564041000000003	84.582527999999996	55.177370000000003	55.165503000000001	Озёрная	0103000020E610000001000000050000009A266C3F19245540E831CA332F954B409A266C3F1924554051A5660FB4964B40464085234825554051A5660FB4964B404640852348255540E831CA332F954B409A266C3F19245540E831CA332F954B40
16373	46745	84.126318999999995	84.154329000000004	55.263855	55.250849000000002	Центральная	0103000020E610000001000000050000004277499C15085540FE9DEDD11BA04B404277499C150855406BF12900C6A14B40C3F4BD86E00955406BF12900C6A14B40C3F4BD86E0095540FE9DEDD11BA04B404277499C15085540FE9DEDD11BA04B40
16361	46631	84.597044999999994	84.636454000000001	55.162931	55.145761	Гагарина	0103000020E61000000100000005000000614F3BFC352655402104E44BA8924B40614F3BFC3526554096404AECDA944B4023DA8EA9BB28554096404AECDA944B4023DA8EA9BB2855402104E44BA8924B40614F3BFC352655402104E44BA8924B40
13933	41326	84.446982000000006	84.465271000000001	55.443505999999999	55.433501	Школьная	0103000020E61000000100000005000000A5F9635A9B1C554043E4F4F57CB74B40A5F9635A9B1C554036CAFACDC4B84B40BE310400C71D554036CAFACDC4B84B40BE310400C71D554043E4F4F57CB74B40A5F9635A9B1C554043E4F4F57CB74B40
68738	59170	83.394300000000001	85.087048999999993	55.499499	54.537394999999997	Школьная	0103000020E61000000100000005000000053411363CD954405704FF5BC9444B40053411363CD954403EB14E95EFBF4B409109F835924555403EB14E95EFBF4B409109F835924555405704FF5BC9444B40053411363CD954405704FF5BC9444B40
13608	7493	84.28877	84.308093	55.281174999999998	55.270133000000001	Центральная	0103000020E6100000010000000500000038842A357B1255400249D8B793A24B4038842A357B125540F5B9DA8AFDA34B4019C8B3CBB7135540F5B9DA8AFDA34B4019C8B3CBB71355400249D8B793A24B4038842A357B1255400249D8B793A24B40
67755	44098	83.849108000000001	83.940259999999995	55.142215999999998	55.111851000000001	Юбилейная	0103000020E6100000010000000500000068B114C957F6544030833122518E4B4068B114C957F65440E57B462234924B402A6F47382DFC5440E57B462234924B402A6F47382DFC544030833122518E4B4068B114C957F6544030833122518E4B40
15003	44098	83.849108000000001	83.940259999999995	55.142215999999998	55.111851000000001	Рабочая	0103000020E6100000010000000500000068B114C957F6544030833122518E4B4068B114C957F65440E57B462234924B402A6F47382DFC5440E57B462234924B402A6F47382DFC544030833122518E4B4068B114C957F6544030833122518E4B40
67772	44098	83.849108000000001	83.940259999999995	55.142215999999998	55.111851000000001	Планетная	0103000020E6100000010000000500000068B114C957F6544030833122518E4B4068B114C957F65440E57B462234924B402A6F47382DFC5440E57B462234924B402A6F47382DFC544030833122518E4B4068B114C957F6544030833122518E4B40
13965	41331	83.983109999999996	84.010158000000004	54.966768000000002	54.953059000000003	Садовая	0103000020E61000000100000005000000B7973446EBFE544049145AD6FD794B40B7973446EBFE5440E068C70DBF7B4B40BD72BD6DA6005540E068C70DBF7B4B40BD72BD6DA600554049145AD6FD794B40B7973446EBFE544049145AD6FD794B40
14151	41331	83.983109999999996	84.010158000000004	54.966768000000002	54.953059000000003	Озерная	0103000020E61000000100000005000000B7973446EBFE544049145AD6FD794B40B7973446EBFE5440E068C70DBF7B4B40BD72BD6DA6005540E068C70DBF7B4B40BD72BD6DA600554049145AD6FD794B40B7973446EBFE544049145AD6FD794B40
13406	9279	84.613898000000006	84.631135999999998	55.451900000000002	55.441468999999998	Центральная	0103000020E610000001000000050000001C45D61A4A2755405299620E82B84B401C45D61A4A275540FD87F4DBD7B94B4002D53F8864285540FD87F4DBD7B94B4002D53F88642855405299620E82B84B401C45D61A4A2755405299620E82B84B40
13896	7249	84.359549000000001	84.397268999999994	55.068406000000003	55.049348999999999	Центральная	0103000020E61000000100000005000000CF13CFD9021755408F8B6A1151864B40CF13CFD902175540D36C1E87C1884B40BCADF4DA6C195540D36C1E87C1884B40BCADF4DA6C1955408F8B6A1151864B40CF13CFD9021755408F8B6A1151864B40
15547	6941	83.789019999999994	83.818673000000004	55.160766000000002	55.134219000000002	переулок Центральный	0103000020E61000000100000005000000F4F8BD4D7FF254403CC093162E914B40F4F8BD4D7FF254408527F4FA93944B409147702365F454408527F4FA93944B409147702365F454403CC093162E914B40F4F8BD4D7FF254403CC093162E914B40
16315	46216	84.078169000000003	84.102513999999999	55.159187000000003	55.139282999999999	Центральная	0103000020E61000000100000005000000E8A38CB800055540C3F17C06D4914B40E8A38CB8000555406479573D60944B407558E1968F0655406479573D60944B407558E1968F065540C3F17C06D4914B40E8A38CB800055540C3F17C06D4914B40
16286	47027	84.103960000000001	84.123615000000001	55.024346999999999	55.010798000000001	переулок Школьный	0103000020E61000000100000005000000E605D847A70655405D6E30D461814B40E605D847A7065540BB6070CD1D834B40E292E34EE9075540BB6070CD1D834B40E292E34EE90755405D6E30D461814B40E605D847A70655405D6E30D461814B40
14061	8202	84.789168000000004	84.823510999999996	55.052376000000002	55.036653999999999	Центральная	0103000020E610000001000000050000002FC37FBA8132554040A20914B1844B402FC37FBA81325540338CBB41B4864B405C397B67B4345540338CBB41B4864B405C397B67B434554040A20914B1844B402FC37FBA8132554040A20914B1844B40
68562	4309	75.345304999999996	75.371347	55.341188000000002	55.32244	Комсомольская	0103000020E610000001000000050000004C89247A19D652400C76C3B645A94B404C89247A19D65240D2E4620CACAB4B40EF1D3526C4D75240D2E4620CACAB4B40EF1D3526C4D752400C76C3B645A94B404C89247A19D652400C76C3B645A94B40
68379	4518	75.358654000000001	75.391307999999995	55.479903	55.469197999999999	Школьная	0103000020E610000001000000050000001825E82FF4D652409FAC18AE0EBC4B401825E82FF4D652404B2025766DBD4B4071AAB5300BD952404B2025766DBD4B4071AAB5300BD952409FAC18AE0EBC4B401825E82FF4D652409FAC18AE0EBC4B40
14145	4926	75.635596000000007	75.656031999999996	55.398088999999999	55.390689999999999	Озёрная	0103000020E61000000100000005000000FB5DD89AADE85240E76F422102B24B40FB5DD89AADE85240DCF29194F4B24B404948A46DFCE95240DCF29194F4B24B404948A46DFCE95240E76F422102B24B40FB5DD89AADE85240E76F422102B24B40
13510	3670	75.505348999999995	75.521598999999995	55.233002999999997	55.222431	Центральная	0103000020E610000001000000050000003E0455A357E05240EC4E779E789C4B403E0455A357E05240586FD40AD39D4B4015A8C5E061E15240586FD40AD39D4B4015A8C5E061E15240EC4E779E789C4B403E0455A357E05240EC4E779E789C4B40
14820	43382	75.401342	75.412867000000006	55.149923000000001	55.148189000000002	Школьная	0103000020E61000000100000005000000B8205B96AFD9524040506EDBF7924B40B8205B96AFD9524088F546AD30934B4040A6B5696CDA524088F546AD30934B4040A6B5696CDA524040506EDBF7924B40B8205B96AFD9524040506EDBF7924B40
14011	41354	75.469505999999996	75.494533000000004	55.319893999999998	55.310718999999999	Клубная	0103000020E61000000100000005000000A6D1E4620CDE5240779FE3A3C5A74B40A6D1E4620CDE5240E3175E49F2A84B40BD72BD6DA6DF5240E3175E49F2A84B40BD72BD6DA6DF5240779FE3A3C5A74B40A6D1E4620CDE5240779FE3A3C5A74B40
13842	3197	75.794686999999996	75.821233000000007	55.118220000000001	55.105500999999997	Гагарина	0103000020E610000001000000050000009BE3DC26DCF25240FF58880E818D4B409BE3DC26DCF25240D7DD3CD5218F4B405859DB148FF45240D7DD3CD5218F4B405859DB148FF45240FF58880E818D4B409BE3DC26DCF25240FF58880E818D4B40
68632	49669	75.933629999999994	75.954640999999995	54.881152	54.867263999999999	Молодёжная	0103000020E6100000010000000500000020240B98C0FB5240C37FBA81026F4B4020240B98C0FB52400A67B796C9704B40ED9A90D618FD52400A67B796C9704B40ED9A90D618FD5240C37FBA81026F4B4020240B98C0FB5240C37FBA81026F4B40
14896	43635	75.673675000000003	75.705601000000001	55.007618000000001	54.99823	Центральная	0103000020E610000001000000050000008048BF7D1DEB52406BF12900C67F4B408048BF7D1DEB5240336E6AA0F9804B4098C1189128ED5240336E6AA0F9804B4098C1189128ED52406BF12900C67F4B408048BF7D1DEB52406BF12900C67F4B40
75530	43635	75.673675000000003	75.705601000000001	55.007618000000001	54.99823	Клубная улица	0103000020E610000001000000050000008048BF7D1DEB52406BF12900C67F4B408048BF7D1DEB5240336E6AA0F9804B4098C1189128ED5240336E6AA0F9804B4098C1189128ED52406BF12900C67F4B408048BF7D1DEB52406BF12900C67F4B40
68395	49668	75.989873000000003	76.024637999999996	55.198211000000001	55.183081000000001	Зелёная	0103000020E61000000100000005000000618C48145AFF52406EC2BD326F974B40618C48145AFF52408E5A61FA5E994B40490F43AB930153408E5A61FA5E994B40490F43AB930153406EC2BD326F974B40618C48145AFF52406EC2BD326F974B40
68378	41263	76.168898999999996	76.196799999999996	55.086666999999998	55.068596999999997	Учительская	0103000020E61000000100000005000000EF54C03DCF0A534046CD57C9C7884B40EF54C03DCF0A53403B527DE7178B4B4094F6065F980C53403B527DE7178B4B4094F6065F980C534046CD57C9C7884B40EF54C03DCF0A534046CD57C9C7884B40
13679	41263	76.168898999999996	76.196799999999996	55.086666999999998	55.068596999999997	Большевистская	0103000020E61000000100000005000000EF54C03DCF0A534046CD57C9C7884B40EF54C03DCF0A53403B527DE7178B4B4094F6065F980C53403B527DE7178B4B4094F6065F980C534046CD57C9C7884B40EF54C03DCF0A534046CD57C9C7884B40
13966	1429	75.903509	75.922329000000005	55.362920000000003	55.359169000000001	Надежды	0103000020E6100000010000000500000011A96917D3F95240575EF23FF9AD4B4011A96917D3F952403C889D2974AE4B40C1C9367007FB52403C889D2974AE4B40C1C9367007FB5240575EF23FF9AD4B4011A96917D3F95240575EF23FF9AD4B40
68633	41380	75.502500999999995	75.529927000000001	55.054630000000003	55.04448	Школьная	0103000020E61000000100000005000000444DF4F928E05240BDA94885B1854B40444DF4F928E05240B4B0A71DFE864B401D91EF52EAE15240B4B0A71DFE864B401D91EF52EAE15240BDA94885B1854B40444DF4F928E05240BDA94885B1854B40
68464	41308	75.72372	75.754344000000003	54.824548999999998	54.806792000000002	Ленина	0103000020E6100000010000000500000083DDB06D51EE52405456D3F544674B4083DDB06D51EE5240897956D28A694B40C47B0E2C47F05240897956D28A694B40C47B0E2C47F052405456D3F544674B4083DDB06D51EE52405456D3F544674B40
13812	4133	75.637563	75.648145	55.235748999999998	55.229255000000002	Центральная	0103000020E61000000100000005000000F0880AD5CDE85240E5B8533A589D4B40F0880AD5CDE852404888F2052D9E4B4038842A357BE952404888F2052D9E4B4038842A357BE95240E5B8533A589D4B40F0880AD5CDE85240E5B8533A589D4B40
15950	2515	75.786585000000002	75.806330000000003	54.828122999999998	54.819051000000002	Школьная	0103000020E610000001000000050000008CA19C6857F25240C860C5A9D6684B408CA19C6857F252405F0839EFFF694B4028F224E99AF352405F0839EFFF694B4028F224E99AF35240C860C5A9D6684B408CA19C6857F25240C860C5A9D6684B40
68713	45429	75.716021999999995	75.736243000000002	55.396427000000003	55.385581999999999	площадь Центральная	0103000020E61000000100000005000000DB4DF04DD3ED524090F63FC05AB14B40DB4DF04DD3ED52402E20B41EBEB24B402CBAF59A1EEF52402E20B41EBEB24B402CBAF59A1EEF524090F63FC05AB14B40DB4DF04DD3ED524090F63FC05AB14B40
14004	41348	75.339071000000004	75.364215000000002	55.196012000000003	55.185456000000002	Сухая	0103000020E610000001000000050000006901DA56B3D552406A6CAF05BD974B406901DA56B3D55240D1CFD4EB16994B409C6D6E4C4FD75240D1CFD4EB16994B409C6D6E4C4FD752406A6CAF05BD974B406901DA56B3D552406A6CAF05BD974B40
68714	45547	76.296009999999995	76.312736999999998	55.542946000000001	55.528931	Центральная	0103000020E610000001000000050000007E52EDD3F1125340986BD102B4C34B407E52EDD3F11253403CBF28417FC54B40F2CF0CE2031453403CBF28417FC54B40F2CF0CE203145340986BD102B4C34B407E52EDD3F1125340986BD102B4C34B40
16593	5057	76.115421999999995	76.131708000000003	55.486682999999999	55.473551	Зеленая	0103000020E610000001000000050000004ACFF412630753407AFEB4519DBC4B404ACFF412630753407442E8A04BBE4B40C82764E76D0853407442E8A04BBE4B40C82764E76D0853407AFEB4519DBC4B404ACFF412630753407AFEB4519DBC4B40
75577	60695	76.310355999999999	76.331070999999994	55.468100999999997	55.460614	Центральная 	0103000020E61000000100000005000000838769DFDC135340350A4966F5BA4B40838769DFDC135340C91CCBBBEABB4B40DB696B4430155340C91CCBBBEABB4B40DB696B4430155340350A4966F5BA4B40838769DFDC135340350A4966F5BA4B40
68634	49671	75.684725	75.707927999999995	55.241149	55.231380000000001	Приозёрная	0103000020E610000001000000050000003B70CE88D2EB524068791EDC9D9D4B403B70CE88D2EB5240473B6EF8DD9E4B400DFB3DB14EED5240473B6EF8DD9E4B400DFB3DB14EED524068791EDC9D9D4B403B70CE88D2EB524068791EDC9D9D4B40
15732	45924	76.056358000000003	76.079040000000006	55.261988000000002	55.251080000000002	Гагарина	0103000020E610000001000000050000008DB7955E9B0353400057B26323A04B408DB7955E9B035340E4F8A1D288A14B40DBC4C9FD0E055340E4F8A1D288A14B40DBC4C9FD0E0553400057B26323A04B408DB7955E9B0353400057B26323A04B40
14178	41386	75.872967000000003	75.886827999999994	54.879494999999999	54.874212	Центральная	0103000020E610000001000000050000002FDFFAB0DEF75240A8E2C62DE66F4B402FDFFAB0DEF752406DFFCA4A93704B40554B3ACAC1F852406DFFCA4A93704B40554B3ACAC1F85240A8E2C62DE66F4B402FDFFAB0DEF75240A8E2C62DE66F4B40
14191	4800	75.858054999999993	75.890466000000004	55.515858999999999	55.502222000000003	Школьная	0103000020E61000000100000005000000D5CA845FEAF6524076AA7CCF48C04B40D5CA845FEAF65240732CEFAA07C24B40CC0C1B65FDF85240732CEFAA07C24B40CC0C1B65FDF8524076AA7CCF48C04B40D5CA845FEAF6524076AA7CCF48C04B40
13457	1952	76.039703000000003	76.066410000000005	55.036169000000001	55.026515000000003	Мира	0103000020E6100000010000000500000066A3737E8A0253403EEDF0D764834B4066A3737E8A0253408410902FA1844B402788BA0F400453408410902FA1844B402788BA0F400453403EEDF0D764834B4066A3737E8A0253403EEDF0D764834B40
68441	49670	75.513092	75.536771999999999	54.857019999999999	54.842595000000003	Ленина	0103000020E61000000100000005000000B6F5D37FD6E05240F6622827DA6B4B40B6F5D37FD6E052404B02D4D4B26D4B40255AF2785AE252404B02D4D4B26D4B40255AF2785AE25240F6622827DA6B4B40B6F5D37FD6E05240F6622827DA6B4B40
13996	41344	75.684265999999994	75.696905999999998	55.087784999999997	55.078958	Школьная	0103000020E61000000100000005000000F1F09E03CBEB5240F8E0B54B1B8A4B40F1F09E03CBEB5240280AF4893C8B4B40B7989F1B9AEC5240280AF4893C8B4B40B7989F1B9AEC5240F8E0B54B1B8A4B40F1F09E03CBEB5240F8E0B54B1B8A4B40
68342	41353	75.591155999999998	75.616453000000007	55.172300999999997	55.156357999999997	Школьная	0103000020E6100000010000000500000063B5F97FD5E55240E63BF88903944B4063B5F97FD5E55240B7088CF50D964B405AA148F773E75240B7088CF50D964B405AA148F773E75240E63BF88903944B4063B5F97FD5E55240E63BF88903944B40
13392	41183	75.796735999999996	75.824349999999995	54.958689	54.948711000000003	Рыбака	0103000020E61000000100000005000000EFE2FDB8FDF25240802DAF5C6F794B40EFE2FDB8FDF2524079043752B67A4B40499D8026C2F4524079043752B67A4B40499D8026C2F45240802DAF5C6F794B40EFE2FDB8FDF25240802DAF5C6F794B40
13476	41206	75.901111	75.914845999999997	54.838825999999997	54.828693000000001	 Сибирская	0103000020E6100000010000000500000037C478CDABF952404AB6BA9C126A4B4037C478CDABF952406A847EA65E6B4B4017B83CD68CFA52406A847EA65E6B4B4017B83CD68CFA52404AB6BA9C126A4B4037C478CDABF952404AB6BA9C126A4B40
13495	3301	75.906519000000003	75.91516	55.088352	55.082256000000001	Школьная	0103000020E61000000100000005000000F88C446804FA52402CF3565D878A4B40F88C446804FA5240A2444B1E4F8B4B40DFA63FFB91FA5240A2444B1E4F8B4B40DFA63FFB91FA52402CF3565D878A4B40F88C446804FA52402CF3565D878A4B40
13985	2854	75.508860999999996	75.531058999999999	54.961941000000003	54.956839000000002	Зеленая	0103000020E610000001000000050000006E4DBA2D91E05240C8444AB3797A4B406E4DBA2D91E052403DD7F7E1207B4B40C64FE3DEFCE152403DD7F7E1207B4B40C64FE3DEFCE15240C8444AB3797A4B406E4DBA2D91E05240C8444AB3797A4B40
13973	41334	76.204373000000004	76.224423000000002	55.319023000000001	55.316062000000002	Мира	0103000020E61000000100000005000000DECB7D72140D534012C138B874A84B40DECB7D72140D5340FED5E3BED5A84B40185E49F25C0E5340FED5E3BED5A84B40185E49F25C0E534012C138B874A84B40DECB7D72140D534012C138B874A84B40
81082	62069	81.714889999999997	83.047469000000007	54.409399000000001	53.494301999999998	Новая 	0103000020E61000000100000005000000328FFCC1C06D5440772CB64945BF4A40328FFCC1C06D5440EF01BA2F67344B40BAA46ABB09C35440EF01BA2F67344B40BAA46ABB09C35440772CB64945BF4A40328FFCC1C06D5440772CB64945BF4A40
15707	46433	82.593658000000005	82.601680000000002	53.971826	53.963923999999999	Центральная	0103000020E6100000010000000500000090C01F7EFEA554402DEA93DC61FB4A4090C01F7EFEA5544085B35BCB64FC4A4011AAD4EC81A6544085B35BCB64FC4A4011AAD4EC81A654402DEA93DC61FB4A4090C01F7EFEA554402DEA93DC61FB4A40
13451	869	82.510609000000002	82.550279000000003	54.274597	54.25949	Советская	0103000020E61000000100000005000000C5025FD1ADA05440CCD1E3F736214B40C5025FD1ADA05440344A97FE25234B403D2B69C537A35440344A97FE25234B403D2B69C537A35440CCD1E3F736214B40C5025FD1ADA05440CCD1E3F736214B40
16529	260	81.774124999999998	81.808961999999994	54.018098999999999	54.005321000000002	Выглазова	0103000020E61000000100000005000000068195438B715440B37DC85BAE004B40068195438B7154408F8B6A1151024B403B6D8D08C67354408F8B6A1151024B403B6D8D08C6735440B37DC85BAE004B40068195438B715440B37DC85BAE004B40
13415	32261	81.839083000000002	81.853589999999997	53.775606000000003	53.765360999999999	Полевая	0103000020E610000001000000050000004BE82E89B375544022516859F7E14A404BE82E89B37554406B4AB20E47E34A40548CF337A17654406B4AB20E47E34A40548CF337A176544022516859F7E14A404BE82E89B375544022516859F7E14A40
15616	31459	82.276157999999995	82.348130999999995	53.822735000000002	53.762695000000001	Строительная	0103000020E61000000100000005000000D7A19A92AC9154404FE960FD9FE14A40D7A19A92AC915440252367614FE94A4052EE3EC747965440252367614FE94A4052EE3EC7479654404FE960FD9FE14A40D7A19A92AC9154404FE960FD9FE14A40
15639	31459	82.276157999999995	82.348130999999995	53.822735000000002	53.762695000000001	Партизанская	0103000020E61000000100000005000000D7A19A92AC9154404FE960FD9FE14A40D7A19A92AC915440252367614FE94A4052EE3EC747965440252367614FE94A4052EE3EC7479654404FE960FD9FE14A40D7A19A92AC9154404FE960FD9FE14A40
16444	31459	82.276157999999995	82.348130999999995	53.822735000000002	53.762695000000001	Молодежная	0103000020E61000000100000005000000D7A19A92AC9154404FE960FD9FE14A40D7A19A92AC915440252367614FE94A4052EE3EC747965440252367614FE94A4052EE3EC7479654404FE960FD9FE14A40D7A19A92AC9154404FE960FD9FE14A40
13778	31459	82.276157999999995	82.348130999999995	53.822735000000002	53.762695000000001	Ленина	0103000020E61000000100000005000000D7A19A92AC9154404FE960FD9FE14A40D7A19A92AC915440252367614FE94A4052EE3EC747965440252367614FE94A4052EE3EC7479654404FE960FD9FE14A40D7A19A92AC9154404FE960FD9FE14A40
13435	915	82.442930000000004	82.466807000000003	54.217357	54.204566999999997	Молодёжная	0103000020E61000000100000005000000B51A12F7589C5440A06B5F402F1A4B40B51A12F7589C54404147AB5AD21B4B40CFA2772AE09D54404147AB5AD21B4B40CFA2772AE09D5440A06B5F402F1A4B40B51A12F7589C5440A06B5F402F1A4B40
13972	41333	82.440450999999996	82.456001000000001	53.807042000000003	53.800739999999998	Лесниковская	0103000020E61000000100000005000000641F6459309C5440AD4CF8A57EE64A40641F6459309C5440CD3FFA264DE74A405F7CD11E2F9D5440CD3FFA264DE74A405F7CD11E2F9D5440AD4CF8A57EE64A40641F6459309C5440AD4CF8A57EE64A40
14127	31842	82.386938000000001	82.409737000000007	53.585445999999997	53.566054000000001	Чкалова	0103000020E6100000010000000500000019E59997C39854408FE21C7574C84A4019E59997C398544079C9FFE4EFCA4A4084BD8921399A544079C9FFE4EFCA4A4084BD8921399A54408FE21C7574C84A4019E59997C39854408FE21C7574C84A40
14140	1016	82.421396999999999	82.450018	54.327620000000003	54.307972999999997	Центральная	0103000020E610000001000000050000007B681F2BF89A54408786C5A86B274B407B681F2BF89A5440FDC1C073EF294B4020274C18CD9C5440FDC1C073EF294B4020274C18CD9C54408786C5A86B274B407B681F2BF89A54408786C5A86B274B40
13444	32153	82.040754000000007	82.080262000000005	53.747532999999997	53.736663999999998	Центральная	0103000020E61000000100000005000000994BAAB69B825440FD1186014BDE4A40994BAAB69B82544023D74D29AFDF4A4024473A032385544023D74D29AFDF4A4024473A0323855440FD1186014BDE4A40994BAAB69B825440FD1186014BDE4A40
14682	32153	82.040754000000007	82.080262000000005	53.747532999999997	53.736663999999998	Озерная	0103000020E61000000100000005000000994BAAB69B825440FD1186014BDE4A40994BAAB69B82544023D74D29AFDF4A4024473A032385544023D74D29AFDF4A4024473A0323855440FD1186014BDE4A40994BAAB69B825440FD1186014BDE4A40
13940	31901	82.351185000000001	82.372439	53.597664000000002	53.589792000000003	Рабочая	0103000020E610000001000000050000002176A6D079965440A2B8E34D7ECB4A402176A6D0799654408FFF024180CC4A405130630AD69754408FFF024180CC4A405130630AD6975440A2B8E34D7ECB4A402176A6D079965440A2B8E34D7ECB4A40
14131	32447	82.032139999999998	82.054175000000001	53.869199999999999	53.860624000000001	Центральная	0103000020E610000001000000050000002E39EE940E8254408C135FED28EE4A402E39EE940E82544073D712F241EF4A40B1506B9A7783544073D712F241EF4A40B1506B9A778354408C135FED28EE4A402E39EE940E8254408C135FED28EE4A40
13791	32016	82.269591000000005	82.316663000000005	53.690835	53.672435999999998	Мира	0103000020E61000000100000005000000F1129CFA409154409753026212D64A40F1129CFA4091544051F701486DD84A409C36E3344494544051F701486DD84A409C36E334449454409753026212D64A40F1129CFA409154409753026212D64A40
13807	625	82.247581999999994	82.276436000000004	54.038350000000001	54.017764999999997	Центральная	0103000020E6100000010000000500000002452C62D88F5440B8019F1F46024B4002452C62D88F54409BE61DA7E8044B40F9DB9E20B19154409BE61DA7E8044B40F9DB9E20B1915440B8019F1F46024B4002452C62D88F5440B8019F1F46024B40
13809	503	82.249450999999993	82.296091000000004	54.213124000000001	54.189835000000002	Ленина	0103000020E6100000010000000500000016BD5301F78F54406E5166834C184B4016BD5301F78F544011FFB0A5471B4B40F568AA27F392544011FFB0A5471B4B40F568AA27F39254406E5166834C184B4016BD5301F78F54406E5166834C184B40
16620	49608	77.709418999999997	77.724709000000004	56.284323999999998	56.273584999999997	Красная	0103000020E610000001000000050000004E0AF31E676D53408CD651D504234C404E0AF31E676D5340E4BB94BA64244C407B87DBA1616E5340E4BB94BA64244C407B87DBA1616E53408CD651D504234C404E0AF31E676D53408CD651D504234C40
13782	31182	78.797279000000003	78.831756999999996	56.403830999999997	56.393279999999997	Советская	0103000020E6100000010000000500000068B27F9E06B35340DF15C1FF56324C4068B27F9E06B35340340EF5BBB0334C40054EB6813BB55340340EF5BBB0334C40054EB6813BB55340DF15C1FF56324C4068B27F9E06B35340DF15C1FF56324C40
13389	31123	78.535932000000003	78.564687000000006	56.328349000000003	56.317816999999998	Советская	0103000020E610000001000000050000005038BBB54CA25340718E3A3AAE284C405038BBB54CA2534050560C57072A4C407D5EF1D423A4534050560C57072A4C407D5EF1D423A45340718E3A3AAE284C405038BBB54CA25340718E3A3AAE284C40
68630	31075	78.821363000000005	78.853622000000001	56.082416000000002	56.067498999999998	Центральная	0103000020E610000001000000050000003FC91D3691B45340A0C1A6CEA3084C403FC91D3691B453406555849B8C0A4C405A492BBEA1B653406555849B8C0A4C405A492BBEA1B65340A0C1A6CEA3084C403FC91D3691B45340A0C1A6CEA3084C40
13768	30796	78.437297000000001	78.455038999999999	55.898856000000002	55.887977999999997	Центральная	0103000020E61000000100000005000000E4688EACFC9B5340A3C85A43A9F14B40E4688EACFC9B53401DE8A1B60DF34B40E4D9E55B1F9D53401DE8A1B60DF34B40E4D9E55B1F9D5340A3C85A43A9F14B40E4688EACFC9B5340A3C85A43A9F14B40
13385	30881	78.320238000000003	78.387682999999996	56.361274999999999	56.332656	Ленина	0103000020E61000000100000005000000EF3B86C77E945340BA68C878942A4C40EF3B86C77E94534063EE5A423E2E4C40C58D5BCCCF98534063EE5A423E2E4C40C58D5BCCCF985340BA68C878942A4C40EF3B86C77E945340BA68C878942A4C40
13410	30977	78.248894000000007	78.278223999999994	56.729925999999999	56.716403	Зеленая	0103000020E61000000100000005000000EC8A19E1ED8F5340CEE0EF17B35B4C40EC8A19E1ED8F5340034015376E5D4C40963D096CCE915340034015376E5D4C40963D096CCE915340CEE0EF17B35B4C40EC8A19E1ED8F5340CEE0EF17B35B4C40
15583	45957	77.286996000000002	80.555749000000006	57.112099000000001	55.727297999999998	Набережная	0103000020E610000001000000050000004D8578245E5253401D39D21918DD4B404D8578245E52534008759142598E4C4039F240649123544008759142598E4C4039F24064912354401D39D21918DD4B404D8578245E5253401D39D21918DD4B40
14165	41383	78.840057000000002	78.850549000000001	56.349330000000002	56.344441000000003	Центральная	0103000020E61000000100000005000000A8716F7EC3B55340663387A4162C4C40A8716F7EC3B553407FC16ED8B62C4C4050A912656FB653407FC16ED8B62C4C4050A912656FB65340663387A4162C4C40A8716F7EC3B55340663387A4162C4C40
13394	31143	78.403709000000006	78.426410000000004	56.306562999999997	56.293326999999998	Центральная	0103000020E610000001000000050000007506465ED6995340530438BD8B254C407506465ED6995340F294D5743D274C40FE2B2B4D4A9B5340F294D5743D274C40FE2B2B4D4A9B5340530438BD8B254C407506465ED6995340530438BD8B254C40
14143	31344	78.213419000000002	78.230829	56.612454	56.599423999999999	Веселая	0103000020E6100000010000000500000015562AA8A88D53400038F6ECB94C4C4015562AA8A88D5340F62686E4644E4C40FA7DFFE6C58E5340F62686E4644E4C40FA7DFFE6C58E53400038F6ECB94C4C4015562AA8A88D53400038F6ECB94C4C40
13621	31282	78.288375000000002	78.310123000000004	56.605964999999998	56.583485000000003	Бугаева	0103000020E61000000100000005000000FA7E6ABC74925340715AF0A2AF4A4C40FA7E6ABC74925340A4C2D842904D4C4032AF230ED9935340A4C2D842904D4C4032AF230ED9935340715AF0A2AF4A4C40FA7E6ABC74925340715AF0A2AF4A4C40
16547	30568	78.463277000000005	78.498553000000001	56.612473999999999	56.601757999999997	Гагарина	0103000020E610000001000000050000004CFF9254A69D53409D0DF967064D4C404CFF9254A69D53403DD34B8C654E4C40A794D74AE89F53403DD34B8C654E4C40A794D74AE89F53409D0DF967064D4C404CFF9254A69D53409D0DF967064D4C40
13907	14944	77.723073999999997	77.736917000000005	56.316578999999997	56.312004999999999	Сибирская	0103000020E61000000100000005000000A0A52BD8466E53402098A3C7EF274C40A0A52BD8466E5340D9CC21A985284C4074B7EBA5296F5340D9CC21A985284C4074B7EBA5296F53402098A3C7EF274C40A0A52BD8466E53402098A3C7EF274C40
16629	49614	81.580431000000004	81.657910000000001	54.132503999999997	54.118516	Школьная	0103000020E610000001000000050000006AA510C825655440C00644882B0F4B406AA510C8256554406A4B1DE4F5104B40876D8B321B6A54406A4B1DE4F5104B40876D8B321B6A5440C00644882B0F4B406AA510C825655440C00644882B0F4B40
13770	28810	81.923398000000006	82.454787999999994	54.383468000000001	54.362904	Ильича	0103000020E6100000010000000500000047CCECF3187B544036CB65A3732E4B4047CCECF3187B54400188BB7A15314B403FA7203F1B9D54400188BB7A15314B403FA7203F1B9D544036CB65A3732E4B4047CCECF3187B544036CB65A3732E4B40
14892	29593	81.489243000000002	81.504469	54.219788999999999	54.211754999999997	Садовая	0103000020E610000001000000050000000133DFC14F5F5440DAE1AFC91A1B4B400133DFC14F5F5440A182C30B221C4B402236583849605440A182C30B221C4B402236583849605440DAE1AFC91A1B4B400133DFC14F5F5440DAE1AFC91A1B4B40
13756	29699	81.510191000000006	81.540177	54.326490999999997	54.309396	Советская	0103000020E61000000100000005000000ABED26F8A6605440B1C1C2499A274B40ABED26F8A66054401BB80375CA294B404A438D42926254401BB80375CA294B404A438D4292625440B1C1C2499A274B40ABED26F8A6605440B1C1C2499A274B40
14929	29965	81.285801000000006	81.344515000000001	54.189734999999999	54.175218000000001	Школьная	0103000020E61000000100000005000000810A47904A525440D4D51D8B6D164B40810A47904A5254400AF4893C49184B40D07EA4880C5654400AF4893C49184B40D07EA4880C565440D4D51D8B6D164B40810A47904A525440D4D51D8B6D164B40
14924	29889	81.437023999999994	81.458331999999999	54.102353000000001	54.097000000000001	Кириллова	0103000020E610000001000000050000004BE48233F85B544023DBF97E6A0C4B404BE48233F85B5440E1D231E7190D4B4075ADBD4F555D5440E1D231E7190D4B4075ADBD4F555D544023DBF97E6A0C4B404BE48233F85B544023DBF97E6A0C4B40
68975	29184	82.100160000000002	82.116060000000004	54.69699	54.688462000000001	Школьная	0103000020E6100000010000000500000083177D0569865440F644D7851F584B4083177D0569865440CCD1E3F736594B40EC17EC866D875440CCD1E3F736594B40EC17EC866D875440F644D7851F584B4083177D0569865440F644D7851F584B40
14919	29873	81.529747999999998	81.585038999999995	54.146023	54.122183	Ленина	0103000020E61000000100000005000000C5C72764E761544047904AB1A30F4B40C5C72764E76154405EBBB4E1B0124B409CF86A47716554405EBBB4E1B0124B409CF86A477165544047904AB1A30F4B40C5C72764E761544047904AB1A30F4B40
14063	29686	81.575875999999994	81.611997000000002	54.354734999999998	54.336933000000002	Советская	0103000020E6100000010000000500000048A30227DB645440BAF8DB9E202B4B4048A30227DB6454408FDFDBF4672D4B40021077F52A6754408FDFDBF4672D4B40021077F52A675440BAF8DB9E202B4B4048A30227DB645440BAF8DB9E202B4B40
14075	28601	81.846197000000004	81.944643999999997	54.374741999999998	54.342759000000001	Пушкина	0103000020E610000001000000050000004B3E76172876544070B4E386DF2B4B404B3E7617287654400438BD8BF72F4B4035971B0C757C54400438BD8BF72F4B4035971B0C757C544070B4E386DF2B4B404B3E76172876544070B4E386DF2B4B40
14457	28601	81.846197000000004	81.944643999999997	54.374741999999998	54.342759000000001	Октябрьская	0103000020E610000001000000050000004B3E76172876544070B4E386DF2B4B404B3E7617287654400438BD8BF72F4B4035971B0C757C54400438BD8BF72F4B4035971B0C757C544070B4E386DF2B4B404B3E76172876544070B4E386DF2B4B40
13746	28601	81.846197000000004	81.944643999999997	54.374741999999998	54.342759000000001	Западная	0103000020E610000001000000050000004B3E76172876544070B4E386DF2B4B404B3E7617287654400438BD8BF72F4B4035971B0C757C54400438BD8BF72F4B4035971B0C757C544070B4E386DF2B4B404B3E76172876544070B4E386DF2B4B40
13583	29368	82.021790999999993	82.062771999999995	54.423276999999999	54.405526000000002	Мира	0103000020E610000001000000050000003716140665815440BFD6A546E8334B4037161406658154401213D4F02D364B40B0C6D974048454401213D4F02D364B40B0C6D97404845440BFD6A546E8334B403716140665815440BFD6A546E8334B40
14058	30072	81.151386000000002	81.185261999999994	54.134624000000002	54.125929999999997	Центральная	0103000020E61000000100000005000000A0C4E74EB0495440EACA67791E104B40A0C4E74EB0495440DCA0F65B3B114B4042CC2555DB4B5440DCA0F65B3B114B4042CC2555DB4B5440EACA67791E104B40A0C4E74EB0495440EACA67791E104B40
14056	30263	81.542612000000005	81.561818000000002	54.097507	54.089036999999998	Береговая	0103000020E61000000100000005000000B39AAE27BA62544025917D90650B4B40B39AAE27BA625440C710001C7B0C4B4077137CD3F4635440C710001C7B0C4B4077137CD3F463544025917D90650B4B40B39AAE27BA62544025917D90650B4B40
14039	29113	81.878905000000003	81.905485999999996	54.543709999999997	54.531022	Центральная	0103000020E610000001000000050000009ED2C1FA3F7854406FBA6587F8434B409ED2C1FA3F7854400B410E4A98454B40183F8D7BF37954400B410E4A98454B40183F8D7BF37954406FBA6587F8434B409ED2C1FA3F7854406FBA6587F8434B40
16581	29239	81.925535999999994	81.953554999999994	54.662166999999997	54.638361000000003	Молодежная	0103000020E6100000010000000500000052D158FB3B7B54405C0531D0B5514B4052D158FB3B7B5440C6BE64E3C1544B40FCFB8C0B077D5440C6BE64E3C1544B40FCFB8C0B077D54405C0531D0B5514B4052D158FB3B7B54405C0531D0B5514B40
14084	28875	82.206789999999998	82.260985000000005	54.589717	54.557527	Кандикова	0103000020E61000000100000005000000F3C81F0C3C8D544089D1730B5D474B40F3C81F0C3C8D54409772BED87B4B4B40C8EF6DFAB39054409772BED87B4B4B40C8EF6DFAB390544089D1730B5D474B40F3C81F0C3C8D544089D1730B5D474B40
13749	28791	81.839217000000005	81.881051999999997	54.374710999999998	54.358669999999996	Космонавтов	0103000020E61000000100000005000000D34F38BBB5755440350708E6E82D4B40D34F38BBB5755440C939B187F62F4B40D384ED2763785440C939B187F62F4B40D384ED2763785440350708E6E82D4B40D34F38BBB5755440350708E6E82D4B40
13893	29482	81.697185000000005	81.708359999999999	54.476191	54.469451999999997	Центральная	0103000020E61000000100000005000000C190D5AD9E6C54405985CD00173C4B40C190D5AD9E6C544024D3A1D3F33C4B40DA722EC5556D544024D3A1D3F33C4B40DA722EC5556D54405985CD00173C4B40C190D5AD9E6C54405985CD00173C4B40
75546	60678	82.043897999999999	82.068144000000004	54.615870999999999	54.603180000000002	Центральная	0103000020E6100000010000000500000007978E39CF825440F7CC9200354D4B4007978E39CF82544004C765DCD44E4B40CBDAA6785C84544004C765DCD44E4B40CBDAA6785C845440F7CC9200354D4B4007978E39CF825440F7CC9200354D4B40
16566	27929	82.579527999999996	82.622844999999998	54.817338999999997	54.795223999999997	Подгорбунского	0103000020E6100000010000000500000071C79BFC16A55440457F68E6C9654B4071C79BFC16A55440675F79909E684B40895E46B1DCA75440675F79909E684B40895E46B1DCA75440457F68E6C9654B4071C79BFC16A55440457F68E6C9654B40
14152	25300	82.936877999999993	82.958509000000006	54.917841000000003	54.908811	Минеральная	0103000020E61000000100000005000000E19524CFF5BB54405E9F39EB53744B40E19524CFF5BB5440C7F65AD07B754B40FDFA213658BD5440C7F65AD07B754B40FDFA213658BD54405E9F39EB53744B40E19524CFF5BB54405E9F39EB53744B40
14192	27451	82.825298000000004	82.848635999999999	54.923279000000001	54.901972999999998	Академика Першилина	0103000020E6100000010000000500000012DDB3AED1B454400070ECD973734B4012DDB3AED1B45440B30A9B012E764B40548D5E0D50B65440B30A9B012E764B40548D5E0D50B654400070ECD973734B4012DDB3AED1B454400070ECD973734B40
13953	28070	82.664023	82.755688000000006	54.994486000000002	54.972659	Олега Кошевого	0103000020E61000000100000005000000AD32535A7FAA54407D941117807C4B40AD32535A7FAA5440392A37514B7F4B40B37E33315DB05440392A37514B7F4B40B37E33315DB054407D941117807C4B40AD32535A7FAA54407D941117807C4B40
13711	26742	83.057674000000006	83.074445999999995	55.237772	55.229840000000003	Центральная	0103000020E6100000010000000500000017F549EEB0C3544005A8A9656B9D4B4017F549EEB0C35440C7F319506F9E4B405AD427B9C3C45440C7F319506F9E4B405AD427B9C3C4544005A8A9656B9D4B4017F549EEB0C3544005A8A9656B9D4B40
68330	26704	82.936186000000006	82.957153000000005	55.242046999999999	55.228875000000002	Школьная	0103000020E61000000100000005000000473EAF78EABB54409EEFA7C64B9D4B40473EAF78EABB5440268C6665FB9E4B402C11A8FE41BD5440268C6665FB9E4B402C11A8FE41BD54409EEFA7C64B9D4B40473EAF78EABB54409EEFA7C64B9D4B40
13852	26704	82.936186000000006	82.957153000000005	55.242046999999999	55.228875000000002	Центральная	0103000020E61000000100000005000000473EAF78EABB54409EEFA7C64B9D4B40473EAF78EABB5440268C6665FB9E4B402C11A8FE41BD5440268C6665FB9E4B402C11A8FE41BD54409EEFA7C64B9D4B40473EAF78EABB54409EEFA7C64B9D4B40
16644	49619	83.109031000000002	83.120772000000002	55.131171999999999	55.127116000000001	Береговая	0103000020E6100000010000000500000003D0285DFAC6544030664B5645904B4003D0285DFAC6544051137D3ECA904B4071917BBABAC7544051137D3ECA904B4071917BBABAC7544030664B5645904B4003D0285DFAC6544030664B5645904B40
13737	28321	82.439048999999997	82.477712999999994	54.847482999999997	54.837845999999999	Строителей	0103000020E61000000100000005000000DB15FA60199C5440CE8AA8893E6B4B40DB15FA60199C54403E75AC527A6C4B40F0F78BD9929E54403E75AC527A6C4B40F0F78BD9929E5440CE8AA8893E6B4B40DB15FA60199C5440CE8AA8893E6B4B40
68314	59137	83.215248000000003	83.347048999999998	55.020363000000003	54.944564	Совхозная	0103000020E61000000100000005000000E2218C9FC6CD54404E7D2079E7784B40E2218C9FC6CD5440348639419B824B400247020D36D65440348639419B824B400247020D36D654404E7D2079E7784B40E2218C9FC6CD54404E7D2079E7784B40
13708	26535	83.110369000000006	83.146006	55.063395	55.051690000000001	Ленина	0103000020E61000000100000005000000815F234910C75440DFC325C79D864B40815F234910C754406EDDCD531D884B4044C18C2958C954406EDDCD531D884B4044C18C2958C95440DFC325C79D864B40815F234910C75440DFC325C79D864B40
68617	27050	83.098341000000005	83.133105999999998	55.167966	55.149954000000001	Первомайская	0103000020E61000000100000005000000C8B60C384BC65440C3F352B131934B40C8B60C384BC65440836BEEE87F954B40B03907CF84C85440836BEEE87F954B40B03907CF84C85440C3F352B131934B40C8B60C384BC65440C3F352B131934B40
13727	27050	83.098341000000005	83.133105999999998	55.167966	55.149954000000001	Линейная	0103000020E61000000100000005000000C8B60C384BC65440C3F352B131934B40C8B60C384BC65440836BEEE87F954B40B03907CF84C85440836BEEE87F954B40B03907CF84C85440C3F352B131934B40C8B60C384BC65440C3F352B131934B40
13882	41316	83.440374000000006	83.467549000000005	55.078988000000003	55.068747000000002	Зеленая	0103000020E610000001000000050000008F006E162FDC54405C59A2B3CC884B408F006E162FDC544063635E471C8A4B40C311A452ECDD544063635E471C8A4B40C311A452ECDD54405C59A2B3CC884B408F006E162FDC54405C59A2B3CC884B40
13829	25341	82.830948000000006	82.876816000000005	54.828195000000001	54.809691999999998	Ленина	0103000020E610000001000000050000004E2B85402EB554409AEAC9FCA3674B404E2B85402EB55440F9DA334B026A4B400327DBC01DB85440F9DA334B026A4B400327DBC01DB854409AEAC9FCA3674B404E2B85402EB554409AEAC9FCA3674B40
68385	59141	82.761921999999998	82.781164000000004	55.118385000000004	55.089691000000002	Октябрьская 	0103000020E6100000010000000500000096067E54C3B054406EDFA3FE7A8B4B4096067E54C3B0544022AB5B3D278F4B4001344A97FEB1544022AB5B3D278F4B4001344A97FEB154406EDFA3FE7A8B4B4096067E54C3B054406EDFA3FE7A8B4B40
13534	27351	82.729708000000002	82.747549000000006	54.835284000000001	54.825473000000002	Степная	0103000020E610000001000000050000004BE82E89B3AE5440925D6919A9694B404BE82E89B3AE5440A06F0B96EA6A4B4015CAC2D7D7AF5440A06F0B96EA6A4B4015CAC2D7D7AF5440925D6919A9694B404BE82E89B3AE5440925D6919A9694B40
13642	27503	82.808913000000004	82.818938000000003	54.934851999999999	54.922322000000001	Советская	0103000020E61000000100000005000000CB13083BC5B35440CF30B5A50E764B40CB13083BC5B35440D34CF73AA9774B40E8DCED7A69B45440D34CF73AA9774B40E8DCED7A69B45440CF30B5A50E764B40CB13083BC5B35440CF30B5A50E764B40
13729	28210	82.509747000000004	82.529330000000002	54.998730999999999	54.990602000000003	Школьная	0103000020E61000000100000005000000FC8EE1B19FA0544015ADDC0BCC7E4B40FC8EE1B19FA054402D40DB6AD67F4B40ABB2EF8AE0A154402D40DB6AD67F4B40ABB2EF8AE0A1544015ADDC0BCC7E4B40FC8EE1B19FA0544015ADDC0BCC7E4B40
67752	28145	82.693425000000005	82.710628	54.976756999999999	54.965702999999998	Мира	0103000020E61000000100000005000000A54E401361AC54401553E9279C7B4B40A54E401361AC5440CD91955F067D4B40CDE7DCED7AAD5440CD91955F067D4B40CDE7DCED7AAD54401553E9279C7B4B40A54E401361AC54401553E9279C7B4B40
13672	26378	83.225120000000004	83.252330000000001	54.995054000000003	54.980963000000003	Школьный переулок	0103000020E610000001000000050000003C6BB75D68CE544004CB1132907D4B403C6BB75D68CE544083E0F1ED5D7F4B402E73BA2C26D0544083E0F1ED5D7F4B402E73BA2C26D0544004CB1132907D4B403C6BB75D68CE544004CB1132907D4B40
16552	26378	83.225120000000004	83.252330000000001	54.995054000000003	54.980963000000003	Лесная	0103000020E610000001000000050000003C6BB75D68CE544004CB1132907D4B403C6BB75D68CE544083E0F1ED5D7F4B402E73BA2C26D0544083E0F1ED5D7F4B402E73BA2C26D0544004CB1132907D4B403C6BB75D68CE544004CB1132907D4B40
75552	60680	82.885153000000003	82.894216999999998	55.299973000000001	55.293908999999999	Береговая	0103000020E6100000010000000500000034BDC458A6B85440028063CF9EA54B4034BDC458A6B854406D57E88365A64B40BEA1F0D93AB954406D57E88365A64B40BEA1F0D93AB95440028063CF9EA54B4034BDC458A6B85440028063CF9EA54B40
14000	26596	83.222057000000007	83.254064	55.074922000000001	55.062421000000001	Центральная	0103000020E610000001000000050000004436902E36CE5440B4CA4C69FD874B404436902E36CE54401EE0490B97894B40D2C5A69542D054401EE0490B97894B40D2C5A69542D05440B4CA4C69FD874B404436902E36CE5440B4CA4C69FD874B40
75566	60689	82.904591999999994	82.928200000000004	54.837369000000002	54.830782999999997	м/район Сибирский	0103000020E61000000100000005000000490ED8D5E4B954405089EB18576A4B40490ED8D5E4B9544095D74AE82E6B4B406C09F9A067BB544095D74AE82E6B4B406C09F9A067BB54405089EB18576A4B40490ED8D5E4B954405089EB18576A4B40
13479	26032	83.039806999999996	83.061744000000004	55.089922999999999	55.077075999999998	Титова	0103000020E61000000100000005000000B8C9A8328CC254403BA759A0DD894B40B8C9A8328CC254404014CC98828B4B405A2E1B9DF3C354404014CC98828B4B405A2E1B9DF3C354403BA759A0DD894B40B8C9A8328CC254403BA759A0DD894B40
13527	27228	83.097352999999998	83.113180999999997	55.138629000000002	55.131393000000003	Центральная	0103000020E61000000100000005000000B8CA13083BC6544030F65E7CD1904B40B8CA13083BC654407BA35698BE914B40D461855B3EC754407BA35698BE914B40D461855B3EC7544030F65E7CD1904B40B8CA13083BC6544030F65E7CD1904B40
13528	27299	82.756378999999995	82.794594000000004	54.899358999999997	54.867741000000002	Советская	0103000020E610000001000000050000006518778368B05440FD321823126F4B406518778368B054407F2E1A321E734B4043E6CAA0DAB254407F2E1A321E734B4043E6CAA0DAB25440FD321823126F4B406518778368B05440FD321823126F4B40
15440	26019	83.278839000000005	83.301755	54.939340999999999	54.927810999999998	Школьная	0103000020E610000001000000050000005C76887FD8D154403DEFC682C2764B405C76887FD8D154405E656D533C784B40E31934F44FD354405E656D533C784B40E31934F44FD354403DEFC682C2764B405C76887FD8D154403DEFC682C2764B40
16159	25895	83.318841000000006	83.350525000000005	54.999650000000003	54.984408000000002	Школьная	0103000020E61000000100000005000000EFE714E467D45440DCF5D214017E4B40EFE714E467D4544024B9FC87F47F4B408CDB68006FD6544024B9FC87F47F4B408CDB68006FD65440DCF5D214017E4B40EFE714E467D45440DCF5D214017E4B40
13986	25776	83.148798999999997	83.203489000000005	54.976880999999999	54.945681	Матросова	0103000020E610000001000000050000005CAB3DEC85C954406BB933130C794B405CAB3DEC85C95440B98AC56F0A7D4B402106BAF605CD5440B98AC56F0A7D4B402106BAF605CD54406BB933130C794B405CAB3DEC85C954406BB933130C794B40
16200	25776	83.148798999999997	83.203489000000005	54.976880999999999	54.945681	Институтский переулок	0103000020E610000001000000050000005CAB3DEC85C954406BB933130C794B405CAB3DEC85C95440B98AC56F0A7D4B402106BAF605CD5440B98AC56F0A7D4B402106BAF605CD54406BB933130C794B405CAB3DEC85C954406BB933130C794B40
68364	24462	83.865170000000006	83.892290000000003	55.477102000000002	55.460746999999998	Семилетка	0103000020E61000000100000005000000BEDEFDF15EF75440745DF8C1F9BA4B40BEDEFDF15EF75440986DA7AD11BD4B40102384471BF95440986DA7AD11BD4B40102384471BF95440745DF8C1F9BA4B40BEDEFDF15EF75440745DF8C1F9BA4B40
13663	24396	83.926129000000003	83.954992000000004	55.431488999999999	55.416254000000002	Кирова	0103000020E6100000010000000500000024B891B245FB5440236AA2CF47B54B4024B891B245FB5440B8CA13083BB74B4044FCC3961EFD5440B8CA13083BB74B4044FCC3961EFD5440236AA2CF47B54B4024B891B245FB5440236AA2CF47B54B40
13992	23611	83.227913999999998	83.253291000000004	55.440105000000003	55.432550999999997	Союзная	0103000020E610000001000000050000003C139A2496CE5440116DC7D45DB74B403C139A2496CE54402EE7525C55B84B40C15774EB35D054402EE7525C55B84B40C15774EB35D05440116DC7D45DB74B403C139A2496CE5440116DC7D45DB74B40
15768	23611	83.227913999999998	83.253291000000004	55.440105000000003	55.432550999999997	Поросская	0103000020E610000001000000050000003C139A2496CE5440116DC7D45DB74B403C139A2496CE54402EE7525C55B84B40C15774EB35D054402EE7525C55B84B40C15774EB35D05440116DC7D45DB74B403C139A2496CE5440116DC7D45DB74B40
14022	18819	83.612122999999997	83.637438000000003	55.550702000000001	55.542186999999998	 Восточная	0103000020E610000001000000050000004888F2052DE754407EA8346266C54B404888F2052DE75440C0EB33677DC64B4092CEC0C8CBE85440C0EB33677DC64B4092CEC0C8CBE854407EA8346266C54B404888F2052DE754407EA8346266C54B40
68462	24154	83.826138	83.849000000000004	55.221496000000002	55.207571999999999	Школьная	0103000020E61000000100000005000000E7FEEA71DFF454405CC823B8919A4B40E7FEEA71DFF45440F0181EFB599C4B407593180456F65440F0181EFB599C4B407593180456F654405CC823B8919A4B40E7FEEA71DFF454405CC823B8919A4B40
68338	23501	83.456320000000005	83.533565999999993	55.532547999999998	55.506459	Обская	0103000020E61000000100000005000000B020CD5834DD5440E7E104A6D3C04B40B020CD5834DD54406DC669882AC44B407B1002F225E254406DC669882AC44B407B1002F225E25440E7E104A6D3C04B40B020CD5834DD5440E7E104A6D3C04B40
13799	23501	83.456320000000005	83.533565999999993	55.532547999999998	55.506459	Гагарина	0103000020E61000000100000005000000B020CD5834DD5440E7E104A6D3C04B40B020CD5834DD54406DC669882AC44B407B1002F225E254406DC669882AC44B407B1002F225E25440E7E104A6D3C04B40B020CD5834DD5440E7E104A6D3C04B40
13646	23864	83.804884000000001	83.841274999999996	55.480657999999998	55.447595999999997	Производственная	0103000020E61000000100000005000000B7442E3883F3544003E962D34AB94B40B7442E3883F35440C7478B3386BD4B4050FC1873D7F55440C7478B3386BD4B4050FC1873D7F5544003E962D34AB94B40B7442E3883F3544003E962D34AB94B40
13969	24890	83.281983999999994	83.344434000000007	55.221665999999999	55.197491999999997	квартал 4	0103000020E61000000100000005000000B27F9E060CD254405E9CF86A47994B40B27F9E060CD254404C512E8D5F9C4B405A68E7340BD654404C512E8D5F9C4B405A68E7340BD654405E9CF86A47994B40B27F9E060CD254405E9CF86A47994B40
13442	25031	83.351307000000006	83.378210999999993	55.205409000000003	55.193314000000001	Победы	0103000020E61000000100000005000000C7F65AD07BD65440F2ED5D83BE984B40C7F65AD07BD65440ECA694D74A9A4B4032FFE89B34D85440ECA694D74A9A4B4032FFE89B34D85440F2ED5D83BE984B40C7F65AD07BD65440F2ED5D83BE984B40
13949	23404	83.581787000000006	83.606949	55.509528000000003	55.493155000000002	Н.Передня	0103000020E610000001000000050000003B8F8AFF3BE55440F06DFAB31FBF4B403B8F8AFF3BE55440BA32A83638C14B40C1559E40D8E65440BA32A83638C14B40C1559E40D8E65440F06DFAB31FBF4B403B8F8AFF3BE55440F06DFAB31FBF4B40
68339	24093	83.731087000000002	83.764702	55.164175999999998	55.151307000000003	Ленина	0103000020E61000000100000005000000F8E12021CAEE5440F4531C075E934B40F8E12021CAEE5440E0641BB803954B40E44BA8E0F0F05440E0641BB803954B40E44BA8E0F0F05440F4531C075E934B40F8E12021CAEE5440F4531C075E934B40
16602	23938	83.732793999999998	83.738794999999996	55.498958999999999	55.494374000000001	Ключевская	0103000020E610000001000000050000001F2DCE18E6EE544011FFB0A547BF4B401F2DCE18E6EE5440BE8575E3DDBF4B40B1DCD26A48EF5440BE8575E3DDBF4B40B1DCD26A48EF544011FFB0A547BF4B401F2DCE18E6EE544011FFB0A547BF4B40
13822	25076	83.414719000000005	83.440715999999995	55.215671999999998	55.201411999999998	Центральная	0103000020E61000000100000005000000E9818FC18ADA5440CF8250DEC7994B40E9818FC18ADA5440DA54DD239B9B4B40BBB4E1B034DC5440DA54DD239B9B4B40BBB4E1B034DC5440CF8250DEC7994B40E9818FC18ADA5440CF8250DEC7994B40
16632	22950	83.552323000000001	83.634303000000003	55.318899999999999	55.288352000000003	Школьная	0103000020E610000001000000050000000875914259E354403CDEE4B7E8A44B400875914259E35440E25817B7D1A84B404D309C6B98E85440E25817B7D1A84B404D309C6B98E854403CDEE4B7E8A44B400875914259E354403CDEE4B7E8A44B40
13794	22950	83.552323000000001	83.634303000000003	55.318899999999999	55.288352000000003	Советская	0103000020E610000001000000050000000875914259E354403CDEE4B7E8A44B400875914259E35440E25817B7D1A84B404D309C6B98E85440E25817B7D1A84B404D309C6B98E854403CDEE4B7E8A44B400875914259E354403CDEE4B7E8A44B40
13786	22950	83.552323000000001	83.634303000000003	55.318899999999999	55.288352000000003	Линейная	0103000020E610000001000000050000000875914259E354403CDEE4B7E8A44B400875914259E35440E25817B7D1A84B404D309C6B98E85440E25817B7D1A84B404D309C6B98E854403CDEE4B7E8A44B400875914259E354403CDEE4B7E8A44B40
13936	22950	83.552323000000001	83.634303000000003	55.318899999999999	55.288352000000003	Западная	0103000020E610000001000000050000000875914259E354403CDEE4B7E8A44B400875914259E35440E25817B7D1A84B404D309C6B98E85440E25817B7D1A84B404D309C6B98E854403CDEE4B7E8A44B400875914259E354403CDEE4B7E8A44B40
13825	25150	83.481274999999997	83.507442999999995	55.261125999999997	55.251742	Школьная	0103000020E610000001000000050000007958A835CDDE5440CB83F41439A04B407958A835CDDE54405111A7936CA14B40626534F279E054405111A7936CA14B40626534F279E05440CB83F41439A04B407958A835CDDE5440CB83F41439A04B40
68440	24216	84.076391000000001	84.105711999999997	55.304907999999998	55.285111999999998	Школьная	0103000020E610000001000000050000005CAD1397E30455403CD9CD8C7EA44B405CAD1397E3045540F624B03907A74B40DDB243FCC3065540F624B03907A74B40DDB243FCC30655403CD9CD8C7EA44B405CAD1397E30455403CD9CD8C7EA44B40
13680	24967	83.336134000000001	83.355421000000007	55.259571000000001	55.244926999999997	Школьная	0103000020E61000000100000005000000B7442E3883D55440257497C4599F4B40B7442E3883D55440B9FE5D9F39A14B40F2D3B837BFD65440B9FE5D9F39A14B40F2D3B837BFD65440257497C4599F4B40B7442E3883D55440257497C4599F4B40
13645	23603	83.273171000000005	83.303713999999999	55.481045999999999	55.465024	Советская	0103000020E61000000100000005000000CDCD37A27BD1544074ED0BE885BB4B40CDCD37A27BD1544091EF52EA92BD4B409755D80C70D3544091EF52EA92BD4B409755D80C70D3544074ED0BE885BB4B40CDCD37A27BD1544074ED0BE885BB4B40
14048	23312	83.534499999999994	83.550642999999994	55.333542999999999	55.324607	Советская	0103000020E6100000010000000500000091ED7C3F35E25440BE86E0B88CA94B4091ED7C3F35E25440A5677A89B1AA4B405D3123BC3DE35440A5677A89B1AA4B405D3123BC3DE35440BE86E0B88CA94B4091ED7C3F35E25440BE86E0B88CA94B40
68711	24493	83.767962999999995	83.808801000000003	55.489156999999999	55.474597000000003	Школьная	0103000020E610000001000000050000006F62484E26F15440CEE33098BFBC4B406F62484E26F1544003CE52B29CBE4B4037FE4465C3F3544003CE52B29CBE4B4037FE4465C3F35440CEE33098BFBC4B406F62484E26F15440CEE33098BFBC4B40
68340	24553	83.856725999999995	83.879372000000004	55.525852999999998	55.507666999999998	Шкрольная	0103000020E6100000010000000500000081E84999D4F654401421753BFBC04B4081E84999D4F6544072C0AE264FC34B4029417FA147F8544072C0AE264FC34B4029417FA147F854401421753BFBC04B4081E84999D4F654401421753BFBC04B40
68707	21022	84.144231000000005	84.172743999999994	54.404017000000003	54.386797000000001	Центральная 	0103000020E610000001000000050000007104A9143B0955407098689082314B407104A9143B09554097033DD4B6334B4022A5D93C0E0B554097033DD4B6334B4022A5D93C0E0B55407098689082314B407104A9143B0955407098689082314B40
16377	21966	84.812623000000002	84.842690000000005	54.343646	54.328538000000002	Школьная	0103000020E610000001000000050000008E3EE6030234554023BF7E880D2A4B408E3EE603023455405BB39597FC2B4B40A4AA09A2EE3555405BB39597FC2B4B40A4AA09A2EE35554023BF7E880D2A4B408E3EE6030234554023BF7E880D2A4B40
68439	21663	84.526824000000005	84.570868000000004	54.413811000000003	54.392952000000001	Школьная	0103000020E61000000100000005000000DEAF027CB7215540EB724A404C324B40DEAF027CB7215540CFDC43C2F7344B404F95EF1989245540CFDC43C2F7344B404F95EF1989245540EB724A404C324B40DEAF027CB7215540EB724A404C324B40
13598	20948	84.428252000000001	84.457482999999996	54.374333	54.361471000000002	Центральная	0103000020E61000000100000005000000959C137B681B5540E9B985AE442E4B40959C137B681B55402368CC24EA2F4B4076DEC666471D55402368CC24EA2F4B4076DEC666471D5540E9B985AE442E4B40959C137B681B5540E9B985AE442E4B40
14119	22321	83.976408000000006	83.998327000000003	54.346449	54.332087000000001	Центральная	0103000020E6100000010000000500000061E3FA777DFE5440A036AAD3812A4B4061E3FA777DFE5440AF5DDA70582C4B40AFEDED96E4FF5440AF5DDA70582C4B40AFEDED96E4FF5440A036AAD3812A4B4061E3FA777DFE5440A036AAD3812A4B40
13625	22507	84.111199999999997	84.133118999999994	54.417304999999999	54.393628	Центральная	0103000020E610000001000000050000002CD49AE61D0755401B65FD6662324B402CD49AE61D07554088BA0F406A354B407ADE8D058508554088BA0F406A354B407ADE8D05850855401B65FD6662324B402CD49AE61D0755401B65FD6662324B40
13909	21478	84.755112999999994	84.769513000000003	54.467709999999997	54.459812999999997	Центральная	0103000020E6100000010000000500000034F279C55330554048A30227DB3A4B4034F279C5533055408E01D9EBDD3B4B40333674B33F3155408E01D9EBDD3B4B40333674B33F31554048A30227DB3A4B4034F279C55330554048A30227DB3A4B40
16428	22538	84.143018999999995	84.248373000000001	54.363810999999998	54.315945999999997	Озерная	0103000020E6100000010000000500000039ED293927095540A8A624EB70284B4039ED2939270955406876DD5B912E4B40670DDE57E50F55406876DD5B912E4B40670DDE57E50F5540A8A624EB70284B4039ED293927095540A8A624EB70284B40
14125	22538	84.143018999999995	84.248373000000001	54.363810999999998	54.315945999999997	Ленинская	0103000020E6100000010000000500000039ED293927095540A8A624EB70284B4039ED2939270955406876DD5B912E4B40670DDE57E50F55406876DD5B912E4B40670DDE57E50F5540A8A624EB70284B4039ED293927095540A8A624EB70284B40
14122	22538	84.143018999999995	84.248373000000001	54.363810999999998	54.315945999999997	Коммунистическая	0103000020E6100000010000000500000039ED293927095540A8A624EB70284B4039ED2939270955406876DD5B912E4B40670DDE57E50F55406876DD5B912E4B40670DDE57E50F5540A8A624EB70284B4039ED293927095540A8A624EB70284B40
16589	22538	84.143018999999995	84.248373000000001	54.363810999999998	54.315945999999997	Заводская	0103000020E6100000010000000500000039ED293927095540A8A624EB70284B4039ED2939270955406876DD5B912E4B40670DDE57E50F55406876DD5B912E4B40670DDE57E50F5540A8A624EB70284B4039ED293927095540A8A624EB70284B40
13930	22538	84.143018999999995	84.248373000000001	54.363810999999998	54.315945999999997	Больничная	0103000020E6100000010000000500000039ED293927095540A8A624EB70284B4039ED2939270955406876DD5B912E4B40670DDE57E50F55406876DD5B912E4B40670DDE57E50F5540A8A624EB70284B4039ED293927095540A8A624EB70284B40
13628	22538	84.143018999999995	84.248373000000001	54.363810999999998	54.315945999999997	Бердская	0103000020E6100000010000000500000039ED293927095540A8A624EB70284B4039ED2939270955406876DD5B912E4B40670DDE57E50F55406876DD5B912E4B40670DDE57E50F5540A8A624EB70284B4039ED293927095540A8A624EB70284B40
13916	21969	84.405614	84.426400999999998	54.296835000000002	54.284942000000001	Центральная	0103000020E610000001000000050000002F336C94F5195540E0A0BDFA78244B402F336C94F519554072A774B0FE254B40D47E6B274A1B554072A774B0FE254B40D47E6B274A1B5540E0A0BDFA78244B402F336C94F5195540E0A0BDFA78244B40
13917	21862	84.597476	84.617283999999998	54.306832999999997	54.298689000000003	Центральная	0103000020E610000001000000050000004609FA0B3D2655406556EF703B264B404609FA0B3D265540B22AC24D46274B400516C09481275540B22AC24D46274B400516C094812755406556EF703B264B404609FA0B3D2655406556EF703B264B40
13934	21679	84.574399	84.613007999999994	54.332355	54.311790999999999	Парковая	0103000020E61000000100000005000000BAF605F4C2245540F4177AC4E8274B40BAF605F4C2245540BFD4CF9B8A2A4B40ED0BE8853B275540BFD4CF9B8A2A4B40ED0BE8853B275540F4177AC4E8274B40BAF605F4C2245540F4177AC4E8274B40
14111	21585	84.578693000000001	84.609989999999996	54.508978999999997	54.491087999999998	Почтовая	0103000020E61000000100000005000000255B5D4E09255540A1BAB9F8DB3E4B40255B5D4E09255540E6AC4F3926414B40C5387F130A275540E6AC4F3926414B40C5387F130A275540A1BAB9F8DB3E4B40255B5D4E09255540A1BAB9F8DB3E4B40
13610	22067	84.535511	84.547961000000001	54.206778999999997	54.186931999999999	Новая	0103000020E610000001000000050000007DE9EDCF45225540B6494563ED174B407DE9EDCF45225540F23FF9BB771A4B40F19E03CB11235540F23FF9BB771A4B40F19E03CB11235540B6494563ED174B407DE9EDCF45225540B6494563ED174B40
14067	21273	84.124854999999997	84.601106000000001	54.616680000000002	54.512466000000003	Пролетарская	0103000020E610000001000000050000007E6FD39FFD075540EE27637C98414B407E6FD39FFD075540740CC85EEF4E4B407BDB4C8578265540740CC85EEF4E4B407BDB4C8578265540EE27637C98414B407E6FD39FFD075540EE27637C98414B40
13803	22288	83.923938000000007	83.941607000000005	54.397790000000001	54.387500000000003	Центральная	0103000020E610000001000000050000000762D9CC21FB54409A99999999314B400762D9CC21FB5440825660C8EA324B40D2AB014A43FC5440825660C8EA324B40D2AB014A43FC54409A99999999314B400762D9CC21FB54409A99999999314B40
14102	20874	84.261830000000003	84.292489000000003	54.381601000000003	54.365862	Советская	0103000020E6100000010000000500000026C79DD2C1105540B16CE690D42E4B4026C79DD2C11055407A8F334DD8304B40255CC823B81255407A8F334DD8304B40255CC823B8125540B16CE690D42E4B4026C79DD2C1105540B16CE690D42E4B40
67782	59101	82.867733999999999	82.868308999999996	54.985627999999998	54.981738	Крашенинникова	0103000020E6100000010000000500000025E82FF488B75440C79E3D97A97D4B4025E82FF488B75440CD02ED0E297E4B40A374E95F92B75440CD02ED0E297E4B40A374E95F92B75440C79E3D97A97D4B4025E82FF488B75440C79E3D97A97D4B40
75304	20315	76.443262000000004	76.479050999999998	56.784826000000002	56.771194999999999	Школьная	0103000020E61000000100000005000000D06394675E1C53405BEB8B84B6624C40D06394675E1C53407786A92D75644C406E8786C5A81E53407786A92D75644C406E8786C5A81E53405BEB8B84B6624C40D06394675E1C53405BEB8B84B6624C40
68436	20315	76.443262000000004	76.479050999999998	56.784826000000002	56.771194999999999	Центральная	0103000020E61000000100000005000000D06394675E1C53405BEB8B84B6624C40D06394675E1C53407786A92D75644C406E8786C5A81E53407786A92D75644C406E8786C5A81E53405BEB8B84B6624C40D06394675E1C53405BEB8B84B6624C40
13561	19186	77.249617000000001	77.281642000000005	56.581884000000002	56.568491000000002	Нарымская	0103000020E61000000100000005000000A4E194B9F94F534001892650C4484C40A4E194B9F94F53406808C72C7B4A4C4086CB2A6C065253406808C72C7B4A4C4086CB2A6C0652534001892650C4484C40A4E194B9F94F534001892650C4484C40
14069	19491	76.474091999999999	76.489534000000006	56.297223000000002	56.290728999999999	Школьная	0103000020E61000000100000005000000E5D2F885571E5340D87F9D9B36254C40E5D2F885571E53403C4F3C670B264C40ED116A86541F53403C4F3C670B264C40ED116A86541F5340D87F9D9B36254C40E5D2F885571E5340D87F9D9B36254C40
68434	19579	76.187916000000001	76.222060999999997	56.457974999999998	56.447463999999997	Школьная	0103000020E610000001000000050000004A99D4D0060C53409411178046394C404A99D4D0060C53405BB1BFEC9E3A4C40E42D573F360E53405BB1BFEC9E3A4C40E42D573F360E53409411178046394C404A99D4D0060C53409411178046394C40
13731	19372	76.614588999999995	76.636606	56.433675000000001	56.422514999999997	Соловьева	0103000020E61000000100000005000000CEDE196D55275340E388B5F814364C40CEDE196D55275340E10B93A982374C40FE9B1727BE285340E10B93A982374C40FE9B1727BE285340E388B5F814364C40CEDE196D55275340E388B5F814364C40
13899	20482	76.314263999999994	76.345426000000003	56.946480999999999	56.931852999999997	Центральная	0103000020E61000000100000005000000D993C0E61C145340F9D687F546774C40D993C0E61C14534087A4164A26794C400A4CA7751B16534087A4164A26794C400A4CA7751B165340F9D687F546774C40D993C0E61C145340F9D687F546774C40
13857	20482	76.314263999999994	76.345426000000003	56.946480999999999	56.931852999999997	Первомайская	0103000020E61000000100000005000000D993C0E61C145340F9D687F546774C40D993C0E61C14534087A4164A26794C400A4CA7751B16534087A4164A26794C400A4CA7751B165340F9D687F546774C40D993C0E61C145340F9D687F546774C40
68702	18985	76.945240999999996	76.975711000000004	56.579053000000002	56.565837999999999	Школьная	0103000020E61000000100000005000000A7751BD47E3C5340C26A2C616D484C40A7751BD47E3C53404AD3A0681E4A4C403DD68C0C723E53404AD3A0681E4A4C403DD68C0C723E5340C26A2C616D484C40A7751BD47E3C5340C26A2C616D484C40
14758	20267	76.409198000000004	76.428906999999995	56.511812999999997	56.502609	Центральная	0103000020E61000000100000005000000ACE5CE4C301A53406FD6E07D55404C40ACE5CE4C301A53407555A01683414C40A1815836731B53407555A01683414C40A1815836731B53406FD6E07D55404C40ACE5CE4C301A53406FD6E07D55404C40
14080	19874	75.999126000000004	76.018924999999996	56.469228999999999	56.459701000000003	Школьная	0103000020E6100000010000000500000055A52DAEF1FF524021787C7BD73A4C4055A52DAEF1FF5240DAAA24B20F3C4C40EA04341136015340DAAA24B20F3C4C40EA0434113601534021787C7BD73A4C4055A52DAEF1FF524021787C7BD73A4C40
13573	19897	76.070847000000001	76.102431999999993	56.486072	56.475194999999999	Горская	0103000020E610000001000000050000004301DBC188045340821C9430D33C4C404301DBC1880453402BC0779B373E4C401684F23E8E0653402BC0779B373E4C401684F23E8E065340821C9430D33C4C404301DBC188045340821C9430D33C4C40
14280	18572	76.586057999999994	76.657582000000005	56.575785000000003	56.534792000000003	Садовая	0103000020E61000000100000005000000C9E369F981255340CB14731074444C40C9E369F9812553408143A852B3494C400D1CD0D2152A53408143A852B3494C400D1CD0D2152A5340CB14731074444C40C9E369F981255340CB14731074444C40
13870	18572	76.586057999999994	76.657582000000005	56.575785000000003	56.534792000000003	Мелиоративная	0103000020E61000000100000005000000C9E369F981255340CB14731074444C40C9E369F9812553408143A852B3494C400D1CD0D2152A53408143A852B3494C400D1CD0D2152A5340CB14731074444C40C9E369F981255340CB14731074444C40
14214	18572	76.586057999999994	76.657582000000005	56.575785000000003	56.534792000000003	Ленина	0103000020E61000000100000005000000C9E369F981255340CB14731074444C40C9E369F9812553408143A852B3494C400D1CD0D2152A53408143A852B3494C400D1CD0D2152A5340CB14731074444C40C9E369F981255340CB14731074444C40
14027	18572	76.586057999999994	76.657582000000005	56.575785000000003	56.534792000000003	Волкова	0103000020E61000000100000005000000C9E369F981255340CB14731074444C40C9E369F9812553408143A852B3494C400D1CD0D2152A53408143A852B3494C400D1CD0D2152A5340CB14731074444C40C9E369F981255340CB14731074444C40
14277	19133	77.180069000000003	77.199239000000006	56.526263999999998	56.514699	Центральная	0103000020E6100000010000000500000080812040864B5340572426A8E1414C4080812040864B5340F487669E5C434C409E45EF54C04C5340F487669E5C434C409E45EF54C04C5340572426A8E1414C4080812040864B5340572426A8E1414C40
68706	20829	77.152373999999995	77.181515000000005	56.824666000000001	56.811832000000003	Матросовка	0103000020E61000000100000005000000AFB0E07EC049534053EC681CEA674C40AFB0E07EC0495340C30FCEA78E694C40F12E17F19D4B5340C30FCEA78E694C40F12E17F19D4B534053EC681CEA674C40AFB0E07EC049534053EC681CEA674C40
68624	20402	76.681127000000004	76.714877000000001	56.894424999999998	56.881424000000003	Центральная	0103000020E610000001000000050000000C5BB395972B53406BF46A80D2704C400C5BB395972B5340C6DCB5847C724C4068EA758BC02D5340C6DCB5847C724C4068EA758BC02D53406BF46A80D2704C400C5BB395972B53406BF46A80D2704C40
13703	41269	77.019163000000006	77.040327000000005	56.791570999999998	56.783208999999999	Школьная	0103000020E61000000100000005000000C59272F7394153406877483140644C40C59272F73941534023BBD23252654C405589B2B79442534023BBD23252654C405589B2B7944253406877483140644C40C59272F7394153406877483140644C40
75574	60693	76.855013999999997	76.866431000000006	56.734864000000002	56.716580999999998	Центральная	0103000020E61000000100000005000000D1E7A38CB8365340ADF71BEDB85B4C40D1E7A38CB8365340FE800706105E4C40664F029B73375340FE800706105E4C40664F029B73375340ADF71BEDB85B4C40D1E7A38CB8365340ADF71BEDB85B4C40
68433	19565	76.323408999999998	76.340513000000001	56.456746000000003	56.446289999999998	Центральная	0103000020E61000000100000005000000DA8EA9BBB21453401344DD0720394C40DA8EA9BBB2145340174A26A7763A4C4039B709F7CA155340174A26A7763A4C4039B709F7CA1553401344DD0720394C40DA8EA9BBB21453401344DD0720394C40
14286	18848	76.701716000000005	76.719413000000003	56.547407999999997	56.539760999999999	Центральная	0103000020E610000001000000050000001EC539EAE82C5340005471E316454C401EC539EAE82C5340CDC8207711464C404ED4D2DC0A2E5340CDC8207711464C404ED4D2DC0A2E5340005471E316454C401EC539EAE82C5340005471E316454C40
13858	19680	76.145740000000004	76.166841000000005	56.443060000000003	56.430110999999997	Центральная	0103000020E61000000100000005000000056EDDCD530953402E5393E00D374C40056EDDCD530953403815A930B6384C4072A8DF85AD0A53403815A930B6384C4072A8DF85AD0A53402E5393E00D374C40056EDDCD530953402E5393E00D374C40
68608	19257	77.474132999999995	77.520126000000005	56.625297000000003	56.612400000000001	Волкова	0103000020E61000000100000005000000143DF031585E534003098A1F634E4C40143DF031585E5340BAA46ABB09504C4028F38FBE49615340BAA46ABB09504C4028F38FBE4961534003098A1F634E4C40143DF031585E534003098A1F634E4C40
16322	20578	76.874121000000002	76.910106999999996	56.690396	56.678649	Нарымская	0103000020E61000000100000005000000CCEF3499F1375340473B6EF8DD564C40CCEF3499F137534005A568E55E584C4015376E313F3A534005A568E55E584C4015376E313F3A5340473B6EF8DD564C40CCEF3499F1375340473B6EF8DD564C40
68437	20479	76.849795	76.876132999999996	56.939788999999998	56.927708000000003	Школьная	0103000020E610000001000000050000007A53910A63365340691EC022BF764C407A53910A63365340FD1186014B784C40917C259012385340FD1186014B784C40917C259012385340691EC022BF764C407A53910A63365340691EC022BF764C40
68705	19997	76.209492999999995	76.244105000000005	56.573335999999998	56.557578999999997	Смоленская	0103000020E610000001000000050000006BEF5355680D5340DBF7A8BF5E474C406BEF5355680D53404ACFF41263494C4091F2936A9F0F53404ACFF41263494C4091F2936A9F0F5340DBF7A8BF5E474C406BEF5355680D5340DBF7A8BF5E474C40
68460	20676	76.913171000000006	76.939984999999993	56.802632000000003	56.791314999999997	Заречная	0103000020E61000000100000005000000F629C764713A5340C8EA56CF49654C40F629C764713A53408E5C37A5BC664C40C16ED8B6283C53408E5C37A5BC664C40C16ED8B6283C5340C8EA56CF49654C40F629C764713A5340C8EA56CF49654C40
13748	19767	76.193691999999999	76.207373000000004	56.475085999999997	56.466518999999998	Центральная	0103000020E61000000100000005000000CC5F2173650C534037FB03E5B63B4C40CC5F2173650C5340CB64389ECF3C4C40B3446799450D5340CB64389ECF3C4C40B3446799450D534037FB03E5B63B4C40CC5F2173650C534037FB03E5B63B4C40
13984	14008	77.362131000000005	77.404217000000003	54.646619000000001	54.629747000000002	Советская	0103000020E610000001000000050000008A7780272D57534087E0B88C9B504B408A7780272D57534072FC5069C4524B402FDFFAB0DE59534072FC5069C4524B402FDFFAB0DE59534087E0B88C9B504B408A7780272D57534087E0B88C9B504B40
16612	16507	77.326269999999994	77.356973999999994	54.522207000000002	54.511749000000002	Школьная	0103000020E610000001000000050000009EEA909BE15453405F61C1FD80414B409EEA909BE1545340035FD1ADD7424B406DE179A9D8565340035FD1ADD7424B406DE179A9D85653405F61C1FD80414B409EEA909BE15453405F61C1FD80414B40
14020	41358	77.023636999999994	77.042214000000001	54.035975000000001	54.022018000000003	Ленина	0103000020E610000001000000050000006F7EC3448341534030F65E7CD1024B406F7EC344834153409F3C2CD49A044B40BC5B59A2B34253409F3C2CD49A044B40BC5B59A2B342534030F65E7CD1024B406F7EC3448341534030F65E7CD1024B40
16125	40396	77.541928999999996	77.588352999999998	54.294701000000003	54.278466000000002	Южная	0103000020E6100000010000000500000041F0F8F6AE62534023861DC6A4234B4041F0F8F6AE6253409C8C2AC3B8254B4039605793A76553409C8C2AC3B8254B4039605793A765534023861DC6A4234B4041F0F8F6AE62534023861DC6A4234B40
14076	40396	77.541928999999996	77.588352999999998	54.294701000000003	54.278466000000002	Светлая	0103000020E6100000010000000500000041F0F8F6AE62534023861DC6A4234B4041F0F8F6AE6253409C8C2AC3B8254B4039605793A76553409C8C2AC3B8254B4039605793A765534023861DC6A4234B4041F0F8F6AE62534023861DC6A4234B40
13767	40396	77.541928999999996	77.588352999999998	54.294701000000003	54.278466000000002	Путевая	0103000020E6100000010000000500000041F0F8F6AE62534023861DC6A4234B4041F0F8F6AE6253409C8C2AC3B8254B4039605793A76553409C8C2AC3B8254B4039605793A765534023861DC6A4234B4041F0F8F6AE62534023861DC6A4234B40
14079	40396	77.541928999999996	77.588352999999998	54.294701000000003	54.278466000000002	 Кооперативная	0103000020E6100000010000000500000041F0F8F6AE62534023861DC6A4234B4041F0F8F6AE6253409C8C2AC3B8254B4039605793A76553409C8C2AC3B8254B4039605793A765534023861DC6A4234B4041F0F8F6AE62534023861DC6A4234B40
13801	41292	77.059101999999996	77.066513	53.917506000000003	53.905504000000001	Центральная	0103000020E610000001000000050000003448C153C8435340D732198EE7F34A403448C153C843534020F12BD670F54A4091F0BDBF4144534020F12BD670F54A4091F0BDBF41445340D732198EE7F34A403448C153C8435340D732198EE7F34A40
13952	40467	77.846385999999995	77.869364000000004	54.276395000000001	54.253131000000003	Центральная	0103000020E61000000100000005000000B4722F302B765340494DBB9866204B40B4722F302B76534093E34EE960234B407714E7A8A377534093E34EE960234B407714E7A8A3775340494DBB9866204B40B4722F302B765340494DBB9866204B40
68697	49667	76.921372000000005	76.944163000000003	54.320709000000001	54.309302000000002	Центральная	0103000020E61000000100000005000000CFDC43C2F73A5340304B3B3597274B40CFDC43C2F73A5340354415FE0C294B40F8C5A52A6D3C5340354415FE0C294B40F8C5A52A6D3C5340304B3B3597274B40CFDC43C2F73A5340304B3B3597274B40
14268	41600	76.859630999999993	76.902651000000006	54.182712000000002	54.165577999999996	Новосельский проспект	0103000020E610000001000000050000002DE8BD3104375340F277EFA831154B402DE8BD31043753401B4B581B63174B40E92CB308C53953401B4B581B63174B40E92CB308C5395340F277EFA831154B402DE8BD3104375340F277EFA831154B40
13736	17121	77.993898000000002	78.019131999999999	54.250259	54.237484000000002	Школьная	0103000020E61000000100000005000000D4635B069C7F534061A92EE0651E4B40D4635B069C7F5340CC43A67C08204B40A7936C7539815340CC43A67C08204B40A7936C753981534061A92EE0651E4B40D4635B069C7F534061A92EE0651E4B40
16550	16987	77.804623000000007	77.828626	54.379530000000003	54.367536000000001	 Надежды	0103000020E6100000010000000500000001A777F17E735340240D6E6B0B2F4B4001A777F17E735340EAEC647094304B4061A7583508755340EAEC647094304B4061A7583508755340240D6E6B0B2F4B4001A777F17E735340240D6E6B0B2F4B40
14770	43197	77.273691999999997	77.297452000000007	54.242562	54.235695	Морьевская	0103000020E61000000100000005000000514B732B84515340556AF6402B1E4B40514B732B845153404DA088450C1F4B404F081D74095353404DA088450C1F4B404F081D7409535340556AF6402B1E4B40514B732B84515340556AF6402B1E4B40
13541	18376	76.722153000000006	76.751187000000002	54.096376999999997	54.088371000000002	Центральная	0103000020E61000000100000005000000556D37C1372E53401975ADBD4F0B4B40556D37C1372E5340158BDF14560C4B408B8BA37213305340158BDF14560C4B408B8BA372133053401975ADBD4F0B4B40556D37C1372E53401975ADBD4F0B4B40
14002	41347	77.07432	77.101314000000002	54.138238000000001	54.117032999999999	Пролетарская	0103000020E61000000100000005000000145CACA8C1445340C1C6F5EFFA0E4B40145CACA8C1445340408864C8B1114B402028B7ED7B465340408864C8B1114B402028B7ED7B465340C1C6F5EFFA0E4B40145CACA8C1445340C1C6F5EFFA0E4B40
68616	41373	77.429873000000001	77.458053000000007	54.585971000000001	54.57779	Школьная	0103000020E61000000100000005000000BD1B0B0A835B534059FAD005F5494B40BD1B0B0A835B5340C4B30419014B4B406CB587BD505D5340C4B30419014B4B406CB587BD505D534059FAD005F5494B40BD1B0B0A835B534059FAD005F5494B40
68886	17104	78.063787000000005	78.085938999999996	54.324254000000003	54.314033999999999	Центральная	0103000020E610000001000000050000003DBA11161584534081EA1F4432284B403DBA11161584534071CCB22781294B40DC9C4A068085534071CCB22781294B40DC9C4A068085534081EA1F4432284B403DBA11161584534081EA1F4432284B40
14176	1791	77.252302999999998	77.344882999999996	54.387348000000003	54.326721999999997	Советов	0103000020E61000000100000005000000B16B7BBB255053401D71C806D2294B40B16B7BBB25505340E415889E94314B40917C259012565340E415889E94314B40917C2590125653401D71C806D2294B40B16B7BBB255053401D71C806D2294B40
13455	1791	77.252302999999998	77.344882999999996	54.387348000000003	54.326721999999997	Садовая	0103000020E61000000100000005000000B16B7BBB255053401D71C806D2294B40B16B7BBB25505340E415889E94314B40917C259012565340E415889E94314B40917C2590125653401D71C806D2294B40B16B7BBB255053401D71C806D2294B40
13441	1791	77.252302999999998	77.344882999999996	54.387348000000003	54.326721999999997	Осипенко	0103000020E61000000100000005000000B16B7BBB255053401D71C806D2294B40B16B7BBB25505340E415889E94314B40917C259012565340E415889E94314B40917C2590125653401D71C806D2294B40B16B7BBB255053401D71C806D2294B40
13929	1791	77.252302999999998	77.344882999999996	54.387348000000003	54.326721999999997	Новый городок	0103000020E61000000100000005000000B16B7BBB255053401D71C806D2294B40B16B7BBB25505340E415889E94314B40917C259012565340E415889E94314B40917C2590125653401D71C806D2294B40B16B7BBB255053401D71C806D2294B40
13574	41243	77.142582000000004	77.15992	54.509444000000002	54.503233999999999	Центральная	0103000020E61000000100000005000000E4BF4010204953401D1EC2F869404B40E4BF4010204953405C92037635414B407C7E18213C4A53405C92037635414B407C7E18213C4A53401D1EC2F869404B40E4BF4010204953401D1EC2F869404B40
13982	41243	77.142582000000004	77.15992	54.509444000000002	54.503233999999999	Куликовская	0103000020E61000000100000005000000E4BF4010204953401D1EC2F869404B40E4BF4010204953405C92037635414B407C7E18213C4A53405C92037635414B407C7E18213C4A53401D1EC2F869404B40E4BF4010204953401D1EC2F869404B40
13488	16898	77.616946999999996	77.648505	54.401774000000003	54.381323000000002	Центральная	0103000020E610000001000000050000006117450F7C675340371B2B31CF304B406117450F7C6753400A3197546D334B40B8921D1B816953400A3197546D334B40B8921D1B81695340371B2B31CF304B406117450F7C675340371B2B31CF304B40
13512	17297	77.310018999999997	77.349473000000003	54.285761999999998	54.273497999999996	Центральная	0103000020E61000000100000005000000DF88EE59D7535340BDC282FB01234B40DF88EE59D7535340433866D993244B40717500C45D565340433866D993244B40717500C45D565340BDC282FB01234B40DF88EE59D7535340BDC282FB01234B40
68699	46506	77.737887000000001	77.763865999999993	54.348385	54.34151	Центральная	0103000020E610000001000000050000003049658A396F5340E4A08499B62B4B403049658A396F53405FB532E1972C4B40AF21382EE37053405FB532E1972C4B40AF21382EE3705340E4A08499B62B4B403049658A396F5340E4A08499B62B4B40
13856	41307	76.831908999999996	76.854268000000005	53.987129000000003	53.980103	Центральная	0103000020E61000000100000005000000E00F3FFF3D35534012DBDD0374FD4A40E00F3FFF3D35534073F7393E5AFE4A403D81B053AC36534073F7393E5AFE4A403D81B053AC36534012DBDD0374FD4A40E00F3FFF3D35534012DBDD0374FD4A40
13647	41256	76.917258000000004	76.945474000000004	54.048929000000001	54.033949999999997	Центральная	0103000020E61000000100000005000000A4FFE55AB43A53407FD93D7958044B40A4FFE55AB43A5340BA69334E43064B40F94D61A5823C5340BA69334E43064B40F94D61A5823C53407FD93D7958044B40A4FFE55AB43A53407FD93D7958044B40
13943	41328	77.649313000000006	77.664125999999996	54.468082000000003	54.460959000000003	Школьная	0103000020E6100000010000000500000088F71C588E69534000E65AB4003B4B4088F71C588E69534053EC681CEA3B4B40179B560A816A534053EC681CEA3B4B40179B560A816A534000E65AB4003B4B4088F71C588E69534000E65AB4003B4B40
14215	41447	76.498005000000006	76.524524	54.117306999999997	54.109290000000001	Солнечная	0103000020E61000000100000005000000A60F5D50DF1F5340D2E3F736FD0D4B40A60F5D50DF1F5340C24B70EA030F4B40E57D1CCD91215340C24B70EA030F4B40E57D1CCD91215340D2E3F736FD0D4B40A60F5D50DF1F5340D2E3F736FD0D4B40
75554	49616	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	Школьная	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
14135	14558	79.034649999999999	79.069792000000007	55.693896000000002	55.678966000000003	Советская	0103000020E610000001000000050000009C33A2B437C25340488C9E5BE8D64B409C33A2B437C25340A1698995D1D84B407061DD7877C45340A1698995D1D84B407061DD7877C45340488C9E5BE8D64B409C33A2B437C25340488C9E5BE8D64B40
14109	14494	78.417696000000007	78.442983999999996	55.789845999999997	55.781295999999998	Речная	0103000020E61000000100000005000000E2EA0088BB9A5340703FE08101E44B40E2EA0088BB9A53402E7079AC19E54B40AE2990D9599C53402E7079AC19E54B40AE2990D9599C5340703FE08101E44B40E2EA0088BB9A5340703FE08101E44B40
13678	41262	78.470903000000007	78.479912999999996	55.459587999999997	55.454810000000002	Школьная	0103000020E61000000100000005000000A7255646239E534067F2CD3637BA4B40A7255646239E534028D192C7D3BA4B4037FB03E5B69E534028D192C7D3BA4B4037FB03E5B69E534067F2CD3637BA4B40A7255646239E534067F2CD3637BA4B40
13800	14202	78.501581000000002	78.526364999999998	55.470173000000003	55.45919	Северная	0103000020E61000000100000005000000E1D231E719A053403B53E8BCC6BA4B40E1D231E719A053402A3BFDA02EBC4B409430D3F6AFA153402A3BFDA02EBC4B409430D3F6AFA153403B53E8BCC6BA4B40E1D231E719A053403B53E8BCC6BA4B40
16634	49613	77.782173999999998	77.796735999999996	55.428592000000002	55.422007000000001	Береговая	0103000020E61000000100000005000000047289230F7253406FD74B5304B64B40047289230F725340E3A9471ADCB64B40EFE2FDB8FD725340E3A9471ADCB64B40EFE2FDB8FD7253406FD74B5304B64B40047289230F7253406FD74B5304B64B40
14129	14138	77.614008999999996	77.632109999999997	55.666310000000003	55.658372999999997	Школьная	0103000020E61000000100000005000000C79C67EC4B675340E2C8039145D44B40C79C67EC4B675340B77F65A549D54B405F5E807D74685340B77F65A549D54B405F5E807D74685340E2C8039145D44B40C79C67EC4B675340E2C8039145D44B40
16264	14050	79.347587000000004	79.370827000000006	55.592393000000001	55.577429000000002	Заимская	0103000020E61000000100000005000000F2608BDD3ED6534089618731E9C94B40F2608BDD3ED653408EB0A888D3CB4B40535E2BA1BBD753408EB0A888D3CB4B40535E2BA1BBD7534089618731E9C94B40F2608BDD3ED6534089618731E9C94B40
13450	40315	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	Партизанская	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
15886	40315	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	Каинская	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
9802	40315	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	Закраевского	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
13898	41320	78.947845999999998	78.964213000000001	55.633876999999998	55.627844000000003	Центральная	0103000020E610000001000000050000003EE94482A9BC5340B37E33315DD04B403EE94482A9BC5340E257ACE122D14B40325871AAB5BD5340E257ACE122D14B40325871AAB5BD5340B37E33315DD04B403EE94482A9BC5340B37E33315DD04B40
68964	48994	78.986985000000004	79.009011999999998	55.488055000000003	55.480572000000002	17	0103000020E61000000100000005000000202922C32ABF5340C9AF1F6283BD4B40202922C32ABF53401CD3139678BE4B40615111A793C053401CD3139678BE4B40615111A793C05340C9AF1F6283BD4B40202922C32ABF5340C9AF1F6283BD4B40
13632	13716	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	Центральная	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
13685	13716	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	Ленина	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
16599	14361	78.928442000000004	78.948312999999999	55.450563000000002	55.440227999999998	Центральная	0103000020E61000000100000005000000E78EFE976BBB534049641F6459B84B40E78EFE976BBB5340D2E4620CACB94B40C9570229B1BC5340D2E4620CACB94B40C9570229B1BC534049641F6459B84B40E78EFE976BBB534049641F6459B84B40
68326	13850	77.692081999999999	77.738659999999996	55.886746000000002	55.870742999999997	Показановская	0103000020E610000001000000050000009E094D124B6C5340471CB28174EF4B409E094D124B6C5340EEED96E480F14B4041B79734466F5340EEED96E480F14B4041B79734466F5340471CB28174EF4B409E094D124B6C5340471CB28174EF4B40
14072	13802	79.315202999999997	79.338837999999996	55.736285000000002	55.72636	Новая	0103000020E61000000100000005000000782634492CD45340B08F4E5DF9DC4B40782634492CD4534087C43D963EDE4B4017299485AFD5534087C43D963EDE4B4017299485AFD55340B08F4E5DF9DC4B40782634492CD45340B08F4E5DF9DC4B40
13405	13708	78.698994999999996	78.738007999999994	55.515523000000002	55.506877000000003	Рабочая	0103000020E6100000010000000500000052448655BCAC53401C0C7558E1C04B4052448655BCAC5340FCAA5CA8FCC14B40ED0BE8853BAF5340FCAA5CA8FCC14B40ED0BE8853BAF53401C0C7558E1C04B4052448655BCAC53401C0C7558E1C04B40
14126	13607	78.164361999999997	78.200681000000003	55.712822000000003	55.691941999999997	Центральная	0103000020E6100000010000000500000021AD31E8848A53404A5D328E91D84B4021AD31E8848A534046EF54C03DDB4B406EFB1EF5D78C534046EF54C03DDB4B406EFB1EF5D78C53404A5D328E91D84B4021AD31E8848A53404A5D328E91D84B40
13783	13382	78.111389000000003	78.135113000000004	55.549571999999998	55.541708	Центральная	0103000020E61000000100000005000000960854FF20875340A4FD0FB056C54B40960854FF208753400E66136058C64B40ED10FFB0A58853400E66136058C64B40ED10FFB0A5885340A4FD0FB056C54B40960854FF20875340A4FD0FB056C54B40
13795	13437	77.993835000000004	78.032373000000007	55.735641999999999	55.721772000000001	Молодежная	0103000020E61000000100000005000000B1A71DFE9A7F534092955F0663DC4B40B1A71DFE9A7F534032C85D8429DE4B40801134661282534032C85D8429DE4B40801134661282534092955F0663DC4B40B1A71DFE9A7F534092955F0663DC4B40
16420	13160	79.417602000000002	79.448639	55.809206000000003	55.797620000000002	Центральная	0103000020E61000000100000005000000A12FBDFDB9DA53405951836918E64B40A12FBDFDB9DA53400EDDEC0F94E74B40732D5A80B6DC53400EDDEC0F94E74B40732D5A80B6DC53405951836918E64B40A12FBDFDB9DA53405951836918E64B40
13944	13665	78.347842999999997	78.374962999999994	55.611581999999999	55.601640000000003	Рапикова	0103000020E610000001000000050000001F49490F4396534094FB1D8A02CD4B401F49490F439653404069A85148CE4B40718DCF64FF9753404069A85148CE4B40718DCF64FF97534094FB1D8A02CD4B401F49490F4396534094FB1D8A02CD4B40
9949	14663	79.138036999999997	79.159058000000002	55.713841000000002	55.702688000000002	Центральная	0103000020E61000000100000005000000D4282499D5C8534055A52DAEF1D94B40D4282499D5C85340A0C552245FDB4B40B30A9B012ECA5340A0C552245FDB4B40B30A9B012ECA534055A52DAEF1D94B40D4282499D5C8534055A52DAEF1D94B40
13616	13052	78.204059000000001	78.234888999999995	55.444558000000001	55.431396999999997	Зеленая	0103000020E6100000010000000500000016DD7A4D0F8D5340D74B530438B74B4016DD7A4D0F8D53406C96CB46E7B84B402B4CDF6B088F53406C96CB46E7B84B402B4CDF6B088F5340D74B530438B74B4016DD7A4D0F8D5340D74B530438B74B40
13735	37222	50.238273	50.256284999999998	53.697178999999998	53.682899999999997	Гагарина 	0103000020E610000001000000050000008942CBBA7F1E49401D38674469D74A408942CBBA7F1E49409F3A56293DD94A4049BA66F2CD2049409F3A56293DD94A4049BA66F2CD2049401D38674469D74A408942CBBA7F1E49401D38674469D74A40
14042	11265	79.797571000000005	79.829380999999998	54.082118000000001	54.068551999999997	Молодежная	0103000020E610000001000000050000003C4F3C670BF35340A609DB4FC6084B403C4F3C670BF35340DB34B6D7820A4B401FBB0B9414F55340DB34B6D7820A4B401FBB0B9414F55340A609DB4FC6084B403C4F3C670BF35340A609DB4FC6084B40
13384	11380	79.527384999999995	79.547910999999999	53.752026999999998	53.746724	Школьная	0103000020E61000000100000005000000A9D903ADC0E15340B491EBA694DF4A40A9D903ADC0E15340C05AB56B42E04A4098874CF910E35340C05AB56B42E04A4098874CF910E35340B491EBA694DF4A40A9D903ADC0E15340B491EBA694DF4A40
13603	11982	79.757694999999998	79.772796	53.848711999999999	53.842714000000001	Школьная	0103000020E61000000100000005000000EF552B137EF05340D0F0660DDEEB4A40EF552B137EF0534083DC4598A2EC4A40B29E5A7D75F1534083DC4598A2EC4A40B29E5A7D75F15340D0F0660DDEEB4A40EF552B137EF05340D0F0660DDEEB4A40
13880	10245	78.724380999999994	78.749435000000005	53.664914000000003	53.654760000000003	Рязань	0103000020E61000000100000005000000003620425CAE53404F5DF92CCFD34A40003620425CAE53408753E6E61BD54A4094DE37BEF6AF53408753E6E61BD54A4094DE37BEF6AF53404F5DF92CCFD34A40003620425CAE53404F5DF92CCFD34A40
13732	10148	78.804196000000005	78.826322000000005	53.744391	53.732115	Зеленорощенская	0103000020E61000000100000005000000BDE47FF277B353409DF4BEF1B5DD4A40BDE47FF277B35340E7374C3448DF4A40C87DAB75E2B45340E7374C3448DF4A40C87DAB75E2B453409DF4BEF1B5DD4A40BDE47FF277B353409DF4BEF1B5DD4A40
13772	12861	78.700682999999998	78.725486000000004	54.205800000000004	54.183312000000001	Центральная	0103000020E610000001000000050000003E7782FDD7AC5340707B82C476174B403E7782FDD7AC534027C286A7571A4B402DEDD45C6EAE534027C286A7571A4B402DEDD45C6EAE5340707B82C476174B403E7782FDD7AC5340707B82C476174B40
75370	60586	79.482872999999998	79.505700000000004	53.752437	53.737617	Почтовая 	0103000020E61000000100000005000000C5C72764E7DE5340A0FCDD3B6ADE4A40C5C72764E7DE534072A609DB4FE04A40956588635DE0534072A609DB4FE04A40956588635DE05340A0FCDD3B6ADE4A40C5C72764E7DE5340A0FCDD3B6ADE4A40
75512	60654	78.778773999999999	78.791709999999995	54.293351000000001	54.282308999999998	Центральная улица	0103000020E61000000100000005000000683EE76ED7B15340E82E89B322244B40683EE76ED7B15340DC9F8B868C254B40A27A6B60ABB25340DC9F8B868C254B40A27A6B60ABB25340E82E89B322244B40683EE76ED7B15340E82E89B322244B40
13762	12379	79.210217	79.273296999999999	53.776696999999999	53.723464	Станционная	0103000020E610000001000000050000000C04013274CD5340ABEAE5779ADC4A400C04013274CD53405EF3AACE6AE34A401346B3B27DD153405EF3AACE6AE34A401346B3B27DD15340ABEAE5779ADC4A400C04013274CD5340ABEAE5779ADC4A40
13622	12379	79.210217	79.273296999999999	53.776696999999999	53.723464	Северная	0103000020E610000001000000050000000C04013274CD5340ABEAE5779ADC4A400C04013274CD53405EF3AACE6AE34A401346B3B27DD153405EF3AACE6AE34A401346B3B27DD15340ABEAE5779ADC4A400C04013274CD5340ABEAE5779ADC4A40
13914	12379	79.210217	79.273296999999999	53.776696999999999	53.723464	Молодежная	0103000020E610000001000000050000000C04013274CD5340ABEAE5779ADC4A400C04013274CD53405EF3AACE6AE34A401346B3B27DD153405EF3AACE6AE34A401346B3B27DD15340ABEAE5779ADC4A400C04013274CD5340ABEAE5779ADC4A40
13925	12379	79.210217	79.273296999999999	53.776696999999999	53.723464	Малининская	0103000020E610000001000000050000000C04013274CD5340ABEAE5779ADC4A400C04013274CD53405EF3AACE6AE34A401346B3B27DD153405EF3AACE6AE34A401346B3B27DD15340ABEAE5779ADC4A400C04013274CD5340ABEAE5779ADC4A40
14047	11512	79.611440000000002	79.675122000000002	54.027599000000002	54.002299000000001	Полтавская	0103000020E61000000100000005000000D7DD3CD521E7534021E868554B004B40D7DD3CD521E753407F33315D88034B40D9B3E73235EB53407F33315D88034B40D9B3E73235EB534021E868554B004B40D7DD3CD521E7534021E868554B004B40
68955	11512	79.611440000000002	79.675122000000002	54.027599000000002	54.002299000000001	Зеленая	0103000020E61000000100000005000000D7DD3CD521E7534021E868554B004B40D7DD3CD521E753407F33315D88034B40D9B3E73235EB53407F33315D88034B40D9B3E73235EB534021E868554B004B40D7DD3CD521E7534021E868554B004B40
13590	11610	78.782718000000003	78.801861000000002	53.894388999999997	53.886865	Московская	0103000020E6100000010000000500000065FF3C0D18B25340C87BD5CA84F14A4065FF3C0D18B253407973B8567BF24A4006BCCCB051B353407973B8567BF24A4006BCCCB051B35340C87BD5CA84F14A4065FF3C0D18B25340C87BD5CA84F14A40
16584	11818	79.627905999999996	79.657011999999995	53.966858000000002	53.949460000000002	Школьная	0103000020E6100000010000000500000094BDA59C2FE853401A6EC0E787F94A4094BDA59C2FE8534020F0C000C2FB4A4017450F7C0CEA534020F0C000C2FB4A4017450F7C0CEA53401A6EC0E787F94A4094BDA59C2FE853401A6EC0E787F94A40
68431	13009	78.712378999999999	78.745006000000004	53.877062000000002	53.853349000000001	Мира	0103000020E61000000100000005000000DCD6169E97AD534083893F8A3AED4A40DCD6169E97AD53403D484F9143F04A40B954A52DAEAF53403D484F9143F04A40B954A52DAEAF534083893F8A3AED4A40DCD6169E97AD534083893F8A3AED4A40
16330	11440	79.561126000000002	79.627403000000001	54.028683000000001	54.006982000000001	Молодежная	0103000020E61000000100000005000000DCBB067DE9E3534091D442C9E4004B40DCBB067DE9E35340C07971E2AB034B40639AE95E27E85340C07971E2AB034B40639AE95E27E8534091D442C9E4004B40DCBB067DE9E3534091D442C9E4004B40
14040	11189	79.745791999999994	79.774467000000001	54.080074000000003	54.063955	Ломоносова	0103000020E6100000010000000500000094675E0EBBEF534035B56CAD2F084B4094675E0EBBEF534045A165DD3F0A4B40333509DE90F1534045A165DD3F0A4B40333509DE90F1534035B56CAD2F084B4094675E0EBBEF534035B56CAD2F084B40
13890	11176	78.775925999999998	78.819468000000001	54.148294999999997	54.126826999999999	Лазорская	0103000020E610000001000000050000006E8786C5A8B15340F99FFCDD3B104B406E8786C5A8B1534085949F54FB124B409607E92972B4534085949F54FB124B409607E92972B45340F99FFCDD3B104B406E8786C5A8B15340F99FFCDD3B104B40
68430	10946	79.00479	79.058518000000007	53.963484000000001	53.941701999999999	Центральная	0103000020E610000001000000050000004356B77A4EC05340F549EEB089F84A404356B77A4EC05340111C977153FB4A408D0E48C2BEC35340111C977153FB4A408D0E48C2BEC35340F549EEB089F84A404356B77A4EC05340F549EEB089F84A40
14093	11130	79.003163999999998	79.042761999999996	53.875309999999999	53.847431999999998	Полтава	0103000020E610000001000000050000009221C7D633C05340BCCADAA678EC4A409221C7D633C053404EEE77280AF04A40BDE0D39CBCC253404EEE77280AF04A40BDE0D39CBCC25340BCCADAA678EC4A409221C7D633C05340BCCADAA678EC4A40
75549	60655	79.232782	79.243786999999998	54.136054000000001	54.122252000000003	Новая	0103000020E610000001000000050000003D4679E6E5CE534070EF1AF4A50F4B403D4679E6E5CE5340B83EAC376A114B40280CCA349ACF5340B83EAC376A114B40280CCA349ACF534070EF1AF4A50F4B403D4679E6E5CE534070EF1AF4A50F4B40
68602	11804	79.837644999999995	79.859268	53.961593000000001	53.948936000000003	Школьная	0103000020E610000001000000050000001B2AC6F99BF55340A0FF1EBC76F94A401B2AC6F99BF553400188BB7A15FB4A40F59F353FFEF653400188BB7A15FB4A40F59F353FFEF65340A0FF1EBC76F94A401B2AC6F99BF55340A0FF1EBC76F94A40
13873	10429	79.208248999999995	79.283151000000004	53.995328999999998	53.966878999999999	Советская	0103000020E610000001000000050000002E1B9DF353CD53403718EAB0C2FB4A402E1B9DF353CD534054E1CFF066FF4A401A355F251FD2534054E1CFF066FF4A401A355F251FD253403718EAB0C2FB4A402E1B9DF353CD53403718EAB0C2FB4A40
13752	10429	79.208248999999995	79.283151000000004	53.995328999999998	53.966878999999999	Панарина	0103000020E610000001000000050000002E1B9DF353CD53403718EAB0C2FB4A402E1B9DF353CD534054E1CFF066FF4A401A355F251FD2534054E1CFF066FF4A401A355F251FD253403718EAB0C2FB4A402E1B9DF353CD53403718EAB0C2FB4A40
68377	10983	78.993955999999997	79.012974	54.245482000000003	54.224727000000001	Дмитрия Пахомова	0103000020E610000001000000050000006E6AA0F99CBF53409CC3B5DAC31C4B406E6AA0F99CBF5340DBE044F46B1F4B40B16CE690D4C05340DBE044F46B1F4B40B16CE690D4C053409CC3B5DAC31C4B406E6AA0F99CBF53409CC3B5DAC31C4B40
68359	10886	79.123762999999997	79.158321000000001	54.073354000000002	54.058728000000002	Центральная	0103000020E610000001000000050000001C5DA5BBEBC7534004AE2B6684074B401C5DA5BBEBC75340F183F3A963094B40485167EE21CA5340F183F3A963094B40485167EE21CA534004AE2B6684074B401C5DA5BBEBC7534004AE2B6684074B40
13750	10647	79.185118000000003	79.209057999999999	53.991571	53.976402	Студенческая	0103000020E61000000100000005000000A9F92AF9D8CB5340DFDFA0BDFAFC4A40A9F92AF9D8CB5340BD546CCCEBFE4A40E63DCE3461CD5340BD546CCCEBFE4A40E63DCE3461CD5340DFDFA0BDFAFC4A40A9F92AF9D8CB5340DFDFA0BDFAFC4A40
13779	10326	79.146687999999997	79.175685999999999	54.194234000000002	54.176183000000002	Набарежная	0103000020E61000000100000005000000CDAD105663C953403B8E1F2A8D164B40CDAD105663C95340B9E2E2A8DC184B405D177E703ECB5340B9E2E2A8DC184B405D177E703ECB53403B8E1F2A8D164B40CDAD105663C953403B8E1F2A8D164B40
68335	10064	78.634190000000004	78.674102000000005	53.785299999999999	53.762551000000002	Центральная	0103000020E61000000100000005000000D15CA79196A853401C446B459BE14A40D15CA79196A853403FC6DCB584E44A40C40AB77C24AB53403FC6DCB584E44A40C40AB77C24AB53401C446B459BE14A40D15CA79196A853401C446B459BE14A40
75572	10064	78.634190000000004	78.674102000000005	53.785299999999999	53.762551000000002	Новая	0103000020E61000000100000005000000D15CA79196A853401C446B459BE14A40D15CA79196A853403FC6DCB584E44A40C40AB77C24AB53403FC6DCB584E44A40C40AB77C24AB53401C446B459BE14A40D15CA79196A853401C446B459BE14A40
14169	11692	79.641542999999999	79.654757000000004	53.907778999999998	53.898777000000003	Центральная	0103000020E6100000010000000500000093FE5E0A0FE95340D1B2EE1F0BF34A4093FE5E0A0FE953406F7F2E1A32F44A40EF74E789E7E953406F7F2E1A32F44A40EF74E789E7E95340D1B2EE1F0BF34A4093FE5E0A0FE95340D1B2EE1F0BF34A40
13765	12296	79.259399999999999	79.278443999999993	53.708075000000001	53.696241000000001	Центральная	0103000020E61000000100000005000000462575029AD053403291D26C1ED94A40462575029AD05340BF0E9C33A2DA4A401D71C806D2D15340BF0E9C33A2DA4A401D71C806D2D153403291D26C1ED94A40462575029AD053403291D26C1ED94A40
14086	10863	79.405816000000002	79.443860000000001	53.993375999999998	53.974178000000002	Новая	0103000020E61000000100000005000000630CACE3F8D95340C93D5DDDB1FC4A40630CACE3F8D95340CE50DCF126FF4A402A00C63368DC5340CE50DCF126FF4A402A00C63368DC5340C93D5DDDB1FC4A40630CACE3F8D95340C93D5DDDB1FC4A40
14030	10028	79.017860999999996	79.027814000000006	53.766596	53.755093000000002	Ганинская	0103000020E61000000100000005000000EDB776A224C1534022382EE3A6E04A40EDB776A224C15340499F56D11FE24A40BE175FB4C7C15340499F56D11FE24A40BE175FB4C7C1534022382EE3A6E04A40EDB776A224C1534022382EE3A6E04A40
68363	12915	78.689311000000004	78.734801000000004	54.009655000000002	53.975703000000003	Ленина	0103000020E610000001000000050000007A71E2AB1DAC5340F7CDFDD5E3FC4A407A71E2AB1DAC5340179F02603C014B405C04C6FA06AF5340179F02603C014B405C04C6FA06AF5340F7CDFDD5E3FC4A407A71E2AB1DAC5340F7CDFDD5E3FC4A40
13937	34708	37.196235999999999	37.217920999999997	55.755884999999999	55.744687999999996	Длинная	0103000020E610000001000000050000002026E1421E994240A0DCB6EF51DF4B402026E1421E994240BB44F5D6C0E04B40490ED8D5E49B4240BB44F5D6C0E04B40490ED8D5E49B4240A0DCB6EF51DF4B402026E1421E994240A0DCB6EF51DF4B40
14007	41350	80.392346000000003	80.405129000000002	54.205441999999998	54.196292999999997	Гагарина	0103000020E61000000100000005000000DAAD65321C19544084B7072120194B40DAAD65321C195440C79C67EC4B1A4B40516A2FA2ED195440C79C67EC4B1A4B40516A2FA2ED19544084B7072120194B40DAAD65321C19544084B7072120194B40
13551	9814	80.772693000000004	80.788916	54.270054000000002	54.260868000000002	Центральная	0103000020E61000000100000005000000483657CD733154405649641F64214B40483657CD73315440B613252191224B40A2D288997D325440B613252191224B40A2D288997D3254405649641F64214B40483657CD733154405649641F64214B40
68647	41341	80.507994999999994	80.525852999999998	54.123159999999999	54.111955999999999	Школьная	0103000020E6100000010000000500000004E275FD82205440A54BFF92540E4B4004E275FD822054407216F6B4C30F4B4039605793A72154407216F6B4C30F4B4039605793A7215440A54BFF92540E4B4004E275FD82205440A54BFF92540E4B40
13988	41341	80.507994999999994	80.525852999999998	54.123159999999999	54.111955999999999	Центральная	0103000020E6100000010000000500000004E275FD82205440A54BFF92540E4B4004E275FD822054407216F6B4C30F4B4039605793A72154407216F6B4C30F4B4039605793A7215440A54BFF92540E4B4004E275FD82205440A54BFF92540E4B40
14017	9269	80.506197999999998	80.531513000000004	54.362363000000002	54.350133	Комсомольская	0103000020E610000001000000050000003DD34B8C652054400C207C28D12C4B403DD34B8C65205440E62329E9612E4B4087191A4F04225440E62329E9612E4B4087191A4F042254400C207C28D12C4B403DD34B8C652054400C207C28D12C4B40
13726	9713	80.456072000000006	80.518083000000004	54.345976	54.318776999999997	Революционная	0103000020E61000000100000005000000C4279D48301D5440C6DB4AAFCD284B40C4279D48301D5440B7990AF1482C4B404567994528215440B7990AF1482C4B404567994528215440C6DB4AAFCD284B40C4279D48301D5440C6DB4AAFCD284B40
14285	9845	80.580129999999997	80.636471999999998	54.373683	54.347262000000001	Лахина	0103000020E610000001000000050000006C5B94D9202554406092CA14732C4B406C5B94D9202554401C0934D8D42F4B4076340EF5BB2854401C0934D8D42F4B4076340EF5BB2854406092CA14732C4B406C5B94D9202554406092CA14732C4B40
13864	41311	80.848716999999994	80.906856000000005	54.446261	54.422381000000001	Центральная	0103000020E61000000100000005000000CAA31B6151365440D4B9A29410364B40CAA31B6151365440793D98141F394B409C8BBFED093A5440793D98141F394B409C8BBFED093A5440D4B9A29410364B40CAA31B6151365440D4B9A29410364B40
14177	41385	82.20608	82.230101000000005	54.918095000000001	54.907325	Школьная	0103000020E6100000010000000500000005172B6A308D5440EEEBC03923744B4005172B6A308D544081CF0F2384754B40B9718BF9B98E544081CF0F2384754B40B9718BF9B98E5440EEEBC03923744B4005172B6A308D5440EEEBC03923744B40
13515	41225	82.489138999999994	82.506028000000001	54.972209999999997	54.955933999999999	Центральная	0103000020E61000000100000005000000AE0CAA0D4E9F54403691990B5C7A4B40AE0CAA0D4E9F54400D6C9560717C4B400FB743C362A054400D6C9560717C4B400FB743C362A054403691990B5C7A4B40AE0CAA0D4E9F54403691990B5C7A4B40
13734	7488	82.419475000000006	82.462630000000004	55.000186999999997	54.985647999999998	Новая	0103000020E61000000100000005000000569FABADD89A544014AFB2B6297E4B40569FABADD89A54403271AB2006804B408109DCBA9B9D54403271AB2006804B408109DCBA9B9D544014AFB2B6297E4B40569FABADD89A544014AFB2B6297E4B40
14077	41369	81.325291000000007	82.821893000000003	55.513697999999998	54.649197999999998	Клубная	0103000020E61000000100000005000000B9AB5791D1545440765089EB18534B40B9AB5791D1545440A30227DBC0C14B40EDF318E599B45440A30227DBC0C14B40EDF318E599B45440765089EB18534B40B9AB5791D1545440765089EB18534B40
13601	41248	81.832255000000004	81.849027000000007	55.176197999999999	55.160750999999998	 Лесная	0103000020E61000000100000005000000AEBB79AA437554404FE61F7D93944B40AEBB79AA4375544070CFF3A78D964B40F29A57755676544070CFF3A78D964B40F29A5775567654404FE61F7D93944B40AEBB79AA437554404FE61F7D93944B40
68969	41211	82.052756000000002	82.060301999999993	55.166840000000001	55.150854000000002	Центральная	0103000020E61000000100000005000000BDAAB35A60835440433C122F4F934B40BDAAB35A6083544013D55B035B954B408978EBFCDB83544013D55B035B954B408978EBFCDB835440433C122F4F934B40BDAAB35A60835440433C122F4F934B40
13942	40453	82.496900999999994	82.514508000000006	54.901367	54.888879000000003	Центральная	0103000020E610000001000000050000006116DA39CD9F5440F48C7DC9C6714B406116DA39CD9F5440C9586DFE5F734B40F261F6B2EDA05440C9586DFE5F734B40F261F6B2EDA05440F48C7DC9C6714B406116DA39CD9F5440F48C7DC9C6714B40
16559	7207	82.431728000000007	82.478089999999995	55.025776999999998	55.000559000000003	Вокзальная	0103000020E610000001000000050000001F317A6EA19B5440F75B3B5112804B401F317A6EA19B544097FE25A94C834B40DBA2CC06999E544097FE25A94C834B40DBA2CC06999E5440F75B3B5112804B401F317A6EA19B5440F75B3B5112804B40
14184	6934	82.103322000000006	82.437944000000002	54.835242999999998	54.722540000000002	Центральный переулок	0103000020E6100000010000000500000045BDE0D39C865440A306D3307C5C4B4045BDE0D39C865440419B1C3EE96A4B40AF5E4546079C5440419B1C3EE96A4B40AF5E4546079C5440A306D3307C5C4B4045BDE0D39C865440A306D3307C5C4B40
13449	41197	81.672481000000005	81.698235999999994	55.203642000000002	55.193216999999997	Советская	0103000020E610000001000000050000009C8BBFED096B5440FF03AC55BB984B409C8BBFED096B5440C80BE9F0109A4B40F3380CE6AF6C5440C80BE9F0109A4B40F3380CE6AF6C5440FF03AC55BB984B409C8BBFED096B5440FF03AC55BB984B40
16623	49611	81.603876999999997	81.618654000000006	55.213915999999998	55.203786000000001	Сибирская	0103000020E610000001000000050000009F73B7EBA5665440FBB0DEA8159A4B409F73B7EBA5665440AA0B7899619B4B408962F20698675440AA0B7899619B4B408962F20698675440FBB0DEA8159A4B409F73B7EBA5665440FBB0DEA8159A4B40
13673	6048	82.303888999999998	82.329804999999993	55.205424999999998	55.190641999999997	Маяковского	0103000020E610000001000000050000004E27D9EA729354403C9F01F566984B404E27D9EA72935440F163CC5D4B9A4B40AA436E861B955440F163CC5D4B9A4B40AA436E861B9554403C9F01F566984B404E27D9EA729354403C9F01F566984B40
13698	6117	82.282599000000005	82.301580000000001	55.303939	55.294324000000003	Заводская	0103000020E6100000010000000500000078B81D1A16925440C636A968ACA54B4078B81D1A169254404E7D2079E7A64B402C4833164D9354404E7D2079E7A64B402C4833164D935440C636A968ACA54B4078B81D1A16925440C636A968ACA54B40
13507	41221	81.833108999999993	81.847634999999997	54.869197	54.861792999999999	Центральная	0103000020E61000000100000005000000354069A851755440FB75A73B4F6E4B40354069A8517554400264E8D8416F4B407AFCDEA63F7654400264E8D8416F4B407AFCDEA63F765440FB75A73B4F6E4B40354069A851755440FB75A73B4F6E4B40
14019	8352	81.999504000000002	82.011190999999997	54.850132000000002	54.838493999999997	Школьная	0103000020E61000000100000005000000280EA0DFF77F544034F279C5536B4B40280EA0DFF77F54403CA41820D16C4B409CC0745AB78054403CA41820D16C4B409CC0745AB780544034F279C5536B4B40280EA0DFF77F544034F279C5536B4B40
13511	6361	81.919347000000002	81.954425999999998	55.051921999999998	55.033723000000002	Школьная	0103000020E610000001000000050000003FABCC94D67A5440BF0F070951844B403FABCC94D67A5440B1F84D61A5864B40EF1CCA50157D5440B1F84D61A5864B40EF1CCA50157D5440BF0F070951844B403FABCC94D67A5440BF0F070951844B40
14012	8716	82.166689000000005	82.245939000000007	55.043194999999997	54.995187999999999	Строительная 	0103000020E6100000010000000500000097E65608AB8A544092AF0452627F4B4097E65608AB8A5440E42CEC6987854B40E773EE76BD8F5440E42CEC6987854B40E773EE76BD8F544092AF0452627F4B4097E65608AB8A544092AF0452627F4B40
13522	8716	82.166689000000005	82.245939000000007	55.043194999999997	54.995187999999999	Строительная	0103000020E6100000010000000500000097E65608AB8A544092AF0452627F4B4097E65608AB8A5440E42CEC6987854B40E773EE76BD8F5440E42CEC6987854B40E773EE76BD8F544092AF0452627F4B4097E65608AB8A544092AF0452627F4B40
13851	8716	82.166689000000005	82.245939000000007	55.043194999999997	54.995187999999999	Малокузнецкая	0103000020E6100000010000000500000097E65608AB8A544092AF0452627F4B4097E65608AB8A5440E42CEC6987854B40E773EE76BD8F5440E42CEC6987854B40E773EE76BD8F544092AF0452627F4B4097E65608AB8A544092AF0452627F4B40
13523	8716	82.166689000000005	82.245939000000007	55.043194999999997	54.995187999999999	Максима Горького	0103000020E6100000010000000500000097E65608AB8A544092AF0452627F4B4097E65608AB8A5440E42CEC6987854B40E773EE76BD8F5440E42CEC6987854B40E773EE76BD8F544092AF0452627F4B4097E65608AB8A544092AF0452627F4B40
14182	8716	82.166689000000005	82.245939000000007	55.043194999999997	54.995187999999999	 Кузнецкая	0103000020E6100000010000000500000097E65608AB8A544092AF0452627F4B4097E65608AB8A5440E42CEC6987854B40E773EE76BD8F5440E42CEC6987854B40E773EE76BD8F544092AF0452627F4B4097E65608AB8A544092AF0452627F4B40
14884	7014	82.112054000000001	82.123849000000007	54.780776000000003	54.771315000000001	Раздольная	0103000020E61000000100000005000000B4588AE42B87544006F52D73BA624B40B4588AE42B87544038C0CC77F0634B401C295B24ED87544038C0CC77F0634B401C295B24ED87544006F52D73BA624B40B4588AE42B87544006F52D73BA624B40
13705	41271	81.934672000000006	81.957076000000001	54.914504000000001	54.903547000000003	Центральная	0103000020E610000001000000050000002A1F82AAD17B544010B3976DA7734B402A1F82AAD17B5440D50792770E754B4056F2B1BB407D5440D50792770E754B4056F2B1BB407D544010B3976DA7734B402A1F82AAD17B544010B3976DA7734B40
14158	41382	81.898847000000004	82.549695	55.214553000000002	55.105671000000001	Лесная	0103000020E61000000100000005000000E54691B5867954405C9198A0868D4B40E54691B5867954401D210379769B4B4095F1EF332EA354401D210379769B4B4095F1EF332EA354405C9198A0868D4B40E54691B5867954405C9198A0868D4B40
13721	41278	82.285068999999993	82.308901000000006	54.951813000000001	54.942661000000001	Центральная	0103000020E610000001000000050000009E060C923E9254407A1B9B1DA9784B409E060C923E9254402E742502D5794B40E92CB308C59354402E742502D5794B40E92CB308C59354407A1B9B1DA9784B409E060C923E9254407A1B9B1DA9784B40
13456	41198	81.927638999999999	81.953214000000003	55.31765	55.301248999999999	Школьная	0103000020E61000000100000005000000A0DFF76F5E7B5440F279C5538FA64B40A0DFF76F5E7B544086C954C1A8A84B40B8054B75017D544086C954C1A8A84B40B8054B75017D5440F279C5538FA64B40A0DFF76F5E7B5440F279C5538FA64B40
13494	5978	81.605654999999999	81.635686000000007	55.099521000000003	55.078128	Садовая	0103000020E610000001000000050000002B6A300DC366544071732A19008A4B402B6A300DC3665440F321A81ABD8C4B409B215514AF685440F321A81ABD8C4B409B215514AF68544071732A19008A4B402B6A300DC366544071732A19008A4B40
14066	41367	82.152675000000002	82.164237	54.976385000000001	54.971491	Цетральная	0103000020E61000000100000005000000ADFA5C6DC5895440DEAD2CD1597C4B40ADFA5C6DC589544009A7052FFA7C4B40C3F2E7DB828A544009A7052FFA7C4B40C3F2E7DB828A5440DEAD2CD1597C4B40ADFA5C6DC5895440DEAD2CD1597C4B40
16536	46655	82.140162000000004	82.171828000000005	55.253208999999998	55.240394999999999	Московская	0103000020E610000001000000050000001689096AF88854409B8F6B43C59E4B401689096AF8885440C4060B2769A04B406022DE3AFF8A5440C4060B2769A04B406022DE3AFF8A54409B8F6B43C59E4B401689096AF88854409B8F6B43C59E4B40
13830	41300	82.473742000000001	82.496792999999997	55.068123	55.058481999999998	Молодёжная	0103000020E61000000100000005000000772FF7C9519E5440CCB392567C874B40772FF7C9519E54407E8D2441B8884B406EF8DD74CB9F54407E8D2441B8884B406EF8DD74CB9F5440CCB392567C874B40772FF7C9519E5440CCB392567C874B40
14157	41381	82.033216999999993	82.056753	55.074814000000003	55.058193000000003	Новая	0103000020E61000000100000005000000F52A323A2082544096ED43DE72874B40F52A323A2082544038A4518193894B40CBBC55D7A183544038A4518193894B40CBBC55D7A183544096ED43DE72874B40F52A323A2082544096ED43DE72874B40
13537	9147	82.062996999999996	82.078502	55.012352	55.003126000000002	Центральная	0103000020E61000000100000005000000C0AF91240884544037E2C96E66804B40C0AF912408845440250516C094814B40EBAA402D06855440250516C094814B40EBAA402D0685544037E2C96E66804B40C0AF91240884544037E2C96E66804B40
13460	41200	82.287333000000004	82.315899000000002	54.836517999999998	54.824570000000001	Школьная	0103000020E61000000100000005000000F183F3A963925440A1A17F828B694B40F183F3A963925440F6419605136B4B40B47570B037945440F6419605136B4B40B47570B037945440A1A17F828B694B40F183F3A963925440A1A17F828B694B40
15917	5211	83.555762999999999	83.571663000000001	55.664735999999998	55.650779999999997	Центральная	0103000020E61000000100000005000000EB54F99E91E35440087250C24CD34B40EB54F99E91E35440A73CBA1116D54B405455682096E45440A73CBA1116D54B405455682096E45440087250C24CD34B40EB54F99E91E35440087250C24CD34B40
68428	4292	82.508004	82.531171999999998	55.495925	55.482667999999997	Школьная	0103000020E610000001000000050000002E8F352383A05440B169A510C8BD4B402E8F352383A0544068226C787ABF4B404223D8B8FEA1544068226C787ABF4B404223D8B8FEA15440B169A510C8BD4B402E8F352383A05440B169A510C8BD4B40
13452	5058	83.256714000000002	83.274473999999998	55.521006999999997	55.511037000000002	Лесная	0103000020E61000000100000005000000399B8E006ED05440E20511A969C14B40399B8E006ED0544058FE7C5BB0C24B408C6665FB90D1544058FE7C5BB0C24B408C6665FB90D15440E20511A969C14B40399B8E006ED05440E20511A969C14B40
13627	3930	82.776240999999999	82.783193999999995	55.350473999999998	55.337091999999998	Титова	0103000020E610000001000000050000001E34BBEEADB1544022DFA5D425AB4B401E34BBEEADB15440950C0055DCAC4B40191BBAD91FB25440950C0055DCAC4B40191BBAD91FB2544022DFA5D425AB4B401E34BBEEADB1544022DFA5D425AB4B40
13948	4027	82.550342000000001	82.575458999999995	55.215133000000002	55.186587000000003	Советская	0103000020E6100000010000000500000060E7A6CD38A35440EC6D3315E2974B4060E7A6CD38A354402BA5677A899B4B40164CFC51D4A454402BA5677A899B4B40164CFC51D4A45440EC6D3315E2974B4060E7A6CD38A35440EC6D3315E2974B40
13815	4315	82.749166000000002	82.782286999999997	55.386415	55.369484999999997	Калинина	0103000020E610000001000000050000009C51F355F2AF544068AED3484BAF4B409C51F355F2AF544088D7F50B76B14B4080457EFD10B2544088D7F50B76B14B4080457EFD10B2544068AED3484BAF4B409C51F355F2AF544068AED3484BAF4B40
13434	4248	82.394285999999994	82.422359	55.450563000000002	55.432693999999998	Советская	0103000020E6100000010000000500000052D158FB3B9954407496598462B74B4052D158FB3B995440D2E4620CACB94B40F60A0BEE079B5440D2E4620CACB94B40F60A0BEE079B54407496598462B74B4052D158FB3B9954407496598462B74B40
14018	5442	82.679951000000003	82.701519000000005	56.023117999999997	56.013038999999999	Октябрьская	0103000020E610000001000000050000007BF8325184AB544049490F43AB014C407BF8325184AB544076F9D687F5024C4073A1F2AFE5AC544076F9D687F5024C4073A1F2AFE5AC544049490F43AB014C407BF8325184AB544049490F43AB014C40
13838	5798	82.353440000000006	82.383883999999995	56.140900999999999	56.130146000000003	Береговая	0103000020E610000001000000050000004A46CEC29E96544045DAC69FA8104C404A46CEC29E965440A27C410B09124C404A5D328E91985440A27C410B09124C404A5D328E9198544045DAC69FA8104C404A46CEC29E96544045DAC69FA8104C40
13831	5420	82.677875	82.739248000000003	56.011172000000002	55.979933000000003	Максима Горького	0103000020E61000000100000005000000AAF1D24D62AB5440B6A2CD716EFD4B40AAF1D24D62AB5440C25087156E014C408AE8D7D64FAF5440C25087156E014C408AE8D7D64FAF5440B6A2CD716EFD4B40AAF1D24D62AB5440B6A2CD716EFD4B40
15803	4151	82.387540000000001	82.432213000000004	55.296712999999997	55.278492999999997	Мира	0103000020E6100000010000000500000014799274CD9854401C959BA8A5A34B4014799274CD98544026A60BB1FAA54B40FDF9B660A99B544026A60BB1FAA54B40FDF9B660A99B54401C959BA8A5A34B4014799274CD9854401C959BA8A5A34B40
68951	41339	82.520733000000007	82.538798	56.171757999999997	56.164175	Иванова	0103000020E61000000100000005000000AC3C81B053A1544010E9B7AF03154C40AC3C81B053A15440C669882AFC154C409D499BAA7BA25440C669882AFC154C409D499BAA7BA2544010E9B7AF03154C40AC3C81B053A1544010E9B7AF03154C40
13981	41339	82.520733000000007	82.538798	56.171757999999997	56.164175	Горького	0103000020E61000000100000005000000AC3C81B053A1544010E9B7AF03154C40AC3C81B053A15440C669882AFC154C409D499BAA7BA25440C669882AFC154C409D499BAA7BA2544010E9B7AF03154C40AC3C81B053A1544010E9B7AF03154C40
13958	5676	82.540199999999999	82.562360999999996	55.854052000000003	55.843040000000002	Школьная	0103000020E61000000100000005000000265305A392A25440249C16BCE8EB4B40265305A392A25440AD8A709351ED4B40EFE2FDB8FDA35440AD8A709351ED4B40EFE2FDB8FDA35440249C16BCE8EB4B40265305A392A25440249C16BCE8EB4B40
13641	4033	82.648842000000002	82.676446999999996	55.282231000000003	55.272190000000002	Октябрьская	0103000020E610000001000000050000005C9198A086A954402D26361FD7A24B405C9198A086A954406D75392520A44B408C9E5BE84AAB54406D75392520A44B408C9E5BE84AAB54402D26361FD7A24B405C9198A086A954402D26361FD7A24B40
13867	41312	82.732268000000005	82.739643999999998	56.033686000000003	56.025185	Лесная	0103000020E6100000010000000500000012FA997ADDAE5440C5AC174339034C4012FA997ADDAE5440A22AA6D24F044C40B0ABC95356AF5440A22AA6D24F044C40B0ABC95356AF5440C5AC174339034C4012FA997ADDAE5440C5AC174339034C40
14164	5740	83.008607999999995	83.043535000000006	56.039876999999997	56.023183000000003	Школьная	0103000020E61000000100000005000000F99E91088DC054405E6919A9F7024C40F99E91088DC05440696E85B01A054C40CF4E0647C9C25440696E85B01A054C40CF4E0647C9C254405E6919A9F7024C40F99E91088DC054405E6919A9F7024C40
16223	3752	82.709729999999993	82.768281999999999	55.325001	55.294446999999998	Чехова	0103000020E610000001000000050000005DBF60376CAD5440E1B37570B0A54B405DBF60376CAD54406A15FDA199A94B40C00644882BB154406A15FDA199A94B40C00644882BB15440E1B37570B0A54B405DBF60376CAD5440E1B37570B0A54B40
14168	3752	82.709729999999993	82.768281999999999	55.325001	55.294446999999998	Советская	0103000020E610000001000000050000005DBF60376CAD5440E1B37570B0A54B405DBF60376CAD54406A15FDA199A94B40C00644882BB154406A15FDA199A94B40C00644882BB15440E1B37570B0A54B405DBF60376CAD5440E1B37570B0A54B40
16337	3752	82.709729999999993	82.768281999999999	55.325001	55.294446999999998	Московская	0103000020E610000001000000050000005DBF60376CAD5440E1B37570B0A54B405DBF60376CAD54406A15FDA199A94B40C00644882BB154406A15FDA199A94B40C00644882BB15440E1B37570B0A54B405DBF60376CAD5440E1B37570B0A54B40
13467	5340	83.185333999999997	83.203192000000001	55.685523000000003	55.662953000000002	Советская	0103000020E610000001000000050000008F352383DCCB54407EE4D6A4DBD44B408F352383DCCB5440F2D3B837BFD74B40C4B3041901CD5440F2D3B837BFD74B40C4B3041901CD54407EE4D6A4DBD44B408F352383DCCB54407EE4D6A4DBD44B40
13983	5156	83.467827	83.486198000000002	55.671548999999999	55.663353999999998	Зарипова	0103000020E61000000100000005000000E44BA8E0F0DD5440DCD5ABC8E8D44B40E44BA8E0F0DD5440AC545051F5D54B405C5837DE1DDF5440AC545051F5D54B405C5837DE1DDF5440DCD5ABC8E8D44B40E44BA8E0F0DD5440DCD5ABC8E8D44B40
13433	4138	82.555255000000002	82.585222999999999	55.312711999999998	55.306716999999999	Дорожная	0103000020E61000000100000005000000317C444C89A354404910AE8042A74B40317C444C89A354408B8862F206A84B407D772B4B74A554408B8862F206A84B407D772B4B74A554404910AE8042A74B40317C444C89A354404910AE8042A74B40
14139	4550	82.736526999999995	82.765713000000005	55.632164000000003	55.610545000000002	Ленина	0103000020E61000000100000005000000BE67244223AF544040DEAB5626CE4B40BE67244223AF5440B2DAFCBFEAD04B40D047197101B15440B2DAFCBFEAD04B40D047197101B1544040DEAB5626CE4B40BE67244223AF544040DEAB5626CE4B40
14121	3925	82.699408000000005	82.733345999999997	55.294089	55.284301999999997	Суворова	0103000020E61000000100000005000000E4A3C519C3AC5440FC17080264A44B40E4A3C519C3AC5440828E56B5A4A54B40C1A90F24EFAE5440828E56B5A4A54B40C1A90F24EFAE5440FC17080264A44B40E4A3C519C3AC5440FC17080264A44B40
16607	4408	82.758077	82.778639999999996	55.447274	55.430599999999998	Школьная	0103000020E6100000010000000500000063B6645584B054402CD49AE61DB74B4063B6645584B05440F12C414640B94B40E0D6DD3CD5B15440F12C414640B94B40E0D6DD3CD5B154402CD49AE61DB74B4063B6645584B054402CD49AE61DB74B40
13575	1029	80.220965000000007	80.331180000000003	55.213962000000002	55.174373000000003	Советская	0103000020E61000000100000005000000E223624A240E54401827BEDA51964B40E223624A240E54401B4B581B639B4B40B745990D321554401B4B581B639B4B40B745990D321554401827BEDA51964B40E223624A240E54401827BEDA51964B40
13884	41318	80.134089000000003	80.158371000000002	55.166361999999999	55.156759999999998	Лесная	0103000020E61000000100000005000000377007EA9408544015A930B610944B40377007EA9408544009A69A594B954B40A1681EC0220A544009A69A594B954B40A1681EC0220A544015A930B610944B40377007EA9408544015A930B610944B40
14180	41387	78.009196000000003	78.021979000000002	53.765504999999997	53.760209000000003	Школьная	0103000020E6100000010000000500000042D0D1AA96805340FC8F4C874EE14A4042D0D1AA9680534055F65D11FCE14A40B98C9B1A6881534055F65D11FCE14A40B98C9B1A68815340FC8F4C874EE14A4042D0D1AA96805340FC8F4C874EE14A40
68351	31339	78.162700000000001	78.197348000000005	53.811278999999999	53.800857000000001	Центральная	0103000020E61000000100000005000000CAC342AD698A5340E7E26F7B82E64A40CAC342AD698A53403E7782FDD7E74A40967B8159A18C53403E7782FDD7E74A40967B8159A18C5340E7E26F7B82E64A40CAC342AD698A5340E7E26F7B82E64A40
13876	764	78.359403999999998	78.386902000000006	53.855483999999997	53.841833000000001	Центральная	0103000020E610000001000000050000004D83A27900975340C7D8092FC1EB4A404D83A279009753402920ED7F80ED4A4073309B00C39853402920ED7F80ED4A4073309B00C3985340C7D8092FC1EB4A404D83A27900975340C7D8092FC1EB4A40
68357	642	78.482815000000002	78.523606999999998	53.602173999999998	53.567284000000001	Набережная	0103000020E610000001000000050000002BC1E270E69E5340A4C519C39CC84A402BC1E270E69E53403140A20914CD4A403A3DEFC682A153403140A20914CD4A403A3DEFC682A15340A4C519C39CC84A402BC1E270E69E5340A4C519C39CC84A40
13556	41235	77.793492999999998	77.841678000000002	53.730395000000001	53.719681000000001	Зеленая	0103000020E61000000100000005000000B726DD96C8725340BB46CB811EDC4A40B726DD96C8725340BA1457957DDD4A40D0F0660DDE755340BA1457957DDD4A40D0F0660DDE755340BB46CB811EDC4A40B726DD96C8725340BB46CB811EDC4A40
14487	735	78.340772999999999	78.350905999999995	53.599924000000001	53.588102999999997	Мира	0103000020E6100000010000000500000007978E39CF955340F9D687F546CB4A4007978E39CF955340F20A444FCACC4A40177E703E75965340F20A444FCACC4A40177E703E75965340F9D687F546CB4A4007978E39CF955340F9D687F546CB4A40
68355	48892	77.512957999999998	77.547363000000004	53.618045000000002	53.609946999999998	35 лет Победы	0103000020E610000001000000050000002E8ECA4DD46053408BA548BE12CE4A402E8ECA4DD4605340693A3B191CCF4A409702D2FE07635340693A3B191CCF4A409702D2FE076353408BA548BE12CE4A402E8ECA4DD46053408BA548BE12CE4A40
68425	41356	78.565047000000007	78.585752999999997	54.114806000000002	54.093736999999997	переулок Центральный	0103000020E61000000100000005000000FD6CE4BA29A453406BB6F292FF0B4B40FD6CE4BA29A453403AB187F6B10E4B402BA226FA7CA553403AB187F6B10E4B402BA226FA7CA553406BB6F292FF0B4B40FD6CE4BA29A453406BB6F292FF0B4B40
14331	41766	77.911963	77.928967999999998	53.672212000000002	53.656334000000001	Школьная	0103000020E610000001000000050000005F0A0F9A5D7A53405EA0A4C002D44A405F0A0F9A5D7A534048FDF50A0BD64A40F4C13236747B534048FDF50A0BD64A40F4C13236747B53405EA0A4C002D44A405F0A0F9A5D7A53405EA0A4C002D44A40
68376	49662	77.636906999999994	77.657702999999998	53.744385999999999	53.725371000000003	Ленина	0103000020E61000000100000005000000FBE59315C3685340C13BF9F4D8DC4A40FBE59315C3685340D5CC5A0A48DF4A40CADE52CE176A5340D5CC5A0A48DF4A40CADE52CE176A5340C13BF9F4D8DC4A40FBE59315C3685340C13BF9F4D8DC4A40
68457	49666	77.752583000000001	77.761638000000005	53.438253000000003	53.428269999999998	Молодёжная	0103000020E61000000100000005000000A321E3512A705340D0ED258DD1B64A40A321E3512A705340DC2F9FAC18B84A4004594FADBE705340DC2F9FAC18B84A4004594FADBE705340D0ED258DD1B64A40A321E3512A705340D0ED258DD1B64A40
13860	31484	77.952369000000004	77.959851999999998	53.780037999999998	53.777329999999999	Станционная	0103000020E610000001000000050000005A2E1B9DF37C53408F19A88C7FE34A405A2E1B9DF37C534091D10149D8E34A40034015376E7D534091D10149D8E34A40034015376E7D53408F19A88C7FE34A405A2E1B9DF37C53408F19A88C7FE34A40
13567	41239	77.894238999999999	77.900041999999999	53.465676000000002	53.453933999999997	Сиреневая	0103000020E61000000100000005000000B2F336363B7953406F4562821ABA4A40B2F336363B7953401C446B459BBB4A40B1C1C2499A7953401C446B459BBB4A40B1C1C2499A7953406F4562821ABA4A40B2F336363B7953406F4562821ABA4A40
68426	48688	78.519375999999994	78.542068	53.784979999999997	53.773978	Заречная	0103000020E61000000100000005000000F294D5743DA1534068E90AB611E34A40F294D5743DA15340CD0182397AE44A40520DFB3DB1A25340CD0182397AE44A40520DFB3DB1A2534068E90AB611E34A40F294D5743DA1534068E90AB611E34A40
68582	49110	78.318055000000001	78.343873000000002	53.926971000000002	53.912913000000003	Пушкина	0103000020E6100000010000000500000013D55B035B945340F08B4B55DAF44A4013D55B035B94534093AB58FCA6F64A408E3EE6030296534093AB58FCA6F64A408E3EE60302965340F08B4B55DAF44A4013D55B035B945340F08B4B55DAF44A40
14163	41275	78.038597999999993	78.063732999999999	53.649566999999998	53.637931000000002	Центральная	0103000020E6100000010000000500000039ECBE6378825340630D17B9A7D14A4039ECBE6378825340C9C7EE0225D34A4043AB933314845340C9C7EE0225D34A4043AB933314845340630D17B9A7D14A4039ECBE6378825340630D17B9A7D14A40
68333	41275	78.038597999999993	78.063732999999999	53.649566999999998	53.637931000000002	Ценетральная	0103000020E6100000010000000500000039ECBE6378825340630D17B9A7D14A4039ECBE6378825340C9C7EE0225D34A4043AB933314845340C9C7EE0225D34A4043AB933314845340630D17B9A7D14A4039ECBE6378825340630D17B9A7D14A40
13877	917	78.201498999999998	78.223849000000001	54.00403	53.992300999999998	Школьная	0103000020E610000001000000050000004FCB0F5CE58C5340E0641BB803FF4A404FCB0F5CE58C5340F819170E84004B40828FC18A538E5340F819170E84004B40828FC18A538E5340E0641BB803FF4A404FCB0F5CE58C5340E0641BB803FF4A40
13862	41310	78.385886999999997	78.410068999999993	54.220047000000001	54.196077000000002	Школьная	0103000020E61000000100000005000000E63C635FB2985340B83F170D19194B40E63C635FB29853409D4A06802A1C4B409E060C923E9A53409D4A06802A1C4B409E060C923E9A5340B83F170D19194B40E63C635FB2985340B83F170D19194B40
13835	29532	77.996673999999999	78.087089000000006	53.754268000000003	53.715733	Щорса	0103000020E6100000010000000500000081B1BE81C97F534080D591239DDB4A4081B1BE81C97F5340AD3594DA8BE04A40D9B5BDDD92855340AD3594DA8BE04A40D9B5BDDD9285534080D591239DDB4A4081B1BE81C97F534080D591239DDB4A40
16567	29532	77.996673999999999	78.087089000000006	53.754268000000003	53.715733	Фрунзе	0103000020E6100000010000000500000081B1BE81C97F534080D591239DDB4A4081B1BE81C97F5340AD3594DA8BE04A40D9B5BDDD92855340AD3594DA8BE04A40D9B5BDDD9285534080D591239DDB4A4081B1BE81C97F534080D591239DDB4A40
14005	29532	77.996673999999999	78.087089000000006	53.754268000000003	53.715733	Тургенева	0103000020E6100000010000000500000081B1BE81C97F534080D591239DDB4A4081B1BE81C97F5340AD3594DA8BE04A40D9B5BDDD92855340AD3594DA8BE04A40D9B5BDDD9285534080D591239DDB4A4081B1BE81C97F534080D591239DDB4A40
13709	29532	77.996673999999999	78.087089000000006	53.754268000000003	53.715733	Сергея Лазо	0103000020E6100000010000000500000081B1BE81C97F534080D591239DDB4A4081B1BE81C97F5340AD3594DA8BE04A40D9B5BDDD92855340AD3594DA8BE04A40D9B5BDDD9285534080D591239DDB4A4081B1BE81C97F534080D591239DDB4A40
13713	29532	77.996673999999999	78.087089000000006	53.754268000000003	53.715733	Луначарского	0103000020E6100000010000000500000081B1BE81C97F534080D591239DDB4A4081B1BE81C97F5340AD3594DA8BE04A40D9B5BDDD92855340AD3594DA8BE04A40D9B5BDDD9285534080D591239DDB4A4081B1BE81C97F534080D591239DDB4A40
13849	29532	77.996673999999999	78.087089000000006	53.754268000000003	53.715733	Ленина	0103000020E6100000010000000500000081B1BE81C97F534080D591239DDB4A4081B1BE81C97F5340AD3594DA8BE04A40D9B5BDDD92855340AD3594DA8BE04A40D9B5BDDD9285534080D591239DDB4A4081B1BE81C97F534080D591239DDB4A40
68586	49665	78.258227000000005	78.267398999999997	53.628084999999999	53.620410999999997	Центральная	0103000020E610000001000000050000006EFC89CA86905340118AADA069CF4A406EFC89CA86905340D80DDB1665D04A40EBFEB1101D915340D80DDB1665D04A40EBFEB1101D915340118AADA069CF4A406EFC89CA86905340118AADA069CF4A40
68686	49663	78.487611999999999	78.507591000000005	53.726084999999998	53.708016000000001	Школьная	0103000020E61000000100000005000000C748F608359F5340BA85AE44A0DA4A40C748F608359F5340DE8E705AF0DC4A409D2FF65E7CA05340DE8E705AF0DC4A409D2FF65E7CA05340BA85AE44A0DA4A40C748F608359F5340BA85AE44A0DA4A40
68962	49663	78.487611999999999	78.507591000000005	53.726084999999998	53.708016000000001	Калиновская	0103000020E61000000100000005000000C748F608359F5340BA85AE44A0DA4A40C748F608359F5340DE8E705AF0DC4A409D2FF65E7CA05340DE8E705AF0DC4A409D2FF65E7CA05340BA85AE44A0DA4A40C748F608359F5340BA85AE44A0DA4A40
68687	32347	77.866202000000001	77.888750000000002	53.595301999999997	53.585301999999999	Набережная	0103000020E61000000100000005000000B56E83DA6F77534046240A2DEBCA4A40B56E83DA6F775340279F1EDB32CC4A407B14AE47E1785340279F1EDB32CC4A407B14AE47E178534046240A2DEBCA4A40B56E83DA6F77534046240A2DEBCA4A40
16473	49347	78.152351999999993	78.164201000000006	53.651792999999998	53.644513000000003	Сельская	0103000020E61000000100000005000000BB5E9A22C0895340666CE8667FD24A40BB5E9A22C08953408061F9F36DD34A401D3EE944828A53408061F9F36DD34A401D3EE944828A5340666CE8667FD24A40BB5E9A22C0895340666CE8667FD24A40
68354	31754	78.463527999999997	78.486759000000006	54.048278000000003	54.024678999999999	Центральная	0103000020E61000000100000005000000F0315871AA9D5340F1F274AE28034B40F0315871AA9D5340E38E37F92D064B402882380F279F5340E38E37F92D064B402882380F279F5340F1F274AE28034B40F0315871AA9D5340F1F274AE28034B40
13865	32014	78.34469	78.356386000000001	53.750802	53.739789999999999	Центральная	0103000020E610000001000000050000008750A5660F96534034F44F70B1DE4A408750A5660F965340BDE2A9471AE04A4025B03907CF965340BDE2A9471AE04A4025B03907CF96534034F44F70B1DE4A408750A5660F96534034F44F70B1DE4A40
68374	41352	78.034420999999995	78.073667999999998	53.851649000000002	53.833018000000003	Центральная	0103000020E61000000100000005000000EB5223F4338253405B7D7555A0EA4A40EB5223F433825340E7559DD502ED4A40C0B0FCF9B6845340E7559DD502ED4A40C0B0FCF9B68453405B7D7555A0EA4A40EB5223F4338253405B7D7555A0EA4A40
68352	48543	78.443010999999998	78.481566000000001	53.955066000000002	53.927585999999998	Пушкина	0103000020E610000001000000050000002B31CF4A5A9C53401D1D5723BBF64A402B31CF4A5A9C5340C2C2499A3FFA4A40653733FAD19E5340C2C2499A3FFA4A40653733FAD19E53401D1D5723BBF64A402B31CF4A5A9C53401D1D5723BBF64A40
68593	627	77.757272999999998	77.776523999999995	53.647347000000003	53.630209999999998	Озерная	0103000020E6100000010000000500000034492C29777053405BCEA5B8AAD04A4034492C2977705340F5143944DCD24A40C823B891B2715340F5143944DCD24A40C823B891B27153405BCEA5B8AAD04A4034492C29777053405BCEA5B8AAD04A40
68691	48874	77.848046999999994	77.872185000000002	53.415418000000003	53.413243999999999	Заречная	0103000020E61000000100000005000000239EEC664676534055A2EC2DE5B44A40239EEC6646765340BA15C26A2CB54A40F4C308E1D1775340BA15C26A2CB54A40F4C308E1D177534055A2EC2DE5B44A40239EEC664676534055A2EC2DE5B44A40
68583	49664	78.207293000000007	78.228475000000003	53.708384000000002	53.693708999999998	Центральная	0103000020E6100000010000000500000025ECDB49448D53406EF8DD74CBD84A4025ECDB49448D53403D81B053ACDA4A40083D9B559F8E53403D81B053ACDA4A40083D9B559F8E53406EF8DD74CBD84A4025ECDB49448D53406EF8DD74CBD84A40
67817	59108	82.958347000000003	82.977158000000003	55.109219000000003	55.103116	Курчатова	0103000020E6100000010000000500000010CEA78E55BD5440E0D8B3E7328D4B4010CEA78E55BD5440098D60E3FA8D4B409641B5C189BE5440098D60E3FA8D4B409641B5C189BE5440E0D8B3E7328D4B4010CEA78E55BD5440E0D8B3E7328D4B40
67821	59108	82.948682000000005	82.952175999999994	55.113323000000001	55.108770999999997	 Родники	0103000020E610000001000000050000007313B534B7BC544069E04735EC8D4B407313B534B7BC54403B71395E818E4B404F029B73F0BC54403B71395E818E4B404F029B73F0BC544069E04735EC8D4B407313B534B7BC544069E04735EC8D4B40
14070	26865	83.272129000000007	83.308645999999996	54.499611000000002	54.485173000000003	Советская	0103000020E61000000100000005000000C4D2C08F6AD154407CF31B261A3E4B40C4D2C08F6AD1544066DCD440F33F4B40A30227DBC0D3544066DCD440F33F4B40A30227DBC0D354407CF31B261A3E4B40C4D2C08F6AD154407CF31B261A3E4B40
13784	26865	83.272129000000007	83.308645999999996	54.499611000000002	54.485173000000003	Береговая	0103000020E61000000100000005000000C4D2C08F6AD154407CF31B261A3E4B40C4D2C08F6AD1544066DCD440F33F4B40A30227DBC0D3544066DCD440F33F4B40A30227DBC0D354407CF31B261A3E4B40C4D2C08F6AD154407CF31B261A3E4B40
13631	27300	83.402159999999995	83.421986000000004	54.465361000000001	54.452883999999997	Центральная	0103000020E6100000010000000500000099F04BFDBCD95440DA70581AF8394B4099F04BFDBCD95440BCEA01F3903B4B40AC5791D101DB5440BCEA01F3903B4B40AC5791D101DB5440DA70581AF8394B4099F04BFDBCD95440DA70581AF8394B40
13613	30464	82.849210999999997	82.863072000000003	54.373274000000002	54.365609999999997	Зелена	0103000020E61000000100000005000000D219187959B65440978BF84ECC2E4B40D219187959B654403B394371C72F4B40F98557923CB754403B394371C72F4B40F98557923CB75440978BF84ECC2E4B40D219187959B65440978BF84ECC2E4B40
13956	28071	83.587194999999994	83.617181000000002	54.622439999999997	54.611798999999998	Центральная	0103000020E61000000100000005000000FB57569A94E55440DD5CFC6D4F4E4B40FB57569A94E5544072DC291DAC4F4B409BADBCE47FE7544072DC291DAC4F4B409BADBCE47FE75440DD5CFC6D4F4E4B40FB57569A94E55440DD5CFC6D4F4E4B40
13702	30755	82.432419999999993	82.449253999999996	54.483080000000001	54.471131999999997	Красный Факел	0103000020E61000000100000005000000B988EFC4AC9B5440AE0CAA0D4E3C4B40B988EFC4AC9B544004ADC090D53D4B403866D993C09C544004ADC090D53D4B403866D993C09C5440AE0CAA0D4E3C4B40B988EFC4AC9B5440AE0CAA0D4E3C4B40
13810	27994	83.711305999999993	83.747040999999996	54.672763000000003	54.654995	Центральная	0103000020E61000000100000005000000B5DC990986ED544092054CE0D6534B40B5DC990986ED5440BC7A15191D564B405AF10D85CFEF5440BC7A15191D564B405AF10D85CFEF544092054CE0D6534B40B5DC990986ED544092054CE0D6534B40
13416	27502	83.415563000000006	83.446680999999998	54.514080999999997	54.487572999999998	Школьная	0103000020E610000001000000050000005F9B8D9598DA5440D0B4C4CA683E4B405F9B8D9598DA54405B3FFD67CD414B40A7AFE76B96DC54405B3FFD67CD414B40A7AFE76B96DC5440D0B4C4CA683E4B405F9B8D9598DA5440D0B4C4CA683E4B40
14150	29685	82.927975000000004	82.955572000000004	54.510196999999998	54.498319000000002	Первомайская	0103000020E610000001000000050000005C2041F163BB5440DBFCBFEAC83F4B405C2041F163BB544037C2A2224E414B404B3E761728BD544037C2A2224E414B404B3E761728BD5440DBFCBFEAC83F4B405C2041F163BB5440DBFCBFEAC83F4B40
13776	26825	83.382289	83.418096000000006	54.618186000000001	54.607008	Солнечный переулок	0103000020E61000000100000005000000B727486C77D8544087342A70B24D4B40B727486C77D854402B6C06B8204F4B40A9A5B915C2DA54402B6C06B8204F4B40A9A5B915C2DA544087342A70B24D4B40B727486C77D8544087342A70B24D4B40
68128	59133	82.374792999999997	84.084395000000001	54.989099000000003	54.252999000000003	Пушкина	0103000020E610000001000000050000004371C79BFC975440DA756F4562204B404371C79BFC975440CFC0C8CB9A7E4B408A3C49BA66055540CFC0C8CB9A7E4B408A3C49BA66055540DA756F4562204B404371C79BFC975440DA756F4562204B40
13682	29393	82.669162	82.686131000000003	54.457427000000003	54.446114999999999	Школьная	0103000020E61000000100000005000000766EDA8CD3AA5440A5A0DB4B1A394B40766EDA8CD3AA544059A7CAF78C3A4B406571FF91E9AB544059A7CAF78C3A4B406571FF91E9AB5440A5A0DB4B1A394B40766EDA8CD3AA5440A5A0DB4B1A394B40
13874	41314	82.374792999999997	84.084395000000001	54.989099000000003	54.252999000000003	Степная	0103000020E610000001000000050000004371C79BFC975440DA756F4562204B404371C79BFC975440CFC0C8CB9A7E4B408A3C49BA66055540CFC0C8CB9A7E4B408A3C49BA66055540DA756F4562204B404371C79BFC975440DA756F4562204B40
13475	29797	83.079026999999996	83.092348999999999	54.489116000000003	54.480443999999999	Лесная	0103000020E61000000100000005000000102043C70EC554409BC761307F3D4B40102043C70EC55440A5F9635A9B3E4B405FB4C70BE9C55440A5F9635A9B3E4B405FB4C70BE9C554409BC761307F3D4B40102043C70EC554409BC761307F3D4B40
13980	29489	83.002868000000007	83.016216999999997	54.583252999999999	54.571423000000003	Садовая	0103000020E610000001000000050000001E8D43FD2EC0544053978C6324494B401E8D43FD2EC054409E25C808A84A4B40E92807B309C154409E25C808A84A4B40E92807B309C1544053978C6324494B401E8D43FD2EC0544053978C6324494B40
13696	30271	82.898016999999996	82.919549000000004	54.399498999999999	54.386436000000003	Советская	0103000020E6100000010000000500000021904B1C79B95440A0FF1EBC76314B4021904B1C79B9544071E481C822334B4073840CE4D9BA544071E481C822334B4073840CE4D9BA5440A0FF1EBC76314B4021904B1C79B95440A0FF1EBC76314B40
13629	27008	83.133275999999995	83.169110000000003	54.465685000000001	54.458106999999998	Центральная	0103000020E61000000100000005000000DE550F9887C85440CA880B40A33A4B40DE550F9887C854406F9EEA909B3B4B404DDBBFB2D2CA54406F9EEA909B3B4B404DDBBFB2D2CA5440CA880B40A33A4B40DE550F9887C85440CA880B40A33A4B40
13666	28604	83.385451000000003	83.402959999999993	54.825960000000002	54.808878	Нагорный переулок	0103000020E6100000010000000500000079CDAB3AABD85440193A765089674B4079CDAB3AABD85440EFE6A90EB9694B402766BD18CAD95440EFE6A90EB9694B402766BD18CAD95440193A765089674B4079CDAB3AABD85440193A765089674B40
13422	28059	83.841363999999999	83.875733999999994	54.781410000000001	54.762709000000001	Рабочая	0103000020E61000000100000005000000080264E8D8F55440B4AED172A0614B40080264E8D8F5544039622D3E05644B40B27F9E060CF8544039622D3E05644B40B27F9E060CF85440B4AED172A0614B40080264E8D8F55440B4AED172A0614B40
13816	27272	83.205528000000001	83.230609000000001	54.777033000000003	54.762740000000001	Школьная	0103000020E61000000100000005000000639AE95E27CD5440EFACDD76A1614B40639AE95E27CD5440D6743DD175634B40734A404CC2CE5440D6743DD175634B40734A404CC2CE5440EFACDD76A1614B40639AE95E27CD5440EFACDD76A1614B40
13401	27272	83.205528000000001	83.230609000000001	54.777033000000003	54.762740000000001	Тимуровская	0103000020E61000000100000005000000639AE95E27CD5440EFACDD76A1614B40639AE95E27CD5440D6743DD175634B40734A404CC2CE5440D6743DD175634B40734A404CC2CE5440EFACDD76A1614B40639AE95E27CD5440EFACDD76A1614B40
16533	28413	83.079755000000006	83.100667999999999	54.435020000000002	54.423805999999999	Центральная	0103000020E61000000100000005000000522CB7B41AC554409EEC66463F364B40522CB7B41AC554408F8D40BCAE374B403DF0315871C654408F8D40BCAE374B403DF0315871C654409EEC66463F364B40522CB7B41AC554409EEC66463F364B40
13946	27803	83.849907000000002	83.864926999999994	54.669195999999999	54.654417000000002	Центральная	0103000020E610000001000000050000000E6954E064F654402579AEEFC3534B400E6954E064F65440984EEB36A8554B405A9BC6F65AF75440984EEB36A8554B405A9BC6F65AF754402579AEEFC3534B400E6954E064F654402579AEEFC3534B40
14064	26100	83.353821999999994	83.398396000000005	54.465831000000001	54.437716000000002	пр.Мира	0103000020E61000000100000005000000BDA60705A5D65440CD77F01307384B40BDA60705A5D65440433BA759A03B4B40DDB6EF517FD95440433BA759A03B4B40DDB6EF517FD95440CD77F01307384B40BDA60705A5D65440CD77F01307384B40
14117	26100	83.353821999999994	83.398396000000005	54.465831000000001	54.437716000000002	пр.Коммунистический	0103000020E61000000100000005000000BDA60705A5D65440CD77F01307384B40BDA60705A5D65440433BA759A03B4B40DDB6EF517FD95440433BA759A03B4B40DDB6EF517FD95440CD77F01307384B40BDA60705A5D65440CD77F01307384B40
13501	26100	83.353821999999994	83.398396000000005	54.465831000000001	54.437716000000002	Листвянская	0103000020E61000000100000005000000BDA60705A5D65440CD77F01307384B40BDA60705A5D65440433BA759A03B4B40DDB6EF517FD95440433BA759A03B4B40DDB6EF517FD95440CD77F01307384B40BDA60705A5D65440CD77F01307384B40
13869	26100	83.353821999999994	83.398396000000005	54.465831000000001	54.437716000000002	Бульвар Ветеранов войны	0103000020E61000000100000005000000BDA60705A5D65440CD77F01307384B40BDA60705A5D65440433BA759A03B4B40DDB6EF517FD95440433BA759A03B4B40DDB6EF517FD95440CD77F01307384B40BDA60705A5D65440CD77F01307384B40
13918	26100	83.353821999999994	83.398396000000005	54.465831000000001	54.437716000000002	4-й микрорайон	0103000020E61000000100000005000000BDA60705A5D65440CD77F01307384B40BDA60705A5D65440433BA759A03B4B40DDB6EF517FD95440433BA759A03B4B40DDB6EF517FD95440CD77F01307384B40BDA60705A5D65440CD77F01307384B40
13840	27793	83.775689	83.842155000000005	54.662562999999999	54.631180999999998	Новый Поселок	0103000020E610000001000000050000007CB779E3A4F15440A46DFC89CA504B407CB779E3A4F15440134548DDCE544B406DCA15DEE5F55440134548DDCE544B406DCA15DEE5F55440A46DFC89CA504B407CB779E3A4F15440A46DFC89CA504B40
16597	27793	83.775689	83.842155000000005	54.662562999999999	54.631180999999998	Милицейская	0103000020E610000001000000050000007CB779E3A4F15440A46DFC89CA504B407CB779E3A4F15440134548DDCE544B406DCA15DEE5F55440134548DDCE544B406DCA15DEE5F55440A46DFC89CA504B407CB779E3A4F15440A46DFC89CA504B40
13659	28492	83.683755000000005	83.702539000000002	54.850422000000002	54.839795000000002	Центральная	0103000020E610000001000000050000007FDE54A4C2EB5440132C0E677E6B4B407FDE54A4C2EB544043E6CAA0DA6C4B40884A2366F6EC544043E6CAA0DA6C4B40884A2366F6EC5440132C0E677E6B4B407FDE54A4C2EB5440132C0E677E6B4B40
13785	27170	83.337967000000006	83.352626999999998	54.443282000000004	54.427802999999997	Центральная	0103000020E6100000010000000500000025085740A1D55440BA10AB3FC2364B4025085740A1D55440E773EE76BD384B40F12BD67091D65440E773EE76BD384B40F12BD67091D65440BA10AB3FC2364B4025085740A1D55440BA10AB3FC2364B40
14162	30071	82.607996	82.618235999999996	54.393129999999999	54.381658999999999	Центральная	0103000020E6100000010000000500000053060E68E9A65440AE9CBD33DA304B4053060E68E9A65440CA89761552324B406E4DBA2D91A75440CA89761552324B406E4DBA2D91A75440AE9CBD33DA304B4053060E68E9A65440AE9CBD33DA304B40
68380	29330	82.428466999999998	82.462522000000007	54.511420000000001	54.484063999999996	Центральная	0103000020E61000000100000005000000931ADA006C9B5440E19524CFF53D4B40931ADA006C9B54409A42E73576414B408EEBDFF5999D54409A42E73576414B408EEBDFF5999D5440E19524CFF53D4B40931ADA006C9B5440E19524CFF53D4B40
13445	29330	82.428466999999998	82.462522000000007	54.511420000000001	54.484063999999996	Совхозная	0103000020E61000000100000005000000931ADA006C9B5440E19524CFF53D4B40931ADA006C9B54409A42E73576414B408EEBDFF5999D54409A42E73576414B408EEBDFF5999D5440E19524CFF53D4B40931ADA006C9B5440E19524CFF53D4B40
13425	28214	83.576317000000003	83.608143999999996	54.744045	54.725904	Центральная	0103000020E610000001000000050000003FC8B260E2E454408E041A6CEA5C4B403FC8B260E2E454404CE0D6DD3C5F4B408DD0CFD4EBE654404CE0D6DD3C5F4B408DD0CFD4EBE654408E041A6CEA5C4B403FC8B260E2E454408E041A6CEA5C4B40
13789	27142	83.312597999999994	83.328767999999997	54.424435000000003	54.409754999999997	Речная	0103000020E61000000100000005000000E1B20A9B01D45440AD2F12DA72344B40E1B20A9B01D454408E23D6E253364B402AFEEF880AD554408E23D6E253364B402AFEEF880AD55440AD2F12DA72344B40E1B20A9B01D45440AD2F12DA72344B40
14137	28447	83.474439000000004	83.485308000000003	54.915647	54.911315999999999	Школьный переулок	0103000020E610000001000000050000009B3C65355DDE54402829B000A6744B409B3C65355DDE54401BD7BFEB33754B402E1F49490FDF54401BD7BFEB33754B402E1F49490FDF54402829B000A6744B409B3C65355DDE54402829B000A6744B40
13792	27610	83.679353000000006	83.703823	54.525719000000002	54.505853000000002	Центральная	0103000020E61000000100000005000000215C01857AEB5440B0CA85CABF404B40215C01857AEB544063F19BC24A434B400CCB9F6F0BED544063F19BC24A434B400CCB9F6F0BED5440B0CA85CABF404B40215C01857AEB5440B0CA85CABF404B40
13694	30169	82.699139000000002	82.822800999999998	54.431925	54.357222	Зеленая	0103000020E61000000100000005000000EC1681B1BEAC5440B3B45373B92D4B40EC1681B1BEAC544093A9825149374B406E8786C5A8B4544093A9825149374B406E8786C5A8B45440B3B45373B92D4B40EC1681B1BEAC5440B3B45373B92D4B40
13655	28332	83.483979000000005	83.514619999999994	54.880464000000003	54.860860000000002	Газовая	0103000020E61000000100000005000000DA3C0E83F9DE5440A03715A9306E4B40DA3C0E83F9DE544016A75A0BB3704B408577B988EFE0544016A75A0BB3704B408577B988EFE05440A03715A9306E4B40DA3C0E83F9DE5440A03715A9306E4B40
14141	28804	82.820150999999996	82.850406000000007	54.645316999999999	54.626584000000001	Береговая	0103000020E6100000010000000500000007B29E5A7DB4544033198EE733504B4007B29E5A7DB45440C34659BF99524B409F94490D6DB65440C34659BF99524B409F94490D6DB6544033198EE733504B4007B29E5A7DB4544033198EE733504B40
13827	29691	82.897514000000001	82.915525000000002	54.492885999999999	54.481735999999998	.Школьная	0103000020E61000000100000005000000F06C8FDE70B9544026A77686A93D4B40F06C8FDE70B95440005471E3163F4B40E86A2BF697BA5440005471E3163F4B40E86A2BF697BA544026A77686A93D4B40F06C8FDE70B9544026A77686A93D4B40
13688	29874	82.986931999999996	82.999059000000003	54.486172000000003	54.477953999999997	Школьная	0103000020E610000001000000050000000ED8D5E429BF5440067FBF982D3D4B400ED8D5E429BF54408F1D54E23A3E4B4091F12895F0BF54408F1D54E23A3E4B4091F12895F0BF5440067FBF982D3D4B400ED8D5E429BF5440067FBF982D3D4B40
13970	28726	83.161069999999995	83.195286999999993	54.745345	54.732345000000002	Речная	0103000020E6100000010000000500000078978BF84ECA5440CF31207BBD5D4B4078978BF84ECA54405A9E0777675F4B405F950B957FCC54405A9E0777675F4B405F950B957FCC5440CF31207BBD5D4B4078978BF84ECA5440CF31207BBD5D4B40
68348	27634	83.620549999999994	83.646448000000007	54.546567000000003	54.52854	Зеленая	0103000020E6100000010000000500000019E25817B7E754405D50DF32A7434B4019E25817B7E7544053094FE8F5454B4023A46E675FE9544053094FE8F5454B4023A46E675FE954405D50DF32A7434B4019E25817B7E754405D50DF32A7434B40
13624	23208	78.379823000000002	78.399685000000005	54.668545999999999	54.661948000000002	Садовая	0103000020E6100000010000000500000031D120054F98534089D349B6BA544B4031D120054F98534091EF52EA92554B40EAEC64709499534091EF52EA92554B40EAEC64709499534089D349B6BA544B4031D120054F98534089D349B6BA544B40
13912	25892	78.137134000000003	78.152540000000002	54.574131999999999	54.565921000000003	Курьинская	0103000020E61000000100000005000000DC4AAFCDC6885340508F6D1970484B40DC4AAFCDC688534025CB49287D494B403DD52137C389534025CB49287D494B403DD52137C3895340508F6D1970484B40DC4AAFCDC6885340508F6D1970484B40
15333	25767	78.572018	78.590576999999996	54.748747999999999	54.741622999999997	Утюпина	0103000020E610000001000000050000004BAE62F19BA453400F7BA180ED5E4B404BAE62F19BA45340037976F9D65F4B4044317903CCA55340037976F9D65F4B4044317903CCA553400F7BA180ED5E4B404BAE62F19BA453400F7BA180ED5E4B40
15073	44373	78.744754999999998	78.760475	54.709226000000001	54.697412	Центральная	0103000020E610000001000000050000001422E010AAAF534042EBE1CB44594B401422E010AAAF534088BCE5EAC75A4B403D9B559FABB0534088BCE5EAC75A4B403D9B559FABB0534042EBE1CB44594B401422E010AAAF534042EBE1CB44594B40
14113	24965	78.838853	78.865128999999996	54.716850999999998	54.707259999999998	Ленина	0103000020E61000000100000005000000B2497EC4AFB553406DE2E47E875A4B40B2497EC4AFB553406D8D08C6C15B4B408E7406465EB753406D8D08C6C15B4B408E7406465EB753406DE2E47E875A4B40B2497EC4AFB553406DE2E47E875A4B40
68973	15374	78.734164000000007	78.776815999999997	54.834505999999998	54.820295999999999	Набережная	0103000020E61000000100000005000000A379008BFCAE534012859675FF684B40A379008BFCAE53406B28B517D16A4B409CC0745AB7B153406B28B517D16A4B409CC0745AB7B1534012859675FF684B40A379008BFCAE534012859675FF684B40
14937	15374	78.734164000000007	78.776815999999997	54.834505999999998	54.820295999999999	Береговая	0103000020E61000000100000005000000A379008BFCAE534012859675FF684B40A379008BFCAE53406B28B517D16A4B409CC0745AB7B153406B28B517D16A4B409CC0745AB7B1534012859675FF684B40A379008BFCAE534012859675FF684B40
13571	41242	78.637693999999996	78.648374000000004	54.921008	54.916372000000003	Береговая	0103000020E61000000100000005000000BFB67EFACFA853402D7C7DAD4B754B40BFB67EFACFA853405CAD1397E3754B40E964A9F57EA953405CAD1397E3754B40E964A9F57EA953402D7C7DAD4B754B40BFB67EFACFA853402D7C7DAD4B754B40
14104	25418	78.885727000000003	78.898852000000005	54.945422999999998	54.936677000000003	Центральная	0103000020E61000000100000005000000CA8B4CC0AFB853402CF52C08E5774B40CA8B4CC0AFB853406FF1F09E03794B406EFC89CA86B953406FF1F09E03794B406EFC89CA86B953402CF52C08E5774B40CA8B4CC0AFB853402CF52C08E5774B40
13755	41286	78.264300000000006	78.299711000000002	54.350138000000001	54.339084999999997	Центральная	0103000020E610000001000000050000004D158C4AEA90534036C82423672B4B404D158C4AEA9053401E8B6D52D12C4B4018D00B772E9353401E8B6D52D12C4B4018D00B772E93534036C82423672B4B404D158C4AEA90534036C82423672B4B40
68450	49661	78.507904999999994	78.532158999999993	54.906025999999997	54.896360999999999	Сартланская	0103000020E61000000100000005000000641EF98381A0534076340EF5BB724B40641EF98381A05340B0A9F3A8F8734B4069519FE40EA25340B0A9F3A8F8734B4069519FE40EA2534076340EF5BB724B40641EF98381A0534076340EF5BB724B40
68456	46272	77.952997999999994	79.582792999999995	55.0383	54.247297000000003	Северная	0103000020E61000000100000005000000D1C952EBFD7C534010B3976DA71F4B40D1C952EBFD7C5340E9B7AF03E7844B409DD5027B4CE55340E9B7AF03E7844B409DD5027B4CE5534010B3976DA71F4B40D1C952EBFD7C534010B3976DA71F4B40
13895	25081	78.259169999999997	78.274540999999999	54.449387000000002	54.440072999999998	Садовая	0103000020E61000000100000005000000AD86C43D96905340226DE34F54384B40AD86C43D96905340B01F628385394B40501A6A1492915340B01F628385394B40501A6A1492915340226DE34F54384B40AD86C43D96905340226DE34F54384B40
14123	25204	78.534064000000001	78.560061000000005	54.81335	54.804009999999998	Школьная	0103000020E61000000100000005000000247EC51A2EA2534017D4B7CCE9664B40247EC51A2EA25340CE1951DA1B684B40F7B0170AD8A35340CE1951DA1B684B40F7B0170AD8A3534017D4B7CCE9664B40247EC51A2EA2534017D4B7CCE9664B40
13886	41319	78.479095999999998	78.535428999999993	54.376268000000003	54.359845	Центральная	0103000020E610000001000000050000003EE94482A99E53408750A5660F2E4B403EE94482A99E53400344C18C29304B401E15FF7744A253400344C18C29304B401E15FF7744A253408750A5660F2E4B403EE94482A99E53408750A5660F2E4B40
13911	26020	78.64161	78.685492999999994	54.713793000000003	54.690741000000003	Калинина	0103000020E6100000010000000500000057B2632310A95340D0807A336A584B4057B2632310A953408F8EAB915D5B4B40C328081EDFAB53408F8EAB915D5B4B40C328081EDFAB5340D0807A336A584B4057B2632310A95340D0807A336A584B40
14105	25594	78.808293000000006	78.828208000000004	54.884773000000003	54.875754999999998	Озерная	0103000020E610000001000000050000007D259012BBB353407C2766BD18704B407D259012BBB3534021B1DD3D40714B404792205C01B5534021B1DD3D40714B404792205C01B553407C2766BD18704B407D259012BBB353407C2766BD18704B40
14702	42961	78.972054999999997	78.984829000000005	54.760724000000003	54.753943999999997	Береговая	0103000020E6100000010000000500000073BA2C2636BE5340F981AB3C81604B4073BA2C2636BE534023A46E675F614B40C1C9367007BF534023A46E675F614B40C1C9367007BF5340F981AB3C81604B4073BA2C2636BE5340F981AB3C81604B40
13887	24798	78.651959000000005	78.683957000000007	54.311644000000001	54.300238999999998	Центральная	0103000020E610000001000000050000004ED53DB2B9A95340EBFD463B6E264B404ED53DB2B9A9534050FF59F3E3274B40B3B794F3C5AB534050FF59F3E3274B40B3B794F3C5AB5340EBFD463B6E264B404ED53DB2B9A95340EBFD463B6E264B40
13581	24619	78.801995000000005	78.815029999999993	54.555945000000001	54.546242999999997	Молодежная	0103000020E610000001000000050000008E23D6E253B353409F55664AEB454B408E23D6E253B35340F7AFAC3429474B4091D0967329B45340F7AFAC3429474B4091D0967329B453409F55664AEB454B408E23D6E253B353409F55664AEB454B40
75547	45362	78.498230000000007	78.538672000000005	54.893279999999997	54.881985999999998	Центральная	0103000020E61000000100000005000000B6F81400E39F5340D2C3D0EAE4704B40B6F81400E39F5340DF15C1FF56724B4057D11F9A79A25340DF15C1FF56724B4057D11F9A79A25340D2C3D0EAE4704B40B6F81400E39F5340D2C3D0EAE4704B40
13564	23778	79.476512999999997	79.498746999999995	54.302928999999999	54.288989000000001	Центральная	0103000020E610000001000000050000009BC761307FDE5340AEF36F97FD244B409BC761307FDE53404701A260C6264B40997E8978EBDF53404701A260C6264B40997E8978EBDF5340AEF36F97FD244B409BC761307FDE5340AEF36F97FD244B40
13871	23789	79.698721000000006	79.823721000000006	54.801679999999998	54.697032	Центральная	0103000020E61000000100000005000000D20149D8B7EC5340FB21365838594B40D20149D8B7EC5340BBED42739D664B40D20149D8B7F45340BBED42739D664B40D20149D8B7F45340FB21365838594B40D20149D8B7EC5340FB21365838594B40
13868	41313	79.598532000000006	79.632964000000001	54.263807	54.227105999999999	Юбилейная	0103000020E61000000100000005000000026729594EE65340D95C35CF111D4B40026729594EE653405ABA826DC4214B40E7E26F7B82E853405ABA826DC4214B40E7E26F7B82E85340D95C35CF111D4B40026729594EE65340D95C35CF111D4B40
16651	23300	79.895612999999997	79.908907999999997	54.811622	54.805821000000002	Солнечная	0103000020E61000000100000005000000D63730B951F953400BB77C2425674B40D63730B951F95340685BCD3AE3674B40A8C4758C2BFA5340685BCD3AE3674B40A8C4758C2BFA53400BB77C2425674B40D63730B951F953400BB77C2425674B40
13758	15426	79.940538000000004	79.962933000000007	54.755737000000003	54.745058999999998	Клубная	0103000020E610000001000000050000004CA94BC631FC5340944BE3175E5F4B404CA94BC631FC534047B071FDBB604B404FCFBBB1A0FD534047B071FDBB604B404FCFBBB1A0FD5340944BE3175E5F4B404CA94BC631FC5340944BE3175E5F4B40
76005	60762	82.929754000000003	82.955015000000003	55.053896999999999	55.051524999999998	Партизанская 	0103000020E61000000100000005000000D0D4EB1681BB544094F6065F98864B40D0D4EB1681BB54401F2DCE18E6864B40200C3CF71EBD54401F2DCE18E6864B40200C3CF71EBD544094F6065F98864B40D0D4EB1681BB544094F6065F98864B40
14028	23698	79.616479999999996	79.629461000000006	54.605922999999997	54.598360999999997	Набережная	0103000020E61000000100000005000000D6A8876874E75340D619DF17974C4B40D6A8876874E75340757286E28E4D4B40E146CA1649E85340757286E28E4D4B40E146CA1649E85340D619DF17974C4B40D6A8876874E75340D619DF17974C4B40
14026	23113	80.199405999999996	80.240144000000001	54.431223000000003	54.410321000000003	Центральная	0103000020E6100000010000000500000013286211C30C544057EE056685344B4013286211C30C54403A24B55032374B402995F0845E0F54403A24B55032374B402995F0845E0F544057EE056685344B4013286211C30C544057EE056685344B40
13722	23059	79.969005999999993	80.001911000000007	54.560273000000002	54.524411999999998	Новая	0103000020E610000001000000050000002DE8BD3104FE5340A2D0B2EE1F434B402DE8BD3104FE534079EA9106B7474B402CA0504F1F00544079EA9106B7474B402CA0504F1F005440A2D0B2EE1F434B402DE8BD3104FE5340A2D0B2EE1F434B40
13701	22989	79.211798000000002	79.268320000000003	54.535640000000001	54.511733999999997	 Рабочая	0103000020E61000000100000005000000EDD632198ECD53402920ED7F80414B40EDD632198ECD5340F836FDD98F444B403737A6272CD15340F836FDD98F444B403737A6272CD153402920ED7F80414B40EDD632198ECD53402920ED7F80414B40
68422	23016	79.085134999999994	79.103757000000002	54.438183000000002	54.428918000000003	Баганская	0103000020E61000000100000005000000AD2F12DA72C553403755F7C8E6364B40AD2F12DA72C55340E3546B6116384B40CA6E66F4A3C65340E3546B6116384B40CA6E66F4A3C653403755F7C8E6364B40AD2F12DA72C553403755F7C8E6364B40
13724	22674	79.631750999999994	79.693960000000004	54.510630999999997	54.460425999999998	Рабочая	0103000020E61000000100000005000000C70DBF9B6EE85340321D3A3DEF3A4B40C70DBF9B6EE8534071A94A5B5C414B40DC2E34D769EC534071A94A5B5C414B40DC2E34D769EC5340321D3A3DEF3A4B40C70DBF9B6EE85340321D3A3DEF3A4B40
13532	22674	79.631750999999994	79.693960000000004	54.510630999999997	54.460425999999998	Пушкина	0103000020E61000000100000005000000C70DBF9B6EE85340321D3A3DEF3A4B40C70DBF9B6EE8534071A94A5B5C414B40DC2E34D769EC534071A94A5B5C414B40DC2E34D769EC5340321D3A3DEF3A4B40C70DBF9B6EE85340321D3A3DEF3A4B40
14186	22674	79.631750999999994	79.693960000000004	54.510630999999997	54.460425999999998	Коммунистическая	0103000020E61000000100000005000000C70DBF9B6EE85340321D3A3DEF3A4B40C70DBF9B6EE8534071A94A5B5C414B40DC2E34D769EC534071A94A5B5C414B40DC2E34D769EC5340321D3A3DEF3A4B40C70DBF9B6EE85340321D3A3DEF3A4B40
13725	23499	80.106834000000006	80.130936000000005	54.722175999999997	54.714458	Центральная	0103000020E610000001000000050000007506465ED6065440CB2E185C735B4B407506465ED606544061FA5E43705C4B409F7763416108544061FA5E43705C4B409F77634161085440CB2E185C735B4B407506465ED6065440CB2E185C735B4B40
13718	22582	79.386501999999993	79.418177	54.445518	54.418982	Центральная	0103000020E61000000100000005000000AB75E272BCD853406CCEC133A1354B40AB75E272BCD85340C1E3DBBB06394B401FBC7669C3DA5340C1E3DBBB06394B401FBC7669C3DA53406CCEC133A1354B40AB75E272BCD853406CCEC133A1354B40
13853	22495	79.106038999999996	79.139142000000007	54.396852000000003	54.362468	Гагарина	0103000020E610000001000000050000006F46CD57C9C653405BECF659652E4B406F46CD57C9C6534015ADDC0BCC324B4001E0D8B3E7C8534015ADDC0BCC324B4001E0D8B3E7C853405BECF659652E4B406F46CD57C9C653405BECF659652E4B40
13536	22863	79.765096999999997	79.787482999999995	54.518250999999999	54.500829000000003	Школьная	0103000020E6100000010000000500000022516859F7F05340B7F1272A1B404B4022516859F7F05340450F7C0C56424B40FBC9181F66F25340450F7C0C56424B40FBC9181F66F25340B7F1272A1B404B4022516859F7F05340B7F1272A1B404B40
13863	41228	77.270745000000005	77.306875000000005	56.079307	56.069555000000001	Ленина	0103000020E610000001000000050000008E23D6E253515340FB22A12DE7084C408E23D6E25351534004AC55BB260A4C40713D0AD7A353534004AC55BB260A4C40713D0AD7A3535340FB22A12DE7084C408E23D6E253515340FB22A12DE7084C40
14172	21771	76.690325999999999	76.711417999999995	55.799182999999999	55.789724999999997	Школьная	0103000020E6100000010000000500000006651A4D2E2C5340B3EA73B515E54B4006651A4D2E2C53407442E8A04BE64B4049F25CDF872D53407442E8A04BE64B4049F25CDF872D5340B3EA73B515E54B4006651A4D2E2C5340B3EA73B515E54B40
14003	22255	77.347282000000007	77.368122	56.252442000000002	56.240457999999997	Центральная	0103000020E61000000100000005000000541F48DE39565340E107E753C71E4C40541F48DE395653408411FB0450204C400ABC934F8F5753408411FB0450204C400ABC934F8F575340E107E753C71E4C40541F48DE39565340E107E753C71E4C40
13848	22156	76.934163999999996	76.955832000000001	55.935546000000002	55.924351000000001	Ленина	0103000020E610000001000000050000006F46CD57C93B53403083312251F64B406F46CD57C93B5340AAF3A8F8BFF74B40191EFB592C3D5340AAF3A8F8BFF74B40191EFB592C3D53403083312251F64B406F46CD57C93B53403083312251F64B40
13706	21979	77.113225999999997	77.129952000000003	55.924087999999998	55.911774000000001	Зелёная	0103000020E61000000100000005000000A4C343183F475340EBABAB02B5F44B40A4C343183F4753402250FD8348F64B4030833122514853402250FD8348F64B403083312251485340EBABAB02B5F44B40A4C343183F475340EBABAB02B5F44B40
13498	21789	77.019171999999998	77.048978000000005	55.646943999999998	55.635691000000001	Новая	0103000020E61000000100000005000000EE3F321D3A41534047AE9B525ED14B40EE3F321D3A415340F52B9D0FCFD24B404E0E9F7422435340F52B9D0FCFD24B404E0E9F742243534047AE9B525ED14B40EE3F321D3A41534047AE9B525ED14B40
75228	49605	76.526060000000001	76.554356999999996	55.598711000000002	55.591665999999996	Школьная	0103000020E61000000100000005000000F6EE8FF7AA215340DB1324B6BBCB4B40F6EE8FF7AA215340B360E28FA2CC4B40C153C8957A235340B360E28FA2CC4B40C153C8957A235340DB1324B6BBCB4B40F6EE8FF7AA215340DB1324B6BBCB4B40
15972	47485	76.526060000000001	76.554356999999996	55.598711000000002	55.591665999999996	Центральная	0103000020E61000000100000005000000F6EE8FF7AA215340DB1324B6BBCB4B40F6EE8FF7AA215340B360E28FA2CC4B40C153C8957A235340B360E28FA2CC4B40C153C8957A235340DB1324B6BBCB4B40F6EE8FF7AA215340DB1324B6BBCB4B40
13686	20665	76.337647000000004	76.358236000000005	55.777388000000002	55.766146999999997	Советская	0103000020E61000000100000005000000ECA529029C155340D976DA1A11E24B40ECA529029C155340C426327381E34B40FE0FB056ED165340C426327381E34B40FE0FB056ED165340D976DA1A11E24B40ECA529029C155340D976DA1A11E24B40
68453	21474	76.546954999999997	76.564848999999995	55.983811000000003	55.970857000000002	Школьная	0103000020E610000001000000050000008E588B4F01235340DD0BCC0A45FC4B408E588B4F01235340F838D384EDFD4B40698B6B7C26245340F838D384EDFD4B40698B6B7C26245340DD0BCC0A45FC4B408E588B4F01235340DD0BCC0A45FC4B40
14038	21303	76.983006000000003	76.998007999999999	55.812206000000003	55.797609000000001	Юбилейная	0103000020E610000001000000050000006571FF91E93E534065FF3C0D18E64B406571FF91E93E5340B8CEBF5DF6E74B405E49F25CDF3F5340B8CEBF5DF6E74B405E49F25CDF3F534065FF3C0D18E64B406571FF91E93E534065FF3C0D18E64B40
13987	41340	76.775028000000006	76.795680000000004	56.153131000000002	56.142611000000002	Площадь	0103000020E61000000100000005000000FF5E0A0F9A3153406286C61341124C40FF5E0A0F9A3153407C80EECB99134C403485CE6BEC3253407C80EECB99134C403485CE6BEC3253406286C61341124C40FF5E0A0F9A3153406286C61341124C40
13459	41199	76.913144000000003	76.921048999999996	55.785108000000001	55.773029000000001	Центральная	0103000020E61000000100000005000000792288F3703A534007EE409DF2E24B40792288F3703A5340FBE93F6B7EE44B40DD408177F23A5340FBE93F6B7EE44B40DD408177F23A534007EE409DF2E24B40792288F3703A534007EE409DF2E24B40
13466	41204	76.964572000000004	76.987838999999994	55.817694000000003	55.809403000000003	Набережная	0103000020E61000000100000005000000CAA8328CBB3D534064247B849AE74B40CAA8328CBB3D534056116E32AAE84B40A7AD11C1383F534056116E32AAE84B40A7AD11C1383F534064247B849AE74B40CAA8328CBB3D534064247B849AE74B40
13834	21117	76.685025999999993	76.739266000000001	55.679088	55.667178	Юбилейная	0103000020E6100000010000000500000038BA4A77D72B53402B4EB51666D54B4038BA4A77D72B5340938D075BECD64B40DD425722502F5340938D075BECD64B40DD425722502F53402B4EB51666D54B4038BA4A77D72B53402B4EB51666D54B40
68656	21024	77.176008999999993	77.191630000000004	56.148868999999998	56.139811999999999	Центральная	0103000020E610000001000000050000004EB340BB434B53404FCB0F5CE5114C404EB340BB434B5340B131AF230E134C40AEBB79AA434C5340B131AF230E134C40AEBB79AA434C53404FCB0F5CE5114C404EB340BB434B53404FCB0F5CE5114C40
14155	41265	77.522515999999996	77.546034000000006	56.176563999999999	56.168686000000001	Зелёная	0103000020E61000000100000005000000C0E8F2E67061534083A5BA8097154C40C0E8F2E67061534052D32EA699164C4043209738F262534052D32EA699164C4043209738F262534083A5BA8097154C40C0E8F2E67061534083A5BA8097154C40
14071	41368	76.680220000000006	76.714751000000007	55.939917999999999	55.925057000000002	Школьная	0103000020E61000000100000005000000738577B9882B5340CBF78C4468F64B40738577B9882B5340FB75A73B4FF84B402272FA7ABE2D5340FB75A73B4FF84B402272FA7ABE2D5340CBF78C4468F64B40738577B9882B5340CBF78C4468F64B40
13516	22072	77.217843000000002	77.238180999999997	55.972987000000003	55.966926999999998	Центральная	0103000020E61000000100000005000000672AC423F14D5340484F9143C4FB4B40672AC423F14D5340723788D68AFC4B40D461855B3E4F5340723788D68AFC4B40D461855B3E4F5340484F9143C4FB4B40672AC423F14D5340484F9143C4FB4B40
13843	41304	76.952256000000006	76.964222000000007	55.757004000000002	55.747008000000001	Набережная	0103000020E61000000100000005000000DE5A26C3F13C5340D9EC48F59DDF4B40DE5A26C3F13C53407978CF81E5E04B405C0531D0B53D53407978CF81E5E04B405C0531D0B53D5340D9EC48F59DDF4B40DE5A26C3F13C5340D9EC48F59DDF4B40
14147	41377	76.827524999999994	76.846686000000005	55.723672999999998	55.712634000000001	Советская	0103000020E61000000100000005000000D5E76A2BF63453404302469737DB4B40D5E76A2BF6345340C5FF1D51A1DC4B40CAFE791A30365340C5FF1D51A1DC4B40CAFE791A303653404302469737DB4B40D5E76A2BF63453404302469737DB4B40
16542	48684	76.527856	76.544376	55.615547999999997	55.606695000000002	Центральная	0103000020E61000000100000005000000D53F8864C8215340C8D2872EA8CD4B40D53F8864C8215340218FE046CACE4B408C2E6F0ED7225340218FE046CACE4B408C2E6F0ED7225340C8D2872EA8CD4B40D53F8864C8215340C8D2872EA8CD4B40
13492	41214	76.722881000000001	76.750630000000001	55.710442999999998	55.700999000000003	Советская	0103000020E610000001000000050000009679ABAE432E5340ADC3D155BAD94B409679ABAE432E53400856D5CBEFDA4B40605969520A3053400856D5CBEFDA4B40605969520A305340ADC3D155BAD94B409679ABAE432E5340ADC3D155BAD94B40
15957	47438	76.991342000000003	77.009649999999993	55.854734000000001	55.842801999999999	Луговая	0103000020E61000000100000005000000AE49B725723F53406F8099EFE0EB4B40AE49B725723F5340BF6378EC67ED4B40029A081B9E405340BF6378EC67ED4B40029A081B9E4053406F8099EFE0EB4B40AE49B725723F53406F8099EFE0EB4B40
68419	49660	76.514336999999998	76.539884999999998	56.133572000000001	56.119357999999998	Дорожная	0103000020E61000000100000005000000DB87BCE5EA2053400B42791F470F4C40DB87BCE5EA205340A6D425E318114C4076A6D0798D225340A6D425E318114C4076A6D0798D2253400B42791F470F4C40DB87BCE5EA2053400B42791F470F4C40
14016	41357	76.366483000000002	76.403197000000006	55.620814000000003	55.607849999999999	Школьная	0103000020E610000001000000050000008FE21C7574175340D26F5F07CECD4B408FE21C7574175340117349D576CF4B401A36CAFACD195340117349D576CF4B401A36CAFACD195340D26F5F07CECD4B408FE21C7574175340D26F5F07CECD4B40
16238	41357	76.366483000000002	76.403197000000006	55.620814000000003	55.607849999999999	Ленина	0103000020E610000001000000050000008FE21C7574175340D26F5F07CECD4B408FE21C7574175340117349D576CF4B401A36CAFACD195340117349D576CF4B401A36CAFACD195340D26F5F07CECD4B408FE21C7574175340D26F5F07CECD4B40
13684	20327	76.708831000000004	76.800269999999998	55.697589000000001	55.668483000000002	Луговая	0103000020E6100000010000000500000006D9B27C5D2D53404B77D7D990D54B4006D9B27C5D2D53405186AA984AD94B40137EA99F373353405186AA984AD94B40137EA99F373353404B77D7D990D54B4006D9B27C5D2D53404B77D7D990D54B40
13846	20327	76.708831000000004	76.800269999999998	55.697589000000001	55.668483000000002	Ленина	0103000020E6100000010000000500000006D9B27C5D2D53404B77D7D990D54B4006D9B27C5D2D53405186AA984AD94B40137EA99F373353405186AA984AD94B40137EA99F373353404B77D7D990D54B4006D9B27C5D2D53404B77D7D990D54B40
13509	41222	76.996731999999994	77.012514999999993	55.928345	55.916981	Центральная	0103000020E610000001000000050000001BB80375CA3F5340D50627A25FF54B401BB80375CA3F5340DB334B02D4F64B4067EDB60BCD405340DB334B02D4F64B4067EDB60BCD405340D50627A25FF54B401BB80375CA3F5340D50627A25FF54B40
16621	49609	84.021584000000004	84.046386999999996	55.496873000000001	55.481873	Садовая	0103000020E610000001000000050000007B87DBA161015540A7E9B303AEBD4B407B87DBA161015540F9A1D28899BF4B4069FD2D01F8025540F9A1D28899BF4B4069FD2D01F8025540A7E9B303AEBD4B407B87DBA161015540A7E9B303AEBD4B40
15787	19127	84.713331999999994	84.736059999999995	55.555743999999997	55.543236	Сосновская	0103000020E610000001000000050000002DCC423BA72D55404301DBC188C54B402DCC423BA72D55405F79909E22C74B4033F9669B1B2F55405F79909E22C74B4033F9669B1B2F55404301DBC188C54B402DCC423BA72D55404301DBC188C54B40
75542	60573	83.826857000000004	83.853070000000002	55.562128000000001	55.537353000000003	Школьная	0103000020E61000000100000005000000FF5D9F39EBF4544029B4ACFBC7C44B40FF5D9F39EBF454403C1570CFF3C74B40B8CCE9B298F654403C1570CFF3C74B40B8CCE9B298F6544029B4ACFBC7C44B40FF5D9F39EBF4544029B4ACFBC7C44B40
75489	60573	83.826857000000004	83.853070000000002	55.562128000000001	55.537353000000003	2-я Школьная улица	0103000020E61000000100000005000000FF5D9F39EBF4544029B4ACFBC7C44B40FF5D9F39EBF454403C1570CFF3C74B40B8CCE9B298F654403C1570CFF3C74B40B8CCE9B298F6544029B4ACFBC7C44B40FF5D9F39EBF4544029B4ACFBC7C44B40
75475	60623	84.285248999999993	84.310293999999999	55.927129999999998	55.909685000000003	Центральная улица	0103000020E61000000100000005000000DE8D058541125540B554DE8E70F44B40DE8D058541125540FB912232ACF64B4048895DDBDB135540FB912232ACF64B4048895DDBDB135540B554DE8E70F44B40DE8D058541125540B554DE8E70F44B40
68573	49659	84.168091000000004	84.186173999999994	55.511073000000003	55.495787	переулок Центральный	0103000020E6100000010000000500000020F0C000C20A55401764CBF275BF4B4020F0C000C20A55402F6F0ED76AC14B4064575A46EA0B55402F6F0ED76AC14B4064575A46EA0B55401764CBF275BF4B4020F0C000C20A55401764CBF275BF4B40
75548	41338	84.586130999999995	84.608607000000006	55.523820000000001	55.508992999999997	Новая	0103000020E61000000100000005000000FE0A992B832555404B72C0AE26C14B40FE0A992B83255540D07EA4880CC34B407847C66AF3265540D07EA4880CC34B407847C66AF32655404B72C0AE26C14B40FE0A992B832555404B72C0AE26C14B40
68958	46957	84.219015999999996	84.237646999999996	55.607655999999999	55.604101999999997	Центральная	0103000020E610000001000000050000003F53AF5B040E55405EB9DE3653CD4B403F53AF5B040E5540ED9BFBABC7CD4B40853FC39B350F5540ED9BFBABC7CD4B40853FC39B350F55405EB9DE3653CD4B403F53AF5B040E55405EB9DE3653CD4B40
75329	60576	84.151840000000007	84.176652000000004	55.727567000000001	55.715904999999999	Центральная	0103000020E61000000100000005000000618E1EBFB70955407D0569C6A2DB4B40618E1EBFB70955400D535BEA20DD4B4079B130444E0B55400D535BEA20DD4B4079B130444E0B55407D0569C6A2DB4B40618E1EBFB70955407D0569C6A2DB4B40
75477	60576	84.151840000000007	84.176652000000004	55.727567000000001	55.715904999999999	Молодежная улица	0103000020E61000000100000005000000618E1EBFB70955407D0569C6A2DB4B40618E1EBFB70955400D535BEA20DD4B4079B130444E0B55400D535BEA20DD4B4079B130444E0B55407D0569C6A2DB4B40618E1EBFB70955407D0569C6A2DB4B40
75344	41360	84.251166999999995	84.264371999999995	55.832293	55.817157999999999	Центральная 	0103000020E6100000010000000500000067B5C01E1310554017D522A298E84B4067B5C01E1310554049D8B79388EA4B40997E8978EB10554049D8B79388EA4B40997E8978EB10554017D522A298E84B4067B5C01E1310554017D522A298E84B40
14033	41360	84.251166999999995	84.264371999999995	55.832293	55.817157999999999	Бабахина	0103000020E6100000010000000500000067B5C01E1310554017D522A298E84B4067B5C01E1310554049D8B79388EA4B40997E8978EB10554049D8B79388EA4B40997E8978EB10554017D522A298E84B4067B5C01E1310554017D522A298E84B40
16600	47908	84.680014	84.694655999999995	55.638784999999999	55.626319000000002	Центральная	0103000020E610000001000000050000009EB47059852B554085EE92382BD04B409EB47059852B55407216F6B4C3D14B40177E703E752C55407216F6B4C3D14B40177E703E752C554085EE92382BD04B409EB47059852B554085EE92382BD04B40
75560	60684	84.200609999999998	84.233389000000003	55.627046	55.612614000000001	Школьная	0103000020E61000000100000005000000095053CBD60C55402F89B3226ACE4B40095053CBD60C5540378B170B43D04B40C18F6AD8EF0E5540378B170B43D04B40C18F6AD8EF0E55402F89B3226ACE4B40095053CBD60C55402F89B3226ACE4B40
75350	60579	84.463950999999994	84.486480999999998	55.702266999999999	55.690140999999997	Центральная 	0103000020E6100000010000000500000093FC885FB11D55407A50508A56D84B4093FC885FB11D5540AF0793E2E3D94B4006483481221F5540AF0793E2E3D94B4006483481221F55407A50508A56D84B4093FC885FB11D55407A50508A56D84B40
75571	60579	84.463950999999994	84.486480999999998	55.702266999999999	55.690140999999997	Центральная	0103000020E6100000010000000500000093FC885FB11D55407A50508A56D84B4093FC885FB11D5540AF0793E2E3D94B4006483481221F5540AF0793E2E3D94B4006483481221F55407A50508A56D84B4093FC885FB11D55407A50508A56D84B40
75555	60682	84.352344000000002	84.369763000000006	55.815255999999998	55.800432999999998	Почтовая 	0103000020E61000000100000005000000473CD9CD8C165540D0D1AA9674E64B40473CD9CD8C16554013EF004F5AE84B4056116E32AA17554013EF004F5AE84B4056116E32AA175540D0D1AA9674E64B40473CD9CD8C165540D0D1AA9674E64B40
13971	19692	84.348212000000004	84.431638000000007	55.687274000000002	55.650002000000001	Ремесленная	0103000020E61000000100000005000000C904FC1A49165540D42AFA4333D34B40C904FC1A4916554010B22C98F8D74B407F6DFDF49F1B554010B22C98F8D74B407F6DFDF49F1B5540D42AFA4333D34B40C904FC1A49165540D42AFA4333D34B40
13823	19692	84.348212000000004	84.431638000000007	55.687274000000002	55.650002000000001	Промышленная	0103000020E61000000100000005000000C904FC1A49165540D42AFA4333D34B40C904FC1A4916554010B22C98F8D74B407F6DFDF49F1B554010B22C98F8D74B407F6DFDF49F1B5540D42AFA4333D34B40C904FC1A49165540D42AFA4333D34B40
13448	19692	84.348212000000004	84.431638000000007	55.687274000000002	55.650002000000001	Московская	0103000020E61000000100000005000000C904FC1A49165540D42AFA4333D34B40C904FC1A4916554010B22C98F8D74B407F6DFDF49F1B554010B22C98F8D74B407F6DFDF49F1B5540D42AFA4333D34B40C904FC1A49165540D42AFA4333D34B40
14134	19692	84.348212000000004	84.431638000000007	55.687274000000002	55.650002000000001	Ленина	0103000020E61000000100000005000000C904FC1A49165540D42AFA4333D34B40C904FC1A4916554010B22C98F8D74B407F6DFDF49F1B554010B22C98F8D74B407F6DFDF49F1B5540D42AFA4333D34B40C904FC1A49165540D42AFA4333D34B40
15879	19692	84.348212000000004	84.431638000000007	55.687274000000002	55.650002000000001	Березовская	0103000020E61000000100000005000000C904FC1A49165540D42AFA4333D34B40C904FC1A4916554010B22C98F8D74B407F6DFDF49F1B554010B22C98F8D74B407F6DFDF49F1B5540D42AFA4333D34B40C904FC1A49165540D42AFA4333D34B40
68371	19692	84.348212000000004	84.431638000000007	55.687274000000002	55.650002000000001	40 лет Победы	0103000020E61000000100000005000000C904FC1A49165540D42AFA4333D34B40C904FC1A4916554010B22C98F8D74B407F6DFDF49F1B554010B22C98F8D74B407F6DFDF49F1B5540D42AFA4333D34B40C904FC1A49165540D42AFA4333D34B40
75558	49200	84.441142999999997	84.467642999999995	55.620657000000001	55.614963000000003	Пролетарская 	0103000020E61000000100000005000000FF76D9AF3B1C554002A08A1BB7CE4B40FF76D9AF3B1C5540498446B071CF4B4003CDE7DCED1D5540498446B071CF4B4003CDE7DCED1D554002A08A1BB7CE4B40FF76D9AF3B1C554002A08A1BB7CE4B40
75550	49200	84.441142999999997	84.467642999999995	55.620657000000001	55.614963000000003	Озерная	0103000020E61000000100000005000000FF76D9AF3B1C554002A08A1BB7CE4B40FF76D9AF3B1C5540498446B071CF4B4003CDE7DCED1D5540498446B071CF4B4003CDE7DCED1D554002A08A1BB7CE4B40FF76D9AF3B1C554002A08A1BB7CE4B40
75561	49200	84.441142999999997	84.467642999999995	55.620657000000001	55.614963000000003	Береговая	0103000020E61000000100000005000000FF76D9AF3B1C554002A08A1BB7CE4B40FF76D9AF3B1C5540498446B071CF4B4003CDE7DCED1D5540498446B071CF4B4003CDE7DCED1D554002A08A1BB7CE4B40FF76D9AF3B1C554002A08A1BB7CE4B40
75559	60683	83.876039000000006	83.899674000000005	55.646340000000002	55.631284999999998	Центральная	0103000020E6100000010000000500000051C1E10511F8544049BA66F2CDD04B4051C1E10511F854405F0CE544BBD24B40F0C3414294F954405F0CE544BBD24B40F0C3414294F9544049BA66F2CDD04B4051C1E10511F8544049BA66F2CDD04B40
75479	60627	84.601043000000004	84.625189000000006	55.648377000000004	55.632362000000001	Центральная улица	0103000020E61000000100000005000000581F0F7D77265540D89DEE3CF1D04B40581F0F7D77265540433D7D04FED24B406A34B91803285540433D7D04FED24B406A34B91803285540D89DEE3CF1D04B40581F0F7D77265540D89DEE3CF1D04B40
13557	41236	77.889522999999997	78.021322999999995	55.378872000000001	55.303755000000002	Вокзальная	0103000020E610000001000000050000008C82E0F1ED7853408D7F9F71E1A64B408C82E0F1ED78534060AFB0E07EB04B40C4E9245B5D81534060AFB0E07EB04B40C4E9245B5D8153408D7F9F71E1A64B408C82E0F1ED7853408D7F9F71E1A64B40
14094	15608	78.186954999999998	78.205882000000003	55.158045000000001	55.148651999999998	Весенняя	0103000020E61000000100000005000000B7B41A12F78B5340143E5B0707934B40B7B41A12F78B5340EE258DD13A944B407235B22B2D8D5340EE258DD13A944B407235B22B2D8D5340143E5B0707934B40B7B41A12F78B5340143E5B0707934B40
68563	14360	78.206357999999994	78.221440999999999	55.328724000000001	55.318874999999998	Новая	0103000020E6100000010000000500000026512FF8348D5340894160E5D0A84B4026512FF8348D534085B4C6A013AA4B40963FDF162C8E534085B4C6A013AA4B40963FDF162C8E5340894160E5D0A84B4026512FF8348D5340894160E5D0A84B40
68349	14112	77.922535999999994	77.952772999999993	55.297369000000003	55.282943000000003	Центральная	0103000020E610000001000000050000007D586FD40A7B5340EAD0E97937A44B407D586FD40A7B534010ECF82F10A64B40C1E09A3BFA7C534010ECF82F10A64B40C1E09A3BFA7C5340EAD0E97937A44B407D586FD40A7B5340EAD0E97937A44B40
13600	16089	78.067892000000001	78.092308000000003	55.011597999999999	55.002687000000002	переулок Школьный	0103000020E610000001000000050000003EEAAF5758845340EB8F300C58804B403EEAAF57588453407959130B7C814B40304AD05FE88553407959130B7C814B40304AD05FE8855340EB8F300C58804B403EEAAF5758845340EB8F300C58804B40
14082	14882	78.746273000000002	78.764976000000004	55.345038000000002	55.340649999999997	Северная 	0103000020E61000000100000005000000D238D4EFC2AF5340F2B0506B9AAB4B40D238D4EFC2AF53404AF086342AAC4B40658EE55DF5B053404AF086342AAC4B40658EE55DF5B05340F2B0506B9AAB4B40D238D4EFC2AF5340F2B0506B9AAB4B40
14106	16372	78.036631	78.052880999999999	54.818480999999998	54.811923	Школьная	0103000020E6100000010000000500000044C18C295882534063EFC517ED674B4044C18C2958825340DDB243FCC3684B401B65FD6662835340DDB243FCC3684B401B65FD666283534063EFC517ED674B4044C18C295882534063EFC517ED674B40
68392	46628	78.575862000000001	78.620096000000004	55.101066000000003	55.087274999999998	Центральная	0103000020E6100000010000000500000096404AECDAA453401361C3D32B8B4B4096404AECDAA45340685E0EBBEF8C4B40591822A7AFA75340685E0EBBEF8C4B40591822A7AFA753401361C3D32B8B4B4096404AECDAA453401361C3D32B8B4B40
68662	15388	78.901223000000002	78.914698000000001	55.073618000000003	55.064642999999997	Молодёжная	0103000020E61000000100000005000000CBD93BA3ADB953402975C93846884B40CBD93BA3ADB95340CF328B506C894B40DDED7A698ABA5340CF328B506C894B40DDED7A698ABA53402975C93846884B40CBD93BA3ADB953402975C93846884B40
14340	14590	77.401899	78.985494000000003	55.429195	54.654494999999997	Мира	0103000020E61000000100000005000000E35295B6B8595340A032FE7DC6534B40E35295B6B8595340A94D9CDCEFB64B40DF196D5512BF5340A94D9CDCEFB64B40DF196D5512BF5340A032FE7DC6534B40E35295B6B8595340A032FE7DC6534B40
13902	41321	78.261246	78.284090000000006	54.900052000000002	54.892214000000003	Центральная	0103000020E610000001000000050000007E8D2441B890534045847F1134724B407E8D2441B8905340865968E734734B40B9C7D2872E925340865968E734734B40B9C7D2872E92534045847F1134724B407E8D2441B890534045847F1134724B40
68659	15133	77.401899	78.985494000000003	55.429195	54.654494999999997	Школьная	0103000020E61000000100000005000000E35295B6B8595340A032FE7DC6534B40E35295B6B8595340A94D9CDCEFB64B40DF196D5512BF5340A94D9CDCEFB64B40DF196D5512BF5340A032FE7DC6534B40E35295B6B8595340A032FE7DC6534B40
68565	16346	78.078573000000006	78.104839999999996	54.931288000000002	54.920211000000002	Центральная	0103000020E6100000010000000500000050560C5707855340B1355B79C9754B4050560C57078553402194F77134774B4002D4D4B2B58653402194F77134774B4002D4D4B2B5865340B1355B79C9754B4050560C5707855340B1355B79C9754B40
13900	16048	78.160706000000005	78.187529999999995	54.959159999999997	54.945205000000001	Центральная	0103000020E610000001000000050000005891D101498A53400282397AFC784B405891D101498A5340D0D03FC1C57A4B403541D47D008C5340D0D03FC1C57A4B403541D47D008C53400282397AFC784B405891D101498A53400282397AFC784B40
16601	14741	78.509198999999995	78.540693000000005	55.401983999999999	55.392183000000003	площадь Труда	0103000020E61000000100000005000000FA0967B796A053400A86730D33B24B40FA0967B796A05340F4C1323674B34B40460BD0B69AA25340F4C1323674B34B40460BD0B69AA253400A86730D33B24B40FA0967B796A053400A86730D33B24B40
14097	41372	78.167327	78.194168000000005	55.118538999999998	55.106948000000003	Центральная	0103000020E61000000100000005000000382F4E7CB58A5340B22FD978B08D4B40382F4E7CB58A5340782634492C8F4B40817B9E3F6D8C5340782634492C8F4B40817B9E3F6D8C5340B22FD978B08D4B40382F4E7CB58A5340B22FD978B08D4B40
68613	46385	77.814019000000002	77.847427999999994	54.801493000000001	54.791097000000001	Южная	0103000020E61000000100000005000000A6D425E3187453405B7B9FAA42654B40A6D425E318745340897C975297664B40BD6DA6423C765340897C975297664B40BD6DA6423C7653405B7B9FAA42654B40A6D425E3187453405B7B9FAA42654B40
68568	46385	77.814019000000002	77.847427999999994	54.801493000000001	54.791097000000001	Школьная	0103000020E61000000100000005000000A6D425E3187453405B7B9FAA42654B40A6D425E318745340897C975297664B40BD6DA6423C765340897C975297664B40BD6DA6423C7653405B7B9FAA42654B40A6D425E3187453405B7B9FAA42654B40
14877	15657	78.314839000000006	78.336021000000002	55.105227999999997	55.097177000000002	Башира	0103000020E6100000010000000500000058207A52269453403276C24B708C4B4058207A5226945340CE4F711C788D4B403B71395E81955340CE4F711C788D4B403B71395E819553403276C24B708C4B4058207A52269453403276C24B708C4B40
13879	14999	78.533489000000003	78.555685999999994	55.275492999999997	55.265779000000002	Зеленая	0103000020E61000000100000005000000A6F10BAF24A25340577BD80B05A24B40A6F10BAF24A2534072A3C85A43A34B401536035C90A3534072A3C85A43A34B401536035C90A35340577BD80B05A24B40A6F10BAF24A25340577BD80B05A24B40
13569	41241	78.077072999999999	78.086433	55.268661000000002	55.264403999999999	переулок Сельский	0103000020E61000000100000005000000E59997C3EE8453403E7782FDD7A14B40E59997C3EE845340F75AD07B63A24B40E412471E88855340F75AD07B63A24B40E412471E888553403E7782FDD7A14B40E59997C3EE8453403E7782FDD7A14B40
68416	41375	77.401899	78.985494000000003	55.429195	54.654494999999997	Сибирская	0103000020E61000000100000005000000E35295B6B8595340A032FE7DC6534B40E35295B6B8595340A94D9CDCEFB64B40DF196D5512BF5340A94D9CDCEFB64B40DF196D5512BF5340A032FE7DC6534B40E35295B6B8595340A032FE7DC6534B40
68571	41323	77.824079999999995	77.846574000000004	55.014178999999999	55.005412999999997	Рыбозаводская	0103000020E6100000010000000500000069520ABABD74534093FC885FB1804B4069520ABABD7453401EA5129ED0814B4036E9B6442E7653401EA5129ED0814B4036E9B6442E76534093FC885FB1804B4069520ABABD74534093FC885FB1804B40
16545	16201	78.390889999999999	78.420670000000001	54.968380000000003	54.959108000000001	Центральная	0103000020E6100000010000000500000057957D57049953407EAA0A0DC47A4B4057957D5704995340DD0C37E0F37B4B40221ADD41EC9A5340DD0C37E0F37B4B40221ADD41EC9A53407EAA0A0DC47A4B4057957D57049953407EAA0A0DC47A4B40
13764	41287	77.665366000000006	77.704235999999995	55.084435999999997	55.069819000000003	Центральная	0103000020E61000000100000005000000B477465B956A5340D9D138D4EF884B40B477465B956A5340724D81CCCE8A4B409D2ADF33126D5340724D81CCCE8A4B409D2ADF33126D5340D9D138D4EF884B40B477465B956A5340D9D138D4EF884B40
68369	16659	77.832093	77.873631000000003	55.097496	55.085461000000002	Молодёжная	0103000020E61000000100000005000000C18EFF0241755340AF0AD462F08A4B40C18EFF0241755340D3BEB9BF7A8C4B406571FF91E9775340D3BEB9BF7A8C4B406571FF91E9775340AF0AD462F08A4B40C18EFF0241755340AF0AD462F08A4B40
13589	41246	78.216824000000003	78.228367000000006	55.222523000000002	55.213175999999997	Школьная	0103000020E610000001000000050000003A3FC571E08D53406325E659499B4B403A3FC571E08D5340CDCD37A27B9C4B40151F9F909D8E5340CDCD37A27B9C4B40151F9F909D8E53406325E659499B4B403A3FC571E08D53406325E659499B4B40
15665	46152	78.347950999999995	78.363788	55.411015999999996	55.403809000000003	Центральная	0103000020E61000000100000005000000126745D4449653404D6A6803B0B34B40126745D444965340FD101B2C9CB44B4058AB764D48975340FD101B2C9CB44B4058AB764D489753404D6A6803B0B34B40126745D4449653404D6A6803B0B34B40
13906	41322	78.265287999999998	78.281485000000004	54.989289999999997	54.982745000000001	 Школьная	0103000020E610000001000000050000005C01857AFA9053405DA79196CA7D4B405C01857AFA9053404221020EA17E4B402254A9D9039253404221020EA17E4B402254A9D9039253405DA79196CA7D4B405C01857AFA9053405DA79196CA7D4B40
68569	16605	77.814423000000005	77.833504000000005	54.715004	54.707155999999998	Центральная	0103000020E610000001000000050000000E87A5811F745340C8957A16845A4B400E87A5811F7453402D414640855B4B4074452921587553402D414640855B4B407445292158755340C8957A16845A4B400E87A5811F745340C8957A16845A4B40
14062	41366	77.495431999999994	77.531965999999997	55.050457000000002	55.038026000000002	Центральная	0103000020E6100000010000000500000014596B28B55F5340E8323509DE844B4014596B28B55F5340596DFE5F75864B405F251FBB0B625340596DFE5F75864B405F251FBB0B625340E8323509DE844B4014596B28B55F5340E8323509DE844B40
68661	15308	78.823941000000005	78.849534000000006	55.158723999999999	55.146548000000003	Центральная	0103000020E6100000010000000500000059350873BBB45340A9A5B915C2924B4059350873BBB453408F8B6A1151944B40C4B5DAC35EB653408F8B6A1151944B40C4B5DAC35EB65340A9A5B915C2924B4059350873BBB45340A9A5B915C2924B40
68564	15689	78.112952000000007	78.137386000000006	55.192677000000003	55.183328000000003	Майская	0103000020E610000001000000050000002481069B3A8753407638BA4A77974B402481069B3A87534080D8D2A3A9984B40693BA6EECA88534080D8D2A3A9984B40693BA6EECA8853407638BA4A77974B402481069B3A8753407638BA4A77974B40
13584	41244	78.642374000000004	78.650423000000004	55.194814999999998	55.188904999999998	Зеленая	0103000020E610000001000000050000003F73D6A71CA953408386FE092E984B403F73D6A71CA9534097E2AAB2EF984B403D64CA87A0A9534097E2AAB2EF984B403D64CA87A0A953408386FE092E984B403F73D6A71CA953408386FE092E984B40
15778	46710	77.780215999999996	77.794130999999993	54.112372999999998	54.100025000000002	Центральная	0103000020E6100000010000000500000038F4160FEF71534026E4839ECD0C4B4038F4160FEF71534009FA0B3D620E4B40586FD40AD372534009FA0B3D620E4B40586FD40AD372534026E4839ECD0C4B4038F4160FEF71534026E4839ECD0C4B40
14161	11971	77.153092999999998	77.171895000000006	53.832496999999996	53.819853999999999	Школьная	0103000020E61000000100000005000000C70F9546CC49534055BFD2F9F0E84A40C70F9546CC4953405182FE428FEA4A4024D6E253004B53405182FE428FEA4A4024D6E253004B534055BFD2F9F0E84A40C70F9546CC49534055BFD2F9F0E84A40
13710	41274	77.744300999999993	77.752133999999998	54.059420000000003	54.043283000000002	Жемчужная	0103000020E610000001000000050000005358A9A0A26F534084BC1E4C8A054B405358A9A0A26F53403A5D16139B074B406B0DA5F6227053403A5D16139B074B406B0DA5F62270534084BC1E4C8A054B405358A9A0A26F534084BC1E4C8A054B40
13704	41270	77.358861000000005	77.377699000000007	53.943466999999998	53.931891	Приозерная	0103000020E61000000100000005000000D5B32094F7565340E7374C3448F74A40D5B32094F756534078EDD286C3F84A40D82E6D382C58534078EDD286C3F84A40D82E6D382C585340E7374C3448F74A40D5B32094F7565340E7374C3448F74A40
14008	41351	77.337517000000005	77.356813000000002	54.140779999999999	54.132736000000001	Светлая	0103000020E610000001000000050000000536E7E0995553403D80457EFD104B400536E7E09955534027F73B1405124B4069723106D656534027F73B1405124B4069723106D65653403D80457EFD104B400536E7E0995553403D80457EFD104B40
16563	45750	77.893538000000007	77.918260000000004	53.909937999999997	53.895763000000002	Садовая	0103000020E61000000100000005000000EEEE01BA2F795340C2FBAA5CA8F24A40EEEE01BA2F7953409EB12FD978F44A40664E97C5C47A53409EB12FD978F44A40664E97C5C47A5340C2FBAA5CA8F24A40EEEE01BA2F795340C2FBAA5CA8F24A40
13841	41303	77.273871	77.284920999999997	53.866900999999999	53.851309000000001	 Зеленая	0103000020E61000000100000005000000A9143B1A875153402EE57CB1F7EC4A40A9143B1A8751534052EFA99CF6EE4A40643C4A253C52534052EFA99CF6EE4A40643C4A253C5253402EE57CB1F7EC4A40A9143B1A875153402EE57CB1F7EC4A40
13720	41213	77.423899000000006	77.435388000000003	53.784156000000003	53.781379000000001	переулок Половинный	0103000020E61000000100000005000000A8734529215B5340FE63213A04E44A40A8734529215B5340297B4B395FE44A408944A165DD5B5340297B4B395FE44A408944A165DD5B5340FE63213A04E44A40A8734529215B5340FE63213A04E44A40
13994	41343	77.212974000000003	77.235594000000006	53.960951999999999	53.955866	Степная	0103000020E610000001000000050000007E39B35DA14D5340DEAD2CD159FA4A407E39B35DA14D53404D83A27900FB4A409148DBF8134F53404D83A27900FB4A409148DBF8134F5340DEAD2CD159FA4A407E39B35DA14D5340DEAD2CD159FA4A40
15753	45499	77.417412999999996	77.433977999999996	54.153905999999999	54.146613000000002	Целинная	0103000020E6100000010000000500000037FB03E5B65A53409015FC36C4124B4037FB03E5B65A53403F541A31B3134B40BE4BA94BC65B53403F541A31B3134B40BE4BA94BC65B53409015FC36C4124B4037FB03E5B65A53409015FC36C4124B40
75594	45499	77.417412999999996	77.433977999999996	54.153905999999999	54.146613000000002	Переселенческая 	0103000020E6100000010000000500000037FB03E5B65A53409015FC36C4124B4037FB03E5B65A53403F541A31B3134B40BE4BA94BC65B53403F541A31B3134B40BE4BA94BC65B53409015FC36C4124B4037FB03E5B65A53409015FC36C4124B40
13938	12916	77.390347000000006	77.404692999999995	54.088382000000003	54.084083	Молодежная	0103000020E61000000100000005000000DFC5FB71FB5853402593533BC30A4B40DFC5FB71FB5853400DC7F319500B4B40E3FA777DE65953400DC7F319500B4B40E3FA777DE65953402593533BC30A4B40DFC5FB71FB5853402593533BC30A4B40
13519	41227	77.730377000000004	77.763130000000004	53.848329	53.837434000000002	Центральная	0103000020E610000001000000050000000A302C7FBE6E53407C478D0931EB4A400A302C7FBE6E5340CB9F6F0B96EC4A402D26361FD7705340CB9F6F0B96EC4A402D26361FD77053407C478D0931EB4A400A302C7FBE6E53407C478D0931EB4A40
13999	12765	77.621150999999998	77.632936999999998	54.106544999999997	54.095632000000002	Центральная	0103000020E610000001000000050000002CB81FF0C0675340BD395CAB3D0C4B402CB81FF0C0675340B2463D44A30D4B406ADB300A82685340B2463D44A30D4B406ADB300A82685340BD395CAB3D0C4B402CB81FF0C0675340BD395CAB3D0C4B40
14006	41349	77.541390000000007	77.567916999999994	53.916716000000001	53.904947	Центральная	0103000020E610000001000000050000006A183E22A662534081CEA44DD5F34A406A183E22A662534027DC2BF356F54A40EA758BC05864534027DC2BF356F54A40EA758BC05864534081CEA44DD5F34A406A183E22A662534081CEA44DD5F34A40
14190	41391	78.305567999999994	78.314577999999997	54.115918999999998	54.105452	Зеленая	0103000020E6100000010000000500000010AD156D8E9353401EA67D737F0D4B4010AD156D8E93534015FE0C6FD60E4B40A182C30B2294534015FE0C6FD60E4B40A182C30B229453401EA67D737F0D4B4010AD156D8E9353401EA67D737F0D4B40
13538	41231	77.418132	77.438353000000006	53.991014999999997	53.974384000000001	Центральная	0103000020E610000001000000050000004F5AB8ACC25A534072DF6A9DB8FC4A404F5AB8ACC25A5340376C5B94D9FE4A40A0C6BDF90D5C5340376C5B94D9FE4A40A0C6BDF90D5C534072DF6A9DB8FC4A404F5AB8ACC25A534072DF6A9DB8FC4A40
68595	41231	77.418132	77.438353000000006	53.991014999999997	53.974384000000001	Весенняя	0103000020E610000001000000050000004F5AB8ACC25A534072DF6A9DB8FC4A404F5AB8ACC25A5340376C5B94D9FE4A40A0C6BDF90D5C5340376C5B94D9FE4A40A0C6BDF90D5C534072DF6A9DB8FC4A404F5AB8ACC25A534072DF6A9DB8FC4A40
13891	906	77.692656999999997	77.712059999999994	54.165399000000001	54.160707000000002	Молодежная	0103000020E610000001000000050000001C96067E546C5340809E060C92144B401C96067E546C534043E55FCB2B154B408B321B64926D534043E55FCB2B154B408B321B64926D5340809E060C92144B401C96067E546C5340809E060C92144B40
13861	41309	78.194733999999997	78.204696999999996	54.042589999999997	54.027428999999998	Широкая	0103000020E61000000100000005000000D55A9885768C534022FB20CB82034B40D55A9885768C53407D91D09673054B40B72572C1198D53407D91D09673054B40B72572C1198D534022FB20CB82034B40D55A9885768C534022FB20CB82034B40
13478	12043	77.633718000000002	77.697453999999993	54.108873000000003	54.084622000000003	Сибиряков-Гвардейцев	0103000020E61000000100000005000000BD38F1D58E685340D542C9E4D40A4B40BD38F1D58E6853406E35EB8CEF0D4B40B81D1A16A36C53406E35EB8CEF0D4B40B81D1A16A36C5340D542C9E4D40A4B40BD38F1D58E685340D542C9E4D40A4B40
13844	12043	77.633718000000002	77.697453999999993	54.108873000000003	54.084622000000003	Максима Горького	0103000020E61000000100000005000000BD38F1D58E685340D542C9E4D40A4B40BD38F1D58E6853406E35EB8CEF0D4B40B81D1A16A36C53406E35EB8CEF0D4B40B81D1A16A36C5340D542C9E4D40A4B40BD38F1D58E685340D542C9E4D40A4B40
16594	12043	77.633718000000002	77.697453999999993	54.108873000000003	54.084622000000003	Куйбышева	0103000020E61000000100000005000000BD38F1D58E685340D542C9E4D40A4B40BD38F1D58E6853406E35EB8CEF0D4B40B81D1A16A36C53406E35EB8CEF0D4B40B81D1A16A36C5340D542C9E4D40A4B40BD38F1D58E685340D542C9E4D40A4B40
14051	12043	77.633718000000002	77.697453999999993	54.108873000000003	54.084622000000003	Инкубаторская	0103000020E61000000100000005000000BD38F1D58E685340D542C9E4D40A4B40BD38F1D58E6853406E35EB8CEF0D4B40B81D1A16A36C53406E35EB8CEF0D4B40B81D1A16A36C5340D542C9E4D40A4B40BD38F1D58E685340D542C9E4D40A4B40
13505	41219	77.379405000000006	77.406695999999997	54.024191999999999	54.015607000000003	Степная	0103000020E6100000010000000500000017BCE82B485853405A4B0169FF014B4017BCE82B48585340946934B918034B407FDAA84E075A5340946934B918034B407FDAA84E075A53405A4B0169FF014B4017BCE82B485853405A4B0169FF014B40
75623	59636	93.152608999999998	93.162678999999997	55.973934	55.946955000000003	Советская	0103000020E61000000100000005000000D1048A58C449574050E449D235F94B40D1048A58C4495740323B8BDEA9FC4B40BE2F2E55694A5740323B8BDEA9FC4B40BE2F2E55694A574050E449D235F94B40D1048A58C449574050E449D235F94B40
73100	59833	93.433261000000002	93.435803000000007	56.124828000000001	56.121600999999998	Рабочая	0103000020E610000001000000050000007768588CBA5B574098141F9F900F4C407768588CBA5B574003D0285DFA0F4C40EB1F4432E45B574003D0285DFA0F4C40EB1F4432E45B574098141F9F900F4C407768588CBA5B574098141F9F900F4C40
28107	51807	93.270432	93.277511000000004	56.006210000000003	56.000351000000002	Солнечная	0103000020E61000000100000005000000AEF204C24E515740ADC266800B004C40AEF204C24E5157403F74417DCB004C40F0517FBDC25157403F74417DCB004C40F0517FBDC2515740ADC266800B004C40AEF204C24E515740ADC266800B004C40
72767	59701	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Нефтеразведочная	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72312	59593	91.673946000000001	91.726623000000004	53.715775000000001	53.695675999999999	Ленина	0103000020E61000000100000005000000485167EE21EB5640594E42E90BD94A40485167EE21EB5640AF25E4839EDB4A405F61C1FD80EE5640AF25E4839EDB4A405F61C1FD80EE5640594E42E90BD94A40485167EE21EB5640594E42E90BD94A40
73305	59905	90.525773000000001	90.529510000000002	56.284213999999999	56.277797999999997	Школьная	0103000020E61000000100000005000000AB07CC43A6A15640757286E28E234C40AB07CC43A6A156405D88D51F61244C40EB39E97DE3A156405D88D51F61244C40EB39E97DE3A15640757286E28E234C40AB07CC43A6A15640757286E28E234C40
72601	59631	95.749791000000002	95.751022000000006	56.234794999999998	56.231043	Юбилейная	0103000020E6100000010000000500000073F56393FCEF5740207C28D1921D4C4073F56393FCEF5740D52137C30D1E4C40E62494BE10F05740D52137C30D1E4C40E62494BE10F05740207C28D1921D4C4073F56393FCEF5740207C28D1921D4C40
71703	59498	94.078601000000006	94.107922000000002	55.067149000000001	55.06521	Береговая	0103000020E61000000100000005000000B51B7DCC07855740A3AF20CD58884B40B51B7DCC07855740C47AA35698884B403621AD31E8865740C47AA35698884B403621AD31E8865740A3AF20CD58884B40B51B7DCC07855740A3AF20CD58884B40
73253	59893	92.981048999999999	92.985522000000003	56.169663999999997	56.159588999999997	Центральная	0103000020E6100000010000000500000081B1BE81C93E574092E68F696D144C4081B1BE81C93E57407EA7C98CB7154C4044DFDDCA123F57407EA7C98CB7154C4044DFDDCA123F574092E68F696D144C4081B1BE81C93E574092E68F696D144C40
28259	15627	93.468429999999998	93.510058000000001	56.336848000000003	56.312969000000002	Центральная	0103000020E61000000100000005000000C79DD2C1FA5D5740B7D4415E0F284C40C79DD2C1FA5D57408CDCD3D51D2B4C400B444FCAA46057408CDCD3D51D2B4C400B444FCAA4605740B7D4415E0F284C40C79DD2C1FA5D5740B7D4415E0F284C40
27910	48592	95.67595	95.692092000000002	56.301259000000002	56.284053999999998	Лесная	0103000020E61000000100000005000000CCEEC9C342EB57402426A8E15B244C40CCEEC9C342EB57401650A8A78F264C40B0743E3C4BEC57401650A8A78F264C40B0743E3C4BEC57402426A8E15B244C40CCEEC9C342EB57402426A8E15B244C40
28498	51737	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	6 микрорайон	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
27892	51737	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	4 микрорайон	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
72605	59633	91.166640999999998	91.199725000000001	55.253675999999999	55.241339000000004	Пришкольная	0103000020E610000001000000050000000E4B033FAACA5640EB1F4432E49E4B400E4B033FAACA5640DAE3857478A04B4064CC5D4BC8CC5640DAE3857478A04B4064CC5D4BC8CC5640EB1F4432E49E4B400E4B033FAACA5640EB1F4432E49E4B40
71564	6946	95.687691000000001	95.739127999999994	56.142240000000001	56.118540000000003	Кооперативная	0103000020E610000001000000050000003AB01C2103EC574049A297512C0F4C403AB01C2103EC57406E179AEB34124C40B4E386DF4DEF57406E179AEB34124C40B4E386DF4DEF574049A297512C0F4C403AB01C2103EC574049A297512C0F4C40
73150	59871	92.981048999999999	92.985522000000003	56.169663999999997	56.159588999999997	Центральная	0103000020E6100000010000000500000081B1BE81C93E574092E68F696D144C4081B1BE81C93E57407EA7C98CB7154C4044DFDDCA123F57407EA7C98CB7154C4044DFDDCA123F574092E68F696D144C4081B1BE81C93E574092E68F696D144C40
71691	59495	93.152608999999998	93.162678999999997	55.973934	55.946955000000003	Советская	0103000020E61000000100000005000000D1048A58C449574050E449D235F94B40D1048A58C4495740323B8BDEA9FC4B40BE2F2E55694A5740323B8BDEA9FC4B40BE2F2E55694A574050E449D235F94B40D1048A58C449574050E449D235F94B40
73036	59781	90.516862000000003	90.528081999999998	56.242234000000003	56.242069000000001	Киевская	0103000020E61000000100000005000000E4A25A4414A156400E30F31DFC1E4C40E4A25A4414A1564059FD1186011F4C40CDE67118CCA1564059FD1186011F4C40CDE67118CCA156400E30F31DFC1E4C40E4A25A4414A156400E30F31DFC1E4C40
72695	59668	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Л.Чайкиной	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
28202	51753	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	Тракторная	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
72657	51753	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	Строителей	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
27851	51753	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	Ленина	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
72676	51753	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	Гоголя	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
72742	59465	95.754570000000001	95.754579000000007	56.220188	56.218465999999999	Таежная	0103000020E61000000100000005000000BC22F8DF4AF05740DBA4A2B1F61B4C40BC22F8DF4AF057405F7CD11E2F1C4C40E6CFB7054BF057405F7CD11E2F1C4C40E6CFB7054BF05740DBA4A2B1F61B4C40BC22F8DF4AF05740DBA4A2B1F61B4C40
71655	59465	93.152608999999998	93.162678999999997	55.973934	55.946955000000003	Советская	0103000020E61000000100000005000000D1048A58C449574050E449D235F94B40D1048A58C4495740323B8BDEA9FC4B40BE2F2E55694A5740323B8BDEA9FC4B40BE2F2E55694A574050E449D235F94B40D1048A58C449574050E449D235F94B40
28483	51876	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Увачана	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
28194	17183	91.632902000000001	91.650948999999997	53.667907	53.654957000000003	Набережная	0103000020E61000000100000005000000ACE4637781E85640A5A487A1D5D34A40ACE4637781E856407EE200FA7DD54A404A97FE25A9E956407EE200FA7DD54A404A97FE25A9E95640A5A487A1D5D34A40ACE4637781E85640A5A487A1D5D34A40
72922	13809	93.279190999999997	93.316757999999993	56.128489999999999	56.104697000000002	Гагарина	0103000020E610000001000000050000009A95ED43DE515740A27E17B6660D4C409A95ED43DE51574078EE3D5C72104C40C4AF58C34554574078EE3D5C72104C40C4AF58C345545740A27E17B6660D4C409A95ED43DE515740A27E17B6660D4C40
72636	59645	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	Кирова	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
72489	59607	93.332217999999997	93.346924000000001	56.126483999999998	56.119815000000003	Энтузиастов	0103000020E610000001000000050000001F49490F43555740FE481119560F4C401F49490F43555740CFBBB1A030104C40A48CB80034565740CFBBB1A030104C40A48CB80034565740FE481119560F4C401F49490F43555740FE481119560F4C40
72906	25896	92.886347999999998	92.927851000000004	56.151381999999998	56.132710000000003	Почтовая	0103000020E610000001000000050000000038F6ECB938574014ED2AA4FC104C400038F6ECB9385740FE99417C60134C40E62329E9613B5740FE99417C60134C40E62329E9613B574014ED2AA4FC104C400038F6ECB938574014ED2AA4FC104C40
73261	59895	90.525773000000001	90.529510000000002	56.284213999999999	56.277797999999997	Школьная	0103000020E61000000100000005000000AB07CC43A6A15640757286E28E234C40AB07CC43A6A156405D88D51F61244C40EB39E97DE3A156405D88D51F61244C40EB39E97DE3A15640757286E28E234C40AB07CC43A6A15640757286E28E234C40
28645	51907	95.804013999999995	95.822311999999997	55.552799999999998	55.541749000000003	Береговая	0103000020E61000000100000005000000ACE122F774F3574003D2FE0758C54B40ACE122F774F35740499D8026C2C64B40EFC682C2A0F45740499D8026C2C64B40EFC682C2A0F4574003D2FE0758C54B40ACE122F774F3574003D2FE0758C54B40
27779	9531	92.964393999999999	92.995565999999997	56.177145000000003	56.151682000000001	Новая	0103000020E610000001000000050000005A9D9CA1B83D574029B2D6506A134C405A9D9CA1B83D574031D3F6AFAC164C409CC0745AB73F574031D3F6AFAC164C409CC0745AB73F574029B2D6506A134C405A9D9CA1B83D574029B2D6506A134C40
72543	3083	93.316147000000001	93.335991000000007	56.129036999999997	56.117064999999997	Юности	0103000020E61000000100000005000000A06EA0C03B545740CC4065FCFB0E4C40A06EA0C03B545740AA7CCF4884104C40063065E080555740AA7CCF4884104C40063065E080555740CC4065FCFB0E4C40A06EA0C03B545740CC4065FCFB0E4C40
72478	3083	93.332217999999997	93.346924000000001	56.126483999999998	56.119815000000003	Энтузиастов	0103000020E610000001000000050000001F49490F43555740FE481119560F4C401F49490F43555740CFBBB1A030104C40A48CB80034565740CFBBB1A030104C40A48CB80034565740FE481119560F4C401F49490F43555740FE481119560F4C40
72178	3083	93.335982000000001	93.349312999999995	56.129032000000002	56.121732000000002	Труда	0103000020E61000000100000005000000DC82A5BA80555740377007EA940F4C40DC82A5BA805557409911DE1E84104C4054C4E9245B5657409911DE1E84104C4054C4E9245B565740377007EA940F4C40DC82A5BA80555740377007EA940F4C40
72292	3083	93.325103999999996	93.351748000000001	56.131189999999997	56.113115000000001	Ленинского Комсомола	0103000020E610000001000000050000001FF30181CE545740F1D7648D7A0E4C401FF30181CE545740F7C77BD5CA104C40BD1B0B0A83565740F7C77BD5CA104C40BD1B0B0A83565740F1D7648D7A0E4C401FF30181CE545740F1D7648D7A0E4C40
72541	3083	93.324043000000003	93.337985000000003	56.120401999999999	56.113446000000003	Весенняя	0103000020E61000000100000005000000DBDFD91EBD54574057EE0566850E4C40DBDFD91EBD545740BE2F2E55690F4C407862D68BA1555740BE2F2E55690F4C407862D68BA155574057EE0566850E4C40DBDFD91EBD54574057EE0566850E4C40
72293	3083	93.305969000000005	93.410838999999996	56.155718999999998	56.099521000000003	9 Пятилетки	0103000020E61000000100000005000000C02500FF94535740F321A81ABD0C4C40C02500FF94535740D32EA699EE134C40F73AA92F4B5A5740D32EA699EE134C40F73AA92F4B5A5740F321A81ABD0C4C40C02500FF94535740F321A81ABD0C4C40
28017	51796	93.382199999999997	93.398522999999997	55.887498000000001	55.874192999999998	Советская	0103000020E61000000100000005000000FF21FDF67558574031B2648EE5EF4B40FF21FDF675585740F9A1D28899F14B400BED9C6681595740F9A1D28899F14B400BED9C668159574031B2648EE5EF4B40FF21FDF67558574031B2648EE5EF4B40
28651	51908	92.726736000000002	92.727023000000003	56.047801	56.045780000000001	Хантайская Набережная	0103000020E61000000100000005000000DB34B6D7822E5740CB67791EDC054C40DB34B6D7822E5740A9DBD9571E064C40261C7A8B872E5740A9DBD9571E064C40261C7A8B872E5740CB67791EDC054C40DB34B6D7822E5740CB67791EDC054C40
27813	24874	92.389741999999998	92.426770000000005	56.097045999999999	56.082912999999998	Вокзальная	0103000020E610000001000000050000002BF86D88F1185740E5B4A7E49C0A4C402BF86D88F1185740931ADA006C0C4C407E3A1E33501B5740931ADA006C0C4C407E3A1E33501B5740E5B4A7E49C0A4C402BF86D88F1185740E5B4A7E49C0A4C40
76415	60820	92.889015999999998	92.899732999999998	56.031081	56.028424999999999	Спандаряна	0103000020E61000000100000005000000BA675DA3E5385740C4B12E6EA3034C40BA675DA3E538574074435376FA034C407288B8399539574074435376FA034C407288B83995395740C4B12E6EA3034C40BA675DA3E5385740C4B12E6EA3034C40
72598	51798	92.865803999999997	92.867771000000005	56.020758000000001	56.006905000000003	Перенсона	0103000020E61000000100000005000000BE2F2E5569375740E6965643E2004C40BE2F2E5569375740B090B932A8024C40B45A608F89375740B090B932A8024C40B45A608F89375740E6965643E2004C40BE2F2E5569375740E6965643E2004C40
28030	51798	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Олимпийская	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72195	51798	91.684410999999997	91.728088	53.716500000000003	53.696874999999999	Октябрьская	0103000020E610000001000000050000007381CB63CDEB56403333333333D94A407381CB63CDEB5640C1CAA145B6DB4A400B2769FE98EE5640C1CAA145B6DB4A400B2769FE98EE56403333333333D94A407381CB63CDEB56403333333333D94A40
72593	51798	95.754920999999996	95.768125999999995	56.227209999999999	56.220773999999999	Космонавтов	0103000020E6100000010000000500000012842BA050F057404FE78A52421C4C4012842BA050F057407EA99F37151D4C40444DF4F928F157407EA99F37151D4C40444DF4F928F157404FE78A52421C4C4012842BA050F057404FE78A52421C4C40
72573	51798	92.873835	92.874509000000003	56.028737	56.020733	Заречная	0103000020E6100000010000000500000069C6A2E9EC37574057790261A7024C4069C6A2E9EC375740B3976DA7AD034C40B1C398F4F7375740B3976DA7AD034C40B1C398F4F737574057790261A7024C4069C6A2E9EC37574057790261A7024C40
28405	17053	91.594076999999999	91.628878	53.705275999999998	53.680159000000003	Набережная	0103000020E610000001000000050000009293895B05E65640408A3A730FD74A409293895B05E65640AC53E57B46DA4A4021CB82893FE85640AC53E57B46DA4A4021CB82893FE85640408A3A730FD74A409293895B05E65640408A3A730FD74A40
28534	17053	91.594076999999999	91.628878	53.705275999999998	53.680159000000003	Дудинская	0103000020E610000001000000050000009293895B05E65640408A3A730FD74A409293895B05E65640AC53E57B46DA4A4021CB82893FE85640AC53E57B46DA4A4021CB82893FE85640408A3A730FD74A409293895B05E65640408A3A730FD74A40
72477	59605	91.668655000000001	91.697940000000003	53.702691000000002	53.696049000000002	Карла Маркса	0103000020E61000000100000005000000A453573ECBEA5640EEB4352218D94A40A453573ECBEA5640C61858C7F1D94A407FA4880CABEC5640C61858C7F1D94A407FA4880CABEC5640EEB4352218D94A40A453573ECBEA5640EEB4352218D94A40
27883	47800	93.200247000000005	93.227663000000007	55.890476999999997	55.875298999999998	Октябрьская	0103000020E61000000100000005000000D107CBD8D04C57405A9C31CC09F04B40D107CBD8D04C57408B6B7C26FBF14B4098E0D407924E57408B6B7C26FBF14B4098E0D407924E57405A9C31CC09F04B40D107CBD8D04C57405A9C31CC09F04B40
72735	59688	92.815192999999994	93.033663000000004	56.005187999999997	55.997487	Энергетиков	0103000020E6100000010000000500000066BB421F2C345740B3976DA7ADFF4B4066BB421F2C345740732A1900AA004C407505DB8827425740732A1900AA004C407505DB8827425740B3976DA7ADFF4B4066BB421F2C345740B3976DA7ADFF4B40
28493	10388	90.420553999999996	90.445804999999993	56.400512999999997	56.378514000000003	Просвещения	0103000020E61000000100000005000000ED0C535BEA9A5640018A912573304C40ED0C535BEA9A5640B94F8E0244334C402BD9B111889C5640B94F8E0244334C402BD9B111889C5640018A912573304C40ED0C535BEA9A5640018A912573304C40
73034	10388	90.420553999999996	90.445804999999993	56.400512999999997	56.378514000000003	Коммунаров	0103000020E61000000100000005000000ED0C535BEA9A5640018A912573304C40ED0C535BEA9A5640B94F8E0244334C402BD9B111889C5640B94F8E0244334C402BD9B111889C5640018A912573304C40ED0C535BEA9A5640018A912573304C40
6691	25797	92.973152999999996	92.981380999999999	56.228966	56.228445999999998	улица Трактовая	0103000020E6100000010000000500000046408523483E57407573F1B73D1D4C4046408523483E5740AEF204C24E1D4C409CFA40F2CE3E5740AEF204C24E1D4C409CFA40F2CE3E57407573F1B73D1D4C4046408523483E57407573F1B73D1D4C40
28064	16851	90.560484000000002	90.589751000000007	56.36307	56.345868000000003	Школьная	0103000020E610000001000000050000009A7B48F8DEA35640D15D1267452C4C409A7B48F8DEA356405114E813792E4C402272FA7ABEA556405114E813792E4C402272FA7ABEA55640D15D1267452C4C409A7B48F8DEA35640D15D1267452C4C40
73359	59915	93.337373999999997	93.350526000000002	56.122334000000002	56.113446000000003	 Солнечная	0103000020E6100000010000000500000053211E899755574057EE0566850E4C4053211E89975557402D98F8A3A80F4C4074999A046F5657402D98F8A3A80F4C4074999A046F56574057EE0566850E4C4053211E899755574057EE0566850E4C40
72537	59620	91.676686000000004	91.694301999999993	53.696283999999999	53.692284999999998	Калинина	0103000020E610000001000000050000004FEACBD24EEB564074417DCB9CD84A404FEACBD24EEB5640315D88D51FD94A4008E3A7716FEC5640315D88D51FD94A4008E3A7716FEC564074417DCB9CD84A404FEACBD24EEB564074417DCB9CD84A40
72298	6241	93.433126000000001	93.437670999999995	56.124381	56.118385000000004	Мира	0103000020E6100000010000000500000007431D56B85B574022AB5B3D270F4C4007431D56B85B5740349F73B7EB0F4C4016DA39CD025C5740349F73B7EB0F4C4016DA39CD025C574022AB5B3D270F4C4007431D56B85B574022AB5B3D270F4C40
72544	6241	93.427395000000004	93.434545	56.123925	56.123227	Лесная	0103000020E6100000010000000500000055DE8E705A5B5740FA7DFFE6C50F4C4055DE8E705A5B574012143FC6DC0F4C40FBE8D495CF5B574012143FC6DC0F4C40FBE8D495CF5B5740FA7DFFE6C50F4C4055DE8E705A5B5740FA7DFFE6C50F4C40
27784	26231	92.956354000000005	93.004341999999994	56.349573999999997	56.325952999999998	Центральная	0103000020E61000000100000005000000865968E7343D57403C84F1D3B8294C40865968E7343D574015C440D7BE2C4C40F3FFAA234740574015C440D7BE2C4C40F3FFAA23474057403C84F1D3B8294C40865968E7343D57403C84F1D3B8294C40
73041	59784	91.676686000000004	91.694301999999993	53.696283999999999	53.692284999999998	Калинина	0103000020E610000001000000050000004FEACBD24EEB564074417DCB9CD84A404FEACBD24EEB5640315D88D51FD94A4008E3A7716FEC5640315D88D51FD94A4008E3A7716FEC564074417DCB9CD84A404FEACBD24EEB564074417DCB9CD84A40
72469	59602	91.673946000000001	91.726623000000004	53.715775000000001	53.695675999999999	Ленина	0103000020E61000000100000005000000485167EE21EB5640594E42E90BD94A40485167EE21EB5640AF25E4839EDB4A405F61C1FD80EE5640AF25E4839EDB4A405F61C1FD80EE5640594E42E90BD94A40485167EE21EB5640594E42E90BD94A40
28254	24564	92.282859999999999	92.350960999999998	56.231938	56.200158000000002	Советская 	0103000020E610000001000000050000002E56D4601A125740320400C79E194C402E56D4601A1257408E59F624B01D4C40F94A2025761657408E59F624B01D4C40F94A202576165740320400C79E194C402E56D4601A125740320400C79E194C40
28631	24564	92.282859999999999	92.350960999999998	56.231938	56.200158000000002	Лесная	0103000020E610000001000000050000002E56D4601A125740320400C79E194C402E56D4601A1257408E59F624B01D4C40F94A2025761657408E59F624B01D4C40F94A202576165740320400C79E194C402E56D4601A125740320400C79E194C40
27891	45449	90.620168000000007	90.640047999999993	56.246440999999997	56.231383000000001	Октябрьская	0103000020E61000000100000005000000A6811FD5B0A75640D9EC48F59D1D4C40A6811FD5B0A756405FB2F1608B1F4C40B1F7E28BF6A856405FB2F1608B1F4C40B1F7E28BF6A85640D9EC48F59D1D4C40A6811FD5B0A75640D9EC48F59D1D4C40
27738	45449	90.620168000000007	90.640047999999993	56.246440999999997	56.231383000000001	 Лесная	0103000020E61000000100000005000000A6811FD5B0A75640D9EC48F59D1D4C40A6811FD5B0A756405FB2F1608B1F4C40B1F7E28BF6A856405FB2F1608B1F4C40B1F7E28BF6A85640D9EC48F59D1D4C40A6811FD5B0A75640D9EC48F59D1D4C40
72988	18240	92.543929000000006	92.588071999999997	55.961843000000002	55.959097	Набережная	0103000020E61000000100000005000000259694BBCF2257408A58C4B0C3FA4B40259694BBCF2257407A71E2AB1DFB4B405FECBDF8A22557407A71E2AB1DFB4B405FECBDF8A22557408A58C4B0C3FA4B40259694BBCF2257408A58C4B0C3FA4B40
71611	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	площадь Металлургов	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72615	51757	90.528036999999998	90.529482999999999	56.251727000000002	56.240388000000003	Шахтерская	0103000020E61000000100000005000000FD84B35BCBA15640E92CB308C51E4C40FD84B35BCBA156409642209738204C406E32AA0CE3A156409642209738204C406E32AA0CE3A15640E92CB308C51E4C40FD84B35BCBA15640E92CB308C51E4C40
71685	51757	92.726736000000002	92.727023000000003	56.047801	56.045780000000001	Хантайская	0103000020E61000000100000005000000DB34B6D7822E5740CB67791EDC054C40DB34B6D7822E5740A9DBD9571E064C40261C7A8B872E5740A9DBD9571E064C40261C7A8B872E5740CB67791EDC054C40DB34B6D7822E5740CB67791EDC054C40
71670	51757	91.668457000000004	91.675976000000006	53.725211000000002	53.722116	Талнахская	0103000020E610000001000000050000001172DEFFC7EA56408CF50D4C6EDC4A401172DEFFC7EA564088D9CBB6D3DC4A406138D73043EB564088D9CBB6D3DC4A406138D73043EB56408CF50D4C6EDC4A401172DEFFC7EA56408CF50D4C6EDC4A40
71697	51757	93.144927999999993	93.150857000000002	55.946955000000003	55.946184000000002	Строителей	0103000020E610000001000000050000009411178046495740CEFFAB8E1CF94B40941117804649574050E449D235F94B40DA571EA4A749574050E449D235F94B40DA571EA4A7495740CEFFAB8E1CF94B409411178046495740CEFFAB8E1CF94B40
71671	51757	93.152608999999998	93.162678999999997	55.973934	55.946955000000003	Советская	0103000020E61000000100000005000000D1048A58C449574050E449D235F94B40D1048A58C4495740323B8BDEA9FC4B40BE2F2E55694A5740323B8BDEA9FC4B40BE2F2E55694A574050E449D235F94B40D1048A58C449574050E449D235F94B40
28048	51757	92.316276999999999	92.473060000000004	53.077247	53.062551999999997	Рудная	0103000020E6100000010000000500000087DEE2E13D145740522635B401884A4087DEE2E13D145740685BCD3AE3894A40EE42739D461E5740685BCD3AE3894A40EE42739D461E5740522635B401884A4087DEE2E13D145740522635B401884A40
56766	51757	91.690430000000006	91.729344999999995	53.719521	53.700287000000003	Пушкина	0103000020E61000000100000005000000598B4F0130EC564030682101A3D94A40598B4F0130EC564082E49D4319DC4A4012A0A696ADEE564082E49D4319DC4A4012A0A696ADEE564030682101A3D94A40598B4F0130EC564030682101A3D94A40
72554	51757	92.524722999999994	92.538404	58.196072999999998	58.177778000000004	Победы	0103000020E61000000100000005000000601DC70F9521574062F9F36DC1164D40601DC70F95215740765089EB18194D4047020D3675225740765089EB18194D4047020D367522574062F9F36DC1164D40601DC70F9521574062F9F36DC1164D40
27932	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Площадь Металлургов	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
71701	51757	92.565847000000005	92.572575999999998	56.083987999999998	56.083374999999997	Первомайская	0103000020E610000001000000050000008BE255D636245740E9263108AC0A4C408BE255D636245740D3A0681EC00A4C405E9ECE15A5245740D3A0681EC00A4C405E9ECE15A5245740E9263108AC0A4C408BE255D636245740E9263108AC0A4C40
72460	51757	92.928336000000002	92.968338000000003	55.999389999999998	55.989260000000002	Павлова	0103000020E61000000100000005000000C4EC65DB693B5740D89E5912A0FE4B40C4EC65DB693B574087F9F202ECFF4B40575EF23FF93D574087F9F202ECFF4B40575EF23FF93D5740D89E5912A0FE4B40C4EC65DB693B5740D89E5912A0FE4B40
71696	51757	95.771350999999996	95.773021999999997	56.191457999999997	56.188743000000002	Озерная	0103000020E6100000010000000500000029AF95D05DF15740AA2C0ABB28184C4029AF95D05DF157405E471CB281184C40AA45443179F157405E471CB281184C40AA45443179F15740AA2C0ABB28184C4029AF95D05DF15740AA2C0ABB28184C40
72471	51757	90.523320999999996	90.524191999999999	56.254427	56.240403000000001	Норильская	0103000020E61000000100000005000000D7135D177EA156401E6E8786C51E4C40D7135D177EA15640151C5E1091204C40CA349A5C8CA15640151C5E1091204C40CA349A5C8CA156401E6E8786C51E4C40D7135D177EA156401E6E8786C51E4C40
28122	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Надеждинская	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
28212	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Молодежный проезд	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72462	51757	92.835341999999997	92.892743999999993	56.013195000000003	56.010201000000002	Мира	0103000020E610000001000000050000006ABE4A3E7635574079B130444E014C406ABE4A3E7635574041BCAE5FB0014C40D0ECBAB72239574041BCAE5FB0014C40D0ECBAB72239574079B130444E014C406ABE4A3E7635574079B130444E014C40
28411	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Маслова	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
27872	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Ленинский проспект	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
28217	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Кравца	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72451	51757	91.683674999999994	91.70881	53.719653999999998	53.707861000000001	Комсомольская	0103000020E61000000100000005000000F085C954C1EB5640938E72309BDA4A40F085C954C1EB5640C1374D9F1DDC4A40FA449E245DED5640C1374D9F1DDC4A40FA449E245DED5640938E72309BDA4A40F085C954C1EB5640938E72309BDA4A40
72516	51757	93.124230999999995	93.128147999999996	56.046166999999997	56.022644999999997	Кирова	0103000020E610000001000000050000008F899466F34757407E350708E6024C408F899466F3475740C493DDCCE8054C400F43AB9333485740C493DDCCE8054C400F43AB93334857407E350708E6024C408F899466F34757407E350708E6024C40
71707	51757	92.875748000000002	92.888171999999997	56.023842000000002	56.018523999999999	Игарская	0103000020E6100000010000000500000065E256410C385740761893FE5E024C4065E256410C385740B82231410D034C40444E5FCFD7385740B82231410D034C40444E5FCFD7385740761893FE5E024C4065E256410C385740761893FE5E024C40
72548	51757	92.875748000000002	92.888171999999997	56.023842000000002	56.018523999999999	Игарская	0103000020E6100000010000000500000065E256410C385740761893FE5E024C4065E256410C385740B82231410D034C40444E5FCFD7385740B82231410D034C40444E5FCFD7385740761893FE5E024C4065E256410C385740761893FE5E024C40
72532	51757	92.883769999999998	92.884317999999993	56.030712999999999	56.023842000000002	Енисейская	0103000020E61000000100000005000000E6CB0BB08F385740B82231410D034C40E6CB0BB08F385740F1475167EE034C40E75086AA98385740F1475167EE034C40E75086AA98385740B82231410D034C40E6CB0BB08F385740B82231410D034C40
28178	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Ветеранов	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
71563	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Вальковская	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72468	51757	93.008555000000001	93.019262999999995	56.010423000000003	56.000380999999997	Богдана Хмельницкого	0103000020E61000000100000005000000E84D452A8C40574017450F7C0C004C40E84D452A8C4057402810768A55014C4076C1E09A3B4157402810768A55014C4076C1E09A3B41574017450F7C0C004C40E84D452A8C40574017450F7C0C004C40
72463	51757	92.944783999999999	92.944918999999999	56.070349	56.069535000000002	Бегичева	0103000020E610000001000000050000002E724F57773C5740B476DB85E6084C402E724F57773C574035272F3201094C409E978A8D793C574035272F3201094C409E978A8D793C5740B476DB85E6084C402E724F57773C5740B476DB85E6084C40
28274	51757	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Бауманская	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72611	59609	90.525773000000001	90.529510000000002	56.284213999999999	56.277797999999997	Школьная	0103000020E61000000100000005000000AB07CC43A6A15640757286E28E234C40AB07CC43A6A156405D88D51F61244C40EB39E97DE3A156405D88D51F61244C40EB39E97DE3A15640757286E28E234C40AB07CC43A6A15640757286E28E234C40
72521	59609	95.752764999999997	95.764560000000003	56.228966	56.224052	Севастопольская	0103000020E61000000100000005000000B324404D2DF057403C4D66BCAD1C4C40B324404D2DF05740AEF204C24E1D4C401BF5108DEEF05740AEF204C24E1D4C401BF5108DEEF057403C4D66BCAD1C4C40B324404D2DF057403C4D66BCAD1C4C40
75621	59609	92.565847000000005	92.572575999999998	56.083987999999998	56.083374999999997	Первомайская	0103000020E610000001000000050000008BE255D636245740E9263108AC0A4C408BE255D636245740D3A0681EC00A4C405E9ECE15A5245740D3A0681EC00A4C405E9ECE15A5245740E9263108AC0A4C408BE255D636245740E9263108AC0A4C40
72696	6422	93.460892999999999	93.461539999999999	56.170721	56.166204999999998	Юрия Гагарина	0103000020E61000000100000005000000247D5A457F5D574041B7973446154C40247D5A457F5D5740C6DE8B2FDA154C40EF7211DF895D5740C6DE8B2FDA154C40EF7211DF895D574041B7973446154C40247D5A457F5D574041B7973446154C40
27917	6422	93.434599000000006	93.485336000000004	56.175967999999997	56.157738999999999	Зеленая	0103000020E61000000100000005000000F5F75278D05B5740E126A3CA30144C40F5F75278D05B57403E92921E86164C4093E4B9BE0F5F57403E92921E86164C4093E4B9BE0F5F5740E126A3CA30144C40F5F75278D05B5740E126A3CA30144C40
28219	7257	89.307811000000001	89.342746000000005	55.762535	55.754578000000002	Центральная	0103000020E610000001000000050000005796E82CB3535640FB230C0396E04B405796E82CB3535640168733BF9AE14B406E35EB8CEF555640168733BF9AE14B406E35EB8CEF555640FB230C0396E04B405796E82CB3535640FB230C0396E04B40
71500	51788	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Кузнечная	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
28140	51788	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Борисенко	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
27996	51788	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Арбузова	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
72510	745	91.694095000000004	91.715457000000001	53.719852000000003	53.705888999999999	Штабная	0103000020E610000001000000050000004C546F0D6CEC564096CD1C925ADA4A404C546F0D6CEC5640E8FA3E1C24DC4A406F2C280CCAED5640E8FA3E1C24DC4A406F2C280CCAED564096CD1C925ADA4A404C546F0D6CEC564096CD1C925ADA4A40
71722	745	91.662726000000006	91.690565000000007	53.721955999999999	53.718626	Хвастанцева	0103000020E610000001000000050000005F0D501A6AEA56401407D0EFFBDB4A405F0D501A6AEA56405393E00D69DC4A40C9B08A3732EC56405393E00D69DC4A40C9B08A3732EC56401407D0EFFBDB4A405F0D501A6AEA56401407D0EFFBDB4A40
72216	745	91.684635999999998	91.691894000000005	53.704594	53.693601999999998	Февральская	0103000020E61000000100000005000000836A8313D1EB5640583849F3C7D84A40836A8313D1EB56409A7ADD2230DA4A401D93C5FD47EC56409A7ADD2230DA4A401D93C5FD47EC5640583849F3C7D84A40836A8313D1EB5640583849F3C7D84A40
72177	745	91.661683999999994	91.677243000000004	53.695734999999999	53.686574999999998	Тимирязева	0103000020E610000001000000050000005512D90759EA564027A089B0E1D74A405512D90759EA56405ED72FD80DD94A407A1C06F357EB56405ED72FD80DD94A407A1C06F357EB564027A089B0E1D74A405512D90759EA564027A089B0E1D74A40
71644	745	91.668457000000004	91.675976000000006	53.725211000000002	53.722116	Талнахская	0103000020E610000001000000050000001172DEFFC7EA56408CF50D4C6EDC4A401172DEFFC7EA564088D9CBB6D3DC4A406138D73043EB564088D9CBB6D3DC4A406138D73043EB56408CF50D4C6EDC4A401172DEFFC7EA56408CF50D4C6EDC4A40
7945	745	91.656204000000002	91.664118999999999	53.693570000000001	53.689427000000002	Сургуладзе проезд	0103000020E6100000010000000500000048E00F3FFFE956405DFDD8243FD84A4048E00F3FFFE956404DBED9E6C6D84A40BE69FAEC80EA56404DBED9E6C6D84A40BE69FAEC80EA56405DFDD8243FD84A4048E00F3FFFE956405DFDD8243FD84A40
72701	745	91.662177999999997	91.697203000000002	53.704658000000002	53.697690999999999	Советская	0103000020E610000001000000050000005D88D51F61EA564055DB4DF04DD94A405D88D51F61EA5640B16EBC3B32DA4A4014EB54F99EEC5640B16EBC3B32DA4A4014EB54F99EEC564055DB4DF04DD94A405D88D51F61EA564055DB4DF04DD94A40
72287	745	91.664845999999997	91.694085999999999	53.708123000000001	53.701566999999997	Свердлова	0103000020E6100000010000000500000017B83CD68CEA5640F6798CF2CCD94A4017B83CD68CEA5640D04543C6A3DA4A4022A7AFE76BEC5640D04543C6A3DA4A4022A7AFE76BEC5640F6798CF2CCD94A4017B83CD68CEA5640F6798CF2CCD94A40
8018	745	91.661522000000005	91.669796000000005	53.689506999999999	53.685572000000001	Сафьяновых проезд	0103000020E6100000010000000500000069E55E6056EA5640D386C3D2C0D74A4069E55E6056EA564079AEEFC341D84A4077BF0AF0DDEA564079AEEFC341D84A4077BF0AF0DDEA5640D386C3D2C0D74A4069E55E6056EA5640D386C3D2C0D74A40
72019	745	91.668574000000007	91.684940999999995	53.711559999999999	53.70937	Подсинская	0103000020E610000001000000050000002E3D9AEAC9EA5640BB61DBA2CCDA4A402E3D9AEAC9EA56402592E86514DB4A4021ACC612D6EB56402592E86514DB4A4021ACC612D6EB5640BB61DBA2CCDA4A402E3D9AEAC9EA5640BB61DBA2CCDA4A40
72078	745	91.684410999999997	91.728088	53.716500000000003	53.696874999999999	Октябрьская	0103000020E610000001000000050000007381CB63CDEB56403333333333D94A407381CB63CDEB5640C1CAA145B6DB4A400B2769FE98EE5640C1CAA145B6DB4A400B2769FE98EE56403333333333D94A407381CB63CDEB56403333333333D94A40
72058	745	91.655674000000005	91.702781999999999	53.712567	53.691251000000001	Набережная	0103000020E610000001000000050000009AB51490F6E95640E529ABE97AD84A409AB51490F6E95640BB9A3C6535DB4A40EB8D5A61FAEC5640BB9A3C6535DB4A40EB8D5A61FAEC5640E529ABE97AD84A409AB51490F6E95640E529ABE97AD84A40
71690	745	91.687358000000003	91.727790999999996	53.718300999999997	53.697473000000002	Мира	0103000020E6100000010000000500000037A968ACFDEB5640E86B96CB46D94A4037A968ACFDEB564090D78349F1DB4A40AED4B32094EE564090D78349F1DB4A40AED4B32094EE5640E86B96CB46D94A4037A968ACFDEB5640E86B96CB46D94A40
72513	745	91.695048	91.698263999999995	53.721891999999997	53.719047000000003	Литейная	0103000020E610000001000000050000009D499BAA7BEC5640BAA46ABB09DC4A409D499BAA7BEC56403C9F01F566DC4A4058FE7C5BB0EC56403C9F01F566DC4A4058FE7C5BB0EC5640BAA46ABB09DC4A409D499BAA7BEC5640BAA46ABB09DC4A40
72173	745	91.673946000000001	91.726623000000004	53.715775000000001	53.695675999999999	Ленина	0103000020E61000000100000005000000485167EE21EB5640594E42E90BD94A40485167EE21EB5640AF25E4839EDB4A405F61C1FD80EE5640AF25E4839EDB4A405F61C1FD80EE5640594E42E90BD94A40485167EE21EB5640594E42E90BD94A40
28162	745	91.710920999999999	91.740528999999995	53.680095000000001	53.675091999999999	Кызыльская	0103000020E610000001000000050000008942CBBA7FED564047E5266A69D64A408942CBBA7FED564029965B5A0DD74A40552FBFD364EF564029965B5A0DD74A40552FBFD364EF564047E5266A69D64A408942CBBA7FED564047E5266A69D64A40
72175	745	91.665779999999998	91.695389000000006	53.700474	53.693517	Крупской	0103000020E610000001000000050000002D95B7239CEA56402A1C412AC5D84A402D95B7239CEA564062D9CC21A9D94A40E23FDD4081EC564062D9CC21A9D94A40E23FDD4081EC56402A1C412AC5D84A402D95B7239CEA56402A1C412AC5D84A40
72580	745	91.674485000000004	91.690870000000004	53.694727	53.688915000000001	Кретова	0103000020E61000000100000005000000202922C32AEB5640A75CE15D2ED84A40202922C32AEB5640F85278D0ECD84A4067F2CD3637EC5640F85278D0ECD84A4067F2CD3637EC5640A75CE15D2ED84A40202922C32AEB5640A75CE15D2ED84A40
28229	745	91.621071000000001	91.629749000000004	53.621943999999999	53.619929999999997	Журавлева	0103000020E610000001000000050000009E5F94A0BFE7564096E7C1DD59CF4A409E5F94A0BFE75640C2F869DC9BCF4A4014ECBFCE4DE85640C2F869DC9BCF4A4014ECBFCE4DE8564096E7C1DD59CF4A409E5F94A0BFE7564096E7C1DD59CF4A40
72069	745	91.702530999999993	91.722311000000005	53.694102999999998	53.686419999999998	Вокзальная	0103000020E61000000100000005000000465B9544F6EC564000A94D9CDCD74A40465B9544F6EC56401A87FA5DD8D84A40A1A2EA573AEE56401A87FA5DD8D84A40A1A2EA573AEE564000A94D9CDCD74A40465B9544F6EC564000A94D9CDCD74A40
72577	745	91.671143000000001	91.681725999999998	53.694262999999999	53.688594999999999	Ванеева	0103000020E610000001000000050000001EFCC401F4EA5640359886E123D84A401EFCC401F4EA564053E9279CDDD84A404EB51666A1EB564053E9279CDDD84A404EB51666A1EB5640359886E123D84A401EFCC401F4EA5640359886E123D84A40
72089	745	91.710391000000001	91.731609000000006	53.712082000000002	53.702969000000003	Автомобильная	0103000020E61000000100000005000000DB17D00B77ED5640098D60E3FAD94A40DB17D00B77ED5640FF08C38025DB4A40651D8EAED2EE5640FF08C38025DB4A40651D8EAED2EE5640098D60E3FAD94A40DB17D00B77ED5640098D60E3FAD94A40
71510	24861	92.499390000000005	92.567132000000001	56.067314000000003	56.037775000000003	Вокзальная	0103000020E61000000100000005000000C47C7901F61F57409FCDAACFD5044C40C47C7901F61F57400F48C2BE9D084C40F72004E44B2457400F48C2BE9D084C40F72004E44B2457409FCDAACFD5044C40C47C7901F61F57409FCDAACFD5044C40
28005	51791	93.126423000000003	93.148512999999994	56.284658999999998	56.263531999999998	Лесная	0103000020E61000000100000005000000959D7E501748574088B9A46ABB214C40959D7E50174857408BC1C3B46F244C40F981AB3C814957408BC1C3B46F244C40F981AB3C8149574088B9A46ABB214C40959D7E501748574088B9A46ABB214C40
72518	59614	91.673946000000001	91.726623000000004	53.715775000000001	53.695675999999999	Ленина	0103000020E61000000100000005000000485167EE21EB5640594E42E90BD94A40485167EE21EB5640AF25E4839EDB4A405F61C1FD80EE5640AF25E4839EDB4A405F61C1FD80EE5640594E42E90BD94A40485167EE21EB5640594E42E90BD94A40
73005	59756	89.326361000000006	89.346896000000001	55.135154999999997	55.121659000000001	Центральная	0103000020E61000000100000005000000276C3F19E3545640CD21A985928F4B40276C3F19E3545640087250C24C914B403FC7478B33565640087250C24C914B403FC7478B33565640CD21A985928F4B40276C3F19E3545640CD21A985928F4B40
7536	3405	92.381459000000007	92.392769000000001	58.292085	58.289738999999997	улица Комсомольская	0103000020E61000000100000005000000F47002D36918574018B0E42A16254D40F47002D3691857407A53910A63254D407D789620231957407A53910A63254D407D7896202319574018B0E42A16254D40F47002D36918574018B0E42A16254D40
7674	3405	92.472898999999998	92.520581000000007	58.246484000000002	58.196305000000002	улица Горького	0103000020E61000000100000005000000E9D32AFA431E57404985B18520194D40E9D32AFA431E57405F7EA7C98C1F4D40D17AF832512157405F7EA7C98C1F4D40D17AF832512157404985B18520194D40E9D32AFA431E57404985B18520194D40
72165	3405	92.524507	92.531101000000007	58.174708000000003	58.170512000000002	микрорайон Строитель	0103000020E610000001000000050000007AE1CE8591215740ACC95356D3154D407AE1CE8591215740BF2CEDD45C164D40DE770C8FFD215740BF2CEDD45C164D40DE770C8FFD215740ACC95356D3154D407AE1CE8591215740ACC95356D3154D40
72714	3405	92.412657999999993	92.421290999999997	58.323314000000003	58.316253000000003	Рябиновая	0103000020E61000000100000005000000B29B19FD681A5740862172FA7A284D40B29B19FD681A5740632B685A62294D4058C6866EF61A5740632B685A62294D4058C6866EF61A5740862172FA7A284D40B29B19FD681A5740862172FA7A284D40
72370	3405	92.386454000000001	92.387155000000007	58.301270000000002	58.284961000000003	Просвещения	0103000020E6100000010000000500000023DA8EA9BB18574057D11F9A79244D4023DA8EA9BB1857400AA2EE0390264D40E8DEC325C71857400AA2EE0390264D40E8DEC325C718574057D11F9A79244D4023DA8EA9BB18574057D11F9A79244D40
72285	3405	92.391430999999997	92.392319999999998	58.307932000000001	58.285760000000003	Промышленная	0103000020E61000000100000005000000FFE89B340D195740A3409FC893244D40FFE89B340D19574029B2D6506A274D40456458C51B19574029B2D6506A274D40456458C51B195740A3409FC893244D40FFE89B340D195740A3409FC893244D40
73015	3405	92.331233999999995	92.349029999999999	58.252929999999999	58.242927000000002	Подгорная	0103000020E61000000100000005000000B05417F0321557405F28603B181F4D40B05417F032155740B1169F0260204D40AAD4EC8156165740B1169F0260204D40AAD4EC81561657405F28603B181F4D40B05417F0321557405F28603B181F4D40
72280	3405	92.524722999999994	92.538404	58.196072999999998	58.177778000000004	Победы	0103000020E61000000100000005000000601DC70F9521574062F9F36DC1164D40601DC70F95215740765089EB18194D4047020D3675225740765089EB18194D4047020D367522574062F9F36DC1164D40601DC70F9521574062F9F36DC1164D40
72213	3405	92.462029000000001	92.471344999999999	58.241767000000003	58.230443000000001	Пионерская	0103000020E610000001000000050000006E3315E2911D5740CB4BFE277F1D4D406E3315E2911D574043209738F21E4D40850838842A1E574043209738F21E4D40850838842A1E5740CB4BFE277F1D4D406E3315E2911D5740CB4BFE277F1D4D40
72087	3405	92.479286000000002	92.489832000000007	58.237744999999997	58.235073	Первомайская	0103000020E6100000010000000500000090DB2F9FAC1E574018963FDF161E4D4090DB2F9FAC1E5740CDE49B6D6E1E4D4032225168591F5740CDE49B6D6E1E4D4032225168591F574018963FDF161E4D4090DB2F9FAC1E574018963FDF161E4D40
71688	3405	92.449138000000005	92.456406000000001	58.251489999999997	58.248629999999999	Октябрьская	0103000020E6100000010000000500000004594FADBE1C5740F9669B1BD31F4D4004594FADBE1C5740B1A206D330204D40AFEC82C1351D5740B1A206D330204D40AFEC82C1351D5740F9669B1BD31F4D4004594FADBE1C5740F9669B1BD31F4D40
72693	3405	92.451734000000002	92.463188000000002	58.253351000000002	58.251438	Мичурина	0103000020E61000000100000005000000711FB935E91C57405F7CD11E2F204D40711FB935E91C574057B439CE6D204D4094F947DFA41D574057B439CE6D204D4094F947DFA41D57405F7CD11E2F204D40711FB935E91C57405F7CD11E2F204D40
72172	3405	92.369699999999995	92.392401000000007	58.292141999999998	58.291938000000002	Ленинградская	0103000020E610000001000000050000003255302AA9175740D63A71395E254D403255302AA9175740DEE4B7E864254D40BC7A15191D195740DEE4B7E864254D40BC7A15191D195740D63A71395E254D403255302AA9175740D63A71395E254D40
7101	3405	92.497495000000001	92.499003999999999	58.230221	58.229543	Клубный переулок	0103000020E610000001000000050000001BBB44F5D61F57404B033FAA611D4D401BBB44F5D61F57401CEDB8E1771D4D40AF2479AEEF1F57401CEDB8E1771D4D40AF2479AEEF1F57404B033FAA611D4D401BBB44F5D61F57404B033FAA611D4D40
73032	3405	92.478926000000001	92.481532000000001	58.196480999999999	58.191637999999998	Клубная	0103000020E6100000010000000500000010CD3CB9A61E5740DE550F9887184D4010CD3CB9A61E574087A4164A26194D408FFE976BD11E574087A4164A26194D408FFE976BD11E5740DE550F9887184D4010CD3CB9A61E5740DE550F9887184D40
72283	3405	92.472898999999998	92.520581000000007	58.246484000000002	58.196305000000002	Горького	0103000020E61000000100000005000000E9D32AFA431E57404985B18520194D40E9D32AFA431E57405F7EA7C98C1F4D40D17AF832512157405F7EA7C98C1F4D40D17AF832512157404985B18520194D40E9D32AFA431E57404985B18520194D40
72170	3405	92.522064	92.532780000000002	58.193297999999999	58.191737000000003	Белинского	0103000020E61000000100000005000000D09A1F7F69215740723788D68A184D40D09A1F7F69215740EC3026FDBD184D40A0FD481119225740EC3026FDBD184D40A0FD481119225740723788D68A184D40D09A1F7F69215740723788D68A184D40
72719	3405	92.595815000000002	92.602508	58.150129999999997	58.145902	Абалаковская	0103000020E61000000100000005000000D7DD3CD521265740E335AFEAAC124D40D7DD3CD5212657400113B87537134D4004E5B67D8F2657400113B87537134D4004E5B67D8F265740E335AFEAAC124D40D7DD3CD521265740E335AFEAAC124D40
72282	3405	92.504636000000005	92.516135000000006	58.210124	58.2057	7 микрорайон	0103000020E610000001000000050000009818CBF44B205740C364AA60541A4D409818CBF44B205740670DDE57E51A4D408B54185B08215740670DDE57E51A4D408B54185B08215740C364AA60541A4D409818CBF44B205740C364AA60541A4D40
72286	3405	92.383319	92.390765999999999	58.305118999999998	58.302008000000001	6 квартал	0103000020E61000000100000005000000DE3B6A4C88185740B090B932A8264D40DE3B6A4C88185740B131AF230E274D40E198654F02195740B131AF230E274D40E198654F02195740B090B932A8264D40DE3B6A4C88185740B090B932A8264D40
72171	3405	92.496758	92.507510999999994	58.220784999999999	58.214996999999997	5 микрорайон	0103000020E61000000100000005000000B00111E2CA1F57407ADE8D05851B4D40B00111E2CA1F57404339D1AE421C4D400ED76A0F7B2057404339D1AE421C4D400ED76A0F7B2057407ADE8D05851B4D40B00111E2CA1F57407ADE8D05851B4D40
73057	3405	92.496758	92.507510999999994	58.220784999999999	58.214996999999997	5 микрорайон	0103000020E61000000100000005000000B00111E2CA1F57407ADE8D05851B4D40B00111E2CA1F57404339D1AE421C4D400ED76A0F7B2057404339D1AE421C4D400ED76A0F7B2057407ADE8D05851B4D40B00111E2CA1F57407ADE8D05851B4D40
72578	3405	92.524722999999994	92.538404	58.196072999999998	58.177778000000004	 Победы	0103000020E61000000100000005000000601DC70F9521574062F9F36DC1164D40601DC70F95215740765089EB18194D4047020D3675225740765089EB18194D4047020D367522574062F9F36DC1164D40601DC70F9521574062F9F36DC1164D40
72987	59743	95.569525999999996	95.611091000000002	56.240367999999997	56.230072	Береговая	0103000020E61000000100000005000000300E2E1D73E45740D7DCD1FF721D4C40300E2E1D73E45740A180ED60C41E4C4051F86C1D1CE75740A180ED60C41E4C4051F86C1D1CE75740D7DCD1FF721D4C40300E2E1D73E45740D7DCD1FF721D4C40
72640	59647	92.998512000000005	93.019569000000004	56.803238	56.792597000000001	Мира	0103000020E61000000100000005000000782AE09EE73F574030F488D173654C40782AE09EE73F5740C573B680D0664C40FDC0559E40415740C573B680D0664C40FDC0559E4041574030F488D173654C40782AE09EE73F574030F488D173654C40
28571	46862	90.424964000000003	90.455911	56.361693000000002	56.347873	Центральная	0103000020E610000001000000050000008D7E349C329B5640A9143B1A872C4C408D7E349C329B56409818CBF44B2E4C40BFB854A52D9D56409818CBF44B2E4C40BFB854A52D9D5640A9143B1A872C4C408D7E349C329B5640A9143B1A872C4C40
72697	59669	95.700751999999994	95.715511000000006	56.238737	56.226204000000003	Ангарская	0103000020E61000000100000005000000D2A6EA1ED9EC5740B91CAF40F41C4C40D2A6EA1ED9EC57402EAC1BEF8E1E4C40693BA6EECAED57402EAC1BEF8E1E4C40693BA6EECAED5740B91CAF40F41C4C40D2A6EA1ED9EC5740B91CAF40F41C4C40
27895	13985	93.029567	93.081030999999996	55.960115000000002	55.928542	 Кооперативная	0103000020E610000001000000050000009D82FC6CE4415740317BD976DAF64B409D82FC6CE441574014B35E0CE5FA4B4094BDA59C2F45574014B35E0CE5FA4B4094BDA59C2F455740317BD976DAF64B409D82FC6CE4415740317BD976DAF64B40
72853	26135	93.363901999999996	93.394175000000004	56.255491999999997	56.228164999999997	Еланская	0103000020E61000000100000005000000BC3C9D2B4A575740C18BBE82341D4C40BC3C9D2B4A575740DF313CF6B3204C40A779C7293A595740DF313CF6B3204C40A779C7293A595740C18BBE82341D4C40BC3C9D2B4A575740C18BBE82341D4C40
72846	25689	93.053416999999996	93.078202000000005	56.291314	56.276922999999996	Центральная	0103000020E610000001000000050000003A03232F6B4357404E417E3672234C403A03232F6B435740F86EF3C649254C40D61EF64201455740F86EF3C649254C40D61EF642014557404E417E3672234C403A03232F6B4357404E417E3672234C40
5886	1225	92.832683000000003	92.835773000000003	56.028751999999997	56.025275999999998	улица Северо-Енисейская	0103000020E61000000100000005000000DA3BA3AD4A355740D5AF743E3C034C40DA3BA3AD4A355740E8D84125AE034C404F78094E7D355740E8D84125AE034C404F78094E7D355740D5AF743E3C034C40DA3BA3AD4A355740D5AF743E3C034C40
5938	1225	92.950757999999993	92.974885999999998	55.990479000000001	55.984878999999999	улица Новая	0103000020E61000000100000005000000431A1538D93C574033C2DB8310FE4B40431A1538D93C5740F92F1004C8FE4B4002D53F88643E5740F92F1004C8FE4B4002D53F88643E574033C2DB8310FE4B40431A1538D93C574033C2DB8310FE4B40
4740	1225	92.798941999999997	92.890542999999994	56.014685	56.010230999999997	улица Ленина	0103000020E61000000100000005000000A759A0DD21335740E333D93F4F014C40A759A0DD21335740F25EB532E1014C40A12B11A8FE385740F25EB532E1014C40A12B11A8FE385740E333D93F4F014C40A759A0DD21335740E333D93F4F014C40
3230	1225	92.935585000000003	92.975282000000007	55.993428999999999	55.983449	улица Кутузова	0103000020E610000001000000050000003468E89FE03B5740572426A8E1FD4B403468E89FE03B5740F1F274AE28FF4B40299831056B3E5740F1F274AE28FF4B40299831056B3E5740572426A8E1FD4B403468E89FE03B5740572426A8E1FD4B40
6481	1225	92.808509000000001	92.809496999999993	56.012335	56.002329000000003	улица Корнеева	0103000020E610000001000000050000006361889CBE3357408C6A11514C004C406361889CBE3357404FCC7A3194014C40724D81CCCE3357404FCC7A3194014C40724D81CCCE3357408C6A11514C004C406361889CBE3357408C6A11514C004C40
5996	1225	92.932180000000002	92.950514999999996	56.008873000000001	56.004665000000003	улица Коммунальная	0103000020E610000001000000050000000F7F4DD6A83B5740CA37DBDC98004C400F7F4DD6A83B5740A1681EC022014C40E0D6DD3CD53C5740A1681EC022014C40E0D6DD3CD53C5740CA37DBDC98004C400F7F4DD6A83B5740CA37DBDC98004C40
7420	1225	92.862830000000002	92.864419999999996	56.016607	56.006920000000001	улица Кирова	0103000020E610000001000000050000007E00529B383757401BD82AC1E2004C407E00529B383757403DF19C2D20024C40888043A8523757403DF19C2D20024C40888043A8523757401BD82AC1E2004C407E00529B383757401BD82AC1E2004C40
4565	1225	92.763413999999997	92.768039999999999	56.025441999999998	56.019435000000001	улица Вильского	0103000020E61000000100000005000000BFD364C6DB305740EAB298D87C024C40BFD364C6DB305740F0F8F6AE41034C4045813E9127315740F0F8F6AE41034C4045813E9127315740EAB298D87C024C40BFD364C6DB305740EAB298D87C024C40
73334	1225	92.835341999999997	92.892743999999993	56.013195000000003	56.010201000000002	проспект Мира	0103000020E610000001000000050000006ABE4A3E7635574079B130444E014C406ABE4A3E7635574041BCAE5FB0014C40D0ECBAB72239574041BCAE5FB0014C40D0ECBAB72239574079B130444E014C406ABE4A3E7635574079B130444E014C40
72523	1225	92.744208	92.774750999999995	55.993428999999999	55.983277999999999	микрорайон Академгородок 	0103000020E61000000100000005000000FB5A971AA12F57402A70B20DDCFD4B40FB5A971AA12F5740F1F274AE28FF4B40C5E2378595315740F1F274AE28FF4B40C5E23785953157402A70B20DDCFD4B40FB5A971AA12F57402A70B20DDCFD4B40
73332	1225	92.939087999999998	92.943948000000006	55.992362	55.985588999999997	имени Газеты Пионерская Правда	0103000020E610000001000000050000003A048E041A3C57400F26C5C727FE4B403A048E041A3C574086E5CFB705FF4B40FA47DFA4693C574086E5CFB705FF4B40FA47DFA4693C57400F26C5C727FE4B403A048E041A3C57400F26C5C727FE4B40
4729	1225	92.887452999999994	93.025910999999994	56.025452000000001	55.991858000000001	имени Газеты Красноярский Рабочий проспект	0103000020E610000001000000050000002CEFAA07CC3857405323F433F5FE4B402CEFAA07CC38574014CFD90242034C40D3669C86A841574014CFD90242034C40D3669C86A84157405323F433F5FE4B402CEFAA07CC3857405323F433F5FE4B40
72086	1225	92.904081000000005	92.955940999999996	56.004282000000003	55.992075	академика Вавилова	0103000020E61000000100000005000000D7FB8D76DC395740F0164850FCFE4B40D7FB8D76DC39574012FB04508C004C40F4F928232E3D574012FB04508C004C40F4F928232E3D5740F0164850FCFE4B40D7FB8D76DC395740F0164850FCFE4B40
6038	1225	92.930186000000006	92.933796999999998	56.002425000000002	55.997396000000002	Якорный переулок	0103000020E610000001000000050000009D4CDC2A883B5740A39410ACAAFF4B409D4CDC2A883B5740AED85F764F004C4096067E54C33B5740AED85F764F004C4096067E54C33B5740A39410ACAAFF4B409D4CDC2A883B5740A39410ACAAFF4B40
72475	1225	92.824284000000006	92.824939999999998	56.028027000000002	56.020265000000002	Яковлева	0103000020E610000001000000050000006EA7AD11C13457407120240B98024C406EA7AD11C1345740D733846396034C40624A24D1CB345740D733846396034C40624A24D1CB3457407120240B98024C406EA7AD11C13457407120240B98024C40
72143	1225	92.764680999999996	92.774912	56.040184000000004	56.030568000000002	Юшкова	0103000020E61000000100000005000000D8B79388F0305740EE26F8A6E9034C40D8B79388F030574047E9D2BF24054C40CA5180289831574047E9D2BF24054C40CA51802898315740EE26F8A6E9034C40D8B79388F0305740EE26F8A6E9034C40
72253	1225	92.971006000000003	92.992447999999996	56.019717	56.014764999999997	Юности	0103000020E61000000100000005000000118E59F6243E57400E10CCD1E3014C40118E59F6243E57406E162F1686024C40C2BE9D44843F57406E162F1686024C40C2BE9D44843F57400E10CCD1E3014C40118E59F6243E57400E10CCD1E3014C40
72131	1225	92.815192999999994	93.033663000000004	56.005187999999997	55.997487	Энергетиков	0103000020E6100000010000000500000066BB421F2C345740B3976DA7ADFF4B4066BB421F2C345740732A1900AA004C407505DB8827425740732A1900AA004C407505DB8827425740B3976DA7ADFF4B4066BB421F2C345740B3976DA7ADFF4B40
73308	1225	92.930239999999998	92.971652000000006	55.995593999999997	55.988021000000003	Щорса	0103000020E61000000100000005000000965B5A0D893B57407061DD7877FE4B40965B5A0D893B5740020CCB9F6FFF4B40F4C5DE8B2F3E5740020CCB9F6FFF4B40F4C5DE8B2F3E57407061DD7877FE4B40965B5A0D893B57407061DD7877FE4B40
72483	1225	92.839186999999995	92.840282999999999	56.025582999999997	56.025205	Щетинкина	0103000020E610000001000000050000009D0E643DB53557400C59DDEA39034C409D0E643DB5355740B22AC24D46034C40A0185932C7355740B22AC24D46034C40A0185932C73557400C59DDEA39034C409D0E643DB53557400C59DDEA39034C40
72156	1225	92.934471000000002	92.943085999999994	56.068911999999997	56.063046999999997	Шумяцкого	0103000020E61000000100000005000000DE03745FCE3B5740328E91EC11084C40DE03745FCE3B5740A626C11BD2084C4030D461855B3C5740A626C11BD2084C4030D461855B3C5740328E91EC11084C40DE03745FCE3B5740328E91EC11084C40
72133	1225	93.013496000000004	93.042916000000005	56.001846	55.991419999999998	Шевченко	0103000020E610000001000000050000001EA8531EDD405740D74CBED9E6FE4B401EA8531EDD40574070D05E7D3C004C40691EC022BF42574070D05E7D3C004C40691EC022BF425740D74CBED9E6FE4B401EA8531EDD405740D74CBED9E6FE4B40
72572	1225	92.969272000000004	92.973080999999993	56.017035	56.010140999999997	Чайковского	0103000020E610000001000000050000006D3B6D8D083E5740A3ACDF4C4C014C406D3B6D8D083E574095F1EF332E024C40F9D687F5463E574095F1EF332E024C40F9D687F5463E5740A3ACDF4C4C014C406D3B6D8D083E5740A3ACDF4C4C014C40
73304	1225	92.857035999999994	92.884049000000005	56.009793999999999	56.008425000000003	Урицкого	0103000020E61000000100000005000000A8DF85ADD936574002BC051214014C40A8DF85ADD936574038D906EE40014C40F0C341429438574038D906EE40014C40F0C341429438574002BC051214014C40A8DF85ADD936574002BC051214014C40
72036	1225	92.914511000000005	92.925990999999996	56.066051999999999	56.058956000000002	Урванцева	0103000020E6100000010000000500000044352559873A574095F3C5DE8B074C4044352559873A5740EEEA556474084C40FB58C16F433B5740EEEA556474084C40FB58C16F433B574095F3C5DE8B074C4044352559873A574095F3C5DE8B074C40
72435	1225	92.914511000000005	92.925990999999996	56.066051999999999	56.058956000000002	Урванцева	0103000020E6100000010000000500000044352559873A574095F3C5DE8B074C4044352559873A5740EEEA556474084C40FB58C16F433B5740EEEA556474084C40FB58C16F433B574095F3C5DE8B074C4044352559873A574095F3C5DE8B074C40
72249	1225	92.808878000000007	92.828891999999996	56.022030999999998	56.021357000000002	Толстого	0103000020E610000001000000050000000D1D3BA8C4335740354580D3BB024C400D1D3BA8C4335740C43F6CE9D1024C40A0FA07910C355740C43F6CE9D1024C40A0FA07910C355740354580D3BB024C400D1D3BA8C4335740354580D3BB024C40
6102	1225	92.951216000000002	92.959237999999999	56.012093	56.009304999999998	Тихий переулок	0103000020E61000000100000005000000A5DB12B9E03C57403A58FFE730014C40A5DB12B9E03C574059C16F438C014C4026C5C727643D574059C16F438C014C4026C5C727643D57403A58FFE730014C40A5DB12B9E03C57403A58FFE730014C40
72080	1225	92.955303000000001	92.979567000000003	56.063071999999998	56.048479999999998	Тельмана	0103000020E6100000010000000500000053B131AF233D57404A41B79734064C4053B131AF233D57408BA548BE12084C406A4FC939B13E57408BA548BE12084C406A4FC939B13E57404A41B79734064C4053B131AF233D57404A41B79734064C40
73328	1225	92.875470000000007	92.877302	56.017919999999997	56.007353000000002	Сурикова	0103000020E6100000010000000500000044A852B30738574085436FF1F0004C4044A852B307385740DFF8DA334B024C40C9AD49B725385740DFF8DA334B024C40C9AD49B72538574085436FF1F0004C4044A852B30738574085436FF1F0004C40
72275	1225	92.821444999999997	92.870529000000005	55.989047999999997	55.979489999999998	Судостроительная	0103000020E610000001000000050000009D9D0C8E923457402861A6ED5FFD4B409D9D0C8E923457404C16F71F99FE4B400E4E44BFB63757404C16F71F99FE4B400E4E44BFB63757402861A6ED5FFD4B409D9D0C8E923457402861A6ED5FFD4B40
73312	1225	92.864187000000001	92.885468000000003	56.023842000000002	56.023564999999998	Степана Разина	0103000020E6100000010000000500000037A8FDD64E375740452A8C2D04034C4037A8FDD64E375740B82231410D034C40E469F981AB385740B82231410D034C40E469F981AB385740452A8C2D04034C4037A8FDD64E375740452A8C2D04034C40
72134	1225	92.801709000000002	92.818984	56.006310999999997	56.005772	Сопочная	0103000020E610000001000000050000002BFA43334F335740C39D0B23BD004C402BFA43334F335740724D81CCCE004C40A0FCDD3B6A345740724D81CCCE004C40A0FCDD3B6A345740C39D0B23BD004C402BFA43334F335740C39D0B23BD004C40
7287	1225	92.927653000000007	92.935872000000003	56.120859000000003	56.112949	Солнечный бульвар	0103000020E610000001000000050000005342B0AA5E3B5740D68EE21C750E4C405342B0AA5E3B5740B136C64E780F4C407F4FAC53E53B5740B136C64E780F4C407F4FAC53E53B5740D68EE21C750E4C405342B0AA5E3B5740D68EE21C750E4C40
72681	1225	92.949554000000006	92.955995000000001	56.047696000000002	56.044609000000001	Сергея Лазо	0103000020E610000001000000050000004EF2237EC53C5740BB0D6ABFB5054C404EF2237EC53C574034130CE71A064C40EE08A7052F3D574034130CE71A064C40EE08A7052F3D5740BB0D6ABFB5054C404EF2237EC53C5740BB0D6ABFB5054C40
72085	1225	92.834776000000005	93.031130000000005	56.016002999999998	55.979827999999998	Семафорная	0103000020E6100000010000000500000016DF50F86C35574040DAFF006BFD4B4016DF50F86C355740A6D1E4620C024C402BFBAE08FE415740A6D1E4620C024C402BFBAE08FE41574040DAFF006BFD4B4016DF50F86C35574040DAFF006BFD4B40
72250	1225	92.832683000000003	92.835773000000003	56.028751999999997	56.025275999999998	Северо-Енисейская	0103000020E61000000100000005000000DA3BA3AD4A355740D5AF743E3C034C40DA3BA3AD4A355740E8D84125AE034C404F78094E7D355740E8D84125AE034C404F78094E7D355740D5AF743E3C034C40DA3BA3AD4A355740D5AF743E3C034C40
5829	1225	92.742061000000007	92.833375000000004	56.024546000000001	55.989784	Свободный проспект	0103000020E61000000100000005000000C6A86BED7D2F5740520DFB3DB1FE4B40C6A86BED7D2F5740B29FC55224034C407593180456355740B29FC55224034C407593180456355740520DFB3DB1FE4B40C6A86BED7D2F5740520DFB3DB1FE4B40
7249	1225	92.900497000000001	92.908311999999995	56.061940999999997	56.058020999999997	Светлогорский переулок	0103000020E610000001000000050000005A492BBEA139574098BD6C3B6D074C405A492BBEA139574009A4C4AEED074C401EA4A7C8213A574009A4C4AEED074C401EA4A7C8213A574098BD6C3B6D074C405A492BBEA139574098BD6C3B6D074C40
72160	1225	92.913387999999998	92.925855999999996	56.122714999999999	56.118760999999999	Светлова	0103000020E61000000100000005000000C423F1F2743A57402785798F330F4C40C423F1F2743A574044DD0720B50F4C408B338639413B574044DD0720B50F4C408B338639413B57402785798F330F4C40C423F1F2743A57402785798F330F4C40
72155	1225	92.720403000000005	92.887804000000003	55.983826000000001	55.965344999999999	Свердловская	0103000020E610000001000000050000002E3C2F151B2E5740B62DCA6C90FB4B402E3C2F151B2E57402D7AA702EEFD4B408350DEC7D13857402D7AA702EEFD4B408350DEC7D1385740B62DCA6C90FB4B402E3C2F151B2E5740B62DCA6C90FB4B40
72130	1225	93.007818999999998	93.030456000000001	56.044728999999997	56.042316	Рейдовая	0103000020E610000001000000050000006552431B804057407C0C569C6A054C406552431B8040574065170CAEB9054C40E3FDB8FDF241574065170CAEB9054C40E3FDB8FDF24157407C0C569C6A054C406552431B804057407C0C569C6A054C40
72236	1225	92.836868999999993	92.838513000000006	56.015695999999998	56.006135	Профсоюзов	0103000020E610000001000000050000005182FE428F355740342E1C08C9004C405182FE428F355740C956975302024C4056116E32AA355740C956975302024C4056116E32AA355740342E1C08C9004C405182FE428F355740342E1C08C9004C40
72245	1225	92.914178000000007	92.923277999999996	55.997436	55.995356999999998	Побежимова	0103000020E61000000100000005000000412E71E4813A57401E6CB1DB67FF4B40412E71E4813A574031ED9BFBABFF4B4071C79BFC163B574031ED9BFBABFF4B4071C79BFC163B57401E6CB1DB67FF4B40412E71E4813A57401E6CB1DB67FF4B40
72162	1225	92.932772999999997	92.946104000000005	56.122500000000002	56.119107	Петрушина	0103000020E61000000100000005000000E065868DB23B5740C2DCEEE53E0F4C40E065868DB23B574048E17A14AE0F4C4059A7CAF78C3C574048E17A14AE0F4C4059A7CAF78C3C5740C2DCEEE53E0F4C40E065868DB23B5740C2DCEEE53E0F4C40
72505	1225	92.745214000000004	92.763333000000003	56.026663999999997	56.026463	Петра Словцова	0103000020E610000001000000050000005EA10F96B12F5740EBC6BB2363034C405EA10F96B12F574082FDD7B969034C4049BDA772DA30574082FDD7B969034C4049BDA772DA305740EBC6BB2363034C405EA10F96B12F5740EBC6BB2363034C40
72128	1225	93.005330000000001	93.017843999999997	56.026307000000003	56.023378999999998	Песочная	0103000020E6100000010000000500000003ECA35357405740E3344415FE024C4003ECA35357405740F4531C075E034C40821B295B24415740F4531C075E034C40821B295B24415740E3344415FE024C4003ECA35357405740E3344415FE024C40
72097	1225	92.859263999999996	92.888738000000004	55.980392000000002	55.974811000000003	Парашютная	0103000020E6100000010000000500000054A86E2EFE365740FA635A9BC6FC4B4054A86E2EFE36574049A12C7C7DFD4B40992D5915E138574049A12C7C7DFD4B40992D5915E1385740FA635A9BC6FC4B4054A86E2EFE365740FA635A9BC6FC4B40
72485	1225	93.018058999999994	93.021527000000006	56.056488000000002	56.050451000000002	Одесская	0103000020E610000001000000050000008099EFE0274157407786A92D75064C408099EFE027415740E84EB0FF3A074C40C93EC8B260415740E84EB0FF3A074C40C93EC8B2604157407786A92D75064C408099EFE0274157407786A92D75064C40
73293	1225	92.852922000000007	92.855141000000003	56.020164000000001	56.011116999999999	Обороны	0103000020E610000001000000050000007E02284696365740FEB627486C014C407E022846963657403D47E4BB94024C40001E51A1BA3657403D47E4BB94024C40001E51A1BA365740FEB627486C014C407E02284696365740FEB627486C014C40
72702	1225	92.702894000000001	92.727678999999995	56.058900999999999	56.053964999999998	Норильская	0103000020E610000001000000050000007FA31D37FC2C574077103B53E8064C407FA31D37FC2C5740D15966118A074C401ABFF04A922E5740D15966118A074C401ABFF04A922E574077103B53E8064C407FA31D37FC2C574077103B53E8064C40
72492	1225	92.800837999999999	92.808878000000007	56.028480000000002	56.01708	Новая Заря	0103000020E6100000010000000500000038D906EE4033574035B56CAD2F024C4038D906EE40335740884B8E3BA5034C400D1D3BA8C4335740884B8E3BA5034C400D1D3BA8C433574035B56CAD2F024C4038D906EE4033574035B56CAD2F024C40
73300	1225	92.950757999999993	92.974885999999998	55.990479000000001	55.984878999999999	Новая	0103000020E61000000100000005000000431A1538D93C574033C2DB8310FE4B40431A1538D93C5740F92F1004C8FE4B4002D53F88643E5740F92F1004C8FE4B4002D53F88643E574033C2DB8310FE4B40431A1538D93C574033C2DB8310FE4B40
72252	1225	92.954116999999997	92.975658999999993	56.010900999999997	56.005932999999999	Московская	0103000020E61000000100000005000000B0E3BF40103D5740CC7B9C69C2004C40B0E3BF40103D5740313F373465014C4013437232713E5740313F373465014C4013437232713E5740CC7B9C69C2004C40B0E3BF40103D5740CC7B9C69C2004C40
73297	1225	92.957216000000003	92.978228000000001	56.015037	55.985608999999997	Мичурина	0103000020E610000001000000050000004FCDE506433D574056D28A6F28FE4B404FCDE506433D57406F9D7FBBEC014C4004029D499B3E57406F9D7FBBEC014C4004029D499B3E574056D28A6F28FE4B404FCDE506433D574056D28A6F28FE4B40
368	1225	92.835341999999997	92.892743999999993	56.013195000000003	56.010201000000002	Мира проспект	0103000020E610000001000000050000006ABE4A3E7635574079B130444E014C406ABE4A3E7635574041BCAE5FB0014C40D0ECBAB72239574041BCAE5FB0014C40D0ECBAB72239574079B130444E014C406ABE4A3E7635574079B130444E014C40
72279	1225	92.921850000000006	92.926834999999997	56.118966999999998	56.111283	Микуцкого	0103000020E6100000010000000500000054742497FF3A5740E6CC76853E0E4C4054742497FF3A5740D026874F3A0F4C407172BF43513B5740D026874F3A0F4C407172BF43513B5740E6CC76853E0E4C4054742497FF3A5740E6CC76853E0E4C40
72246	1225	92.801889000000003	92.827822999999995	56.025894999999998	56.024008000000002	Мечникова	0103000020E610000001000000050000006B813D2652335740D36BB3B112034C406B813D2652335740A110018750034C401AF8510DFB345740A110018750034C401AF8510DFB345740D36BB3B112034C406B813D2652335740D36BB3B112034C40
7165	1225	92.941208000000003	92.987354999999994	56.070414	56.042622000000001	Металлургов проспект	0103000020E61000000100000005000000F3AE7AC03C3C5740890B40A374054C40F3AE7AC03C3C57401C97715303094C40B1A206D3303F57401C97715303094C40B1A206D3303F5740890B40A374054C40F3AE7AC03C3C5740890B40A374054C40
72233	1225	92.797622000000004	92.823278000000002	56.016345000000001	56.014755000000001	Менжинского	0103000020E610000001000000050000007D24253D0C335740EB39E97DE3014C407D24253D0C335740003ACC9717024C400B613596B0345740003ACC9717024C400B613596B0345740EB39E97DE3014C407D24253D0C335740EB39E97DE3014C40
72688	1225	92.807665	92.815274000000002	56.002288999999998	55.996414000000001	Мелькомбинатская	0103000020E61000000100000005000000ED478AC8B033574066A3737E8AFF4B40ED478AC8B0335740FD1186014B004C40DDD1FF722D345740FD1186014B004C40DDD1FF722D34574066A3737E8AFF4B40ED478AC8B033574066A3737E8AFF4B40
7008	1225	92.841899999999995	92.857476000000005	55.978895999999999	55.973123000000001	Медицинский переулок	0103000020E6100000010000000500000027A089B0E135574022FE614B8FFC4B4027A089B0E1355740B517D1764CFD4B40B74604E3E0365740B517D1764CFD4B40B74604E3E036574022FE614B8FFC4B4027A089B0E135574022FE614B8FFC4B40
1017	1225	92.961006999999995	92.966127999999998	55.997732999999997	55.988570000000003	Маяковского переулок	0103000020E61000000100000005000000880E8123813D574043E7357689FE4B40880E8123813D5740EA9106B7B5FF4B40FEEF880AD53D5740EA9106B7B5FF4B40FEEF880AD53D574043E7357689FE4B40880E8123813D574043E7357689FE4B40
6325	1225	93.003658999999999	93.022919000000002	55.987825000000001	55.981791999999999	Машиностроителей проспект	0103000020E610000001000000050000008255F5F23B405740BABC395CABFD4B408255F5F23B405740EA95B20C71FE4B4040DD408177415740EA95B20C71FE4B4040DD408177415740BABC395CABFD4B408255F5F23B405740BABC395CABFD4B40
72076	1225	92.934479999999994	92.946472999999997	56.067841000000001	56.061424000000002	Мате Залки	0103000020E6100000010000000500000007B13385CE3B57404298DBBDDC074C4007B13385CE3B5740FA298E03AF084C4002637D03933C5740FA298E03AF084C4002637D03933C57404298DBBDDC074C4007B13385CE3B57404298DBBDDC074C40
73321	1225	92.866315999999998	92.882908	56.015576000000003	56.014724999999999	Марковского	0103000020E610000001000000050000001900AAB87137574080B74082E2014C401900AAB8713757401F4DF564FE014C401D588E90813857401F4DF564FE014C401D588E908138574080B74082E2014C401900AAB87137574080B74082E2014C40
71555	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	Малая	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
72122	1225	92.827265999999995	92.838603000000006	56.041018000000001	56.015695999999998	Маерчака	0103000020E61000000100000005000000EFC517EDF1345740C956975302024C40EFC517EDF13457400F46EC1340054C40F6D4EAABAB3557400F46EC1340054C40F6D4EAABAB355740C956975302024C40EFC517EDF1345740C956975302024C40
72488	1225	93.002032999999997	93.029844999999995	56.003115000000001	55.996228000000002	Львовская	0103000020E61000000100000005000000D120054F2140574004AE2B6684FF4B40D120054F214057404390831266004C40BEBC00FBE84157404390831266004C40BEBC00FBE841574004AE2B6684FF4B40D120054F2140574004AE2B6684FF4B40
72208	1225	92.804817	92.849588999999995	56.005420000000001	55.992854999999999	Ломоносова	0103000020E61000000100000005000000F390291F82335740C55565DF15FF4B40F390291F82335740465F419AB1004C40A5828AAA5F365740465F419AB1004C40A5828AAA5F365740C55565DF15FF4B40F390291F82335740C55565DF15FF4B40
5813	1225	92.819693000000001	92.819908999999996	56.033993000000002	56.032573999999997	Лизы Чайкиной переулок	0103000020E61000000100000005000000A6F0A0D975345740965984622B044C40A6F0A0D9753457407FA5F3E159044C408C2C9963793457407FA5F3E159044C408C2C996379345740965984622B044C40A6F0A0D975345740965984622B044C40
72121	1225	92.838109000000003	92.841999000000001	56.019660999999999	56.019410000000001	Лиды Прушинской	0103000020E61000000100000005000000EE5EEE93A3355740919BE1067C024C40EE5EEE93A3355740DA006C4084024C40F110C64FE3355740DA006C4084024C40F110C64FE3355740919BE1067C024C40EE5EEE93A3355740919BE1067C024C40
72493	1225	92.618165000000005	92.757287000000005	55.991802999999997	55.968766000000002	Лесная	0103000020E610000001000000050000000AA2EE039027574006BD378600FC4B400AA2EE03902757408F899466F3FE4B40E7ABE463773057408F899466F3FE4B40E7ABE4637730574006BD378600FC4B400AA2EE039027574006BD378600FC4B40
73318	1225	92.798941999999997	92.890542999999994	56.014685	56.010230999999997	Ленина	0103000020E61000000100000005000000A759A0DD21335740E333D93F4F014C40A759A0DD21335740F25EB532E1014C40A12B11A8FE385740F25EB532E1014C40A12B11A8FE385740E333D93F4F014C40A759A0DD21335740E333D93F4F014C40
72472	1225	92.812191999999996	92.814339000000004	56.025502000000003	56.002963999999999	Ладо Кецховели	0103000020E61000000100000005000000A98427F4FA3357405D88D51F61004C40A98427F4FA335740C6FD47A643034C40DF3653211E345740C6FD47A643034C40DF3653211E3457405D88D51F61004C40A98427F4FA3357405D88D51F61004C40
73309	1225	92.935585000000003	92.975282000000007	55.993428999999999	55.983449	Кутузова	0103000020E610000001000000050000003468E89FE03B5740572426A8E1FD4B403468E89FE03B5740F1F274AE28FF4B40299831056B3E5740F1F274AE28FF4B40299831056B3E5740572426A8E1FD4B403468E89FE03B5740572426A8E1FD4B40
72138	1225	92.779970000000006	92.789518999999999	56.020913999999998	56.016027999999999	Курчатова	0103000020E610000001000000050000001D774A07EB315740FFE89B340D024C401D774A07EB315740A703594FAD024C408524B37A87325740A703594FAD024C408524B37A87325740FFE89B340D024C401D774A07EB315740FFE89B340D024C40
72376	1225	92.773285999999999	92.784667999999996	56.027303000000003	56.021337000000003	Крупской	0103000020E61000000100000005000000191D90847D315740EE98BA2BBB024C40191D90847D315740960A2AAA7E034C40EF8D210038325740960A2AAA7E034C40EF8D210038325740EE98BA2BBB024C40191D90847D315740EE98BA2BBB024C40
72127	1225	92.887452999999994	93.025910999999994	56.025452000000001	55.991858000000001	Красноярский Рабочий	0103000020E610000001000000050000002CEFAA07CC3857405323F433F5FE4B402CEFAA07CC38574014CFD90242034C40D3669C86A841574014CFD90242034C40D3669C86A84157405323F433F5FE4B402CEFAA07CC3857405323F433F5FE4B40
71718	1225	92.911708000000004	92.920484000000002	55.974665000000002	55.969752999999997	Краснопресненская	0103000020E610000001000000050000001AE0826C593A57405419C6DD20FC4B401AE0826C593A574026C79DD2C1FC4B40711FB935E93A574026C79DD2C1FC4B40711FB935E93A57405419C6DD20FC4B401AE0826C593A57405419C6DD20FC4B40
72239	1225	92.794387999999998	92.858348000000007	56.01388	56.010941000000003	Красной Армии	0103000020E610000001000000050000006E15C440D7325740C097C28366014C406E15C440D7325740C408E1D1C6014C409225732CEF365740C408E1D1C6014C409225732CEF365740C097C28366014C406E15C440D7325740C097C28366014C40
72033	1225	92.941208000000003	92.944415000000006	56.05782	56.042622000000001	Краснодарская	0103000020E61000000100000005000000F3AE7AC03C3C5740890B40A374054C40F3AE7AC03C3C5740018750A566074C4085B69C4B713C5740018750A566074C4085B69C4B713C5740890B40A374054C40F3AE7AC03C3C5740890B40A374054C40
73331	1225	92.957351000000003	92.969522999999995	56.019056999999997	56.015006999999997	Крайняя	0103000020E61000000100000005000000BFF2203D453D5740041BD7BFEB014C40BFF2203D453D574043E1B37570024C40116E32AA0C3E574043E1B37570024C40116E32AA0C3E5740041BD7BFEB014C40BFF2203D453D5740041BD7BFEB014C40
73295	1225	92.952400999999995	92.966297999999995	56.007795999999999	56.001635	Корнетова	0103000020E610000001000000050000005FEB5223F43C5740B5C35F9335004C405FEB5223F43C574012859675FF004C402C0C91D3D73D574012859675FF004C402C0C91D3D73D5740B5C35F9335004C405FEB5223F43C5740B5C35F9335004C40
72263	1225	92.808509000000001	92.809496999999993	56.012335	56.002329000000003	Корнеева	0103000020E610000001000000050000006361889CBE3357408C6A11514C004C406361889CBE3357404FCC7A3194014C40724D81CCCE3357404FCC7A3194014C40724D81CCCE3357408C6A11514C004C406361889CBE3357408C6A11514C004C40
73167	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	Конституции СССР	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
4207	1225	92.922783999999993	92.942402999999999	56.068756	56.056894999999997	Комсомольский проспект	0103000020E6100000010000000500000069519FE40E3B57402827DA5548074C4069519FE40E3B5740AFB321FFCC084C40BF29AC54503C5740AFB321FFCC084C40BF29AC54503C57402827DA5548074C4069519FE40E3B57402827DA5548074C40
73319	1225	92.932180000000002	92.950514999999996	56.008873000000001	56.004665000000003	Коммунальная	0103000020E610000001000000050000000F7F4DD6A83B5740CA37DBDC98004C400F7F4DD6A83B5740A1681EC022014C40E0D6DD3CD53C5740A1681EC022014C40E0D6DD3CD53C5740CA37DBDC98004C400F7F4DD6A83B5740CA37DBDC98004C40
72530	1225	92.817699000000005	92.828263000000007	56.032826	56.032483999999997	Комбайностроителей	0103000020E6100000010000000500000034BE2F2E5534574056D28A6F28044C4034BE2F2E55345740B03A72A433044C40295FD04202355740B03A72A433044C40295FD0420235574056D28A6F28044C4034BE2F2E5534574056D28A6F28044C40
72269	1225	92.889555000000001	92.903685999999993	55.994672999999999	55.988525000000003	Кольцевая	0103000020E61000000100000005000000923F1878EE385740A323B9FC87FE4B40923F1878EE3857406B9BE27151FF4B4098F6CDFDD53957406B9BE27151FF4B4098F6CDFDD5395740A323B9FC87FE4B40923F1878EE385740A323B9FC87FE4B40
72123	1225	92.963379000000003	92.966944999999996	56.013804	56.009017999999998	Коломенская	0103000020E61000000100000005000000CEA96400A83D5740A489778027014C40CEA96400A83D5740E9465854C4014C40F701486DE23D5740E9465854C4014C40F701486DE23D5740A489778027014C40CEA96400A83D5740A489778027014C40
72506	1225	92.801259999999999	92.818417999999994	55.976871000000003	55.974896999999999	Ключевская	0103000020E61000000100000005000000F3E505D847335740F8FBC56CC9FC4B40F3E505D84733574096B4E21B0AFD4B404B1DE4F56034574096B4E21B0AFD4B404B1DE4F560345740F8FBC56CC9FC4B40F3E505D847335740F8FBC56CC9FC4B40
71627	1225	92.784767000000002	92.788019000000006	55.973018000000003	55.968100999999997	Карьерная	0103000020E61000000100000005000000B9FE5D9F39325740C91CCBBBEAFB4B40B9FE5D9F39325740AD3594DA8BFC4B401B683EE76E325740AD3594DA8BFC4B401B683EE76E325740C91CCBBBEAFB4B40B9FE5D9F39325740C91CCBBBEAFB4B40
73303	1225	92.799094999999994	92.894119000000003	56.01153	56.008429999999997	Карла Маркса	0103000020E610000001000000050000006AD95A5F243357401327F73B14014C406AD95A5F243357402176A6D079014C40DDEEE53E393957402176A6D079014C40DDEEE53E393957401327F73B14014C406AD95A5F243357401327F73B14014C40
72146	1225	92.777400999999998	92.784255000000002	56.035974000000003	56.029696999999999	Карбышева	0103000020E610000001000000050000002CB81FF0C031574008E57D1CCD034C402CB81FF0C0315740CFC0C8CB9A044C405E2EE23B31325740CFC0C8CB9A044C405E2EE23B3132574008E57D1CCD034C402CB81FF0C031574008E57D1CCD034C40
72149	1225	92.717645000000005	92.831084000000004	56.061644999999999	56.031588999999997	Калинина	0103000020E61000000100000005000000D4484BE5ED2D5740E8F4BC1B0B044C40D4484BE5ED2D5740207BBDFBE3074C40A60EF27A30355740207BBDFBE3074C40A60EF27A30355740E8F4BC1B0B044C40D4484BE5ED2D5740E8F4BC1B0B044C40
73306	1225	92.883769999999998	92.884317999999993	56.030712999999999	56.023842000000002	Енисейская	0103000020E61000000100000005000000E6CB0BB08F385740B82231410D034C40E6CB0BB08F385740F1475167EE034C40E75086AA98385740F1475167EE034C40E75086AA98385740B82231410D034C40E6CB0BB08F385740B82231410D034C40
72500	1225	92.714635000000001	92.763333000000003	56.026463	56.019581000000002	Елены Стасовой	0103000020E61000000100000005000000ED647094BC2D5740BE4F55A181024C40ED647094BC2D5740EBC6BB2363034C4049BDA772DA305740EBC6BB2363034C4049BDA772DA305740BE4F55A181024C40ED647094BC2D5740BE4F55A181024C40
72278	1225	92.976252000000002	92.986671999999999	56.063654999999997	56.059820000000002	Джамбульская	0103000020E61000000100000005000000E529ABE97A3E5740C8D2872EA8074C40E529ABE97A3E57400A9DD7D825084C4040F850A2253F57400A9DD7D825084C4040F850A2253F5740C8D2872EA8074C40E529ABE97A3E5740C8D2872EA8074C40
72503	1225	92.924626000000004	92.926844000000003	55.974564000000001	55.962831000000001	Делегатская	0103000020E6100000010000000500000001C287122D3B57409949D40B3EFB4B4001C287122D3B5740F2ED5D83BEFC4B409B1F7F69513B5740F2ED5D83BEFC4B409B1F7F69513B57409949D40B3EFB4B4001C287122D3B57409949D40B3EFB4B40
72267	1225	92.741997999999995	92.776016999999996	56.030915	56.026463	Гусарова	0103000020E61000000100000005000000A2EC2DE57C2F5740EBC6BB2363034C40A2EC2DE57C2F574059FAD005F5034C40F6083543AA31574059FAD005F5034C40F6083543AA315740EBC6BB2363034C40A2EC2DE57C2F5740EBC6BB2363034C40
73302	1225	92.846615999999997	92.849705999999998	56.020108999999998	56.004961999999999	Горького	0103000020E610000001000000050000004D11E0F42E36574083DC4598A2004C404D11E0F42E36574079AD84EE92024C40C24D46956136574079AD84EE92024C40C24D46956136574083DC4598A2004C404D11E0F42E36574083DC4598A2004C40
72258	1225	93.030626999999996	93.061627999999999	56.022786000000004	56.018962000000002	Глинки	0103000020E61000000100000005000000F9D7F2CAF5415740F2EEC8586D024C40F9D7F2CAF54157404167D2A6EA024C40252191B6F14357404167D2A6EA024C40252191B6F1435740F2EEC8586D024C40F9D7F2CAF5415740F2EEC8586D024C40
73299	1225	92.954881	92.971975999999998	55.997929999999997	55.993932000000001	Гастелло	0103000020E6100000010000000500000098A432C51C3D57405439ED2939FF4B4098A432C51C3D574040D9942BBCFF4B40CD1FD3DA343E574040D9942BBCFF4B40CD1FD3DA343E57405439ED2939FF4B4098A432C51C3D57405439ED2939FF4B40
72499	1225	92.776016999999996	92.794370000000001	56.030296	56.018625	Высотная	0103000020E61000000100000005000000F6083543AA315740AAF1D24D62024C40F6083543AA3157408D9944BDE0034C401BBB44F5D63257408D9944BDE0034C401BBB44F5D6325740AAF1D24D62024C40F6083543AA315740AAF1D24D62024C40
72054	1225	92.946005	92.965328	56.063997000000001	56.050716999999999	Воронова	0103000020E610000001000000050000008F368E588B3C5740F52C08E57D064C408F368E588B3C57406405BF0D31084C40707A17EFC73D57406405BF0D31084C40707A17EFC73D5740F52C08E57D064C408F368E588B3C5740F52C08E57D064C40
73291	1225	92.932477000000006	92.938460000000006	56.096980000000002	56.095896000000003	Волочанская	0103000020E610000001000000050000006CD102B4AD3B57409BE8F351460C4C406CD102B4AD3B5740DC2E34D7690C4C40AB2688BA0F3C5740DC2E34D7690C4C40AB2688BA0F3C57409BE8F351460C4C406CD102B4AD3B57409BE8F351460C4C40
72497	1225	92.806128999999999	92.807135000000002	56.012284999999999	56.001418000000001	Волочаевская	0103000020E61000000100000005000000DCD6169E9733574018D00B772E004C40DCD6169E973357409D9D0C8E92014C403F1D8F19A83357409D9D0C8E92014C403F1D8F19A833574018D00B772E004C40DCD6169E9733574018D00B772E004C40
72030	1225	92.977096000000003	93.018275000000003	55.998145999999998	55.988208	Волжская	0103000020E610000001000000050000005B43A9BD883E5740A2D288997DFE4B405B43A9BD883E57400D51853FC3FF4B4067D5E76A2B4157400D51853FC3FF4B4067D5E76A2B415740A2D288997DFE4B405B43A9BD883E5740A2D288997DFE4B40
72480	1225	92.955940999999996	92.972200000000001	56.010140999999997	56.003743999999998	Волгоградская	0103000020E61000000100000005000000F4F928232E3D574032C7F2AE7A004C40F4F928232E3D5740A3ACDF4C4C014C40F54A5986383E5740A3ACDF4C4C014C40F54A5986383E574032C7F2AE7A004C40F4F928232E3D574032C7F2AE7A004C40
73311	1225	92.845833999999996	92.864124000000004	56.032997000000002	56.032283	Водянникова	0103000020E6100000010000000500000012F6ED2422365740BF9B6ED921044C4012F6ED2422365740DDEEE53E39044C4014ECBFCE4D375740DDEEE53E39044C4014ECBFCE4D375740BF9B6ED921044C4012F6ED2422365740BF9B6ED921044C40
72141	1225	92.763413999999997	92.768039999999999	56.025441999999998	56.019435000000001	Вильского	0103000020E61000000100000005000000BFD364C6DB305740EAB298D87C024C40BFD364C6DB305740F0F8F6AE41034C4045813E9127315740F0F8F6AE41034C4045813E9127315740EAB298D87C024C40BFD364C6DB305740EAB298D87C024C40
72322	1225	92.891559000000001	92.919899999999998	56.036593000000003	56.033735999999998	Взлетная	0103000020E6100000010000000500000016DD7A4D0F3957405359147651044C4016DD7A4D0F3957409B215514AF044C40C9E53FA4DF3A57409B215514AF044C40C9E53FA4DF3A57405359147651044C4016DD7A4D0F3957405359147651044C40
72079	1225	92.908815000000004	92.915031999999997	56.039780999999998	56.033735999999998	Весны	0103000020E6100000010000000500000050C763062A3A57405359147651044C4050C763062A3A57404700378B17054C40C8B260E28F3A57404700378B17054C40C8B260E28F3A57405359147651044C4050C763062A3A57405359147651044C40
72584	1225	93.055025000000001	93.082297999999994	56.022931	56.019168000000001	Верхняя	0103000020E6100000010000000500000098DD9387854357409B90D61874024C4098DD93878543574044882B67EF024C40ADA1D45E4445574044882B67EF024C40ADA1D45E444557409B90D61874024C4098DD9387854357409B90D61874024C40
72018	1225	92.739284999999995	92.741324000000006	56.040224000000002	56.037579000000001	Ботаническая	0103000020E61000000100000005000000185B0872502F574019028063CF044C40185B0872502F5740D5415E0F26054C405BEF37DA712F5740D5415E0F26054C405BEF37DA712F574019028063CF044C40185B0872502F574019028063CF044C40
72491	1225	92.788090999999994	92.798789999999997	55.994798000000003	55.994687999999996	Борисова	0103000020E6100000010000000500000067D13B1570325740A0DCB6EF51FF4B4067D13B15703257402810768A55FF4B40CC9717601F3357402810768A55FF4B40CC9717601F335740A0DCB6EF51FF4B4067D13B1570325740A0DCB6EF51FF4B40
72261	1225	93.044100999999998	93.064745000000002	56.019601000000002	56.002077999999997	Борисевича	0103000020E61000000100000005000000232E008DD24257404205871744004C40232E008DD242574005FC1A4982024C40176536C82444574005FC1A4982024C40176536C8244457404205871744004C40232E008DD24257404205871744004C40
72559	1225	92.811591000000007	92.879026999999994	56.008676000000001	56.005893	Бограда	0103000020E6100000010000000500000097AE601BF13357403E23111AC1004C4097AE601BF13357404B21904B1C014C40435376FA413857404B21904B1C014C40435376FA413857403E23111AC1004C4097AE601BF13357403E23111AC1004C40
73327	1225	92.913639000000003	92.929629000000006	56.000467	55.995468000000002	Базарная	0103000020E610000001000000050000006956B60F793A5740761BD47E6BFF4B406956B60F793A574016DD7A4D0F004C40721AA20A7F3B574016DD7A4D0F004C40721AA20A7F3B5740761BD47E6BFF4B406956B60F793A5740761BD47E6BFF4B40
72368	1225	93.002842000000001	93.010611999999995	55.995116000000003	55.984904	Аральская	0103000020E61000000100000005000000894336902E4057408CD9925511FE4B40894336902E405740F9DC09F65FFF4B407D3CF4DDAD405740F9DC09F65FFF4B407D3CF4DDAD4057408CD9925511FE4B40894336902E4057408CD9925511FE4B40
72501	1225	92.876745	92.885818	55.991888000000003	55.983674999999998	Анатолия Гладкова	0103000020E610000001000000050000009E7B0F971C3857404772F90FE9FD4B409E7B0F971C385740BEA59C2FF6FE4B40520DFB3DB1385740BEA59C2FF6FE4B40520DFB3DB13857404772F90FE9FD4B409E7B0F971C3857404772F90FE9FD4B40
72231	1225	92.925272000000007	92.949257000000003	55.976100000000002	55.967213999999998	Алеши Тимошенкова	0103000020E61000000100000005000000E4F90CA8373B5740DE1D19ABCDFB4B40E4F90CA8373B574014D044D8F0FC4B40F19F6EA0C03C574014D044D8F0FC4B40F19F6EA0C03C5740DE1D19ABCDFB4B40E4F90CA8373B5740DE1D19ABCDFB4B40
72199	1225	92.893642999999997	92.921553000000003	56.056291999999999	56.042003999999999	Алексеева	0103000020E6100000010000000500000028D36872313957408D26176360054C4028D36872313957406283859334074C40F7216FB9FA3A57406283859334074C40F7216FB9FA3A57408D26176360054C4028D36872313957408D26176360054C40
72152	1225	92.886429000000007	92.890472000000003	55.991345000000003	55.977128	Александра Матросова	0103000020E61000000100000005000000774EB340BB385740C100C28712FD4B40774EB340BB385740CD069964E4FE4B403D80457EFD385740CD069964E4FE4B403D80457EFD385740C100C28712FD4B40774EB340BB385740C100C28712FD4B40
73294	1225	92.928336000000002	92.968338000000003	55.999389999999998	55.989260000000002	Академика Павлова	0103000020E61000000100000005000000C4EC65DB693B5740D89E5912A0FE4B40C4EC65DB693B574087F9F202ECFF4B40575EF23FF93D574087F9F202ECFF4B40575EF23FF93D5740D89E5912A0FE4B40C4EC65DB693B5740D89E5912A0FE4B40
72574	1225	92.750307000000006	92.801889000000003	56.019913000000003	55.988253	Академика Киренского	0103000020E610000001000000050000006FBDA60705305740429605137FFE4B406FBDA60705305740F4E159828C024C406B813D2652335740F4E159828C024C406B813D2652335740429605137FFE4B406FBDA60705305740429605137FFE4B40
72439	1225	92.904081000000005	92.955940999999996	56.004282000000003	55.992075	Академика Вавилова	0103000020E61000000100000005000000D7FB8D76DC395740F0164850FCFE4B40D7FB8D76DC39574012FB04508C004C40F4F928232E3D574012FB04508C004C40F4F928232E3D5740F0164850FCFE4B40D7FB8D76DC395740F0164850FCFE4B40
72494	1225	92.744208	92.774750999999995	55.993428999999999	55.983277999999999	Академгородок	0103000020E61000000100000005000000FB5A971AA12F57402A70B20DDCFD4B40FB5A971AA12F5740F1F274AE28FF4B40C5E2378595315740F1F274AE28FF4B40C5E23785953157402A70B20DDCFD4B40FB5A971AA12F57402A70B20DDCFD4B40
72710	1225	92.705634000000003	92.707825999999997	56.028424999999999	56.026246999999998	Азовская	0103000020E61000000100000005000000863C821B292D57401E4FCB0F5C034C40863C821B292D5740C4B12E6EA3034C408B506C054D2D5740C4B12E6EA3034C408B506C054D2D57401E4FCB0F5C034C40863C821B292D57401E4FCB0F5C034C40
73322	1225	92.840867000000003	92.875551000000002	56.016517	56.014645000000002	Ады Лебедевой	0103000020E610000001000000050000004852D2C3D035574064062AE3DF014C404852D2C3D0355740FD69A33A1D024C40BABE0F0709385740FD69A33A1D024C40BABE0F070938574064062AE3DF014C404852D2C3D035574064062AE3DF014C40
4705	1225	92.936132999999998	92.94314	55.991686999999999	55.982039	Автобусный переулок	0103000020E6100000010000000500000035ED629AE93B5740C2323674B3FD4B4035ED629AE93B5740266F8099EFFE4B402AE3DF675C3C5740266F8099EFFE4B402AE3DF675C3C5740C2323674B3FD4B4035ED629AE93B5740C2323674B3FD4B40
71665	1225	92.897784000000001	92.928156000000001	56.058779999999999	56.039071999999997	Авиаторов	0103000020E61000000100000005000000D0B7054B753957403B18B14F00054C40D0B7054B7539574056D4601A86074C4084656CE8663B574056D4601A86074C4084656CE8663B57403B18B14F00054C40D0B7054B753957403B18B14F00054C40
72077	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	9 мая	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
72508	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	9 Мая	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
72132	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	60 лет Октября	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
27877	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	60 Лет Октября	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
72571	1225	92.952023999999994	92.957621000000003	56.013860000000001	56.012062999999998	52 Квартал	0103000020E61000000100000005000000744012F6ED3C5740EE3EC7478B014C40744012F6ED3C57407D5C1B2AC6014C409F3D97A9493D57407D5C1B2AC6014C409F3D97A9493D5740EE3EC7478B014C40744012F6ED3C5740EE3EC7478B014C40
72084	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	40 лет победы	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
72448	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	40 Лет Победы	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
73329	1225	92.855913000000001	92.856954999999999	56.037472999999999	56.027062000000001	4-ая Продольная	0103000020E6100000010000000500000029CE5147C7365740707B82C476034C4029CE5147C7365740D3BD4EEACB044C4032C9C859D8365740D3BD4EEACB044C4032C9C859D8365740707B82C476034C4029CE5147C7365740707B82C476034C40
72075	1225	92.622422999999998	93.173197999999999	56.136346000000003	55.908898000000001	26 Бакинских Комиссаров	0103000020E61000000100000005000000CE5147C7D52757402DB308C556F44B40CE5147C7D5275740607825C973114C40E36E10AD154B5740607825C973114C40E36E10AD154B57402DB308C556F44B40CE5147C7D52757402DB308C556F44B40
27964	6912	95.555773000000002	95.571916000000002	56.183588999999998	56.175953	Центральная	0103000020E61000000100000005000000FDBFEAC891E357400951BEA085164C40FDBFEAC891E35740E27327D87F174C40C90391459AE45740E27327D87F174C40C90391459AE457400951BEA085164C40FDBFEAC891E357400951BEA085164C40
72509	59612	91.673946000000001	91.726623000000004	53.715775000000001	53.695675999999999	Ленина	0103000020E61000000100000005000000485167EE21EB5640594E42E90BD94A40485167EE21EB5640AF25E4839EDB4A405F61C1FD80EE5640AF25E4839EDB4A405F61C1FD80EE5640594E42E90BD94A40485167EE21EB5640594E42E90BD94A40
72454	51789	92.474839000000003	92.483490000000003	58.235641000000001	58.228831999999997	Маяковского	0103000020E6100000010000000500000062F71DC3631E57409E23F25D4A1D4D4062F71DC3631E5740624CFA7B291E4D405B7C0A80F11E5740624CFA7B291E4D405B7C0A80F11E57409E23F25D4A1D4D4062F71DC3631E57409E23F25D4A1D4D40
28373	51854	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	улица Ветеранов	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72841	13664	93.294721999999993	93.343931999999995	56.077497999999999	56.050541000000003	Березовая	0103000020E6100000010000000500000059DAA9B9DC525740B70DA32078064C4059DAA9B9DC525740B1C05774EB094C4010035DFB02565740B1C05774EB094C4010035DFB02565740B70DA32078064C4059DAA9B9DC525740B70DA32078064C40
72954	7605	92.292544000000007	92.350583999999998	56.251922	56.222594999999998	Школьная	0103000020E610000001000000050000000729780AB912574066A032FE7D1C4C400729780AB91257404B92E7FA3E204C400EA0DFF76F1657404B92E7FA3E204C400EA0DFF76F16574066A032FE7D1C4C400729780AB912574066A032FE7D1C4C40
72217	7605	92.327236999999997	92.336884999999995	56.236680999999997	56.235415000000003	Жуковского	0103000020E61000000100000005000000A2427573F114574072FE2614221E4C40A2427573F1145740D34A21904B1E4C40D4601A868F155740D34A21904B1E4C40D4601A868F15574072FE2614221E4C40A2427573F114574072FE2614221E4C40
72447	1037	95.770685999999998	95.781762000000001	56.200648000000001	56.197744	поселок Строителей	0103000020E610000001000000050000000B5F5FEB52F15740787DE6AC4F194C400B5F5FEB52F1574000016BD5AE194C405BD07B6308F2574000016BD5AE194C405BD07B6308F25740787DE6AC4F194C400B5F5FEB52F15740787DE6AC4F194C40
72453	1037	95.749791000000002	95.751022000000006	56.234794999999998	56.231043	Юбилейная	0103000020E6100000010000000500000073F56393FCEF5740207C28D1921D4C4073F56393FCEF5740D52137C30D1E4C40E62494BE10F05740D52137C30D1E4C40E62494BE10F05740207C28D1921D4C4073F56393FCEF5740207C28D1921D4C40
72073	1037	95.705494999999999	95.706708000000006	56.190761999999999	56.189323999999999	Элеваторная	0103000020E61000000100000005000000751F80D426ED5740882CD2C43B184C40751F80D426ED5740E7A8A3E36A184C4095F430B43AED5740E7A8A3E36A184C4095F430B43AED5740882CD2C43B184C40751F80D426ED5740882CD2C43B184C40
72533	1037	95.718762999999996	95.729319000000004	56.198895999999998	56.181553999999998	Эйдемана	0103000020E61000000100000005000000CAA4863600EE57409F3A56293D174C40CAA4863600EE574011A7936C75194C407E569929ADEE574011A7936C75194C407E569929ADEE57409F3A56293D174C40CAA4863600EE57409F3A56293D174C40
72228	1037	95.744123000000002	95.752351000000004	56.225183000000001	56.215632999999997	Шоссейная	0103000020E61000000100000005000000E44C13B69FEF57401C78B5DC991B4C40E44C13B69FEF5740BE4EEACBD21C4C403A07CF8426F05740BE4EEACBD21C4C403A07CF8426F057401C78B5DC991B4C40E44C13B69FEF57401C78B5DC991B4C40
72418	1037	95.672939999999997	95.684051999999994	56.258243	56.252037000000001	Солнечный	0103000020E61000000100000005000000E50AEF7211EB5740E43098BF42204C40E50AEF7211EB5740E1B54B1B0E214C40DB300A82C7EB5740E1B54B1B0E214C40DB300A82C7EB5740E43098BF42204C40E50AEF7211EB5740E43098BF42204C40
71656	1037	95.687681999999995	95.688849000000005	56.22175	56.218851999999998	Северный	0103000020E6100000010000000500000010035DFB02EC57400455A357031C4C4010035DFB02EC5740AAF1D24D621C4C4078B81D1A16EC5740AAF1D24D621C4C4078B81D1A16EC57400455A357031C4C4010035DFB02EC57400455A357031C4C40
71680	1037	95.687681999999995	95.688849000000005	56.22175	56.218851999999998	Северная	0103000020E6100000010000000500000010035DFB02EC57400455A357031C4C4010035DFB02EC5740AAF1D24D621C4C4078B81D1A16EC5740AAF1D24D621C4C4078B81D1A16EC57400455A357031C4C4010035DFB02EC57400455A357031C4C40
72410	1037	95.700231000000002	95.716759999999994	56.200834	56.200347999999998	Революции	0103000020E610000001000000050000004E29AF95D0EC5740D5E8D500A5194C404E29AF95D0EC574062F6B2EDB4194C402EC55565DFED574062F6B2EDB4194C402EC55565DFED5740D5E8D500A5194C404E29AF95D0EC5740D5E8D500A5194C40
71537	1037	95.604381000000004	95.801192999999998	56.276743000000003	56.155267000000002	Предмостная площадь	0103000020E61000000100000005000000B954A52DAEE65740F392FFC9DF134C40B954A52DAEE65740CF328B506C234C402F3201BF46F35740CF328B506C234C402F3201BF46F35740F392FFC9DF134C40B954A52DAEE65740F392FFC9DF134C40
72116	1037	95.707436000000001	95.744140999999999	56.192064000000002	56.184950999999998	Николая Буды	0103000020E61000000100000005000000D600A5A146ED5740662E7079AC174C40D600A5A146ED5740965E9B8D95184C4037A79201A0EF5740965E9B8D95184C4037A79201A0EF5740662E7079AC174C40D600A5A146ED5740662E7079AC174C40
72417	1037	95.690681999999995	95.702072999999999	56.272930000000002	56.243614999999998	Муромская	0103000020E61000000100000005000000E57B462234EC574053E8BCC62E1F4C40E57B462234EC5740740CC85EEF224C40E59997C3EEEC5740740CC85EEF224C40E59997C3EEEC574053E8BCC62E1F4C40E57B462234EC574053E8BCC62E1F4C40
72555	1037	95.712484000000003	95.714155000000005	56.227083999999998	56.225732999999998	Молодогвардейская	0103000020E6100000010000000500000017BB7D5699ED57406150A6D1E41C4C4017BB7D5699ED5740F1B8A816111D4C4098512CB7B4ED5740F1B8A816111D4C4098512CB7B4ED57406150A6D1E41C4C4017BB7D5699ED57406150A6D1E41C4C40
5531	1037	95.686271000000005	95.688840999999996	56.191037000000001	56.188462999999999	Мелькомбината переулок	0103000020E610000001000000050000005E4C33DDEBEB5740C6C03A8E1F184C405E4C33DDEBEB5740B9A981E673184C4036C98FF815EC5740B9A981E673184C4036C98FF815EC5740C6C03A8E1F184C405E4C33DDEBEB5740C6C03A8E1F184C40
72224	1037	95.660884999999993	95.691130999999999	56.210687	56.209885999999997	Луначарского	0103000020E61000000100000005000000AF5A99F04BEA5740B2F1608BDD1A4C40AF5A99F04BEA57409F58A7CAF71A4C401D90847D3BEC57409F58A7CAF71A4C401D90847D3BEC5740B2F1608BDD1A4C40AF5A99F04BEA5740B2F1608BDD1A4C40
72412	1037	95.704929000000007	95.705135999999996	56.208433999999997	56.199981999999999	Ленина	0103000020E610000001000000050000002140868E1DED5740F3E49A0299194C402140868E1DED5740EEAF1EF7AD1A4C40DDCEBEF220ED5740EEAF1EF7AD1A4C40DDCEBEF220ED5740F3E49A0299194C402140868E1DED5740F3E49A0299194C40
72111	1037	95.689137000000002	95.699781999999999	56.206606999999998	56.205666000000001	Крестьянская	0103000020E61000000100000005000000AB5D13D21AEC574017F37343531A4C40AB5D13D21AEC5740F50F2219721A4C401615713AC9EC5740F50F2219721A4C401615713AC9EC574017F37343531A4C40AB5D13D21AEC574017F37343531A4C40
72114	1037	95.710183999999998	95.742137999999997	56.193722000000001	56.18712	Красноярская	0103000020E610000001000000050000001E8997A773ED5740B936548CF3174C401E8997A773ED57400342EBE1CB184C409BC761307FEF57400342EBE1CB184C409BC761307FEF5740B936548CF3174C401E8997A773ED5740B936548CF3174C40
72112	1037	95.668512000000007	95.726031000000006	56.208098999999997	56.205309999999997	Краснопартизанская	0103000020E61000000100000005000000F33E8EE6C8EA574058C51B99471A4C40F33E8EE6C8EA574047AAEFFCA21A4C407638BA4A77EE574047AAEFFCA21A4C407638BA4A77EE574058C51B99471A4C40F33E8EE6C8EA574058C51B99471A4C40
72226	1037	95.737790000000004	95.757938999999993	56.206592000000001	56.192791	Краевая	0103000020E6100000010000000500000037548CF337EF574048FB1F60AD184C4037548CF337EF5740C0CE4D9B711A4C403A57941282F05740C0CE4D9B711A4C403A57941282F0574048FB1F60AD184C4037548CF337EF574048FB1F60AD184C40
73141	1037	95.751165999999998	95.751866000000007	56.190320999999997	56.189304	Карьерный переулок	0103000020E610000001000000050000007FF78E1A13F0574041800C1D3B184C407FF78E1A13F05740FA5E43705C184C405C3E92921EF05740FA5E43705C184C405C3E92921EF0574041800C1D3B184C407FF78E1A13F0574041800C1D3B184C40
72408	1037	95.672023999999993	95.714335000000005	56.243335000000002	56.207622999999998	Кайтымская	0103000020E610000001000000050000002288F37002EB5740DE72F563931A4C402288F37002EB5740707CED99251F4C40D8D825AAB7ED5740707CED99251F4C40D8D825AAB7ED5740DE72F563931A4C402288F37002EB5740DE72F563931A4C40
5619	1037	95.691490999999999	95.697141000000002	56.238232000000004	56.234720000000003	Индустриальный переулок	0103000020E610000001000000050000009D9E776341EC5740CBDB114E0B1E4C409D9E776341EC57402B6EDC627E1E4C40D9EC48F59DEC57402B6EDC627E1E4C40D9EC48F59DEC5740CBDB114E0B1E4C409D9E776341EC5740CBDB114E0B1E4C40
72522	1037	95.666616000000005	95.689567999999994	56.203477999999997	56.203181999999998	Земледелия	0103000020E6100000010000000500000062BF27D6A9EA5740649126DE011A4C4062BF27D6A9EA57404DBA2D910B1A4C408F17D2E121EC57404DBA2D910B1A4C408F17D2E121EC5740649126DE011A4C4062BF27D6A9EA5740649126DE011A4C40
72531	1037	95.663911999999996	95.691220999999999	56.209606000000001	56.208739999999999	Бограда	0103000020E6100000010000000500000001DBC1887DEA5740FBAE08FEB71A4C4001DBC1887DEA5740CF85915ED41A4C40BD5301F73CEC5740CF85915ED41A4C40BD5301F73CEC5740FBAE08FEB71A4C4001DBC1887DEA5740FBAE08FEB71A4C40
72119	1037	95.604381000000004	95.801192999999998	56.276743000000003	56.155267000000002	40 лет Октября	0103000020E61000000100000005000000B954A52DAEE65740F392FFC9DF134C40B954A52DAEE65740CF328B506C234C402F3201BF46F35740CF328B506C234C402F3201BF46F35740F392FFC9DF134C40B954A52DAEE65740F392FFC9DF134C40
72882	24992	92.280381000000006	92.313851999999997	56.121155000000002	56.107624000000001	Заводская	0103000020E61000000100000005000000DE5A26C3F1115740E2218C9FC60D4C40DE5A26C3F11157409A5FCD01820F4C4030F2B226161457409A5FCD01820F4C4030F2B22616145740E2218C9FC60D4C40DE5A26C3F1115740E2218C9FC60D4C40
27888	49394	90.416349999999994	90.443648999999994	56.170982000000002	56.161223	Мира	0103000020E61000000100000005000000226C787AA59A5640772E8CF4A2144C40226C787AA59A5640331AF9BCE2154C40CC79C6BE649C5640331AF9BCE2154C40CC79C6BE649C5640772E8CF4A2144C40226C787AA59A5640772E8CF4A2144C40
28266	49394	90.416349999999994	90.443648999999994	56.170982000000002	56.161223	Лесная	0103000020E61000000100000005000000226C787AA59A5640772E8CF4A2144C40226C787AA59A5640331AF9BCE2154C40CC79C6BE649C5640331AF9BCE2154C40CC79C6BE649C5640772E8CF4A2144C40226C787AA59A5640772E8CF4A2144C40
72855	49394	90.416349999999994	90.443648999999994	56.170982000000002	56.161223	Длинная	0103000020E61000000100000005000000226C787AA59A5640772E8CF4A2144C40226C787AA59A5640331AF9BCE2154C40CC79C6BE649C5640331AF9BCE2154C40CC79C6BE649C5640772E8CF4A2144C40226C787AA59A5640772E8CF4A2144C40
28322	30713	93.107360999999997	93.139951999999994	56.386453000000003	56.367133000000003	Советская	0103000020E610000001000000050000006AF7AB00DF4657402524D236FE2E4C406AF7AB00DF4657407638BA4A77314C40A0C03BF9F44857407638BA4A77314C40A0C03BF9F44857402524D236FE2E4C406AF7AB00DF4657402524D236FE2E4C40
71492	59468	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Первый м-он	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72709	59468	91.672724000000002	91.693224000000001	53.704929999999997	53.700223000000001	Горького	0103000020E61000000100000005000000FFCEF6E80DEB5640197442E8A0D94A40FFCEF6E80DEB564011FC6F253BDA4A40593332C85DEC564011FC6F253BDA4A40593332C85DEC5640197442E8A0D94A40FFCEF6E80DEB5640197442E8A0D94A40
71609	59468	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Второй м-он	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72545	1592	93.149536999999995	93.151747	55.950332000000003	55.944606	Школьная	0103000020E61000000100000005000000AF22A303924957407DCD72D9E8F84B40AF22A30392495740D02B9E7AA4F94B4008910C39B6495740D02B9E7AA4F94B4008910C39B64957407DCD72D9E8F84B40AF22A303924957407DCD72D9E8F84B40
71629	1592	93.152608999999998	93.162678999999997	55.973934	55.946955000000003	Советская	0103000020E61000000100000005000000D1048A58C449574050E449D235F94B40D1048A58C4495740323B8BDEA9FC4B40BE2F2E55694A5740323B8BDEA9FC4B40BE2F2E55694A574050E449D235F94B40D1048A58C449574050E449D235F94B40
72535	1592	93.147255000000001	93.149356999999995	55.950983000000001	55.945704999999997	Клубная	0103000020E610000001000000050000000A4B3CA06C495740F35487DC0CF94B400A4B3CA06C495740A7069ACFB9F94B406F9BA9108F495740A7069ACFB9F94B406F9BA9108F495740F35487DC0CF94B400A4B3CA06C495740F35487DC0CF94B40
28138	48555	95.761208999999994	95.780845999999997	56.167799000000002	56.156058999999999	Первомайская	0103000020E61000000100000005000000EF1AF4A5B7F057408C9FC6BDF9134C40EF1AF4A5B7F0574098A608707A154C40984D8061F9F1574098A608707A154C40984D8061F9F157408C9FC6BDF9134C40EF1AF4A5B7F057408C9FC6BDF9134C40
71617	59489	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Первомайская	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
71612	59489	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Парковая	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
71666	59489	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Диктатуры Пролетариата	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
72403	59598	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	Победы	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
72406	59598	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	40 лет Октября	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
28466	51733	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Свердлова	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
71620	51733	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Саянская	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28256	51733	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Ленинградский проспект	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28455	51733	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Белорусская	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
71532	11422	93.254324999999994	93.301720000000003	56.150202999999998	56.122148000000003	Клубная	0103000020E6100000010000000500000088635DDC46505740CBA2B08BA20F4C4088635DDC465057406B6116DA39134C40252367614F5357406B6116DA39134C40252367614F535740CBA2B08BA20F4C4088635DDC46505740CBA2B08BA20F4C40
28581	47515	93.132891000000001	93.175848000000002	56.153793	56.120793999999997	Первомайская	0103000020E61000000100000005000000B2BB404981485740C9C6832D760F4C40B2BB40498148574047AD307DAF134C404A44F817414B574047AD307DAF134C404A44F817414B5740C9C6832D760F4C40B2BB404981485740C9C6832D760F4C40
71545	59478	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Рабоче-Крестьянская	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
71678	59478	92.865803999999997	92.867771000000005	56.020758000000001	56.006905000000003	Перенсона	0103000020E61000000100000005000000BE2F2E5569375740E6965643E2004C40BE2F2E5569375740B090B932A8024C40B45A608F89375740B090B932A8024C40B45A608F89375740E6965643E2004C40BE2F2E5569375740E6965643E2004C40
72461	59478	91.673946000000001	91.726623000000004	53.715775000000001	53.695675999999999	Ленина	0103000020E61000000100000005000000485167EE21EB5640594E42E90BD94A40485167EE21EB5640AF25E4839EDB4A405F61C1FD80EE5640AF25E4839EDB4A405F61C1FD80EE5640594E42E90BD94A40485167EE21EB5640594E42E90BD94A40
71649	59478	90.494412999999994	90.504249999999999	56.274399000000003	56.269795999999999	Куйбышева	0103000020E61000000100000005000000E76D6C76A49F5640BA4BE2AC88224C40E76D6C76A49F56400E87A5811F234C4083C0CAA145A056400E87A5811F234C4083C0CAA145A05640BA4BE2AC88224C40E76D6C76A49F5640BA4BE2AC88224C40
72538	59478	91.672724000000002	91.693224000000001	53.704929999999997	53.700223000000001	Горького	0103000020E61000000100000005000000FFCEF6E80DEB5640197442E8A0D94A40FFCEF6E80DEB564011FC6F253BDA4A40593332C85DEC564011FC6F253BDA4A40593332C85DEC5640197442E8A0D94A40FFCEF6E80DEB5640197442E8A0D94A40
72479	59478	93.122479999999996	93.124634999999998	56.035863999999997	56.028475	Гастелло	0103000020E61000000100000005000000809A5AB6D647574076E09C11A5034C40809A5AB6D6475740478D093197044C40F73B1405FA475740478D093197044C40F73B1405FA47574076E09C11A5034C40809A5AB6D647574076E09C11A5034C40
71702	59478	92.473285000000004	92.478639000000001	58.245158000000004	58.242936999999998	Бабкина	0103000020E61000000100000005000000FE2B2B4D4A1E574082FE428F181F4D40FE2B2B4D4A1E5740282D5C56611F4D40C5E57805A21E5740282D5C56611F4D40C5E57805A21E574082FE428F181F4D40FE2B2B4D4A1E574082FE428F181F4D40
6396	1330	92.664463999999995	92.673753000000005	56.175457000000002	56.173633000000002	улица Советская	0103000020E61000000100000005000000A3570394862A5740D1402C9B39164C40A3570394862A5740596DFE5F75164C403E25E7C41E2B5740596DFE5F75164C403E25E7C41E2B5740D1402C9B39164C40A3570394862A5740D1402C9B39164C40
72998	1330	92.675047000000006	92.677848999999995	56.190455999999998	56.189605	Центральная	0103000020E61000000100000005000000D41055F8332B57403C1405FA44184C40D41055F8332B5740DAA9B9DC60184C4015A8C5E0612B5740DAA9B9DC60184C4015A8C5E0612B57403C1405FA44184C40D41055F8332B57403C1405FA44184C40
72689	1330	92.675252999999998	92.676861000000002	56.192270000000001	56.190156000000002	Спортивная	0103000020E61000000100000005000000A8E15B58372B5740B091240857184C40A8E15B58372B57403F00A94D9C184C4006BCCCB0512B57403F00A94D9C184C4006BCCCB0512B5740B091240857184C40A8E15B58372B5740B091240857184C40
27923	1330	92.661437000000006	92.665390000000002	56.170932000000001	56.165433999999998	СПТУ-81	0103000020E6100000010000000500000052D7DAFB542A5740BFD2F9F02C154C4052D7DAFB542A574081EB8A19E1154C407845F0BF952A574081EB8A19E1154C407845F0BF952A5740BFD2F9F02C154C4052D7DAFB542A5740BFD2F9F02C154C40
72610	1330	92.685170999999997	92.692366000000007	56.163193	56.160902	Новая	0103000020E61000000100000005000000BA4A77D7D92B574035EECD6F98144C40BA4A77D7D92B5740D3F71A82E3144C4031B77BB94F2C5740D3F71A82E3144C4031B77BB94F2C574035EECD6F98144C40BA4A77D7D92B574035EECD6F98144C40
72556	1330	92.616682999999995	92.728765999999993	56.180432000000003	56.155523000000002	Московская	0103000020E61000000100000005000000F23FF9BB772757404E637B2DE8134C40F23FF9BB772757407193516518174C40F31B261AA42E57407193516518174C40F31B261AA42E57404E637B2DE8134C40F23FF9BB772757404E637B2DE8134C40
72313	1330	92.652140000000003	92.717545999999999	56.171523000000001	56.160671999999998	Декабристов	0103000020E61000000100000005000000761A69A9BC29574003B16CE690144C40761A69A9BC29574083C13577F4154C400AD80E46EC2D574083C13577F4154C400AD80E46EC2D574003B16CE690144C40761A69A9BC29574003B16CE690144C40
28127	1330	92.616682999999995	92.728765999999993	56.180432000000003	56.155523000000002	 Московская	0103000020E61000000100000005000000F23FF9BB772757404E637B2DE8134C40F23FF9BB772757407193516518174C40F31B261AA42E57407193516518174C40F31B261AA42E57404E637B2DE8134C40F23FF9BB772757404E637B2DE8134C40
72684	25495	92.737523999999993	92.754745	56.120277000000002	56.089885000000002	Московская	0103000020E61000000100000005000000F700DD97332F574053B3075A810B4C40F700DD97332F574002BB9A3C650F4C4073F4F8BD4D30574002BB9A3C650F4C4073F4F8BD4D30574053B3075A810B4C40F700DD97332F574053B3075A810B4C40
27753	51734	90.536697000000004	90.541484999999994	56.304884999999999	56.304474999999996	Новоселов	0103000020E6100000010000000500000020B75F3E59A256408CB96B09F9264C4020B75F3E59A256403E05C07806274C409291B3B0A7A256403E05C07806274C409291B3B0A7A256408CB96B09F9264C4020B75F3E59A256408CB96B09F9264C40
72106	17601	92.359279999999998	92.387882000000005	55.962332000000004	55.952852999999998	Чкалова	0103000020E61000000100000005000000D7868A71FE1657409F724C16F7F94B40D7868A71FE16574078F2E9B12DFB4B40412D060FD318574078F2E9B12DFB4B40412D060FD31857409F724C16F7F94B40D7868A71FE1657409F724C16F7F94B40
72104	17601	92.388070999999997	92.388349000000005	55.954667000000001	55.953023999999999	Спортивная	0103000020E61000000100000005000000AA61BF27D6185740CC26C0B0FCF94B40AA61BF27D618574004C93B8732FA4B40CC9BC3B5DA18574004C93B8732FA4B40CC9BC3B5DA185740CC26C0B0FCF94B40AA61BF27D6185740CC26C0B0FCF94B40
72071	17601	92.371325999999996	92.381342000000004	55.954656999999997	55.948120000000003	Саянская	0103000020E61000000100000005000000E38920CEC31757407E5704FF5BF94B40E38920CEC3175740E0F2583332FA4B40D7A546E867185740E0F2583332FA4B40D7A546E8671857407E5704FF5BF94B40E38920CEC31757407E5704FF5BF94B40
72524	17601	92.367311000000001	92.373373999999998	55.965617000000002	55.965440999999998	Парковая	0103000020E61000000100000005000000821DFF0582175740D89B189293FB4B40821DFF058217574017BB7D5699FB4B404FCB0F5CE517574017BB7D5699FB4B404FCB0F5CE5175740D89B189293FB4B40821DFF0582175740D89B189293FB4B40
72110	17601	92.364857999999998	92.392086000000006	55.967748	55.964714999999998	Набережная	0103000020E61000000100000005000000C66B5ED559175740F67AF7C77BFB4B40C66B5ED5591757407C629D2ADFFB4B400CCEE0EF171957407C629D2ADFFB4B400CCEE0EF17195740F67AF7C77BFB4B40C66B5ED559175740F67AF7C77BFB4B40
72390	17601	92.368307999999999	92.390128000000004	55.962730000000001	55.962246	Комсомольская	0103000020E61000000100000005000000BBB6B75B92175740795A7EE02AFB4B40BBB6B75B92175740657094BC3AFB4B4040506EDBF7185740657094BC3AFB4B4040506EDBF7185740795A7EE02AFB4B40BBB6B75B92175740795A7EE02AFB4B40
72389	17601	92.358462000000003	92.383966000000001	55.962201	55.957498999999999	Бочкина	0103000020E61000000100000005000000F6B6990AF1165740F279C5538FFA4B40F6B6990AF1165740D996016729FB4B40A93121E692185740D996016729FB4B40A93121E692185740F279C5538FFA4B40F6B6990AF1165740F279C5538FFA4B40
72388	17601	92.365630999999993	92.384280000000004	55.963526000000002	55.959470000000003	Б.Полевого	0103000020E61000000100000005000000D7D9907F661757401FBFB7E9CFFA4B40D7D9907F66175740406CE9D154FB4B407120240B98185740406CE9D154FB4B407120240B981857401FBFB7E9CFFA4B40D7D9907F661757401FBFB7E9CFFA4B40
73000	59752	90.493433999999993	90.509720999999999	56.309144000000003	56.306821999999997	Северная	0103000020E61000000100000005000000012F336C949F5640BED87BF145274C40012F336C949F564098E0D40792274C406745D4449FA0564098E0D40792274C406745D4449FA05640BED87BF145274C40012F336C949F5640BED87BF145274C40
28641	10919	90.535978	90.571183000000005	56.253222000000001	56.233404	Центральная	0103000020E610000001000000050000000858AB764DA25640B760A92EE01D4C400858AB764DA256405950189469204C40FF4124438EA456405950189469204C40FF4124438EA45640B760A92EE01D4C400858AB764DA25640B760A92EE01D4C40
28526	51889	92.571703999999997	92.590164999999999	56.571848000000003	56.563997999999998	Первомайский	0103000020E6100000010000000500000083BF5FCC962457403481221631484C4083BF5FCC962457403A24B55032494C409B8F6B43C52557403A24B55032494C409B8F6B43C52557403481221631484C4083BF5FCC962457403481221631484C40
72857	8248	93.242512000000005	93.298370000000006	56.031387000000002	55.990352999999999	Центральная	0103000020E61000000100000005000000CE380D51854F57406C3F19E3C3FE4B40CE380D51854F574081423D7D04044C40E2067C7E1853574081423D7D04044C40E2067C7E185357406C3F19E3C3FE4B40CE380D51854F57406C3F19E3C3FE4B40
28214	8248	93.242512000000005	93.298370000000006	56.031387000000002	55.990352999999999	Советская	0103000020E61000000100000005000000CE380D51854F57406C3F19E3C3FE4B40CE380D51854F574081423D7D04044C40E2067C7E1853574081423D7D04044C40E2067C7E185357406C3F19E3C3FE4B40CE380D51854F57406C3F19E3C3FE4B40
72527	59617	92.493120000000005	92.499336	58.231499999999997	58.228700000000003	Геофизиков	0103000020E610000001000000050000003A4030478F1F5740304CA60A461D4D403A4030478F1F57401283C0CAA11D4D40CA6DFB1EF51F57401283C0CAA11D4D40CA6DFB1EF51F5740304CA60A461D4D403A4030478F1F5740304CA60A461D4D40
71692	59496	93.152608999999998	93.162678999999997	55.973934	55.946955000000003	Советская	0103000020E61000000100000005000000D1048A58C449574050E449D235F94B40D1048A58C4495740323B8BDEA9FC4B40BE2F2E55694A5740323B8BDEA9FC4B40BE2F2E55694A574050E449D235F94B40D1048A58C449574050E449D235F94B40
72576	59625	93.152608999999998	93.162678999999997	55.973934	55.946955000000003	Советская	0103000020E61000000100000005000000D1048A58C449574050E449D235F94B40D1048A58C4495740323B8BDEA9FC4B40BE2F2E55694A5740323B8BDEA9FC4B40BE2F2E55694A574050E449D235F94B40D1048A58C449574050E449D235F94B40
28479	25325	92.625495999999998	92.702552999999995	56.057574000000002	56.033304000000001	Заречная	0103000020E61000000100000005000000D8F15F2008285740BA69334E43044C40D8F15F2008285740CA8CB7955E074C403AADDBA0F62C5740CA8CB7955E074C403AADDBA0F62C5740BA69334E43044C40D8F15F2008285740BA69334E43044C40
28414	17249	94.868858000000003	94.935081999999994	55.920805000000001	55.893667000000001	мкр. Стахановский	0103000020E610000001000000050000008DB7955E9BB75740D94125AE63F24B408DB7955E9BB75740247F30F0DCF54B4002452C62D8BB5740247F30F0DCF54B4002452C62D8BB5740D94125AE63F24B408DB7955E9BB75740D94125AE63F24B40
71489	17249	94.868858000000003	94.935081999999994	55.920805000000001	55.893667000000001	Советская	0103000020E610000001000000050000008DB7955E9BB75740D94125AE63F24B408DB7955E9BB75740247F30F0DCF54B4002452C62D8BB5740247F30F0DCF54B4002452C62D8BB5740D94125AE63F24B408DB7955E9BB75740D94125AE63F24B40
27862	17249	94.868858000000003	94.935081999999994	55.920805000000001	55.893667000000001	Октябрьская	0103000020E610000001000000050000008DB7955E9BB75740D94125AE63F24B408DB7955E9BB75740247F30F0DCF54B4002452C62D8BB5740247F30F0DCF54B4002452C62D8BB5740D94125AE63F24B408DB7955E9BB75740D94125AE63F24B40
28060	17249	94.868858000000003	94.935081999999994	55.920805000000001	55.893667000000001	Маяковского	0103000020E610000001000000050000008DB7955E9BB75740D94125AE63F24B408DB7955E9BB75740247F30F0DCF54B4002452C62D8BB5740247F30F0DCF54B4002452C62D8BB5740D94125AE63F24B408DB7955E9BB75740D94125AE63F24B40
71533	17249	94.868858000000003	94.935081999999994	55.920805000000001	55.893667000000001	Ленина	0103000020E610000001000000050000008DB7955E9BB75740D94125AE63F24B408DB7955E9BB75740247F30F0DCF54B4002452C62D8BB5740247F30F0DCF54B4002452C62D8BB5740D94125AE63F24B408DB7955E9BB75740D94125AE63F24B40
28208	17249	94.868858000000003	94.935081999999994	55.920805000000001	55.893667000000001	 9 Мая	0103000020E610000001000000050000008DB7955E9BB75740D94125AE63F24B408DB7955E9BB75740247F30F0DCF54B4002452C62D8BB5740247F30F0DCF54B4002452C62D8BB5740D94125AE63F24B408DB7955E9BB75740D94125AE63F24B40
27776	29937	93.430530000000005	93.466301000000001	56.403094000000003	56.387644000000002	Космонавтов	0103000020E610000001000000050000009A7CB3CD8D5B5740CD3E8F519E314C409A7CB3CD8D5B57405F9B8D9598334C40E54526E0D75D57405F9B8D9598334C40E54526E0D75D5740CD3E8F519E314C409A7CB3CD8D5B5740CD3E8F519E314C40
73213	59867	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Школьная	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73142	59867	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Урицкого	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73204	59867	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	40 лет Октября	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73220	59886	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Северная 	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73243	59886	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Деповская	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73335	59886	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	40 лет Октября	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
72092	1148	93.12424	93.143482000000006	56.043512	56.043191	Центральная	0103000020E61000000100000005000000B936548CF3475740A33D5E4887054C40B936548CF3475740E57D1CCD91054C40246420CF2E495740E57D1CCD91054C40246420CF2E495740A33D5E4887054C40B936548CF3475740A33D5E4887054C40
72486	1148	93.062544000000003	93.111070999999995	56.027071999999997	56.024611999999998	Солнечная	0103000020E61000000100000005000000E8A38CB800445740698B6B7C26034C40E8A38CB8004457409351651877034C402D228AC91B4757409351651877034C402D228AC91B475740698B6B7C26034C40E8A38CB800445740698B6B7C26034C40
72482	1148	93.128084999999999	93.145116999999999	56.045242000000002	56.044849999999997	Советская	0103000020E61000000100000005000000EC866D8B32485740E09C11A5BD054C40EC866D8B32485740EC33677DCA054C40FE45D09849495740EC33677DCA054C40FE45D09849495740E09C11A5BD054C40EC866D8B32485740E09C11A5BD054C40
72997	1148	93.128192999999996	93.129521999999994	56.036456999999999	56.031678999999997	Мира	0103000020E61000000100000005000000DFA4695034485740287CB60E0E044C40DFA4695034485740EA5A7B9FAA044C403387A4164A485740EA5A7B9FAA044C403387A4164A485740287CB60E0E044C40DFA4695034485740287CB60E0E044C40
71727	1148	93.124230999999995	93.128147999999996	56.046166999999997	56.022644999999997	Кирова	0103000020E610000001000000050000008F899466F34757407E350708E6024C408F899466F3475740C493DDCCE8054C400F43AB9333485740C493DDCCE8054C400F43AB93334857407E350708E6024C408F899466F34757407E350708E6024C40
72083	1148	93.113253999999998	93.116828999999996	56.041828000000002	56.027172	Заводская	0103000020E610000001000000050000000989B48D3F475740F7AE415F7A034C400989B48D3F4757404F07B29E5A054C405C8E57207A4757404F07B29E5A054C405C8E57207A475740F7AE415F7A034C400989B48D3F475740F7AE415F7A034C40
72181	1148	93.100040000000007	93.15437	56.039942000000003	56.037019999999998	Дружбы	0103000020E61000000100000005000000AE122C0E6746574022A64412BD044C40AE122C0E6746574051DEC7D11C054C40F25EB532E149574051DEC7D11C054C40F25EB532E149574022A64412BD044C40AE122C0E6746574022A64412BD044C40
72999	1148	93.115651999999997	93.116551000000001	56.022191999999997	56.017367	 2-ая Новая	0103000020E61000000100000005000000E36DA5D766475740CB83F41439024C40E36DA5D766475740CD1DFD2FD7024C403B54539275475740CD1DFD2FD7024C403B54539275475740CB83F41439024C40E36DA5D766475740CB83F41439024C40
27845	48664	95.626129000000006	95.644248000000005	56.237957000000002	56.227445000000003	Новая	0103000020E61000000100000005000000F1845E7F12E85740C251F2EA1C1D4C40F1845E7F12E85740596DFE5F751E4C40DCA0F65B3BE95740596DFE5F751E4C40DCA0F65B3BE95740C251F2EA1C1D4C40F1845E7F12E85740C251F2EA1C1D4C40
71635	13618	93.356696999999997	93.362634999999997	56.044553000000001	56.037081000000001	Ленина	0103000020E610000001000000050000003465A71FD4565740C826F911BF044C403465A71FD456574027F8A6E9B3054C40A3586E693557574027F8A6E9B3054C40A3586E6935575740C826F911BF044C403465A71FD4565740C826F911BF044C40
72591	59628	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	Мудрова	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
28550	51896	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Увачана	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
72550	51896	92.857125999999994	92.888208000000006	56.027498999999999	56.026508	Гагарина	0103000020E6100000010000000500000048A30227DB3657408B8A389D64034C4048A30227DB3657401BD6541685034C40EB025E66D83857401BD6541685034C40EB025E66D83857408B8A389D64034C4048A30227DB3657408B8A389D64034C40
72381	3300	90.483885000000001	90.493937000000003	56.270905999999997	56.266236999999997	микрорайон 8	0103000020E610000001000000050000009981CAF8F79E564019FED30D14224C409981CAF8F79E564024253D0CAD224C403352EFA99C9F564024253D0CAD224C403352EFA99C9F564019FED30D14224C409981CAF8F79E564019FED30D14224C40
72096	3300	90.489301999999995	90.498733999999999	56.268915999999997	56.263612000000002	микрорайон 7	0103000020E6100000010000000500000083F755B9509F5640A56ABB09BE214C4083F755B9509F564081AFE8D66B224C40CFD90242EB9F564081AFE8D66B224C40CFD90242EB9F5640A56ABB09BE214C4083F755B9509F5640A56ABB09BE214C40
72373	3300	90.483148	90.496775999999997	56.258018	56.252132000000003	микрорайон 4	0103000020E610000001000000050000002EC896E5EB9E5640362383DC45204C402EC896E5EB9E5640C1E3DBBB06214C40035C902DCB9F5640C1E3DBBB06214C40035C902DCB9F5640362383DC45204C402EC896E5EB9E5640362383DC45204C40
72095	3300	90.486355000000003	90.502633000000003	56.263401999999999	56.255828000000001	микрорайон 3	0103000020E61000000100000005000000C0CFB870209F564057B3CEF8BE204C40C0CFB870209F5640BAD91F28B7214C40FC389A232BA05640BAD91F28B7214C40FC389A232BA0564057B3CEF8BE204C40C0CFB870209F564057B3CEF8BE204C40
72382	3300	90.483580000000003	90.494314000000003	56.266106999999998	56.259932999999997	микрорайон 1	0103000020E61000000100000005000000FB3F87F9F29E564059130B7C45214C40FB3F87F9F29E56404B1E4FCB0F224C401EFD2FD7A29F56404B1E4FCB0F224C401EFD2FD7A29F564059130B7C45214C40FB3F87F9F29E564059130B7C45214C40
28035	3300	90.496848	90.511086000000006	56.259408000000001	56.252766999999999	Юго-Восточный микрорайон	0103000020E6100000010000000500000050C58D5BCC9F5640074147AB5A204C4050C58D5BCC9F56400F29064834214C4062DC0DA2B5A056400F29064834214C4062DC0DA2B5A05640074147AB5A204C4050C58D5BCC9F5640074147AB5A204C40
27850	3300	90.303836000000004	90.601096999999996	56.336078999999998	56.189749999999997	Чернявского	0103000020E610000001000000050000003DD68C0C729356403F355EBA49184C403DD68C0C72935640AAEFFCA2042B4C40512E8D5F78A65640AAEFFCA2042B4C40512E8D5F78A656403F355EBA49184C403DD68C0C729356403F355EBA49184C40
72386	3300	90.515416000000002	90.528144999999995	56.244005000000001	56.243715000000002	Чайковского	0103000020E6100000010000000500000073F56393FCA05640B745990D321F4C4073F56393FCA05640BE874B8E3B1F4C40F0A2AF20CDA15640BE874B8E3B1F4C40F0A2AF20CDA15640B745990D321F4C4073F56393FCA05640B745990D321F4C40
72722	3300	90.513340999999997	90.517356000000007	56.279426999999998	56.276319000000001	Трудовых Резервов	0103000020E610000001000000050000008AAC3594DAA05640B821C66B5E234C408AAC3594DAA05640484F9143C4234C40EC18575C1CA15640484F9143C4234C40EC18575C1CA15640B821C66B5E234C408AAC3594DAA05640B821C66B5E234C40
72223	3300	90.478262000000001	90.501707999999994	56.274234999999997	56.259132999999999	Свердлова	0103000020E61000000100000005000000DA3A38D89B9E56403D2828452B214C40DA3A38D89B9E56409335EA211A234C400F09DFFB1BA056409335EA211A234C400F09DFFB1BA056403D2828452B214C40DA3A38D89B9E56403D2828452B214C40
72221	3300	90.499525000000006	90.50018	56.250432000000004	56.247401000000004	Республики	0103000020E6100000010000000500000034A2B437F89F5640B5FF01D6AA1F4C4034A2B437F89F56409AEFE0270E204C404087F9F202A056409AEFE0270E204C404087F9F202A05640B5FF01D6AA1F4C4034A2B437F89F5640B5FF01D6AA1F4C40
72099	3300	90.498761000000002	90.507537999999997	56.282499999999999	56.275114000000002	Партизанская	0103000020E610000001000000050000004CE141B3EB9F5640FC5580EF36234C404CE141B3EB9F56405C8FC2F528244C408BDEA9807BA056405C8FC2F528244C408BDEA9807BA05640FC5580EF36234C404CE141B3EB9F5640FC5580EF36234C40
72385	3300	90.517652999999996	90.533462999999998	56.283504999999998	56.281320999999998	Омская	0103000020E61000000100000005000000486B0C3A21A15640C956975302244C40486B0C3A21A1564051A04FE449244C4011A8FE4124A2564051A04FE449244C4011A8FE4124A25640C956975302244C40486B0C3A21A15640C956975302244C40
72220	3300	90.501366000000004	90.506460000000004	56.297407999999997	56.283873999999997	Льва Толстого	0103000020E61000000100000005000000E3546B6116A05640A417B5FB55244C40E3546B6116A05640CDC8207711264C40DC2E34D769A05640CDC8207711264C40DC2E34D769A05640A417B5FB55244C40E3546B6116A05640A417B5FB55244C40
72101	3300	90.445823000000004	90.506675000000001	56.271644999999999	56.238847	Кравченко	0103000020E610000001000000050000007F33315D889C5640B5DFDA89921E4C407F33315D889C56409B8F6B43C5224C40DAACFA5C6DA056409B8F6B43C5224C40DAACFA5C6DA05640B5DFDA89921E4C407F33315D889C5640B5DFDA89921E4C40
72093	3300	90.499003999999999	90.507492999999997	56.278947000000002	56.276018999999998	Комсомольская	0103000020E61000000100000005000000AF2479AEEF9F56408D09319754234C40AF2479AEEF9F56409E280989B4234C40BB7CEBC37AA056409E280989B4234C40BB7CEBC37AA056408D09319754234C40AF2479AEEF9F56408D09319754234C40
72219	3300	90.502786	90.544297	56.306652999999997	56.297407999999997	Кирова	0103000020E61000000100000005000000BFB854A52DA05640CDC8207711264C40BFB854A52DA05640321CCF6740274C40E69315C3D5A25640321CCF6740274C40E69315C3D5A25640CDC8207711264C40BFB854A52DA05640CDC8207711264C40
72222	3300	90.465101000000004	90.479573000000002	56.248676000000003	56.248336000000002	Калинина	0103000020E610000001000000050000009015FC36C49D5640B1355B79C91F4C409015FC36C49D56406AA67B9DD41F4C40DBC2F352B19E56406AA67B9DD41F4C40DBC2F352B19E5640B1355B79C91F4C409015FC36C49D5640B1355B79C91F4C40
72218	3300	90.523814999999999	90.537101000000007	56.301574000000002	56.295960000000001	Дружбы Народов	0103000020E61000000100000005000000DF89592F86A156404B766C04E2254C40DF89592F86A1564076A911FA99264C408869DFDC5FA2564076A911FA99264C408869DFDC5FA256404B766C04E2254C40DF89592F86A156404B766C04E2254C40
72387	3300	90.472800000000007	90.473662000000004	56.253476999999997	56.240032999999997	Декабристов	0103000020E610000001000000050000002063EE5A429E5640FA7ABE66B91E4C402063EE5A429E5640E3A430EF71204C40E9D66B7A509E5640E3A430EF71204C40E9D66B7A509E5640FA7ABE66B91E4C402063EE5A429E5640FA7ABE66B91E4C40
72081	3300	90.478871999999996	90.479843000000002	56.259518	56.244799999999998	Гагарина	0103000020E6100000010000000500000016BEBED6A59E5640C8073D9B551F4C4016BEBED6A59E5640965CC5E237214C40BB0D6ABFB59E5640965CC5E237214C40BB0D6ABFB59E5640C8073D9B551F4C4016BEBED6A59E5640C8073D9B551F4C40
72705	3300	90.505354999999994	90.511229999999998	56.310662000000001	56.306202999999996	Береговая	0103000020E61000000100000005000000AF777FBC57A05640F277EFA831274C40AF777FBC57A05640130EBDC5C3274C40FBAE08FEB7A05640130EBDC5C3274C40FBAE08FEB7A05640F277EFA831274C40AF777FBC57A05640F277EFA831274C40
72536	3300	90.479321999999996	90.490937000000002	56.255837999999997	56.245195000000002	5-ый микрорайон	0103000020E6100000010000000500000036902E36AD9E56404512BD8C621F4C4036902E36AD9E56407A89B14CBF204C405ED905836B9F56407A89B14CBF204C405ED905836B9F56404512BD8C621F4C4036902E36AD9E56404512BD8C621F4C40
72565	3300	90.483148	90.496775999999997	56.258018	56.252132000000003	4-ый микрорайон	0103000020E610000001000000050000002EC896E5EB9E5640362383DC45204C402EC896E5EB9E5640C1E3DBBB06214C40035C902DCB9F5640C1E3DBBB06214C40035C902DCB9F5640362383DC45204C402EC896E5EB9E5640362383DC45204C40
72549	3300	90.486355000000003	90.502633000000003	56.263401999999999	56.255828000000001	3-ий микрорайон	0103000020E61000000100000005000000C0CFB870209F564057B3CEF8BE204C40C0CFB870209F5640BAD91F28B7214C40FC389A232BA05640BAD91F28B7214C40FC389A232BA0564057B3CEF8BE204C40C0CFB870209F564057B3CEF8BE204C40
71486	3300	90.486355000000003	90.502633000000003	56.263401999999999	56.255828000000001	3 микрорайон 	0103000020E61000000100000005000000C0CFB870209F564057B3CEF8BE204C40C0CFB870209F5640BAD91F28B7214C40FC389A232BA05640BAD91F28B7214C40FC389A232BA0564057B3CEF8BE204C40C0CFB870209F564057B3CEF8BE204C40
28173	3300	90.486355000000003	90.502633000000003	56.263401999999999	56.255828000000001	3 микрорайон	0103000020E61000000100000005000000C0CFB870209F564057B3CEF8BE204C40C0CFB870209F5640BAD91F28B7214C40FC389A232BA05640BAD91F28B7214C40FC389A232BA0564057B3CEF8BE204C40C0CFB870209F564057B3CEF8BE204C40
72102	3300	90.486355000000003	90.502633000000003	56.263401999999999	56.255828000000001	3 микрорайон	0103000020E61000000100000005000000C0CFB870209F564057B3CEF8BE204C40C0CFB870209F5640BAD91F28B7214C40FC389A232BA05640BAD91F28B7214C40FC389A232BA0564057B3CEF8BE204C40C0CFB870209F564057B3CEF8BE204C40
28518	3300	90.496848	90.511086000000006	56.259408000000001	56.252766999999999	2-ой микрорайон	0103000020E6100000010000000500000050C58D5BCC9F5640074147AB5A204C4050C58D5BCC9F56400F29064834214C4062DC0DA2B5A056400F29064834214C4062DC0DA2B5A05640074147AB5A204C4050C58D5BCC9F5640074147AB5A204C40
72626	59643	93.413811999999993	93.457165000000003	54.364609000000002	54.329546000000001	Ольховская	0103000020E610000001000000050000004FAC53E57B5A5740894336902E2A4B404FAC53E57B5A5740E469F981AB2E4B400EF8FC30425D5740E469F981AB2E4B400EF8FC30425D5740894336902E2A4B404FAC53E57B5A5740894336902E2A4B40
28097	4815	95.502843999999996	95.558441000000002	56.265296999999997	56.249080999999997	Советская	0103000020E6100000010000000500000059BF99982EE057400987DEE2E11F4C4059BF99982EE057400B5D8940F5214C40B7EF517FBDE357400B5D8940F5214C40B7EF517FBDE357400987DEE2E11F4C4059BF99982EE057400987DEE2E11F4C40
73126	59857	93.427395000000004	93.434545	56.123925	56.123227	Лесная	0103000020E6100000010000000500000055DE8E705A5B5740FA7DFFE6C50F4C4055DE8E705A5B574012143FC6DC0F4C40FBE8D495CF5B574012143FC6DC0F4C40FBE8D495CF5B5740FA7DFFE6C50F4C4055DE8E705A5B5740FA7DFFE6C50F4C40
28499	51883	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Максима Ялогира	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
73080	59817	95.754570000000001	95.754579000000007	56.220188	56.218465999999999	Таежная	0103000020E61000000100000005000000BC22F8DF4AF05740DBA4A2B1F61B4C40BC22F8DF4AF057405F7CD11E2F1C4C40E6CFB7054BF057405F7CD11E2F1C4C40E6CFB7054BF05740DBA4A2B1F61B4C40BC22F8DF4AF05740DBA4A2B1F61B4C40
73344	59911	95.692119000000005	95.726651000000004	56.216934999999999	56.206316999999999	Набережная	0103000020E610000001000000050000002D7C7DAD4BEC5740EECD6F98681A4C402D7C7DAD4BEC5740CB2DAD86C41B4C40C426327381EE5740CB2DAD86C41B4C40C426327381EE5740EECD6F98681A4C402D7C7DAD4BEC5740EECD6F98681A4C40
73083	59820	93.110909000000007	93.113371000000001	56.026926000000003	56.022348000000001	Нефтяников	0103000020E6100000010000000500000041F50F2219475740C5909C4CDC024C4041F50F2219475740C0B4A84F72034C402654707841475740C0B4A84F72034C402654707841475740C5909C4CDC024C4041F50F2219475740C5909C4CDC024C40
27857	51754	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	Бояки	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
28235	51831	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	70 лет Октября	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
73122	59854	93.427395000000004	93.434545	56.123925	56.123227	Лесная	0103000020E6100000010000000500000055DE8E705A5B5740FA7DFFE6C50F4C4055DE8E705A5B574012143FC6DC0F4C40FBE8D495CF5B574012143FC6DC0F4C40FBE8D495CF5B5740FA7DFFE6C50F4C4055DE8E705A5B5740FA7DFFE6C50F4C40
73056	59797	93.337373999999997	93.350526000000002	56.122334000000002	56.113446000000003	Солнечная	0103000020E6100000010000000500000053211E899755574057EE0566850E4C4053211E89975557402D98F8A3A80F4C4074999A046F5657402D98F8A3A80F4C4074999A046F56574057EE0566850E4C4053211E899755574057EE0566850E4C40
72822	59717	92.977303000000006	93.011232000000007	55.994557	55.986863	Спортивная	0103000020E6100000010000000500000018D2E1218C3E5740F450DB8651FE4B4018D2E1218C3E57400281CEA44DFF4B40CC2A6C06B84057400281CEA44DFF4B40CC2A6C06B8405740F450DB8651FE4B4018D2E1218C3E5740F450DB8651FE4B40
73153	59872	95.754570000000001	95.754579000000007	56.220188	56.218465999999999	Таежная	0103000020E61000000100000005000000BC22F8DF4AF05740DBA4A2B1F61B4C40BC22F8DF4AF057405F7CD11E2F1C4C40E6CFB7054BF057405F7CD11E2F1C4C40E6CFB7054BF05740DBA4A2B1F61B4C40BC22F8DF4AF05740DBA4A2B1F61B4C40
73175	59640	92.981048999999999	92.985522000000003	56.169663999999997	56.159588999999997	Центральная	0103000020E6100000010000000500000081B1BE81C93E574092E68F696D144C4081B1BE81C93E57407EA7C98CB7154C4044DFDDCA123F57407EA7C98CB7154C4044DFDDCA123F574092E68F696D144C4081B1BE81C93E574092E68F696D144C40
73315	8427	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	Тельмана	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73310	8427	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	Первомайская	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73168	59878	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	квартал Строителей	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73288	59878	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	квартал СХТ	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73269	59878	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	Полукольцевая	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73320	59878	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	Победы	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73330	59878	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	Новая	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73292	59878	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	2 микрорайон	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73230	59878	91.905225999999999	91.982570999999993	53.358690000000003	53.301439000000002	1 микрорайон	0103000020E610000001000000050000004A5F0839EFF95640965E9B8D95A64A404A5F0839EFF956407DB3CD8DE9AD4A40DFBF7971E2FE56407DB3CD8DE9AD4A40DFBF7971E2FE5640965E9B8D95A64A404A5F0839EFF95640965E9B8D95A64A40
73190	32605	91.579228000000001	91.601433999999998	53.131276999999997	53.122976999999999	Победы	0103000020E610000001000000050000005C3B511212E556408194D8B5BD8F4A405C3B511212E55640C6DB4AAFCD904A40F52C08E57DE65640C6DB4AAFCD904A40F52C08E57DE656408194D8B5BD8F4A405C3B511212E556408194D8B5BD8F4A40
73231	32612	91.621988000000002	91.636827999999994	53.106437999999997	53.089297999999999	Большая	0103000020E6100000010000000500000049A0C1A6CEE7564092CCEA1D6E8B4A4049A0C1A6CEE756409C86A8C29F8D4A40554B3ACAC1E856409C86A8C29F8D4A40554B3ACAC1E8564092CCEA1D6E8B4A4049A0C1A6CEE7564092CCEA1D6E8B4A40
73146	32640	91.905478000000002	91.936892	53.090201	53.056361000000003	Ленина	0103000020E61000000100000005000000D74FFF59F3F956408BE255D636874A40D74FFF59F3F956408388D4B48B8B4A4094F8DC09F6FB56408388D4B48B8B4A4094F8DC09F6FB56408BE255D636874A40D74FFF59F3F956408BE255D636874A40
73203	32652	91.953654999999998	91.985042000000007	53.044992999999998	53.032296000000002	Ленина	0103000020E61000000100000005000000AE2AFBAE08FD564054E57B4622844A40AE2AFBAE08FD564043C6A354C2854A40EFCB99ED0AFF564043C6A354C2854A40EFCB99ED0AFF564054E57B4622844A40AE2AFBAE08FD564054E57B4622844A40
73240	32717	92.083783999999994	92.112449999999995	53.490031999999999	53.479064000000001	Ленина	0103000020E6100000010000000500000065FB90B75C05574071581AF851BD4A4065FB90B75C0557402AFF5A5EB9BE4A40DA1B7C61320757402AFF5A5EB9BE4A40DA1B7C613207574071581AF851BD4A4065FB90B75C05574071581AF851BD4A40
73251	32634	91.497372999999996	91.540546000000006	53.011333999999998	52.987563999999999	Ленина	0103000020E61000000100000005000000753A90F5D4DF56407D5A457F687E4A40753A90F5D4DF56409BAA7B6473814A40F4FE3F4E98E256409BAA7B6473814A40F4FE3F4E98E256407D5A457F687E4A40753A90F5D4DF56407D5A457F687E4A40
73248	32617	91.473622000000006	91.486206999999993	53.143009999999997	53.135058999999998	Малая	0103000020E61000000100000005000000A22AA6D24FDE5640E603029D49914A40A22AA6D24FDE56401F80D4264E924A408505F7031EDF56401F80D4264E924A408505F7031EDF5640E603029D49914A40A22AA6D24FDE5640E603029D49914A40
27824	32619	91.681025000000005	91.707111999999995	53.150382	53.139206999999999	Шинкарева	0103000020E610000001000000050000008AB0E1E995EB5640E82FF488D1914A408AB0E1E995EB56401BF4A5B73F934A40FCA6B05241ED56401BF4A5B73F934A40FCA6B05241ED5640E82FF488D1914A408AB0E1E995EB5640E82FF488D1914A40
73233	32619	91.681025000000005	91.707111999999995	53.150382	53.139206999999999	Большая	0103000020E610000001000000050000008AB0E1E995EB5640E82FF488D1914A408AB0E1E995EB56401BF4A5B73F934A40FCA6B05241ED56401BF4A5B73F934A40FCA6B05241ED5640E82FF488D1914A408AB0E1E995EB5640E82FF488D1914A40
73229	32684	91.909188	91.935445999999999	53.459687000000002	53.451515999999998	Центральная	0103000020E610000001000000050000009A7ADD2230FA564074CFBA46CBB94A409A7ADD2230FA5640BCB20B06D7BA4A40234BE658DEFB5640BCB20B06D7BA4A40234BE658DEFB564074CFBA46CBB94A409A7ADD2230FA564074CFBA46CBB94A40
73179	32645	91.852935000000002	91.887512000000001	53.036400999999998	53.029744999999998	Центральная	0103000020E6100000010000000500000048A7AE7C96F65640191C25AFCE834A4048A7AE7C96F656405645B8C9A8844A40AFB321FFCCF856405645B8C9A8844A40AFB321FFCCF85640191C25AFCE834A4048A7AE7C96F65640191C25AFCE834A40
73191	32690	92.027783999999997	92.043009999999995	53.505614000000001	53.497686999999999	 Советская	0103000020E6100000010000000500000088D68A36C70157407A522635B4BF4A4088D68A36C70157402B33A5F5B7C04A40A9D903ADC00257402B33A5F5B7C04A40A9D903ADC00257407A522635B4BF4A4088D68A36C70157407A522635B4BF4A40
73236	32659	91.805899999999994	91.829238000000004	53.059229000000002	53.04148	Ленина	0103000020E610000001000000050000002BF697DD93F3564013B875374F854A402BF697DD93F35640C6FCDCD094874A406EA6423C12F55640C6FCDCD094874A406EA6423C12F5564013B875374F854A402BF697DD93F3564013B875374F854A40
73170	32693	92.047385000000006	92.058972999999995	53.397897	53.393188000000002	Центральная	0103000020E610000001000000050000008B54185B08035740FF9600FC53B24A408B54185B080357409816F549EEB24A403596B036C60357409816F549EEB24A403596B036C6035740FF9600FC53B24A408B54185B08035740FF9600FC53B24A40
73161	32599	91.777540000000002	91.819948999999994	53.211083000000002	53.184460999999999	Малая	0103000020E610000001000000050000003DD52137C3F156409831056B9C974A403DD52137C3F15640ECDE8AC4049B4A40D3D85E0B7AF45640ECDE8AC4049B4A40D3D85E0B7AF456409831056B9C974A403DD52137C3F156409831056B9C974A40
73307	59906	91.990224999999995	92.022994999999995	53.417473000000001	53.398305000000001	Ленина	0103000020E610000001000000050000009FABADD85FFF5640A96A82A8FBB24A409FABADD85FFF564044FB58C16FB54A402D3E05C07801574044FB58C16FB54A402D3E05C078015740A96A82A8FBB24A409FABADD85FFF5640A96A82A8FBB24A40
73215	32559	91.827225999999996	91.868898000000002	53.281556000000002	53.265110999999997	Кирова 	0103000020E61000000100000005000000A8195245F1F45640A9674128EFA14A40A8195245F1F456400DFFE9060AA44A40D4635B069CF756400DFFE9060AA44A40D4635B069CF75640A9674128EFA14A40A8195245F1F45640A9674128EFA14A40
73197	32630	91.954445000000007	91.987179999999995	53.190795999999999	53.173586999999998	Большая	0103000020E610000001000000050000002B357BA015FD564060014C1938964A402B357BA015FD5640931ADA006C984A40FAD005F52DFF5640931ADA006C984A40FAD005F52DFF564060014C1938964A402B357BA015FD564060014C1938964A40
73266	9006	91.965917000000005	91.986155999999994	53.248600000000003	53.240636000000002	Ленина	0103000020E61000000100000005000000A1698995D1FD5640C11E1329CD9E4A40A1698995D1FD56408FE4F21FD29F4A4044300E2E1DFF56408FE4F21FD29F4A4044300E2E1DFF5640C11E1329CD9E4A40A1698995D1FD5640C11E1329CD9E4A40
73242	32582	91.998157000000006	92.016419999999997	53.237779000000003	53.231419000000002	Центральная	0103000020E6100000010000000500000081D1E5CDE1FF5640265646239F9D4A4081D1E5CDE1FF56407A56D28A6F9E4A4005C078060D0157407A56D28A6F9E4A4005C078060D015740265646239F9D4A4081D1E5CDE1FF5640265646239F9D4A40
73258	32721	92.295795999999996	92.316349000000002	53.475645	53.458067999999997	Октябрьская	0103000020E6100000010000000500000068925852EE1257400CACE3F8A1BA4A4068925852EE125740C2C073EFE1BC4A40D447E00F3F145740C2C073EFE1BC4A40D447E00F3F1457400CACE3F8A1BA4A4068925852EE1257400CACE3F8A1BA4A40
73211	32733	92.359666000000004	92.371245000000002	53.450133000000001	53.447445999999999	Комсомольская	0103000020E61000000100000005000000ECDE8AC404175740EE5C18E945B94A40ECDE8AC404175740D9EC48F59DB94A406D73637AC2175740D9EC48F59DB94A406D73637AC2175740EE5C18E945B94A40ECDE8AC404175740EE5C18E945B94A40
73282	32670	91.732641999999998	91.747949000000006	53.103324000000001	53.078816000000003	Ленина	0103000020E61000000100000005000000446B459BE3EE5640663387A4168A4A40446B459BE3EE56402A7288B8398D4A40DC847B65DEEF56402A7288B8398D4A40DC847B65DEEF5640663387A4168A4A40446B459BE3EE5640663387A4168A4A40
73205	9090	91.881403000000006	91.892273000000003	53.244774	53.236545	Школьная	0103000020E610000001000000050000002AE620E868F856402384471B479E4A402AE620E868F856409F7422C1549F4A40A58636001BF956409F7422C1549F4A40A58636001BF956402384471B479E4A402AE620E868F856402384471B479E4A40
28032	7740	89.441399000000004	89.463255000000004	55.606878000000002	55.590674	Октябрьская	0103000020E610000001000000050000002D5F97E13F5C56407B4CA4349BCB4B402D5F97E13F5C5640B954A52DAECD4B4058AD4CF8A55D5640B954A52DAECD4B4058AD4CF8A55D56407B4CA4349BCB4B402D5F97E13F5C56407B4CA4349BCB4B40
71506	4113	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	переулок Школьный	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
28091	4113	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	Шахтерская	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
71543	4113	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	Северный микрорайон	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
27763	4113	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	Пионерный микрорайон	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
28225	4113	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	Комсомольская	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
71526	4113	89.132046000000003	89.228803999999997	55.562275999999997	55.513010000000001	Кирова	0103000020E6100000010000000500000054E4107173485640AF42CA4FAAC14B4054E4107173485640B0A9F3A8F8C74B406A4C88B9A44E5640B0A9F3A8F8C74B406A4C88B9A44E5640AF42CA4FAAC14B4054E4107173485640AF42CA4FAAC14B40
28471	7815	89.103480000000005	89.142368000000005	55.480587	55.441346000000003	Центральная	0103000020E6100000010000000500000091F2936A9F465640371C96067EB84B4091F2936A9F465640FEF0F3DF83BD4B40CEFFAB8E1C495640FEF0F3DF83BD4B40CEFFAB8E1C495640371C96067EB84B4091F2936A9F465640371C96067EB84B40
27781	8031	89.259589000000005	89.275362999999999	55.443480999999998	55.425123999999997	Калинина	0103000020E61000000100000005000000B0592E1B9D505640525F96766AB64B40B0592E1B9D505640DDB243FCC3B84B40D2E1218C9F515640DDB243FCC3B84B40D2E1218C9F515640525F96766AB64B40B0592E1B9D505640525F96766AB64B40
72939	20505	89.752601999999996	89.770847000000003	55.899467000000001	55.891430999999997	Советская	0103000020E61000000100000005000000DE3994A12A705640FED137691AF24B40DE3994A12A705640666A12BC21F34B4010CEA78E55715640666A12BC21F34B4010CEA78E55715640FED137691AF24B40DE3994A12A705640FED137691AF24B40
72980	7319	89.374250000000004	89.388155999999995	55.797038000000001	55.788707000000002	Школьная	0103000020E61000000100000005000000CBA145B6F35756402A90D959F4E44B40CBA145B6F3575640AAD5575705E64B40C16F438CD7585640AAD5575705E64B40C16F438CD75856402A90D959F4E44B40CBA145B6F35756402A90D959F4E44B40
28242	5698	89.213092000000003	89.230277000000001	55.252167999999998	55.244798000000003	Набережная	0103000020E6100000010000000500000083C2A04CA34D56402810768A559F4B4083C2A04CA34D5640828C800A47A04B405801BEDBBC4E5640828C800A47A04B405801BEDBBC4E56402810768A559F4B4083C2A04CA34D56402810768A559F4B40
72863	48226	89.331166999999994	89.349124000000003	55.692048999999997	55.689999	Центральная	0103000020E61000000100000005000000ECA012D731555640E8A221E351D84B40ECA012D731555640601DC70F95D84B40EB8F300C58565640601DC70F95D84B40EB8F300C58565640E8A221E351D84B40ECA012D731555640E8A221E351D84B40
72677	33057	89.190202999999997	89.208546999999996	55.650947000000002	55.629623000000002	Октябрьская	0103000020E61000000100000005000000782634492C4C56409BE7887C97D04B40782634492C4C5640F436363B52D34B40732B84D5584D5640F436363B52D34B40732B84D5584D56409BE7887C97D04B40782634492C4C56409BE7887C97D04B40
72648	8176	89.207207999999994	89.259777999999997	55.299219000000001	55.276589999999999	Советская	0103000020E610000001000000050000000DDE57E5424D56404833164D67A34B400DDE57E5424D5640C1ABE5CE4CA64B40198EE733A0505640C1ABE5CE4CA64B40198EE733A05056404833164D67A34B400DDE57E5424D56404833164D67A34B40
28467	8280	89.502843999999996	89.530125999999996	55.335991	55.313741	Центральная	0103000020E6100000010000000500000059BF99982E605640093543AA28A84B4059BF99982E6056400B60CAC001AB4B4098309A95ED6156400B60CAC001AB4B4098309A95ED615640093543AA28A84B4059BF99982E605640093543AA28A84B40
28469	7176	89.473827999999997	89.486512000000005	55.728985999999999	55.719920999999999	Советская	0103000020E6100000010000000500000076FBAC32535E5640105A0F5F26DC4B4076FBAC32535E5640F59ECA694FDD4B4024473A03235F5640F59ECA694FDD4B4024473A03235F5640105A0F5F26DC4B4076FBAC32535E5640105A0F5F26DC4B40
28492	51880	89.150560999999996	89.172191999999995	55.702094000000002	55.688445999999999	Октябрьская	0103000020E6100000010000000500000065C39ACAA2495640F0879FFF1ED84B4065C39ACAA2495640E25B5837DED94B4080289831054B5640E25B5837DED94B4080289831054B5640F0879FFF1ED84B4065C39ACAA2495640F0879FFF1ED84B40
72927	7803	89.566714000000005	89.608135000000004	55.511409	55.498111999999999	Центральная	0103000020E61000000100000005000000DD0BCC0A4564564061DF4E22C2BF4B40DD0BCC0A45645640A6F0A0D975C14B40642310AFEB665640A6F0A0D975C14B40642310AFEB66564061DF4E22C2BF4B40DD0BCC0A4564564061DF4E22C2BF4B40
72869	48427	89.073773000000003	89.089806999999993	55.392986000000001	55.372871000000004	Кирова	0103000020E61000000100000005000000FB9463B2B84456403C50A73CBAAF4B40FB9463B2B844564097E4805D4DB24B40EBFCDB65BF45564097E4805D4DB24B40EBFCDB65BF4556403C50A73CBAAF4B40FB9463B2B84456403C50A73CBAAF4B40
28454	48138	89.617568000000006	89.635587999999998	55.725442999999999	55.720529999999997	Центральная	0103000020E6100000010000000500000098C3EE3B86675640B8E4B8533ADC4B4098C3EE3B866756405A0EF450DBDC4B40B96E4A79AD6856405A0EF450DBDC4B40B96E4A79AD685640B8E4B8533ADC4B4098C3EE3B86675640B8E4B8533ADC4B40
72981	8258	89.208411999999996	89.221266999999997	55.381695000000001	55.369473999999997	Центральная	0103000020E610000001000000050000000306499F564D5640745C8DEC4AAF4B400306499F564D5640FB05BB61DBB04B40C72B103D294E5640FB05BB61DBB04B40C72B103D294E5640745C8DEC4AAF4B400306499F564D5640745C8DEC4AAF4B40
28497	7673	88.702219999999997	88.718200999999993	55.520252999999997	55.513209000000003	квартал Путейский	0103000020E6100000010000000500000037A6272CF12C5640A6811FD5B0C14B4037A6272CF12C5640AC527AA697C24B4016BD5301F72D5640AC527AA697C24B4016BD5301F72D5640A6811FD5B0C14B4037A6272CF12C5640A6811FD5B0C14B40
28113	7610	88.765569999999997	88.807080999999997	55.579531000000003	55.558090999999997	Строителей 	0103000020E610000001000000050000001E335019FF3056409198A0866FC74B401E335019FF305640540262122ECA4B40450E1137A7335640540262122ECA4B40450E1137A73356409198A0866FC74B401E335019FF3056409198A0866FC74B40
28074	47983	89.38485	89.398747	55.952050999999997	55.943244999999997	Садовая	0103000020E6100000010000000500000066F7E461A1585640C98E8D40BCF84B4066F7E461A1585640E28FA2CEDCF94B403318231285595640E28FA2CEDCF94B403318231285595640C98E8D40BCF84B4066F7E461A1585640C98E8D40BCF84B40
28489	7462	89.074662000000004	89.123412999999999	55.638587000000001	55.611739	Школьная	0103000020E6100000010000000500000041102043C74456400858AB764DCE4B4041102043C74456404C530438BDD14B40AEB9A3FFE54756404C530438BDD14B40AEB9A3FFE54756400858AB764DCE4B4041102043C74456400858AB764DCE4B40
27782	7462	89.074662000000004	89.123412999999999	55.638587000000001	55.611739	 Олега Кошевого	0103000020E6100000010000000500000041102043C74456400858AB764DCE4B4041102043C74456404C530438BDD14B40AEB9A3FFE54756404C530438BDD14B40AEB9A3FFE54756400858AB764DCE4B4041102043C74456400858AB764DCE4B40
72979	7029	89.606222000000002	89.617216999999997	55.901622000000003	55.888967000000001	Южная	0103000020E6100000010000000500000068075C57CC665640931CB0ABC9F14B4068075C57CC66564054AD855968F34B404162BB7B8067564054AD855968F34B404162BB7B80675640931CB0ABC9F14B4068075C57CC665640931CB0ABC9F14B40
72646	59650	88.879852999999997	88.933851000000004	55.416054000000003	55.379694999999998	Центральная	0103000020E610000001000000050000006612F5824F38564034BA83D899B04B406612F5824F3856405CAFE94141B54B409015FC36C43B56405CAFE94141B54B409015FC36C43B564034BA83D899B04B406612F5824F38564034BA83D899B04B40
28635	7152	89.720963999999995	89.740035000000006	55.773468999999999	55.756780999999997	Центральная	0103000020E61000000100000005000000F9653046246E5640F99D2633DEE04B40F9653046246E564023BC3D0801E34B404EB9C2BB5C6F564023BC3D0801E34B404EB9C2BB5C6F5640F99D2633DEE04B40F9653046246E5640F99D2633DEE04B40
73156	59875	89.287599	89.313713000000007	55.503261999999999	55.489911999999997	Новая	0103000020E6100000010000000500000030D7A205685256407FF5B86FB5BE4B4030D7A20568525640E7A8A3E36AC04B4020D5B0DF13545640E7A8A3E36AC04B4020D5B0DF135456407FF5B86FB5BE4B4030D7A205685256407FF5B86FB5BE4B40
28098	7327	89.515231999999997	89.533647000000002	55.777844000000002	55.760590999999998	Центральная	0103000020E610000001000000050000009276A38FF9605640E350BF0B5BE14B409276A38FF9605640E6B1666490E34B40F226BF4527625640E6B1666490E34B40F226BF4527625640E350BF0B5BE14B409276A38FF9605640E350BF0B5BE14B40
73002	59753	89.307828999999998	89.325587999999996	55.195241000000003	55.182448999999998	Советская	0103000020E61000000100000005000000AAF06778B35356400D18247D5A974B40AAF06778B35356404FEB36A8FD984B4015FE0C6FD65456404FEB36A8FD984B4015FE0C6FD65456400D18247D5A974B40AAF06778B35356400D18247D5A974B40
28136	8105	89.140642999999997	89.162598000000003	55.493986999999997	55.476587000000002	Школьная	0103000020E61000000100000005000000535A7F4B00495640715985CD00BD4B40535A7F4B0049564017D34CF73ABF4B4048197101684A564017D34CF73ABF4B4048197101684A5640715985CD00BD4B40535A7F4B00495640715985CD00BD4B40
28468	6932	89.562500999999997	89.609527999999997	55.858761000000001	55.835493	Просвещения	0103000020E61000000100000005000000E8BD310400645640BA84436FF1EA4B40E8BD310400645640460A65E1EBED4B40C37FBA8102675640460A65E1EBED4B40C37FBA8102675640BA84436FF1EA4B40E8BD310400645640BA84436FF1EA4B40
28302	48159	89.532964000000007	89.560426000000007	55.657778999999998	55.644044000000001	Центральная	0103000020E61000000100000005000000817C09151C625640AF97A60870D24B40817C09151C6256406F7F2E1A32D44B4000750305DE6356406F7F2E1A32D44B4000750305DE635640AF97A60870D24B40817C09151C625640AF97A60870D24B40
28363	45910	89.739791999999994	89.760830999999996	55.806159999999998	55.799021000000003	Центральная	0103000020E61000000100000005000000EA758BC0586F56409BE8F35146E64B40EA758BC0586F5640F3AB394030E74B401CB28174B1705640F3AB394030E74B401CB28174B17056409BE8F35146E64B40EA758BC0586F56409BE8F35146E64B40
72918	45910	89.739791999999994	89.760830999999996	55.806159999999998	55.799021000000003	Свободная	0103000020E61000000100000005000000EA758BC0586F56409BE8F35146E64B40EA758BC0586F5640F3AB394030E74B401CB28174B1705640F3AB394030E74B401CB28174B17056409BE8F35146E64B40EA758BC0586F56409BE8F35146E64B40
28187	7953	89.199203999999995	89.219300000000004	55.552667999999997	55.539425999999999	Комсомольская	0103000020E61000000100000005000000DF4E22C2BF4C5640594E42E90BC54B40DF4E22C2BF4C5640DAC534D3BDC64B40D200DE02094E5640DAC534D3BDC64B40D200DE02094E5640594E42E90BC54B40DF4E22C2BF4C5640594E42E90BC54B40
28147	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Уланова	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
27897	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Ленина	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
28622	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Красных Партизан	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
28616	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Интернациональная	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
27668	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Дзержинского	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
72675	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Громовой	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
28206	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	Герцена	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
28233	5070	94.260087999999996	94.372547999999995	55.828961	55.781073999999997	30 лет ВЛКСМ	0103000020E6100000010000000500000040852348A5905740C1E09A3BFAE34B4040852348A59057406954E0641BEA4B402C0C91D3D79757406954E0641BEA4B402C0C91D3D7975740C1E09A3BFAE34B4040852348A5905740C1E09A3BFAE34B40
73003	28218	94.592123000000001	94.616934999999998	55.815367000000002	55.802076999999997	Трактовая	0103000020E61000000100000005000000670DDE57E5A55740D8EF8975AAE64B40670DDE57E5A557406B9E23F25DE84B407F30F0DC7BA757406B9E23F25DE84B407F30F0DC7BA75740D8EF8975AAE64B40670DDE57E5A55740D8EF8975AAE64B40
27789	51741	94.192283000000003	94.224604999999997	55.787255000000002	55.769286000000001	Школьная	0103000020E61000000100000005000000EA245B5D4E8C5740A5A2B1F677E24B40EA245B5D4E8C5740664E97C5C4E44B402861A6ED5F8E5740664E97C5C4E44B402861A6ED5F8E5740A5A2B1F677E24B40EA245B5D4E8C5740A5A2B1F677E24B40
73101	59834	94.154779000000005	94.181369000000004	55.618878000000002	55.601441999999999	Механизаторов	0103000020E61000000100000005000000E3C62DE6E78957406D382C0DFCCC4B40E3C62DE6E7895740611BF16437CF4B4087E0B88C9B8B5740611BF16437CF4B4087E0B88C9B8B57406D382C0DFCCC4B40E3C62DE6E78957406D382C0DFCCC4B40
72654	32942	94.460475000000002	94.499353999999997	55.860700999999999	55.846451000000002	Центральный переулок	0103000020E610000001000000050000000A68226C789D57405055A18158EC4B400A68226C789D574037514B732BEE4B401DC87A6AF59F574037514B732BEE4B401DC87A6AF59F57405055A18158EC4B400A68226C789D57405055A18158EC4B40
72856	5940	94.018477000000004	94.048300999999995	55.904795999999997	55.893101999999999	Школьная	0103000020E610000001000000050000009BAE27BA2E81574000FF942A51F24B409BAE27BA2E8157409BC6F65AD0F34B404DD7135D178357409BC6F65AD0F34B404DD7135D1783574000FF942A51F24B409BAE27BA2E81574000FF942A51F24B40
28447	5992	94.131682999999995	94.152991	55.856684000000001	55.845227999999999	Ленина	0103000020E610000001000000050000001B9C887E6D885740EDD45C6E30EC4B401B9C887E6D885740D48041D2A7ED4B404565C39ACA895740D48041D2A7ED4B404565C39ACA895740EDD45C6E30EC4B401B9C887E6D885740EDD45C6E30EC4B40
27726	5895	93.922537000000005	93.932302000000007	55.894460000000002	55.886367	Ленина	0103000020E610000001000000050000006616A1D80A7B574077A04E7974F14B406616A1D80A7B574043CA4FAA7DF24B40B5FF01D6AA7B574043CA4FAA7DF24B40B5FF01D6AA7B574077A04E7974F14B406616A1D80A7B574077A04E7974F14B40
72625	59642	94.373923000000005	94.421192000000005	55.908586	55.887836	Железнодорожная	0103000020E61000000100000005000000390EBC5AEE975740111B2C9CA4F14B40390EBC5AEE9757403ECDC98B4CF44B408F554ACFF49A57403ECDC98B4CF44B408F554ACFF49A5740111B2C9CA4F14B40390EBC5AEE975740111B2C9CA4F14B40
73030	59777	94.470490999999996	94.502786	55.632784000000001	55.619365999999999	Советская	0103000020E61000000100000005000000FD8348861C9E57408E20956247CF4B40FD8348861C9E57404EB7EC10FFD04B40BFB854A52DA057404EB7EC10FFD04B40BFB854A52DA057408E20956247CF4B40FD8348861C9E57408E20956247CF4B40
9684	40267	93.973813000000007	94.013257999999993	55.875703000000001	55.857931999999998	Ленина	0103000020E61000000100000005000000DCDAC2F3527E57408F183DB7D0ED4B40DCDAC2F3527E57402A01310917F04B40431A1538D98057402A01310917F04B40431A1538D98057408F183DB7D0ED4B40DCDAC2F3527E57408F183DB7D0ED4B40
73074	59811	94.612909999999999	94.628972000000005	55.742575000000002	55.733274999999999	Юбилейная	0103000020E610000001000000050000000C59DDEA39A75740B9FC87F4DBDD4B400C59DDEA39A75740E2E995B20CDF4B406286C61341A85740E2E995B20CDF4B406286C61341A85740B9FC87F4DBDD4B400C59DDEA39A75740B9FC87F4DBDD4B40
72978	4004	90.252919000000006	90.266249999999999	55.507249000000002	55.495756	Советская	0103000020E610000001000000050000005F622CD32F905640DC65BFEE74BF4B405F622CD32F905640E0F60489EDC04B40D7A3703D0A915640E0F60489EDC04B40D7A3703D0A915640DC65BFEE74BF4B405F622CD32F905640DC65BFEE74BF4B40
28038	4187	90.206942999999995	90.218073000000004	55.187137	55.180880999999999	Школьная	0103000020E61000000100000005000000B648DA8D3E8D5640E0BBCD1B27974B40B648DA8D3E8D56408F6FEF1AF4974B4000C974E8F48D56408F6FEF1AF4974B4000C974E8F48D5640E0BBCD1B27974B40B648DA8D3E8D5640E0BBCD1B27974B40
72850	10272	90.215881999999993	90.225700000000003	55.573073000000001	55.568237000000003	Главная	0103000020E61000000100000005000000E272BC02D18D564047B071FDBBC84B40E272BC02D18D56403D9CC0745AC94B4043AD69DE718E56403D9CC0745AC94B4043AD69DE718E564047B071FDBBC84B40E272BC02D18D564047B071FDBBC84B40
28416	3737	89.315697999999998	90.779996999999995	55.684797000000003	55.055697000000002	Центральная	0103000020E61000000100000005000000685A6265345456401FBE4C1421874B40685A62653454564010B3976DA7D74B40997E8978EBB1564010B3976DA7D74B40997E8978EBB156401FBE4C1421874B40685A6265345456401FBE4C1421874B40
28485	2845	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	Советская	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
28044	2845	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	Кирова	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
28031	2845	89.800275999999997	89.872725000000003	55.341582000000002	55.290971999999996	Вокзальная	0103000020E6100000010000000500000084F1D3B8377356409E060C923EA54B4084F1D3B8377356407E737FF5B8AB4B40B459F5B9DA7756407E737FF5B8AB4B40B459F5B9DA7756409E060C923EA54B4084F1D3B8377356409E060C923EA54B40
72852	4829	89.994401999999994	90.013114000000002	55.138041999999999	55.125314000000003	Школьная	0103000020E61000000100000005000000ED444948A47F564090DD054A0A904B40ED444948A47F5640BABC395CAB914B40AA471ADCD6805640BABC395CAB914B40AA471ADCD680564090DD054A0A904B40ED444948A47F564090DD054A0A904B40
28656	3961	90.189723000000001	90.199675999999997	55.435288999999997	55.429726000000002	Крупской	0103000020E610000001000000050000002313F06B248C5640D61EF64201B74B402313F06B248C56407EA7C98CB7B74B40F372D87DC78C56407EA7C98CB7B74B40F372D87DC78C5640D61EF64201B74B402313F06B248C5640D61EF64201B74B40
72972	4112	90.443918999999994	90.471829999999997	55.604264000000001	55.586709999999997	Советская	0103000020E61000000100000005000000ACC43C2B699C56403A1E335019CB4B40ACC43C2B699C56403813D38558CD4B4063D17476329E56403813D38558CD4B4063D17476329E56403A1E335019CB4B40ACC43C2B699C56403A1E335019CB4B40
28523	10294	90.631972000000005	90.649939000000003	55.282533000000001	55.273062000000003	Школьная	0103000020E6100000010000000500000037FFAF3A72A85640E3E313B2F3A24B4037FFAF3A72A856403885950A2AA44B404759BF9998A956403885950A2AA44B404759BF9998A95640E3E313B2F3A24B4037FFAF3A72A85640E3E313B2F3A24B40
72787	10136	90.081044000000006	90.087143999999995	55.596493000000002	55.590938000000001	Садовая	0103000020E610000001000000050000005F622CD32F85564059FB3BDBA3CB4B405F622CD32F8556407FA5F3E159CC4B40BA826DC4938556407FA5F3E159CC4B40BA826DC49385564059FB3BDBA3CB4B405F622CD32F85564059FB3BDBA3CB4B40
28583	4948	89.773165000000006	89.786837000000006	55.236935000000003	55.229799	Российская	0103000020E610000001000000050000005C5A0D897B715640A6D3BA0D6A9D4B405C5A0D897B7156408E23D6E2539E4B40199293895B7256408E23D6E2539E4B40199293895B725640A6D3BA0D6A9D4B405C5A0D897B715640A6D3BA0D6A9D4B40
72970	4236	90.344376999999994	90.369726999999997	55.223323999999998	55.213793000000003	Новая	0103000020E61000000100000005000000A71FD4450A9656408F8EAB915D9B4B40A71FD4450A965640B9347EE1959C4B40AF5C6F9BA9975640B9347EE1959C4B40AF5C6F9BA99756408F8EAB915D9B4B40A71FD4450A9656408F8EAB915D9B4B40
28554	51778	89.738966000000005	89.844626000000005	55.294801	55.26267	Неделина М.И.	0103000020E61000000100000005000000C8B60C384B6F5640F6D1A92B9FA14B40C8B60C384B6F5640FFE9060ABCA54B407CD6355A0E765640FFE9060ABCA54B407CD6355A0E765640F6D1A92B9FA14B40C8B60C384B6F5640F6D1A92B9FA14B40
27961	51778	89.738966000000005	89.844626000000005	55.294801	55.26267	Неделина М.И	0103000020E61000000100000005000000C8B60C384B6F5640F6D1A92B9FA14B40C8B60C384B6F5640FFE9060ABCA54B407CD6355A0E765640FFE9060ABCA54B407CD6355A0E765640F6D1A92B9FA14B40C8B60C384B6F5640F6D1A92B9FA14B40
72007	59573	89.738966000000005	89.844626000000005	55.294801	55.26267	Солнечная	0103000020E61000000100000005000000C8B60C384B6F5640F6D1A92B9FA14B40C8B60C384B6F5640FFE9060ABCA54B407CD6355A0E765640FFE9060ABCA54B407CD6355A0E765640F6D1A92B9FA14B40C8B60C384B6F5640F6D1A92B9FA14B40
71624	4065	90.373589999999993	90.399839	55.536409999999997	55.517898000000002	Совхозная	0103000020E61000000100000005000000350708E6E8975640F8544E7B4AC24B40350708E6E8975640A99F3715A9C44B40952A51F696995640A99F3715A9C44B40952A51F696995640F8544E7B4AC24B40350708E6E8975640F8544E7B4AC24B40
72973	4968	89.706976999999995	89.722751000000002	55.178182	55.171041000000002	Мира	0103000020E610000001000000050000008C81751C3F6D564038A3E6ABE4954B408C81751C3F6D5640315EF3AACE964B40AF09698D416E5640315EF3AACE964B40AF09698D416E564038A3E6ABE4954B408C81751C3F6D564038A3E6ABE4954B40
28063	4421	90.262090999999998	90.286741000000006	55.216977	55.203235999999997	Октябрьская	0103000020E61000000100000005000000DC645419C690564057AF22A3039A4B40DC645419C6905640FA7DFFE6C59B4B40085BECF659925640FA7DFFE6C59B4B40085BECF65992564057AF22A3039A4B40DC645419C690564057AF22A3039A4B40
73065	59803	89.839900999999998	89.856995999999995	55.176577999999999	55.164382000000003	Садовая	0103000020E610000001000000050000002CB81FF0C07556408A0629780A954B402CB81FF0C0755640B7989F1B9A964B406133C005D9765640B7989F1B9A964B406133C005D97656408A0629780A954B402CB81FF0C07556408A0629780A954B40
72716	5029	89.687753000000001	89.712322	55.085945000000002	55.071390999999998	Почтовая	0103000020E6100000010000000500000075AE2825046C5640471D1D5723894B4075AE2825046C56409B20EA3E008B4B402A8E03AF966D56409B20EA3E008B4B402A8E03AF966D5640471D1D5723894B4075AE2825046C5640471D1D5723894B40
27858	3731	90.140090999999998	90.148211000000003	55.586654000000003	55.582054999999997	Победы	0103000020E61000000100000005000000B1DD3D40F788564094BC3AC780CA4B40B1DD3D40F7885640A708707A17CB4B40147AFD497C895640A708707A17CB4B40147AFD497C89564094BC3AC780CA4B40B1DD3D40F788564094BC3AC780CA4B40
72974	4679	90.175493000000003	90.196173000000002	55.262829000000004	55.252799000000003	Школьная	0103000020E6100000010000000500000053EBFD463B8B564013BBB6B75BA04B4053EBFD463B8B56405FB87361A4A14B40EDD632198E8C56405FB87361A4A14B40EDD632198E8C564013BBB6B75BA04B4053EBFD463B8B564013BBB6B75BA04B40
27855	3527	89.879605999999995	89.920649999999995	55.594518999999998	55.582538	Тимирязева	0103000020E6100000010000000500000062D7F6764B785640B056ED9A90CA4B4062D7F6764B785640E1ECD63219CC4B40FE43FAEDEB7A5640E1ECD63219CC4B40FE43FAEDEB7A5640B056ED9A90CA4B4062D7F6764B785640B056ED9A90CA4B40
72763	11633	89.876892999999995	89.884574000000001	55.453288999999998	55.449235000000002	Центральная	0103000020E61000000100000005000000D845D1031F785640FA9B508880B94B40D845D1031F7856407A51BB5F05BA4B40153944DC9C7856407A51BB5F05BA4B40153944DC9C785640FA9B508880B94B40D845D1031F785640FA9B508880B94B40
28422	4285	90.502606	90.547387000000001	55.228242999999999	55.211846000000001	Кооперативная	0103000020E610000001000000050000007F315BB22AA05640EBE40CC51D9B4B407F315BB22AA056403D450E11379D4B405BD07B6308A356403D450E11379D4B405BD07B6308A35640EBE40CC51D9B4B407F315BB22AA05640EBE40CC51D9B4B40
9936	4720	90.155163999999999	90.179948999999993	55.327936000000001	55.315252999999998	Главная	0103000020E610000001000000050000000F61FC34EE895640A27BD6355AA84B400F61FC34EE8956402D978DCEF9A94B40AA7CCF48848B56402D978DCEF9A94B40AA7CCF48848B5640A27BD6355AA84B400F61FC34EE895640A27BD6355AA84B40
72603	3429	89.675841000000005	89.717658	55.479500000000002	55.464171999999998	Центральная	0103000020E61000000100000005000000F1129CFA406B564005DCF3FC69BB4B40F1129CFA406B56404C37894160BD4B409EEDD11BEE6D56404C37894160BD4B409EEDD11BEE6D564005DCF3FC69BB4B40F1129CFA406B564005DCF3FC69BB4B40
71626	3327	89.762951000000001	89.790439000000006	55.347101000000002	55.323853999999997	Главная	0103000020E61000000100000005000000D55C6E30D4705640E256410C74A94B40D55C6E30D470564057B439CE6DAC4B40E99E758D9672564057B439CE6DAC4B40E99E758D96725640E256410C74A94B40D55C6E30D4705640E256410C74A94B40
71521	3624	89.986524000000003	90.021765000000002	55.581485000000001	55.558804000000002	Главная	0103000020E61000000100000005000000062E8F35237F5640DF6FB4E386C74B40062E8F35237F5640AA0EB9196ECA4B40A3CC069964815640AA0EB9196ECA4B40A3CC069964815640DF6FB4E386C74B40062E8F35237F5640DF6FB4E386C74B40
28592	51904	89.315697999999998	90.779996999999995	55.684797000000003	55.055697000000002	Школьная	0103000020E61000000100000005000000685A6265345456401FBE4C1421874B40685A62653454564010B3976DA7D74B40997E8978EBB1564010B3976DA7D74B40997E8978EBB156401FBE4C1421874B40685A6265345456401FBE4C1421874B40
72976	4620	90.014083999999997	90.053816999999995	55.295867000000001	55.280810000000002	Главная 	0103000020E6100000010000000500000066D993C0E6805640E4310395F1A34B4066D993C0E68056409A7B48F8DEA54B4001BEDBBC718356409A7B48F8DEA54B4001BEDBBC71835640E4310395F1A34B4066D993C0E6805640E4310395F1A34B40
72969	3921	90.049306999999999	90.070687000000007	55.452058000000001	55.444674999999997	Ужурская	0103000020E61000000100000005000000B01D8CD827835640A52C431CEBB84B40B01D8CD82783564095F25A09DDB94B402750C4228684564095F25A09DDB94B402750C42286845640A52C431CEBB84B40B01D8CD827835640A52C431CEBB84B40
27886	4891	89.794392000000002	89.816373999999996	55.138047999999998	55.125951999999998	Мира	0103000020E610000001000000050000000F0D8B51D7725640D26EF4311F904B400F0D8B51D77256409CA38E8EAB914B4080D3BB783F7456409CA38E8EAB914B4080D3BB783F745640D26EF4311F904B400F0D8B51D7725640D26EF4311F904B40
28057	4314	90.615667999999999	90.631056000000001	55.144314999999999	55.132370999999999	Школьная	0103000020E61000000100000005000000664CC11A67A756402BF86D88F1904B40664CC11A67A756403FA9F6E978924B40747CB43863A856403FA9F6E978924B40747CB43863A856402BF86D88F1904B40664CC11A67A756402BF86D88F1904B40
72771	4401	90.653684999999996	90.668425999999997	55.163307000000003	55.153430999999998	Первомайская	0103000020E61000000100000005000000B0389CF9D5A95640A69883A0A3934B40B0389CF9D5A956409C1A683EE7944B40F372D87DC7AA56409C1A683EE7944B40F372D87DC7AA5640A69883A0A3934B40B0389CF9D5A95640A69883A0A3934B40
28423	4502	90.345284000000007	90.355615	55.146763999999997	55.141542000000001	Красноярская	0103000020E6100000010000000500000041F50F221996564056815A0C1E924B4041F50F2219965640751DAA29C9924B40E4BD6A65C2965640751DAA29C9924B40E4BD6A65C296564056815A0C1E924B4041F50F221996564056815A0C1E924B40
73127	59858	89.833082000000005	89.846270000000004	55.502170999999997	55.493966	Главная	0103000020E61000000100000005000000B9382A375175564000AB23473ABF4B40B9382A3751755640F3FFAA2347C04B408065A54929765640F3FFAA2347C04B408065A5492976564000AB23473ABF4B40B9382A375175564000AB23473ABF4B40
27852	3413	89.547489999999996	89.574286999999998	55.379137999999998	55.366681	Школьная	0103000020E61000000100000005000000C5387F130A63564044882B67EFAE4B40C5387F130A635640DE550F9887B04B4026E1421EC1645640DE550F9887B04B4026E1421EC164564044882B67EFAE4B40C5387F130A63564044882B67EFAE4B40
72775	4573	90.314138999999997	90.333651000000003	55.088521999999998	55.077942	Промышленная	0103000020E610000001000000050000007BD976DA1A9456400F7EE200FA894B407BD976DA1A945640FE7C5BB0548B4B40C651B9895A955640FE7C5BB0548B4B40C651B9895A9556400F7EE200FA894B407BD976DA1A9456400F7EE200FA894B40
27957	10227	89.948040000000006	89.960741999999996	55.624281000000003	55.618383999999999	Звездная	0103000020E6100000010000000500000031D3F6AFAC7C5640512FF83427CF4B4031D3F6AFAC7C5640D1419770E8CF4B40317903CC7C7D5640D1419770E8CF4B40317903CC7C7D5640512FF83427CF4B4031D3F6AFAC7C5640512FF83427CF4B40
28221	51825	89.396985999999998	89.409059999999997	57.505443	57.498693000000003	Заполярная	0103000020E6100000010000000500000012BEF7376859564040DF162CD5BF4C4012BEF73768595640FE7E315BB2C04C408386FE092E5A5640FE7E315BB2C04C408386FE092E5A564040DF162CD5BF4C4012BEF7376859564040DF162CD5BF4C40
28393	2728	89.294758000000002	89.304935999999998	57.3962	57.371335999999999	 Центральная	0103000020E61000000100000005000000008FA850DD525640EAE923F087AF4C40008FA850DD5256406D567DAEB6B24C40E0D74812845356406D567DAEB6B24C40E0D7481284535640EAE923F087AF4C40008FA850DD525640EAE923F087AF4C40
28484	1606	89.288101999999995	89.352619000000004	56.549576999999999	56.514966999999999	Юбилейная	0103000020E6100000010000000500000061FA5E437052564076C24B70EA414C4061FA5E437052564020D1048A58464C40B03C484F9156564020D1048A58464C40B03C484F9156564076C24B70EA414C4061FA5E437052564076C24B70EA414C40
27972	1606	89.288101999999995	89.352619000000004	56.549576999999999	56.514966999999999	Советская	0103000020E6100000010000000500000061FA5E437052564076C24B70EA414C4061FA5E437052564020D1048A58464C40B03C484F9156564020D1048A58464C40B03C484F9156564076C24B70EA414C4061FA5E437052564076C24B70EA414C40
27939	2619	89.069756999999996	89.094631000000007	57.016325999999999	57.001745	Трактовая	0103000020E61000000100000005000000B16A10E6764456403CF71E2E39804C40B16A10E67644564089096AF816824C40058C2E6F0E46564089096AF816824C40058C2E6F0E4656403CF71E2E39804C40B16A10E6764456403CF71E2E39804C40
28501	2274	89.205770999999999	89.233941999999999	56.578978999999997	56.570037999999997	Боброва	0103000020E61000000100000005000000C6DD205A2B4D564016BD5301F7484C40C6DD205A2B4D56400F09DFFB1B4A4C404BCADDE7F84E56400F09DFFB1B4A4C404BCADDE7F84E564016BD5301F7484C40C6DD205A2B4D564016BD5301F7484C40
28379	1799	89.303903000000005	89.320728000000003	56.434730000000002	56.422987999999997	 Центральная	0103000020E61000000100000005000000018A912573535640DB4C857824364C40018A912573535640884B8E3BA5374C4056BABBCE86545640884B8E3BA5374C4056BABBCE86545640DB4C857824364C40018A912573535640DB4C857824364C40
28356	15664	89.899000999999998	89.929067000000003	57.510384999999999	57.496133999999998	Советская	0103000020E6100000010000000500000090847D3B897956408237A45181BF4C4090847D3B897956403AAFB14B54C14C40BE326FD5757B56403AAFB14B54C14C40BE326FD5757B56408237A45181BF4C4090847D3B897956408237A45181BF4C40
27833	1695	89.228615000000005	89.248863	56.543021000000003	56.530383999999998	 Заречная	0103000020E610000001000000050000000118CFA0A14E56402C29779FE3434C400118CFA0A14E564047054EB681454C40CE8B135FED4F564047054EB681454C40CE8B135FED4F56402C29779FE3434C400118CFA0A14E56402C29779FE3434C40
72774	2707	88.941181	88.969757000000001	57.076877000000003	57.058537000000001	Сибирская	0103000020E6100000010000000500000076A73B4F3C3C5640904DF2237E874C4076A73B4F3C3C56404568041BD7894C404B04AA7F103E56404568041BD7894C404B04AA7F103E5640904DF2237E874C4076A73B4F3C3C5640904DF2237E874C40
27944	2840	89.306426999999999	89.324510000000004	57.440854000000002	57.433141999999997	Чулымская	0103000020E6100000010000000500000021E7FD7F9C5356401343723271B74C4021E7FD7F9C535640C82764E76DB84C40664E97C5C4545640C82764E76DB84C40664E97C5C45456401343723271B74C4021E7FD7F9C5356401343723271B74C40
28555	1809	89.168876999999995	89.195978999999994	56.439055000000003	56.426597000000001	 Колхозная	0103000020E61000000100000005000000FB027AE1CE4A56402EC901BB9A364C40FB027AE1CE4A5640991249F432384C40FAEC80EB8A4C5640991249F432384C40FAEC80EB8A4C56402EC901BB9A364C40FB027AE1CE4A56402EC901BB9A364C40
72764	2151	89.626569000000003	89.658503999999994	56.539566999999998	56.531596	Советская	0103000020E61000000100000005000000FFEBDCB4196856409B5775560B444C40FFEBDCB4196856401B800D8810454C404012F6ED246A56401B800D8810454C404012F6ED246A56409B5775560B444C40FFEBDCB4196856409B5775560B444C40
72983	2169	89.780557999999999	89.796718999999996	56.552534000000001	56.547238999999998	Лесная	0103000020E6100000010000000500000065A88AA9F4715640410C74ED0B464C4065A88AA9F4715640CBF6216FB9464C408446B071FD725640CBF6216FB9464C408446B071FD725640410C74ED0B464C4065A88AA9F4715640410C74ED0B464C40
72849	2384	89.124140999999995	89.180456000000007	56.616262999999996	56.592109999999998	Центральная	0103000020E61000000100000005000000EFC517EDF147564039D1AE42CA4B4C40EFC517EDF14756400F5EBBB4E14E4C407D9752978C4B56400F5EBBB4E14E4C407D9752978C4B564039D1AE42CA4B4C40EFC517EDF147564039D1AE42CA4B4C40
28182	2030	89.469965000000002	89.498783000000003	56.524237999999997	56.517366000000003	Верхняя	0103000020E61000000100000005000000F05014E8135E5640FB07910C39424C40F05014E8135E564004A9143B1A434C404033880FEC5F564004A9143B1A434C404033880FEC5F5640FB07910C39424C40F05014E8135E5640FB07910C39424C40
72756	1929	89.433520999999999	89.465878000000004	56.451712000000001	56.438487000000002	Шахова	0103000020E610000001000000050000004548DDCEBE5B56404F5C8E5720384C404548DDCEBE5B5640FA9AE5B2D1394C40427BF5F1D05D5640FA9AE5B2D1394C40427BF5F1D05D56404F5C8E5720384C404548DDCEBE5B56404F5C8E5720384C40
27848	2503	89.364098999999996	89.399331000000004	56.861485999999999	56.843176	Советская	0103000020E610000001000000050000006760E4654D575640D462F030ED6B4C406760E4654D5756401EFB592C456E4C40DB519CA38E5956401EFB592C456E4C40DB519CA38E595640D462F030ED6B4C406760E4654D575640D462F030ED6B4C40
73246	51885	89.094227000000004	89.105905000000007	56.570861999999998	56.565832999999998	Интернациональная	0103000020E610000001000000050000009DD9AED007465640B0FF3A376D484C409DD9AED007465640BB438A0112494C40E8DEC325C7465640BB438A0112494C40E8DEC325C7465640B0FF3A376D484C409DD9AED007465640B0FF3A376D484C40
73008	59759	89.263101000000006	89.305088999999995	56.592565999999998	56.579762000000002	Революции	0103000020E61000000100000005000000E0A293A5D650564056BB26A4354A4C40E0A293A5D65056405B5CE333D94B4C40A3570394865356405B5CE333D94B4C40A35703948653564056BB26A4354A4C40E0A293A5D650564056BB26A4354A4C40
28561	1906	88.957890000000006	88.984802999999999	56.490459999999999	56.478735	Советская	0103000020E6100000010000000500000097CADB114E3D5640AC394030473D4C4097CADB114E3D564082FFAD64C73E4C402C802903073F564082FFAD64C73E4C402C802903073F5640AC394030473D4C4097CADB114E3D5640AC394030473D4C40
28647	2602	89.058079000000006	89.069783999999999	56.928066999999999	56.918928999999999	Советская	0103000020E610000001000000050000006765FB90B7435640492C29779F754C406765FB90B743564098BF42E6CA764C402E724F577744564098BF42E6CA764C402E724F5777445640492C29779F754C406765FB90B7435640492C29779F754C40
28378	2048	89.530214999999998	89.571286000000001	56.529600000000002	56.520305	 Еланьская	0103000020E610000001000000050000005036E50AEF615640FF78AF5A99424C405036E50AEF61564016FBCBEEC9434C4069AA27F38F64564016FBCBEEC9434C4069AA27F38F645640FF78AF5A99424C405036E50AEF615640FF78AF5A99424C40
73088	59823	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	Центральная	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
73241	59889	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	Декабристов	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
73490	60007	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	Центральная	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
73144	59869	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	Центральная	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
73073	59810	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	Бограда	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
73284	59899	94.496793999999994	94.507484000000005	54.838991	54.815555000000003	Набережная	0103000020E6100000010000000500000056B60F79CB9F57406E8B321B64684B4056B60F79CB9F5740B5519D0E646B4B4092CF2B9E7AA05740B5519D0E646B4B4092CF2B9E7AA057406E8B321B64684B4056B60F79CB9F57406E8B321B64684B40
73401	59942	95.692119000000005	95.726651000000004	56.216934999999999	56.206316999999999	Набережная	0103000020E610000001000000050000002D7C7DAD4BEC5740EECD6F98681A4C402D7C7DAD4BEC5740CB2DAD86C41B4C40C426327381EE5740CB2DAD86C41B4C40C426327381EE5740EECD6F98681A4C402D7C7DAD4BEC5740EECD6F98681A4C40
28337	32141	94.231459000000001	94.246380000000002	57.149230000000003	57.138536000000002	Школьная	0103000020E610000001000000050000005AD76839D08E5740CAA8328CBB914C405AD76839D08E574082CAF8F719934C40DD989EB0C48F574082CAF8F719934C40DD989EB0C48F5740CAA8328CBB914C405AD76839D08E5740CAA8328CBB914C40
28655	6460	95.949082000000004	95.956799000000004	57.379351999999997	57.376271000000003	Лесная	0103000020E610000001000000050000003ACE6DC2BDFC574074B7EBA529B04C403ACE6DC2BDFC57400AD6389B8EB04C401D76DF313CFD57400AD6389B8EB04C401D76DF313CFD574074B7EBA529B04C403ACE6DC2BDFC574074B7EBA529B04C40
28276	9236	95.987314999999995	95.998660000000001	57.391364000000003	57.386105999999998	Школьная	0103000020E610000001000000050000006AF6402B30FF57400A65E1EB6BB14C406AF6402B30FF5740776A2E3718B24C40B2F4A10BEAFF5740776A2E3718B24C40B2F4A10BEAFF57400A65E1EB6BB14C406AF6402B30FF57400A65E1EB6BB14C40
28435	32162	94.906704000000005	94.925685999999999	57.134394	57.124989999999997	Центральная	0103000020E61000000100000005000000C1C9367007BA5740DC291DACFF8F4C40C1C9367007BA5740AA6395D233914C405D177E703EBB5740AA6395D233914C405D177E703EBB5740DC291DACFF8F4C40C1C9367007BA5740DC291DACFF8F4C40
27898	32338	95.474107000000004	95.499251000000001	57.150464999999997	57.143116999999997	Центральная 	0103000020E6100000010000000500000080F3E2C457DE5740354069A851924C4080F3E2C457DE5740A818E76F42934C40B35F77BAF3DF5740A818E76F42934C40B35F77BAF3DF5740354069A851924C4080F3E2C457DE5740354069A851924C40
72968	45422	94.474812	94.512083000000004	57.219208999999999	57.210397	Карпачева	0103000020E61000000100000005000000E5EFDE51639E57409816F549EE9A4C40E5EFDE51639E574093FE5E0A0F9C4C409B75C6F7C5A0574093FE5E0A0F9C4C409B75C6F7C5A057409816F549EE9A4C40E5EFDE51639E57409816F549EE9A4C40
72661	113	94.816980999999998	94.863962000000001	57.421793000000001	57.40936	Большевистская	0103000020E61000000100000005000000041DAD6A49B45740312592E865B44C40041DAD6A49B4574043572250FDB54C4027BF45274BB7574043572250FDB54C4027BF45274BB75740312592E865B44C40041DAD6A49B45740312592E865B44C40
27816	1549	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	переулок Центральный	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
28011	1549	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	Сурикова,	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
72639	1549	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	Октябрьская	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
72606	1549	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	Мичурина	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
27759	1549	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	Луначарского	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
27825	1549	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	Гагарина	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
28351	1549	94.852725000000007	94.923674000000005	57.230504000000003	57.174723	 Лихачева	0103000020E61000000100000005000000D3DEE00B93B65740F46DC1525D964C40D3DEE00B93B6574071CCB227819D4C40988A8D791DBB574071CCB227819D4C40988A8D791DBB5740F46DC1525D964C40D3DEE00B93B65740F46DC1525D964C40
28015	32943	94.628801999999993	94.656586000000004	57.081955000000001	57.058135	Пролетарская	0103000020E61000000100000005000000336ABE4A3EA8574061E0B9F770874C40336ABE4A3EA85740315F5E807D8A4C40BC40498105AA5740315F5E807D8A4C40BC40498105AA574061E0B9F770874C40336ABE4A3EA8574061E0B9F770874C40
27841	49476	94.514202999999995	94.536795999999995	56.992483999999997	56.986579999999996	Раздолинская	0103000020E610000001000000050000005320B3B3E8A057409F71E140487E4C405320B3B3E8A05740D1E638B7097F4C40E9279CDD5AA25740D1E638B7097F4C40E9279CDD5AA257409F71E140487E4C405320B3B3E8A057409F71E140487E4C40
28223	32305	95.045512000000002	95.072227999999996	57.144362000000001	57.132263999999999	Гагарина	0103000020E61000000100000005000000D6E429ABE9C257401538D906EE904C40D6E429ABE9C2574080643A747A924C40C07630629FC4574080643A747A924C40C07630629FC457401538D906EE904C40D6E429ABE9C257401538D906EE904C40
72759	31984	94.512685000000005	94.534352999999996	57.099673000000003	57.084282999999999	Слобода	0103000020E610000001000000050000009609BFD4CFA05740EC4D0CC9C98A4C409609BFD4CFA05740A9A5B915C28C4C403FE1ECD632A25740A9A5B915C28C4C403FE1ECD632A25740EC4D0CC9C98A4C409609BFD4CFA05740EC4D0CC9C98A4C40
28112	32411	94.790265000000005	94.805868000000004	57.287669000000001	57.280397000000001	 Советская	0103000020E610000001000000050000001A8BA6B393B25740C172840CE4A34C401A8BA6B393B2574059897956D2A44C402639605793B3574059897956D2A44C402639605793B35740C172840CE4A34C401A8BA6B393B25740C172840CE4A34C40
72848	32077	94.366116000000005	94.378153999999995	57.130662000000001	57.123337999999997	Центральная	0103000020E61000000100000005000000B6A2CD716E975740512D228AC98F4C40B6A2CD716E9757403C6A4C88B9904C4080B6D5AC339857403C6A4C88B9904C4080B6D5AC33985740512D228AC98F4C40B6A2CD716E975740512D228AC98F4C40
27834	45516	94.765614999999997	94.779656000000003	57.319369999999999	57.305050000000001	Чкалова	0103000020E61000000100000005000000EE940ED6FFB0574089D2DEE00BA74C40EE940ED6FFB0574069A9BC1DE1A84C40558847E2E5B1574069A9BC1DE1A84C40558847E2E5B1574089D2DEE00BA74C40EE940ED6FFB0574089D2DEE00BA74C40
27799	49544	94.378342000000004	94.407168999999996	57.084890000000001	57.080036999999997	Гагарина	0103000020E61000000100000005000000022D5DC13698574027BC04A73E8A4C40022D5DC136985740F4E0EEACDD8A4C407BBC900E0F9A5740F4E0EEACDD8A4C407BBC900E0F9A574027BC04A73E8A4C40022D5DC13698574027BC04A73E8A4C40
28332	49486	94.730014999999995	94.757755000000003	57.085095000000003	57.079284000000001	Октябрьская	0103000020E61000000100000005000000B9A5D590B8AE57404C8C65FA258A4C40B9A5D590B8AE5740CD069964E48A4C405AD8D30E7FB05740CD069964E48A4C405AD8D30E7FB057404C8C65FA258A4C40B9A5D590B8AE57404C8C65FA258A4C40
72845	45363	95.180232000000004	95.204719999999995	57.089086000000002	57.078066	Советская	0103000020E61000000100000005000000556CCCEB88CB5740FB761211FE894C40556CCCEB88CB57400744882B678B4C409335EA211ACD57400744882B678B4C409335EA211ACD5740FB761211FE894C40556CCCEB88CB5740FB761211FE894C40
27758	45458	94.495868999999999	94.514581000000007	57.232813	57.218463999999997	Центральная	0103000020E610000001000000050000006A865451BC9F57403AADDBA0F69B4C406A865451BC9F5740B58AFED0CC9D4C40278925E5EEA05740B58AFED0CC9D4C40278925E5EEA057403AADDBA0F69B4C406A865451BC9F57403AADDBA0F69B4C40
28509	49515	94.778954999999996	94.784739999999999	57.017114999999997	57.007621999999998	Чапаева	0103000020E6100000010000000500000090831266DAB15740745DF8C1F9804C4090831266DAB15740B1A206D330824C403CF71E2E39B25740B1A206D330824C403CF71E2E39B25740745DF8C1F9804C4090831266DAB15740745DF8C1F9804C40
28478	32472	94.654718000000003	94.667689999999993	57.260069000000001	57.256213000000002	Пролетарская	0103000020E61000000100000005000000908653E6E6A95740B0E76B96CBA04C40908653E6E6A957400ADAE4F049A14C407077D66EBBAA57400ADAE4F049A14C407077D66EBBAA5740B0E76B96CBA04C40908653E6E6A95740B0E76B96CBA04C40
28338	32218	94.977815000000007	94.997119999999995	57.065309999999997	57.049799	Кузнечная	0103000020E6100000010000000500000073A25D8594BE5740CF2F4AD05F864C4073A25D8594BE5740060DFD135C884C40008C67D0D0BF5740060DFD135C884C40008C67D0D0BF5740CF2F4AD05F864C4073A25D8594BE5740CF2F4AD05F864C40
28137	51775	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	поселок Левинские Пески	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
71490	59466	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	Степная	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
28114	51810	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	Школьная	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
27983	51786	93.187167000000002	93.202851999999993	56.504863999999998	56.494729	Школьная	0103000020E61000000100000005000000FDF84B8BFA4B5740FFB0A547533F4C40FDF84B8BFA4B5740C07630629F404C40677BF486FB4C5740C07630629F404C40677BF486FB4C5740FFB0A547533F4C40FDF84B8BFA4B5740FFB0A547533F4C40
27973	51782	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	Ленина	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
28218	31604	92.803685000000002	92.824185	56.588675000000002	56.581972999999998	Зеланая	0103000020E610000001000000050000004AD235936F335740D7135D177E4A4C404AD235936F335740857CD0B3594B4C40A4367172BF345740857CD0B3594B4C40A4367172BF345740D7135D177E4A4C404AD235936F335740D7135D177E4A4C40
72965	30237	92.903371000000007	92.924850000000006	56.544742999999997	56.531933000000002	Новая	0103000020E61000000100000005000000E94999D4D0395740E3546B6116444C40E94999D4D0395740CADC7C23BA454C4029ED0DBE303B5740CADC7C23BA454C4029ED0DBE303B5740E3546B6116444C40E94999D4D0395740E3546B6116444C40
27981	31454	93.032055	93.070888999999994	56.559161000000003	56.540734	Ленина	0103000020E61000000100000005000000172B6A300D425740EAEA8EC536454C40172B6A300D4257406E19709692474C405A290472894457406E19709692474C405A29047289445740EAEA8EC536454C40172B6A300D425740EAEA8EC536454C40
72966	30594	93.640691000000004	93.658747000000005	56.475394000000001	56.459541999999999	Первомайская	0103000020E61000000100000005000000DCF5D21401695740B891B245D23A4C40DCF5D21401695740795BE9B5D93C4C40A4552DE9286A5740795BE9B5D93C4C40A4552DE9286A5740B891B245D23A4C40DCF5D21401695740B891B245D23A4C40
72986	59742	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	Южная	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
27730	14809	93.248450000000005	93.304226999999997	56.510860000000001	56.485410999999999	Юбилейная	0103000020E610000001000000050000003D2CD49AE64F5740300F99F2213E4C403D2CD49AE64F5740D36A48DC63414C40DAE3857478535740D36A48DC63414C40DAE3857478535740300F99F2213E4C403D2CD49AE64F5740300F99F2213E4C40
72595	14809	93.248450000000005	93.304226999999997	56.510860000000001	56.485410999999999	Центральная	0103000020E610000001000000050000003D2CD49AE64F5740300F99F2213E4C403D2CD49AE64F5740D36A48DC63414C40DAE3857478535740D36A48DC63414C40DAE3857478535740300F99F2213E4C403D2CD49AE64F5740300F99F2213E4C40
28294	14809	93.248450000000005	93.304226999999997	56.510860000000001	56.485410999999999	Ленина	0103000020E610000001000000050000003D2CD49AE64F5740300F99F2213E4C403D2CD49AE64F5740D36A48DC63414C40DAE3857478535740D36A48DC63414C40DAE3857478535740300F99F2213E4C403D2CD49AE64F5740300F99F2213E4C40
28318	30440	93.390258000000003	93.412571999999997	56.530816000000002	56.519233	8 Марта	0103000020E6100000010000000500000027C0B0FCF95857408200193A76424C4027C0B0FCF9585740C61858C7F1434C40B3CF6394675A5740C61858C7F1434C40B3CF6394675A57408200193A76424C4027C0B0FCF95857408200193A76424C40
27945	26527	92.571703999999997	92.590164999999999	56.571848000000003	56.563997999999998	Октябрьская	0103000020E6100000010000000500000083BF5FCC962457403481221631484C4083BF5FCC962457403A24B55032494C409B8F6B43C52557403A24B55032494C409B8F6B43C52557403481221631484C4083BF5FCC962457403481221631484C40
28139	30935	93.563695999999993	93.595675999999997	56.766134000000001	56.736922999999997	Лукьянова	0103000020E61000000100000005000000B438639813645740C9552C7E535E4C40B438639813645740452DCDAD10624C40C6C03A8E1F665740452DCDAD10624C40C6C03A8E1F665740C9552C7E535E4C40B438639813645740C9552C7E535E4C40
28200	31551	93.018697000000003	93.032846000000006	56.663905999999997	56.655268	Ленина	0103000020E6100000010000000500000022E2E65432415740C30E63D2DF534C4022E2E6543241574020CF2EDFFA544C407CF31B261A42574020CF2EDFFA544C407CF31B261A425740C30E63D2DF534C4022E2E65432415740C30E63D2DF534C40
72799	30753	93.564701999999997	93.587509999999995	56.677822999999997	56.669826999999998	Школьная	0103000020E61000000100000005000000177FDB1324645740287D21E4BC554C40177FDB132464574001BD70E7C2564C40AB048BC39965574001BD70E7C2564C40AB048BC399655740287D21E4BC554C40177FDB1324645740287D21E4BC554C40
28319	30866	93.557137999999995	93.568655000000007	56.713301000000001	56.696728	 Новая	0103000020E61000000100000005000000F7562426A86357408F1A13622E594C40F7562426A8635740209A79724D5B4C403EEDF0D764645740209A79724D5B4C403EEDF0D7646457408F1A13622E594C40F7562426A86357408F1A13622E594C40
28270	10781	93.472104000000002	93.486630000000005	56.597745000000003	56.583703	Трактовая	0103000020E61000000100000005000000E413B2F3365E5740DEC9A7C7B64A4C40E413B2F3365E57407C2C7DE8824C4C4029D027F2245F57407C2C7DE8824C4C4029D027F2245F5740DEC9A7C7B64A4C40E413B2F3365E5740DEC9A7C7B64A4C40
72670	30474	93.694985000000003	93.738022999999998	56.512638000000003	56.494112999999999	Транспортная	0103000020E610000001000000050000007A8D5DA27A6C5740A4C343183F3F4C407A8D5DA27A6C5740EB573A1F9E414C40882CD2C43B6F5740EB573A1F9E414C40882CD2C43B6F5740A4C343183F3F4C407A8D5DA27A6C5740A4C343183F3F4C40
28340	31489	93.198916999999994	93.224708000000007	56.628025000000001	56.615951000000003	Ленина	0103000020E6100000010000000500000094675E0EBB4C574021787C7BD74E4C4094675E0EBB4C574003098A1F63504C4093C9A99D614E574003098A1F63504C4093C9A99D614E574021787C7BD74E4C4094675E0EBB4C574021787C7BD74E4C40
27967	30399	93.559663	93.583432000000002	56.622419999999998	56.608898000000003	Центральная	0103000020E610000001000000050000000072C284D1635740C74CA25EF04D4C400072C284D16357402B306475AB4F4C4027DC2BF3566557402B306475AB4F4C4027DC2BF356655740C74CA25EF04D4C400072C284D1635740C74CA25EF04D4C40
28134	51815	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	Центральная	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
27777	30033	93.688265000000001	93.710993000000002	56.610230000000001	56.597729999999999	Центральная	0103000020E61000000100000005000000D07EA4880C6C574046EBA86A824C4C40D07EA4880C6C5740E08442041C4E4C40D6ABC8E8806D5740E08442041C4E4C40D6ABC8E8806D574046EBA86A824C4C40D07EA4880C6C574046EBA86A824C4C40
27884	30307	93.393510000000006	93.426254	56.557032999999997	56.543135999999997	Площадь Победы	0103000020E61000000100000005000000892991442F595740DFA3FE7A85454C40892991442F59574079E57ADB4C474C408272DBBE475B574079E57ADB4C474C408272DBBE475B5740DFA3FE7A85454C40892991442F595740DFA3FE7A85454C40
72864	19871	93.317594	93.327815999999999	56.703325999999997	56.694800000000001	Механизаторов	0103000020E61000000100000005000000F9D9C8755354574062A1D634EF584C40F9D9C8755354574097361C96065A4C40C1C6F5EFFA54574097361C96065A4C40C1C6F5EFFA54574062A1D634EF584C40F9D9C8755354574062A1D634EF584C40
28490	30016	93.347283000000004	93.364153000000002	56.510586000000004	56.501133000000003	Школьная	0103000020E610000001000000050000003CDD79E23956574023F94A2025404C403CDD79E239565740D2E5CDE15A414C40616F62484E575740D2E5CDE15A414C40616F62484E57574023F94A2025404C403CDD79E23956574023F94A2025404C40
72753	30547	93.705819000000005	93.717918999999995	56.458348000000001	56.448369	Центральная	0103000020E610000001000000050000004F7974232C6D574026C5C72764394C404F7974232C6D5740F017B325AB3A4C40548B8862F26D5740F017B325AB3A4C40548B8862F26D574026C5C72764394C404F7974232C6D574026C5C72764394C40
28500	30787	93.511090999999993	93.546070999999998	56.797837000000001	56.793311000000003	Береговая	0103000020E61000000100000005000000EA9106B7B56057404E4700378B654C40EA9106B7B5605740F644D7851F664C40D192C7D3F2625740F644D7851F664C40D192C7D3F26257404E4700378B654C40EA9106B7B56057404E4700378B654C40
28299	21467	93.597849999999994	93.657453000000004	56.416924000000002	56.385800000000003	Школьная	0103000020E61000000100000005000000787AA52C43665740FE65F7E461314C40787AA52C43665740717500C45D354C400E6ABFB5136A5740717500C45D354C400E6ABFB5136A5740FE65F7E461314C40787AA52C43665740FE65F7E461314C40
28385	21467	93.597849999999994	93.657453000000004	56.416924000000002	56.385800000000003	Октябрьская	0103000020E61000000100000005000000787AA52C43665740FE65F7E461314C40787AA52C43665740717500C45D354C400E6ABFB5136A5740717500C45D354C400E6ABFB5136A5740FE65F7E461314C40787AA52C43665740FE65F7E461314C40
28311	30323	93.681438	93.707066999999995	56.579990000000002	56.563640999999997	Центральная	0103000020E610000001000000050000001B1021AE9C6B5740A5D7666325484C401B1021AE9C6B5740E700C11C3D4A4C402C45F295406D5740E700C11C3D4A4C402C45F295406D5740A5D7666325484C401B1021AE9C6B5740A5D7666325484C40
27974	51783	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	Новая	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
27794	51744	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	Новая	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
72616	59639	91.673946000000001	91.726623000000004	53.715775000000001	53.695675999999999	Ленина	0103000020E61000000100000005000000485167EE21EB5640594E42E90BD94A40485167EE21EB5640AF25E4839EDB4A405F61C1FD80EE5640AF25E4839EDB4A405F61C1FD80EE5640594E42E90BD94A40485167EE21EB5640594E42E90BD94A40
73059	59627	92.815192999999994	93.033663000000004	56.005187999999997	55.997487	Энергетиков	0103000020E6100000010000000500000066BB421F2C345740B3976DA7ADFF4B4066BB421F2C345740732A1900AA004C407505DB8827425740732A1900AA004C407505DB8827425740B3976DA7ADFF4B4066BB421F2C345740B3976DA7ADFF4B40
73106	59838	92.981048999999999	92.985522000000003	56.169663999999997	56.159588999999997	Центральная	0103000020E6100000010000000500000081B1BE81C93E574092E68F696D144C4081B1BE81C93E57407EA7C98CB7154C4044DFDDCA123F57407EA7C98CB7154C4044DFDDCA123F574092E68F696D144C4081B1BE81C93E574092E68F696D144C40
73351	59914	90.525773000000001	90.529510000000002	56.284213999999999	56.277797999999997	Школьная	0103000020E61000000100000005000000AB07CC43A6A15640757286E28E234C40AB07CC43A6A156405D88D51F61244C40EB39E97DE3A156405D88D51F61244C40EB39E97DE3A15640757286E28E234C40AB07CC43A6A15640757286E28E234C40
27837	25330	95.155448000000007	95.182128000000006	55.386062000000003	55.371332000000002	Центральная	0103000020E61000000100000005000000A20E2BDCF2C95740A9FA95CE87AF4B40A20E2BDCF2C957403B1DC87A6AB14B40E6EB32FCA7CB57403B1DC87A6AB14B40E6EB32FCA7CB5740A9FA95CE87AF4B40A20E2BDCF2C95740A9FA95CE87AF4B40
28634	21413	95.124275999999995	95.145287999999994	55.353217000000001	55.339094000000003	Центральная	0103000020E610000001000000050000005FEB5223F4C757408A22A46E67AB4B405FEB5223F4C7574014B2F33636AD4B4014200A664CC9574014B2F33636AD4B4014200A664CC957408A22A46E67AB4B405FEB5223F4C757408A22A46E67AB4B40
27748	29363	94.762703999999999	94.808231000000006	55.449899000000002	55.433450000000001	Советская	0103000020E61000000100000005000000D1217024D0B05740C139234A7BB74B40D1217024D0B0574066C0594A96B94B404227840EBAB3574066C0594A96B94B404227840EBAB35740C139234A7BB74B40D1217024D0B05740C139234A7BB74B40
28604	29033	95.260909999999996	95.304029	55.141593	55.129865000000002	Антонова	0103000020E61000000100000005000000C24CDBBFB2D0574091F2936A9F904B40C24CDBBFB2D05740D82B2CB81F924B4047020D3675D35740D82B2CB81F924B4047020D3675D3574091F2936A9F904B40C24CDBBFB2D0574091F2936A9F904B40
72898	1042	95.016946000000004	95.062911999999997	55.422789000000002	55.415895999999996	Ковалева	0103000020E6100000010000000500000013F3ACA415C15740C34483143CB54B4013F3ACA415C15740E50D30F31DB64B40A9A10DC006C45740E50D30F31DB64B40A9A10DC006C45740C34483143CB54B4013F3ACA415C15740C34483143CB54B40
28070	29298	94.73536	94.757045000000005	55.325482000000001	55.316876999999998	Советская	0103000020E6100000010000000500000057B2632310AF574063EDEF6C8FA84B4057B2632310AF5740E5B7E864A9A94B406C26DF6C73B05740E5B7E864A9A94B406C26DF6C73B0574063EDEF6C8FA84B4057B2632310AF574063EDEF6C8FA84B40
72868	47044	94.844477999999995	94.874454999999998	55.183559000000002	55.177441999999999	Ленина	0103000020E61000000100000005000000410C74ED0BB65740EA77616BB6964B40410C74ED0BB6574078F17EDC7E974B40B7B41A12F7B7574078F17EDC7E974B40B7B41A12F7B75740EA77616BB6964B40410C74ED0BB65740EA77616BB6964B40
72673	59660	94.871131000000005	94.881929	55.245942999999997	55.241283000000003	Центральная	0103000020E6100000010000000500000009E23C9CC0B75740570A815CE29E4B4009E23C9CC0B757400ED76A0F7B9F4B403719558671B857400ED76A0F7B9F4B403719558671B85740570A815CE29E4B4009E23C9CC0B75740570A815CE29E4B40
72747	29018	95.102483000000007	95.123513000000003	55.013353000000002	55.000982999999998	Школьный	0103000020E610000001000000050000005859DB148FC657400D6D003620804B405859DB148FC65740D926158DB5814B4060E811A3E7C75740D926158DB5814B4060E811A3E7C757400D6D003620804B405859DB148FC657400D6D003620804B40
72910	59726	94.625864000000007	94.650324999999995	55.238131000000003	55.219324	Центральная	0103000020E610000001000000050000009AEFE0270EA857402C9D0FCF129C4B409AEFE0270EA85740F7949C137B9E4B405BB1BFEC9EA95740F7949C137B9E4B405BB1BFEC9EA957402C9D0FCF129C4B409AEFE0270EA857402C9D0FCF129C4B40
28355	46790	95.044613999999996	95.074742999999998	55.325636000000003	55.311681999999998	Кузьмина	0103000020E6100000010000000500000066BCADF4DAC257403D601E32E5A74B4066BCADF4DAC257403C33C170AEA94B40B726DD96C8C457403C33C170AEA94B40B726DD96C8C457403D601E32E5A74B4066BCADF4DAC257403D601E32E5A74B40
28548	19970	94.971778	95.005482999999998	55.551451	55.535711999999997	Я.Стоценко	0103000020E610000001000000050000003A3E5A9C31BE57409109F83592C44B403A3E5A9C31BE57405A2C45F295C64B40C66B5ED559C057405A2C45F295C64B40C66B5ED559C057409109F83592C44B403A3E5A9C31BE57409109F83592C44B40
72652	19970	94.971778	95.005482999999998	55.551451	55.535711999999997	Новая	0103000020E610000001000000050000003A3E5A9C31BE57409109F83592C44B403A3E5A9C31BE57405A2C45F295C64B40C66B5ED559C057405A2C45F295C64B40C66B5ED559C057409109F83592C44B403A3E5A9C31BE57409109F83592C44B40
72854	48514	94.753380000000007	94.779286999999997	55.133411000000002	55.121932000000001	Ленина	0103000020E61000000100000005000000795DBF6037B05740FE2AC0779B8F4B40795DBF6037B057409DF6949C13914B40ABCC94D6DFB157409DF6949C13914B40ABCC94D6DFB15740FE2AC0779B8F4B40795DBF6037B05740FE2AC0779B8F4B40
72984	29265	94.670357999999993	94.708445999999995	55.279451999999999	55.273297999999997	Советская	0103000020E610000001000000050000002AA73D25E7AA5740F607CA6DFBA24B402AA73D25E7AA5740A1664815C5A34B40D93EE42D57AD5740A1664815C5A34B40D93EE42D57AD5740F607CA6DFBA24B402AA73D25E7AA5740F607CA6DFBA24B40
28096	29123	94.654116000000002	94.687550999999999	55.132736999999999	55.125227000000002	Таежная	0103000020E6100000010000000500000095F25A09DDA95740C1C9367007904B4095F25A09DDA957400DFCA886FD904B4041D5E8D500AC57400DFCA886FD904B4041D5E8D500AC5740C1C9367007904B4095F25A09DDA95740C1C9367007904B40
72964	48572	95.073296999999997	95.091012000000006	55.225670999999998	55.205029000000003	Киселева	0103000020E610000001000000050000004679E6E5B0C45740A5DDE8633E9A4B404679E6E5B0C45740EB538EC9E29C4B40CAE2FE23D3C55740EB538EC9E29C4B40CAE2FE23D3C55740A5DDE8633E9A4B404679E6E5B0C45740A5DDE8633E9A4B40
73108	59840	94.931443999999999	94.952123	55.182917000000003	55.170212999999997	Зеленая	0103000020E610000001000000050000008C834BC79CBB5740512D228AC9954B408C834BC79CBB5740F47002D369974B403EB14E95EFBC5740F47002D369974B403EB14E95EFBC5740512D228AC9954B408C834BC79CBB5740512D228AC9954B40
28119	21370	94.687848000000002	94.705922000000001	55.187553000000001	55.173662999999998	Кооперативная	0103000020E610000001000000050000009E279EB305AC57403BC3D4963A964B409E279EB305AC574023A298BC01984B40B9E177D32DAD574023A298BC01984B40B9E177D32DAD57403BC3D4963A964B409E279EB305AC57403BC3D4963A964B40
28365	48705	94.816163000000003	94.837919999999997	55.499566000000002	55.483708999999998	Центральная	0103000020E61000000100000005000000234DBC033CB45740F3E32F2DEABD4B40234DBC033CB45740C61858C7F1BF4B40842A357BA0B55740C61858C7F1BF4B40842A357BA0B55740F3E32F2DEABD4B40234DBC033CB45740F3E32F2DEABD4B40
28515	28710	94.880420000000001	94.931139000000002	55.274585000000002	55.244942000000002	Строительная	0103000020E61000000100000005000000A3AF20CD58B857405BB56B425A9F4B40A3AF20CD58B85740707CED9925A34B40EE4108C897BB5740707CED9925A34B40EE4108C897BB57405BB56B425A9F4B40A3AF20CD58B857405BB56B425A9F4B40
28427	28710	94.880420000000001	94.931139000000002	55.274585000000002	55.244942000000002	Советская	0103000020E61000000100000005000000A3AF20CD58B857405BB56B425A9F4B40A3AF20CD58B85740707CED9925A34B40EE4108C897BB5740707CED9925A34B40EE4108C897BB57405BB56B425A9F4B40A3AF20CD58B857405BB56B425A9F4B40
27734	28710	94.880420000000001	94.931139000000002	55.274585000000002	55.244942000000002	Дружбы	0103000020E61000000100000005000000A3AF20CD58B857405BB56B425A9F4B40A3AF20CD58B85740707CED9925A34B40EE4108C897BB5740707CED9925A34B40EE4108C897BB57405BB56B425A9F4B40A3AF20CD58B857405BB56B425A9F4B40
28325	27226	94.825883000000005	94.837282999999999	55.073489000000002	55.062735000000004	Школьная	0103000020E61000000100000005000000A2D45E44DBB4574044A852B307884B40A2D45E44DBB45740D1CE691668894B40CB9F6F0B96B55740D1CE691668894B40CB9F6F0B96B5574044A852B307884B40A2D45E44DBB4574044A852B307884B40
71514	27226	94.825883000000005	94.837282999999999	55.073489000000002	55.062735000000004	Нефтяников	0103000020E61000000100000005000000A2D45E44DBB4574044A852B307884B40A2D45E44DBB45740D1CE691668894B40CB9F6F0B96B55740D1CE691668894B40CB9F6F0B96B5574044A852B307884B40A2D45E44DBB4574044A852B307884B40
28090	28500	94.857701000000006	94.883078999999995	55.659362999999999	55.653756000000001	Подгорная	0103000020E61000000100000005000000C72FBC92E4B657402AC8CF46AED34B40C72FBC92E4B65740A298BC0166D44B403332C85D84B85740A298BC0166D44B403332C85D84B857402AC8CF46AED34B40C72FBC92E4B657402AC8CF46AED34B40
28095	28619	94.717708000000002	94.752741999999998	55.546016999999999	55.532895000000003	 Советская	0103000020E61000000100000005000000F70489EDEEAD5740D99942E735C44B40F70489EDEEAD5740AF0793E2E3C54B40D714C8EC2CB05740AF0793E2E3C54B40D714C8EC2CB05740D99942E735C44B40F70489EDEEAD5740D99942E735C44B40
73187	9979	94.488906999999998	94.530625000000001	55.932091999999997	55.919502999999999	Энергетиков	0103000020E6100000010000000500000045F295404A9F574075C93846B2F54B4045F295404A9F57407E6E68CA4EF74B40295C8FC2F5A157407E6E68CA4EF74B40295C8FC2F5A1574075C93846B2F54B4045F295404A9F574075C93846B2F54B40
27924	9979	94.488906999999998	94.530625000000001	55.932091999999997	55.919502999999999	Центральная	0103000020E6100000010000000500000045F295404A9F574075C93846B2F54B4045F295404A9F57407E6E68CA4EF74B40295C8FC2F5A157407E6E68CA4EF74B40295C8FC2F5A1574075C93846B2F54B4045F295404A9F574075C93846B2F54B40
72587	9979	94.488906999999998	94.530625000000001	55.932091999999997	55.919502999999999	Просвещения	0103000020E6100000010000000500000045F295404A9F574075C93846B2F54B4045F295404A9F57407E6E68CA4EF74B40295C8FC2F5A157407E6E68CA4EF74B40295C8FC2F5A1574075C93846B2F54B4045F295404A9F574075C93846B2F54B40
28529	9979	94.488906999999998	94.530625000000001	55.932091999999997	55.919502999999999	Новая	0103000020E6100000010000000500000045F295404A9F574075C93846B2F54B4045F295404A9F57407E6E68CA4EF74B40295C8FC2F5A157407E6E68CA4EF74B40295C8FC2F5A1574075C93846B2F54B4045F295404A9F574075C93846B2F54B40
28646	19395	94.736968000000005	94.768714000000003	55.920783999999998	55.895020000000002	Первомайская	0103000020E61000000100000005000000B58CD47B2AAF57400AA2EE0390F24B40B58CD47B2AAF57400C570740DCF54B408D7E349C32B157400C570740DCF54B408D7E349C32B157400AA2EE0390F24B40B58CD47B2AAF57400AA2EE0390F24B40
28236	28098	95.020880000000005	95.039034999999998	55.834359999999997	55.830392000000003	Зеленая	0103000020E61000000100000005000000FE48111956C15740166EF9484AEA4B40FE48111956C15740978BF84ECCEA4B408F19A88C7FC25740978BF84ECCEA4B408F19A88C7FC25740166EF9484AEA4B40FE48111956C15740166EF9484AEA4B40
28587	27683	95.268411	95.283412999999996	56.045623999999997	56.034022999999998	Школьная	0103000020E61000000100000005000000BFB854A52DD15740E9279CDD5A044C40BFB854A52DD15740D3F4D901D7054C40B890477023D25740D3F4D901D7054C40B890477023D25740E9279CDD5A044C40BFB854A52DD15740E9279CDD5A044C40
72955	28434	94.940634000000003	94.950802999999993	55.710393000000003	55.705244	Школьная	0103000020E610000001000000050000005DE0F25833BC5740A1D9756F45DA4B405DE0F25833BC574057276728EEDA4B40137CD3F4D9BC574057276728EEDA4B40137CD3F4D9BC5740A1D9756F45DA4B405DE0F25833BC5740A1D9756F45DA4B40
27733	28514	94.727023000000003	94.741585000000001	55.601294000000003	55.593161000000002	Центральная	0103000020E61000000100000005000000261C7A8B87AE57409F211CB3ECCB4B40261C7A8B87AE5740F9A3A833F7CC4B40118DEE2076AF5740F9A3A833F7CC4B40118DEE2076AF57409F211CB3ECCB4B40261C7A8B87AE57409F211CB3ECCB4B40
72941	25870	94.524444000000003	94.529430000000005	55.912143	55.910896000000001	Центральная	0103000020E610000001000000050000005725917D90A157405307793D98F44B405725917D90A157403E23111AC1F44B405DE15D2EE2A157403E23111AC1F44B405DE15D2EE2A157405307793D98F44B405725917D90A157405307793D98F44B40
27737	15423	94.690363000000005	94.725074000000006	55.557245999999999	55.540984999999999	Комсомольская	0103000020E6100000010000000500000095D74AE82EAC5740335019FF3EC54B4095D74AE82EAC5740D5E940D653C74B40844BC79C67AE5740D5E940D653C74B40844BC79C67AE5740335019FF3EC54B4095D74AE82EAC5740335019FF3EC54B40
72748	27647	95.148557999999994	95.158242000000001	56.012461000000002	56.006089000000003	Лесная	0103000020E61000000100000005000000C9E369F981C95740C4EE3B86C7004C40C9E369F981C95740DCBC715298014C40A2B60DA320CA5740DCBC715298014C40A2B60DA320CA5740C4EE3B86C7004C40C9E369F981C95740C4EE3B86C7004C40
28071	18757	94.75797	94.812633000000005	55.786879999999996	55.769478999999997	Трактовая	0103000020E6100000010000000500000058569A9482B05740B9FAB1497EE24B4058569A9482B0574030F0DC7BB8E44B40A0A9D72D02B4574030F0DC7BB8E44B40A0A9D72D02B45740B9FAB1497EE24B4058569A9482B05740B9FAB1497EE24B40
27904	18757	94.75797	94.812633000000005	55.786879999999996	55.769478999999997	Советская	0103000020E6100000010000000500000058569A9482B05740B9FAB1497EE24B4058569A9482B0574030F0DC7BB8E44B40A0A9D72D02B4574030F0DC7BB8E44B40A0A9D72D02B45740B9FAB1497EE24B4058569A9482B05740B9FAB1497EE24B40
28222	32861	94.727975999999998	94.765292000000002	55.679777999999999	55.664116	Садовая	0103000020E610000001000000050000007711A62897AE57400B60CAC001D54B407711A62897AE574028452BF702D74B40FDF84B8BFAB0574028452BF702D74B40FDF84B8BFAB057400B60CAC001D54B407711A62897AE57400B60CAC001D54B40
28213	27308	94.961590999999999	95.037893999999994	55.979081999999998	55.959705999999997	Шахтерская	0103000020E610000001000000050000003048FAB48ABD574032E36DA5D7FA4B403048FAB48ABD5740170D198F52FD4B40BCADF4DA6CC25740170D198F52FD4B40BCADF4DA6CC2574032E36DA5D7FA4B403048FAB48ABD574032E36DA5D7FA4B40
72667	27308	94.961590999999999	95.037893999999994	55.979081999999998	55.959705999999997	Советская	0103000020E610000001000000050000003048FAB48ABD574032E36DA5D7FA4B403048FAB48ABD5740170D198F52FD4B40BCADF4DA6CC25740170D198F52FD4B40BCADF4DA6CC2574032E36DA5D7FA4B403048FAB48ABD574032E36DA5D7FA4B40
27882	27562	95.180340000000001	95.230754000000005	56.013382	55.993594999999999	Южная	0103000020E61000000100000005000000488AC8B08ACB57400C3CF71E2EFF4B40488AC8B08ACB5740732D5A80B6014C40F5DA6CACC4CE5740732D5A80B6014C40F5DA6CACC4CE57400C3CF71E2EFF4B40488AC8B08ACB57400C3CF71E2EFF4B40
28449	27562	95.180340000000001	95.230754000000005	56.013382	55.993594999999999	1-я Центральная	0103000020E61000000100000005000000488AC8B08ACB57400C3CF71E2EFF4B40488AC8B08ACB5740732D5A80B6014C40F5DA6CACC4CE5740732D5A80B6014C40F5DA6CACC4CE57400C3CF71E2EFF4B40488AC8B08ACB57400C3CF71E2EFF4B40
28058	27148	94.495204000000001	94.513907000000003	56.014080999999997	56.006934999999999	Низовая	0103000020E610000001000000050000004C361E6CB19F57405019FF3EE3004C404C361E6CB19F57405B3FFD67CD014C40DF8B2FDAE3A057405B3FFD67CD014C40DF8B2FDAE3A057405019FF3EE3004C404C361E6CB19F57405019FF3EE3004C40
72956	27160	94.511094999999997	94.532968999999994	56.056086000000001	56.041953999999997	Советская	0103000020E610000001000000050000008B89CDC7B5A05740DBF7A8BF5E054C408B89CDC7B5A05740B9E177D32D074C400932022A1CA25740B9E177D32D074C400932022A1CA25740DBF7A8BF5E054C408B89CDC7B5A05740DBF7A8BF5E054C40
73140	59749	\N	\N	\N	\N	Молодежная	\N
27894	27979	95.018805	95.031336999999994	55.809894	55.805785999999998	Центральная	0103000020E610000001000000050000001500E31934C157408EC9E2FE23E74B401500E31934C15740029D499BAAE74B40E789E76C01C25740029D499BAAE74B40E789E76C01C257408EC9E2FE23E74B401500E31934C157408EC9E2FE23E74B40
28240	28295	94.682269000000005	94.698385000000002	55.911371000000003	55.897492999999997	Советская	0103000020E61000000100000005000000C784984BAAAB5740C8B1F50CE1F24B40C784984BAAAB5740ECC20FCEA7F44B4016C1FF56B2AC5740ECC20FCEA7F44B4016C1FF56B2AC5740C8B1F50CE1F24B40C784984BAAAB5740C8B1F50CE1F24B40
28437	27234	94.925955000000002	94.956227999999996	56.096639000000003	56.083185	Трактовая	0103000020E6100000010000000500000055A4C2D842BB574046425BCEA50A4C4055A4C2D842BB57405342B0AA5E0C4C403FE1ECD632BD57405342B0AA5E0C4C403FE1ECD632BD574046425BCEA50A4C4055A4C2D842BB574046425BCEA50A4C40
27900	28125	95.158089000000004	95.167502999999996	55.764465000000001	55.756498000000001	Центральная	0103000020E61000000100000005000000DF3653211ECA5740A5BE2CEDD4E04B40DF3653211ECA5740E4F736FDD9E14B40D7BE805EB8CA5740E4F736FDD9E14B40D7BE805EB8CA5740A5BE2CEDD4E04B40DF3653211ECA5740A5BE2CEDD4E04B40
72893	27986	94.906353999999993	94.916630999999995	55.781317000000001	55.770679000000001	Центральная	0103000020E61000000100000005000000522635B401BA5740645B069CA5E24B40522635B401BA57408867093202E44B40FCDF1115AABA57408867093202E44B40FCDF1115AABA5740645B069CA5E24B40522635B401BA5740645B069CA5E24B40
28448	28595	94.806183000000004	94.837183999999993	55.579566	55.570996000000001	Школьная	0103000020E61000000100000005000000D6E5948098B35740CB129D6516C94B40D6E5948098B35740D0EFFB372FCA4B40012F336C94B55740D0EFFB372FCA4B40012F336C94B55740CB129D6516C94B40D6E5948098B35740CB129D6516C94B40
27728	19343	94.758257999999998	94.823268999999996	55.938819000000002	55.916395999999999	Победы	0103000020E610000001000000050000008BFB8F4C87B05740B517D1764CF54B408BFB8F4C87B0574085EE92382BF84B40E1B37570B0B4574085EE92382BF84B40E1B37570B0B45740B517D1764CF54B408BFB8F4C87B05740B517D1764CF54B40
28532	27440	95.042744999999996	95.069443000000007	56.052169999999997	56.041415999999998	Трактовая	0103000020E6100000010000000500000052448655BCC25740FCC3961E4D054C4052448655BCC2574089EAAD81AD064C40EA7B0DC171C4574089EAAD81AD064C40EA7B0DC171C45740FCC3961E4D054C4052448655BCC25740FCC3961E4D054C40
72959	27440	95.042744999999996	95.069443000000007	56.052169999999997	56.041415999999998	Советская	0103000020E6100000010000000500000052448655BCC25740FCC3961E4D054C4052448655BCC2574089EAAD81AD064C40EA7B0DC171C4574089EAAD81AD064C40EA7B0DC171C45740FCC3961E4D054C4052448655BCC25740FCC3961E4D054C40
28020	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Шолохова	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
28023	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Строителей	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
28132	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Советская	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
28135	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Парковая	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
27808	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Набережная	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
27966	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Заводская	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
71613	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Диктатуры Пролетариата	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
28374	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Гагарина	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
27835	40374	94.546785	94.678038000000001	56.118676000000001	56.050857999999998	Бортникова	0103000020E61000000100000005000000603C8386FEA25740B75ED38382064C40603C8386FEA25740F96871C6300F4C407FDC7EF964AB5740F96871C6300F4C407FDC7EF964AB5740B75ED38382064C40603C8386FEA25740B75ED38382064C40
27928	33106	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	Советская	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
27903	33106	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	Прохорова	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
28164	33106	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	Панина	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
73009	33106	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	Армейская	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
28283	33106	94.668272999999999	94.738522000000003	55.983060999999999	55.933548999999999	3-е Сентября	0103000020E6100000010000000500000030F31DFCC4AA5740541B9C887EF74B4030F31DFCC4AA57408D7C5EF1D4FD4B401958C7F143AF57408D7C5EF1D4FD4B401958C7F143AF5740541B9C887EF74B4030F31DFCC4AA5740541B9C887EF74B40
28436	27744	95.353733000000005	95.362500999999995	55.972630000000002	55.967188999999998	Победы	0103000020E6100000010000000500000006A1BC8FA3D65740850662D9CCFB4B4006A1BC8FA3D65740E38DCC237FFC4B401BF1643733D75740E38DCC237FFC4B401BF1643733D75740850662D9CCFB4B4006A1BC8FA3D65740850662D9CCFB4B40
27880	28425	94.758527000000001	94.780158999999998	55.714095	55.703012999999999	Садовая	0103000020E610000001000000050000008388D4B48BB05740D8D47954FCD94B408388D4B48BB057405A9E077767DB4B4086AB0320EEB157405A9E077767DB4B4086AB0320EEB15740D8D47954FCD94B408388D4B48BB05740D8D47954FCD94B40
28595	27419	94.865956999999995	94.883510000000001	56.009013000000003	56.002842999999999	Центральная	0103000020E6100000010000000500000081AFE8D66BB75740E202D0285D004C4081AFE8D66BB75740931E865627014C4018EC866D8BB85740931E865627014C4018EC866D8BB85740E202D0285D004C4081AFE8D66BB75740E202D0285D004C40
27725	28355	94.754422000000005	94.767635999999996	55.864353000000001	55.854719000000003	Школьная	0103000020E610000001000000050000008258367348B057408A22A46E67ED4B408258367348B0574089997D1EA3EE4B40DDCEBEF220B1574089997D1EA3EE4B40DDCEBEF220B157408A22A46E67ED4B408258367348B057408A22A46E67ED4B40
72746	27519	94.962165999999996	94.983384999999998	55.949229000000003	55.941037000000001	Лесная	0103000020E61000000100000005000000AED4B32094BD5740B9A981E673F84B40AED4B32094BD574018B5FB5580F94B402098A3C7EFBE574018B5FB5580F94B402098A3C7EFBE5740B9A981E673F84B40AED4B32094BD5740B9A981E673F84B40
72751	28055	95.096114	95.119703999999999	55.897629000000002	55.890118000000001	Центральная	0103000020E6100000010000000500000004AC55BB26C657405CCAF962EFF14B4004AC55BB26C657407978CF81E5F24B40D34CF73AA9C757407978CF81E5F24B40D34CF73AA9C757405CCAF962EFF14B4004AC55BB26C657405CCAF962EFF14B40
28441	27895	94.954116999999997	94.985575999999995	55.876666999999998	55.864803000000002	Советская	0103000020E61000000100000005000000B0E3BF4010BD5740C93D5DDDB1EE4B40B0E3BF4010BD5740C03DCF9F36F04B403DEE5BAD13BF5740C03DCF9F36F04B403DEE5BAD13BF5740C93D5DDDB1EE4B40B0E3BF4010BD5740C93D5DDDB1EE4B40
72914	27891	95.166793999999996	95.198953000000003	55.956733	55.942287	40 лет Победы	0103000020E61000000100000005000000D1CABDC0ACCA5740153944DC9CF84B40D1CABDC0ACCA57408200193A76FA4B403B1C5DA5BBCC57408200193A76FA4B403B1C5DA5BBCC5740153944DC9CF84B40D1CABDC0ACCA5740153944DC9CF84B40
28473	27088	94.535528999999997	94.578146000000004	55.997002999999999	55.988067000000001	Советская	0103000020E61000000100000005000000D0436D1B46A25740E0A0BDFA78FE4B40D0436D1B46A25740C78157CB9DFF4B400C94145800A55740C78157CB9DFF4B400C94145800A55740E0A0BDFA78FE4B40D0436D1B46A25740E0A0BDFA78FE4B40
72963	27014	91.697481999999994	91.714595000000003	57.436131000000003	57.424714999999999	Школьная	0103000020E610000001000000050000001DE38A8BA3EC5640718FA50F5DB64C401DE38A8BA3EC5640CAE2FE23D3B74C40A6B8AAECBBED5640CAE2FE23D3B74C40A6B8AAECBBED5640718FA50F5DB64C401DE38A8BA3EC5640718FA50F5DB64C40
28614	51906	91.831241000000006	91.841697999999994	57.593975999999998	57.588712999999998	Портовая	0103000020E610000001000000050000000A86730D33F5564072DD94F25ACB4C400A86730D33F55640F04DD36707CC4C40F3C64961DEF55640F04DD36707CC4C40F3C64961DEF5564072DD94F25ACB4C400A86730D33F5564072DD94F25ACB4C40
28116	51812	92.150107000000006	92.186200999999997	57.776854999999998	57.766568999999997	Мира	0103000020E61000000100000005000000A5F9635A9B0957404F90D8EE1EE24C40A5F9635A9B095740F65D11FC6FE34C40E15E99B7EA0B5740F65D11FC6FE34C40E15E99B7EA0B57404F90D8EE1EE24C40A5F9635A9B0957404F90D8EE1EE24C40
28201	26731	92.295113000000001	92.313321999999999	57.759300000000003	57.750247999999999	Центральная	0103000020E61000000100000005000000F7E7A221E3125740D8F15F2008E04C40F7E7A221E312574029ED0DBE30E14C4082C7B7770D14574029ED0DBE30E14C4082C7B7770D145740D8F15F2008E04C40F7E7A221E3125740D8F15F2008E04C40
28410	26679	92.250322999999995	92.299792999999994	57.634601000000004	57.608559999999997	1 Мая	0103000020E61000000100000005000000F19BC24A05105740AED3484BE5CD4C40F19BC24A051057402481069B3AD14C4076A4FACE2F1357402481069B3AD14C4076A4FACE2F135740AED3484BE5CD4C40F19BC24A05105740AED3484BE5CD4C40
28524	45395	92.163959000000006	92.173193999999995	57.569923000000003	57.560291999999997	Молодежная	0103000020E61000000100000005000000A2B8E34D7E0A5740EF1AF4A5B7C74C40A2B8E34D7E0A57407E1EA33CF3C84C404277499C150B57407E1EA33CF3C84C404277499C150B5740EF1AF4A5B7C74C40A2B8E34D7E0A5740EF1AF4A5B7C74C40
28577	26453	91.888715000000005	91.902028000000001	57.598683999999999	57.588824000000002	Школьная	0103000020E61000000100000005000000BD1DE1B4E0F85640CA8CB7955ECB4C40BD1DE1B4E0F85640B95164ADA1CC4C40E204A6D3BAF95640B95164ADA1CC4C40E204A6D3BAF95640CA8CB7955ECB4C40BD1DE1B4E0F85640CA8CB7955ECB4C40
73044	59787	92.071172000000004	92.084018	57.598157999999998	57.593349000000003	Центральная	0103000020E61000000100000005000000051901158E045740A20E2BDCF2CB4C40051901158E0457409EEBFB7090CC4C409F91088D600557409EEBFB7090CC4C409F91088D60055740A20E2BDCF2CB4C40051901158E045740A20E2BDCF2CB4C40
72843	47650	92.048786000000007	92.056214999999995	57.631262	57.626100999999998	Центральная	0103000020E610000001000000050000002CA0504F1F035740177FDB1324D04C402CA0504F1F035740919A7631CDD04C40DBA2CC0699035740919A7631CDD04C40DBA2CC0699035740177FDB1324D04C402CA0504F1F035740177FDB1324D04C40
27863	47646	92.433183999999997	92.443235999999999	57.875768999999998	57.867612999999999	Бирнасовская	0103000020E61000000100000005000000A1496249B91B5740CF4A5AF10DEF4C40A1496249B91B5740E1ECD63219F04C403B1A87FA5D1C5740E1ECD63219F04C403B1A87FA5D1C5740CF4A5AF10DEF4C40A1496249B91B5740CF4A5AF10DEF4C40
28052	26969	92.226957999999996	92.252443	57.824944000000002	57.822125999999997	Солнечная	0103000020E6100000010000000500000032E4D87A860E57407C98BD6C3BE94C4032E4D87A860E57400684D6C397E94C40AA46AF06281057400684D6C397E94C40AA46AF06281057407C98BD6C3BE94C4032E4D87A860E57407C98BD6C3BE94C40
28409	47574	91.874144999999999	91.888184999999993	57.567717000000002	57.557240999999998	Центральный	0103000020E6100000010000000500000090BDDEFDF1F75640C37E4FAC53C74C4090BDDEFDF1F756400E315EF3AAC84C400EF3E505D8F856400E315EF3AAC84C400EF3E505D8F85640C37E4FAC53C74C4090BDDEFDF1F75640C37E4FAC53C74C40
72842	26578	91.965008999999995	91.979579999999999	57.617010999999998	57.613328000000003	Зелёная	0103000020E610000001000000050000001FD61BB5C2FD56404DDC2A8881CE4C401FD61BB5C2FD5640D9226937FACE4C4034F44F70B1FE5640D9226937FACE4C4034F44F70B1FE56404DDC2A8881CE4C401FD61BB5C2FD56404DDC2A8881CE4C40
28408	47532	92.475046000000006	92.490882999999997	57.584159	57.576993000000002	Зеленая	0103000020E610000001000000050000001F865627671E5740AE8218E8DAC94C401F865627671E57400055DCB8C5CA4C4064CA87A06A1F57400055DCB8C5CA4C4064CA87A06A1F5740AE8218E8DAC94C401F865627671E5740AE8218E8DAC94C40
27854	26364	91.863392000000005	91.892038999999997	57.586938000000004	57.577359999999999	 Центральная	0103000020E6100000010000000500000032E884D041F756406002B7EEE6C94C4032E884D041F75640CC63CDC820CB4C406BF0BE2A17F95640CC63CDC820CB4C406BF0BE2A17F956406002B7EEE6C94C4032E884D041F756406002B7EEE6C94C40
28192	26285	91.992425999999995	92.010122999999993	57.642868	57.634587000000003	Школьная	0103000020E61000000100000005000000CE6C57E883FF5640BFBB95253AD14C40CE6C57E883FF56408DD2A57F49D24C40FE7BF0DAA50057408DD2A57F49D24C40FE7BF0DAA5005740BFBB95253AD14C40CE6C57E883FF5640BFBB95253AD14C40
28415	47619	92.303162	92.325674000000006	57.736203000000003	57.726073	Качаева	0103000020E61000000100000005000000F5D89601671357401AC1C6F5EFDC4C40F5D8960167135740CA1B60E63BDE4C4015CAC2D7D7145740CA1B60E63BDE4C4015CAC2D7D71457401AC1C6F5EFDC4C40F5D89601671357401AC1C6F5EFDC4C40
28195	26551	92.439958000000004	92.451851000000005	57.661231000000001	57.655535	Березовая	0103000020E6100000010000000500000045679945281C574012312592E8D34C4045679945281C5740FA0CA837A3D44C408EEA7420EB1C5740FA0CA837A3D44C408EEA7420EB1C574012312592E8D34C4045679945281C574012312592E8D34C40
28574	26259	92.204006000000007	92.219842999999997	57.469929999999998	57.463124000000001	Молодёжная	0103000020E61000000100000005000000058C2E6F0E0D574011FFB0A547BB4C40058C2E6F0E0D574063B48EAA26BC4C404AD05FE8110E574063B48EAA26BC4C404AD05FE8110E574011FFB0A547BB4C40058C2E6F0E0D574011FFB0A547BB4C40
28207	47674	92.155253999999999	92.172905999999998	57.826113999999997	57.815933000000001	Дзержинского	0103000020E61000000100000005000000AF2479AEEF095740145D177E70E84C40AF2479AEEF0957404562821ABEE94C400FD253E4100B57404562821ABEE94C400FD253E4100B5740145D177E70E84C40AF2479AEEF095740145D177E70E84C40
72816	26169	91.387240000000006	91.404388999999995	57.494518999999997	57.488351000000002	Советская	0103000020E61000000100000005000000FFEC478AC8D8564005FC1A4982BE4C40FFEC478AC8D8564014200A664CBF4C402D776682E1D9564014200A664CBF4C402D776682E1D9564005FC1A4982BE4C40FFEC478AC8D8564005FC1A4982BE4C40
72847	26169	91.387240000000006	91.404388999999995	57.494518999999997	57.488351000000002	Партизанская	0103000020E61000000100000005000000FFEC478AC8D8564005FC1A4982BE4C40FFEC478AC8D8564014200A664CBF4C402D776682E1D9564014200A664CBF4C402D776682E1D9564005FC1A4982BE4C40FFEC478AC8D8564005FC1A4982BE4C40
73016	59765	93.565897000000007	94.957898999999998	55.619798000000003	54.414496999999997	улица Школьная	0103000020E61000000100000005000000E4F90CA83764574022A5D93C0E354B40E4F90CA8376457402810768A55CF4B40C0779B374EBD57402810768A55CF4B40C0779B374EBD574022A5D93C0E354B40E4F90CA83764574022A5D93C0E354B40
27846	25617	94.060878000000002	94.105092999999997	55.472040999999997	55.463757999999999	 Центральная	0103000020E61000000100000005000000F0C2D66CE583574012A1116C5CBB4B40F0C2D66CE583574081AFE8D66BBC4B407782FDD7B986574081AFE8D66BBC4B407782FDD7B986574012A1116C5CBB4B40F0C2D66CE583574012A1116C5CBB4B40
9786	19039	93.981780999999998	94.010985000000005	54.952615000000002	54.935136	Гагарина	0103000020E6100000010000000500000063B5F97FD57E5740F8A75489B2774B4063B5F97FD57E5740EB56CF49EF794B40C8EF6DFAB3805740EB56CF49EF794B40C8EF6DFAB3805740F8A75489B2774B4063B5F97FD57E5740F8A75489B2774B40
28624	24599	94.484622000000002	94.500377999999998	55.505046999999998	55.491177	Советская	0103000020E61000000100000005000000043BFE0B049F574011C64FE3DEBE4B40043BFE0B049F5740B1F84D61A5C04B40D368723106A05740B1F84D61A5C04B40D368723106A0574011C64FE3DEBE4B40043BFE0B049F574011C64FE3DEBE4B40
72942	25384	94.224344000000002	94.251608000000004	55.300936	55.290197999999997	Партизанская	0103000020E6100000010000000500000072C3EFA65B8E5740ABAE433525A54B4072C3EFA65B8E57403318231285A64B405EDA70581A9057403318231285A64B405EDA70581A905740ABAE433525A54B4072C3EFA65B8E5740ABAE433525A54B40
28130	26107	94.360690000000005	94.429016000000004	55.514682000000001	55.487774999999999	Советская	0103000020E61000000100000005000000A27F828B15975740386744696FBE4B40A27F828B1597574081EB8A19E1C14B407D5D86FF749B574081EB8A19E1C14B407D5D86FF749B5740386744696FBE4B40A27F828B15975740386744696FBE4B40
28189	26107	94.360690000000005	94.429016000000004	55.514682000000001	55.487774999999999	 60 лет СССР	0103000020E61000000100000005000000A27F828B15975740386744696FBE4B40A27F828B1597574081EB8A19E1C14B407D5D86FF749B574081EB8A19E1C14B407D5D86FF749B5740386744696FBE4B40A27F828B15975740386744696FBE4B40
27971	17737	94.276589999999999	94.300466999999998	55.551833000000002	55.538677	Центральная	0103000020E61000000100000005000000A4198BA6B3915740BF0D315EF3C44B40A4198BA6B391574042EDB776A2C64B40BEA1F0D93A93574042EDB776A2C64B40BEA1F0D93A935740BF0D315EF3C44B40A4198BA6B3915740BF0D315EF3C44B40
72788	47195	94.540946000000005	94.573105999999996	55.293678999999997	55.277036000000003	Кирова	0103000020E61000000100000005000000BBB9F8DB9EA2574047E867EA75A34B40BBB9F8DB9EA25740D042024697A54B400CC9C9C4ADA45740D042024697A54B400CC9C9C4ADA4574047E867EA75A34B40BBB9F8DB9EA2574047E867EA75A34B40
72951	25948	94.122007999999994	94.149199999999993	54.983989999999999	54.971826999999998	Школьная	0103000020E610000001000000050000006C76A4FACE875740552FBFD3647C4B406C76A4FACE875740A7CB6262F37D4B400B24287E8C895740A7CB6262F37D4B400B24287E8C895740552FBFD3647C4B406C76A4FACE875740552FBFD3647C4B40
72633	26017	93.941833000000003	93.964893000000004	54.967852999999998	54.951099999999997	Лесная	0103000020E61000000100000005000000CA52EBFD467C5740E09C11A5BD794B40CA52EBFD467C5740F12A6B9BE27B4B40EBC891CEC07D5740F12A6B9BE27B4B40EBC891CEC07D5740E09C11A5BD794B40CA52EBFD467C5740E09C11A5BD794B40
28185	25506	94.050044	94.083029999999994	55.546812000000003	55.523800000000001	Зеленая	0103000020E610000001000000050000001BD7BFEB3383574089D2DEE00BC34B401BD7BFEB33835740BA8784EFFDC54B408FA50F5D50855740BA8784EFFDC54B408FA50F5D5085574089D2DEE00BC34B401BD7BFEB3383574089D2DEE00BC34B40
72949	25926	94.054885999999996	94.096029000000001	55.113529	55.088728000000003	Берегового	0103000020E6100000010000000500000087C0914083835740A81E69705B8B4B4087C0914083835740E412471E888E4B40ED9DD15625865740E412471E888E4B40ED9DD15625865740A81E69705B8B4B4087C0914083835740A81E69705B8B4B40
28040	25863	93.985247999999999	94.026077000000001	55.347802000000001	55.332053000000002	Центральная	0103000020E61000000100000005000000C39CA04D0E7F5740F4C473B680AA4B40C39CA04D0E7F5740E0BDA3C684AC4B40618BDD3EAB815740E0BDA3C684AC4B40618BDD3EAB815740F4C473B680AA4B40C39CA04D0E7F5740F4C473B680AA4B40
72826	47174	94.475261000000003	94.516915999999995	55.187697	55.184438	Гагарина	0103000020E610000001000000050000001D041DAD6A9E5740E01115AA9B974B401D041DAD6A9E574056478E7406984B40DDB1D82615A1574056478E7406984B40DDB1D82615A15740E01115AA9B974B401D041DAD6A9E5740E01115AA9B974B40
72682	25499	94.103808000000001	94.134009000000006	55.570197	55.546633	Центральная	0103000020E610000001000000050000000B444FCAA48657400AF5F411F8C54B400B444FCAA48657407FA31D37FCC84B40A9177C9A938857407FA31D37FCC84B40A9177C9A938857400AF5F411F8C54B400B444FCAA48657400AF5F411F8C54B40
72602	59632	93.565897000000007	94.957898999999998	55.619798000000003	54.414496999999997	Андреевой	0103000020E61000000100000005000000E4F90CA83764574022A5D93C0E354B40E4F90CA8376457402810768A55CF4B40C0779B374EBD57402810768A55CF4B40C0779B374EBD574022A5D93C0E354B40E4F90CA83764574022A5D93C0E354B40
72662	23136	94.305173999999994	94.348365000000001	55.292802000000002	55.267978999999997	Ленина	0103000020E61000000100000005000000BA6587F887935740E481C8224DA24B40BA6587F887935740091A33897AA54B408C84B69C4B965740091A33897AA54B408C84B69C4B965740E481C8224DA24B40BA6587F887935740E481C8224DA24B40
73028	59775	94.628693999999996	94.643542999999994	55.488570000000003	55.473081999999998	Школьный переулок	0103000020E61000000100000005000000404CC2853CA85740C32973F38DBC4B40404CC2853CA8574043E7357689BE4B4076A4FACE2FA9574043E7357689BE4B4076A4FACE2FA95740C32973F38DBC4B40404CC2853CA85740C32973F38DBC4B40
28010	51794	90.498149999999995	91.788094999999998	55.249099000000001	54.627198999999997	Советская	0103000020E6100000010000000500000027A089B0E19F5640BD8A8C0E48504B4027A089B0E19F5640B03BDD79E29F4B4008C9022670F25640B03BDD79E29F4B4008C9022670F25640BD8A8C0E48504B4027A089B0E19F5640BD8A8C0E48504B40
72825	24862	91.532838999999996	91.545730000000006	55.207701	55.202084999999997	Зеленая	0103000020E6100000010000000500000022C2BF081AE256408E01D9EBDD994B4022C2BF081AE256405A2C45F2959A4B408D9C853DEDE256405A2C45F2959A4B408D9C853DEDE256408E01D9EBDD994B4022C2BF081AE256408E01D9EBDD994B40
28290	24393	91.267799999999994	91.282685000000001	54.937060000000002	54.920738999999998	Народная	0103000020E610000001000000050000009A779CA223D156406C938AC6DA754B409A779CA223D15640E4310395F1774B407784D38217D25640E4310395F1774B407784D38217D256406C938AC6DA754B409A779CA223D156406C938AC6DA754B40
28551	24994	90.976144000000005	91.000478999999999	55.114610999999996	55.108040000000003	Центральная	0103000020E61000000100000005000000F20BAF2479BE564076543541D48D4B40F20BAF2479BE56408461C092AB8E4B406D5512D907C056408461C092AB8E4B406D5512D907C0564076543541D48D4B40F20BAF2479BE564076543541D48D4B40
72744	25183	90.743129999999994	90.783355999999998	54.976142000000003	54.962690000000002	Степная	0103000020E610000001000000050000004BAB21718FAF5640D717096D397B4B404BAB21718FAF564043209738F27C4B400648348122B2564043209738F27C4B400648348122B25640D717096D397B4B404BAB21718FAF5640D717096D397B4B40
28345	24175	91.086448000000004	91.096940000000004	54.746882999999997	54.740749999999998	Школьная	0103000020E610000001000000050000007F33315D88C55640894160E5D05E4B407F33315D88C556401C78B5DC995F4B40276BD44334C656401C78B5DC995F4B40276BD44334C65640894160E5D05E4B407F33315D88C55640894160E5D05E4B40
27980	24160	91.154809999999998	91.167952	54.897163999999997	54.891871999999999	Победы	0103000020E6100000010000000500000000C63368E8C95640EB1B98DC28724B4000C63368E8C9564003931B45D6724B400FD3BEB9BFCA564003931B45D6724B400FD3BEB9BFCA5640EB1B98DC28724B4000C63368E8C95640EB1B98DC28724B40
28522	24260	91.075839000000002	91.084183999999993	54.814014	54.808753000000003	Советская	0103000020E61000000100000005000000BA30D28BDAC456405DC5E23785674B40BA30D28BDAC456403A3E5A9C31684B402CB6494563C556403A3E5A9C31684B402CB6494563C556405DC5E23785674B40BA30D28BDAC456405DC5E23785674B40
28370	33088	90.820547000000005	90.863414000000006	55.100278000000003	55.086315999999997	Мудрова	0103000020E610000001000000050000002E7590D783B456408E8F16670C8B4B402E7590D783B456401041D5E8D58C4B40263ACB2C42B756401041D5E8D58C4B40263ACB2C42B756408E8F16670C8B4B402E7590D783B456408E8F16670C8B4B40
28346	24290	90.978712999999999	90.990803999999997	54.755580999999999	54.747537999999999	Советская	0103000020E61000000100000005000000E2CAD93BA3BE564035423F53AF5F4B40E2CAD93BA3BE56404F3DD2E0B6604B40BE2F2E5569BF56404F3DD2E0B6604B40BE2F2E5569BF564035423F53AF5F4B40E2CAD93BA3BE564035423F53AF5F4B40
28511	23911	90.957800000000006	90.998690999999994	55.021411000000001	54.983922999999997	Школьная	0103000020E61000000100000005000000F7065F984CBD56401F645930F17D4B40F7065F984CBD564028637C98BD824B40CFF3A78DEABF564028637C98BD824B40CFF3A78DEABF56401F645930F17D4B40F7065F984CBD56401F645930F17D4B40
71622	23911	90.957800000000006	90.998690999999994	55.021411000000001	54.983922999999997	Театральная	0103000020E61000000100000005000000F7065F984CBD56401F645930F17D4B40F7065F984CBD564028637C98BD824B40CFF3A78DEABF564028637C98BD824B40CFF3A78DEABF56401F645930F17D4B40F7065F984CBD56401F645930F17D4B40
27937	23911	90.957800000000006	90.998690999999994	55.021411000000001	54.983922999999997	Почтовая	0103000020E61000000100000005000000F7065F984CBD56401F645930F17D4B40F7065F984CBD564028637C98BD824B40CFF3A78DEABF564028637C98BD824B40CFF3A78DEABF56401F645930F17D4B40F7065F984CBD56401F645930F17D4B40
72834	25060	90.762317999999993	90.777805000000001	55.110650999999997	55.098289999999999	Рабочая	0103000020E61000000100000005000000BCC96FD1C9B056400DC347C4948C4B40BCC96FD1C9B056408522DDCF298E4B40946A9F8EC7B156408522DDCF298E4B40946A9F8EC7B156400DC347C4948C4B40BCC96FD1C9B056400DC347C4948C4B40
72802	24940	91.019523000000007	91.054315000000003	55.137234999999997	55.128844999999998	Октябрьская	0103000020E6100000010000000500000045A165DD3FC1564066A032FE7D904B4045A165DD3FC15640EB6E9EEA90914B40AA2B9FE579C35640EB6E9EEA90914B40AA2B9FE579C3564066A032FE7D904B4045A165DD3FC1564066A032FE7D904B40
27773	24817	91.533602000000002	91.545271	55.150647999999997	55.145708999999997	Школьный	0103000020E6100000010000000500000022C5008926E25640CEDDAE97A6924B4022C5008926E25640999A046F48934B40431D56B8E5E25640999A046F48934B40431D56B8E5E25640CEDDAE97A6924B4022C5008926E25640CEDDAE97A6924B40
72741	24718	91.307980999999998	91.324006999999995	55.184741000000002	55.179456999999999	Советская	0103000020E6100000010000000500000085B2F0F5B5D35640E6046D72F8964B4085B2F0F5B5D356407C9DD497A5974B40342BDB87BCD456407C9DD497A5974B40342BDB87BCD45640E6046D72F8964B4085B2F0F5B5D35640E6046D72F8964B40
27819	24563	91.400660999999999	91.429613000000003	54.918928000000001	54.902703000000002	Клубная	0103000020E6100000010000000500000017F2086EA4D9564024809BC58B734B4017F2086EA4D9564079B0C56E9F754B40EF3B86C77EDB564079B0C56E9F754B40EF3B86C77EDB564024809BC58B734B4017F2086EA4D9564024809BC58B734B40
28159	24081	91.177392999999995	91.191361999999998	54.820430999999999	54.811093	Центральная	0103000020E6100000010000000500000084622B685ACB5640DC813AE5D1674B4084622B685ACB5640F2CF0CE203694B409EEC66463FCC5640F2CF0CE203694B409EEC66463FCC5640DC813AE5D1674B4084622B685ACB5640DC813AE5D1674B40
72630	24359	91.199177000000006	91.221131999999997	55.016553999999999	55.005253000000003	Анашкина	0103000020E610000001000000050000006347E350BFCC56405B9A5B21AC804B406347E350BFCC56401A4F04711E824B405706D50627CE56401A4F04711E824B405706D50627CE56405B9A5B21AC804B406347E350BFCC56405B9A5B21AC804B40
28557	25143	90.854611000000006	90.873250999999996	55.123564000000002	55.119332	Береговая	0103000020E6100000010000000500000052F355F2B1B65640E2AE5E45468F4B4052F355F2B1B65640427BF5F1D08F4B40C18C2958E3B75640427BF5F1D08F4B40C18C2958E3B75640E2AE5E45468F4B4052F355F2B1B65640E2AE5E45468F4B40
28179	25293	90.569817999999998	90.595158999999995	54.957774000000001	54.948343999999999	Октябрьская	0103000020E6100000010000000500000004ABEAE577A45640CDAD105663794B4004ABEAE577A45640C47AA356987A4B40E23AC61517A65640C47AA356987A4B40E23AC61517A65640CDAD105663794B4004ABEAE577A45640CDAD105663794B40
72925	24464	91.351046999999994	91.369596999999999	55.040641999999998	55.033605000000001	Партизанская	0103000020E61000000100000005000000F816D68D77D65640B5FD2B2B4D844B40F816D68D77D65640096CCEC133854B40C8EC2C7AA7D75640096CCEC133854B40C8EC2C7AA7D75640B5FD2B2B4D844B40F816D68D77D65640B5FD2B2B4D844B40
27826	24753	91.259769000000006	91.275408999999996	55.097656000000001	55.091262999999998	Центральная	0103000020E61000000100000005000000F0E0270EA0D05640DC2A8881AE8B4B40F0E0270EA0D056400C21E7FD7F8C4B408A01124DA0D156400C21E7FD7F8C4B408A01124DA0D15640DC2A8881AE8B4B40F0E0270EA0D05640DC2A8881AE8B4B40
28446	24506	91.297633000000005	91.318510000000003	54.905513999999997	54.897126999999998	Рабочая	0103000020E61000000100000005000000774D486B0CD35640E6ADBA0ED5724B40774D486B0CD35640FA08FCE1E7734B40BC5CC47762D45640FA08FCE1E7734B40BC5CC47762D45640E6ADBA0ED5724B40774D486B0CD35640E6ADBA0ED5724B40
72820	24664	91.196447000000006	91.215346999999994	55.192923999999998	55.186283000000003	Маяковского	0103000020E610000001000000050000006E19709692CC56408066101FD8974B406E19709692CC5640874ECFBBB1984B40AB92C83EC8CD5640874ECFBBB1984B40AB92C83EC8CD56408066101FD8974B406E19709692CC56408066101FD8974B40
72839	25096	90.739769999999993	90.767653999999993	55.171225999999997	55.154327000000002	Центральная	0103000020E61000000100000005000000F623456458AF5640E5F1B4FCC0934B40F623456458AF5640C91CCBBBEA954B4030293E3E21B15640C91CCBBBEA954B4030293E3E21B15640E5F1B4FCC0934B40F623456458AF5640E5F1B4FCC0934B40
28560	25223	90.837784999999997	90.861079000000004	54.924396999999999	54.920366000000001	Школьная	0103000020E610000001000000050000001405FA449EB55640D82C978DCE754B401405FA449EB55640A0C211A452764B406F1118EB1BB75640A0C211A452764B406F1118EB1BB75640D82C978DCE754B401405FA449EB55640D82C978DCE754B40
28018	24075	91.043086000000002	91.071087000000006	54.877034999999999	54.865009999999998	Октябрьская	0103000020E61000000100000005000000973AC8EBC1C25640425BCEA5B86E4B40973AC8EBC1C256404339D1AE42704B40EE0A7DB08CC456404339D1AE42704B40EE0A7DB08CC45640425BCEA5B86E4B40973AC8EBC1C25640425BCEA5B86E4B40
28285	22605	97.418977999999996	97.446124999999995	56.498629000000001	56.482970000000002	Трактовая	0103000020E6100000010000000500000095EF1989D05A58407D7901F6D13D4C4095EF1989D05A584029EB3713D33F4C40643BDF4F8D5C584029EB3713D33F4C40643BDF4F8D5C58407D7901F6D13D4C4095EF1989D05A58407D7901F6D13D4C40
27965	23032	96.487452000000005	96.507887999999994	56.402774999999998	56.395361999999999	Таллинская	0103000020E61000000100000005000000AB97DF69321F5840630AD6389B324C40AB97DF69321F5840BD5296218E334C40F981AB3C81205840BD5296218E334C40F981AB3C81205840630AD6389B324C40AB97DF69321F5840630AD6389B324C40
27993	23625	96.834245999999993	96.914017000000001	56.135413	56.115931000000003	Мира	0103000020E6100000010000000500000067B4554964355840DACBB6D3D60E4C4067B4554964355840043A933655114C403CBF28417F3A5840043A933655114C403CBF28417F3A5840DACBB6D3D60E4C4067B4554964355840DACBB6D3D60E4C40
27952	21152	96.893320000000003	96.974788000000004	56.180177	56.130240999999998	Молодежная	0103000020E610000001000000050000003737A6272C39584096CCB1BCAB104C403737A6272C395840E63E390A10174C40212235ED623E5840E63E390A10174C40212235ED623E584096CCB1BCAB104C403737A6272C39584096CCB1BCAB104C40
28320	21152	96.893320000000003	96.974788000000004	56.180177	56.130240999999998	Вокзальная	0103000020E610000001000000050000003737A6272C39584096CCB1BCAB104C403737A6272C395840E63E390A10174C40212235ED623E5840E63E390A10174C40212235ED623E584096CCB1BCAB104C403737A6272C39584096CCB1BCAB104C40
72631	51776	96.893320000000003	96.974788000000004	56.180177	56.130240999999998	Советская	0103000020E610000001000000050000003737A6272C39584096CCB1BCAB104C403737A6272C395840E63E390A10174C40212235ED623E5840E63E390A10174C40212235ED623E584096CCB1BCAB104C403737A6272C39584096CCB1BCAB104C40
72634	51776	96.893320000000003	96.974788000000004	56.180177	56.130240999999998	Первомайская	0103000020E610000001000000050000003737A6272C39584096CCB1BCAB104C403737A6272C395840E63E390A10174C40212235ED623E5840E63E390A10174C40212235ED623E584096CCB1BCAB104C403737A6272C39584096CCB1BCAB104C40
27988	23134	96.392652999999996	96.416304999999994	56.471805000000003	56.459547000000001	переулок Западный	0103000020E61000000100000005000000486B0C3A21195840CAFCA36FD23A4C40486B0C3A211958406E8B321B643C4C40520ABABDA41A58406E8B321B643C4C40520ABABDA41A5840CAFCA36FD23A4C40486B0C3A21195840CAFCA36FD23A4C40
72717	59681	92.981048999999999	92.985522000000003	56.169663999999997	56.159588999999997	Центральная	0103000020E6100000010000000500000081B1BE81C93E574092E68F696D144C4081B1BE81C93E57407EA7C98CB7154C4044DFDDCA123F57407EA7C98CB7154C4044DFDDCA123F574092E68F696D144C4081B1BE81C93E574092E68F696D144C40
72905	20905	96.715929000000003	96.762254999999996	56.381898	56.366675000000001	переулок Клубный	0103000020E610000001000000050000008350DEC7D12D584062A1D634EF2E4C408350DEC7D12D584033349E08E2304C40990D32C9C830584033349E08E2304C40990D32C9C830584062A1D634EF2E4C408350DEC7D12D584062A1D634EF2E4C40
28255	23510	96.287074000000004	96.313806999999997	56.475752	56.47175	Центральная	0103000020E610000001000000050000000B62A06B5F125840AAF1D24D623C4C400B62A06B5F125840D8800871E53C4C406090F46915145840D8800871E53C4C406090F46915145840AAF1D24D623C4C400B62A06B5F125840AAF1D24D623C4C40
28247	23127	96.761519000000007	96.772227000000001	56.428109999999997	56.416535000000003	Советская	0103000020E61000000100000005000000171230BABC305840D751D50451354C40171230BABC305840978BF84ECC364C40A585CB2A6C315840978BF84ECC364C40A585CB2A6C315840D751D50451354C40171230BABC305840D751D50451354C40
28649	23127	96.761519000000007	96.772227000000001	56.428109999999997	56.416535000000003	Зеленая	0103000020E61000000100000005000000171230BABC305840D751D50451354C40171230BABC305840978BF84ECC364C40A585CB2A6C315840978BF84ECC364C40A585CB2A6C315840D751D50451354C40171230BABC305840D751D50451354C40
27906	22600	97.634186999999997	97.681331	56.524635000000004	56.502136999999998	Октябрьская 	0103000020E610000001000000050000001823128596685840478E740646404C40182312859668584022AB5B3D27434C4010B056ED9A6B584022AB5B3D27434C4010B056ED9A6B5840478E740646404C401823128596685840478E740646404C40
27925	18235	96.725612999999996	96.747415000000004	56.079518	56.064987000000002	Центральная	0103000020E610000001000000050000005B238271702E584024D5777E51084C405B238271702E5840BFB854A52D0A4C408D62B9A5D52F5840BFB854A52D0A4C408D62B9A5D52F584024D5777E51084C405B238271702E584024D5777E51084C40
27956	23043	96.614033000000006	96.632170000000002	56.090356999999997	56.081823	Центральная	0103000020E610000001000000050000008C6A11514C275840C287122D790A4C408C6A11514C2758407AFB73D1900B4C40CAE02879752858407AFB73D1900B4C40CAE0287975285840C287122D790A4C408C6A11514C275840C287122D790A4C40
72913	59727	96.740686999999994	96.774085999999997	56.277858000000002	56.275838999999998	Дачная	0103000020E61000000100000005000000A164726A672F58400DFB3DB14E234C40A164726A672F58404B77D7D990234C40A79201A08A3158404B77D7D990234C40A79201A08A3158400DFB3DB14E234C40A164726A672F58400DFB3DB14E234C40
72982	14269	96.740686999999994	96.774085999999997	56.277858000000002	56.275838999999998	Набережная	0103000020E61000000100000005000000A164726A672F58400DFB3DB14E234C40A164726A672F58404B77D7D990234C40A79201A08A3158404B77D7D990234C40A79201A08A3158400DFB3DB14E234C40A164726A672F58400DFB3DB14E234C40
28153	23588	96.411580000000001	96.432115999999994	56.439239000000001	56.431251000000003	Молодежная	0103000020E6100000010000000500000003ECA353571A584004AF963B33374C4003ECA353571A58405A10CAFB38384C400305DEC9A71B58405A10CAFB38384C400305DEC9A71B584004AF963B33374C4003ECA353571A584004AF963B33374C40
28109	21588	96.564616999999998	96.594594000000001	56.426622000000002	56.418447	Центральная	0103000020E61000000100000005000000007157AF22245840FE0DDAAB8F354C40007157AF2224584087E0B88C9B364C407619FED30D26584087E0B88C9B364C407619FED30D265840FE0DDAAB8F354C40007157AF22245840FE0DDAAB8F354C40
72908	22509	96.581909999999993	96.603145999999995	56.180708000000003	56.176900000000003	Центральная	0103000020E61000000100000005000000C8CD70033E255840CA54C1A8A4164C40C8CD70033E2558401310937021174C40A52DAEF1992658401310937021174C40A52DAEF199265840CA54C1A8A4164C40C8CD70033E255840CA54C1A8A4164C40
71595	59487	97.157550000000001	97.236789999999999	56.181705000000001	56.146653000000001	Дзержинского	0103000020E61000000100000005000000075F984C154A58401E6E8786C5124C40075F984C154A58408542041C42174C4045813E91274F58408542041C42174C4045813E91274F58401E6E8786C5124C40075F984C154A58401E6E8786C5124C40
27921	22054	97.157550000000001	97.236789999999999	56.181705000000001	56.146653000000001	микрорайон Спутник 	0103000020E61000000100000005000000075F984C154A58401E6E8786C5124C40075F984C154A58408542041C42174C4045813E91274F58408542041C42174C4045813E91274F58401E6E8786C5124C40075F984C154A58401E6E8786C5124C40
28480	22054	97.157550000000001	97.236789999999999	56.181705000000001	56.146653000000001	Семафорная	0103000020E61000000100000005000000075F984C154A58401E6E8786C5124C40075F984C154A58408542041C42174C4045813E91274F58408542041C42174C4045813E91274F58401E6E8786C5124C40075F984C154A58401E6E8786C5124C40
27969	22054	97.157550000000001	97.236789999999999	56.181705000000001	56.146653000000001	Первомайская	0103000020E61000000100000005000000075F984C154A58401E6E8786C5124C40075F984C154A58408542041C42174C4045813E91274F58408542041C42174C4045813E91274F58401E6E8786C5124C40075F984C154A58401E6E8786C5124C40
28314	51848	96.493928999999994	96.572765000000004	56.217615000000002	56.174228999999997	Зеленая	0103000020E61000000100000005000000F16261889C1F5840E481C8224D164C40F16261889C1F58403D0FEECEDA1B4C40C8D2872EA82458403D0FEECEDA1B4C40C8D2872EA8245840E481C8224D164C40F16261889C1F5840E481C8224D164C40
72828	21653	96.493928999999994	96.572765000000004	56.217615000000002	56.174228999999997	Терешковой	0103000020E61000000100000005000000F16261889C1F5840E481C8224D164C40F16261889C1F58403D0FEECEDA1B4C40C8D2872EA82458403D0FEECEDA1B4C40C8D2872EA8245840E481C8224D164C40F16261889C1F5840E481C8224D164C40
28642	21653	96.493928999999994	96.572765000000004	56.217615000000002	56.174228999999997	Новая	0103000020E61000000100000005000000F16261889C1F5840E481C8224D164C40F16261889C1F58403D0FEECEDA1B4C40C8D2872EA82458403D0FEECEDA1B4C40C8D2872EA8245840E481C8224D164C40F16261889C1F5840E481C8224D164C40
28477	21653	96.493928999999994	96.572765000000004	56.217615000000002	56.174228999999997	Лесная	0103000020E61000000100000005000000F16261889C1F5840E481C8224D164C40F16261889C1F58403D0FEECEDA1B4C40C8D2872EA82458403D0FEECEDA1B4C40C8D2872EA8245840E481C8224D164C40F16261889C1F5840E481C8224D164C40
28648	21653	96.493928999999994	96.572765000000004	56.217615000000002	56.174228999999997	Ленина	0103000020E61000000100000005000000F16261889C1F5840E481C8224D164C40F16261889C1F58403D0FEECEDA1B4C40C8D2872EA82458403D0FEECEDA1B4C40C8D2872EA8245840E481C8224D164C40F16261889C1F5840E481C8224D164C40
28591	17906	96.622882000000004	96.652040999999997	56.348337000000001	56.339860999999999	Цетральная	0103000020E6100000010000000500000018D1764CDD275840CA17B490802B4C4018D1764CDD2758404E7E8B4E962C4C40ACA92C0ABB2958404E7E8B4E962C4C40ACA92C0ABB295840CA17B490802B4C4018D1764CDD275840CA17B490802B4C40
28419	22777	96.506236000000001	96.529393999999996	56.264487000000003	56.258963000000001	Центральная	0103000020E61000000100000005000000B403AE2B66205840E1EF17B325214C40B403AE2B66205840CC9BC3B5DA214C40B62C5F97E1215840CC9BC3B5DA214C40B62C5F97E1215840E1EF17B325214C40B403AE2B66205840E1EF17B325214C40
28059	22865	96.948008999999999	96.980474000000001	56.317697000000003	56.301558999999997	Центральная	0103000020E6100000010000000500000013D4F02DAC3C584040683D7C99264C4013D4F02DAC3C5840C784984BAA284C4003250516C03E5840C784984BAA284C4003250516C03E584040683D7C99264C4013D4F02DAC3C584040683D7C99264C40
28482	22232	97.241111000000004	97.256885999999994	56.092069000000002	56.086992000000002	Центральная	0103000020E610000001000000050000002DEDD45C6E4F5840BF81C98D220B4C402DEDD45C6E4F5840DBFCBFEAC80B4C403733FAD170505840DBFCBFEAC80B4C403733FAD170505840BF81C98D220B4C402DEDD45C6E4F5840BF81C98D220B4C40
27795	21190	97.690521000000004	97.711460000000002	56.553699999999999	56.540967000000002	переулок Школьный	0103000020E61000000100000005000000E10CFE7E316C58408D9B1A683E454C40E10CFE7E316C5840C9E53FA4DF464C40611A868F886D5840C9E53FA4DF464C40611A868F886D58408D9B1A683E454C40E10CFE7E316C58408D9B1A683E454C40
28003	18111	96.345760999999996	96.363071000000005	56.064464000000001	56.051048999999999	Центральная	0103000020E61000000100000005000000DDCEBEF2201658402BBF0CC688064C40DDCEBEF2201658407AE2395B40084C4011C8258E3C1758407AE2395B40084C4011C8258E3C1758402BBF0CC688064C40DDCEBEF2201658402BBF0CC688064C40
71585	21288	97.311224999999993	97.369749999999996	56.277628	56.254322000000002	Школьная	0103000020E61000000100000005000000A52C431CEB535840A053909F8D204C40A52C431CEB535840193A765089234C408B6CE7FBA9575840193A765089234C408B6CE7FBA9575840A053909F8D204C40A52C431CEB535840A053909F8D204C40
28210	22767	96.500557999999998	96.527445	56.318336000000002	56.304609999999997	Центральная	0103000020E6100000010000000500000013F06B24092058406C04E275FD264C4013F06B2409205840DA91EA3BBF284C40145CACA8C1215840DA91EA3BBF284C40145CACA8C12158406C04E275FD264C4013F06B24092058406C04E275FD264C40
27908	18157	97.038137000000006	97.065085999999994	56.139676999999999	56.129669	Центральная	0103000020E6100000010000000500000020F12BD6704258400B2769FE98104C4020F12BD6704258406F8099EFE0114C405B5B785E2A4458406F8099EFE0114C405B5B785E2A4458400B2769FE98104C4020F12BD6704258400B2769FE98104C40
28303	21230	96.404006999999993	96.457240999999996	56.211243000000003	56.205765999999997	Центральная	0103000020E61000000100000005000000B9162D40DB1958407A50508A561A4C40B9162D40DB1958402541B8020A1B4C40FB58C16F431D58402541B8020A1B4C40FB58C16F431D58407A50508A561A4C40B9162D40DB1958407A50508A561A4C40
28009	21230	96.404006999999993	96.457240999999996	56.211243000000003	56.205765999999997	Лаптева	0103000020E61000000100000005000000B9162D40DB1958407A50508A561A4C40B9162D40DB1958402541B8020A1B4C40FB58C16F431D58402541B8020A1B4C40FB58C16F431D58407A50508A561A4C40B9162D40DB1958407A50508A561A4C40
28549	22847	97.230717999999996	97.248154	56.245944999999999	56.232298	Молодежная	0103000020E610000001000000050000004E266E15C44E58408E76DCF0BB1D4C404E266E15C44E5840AFCE31207B1F4C40C89750C1E14F5840AFCE31207B1F4C40C89750C1E14F58408E76DCF0BB1D4C404E266E15C44E58408E76DCF0BB1D4C40
28361	22683	97.002437999999998	97.025345000000002	56.348497000000002	56.331149000000003	Центральная	0103000020E610000001000000050000002191B6F127405840338D2617632A4C402191B6F12740584087E0B88C9B2C4C407F87A2409F41584087E0B88C9B2C4C407F87A2409F415840338D2617632A4C402191B6F127405840338D2617632A4C40
27800	2904	90.746813000000003	90.77149	56.012887999999997	56.003234999999997	Садовая	0103000020E6100000010000000500000092CEC0C8CBAF5640ED9925016A004C4092CEC0C8CBAF564063416150A6014C403ACC971760B1564063416150A6014C403ACC971760B15640ED9925016A004C4092CEC0C8CBAF5640ED9925016A004C40
73134	59864	89.959762999999995	89.986002999999997	55.780552	55.773296999999999	Нижняя	0103000020E610000001000000050000004B3ACAC16C7D5640268C6665FBE24B404B3ACAC16C7D5640E869C020E9E34B4081B053AC1A7F5640E869C020E9E34B4081B053AC1A7F5640268C6665FBE24B404B3ACAC16C7D5640268C6665FBE24B40
28265	49407	90.318720999999996	90.328845000000001	55.874237999999998	55.867243000000002	Молодежная	0103000020E6100000010000000500000019E3C3EC65945640AC5791D101EF4B4019E3C3EC65945640D175E107E7EF4B40001DE6CB0B955640D175E107E7EF4B40001DE6CB0B955640AC5791D101EF4B4019E3C3EC65945640AC5791D101EF4B40
27918	21018	90.647773999999998	90.667554999999993	55.807870000000001	55.799112000000001	Гусарова	0103000020E61000000100000005000000BE4C142175A95640ABEB504D49E64B40BE4C142175A95640B3B5BE4868E74B4000529B38B9AA5640B3B5BE4868E74B4000529B38B9AA5640ABEB504D49E64B40BE4C142175A95640ABEB504D49E64B40
28312	49599	90.392814000000001	90.415899999999993	55.796309000000001	55.792017000000001	Заречная	0103000020E610000001000000050000004DDA54DD23995640227024D060E54B404DDA54DD2399564057410C74EDE54B40029A081B9E9A564057410C74EDE54B40029A081B9E9A5640227024D060E54B404DDA54DD23995640227024D060E54B40
28425	19270	90.121557999999993	90.152208999999999	55.739848000000002	55.733964	Центральная	0103000020E610000001000000050000004CA4349BC78756407E384888F2DD4B404CA4349BC78756406901DA56B3DE4B400A4AD1CABD8956406901DA56B3DE4B400A4AD1CABD8956407E384888F2DD4B404CA4349BC78756407E384888F2DD4B40
28433	49478	90.412406000000004	90.443990999999997	55.706665000000001	55.692424000000003	Школьная	0103000020E6100000010000000500000026AB22DC649A5640967B8159A1D84B4026AB22DC649A56402A1DACFF73DA4B40F92D3A596A9C56402A1DACFF73DA4B40F92D3A596A9C5640967B8159A1D84B4026AB22DC649A5640967B8159A1D84B40
28633	20677	90.876575000000003	90.884919999999994	55.833466000000001	55.826695000000001	Центральная	0103000020E61000000100000005000000705F07CE19B8564024624A24D1E94B40705F07CE19B85640FA298E03AFEA4B40E2E47E87A2B85640FA298E03AFEA4B40E2E47E87A2B8564024624A24D1E94B40705F07CE19B8564024624A24D1E94B40
28659	21282	90.349659000000003	90.375225	55.751649	55.742068000000003	Степная	0103000020E61000000100000005000000227024D0609656403EB48F15FCDE4B40227024D0609656401A89D00836E04B4010E9B7AF039856401A89D00836E04B4010E9B7AF039856403EB48F15FCDE4B40227024D0609656403EB48F15FCDE4B40
72814	18967	90.171424000000002	90.187746000000004	55.963793000000003	55.957166999999998	Борьбы	0103000020E61000000100000005000000F86F5E9CF88A5640BCE7C07284FA4B40F86F5E9CF88A56408F8EAB915DFB4B401C7DCC07048C56408F8EAB915DFB4B401C7DCC07048C5640BCE7C07284FA4B40F86F5E9CF88A5640BCE7C07284FA4B40
28099	20610	90.865201999999996	90.886869000000004	55.759217999999997	55.756118000000001	Центральная	0103000020E61000000100000005000000C39B35785FB756405EF58079C8E04B40C39B35785FB756406B44300E2EE14B4085B53176C2B856406B44300E2EE14B4085B53176C2B856405EF58079C8E04B40C39B35785FB756405EF58079C8E04B40
28636	49435	90.529123999999996	90.551940999999999	55.796415000000003	55.787239	Борисенко	0103000020E61000000100000005000000D6E1E82ADDA1564060915F3FC4E44B40D6E1E82ADDA156409D853DEDF0E54B409414580053A356409D853DEDF0E54B409414580053A3564060915F3FC4E44B40D6E1E82ADDA1564060915F3FC4E44B40
28609	18651	90.196100999999999	90.202603999999994	55.860585	55.857537999999998	Клубная	0103000020E61000000100000005000000A06D35EB8C8C5640E38920CEC3ED4B40A06D35EB8C8C5640CE3637A627EE4B407B82C476F78C5640CE3637A627EE4B407B82C476F78C5640E38920CEC3ED4B40A06D35EB8C8C5640E38920CEC3ED4B40
28562	20717	91.035045999999994	91.049096000000006	55.896807000000003	55.889986999999998	Причулымская	0103000020E61000000100000005000000C2F693313EC25640BD6E1118EBF14B40C2F693313EC2564075E95F92CAF24B4053978C6324C3564075E95F92CAF24B4053978C6324C35640BD6E1118EBF14B40C2F693313EC25640BD6E1118EBF14B40
72686	20930	90.676276999999999	90.704555999999997	55.768061000000003	55.749814999999998	Клубная	0103000020E610000001000000050000005E82531F48AB56406E861BF0F9DF4B405E82531F48AB5640A22AA6D24FE24B40D68C0C7217AD5640A22AA6D24FE24B40D68C0C7217AD56406E861BF0F9DF4B405E82531F48AB56406E861BF0F9DF4B40
72923	49058	90.046756000000002	90.053061999999997	55.844430000000003	55.832433999999999	Центральная	0103000020E6100000010000000500000013B9E00CFE8256400B0A83328DEA4B4013B9E00CFE82564072E1404816EC4B4043AA285E6583564072E1404816EC4B4043AA285E658356400B0A83328DEA4B4013B9E00CFE8256400B0A83328DEA4B40
28100	20790	90.428261000000006	90.447198	55.946330000000003	55.927992000000003	 Комсомольская	0103000020E61000000100000005000000BF49D3A0689B56408E791D71C8F64B40BF49D3A0689B5640A29C685721F94B408B355CE49E9C5640A29C685721F94B408B355CE49E9C56408E791D71C8F64B40BF49D3A0689B56408E791D71C8F64B40
28431	49487	90.249964000000006	90.263150999999993	55.642696999999998	55.635894	Полевая	0103000020E610000001000000050000005A4B0169FF8F56407FDC7EF964D14B405A4B0169FF8F5640601E32E543D24B4038BA4A77D7905640601E32E543D24B4038BA4A77D79056407FDC7EF964D14B405A4B0169FF8F56407FDC7EF964D14B40
27915	20566	90.992887999999994	91.017853000000002	55.856451999999997	55.830446999999999	Школьная	0103000020E61000000100000005000000D0251C7A8BBF5640D90759164CEA4B40D0251C7A8BBF5640014C1938A0ED4B40ACC8E88024C15640014C1938A0ED4B40ACC8E88024C15640D90759164CEA4B40D0251C7A8BBF5640D90759164CEA4B40
72765	40386	90.055766000000006	90.064892999999998	55.851838999999998	55.846274999999999	Щетинкина	0103000020E61000000100000005000000A48E8EAB9183564011363CBD52EC4B40A48E8EAB918356408A3A730F09ED4B40512FF834278456408A3A730F09ED4B40512FF8342784564011363CBD52EC4B40A48E8EAB9183564011363CBD52EC4B40
28660	51909	90.626789000000002	90.638979000000006	55.592424000000001	55.583891999999999	Школьная	0103000020E61000000100000005000000861F9C4F1DA85640B1321AF9BCCA4B40861F9C4F1DA85640C9AEB48CD4CB4B402CF52C08E5A85640C9AEB48CD4CB4B402CF52C08E5A85640B1321AF9BCCA4B40861F9C4F1DA85640B1321AF9BCCA4B40
27742	20189	89.836962999999997	89.857059000000007	55.687339999999999	55.672508999999998	Просвещения	0103000020E61000000100000005000000923D42CD9075564001A260C614D64B40923D42CD90755640C79DD2C1FAD74B4085EFFD0DDA765640C79DD2C1FAD74B4085EFFD0DDA76564001A260C614D64B40923D42CD9075564001A260C614D64B40
28085	19072	90.274218000000005	90.293612999999993	55.919497999999997	55.910088999999999	Зеленая	0103000020E610000001000000050000005F7EA7C98C91564084B9DDCB7DF44B405F7EA7C98C915640635E471CB2F54B408C2B2E8ECA925640635E471CB2F54B408C2B2E8ECA92564084B9DDCB7DF44B405F7EA7C98C91564084B9DDCB7DF44B40
71503	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Труда	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
71540	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Полиграфистов	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
27916	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Ленина	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
27827	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Кузнечная	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
71539	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Кравченко	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
71497	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Клубная	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
28286	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Карла Маркса	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
28343	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	К.Маркса	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
28289	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Гуськова	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
28024	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Вокзальная	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
73280	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Борисенко	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
27991	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	Арбузова	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
27987	95	90.312090999999995	90.459370000000007	56.037376999999999	55.985211	30 лет ВЛКСМ	0103000020E610000001000000050000000F98874CF99356406954E0641BFE4B400F98874CF9935640B14F00C5C8044C40DEB06D51669D5640B14F00C5C8044C40DEB06D51669D56406954E0641BFE4B400F98874CF99356406954E0641BFE4B40
72835	49575	90.569647000000003	90.595518999999996	55.636671	55.628301999999998	Подгорная	0103000020E61000000100000005000000EED0B01875A4564075012F336CD04B40EED0B01875A45640E3A7716F7ED14B406249B9FB1CA65640E3A7716F7ED14B406249B9FB1CA6564075012F336CD04B40EED0B01875A4564075012F336CD04B40
73063	59801	90.476600000000005	90.496928999999994	55.693997000000003	55.681812999999998	Московская	0103000020E610000001000000050000008351499D809E56406B7EFCA545D74B408351499D809E5640D542C9E4D4D84B40C6DB4AAFCD9F5640D542C9E4D4D84B40C6DB4AAFCD9F56406B7EFCA545D74B408351499D809E56406B7EFCA545D74B40
72811	48519	90.708292999999998	90.720428999999996	55.928289999999997	55.920133999999997	Школьная	0103000020E6100000010000000500000016BF29AC54AD564005F86EF3C6F54B4016BF29AC54AD5640179AEB34D2F64B40C2853C821BAE5640179AEB34D2F64B40C2853C821BAE564005F86EF3C6F54B4016BF29AC54AD564005F86EF3C6F54B40
27746	20361	89.668869999999998	89.685794999999999	55.994632000000003	55.988056999999998	 Центральная	0103000020E61000000100000005000000A2D11DC4CE6A5640BCCADAA678FE4B40A2D11DC4CE6A56400DC7F31950FF4B40A930B610E46B56400DC7F31950FF4B40A930B610E46B5640BCCADAA678FE4B40A2D11DC4CE6A5640BCCADAA678FE4B40
72745	49504	90.379626000000002	90.386876000000001	55.625857000000003	55.617947000000001	Центральная	0103000020E6100000010000000500000086ADD9CA4B985640A6D425E318CF4B4086ADD9CA4B985640817C09151CD04B40DEE68D93C2985640817C09151CD04B40DEE68D93C2985640A6D425E318CF4B4086ADD9CA4B985640A6D425E318CF4B40
72928	19764	90.015880999999993	90.060653000000002	55.709972	55.691657999999997	Новая	0103000020E610000001000000050000002DE8BD31048156402502D53F88D84B402DE8BD3104815640B189CC5CE0DA4B40E0D91EBDE1835640B189CC5CE0DA4B40E0D91EBDE18356402502D53F88D84B402DE8BD31048156402502D53F88D84B40
28251	19764	90.015880999999993	90.060653000000002	55.709972	55.691657999999997	Вокзальная	0103000020E610000001000000050000002DE8BD31048156402502D53F88D84B402DE8BD3104815640B189CC5CE0DA4B40E0D91EBDE1835640B189CC5CE0DA4B40E0D91EBDE18356402502D53F88D84B402DE8BD31048156402502D53F88D84B40
28573	48237	90.650801000000001	90.679564999999997	55.962679000000001	55.934269999999998	Мира	0103000020E6100000010000000500000010CD3CB9A6A9564024D1CB2896F74B4010CD3CB9A6A95640E3C5C21039FB4B4066A032FE7DAB5640E3C5C21039FB4B4066A032FE7DAB564024D1CB2896F74B4010CD3CB9A6A9564024D1CB2896F74B40
28607	45351	90.266105999999994	90.291942000000006	55.788767999999997	55.785367000000001	Верхняя	0103000020E610000001000000050000003DD175E107915640C72DE6E786E44B403DD175E107915640CF108E59F6E44B400C957F2DAF925640CF108E59F6E44B400C957F2DAF925640C72DE6E786E44B403DD175E107915640C72DE6E786E44B40
27792	19457	90.036524	90.066743000000002	55.803731999999997	55.794659000000003	Центральная	0103000020E610000001000000050000003961C268568256406D3CD862B7E54B403961C26856825640D45FAFB0E0E64B402A8F6E8445845640D45FAFB0E0E64B402A8F6E84458456406D3CD862B7E54B403961C268568256406D3CD862B7E54B40
28629	20016	89.880459999999999	89.907391000000004	55.779727000000001	55.772162999999999	Зеленая	0103000020E61000000100000005000000EA5BE674597856403317B83CD6E24B40EA5BE6745978564073672618CEE34B40D36BB3B1127A564073672618CEE34B40D36BB3B1127A56403317B83CD6E24B40EA5BE674597856403317B83CD6E24B40
28470	49458	90.760358999999994	90.771327999999997	55.705036999999997	55.698968999999998	Верхняя	0103000020E61000000100000005000000088ECBB8A9B056407BF5F1D077D94B40088ECBB8A9B0564027BC04A73EDA4B404D9F1D705DB1564027BC04A73EDA4B404D9F1D705DB156407BF5F1D077D94B40088ECBB8A9B056407BF5F1D077D94B40
72916	49038	89.936182000000002	89.953304000000003	55.896352	55.891365	Цветочная	0103000020E61000000100000005000000A646E867EA7B564047E6913F18F24B40A646E867EA7B564023DA8EA9BBF24B4058C9C7EE027D564023DA8EA9BBF24B4058C9C7EE027D564047E6913F18F24B40A646E867EA7B564047E6913F18F24B40
28460	20347	89.850482999999997	89.874459000000002	56.02937	56.016939000000001	Центральная	0103000020E6100000010000000500000074B33F506E7656407383A10E2B024C4074B33F506E765640E4BD6A65C2034C4058ACE122F7775640E4BD6A65C2034C4058ACE122F77756407383A10E2B024C4074B33F506E7656407383A10E2B024C40
28445	19344	90.051032000000006	90.060410000000005	55.899033000000003	55.892446	Центральная	0103000020E610000001000000050000002BC3B81B4483564017B9A7AB3BF24B402BC3B81B448356402C836A8313F34B407D96E7C1DD8356402C836A8313F34B407D96E7C1DD83564017B9A7AB3BF24B402BC3B81B4483564017B9A7AB3BF24B40
27960	49587	90.436687000000006	90.443038999999999	55.676046999999997	55.668762000000001	Набережная	0103000020E61000000100000005000000A8E507AEF29B56405E6743FE99D54B40A8E507AEF29B56408AC745B588D64B4090F63FC05A9C56408AC745B588D64B4090F63FC05A9C56405E6743FE99D54B40A8E507AEF29B56405E6743FE99D54B40
72932	48918	90.029391000000004	90.044088000000002	55.942630000000001	55.929882999999997	Комсомольская	0103000020E61000000100000005000000FEF2C98AE18156409D0DF96706F74B40FEF2C98AE18156403F1D8F19A8F84B4059897956D28256403F1D8F19A8F84B4059897956D28256409D0DF96706F74B40FEF2C98AE18156409D0DF96706F74B40
72638	33058	90.220768000000007	90.331827000000004	56.054597999999999	56.014885999999997	Зеленая	0103000020E6100000010000000500000037001B10218E56408995D1C8E7014C4037001B10218E5640A8363811FD064C40823B50A73C955640A8363811FD064C40823B50A73C9556408995D1C8E7014C4037001B10218E56408995D1C8E7014C40
28463	33058	90.220768000000007	90.331827000000004	56.054597999999999	56.014885999999997	Верхняя	0103000020E6100000010000000500000037001B10218E56408995D1C8E7014C4037001B10218E5640A8363811FD064C40823B50A73C955640A8363811FD064C40823B50A73C9556408995D1C8E7014C4037001B10218E56408995D1C8E7014C40
72921	19557	90.190602999999996	90.200646000000006	55.789644000000003	55.785549000000003	Школьная	0103000020E610000001000000050000003FE1ECD6328C5640E833A0DE8CE44B403FE1ECD6328C5640C7BDF90D13E54B40B0045262D78C5640C7BDF90D13E54B40B0045262D78C5640E833A0DE8CE44B403FE1ECD6328C5640E833A0DE8CE44B40
72821	19153	90.123930000000001	90.153925000000001	55.794477000000001	55.767246	Элеваторная	0103000020E61000000100000005000000923F1878EE87564050FEEE1D35E24B40923F1878EE8756404C361E6CB1E54B405B423EE8D98956404C361E6CB1E54B405B423EE8D989564050FEEE1D35E24B40923F1878EE87564050FEEE1D35E24B40
28615	19153	90.123930000000001	90.153925000000001	55.794477000000001	55.767246	Новая	0103000020E61000000100000005000000923F1878EE87564050FEEE1D35E24B40923F1878EE8756404C361E6CB1E54B405B423EE8D98956404C361E6CB1E54B405B423EE8D989564050FEEE1D35E24B40923F1878EE87564050FEEE1D35E24B40
28626	19153	90.123930000000001	90.153925000000001	55.794477000000001	55.767246	 Пролетарская	0103000020E61000000100000005000000923F1878EE87564050FEEE1D35E24B40923F1878EE8756404C361E6CB1E54B405B423EE8D98956404C361E6CB1E54B405B423EE8D989564050FEEE1D35E24B40923F1878EE87564050FEEE1D35E24B40
28452	49121	90.507744000000002	90.538304999999994	56.022649999999999	56.010804999999998	Новая	0103000020E6100000010000000500000060AFB0E07EA056400FD1E80E62014C4060AFB0E07EA0564090A0F831E6024C407D91D09673A2564090A0F831E6024C407D91D09673A256400FD1E80E62014C4060AFB0E07EA056400FD1E80E62014C40
28304	21376	90.270669999999996	90.298930999999996	55.692115000000001	55.680239999999998	Заречная	0103000020E61000000100000005000000888043A8529156402CB7B41A12D74B40888043A85291564018096D3997D84B40AD307DAF2193564018096D3997D84B40AD307DAF219356402CB7B41A12D74B40888043A8529156402CB7B41A12D74B40
72947	18923	90.184736999999998	90.232266999999993	55.913120999999997	55.902746999999998	Курская	0103000020E610000001000000050000001D5723BBD28B5640F3C7B4368DF34B401D5723BBD28B564039252026E1F44B40293C6876DD8E564039252026E1F44B40293C6876DD8E5640F3C7B4368DF34B401D5723BBD28B5640F3C7B4368DF34B40
27745	20151	90.026067999999995	90.046746999999996	55.686371000000001	55.674742000000002	Школьная	0103000020E6100000010000000500000037DE1D19AB8156406B9E23F25DD64B4037DE1D19AB8156401FF64201DBD74B40E90B21E7FD8256401FF64201DBD74B40E90B21E7FD8256406B9E23F25DD64B4037DE1D19AB8156406B9E23F25DD64B40
73014	59764	90.012467000000001	90.024045999999998	55.724814000000002	55.720498999999997	Клубная	0103000020E61000000100000005000000DF516342CC8056407DE6AC4F39DC4B40DF516342CC8056406BD784B4C6DC4B4060E63BF8898156406BD784B4C6DC4B4060E63BF8898156407DE6AC4F39DC4B40DF516342CC8056407DE6AC4F39DC4B40
28627	49196	89.841274999999996	89.851748999999998	55.726030999999999	55.719850000000001	Дорожная	0103000020E6100000010000000500000050FC1873D77556404703780B24DC4B4050FC1873D7755640EB707495EEDC4B40A5D93C0E83765640EB707495EEDC4B40A5D93C0E837656404703780B24DC4B4050FC1873D77556404703780B24DC4B40
27723	48976	90.138706999999997	90.155496999999997	55.825617999999999	55.806170999999999	Романова	0103000020E610000001000000050000007B2E5393E0885640E7FD7F9C30E74B407B2E5393E0885640957EC2D9ADE94B401268B0A9F3895640957EC2D9ADE94B401268B0A9F3895640E7FD7F9C30E74B407B2E5393E0885640E7FD7F9C30E74B40
72047	59568	93.244479999999996	95.564684	58.000765000000001	57.726799	Центральная	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
71978	59568	93.244479999999996	95.564684	58.000765000000001	57.726799	Советская	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
28369	51853	93.244479999999996	95.564684	58.000765000000001	57.726799	Оборонная	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
72734	18820	94.180820999999995	94.204042000000001	57.991326000000001	57.977817999999999	Клубная	0103000020E61000000100000005000000855B3E92928B574056B8E52329FD4C40855B3E92928B574056D636C5E3FE4C40AB402D060F8D574056D636C5E3FE4C40AB402D060F8D574056B8E52329FD4C40855B3E92928B574056B8E52329FD4C40
72203	59587	93.244479999999996	95.564684	58.000765000000001	57.726799	Комсомольская	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
72708	59677	93.244479999999996	95.564684	58.000765000000001	57.726799	Центральная	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
72793	59710	93.244479999999996	95.564684	58.000765000000001	57.726799	Центральная	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
72808	59714	93.244479999999996	95.564684	58.000765000000001	57.726799	Строителей	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
73111	51771	93.244479999999996	95.564684	58.000765000000001	57.726799	Просвещения	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
27933	51771	93.244479999999996	95.564684	58.000765000000001	57.726799	4 квартал	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
28145	48195	94.247601000000003	94.256045999999998	57.883735999999999	57.880065999999999	Советская	0103000020E610000001000000050000003E5DDDB1D88F57402829B000A6F04C403E5DDDB1D88F57402026E1421EF14C406211C30E639057402026E1421EF14C406211C30E639057402829B000A6F04C403E5DDDB1D88F57402829B000A6F04C40
72712	59678	93.244479999999996	95.564684	58.000765000000001	57.726799	Шоссейная	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
72730	59678	93.244479999999996	95.564684	58.000765000000001	57.726799	Советская	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
28068	18329	94.361373	94.419107999999994	57.805633999999998	57.783098000000003	Центральная	0103000020E61000000100000005000000132A38BC2097574011C8258E3CE44C40132A38BC20975740D845D1031FE74C407C5F5CAAD29A5740D845D1031FE74C407C5F5CAAD29A574011C8258E3CE44C40132A38BC2097574011C8258E3CE44C40
72926	59730	93.244479999999996	95.564684	58.000765000000001	57.726799	Новая	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
73072	59809	93.244479999999996	95.564684	58.000765000000001	57.726799	Советская	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
28420	17736	91.952028999999996	91.968603000000002	53.694603999999998	53.690973999999997	Вокзальная	0103000020E61000000100000005000000FDF50A0BEEFC5640723106D671D84A40FDF50A0BEEFC5640DCD5ABC8E8D84A40AEF36F97FDFD5640DCD5ABC8E8D84A40AEF36F97FDFD5640723106D671D84A40FDF50A0BEEFC5640723106D671D84A40
28045	17308	92.426483000000005	92.453792000000007	53.823867	53.813155999999999	Хвастанцева	0103000020E6100000010000000500000033535A7F4B1B5740E945ED7E15E84A4033535A7F4B1B574077A04E7974E94A40EFCB99ED0A1D574077A04E7974E94A40EFCB99ED0A1D5740E945ED7E15E84A4033535A7F4B1B5740E945ED7E15E84A40
72623	17934	92.406369999999995	92.431927000000002	53.601661	53.586323	Ленина	0103000020E61000000100000005000000D50451F7011A574041F2CEA10CCB4A40D50451F7011A5740AB23473A03CD4A409AD024B1A41B5740AB23473A03CD4A409AD024B1A41B574041F2CEA10CCB4A40D50451F7011A574041F2CEA10CCB4A40
28042	16648	92.166798	92.199640000000002	53.879541000000003	53.857072000000002	Мира	0103000020E6100000010000000500000072C284D1AC0A57409E280989B4ED4A4072C284D1AC0A5740DE3EABCC94F04A404DBED9E6C60C5740DE3EABCC94F04A404DBED9E6C60C57409E280989B4ED4A4072C284D1AC0A57409E280989B4ED4A40
28412	17492	91.891743000000005	91.905261999999993	53.611742	53.603360000000002	Школьная	0103000020E61000000100000005000000F75B3B5112F9564077DB85E63ACD4A40F75B3B5112F9564079CBD58F4DCE4A40F01307D0EFF9564079CBD58F4DCE4A40F01307D0EFF9564077DB85E63ACD4A40F75B3B5112F9564077DB85E63ACD4A40
72911	16583	91.767694000000006	91.787394000000006	53.788938000000002	53.780549000000001	Трактовая	0103000020E6100000010000000500000078D503E621F1564077F69507E9E34A4078D503E621F156402C499EEBFBE44A4044C4CDA964F256402C499EEBFBE44A4044C4CDA964F2564077F69507E9E34A4078D503E621F1564077F69507E9E34A40
28580	17248	91.833415000000002	91.853123999999994	53.662252000000002	53.654274000000001	Некрасова	0103000020E61000000100000005000000BC3FDEAB56F55640C24F1C40BFD34A40BC3FDEAB56F55640F5DA6CACC4D44A40B1DB679599F65640F5DA6CACC4D44A40B1DB679599F65640C24F1C40BFD34A40BC3FDEAB56F55640C24F1C40BFD34A40
72651	16803	92.052514000000002	92.090648000000002	53.800884000000003	53.790326999999998	Зеленая	0103000020E610000001000000050000004225AE635C035740A912656F29E54A404225AE635C035740E1F1ED5D83E64A40A9DC442DCD055740E1F1ED5D83E64A40A9DC442DCD055740A912656F29E54A404225AE635C035740A912656F29E54A40
28395	16858	92.000313000000006	92.018979999999999	53.904952000000002	53.897212000000003	Комсомольская	0103000020E61000000100000005000000E030D1200500574015CAC2D7D7F24A40E030D1200500574093399677D5F34A40CCD1E3F73601574093399677D5F34A40CCD1E3F73601574015CAC2D7D7F24A40E030D1200500574015CAC2D7D7F24A40
72733	17397	92.027244999999994	92.033973000000003	53.553539000000001	53.545996000000002	Веселая	0103000020E61000000100000005000000B0FECF61BE01574098DF6932E3C54A40B0FECF61BE015740C007AF5DDAC64A409CFC169D2C025740C007AF5DDAC64A409CFC169D2C02574098DF6932E3C54A40B0FECF61BE01574098DF6932E3C54A40
72995	59751	91.665709000000007	91.684231999999994	53.675690000000003	53.672873000000003	Набережная	0103000020E61000000100000005000000C9E9EBF99AEA564043AED4B320D64A40C9E9EBF99AEA5640FC1D8A027DD64A401BB80375CAEB5640FC1D8A027DD64A401BB80375CAEB564043AED4B320D64A40C9E9EBF99AEA564043AED4B320D64A40
28575	16982	91.791157999999996	91.802611999999996	53.601692999999997	53.595568999999998	Юбилейная	0103000020E6100000010000000500000000FE2955A2F2564076C1E09A3BCC4A4000FE2955A2F25640B69DB64604CD4A4023D8B8FE5DF35640B69DB64604CD4A4023D8B8FE5DF3564076C1E09A3BCC4A4000FE2955A2F2564076C1E09A3BCC4A40
28036	16343	91.776156	91.808963000000006	53.881632000000003	53.861989000000001	Мира	0103000020E610000001000000050000000726378AACF156408141D2A755EE4A400726378AACF15640B58D3F51D9F04A40242BBF0CC6F35640B58D3F51D9F04A40242BBF0CC6F356408141D2A755EE4A400726378AACF156408141D2A755EE4A40
28391	16277	91.668323000000001	91.700770000000006	53.940759	53.926054000000001	Советская	0103000020E61000000100000005000000890AD5CDC5EA56403D2AFEEF88F64A40890AD5CDC5EA5640763579CA6AF84A4026016A6AD9EC5640763579CA6AF84A4026016A6AD9EC56403D2AFEEF88F64A40890AD5CDC5EA56403D2AFEEF88F64A40
72739	17642	92.019968000000006	92.050753	53.633915999999999	53.625382999999999	1 Мая	0103000020E61000000100000005000000DCBDDC2747015740B83CD68C0CD04A40DCBDDC2747015740A034D42824D14A4021CB82893F035740A034D42824D14A4021CB82893F035740B83CD68C0CD04A40DCBDDC2747015740B83CD68C0CD04A40
28041	16538	91.765501999999998	91.813885999999997	53.738245999999997	53.721939999999996	переулок Центральный	0103000020E6100000010000000500000072C119FCFDF056404DD6A88768DC4A4072C119FCFDF056408F334DD87EDE4A40062B4EB516F456408F334DD87EDE4A40062B4EB516F456404DD6A88768DC4A4072C119FCFDF056404DD6A88768DC4A40
72798	16760	92.202290000000005	92.227909999999994	53.811459999999997	53.798411000000002	Чапаева	0103000020E61000000100000005000000B493C151F20C574022E2E65432E64A40B493C151F20C57408E01D9EBDDE74A409B1BD313960E57408E01D9EBDDE74A409B1BD313960E574022E2E65432E64A40B493C151F20C574022E2E65432E64A40
28193	16891	91.782201999999998	91.805099999999996	53.527602999999999	53.511868	Ленина	0103000020E610000001000000050000006937FA980FF2564039EFFFE384C14A406937FA980FF25640C022BF7E88C34A409D8026C286F35640C022BF7E88C34A409D8026C286F3564039EFFFE384C14A406937FA980FF2564039EFFFE384C14A40
28399	16959	91.917541999999997	91.931942000000006	53.600966	53.583933000000002	Ленина	0103000020E6100000010000000500000036AD1402B9FA564010070951BECA4A4036AD1402B9FA564004013274ECCC4A4035F10EF0A4FB564004013274ECCC4A4035F10EF0A4FB564010070951BECA4A4036AD1402B9FA564010070951BECA4A40
73094	59828	91.955980999999994	91.990656000000001	53.931573	53.924717999999999	Октябрьская	0103000020E610000001000000050000003BA6EECA2EFD5640E202D0285DF64A403BA6EECA2EFD5640166BB8C83DF74A4084656CE866FF5640166BB8C83DF74A4084656CE866FF5640E202D0285DF64A403BA6EECA2EFD5640E202D0285DF64A40
72668	32811	92.475871999999995	92.511769000000001	53.820076999999998	53.810662000000001	Школьная	0103000020E610000001000000050000004145D5AF741E5740130EBDC5C3E74A404145D5AF741E5740D4997B48F8E84A40D386C3D2C0205740D4997B48F8E84A40D386C3D2C0205740130EBDC5C3E74A404145D5AF741E5740130EBDC5C3E74A40
72909	17710	92.043863000000002	92.063059999999993	53.694322	53.687449000000001	Боровая	0103000020E6100000010000000500000049A0C1A6CE0257407E552E54FED74A4049A0C1A6CE0257405872158BDFD84A40E36BCF2C090457405872158BDFD84A40E36BCF2C090457407E552E54FED74A4049A0C1A6CE0257407E552E54FED74A40
28211	17846	92.294331999999997	92.310339999999997	53.716419999999999	53.706826999999997	Луговая	0103000020E61000000100000005000000A48AE255D61257400377A04E79DA4A40A48AE255D6125740A4198BA6B3DB4A4000A94D9CDC135740A4198BA6B3DB4A4000A94D9CDC1357400377A04E79DA4A40A48AE255D61257400377A04E79DA4A40
27831	16448	91.905586	91.950861000000003	53.972132999999999	53.959040000000002	Калинина	0103000020E61000000100000005000000CA6DFB1EF5F9564026C79DD2C1FA4A40CA6DFB1EF5F95640622EA9DA6EFC4A40AE8218E8DAFC5640622EA9DA6EFC4A40AE8218E8DAFC564026C79DD2C1FA4A40CA6DFB1EF5F9564026C79DD2C1FA4A40
28197	17315	91.888553999999999	91.932822999999999	53.542822999999999	53.524963999999997	Пролетарская	0103000020E61000000100000005000000B8AE9811DEF85640E6C9350532C34A40B8AE9811DEF8564020425C397BC54A40397D3D5FB3FB564020425C397BC54A40397D3D5FB3FB5640E6C9350532C34A40B8AE9811DEF85640E6C9350532C34A40
27870	17799	92.431594000000004	92.450558000000001	53.762582999999999	53.749583000000001	Школьная	0103000020E6100000010000000500000097C9703C9F1B57409C51F355F2DF4A4097C9703C9F1B574027BEDA519CE14A40E0BC38F1D51C574027BEDA519CE14A40E0BC38F1D51C57409C51F355F2DF4A4097C9703C9F1B57409C51F355F2DF4A40
28033	16234	91.786261999999994	91.823210000000003	53.933003999999997	53.910755000000002	Заводская	0103000020E610000001000000050000009A05DA1D52F2564091D5AD9E93F44A409A05DA1D52F25640C284D1AC6CF74A405FEFFE78AFF45640C284D1AC6CF74A405FEFFE78AFF4564091D5AD9E93F44A409A05DA1D52F2564091D5AD9E93F44A40
72901	17429	92.112513000000007	92.144887999999995	53.580801000000001	53.568818999999998	Ленина	0103000020E61000000100000005000000FED7B96933075740F52B9D0FCFC84A40FED7B96933075740F73DEAAF57CA4A404D6551D845095740F73DEAAF57CA4A404D6551D845095740F52B9D0FCFC84A40FED7B96933075740F52B9D0FCFC84A40
27865	17548	92.149783999999997	92.170580000000001	53.498555000000003	53.490841000000003	Юбилейная	0103000020E61000000100000005000000B35DA10F960957409A44BDE0D3BE4A40B35DA10F96095740EF2076A6D0BF4A40825660C8EA0A5740EF2076A6D0BF4A40825660C8EA0A57409A44BDE0D3BE4A40B35DA10F960957409A44BDE0D3BE4A40
72663	59655	91.424627999999998	92.644693000000004	54.032997999999999	53.463943999999998	переулок Молодежный	0103000020E61000000100000005000000D13DEB1A2DDB56407496598462BB4A40D13DEB1A2DDB5640AD6A494739044B4073BD6DA642295740AD6A494739044B4073BD6DA6422957407496598462BB4A40D13DEB1A2DDB56407496598462BB4A40
28051	17607	92.121307000000002	92.144852	53.677204000000003	53.657231000000003	Автомобильная	0103000020E61000000100000005000000A8716F7EC30757406D75392520D44A40A8716F7EC3075740365CE49EAED64A40A7B0524145095740365CE49EAED64A40A7B05241450957406D75392520D44A40A8716F7EC30757406D75392520D44A40
28568	16690	92.097789000000006	92.132266999999999	53.777164999999997	53.757275999999997	Ленина	0103000020E61000000100000005000000263ACB2C42065740D905836BEEE04A40263ACB2C42065740444C89247AE34A40C3D5011077085740444C89247AE34A40C3D5011077085740D905836BEEE04A40263ACB2C42065740D905836BEEE04A40
71602	15241	93.726326999999998	93.773983000000001	55.732033000000001	55.698811999999997	Манская	0103000020E61000000100000005000000EACC3D247C6E5740B306EFAB72D94B40EACC3D247C6E5740E04BE141B3DD4B403D2AFEEF88715740E04BE141B3DD4B403D2AFEEF88715740B306EFAB72D94B40EACC3D247C6E5740B306EFAB72D94B40
71623	15241	93.726326999999998	93.773983000000001	55.732033000000001	55.698811999999997	Ленина	0103000020E61000000100000005000000EACC3D247C6E5740B306EFAB72D94B40EACC3D247C6E5740E04BE141B3DD4B403D2AFEEF88715740E04BE141B3DD4B403D2AFEEF88715740B306EFAB72D94B40EACC3D247C6E5740B306EFAB72D94B40
72896	15116	93.735741000000004	93.775437999999994	55.884645999999996	55.871324000000001	Юности	0103000020E61000000100000005000000E3546B61166F5740261C7A8B87EF4B40E3546B61166F5740C34483143CF14B40D784B4C6A0715740C34483143CF14B40D784B4C6A0715740261C7A8B87EF4B40E3546B61166F5740261C7A8B87EF4B40
12172	41028	\N	\N	\N	\N	Новая	\N
28360	15478	93.841796000000002	93.868224999999995	55.58296	55.572065000000002	Лесная	0103000020E61000000100000005000000D57954FCDF755740D717096D39C94B40D57954FCDF7557402670EB6E9ECA4B40742497FF907757402670EB6E9ECA4B40742497FF90775740D717096D39C94B40D57954FCDF755740D717096D39C94B40
28564	16031	93.748712999999995	93.765044000000003	55.212179999999996	55.196254000000003	Партизанская	0103000020E61000000100000005000000C345EEE9EA6F5740C7DADFD91E994B40C345EEE9EA6F5740C16ED8B6289B4B4011001C7BF6705740C16ED8B6289B4B4011001C7BF6705740C7DADFD91E994B40C345EEE9EA6F5740C7DADFD91E994B40
73017	59766	93.769383000000005	93.779839999999993	55.643895999999998	55.626787	Трактовая	0103000020E610000001000000050000004CC631923D7157406B47718E3AD04B404CC631923D7157403A03232F6BD24B40350708E6E87157403A03232F6BD24B40350708E6E87157406B47718E3AD04B404CC631923D7157406B47718E3AD04B40
28353	15184	93.788329000000004	93.809089	55.931990999999996	55.924143999999998	Центральная	0103000020E61000000100000005000000425F7AFB73725740B665C0594AF64B40425F7AFB737257404A95287B4BF74B406AA33A1DC87357404A95287B4BF74B406AA33A1DC8735740B665C0594AF64B40425F7AFB73725740B665C0594AF64B40
28141	15538	93.935436999999993	93.953097999999997	55.593618999999997	55.579943	Зеленая 	0103000020E61000000100000005000000F99D2633DE7B5740A6457D923BCA4B40F99D2633DE7B574061A417B5FBCB4B4083F8C08EFF7C574061A417B5FBCB4B4083F8C08EFF7C5740A6457D923BCA4B40F99D2633DE7B5740A6457D923BCA4B40
28029	15857	93.631285000000005	93.649772999999996	55.370851000000002	55.353555	Центральная	0103000020E61000000100000005000000255D33F9666857402C2B4D4A41AD4B40255D33F9666857402E58AA0B78AF4B40B9347EE1956957402E58AA0B78AF4B40B9347EE1956957402C2B4D4A41AD4B40255D33F9666857402C2B4D4A41AD4B40
27814	14834	93.609654000000006	93.651236999999995	55.863833	55.846113000000003	Крупской	0103000020E610000001000000050000000AF835920467574038DC476E4DEC4B400AF8359204675740501A6A1492EE4B407D3CF4DDAD695740501A6A1492EE4B407D3CF4DDAD69574038DC476E4DEC4B400AF835920467574038DC476E4DEC4B40
72903	15892	93.656689999999998	93.699242999999996	55.306753	55.275492999999997	Партизанская	0103000020E610000001000000050000000E677E35076A574072A3C85A43A34B400E677E35076A57409679ABAE43A74B403E3DB665C06C57409679ABAE43A74B403E3DB665C06C574072A3C85A43A34B400E677E35076A574072A3C85A43A34B40
72912	14962	93.473990000000001	93.498172999999994	55.833167000000003	55.812503999999997	Железнодорожная	0103000020E61000000100000005000000632827DA555E574041EF8D2100E84B40632827DA555E5740A08D5C37A5EA4B4003B00111E25F5740A08D5C37A5EA4B4003B00111E25F574041EF8D2100E84B40632827DA555E574041EF8D2100E84B40
28348	14972	93.594938999999997	93.625328999999994	55.789588000000002	55.777656	Центральная	0103000020E610000001000000050000005B07077B13665740E3C4573B8AE34B405B07077B1366574033A8363811E54B40620FED630568574033A8363811E54B40620FED6305685740E3C4573B8AE34B405B07077B13665740E3C4573B8AE34B40
72837	15413	93.763356000000002	93.784385	55.567998000000003	55.560896	Здрестова	0103000020E6100000010000000500000025CD1FD3DA705740863AAC70CBC74B4025CD1FD3DA705740C2189128B4C84B40459E245D33725740C2189128B4C84B40459E245D33725740863AAC70CBC74B4025CD1FD3DA705740863AAC70CBC74B40
27947	15088	93.707955999999996	93.739254000000003	55.789127000000001	55.782612999999998	Школьная	0103000020E6100000010000000500000072C0AE264F6D57405436ACA92CE44B4072C0AE264F6D5740FFB1101D02E54B40FB5B02F04F6F5740FFB1101D02E54B40FB5B02F04F6F57405436ACA92CE44B4072C0AE264F6D57405436ACA92CE44B40
27977	15753	93.629956000000007	93.662439000000006	55.420943999999999	55.385872999999997	Кравченко	0103000020E61000000100000005000000D17AF8325168574067B4554964B14B40D17AF8325168574045B9347EE1B54B4014268C66656A574045B9347EE1B54B4014268C66656A574067B4554964B14B40D17AF8325168574067B4554964B14B40
28376	15753	93.629956000000007	93.662439000000006	55.420943999999999	55.385872999999997	Заводская	0103000020E61000000100000005000000D17AF8325168574067B4554964B14B40D17AF8325168574045B9347EE1B54B4014268C66656A574045B9347EE1B54B4014268C66656A574067B4554964B14B40D17AF8325168574067B4554964B14B40
72838	15670	93.346402999999995	93.360883000000001	55.445258000000003	55.439982000000001	Манская	0103000020E610000001000000050000001F0F7D772B565740126A865451B84B401F0F7D772B5657402524D236FEB84B40ACAB02B5185757402524D236FEB84B40ACAB02B518575740126A865451B84B401F0F7D772B565740126A865451B84B40
72915	14757	93.564199000000002	93.602440000000001	55.957101000000002	55.943376000000001	Трактовая	0103000020E61000000100000005000000E65B1FD61B64574068EA758BC0F84B40E65B1FD61B64574005FC1A4982FA4B40587380608E66574005FC1A4982FA4B40587380608E66574068EA758BC0F84B40E65B1FD61B64574068EA758BC0F84B40
28027	15946	93.486980000000003	93.525958000000003	55.174280000000003	55.153832999999999	Советская 	0103000020E61000000100000005000000977329AE2A5F5740D505BCCCB0934B40977329AE2A5F5740672C9ACE4E964B407444BE4BA9615740672C9ACE4E964B407444BE4BA9615740D505BCCCB0934B40977329AE2A5F5740D505BCCCB0934B40
28016	15559	93.762232999999995	93.784547000000003	55.526015999999998	55.505057000000001	Школьная	0103000020E61000000100000005000000A5BBEB6CC8705740D5CE30B5A5C04B40A5BBEB6CC87057401C96067E54C34B4032CB9E04367257401C96067E54C34B4032CB9E0436725740D5CE30B5A5C04B40A5BBEB6CC8705740D5CE30B5A5C04B40
27866	16072	93.785139999999998	93.804147999999998	55.114106	55.106428000000001	Чапаева	0103000020E6100000010000000500000003B2D7BB3F72574079B0C56E9F8D4B4003B2D7BB3F725740812381069B8E4B4034492C2977735740812381069B8E4B4034492C297773574079B0C56E9F8D4B4003B2D7BB3F72574079B0C56E9F8D4B40
28349	15037	93.664128000000005	93.718045000000004	55.826261000000002	55.799441000000002	Линейная 	0103000020E61000000100000005000000E816BA12816A5740700A2B1554E64B40E816BA12816A5740EA7AA2EBC2E94B409B030473F46D5740EA7AA2EBC2E94B409B030473F46D5740700A2B1554E64B40E816BA12816A5740700A2B1554E64B40
28384	16176	93.668547000000004	93.687565000000006	54.859129000000003	54.842283999999999	Вокзальная	0103000020E61000000100000005000000B1355B79C96A5740D7F84CF6CF6B4B40B1355B79C96A5740C90567F0F76D4B40F437A110016C5740C90567F0F76D4B40F437A110016C5740D7F84CF6CF6B4B40B1355B79C96A5740D7F84CF6CF6B4B40
27840	16134	93.909107000000006	93.946997999999994	54.979360999999997	54.965930999999998	Советская	0103000020E61000000100000005000000246420CF2E7A5740A69883A0A37B4B40246420CF2E7A57402AFD84B35B7D4B4027D87F9D9B7C57402AFD84B35B7D4B4027D87F9D9B7C5740A69883A0A37B4B40246420CF2E7A5740A69883A0A37B4B40
28158	14816	93.590933000000007	93.600087000000002	55.895434000000002	55.888255000000001	Мирная	0103000020E610000001000000050000002448A5D8D165574016C1FF56B2F14B402448A5D8D1655740FDDCD0949DF24B404EF04DD367665740FDDCD0949DF24B404EF04DD36766574016C1FF56B2F14B402448A5D8D165574016C1FF56B2F14B40
72790	15329	93.773758000000001	93.801094000000006	55.679164	55.668280000000003	Мира	0103000020E610000001000000050000002D414640857157401349F4328AD54B402D414640857157406E4F90D8EED64B4066C1C41F457357406E4F90D8EED64B4066C1C41F457357401349F4328AD54B402D414640857157401349F4328AD54B40
28367	15621	93.391380999999996	93.437348	55.444941	55.417000000000002	Юбилейная	0103000020E61000000100000005000000A6D1E4620C5957404C37894160B54B40A6D1E4620C59574024D3A1D3F3B84B40253E7782FD5B574024D3A1D3F3B84B40253E7782FD5B57404C37894160B54B40A6D1E4620C5957404C37894160B54B40
28180	15988	93.380996999999994	93.403868000000003	55.131753000000003	55.115012	Мира	0103000020E61000000100000005000000F1B73D4162585740E35295B6B88E4B40F1B73D416258574030134548DD904B40A9F92AF9D859574030134548DD904B40A9F92AF9D8595740E35295B6B88E4B40F1B73D4162585740E35295B6B88E4B40
28440	51865	92.954116999999997	92.975658999999993	56.010900999999997	56.005932999999999	Московская	0103000020E61000000100000005000000B0E3BF40103D5740CC7B9C69C2004C40B0E3BF40103D5740313F373465014C4013437232713E5740313F373465014C4013437232713E5740CC7B9C69C2004C40B0E3BF40103D5740CC7B9C69C2004C40
28203	12893	93.440357000000006	93.454982000000001	54.541849999999997	54.532338000000003	Школьная	0103000020E61000000100000005000000246420CF2E5C57408335CEA623444B40246420CF2E5C574036AB3E575B454B403291D26C1E5D574036AB3E575B454B403291D26C1E5D57408335CEA623444B40246420CF2E5C57408335CEA623444B40
28155	12893	93.440357000000006	93.454982000000001	54.541849999999997	54.532338000000003	Кравченко	0103000020E61000000100000005000000246420CF2E5C57408335CEA623444B40246420CF2E5C574036AB3E575B454B403291D26C1E5D574036AB3E575B454B403291D26C1E5D57408335CEA623444B40246420CF2E5C57408335CEA623444B40
72692	12219	92.273554000000004	92.296766000000005	53.948315999999998	53.931731999999997	Ленина	0103000020E6100000010000000500000029ECA2E8811157407E5182FE42F74A4029ECA2E88111574003232F6B62F94A402524D236FE12574003232F6B62F94A402524D236FE1257407E5182FE42F74A4029ECA2E8811157407E5182FE42F74A40
27811	14671	93.579875000000001	93.672752000000003	54.408056999999999	54.392695000000003	Заречная	0103000020E61000000100000005000000273108AC1C655740C0266BD443324B40273108AC1C655740B2F336363B344B406494675E0E6B5740B2F336363B344B406494675E0E6B5740C0266BD443324B40273108AC1C655740C0266BD443324B40
28643	14322	93.719517999999994	93.751300000000001	53.883532000000002	53.870080999999999	Октябрьская	0103000020E6100000010000000500000088B839950C6E57407CEF6FD05EEF4A4088B839950C6E5740187C9A9317F14A40075F984C15705740187C9A9317F14A40075F984C157057407CEF6FD05EEF4A4088B839950C6E57407CEF6FD05EEF4A40
27861	14322	93.719517999999994	93.751300000000001	53.883532000000002	53.870080999999999	Лесная	0103000020E6100000010000000500000088B839950C6E57407CEF6FD05EEF4A4088B839950C6E5740187C9A9317F14A40075F984C15705740187C9A9317F14A40075F984C157057407CEF6FD05EEF4A4088B839950C6E57407CEF6FD05EEF4A40
28324	13057	92.152199999999993	96.685323999999994	54.913696000000002	53.363897000000001	Молодежная	0103000020E61000000100000005000000E09C11A5BD095740670E492D94AE4A40E09C11A5BD095740363E93FDF3744B407DCA3159DC2B5840363E93FDF3744B407DCA3159DC2B5840670E492D94AE4A40E09C11A5BD095740670E492D94AE4A40
27805	14231	93.506527000000006	93.530987999999994	53.929080999999996	53.920135999999999	Центральная	0103000020E61000000100000005000000A0E238F06A605740A6EF3504C7F54A40A0E238F06A605740E02A4F20ECF64A4061A417B5FB615740E02A4F20ECF64A4061A417B5FB615740A6EF3504C7F54A40A0E238F06A605740A6EF3504C7F54A40
72889	13534	92.595510000000004	92.605562000000006	54.192357999999999	54.182954000000002	Трудовая	0103000020E61000000100000005000000399CF9D51C265740115663096B174B40399CF9D51C265740DE8FDB2F9F184B40D36C1E87C1265740DE8FDB2F9F184B40D36C1E87C1265740115663096B174B40399CF9D51C265740115663096B174B40
27927	13807	92.772720000000007	92.807565999999994	53.881881	53.873334999999997	Советская	0103000020E61000000100000005000000C53D963E74315740E0B9F770C9EF4A40C53D963E743157405DFB027AE1F04A4023D74D29AF3357405DFB027AE1F04A4023D74D29AF335740E0B9F770C9EF4A40C53D963E74315740E0B9F770C9EF4A40
72586	13807	92.772720000000007	92.807565999999994	53.881881	53.873334999999997	Мира	0103000020E61000000100000005000000C53D963E74315740E0B9F770C9EF4A40C53D963E743157405DFB027AE1F04A4023D74D29AF3357405DFB027AE1F04A4023D74D29AF335740E0B9F770C9EF4A40C53D963E74315740E0B9F770C9EF4A40
28510	13267	92.468147000000002	92.484675999999993	54.002569000000001	53.995185999999997	Клубная	0103000020E610000001000000050000001DAED51EF61D5740F1B73D4162FF4A401DAED51EF61D5740E17D552E54004B40FD497CEE041F5740E17D552E54004B40FD497CEE041F5740F1B73D4162FF4A401DAED51EF61D5740F1B73D4162FF4A40
28456	13126	92.768822	92.786276000000001	54.127549999999999	54.116900999999999	 Горка	0103000020E61000000100000005000000809C30613431574052EFA99CF60E4B40809C3061343157406A4DF38E53104B404D689258523257406A4DF38E53104B404D6892585232574052EFA99CF60E4B40809C30613431574052EFA99CF60E4B40
27780	12387	92.436751000000001	92.460565000000003	53.865471999999997	53.840929000000003	Мира	0103000020E61000000100000005000000B35F77BAF31B574006A1BC8FA3EB4A40B35F77BAF31B574046CD57C9C7EE4A40AA2B9FE5791D574046CD57C9C7EE4A40AA2B9FE5791D574006A1BC8FA3EB4A40B35F77BAF31B574006A1BC8FA3EB4A40
72894	13815	92.844110000000001	92.852661999999995	53.862149000000002	53.843192999999999	Трактовая	0103000020E61000000100000005000000800EF3E505365740AA9B8BBFEDEB4A40800EF3E505365740BAA3FFE55AEE4A40AF22A30392365740BAA3FFE55AEE4A40AF22A30392365740AA9B8BBFEDEB4A40800EF3E505365740AA9B8BBFEDEB4A40
27926	14271	93.646161000000006	93.681383999999994	53.904485000000001	53.895423999999998	Октябрьская	0103000020E61000000100000005000000D8BCAAB35A695740D906EE409DF24A40D8BCAAB35A6957407D5C1B2AC6F34A402101A3CB9B6B57407D5C1B2AC6F34A402101A3CB9B6B5740D906EE409DF24A40D8BCAAB35A695740D906EE409DF24A40
72962	12576	92.565515000000005	92.582932999999997	53.874737000000003	53.861756	Мира	0103000020E610000001000000050000007099D36531245740DE9046054EEE4A407099D36531245740F3CCCB61F7EF4A4096B036C64E255740F3CCCB61F7EF4A4096B036C64E255740DE9046054EEE4A407099D36531245740DE9046054EEE4A40
72958	12176	92.265478000000002	92.285096999999993	54.132820000000002	54.114932000000003	Школьная	0103000020E61000000100000005000000AEF36F97FD105740C7A17E17B60E4B40AEF36F97FD1057409B20EA3E00114B4003CC7C073F1257409B20EA3E00114B4003CC7C073F125740C7A17E17B60E4B40AEF36F97FD105740C7A17E17B60E4B40
28151	14604	92.807647000000003	92.825236000000004	54.220942000000001	54.214677000000002	Центральная	0103000020E610000001000000050000009AED0A7DB0335740091A33897A1B4B409AED0A7DB03357400B28D4D3471C4B40D7DEA7AAD03457400B28D4D3471C4B40D7DEA7AAD0345740091A33897A1B4B409AED0A7DB0335740091A33897A1B4B40
72961	12418	92.586490999999995	92.607196999999999	53.844946	53.832231999999998	Ленина	0103000020E610000001000000050000007E198C1189255740A357039486EA4A407E198C11892557406971C63027EC4A40AD4ECE50DC2657406971C63027EC4A40AD4ECE50DC265740A357039486EA4A407E198C1189255740A357039486EA4A40
72629	14173	93.318985999999995	93.346097	53.970618999999999	53.959823999999998	Школьная	0103000020E61000000100000005000000707841446A5457403CF54883DBFA4A40707841446A54574028F04E3E3DFC4A40990F08742656574028F04E3E3DFC4A40990F0874265657403CF54883DBFA4A40707841446A5457403CF54883DBFA4A40
72632	13186	92.581119000000001	92.597629999999995	54.023435999999997	54.014156999999997	Школьная	0103000020E610000001000000050000006405BF0D31255740360186E5CF014B406405BF0D3125574047C66AF3FF024B40F146E6913F26574047C66AF3FF024B40F146E6913F265740360186E5CF014B406405BF0D31255740360186E5CF014B40
28542	13542	92.900012000000004	92.922298999999995	53.998112999999996	53.972710999999997	Октябрьская	0103000020E610000001000000050000007C80EECB99395740CFBA46CB81FC4A407C80EECB99395740315BB22AC2FF4A408B8862F2063B5740315BB22AC2FF4A408B8862F2063B5740CFBA46CB81FC4A407C80EECB99395740CFBA46CB81FC4A40
27968	12267	92.319627999999994	92.333094000000003	53.987870000000001	53.970194999999997	Комсомольская	0103000020E61000000100000005000000B2B8FFC87414574011DF89592FFC4A40B2B8FFC8741457408A592F8672FE4A409B1F7F69511557408A592F8672FE4A409B1F7F695115574011DF89592FFC4A40B2B8FFC87414574011DF89592FFC4A40
71566	59475	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	Трактовая	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
71520	59475	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	Партизанская	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
71621	59475	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	Новостройка	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
27757	12592	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	Партизанская	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
72690	12592	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	Новостройка	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
28653	12592	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	Монаенко	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
28321	12592	92.610547999999994	92.724607000000006	53.903005	53.863379999999999	Красноярская	0103000020E61000000100000005000000D828EB37132757409F02603C83EE4A40D828EB3713275740EF8FF7AA95F34A40F9DC09F65F2E5740EF8FF7AA95F34A40F9DC09F65F2E57409F02603C83EE4A40D828EB37132757409F02603C83EE4A40
28506	13616	93.073026999999996	93.078794000000002	54.069994000000001	54.067515999999998	Железнодорожников	0103000020E61000000100000005000000662E7079AC44574076FA415DA4084B40662E7079AC44574047753A90F5084B40BF47FDF50A45574047753A90F5084B40BF47FDF50A45574076FA415DA4084B40662E7079AC44574076FA415DA4084B40
28342	14546	93.246519000000006	93.266937999999996	54.345756000000002	54.333122000000003	Центральная	0103000020E61000000100000005000000EEB5A0F7C64F574000CADFBDA32A4B40EEB5A0F7C64F5740A9328CBB412C4B40D1031F8315515740A9328CBB412C4B40D1031F831551574000CADFBDA32A4B40EEB5A0F7C64F574000CADFBDA32A4B40
27815	14457	93.359644000000003	93.402314000000004	54.327272999999998	54.290360999999997	Центральная	0103000020E61000000100000005000000F88C44680457574055849B8C2A254B40F88C44680457574091EEE714E4294B40452E3883BF59574091EEE714E4294B40452E3883BF59574055849B8C2A254B40F88C44680457574055849B8C2A254B40
27942	14457	93.359644000000003	93.402314000000004	54.327272999999998	54.290360999999997	Невского	0103000020E61000000100000005000000F88C44680457574055849B8C2A254B40F88C44680457574091EEE714E4294B40452E3883BF59574091EEE714E4294B40452E3883BF59574055849B8C2A254B40F88C44680457574055849B8C2A254B40
28329	13662	93.250102999999996	93.292080999999996	54.104930000000003	54.085946999999997	Наберажная	0103000020E610000001000000050000006A6803B0015057403B18B14F000B4B406A6803B001505740452FA3586E0D4B401CB28174B1525740452FA3586E0D4B401CB28174B15257403B18B14F000B4B406A6803B0015057403B18B14F000B4B40
27801	14135	93.152608999999998	93.174132999999998	53.911047000000003	53.895907000000001	Береговая	0103000020E61000000100000005000000D1048A58C4495740F5A0A014ADF24A40D1048A58C4495740390F27309DF44A40E109BDFE244B5740390F27309DF44A40E109BDFE244B5740F5A0A014ADF24A40D1048A58C4495740F5A0A014ADF24A40
28531	51890	92.152199999999993	96.685323999999994	54.913696000000002	53.363897000000001	Боровая	0103000020E61000000100000005000000E09C11A5BD095740670E492D94AE4A40E09C11A5BD095740363E93FDF3744B407DCA3159DC2B5840363E93FDF3744B407DCA3159DC2B5840670E492D94AE4A40E09C11A5BD095740670E492D94AE4A40
28149	13388	92.379724999999993	92.389571000000004	54.057760999999999	54.050398000000001	Верхняя	0103000020E610000001000000050000004F1E166A4D18574054E4107173064B404F1E166A4D185740FCFD62B664074B40151E34BBEE185740FCFD62B664074B40151E34BBEE18574054E4107173064B404F1E166A4D18574054E4107173064B40
28156	13415	92.532430000000005	92.539086999999995	54.111797000000003	54.106592999999997	Советская	0103000020E61000000100000005000000325A475513225740C37DE4D6A40D4B40325A4755132257403D65355D4F0E4B40B8ACC266802257403D65355D4F0E4B40B8ACC26680225740C37DE4D6A40D4B40325A475513225740C37DE4D6A40D4B40
27982	13745	93.244281999999998	93.258080000000007	54.169404999999998	54.152540000000002	Лесная	0103000020E610000001000000050000001840F850A24F57407AAA436E86134B401840F850A24F5740B2632310AF154B401CF0F96184505740B2632310AF154B401CF0F961845057407AAA436E86134B401840F850A24F57407AAA436E86134B40
28336	14043	93.097497000000004	93.123700999999997	53.870303999999997	53.859710999999997	Школьная	0103000020E61000000100000005000000529D0E643D465740778192020BEE4A40529D0E643D465740FBC9181F66EF4A40E15E99B7EA475740FBC9181F66EF4A40E15E99B7EA475740778192020BEE4A40529D0E643D465740778192020BEE4A40
28514	13341	92.439284000000001	92.458481000000006	54.097396000000003	54.084409999999998	Ленина	0103000020E61000000100000005000000FD69A33A1D1C574049BA66F2CD0A4B40FD69A33A1D1C57407061DD78770C4B409835B1C0571D57407061DD78770C4B409835B1C0571D574049BA66F2CD0A4B40FD69A33A1D1C574049BA66F2CD0A4B40
72897	13957	92.856613999999993	92.882116999999994	53.820252000000004	53.805925000000002	Береговая	0103000020E61000000100000005000000EDD286C3D2365740B003E78C28E74A40EDD286C3D2365740433D7D04FEE84A40B88FDC9A74385740433D7D04FEE84A40B88FDC9A74385740B003E78C28E74A40EDD286C3D2365740B003E78C28E74A40
28528	13472	92.591853999999998	92.620994999999994	54.129227	54.096043999999999	Центральная	0103000020E610000001000000050000006F8099EFE02557400F7D772B4B0C4B406F8099EFE02557404E61A5828A104B40B0FECF61BE2757404E61A5828A104B40B0FECF61BE2757400F7D772B4B0C4B406F8099EFE02557400F7D772B4B0C4B40
28328	9425	92.913379000000006	92.944396999999995	54.101635000000002	54.068282000000004	Луговая	0103000020E610000001000000050000009B7631CD743A5740E773EE76BD084B409B7631CD743A574082902C60020D4B40315C1D00713C574082902C60020D4B40315C1D00713C5740E773EE76BD084B409B7631CD743A5740E773EE76BD084B40
71574	9425	92.913379000000006	92.944396999999995	54.101635000000002	54.068282000000004	Ленина	0103000020E610000001000000050000009B7631CD743A5740E773EE76BD084B409B7631CD743A574082902C60020D4B40315C1D00713C574082902C60020D4B40315C1D00713C5740E773EE76BD084B409B7631CD743A5740E773EE76BD084B40
28315	12979	92.793040000000005	92.817779999999999	53.944308999999997	53.923493000000001	Ленина	0103000020E61000000100000005000000DF1AD82AC1325740DF8AC40435F64A40DF1AD82AC1325740C328081EDFF84A40AAD4EC8156345740C328081EDFF84A40AAD4EC8156345740DF8AC40435F64A40DF1AD82AC1325740DF8AC40435F64A40
72887	10144	92.658500000000004	92.678775000000002	53.842019000000001	53.835016000000003	Зеленая	0103000020E61000000100000005000000A01A2FDD242A574081D1E5CDE1EA4A40A01A2FDD242A574029CE5147C7EB4A40EA95B20C712B574029CE5147C7EB4A40EA95B20C712B574081D1E5CDE1EA4A40A01A2FDD242A574081D1E5CDE1EA4A40
27992	13256	92.557366999999999	92.571695000000005	54.012315999999998	54.005406000000001	Мира	0103000020E61000000100000005000000A837A3E6AB235740E199D024B1004B40A837A3E6AB235740D89B189293014B405A12A0A696245740D89B189293014B405A12A0A696245740E199D024B1004B40A837A3E6AB235740E199D024B1004B40
28154	14368	93.413811999999993	93.457165000000003	54.364609000000002	54.329546000000001	Ольховская	0103000020E610000001000000050000004FAC53E57B5A5740894336902E2A4B404FAC53E57B5A5740E469F981AB2E4B400EF8FC30425D5740E469F981AB2E4B400EF8FC30425D5740894336902E2A4B404FAC53E57B5A5740894336902E2A4B40
28262	12141	92.221486999999996	92.239363999999995	54.064487999999997	54.038370999999998	Колхозный	0103000020E610000001000000050000004E5FCFD72C0E5740B20E4757E9044B404E5FCFD72C0E5740027E8D2441084B40BEF561BD510F5740027E8D2441084B40BEF561BD510F5740B20E4757E9044B404E5FCFD72C0E5740B20E4757E9044B40
28359	11635	91.882830999999996	91.907094999999998	54.305304	54.286813000000002	Центральная	0103000020E610000001000000050000004739984D80F85640A988D349B6244B404739984D80F8564043AB933314274B405ED72FD80DFA564043AB933314274B405ED72FD80DFA5640A988D349B6244B404739984D80F85640A988D349B6244B40
72874	11635	91.882830999999996	91.907094999999998	54.305304	54.286813000000002	Красных Партизан	0103000020E610000001000000050000004739984D80F85640A988D349B6244B404739984D80F8564043AB933314274B405ED72FD80DFA564043AB933314274B405ED72FD80DFA5640A988D349B6244B404739984D80F85640A988D349B6244B40
28106	11386	91.540087999999997	91.590663000000006	54.325693000000001	54.304704999999998	Советская	0103000020E61000000100000005000000923D42CD90E25640BEF6CC9200274B40923D42CD90E25640A0C4E74EB0294B4044FD2E6CCDE55640A0C4E74EB0294B4044FD2E6CCDE55640BEF6CC9200274B40923D42CD90E25640BEF6CC9200274B40
28261	11386	91.540087999999997	91.590663000000006	54.325693000000001	54.304704999999998	Ленина	0103000020E61000000100000005000000923D42CD90E25640BEF6CC9200274B40923D42CD90E25640A0C4E74EB0294B4044FD2E6CCDE55640A0C4E74EB0294B4044FD2E6CCDE55640BEF6CC9200274B40923D42CD90E25640BEF6CC9200274B40
73201	11059	91.646664000000001	91.668807999999999	54.096677999999997	54.086559999999999	Восточная	0103000020E6100000010000000500000009E066F162E956402592E865140B4B4009E066F162E95640101FD8F15F0C4B4067D311C0CDEA5640101FD8F15F0C4B4067D311C0CDEA56402592E865140B4B4009E066F162E956402592E865140B4B40
28170	11001	91.665447999999998	91.685929999999999	54.392527999999999	54.384213000000003	переулок Тупиковый	0103000020E61000000100000005000000124C35B396EA56405AD93EE42D314B40124C35B396EA5640D461855B3E324B401956F146E6EB5640D461855B3E324B401956F146E6EB56405AD93EE42D314B40124C35B396EA56405AD93EE42D314B40
28451	51868	91.095789999999994	91.123863	55.882404000000001	55.865383999999999	Советский	0103000020E610000001000000050000002A52616C21C65640A73D25E7C4EE4B402A52616C21C6564007EE409DF2F04B40CE8B135FEDC7564007EE409DF2F04B40CE8B135FEDC75640A73D25E7C4EE4B402A52616C21C65640A73D25E7C4EE4B40
28237	9981	91.320791	91.340778999999998	56.210751999999999	56.202205999999997	Трактовая	0103000020E610000001000000050000007976F9D687D456400987DEE2E1194C407976F9D687D4564086C8E9EBF91A4C40780AB952CFD5564086C8E9EBF91A4C40780AB952CFD556400987DEE2E1194C407976F9D687D456400987DEE2E1194C40
28250	10598	91.064547000000005	91.119101999999998	56.278568	56.257753000000001	Советский район	0103000020E610000001000000050000008483BD8921C4564013B9E00CFE204C408483BD8921C4564027DBC01DA8234C40D8B8FE5D9FC7564027DBC01DA8234C40D8B8FE5D9FC7564013B9E00CFE204C408483BD8921C4564013B9E00CFE204C40
27740	10598	91.064547000000005	91.119101999999998	56.278568	56.257753000000001	Железнодорожная	0103000020E610000001000000050000008483BD8921C4564013B9E00CFE204C408483BD8921C4564027DBC01DA8234C40D8B8FE5D9FC7564027DBC01DA8234C40D8B8FE5D9FC7564013B9E00CFE204C408483BD8921C4564013B9E00CFE204C40
71525	51768	91.064547000000005	91.119101999999998	56.278568	56.257753000000001	Кооперативная	0103000020E610000001000000050000008483BD8921C4564013B9E00CFE204C408483BD8921C4564027DBC01DA8234C40D8B8FE5D9FC7564027DBC01DA8234C40D8B8FE5D9FC7564013B9E00CFE204C408483BD8921C4564013B9E00CFE204C40
27929	51768	91.064547000000005	91.119101999999998	56.278568	56.257753000000001	Деповская	0103000020E610000001000000050000008483BD8921C4564013B9E00CFE204C408483BD8921C4564027DBC01DA8234C40D8B8FE5D9FC7564027DBC01DA8234C40D8B8FE5D9FC7564013B9E00CFE204C408483BD8921C4564013B9E00CFE204C40
72810	10452	91.203632999999996	91.219875000000002	56.075719999999997	56.065750999999999	Школьный переулок	0103000020E61000000100000005000000BAD8B45208CD5640F3565D876A084C40BAD8B45208CD564099D36531B1094C40508D976E12CE564099D36531B1094C40508D976E12CE5640F3565D876A084C40BAD8B45208CD5640F3565D876A084C40
28081	33086	91.409014999999997	91.424062000000006	56.163207999999997	56.154611000000003	Центральная	0103000020E61000000100000005000000B324404D2DDA56400A4D124BCA134C40B324404D2DDA56400839EFFFE3144C407D5EF1D423DB56400839EFFFE3144C407D5EF1D423DB56400A4D124BCA134C40B324404D2DDA56400A4D124BCA134C40
73325	59908	91.042492999999993	91.061770999999993	55.996051999999999	55.980623000000001	Чулымская	0103000020E61000000100000005000000C5538F34B8C256404B5AF10D85FD4B40C5538F34B8C25640C58EC6A17EFF4B40D6355A0EF4C35640C58EC6A17EFF4B40D6355A0EF4C356404B5AF10D85FD4B40C5538F34B8C256404B5AF10D85FD4B40
27755	10237	91.611001000000002	91.642972	56.140965999999999	56.128531000000002	Молодежна	0103000020E61000000100000005000000B134F0A31AE75640D7C22CB473104C40B134F0A31AE7564089EC832C0B124C40990F087426E9564089EC832C0B124C40990F087426E95640D7C22CB473104C40B134F0A31AE75640D7C22CB473104C40
28228	9530	91.354245000000006	91.440985999999995	56.178378000000002	56.152234	Школьная	0103000020E61000000100000005000000617138F3ABD656406DAB59677C134C40617138F3ABD65640B7291E17D5164C409BFF571D39DC5640B7291E17D5164C409BFF571D39DC56406DAB59677C134C40617138F3ABD656406DAB59677C134C40
28226	9530	91.354245000000006	91.440985999999995	56.178378000000002	56.152234	Советская	0103000020E61000000100000005000000617138F3ABD656406DAB59677C134C40617138F3ABD65640B7291E17D5164C409BFF571D39DC5640B7291E17D5164C409BFF571D39DC56406DAB59677C134C40617138F3ABD656406DAB59677C134C40
28443	9530	91.354245000000006	91.440985999999995	56.178378000000002	56.152234	Свердлова	0103000020E61000000100000005000000617138F3ABD656406DAB59677C134C40617138F3ABD65640B7291E17D5164C409BFF571D39DC5640B7291E17D5164C409BFF571D39DC56406DAB59677C134C40617138F3ABD656406DAB59677C134C40
28079	9530	91.354245000000006	91.440985999999995	56.178378000000002	56.152234	40 лет Победы	0103000020E61000000100000005000000617138F3ABD656406DAB59677C134C40617138F3ABD65640B7291E17D5164C409BFF571D39DC5640B7291E17D5164C409BFF571D39DC56406DAB59677C134C40617138F3ABD656406DAB59677C134C40
28620	33112	91.687151	91.728105999999997	56.106113000000001	56.076985999999998	Школьная	0103000020E610000001000000050000007A1A3048FAEB5640FB1F60ADDA094C407A1A3048FAEB564019575C1C950D4C405E81E84999EE564019575C1C950D4C405E81E84999EE5640FB1F60ADDA094C407A1A3048FAEB5640FB1F60ADDA094C40
27810	10356	91.225605999999999	91.253444999999999	55.992654000000002	55.976478	Молодежная	0103000020E6100000010000000500000002F2255470CE5640BAA1293BFDFC4B4002F2255470CE56402E1F49490FFF4B406C95607138D056402E1F49490FFF4B406C95607138D05640BAA1293BFDFC4B4002F2255470CE5640BAA1293BFDFC4B40
72881	10593	91.090023000000002	91.108816000000004	55.800553999999998	55.791111000000001	Рабочая	0103000020E61000000100000005000000D238D4EFC2C55640C040102043E54B40D238D4EFC2C556404B57B08D78E64B40055262D7F6C656404B57B08D78E64B40055262D7F6C65640C040102043E54B40D238D4EFC2C55640C040102043E54B40
72870	59719	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Первомайская	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
73037	59782	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Центральная	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
28072	51799	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Первомайский переулок	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
28413	51862	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Супругов Самаль	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
28599	51817	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	пр.Ленинского Комсомола	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
28157	51817	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Колесниченко	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
73115	59846	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Ленина	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
72731	59686	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Мира	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
73260	32824	93.107108999999994	93.128849000000002	53.362924	53.344074999999997	Мира 	0103000020E61000000100000005000000DD06B5DFDA465740832F4CA60AAC4A40DD06B5DFDA4657407D772B4B74AE4A40D447E00F3F4857407D772B4B74AE4A40D447E00F3F485740832F4CA60AAC4A40DD06B5DFDA465740832F4CA60AAC4A40
73225	32824	93.107108999999994	93.128849000000002	53.362924	53.344074999999997	Мира	0103000020E61000000100000005000000DD06B5DFDA465740832F4CA60AAC4A40DD06B5DFDA4657407D772B4B74AE4A40D447E00F3F4857407D772B4B74AE4A40D447E00F3F485740832F4CA60AAC4A40DD06B5DFDA465740832F4CA60AAC4A40
73181	32938	92.760206999999994	92.777193999999994	53.527228000000001	53.523797000000002	Центральная	0103000020E610000001000000050000002DCC423BA7305740185FB4C70BC34A402DCC423BA73057408BC404357CC34A406F29E78BBD3157408BC404357CC34A406F29E78BBD315740185FB4C70BC34A402DCC423BA7305740185FB4C70BC34A40
73273	32967	92.640974	92.650576999999998	53.543667999999997	53.538018000000001	Мира	0103000020E6100000010000000500000086E5CFB705295740655419C6DDC44A4086E5CFB705295740DCF0BBE996C54A40E8A1B60DA3295740DCF0BBE996C54A40E8A1B60DA3295740655419C6DDC44A4086E5CFB705295740655419C6DDC44A40
73171	32929	92.711312000000007	92.739572999999993	53.538958999999998	53.52346	Зеленая 	0103000020E610000001000000050000002750C422862D5740D061BEBC00C34A402750C422862D57404371C79BFCC44A404B00FE29552F57404371C79BFCC44A404B00FE29552F5740D061BEBC00C34A402750C422862D5740D061BEBC00C34A40
73234	32973	92.803380000000004	92.828828999999999	53.743667000000002	53.732908999999999	Советская	0103000020E61000000100000005000000AC90F2936A335740D7F84CF6CFDD4A40AC90F2936A335740A60EF27A30DF4A407D3ECA880B355740A60EF27A30DF4A407D3ECA880B355740D7F84CF6CFDD4A40AC90F2936A335740D7F84CF6CFDD4A40
73290	32920	93.481886000000003	93.501092	53.778132999999997	53.764434999999999	Советская	0103000020E610000001000000050000009E996038D75E574079758E01D9E14A409E996038D75E57401C78B5DC99E34A4062122EE4116057401C78B5DC99E34A4062122EE41160574079758E01D9E14A409E996038D75E574079758E01D9E14A40
73180	24715	92.571883999999997	92.609937000000002	53.715758999999998	53.706283999999997	Советская	0103000020E61000000100000005000000C34659BF9924574012D89C8367DA4A40C34659BF99245740A968ACFD9DDB4A40B4E7323509275740A968ACFD9DDB4A40B4E732350927574012D89C8367DA4A40C34659BF9924574012D89C8367DA4A40
72627	59644	92.992313999999993	93.007315000000006	53.363036999999998	53.357002000000001	Советская	0103000020E610000001000000050000003A579412823F5740A54DD53DB2AD4A403A579412823F5740751E15FF77AE4A404C7155D977405740751E15FF77AE4A404C7155D977405740A54DD53DB2AD4A403A579412823F5740A54DD53DB2AD4A40
73238	32957	92.562253999999996	92.574021999999999	53.565204000000001	53.559973999999997	Центральная	0103000020E61000000100000005000000E48233F8FB2357401E4E603AADC74A40E48233F8FB235740C1C8CB9A58C84A40CF4BC5C6BC245740C1C8CB9A58C84A40CF4BC5C6BC2457401E4E603AADC74A40E48233F8FB2357401E4E603AADC74A40
73216	32910	92.877831999999998	92.901674	53.658810000000003	53.649225999999999	Советская	0103000020E6100000010000000500000077D844662E38574040DB6AD619D34A4077D844662E3857408E23D6E253D44A40D369DD06B53957408E23D6E253D44A40D369DD06B539574040DB6AD619D34A4077D844662E38574040DB6AD619D34A40
73209	32871	92.385797999999994	94.711797000000004	53.859000000000002	52.802098999999998	Полтавская	0103000020E610000001000000050000002E3718EAB0185740C093162EAB664A402E3718EAB0185740CBA145B6F3ED4A40051901158EAD5740CBA145B6F3ED4A40051901158EAD5740C093162EAB664A402E3718EAB0185740C093162EAB664A40
73157	32894	92.777697000000003	92.813683999999995	53.654572999999999	53.638272000000001	Советская	0103000020E61000000100000005000000A14CA3C9C5315740ECF99AE5B2D14A40A14CA3C9C53157401CEC4D0CC9D34A40D2510E66133457401CEC4D0CC9D34A40D2510E6613345740ECF99AE5B2D14A40A14CA3C9C5315740ECF99AE5B2D14A40
73272	32862	92.697261999999995	92.716881000000001	53.353411999999999	53.346665999999999	Колхозная	0103000020E6100000010000000500000096AFCBF09F2C57404C512E8D5FAC4A4096AFCBF09F2C5740C901BB9A3CAD4A40EC87D860E12D5740C901BB9A3CAD4A40EC87D860E12D57404C512E8D5FAC4A4096AFCBF09F2C57404C512E8D5FAC4A40
73151	32875	93.066416000000004	93.092681999999996	53.540500999999999	53.529443999999998	Советская	0103000020E6100000010000000500000098FBE428404457401E882CD2C4C34A4098FBE42840445740473A03232FC54A4062BB7B80EE455740473A03232FC54A4062BB7B80EE4557401E882CD2C4C34A4098FBE428404457401E882CD2C4C34A40
73268	32889	93.187292999999997	93.205403000000004	53.791912000000004	53.775835000000001	Советская	0103000020E610000001000000050000004371C79BFC4B5740CC0BB08F4EE34A404371C79BFC4B5740ADA7565F5DE54A4005E09F52254D5740ADA7565F5DE54A4005E09F52254D5740CC0BB08F4EE34A404371C79BFC4B5740CC0BB08F4EE34A40
73249	32860	92.920287000000002	92.955140999999998	53.412444999999998	53.393607000000003	Крупская	0103000020E61000000100000005000000C6FB71FBE53A5740043DD4B661B24A40C6FB71FBE53A574009336DFFCAB44A406684B707213D574009336DFFCAB44A406684B707213D5740043DD4B661B24A40C6FB71FBE53A5740043DD4B661B24A40
73277	32970	92.749661000000003	92.773610000000005	53.592137999999998	53.587611000000003	Центральная	0103000020E610000001000000050000008C852172FA2F57408BE255D636CB4A408C852172FA2F5740035C902DCBCB4A40F37684D382315740035C902DCBCB4A40F37684D3823157408BE255D636CB4A408C852172FA2F57408BE255D636CB4A40
73227	32850	92.899535999999998	92.924032999999994	53.769848000000003	53.746451999999998	Мира	0103000020E61000000100000005000000C76471FF91395740530438BD8BDF4A40C76471FF913957400D7217618AE24A402FDB4E5B233B57400D7217618AE24A402FDB4E5B233B5740530438BD8BDF4A40C76471FF91395740530438BD8BDF4A40
73267	32793	92.848871000000003	92.903587000000002	53.619540999999998	53.578785000000003	Шевченко	0103000020E6100000010000000500000076E107E7533657402B357BA015CA4A4076E107E753365740FCC3961E4DCF4A40CF85915ED4395740FCC3961E4DCF4A40CF85915ED43957402B357BA015CA4A4076E107E7533657402B357BA015CA4A40
73256	32793	92.848871000000003	92.903587000000002	53.619540999999998	53.578785000000003	Советская	0103000020E6100000010000000500000076E107E7533657402B357BA015CA4A4076E107E753365740FCC3961E4DCF4A40CF85915ED4395740FCC3961E4DCF4A40CF85915ED43957402B357BA015CA4A4076E107E7533657402B357BA015CA4A40
73166	32793	92.848871000000003	92.903587000000002	53.619540999999998	53.578785000000003	Революционная	0103000020E6100000010000000500000076E107E7533657402B357BA015CA4A4076E107E753365740FCC3961E4DCF4A40CF85915ED4395740FCC3961E4DCF4A40CF85915ED43957402B357BA015CA4A4076E107E7533657402B357BA015CA4A40
73208	32793	92.848871000000003	92.903587000000002	53.619540999999998	53.578785000000003	Пушкина	0103000020E6100000010000000500000076E107E7533657402B357BA015CA4A4076E107E753365740FCC3961E4DCF4A40CF85915ED4395740FCC3961E4DCF4A40CF85915ED43957402B357BA015CA4A4076E107E7533657402B357BA015CA4A40
73250	32959	92.516799000000006	92.540756999999999	53.466211999999999	53.456319999999998	 Партизанская 	0103000020E61000000100000005000000C1E61C3C132157405F419AB168BA4A40C1E61C3C132157405A80B6D5ACBB4A4051853FC39B2257405A80B6D5ACBB4A4051853FC39B2257405F419AB168BA4A40C1E61C3C132157405F419AB168BA4A40
73195	32847	93.227214000000004	93.257146000000006	53.376963000000003	53.359813000000003	Садовая	0103000020E6100000010000000500000060CC96AC8A4E57407CD6355A0EAE4A4060CC96AC8A4E5740AA66D65240B04A4006137F1475505740AA66D65240B04A4006137F14755057407CD6355A0EAE4A4060CC96AC8A4E57407CD6355A0EAE4A40
73165	32847	93.227214000000004	93.257146000000006	53.376963000000003	53.359813000000003	Ленина	0103000020E6100000010000000500000060CC96AC8A4E57407CD6355A0EAE4A4060CC96AC8A4E5740AA66D65240B04A4006137F1475505740AA66D65240B04A4006137F14755057407CD6355A0EAE4A4060CC96AC8A4E57407CD6355A0EAE4A40
73038	7266	95.185613000000004	95.215383000000003	56.341836999999998	56.334268000000002	Молодежная	0103000020E61000000100000005000000992D5915E1CB5740B70C384BC92A4C40992D5915E1CB574008C89750C12B4C405247C7D5C8CD574008C89750C12B4C405247C7D5C8CD5740B70C384BC92A4C40992D5915E1CB5740B70C384BC92A4C40
27881	7469	95.438534000000004	95.474179000000007	56.214511999999999	56.195295000000002	Луговая	0103000020E61000000100000005000000C80BE9F010DC57404209336DFF184C40C80BE9F010DC5740BE4C1421751B4C40CD5CE0F258DE5740BE4C1421751B4C40CD5CE0F258DE57404209336DFF184C40C80BE9F010DC57404209336DFF184C40
27731	6835	95.193752000000003	95.219551999999993	56.216284000000002	56.209865999999998	Центральная	0103000020E6100000010000000500000037E2C96E66CC57406B459BE3DC1A4C4037E2C96E66CC5740F452B131AF1B4C405EF1D4230DCE5740F452B131AF1B4C405EF1D4230DCE57406B459BE3DC1A4C4037E2C96E66CC57406B459BE3DC1A4C40
28013	5043	95.823363000000001	95.842011999999997	55.867883999999997	55.856431999999998	Ушакова	0103000020E61000000100000005000000226FB9FAB1F45740BA9F53909FED4B40226FB9FAB1F457405F5CAAD216EF4B40BBB54C86E3F557405F5CAAD216EF4B40BBB54C86E3F55740BA9F53909FED4B40226FB9FAB1F45740BA9F53909FED4B40
27912	47897	95.497769000000005	95.516822000000005	56.445523000000001	56.433481	Трактовая	0103000020E610000001000000050000009CFD8172DBDF5740FC372F4E7C374C409CFD8172DBDF5740D34ECDE506394C409DF6949C13E15740D34ECDE506394C409DF6949C13E15740FC372F4E7C374C409CFD8172DBDF5740FC372F4E7C374C40
72440	7164	94.969380000000001	95.016811000000004	56.265182000000003	56.244990000000001	Новая	0103000020E61000000100000005000000605969520ABE57406CEC12D55B1F4C40605969520ABE574073BED87BF1214C40A3CD716E13C1574073BED87BF1214C40A3CD716E13C157406CEC12D55B1F4C40605969520ABE57406CEC12D55B1F4C40
28380	7164	94.969380000000001	95.016811000000004	56.265182000000003	56.244990000000001	Ленина	0103000020E61000000100000005000000605969520ABE57406CEC12D55B1F4C40605969520ABE574073BED87BF1214C40A3CD716E13C1574073BED87BF1214C40A3CD716E13C157406CEC12D55B1F4C40605969520ABE57406CEC12D55B1F4C40
72797	6421	95.674987999999999	95.686891000000003	56.520504000000003	56.510860000000001	Клубный переулок	0103000020E61000000100000005000000514CDE0033EB5740D36A48DC63414C40514CDE0033EB5740F6B704E09F424C40AC3AAB05F6EB5740F6B704E09F424C40AC3AAB05F6EB5740D36A48DC63414C40514CDE0033EB5740D36A48DC63414C40
28174	48450	95.362842000000001	95.374825000000001	56.202947000000002	56.198774999999998	магазинная	0103000020E6100000010000000500000060E7A6CD38D7574096218E7571194C4060E7A6CD38D7574021E9D32AFA194C40492EFF21FDD7574021E9D32AFA194C40492EFF21FDD7574096218E7571194C4060E7A6CD38D7574096218E7571194C40
28368	47975	95.722769999999997	95.735562000000002	55.958320999999998	55.951546999999998	Юбилейная	0103000020E61000000100000005000000EA211ADD41EE5740AFCDC64ACCF94B40EA211ADD41EE5740F6083543AAFA4B408B8BA37213EF5740F6083543AAFA4B408B8BA37213EF5740AFCDC64ACCF94B40EA211ADD41EE5740AFCDC64ACCF94B40
27901	6572	95.518628000000007	95.559375000000003	56.351146	56.340690000000002	 Комсомольская	0103000020E610000001000000050000008EB27E3331E157408109DCBA9B2B4C408EB27E3331E15740840F255AF22C4C40CDCCCCCCCCE35740840F255AF22C4C40CDCCCCCCCCE357408109DCBA9B2B4C408EB27E3331E157408109DCBA9B2B4C40
73123	59855	95.235937000000007	95.261619999999994	56.534500000000001	56.523423999999999	Пионерская	0103000020E61000000100000005000000A6BA809719CF574083F8C08EFF424C40A6BA809719CF574023DBF97E6A444C40B0FECF61BED0574023DBF97E6A444C40B0FECF61BED0574083F8C08EFF424C40A6BA809719CF574083F8C08EFF424C40
27722	6354	95.603014999999999	95.630027999999996	56.510125000000002	56.495832	Новая	0103000020E61000000100000005000000D6FF39CC97E65740B727486C773F4C40D6FF39CC97E657409EEFA7C64B414C401DE4F56052E857409EEFA7C64B414C401DE4F56052E85740B727486C773F4C40D6FF39CC97E65740B727486C773F4C40
72851	7449	95.493465999999998	95.507596000000007	56.213836000000001	56.207458000000003	Лугова	0103000020E6100000010000000500000007EC6AF294DF574094A5D6FB8D1A4C4007EC6AF294DF57408E5A61FA5E1B4C4026E5EE737CE057408E5A61FA5E1B4C4026E5EE737CE0574094A5D6FB8D1A4C4007EC6AF294DF574094A5D6FB8D1A4C40
28339	6760	95.224771000000004	95.244739999999993	56.132328000000001	56.125529999999998	Соломенная	0103000020E61000000100000005000000B685E7A562CE57405C55F65D11104C40B685E7A562CE57402C2CB81FF0104C407901F6D1A9CF57402C2CB81FF0104C407901F6D1A9CF57405C55F65D11104C40B685E7A562CE57405C55F65D11104C40
28546	51895	95.182226999999997	95.200355000000002	56.237917000000003	56.226734	Набережная	0103000020E61000000100000005000000AF5C6F9BA9CB57401572A59E051D4C40AF5C6F9BA9CB5740CB147310741E4C40C425C79DD2CC5740CB147310741E4C40C425C79DD2CC57401572A59E051D4C40AF5C6F9BA9CB57401572A59E051D4C40
28092	51804	95.616148999999993	95.625725000000003	55.866636999999997	55.861004000000001	Новая	0103000020E61000000100000005000000A31D37FC6EE75740D3DC0A6135EE4B40A31D37FC6EE75740744012F6EDEE4B4089D2DEE00BE85740744012F6EDEE4B4089D2DEE00BE85740D3DC0A6135EE4B40A31D37FC6EE75740D3DC0A6135EE4B40
28459	51870	95.157227000000006	95.168571999999998	56.062835999999997	56.057201999999997	Солнечная	0103000020E6100000010000000500000016C3D50110CA574005A2276552074C4016C3D50110CA5740778192020B084C405DC136E2C9CA5740778192020B084C405DC136E2C9CA574005A2276552074C4016C3D50110CA574005A2276552074C40
28552	32583	95.179945000000004	95.237966999999998	56.432226999999997	56.417850000000001	Школьная	0103000020E610000001000000050000000A85083884CB57401A51DA1B7C354C400A85083884CB57405EB9DE3653374C40BEA1F0D93ACF57405EB9DE3653374C40BEA1F0D93ACF57401A51DA1B7C354C400A85083884CB57401A51DA1B7C354C40
73131	59861	95.586280000000002	95.599243000000001	56.107016000000002	56.101619999999997	Московская	0103000020E6100000010000000500000021938C9C85E557404C4F58E2010D4C4021938C9C85E557400A1346B3B20D4C40D8D64FFF59E657400A1346B3B20D4C40D8D64FFF59E657404C4F58E2010D4C4021938C9C85E557404C4F58E2010D4C40
28424	5494	95.425481000000005	95.437663000000001	56.123328000000001	56.110424999999999	Набережная	0103000020E610000001000000050000007104A9143BDB574095D40968220E4C407104A9143BDB57402E573F36C90F4C40D5EAABAB02DC57402E573F36C90F4C40D5EAABAB02DC574095D40968220E4C407104A9143BDB574095D40968220E4C40
72801	6157	95.089232999999993	95.105618000000007	56.384928000000002	56.380692000000003	Центральная	0103000020E61000000100000005000000552E54FEB5C55740A7ECF483BA304C40552E54FEB5C5574048A8195245314C409DF7FF71C2C6574048A8195245314C409DF7FF71C2C65740A7ECF483BA304C40552E54FEB5C55740A7ECF483BA304C40
27830	51751	95.416319000000001	95.429047999999995	56.459577000000003	56.451816999999998	Центральная	0103000020E61000000100000005000000056D72F8A4DA57406F63B323D5394C40056D72F8A4DA5740357F4C6BD33A4C40821ABE8575DB5740357F4C6BD33A4C40821ABE8575DB57406F63B323D5394C40056D72F8A4DA57406F63B323D5394C40
28037	48709	95.469453999999999	95.481887	56.168792000000003	56.159824	Луговая	0103000020E610000001000000050000007D3ECA880BDE5740D68EE21C75144C407D3ECA880BDE5740C9E9EBF99A154C408657923CD7DE5740C9E9EBF99A154C408657923CD7DE5740D68EE21C75144C407D3ECA880BDE5740D68EE21C75144C40
73054	59795	95.410568999999995	95.422282999999993	56.342615000000002	56.335855000000002	Зеленая	0103000020E6100000010000000500000017F032C346DA57405B99F04BFD2A4C4017F032C346DA57403D0FEECEDA2B4C4008AA46AF06DB57403D0FEECEDA2B4C4008AA46AF06DB57405B99F04BFD2A4C4017F032C346DA57405B99F04BFD2A4C40
28026	32678	95.424655000000001	95.446933000000001	56.209411000000003	56.192704999999997	Победы	0103000020E610000001000000050000004E452A8C2DDB57404963B48EAA184C404E452A8C2DDB57401A36CAFACD1A4C4034A0DE8C9ADC57401A36CAFACD1A4C4034A0DE8C9ADC57404963B48EAA184C404E452A8C2DDB57404963B48EAA184C40
28628	7185	95.031193000000002	95.062004999999999	56.218586000000002	56.211568	Центральная	0103000020E610000001000000050000004EB7EC10FFC15740A87004A9141B4C404EB7EC10FFC1574086AE44A0FA1B4C4010CCD1E3F7C3574086AE44A0FA1B4C4010CCD1E3F7C35740A87004A9141B4C404EB7EC10FFC15740A87004A9141B4C40
72957	48130	95.523020000000002	95.534564000000003	55.917324000000001	55.908656000000001	Центральная	0103000020E61000000100000005000000DAC9E02879E1574037A8FDD64EF44B40DAC9E02879E15740FFEA71DF6AF54B409D67EC4B36E25740FFEA71DF6AF54B409D67EC4B36E2574037A8FDD64EF44B40DAC9E02879E1574037A8FDD64EF44B40
27950	48295	94.958303999999998	94.978488999999996	56.502653000000002	56.495891	Первая	0103000020E6100000010000000500000010E84CDA54BD5740BCB0355B793F4C4010E84CDA54BD57403F1EFAEE56404C40BA9F53909FBE57403F1EFAEE56404C40BA9F53909FBE5740BCB0355B793F4C4010E84CDA54BD5740BCB0355B793F4C40
73139	59866	95.038047000000006	95.050336000000001	56.111750000000001	56.106127999999998	Школьная	0103000020E61000000100000005000000802DAF5C6FC257404E98309A950D4C40802DAF5C6FC25740FCA9F1D24D0E4C40EF737CB438C35740FCA9F1D24D0E4C40EF737CB438C357404E98309A950D4C40802DAF5C6FC257404E98309A950D4C40
28301	48030	95.567217999999997	95.582597000000007	56.052844	56.047584999999998	Первомайская	0103000020E61000000100000005000000F6ECB94C4DE45740DC63E94317064C40F6ECB94C4DE4574019E59997C3064C40DB6FED4449E5574019E59997C3064C40DB6FED4449E55740DC63E94317064C40F6ECB94C4DE45740DC63E94317064C40
72885	59721	95.777585000000002	95.784465999999995	56.446071000000003	56.435625999999999	Центральная	0103000020E610000001000000050000000D37E0F3C3F15740C6A4BF97C2374C400D37E0F3C3F15740D658C2DA18394C40BBB4E1B034F25740D658C2DA18394C40BBB4E1B034F25740C6A4BF97C2374C400D37E0F3C3F15740C6A4BF97C2374C40
72642	59648	95.375185000000002	95.429856000000001	56.520950999999997	56.509155999999997	Советская	0103000020E61000000100000005000000C93CF20703D85740F54718062C414C40C93CF20703D85740C4E8B985AE424C40527FBDC282DB5740C4E8B985AE424C40527FBDC282DB5740F54718062C414C40C93CF20703D85740F54718062C414C40
28596	5705	95.613984000000002	95.650509	55.910311	55.895918000000002	Центральная	0103000020E610000001000000050000001B118C834BE75740E9F2E670ADF24B401B118C834BE757403318231285F44B403C3080F0A1E957403318231285F44B403C3080F0A1E95740E9F2E670ADF24B401B118C834BE75740E9F2E670ADF24B40
27802	6629	95.319040000000001	95.353508000000005	56.118600999999998	56.110385000000001	Центральная	0103000020E610000001000000050000006A87BF266BD45740077C7E18210E4C406A87BF266BD45740EE224C512E0F4C40F6B704E09FD65740EE224C512E0F4C40F6B704E09FD65740077C7E18210E4C406A87BF266BD45740077C7E18210E4C40
72655	5469	95.468779999999995	95.495388000000005	56.036357000000002	56.017372000000002	9 Пятилетки	0103000020E610000001000000050000003541D47D00DE5740DDEEE53E39024C403541D47D00DE574087FD9E58A7044C402DB5DE6FB4DF574087FD9E58A7044C402DB5DE6FB4DF5740DDEEE53E39024C403541D47D00DE5740DDEEE53E39024C40
28142	5324	95.812341000000004	95.829650999999998	56.117953	56.101218000000003	Кирова	0103000020E61000000100000005000000CC0C1B65FDF357401EE21FB6F40C4C40CC0C1B65FDF3574088BB7A15190F4C40FF05820019F5574088BB7A15190F4C40FF05820019F557401EE21FB6F40C4C40CC0C1B65FDF357401EE21FB6F40C4C40
72596	5164	94.500198999999995	95.910499999999999	56.630600000000001	55.708998000000001	Пионерская	0103000020E610000001000000050000007B9FAA4203A05740F7764B72C0DA4B407B9FAA4203A05740C66D3480B7504C4083C0CAA145FA5740C66D3480B7504C4083C0CAA145FA5740F7764B72C0DA4B407B9FAA4203A05740F7764B72C0DA4B40
72795	48314	94.500198999999995	95.910499999999999	56.630600000000001	55.708998000000001	Центральная	0103000020E610000001000000050000007B9FAA4203A05740F7764B72C0DA4B407B9FAA4203A05740C66D3480B7504C4083C0CAA145FA5740C66D3480B7504C4083C0CAA145FA5740F7764B72C0DA4B407B9FAA4203A05740F7764B72C0DA4B40
28067	6459	95.710893999999996	95.739056000000005	56.360771	56.352457000000001	Молодежная	0103000020E610000001000000050000000C3B8C497FED5740861F9C4F1D2D4C400C3B8C497FED5740302C7FBE2D2E4C40687A89B14CEF5740302C7FBE2D2E4C40687A89B14CEF5740861F9C4F1D2D4C400C3B8C497FED5740861F9C4F1D2D4C40
28335	6111	95.077860000000001	95.108806999999999	56.423520000000003	56.42022	 Полевая	0103000020E61000000100000005000000A96A82A8FBC457400490DAC4C9354C40A96A82A8FBC45740D99942E735364C40DBA4A2B1F6C65740D99942E735364C40DBA4A2B1F6C657400490DAC4C9354C40A96A82A8FBC457400490DAC4C9354C40
28334	4801	93.197156000000007	93.222525000000005	57.585152999999998	57.570956000000002	Ленина	0103000020E61000000100000005000000740D33349E4C57403DBA111615C94C40740D33349E4C57400114234BE6CA4C40B7627FD93D4E57400114234BE6CA4C40B7627FD93D4E57403DBA111615C94C40740D33349E4C57403DBA111615C94C40
28543	4724	92.765524999999997	92.783743000000001	57.521793000000002	57.512608999999998	Советская	0103000020E610000001000000050000004ED1915CFE3057405051F52B9DC14C404ED1915CFE3057401024EF1CCAC24C40035E66D8283257401024EF1CCAC24C40035E66D8283257405051F52B9DC14C404ED1915CFE3057405051F52B9DC14C40
28169	47724	93.127277000000007	93.165876999999995	57.625084000000001	57.612070000000003	Пушкина	0103000020E610000001000000050000001D226E4E254857406E6E4C4F58CE4C401D226E4E254857405EA0A4C002D04C40268A90BA9D4A57405EA0A4C002D04C40268A90BA9D4A57406E6E4C4F58CE4C401D226E4E254857406E6E4C4F58CE4C40
72800	47704	93.187939999999998	93.199645000000004	57.417639000000001	57.402543000000001	Школьная	0103000020E610000001000000050000000E677E35074C5740EB1D6E8786B34C400E677E35074C57405F44DB3175B54C40D673D2FBC64C57405F44DB3175B54C40D673D2FBC64C5740EB1D6E8786B34C400E677E35074C5740EB1D6E8786B34C40
28330	4580	93.331140000000005	93.349861000000004	57.560668999999997	57.539738999999997	Клубная	0103000020E610000001000000050000007099D3653155574018B0E42A16C54C407099D36531555740C5707500C4C74C405649641F64565740C5707500C4C74C405649641F6456574018B0E42A16C54C407099D3653155574018B0E42A16C54C40
28507	4515	92.696524999999994	92.722037999999998	57.386999000000003	57.373747999999999	Школьная	0103000020E610000001000000050000002BF697DD932C5740037976F9D6AF4C402BF697DD932C5740D84AE82E89B14C40081EDFDE352E5740D84AE82E89B14C40081EDFDE352E5740037976F9D6AF4C402BF697DD932C5740037976F9D6AF4C40
28537	4318	93.303229999999999	93.336584000000002	57.638658	57.619228	Центральная	0103000020E61000000100000005000000A14ACD1E685357403D62F4DC42CF4C40A14ACD1E6853574015AA9B8BBFD14C40D7169E978A55574015AA9B8BBFD14C40D7169E978A5557403D62F4DC42CF4C40A14ACD1E685357403D62F4DC42CF4C40
72609	4283	93.181876000000003	93.210262999999998	57.529949999999999	57.511336999999997	Свердлова	0103000020E6100000010000000500000059FB3BDBA34B57400C1EA67D73C14C4059FB3BDBA34B5740F241CF66D5C34C40C423F1F2744D5740F241CF66D5C34C40C423F1F2744D57400C1EA67D73C14C4059FB3BDBA34B57400C1EA67D73C14C40
72917	49600	92.837309000000005	92.855940000000004	57.532690000000002	57.526238999999997	Советская	0103000020E6100000010000000500000060E97C78963557409B70AFCC5BC34C4060E97C78963557400074982F2FC44C40A6D590B8C73657400074982F2FC44C40A6D590B8C73657409B70AFCC5BC34C4060E97C78963557409B70AFCC5BC34C40
72904	49600	92.837309000000005	92.855940000000004	57.532690000000002	57.526238999999997	Новая	0103000020E6100000010000000500000060E97C78963557409B70AFCC5BC34C4060E97C78963557400074982F2FC44C40A6D590B8C73657400074982F2FC44C40A6D590B8C73657409B70AFCC5BC34C4060E97C78963557409B70AFCC5BC34C40
28148	4131	92.886914000000004	92.901745000000005	57.402456000000001	57.385485000000003	Центральная	0103000020E610000001000000050000005517F032C33857409E0C8E9257B14C405517F032C33857401C0A9FAD83B34C403815A930B63957401C0A9FAD83B34C403815A930B63957409E0C8E9257B14C405517F032C33857409E0C8E9257B14C40
71515	4076	93.259410000000003	93.287786999999994	57.717354	57.677039000000001	Советская	0103000020E610000001000000050000005890662C9A505740EB8EC536A9D64C405890662C9A505740D0D38041D2DB4C40B14D2A1A6B525740D0D38041D2DB4C40B14D2A1A6B525740EB8EC536A9D64C405890662C9A505740EB8EC536A9D64C40
28152	4016	93.769526999999997	93.789181999999997	57.348737999999997	57.339505000000003	Школьная	0103000020E61000000100000005000000E5982CEE3F7157400CEA5BE674AB4C40E5982CEE3F715740AC6F6072A3AC4C40E12538F581725740AC6F6072A3AC4C40E12538F5817257400CEA5BE674AB4C40E5982CEE3F7157400CEA5BE674AB4C40
72960	47470	93.297749999999994	93.304173000000006	57.807298000000003	57.794905	Набережная	0103000020E61000000100000005000000931804560E535740A4367172BFE54C40931804560E5357402810768A55E74C40E1D40792775357402810768A55E74C40E1D4079277535740A4367172BFE54C40931804560E535740A4367172BFE54C40
28640	3834	93.069012000000001	93.103093999999999	57.462828999999999	57.451886999999999	Буденного	0103000020E6100000010000000500000005C24EB16A445740683EE76ED7B94C4005C24EB16A445740F8510DFB3DBB4C407C9A931799465740F8510DFB3DBB4C407C9A931799465740683EE76ED7B94C4005C24EB16A445740683EE76ED7B94C40
72791	40436	92.647970999999998	92.66601	57.399797999999997	57.394075999999998	Лесная	0103000020E6100000010000000500000069705B5B78295740BA11161571B24C4069705B5B78295740CB80B3942CB34C40C63368E89F2A5740CB80B3942CB34C40C63368E89F2A5740BA11161571B24C4069705B5B78295740BA11161571B24C40
28502	47417	93.259238999999994	93.287679999999995	57.636378999999998	57.607956999999999	Трактовая	0103000020E6100000010000000500000041B62C5F97505740E82FF488D1CD4C4041B62C5F975057403B6EF8DD74D14C40A6ED5F59695257403B6EF8DD74D14C40A6ED5F5969525740E82FF488D1CD4C4041B62C5F97505740E82FF488D1CD4C40
28323	3729	92.845646000000002	92.860881000000006	57.600999000000002	57.589272999999999	Советская	0103000020E61000000100000005000000917F66101F36574039B5334C6DCB4C40917F66101F365740E0F60489EDCC4C40DC2F9FAC18375740E0F60489EDCC4C40DC2F9FAC1837574039B5334C6DCB4C40917F66101F36574039B5334C6DCB4C40
72943	3645	93.126199	93.145521000000002	57.331479999999999	57.315185999999997	Центральная	0103000020E610000001000000050000006D72F8A4134857401A14CD0358A84C406D72F8A41348574098A3C7EF6DAA4C4066F84F375049574098A3C7EF6DAA4C4066F84F37504957401A14CD0358A84C406D72F8A4134857401A14CD0358A84C40
73177	33044	95.491696000000005	95.529353999999998	55.680289999999999	55.661186000000001	Колхозная	0103000020E61000000100000005000000BDE47FF277DF57405A492BBEA1D44B40BDE47FF277DF5740DEE522BE13D74B406F8099EFE0E15740DEE522BE13D74B406F8099EFE0E157405A492BBEA1D44B40BDE47FF277DF57405A492BBEA1D44B40
73147	32944	95.459680000000006	95.476478999999998	55.800398000000001	55.792427000000004	Комсомольская	0103000020E6100000010000000500000005A8A9656BDD5740D4BB783F6EE54B4005A8A9656BDD574054E4107173E64B40C58EC6A17EDE574054E4107173E64B40C58EC6A17EDE5740D4BB783F6EE54B4005A8A9656BDD5740D4BB783F6EE54B40
73224	32897	95.666067999999996	95.679120999999995	55.728489000000003	55.716929999999998	Комсомольская	0103000020E61000000100000005000000603AADDBA0EA5740B9C2BB5CC4DB4B40603AADDBA0EA5740753FA7203FDD4B40B741EDB776EB5740753FA7203FDD4B40B741EDB776EB5740B9C2BB5CC4DB4B40603AADDBA0EA5740B9C2BB5CC4DB4B40
73217	32906	95.268061000000003	95.293833000000006	55.808588999999998	55.794274999999999	Строительная	0103000020E61000000100000005000000511553E927D15740E4839ECDAAE54B40511553E927D15740E27327D87FE74B40145FED28CED25740E27327D87FE74B40145FED28CED25740E4839ECDAAE54B40511553E927D15740E4839ECDAAE54B40
73228	32891	95.412167999999994	95.426513999999997	55.868732999999999	55.861801999999997	Молодежная	0103000020E610000001000000050000004B1DE4F560DA57404ED026874FEE4B404B1DE4F560DA57405DFA97A432EF4B40505260014CDB57405DFA97A432EF4B40505260014CDB57404ED026874FEE4B404B1DE4F560DA57404ED026874FEE4B40
73254	32879	95.549295999999998	95.581483000000006	55.800843	55.787461999999998	Советская	0103000020E61000000100000005000000B6F468AA27E35740DF6B088ECBE44B40B6F468AA27E35740821DFF0582E64B40850B790437E55740821DFF0582E64B40850B790437E55740DF6B088ECBE44B40B6F468AA27E35740DF6B088ECBE44B40
73265	26425	95.646054000000007	95.682714000000004	55.414853000000001	55.401722999999997	Рабочая	0103000020E61000000100000005000000CD5CE0F258E957408786C5A86BB34B40CD5CE0F258E95740E1D231E719B54B405EA10F96B1EB5740E1D231E719B54B405EA10F96B1EB57408786C5A86BB34B40CD5CE0F258E957408786C5A86BB34B40
73184	2165	95.804013999999995	95.822311999999997	55.552799999999998	55.541749000000003	Набережная	0103000020E61000000100000005000000ACE122F774F3574003D2FE0758C54B40ACE122F774F35740499D8026C2C64B40EFC682C2A0F45740499D8026C2C64B40EFC682C2A0F4574003D2FE0758C54B40ACE122F774F3574003D2FE0758C54B40
73185	2494	95.754669000000007	95.777090999999999	55.206000000000003	55.166110000000003	Центральная	0103000020E610000001000000050000008693347F4CF05740F0C4AC1743954B408693347F4CF05740EE7C3F355E9A4B4005C1E3DBBBF15740EE7C3F355E9A4B4005C1E3DBBBF15740F0C4AC1743954B408693347F4CF05740F0C4AC1743954B40
73193	32816	95.377215000000007	95.389090999999993	55.486519999999999	55.476300999999999	Советская	0103000020E61000000100000005000000E223624A24D85740AB06616EF7BC4B40E223624A24D85740CA6C904946BE4B40BF0AF0DDE6D85740CA6C904946BE4B40BF0AF0DDE6D85740AB06616EF7BC4B40E223624A24D85740AB06616EF7BC4B40
73296	32863	95.664820000000006	95.683019000000002	55.366956999999999	55.353974999999998	Центральная	0103000020E61000000100000005000000836E2F698CEA5740014D840D4FAD4B40836E2F698CEA5740E6046D72F8AE4B40FCE25295B6EB5740E6046D72F8AE4B40FCE25295B6EB5740014D840D4FAD4B40836E2F698CEA5740014D840D4FAD4B40
73287	32923	95.329901000000007	95.354011	55.803499000000002	55.797441999999997	Мира 	0103000020E61000000100000005000000BC7A15191DD55740793A579412E64B40BC7A15191DD5574032AF230ED9E64B4027DBC01DA8D6574032AF230ED9E64B4027DBC01DA8D65740793A579412E64B40BC7A15191DD55740793A579412E64B40
73055	33149	95.784465999999995	95.799486000000002	55.799137999999999	55.787421999999999	Школьная	0103000020E61000000100000005000000BBB4E1B034F2574051137D3ECAE44B40BBB4E1B034F25740D47E6B274AE64B4008E753C72AF35740D47E6B274AE64B4008E753C72AF3574051137D3ECAE44B40BBB4E1B034F2574051137D3ECAE44B40
73182	32972	95.726228000000006	95.750850999999997	55.683858000000001	55.676670999999999	Советская	0103000020E61000000100000005000000215C01857AEE57406893C3279DD64B40215C01857AEE5740D28DB0A888D74B40CF4A5AF10DF05740D28DB0A888D74B40CF4A5AF10DF057406893C3279DD64B40215C01857AEE57406893C3279DD64B40
73274	32776	95.339754999999997	95.356229999999996	55.617317	55.603195999999997	Центральная	0103000020E61000000100000005000000C269C18BBED55740FC89CA8635CD4B40C269C18BBED55740E621533E04CF4B40A9F6E978CCD65740E621533E04CF4B40A9F6E978CCD65740FC89CA8635CD4B40C269C18BBED55740FC89CA8635CD4B40
28584	2397	95.312707000000003	95.342432000000002	55.462527999999999	55.453912000000003	 Новотроицкая	0103000020E61000000100000005000000BD8E386403D4574088A1D5C919BA4B40BD8E386403D45740FDBD141E34BB4B40A646E867EAD55740FDBD141E34BB4B40A646E867EAD5574088A1D5C919BA4B40BD8E386403D4574088A1D5C919BA4B40
73259	1687	95.187527000000003	95.217027000000002	55.436641999999999	55.430539000000003	пер. Школьный	0103000020E610000001000000050000007D073F7100CC57408753E6E61BB74B407D073F7100CC5740AF0793E2E3B74B4056D636C5E3CD5740AF0793E2E3B74B4056D636C5E3CD57408753E6E61BB74B407D073F7100CC57408753E6E61BB74B40
73301	59903	95.423811000000001	95.438794000000001	55.682783000000001	55.668996	Трактовая	0103000020E61000000100000005000000D82B2CB81FDB5740D19332A9A1D54B40D82B2CB81FDB5740E4A1EF6E65D74B4096EB6D3315DC5740E4A1EF6E65D74B4096EB6D3315DC5740D19332A9A1D54B40D82B2CB81FDB5740D19332A9A1D54B40
73244	32715	95.142439999999993	95.163910000000001	55.706268999999999	55.694616000000003	Ленина	0103000020E610000001000000050000001A69A9BC1DC95740A1A3552DE9D84B401A69A9BC1DC95740DD96C80567DA4B40315F5E807DCA5740DD96C80567DA4B40315F5E807DCA5740A1A3552DE9D84B401A69A9BC1DC95740A1A3552DE9D84B40
73270	32688	95.882013999999998	95.899540000000002	55.404283999999997	55.395031000000003	Центральная	0103000020E610000001000000050000004E27D9EA72F85740FEF3346090B24B404E27D9EA72F85740E525FF93BFB34B40685C381092F95740E525FF93BFB34B40685C381092F95740FEF3346090B24B404E27D9EA72F85740FEF3346090B24B40
73281	32807	95.575948999999994	95.600204000000005	55.612945000000003	55.595627999999998	Школьная	0103000020E610000001000000050000007DCA3159DCE457407B4ACE893DCC4B407DCA3159DCE45740959F54FB74CE4B406BBB09BE69E65740959F54FB74CE4B406BBB09BE69E657407B4ACE893DCC4B407DCA3159DCE457407B4ACE893DCC4B40
73186	32753	95.373182	95.381176999999994	55.640030000000003	55.634776000000002	Школьная	0103000020E610000001000000050000002D5DC136E2D757409224085740D14B402D5DC136E2D75740BD3AC780ECD14B40313F373465D85740BD3AC780ECD14B40313F373465D857409224085740D14B402D5DC136E2D757409224085740D14B40
73210	32785	95.644041999999999	95.662367000000003	55.685229	55.676149000000002	Школьная	0103000020E6100000010000000500000007D0EFFB37E957408F1CE90C8CD64B4007D0EFFB37E95740A9A27895B5D74B40C7BC8E3864EA5740A9A27895B5D74B40C7BC8E3864EA57408F1CE90C8CD64B4007D0EFFB37E957408F1CE90C8CD64B40
73149	32956	95.351433	95.365832999999995	55.728282	55.717537999999998	Советская	0103000020E610000001000000050000000D6FD6E07DD6574091D10149D8DB4B400D6FD6E07DD65740FB21365838DD4B400BB3D0CE69D75740FB21365838DD4B400BB3D0CE69D7574091D10149D8DB4B400D6FD6E07DD6574091D10149D8DB4B40
73263	32792	95.593242000000004	95.628510000000006	55.674889999999998	55.670071999999998	Солнечная	0103000020E6100000010000000500000046274BADF7E557408FFB56EBC4D54B4046274BADF7E55740DF32A7CB62D64B4060CD018239E85740DF32A7CB62D64B4060CD018239E857408FFB56EBC4D54B4046274BADF7E557408FFB56EBC4D54B40
73152	32916	95.226495999999997	95.258771999999993	55.845779	55.834274999999998	Центральная	0103000020E61000000100000005000000302B14E97ECE5740696FF085C9EA4B40302B14E97ECE574061527C7C42EC4B40B6476FB88FD0574061527C7C42EC4B40B6476FB88FD05740696FF085C9EA4B40302B14E97ECE5740696FF085C9EA4B40
73194	32760	95.398577000000003	95.501424999999998	55.660362999999997	55.620128000000001	Ленина	0103000020E6100000010000000500000005FC1A4982D95740BDAAB35A60CF4B4005FC1A4982D95740853E58C686D44B406519E25817E05740853E58C686D44B406519E25817E05740BDAAB35A60CF4B4005FC1A4982D95740BDAAB35A60CF4B40
73192	32760	95.398577000000003	95.501424999999998	55.660362999999997	55.620128000000001	Интеранциональная	0103000020E6100000010000000500000005FC1A4982D95740BDAAB35A60CF4B4005FC1A4982D95740853E58C686D44B406519E25817E05740853E58C686D44B406519E25817E05740BDAAB35A60CF4B4005FC1A4982D95740BDAAB35A60CF4B40
73239	1704	95.416543000000004	95.431293999999994	55.657845000000002	55.651058999999997	переулок Центральный	0103000020E610000001000000050000002D98F8A3A8DA57401B62BCE655D34B402D98F8A3A8DA5740276BD44334D44B40813D26529ADB5740276BD44334D44B40813D26529ADB57401B62BCE655D34B402D98F8A3A8DA57401B62BCE655D34B40
28271	33036	95.219228000000001	95.234859	55.456341999999999	55.440671999999999	Суворова	0103000020E610000001000000050000008597E0D407CE5740A721AAF067B84B408597E0D407CE574047E5266A69BA4B40F60A0BEE07CF574047E5266A69BA4B40F60A0BEE07CF5740A721AAF067B84B408597E0D407CE5740A721AAF067B84B40
28430	33036	95.219228000000001	95.234859	55.456341999999999	55.440671999999999	Колхозная	0103000020E610000001000000050000008597E0D407CE5740A721AAF067B84B408597E0D407CE574047E5266A69BA4B40F60A0BEE07CF574047E5266A69BA4B40F60A0BEE07CF5740A721AAF067B84B408597E0D407CE5740A721AAF067B84B40
73160	32719	95.082693000000006	95.113443000000004	55.595948999999997	55.586547000000003	40 Лет Октября	0103000020E61000000100000005000000ECA694D74AC557409148DBF813CB4B40ECA694D74AC55740BD8A8C0E48CC4B4073BD6DA642C75740BD8A8C0E48CC4B4073BD6DA642C757409148DBF813CB4B40ECA694D74AC557409148DBF813CB4B40
73264	32703	95.055941000000004	95.098197999999996	55.680250000000001	55.667355999999998	40 Лет Октября	0103000020E610000001000000050000005B608F8994C357400A65E1EB6BD54B405B608F8994C35740508D976E12D74B4016A243E048C65740508D976E12D74B4016A243E048C657400A65E1EB6BD54B405B608F8994C357400A65E1EB6BD54B40
28428	31376	95.722122999999996	95.736863999999997	55.489840000000001	55.485070999999998	Таёжная	0103000020E610000001000000050000001F2C634337EE5740779E78CE16BE4B401F2C634337EE5740E622BE13B3BE4B4062669FC728EF5740E622BE13B3BE4B4062669FC728EF5740779E78CE16BE4B401F2C634337EE5740779E78CE16BE4B40
73178	31376	95.722122999999996	95.736863999999997	55.489840000000001	55.485070999999998	Ленина	0103000020E610000001000000050000001F2C634337EE5740779E78CE16BE4B401F2C634337EE5740E622BE13B3BE4B4062669FC728EF5740E622BE13B3BE4B4062669FC728EF5740779E78CE16BE4B401F2C634337EE5740779E78CE16BE4B40
73219	32971	95.763651999999993	95.778277000000003	55.636609999999997	55.631701999999997	Таежная	0103000020E610000001000000050000009961A3ACDFF05740AD68739CDBD04B409961A3ACDFF057403D27BD6F7CD14B40A88E554ACFF157403D27BD6F7CD14B40A88E554ACFF15740AD68739CDBD04B409961A3ACDFF05740AD68739CDBD04B40
73183	32936	95.489001000000002	95.504065999999995	55.311574	55.296042	Центральная	0103000020E6100000010000000500000086ADD9CA4BDF5740081F4AB4E4A54B4086ADD9CA4BDF5740572426A8E1A74B40A2410A9E42E05740572426A8E1A74B40A2410A9E42E05740081F4AB4E4A54B4086ADD9CA4BDF5740081F4AB4E4A54B40
73202	32858	95.763921999999994	95.790602000000007	55.387832000000003	55.37679	Центральная	0103000020E6100000010000000500000079AC1919E4F05740DCBA9BA73AB04B4079AC1919E4F05740D02B9E7AA4B14B40BE89213999F25740D02B9E7AA4B14B40BE89213999F25740DCBA9BA73AB04B4079AC1919E4F05740DCBA9BA73AB04B40
73278	32673	95.795686000000003	95.823130000000006	55.446599999999997	55.437035999999999	Трактовая	0103000020E61000000100000005000000A5F8F884ECF257405B96AFCBF0B74B40A5F8F884ECF25740613255302AB94B40D1967329AEF45740613255302AB94B40D1967329AEF457405B96AFCBF0B74B40A5F8F884ECF257405B96AFCBF0B74B40
73206	32870	95.532938000000001	95.555135000000007	55.447493999999999	55.443812000000001	Центральная	0103000020E61000000100000005000000EC32FCA71BE2574043C9E4D4CEB84B40EC32FCA71BE25740FF93BF7B47B94B405C77F35487E35740FF93BF7B47B94B405C77F35487E3574043C9E4D4CEB84B40EC32FCA71BE2574043C9E4D4CEB84B40
73262	1146	95.361782000000005	95.389953000000006	55.571744000000002	55.559165	Красноармейский переулок	0103000020E610000001000000050000000492B06F27D75740AF08FEB792C74B400492B06F27D7574095D74AE82EC94B40897E6DFDF4D8574095D74AE82EC94B40897E6DFDF4D85740AF08FEB792C74B400492B06F27D75740AF08FEB792C74B40
73283	32686	95.876345999999998	95.896962000000002	55.505862999999998	55.496668999999997	Центральная	0103000020E61000000100000005000000BF7E880D16F85740F0F78BD992BF4B40BF7E880D16F85740D3A0681EC0C04B404EF04DD367F95740D3A0681EC0C04B404EF04DD367F95740F0F78BD992BF4B40BF7E880D16F85740F0F78BD992BF4B40
73121	59853	92.981048999999999	92.985522000000003	56.169663999999997	56.159588999999997	Центральная	0103000020E6100000010000000500000081B1BE81C93E574092E68F696D144C4081B1BE81C93E57407EA7C98CB7154C4044DFDDCA123F57407EA7C98CB7154C4044DFDDCA123F574092E68F696D144C4081B1BE81C93E574092E68F696D144C40
27842	32049	96.015395999999996	96.044860999999997	56.312465000000003	56.307077	Центральная	0103000020E610000001000000050000004F1F813FFC005840492D944C4E274C404F1F813FFC005840841266DAFE274C406AF7AB00DF025840841266DAFE274C406AF7AB00DF025840492D944C4E274C404F1F813FFC005840492D944C4E274C40
27943	1093	96.607619	96.637893000000005	55.794234000000003	55.785133999999999	Первомайская	0103000020E61000000100000005000000685BCD3AE3265840247D5A457FE44B40685BCD3AE326584086AFAF75A9E54B403B56293DD328584086AFAF75A9E54B403B56293DD3285840247D5A457FE44B40685BCD3AE3265840247D5A457FE44B40
72879	746	96.168145999999993	96.188843000000006	55.959111999999998	55.953083999999997	Центральная	0103000020E6100000010000000500000001BD70E7C20A5840A12B11A8FEF94B4001BD70E7C20A5840BF99982EC4FA4B400745F300160C5840BF99982EC4FA4B400745F300160C5840A12B11A8FEF94B4001BD70E7C20A5840A12B11A8FEF94B40
72760	746	96.168145999999993	96.188843000000006	55.959111999999998	55.953083999999997	Нагорная	0103000020E6100000010000000500000001BD70E7C20A5840A12B11A8FEF94B4001BD70E7C20A5840BF99982EC4FA4B400745F300160C5840BF99982EC4FA4B400745F300160C5840A12B11A8FEF94B4001BD70E7C20A5840A12B11A8FEF94B40
27729	299	96.152551000000003	96.167912000000001	56.434013	56.427557999999998	Центральная	0103000020E6100000010000000500000037FE4465C309584053927538BA364C4037FE4465C3095840F984ECBC8D374C40C826F911BF0A5840F984ECBC8D374C40C826F911BF0A584053927538BA364C4037FE4465C309584053927538BA364C40
28610	32159	96.272350000000003	96.325090000000003	56.227874999999997	56.219316999999997	Центральная	0103000020E6100000010000000500000033C4B12E6E115840793A5794121C4C4033C4B12E6E115840BA490C022B1D4C406D904946CE145840BA490C022B1D4C406D904946CE145840793A5794121C4C4033C4B12E6E115840793A5794121C4C40
72985	59741	95.891581000000002	95.907732999999993	56.431251000000003	56.42022	Центральная	0103000020E610000001000000050000000A2FC1A90FF957400490DAC4C9354C400A2FC1A90FF9574004AF963B33374C40FF1F274C18FA574004AF963B33374C40FF1F274C18FA57400490DAC4C9354C400A2FC1A90FF957400490DAC4C9354C40
27736	1040	96.286202000000003	96.304708000000005	55.716818000000004	55.709783999999999	Центральная	0103000020E610000001000000050000003083312251125840AE9CBD33DADA4B403083312251125840929735B1C0DB4B4018B5FB5580135840929735B1C0DB4B4018B5FB5580135840AE9CBD33DADA4B403083312251125840AE9CBD33DADA4B40
72952	884	95.878313000000006	95.895533999999998	55.758747	55.748848000000002	Центральная	0103000020E61000000100000005000000B5A9BA4736F8574067D65240DADF4B40B5A9BA4736F857401478279F1EE14B40309DD66D50F957401478279F1EE14B40309DD66D50F9574067D65240DADF4B40B5A9BA4736F8574067D65240DADF4B40
27935	32337	95.936210000000003	95.959584000000007	56.410170999999998	56.402810000000002	Центральная	0103000020E610000001000000050000000B0C59DDEAFB57403A4030478F334C400B0C59DDEAFB57404162BB7B80344C40F47002D369FD57404162BB7B80344C40F47002D369FD57403A4030478F334C400B0C59DDEAFB57403A4030478F334C40
72907	59725	96.091150999999996	96.127155000000002	56.360202000000001	56.352880999999996	Центральная	0103000020E61000000100000005000000DAFF006BD50558409C3061342B2D4C40DAFF006BD505584016FA60191B2E4C4077A1B94E2308584016FA60191B2E4C4077A1B94E230858409C3061342B2D4C40DAFF006BD50558409C3061342B2D4C40
28450	111	96.227209999999999	96.253342000000004	56.390126000000002	56.373947999999999	Центральная	0103000020E61000000100000005000000BFD4CF9B8A0E5840CA332F87DD2F4C40BFD4CF9B8A0E5840DFA815A6EF314C40022D5DC136105840DFA815A6EF314C40022D5DC136105840CA332F87DD2F4C40BFD4CF9B8A0E5840CA332F87DD2F4C40
72827	111	96.227209999999999	96.253342000000004	56.390126000000002	56.373947999999999	Советская	0103000020E61000000100000005000000BFD4CF9B8A0E5840CA332F87DD2F4C40BFD4CF9B8A0E5840DFA815A6EF314C40022D5DC136105840DFA815A6EF314C40022D5DC136105840CA332F87DD2F4C40BFD4CF9B8A0E5840CA332F87DD2F4C40
27934	20457	96.170499000000007	96.201958000000005	55.795757000000002	55.777464000000002	Центральная	0103000020E610000001000000050000000C40A374E90A58409FE8BAF083E34B400C40A374E90A58401348895DDBE54B40994A3FE1EC0C58401348895DDBE54B40994A3FE1EC0C58409FE8BAF083E34B400C40A374E90A58409FE8BAF083E34B40
72945	20457	96.170499000000007	96.201958000000005	55.795757000000002	55.777464000000002	Тамбовская	0103000020E610000001000000050000000C40A374E90A58409FE8BAF083E34B400C40A374E90A58401348895DDBE54B40994A3FE1EC0C58401348895DDBE54B40994A3FE1EC0C58409FE8BAF083E34B400C40A374E90A58409FE8BAF083E34B40
28088	381	95.711693999999994	96.838584999999995	56.492597000000004	55.568399999999997	Центральная	0103000020E610000001000000050000009AB0FD648CED5740F085C954C1C84B409AB0FD648CED5740CA8D226B0D3F4C40A27A6B60AB355840CA8D226B0D3F4C40A27A6B60AB355840F085C954C1C84B409AB0FD648CED5740F085C954C1C84B40
28249	655	96.346541999999999	96.360511000000002	55.840462000000002	55.830685000000003	Центральная	0103000020E61000000100000005000000302C7FBE2D1658408E23D6E253EA4B40302C7FBE2D165840F0C3414294EB4B404AB6BA9C12175840F0C3414294EB4B404AB6BA9C121758408E23D6E253EA4B40302C7FBE2D1658408E23D6E253EA4B40
28126	51814	95.914803000000006	95.942183	55.950432999999997	55.937800000000003	Центральная	0103000020E6100000010000000500000018D2E1218CFA57402B1895D409F84B4018D2E1218CFA57400305DEC9A7F94B4038F6ECB94CFC57400305DEC9A7F94B4038F6ECB94CFC57402B1895D409F84B4018D2E1218CFA57402B1895D409F84B40
27889	32083	95.752729000000002	95.770938000000001	56.346491999999998	56.340445000000003	Центральная	0103000020E610000001000000050000000D7041B62CF057401A8BA6B3932B4C400D7041B62CF05740AE2990D9592C4C40984F560C57F15740AE2990D9592C4C40984F560C57F157401A8BA6B3932B4C400D7041B62CF057401A8BA6B3932B4C40
28231	32249	96.005092000000005	96.029642999999993	56.294376	56.287990999999998	Центральная	0103000020E61000000100000005000000295E656D530058406B459BE3DC244C40295E656D53005840185DDE1CAE254C408AE3C0ABE5015840185DDE1CAE254C408AE3C0ABE50158406B459BE3DC244C40295E656D530058406B459BE3DC244C40
72946	373	96.050341000000003	96.067507000000006	56.413297999999998	56.403860999999999	Центральная	0103000020E61000000100000005000000782975C9380358409F909DB7B1334C40782975C93803584048C0E8F2E6344C401250E1085204584048C0E8F2E6344C401250E108520458409F909DB7B1334C40782975C9380358409F909DB7B1334C40
28619	101	96.330883999999998	96.349992	56.354961000000003	56.344735999999997	Центральная	0103000020E6100000010000000500000042B115342D1558407EE02A4F202C4C4042B115342D155840802DAF5C6F2D4C402577D84466165840802DAF5C6F2D4C402577D844661658407EE02A4F202C4C4042B115342D1558407EE02A4F202C4C40
72621	59641	95.876840000000001	95.900187000000003	56.223086000000002	56.212124000000003	Центральная	0103000020E61000000100000005000000C7F484251EF857402E5915E1261B4C40C7F484251EF85740051901158E1C4C403352EFA99CF95740051901158E1C4C403352EFA99CF957402E5915E1261B4C40C7F484251EF857402E5915E1261B4C40
71559	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	пер. Алгасинский	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
71558	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Школьная	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
27938	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Центральная	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
27931	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Трактовая	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
71512	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Первомайская	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
28358	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Медицинская	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
28594	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Ленина	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
28593	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Красная	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
27768	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	Коммунистическая	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
28605	11004	96.019627	96.129634999999993	56.254632000000001	56.219873	50 лет Краснохлеборобовской Коммуны	0103000020E6100000010000000500000097C79A9141015840FF2268CC241C4C4097C79A9141015840EE4108C897204C40AF5A99F04B085840EE4108C897204C40AF5A99F04B085840FF2268CC241C4C4097C79A9141015840FF2268CC241C4C40
27735	985	96.401338999999993	96.431307000000004	55.748204000000001	55.734890999999998	Центральная	0103000020E61000000100000005000000FFE6C589AF195840F78F85E810DE4B40FFE6C589AF195840425E0F26C5DF4B404CE2AC889A1B5840425E0F26C5DF4B404CE2AC889A1B5840F78F85E810DE4B40FFE6C589AF195840F78F85E810DE4B40
28494	51881	95.891464999999997	95.917766999999998	56.298512000000002	56.289655000000003	Центральная	0103000020E61000000100000005000000D52137C30DF95740BB0F406A13254C40D52137C30DF9574056BB26A435264C404696CCB1BCFA574056BB26A435264C404696CCB1BCFA5740BB0F406A13254C40D52137C30DF95740BB0F406A13254C40
28288	754	96.176068999999998	96.189391000000001	56.001826000000001	55.989265000000003	Центральная	0103000020E61000000100000005000000B935E9B6440B5840EA094B3CA0FE4B40B935E9B6440B5840292499D53B004C4008CA6DFB1E0C5840292499D53B004C4008CA6DFB1E0C5840EA094B3CA0FE4B40B935E9B6440B5840EA094B3CA0FE4B40
72886	613	96.290936000000002	96.304239999999993	55.915013000000002	55.908954000000001	Центральная	0103000020E61000000100000005000000A94E07B29E125840C1C8CB9A58F44B40A94E07B29E1258401A355F251FF54B40A4880CAB781358401A355F251FF54B40A4880CAB78135840C1C8CB9A58F44B40A94E07B29E125840C1C8CB9A58F44B40
71516	47963	95.845471000000003	95.874864000000002	56.073343000000001	56.057011000000003	Коростелева	0103000020E61000000100000005000000DAAD65321CF657409241EE224C074C40DAAD65321CF65740FD31AD4D63094C40A81C93C5FDF75740FD31AD4D63094C40A81C93C5FDF757409241EE224C074C40DAAD65321CF657409241EE224C074C40
72944	32389	95.884484999999998	95.904759999999996	56.461888999999999	56.457607000000003	Центральная	0103000020E610000001000000050000005D33F9669BF85740D9B5BDDD923A4C405D33F9669BF85740EAB0C22D1F3B4C40A7AE7C96E7F95740EAB0C22D1F3B4C40A7AE7C96E7F95740D9B5BDDD923A4C405D33F9669BF85740D9B5BDDD923A4C40
27976	4969	95.832256999999998	95.846611999999993	55.909624999999998	55.899763999999998	Школьная	0103000020E610000001000000050000007E37DDB243F557401F0F7D772BF34B407E37DDB243F55740DF4F8D976EF44B40AC1919E42EF65740DF4F8D976EF44B40AC1919E42EF657401F0F7D772BF34B407E37DDB243F557401F0F7D772BF34B40
28567	30107	92.24691	92.272717999999998	54.369114000000003	54.356214000000001	Советская	0103000020E610000001000000050000008BC3995FCD0F57404D309C6B982D4B408BC3995FCD0F5740753FA7203F2F4B40F4C1323674115740753FA7203F2F4B40F4C13236741157404D309C6B982D4B408BC3995FCD0F57404D309C6B982D4B40
28401	30468	92.302102000000005	92.317696999999995	54.195028999999998	54.184730000000002	Рабочий	0103000020E610000001000000050000009983A0A355135740884B8E3BA5174B409983A0A355135740C362D4B5F6184B406342CC2555145740C362D4B5F6184B406342CC2555145740884B8E3BA5174B409983A0A355135740884B8E3BA5174B40
28104	30934	92.011748999999995	92.026724000000002	54.736919999999998	54.716289000000003	Таежная	0103000020E61000000100000005000000AFB0E07EC000574006BEA25BAF5B4B40AFB0E07EC000574058E20165535E4B402C8194D8B501574058E20165535E4B402C8194D8B501574006BEA25BAF5B4B40AFB0E07EC000574006BEA25BAF5B4B40
72877	30934	92.011748999999995	92.026724000000002	54.736919999999998	54.716289000000003	Молодежная	0103000020E61000000100000005000000AFB0E07EC000574006BEA25BAF5B4B40AFB0E07EC000574058E20165535E4B402C8194D8B501574058E20165535E4B402C8194D8B501574006BEA25BAF5B4B40AFB0E07EC000574006BEA25BAF5B4B40
28390	51857	91.765996000000001	93.304793000000004	54.945898	54.123196	Краснокаменная	0103000020E610000001000000050000007A37161406F15640BF7FF3E2C40F4B407A37161406F1564008AD872F13794B402FC37FBA8153574008AD872F13794B402FC37FBA81535740BF7FF3E2C40F4B407A37161406F15640BF7FF3E2C40F4B40
28394	30233	92.538304999999994	92.559308000000001	54.451261000000002	54.441366000000002	Школьная	0103000020E610000001000000050000007D91D096732257407EC85BAE7E384B407D91D09673225740EA7AA2EBC2394B400919C8B3CB235740EA7AA2EBC2394B400919C8B3CB2357407EC85BAE7E384B407D91D096732257407EC85BAE7E384B40
72878	30912	91.860077000000004	91.875878	54.393759000000003	54.387379000000003	Центральная 	0103000020E61000000100000005000000ADC266800BF756401F1494A295314B40ADC266800BF75640BAC0E5B166324B404C5299620EF85640BAC0E5B166324B404C5299620EF856401F1494A295314B40ADC266800BF756401F1494A295314B40
28083	31481	92.521281999999999	92.546515999999997	54.550749000000003	54.537211999999997	Октябрьская	0103000020E61000000100000005000000957F2DAF5C2157406682E15CC3444B40957F2DAF5C21574001A777F17E464B4068AF3E1EFA22574001A777F17E464B4068AF3E1EFA2257406682E15CC3444B40957F2DAF5C2157406682E15CC3444B40
27864	31204	92.050258999999997	92.078619000000003	54.551088999999997	54.520744000000001	Ленина	0103000020E6100000010000000500000019558671370357404BCB48BDA7424B401955867137035740B91798158A464B400876FC1708055740B91798158A464B400876FC17080557404BCB48BDA7424B4019558671370357404BCB48BDA7424B40
27867	31338	92.218908999999996	92.259970999999993	54.490251000000001	54.481647000000002	Ленина	0103000020E6100000010000000500000034F3E49A020E5740B79BE09BA63D4B4034F3E49A020E574068EA758BC03E4B4023BA675DA310574068EA758BC03E4B4023BA675DA3105740B79BE09BA63D4B4034F3E49A020E5740B79BE09BA63D4B40
28056	31308	92.236552000000003	92.246200000000002	54.566750999999996	54.555188000000001	Громовой	0103000020E610000001000000050000006BF3FFAA230F5740DA907F6610474B406BF3FFAA230F5740D6FCF84B8B484B409D11A5BDC10F5740D6FCF84B8B484B409D11A5BDC10F5740DA907F6610474B406BF3FFAA230F5740DA907F6610474B40
72876	30747	92.059736999999998	92.093845999999999	54.446691000000001	54.432893	Мира	0103000020E610000001000000050000001D5723BBD20357406BD5AE0969374B401D5723BBD20357407235B22B2D394B401137A792010657407235B22B2D394B401137A792010657406BD5AE0969374B401D5723BBD20357406BD5AE0969374B40
28191	28390	91.983819999999994	92.003851999999995	54.393045999999998	54.384601000000004	Молодежная	0103000020E61000000100000005000000A54929E8F6FE56402481069B3A314B40A54929E8F6FE56406CE9D1544F324B408C81751C3F0057406CE9D1544F324B408C81751C3F0057402481069B3A314B40A54929E8F6FE56402481069B3A314B40
28638	30862	91.978367000000006	91.998112000000006	54.493184999999997	54.481453999999999	Центральная	0103000020E61000000100000005000000151F9F909DFE5640A243E048A03D4B40151F9F909DFE56405AF0A2AF203F4B40B16F2711E1FF56405AF0A2AF203F4B40B16F2711E1FF5640A243E048A03D4B40151F9F909DFE5640A243E048A03D4B40
72899	30606	92.091205000000002	92.117489000000006	54.219952999999997	54.203225000000003	Зеленая	0103000020E61000000100000005000000D40E7F4DD6055740645DDC46031A4B40D40E7F4DD60557401BD47E6B271C4B40F22895F0840757401BD47E6B271C4B40F22895F084075740645DDC46031A4B40D40E7F4DD6055740645DDC46031A4B40
28204	31094	92.132966999999994	92.153332000000006	54.746997	54.738197999999997	Заречная	0103000020E610000001000000050000009F1C0588820857407EFCA5457D5E4B409F1C058882085740E59A02999D5F4B408A5B0531D0095740E59A02999D5F4B408A5B0531D00957407EFCA5457D5E4B409F1C0588820857407EFCA5457D5E4B40
72872	30308	92.668335999999996	92.688063	54.444533999999997	54.436329000000001	Хохлатская	0103000020E6100000010000000500000053AF5B04C62A5740F0A5F0A0D9374B4053AF5B04C62A5740E3FA777DE6384B409CA56439092C5740E3FA777DE6384B409CA56439092C5740F0A5F0A0D9374B4053AF5B04C62A5740F0A5F0A0D9374B40
73019	11311	92.030218000000005	92.038392999999999	54.177953000000002	54.171818999999999	Кедровая	0103000020E6100000010000000500000009707A17EF0157406CEA3C2AFE154B4009707A17EF015740D09CF529C7164B404DD9E90775025740D09CF529C7164B404DD9E907750257406CEA3C2AFE154B4009707A17EF0157406CEA3C2AFE154B40
72950	31012	91.868709999999993	91.896010000000004	54.786850999999999	54.774653999999998	Красных Партизан	0103000020E6100000010000000500000052EDD3F198F7564098DBBDDC27634B4052EDD3F198F7564096E99788B7644B40E5B8533A58F9564096E99788B7644B40E5B8533A58F9564098DBBDDC27634B4052EDD3F198F7564098DBBDDC27634B40
28054	31012	91.868709999999993	91.896010000000004	54.786850999999999	54.774653999999998	Зеленая	0103000020E6100000010000000500000052EDD3F198F7564098DBBDDC27634B4052EDD3F198F7564096E99788B7644B40E5B8533A58F9564096E99788B7644B40E5B8533A58F9564098DBBDDC27634B4052EDD3F198F7564098DBBDDC27634B40
28388	29919	92.078691000000006	92.189443999999995	54.400069999999999	54.361372000000003	Титова	0103000020E6100000010000000500000055DFF9450905574056D80C70412E4B4055DFF945090557402C0E677E35334B40191BBAD91F0C57402C0E677E35334B40191BBAD91F0C574056D80C70412E4B4055DFF9450905574056D80C70412E4B40
28186	29919	92.078691000000006	92.189443999999995	54.400069999999999	54.361372000000003	Октябрьская	0103000020E6100000010000000500000055DFF9450905574056D80C70412E4B4055DFF945090557402C0E677E35334B40191BBAD91F0C57402C0E677E35334B40191BBAD91F0C574056D80C70412E4B4055DFF9450905574056D80C70412E4B40
71517	29919	92.078691000000006	92.189443999999995	54.400069999999999	54.361372000000003	Мира	0103000020E6100000010000000500000055DFF9450905574056D80C70412E4B4055DFF945090557402C0E677E35334B40191BBAD91F0C57402C0E677E35334B40191BBAD91F0C574056D80C70412E4B4055DFF9450905574056D80C70412E4B40
28061	31547	92.430695999999998	92.450700999999995	54.566146000000003	54.555950000000003	Таёжная	0103000020E6100000010000000500000027A1F485901B5740091B9E5E29474B4027A1F485901B57407061DD7877484B4091D10149D81C57407061DD7877484B4091D10149D81C5740091B9E5E29474B4027A1F485901B5740091B9E5E29474B40
72883	31445	92.364885000000001	92.392464000000004	54.509518	54.501775000000002	Ленина	0103000020E6100000010000000500000043739D465A175740A779C7293A404B4043739D465A175740965CC5E237414B40DF3653211E195740965CC5E237414B40DF3653211E195740A779C7293A404B4043739D465A175740A779C7293A404B40
28053	31213	92.146630999999999	92.168046000000004	54.566082999999999	54.546351999999999	Ленина	0103000020E610000001000000050000001B65FD6662095740560DC2DCEE454B401B65FD666209574029E9616875484B40508E0244C10A574029E9616875484B40508E0244C10A5740560DC2DCEE454B401B65FD6662095740560DC2DCEE454B40
27752	30794	91.873227999999997	91.889452000000006	54.504776	54.488624000000002	Храпова	0103000020E61000000100000005000000E57CB1F7E2F756403605323B8B3E4B40E57CB1F7E2F7564021E7FD7F9C404B4028D714C8ECF8564021E7FD7F9C404B4028D714C8ECF856403605323B8B3E4B40E57CB1F7E2F756403605323B8B3E4B40
28582	30707	91.929902999999996	91.957104000000001	54.431741000000002	54.417462	Ленина	0103000020E61000000100000005000000F25CDF8783FB564050A912656F354B40F25CDF8783FB5640D2AB014A43374B40BBB7223141FD5640D2AB014A43374B40BBB7223141FD564050A912656F354B40F25CDF8783FB564050A912656F354B40
72902	30546	92.044088000000002	92.083056999999997	54.298468999999997	54.288947	Советская	0103000020E6100000010000000500000059897956D20257407FA31D37FC244B4059897956D202574056EF703B34264B400CAD4ECE5005574056EF703B34264B400CAD4ECE500557407FA31D37FC244B4059897956D20257407FA31D37FC244B40
72796	30333	92.551061000000004	92.584136999999998	54.267415	54.243640999999997	Байкалова	0103000020E6100000010000000500000078465B95442357407C7BD7A02F1F4B4078465B9544235740DCBA9BA73A224B408CD8278062255740DCBA9BA73A224B408CD82780622557407C7BD7A02F1F4B4078465B95442357407C7BD7A02F1F4B40
28398	30443	92.317229999999995	92.339427000000001	54.245339999999999	54.225332000000002	Советская	0103000020E61000000100000005000000D8D30E7F4D145740035FD1ADD71C4B40D8D30E7F4D1457404833164D671F4B404818062CB91557404833164D671F4B404818062CB9155740035FD1ADD71C4B40D8D30E7F4D145740035FD1ADD71C4B40
72873	30145	92.351330000000004	92.370903999999996	54.359971000000002	54.350510999999997	Советская	0103000020E61000000100000005000000A306D3307C165740B2F1608BDD2C4B40A306D3307C16574014419C87132E4B40287D21E4BC17574014419C87132E4B40287D21E4BC175740B2F1608BDD2C4B40A306D3307C165740B2F1608BDD2C4B40
28305	18277	92.413034999999994	92.424605	54.432192000000001	54.418232000000003	Адрихинская 	0103000020E610000001000000050000009D465A2A6F1A574002124DA088354B409D465A2A6F1A5740E2CB441152374B40F52D73BA2C1B5740E2CB441152374B40F52D73BA2C1B574002124DA088354B409D465A2A6F1A574002124DA088354B40
28559	29359	92.928011999999995	92.964941999999994	53.141221999999999	53.093223999999999	Мира	0103000020E61000000100000005000000EA92718C643B5740E59997C3EE8B4A40EA92718C643B5740E4BCFF8F13924A405B22179CC13D5740E4BCFF8F13924A405B22179CC13D5740E59997C3EE8B4A40EA92718C643B5740E59997C3EE8B4A40
72624	32892	92.219143000000003	92.258210000000005	53.204605999999998	53.195948000000001	Трактовая	0103000020E610000001000000050000006E895C70060E5740BADBF5D214994A406E895C70060E57405E488787309A4A4003603C83861057405E488787309A4A4003603C8386105740BADBF5D214994A406E895C70060E5740BADBF5D214994A40
28366	49136	92.584154999999996	92.611096000000003	53.247210000000003	53.227041999999997	Центральная	0103000020E61000000100000005000000DF32A7CB62255740C26856B60F9D4A40DF32A7CB62255740419FC893A49F4A40DAAD65321C275740419FC893A49F4A40DAAD65321C275740C26856B60F9D4A40DF32A7CB62255740C26856B60F9D4A40
27844	29772	92.418469999999999	92.451859999999996	53.131740999999998	53.114621999999997	Саянская	0103000020E61000000100000005000000DB166536C81A574078B306EFAB8E4A40DB166536C81A57406B459BE3DC904A40B7973446EB1C57406B459BE3DC904A40B7973446EB1C574078B306EFAB8E4A40DB166536C81A574078B306EFAB8E4A40
28175	40416	92.442481999999998	92.454060999999996	53.271599999999999	53.263235999999999	Центральная	0103000020E6100000010000000500000065C405A0511C57409F909DB7B1A14A4065C405A0511C5740FBCBEEC9C3A24A40E658DE550F1D5740FBCBEEC9C3A24A40E658DE550F1D57409F909DB7B1A14A4065C405A0511C57409F909DB7B1A14A40
72592	29125	92.481881999999999	92.511508000000006	53.251837999999999	53.234098000000003	Мира	0103000020E61000000100000005000000FDA19927D71E57408E075BECF69D4A40FDA19927D71E5740EDF1423A3CA04A401DE90C8CBC205740EDF1423A3CA04A401DE90C8CBC2057408E075BECF69D4A40FDA19927D71E57408E075BECF69D4A40
28375	32805	92.607906999999997	92.627571000000003	53.329977	53.318882000000002	Комсомольская	0103000020E610000001000000050000009B00C3F2E72657403CA41820D1A84A409B00C3F2E726574052B7B3AF3CAA4A40C13A8E1F2A28574052B7B3AF3CAA4A40C13A8E1F2A2857403CA41820D1A84A409B00C3F2E72657403CA41820D1A84A40
72871	29109	92.401492000000005	92.426599999999993	53.250312999999998	53.237343000000003	Центральная 	0103000020E61000000100000005000000C366800BB21957409F776341619E4A40C366800BB2195740BF61A2410AA04A404F1E166A4D1B5740BF61A2410AA04A404F1E166A4D1B57409F776341619E4A40C366800BB21957409F776341619E4A40
27843	29628	92.995385999999996	93.025929000000005	52.263342000000002	52.255118000000003	 Кравченко	0103000020E610000001000000050000005C397B67B43F57407B4FE5B4A7204A405C397B67B43F5740E5D4CE30B5214A4027C11BD2A8415740E5D4CE30B5214A4027C11BD2A84157407B4FE5B4A7204A405C397B67B43F57407B4FE5B4A7204A40
72738	59692	92.453620999999998	92.475666000000004	53.352251000000003	53.336773999999998	Ленина	0103000020E61000000100000005000000D8F15F20081D5740511212691BAB4A40D8F15F20081D5740DD7D8E8F16AD4A406D74CE4F711E5740DD7D8E8F16AD4A406D74CE4F711E5740511212691BAB4A40D8F15F20081D5740511212691BAB4A40
28183	29703	92.209682999999998	92.238159999999993	53.143096	53.121529000000002	 Щетинкина	0103000020E61000000100000005000000BDE13E726B0D5740FF4124438E8F4A40BDE13E726B0D57401E1840F850924A40C8CD70033E0F57401E1840F850924A40C8CD70033E0F5740FF4124438E8F4A40BDE13E726B0D5740FF4124438E8F4A40
73006	59757	92.184944000000002	92.203807999999995	53.388247999999997	53.381200999999997	Ленина	0103000020E61000000100000005000000DAE55B1FD60B5740EB19C231CBB04A40DAE55B1FD60B5740635E471CB2B14A4071AAB5300B0D5740635E471CB2B14A4071AAB5300B0D5740EB19C231CBB04A40DAE55B1FD60B5740EB19C231CBB04A40
28597	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	площадь Победы	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
72589	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	Щетинкина	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
72622	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	Трактовая	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
71552	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	Старковых	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
71554	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	Российская	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
27989	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	Октябрьская	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
72803	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	Мостовая	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
72659	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	Ленина	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
28019	23304	92.332914000000002	92.432366999999999	53.293776000000001	53.261771000000003	60 лет ВЛКСМ	0103000020E610000001000000050000005B9885764E15574047054EB681A14A405B9885764E155740C32CB4739AA54A40A837A3E6AB1B5740C32CB4739AA54A40A837A3E6AB1B574047054EB681A14A405B9885764E15574047054EB681A14A40
72599	32810	92.834227999999996	92.856128999999996	53.231689000000003	53.208590999999998	Трактовая	0103000020E61000000100000005000000145AD6FD63355740B69E211CB39A4A40145AD6FD63355740E6EB32FCA79D4A400F0A4AD1CA365740E6EB32FCA79D4A400F0A4AD1CA365740B69E211CB39A4A40145AD6FD63355740B69E211CB39A4A40
28181	29562	92.996527	93.049599000000001	52.248375000000003	52.230535000000003	Ленина	0103000020E610000001000000050000002FA52E19C73F5740ACCABE2B821D4A402FA52E19C73F57406F1283C0CA1F4A4084BA48A12C4357406F1283C0CA1F4A4084BA48A12C435740ACCABE2B821D4A402FA52E19C73F5740ACCABE2B821D4A40
28034	49325	92.405139000000005	92.433633	53.038713000000001	53.033768999999999	Ленина	0103000020E6100000010000000500000063D520CCED1957402F4FE78A52844A4063D520CCED1957400C772E8CF4844A40D95DA0A4C01B57400C772E8CF4844A40D95DA0A4C01B57402F4FE78A52844A4063D520CCED1957402F4FE78A52844A40
27836	29425	93.440070000000006	93.446788999999995	52.581347999999998	52.569817	Нагорная	0103000020E61000000100000005000000D97C5C1B2A5C574038DA71C3EF484A40D97C5C1B2A5C574029CC7B9C694A4A409ACDE330985C574029CC7B9C694A4A409ACDE330985C574038DA71C3EF484A40D97C5C1B2A5C574038DA71C3EF484A40
72028	59578	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Матросова	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72320	59594	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Набережная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73061	59799	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Лесная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72975	59738	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Ермака	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
28519	51888	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	70 лет Октября	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73133	59863	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Набережная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73079	59816	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Школьная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
27990	27047	93.031398999999993	93.074177000000006	57.898586000000002	57.869154000000002	Центральная	0103000020E610000001000000050000002288F370024257400398327040EF4C402288F370024257405D52B5DD04F34C406347E350BF4457405D52B5DD04F34C406347E350BF4457400398327040EF4C402288F370024257400398327040EF4C40
72782	27047	93.031398999999993	93.074177000000006	57.898586000000002	57.869154000000002	Мира	0103000020E610000001000000050000002288F370024257400398327040EF4C402288F370024257405D52B5DD04F34C406347E350BF4457405D52B5DD04F34C406347E350BF4457400398327040EF4C402288F370024257400398327040EF4C40
72789	59709	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Рождественского	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73119	59851	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Центральная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73129	59860	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Молодежная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72474	59603	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Калинина	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
28196	51823	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Набережная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72678	59663	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Административная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
28326	51849	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Талалихина	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72563	51849	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Калинина	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
71661	59492	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Ленинградская	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73135	59865	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Восточная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72694	59667	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Центральная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72996	59750	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Пролетарская	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
28538	51893	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Школьная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72706	59674	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Рабочая	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
28076	51800	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Свободная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73012	59762	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	70 лет Октября	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72737	59691	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Набережная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73107	59839	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Набережная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73247	59891	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Лесная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
73058	59798	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	Лесная	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
72014	59575	92.567419000000001	92.573187000000004	56.087293000000003	56.081842999999999	Заводская	0103000020E610000001000000050000004208C897502457400934D8D4790A4C404208C89750245740BA15C26A2C0B4C4083DF8618AF245740BA15C26A2C0B4C4083DF8618AF2457400934D8D4790A4C404208C897502457400934D8D4790A4C40
72672	59659	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Просвещения	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
71634	59491	93.319776000000005	93.340114	56.197589000000001	56.18947	Советская	0103000020E61000000100000005000000ED82C135775457405CC98E8D40184C40ED82C135775457405186AA984A194C405ABA826DC45557405186AA984A194C405ABA826DC45557405CC98E8D40184C40ED82C135775457405CC98E8D40184C40
72660	59654	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Трактовая	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
72607	59634	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Центральная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
72446	59599	92.847864999999999	92.868463000000006	56.071021999999999	56.068855999999997	Новостроек	0103000020E61000000100000005000000139B8F6B433657401211FE45D0084C40139B8F6B43365740F4A5B73F17094C404FB2D5E594375740F4A5B73F17094C404FB2D5E5943757401211FE45D0084C40139B8F6B433657401211FE45D0084C40
73112	59843	93.243402000000003	93.263749000000004	56.216954999999999	56.213755999999997	Центральная	0103000020E61000000100000005000000FC71FBE5934F574071A94A5B5C1B4C40FC71FBE5934F574012DA722EC51B4C4093567C43E150574012DA722EC51B4C4093567C43E150574071A94A5B5C1B4C40FC71FBE5934F574071A94A5B5C1B4C40
72936	59733	92.091033999999993	92.222835000000003	56.136310999999999	56.062645000000003	Лесная	0103000020E61000000100000005000000BD344580D3055740042159C004084C40BD344580D3055740E38A8BA372114C40DE59BBED420E5740E38A8BA372114C40DE59BBED420E5740042159C004084C40BD344580D3055740042159C004084C40
72884	59720	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Центральная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
28461	51871	92.282859999999999	92.350960999999998	56.231938	56.200158000000002	Кульутры	0103000020E610000001000000050000002E56D4601A125740320400C79E194C402E56D4601A1257408E59F624B01D4C40F94A2025761657408E59F624B01D4C40F94A202576165740320400C79E194C402E56D4601A125740320400C79E194C40
71568	59480	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Советская	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
72656	59652	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Юбилейная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
72940	26411	92.401887000000002	92.412164000000004	56.510651000000003	56.502200999999999	Центральная	0103000020E61000000100000005000000016C4084B81957405E82531F48404C40016C4084B8195740B95510035D414C40AB251DE5601A5740B95510035D414C40AB251DE5601A57405E82531F48404C40016C4084B81957405E82531F48404C40
28014	18712	92.140512999999999	92.161049000000006	56.233524000000003	56.227334999999997	60 лет СССР	0103000020E610000001000000050000006CEA3C2AFE0857403A1E3350191D4C406CEA3C2AFE085740626A4B1DE41D4C406D0377A04E0A5740626A4B1DE41D4C406D0377A04E0A57403A1E3350191D4C406CEA3C2AFE0857403A1E3350191D4C40
72924	59729	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Центральная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
27749	25138	92.212701999999993	92.230649999999997	56.103828999999998	56.093651000000001	Вокзальная	0103000020E61000000100000005000000CD72D9E89C0D57406D1E87C1FC0B4C40CD72D9E89C0D57402DB0C7444A0D4C40A2B437F8C20E57402DB0C7444A0D4C40A2B437F8C20E57406D1E87C1FC0B4C40CD72D9E89C0D57406D1E87C1FC0B4C40
28101	25064	91.959224000000006	91.994726	56.079362000000003	56.068620000000003	Центральная	0103000020E6100000010000000500000074620FED63FD5640FFEC478AC8084C4074620FED63FD5640C845B588280A4C40C79E3D97A9FF5640C845B588280A4C40C79E3D97A9FF5640FFEC478AC8084C4074620FED63FD5640FFEC478AC8084C40
73132	59862	\N	\N	\N	\N	Новая	\N
73001	59649	92.665712999999997	92.666477	56.174894999999999	56.173512000000002	Рабочая	0103000020E6100000010000000500000069E1B20A9B2A574056BB26A435164C4069E1B20A9B2A5740F19D98F562164C4051A2258FA72A5740F19D98F562164C4051A2258FA72A574056BB26A435164C4069E1B20A9B2A574056BB26A435164C40
27823	51749	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Гурского	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
73048	59791	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Центральная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
28143	26494	92.637658999999999	92.658338000000001	56.652042000000002	56.640199000000003	Центральная	0103000020E6100000010000000500000001C0B167CF28574049F7730AF2514C4001C0B167CF28574029CFBC1C76534C40B3EDB435222A574029CFBC1C76534C40B3EDB435222A574049F7730AF2514C4001C0B167CF28574049F7730AF2514C40
72761	765	92.417445999999998	92.424992000000003	55.74109	55.736806999999999	Школьная	0103000020E6100000010000000500000025766D6FB71A5740603B18B14FDE4B4025766D6FB71A574042B28009DCDE4B40F243A511331B574042B28009DCDE4B40F243A511331B5740603B18B14FDE4B4025766D6FB71A5740603B18B14FDE4B40
73022	59769	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Горная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
28268	51838	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Солнечная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
73039	59783	92.844154000000003	92.849076999999994	56.238366999999997	56.228135000000002	Центральная	0103000020E6100000010000000500000068B27F9E0636574057091687331D4C4068B27F9E063657400AB952CF821E4C404AB20E47573657400AB952CF821E4C404AB20E475736574057091687331D4C4068B27F9E0636574057091687331D4C40
27959	51777	91.979292000000001	91.985123000000002	56.628673999999997	56.623806000000002	Первомайская	0103000020E61000000100000005000000014F5AB8ACFE5640388600E0D84F4C40014F5AB8ACFE564039ECBE6378504C4065E256410CFF564039ECBE6378504C4065E256410CFF5640388600E0D84F4C40014F5AB8ACFE5640388600E0D84F4C40
28267	51837	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	Школьная	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
28238	23775	94.840093999999993	94.874257	56.808950000000003	56.793385000000001	Центральная	0103000020E6100000010000000500000036E49F19C4B557408811C2A38D654C4036E49F19C4B55740B30C71AC8B674C4024D3A1D3F3B75740B30C71AC8B674C4024D3A1D3F3B757408811C2A38D654C4036E49F19C4B557408811C2A38D654C40
27874	22858	95.049634999999995	95.066559999999996	56.638714	56.627253000000003	Центральная	0103000020E610000001000000050000002A6F47382DC35740B1A888D349504C402A6F47382DC35740A9BF5E61C1514C4031CEDF8442C45740A9BF5E61C1514C4031CEDF8442C45740B1A888D349504C402A6F47382DC35740B1A888D349504C40
72780	23488	95.337733999999998	95.347885000000005	56.910547000000001	56.905062000000001	Центральная	0103000020E61000000100000005000000D32F116F9DD557401A6D5512D9734C40D32F116F9DD55740473CD9CD8C744C40377172BF43D65740473CD9CD8C744C40377172BF43D657401A6D5512D9734C40D32F116F9DD557401A6D5512D9734C40
72777	22686	95.310461000000004	95.331256999999994	56.786127999999998	56.771703000000002	Центральная 	0103000020E61000000100000005000000BE6BD097DED35740D09CF529C7624C40BE6BD097DED35740253CA1D79F644C408C648F5033D55740253CA1D79F644C408C648F5033D55740D09CF529C7624C40BE6BD097DED35740D09CF529C7624C40
27878	22956	94.909417000000005	94.937192999999994	56.711951999999997	56.702109999999998	Центральная	0103000020E610000001000000050000004B5B5CE333BA5740E71890BDDE594C404B5B5CE333BA574030293E3E215B4C40914259F8FABB574030293E3E215B4C40914259F8FABB5740E71890BDDE594C404B5B5CE333BA5740E71890BDDE594C40
27896	23626	95.102329999999995	95.134238999999994	56.948509000000001	56.938797000000001	Центральная	0103000020E6100000010000000500000094D920938CC657409D4A06802A784C4094D920938CC65740187B2FBE68794C4041B62C5F97C85740187B2FBE68794C4041B62C5F97C857409D4A06802A784C4094D920938CC657409D4A06802A784C40
27807	23306	95.481966999999997	95.502808000000002	56.808447000000001	56.803322000000001	Кедровая	0103000020E6100000010000000500000014B01D8CD8DE574023145B41D3664C4014B01D8CD8DE574050C6F8307B674C40B30A9B012EE0574050C6F8307B674C40B30A9B012EE0574023145B41D3664C4014B01D8CD8DE574023145B41D3664C40
28392	23306	95.481966999999997	95.502808000000002	56.808447000000001	56.803322000000001	Дружбы	0103000020E6100000010000000500000014B01D8CD8DE574023145B41D3664C4014B01D8CD8DE574050C6F8307B674C40B30A9B012EE0574050C6F8307B674C40B30A9B012EE0574023145B41D3664C4014B01D8CD8DE574023145B41D3664C40
72792	5904	95.289278999999993	95.316937999999993	56.587950999999997	56.578893999999998	Зеленая	0103000020E61000000100000005000000DA1A118C83D25740E1ECD632194A4C40DA1A118C83D25740435376FA414B4C40043752B648D45740435376FA414B4C40043752B648D45740E1ECD632194A4C40DA1A118C83D25740E1ECD632194A4C40
72727	23319	95.405404000000004	95.427825999999996	56.844033000000003	56.837913	Школьная	0103000020E61000000100000005000000BA6A9E23F2D9574056F2B1BB406B4C40BA6A9E23F2D9574055DFF945096C4C4039984D8061DB574055DFF945096C4C4039984D8061DB574056F2B1BB406B4C40BA6A9E23F2D9574056F2B1BB406B4C40
27887	23223	95.547527000000002	95.563849000000005	56.744624000000002	56.743281000000003	Чулпан	0103000020E6100000010000000500000054ABAFAE0AE357407D5EF1D4235F4C4054ABAFAE0AE357408AE8D7D64F5F4C4078B81D1A16E457408AE8D7D64F5F4C4078B81D1A16E457407D5EF1D4235F4C4054ABAFAE0AE357407D5EF1D4235F4C40
28073	23133	94.333292	95.801597000000001	57.136699	56.542495000000002	Центральная	0103000020E610000001000000050000002E01F8A7549557402C9FE57970454C402E01F8A754955740AD32535A7F914C4097E4805D4DF35740AD32535A7F914C4097E4805D4DF357402C9FE57970454C402E01F8A7549557402C9FE57970454C40
73118	17538	95.483485999999999	95.520532000000003	56.944409999999998	56.929447000000003	Центральная	0103000020E61000000100000005000000BA84436FF1DE5740C32E8A1EF8764C40BA84436FF1DE5740F701486DE2784C406021736550E15740F701486DE2784C406021736550E15740C32E8A1EF8764C40BA84436FF1DE5740C32E8A1EF8764C40
73078	59815	94.777697000000003	94.793453999999997	56.734690999999998	56.725076999999999	улица Школьная	0103000020E61000000100000005000000A14CA3C9C5B15740780AB952CF5C4C40A14CA3C9C5B1574030D5CC5A0A5E4C40583849F3C7B2574030D5CC5A0A5E4C40583849F3C7B25740780AB952CF5C4C40A14CA3C9C5B15740780AB952CF5C4C40
27876	22783	95.355852999999996	95.381930999999994	56.623603000000003	56.613830999999998	Центральная	0103000020E61000000100000005000000BE4BA94BC6D65740AF22A303924E4C40BE4BA94BC6D6574000581D39D24F4C400795B88E71D8574000581D39D24F4C400795B88E71D85740AF22A303924E4C40BE4BA94BC6D65740AF22A303924E4C40
72888	23231	95.348505000000003	95.375679000000005	56.758941	56.747402999999998	Набережная	0103000020E61000000100000005000000855FEAE74DD6574055F7C8E6AA5F4C40855FEAE74DD65740F94B8BFA24614C40D1B2EE1F0BD85740F94B8BFA24614C40D1B2EE1F0BD8574055F7C8E6AA5F4C40855FEAE74DD6574055F7C8E6AA5F4C40
72935	22933	95.117035999999999	95.150830999999997	56.695442999999997	56.688240999999998	Центральная	0103000020E61000000100000005000000191D90847DC757401762F54718584C40191D90847DC75740B69DB64604594C40450E1137A7C95740B69DB64604594C40450E1137A7C957401762F54718584C40191D90847DC757401762F54718584C40
27727	23952	94.891271000000003	94.910764999999998	56.820335999999998	56.813403999999998	Центральная	0103000020E61000000100000005000000E33785950AB95740C1374D9F1D684C40E33785950AB95740A0DD21C500694C40DA5548F949BA5740A0DD21C500694C40DA5548F949BA5740C1374D9F1D684C40E33785950AB95740C1374D9F1D684C40
28066	23040	95.471896999999998	95.517450999999994	56.701951999999999	56.680306000000002	Новая	0103000020E610000001000000050000002785798F33DE5740E4A25A4414574C402785798F33DE57404FAE2990D9594C401492CCEA1DE157404FAE2990D9594C401492CCEA1DE15740E4A25A4414574C402785798F33DE5740E4A25A4414574C40
28444	23700	94.996105	95.018590000000003	56.851804999999999	56.843181000000001	Центральная	0103000020E6100000010000000500000074982F2FC0BF5740E6CDE15AED6B4C4074982F2FC0BF5740DEC83CF2076D4C4017821C9430C15740DEC83CF2076D4C4017821C9430C15740E6CDE15AED6B4C4074982F2FC0BF5740E6CDE15AED6B4C40
28239	23593	95.098224999999999	95.116461000000001	57.022072999999999	57.013694999999998	Центральная	0103000020E6100000010000000500000093A9825149C65740328FFCC1C0814C4093A9825149C65740F38FBE49D3824C409B90D61874C75740F38FBE49D3824C409B90D61874C75740328FFCC1C0814C4093A9825149C65740328FFCC1C0814C40
28650	22598	95.301091999999997	95.319139000000007	56.864767000000001	56.854467999999997	Центральная	0103000020E610000001000000050000009545611745D3574040BD19355F6D4C409545611745D357407CD45FAFB06E4C4034F8FBC56CD457407CD45FAFB06E4C4034F8FBC56CD4574040BD19355F6D4C409545611745D3574040BD19355F6D4C40
72934	8926	94.720231999999996	94.751268999999994	56.958449000000002	56.944409999999998	Школьная	0103000020E610000001000000050000001762F54718AE5740F701486DE2784C401762F54718AE574024F1F274AE7A4C40E95F92CA14B0574024F1F274AE7A4C40E95F92CA14B05740F701486DE2784C401762F54718AE5740F701486DE2784C40
72619	22235	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	переулок Южный	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
28205	22235	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	Советская	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
28291	22235	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	Ракуса	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
28417	22235	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	Новый переулок	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
28418	22235	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	Кирова	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
28199	22235	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	Денисовская	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
28586	22235	95.178866999999997	95.272812999999999	56.859378999999997	56.809565999999997	Больничная	0103000020E610000001000000050000005AD5928E72CB57400DFAD2DB9F674C405AD5928E72CB574041EF8D21006E4C401D3BA8C475D1574041EF8D21006E4C401D3BA8C475D157400DFAD2DB9F674C405AD5928E72CB57400DFAD2DB9F674C40
72614	23502	95.077922999999998	95.109471999999997	56.863444000000001	56.845692	Лесная	0103000020E61000000100000005000000CC26C0B0FCC45740923EADA23F6C4C40CC26C0B0FCC45740B6F63E55856E4C40F9F4D89601C75740B6F63E55856E4C40F9F4D89601C75740923EADA23F6C4C40CC26C0B0FCC45740923EADA23F6C4C40
72778	22846	95.044730000000001	95.071330000000003	56.660590999999997	56.654465999999999	Центральная	0103000020E610000001000000050000009BC937DBDCC25740062CB98AC5534C409BC937DBDCC257401684F23E8E544C40514EB4AB90C457401684F23E8E544C40514EB4AB90C45740062CB98AC5534C409BC937DBDCC25740062CB98AC5534C40
28530	45472	94.945988	94.968176	56.974454999999999	56.968062000000003	Лесная	0103000020E61000000100000005000000249A40118BBC57400C40A374E97B4C40249A40118BBC57403B3602F1BA7C4C406A317898F6BD57403B3602F1BA7C4C406A317898F6BD57400C40A374E97B4C40249A40118BBC57400C40A374E97B4C40
72867	23908	94.781524000000005	94.799131000000003	56.887934999999999	56.880253000000003	Калинина	0103000020E6100000010000000500000081423D7D04B257405B9A5B21AC704C4081423D7D04B25740A4FCA4DAA7714C40118E59F624B35740A4FCA4DAA7714C40118E59F624B357405B9A5B21AC704C4081423D7D04B257405B9A5B21AC704C40
28621	23851	94.577759	94.602633999999995	56.838690999999997	56.830506999999997	Кайтымская	0103000020E610000001000000050000000F7EE200FAA45740AE0CAA0D4E6A4C400F7EE200FAA457408A39083A5A6B4C404A5D328E91A657408A39083A5A6B4C404A5D328E91A65740AE0CAA0D4E6A4C400F7EE200FAA45740AE0CAA0D4E6A4C40
28606	23126	95.522516999999993	95.557489000000004	56.690579	56.681041999999998	Центральная	0103000020E61000000100000005000000A8A624EB70E15740E9995E622C574C40A8A624EB70E15740F62686E464584C404EB857E6ADE35740F62686E464584C404EB857E6ADE35740E9995E622C574C40A8A624EB70E15740E9995E622C574C40
28589	22698	95.239673999999994	95.290492	56.635010999999999	56.624097999999996	Центральная	0103000020E61000000100000005000000E5EC9DD156CF5740DFBF7971E24F4C40E5EC9DD156CF5740D5CC5A0A48514C40FAEFC16B97D25740D5CC5A0A48514C40FAEFC16B97D25740DFBF7971E24F4C40E5EC9DD156CF5740DFBF7971E24F4C40
28402	21790	90.363493000000005	90.385546000000005	56.684685999999999	56.674708000000003	Советская	0103000020E61000000100000005000000CCD4247843975640BF2CEDD45C564C40CCD4247843975640B80375CAA3574C40A24621C9AC985640B80375CAA3574C40A24621C9AC985640BF2CEDD45C564C40CCD4247843975640BF2CEDD45C564C40
28209	14837	90.678712000000004	90.701663999999994	56.580247999999997	56.570827000000001	Колхозная	0103000020E61000000100000005000000C7D9740470AB56403F56F0DB10494C40C7D9740470AB5640E2C80391454A4C40F4311F10E8AC5640E2C80391454A4C40F4311F10E8AC56403F56F0DB10494C40C7D9740470AB56403F56F0DB10494C40
72768	21178	90.999904000000001	91.018904000000006	56.62697	56.618952999999998	Центральная 	0103000020E61000000100000005000000EFC8586DFEBF56406B6116DA394F4C40EFC8586DFEBF56405CC98E8D40504C40DF701FB935C156405CC98E8D40504C40DF701FB935C156406B6116DA394F4C40EFC8586DFEBF56406B6116DA394F4C40
28572	46009	90.440910000000002	90.510664000000006	56.579489000000002	56.569080999999997	Советская	0103000020E61000000100000005000000AE9E93DE379C564032E36DA5D7484C40AE9E93DE379C564025B20FB22C4A4C40A7CF0EB8AEA0564025B20FB22C4A4C40A7CF0EB8AEA0564032E36DA5D7484C40AE9E93DE379C564032E36DA5D7484C40
73035	59780	90.550702000000001	90.565451999999993	56.624623	56.616630000000001	Боровая	0103000020E61000000100000005000000E0F599B33EA35640C2DD59BBED4E4C40E0F599B33EA356402AAA7EA5F34F4C404CDD955D30A456402AAA7EA5F34F4C404CDD955D30A45640C2DD59BBED4E4C40E0F599B33EA35640C2DD59BBED4E4C40
72862	21657	90.455579	90.471299999999999	56.512493999999997	56.504308000000002	Мира	0103000020E61000000100000005000000A46FD234289D56403B8E1F2A8D404C40A46FD234289D5640B7B2446799414C40B5A679C7299E5640B7B2446799414C40B5A679C7299E56403B8E1F2A8D404C40A46FD234289D56403B8E1F2A8D404C40
27853	21559	90.633463000000006	90.653226000000004	56.504243000000002	56.482258999999999	Советская	0103000020E61000000100000005000000780E65A88AA85640D099B4A9BA3D4C40780E65A88AA85640541EDD088B404C4067B96C74CEA95640541EDD088B404C4067B96C74CEA95640D099B4A9BA3D4C40780E65A88AA85640D099B4A9BA3D4C40
28565	21107	91.192430999999999	91.209327999999999	56.810639999999999	56.797817000000002	Таежная	0103000020E6100000010000000500000024EF1CCA50CC5640AF9811DE1E664C4024EF1CCA50CC56402B6A300DC3674C40C68844A165CD56402B6A300DC3674C40C68844A165CD5640AF9811DE1E664C4024EF1CCA50CC5640AF9811DE1E664C40
73004	59754	90.419196999999997	90.443990999999997	56.752195	56.743246999999997	Лесная	0103000020E610000001000000050000003465A71FD49A5640D0ECBAB7225F4C403465A71FD49A56407C9BFEEC47604C40F92D3A596A9C56407C9BFEEC47604C40F92D3A596A9C5640D0ECBAB7225F4C403465A71FD49A5640D0ECBAB7225F4C40
27829	21011	90.826753999999994	90.852985000000004	56.799033999999999	56.792054	Дружбы	0103000020E6100000010000000500000094F59B89E9B456403F55850662654C4094F59B89E9B456402F3201BF46664C40A1BE654E97B656402F3201BF46664C40A1BE654E97B656403F55850662654C4094F59B89E9B456403F55850662654C40
72948	21985	90.235905000000002	90.267579999999995	56.566636000000003	56.550564000000001	Центральная	0103000020E61000000100000005000000A0FD4811198F56406F2D93E178464C40A0FD4811198F56403E5E488787484C401344DD07209156403E5E488787484C401344DD07209156406F2D93E178464C40A0FD4811198F56406F2D93E178464C40
71551	20827	90.561158000000006	90.600621000000004	56.668030999999999	56.636257999999998	Советская	0103000020E61000000100000005000000E2783E03EAA35640C0E8F2E670514C40E2783E03EAA356406ADB300A82554C409D12109370A656406ADB300A82554C409D12109370A65640C0E8F2E670514C40E2783E03EAA35640C0E8F2E670514C40
27859	20827	90.561158000000006	90.600621000000004	56.668030999999999	56.636257999999998	Медицинская	0103000020E61000000100000005000000E2783E03EAA35640C0E8F2E670514C40E2783E03EAA356406ADB300A82554C409D12109370A656406ADB300A82554C409D12109370A65640C0E8F2E670514C40E2783E03EAA35640C0E8F2E670514C40
28295	21310	90.804494000000005	90.823708999999994	56.632674000000002	56.613112999999998	 Трактовая	0103000020E6100000010000000500000002F566D47CB3564050E09D7C7A4E4C4002F566D47CB35640C7832D76FB504C40EF1AF4A5B7B45640C7832D76FB504C40EF1AF4A5B7B4564050E09D7C7A4E4C4002F566D47CB3564050E09D7C7A4E4C40
72769	20352	93.290024000000003	93.306329000000005	57.330877000000001	57.315764000000001	Набережная	0103000020E6100000010000000500000087C3D2C08F52574088A06AF46AA84C4087C3D2C08F525740D2FF722D5AAA4C404034F3E49A535740D2FF722D5AAA4C404034F3E49A53574088A06AF46AA84C4087C3D2C08F52574088A06AF46AA84C40
28002	51790	93.432918999999998	93.446788999999995	56.857401000000003	56.836883999999998	Центральная	0103000020E610000001000000050000004AB4E4F1B45B5740D845D1031F6B4C404AB4E4F1B45B57406347E350BF6D4C409ACDE330985C57406347E350BF6D4C409ACDE330985C5740D845D1031F6B4C404AB4E4F1B45B5740D845D1031F6B4C40
72931	19638	93.141659000000004	93.166775000000001	56.814546999999997	56.803947999999998	пер.Садовый	0103000020E61000000100000005000000C80BE9F010495740A1D79FC4E7664C40C80BE9F01049574007077B1343684C4096B20C71AC4A574007077B1343684C4096B20C71AC4A5740A1D79FC4E7664C40C80BE9F010495740A1D79FC4E7664C40
28371	16762	93.299150999999995	93.326864	57.078133999999999	57.047145	Заречная	0103000020E6100000010000000500000034643C4A25535740C095ECD808864C4034643C4A25535740535A7F4B008A4C40588FFB56EB545740535A7F4B008A4C40588FFB56EB545740C095ECD808864C4034643C4A25535740C095ECD808864C40
72929	45432	93.131984000000003	93.152753000000004	57.242151	57.233587999999997	Центральная	0103000020E6100000010000000500000019E6046D72485740785E2A36E69D4C4019E6046D72485740CBD8D0CDFE9E4C406BD784B4C6495740CBD8D0CDFE9E4C406BD784B4C6495740785E2A36E69D4C4019E6046D72485740785E2A36E69D4C40
28354	19063	93.414413999999994	93.453121999999993	57.077244	57.046968999999997	Луговая	0103000020E610000001000000050000004A404CC2855A57408176871403864C404A404CC2855A5740F7E7A221E3894C4047C66AF3FF5C5740F7E7A221E3894C4047C66AF3FF5C57408176871403864C404A404CC2855A57408176871403864C40
72866	20726	93.317836	93.336924999999994	56.850540000000002	56.842841	Лесная	0103000020E61000000100000005000000745FCE6C575457402D5DC136E26B4C40745FCE6C575457404DF8A57EDE6C4C401B0DE02D905557404DF8A57EDE6C4C401B0DE02D905557402D5DC136E26B4C40745FCE6C575457402D5DC136E26B4C40
27838	45583	93.294633000000005	93.316156000000007	57.192694000000003	57.181626999999999	Дачная	0103000020E61000000100000005000000A2D45E44DB5257400989B48D3F974C40A2D45E44DB52574056116E32AA984C40CA1B60E63B54574056116E32AA984C40CA1B60E63B5457400989B48D3F974C40A2D45E44DB5257400989B48D3F974C40
28168	19157	92.738619999999997	92.761634999999998	56.764184999999998	56.755768000000003	Чуева 	0103000020E61000000100000005000000FA0AD28C452F574082AE7D01BD604C40FA0AD28C452F5740008C67D0D0614C404B1FBAA0BE305740008C67D0D0614C404B1FBAA0BE30574082AE7D01BD604C40FA0AD28C452F574082AE7D01BD604C40
28277	20508	93.325947999999997	93.347893999999997	57.101115	57.095320999999998	Нагорная	0103000020E61000000100000005000000950C0055DC5457409ECF807A338C4C40950C0055DC54574049111956F18C4C40601E32E54356574049111956F18C4C40601E32E5435657409ECF807A338C4C40950C0055DC5457409ECF807A338C4C40
28160	19564	93.112031999999999	93.126171999999997	56.961044999999999	56.944498000000003	Новая	0103000020E61000000100000005000000C00644882B47574097917A4FE5784C40C00644882B475740FE7DC685037B4C40F06AB93313485740FE7DC685037B4C40F06AB9331348574097917A4FE5784C40C00644882B47574097917A4FE5784C40
28230	51827	93.297148000000007	93.318106	57.309547000000002	57.297843999999998	Центральная	0103000020E6100000010000000500000099840B7904535740A8A78FC01FA64C4099840B790453574097C9703C9FA74C4054AA44D95B54574097C9703C9FA74C4054AA44D95B545740A8A78FC01FA64C4099840B7904535740A8A78FC01FA64C40
28105	45353	92.774805000000001	92.796633999999997	56.930914999999999	56.922682999999999	Советская	0103000020E61000000100000005000000BFF1B567963157409FC9FE791A764C40BFF1B567963157408C2D043928774C406D382C0DFC3257408C2D043928774C406D382C0DFC3257409FC9FE791A764C40BFF1B567963157409FC9FE791A764C40
28172	45644	93.288767000000007	93.309912999999995	56.903843000000002	56.89676	Школьная	0103000020E61000000100000005000000804A95287B525740342E1C08C9724C40804A95287B525740F9DB9E20B1734C40BCE6559DD5535740F9DB9E20B1734C40BCE6559DD5535740342E1C08C9724C40804A95287B525740342E1C08C9724C40
72724	45644	93.288767000000007	93.309912999999995	56.903843000000002	56.89676	Центральная	0103000020E61000000100000005000000804A95287B525740342E1C08C9724C40804A95287B525740F9DB9E20B1734C40BCE6559DD5535740F9DB9E20B1734C40BCE6559DD5535740342E1C08C9724C40804A95287B525740342E1C08C9724C40
72779	49567	92.821894	92.838774000000001	57.033683000000003	57.024101999999999	Кооперативная	0103000020E61000000100000005000000D5B14AE99934574054E23AC615834C40D5B14AE99934574031B77BB94F844C400CAF2479AE35574031B77BB94F844C400CAF2479AE35574054E23AC615834C40D5B14AE99934574054E23AC615834C40
72875	46751	93.259615999999994	93.285075000000006	56.758028000000003	56.749402000000003	Центральная	0103000020E610000001000000050000002C616D8C9D5057404CC79C67EC5F4C402C616D8C9D505740E5B9BE0F07614C40107A36AB3E525740E5B9BE0F07614C40107A36AB3E5257404CC79C67EC5F4C402C616D8C9D5057404CC79C67EC5F4C40
72890	19701	92.776386000000002	92.797145999999998	57.053001000000002	57.044217000000003	Солнечная	0103000020E61000000100000005000000A0C4E74EB0315740B07614E7A8854C40A0C4E74EB0315740E1D39CBCC8864C40C808A87004335740E1D39CBCC8864C40C808A87004335740B07614E7A8854C40A0C4E74EB0315740B07614E7A8854C40
72865	20463	93.121167999999997	93.148261000000005	57.055472999999999	57.041401999999998	Верхняя	0103000020E6100000010000000500000097546D37C147574097FE25A94C854C4097546D37C1475740CF6740BD19874C406D91B41B7D495740CF6740BD19874C406D91B41B7D49574097FE25A94C854C4097546D37C147574097FE25A94C854C40
71618	19273	93.104737999999998	93.192413000000002	56.918536000000003	56.886243	пер.Центральный	0103000020E6100000010000000500000080290307B44657408BA71E6970714C4080290307B44657406E19709692754C40D1949D7E504C57406E19709692754C40D1949D7E504C57408BA71E6970714C4080290307B44657408BA71E6970714C40
71619	59486	93.104737999999998	93.192413000000002	56.918536000000003	56.886243	Советская	0103000020E6100000010000000500000080290307B44657408BA71E6970714C4080290307B44657406E19709692754C40D1949D7E504C57406E19709692754C40D1949D7E504C57408BA71E6970714C4080290307B44657408BA71E6970714C40
71590	59486	93.104737999999998	93.192413000000002	56.918536000000003	56.886243	Кооперативная	0103000020E6100000010000000500000080290307B44657408BA71E6970714C4080290307B44657406E19709692754C40D1949D7E504C57406E19709692754C40D1949D7E504C57408BA71E6970714C4080290307B44657408BA71E6970714C40
28004	19149	93.126576	93.147219000000007	56.735470999999997	56.715103999999997	Центральная 	0103000020E61000000100000005000000581D39D219485740909E2287885B4C40581D39D2194857400514EAE9235E4C4064963D096C4957400514EAE9235E4C4064963D096C495740909E2287885B4C40581D39D219485740909E2287885B4C40
28487	19468	92.974993999999995	92.993894999999995	57.015521999999997	57.004367999999999	Новая	0103000020E61000000100000005000000F5F23B4D663E5740109370218F804C40F5F23B4D663E57402B2FF99FFC814C401B2AC6F99B3F57402B2FF99FFC814C401B2AC6F99B3F5740109370218F804C40F5F23B4D663E5740109370218F804C40
72804	59712	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Киевская	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
73124	59856	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Школьная	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
72664	59656	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Ленина	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
73114	59845	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Ленина	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
72704	59672	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Центральный переулок	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
28341	18867	97.298810000000003	97.348325000000003	57.45346	57.439672000000002	Партизанская	0103000020E61000000100000005000000F06DFAB31F535840C47B0E2C47B84C40F06DFAB31F535840A7052FFA0ABA4C4045D8F0F44A565840A7052FFA0ABA4C4045D8F0F44A565840C47B0E2C47B84C40F06DFAB31F535840C47B0E2C47B84C40
27875	51758	96.691638999999995	96.712542999999997	57.621555999999998	57.613767000000003	50 лет Октября	0103000020E61000000100000005000000D76839D0432C5840992EC4EA8FCE4C40D76839D0432C5840F850A2258FCF4C40997FF44D9A2D5840F850A2258FCF4C40997FF44D9A2D5840992EC4EA8FCE4C40D76839D0432C5840992EC4EA8FCE4C40
72542	59621	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Октябрьская	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
73091	59826	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Ленина	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
28352	32714	96.894191000000006	96.929522000000006	57.574711000000001	57.560316999999998	Советская	0103000020E610000001000000050000002A58E36C3A3958404832AB77B8C74C402A58E36C3A39584063D34A2190C94C4067BAD7497D3B584063D34A2190C94C4067BAD7497D3B58404832AB77B8C74C402A58E36C3A3958404832AB77B8C74C40
28533	49301	97.500168000000002	97.570874000000003	57.453606000000001	57.433897000000002	Победы	0103000020E610000001000000050000005EA0A4C002605840906AD8EF89B74C405EA0A4C0026058407BA2EBC20FBA4C40C0081A33896458407BA2EBC20FBA4C40C0081A3389645840906AD8EF89B74C405EA0A4C002605840906AD8EF89B74C40
27803	18719	97.412042999999997	97.443788999999995	57.762574999999998	57.74765	Школьная	0103000020E61000000100000005000000ED629AE95E5A58405D6DC5FEB2DF4C40ED629AE95E5A5840A4DFBE0E9CE14C40C554FA09675C5840A4DFBE0E9CE14C40C554FA09675C58405D6DC5FEB2DF4C40ED629AE95E5A58405D6DC5FEB2DF4C40
73559	60034	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Октябрьская	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
72930	49315	97.522256999999996	97.548289999999994	57.432735000000001	57.428455999999997	Центральная	0103000020E61000000100000005000000DAC69FA86C61584032E36DA5D7B64C40DAC69FA86C615840D36A48DC63B74C4053AEF02E17635840D36A48DC63B74C4053AEF02E1763584032E36DA5D7B64C40DAC69FA86C61584032E36DA5D7B64C40
27984	18647	97.775662999999994	97.789434	57.822701000000002	57.816018999999997	Черемушки	0103000020E61000000100000005000000E76D6C76A471584012F5824F73E84C40E76D6C76A471584079B130444EE94C406E162F168672584079B130444EE94C406E162F168672584012F5824F73E84C40E76D6C76A471584012F5824F73E84C40
73145	59870	97.458305999999993	97.688588999999993	58.000593000000002	57.856495000000002	Центральная	0103000020E61000000100000005000000E063B0E2545D58400118CFA0A1ED4C40E063B0E2545D5840A3CD716E13004D40A9D898D7116C5840A3CD716E13004D40A9D898D7116C58400118CFA0A1ED4C40E063B0E2545D58400118CFA0A1ED4C40
73109	59841	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Октябрьская	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
73086	59822	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Ленина	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
72707	59676	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	Юбилейная	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
27832	51752	89.995058	90.019591000000005	56.381937999999998	56.371724999999998	Школьная	0103000020E61000000100000005000000E2E7BF07AF7F5640840D4FAF942F4C40E2E7BF07AF7F5640C18C2958E3304C40F1129CFA40815640C18C2958E3304C40F1129CFA40815640840D4FAF942F4C40E2E7BF07AF7F5640840D4FAF942F4C40
28544	20374	89.288497000000007	89.352062000000004	56.321460999999999	56.307087000000003	Центральная	0103000020E61000000100000005000000A0FF1EBC765256406D0377A04E274C40A0FF1EBC7652564040F850A225294C40850A0E2F8856564040F850A225294C40850A0E2F885656406D0377A04E274C40A0FF1EBC765256406D0377A04E274C40
72818	32756	89.586010000000002	89.604146999999998	56.387639	56.379022999999997	50 лет Октября	0103000020E61000000100000005000000414816308165564045B75ED383304C404148163081655640BBD39D279E314C407FBE2D58AA665640BBD39D279E314C407FBE2D58AA66564045B75ED383304C40414816308165564045B75ED383304C40
9701	40279	89.639612	89.664351999999994	56.287742000000001	56.280177000000002	Советская	0103000020E6100000010000000500000044882B67EF685640B30B06D7DC234C4044882B67EF685640C3D7D7BAD4244C400F4240BE846A5640C3D7D7BAD4244C400F4240BE846A5640B30B06D7DC234C4044882B67EF685640B30B06D7DC234C40
72830	32735	89.829660000000004	89.859071	56.275064	56.266362000000001	Центральная	0103000020E6100000010000000500000029B3412619755640D672672618224C4029B34126197556404A27124C35234C404A7CEE04FB7656404A27124C35234C404A7CEE04FB765640D672672618224C4029B3412619755640D672672618224C40
28129	19558	89.768609999999995	89.788176000000007	56.155999000000001	56.147148999999999	Мира 	0103000020E610000001000000050000003A58FFE730715640CE5147C7D5124C403A58FFE730715640B79A75C6F7134C407FDFBF7971725640B79A75C6F7134C407FDFBF7971725640CE5147C7D5124C403A58FFE730715640CE5147C7D5124C40
28047	19635	89.334076999999994	89.351665999999994	56.088543999999999	56.079864000000001	Береговая	0103000020E6100000010000000500000021567F84615556405A10CAFB380A4C4021567F8461555640E620E868550B4C405E471CB281565640E620E868550B4C405E471CB2815656405A10CAFB380A4C4021567F84615556405A10CAFB380A4C40
27871	32773	89.242180000000005	89.261358999999999	56.282001000000001	56.266621999999998	Верхняя	0103000020E61000000100000005000000B3EF8AE07F4F5640723271AB20224C40B3EF8AE07F4F56403B38D89B18244C40FA60191BBA5056403B38D89B18244C40FA60191BBA505640723271AB20224C40B3EF8AE07F4F5640723271AB20224C40
72679	20149	89.986569000000003	90.026579999999996	56.248345999999998	56.233843999999998	Переездная	0103000020E61000000100000005000000D68F4DF2237F5640D32EA699EE1D4C40D68F4DF2237F5640D40B3ECDC91F4C4092AE997CB3815640D40B3ECDC91F4C4092AE997CB3815640D32EA699EE1D4C40D68F4DF2237F5640D32EA699EE1D4C40
27821	20002	90.010696999999993	90.045471000000006	56.196572000000003	56.171166999999997	Центральная	0103000020E61000000100000005000000944A7842AF805640C493DDCCE8154C40944A7842AF80564098A7734529194C40A77A32FFE882564098A7734529194C40A77A32FFE8825640C493DDCCE8154C40944A7842AF805640C493DDCCE8154C40
28539	20097	90.040296999999995	90.074854999999999	56.234340000000003	56.223650999999997	Трактовая	0103000020E610000001000000050000001F48DE3994825640DD5B9198A01C4C401F48DE3994825640841266DAFE1D4C404B3CA06CCA845640841266DAFE1D4C404B3CA06CCA845640DD5B9198A01C4C401F48DE3994825640DD5B9198A01C4C40
27902	16594	89.239780999999994	89.260262999999995	56.124029999999998	56.110785999999997	Буркова	0103000020E61000000100000005000000F04C6892584F5640656D533C2E0E4C40F04C6892584F564087DC0C37E00F4C40F7562426A850564087DC0C37E00F4C40F7562426A8505640656D533C2E0E4C40F04C6892584F5640656D533C2E0E4C40
28078	51735	89.786370000000005	89.816850000000002	56.372976000000001	56.358905999999998	 Школьная	0103000020E610000001000000050000008E23D6E253725640492BBEA1F02D4C408E23D6E253725640B11875ADBD2F4C4035EF384547745640B11875ADBD2F4C4035EF384547745640492BBEA1F02D4C408E23D6E253725640492BBEA1F02D4C40
27764	51735	89.786370000000005	89.816850000000002	56.372976000000001	56.358905999999998	 Пахомова	0103000020E610000001000000050000008E23D6E253725640492BBEA1F02D4C408E23D6E253725640B11875ADBD2F4C4035EF384547745640B11875ADBD2F4C4035EF384547745640492BBEA1F02D4C408E23D6E253725640492BBEA1F02D4C40
72817	51780	89.895228000000003	89.927809999999994	56.393403999999997	56.385651000000003	Октябрьская	0103000020E61000000100000005000000AA9D616A4B795640B95510035D314C40AA9D616A4B795640CB0EF10F5B324C40B6B9313D617B5640CB0EF10F5B324C40B6B9313D617B5640B95510035D314C40AA9D616A4B795640B95510035D314C40
72900	33054	89.875698999999997	89.897689	56.288685999999998	56.278002999999998	Центральная 	0103000020E61000000100000005000000F488D1730B7856404E98309A95234C40F488D1730B7856401268B0A9F3244C40A73E90BC737956401268B0A9F3244C40A73E90BC737956404E98309A95234C40F488D1730B7856404E98309A95234C40
72836	32762	89.330089000000001	89.356399999999994	56.399537000000002	56.387565000000002	Центральная	0103000020E610000001000000050000003DF19C2D205556408109DCBA9B314C403DF19C2D205556405F45460724334C40D712F241CF5656405F45460724334C40D712F241CF5656408109DCBA9B314C403DF19C2D205556408109DCBA9B314C40
28632	32635	89.830629999999999	89.857939000000002	56.176409	56.160155000000003	 Школьная	0103000020E61000000100000005000000E544BB0A297556403CA583F57F144C40E544BB0A297556402BDCF29194164C40A1BDFA78E87656402BDCF29194164C40A1BDFA78E87656403CA583F57F144C40E544BB0A297556403CA583F57F144C40
28080	33002	89.453795999999997	89.464899000000003	56.311756000000003	56.302757	Центральная	0103000020E610000001000000050000008FC360FE0A5D56404AD1CABDC0264C408FC360FE0A5D5640782AE09EE7274C405C3CBCE7C05D5640782AE09EE7274C405C3CBCE7C05D56404AD1CABDC0264C408FC360FE0A5D56404AD1CABDC0264C40
28350	19709	89.792936999999995	89.834564999999998	56.363712999999997	56.337859999999999	Северная	0103000020E6100000010000000500000074B2D47ABF725640335019FF3E2B4C4074B2D47ABF725640A510C8258E2E4C40B858518369755640A510C8258E2E4C40B858518369755640335019FF3E2B4C4074B2D47ABF725640335019FF3E2B4C40
28021	19709	89.792936999999995	89.834564999999998	56.363712999999997	56.337859999999999	Кооперативная	0103000020E6100000010000000500000074B2D47ABF725640335019FF3E2B4C4074B2D47ABF725640A510C8258E2E4C40B858518369755640A510C8258E2E4C40B858518369755640335019FF3E2B4C4074B2D47ABF725640335019FF3E2B4C40
73164	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Школьная	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73198	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Совхозная	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
28637	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Советская 	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73279	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Советская	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73212	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Сибирская	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73199	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Кирова 	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73285	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Кирова	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73196	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	40 лет Октября	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73226	16488	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	1-я Зарельсовая	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
28055	51747	89.193769000000003	89.223332999999997	56.396622999999998	56.382890000000003	Ленинская	0103000020E61000000100000005000000A27E17B6664C564094FB1D8A02314C40A27E17B6664C5640B3EBDE8AC4324C4086C77E164B4E5640B3EBDE8AC4324C4086C77E164B4E564094FB1D8A02314C40A27E17B6664C564094FB1D8A02314C40
73252	59892	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Куйбышева	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73257	59892	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Деповская	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
73188	59882	89.408744999999996	89.578653000000003	56.239967999999998	56.169618999999997	Промышленная	0103000020E61000000100000005000000D3D9C9E0285A5640DEE34C13B6154C40D3D9C9E0285A5640130B7C45B71E4C40DEAE97A608655640130B7C45B71E4C40DEAE97A608655640DEE34C13B6154C40D3D9C9E0285A5640DEE34C13B6154C40
27986	15533	90.618938	90.626277000000002	57.214252999999999	57.209764	 Центральная	0103000020E610000001000000050000001B1021AE9CA7564067F0F78BD99A4C401B1021AE9CA75640F2086EA46C9B4C402B4F20EC14A85640F2086EA46C9B4C402B4F20EC14A8564067F0F78BD99A4C401B1021AE9CA7564067F0F78BD99A4C40
28252	32917	91.389126000000005	91.407415999999998	56.990341000000001	56.976112999999998	 Строительная	0103000020E610000001000000050000007E01BD70E7D85640A8195245F17C4C407E01BD70E7D85640A8716F7EC37E4C407FF78E1A13DA5640A8716F7EC37E4C407FF78E1A13DA5640A8195245F17C4C407E01BD70E7D85640A8195245F17C4C40
28601	14607	90.658535000000001	90.671750000000003	56.902515999999999	56.884320000000002	Школьная	0103000020E610000001000000050000005E11FC6F25AA56407099D36531714C405E11FC6F25AA5640F10EF0A485734C40A245B6F3FDAA5640F10EF0A485734C40A245B6F3FDAA56407099D36531714C405E11FC6F25AA56407099D36531714C40
72858	17552	90.060006000000001	90.074972000000002	57.472147	57.466299999999997	Новая	0103000020E6100000010000000500000015E46723D7835640F90FE9B7AFBB4C4015E46723D7835640C7F319506FBC4C4068075C57CC845640C7F319506FBC4C4068075C57CC845640F90FE9B7AFBB4C4015E46723D7835640F90FE9B7AFBB4C40
72809	14806	90.288870000000003	90.299684999999997	56.810192000000001	56.799641000000001	Профсоюзная	0103000020E61000000100000005000000EAB298D87C92564037C5E3A25A664C40EAB298D87C9256408CBD175FB4674C408386FE092E9356408CBD175FB4674C408386FE092E93564037C5E3A25A664C40EAB298D87C92564037C5E3A25A664C40
28429	48055	91.455466999999999	91.488569999999996	57.009210000000003	56.993043	Комсомольская	0103000020E61000000100000005000000105A0F5F26DD5640C84274081C7F4C40105A0F5F26DD5640E96514CB2D814C40A1F31ABB44DF5640E96514CB2D814C40A1F31ABB44DF5640C84274081C7F4C40105A0F5F26DD5640C84274081C7F4C40
28465	15624	90.398491000000007	90.411974999999998	57.333243000000003	57.325304000000003	Центральная	0103000020E61000000100000005000000063065E08099564006A1BC8FA3A94C40063065E0809956407B4FE5B4A7AA4C4041F163CC5D9A56407B4FE5B4A7AA4C4041F163CC5D9A564006A1BC8FA3A94C40063065E08099564006A1BC8FA3A94C40
27914	48238	90.521739999999994	90.545815000000005	57.354816999999997	57.341084000000002	Центральная	0103000020E61000000100000005000000F6402B3064A156402D98F8A3A8AB4C40F6402B3064A156404C88B9A46AAD4C40A4AA09A2EEA256404C88B9A46AAD4C40A4AA09A2EEA256402D98F8A3A8AB4C40F6402B3064A156402D98F8A3A8AB4C40
28089	14505	90.662137999999999	90.702085999999994	56.970244999999998	56.930197999999997	Советская	0103000020E6100000010000000500000016DC0F7860AA5640FD6662BA10774C4016DC0F7860AA5640C30DF8FC307C4C40AF3E1EFAEEAC5640C30DF8FC307C4C40AF3E1EFAEEAC5640FD6662BA10774C4016DC0F7860AA5640FD6662BA10774C40
72953	15699	90.341025999999999	90.357006999999996	57.104356000000003	57.096822000000003	Новая	0103000020E610000001000000050000007C45B75ED395564044C4CDA9648C4C407C45B75ED3955640199293895B8D4C405B5CE333D9965640199293895B8D4C405B5CE333D996564044C4CDA9648C4C407C45B75ED395564044C4CDA9648C4C40
73070	15795	90.228134999999995	90.242695999999995	57.170219000000003	57.160823999999998	Центральная	0103000020E61000000100000005000000AB048BC3998E5640B9347EE195944C40AB048BC3998E5640341477BCC9954C40AEB7CD54888F5640341477BCC9954C40AEB7CD54888F5640B9347EE195944C40AB048BC3998E5640B9347EE195944C40
27739	15245	91.472463000000005	91.484977000000001	57.102454000000002	57.092298999999997	 Центральная	0103000020E610000001000000050000007C6473D53CDE56400C3A2174D08B4C407C6473D53CDE564015AC71361D8D4C40FB93F8DC09DF564015AC71361D8D4C40FB93F8DC09DF56400C3A2174D08B4C407C6473D53CDE56400C3A2174D08B4C40
28260	15389	90.862435000000005	90.891154	57.158510999999997	57.145988000000003	Школьная	0103000020E6100000010000000500000040FB912232B75640E2CD1ABCAF924C4040FB912232B756403387A4164A944C40C66CC9AA08B956403387A4164A944C40C66CC9AA08B95640E2CD1ABCAF924C4040FB912232B75640E2CD1ABCAF924C40
27817	15326	91.649322999999995	91.669534999999996	57.333666000000001	57.321610999999997	 Почтовая	0103000020E6100000010000000500000099620E828EE9564055849B8C2AA94C4099620E828EE95640C1E44691B5AA4C40C02154A9D9EA5640C1E44691B5AA4C40C02154A9D9EA564055849B8C2AA94C4099620E828EE9564055849B8C2AA94C40
27747	15747	90.194906000000003	90.208191999999997	57.143487999999998	57.129762999999997	Советская	0103000020E61000000100000005000000D4F20357798C56408C9DF0129C904C40D4F20357798C564029AF95D05D924C407CD28904538D564029AF95D05D924C407CD28904538D56408C9DF0129C904C40D4F20357798C56408C9DF0129C904C40
72859	15235	91.461125999999993	91.482613999999998	57.026345999999997	57.019119000000003	Береговая	0103000020E610000001000000050000007555A01683DD5640BADDCB7D72824C407555A01683DD5640B130444E5F834C40DFA5D425E3DE5640B130444E5F834C40DFA5D425E3DE5640BADDCB7D72824C407555A01683DD5640BADDCB7D72824C40
28280	14760	90.446325999999999	90.466151999999994	56.895167000000001	56.884354999999999	Новая	0103000020E61000000100000005000000B056ED9A909C5640EC866D8B32714C40B056ED9A909C5640AEBA0ED594724C40C2BD326FD59D5640AEBA0ED594724C40C2BD326FD59D5640EC866D8B32714C40B056ED9A909C5640EC866D8B32714C40
28623	14673	90.561688000000004	90.572907999999998	57.148463999999997	57.141314999999999	Центральная	0103000020E6100000010000000500000090A339B2F2A3564095B7239C16924C4090A339B2F2A3564011514CDE00934C4079E75086AAA4564011514CDE00934C4079E75086AAA4564095B7239C16924C4090A339B2F2A3564095B7239C16924C40
72068	51875	89.939344000000006	89.945659000000006	57.493924	57.485478000000001	Кирова	0103000020E6100000010000000500000068EC4B361E7C5640B876A22424BE4C4068EC4B361E7C5640D15AD1E638BF4C40C28A53AD857C5640D15AD1E638BF4C40C28A53AD857C5640B876A22424BE4C4068EC4B361E7C5640B876A22424BE4C40
28481	51875	89.939344000000006	89.945659000000006	57.493924	57.485478000000001	60 лет Аэрофлота	0103000020E6100000010000000500000068EC4B361E7C5640B876A22424BE4C4068EC4B361E7C5640D15AD1E638BF4C40C28A53AD857C5640D15AD1E638BF4C40C28A53AD857C5640B876A22424BE4C4068EC4B361E7C5640B876A22424BE4C40
72806	15829	90.227442999999994	90.242075999999997	57.204957	57.194834999999998	Зеленая	0103000020E6100000010000000500000010AD156D8E8E5640DE8E705AF0984C4010AD156D8E8E56400B0BEE073C9A4C4060C9552C7E8F56400B0BEE073C9A4C4060C9552C7E8F5640DE8E705AF0984C4010AD156D8E8E5640DE8E705AF0984C40
28243	47863	90.666889999999995	90.685205999999994	57.040643000000003	57.010342000000001	Школьная	0103000020E61000000100000005000000E2016553AEAA56403BE3FBE252814C40E2016553AEAA5640DAE731CA33854C407841446ADAAB5640DAE731CA33854C407841446ADAAB56403BE3FBE252814C40E2016553AEAA56403BE3FBE252814C40
27946	51773	90.225395000000006	90.232815000000002	57.112045000000002	57.102879999999999	Центральная	0103000020E61000000100000005000000A56B26DF6C8E5640CCB4FD2B2B8D4C40A56B26DF6C8E56401557957D578E4C402BC1E270E68E56401557957D578E4C402BC1E270E68E5640CCB4FD2B2B8D4C40A56B26DF6C8E5640CCB4FD2B2B8D4C40
28600	14355	92.973521000000005	92.991136999999995	55.557628000000001	55.546143999999998	Молодежная	0103000020E61000000100000005000000083E062B4E3E57400C74ED0BE8C54B40083E062B4E3E5740BDAAB35A60C74B40C136E2C96E3F5740BDAAB35A60C74B40C136E2C96E3F57400C74ED0BE8C54B40083E062B4E3E57400C74ED0BE8C54B40
28102	6148	93.351730000000003	93.383970000000005	56.175462000000003	56.157724000000002	 40 лет Октября	0103000020E610000001000000050000006AC18BBE82565740ACE5CE4C30144C406AC18BBE825657406BD8EF8975164C404A29E8F6925857406BD8EF8975164C404A29E8F692585740ACE5CE4C30144C406AC18BBE82565740ACE5CE4C30144C40
72649	14037	93.243267000000003	93.272120999999999	55.875577	55.854522000000003	Новая	0103000020E610000001000000050000008C4CC0AF914F574034DB15FA60ED4B408C4CC0AF914F57409D103AE812F04B4082E3326E6A5157409D103AE812F04B4082E3326E6A51574034DB15FA60ED4B408C4CC0AF914F574034DB15FA60ED4B40
72772	59703	92.230892999999995	94.071692999999996	56.374696	55.229897000000001	Мамина	0103000020E6100000010000000500000005F86EF3C60E57406939D0436D9D4B4005F86EF3C60E574094F8DC09F62F4C4089963C9E9684574094F8DC09F62F4C4089963C9E968457406939D0436D9D4B4005F86EF3C60E57406939D0436D9D4B40
72938	59735	93.396069999999995	93.443987000000007	56.200293000000002	56.170555999999998	Советская	0103000020E610000001000000050000004F3BFC35595957407B116DC7D4154C404F3BFC3559595740124F7633A3194C40593673486A5C5740124F7633A3194C40593673486A5C57407B116DC7D4154C404F3BFC35595957407B116DC7D4154C40
28120	51809	93.290626000000003	93.300319000000002	55.405802000000001	55.394351	Нагорная	0103000020E610000001000000050000008257CB9D995257408C12F4177AB24B408257CB9D995257406153E751F1B34B4084D72E6D385357406153E751F1B34B4084D72E6D385357408C12F4177AB24B408257CB9D995257408C12F4177AB24B40
28082	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Школьная	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
27744	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Толстого	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28438	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Сибирская	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28464	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Свердлова	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
27879	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Парковая	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
71541	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Молодежная	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28248	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Ленинградский проспект	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
71546	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Ленина	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28087	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Крупской	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28246	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Королева	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
71604	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Комсомольская	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28602	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Восточная	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
71550	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Белорусская	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28612	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	Андреева	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
28603	2945	93.407937000000004	93.574054000000004	56.292498000000002	56.188864000000002	60 лет ВЛКСМ	0103000020E610000001000000050000000475CAA31B5A574025B20FB22C184C400475CAA31B5A57409D12109370254C40D508FD4CBD6457409D12109370254C40D508FD4CBD64574025B20FB22C184C400475CAA31B5A574025B20FB22C184C40
27907	14174	93.369202000000001	93.397328000000002	55.697721000000001	55.683670999999997	Школьная	0103000020E610000001000000050000008AE76C01A15757409F1C058882D74B408AE76C01A1575740C05DF6EB4ED94B403F726BD26D595740C05DF6EB4ED94B403F726BD26D5957409F1C058882D74B408AE76C01A15757409F1C058882D74B40
72861	14267	92.991505000000004	93.012589000000006	55.693916000000002	55.686025999999998	Центральная	0103000020E61000000100000005000000833463D1743F5740541A31B3CFD74B40833463D1743F5740E8154F3DD2D84B4085D21742CE405740E8154F3DD2D84B4085D21742CE405740541A31B3CFD74B40833463D1743F5740541A31B3CFD74B40
72933	14130	93.270109000000005	93.298522000000006	55.816465000000001	55.796542000000002	Победы	0103000020E61000000100000005000000BD56427749515740FAF19716F5E54B40BD5642774951574011AAD4EC81E84B40BDC804FC1A53574011AAD4EC81E84B40BDC804FC1A535740FAF19716F5E54B40BD56427749515740FAF19716F5E54B40
28611	14130	93.270109000000005	93.298522000000006	55.816465000000001	55.796542000000002	 Нагорная	0103000020E61000000100000005000000BD56427749515740FAF19716F5E54B40BD5642774951574011AAD4EC81E84B40BDC804FC1A53574011AAD4EC81E84B40BDC804FC1A535740FAF19716F5E54B40BD56427749515740FAF19716F5E54B40
71572	59481	92.230892999999995	94.071692999999996	56.374696	55.229897000000001	Юбилейная	0103000020E6100000010000000500000005F86EF3C60E57406939D0436D9D4B4005F86EF3C60E574094F8DC09F62F4C4089963C9E9684574094F8DC09F62F4C4089963C9E968457406939D0436D9D4B4005F86EF3C60E57406939D0436D9D4B40
73087	59481	93.102878000000004	93.10454	56.008893	56.006833999999998	Молодежная	0103000020E61000000100000005000000965E9B8D954657401C40BFEFDF004C40965E9B8D95465740E814E46723014C40ED478AC8B0465740E814E46723014C40ED478AC8B04657401C40BFEFDF004C40965E9B8D954657401C40BFEFDF004C40
72041	59481	93.117754000000005	93.11797	56.021332000000001	56.018383	Матросова	0103000020E6100000010000000500000049BE124889475740B4E6C75F5A024C4049BE124889475740DC2DC901BB024C402FFA0AD28C475740DC2DC901BB024C402FFA0AD28C475740B4E6C75F5A024C4049BE124889475740B4E6C75F5A024C40
73042	59785	91.728384000000005	91.741230000000002	55.329692000000001	55.318885000000002	Клубная	0103000020E6100000010000000500000080BBECD79DEE5640AD174339D1A84B4080BBECD79DEE56405DE0F25833AA4B401A34F44F70EF56405DE0F25833AA4B401A34F44F70EF5640AD174339D1A84B4080BBECD79DEE5640AD174339D1A84B40
73027	59773	91.620469	91.635220000000004	55.236077999999999	55.230528	Мира	0103000020E61000000100000005000000A3CB9BC3B5E75640F96706F1819D4B40A3CB9BC3B5E756400DA7CCCD379E4B40F870C971A7E856400DA7CCCD379E4B40F870C971A7E85640F96706F1819D4B40A3CB9BC3B5E75640F96706F1819D4B40
72805	59713	91.048817	91.066595000000007	55.195385000000002	55.187676000000003	Новая	0103000020E61000000100000005000000499F56D11FC356403F1F65C405984B40499F56D11FC3564082902C6002994B40F0C4AC1743C4564082902C6002994B40F0C4AC1743C456403F1F65C405984B40499F56D11FC356403F1F65C405984B40
72752	47249	92.162808999999996	92.199325999999999	55.187260000000002	55.167713999999997	Мира	0103000020E61000000100000005000000A59F70766B0A5740698A00A777954B40A59F70766B0A5740ABECBB22F8974B4085CFD6C1C10C5740ABECBB22F8974B4085CFD6C1C10C5740698A00A777954B40A59F70766B0A5740698A00A777954B40
72812	46821	91.031201999999993	91.041020000000003	55.504894	55.497622999999997	Школьная	0103000020E610000001000000050000007764AC36FFC15640635E471CB2BF4B407764AC36FFC156402BF9D85DA0C04B40D89E5912A0C256402BF9D85DA0C04B40D89E5912A0C25640635E471CB2BF4B407764AC36FFC15640635E471CB2BF4B40
72937	12152	91.329702999999995	91.353426999999996	55.380916999999997	55.369382000000002	Мира	0103000020E6100000010000000500000028999CDA19D5564094DDCCE847AF4B4028999CDA19D55640C6BE64E3C1B04B407FA1478C9ED65640C6BE64E3C1B04B407FA1478C9ED6564094DDCCE847AF4B4028999CDA19D5564094DDCCE847AF4B40
72635	11794	91.217484999999996	91.281741999999994	55.362608000000002	55.352552000000003	Ленина	0103000020E61000000100000005000000B7973446EBCD5640D811876C20AD4B40B7973446EBCD56404DA25EF069AE4B4037FA980F08D256404DA25EF069AE4B4037FA980F08D25640D811876C20AD4B40B7973446EBCD5640D811876C20AD4B40
72833	12301	91.145296999999999	91.155196000000004	55.475285999999997	55.468009000000002	Заречная	0103000020E610000001000000050000003ECDC98B4CC95640E99D0AB8E7BB4B403ECDC98B4CC95640921FF12BD6BC4B40151E34BBEEC95640921FF12BD6BC4B40151E34BBEEC95640E99D0AB8E7BB4B403ECDC98B4CC95640E99D0AB8E7BB4B40
27954	33118	91.112561999999997	91.128776999999999	55.517581999999997	55.502865	Школьная	0103000020E610000001000000050000006E313F3734C75640CAA65CE15DC04B406E313F3734C75640C77F812040C24B4087DEE2E13DC85640C77F812040C24B4087DEE2E13DC85640CAA65CE15DC04B406E313F3734C75640CAA65CE15DC04B40
71614	47093	91.878788999999998	91.909610000000001	55.209935000000002	55.197518000000002	Карла Маркса	0103000020E6100000010000000500000069C537143EF85640882F134548994B4069C537143EF8564094A46B26DF9A4B405587DC0C37FA564094A46B26DF9A4B405587DC0C37FA5640882F134548994B4069C537143EF85640882F134548994B40
28556	23471	91.849170999999998	91.887906999999998	55.362188000000003	55.349798	Тольятти	0103000020E610000001000000050000008B6D52D158F65640651A4D2EC6AC4B408B6D52D158F656407880272D5CAE4B40EDB8E177D3F856407880272D5CAE4B40EDB8E177D3F85640651A4D2EC6AC4B408B6D52D158F65640651A4D2EC6AC4B40
27860	12717	90.828064999999995	90.853720999999993	55.267907000000001	55.255015	Новая	0103000020E61000000100000005000000957D5704FFB45640A67EDE54A4A04B40957D5704FFB456404BAFCDC64AA24B4023BA675DA3B656404BAFCDC64AA24B4023BA675DA3B65640A67EDE54A4A04B40957D5704FFB45640A67EDE54A4A04B40
72583	26797	90.607896999999994	93.288595999999998	55.771296999999997	54.763399	Лесная	0103000020E610000001000000050000008995D1C8E7A656404966F50EB7614B408995D1C8E7A656405F402FDCB9E24B4069705B5B785257405F402FDCB9E24B4069705B5B785257404966F50EB7614B408995D1C8E7A656404966F50EB7614B40
27994	51787	91.146778999999995	91.176809000000006	55.581698000000003	55.576177000000001	Береговая	0103000020E61000000100000005000000552FBFD364C956408CDAFD2AC0C94B40552FBFD364C9564006137F1475CA4B40DD28B2D650CB564006137F1475CA4B40DD28B2D650CB56408CDAFD2AC0C94B40552FBFD364C956408CDAFD2AC0C94B40
72824	46691	91.030006999999998	91.047201000000001	55.360791999999996	55.357275999999999	Центральная	0103000020E61000000100000005000000ABE97AA2EBC15640A6D24F38BBAD4B40ABE97AA2EBC156404754A86E2EAE4B40AAD5575705C356404754A86E2EAE4B40AAD5575705C35640A6D24F38BBAD4B40ABE97AA2EBC15640A6D24F38BBAD4B40
73050	59793	91.952038000000002	91.976382000000001	55.452921000000003	55.440345000000001	Центральная	0103000020E6100000010000000500000027A3CA30EEFC564083FA96395DB84B4027A3CA30EEFC5640F855B950F9B94B40CC99ED0A7DFE5640F855B950F9B94B40CC99ED0A7DFE564083FA96395DB84B4027A3CA30EEFC564083FA96395DB84B40
73052	59794	91.670361999999997	91.702332999999996	55.314602000000001	55.300721000000003	Центральная	0103000020E61000000100000005000000CB9E0436E7EA5640371C96067EA64B40CB9E0436E7EA5640CBA0DAE044A84B40B3791C06F3EC5640CBA0DAE044A84B40B3791C06F3EC5640371C96067EA64B40CB9E0436E7EA5640371C96067EA64B40
28372	46690	91.140022999999999	91.157621000000006	55.358786000000002	55.347607000000004	Центральная	0103000020E61000000100000005000000056C0723F6C856402B6EDC627EAC4B40056C0723F6C856409F211CB3ECAD4B406C0A647616CA56409F211CB3ECAD4B406C0A647616CA56402B6EDC627EAC4B40056C0723F6C856402B6EDC627EAC4B40
72823	12491	91.094048000000001	91.104135999999997	55.21651	55.209128999999997	Космонавтов	0103000020E610000001000000050000004510E7E104C6564095D233BDC49A4B404510E7E104C65640E4A08499B69B4B4085950A2AAAC65640E4A08499B69B4B4085950A2AAAC6564095D233BDC49A4B404510E7E104C6564095D233BDC49A4B40
73096	59830	91.677018000000004	91.689010999999994	55.196731	55.189573000000003	Ижульская	0103000020E610000001000000050000006A334E4354EB5640319A95ED43984B406A334E4354EB5640008E3D7B2E994B4064E597C118EC5640008E3D7B2E994B4064E597C118EC5640319A95ED43984B406A334E4354EB5640319A95ED43984B40
28227	51826	90.607896999999994	93.288595999999998	55.771296999999997	54.763399	Ойская	0103000020E610000001000000050000008995D1C8E7A656404966F50EB7614B408995D1C8E7A656405F402FDCB9E24B4069705B5B785257405F402FDCB9E24B4069705B5B785257404966F50EB7614B408995D1C8E7A656404966F50EB7614B40
28472	12816	91.960221000000004	91.978887999999998	55.228408000000002	55.220258999999999	Юности	0103000020E61000000100000005000000ADFBC74274FD564028D36872319C4B40ADFBC74274FD564088122D793C9D4B40999CDA19A6FE564088122D793C9D4B40999CDA19A6FE564028D36872319C4B40ADFBC74274FD564028D36872319C4B40
72749	12386	90.951340999999999	90.969451000000007	55.486345999999998	55.472555999999997	Московская	0103000020E6100000010000000500000003965CC5E2BC5640A8C30AB77CBC4B4003965CC5E2BC56402C45F29540BE4B40C504357C0BBE56402C45F29540BE4B40C504357C0BBE5640A8C30AB77CBC4B4003965CC5E2BC5640A8C30AB77CBC4B40
28389	46792	91.255026000000001	91.2761	55.490253000000003	55.482194	Мира	0103000020E610000001000000050000004D68925852D05640E9297288B8BD4B404D68925852D0564009E23C9CC0BE4B403D9B559FABD1564009E23C9CC0BE4B403D9B559FABD15640E9297288B8BD4B404D68925852D05640E9297288B8BD4B40
28406	46992	91.036276999999998	91.044353000000001	55.271734000000002	55.267333000000001	Старая	0103000020E610000001000000050000003526C45C52C256401F12BEF737A24B403526C45C52C256400B9B012EC8A24B40B01EF7ADD6C256400B9B012EC8A24B40B01EF7ADD6C256401F12BEF737A24B403526C45C52C256401F12BEF737A24B40
72860	13101	91.559734000000006	91.578770000000006	55.605311999999998	55.594915999999998	Ленина	0103000020E61000000100000005000000651D8EAED2E35640FEEE1D3526CC4B40651D8EAED2E356402CF015DD7ACD4B40FB7953910AE556402CF015DD7ACD4B40FB7953910AE55640FEEE1D3526CC4B40651D8EAED2E35640FEEE1D3526CC4B40
28215	13059	91.539000999999999	91.560784999999996	55.521566999999997	55.510843000000001	Космонавтов	0103000020E61000000100000005000000B9E00CFE7EE25640FD31AD4D63C14B40B9E00CFE7EE256401FD61BB5C2C24B4097C5C4E6E3E356401FD61BB5C2C24B4097C5C4E6E3E35640FD31AD4D63C14B40B9E00CFE7EE25640FD31AD4D63C14B40
72832	11743	91.492054999999993	91.512618000000003	55.291131	55.284030000000001	переулок Центральный	0103000020E61000000100000005000000543541D47DDF56409C8A54185BA44B40543541D47DDF564007EDD5C743A54B40D255BABBCEE0564007EDD5C743A54B40D255BABBCEE056409C8A54185BA44B40543541D47DDF56409C8A54185BA44B40
28403	12429	90.989106000000007	90.996554000000003	55.409078999999998	55.401814999999999	Центральная	0103000020E61000000100000005000000C19140834DBF5640680586AC6EB34B40C19140834DBF56407D3D5FB35CB44B40ACAC6D8AC7BF56407D3D5FB35CB44B40ACAC6D8AC7BF5640680586AC6EB34B40C19140834DBF5640680586AC6EB34B40
71597	59477	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	Ленина	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
71528	59477	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	60 лет Октября	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
28563	11245	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	Чайковского	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
28387	11245	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	Переулок Школьный	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
27770	11245	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	Космонавтов	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
27839	11245	91.574529999999996	91.660533999999998	55.408118000000002	55.370431000000004	Каткова	0103000020E6100000010000000500000089247A19C5E45640593673486AAF4B4089247A19C5E456405874EB353DB44B4059F9653046EA56405874EB353DB44B4059F9653046EA5640593673486AAF4B4089247A19C5E45640593673486AAF4B40
28117	10996	90.660673000000003	90.683886000000001	56.143453999999998	56.131189999999997	Новая	0103000020E610000001000000050000006A16687748AA5640F7C77BD5CA104C406A16687748AA56407D3D5FB35C124C404E0CC9C9C4AB56407D3D5FB35C124C404E0CC9C9C4AB5640F7C77BD5CA104C406A16687748AA5640F7C77BD5CA104C40
28118	10673	90.723833999999997	90.769638999999998	56.403945	56.395561999999998	им.Ивченко М.Л	0103000020E61000000100000005000000E76ED74B53AE56402AC58EC6A1324C40E76ED74B53AE5640FD304278B4334C4079AEEFC341B15640FD304278B4334C4079AEEFC341B156402AC58EC6A1324C40E76ED74B53AE56402AC58EC6A1324C40
28541	10852	90.812965000000005	90.859380999999999	56.309812999999998	56.288955999999999	Переулок Клубный	0103000020E61000000100000005000000BBF2599E07B45640D2FD9C82FC244C40BBF2599E07B456401570CFF3A7274C4071732A1900B756401570CFF3A7274C4071732A1900B75640D2FD9C82FC244C40BBF2599E07B45640D2FD9C82FC244C40
72919	10786	90.748771000000005	90.788486000000006	56.295439999999999	56.289161	Центральная	0103000020E610000001000000050000005E4C33DDEBAF5640AB23473A03254C405E4C33DDEBAF564012F758FAD0254C40A6D6FB8D76B2564012F758FAD0254C40A6D6FB8D76B25640AB23473A03254C405E4C33DDEBAF5640AB23473A03254C40
72786	27626	90.832673999999997	90.858671000000001	56.046689999999998	56.040455000000001	Советская	0103000020E61000000100000005000000B08EE3874AB55640D7FA22A12D054C40B08EE3874AB556406E861BF0F9054C4083C13577F4B656406E861BF0F9054C4083C13577F4B65640D7FA22A12D054C40B08EE3874AB55640D7FA22A12D054C40
28377	11212	90.948260000000005	90.983258000000006	56.409424000000001	56.401305000000001	Партизанская	0103000020E61000000100000005000000B806B64AB0BC5640535C55F65D334C40B806B64AB0BC56404819710168344C40F261F6B2EDBE56404819710168344C40F261F6B2EDBE5640535C55F65D334C40B806B64AB0BC5640535C55F65D334C40
73021	59768	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	Уланова	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
72892	11062	90.420957999999999	90.440190999999999	56.128962000000001	56.110062999999997	Центральная	0103000020E6100000010000000500000055BFD2F9F09A5640F4BF5C8B160E4C4055BFD2F9F09A5640A036AAD381104C40963FDF162C9C5640A036AAD381104C40963FDF162C9C5640F4BF5C8B160E4C4055BFD2F9F09A5640F4BF5C8B160E4C40
28124	10601	90.730877000000007	90.775855000000007	56.460267999999999	56.446444	Советская	0103000020E61000000100000005000000831953B0C6AE56406ABFB51325394C40831953B0C6AE56409AB2D30FEA3A4C400ADCBA9BA7B156409AB2D30FEA3A4C400ADCBA9BA7B156406ABFB51325394C40831953B0C6AE56406ABFB51325394C40
72773	46199	90.286067000000003	90.297034999999994	56.488422999999997	56.478670000000001	Зеленая	0103000020E61000000100000005000000C05DF6EB4E925640C5C9FD0E453D4C40C05DF6EB4E9256409ECE15A5843E4C401CB1169F029356409ECE15A5843E4C401CB1169F02935640C5C9FD0E453D4C40C05DF6EB4E925640C5C9FD0E453D4C40
73029	59776	90.465128000000007	90.477705	56.080531999999998	56.069167999999998	Зеленая	0103000020E610000001000000050000000D1D3BA8C49D564001F73C7FDA084C400D1D3BA8C49D5640072461DF4E0A4C40AF08FEB7929E5640072461DF4E0A4C40AF08FEB7929E564001F73C7FDA084C400D1D3BA8C49D564001F73C7FDA084C40
28397	51859	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	Центральная	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
72990	59747	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	Армейская	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
28161	10465	90.232195000000004	90.251283999999998	56.393728000000003	56.387056000000001	Центральная	0103000020E61000000100000005000000DDD26A48DC8E56403CDC0E0D8B314C40DDD26A48DC8E56407FC2D9AD65324C4084807C09159056407FC2D9AD65324C4084807C09159056403CDC0E0D8B314C40DDD26A48DC8E56403CDC0E0D8B314C40
71695	59497	90.516081	90.518156000000005	56.310966999999998	56.307077	Школьная	0103000020E6100000010000000500000091459A7807A15640492D944C4E274C4091459A7807A156404F9143C4CD274C407A8EC87729A156404F9143C4CD274C407A8EC87729A15640492D944C4E274C4091459A7807A15640492D944C4E274C40
28241	51832	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	Трактовая	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
28006	51792	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	Квартал 1	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
28171	51820	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	Клубная	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
73128	59859	95.537492	97.672797000000003	57.578499000000001	56.424695	Заречная	0103000020E610000001000000050000002577D84466E257402AE3DF675C364C402577D84466E2574065E256410CCA4C4034F6251B0F6B584065E256410CCA4C4034F6251B0F6B58402AE3DF675C364C402577D84466E257402AE3DF675C364C40
72844	9995	97.111547000000002	97.132936000000001	57.099223000000002	57.086874999999999	Школьная	0103000020E61000000100000005000000E23D07962347584085EB51B81E8B4C40E23D0796234758406901DA56B38C4C40821DFF05824858406901DA56B38C4C40821DFF058248584085EB51B81E8B4C40E23D07962347584085EB51B81E8B4C40
28516	9682	95.980469999999997	96.036021000000005	56.530245000000001	56.513863999999998	Мира	0103000020E61000000100000005000000622D3E05C0FE5740BE4BA94BC6414C40622D3E05C0FE57400BEF7211DF434C40083E062B4E0258400BEF7211DF434C40083E062B4E025840BE4BA94BC6414C40622D3E05C0FE5740BE4BA94BC6414C40
28065	45667	96.394620000000003	96.434137000000007	56.657508999999997	56.64931	Советская	0103000020E610000001000000050000003E963E74411958409E7B0F971C534C403E963E7441195840AFE9414129544C40F33E8EE6C81B5840AFE9414129544C40F33E8EE6C81B58409E7B0F971C534C403E963E74411958409E7B0F971C534C40
28442	49522	95.872833	95.892650000000003	56.670642999999998	56.664470000000001	Центральная	0103000020E61000000100000005000000A777F17EDCF7574029965B5A0D554C40A777F17EDCF757404A253CA1D7554C409031772D21F957404A253CA1D7554C409031772D21F9574029965B5A0D554C40A777F17EDCF7574029965B5A0D554C40
27798	8677	95.854759000000001	95.874602999999993	56.739761999999999	56.723565999999998	Набережная	0103000020E610000001000000050000008CBD175FB4F65740AF3F89CF9D5C4C408CBD175FB4F657406A696E85B05E4C40F17EDC7EF9F757406A696E85B05E4C40F17EDC7EF9F75740AF3F89CF9D5C4C408CBD175FB4F65740AF3F89CF9D5C4C40
28630	15540	96.317966999999996	96.346846999999997	56.616298	56.611047999999997	Советская	0103000020E61000000100000005000000438D429259145840A22424D2364E4C40438D4292591458408C4B55DAE24E4C40CE6DC2BD321658408C4B55DAE24E4C40CE6DC2BD32165840A22424D2364E4C40438D429259145840A22424D2364E4C40
72618	32806	95.882805000000005	95.915045000000006	56.842689	56.828831999999998	Советская	0103000020E61000000100000005000000B3EF8AE07FF857406BF0BE2A176A4C40B3EF8AE07FF8574077D9AF3BDD6B4C409357E71890FA574077D9AF3BDD6B4C409357E71890FA57406BF0BE2A176A4C40B3EF8AE07FF857406BF0BE2A176A4C40
27951	45708	96.503647999999998	96.528818999999999	56.709868	56.706378999999998	А.С. Пушкина	0103000020E61000000100000005000000882CD2C43B20584064CA87A06A5A4C40882CD2C43B2058400C3D62F4DC5A4C4038A0A52BD82158400C3D62F4DC5A4C4038A0A52BD821584064CA87A06A5A4C40882CD2C43B20584064CA87A06A5A4C40
72891	9074	96.410385000000005	96.444737000000003	57.204031000000001	57.176313999999998	Юбилейная	0103000020E61000000100000005000000377172BF431A5840D9E9077591964C40377172BF431A5840622F14B01D9A4C408E942D92761C5840622F14B01D9A4C408E942D92761C5840D9E9077591964C40377172BF431A5840D9E9077591964C40
28613	9074	96.410385000000005	96.444737000000003	57.204031000000001	57.176313999999998	Победы	0103000020E61000000100000005000000377172BF431A5840D9E9077591964C40377172BF431A5840622F14B01D9A4C408E942D92761C5840622F14B01D9A4C408E942D92761C5840D9E9077591964C40377172BF431A5840D9E9077591964C40
72991	59748	97.401675999999995	97.418744000000004	57.002647000000003	56.982199999999999	Советская	0103000020E61000000100000005000000A3E5400FB5595840CB10C7BAB87D4C40A3E5400FB55958405D37A5BC56804C405C59A2B3CC5A58405D37A5BC56804C405C59A2B3CC5A5840CB10C7BAB87D4C40A3E5400FB5595840CB10C7BAB87D4C40
28075	45535	96.584110999999993	96.595753000000002	57.298257	57.282595999999998	 Школьная	0103000020E61000000100000005000000F78E1A13622558407EFD101B2CA44C40F78E1A1362255840CB660E492DA64C409CDF30D120265840CB660E492DA64C409CDF30D1202658407EFD101B2CA44C40F78E1A13622558407EFD101B2CA44C40
28357	45903	96.862615000000005	96.893347000000006	57.179529000000002	57.172536999999998	Больничная	0103000020E6100000010000000500000080828B1535375840CB2C42B115964C4080828B153537584080D767CEFA964C40B43EE5982C39584080D767CEFA964C40B43EE5982C395840CB2C42B115964C4080828B1535375840CB2C42B115964C40
27809	9921	95.884152	95.921181000000004	56.536603999999997	56.530315000000002	Береговая	0103000020E610000001000000050000005A2C45F295F8574004CAA65CE1434C405A2C45F295F857408E739B70AF444C40952C27A1F4FA57408E739B70AF444C40952C27A1F4FA574004CAA65CE1434C405A2C45F295F8574004CAA65CE1434C40
28144	8109	95.705467999999996	95.736119000000002	56.611013	56.602525999999997	Советская	0103000020E61000000100000005000000F817416326ED5740AE7E6C921F4D4C40F817416326ED574026378AAC354E4C40B6BDDD921CEF574026378AAC354E4C40B6BDDD921CEF5740AE7E6C921F4D4C40F817416326ED5740AE7E6C921F4D4C40
73060	45342	96.311875999999998	96.338125000000005	56.777523000000002	56.761353	Советская	0103000020E61000000100000005000000111AC1C6F513584012DBDD0374614C40111AC1C6F5135840A471A8DF85634C40713D0AD7A3155840A471A8DF85634C40713D0AD7A315584012DBDD0374614C40111AC1C6F513584012DBDD0374614C40
28512	45342	96.311875999999998	96.338125000000005	56.777523000000002	56.761353	А.Лебедя	0103000020E61000000100000005000000111AC1C6F513584012DBDD0374614C40111AC1C6F5135840A471A8DF85634C40713D0AD7A3155840A471A8DF85634C40713D0AD7A315584012DBDD0374614C40111AC1C6F513584012DBDD0374614C40
27806	9858	96.196865000000003	96.217544000000004	56.567053000000001	56.558636	Покровская	0103000020E61000000100000005000000882EA86F990C5840232F6B6281474C40882EA86F990C5840A20C553195484C403A5CAB3DEC0D5840A20C553195484C403A5CAB3DEC0D5840232F6B6281474C40882EA86F990C5840232F6B6281474C40
73013	59763	96.153305000000003	96.173840999999996	56.468373999999997	56.457895000000001	Центральная	0103000020E610000001000000050000000D54C6BFCF0958403F00A94D9C3A4C400D54C6BFCF095840FA25E2ADF33B4C400D6D0036200B5840FA25E2ADF33B4C400D6D0036200B58403F00A94D9C3A4C400D54C6BFCF0958403F00A94D9C3A4C40
72807	49439	95.768189000000007	95.782705000000007	56.564692000000001	56.557594000000002	Школьная	0103000020E61000000100000005000000680932022AF1574011397D3D5F474C40680932022AF157400B28D4D347484C409B5AB6D617F257400B28D4D347484C409B5AB6D617F2574011397D3D5F474C40680932022AF1574011397D3D5F474C40
28462	15546	95.805926999999997	95.820507000000006	56.925665000000002	56.918477000000003	Школьная	0103000020E61000000100000005000000A8FDD64E94F35740699082A790754C40A8FDD64E94F35740A306D3307C764C40E7C8CA2F83F45740A306D3307C764C40E7C8CA2F83F45740699082A790754C40A8FDD64E94F35740699082A790754C40
27797	49488	96.786159999999995	96.812416999999996	56.829388999999999	56.817867999999997	Центральная	0103000020E61000000100000005000000185B087250325840F3380CE6AF684C40185B087250325840C154336B296A4C40B96DDFA3FE335840C154336B296A4C40B96DDFA3FE335840F3380CE6AF684C40185B087250325840F3380CE6AF684C40
72831	9675	95.864137999999997	95.879803999999993	56.820937000000001	56.816581999999997	Советская	0103000020E61000000100000005000000C64E78094EF757404A404CC285684C40C64E78094EF75740C689AF7614694C40F5B86FB54EF85740C689AF7614694C40F5B86FB54EF857404A404CC285684C40C64E78094EF757404A404CC285684C40
27999	45794	96.098499000000004	96.110303000000002	56.544525	56.538654000000001	Школьная	0103000020E6100000010000000500000014ECBFCE4D06584007EE409DF2444C4014ECBFCE4D0658405D6DC5FEB2454C40A56950340F0758405D6DC5FEB2454C40A56950340F07584007EE409DF2444C4014ECBFCE4D06584007EE409DF2444C40
28163	45439	96.196693999999994	96.225628999999998	56.719585000000002	56.715153999999998	Подгорная	0103000020E6100000010000000500000071546EA2960C584042CD902A8A5B4C4071546EA2960C584099D87C5C1B5C4C40DE019EB4700E584099D87C5C1B5C4C40DE019EB4700E584042CD902A8A5B4C4071546EA2960C584042CD902A8A5B4C40
28317	8418	95.806448000000003	95.827082000000004	56.716033000000003	56.708474000000002	Сибирская	0103000020E610000001000000050000002D7B12D89CF357407D08AA46AF5A4C402D7B12D89CF35740ABED26F8A65B4C400F4757E9EEF45740ABED26F8A65B4C400F4757E9EEF457407D08AA46AF5A4C402D7B12D89CF357407D08AA46AF5A4C40
28282	9545	96.351140999999998	96.383571000000003	56.679974000000001	56.663742999999997	Молодежная	0103000020E6100000010000000500000039D219187916584076F9D687F5544C4039D2191879165840AE10566309574C406B2C616D8C185840AE10566309574C406B2C616D8C18584076F9D687F5544C4039D219187916584076F9D687F5544C40
27772	8506	95.893997999999996	95.903510999999995	56.691983	56.681477999999998	Буденного	0103000020E610000001000000050000001F2C634337F95740C478CDAB3A574C401F2C634337F95740A93121E692584C40E124CD1FD3F95740A93121E692584C40E124CD1FD3F95740C478CDAB3A574C401F2C634337F95740C478CDAB3A574C40
27948	49473	96.774437000000006	96.825443000000007	56.761175999999999	56.738413999999999	Советская 	0103000020E61000000100000005000000FEF33460903158404B749659845E4C40FEF3346090315840034015376E614C40946DE00ED4345840034015376E614C40946DE00ED43458404B749659845E4C40FEF33460903158404B749659845E4C40
72680	49473	96.774437000000006	96.825443000000007	56.761175999999999	56.738413999999999	Дзержинского	0103000020E61000000100000005000000FEF33460903158404B749659845E4C40FEF3346090315840034015376E614C40946DE00ED4345840034015376E614C40946DE00ED43458404B749659845E4C40FEF33460903158404B749659845E4C40
72920	45765	96.049531999999999	96.102631000000002	56.583548999999998	56.561298999999998	Почтовая	0103000020E61000000100000005000000C00644882B035840852348A5D8474C40C00644882B035840874ECFBBB14A4C4092239D8191065840874ECFBBB14A4C4092239D8191065840852348A5D8474C40C00644882B035840852348A5D8474C40
28166	8868	96.098140000000001	96.116671999999994	56.730687000000003	56.725352999999998	Молодежная	0103000020E610000001000000050000007C9BFEEC470658401A87FA5DD85C4C407C9BFEEC47065840624ED026875D4C40F816D68D77075840624ED026875D4C40F816D68D770758401A87FA5DD85C4C407C9BFEEC470658401A87FA5DD85C4C40
72815	9010	96.275225000000006	96.306190000000001	56.715964	56.707026999999997	Советская	0103000020E61000000100000005000000AA8251499D115840CA3159DC7F5A4C40AA8251499D115840828E56B5A45B4C402F17F19D98135840828E56B5A45B4C402F17F19D98135840CA3159DC7F5A4C40AA8251499D115840CA3159DC7F5A4C40
28216	45590	95.808963000000006	95.830972000000003	56.955725000000001	56.945611999999997	 Первомайская	0103000020E61000000100000005000000242BBF0CC6F35740425A63D009794C40242BBF0CC6F357401C7C6132557A4C4012F92EA52EF557401C7C6132557A4C4012F92EA52EF55740425A63D009794C40242BBF0CC6F35740425A63D009794C40
28146	9367	95.692047000000002	95.702639000000005	56.981082000000001	56.972507	Школьная	0103000020E61000000100000005000000E012807F4AEC5740C710001C7B7C4C40E012807F4AEC5740DE585018947D4C403A799109F8EC5740DE585018947D4C403A799109F8EC5740C710001C7B7C4C40E012807F4AEC5740C710001C7B7C4C40
28001	45870	97.126324999999994	97.148396000000005	57.124271999999998	57.107568000000001	 Железнодорожная	0103000020E61000000100000005000000B3EA73B5154858404E0CC9C9C48D4C40B3EA73B5154858407DE71725E88F4C40DDB6EF517F4958407DE71725E88F4C40DDB6EF517F4958404E0CC9C9C48D4C40B3EA73B5154858404E0CC9C9C48D4C40
28364	9118	96.490083999999996	96.501322000000002	57.166603000000002	57.158861999999999	Новая	0103000020E61000000100000005000000BE1248895D1F5840E0490B9755944C40BE1248895D1F58402F35423F53954C40FBB0DEA8152058402F35423F53954C40FBB0DEA815205840E0490B9755944C40BE1248895D1F5840E0490B9755944C40
27920	7959	96.202146999999997	96.224389000000002	56.865594000000002	56.851210000000002	Советская	0103000020E61000000100000005000000027FF8F9EF0C58409B030473F46C4C40027FF8F9EF0C584092CEC0C8CB6E4C404225AE635C0E584092CEC0C8CB6E4C404225AE635C0E58409B030473F46C4C40027FF8F9EF0C58409B030473F46C4C40
72743	49574	96.008658999999994	96.029149000000004	56.738809000000003	56.731625000000001	Трактовая	0103000020E610000001000000050000003A747ADE8D005840CFF753E3A55D4C403A747ADE8D005840C87E164B915E4C40836DC493DD015840C87E164B915E4C40836DC493DD015840CFF753E3A55D4C403A747ADE8D005840CFF753E3A55D4C40
27790	7810	96.034008999999998	96.107617000000005	56.690123999999997	56.659112	Советская	0103000020E6100000010000000500000042B115342D025840593332C85D544C4042B115342D025840A417B5FB55584C4098DF6932E3065840A417B5FB55584C4098DF6932E3065840593332C85D544C4042B115342D025840593332C85D544C40
27788	7810	96.034008999999998	96.107617000000005	56.690123999999997	56.659112	Пионерская	0103000020E6100000010000000500000042B115342D025840593332C85D544C4042B115342D025840A417B5FB55584C4098DF6932E3065840A417B5FB55584C4098DF6932E3065840593332C85D544C4042B115342D025840593332C85D544C40
28617	7810	96.034008999999998	96.107617000000005	56.690123999999997	56.659112	Больничная	0103000020E6100000010000000500000042B115342D025840593332C85D544C4042B115342D025840A417B5FB55584C4098DF6932E3065840A417B5FB55584C4098DF6932E3065840593332C85D544C4042B115342D025840593332C85D544C40
27750	7810	96.034008999999998	96.107617000000005	56.690123999999997	56.659112	 Д.Бедного	0103000020E6100000010000000500000042B115342D025840593332C85D544C4042B115342D025840A417B5FB55584C4098DF6932E3065840A417B5FB55584C4098DF6932E3065840593332C85D544C4042B115342D025840593332C85D544C40
28008	51793	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Колесниченко	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
72819	59716	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	Октябрьская	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
50409	56070	87.404675999999995	87.413927999999999	53.760736000000001	53.760465000000003	Свердлова	0103000020E61000000100000005000000785E2A36E6D955405760C8EA56E14A40785E2A36E6D95540E77118CC5FE14A4084B9DDCB7DDA5540E77118CC5FE14A4084B9DDCB7DDA55405760C8EA56E14A40785E2A36E6D955405760C8EA56E14A40
75859	60737	87.105276000000003	87.122506000000001	53.717703999999998	53.709690000000002	Жуковского	0103000020E6100000010000000500000070438CD7BCC655402D26361FD7DA4A4070438CD7BCC65540AC1A84B9DDDB4A4015E46723D7C75540AC1A84B9DDDB4A4015E46723D7C755402D26361FD7DA4A4070438CD7BCC655402D26361FD7DA4A40
957	3682	85.887699999999995	85.897339000000002	55.351661	55.342314000000002	Центральная улица	0103000020E61000000100000005000000302AA913D0785540427BF5F1D0AB4B40302AA913D0785540AB23473A03AD4B40399B8E006E795540AB23473A03AD4B40399B8E006E795540427BF5F1D0AB4B40302AA913D0785540427BF5F1D0AB4B40
70330	3682	85.887699999999995	85.897339000000002	55.351661	55.342314000000002	Центральная	0103000020E61000000100000005000000302AA913D0785540427BF5F1D0AB4B40302AA913D0785540AB23473A03AD4B40399B8E006E795540AB23473A03AD4B40399B8E006E795540427BF5F1D0AB4B40302AA913D0785540427BF5F1D0AB4B40
76277	60794	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	К. Цеткин	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
76224	60794	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	Геологическая	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
76298	60794	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	20 партсъезда	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
49998	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Щетинкина	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
75763	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Трудовые резервы	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
50146	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Советская	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
75759	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Привокзальная	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
49994	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Почтовая	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
75953	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Народная	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
75775	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Молокова	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
12416	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Молодежная	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
50150	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Мира	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
49996	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Кирова	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
13668	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Калинина	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
50339	7244	85.584653000000003	85.666103000000007	56.082371000000002	56.044145999999998	Деповская	0103000020E6100000010000000500000088A06AF46A655540E61F7D93A6054C4088A06AF46A655540C59107228B0A4C401F317A6EA16A5540C59107228B0A4C401F317A6EA16A5540E61F7D93A6054C4088A06AF46A655540E61F7D93A6054C40
803	3096	86.203762999999995	86.212098999999995	55.370604999999998	55.359696	Заречная улица	0103000020E61000000100000005000000A148F7730A8D55404240BE840AAE4B40A148F7730A8D5540F65D11FC6FAF4B40EA20AF07938D5540F65D11FC6FAF4B40EA20AF07938D55404240BE840AAE4B40A148F7730A8D55404240BE840AAE4B40
76186	60781	87.464332999999996	87.495253000000005	53.826939000000003	53.815272	Линейная	0103000020E61000000100000005000000075DC2A1B7DD554019AC38D55AE84A40075DC2A1B7DD5540BB641C23D9E94A40BD8FA339B2DF5540BB641C23D9E94A40BD8FA339B2DF554019AC38D55AE84A40075DC2A1B7DD554019AC38D55AE84A40
75741	60720	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	Приисковая	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
76179	60720	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	Мира	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
76255	60798	86.223813000000007	86.281647000000007	56.102378000000002	56.064585000000001	Советская	0103000020E61000000100000005000000DCDAC2F3528E5540F5673F5244084C40DCDAC2F3528E55403AEAE8B81A0D4C400F812381069255403AEAE8B81A0D4C400F81238106925540F5673F5244084C40DCDAC2F3528E5540F5673F5244084C40
75693	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	проспект Строителей	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75910	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	переулок Городской	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75612	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Революции	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75732	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Калинина	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75614	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Институтская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75739	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Захаренко	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75604	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Есенина	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75696	60705	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Вокзальная	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
50153	3800	85.923713000000006	85.965512000000004	55.372401000000004	55.337491	Центральная	0103000020E61000000100000005000000F778211D1E7B5540E0D8B3E732AB4B40F778211D1E7B5540B5FF01D6AAAF4B4051F9D7F2CA7D5540B5FF01D6AAAF4B4051F9D7F2CA7D5540E0D8B3E732AB4B40F778211D1E7B5540E0D8B3E732AB4B40
70069	59364	84.452399	89.402564999999996	56.832393000000003	52.162630999999998	Ефимова	0103000020E610000001000000050000008F6FEF1AF41C55406B28B517D1144A408F6FEF1AF41C5540AD3594DA8B6A4C40E960FD9FC3595640AD3594DA8B6A4C40E960FD9FC35956406B28B517D1144A408F6FEF1AF41C55406B28B517D1144A40
50571	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	улица 50 лет Октября	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
12789	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Шахтовая	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
75601	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Советская	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
75602	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Победы	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
69696	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Победы	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
13681	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Куйбышева	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
50037	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Кирова	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
75595	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Заречная	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
13419	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Ефимова	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
69697	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	Вокзальная	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
12299	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	9-я штольня	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
75900	16765	87.294093000000004	87.445774	53.652033000000003	53.584381999999998	50 лет Октября	0103000020E61000000100000005000000E23E726BD2D255407F2F8507CDCA4A40E23E726BD2D25540D6743DD175D34A400EDAAB8F87DC5540D6743DD175D34A400EDAAB8F87DC55407F2F8507CDCA4A40E23E726BD2D255407F2F8507CDCA4A40
81138	51916	87.103218999999996	87.126090000000005	53.759053999999999	53.758766000000001	улица Энтузиастов	0103000020E61000000100000005000000DA54DD239BC655408BA8893E1FE14A40DA54DD239BC65540F1F274AE28E14A409296CADB11C85540F1F274AE28E14A409296CADB11C855408BA8893E1FE14A40DA54DD239BC655408BA8893E1FE14A40
76216	51916	87.151584	87.157801000000006	53.763573000000001	53.758633000000003	улица Франкфурта	0103000020E6100000010000000500000033A6608DB3C955404C55DAE21AE14A4033A6608DB3C95540E78D93C2BCE14A40AC915D6919CA5540E78D93C2BCE14A40AC915D6919CA55404C55DAE21AE14A4033A6608DB3C955404C55DAE21AE14A40
28867	51916	87.108007000000001	87.108106000000006	53.754044999999998	53.750728000000002	улица Невского	0103000020E610000001000000050000004D2F3196E9C655408318E8DA17E04A404D2F3196E9C655402D5BEB8B84E04A4017A06D35EBC655402D5BEB8B84E04A4017A06D35EBC655408318E8DA17E04A404D2F3196E9C655408318E8DA17E04A40
28832	51916	87.101421999999999	87.143310999999997	53.894655	53.885824999999997	улица Косыгина	0103000020E610000001000000050000001346B3B27DC65540567DAEB662F14A401346B3B27DC65540F819170E84F24A400D8AE6012CC95540F819170E84F24A400D8AE6012CC95540567DAEB662F14A401346B3B27DC65540567DAEB662F14A40
28818	51916	87.096885999999998	87.133429000000007	53.781368000000001	53.766761000000002	проспект Строителей	0103000020E610000001000000050000002D5C566133C65540946C753925E24A402D5C566133C655400A12DBDD03E44A40A2D5C9198AC855400A12DBDD03E44A40A2D5C9198AC85540946C753925E24A402D5C566133C65540946C753925E24A40
28863	51916	87.162858	87.183860999999993	53.845078999999998	53.829037999999997	проспект Советской Армии	0103000020E6100000010000000500000016F9F5436CCA55401492CCEA1DEA4A4016F9F5436CCA5540A8C4758C2BEC4A40A180ED60C4CB5540A8C4758C2BEC4A40A180ED60C4CB55401492CCEA1DEA4A4016F9F5436CCA55401492CCEA1DEA4A40
28840	51916	87.136617999999999	87.143302000000006	53.908797999999997	53.894623000000003	проспект Мира	0103000020E61000000100000005000000E0826C59BEC85540ED9FA70183F24A40E0826C59BEC85540C9552C7E53F44A40E4DC26DC2BC95540C9552C7E53F44A40E4DC26DC2BC95540ED9FA70183F24A40E0826C59BEC85540ED9FA70183F24A40
28942	51916	87.093598	87.117107000000004	53.766441999999998	53.747911000000002	проспект Курако	0103000020E61000000100000005000000253E7782FDC55540CAA8328CBBDF4A40253E7782FDC55540F2237EC51AE24A407EC85BAE7EC75540F2237EC51AE24A407EC85BAE7EC75540CAA8328CBBDF4A40253E7782FDC55540CAA8328CBBDF4A40
76238	51916	87.118931000000003	87.135765000000006	53.757207000000001	53.747725000000003	проспект Бардина	0103000020E61000000100000005000000C2DEC4909CC7554068B3EA73B5DF4A40C2DEC4909CC75540B1A6B228ECE04A4041BCAE5FB0C85540B1A6B228ECE04A4041BCAE5FB0C8554068B3EA73B5DF4A40C2DEC4909CC7554068B3EA73B5DF4A40
28835	51916	87.097200000000001	87.139645999999999	53.901800999999999	53.89622	проспект Авиаторов	0103000020E61000000100000005000000F54A598638C65540B4024356B7F24A40F54A598638C65540034015376EF34A401AC1C6F5EFC85540034015376EF34A401AC1C6F5EFC85540B4024356B7F24A40F54A598638C65540B4024356B7F24A40
75840	51916	87.182638999999995	87.186969000000005	53.828043999999998	53.826459999999997	проезд Чекистов	0103000020E6100000010000000500000058FE7C5BB0CB5540E0B9F770C9E94A4058FE7C5BB0CB554013D38558FDE94A406A17D34CF7CB554013D38558FDE94A406A17D34CF7CB5540E0B9F770C9E94A4058FE7C5BB0CB5540E0B9F770C9E94A40
81139	51916	87.114420999999993	87.114484000000004	53.754725999999998	53.752026999999998	проезд Кулакова	0103000020E61000000100000005000000703E75AC52C75540C05AB56B42E04A40703E75AC52C755406FB88FDC9AE04A4094FAB2B453C755406FB88FDC9AE04A4094FAB2B453C75540C05AB56B42E04A40703E75AC52C75540C05AB56B42E04A40
76290	51916	87.114484000000004	87.115176000000005	53.757807999999997	53.754725999999998	проезд Коммунаров	0103000020E6100000010000000500000094FAB2B453C755406FB88FDC9AE04A4094FAB2B453C75540D65240DAFFE04A402F52280B5FC75540D65240DAFFE04A402F52280B5FC755406FB88FDC9AE04A4094FAB2B453C755406FB88FDC9AE04A40
50624	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	Яворского	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
71716	51916	87.122865000000004	87.129198000000002	53.710712999999998	53.704785999999999	Юдина	0103000020E61000000100000005000000AD342905DDC75540DE567A6D36DA4A40AD342905DDC75540C8EBC1A4F8DA4A405A2DB0C744C85540C8EBC1A4F8DA4A405A2DB0C744C85540DE567A6D36DA4A40AD342905DDC75540DE567A6D36DA4A40
70434	51916	87.180807000000001	87.195485000000005	53.776339999999998	53.771082999999997	Шункова	0103000020E61000000100000005000000D3F8855792CB554033C005D9B2E24A40D3F8855792CB5540CF49EF1B5FE34A40F37684D382CC5540CF49EF1B5FE34A40F37684D382CC554033C005D9B2E24A40D3F8855792CB554033C005D9B2E24A40
71067	51916	87.209992999999997	87.211933000000002	53.777175	53.775610999999998	Шестакова	0103000020E61000000100000005000000E4D87A8670CD55407CB5A33847E34A40E4D87A8670CD554068226C787AE34A405DFC6D4F90CD554068226C787AE34A405DFC6D4F90CD55407CB5A33847E34A40E4D87A8670CD55407CB5A33847E34A40
75762	51916	87.053793999999996	87.062444999999997	53.754778999999999	53.751722999999998	Шебелинская	0103000020E6100000010000000500000025AE635C71C355405453927538E04A4025AE635C71C35540925A28999CE04A401E335019FFC35540925A28999CE04A401E335019FFC355405453927538E04A4025AE635C71C355405453927538E04A40
28938	51916	87.063351999999995	87.070178999999996	53.742047999999997	53.741802999999997	Читинский проезд	0103000020E61000000100000005000000B7088CF50DC455408F899466F3DE4A40B7088CF50DC45540F607CA6DFBDE4A406C770FD07DC45540F607CA6DFBDE4A406C770FD07DC455408F899466F3DE4A40B7088CF50DC455408F899466F3DE4A40
71501	51916	87.104037000000005	87.108079000000004	53.751553000000001	53.751461999999997	Черноморская	0103000020E61000000100000005000000BC24CE8AA8C65540E71725E82FE04A40BC24CE8AA8C65540F81A82E332E04A409A982EC4EAC65540F81A82E332E04A409A982EC4EAC65540E71725E82FE04A40BC24CE8AA8C65540E71725E82FE04A40
71306	51916	87.046543999999997	87.077132000000006	53.747272000000002	53.744625999999997	Челюскина	0103000020E61000000100000005000000CD74AF93FAC255402AE09EE74FDF4A40CD74AF93FAC25540B79BE09BA6DF4A40685E0EBBEFC45540B79BE09BA6DF4A40685E0EBBEFC455402AE09EE74FDF4A40CD74AF93FAC255402AE09EE74FDF4A40
76215	51916	87.126602000000005	87.150390000000002	53.756402999999999	53.743496999999998	Циолковского	0103000020E61000000100000005000000ED66463F1AC8554049D6E1E82ADF4A40ED66463F1AC8554053CC41D0D1E04A404FE960FD9FC9554053CC41D0D1E04A404FE960FD9FC9554049D6E1E82ADF4A40ED66463F1AC8554049D6E1E82ADF4A40
76282	51916	87.151584	87.157801000000006	53.763573000000001	53.758633000000003	Франкфурта	0103000020E6100000010000000500000033A6608DB3C955404C55DAE21AE14A4033A6608DB3C95540E78D93C2BCE14A40AC915D6919CA5540E78D93C2BCE14A40AC915D6919CA55404C55DAE21AE14A4033A6608DB3C955404C55DAE21AE14A40
76250	51916	87.125101999999998	87.129827000000006	53.774047000000003	53.771465999999997	Филиппова	0103000020E6100000010000000500000082AAD1AB01C85540EBFCDB65BFE24A4082AAD1AB01C855409148DBF813E34A40D2C8E7154FC855409148DBF813E34A40D2C8E7154FC85540EBFCDB65BFE24A4082AAD1AB01C85540EBFCDB65BFE24A40
71283	51916	87.361825999999994	87.363596000000001	53.804537000000003	53.801485	Уютная	0103000020E61000000100000005000000EB353D2828D75540069E7B0F97E64A40EB353D2828D7554003B68311FBE64A40363D282845D7554003B68311FBE64A40363D282845D75540069E7B0F97E64A40EB353D2828D75540069E7B0F97E64A40
76383	51916	87.111879000000002	87.120197000000005	53.765557999999999	53.765456999999998	Ушинского	0103000020E61000000100000005000000FD86890629C7554044BFB67EFAE14A40FD86890629C755407898F6CDFDE14A40F304C24EB1C755407898F6CDFDE14A40F304C24EB1C7554044BFB67EFAE14A40FD86890629C7554044BFB67EFAE14A40
71076	51916	87.368562999999995	87.377897000000004	53.800713999999999	53.799847	Тузовского	0103000020E6100000010000000500000000E1438996D75540E066F16261E64A4000E1438996D7554084B9DDCB7DE64A406B10E6762FD8554084B9DDCB7DE64A406B10E6762FD85540E066F16261E64A4000E1438996D75540E066F16261E64A40
71720	51916	87.118329000000003	87.177537000000001	53.758724000000001	53.741211999999997	Транспортная	0103000020E61000000100000005000000C74ACCB392C755408DB3E908E0DE4A40C74ACCB392C755405C5837DE1DE14A401E3526C45CCB55405C5837DE1DE14A401E3526C45CCB55408DB3E908E0DE4A40C74ACCB392C755408DB3E908E0DE4A40
70619	51916	87.118329000000003	87.177537000000001	53.758724000000001	53.741211999999997	Транспортная	0103000020E61000000100000005000000C74ACCB392C755408DB3E908E0DE4A40C74ACCB392C755405C5837DE1DE14A401E3526C45CCB55405C5837DE1DE14A401E3526C45CCB55408DB3E908E0DE4A40C74ACCB392C755408DB3E908E0DE4A40
70422	51916	87.154612	87.188406000000001	53.845626000000003	53.818109999999997	Тореза	0103000020E610000001000000050000006DE4BA29E5C95540E94317D4B7E84A406DE4BA29E5C95540DB5207793DEC4A40B1170AD80ECC5540DB5207793DEC4A40B1170AD80ECC5540E94317D4B7E84A406DE4BA29E5C95540E94317D4B7E84A40
28873	51916	87.145996999999994	87.154396000000006	53.784447999999998	53.780920999999999	Томский проезд	0103000020E610000001000000050000001A14CD0358C955403BE12538F5E34A401A14CD0358C95540D0B4C4CA68E44A4087A8C29FE1C95540D0B4C4CA68E44A4087A8C29FE1C955403BE12538F5E34A401A14CD0358C955403BE12538F5E34A40
76209	51916	87.141002	87.165813999999997	53.763387000000002	53.747585999999998	Тольятти	0103000020E61000000100000005000000EBAA402D06C955404679E6E5B0DF4A40EBAA402D06C9554085984BAAB6E14A4003CE52B29CCA554085984BAAB6E14A4003CE52B29CCA55404679E6E5B0DF4A40EBAA402D06C955404679E6E5B0DF4A40
75737	51916	87.319856999999999	87.321797000000004	53.910299000000002	53.90936	Строительная	0103000020E6100000010000000500000063997E8978D45540312592E865F44A4063997E8978D455406F4A79AD84F44A40DCBC715298D455406F4A79AD84F44A40DCBC715298D45540312592E865F44A4063997E8978D45540312592E865F44A40
75768	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	Спортивная	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
71098	51916	87.094397999999998	87.107737999999998	53.751238999999998	53.750306999999999	Сибиряков-Гвардейцев	0103000020E61000000100000005000000B3B3E89D0AC65540DD7A4D0F0AE04A40B3B3E89D0AC65540683D7C9928E04A4055A2EC2DE5C65540683D7C9928E04A4055A2EC2DE5C65540DD7A4D0F0AE04A40B3B3E89D0AC65540DD7A4D0F0AE04A40
50402	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	Сетевая	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
76354	51916	87.139510999999999	87.143220999999997	53.761502999999998	53.757601000000001	Свердлова	0103000020E61000000100000005000000AA9B8BBFEDC855405D35CF11F9E04A40AA9B8BBFEDC85540276728EE78E14A406DC669882AC95540276728EE78E14A406DC669882AC955405D35CF11F9E04A40AA9B8BBFEDC855405D35CF11F9E04A40
76231	51916	87.121140999999994	87.127392999999998	53.906337000000001	53.899827999999999	Рокоссовского	0103000020E610000001000000050000001A4D2EC6C0C7554036035C902DF34A401A4D2EC6C0C75540CF13CFD902F44A40512FF83427C85540CF13CFD902F44A40512FF83427C8554036035C902DF34A401A4D2EC6C0C7554036035C902DF34A40
70614	51916	87.093992999999998	87.111151000000007	53.726277000000003	53.713132000000002	Редаково	0103000020E61000000100000005000000634337FB03C6554094DDCCE847DB4A40634337FB03C65540236B0DA5F6DC4A40BC7A15191DC75540236B0DA5F6DC4A40BC7A15191DC7554094DDCCE847DB4A40634337FB03C6554094DDCCE847DB4A40
71085	51916	87.2988	87.335254000000006	53.785699000000001	53.781059999999997	Разведчиков	0103000020E61000000100000005000000DE02098A1FD355405C1B2AC6F9E34A40DE02098A1FD35540FDBFEAC891E44A409B7631CD74D55540FDBFEAC891E44A409B7631CD74D555405C1B2AC6F9E34A40DE02098A1FD355405C1B2AC6F9E34A40
71289	51916	87.333061999999998	87.337238999999997	53.791550000000001	53.788001999999999	Радищева	0103000020E61000000100000005000000956247E350D555405F97E13FDDE44A40956247E350D555400C93A98251E54A40E3FBE25295D555400C93A98251E54A40E3FBE25295D555405F97E13FDDE44A40956247E350D555405F97E13FDDE44A40
71474	51916	87.374510000000001	87.377430000000004	53.806838999999997	53.799576000000002	Пушкина	0103000020E610000001000000050000009981CAF8F7D755405055A18158E64A409981CAF8F7D755409411178046E74A40E0A128D027D855409411178046E74A40E0A128D027D855405055A18158E64A409981CAF8F7D755405055A18158E64A40
71100	51916	87.096481999999995	87.116738999999995	53.743001	53.725535999999998	Пролетарская	0103000020E61000000100000005000000C5A9D6C22CC655400B09185DDEDC4A40C5A9D6C22CC6554099F221A81ADF4A40BCCADAA678C7554099F221A81ADF4A40BCCADAA678C755400B09185DDEDC4A40C5A9D6C22CC655400B09185DDEDC4A40
28704	51916	87.199420000000003	87.202455999999998	53.765206999999997	53.761833000000003	Прокопьевский переулок	0103000020E61000000100000005000000C68A1A4CC3CC5540BD0166BE83E14A40C68A1A4CC3CC5540CBD58F4DF2E14A4041B8020AF5CC5540CBD58F4DF2E14A4041B8020AF5CC5540BD0166BE83E14A40C68A1A4CC3CC5540BD0166BE83E14A40
76220	51916	87.120152000000004	87.127465000000001	53.772786000000004	53.763339000000002	Покрышкина	0103000020E6100000010000000500000023A30392B0C755407461A417B5E14A4023A30392B0C755404167D2A6EAE24A409E98F56228C855404167D2A6EAE24A409E98F56228C855407461A417B5E14A4023A30392B0C755407461A417B5E14A40
76348	51916	87.100830000000002	87.142088999999999	53.763328000000001	53.760176999999999	Пионерский проспект	0103000020E610000001000000050000002A1DACFF73C65540F015DD7A4DE14A402A1DACFF73C65540800F5EBBB4E14A40C40776FC17C95540800F5EBBB4E14A40C40776FC17C95540F015DD7A4DE14A402A1DACFF73C65540F015DD7A4DE14A40
76370	51916	87.100830000000002	87.142088999999999	53.763328000000001	53.760176999999999	Пионерский	0103000020E610000001000000050000002A1DACFF73C65540F015DD7A4DE14A402A1DACFF73C65540800F5EBBB4E14A40C40776FC17C95540800F5EBBB4E14A40C40776FC17C95540F015DD7A4DE14A402A1DACFF73C65540F015DD7A4DE14A40
76334	51916	87.097012000000007	87.131012999999996	53.766474000000002	53.763146999999996	Орджоникидзе	0103000020E6100000010000000500000074D4D17135C655402F8507CDAEE14A4074D4D17135C65540FE9DEDD11BE24A407496598462C85540FE9DEDD11BE24A407496598462C855402F8507CDAEE14A4074D4D17135C655402F8507CDAEE14A40
76389	51916	87.106084999999993	87.113737999999998	53.891773000000001	53.889943000000002	Олимпийская	0103000020E610000001000000050000002766BD18CAC65540EE26F8A6E9F14A402766BD18CAC65540583A1F9E25F24A40FF93BF7B47C75540583A1F9E25F24A40FF93BF7B47C75540EE26F8A6E9F14A402766BD18CAC65540EE26F8A6E9F14A40
76340	51916	87.136367000000007	87.156785999999997	53.757339999999999	53.745068000000003	Октябрьский проспект	0103000020E610000001000000050000003C50A73CBAC85540E8A562635EDF4A403C50A73CBAC85540F0F96184F0E04A401F9E25C808CA5540F0F96184F0E04A401F9E25C808CA5540E8A562635EDF4A403C50A73CBAC85540E8A562635EDF4A40
70594	51916	87.194506000000004	87.259193999999994	53.781267	53.772556999999999	Обнорского	0103000020E610000001000000050000000D384BC972CC5540DFA5D425E3E24A400D384BC972CC5540D6389B8E00E44A4071546EA296D05540D6389B8E00E44A4071546EA296D05540DFA5D425E3E24A400D384BC972CC5540DFA5D425E3E24A40
76384	51916	87.116083000000003	87.141739000000001	53.897429000000002	53.891751999999997	Новоселов	0103000020E61000000100000005000000C82764E76DC755404012F6ED24F24A40C82764E76DC75540B2BD16F4DEF24A405664744012C95540B2BD16F4DEF24A405664744012C955404012F6ED24F24A40C82764E76DC755404012F6ED24F24A40
28889	51916	87.289807999999994	87.290194	53.768479999999997	53.762008000000002	Новогодняя улица	0103000020E61000000100000005000000A087DA368CD255402BA5677A89E14A40A087DA368CD25540A6D0798D5DE24A40B5DFDA8992D25540A6D0798D5DE24A40B5DFDA8992D255402BA5677A89E14A40A087DA368CD255402BA5677A89E14A40
71294	51916	87.289681999999999	87.292610999999994	53.788364000000001	53.781198000000003	Новобайдаевская	0103000020E610000001000000050000005A0F5F268AD25540AED9CA4BFEE34A405A0F5F268AD2554000AC8E1CE9E44A40CADC7C23BAD2554000AC8E1CE9E44A40CADC7C23BAD25540AED9CA4BFEE34A405A0F5F268AD25540AED9CA4BFEE34A40
71070	51916	87.184948000000006	87.218186000000003	53.775882000000003	53.767639000000003	Народная	0103000020E610000001000000050000007BDD2230D6CB55402C11A8FE41E24A407BDD2230D6CB55400DC7F31950E34A407C9C69C2F6CD55400DC7F31950E34A407C9C69C2F6CD55402C11A8FE41E24A407BDD2230D6CB55402C11A8FE41E24A40
70606	51916	87.306866999999997	87.310424999999995	53.789411999999999	53.778804000000001	Мурманская	0103000020E610000001000000050000002F4E7CB5A3D355403BFF76D9AFE34A402F4E7CB5A3D35540F488D1730BE54A4017B7D100DED35540F488D1730BE54A4017B7D100DED355403BFF76D9AFE34A402F4E7CB5A3D355403BFF76D9AFE34A40
70439	51916	87.335991000000007	87.337795999999997	53.787933000000002	53.785629	Монтажная	0103000020E61000000100000005000000063065E080D5554004E5B67D8FE44A40063065E080D55540373811FDDAE44A400E2E1D739ED55540373811FDDAE44A400E2E1D739ED5554004E5B67D8FE44A40063065E080D5554004E5B67D8FE44A40
70492	51916	87.094352999999998	87.108806999999999	53.754353000000002	53.750306999999999	Мичурина	0103000020E61000000100000005000000E3512AE109C65540DD7A4D0F0AE04A40E3512AE109C65540DB519CA38EE04A40DBA4A2B1F6C65540DB519CA38EE04A40DBA4A2B1F6C65540DD7A4D0F0AE04A40E3512AE109C65540DD7A4D0F0AE04A40
70600	51916	87.373368999999997	87.374842999999998	53.807158999999999	53.802883000000001	Маркшейдерская	0103000020E61000000100000005000000C6151747E5D75540D7C1C1DEC4E64A40C6151747E5D7554006D671FC50E74A409C887E6DFDD7554006D671FC50E74A409C887E6DFDD75540D7C1C1DEC4E64A40C6151747E5D75540D7C1C1DEC4E64A40
71519	51916	87.182271	87.185433000000003	53.771023999999997	53.768586999999997	Луначарского	0103000020E610000001000000050000009700FC53AACB5540BC900E0F61E24A409700FC53AACB55402E3718EAB0E24A4059A65F22DECB55402E3718EAB0E24A4059A65F22DECB5540BC900E0F61E24A409700FC53AACB5540BC900E0F61E24A40
75681	51916	87.101027000000002	87.105276000000003	53.717171	53.703010999999996	Литейная улица	0103000020E61000000100000005000000D540F33977C6554037DDB243FCD94A40D540F33977C65540DF516342CCDB4A4070438CD7BCC65540DF516342CCDB4A4070438CD7BCC6554037DDB243FCD94A40D540F33977C6554037DDB243FCD94A40
71096	51916	87.029854	87.044944999999998	53.742666	53.731065999999998	Лесная	0103000020E61000000100000005000000E869C020E9C15540D89B189293DD4A40E869C020E9C15540F2ECF2AD0FDF4A409947FE60E0C25540F2ECF2AD0FDF4A409947FE60E0C25540D89B189293DD4A40E869C020E9C15540D89B189293DD4A40
71057	51916	87.184659999999994	87.237049999999996	53.791257000000002	53.768464000000002	Ленина	0103000020E6100000010000000500000047382D78D1CB5540A11342075DE24A4047382D78D1CB554094DDCCE847E54A401361C3D32BCF554094DDCCE847E54A401361C3D32BCF5540A11342075DE24A4047382D78D1CB5540A11342075DE24A40
70367	51916	87.228758999999997	87.233806999999999	53.793965	53.789965000000002	Левитана	0103000020E610000001000000050000009AEAC9FCA3CE554009FEB7921DE54A409AEAC9FCA3CE5540969526A5A0E54A40DBA4A2B1F6CE5540969526A5A0E54A40DBA4A2B1F6CE554009FEB7921DE54A409AEAC9FCA3CE554009FEB7921DE54A40
70364	51916	87.146688999999995	87.148818000000006	53.801453000000002	53.788752000000002	Ладожская	0103000020E61000000100000005000000B56B425A63C95540CA5356D3F5E44A40B56B425A63C95540FB230C0396E64A4098C3EE3B86C95540FB230C0396E64A4098C3EE3B86C95540CA5356D3F5E44A40B56B425A63C95540CA5356D3F5E44A40
75608	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	Кучина	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
71102	51916	87.112211000000002	87.143527000000006	53.752155000000002	53.743395999999997	Кутузова	0103000020E6100000010000000500000018D00B772EC7554015FDA19927DF4A4018D00B772EC75540EE42739D46E04A40F4C5DE8B2FC95540EE42739D46E04A40F4C5DE8B2FC9554015FDA19927DF4A4018D00B772EC7554015FDA19927DF4A40
75760	51916	87.383663999999996	87.389961	53.805936000000003	53.804473000000002	Кустарная	0103000020E61000000100000005000000C32973F38DD85540ECC1A4F8F8E64A40C32973F38DD85540A4552DE928E74A40CA6DFB1EF5D85540A4552DE928E74A40CA6DFB1EF5D85540ECC1A4F8F8E64A40C32973F38DD85540ECC1A4F8F8E64A40
70289	51916	87.088738000000006	87.104422999999997	53.757759999999998	53.756993999999999	Куйбышева	0103000020E6100000010000000500000066FA25E2ADC5554055A2EC2DE5E04A4066FA25E2ADC55540C51B9947FEE04A40D07CCEDDAEC65540C51B9947FEE04A40D07CCEDDAEC6554055A2EC2DE5E04A4066FA25E2ADC5554055A2EC2DE5E04A40
70286	51916	86.961338999999995	86.963351000000003	53.677759000000002	53.675418000000001	Кубинская улица	0103000020E61000000100000005000000A357039486BD55409B90D61874D64A40A357039486BD5540EBC891CEC0D64A4069E4F38AA7BD5540EBC891CEC0D64A4069E4F38AA7BD55409B90D61874D64A40A357039486BD55409B90D61874D64A40
70587	51916	87.275067000000007	87.288227000000006	53.796841999999998	53.792752	Крупской	0103000020E610000001000000050000005E4D9EB29AD1554057EBC4E578E54A405E4D9EB29AD15540240A2DEBFEE54A40C0B4A84F72D25540240A2DEBFEE54A40C0B4A84F72D2554057EBC4E578E54A405E4D9EB29AD1554057EBC4E578E54A40
50455	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	Красина	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
76382	51916	87.101421999999999	87.143310999999997	53.894655	53.885824999999997	Косыгина	0103000020E610000001000000050000001346B3B27DC65540567DAEB662F14A401346B3B27DC65540F819170E84F24A400D8AE6012CC95540F819170E84F24A400D8AE6012CC95540567DAEB662F14A401346B3B27DC65540567DAEB662F14A40
70535	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	Коммунистическая	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
70420	51916	87.156560999999996	87.168274999999994	53.831764	53.819651999999998	Клименко	0103000020E610000001000000050000000FB56D1805CA5540ED0C535BEAE84A400FB56D1805CA5540BDFE243E77EA4A40006F8104C5CA5540BDFE243E77EA4A40006F8104C5CA5540ED0C535BEAE84A400FB56D1805CA5540ED0C535BEAE84A40
71023	51916	87.162893999999994	87.186520000000002	53.838863000000003	53.835340000000002	Климасенко	0103000020E61000000100000005000000BCADF4DA6CCA55403485CE6BECEA4A40BCADF4DA6CCA55408869DFDC5FEB4A40320395F1EFCB55408869DFDC5FEB4A40320395F1EFCB55403485CE6BECEA4A40BCADF4DA6CCA55403485CE6BECEA4A40
28701	51916	87.123844000000005	87.125703999999999	53.740093999999999	53.737985000000002	Киселевский переулок	0103000020E610000001000000050000009373620FEDC7554023F8DF4A76DE4A409373620FEDC75540A0FB7266BBDE4A407D3ECA880BC85540A0FB7266BBDE4A407D3ECA880BC8554023F8DF4A76DE4A409373620FEDC7554023F8DF4A76DE4A40
71522	51916	87.104620999999995	87.169443000000001	53.758122	53.756833999999998	Кирова	0103000020E61000000100000005000000635E471CB2C655401C40BFEFDFE04A40635E471CB2C65540663046240AE14A4050E27327D8CA5540663046240AE14A4050E27327D8CA55401C40BFEFDFE04A40635E471CB2C655401C40BFEFDFE04A40
76344	51916	87.104620999999995	87.169443000000001	53.758122	53.756833999999998	Кирова	0103000020E61000000100000005000000635E471CB2C655401C40BFEFDFE04A40635E471CB2C65540663046240AE14A4050E27327D8CA5540663046240AE14A4050E27327D8CA55401C40BFEFDFE04A40635E471CB2C655401C40BFEFDFE04A40
28940	51916	87.075047999999995	87.079601999999994	53.744385999999999	53.737873	Кирзаводская улица	0103000020E6100000010000000500000055682096CDC45540FBCC599F72DE4A4055682096CDC45540D5CC5A0A48DF4A408EACFC3218C55540D5CC5A0A48DF4A408EACFC3218C55540FBCC599F72DE4A4055682096CDC45540FBCC599F72DE4A40
28885	51916	87.371824000000004	87.372606000000005	53.808855000000001	53.805287	Кедровый переулок	0103000020E610000001000000050000008CF7E3F6CBD755406D72F8A413E74A408CF7E3F6CBD75540611A868F88E74A40C712D6C6D8D75540611A868F88E74A40C712D6C6D8D755406D72F8A413E74A408CF7E3F6CBD755406D72F8A413E74A40
70612	51916	87.056031000000004	87.062669	53.749237000000001	53.748852999999997	Карла Маркса	0103000020E61000000100000005000000FB230C0396C355407841446ADADF4A40FB230C0396C3554001FA7DFFE6DF4A40465ED6C402C4554001FA7DFFE6DF4A40465ED6C402C455407841446ADADF4A40FB230C0396C355407841446ADADF4A40
75677	51916	87.370880999999997	87.379576999999998	53.829138999999998	53.813915999999999	Кавказская	0103000020E610000001000000050000004C6DA983BCD7554077D844662EE84A404C6DA983BCD75540486B0C3A21EA4A40155454FD4AD85540486B0C3A21EA4A40155454FD4AD8554077D844662EE84A404C6DA983BCD7554077D844662EE84A40
70280	51916	87.186520000000002	87.196509000000006	53.835340000000002	53.831423999999998	Ижевский проезд	0103000020E61000000100000005000000320395F1EFCB5540048E041A6CEA4A40320395F1EFCB55403485CE6BECEA4A40A9177C9A93CC55403485CE6BECEA4A40A9177C9A93CC5540048E041A6CEA4A40320395F1EFCB5540048E041A6CEA4A40
70602	51916	87.335254000000006	87.368562999999995	53.799847	53.785699000000001	Зыряновская	0103000020E610000001000000050000009B7631CD74D55540FDBFEAC891E44A409B7631CD74D55540E066F16261E64A4000E1438996D75540E066F16261E64A4000E1438996D75540FDBFEAC891E44A409B7631CD74D55540FDBFEAC891E44A40
71291	51916	87.282612999999998	87.291128999999998	53.789481000000002	53.775632000000002	Зорге	0103000020E610000001000000050000002A1BD65416D2554094DDCCE847E34A402A1BD65416D255401DE8A1B60DE54A40B37A87DBA1D255401DE8A1B60DE54A40B37A87DBA1D2554094DDCCE847E34A402A1BD65416D2554094DDCCE847E34A40
71719	51916	87.063011000000003	87.064259000000007	53.739491999999998	53.736291000000001	Западная	0103000020E6100000010000000500000073124A5F08C4554069AB92C83EDE4A4073124A5F08C45540AAD381ACA7DE4A4051DEC7D11CC45540AAD381ACA7DE4A4051DEC7D11CC4554069AB92C83EDE4A4073124A5F08C4554069AB92C83EDE4A40
71298	51916	87.022621999999998	87.03528	53.744028999999998	53.743374000000003	Жасминная	0103000020E61000000100000005000000E38A8BA372C155402E5915E126DF4A40E38A8BA372C1554046239F573CDF4A40FC8C0B0742C2554046239F573CDF4A40FC8C0B0742C255402E5915E126DF4A40E38A8BA372C155402E5915E126DF4A40
70515	51916	87.355215000000001	87.368140999999994	53.797454000000002	53.793885000000003	Емельяновская	0103000020E610000001000000050000001D03B2D7BBD655407AE40F069EE54A401D03B2D7BBD655403E0801F912E64A4045D4449F8FD755403E0801F912E64A4045D4449F8FD755407AE40F069EE54A401D03B2D7BBD655407AE40F069EE54A40
71475	51916	87.341300000000004	87.354262000000006	53.796714000000001	53.794204000000001	Дузенко	0103000020E61000000100000005000000FD87F4DBD7D555401B2D077AA8E54A40FD87F4DBD7D55540F7216FB9FAE54A40CC0D863AACD65540F7216FB9FAE54A40CC0D863AACD655401B2D077AA8E54A40FD87F4DBD7D555401B2D077AA8E54A40
71473	51916	87.306471999999999	87.313541999999998	53.747670999999997	53.743623999999997	Дорстроевская	0103000020E61000000100000005000000F148BC3C9DD35540A6423C122FDF4A40F148BC3C9DD355407495EEAEB3DF4A4009FB761211D455407495EEAEB3DF4A4009FB761211D45540A6423C122FDF4A40F148BC3C9DD35540A6423C122FDF4A40
76276	51916	87.128686000000002	87.131237999999996	53.789315999999999	53.778968999999996	ДОЗ	0103000020E61000000100000005000000FF5C34643CC8554085CC9541B5E34A40FF5C34643CC85540D21A834E08E54A40847F113466C85540D21A834E08E54A40847F113466C8554085CC9541B5E34A40FF5C34643CC8554085CC9541B5E34A40
76235	51916	87.162463000000002	87.173917000000003	53.757041999999998	53.750290999999997	Грдины	0103000020E61000000100000005000000D8F335CB65CA5540D7BD158909E04A40D8F335CB65CA554066D993C0E6E04A40FBCDC47421CB554066D993C0E6E04A40FBCDC47421CB5540D7BD158909E04A40D8F335CB65CA5540D7BD158909E04A40
70430	51916	87.174931999999998	87.189573999999993	53.834150000000001	53.821693000000003	Горьковская	0103000020E6100000010000000500000087C1FC1532CB5540132D793C2DE94A4087C1FC1532CB5540ADFA5C6DC5EA4A40008BFCFA21CC5540ADFA5C6DC5EA4A40008BFCFA21CC5540132D793C2DE94A4087C1FC1532CB5540132D793C2DE94A40
71088	51916	87.036940999999999	87.044622000000004	53.749316999999998	53.746223000000001	Горноспасательная	0103000020E610000001000000050000006BB8C83D5DC25540F2423A3C84DF4A406BB8C83D5DC255401DAB949EE9DF4A40A8AB3B16DBC255401DAB949EE9DF4A40A8AB3B16DBC25540F2423A3C84DF4A406BB8C83D5DC25540F2423A3C84DF4A40
71560	51916	87.110972000000004	87.121572	53.736184999999999	53.726517000000001	Волховская	0103000020E6100000010000000500000064B14D2A1AC75540787E5182FEDC4A4064B14D2A1AC755402367614F3BDE4A40FF06EDD5C7C755402367614F3BDE4A40FF06EDD5C7C75540787E5182FEDC4A4064B14D2A1AC75540787E5182FEDC4A40
71638	51916	87.127941000000007	87.131919999999994	53.713408999999999	53.709668000000001	Волжская	0103000020E6100000010000000500000053B4722F30C855404582A966D6DA4A4053B4722F30C8554006D671FC50DB4A400D6C956071C8554006D671FC50DB4A400D6C956071C855404582A966D6DA4A4053B4722F30C855404582A966D6DA4A40
70495	51916	87.107217000000006	87.127752000000001	53.749566999999999	53.739817000000002	Вокзальная	0103000020E61000000100000005000000D124B1A4DCC655402E03CE52B2DE4A40D124B1A4DCC655409694BBCFF1DF4A40E97FB9162DC855409694BBCFF1DF4A40E97FB9162DC855402E03CE52B2DE4A40D124B1A4DCC655402E03CE52B2DE4A40
75772	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	Водосточная	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
71092	51916	87.045314000000005	87.056031000000004	53.749215999999997	53.744571999999998	Веры Соломиной	0103000020E610000001000000050000004303B16CE6C2554037C2A2224EDF4A404303B16CE6C25540E9D1544FE6DF4A40FB230C0396C35540E9D1544FE6DF4A40FB230C0396C3554037C2A2224EDF4A404303B16CE6C2554037C2A2224EDF4A40
71229	51916	87.123026999999993	87.148081000000005	53.723523	53.714081	Варшавская	0103000020E610000001000000050000009961A3ACDFC75540F5D8960167DB4A409961A3ACDFC75540B073D3669CDC4A402D0ABB287AC95540B073D3669CDC4A402D0ABB287AC95540F5D8960167DB4A409961A3ACDFC75540F5D8960167DB4A40
70591	51916	87.207406000000006	87.218545000000006	53.78098	53.776094999999998	Бугарева	0103000020E61000000100000005000000A1BFD02346CD554068CBB91457E34A40A1BFD02346CD5540406A1327F7E34A4014ED2AA4FCCD5540406A1327F7E34A4014ED2AA4FCCD554068CBB91457E34A40A1BFD02346CD554068CBB91457E34A40
28797	51916	87.157539999999997	87.157998000000006	53.792634999999997	53.791018000000001	Беловский проезд	0103000020E61000000100000005000000F5F3A62215CA55400F46EC1340E54A40F5F3A62215CA55401D554D1075E54A4057B5A4A31CCA55401D554D1075E54A4057B5A4A31CCA55400F46EC1340E54A40F5F3A62215CA55400F46EC1340E54A40
70626	51916	87.146580999999998	87.150155999999996	53.745652999999997	53.741222999999998	Батюшкова	0103000020E61000000100000005000000C24D469561C9554081053065E0DE4A40C24D469561C955400795B88E71DF4A401553E9279CC955400795B88E71DF4A401553E9279CC9554081053065E0DE4A40C24D469561C9554081053065E0DE4A40
71607	51916	87.128803000000005	87.132828000000003	53.713745000000003	53.710008999999999	Акмолинская	0103000020E610000001000000050000001C28F04E3EC85540CE6E2D93E1DA4A401C28F04E3EC855407E5704FF5BDB4A408FFF024180C855407E5704FF5BDB4A408FFF024180C85540CE6E2D93E1DA4A401C28F04E3EC85540CE6E2D93E1DA4A40
76353	51916	87.369174000000001	87.376414999999994	53.830016000000001	53.808855000000001	Автодорожная 	0103000020E610000001000000050000002522FC8BA0D75540611A868F88E74A402522FC8BA0D755401094DBF63DEA4A4053AEF02E17D855401094DBF63DEA4A4053AEF02E17D85540611A868F88E74A402522FC8BA0D75540611A868F88E74A40
50403	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	50 лет городу	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
70772	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	40 лет Победы	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
70574	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	40 лет ВЛКСМ	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
50400	51916	86.859110999999999	87.451289000000003	53.932192999999998	53.640301000000001	3 микрорайон	0103000020E610000001000000050000009128B4ACFBB655404D4C1762F5D14A409128B4ACFBB65540B247A81952F74A40DA0242EBE1DC5540B247A81952F74A40DA0242EBE1DC55404D4C1762F5D14A409128B4ACFBB655404D4C1762F5D14A40
76236	51916	87.125101999999998	87.129827000000006	53.774047000000003	53.771465999999997	 Филиппова	0103000020E6100000010000000500000082AAD1AB01C85540EBFCDB65BFE24A4082AAD1AB01C855409148DBF813E34A40D2C8E7154FC855409148DBF813E34A40D2C8E7154FC85540EBFCDB65BFE24A4082AAD1AB01C85540EBFCDB65BFE24A40
50369	4775	86.061595999999994	86.069061000000005	55.302529999999997	55.300009000000003	Октябрьская	0103000020E610000001000000050000001F645930F1835540BAC0E5B166A64B401F645930F18355408907944DB9A64B40761BD47E6B8455408907944DB9A64B40761BD47E6B845540BAC0E5B166A64B401F645930F1835540BAC0E5B166A64B40
75991	4775	86.05829	86.062081000000006	55.305379000000002	55.302961000000003	Новая улица	0103000020E61000000100000005000000C4EBFA05BB835540537B116DC7A64B40C4EBFA05BB8355404EF1B8A816A74B40FE2C9622F98355404EF1B8A816A74B40FE2C9622F9835540537B116DC7A64B40C4EBFA05BB835540537B116DC7A64B40
12914	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	квартал 7	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
12968	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	бульвар Юбилейный	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76386	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Энергетиков	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76372	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Энергетиков	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76366	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Центральная	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76252	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Рембазовская	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76311	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Первомайская 	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76301	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Первомайская	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76358	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Панфилова	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
12389	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Олимпийская	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76364	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Ленина	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76286	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	Левологовая	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
12946	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	50 лет пионерии	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
76246	41081	87.669462999999993	87.887591999999998	53.751063000000002	53.687880999999997	17 квартал	0103000020E6100000010000000500000073B8567BD8EA554017450F7C0CD84A4073B8567BD8EA55402A1E17D522E04A403D0CAD4ECEF855402A1E17D522E04A403D0CAD4ECEF8554017450F7C0CD84A4073B8567BD8EA554017450F7C0CD84A40
75849	2899	85.906187000000003	85.939442999999997	55.434998	55.409753000000002	Школьная	0103000020E61000000100000005000000DD43C2F7FE7955400D384BC972B44B40DD43C2F7FE795540A7E9B303AEB74B40315D88D51F7C5540A7E9B303AEB74B40315D88D51F7C55400D384BC972B44B40DD43C2F7FE7955400D384BC972B44B40
75774	59411	87.029422999999994	87.032754999999995	53.900199000000001	53.897869999999998	Рабочая	0103000020E6100000010000000500000003B00111E2C155409E077767EDF24A4003B00111E2C155402A7288B839F34A40F3716DA818C255402A7288B839F34A40F3716DA818C255409E077767EDF24A4003B00111E2C155409E077767EDF24A40
71401	59411	87.030688999999995	87.044397000000004	53.902873	53.897508999999999	Молодежная	0103000020E6100000010000000500000034D6FECEF6C15540CE6E2D93E1F24A4034D6FECEF6C1554080B8AB5791F34A4098C28366D7C2554080B8AB5791F34A4098C28366D7C25540CE6E2D93E1F24A4034D6FECEF6C15540CE6E2D93E1F24A40
50393	2673	86.195570000000004	86.202810999999997	55.327218999999999	55.319966000000001	Южная	0103000020E610000001000000050000000A850838848C55407DEA58A5F4A84B400A850838848C55409ED0EB4FE2A94B403811FDDAFA8C55409ED0EB4FE2A94B403811FDDAFA8C55407DEA58A5F4A84B400A850838848C55407DEA58A5F4A84B40
1590	2673	86.200637	86.201733000000004	55.312783000000003	55.308253999999998	Советская улица	0103000020E610000001000000050000008657923CD78C55403B6EF8DD74A74B408657923CD78C554055DFF94509A84B4089618731E98C554055DFF94509A84B4089618731E98C55403B6EF8DD74A74B408657923CD78C55403B6EF8DD74A74B40
50370	2673	86.200637	86.201733000000004	55.312783000000003	55.308253999999998	Советская	0103000020E610000001000000050000008657923CD78C55403B6EF8DD74A74B408657923CD78C554055DFF94509A84B4089618731E98C554055DFF94509A84B4089618731E98C55403B6EF8DD74A74B408657923CD78C55403B6EF8DD74A74B40
71179	2673	86.199712000000005	86.204364999999996	55.313291	55.311425999999997	Зеленая	0103000020E610000001000000050000009A27D714C88C5540E28FA2CEDCA74B409A27D714C88C5540C99063EB19A84B409CDCEF50148D5540C99063EB19A84B409CDCEF50148D5540E28FA2CEDCA74B409A27D714C88C5540E28FA2CEDCA74B40
75987	60703	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Лесорубов	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
75593	60703	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Кузнецкая	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50563	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	бульвар Строителей	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50033	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Ярославского	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
12762	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Юргинская	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
12984	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Чумова	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50579	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Черных	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50621	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Цветочный переулок	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75642	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Хмельницкого	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50653	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Фадеева	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50619	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Ускатная	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50105	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Строителей проезд	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75622	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Садовая	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50570	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Рейдовая	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
13053	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Привольная	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
12382	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Пионерская	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
13635	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Панфилова	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75885	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Нижне-Заводская	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50566	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Мурманский переулок	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75590	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Мира	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
12388	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Лутугина	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75655	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Луговая	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75660	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Ленина	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75674	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Ленина	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50406	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Кустарная	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
50439	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Коксовая	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
12403	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Кирпичный переулок	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75856	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Дружбы	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75620	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Дзержинского	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75618	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Весенняя	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75584	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	Багратиона	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
12415	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	50 лет городу	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
75650	26262	86.499875000000003	86.799049999999994	54.075457	53.936985	50 лет Октября	0103000020E61000000100000005000000A245B6F3FD9F5540D9EBDD1FEFF74A40A245B6F3FD9F55408CA03193A8094B409A779CA223B355408CA03193A8094B409A779CA223B35540D9EBDD1FEFF74A40A245B6F3FD9F5540D9EBDD1FEFF74A40
16037	2895	86.045030999999994	86.058982	55.361631000000003	55.357742000000002	улица Щетинкина	0103000020E610000001000000050000009813B4C9E1825540EC33677DCAAD4B409813B4C9E1825540221CB3EC49AE4B405F43705CC6835540221CB3EC49AE4B405F43705CC6835540EC33677DCAAD4B409813B4C9E1825540EC33677DCAAD4B40
16101	2895	86.022492	86.023084999999995	55.386318000000003	55.384343999999999	улица Шишкина	0103000020E61000000100000005000000FC1A498270815540F834272F32B14B40FC1A49827081554096ED43DE72B14B40CD0182397A81554096ED43DE72B14B40CD0182397A815540F834272F32B14B40FC1A498270815540F834272F32B14B40
16190	2895	86.131556000000003	86.140495000000001	55.344791999999998	55.305050999999999	улица Тухачевского	0103000020E61000000100000005000000ED65DB696B885540594E42E90BA74B40ED65DB696B88554012F6ED2422AC4B401990BDDEFD88554012F6ED2422AC4B401990BDDEFD885540594E42E90BA74B40ED65DB696B885540594E42E90BA74B40
16430	2895	86.111092999999997	86.111352999999994	55.342405999999997	55.332405999999999	улица Трофимова	0103000020E610000001000000050000002174D0251C875540417FA1478CAA4B402174D0251C87554022FAB5F5D3AB4B40EF5355682087554022FAB5F5D3AB4B40EF53556820875540417FA1478CAA4B402174D0251C875540417FA1478CAA4B40
16028	2895	86.034368000000001	86.049171999999999	55.408878999999999	55.403905999999999	улица Спартака	0103000020E61000000100000005000000DA01D715338255403F541A31B3B34B40DA01D71533825540B682A62556B44B4040F850A225835540B682A62556B44B4040F850A2258355403F541A31B3B34B40DA01D715338255403F541A31B3B34B40
15517	2895	86.073066999999995	86.096675000000005	55.323509999999999	55.310073000000003	улица Радищева	0103000020E61000000100000005000000ADDA3521AD845540B22FD978B0A74B40ADDA3521AD845540E8F692C668A94B40D0D556EC2F865540E8F692C668A94B40D0D556EC2F865540B22FD978B0A74B40ADDA3521AD845540B22FD978B0A74B40
15979	2895	85.994438000000002	86.006276999999997	55.388640000000002	55.386420000000001	улица Назарова	0103000020E6100000010000000500000094F947DFA47F55409A42E73576B14B4094F947DFA47F55406FF59CF4BEB14B40E36DA5D7668055406FF59CF4BEB14B40E36DA5D7668055409A42E73576B14B4094F947DFA47F55409A42E73576B14B40
15677	2895	86.066806	86.078492999999995	55.364910999999999	55.352705999999998	улица Кирова	0103000020E610000001000000050000004D4BAC8C468455402E8D5F7825AD4B404D4BAC8C46845540AF795567B5AE4B40C1FD800706855540AF795567B5AE4B40C1FD8007068555402E8D5F7825AD4B404D4BAC8C468455402E8D5F7825AD4B40
15706	2895	86.089246000000003	86.143450000000001	55.341183000000001	55.339370000000002	улица Гагарина	0103000020E6100000010000000500000020D3DA34B68555402C9FE57970AB4B4020D3DA34B6855540C07971E2ABAB4B401EA7E8482E895540C07971E2ABAB4B401EA7E8482E8955402C9FE57970AB4B4020D3DA34B68555402C9FE57970AB4B40
16080	2895	86.042803000000006	86.061002999999999	55.408925000000004	55.401549000000003	улица Василия Толстикова	0103000020E61000000100000005000000ED4ACB48BD825540EA5E27F565B34B40ED4ACB48BD82554027C286A757B44B404E7D2079E783554027C286A757B44B404E7D2079E7835540EA5E27F565B34B40ED4ACB48BD825540EA5E27F565B34B40
15679	2895	86.033271999999997	86.043161999999995	55.389422000000003	55.384549	улица Багратиона	0103000020E61000000100000005000000D7F7E12021825540D15AD1E638B14B40D7F7E12021825540E52B8194D8B14B40849B8C2AC3825540E52B8194D8B14B40849B8C2AC3825540D15AD1E638B14B40D7F7E12021825540D15AD1E638B14B40
15350	2895	86.080972000000003	86.128089000000003	55.411613000000003	55.383862999999998	проспект Шахтеров	0103000020E6100000010000000500000012F92EA52E8555407D923B6C22B14B4012F92EA52E855540E2CD1ABCAFB44B408D7E349C32885540E2CD1ABCAFB44B408D7E349C328855407D923B6C22B14B4012F92EA52E8555407D923B6C22B14B40
76388	2895	86.080972000000003	86.128089000000003	55.411613000000003	55.383862999999998	проспект Шахтеров	0103000020E6100000010000000500000012F92EA52E8555407D923B6C22B14B4012F92EA52E855540E2CD1ABCAFB44B408D7E349C32885540E2CD1ABCAFB44B408D7E349C328855407D923B6C22B14B4012F92EA52E8555407D923B6C22B14B40
15654	2895	86.062349999999995	86.178224	55.353856999999998	55.344130999999997	проспект Ленина	0103000020E61000000100000005000000F5B9DA8AFD83554017450F7C0CAC4B40F5B9DA8AFD835540F73AA92F4BAD4B4030D7A205688B5540F73AA92F4BAD4B4030D7A205688B554017450F7C0CAC4B40F5B9DA8AFD83554017450F7C0CAC4B40
71538	2895	86.042803000000006	86.061002999999999	55.408925000000004	55.401549000000003	имени Толстикова Василия	0103000020E61000000100000005000000ED4ACB48BD825540EA5E27F565B34B40ED4ACB48BD82554027C286A757B44B404E7D2079E783554027C286A757B44B404E7D2079E7835540EA5E27F565B34B40ED4ACB48BD825540EA5E27F565B34B40
71588	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	город КемеровоГагарина	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
15892	2895	86.153959999999998	86.177064999999999	55.357070999999998	55.333056999999997	бульвар Строителей	0103000020E6100000010000000500000019390B7BDA895540185A9D9CA1AA4B4019390B7BDA895540CDACA580B4AD4B400A117008558B5540CDACA580B4AD4B400A117008558B5540185A9D9CA1AA4B4019390B7BDA895540185A9D9CA1AA4B40
71592	2895	86.101992999999993	86.108191000000005	55.397965999999997	55.387683000000003	Ю. Смирнова	0103000020E61000000100000005000000F0DAA50D878655408B1BB7989FB14B40F0DAA50D87865540C075C58CF0B24B402EAEF199EC865540C075C58CF0B24B402EAEF199EC8655408B1BB7989FB14B40F0DAA50D878655408B1BB7989FB14B40
50510	2895	86.233227999999997	86.237089999999995	55.423774999999999	55.415292999999998	Щегловская	0103000020E61000000100000005000000BC202235ED8E5540FDA02E5228B54B40BC202235ED8E554063EE5A423EB64B405A0D897B2C8F554063EE5A423EB64B405A0D897B2C8F5540FDA02E5228B54B40BC202235ED8E5540FDA02E5228B54B40
71710	2895	86.067974000000007	86.075214000000003	55.399172	55.384062999999998	Шахтерская	0103000020E610000001000000050000009DBE9EAF59845540444DF4F928B14B409DBE9EAF598455404DBD6E1118B34B40E38C614ED08455404DBD6E1118B34B40E38C614ED0845540444DF4F928B14B409DBE9EAF59845540444DF4F928B14B40
71142	2895	86.084547999999998	86.096485999999999	55.419620999999999	55.418619999999997	Черноморская	0103000020E610000001000000050000004DBC033C69855540CBB9145795B54B404DBC033C698555407FDB1324B6B54B4066A19DD32C8655407FDB1324B6B54B4066A19DD32C865540CBB9145795B54B404DBC033C69855540CBB9145795B54B40
71549	2895	86.042839000000001	86.046333000000004	55.393476999999997	55.380662000000001	Циолковского	0103000020E6100000010000000500000093FFC9DFBD8255403C6A4C88B9B04B4093FFC9DFBD825540355D4F745DB24B4070EEAF1EF7825540355D4F745DB24B4070EEAF1EF78255403C6A4C88B9B04B4093FFC9DFBD8255403C6A4C88B9B04B40
50372	2895	86.102216999999996	86.117902000000001	55.398544000000001	55.396304000000001	Цимлянская	0103000020E6100000010000000500000018062CB98A86554012A3E716BAB24B4018062CB98A8655402E02637D03B34B408388D4B48B8755402E02637D03B34B408388D4B48B87554012A3E716BAB24B4018062CB98A86554012A3E716BAB24B40
70414	2895	85.980073000000004	86.025501000000006	55.306578000000002	55.289110999999998	Центральная	0103000020E6100000010000000500000054AC1A84B97E5540F9F4D89601A54B4054AC1A84B97E554028D6A9F23DA74B40FB40F2CEA181554028D6A9F23DA74B40FB40F2CEA1815540F9F4D89601A54B4054AC1A84B97E5540F9F4D89601A54B40
71534	2895	86.062296000000003	86.076795000000004	55.334204	55.334091000000001	Федоровского	0103000020E61000000100000005000000FCAA5CA8FC835540A8716F7EC3AA4B40FCAA5CA8FC835540A0185932C7AA4B40C45F9335EA845540A0185932C7AA4B40C45F9335EA845540A8716F7EC3AA4B40FCAA5CA8FC835540A8716F7EC3AA4B40
71673	2895	86.044267000000005	86.055271000000005	55.354486999999999	55.339575000000004	Угловая	0103000020E61000000100000005000000B1524145D582554005C58F3177AB4B40B1524145D5825540B7ED7BD45FAD4B40B45A608F89835540B7ED7BD45FAD4B40B45A608F8983554005C58F3177AB4B40B1524145D582554005C58F3177AB4B40
71589	2895	86.131556000000003	86.140495000000001	55.344791999999998	55.305050999999999	Тухачевского	0103000020E61000000100000005000000ED65DB696B885540594E42E90BA74B40ED65DB696B88554012F6ED2422AC4B401990BDDEFD88554012F6ED2422AC4B401990BDDEFD885540594E42E90BA74B40ED65DB696B885540594E42E90BA74B40
50378	2895	86.084322999999998	86.089021000000002	55.351292999999998	55.350181999999997	Томская	0103000020E610000001000000050000003DD34B8C65855540EDD286C3D2AC4B403DD34B8C658555402828452BF7AC4B4010EA2285B28555402828452BF7AC4B4010EA2285B2855540EDD286C3D2AC4B403DD34B8C65855540EDD286C3D2AC4B40
71542	2895	86.106880000000004	86.168773999999999	55.389268999999999	55.302155999999997	Терешковой	0103000020E610000001000000050000002D26361FD786554024253D0CADA64B402D26361FD78655405E2C0C91D3B14B40919A7631CD8A55405E2C0C91D3B14B40919A7631CD8A554024253D0CADA64B402D26361FD786554024253D0CADA64B40
15791	2895	86.099800999999999	86.102361000000002	55.390317000000003	55.389499000000001	Студенческая улица	0103000020E61000000100000005000000EBC6BB236386554090696D1ADBB14B40EBC6BB236386554053094FE8F5B14B40B2D826158D86554053094FE8F5B14B40B2D826158D86554090696D1ADBB14B40EBC6BB236386554090696D1ADBB14B40
16117	2895	86.048399000000003	86.101112000000001	55.363539000000003	55.348457000000003	Советский проспект	0103000020E610000001000000050000002F8A1EF818835540F9872D3D9AAC4B402F8A1EF81883554008E9297288AE4B40EC4E779E7886554008E9297288AE4B40EC4E779E78865540F9872D3D9AAC4B402F8A1EF818835540F9872D3D9AAC4B40
71531	2895	86.097232000000005	86.101112000000001	55.348457000000003	55.336103999999999	Соборная	0103000020E61000000100000005000000FB07910C398655400307B47405AB4B40FB07910C39865540F9872D3D9AAC4B40EC4E779E78865540F9872D3D9AAC4B40EC4E779E788655400307B47405AB4B40FB07910C398655400307B47405AB4B40
71544	2895	86.062144000000004	86.152900000000002	55.339708000000002	55.335822	Сибиряков-Гвардейцев	0103000020E6100000010000000500000021E9D32AFA8355407FA31D37FCAA4B4021E9D32AFA83554044183F8D7BAB4B40BDE3141DC989554044183F8D7BAB4B40BDE3141DC98955407FA31D37FCAA4B4021E9D32AFA8355407FA31D37FCAA4B40
71659	2895	86.074854999999999	86.084754000000004	55.319664000000003	55.314560999999998	Сергея Тюленина	0103000020E610000001000000050000004B3CA06CCA8455406CCCEB8843A84B404B3CA06CCA845540B2DAFCBFEAA84B40228D0A9C6C855540B2DAFCBFEAA84B40228D0A9C6C8555406CCCEB8843A84B404B3CA06CCA8455406CCCEB8843A84B40
71136	2895	86.031008	86.044267000000005	55.342601000000002	55.339570000000002	Семашко	0103000020E61000000100000005000000857AFA08FC815540F3599E0777AB4B40857AFA08FC815540D8497D59DAAB4B40B1524145D5825540D8497D59DAAB4B40B1524145D5825540F3599E0777AB4B40857AFA08FC815540F3599E0777AB4B40
71583	2895	86.066311999999996	86.066743000000002	55.352618	55.341566999999998	Рукавишникова	0103000020E6100000010000000500000045D5AF743E8455404832AB77B8AB4B4045D5AF743E8455408FFD2C9622AD4B402A8F6E84458455408FFD2C9622AD4B402A8F6E84458455404832AB77B8AB4B4045D5AF743E8455404832AB77B8AB4B40
71547	2895	86.104947999999993	86.128089000000003	55.421894999999999	55.411597999999998	Ракитянского	0103000020E61000000100000005000000F5F1D077B7865540AC8C463EAFB44B40F5F1D077B786554047ACC5A700B64B408D7E349C3288554047ACC5A700B64B408D7E349C32885540AC8C463EAFB44B40F5F1D077B7865540AC8C463EAFB44B40
71571	2895	86.073066999999995	86.096675000000005	55.323509999999999	55.310073000000003	Радищева	0103000020E61000000100000005000000ADDA3521AD845540B22FD978B0A74B40ADDA3521AD845540E8F692C668A94B40D0D556EC2F865540E8F692C668A94B40D0D556EC2F865540B22FD978B0A74B40ADDA3521AD845540B22FD978B0A74B40
71715	2895	86.039713000000006	86.044357000000005	55.354860000000002	55.347299999999997	Пушкина	0103000020E61000000100000005000000780E65A88A8255404DF38E5374AC4B40780E65A88A8255404C546F0D6CAD4B405116BEBED68255404C546F0D6CAD4B405116BEBED68255404DF38E5374AC4B40780E65A88A8255404DF38E5374AC4B40
76484	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	Промшоссе	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
71576	2895	86.069293999999999	86.075024999999997	55.344248999999998	55.334167999999998	Пролетарская	0103000020E61000000100000005000000C7F319506F84554053AF5B04C6AA4B40C7F319506F8455402157EA5910AC4B407958A835CD8455402157EA5910AC4B407958A835CD84554053AF5B04C6AA4B40C7F319506F84554053AF5B04C6AA4B40
76170	2895	86.113078000000002	86.119528000000003	55.318930999999999	55.310242000000002	Плодопитомник	0103000020E610000001000000050000006AF981AB3C8755403EEC8502B6A74B406AF981AB3C8755401D5723BBD2A84B4034BDC458A68755401D5723BBD2A84B4034BDC458A68755403EEC8502B6A74B406AF981AB3C8755403EEC8502B6A74B40
16325	2895	86.107894999999999	86.108371000000005	55.350771000000002	55.336201000000003	Пионерский бульвар	0103000020E61000000100000005000000B9196EC0E7865540F6F065A208AB4B40B9196EC0E78655404FB16A10E6AC4B406E35EB8CEF8655404FB16A10E6AC4B406E35EB8CEF865540F6F065A208AB4B40B9196EC0E7865540F6F065A208AB4B40
76398	2895	86.074315999999996	86.090378000000001	55.322009999999999	55.312184000000002	Патриотов	0103000020E610000001000000050000007364E597C1845540D02A33A5F5A74B407364E597C1845540137EA99F37A94B40C991CEC0C8855540137EA99F37A94B40C991CEC0C8855540D02A33A5F5A74B407364E597C1845540D02A33A5F5A74B40
71654	2895	86.074315999999996	86.090378000000001	55.322009999999999	55.312184000000002	Патриотов	0103000020E610000001000000050000007364E597C1845540D02A33A5F5A74B407364E597C1845540137EA99F37A94B40C991CEC0C8855540137EA99F37A94B40C991CEC0C8855540D02A33A5F5A74B407364E597C1845540D02A33A5F5A74B40
71713	2895	86.047600000000003	86.058407000000003	55.391779	55.387309999999999	Панфилова	0103000020E6100000010000000500000089D2DEE00B835540F6B4C35F93B14B4089D2DEE00B8355403A2174D025B24B40E1B6B6F0BC8355403A2174D025B24B40E1B6B6F0BC835540F6B4C35F93B14B4089D2DEE00B835540F6B4C35F93B14B40
71645	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	Осинниковский городской округРадищева	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
71582	2895	86.086802000000006	86.088087000000002	55.358105000000002	55.355398000000001	Орджоникидзе	0103000020E610000001000000050000008ECEF9298E8555402B8881AE7DAD4B408ECEF9298E8555405DC47762D6AD4B40FA0CA837A38555405DC47762D6AD4B40FA0CA837A38555402B8881AE7DAD4B408ECEF9298E8555402B8881AE7DAD4B40
16221	2895	86.101112000000001	86.177396999999999	55.358586000000003	55.348416	Октябрьский проспект	0103000020E61000000100000005000000EC4E779E788655409AB33EE598AC4B40EC4E779E78865540D8666325E6AD4B40255AF2785A8B5540D8666325E6AD4B40255AF2785A8B55409AB33EE598AC4B40EC4E779E788655409AB33EE598AC4B40
71548	2895	86.050807000000006	86.058989999999994	55.384748000000002	55.383116999999999	Озерная	0103000020E610000001000000050000001BDA006C4083554054C554FA09B14B401BDA006C40835540C899266C3FB14B40A032FE7DC6835540C899266C3FB14B40A032FE7DC683554054C554FA09B14B401BDA006C4083554054C554FA09B14B40
71529	2895	86.002602999999993	86.004273999999995	55.345421999999999	55.340676000000002	Невьянская	0103000020E61000000100000005000000C6F7C5A52A8055401C446B459BAB4B40C6F7C5A52A805540D2A8C0C936AC4B40478E740646805540D2A8C0C936AC4B40478E7406468055401C446B459BAB4B40C6F7C5A52A8055401C446B459BAB4B40
71130	2895	86.089586999999995	86.139273000000003	55.438062000000002	55.385679000000003	Нахимова	0103000020E6100000010000000500000064C91CCBBB85554083E0F1ED5DB14B4064C91CCBBB85554068CF656A12B84B40D00D4DD9E988554068CF656A12B84B40D00D4DD9E988554083E0F1ED5DB14B4064C91CCBBB85554083E0F1ED5DB14B40
16241	2895	86.147681000000006	86.173687000000001	55.362608000000002	55.354036000000001	Московский проспект	0103000020E61000000100000005000000664F029B73895540A7CD380D51AD4B40664F029B738955404DA25EF069AE4B40622F14B01D8B55404DA25EF069AE4B40622F14B01D8B5540A7CD380D51AD4B40664F029B73895540A7CD380D51AD4B40
15838	2895	86.112026999999998	86.132103999999998	55.330193999999999	55.321241000000001	Молодежный проспект	0103000020E6100000010000000500000037514B732B8755403291D26C1EA94B4037514B732B875540EFAA07CC43AA4B40EEEA556474885540EFAA07CC43AA4B40EEEA5564748855403291D26C1EA94B4037514B732B8755403291D26C1EA94B40
71578	2895	86.076795000000004	86.098049000000003	55.353622000000001	55.334204	Мичурина	0103000020E61000000100000005000000C45F9335EA845540A0185932C7AA4B40C45F9335EA845540B492567C43AD4B40F419506F46865540B492567C43AD4B40F419506F46865540A0185932C7AA4B40C45F9335EA845540A0185932C7AA4B40
50373	2895	86.049009999999996	86.052926999999997	55.362290999999999	55.359726999999999	Маркса	0103000020E6100000010000000500000053CBD6FA228355407D3ECA880BAE4B4053CBD6FA228355404C512E8D5FAE4B40D384ED27638355404C512E8D5FAE4B40D384ED27638355407D3ECA880BAE4B4053CBD6FA228355407D3ECA880BAE4B40
70802	2895	85.949127000000004	85.952262000000005	55.324361000000003	55.322167999999998	Марата	0103000020E610000001000000050000000A302C7FBE7C5540ABE80FCD3CA94B400A302C7FBE7C5540878C47A984A94B404FCE50DCF17C5540878C47A984A94B404FCE50DCF17C5540ABE80FCD3CA94B400A302C7FBE7C5540ABE80FCD3CA94B40
16115	2895	86.157796000000005	86.185868999999997	55.365662999999998	55.335811999999997	Ленинградский проспект	0103000020E6100000010000000500000023DC6454198A55405BCD3AE3FBAA4B4023DC6454198A5540BA2D910BCEAE4B40C6151747E58B5540BA2D910BCEAE4B40C6151747E58B55405BCD3AE3FBAA4B4023DC6454198A55405BCD3AE3FBAA4B40
15681	2895	86.025501000000006	86.078537999999995	55.371699999999997	55.306578000000002	Кузнецкий проспект	0103000020E61000000100000005000000FB40F2CEA181554028D6A9F23DA74B40FB40F2CEA18155402BF697DD93AF4B40915F3FC4068555402BF697DD93AF4B40915F3FC40685554028D6A9F23DA74B40FB40F2CEA181554028D6A9F23DA74B40
50376	2895	86.029813000000004	86.034574000000006	55.387273999999998	55.386789	Крылова	0103000020E61000000100000005000000B9FFC874E8815540EDB94C4D82B14B40B9FFC874E8815540A94BC63192B14B40AFD2DD7536825540A94BC63192B14B40AFD2DD7536825540EDB94C4D82B14B40B9FFC874E8815540EDB94C4D82B14B40
71207	2895	85.998956000000007	86.097474000000005	55.358283999999998	55.345452000000002	Красноармейская	0103000020E61000000100000005000000278925E5EE7F55403D2B69C537AC4B40278925E5EE7F55400C570740DCAD4B40768D96033D8655400C570740DCAD4B40768D96033D8655403D2B69C537AC4B40278925E5EE7F55403D2B69C537AC4B40
16335	2895	86.085024000000004	86.092901999999995	55.356938	55.344499999999996	Красная улица	0103000020E6100000010000000500000002D88008718555406ABC749318AC4B4002D88008718555408E59F624B0AD4B40E9EE3A1BF28555408E59F624B0AD4B40E9EE3A1BF28555406ABC749318AC4B4002D88008718555406ABC749318AC4B40
71653	2895	86.085024000000004	86.092901999999995	55.356938	55.344499999999996	Красная	0103000020E6100000010000000500000002D88008718555406ABC749318AC4B4002D88008718555408E59F624B0AD4B40E9EE3A1BF28555408E59F624B0AD4B40E9EE3A1BF28555406ABC749318AC4B4002D88008718555406ABC749318AC4B40
71535	2895	86.126463000000001	86.126525999999998	55.336266999999999	55.335160999999999	Котовского	0103000020E61000000100000005000000DC4944F81788554084F23E8EE6AA4B40DC4944F817885540ADDC0BCC0AAB4B40FF05820019885540ADDC0BCC0AAB4B40FF0582001988554084F23E8EE6AA4B40DC4944F81788554084F23E8EE6AA4B40
15494	2895	86.077827999999997	86.098327999999995	55.323869000000002	55.311250999999999	Космическая улица	0103000020E61000000100000005000000A3AD4A22FB84554074ECA012D7A74B40A3AD4A22FB8455401898158A74A94B40FD1186014B8655401898158A74A94B40FD1186014B86554074ECA012D7A74B40A3AD4A22FB84554074ECA012D7A74B40
71527	2895	86.077827999999997	86.098327999999995	55.323869000000002	55.311250999999999	Космическая	0103000020E61000000100000005000000A3AD4A22FB84554074ECA012D7A74B40A3AD4A22FB8455401898158A74A94B40FD1186014B8655401898158A74A94B40FD1186014B86554074ECA012D7A74B40A3AD4A22FB84554074ECA012D7A74B40
71561	2895	86.052189999999996	86.057670000000002	55.339928	55.332959000000002	Комсомольская	0103000020E6100000010000000500000068CBB9145783554056F487669EAA4B4068CBB91457835540527FBDC282AB4B4076FD82DDB0835540527FBDC282AB4B4076FD82DDB083554056F487669EAA4B4068CBB9145783554056F487669EAA4B40
71125	2895	86.037467000000007	86.074665999999993	55.353678000000002	55.347628	Коммунистическая	0103000020E6100000010000000500000079EBFCDB65825540429605137FAC4B4079EBFCDB6582554048A8195245AD4B40E107E753C784554048A8195245AD4B40E107E753C7845540429605137FAC4B4079EBFCDB65825540429605137FAC4B40
71596	2895	86.066806	86.078492999999995	55.364910999999999	55.352705999999998	Кирова	0103000020E610000001000000050000004D4BAC8C468455402E8D5F7825AD4B404D4BAC8C46845540AF795567B5AE4B40C1FD800706855540AF795567B5AE4B40C1FD8007068555402E8D5F7825AD4B404D4BAC8C468455402E8D5F7825AD4B40
50377	2895	86.089246000000003	86.089344999999994	55.339370000000002	55.334274999999998	Киевская	0103000020E6100000010000000500000020D3DA34B6855540696FF085C9AA4B4020D3DA34B68555402C9FE57970AB4B40E94317D4B78555402C9FE57970AB4B40E94317D4B7855540696FF085C9AA4B4020D3DA34B6855540696FF085C9AA4B40
76408	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	Каракумская	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
71594	2895	86.042586999999997	86.058325999999994	55.355418	55.351835000000001	Интернациональная	0103000020E61000000100000005000000060FD3BEB9825540494BE5ED08AD4B40060FD3BEB9825540723447567EAD4B406AA0F99CBB835540723447567EAD4B406AA0F99CBB835540494BE5ED08AD4B40060FD3BEB9825540494BE5ED08AD4B40
15457	2895	86.110400999999996	86.117902000000001	55.396304000000001	55.388173999999999	Институтская улица	0103000020E61000000100000005000000861C5BCF10875540299485AFAFB14B40861C5BCF1087554012A3E716BAB24B408388D4B48B87554012A3E716BAB24B408388D4B48B875540299485AFAFB14B40861C5BCF10875540299485AFAFB14B40
70651	2895	86.110400999999996	86.117902000000001	55.396304000000001	55.388173999999999	Институтская	0103000020E61000000100000005000000861C5BCF10875540299485AFAFB14B40861C5BCF1087554012A3E716BAB24B408388D4B48B87554012A3E716BAB24B408388D4B48B875540299485AFAFB14B40861C5BCF10875540299485AFAFB14B40
71536	2895	85.998964999999998	86.061982	55.411653999999999	55.391570000000002	Инициативная	0103000020E610000001000000050000005036E50AEF7F5540200C3CF71EB24B405036E50AEF7F554040A20914B1B44B4034BC5983F783554040A20914B1B44B4034BC5983F7835540200C3CF71EB24B405036E50AEF7F5540200C3CF71EB24B40
16050	2895	86.039398000000006	86.050753	55.356380000000001	55.340476000000002	Индустриальная улица	0103000020E61000000100000005000000C861307F858255405589B2B794AB4B40C861307F8582554068791EDC9DAD4B4021CB82893F83554068791EDC9DAD4B4021CB82893F8355405589B2B794AB4B40C861307F858255405589B2B794AB4B40
71575	2895	86.030415000000005	86.052531999999999	55.314131000000003	55.295893	Зейская	0103000020E61000000100000005000000B493C151F2815540C30E63D2DFA54B40B493C151F281554074D4D17135A84B40957F2DAF5C83554074D4D17135A84B40957F2DAF5C835540C30E63D2DFA54B40B493C151F2815540C30E63D2DFA54B40
15390	2895	86.097879000000006	86.125788999999997	55.369233999999999	55.367106	Елыкаевская улица	0103000020E61000000100000005000000C6FD47A6438655402B155454FDAE4B40C6FD47A6438655401F49490F43AF4B40944C4EED0C8855401F49490F43AF4B40944C4EED0C8855402B155454FDAE4B40C6FD47A6438655402B155454FDAE4B40
78546	2895	86.093117000000007	86.110337999999999	55.320678000000001	55.306536999999999	Дружбы	0103000020E61000000100000005000000E86C01A1F5855540C901BB9A3CA74B40E86C01A1F5855540FA4509FA0BA94B4063601DC70F875540FA4509FA0BA94B4063601DC70F875540C901BB9A3CA74B40E86C01A1F5855540C901BB9A3CA74B40
50287	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	Докучаева	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
15655	2895	86.016571999999996	86.019384000000002	55.399780999999997	55.397097000000002	Гурьевская улица	0103000020E61000000100000005000000E08101840F8155407C2B1213D4B24B40E08101840F815540F54718062CB34B40348463963D815540F54718062CB34B40348463963D8155407C2B1213D4B24B40E08101840F8155407C2B1213D4B24B40
76357	2895	85.973381000000003	85.998956000000007	55.346988000000003	55.328795999999997	Грузовая	0103000020E610000001000000050000000F63D2DF4B7E55401E87C1FC15AA4B400F63D2DF4B7E55405F0D501A6AAC4B40278925E5EE7F55405F0D501A6AAC4B40278925E5EE7F55401E87C1FC15AA4B400F63D2DF4B7E55401E87C1FC15AA4B40
71181	2895	86.074262000000004	86.085051000000007	55.449184000000002	55.444068000000001	Городецкая	0103000020E610000001000000050000007A5567B5C08455409E996038D7B84B407A5567B5C084554078F17EDC7EB94B407FDFBF797185554078F17EDC7EB94B407FDFBF79718555409E996038D7B84B407A5567B5C08455409E996038D7B84B40
71600	2895	86.029148000000006	86.035400999999993	55.392122000000001	55.390031	Гайдара	0103000020E610000001000000050000009BAF928FDD8155408DB62A89ECB14B409BAF928FDD8155406405BF0D31B24B40B94F8E02448255406405BF0D31B24B40B94F8E02448255408DB62A89ECB14B409BAF928FDD8155408DB62A89ECB14B40
71557	2895	86.089246000000003	86.143450000000001	55.341183000000001	55.339370000000002	Гагарина	0103000020E6100000010000000500000020D3DA34B68555402C9FE57970AB4B4020D3DA34B6855540C07971E2ABAB4B401EA7E8482E895540C07971E2ABAB4B401EA7E8482E8955402C9FE57970AB4B4020D3DA34B68555402C9FE57970AB4B40
49970	2895	86.154732999999993	86.172815999999997	55.346834000000001	55.327244	Ворошилова	0103000020E610000001000000050000002AA73D25E7895540F7E7A221E3A94B402AA73D25E78955400892770E65AC4B406F0ED76A0F8B55400892770E65AC4B406F0ED76A0F8B5540F7E7A221E3A94B402AA73D25E7895540F7E7A221E3A94B40
71699	2895	86.147672	86.177989999999994	55.354036000000001	55.312460999999999	Волгоградская	0103000020E610000001000000050000003CA24275738955404223D8B8FEA74B403CA2427573895540A7CD380D51AD4B40F6402B30648B5540A7CD380D51AD4B40F6402B30648B55404223D8B8FEA74B403CA24275738955404223D8B8FEA74B40
71553	2895	86.076660000000004	86.085382999999993	55.360413000000001	55.347607000000004	Весенняя	0103000020E61000000100000005000000543A58FFE78455402B6EDC627EAC4B40543A58FFE7845540D106600322AE4B40992842EA76855540D106600322AE4B40992842EA768555402B6EDC627EAC4B40543A58FFE78455402B6EDC627EAC4B40
71569	2895	86.070857000000004	86.093117000000007	55.319826999999997	55.306536999999999	Веры Волошиной	0103000020E61000000100000005000000556CCCEB88845540C901BB9A3CA74B40556CCCEB888455405BB05417F0A84B40E86C01A1F58555405BB05417F0A84B40E86C01A1F5855540C901BB9A3CA74B40556CCCEB88845540C901BB9A3CA74B40
16512	2895	86.087755000000001	86.090530000000001	55.447780000000002	55.435493000000001	Благовещенская улица	0103000020E61000000100000005000000DFC325C79D8555408751103CBEB74B40DFC325C79D855540C5E6E3DA50B94B40A453573ECB855540C5E6E3DA50B94B40A453573ECB8555408751103CBEB74B40DFC325C79D8555408751103CBEB74B40
71567	2895	86.083883	86.092444	55.334296000000002	55.330809000000002	Бийская	0103000020E610000001000000050000002F6CCD565E8555407A1C06F357AA4B402F6CCD565E85554081971936CAAA4B40882D3D9AEA85554081971936CAAA4B40882D3D9AEA8555407A1C06F357AA4B402F6CCD565E8555407A1C06F357AA4B40
70809	2895	85.986523000000005	85.994490999999996	55.285758000000001	55.280411000000001	Белозерная	0103000020E610000001000000050000001E705D31237F55402638F581E4A34B401E705D31237F55400249D8B793A44B40A54A94BDA57F55400249D8B793A44B40A54A94BDA57F55402638F581E4A34B401E705D31237F55402638F581E4A34B40
70760	2895	85.96199	85.980073000000004	55.289110999999998	55.279893000000001	Баха	0103000020E610000001000000050000000F45813E917D55408EB0A888D3A34B400F45813E917D5540F9F4D89601A54B4054AC1A84B97E5540F9F4D89601A54B4054AC1A84B97E55408EB0A888D3A34B400F45813E917D55408EB0A888D3A34B40
49966	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	Барнаульская	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
71632	2895	86.035606999999999	86.049334000000002	55.399822	55.395271000000001	Артема	0103000020E610000001000000050000008E209562478255405307793D98B24B408E20956247825540541C075E2DB34B402D25CB4928835540541C075E2DB34B402D25CB49288355405307793D98B24B408E209562478255405307793D98B24B40
71709	2895	86.124405999999993	86.145264999999995	55.438766999999999	55.418461000000001	Антипова	0103000020E61000000100000005000000465B9544F687554063D34A2190B54B40465B9544F687554032C85D8429B84B40381092054C89554032C85D8429B84B40381092054C89554063D34A2190B54B40465B9544F687554063D34A2190B54B40
71138	2895	86.013571999999996	86.023363000000003	55.398313000000002	55.394790999999998	Александрова	0103000020E610000001000000050000000B09185DDE805540A8E0F08288B24B400B09185DDE8055402C499EEBFBB24B40EF3B86C77E8155402C499EEBFBB24B40EF3B86C77E815540A8E0F08288B24B400B09185DDE805540A8E0F08288B24B40
49972	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	А.К.Боброва	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
71148	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	50 лет Октября	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
71579	2895	85.909133999999995	86.266437999999994	55.461486999999998	55.257437000000003	40 лет Октября	0103000020E61000000100000005000000A06B5F402F7A5540E3E313B2F3A04B40A06B5F402F7A5540BB438A0112BB4B40581AF8510D915540BB438A0112BB4B40581AF8510D915540E3E313B2F3A04B40A06B5F402F7A5540E3E313B2F3A04B40
71662	2895	86.058892	86.072886999999994	55.316749000000002	55.308515	4-я Цветочная	0103000020E61000000100000005000000BF7FF3E2C4835540A8A9656B7DA74B40BF7FF3E2C48355403605323B8BA84B406D533C2EAA8455403605323B8BA84B406D533C2EAA845540A8A9656B7DA74B40BF7FF3E2C4835540A8A9656B7DA74B40
76387	2895	86.058892	86.072886999999994	55.316749000000002	55.308515	4-я Цветочная	0103000020E61000000100000005000000BF7FF3E2C4835540A8A9656B7DA74B40BF7FF3E2C48355403605323B8BA84B406D533C2EAA8455403605323B8BA84B406D533C2EAA845540A8A9656B7DA74B40BF7FF3E2C4835540A8A9656B7DA74B40
71642	2895	85.940771999999996	85.944014999999993	55.326439999999998	55.319437999999998	2-я Аральская	0103000020E61000000100000005000000853FC39B357C5540C18C2958E3A84B40853FC39B357C5540990D32C9C8A94B40BDFBE3BD6A7C5540990D32C9C8A94B40BDFBE3BD6A7C5540C18C2958E3A84B40853FC39B357C5540C18C2958E3A84B40
76326	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	проспект Мира	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76350	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Спортивная	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76296	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Советский переулок	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76404	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Пожарского	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
13461	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Мира проспект	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76303	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Мира	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76376	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Комсомольская	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76305	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Калинина	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76347	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Дзержинского	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76375	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Дзержинского	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76367	41201	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	60 лет Октября	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
75995	60760	87.753356999999994	87.773478999999995	55.891914999999997	55.880550999999997	Центральная	0103000020E610000001000000050000009C4D470037F05540E4BA29E5B5F04B409C4D470037F05540EAE74D452AF24B40234910AE80F15540EAE74D452AF24B40234910AE80F15540E4BA29E5B5F04B409C4D470037F05540E4BA29E5B5F04B40
50349	2542	86.235365999999999	86.265190000000004	55.314413000000002	55.287050000000001	Клопова	0103000020E61000000100000005000000C8258E3C108F55408D28ED0DBEA44B40C8258E3C108F5540F83768AF3EA84B407B4E7ADFF8905540F83768AF3EA84B407B4E7ADFF89055408D28ED0DBEA44B40C8258E3C108F55408D28ED0DBEA44B40
70728	59402	87.260549999999995	87.270746000000003	53.705776999999998	53.705213000000001	Победы	0103000020E61000000100000005000000423EE8D9ACD0554066DB696B44DA4A40423EE8D9ACD055406EA296E656DA4A4076E107E753D155406EA296E656DA4A4076E107E753D1554066DB696B44DA4A40423EE8D9ACD0554066DB696B44DA4A40
78010	59402	87.265625999999997	87.267790000000005	53.711427	53.707462	Обручева	0103000020E61000000100000005000000E8BD310400D15540D594641D8EDA4A40E8BD310400D15540E63E390A10DB4A40890CAB7823D15540E63E390A10DB4A40890CAB7823D15540D594641D8EDA4A40E8BD310400D15540D594641D8EDA4A40
75861	60719	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Мичурина	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75855	60719	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Мира	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75887	60719	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Ленина	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75898	60719	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Гагарина	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75736	60719	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	7 Ноября	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
50552	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	проезд Карбышева	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
49963	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Школьная	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
13289	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Шахтеров п-т	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50089	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Чехова	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
12361	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Советская	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
75970	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Резвых	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50284	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Молодежный б-р	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50096	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Мира	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50031	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Мира	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
76060	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Механическая	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50030	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Ленина проспект	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50099	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Ленина п-т	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
75972	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Ермака	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50102	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Волкова	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
13319	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	Больничная	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50279	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	А.Лужбина	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
50029	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	8 Марта	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
49965	9765	86.169977000000003	86.300681999999995	55.692144999999996	55.550071000000003	40 лет Победы	0103000020E610000001000000050000009F0436E7E08A554030BDFDB968C64B409F0436E7E08A5540828B153598D84B40BC1FB75F3E935540828B153598D84B40BC1FB75F3E93554030BDFDB968C64B409F0436E7E08A554030BDFDB968C64B40
75651	60701	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Хмельницкого	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75587	60701	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Тимирязева	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75733	60701	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Киевская	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
71392	52146	87.374789000000007	87.432873999999998	53.786921999999997	53.768751999999999	Центральная	0103000020E61000000100000005000000A379008BFCD75540075E2D7766E24A40A379008BFCD755405F402FDCB9E44A407A522635B4DB55405F402FDCB9E44A407A522635B4DB5540075E2D7766E24A40A379008BFCD75540075E2D7766E24A40
76369	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	проспект Ленина	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76269	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	переулок Силовой	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76363	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Школьная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76395	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Челябинская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
13658	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Чекистов	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76331	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Фестивальная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76339	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Угольная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76380	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Солнечная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
12929	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Силовой	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76234	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Семеновка	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76225	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Северная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76249	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Рабиновича	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76356	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Прокопьевская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76274	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Перовская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76270	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Новобольничная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76355	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Мира	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76333	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Милицейская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76360	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Менделеева	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76379	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Львовская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76374	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Ленина	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76265	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Лебедянский переулок	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
13496	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Куйбышева	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76223	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Кубанская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76397	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Коминтерна	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76240	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Китатская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76362	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Киселевская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
12498	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Кемсеть	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76402	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Карла Маркса	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
13542	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Динамитная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76319	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Гурьевская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76325	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Горького	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76359	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Гайдара	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76361	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Гагарина	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76304	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Восстания	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76294	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Войкова	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
12810	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Водоканальная	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76228	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Ванцетти	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76310	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Бийская	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76327	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	Александра Матросова	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76237	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	6 пер. У.Громовой	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76390	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	137 Отд. Стр. Бригады	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
76288	41109	85.940036000000006	86.137431000000007	56.14396	56.029843	137 ОСБ	0103000020E610000001000000050000000344C18C297C5540DC813AE5D1034C400344C18C297C554051F701486D124C40399D64ABCB88554051F701486D124C40399D64ABCB885540DC813AE5D1034C400344C18C297C5540DC813AE5D1034C40
12409	41089	87.413713000000001	87.474654999999998	53.709342999999997	53.655512000000002	Коммунистическая	0103000020E61000000100000005000000863B17467ADA55405A1135D1E7D34A40863B17467ADA5540C1525DC0CBDA4A4081785DBF60DE5540C1525DC0CBDA4A4081785DBF60DE55405A1135D1E7D34A40863B17467ADA55405A1135D1E7D34A40
50338	16092	87.413713000000001	87.474654999999998	53.709342999999997	53.655512000000002	Дорожная	0103000020E61000000100000005000000863B17467ADA55405A1135D1E7D34A40863B17467ADA5540C1525DC0CBDA4A4081785DBF60DE5540C1525DC0CBDA4A4081785DBF60DE55405A1135D1E7D34A40863B17467ADA55405A1135D1E7D34A40
13267	41161	87.801784999999995	87.824332999999996	53.601911999999999	53.584221999999997	Алтын Шор	0103000020E61000000100000005000000185B087250F3554046CD57C9C7CA4A40185B087250F35540F488D1730BCD4A40DE0033DFC1F45540F488D1730BCD4A40DE0033DFC1F4554046CD57C9C7CA4A40185B087250F3554046CD57C9C7CA4A40
76258	4783	87.743528999999995	87.800940999999995	53.754038999999999	53.736407999999997	Бородинская	0103000020E610000001000000050000002AA8A8FA95EF5540A2410A9E42DE4A402AA8A8FA95EF55404B74965984E04A40A2410A9E42F355404B74965984E04A40A2410A9E42F35540A2410A9E42DE4A402AA8A8FA95EF5540A2410A9E42DE4A40
75827	4229	85.386215000000007	85.414942999999994	55.880035999999997	55.866667	Осенняя	0103000020E61000000100000005000000618E1EBFB7585540DFC2BAF1EEEE4B40618E1EBFB7585540BDA60705A5F04B4010AD156D8E5A5540BDA60705A5F04B4010AD156D8E5A5540DFC2BAF1EEEE4B40618E1EBFB7585540DFC2BAF1EEEE4B40
50368	3580	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	Ленинская	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
13633	3580	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	Куйбышева	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
50367	3580	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	Комарова	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
50365	3580	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	Заводская	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
75818	3580	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	Больничная	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
76147	3580	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	50 лет Советской власти	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
13124	41157	85.397847999999996	85.471491999999998	55.901294	55.857857000000003	Вторая	0103000020E61000000100000005000000DB3175577659554085D21742CEED4B40DB317557765955405F0A0F9A5DF34B40D714C8EC2C5E55405F0A0F9A5DF34B40D714C8EC2C5E554085D21742CEED4B40DB3175577659554085D21742CEED4B40
76015	4714	84.949005	84.965237999999999	56.074021000000002	56.061956000000002	братьев Сидельниковых	0103000020E6100000010000000500000064AF777FBC3C55403FE5982CEE074C4064AF777FBC3C5540CE1B278579094C40D0B69A75C63D5540CE1B278579094C40D0B69A75C63D55403FE5982CEE074C4064AF777FBC3C55403FE5982CEE074C40
12429	41094	85.116864000000007	85.140274000000005	55.821117999999998	55.806105000000002	Новая	0103000020E610000001000000050000001B8524B37A4755403012DA722EE74B401B8524B37A475540161406651AE94B40AA9ECC3FFA485540161406651AE94B40AA9ECC3FFA4855403012DA722EE74B401B8524B37A4755403012DA722EE74B40
76180	60778	85.436628999999996	85.457325999999995	55.946612999999999	55.935153	Железнодорожная	0103000020E610000001000000050000000DDFC2BAF15B5540CEE0EF17B3F74B400DDFC2BAF15B5540F67B629D2AF94B40126745D4445D5540F67B629D2AF94B40126745D4445D5540CEE0EF17B3F74B400DDFC2BAF15B5540CEE0EF17B3F74B40
76154	5537	84.977913000000001	85.010513000000003	55.763973999999997	55.747889999999998	М.Ракевича	0103000020E6100000010000000500000054556820963E5540B28009DCBADF4B4054556820963E5540457F68E6C9E14B40B4CBB73EAC405540457F68E6C9E14B40B4CBB73EAC405540B28009DCBADF4B4054556820963E5540B28009DCBADF4B40
12421	41092	85.828411000000003	85.843260000000001	55.966796000000002	55.958477000000002	Школьная	0103000020E61000000100000005000000632992AF04755540EE7BD45FAFFA4B40632992AF04755540AAF3A8F8BFFB4B409981CAF8F7755540AAF3A8F8BFFB4B409981CAF8F7755540EE7BD45FAFFA4B40632992AF04755540EE7BD45FAFFA4B40
76150	4680	85.006146999999999	85.031155999999996	55.934679000000003	55.924002999999999	пер.Школьный	0103000020E61000000100000005000000FCFD62B664405540F433F5BA45F64B40FCFD62B66440554006A1BC8FA3F74B40BF44BC75FE41554006A1BC8FA3F74B40BF44BC75FE415540F433F5BA45F64B40FCFD62B664405540F433F5BA45F64B40
76151	5278	85.312004999999999	85.329936000000004	56.049787000000002	56.037402999999998	Верхняя	0103000020E6100000010000000500000010CCD1E3F7535540DAE21A9FC9044C4010CCD1E3F75355400B62A06B5F064C407A71E2AB1D5555400B62A06B5F064C407A71E2AB1D555540DAE21A9FC9044C4010CCD1E3F7535540DAE21A9FC9044C40
75825	5368	84.945322000000004	84.980410000000006	55.754734999999997	55.734096000000001	Бениваленского	0103000020E610000001000000050000001E8CD827803C5540ED0F94DBF6DD4B401E8CD827803C5540C2120F289BE04B40F8AA9509BF3E5540C2120F289BE04B40F8AA9509BF3E5540ED0F94DBF6DD4B401E8CD827803C5540ED0F94DBF6DD4B40
75823	5368	84.945322000000004	84.980410000000006	55.754734999999997	55.734096000000001	Базарная	0103000020E610000001000000050000001E8CD827803C5540ED0F94DBF6DD4B401E8CD827803C5540C2120F289BE04B40F8AA9509BF3E5540C2120F289BE04B40F8AA9509BF3E5540ED0F94DBF6DD4B401E8CD827803C5540ED0F94DBF6DD4B40
75826	5265	85.104844999999997	85.151754999999994	56.061193000000003	56.038172000000003	Леонова	0103000020E610000001000000050000008B89CDC7B5465540BCCFF1D1E2044C408B89CDC7B546554040DF162CD5074C4049809A5AB649554040DF162CD5074C4049809A5AB6495540BCCFF1D1E2044C408B89CDC7B5465540BCCFF1D1E2044C40
75820	5105	85.478688000000005	85.508413000000004	55.713211999999999	55.696286000000001	Ленина	0103000020E61000000100000005000000363FFED2A25E5540D2544FE61FD94B40363FFED2A25E5540B08EE3874ADB4B401FF7ADD689605540B08EE3874ADB4B401FF7ADD689605540D2544FE61FD94B40363FFED2A25E5540D2544FE61FD94B40
76003	4096	85.209965999999994	85.225695000000002	55.674985999999997	55.665537999999998	Кирпичная	0103000020E6100000010000000500000067D13B15704D5540641F645930D54B4067D13B15704D554001A1F5F065D64B40BAF770C9714E554001A1F5F065D64B40BAF770C9714E5540641F645930D54B4067D13B15704D5540641F645930D54B40
76157	5188	85.463749000000007	85.502573999999996	55.835973000000003	55.823383	Солнечная	0103000020E6100000010000000500000060234910AE5D55408B8A389D64E94B4060234910AE5D554065ABCB2901EB4B407974232C2A60554065ABCB2901EB4B407974232C2A6055408B8A389D64E94B4060234910AE5D55408B8A389D64E94B40
76164	5674	84.942897000000002	84.957098999999999	55.843409000000001	55.830573999999999	Центральная	0103000020E61000000100000005000000C79FA86C583C55403674B33F50EA4B40C79FA86C583C554077137CD3F4EB4B4032022A1C413D554077137CD3F4EB4B4032022A1C413D55403674B33F50EA4B40C79FA86C583C55403674B33F50EA4B40
76153	5118	85.614108999999999	85.625230000000002	55.714013999999999	55.697265000000002	Молодежная	0103000020E6100000010000000500000079CBD58F4D6755409ED2C1FA3FD94B4079CBD58F4D6755406D718DCF64DB4B40999EB0C4036855406D718DCF64DB4B40999EB0C4036855409ED2C1FA3FD94B4079CBD58F4D6755409ED2C1FA3FD94B40
76155	4982	85.287068000000005	85.304316	55.837530000000001	55.826726000000001	Строительная	0103000020E610000001000000050000009AEE75525F5255405F605628D2E94B409AEE75525F5255409EB5DB2E34EB4B4092E9D0E9795355409EB5DB2E34EB4B4092E9D0E9795355405F605628D2E94B409AEE75525F5255405F605628D2E94B40
75845	4982	85.287068000000005	85.304316	55.837530000000001	55.826726000000001	Октябрьская	0103000020E610000001000000050000009AEE75525F5255405F605628D2E94B409AEE75525F5255409EB5DB2E34EB4B4092E9D0E9795355409EB5DB2E34EB4B4092E9D0E9795355405F605628D2E94B409AEE75525F5255405F605628D2E94B40
76156	4547	85.057440999999997	85.074625999999995	56.032910999999999	56.017617999999999	Больничная	0103000020E61000000100000005000000C51C041DAD43554014E97E4E41024C40C51C041DAD435540DE567A6D36044C409A5B21ACC6445540DE567A6D36044C409A5B21ACC644554014E97E4E41024C40C51C041DAD43554014E97E4E41024C40
76148	4614	85.019298000000006	85.029629	55.896816999999999	55.883707000000001	Береговая	0103000020E6100000010000000500000035B8AD2D3C415540861F9C4F1DF14B4035B8AD2D3C41554098BF42E6CAF24B40D8800871E541554098BF42E6CAF24B40D8800871E5415540861F9C4F1DF14B4035B8AD2D3C415540861F9C4F1DF14B40
75828	4936	85.196382999999997	85.226854000000003	55.875546	55.857436999999997	Мира	0103000020E61000000100000005000000629F008A914C5540AFB0E07EC0ED4B40629F008A914C554062122EE411F04B40E0BDA3C6844E554062122EE411F04B40E0BDA3C6844E5540AFB0E07EC0ED4B40629F008A914C5540AFB0E07EC0ED4B40
12396	41083	85.259210999999993	85.269596000000007	55.805123000000002	55.796542000000002	Клубная	0103000020E61000000100000005000000DCF0BBE996505540FAF19716F5E54B40DCF0BBE996505540F3203D450EE74B407AC8940F41515540F3203D450EE74B407AC8940F41515540FAF19716F5E54B40DCF0BBE996505540FAF19716F5E54B40
50079	4508	85.638964999999999	85.683503999999999	55.649804000000003	55.626477000000001	мкр.Молодежный	0103000020E61000000100000005000000799274CDE46855401D59F96530D04B40799274CDE4685540AE6708C72CD34B40DAAB8F87BE6B5540AE6708C72CD34B40DAAB8F87BE6B55401D59F96530D04B40799274CDE46855401D59F96530D04B40
76143	4083	85.216352999999998	85.238532000000006	55.724347000000002	55.711644999999997	Центральная	0103000020E610000001000000050000000ED940BAD84D554053AEF02E17DB4B400ED940BAD84D554055FA0967B7DC4B402BC3B81B444F554055FA0967B7DC4B402BC3B81B444F554053AEF02E17DB4B400ED940BAD84D554053AEF02E17DB4B40
76149	4395	85.334248000000002	85.367620000000002	55.925203000000003	55.919835999999997	40 лет Победы	0103000020E610000001000000050000003830B951645555407BD7A02FBDF54B403830B951645555409F94490D6DF64B40C1560916875755409F94490D6DF64B40C1560916875755407BD7A02FBDF54B403830B951645555407BD7A02FBDF54B40
76011	3973	85.403355000000005	85.424762000000001	55.759267999999999	55.750064000000002	Центральная	0103000020E61000000100000005000000666B7D91D059554017F4DE1802E04B40666B7D91D05955401D739EB12FE14B4059A5F44C2F5B55401D739EB12FE14B4059A5F44C2F5B554017F4DE1802E04B40666B7D91D059554017F4DE1802E04B40
13275	41164	85.224770000000007	85.239582999999996	55.939765999999999	55.929682	Победы	0103000020E61000000100000005000000CEC7B5A1624E554006D7DCD1FFF64B40CEC7B5A1624E554045F295404AF84B405D6BEF53554F554045F295404AF84B405D6BEF53554F554006D7DCD1FFF64B40CEC7B5A1624E554006D7DCD1FFF64B40
13315	4841	85.222210000000004	85.237579999999994	55.907525999999997	55.892279000000002	Центральная	0103000020E6100000010000000500000007B64AB0384E55402CF4C13236F24B4007B64AB0384E55408522DDCF29F44B40C18BBE82344F55408522DDCF29F44B40C18BBE82344F55402CF4C13236F24B4007B64AB0384E55402CF4C13236F24B40
75764	3965	85.356202999999994	85.384103999999994	55.739823000000001	55.728727999999997	Мира	0103000020E610000001000000050000002CEFAA07CC565540F9D687F546DD4B402CEFAA07CC56554010EA2285B2DE4B40D190F1289558554010EA2285B2DE4B40D190F12895585540F9D687F546DD4B402CEFAA07CC565540F9D687F546DD4B40
76146	1276	86.440927000000002	86.470840999999993	56.283749	56.263952000000003	Центральная	0103000020E61000000100000005000000193BE125389C55405EDBDB2DC9214C40193BE125389C5540E8A221E351244C406B274A42229E5540E8A221E351244C406B274A42229E55405EDBDB2DC9214C40193BE125389C55405EDBDB2DC9214C40
75839	41150	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Юбилейный	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
13027	41150	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Августовская	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
75892	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	проспект Ленина	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
76145	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Юбилейный	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
75862	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Юбилейная	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
75616	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Школьная	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
75784	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Трактовая	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
13609	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Пионерская	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
76152	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Переулок Логовой	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
75858	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Осоавиахимовская	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
76218	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Озерная	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
75902	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Ленина	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
76206	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Западная улица	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
76160	41250	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	Жуковского	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
13552	1163	85.966716000000005	85.987008000000003	56.188378	56.171914000000001	Пролетарская	0103000020E610000001000000050000004721C9ACDE7D5540BEDC274701164C404721C9ACDE7D554098A432C51C184C40FC389A232B7F554098A432C51C184C40FC389A232B7F5540BEDC274701164C404721C9ACDE7D5540BEDC274701164C40
75822	2454	86.089164999999994	86.116348000000002	56.416670000000003	56.396239000000001	Ленина	0103000020E61000000100000005000000A9BC1DE1B48555402B33A5F5B7324C40A9BC1DE1B4855540B79C4B7155354C401FBDE13E72875540B79C4B7155354C401FBDE13E728755402B33A5F5B7324C40A9BC1DE1B48555402B33A5F5B7324C40
13578	1738	86.167202000000003	86.193027999999998	56.090240999999999	56.077463000000002	Майская	0103000020E61000000100000005000000DA740470B38A554035D3BD4EEA094C40DA740470B38A554011E15F048D0B4C4096CD1C925A8C554011E15F048D0B4C4096CD1C925A8C554035D3BD4EEA094C40DA740470B38A554035D3BD4EEA094C40
76144	2343	86.236020999999994	86.271908999999994	56.192143999999999	56.173090999999999	Советская	0103000020E61000000100000005000000D40AD3F71A8F5540B01D8CD827164C40D40AD3F71A8F5540B20FB22C98184C403C9F01F566915540B20FB22C98184C403C9F01F566915540B01D8CD827164C40D40AD3F71A8F5540B01D8CD827164C40
75844	2343	86.236020999999994	86.271908999999994	56.192143999999999	56.173090999999999	Механическая	0103000020E61000000100000005000000D40AD3F71A8F5540B01D8CD827164C40D40AD3F71A8F5540B20FB22C98184C403C9F01F566915540B20FB22C98184C403C9F01F566915540B01D8CD827164C40D40AD3F71A8F5540B01D8CD827164C40
76132	1526	85.874736999999996	85.902010000000004	56.273004999999998	56.262461999999999	Таежная	0103000020E6100000010000000500000079E6E5B0FB775540AC38D55A98214C4079E6E5B0FB7755407E52EDD3F1224C408FAA2688BA7955407E52EDD3F1224C408FAA2688BA795540AC38D55A98214C4079E6E5B0FB775540AC38D55A98214C40
76134	2108	86.343773999999996	86.362324999999998	56.393059999999998	56.376933999999999	Сибирская	0103000020E61000000100000005000000C4CDA964009655400F60915F3F304C40C4CDA96400965540D1AE42CA4F324C407C61325530975540D1AE42CA4F324C407C613255309755400F60915F3F304C40C4CDA964009655400F60915F3F304C40
76251	6230	86.223813000000007	86.281647000000007	56.102378000000002	56.064585000000001	Металлургов	0103000020E61000000100000005000000DCDAC2F3528E5540F5673F5244084C40DCDAC2F3528E55403AEAE8B81A0D4C400F812381069255403AEAE8B81A0D4C400F81238106925540F5673F5244084C40DCDAC2F3528E5540F5673F5244084C40
13595	2444	86.347188000000003	86.379176999999999	56.232373000000003	56.223691000000002	Октябрьская	0103000020E6100000010000000500000013640454389655406CB41CE8A11C4C40136404543896554099BC0166BE1D4C404E999B6F4498554099BC0166BE1D4C404E999B6F449855406CB41CE8A11C4C4013640454389655406CB41CE8A11C4C40
76014	1060	86.101821999999999	86.117272999999997	56.181604999999998	56.174675000000001	Гагарина	0103000020E61000000100000005000000DA006C4084865540E3361AC05B164C40DA006C408486554021E527D53E174C400BED9C668187554021E527D53E174C400BED9C6681875540E3361AC05B164C40DA006C4084865540E3361AC05B164C40
75834	1862	86.450952000000001	86.483840000000001	56.178147000000003	56.159072000000002	Школьная	0103000020E610000001000000050000003604C765DC9C5540CBDAA6785C144C403604C765DC9C5540B5705985CD164C40C91F0C3CF79E5540B5705985CD164C40C91F0C3CF79E5540CBDAA6785C144C403604C765DC9C5540CBDAA6785C144C40
13576	1631	85.893906999999999	85.917271999999997	56.242939	56.232999	Школьная	0103000020E6100000010000000500000097AAB4C535795540178046E9D21D4C4097AAB4C53579554023F609A0181F4C4056629E95B47A554023F609A0181F4C4056629E95B47A5540178046E9D21D4C4097AAB4C535795540178046E9D21D4C40
76055	48283	85.804282000000001	85.809582000000006	56.275489	56.271531000000003	Зеленая	0103000020E61000000100000005000000BCB0355B79735540D36C1E87C1224C40BCB0355B7973554031B43A3943234C408A5B0531D073554031B43A3943234C408A5B0531D0735540D36C1E87C1224C40BCB0355B79735540D36C1E87C1224C40
76137	2569	86.182768999999993	86.194933000000006	56.533169000000001	56.520440000000001	Центральная	0103000020E610000001000000050000003F6EBF7CB28B5540DFC325C79D424C403F6EBF7CB28B5540DA1EBDE13E444C4051FA42C8798C5540DA1EBDE13E444C4051FA42C8798C5540DFC325C79D424C403F6EBF7CB28B5540DFC325C79D424C40
76139	2094	86.378629000000004	86.398274999999998	56.304650000000002	56.285153999999999	Школьная	0103000020E610000001000000050000004D1421753B9855406B2920ED7F244C404D1421753B985540FB5C6DC5FE264C401FF46C567D995540FB5C6DC5FE264C401FF46C567D9955406B2920ED7F244C404D1421753B9855406B2920ED7F244C40
76133	1989	86.440550000000002	86.456835999999996	56.12697	56.113306000000001	Набережная	0103000020E610000001000000050000002E90A0F8319C554065389ECF800E4C402E90A0F8319C55405CC98E8D40104C40ABE80FCD3C9D55405CC98E8D40104C40ABE80FCD3C9D554065389ECF800E4C402E90A0F8319C554065389ECF800E4C40
76140	937	86.157069000000007	86.167362999999995	56.184826000000001	56.169854000000001	Героев Соцтруда	0103000020E61000000100000005000000CA8D226B0D8A5540228C9FC6BD154C40CA8D226B0D8A5540AAB9DC60A8174C40DEE34C13B68A5540AAB9DC60A8174C40DEE34C13B68A5540228C9FC6BD154C40CA8D226B0D8A5540228C9FC6BD154C40
76284	60802	86.036398000000005	86.051947999999996	56.117395999999999	56.106138000000001	Тепличная	0103000020E61000000100000005000000F3E8465854825540726E13EE950D4C40F3E8465854825540325706D5060F4C40ED45B41D53835540325706D5060F4C40ED45B41D53835540726E13EE950D4C40F3E8465854825540726E13EE950D4C40
75817	1757	86.066823999999997	86.096773999999996	56.240037999999998	56.215702999999998	Садовая	0103000020E61000000100000005000000A0A52BD8468455401553E9279C1B4C40A0A52BD8468455400CE6AF90B91E4C409946938B318655400CE6AF90B91E4C409946938B318655401553E9279C1B4C40A0A52BD8468455401553E9279C1B4C40
76138	1503	85.895298999999994	85.921763999999996	56.387385000000002	56.370623000000002	Центральная	0103000020E610000001000000050000000E492D944C7955409D121093702F4C400E492D944C79554001FBE8D495314C4054A86E2EFE7A554001FBE8D495314C4054A86E2EFE7A55409D121093702F4C400E492D944C7955409D121093702F4C40
76136	1845	86.1006	86.118172000000001	56.307352000000002	56.286912000000001	Советская	0103000020E61000000100000005000000917EFB3A708655403C6A4C88B9244C40917EFB3A708655401B2E724F57274C4063D34A21908755401B2E724F57274C4063D34A21908755403C6A4C88B9244C40917EFB3A708655403C6A4C88B9244C40
13562	1402	85.942677000000003	85.976569999999995	56.328403999999999	56.310721999999998	Центральная	0103000020E61000000100000005000000406CE9D1547C5540E8120EBDC5274C40406CE9D1547C554013F06B24092A4C404D10751F807E554013F06B24092A4C404D10751F807E5540E8120EBDC5274C40406CE9D1547C5540E8120EBDC5274C40
76131	1398	86.353755000000007	86.375916000000004	56.430956999999999	56.419811000000003	Советская	0103000020E61000000100000005000000FAF202ECA396554023C0E95DBC354C40FAF202ECA3965540BB7D569929374C40C382FB010F985540BB7D569929374C40C382FB010F98554023C0E95DBC354C40FAF202ECA396554023C0E95DBC354C40
76142	1310	86.456450000000004	86.481549000000001	56.365153999999997	56.355598999999998	Центральная	0103000020E6100000010000000500000097900F7A369D5540C2BE9D44842D4C4097900F7A369D55407500C45DBD2E4C40FA9AE5B2D19E55407500C45DBD2E4C40FA9AE5B2D19E5540C2BE9D44842D4C4097900F7A369D5540C2BE9D44842D4C40
13548	928	86.100223	86.123427000000007	56.149321	56.138618999999998	Ленинградская	0103000020E61000000100000005000000A6D3BA0D6A86554057CD7344BE114C40A6D3BA0D6A86554092CD55F31C134C40611C5C3AE687554092CD55F31C134C40611C5C3AE687554057CD7344BE114C40A6D3BA0D6A86554057CD7344BE114C40
12606	41131	86.376653000000005	86.401634999999999	56.319803999999998	56.310343000000003	Арышева	0103000020E610000001000000050000002E3C2F151B98554072C5C551B9274C402E3C2F151B985540A3906456EF284C40747B4963B4995540A3906456EF284C40747B4963B499554072C5C551B9274C402E3C2F151B98554072C5C551B9274C40
12453	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	пр.Победы	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
13446	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	пр.Кузбасский	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
12483	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	б-р Металлургов	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50151	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Шоссейная	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
12472	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Фестивальная	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50063	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Строительная	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50346	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Осенняя	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50345	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Никитина	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
12523	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Московская	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
13404	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Мира	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50344	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Машиностроителей	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
12437	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Леонова	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50084	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Ленинградская	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
12379	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Ленина	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
69787	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Колхозная	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
12372	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Кирова	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
49991	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Исайченко	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50340	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Достоевского	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
50001	6960	84.820429000000004	84.997613000000001	55.758833000000003	55.686163000000001	Волгоградская	0103000020E6100000010000000500000029ECA2E881345540D55C6E30D4D74B4029ECA2E8813455401310937021E14B40204432E4D83F55401310937021E14B40204432E4D83F5540D55C6E30D4D74B4029ECA2E881345540D55C6E30D4D74B40
76129	32213	84.705831000000003	84.740820999999997	55.849528999999997	55.825285000000001	Сосновая	0103000020E610000001000000050000003160C9552C2D55408F705AF0A2E94B403160C9552C2D55407500C45DBDEC4B4029CC7B9C692F55407500C45DBDEC4B4029CC7B9C692F55408F705AF0A2E94B403160C9552C2D55408F705AF0A2E94B40
76119	30793	87.952360999999996	87.975617999999997	55.903433	55.885866999999998	Оренбурская	0103000020E61000000100000005000000183F8D7BF3FC554085CD001764F14B40183F8D7BF3FC554047904AB1A3F34B40E4D87A8670FE554047904AB1A3F34B40E4D87A8670FE554085CD001764F14B40183F8D7BF3FC554085CD001764F14B40
76127	6033	87.748999999999995	87.79759	55.752941	55.728676999999998	Совхозная	0103000020E610000001000000050000000E2DB29DEFEF5540772CB64945DD4B400E2DB29DEFEF5540A568E55E60E04B407767EDB60BF35540A568E55E60E04B407767EDB60BF35540772CB64945DD4B400E2DB29DEFEF5540772CB64945DD4B40
76121	30847	87.756501	87.774341000000007	56.139606999999998	56.116934000000001	Лесная	0103000020E610000001000000050000000B992B836AF055402EE57CB1F70E4C400B992B836AF0554076A565A4DE114C40EDBC8DCD8EF1554076A565A4DE114C40EDBC8DCD8EF155402EE57CB1F70E4C400B992B836AF055402EE57CB1F70E4C40
75814	6016	87.973633000000007	88.009754000000001	56.013506999999997	55.996319	Кирова	0103000020E610000001000000050000009C53C90050FE554014B1886187FF4B409C53C90050FE55402FA2ED98BA014C4055C03DCF9F0056402FA2ED98BA014C4055C03DCF9F00564014B1886187FF4B409C53C90050FE554014B1886187FF4B40
12418	41091	87.680261000000002	87.688552000000001	55.970951999999997	55.954697000000003	Трактовая	0103000020E61000000100000005000000A2EF6E6589EB55406F4BE48233FA4B40A2EF6E6589EB55402EFEB62748FC4B401B66683C11EC55402EFEB62748FC4B401B66683C11EC55406F4BE48233FA4B40A2EF6E6589EB55406F4BE48233FA4B40
76012	30132	87.680261000000002	87.688552000000001	55.970951999999997	55.954697000000003	Центральная	0103000020E61000000100000005000000A2EF6E6589EB55406F4BE48233FA4B40A2EF6E6589EB55402EFEB62748FC4B401B66683C11EC55402EFEB62748FC4B401B66683C11EC55406F4BE48233FA4B40A2EF6E6589EB55406F4BE48233FA4B40
76122	30115	87.509985	87.519875999999996	55.974820999999999	55.963340000000002	Центральная	0103000020E61000000100000005000000D61C2098A3E05540DE76A1B94EFB4B40D61C2098A3E055401D3A3DEFC6FC4B406B7EFCA545E155401D3A3DEFC6FC4B406B7EFCA545E15540DE76A1B94EFB4B40D61C2098A3E05540DE76A1B94EFB4B40
76111	30202	87.702637999999993	87.729641000000001	56.063006999999999	56.047339000000001	Молодежная	0103000020E6100000010000000500000051BB5F05F8EC5540A56950340F064C4051BB5F05F8EC5540A435069D10084C4087342A70B2EE5540A435069D10084C4087342A70B2EE5540A56950340F064C4051BB5F05F8EC5540A56950340F064C40
76141	30046	87.578410000000005	87.606042000000002	56.112704000000001	56.098320999999999	Молодежная	0103000020E610000001000000050000007B6B60AB04E5554048C153C8950C4C407B6B60AB04E555406F10AD156D0E4C4028806264C9E655406F10AD156D0E4C4028806264C9E6554048C153C8950C4C407B6B60AB04E5554048C153C8950C4C40
75813	30370	87.786081999999993	87.802871999999994	55.865243	55.852536000000001	Трактовая	0103000020E610000001000000050000005A7EE02A4FF25540D2544FE61FED4B405A7EE02A4FF25540E50B5A48C0EE4B40F1B73D4162F35540E50B5A48C0EE4B40F1B73D4162F35540D2544FE61FED4B405A7EE02A4FF25540D2544FE61FED4B40
76118	30640	87.249787999999995	87.289008999999993	55.889543000000003	55.873092	Центральная	0103000020E61000000100000005000000BABBCE86FCCF55401A33897AC1EF4B40BABBCE86FCCF554060B1868BDCF14B40FACF9A1F7FD2554060B1868BDCF14B40FACF9A1F7FD255401A33897AC1EF4B40BABBCE86FCCF55401A33897AC1EF4B40
12433	30469	87.889362000000006	87.913822999999994	55.915073999999997	55.904231000000003	Набережная	0103000020E610000001000000050000008813984EEBF85540C38366D7BDF34B408813984EEBF85540BFB5132521F54B4049D576137CFA5540BFB5132521F54B4049D576137CFA5540C38366D7BDF34B408813984EEBF85540C38366D7BDF34B40
76116	30745	88.079239000000001	88.126992999999999	55.964458	55.948149999999998	Советская	0103000020E610000001000000050000005664744012055640E8D9ACFA5CF94B405664744012055640CB2E185C73FB4B408A743FA720085640CB2E185C73FB4B408A743FA720085640E8D9ACFA5CF94B405664744012055640E8D9ACFA5CF94B40
76123	30956	87.838571000000002	87.857776999999999	55.759830999999998	55.744374000000001	Юбилейная	0103000020E61000000100000005000000F017B325ABF5554011FFB0A547DF4B40F017B325ABF5554055BE672442E14B40B49080D1E5F6554055BE672442E14B40B49080D1E5F6554011FFB0A547DF4B40F017B325ABF5554011FFB0A547DF4B40
76124	31052	87.675759999999997	87.705791000000005	55.750950000000003	55.739477999999998	Первомайская	0103000020E610000001000000050000007AFCDEA63FEB5540450E1137A7DE4B407AFCDEA63FEB554032772D211FE04B40EAB303AE2BED554032772D211FE04B40EAB303AE2BED5540450E1137A7DE4B407AFCDEA63FEB5540450E1137A7DE4B40
76010	30991	87.498683999999997	87.520576000000005	55.654462000000002	55.644759999999998	Школьная	0103000020E6100000010000000500000076C24B70EADF55406DE2E47E87D24B4076C24B70EADF5540C53C2B69C5D34B4048C5FF1D51E15540C53C2B69C5D34B4048C5FF1D51E155406DE2E47E87D24B4076C24B70EADF55406DE2E47E87D24B40
76120	30433	87.753356999999994	87.773478999999995	55.891914999999997	55.880550999999997	Кооперативная	0103000020E610000001000000050000009C4D470037F05540E4BA29E5B5F04B409C4D470037F05540EAE74D452AF24B40234910AE80F15540EAE74D452AF24B40234910AE80F15540E4BA29E5B5F04B409C4D470037F05540E4BA29E5B5F04B40
13372	41178	87.899790999999993	87.917057	56.039887	56.021557999999999	Октябрьская	0103000020E610000001000000050000000C8FFD2C96F95540CC7B9C69C2024C400C8FFD2C96F955408D4468041B054C4058E4D70FB1FA55408D4468041B054C4058E4D70FB1FA5540CC7B9C69C2024C400C8FFD2C96F95540CC7B9C69C2024C40
75816	5905	87.587159999999997	87.642199000000005	56.053753	56.016812999999999	м-р. Южный	0103000020E610000001000000050000003D61890794E55540E692AAED26024C403D61890794E55540EC87D860E1064C4088A1D5C919E95540EC87D860E1064C4088A1D5C919E95540E692AAED26024C403D61890794E55540E692AAED26024C40
75766	5905	87.587159999999997	87.642199000000005	56.053753	56.016812999999999	Советская	0103000020E610000001000000050000003D61890794E55540E692AAED26024C403D61890794E55540EC87D860E1064C4088A1D5C919E95540EC87D860E1064C4088A1D5C919E95540E692AAED26024C403D61890794E55540E692AAED26024C40
13341	41175	87.587159999999997	87.642199000000005	56.053753	56.016812999999999	Советская	0103000020E610000001000000050000003D61890794E55540E692AAED26024C403D61890794E55540EC87D860E1064C4088A1D5C919E95540EC87D860E1064C4088A1D5C919E95540E692AAED26024C403D61890794E55540E692AAED26024C40
76113	30574	87.384428	87.403273999999996	55.916092999999996	55.906396000000001	Центральна	0103000020E61000000100000005000000ABEAE5779AD85540D49CBCC804F44B40ABEAE5779AD85540198C118942F54B40EF54C03DCFD95540198C118942F54B40EF54C03DCFD95540D49CBCC804F44B40ABEAE5779AD85540D49CBCC804F44B40
76114	30241	87.901263999999998	87.925600000000003	55.992331	55.977308999999998	Октябрьская	0103000020E61000000100000005000000FA43334FAEF95540118B187618FD4B40FA43334FAEF955404BE7C3B304FF4B405E4BC8073DFB55404BE7C3B304FF4B405E4BC8073DFB5540118B187618FD4B40FA43334FAEF95540118B187618FD4B40
75920	30241	87.901263999999998	87.925600000000003	55.992331	55.977308999999998	Воронова	0103000020E61000000100000005000000FA43334FAEF95540118B187618FD4B40FA43334FAEF955404BE7C3B304FF4B405E4BC8073DFB55404BE7C3B304FF4B405E4BC8073DFB5540118B187618FD4B40FA43334FAEF95540118B187618FD4B40
76107	46367	89.195701	89.214988000000005	56.056528	56.031497999999999	Школьная	0103000020E61000000100000005000000D9B27C5D864C5640D8F15F2008044C40D9B27C5D864C564076A73B4F3C074C401442075DC24D564076A73B4F3C074C401442075DC24D5640D8F15F2008044C40D9B27C5D864C5640D8F15F2008044C40
76219	60793	89.251018999999999	89.267943000000002	55.956083	55.94811	Чулымская	0103000020E610000001000000050000002DEBFEB1105056405A8121AB5BF94B402DEBFEB1105056407BA180ED60FA4B404C8C65FA255156407BA180ED60FA4B404C8C65FA255156405A8121AB5BF94B402DEBFEB1105056405A8121AB5BF94B40
76017	60765	88.415604000000002	88.434809999999999	56.304659999999998	56.294331	Горская	0103000020E610000001000000050000008E058541991A5640789961A3AC254C408E058541991A56401E335019FF264C40527E52EDD31B56401E335019FF264C40527E52EDD31B5640789961A3AC254C408E058541991A5640789961A3AC254C40
75716	41259	88.471147000000002	88.547889999999995	56.130372000000001	56.094017999999998	Чехова	0103000020E61000000100000005000000F226BF45271E56401F9E25C8080C4C40F226BF45271E564035289A07B0104C408CF337A11023564035289A07B0104C408CF337A1102356401F9E25C8080C4C40F226BF45271E56401F9E25C8080C4C40
75850	41259	88.471147000000002	88.547889999999995	56.130372000000001	56.094017999999998	Чапаева	0103000020E61000000100000005000000F226BF45271E56401F9E25C8080C4C40F226BF45271E564035289A07B0104C408CF337A11023564035289A07B0104C408CF337A1102356401F9E25C8080C4C40F226BF45271E56401F9E25C8080C4C40
75588	41259	88.471147000000002	88.547889999999995	56.130372000000001	56.094017999999998	Советская	0103000020E61000000100000005000000F226BF45271E56401F9E25C8080C4C40F226BF45271E564035289A07B0104C408CF337A11023564035289A07B0104C408CF337A1102356401F9E25C8080C4C40F226BF45271E56401F9E25C8080C4C40
75838	41259	88.471147000000002	88.547889999999995	56.130372000000001	56.094017999999998	Радищева	0103000020E61000000100000005000000F226BF45271E56401F9E25C8080C4C40F226BF45271E564035289A07B0104C408CF337A11023564035289A07B0104C408CF337A1102356401F9E25C8080C4C40F226BF45271E56401F9E25C8080C4C40
76163	41259	88.471147000000002	88.547889999999995	56.130372000000001	56.094017999999998	Рабочая	0103000020E61000000100000005000000F226BF45271E56401F9E25C8080C4C40F226BF45271E564035289A07B0104C408CF337A11023564035289A07B0104C408CF337A1102356401F9E25C8080C4C40F226BF45271E56401F9E25C8080C4C40
13664	41259	88.471147000000002	88.547889999999995	56.130372000000001	56.094017999999998	Коммунальная	0103000020E61000000100000005000000F226BF45271E56401F9E25C8080C4C40F226BF45271E564035289A07B0104C408CF337A11023564035289A07B0104C408CF337A1102356401F9E25C8080C4C40F226BF45271E56401F9E25C8080C4C40
76105	28921	88.578657000000007	88.605328	55.925193	55.910220000000002	Ленина	0103000020E610000001000000050000007FA65EB7082556402315C61682F44B407FA65EB7082556407BBE66B96CF64B4099D6A6B1BD2656407BBE66B96CF64B4099D6A6B1BD2656402315C61682F44B407FA65EB7082556402315C61682F44B40
75833	29257	88.670760999999999	88.698393999999993	56.081797999999999	56.059192000000003	Пушкина	0103000020E61000000100000005000000AA9B8BBFED2A5640A9177C9A93074C40AA9B8BBFED2A564069705B5B780A4C403F6EBF7CB22C564069705B5B780A4C403F6EBF7CB22C5640A9177C9A93074C40AA9B8BBFED2A5640A9177C9A93074C40
13292	41166	88.532393999999996	88.583813000000006	56.216558999999997	56.199812000000001	Кирова	0103000020E610000001000000050000008BA548BE1222564097AC8A7093194C408BA548BE12225640C5538F34B81B4C40B37E33315D255640C5538F34B81B4C40B37E33315D25564097AC8A7093194C408BA548BE1222564097AC8A7093194C40
76099	27949	89.313614000000001	89.343491999999998	55.848488000000003	55.830765999999997	Советская	0103000020E6100000010000000500000056647440125456407A50508A56EA4B405664744012545640348639419BEC4B40029CDEC5FB555640348639419BEC4B40029CDEC5FB5556407A50508A56EA4B4056647440125456407A50508A56EA4B40
13097	41154	88.569385999999994	88.583364000000003	56.140433999999999	56.133170999999997	Московская	0103000020E610000001000000050000003733FAD17024564047E350BF0B114C403733FAD1702456408C9FC6BDF9114C407B6AF5D5552556408C9FC6BDF9114C407B6AF5D55525564047E350BF0B114C403733FAD17024564047E350BF0B114C40
75939	29132	88.452164999999994	88.467769000000004	56.345109999999998	56.327689999999997	Береговая	0103000020E6100000010000000500000055D97745F01C5640F59CF4BEF1294C4055D97745F01C5640E3C281902C2C4C404A4563EDEF1D5640E3C281902C2C4C404A4563EDEF1D5640F59CF4BEF1294C4055D97745F01C5640F59CF4BEF1294C40
76100	28136	88.259772999999996	88.271972000000005	56.000225	55.994154000000002	Центральная	0103000020E6100000010000000500000090D8EE1EA01056400398327040FF4B4090D8EE1EA010564020D26F5F07004C40605B3FFD6711564020D26F5F07004C40605B3FFD671156400398327040FF4B4090D8EE1EA01056400398327040FF4B40
76117	46244	88.332851000000005	88.357500999999999	56.369351999999999	56.361882999999999	Курская	0103000020E6100000010000000500000038DC476E4D1556403BFDA02E522E4C4038DC476E4D155640295B24ED462F4C4063D2DF4BE1165640295B24ED462F4C4063D2DF4BE11656403BFDA02E522E4C4038DC476E4D1556403BFDA02E522E4C40
75811	46122	88.553027999999998	88.590191000000004	56.046920999999998	56.026432999999997	Советская	0103000020E610000001000000050000006D718DCF642356408044132862034C406D718DCF64235640703FE08101064C4030D978B0C5255640703FE08101064C4030D978B0C52556408044132862034C406D718DCF642356408044132862034C40
76106	45899	88.403495000000007	88.436291999999995	56.141683	56.130747999999997	Почаевская	0103000020E610000001000000050000005F46B1DCD21956403A02B859BC104C405F46B1DCD219564018B325AB22124C4069E04735EC1B564018B325AB22124C4069E04735EC1B56403A02B859BC104C405F46B1DCD21956403A02B859BC104C40
76101	27930	89.213407000000004	89.236699999999999	55.886139999999997	55.875808999999997	Молодежная	0103000020E61000000100000005000000336FD575A84D56406F4562821AF04B40336FD575A84D5640B6D617096DF14B40A5BDC117264F5640B6D617096DF14B40A5BDC117264F56406F4562821AF04B40336FD575A84D56406F4562821AF04B40
75952	60756	88.139498000000003	89.388892999999996	56.457999999999998	55.702697999999998	Мира	0103000020E61000000100000005000000E0F60489ED085640787B1002F2D94B40E0F60489ED085640B4C876BE9F3A4C402C29779FE3585640B4C876BE9F3A4C402C29779FE3585640787B1002F2D94B40E0F60489ED085640787B1002F2D94B40
13116	41156	89.071130999999994	89.107612000000003	55.869971	55.848948	Пролетарская	0103000020E61000000100000005000000D5AE09698D4456409700FC53AAEC4B40D5AE09698D445640F5BBB0355BEF4B400F2A711DE3465640F5BBB0355BEF4B400F2A711DE34656409700FC53AAEC4B40D5AE09698D4456409700FC53AAEC4B40
75915	60751	88.999904000000001	89.021850000000001	56.092731999999998	56.082506000000002	Центральная	0103000020E61000000100000005000000EFC8586DFE3F5640A5DC7D8E8F0A4C40EFC8586DFE3F564076A565A4DE0B4C40BADA8AFD6541564076A565A4DE0B4C40BADA8AFD65415640A5DC7D8E8F0A4C40EFC8586DFE3F5640A5DC7D8E8F0A4C40
76110	28281	88.533597999999998	88.567266000000004	56.164110000000001	56.133091	Советская	0103000020E6100000010000000500000081CD3978262256402B323A2009114C4081CD3978262256402979758E01154C407F880D164E2456402979758E01154C407F880D164E2456402B323A2009114C4081CD3978262256402B323A2009114C40
13254	41158	88.869999000000007	88.906487999999996	55.856487000000001	55.841478000000002	Новая	0103000020E6100000010000000500000060234910AE375640D926158DB5EB4B4060234910AE3756407E39B35DA1ED4B40DA8D3EE6033A56407E39B35DA1ED4B40DA8D3EE6033A5640D926158DB5EB4B4060234910AE375640D926158DB5EB4B40
75808	45774	88.383633000000003	88.407735000000002	56.075152000000003	56.064449000000003	Советская	0103000020E61000000100000005000000A62A6D718D18564045A165DD3F084C40A62A6D718D185640501DAB949E094C40D09B8A54181A5640501DAB949E094C40D09B8A54181A564045A165DD3F084C40A62A6D718D18564045A165DD3F084C40
75643	27876	89.115031999999999	89.147892999999996	55.954506000000002	55.936937999999998	Рабочая	0103000020E61000000100000005000000957F2DAF5C47564098309A95EDF74B40957F2DAF5C475640FBEAAA402DFA4B40AB93331477495640FBEAAA402DFA4B40AB9333147749564098309A95EDF74B40957F2DAF5C47564098309A95EDF74B40
75615	60706	88.991378999999995	89.102384000000001	56.079583	56.057569000000001	Советская	0103000020E610000001000000050000003CBCE7C0723F5640B821C66B5E074C403CBCE7C0723F5640A62897C62F0A4C408EE89E758D465640A62897C62F0A4C408EE89E758D465640B821C66B5E074C403CBCE7C0723F5640B821C66B5E074C40
12364	41074	89.173835999999994	89.200075999999996	55.756639	55.744323000000001	Школьная	0103000020E6100000010000000500000084B70721204B56408F54DFF945DF4B4084B70721204B564067F0F78BD9E04B40BA2D910BCE4C564067F0F78BD9E04B40BA2D910BCE4C56408F54DFF945DF4B4084B70721204B56408F54DFF945DF4B40
76102	45755	88.312755999999993	88.327433999999997	56.044417000000003	56.037512999999997	Наберажная	0103000020E610000001000000050000002DE8BD31041456406116DA39CD044C402DE8BD31041456407731CD74AF054C404D66BCADF41456407731CD74AF054C404D66BCADF41456406116DA39CD044C402DE8BD31041456406116DA39CD044C40
76108	46189	88.631352000000007	88.662991000000005	56.317082999999997	56.299930000000003	Школьная	0103000020E61000000100000005000000E9103812682856406E8B321B64264C40E9103812682856400C8FFD2C96284C40B6A2CD716E2A56400C8FFD2C96284C40B6A2CD716E2A56406E8B321B64264C40E9103812682856406E8B321B64264C40
76109	28011	88.377075000000005	88.408732000000001	56.020420999999999	56.004756	Средняя	0103000020E61000000100000005000000E9482EFF21185640DA3A38D89B004C40E9482EFF211856406893C3279D024C40093543AA281A56406893C3279D024C40093543AA281A5640DA3A38D89B004C40E9482EFF21185640DA3A38D89B004C40
12335	41068	88.753263000000004	88.785162	56.136220999999999	56.123227	Верхняя	0103000020E610000001000000050000005C92037635305640FA7DFFE6C50F4C405C92037635305640A30392B06F114C40F7031E1840325640A30392B06F114C40F7031E1840325640FA7DFFE6C50F4C405C92037635305640FA7DFFE6C50F4C40
12351	41072	88.621326999999994	88.646739999999994	56.202705999999999	56.191498000000003	Центральная	0103000020E61000000100000005000000CB4752D2C3275640ED9FA70183184C40CB4752D2C3275640FB592C45F2194C40F6402B3064295640FB592C45F2194C40F6402B3064295640ED9FA70183184C40CB4752D2C3275640ED9FA70183184C40
76197	60786	88.778784000000002	88.801447999999993	55.910341000000003	55.898003000000003	Некрасова	0103000020E610000001000000050000007AA9D898D7315640DE5A26C3F1F24B407AA9D898D73156409E9ACB0D86F44B40745C8DEC4A3356409E9ACB0D86F44B40745C8DEC4A335640DE5A26C3F1F24B407AA9D898D7315640DE5A26C3F1F24B40
76112	27788	88.782861999999994	88.814249000000004	56.085636000000001	56.073433999999999	Центральная	0103000020E61000000100000005000000FED137691A3256400D350A4966094C40FED137691A3256401DAED51EF60A4C403F73D6A71C3456401DAED51EF60A4C403F73D6A71C3456400D350A4966094C40FED137691A3256400D350A4966094C40
50362	26579	85.212875999999994	85.241640000000004	55.375030000000002	55.355637999999999	Максима Горького	0103000020E610000001000000050000009C86A8C29F4D5540809BC58B85AD4B409C86A8C29F4D55406B82A8FB00B04B40F3599E07774F55406B82A8FB00B04B40F3599E07774F5540809BC58B85AD4B409C86A8C29F4D5540809BC58B85AD4B40
75744	27341	85.846862000000002	85.869292999999999	55.162875	55.148848000000001	м-он Дружба	0103000020E61000000100000005000000698EACFC327655409A0986730D934B40698EACFC32765540022B8716D9944B4012691B7FA2775540022B8716D9944B4012691B7FA27755409A0986730D934B40698EACFC327655409A0986730D934B40
75949	27588	85.486395000000002	85.512842000000006	55.150534999999998	55.136746000000002	пер.Школьный	0103000020E61000000100000005000000077C7E18215F5540EEED96E480914B40077C7E18215F5540A1F31ABB44934B40FA804067D2605540A1F31ABB44934B40FA804067D2605540EEED96E480914B40077C7E18215F5540EEED96E480914B40
75806	26409	85.331695999999994	85.357909000000006	55.251849999999997	55.239060000000002	Советская	0103000020E61000000100000005000000B20DDC813A55554011E4A084999E4B40B20DDC813A555540B1BFEC9E3CA04B406C7C26FBE7565540B1BFEC9E3CA04B406C7C26FBE756554011E4A084999E4B40B20DDC813A55554011E4A084999E4B40
76088	27003	85.414385999999993	85.447579000000005	55.523417000000002	55.513182999999998	Школьная	0103000020E61000000100000005000000E57ADB4C855A55407CEE04FBAFC14B40E57ADB4C855A5540D1950854FFC24B4017D86322A55C5540D1950854FFC24B4017D86322A55C55407CEE04FBAFC14B40E57ADB4C855A55407CEE04FBAFC14B40
13611	26156	84.980868000000001	85.004782000000006	55.231858000000003	55.21275	Красная	0103000020E61000000100000005000000596C938AC63E5540AC1C5A643B9B4B40596C938AC63E554072A8DF85AD9D4B40026729594E40554072A8DF85AD9D4B40026729594E405540AC1C5A643B9B4B40596C938AC63E5540AC1C5A643B9B4B40
76006	26035	85.245188999999996	85.270691999999997	55.141413	55.122148000000003	Молодежная	0103000020E61000000100000005000000B115342DB14F5540CBA2B08BA28F4B40B115342DB14F5540581D39D219924B407CD2890453515540581D39D219924B407CD2890453515540CBA2B08BA28F4B40B115342DB14F5540CBA2B08BA28F4B40
75807	27442	85.755449999999996	85.785893999999999	55.131079	55.117401000000001	Малыхина	0103000020E61000000100000005000000D8F0F44A5970554044C2F7FE068F4B40D8F0F44A59705540A0185932C7904B40D90759164C725540A0185932C7904B40D90759164C72554044C2F7FE068F4B40D8F0F44A5970554044C2F7FE068F4B40
50162	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	м-он Солнечный	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
12656	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	м-он Красная Горка	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
50360	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Топкинская	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
12304	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Революции	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
50161	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Пролетарская	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
12648	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Пионерская	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
12640	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Микрорайон	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
12568	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Максима Горького	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
50163	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Кузнецкая	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
50023	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Калинина	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
50359	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Заводская	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
12678	24390	85.575363999999993	85.665969000000004	55.297333000000002	55.255127999999999	Алма-Атинская	0103000020E61000000100000005000000EDD286C3D26455409E25C808A8A04B40EDD286C3D2645540C382FB010FA64B4097C9703C9F6A5540C382FB010FA64B4097C9703C9F6A55409E25C808A8A04B40EDD286C3D26455409E25C808A8A04B40
76087	26834	85.484122999999997	85.511018000000007	55.350264000000003	55.342467999999997	Центральная	0103000020E61000000100000005000000730F09DFFB5E554098F6CDFDD5AB4B40730F09DFFB5E5540AB7B6473D5AC4B40B66AD784B4605540AB7B6473D5AC4B40B66AD784B460554098F6CDFDD5AB4B40730F09DFFB5E554098F6CDFDD5AB4B40
13661	25880	85.193310999999994	85.208186999999995	55.208004000000003	55.199793999999997	Майская	0103000020E6100000010000000500000040BD19355F4C5540F0F78BD992994B4040BD19355F4C5540F6B704E09F9A4B40F31C91EF524D5540F6B704E09F9A4B40F31C91EF524D5540F0F78BD992994B4040BD19355F4C5540F0F78BD992994B40
76086	26722	85.324698999999995	85.350156999999996	55.395333000000001	55.376514	Школьная	0103000020E61000000100000005000000CF8250DEC75455403A3E5A9C31B04B40CF8250DEC7545540C90391459AB24B40CADDE7F868565540C90391459AB24B40CADDE7F8685655403A3E5A9C31B04B40CF8250DEC75455403A3E5A9C31B04B40
76082	26353	84.995304000000004	85.008285000000001	55.277467000000001	55.266916999999999	Леонова	0103000020E61000000100000005000000FE648C0FB33F55408BDF14562AA24B40FE648C0FB33F5540105CE50984A34B400803CFBD87405540105CE50984A34B400803CFBD874055408BDF14562AA24B40FE648C0FB33F55408BDF14562AA24B40
12703	41138	85.416848000000002	85.446680999999998	55.358063999999999	55.347422999999999	Ленина	0103000020E61000000100000005000000CBD93BA3AD5A554069705B5B78AC4B40CBD93BA3AD5A5540FEEF880AD5AD4B40A7AFE76B965C5540FEEF880AD5AD4B40A7AFE76B965C554069705B5B78AC4B40CBD93BA3AD5A554069705B5B78AC4B40
12766	41140	85.300883999999996	85.326476999999997	55.491956999999999	55.477137999999997	Центральная	0103000020E61000000100000005000000F0F8F6AE41535540E4D6A4DB12BD4B40F0F8F6AE41535540E6046D72F8BE4B405B79C9FFE4545540E6046D72F8BE4B405B79C9FFE4545540E4D6A4DB12BD4B40F0F8F6AE41535540E4D6A4DB12BD4B40
76092	27411	85.980504999999994	86.002217000000002	55.091071999999997	55.077246000000002	Центральная	0103000020E6100000010000000500000020240B98C07E554098DF6932E3894B4020240B98C07E554068CA4E3FA88B4B40B29FC5522480554068CA4E3FA88B4B40B29FC5522480554098DF6932E3894B4020240B98C07E554098DF6932E3894B40
75805	27077	85.206247000000005	85.240696999999997	55.436872000000001	55.426166000000002	Центральная	0103000020E610000001000000050000007BF99D26334D55406555849B8CB64B407BF99D26334D5540E144F46BEBB74B40B3CF6394674F5540E144F46BEBB74B40B3CF6394674F55406555849B8CB64B407BF99D26334D55406555849B8CB64B40
12802	41142	85.589907999999994	85.603446000000005	55.327238999999999	55.315950000000001	Центральная	0103000020E6100000010000000500000085E97B0DC1655540EA95B20C71A84B4085E97B0DC1655540E57CB1F7E2A94B40BBB9F8DB9E665540E57CB1F7E2A94B40BBB9F8DB9E665540EA95B20C71A84B4085E97B0DC1655540EA95B20C71A84B40
76103	27635	85.555628999999996	85.578536	55.182341000000001	55.172716999999999	Центральная	0103000020E6100000010000000500000063EDEF6C8F6355404B3B35971B964B4063EDEF6C8F63554027DC2BF356974B40C1E3DBBB0665554027DC2BF356974B40C1E3DBBB066555404B3B35971B964B4063EDEF6C8F6355404B3B35971B964B40
76091	27287	85.602942999999996	85.637698999999998	55.565361000000003	55.542487000000001	Центральная	0103000020E6100000010000000500000089963C9E96665540A9C0C93670C54B4089963C9E9666554089B7CEBF5DC84B40486C770FD068554089B7CEBF5DC84B40486C770FD0685540A9C0C93670C54B4089963C9E96665540A9C0C93670C54B40
76115	27568	85.568258999999998	85.590329999999994	55.241827000000001	55.232858999999998	Центральная	0103000020E61000000100000005000000172AFF5A5E64554025CADE52CE9D4B40172AFF5A5E6455401825E82FF49E4B4040F67AF7C76555401825E82FF49E4B4040F67AF7C765554025CADE52CE9D4B40172AFF5A5E64554025CADE52CE9D4B40
76094	25954	85.280671999999996	85.300246000000001	55.188102999999998	55.175848000000002	Строителей	0103000020E61000000100000005000000C939B187F65155409488F02F82964B40C939B187F6515540C6A354C213984B404FB0FF3A37535540C6A354C213984B404FB0FF3A375355409488F02F82964B40C939B187F65155409488F02F82964B40
12664	41137	85.175983000000002	85.218491	55.275230999999998	55.264245000000003	Кооперативная	0103000020E61000000100000005000000BA69334E434B5540D690B8C7D2A14B40BA69334E434B554035ECF7C43AA34B401ADEACC1FB4D554035ECF7C43AA34B401ADEACC1FB4D5540D690B8C7D2A14B40BA69334E434B5540D690B8C7D2A14B40
76093	26636	85.171069000000003	85.183464999999998	55.379716000000002	55.373894	Центральная	0103000020E61000000100000005000000011764CBF24A5540D71533C2DBAF4B40011764CBF24A55404CE2AC889AB04B407BBDFBE3BD4B55404CE2AC889AB04B407BBDFBE3BD4B5540D71533C2DBAF4B40011764CBF24A5540D71533C2DBAF4B40
76042	60767	85.013261999999997	85.021507999999997	55.336559000000001	55.326379000000003	Свободная	0103000020E61000000100000005000000E411DC48D9405540F48C7DC9C6A94B40E411DC48D94055405516855D14AB4B408D261763604155405516855D14AB4B408D26176360415540F48C7DC9C6A94B40E411DC48D9405540F48C7DC9C6A94B40
76084	26552	85.249033999999995	85.263666999999998	55.239527000000002	55.227950999999997	Нагорного	0103000020E61000000100000005000000E4654D2CF04F5540950B957F2D9D4B40E4654D2CF04F554027C11BD2A89E4B4034828DEBDF50554027C11BD2A89E4B4034828DEBDF505540950B957F2D9D4B40E4654D2CF04F5540950B957F2D9D4B40
76089	26837	85.362257	85.375929999999997	55.330275999999998	55.320785000000001	Новая	0103000020E61000000100000005000000D0EFFB372F57554010069E7B0FA94B40D0EFFB372F575540AC53E57B46AA4B4075E5B33C0F585540AC53E57B46AA4B4075E5B33C0F58554010069E7B0FA94B40D0EFFB372F57554010069E7B0FA94B40
76097	26136	85.047982000000005	85.070098000000002	55.151909000000003	55.139406000000001	Клубная	0103000020E61000000100000005000000FD32182312435540DF6E490ED8914B40FD32182312435540EA7B0DC171934B40F660527C7C445540EA7B0DC171934B40F660527C7C445540DF6E490ED8914B40FD32182312435540DF6E490ED8914B40
76096	27485	85.689756000000003	85.706393000000006	55.198405999999999	55.190677999999998	Клубная	0103000020E61000000100000005000000118E59F6246C55408908FF2268984B40118E59F6246C554043AA285E65994B40E547FC8A356D554043AA285E65994B40E547FC8A356D55408908FF2268984B40118E59F6246C55408908FF2268984B40
50364	27125	85.511889999999994	85.556482000000003	55.469662999999997	55.444496999999998	Центральная	0103000020E61000000100000005000000904946CEC2605540C6151747E5B84B40904946CEC26055401492CCEA1DBC4B4003B4AD669D6355401492CCEA1DBC4B4003B4AD669D635540C6151747E5B84B40904946CEC2605540C6151747E5B84B40
75809	27187	85.690870000000004	85.7346	55.535227999999996	55.512740000000001	Рабочая	0103000020E6100000010000000500000067F2CD36376C5540EFACDD76A1C14B4067F2CD36376C5540A5F3E15982C44B4010E9B7AF036F5540A5F3E15982C44B4010E9B7AF036F5540EFACDD76A1C14B4067F2CD36376C5540EFACDD76A1C14B40
13654	25833	85.194901000000002	85.216037999999998	55.162633	55.150416999999997	Советская	0103000020E610000001000000050000004B3D0B42794C554097E13FDD40934B404B3D0B42794C55400C207C28D1944B405E2C0C91D34D55400C207C28D1944B405E2C0C91D34D554097E13FDD40934B404B3D0B42794C554097E13FDD40934B40
12329	41065	85.383987000000005	85.400453999999996	55.213766999999997	55.204191999999999	Магистральная	0103000020E61000000100000005000000B5C5353E935855406B0DA5F6229A4B40B5C5353E9358554065FB90B75C9B4B405A63D009A159554065FB90B75C9B4B405A63D009A15955406B0DA5F6229A4B40B5C5353E935855406B0DA5F6229A4B40
76081	26204	85.035000999999994	85.067717999999999	55.364972000000002	55.356344	Новая	0103000020E61000000100000005000000F294D5743D4255401B1021AE9CAD4B40F294D5743D42554055FA0967B7AE4B406FD6E07D5544554055FA0967B7AE4B406FD6E07D554455401B1021AE9CAD4B40F294D5743D4255401B1021AE9CAD4B40
12563	41120	87.630691999999996	87.661810000000003	55.223751	55.197245000000002	Леонова	0103000020E610000001000000050000005376FA415DE855405726FC523F994B405376FA415DE8554041B96DDFA39C4B409C8A54185BEA554041B96DDFA39C4B409C8A54185BEA55405726FC523F994B405376FA415DE855405726FC523F994B40
76080	24542	88.330326999999997	88.345230000000001	55.745443000000002	55.735205999999998	Ленина	0103000020E61000000100000005000000177FDB132415564057E9EE3A1BDE4B40177FDB13241556401D041DAD6ADF4B4047E6913F181656401D041DAD6ADF4B4047E6913F1816564057E9EE3A1BDE4B40177FDB132415564057E9EE3A1BDE4B40
76072	24004	88.285347999999999	88.309549000000004	55.892496000000001	55.872238000000003	Советская	0103000020E61000000100000005000000A8FE4124431256400B2AAA7EA5EF4B40A8FE412443125640C9E7154F3DF24B409CE09BA6CF135640C9E7154F3DF24B409CE09BA6CF1356400B2AAA7EA5EF4B40A8FE4124431256400B2AAA7EA5EF4B40
76068	23762	88.672844999999995	88.699274000000003	55.826037999999997	55.807046	Центральная	0103000020E61000000100000005000000BC9179E40F2B56400E2F88484DE74B40BC9179E40F2B56406AA0F99CBBE94B405C3CBCE7C02C56406AA0F99CBBE94B405C3CBCE7C02C56400E2F88484DE74B40BC9179E40F2B56400E2F88484DE74B40
76074	24285	88.435492999999994	88.463223999999997	55.798423999999997	55.788814000000002	Береговая	0103000020E61000000100000005000000C328081EDF1B564040506EDBF7E44B40C328081EDF1B5640B62BF4C132E64B403AAE4676A51D5640B62BF4C132E64B403AAE4676A51D564040506EDBF7E44B40C328081EDF1B564040506EDBF7E44B40
50078	22614	88.285230999999996	88.336543000000006	55.782228000000003	55.739548999999997	Терешковой	0103000020E610000001000000050000008B338639411256400E65A88AA9DE4B408B33863941125640FC010F0C20E44B40A8ACA6EB89155640FC010F0C20E44B40A8ACA6EB891556400E65A88AA9DE4B408B338639411256400E65A88AA9DE4B40
75799	22614	88.285230999999996	88.336543000000006	55.782228000000003	55.739548999999997	Октябрьская	0103000020E610000001000000050000008B338639411256400E65A88AA9DE4B408B33863941125640FC010F0C20E44B40A8ACA6EB89155640FC010F0C20E44B40A8ACA6EB891556400E65A88AA9DE4B408B338639411256400E65A88AA9DE4B40
12484	22614	88.285230999999996	88.336543000000006	55.782228000000003	55.739548999999997	Ленина	0103000020E610000001000000050000008B338639411256400E65A88AA9DE4B408B33863941125640FC010F0C20E44B40A8ACA6EB89155640FC010F0C20E44B40A8ACA6EB891556400E65A88AA9DE4B408B338639411256400E65A88AA9DE4B40
12469	41103	88.285230999999996	88.336543000000006	55.782228000000003	55.739548999999997	Заводская	0103000020E610000001000000050000008B338639411256400E65A88AA9DE4B408B33863941125640FC010F0C20E44B40A8ACA6EB89155640FC010F0C20E44B40A8ACA6EB891556400E65A88AA9DE4B408B338639411256400E65A88AA9DE4B40
13439	41103	88.285230999999996	88.336543000000006	55.782228000000003	55.739548999999997	Гагарина	0103000020E610000001000000050000008B338639411256400E65A88AA9DE4B408B33863941125640FC010F0C20E44B40A8ACA6EB89155640FC010F0C20E44B40A8ACA6EB891556400E65A88AA9DE4B408B338639411256400E65A88AA9DE4B40
75803	24186	88.599290999999994	88.637703000000002	55.604793000000001	55.585234999999997	Калинина	0103000020E610000001000000050000006072A3C85A265640BEBC00FBE8CA4B406072A3C85A265640C4EC65DB69CD4B40E9633E20D0285640C4EC65DB69CD4B40E9633E20D0285640BEBC00FBE8CA4B406072A3C85A265640BEBC00FBE8CA4B40
76211	60792	89.005212999999998	89.041872999999995	55.699486999999998	55.685411000000002	Новая	0103000020E61000000100000005000000E620E86855405640CAA8328CBBD74B40E620E86855405640137D3ECA88D94B407765170CAE425640137D3ECA88D94B407765170CAE425640CAA8328CBBD74B40E620E86855405640CAA8328CBBD74B40
76062	23116	88.268945000000002	88.281890000000004	55.697477999999997	55.688999000000003	Клубная	0103000020E610000001000000050000000EDB16653611564005FD851E31D84B400EDB166536115640F9D687F546D94B4072C45A7C0A125640F9D687F546D94B4072C45A7C0A12564005FD851E31D84B400EDB16653611564005FD851E31D84B40
75804	6457	88.463897000000003	88.486570999999998	55.332253000000001	55.316522999999997	Школьная	0103000020E610000001000000050000009AED0A7DB01D564045B75ED383A84B409AED0A7DB01D5640BB7F2C4487AA4B40A60BB1FA231F5640BB7F2C4487AA4B40A60BB1FA231F564045B75ED383A84B409AED0A7DB01D564045B75ED383A84B40
75912	23521	88.106223999999997	88.137674000000004	55.497622999999997	55.481265	Октябрьская	0103000020E610000001000000050000003883BF5FCC065640CFDA6D179ABD4B403883BF5FCC065640635E471CB2BF4B409CE09BA6CF085640635E471CB2BF4B409CE09BA6CF085640CFDA6D179ABD4B403883BF5FCC065640CFDA6D179ABD4B40
76007	23330	88.030325000000005	88.056124999999994	55.606755999999997	55.590577000000003	Советская	0103000020E6100000010000000500000014D044D8F00156408962F20698CB4B4014D044D8F00156406D533C2EAACD4B403BDF4F8D970356406D533C2EAACD4B403BDF4F8D970356408962F20698CB4B4014D044D8F00156408962F20698CB4B40
76070	23923	88.196909000000005	88.214883999999998	55.932082000000001	55.919367000000001	Советская	0103000020E6100000010000000500000070D234289A0C5640C5025FD1ADF54B4070D234289A0C56405B9885764EF74B40C11BD2A8C00D56405B9885764EF74B40C11BD2A8C00D5640C5025FD1ADF54B4070D234289A0C5640C5025FD1ADF54B40
76069	23857	88.117947000000001	88.145129999999995	55.801141000000001	55.789825999999998	Советская	0103000020E6100000010000000500000053EA92718C075640E7C3B30419E54B4053EA92718C0756400C3ECDC98BE64B40C8EA56CF490956400C3ECDC98BE64B40C8EA56CF49095640E7C3B30419E54B4053EA92718C075640E7C3B30419E54B40
76078	24615	88.400422000000006	88.416556	55.728434	55.717548000000001	Школьная	0103000020E6100000010000000500000055A69883A0195640B5A7E49CD8DB4B4055A69883A0195640B1A547533DDD4B40F73C7FDAA81A5640B1A547533DDD4B40F73C7FDAA81A5640B5A7E49CD8DB4B4055A69883A0195640B5A7E49CD8DB4B40
76066	23209	88.142660000000006	88.226795999999993	55.651840999999997	55.603603	Октябрьская	0103000020E61000000100000005000000A29C6857210956403D62F4DC42CD4B40A29C6857210956409198A0866FD34B4045B75ED3830E56409198A0866FD34B4045B75ED3830E56403D62F4DC42CD4B40A29C6857210956403D62F4DC42CD4B40
75801	23209	88.142660000000006	88.226795999999993	55.651840999999997	55.603603	Ленина	0103000020E61000000100000005000000A29C6857210956403D62F4DC42CD4B40A29C6857210956409198A0866FD34B4045B75ED3830E56409198A0866FD34B4045B75ED3830E56403D62F4DC42CD4B40A29C6857210956403D62F4DC42CD4B40
12493	41106	88.142660000000006	88.226795999999993	55.651840999999997	55.603603	1 мая	0103000020E61000000100000005000000A29C6857210956403D62F4DC42CD4B40A29C6857210956409198A0866FD34B4045B75ED3830E56409198A0866FD34B4045B75ED3830E56403D62F4DC42CD4B40A29C6857210956403D62F4DC42CD4B40
76073	23914	88.194879	88.223220999999995	55.831848000000001	55.820981000000003	Школьная	0103000020E6100000010000000500000057EBC4E5780C564096D1C8E715E94B4057EBC4E5780C56401B9FC9FE79EA4B40F2B1BB40490E56401B9FC9FE79EA4B40F2B1BB40490E564096D1C8E715E94B4057EBC4E5780C564096D1C8E715E94B40
76077	24445	88.547881000000004	88.568353000000002	55.743436000000003	55.728189999999998	Центральная	0103000020E610000001000000050000006346787B102356401AA3755435DD4B406346787B10235640A4552DE928DF4B4058E542E55F245640A4552DE928DF4B4058E542E55F2456401AA3755435DD4B406346787B102356401AA3755435DD4B40
76075	24340	88.399596000000003	88.414013999999995	55.804212999999997	55.792225000000002	Центральная	0103000020E6100000010000000500000032E719FB921956406C09F9A067E54B4032E719FB921956404F029B73F0E64B40838593347F1A56404F029B73F0E64B40838593347F1A56406C09F9A067E54B4032E719FB921956406C09F9A067E54B40
13506	41220	88.701915	88.730266	55.776603000000001	55.76014	Молодежная	0103000020E610000001000000050000009964E42CEC2C5640D3307C444CE14B409964E42CEC2C5640DD7C23BA67E34B405ED89AADBC2E5640DD7C23BA67E34B405ED89AADBC2E5640D3307C444CE14B409964E42CEC2C5640D3307C444CE14B40
76079	24639	88.293064999999999	88.312109000000007	55.645150999999998	55.627122	пер. Советский	0103000020E610000001000000050000008BA6B393C1125640124DA08845D04B408BA6B393C1125640A8FDD64E94D24B4063F20698F9135640A8FDD64E94D24B4063F20698F9135640124DA08845D04B408BA6B393C1125640124DA08845D04B40
76067	23616	88.743191999999993	88.770680999999996	55.767712000000003	55.747540000000001	Школьная	0103000020E6100000010000000500000086A92D75902F5640D6390664AFDF4B4086A92D75902F5640965F066344E24B4082A966D652315640965F066344E24B4082A966D652315640D6390664AFDF4B4086A92D75902F5640D6390664AFDF4B40
76085	23387	87.923085	87.942012000000005	55.523932000000002	55.511617999999999	Почтовая	0103000020E61000000100000005000000679B1BD313FB5540C005D9B27CC14B40679B1BD313FB5540F8A92A3410C34B40221CB3EC49FC5540F8A92A3410C34B40221CB3EC49FC5540C005D9B27CC14B40679B1BD313FB5540C005D9B27CC14B40
75802	23486	88.105919	88.152244999999994	55.538671999999998	55.513294999999999	Горняка	0103000020E610000001000000050000009A417C60C7065640A4198BA6B3C14B409A417C60C7065640ADA23F34F3C44B40B0FECF61BE095640ADA23F34F3C44B40B0FECF61BE095640A4198BA6B3C14B409A417C60C7065640A4198BA6B3C14B40
50160	23148	88.470500000000001	88.494996999999998	55.033507	55.009512000000001	Юбилейная	0103000020E61000000100000005000000273108AC1C1E5640B47570B037814B40273108AC1C1E5640F29716F549844B408FA7E507AE1F5640F29716F549844B408FA7E507AE1F5640B47570B037814B40273108AC1C1E5640B47570B037814B40
76076	24522	88.495679999999993	88.507447999999997	55.748609999999999	55.740740000000002	Трактовая	0103000020E6100000010000000500000000529B38B91F5640666B7D91D0DE4B4000529B38B91F5640B2BAD573D2DF4B40EB1A2D077A205640B2BAD573D2DF4B40EB1A2D077A205640666B7D91D0DE4B4000529B38B91F5640666B7D91D0DE4B40
76254	21993	87.966571999999999	88.018369000000007	52.934134	52.905808999999998	Советская	0103000020E61000000100000005000000AD4ECE50DCFD554013B69F8CF1734A40AD4ECE50DCFD5540740AF2B391774A40A8902BF52C015640740AF2B391774A40A8902BF52C01564013B69F8CF1734A40AD4ECE50DCFD554013B69F8CF1734A40
76278	21993	87.966571999999999	88.018369000000007	52.934134	52.905808999999998	Дзержинского	0103000020E61000000100000005000000AD4ECE50DCFD554013B69F8CF1734A40AD4ECE50DCFD5540740AF2B391774A40A8902BF52C015640740AF2B391774A40A8902BF52C01564013B69F8CF1734A40AD4ECE50DCFD554013B69F8CF1734A40
76273	21993	87.966571999999999	88.018369000000007	52.934134	52.905808999999998	Гагарина	0103000020E61000000100000005000000AD4ECE50DCFD554013B69F8CF1734A40AD4ECE50DCFD5540740AF2B391774A40A8902BF52C015640740AF2B391774A40A8902BF52C01564013B69F8CF1734A40AD4ECE50DCFD554013B69F8CF1734A40
76289	21993	87.966571999999999	88.018369000000007	52.934134	52.905808999999998	19 партсъезда	0103000020E61000000100000005000000AD4ECE50DCFD554013B69F8CF1734A40AD4ECE50DCFD5540740AF2B391774A40A8902BF52C015640740AF2B391774A40A8902BF52C01564013B69F8CF1734A40AD4ECE50DCFD554013B69F8CF1734A40
76293	21910	87.411009000000007	87.478804999999994	53.156457000000003	53.125166	Центральная	0103000020E610000001000000050000002657B1F84DDA55401B49827005904A402657B1F84DDA55407A1D71C806944A40520ABABDA4DE55407A1D71C806944A40520ABABDA4DE55401B49827005904A402657B1F84DDA55401B49827005904A40
76257	21910	87.411009000000007	87.478804999999994	53.156457000000003	53.125166	 Центральная	0103000020E610000001000000050000002657B1F84DDA55401B49827005904A402657B1F84DDA55407A1D71C806944A40520ABABDA4DE55407A1D71C806944A40520ABABDA4DE55401B49827005904A402657B1F84DDA55401B49827005904A40
76229	20973	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	Советская	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
12412	20973	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	Поспелова	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
13343	20973	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	Ноградская	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
76239	20973	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	Ленина	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
76264	20973	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	Коммунистическая	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
13328	20973	87.816013999999996	87.942837999999995	52.878143999999999	52.734095000000003	Калинина	0103000020E6100000010000000500000000C5C89239F455401D9430D3F65D4A4000C5C89239F45540DD96C80567704A4044DB317557FC5540DD96C80567704A4044DB317557FC55401D9430D3F65D4A4000C5C89239F455401D9430D3F65D4A40
76241	21748	87.249716000000006	87.319964999999996	53.230103999999997	53.185524000000001	Школьная	0103000020E610000001000000050000006E52D158FBCF5540C24F1C40BF974A406E52D158FBCF5540E256410C749D4A4056B77A4E7AD45540E256410C749D4A4056B77A4E7AD45540C24F1C40BF974A406E52D158FBCF5540C24F1C40BF974A40
76245	21748	87.249716000000006	87.319964999999996	53.230103999999997	53.185524000000001	Октябрьская	0103000020E610000001000000050000006E52D158FBCF5540C24F1C40BF974A406E52D158FBCF5540E256410C749D4A4056B77A4E7AD45540E256410C749D4A4056B77A4E7AD45540C24F1C40BF974A406E52D158FBCF5540C24F1C40BF974A40
76244	21748	87.249716000000006	87.319964999999996	53.230103999999997	53.185524000000001	Ленина	0103000020E610000001000000050000006E52D158FBCF5540C24F1C40BF974A406E52D158FBCF5540E256410C749D4A4056B77A4E7AD45540E256410C749D4A4056B77A4E7AD45540C24F1C40BF974A406E52D158FBCF5540C24F1C40BF974A40
76283	21581	87.52664	87.631797000000006	53.124673999999999	53.099269	Победы	0103000020E61000000100000005000000FD304278B4E15540D940BAD8B48C4A40FD304278B4E15540AC545051F58F4A40802DAF5C6FE85540AC545051F58F4A40802DAF5C6FE85540D940BAD8B48C4A40FD304278B4E15540D940BAD8B48C4A40
76233	21581	87.52664	87.631797000000006	53.124673999999999	53.099269	Ленина	0103000020E61000000100000005000000FD304278B4E15540D940BAD8B48C4A40FD304278B4E15540AC545051F58F4A40802DAF5C6FE85540AC545051F58F4A40802DAF5C6FE85540D940BAD8B48C4A40FD304278B4E15540D940BAD8B48C4A40
76247	21581	87.52664	87.631797000000006	53.124673999999999	53.099269	Горноспасательная	0103000020E61000000100000005000000FD304278B4E15540D940BAD8B48C4A40FD304278B4E15540AC545051F58F4A40802DAF5C6FE85540AC545051F58F4A40802DAF5C6FE85540D940BAD8B48C4A40FD304278B4E15540D940BAD8B48C4A40
50106	28829	87.389511999999996	87.392871999999997	52.978749000000001	52.976368000000001	Веселая	0103000020E610000001000000050000009259BDC3EDD85540336E6AA0F97C4A409259BDC3EDD8554011FFB0A5477D4A40E7E099D024D9554011FFB0A5477D4A40E7E099D024D95540336E6AA0F97C4A409259BDC3EDD85540336E6AA0F97C4A40
76130	45867	85.812366999999995	85.824107999999995	54.983882000000001	54.975459999999998	Школьная	0103000020E61000000100000005000000605628D2FD73554030478FDFDB7C4B40605628D2FD735540C18F6AD8EF7D4B40CE177B2FBE745540C18F6AD8EF7D4B40CE177B2FBE74554030478FDFDB7C4B40605628D2FD73554030478FDFDB7C4B40
76057	46796	85.029036000000005	85.055222000000001	55.183698	55.164731000000003	Школьная	0103000020E61000000100000005000000079ACFB9DB41554096D1C8E715954B40079ACFB9DB415540992B836A83974B404301DBC188435540992B836A83974B404301DBC18843554096D1C8E715954B40079ACFB9DB41554096D1C8E715954B40
69913	59367	86.089119999999994	87.096193999999997	54.321807	53.608040000000003	Институтская	0103000020E61000000100000005000000D95A5F24B485554076543541D4CD4A40D95A5F24B4855540DB4FC6F830294B409204E10A28C65540DB4FC6F830294B409204E10A28C6554076543541D4CD4A40D95A5F24B485554076543541D4CD4A40
75697	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	проспект Строителей	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
78191	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	проспект Ленина	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12843	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	пр.Гагарина	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12696	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	пер. Соколовский	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75694	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Шишкина	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12314	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Черных	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
50460	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Цикличная	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
50635	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Тюленевка	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12296	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Союзная	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
50520	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Сафоновская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75607	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Революции	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75606	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Проспектная	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
78050	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Прокопьевский переулок	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
50388	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Прокопьевская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
13636	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Подольская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75609	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Пионерская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12358	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Пионерская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12688	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Печорская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
13683	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Петренко	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12316	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Обручева	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
13015	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Морозовой	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
76316	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Молодогвардейцев	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75735	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Маганак	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12383	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Крестьянская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
50500	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Космонавта Волынова	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
70161	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Комсомольская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75605	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Институтская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75888	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Зенковская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
12347	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Жолтовского	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75599	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Есенина	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
70163	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Дружбы	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75891	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Гончарова	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
13640	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Главная	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
69703	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Гайдара	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
69812	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Высокогорная	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
75868	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	Ветеранов	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
50503	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	2-я Ярославская	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
13502	41060	86.578593999999995	86.845366999999996	53.954191999999999	53.794704000000003	10-й микрорайон	0103000020E610000001000000050000005BEA20AF07A555400D0055DCB8E54A405BEA20AF07A555406B0DA5F622FA4A408787307E1AB655406B0DA5F622FA4A408787307E1AB655400D0055DCB8E54A405BEA20AF07A555400D0055DCB8E54A40
49973	29819	86.410060999999999	86.470464000000007	54.17145	54.146112000000002	Новая	0103000020E610000001000000050000005D177E703E9A5540CEC64ACCB3124B405D177E703E9A55401973D712F2154B40817C09151C9E55401973D712F2154B40817C09151C9E5540CEC64ACCB3124B405D177E703E9A5540CEC64ACCB3124B40
75632	29819	86.410060999999999	86.470464000000007	54.17145	54.146112000000002	Линейная	0103000020E610000001000000050000005D177E703E9A5540CEC64ACCB3124B405D177E703E9A55401973D712F2154B40817C09151C9E55401973D712F2154B40817C09151C9E5540CEC64ACCB3124B405D177E703E9A5540CEC64ACCB3124B40
50289	29819	86.410060999999999	86.470464000000007	54.17145	54.146112000000002	Комсомольская	0103000020E610000001000000050000005D177E703E9A5540CEC64ACCB3124B405D177E703E9A55401973D712F2154B40817C09151C9E55401973D712F2154B40817C09151C9E5540CEC64ACCB3124B405D177E703E9A5540CEC64ACCB3124B40
13257	41159	86.459620999999999	86.476393000000002	53.971313000000002	53.953386999999999	Центральная	0103000020E6100000010000000500000082E3326E6A9D55403DB7D09508FA4A4082E3326E6A9D5540FF9600FC53FC4A40C6C210397D9E5540FF9600FC53FC4A40C6C210397D9E55403DB7D09508FA4A4082E3326E6A9D55403DB7D09508FA4A40
76287	4097	87.724449000000007	87.736728999999997	53.494050000000001	53.488762000000001	Центральная	0103000020E61000000100000005000000ADA7565F5DEE554087C3D2C08FBE4A40ADA7565F5DEE55405E4BC8073DBF4A40F240649126EF55405E4BC8073DBF4A40F240649126EF554087C3D2C08FBE4A40ADA7565F5DEE554087C3D2C08FBE4A40
76041	13123	87.160737999999995	87.177115000000001	53.995095999999997	53.990299999999998	Центральная	0103000020E610000001000000050000005D4E098849CA5540499D8026C2FE4A405D4E098849CA5540B130444E5FFF4A40632827DA55CB5540B130444E5FFF4A40632827DA55CB5540499D8026C2FE4A405D4E098849CA5540499D8026C2FE4A40
76126	48742	87.196023999999994	87.232737999999998	54.085588000000001	54.077627999999997	Центральная	0103000020E61000000100000005000000CA4E3FA88BCC55407FA0DCB6EF094B40CA4E3FA88BCC55400C772E8CF40A4B4055A2EC2DE5CE55400C772E8CF40A4B4055A2EC2DE5CE55407FA0DCB6EF094B40CA4E3FA88BCC55407FA0DCB6EF094B40
76135	49021	87.326316000000006	87.346733999999998	53.998483	53.983217000000003	Центральная	0103000020E61000000100000005000000570A815CE2D4554085EFFD0DDAFD4A40570A815CE2D45540554E7B4ACEFF4A40529ACDE330D65540554E7B4ACEFF4A40529ACDE330D6554085EFFD0DDAFD4A40570A815CE2D4554085EFFD0DDAFD4A40
75906	60749	87.094829000000004	87.109992000000005	53.562744000000002	53.546230999999999	Лесная	0103000020E61000000100000005000000986DA7AD11C65540DB87BCE5EAC54A40986DA7AD11C655409702D2FE07C84A4096B4E21B0AC755409702D2FE07C84A4096B4E21B0AC75540DB87BCE5EAC54A40986DA7AD11C65540DB87BCE5EAC54A40
76034	11550	87.432496999999998	87.451387999999994	53.753490999999997	53.743028000000002	Центральная	0103000020E610000001000000050000008FA7E507AEDB55409301A08A1BDF4A408FA7E507AEDB5540486AA16472E04A40A3737E8AE3DC5540486AA16472E04A40A3737E8AE3DC55409301A08A1BDF4A408FA7E507AEDB55409301A08A1BDF4A40
76043	12149	87.192053999999999	87.216747999999995	53.449810999999997	53.439867999999997	Школьная	0103000020E610000001000000050000003944DC9C4ACC5540494739984DB84A403944DC9C4ACC5540C630276893B94A404CDE0033DFCD5540C630276893B94A404CDE0033DFCD5540494739984DB84A403944DC9C4ACC5540494739984DB84A40
50158	13445	87.108834000000002	87.127662000000001	53.957673	53.950265999999999	Старцева	0103000020E6100000010000000500000058ACE122F7C655401840F850A2F94A4058ACE122F7C6554090A1630795FA4A4049BC3C9D2BC8554090A1630795FA4A4049BC3C9D2BC855401840F850A2F94A4058ACE122F7C655401840F850A2F94A40
76198	60787	87.176585000000003	87.192385999999999	53.995370999999999	53.991253	Вокзальная	0103000020E61000000100000005000000B5FD2B2B4DCB5540EC87D860E1FE4A40B5FD2B2B4DCB55408331225168FF4A40548D5E0D50CC55408331225168FF4A40548D5E0D50CC5540EC87D860E1FE4A40B5FD2B2B4DCB5540EC87D860E1FE4A40
12410	41090	87.115679	87.169605000000004	53.681033999999997	53.648094	Кузнецкая	0103000020E610000001000000050000006075E44867C75540EE5D83BEF4D24A406075E44867C7554066BB421F2CD74A403D0FEECEDACA554066BB421F2CD74A403D0FEECEDACA5540EE5D83BEF4D24A406075E44867C75540EE5D83BEF4D24A40
75796	49015	87.331031999999993	87.348324000000005	53.967689999999997	53.955972000000003	Куюкова	0103000020E610000001000000050000007C7BD7A02FD5554024F25D4A5DFA4A407C7BD7A02FD5554047551344DDFB4A405D1ABFF04AD6554047551344DDFB4A405D1ABFF04AD6554024F25D4A5DFA4A407C7BD7A02FD5554024F25D4A5DFA4A40
76053	14542	86.707393999999994	86.737253999999993	53.246175000000001	53.233694	Советская	0103000020E61000000100000005000000BED87BF145AD5540BEA25BAFE99D4A40BED87BF145AD5540E10B93A9829F4A4017B6662B2FAF5540E10B93A9829F4A4017B6662B2FAF5540BEA25BAFE99D4A40BED87BF145AD5540BEA25BAFE99D4A40
13472	41207	87.291927999999999	87.351450999999997	53.470692999999997	53.452589000000003	Советская	0103000020E610000001000000050000005932C7F2AED25540C2C3B46FEEB94A405932C7F2AED2554062BA10AB3FBC4A4060C9552C7ED6554062BA10AB3FBC4A4060C9552C7ED65540C2C3B46FEEB94A405932C7F2AED25540C2C3B46FEEB94A40
13427	41191	86.922783999999993	86.942977999999997	53.731039000000003	53.716419999999999	Центральная	0103000020E6100000010000000500000069519FE40EBB5540A4198BA6B3DB4A4069519FE40EBB5540DF8C9AAF92DD4A403DB665C059BC5540DF8C9AAF92DD4A403DB665C059BC5540A4198BA6B3DB4A4069519FE40EBB5540A4198BA6B3DB4A40
76040	48866	86.688000000000002	87.909484000000006	54.499693999999998	53.085965999999999	Центральная	0103000020E6100000010000000500000079E9263108AC5540B24813EF008B4A4079E9263108AC5540F30016F9F53F4B400F0F61FC34FA5540F30016F9F53F4B400F0F61FC34FA5540B24813EF008B4A4079E9263108AC5540B24813EF008B4A40
75745	14089	87.537267	87.583062999999996	54.216135999999999	54.203867000000002	Суворова	0103000020E61000000100000005000000158E209562E25540E8DD5850181A4B40158E209562E255407FBE2D58AA1B4B407D2079E750E555407FBE2D58AA1B4B407D2079E750E55540E8DD5850181A4B40158E209562E25540E8DD5850181A4B40
76016	46629	\N	\N	\N	\N	Луговая	\N
13648	6235	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	пр. Авиаторов	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
12578	6235	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	Тольятти	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
12661	6235	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	Покрышкина	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
12350	6235	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	Олимпийская	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
12407	6235	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	Ливинская	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
75770	6235	87.093823	87.098996999999997	53.749003000000002	53.746223000000001	Лермонтова	0103000020E6100000010000000500000035272F3201C65540F2423A3C84DF4A4035272F3201C655408ECD8E54DFDF4A40BC5983F755C655408ECD8E54DFDF4A40BC5983F755C65540F2423A3C84DF4A4035272F3201C65540F2423A3C84DF4A40
12298	6235	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	Кутузова	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
75749	6235	87.312347000000003	87.315472999999997	53.750822999999997	53.750658000000001	Интернатная	0103000020E610000001000000050000003D80457EFDD355408A3DB48F15E04A403D80457EFDD35540D40AD3F71AE04A405871AAB530D45540D40AD3F71AE04A405871AAB530D455408A3DB48F15E04A403D80457EFDD355408A3DB48F15E04A40
76308	6235	87.143527000000006	87.166847000000004	53.756833999999998	53.743485999999997	Дружбы	0103000020E61000000100000005000000F4C5DE8B2FC9554055849B8C2ADF4A40F4C5DE8B2FC955401C40BFEFDFE04A40E31B0A9FADCA55401C40BFEFDFE04A40E31B0A9FADCA554055849B8C2ADF4A40F4C5DE8B2FC9554055849B8C2ADF4A40
12391	6235	87.022479000000004	87.402448000000007	53.916651999999999	53.682543000000003	40 лет ВЛКСМ	0103000020E610000001000000050000003276C24B70C155408F8EAB915DD74A403276C24B70C1554010E84CDA54F54A40CD9541B5C1D9554010E84CDA54F54A40CD9541B5C1D955408F8EAB915DD74A403276C24B70C155408F8EAB915DD74A40
76168	13168	87.140238999999994	87.189098000000001	53.488264000000001	53.469673999999998	Школьная	0103000020E61000000100000005000000EBA7FFACF9C8554008E412471EBC4A40EBA7FFACF9C8554036E84B6F7FBE4A404C6F7F2E1ACC554036E84B6F7FBE4A404C6F7F2E1ACC554008E412471EBC4A40EBA7FFACF9C8554008E412471EBC4A40
75791	12879	86.688000000000002	87.909484000000006	54.499693999999998	53.085965999999999	Центральная	0103000020E6100000010000000500000079E9263108AC5540B24813EF008B4A4079E9263108AC5540F30016F9F53F4B400F0F61FC34FA5540F30016F9F53F4B400F0F61FC34FA5540B24813EF008B4A4079E9263108AC5540B24813EF008B4A40
13430	41194	87.003488000000004	87.019766000000004	53.741159000000003	53.734422000000002	Куйбышева	0103000020E610000001000000050000006C7BBB2539C0554041BB438A01DE4A406C7BBB2539C055406B11514CDEDE4A40A8E49CD843C155406B11514CDEDE4A40A8E49CD843C1554041BB438A01DE4A406C7BBB2539C0554041BB438A01DE4A40
13482	41212	87.261745000000005	87.335982000000001	53.430888000000003	53.390470999999998	60 лет Октября	0103000020E610000001000000050000000FB9196EC0D05540A98427F4FAB14A400FB9196EC0D05540931E865627B74A40DC82A5BA80D55540931E865627B74A40DC82A5BA80D55540A98427F4FAB14A400FB9196EC0D05540A98427F4FAB14A40
75968	9411	87.026161999999999	87.054809000000006	53.159044000000002	53.146850000000001	Мира	0103000020E61000000100000005000000789961A3ACC1554074B515FBCB924A40789961A3ACC155400150C58D5B944A40B2A19BFD81C355400150C58D5B944A40B2A19BFD81C3554074B515FBCB924A40789961A3ACC1554074B515FBCB924A40
75792	11966	86.688000000000002	87.909484000000006	54.499693999999998	53.085965999999999	Полосухина	0103000020E6100000010000000500000079E9263108AC5540B24813EF008B4A4079E9263108AC5540F30016F9F53F4B400F0F61FC34FA5540F30016F9F53F4B400F0F61FC34FA5540B24813EF008B4A4079E9263108AC5540B24813EF008B4A40
75958	14726	87.141568000000007	87.255878999999993	53.344790000000003	53.315556999999998	Яценко	0103000020E61000000100000005000000408A3A730FC955400E83F92B64A84A40408A3A730FC9554072FE261422AC4A40EC2E505260D0554072FE261422AC4A40EC2E505260D055400E83F92B64A84A40408A3A730FC955400E83F92B64A84A40
13545	14726	87.141568000000007	87.255878999999993	53.344790000000003	53.315556999999998	Станционная	0103000020E61000000100000005000000408A3A730FC955400E83F92B64A84A40408A3A730FC9554072FE261422AC4A40EC2E505260D0554072FE261422AC4A40EC2E505260D055400E83F92B64A84A40408A3A730FC955400E83F92B64A84A40
75646	14726	87.141568000000007	87.255878999999993	53.344790000000003	53.315556999999998	Октябрьская	0103000020E61000000100000005000000408A3A730FC955400E83F92B64A84A40408A3A730FC9554072FE261422AC4A40EC2E505260D0554072FE261422AC4A40EC2E505260D055400E83F92B64A84A40408A3A730FC955400E83F92B64A84A40
13546	14726	87.141568000000007	87.255878999999993	53.344790000000003	53.315556999999998	Ленинская	0103000020E61000000100000005000000408A3A730FC955400E83F92B64A84A40408A3A730FC9554072FE261422AC4A40EC2E505260D0554072FE261422AC4A40EC2E505260D055400E83F92B64A84A40408A3A730FC955400E83F92B64A84A40
76054	14726	87.141568000000007	87.255878999999993	53.344790000000003	53.315556999999998	40 лет Победы	0103000020E61000000100000005000000408A3A730FC955400E83F92B64A84A40408A3A730FC9554072FE261422AC4A40EC2E505260D0554072FE261422AC4A40EC2E505260D055400E83F92B64A84A40408A3A730FC955400E83F92B64A84A40
76051	13980	87.202230999999998	87.211851999999993	53.812947999999999	53.811678000000001	Мира	0103000020E6100000010000000500000031CF4A5AF1CC5540FC709010E5E74A4031CF4A5AF1CC55409FAC18AE0EE84A40E6E5B0FB8ECD55409FAC18AE0EE84A40E6E5B0FB8ECD5540FC709010E5E74A4031CF4A5AF1CC5540FC709010E5E74A40
12445	41096	87.065786000000003	87.093930999999998	54.032617000000002	54.018436999999999	Центральная	0103000020E6100000010000000500000038A27BD635C45540A704C4245C024B4038A27BD635C4554096253ACB2C044B4028452BF702C6554096253ACB2C044B4028452BF702C65540A704C4245C024B4038A27BD635C45540A704C4245C024B40
12533	41112	87.326764999999995	87.338964000000004	53.588470999999998	53.580190999999999	60 лет Октября	0103000020E610000001000000050000008E1EBFB7E9D455407E37DDB243CA4A408E1EBFB7E9D455407CD2890453CB4A405EA10F96B1D555407CD2890453CB4A405EA10F96B1D555407E37DDB243CA4A408E1EBFB7E9D455407E37DDB243CA4A40
75848	13541	86.800128000000001	86.844387999999995	53.644523	53.613916000000003	Школьная	0103000020E610000001000000050000004A27124C35B35540DE3EABCC94CE4A404A27124C35B355408942CBBA7FD24A40A148F7730AB655408942CBBA7FD24A40A148F7730AB65540DE3EABCC94CE4A404A27124C35B35540DE3EABCC94CE4A40
76044	13541	86.800128000000001	86.844387999999995	53.644523	53.613916000000003	Центральная	0103000020E610000001000000050000004A27124C35B35540DE3EABCC94CE4A404A27124C35B355408942CBBA7FD24A40A148F7730AB655408942CBBA7FD24A40A148F7730AB65540DE3EABCC94CE4A404A27124C35B35540DE3EABCC94CE4A40
13543	14625	86.908203999999998	86.937139000000002	53.276183000000003	53.269306	Школьная	0103000020E610000001000000050000002B86AB0320BA5540EC4E779E78A24A402B86AB0320BA5540085BECF659A34A409833DB15FABB5540085BECF659A34A409833DB15FABB5540EC4E779E78A24A402B86AB0320BA5540EC4E779E78A24A40
13402	12988	87.255330999999998	87.285810999999995	54.006321	53.990839999999999	Юбилейная	0103000020E61000000100000005000000EBA9D55757D05540C9C859D8D3FE4A40EBA9D55757D0554096236420CF004B40927538BA4AD2554096236420CF004B40927538BA4AD25540C9C859D8D3FE4A40EBA9D55757D05540C9C859D8D3FE4A40
75731	60718	87.142951999999994	87.173665	53.901912000000003	53.884774	Жиха	0103000020E610000001000000050000007539252026C95540F12C414640F14A407539252026C955405BEF37DA71F34A406EDDCD531DCB55405BEF37DA71F34A406EDDCD531DCB5540F12C414640F14A407539252026C95540F12C414640F14A40
76046	14455	87.298468	87.304845999999998	53.483088000000002	53.472445	Новая	0103000020E61000000100000005000000C3B986191AD355405114E81379BC4A40C3B986191AD35540878BDCD3D5BD4A404014CC9882D35540878BDCD3D5BD4A404014CC9882D355405114E81379BC4A40C3B986191AD355405114E81379BC4A40
76071	60770	87.299609000000004	87.306911999999997	53.600731000000003	53.596018000000001	Юный Запсибовец	0103000020E6100000010000000500000096253ACB2CD35540E6E95C514ACC4A4096253ACB2CD35540C158DFC0E4CC4A40FFAF3A72A4D35540C158DFC0E4CC4A40FFAF3A72A4D35540E6E95C514ACC4A4096253ACB2CD35540E6E95C514ACC4A40
76047	14373	87.811963000000006	87.821637999999993	54.153737	54.137203999999997	Центральная	0103000020E61000000100000005000000F9A3A833F7F35540B07092E68F114B40F9A3A833F7F35540B3976DA7AD134B40A7C98CB795F45540B3976DA7AD134B40A7C98CB795F45540B07092E68F114B40F9A3A833F7F35540B07092E68F114B40
12495	41108	87.430492999999998	87.444614999999999	53.898899	53.893031000000001	Лесная	0103000020E610000001000000050000000B0A83328DDB554037A8FDD64EF24A400B0A83328DDB55401CB4571F0FF34A40E813799274DC55401CB4571F0FF34A40E813799274DC554037A8FDD64EF24A400B0A83328DDB554037A8FDD64EF24A40
13423	41187	86.982737	87.023241999999996	53.754534	53.738714000000002	Ленинская	0103000020E610000001000000050000006DE4BA29E5BE5540768C2B2E8EDE4A406DE4BA29E5BE55402BDCF29194E04A40317903CC7CC155402BDCF29194E04A40317903CC7CC15540768C2B2E8EDE4A406DE4BA29E5BE5540768C2B2E8EDE4A40
13330	41173	87.485668000000004	87.508701000000002	53.794635	53.787444000000001	Школьная	0103000020E61000000100000005000000AE2D3C2F15DF554039B709F7CAE44A40AE2D3C2F15DF5540E4A08499B6E54A40529CA38E8EE05540E4A08499B6E54A40529CA38E8EE0554039B709F7CAE44A40AE2D3C2F15DF554039B709F7CAE44A40
13340	41174	87.571718000000004	87.589342000000002	53.684531999999997	53.667864000000002	Речная	0103000020E610000001000000050000003622180797E455407F164B917CD54A403622180797E4554061889CBE9ED74A40310A82C7B7E5554061889CBE9ED74A40310A82C7B7E555407F164B917CD54A403622180797E455407F164B917CD54A40
12538	41114	86.779510999999999	86.806765999999996	53.269382	53.25667	Зеленая	0103000020E61000000100000005000000D3F71A82E3B15540A2EE0390DAA04A40D3F71A82E3B15540C710001C7BA24A409561DC0DA2B35540C710001C7BA24A409561DC0DA2B35540A2EE0390DAA04A40D3F71A82E3B15540A2EE0390DAA04A40
13544	14698	86.975110000000001	87.026071999999999	53.332467000000001	53.311909999999997	Центральная	0103000020E610000001000000050000002A00C63368BE5540CEA5B8AAECA74A402A00C63368BE5540E7FF55478EAA4A40D8D5E429ABC15540E7FF55478EAA4A40D8D5E429ABC15540CEA5B8AAECA74A402A00C63368BE5540CEA5B8AAECA74A40
71725	12443	87.541291999999999	87.625005999999999	53.786752	53.757744000000002	Коммунальная	0103000020E6100000010000000500000088653387A4E25540C05E61C1FDE04A4088653387A4E2554003081F4AB4E44A4071732A1900E8554003081F4AB4E44A4071732A1900E85540C05E61C1FDE04A4088653387A4E25540C05E61C1FDE04A40
76039	12391	87.107153999999994	87.123575000000002	53.855877	53.854177	Центральная	0103000020E61000000100000005000000AD68739CDBC6554069FF03AC55ED4A40AD68739CDBC655400533A6608DED4A409BE61DA7E8C755400533A6608DED4A409BE61DA7E8C7554069FF03AC55ED4A40AD68739CDBC6554069FF03AC55ED4A40
76037	11423	87.411197999999999	87.421896000000004	53.729111000000003	53.722143000000003	Зеленая	0103000020E610000001000000050000008F8B6A1151DA554086048C2E6FDC4A408F8B6A1151DA5540B2135E8253DD4A400C94145800DB5540B2135E8253DD4A400C94145800DB554086048C2E6FDC4A408F8B6A1151DA554086048C2E6FDC4A40
76038	11805	86.688000000000002	87.909484000000006	54.499693999999998	53.085965999999999	Советская	0103000020E6100000010000000500000079E9263108AC5540B24813EF008B4A4079E9263108AC5540F30016F9F53F4B400F0F61FC34FA5540F30016F9F53F4B400F0F61FC34FA5540B24813EF008B4A4079E9263108AC5540B24813EF008B4A40
13462	41202	86.832170000000005	86.851286999999999	53.535159999999998	53.51923	Шабалова	0103000020E6100000010000000500000097ADF54542B55540118DEE2076C24A4097ADF54542B555404D10751F80C44A40A320787C7BB655404D10751F80C44A40A320787C7BB65540118DEE2076C24A4097ADF54542B55540118DEE2076C24A40
13390	41182	86.496191999999994	88.620643999999999	54.833199999999998	52.889898000000002	Центральная	0103000020E610000001000000050000005B22179CC19F55404E637B2DE8714A405B22179CC19F55407B832F4CA66A4B405A9D9CA1B82756407B832F4CA66A4B405A9D9CA1B82756404E637B2DE8714A405B22179CC19F55404E637B2DE8714A40
12639	41134	87.186942000000002	87.318742999999998	53.764819000000003	53.686655000000002	Громовой	0103000020E61000000100000005000000ED0F94DBF6CB55404451A04FE4D74A40ED0F94DBF6CB5540022EC896E5E14A400D350A4966D45540022EC896E5E14A400D350A4966D455404451A04FE4D74A40ED0F94DBF6CB55404451A04FE4D74A40
50517	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	проспект Строителей	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50308	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	проспект Коммунистический	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
49974	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	ШИРОКИЙ ЛОГ	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50267	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	УСИНСКАЯ	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
12586	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Строителей	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50288	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	СТРОИТЕЛЕЙ	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
75909	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Пушкина	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50051	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Проходчиков	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50312	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	ПУШКИНА	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50310	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	ПРИТОМСКИЙ	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
71511	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Лазо	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50048	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	ЛАЗО	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50127	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Кузнецкая	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
13591	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Коммунистический	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
75585	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Комарова	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
13499	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	КУЗНЕЦКАЯ	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50050	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	ДУНАЕВСКОГО	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50046	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	ГУЛИ КОРОЛЕВОЙ	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
12954	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Вокзальная	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
13594	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Весенняя	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
12650	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Вахрушева	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
12676	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	Бульвар медиков	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
49976	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	БРЯНСКАЯ	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
50129	1208	87.914873999999998	88.275332000000006	53.743006999999999	53.643653	50 лет Комсомола	0103000020E610000001000000050000007C7DAD4B8DFA5540747CB43863D24A407C7DAD4B8DFA55407BD976DA1ADF4A40B5E21B0A9F1156407BD976DA1ADF4A40B5E21B0A9F115640747CB43863D24A407C7DAD4B8DFA5540747CB43863D24A40
75934	47728	87.237993000000003	87.274995000000004	56.246105999999997	56.233739	Радищева	0103000020E6100000010000000500000053EBFD463BCF55405E66D828EB1D4C4053EBFD463BCF5540B8ACC266801F4C4011E4A08499D15540B8ACC266801F4C4011E4A08499D155405E66D828EB1D4C4053EBFD463BCF55405E66D828EB1D4C40
76029	10753	88.298445999999998	88.322134000000005	56.542619000000002	56.535626000000001	Лесная	0103000020E61000000100000005000000CF6740BD1913564093718C648F444C40CF6740BD191356401898158A74454C4080BBECD79D1456401898158A74454C4080BBECD79D14564093718C648F444C40CF6740BD1913564093718C648F444C40
76036	48032	87.196824000000007	87.221114	56.609927999999996	56.594195999999997	Паромская	0103000020E6100000010000000500000059C4B0C398CC5540FEB4519D0E4C4C4059C4B0C398CC55401475E61E124E4C4004AC55BB26CE55401475E61E124E4C4004AC55BB26CE5540FEB4519D0E4C4C4059C4B0C398CC5540FEB4519D0E4C4C40
75978	14164	87.542000999999999	87.575967000000006	56.385446999999999	56.375478999999999	Городская	0103000020E610000001000000050000008E59F624B0E25540DAAA24B20F304C408E59F624B0E25540B0ABC95356314C40D124B1A4DCE45540B0ABC95356314C40D124B1A4DCE45540DAAA24B20F304C408E59F624B0E25540DAAA24B20F304C40
76196	60785	87.454254000000006	87.492018999999999	56.540520000000001	56.522658999999997	Школьный бульвар	0103000020E61000000100000005000000F1845E7F12DD5540E3FA777DE6424C40F1845E7F12DD5540BE6A65C22F454C40AE80423D7DDF5540BE6A65C22F454C40AE80423D7DDF5540E3FA777DE6424C40F1845E7F12DD5540E3FA777DE6424C40
76227	60795	87.328102999999999	87.369246000000004	56.577060000000003	56.565961999999999	Александровская	0103000020E610000001000000050000000CAEB9A3FFD45540AE635C7171484C400CAEB9A3FFD4554036EA211ADD494C40728BF9B9A1D7554036EA211ADD494C40728BF9B9A1D75540AE635C7171484C400CAEB9A3FFD45540AE635C7171484C40
50020	11069	88.096603000000002	88.158174000000002	56.226948999999998	56.205651000000003	Трактовая	0103000020E61000000100000005000000836C59BE2E065640E2B19FC5521A4C40836C59BE2E065640116E32AA0C1D4C40F644D7851F0A5640116E32AA0C1D4C40F644D7851F0A5640E2B19FC5521A4C40836C59BE2E065640E2B19FC5521A4C40
50018	11069	88.096603000000002	88.158174000000002	56.226948999999998	56.205651000000003	Стройка	0103000020E61000000100000005000000836C59BE2E065640E2B19FC5521A4C40836C59BE2E065640116E32AA0C1D4C40F644D7851F0A5640116E32AA0C1D4C40F644D7851F0A5640E2B19FC5521A4C40836C59BE2E065640E2B19FC5521A4C40
76032	47903	88.158253999999999	88.183614000000006	56.362625999999999	56.352606999999999	Школьная	0103000020E61000000100000005000000849D62D5200A56409BABE639222D4C40849D62D5200A5640F3565D876A2E4C409E45EF54C00B5640F3565D876A2E4C409E45EF54C00B56409BABE639222D4C40849D62D5200A56409BABE639222D4C40
75998	47648	87.870694999999998	87.885633999999996	56.181939999999997	56.160981999999997	Центральная	0103000020E610000001000000050000009B728577B9F75540519FE40E9B144C409B728577B9F75540C8EA56CF49174C40718E3A3AAEF85540C8EA56CF49174C40718E3A3AAEF85540519FE40E9B144C409B728577B9F75540519FE40E9B144C40
75873	60740	87.794292999999996	87.838399999999993	56.210462	56.190361000000003	Весенняя	0103000020E61000000100000005000000459C4EB2D5F2554089B7CEBF5D184C40459C4EB2D5F255407F86376BF01A4C40D93D7958A8F555407F86376BF01A4C40D93D7958A8F5554089B7CEBF5D184C40459C4EB2D5F2554089B7CEBF5D184C40
12366	41075	87.902557999999999	87.927961999999994	56.235435000000003	56.226838999999998	Центральная	0103000020E61000000100000005000000902FA182C3F955408A3A730F091D4C40902FA182C3F95540B9AAECBB221E4C40917BBABA63FB5540B9AAECBB221E4C40917BBABA63FB55408A3A730F091D4C40902FA182C3F955408A3A730F091D4C40
75923	9937	87.158069999999995	87.194864999999993	56.339481999999997	56.321829999999999	Правдинская	0103000020E61000000100000005000000A31EA2D11DCA5540936FB6B931294C40A31EA2D11DCA554053CA6B25742B4C40A4880CAB78CC554053CA6B25742B4C40A4880CAB78CC5540936FB6B931294C40A31EA2D11DCA5540936FB6B931294C40
75897	60745	88.068971000000005	88.085984999999994	56.654783000000002	56.648978999999997	Лесная	0103000020E61000000100000005000000D65757056A04564038656EBE11534C40D65757056A045640077DE9EDCF534C4094BC3AC780055640077DE9EDCF534C4094BC3AC78005564038656EBE11534C40D65757056A04564038656EBE11534C40
76045	47746	87.384904000000006	87.399079	56.217896000000003	56.211548000000001	Центральная	0103000020E6100000010000000500000060066344A2D8554061C43E01141B4C4060066344A2D85540F1F62004E41B4C404E61A5828AD95540F1F62004E41B4C404E61A5828AD9554061C43E01141B4C4060066344A2D8554061C43E01141B4C40
76058	45470	88.010328999999999	88.032247999999996	56.179786	56.169638999999997	Рабочая	0103000020E61000000100000005000000D34CF73AA9005640259012BBB6154C40D34CF73AA9005640AB23473A03174C402157EA5910025640AB23473A03174C402157EA5910025640259012BBB6154C40D34CF73AA9005640259012BBB6154C40
9641	23191	87.607228000000006	87.637016000000003	56.364395999999999	56.349310000000003	Новая	0103000020E61000000100000005000000CB4DD4D2DCE655403815A930B62C4C40CB4DD4D2DCE6554088653387A42E4C40D7C1C1DEC4E8554088653387A42E4C40D7C1C1DEC4E855403815A930B62C4C40CB4DD4D2DCE655403815A930B62C4C40
76166	60776	88.070417000000006	88.110258000000002	56.296273999999997	56.279932000000002	Молодежная	0103000020E6100000010000000500000047054EB6810456404C8DD0CFD4234C4047054EB681045640DA53724EEC254C40D50792770E075640DA53724EEC254C40D50792770E0756404C8DD0CFD4234C4047054EB6810456404C8DD0CFD4234C40
76193	60782	87.301989000000006	87.319704000000002	56.287207000000002	56.277093000000001	Николаевская	0103000020E610000001000000050000001DB0ABC953D35540AB798EC877234C401DB0ABC953D355405517F032C3244C40A019C40776D455405517F032C3244C40A019C40776D45540AB798EC877234C401DB0ABC953D35540AB798EC877234C40
76030	47892	87.913751000000005	87.941643999999997	56.324660999999999	56.321725999999998	Боровая	0103000020E61000000100000005000000FD6B79E57AFA5540EE224C512E294C40FD6B79E57AFA5540B1A4DC7D8E294C40601E32E543FC5540B1A4DC7D8E294C40601E32E543FC5540EE224C512E294C40FD6B79E57AFA5540EE224C512E294C40
49951	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Юбилейная	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50076	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Чердынцева	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
12297	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Фабричная	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50077	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Трудовая	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
75790	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Сибиряков-Гвардейцев	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50072	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Покрышкина	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
12322	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Пальчикова	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50074	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Ноградский	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50017	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Молодежная	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
12317	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Ленина	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50354	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Котовского	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
12784	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Достоевского	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
13671	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Дорожная	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
12328	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Добролюбова	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50015	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	Гагарина	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
50016	6824	87.677198000000004	87.788741000000002	56.271146000000002	56.157136999999999	50 лет Октября	0103000020E61000000100000005000000AABA473657EB5540EBFEB1101D144C40AABA473657EB55407A3881E9B4224C40EB0088BB7AF255407A3881E9B4224C40EB0088BB7AF25540EBFEB1101D144C40AABA473657EB5540EBFEB1101D144C40
13090	41153	87.544569999999993	87.582550999999995	56.143698999999998	56.128901999999997	Центральная	0103000020E610000001000000050000007E18213CDAE25540CA3159DC7F104C407E18213CDAE25540E4BB94BA64124C402250FD8348E55540E4BB94BA64124C402250FD8348E55540CA3159DC7F104C407E18213CDAE25540CA3159DC7F104C40
76009	10043	87.691615999999996	87.713840000000005	56.286392999999997	56.275109	Просвещения	0103000020E61000000100000005000000FB58C16F43EC5540EAEA8EC536234C40FB58C16F43EC5540D3669C86A8244C40E8A4F78DAFED5540D3669C86A8244C40E8A4F78DAFED5540EAEA8EC536234C40FB58C16F43EC5540EAEA8EC536234C40
76031	10806	87.096985000000004	87.141613000000007	56.445996000000001	56.415464999999998	Победы	0103000020E61000000100000005000000F7CC920035C65540FAD005F52D354C40F7CC920035C65540CB129D6516394C4010ECF82F10C95540CB129D6516394C4010ECF82F10C95540FAD005F52D354C40F7CC920035C65540FAD005F52D354C40
76025	47759	88.152083000000005	88.174721000000005	56.387265999999997	56.378279999999997	Школьная	0103000020E61000000100000005000000C4D155BABB0956408D5DA27A6B304C40C4D155BABB095640266DAAEE91314C402A3BFDA02E0B5640266DAAEE91314C402A3BFDA02E0B56408D5DA27A6B304C40C4D155BABB0956408D5DA27A6B304C40
76027	10665	88.045516000000006	88.062843999999998	56.413338000000003	56.406491000000003	Рабочая	0103000020E6100000010000000500000077DCF0BBE9025640268FA7E507344C4077DCF0BBE9025640D7187442E8344C40FD2FD7A205045640D7187442E8344C40FD2FD7A205045640268FA7E507344C4077DCF0BBE9025640268FA7E507344C40
75785	10413	87.209103999999996	87.254298000000006	56.179369999999999	56.159498999999997	Центральная	0103000020E610000001000000050000009E5DBEF561CD5540525F96766A144C409E5DBEF561CD554017F19D98F5164C400C5C1E6B46D0554017F19D98F5164C400C5C1E6B46D05540525F96766A144C409E5DBEF561CD5540525F96766A144C40
13296	41167	88.069976999999994	88.075574000000003	56.139226000000001	56.123041999999998	Центральная	0103000020E61000000100000005000000389ECF807A04564068041BD7BF0F4C40389ECF807A0456405F605628D2114C40639B5434D60456405F605628D2114C40639B5434D604564068041BD7BF0F4C40389ECF807A04564068041BD7BF0F4C40
75985	12958	87.329963000000006	87.352241000000006	56.524337000000003	56.509737000000001	Ленина	0103000020E61000000100000005000000F778211D1ED55540D447E00F3F414C40F778211D1ED55540988A8D791D434C40DDD3D51D8BD65540988A8D791D434C40DDD3D51D8BD65540D447E00F3F414C40F778211D1ED55540D447E00F3F414C40
76033	47850	87.049921999999995	87.087075999999996	56.509920999999999	56.496478000000003	Победы	0103000020E6100000010000000500000075560BEC31C355407D9752978C3F4C4075560BEC31C355409545611745414C400E1137A792C555409545611745414C400E1137A792C555407D9752978C3F4C4075560BEC31C355407D9752978C3F4C40
12369	41076	87.240939999999995	87.264808000000002	56.108255999999997	56.098326	Центральная	0103000020E6100000010000000500000016139B8F6BCF55405A2C45F2950C4C4016139B8F6BCF554042CC2555DB0D4C4007EE409DF2D0554042CC2555DB0D4C4007EE409DF2D055405A2C45F2950C4C4016139B8F6BCF55405A2C45F2950C4C40
75800	47580	87.628707000000006	87.649242000000001	56.198715	56.191113000000001	Студенческая	0103000020E610000001000000050000000BF148BC3CE85540946B0A6476184C400BF148BC3CE85540C11C3D7E6F194C40234C512E8DE95540C11C3D7E6F194C40234C512E8DE95540946B0A6476184C400BF148BC3CE85540946B0A6476184C40
76000	10066	87.486673999999994	87.516732000000005	56.285663	56.275494000000002	Дорожная	0103000020E610000001000000050000001074B4AA25DF5540431F2C6343234C401074B4AA25DF5540B056ED9A90244C40FD32182312E15540B056ED9A90244C40FD32182312E15540431F2C6343234C401074B4AA25DF5540431F2C6343234C40
76035	47980	88.221990000000005	88.246577000000002	56.066232999999997	56.044252	Центральная	0103000020E6100000010000000500000080828B15350E56402C64AE0CAA054C4080828B15350E56403E75AC527A084C4088BCE5EAC70F56403E75AC527A084C4088BCE5EAC70F56402C64AE0CAA054C4080828B15350E56402C64AE0CAA054C40
76208	60789	87.739531999999997	87.764585999999994	56.313344000000001	56.297338000000003	Ленина	0103000020E610000001000000050000001C96067E54EF5540D5EDEC2B0F264C401C96067E54EF5540EC32FCA71B284C40AF3E1EFAEEF05540EC32FCA71B284C40AF3E1EFAEEF05540D5EDEC2B0F264C401C96067E54EF5540D5EDEC2B0F264C40
75752	48673	87.367583999999994	87.405314000000004	56.391167000000003	56.368459999999999	Трактовая	0103000020E610000001000000050000001AA20A7F86D755402CF180B2292F4C401AA20A7F86D755402123A0C211324C401AA721AAF0D955402123A0C211324C401AA721AAF0D955402CF180B2292F4C401AA20A7F86D755402CF180B2292F4C40
76018	5826	87.148071999999999	87.186160999999998	56.296314000000002	56.278503000000001	Пальчикова	0103000020E61000000100000005000000035DFB027AC95540406B7EFCA5234C40035DFB027AC9554069ACFD9DED254C409AB2D30FEACB554069ACFD9DED254C409AB2D30FEACB5540406B7EFCA5234C40035DFB027AC95540406B7EFCA5234C40
76203	60790	87.514701000000002	87.534509	56.172469999999997	56.166476000000003	Зеленая	0103000020E61000000100000005000000FC8D76DCF0E05540D2C8E7154F154C40FC8D76DCF0E0554043C5387F13164C40BB9A3C6535E2554043C5387F13164C40BB9A3C6535E25540D2C8E7154F154C40FC8D76DCF0E05540D2C8E7154F154C40
50353	8378	85.577538000000004	85.632497000000001	54.682174000000003	54.658948000000002	Советская	0103000020E61000000100000005000000A08CF161F6645540DFE1766858544B40A08CF161F66455403C17467A51574B405C74B2D47A6855403C17467A51574B405C74B2D47A685540DFE1766858544B40A08CF161F6645540DFE1766858544B40
75794	7748	86.307348000000005	86.344600999999997	54.848109999999998	54.827500000000001	Школьная	0103000020E610000001000000050000006D1FF296AB93554052B81E85EB694B406D1FF296AB9355408DB454DE8E6C4B40CF4A5AF10D9655408DB454DE8E6C4B40CF4A5AF10D96554052B81E85EB694B406D1FF296AB93554052B81E85EB694B40
71723	59500	85.942982000000001	85.969059999999999	54.694944999999997	54.682206000000001	50 Лет Октября	0103000020E61000000100000005000000DEAD2CD1597C55404791B58652574B40DEAD2CD1597C554065C22FF5F3584B4027F73B14057E554065C22FF5F3584B4027F73B14057E55404791B58652574B40DEAD2CD1597C55404791B58652574B40
75955	45907	86.389813000000004	86.431863000000007	54.822454	54.814014	Центральная	0103000020E6100000010000000500000090A339B2F29855403A3E5A9C31684B4090A339B2F2985540713B342C46694B408F56B5A4A39B5540713B342C46694B408F56B5A4A39B55403A3E5A9C31684B4090A339B2F29855403A3E5A9C31684B40
75946	6768	86.033693999999997	86.048839999999998	54.824388999999996	54.809018000000002	Центральная	0103000020E610000001000000050000009204E10A288255400BF0DDE68D674B409204E10A288255405017299485694B4025AFCE31208355405017299485694B4025AFCE31208355400BF0DDE68D674B409204E10A288255400BF0DDE68D674B40
75924	7040	85.309866999999997	85.338721000000007	54.577122000000003	54.565854000000002	Старательская	0103000020E6100000010000000500000004C765DCD4535540C82764E76D484B4004C765DCD4535540ACE63922DF494B40FB5DD89AAD555540ACE63922DF494B40FB5DD89AAD555540C82764E76D484B4004C765DCD4535540C82764E76D484B40
75943	46042	86.061856000000006	86.086298999999997	54.729630999999998	54.711883999999998	Зеленая	0103000020E61000000100000005000000EE43DE72F5835540D845D1031F5B4B40EE43DE72F5835540EA92718C645D4B405CAB3DEC85855540EA92718C645D4B405CAB3DEC85855540D845D1031F5B4B40EE43DE72F5835540D845D1031F5B4B40
75947	6739	86.057670000000002	86.076481000000001	54.836289999999998	54.827235999999999	Горка	0103000020E6100000010000000500000076FD82DDB0835540740987DEE2694B4076FD82DDB083554065FCFB8C0B6B4B40FC709010E584554065FCFB8C0B6B4B40FC709010E5845540740987DEE2694B4076FD82DDB0835540740987DEE2694B40
12343	8514	85.680493999999996	85.718294999999998	54.688878000000003	54.675334999999997	Весенняя	0103000020E61000000100000005000000F3C7B4368D6B55400D6C956071564B40F3C7B4368D6B55408A7780272D584B405778978BF86D55408A7780272D584B405778978BF86D55400D6C956071564B40F3C7B4368D6B55400D6C956071564B40
75942	45834	86.085139999999996	86.096288999999999	54.644790999999998	54.633161000000001	Апрельская	0103000020E6100000010000000500000036E50AEF72855540240D6E6B0B514B4036E50AEF72855540A8E0F08288524B40BB7D569929865540A8E0F08288524B40BB7D569929865540240D6E6B0B514B4036E50AEF72855540240D6E6B0B514B40
76022	46581	86.414831000000007	86.424210000000002	54.909199000000001	54.890241000000003	Центральная	0103000020E610000001000000050000007D9752978C9A55407847C66AF3714B407D9752978C9A5540284701A260744B40B728B341269B5540284701A260744B40B728B341269B55407847C66AF3714B407D9752978C9A55407847C66AF3714B40
13599	41247	86.126408999999995	86.156422000000006	54.590285999999999	54.575786000000001	Школьная	0103000020E61000000100000005000000E23AC6151788554051BF0B5BB3494B40E23AC61517885540B1A4DC7D8E4B4B40FF976BD1028A5540B1A4DC7D8E4B4B40FF976BD1028A554051BF0B5BB3494B40E23AC6151788554051BF0B5BB3494B40
75893	60743	86.027000999999998	86.039308000000005	54.406821000000001	54.396973000000003	Садовая	0103000020E6100000010000000500000065FD6662BA8155409032E202D0324B4065FD6662BA815540BB29E5B512344B40289EB30584825540BB29E5B512344B40289EB305848255409032E202D0324B4065FD6662BA8155409032E202D0324B40
75981	6030	86.065969999999993	86.088734000000002	54.716455000000003	54.686604000000003	Заводская	0103000020E6100000010000000500000018213CDA38845540C2A6CEA3E2574B4018213CDA38845540210725CCB45B4B40C5025FD1AD855540210725CCB45B4B40C5025FD1AD855540C2A6CEA3E2574B4018213CDA38845540C2A6CEA3E2574B40
12486	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Ягодная	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76335	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Читинская	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76222	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Токарева	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
12342	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Покрышкина	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
12500	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Панферова	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76337	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Мира	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76314	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Макаренко	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76313	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Крупской	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76351	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Кремлевская	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
13469	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Космонавтов	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76336	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Карбышева	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76329	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Заречная	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
76242	41071	86.210679999999996	86.312702000000002	54.617638999999997	54.567143000000002	Бажова	0103000020E61000000100000005000000F67AF7C77B8D5540E2934E2498484B40F67AF7C77B8D5540F8DD74CB0E4F4B4034D93F4F03945540F8DD74CB0E4F4B4034D93F4F03945540E2934E2498484B40F67AF7C77B8D5540E2934E2498484B40
75789	46276	85.990054000000001	86.019456000000005	54.495977000000003	54.48115	пер. Кольцевой	0103000020E6100000010000000500000089D1730B5D7F5540363CBD52963D4B4089D1730B5D7F5540BB48A12C7C3F4B4081ED60C43E815540BB48A12C7C3F4B4081ED60C43E815540363CBD52963D4B4089D1730B5D7F5540363CBD52963D4B40
50070	46618	86.366529	86.394043999999994	54.960110999999998	54.934055000000001	Советская	0103000020E6100000010000000500000047020D367597554028D53E1D8F774B4047020D3675975540D2C3D0EAE47A4B40D74B530438995540D2C3D0EAE47A4B40D74B53043899554028D53E1D8F774B4047020D367597554028D53E1D8F774B40
75965	46398	86.072609	86.104292999999998	54.502370999999997	54.498142000000001	Центральная	0103000020E610000001000000050000004C1938A0A5845540CC61F71DC33F4B404C1938A0A5845540BABA63B14D404B40E90C8CBCAC865540BABA63B14D404B40E90C8CBCAC865540CC61F71DC33F4B404C1938A0A5845540CC61F71DC33F4B40
75992	46748	85.732991999999996	85.740680999999995	54.801903000000003	54.785164000000002	Магистральная	0103000020E61000000100000005000000B20E4757E96E55408FFF024180644B40B20E4757E96E55403BC8EBC1A4664B4030F14751676F55403BC8EBC1A4664B4030F14751676F55408FFF024180644B40B20E4757E96E55408FFF024180644B40
13585	7013	86.452695000000006	86.466448	54.664468999999997	54.653053	Центральная	0103000020E61000000100000005000000040473F4F89C554000C79E3D97534B40040473F4F89C5540581AF8510D554B403752B648DA9D5540581AF8510D554B403752B648DA9D554000C79E3D97534B40040473F4F89C554000C79E3D97534B40
75961	7590	85.876749000000004	85.915852999999998	54.710324	54.701928000000002	Туснолобовой-Марченко	0103000020E610000001000000050000003F73D6A71C785540C712D6C6D8594B403F73D6A71C7855402EC896E5EB5A4B4062BCE6559D7A55402EC896E5EB5A4B4062BCE6559D7A5540C712D6C6D8594B403F73D6A71C785540C712D6C6D8594B40
75973	7645	86.030288999999996	86.051614999999998	54.617759	54.606662999999998	Никитинская	0103000020E610000001000000050000006D1B4641F0815540BC581822A74D4B406D1B4641F0815540A3E716BA124F4B40EA3E00A94D835540A3E716BA124F4B40EA3E00A94D835540BC581822A74D4B406D1B4641F0815540BC581822A74D4B40
13568	41240	86.310329999999993	86.333434999999994	54.708368	54.685656000000002	Молодежная	0103000020E61000000100000005000000EE3D5C72DC93554031276893C3574B40EE3D5C72DC93554037C478CDAB5A4B40DF15C1FF5695554037C478CDAB5A4B40DF15C1FF5695554031276893C3574B40EE3D5C72DC93554031276893C3574B40
76004	8151	85.757902000000001	85.791471999999999	54.716465999999997	54.703831999999998	Советская	0103000020E61000000100000005000000ACE46377817055406BF0BE2A175A4B40ACE463778170554014596B28B55B4B40C8EC2C7AA772554014596B28B55B4B40C8EC2C7AA77255406BF0BE2A175A4B40ACE46377817055406BF0BE2A175A4B40
75786	46512	85.916904000000002	85.940196999999998	54.617393999999997	54.606439000000002	Весенняя	0103000020E6100000010000000500000095641D8EAE7A55406D020CCB9F4D4B4095641D8EAE7A5540915F3FC4064F4B4007B309302C7C5540915F3FC4064F4B4007B309302C7C55406D020CCB9F4D4B4095641D8EAE7A55406D020CCB9F4D4B40
50085	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	проспект Шахтеров	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50042	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	проспект Текстильщиков	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
12455	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	проспект Ленина	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50081	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	проспект Кольчугинский	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
12549	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	проспект Кирова	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
12557	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	проспект Дзержинского	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50264	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	площадь Кирова	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50306	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	переулок Челюскина	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50294	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	бульвар Химиков	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50296	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Юргинская	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50119	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Энгельса	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50301	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Широкая	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50125	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Шилина	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
13474	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Шевцовой	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
13396	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Топкинская	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
75932	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Телефонная	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
13566	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Суворова	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50121	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Советская	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50118	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Садовая	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50108	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Рылеева	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50307	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Рубинштейна	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
12491	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Пушкина	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50035	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Пирогова	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
75634	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Мусохранова	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50293	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Лесной городок	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50123	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Кирсанова	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
13533	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Зорина	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50109	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Зварыгина	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
12532	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Горького	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
13549	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Глинки	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50299	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Вокзальная	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
50124	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	Витебская	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
12584	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	7 Ноября	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
13580	43	86.122006999999996	86.249235999999996	54.717246000000003	54.617215999999999	 Ноября	0103000020E6100000010000000500000084B872F6CE875540B24813EF004F4B4084B872F6CE875540EA9788B7CE5B4B40183F8D7BF38F5540EA9788B7CE5B4B40183F8D7BF38F5540B24813EF004F4B4084B872F6CE875540B24813EF004F4B40
9906	6842	86.298544000000007	86.339391000000006	54.663775999999999	54.639034000000002	Центральная	0103000020E61000000100000005000000B11A4B581B9355401B84B9DDCB514B40B11A4B581B93554052EFA99CF6544B40A2630795B895554052EFA99CF6544B40A2630795B89555401B84B9DDCB514B40B11A4B581B9355401B84B9DDCB514B40
12499	41110	85.335172999999998	85.412751	54.618608000000002	54.594673	40 Лет Октября	0103000020E6100000010000000500000024607479735555403868AF3E1E4C4B402460747973555540A185048C2E4F4B400B992B836A5A5540A185048C2E4F4B400B992B836A5A55403868AF3E1E4C4B4024607479735555403868AF3E1E4C4B40
50014	7337	85.335172999999998	85.412751	54.618608000000002	54.594673	40 лет Октября	0103000020E6100000010000000500000024607479735555403868AF3E1E4C4B402460747973555540A185048C2E4F4B400B992B836A5A5540A185048C2E4F4B400B992B836A5A55403868AF3E1E4C4B4024607479735555403868AF3E1E4C4B40
75941	60753	86.192982999999998	86.201938999999996	54.739789000000002	54.727209000000002	пер. Энергетиков	0103000020E61000000100000005000000C66B5ED5598C5540AE2D3C2F155D4B40C66B5ED5598C55406478EC67B15E4B405D328E91EC8C55406478EC67B15E4B405D328E91EC8C5540AE2D3C2F155D4B40C66B5ED5598C5540AE2D3C2F155D4B40
75787	8574	85.779650000000004	85.809510000000003	54.628329999999998	54.609912000000001	Центральная	0103000020E61000000100000005000000E4141DC9E57155400FB8AE98114E4B40E4141DC9E57155403F8C101E6D504B403DF20703CF7355403F8C101E6D504B403DF20703CF7355400FB8AE98114E4B40E4141DC9E57155400FB8AE98114E4B40
75846	60734	86.106305000000006	86.119887000000006	54.717958000000003	54.709668000000001	Полевая	0103000020E61000000100000005000000AF997CB3CD8655404582A966D65A4B40AF997CB3CD86554067F3380CE65B4B40CC0D863AAC87554067F3380CE65B4B40CC0D863AAC8755404582A966D65A4B40AF997CB3CD8655404582A966D65A4B40
12466	6657	86.022941000000003	86.055244999999999	54.775345000000002	54.748728	переулок Рабочий	0103000020E61000000100000005000000342F87DD77815540BCCCB051D65F4B40342F87DD77815540FE0E45813E634B401F11532289835540FE0E45813E634B401F11532289835540BCCCB051D65F4B40342F87DD77815540BCCCB051D65F4B40
13550	41234	86.230147000000002	86.261551999999995	54.762298000000001	54.738920999999998	Чкалова	0103000020E6100000010000000500000071917BBABA8E5540EFA99CF6945E4B4071917BBABA8E554032E719FB92614B40048D9944BD90554032E719FB92614B40048D9944BD905540EFA99CF6945E4B4071917BBABA8E5540EFA99CF6945E4B40
75788	6005	86.060715000000002	86.088194999999999	54.689622	54.678426999999999	Вострикова	0103000020E610000001000000050000001BD82AC1E283554098DC28B2D6564B401BD82AC1E2835540124DA08845584B40ED2AA4FCA4855540124DA08845584B40ED2AA4FCA485554098DC28B2D6564B401BD82AC1E283554098DC28B2D6564B40
75986	7701	85.854004000000003	85.872680000000003	54.573923000000001	54.566046999999998	Октябрьская	0103000020E61000000100000005000000CEA96400A8765540DC7F643A74484B40CEA96400A87655400BB6114F76494B40E4F736FDD97755400BB6114F76494B40E4F736FDD9775540DC7F643A74484B40CEA96400A8765540DC7F643A74484B40
12588	41125	85.396618000000004	85.423908999999995	54.569043000000001	54.545000000000002	Центральная	0103000020E6100000010000000500000051C0763062595540F6285C8FC2454B4051C07630625955404582A966D6484B40B9DE3653215B55404582A966D6484B40B9DE3653215B5540F6285C8FC2454B4051C0763062595540F6285C8FC2454B40
75781	5759	86.333613999999997	86.363735000000005	55.078288000000001	55.064596999999999	Московская	0103000020E6100000010000000500000037DF88EE59955540B935E9B644884B4037DF88EE59955540AAD55757058A4B40475A2A6F47975540AAD55757058A4B40475A2A6F47975540B935E9B644884B4037DF88EE59955540B935E9B644884B40
75780	5283	86.669863000000007	86.704393999999994	54.760058999999998	54.738847999999997	Садовая	0103000020E610000001000000050000003B730F09DFAA5540855B3E92925E4B403B730F09DFAA5540E603029D49614B40E95F92CA14AD5540E603029D49614B40E95F92CA14AD5540855B3E92925E4B403B730F09DFAA5540855B3E92925E4B40
75935	4517	86.223122000000004	86.257033000000007	54.965480999999997	54.954884	Школьная	0103000020E6100000010000000500000029417FA1478E5540A1BC8FA3397A4B4029417FA1478E554066F4A3E1947B4B408A3F8A3A7390554066F4A3E1947B4B408A3F8A3A73905540A1BC8FA3397A4B4029417FA1478E5540A1BC8FA3397A4B40
75959	5922	86.396703000000002	86.432042999999993	55.074896000000003	55.063622000000002	Центральная	0103000020E6100000010000000500000068CEFA94639955402FA704C424884B4068CEFA9463995540F54C2F3196894B40CEDDAE97A69B5540F54C2F3196894B40CEDDAE97A69B55402FA704C424884B4068CEFA94639955402FA704C424884B40
75950	5185	86.780248	86.800882000000001	54.874656999999999	54.859434999999998	Набережная	0103000020E610000001000000050000003EB14E95EFB15540D50451F7016E4B403EB14E95EFB15540D61BB5C2F46F4B40207D93A641B35540D61BB5C2F46F4B40207D93A641B35540D50451F7016E4B403EB14E95EFB15540D50451F7016E4B40
76159	60774	86.475530000000006	86.490747999999996	55.018045000000001	55.009419000000001	Школьная	0103000020E61000000100000005000000159161156F9E5540037B4CA434814B40159161156F9E55409C6D6E4C4F824B40F4A44C6A689F55409C6D6E4C4F824B40F4A44C6A689F5540037B4CA434814B40159161156F9E5540037B4CA434814B40
75778	5439	86.54974	86.589697000000001	54.892411000000003	54.872264000000001	Центральная	0103000020E610000001000000050000006553AEF02EA3554034BDC458A66F4B406553AEF02EA355409BCB0D863A724B4028637C98BDA555409BCB0D863A724B4028637C98BDA5554034BDC458A66F4B406553AEF02EA3554034BDC458A66F4B40
76167	60777	86.161955000000006	86.182175999999998	55.052221000000003	55.039729000000001	Советская	0103000020E610000001000000050000001E1B81785D8A5540F5D901D715854B401E1B81785D8A55400C957F2DAF864B406E8786C5A88B55400C957F2DAF864B406E8786C5A88B5540F5D901D715854B401E1B81785D8A5540F5D901D715854B40
75956	4339	86.638637000000003	86.647630000000007	55.004928	54.997729	Кооперативная	0103000020E61000000100000005000000FF40B96DDFA85540A9A27895B57F4B40FF40B96DDFA85540D76A0F7BA1804B40257A19C572A95540D76A0F7BA1804B40257A19C572A95540A9A27895B57F4B40FF40B96DDFA85540A9A27895B57F4B40
13535	5093	86.818696000000003	86.840686000000005	54.943080000000002	54.921354999999998	60 лет октября	0103000020E610000001000000050000006D57E88365B45540C780ECF5EE754B406D57E88365B455407FC16ED8B6784B40200DA7CCCDB555407FC16ED8B6784B40200DA7CCCDB55540C780ECF5EE754B406D57E88365B45540C780ECF5EE754B40
75944	4682	86.521794	86.538915000000003	54.831254999999999	54.825420999999999	Школьная	0103000020E61000000100000005000000F04FA91265A155403F373465A7694B40F04FA91265A1554078D15790666A4B40BA1457957DA2554078D15790666A4B40BA1457957DA255403F373465A7694B40F04FA91265A155403F373465A7694B40
75945	60754	86.256719000000004	86.276229999999998	55.003394	54.992193	Ленина	0103000020E61000000100000005000000C25087156E905540FA28232E007F4B40C25087156E9055405680EF366F804B40240B98C0AD9155405680EF366F804B40240B98C0AD915540FA28232E007F4B40C25087156E905540FA28232E007F4B40
75613	3886	86.763997000000003	86.835403999999997	55.031298	54.981954999999999	Юбилейная	0103000020E610000001000000050000007F4FAC53E5B05540649291B3B07D4B407F4FAC53E5B055401137A79201844B40A5BC564277B555401137A79201844B40A5BC564277B55540649291B3B07D4B407F4FAC53E5B05540649291B3B07D4B40
50155	3886	86.763997000000003	86.835403999999997	55.031298	54.981954999999999	Мостовая	0103000020E610000001000000050000007F4FAC53E5B05540649291B3B07D4B407F4FAC53E5B055401137A79201844B40A5BC564277B555401137A79201844B40A5BC564277B55540649291B3B07D4B407F4FAC53E5B05540649291B3B07D4B40
50154	3886	86.763997000000003	86.835403999999997	55.031298	54.981954999999999	Кирова	0103000020E610000001000000050000007F4FAC53E5B05540649291B3B07D4B407F4FAC53E5B055401137A79201844B40A5BC564277B555401137A79201844B40A5BC564277B55540649291B3B07D4B407F4FAC53E5B05540649291B3B07D4B40
75940	5125	86.82696	86.858743000000004	54.778818999999999	54.771227000000003	Центральная	0103000020E6100000010000000500000069C6A2E9ECB455406765FB90B7624B4069C6A2E9ECB4554070404B57B0634B40D02A33A5F5B6554070404B57B0634B40D02A33A5F5B655406765FB90B7624B4069C6A2E9ECB455406765FB90B7624B40
75948	5262	86.707915	86.733410000000006	54.961221999999999	54.944895000000002	Мира	0103000020E610000001000000050000004356B77A4EAD5540B493C151F2784B404356B77A4EAD55400D198F52097B4B40CD237F30F0AE55400D198F52097B4B40CD237F30F0AE5540B493C151F2784B404356B77A4EAD5540B493C151F2784B40
75782	4842	86.691854000000006	86.717491999999993	54.805515	54.793053999999998	Почтовая	0103000020E61000000100000005000000D6E6FF5547AC554022FB20CB82654B40D6E6FF5547AC5540FEB7921D1B674B4010C99063EBAD5540FEB7921D1B674B4010C99063EBAD554022FB20CB82654B40D6E6FF5547AC554022FB20CB82654B40
50351	4234	86.938638999999995	86.976637999999994	55.009172	54.996727	Центральная	0103000020E6100000010000000500000002F04FA912BC5540250516C0947F4B4002F04FA912BC5540FB04508C2C814B40F981AB3C81BE5540FB04508C2C814B40F981AB3C81BE5540250516C0947F4B4002F04FA912BC5540250516C0947F4B40
75836	60731	86.382194999999996	86.397008999999997	55.011597999999999	54.989130000000003	Школьная	0103000020E61000000100000005000000766C04E2759855400ABFD4CF9B7E4B40766C04E2759855407959130B7C814B40EECD6F98689955407959130B7C814B40EECD6F98689955400ABFD4CF9B7E4B40766C04E2759855400ABFD4CF9B7E4B40
75938	5608	86.595517999999998	86.614221000000001	54.779654999999998	54.769413999999998	Мира	0103000020E610000001000000050000007A8B87F71CA65540D28A6F287C624B407A8B87F71CA65540D9942BBCCB634B400DE198654FA75540D9942BBCCB634B400DE198654FA75540D28A6F287C624B407A8B87F71CA65540D28A6F287C624B40
76297	4621	86.543711999999999	86.585170000000005	54.819662999999998	54.796531999999999	Санаторий	0103000020E61000000100000005000000569C6A2DCCA25540D61BB5C2F4654B40569C6A2DCCA25540E15E99B7EA684B406C26DF6C73A55540E15E99B7EA684B406C26DF6C73A55540D61BB5C2F4654B40569C6A2DCCA25540D61BB5C2F4654B40
50013	4621	86.543711999999999	86.585170000000005	54.819662999999998	54.796531999999999	Геологов	0103000020E61000000100000005000000569C6A2DCCA25540D61BB5C2F4654B40569C6A2DCCA25540E15E99B7EA684B406C26DF6C73A55540E15E99B7EA684B406C26DF6C73A55540D61BB5C2F4654B40569C6A2DCCA25540D61BB5C2F4654B40
75936	5768	86.497664999999998	86.518613999999999	55.129565999999997	55.110284999999998	Новая	0103000020E6100000010000000500000049D74CBED99F5540A31EA2D11D8E4B4049D74CBED99F55403656629E95904B40DB4FC6F830A155403656629E95904B40DB4FC6F830A15540A31EA2D11D8E4B4049D74CBED99F5540A31EA2D11D8E4B40
75905	5534	86.471604999999997	86.494197	54.87144	54.859952999999997	Школьная	0103000020E6100000010000000500000053E8BCC62E9E55406D8C9DF0126E4B4053E8BCC62E9E55408F368E588B6F4B40013274ECA09F55408F368E588B6F4B40013274ECA09F55406D8C9DF0126E4B4053E8BCC62E9E55406D8C9DF0126E4B40
75779	4404	86.183102000000005	86.221845999999999	54.982771	54.966648999999997	Юбилейная	0103000020E61000000100000005000000437573F1B78B554005DB8827BB7B4B40437573F1B78B5540863AAC70CB7D4B40E6AF90B9328E5540863AAC70CB7D4B40E6AF90B9328E554005DB8827BB7B4B40437573F1B78B554005DB8827BB7B4B40
75769	4254	86.690398000000002	86.726933000000002	55.092041000000002	55.076602000000001	Центральная	0103000020E6100000010000000500000053CE177B2FAC554073672618CE894B4053CE177B2FAC55401172DEFFC78B4B408658FD1186AE55401172DEFFC78B4B408658FD1186AE554073672618CE894B4053CE177B2FAC554073672618CE894B40
75937	4991	86.866809000000003	86.886977000000002	54.807259000000002	54.799542000000002	Почтовая	0103000020E6100000010000000500000039B874CC79B75540A4E36A6457664B4039B874CC79B755406A334E4354674B4078D32D3BC4B855406A334E4354674B4078D32D3BC4B85540A4E36A6457664B4039B874CC79B75540A4E36A6457664B40
75713	60710	87.123844000000005	87.125703999999999	53.740093999999999	53.737985000000002	Студенческая	0103000020E610000001000000050000009373620FEDC7554023F8DF4A76DE4A409373620FEDC75540A0FB7266BBDE4A407D3ECA880BC85540A0FB7266BBDE4A407D3ECA880BC8554023F8DF4A76DE4A409373620FEDC7554023F8DF4A76DE4A40
75649	60710	87.123844000000005	87.125703999999999	53.740093999999999	53.737985000000002	Весенняя	0103000020E610000001000000050000009373620FEDC7554023F8DF4A76DE4A409373620FEDC75540A0FB7266BBDE4A407D3ECA880BC85540A0FB7266BBDE4A407D3ECA880BC8554023F8DF4A76DE4A409373620FEDC7554023F8DF4A76DE4A40
13395	41184	85.977406000000002	86.025419999999997	55.258592	55.234614999999998	Центральная	0103000020E61000000100000005000000823AE5D18D7E5540551344DD079E4B40823AE5D18D7E5540ED80EB8A19A14B40842A357BA0815540ED80EB8A19A14B40842A357BA0815540551344DD079E4B40823AE5D18D7E5540551344DD079E4B40
75765	3495	85.909312999999997	85.937466000000001	55.568618999999998	55.557169000000002	Советская	0103000020E61000000100000005000000F834272F327A55402AAC545051C74B40F834272F327A55402E71E481C8C84B402AC76471FF7B55402E71E481C8C84B402AC76471FF7B55402AAC545051C74B40F834272F327A55402AAC545051C74B40
75927	3269	85.911738999999997	85.924315000000007	55.613686999999999	55.607559999999999	Школьная	0103000020E6100000010000000500000037DF88EE597A5540CB2DAD86C4CD4B4037DF88EE597A55407C7DAD4B8DCE4B40F20C1AFA277B55407C7DAD4B8DCE4B40F20C1AFA277B5540CB2DAD86C4CD4B4037DF88EE597A5540CB2DAD86C4CD4B40
75931	3401	85.798084000000003	85.810147999999998	55.628551000000002	55.615304000000002	Школьная	0103000020E610000001000000050000007FDDE9CE137355408B8C0E48C2CE4B407FDDE9CE137355401E6FF25B74D04B40DE3AFF76D97355401E6FF25B74D04B40DE3AFF76D97355408B8C0E48C2CE4B407FDDE9CE137355408B8C0E48C2CE4B40
75928	2099	86.579240999999996	86.611965999999995	55.721828000000002	55.700557000000003	Промысловая	0103000020E6100000010000000500000026E0D74812A55540F0FD0DDAABD94B4026E0D74812A5554026AB22DC64DC4B40E41071732AA7554026AB22DC64DC4B40E41071732AA75540F0FD0DDAABD94B4026E0D74812A55540F0FD0DDAABD94B40
75922	2565	86.348804999999999	86.367058999999998	55.365678000000003	55.354773000000002	Центральная	0103000020E610000001000000050000009AEB34D2529655407D40A03369AD4B409AEB34D252965540F06E6589CEAE4B40F52C08E57D975540F06E6589CEAE4B40F52C08E57D9755407D40A03369AD4B409AEB34D2529655407D40A03369AD4B40
13346	41176	86.105639999999994	86.132238999999998	55.241703999999999	55.235030999999999	Школьная	0103000020E61000000100000005000000904946CEC2865540E945ED7E159E4B40904946CEC2865540FCA71B28F09E4B405E10919A76885540FCA71B28F09E4B405E10919A76885540E945ED7E159E4B40904946CEC2865540E945ED7E159E4B40
75756	2778	86.354303000000002	86.378889999999998	55.170614	55.150849000000001	Советская	0103000020E61000000100000005000000FB777DE6AC96554031D120054F934B40FB777DE6AC965540B01EF7ADD6954B4003B2D7BB3F985540B01EF7ADD6954B4003B2D7BB3F98554031D120054F934B40FB777DE6AC96554031D120054F934B40
75925	48904	86.004138999999995	86.016886	55.846659000000002	55.835599000000002	Школьная	0103000020E61000000100000005000000D76839D04380554000C974E8F4EA4B40D76839D0438055409AEE75525FEC4B40A87004A9148155409AEE75525FEC4B40A87004A91481554000C974E8F4EA4B40D76839D04380554000C974E8F4EA4B40
75777	2675	86.285914000000005	86.309396000000007	55.275047000000001	55.261054000000001	Центральная	0103000020E61000000100000005000000FDDD3B6A4C925540B83EAC376AA14B40FDDD3B6A4C92554074EE76BD34A34B40D960E124CD93554074EE76BD34A34B40D960E124CD935540B83EAC376AA14B40FDDD3B6A4C925540B83EAC376AA14B40
75750	1979	86.149523000000002	86.169070000000005	55.744627000000001	55.723775000000003	Коммунистическая	0103000020E61000000100000005000000FDBFEAC891895540CA54C1A8A4DC4B40FDBFEAC891895540FB5B02F04FDF4B40062FFA0AD28A5540FB5B02F04FDF4B40062FFA0AD28A5540CA54C1A8A4DC4B40FDBFEAC891895540CA54C1A8A4DC4B40
76499	60866	86.139623	86.213806000000005	55.512469000000003	55.455039999999997	Промышленное шоссе	0103000020E610000001000000050000003EB14E95EF885540982F2FC03EBA4B403EB14E95EF8855405F9B8D9598C14B40126C5CFFAE8D55405F9B8D9598C14B40126C5CFFAE8D5540982F2FC03EBA4B403EB14E95EF885540982F2FC03EBA4B40
75767	2667	86.287863000000002	86.320651999999995	55.393773000000003	55.385249000000002	Центральная	0103000020E610000001000000050000009FAEEE586C9255408AE8D7D64FB14B409FAEEE586C9255401F86562767B24B406859F78F859455401F86562767B24B406859F78F859455408AE8D7D64FB14B409FAEEE586C9255408AE8D7D64FB14B40
50262	2330	86.195418000000004	86.239444000000006	55.261526000000003	55.241160000000001	Набережная	0103000020E610000001000000050000002FC37FBA818C55403B8DB454DE9E4B402FC37FBA818C5540E08618AF79A14B404D4EED0C538F5540E08618AF79A14B404D4EED0C538F55403B8DB454DE9E4B402FC37FBA818C55403B8DB454DE9E4B40
75783	60726	85.729478999999998	86.659101000000007	55.866556000000003	55.104754	Школьная	0103000020E610000001000000050000009A07B0C8AF6E554006103E94688D4B409A07B0C8AF6E55408813984EEBEE4B40B3F0F5B52EAA55408813984EEBEE4B40B3F0F5B52EAA554006103E94688D4B409A07B0C8AF6E554006103E94688D4B40
50010	2220	86.138366000000005	86.172141999999994	55.150272999999999	55.133600999999999	Лобанова	0103000020E61000000100000005000000373811FDDA88554040DB6AD619914B40373811FDDA885540643C4A253C934B402711E15F048B5540643C4A253C934B402711E15F048B554040DB6AD619914B40373811FDDA88554040DB6AD619914B40
76318	45980	86.075869999999995	86.128888000000003	55.530372999999997	55.499299999999998	Стадионная	0103000020E61000000100000005000000D72FD80DDB8455404772F90FE9BF4B40D72FD80DDB84554038D73043E3C34B40333674B33F88554038D73043E3C34B40333674B33F8855404772F90FE9BF4B40D72FD80DDB8455404772F90FE9BF4B40
76285	45980	86.075869999999995	86.128888000000003	55.530372999999997	55.499299999999998	Советская	0103000020E61000000100000005000000D72FD80DDB8455404772F90FE9BF4B40D72FD80DDB84554038D73043E3C34B40333674B33F88554038D73043E3C34B40333674B33F8855404772F90FE9BF4B40D72FD80DDB8455404772F90FE9BF4B40
76267	45980	86.075869999999995	86.128888000000003	55.530372999999997	55.499299999999998	Новогодняя	0103000020E61000000100000005000000D72FD80DDB8455404772F90FE9BF4B40D72FD80DDB84554038D73043E3C34B40333674B33F88554038D73043E3C34B40333674B33F8855404772F90FE9BF4B40D72FD80DDB8455404772F90FE9BF4B40
75773	2790	85.837682000000001	85.860211000000007	55.460594	55.449734999999997	Центральная	0103000020E61000000100000005000000AA9CF6949C755540EB6E9EEA90B94B40AA9CF6949C755540EE5D83BEF4BA4B40352A70B20D775540EE5D83BEF4BA4B40352A70B20D775540EB6E9EEA90B94B40AA9CF6949C755540EB6E9EEA90B94B40
13388	3456	85.932525999999996	85.975258999999994	55.491762999999999	55.459260999999998	Московская	0103000020E61000000100000005000000DC2A8881AE7B554004AA7F10C9BA4B40DC2A8881AE7B554001310917F2BE4B404C88B9A46A7E554001310917F2BE4B404C88B9A46A7E554004AA7F10C9BA4B40DC2A8881AE7B554004AA7F10C9BA4B40
12425	41093	85.803670999999994	85.823452000000003	55.406002000000001	55.395935999999999	Весенняя	0103000020E61000000100000005000000976F7D586F7355408FA7E507AEB24B40976F7D586F735540280EA0DFF7B34B40DA740470B3745540280EA0DFF7B34B40DA740470B37455408FA7E507AEB24B40976F7D586F7355408FA7E507AEB24B40
50347	2325	86.221971999999994	86.259432000000004	55.244829000000003	55.220993	Абызова	0103000020E610000001000000050000002C280CCA348E55408DD2A57F499C4B402C280CCA348E5540630E828E569F4B404CE2AC889A905540630E828E569F4B404CE2AC889A9055408DD2A57F499C4B402C280CCA348E55408DD2A57F499C4B40
50009	2209	86.294655000000006	86.324145999999999	55.154944	55.120793999999997	Молодежная	0103000020E610000001000000050000009626A5A0DB925540C9C6832D768F4B409626A5A0DB925540105B7A34D5934B404548DDCEBE945540105B7A34D5934B404548DDCEBE945540C9C6832D768F4B409626A5A0DB925540C9C6832D768F4B40
75771	3256	85.932830999999993	85.973516000000004	55.650658	55.626278999999997	Центральная	0103000020E610000001000000050000007A6CCB80B37B5540F69507E929D04B407A6CCB80B37B5540BD70E7C248D34B407F880D164E7E5540BD70E7C248D34B407F880D164E7E5540F69507E929D04B407A6CCB80B37B5540F69507E929D04B40
50152	2449	86.198561999999995	86.236937999999995	55.453524000000002	55.435059000000003	Советская	0103000020E610000001000000050000009D0E643DB58C55404D6A6803B0B74B409D0E643DB58C5540BEF90D130DBA4B407F4B00FE298F5540BEF90D130DBA4B407F4B00FE298F55404D6A6803B0B74B409D0E643DB58C55404D6A6803B0B74B40
76299	60804	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	Советская	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
76214	29220	86.649632999999994	86.668317999999999	56.353085999999998	56.335101000000002	Строителей	0103000020E61000000100000005000000C0594A9693A95540AFEDED96E42A4C40C0594A9693A9554075560BEC312D4C400055DCB8C5AA554075560BEC312D4C400055DCB8C5AA5540AFEDED96E42A4C40C0594A9693A95540AFEDED96E42A4C40
75980	1396	87.054180000000002	87.083573000000001	56.022398000000003	56.015742000000003	Ленина	0103000020E610000001000000050000003A0664AF77C355403A9677D503024C403A0664AF77C3554077BF0AF0DD024C400875914259C5554077BF0AF0DD024C400875914259C555403A9677D503024C403A0664AF77C355403A9677D503024C40
75748	48851	86.868938999999997	86.897729999999996	56.070735999999997	56.043667999999997	Молодежная	0103000020E6100000010000000500000003CE52B29CB75540DCF0BBE996054C4003CE52B29CB755402E5393E00D094C40D6A8876874B955402E5393E00D094C40D6A8876874B95540DCF0BBE996054C4003CE52B29CB75540DCF0BBE996054C40
75919	1313	87.140480999999994	87.179989000000006	56.049520999999999	56.032429	Новая	0103000020E61000000100000005000000662D05A4FDC8554093382BA226044C40662D05A4FDC855408CBB41B456064C40F22895F084CB55408CBB41B456064C40F22895F084CB554093382BA226044C40662D05A4FDC8554093382BA226044C40
75926	48559	86.789446999999996	86.827032000000003	56.444403999999999	56.428981	Советская	0103000020E6100000010000000500000038BBB54C86B255407DCD72D9E8364C4038BBB54C86B25540151BF33AE2384C40B62FA017EEB45540151BF33AE2384C40B62FA017EEB455407DCD72D9E8364C4038BBB54C86B255407DCD72D9E8364C40
75929	1522	86.678450999999995	86.707035000000005	56.295070000000003	56.276803000000001	Ленинская	0103000020E61000000100000005000000103CBEBD6BAB5540A437DC476E234C40103CBEBD6BAB5540EF0390DAC4254C402788BA0F40AD5540EF0390DAC4254C402788BA0F40AD5540A437DC476E234C40103CBEBD6BAB5540A437DC476E234C40
13298	41170	86.756308000000004	86.792689999999993	56.248210999999998	56.236725999999997	Ленинская	0103000020E61000000100000005000000016DAB5967B05540730E9E094D1E4C40016DAB5967B05540F4C0C760C51F4C407077D66EBBB25540F4C0C760C51F4C407077D66EBBB25540730E9E094D1E4C40016DAB5967B05540730E9E094D1E4C40
76063	48428	86.363465000000005	86.377470000000002	56.561045999999997	56.54589	Лесная	0103000020E61000000100000005000000670FB40243975540529B38B9DF454C40670FB402439755409BC6F65AD0474C40274EEE77289855409BC6F65AD0474C40274EEE7728985540529B38B9DF454C40670FB40243975540529B38B9DF454C40
75918	1161	86.764212999999998	86.805059	56.546292000000001	56.523915000000002	Молодежная	0103000020E61000000100000005000000658BA4DDE8B0554022718FA50F434C40658BA4DDE8B05540810871E5EC454C406E162F1686B35540810871E5EC454C406E162F1686B3554022718FA50F434C40658BA4DDE8B0554022718FA50F434C40
76026	48639	86.662739000000002	86.691979000000003	56.569374000000003	56.561528000000003	Заречная	0103000020E6100000010000000500000029B2D6506AAA5540E7E44526E0474C4029B2D6506AAA5540AB984A3FE1484C4034A1496249AC5540AB984A3FE1484C4034A1496249AC5540E7E44526E0474C4029B2D6506AAA5540E7E44526E0474C40
75951	48466	86.600468000000006	86.614203000000003	56.418357999999998	56.398456000000003	Советская	0103000020E61000000100000005000000DA9255116EA655408F72309B00334C40DA9255116EA655408E0244C18C354C40BA86191A4FA755408E0244C18C354C40BA86191A4FA755408F72309B00334C40DA9255116EA655408F72309B00334C40
12401	41086	86.816091	86.845448000000005	56.140464000000001	56.132303	Школьная	0103000020E61000000100000005000000D6E3BED53AB45540D314014EEF104C40D6E3BED53AB45540F7216FB9FA114C40FE9DEDD11BB65540F7216FB9FA114C40FE9DEDD11BB65540D314014EEF104C40D6E3BED53AB45540D314014EEF104C40
75975	1390	87.181884999999994	87.194226999999998	56.000120000000003	55.979585999999998	Молодежная	0103000020E6100000010000000500000082A8FB00A4CB55404ACFF41263FD4B4082A8FB00A4CB5540AB09A2EE03004C40034015376ECC5540AB09A2EE03004C40034015376ECC55404ACFF41263FD4B4082A8FB00A4CB55404ACFF41263FD4B40
13291	41165	86.898295000000005	86.928398000000001	56.541632	56.52966	Набережная	0103000020E6100000010000000500000043CA4FAA7DB95540EBFF1CE6CB434C4043CA4FAA7DB95540C93B873254454C40FFEA71DF6ABB5540C93B873254454C40FFEA71DF6ABB5540EBFF1CE6CB434C4043CA4FAA7DB95540EBFF1CE6CB434C40
75758	48501	86.922792999999999	86.963639000000001	55.912072000000002	55.890492000000002	Школьный переулок	0103000020E6100000010000000500000093FE5E0A0FBB5540C1AC50A4FBF14B4093FE5E0A0FBB554075CC79C6BEF44B409C89E942ACBD554075CC79C6BEF44B409C89E942ACBD5540C1AC50A4FBF14B4093FE5E0A0FBB5540C1AC50A4FBF14B40
76021	923	86.875370000000004	86.893219999999999	55.905093999999998	55.897402	Центральная	0103000020E610000001000000050000009279E40F06B85540B8AE9811DEF24B409279E40F06B8554025E7C41EDAF34B40850838842AB9554025E7C41EDAF34B40850838842AB95540B8AE9811DEF24B409279E40F06B85540B8AE9811DEF24B40
76024	1057	86.765649999999994	86.778172999999995	56.377347999999998	56.367122999999999	Школьная	0103000020E61000000100000005000000AC8BDB6800B15540014EEFE2FD2E4C40AC8BDB6800B15540029B73F04C304C4055682096CDB15540029B73F04C304C4055682096CDB15540014EEFE2FD2E4C40AC8BDB6800B15540014EEFE2FD2E4C40
75746	452	86.535833999999994	86.571982000000006	56.482826000000003	56.464868000000003	Микрорайон	0103000020E610000001000000050000006E85B01A4BA255407D7A6CCB803B4C406E85B01A4BA255404AD40B3ECD3D4C40A5F9635A9BA455404AD40B3ECD3D4C40A5F9635A9BA455407D7A6CCB803B4C406E85B01A4BA255407D7A6CCB803B4C40
75743	183	86.608508	86.672602999999995	56.206916999999997	56.182191000000003	Почтовая	0103000020E61000000100000005000000AED689CBF1A655401250E10852174C40AED689CBF1A6554043FE99417C1A4C40410C74ED0BAB554043FE99417C1A4C40410C74ED0BAB55401250E10852174C40AED689CBF1A655401250E10852174C40
76221	183	86.608508	86.672602999999995	56.206916999999997	56.182191000000003	Лесная	0103000020E61000000100000005000000AED689CBF1A655401250E10852174C40AED689CBF1A6554043FE99417C1A4C40410C74ED0BAB554043FE99417C1A4C40410C74ED0BAB55401250E10852174C40AED689CBF1A655401250E10852174C40
50068	183	86.608508	86.672602999999995	56.206916999999997	56.182191000000003	Ленинская	0103000020E61000000100000005000000AED689CBF1A655401250E10852174C40AED689CBF1A6554043FE99417C1A4C40410C74ED0BAB554043FE99417C1A4C40410C74ED0BAB55401250E10852174C40AED689CBF1A655401250E10852174C40
75753	183	86.608508	86.672602999999995	56.206916999999997	56.182191000000003	Комсомольская	0103000020E61000000100000005000000AED689CBF1A655401250E10852174C40AED689CBF1A6554043FE99417C1A4C40410C74ED0BAB554043FE99417C1A4C40410C74ED0BAB55401250E10852174C40AED689CBF1A655401250E10852174C40
75742	183	86.608508	86.672602999999995	56.206916999999997	56.182191000000003	Кирова	0103000020E61000000100000005000000AED689CBF1A655401250E10852174C40AED689CBF1A6554043FE99417C1A4C40410C74ED0BAB554043FE99417C1A4C40410C74ED0BAB55401250E10852174C40AED689CBF1A655401250E10852174C40
75916	31	86.623491999999999	86.641295999999997	56.167754000000002	56.151201	Москалева	0103000020E610000001000000050000005454FD4AE7A75540AE0FEB8D5A134C405454FD4AE7A75540F8E28BF678154C408FC360FE0AA95540F8E28BF678154C408FC360FE0AA95540AE0FEB8D5A134C405454FD4AE7A75540AE0FEB8D5A134C40
12375	41077	86.812911	86.842096999999995	55.948644000000002	55.938017000000002	Трактовая	0103000020E61000000100000005000000C1E3DBBB06B45540C80BE9F010F84B40C1E3DBBB06B45540F8C5A52A6DF94B40D2C3D0EAE4B55540F8C5A52A6DF94B40D2C3D0EAE4B55540C80BE9F010F84B40C1E3DBBB06B45540C80BE9F010F84B40
75957	1756	86.933464000000001	86.964618000000002	56.143613999999999	56.131439999999998	Школьная	0103000020E6100000010000000500000093FFC9DFBDBB554070B1A206D3104C4093FFC9DFBDBB5540B69F8CF161124C4082C8224DBCBD5540B69F8CF161124C4082C8224DBCBD554070B1A206D3104C4093FFC9DFBDBB554070B1A206D3104C40
75921	1500	86.865758	86.889078999999995	56.239277999999999	56.231797999999998	Ленинская	0103000020E6100000010000000500000006103E9468B755409CA38E8EAB1D4C4006103E9468B755407E5358A9A01E4C40DD239BABE6B855407E5358A9A01E4C40DD239BABE6B855409CA38E8EAB1D4C4006103E9468B755409CA38E8EAB1D4C40
75989	17165	87.051602000000003	87.079359999999994	56.213661000000002	56.205696000000003	Молодежная	0103000020E61000000100000005000000209A79724DC3554082751C3F541A4C40209A79724DC3554020B75F3E591B4C401327F73B14C5554020B75F3E591B4C401327F73B14C5554082751C3F541A4C40209A79724DC3554082751C3F541A4C40
76020	48327	86.553944000000001	86.589751000000007	56.120538000000003	56.106699999999996	Колхозная	0103000020E6100000010000000500000030F488D173A35540D93D7958A80D4C4030F488D173A355406FF607CA6D0F4C402272FA7ABEA555406FF607CA6D0F4C402272FA7ABEA55540D93D7958A80D4C4030F488D173A35540D93D7958A80D4C40
12295	41059	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	Широкая	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
75882	60742	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	Стахановская	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
76182	60742	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	Солнечная	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
76189	60742	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	Пушкина	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
76169	60742	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	Мира	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
76173	60742	85.380277000000007	85.415761000000003	54.464356000000002	54.440911	Алтайская	0103000020E61000000100000005000000F29A5775565855402CB98AC56F384B40F29A577556585540C7D97404703B4B40F27C06D49B5A5540C7D97404703B4B40F27C06D49B5A55402CB98AC56F384B40F29A5775565855402CB98AC56F384B40
76172	60779	85.921386999999996	85.954885000000004	54.450167	54.436453999999998	Советская	0103000020E6100000010000000500000069FD2D01F87A5540AC1A84B9DD374B4069FD2D01F87A5540855E7F129F394B40399CF9D51C7D5540855E7F129F394B40399CF9D51C7D5540AC1A84B9DD374B4069FD2D01F87A5540AC1A84B9DD374B40
76187	60779	85.921386999999996	85.954885000000004	54.450167	54.436453999999998	Проездная	0103000020E6100000010000000500000069FD2D01F87A5540AC1A84B9DD374B4069FD2D01F87A5540855E7F129F394B40399CF9D51C7D5540855E7F129F394B40399CF9D51C7D5540AC1A84B9DD374B4069FD2D01F87A5540AC1A84B9DD374B40
12333	41067	85.704775999999995	85.746816999999993	54.302881999999997	54.284962999999998	8 Марта	0103000020E610000001000000050000005DC0CB0C1B6D5540F7C8E6AA79244B405DC0CB0C1B6D554006465ED6C4264B4032C687D9CB6F554006465ED6C4264B4032C687D9CB6F5540F7C8E6AA79244B405DC0CB0C1B6D5540F7C8E6AA79244B40
76212	60783	85.704775999999995	85.746816999999993	54.302881999999997	54.284962999999998	Пушкина	0103000020E610000001000000050000005DC0CB0C1B6D5540F7C8E6AA79244B405DC0CB0C1B6D554006465ED6C4264B4032C687D9CB6F554006465ED6C4264B4032C687D9CB6F5540F7C8E6AA79244B405DC0CB0C1B6D5540F7C8E6AA79244B40
76195	60783	85.704775999999995	85.746816999999993	54.302881999999997	54.284962999999998	Полевая	0103000020E610000001000000050000005DC0CB0C1B6D5540F7C8E6AA79244B405DC0CB0C1B6D554006465ED6C4264B4032C687D9CB6F554006465ED6C4264B4032C687D9CB6F5540F7C8E6AA79244B405DC0CB0C1B6D5540F7C8E6AA79244B40
76205	60783	85.704775999999995	85.746816999999993	54.302881999999997	54.284962999999998	К.Маркса	0103000020E610000001000000050000005DC0CB0C1B6D5540F7C8E6AA79244B405DC0CB0C1B6D554006465ED6C4264B4032C687D9CB6F554006465ED6C4264B4032C687D9CB6F5540F7C8E6AA79244B405DC0CB0C1B6D5540F7C8E6AA79244B40
76177	41144	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	Станционная	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
69922	41144	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	Ленина	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
75895	41144	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	Крупской	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
75611	41144	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	Коммунистическая	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
50525	41144	85.767685	85.837941999999998	54.261620000000001	54.206615999999997	Гагарина	0103000020E610000001000000050000004E2844C021715540486AA164721A4B404E2844C02171554061FD9FC37C214B40787C7BD7A075554061FD9FC37C214B40787C7BD7A0755540486AA164721A4B404E2844C021715540486AA164721A4B40
76213	60741	85.988669999999999	86.019509999999997	54.298189999999998	54.287537999999998	Шоссейная	0103000020E610000001000000050000005322895E467F5540BA2D910BCE244B405322895E467F554043FF04172B264B407AFCDEA63F81554043FF04172B264B407AFCDEA63F815540BA2D910BCE244B405322895E467F5540BA2D910BCE244B40
75877	60741	85.988669999999999	86.019509999999997	54.298189999999998	54.287537999999998	Центральная	0103000020E610000001000000050000005322895E467F5540BA2D910BCE244B405322895E467F554043FF04172B264B407AFCDEA63F81554043FF04172B264B407AFCDEA63F815540BA2D910BCE244B405322895E467F5540BA2D910BCE244B40
76268	60741	85.988669999999999	86.019509999999997	54.298189999999998	54.287537999999998	Клубная	0103000020E610000001000000050000005322895E467F5540BA2D910BCE244B405322895E467F554043FF04172B264B407AFCDEA63F81554043FF04172B264B407AFCDEA63F815540BA2D910BCE244B405322895E467F5540BA2D910BCE244B40
76192	60733	85.710398999999995	85.787330999999995	54.457019000000003	54.428049000000001	Центральная	0103000020E610000001000000050000001C075E2D776D5540F20A444FCA364B401C075E2D776D554048533D997F3A4B40200890A16372554048533D997F3A4B40200890A163725540F20A444FCA364B401C075E2D776D5540F20A444FCA364B40
75843	60733	85.710398999999995	85.787330999999995	54.457019000000003	54.428049000000001	Степная	0103000020E610000001000000050000001C075E2D776D5540F20A444FCA364B401C075E2D776D554048533D997F3A4B40200890A16372554048533D997F3A4B40200890A163725540F20A444FCA364B401C075E2D776D5540F20A444FCA364B40
75913	60733	85.710398999999995	85.787330999999995	54.457019000000003	54.428049000000001	Лесная	0103000020E610000001000000050000001C075E2D776D5540F20A444FCA364B401C075E2D776D554048533D997F3A4B40200890A16372554048533D997F3A4B40200890A163725540F20A444FCA364B401C075E2D776D5540F20A444FCA364B40
75586	60700	85.928600000000003	85.964675999999997	54.335914000000002	54.321086999999999	Трактовая	0103000020E6100000010000000500000033C4B12E6E7B5540DB15FA6019294B4033C4B12E6E7B55406022DE3AFF2A4B401CCF6740BD7D55406022DE3AFF2A4B401CCF6740BD7D5540DB15FA6019294B4033C4B12E6E7B5540DB15FA6019294B40
50451	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	улица Лермонтова	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
50093	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	пер. Лесной	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
50549	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Садовая улица	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75596	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Революционная	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
69679	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Лермонтова	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75881	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Ленина	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
69649	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Коммунистическая	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75851	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Коммунистическая	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
12321	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	Войкова	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75880	41063	85.893502999999995	85.997608999999997	54.308093	54.261187999999997	40 лет ВЛКСМ	0103000020E610000001000000050000002FF834272F795540C70DBF9B6E214B402FF834272F795540329067976F274B407F4C6BD3D87F5540329067976F274B407F4C6BD3D87F5540C70DBF9B6E214B402FF834272F795540C70DBF9B6E214B40
75904	60748	85.610695000000007	85.645854999999997	54.477733999999998	54.454720999999999	Революционная	0103000020E610000001000000050000002B357BA015675540F7E6374C343A4B402B357BA015675540F8174163263D4B4051BD35B055695540F8174163263D4B4051BD35B055695540F7E6374C343A4B402B357BA015675540F7E6374C343A4B40
76210	60791	85.825473000000002	85.845343999999997	54.266658	54.254992999999999	Молодежная	0103000020E61000000100000005000000C9AEB48CD4745540BEDA519CA3204B40C9AEB48CD4745540BF9B6ED921224B40AB77B81D1A765540BF9B6ED921224B40AB77B81D1A765540BEDA519CA3204B40C9AEB48CD4745540BEDA519CA3204B40
69799	59361	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Фрунзе	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
50083	23478	86.174055999999993	86.305857000000003	54.582272000000003	54.505643999999997	Проектная	0103000020E610000001000000050000000BEBC6BB238B554095B54DF1B8404B400BEBC6BB238B554032B08EE3874A4B402C103D299393554032B08EE3874A4B402C103D299393554095B54DF1B8404B400BEBC6BB238B554095B54DF1B8404B40
12336	41069	86.274343999999999	86.318415000000002	54.317830999999998	54.291863999999997	Гражданская	0103000020E61000000100000005000000A5F622DA8E9155409B70AFCC5B254B40A5F622DA8E915540D653ABAFAE284B4093E34EE960945540D653ABAFAE284B4093E34EE9609455409B70AFCC5B254B40A5F622DA8E9155409B70AFCC5B254B40
12777	41069	86.274343999999999	86.318415000000002	54.317830999999998	54.291863999999997	Гастелло	0103000020E61000000100000005000000A5F622DA8E9155409B70AFCC5B254B40A5F622DA8E915540D653ABAFAE284B4093E34EE960945540D653ABAFAE284B4093E34EE9609455409B70AFCC5B254B40A5F622DA8E9155409B70AFCC5B254B40
75592	60702	86.274343999999999	86.318415000000002	54.317830999999998	54.291863999999997	Киевская	0103000020E61000000100000005000000A5F622DA8E9155409B70AFCC5B254B40A5F622DA8E915540D653ABAFAE284B4093E34EE960945540D653ABAFAE284B4093E34EE9609455409B70AFCC5B254B40A5F622DA8E9155409B70AFCC5B254B40
50027	9204	86.389426999999998	86.454986000000005	54.452207999999999	54.414957999999999	Энергетическая	0103000020E610000001000000050000007B4B395FEC985540569BFF571D354B407B4B395FEC985540AA7EA5F3E1394B40D388997D1E9D5540AA7EA5F3E1394B40D388997D1E9D5540569BFF571D354B407B4B395FEC985540569BFF571D354B40
50087	9204	86.389426999999998	86.454986000000005	54.452207999999999	54.414957999999999	Чистопольская	0103000020E610000001000000050000007B4B395FEC985540569BFF571D354B407B4B395FEC985540AA7EA5F3E1394B40D388997D1E9D5540AA7EA5F3E1394B40D388997D1E9D5540569BFF571D354B407B4B395FEC985540569BFF571D354B40
49956	9204	86.389426999999998	86.454986000000005	54.452207999999999	54.414957999999999	Парковая	0103000020E610000001000000050000007B4B395FEC985540569BFF571D354B407B4B395FEC985540AA7EA5F3E1394B40D388997D1E9D5540AA7EA5F3E1394B40D388997D1E9D5540569BFF571D354B407B4B395FEC985540569BFF571D354B40
50276	9204	86.389426999999998	86.454986000000005	54.452207999999999	54.414957999999999	Ильича	0103000020E610000001000000050000007B4B395FEC985540569BFF571D354B407B4B395FEC985540AA7EA5F3E1394B40D388997D1E9D5540AA7EA5F3E1394B40D388997D1E9D5540569BFF571D354B407B4B395FEC985540569BFF571D354B40
75963	8604	86.226355999999996	86.260923000000005	54.322032999999998	54.304695000000002	Кузбасская	0103000020E610000001000000050000003750E09D7C8E55409B20EA3E00274B403750E09D7C8E5540CB9D996038294B408DF161F6B2905540CB9D996038294B408DF161F6B29055409B20EA3E00274B403750E09D7C8E55409B20EA3E00274B40
50269	9363	86.361785999999995	86.407582000000005	54.541902999999998	54.500798000000003	Центральная	0103000020E61000000100000005000000A4897780279755407CF31B261A404B40A489778027975540594DD7135D454B400D1CD0D2159A5540594DD7135D454B400D1CD0D2159A55407CF31B261A404B40A4897780279755407CF31B261A404B40
50277	9363	86.361785999999995	86.407582000000005	54.541902999999998	54.500798000000003	Светлая	0103000020E61000000100000005000000A4897780279755407CF31B261A404B40A489778027975540594DD7135D454B400D1CD0D2159A5540594DD7135D454B400D1CD0D2159A55407CF31B261A404B40A4897780279755407CF31B261A404B40
49957	9363	86.361785999999995	86.407582000000005	54.541902999999998	54.500798000000003	Лесная	0103000020E61000000100000005000000A4897780279755407CF31B261A404B40A489778027975540594DD7135D454B400D1CD0D2159A5540594DD7135D454B400D1CD0D2159A55407CF31B261A404B40A4897780279755407CF31B261A404B40
50088	9363	86.361785999999995	86.407582000000005	54.541902999999998	54.500798000000003	Колмогоровская	0103000020E61000000100000005000000A4897780279755407CF31B261A404B40A489778027975540594DD7135D454B400D1CD0D2159A5540594DD7135D454B400D1CD0D2159A55407CF31B261A404B40A4897780279755407CF31B261A404B40
49952	9363	86.361785999999995	86.407582000000005	54.541902999999998	54.500798000000003	Грамотеинская	0103000020E61000000100000005000000A4897780279755407CF31B261A404B40A489778027975540594DD7135D454B400D1CD0D2159A5540594DD7135D454B400D1CD0D2159A55407CF31B261A404B40A4897780279755407CF31B261A404B40
50286	9363	86.361785999999995	86.407582000000005	54.541902999999998	54.500798000000003	7 Ноября	0103000020E61000000100000005000000A4897780279755407CF31B261A404B40A489778027975540594DD7135D454B400D1CD0D2159A5540594DD7135D454B400D1CD0D2159A55407CF31B261A404B40A4897780279755407CF31B261A404B40
50548	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Юности	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75984	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Энгельса	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75641	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Энгельса	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
12772	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Шахтовая	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
50491	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Цинкзаводской пер	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75583	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Советская	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75639	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Победы	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
13674	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Морозова	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75755	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Механическая улица	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
75591	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Линейный переулок	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
69820	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Ленина	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
50639	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Ленина	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
50420	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	Боевая	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
13368	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	3 микрорайон	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
76202	41141	86.255757000000003	86.377523999999994	54.460771000000001	54.309238999999998	3 Телеут	0103000020E6100000010000000500000047AE9B525E905540E9D2BF2495274B4047AE9B525E905540FDF84B8BFA3A4B40205D6C5A29985540FDF84B8BFA3A4B40205D6C5A29985540E9D2BF2495274B4047AE9B525E905540E9D2BF2495274B40
12324	41064	86.049126999999999	86.127899999999997	54.297033999999996	54.269502000000003	мкрн Финский	0103000020E61000000100000005000000709692E524835540721AA20A7F224B40709692E52483554068E6C93505264B40234A7B832F88554068E6C93505264B40234A7B832F885540721AA20A7F224B40709692E524835540721AA20A7F224B40
49955	8672	86.049126999999999	86.127899999999997	54.297033999999996	54.269502000000003	Шевцовой	0103000020E61000000100000005000000709692E524835540721AA20A7F224B40709692E52483554068E6C93505264B40234A7B832F88554068E6C93505264B40234A7B832F885540721AA20A7F224B40709692E524835540721AA20A7F224B40
50026	8672	86.049126999999999	86.127899999999997	54.297033999999996	54.269502000000003	Комсомольская	0103000020E61000000100000005000000709692E524835540721AA20A7F224B40709692E52483554068E6C93505264B40234A7B832F88554068E6C93505264B40234A7B832F885540721AA20A7F224B40709692E524835540721AA20A7F224B40
13695	8672	86.049126999999999	86.127899999999997	54.297033999999996	54.269502000000003	50 лет Октября	0103000020E61000000100000005000000709692E524835540721AA20A7F224B40709692E52483554068E6C93505264B40234A7B832F88554068E6C93505264B40234A7B832F885540721AA20A7F224B40709692E524835540721AA20A7F224B40
69461	59262	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Школьная	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68554	59156	103.646827	103.65432800000001	52.769350000000003	52.764501000000003	Чапаева	0103000020E61000000100000005000000DECA129D65E959403161342BDB614A40DECA129D65E95940BC96900F7A624A40DB368C82E0E95940BC96900F7A624A40DB368C82E0E959403161342BDB614A40DECA129D65E959403161342BDB614A40
69392	59254	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Школьная	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
67736	59098	103.938366	104.123159	52.23171	52.169508	переулок Садовый	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
68091	59098	103.938366	104.123159	52.23171	52.169508	квартал315	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
67829	59098	103.938366	104.123159	52.23171	52.169508	М-55	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
68094	59098	103.938366	104.123159	52.23171	52.169508	Кочубея	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
69603	59327	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
68628	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Щорса	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67965	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Ференца Патаки	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68019	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Толстого	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
69226	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Спартаковская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
69227	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Сибирская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68815	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Первомайская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67708	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Маяковского	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68825	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Краснодонская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67783	59090	103.008978	103.233692	53.189619999999998	53.035524000000002	Дударского	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68799	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Энергетический переулок	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68179	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Школьный переулок	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68557	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Школьная	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68361	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Советская	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68902	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Седова	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
67744	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Речников	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68391	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Пушкина	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
69548	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Партизанская	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
69427	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Панихинская	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68915	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Островского	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
67843	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Нефтяников	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68370	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Набережная	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68513	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Коммунистическая	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68331	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Кирова	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68921	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Кедровая	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68675	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Горбунова	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
9960	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Геологическая	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68332	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	Володарского	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
69517	29581	105.56756900000001	106.038169	56.860418000000003	56.745192000000003	 Береговая	0103000020E610000001000000050000004D4EED0C53645A40D49E9273625F4C404D4EED0C53645A40E371512D226E4C4025AE635C71825A40E371512D226E4C4025AE635C71825A40D49E9273625F4C404D4EED0C53645A40D49E9273625F4C40
68111	59092	102.560647	102.771293	58.135641	57.926875000000003	пр.Мира	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67999	59092	102.560647	102.771293	58.135641	57.926875000000003	Чайковского	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67711	59092	102.560647	102.771293	58.135641	57.926875000000003	Трудовая	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67746	59092	102.560647	102.771293	58.135641	57.926875000000003	Романтиков	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67713	59092	102.560647	102.771293	58.135641	57.926875000000003	Наймушина	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67762	59092	102.560647	102.771293	58.135641	57.926875000000003	Ленина	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67716	59092	102.560647	102.771293	58.135641	57.926875000000003	Дружбы Народов	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67722	59092	102.560647	102.771293	58.135641	57.926875000000003	Героев Труда	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
68133	59092	102.560647	102.771293	58.135641	57.926875000000003	Георгия Димитрова	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
4187	1308	103.642578	103.65877500000001	52.757275	52.748106999999997	улица Толбухина	0103000020E6100000010000000500000043C879FF1FE959404F745DF8C15F4A4043C879FF1FE95940098A1F63EE604A40091B9E5E29EA5940098A1F63EE604A40091B9E5E29EA59404F745DF8C15F4A4043C879FF1FE959404F745DF8C15F4A40
3697	1308	103.654382	103.666213	52.764342999999997	52.761116999999999	улица Пушкина	0103000020E61000000100000005000000D4450A65E1E95940FEB627486C614A40D4450A65E1E9594098F6CDFDD5614A40E2CAD93BA3EA594098F6CDFDD5614A40E2CAD93BA3EA5940FEB627486C614A40D4450A65E1E95940FEB627486C614A40
68683	1308	103.66058	103.671117	52.749808000000002	52.747430999999999	улица Матросова	0103000020E61000000100000005000000111956F146EA59401F82AAD1AB5F4A40111956F146EA5940BC2363B5F95F4A4089B2B794F3EA5940BC2363B5F95F4A4089B2B794F3EA59401F82AAD1AB5F4A40111956F146EA59401F82AAD1AB5F4A40
4242	1308	103.64828199999999	103.658891	52.739345999999998	52.734144000000001	улица Луначарского	0103000020E610000001000000050000007825C9737DE95940FE463B6EF85D4A407825C9737DE95940D636C5E3A25E4A403D2828452BEA5940D636C5E3A25E4A403D2828452BEA5940FE463B6EF85D4A407825C9737DE95940FE463B6EF85D4A40
346	1308	103.63322599999999	103.65221699999999	52.755938999999998	52.746935000000001	улица Куйбышева	0103000020E61000000100000005000000853E58C686E859406F9EEA909B5F4A40853E58C686E85940AE62F19BC2604A404B395FECBDE95940AE62F19BC2604A404B395FECBDE959406F9EEA909B5F4A40853E58C686E859406F9EEA909B5F4A40
4099	1308	103.621234	103.63909200000001	52.765720999999999	52.756641999999999	улица Коростова	0103000020E61000000100000005000000734A404CC2E75940D86322A5D9604A40734A404CC2E75940226E4E2503624A40A8C821E2E6E85940226E4E2503624A40A8C821E2E6E85940D86322A5D9604A40734A404CC2E75940D86322A5D9604A40
4297	1308	103.65310599999999	103.666141	52.728506000000003	52.721300999999997	проспект Химиков	0103000020E6100000010000000500000091B41B7DCCE959403AC95697535C4A4091B41B7DCCE959404B7842AF3F5D4A409561DC0DA2EA59404B7842AF3F5D4A409561DC0DA2EA59403AC95697535C4A4091B41B7DCCE959403AC95697535C4A40
4282	1308	103.656313	103.66526	52.731827000000003	52.723782999999997	проспект Космонавтов	0103000020E6100000010000000500000023BC3D0801EA59404C33DDEBA45C4A4023BC3D0801EA594037AAD381AC5D4A4091D5AD9E93EA594037AAD381AC5D4A4091D5AD9E93EA59404C33DDEBA45C4A4023BC3D0801EA59404C33DDEBA45C4A40
4132	1308	103.627684	103.641248	52.759960999999997	52.750188999999999	проезд Серегина	0103000020E610000001000000050000003D0E83F92BE85940D368723106604A403D0E83F92BE85940239EEC6646614A4007280D350AE95940239EEC6646614A4007280D350AE95940D368723106604A403D0E83F92BE85940D368723106604A40
68904	1308	103.60581000000001	103.612736	52.748739	52.745212000000002	Щорса	0103000020E61000000100000005000000BF654E97C5E659401B4B581B635F4A40BF654E97C5E65940B01EF7ADD65F4A403D450E1137E75940B01EF7ADD65F4A403D450E1137E759401B4B581B635F4A40BF654E97C5E659401B4B581B635F4A40
4075	1308	103.64176	103.64507500000001	52.760069999999999	52.757531	Фестивальный проезд	0103000020E6100000010000000500000062F8889812E95940645A9BC6F6604A4062F8889812E95940DA5548F949614A40E71DA7E848E95940DA5548F949614A40E71DA7E848E95940645A9BC6F6604A4062F8889812E95940645A9BC6F6604A40
68399	1308	103.642578	103.65877500000001	52.757275	52.748106999999997	Толбухина	0103000020E6100000010000000500000043C879FF1FE959404F745DF8C15F4A4043C879FF1FE95940098A1F63EE604A40091B9E5E29EA5940098A1F63EE604A40091B9E5E29EA59404F745DF8C15F4A4043C879FF1FE959404F745DF8C15F4A40
68572	1308	103.660077	103.672977	52.744323999999999	52.741810000000001	Розы Люксембург	0103000020E61000000100000005000000E0F599B33EEA594042EC4CA1F35E4A40E0F599B33EEA59405FD04202465F4A40747D1F0E12EB59405FD04202465F4A40747D1F0E12EB594042EC4CA1F35E4A40E0F599B33EEA594042EC4CA1F35E4A40
68520	1308	103.652738	103.659188	52.757776	52.755764999999997	Октябрьская	0103000020E61000000100000005000000D0B69A75C6E95940103B53E8BC604A40D0B69A75C6E95940CBD8D0CDFE604A409A7ADD2230EA5940CBD8D0CDFE604A409A7ADD2230EA5940103B53E8BC604A40D0B69A75C6E95940103B53E8BC604A40
3966	1308	103.668099	103.674549	52.758178999999998	52.741483000000002	Молотовая улица	0103000020E6100000010000000500000061DF4E22C2EA59401EC539EAE85E4A4061DF4E22C2EA5940CAC16C020C614A402BA391CF2BEB5940CAC16C020C614A402BA391CF2BEB59401EC539EAE85E4A4061DF4E22C2EA59401EC539EAE85E4A40
68481	1308	103.63690099999999	103.649351	52.768870999999997	52.758147000000001	Менделеева	0103000020E610000001000000050000008A7269FCC2E85940BF47FDF50A614A408A7269FCC2E85940E1EB6B5D6A624A40FE277FF78EE95940E1EB6B5D6A624A40FE277FF78EE95940BF47FDF50A614A408A7269FCC2E85940BF47FDF50A614A40
68400	1308	103.64828199999999	103.658891	52.739345999999998	52.734144000000001	Луначарского	0103000020E610000001000000050000007825C9737DE95940FE463B6EF85D4A407825C9737DE95940D636C5E3A25E4A403D2828452BEA5940D636C5E3A25E4A403D2828452BEA5940FE463B6EF85D4A407825C9737DE95940FE463B6EF85D4A40
68927	1308	103.627989	103.66989599999999	52.760959	52.751987999999997	Ленина	0103000020E61000000100000005000000DB4FC6F830E85940027E8D2441604A40DB4FC6F830E85940664CC11A67614A4028EE7893DFEA5940664CC11A67614A4028EE7893DFEA5940027E8D2441604A40DB4FC6F830E85940027E8D2441604A40
68353	1308	103.666213	103.666788	52.775658999999997	52.765715999999998	Крупской	0103000020E61000000100000005000000E2CAD93BA3EA594010035DFB02624A40E2CAD93BA3EA59408DEC4ACB48634A40605793A7ACEA59408DEC4ACB48634A40605793A7ACEA594010035DFB02624A40E2CAD93BA3EA594010035DFB02624A40
4084	1308	103.631439	103.663113	52.761944999999997	52.734641000000003	Комсомольский проспект	0103000020E61000000100000005000000D09A1F7F69E859407FA65EB7085E4A40D09A1F7F69E85940E42CEC6987614A405B23827170EA5940E42CEC6987614A405B23827170EA59407FA65EB7085E4A40D09A1F7F69E859407FA65EB7085E4A40
68394	1308	103.625294	103.63938	52.737110999999999	52.731085	Клары Цеткин	0103000020E61000000100000005000000A41820D104E859404FCC7A31945D4A40A41820D104E85940CC423BA7595E4A40DB6D179AEBE85940CC423BA7595E4A40DB6D179AEBE859404FCC7A31945D4A40A41820D104E859404FCC7A31945D4A40
68511	1308	103.654651	103.667344	52.752718000000002	52.745260999999999	Карла Либкнехта	0103000020E61000000100000005000000CCD24ECDE5E95940FCFD62B6645F4A40CCD24ECDE5E95940268E3C1059604A40A3CB9BC3B5EA5940268E3C1059604A40A3CB9BC3B5EA5940FCFD62B6645F4A40CCD24ECDE5E95940FCFD62B6645F4A40
68500	1308	103.649181	103.666096	52.758189999999999	52.748603000000003	Интернациональная	0103000020E61000000100000005000000D00B772E8CE9594000581D39D25F4A40D00B772E8CE95940BE13B35E0C614A40C5FF1D51A1EA5940BE13B35E0C614A40C5FF1D51A1EA594000581D39D25F4A40D00B772E8CE9594000581D39D25F4A40
68307	1308	103.60369	103.622258	52.751176000000001	52.740529000000002	Жуковского	0103000020E6100000010000000500000006BB61DBA2E65940AB5E7EA7C95E4A4006BB61DBA2E6594022C5008926604A4029EB3713D3E7594022C5008926604A4029EB3713D3E75940AB5E7EA7C95E4A4006BB61DBA2E65940AB5E7EA7C95E4A40
68911	59188	104.291584	104.31180500000001	52.271362000000003	52.261524000000001	Коммунистическая	0103000020E610000001000000050000005C02F04FA9125A403F8F519E79214A405C02F04FA9125A4047B071FDBB224A40AD6EF59CF4135A4047B071FDBB224A40AD6EF59CF4135A403F8F519E79214A405C02F04FA9125A403F8F519E79214A40
68601	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	микрорайон Угольщиков	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68726	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Строителей	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68528	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Совхозная	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
67774	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Сигаева	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
67703	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Речная	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68611	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Островского	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68928	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Мясокомбинатская	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68266	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Ленина	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68268	59087	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Ватутина	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
69130	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	мкр-н.Пахотищева	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
38294	52142	103.63663099999999	103.64154499999999	52.764473000000002	52.76097	Шевченко	0103000020E61000000100000005000000AA27F38FBEE859405A9E077767614A40AA27F38FBEE8594067D65240DA614A40637AC2120FE9594067D65240DA614A40637AC2120FE959405A9E077767614A40AA27F38FBEE859405A9E077767614A40
68724	52142	103.646827	103.65432800000001	52.769350000000003	52.764501000000003	Чапаева	0103000020E61000000100000005000000DECA129D65E959403161342BDB614A40DECA129D65E95940BC96900F7A624A40DB368C82E0E95940BC96900F7A624A40DB368C82E0E959403161342BDB614A40DECA129D65E959403161342BDB614A40
38226	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	Транспортная	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
68929	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	Суворова	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
67906	52142	103.654382	103.666213	52.764342999999997	52.761116999999999	Пушкина	0103000020E61000000100000005000000D4450A65E1E95940FEB627486C614A40D4450A65E1E9594098F6CDFDD5614A40E2CAD93BA3EA594098F6CDFDD5614A40E2CAD93BA3EA5940FEB627486C614A40D4450A65E1E95940FEB627486C614A40
68258	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	Пионерская	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
68269	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	Первомайская	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
38305	52142	103.88845600000001	103.900808	52.555638999999999	52.535496000000002	Мира	0103000020E61000000100000005000000D7FB8D76DCF85940C59107228B444A40D7FB8D76DCF85940EAB0C22D1F474A4069FE98D6A6F95940EAB0C22D1F474A4069FE98D6A6F95940C59107228B444A40D7FB8D76DCF85940C59107228B444A40
68264	52142	103.876059	103.90655700000001	52.548870999999998	52.542380999999999	Ленина	0103000020E610000001000000050000007497C45911F85940637C98BD6C454A407497C45911F85940855CA96741464A406FBDA60705FA5940855CA96741464A406FBDA60705FA5940637C98BD6C454A407497C45911F85940637C98BD6C454A40
38236	52142	103.874765	103.881691	52.530296999999997	52.514417999999999	Крупской	0103000020E61000000100000005000000DEAB5626FCF75940A33CF372D8414A40DEAB5626FCF759405D15A8C5E0434A405D8B16A06DF859405D15A8C5E0434A405D8B16A06DF85940A33CF372D8414A40DEAB5626FCF75940A33CF372D8414A40
38885	52142	103.875969	103.90167	52.556662000000003	52.548005000000003	Кирова	0103000020E61000000100000005000000D4D347E00FF85940B285200725464A40D4D347E00FF8594086764EB340474A40327216F6B4F9594086764EB340474A40327216F6B4F95940B285200725464A40D4D347E00FF85940B285200725464A40
38213	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	Ивана Бича	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
68260	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	Воинов Интернационалистов	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
68781	52142	97.913275999999996	98.076886000000002	55.964005	55.909272000000001	50 лет ВЛКСМ	0103000020E61000000100000005000000300E2E1D737A584092955F0663F44B40300E2E1D737A58401A170E8464FB4B404CE141B3EB8458401A170E8464FB4B404CE141B3EB84584092955F0663F44B40300E2E1D737A584092955F0663F44B40
69542	59286	103.752954	103.764758	51.646805999999998	51.640680000000003	Линейная	0103000020E610000001000000050000001D59F96530F05940C4995FCD01D249401D59F96530F05940A46DFC89CAD24940AED689CBF1F05940A46DFC89CAD24940AED689CBF1F05940C4995FCD01D249401D59F96530F05940C4995FCD01D24940
68256	59085	103.652343	103.738527	51.690190999999999	51.633105999999998	Слюдянских Красногвардейцев	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
67697	59085	103.652343	103.738527	51.690190999999999	51.633105999999998	Ленина	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
68723	59160	103.287474	103.406025	53.122621000000002	52.979940999999997	Тимирязева	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68622	59160	103.287474	103.406025	53.122621000000002	52.979940999999997	Молодёжная	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
69196	59160	103.287474	103.406025	53.122621000000002	52.979940999999997	Лесная	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
67692	59083	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Центральный	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
67694	59083	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Строителей	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
68083	59083	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Солнечный	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
67699	59083	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Олимпийский	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
69552	59293	104.37183899999999	104.373268	52.277588000000002	52.275494000000002	Молодежная	0103000020E610000001000000050000002618CE35CC175A40431F2C6343234A402618CE35CC175A408BE1EA0088234A402C29779FE3175A408BE1EA0088234A402C29779FE3175A40431F2C6343234A402618CE35CC175A40431F2C6343234A40
69538	59284	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	улица Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
69620	59332	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
69502	5456	104.449759	104.46084399999999	52.239558000000002	52.230739	Клубная	0103000020E610000001000000050000003A05F9D9C81C5A40B47405DB881D4A403A05F9D9C81C5A4062BF27D6A91E4A40B323D5777E1D5A4062BF27D6A91E4A40B323D5777E1D5A40B47405DB881D4A403A05F9D9C81C5A40B47405DB881D4A40
68903	59186	104.39496200000001	104.397513	52.250982999999998	52.245733999999999	Совхозная	0103000020E610000001000000050000006B4AB20E47195A40F4C13236741F4A406B4AB20E47195A400D6D003620204A4008AF5DDA70195A400D6D003620204A4008AF5DDA70195A40F4C13236741F4A406B4AB20E47195A40F4C13236741F4A40
67968	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	переулок Красный	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67868	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Шнеерсон	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67951	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Циолковского	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68231	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Советская	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68688	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Петина	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67957	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	П. Осипенко	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67943	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Октябрьская	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67865	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Нагорная	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68879	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Маяковского	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67971	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Масловского	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67866	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Лермонтова	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68760	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Ленина	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67955	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Кржижановского	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68234	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Краснопролетарская	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68229	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Карла Маркса	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67683	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Знаменская	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
67969	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	Гагарина	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68243	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	6-й Пятилетки	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
68665	25086	98.979440999999994	99.084525999999997	54.956037000000002	54.870285000000003	2-я Западная	0103000020E6100000010000000500000023D74D29AFBE58408599B67F656F4B4023D74D29AFBE58400B62A06B5F7A4B40596ABDDF68C558400B62A06B5F7A4B40596ABDDF68C558408599B67F656F4B4023D74D29AFBE58408599B67F656F4B40
69195	59223	104.673934	104.770754	58.184278999999997	57.935127999999999	Школьная	0103000020E61000000100000005000000666A12BC212B5A4075C93846B2F74C40666A12BC212B5A40772B4B7496174D40B7D0950854315A40772B4B7496174D40B7D0950854315A4075C93846B2F74C40666A12BC212B5A4075C93846B2F74C40
69590	59321	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
68415	59142	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
1333	2001	104.314742	104.318336	52.350278000000003	52.341133999999997	улица Ключевая	0103000020E610000001000000050000005E2BA1BB24145A40DEC66647AA2B4A405E2BA1BB24145A401041D5E8D52C4A40ED48F59D5F145A401041D5E8D52C4A40ED48F59D5F145A40DEC66647AA2B4A405E2BA1BB24145A40DEC66647AA2B4A40
68618	59159	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Красный Октябрь	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
69167	59218	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
69570	59309	104.302301	104.324696	52.317843000000003	52.300823999999999	Первомайская	0103000020E6100000010000000500000014234BE658135A400BED9C6681264A4014234BE658135A409B215514AF284A401749BBD1C7145A409B215514AF284A401749BBD1C7145A400BED9C6681264A4014234BE658135A400BED9C6681264A40
67845	59112	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	квартал Водников	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
69694	59112	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Школьная	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
67854	59112	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Ленрабочих	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68945	59112	104.300495	104.301941	52.264527999999999	52.263446999999999	Алексеева	0103000020E610000001000000050000002367614F3B135A405A9D9CA1B8214A402367614F3B135A402A70B20DDC214A409414580053135A402A70B20DDC214A409414580053135A405A9D9CA1B8214A402367614F3B135A405A9D9CA1B8214A40
3370	27	104.195455	104.21372700000001	52.268573000000004	52.259279999999997	улица маршала Конева	0103000020E61000000100000005000000BD35B055820C5A40E140481630214A40BD35B055820C5A4058CB9D9960224A406CD102B4AD0D5A4058CB9D9960224A406CD102B4AD0D5A40E140481630214A40BD35B055820C5A40E140481630214A40
2202	27	104.234065	104.26411299999999	52.331091999999998	52.330508999999999	улица генерала Доватора	0103000020E61000000100000005000000D908C4EBFA0E5A404F04711E4E2A4A40D908C4EBFA0E5A40CEFBFF38612A4A40B35C363AE7105A40CEFBFF38612A4A40B35C363AE7105A404F04711E4E2A4A40D908C4EBFA0E5A404F04711E4E2A4A40
2226	27	104.251312	104.26411299999999	52.332797999999997	52.330641	улица генерала Воровского	0103000020E61000000100000005000000E945ED7E15105A40BEDBBC71522A4A40E945ED7E15105A404C16F71F992A4A40B35C363AE7105A404C16F71F992A4A40B35C363AE7105A40BEDBBC71522A4A40E945ED7E15105A40BEDBBC71522A4A40
1947	27	104.20225499999999	104.21544299999999	52.342388999999997	52.333376000000001	улица академика Образцова	0103000020E61000000100000005000000F59CF4BEF10C5A40BAA29410AC2A4A40F59CF4BEF10C5A404CC11A67D32B4A40BCC96FD1C90D5A404CC11A67D32B4A40BCC96FD1C90D5A40BAA29410AC2A4A40F59CF4BEF10C5A40BAA29410AC2A4A40
2022	27	104.16583799999999	104.195994	52.345376000000002	52.327091000000003	улица Ярославского	0103000020E61000000100000005000000C79BFC169D0A5A4071E82D1EDE294A40C79BFC169D0A5A406269E047352C4A40950D6B2A8B0C5A406269E047352C4A40950D6B2A8B0C5A4071E82D1EDE294A40C79BFC169D0A5A4071E82D1EDE294A40
1850	27	104.217742	104.234172	52.349139000000001	52.339340999999997	улица Шпачека	0103000020E61000000100000005000000CD3D247CEF0D5A409198A0866F2B4A40CD3D247CEF0D5A400B613596B02C4A40E4688EACFC0E5A400B613596B02C4A40E4688EACFC0E5A409198A0866F2B4A40CD3D247CEF0D5A409198A0866F2B4A40
28866	27	104.313377	104.315245	52.283082	52.281554999999997	улица Трудовых Резервов	0103000020E610000001000000050000006494675E0E145A403C8386FE09244A406494675E0E145A400B0BEE073C244A40904E5DF92C145A400B0BEE073C244A40904E5DF92C145A403C8386FE09244A406494675E0E145A403C8386FE09244A40
4891	27	104.318443	104.32952	52.272959999999998	52.262571000000001	улица Трудовая	0103000020E61000000100000005000000F8A8BF5E61145A4063F030ED9B214A40F8A8BF5E61145A40DE8E705AF0224A4030D80DDB16155A40DE8E705AF0224A4030D80DDB16155A4063F030ED9B214A40F8A8BF5E61145A4063F030ED9B214A40
3437	27	104.286383	104.305166	52.289340000000003	52.276260000000001	улица Тимирязева	0103000020E6100000010000000500000058C85C1954125A40B398D87C5C234A4058C85C1954125A405BB6D61709254A407976F9D687135A405BB6D61709254A407976F9D687135A40B398D87C5C234A4058C85C1954125A40B398D87C5C234A40
2883	27	104.27271	104.279178	52.286293000000001	52.281660000000002	улица Степана Разина	0103000020E61000000100000005000000B3D2A41474115A40B24B546F0D244A40B3D2A41474115A407009C03FA5244A40D0F0660DDE115A407009C03FA5244A40D0F0660DDE115A40B24B546F0D244A40B3D2A41474115A40B24B546F0D244A40
627	27	104.294746	104.356155	52.280768000000002	52.273555000000002	улица Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40A453573ECB165A40B5E1B034F0234A40A453573ECB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
1728	27	104.211265	104.22942	52.354294000000003	52.343170000000001	улица Сибирских Партизан	0103000020E610000001000000050000008672A25D850D5A40F27B9BFEEC2B4A408672A25D850D5A40A3957B81592D4A40184339D1AE0E5A40A3957B81592D4A40184339D1AE0E5A40F27B9BFEEC2B4A408672A25D850D5A40F27B9BFEEC2B4A40
2075	27	104.1553	104.19598499999999	52.353000999999999	52.333370000000002	улица Севастопольская	0103000020E610000001000000050000006744696FF0095A40D8BB3FDEAB2A4A406744696FF0095A40473A03232F2D4A406B60AB048B0C5A40473A03232F2D4A406B60AB048B0C5A40D8BB3FDEAB2A4A406744696FF0095A40D8BB3FDEAB2A4A40
2904	27	104.271219	104.280013	52.287219	52.283208000000002	улица Российская	0103000020E6100000010000000500000072C3EFA65B115A4098FBE42840244A4072C3EFA65B115A4019E59997C3244A401C5DA5BBEB115A4019E59997C3244A401C5DA5BBEB115A4098FBE42840244A4072C3EFA65B115A4098FBE42840244A40
2042	27	104.143317	104.210098	52.360399000000001	52.329462999999997	улица Розы Люксембург	0103000020E610000001000000050000007EFD101B2C095A40FB1EF5D72B2A4A407EFD101B2C095A406C41EF8D212E4A401FBDE13E720D5A406C41EF8D212E4A401FBDE13E720D5A40FB1EF5D72B2A4A407EFD101B2C095A40FB1EF5D72B2A4A40
2483	27	104.35990099999999	104.36501199999999	52.250388000000001	52.247751999999998	улица Ржанова	0103000020E610000001000000050000000D33349E08175A4061C26856B61F4A400D33349E08175A40CAA7C7B60C204A4071A94A5B5C175A40CAA7C7B60C204A4071A94A5B5C175A4061C26856B61F4A400D33349E08175A4061C26856B61F4A40
3274	27	104.297629	104.306684	52.326056000000001	52.299760999999997	улица Рабочего Штаба	0103000020E61000000100000005000000D655815A0C135A40E1CE85915E264A40D655815A0C135A401155F833BC294A40378DEDB5A0135A401155F833BC294A40378DEDB5A0135A40E1CE85915E264A40D655815A0C135A40E1CE85915E264A40
3604	27	104.25535499999999	104.26113100000001	52.287576999999999	52.274988	улица Профсоюзная	0103000020E61000000100000005000000AF777FBC57105A406F6589CE32234A40AF777FBC57105A40780AB952CF244A40323ECC5EB6105A40780AB952CF244A40323ECC5EB6105A406F6589CE32234A40AF777FBC57105A406F6589CE32234A40
1797	27	104.213089	104.230903	52.353743999999999	52.342125000000003	улица Просвещения	0103000020E61000000100000005000000CA880B40A30D5A406F1283C0CA2B4A40CA880B40A30D5A40FF93BF7B472D4A401763601DC70E5A40FF93BF7B472D4A401763601DC70E5A406F1283C0CA2B4A40CA880B40A30D5A406F1283C0CA2B4A40
5065	27	104.283041	104.287119	52.291086	52.286414999999998	улица Пролетарская	0103000020E61000000100000005000000569BFF571D125A40BB0A293FA9244A40569BFF571D125A406729594E42254A40DBC35E2860125A406729594E42254A40DBC35E2860125A40BB0A293FA9244A40569BFF571D125A40BB0A293FA9244A40
1999	27	104.182205	104.20323399999999	52.345689999999998	52.331180000000003	улица Пржевальского	0103000020E61000000100000005000000BB0A293FA90B5A406E8B321B642A4A40BB0A293FA90B5A40F146E6913F2C4A40DBDB2DC9010D5A40F146E6913F2C4A40DBDB2DC9010D5A406E8B321B642A4A40BB0A293FA90B5A406E8B321B642A4A40
28856	27	104.268767	104.27216199999999	52.288150000000002	52.287010000000002	улица Полины Осипенко	0103000020E610000001000000050000009ECF807A33115A40FFCF61BEBC244A409ECF807A33115A40D42B6519E2244A40B14D2A1A6B115A40D42B6519E2244A40B14D2A1A6B115A40FFCF61BEBC244A409ECF807A33115A40FFCF61BEBC244A40
3070	27	104.313377	104.320635	52.286392999999997	52.283262999999998	улица Поленова	0103000020E610000001000000050000006494675E0E145A405B9544F641244A406494675E0E145A40D3669C86A8244A40FDBCA94885145A40D3669C86A8244A40FDBCA94885145A405B9544F641244A406494675E0E145A405B9544F641244A40
2260	27	104.297944	104.33530500000001	52.272826999999999	52.262549	улица Пискунова	0103000020E610000001000000050000008602B68311135A407B4CA4349B214A408602B68311135A409F3BC1FEEB224A40DC4B1AA375155A409F3BC1FEEB224A40DC4B1AA375155A407B4CA4349B214A408602B68311135A407B4CA4349B214A40
1940	27	104.178073	104.19443099999999	52.346873000000002	52.335912999999998	улица Павла Красильникова	0103000020E610000001000000050000003DD34B8C650B5A408FA67A32FF2A4A403DD34B8C650B5A40C66E9F55662C4A400795B88E710C5A40C66E9F55662C4A400795B88E710C5A408FA67A32FF2A4A403DD34B8C650B5A408FA67A32FF2A4A40
1692	27	104.20805799999999	104.21759	52.367849999999997	52.345415000000003	улица Новаторов	0103000020E61000000100000005000000F46A80D2500D5A402046088F362C4A40F46A80D2500D5A40B3EA73B5152F4A40F27B9BFEEC0D5A40B3EA73B5152F4A40F27B9BFEEC0D5A402046088F362C4A40F46A80D2500D5A402046088F362C4A40
1809	27	104.212604	104.22433599999999	52.351751999999998	52.344298000000002	улица Муравьева	0103000020E61000000100000005000000ECBFCE4D9B0D5A40030AF5F4112C4A40ECBFCE4D9B0D5A40BB26A435062D4A4030D461855B0E5A40BB26A435062D4A4030D461855B0E5A40030AF5F4112C4A40ECBFCE4D9B0D5A40030AF5F4112C4A40
1874	27	104.21048399999999	104.232088	52.351889999999997	52.338977999999997	улица Мира	0103000020E610000001000000050000003315E291780D5A40200890A1632B4A403315E291780D5A400CE544BB0A2D4A40D272A087DA0E5A400CE544BB0A2D4A40D272A087DA0E5A40200890A1632B4A403315E291780D5A40200890A1632B4A40
2279	27	104.305319	104.330499	52.270529000000003	52.261546000000003	улица Лыткина	0103000020E610000001000000050000003CF6B3588A135A402733DE567A214A403CF6B3588A135A404FCFBBB1A0224A40161747E526155A404FCFBBB1A0224A40161747E526155A402733DE567A214A403CF6B3588A135A402733DE567A214A40
3474	27	104.329268	104.34119800000001	52.307001999999997	52.297953999999997	улица Лесная	0103000020E61000000100000005000000A3E716BA12155A402FDB4E5B23264A40A3E716BA12155A403EE76ED74B274A407BDD2230D6155A403EE76ED74B274A407BDD2230D6155A402FDB4E5B23264A40A3E716BA12155A402FDB4E5B23264A40
3678	27	104.25148299999999	104.285736	52.278641	52.234302	улица Лермонтова	0103000020E61000000100000005000000FF1F274C18105A4096B1A19BFD1D4A40FF1F274C18105A4091291F82AA234A408DD2A57F49125A4091291F82AA234A408DD2A57F49125A4096B1A19BFD1D4A40FF1F274C18105A4096B1A19BFD1D4A40
3135	27	104.339356	104.340785	52.302624999999999	52.291637000000001	улица Ленская	0103000020E61000000100000005000000E36C3A02B8155A40DBA6785C54254A40E36C3A02B8155A40DBF97E6ABC264A40E97DE36BCF155A40DBF97E6ABC264A40E97DE36BCF155A40DBA6785C54254A40E36C3A02B8155A40DBA6785C54254A40
1767	27	104.209289	104.22953699999999	52.348588999999997	52.336627999999997	улица Ленинградская	0103000020E61000000100000005000000679AB0FD640D5A407D7555A0162B4A40679AB0FD640D5A40675F79909E2C4A40340EF5BBB00E5A40675F79909E2C4A40340EF5BBB00E5A407D7555A0162B4A40679AB0FD640D5A407D7555A0162B4A40
519	27	104.278621	104.286652	52.290756000000002	52.276111999999998	улица Ленина	0103000020E61000000100000005000000A5BE2CEDD4115A403E0455A357234A40A5BE2CEDD4115A40D28E1B7E37254A405055A18158125A40D28E1B7E37254A405055A18158125A403E0455A357234A40A5BE2CEDD4115A403E0455A357234A40
3842	27	104.281505	104.282331	52.233744999999999	52.231461000000003	улица Костычева	0103000020E61000000100000005000000452A8C2D04125A4055A69883A01D4A40452A8C2D04125A40404D2D5BEB1D4A4068E90AB611125A40404D2D5BEB1D4A4068E90AB611125A4055A69883A01D4A40452A8C2D04125A4055A69883A01D4A40
2625	27	104.28874500000001	104.293228	52.276271000000001	52.275539000000002	улица Коммунаров	0103000020E610000001000000050000008CF84ECC7A125A40E3E2A8DC44234A408CF84ECC7A125A40A7EA1ED95C234A4060915F3FC4125A40A7EA1ED95C234A4060915F3FC4125A40E3E2A8DC44234A408CF84ECC7A125A40E3E2A8DC44234A40
68438	27	104.27763299999999	104.295833	52.291147000000002	52.275787000000001	улица Карла Маркса	0103000020E6100000010000000500000095D233BDC4115A40BBD408FD4C234A4095D233BDC4115A400DAA0D4E44254A40F70489EDEE125A400DAA0D4E44254A40F70489EDEE125A40BBD408FD4C234A4095D233BDC4115A40BBD408FD4C234A40
68620	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Фрунзе	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
2662	27	104.292877	104.321731	52.288513999999999	52.260719000000002	улица Карла Либкнехта	0103000020E610000001000000050000000A302C7FBE125A4011397D3D5F214A400A302C7FBE125A401538D906EE244A4000C79E3D97145A401538D906EE244A4000C79E3D97145A4011397D3D5F214A400A302C7FBE125A4011397D3D5F214A40
28894	27	104.254986	104.259415	52.325158999999999	52.322097999999997	улица Загородная	0103000020E6100000010000000500000006BCCCB051105A40B20DDC813A294A4006BCCCB051105A40028063CF9E294A40E1455F419A105A40028063CF9E294A40E1455F419A105A40B20DDC813A294A4006BCCCB051105A40B20DDC813A294A40
1833	27	104.22164100000001	104.231675	52.349347999999999	52.343209000000002	улица Жукова	0103000020E61000000100000005000000FA9CBB5D2F0E5A40B058C345EE2B4A40FA9CBB5D2F0E5A4025766D6FB72C4A40401361C3D30E5A4025766D6FB72C4A40401361C3D30E5A40B058C345EE2B4A40FA9CBB5D2F0E5A40B058C345EE2B4A40
1297	27	104.3562	104.373268	52.279488999999998	52.277588000000002	улица Дорожная	0103000020E6100000010000000500000074B515FBCB165A408BE1EA0088234A4074B515FBCB165A40BE4BA94BC6234A402C29779FE3175A40BE4BA94BC6234A402C29779FE3175A408BE1EA0088234A4074B515FBCB165A408BE1EA0088234A40
2238	27	104.23885300000001	104.241826	52.309739	52.308985	улица Днепровская	0103000020E610000001000000050000004CE3175E490F5A402FFA0AD28C274A404CE3175E490F5A40DBA50D87A5274A40A454C2137A0F5A40DBA50D87A5274A40A454C2137A0F5A402FFA0AD28C274A404CE3175E490F5A402FFA0AD28C274A40
2318	27	104.318021	104.34401800000001	52.2789	52.260581000000002	улица Депутатская	0103000020E610000001000000050000003D9CC0745A145A40C07ADCB75A214A403D9CC0745A145A405D6DC5FEB2234A4010CF126404165A405D6DC5FEB2234A4010CF126404165A40C07ADCB75A214A403D9CC0745A145A40C07ADCB75A214A40
3014	27	104.2864	104.317967	52.293399000000001	52.279544000000001	улица Декабрьских Событий	0103000020E61000000100000005000000C364AA6054125A4082E50819C8234A40C364AA6054125A40EDD632198E254A40438D429259145A40EDD632198E254A40438D429259145A4082E50819C8234A40C364AA6054125A4082E50819C8234A40
3626	27	104.24976700000001	104.258849	52.286805999999999	52.269388999999997	улица Гоголя	0103000020E61000000100000005000000AF27BA2EFC0F5A407973B8567B224A40AF27BA2EFC0F5A40F6251B0FB6244A408C6665FB90105A40F6251B0FB6244A408C6665FB90105A407973B8567B224A40AF27BA2EFC0F5A407973B8567B224A40
3232	27	104.333068	104.334577	52.310301000000003	52.309595999999999	улица Вьюжная	0103000020E6100000010000000500000006D671FC50155A40787C7BD7A0274A4006D671FC50155A40437573F1B7274A409A3FA6B569155A40437573F1B7274A409A3FA6B569155A40787C7BD7A0274A4006D671FC50155A40787C7BD7A0274A40
2332	27	104.312281	104.324714	52.266468000000003	52.263519000000002	улица Волжская	0103000020E61000000100000005000000618A7269FC135A40F46F97FDBA214A40618A7269FC135A401CB7989F1B224A406AA33A1DC8145A401CB7989F1B224A406AA33A1DC8145A40F46F97FDBA214A40618A7269FC135A40F46F97FDBA214A40
1969	27	104.198087	104.20416899999999	52.341040999999997	52.337981999999997	улица Василия Ледовского	0103000020E61000000100000005000000D1B01875AD0C5A407E5182FE422B4A40D1B01875AD0C5A402DCC423BA72B4A40D976DA1A110D5A402DCC423BA72B4A40D976DA1A110D5A407E5182FE422B4A40D1B01875AD0C5A407E5182FE422B4A40
3649	27	104.24145799999999	104.258741	52.281312999999997	52.274332000000001	улица Валентины Терешковой	0103000020E61000000100000005000000E256410C740F5A40861F9C4F1D234A40E256410C740F5A4046787B1002244A40994869368F105A4046787B1002244A40994869368F105A40861F9C4F1D234A40E256410C740F5A40861F9C4F1D234A40
1985	27	104.139957	104.194934	52.355750999999998	52.331180000000003	улица Баумана	0103000020E610000001000000050000002976340EF5085A406E8B321B642A4A402976340EF5085A407842AF3F892D4A4039B874CC790C5A407842AF3F892D4A4039B874CC790C5A406E8B321B642A4A402976340EF5085A406E8B321B642A4A40
3144	27	104.300208	104.364141	52.297690000000003	52.291046999999999	улица Баррикад	0103000020E61000000100000005000000D87F9D9B36135A40A94C310741254A40D87F9D9B36135A40522CB7B41A264A407F880D164E175A40522CB7B41A264A407F880D164E175A40A94C310741254A40D87F9D9B36135A40A94C310741254A40
2351	27	104.295833	104.393022	52.281126	52.253292999999999	улица Байкальская	0103000020E61000000100000005000000F70489EDEE125A4022A7AFE76B204A40F70489EDEE125A401407D0EFFB234A40F226BF4527195A401407D0EFFB234A40F226BF4527195A4022A7AFE76B204A40F70489EDEE125A4022A7AFE76B204A40
3970	27	104.304097	104.313575	52.228957000000001	52.216842	улица Багратиона	0103000020E61000000100000005000000F373435376135A401A33897AC11B4A40F373435376135A405B9885764E1D4A40F775E09C11145A405B9885764E1D4A40F775E09C11145A401A33897AC11B4A40F373435376135A401A33897AC11B4A40
3949	27	104.313575	104.317419	52.226249000000003	52.224401	улица Аносова	0103000020E61000000100000005000000F775E09C11145A404818062CB91C4A40F775E09C11145A4059E02BBAF51C4A404208C89750145A4059E02BBAF51C4A404208C89750145A404818062CB91C4A40F775E09C11145A404818062CB91C4A40
3920	27	104.312425	104.317177	52.235669999999999	52.233435999999998	улица Ангаргэсстроя	0103000020E61000000100000005000000FB5C6DC5FE135A40C2DA183BE11D4A40FB5C6DC5FE135A40FC523F6F2A1E4A40C782C2A04C145A40FC523F6F2A1E4A40C782C2A04C145A40C2DA183BE11D4A40FB5C6DC5FE135A40C2DA183BE11D4A40
3473	27	104.231154	104.241664	52.261842999999999	52.257008999999996	улица Алмазная	0103000020E61000000100000005000000BC95253ACB0E5A408AE3C0ABE5204A40BC95253ACB0E5A40E0D7481284214A40B727486C770F5A40E0D7481284214A40B727486C770F5A408AE3C0ABE5204A40BC95253ACB0E5A408AE3C0ABE5204A40
3888	27	104.285736	104.307295	52.235427000000001	52.230606000000002	улица Академическая	0103000020E610000001000000050000008DD2A57F49125A407521567F841D4A408DD2A57F49125A4036CCD078221E4A405BCEA5B8AA135A4036CCD078221E4A405BCEA5B8AA135A407521567F841D4A408DD2A57F49125A407521567F841D4A40
3662	27	104.25063	104.253226	52.270816000000003	52.266159000000002	улица 5-я Железнодорожная	0103000020E61000000100000005000000605969520A105A409E44847F11224A40605969520A105A40E59D4319AA224A40CD1FD3DA34105A40E59D4319AA224A40CD1FD3DA34105A409E44847F11224A40605969520A105A409E44847F11224A40
2363	27	104.29475499999999	104.321147	52.273549000000003	52.265520000000002	улица 4-я Советская	0103000020E6100000010000000500000047551344DD125A408B37328FFC214A4047551344DD125A40406D54A703234A40588D25AC8D145A40406D54A703234A40588D25AC8D145A408B37328FFC214A4047551344DD125A408B37328FFC214A40
2293	27	104.32241399999999	104.335071	52.267817999999998	52.252687000000002	улица 30 Иркутской Дивизии	0103000020E610000001000000050000007171546EA2145A40EB8F300C58204A407171546EA2145A40DBA337DC47224A40A2B5A2CD71155A40DBA337DC47224A40A2B5A2CD71155A40EB8F300C58204A407171546EA2145A40EB8F300C58204A40
3565	27	104.244072	104.25148299999999	52.294094000000001	52.278641	улица 2-я Железнодорожная	0103000020E61000000100000005000000A3772AE09E0F5A4091291F82AA234A40A3772AE09E0F5A4094F947DFA4254A40FF1F274C18105A4094F947DFA4254A40FF1F274C18105A4091291F82AA234A40A3772AE09E0F5A4091291F82AA234A40
3089	27	104.311544	104.335493	52.284789000000004	52.264901999999999	улица 1-я Красноказачья	0103000020E61000000100000005000000F6D03E56F0135A408F52094FE8214A40F6D03E56F0135A405AA148F773244A405DC2A1B778155A405AA148F773244A405DC2A1B778155A408F52094FE8214A40F6D03E56F0135A408F52094FE8214A40
69180	27	104.077291	104.473969	52.418295000000001	52.207489000000002	поселок Затон	0103000020E610000001000000050000009C51F355F2045A40CFA3E2FF8E1A4A409C51F355F2045A40488AC8B08A354A4057941282551E5A40488AC8B08A354A4057941282551E5A40CFA3E2FF8E1A4A409C51F355F2045A40CFA3E2FF8E1A4A40
68350	27	104.30319900000001	104.306595	52.288435999999997	52.287301999999997	переулок Волконского	0103000020E61000000100000005000000844BC79C67135A40A609DB4FC6244A40844BC79C67135A40997E8978EB244A407F87A2409F135A40997E8978EB244A407F87A2409F135A40A609DB4FC6244A40844BC79C67135A40A609DB4FC6244A40
68503	27	104.290137	104.305678	52.229149999999997	52.215710999999999	микрорайон Юбилейный	0103000020E610000001000000050000000397C79A91125A409831056B9C1B4A400397C79A91125A406FF085C9541D4A40D446753A90135A406FF085C9541D4A40D446753A90135A409831056B9C1B4A400397C79A91125A409831056B9C1B4A40
68401	27	104.290137	104.305678	52.229149999999997	52.215710999999999	микрорайон Юбилейный	0103000020E610000001000000050000000397C79A91125A409831056B9C1B4A400397C79A91125A406FF085C9541D4A40D446753A90135A406FF085C9541D4A40D446753A90135A409831056B9C1B4A400397C79A91125A409831056B9C1B4A40
68245	27	104.24111600000001	104.25612700000001	52.258178000000001	52.248534999999997	микрорайон Университетскийё	0103000020E61000000100000005000000B6A2CD716E0F5A40A774B0FECF1F4A40B6A2CD716E0F5A40FA4509FA0B214A40D927806264105A40FA4509FA0B214A40D927806264105A40A774B0FECF1F4A40B6A2CD716E0F5A40A774B0FECF1F4A40
68222	27	104.24111600000001	104.25612700000001	52.258178000000001	52.248534999999997	микрорайон Университетский	0103000020E61000000100000005000000B6A2CD716E0F5A40A774B0FECF1F4A40B6A2CD716E0F5A40FA4509FA0B214A40D927806264105A40FA4509FA0B214A40D927806264105A40A774B0FECF1F4A40B6A2CD716E0F5A40A774B0FECF1F4A40
67949	27	104.24111600000001	104.25612700000001	52.258178000000001	52.248534999999997	микрорайон Университетский	0103000020E61000000100000005000000B6A2CD716E0F5A40A774B0FECF1F4A40B6A2CD716E0F5A40FA4509FA0B214A40D927806264105A40FA4509FA0B214A40D927806264105A40A774B0FECF1F4A40B6A2CD716E0F5A40A774B0FECF1F4A40
68486	27	104.314329	104.324247	52.328065000000002	52.320996999999998	микрорайон Топкинский	0103000020E61000000100000005000000CDCB61F71D145A409B8E006E16294A40CDCB61F71D145A402BFBAE08FE294A40DF347D76C0145A402BFBAE08FE294A40DF347D76C0145A409B8E006E16294A40CDCB61F71D145A409B8E006E16294A40
68429	27	104.265811	104.283023	52.239562999999997	52.226667999999997	микрорайон Радужный	0103000020E61000000100000005000000B1FA230C03115A405D86FF74031D4A40B1FA230C03115A40732A1900AA1E4A400341800C1D125A40732A1900AA1E4A400341800C1D125A405D86FF74031D4A40B1FA230C03115A405D86FF74031D4A40
68516	27	104.224129	104.24426099999999	52.265013000000003	52.248750000000001	микрорайон Первомайский	0103000020E6100000010000000500000074452921580E5A40A4703D0AD71F4A4074452921580E5A40E7012CF2EB214A400CACE3F8A10F5A40E7012CF2EB214A400CACE3F8A10F5A40A4703D0AD71F4A4074452921580E5A40A4703D0AD71F4A40
68461	27	104.224129	104.24426099999999	52.265013000000003	52.248750000000001	микрорайон Первомайский	0103000020E6100000010000000500000074452921580E5A40A4703D0AD71F4A4074452921580E5A40E7012CF2EB214A400CACE3F8A10F5A40E7012CF2EB214A400CACE3F8A10F5A40A4703D0AD71F4A4074452921580E5A40A4703D0AD71F4A40
68465	27	104.36630599999999	104.376124	52.330910000000003	52.323546	микрорайон Зелёный	0103000020E610000001000000050000000795B88E71175A40356090F469294A400795B88E71175A40AEF545425B2A4A4068CF656A12185A40AEF545425B2A4A4068CF656A12185A40356090F469294A400795B88E71175A40356090F469294A40
68397	27	104.36630599999999	104.376124	52.330910000000003	52.323546	микрорайон Зелёный	0103000020E610000001000000050000000795B88E71175A40356090F469294A400795B88E71175A40AEF545425B2A4A4068CF656A12185A40AEF545425B2A4A4068CF656A12185A40356090F469294A400795B88E71175A40356090F469294A40
68499	27	104.36630599999999	104.376124	52.330910000000003	52.323546	микрорайон Зелёный	0103000020E610000001000000050000000795B88E71175A40356090F469294A400795B88E71175A40AEF545425B2A4A4068CF656A12185A40AEF545425B2A4A4068CF656A12185A40356090F469294A400795B88E71175A40356090F469294A40
2497	27	104.343309	104.35717	52.252797000000001	52.247978000000003	маршала Жукова проспект	0103000020E610000001000000050000000ADB4FC6F8155A4052103CBEBD1F4A400ADB4FC6F8155A4072C3EFA65B204A4030478FDFDB165A4072C3EFA65B204A4030478FDFDB165A4052103CBEBD1F4A400ADB4FC6F8155A4052103CBEBD1F4A40
68402	27	104.206998	104.21583800000001	52.264913	52.250807000000002	бульвар Валентина Рябикова	0103000020E6100000010000000500000098158A743F0D5A40CF4D9B711A204A4098158A743F0D5A4083A44FABE8214A40FBCE2F4AD00D5A4083A44FABE8214A40FBCE2F4AD00D5A40CF4D9B711A204A4098158A743F0D5A40CF4D9B711A204A40
68413	27	104.263413	104.27138100000001	52.258150000000001	52.256633999999998	академика Курчатова	0103000020E61000000100000005000000D71533C2DB105A4055850662D9204A40D71533C2DB105A4030BB270F0B214A405FF0694E5E115A4030BB270F0B214A405FF0694E5E115A4055850662D9204A40D71533C2DB105A4055850662D9204A40
68512	27	104.16583799999999	104.195994	52.345376000000002	52.327091000000003	Ярославского	0103000020E61000000100000005000000C79BFC169D0A5A4071E82D1EDE294A40C79BFC169D0A5A406269E047352C4A40950D6B2A8B0C5A406269E047352C4A40950D6B2A8B0C5A4071E82D1EDE294A40C79BFC169D0A5A4071E82D1EDE294A40
67929	27	104.335071	104.33605	52.281284999999997	52.267752000000002	Ядринцева	0103000020E61000000100000005000000A2B5A2CD71155A4024B891B245224A40A2B5A2CD71155A407CED992501244A4088F4DBD781155A407CED992501244A4088F4DBD781155A4024B891B245224A40A2B5A2CD71155A4024B891B245224A40
68396	27	104.342437	104.356757	52.279693000000002	52.253717999999999	Ширямова	0103000020E610000001000000050000002FFCE07CEA155A400934D8D479204A402FFCE07CEA155A40C7F5EFFACC234A409FE74F1BD5165A40C7F5EFFACC234A409FE74F1BD5165A400934D8D479204A402FFCE07CEA155A400934D8D479204A40
68470	27	104.29294899999999	104.32404	52.325814000000001	52.305774	Шевцова	0103000020E61000000100000005000000569929ADBF125A40CAFB389A23274A40569929ADBF125A401B4AED45B4294A4022A64412BD145A401B4AED45B4294A4022A64412BD145A40CAFB389A23274A40569929ADBF125A40CAFB389A23274A40
68501	27	104.244243	104.264329	52.273212999999998	52.268346999999999	Чернышевского	0103000020E61000000100000005000000B95164ADA10F5A40677DCA3159224A40B95164ADA10F5A40C8EBC1A4F8224A409A982EC4EA105A40C8EBC1A4F8224A409A982EC4EA105A40677DCA3159224A40B95164ADA10F5A40677DCA3159224A40
69556	27	104.25770799999999	104.262317	52.287984999999999	52.275323999999998	Челнокова	0103000020E61000000100000005000000B9FAB1497E105A40E6E61BD13D234A40B9FAB1497E105A40895E46B1DC244A40D40B3ECDC9105A40895E46B1DC244A40D40B3ECDC9105A40E6E61BD13D234A40B9FAB1497E105A40E6E61BD13D234A40
68423	27	104.12985999999999	104.145302	52.392659000000002	52.386471	Центральная	0103000020E61000000100000005000000BF4351A04F085A401CEDB8E177314A40BF4351A04F085A4073BD6DA642324A40C782C2A04C095A4073BD6DA642324A40C782C2A04C095A401CEDB8E177314A40BF4351A04F085A401CEDB8E177314A40
68466	27	104.232088	104.242257	52.338977999999997	52.303324000000003	Трактовая	0103000020E61000000100000005000000D272A087DA0E5A40C40B2252D3264A40D272A087DA0E5A40200890A1632B4A40880E8123810F5A40200890A1632B4A40880E8123810F5A40C40B2252D3264A40D272A087DA0E5A40C40B2252D3264A40
68484	27	104.281711	104.286418	52.292408000000002	52.283082	Сухэ-Батора	0103000020E610000001000000050000001AFB928D07125A400B0BEE073C244A401AFB928D07125A405D8B16A06D254A4016BF29AC54125A405D8B16A06D254A4016BF29AC54125A400B0BEE073C244A401AFB928D07125A400B0BEE073C244A40
68334	27	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
68913	27	104.296812	104.30937	52.265520000000002	52.260432000000002	Сибирская	0103000020E61000000100000005000000DD43C2F7FE125A407B6AF5D555214A40DD43C2F7FE125A408B37328FFC214A404417D4B7CC135A408B37328FFC214A404417D4B7CC135A407B6AF5D555214A40DD43C2F7FE125A407B6AF5D555214A40
68452	27	104.1553	104.19598499999999	52.353000999999999	52.333370000000002	Севастопольская	0103000020E610000001000000050000006744696FF0095A40D8BB3FDEAB2A4A406744696FF0095A40473A03232F2D4A406B60AB048B0C5A40473A03232F2D4A406B60AB048B0C5A40D8BB3FDEAB2A4A406744696FF0095A40D8BB3FDEAB2A4A40
68479	27	104.143317	104.210098	52.360399000000001	52.329462999999997	Розы Люксембург	0103000020E610000001000000050000007EFD101B2C095A40FB1EF5D72B2A4A407EFD101B2C095A406C41EF8D212E4A401FBDE13E720D5A406C41EF8D212E4A401FBDE13E720D5A40FB1EF5D72B2A4A407EFD101B2C095A40FB1EF5D72B2A4A40
68373	27	104.29983900000001	104.334272	52.310938999999998	52.298478000000003	Радищева	0103000020E610000001000000050000002FC4EA8F30135A40AA49F08634264A402FC4EA8F30135A40850662D9CC274A40FCFD62B664155A40850662D9CC274A40FCFD62B664155A40AA49F08634264A402FC4EA8F30135A40AA49F08634264A40
68495	27	104.297629	104.306684	52.326056000000001	52.299760999999997	Рабочего Штаба	0103000020E61000000100000005000000D655815A0C135A40E1CE85915E264A40D655815A0C135A401155F833BC294A40378DEDB5A0135A401155F833BC294A40378DEDB5A0135A40E1CE85915E264A40D655815A0C135A40E1CE85915E264A40
1792	27	104.212334	104.22615	52.355635999999997	52.346972000000001	Пулковский переулок	0103000020E610000001000000050000000C7558E1960D5A4059501894692C4A400C7558E1960D5A40DFA3FE7A852D4A40637FD93D790E5A40DFA3FE7A852D4A40637FD93D790E5A4059501894692C4A400C7558E1960D5A4059501894692C4A40
2393	27	104.31109499999999	104.31273899999999	52.261429999999997	52.256838000000002	Постышева бульвар	0103000020E61000000100000005000000BEBC00FBE8135A405E2F4D11E0204A40BEBC00FBE8135A40BD18CA8976214A40C24B70EA03145A40BD18CA8976214A40C24B70EA03145A405E2F4D11E0204A40BEBC00FBE8135A405E2F4D11E0204A40
68427	27	104.25575000000001	104.27187499999999	52.354002000000001	52.306507000000003	Полярная	0103000020E61000000100000005000000EE7C3F355E105A405F7F129F3B274A40EE7C3F355E105A40FB5B02F04F2D4A406666666666115A40FB5B02F04F2D4A406666666666115A405F7F129F3B274A40EE7C3F355E105A405F7F129F3B274A40
28865	27	104.297037	104.31415800000001	52.282381999999998	52.264048000000003	Партизанская улица	0103000020E61000000100000005000000ED2C7AA702135A4080492A53CC214A40ED2C7AA702135A40527DE71725244A40B7F1272A1B145A40527DE71725244A40B7F1272A1B145A4080492A53CC214A40ED2C7AA702135A4080492A53CC214A40
68515	27	104.323887	104.328855	52.279935999999999	52.272789000000003	Омулевского	0103000020E610000001000000050000005F268A90BA145A40B2DAFCBFEA224A405F268A90BA145A408D7C5EF1D4234A401288D7F50B155A408D7C5EF1D4234A401288D7F50B155A40B2DAFCBFEA224A405F268A90BA145A40B2DAFCBFEA224A40
68906	27	104.22013200000001	104.240146	52.299909999999997	52.298208000000002	Олонская	0103000020E61000000100000005000000663387A4160E5A40EAB303AE2B264A40663387A4160E5A4026DF6C7363264A40F910548D5E0F5A4026DF6C7363264A40F910548D5E0F5A40EAB303AE2B264A40663387A4160E5A40EAB303AE2B264A40
68490	27	104.247432	104.250692	52.27178	52.265652000000003	Новокшонова	0103000020E61000000100000005000000F8FE06EDD50F5A40FA0E7EE200224A40F8FE06EDD50F5A407BDAE1AFC9224A409B5775560B105A407BDAE1AFC9224A409B5775560B105A40FA0E7EE200224A40F8FE06EDD50F5A40FA0E7EE200224A40
68472	27	104.20796900000001	104.21759	52.367849999999997	52.345365000000001	Новаторов	0103000020E610000001000000050000003D65355D4F0D5A406E179AEB342C4A403D65355D4F0D5A40B3EA73B5152F4A40F27B9BFEEC0D5A40B3EA73B5152F4A40F27B9BFEEC0D5A406E179AEB342C4A403D65355D4F0D5A406E179AEB342C4A40
68912	27	104.305723	104.328864	52.301132000000003	52.297744999999999	Нестерова	0103000020E61000000100000005000000A4A833F790135A4015C616821C264A40A4A833F790135A40B9E34D7E8B264A403B35971B0C155A40B9E34D7E8B264A403B35971B0C155A4015C616821C264A40A4A833F790135A4015C616821C264A40
68496	27	104.281828	104.287999	52.291393999999997	52.288376	Некрасова	0103000020E6100000010000000500000037C64E7809125A40C4793881E9244A4037C64E7809125A4014200A664C254A40F7915B936E125A4014200A664C254A40F7915B936E125A40C4793881E9244A4037C64E7809125A40C4793881E9244A40
68517	27	104.307295	104.315003	52.230606000000002	52.225012999999997	Мухиной	0103000020E610000001000000050000005BCEA5B8AA135A406116DA39CD1C4A405BCEA5B8AA135A407521567F841D4A4015C9570229145A407521567F841D4A4015C9570229145A406116DA39CD1C4A405BCEA5B8AA135A406116DA39CD1C4A40
68487	27	104.195455	104.21372700000001	52.268573000000004	52.259279999999997	Маршала Конева	0103000020E61000000100000005000000BD35B055820C5A40E140481630214A40BD35B055820C5A4058CB9D9960224A406CD102B4AD0D5A4058CB9D9960224A406CD102B4AD0D5A40E140481630214A40BD35B055820C5A40E140481630214A40
68497	27	104.22807299999999	104.23658	52.265138999999998	52.254649000000001	Мамина-Сибиряка	0103000020E6100000010000000500000070067FBF980E5A40C47AA35698204A4070067FBF980E5A4073F22213F0214A40D0B87020240F5A4073F22213F0214A40D0B87020240F5A40C47AA35698204A4070067FBF980E5A40C47AA35698204A40
68504	27	104.210655	104.21684399999999	52.356197000000002	52.352572000000002	Макаренко	0103000020E610000001000000050000004AEF1B5F7B0D5A401FBE4C14212D4A404AEF1B5F7B0D5A4077F700DD972D4A405D15A8C5E00D5A4077F700DD972D4A405D15A8C5E00D5A401FBE4C14212D4A404AEF1B5F7B0D5A401FBE4C14212D4A40
68459	27	104.25148299999999	104.285736	52.278641	52.234302	Лермонтова	0103000020E61000000100000005000000FF1F274C18105A4096B1A19BFD1D4A40FF1F274C18105A4091291F82AA234A408DD2A57F49125A4091291F82AA234A408DD2A57F49125A4096B1A19BFD1D4A40FF1F274C18105A4096B1A19BFD1D4A40
68919	27	104.278621	104.2864	52.290756000000002	52.276111999999998	Ленина	0103000020E61000000100000005000000A5BE2CEDD4115A403E0455A357234A40A5BE2CEDD4115A40D28E1B7E37254A40C364AA6054125A40D28E1B7E37254A40C364AA6054125A403E0455A357234A40A5BE2CEDD4115A403E0455A357234A40
68483	27	104.293695	104.335916	52.27825	52.270606999999998	Красных Мадьяр	0103000020E61000000100000005000000EBFF1CE6CB125A40CA880B40A3224A40EBFF1CE6CB125A40560E2DB29D234A40008DD2A57F155A40560E2DB29D234A40008DD2A57F155A40CA880B40A3224A40EBFF1CE6CB125A40CA880B40A3224A40
68383	27	104.329466	104.335071	52.287021000000003	52.267778999999997	Красноярская	0103000020E6100000010000000500000036C98FF815155A401DC70F9546224A4036C98FF815155A40F321A81ABD244A40A2B5A2CD71155A40F321A81ABD244A40A2B5A2CD71155A401DC70F9546224A4036C98FF815155A401DC70F9546224A40
68494	27	104.28155	104.286383	52.275787000000001	52.273147000000002	Красного Восстания	0103000020E61000000100000005000000158C4AEA04125A4011001C7BF6224A40158C4AEA04125A40BBD408FD4C234A4058C85C1954125A40BBD408FD4C234A4058C85C1954125A4011001C7BF6224A40158C4AEA04125A4011001C7BF6224A40
68080	27	103.836389	103.86677	52.516751999999997	52.503937999999998	Космонавтов	0103000020E61000000100000005000000FC6EBA6587F55940179B560A81404A40FC6EBA6587F559404012F6ED24424A40DAC9E02879F759404012F6ED24424A40DAC9E02879F75940179B560A81404A40FC6EBA6587F55940179B560A81404A40
28859	27	104.291584	104.31180500000001	52.271362000000003	52.261524000000001	Коммунистическая улица	0103000020E610000001000000050000005C02F04FA9125A403F8F519E79214A405C02F04FA9125A4047B071FDBB224A40AD6EF59CF4135A4047B071FDBB224A40AD6EF59CF4135A403F8F519E79214A405C02F04FA9125A403F8F519E79214A40
68918	27	104.291584	104.31180500000001	52.271362000000003	52.261524000000001	Коммунистическая	0103000020E610000001000000050000005C02F04FA9125A403F8F519E79214A405C02F04FA9125A4047B071FDBB224A40AD6EF59CF4135A4047B071FDBB224A40AD6EF59CF4135A403F8F519E79214A405C02F04FA9125A403F8F519E79214A40
68360	27	104.319827	104.340219	52.298350999999997	52.295465	Каштаковская	0103000020E610000001000000050000002E58AA0B78145A406B0E10CCD1254A402E58AA0B78145A404CDD955D30264A40959EE925C6155A404CDD955D30264A40959EE925C6155A406B0E10CCD1254A402E58AA0B78145A406B0E10CCD1254A40
68356	27	104.292877	104.321731	52.288513999999999	52.260719000000002	Карла Либкнехта	0103000020E610000001000000050000000A302C7FBE125A4011397D3D5F214A400A302C7FBE125A401538D906EE244A4000C79E3D97145A401538D906EE244A4000C79E3D97145A4011397D3D5F214A400A302C7FBE125A4011397D3D5F214A40
67942	27	104.077291	104.473969	52.418295000000001	52.207489000000002	Иосифа Уткина	0103000020E610000001000000050000009C51F355F2045A40CFA3E2FF8E1A4A409C51F355F2045A40488AC8B08A354A4057941282551E5A40488AC8B08A354A4057941282551E5A40CFA3E2FF8E1A4A409C51F355F2045A40CFA3E2FF8E1A4A40
68480	27	104.321022	104.331298	52.269410999999998	52.262025000000001	Зверева	0103000020E61000000100000005000000FAD2DB9F8B145A4001DE02098A214A40FAD2DB9F8B145A406117450F7C224A40BCCE86FC33155A406117450F7C224A40BCCE86FC33155A4001DE02098A214A40FAD2DB9F8B145A4001DE02098A214A40
68471	27	104.242554	104.262281	52.275323999999998	52.270937000000004	Звездинская	0103000020E61000000100000005000000E5603601860F5A4060234910AE224A40E5603601860F5A40E6E61BD13D234A402E573F36C9105A40E6E61BD13D234A402E573F36C9105A4060234910AE224A40E5603601860F5A4060234910AE224A40
68476	27	104.35616400000001	104.381604	52.279693000000002	52.275973999999998	Дорожная	0103000020E61000000100000005000000CE001764CB165A40ED45B41D53234A40CE001764CB165A40C7F5EFFACC234A4075012F336C185A40C7F5EFFACC234A4075012F336C185A40ED45B41D53234A40CE001764CB165A40ED45B41D53234A40
68454	27	104.2864	104.317967	52.293399000000001	52.279544000000001	Декабрьских Событий	0103000020E61000000100000005000000C364AA6054125A4082E50819C8234A40C364AA6054125A40EDD632198E254A40438D429259145A40EDD632198E254A40438D429259145A4082E50819C8234A40C364AA6054125A4082E50819C8234A40
68455	27	104.303307	104.311374	52.303874999999998	52.298383999999999	Госпитальная	0103000020E610000001000000050000007769C36169135A4028D3687231264A407769C36169135A4037894160E5264A40C8B4368DED135A4037894160E5264A40C8B4368DED135A4028D3687231264A407769C36169135A4028D3687231264A40
68488	27	104.31079	104.31422999999999	52.234771000000002	52.231985000000002	Гидростроителей	0103000020E61000000100000005000000207BBDFBE3135A40CF143AAFB11D4A40207BBDFBE3135A404D86E3F90C1E4A40035B25581C145A404D86E3F90C1E4A40035B25581C145A40CF143AAFB11D4A40207BBDFBE3135A40CF143AAFB11D4A40
68410	27	104.229663	104.235223	52.273631999999999	52.270783000000002	Воронежская	0103000020E610000001000000050000007B8670CCB20E5A4009A87004A9224A407B8670CCB20E5A40CD91955F06234A401711C5E40D0F5A40CD91955F06234A401711C5E40D0F5A4009A87004A9224A407B8670CCB20E5A4009A87004A9224A40
68787	27	104.199066	104.203414	52.350911000000004	52.346877999999997	Воинская Площадка	0103000020E61000000100000005000000B7EF517FBD0C5A40D7D9907F662C4A40B7EF517FBD0C5A404167D2A6EA2C4A401B6327BC040D5A404167D2A6EA2C4A401B6327BC040D5A40D7D9907F662C4A40B7EF517FBD0C5A40D7D9907F662C4A40
3396	27	104.206998	104.21583800000001	52.264913	52.250807000000002	Валентина Рябикова бульвар	0103000020E6100000010000000500000098158A743F0D5A40CF4D9B711A204A4098158A743F0D5A4083A44FABE8214A40FBCE2F4AD00D5A4083A44FABE8214A40FBCE2F4AD00D5A40CF4D9B711A204A4098158A743F0D5A40CF4D9B711A204A40
68389	27	104.242509	104.252471	52.290242999999997	52.288519000000001	Боткина	0103000020E6100000010000000500000015FF7744850F5A4027A3CA30EE244A4015FF7744850F5A404B72C0AE26254A400F0C207C28105A404B72C0AE26254A400F0C207C28105A4027A3CA30EE244A4015FF7744850F5A4027A3CA30EE244A40
68468	27	104.29724299999999	104.31465300000001	52.238625999999996	52.231400999999998	Безбокова	0103000020E61000000100000005000000C1FD800706135A407FA1478C9E1D4A40C1FD800706135A40D6FCF84B8B1E4A40A725564623145A40D6FCF84B8B1E4A40A725564623145A407FA1478C9E1D4A40C1FD800706135A407FA1478C9E1D4A40
68493	27	104.295833	104.39894099999999	52.281126	52.252698000000002	Байкальская	0103000020E61000000100000005000000F70489EDEE125A40DFE1766858204A40F70489EDEE125A401407D0EFFB234A402502D53F88195A401407D0EFFB234A402502D53F88195A40DFE1766858204A40F70489EDEE125A40DFE1766858204A40
68458	27	104.235664	104.237739	52.260074000000003	52.258139	Афанасьева	0103000020E610000001000000050000000D36751E150F5A403C69E1B20A214A400D36751E150F5A401C45D61A4A214A40F67EA31D370F5A401C45D61A4A214A40F67EA31D370F5A403C69E1B20A214A400D36751E150F5A403C69E1B20A214A40
68412	27	104.213188	104.229986	52.358435	52.348303000000001	Авиастроителей	0103000020E6100000010000000500000094F947DFA40D5A40A20C5531952C4A4094F947DFA40D5A40F25EB532E12D4A406C223317B80E5A40F25EB532E12D4A406C223317B80E5A40A20C5531952C4A4094F947DFA40D5A40A20C5531952C4A40
2973	27	104.29085600000001	104.29906699999999	52.288254999999999	52.283219000000003	8 Марта переулок	0103000020E610000001000000050000001BF67B629D125A408C4D2B8540244A401BF67B629D125A4049F4328AE5244A400514EAE923135A4049F4328AE5244A400514EAE923135A408C4D2B8540244A401BF67B629D125A408C4D2B8540244A40
68343	27	104.268497	104.279861	52.286656999999998	52.277631999999997	5-й Армии	0103000020E61000000100000005000000BE840A0E2F115A405A29047289234A40BE840A0E2F115A40B115342DB1244A40419B1C3EE9115A40B115342DB1244A40419B1C3EE9115A405A29047289234A40BE840A0E2F115A405A29047289234A40
68485	27	104.077291	104.473969	52.418295000000001	52.207489000000002	30 Иркутской Дивизии	0103000020E610000001000000050000009C51F355F2045A40CFA3E2FF8E1A4A409C51F355F2045A40488AC8B08A354A4057941282551E5A40488AC8B08A354A4057941282551E5A40CFA3E2FF8E1A4A409C51F355F2045A40CFA3E2FF8E1A4A40
2062	27	104.172422	104.179573	52.351323000000001	52.347076000000001	15-й Советский переулок	0103000020E6100000010000000500000019C748F6080B5A40FE9C82FC6C2C4A4019C748F6080B5A4093AAED26F82C4A40A88FC01F7E0B5A4093AAED26F82C4A40A88FC01F7E0B5A40FE9C82FC6C2C4A4019C748F6080B5A40FE9C82FC6C2C4A40
2008	27	104.177525	104.186652	52.345877000000002	52.341151000000004	12-й Советский переулок	0103000020E610000001000000050000003C4ED1915C0B5A40B5FF01D6AA2B4A403C4ED1915C0B5A4024B891B2452C4A40E9EE3A1BF20B5A4024B891B2452C4A40E9EE3A1BF20B5A40B5FF01D6AA2B4A403C4ED1915C0B5A40B5FF01D6AA2B4A40
68524	27	104.16583799999999	104.195994	52.345376000000002	52.327091000000003	 Ярославского	0103000020E61000000100000005000000C79BFC169D0A5A4071E82D1EDE294A40C79BFC169D0A5A406269E047352C4A40950D6B2A8B0C5A406269E047352C4A40950D6B2A8B0C5A4071E82D1EDE294A40C79BFC169D0A5A4071E82D1EDE294A40
68443	27	104.16583799999999	104.195994	52.345376000000002	52.327091000000003	 Ярославского	0103000020E61000000100000005000000C79BFC169D0A5A4071E82D1EDE294A40C79BFC169D0A5A406269E047352C4A40950D6B2A8B0C5A406269E047352C4A40950D6B2A8B0C5A4071E82D1EDE294A40C79BFC169D0A5A4071E82D1EDE294A40
68447	27	104.295833	104.39894099999999	52.281126	52.252698000000002	 Байкальская	0103000020E61000000100000005000000F70489EDEE125A40DFE1766858204A40F70489EDEE125A401407D0EFFB234A402502D53F88195A401407D0EFFB234A402502D53F88195A40DFE1766858204A40F70489EDEE125A40DFE1766858204A40
68157	59134	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	микрорайон Ангарский	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
68337	59134	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Мира	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
68474	59134	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Ленина	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
67908	59118	102.467016	102.53517100000001	53.577737999999997	53.534320000000001	Российская	0103000020E610000001000000050000005CAD1397E39D5940A3CC069964C44A405CAD1397E39D594006D49B51F3C94A4021B1DD3D40A2594006D49B51F3C94A4021B1DD3D40A25940A3CC069964C44A405CAD1397E39D5940A3CC069964C44A40
68729	59169	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	Рабочая	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
67950	59124	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
69055	59206	104.278621	104.2864	52.290756000000002	52.276111999999998	Ленина	0103000020E61000000100000005000000A5BE2CEDD4115A403E0455A357234A40A5BE2CEDD4115A40D28E1B7E37254A40C364AA6054125A40D28E1B7E37254A40C364AA6054125A403E0455A357234A40A5BE2CEDD4115A403E0455A357234A40
718	2764	104.378963	104.387308	52.281224999999999	52.280993000000002	улица Центральная	0103000020E6100000010000000500000038D906EE40185A40D5B32094F7234A4038D906EE40185A40A7E8482EFF234A40AB5E7EA7C9185A40A7E8482EFF234A40AB5E7EA7C9185A40D5B32094F7234A4038D906EE40185A40D5B32094F7234A40
68667	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	переулок 4-й Коммунальный	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68196	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	бульвар Победы	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67665	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Юбилейная	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67919	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Юбилейная	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68203	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Фридриха Энгельса	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67704	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Томская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68160	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Спортивная	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68077	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Снежная	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68068	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Рябикова	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68174	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Приморская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67857	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Подбельского	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68202	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Погодаева	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67877	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Обручева	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68381	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Набережная	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68170	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Макаренко	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67939	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Ленина	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67660	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Крупской	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68142	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Космонавтов	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67888	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Комсомольская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67701	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	К. Маркса	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68184	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Иркутская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68663	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Енисейская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68118	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Депутатская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67940	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Горького	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68299	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Гидростроителей	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68214	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Гагарина	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67663	59081	101.36801699999999	101.978359	56.379621	56.081105000000001	Возрождения	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67847	59113	103.76191	103.803799	53.171671000000003	53.117330000000003	Карла Маркса	0103000020E61000000100000005000000B41F2922C3F059407B6B60AB048F4A40B41F2922C3F05940F855B950F9954A40AE635C7171F35940F855B950F9954A40AE635C7171F359407B6B60AB048F4A40B41F2922C3F059407B6B60AB048F4A40
68596	59158	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Школьная	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68346	59080	103.90046599999999	103.903368	52.530900000000003	52.526166000000003	улица Урицкого	0103000020E610000001000000050000003C4A253CA1F959403222516859434A403C4A253CA1F9594024B9FC87F4434A40301004C8D0F9594024B9FC87F4434A40301004C8D0F959403222516859434A403C4A253CA1F959403222516859434A40
69524	59080	104.378963	104.387308	52.281224999999999	52.280993000000002	Центральная	0103000020E6100000010000000500000038D906EE40185A40D5B32094F7234A4038D906EE40185A40A7E8482EFF234A40AB5E7EA7C9185A40A7E8482EFF234A40AB5E7EA7C9185A40D5B32094F7234A4038D906EE40185A40D5B32094F7234A40
69522	59080	104.388395	104.405823	52.277940999999998	52.277092000000003	Солнечная	0103000020E6100000010000000500000084BBB376DB185A40DBFD2AC077234A4084BBB376DB185A40D89B189293234A40BC3D0801F9195A40D89B189293234A40BC3D0801F9195A40DBFD2AC077234A4084BBB376DB185A40DBFD2AC077234A40
68432	59080	104.314221	104.322288	52.294077000000001	52.291907000000002	Ремесленная	0103000020E61000000100000005000000DAAD65321C145A409B3C65355D254A40DAAD65321C145A40BEC0AC50A4254A402BF9D85DA0145A40BEC0AC50A4254A402BF9D85DA0145A409B3C65355D254A40DAAD65321C145A409B3C65355D254A40
68387	59080	103.64706099999999	103.649872	52.766570999999999	52.765171000000002	Почтовый переулок	0103000020E6100000010000000500000017618A7269E959407F6C921FF1614A4017618A7269E95940F0879FFF1E624A4083A5BA8097E95940F0879FFF1E624A4083A5BA8097E959407F6C921FF1614A4017618A7269E959407F6C921FF1614A40
67656	59080	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Петра Поручикова	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68923	59080	103.869933	103.87516100000001	52.55583	52.546526999999998	Набережная улица	0103000020E61000000100000005000000842D76FBACF75940C4B0C398F4454A40842D76FBACF759405E11FC6F25474A40056F48A302F859405E11FC6F25474A40056F48A302F85940C4B0C398F4454A40842D76FBACF75940C4B0C398F4454A40
68875	59080	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Мехколонна	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68414	59080	103.87291500000001	103.89821999999999	52.562246999999999	52.55583	Иркутская	0103000020E61000000100000005000000064CE0D6DDF759405E11FC6F25474A40064CE0D6DDF7594016A3AEB5F7474A403D27BD6F7CF9594016A3AEB5F7474A403D27BD6F7CF959405E11FC6F25474A40064CE0D6DDF759405E11FC6F25474A40
68367	59080	104.24385599999999	104.256711	52.286011999999999	52.262085999999996	Железнодорожная	0103000020E61000000100000005000000BC3B32569B0F5A40A65EB7088C214A40BC3B32569B0F5A40BC218D0A9C244A408061F9F36D105A40BC218D0A9C244A408061F9F36D105A40A65EB7088C214A40BC3B32569B0F5A40A65EB7088C214A40
68693	59080	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Аэропортовая	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68580	59080	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Артемовская	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68694	59080	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	60 лет Октября	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68197	59080	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	30 лет Победы	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68262	59135	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	Октябрьская	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
69489	59135	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	Марата	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
68871	59180	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Школьная	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
2956	304	103.90046599999999	103.903368	52.530900000000003	52.526166000000003	улица Урицкого	0103000020E610000001000000050000003C4A253CA1F959403222516859434A403C4A253CA1F9594024B9FC87F4434A40301004C8D0F9594024B9FC87F4434A40301004C8D0F959403222516859434A403C4A253CA1F959403222516859434A40
3637	304	103.874289	103.892157	52.549697999999999	52.545797999999998	улица Маяковского	0103000020E610000001000000050000002A90D959F4F75940711C78B5DC454A402A90D959F4F759409B560A815C464A407079AC1919F959409B560A815C464A407079AC1919F95940711C78B5DC454A402A90D959F4F75940711C78B5DC454A40
425	304	103.875969	103.90167	52.556662000000003	52.548005000000003	улица Кирова	0103000020E61000000100000005000000D4D347E00FF85940B285200725464A40D4D347E00FF8594086764EB340474A40327216F6B4F9594086764EB340474A40327216F6B4F95940B285200725464A40D4D347E00FF85940B285200725464A40
67640	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	проспект Карла Маркса	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
68043	304	103.852245	103.86640199999999	52.507483999999998	52.498384000000001	мкр.15	0103000020E610000001000000050000007DCB9C2E8BF65940C26C020CCB3F4A407DCB9C2E8BF65940239F573CF5404A4018CC5F2173F75940239F573CF5404A4018CC5F2173F75940C26C020CCB3F4A407DCB9C2E8BF65940C26C020CCB3F4A40
67633	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	мкр.1064	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
67879	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	мкр.,  983	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
68123	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	мкр.,  1218	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
67921	304	103.886668	103.898661	52.60333	52.595103000000002	мкр. Цементный	0103000020E61000000100000005000000399A232BBFF859403160C9552C4C4A40399A232BBFF859400C59DDEA394D4A40344C6DA983F959400C59DDEA394D4A40344C6DA983F959403160C9552C4C4A40399A232BBFF859403160C9552C4C4A40
67653	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	мкр. Новый-440	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
68140	304	103.86679700000001	103.878916	52.516176999999999	52.509062999999998	мкр. 8	0103000020E6100000010000000500000057D11F9A79F75940444DF4F928414A4057D11F9A79F7594044F9821612424A4098FBE42840F8594044F9821612424A4098FBE42840F85940444DF4F928414A4057D11F9A79F75940444DF4F928414A40
68009	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	мкр. 6а	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
66997	304	103.85686200000001	103.866249	52.516072999999999	52.508290000000002	мкр. 12а	0103000020E61000000100000005000000DACBB6D3D6F6594022718FA50F414A40DACBB6D3D6F659409FAC18AE0E424A40554CA59F70F759409FAC18AE0E424A40554CA59F70F7594022718FA50F414A40DACBB6D3D6F6594022718FA50F414A40
68408	304	103.842309	103.852739	52.499273000000002	52.493307000000001	микрорайон 17А	0103000020E6100000010000000500000018080264E8F55940A6F10BAF243F4A4018080264E8F559404E637B2DE83F4A408541994693F659404E637B2DE83F4A408541994693F65940A6F10BAF243F4A4018080264E8F55940A6F10BAF243F4A40
68477	304	103.85686200000001	103.866249	52.516072999999999	52.508290000000002	микрорайон 12а	0103000020E61000000100000005000000DACBB6D3D6F6594022718FA50F414A40DACBB6D3D6F659409FAC18AE0E424A40554CA59F70F759409FAC18AE0E424A40554CA59F70F7594022718FA50F414A40DACBB6D3D6F6594022718FA50F414A40
68519	304	103.87791	103.886156	52.531118999999997	52.523690000000002	квартал94	0103000020E6100000010000000500000035B56CAD2FF85940029F1F4608434A4035B56CAD2FF8594061A417B5FB434A40DEC9A7C7B6F8594061A417B5FB434A40DEC9A7C7B6F85940029F1F4608434A4035B56CAD2FF85940029F1F4608434A40
67991	304	103.889498	103.898652	52.534055000000002	52.526308999999998	квартал93	0103000020E61000000100000005000000E0F60489EDF85940944BE3175E434A40E0F60489EDF85940F5A10BEA5B444A400A9FAD8383F95940F5A10BEA5B444A400A9FAD8383F95940944BE3175E434A40E0F60489EDF85940944BE3175E434A40
68163	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал9221	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
67641	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал9221	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
67643	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал21118	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
67852	304	103.82455	103.83080200000001	52.511316000000001	52.507545	квартал189	0103000020E61000000100000005000000ADFA5C6DC5F45940C91F0C3CF7404A40ADFA5C6DC5F45940F5F57CCD72414A40E4DC26DC2BF55940F5F57CCD72414A40E4DC26DC2BF55940C91F0C3CF7404A40ADFA5C6DC5F45940C91F0C3CF7404A40
68211	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал А	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
68032	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал 983	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
67864	304	103.861255	103.873364	52.540272000000002	52.535018999999998	квартал 95	0103000020E610000001000000050000000EA14ACD1EF759408BDEA9807B444A400EA14ACD1EF75940E67805A227454A403D601E32E5F75940E67805A227454A403D601E32E5F759408BDEA9807B444A400EA14ACD1EF759408BDEA9807B444A40
67850	304	103.87791	103.886156	52.531118999999997	52.523690000000002	квартал 94	0103000020E6100000010000000500000035B56CAD2FF85940029F1F4608434A4035B56CAD2FF8594061A417B5FB434A40DEC9A7C7B6F8594061A417B5FB434A40DEC9A7C7B6F85940029F1F4608434A4035B56CAD2FF85940029F1F4608434A40
68076	304	103.87271699999999	103.882518	52.538350000000001	52.529158000000002	квартал 85	0103000020E61000000100000005000000726A6798DAF7594059350873BB434A40726A6798DAF759409BE61DA7E8444A406808C72C7BF859409BE61DA7E8444A406808C72C7BF8594059350873BB434A40726A6798DAF7594059350873BB434A40
68049	304	103.87860999999999	103.884934	52.564064000000002	52.561293999999997	квартал 7	0103000020E6100000010000000500000011FC6F253BF8594073B8567BD8474A4011FC6F253BF85940EC6CC83F33484A40954737C2A2F85940EC6CC83F33484A40954737C2A2F8594073B8567BD8474A4011FC6F253BF8594073B8567BD8474A40
67024	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал 63	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
68291	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал 4	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
68047	304	103.796882	103.99841000000001	52.635871000000002	52.417180000000002	квартал 207/2103	0103000020E6100000010000000500000059315C1D00F35940CC457C2766354A4059315C1D00F35940C7BC8E3864514A40F67F0EF3E5FF5940C7BC8E3864514A40F67F0EF3E5FF5940CC457C2766354A4059315C1D00F35940CC457C2766354A40
68505	304	103.859296	103.926194	52.544790999999996	52.525903	Чайковского	0103000020E610000001000000050000005A65A6B4FEF6594024EF1CCA50434A405A65A6B4FEF65940DB1324B6BB454A4017F032C346FB5940DB1324B6BB454A4017F032C346FB594024EF1CCA50434A405A65A6B4FEF6594024EF1CCA50434A40
67010	304	103.845777	103.88081099999999	52.598225999999997	52.575892000000003	Трактовая	0103000020E6100000010000000500000060ADDA3521F6594097033DD4B6494A4060ADDA3521F65940F6CE68AB924C4A4040BD19355FF85940F6CE68AB924C4A4040BD19355FF8594097033DD4B6494A4060ADDA3521F6594097033DD4B6494A40
67938	304	103.88587800000001	103.889174	52.542676999999998	52.537238000000002	Советская улица	0103000020E61000000100000005000000BD8FA339B2F859409015FC36C4444A40BD8FA339B2F859404CA59F7076454A40069D103AE8F859404CA59F7076454A40069D103AE8F859409015FC36C4444A40BD8FA339B2F859409015FC36C4444A40
67769	304	103.893163	103.894133	52.526166000000003	52.524478999999999	Полевая улица	0103000020E61000000100000005000000D3BF249529F959402A38BC2022434A40D3BF249529F959403222516859434A408F519E7939F959403222516859434A408F519E7939F959402A38BC2022434A40D3BF249529F959402A38BC2022434A40
1095	304	103.869933	103.87516100000001	52.55583	52.546526999999998	Набережная улица	0103000020E61000000100000005000000842D76FBACF75940C4B0C398F4454A40842D76FBACF759405E11FC6F25474A40056F48A302F859405E11FC6F25474A40056F48A302F85940C4B0C398F4454A40842D76FBACF75940C4B0C398F4454A40
3967	304	103.87516100000001	103.88592300000001	52.553038000000001	52.536504000000001	Московская улица	0103000020E61000000100000005000000056F48A302F859402B16BF29AC444A40056F48A302F85940FEB8FDF2C9464A408DF161F6B2F85940FEB8FDF2C9464A408DF161F6B2F859402B16BF29AC444A40056F48A302F859402B16BF29AC444A40
67657	304	103.87516100000001	103.88592300000001	52.553038000000001	52.536504000000001	Московская	0103000020E61000000100000005000000056F48A302F859402B16BF29AC444A40056F48A302F85940FEB8FDF2C9464A408DF161F6B2F85940FEB8FDF2C9464A408DF161F6B2F859402B16BF29AC444A40056F48A302F859402B16BF29AC444A40
4185	304	103.82835900000001	103.865639	52.535496000000002	52.494157000000001	Ленинградский проспект	0103000020E610000001000000050000003A9677D503F55940740B5D89403F4A403A9677D503F55940C59107228B444A4019C91EA166F75940C59107228B444A4019C91EA166F75940740B5D89403F4A403A9677D503F55940740B5D89403F4A40
68046	304	103.904185	103.906458	52.526237000000002	52.525311000000002	Кольский переулок	0103000020E610000001000000050000002922C32ADEF95940529D0E643D434A402922C32ADEF95940FB78E8BB5B434A40A54C6A6803FA5940FB78E8BB5B434A40A54C6A6803FA5940529D0E643D434A402922C32ADEF95940529D0E643D434A40
67033	304	103.885024	103.921379	52.550485999999999	52.518391000000001	Карла Маркса	0103000020E61000000100000005000000350BB43BA4F8594037C5E3A25A424A40350BB43BA4F85940F373435376464A40280EA0DFF7FA5940F373435376464A40280EA0DFF7FA594037C5E3A25A424A40350BB43BA4F8594037C5E3A25A424A40
67636	304	103.883605	103.893468	52.519975000000002	52.517876000000001	Заводская	0103000020E610000001000000050000004165FCFB8CF8594010B1C1C249424A404165FCFB8CF859406ADE718A8E424A40710168942EF959406ADE718A8E424A40710168942EF9594010B1C1C249424A404165FCFB8CF8594010B1C1C249424A40
67893	304	103.854428	103.86442599999999	52.520358000000002	52.518177000000001	Гражданская улица	0103000020E610000001000000050000005932C7F2AEF659400B45BA9F53424A405932C7F2AEF65940221B48179B424A40F9F36DC152F75940221B48179B424A40F9F36DC152F759400B45BA9F53424A405932C7F2AEF659400B45BA9F53424A40
67016	304	103.865639	103.90873999999999	52.545366000000001	52.535496000000002	Горького	0103000020E6100000010000000500000019C91EA166F75940C59107228B444A4019C91EA166F75940D82C978DCE454A404A24D1CB28FA5940D82C978DCE454A404A24D1CB28FA5940C59107228B444A4019C91EA166F75940C59107228B444A40
68910	304	103.857608	103.872062	52.595776000000001	52.588357999999999	Гагарина	0103000020E610000001000000050000006E32AA0CE3F65940842BA0504F4B4A406E32AA0CE3F65940F0DE5163424C4A40668522DDCFF75940F0DE5163424C4A40668522DDCFF75940842BA0504F4B4A406E32AA0CE3F65940842BA0504F4B4A40
68063	304	103.86139	103.86635699999999	52.518396000000003	52.512993000000002	Блудова	0103000020E610000001000000050000007EC6850321F75940D9092FC1A9414A407EC6850321F759404930D5CC5A424A40486AA16472F759404930D5CC5A424A40486AA16472F75940D9092FC1A9414A407EC6850321F75940D9092FC1A9414A40
67823	304	103.89550800000001	103.90219999999999	52.535310000000003	52.531880000000001	91-й квартал	0103000020E610000001000000050000009C53C90050F95940C0B2D2A414444A409C53C90050F95940639CBF0985444A40E09C11A5BDF95940639CBF0985444A40E09C11A5BDF95940C0B2D2A414444A409C53C90050F95940C0B2D2A414444A40
68053	304	103.887171	103.894789	52.537976999999998	52.533442000000001	88-й квартал	0103000020E610000001000000050000006ABDDF68C7F859400B28D4D347444A406ABDDF68C7F8594006802A6EDC444A4084F4143944F9594006802A6EDC444A4084F4143944F959400B28D4D347444A406ABDDF68C7F859400B28D4D347444A40
68506	304	103.87271699999999	103.882518	52.538350000000001	52.529158000000002	85-й квартал	0103000020E61000000100000005000000726A6798DAF7594059350873BB434A40726A6798DAF759409BE61DA7E8444A406808C72C7BF859409BE61DA7E8444A406808C72C7BF8594059350873BB434A40726A6798DAF7594059350873BB434A40
68384	304	103.885312	103.889471	52.551138000000002	52.548470999999999	52-й квартал	0103000020E6100000010000000500000068B0A9F3A8F85940F7E6374C34464A4068B0A9F3A8F859409BCAA2B08B464A4063EFC517EDF859409BCAA2B08B464A4063EFC517EDF85940F7E6374C34464A4068B0A9F3A8F85940F7E6374C34464A40
68489	304	103.882644	103.889076	52.522665000000003	52.519568999999997	277-й квартал	0103000020E61000000100000005000000AE80423D7DF85940F981AB3C81424A40AE80423D7DF85940C6E1CCAFE6424A4025EA059FE6F85940C6E1CCAFE6424A4025EA059FE6F85940F981AB3C81424A40AE80423D7DF85940F981AB3C81424A40
68446	304	103.82896	103.834889	52.505263999999997	52.501548	206-й квартал	0103000020E610000001000000050000004C6C3EAE0DF55940E6AF90B932404A404C6C3EAE0DF559404EECA17DAC404A4092B245D26EF559404EECA17DAC404A4092B245D26EF55940E6AF90B932404A404C6C3EAE0DF55940E6AF90B932404A40
67874	304	103.829032	103.834045	52.513688999999999	52.511118000000003	180-й квартал	0103000020E6100000010000000500000099D53BDC0EF55940CF328B506C414A4099D53BDC0EF5594050A8A78FC0414A401C9947FE60F5594050A8A78FC0414A401C9947FE60F55940CF328B506C414A4099D53BDC0EF55940CF328B506C414A40
68677	304	103.83794399999999	103.849343	52.504683	52.497337000000002	18-й микрорайон	0103000020E6100000010000000500000048F8DEDFA0F559409E0B23BDA83F4A4048F8DEDFA0F5594070ECD97399404A408A05BEA25BF6594070ECD97399404A408A05BEA25BF659409E0B23BDA83F4A4048F8DEDFA0F559409E0B23BDA83F4A40
68190	304	103.845579	103.85746399999999	52.502451999999998	52.495390999999998	17-й микрорайон	0103000020E61000000100000005000000CDCB61F71DF65940CADDE7F8683F4A40CDCB61F71DF65940A7E7DD5850404A40D45FAFB0E0F65940A7E7DD5850404A40D45FAFB0E0F65940CADDE7F8683F4A40CDCB61F71DF65940CADDE7F8683F4A40
68172	304	103.852245	103.86640199999999	52.507483999999998	52.498384000000001	15-й микрорайон	0103000020E610000001000000050000007DCB9C2E8BF65940C26C020CCB3F4A407DCB9C2E8BF65940239F573CF5404A4018CC5F2173F75940239F573CF5404A4018CC5F2173F75940C26C020CCB3F4A407DCB9C2E8BF65940C26C020CCB3F4A40
68666	59163	106.70241900000001	106.748395	56.384678999999998	56.342356000000002	Ленский	0103000020E61000000100000005000000B345D26EF4AC5A4071CB4752D22B4C40B345D26EF4AC5A409F3A56293D314C405B5F24B4E5AF5A409F3A56293D314C405B5F24B4E5AF5A4071CB4752D22B4C40B345D26EF4AC5A4071CB4752D22B4C40
68327	59099	104.07950099999999	104.131935	52.229993999999998	52.199066000000002	Орловских комсомольцев	0103000020E61000000100000005000000F4BF5C8B16055A406EDFA3FE7A194A40F4BF5C8B16055A405B238271701D4A40A88C7F9F71085A405B238271701D4A40A88C7F9F71085A406EDFA3FE7A194A40F4BF5C8B16055A406EDFA3FE7A194A40
67706	59088	99.000434999999996	99.077088000000003	54.933630999999998	54.877935999999998	Петина	0103000020E6100000010000000500000085B1852007C0584093FDF33460704B4085B1852007C0584011C4793881774B4080BA8102EFC4584011C4793881774B4080BA8102EFC4584093FDF33460704B4085B1852007C0584093FDF33460704B40
68435	59145	102.02002299999999	102.083049	53.943271000000003	53.890818000000003	Степная	0103000020E61000000100000005000000BD8A8C0E488159401558005306F24A40BD8A8C0E48815940F321A81ABDF84A40CBBDC0AC50855940F321A81ABDF84A40CBBDC0AC508559401558005306F24A40BD8A8C0E488159401558005306F24A40
69445	28534	105.09833399999999	105.12374699999999	52.816600000000001	52.801684999999999	Школьная	0103000020E610000001000000050000006E85B01A4B465A40CD58349D9D664A406E85B01A4B465A40F1F44A5986684A40997E8978EB475A40F1F44A5986684A40997E8978EB475A40CD58349D9D664A406E85B01A4B465A40CD58349D9D664A40
68604	28280	105.037374	105.089557	52.762861000000001	52.743870999999999	Ленина	0103000020E6100000010000000500000020EEEA5564425A40AEB8382A375F4A4020EEEA5564425A406A32E36DA5614A402F88484DBB455A406A32E36DA5614A402F88484DBB455A40AEB8382A375F4A4020EEEA5564425A40AEB8382A375F4A40
69313	28763	104.916398	104.977097	52.778399	52.741450999999998	Школьная	0103000020E61000000100000005000000AB07CC43A63A5A40124BCADDE75E4A40AB07CC43A63A5A409B1E1494A2634A404301DBC1883E5A409B1E1494A2634A404301DBC1883E5A40124BCADDE75E4A40AB07CC43A63A5A40124BCADDE75E4A40
69462	28139	104.994551	105.010227	53.104680999999999	53.095137999999999	Центральная	0103000020E6100000010000000500000010CD3CB9A63F5A40AD4D637B2D8C4A4010CD3CB9A63F5A409CC1DF2F668D4A4051A2258FA7405A409CC1DF2F668D4A4051A2258FA7405A40AD4D637B2D8C4A4010CD3CB9A63F5A40AD4D637B2D8C4A40
67805	27070	104.701835	104.779144	52.833148000000001	52.784101999999997	пер.Коммунальный	0103000020E610000001000000050000000B0C59DDEA2C5A40355D4F745D644A400B0C59DDEA2C5A40295DFA97A46A4A40FAB7CB7EDD315A40295DFA97A46A4A40FAB7CB7EDD315A40355D4F745D644A400B0C59DDEA2C5A40355D4F745D644A40
68098	27070	104.701835	104.779144	52.833148000000001	52.784101999999997	Чапаева	0103000020E610000001000000050000000B0C59DDEA2C5A40355D4F745D644A400B0C59DDEA2C5A40295DFA97A46A4A40FAB7CB7EDD315A40295DFA97A46A4A40FAB7CB7EDD315A40355D4F745D644A400B0C59DDEA2C5A40355D4F745D644A40
68597	27070	104.701835	104.779144	52.833148000000001	52.784101999999997	Первомайская	0103000020E610000001000000050000000B0C59DDEA2C5A40355D4F745D644A400B0C59DDEA2C5A40295DFA97A46A4A40FAB7CB7EDD315A40295DFA97A46A4A40FAB7CB7EDD315A40355D4F745D644A400B0C59DDEA2C5A40355D4F745D644A40
67737	27070	104.701835	104.779144	52.833148000000001	52.784101999999997	Ленина	0103000020E610000001000000050000000B0C59DDEA2C5A40355D4F745D644A400B0C59DDEA2C5A40295DFA97A46A4A40FAB7CB7EDD315A40295DFA97A46A4A40FAB7CB7EDD315A40355D4F745D644A400B0C59DDEA2C5A40355D4F745D644A40
37455	27070	104.701835	104.779144	52.833148000000001	52.784101999999997	Буденного	0103000020E610000001000000050000000B0C59DDEA2C5A40355D4F745D644A400B0C59DDEA2C5A40295DFA97A46A4A40FAB7CB7EDD315A40295DFA97A46A4A40FAB7CB7EDD315A40355D4F745D644A400B0C59DDEA2C5A40355D4F745D644A40
68284	27070	104.701835	104.779144	52.833148000000001	52.784101999999997	50 лет Октября	0103000020E610000001000000050000000B0C59DDEA2C5A40355D4F745D644A400B0C59DDEA2C5A40295DFA97A46A4A40FAB7CB7EDD315A40295DFA97A46A4A40FAB7CB7EDD315A40355D4F745D644A400B0C59DDEA2C5A40355D4F745D644A40
68832	28584	104.77081699999999	104.826477	52.693944000000002	52.667769999999997	Степная	0103000020E61000000100000005000000DA8CD31055315A40FD9FC37C79554A40DA8CD31055315A40B2A03028D3584A405B79C9FFE4345A40B2A03028D3584A405B79C9FFE4345A40FD9FC37C79554A40DA8CD31055315A40FD9FC37C79554A40
69442	27945	104.884139	104.89786599999999	53.152472000000003	53.133924	переулок Школьный	0103000020E610000001000000050000009087BEBB95385A402313F06B24914A409087BEBB95385A4022C7D63384934A402E8CF4A276395A4022C7D63384934A402E8CF4A276395A402313F06B24914A409087BEBB95385A402313F06B24914A40
69448	28855	104.776881	104.80614799999999	52.592395000000003	52.583109999999998	Советская	0103000020E6100000010000000500000090F8156BB8315A403BFC3559A34A4A4090F8156BB8315A402FA86F99D34B4A4017EFC7ED97335A402FA86F99D34B4A4017EFC7ED97335A403BFC3559A34A4A4090F8156BB8315A403BFC3559A34A4A40
69451	28208	105.07694499999999	105.13282	52.959012999999999	52.939860000000003	Школьная	0103000020E61000000100000005000000CEA5B8AAEC445A40C7681D554D784A40CEA5B8AAEC445A402CB81FF0C07A4A404D10751F80485A402CB81FF0C07A4A404D10751F80485A40C7681D554D784A40CEA5B8AAEC445A40C7681D554D784A40
68762	28161	105.02206700000001	105.079289	52.914172000000001	52.899872000000002	Трактовая	0103000020E6100000010000000500000089D4B48B69415A40064B75012F734A4089D4B48B69415A409F758D9603754A40AF7B2B1213455A409F758D9603754A40AF7B2B1213455A40064B75012F734A4089D4B48B69415A40064B75012F734A40
69560	59299	105.07509400000001	105.10727199999999	53.159756000000002	53.145014000000003	Советская	0103000020E610000001000000050000000E881057CE445A4028BB99D18F924A400E881057CE445A407EAB75E272944A40B2F1608BDD465A407EAB75E272944A40B2F1608BDD465A4028BB99D18F924A400E881057CE445A4028BB99D18F924A40
69439	27668	104.600218	104.64472000000001	52.910375999999999	52.897883999999998	Шабагановская	0103000020E610000001000000050000001D1EC2F869265A4003CDE7DCED724A401D1EC2F869265A401A88653387744A40F0C4AC1743295A401A88653387744A40F0C4AC1743295A4003CDE7DCED724A401D1EC2F869265A4003CDE7DCED724A40
69333	59245	105.197113	105.217603	53.211153000000003	53.196536000000002	Школьная	0103000020E610000001000000050000007427D87F9D4C5A404B3E761728994A407427D87F9D4C5A40E5B9BE0F079B4A40BC202235ED4D5A40E5B9BE0F079B4A40BC202235ED4D5A404B3E761728994A407427D87F9D4C5A404B3E761728994A40
69454	29003	104.65497000000001	104.689519	52.620429000000001	52.607999999999997	Молодежная	0103000020E610000001000000050000001D774A07EB295A40E7FBA9F1D24D4A401D774A07EB295A40B83EAC376A4F4A401FBE4C14212C5A40B83EAC376A4F4A401FBE4C14212C5A40E7FBA9F1D24D4A401D774A07EB295A40E7FBA9F1D24D4A40
69232	27406	104.317294	105.588095	53.446100000000001	52.381594999999997	Школьная	0103000020E61000000100000005000000E44D7E8B4E145A4097A8DE1AD8304A40E44D7E8B4E145A40705F07CE19B94A403BFC3559A3655A40705F07CE19B94A403BFC3559A3655A4097A8DE1AD8304A40E44D7E8B4E145A4097A8DE1AD8304A40
69345	59247	104.69355299999999	104.731426	52.999684000000002	52.979649000000002	Школьная	0103000020E61000000100000005000000BB421F2C632C5A4091477023657D4A40BB421F2C632C5A40D02A33A5F57F4A406C5CFFAECF2E5A40D02A33A5F57F4A406C5CFFAECF2E5A4091477023657D4A40BB421F2C632C5A4091477023657D4A40
69238	28380	104.98889200000001	105.02037799999999	52.800896000000002	52.783988000000001	Трактовая	0103000020E61000000100000005000000ABD1AB014A3F5A406D3A02B859644A40ABD1AB014A3F5A40A5BF97C283664A40B4E386DF4D415A40A5BF97C283664A40B4E386DF4D415A406D3A02B859644A40ABD1AB014A3F5A406D3A02B859644A40
69423	59258	104.880295	104.898045	52.717728000000001	52.704149000000001	Школьная	0103000020E6100000010000000500000045F5D6C056385A406C41EF8D215A4A4045F5D6C056385A4035B6D782DE5B4A408655BC9179395A4035B6D782DE5B4A408655BC9179395A406C41EF8D215A4A4045F5D6C056385A406C41EF8D215A4A40
68950	29059	104.63271	104.64907700000001	52.691279999999999	52.682797000000001	Центральная	0103000020E610000001000000050000008A7615527E285A40496760E465574A408A7615527E285A407F30F0DC7B584A407EE5417A8A295A407F30F0DC7B584A407EE5417A8A295A40496760E465574A408A7615527E285A40496760E465574A40
69440	28461	105.001513	105.016327	52.821263999999999	52.808844000000001	Нагорная	0103000020E610000001000000050000003561FBC918405A406DC83F3388674A403561FBC918405A40EAB0C22D1F694A40ADC266800B415A40EAB0C22D1F694A40ADC266800B415A406DC83F3388674A403561FBC918405A406DC83F3388674A40
68987	28939	104.711178	104.765463	52.608099000000003	52.595699000000003	Свердлова	0103000020E610000001000000050000009FE8BAF0832D5A4045A165DD3F4C4A409FE8BAF0832D5A407BDD2230D64D4A4013D38558FD305A407BDD2230D64D4A4013D38558FD305A4045A165DD3F4C4A409FE8BAF0832D5A4045A165DD3F4C4A40
69007	29090	104.55636199999999	104.579323	52.770772000000001	52.762784000000003	Депутатская	0103000020E610000001000000050000002DAF5C6F9B235A40BFF4F6E7A2614A402DAF5C6F9B235A4015562AA8A8624A4085B4C6A013255A4015562AA8A8624A4085B4C6A013255A40BFF4F6E7A2614A402DAF5C6F9B235A40BFF4F6E7A2614A40
69316	28928	104.761573	104.802716	52.619312999999998	52.607436999999997	Школьная	0103000020E610000001000000050000001021AE9CBD305A40AFB0E07EC04D4A401021AE9CBD305A406B7EFCA5454F4A4076FEEDB25F335A406B7EFCA5454F4A4076FEEDB25F335A40AFB0E07EC04D4A401021AE9CBD305A40AFB0E07EC04D4A40
68996	59200	104.977636	105.00234	52.891077000000003	52.879322999999999	Школьная	0103000020E610000001000000050000001BD99596913E5A4070CFF3A78D704A401BD99596913E5A40E19BA6CF0E724A4040DEAB5626405A40E19BA6CF0E724A4040DEAB5626405A4070CFF3A78D704A401BD99596913E5A4070CFF3A78D704A40
68827	27558	104.85646199999999	104.883672	53.055646000000003	53.039011000000002	Советская	0103000020E610000001000000050000001211FE45D0365A409697FC4FFE844A401211FE45D0365A409D137B681F874A40051901158E385A409D137B681F874A40051901158E385A409697FC4FFE844A401211FE45D0365A409697FC4FFE844A40
69438	27731	104.55355	104.571364	52.929178999999998	52.916674999999998	Бохолдой	0103000020E61000000100000005000000DAACFA5C6D235A40C8073D9B55754A40DAACFA5C6D235A40A3906456EF764A4027874F3A91245A40A3906456EF764A4027874F3A91245A40C8073D9B55754A40DAACFA5C6D235A40C8073D9B55754A40
69236	28364	105.05381300000001	105.09165900000001	52.748095999999997	52.724803000000001	Российская	0103000020E6100000010000000500000061C614AC71435A4077853E58C65C4A4061C614AC71435A405B22179CC15F4A4095D8B5BDDD455A405B22179CC15F4A4095D8B5BDDD455A4077853E58C65C4A4061C614AC71435A4077853E58C65C4A40
69435	27434	104.592412	104.609938	52.805365999999999	52.791133000000002	Молодежная	0103000020E6100000010000000500000082700514EA255A40A8E49CD843654A4082700514EA255A40B9A7AB3B16674A409CA5643909275A40B9A7AB3B16674A409CA5643909275A40A8E49CD843654A4082700514EA255A40A8E49CD843654A40
68993	28703	104.83849600000001	104.858924	52.741619999999998	52.727283999999997	Центральная	0103000020E61000000100000005000000EB7420EBA9355A40B87361A4175D4A40EB7420EBA9355A409E077767ED5E4A40F86F5E9CF8365A409E077767ED5E4A40F86F5E9CF8365A40B87361A4175D4A40EB7420EBA9355A40B87361A4175D4A40
68576	27639	104.84025699999999	104.86344200000001	52.938623	52.918830999999997	Ленина	0103000020E610000001000000050000000BCF4BC5C6355A4086C613419C754A400BCF4BC5C6355A40FF2268CC24784A408BFF3BA242375A40FF2268CC24784A408BFF3BA242375A4086C613419C754A400BCF4BC5C6355A4086C613419C754A40
69443	28269	104.964386	104.986413	52.994501999999997	52.980786999999999	Школьная	0103000020E6100000010000000500000019AE0E80B83D5A40C5ABAC6D8A7D4A4019AE0E80B83D5A403EE76ED74B7F4A405AD6FD63213F5A403EE76ED74B7F4A405AD6FD63213F5A40C5ABAC6D8A7D4A4019AE0E80B83D5A40C5ABAC6D8A7D4A40
69235	27932	104.859894	104.88369899999999	53.154449	53.130454999999998	Советская	0103000020E61000000100000005000000B401D88008375A40C24CDBBFB2904A40B401D88008375A4030F31DFCC4934A40812040868E385A4030F31DFCC4934A40812040868E385A40C24CDBBFB2904A40B401D88008375A40C24CDBBFB2904A40
69234	27880	104.968132	104.993078	53.267555999999999	53.255625000000002	Ленина	0103000020E61000000100000005000000828DEBDFF53D5A401F85EB51B8A04A40828DEBDFF53D5A409EEC66463FA24A40221807978E3F5A409EEC66463FA24A40221807978E3F5A401F85EB51B8A04A40828DEBDFF53D5A401F85EB51B8A04A40
69509	59269	104.754593	104.80510599999999	52.716124000000001	52.698096999999997	Центральная	0103000020E61000000100000005000000983270404B305A40C537143E5B594A40983270404B305A40BBF083F3A95B4A400EF450DB86335A40BBF083F3A95B4A400EF450DB86335A40C537143E5B594A40983270404B305A40C537143E5B594A40
68092	25959	103.938366	104.123159	52.23171	52.169508	микрорайон 418	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
68127	25959	103.938366	104.123159	52.23171	52.169508	микрорайон 4	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
67750	25959	103.938366	104.123159	52.23171	52.169508	микрорайон	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
67807	25959	103.938366	104.123159	52.23171	52.169508	квартал 4	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
67790	25959	103.938366	104.123159	52.23171	52.169508	квартал 1839	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
68085	25959	103.938366	104.123159	52.23171	52.169508	Орловских комсомольцев	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
68109	25959	103.938366	104.123159	52.23171	52.169508	Микрорайон 444	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
68280	25959	103.938366	104.123159	52.23171	52.169508	Ленина	0103000020E610000001000000050000006A6B44300EFC594087342A70B2154A406A6B44300EFC5940FD135CACA81D4A40514D49D6E1075A40FD135CACA81D4A40514D49D6E1075A4087342A70B2154A406A6B44300EFC594087342A70B2154A40
68830	26994	103.70893599999999	103.84198600000001	52.116765000000001	52.060747999999997	Советская	0103000020E6100000010000000500000040BD19355FED594011A62897C6074A4040BD19355FED5940A228D027F20E4A40276C3F19E3F55940A228D027F20E4A40276C3F19E3F5594011A62897C6074A4040BD19355FED594011A62897C6074A40
68813	26934	103.888321	103.917337	51.975583	51.961466999999999	Железнодорожная	0103000020E6100000010000000500000067D65240DAF859407497C45911FB494067D65240DAF859404CC45BE7DFFC49404A9A3FA6B5FA59404CC45BE7DFFC49404A9A3FA6B5FA59407497C45911FB494067D65240DAF859407497C45911FB4940
67784	26911	104.074721	104.127021	52.173071	52.152039000000002	Школьная	0103000020E61000000100000005000000C3D4963AC8045A40B85B920376134A40C3D4963AC8045A406971C63027164A40EF39B01C21085A406971C63027164A40EF39B01C21085A40B85B920376134A40C3D4963AC8045A40B85B920376134A40
68986	27057	103.87800799999999	103.925179	52.086671000000003	52.037131000000002	переулок Солнечный	0103000020E610000001000000050000001668774831F859407A5567B5C0044A401668774831F859407D410B09180B4A408BFCFA2136FB59407D410B09180B4A408BFCFA2136FB59407A5567B5C0044A401668774831F859407A5567B5C0044A40
67743	26819	103.909009	103.96294399999999	52.219419000000002	52.194009000000001	Мира	0103000020E6100000010000000500000042B115342DFA594099107349D5184A4042B115342DFA59407E8FFAEB151C4A4048F8DEDFA0FD59407E8FFAEB151C4A4048F8DEDFA0FD594099107349D5184A4042B115342DFA594099107349D5184A40
67741	26623	103.470793	104.223294	52.286496999999997	51.801794999999998	Клубная	0103000020E61000000100000005000000E38BF67821DE5940548CF337A1E64940E38BF67821DE594078B306EFAB244A4027D9EA724A0E5A4078B306EFAB244A4027D9EA724A0E5A40548CF337A1E64940E38BF67821DE5940548CF337A1E64940
68097	26623	103.470793	104.223294	52.286496999999997	51.801794999999998	2-я Железнодорожная	0103000020E61000000100000005000000E38BF67821DE5940548CF337A1E64940E38BF67821DE594078B306EFAB244A4027D9EA724A0E5A4078B306EFAB244A4027D9EA724A0E5A40548CF337A1E64940E38BF67821DE5940548CF337A1E64940
68101	26723	104.001886	104.079932	52.237628000000001	52.211511999999999	Ангарская	0103000020E610000001000000050000007F1475E61E005A40145B41D3121B4A407F1475E61E005A40944E24986A1E4A40D9791B9B1D055A40944E24986A1E4A40D9791B9B1D055A40145B41D3121B4A407F1475E61E005A40145B41D3121B4A40
68096	26723	104.001886	104.079932	52.237628000000001	52.211511999999999	8 Марта	0103000020E610000001000000050000007F1475E61E005A40145B41D3121B4A407F1475E61E005A40944E24986A1E4A40D9791B9B1D055A40944E24986A1E4A40D9791B9B1D055A40145B41D3121B4A407F1475E61E005A40145B41D3121B4A40
68816	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	м-н Северный	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
67779	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	Солнечная	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
68034	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	Советская	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
68036	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	Мира	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
67729	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	Ленина	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
68802	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	Коморова	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
9861	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	Комарова	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
67768	24042	99.606482999999997	99.692048	56.106805999999999	56.066198	50 лет Октября	0103000020E610000001000000050000001EA5129ED0E65840C287122D79084C401EA5129ED0E658401F82AAD1AB0D4C40C8D0B1834AEC58401F82AAD1AB0D4C40C8D0B1834AEC5840C287122D79084C401EA5129ED0E65840C287122D79084C40
69124	25089	99.352224000000007	99.39237	56.084876999999999	56.058638999999999	Совхозная	0103000020E61000000100000005000000723788D68AD6584094A2957B81074C40723788D68AD658405F97E13FDD0A4C409E7B0F971CD958405F97E13FDD0A4C409E7B0F971CD9584094A2957B81074C40723788D68AD6584094A2957B81074C40
68982	25364	99.947062000000003	99.966762000000003	56.175325999999998	56.155794	Школьная	0103000020E610000001000000050000003352EFA99CFC5840DE74CB0EF1134C403352EFA99CFC5840BA11161571164C40FF40B96DDFFD5840BA11161571164C40FF40B96DDFFD5840DE74CB0EF1134C403352EFA99CFC5840DE74CB0EF1134C40
68805	12507	100.21966399999999	100.259585	56.139757000000003	56.115493999999998	Первомайская	0103000020E61000000100000005000000F20698F90E0E59402E71E481C80E4C40F20698F90E0E59408C31B08EE3114C400F62670A9D1059408C31B08EE3114C400F62670A9D1059402E71E481C80E4C40F20698F90E0E59402E71E481C80E4C40
68979	25883	99.444552999999999	99.459734999999995	55.732326999999998	55.72307	Мира	0103000020E61000000100000005000000AD156D8E73DC5840FF5BC98E8DDC4B40AD156D8E73DC5840287D21E4BCDD4B40E674594C6CDD5840287D21E4BCDD4B40E674594C6CDD5840FF5BC98E8DDC4B40AD156D8E73DC5840FF5BC98E8DDC4B40
69242	25588	99.349447999999995	99.366506999999999	56.098641999999998	56.084449999999997	Рабочая	0103000020E61000000100000005000000C4E9245B5DD65840D712F241CF0A4C40C4E9245B5DD658408A01124DA00C4C4053B0C6D974D758408A01124DA00C4C4053B0C6D974D75840D712F241CF0A4C40C4E9245B5DD65840D712F241CF0A4C40
68635	25550	99.015248	99.046339000000003	56.175913000000001	56.159773999999999	Центральная	0103000020E610000001000000050000001555BFD2F9C058402460747973144C401555BFD2F9C058407BF8325184164C40E161DA37F7C258407BF8325184164C40E161DA37F7C258402460747973144C401555BFD2F9C058402460747973144C40
69017	25220	99.568098000000006	99.581626999999997	55.932803	55.924784000000002	Совхозная	0103000020E6100000010000000500000013BBB6B75BE458409AEE75525FF64B4013BBB6B75BE458402B4EB51666F74B401EDE736039E558402B4EB51666F74B401EDE736039E558409AEE75525FF64B4013BBB6B75BE458409AEE75525FF64B40
69224	1278	99.368105999999997	99.479613999999998	56.087755000000001	56.054864000000002	Советская	0103000020E6100000010000000500000087DD770C8FD7584027DD96C805074C4087DD770C8FD75840BE874B8E3B0B4C400A2DEBFEB1DE5840BE874B8E3B0B4C400A2DEBFEB1DE584027DD96C805074C4087DD770C8FD7584027DD96C805074C40
68758	1278	99.368105999999997	99.479613999999998	56.087755000000001	56.054864000000002	Октябрьская	0103000020E6100000010000000500000087DD770C8FD7584027DD96C805074C4087DD770C8FD75840BE874B8E3B0B4C400A2DEBFEB1DE5840BE874B8E3B0B4C400A2DEBFEB1DE584027DD96C805074C4087DD770C8FD7584027DD96C805074C40
69230	1278	99.368105999999997	99.479613999999998	56.087755000000001	56.054864000000002	Красные Зори	0103000020E6100000010000000500000087DD770C8FD7584027DD96C805074C4087DD770C8FD75840BE874B8E3B0B4C400A2DEBFEB1DE5840BE874B8E3B0B4C400A2DEBFEB1DE584027DD96C805074C4087DD770C8FD7584027DD96C805074C40
69433	1278	99.368105999999997	99.479613999999998	56.087755000000001	56.054864000000002	Звездная	0103000020E6100000010000000500000087DD770C8FD7584027DD96C805074C4087DD770C8FD75840BE874B8E3B0B4C400A2DEBFEB1DE5840BE874B8E3B0B4C400A2DEBFEB1DE584027DD96C805074C4087DD770C8FD7584027DD96C805074C40
68821	1278	99.368105999999997	99.479613999999998	56.087755000000001	56.054864000000002	Декабристов	0103000020E6100000010000000500000087DD770C8FD7584027DD96C805074C4087DD770C8FD75840BE874B8E3B0B4C400A2DEBFEB1DE5840BE874B8E3B0B4C400A2DEBFEB1DE584027DD96C805074C4087DD770C8FD7584027DD96C805074C40
68044	1278	99.368105999999997	99.479613999999998	56.087755000000001	56.054864000000002	Горького	0103000020E6100000010000000500000087DD770C8FD7584027DD96C805074C4087DD770C8FD75840BE874B8E3B0B4C400A2DEBFEB1DE5840BE874B8E3B0B4C400A2DEBFEB1DE584027DD96C805074C4087DD770C8FD7584027DD96C805074C40
68278	25619	99.241228000000007	99.306787	56.124682	56.095483999999999	Толстого	0103000020E610000001000000050000004AB8904770CF584048A5D8D1380C4C404AB8904770CF58402F336C94F50F4C40A1F5F065A2D358402F336C94F50F4C40A1F5F065A2D3584048A5D8D1380C4C404AB8904770CF584048A5D8D1380C4C40
69527	59278	99.186952000000005	99.212239999999994	56.187992000000001	56.174289000000002	Береговая	0103000020E61000000100000005000000FF7A8505F7CB5840BA86191A4F164C40FF7A8505F7CB58406FF4311F10184C40CBB9145795CD58406FF4311F10184C40CBB9145795CD5840BA86191A4F164C40FF7A8505F7CB5840BA86191A4F164C40
68981	25828	99.494399999999999	99.511262000000002	55.824299000000003	55.814866000000002	Школьная	0103000020E610000001000000050000001DC9E53FA4DF5840A94F72874DE84B401DC9E53FA4DF584011902FA182E94B40016C4084B8E0584011902FA182E94B40016C4084B8E05840A94F72874DE84B401DC9E53FA4DF5840A94F72874DE84B40
68026	24620	99.507857000000001	99.561279999999996	56.071478999999997	56.037156000000003	Шастина	0103000020E61000000100000005000000DC82A5BA80E05840D36C1E87C1044C40DC82A5BA80E05840E6AC4F3926094C4087F9F202ECE35840E6AC4F3926094C4087F9F202ECE35840D36C1E87C1044C40DC82A5BA80E05840D36C1E87C1044C40
67731	24620	99.507857000000001	99.561279999999996	56.071478999999997	56.037156000000003	Рабочая	0103000020E61000000100000005000000DC82A5BA80E05840D36C1E87C1044C40DC82A5BA80E05840E6AC4F3926094C4087F9F202ECE35840E6AC4F3926094C4087F9F202ECE35840D36C1E87C1044C40DC82A5BA80E05840D36C1E87C1044C40
68828	24620	99.507857000000001	99.561279999999996	56.071478999999997	56.037156000000003	Мелиораторов	0103000020E61000000100000005000000DC82A5BA80E05840D36C1E87C1044C40DC82A5BA80E05840E6AC4F3926094C4087F9F202ECE35840E6AC4F3926094C4087F9F202ECE35840D36C1E87C1044C40DC82A5BA80E05840D36C1E87C1044C40
67730	24620	99.507857000000001	99.561279999999996	56.071478999999997	56.037156000000003	Ленина	0103000020E61000000100000005000000DC82A5BA80E05840D36C1E87C1044C40DC82A5BA80E05840E6AC4F3926094C4087F9F202ECE35840E6AC4F3926094C4087F9F202ECE35840D36C1E87C1044C40DC82A5BA80E05840D36C1E87C1044C40
69229	25277	99.725527999999997	99.747760999999997	55.845506	55.836781999999999	Совхозная	0103000020E610000001000000050000004415FE0C6FEE5840D4F02DAC1BEB4B404415FE0C6FEE58403049658A39EC4B405A0EF450DBEF58403049658A39EC4B405A0EF450DBEF5840D4F02DAC1BEB4B404415FE0C6FEE5840D4F02DAC1BEB4B40
68829	25469	99.108457000000001	99.136556999999996	56.179364999999997	56.167898999999998	Молодежная	0103000020E610000001000000050000006D01A1F5F0C65840FB03E5B67D154C406D01A1F5F0C658400586AC6EF5164C408D429259BDC858400586AC6EF5164C408D429259BDC85840FB03E5B67D154C406D01A1F5F0C65840FB03E5B67D154C40
69349	25317	99.755864000000003	99.787682000000004	56.133532000000002	56.120457000000002	Ангарская	0103000020E61000000100000005000000520E661360F0584082C98D226B0F4C40520E661360F05840187C9A9317114C407769C36169F25840187C9A9317114C407769C36169F2584082C98D226B0F4C40520E661360F0584082C98D226B0F4C40
69308	25667	99.169748999999996	99.188524000000001	56.159137999999999	56.150243000000003	Первомайская	0103000020E61000000100000005000000D6E1E82ADDCA5840FAB9A1293B134C40D6E1E82ADDCA584082C64CA25E144C40B6A0F7C610CC584082C64CA25E144C40B6A0F7C610CC5840FAB9A1293B134C40D6E1E82ADDCA5840FAB9A1293B134C40
68070	25198	99.565089	99.604202000000001	55.948684	55.922535000000003	Мира	0103000020E6100000010000000500000014950D6B2AE458402B357BA015F64B4014950D6B2AE45840861E317A6EF94B40618BDD3EABE65840861E317A6EF94B40618BDD3EABE658402B357BA015F64B4014950D6B2AE458402B357BA015F64B40
69233	25773	99.014753999999996	99.035307000000003	56.392338000000002	56.374442000000002	Советская	0103000020E610000001000000050000000DDFC2BAF1C05840DA1F28B7ED2F4C400DDFC2BAF1C05840317DAF2138324C4079944A7842C25840317DAF2138324C4079944A7842C25840DA1F28B7ED2F4C400DDFC2BAF1C05840DA1F28B7ED2F4C40
69568	59307	99.440250000000006	99.498532999999995	56.059438	56.039026999999997	Советская	0103000020E610000001000000050000001904560E2DDC58409B5434D6FE044C401904560E2DDC5840E01115AA9B074C4083BEF4F6E7DF5840E01115AA9B074C4083BEF4F6E7DF58409B5434D6FE044C401904560E2DDC58409B5434D6FE044C40
69228	24792	99.556375000000003	99.570065999999997	55.999927999999997	55.989727999999999	Зеленая	0103000020E61000000100000005000000F853E3A59BE35840BEF73768AFFE4B40F853E3A59BE35840662D05A4FDFF4B40F0A31AF67BE45840662D05A4FDFF4B40F0A31AF67BE45840BEF73768AFFE4B40F853E3A59BE35840BEF73768AFFE4B40
69120	21886	102.379071	102.394549	52.747742000000002	52.732987999999999	Дроздова	0103000020E610000001000000050000002BF702B342985940232E008DD25D4A402BF702B3429859403EEC8502B65F4A40D9EA724A409959403EEC8502B65F4A40D9EA724A40995940232E008DD25D4A402BF702B342985940232E008DD25D4A40
68021	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	проезд Краснопеева	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67727	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	переулок Пролетарский	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68801	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	переулок Копейский	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68274	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Ярославского	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68287	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Шевченко	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67960	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Ференца Патаки	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67669	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Советская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
69307	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Российская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68226	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Пролетарский переулок	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68535	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Первомайская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68008	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Орджоникидзе	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67696	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Маяковского	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
69420	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Маковского	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68277	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Ленина	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68626	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Красношахтерская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68004	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Забойщика	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
69305	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Ершовская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68270	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Дударского	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68540	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Детская	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
67787	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Декабрьских Событий	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68974	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Врубовая	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68275	3270	103.008978	103.233692	53.189619999999998	53.035524000000002	Бердниковой	0103000020E610000001000000050000008B18761893C059408F1CE90C8C844A408B18761893C059407155D97745984A408F554ACFF4CE59407155D97745984A408F554ACFF4CE59408F1CE90C8C844A408B18761893C059408F1CE90C8C844A40
68970	22274	103.280135	103.308773	53.152461000000002	53.139926000000003	Школьная	0103000020E61000000100000005000000C2DD59BBEDD1594018EE5C18E9914A40C2DD59BBEDD159402E7590D783934A40D238D4EFC2D359402E7590D783934A40D238D4EFC2D3594018EE5C18E9914A40C2DD59BBEDD1594018EE5C18E9914A40
69523	59276	103.225697	103.241085	52.969828	52.962131999999997	Колхозная	0103000020E610000001000000050000008A73D4D171CE5940B0373124277B4A408A73D4D171CE59405F5FEB52237C4A4098A3C7EF6DCF59405F5FEB52237C4A4098A3C7EF6DCF5940B0373124277B4A408A73D4D171CE5940B0373124277B4A40
69299	21971	103.23311699999999	103.260848	52.909942000000001	52.896526000000001	Центральная	0103000020E6100000010000000500000010C99063EBCE5940C1012D5DC1724A4010C99063EBCE5940E0A0BDFA78744A40874ECFBBB1D05940E0A0BDFA78744A40874ECFBBB1D05940C1012D5DC1724A4010C99063EBCE5940C1012D5DC1724A40
69311	21952	102.78037500000001	102.799886	52.654733	52.636969000000001	Октябрьская	0103000020E610000001000000050000006DE7FBA9F1B159406DC83F3388514A406DE7FBA9F1B15940554E7B4ACE534A40CFA10C5531B35940554E7B4ACE534A40CFA10C5531B359406DC83F3388514A406DE7FBA9F1B159406DC83F3388514A40
68838	2925	102.403379	102.436149	52.790371	52.775168999999998	Лесозаготовительная	0103000020E610000001000000050000002A3927F6D0995940BFEFDFBC38634A402A3927F6D0995940795A7EE02A654A40B8CB7EDDE99B5940795A7EE02A654A40B8CB7EDDE99B5940BFEFDFBC38634A402A3927F6D0995940BFEFDFBC38634A40
68607	30236	102.869057	102.88954699999999	53.043239	53.028033999999998	Солнечная	0103000020E61000000100000005000000085740A19EB7594089963C9E96834A40085740A19EB75940B47405DB88854A4050508A56EEB85940B47405DB88854A4050508A56EEB8594089963C9E96834A40085740A19EB7594089963C9E96834A40
69303	22190	103.178517	103.196457	53.260742999999998	53.247521999999996	Сосновая	0103000020E61000000100000005000000EC3191D26CCB59402F8507CDAE9F4A40EC3191D26CCB594099D4D00660A14A407F8461C092CC594099D4D00660A14A407F8461C092CC59402F8507CDAE9F4A40EC3191D26CCB59402F8507CDAE9F4A40
69253	20076	103.11756699999999	103.12968499999999	52.978445000000001	52.961779999999997	Советская	0103000020E61000000100000005000000AF05BD3786C7594033F9669B1B7B4A40AF05BD3786C75940A5F78DAF3D7D4A40087250C24CC85940A5F78DAF3D7D4A40087250C24CC8594033F9669B1B7B4A40AF05BD3786C7594033F9669B1B7B4A40
68853	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	Хасановских боёв	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68716	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	Тимирязева	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
69412	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	Серегина	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68708	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	О.Кошевого	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68812	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	Мира	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68550	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	Ленина	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68673	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	Киевская	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68778	1874	103.287474	103.406025	53.122621000000002	52.979940999999997	Дзержинского	0103000020E61000000100000005000000D21C59F965D259403881E9B46E7D4A40D21C59F965D25940C366800BB28F4A40F0164850FCD95940C366800BB28F4A40F0164850FCD959403881E9B46E7D4A40D21C59F965D259403881E9B46E7D4A40
68797	21700	102.23880800000001	102.263008	53.089410999999998	53.062784000000001	Совхозная	0103000020E610000001000000050000007C8159A1488F5940255B5D4E09884A407C8159A1488F59408A73D4D1718B4A4087A5811FD59059408A73D4D1718B4A4087A5811FD5905940255B5D4E09884A407C8159A1488F5940255B5D4E09884A40
68819	22114	103.00972400000001	103.02940599999999	53.205415000000002	53.196249999999999	Российсская	0103000020E61000000100000005000000207F69519FC0594085EB51B81E994A40207F69519FC05940CE8DE9094B9A4A409813B4C9E1C15940CE8DE9094B9A4A409813B4C9E1C1594085EB51B81E994A40207F69519FC0594085EB51B81E994A40
69436	21620	102.755465	102.778192	52.950268000000001	52.943663999999998	Центральная	0103000020E610000001000000050000007311DF8959B05940CE3461FBC9784A407311DF8959B05940B937BF61A2794A409180D1E5CDB15940B937BF61A2794A409180D1E5CDB15940CE3461FBC9784A407311DF8959B05940CE3461FBC9784A40
69432	22215	103.27738600000001	103.29599	53.200701000000002	53.189959999999999	Нагорная	0103000020E61000000100000005000000929735B1C0D159402AC6F99B50984A40929735B1C0D1594023A30392B0994A405B7C0A80F1D2594023A30392B0994A405B7C0A80F1D259402AC6F99B50984A40929735B1C0D159402AC6F99B50984A40
69274	20560	103.194885	103.222229	53.061399000000002	53.052717999999999	Морозова	0103000020E61000000100000005000000C85EEFFE78CC59408CF4A276BF864A40C85EEFFE78CC5940E98024ECDB874A4042CEFBFF38CE5940E98024ECDB874A4042CEFBFF38CE59408CF4A276BF864A40C85EEFFE78CC59408CF4A276BF864A40
69222	20000	103.150454	103.167621	53.041187000000001	53.032696999999999	Северная	0103000020E610000001000000050000005A63D009A1C95940B2D6506A2F844A405A63D009A1C959409B02999D45854A40DC476E4DBACA59409B02999D45854A40DC476E4DBACA5940B2D6506A2F844A405A63D009A1C95940B2D6506A2F844A40
68756	2883	102.828875	102.86514	52.996302	52.979621999999999	Мира	0103000020E61000000100000005000000355EBA490CB559409738F240647D4A40355EBA490CB559403E78EDD2867F4A40889D29745EB759403E78EDD2867F4A40889D29745EB759409738F240647D4A40355EBA490CB559409738F240647D4A40
68525	21465	102.036489	102.070886	52.742066999999999	52.733310000000003	Школьная	0103000020E610000001000000050000007B6AF5D55582594036EA211ADD5D4A407B6AF5D5558259406D382C0DFC5E4A40A2EF6E65898459406D382C0DFC5E4A40A2EF6E658984594036EA211ADD5D4A407B6AF5D55582594036EA211ADD5D4A40
68814	21365	101.810886	101.84893	52.985959000000001	52.972642999999998	Школьная	0103000020E6100000010000000500000031B2648EE573594077D7D9907F7C4A4031B2648EE573594033198EE7337E4A40F8A57EDE5476594033198EE7337E4A40F8A57EDE5476594077D7D9907F7C4A4031B2648EE573594077D7D9907F7C4A40
68743	2766	102.950264	102.967826	53.184683	53.175611000000004	Советская	0103000020E610000001000000050000003CA41820D1BC5940B0E8D66B7A964A403CA41820D1BC594047904AB1A3974A40FC8D76DCF0BD594047904AB1A3974A40FC8D76DCF0BD5940B0E8D66B7A964A403CA41820D1BC5940B0E8D66B7A964A40
68643	814	102.466989	102.51209299999999	52.991565000000001	52.967176000000002	Советская	0103000020E61000000100000005000000DFA5D425E39D5940F1BC546CCC7B4A40DFA5D425E39D5940DB6D179AEB7E4A40ACE0B721C6A05940DB6D179AEB7E4A40ACE0B721C6A05940F1BC546CCC7B4A40DFA5D425E39D5940F1BC546CCC7B4A40
68943	20885	102.800273	102.815203	53.102145999999998	53.084273000000003	Школьная	0103000020E61000000100000005000000CCB73EAC37B35940C9772975C98A4A40CCB73EAC37B3594067B5C01E138D4A40782634492CB4594067B5C01E138D4A40782634492CB45940C9772975C98A4A40CCB73EAC37B35940C9772975C98A4A40
69537	59190	103.136961	103.297912	52.903391999999997	52.842553000000002	Щорса	0103000020E61000000100000005000000F5F411F8C3C85940C712D6C6D86B4A40F5F411F8C3C85940E8BB5B59A2734A4080457EFD10D35940E8BB5B59A2734A4080457EFD10D35940C712D6C6D86B4A40F5F411F8C3C85940C712D6C6D86B4A40
68920	59190	103.136961	103.297912	52.903391999999997	52.842553000000002	Ленина	0103000020E61000000100000005000000F5F411F8C3C85940C712D6C6D86B4A40F5F411F8C3C85940E8BB5B59A2734A4080457EFD10D35940E8BB5B59A2734A4080457EFD10D35940C712D6C6D86B4A40F5F411F8C3C85940C712D6C6D86B4A40
68930	59193	101.072318	103.493898	53.314895999999997	52.214100000000002	переулок Бельский	0103000020E61000000100000005000000603AADDBA04459406C09F9A0671B4A40603AADDBA044594013D21A834EA84A40D4635B069CDF594013D21A834EA84A40D4635B069CDF59406C09F9A0671B4A40603AADDBA04459406C09F9A0671B4A40
68000	20926	103.269463	103.31927399999999	52.984766999999998	52.945867	Советская	0103000020E61000000100000005000000DA1EBDE13ED15940CDAE7B2B12794A40DA1EBDE13ED159400B9755D80C7E4A40A31D37FC6ED459400B9755D80C7E4A40A31D37FC6ED45940CDAE7B2B12794A40DA1EBDE13ED15940CDAE7B2B12794A40
69298	20926	103.269463	103.31927399999999	52.984766999999998	52.945867	Заречная	0103000020E61000000100000005000000DA1EBDE13ED15940CDAE7B2B12794A40DA1EBDE13ED159400B9755D80C7E4A40A31D37FC6ED459400B9755D80C7E4A40A31D37FC6ED45940CDAE7B2B12794A40DA1EBDE13ED15940CDAE7B2B12794A40
67726	20926	103.269463	103.31927399999999	52.984766999999998	52.945867	Горького	0103000020E61000000100000005000000DA1EBDE13ED15940CDAE7B2B12794A40DA1EBDE13ED159400B9755D80C7E4A40A31D37FC6ED459400B9755D80C7E4A40A31D37FC6ED45940CDAE7B2B12794A40DA1EBDE13ED15940CDAE7B2B12794A40
67994	20926	103.269463	103.31927399999999	52.984766999999998	52.945867	Iкв	0103000020E61000000100000005000000DA1EBDE13ED15940CDAE7B2B12794A40DA1EBDE13ED159400B9755D80C7E4A40A31D37FC6ED459400B9755D80C7E4A40A31D37FC6ED45940CDAE7B2B12794A40DA1EBDE13ED15940CDAE7B2B12794A40
67764	20926	103.269463	103.31927399999999	52.984766999999998	52.945867	IIкв	0103000020E61000000100000005000000DA1EBDE13ED15940CDAE7B2B12794A40DA1EBDE13ED159400B9755D80C7E4A40A31D37FC6ED459400B9755D80C7E4A40A31D37FC6ED45940CDAE7B2B12794A40DA1EBDE13ED15940CDAE7B2B12794A40
68800	20763	102.87486	102.910631	53.073222000000001	53.046385000000001	Школьная	0103000020E610000001000000050000000725CCB4FDB75940320395F1EF854A400725CCB4FDB7594082ACA7565F894A4052EE3EC747BA594082ACA7565F894A4052EE3EC747BA5940320395F1EF854A400725CCB4FDB75940320395F1EF854A40
69295	20292	102.924581	102.94379600000001	53.038750999999998	53.028748999999998	Нижняя	0103000020E610000001000000050000003160C9552CBB59407765170CAE834A403160C9552CBB5940F9D7F2CAF5844A401F86562767BC5940F9D7F2CAF5844A401F86562767BC59407765170CAE834A403160C9552CBB59407765170CAE834A40
69135	20185	103.032819	103.060559	52.952095999999997	52.941780999999999	Школьная	0103000020E61000000100000005000000FFEBDCB419C25940417FA1478C784A40FFEBDCB419C2594082531F48DE794A409F1EDB32E0C3594082531F48DE794A409F1EDB32E0C35940417FA1478C784A40FFEBDCB419C25940417FA1478C784A40
69225	22322	102.92608199999999	102.93526199999999	53.227722	53.218491999999998	Полевая	0103000020E6100000010000000500000083DA6FED44BB59400438BD8BF79B4A4083DA6FED44BB5940344A97FE259D4A4042CC2555DBBB5940344A97FE259D4A4042CC2555DBBB59400438BD8BF79B4A4083DA6FED44BB59400438BD8BF79B4A40
68847	30277	102.85243800000001	102.866658	53.161569999999998	53.150803000000003	Тополиная	0103000020E6100000010000000500000088F71C588EB65940C19140834D934A4088F71C588EB65940E2016553AE944A4046B41D5377B75940E2016553AE944A4046B41D5377B75940C19140834D934A4088F71C588EB65940C19140834D934A40
69142	20661	103.362375	103.37868	53.289549999999998	53.272768999999997	Совхозная	0103000020E61000000100000005000000D578E92631D759406A2E3718EAA24A40D578E92631D75940454772F90FA54A408EE9094B3CD85940454772F90FA54A408EE9094B3CD859406A2E3718EAA24A40D578E92631D759406A2E3718EAA24A40
69318	2803	101.95007099999999	101.98653400000001	52.979069000000003	52.968077000000001	Берёзовая	0103000020E61000000100000005000000317898F6CD7C5940418177F2E97B4A40317898F6CD7C594083C30B22527D4A401899805F237F594083C30B22527D4A401899805F237F5940418177F2E97B4A40317898F6CD7C5940418177F2E97B4A40
68861	2658	103.252529	103.272158	53.059407999999998	53.047336999999999	Иркутская	0103000020E61000000100000005000000A912656F29D05940047289230F864A40A912656F29D05940758F6CAE9A874A40115663096BD15940758F6CAE9A874A40115663096BD15940047289230F864A40A912656F29D05940047289230F864A40
67995	20397	102.33857399999999	102.41036800000001	53.060586999999998	53.021566999999997	Кирова	0103000020E61000000100000005000000A8514832AB9559401FD61BB5C2824A40A8514832AB95594008C89750C1874A40CCD42478439A594008C89750C1874A40CCD42478439A59401FD61BB5C2824A40A8514832AB9559401FD61BB5C2824A40
68605	20397	102.33857399999999	102.41036800000001	53.060586999999998	53.021566999999997	Калинина	0103000020E61000000100000005000000A8514832AB9559401FD61BB5C2824A40A8514832AB95594008C89750C1874A40CCD42478439A594008C89750C1874A40CCD42478439A59401FD61BB5C2824A40A8514832AB9559401FD61BB5C2824A40
69724	59350	102.77588299999999	102.789331	53.014389000000001	52.995255999999998	улица Центральная	0103000020E610000001000000050000006EA12B11A8B15940EA92718C647F4A406EA12B11A8B159400936AE7FD7814A4004AE2B6684B259400936AE7FD7814A4004AE2B6684B25940EA92718C647F4A406EA12B11A8B15940EA92718C647F4A40
69449	20278	103.011062	103.066686	53.037770999999999	53.024481000000002	Булайская	0103000020E610000001000000050000009D0E643DB5C05940CB2F833122834A409D0E643DB5C059405DDE1CAED5844A4078465B9544C459405DDE1CAED5844A4078465B9544C45940CB2F833122834A409D0E643DB5C05940CB2F833122834A40
68165	20122	103.066228	103.090671	52.882866	52.859139999999996	Иванова	0103000020E6100000010000000500000016855D143DC45940BC57AD4CF86D4A4016855D143DC459400B60CAC001714A4085ECBC8DCDC559400B60CAC001714A4085ECBC8DCDC55940BC57AD4CF86D4A4016855D143DC45940BC57AD4CF86D4A40
69460	549	103.064719	103.080376	53.223635000000002	53.212215	Центральная	0103000020E61000000100000005000000821B295B24C459403E5C72DC299B4A40821B295B24C45940D89E5912A09C4A4088D860E124C55940D89E5912A09C4A4088D860E124C559403E5C72DC299B4A40821B295B24C459403E5C72DC299B4A40
69296	20613	103.347751	103.357722	53.011468999999998	53.004294999999999	Ангарская	0103000020E61000000100000005000000AF09698D41D65940A64412BD8C804A40AF09698D41D659407BF5F1D077814A40D2C3D0EAE4D659407BF5F1D077814A40D2C3D0EAE4D65940A64412BD8C804A40AF09698D41D65940A64412BD8C804A40
69284	20749	103.23671	103.26110799999999	53.245193999999998	53.236576999999997	Школьная	0103000020E61000000100000005000000B728B34126CF59402EFEB627489E4A40B728B34126CF594074965984629F4A40552E54FEB5D0594074965984629F4A40552E54FEB5D059402EFEB627489E4A40B728B34126CF59402EFEB627489E4A40
69320	21246	102.622981	102.671122	52.977679999999999	52.967739999999999	Луговая	0103000020E61000000100000005000000E141B3EBDEA75940F98381E7DE7B4A40E141B3EBDEA7594005FA449E247D4A401268B0A9F3AA594005FA449E247D4A401268B0A9F3AA5940F98381E7DE7B4A40E141B3EBDEA75940F98381E7DE7B4A40
68530	19967	103.100948	103.14420200000001	53.078046999999998	53.060473999999999	Площадь Труда	0103000020E610000001000000050000002FA699EE75C659401021AE9CBD874A402FA699EE75C659408446B071FD894A402481069B3AC959408446B071FD894A402481069B3AC959401021AE9CBD874A402FA699EE75C659401021AE9CBD874A40
68837	29745	103.279515	103.31229399999999	54.193454000000003	54.177748000000001	Мира	0103000020E6100000010000000500000074EFE192E3D15940F7764B72C0164B4074EFE192E3D15940E4A3C519C3184B402B2FF99FFCD35940E4A3C519C3184B402B2FF99FFCD35940F7764B72C0164B4074EFE192E3D15940F7764B72C0164B40
69317	29950	103.702082	103.718548	54.199485000000003	54.179144000000001	Центральная	0103000020E610000001000000050000000F4757E9EEEC594027A3CA30EE164B400F4757E9EEEC5940738577B988194B40CC26C0B0FCED5940738577B988194B40CC26C0B0FCED594027A3CA30EE164B400F4757E9EEEC594027A3CA30EE164B40
68965	3126	103.386109	103.399638	53.840882000000001	53.831440000000001	Центральная	0103000020E610000001000000050000003EEC8502B6D859400A4B3CA06CEA4A403EEC8502B6D85940C5E57805A2EB4A40490F43AB93D95940C5E57805A2EB4A40490F43AB93D959400A4B3CA06CEA4A403EEC8502B6D859400A4B3CA06CEA4A40
67899	19271	103.01026299999999	103.058898	54.186473999999997	54.157017000000003	Пионерская	0103000020E61000000100000005000000F7562426A8C0594041F50F2219144B40F7562426A8C05940F3C64961DE174B4030F31DFCC4C35940F3C64961DE174B4030F31DFCC4C3594041F50F2219144B40F7562426A8C0594041F50F2219144B40
68988	27583	103.654768	103.67304	53.953772999999998	53.945760999999997	Ленина	0103000020E61000000100000005000000E99D0AB8E7E95940876A4AB20EF94A40E99D0AB8E7E959406667D13B15FA4A4097395D1613EB59406667D13B15FA4A4097395D1613EB5940876A4AB20EF94A40E99D0AB8E7E95940876A4AB20EF94A40
69360	803	103.533478	103.541994	53.726894999999999	53.707765999999999	Школьная	0103000020E61000000100000005000000ACC8E88024E25940419C871398DA4A40ACC8E88024E259401E5036E50ADD4A4035289A07B0E259401E5036E50ADD4A4035289A07B0E25940419C871398DA4A40ACC8E88024E25940419C871398DA4A40
68600	29648	103.51160400000001	103.531205	54.342156000000003	54.328223000000001	Лесная	0103000020E610000001000000050000002E20B41EBEE05940C3651536032A4B402E20B41EBEE05940AA108FC4CB2B4B40309E4143FFE15940AA108FC4CB2B4B40309E4143FFE15940C3651536032A4B402E20B41EBEE05940C3651536032A4B40
68940	19909	103.116587	103.139162	54.289546000000001	54.274301999999999	Совхозная	0103000020E61000000100000005000000E108522976C759401B9DF3531C234B40E108522976C759400458E4D70F254B4024B6BB07E8C859400458E4D70F254B4024B6BB07E8C859401B9DF3531C234B40E108522976C759401B9DF3531C234B40
69397	30126	103.36179199999999	103.373164	55.209504000000003	55.204093999999998	Советская	0103000020E6100000010000000500000015FDA19927D75940A8A78FC01F9A4B4015FDA19927D75940CB30EE06D19A4B40DA0242EBE1D75940CB30EE06D19A4B40DA0242EBE1D75940A8A78FC01F9A4B4015FDA19927D75940A8A78FC01F9A4B40
68614	29884	103.595479	103.62311099999999	54.040109999999999	54.016702000000002	Юбилейная	0103000020E610000001000000050000001B9DF3531CE659408FE3874A23024B401B9DF3531CE659400C1F115322054B40C8B1F50CE1E759400C1F115322054B40C8B1F50CE1E759408FE3874A23024B401B9DF3531CE659408FE3874A23024B40
68757	2577	103.321673	103.345766	53.889242000000003	53.874301000000003	Радищева	0103000020E6100000010000000500000066C0594A96D4594018EE5C18E9EF4A4066C0594A96D45940651D8EAED2F14A406684B70721D65940651D8EAED2F14A406684B70721D6594018EE5C18E9EF4A4066C0594A96D4594018EE5C18E9EF4A40
69133	19832	103.03169699999999	103.044875	54.204557000000001	54.196530000000003	Набережная	0103000020E610000001000000050000006798DA5207C25940695721E527194B406798DA5207C259407D957CEC2E1A4B401D5A643BDFC259407D957CEC2E1A4B401D5A643BDFC25940695721E527194B406798DA5207C25940695721E527194B40
68841	19559	103.37857200000001	103.399027	53.743332000000002	53.726165000000002	Центральная	0103000020E610000001000000050000009BCB0D863AD85940FB3F87F9F2DC4A409BCB0D863AD85940FF08C38025DF4A4025CE8AA889D95940FF08C38025DF4A4025CE8AA889D95940FB3F87F9F2DC4A409BCB0D863AD85940FB3F87F9F2DC4A40
68941	19681	103.324799	103.334519	53.959319999999998	53.942317000000003	Советская	0103000020E6100000010000000500000081B1BE81C9D4594080BBECD79DF84A4081B1BE81C9D4594009336DFFCAFA4A40003961C268D5594009336DFFCAFA4A40003961C268D5594080BBECD79DF84A4081B1BE81C9D4594080BBECD79DF84A40
68957	29983	103.25791	103.266705	54.541704000000003	54.533648999999997	Комарова	0103000020E61000000100000005000000EDD3F19881D059408445459C4E444B40EDD3F19881D05940630E828E56454B40802BD9B111D15940630E828E56454B40802BD9B111D159408445459C4E444B40EDD3F19881D059408445459C4E444B40
69237	29807	103.35404800000001	103.375608	54.129174999999996	54.119239	Мира	0103000020E61000000100000005000000B64DF1B8A8D6594031B43A39430F4B40B64DF1B8A8D65940FB3A70CE88104B406C0723F609D85940FB3A70CE88104B406C0723F609D8594031B43A39430F4B40B64DF1B8A8D6594031B43A39430F4B40
68804	19745	103.127861	103.15338199999999	54.028914999999998	54.015945000000002	Некрасова	0103000020E61000000100000005000000C45BE7DF2EC8594072C45A7C0A024B40C45BE7DF2EC8594092AE997CB3034B40E272BC02D1C9594092AE997CB3034B40E272BC02D1C9594072C45A7C0A024B40C45BE7DF2EC8594072C45A7C0A024B40
69450	29863	103.312214	103.34964600000001	54.074294999999999	54.060054999999998	Рабочая	0103000020E610000001000000050000009DD66D50FBD359400B7BDAE1AF074B409DD66D50FBD35940CFA0A17F82094B4058CB9D9960D65940CFA0A17F82094B4058CB9D9960D659400B7BDAE1AF074B409DD66D50FBD359400B7BDAE1AF074B40
69312	30118	103.078436	103.091156	54.836181000000003	54.824134000000001	Школьная	0103000020E610000001000000050000000FB56D1805C55940C6C210397D694B400FB56D1805C55940AF44A0FA076B4B4063B5F97FD5C55940AF44A0FA076B4B4063B5F97FD5C55940C6C210397D694B400FB56D1805C55940C6C210397D694B40
68603	30042	103.23353	103.258072	54.667003999999999	54.639533999999998	Набережная	0103000020E61000000100000005000000A228D027F2CE59400C570740DC514B40A228D027F2CE59408D26176360554B40DA006C4084D059408D26176360554B40DA006C4084D059400C570740DC514B40A228D027F2CE59400C570740DC514B40
68421	59144	105.21430599999999	105.254829	56.859025000000003	56.842457000000003	улица Лесная	0103000020E610000001000000050000008A558330B74D5A40A5A487A1D56B4C408A558330B74D5A4024B9FC87F46D4C40A2444B1E4F505A4024B9FC87F46D4C40A2444B1E4F505A40A5A487A1D56B4C408A558330B74D5A40A5A487A1D56B4C40
68905	59187	106.174201	106.184657	56.981620999999997	56.970908000000001	Мира	0103000020E610000001000000050000008D7BF31B268B5A405FB69DB6467C4C408D7BF31B268B5A408D08C6C1A57D4C408FFE976BD18B5A408D08C6C1A57D4C408FFE976BD18B5A405FB69DB6467C4C408D7BF31B268B5A405FB69DB6467C4C40
68834	59177	106.800704	106.808322	56.563496999999998	56.542262000000001	Тбилисская	0103000020E61000000100000005000000B071FDBB3EB35A4089EE59D768454C40B071FDBB3EB35A40723271AB20484C40CAA8328CBBB35A40723271AB20484C40CAA8328CBBB35A4089EE59D768454C40B071FDBB3EB35A4089EE59D768454C40
69624	59335	107.061305	107.07293	56.374442000000002	56.367946000000003	Молодежная	0103000020E610000001000000050000003485CE6BECC35A40D658C2DA182F4C403485CE6BECC35A40DA1F28B7ED2F4C406D3997E2AAC45A40DA1F28B7ED2F4C406D3997E2AAC45A40D658C2DA182F4C403485CE6BECC35A40D658C2DA182F4C40
69593	59176	106.997435	107.06992	57.339796	57.315322000000002	Центральная	0103000020E61000000100000005000000B0389CF9D5BF5A40CBDAA6785CA84C40B0389CF9D5BF5A40E3A7716F7EAB4C408655BC9179C45A40E3A7716F7EAB4C408655BC9179C45A40CBDAA6785CA84C40B0389CF9D5BF5A40CBDAA6785CA84C40
68810	59176	106.997435	107.06992	57.339796	57.315322000000002	Фонтанная	0103000020E61000000100000005000000B0389CF9D5BF5A40CBDAA6785CA84C40B0389CF9D5BF5A40E3A7716F7EAB4C408655BC9179C45A40E3A7716F7EAB4C408655BC9179C45A40CBDAA6785CA84C40B0389CF9D5BF5A40CBDAA6785CA84C40
69535	59176	106.997435	107.06992	57.339796	57.315322000000002	40 лет Победы	0103000020E61000000100000005000000B0389CF9D5BF5A40CBDAA6785CA84C40B0389CF9D5BF5A40E3A7716F7EAB4C408655BC9179C45A40E3A7716F7EAB4C408655BC9179C45A40CBDAA6785CA84C40B0389CF9D5BF5A40CBDAA6785CA84C40
67979	59126	102.72754500000001	102.806381	57.918353000000003	57.897266000000002	Ленина	0103000020E610000001000000050000009357E71890AE594008E8BE9CD9F24C409357E71890AE59407D9752978CF54C4069C70DBF9BB359407D9752978CF54C4069C70DBF9BB3594008E8BE9CD9F24C409357E71890AE594008E8BE9CD9F24C40
68619	15780	102.11676199999999	102.166763	57.37003	57.357235000000003	Ермака	0103000020E6100000010000000500000098DA52077987594048FE60E0B9AD4C4098DA520779875940FA449E245DAF4C40B4CBB73EAC8A5940FA449E245DAF4C40B4CBB73EAC8A594048FE60E0B9AD4C4098DA52077987594048FE60E0B9AD4C40
68621	15780	102.11676199999999	102.166763	57.37003	57.357235000000003	Дзержинского	0103000020E6100000010000000500000098DA52077987594048FE60E0B9AD4C4098DA520779875940FA449E245DAF4C40B4CBB73EAC8A5940FA449E245DAF4C40B4CBB73EAC8A594048FE60E0B9AD4C4098DA52077987594048FE60E0B9AD4C40
67759	14351	102.560647	102.771293	58.135641	57.926875000000003	проспект Дружбы Народов	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67725	14351	102.560647	102.771293	58.135641	57.926875000000003	Энгельса	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
68794	14351	102.560647	102.771293	58.135641	57.926875000000003	Солнечная	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
68120	14351	102.560647	102.771293	58.135641	57.926875000000003	Наймушина	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67724	14351	102.560647	102.771293	58.135641	57.926875000000003	Карла Маркса	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67723	14351	102.560647	102.771293	58.135641	57.926875000000003	Героев Труда	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67977	14351	102.560647	102.771293	58.135641	57.926875000000003	Георгия Димитрова	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67718	14351	102.560647	102.771293	58.135641	57.926875000000003	Булгакова	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67983	14351	102.560647	102.771293	58.135641	57.926875000000003	Братская	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67796	59103	102.560647	102.771293	58.135641	57.926875000000003	Карла Маркса	0103000020E610000001000000050000006F66F4A3E1A35940713D0AD7A3F64C406F66F4A3E1A35940957F2DAF5C114D408FA850DD5CB15940957F2DAF5C114D408FA850DD5CB15940713D0AD7A3F64C406F66F4A3E1A35940713D0AD7A3F64C40
67040	15515	103.268699	103.289935	57.676909000000002	57.637776000000002	Спортивная	0103000020E61000000100000005000000F25D4A5D32D159403C16DBA4A2D14C40F25D4A5D32D159401DAF40F4A4D64C40CFBD874B8ED259401DAF40F4A4D64C40CFBD874B8ED259403C16DBA4A2D14C40F25D4A5D32D159403C16DBA4A2D14C40
67781	1654	101.298289	101.319705	56.988501999999997	56.971128	Солнечная	0103000020E610000001000000050000006BF0BE2A175359406D1D1CEC4D7C4C406BF0BE2A17535940EA03C93B877E4C4088D7F50B76545940EA03C93B877E4C4088D7F50B765459406D1D1CEC4D7C4C406BF0BE2A175359406D1D1CEC4D7C4C40
69466	15942	101.64160800000001	101.657984	57.088543000000001	57.076411999999998	Мира	0103000020E610000001000000050000008736001B10695940CF8250DEC7894C408736001B1069594016A58460558B4C40A452EC681C6A594016A58460558B4C40A452EC681C6A5940CF8250DEC7894C408736001B10695940CF8250DEC7894C40
68119	15409	102.700101	102.738765	58.063378	58.030613000000002	Сказочная	0103000020E6100000010000000500000067B96C74CEAC59408EEA7420EB034D4067B96C74CEAC594098A432C51C084D407C9BFEEC47AF594098A432C51C084D407C9BFEEC47AF59408EEA7420EB034D4067B96C74CEAC59408EEA7420EB034D40
68013	15409	102.700101	102.738765	58.063378	58.030613000000002	Кеульская	0103000020E6100000010000000500000067B96C74CEAC59408EEA7420EB034D4067B96C74CEAC594098A432C51C084D407C9BFEEC47AF594098A432C51C084D407C9BFEEC47AF59408EEA7420EB034D4067B96C74CEAC59408EEA7420EB034D40
67777	1536	102.80234799999999	102.833915	58.437927999999999	58.409534999999998	Ленина	0103000020E61000000100000005000000B4006DAB59B359409FC893A46B344D40B4006DAB59B35940580053060E384D40352905DD5EB55940580053060E384D40352905DD5EB559409FC893A46B344D40B4006DAB59B359409FC893A46B344D40
67712	13411	102.72754500000001	102.806381	57.918353000000003	57.897266000000002	Ленина	0103000020E610000001000000050000009357E71890AE594008E8BE9CD9F24C409357E71890AE59407D9752978CF54C4069C70DBF9BB359407D9752978CF54C4069C70DBF9BB3594008E8BE9CD9F24C409357E71890AE594008E8BE9CD9F24C40
67734	13411	102.72754500000001	102.806381	57.918353000000003	57.897266000000002	Комсомольская	0103000020E610000001000000050000009357E71890AE594008E8BE9CD9F24C409357E71890AE59407D9752978CF54C4069C70DBF9BB359407D9752978CF54C4069C70DBF9BB3594008E8BE9CD9F24C409357E71890AE594008E8BE9CD9F24C40
68121	13411	102.72754500000001	102.806381	57.918353000000003	57.897266000000002	Дорожная	0103000020E610000001000000050000009357E71890AE594008E8BE9CD9F24C409357E71890AE59407D9752978CF54C4069C70DBF9BB359407D9752978CF54C4069C70DBF9BB3594008E8BE9CD9F24C409357E71890AE594008E8BE9CD9F24C40
68796	15881	102.226635	102.24212199999999	57.152476999999998	57.146192999999997	Комарова	0103000020E6100000010000000500000041481630818E5940BAF3C473B6924C4041481630818E59403332C85D84934C4018E945ED7E8F59403332C85D84934C4018E945ED7E8F5940BAF3C473B6924C4041481630818E5940BAF3C473B6924C40
68645	1618	102.376259	102.39304799999999	57.772435000000002	57.761705999999997	Школьная	0103000020E61000000100000005000000D8F4A0A0149859405F950B957FE14C40D8F4A0A01498594094A46B26DFE24C408670CCB22799594094A46B26DFE24C408670CCB2279959405F950B957FE14C40D8F4A0A0149859405F950B957FE14C40
69145	15748	102.42135399999999	102.43229599999999	57.757586000000003	57.750532	Молодежная	0103000020E610000001000000050000007B82C476F79A5940FD4CBD6E11E04C407B82C476F79A594028F4FA93F8E04C40438CD7BCAA9B594028F4FA93F8E04C40438CD7BCAA9B5940FD4CBD6E11E04C407B82C476F79A5940FD4CBD6E11E04C40
69129	13594	103.528941	103.553708	52.482269000000002	52.473354999999998	Мира	0103000020E61000000100000005000000DE205A2BDAE15940F4328AE5963C4A40DE205A2BDAE15940F46F97FDBA3D4A4026E2ADF36FE35940F46F97FDBA3D4A4026E2ADF36FE35940F4328AE5963C4A40DE205A2BDAE15940F4328AE5963C4A40
68937	12880	103.303078	103.317954	52.886550999999997	52.863511000000003	Набережная	0103000020E61000000100000005000000C68844A165D359403E5E4887876E4A40C68844A165D35940389ECF807A714A4079E8BB5B59D45940389ECF807A714A4079E8BB5B59D459403E5E4887876E4A40C68844A165D359403E5E4887876E4A40
69137	13988	103.209779	103.226218	52.264588000000003	52.257852	Набережная	0103000020E61000000100000005000000CE18E6046DCD5940A69A594B01214A40CE18E6046DCD594000750305DE214A400FF10F5B7ACE594000750305DE214A400FF10F5B7ACE5940A69A594B01214A40CE18E6046DCD5940A69A594B01214A40
69446	12471	103.185452	103.208997	52.819462999999999	52.801293000000001	Центральная	0103000020E6100000010000000500000094BE1072DECB5940C2C1DEC490664A4094BE1072DECB59401AA4E029E4684A4093FDF33460CD59401AA4E029E4684A4093FDF33460CD5940C2C1DEC490664A4094BE1072DECB5940C2C1DEC490664A40
67961	13318	103.695695	103.738653	52.708486000000001	52.662216000000001	Крупской	0103000020E61000000100000005000000683F524486EC5940A8716F7EC3544A40683F524486EC594041D653ABAF5A4A40E8853B1746EF594041D653ABAF5A4A40E8853B1746EF5940A8716F7EC3544A40683F524486EC5940A8716F7EC3544A40
67710	13318	103.695695	103.738653	52.708486000000001	52.662216000000001	2-я Советская	0103000020E61000000100000005000000683F524486EC5940A8716F7EC3544A40683F524486EC594041D653ABAF5A4A40E8853B1746EF594041D653ABAF5A4A40E8853B1746EF5940A8716F7EC3544A40683F524486EC5940A8716F7EC3544A40
69463	13318	103.695695	103.738653	52.708486000000001	52.662216000000001	2-я Железнодорожная	0103000020E61000000100000005000000683F524486EC5940A8716F7EC3544A40683F524486EC594041D653ABAF5A4A40E8853B1746EF594041D653ABAF5A4A40E8853B1746EF5940A8716F7EC3544A40683F524486EC5940A8716F7EC3544A40
68924	59191	103.250895	103.272948	52.207189999999997	52.184457999999999	Клубная	0103000020E61000000100000005000000B7EEE6A90ED0594027BEDA519C174A40B7EEE6A90ED059407407B133851A4A408D60E3FA77D159407407B133851A4A408D60E3FA77D1594027BEDA519C174A40B7EEE6A90ED0594027BEDA519C174A40
67707	12911	103.42021800000001	103.492407	52.876818	52.853523000000003	Пеньковского	0103000020E6100000010000000500000032CC09DAE4DA594021B1DD3D406D4A4032CC09DAE4DA5940A6457D923B704A409354A69883DF5940A6457D923B704A409354A69883DF594021B1DD3D406D4A4032CC09DAE4DA594021B1DD3D406D4A40
68523	12911	103.42021800000001	103.492407	52.876818	52.853523000000003	Ленина	0103000020E6100000010000000500000032CC09DAE4DA594021B1DD3D406D4A4032CC09DAE4DA5940A6457D923B704A409354A69883DF5940A6457D923B704A409354A69883DF594021B1DD3D406D4A4032CC09DAE4DA594021B1DD3D406D4A40
67926	12911	103.42021800000001	103.492407	52.876818	52.853523000000003	Гоголя	0103000020E6100000010000000500000032CC09DAE4DA594021B1DD3D406D4A4032CC09DAE4DA5940A6457D923B704A409354A69883DF5940A6457D923B704A409354A69883DF594021B1DD3D406D4A4032CC09DAE4DA594021B1DD3D406D4A40
67775	59100	103.48020699999999	103.548929	52.912824999999998	52.87341	3-я Степная	0103000020E61000000100000005000000DB1324B6BBDE5940EBFF1CE6CB6F4A40DB1324B6BBDE594050FC1873D7744A40DDB419A721E3594050FC1873D7744A40DDB419A721E35940EBFF1CE6CB6F4A40DB1324B6BBDE5940EBFF1CE6CB6F4A40
66990	58906	103.380827	103.425428	52.829421000000004	52.812430999999997	Лесная	0103000020E61000000100000005000000C39B35785FD85940D7A02FBDFD674A40C39B35785FD85940CDCEA2772A6A4A405FB35C363ADB5940CDCEA2772A6A4A405FB35C363ADB5940D7A02FBDFD674A40C39B35785FD85940D7A02FBDFD674A40
68793	13831	103.17390899999999	103.219579	52.454459	52.437387999999999	Мира	0103000020E61000000100000005000000B9DE365321CB5940D8D47954FC374A40B9DE365321CB5940BA2F67B62B3A4A40DBF813950DCE5940BA2F67B62B3A4A40DBF813950DCE5940D8D47954FC374A40B9DE365321CB5940D8D47954FC374A40
69343	59242	102.97490500000001	102.988497	52.420721999999998	52.405648999999997	Октябрьская	0103000020E610000001000000050000003EEDF0D764BE5940DA53724EEC334A403EEDF0D764BE5940965AEF37DA354A406CCCEB8843BF5940965AEF37DA354A406CCCEB8843BF5940DA53724EEC334A403EEDF0D764BE5940DA53724EEC334A40
67715	13223	103.534627	103.571225	52.878926999999997	52.859107000000002	Квартал	0103000020E61000000100000005000000C0232A5437E25940E161DA37F76D4A40C0232A5437E25940234910AE80704A40166A4DF38EE45940234910AE80704A40166A4DF38EE45940E161DA37F76D4A40C0232A5437E25940E161DA37F76D4A40
67749	12701	103.50655500000001	103.54235300000001	52.853740000000002	52.815463000000001	Школьная	0103000020E6100000010000000500000005A8A9656BE059408D0C721761684A4005A8A9656BE05940BEA4315A476D4A40CD785BE9B5E25940BEA4315A476D4A40CD785BE9B5E259408D0C721761684A4005A8A9656BE059408D0C721761684A40
68795	12701	103.50655500000001	103.54235300000001	52.853740000000002	52.815463000000001	Разведочная	0103000020E6100000010000000500000005A8A9656BE059408D0C721761684A4005A8A9656BE05940BEA4315A476D4A40CD785BE9B5E25940BEA4315A476D4A40CD785BE9B5E259408D0C721761684A4005A8A9656BE059408D0C721761684A40
69429	12701	103.50655500000001	103.54235300000001	52.853740000000002	52.815463000000001	Ленина	0103000020E6100000010000000500000005A8A9656BE059408D0C721761684A4005A8A9656BE05940BEA4315A476D4A40CD785BE9B5E25940BEA4315A476D4A40CD785BE9B5E259408D0C721761684A4005A8A9656BE059408D0C721761684A40
68952	13035	103.40532399999999	103.41746000000001	52.950187	52.936560999999998	Главная	0103000020E610000001000000050000002B1213D4F0D95940C2DA183BE1774A402B1213D4F0D95940CC0A45BA9F794A40D8D825AAB7DA5940CC0A45BA9F794A40D8D825AAB7DA5940C2DA183BE1774A402B1213D4F0D95940C2DA183BE1774A40
69530	59280	103.56836800000001	103.58375599999999	52.591208000000002	52.581814000000001	Рабочая	0103000020E61000000100000005000000F3052D2460E459406F2D93E1784A4A40F3052D2460E45940199128B4AC4B4A40003620425CE55940199128B4AC4B4A40003620425CE559406F2D93E1784A4A40F3052D2460E459406F2D93E1784A4A40
69465	13093	103.493745	103.528752	53.000014	52.981887999999998	Набережная	0103000020E6100000010000000500000011E4A08499DF5940DC2A8881AE7D4A4011E4A08499DF594065C5707500804A4074ECA012D7E1594065C5707500804A4074ECA012D7E15940DC2A8881AE7D4A4011E4A08499DF5940DC2A8881AE7D4A40
67974	13561	103.637574	103.688715	52.587136999999998	52.558590000000002	Победы	0103000020E61000000100000005000000EAB12D03CEE85940B3EF8AE07F474A40EAB12D03CEE85940C2A2224E274B4A40F05014E813EC5940C2A2224E274B4A40F05014E813EC5940B3EF8AE07F474A40EAB12D03CEE85940B3EF8AE07F474A40
68820	13650	103.560211	103.601246	52.545585000000003	52.536093000000001	Мира	0103000020E6100000010000000500000001F73C7FDAE35940A94E07B29E444A4001F73C7FDAE359401618B2BAD5454A4074B680D07AE659401618B2BAD5454A4074B680D07AE65940A94E07B29E444A4001F73C7FDAE35940A94E07B29E444A40
69241	13282	103.59100599999999	103.624441	52.880159999999997	52.873235999999999	Совхозная	0103000020E61000000100000005000000586FD40AD3E559404DD87E32C66F4A40586FD40AD3E55940A99F3715A9704A40055262D7F6E75940A99F3715A9704A40055262D7F6E759404DD87E32C66F4A40586FD40AD3E559404DD87E32C66F4A40
69416	59257	99.237797	101.103696	55.078797999999999	53.233597000000003	Зерновая	0103000020E610000001000000050000009085E81038CF5840CCB8A981E69D4A409085E81038CF5840BF7E880D168A4B40772E8CF4A2465940BF7E880D168A4B40772E8CF4A2465940CCB8A981E69D4A409085E81038CF5840CCB8A981E69D4A40
68925	59192	100.878516	100.910172	54.454763	54.443857999999999	Клубная	0103000020E61000000100000005000000D1402C9B39385940B308C556D0384B40D1402C9B3938594026378AAC353A4B40096F0F42403A594026378AAC353A4B40096F0F42403A5940B308C556D0384B40D1402C9B39385940B308C556D0384B40
37456	9290	100.882334	100.933852	54.467328000000002	54.453767999999997	Гагарина	0103000020E61000000100000005000000878906297838594054FCDF11153A4B408789062978385940A7406667D13B4B4078D32D3BC43B5940A7406667D13B4B4078D32D3BC43B594054FCDF11153A4B40878906297838594054FCDF11153A4B40
68785	9083	100.512767	100.533509	54.604191999999998	54.589733000000003	Докучаева	0103000020E61000000100000005000000F4DDAD2CD12059409D2FF65E7C4B4B40F4DDAD2CD12059409E40D829564D4B40C9C7EE02252259409E40D829564D4B40C9C7EE02252259409D2FF65E7C4B4B40F4DDAD2CD12059409D2FF65E7C4B4B40
69221	10565	100.62221700000001	100.640804	54.704132999999999	54.692655999999999	Шолохова	0103000020E61000000100000005000000FA804067D227594068B0A9F3A8584B40FA804067D22759406684B707215A4B4058C9C7EE022959406684B707215A4B4058C9C7EE0229594068B0A9F3A8584B40FA804067D227594068B0A9F3A8584B40
69372	9460	100.981786	101.008709	54.292757000000002	54.279043999999999	Нижняя	0103000020E61000000100000005000000EC6AF294D53E59409012BBB6B7234B40EC6AF294D53E59406956B60F79254B40938B31B08E4059406956B60F79254B40938B31B08E4059409012BBB6B7234B40EC6AF294D53E59409012BBB6B7234B40
69424	9507	100.889556	100.92636	54.343730000000001	54.333941000000003	Центральная	0103000020E610000001000000050000007AFD497CEE38594093E52494BE2A4B407AFD497CEE385940B9533A58FF2B4B40A514747B493B5940B9533A58FF2B4B40A514747B493B594093E52494BE2A4B407AFD497CEE38594093E52494BE2A4B40
69093	8827	100.29486199999999	100.349992	54.644733000000002	54.630111999999997	Нагорная	0103000020E6100000010000000500000052B5DD04DF12594098689082A7504B4052B5DD04DF12594074D3669C86524B402577D8446616594074D3669C86524B402577D8446616594098689082A7504B4052B5DD04DF12594098689082A7504B40
69425	10659	100.56254199999999	100.586006	54.887433999999999	54.874169999999999	Школьная	0103000020E61000000100000005000000172829B000245940799274CDE46F4B40172829B000245940E2ADF36F97714B40A0504F1F81255940E2ADF36F97714B40A0504F1F81255940799274CDE46F4B40172829B000245940799274CDE46F4B40
68783	10431	100.206836	100.252318	54.75994	54.743738999999998	И.Каторжного	0103000020E61000000100000005000000ABE80FCD3C0D59403FE1ECD6325F4B40ABE80FCD3C0D59400C76C3B645614B404C8C65FA251059400C76C3B645614B404C8C65FA251059403FE1ECD6325F4B40ABE80FCD3C0D59403FE1ECD6325F4B40
69369	9035	100.57997	100.607934	54.093378000000001	54.075567999999997	Школьная	0103000020E6100000010000000500000050AA7D3A1E255940E34F5436AC094B4050AA7D3A1E2559403C1570CFF30B4B4018080264E82659403C1570CFF30B4B4018080264E8265940E34F5436AC094B4050AA7D3A1E255940E34F5436AC094B40
68599	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	микрорайон Угольщиков	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68892	1419	100.681048	100.812849	54.522708999999999	54.445968000000001	Угольная	0103000020E6100000010000000500000066C0594A962B59400188BB7A15394B4066C0594A962B59409529E620E8424B4086E5CFB7053459409529E620E8424B4086E5CFB7053459400188BB7A15394B4066C0594A962B59400188BB7A15394B40
67751	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Сигаева	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68792	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Сибстроя	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68808	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Пугачева	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
67705	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Протасюка	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68960	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Мичурина	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68598	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Мира	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68741	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Ломоносова	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68281	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Ленина	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68522	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Красноармейская	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68790	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Заречная 2-я	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68731	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Жданова	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68789	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Ермакова	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
68791	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Горячкина	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
67740	1419	100.515354	100.74882599999999	54.609245000000001	54.474589999999999	Блюхера	0103000020E6100000010000000500000038F7578FFB2059401B81785DBF3C4B4038F7578FFB20594032207BBDFB4D4B403F19E3C3EC2F594032207BBDFB4D4B403F19E3C3EC2F59401B81785DBF3C4B4038F7578FFB2059401B81785DBF3C4B40
69371	9331	101.04547700000001	101.07318100000001	54.487473999999999	54.48115	Лесная	0103000020E6100000010000000500000018EE5C18E9425940363CBD52963D4B4018EE5C18E94259403DD34B8C653E4B40126C5CFFAE4459403DD34B8C653E4B40126C5CFFAE445940363CBD52963D4B4018EE5C18E9425940363CBD52963D4B40
69459	8985	100.50124099999999	100.523403	54.728180999999999	54.710687999999998	Садовая	0103000020E61000000100000005000000849A2155142059406FD40AD3F75A4B40849A215514205940C748F608355D4B4036E84B6F7F215940C748F608355D4B4036E84B6F7F2159406FD40AD3F75A4B40849A2155142059406FD40AD3F75A4B40
69141	8344	100.089741	100.104123	54.676485	54.669888999999998	Новая	0103000020E6100000010000000500000010070951BE0559409E7939ECBE554B4010070951BE055940069E7B0F97564B40BBF083F3A9065940069E7B0F97564B40BBF083F3A90659409E7939ECBE554B4010070951BE0559409E7939ECBE554B40
69223	9755	100.38462199999999	100.40513	54.373887000000003	54.362231999999999	Центральная	0103000020E610000001000000050000009DD497A59D18594047C8409E5D2E4B409DD497A59D18594025B37A87DB2F4B40392861A6ED19594025B37A87DB2F4B40392861A6ED19594047C8409E5D2E4B409DD497A59D18594047C8409E5D2E4B40
69281	9693	100.476574	100.503846	54.420957000000001	54.398497999999996	50 лет Октября	0103000020E61000000100000005000000EE073C30801E5940BDC282FB01334B40EE073C30801E5940DA0242EBE1354B401B0E4B033F205940DA0242EBE1354B401B0E4B033F205940BDC282FB01334B40EE073C30801E5940BDC282FB01334B40
69428	5037	100.90700099999999	100.93830800000001	54.845559999999999	54.837203000000002	Набережная	0103000020E610000001000000050000001D1CEC4D0C3A59407A8EC877296B4B401D1CEC4D0C3A59402367614F3B6C4B40D064FF3C0D3C59402367614F3B6C4B40D064FF3C0D3C59407A8EC877296B4B401D1CEC4D0C3A59407A8EC877296B4B40
69108	10027	100.46680000000001	100.49118900000001	54.189677000000003	54.181879000000002	Набережная	0103000020E6100000010000000500000076711B0DE01D5940236AA2CF47174B4076711B0DE01D5940D6E6FF5547184B40EBC9FCA36F1F5940D6E6FF5547184B40EBC9FCA36F1F5940236AA2CF47174B4076711B0DE01D5940236AA2CF47174B40
69215	9360	101.038371	101.063757	54.459735000000002	54.451616999999999	Школьная	0103000020E610000001000000050000005987A3AB74425940A8A8FA95CE394B405987A3AB74425940CDE9B298D83A4B4007793D9814445940CDE9B298D83A4B4007793D9814445940A8A8FA95CE394B405987A3AB74425940A8A8FA95CE394B40
68890	10467	100.67771500000001	100.70124199999999	54.637965000000001	54.628596000000002	Кировская	0103000020E610000001000000050000008E40BCAE5F2B5940BE326FD575504B408E40BCAE5F2B59400F7F4DD6A8514B4039252026E12C59400F7F4DD6A8514B4039252026E12C5940BE326FD575504B408E40BCAE5F2B5940BE326FD575504B40
69218	9667	100.516755	100.535251	54.478749000000001	54.456829999999997	Набережная	0103000020E61000000100000005000000D94290831221594074EACA67793A4B40D94290831221594011FFB0A5473D4B40AF09698D4122594011FFB0A5473D4B40AF09698D4122594074EACA67793A4B40D94290831221594074EACA67793A4B40
69100	10216	99.960392999999996	99.995722999999998	54.267378000000001	54.246208000000003	Зеленая	0103000020E61000000100000005000000AB93331477FD5840BD0166BE831F4B40AB93331477FD5840BFD53A7139224B400038F6ECB9FF5840BFD53A7139224B400038F6ECB9FF5840BD0166BE831F4B40AB93331477FD5840BD0166BE831F4B40
68784	10307	100.22729099999999	100.261831	54.485858	54.453648000000001	Ленина	0103000020E6100000010000000500000035EB8CEF8B0E5940AAF23D23113A4B4035EB8CEF8B0E5940FF3F4E98303E4B400E85CFD6C1105940FF3F4E98303E4B400E85CFD6C1105940AAF23D23113A4B4035EB8CEF8B0E5940AAF23D23113A4B40
67036	8896	100.444845	100.46909100000001	54.657428000000003	54.642597000000002	Центральная	0103000020E6100000010000000500000081B22957781C5940FDC0559E40524B4081B22957781C5940C3BCC79926544B4045F64196051E5940C3BCC79926544B4045F64196051E5940FDC0559E40524B4081B22957781C5940FDC0559E40524B40
69426	10277	99.704408999999998	99.724988999999994	54.123972000000002	54.115059000000002	Школьная	0103000020E6100000010000000500000084807C0915ED5840240ED940BA0E4B4084807C0915ED584053CF8250DE0F4B406C3D433866EE584053CF8250DE0F4B406C3D433866EE5840240ED940BA0E4B4084807C0915ED5840240ED940BA0E4B40
68591	10117	100.059881	100.103647	54.199643000000002	54.178491000000001	пер.Пионерский	0103000020E61000000100000005000000B7291E17D5035940AFD007CBD8164B40B7291E17D50359400BF0DDE68D194B4006D50627A20659400BF0DDE68D194B4006D50627A2065940AFD007CBD8164B40B7291E17D5035940AFD007CBD8164B40
69096	9964	100.104896	100.13543799999999	54.320231	54.303927999999999	Ленина	0103000020E61000000100000005000000CC5EB69DB60659405A2BDA1CE7264B40CC5EB69DB60659402B155454FD284B40AE282504AB0859402B155454FD284B40AE282504AB0859405A2BDA1CE7264B40CC5EB69DB60659405A2BDA1CE7264B40
69531	59281	100.50010899999999	100.52494799999999	54.634718999999997	54.623987999999997	Кирова	0103000020E61000000100000005000000DBDB2DC901205940588CBAD6DE4F4B40DBDB2DC9012059402D93E1783E514B4070067FBF982159402D93E1783E514B4070067FBF98215940588CBAD6DE4F4B40DBDB2DC901205940588CBAD6DE4F4B40
68730	9910	100.21199300000001	100.26988	54.261588000000003	54.245528999999998	Ленина	0103000020E61000000100000005000000C87E164B910D59401B9C887E6D1F4B40C87E164B910D5940568330B77B214B400C76C3B645115940568330B77B214B400C76C3B6451159401B9C887E6D1F4B40C87E164B910D59401B9C887E6D1F4B40
68753	59173	100.658294	100.684336	54.251463000000001	54.218294	Центральная	0103000020E61000000100000005000000CB49287D212A5940DE74CB0EF11B4B40CB49287D212A5940B89388F02F204B406EDE3829CC2B5940B89388F02F204B406EDE3829CC2B5940DE74CB0EF11B4B40CB49287D212A5940DE74CB0EF11B4B40
68594	10630	100.622208	100.656273	54.768245999999998	54.748607999999997	Бурлова	0103000020E61000000100000005000000D0D38041D227594011C30E63D25F4B40D0D38041D227594033A48AE255624B40DC0F7860002A594033A48AE255624B40DC0F7860002A594011C30E63D25F4B40D0D38041D227594011C30E63D25F4B40
68782	9551	100.70471000000001	100.76316300000001	54.413732000000003	54.383505	Степная	0103000020E6100000010000000500000082CAF8F7192D59401E6D1CB116314B4082CAF8F7192D594083A7902BF5344B401BA19FA9D730594083A7902BF5344B401BA19FA9D73059401E6D1CB116314B4082CAF8F7192D59401E6D1CB116314B40
69288	10056	100.287442	100.32452499999999	54.180419999999998	54.169020000000003	Полевая	0103000020E61000000100000005000000CC5F2173651259405A2F8672A2154B40CC5F217365125940ACC5A70018174B40006F8104C5145940ACC5A70018174B40006F8104C51459405A2F8672A2154B40CC5F2173651259405A2F8672A2154B40
69212	8795	100.813541	100.831543	54.834682999999998	54.814548000000002	Трактовая	0103000020E61000000100000005000000213D450E11345940D882DE1B43684B40213D450E113459407AC37DE4D66A4B40EF8D2100383559407AC37DE4D66A4B40EF8D210038355940D882DE1B43684B40213D450E11345940D882DE1B43684B40
69095	9168	100.38751499999999	100.40501399999999	54.587657	54.576996999999999	Школьная	0103000020E6100000010000000500000067EDB60BCD185940EF71A609DB494B4067EDB60BCD185940FB213658384B4B40041BD7BFEB195940FB213658384B4B40041BD7BFEB195940EF71A609DB494B4067EDB60BCD185940EF71A609DB494B40
69421	7881	100.11714000000001	100.144565	54.637455000000003	54.616909	Школьная	0103000020E610000001000000050000006C43C5387F075940D5CDC5DFF64E4B406C43C5387F075940FAD51C2098514B405CC98E8D40095940FAD51C2098514B405CC98E8D40095940D5CDC5DFF64E4B406C43C5387F075940D5CDC5DFF64E4B40
68542	9828	100.585252	100.60981200000001	54.408503000000003	54.388632000000001	Братская	0103000020E61000000100000005000000CAFACDC474255940EC1681B1BE314B40CAFACDC474255940B1A888D349344B40562DE92807275940B1A888D349344B40562DE92807275940EC1681B1BE314B40CAFACDC474255940EC1681B1BE314B40
69103	10529	100.606452	100.630653	54.645406000000001	54.635235000000002	Ленина	0103000020E6100000010000000500000001A60C1CD0265940252367614F514B4001A60C1CD02659403352EFA99C524B40F487669E5C2859403352EFA99C524B40F487669E5C285940252367614F514B4001A60C1CD0265940252367614F514B40
69289	10162	99.888518000000005	99.923355000000001	53.941288999999998	53.910075999999997	Школьная	0103000020E6100000010000000500000012FA997ADDF85840EF6FD05E7DF44A4012FA997ADDF85840D28A6F287CF84A4047E6913F18FB5840D28A6F287CF84A4047E6913F18FB5840EF6FD05E7DF44A4012FA997ADDF85840EF6FD05E7DF44A40
68888	10358	100.167355	100.222027	54.420915000000001	54.390068999999997	Солнечная	0103000020E610000001000000050000009DF4BEF1B50A59407A17EFC7ED314B409DF4BEF1B50A5940ABB2EF8AE0354B400EF5BBB0350E5940ABB2EF8AE0354B400EF5BBB0350E59407A17EFC7ED314B409DF4BEF1B50A59407A17EFC7ED314B40
69216	9242	99.237797	101.103696	55.078797999999999	53.233597000000003	Школьная	0103000020E610000001000000050000009085E81038CF5840CCB8A981E69D4A409085E81038CF5840BF7E880D168A4B40772E8CF4A2465940BF7E880D168A4B40772E8CF4A2465940CCB8A981E69D4A409085E81038CF5840CCB8A981E69D4A40
68891	9242	99.237797	101.103696	55.078797999999999	53.233597000000003	Привокзальная	0103000020E610000001000000050000009085E81038CF5840CCB8A981E69D4A409085E81038CF5840BF7E880D168A4B40772E8CF4A2465940BF7E880D168A4B40772E8CF4A2465940CCB8A981E69D4A409085E81038CF5840CCB8A981E69D4A40
68885	7443	97.613544000000005	97.655503999999993	56.063116999999998	56.035254999999999	Школьная	0103000020E610000001000000050000000DAA0D4E446758409F02603C83044C400DAA0D4E446758402B69C53714084C406B990CC7F36958402B69C53714084C406B990CC7F36958409F02603C83044C400DAA0D4E446758409F02603C83044C40
68721	7443	97.613544000000005	97.655503999999993	56.063116999999998	56.035254999999999	Советская	0103000020E610000001000000050000000DAA0D4E446758409F02603C83044C400DAA0D4E446758402B69C53714084C406B990CC7F36958402B69C53714084C406B990CC7F36958409F02603C83044C400DAA0D4E446758409F02603C83044C40
68899	7443	97.613544000000005	97.655503999999993	56.063116999999998	56.035254999999999	Матросова	0103000020E610000001000000050000000DAA0D4E446758409F02603C83044C400DAA0D4E446758402B69C53714084C406B990CC7F36958402B69C53714084C406B990CC7F36958409F02603C83044C400DAA0D4E446758409F02603C83044C40
68590	7443	97.613544000000005	97.655503999999993	56.063116999999998	56.035254999999999	Дружбы	0103000020E610000001000000050000000DAA0D4E446758409F02603C83044C400DAA0D4E446758402B69C53714084C406B990CC7F36958402B69C53714084C406B990CC7F36958409F02603C83044C400DAA0D4E446758409F02603C83044C40
68533	5254	98.329052000000004	98.375207000000003	56.382446999999999	56.356805999999999	Кирова	0103000020E61000000100000005000000BDAB1E300F9558401F82AAD1AB2D4C40BDAB1E300F95584006BAF605F4304C40BD8E38640398584006BAF605F4304C40BD8E3864039858401F82AAD1AB2D4C40BDAB1E300F9558401F82AAD1AB2D4C40
68780	5254	98.329052000000004	98.375207000000003	56.382446999999999	56.356805999999999	Барковская	0103000020E61000000100000005000000BDAB1E300F9558401F82AAD1AB2D4C40BDAB1E300F95584006BAF605F4304C40BD8E38640398584006BAF605F4304C40BD8E3864039858401F82AAD1AB2D4C40BDAB1E300F9558401F82AAD1AB2D4C40
68745	52151	97.679946999999999	97.716139999999996	55.736240000000002	55.707830999999999	Первомайская	0103000020E61000000100000005000000DA006C40846B5840280CCA349ADA4B40DA006C40846B5840E700C11C3DDE4B40E0D6DD3CD56D5840E700C11C3DDE4B40E0D6DD3CD56D5840280CCA349ADA4B40DA006C40846B5840280CCA349ADA4B40
68746	4930	97.682606000000007	97.708495999999997	56.935822000000002	56.918059999999997	Советская	0103000020E610000001000000050000006B8313D1AF6B584004E275FD82754C406B8313D1AF6B58404C70EA03C9774C4032569BFF576D58404C70EA03C9774C4032569BFF576D584004E275FD82754C406B8313D1AF6B584004E275FD82754C40
69365	52134	97.841509000000002	97.876031999999995	56.728873999999998	56.720503000000001	Ленина	0103000020E610000001000000050000008A929048DB755840BFD53A71395C4C408A929048DB755840CD7344BE4B5D4C40F78F85E810785840CD7344BE4B5D4C40F78F85E810785840BFD53A71395C4C408A929048DB755840BFD53A71395C4C40
69090	52203	97.540115999999998	97.555351000000002	55.924622999999997	55.913342999999998	Центральная	0103000020E61000000100000005000000F702B34291625840E883656CE8F44B40F702B342916258409010E50B5AF64B4042B3EBDE8A6358409010E50B5AF64B4042B3EBDE8A635840E883656CE8F44B40F702B34291625840E883656CE8F44B40
69140	52125	98.048642999999998	98.060438000000005	56.724608000000003	56.713267000000002	Центральная	0103000020E610000001000000050000007A8B87F71C835840742843554C5B4C407A8B87F71C835840C23577F4BF5C4C40E25B5837DE835840C23577F4BF5C4C40E25B5837DE835840742843554C5B4C407A8B87F71C835840742843554C5B4C40
69419	52205	97.742165	97.766167999999993	55.947001	55.939045	Зеленая	0103000020E6100000010000000500000018CFA0A17F6F5840753C66A032F84B4018CFA0A17F6F5840C0232A5437F94B4078CF81E508715840C0232A5437F94B4078CF81E508715840753C66A032F84B4018CFA0A17F6F5840753C66A032F84B40
68712	4332	97.713651999999996	97.738534999999999	57.284210999999999	57.263316000000003	Гайнулина	0103000020E61000000100000005000000662E7079AC6D5840BC41B456B4A14C40662E7079AC6D5840EC14AB0661A44C40E3FC4D28446F5840EC14AB0661A44C40E3FC4D28446F5840BC41B456B4A14C40662E7079AC6D5840BC41B456B4A14C40
69272	52185	97.724305999999999	97.771279000000007	55.600805999999999	55.574145999999999	Советская	0103000020E61000000100000005000000FB928D075B6E58408A90BA9D7DC94B40FB928D075B6E5840CB9E0436E7CC4B40DD4598A25C715840CB9E0436E7CC4B40DD4598A25C7158408A90BA9D7DC94B40FB928D075B6E58408A90BA9D7DC94B40
69115	52180	98.053054000000003	98.078942999999995	56.023786999999999	56.006945000000002	Бирюсинская	0103000020E6100000010000000500000002BB9A3C6583584074EFE192E3004C4002BB9A3C65835840F488D1730B034C40E1CFF0660D855840F488D1730B034C40E1CFF0660D85584074EFE192E3004C4002BB9A3C6583584074EFE192E3004C40
68610	52187	97.805424000000002	97.836515000000006	55.542655000000003	55.519981999999999	Береговая	0103000020E6100000010000000500000077DA1A118C7358401C412AC58EC24B4077DA1A118C735840650113B875C54B4043E7357689755840650113B875C54B4043E73576897558401C412AC58EC24B4077DA1A118C7358401C412AC58EC24B40
69089	52191	97.861002999999997	97.866815000000003	55.419274000000001	55.397903999999997	Профсоюзная	0103000020E6100000010000000500000081B053AC1A7758404A79AD84EEB24B4081B053AC1A77584014083BC5AAB54B40AA2B9FE57977584014083BC5AAB54B40AA2B9FE5797758404A79AD84EEB24B4081B053AC1A7758404A79AD84EEB24B40
69457	52200	97.804759000000004	97.831619000000003	55.887810999999999	55.882776999999997	Зеленая	0103000020E61000000100000005000000598AE42B817358409B5434D6FEF04B40598AE42B81735840B80375CAA3F14B40DDEEE53E39755840B80375CAA3F14B40DDEEE53E397558409B5434D6FEF04B40598AE42B817358409B5434D6FEF04B40
68947	52197	97.624934999999994	97.647589999999994	55.802027000000002	55.781869	Колхозная	0103000020E610000001000000050000000CC85EEFFE675840CC608C4814E44B400CC85EEFFE67584027C11BD2A8E64B40DDCD531D7269584027C11BD2A8E64B40DDCD531D72695840CC608C4814E44B400CC85EEFFE675840CC608C4814E44B40
69106	59211	98.378000999999998	98.402741000000006	55.724642000000003	55.709104000000004	Железнодорожная	0103000020E61000000100000005000000BD361B2B319858403DBB7CEBC3DA4B40BD361B2B319858406EA7AD11C1DC4B4089F02F82C69958406EA7AD11C1DC4B4089F02F82C69958403DBB7CEBC3DA4B40BD361B2B319858403DBB7CEBC3DA4B40
68893	52209	97.606078999999994	97.641311000000002	56.078080999999997	56.063961999999997	Трактовая	0103000020E61000000100000005000000B6F292FFC9665840E71725E82F084C40B6F292FFC966584030B8E68EFE094C402AE44A3D0B69584030B8E68EFE094C402AE44A3D0B695840E71725E82F084C40B6F292FFC9665840E71725E82F084C40
69544	59288	98.098517000000001	98.124262999999999	57.353583999999998	57.341594000000001	Центральная	0103000020E6100000010000000500000067463F1A4E8658404241295AB9AB4C4067463F1A4E865840C631923D42AD4C409546CCECF3875840C631923D42AD4C409546CCECF38758404241295AB9AB4C4067463F1A4E8658404241295AB9AB4C40
68680	430	97.543402999999998	97.568691000000001	55.850161	55.840583000000002	Центральная	0103000020E610000001000000050000001763601DC76258406B49473998EB4B401763601DC7625840D6AA5D13D2EC4B40E4A1EF6E65645840D6AA5D13D2EC4B40E4A1EF6E656458406B49473998EB4B401763601DC76258406B49473998EB4B40
69456	52139	97.824882000000002	97.849458999999996	56.899920999999999	56.890726999999998	Капустина	0103000020E61000000100000005000000C843DFDDCA7458400455A35703724C40C843DFDDCA745840E7FD7F9C30734C40BE1248895D765840E7FD7F9C30734C40BE1248895D7658400455A35703724C40C843DFDDCA7458400455A35703724C40
69094	52212	98.113906	98.138349000000005	55.947011000000003	55.936776000000002	Школьная	0103000020E610000001000000050000005D34643C4A875840BFD6A546E8F74B405D34643C4A875840E4F90CA837F94B40CC9BC3B5DA885840E4F90CA837F94B40CC9BC3B5DA885840BFD6A546E8F74B405D34643C4A875840BFD6A546E8F74B40
69547	59291	98.441997000000001	98.462766000000002	55.672061999999997	55.661068999999998	Трактовая	0103000020E6100000010000000500000087FBC8AD499C584020B3B3E89DD44B4087FBC8AD499C58403271AB2006D64B40D9EC48F59D9D58403271AB2006D64B40D9EC48F59D9D584020B3B3E89DD44B4087FBC8AD499C584020B3B3E89DD44B40
69375	59253	98.064327000000006	98.086209999999994	55.914881999999999	55.905225000000002	Трактовая	0103000020E61000000100000005000000FD4FFEEE1D845840C442AD69DEF34B40FD4FFEEE1D8458407BD976DA1AF54B40A4A5F276848558407BD976DA1AF54B40A4A5F27684855840C442AD69DEF34B40FD4FFEEE1D845840C442AD69DEF34B40
69374	52131	98.057967000000005	98.074218000000002	56.729477000000003	56.719906000000002	Зеленая	0103000020E61000000100000005000000D34F38BBB5835840DB183BE1255C4C40D34F38BBB5835840941799805F5D4C4092B1DAFCBF845840941799805F5D4C4092B1DAFCBF845840DB183BE1255C4C40D34F38BBB5835840DB183BE1255C4C40
68777	4491	97.686774999999997	97.742147000000003	56.969509000000002	56.944527000000001	Советская	0103000020E61000000100000005000000772D211FF46B58403198BF42E6784C40772D211FF46B5840BE16F4DE187C4C40C57421567F6F5840BE16F4DE187C4C40C57421567F6F58403198BF42E6784C40772D211FF46B58403198BF42E6784C40
68894	4491	97.686774999999997	97.742147000000003	56.969509000000002	56.944527000000001	Ленина	0103000020E61000000100000005000000772D211FF46B58403198BF42E6784C40772D211FF46B5840BE16F4DE187C4C40C57421567F6F5840BE16F4DE187C4C40C57421567F6F58403198BF42E6784C40772D211FF46B58403198BF42E6784C40
68719	6043	98.158462	98.196667000000005	55.797974000000004	55.783003000000001	40 лет Октября	0103000020E6100000010000000500000029EACC3D248A5840BFD53A7139E44B4029EACC3D248A58407787140324E64B40F54C2F31968C58407787140324E64B40F54C2F31968C5840BFD53A7139E44B4029EACC3D248A5840BFD53A7139E44B40
69405	52147	98.224909999999994	98.239382000000006	56.155206999999997	56.130999000000003	Пионерская	0103000020E61000000100000005000000C6A2E9EC648E584084674293C4104C40C6A2E9EC648E58401D8EAED2DD134C401250E108528F58401D8EAED2DD134C401250E108528F584084674293C4104C40C6A2E9EC648E584084674293C4104C40
69625	59336	98.518874999999994	98.549048999999997	56.127803	56.109270000000002	Транспортная	0103000020E6100000010000000500000091ED7C3F35A158408B37328FFC0D4C4091ED7C3F35A1584054AA44D95B104C40B2B96A9E23A3584054AA44D95B104C40B2B96A9E23A358408B37328FFC0D4C4091ED7C3F35A158408B37328FFC0D4C40
68779	52137	97.695532999999998	97.718207000000007	56.886783999999999	56.871949999999998	Школьная	0103000020E610000001000000050000007B12D89C836C5840A4DFBE0E9C6F4C407B12D89C836C5840DB4E5B2382714C4088307E1AF76D5840DB4E5B2382714C4088307E1AF76D5840A4DFBE0E9C6F4C407B12D89C836C5840A4DFBE0E9C6F4C40
69092	52210	97.846898999999993	97.877917999999994	56.032558999999999	56.025602999999997	Трактовая	0103000020E61000000100000005000000F700DD9733765840F9D687F546034C40F700DD97337658406118B0E42A044C4076A4FACE2F7858406118B0E42A044C4076A4FACE2F785840F9D687F546034C40F700DD9733765840F9D687F546034C40
69088	52149	98.159961999999993	98.176670999999999	56.106268	56.097014999999999	Трактовая	0103000020E6100000010000000500000093A641D13C8A5840581CCEFC6A0C4C4093A641D13C8A5840404E98309A0D4C40B4C9E1934E8B5840404E98309A0D4C40B4C9E1934E8B5840581CCEFC6A0C4C4093A641D13C8A5840581CCEFC6A0C4C40
69567	59305	98.173822999999999	98.196190999999999	57.357326999999998	57.34545	Центральная	0103000020E61000000100000005000000BA1281EA1F8B58409C33A2B437AC4C40BA1281EA1F8B5840287D21E4BCAD4C404031B2648E8C5840287D21E4BCAD4C404031B2648E8C58409C33A2B437AC4C40BA1281EA1F8B58409C33A2B437AC4C40
67698	5525	98.450873000000001	98.493020999999999	56.084310000000002	56.058478000000001	Первомайская	0103000020E6100000010000000500000090696D1ADB9C58408BC404357C074C4090696D1ADB9C5840E65C8AABCA0A4C4070CFF3A78D9F5840E65C8AABCA0A4C4070CFF3A78D9F58408BC404357C074C4090696D1ADB9C58408BC404357C074C40
69417	5525	98.450873000000001	98.493020999999999	56.084310000000002	56.058478000000001	Октябрьская	0103000020E6100000010000000500000090696D1ADB9C58408BC404357C074C4090696D1ADB9C5840E65C8AABCA0A4C4070CFF3A78D9F5840E65C8AABCA0A4C4070CFF3A78D9F58408BC404357C074C4090696D1ADB9C58408BC404357C074C40
67894	5525	98.450873000000001	98.493020999999999	56.084310000000002	56.058478000000001	Калинина	0103000020E6100000010000000500000090696D1ADB9C58408BC404357C074C4090696D1ADB9C5840E65C8AABCA0A4C4070CFF3A78D9F5840E65C8AABCA0A4C4070CFF3A78D9F58408BC404357C074C4090696D1ADB9C58408BC404357C074C40
69366	52145	98.399866000000003	98.412891999999999	56.516674999999999	56.505704000000001	Молодежная	0103000020E6100000010000000500000012329067979958406BBA9EE8BA404C40123290679799584095D4096822424C40EC3191D26C9A584095D4096822424C40EC3191D26C9A58406BBA9EE8BA404C4012329067979958406BBA9EE8BA404C40
69277	52195	97.643834999999996	97.684134	55.974739999999997	55.962522999999997	Ленина	0103000020E610000001000000050000004A41B79734695840EB5223F433FB4B404A41B79734695840300DC347C4FC4B403A05F9D9C86B5840300DC347C4FC4B403A05F9D9C86B5840EB5223F433FB4B404A41B79734695840EB5223F433FB4B40
69087	52124	98.150915999999995	98.173365000000004	56.659063000000003	56.641396999999998	Больничная	0103000020E610000001000000050000005C1C959BA88958405260014C19524C405C1C959BA88958407880272D5C544C4059518369188B58407880272D5C544C4059518369188B58405260014C19524C405C1C959BA88958405260014C19524C40
69602	59326	97.746863000000005	97.778906000000006	57.188640999999997	57.172151999999997	Мира	0103000020E61000000100000005000000EBE5779ACC6F584072F8A41309964C40EBE5779ACC6F5840A5D7666325984C40202A8D98D9715840A5D7666325984C40202A8D98D971584072F8A41309964C40EBE5779ACC6F584072F8A41309964C40
69458	52143	98.371093000000002	98.386868000000007	56.583886999999997	56.567022999999999	Школьная	0103000020E6100000010000000500000092B1DAFCBF975840378AAC3594484C4092B1DAFCBF9758409FC728CFBC4A4C409DF7FF71C29858409FC728CFBC4A4C409DF7FF71C2985840378AAC3594484C4092B1DAFCBF975840378AAC3594484C40
69415	52157	98.285034999999993	98.309550000000002	56.172539999999998	56.158284999999999	Центральная	0103000020E61000000100000005000000C8CD70033E9258404339D1AE42144C40C8CD70033E9258403CA06CCA15164C40849ECDAACF9358403CA06CCA15164C40849ECDAACF9358404339D1AE42144C40C8CD70033E9258404339D1AE42144C40
67896	52216	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	Советская	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
67973	52216	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	Октябрьская	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
67766	52216	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	Ленина	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
67967	52216	97.760346999999996	97.864946000000003	55.98507	55.938012000000001	Дружбы	0103000020E6100000010000000500000026A77686A9705840B6A0F7C610F84B4026A77686A9705840A72215C616FE4B4096B377465B775840A72215C616FE4B4096B377465B775840B6A0F7C610F84B4026A77686A9705840B6A0F7C610F84B40
68966	52155	97.886325999999997	97.902703000000002	56.001458999999997	55.981147	переулок Школьный	0103000020E610000001000000050000000CE6AF90B9785840C5C8923996FD4B400CE6AF90B978584076A4FACE2F004C4012C0CDE2C579584076A4FACE2F004C4012C0CDE2C5795840C5C8923996FD4B400CE6AF90B9785840C5C8923996FD4B40
68750	52174	98.013661999999997	98.041465000000002	55.912954999999997	55.857826000000003	Школьная	0103000020E61000000100000005000000ABCC94D6DF8058404AD40B3ECDED4B40ABCC94D6DF8058401EDC9DB5DBF44B406FBBD05CA78258401EDC9DB5DBF44B406FBBD05CA78258404AD40B3ECDED4B40ABCC94D6DF8058404AD40B3ECDED4B40
69153	59216	98.101877000000002	98.116806999999994	55.964171	55.953946000000002	Юбилейная	0103000020E61000000100000005000000BCCD1B278586584034130CE71AFA4B40BCCD1B2785865840356090F469FB4B40683C11C479875840356090F469FB4B40683C11C47987584034130CE71AFA4B40BCCD1B278586584034130CE71AFA4B40
69086	4079	103.237869	103.277242	51.777042999999999	51.747489000000002	Набережная	0103000020E61000000100000005000000DDEEE53E39CF5940548F34B8ADDF4940DDEEE53E39CF5940F94A202576E34940F8C43A55BED15940F94A202576E34940F8C43A55BED15940548F34B8ADDF4940DDEEE53E39CF5940548F34B8ADDF4940
69091	3565	104.214427	104.242203	51.500568000000001	51.492919999999998	Терешковой	0103000020E610000001000000050000004818062CB90D5A40ACC5A70018BF49404818062CB90D5A404AB6BA9C12C049408FFF0241800F5A404AB6BA9C12C049408FFF0241800F5A40ACC5A70018BF49404818062CB90D5A40ACC5A70018BF4940
68254	919	103.652343	103.738527	51.690190999999999	51.633105999999998	Ржанова	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
67958	919	103.652343	103.738527	51.690190999999999	51.633105999999998	Ленина	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
67959	919	103.652343	103.738527	51.690190999999999	51.633105999999998	Куприна	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
67978	919	103.652343	103.738527	51.690190999999999	51.633105999999998	Гранитная	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
67981	919	103.652343	103.738527	51.690190999999999	51.633105999999998	Героя Ивана Тонконог	0103000020E6100000010000000500000092B1DAFCBFE9594060730E9E09D1494092B1DAFCBFE959402C7FBE2D58D84940A20DC00644EF59402C7FBE2D58D84940A20DC00644EF594060730E9E09D1494092B1DAFCBFE9594060730E9E09D14940
68935	3599	103.64474300000001	103.73099000000001	51.742977000000003	51.703069999999997	Трактовая	0103000020E61000000100000005000000CCD4247843E959403C66A032FED94940CCD4247843E959401157CEDE19DF4940FFEC478AC8EE59401157CEDE19DF4940FFEC478AC8EE59403C66A032FED94940CCD4247843E959403C66A032FED94940
67964	3599	103.64474300000001	103.73099000000001	51.742977000000003	51.703069999999997	Кооперативный переулок	0103000020E61000000100000005000000CCD4247843E959403C66A032FED94940CCD4247843E959401157CEDE19DF4940FFEC478AC8EE59401157CEDE19DF4940FFEC478AC8EE59403C66A032FED94940CCD4247843E959403C66A032FED94940
67892	3599	103.64474300000001	103.73099000000001	51.742977000000003	51.703069999999997	Кирова	0103000020E61000000100000005000000CCD4247843E959403C66A032FED94940CCD4247843E959401157CEDE19DF4940FFEC478AC8EE59401157CEDE19DF4940FFEC478AC8EE59403C66A032FED94940CCD4247843E959403C66A032FED94940
69003	3971	103.422787	103.477998	51.748927000000002	51.735776999999999	Советская	0103000020E61000000100000005000000228B34F10EDB59401213D4F02DDE4940228B34F10EDB5940B30B06D7DCDF49406B63EC8497DE5940B30B06D7DCDF49406B63EC8497DE59401213D4F02DDE4940228B34F10EDB59401213D4F02DDE4940
67803	3244	104.117661	104.159774	51.527970000000003	51.499721000000001	микрорайон Южный 2 квартал	0103000020E61000000100000005000000F0C000C287075A40ED0F94DBF6BF4940F0C000C287075A4073A25D8594C349401230BABC390A5A4073A25D8594C349401230BABC390A5A40ED0F94DBF6BF4940F0C000C287075A40ED0F94DBF6BF4940
67015	3244	104.117661	104.159774	51.527970000000003	51.499721000000001	Школьный переулок	0103000020E61000000100000005000000F0C000C287075A40ED0F94DBF6BF4940F0C000C287075A4073A25D8594C349401230BABC390A5A4073A25D8594C349401230BABC390A5A40ED0F94DBF6BF4940F0C000C287075A40ED0F94DBF6BF4940
67890	3244	104.117661	104.159774	51.527970000000003	51.499721000000001	Гагарина	0103000020E61000000100000005000000F0C000C287075A40ED0F94DBF6BF4940F0C000C287075A4073A25D8594C349401230BABC390A5A4073A25D8594C349401230BABC390A5A40ED0F94DBF6BF4940F0C000C287075A40ED0F94DBF6BF4940
67814	3244	104.117661	104.159774	51.527970000000003	51.499721000000001	3 квартал	0103000020E61000000100000005000000F0C000C287075A40ED0F94DBF6BF4940F0C000C287075A4073A25D8594C349401230BABC390A5A4073A25D8594C349401230BABC390A5A40ED0F94DBF6BF4940F0C000C287075A40ED0F94DBF6BF4940
69574	59312	104.77565	104.81168099999999	51.881911000000002	51.870128999999999	Набережная	0103000020E610000001000000050000001DC9E53FA4315A408D26176360EF49401DC9E53FA4315A40C87DAB75E2F049403672DD94F2335A40C87DAB75E2F049403672DD94F2335A408D26176360EF49401DC9E53FA4315A408D26176360EF4940
69220	31692	104.24223000000001	104.256882	53.437989999999999	53.413029999999999	Шотойская	0103000020E610000001000000050000000C0742B2800F5A402922C32ADEB44A400C0742B2800F5A40CEFC6A0E10B84A40973B33C170105A40CEFC6A0E10B84A40973B33C170105A402922C32ADEB44A400C0742B2800F5A402922C32ADEB44A40
69219	31997	103.962001	103.987154	53.474604999999997	53.456535000000002	Центральная	0103000020E61000000100000005000000096EA46C91FD59405C3D27BD6FBA4A40096EA46C91FD594050C24CDBBFBC4A406687F8872DFF594050C24CDBBFBC4A406687F8872DFF59405C3D27BD6FBA4A40096EA46C91FD59405C3D27BD6FBA4A40
69082	32264	103.872663	103.88857299999999	53.411479	53.395206999999999	Озерная	0103000020E61000000100000005000000795BE9B5D9F759403C139A2496B24A40795BE9B5D9F75940D2FE0758ABB44A40F3C64961DEF85940D2FE0758ABB44A40F3C64961DEF859403C139A2496B24A40795BE9B5D9F759403C139A2496B24A40
69107	464	103.704589	103.73430500000001	53.710397999999998	53.693325000000002	Правая Хайга	0103000020E61000000100000005000000C40776FC17ED5940E63FA4DFBED84A40C40776FC17ED594068925852EEDA4A40841266DAFEEE594068925852EEDA4A40841266DAFEEE5940E63FA4DFBED84A40C40776FC17ED5940E63FA4DFBED84A40
68589	32375	103.610715	103.62948900000001	53.532440999999999	53.516398000000002	Ленина	0103000020E610000001000000050000004E0B5EF415E7594023DC645419C24A404E0B5EF415E759405706D50627C44A40460C3B8C49E859405706D50627C44A40460C3B8C49E8594023DC645419C24A404E0B5EF415E7594023DC645419C24A40
68588	709	103.571243	103.59715	53.708736000000002	53.688723000000003	Школьная	0103000020E6100000010000000500000069C4CC3E8FE459406380441328D84A4069C4CC3E8FE45940BABF7ADCB7DA4A409C33A2B437E65940BABF7ADCB7DA4A409C33A2B437E659406380441328D84A4069C4CC3E8FE459406380441328D84A40
68843	31907	103.978323	104.013205	53.358991000000003	53.337446	Школьная	0103000020E610000001000000050000002D7B12D89CFE59404015376E31AB4A402D7B12D89CFE59407847C66AF3AD4A4032C9C859D8005A407847C66AF3AD4A4032C9C859D8005A404015376E31AB4A402D7B12D89CFE59404015376E31AB4A40
69085	32431	103.430593	103.448497	53.568488000000002	53.552956000000002	Ленина	0103000020E61000000100000005000000BD38F1D58EDB594041102043C7C64A40BD38F1D58EDB59409015FC36C4C84A40AAD6C22CB4DC59409015FC36C4C84A40AAD6C22CB4DC594041102043C7C64A40BD38F1D58EDB594041102043C7C64A40
69409	31809	104.030884	104.043577	53.361350000000002	53.340791000000003	Ворошилова	0103000020E610000001000000050000000F7EE200FA015A40B5E21B0A9FAB4A400F7EE200FA015A406E3480B740AE4A40E6762FF7C9025A406E3480B740AE4A40E6762FF7C9025A40B5E21B0A9FAB4A400F7EE200FA015A40B5E21B0A9FAB4A40
67872	335	103.71491899999999	103.732275	53.591326000000002	53.575657999999997	Октябрьская	0103000020E610000001000000050000007F129F3BC1ED594023D74D29AFC94A407F129F3BC1ED594023A30392B0CB4A406B2BF697DDEE594023A30392B0CB4A406B2BF697DDEE594023D74D29AFC94A407F129F3BC1ED594023D74D29AFC94A40
67771	1070	103.855164	103.89228300000001	53.401826999999997	53.375878	Свердлова	0103000020E61000000100000005000000DC2DC901BBF6594098A432C51CB04A40DC2DC901BBF659402CD32F116FB34A40B7F1272A1BF959402CD32F116FB34A40B7F1272A1BF9594098A432C51CB04A40DC2DC901BBF6594098A432C51CB04A40
69083	31729	104.234622	104.26589199999999	53.395603999999999	53.384757	Онгосорская	0103000020E61000000100000005000000043BFE0B040F5A401BF4A5B73FB14A40043BFE0B040F5A405915E126A3B24A402711E15F04115A405915E126A3B24A402711E15F04115A401BF4A5B73FB14A40043BFE0B040F5A401BF4A5B73FB14A40
69414	31942	104.01872899999999	104.045086	53.518667999999998	53.497065999999997	Нагорная	0103000020E61000000100000005000000279F1EDB32015A400DFAD2DB9FBF4A40279F1EDB32015A40A9BD88B663C24A407AE063B0E2025A40A9BD88B663C24A407AE063B0E2025A400DFAD2DB9FBF4A40279F1EDB32015A400DFAD2DB9FBF4A40
68755	547	103.82567299999999	103.855524	53.728982999999999	53.713217	11 Комсомольцев	0103000020E610000001000000050000002C0C91D3D7F45940C2F9D4B14ADB4A402C0C91D3D7F45940842BA0504FDD4A405C3CBCE7C0F65940842BA0504FDD4A405C3CBCE7C0F65940C2F9D4B14ADB4A402C0C91D3D7F45940C2F9D4B14ADB4A40
69210	32029	103.34820000000001	104.755797	54.064895	53.229899000000003	Молодежная	0103000020E61000000100000005000000E71DA7E848D659400A3197546D9D4A40E71DA7E848D659404356B77A4E084B408E5A61FA5E305A404356B77A4E084B408E5A61FA5E305A400A3197546D9D4A40E71DA7E848D659400A3197546D9D4A40
69158	59217	103.34820000000001	104.755797	54.064895	53.229899000000003	Трактовая	0103000020E61000000100000005000000E71DA7E848D659400A3197546D9D4A40E71DA7E848D659404356B77A4E084B408E5A61FA5E305A404356B77A4E084B408E5A61FA5E305A400A3197546D9D4A40E71DA7E848D659400A3197546D9D4A40
68878	32086	103.894295	103.927083	53.376130000000003	53.361834000000002	Жданова	0103000020E610000001000000050000007C7E18213CF959405A4A969350AE4A407C7E18213CF95940B285200725B04A405D6BEF5355FB5940B285200725B04A405D6BEF5355FB59405A4A969350AE4A407C7E18213CF959405A4A969350AE4A40
69209	300	103.825187	103.85586499999999	53.640605000000001	53.626077000000002	Ленина	0103000020E61000000100000005000000668522DDCFF459408FE3874A23D04A40668522DDCFF45940B9533A58FFD14A40A032FE7DC6F65940B9533A58FFD14A40A032FE7DC6F659408FE3874A23D04A40668522DDCFF459408FE3874A23D04A40
68887	32480	103.791932	103.809494	53.443514999999998	53.426934000000003	Ленина	0103000020E61000000100000005000000FA298E03AFF2594076C6F7C5A5B64A40FA298E03AFF2594089247A19C5B84A40BA13ECBFCEF3594089247A19C5B84A40BA13ECBFCEF3594076C6F7C5A5B64A40FA298E03AFF2594076C6F7C5A5B64A40
69084	10	103.693899	103.712242	53.547942999999997	53.540452000000002	Хлебоприемная	0103000020E6100000010000000500000089EE59D768EC59406687F8872DC54A4089EE59D768EC59403B8908FF22C64A409C35785F95ED59403B8908FF22C64A409C35785F95ED59406687F8872DC54A4089EE59D768EC59406687F8872DC54A40
68898	59184	103.34820000000001	104.755797	54.064895	53.229899000000003	Павлова	0103000020E61000000100000005000000E71DA7E848D659400A3197546D9D4A40E71DA7E848D659404356B77A4E084B408E5A61FA5E305A404356B77A4E084B408E5A61FA5E305A400A3197546D9D4A40E71DA7E848D659400A3197546D9D4A40
69410	31858	104.039427	104.082357	53.331902999999997	53.313513	Гагарина	0103000020E6100000010000000500000015E5D2F885025A4078EFA83121A84A4015E5D2F885025A40DE3829CC7BAA4A4030664B5645055A40DE3829CC7BAA4A4030664B5645055A4078EFA83121A84A4015E5D2F885025A4078EFA83121A84A40
68934	592	103.92396599999999	103.946765	53.725957000000001	53.717022	Горхонская	0103000020E610000001000000050000006B274A4222FB59409A417C60C7DB4A406B274A4222FB5940B1A6B228ECDC4A40D6FF39CC97FC5940B1A6B228ECDC4A40D6FF39CC97FC59409A417C60C7DB4A406B274A4222FB59409A417C60C7DB4A40
69211	673	103.989355	104.00923400000001	53.723927000000003	53.717458999999998	Борохальская	0103000020E610000001000000050000009548A29751FF5940459C4EB2D5DB4A409548A29751FF594080D8D2A3A9DC4A40B900344A97005A4080D8D2A3A9DC4A40B900344A97005A40459C4EB2D5DB4A409548A29751FF5940459C4EB2D5DB4A40
68710	157	103.699001	103.737188	53.572263	53.557636000000002	Ленина	0103000020E61000000100000005000000C3B7B06EBCEC59404089CF9D60C74A40C3B7B06EBCEC5940FDDAFAE93FC94A403CC093162EEF5940FDDAFAE93FC94A403CC093162EEF59404089CF9D60C74A40C3B7B06EBCEC59404089CF9D60C74A40
69413	32342	103.34820000000001	104.755797	54.064895	53.229899000000003	Центральная	0103000020E61000000100000005000000E71DA7E848D659400A3197546D9D4A40E71DA7E848D659404356B77A4E084B408E5A61FA5E305A404356B77A4E084B408E5A61FA5E305A400A3197546D9D4A40E71DA7E848D659400A3197546D9D4A40
69102	31646	107.180108	107.18780599999999	53.140320000000003	53.136031000000003	Восточная	0103000020E61000000100000005000000DF6FB4E386CB5A40001FBC7669914A40DF6FB4E386CB5A40C47C7901F6914A4086FF740305CC5A40C47C7901F6914A4086FF740305CC5A40001FBC7669914A40DF6FB4E386CB5A40001FBC7669914A40
69206	31389	106.705061	106.723341	53.008592	52.996540000000003	50 лет Победы	0103000020E61000000100000005000000D82B2CB81FAD5A40F3936A9F8E7F4A40D82B2CB81FAD5A40ED80EB8A19814A40C8B60C384BAE5A40ED80EB8A19814A40C8B60C384BAE5A40F3936A9F8E7F4A40D82B2CB81FAD5A40F3936A9F8E7F4A40
69080	31295	106.458904	106.480024	52.811957999999997	52.805126000000001	Молодежная	0103000020E610000001000000050000003B00E2AE5E9D5A406494675E0E674A403B00E2AE5E9D5A40DFDC5F3DEE674A40E35295B6B89E5A40DFDC5F3DEE674A40E35295B6B89E5A406494675E0E674A403B00E2AE5E9D5A406494675E0E674A40
68553	31585	107.323272	107.363292	53.200172000000002	53.186976000000001	Советская	0103000020E610000001000000050000009AED0A7DB0D45A4086915ED4EE974A409AED0A7DB0D45A4097C9703C9F994A4080B9162D40D75A4097C9703C9F994A4080B9162D40D75A4086915ED4EE974A409AED0A7DB0D45A4086915ED4EE974A40
69208	31537	107.41257400000001	107.427162	53.226793999999998	53.215327000000002	Байкальская	0103000020E61000000100000005000000844BC79C67DA5A401079CBD58F9B4A40844BC79C67DA5A40EA76F695079D4A400306499F56DB5A40EA76F695079D4A400306499F56DB5A401079CBD58F9B4A40844BC79C67DA5A401079CBD58F9B4A40
69279	30426	106.49824099999999	106.506434	52.883414999999999	52.875034999999997	Лесная	0103000020E61000000100000005000000AF21382EE39F5A407CED992501704A40AF21382EE39F5A40DEE522BE13714A4047E5266A69A05A40DEE522BE13714A4047E5266A69A05A407CED992501704A40AF21382EE39F5A407CED992501704A40
69418	31134	106.214068	106.22976199999999	52.683954	52.667955999999997	Молодежная	0103000020E61000000100000005000000B0C7444AB38D5A405F950B957F554A40B0C7444AB38D5A40F4FBFECD8B574A4044F7AC6BB48E5A40F4FBFECD8B574A4044F7AC6BB48E5A405F950B957F554A40B0C7444AB38D5A405F950B957F554A40
69207	31439	106.88043	106.893249	53.018695999999998	53.014204999999997	Центральная	0103000020E61000000100000005000000B51A12F758B85A4047382D78D1814A40B51A12F758B85A4073486AA164824A40D28BDAFD2AB95A4073486AA164824A40D28BDAFD2AB95A4047382D78D1814A40B51A12F758B85A4047382D78D1814A40
69361	31181	106.354511	106.382943	52.763100000000001	52.754620000000003	Солнечная	0103000020E61000000100000005000000A0C4E74EB0965A402A745E6397604A40A0C4E74EB0965A40EFC9C342AD614A40DB4E5B2382985A40EFC9C342AD614A40DB4E5B2382985A402A745E6397604A40A0C4E74EB0965A402A745E6397604A40
69407	30908	105.804886	105.829616	52.623857000000001	52.610706999999998	Центральная	0103000020E6100000010000000500000087C0914083735A401938A0A52B4E4A4087C0914083735A40BA30D28BDA4F4A40410FB56D18755A40BA30D28BDA4F4A40410FB56D18755A401938A0A52B4E4A4087C0914083735A401938A0A52B4E4A40
69359	31106	106.191152	106.22747099999999	52.824365999999998	52.809857000000001	М. Копыловой	0103000020E61000000100000005000000292499D53B8C5A40E5B7E864A9674A40292499D53B8C5A4098F738D384694A40757286E28E8E5A4098F738D384694A40757286E28E8E5A40E5B7E864A9674A40292499D53B8C5A40E5B7E864A9674A40
69358	31049	106.071236	106.09134	52.851163	52.837826	Верховая	0103000020E61000000100000005000000109370218F845A4087DEE2E13D6B4A40109370218F845A405A48C0E8F26C4A404434BA83D8855A405A48C0E8F26C4A404434BA83D8855A4087DEE2E13D6B4A40109370218F845A4087DEE2E13D6B4A40
67870	31228	106.38228700000001	106.424463	52.811773000000002	52.788322999999998	Советская	0103000020E61000000100000005000000E7ABE46377985A40A1D79FC4E7644A40E7ABE46377985A404E637B2DE8674A402CD7DB662A9B5A404E637B2DE8674A402CD7DB662A9B5A40A1D79FC4E7644A40E7ABE46377985A40A1D79FC4E7644A40
68883	30940	106.057564	106.078728	52.554861000000002	52.534717999999998	Ленина	0103000020E61000000100000005000000535BEA20AF835A40904AB1A371444A40535BEA20AF835A40B6696CAF05474A40E3512AE109855A40B6696CAF05474A40E3512AE109855A40904AB1A371444A40535BEA20AF835A40904AB1A371444A40
69079	30999	105.984504	106.004321	52.782832999999997	52.769851000000003	Центральная	0103000020E61000000100000005000000FFB1101D027F5A407EE5417A8A624A40FFB1101D027F5A40629D2ADF33644A40E86B96CB46805A40629D2ADF33644A40E86B96CB46805A407EE5417A8A624A40FFB1101D027F5A407EE5417A8A624A40
69353	29574	102.560934	102.57737400000001	53.834271999999999	53.817525000000003	Юбилейная	0103000020E61000000100000005000000BA4DB857E6A35940CA54C1A8A4E84A40BA4DB857E6A35940F8FBC56CC9EA4A40E3E313B2F3A45940F8FBC56CC9EA4A40E3E313B2F3A45940CA54C1A8A4E84A40BA4DB857E6A35940CA54C1A8A4E84A40
69356	30541	102.98008799999999	102.999797	53.595275000000001	53.574860999999999	Коммунаров	0103000020E61000000100000005000000EECC04C3B9BE5940785F950B95C94A40EECC04C3B9BE59402E90A0F831CC4A40E4688EACFCBF59402E90A0F831CC4A40E4688EACFCBF5940785F950B95C94A40EECC04C3B9BE5940785F950B95C94A40
69406	29382	102.58049099999999	102.598754	53.646909000000001	53.635554999999997	Советская	0103000020E61000000100000005000000D427B9C326A5594096E7C1DD59D14A40D427B9C326A55940793E03EACDD24A4059164CFC51A65940793E03EACDD24A4059164CFC51A6594096E7C1DD59D14A40D427B9C326A5594096E7C1DD59D14A40
68831	29780	102.714466	102.737247	53.825817000000001	53.805695999999998	Центральная	0103000020E61000000100000005000000A7069ACFB9AD59404E42E90B21E74A40A7069ACFB9AD59408CBD175FB4E94A40BE840A0E2FAF59408CBD175FB4E94A40BE840A0E2FAF59404E42E90B21E74A40A7069ACFB9AD59404E42E90B21E74A40
69078	30337	102.92556999999999	102.938676	53.735753000000003	53.729004000000003	Школьная	0103000020E61000000100000005000000280AF4893CBB59409C53C90050DD4A40280AF4893CBB59408A7780272DDE4A409162804413BC59408A7780272DDE4A409162804413BC59409C53C90050DD4A40280AF4893CBB59409C53C90050DD4A40
68776	30078	103.286216	103.30680599999999	53.559637000000002	53.547685999999999	Административная	0103000020E61000000100000005000000E2E5E95C51D25940103D29931AC64A40E2E5E95C51D25940D7506A2FA2C74A40DC0DA2B5A2D35940D7506A2FA2C74A40DC0DA2B5A2D35940103D29931AC64A40E2E5E95C51D25940103D29931AC64A40
69404	29441	102.583518	102.59972399999999	53.654445000000003	53.644117999999999	Школьная	0103000020E6100000010000000500000026A8E15B58A55940E961687572D24A4026A8E15B58A55940EF0390DAC4D34A4015A8C5E061A65940EF0390DAC4D34A4015A8C5E061A65940E961687572D24A4026A8E15B58A55940E961687572D24A40
69069	29658	102.584632	102.60073	53.780670999999998	53.761066	Нагорная	0103000020E610000001000000050000007C0C569C6AA559407C0C569C6AE14A407C0C569C6AA55940C2F7FE06EDE34A4078EE3D5C72A65940C2F7FE06EDE34A4078EE3D5C72A659407C0C569C6AE14A407C0C569C6AA559407C0C569C6AE14A40
69393	26776	103.021141	103.032685	53.790007000000003	53.782947999999998	пер. Школьный	0103000020E61000000100000005000000B4E6C75F5AC15940FB3BDBA337E44A40B4E6C75F5AC15940384E0AF31EE54A407784D38217C25940384E0AF31EE54A407784D38217C25940FB3BDBA337E44A40B4E6C75F5AC15940FB3BDBA337E44A40
68581	22824	103.22752	103.249134	53.767698000000003	53.752485	Ленина	0103000020E61000000100000005000000E6CB0BB08FCE594083DDB06D51E04A40E6CB0BB08FCE5940319A95ED43E24A409694BBCFF1CF5940319A95ED43E24A409694BBCFF1CF594083DDB06D51E04A40E6CB0BB08FCE594083DDB06D51E04A40
69163	30283	102.79473	102.813029	53.727758000000001	53.713324	Октябрьская	0103000020E610000001000000050000009BC937DBDCB25940D8B969334EDB4A409BC937DBDCB2594081B3942C27DD4A40C66CC9AA08B4594081B3942C27DD4A40C66CC9AA08B45940D8B969334EDB4A409BC937DBDCB25940D8B969334EDB4A40
68773	30634	102.67395999999999	102.72883899999999	53.710537000000002	53.688510000000001	Шолохова	0103000020E61000000100000005000000FAB31F2922AB5940077C7E1821D84A40FAB31F2922AB59408ACC5CE0F2DA4A402843554CA5AE59408ACC5CE0F2DA4A402843554CA5AE5940077C7E1821D84A40FAB31F2922AB5940077C7E1821D84A40
68584	30634	102.67395999999999	102.72883899999999	53.710537000000002	53.688510000000001	Чехова	0103000020E61000000100000005000000FAB31F2922AB5940077C7E1821D84A40FAB31F2922AB59408ACC5CE0F2DA4A402843554CA5AE59408ACC5CE0F2DA4A402843554CA5AE5940077C7E1821D84A40FAB31F2922AB5940077C7E1821D84A40
68541	30634	102.67395999999999	102.72883899999999	53.710537000000002	53.688510000000001	Ленина	0103000020E61000000100000005000000FAB31F2922AB5940077C7E1821D84A40FAB31F2922AB59408ACC5CE0F2DA4A402843554CA5AE59408ACC5CE0F2DA4A402843554CA5AE5940077C7E1821D84A40FAB31F2922AB5940077C7E1821D84A40
68881	30634	102.67395999999999	102.72883899999999	53.710537000000002	53.688510000000001	Ербанова	0103000020E61000000100000005000000FAB31F2922AB5940077C7E1821D84A40FAB31F2922AB59408ACC5CE0F2DA4A402843554CA5AE59408ACC5CE0F2DA4A402843554CA5AE5940077C7E1821D84A40FAB31F2922AB5940077C7E1821D84A40
68728	424	102.819047	102.849096	53.820597999999997	53.798470000000002	школьная	0103000020E61000000100000005000000C3B81B446BB45940276BD44334E64A40C3B81B446BB45940DD94F25A09E94A4086CABF9657B65940DD94F25A09E94A4086CABF9657B65940276BD44334E64A40C3B81B446BB45940276BD44334E64A40
68774	424	102.819047	102.849096	53.820597999999997	53.798470000000002	Мира	0103000020E61000000100000005000000C3B81B446BB45940276BD44334E64A40C3B81B446BB45940DD94F25A09E94A4086CABF9657B65940DD94F25A09E94A4086CABF9657B65940276BD44334E64A40C3B81B446BB45940276BD44334E64A40
69199	29531	102.625703	102.637794	53.664178	53.657758999999999	Школьная	0103000020E61000000100000005000000958098840BA8594028D3687231D44A40958098840BA85940815CE2C803D54A4071E5EC9DD1A85940815CE2C803D54A4071E5EC9DD1A8594028D3687231D44A40958098840BA8594028D3687231D44A40
69076	30136	103.258368	103.274376	53.665126999999998	53.652700000000003	Школьный переулок	0103000020E610000001000000050000004F95EF1989D05940B30C71AC8BD34A404F95EF1989D05940E257ACE122D54A40ABB35A608FD15940E257ACE122D54A40ABB35A608FD15940B30C71AC8BD34A404F95EF1989D05940B30C71AC8BD34A40
69203	30136	102.33099300000001	103.377099	54.072498000000003	53.443396999999997	Центральная	0103000020E610000001000000050000001E8D43FD2E9559407F129F3BC1B84A401E8D43FD2E95594041834D9D47094B40AD16D86322D8594041834D9D47094B40AD16D86322D859407F129F3BC1B84A401E8D43FD2E9559407F129F3BC1B84A40
69521	59275	102.817898	102.847371	53.570450000000001	53.562021999999999	Лесная	0103000020E61000000100000005000000AF5DDA7058B45940F6D03E56F0C74A40AF5DDA7058B4594069006F8104C94A400B2593533BB6594069006F8104C94A400B2593533BB65940F6D03E56F0C74A40AF5DDA7058B45940F6D03E56F0C74A40
69403	29624	102.458787	102.482727	53.828459000000002	53.799757	пер. Школьный	0103000020E610000001000000050000001E3526C45C9D5940A0DFF76F5EE64A401E3526C45C9D5940D789CBF10AEA4A405B79C9FFE49E5940D789CBF10AEA4A405B79C9FFE49E5940A0DFF76F5EE64A401E3526C45C9D5940A0DFF76F5EE64A40
69097	30590	102.33099300000001	103.377099	54.072498000000003	53.443396999999997	Школьная	0103000020E610000001000000050000001E8D43FD2E9559407F129F3BC1B84A401E8D43FD2E95594041834D9D47094B40AD16D86322D8594041834D9D47094B40AD16D86322D859407F129F3BC1B84A401E8D43FD2E9559407F129F3BC1B84A40
69408	29927	102.86539999999999	102.889628	54.032696999999999	54.024515000000001	Центральная	0103000020E61000000100000005000000567DAEB662B7594077A1B94E23034B40567DAEB662B75940B2D6506A2F044B40C76647AAEFB85940B2D6506A2F044B40C76647AAEFB8594077A1B94E23034B40567DAEB662B7594077A1B94E23034B40
69355	30007	102.921976	102.93608	53.845615000000002	53.834957000000003	Школьная	0103000020E610000001000000050000009AEC9FA701BB59407C48F8DEDFEA4A409AEC9FA701BB5940E700C11C3DEC4A40249C16BCE8BB5940E700C11C3DEC4A40249C16BCE8BB59407C48F8DEDFEA4A409AEC9FA701BB59407C48F8DEDFEA4A40
69362	30849	102.66880399999999	102.680024	53.685631000000001	53.679834	Советская	0103000020E61000000100000005000000C6DB4AAFCDAA5940BC5AEECC04D74A40C6DB4AAFCDAA5940D80FB1C1C2D74A40B01F628385AB5940D80FB1C1C2D74A40B01F628385AB5940BC5AEECC04D74A40C6DB4AAFCDAA5940BC5AEECC04D74A40
68715	30190	103.01032600000001	103.039242	53.699204999999999	53.681550999999999	Имегенова	0103000020E610000001000000050000001B13622EA9C059402EC72B103DD74A401B13622EA9C059408F19A88C7FD94A404CA8E0F082C259408F19A88C7FD94A404CA8E0F082C259402EC72B103DD74A401B13622EA9C059402EC72B103DD74A40
68931	59194	102.33099300000001	103.377099	54.072498000000003	53.443396999999997	Школьная	0103000020E610000001000000050000001E8D43FD2E9559407F129F3BC1B84A401E8D43FD2E95594041834D9D47094B40AD16D86322D8594041834D9D47094B40AD16D86322D859407F129F3BC1B84A401E8D43FD2E9559407F129F3BC1B84A40
69072	30058	103.039458	103.050408	53.878686000000002	53.867829999999998	Школьная	0103000020E6100000010000000500000032E4D87A86C259406C3EAE0D15EF4A4032E4D87A86C25940FEB968C878F04A403CDD79E239C35940FEB968C878F04A403CDD79E239C359406C3EAE0D15EF4A4032E4D87A86C259406C3EAE0D15EF4A40
69077	30382	102.82521	102.84045399999999	53.667085	53.655459	Школьная	0103000020E6100000010000000500000042959A3DD0B45940376F9C14E6D34A4042959A3DD0B459407A53910A63D54A40B6F292FFC9B559407A53910A63D54A40B6F292FFC9B55940376F9C14E6D34A4042959A3DD0B45940376F9C14E6D34A40
69201	29849	102.63421	102.651161	53.908113	53.887942000000002	Центральная	0103000020E61000000100000005000000F4328AE596A85940575F5D15A8F14A40F4328AE596A859404609FA0B3DF44A4090DB2F9FACA959404609FA0B3DF44A4090DB2F9FACA95940575F5D15A8F14A40F4328AE596A85940575F5D15A8F14A40
69081	29794	102.569019	102.59013899999999	53.907741999999999	53.895249	Лесная	0103000020E610000001000000050000005EF3AACE6AA459406B63EC8497F24A405EF3AACE6AA45940529ACDE330F44A4006465ED6C4A55940529ACDE330F44A4006465ED6C4A559406B63EC8497F24A405EF3AACE6AA459406B63EC8497F24A40
69245	30496	102.89455100000001	102.933511	53.487915999999998	53.472391999999999	Комсомольская	0103000020E61000000100000005000000AA66D65240B959402E724F5777BC4A40AA66D65240B95940FA980F0874BE4A4033DDEBA4BEBB5940FA980F0874BE4A4033DDEBA4BEBB59402E724F5777BC4A40AA66D65240B959402E724F5777BC4A40
69138	59214	99.777441999999994	99.909242000000006	54.663916999999998	54.587443	Привокзальная	0103000020E610000001000000050000005B22179CC1F15840CFA10C55314B4B405B22179CC1F158401421753BFB544B4094895B0531FA58401421753BFB544B4094895B0531FA5840CFA10C55314B4B405B22179CC1F15840CFA10C55314B4B40
68242	26992	99.110245000000006	99.154352000000003	54.848359000000002	54.815404000000001	Советская	0103000020E610000001000000050000000B630B410EC75840888384285F684B400B630B410EC7584036221807976C4B409F0436E7E0C9584036221807976C4B409F0436E7E0C95840888384285F684B400B630B410EC75840888384285F684B40
69287	27262	99.119291000000004	99.142781999999997	54.817743999999998	54.799750000000003	Нагорная	0103000020E6100000010000000500000042EDB776A2C75840EE7C3F355E664B4042EDB776A2C758400740DCD5AB684B40471D1D5723C958400740DCD5AB684B40471D1D5723C95840EE7C3F355E664B4042EDB776A2C75840EE7C3F355E664B40
68592	28023	99.868162999999996	99.912315000000007	54.646957999999998	54.632244	Трактовая	0103000020E6100000010000000500000039268BFB8FF75840CE8B135FED504B4039268BFB8FF758405AF10D85CF524B409E29745E63FA58405AF10D85CF524B409E29745E63FA5840CE8B135FED504B4039268BFB8FF75840CE8B135FED504B40
69048	27359	99.022919999999999	99.040563000000006	54.820483000000003	54.809479000000003	Школьная	0103000020E61000000100000005000000289B728577C158403FE603029D674B40289B728577C1584045F6419605694B405F9B8D9598C2584045F6419605694B405F9B8D9598C258403FE603029D674B40289B728577C158403FE603029D674B40
69065	27570	99.070656	99.092996999999997	54.656813	54.646394999999998	Центральная	0103000020E610000001000000050000000951BEA085C4584022A64412BD524B400951BEA085C45840384BC97212544B401268B0A9F3C55840384BC97212544B401268B0A9F3C5584022A64412BD524B400951BEA085C4584022A64412BD524B40
68698	28264	99.611639999999994	99.654920000000004	54.721702000000001	54.692509999999999	Школьная	0103000020E610000001000000050000003A3B191C25E758409413ED2AA4584B403A3B191C25E7584099BA2BBB605C4B40C45F9335EAE9584099BA2BBB605C4B40C45F9335EAE958409413ED2AA4584B403A3B191C25E758409413ED2AA4584B40
68822	28264	99.611639999999994	99.654920000000004	54.721702000000001	54.692509999999999	Московская	0103000020E610000001000000050000003A3B191C25E758409413ED2AA4584B403A3B191C25E7584099BA2BBB605C4B40C45F9335EAE9584099BA2BBB605C4B40C45F9335EAE958409413ED2AA4584B403A3B191C25E758409413ED2AA4584B40
69036	26484	99.425580999999994	99.439639	55.154043999999999	55.143106000000003	переулок Школьный	0103000020E61000000100000005000000223317B83CDB584042EE224C51924B40223317B83CDB58409012BBB6B7934B40F4C29D0B23DC58409012BBB6B7934B40F4C29D0B23DC584042EE224C51924B40223317B83CDB584042EE224C51924B40
69290	27924	99.677711000000002	99.697213000000005	54.307589	54.297548999999997	Первомайская	0103000020E61000000100000005000000ED48F59D5FEB58408FFAEB1516264B40ED48F59D5FEB5840FFCD8B135F274B40265646239FEC5840FFCD8B135F274B40265646239FEC58408FFAEB1516264B40ED48F59D5FEB58408FFAEB1516264B40
69400	26708	99.254774999999995	99.277574000000001	55.064700000000002	55.058625999999997	Центральная	0103000020E61000000100000005000000A835CD3B4ED05840FF58880E81874B40A835CD3B4ED058408E06F01648884B40130EBDC5C3D158408E06F01648884B40130EBDC5C3D15840FF58880E81874B40A835CD3B4ED05840FF58880E81874B40
68451	59146	95.655395999999996	100.205399	55.952500000000001	52.970999999999997	40 лет Победы	0103000020E61000000100000005000000787B1002F2E957403F355EBA497C4A40787B1002F2E9574052B81E85EBF94B4064E8D841250D594052B81E85EBF94B4064E8D841250D59403F355EBA497C4A40787B1002F2E957403F355EBA497C4A40
69291	27412	98.942555999999996	98.965113000000002	54.870092999999997	54.864325999999998	Мира	0103000020E6100000010000000500000082A966D652BC58408F8AFF3BA26E4B4082A966D652BC584040BD19355F6F4B4072FC5069C4BD584040BD19355F6F4B4072FC5069C4BD58408F8AFF3BA26E4B4082A966D652BC58408F8AFF3BA26E4B40
69399	28357	99.709242000000003	99.734233000000003	54.634875000000001	54.622543999999998	Центральная	0103000020E61000000100000005000000C7BC8E3864ED584017299485AF4F4B40C7BC8E3864ED58402506819543514B4037A968ACFDEE58402506819543514B4037A968ACFDEE584017299485AF4F4B40C7BC8E3864ED584017299485AF4F4B40
69075	59210	98.990778000000006	99.003497999999993	55.658026999999997	55.652075000000004	Почтовая	0103000020E610000001000000050000002AE620E868BF584005C58F3177D34B402AE620E868BF584047718E3A3AD44B407DE6AC4F39C0584047718E3A3AD44B407DE6AC4F39C0584005C58F3177D34B402AE620E868BF584005C58F3177D34B40
69198	28849	98.591027999999994	98.609695000000002	55.604498	55.589295	Кирова	0103000020E610000001000000050000004CC11A67D3A558402159C0046ECB4B404CC11A67D3A55840AB3FC23060CD4B4039622D3E05A75840AB3FC23060CD4B4039622D3E05A758402159C0046ECB4B404CC11A67D3A558402159C0046ECB4B40
69063	27447	99.180977999999996	99.200624000000005	54.676099999999998	54.661906000000002	Школьная	0103000020E61000000100000005000000E9D2BF2495CB58405A83F755B9544B40E9D2BF2495CB5840AD69DE718A564B40BCB20B06D7CC5840AD69DE718A564B40BCB20B06D7CC58405A83F755B9544B40E9D2BF2495CB58405A83F755B9544B40
69394	27124	99.083026000000004	99.095989000000003	54.873942	54.861829	Береговая	0103000020E61000000100000005000000EFAD484C50C5584048DFA469506E4B40EFAD484C50C55840E84CDA54DD6F4B40A6F10BAF24C65840E84CDA54DD6F4B40A6F10BAF24C6584048DFA469506E4B40EFAD484C50C5584048DFA469506E4B40
69315	27665	99.254909999999995	99.269336999999993	54.573076999999998	54.549961000000003	Центральная	0103000020E61000000100000005000000185B087250D05840A9893E1F65464B40185B087250D058407E8B4E965A494B4093A641D13CD158407E8B4E965A494B4093A641D13CD15840A9893E1F65464B40185B087250D05840A9893E1F65464B40
69067	27645	99.242036999999996	99.266157000000007	54.566104000000003	54.539541999999997	Новая	0103000020E6100000010000000500000001DBC1887DCF5840C26856B60F454B4001DBC1887DCF584041118B1876484B407FA65EB708D1584041118B1876484B407FA65EB708D15840C26856B60F454B4001DBC1887DCF5840C26856B60F454B40
69283	27079	98.985388	98.999851000000007	54.860362000000002	54.853282999999998	Просвещения	0103000020E61000000100000005000000BC77D49810BF5840CB9D9960386D4B40BC77D49810BF58404F5C8E57206E4B40DE770C8FFDBF58404F5C8E57206E4B40DE770C8FFDBF5840CB9D9960386D4B40BC77D49810BF5840CB9D9960386D4B40
69354	28753	95.655395999999996	100.205399	55.952500000000001	52.970999999999997	Центральная	0103000020E61000000100000005000000787B1002F2E957403F355EBA497C4A40787B1002F2E9574052B81E85EBF94B4064E8D841250D594052B81E85EBF94B4064E8D841250D59403F355EBA497C4A40787B1002F2E957403F355EBA497C4A40
69452	1192	99.557822000000002	99.587457000000001	54.318854999999999	54.308129999999998	Центральная	0103000020E6100000010000000500000051BF0B5BB3E358404F75C8CD70274B4051BF0B5BB3E3584042959A3DD0284B409AB33EE598E5584042959A3DD0284B409AB33EE598E558404F75C8CD70274B4051BF0B5BB3E358404F75C8CD70274B40
69402	28914	98.661023999999998	98.680446000000003	55.670985999999999	55.663404999999997	Школьная	0103000020E61000000100000005000000C0779B374EAA58405E807D74EAD44B40C0779B374EAA5840740987DEE2D54B406B2C616D8CAB5840740987DEE2D54B406B2C616D8CAB58405E807D74EAD44B40C0779B374EAA58405E807D74EAD44B40
69351	28645	95.655395999999996	100.205399	55.952500000000001	52.970999999999997	Шевченко	0103000020E61000000100000005000000787B1002F2E957403F355EBA497C4A40787B1002F2E9574052B81E85EBF94B4064E8D841250D594052B81E85EBF94B4064E8D841250D59403F355EBA497C4A40787B1002F2E957403F355EBA497C4A40
69269	59125	95.655395999999996	100.205399	55.952500000000001	52.970999999999997	Центральная	0103000020E61000000100000005000000787B1002F2E957403F355EBA497C4A40787B1002F2E9574052B81E85EBF94B4064E8D841250D594052B81E85EBF94B4064E8D841250D59403F355EBA497C4A40787B1002F2E957403F355EBA497C4A40
67952	27052	99.058043999999995	99.092988000000005	54.867621999999997	54.838996999999999	Ленина	0103000020E61000000100000005000000A86E2EFEB6C358409738F240646B4B40A86E2EFEB6C3584022A5D93C0E6F4B40E9BAF083F3C5584022A5D93C0E6F4B40E9BAF083F3C558409738F240646B4B40A86E2EFEB6C358409738F240646B4B40
69187	28016	99.831367999999998	99.851292000000001	54.604176000000002	54.594276999999998	Клубная	0103000020E6100000010000000500000038BC202235F55840EBE1CB44114C4B4038BC202235F558409983A0A3554D4B402CD670917BF658409983A0A3554D4B402CD670917BF65840EBE1CB44114C4B4038BC202235F55840EBE1CB44114C4B40
69352	28660	98.841307	98.850075000000004	55.003926	54.996521000000001	Московская	0103000020E6100000010000000500000056B950F9D7B558407C6308008E7F4B4056B950F9D7B5584053CDACA580804B406C09F9A067B6584053CDACA580804B406C09F9A067B658407C6308008E7F4B4056B950F9D7B558407C6308008E7F4B40
69128	27290	99.005887999999999	99.019991000000005	54.831539999999997	54.824066999999999	Школьная	0103000020E6100000010000000500000016DC0F7860C058403E5B07077B694B4016DC0F7860C058406DA818E76F6A4B40B8CD548847C158406DA818E76F6A4B40B8CD548847C158403E5B07077B694B4016DC0F7860C058403E5B07077B694B40
69325	26569	99.474547999999999	99.488696000000004	55.049931000000001	55.040193000000002	Просвещения	0103000020E61000000100000005000000761893FE5EDE58409A43520B25854B40761893FE5EDE58403E07962364864B40E86B96CB46DF58403E07962364864B40E86B96CB46DF58409A43520B25854B40761893FE5EDE58409A43520B25854B40
69396	27501	99.186718999999997	99.196331000000001	54.643098000000002	54.633353999999997	Центральная	0103000020E61000000100000005000000ADA23F34F3CB584038656EBE11514B40ADA23F34F3CB5840BF0F070951524B40390CE6AF90CC5840BF0F070951524B40390CE6AF90CC584038656EBE11514B40ADA23F34F3CB584038656EBE11514B40
69579	59317	98.932235000000006	98.968670000000003	54.964033999999998	54.934049999999999	Мира	0103000020E61000000100000005000000F14BFDBCA9BB5840166A4DF38E774B40F14BFDBCA9BB5840B41D5377657B4B4072A774B0FEBD5840B41D5377657B4B4072A774B0FEBD5840166A4DF38E774B40F14BFDBCA9BB5840166A4DF38E774B40
69066	27593	99.288713000000001	99.321178000000003	54.634453000000001	54.622846000000003	Школьная	0103000020E61000000100000005000000863B17467AD25840E338F06AB94F4B40863B17467AD25840AFEC82C135514B40768C2B2E8ED45840AFEC82C135514B40768C2B2E8ED45840E338F06AB94F4B40863B17467AD25840E338F06AB94F4B40
69323	28974	99.100713999999996	99.111215000000001	55.669285000000002	55.663837000000001	Катарминская	0103000020E61000000100000005000000F50F221972C65840F86F5E9CF8D44B40F50F221972C65840085A8121ABD54B40C7F484251EC75840085A8121ABD54B40C7F484251EC75840F86F5E9CF8D44B40F50F221972C65840F86F5E9CF8D44B40
68963	27810	99.669329000000005	99.691760000000002	54.382508000000001	54.347361999999997	Советская	0103000020E61000000100000005000000EC504D49D6EA5840C3EFA65B762C4B40EC504D49D6EA5840AC3AAB05F6304B40952BBCCB45EC5840AC3AAB05F6304B40952BBCCB45EC5840C3EFA65B762C4B40EC504D49D6EA5840C3EFA65B762C4B40
68692	26940	98.787929000000005	98.802499999999995	55.217249000000002	55.190719000000001	Мира	0103000020E610000001000000050000007BA4C16D6DB25840E8DCED7A69984B407BA4C16D6DB258405B0BB3D0CE9B4B408FC2F5285CB358405B0BB3D0CE9B4B408FC2F5285CB35840E8DCED7A69984B407BA4C16D6DB25840E8DCED7A69984B40
69071	28575	98.817035000000004	98.834299999999999	54.938405000000003	54.92747	Садовая	0103000020E61000000100000005000000FE2B2B4D4AB45840B4024356B7764B40FE2B2B4D4AB4584092B3B0A71D784B4061C3D32B65B5584092B3B0A71D784B4061C3D32B65B55840B4024356B7764B40FE2B2B4D4AB45840B4024356B7764B40
69411	28381	99.483189999999993	99.537385	54.751595999999999	54.739429999999999	Дорожная	0103000020E6100000010000000500000045F0BF95ECDE584034D769A4A55E4B4045F0BF95ECDE5840F7E6374C34604B401A170E8464E25840F7E6374C34604B401A170E8464E2584034D769A4A55E4B4045F0BF95ECDE584034D769A4A55E4B40
69293	27953	99.986003999999994	100.012809	54.564872000000001	54.553386000000003	Клубная	0103000020E61000000100000005000000696E85B01AFF58403A083A5AD5464B40696E85B01AFF58408B36C7B94D484B400C06D7DCD10059408B36C7B94D484B400C06D7DCD10059403A083A5AD5464B40696E85B01AFF58403A083A5AD5464B40
68884	28717	98.626133999999993	98.660414000000003	55.376969000000003	55.361297999999998	Школьная	0103000020E61000000100000005000000793A579412A858401B0E4B033FAE4B40793A579412A858408C4D2B8540B04B4084F4143944AA58408C4D2B8540B04B4084F4143944AA58401B0E4B033FAE4B40793A579412A858401B0E4B033FAE4B40
69217	59225	98.675657999999999	98.685153	55.301172000000001	55.297055999999998	Школьная	0103000020E61000000100000005000000F8510DFB3DAB5840508A56EE05A64B40F8510DFB3DAB5840473CD9CD8CA64B4067F0F78BD9AB5840473CD9CD8CA64B4067F0F78BD9AB5840508A56EE05A64B40F8510DFB3DAB5840508A56EE05A64B40
69453	28137	99.870220000000003	99.912979000000007	54.759711000000003	54.743380000000002	Советская	0103000020E61000000100000005000000CF143AAFB1F7584010406A13275F4B40CF143AAFB1F75840ABB4C5353E614B40D4BB783F6EFA5840ABB4C5353E614B40D4BB783F6EFA584010406A13275F4B40CF143AAFB1F7584010406A13275F4B40
68704	27189	99.09863	99.109769	54.900798000000002	54.886325999999997	Транспортная	0103000020E61000000100000005000000E31934F44FC6584018CC5F2173714B40E31934F44FC65840AF264F594D734B4056478E7406C75840AF264F594D734B4056478E7406C7584018CC5F2173714B40E31934F44FC6584018CC5F2173714B40
69039	26920	99.028848999999994	99.041353000000001	55.050164000000002	55.044603000000002	Молодежная	0103000020E610000001000000050000006DE179A9D8C15840D926158DB5854B406DE179A9D8C15840E1B721C66B864B40DBA50D87A5C25840E1B721C66B864B40DBA50D87A5C25840D926158DB5854B406DE179A9D8C15840D926158DB5854B40
69204	28217	99.804382000000004	99.828734999999995	54.633156	54.623654000000002	Школьная	0103000020E610000001000000050000006EDFA3FE7AF358408202EFE4D34F4B406EDFA3FE7AF3584012A27C410B514B403C8386FE09F5584012A27C410B514B403C8386FE09F558408202EFE4D34F4B406EDFA3FE7AF358408202EFE4D34F4B40
69118	28090	99.884674000000004	99.910589999999999	54.697625000000002	54.688571000000003	Советская	0103000020E61000000100000005000000C767B27F9EF85840ADFC321823584B40C767B27F9EF858409EEFA7C64B594B402384471B47FA58409EEFA7C64B594B402384471B47FA5840ADFC321823584B40C767B27F9EF85840ADFC321823584B40
68241	26414	99.331795999999997	99.400588999999997	55.115779000000003	55.091298999999999	переулок Клубный	0103000020E61000000100000005000000643C4A253CD55840299485AFAF8B4B40643C4A253CD558402448A5D8D18E4B40CA880B40A3D958402448A5D8D18E4B40CA880B40A3D95840299485AFAF8B4B40643C4A253CD55840299485AFAF8B4B40
68609	26096	98.634029999999996	98.690920000000006	55.583545999999998	55.527830000000002	Рабочая	0103000020E61000000100000005000000B4AB90F293A8584081ECF5EE8FC34B40B4AB90F293A8584016DBA4A2B1CA4B40C009850838AC584016DBA4A2B1CA4B40C009850838AC584081ECF5EE8FC34B40B4AB90F293A8584081ECF5EE8FC34B40
68844	26096	98.634029999999996	98.690920000000006	55.583545999999998	55.527830000000002	Первомайская	0103000020E61000000100000005000000B4AB90F293A8584081ECF5EE8FC34B40B4AB90F293A8584016DBA4A2B1CA4B40C009850838AC584016DBA4A2B1CA4B40C009850838AC584081ECF5EE8FC34B40B4AB90F293A8584081ECF5EE8FC34B40
68880	26096	98.634029999999996	98.690920000000006	55.583545999999998	55.527830000000002	Некрасова	0103000020E61000000100000005000000B4AB90F293A8584081ECF5EE8FC34B40B4AB90F293A8584016DBA4A2B1CA4B40C009850838AC584016DBA4A2B1CA4B40C009850838AC584081ECF5EE8FC34B40B4AB90F293A8584081ECF5EE8FC34B40
68696	26096	98.634029999999996	98.690920000000006	55.583545999999998	55.527830000000002	Линейная	0103000020E61000000100000005000000B4AB90F293A8584081ECF5EE8FC34B40B4AB90F293A8584016DBA4A2B1CA4B40C009850838AC584016DBA4A2B1CA4B40C009850838AC584081ECF5EE8FC34B40B4AB90F293A8584081ECF5EE8FC34B40
68587	26096	98.634029999999996	98.690920000000006	55.583545999999998	55.527830000000002	Комсомольская	0103000020E61000000100000005000000B4AB90F293A8584081ECF5EE8FC34B40B4AB90F293A8584016DBA4A2B1CA4B40C009850838AC584016DBA4A2B1CA4B40C009850838AC584081ECF5EE8FC34B40B4AB90F293A8584081ECF5EE8FC34B40
68775	26096	98.634029999999996	98.690920000000006	55.583545999999998	55.527830000000002	Вокзальная	0103000020E61000000100000005000000B4AB90F293A8584081ECF5EE8FC34B40B4AB90F293A8584016DBA4A2B1CA4B40C009850838AC584016DBA4A2B1CA4B40C009850838AC584081ECF5EE8FC34B40B4AB90F293A8584081ECF5EE8FC34B40
69046	27203	99.098100000000002	99.120170999999999	54.749755999999998	54.738577999999997	Центральная	0103000020E6100000010000000500000035EF384547C65840C5C551B9895E4B4035EF384547C6584069FD2D01F85F4B405EBBB4E1B0C7584069FD2D01F85F4B405EBBB4E1B0C75840C5C551B9895E4B4035EF384547C65840C5C551B9895E4B40
68873	24758	103.64238	103.65190200000001	57.087335000000003	57.079816999999998	мкр. Космонавтов	0103000020E61000000100000005000000B0E600C11CE9594019558671378A4C40B0E600C11CE95940E96514CB2D8B4C409C8C2AC3B8E95940E96514CB2D8B4C409C8C2AC3B8E9594019558671378A4C40B0E600C11CE9594019558671378A4C40
68742	24146	103.949119	103.97305900000001	56.500463000000003	56.473917999999998	Ленина	0103000020E61000000100000005000000C8409E5DBEFC59402C7E5358A93C4C40C8409E5DBEFC5940D5EDEC2B0F404C400685419946FE5940D5EDEC2B0F404C400685419946FE59402C7E5358A93C4C40C8409E5DBEFC59402C7E5358A93C4C40
69401	59256	103.636685	103.646171	56.416744000000001	56.413024999999998	Железнодорожная	0103000020E61000000100000005000000A4367172BFE8594017B7D100DE344C40A4367172BFE85940F1660DDE57354C40E9279CDD5AE95940F1660DDE57354C40E9279CDD5AE9594017B7D100DE344C40A4367172BFE8594017B7D100DE344C40
69282	24544	103.105538	103.119399	56.389015000000001	56.371865	Ленина	0103000020E610000001000000050000000E9F7422C1C6594076C3B645992F4C400E9F7422C1C65940A453573ECB314C40350BB43BA4C75940A453573ECB314C40350BB43BA4C7594076C3B645992F4C400E9F7422C1C6594076C3B645992F4C40
69117	24354	104.23965200000001	104.28278899999999	56.713064000000003	56.698334000000003	Трактовая	0103000020E61000000100000005000000F29A5775560F5A40AAD72D0263594C40F29A5775560F5A403CFA5FAE455B4C40C9AA083719125A403CFA5FAE455B4C40C9AA083719125A40AAD72D0263594C40F29A5775560F5A40AAD72D0263594C40
67800	24354	104.23965200000001	104.28278899999999	56.713064000000003	56.698334000000003	Калинина	0103000020E61000000100000005000000F29A5775560F5A40AAD72D0263594C40F29A5775560F5A403CFA5FAE455B4C40C9AA083719125A403CFA5FAE455B4C40C9AA083719125A40AAD72D0263594C40F29A5775560F5A40AAD72D0263594C40
68766	24236	103.93239199999999	103.954195	56.506751999999999	56.492531999999997	Зеленая	0103000020E6100000010000000500000054C37E4FACFB5940E21DE0490B3F4C4054C37E4FACFB59405F97E13FDD404C406EC0E78711FD59405F97E13FDD404C406EC0E78711FD5940E21DE0490B3F4C4054C37E4FACFB5940E21DE0490B3F4C40
68869	23980	103.44529900000001	103.464433	56.467896000000003	56.459104000000004	Школьная	0103000020E61000000100000005000000427C60C77FDC59403DBB7CEBC33A4C40427C60C77FDC5940F1F62004E43B4C40B98B3045B9DD5940F1F62004E43B4C40B98B3045B9DD59403DBB7CEBC33A4C40427C60C77FDC59403DBB7CEBC33A4C40
68870	24091	104.625766	104.664618	56.688710999999998	56.672536999999998	Семигорская	0103000020E61000000100000005000000B83CD68C0C285A40CB2C42B115564C40B83CD68C0C285A409EB29AAE27584C404F95EF19892A5A409EB29AAE27584C404F95EF19892A5A40CB2C42B115564C40B83CD68C0C285A40CB2C42B115564C40
69278	24291	103.945786	103.95111300000001	56.444802000000003	56.438448000000001	Нагорная	0103000020E61000000100000005000000F0C000C287FC5940917F66101F384C40F0C000C287FC594003999D45EF384C403B730F09DFFC594003999D45EF384C403B730F09DFFC5940917F66101F384C40F0C000C287FC5940917F66101F384C40
68232	24633	103.74324300000001	103.773561	57.275891000000001	57.259912999999997	Школьная	0103000020E61000000100000005000000C87E164B91EF5940126745D444A14C40C87E164B91EF59406021736550A34C40821DFF0582F159406021736550A34C40821DFF0582F15940126745D444A14C40C87E164B91EF5940126745D444A14C40
67806	24633	103.74324300000001	103.773561	57.275891000000001	57.259912999999997	Вокзальная	0103000020E61000000100000005000000C87E164B91EF5940126745D444A14C40C87E164B91EF59406021736550A34C40821DFF0582F159406021736550A34C40821DFF0582F15940126745D444A14C40C87E164B91EF5940126745D444A14C40
67794	23881	102.856768	102.87602800000001	56.537864999999996	56.527330999999997	Красноярская	0103000020E6100000010000000500000099107349D5B659405F950B957F434C4099107349D5B65940DE54A4C2D8444C405798BED710B85940DE54A4C2D8444C405798BED710B859405F950B957F434C4099107349D5B659405F950B957F434C40
68549	24849	103.674423	103.69203	57.301476000000001	57.290072000000002	Зверева	0103000020E61000000100000005000000E52A16BF29EB59401FBE4C1421A54C40E52A16BF29EB5940B343FCC396A64C40757632384AEC5940B343FCC396A64C40757632384AEC59401FBE4C1421A54C40E52A16BF29EB59401FBE4C1421A54C40
68259	24928	103.877182	103.95611700000001	57.155416000000002	57.120362999999998	микрорайон Химки	0103000020E61000000100000005000000F4A8F8BF23F859400053060E688F4C40F4A8F8BF23F8594038A3E6ABE4934C4094895B0531FD594038A3E6ABE4934C4094895B0531FD59400053060E688F4C40F4A8F8BF23F859400053060E688F4C40
67682	24928	103.877182	103.95611700000001	57.155416000000002	57.120362999999998	квартал 332	0103000020E61000000100000005000000F4A8F8BF23F859400053060E688F4C40F4A8F8BF23F8594038A3E6ABE4934C4094895B0531FD594038A3E6ABE4934C4094895B0531FD59400053060E688F4C40F4A8F8BF23F859400053060E688F4C40
68246	24928	103.877182	103.95611700000001	57.155416000000002	57.120362999999998	Пионерская	0103000020E61000000100000005000000F4A8F8BF23F859400053060E688F4C40F4A8F8BF23F8594038A3E6ABE4934C4094895B0531FD594038A3E6ABE4934C4094895B0531FD59400053060E688F4C40F4A8F8BF23F859400053060E688F4C40
67944	24928	103.877182	103.95611700000001	57.155416000000002	57.120362999999998	Бархатова	0103000020E61000000100000005000000F4A8F8BF23F859400053060E688F4C40F4A8F8BF23F8594038A3E6ABE4934C4094895B0531FD594038A3E6ABE4934C4094895B0531FD59400053060E688F4C40F4A8F8BF23F859400053060E688F4C40
68627	24882	104.18718200000001	104.205822	56.495479000000003	56.486652999999997	Ленина	0103000020E61000000100000005000000981936CAFA0B5A4009C03FA54A3E4C40981936CAFA0B5A406A6D1ADB6B3F4C4007B309302C0D5A406A6D1ADB6B3F4C4007B309302C0D5A4009C03FA54A3E4C40981936CAFA0B5A4009C03FA54A3E4C40
69034	24628	103.09021300000001	103.10906799999999	56.385376999999998	56.373829000000001	Лесная	0103000020E61000000100000005000000242BBF0CC6C55940F0A5F0A0D92F4C40242BBF0CC6C55940B7D0950854314C40914259F8FAC65940B7D0950854314C40914259F8FAC65940F0A5F0A0D92F4C40242BBF0CC6C55940F0A5F0A0D92F4C40
69116	23939	102.826441	102.844128	56.198926	56.186720000000001	Заярская	0103000020E61000000100000005000000B5C4CA68E4B459402BC1E270E6174C40B5C4CA68E4B459407C293C6876194C40D368723106B659407C293C6876194C40D368723106B659402BC1E270E6174C40B5C4CA68E4B459402BC1E270E6174C40
69031	23761	103.19534299999999	103.223208	57.087452999999996	57.080134999999999	Ленина	0103000020E610000001000000050000002920ED7F80CC5940EA211ADD418A4C402920ED7F80CC5940F277EFA8318B4C40280D350A49CE5940F277EFA8318B4C40280D350A49CE5940EA211ADD418A4C402920ED7F80CC5940EA211ADD418A4C40
69054	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	пос. Донецкого ЛПХ	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
68227	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	микрорайон1035	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
68224	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал829	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
67681	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал334	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
68788	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал145	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
67801	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал 6а	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
37453	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал 6	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
67956	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал 243	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
67686	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	квартал	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
68660	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	Энтузиастов	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
67645	23095	104.068873	104.15471599999999	56.597963	56.482253999999998	3 квартал	0103000020E61000000100000005000000F4A44C6A68045A40BE2EC37FBA3D4C40F4A44C6A68045A40E99B340D8A4C4C40BF0AF0DDE6095A40E99B340D8A4C4C40BF0AF0DDE6095A40BE2EC37FBA3D4C40F4A44C6A68045A40BE2EC37FBA3D4C40
68552	23678	102.776889	102.81276800000001	57.366148000000003	57.351467	Школьная	0103000020E61000000100000005000000D1E7A38CB8B15940C64FE3DEFCAC4C40D1E7A38CB8B1594077BF0AF0DDAE4C4010CF126404B4594077BF0AF0DDAE4C4010CF126404B45940C64FE3DEFCAC4C40D1E7A38CB8B15940C64FE3DEFCAC4C40
68678	24442	103.097202	103.12089899999999	56.417143000000003	56.398217000000002	Нагорная	0103000020E61000000100000005000000C5C6BC8E38C659400ADB4FC6F8324C40C5C6BC8E38C65940AF601BF164354C409FC728CFBCC75940AF601BF164354C409FC728CFBCC759400ADB4FC6F8324C40C5C6BC8E38C659400ADB4FC6F8324C40
69390	24442	103.097202	103.12089899999999	56.417143000000003	56.398217000000002	Железнодорожная	0103000020E61000000100000005000000C5C6BC8E38C659400ADB4FC6F8324C40C5C6BC8E38C65940AF601BF164354C409FC728CFBCC75940AF601BF164354C409FC728CFBCC759400ADB4FC6F8324C40C5C6BC8E38C659400ADB4FC6F8324C40
69119	23708	103.258072	103.280126	57.275891000000001	57.265242999999998	Ленина	0103000020E61000000100000005000000DA006C4084D05940183F8D7BF3A14C40DA006C4084D059406021736550A34C4098309A95EDD159406021736550A34C4098309A95EDD15940183F8D7BF3A14C40DA006C4084D05940183F8D7BF3A14C40
68876	23818	103.580477	103.60252199999999	56.946264999999997	56.933675000000001	Янгеля	0103000020E6100000010000000500000022C5008926E55940E10B93A982774C4022C5008926E55940BA2C26361F794C40B6476FB88FE65940BA2C26361F794C40B6476FB88FE65940E10B93A982774C4022C5008926E55940E10B93A982774C40
69622	59334	103.88845600000001	103.900808	52.555638999999999	52.535496000000002	Мира	0103000020E61000000100000005000000D7FB8D76DCF85940C59107228B444A40D7FB8D76DCF85940EAB0C22D1F474A4069FE98D6A6F95940EAB0C22D1F474A4069FE98D6A6F95940C59107228B444A40D7FB8D76DCF85940C59107228B444A40
69629	59337	104.294746	104.35616400000001	52.280768000000002	52.273555000000002	Советская	0103000020E610000001000000050000001EA8531EDD125A402254A9D903234A401EA8531EDD125A40B5E1B034F0234A40CE001764CB165A40B5E1B034F0234A40CE001764CB165A402254A9D903234A401EA8531EDD125A402254A9D903234A40
69595	59323	104.297971	104.302633	52.266468000000003	52.264153	Комсомольская	0103000020E61000000100000005000000030AF5F411135A40F511F8C3CF214A40030AF5F411135A401CB7989F1B224A402F6CCD565E135A401CB7989F1B224A402F6CCD565E135A40F511F8C3CF214A40030AF5F411135A40F511F8C3CF214A40
69464	59265	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Школьная	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68938	59195	101.237357	101.369158	54.469226999999997	54.392386000000002	Ленина	0103000020E61000000100000005000000821E6ADB304F594042B456B439324B40821E6ADB304F594039B35DA10F3C4B40A243E048A057594039B35DA10F3C4B40A243E048A057594042B456B439324B40821E6ADB304F594042B456B439324B40
68579	22628	101.214611	101.256266	54.395038	54.366171999999999	Мира	0103000020E610000001000000050000002997C62FBC4D5940FF5A5EB9DE2E4B402997C62FBC4D5940B056ED9A90324B40E94482A966505940B056ED9A90324B40E94482A966505940FF5A5EB9DE2E4B402997C62FBC4D5940FF5A5EB9DE2E4B40
69112	21004	101.86077	101.883793	54.232843000000003	54.222616000000002	Макарова	0103000020E6100000010000000500000030D80DDB167759407EC85BAE7E1C4B4030D80DDB16775940200DA7CCCD1D4B40C2DB831090785940200DA7CCCD1D4B40C2DB8310907859407EC85BAE7E1C4B4030D80DDB167759407EC85BAE7E1C4B40
68639	52140	101.597635	101.680055	54.253247000000002	54.167417999999998	Озерная	0103000020E610000001000000050000007AFCDEA63F6659408061F9F36D154B407AFCDEA63F665940B267CF656A204B40CD1E6805866B5940B267CF656A204B40CD1E6805866B59408061F9F36D154B407AFCDEA63F6659408061F9F36D154B40
68216	52140	101.597635	101.680055	54.253247000000002	54.167417999999998	Ленина	0103000020E610000001000000050000007AFCDEA63F6659408061F9F36D154B407AFCDEA63F665940B267CF656A204B40CD1E6805866B5940B267CF656A204B40CD1E6805866B59408061F9F36D154B407AFCDEA63F6659408061F9F36D154B40
69249	20497	101.75013300000001	101.78196	54.358234000000003	54.342312999999997	Зеленая	0103000020E61000000100000005000000A0A9D72D0270594071FF91E9D02B4B40A0A9D72D027059405B28999CDA2D4B40EEB1F4A10B7259405B28999CDA2D4B40EEB1F4A10B72594071FF91E9D02B4B40A0A9D72D0270594071FF91E9D02B4B40
68864	22443	101.972987	102.02517	54.354225999999997	54.328622000000003	1-я Советская	0103000020E61000000100000005000000B91B446B457E5940815F2349102A4B40B91B446B457E59404AB20E47572D4B40C8B5A1629C8159404AB20E47572D4B40C8B5A1629C815940815F2349102A4B40B91B446B457E5940815F2349102A4B40
68578	22383	101.108107	101.144767	54.417535999999998	54.390787000000003	Комсомольская	0103000020E61000000100000005000000FF5D9F39EB465940DA59F44E05324B40FF5D9F39EB4659408A73D4D171354B4090A2CEDC434959408A73D4D171354B4090A2CEDC43495940DA59F44E05324B40FF5D9F39EB465940DA59F44E05324B40
69111	22191	102.005425	102.027173	54.507227999999998	54.486207999999998	Лесная	0103000020E610000001000000050000002C6519E258805940DB8651103C3E4B402C6519E258805940C8CEDBD8EC404B406495D233BD815940C8CEDBD8EC404B406495D233BD815940DB8651103C3E4B402C6519E258805940DB8651103C3E4B40
69503	1194	101.43902	101.45465900000001	53.957163999999999	53.946641	Пионерская	0103000020E610000001000000050000008E9257E7185C5940C00644882BF94A408E9257E7185C59404B74965984FA4A4041F50F22195D59404B74965984FA4A4041F50F22195D5940C00644882BF94A408E9257E7185C5940C00644882BF94A40
67788	52497	101.16761200000001	101.208395	54.458840000000002	54.443255999999998	Мира	0103000020E61000000100000005000000B39AAE27BA4A5940BDE0D39CBC384B40B39AAE27BA4A59405F0CE544BB3A4B409869FB57564D59405F0CE544BB3A4B409869FB57564D5940BDE0D39CBC384B40B39AAE27BA4A5940BDE0D39CBC384B40
69285	52497	101.16761200000001	101.208395	54.458840000000002	54.443255999999998	Ленина	0103000020E61000000100000005000000B39AAE27BA4A5940BDE0D39CBC384B40B39AAE27BA4A59405F0CE544BB3A4B409869FB57564D59405F0CE544BB3A4B409869FB57564D5940BDE0D39CBC384B40B39AAE27BA4A5940BDE0D39CBC384B40
69300	20180	101.305314	101.330207	54.458835000000001	54.450957000000002	Степная	0103000020E61000000100000005000000B340BB438A5359407E737FF5B8394B40B340BB438A5359404DA1F31ABB3A4B40427A8A1C225559404DA1F31ABB3A4B40427A8A1C225559407E737FF5B8394B40B340BB438A5359407E737FF5B8394B40
69024	21629	101.63818499999999	101.650043	54.153331000000001	54.143006	Степная	0103000020E610000001000000050000000EF3E505D8685940DE9046054E124B400EF3E505D8685940433BA759A0134B40997FF44D9A695940433BA759A0134B40997FF44D9A695940DE9046054E124B400EF3E505D8685940DE9046054E124B40
69110	20116	101.464541	101.48976500000001	54.447800999999998	54.431866999999997	Трактовая	0103000020E61000000100000005000000ACA92C0ABB5D59405E9CF86A47374B40ACA92C0ABB5D5940DC0E0D8B51394B406E6E4C4F585F5940DC0E0D8B51394B406E6E4C4F585F59405E9CF86A47374B40ACA92C0ABB5D59405E9CF86A47374B40
69431	21856	101.328131	101.348874	54.219994999999997	54.204362000000003	Центральная	0103000020E6100000010000000500000071732A1900555940C845B588281A4B4071732A19005559404A24D1CB281C4B402E1B9DF3535659404A24D1CB281C4B402E1B9DF353565940C845B588281A4B4071732A1900555940C845B588281A4B40
69136	192	101.800214	101.831898	54.290785999999997	54.273949999999999	Трактовая	0103000020E6100000010000000500000049F3C7B4367359409E5E29CB10234B4049F3C7B4367359403C11C47938254B40E6E61BD13D7559403C11C47938254B40E6E61BD13D7559409E5E29CB10234B4049F3C7B4367359409E5E29CB10234B40
69022	21166	101.70093199999999	101.715844	54.200381	54.193744000000002	Центральная	0103000020E61000000100000005000000122EE411DC6C5940EBE5779ACC184B40122EE411DC6C5940B1DEA815A6194B406C425A63D06D5940B1DEA815A6194B406C425A63D06D5940EBE5779ACC184B40122EE411DC6C5940EBE5779ACC184B40
69074	22121	102.186598	102.20451	54.637037999999997	54.624232999999997	Центральная	0103000020E61000000100000005000000F0DFBC38F18B5940BF0AF0DDE64F4B40F0DFBC38F18B5940952710768A514B401E6D1CB1168D5940952710768A514B401E6D1CB1168D5940BF0AF0DDE64F4B40F0DFBC38F18B5940BF0AF0DDE64F4B40
69214	6642	100.968114	100.982541	54.908861999999999	54.888455	Школьная	0103000020E610000001000000050000002F336C94F53D5940DD7BB8E4B8714B402F336C94F53D5940E0490B9755744B40AA7EA5F3E13E5940E0490B9755744B40AA7EA5F3E13E5940DD7BB8E4B8714B402F336C94F53D5940DD7BB8E4B8714B40
69382	20744	101.681951	101.70015100000001	54.621631999999998	54.614662000000003	Верхняя	0103000020E610000001000000050000005E9ECE15A56B5940070C923EAD4E4B405E9ECE15A56B5940D3122BA3914F4B40C0D02346CF6C5940D3122BA3914F4B40C0D02346CF6C5940070C923EAD4E4B405E9ECE15A56B5940070C923EAD4E4B40
69109	22108	101.98408999999999	101.998257	54.785325	54.776493000000002	Ленина	0103000020E6100000010000000500000085949F54FB7E59405649641F64634B4085949F54FB7E594098DD938785644B4032005471E37F594098DD938785644B4032005471E37F59405649641F64634B4085949F54FB7E59405649641F64634B40
69385	22216	101.97908700000001	102.00344	54.531272000000001	54.509366	Мира	0103000020E61000000100000005000000153C855CA97E5940E0D8B3E732414B40153C855CA97E5940E8A38CB800444B40E3DF675C38805940E8A38CB800444B40E3DF675C38805940E0D8B3E732414B40153C855CA97E5940E0D8B3E732414B40
69292	22034	102.04549	102.066097	55.029812	55.021141999999998	Набережная	0103000020E61000000100000005000000E292E34EE98259403849F3C7B4824B40E292E34EE9825940A1832EE1D0834B404757E9EE3A845940A1832EE1D0834B404757E9EE3A8459403849F3C7B4824B40E292E34EE98259403849F3C7B4824B40
69032	21973	101.542811	101.582373	54.743566999999999	54.721187999999998	Мира	0103000020E610000001000000050000002E3A596ABD62594042226DE34F5C4B402E3A596ABD62594042B115342D5F4B40B34467994565594042B115342D5F4B40B34467994565594042226DE34F5C4B402E3A596ABD62594042226DE34F5C4B40
69123	20280	101.37219399999999	101.391121	54.509967000000003	54.497613999999999	Школьная	0103000020E610000001000000050000001D71C806D25759401004C8D0B13F4B401D71C806D25759400685419946414B40D8F15F20085959400685419946414B40D8F15F20085959401004C8D0B13F4B401D71C806D25759401004C8D0B13F4B40
69389	22369	101.233278	101.246331	54.529882999999998	54.518470999999998	Лесная	0103000020E610000001000000050000001538D906EE4E59405376FA415D424B401538D906EE4E59406ADAC534D3434B406C3F19E3C34F59406ADAC534D3434B406C3F19E3C34F59405376FA415D424B401538D906EE4E59405376FA415D424B40
69294	21081	101.727316	101.750681	54.247149999999998	54.230606000000002	Школьная	0103000020E61000000100000005000000E27668588C6E59407521567F841D4B40E27668588C6E59406B9A779CA21F4B40A12E52280B7059406B9A779CA21F4B40A12E52280B7059407521567F841D4B40E27668588C6E59407521567F841D4B40
69029	21727	101.352413	101.383189	54.30791	54.296593000000001	Лазо	0103000020E61000000100000005000000DB6B41EF8D5659407C9C69C2F6254B40DB6B41EF8D565940410E4A9869274B40F7CB272B86585940410E4A9869274B40F7CB272B865859407C9C69C2F6254B40DB6B41EF8D5659407C9C69C2F6254B40
69268	21605	101.66279900000001	101.698615	54.095046000000004	54.084806	Солнечная	0103000020E6100000010000000500000094347F4C6B6A594096404AECDA0A4B4094347F4C6B6A5940CDCEA2772A0C4B40AF5FB01BB66C5940CDCEA2772A0C4B40AF5FB01BB66C594096404AECDA0A4B4094347F4C6B6A594096404AECDA0A4B40
68818	21405	101.24374400000001	101.27611	54.355254000000002	54.326638000000003	переулок Советский	0103000020E6100000010000000500000029266F80994F5940C0D02346CF294B4029266F80994F5940F8E28BF6782D4B404F0647C9AB515940F8E28BF6782D4B404F0647C9AB515940C0D02346CF294B4029266F80994F5940C0D02346CF294B40
68751	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Чернышевского	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
68631	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Фрунзе	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
68866	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Тургенева	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
68733	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Нахимова	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
69386	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Молодежная	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
68867	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Коммунальная	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
68737	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Киевская	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
67786	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	Карла Маркса	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
68740	18957	101.474422	101.54193100000001	54.365856999999998	54.309731999999997	1-я Рабочая	0103000020E6100000010000000500000030A017EE5C5E59402843554CA5274B4030A017EE5C5E59409F01F566D42E4B40126C5CFFAE6259409F01F566D42E4B40126C5CFFAE6259402843554CA5274B4030A017EE5C5E59402843554CA5274B40
69113	22461	100.592995	102.59249199999999	55.199696000000003	53.720996999999997	Зеленая	0103000020E6100000010000000500000042EC4CA1F3255940CEC133A149DC4A4042EC4CA1F32559402E9276A38F994B4010C99063EBA559402E9276A38F994B4010C99063EBA55940CEC133A149DC4A4042EC4CA1F3255940CEC133A149DC4A40
69306	20456	101.583828	101.610068	54.412211999999997	54.397350000000003	Центральная	0103000020E610000001000000050000004D9F1D705D6559406688635DDC324B404D9F1D705D6559406682E15CC3344B408315A75A0B6759406682E15CC3344B408315A75A0B6759406688635DDC324B404D9F1D705D6559406688635DDC324B40
67936	21263	101.809045	101.87835	54.112414999999999	54.090125	Набережная	0103000020E6100000010000000500000082FFAD64C7735940A8C64B37890B4B4082FFAD64C7735940384A5E9D630E4B40431CEBE236785940384A5E9D630E4B40431CEBE236785940A8C64B37890B4B4082FFAD64C7735940A8C64B37890B4B40
69387	21955	101.208629	101.251029	54.144145000000002	54.118679	Российская	0103000020E61000000100000005000000D2FF722D5A4D59406ADC9BDF300F4B40D2FF722D5A4D5940E370E65773124B403F56F0DB10505940E370E65773124B403F56F0DB105059406ADC9BDF300F4B40D2FF722D5A4D59406ADC9BDF300F4B40
68577	21248	101.098271	101.143618	54.365259000000002	54.343819000000003	Мира	0103000020E610000001000000050000004BC972124A465940295FD042022C4B404BC972124A465940EBC891CEC02E4B407C478D0931495940EBC891CEC02E4B407C478D0931495940295FD042022C4B404BC972124A465940295FD042022C4B40
68739	21551	101.73632600000001	101.76897099999999	54.097110999999998	54.080374999999997	Ленина	0103000020E61000000100000005000000734C16F71F6F59403F355EBA490A4B40734C16F71F6F59407A8A1C226E0C4B40A22424D2367159407A8A1C226E0C4B40A22424D2367159403F355EBA490A4B40734C16F71F6F59403F355EBA490A4B40
69027	21800	101.362537	101.37859	54.353774999999999	54.345981999999999	Заречная	0103000020E61000000100000005000000C2A563CE3357594099805F23492C4B40C2A563CE335759403A92CB7F482D4B40EE258DD13A5859403A92CB7F482D4B40EE258DD13A58594099805F23492C4B40C2A563CE3357594099805F23492C4B40
69021	20606	101.550303	101.58425	54.518073999999999	54.506622	Ленина	0103000020E6100000010000000500000001F9122A3863594091B75CFDD8404B4001F9122A386359403674B33F50424B4008AC1C5A646559403674B33F50424B4008AC1C5A6465594091B75CFDD8404B4001F9122A3863594091B75CFDD8404B40
69064	20666	101.48934300000001	101.509546	54.619535999999997	54.609917000000003	Центральная	0103000020E61000000100000005000000B3614D65515F59402123A0C2114E4B40B3614D65515F5940EA58A5F44C4F4B40B073D3669C605940EA58A5F44C4F4B40B073D3669C6059402123A0C2114E4B40B3614D65515F59402123A0C2114E4B40
69250	1159	101.51155799999999	101.530603	54.038117	54.025556999999999	Школьная	0103000020E610000001000000050000007500C45DBD6059408997A77345034B407500C45DBD605940F8359204E1044B40350A4966F5615940F8359204E1044B40350A4966F56159408997A77345034B407500C45DBD6059408997A77345034B40
69261	20552	101.868297	101.884252	54.408864000000001	54.399262999999998	Школьная	0103000020E61000000100000005000000C18D942D927759405DC0CB0C1B334B40C18D942D927759408141D2A755344B400C5BB395977859408141D2A755344B400C5BB395977859405DC0CB0C1B334B40C18D942D927759405DC0CB0C1B334B40
68862	9669	101.69523700000001	101.743584	54.555861	54.519573000000001	Школьная	0103000020E61000000100000005000000077E54C37E6C59403B71395E81424B40077E54C37E6C5940990F087426474B400C7558E1966F5940990F087426474B400C7558E1966F59403B71395E81424B40077E54C37E6C59403B71395E81424B40
69384	21160	101.548102	101.56641	54.241520000000001	54.229269000000002	Центральная	0103000020E61000000100000005000000D237691A146359404A7EC4AF581D4B40D237691A146359403BAA9A20EA1E4B402788BA0F406459403BAA9A20EA1E4B402788BA0F406459404A7EC4AF581D4B40D237691A146359404A7EC4AF581D4B40
69114	22561	101.495739	101.51480100000001	54.199891000000001	54.192352999999997	Лесная	0103000020E6100000010000000500000083161230BA5F5940CC24EA059F184B4083161230BA5F5940E3E13D0796194B40AEBCE47FF2605940E3E13D0796194B40AEBCE47FF2605940CC24EA059F184B4083161230BA5F5940CC24EA059F184B40
69604	59328	101.4111	101.436136	54.109074	54.094883000000003	Советская	0103000020E61000000100000005000000AED85F764F5A594023F94A20250C4B40AED85F764F5A5940056C0723F60D4B40EE26F8A6E95B5940056C0723F60D4B40EE26F8A6E95B594023F94A20250C4B40AED85F764F5A594023F94A20250C4B40
68744	20399	101.60867500000001	101.67164699999999	54.371820999999997	54.356439999999999	Советская	0103000020E6100000010000000500000024B9FC87F46659403D7E6FD39F2D4B4024B9FC87F4665940A67B9DD4972F4B4037DDB243FC6A5940A67B9DD4972F4B4037DDB243FC6A59403D7E6FD39F2D4B4024B9FC87F46659403D7E6FD39F2D4B40
69447	21487	101.106284	101.13430200000001	54.224696000000002	54.208964999999999	Центральная	0103000020E61000000100000005000000A305685BCD4659401B81785DBF1A4B40A305685BCD46594061C5A9D6C21C4B4065726A679848594061C5A9D6C21C4B4065726A67984859401B81785DBF1A4B40A305685BCD4659401B81785DBF1A4B40
69134	20066	101.425185	101.455755	54.501854000000002	54.475997999999997	переулок Больничный	0103000020E61000000100000005000000FC6F253B365B59400F7BA180ED3C4B40FC6F253B365B5940F3AE7AC03C404B4043FF04172B5D5940F3AE7AC03C404B4043FF04172B5D59400F7BA180ED3C4B40FC6F253B365B59400F7BA180ED3C4B40
69434	20298	101.27013599999999	101.30266399999999	54.580267999999997	54.567289000000002	1-я Заречная	0103000020E61000000100000005000000395E81E849515940B6300BED9C484B40395E81E8495159402975C938464A4B404C6BD3D85E5359402975C938464A4B404C6BD3D85E535940B6300BED9C484B40395E81E849515940B6300BED9C484B40
69326	21460	101.274807	101.291372	54.302371999999998	54.285257000000001	Центральная	0103000020E610000001000000050000008F6D19709651594040FA264D83244B408F6D197096515940F19C2D20B4264B4016BEBED6A5525940F19C2D20B4264B4016BEBED6A552594040FA264D83244B408F6D19709651594040FA264D83244B40
69592	59322	104.378963	104.387308	52.281224999999999	52.280993000000002	Центральная	0103000020E6100000010000000500000038D906EE40185A40D5B32094F7234A4038D906EE40185A40A7E8482EFF234A40AB5E7EA7C9185A40A7E8482EFF234A40AB5E7EA7C9185A40D5B32094F7234A4038D906EE40185A40D5B32094F7234A40
69632	59338	103.857608	103.872062	52.595776000000001	52.588357999999999	Гагарина	0103000020E610000001000000050000006E32AA0CE3F65940842BA0504F4B4A406E32AA0CE3F65940F0DE5163424C4A40668522DDCFF75940F0DE5163424C4A40668522DDCFF75940842BA0504F4B4A406E32AA0CE3F65940842BA0504F4B4A40
69010	59202	103.893163	103.894133	52.526166000000003	52.524478999999999	Полевая	0103000020E61000000100000005000000D3BF249529F959402A38BC2022434A40D3BF249529F959403222516859434A408F519E7939F959403222516859434A408F519E7939F959402A38BC2022434A40D3BF249529F959402A38BC2022434A40
69152	59215	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	Боровкова	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
68994	59199	104.28218699999999	104.289131	52.241163	52.237302	Майская	0103000020E61000000100000005000000CE16105A0F125A4040A374E95F1E4A40CE16105A0F125A40AC00DF6DDE1E4A40A0504F1F81125A40AC00DF6DDE1E4A40A0504F1F81125A4040A374E95F1E4A40CE16105A0F125A4040A374E95F1E4A40
69619	59302	104.302301	104.324696	52.317843000000003	52.300823999999999	Первомайская	0103000020E6100000010000000500000014234BE658135A400BED9C6681264A4014234BE658135A409B215514AF284A401749BBD1C7145A409B215514AF284A401749BBD1C7145A400BED9C6681264A4014234BE658135A400BED9C6681264A40
70099	59382	104.378963	104.387308	52.281224999999999	52.280993000000002	улица Центральная	0103000020E6100000010000000500000038D906EE40185A40D5B32094F7234A4038D906EE40185A40A7E8482EFF234A40AB5E7EA7C9185A40A7E8482EFF234A40AB5E7EA7C9185A40D5B32094F7234A4038D906EE40185A40D5B32094F7234A40
69101	16530	106.115056	106.15320699999999	53.994514000000002	53.980716999999999	Ключевая	0103000020E61000000100000005000000594DD7135D875A40CCD0782288FD4A40594DD7135D875A4003B5183C4CFF4A402BA1BB24CE895A4003B5183C4CFF4A402BA1BB24CE895A40CCD0782288FD4A40594DD7135D875A40CCD0782288FD4A40
68933	16581	106.12143399999999	106.13481	54.101086000000002	54.085372	Школьная	0103000020E61000000100000005000000D6A71C93C5875A403FFF3D78ED0A4B40D6A71C93C5875A40AF0AD462F00C4B401F4B1FBAA0885A40AF0AD462F00C4B401F4B1FBAA0885A403FFF3D78ED0A4B40D6A71C93C5875A403FFF3D78ED0A4B40
68735	17246	105.994439	106.012423	53.757573999999998	53.740791000000002	Трактовая	0103000020E610000001000000050000007CB779E3A47F5A40E8154F3DD2DE4A407CB779E3A47F5A406326512FF8E04A40F7ADD689CB805A406326512FF8E04A40F7ADD689CB805A40E8154F3DD2DE4A407CB779E3A47F5A40E8154F3DD2DE4A40
69319	17246	105.994439	106.012423	53.757573999999998	53.740791000000002	Новая	0103000020E610000001000000050000007CB779E3A47F5A40E8154F3DD2DE4A407CB779E3A47F5A406326512FF8E04A40F7ADD689CB805A406326512FF8E04A40F7ADD689CB805A40E8154F3DD2DE4A407CB779E3A47F5A40E8154F3DD2DE4A40
69381	17445	106.03551899999999	106.047943	53.805759999999999	53.798825999999998	Кольцевая	0103000020E61000000100000005000000BED87BF145825A40E5982CEE3FE64A40BED87BF145825A406536C82423E74A409E44847F11835A406536C82423E74A409E44847F11835A40E5982CEE3FE64A40BED87BF145825A40E5982CEE3FE64A40
68953	17048	105.521395	105.558927	54.102263999999998	54.089754999999997	Киселева	0103000020E61000000100000005000000115322895E615A4084D382177D0B4B40115322895E615A4071C79BFC160D4B407D76C075C5635A4071C79BFC160D4B407D76C075C5635A4084D382177D0B4B40115322895E615A4084D382177D0B4B40
69383	16266	105.88658700000001	105.89897499999999	53.932135000000002	53.918137000000002	Совхозная	0103000020E61000000100000005000000C38366D7BD785A40B01F628385F54A40C38366D7BD785A407E3A1E3350F74A40FB3A70CE88795A407E3A1E3350F74A40FB3A70CE88795A40B01F628385F54A40C38366D7BD785A40B01F628385F54A40
69213	17547	105.96484	106.002138	53.534945999999998	53.518180999999998	Трактовая	0103000020E61000000100000005000000D97745F0BF7D5A404C3448C153C24A40D97745F0BF7D5A4021904B1C79C44A400C056C0723805A4021904B1C79C44A400C056C0723805A404C3448C153C24A40D97745F0BF7D5A404C3448C153C24A40
69105	17277	105.951688	105.980417	53.683242	53.666401999999998	Школьная	0103000020E61000000100000005000000B9FFC874E87C5A4097FE25A94CD54A40B9FFC874E87C5A4077A04E7974D74A4051DCF126BF7E5A4077A04E7974D74A4051DCF126BF7E5A4097FE25A94CD54A40B9FFC874E87C5A4097FE25A94CD54A40
68736	17459	106.04732300000001	106.084576	53.497607000000002	53.465069999999997	Октябрьская	0103000020E6100000010000000500000050560C5707835A40E42CEC6987BB4A4050560C5707835A405EA10F96B1BF4A40B28174B169855A405EA10F96B1BF4A40B28174B169855A40E42CEC6987BB4A4050560C5707835A40E42CEC6987BB4A40
69240	16798	106.35182500000001	106.37908	53.838262	53.822941999999998	Петровская	0103000020E61000000100000005000000933A014D84965A409E40D82956E94A40933A014D84965A4062BD512B4CEB4A4055A4C2D842985A4062BD512B4CEB4A4055A4C2D842985A409E40D82956E94A40933A014D84965A409E40D82956E94A40
69270	15468	106.024452	106.056585	53.939183999999997	53.925083000000001	Трактовая	0103000020E6100000010000000500000098141F9F90815A40F48AA71E69F64A4098141F9F90815A4096766A2E37F84A406D1CB1169F835A4096766A2E37F84A406D1CB1169F835A40F48AA71E69F64A4098141F9F90815A40F48AA71E69F64A40
69104	17370	105.980614	105.99982	53.630316999999998	53.609920000000002	Гаражная	0103000020E61000000100000005000000FCFF3861C27E5A409296CADB11CE4A40FCFF3861C27E5A40718E3A3AAED04A40C078060DFD7F5A40718E3A3AAED04A40C078060DFD7F5A409296CADB11CE4A40FCFF3861C27E5A409296CADB11CE4A40
68772	14982	104.395393	108.643598	54.9679	53.217396999999998	Трактовая	0103000020E610000001000000050000004F04711E4E195A40CF9F36AAD39B4A404F04711E4E195A4032E6AE25E47B4B405871AAB530295B4032E6AE25E47B4B405871AAB530295B40CF9F36AAD39B4A404F04711E4E195A40CF9F36AAD39B4A40
68978	17347	106.205112	106.225351	53.748752000000003	53.741356000000003	Школьная	0103000020E610000001000000050000001901158E208D5A40C158DFC0E4DE4A401901158E208D5A404568041BD7DF4A40BDC799266C8E5A404568041BD7DF4A40BDC799266C8E5A40C158DFC0E4DE4A401901158E208D5A40C158DFC0E4DE4A40
69262	17653	106.065541	106.08783699999999	53.367818999999997	53.352342999999998	Лесная	0103000020E6100000010000000500000004E3E0D231845A40BDFC4E9319AD4A4004E3E0D231845A4078EC67B114AF4A403D98141F9F855A4078EC67B114AF4A403D98141F9F855A40BDFC4E9319AD4A4004E3E0D231845A40BDFC4E9319AD4A40
67673	7090	105.812423	105.938636	53.990766000000001	53.934466999999998	пер. Восточный	0103000020E610000001000000050000002AE109BDFE735A407A185A9D9CF74A402AE109BDFE735A408FFE976BD1FE4A404AB6BA9C127C5A408FFE976BD1FE4A404AB6BA9C127C5A407A185A9D9CF74A402AE109BDFE735A407A185A9D9CF74A40
67941	7090	105.812423	105.938636	53.990766000000001	53.934466999999998	Юбилейная	0103000020E610000001000000050000002AE109BDFE735A407A185A9D9CF74A402AE109BDFE735A408FFE976BD1FE4A404AB6BA9C127C5A408FFE976BD1FE4A404AB6BA9C127C5A407A185A9D9CF74A402AE109BDFE735A407A185A9D9CF74A40
68826	7090	105.812423	105.938636	53.990766000000001	53.934466999999998	Пуляевского	0103000020E610000001000000050000002AE109BDFE735A407A185A9D9CF74A402AE109BDFE735A408FFE976BD1FE4A404AB6BA9C127C5A408FFE976BD1FE4A404AB6BA9C127C5A407A185A9D9CF74A402AE109BDFE735A407A185A9D9CF74A40
68561	7090	105.812423	105.938636	53.990766000000001	53.934466999999998	Маяковского	0103000020E610000001000000050000002AE109BDFE735A407A185A9D9CF74A402AE109BDFE735A408FFE976BD1FE4A404AB6BA9C127C5A408FFE976BD1FE4A404AB6BA9C127C5A407A185A9D9CF74A402AE109BDFE735A407A185A9D9CF74A40
67930	7090	105.812423	105.938636	53.990766000000001	53.934466999999998	Красноармейская	0103000020E610000001000000050000002AE109BDFE735A407A185A9D9CF74A402AE109BDFE735A408FFE976BD1FE4A404AB6BA9C127C5A408FFE976BD1FE4A404AB6BA9C127C5A407A185A9D9CF74A402AE109BDFE735A407A185A9D9CF74A40
67676	7090	105.812423	105.938636	53.990766000000001	53.934466999999998	Каландарашвили	0103000020E610000001000000050000002AE109BDFE735A407A185A9D9CF74A402AE109BDFE735A408FFE976BD1FE4A404AB6BA9C127C5A408FFE976BD1FE4A404AB6BA9C127C5A407A185A9D9CF74A402AE109BDFE735A407A185A9D9CF74A40
69126	17678	105.975494	105.999982	53.430962999999998	53.416282000000002	Школьная	0103000020E610000001000000050000006EDC627E6E7E5A40EDF483BA48B54A406EDC627E6E7E5A409D64ABCB29B74A40ADA580B4FF7F5A409D64ABCB29B74A40ADA580B4FF7F5A40EDF483BA48B54A406EDC627E6E7E5A40EDF483BA48B54A40
69121	16386	105.960842	105.9909	53.854962999999998	53.835186	Береговая	0103000020E61000000100000005000000E3A7716F7E7D5A40DD09F65FE7EA4A40E3A7716F7E7D5A402025766D6FED4A40CF66D5E76A7F5A402025766D6FED4A40CF66D5E76A7F5A40DD09F65FE7EA4A40E3A7716F7E7D5A40DD09F65FE7EA4A40
69260	17569	106.095122	106.12527900000001	53.419438	53.407136000000001	Центральная	0103000020E6100000010000000500000054C8957A16865A401B834E081DB44A4054C8957A16865A408E59F624B0B54A400AF8359204885A408E59F624B0B54A400AF8359204885A401B834E081DB44A4054C8957A16865A401B834E081DB44A40
69388	16883	106.372001	106.400711	53.944944999999997	53.928477000000001	Центральная	0103000020E61000000100000005000000134548DDCE975A404A0B9755D8F64A40134548DDCE975A4065C22FF5F3F84A407009C03FA5995A4065C22FF5F3F84A407009C03FA5995A404A0B9755D8F64A40134548DDCE975A404A0B9755D8F64A40
68575	16988	105.55142600000001	105.579471	54.118642000000001	54.083159000000002	Федосеева	0103000020E61000000100000005000000810A47904A635A401DAF40F4A40A4B40810A47904A635A404DF73AA92F0F4B40BF7E880D16655A404DF73AA92F0F4B40BF7E880D16655A401DAF40F4A40A4B40810A47904A635A401DAF40F4A40A4B40
69398	16485	106.10999	106.125539	54.075313999999999	54.040146999999997	Совхозная	0103000020E61000000100000005000000C5387F130A875A402904728923054B40C5387F130A875A4029779FE3A3094B40D8D7BAD408885A4029779FE3A3094B40D8D7BAD408885A402904728923054B40C5387F130A875A402904728923054B40
69304	59237	105.893505	105.917867	53.885384000000002	53.873606000000002	Мархеева	0103000020E610000001000000050000000074982F2F795A4071CB4752D2EF4A400074982F2F795A406A334E4354F14A40F8C43A55BE7A5A406A334E4354F14A40F8C43A55BE7A5A4071CB4752D2EF4A400074982F2F795A4071CB4752D2EF4A40
69243	16952	106.613908	106.636959	53.761912000000002	53.748778999999999	Пуляевского	0103000020E610000001000000050000002DB0C7444AA75A403E7782FDD7DF4A402DB0C7444AA75A400937195586E14A402579AEEFC3A85A400937195586E14A402579AEEFC3A85A403E7782FDD7DF4A402DB0C7444AA75A403E7782FDD7DF4A40
69378	16843	106.138268	106.16645800000001	53.846577000000003	53.837502999999998	Центральная	0103000020E6100000010000000500000055850662D9885A40A4A65D4C33EB4A4055850662D9885A40DD4598A25CEC4A40168A743FA78A5A40DD4598A25CEC4A40168A743FA78A5A40A4A65D4C33EB4A4055850662D9885A40A4A65D4C33EB4A40
69444	16224	105.985546	106.01461500000001	53.87867	53.865143000000003	Береговая	0103000020E6100000010000000500000008AD872F137F5A4082AE7D01BDEE4A4008AD872F137F5A40F8FC304278F04A40FDC1C073EF805A40F8FC304278F04A40FDC1C073EF805A4082AE7D01BDEE4A4008AD872F137F5A4082AE7D01BDEE4A40
68932	16692	106.320761	106.351358	53.876181000000003	53.852477999999998	Окладникова	0103000020E610000001000000050000004435255987945A409D47C5FF1DED4A404435255987945A403430F2B226F04A4008CC43A67C965A403430F2B226F04A4008CC43A67C965A409D47C5FF1DED4A404435255987945A409D47C5FF1DED4A40
68570	16692	106.320761	106.351358	53.876181000000003	53.852477999999998	Ленина	0103000020E610000001000000050000004435255987945A409D47C5FF1DED4A404435255987945A403430F2B226F04A4008CC43A67C965A403430F2B226F04A4008CC43A67C965A409D47C5FF1DED4A404435255987945A409D47C5FF1DED4A40
69016	17088	105.462214	105.47365000000001	54.038412999999998	54.029412999999998	Победы	0103000020E61000000100000005000000377007EA945D5A40E38920CEC3034B40377007EA945D5A40E15E99B7EA044B4007F01648505E5A40E15E99B7EA044B4007F01648505E5A40E38920CEC3034B40377007EA945D5A40E38920CEC3034B40
69377	16647	106.29575199999999	106.317536	54.195055000000004	54.182406	Трактовая	0103000020E6100000010000000500000080EECB99ED925A400E4C6E1459174B4080EECB99ED925A40EDF5EE8FF7184B405FD3838252945A40EDF5EE8FF7184B405FD3838252945A400E4C6E1459174B4080EECB99ED925A400E4C6E1459174B40
69380	17753	105.914247	105.945768	53.376055000000001	53.359082000000001	Центральная	0103000020E61000000100000005000000D55DD905837A5A40884A2366F6AD4A40D55DD905837A5A40A73FFB9122B04A409D668176877C5A40A73FFB9122B04A409D668176877C5A40884A2366F6AD4A40D55DD905837A5A40884A2366F6AD4A40
68732	16436	106.15583100000001	106.20599199999999	53.989198999999999	53.974739	Советская	0103000020E61000000100000005000000FE2C9622F9895A4060915F3FC4FC4A40FE2C9622F9895A40321EA5129EFE4A4035CF11F92E8D5A40321EA5129EFE4A4035CF11F92E8D5A4060915F3FC4FC4A40FE2C9622F9895A4060915F3FC4FC4A40
70016	59373	104.28218699999999	104.289131	52.241163	52.237302	Майская	0103000020E61000000100000005000000CE16105A0F125A4040A374E95F1E4A40CE16105A0F125A40AC00DF6DDE1E4A40A0504F1F81125A40AC00DF6DDE1E4A40A0504F1F81125A4040A374E95F1E4A40CE16105A0F125A4040A374E95F1E4A40
68959	59196	104.344908	104.350756	52.281571999999997	52.281418000000002	Авиаторов	0103000020E610000001000000050000003E0801F912165A40BC40498105244A403E0801F912165A4012BC218D0A244A400D384BC972165A4012BC218D0A244A400D384BC972165A40BC40498105244A403E0801F912165A40BC40498105244A40
67680	52268	107.78046999999999	107.81388699999999	55.938834	55.881050999999999	Машурова	0103000020E6100000010000000500000095607138F3F15A40D68D7747C6F04B4095607138F3F15A40BA2F67B62BF84B40EEE87FB916F45A40BA2F67B62BF84B40EEE87FB916F45A40D68D7747C6F04B4095607138F3F15A40D68D7747C6F04B40
67677	52268	107.78046999999999	107.81388699999999	55.938834	55.881050999999999	Лесная	0103000020E6100000010000000500000095607138F3F15A40D68D7747C6F04B4095607138F3F15A40BA2F67B62BF84B40EEE87FB916F45A40BA2F67B62BF84B40EEE87FB916F45A40D68D7747C6F04B4095607138F3F15A40D68D7747C6F04B40
67923	52268	107.78046999999999	107.81388699999999	55.938834	55.881050999999999	Дзержинского	0103000020E6100000010000000500000095607138F3F15A40D68D7747C6F04B4095607138F3F15A40BA2F67B62BF84B40EEE87FB916F45A40BA2F67B62BF84B40EEE87FB916F45A40D68D7747C6F04B4095607138F3F15A40D68D7747C6F04B40
69122	29487	107.692471	107.70475999999999	56.071776	56.045921	Центральная	0103000020E610000001000000050000006B9BE27151EC5A408D9944BDE0054C406B9BE27151EC5A40A051BAF42F094C40DAE1AFC91AED5A40A051BAF42F094C40DAE1AFC91AED5A408D9944BDE0054C406B9BE27151EC5A408D9944BDE0054C40
69197	52287	107.09979800000001	107.11120699999999	56.357638999999999	56.350093000000001	Ленина	0103000020E61000000100000005000000338D261763C65A407EC7F0D8CF2C4C40338D261763C65A401763601DC72D4C408505F7031EC75A401763601DC72D4C408505F7031EC75A407EC7F0D8CF2C4C40338D261763C65A407EC7F0D8CF2C4C40
67937	52158	107.424629	107.488912	56.179955999999997	56.065655	Российская	0103000020E61000000100000005000000B9FB1C1F2DDB5A40D1E80E6267084C40B9FB1C1F2DDB5A40075C57CC08174C40CEA78E554ADF5A40075C57CC08174C40CEA78E554ADF5A40D1E80E6267084C40B9FB1C1F2DDB5A40D1E80E6267084C40
68637	52158	107.424629	107.488912	56.179955999999997	56.065655	Пугачева	0103000020E61000000100000005000000B9FB1C1F2DDB5A40D1E80E6267084C40B9FB1C1F2DDB5A40075C57CC08174C40CEA78E554ADF5A40075C57CC08174C40CEA78E554ADF5A40D1E80E6267084C40B9FB1C1F2DDB5A40D1E80E6267084C40
67916	52158	107.424629	107.488912	56.179955999999997	56.065655	Ленина	0103000020E61000000100000005000000B9FB1C1F2DDB5A40D1E80E6267084C40B9FB1C1F2DDB5A40075C57CC08174C40CEA78E554ADF5A40075C57CC08174C40CEA78E554ADF5A40D1E80E6267084C40B9FB1C1F2DDB5A40D1E80E6267084C40
69379	52158	107.424629	107.488912	56.179955999999997	56.065655	Карбышева	0103000020E61000000100000005000000B9FB1C1F2DDB5A40D1E80E6267084C40B9FB1C1F2DDB5A40075C57CC08174C40CEA78E554ADF5A40075C57CC08174C40CEA78E554ADF5A40D1E80E6267084C40B9FB1C1F2DDB5A40D1E80E6267084C40
67780	52158	107.424629	107.488912	56.179955999999997	56.065655	60 лет Октября	0103000020E61000000100000005000000B9FB1C1F2DDB5A40D1E80E6267084C40B9FB1C1F2DDB5A40075C57CC08174C40CEA78E554ADF5A40075C57CC08174C40CEA78E554ADF5A40D1E80E6267084C40B9FB1C1F2DDB5A40D1E80E6267084C40
68948	52264	108.427993	108.453766	55.770547000000001	55.757874999999999	Железнодорожная	0103000020E61000000100000005000000AF7AC03C641B5B405EBA490C02E14B40AF7AC03C641B5B40F583BA48A1E24B405A828C800A1D5B40F583BA48A1E24B405A828C800A1D5B405EBA490C02E14B40AF7AC03C641B5B405EBA490C02E14B40
68537	59153	107.706637	107.711614	56.025879000000003	56.018801000000003	40 лет Победы	0103000020E610000001000000050000003049658A39ED5A40E910381268024C403049658A39ED5A409C53C90050034C400C5872158BED5A409C53C90050034C400C5872158BED5A40E910381268024C403049658A39ED5A40E910381268024C40
68700	52294	107.480783	107.50351000000001	56.205554999999997	56.191237999999998	30 лет Победы	0103000020E61000000100000005000000425E0F26C5DE5A4050E09D7C7A184C40425E0F26C5DE5A40BF4351A04F1A4C4060CD018239E05A40BF4351A04F1A4C4060CD018239E05A4050E09D7C7A184C40425E0F26C5DE5A4050E09D7C7A184C40
67932	15178	107.55814599999999	107.59156299999999	56.278443000000003	56.254961999999999	Октябрьская	0103000020E610000001000000050000002A1900AAB8E35A4083DC4598A2204C402A1900AAB8E35A406B662D05A4234C4083A10E2BDCE55A406B662D05A4234C4083A10E2BDCE55A4083DC4598A2204C402A1900AAB8E35A4083DC4598A2204C40
68253	15178	107.55814599999999	107.59156299999999	56.278443000000003	56.254961999999999	Коммунистическая	0103000020E610000001000000050000002A1900AAB8E35A4083DC4598A2204C402A1900AAB8E35A406B662D05A4234C4083A10E2BDCE55A406B662D05A4234C4083A10E2BDCE55A4083DC4598A2204C402A1900AAB8E35A4083DC4598A2204C40
67931	59120	103.835994	106.018092	53.049399999999999	51.797199999999997	Мира	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
69564	59303	103.835994	106.018092	53.049399999999999	51.797199999999997	Центральная	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
68771	6008	104.209963	104.23749599999999	52.564765000000001	52.539960000000001	Ленина	0103000020E61000000100000005000000AF97A608700D5A40F792C6681D454A40AF97A608700D5A40757632384A484A40923B6C22330F5A40757632384A484A40923B6C22330F5A40F792C6681D454A40AF97A608700D5A40F792C6681D454A40
69498	4460	104.560953	104.594792	52.654387999999997	52.637493999999997	Дзержинского	0103000020E61000000100000005000000F56569A7E6235A40B7B2446799514A40F56569A7E6235A408A7269FCC2534A4009FB761211265A408A7269FCC2534A4009FB761211265A40B7B2446799514A40F56569A7E6235A40B7B2446799514A40
67820	5616	104.31489500000001	104.428406	52.494847999999998	52.453519999999997	Колхозная	0103000020E6100000010000000500000022AB5B3D27145A407C0A80F10C3A4A4022AB5B3D27145A40D93EE42D573F4A4040DAFF006B1B5A40D93EE42D573F4A4040DAFF006B1B5A407C0A80F10C3A4A4022AB5B3D27145A407C0A80F10C3A4A40
67928	5616	104.31489500000001	104.428406	52.494847999999998	52.453519999999997	Кирова	0103000020E6100000010000000500000022AB5B3D27145A407C0A80F10C3A4A4022AB5B3D27145A40D93EE42D573F4A4040DAFF006B1B5A40D93EE42D573F4A4040DAFF006B1B5A407C0A80F10C3A4A4022AB5B3D27145A407C0A80F10C3A4A40
68767	5251	104.127354	104.173114	52.447378999999998	52.427906	Муханова	0103000020E61000000100000005000000F240649126085A408FE1B19FC5364A40F240649126085A4066F50EB743394A40B41EBE4C140B5A4066F50EB743394A40B41EBE4C140B5A408FE1B19FC5364A40F240649126085A408FE1B19FC5364A40
68840	5251	104.127354	104.173114	52.447378999999998	52.427906	Геологическая	0103000020E61000000100000005000000F240649126085A408FE1B19FC5364A40F240649126085A4066F50EB743394A40B41EBE4C140B5A4066F50EB743394A40B41EBE4C140B5A408FE1B19FC5364A40F240649126085A408FE1B19FC5364A40
69051	5089	103.978629	104.00618	52.647308000000002	52.621822999999999	Ангарская	0103000020E61000000100000005000000B37A87DBA1FE5940477364E5974F4A40B37A87DBA1FE5940373811FDDA524A40EA78CC4065005A40373811FDDA524A40EA78CC4065005A40477364E5974F4A40B37A87DBA1FE5940477364E5974F4A40
67913	4659	104.216404	104.26013399999999	52.478341	52.437542000000001	Лунина	0103000020E610000001000000050000004FAE2990D90D5A402F50526001384A404FAE2990D90D5A4000AB23473A3D4A40F8A41309A6105A4000AB23473A3D4A40F8A41309A6105A402F50526001384A404FAE2990D90D5A402F50526001384A40
69189	4089	104.439932	104.44619299999999	52.537545000000001	52.524501000000001	Центральная	0103000020E61000000100000005000000B01D8CD8271C5A4012DC48D922434A40B01D8CD8271C5A406D904946CE444A4010AD156D8E1C5A406D904946CE444A4010AD156D8E1C5A4012DC48D922434A40B01D8CD8271C5A4012DC48D922434A40
69053	6099	104.130354	104.170509	52.634028999999998	52.628596000000002	Центральная	0103000020E61000000100000005000000C7B94DB857085A40BE326FD575504A40C7B94DB857085A4098DBBDDC27514A401DAB949EE90A5A4098DBBDDC27514A401DAB949EE90A5A40BE326FD575504A40C7B94DB857085A40BE326FD575504A40
68681	4602	104.496633	104.526044	52.67268	52.650958000000003	Мелехова	0103000020E610000001000000050000005247C7D5C81F5A40E8887C9752534A405247C7D5C81F5A402E56D4601A564A40731074B4AA215A402E56D4601A564A40731074B4AA215A40E8887C9752534A405247C7D5C81F5A40E8887C9752534A40
67911	4558	104.10753699999999	104.15477	52.261997999999998	52.240721999999998	Горького	0103000020E610000001000000050000000987DEE2E1065A40BFB67EFACF1E4A400987DEE2E1065A4007CF842689214A40B9196EC0E7095A4007CF842689214A40B9196EC0E7095A40BFB67EFACF1E4A400987DEE2E1065A40BFB67EFACF1E4A40
69505	2580	104.150836	104.174902	52.846600000000002	52.837842999999999	Комсомольская	0103000020E61000000100000005000000CEC3094CA7095A405D177E703E6B4A40CEC3094CA7095A40956588635D6C4A4052802898310B5A40956588635D6C4A4052802898310B5A405D177E703E6B4A40CEC3094CA7095A405D177E703E6B4A40
69507	3795	104.3228	104.339293	52.720771999999997	52.706091000000001	Школьная	0103000020E6100000010000000500000086C954C1A8145A40FE7F9C30615A4A4086C954C1A8145A40AEEFC341425C4A40C0B0FCF9B6155A40AEEFC341425C4A40C0B0FCF9B6155A40FE7F9C30615A4A4086C954C1A8145A40FE7F9C30615A4A40
68859	4383	104.60521300000001	104.644891	52.598112	52.579794	Молодежная	0103000020E610000001000000050000004D874ECFBB265A40613596B0364A4A404D874ECFBB265A402EAC1BEF8E4C4A40069FE6E445295A402EAC1BEF8E4C4A40069FE6E445295A40613596B0364A4A404D874ECFBB265A40613596B0364A4A40
69059	5770	104.42855900000001	104.445025	52.493718999999999	52.471682000000001	Российская	0103000020E61000000100000005000000045ABA826D1B5A40520E6613603C4A40045ABA826D1B5A40F834272F323F4A40C139234A7B1C5A40F834272F323F4A40C139234A7B1C5A40520E6613603C4A40045ABA826D1B5A40520E6613603C4A40
68218	5356	104.434119	104.465013	52.282558000000002	52.262498999999998	Дачная	0103000020E610000001000000050000009FE40E9BC81B5A40C91D369199214A409FE40E9BC81B5A40919C4CDC2A244A40C0CDE2C5C21D5A40919C4CDC2A244A40C0CDE2C5C21D5A40C91D369199214A409FE40E9BC81B5A40C91D369199214A40
69255	5531	104.460629	104.481317	52.166442000000004	52.154060999999999	Школьная	0103000020E61000000100000005000000B5A50EF27A1D5A40664B5645B8134A40B5A50EF27A1D5A402657B1F84D154A409180D1E5CD1E5A402657B1F84D154A409180D1E5CD1E5A40664B5645B8134A40B5A50EF27A1D5A40664B5645B8134A40
69172	3246	104.366845	104.390192	52.171900000000001	52.156061999999999	Заводской	0103000020E61000000100000005000000DF6C73637A175A40FD12F1D6F9134A40DF6C73637A175A405917B7D100164A404BCADDE7F8185A405917B7D100164A404BCADDE7F8185A40FD12F1D6F9134A40DF6C73637A175A40FD12F1D6F9134A40
67671	3893	104.436177	104.478622	52.614710000000002	52.565061	Кирова	0103000020E610000001000000050000001D91EF52EA1B5A405E9F39EB53484A401D91EF52EA1B5A40184339D1AE4E4A405A492BBEA11E5A40184339D1AE4E4A405A492BBEA11E5A405E9F39EB53484A401D91EF52EA1B5A405E9F39EB53484A40
68769	3701	104.437901	104.468345	52.766016	52.741342000000003	Комсомольская площадь	0103000020E61000000100000005000000AF78EA91061C5A405C936E4BE45E4A40AF78EA91061C5A403B1BF2CF0C624A40B08F4E5DF91D5A403B1BF2CF0C624A40B08F4E5DF91D5A405C936E4BE45E4A40AF78EA91061C5A405C936E4BE45E4A40
68946	4772	104.151977	104.174318	52.532960000000003	52.509177999999999	Центральная	0103000020E61000000100000005000000A12FBDFDB9095A40DDEBA4BE2C414A40A12FBDFDB9095A40C009850838444A40AA46AF06280B5A40C009850838444A40AA46AF06280B5A40DDEBA4BE2C414A40A12FBDFDB9095A40DDEBA4BE2C414A40
68492	59123	104.419234	104.420196	52.245446999999999	52.243533999999997	Совхозная	0103000020E61000000100000005000000C3D7D7BAD41A5A4066BB421F2C1F4A40C3D7D7BAD41A5A405EF3AACE6A1F4A403E7AC37DE41A5A405EF3AACE6A1F4A403E7AC37DE41A5A4066BB421F2C1F4A40C3D7D7BAD41A5A4066BB421F2C1F4A40
68204	3344	104.18342699999999	104.23823299999999	52.224190999999998	52.194367999999997	Мира	0103000020E61000000100000005000000048D9944BD0B5A40C8B1F50CE1184A40048D9944BD0B5A405D876A4AB21C4A40FDF49F353F0F5A405D876A4AB21C4A40FDF49F353F0F5A40C8B1F50CE1184A40048D9944BD0B5A40C8B1F50CE1184A40
68558	3344	104.18342699999999	104.23823299999999	52.224190999999998	52.194367999999997	Лесная	0103000020E61000000100000005000000048D9944BD0B5A40C8B1F50CE1184A40048D9944BD0B5A405D876A4AB21C4A40FDF49F353F0F5A405D876A4AB21C4A40FDF49F353F0F5A40C8B1F50CE1184A40048D9944BD0B5A40C8B1F50CE1184A40
68508	59150	104.15256100000001	104.15556100000001	52.302943999999997	52.298869000000003	Садовая	0103000020E610000001000000050000004969368FC3095A40E564E25641264A404969368FC3095A407C4276DEC6264A401EE21FB6F4095A407C4276DEC6264A401EE21FB6F4095A40E564E25641264A404969368FC3095A40E564E25641264A40
67664	2312	105.304892	105.34415799999999	52.313186000000002	52.295068000000001	Мира	0103000020E61000000100000005000000F833BC5983535A404E0CC9C9C4254A40F833BC5983535A4054C8957A16284A4008AA46AF06565A4054C8957A16284A4008AA46AF06565A404E0CC9C9C4254A40F833BC5983535A404E0CC9C9C4254A40
68679	3155	104.03907599999999	104.072062	52.373584999999999	52.354052000000003	Мелиораторов	0103000020E61000000100000005000000BE839F3880025A40AD8A7093512D4A40BE839F3880025A4059A31EA2D12F4A403352EFA99C045A4059A31EA2D12F4A403352EFA99C045A40AD8A7093512D4A40BE839F3880025A40AD8A7093512D4A40
67666	3034	104.507063	104.549418	52.619034999999997	52.591245999999998	Советская	0103000020E61000000100000005000000BF805EB873205A4006F2ECF2AD4B4A40BF805EB873205A40280AF4893C4F4A405C751DAA29235A40280AF4893C4F4A405C751DAA29235A4006F2ECF2AD4B4A40BF805EB873205A4006F2ECF2AD4B4A40
69191	3034	104.507063	104.549418	52.619034999999997	52.591245999999998	Веселая	0103000020E61000000100000005000000BF805EB873205A4006F2ECF2AD4B4A40BF805EB873205A40280AF4893C4F4A405C751DAA29235A40280AF4893C4F4A405C751DAA29235A4006F2ECF2AD4B4A40BF805EB873205A4006F2ECF2AD4B4A40
69504	6038	104.229366	104.24885999999999	52.528269999999999	52.504607	Мира	0103000020E610000001000000050000001E34BBEEAD0E5A40952A51F696404A401E34BBEEAD0E5A409DBAF2599E434A4015527E52ED0F5A409DBAF2599E434A4015527E52ED0F5A40952A51F696404A401E34BBEEAD0E5A40952A51F696404A40
68857	2889	104.854432	104.88785	51.865017999999999	51.840440999999998	Октябрьская	0103000020E61000000100000005000000FA298E03AF365A40D89B189293EB4940FA298E03AF365A40C539EAE8B8EE49403B70CE88D2385A40C539EAE8B8EE49403B70CE88D2385A40D89B189293EB4940FA298E03AF365A40D89B189293EB4940
68889	2889	104.854432	104.88785	51.865017999999999	51.840440999999998	Горького	0103000020E61000000100000005000000FA298E03AF365A40D89B189293EB4940FA298E03AF365A40C539EAE8B8EE49403B70CE88D2385A40C539EAE8B8EE49403B70CE88D2385A40D89B189293EB4940FA298E03AF365A40D89B189293EB4940
69052	3878	103.835994	106.018092	53.049399999999999	51.797199999999997	Кыцигировская	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
68219	5745	104.37677100000001	104.425011	52.460720000000002	52.427872999999998	Ленина	0103000020E6100000010000000500000033C51C041D185A40B3EBDE8AC4364A4033C51C041D185A407B4E7ADFF83A4A402D5C5661331B5A407B4E7ADFF83A4A402D5C5661331B5A40B3EBDE8AC4364A4033C51C041D185A40B3EBDE8AC4364A40
69348	3978	104.48897100000001	104.523089	52.558376000000003	52.544840000000001	Депутатская	0103000020E61000000100000005000000516C054D4B1F5A40BDC62E51BD454A40516C054D4B1F5A40876F61DD78474A406EF9484A7A215A40876F61DD78474A406EF9484A7A215A40BDC62E51BD454A40516C054D4B1F5A40BDC62E51BD454A40
68113	2801	104.277112	104.313422	52.429881999999999	52.416108999999999	Гагарина	0103000020E610000001000000050000001155F833BC115A401F49490F43354A401155F833BC115A40CD91955F06374A4034F6251B0F145A40CD91955F06374A4034F6251B0F145A401F49490F43354A401155F833BC115A401F49490F43354A40
69193	5136	103.94936199999999	103.963582	52.727071000000002	52.714821000000001	Трактовая	0103000020E610000001000000050000002B84D558C2FC59403CBF28417F5B4A402B84D558C2FC59405D6F9BA9105D4A40EA40D653ABFD59405D6F9BA9105D4A40EA40D653ABFD59403CBF28417F5B4A402B84D558C2FC59403CBF28417F5B4A40
69256	4274	104.52692399999999	104.549876	52.659664999999997	52.648242000000003	Трактовая	0103000020E610000001000000050000008FDE701FB9215A4063F20698F9524A408FDE701FB9215A406DA818E76F544A40BD361B2B31235A406DA818E76F544A40BD361B2B31235A4063F20698F9524A408FDE701FB9215A4063F20698F9524A40
69058	5007	103.95792299999999	103.974362	52.707630000000002	52.693491000000002	Центральная	0103000020E610000001000000050000008445459C4EFD594001892650C4584A408445459C4EFD594091D5AD9E935A4A40C51D6FF25BFE594091D5AD9E935A4A40C51D6FF25BFE594001892650C4584A408445459C4EFD594001892650C4584A40
69497	3775	104.43825200000001	104.45299300000001	52.672941999999999	52.653891000000002	Школьная	0103000020E6100000010000000500000006DA1D520C1C5A400A1346B3B2534A4006DA1D520C1C5A406B0DA5F622564A4049145AD6FD1C5A406B0DA5F622564A4049145AD6FD1C5A400A1346B3B2534A4006DA1D520C1C5A400A1346B3B2534A40
68560	4729	104.269063	104.31706	52.466431999999998	52.458815999999999	Загоскина	0103000020E610000001000000050000001364045438115A40D670917BBA3A4A401364045438115A4068E7340BB43B4A40AAB706B64A145A4068E7340BB43B4A40AAB706B64A145A40D670917BBA3A4A401364045438115A40D670917BBA3A4A40
69061	6146	104.25119599999999	104.263323	52.587975	52.575892000000003	40 лет Октября	0103000020E61000000100000005000000B438639813105A4097033DD4B6494A40B438639813105A40CCEEC9C3424B4A403752B648DA105A40CCEEC9C3424B4A403752B648DA105A4097033DD4B6494A40B438639813105A4097033DD4B6494A40
68868	5406	104.900992	104.919785	52.282277000000001	52.270578999999998	Учительская	0103000020E610000001000000050000004A7D59DAA9395A4000FE2955A2224A404A7D59DAA9395A40DDB419A721244A407D96E7C1DD3A5A40DDB419A721244A407D96E7C1DD3A5A4000FE2955A2224A404A7D59DAA9395A4000FE2955A2224A40
68882	59181	104.014049	104.043173	52.814053000000001	52.798952	Школьная	0103000020E61000000100000005000000A8E2C62DE6005A407289230F44664A40A8E2C62DE6005A40F81A82E332684A407EC4AF58C3025A40F81A82E332684A407EC4AF58C3025A407289230F44664A40A8E2C62DE6005A407289230F44664A40
69585	59181	104.014049	104.043173	52.814053000000001	52.798952	Советская	0103000020E61000000100000005000000A8E2C62DE6005A407289230F44664A40A8E2C62DE6005A40F81A82E332684A407EC4AF58C3025A40F81A82E332684A407EC4AF58C3025A407289230F44664A40A8E2C62DE6005A407289230F44664A40
69496	3969	104.439105	104.455365	52.632809999999999	52.613971999999997	Первомайская	0103000020E61000000100000005000000A5A0DB4B1A1C5A4071546EA2964E4A40A5A0DB4B1A1C5A40774A07EBFF504A408EAF3DB3241D5A40774A07EBFF504A408EAF3DB3241D5A4071546EA2964E4A40A5A0DB4B1A1C5A4071546EA2964E4A40
69000	2699	104.190883	104.21083400000001	52.973494000000002	52.956983999999999	Центральная	0103000020E610000001000000050000003197546D370C5A40CB65A3737E7A4A403197546D370C5A40166D8E739B7C4A40A2B8E34D7E0D5A40166D8E739B7C4A40A2B8E34D7E0D5A40CB65A3737E7A4A403197546D370C5A40CB65A3737E7A4A40
69259	5183	104.006153	104.029788	52.749240999999998	52.730600000000003	Калинина	0103000020E610000001000000050000006D718DCF64005A40933A014D845D4A406D718DCF64005A4042E90B21E75F4A400C74ED0BE8015A4042E90B21E75F4A400C74ED0BE8015A40933A014D845D4A406D718DCF64005A40933A014D845D4A40
69190	59222	104.181468	104.193838	52.900675999999997	52.894140999999998	Некрасова	0103000020E610000001000000050000005051F52B9D0B5A40A181583673724A405051F52B9D0B5A406325E65949734A4036AE7FD7670C5A406325E65949734A4036AE7FD7670C5A40A181583673724A405051F52B9D0B5A40A181583673724A40
69050	4077	104.491692	104.524023	52.571426000000002	52.557845	Придорожная	0103000020E610000001000000050000001CEDB8E1771F5A405A9E077767474A401CEDB8E1771F5A40C40AB77C24494A4084D6C39789215A40C40AB77C24494A4084D6C39789215A405A9E077767474A401CEDB8E1771F5A405A9E077767474A40
69192	5573	104.57211	104.594675	52.103440999999997	52.090373	Лесная	0103000020E61000000100000005000000BBED42739D245A4080B8AB57910B4A40BBED42739D245A406308008E3D0D4A40EC2FBB270F265A406308008E3D0D4A40EC2FBB270F265A4080B8AB57910B4A40BBED42739D245A4080B8AB57910B4A40
69500	4503	104.69301400000001	104.71631600000001	52.549550000000004	52.530510999999997	Центральная	0103000020E61000000100000005000000E46A64575A2C5A408995D1C8E7434A40E46A64575A2C5A4027C286A757464A408066101FD82D5A4027C286A757464A408066101FD82D5A408995D1C8E7434A40E46A64575A2C5A408995D1C8E7434A40
69185	2346	105.40110199999999	105.420793	52.047296000000003	52.026924999999999	Байкальская	0103000020E610000001000000050000000D17B9A7AB595A40EF38454772034A400D17B9A7AB595A40A69D9ACB0D064A40B058C345EE5A5A40A69D9ACB0D064A40B058C345EE5A5A40EF38454772034A400D17B9A7AB595A40EF38454772034A40
68482	59149	104.717691	104.758537	51.962021999999997	51.939324999999997	 Ленина	0103000020E610000001000000050000008C683BA6EE2D5A4058A835CD3BF849408C683BA6EE2D5A402904728923FB494095F3C5DE8B305A402904728923FB494095F3C5DE8B305A4058A835CD3BF849408C683BA6EE2D5A4058A835CD3BF84940
69430	2545	104.041493	104.063546	52.833843999999999	52.814684999999997	Маяковского	0103000020E61000000100000005000000D48041D2A7025A4058C51B9947684A40D48041D2A7025A40A0FB7266BB6A4A40AAF23D2311045A40A0FB7266BB6A4A40AAF23D2311045A4058C51B9947684A40D48041D2A7025A4058C51B9947684A40
69512	59271	102.25434799999999	102.27220699999999	54.211559999999999	54.201138999999998	Школьная	0103000020E610000001000000050000006473D53C479059409E7939ECBE194B406473D53C479059402592E865141B4B4081AFE8D66B9159402592E865141B4B4081AFE8D66B9159409E7939ECBE194B406473D53C479059409E7939ECBE194B40
67918	1076	101.841869	101.86955500000001	53.906464	53.88091	Мира	0103000020E610000001000000050000000AA1832EE1755940145CACA8C1F04A400AA1832EE17559402C80290307F44A40B1C403CAA67759402C80290307F44A40B1C403CAA6775940145CACA8C1F04A400AA1832EE1755940145CACA8C1F04A40
69506	911	102.217562	102.231082	54.07159	54.061587000000003	Центральная	0103000020E610000001000000050000008DB62A89EC8D5940EC6D3315E2074B408DB62A89EC8D59403E5C72DC29094B406F2C280CCA8E59403E5C72DC29094B406F2C280CCA8E5940EC6D3315E2074B408DB62A89EC8D5940EC6D3315E2074B40
69244	956	102.313682	102.326133	53.961545000000001	53.940466999999998	Новокшонова	0103000020E6100000010000000500000002D6AA5D13945940CEFBFF3861F84A4002D6AA5D13945940F05014E813FB4A405E49F25CDF945940F05014E813FB4A405E49F25CDF945940CEFBFF3861F84A4002D6AA5D13945940CEFBFF3861F84A40
68682	595	102.068191	102.086974	53.959018	53.944504999999999	Лесная	0103000020E610000001000000050000006BB8C83D5D84594049F4328AE5F84A406BB8C83D5D8459403E23111AC1FA4A408C6665FB908559403E23111AC1FA4A408C6665FB9085594049F4328AE5F84A406BB8C83D5D84594049F4328AE5F84A40
68567	465	101.95222699999999	101.987387	53.943959999999997	53.921790999999999	40 лет Победы	0103000020E6100000010000000500000090D78349F17C5940A25F5B3FFDF54A4090D78349F17C5940B75D68AED3F84A40B75F3E59317F5940B75D68AED3F84A40B75F3E59317F5940A25F5B3FFDF54A4090D78349F17C5940A25F5B3FFDF54A40
69073	32211	101.729418	101.756287	53.819253000000003	53.807281000000003	Школьная	0103000020E6100000010000000500000047C7D5C8AE6E594052D7DAFB54E74A4047C7D5C8AE6E594030134548DDE84A40F5D896016770594030134548DDE84A40F5D896016770594052D7DAFB54E74A4047C7D5C8AE6E594052D7DAFB54E74A40
67687	828	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Юбилейный	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
67690	828	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Строителей	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
67693	828	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Олимпийский	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
68252	828	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Октябрьский	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
68939	828	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Молодежный	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
67889	828	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Мирный	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
67884	828	102.00609900000001	102.224677	54.119450000000001	53.976168999999999	микрорайон Ленинградский	0103000020E6100000010000000500000074620FED638059403C2F151BF3FC4A4074620FED63805940ECC039234A0F4B4075CAA31B618E5940ECC039234A0F4B4075CAA31B618E59403C2F151BF3FC4A4074620FED638059403C2F151BF3FC4A40
68556	552	101.995723	102.028153	53.856572999999997	53.843542999999997	Черемушки	0103000020E610000001000000050000000038F6ECB97F594086E28E37F9EB4A400038F6ECB97F59407CD11E2FA4ED4A4032923D42CD8159407CD11E2FA4ED4A4032923D42CD81594086E28E37F9EB4A400038F6ECB97F594086E28E37F9EB4A40
69495	12	102.02493699999999	102.056746	54.117508000000001	54.091248999999998	Молодежная	0103000020E6100000010000000500000076DD5B91988159407765170CAE0B4B4076DD5B91988159405A828C800A0F4B40728BF9B9A18359405A828C800A0F4B40728BF9B9A18359407765170CAE0B4B4076DD5B91988159407765170CAE0B4B40
69606	12	102.02493699999999	102.056746	54.117508000000001	54.091248999999998	Вокзальная	0103000020E6100000010000000500000076DD5B91988159407765170CAE0B4B4076DD5B91988159405A828C800A0F4B40728BF9B9A18359405A828C800A0F4B40728BF9B9A18359407765170CAE0B4B4076DD5B91988159407765170CAE0B4B40
69310	678	102.122979	102.13328199999999	53.967489	53.955908999999998	Солнечная	0103000020E6100000010000000500000011C64FE3DE875940DD79E2395BFA4A4011C64FE3DE875940B01EF7ADD6FB4A404FC939B187885940B01EF7ADD6FB4A404FC939B187885940DD79E2395BFA4A4011C64FE3DE875940DD79E2395BFA4A40
69188	338	101.82886999999999	101.862872	53.626499000000003	53.612907	Центральная	0103000020E61000000100000005000000ACA8C1340C755940A73E90BC73CE4A40ACA8C1340C75594005FD851E31D04A4095287B4B3977594005FD851E31D04A4095287B4B39775940A73E90BC73CE4A40ACA8C1340C755940A73E90BC73CE4A40
69194	806	102.077066	102.090639	53.986859000000003	53.974764999999998	Школьная	0103000020E610000001000000050000008C683BA6EE84594089247A19C5FC4A408C683BA6EE845940B3614D6551FE4A407F2F8507CD855940B3614D6551FE4A407F2F8507CD85594089247A19C5FC4A408C683BA6EE84594089247A19C5FC4A40
68539	202	101.673067	101.735086	53.589466000000002	53.555481	Полевая	0103000020E6100000010000000500000014419C87136B594052465C001AC74A4014419C87136B59404E0D349F73CB4A40D66F26A60B6F59404E0D349F73CB4A40D66F26A60B6F594052465C001AC74A4014419C87136B594052465C001AC74A40
67912	32420	101.945409	102.00778800000001	54.146023	54.118996000000003	Чкалова	0103000020E610000001000000050000000516C094817C59406B2DCC423B0F4B400516C094817C59405EBBB4E1B0124B4048533D997F8059405EBBB4E1B0124B4048533D997F8059406B2DCC423B0F4B400516C094817C59406B2DCC423B0F4B40
69367	32420	101.945409	102.00778800000001	54.146023	54.118996000000003	Вокзальная	0103000020E610000001000000050000000516C094817C59406B2DCC423B0F4B400516C094817C59405EBBB4E1B0124B4048533D997F8059405EBBB4E1B0124B4048533D997F8059406B2DCC423B0F4B400516C094817C59406B2DCC423B0F4B40
69056	32382	101.304362	101.341103	53.699210000000001	53.670361	Центральная	0103000020E610000001000000050000004A09C1AA7A535940C6C1A563CED54A404A09C1AA7A535940A18499B67FD94A405264ADA1D4555940A18499B67FD94A405264ADA1D4555940C6C1A563CED54A404A09C1AA7A535940C6C1A563CED54A40
68467	1273	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Трактовая	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
68325	1273	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Садовая	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
68329	1273	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Орджоникидзе	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
42049	1273	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Куйбышева	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
68498	1273	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Кирова	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
68320	1273	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Бограда	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
68507	1273	102.01634900000001	102.100763	53.955167000000003	53.874254000000001	Ангарская	0103000020E61000000100000005000000A114ADDC0B815940D732198EE7EF4A40A114ADDC0B815940F69B89E942FA4A406669A7E672865940F69B89E942FA4A406669A7E672865940D732198EE7EF4A40A114ADDC0B815940D732198EE7EF4A40
69049	835	102.240128	102.271057	53.867570000000001	53.851708000000002	Центральная	0103000020E61000000100000005000000A6B6D4415E8F5940ECDE8AC404ED4A40A6B6D4415E8F5940D07EA4880CEF4A40859675FF58915940D07EA4880CEF4A40859675FF58915940ECDE8AC404ED4A40A6B6D4415E8F5940ECDE8AC404ED4A40
69047	303	101.313552	101.330305	53.471871999999998	53.460379000000003	Школьная	0103000020E610000001000000050000001B66683C11545940F261F6B2EDBA4A401B66683C11545940F5F23B4D66BC4A40232D95B723555940F5F23B4D66BC4A40232D95B723555940F261F6B2EDBA4A401B66683C11545940F261F6B2EDBA4A40
69179	32257	102.271084	102.317114	54.281498999999997	54.267378000000001	Центральная	0103000020E61000000100000005000000029EB47059915940BFD53A7139224B40029EB47059915940A86DC32808244B40A4C684984B945940A86DC32808244B40A4C684984B945940BFD53A7139224B40029EB47059915940BFD53A7139224B40
69536	59283	102.439258	102.44913	53.952495999999996	53.933782999999998	Молодежная	0103000020E61000000100000005000000682096CD1C9C5940C7478B3386F74A40682096CD1C9C594010C99063EBF94A40C269C18BBE9C594010C99063EBF94A40C269C18BBE9C5940C7478B3386F74A40682096CD1C9C5940C7478B3386F74A40
68551	32132	101.60616899999999	101.643458	53.881307999999997	53.864325999999998	Ленина	0103000020E6100000010000000500000056B60F79CB6659408F8AFF3BA2EE4A4056B60F79CB66594001DA56B3CEF04A405F96766A2E69594001DA56B3CEF04A405F96766A2E6959408F8AFF3BA2EE4A4056B60F79CB6659408F8AFF3BA2EE4A40
69499	32169	101.530917	101.566616	53.791268000000002	53.777850999999998	Речная	0103000020E61000000100000005000000FDF84B8BFA61594098141F9F90E34A40FDF84B8BFA615940882F134548E54A40FB58C16F43645940882F134548E54A40FB58C16F4364594098141F9F90E34A40FDF84B8BFA61594098141F9F90E34A40
69182	32486	100.403496	102.674796	54.497895999999997	53.254897999999997	Школьная	0103000020E610000001000000050000004704E3E0D21959406CE8667FA0A04A404704E3E0D219594094675E0EBB3F4B402FDE8FDB2FAB594094675E0EBB3F4B402FDE8FDB2FAB59406CE8667FA0A04A404704E3E0D21959406CE8667FA0A04A40
69173	30900	102.04814	102.068963	53.419517999999997	53.406562000000001	Набережная	0103000020E610000001000000050000004968CBB914835940EFE53E390AB44A404968CBB914835940AA0A0DC4B2B54A409468C9E369845940AA0A0DC4B2B54A409468C9E369845940EFE53E390AB44A404968CBB914835940EFE53E390AB44A40
69042	31329	101.642865	101.659789	53.295062000000001	53.276446999999997	Советская	0103000020E610000001000000050000008EAF3DB324695940E509849D62A34A408EAF3DB3246959406C257497C4A54A40AD50A4FB396A59406C257497C4A54A40AD50A4FB396A5940E509849D62A34A408EAF3DB324695940E509849D62A34A40
69170	31137	102.040424	102.067894	53.370381999999999	53.363596000000001	Трактовая	0103000020E610000001000000050000004E7E8B4E968259406C7A50508AAE4A404E7E8B4E96825940778368AD68AF4A400E66136058845940778368AD68AF4A400E661360588459406C7A50508AAE4A404E7E8B4E968259406C7A50508AAE4A40
68670	31441	101.522401	101.576156	53.429155000000002	53.410223000000002	Леспромхозовская	0103000020E6100000010000000500000074999A046F6159409488F02F82B44A4074999A046F6159401BF5108DEEB64A403A596ABDDF6459401BF5108DEEB64A403A596ABDDF6459409488F02F82B44A4074999A046F6159409488F02F82B44A40
68811	30690	102.280939	102.334613	53.500552999999996	53.482922000000002	Юбилейная	0103000020E61000000100000005000000F14A92E7FA9159406C425A63D0BD4A40F14A92E7FA9159401475E61E12C04A4041F4A44C6A9559401475E61E12C04A4041F4A44C6A9559406C425A63D0BD4A40F14A92E7FA9159406C425A63D0BD4A40
68672	31720	102.208732	102.254465	53.627353999999997	53.609926000000002	переулок Солнечный	0103000020E610000001000000050000003C6876DD5B8D5940747D1F0E12CE4A403C6876DD5B8D5940E481C8224DD04A40813E912749905940E481C8224DD04A40813E912749905940747D1F0E12CE4A403C6876DD5B8D5940747D1F0E12CE4A40
69528	59279	102.11705000000001	102.129941	53.353326000000003	53.334800999999999	Дудкина	0103000020E61000000100000005000000CC7F48BF7D87594084D558C2DAAA4A40CC7F48BF7D875940CB694FC939AD4A40365A0EF450885940CB694FC939AD4A40365A0EF45088594084D558C2DAAA4A40CC7F48BF7D87594084D558C2DAAA4A40
69175	31811	102.31278399999999	102.326241	53.730958999999999	53.709086999999997	Верхняя	0103000020E6100000010000000500000092AD2EA7049459406682E15CC3DA4A4092AD2EA704945940C2DB831090DD4A405167EE21E1945940C2DB831090DD4A405167EE21E19459406682E15CC3DA4A4092AD2EA7049459406682E15CC3DA4A40
67986	1871	102.295024	102.33712800000001	53.685763999999999	53.654972999999998	микр.Солерудник	0103000020E610000001000000050000003FE257ACE1925940AA61BF27D6D34A403FE257ACE19259401763601DC7D74A4038A45181939559401763601DC7D74A4038A4518193955940AA61BF27D6D34A403FE257ACE1925940AA61BF27D6D34A40
68125	59132	102.295024	102.33712800000001	53.685763999999999	53.654972999999998	Школьная	0103000020E610000001000000050000003FE257ACE1925940AA61BF27D6D34A403FE257ACE19259401763601DC7D74A4038A45181939559401763601DC7D74A4038A4518193955940AA61BF27D6D34A403FE257ACE1925940AA61BF27D6D34A40
68671	30803	102.133399	102.178594	53.471769999999999	53.453783999999999	Ленина	0103000020E610000001000000050000006C94F59B898859405AB9179815BA4A406C94F59B89885940F19D98F562BC4A40C25087156E8B5940F19D98F562BC4A40C25087156E8B59405AB9179815BA4A406C94F59B898859405AB9179815BA4A40
69044	31499	101.860823	101.900026	53.599299000000002	53.576326000000002	Дорожная	0103000020E6100000010000000500000041295AB917775940D1EAE40CC5C94A4041295AB91777594044C362D4B5CC4A402EE3A6069A79594044C362D4B5CC4A402EE3A6069A795940D1EAE40CC5C94A4041295AB917775940D1EAE40CC5C94A40
69583	59320	101.660436	101.683864	53.383591000000003	53.378349	Центральная	0103000020E6100000010000000500000078465B95446A5940B6BC72BD6DB04A4078465B95446A59401D05888219B14A405ABA826DC46B59401D05888219B14A405ABA826DC46B5940B6BC72BD6DB04A4078465B95446A5940B6BC72BD6DB04A40
68664	30732	102.210385	102.247449	53.48357	53.470070999999997	Трактовая	0103000020E610000001000000050000006AA4A5F2768D594025E659492BBC4A406AA4A5F2768D5940D2A92B9FE5BD4A40639B5434D68F5940D2A92B9FE5BD4A40639B5434D68F594025E659492BBC4A406AA4A5F2768D594025E659492BBC4A40
69252	30636	102.322755	102.341126	53.565910000000002	53.555641000000001	Центральная	0103000020E61000000100000005000000B6679604A89459408BA8893E1FC74A40B6679604A89459405C3D27BD6FC84A402E742502D59559405C3D27BD6FC84A402E742502D59559408BA8893E1FC74A40B6679604A89459408BA8893E1FC74A40
69043	32036	102.487138	102.517366	53.745061999999997	53.723917	Ленина	0103000020E61000000100000005000000E3A8DC442D9F59405C02F04FA9DC4A40E3A8DC442D9F594005BF0D315EDF4A40FD8348861CA1594005BF0D315EDF4A40FD8348861CA159405C02F04FA9DC4A40E3A8DC442D9F59405C02F04FA9DC4A40
69019	30586	102.357771	102.378514	53.516627999999997	53.507558000000003	Школьная	0103000020E61000000100000005000000431D56B8E59659405E6919A9F7C04A40431D56B8E59659405419C6DD20C24A4000C5C892399859405419C6DD20C24A4000C5C892399859405E6919A9F7C04A40431D56B8E59659405E6919A9F7C04A40
69125	30996	102.346992	102.360242	53.401665999999999	53.389541999999999	Центральная	0103000020E6100000010000000500000050FEEE1D359659408F352383DCB14A4050FEEE1D3596594023F59ECA69B34A40522976340E97594023F59ECA69B34A40522976340E9759408F352383DCB14A4050FEEE1D359659408F352383DCB14A40
69526	59277	102.528344	102.54145	53.404032999999998	53.385159999999999	Центральная	0103000020E610000001000000050000006C425A63D0A159401ADD41EC4CB14A406C425A63D0A159409CC0745AB7B34A40D49AE61DA7A259409CC0745AB7B34A40D49AE61DA7A259401ADD41EC4CB14A406C425A63D0A159401ADD41EC4CB14A40
69248	30489	102.453191	102.474121	53.413066999999998	53.392758000000001	Центральная	0103000020E61000000100000005000000DCF5D214019D5940069FE6E445B24A40DCF5D214019D594046072461DFB44A4032569BFF579E594046072461DFB44A4032569BFF579E5940069FE6E445B24A40DCF5D214019D5940069FE6E445B24A40
69060	59207	102.13251	102.14891299999999	53.645564	53.626494000000001	переулок Верхний	0103000020E610000001000000050000002619390B7B885940F39194F430D04A402619390B7B885940CBBC55D7A1D24A40C03C64CA87895940CBBC55D7A1D24A40C03C64CA87895940F39194F430D04A402619390B7B885940F39194F430D04A40
69127	1762	102.00581200000001	102.02455	53.354933000000003	53.336629000000002	Центральная	0103000020E61000000100000005000000297B4B395F8059404EF1B8A816AB4A40297B4B395F805940B6A2CD716EAD4A407AC7293A92815940B6A2CD716EAD4A407AC7293A928159404EF1B8A816AB4A40297B4B395F8059404EF1B8A816AB4A40
69041	31041	102.220725	102.253468	53.347048000000001	53.334009999999999	Центральная	0103000020E61000000100000005000000371AC05B208E5940BB44F5D6C0AA4A40371AC05B208E59403412A1116CAC4A4048A5D8D1389059403412A1116CAC4A4048A5D8D138905940BB44F5D6C0AA4A40371AC05B208E5940BB44F5D6C0AA4A40
68770	31589	101.98929200000001	102.023571	53.535105999999999	53.517645999999999	Школьная	0103000020E61000000100000005000000728C648F507F5940DE73603942C24A40728C648F507F59405AF2785A7EC44A409488F02F828159405AF2785A7EC44A409488F02F82815940DE73603942C24A40728C648F507F5940DE73603942C24A40
69045	30430	102.489473	102.501583	53.514164999999998	53.505398999999997	пер.Клубный	0103000020E610000001000000050000009AD18F86539F59402E3718EAB0C04A409AD18F86539F5940B9DFA128D0C14A40B14E95EF19A05940B9DFA128D0C14A40B14E95EF19A059402E3718EAB0C04A409AD18F86539F59402E3718EAB0C04A40
69508	59268	102.392815	102.423582	53.715353999999998	53.706529000000003	Олейникова	0103000020E61000000100000005000000359886E1239959407A56D28A6FDA4A40359886E123995940098849B890DB4A40274BADF71B9B5940098849B890DB4A40274BADF71B9B59407A56D28A6FDA4A40359886E1239959407A56D28A6FDA4A40
69322	28658	100.336733	102.73019499999999	53.816398999999997	52.749039000000003	Механизаторов	0103000020E61000000100000005000000F99E91088D155940DB368C82E05F4A40F99E91088D15594059BE2EC37FE84A40F92CCF83BBAE594059BE2EC37FE84A40F92CCF83BBAE5940DB368C82E05F4A40F99E91088D155940DB368C82E05F4A40
68954	1962	102.46477899999999	102.475109	53.724347999999999	53.719147999999997	Ербанова	0103000020E6100000010000000500000086376BF0BE9D5940ED7DAA0A0DDC4A4086376BF0BE9D594025766D6FB7DC4A404242942F689E594025766D6FB7DC4A404242942F689E5940ED7DAA0A0DDC4A4086376BF0BE9D5940ED7DAA0A0DDC4A40
69012	30390	102.42113000000001	102.440264	53.561396000000002	53.551403999999998	Центральная	0103000020E6100000010000000500000054573ECBF39A59401971016894C64A4054573ECBF39A5940780DFAD2DBC74A40CB660E492D9C5940780DFAD2DBC74A40CB660E492D9C59401971016894C64A4054573ECBF39A59401971016894C64A40
67917	30085	102.467016	102.53517100000001	53.577737999999997	53.534320000000001	Победы	0103000020E610000001000000050000005CAD1397E39D5940A3CC069964C44A405CAD1397E39D594006D49B51F3C94A4021B1DD3D40A2594006D49B51F3C94A4021B1DD3D40A25940A3CC069964C44A405CAD1397E39D5940A3CC069964C44A40
68189	30085	102.467016	102.53517100000001	53.577737999999997	53.534320000000001	Ленина	0103000020E610000001000000050000005CAD1397E39D5940A3CC069964C44A405CAD1397E39D594006D49B51F3C94A4021B1DD3D40A2594006D49B51F3C94A4021B1DD3D40A25940A3CC069964C44A405CAD1397E39D5940A3CC069964C44A40
68187	30085	102.467016	102.53517100000001	53.577737999999997	53.534320000000001	Лазо	0103000020E610000001000000050000005CAD1397E39D5940A3CC069964C44A405CAD1397E39D594006D49B51F3C94A4021B1DD3D40A2594006D49B51F3C94A4021B1DD3D40A25940A3CC069964C44A405CAD1397E39D5940A3CC069964C44A40
69174	30851	102.098482	102.123706	53.445306000000002	53.428871000000001	Набережная	0103000020E61000000100000005000000A94F72874D865940F699B33EE5B64A40A94F72874D865940365B79C9FFB84A406A1492CCEA875940365B79C9FFB84A406A1492CCEA875940F699B33EE5B64A40A94F72874D865940F699B33EE5B64A40
69177	31289	102.125647	102.14019999999999	53.310355000000001	53.299981000000002	Юбилейная	0103000020E61000000100000005000000CBF5B6990A885940F03504C765A64A40CBF5B6990A88594036936FB6B9A74A408CB96B09F988594036936FB6B9A74A408CB96B09F9885940F03504C765A64A40CBF5B6990A885940F03504C765A64A40
69491	30953	102.023724	102.047808	53.388640000000002	53.379241	Центральная	0103000020E610000001000000050000005708ABB184815940B32616F88AB04A405708ABB1848159406FF59CF4BEB14A402E1F49490F8359406FF59CF4BEB14A402E1F49490F835940B32616F88AB04A405708ABB184815940B32616F88AB04A40
68547	2351	102.638845	102.669253	53.493557000000003	53.457323000000002	Школьная	0103000020E61000000100000005000000A48D23D6E2A85940B45A608F89BA4A40A48D23D6E2A859401FDB32E02CBF4A40FEEF880AD5AA59401FDB32E02CBF4A40FEEF880AD5AA5940B45A608F89BA4A40A48D23D6E2A85940B45A608F89BA4A40
68901	31783	102.20389	102.234118	53.695200999999997	53.672894999999997	Новая	0103000020E61000000100000005000000D07EA4880C8D59402A52616C21D64A40D07EA4880C8D5940C092AB58FCD84A40EA5910CAFB8E5940C092AB58FCD84A40EA5910CAFB8E59402A52616C21D64A40D07EA4880C8D59402A52616C21D64A40
69251	31645	102.129204	102.166556	53.556480999999998	53.539816000000002	Первомайская	0103000020E61000000100000005000000CBA0DAE044885940C4EDD0B018C54A40CBA0DAE04488594035ECF7C43AC74A40F73C7FDAA88A594035ECF7C43AC74A40F73C7FDAA88A5940C4EDD0B018C54A40CBA0DAE044885940C4EDD0B018C54A40
69131	1841	101.94984700000001	101.973966	53.511938000000001	53.498223000000003	Ветеранов	0103000020E610000001000000050000000A4D124BCA7C5940B98E71C5C5BF4A400A4D124BCA7C594032CA332F87C14A409F5A7D75557E594032CA332F87C14A409F5A7D75557E5940B98E71C5C5BF4A400A4D124BCA7C5940B98E71C5C5BF4A40
69008	30343	102.535782	102.555706	53.597541	53.583078	Юбилейная	0103000020E6100000010000000500000045F295404AA259403082C64CA2CA4A4045F295404AA25940738236397CCC4A40390CE6AF90A35940738236397CCC4A40390CE6AF90A359403082C64CA2CA4A4045F295404AA259403082C64CA2CA4A40
69176	31225	102.083597	102.117041	53.279778999999998	53.262067999999999	пер.Школьный	0103000020E61000000100000005000000CC423BA75985594000AAB8718BA14A40CC423BA759855940C58D5BCCCFA34A40A2D288997D875940C58D5BCCCFA34A40A2D288997D87594000AAB8718BA14A40CC423BA75985594000AAB8718BA14A40
69545	59289	103.970894	106.832594	55.872596999999999	53.762998000000003	Полевая	0103000020E610000001000000050000007D78962023FE5940EB7420EBA9E14A407D78962023FE59403ACB2C42B1EF4B402236583849B55A403ACB2C42B1EF4B402236583849B55A40EB7420EBA9E14A407D78962023FE5940EB7420EBA9E14A40
69002	52562	105.35545	105.37159200000001	54.826867999999997	54.819834	Центральная	0103000020E610000001000000050000003F575BB1BF565A400E130D52F0684B403F575BB1BF565A40F10D85CFD6694B4023DDCF29C8575A40F10D85CFD6694B4023DDCF29C8575A400E130D52F0684B403F575BB1BF565A400E130D52F0684B40
69239	52558	105.638069	105.663724	54.908562000000003	54.897396999999998	Школьная	0103000020E61000000100000005000000DAE55B1FD6685A40A643A7E7DD724B40DAE55B1FD6685A40B63176C24B744B4080643A747A6A5A40B63176C24B744B4080643A747A6A5A40A643A7E7DD724B40DAE55B1FD6685A40A643A7E7DD724B40
68972	52585	105.066075	105.093582	55.013379	55.003445999999997	Молодёжная	0103000020E610000001000000050000005305A3923A445A40A8A624EB70804B405305A3923A445A4002BA2F67B6814B40A25F5B3FFD455A4002BA2F67B6814B40A25F5B3FFD455A40A8A624EB70804B405305A3923A445A40A8A624EB70804B40
69484	52574	104.51042200000001	104.544415	54.585773000000003	54.569648000000001	Таежная	0103000020E610000001000000050000002C4A09C1AA205A40AC1DC539EA484B402C4A09C1AA205A409EF0129CFA4A4B40EB1C03B2D7225A409EF0129CFA4A4B40EB1C03B2D7225A40AC1DC539EA484B402C4A09C1AA205A40AC1DC539EA484B40
69246	52564	105.220496	105.23813	54.788834000000001	54.780943000000001	Кооперативная	0103000020E610000001000000050000008639419B1C4E5A402385B2F0F5634B408639419B1C4E5A4087FC3383F8644B40938C9C853D4F5A4087FC3383F8644B40938C9C853D4F5A402385B2F0F5634B408639419B1C4E5A402385B2F0F5634B40
69562	59301	104.714573	104.732423	54.401276000000003	54.383865999999998	Николаева	0103000020E61000000100000005000000B2666490BB2D5A40EE05668522314B40B2666490BB2D5A40B95510035D334B40A5F5B704E02E5A40B95510035D334B40A5F5B704E02E5A40EE05668522314B40B2666490BB2D5A40EE05668522314B40
69494	59267	105.195576	105.21701899999999	54.761237999999999	54.740380999999999	Школьная	0103000020E610000001000000050000007BF83251844C5A4036CAFACDC45E4B407BF83251844C5A40793C2D3F70614B4014E7A8A3E34D5A40793C2D3F70614B4014E7A8A3E34D5A4036CAFACDC45E4B407BF83251844C5A4036CAFACDC45E4B40
69009	52582	105.21848300000001	105.233413	54.663848999999999	54.654631000000002	Центральная	0103000020E61000000100000005000000D9EE1EA0FB4D5A4051F9D7F2CA534B40D9EE1EA0FB4D5A40BC3D0801F9544B40855D143DF04E5A40BC3D0801F9544B40855D143DF04E5A4051F9D7F2CA534B40D9EE1EA0FB4D5A4051F9D7F2CA534B40
69493	52584	105.219067	105.231078	54.507913000000002	54.483759999999997	Ленская	0103000020E6100000010000000500000080289831054E5A40758E01D9EB3D4B4080289831054E5A404C1B0E4B03414B40CE3461FBC94E5A404C1B0E4B03414B40CE3461FBC94E5A40758E01D9EB3D4B4080289831054E5A40758E01D9EB3D4B40
69486	52568	104.901729	104.947821	54.744861	54.730727999999999	Центральная	0103000020E61000000100000005000000B5368DEDB5395A40C022BF7E885D4B40B5368DEDB5395A406E88F19A575F4B40925D6919A93C5A406E88F19A575F4B40925D6919A93C5A40C022BF7E885D4B40B5368DEDB5395A40C022BF7E885D4B40
69488	52554	105.472949	105.479956	55.362065999999999	55.350709000000002	Ленская	0103000020E6100000010000000500000042EBE1CB445E5A40D9B45208E4AC4B4042EBE1CB445E5A402C7FBE2D58AE4B4037E15E99B75E5A402C7FBE2D58AE4B4037E15E99B75E5A40D9B45208E4AC4B4042EBE1CB445E5A40D9B45208E4AC4B40
69487	52577	104.765535	104.78640300000001	54.618181	54.602116000000002	Речная	0103000020E61000000100000005000000603C8386FE305A40FD321823124D4B40603C8386FE305A401901158E204F4B407C9E3F6D54325A401901158E204F4B407C9E3F6D54325A40FD321823124D4B40603C8386FE305A40FD321823124D4B40
68545	52233	104.81234600000001	104.855214	54.707436999999999	54.684392000000003	Магистральная	0103000020E6100000010000000500000055C2137AFD335A4070D234289A574B4055C2137AFD335A407C7DAD4B8D5A4B40354580D3BB365A407C7DAD4B8D5A4B40354580D3BB365A4070D234289A574B4055C2137AFD335A4070D234289A574B40
69571	52587	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	Сосновая	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
68855	52587	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	Советская	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
68689	52587	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	Партизанская	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
68765	52587	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	Неугодниковская	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
68529	52587	105.09515399999999	105.20661699999999	54.829985000000001	54.793593999999999	Колчанова	0103000020E610000001000000050000005985CD0017465A40A226FA7C94654B405985CD0017465A40D595CFF23C6A4B400C738236394D5A40D595CFF23C6A4B400C738236394D5A40A226FA7C94654B405985CD0017465A40A226FA7C94654B40
69004	52570	104.71275	104.765382	54.666978	54.648125	Школьная	0103000020E61000000100000005000000560E2DB29D2D5A40295C8FC2F5524B40560E2DB29D2D5A406493FC885F554B409DBCC804FC305A406493FC885F554B409DBCC804FC305A40295C8FC2F5524B40560E2DB29D2D5A40295C8FC2F5524B40
69247	52580	105.216399	105.228329	54.777183000000001	54.763388999999997	Центральная	0103000020E61000000100000005000000C6F8307BD94D5A40259012BBB6614B40C6F8307BD94D5A40EB0088BB7A634B409EEE3CF19C4E5A40EB0088BB7A634B409EEE3CF19C4E5A40259012BBB6614B40C6F8307BD94D5A40259012BBB6614B40
69181	52583	105.20914999999999	105.23411400000001	54.582282999999997	54.577685000000002	Таежная	0103000020E61000000100000005000000567DAEB6624D5A40E4310395F1494B40567DAEB6624D5A402502D53F884A4B404A6249B9FB4E5A402502D53F884A4B404A6249B9FB4E5A40E4310395F1494B40567DAEB6624D5A40E4310395F1494B40
67910	54497	101.684206	101.816007	56.338569	56.265292000000002	Наймушина	0103000020E61000000100000005000000876EF607CA6B5940FAF19716F5214C40876EF607CA6B59403F389F3A562B4C40A7936C75397459403F389F3A562B4C40A7936C7539745940FAF19716F5214C40876EF607CA6B5940FAF19716F5214C40
37452	54497	101.684206	101.816007	56.338569	56.265292000000002	Зверева	0103000020E61000000100000005000000876EF607CA6B5940FAF19716F5214C40876EF607CA6B59403F389F3A562B4C40A7936C75397459403F389F3A562B4C40A7936C7539745940FAF19716F5214C40876EF607CA6B5940FAF19716F5214C40
68842	2197	103.000345	103.02354	55.954667000000001	55.941021999999997	Гагарина	0103000020E61000000100000005000000E5ED08A705C059408368AD6873F84B40E5ED08A705C0594004C93B8732FA4B407689EAAD81C1594004C93B8732FA4B407689EAAD81C159408368AD6873F84B40E5ED08A705C059408368AD6873F84B40
69480	23799	100.85150299999999	100.88529800000001	55.478005000000003	55.461047999999998	Центральная	0103000020E61000000100000005000000895C70067F3659406FF1F09E03BB4B40895C70067F365940892991442FBD4B40B64DF1B8A8385940892991442FBD4B40B64DF1B8A83859406FF1F09E03BB4B40895C70067F3659406FF1F09E03BB4B40
69482	23515	100.71937	100.7457	55.341526000000002	55.324739999999998	Ленина	0103000020E610000001000000050000004EEE77280A2E5940FDD98F1491A94B404EEE77280A2E5940EA5DBC1FB7AB4B4024287E8CB92F5940EA5DBC1FB7AB4B4024287E8CB92F5940FDD98F1491A94B404EEE77280A2E5940FDD98F1491A94B40
68150	25189	100.86262499999999	100.913855	56.201273999999998	56.184936	Гагарина	0103000020E6100000010000000500000091ED7C3F3537594031ED9BFBAB174C4091ED7C3F353759407EC4AF58C3194C404F92AE997C3A59407EC4AF58C3194C404F92AE997C3A594031ED9BFBAB174C4091ED7C3F3537594031ED9BFBAB174C40
68764	24845	101.278437	101.30653599999999	55.987758999999997	55.974865999999999	1-ая Нагорная	0103000020E61000000100000005000000C43F6CE9D1515940BDFDB968C8FC4B40C43F6CE9D151594032AA0CE36EFE4B40FCC22B499E53594032AA0CE36EFE4B40FCC22B499E535940BDFDB968C8FC4B40C43F6CE9D1515940BDFDB968C8FC4B40
67846	23644	101.01239200000001	101.052187	55.389591000000003	55.371259999999999	Ленина	0103000020E61000000100000005000000DAAED007CB4059400F289B7285AF4B40DAAED007CB40594071E82D1EDEB14B40B09124085743594071E82D1EDEB14B40B0912408574359400F289B7285AF4B40DAAED007CB4059400F289B7285AF4B40
69168	23890	101.086619	101.09755199999999	55.548619000000002	55.539496999999997	Школьная	0103000020E61000000100000005000000950D6B2A8B45594022A5D93C0EC54B40950D6B2A8B4559406C7BBB2539C64B40336ABE4A3E4659406C7BBB2539C64B40336ABE4A3E46594022A5D93C0EC54B40950D6B2A8B45594022A5D93C0EC54B40
68146	23350	100.66619	100.722667	55.218604999999997	55.196576999999998	переулок Школьный	0103000020E6100000010000000500000006BB61DBA22A5940A912656F29994B4006BB61DBA22A5940FCDEA63FFB9B4B4080B9162D402E5940FCDEA63FFB9B4B4080B9162D402E5940A912656F29994B4006BB61DBA22A5940A912656F29994B40
68156	23848	101.024052	101.07126700000001	55.537194999999997	55.506999	Сибирская	0103000020E61000000100000005000000D15966118A415940670DDE57E5C04B40D15966118A415940904946CEC2C44B402E9276A38F445940904946CEC2C44B402E9276A38F445940670DDE57E5C04B40D15966118A415940670DDE57E5C04B40
69350	23273	\N	\N	\N	\N	Новая	\N
69169	24793	101.546853	101.562709	55.852651999999999	55.845430999999998	Лесная	0103000020E610000001000000050000000CAEB9A3FF6259402503401537EC4B400CAEB9A3FF6259403B6F63B323ED4B408D0A9C6C036459403B6F63B323ED4B408D0A9C6C036459402503401537EC4B400CAEB9A3FF6259402503401537EC4B40
69171	25571	102.648224	102.66660299999999	56.587575000000001	56.575498000000003	Центральная	0103000020E61000000100000005000000DE1E84807CA95940EB7420EBA9494C40DE1E84807CA959403E7958A8354B4C40971AA19FA9AA59403E7958A8354B4C40971AA19FA9AA5940EB7420EBA9494C40DE1E84807CA95940EB7420EBA9494C40
68956	23482	100.478083	100.494342	55.257657999999999	55.248524000000003	Таежная	0103000020E61000000100000005000000827170E9981E5940B4226AA2CF9F4B40827170E9981E5940C1C6F5EFFAA04B4083C2A04CA31F5940C1C6F5EFFAA04B4083C2A04CA31F5940B4226AA2CF9F4B40827170E9981E5940B4226AA2CF9F4B40
69030	24661	101.48959499999999	101.532229	55.579317000000003	55.560316	Кооперативная	0103000020E610000001000000050000003F524486555F594078B6476FB8C74B403F524486555F59402882380F27CA4B40E63E390A106259402882380F27CA4B40E63E390A1062594078B6476FB8C74B403F524486555F594078B6476FB8C74B40
69483	24598	101.766734	101.784018	55.543332999999997	55.524661000000002	Школьная	0103000020E61000000100000005000000CDAE7B2B127159404B3E761728C34B40CDAE7B2B1271594035EB8CEF8BC54B406C5ED5592D72594035EB8CEF8BC54B406C5ED5592D7259404B3E761728C34B40CDAE7B2B127159404B3E761728C34B40
68763	24897	101.226631	101.265124	56.093541000000002	56.080742999999998	Почтовая	0103000020E61000000100000005000000A0504F1F814E5940C23060C9550A4C40A0504F1F814E5940E6EAC726F90B4C409F58A7CAF7505940E6EAC726F90B4C409F58A7CAF7505940C23060C9550A4C40A0504F1F814E5940C23060C9550A4C40
68852	24517	101.94568700000001	101.977829	55.509492000000002	55.494140000000002	Лесная	0103000020E610000001000000050000002750C422867C59409ED2C1FA3FBF4B402750C422867C59406DC9AA0837C14B40250516C0947E59406DC9AA0837C14B40250516C0947E59409ED2C1FA3FBF4B402750C422867C59409ED2C1FA3FBF4B40
69267	23947	101.345972	101.381473	55.444327999999999	55.425654999999999	Школьная	0103000020E610000001000000050000003B55BE67245659407F30F0DC7BB64B403B55BE67245659403A596ABDDFB84B40A6D3BA0D6A5859403A596ABDDFB84B40A6D3BA0D6A5859407F30F0DC7BB64B403B55BE67245659407F30F0DC7BB64B40
68786	25211	101.426883	101.442909	56.592996999999997	56.581909000000003	Сазонова	0103000020E61000000100000005000000FA0D130D525B5940C11F7EFE7B4A4C40FA0D130D525B594024D06053E74B4C40A986FD9E585C594024D06053E74B4C40A986FD9E585C5940C11F7EFE7B4A4C40FA0D130D525B5940C11F7EFE7B4A4C40
67848	24534	101.666715	101.71436199999999	55.533026999999997	55.511051999999999	Ленина	0103000020E610000001000000050000002B306475AB6A59401747E5266AC14B402B306475AB6A594047718E3A3AC44B4054E0641BB86D594047718E3A3AC44B4054E0641BB86D59401747E5266AC14B402B306475AB6A59401747E5266AC14B40
68151	25510	102.41633299999999	102.477463	56.569333999999998	56.544699000000001	Октябрьская	0103000020E61000000100000005000000B7CF2A33A59A5940FB9463B2B8454C40B7CF2A33A59A59401C40BFEFDF484C403483F8C08E9E59401C40BFEFDF484C403483F8C08E9E5940FB9463B2B8454C40B7CF2A33A59A5940FB9463B2B8454C40
69026	23435	100.561976	100.592519	55.219802000000001	55.209144000000002	Трактовая	0103000020E61000000100000005000000C3482F6AF7235940CB13083BC59A4B40C3482F6AF723594036CCD078229C4B408DD0CFD4EB25594036CCD078229C4B408DD0CFD4EB255940CB13083BC59A4B40C3482F6AF7235940CB13083BC59A4B40
68051	24697	101.71843200000001	101.75275600000001	55.690187000000002	55.665888000000002	Погодаева	0103000020E61000000100000005000000981936CAFA6D5940416667D13BD54B40981936CAFA6D5940EB8F300C58D84B408A7780272D705940EB8F300C58D84B408A7780272D705940416667D13BD54B40981936CAFA6D5940416667D13BD54B40
68761	23368	100.65754800000001	100.69922099999999	55.232180999999997	55.214933000000002	Кирова	0103000020E6100000010000000500000037E33444152A594064EAAEEC829B4B4037E33444152A594054E0641BB89D4B404AEB6F09C02C594054E0641BB89D4B404AEB6F09C02C594064EAAEEC829B4B4037E33444152A594064EAAEEC829B4B40
69037	25439	102.117733	102.141583	56.383603000000001	56.374600999999998	Кооперативная	0103000020E610000001000000050000003D2AFEEF888759404206F2ECF22F4C403D2AFEEF88875940E1D231E719314C40DAAA24B20F895940E1D231E719314C40DAAA24B20F8959404206F2ECF22F4C403D2AFEEF888759404206F2ECF22F4C40
69342	23726	101.026881	101.039682	55.456412999999998	55.436534999999999	Центральная	0103000020E6100000010000000500000090F8156BB84159409947FE60E0B74B4090F8156BB8415940103CBEBD6BBA4B405A0F5F268A425940103CBEBD6BBA4B405A0F5F268A4259409947FE60E0B74B4090F8156BB84159409947FE60E0B74B40
69492	25355	101.775187	101.7961	56.614539999999998	56.600186999999998	Центральная	0103000020E610000001000000050000003352EFA99C715940FF3D78EDD24C4C403352EFA99C715940BB0A293FA94E4C401E166A4DF3725940BB0A293FA94E4C401E166A4DF3725940FF3D78EDD24C4C403352EFA99C715940FF3D78EDD24C4C40
68153	2232	101.121887	101.218627	56.148318000000003	56.104953000000002	Школьная	0103000020E61000000100000005000000AFB321FFCC475940FD4E93196F0D4C40AFB321FFCC4759403EB48F15FC124C4072C119FCFD4D59403EB48F15FC124C4072C119FCFD4D5940FD4E93196F0D4C40AFB321FFCC475940FD4E93196F0D4C40
67650	2232	101.121887	101.218627	56.148318000000003	56.104953000000002	Пионерская	0103000020E61000000100000005000000AFB321FFCC475940FD4E93196F0D4C40AFB321FFCC4759403EB48F15FC124C4072C119FCFD4D59403EB48F15FC124C4072C119FCFD4D5940FD4E93196F0D4C40AFB321FFCC475940FD4E93196F0D4C40
68078	2232	101.121887	101.218627	56.148318000000003	56.104953000000002	Октябрьская	0103000020E61000000100000005000000AFB321FFCC475940FD4E93196F0D4C40AFB321FFCC4759403EB48F15FC124C4072C119FCFD4D59403EB48F15FC124C4072C119FCFD4D5940FD4E93196F0D4C40AFB321FFCC475940FD4E93196F0D4C40
68105	2232	101.121887	101.218627	56.148318000000003	56.104953000000002	Ленина	0103000020E61000000100000005000000AFB321FFCC475940FD4E93196F0D4C40AFB321FFCC4759403EB48F15FC124C4072C119FCFD4D59403EB48F15FC124C4072C119FCFD4D5940FD4E93196F0D4C40AFB321FFCC475940FD4E93196F0D4C40
68015	2232	101.121887	101.218627	56.148318000000003	56.104953000000002	Дзержинского	0103000020E61000000100000005000000AFB321FFCC475940FD4E93196F0D4C40AFB321FFCC4759403EB48F15FC124C4072C119FCFD4D59403EB48F15FC124C4072C119FCFD4D5940FD4E93196F0D4C40AFB321FFCC475940FD4E93196F0D4C40
67998	2232	101.121887	101.218627	56.148318000000003	56.104953000000002	35 лет Победы	0103000020E61000000100000005000000AFB321FFCC475940FD4E93196F0D4C40AFB321FFCC4759403EB48F15FC124C4072C119FCFD4D59403EB48F15FC124C4072C119FCFD4D5940FD4E93196F0D4C40AFB321FFCC475940FD4E93196F0D4C40
69479	59266	100.01459699999999	103.507094	56.883896999999997	54.917395999999997	Ленских Событий	0103000020E61000000100000005000000A9674128EF00594098BD6C3B6D754B40A9674128EF0059402904728923714C40DC7F643A74E059402904728923714C40DC7F643A74E0594098BD6C3B6D754B40A9674128EF00594098BD6C3B6D754B40
69481	25350	100.01459699999999	103.507094	56.883896999999997	54.917395999999997	Первомайская	0103000020E61000000100000005000000A9674128EF00594098BD6C3B6D754B40A9674128EF0059402904728923714C40DC7F643A74E059402904728923714C40DC7F643A74E0594098BD6C3B6D754B40A9674128EF00594098BD6C3B6D754B40
68316	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	площадь 50 лет Октября	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68318	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Школьная	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67873	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Снежная	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68301	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Пролетарская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68321	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Приморская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67684	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Погодаева	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68292	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Пионерская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67883	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Олимпийская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67898	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Наймушина	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68207	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Курчатова	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67655	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Крупской	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67027	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Комсомольская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67876	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Кирова	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67920	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Заводская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67948	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Енисейская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67689	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Еловая	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68308	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Гидростроителей	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68768	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Гайнулина	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67903	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Гагарина	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
68169	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Верхняя	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67922	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Байкальская	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
67905	2114	101.36801699999999	101.978359	56.379621	56.081105000000001	Ангарстроя	0103000020E61000000100000005000000CFD72C978D57594063450DA6610A4C40CFD72C978D575940FAEFC16B97304C40D32F116F9D7E5940FAEFC16B97304C40D32F116F9D7E594063450DA6610A4C40CFD72C978D57594063450DA6610A4C40
69038	25487	102.159558	102.177381	56.494022999999999	56.484699999999997	Школьная	0103000020E610000001000000050000002CF4C132368A5940832F4CA60A3E4C402CF4C132368A5940643C4A253C3F4C40A27BD6355A8B5940643C4A253C3F4C40A27BD6355A8B5940832F4CA60A3E4C402CF4C132368A5940832F4CA60A3E4C40
68536	24754	101.727433	101.759359	55.755540000000003	55.732078000000001	Первомайская	0103000020E61000000100000005000000FF4124438E6E5940800F5EBBB4DD4B40FF4124438E6E5940F168E388B5E04B4017BB7D5699705940F168E388B5E04B4017BB7D5699705940800F5EBBB4DD4B40FF4124438E6E5940800F5EBBB4DD4B40
69373	23584	100.78302499999999	100.811609	55.373131999999998	55.364972000000002	Мира	0103000020E61000000100000005000000D3BCE3141D32594055FA0967B7AE4B40D3BCE3141D325940A88B14CAC2AF4B40EA08E066F1335940A88B14CAC2AF4B40EA08E066F133594055FA0967B7AE4B40D3BCE3141D32594055FA0967B7AE4B40
69344	23657	101.145872	101.157856	55.407089999999997	55.389913	Пионерская	0103000020E61000000100000005000000BC5983F75549594083A44FABE8B14B40BC5983F755495940AA436E861BB44B408D5E0D501A4A5940AA436E861BB44B408D5E0D501A4A594083A44FABE8B14B40BC5983F75549594083A44FABE8B14B40
69166	23769	100.909139	100.936789	55.429077999999997	55.418281999999998	Советская	0103000020E61000000100000005000000292158552F3A5940B340BB438AB54B40292158552F3A59406FB72407ECB64B402A90D959F43B59406FB72407ECB64B402A90D959F43B5940B340BB438AB54B40292158552F3A5940B340BB438AB54B40
69554	59295	103.351793	104.724599	53.538595999999998	52.678795000000001	Дорожная	0103000020E610000001000000050000008D7DC9C683D659401BD82AC1E2564A408D7DC9C683D65940D2E0B6B6F0C44A40B7ED7BD45F2E5A40D2E0B6B6F0C44A40B7ED7BD45F2E5A401BD82AC1E2564A408D7DC9C683D659401BD82AC1E2564A40
69338	21949	103.809898	103.835815	53.165197999999997	53.153190000000002	Депутатская	0103000020E6100000010000000500000022C66B5ED5F359408109DCBA9B934A4022C66B5ED5F35940ABAE433525954A4066A032FE7DF55940ABAE433525954A4066A032FE7DF559408109DCBA9B934A4022C66B5ED5F359408109DCBA9B934A40
68548	21857	103.90388900000001	103.94195000000001	53.166952999999999	53.156846000000002	Ленина	0103000020E61000000100000005000000B58D3F51D9F9594014419C8713944A40B58D3F51D9F959400B7C45B75E954A40E71DA7E848FC59400B7C45B75E954A40E71DA7E848FC594014419C8713944A40B58D3F51D9F9594014419C8713944A40
69178	21877	103.862494	103.890432	53.157952999999999	53.14584	Ленина	0103000020E61000000100000005000000C2BF081A33F759406D3997E2AA924A40C2BF081A33F759400DA7CCCD37944A40F6D37FD6FCF859400DA7CCCD37944A40F6D37FD6FCF859406D3997E2AA924A40C2BF081A33F759406D3997E2AA924A40
69474	21709	104.29210500000001	104.31085299999999	53.179912000000002	53.162768999999997	Школьная	0103000020E61000000100000005000000E17F2BD9B1125A40BCE6559DD5944A40E17F2BD9B1125A4038143E5B07974A404337FB03E5135A4038143E5B07974A404337FB03E5135A40BCE6559DD5944A40E17F2BD9B1125A40BCE6559DD5944A40
69339	22281	103.61165800000001	103.64178699999999	53.173036000000003	53.162170000000003	Комсомольская	0103000020E610000001000000050000008E95986725E7594038328FFCC1944A408E95986725E75940ED832C0B26964A40DEFFC70913E95940ED832C0B26964A40DEFFC70913E9594038328FFCC1944A408E95986725E7594038328FFCC1944A40
68833	4611	104.124174	104.147593	53.149296999999997	53.138235000000002	Школьная	0103000020E61000000100000005000000DD408177F2075A40CF143AAFB1914A40DD408177F2075A400932022A1C934A409607E92972095A400932022A1C934A409607E92972095A40CF143AAFB1914A40DD408177F2075A40CF143AAFB1914A40
69164	22968	103.400689	103.40868399999999	53.224023000000003	53.214619999999996	Школьная	0103000020E610000001000000050000007CB779E3A4D95940A4880CAB789B4A407CB779E3A4D95940A24621C9AC9C4A408099EFE027DA5940A24621C9AC9C4A408099EFE027DA5940A4880CAB789B4A407CB779E3A4D95940A4880CAB789B4A40
68100	16487	104.19636199999999	104.257627	53.190525999999998	53.159238000000002	Ленина	0103000020E61000000100000005000000560BEC31910C5A40E62329E961944A40560BEC31910C5A40D384ED2763984A4043E4F4F57C105A40D384ED2763984A4043E4F4F57C105A40E62329E961944A40560BEC31910C5A40E62329E961944A40
68654	22326	103.75572099999999	103.80352000000001	53.098830999999997	53.072778	Ленина	0103000020E61000000100000005000000A0F99CBB5DF0594024EF1CCA50894A40A0F99CBB5DF059405D6A847EA68C4A40A56B26DF6CF359405D6A847EA68C4A40A56B26DF6CF3594024EF1CCA50894A40A0F99CBB5DF0594024EF1CCA50894A40
68990	2543	103.397284	103.41674999999999	53.453178000000001	53.427905000000003	Ленина	0103000020E6100000010000000500000057CEDE196DD95940BF654E97C5B64A4057CEDE196DD9594023A298BC01BA4A40E9263108ACDA594023A298BC01BA4A40E9263108ACDA5940BF654E97C5B64A4057CEDE196DD95940BF654E97C5B64A40
69165	21803	103.966627	103.987037	53.139180000000003	53.125478999999999	Ключевая	0103000020E610000001000000050000008F1B7E37DDFD5940DAAA24B20F904A408F1B7E37DDFD5940EF2076A6D0914A4049BC3C9D2BFF5940EF2076A6D0914A4049BC3C9D2BFF5940DAAA24B20F904A408F1B7E37DDFD5940DAAA24B20F904A40
69331	13089	104.18080399999999	104.19099	53.074627999999997	53.055570000000003	Лесная	0103000020E610000001000000050000001ABFF04A920B5A40C251F2EA1C874A401ABFF04A920B5A40D5AE09698D894A403CF71E2E390C5A40D5AE09698D894A403CF71E2E390C5A40C251F2EA1C874A401ABFF04A920B5A40C251F2EA1C874A40
68145	22445	103.69105999999999	103.721818	52.917577000000001	52.889626	Калинина	0103000020E61000000100000005000000B8E4B8533AEC5940EDD5C743DF714A40B8E4B8533AEC5940E947C32973754A4081EA1F4432EE5940E947C32973754A4081EA1F4432EE5940EDD5C743DF714A40B8E4B8533AEC5940EDD5C743DF714A40
69514	22372	103.663706	103.682373	53.111930000000001	53.104930000000003	Школьная	0103000020E610000001000000050000002D0ABB287AEA5940452FA3586E8D4A402D0ABB287AEA59407CB8E4B8538E4A4019ABCDFFABEB59407CB8E4B8538E4A4019ABCDFFABEB5940452FA3586E8D4A402D0ABB287AEA5940452FA3586E8D4A40
69584	59316	104.005174	104.04216700000001	53.15204	53.146774999999998	Ленина	0103000020E61000000100000005000000873254C554005A40696FF085C9924A40873254C554005A4088D7F50B76934A401C7E37DDB2025A4088D7F50B76934A401C7E37DDB2025A40696FF085C9924A40873254C554005A40696FF085C9924A40
68854	22209	103.681439	103.699675	53.179907	53.172502000000001	Центральная	0103000020E6100000010000000500000003CE52B29CEB59404F3FA88B14964A4003CE52B29CEB594026A94C3107974A400BB5A679C7EC594026A94C3107974A400BB5A679C7EC59404F3FA88B14964A4003CE52B29CEB59404F3FA88B14964A40
69559	59298	103.487861	103.49788599999999	53.388983000000003	53.377678000000003	Полевая	0103000020E610000001000000050000009BFF571D39DF59409835B1C057B04A409BFF571D39DF594099D9E731CAB14A40B8C83D5DDDDF594099D9E731CAB14A40B8C83D5DDDDF59409835B1C057B04A409BFF571D39DF59409835B1C057B04A40
69297	59235	103.505675	103.531807	53.200597999999999	53.193941000000002	Школьная	0103000020E61000000100000005000000E8D9ACFA5CE05940412D060FD3984A40E8D9ACFA5CE059404ED2FC31AD994A402B323A2009E259404ED2FC31AD994A402B323A2009E25940412D060FD3984A40E8D9ACFA5CE05940412D060FD3984A40
69515	59273	103.55889999999999	103.56844	53.295692000000003	53.282702999999998	Трудовая	0103000020E61000000100000005000000006F8104C5E3594094BDA59C2FA44A40006F8104C5E359402CD8463CD9A54A403F6F2A5261E459402CD8463CD9A54A403F6F2A5261E4594094BDA59C2FA44A40006F8104C5E3594094BDA59C2FA44A40
69264	59231	103.501048	103.533675	53.329358999999997	53.315961000000001	Кузнецовская	0103000020E610000001000000050000007A6EA12B11E05940DEE7F86871A84A407A6EA12B11E0594056D28A6F28AA4A4057EC2FBB27E2594056D28A6F28AA4A4057EC2FBB27E25940DEE7F86871A84A407A6EA12B11E05940DEE7F86871A84A40
68701	22908	103.366175	103.380674	53.174855000000001	53.139671999999997	Школьная	0103000020E61000000100000005000000386744696FD759405D15A8C5E0914A40386744696FD7594063450DA661964A40001C7BF65CD8594063450DA661964A40001C7BF65CD859405D15A8C5E0914A40386744696FD759405D15A8C5E0914A40
69478	22823	103.396395	103.407839	53.082402000000002	53.073670999999997	Школьная	0103000020E61000000100000005000000115322895ED95940F1D4230D6E894A40115322895ED95940009013268C8A4A4022C2BF081ADA5940009013268C8A4A4022C2BF081ADA5940F1D4230D6E894A40115322895ED95940F1D4230D6E894A40
68759	23152	103.425186	103.450024	53.346322000000001	53.325906000000003	Мира	0103000020E61000000100000005000000E42D573F36DB5940FCC8AD49B7A94A40E42D573F36DB594052F17F4754AC4A40919A7631CDDC594052F17F4754AC4A40919A7631CDDC5940FCC8AD49B7A94A40E42D573F36DB5940FCC8AD49B7A94A40
69340	22534	103.740216	103.753682	52.972844000000002	52.962907999999999	Трактовая	0103000020E6100000010000000500000076FEEDB25FEF59404487C091407B4A4076FEEDB25FEF59400F0EF626867C4A405E656D533CF059400F0EF626867C4A405E656D533CF059404487C091407B4A4076FEEDB25FEF59404487C091407B4A40
69341	22122	103.73935299999999	103.758892	53.181536999999999	53.169165999999997	Трактовая	0103000020E61000000100000005000000C4CC3E8F51EF59402DCC423BA7954A40C4CC3E8F51EF5940C901BB9A3C974A408C4CC0AF91F05940C901BB9A3C974A408C4CC0AF91F059402DCC423BA7954A40C4CC3E8F51EF59402DCC423BA7954A40
69014	21632	104.32725600000001	104.371776	53.224099000000002	53.206395999999998	Центральная	0103000020E61000000100000005000000DE5A26C3F1145A403A03232F6B9A4A40DE5A26C3F1145A407D08AA46AF9C4A40035C902DCB175A407D08AA46AF9C4A40035C902DCB175A403A03232F6B9A4A40DE5A26C3F1145A403A03232F6B9A4A40
69070	59209	103.351793	104.724599	53.538595999999998	52.678795000000001	Пионерская	0103000020E610000001000000050000008D7DC9C683D659401BD82AC1E2564A408D7DC9C683D65940D2E0B6B6F0C44A40B7ED7BD45F2E5A40D2E0B6B6F0C44A40B7ED7BD45F2E5A401BD82AC1E2564A408D7DC9C683D659401BD82AC1E2564A40
69018	22877	103.62639	103.637152	53.238765999999998	53.225181999999997	Колхозная	0103000020E61000000100000005000000A72215C616E85940EDD286C3D29C4A40A72215C616E85940C8B260E28F9E4A402FA52E19C7E85940C8B260E28F9E4A402FA52E19C7E85940EDD286C3D29C4A40A72215C616E85940EDD286C3D29C4A40
69013	22563	103.762045	103.77697499999999	52.903858999999997	52.897308000000002	Школьная	0103000020E6100000010000000500000024456458C5F05940373811FDDA724A4024456458C5F05940FE98D6A6B1734A40D0B359F5B9F15940FE98D6A6B1734A40D0B359F5B9F15940373811FDDA724A4024456458C5F05940373811FDDA724A40
69020	22636	103.668261	103.677702	53.010677999999999	52.997852000000002	Школьная	0103000020E610000001000000050000004E0CC9C9C4EA5940C51F459DB97F4A404E0CC9C9C4EA5940B2648EE55D814A40C39B35785FEB5940B2648EE55D814A40C39B35785FEB5940C51F459DB97F4A404E0CC9C9C4EA5940C51F459DB97F4A40
69477	21610	104.389608	104.429664	53.257520999999997	53.230255	Советская	0103000020E61000000100000005000000A3906456EF185A40C85EEFFE789D4A40A3906456EF185A404084B872F6A04A4030116F9D7F1B5A404084B872F6A04A4030116F9D7F1B5A40C85EEFFE789D4A40A3906456EF185A40C85EEFFE789D4A40
68615	2466	103.578052	103.58900199999999	53.030487000000001	53.019736000000002	Центральная	0103000020E61000000100000005000000CBD8D0CDFEE45940E54691B586824A40CBD8D0CDFEE4594001FA7DFFE6834A40D4D17135B2E5594001FA7DFFE6834A40D4D17135B2E55940E54691B586824A40CBD8D0CDFEE45940E54691B586824A40
69501	2466	103.578052	103.58900199999999	53.030487000000001	53.019736000000002	Мира	0103000020E61000000100000005000000CBD8D0CDFEE45940E54691B586824A40CBD8D0CDFEE4594001FA7DFFE6834A40D4D17135B2E5594001FA7DFFE6834A40D4D17135B2E55940E54691B586824A40CBD8D0CDFEE45940E54691B586824A40
69161	22195	103.80814599999999	103.823813	53.26182	53.252462999999999	Ленина	0103000020E610000001000000050000002A1900AAB8F359409B3924B550A04A402A1900AAB8F3594028B8585183A14A404241295AB9F4594028B8585183A14A404241295AB9F459409B3924B550A04A402A1900AAB8F359409B3924B550A04A40
68136	21976	103.76191	103.803799	53.171671000000003	53.117330000000003	Ленина	0103000020E61000000100000005000000B41F2922C3F059407B6B60AB048F4A40B41F2922C3F05940F855B950F9954A40AE635C7171F35940F855B950F9954A40AE635C7171F359407B6B60AB048F4A40B41F2922C3F059407B6B60AB048F4A40
69162	21976	103.76191	103.803799	53.171671000000003	53.117330000000003	Киевская	0103000020E61000000100000005000000B41F2922C3F059407B6B60AB048F4A40B41F2922C3F05940F855B950F9954A40AE635C7171F35940F855B950F9954A40AE635C7171F359407B6B60AB048F4A40B41F2922C3F059407B6B60AB048F4A40
68754	22661	103.820076	103.86342	52.805371000000001	52.783160000000002	Дзержинского	0103000020E61000000100000005000000020F0C207CF4594087C43D963E644A40020F0C207CF45940CB129D6516674A4097ADF54542F75940CB129D6516674A4097ADF54542F7594087C43D963E644A40020F0C207CF4594087C43D963E644A40
69682	59345	105.92943699999999	105.95382600000001	53.334398	53.306970999999997	улица Трактовая	0103000020E610000001000000050000004FAC53E57B7B5A4003E962D34AA74A404FAC53E57B7B5A4085ECBC8DCDAA4A40C504357C0B7D5A4085ECBC8DCDAA4A40C504357C0B7D5A4003E962D34AA74A404FAC53E57B7B5A4003E962D34AA74A40
69532	19169	105.592641	105.607705	53.135171999999997	53.119107999999997	Бурлова	0103000020E61000000100000005000000335184D4ED655A40925852EE3E8F4A40335184D4ED655A40DEAAEB504D914A40672783A3E4665A40DEAAEB504D914A40672783A3E4665A40925852EE3E8F4A40335184D4ED655A40925852EE3E8F4A40
68544	20003	105.85185	105.893046	53.257710000000003	53.225521999999998	Трактовая	0103000020E610000001000000050000003FC6DCB584765A40A643A7E7DD9C4A403FC6DCB584765A4014ED2AA4FCA04A40B6F468AA27795A4014ED2AA4FCA04A40B6F468AA27795A40A643A7E7DD9C4A403FC6DCB584765A40A643A7E7DD9C4A40
69276	19690	105.22386400000001	105.245774	52.852342999999998	52.834214000000003	Трактовая	0103000020E610000001000000050000001DB0ABC9534E5A40C4EE3B86C76A4A401DB0ABC9534E5A40BDFC4E93196D4A40410DDFC2BA4F5A40BDFC4E93196D4A40410DDFC2BA4F5A40C4EE3B86C76A4A401DB0ABC9534E5A40C4EE3B86C76A4A40
69470	19016	105.791878	105.826688	53.136316999999998	53.112448999999998	Трактовая	0103000020E61000000100000005000000001B1021AE725A40E4BB94BA648E4A40001B1021AE725A40C571E0D572914A40B9FFC874E8745A40C571E0D572914A40B9FFC874E8745A40E4BB94BA648E4A40001B1021AE725A40E4BB94BA648E4A40
69001	19242	105.715467	105.736892	53.243028000000002	53.229571	Подгорная	0103000020E6100000010000000500000081971936CA6D5A40158E2095629D4A4081971936CA6D5A409301A08A1B9F4A40C72B103D296F5A409301A08A1B9F4A40C72B103D296F5A40158E2095629D4A4081971936CA6D5A40158E2095629D4A40
69475	20398	105.70308	105.720237	53.429760999999999	53.417200000000001	Центральная	0103000020E61000000100000005000000309E4143FF6C5A4013F241CF66B54A40309E4143FF6C5A40520C906802B74A40A017EE5C186E5A40520C906802B74A40A017EE5C186E5A4013F241CF66B54A40309E4143FF6C5A4013F241CF66B54A40
69154	19061	105.64750100000001	105.68952400000001	53.031782	53.021459	Советская	0103000020E6100000010000000500000026C808A870695A40399A232BBF824A4026C808A870695A40FD4CBD6E11844A40A8734529216C5A40FD4CBD6E11844A40A8734529216C5A40399A232BBF824A4026C808A870695A40399A232BBF824A40
69265	20074	105.777236	105.811021	53.307336999999997	53.285136000000001	Трактовая	0103000020E610000001000000050000008751103CBE715A40C57421567FA44A408751103CBE715A40E5EC9DD156A74A40A1D79FC4E7735A40E5EC9DD156A74A40A1D79FC4E7735A40C57421567FA44A408751103CBE715A40C57421567FA44A40
69156	19123	105.6309	105.671207	53.144992000000002	53.123572000000003	пер.Клубный	0103000020E61000000100000005000000F8C264AA60685A40C5591135D18F4A40F8C264AA60685A4040170D198F924A402976340EF56A5A4040170D198F924A402976340EF56A5A40C5591135D18F4A40F8C264AA60685A40C5591135D18F4A40
68642	19268	105.521027	105.552549	53.092844999999997	53.068607	Мира	0103000020E610000001000000050000005055A18158615A406AA33A1DC8884A405055A18158615A406E4C4F58E28B4A40001C7BF65C635A406E4C4F58E28B4A40001C7BF65C635A406AA33A1DC8884A405055A18158615A406AA33A1DC8884A40
68851	19485	105.208162	105.229973	52.956153999999998	52.936619999999998	Титова	0103000020E610000001000000050000004791B586524D5A40C763062AE3774A404791B586524D5A4044F81741637A4A40A27DACE0B74E5A4044F81741637A4A40A27DACE0B74E5A40C763062AE3774A404791B586524D5A40C763062AE3774A40
69183	59220	105.329677	105.34987099999999	53.156905000000002	53.145014000000003	Хургалдайраг	0103000020E61000000100000005000000944F8F6D19555A4028BB99D18F924A40944F8F6D19555A4019CA897615944A4067B4554964565A4019CA897615944A4067B4554964565A4028BB99D18F924A40944F8F6D19555A4028BB99D18F924A40
69011	19738	105.151568	105.181895	52.848841	52.833812000000002	Центральная	0103000020E61000000100000005000000B0C7444AB3495A409581035ABA6A4A40B0C7444AB3495A40814067D2A66C4A409413ED2AA44B5A40814067D2A66C4A409413ED2AA44B5A409581035ABA6A4A40B0C7444AB3495A409581035ABA6A4A40
69015	19824	105.276658	105.32096300000001	53.111330000000002	53.097236000000002	Ленина	0103000020E61000000100000005000000508BC1C3B4515A4037FFAF3A728C4A40508BC1C3B4515A402788BA0F408E4A40780E65A88A545A402788BA0F408E4A40780E65A88A545A4037FFAF3A728C4A40508BC1C3B4515A4037FFAF3A728C4A40
69155	19390	105.449045	105.471045	53.010055000000001	52.992111999999999	Чкалова	0103000020E61000000100000005000000AB5B3D27BD5C5A400DFCA886FD7E4A40AB5B3D27BD5C5A40A514747B49814A40707CED99255E5A40A514747B49814A40707CED99255E5A400DFCA886FD7E4A40AB5B3D27BD5C5A400DFCA886FD7E4A40
69543	59287	105.134787	105.17041500000001	53.090774000000003	53.072144999999999	Центральная	0103000020E61000000100000005000000433BA759A0485A40F3C81F0C3C894A40433BA759A0485A40DFA9807B9E8B4A40DDEF5014E84A5A40DFA9807B9E8B4A40DDEF5014E84A5A40F3C81F0C3C894A40433BA759A0485A40F3C81F0C3C894A40
69674	59343	105.994044	106.008022	53.306815	53.297058999999997	Клубная	0103000020E610000001000000050000003EB2B96A9E7F5A40C1FD800706A64A403EB2B96A9E7F5A400C76C3B645A74A4081E9B46E83805A400C76C3B645A74A4081E9B46E83805A40C1FD800706A64A403EB2B96A9E7F5A40C1FD800706A64A40
68749	19580	105.311378	105.360606	52.898107000000003	52.882300999999998	Микрорайон-141	0103000020E6100000010000000500000069ACFD9DED535A40321D3A3DEF704A4069ACFD9DED535A4083A7902BF5724A40732F302B14575A4083A7902BF5724A40732F302B14575A40321D3A3DEF704A4069ACFD9DED535A40321D3A3DEF704A40
69473	19964	105.416769	105.44018800000001	53.203597000000002	53.192149999999998	Горная	0103000020E61000000100000005000000253FE257AC5A5A4094F6065F98984A40253FE257AC5A5A4028486C770F9A4A40DE054A0A2C5C5A4028486C770F9A4A40DE054A0A2C5C5A4094F6065F98984A40253FE257AC5A5A4094F6065F98984A40
69151	18961	105.741411	105.763797	53.088292000000003	53.065057000000003	Центральная	0103000020E6100000010000000500000042791F47736F5A401DB0ABC953884A4042791F47736F5A40CD3FFA264D8B4A401BF2CF0CE2705A40CD3FFA264D8B4A401BF2CF0CE2705A401DB0ABC953884A4042791F47736F5A401DB0ABC953884A40
69302	19430	105.47920999999999	105.503007	52.992669999999997	52.973641000000001	Муринская	0103000020E61000000100000005000000A27A6B60AB5E5A40BA85AE44A07C4A40A27A6B60AB5E5A4033DC80CF0F7F4A402EAA454431605A4033DC80CF0F7F4A402EAA454431605A40BA85AE44A07C4A40A27A6B60AB5E5A40BA85AE44A07C4A40
67649	19328	105.496503	105.527657	53.076830000000001	53.044609000000001	Гагарина	0103000020E610000001000000050000006BD784B4C65F5A40BB0D6ABFB5854A406BD784B4C65F5A4004ADC090D5894A405AA0DD21C5615A4004ADC090D5894A405AA0DD21C5615A40BB0D6ABFB5854A406BD784B4C65F5A40BB0D6ABFB5854A40
69476	19642	105.37139500000001	105.38426800000001	52.930225999999998	52.917740000000002	Муринская	0103000020E6100000010000000500000078B988EFC4575A40931D1B8178754A4078B988EFC4575A40C7F143A511774A408F39CFD897585A40C7F143A511774A408F39CFD897585A40931D1B8178754A4078B988EFC4575A40931D1B8178754A40
69157	20297	105.613176	105.644626	53.382420000000003	53.360371999999998	Центральная	0103000020E610000001000000050000004BAC8C463E675A40723271AB20AE4A404BAC8C463E675A400DAB7823F3B04A40AF09698D41695A400DAB7823F3B04A40AF09698D41695A40723271AB20AE4A404BAC8C463E675A40723271AB20AE4A40
69160	19818	105.018294	106.183795	53.628394999999998	52.742894999999997	Урбаева	0103000020E61000000100000005000000A2ED98BA2B415A4053AEF02E175F4A40A2ED98BA2B415A4026FC523F6FD04A40C68A1A4CC38B5A4026FC523F6FD04A40C68A1A4CC38B5A4053AEF02E175F4A40A2ED98BA2B415A4053AEF02E175F4A40
69336	18693	103.052663	103.08425699999999	54.337179999999996	54.319831999999998	Центральная	0103000020E6100000010000000500000064ADA1D45EC359406D1B4641F0284B4064ADA1D45EC35940C16ED8B6282B4B4061DD787764C55940C16ED8B6282B4B4061DD787764C559406D1B4641F0284B4064ADA1D45EC359406D1B4641F0284B40
69455	2086	103.07649600000001	103.091515	53.898001999999998	53.885671000000002	Школьная	0103000020E6100000010000000500000097917A4FE5C459400002D6AA5DF14A4097917A4FE5C459400DDFC2BAF1F24A40FB05BB61DBC559400DDFC2BAF1F24A40FB05BB61DBC559400002D6AA5DF14A4097917A4FE5C459400002D6AA5DF14A40
69329	18444	102.735675	102.79120899999999	54.059204000000001	54.041241999999997	Садовый	0103000020E61000000100000005000000075F984C15AF59405E9CF86A47054B40075F984C15AF59406DE525FF93074B4041D3122BA3B259406DE525FF93074B4041D3122BA3B259405E9CF86A47054B40075F984C15AF59405E9CF86A47054B40
68998	18666	102.909086	102.92565	54.386194000000003	54.364865999999999	Школьная	0103000020E6100000010000000500000018D00B772EBA59400FB6D8EDB32E4B4018D00B772EBA5940AAF413CE6E314B40B7627FD93DBB5940AAF413CE6E314B40B7627FD93DBB59400FB6D8EDB32E4B4018D00B772EBA59400FB6D8EDB32E4B40
69286	18550	102.83811900000001	102.87209300000001	54.129085000000003	54.117581999999999	Трудовая	0103000020E6100000010000000500000000CADFBDA3B55940944C4EED0C0F4B4000CADFBDA3B55940BCB376DB85104B408484285FD0B75940BCB376DB85104B408484285FD0B75940944C4EED0C0F4B4000CADFBDA3B55940944C4EED0C0F4B40
68650	18768	102.96634400000001	102.99918700000001	54.496839999999999	54.464345000000002	Первомайская	0103000020E61000000100000005000000E52B8194D8BD5940D3872EA86F3B4B40E52B8194D8BD59401DACFF73983F4B40A8E507AEF2BF59401DACFF73983F4B40A8E507AEF2BF5940D3872EA86F3B4B40E52B8194D8BD5940D3872EA86F3B4B40
68824	18258	103.05664299999999	103.08158	53.990332000000002	53.974834000000001	Лесная	0103000020E610000001000000050000000723F609A0C35940B2834A5CC7FC4A400723F609A0C359405517F032C3FE4A407E00529B38C559405517F032C3FE4A407E00529B38C55940B2834A5CC7FC4A400723F609A0C35940B2834A5CC7FC4A40
68849	18581	102.948324	102.979675	54.226680000000002	54.214325000000002	Ленина	0103000020E61000000100000005000000C3802557B1BC59408CDB68006F1B4B40C3802557B1BC59402254A9D9031D4B405D6DC5FEB2BE59402254A9D9031D4B405D6DC5FEB2BE59408CDB68006F1B4B40C3802557B1BC59408CDB68006F1B4B40
69006	18363	102.88981699999999	102.937059	54.087463	54.064250000000001	2 Советская	0103000020E61000000100000005000000309B00C3F2B859404E62105839084B40309B00C3F2B85940164ED2FC310B4B400ADB4FC6F8BB5940164ED2FC310B4B400ADB4FC6F8BB59404E62105839084B40309B00C3F2B859404E62105839084B40
67839	18787	103.024869	103.073199	54.022219	53.994444999999999	Горького	0103000020E61000000100000005000000CA6B257497C15940DA5548F949FF4A40CA6B257497C15940C72C7B12D8024B4065C6DB4AAFC45940C72C7B12D8024B4065C6DB4AAFC45940DA5548F949FF4A40CA6B257497C15940DA5548F949FF4A40
69057	18473	102.57984399999999	102.59144999999999	54.064805	54.039485999999997	Школьная	0103000020E610000001000000050000000932022A1CA559402E5393E00D054B400932022A1CA5594003CFBD874B084B4007CE1951DAA5594003CFBD874B084B4007CE1951DAA559402E5393E00D054B400932022A1CA559402E5393E00D054B40
67014	17463	103.62833999999999	103.652918	52.340814999999999	52.320501999999998	Клубная	0103000020E6100000010000000500000031B1F9B836E85940BB26A43506294A4031B1F9B836E859403D7E6FD39F2B4A40103E9468C9E959403D7E6FD39F2B4A40103E9468C9E95940BB26A43506294A4031B1F9B836E85940BB26A43506294A40
67647	17578	103.66991400000001	103.73275099999999	52.466597	52.433655000000002	Молодежная	0103000020E610000001000000050000007C48F8DEDFEA59409A5FCD0182374A407C48F8DEDFEA5940B3B45373B93B4A401F477364E5EE5940B3B45373B93B4A401F477364E5EE59409A5FCD0182374A407C48F8DEDFEA59409A5FCD0182374A40
67842	59111	104.03276099999999	104.07320300000001	52.441938999999998	52.400132999999997	переулок Школьный	0103000020E6100000010000000500000064E597C118025A407286E28E37334A4064E597C118025A40D9E9077591384A4006BEA25BAF045A40D9E9077591384A4006BEA25BAF045A407286E28E37334A4064E597C118025A407286E28E37334A40
68072	59111	104.03276099999999	104.07320300000001	52.441938999999998	52.400132999999997	кв-л 17	0103000020E6100000010000000500000064E597C118025A407286E28E37334A4064E597C118025A40D9E9077591384A4006BEA25BAF045A40D9E9077591384A4006BEA25BAF045A407286E28E37334A4064E597C118025A407286E28E37334A40
68147	59111	104.03276099999999	104.07320300000001	52.441938999999998	52.400132999999997	Детсадовская	0103000020E6100000010000000500000064E597C118025A407286E28E37334A4064E597C118025A40D9E9077591384A4006BEA25BAF045A40D9E9077591384A4006BEA25BAF045A407286E28E37334A4064E597C118025A407286E28E37334A40
68809	13460	103.81890799999999	103.84972	52.606462999999998	52.588456000000001	Советская	0103000020E61000000100000005000000B29B19FD68F459404791B586524B4A40B29B19FD68F45940F59D5F94A04D4A4075B0FECF61F65940F59D5F94A04D4A4075B0FECF61F659404791B586524B4A40B29B19FD68F459404791B586524B4A40
67881	59115	103.199196	104.11049199999999	52.488399999999999	52.164796000000003	мкр.1916	0103000020E610000001000000050000009E5F94A0BFCC59407D410B0918154A409E5F94A0BFCC5940E6AE25E4833E4A400E9E094D12075A40E6AE25E4833E4A400E9E094D12075A407D410B0918154A409E5F94A0BFCC59407D410B0918154A40
68983	52030	102.799958	102.819559	53.533790000000003	53.517394000000003	Центральная	0103000020E610000001000000050000001C0B0A8332B35940C59272F739C24A401C0B0A8332B359404777103B53C44A401E8997A773B459404777103B53C44A401E8997A773B45940C59272F739C24A401C0B0A8332B35940C59272F739C24A40
69258	51999	102.31967400000001	102.33623	53.178736000000001	53.162422999999997	Центральная	0103000020E610000001000000050000006BD8EF8975945940218FE046CA944A406BD8EF8975945940164F3DD2E0964A40C87BD5CA84955940164F3DD2E0964A40C87BD5CA84955940218FE046CA944A406BD8EF8975945940218FE046CA944A40
68977	51956	102.970378	102.98996099999999	53.383135000000003	53.373927999999999	Первая	0103000020E6100000010000000500000081B053AC1ABE5940838769DFDCAF4A4081B053AC1ABE5940FB7953910AB14A4030D461855BBF5940FB7953910AB14A4030D461855BBF5940838769DFDCAF4A4081B053AC1ABE5940838769DFDCAF4A40
69468	51943	102.25116800000001	102.261894	53.268531000000003	53.257758000000003	Светлая	0103000020E610000001000000050000005073F222139059402524D236FEA04A405073F22213905940297B4B395FA24A4031410DDFC2905940297B4B395FA24A4031410DDFC29059402524D236FEA04A405073F222139059402524D236FEA04A40
68942	51937	102.6995	102.72167	53.295256000000002	53.279105999999999	Советская	0103000020E6100000010000000500000054E3A59BC4AC5940060FD3BEB9A34A4054E3A59BC4AC594051F9D7F2CAA54A4047205ED72FAE594051F9D7F2CAA54A4047205ED72FAE5940060FD3BEB9A34A4054E3A59BC4AC5940060FD3BEB9A34A40
69490	52040	102.849779	102.86841	53.359054999999998	53.342838999999998	Новая	0103000020E61000000100000005000000F77475C762B659408C65FA25E2AB4A40F77475C762B659408E3BA583F5AD4A403D61890794B759408E3BA583F5AD4A403D61890794B759408C65FA25E2AB4A40F77475C762B659408C65FA25E2AB4A40
68856	52068	103.265097	103.280539	53.358334999999997	53.339592000000003	Советская	0103000020E6100000010000000500000022516859F7D05940DBFD2AC077AB4A4022516859F7D059408E01D9EBDDAD4A402A90D959F4D159408E01D9EBDDAD4A402A90D959F4D15940DBFD2AC077AB4A4022516859F7D05940DBFD2AC077AB4A40
68747	52061	102.89997700000001	102.92334200000001	53.443503999999997	53.419282000000003	Чумакова	0103000020E61000000100000005000000BE89213999B9594097E65608ABB54A40BE89213999B9594095D233BDC4B84A407D410B0918BB594095D233BDC4B84A407D410B0918BB594097E65608ABB54A40BE89213999B9594097E65608ABB54A40
69472	51989	102.34204200000001	102.361086	53.248330000000003	53.233888	Новая	0103000020E61000000100000005000000F1F62004E4955940A376BF0AF09D4A40F1F62004E4955940CF4E0647C99F4A40C84274081C975940CF4E0647C99F4A40C84274081C975940A376BF0AF09D4A40F1F62004E4955940A376BF0AF09D4A40
68527	52057	102.66895700000001	102.695825	53.024557000000001	53.009247999999999	Советская	0103000020E610000001000000050000008A5B0531D0AA5940D6C6D8092F814A408A5B0531D0AA5940A6F10BAF24834A404FAF946588AC5940A6F10BAF24834A404FAF946588AC5940D6C6D8092F814A408A5B0531D0AA5940D6C6D8092F814A40
69332	52048	103.119525	103.137249	53.363956000000002	53.351191999999998	Мира	0103000020E610000001000000050000007B832F4CA6C75940F44E05DCF3AC4A407B832F4CA6C759406C97361C96AE4A40289A07B0C8C859406C97361C96AE4A40289A07B0C8C85940F44E05DCF3AC4A407B832F4CA6C75940F44E05DCF3AC4A40
68997	51965	102.126698	103.384699	53.644298999999997	52.992697	Центральная	0103000020E61000000100000005000000FE9DEDD11B8859402DEBFEB1107F4A40FE9DEDD11B88594039ECBE6378D24A4073F38DE89ED8594039ECBE6378D24A4073F38DE89ED859402DEBFEB1107F4A40FE9DEDD11B8859402DEBFEB1107F4A40
68995	52046	103.047372	103.05952600000001	53.372627999999999	53.358007000000001	Трактовая	0103000020E61000000100000005000000C0AF912408C359409A5E622CD3AD4A40C0AF912408C3594075C93846B2AF4A40C0D02346CFC3594075C93846B2AF4A40C0D02346CFC359409A5E622CD3AD4A40C0AF912408C359409A5E622CD3AD4A40
69148	52038	102.852977	102.87691700000001	53.403319000000003	53.383527000000001	Лесная	0103000020E610000001000000050000005FCFD72C97B659400611A96917B14A405FCFD72C97B659407F6DFDF49FB34A409D137B681FB859407F6DFDF49FB34A409D137B681FB859400611A96917B14A405FCFD72C97B659400611A96917B14A40
69328	52025	102.71827399999999	102.749033	53.510320999999998	53.486956999999997	Советская	0103000020E610000001000000050000004BE48233F8AD594075C7629B54BE4A404BE48233F8AD594023BBD23252C14A40FCA71B28F0AF594023BBD23252C14A40FCA71B28F0AF594075C7629B54BE4A404BE48233F8AD594075C7629B54BE4A40
69023	52037	102.77092500000001	102.78522599999999	53.402611	53.389977000000002	Школьная	0103000020E61000000100000005000000CEAACFD556B159409A982EC4EAB14A40CEAACFD556B159404301DBC188B34A40027E8D2441B259404301DBC188B34A40027E8D2441B259409A982EC4EAB14A40CEAACFD556B159409A982EC4EAB14A40
69485	52031	102.82729399999999	102.83909800000001	53.406002999999998	53.394246000000003	Центральная	0103000020E61000000100000005000000548B8862F2B45940174A26A776B24A40548B8862F2B45940F88903E8F7B34A40E60819C8B3B55940F88903E8F7B34A40E60819C8B3B55940174A26A776B24A40548B8862F2B45940174A26A776B24A40
67763	52008	102.74261	102.807827	53.373804	53.334021	Шилова	0103000020E61000000100000005000000AFEB17EC86AF5940AF963B33C1AA4A40AFEB17EC86AF5940978E39CFD8AF4A40DA740470B3B35940978E39CFD8AF4A40DA740470B3B35940AF963B33C1AA4A40AFEB17EC86AF5940AF963B33C1AA4A40
67945	52008	102.74261	102.807827	53.373804	53.334021	Советская	0103000020E61000000100000005000000AFEB17EC86AF5940AF963B33C1AA4A40AFEB17EC86AF5940978E39CFD8AF4A40DA740470B3B35940978E39CFD8AF4A40DA740470B3B35940AF963B33C1AA4A40AFEB17EC86AF5940AF963B33C1AA4A40
68845	52008	102.74261	102.807827	53.373804	53.334021	Ветеринарная	0103000020E61000000100000005000000AFEB17EC86AF5940AF963B33C1AA4A40AFEB17EC86AF5940978E39CFD8AF4A40DA740470B3B35940978E39CFD8AF4A40DA740470B3B35940AF963B33C1AA4A40AFEB17EC86AF5940AF963B33C1AA4A40
69144	51932	102.41968300000001	102.43291600000001	53.179701999999999	53.167211999999999	Центральная	0103000020E61000000100000005000000FBEB1516DC9A5940D7BFEB3367954A40FBEB1516DC9A59404D83A27900974A40927A4FE5B49B59404D83A27900974A40927A4FE5B49B5940D7BFEB3367954A40FBEB1516DC9A5940D7BFEB3367954A40
69200	32296	103.08852400000001	103.10760399999999	53.281491000000003	53.271718999999997	Партизанская	0103000020E61000000100000005000000503A9160AAC55940D5592DB0C7A24A40503A9160AAC55940268FA7E507A44A40CD3AE3FBE2C65940268FA7E507A44A40CD3AE3FBE2C65940D5592DB0C7A24A40503A9160AAC55940D5592DB0C7A24A40
69143	51928	102.506703	102.53566499999999	53.191437999999998	53.179070000000003	Центральная	0103000020E610000001000000050000003F726BD26DA05940EDD808C4EB964A403F726BD26DA05940179B560A81984A402827DA5548A25940179B560A81984A402827DA5548A25940EDD808C4EB964A403F726BD26DA05940EDD808C4EB964A40
69271	52002	102.732468	102.761403	53.192732999999997	53.179220999999998	Центральная	0103000020E61000000100000005000000755776C1E0AE5940D2E0B6B6F0964A40755776C1E0AE594013EE9579AB984A40E204A6D3BAB0594013EE9579AB984A40E204A6D3BAB05940D2E0B6B6F0964A40755776C1E0AE5940D2E0B6B6F0964A40
69335	52022	102.70312	102.723583	53.395422000000003	53.385900999999997	Центральная	0103000020E61000000100000005000000774A07EBFFAC5940313F373465B14A40774A07EBFFAC5940390F27309DB24A40433C122F4FAE5940390F27309DB24A40433C122F4FAE5940313F373465B14A40774A07EBFFAC5940313F373465B14A40
69337	59246	102.819541	102.84482	53.450975	53.441186999999999	Звездочка	0103000020E61000000100000005000000CB2E185C73B45940CE35CCD078B84A40CB2E185C73B4594024287E8CB9B94A406EC0E78711B6594024287E8CB9B94A406EC0E78711B65940CE35CCD078B84A40CB2E185C73B45940CE35CCD078B84A40
69149	51984	102.39763000000001	102.413512	53.247765000000001	53.229861999999997	Центральная	0103000020E61000000100000005000000257A19C572995940EC4B361E6C9D4A40257A19C572995940F60B76C3B69F4A403A2009FB769A5940F60B76C3B69F4A403A2009FB769A5940EC4B361E6C9D4A40257A19C572995940EC4B361E6C9D4A40
69469	52064	102.126698	103.384699	53.644298999999997	52.992697	Ербанова	0103000020E61000000100000005000000FE9DEDD11B8859402DEBFEB1107F4A40FE9DEDD11B88594039ECBE6378D24A4073F38DE89ED8594039ECBE6378D24A4073F38DE89ED859402DEBFEB1107F4A40FE9DEDD11B8859402DEBFEB1107F4A40
68625	51998	102.68314100000001	102.706255	53.166606999999999	53.150744000000003	Коммунаров	0103000020E61000000100000005000000A2630795B8AB5940BC0853944B934A40A2630795B8AB59407024D06053954A40BCE82B4833AD59407024D06053954A40BCE82B4833AD5940BC0853944B934A40A2630795B8AB5940BC0853944B934A40
69257	51961	102.744936	102.768355	53.324534999999997	53.316665999999998	Белорусская	0103000020E610000001000000050000003C670B08ADAF5940A8E0F08288A84A403C670B08ADAF594024B4E55C8AA94A40F52D73BA2CB1594024B4E55C8AA94A40F52D73BA2CB15940A8E0F08288A84A403C670B08ADAF5940A8E0F08288A84A40
68823	51978	102.32978900000001	102.35522899999999	53.219538	53.182842999999998	Юбилейная	0103000020E61000000100000005000000286552431B955940B9A6406667974A40286552431B955940581D39D2199C4A40CF656A12BC965940581D39D2199C4A40CF656A12BC965940B9A6406667974A40286552431B955940B9A6406667974A40
68835	51970	102.51893800000001	102.553982	53.322991000000002	53.308590000000002	Центральная	0103000020E61000000100000005000000B5A9BA4736A15940B3EF8AE07FA74A40B5A9BA4736A1594080F3E2C457A94A40A724EB7074A3594080F3E2C457A94A40A724EB7074A35940B3EF8AE07FA74A40B5A9BA4736A15940B3EF8AE07FA74A40
69266	51996	102.623924	102.64278	53.169868000000001	53.161473000000001	Первая	0103000020E6100000010000000500000021CCED5EEEA75940F017B325AB944A4021CCED5EEEA759408751103CBE954A4077A1B94E23A959408751103CBE954A4077A1B94E23A95940F017B325AB944A4021CCED5EEEA75940F017B325AB944A40
69139	52018	102.594729	102.62833500000001	53.441524999999999	53.413550000000001	Центральная	0103000020E61000000100000005000000E63E390A10A6594062A1D634EFB44A40E63E390A10A65940E6AE25E483B84A40A9FB00A436A85940E6AE25E483B84A40A9FB00A436A8594062A1D634EFB44A40E63E390A10A6594062A1D634EFB44A40
67756	51960	102.81222	102.845	53.285082000000003	53.259568000000002	70 лет Октября	0103000020E610000001000000050000000E4A9869FBB35940488B338639A14A400E4A9869FBB35940D25625917DA44A40AE47E17A14B65940D25625917DA44A40AE47E17A14B65940488B338639A14A400E4A9869FBB35940488B338639A14A40
69566	59304	103.00447800000001	103.027466	53.309392000000003	53.297542999999997	Центральная	0103000020E610000001000000050000004CE3175E49C05940AD1397E315A64A404CE3175E49C0594070D234289AA74A4020F0C000C2C1594070D234289AA74A4020F0C000C2C15940AD1397E315A64A404CE3175E49C05940AD1397E315A64A40
68117	52006	102.655725	102.678731	53.446277000000002	53.420032999999997	Васильева	0103000020E61000000100000005000000DB8AFD65F7A95940D11E2FA4C3B54A40DB8AFD65F7A959407FFACF9A1FB94A4002F2255470AB59407FFACF9A1FB94A4002F2255470AB5940D11E2FA4C3B54A40DB8AFD65F7A95940D11E2FA4C3B54A40
68971	51941	102.17714700000001	102.192679	53.281750000000002	53.268858999999999	Нагорная	0103000020E6100000010000000500000069E55E60568B59401D1EC2F869A24A4069E55E60568B5940F2D24D6210A44A4010E84CDA548C5940F2D24D6210A44A4010E84CDA548C59401D1EC2F869A24A4069E55E60568B59401D1EC2F869A24A40
69146	51949	103.317891	103.332587	53.508446999999997	53.499380000000002	Мира	0103000020E61000000100000005000000562C7E5358D45940642310AFEBBF4A40562C7E5358D45940E95F92CA14C14A40C904FC1A49D55940E95F92CA14C14A40C904FC1A49D55940642310AFEBBF4A40562C7E5358D45940642310AFEBBF4A40
69368	59252	102.126698	103.384699	53.644298999999997	52.992697	Школьная	0103000020E61000000100000005000000FE9DEDD11B8859402DEBFEB1107F4A40FE9DEDD11B88594039ECBE6378D24A4073F38DE89ED8594039ECBE6378D24A4073F38DE89ED859402DEBFEB1107F4A40FE9DEDD11B8859402DEBFEB1107F4A40
69147	51967	102.42775899999999	102.448133	53.369323999999999	53.343924999999999	Верхняя	0103000020E6100000010000000500000075E44867609B59406EA301BC05AC4A4075E44867609B59405FD0420246AF4A4089D00836AE9C59405FD0420246AF4A4089D00836AE9C59406EA301BC05AC4A4075E44867609B59406EA301BC05AC4A40
69330	52051	102.596535	102.618903	53.027422000000001	53.019632999999999	Школьная	0103000020E61000000100000005000000D7FA22A12DA6594010768A5583824A40D7FA22A12DA659407098689082834A405D19541B9CA759407098689082834A405D19541B9CA7594010768A5583824A40D7FA22A12DA6594010768A5583824A40
68623	51950	103.09562099999999	103.124933	53.513148000000001	53.495790999999997	Ербанова	0103000020E61000000100000005000000E4F38AA71EC659405853591476BF4A40E4F38AA71EC6594000016BD5AEC14A403C4CFBE6FEC7594000016BD5AEC14A403C4CFBE6FEC759405853591476BF4A40E4F38AA71EC659405853591476BF4A40
68968	52045	103.081867	103.101612	53.352938999999999	53.335914000000002	Октябрьская	0103000020E61000000100000005000000C9E7154F3DC559406022DE3AFFAA4A40C9E7154F3DC55940D13DEB1A2DAD4A4065389ECF80C65940D13DEB1A2DAD4A4065389ECF80C659406022DE3AFFAA4A40C9E7154F3DC559406022DE3AFFAA4A40
69467	51946	103.207802	103.216579	53.417274999999997	53.409019999999998	Победы	0103000020E61000000100000005000000C782C2A04CCD594078B471C45AB44A40C782C2A04CCD59401D38674469B54A4006802A6EDCCD59401D38674469B54A4006802A6EDCCD594078B471C45AB44A40C782C2A04CCD594078B471C45AB44A40
68976	51945	103.340771	103.37135000000001	53.466265	53.458336000000003	Ленина	0103000020E61000000100000005000000371B2B31CFD559402C4A09C1AABA4A40371B2B31CFD559407D224F92AEBB4A40A857CA32C4D759407D224F92AEBB4A40A857CA32C4D759402C4A09C1AABA4A40371B2B31CFD559402C4A09C1AABA4A40
68538	51940	102.18606699999999	102.247027	53.228724	53.192593000000002	Жана Зимина	0103000020E6100000010000000500000059F78F85E88B594022382EE3A6984A4059F78F85E88B5940B8E7F9D3469D4A40A88E554ACF8F5940B8E7F9D3469D4A40A88E554ACF8F594022382EE3A6984A4059F78F85E88B594022382EE3A6984A40
69376	51926	102.623817	102.635468	53.116875999999998	53.111628000000003	Школьная	0103000020E61000000100000005000000166C239EECA75940B1A888D3498E4A40166C239EECA75940F9D7F2CAF58E4A40E469F981ABA85940F9D7F2CAF58E4A40E469F981ABA85940B1A888D3498E4A40166C239EECA75940B1A888D3498E4A40
68967	51934	102.643373	102.66902899999999	53.353203000000001	53.328890999999999	Центральная	0103000020E610000001000000050000004888F2052DA959407079AC1919AA4A404888F2052DA95940AFEC82C135AD4A40D6C4025FD1AA5940AFEC82C135AD4A40D6C4025FD1AA59407079AC1919AA4A404888F2052DA959407079AC1919AA4A40
68734	51923	102.525505	102.56018899999999	53.076852000000002	53.062291999999999	Лазо	0103000020E610000001000000050000009B38B9DFA1A15940B6662B2FF9874A409B38B9DFA1A15940EC504D49D6894A400DA5F622DAA35940EC504D49D6894A400DA5F622DAA35940B6662B2FF9874A409B38B9DFA1A15940B6662B2FF9874A40
73597	60046	115.972449	116.069503	51.875777999999997	51.837085000000002	Бородина	0103000020E61000000100000005000000C901BB9A3CFE5C40707CED9925EB4940C901BB9A3CFE5C403447567E19F0494054FEB5BC72045D403447567E19F0494054FEB5BC72045D40707CED9925EB4940C901BB9A3CFE5C40707CED9925EB4940
73707	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	проезд Булгакова	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73598	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	мкр. Геофизический	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73553	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	микрорайон Северный	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73558	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ярославского	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73724	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Юбилейная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
23936	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Труда	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73610	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Строителей	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73642	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Романовский Тракт	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73635	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ползунова	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73766	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Первомайская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73606	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Новобульварная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73576	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Луговая	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
24185	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ленина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67467	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Лазо	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73640	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Красной Звезды	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73574	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Карла Маркса	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73590	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Забайкальского Рабочего	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73645	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Журавлева	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73653	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Жилой городок	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73611	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Декабристов	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73566	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Горького	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73575	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Горького	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73651	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Геофизический микрорайон	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73554	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Геодезическая	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73622	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Гагарина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73727	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Вайнштейна	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73613	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Балябина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67263	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Бабушкина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73701	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Агрогородок Опытный	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73670	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	6 микрорайон	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73627	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	4 микрорайон	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73546	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	 Хабаровская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73682	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	 Промышленная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
34056	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	 Кайдаловская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73685	50869	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	 5 микрорайон	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
34045	54090	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Курнатовского	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73618	54090	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Дивизионная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73678	54090	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Белорусская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73815	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	площадь Ленина	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
24278	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Чехова	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
24275	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Федосеевка	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
23366	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Станционная	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
27376	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Спортивная	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
28103	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Островского	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
27235	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Некрасова	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
73798	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Нагорная	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
28177	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Нагаева	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
73982	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Мира	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
73615	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Микрорайон 1	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
24355	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Лесная	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
24282	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Ленина	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
24327	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Лазо	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
73859	29213	108.25475299999999	108.270123	50.821598000000002	50.81626	Красная	0103000020E61000000100000005000000B4E386DF4D105B4038842A357B684940B4E386DF4D105B40C13A8E1F2A6949406FB9FAB149115B40C13A8E1F2A6949406FB9FAB149115B4038842A357B684940B4E386DF4D105B4038842A357B684940
73981	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Декабристов	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
24234	29213	108.772919	108.911907	51.336545999999998	51.221228000000004	Горбачевского	0103000020E6100000010000000500000040DD408177315B40D17AF832519C494040DD408177315B40C0CC77F013AB4940957F2DAF5C3A5B40C0CC77F013AB4940957F2DAF5C3A5B40D17AF832519C494040DD408177315B40D17AF832519C4940
73572	60040	116.5086	116.610891	52.007510000000003	51.924886000000001	Красноармейская	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
73797	60040	116.5086	116.610891	52.007510000000003	51.924886000000001	Береговая	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
73774	60045	116.58400399999999	116.722525	51.600928000000003	51.538722	Чернышевского	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
73704	51745	113.404777	113.54536299999999	52.085343000000002	51.992057000000003	Трактовая	0103000020E61000000100000005000000124BCADDE7595C404A6249B9FBFE4940124BCADDE7595C40A5F8F884EC0A4A40B35C363AE7625C40A5F8F884EC0A4A40B35C363AE7625C404A6249B9FBFE4940124BCADDE7595C404A6249B9FBFE4940
71615	51745	113.404777	113.54536299999999	52.085343000000002	51.992057000000003	Профсоюзная	0103000020E61000000100000005000000124BCADDE7595C404A6249B9FBFE4940124BCADDE7595C40A5F8F884EC0A4A40B35C363AE7625C40A5F8F884EC0A4A40B35C363AE7625C404A6249B9FBFE4940124BCADDE7595C404A6249B9FBFE4940
73832	51745	113.404777	113.54536299999999	52.085343000000002	51.992057000000003	Молоковский Тракт	0103000020E61000000100000005000000124BCADDE7595C404A6249B9FBFE4940124BCADDE7595C40A5F8F884EC0A4A40B35C363AE7625C40A5F8F884EC0A4A40B35C363AE7625C404A6249B9FBFE4940124BCADDE7595C404A6249B9FBFE4940
27804	51745	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ингодинская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67459	51745	113.404777	113.54536299999999	52.085343000000002	51.992057000000003	Баргузинская	0103000020E61000000100000005000000124BCADDE7595C404A6249B9FBFE4940124BCADDE7595C40A5F8F884EC0A4A40B35C363AE7625C40A5F8F884EC0A4A40B35C363AE7625C404A6249B9FBFE4940124BCADDE7595C404A6249B9FBFE4940
73687	51745	113.404777	113.54536299999999	52.085343000000002	51.992057000000003	1-й Микрорайон	0103000020E61000000100000005000000124BCADDE7595C404A6249B9FBFE4940124BCADDE7595C40A5F8F884EC0A4A40B35C363AE7625C40A5F8F884EC0A4A40B35C363AE7625C404A6249B9FBFE4940124BCADDE7595C404A6249B9FBFE4940
71586	557	115.972449	116.069503	51.875777999999997	51.837085000000002	Ленина	0103000020E61000000100000005000000C901BB9A3CFE5C40707CED9925EB4940C901BB9A3CFE5C403447567E19F0494054FEB5BC72045D403447567E19F0494054FEB5BC72045D40707CED9925EB4940C901BB9A3CFE5C40707CED9925EB4940
73830	557	115.972449	116.069503	51.875777999999997	51.837085000000002	Забелина	0103000020E61000000100000005000000C901BB9A3CFE5C40707CED9925EB4940C901BB9A3CFE5C403447567E19F0494054FEB5BC72045D403447567E19F0494054FEB5BC72045D40707CED9925EB4940C901BB9A3CFE5C40707CED9925EB4940
24203	557	115.972449	116.069503	51.875777999999997	51.837085000000002	Вокзальная	0103000020E61000000100000005000000C901BB9A3CFE5C40707CED9925EB4940C901BB9A3CFE5C403447567E19F0494054FEB5BC72045D403447567E19F0494054FEB5BC72045D40707CED9925EB4940C901BB9A3CFE5C40707CED9925EB4940
67209	557	115.972449	116.069503	51.875777999999997	51.837085000000002	Балябина	0103000020E61000000100000005000000C901BB9A3CFE5C40707CED9925EB4940C901BB9A3CFE5C403447567E19F0494054FEB5BC72045D403447567E19F0494054FEB5BC72045D40707CED9925EB4940C901BB9A3CFE5C40707CED9925EB4940
28108	2226	115.76881	115.785618	51.640607000000003	51.615375999999998	Советская	0103000020E610000001000000050000009EB5DB2E34F15C40245F09A4C4CE49409EB5DB2E34F15C405A4B0169FFD149408849B89047F25C405A4B0169FFD149408849B89047F25C40245F09A4C4CE49409EB5DB2E34F15C40245F09A4C4CE4940
23600	1038	116.216989	116.264402	51.911181999999997	51.896957	Просвещенская	0103000020E61000000100000005000000DFA5D425E30D5D408A75AA7CCFF24940DFA5D425E30D5D40185A9D9CA1F44940CFBF5DF6EB105D40185A9D9CA1F44940CFBF5DF6EB105D408A75AA7CCFF24940DFA5D425E30D5D408A75AA7CCFF24940
74021	2123	115.95283000000001	115.974228	51.551648999999998	51.538386000000003	Советская	0103000020E610000001000000050000007429AE2AFBFC5C40E84F1BD5E9C449407429AE2AFBFC5C4080EF366F9CC649403DB665C059FE5C4080EF366F9CC649403DB665C059FE5C40E84F1BD5E9C449407429AE2AFBFC5C40E84F1BD5E9C44940
74055	60220	115.757015	115.784234	51.474224999999997	51.460282999999997	Зеленая	0103000020E6100000010000000500000036E50AEF72F05C40CFF3A78DEABA494036E50AEF72F05C4009F9A067B3BC4940529ACDE330F25C4009F9A067B3BC4940529ACDE330F25C40CFF3A78DEABA494036E50AEF72F05C40CFF3A78DEABA4940
73994	3145	115.78303099999999	115.79739499999999	52.068061999999998	52.055764000000003	Центральная	0103000020E6100000010000000500000044300E2E1DF25C40A725564623074A4044300E2E1DF25C40D80C7041B6084A409CBF098508F35C40D80C7041B6084A409CBF098508F35C40A725564623074A4044300E2E1DF25C40A725564623074A40
73965	1995	115.63498800000001	115.649658	51.997225	51.989749000000003	Центральная	0103000020E610000001000000050000008F56B5A4A3E85C40D61F6118B0FE49408F56B5A4A3E85C4076E09C11A5FF49406DE525FF93E95C4076E09C11A5FF49406DE525FF93E95C40D61F6118B0FE49408F56B5A4A3E85C40D61F6118B0FE4940
74050	60217	115.074709	115.09317799999999	51.770819000000003	51.756960999999997	Жалган	0103000020E61000000100000005000000E1ED4108C8C45C4079AC1919E4E04940E1ED4108C8C45C4056116E32AAE249403AADDBA0F6C55C4056116E32AAE249403AADDBA0F6C55C4079AC1919E4E04940E1ED4108C8C45C4079AC1919E4E04940
73810	2439	115.47922	115.500106	51.788091999999999	51.763461	Зеленская	0103000020E61000000100000005000000B4E55C8AABDE5C40BF620D17B9E14940B4E55C8AABDE5C409F1EDB32E0E4494023A298BC01E05C409F1EDB32E0E4494023A298BC01E05C40BF620D17B9E14940B4E55C8AABDE5C40BF620D17B9E14940
67211	1166	115.59292000000001	115.649092	51.674599999999998	51.652718	Чкалова	0103000020E610000001000000050000003D49BA66F2E55C4059C16F438CD349403D49BA66F2E55C40D8F0F44A59D6494018062CB98AE95C40D8F0F44A59D6494018062CB98AE95C4059C16F438CD349403D49BA66F2E55C4059C16F438CD34940
28039	1166	115.59292000000001	115.649092	51.674599999999998	51.652718	Строительная	0103000020E610000001000000050000003D49BA66F2E55C4059C16F438CD349403D49BA66F2E55C40D8F0F44A59D6494018062CB98AE95C40D8F0F44A59D6494018062CB98AE95C4059C16F438CD349403D49BA66F2E55C4059C16F438CD34940
73672	60039	115.59292000000001	115.649092	51.674599999999998	51.652718	микрорайон	0103000020E610000001000000050000003D49BA66F2E55C4059C16F438CD349403D49BA66F2E55C40D8F0F44A59D6494018062CB98AE95C40D8F0F44A59D6494018062CB98AE95C4059C16F438CD349403D49BA66F2E55C4059C16F438CD34940
73571	60039	115.59292000000001	115.649092	51.674599999999998	51.652718	Пролетарская	0103000020E610000001000000050000003D49BA66F2E55C4059C16F438CD349403D49BA66F2E55C40D8F0F44A59D6494018062CB98AE95C40D8F0F44A59D6494018062CB98AE95C4059C16F438CD349403D49BA66F2E55C4059C16F438CD34940
73600	60039	115.59292000000001	115.649092	51.674599999999998	51.652718	Ленина	0103000020E610000001000000050000003D49BA66F2E55C4059C16F438CD349403D49BA66F2E55C40D8F0F44A59D6494018062CB98AE95C40D8F0F44A59D6494018062CB98AE95C4059C16F438CD349403D49BA66F2E55C4059C16F438CD34940
73872	2896	115.96993399999999	115.98985	52.076830000000001	52.066040999999998	Центральная	0103000020E61000000100000005000000D2510E6613FE5C40FA980F0874084A40D2510E6613FE5C4004ADC090D5094A40857CD0B359FF5C4004ADC090D5094A40857CD0B359FF5C40FA980F0874084A40D2510E6613FE5C40FA980F0874084A40
73732	3153	115.937918	115.96829	51.490502999999997	51.468755000000002	Школьная	0103000020E610000001000000050000001A1538D906FC5C40126BF12900BC49401A1538D906FC5C4081CB63CDC8BE4940CEC29E76F8FD5C4081CB63CDC8BE4940CEC29E76F8FD5C40126BF12900BC49401A1538D906FC5C40126BF12900BC4940
73909	2350	115.48257099999999	115.50767	51.645850000000003	51.631714000000002	Школьная	0103000020E61000000100000005000000DFBF7971E2DE5C4072361D01DCD04940DFBF7971E2DE5C40910F7A36ABD2494043CA4FAA7DE05C40910F7A36ABD2494043CA4FAA7DE05C4072361D01DCD04940DFBF7971E2DE5C4072361D01DCD04940
73873	2763	116.08517000000001	116.114994	52.11974	52.111572000000002	Центральная	0103000020E610000001000000050000006C26DF6C73055D401D93C5FD470E4A406C26DF6C73055D40F302ECA3530F4A401E4FCB0F5C075D40F302ECA3530F4A401E4FCB0F5C075D401D93C5FD470E4A406C26DF6C73055D401D93C5FD470E4A40
73871	2804	116.146013	116.15807700000001	52.065398999999999	52.051654999999997	Советская	0103000020E610000001000000050000009DF2E84658095D4062D68BA19C064A409DF2E84658095D40761893FE5E084A40FD4FFEEE1D0A5D40761893FE5E084A40FD4FFEEE1D0A5D4062D68BA19C064A409DF2E84658095D4062D68BA19C064A40
27342	1834	115.94223	115.964589	51.824378000000003	51.815019999999997	Глазова	0103000020E61000000100000005000000D8D30E7F4DFC5C40FFCA4A9352E84940D8D30E7F4DFC5C405DC5E23785E94940354580D3BBFD5C405DC5E23785E94940354580D3BBFD5C40FFCA4A9352E84940D8D30E7F4DFC5C40FFCA4A9352E84940
73760	1735	116.132188	116.174516	51.891689	51.881399000000002	Кирова	0103000020E610000001000000050000001D3BA8C475085D4012DDB3AED1F049401D3BA8C475085D40FA997ADD22F249403D2828452B0B5D40FA997ADD22F249403D2828452B0B5D4012DDB3AED1F049401D3BA8C475085D4012DDB3AED1F04940
73912	2091	115.40704100000001	115.42627400000001	52.066462000000001	52.058931999999999	Соболева	0103000020E6100000010000000500000065C8B1F50CDA5C400C5872158B074A4065C8B1F50CDA5C40A036AAD381084A40A648BE1248DB5C40A036AAD381084A40A648BE1248DB5C400C5872158B074A4065C8B1F50CDA5C400C5872158B074A40
24322	2465	115.57842100000001	115.602721	51.770718000000002	51.764781999999997	Центральная	0103000020E61000000100000005000000759483D904E55C40E4486760E4E14940759483D904E55C4022382EE3A6E2494032E719FB92E65C4022382EE3A6E2494032E719FB92E65C40E4486760E4E14940759483D904E55C40E4486760E4E14940
27238	1870	115.85857	115.868101	51.937514999999998	51.929141000000001	Центральная	0103000020E61000000100000005000000E9D495CFF2F65C40B62FA017EEF64940E9D495CFF2F65C403541D47D00F84940FE277FF78EF75C403541D47D00F84940FE277FF78EF75C40B62FA017EEF64940E9D495CFF2F65C40B62FA017EEF64940
28404	2316	115.828422	115.845769	51.605823000000001	51.585490999999998	Заимочная	0103000020E610000001000000050000005D52B5DD04F55C40198D7C5EF1CA49405D52B5DD04F55C401215AA9B8BCD49401FBE4C1421F65C401215AA9B8BCD49401FBE4C1421F65C40198D7C5EF1CA49405D52B5DD04F55C40198D7C5EF1CA4940
74026	1760	114.97969399999999	116.375793	52.326298000000001	51.225898999999998	Лазо	0103000020E610000001000000050000009885764EB3BE5C407C992842EA9C49409885764EB3BE5C4007600322C4294A40354415FE0C185D4007600322C4294A40354415FE0C185D407C992842EA9C49409885764EB3BE5C407C992842EA9C4940
34022	1662	115.847835	115.887657	51.799829000000003	51.751877	Октябрьской революции	0103000020E61000000100000005000000DE59BBED42F65C40ABCE6A813DE04940DE59BBED42F65C403AB2F2CB60E6494031444E5FCFF85C403AB2F2CB60E6494031444E5FCFF85C40ABCE6A813DE04940DE59BBED42F65C40ABCE6A813DE04940
74025	2660	115.256986	115.283073	51.788849999999996	51.782319999999999	Центральная	0103000020E61000000100000005000000E961687572D05C40DC80CF0F23E44940E961687572D05C408CB96B09F9E449405C5837DE1DD25C408CB96B09F9E449405C5837DE1DD25C40DC80CF0F23E44940E961687572D05C40DC80CF0F23E44940
24647	2576	115.17506	115.195038	51.783355999999998	51.769804000000001	Центральная	0103000020E610000001000000050000009EB5DB2E34CB5C403D2AFEEF88E249409EB5DB2E34CB5C400C90680245E449408BDEA9807BCC5C400C90680245E449408BDEA9807BCC5C403D2AFEEF88E249409EB5DB2E34CB5C403D2AFEEF88E24940
73811	3000	115.873392	115.906423	52.093693000000002	52.079901999999997	Советская	0103000020E61000000100000005000000A2258FA7E5F75C4047718E3A3A0A4A40A2258FA7E5F75C409C6ED921FE0B4A40E7559DD502FA5C409C6ED921FE0B4A40E7559DD502FA5C4047718E3A3A0A4A40A2258FA7E5F75C4047718E3A3A0A4A40
73874	3043	115.933031	115.945832	52.031368999999998	52.022807999999998	Клубная	0103000020E61000000100000005000000DEC9A7C7B6FB5C40280B5F5FEB024A40DEC9A7C7B6FB5C40DA8D3EE603044A40A8E0F08288FC5C40DA8D3EE603044A40A8E0F08288FC5C40280B5F5FEB024A40DEC9A7C7B6FB5C40280B5F5FEB024A40
73904	1067	116.264608	116.29595999999999	51.949506	51.935915000000001	Первомайская	0103000020E61000000100000005000000A3906456EF105D40FD6A0E10CCF74940A3906456EF105D408AADA06989F94940253B3602F1125D408AADA06989F94940253B3602F1125D40FD6A0E10CCF74940A3906456EF105D40FD6A0E10CCF74940
73970	60175	117.41261	117.438158	51.896157000000002	51.876033999999997	Центральная	0103000020E610000001000000050000002A00C633685A5D408F17D2E121F049402A00C633685A5D406E8AC745B5F24940C51EDAC70A5C5D406E8AC745B5F24940C51EDAC70A5C5D408F17D2E121F049402A00C633685A5D408F17D2E121F04940
74061	60175	117.41261	117.438158	51.896157000000002	51.876033999999997	Верхняя	0103000020E610000001000000050000002A00C633685A5D408F17D2E121F049402A00C633685A5D406E8AC745B5F24940C51EDAC70A5C5D406E8AC745B5F24940C51EDAC70A5C5D408F17D2E121F049402A00C633685A5D408F17D2E121F04940
73969	50952	117.52985	117.58996500000001	51.668925000000002	51.634324999999997	Центральная	0103000020E610000001000000050000004772F90FE9615D408104C58F31D149404772F90FE9615D40083D9B559FD5494038328FFCC1655D40083D9B559FD5494038328FFCC1655D408104C58F31D149404772F90FE9615D408104C58F31D14940
27270	50952	117.52985	117.58996500000001	51.668925000000002	51.634324999999997	Советская	0103000020E610000001000000050000004772F90FE9615D408104C58F31D149404772F90FE9615D40083D9B559FD5494038328FFCC1655D40083D9B559FD5494038328FFCC1655D408104C58F31D149404772F90FE9615D408104C58F31D14940
73926	50952	117.52985	117.58996500000001	51.668925000000002	51.634324999999997	Набережная	0103000020E610000001000000050000004772F90FE9615D408104C58F31D149404772F90FE9615D40083D9B559FD5494038328FFCC1655D40083D9B559FD5494038328FFCC1655D408104C58F31D149404772F90FE9615D408104C58F31D14940
73715	50952	117.52985	117.58996500000001	51.668925000000002	51.634324999999997	Лазо	0103000020E610000001000000050000004772F90FE9615D408104C58F31D149404772F90FE9615D40083D9B559FD5494038328FFCC1655D40083D9B559FD5494038328FFCC1655D408104C58F31D149404772F90FE9615D408104C58F31D14940
74035	60205	117.682419	117.695652	51.403440000000003	51.377355999999999	Первомайская улица	0103000020E61000000100000005000000D1CABDC0AC6B5D4085798F334DB04940D1CABDC0AC6B5D40FAF202ECA3B349406859F78F856C5D40FAF202ECA3B349406859F78F856C5D4085798F334DB04940D1CABDC0AC6B5D4085798F334DB04940
74049	60205	117.682419	117.695652	51.403440000000003	51.377355999999999	Нагорная улица	0103000020E61000000100000005000000D1CABDC0AC6B5D4085798F334DB04940D1CABDC0AC6B5D40FAF202ECA3B349406859F78F856C5D40FAF202ECA3B349406859F78F856C5D4085798F334DB04940D1CABDC0AC6B5D4085798F334DB04940
73913	50976	117.638357	117.654419	51.989578000000002	51.964751999999997	Школьная	0103000020E610000001000000050000000D8B51D7DA685D40136058FE7CFB49400D8B51D7DA685D40A96BED7DAAFE494063B83A00E2695D40A96BED7DAAFE494063B83A00E2695D40136058FE7CFB49400D8B51D7DA685D40136058FE7CFB4940
24182	50976	117.638357	117.654419	51.989578000000002	51.964751999999997	Центральная	0103000020E610000001000000050000000D8B51D7DA685D40136058FE7CFB49400D8B51D7DA685D40A96BED7DAAFE494063B83A00E2695D40A96BED7DAAFE494063B83A00E2695D40136058FE7CFB49400D8B51D7DA685D40136058FE7CFB4940
73877	51435	117.778746	117.807725	51.845638000000001	51.826971999999998	Чугуевского	0103000020E61000000100000005000000037976F9D6715D40965AEF37DAE94940037976F9D6715D409F20B1DD3DEC494058CA32C4B1735D409F20B1DD3DEC494058CA32C4B1735D40965AEF37DAE94940037976F9D6715D40965AEF37DAE94940
27025	51435	117.778746	117.807725	51.845638000000001	51.826971999999998	Атавина	0103000020E61000000100000005000000037976F9D6715D40965AEF37DAE94940037976F9D6715D409F20B1DD3DEC494058CA32C4B1735D409F20B1DD3DEC494058CA32C4B1735D40965AEF37DAE94940037976F9D6715D40965AEF37DAE94940
74053	60216	117.634539	117.65902699999999	51.899307999999998	51.853549000000001	Верхняя	0103000020E61000000100000005000000574277499C685D404A44F81741ED4940574277499C685D40FD8348861CF34940950B957F2D6A5D40FD8348861CF34940950B957F2D6A5D404A44F81741ED4940574277499C685D404A44F81741ED4940
74031	60202	117.28089900000001	118.656993	52.137796999999999	51.211795000000002	Нагорная	0103000020E61000000100000005000000AA9ECC3FFA515D40693A3B191C9B4940AA9ECC3FFA515D40533E0455A3114A40DC2C5E2C0CAA5D40533E0455A3114A40DC2C5E2C0CAA5D40693A3B191C9B4940AA9ECC3FFA515D40693A3B191C9B4940
27698	51726	117.394626	117.41632	51.664641000000003	51.652757000000001	Центральная	0103000020E61000000100000005000000AF09698D41595D40179E978A8DD34940AF09698D41595D40564ACFF412D54940ED2AA4FCA45A5D40564ACFF412D54940ED2AA4FCA45A5D40179E978A8DD34940AF09698D41595D40179E978A8DD34940
74039	51726	117.394626	117.41632	51.664641000000003	51.652757000000001	Трактовая	0103000020E61000000100000005000000AF09698D41595D40179E978A8DD34940AF09698D41595D40564ACFF412D54940ED2AA4FCA45A5D40564ACFF412D54940ED2AA4FCA45A5D40179E978A8DD34940AF09698D41595D40179E978A8DD34940
23598	50786	117.864912	117.914706	51.305970000000002	51.283306000000003	Трактовая	0103000020E61000000100000005000000C07ADCB75A775D405B61FA5E43A44940C07ADCB75A775D4050C763062AA749401EDD088B8A7A5D4050C763062AA749401EDD088B8A7A5D405B61FA5E43A44940C07ADCB75A775D405B61FA5E43A44940
24378	7983	112.744389	112.772507	51.848346999999997	51.835521	Школьная	0103000020E6100000010000000500000023A0C211A42F5C40840F255AF2EA494023A0C211A42F5C4071546EA296EC4940973B33C170315C4071546EA296EC4940973B33C170315C40840F255AF2EA494023A0C211A42F5C40840F255AF2EA4940
73856	7983	112.744389	112.772507	51.848346999999997	51.835521	Вокзальная	0103000020E6100000010000000500000023A0C211A42F5C40840F255AF2EA494023A0C211A42F5C4071546EA296EC4940973B33C170315C4071546EA296EC4940973B33C170315C40840F255AF2EA494023A0C211A42F5C40840F255AF2EA4940
67860	7308	113.571163	113.59345	52.319693000000001	52.297117	Центральная	0103000020E61000000100000005000000DB6B41EF8D645C40F60A0BEE07264A40DB6B41EF8D645C404CE141B3EB284A40EB73B515FB655C404CE141B3EB284A40EB73B515FB655C40F60A0BEE07264A40DB6B41EF8D645C40F60A0BEE07264A40
27970	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	проспект Фадеева	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67399	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	мкр. Октябрьский	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73581	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	микрорайон Северный	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27242	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ямаровская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67448	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Юности	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28327	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Школьная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73545	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Чайковского	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27102	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Текстильщиков	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27524	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Строителей	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73722	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Сретенская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73719	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Рахова	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73708	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ранетная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73564	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Полины Осипенко	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27724	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Подгорбунского	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
24085	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Новобульварная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28133	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Недорезова	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73700	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Назара Широких	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73550	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Малая	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73690	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Магистральная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73694	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ленинградская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73565	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Лазо	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28128	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Краснознаменная	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28407	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Космонавтов	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28028	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ключевая	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
24631	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Карла Маркса	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73570	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Каларская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27585	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Кайдаловская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28184	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Июньская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27066	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Зыкова	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
71712	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Донская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73706	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Гайдара	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67758	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Весенняя	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
71630	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Ватутина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28458	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Богомягкова	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
24637	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Баргузинская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67219	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Балябина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73745	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Балейская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27098	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Бабушкина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
24044	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Анохина	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73703	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Амурская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27285	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Автозаводская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73585	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	9 Января	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73693	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	6 микрорайон	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
67451	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	5 микрорайон	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
27531	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	40 лет октября	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
28588	50808	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	 Богомягкова	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
74001	8621	113.24263999999999	113.251102	51.961194999999996	51.952475999999997	Центральная	0103000020E61000000100000005000000E42CEC69874F5C40C91CCBBBEAF94940E42CEC69874F5C40130A117008FB4940747D1F0E12505C40130A117008FB4940747D1F0E12505C40C91CCBBBEAF94940E42CEC69874F5C40C91CCBBBEAF94940
73663	60055	113.440997	113.463751	52.165509	52.150402999999997	Центральная	0103000020E6100000010000000500000095287B4B395C5C40321CCF6740134A4095287B4B395C5C40CA181F662F154A40309FAC18AE5D5C40CA181F662F154A40309FAC18AE5D5C40321CCF6740134A4095287B4B395C5C40321CCF6740134A40
24510	7611	112.944148	112.962958	52.219572999999997	52.210633999999999	Центральная	0103000020E610000001000000050000005DA5BBEB6C3C5C407CB60E0EF61A4A405DA5BBEB6C3C5C40D40AD3F71A1C4A40FB5A971AA13D5C40D40AD3F71A1C4A40FB5A971AA13D5C407CB60E0EF61A4A405DA5BBEB6C3C5C407CB60E0EF61A4A40
28307	8890	113.962559	113.978261	51.999974999999999	51.987037000000001	Центральная	0103000020E610000001000000050000001C5E10919A7D5C409278793A57FE49401C5E10919A7D5C40A7E8482EFFFF4940F27C06D49B7E5C40A7E8482EFFFF4940F27C06D49B7E5C409278793A57FE49401C5E10919A7D5C409278793A57FE4940
73998	9504	113.436954	113.457014	51.356499999999997	51.346859000000002	Комсомольская	0103000020E61000000100000005000000CFF6E80DF75B5C4061A92EE065AC4940CFF6E80DF75B5C401283C0CAA1AD49401BF4A5B73F5D5C401283C0CAA1AD49401BF4A5B73F5D5C4061A92EE065AC4940CFF6E80DF75B5C4061A92EE065AC4940
73743	7871	112.492789	112.54422700000001	51.837513999999999	51.807747999999997	Центральная	0103000020E6100000010000000500000007B5DFDA891F5C4067B4554964E7494007B5DFDA891F5C4098F8A3A833EB49406AA67B9DD4225C4098F8A3A833EB49406AA67B9DD4225C4067B4554964E7494007B5DFDA891F5C4067B4554964E74940
28381	795	113.48650499999999	113.52632800000001	52.149889000000002	52.129184000000002	Садовая 	0103000020E61000000100000005000000CA15DEE5225F5C404F95EF1989104A40CA15DEE5225F5C40DC8310902F134A4006BEA25BAF615C40DC8310902F134A4006BEA25BAF615C404F95EF1989104A40CA15DEE5225F5C404F95EF1989104A40
73616	795	113.48650499999999	113.52632800000001	52.149889000000002	52.129184000000002	Садовая	0103000020E61000000100000005000000CA15DEE5225F5C404F95EF1989104A40CA15DEE5225F5C40DC8310902F134A4006BEA25BAF615C40DC8310902F134A4006BEA25BAF615C404F95EF1989104A40CA15DEE5225F5C404F95EF1989104A40
73802	8665	113.22173600000001	113.243628	51.900596999999998	51.887542000000003	Советская	0103000020E61000000100000005000000231631EC304E5C40C9E9EBF99AF14940231631EC304E5C4017F032C346F34940F418E599974F5C4017F032C346F34940F418E599974F5C40C9E9EBF99AF14940231631EC304E5C40C9E9EBF99AF14940
73975	7196	113.674244	113.687207	52.427323000000001	52.414076000000001	Центральная	0103000020E610000001000000050000008D614ED0266B5C407D073F7100354A408D614ED0266B5C4010EA2285B2364A4044A51133FB6B5C4010EA2285B2364A4044A51133FB6B5C407D073F7100354A408D614ED0266B5C407D073F7100354A40
27676	9555	113.398884	113.42758499999999	51.314196000000003	51.299781000000003	Центральная	0103000020E6100000010000000500000073B9C15087595C40297B4B395FA6494073B9C15087595C405B44149337A84940A6D0798D5D5B5C405B44149337A84940A6D0798D5D5B5C40297B4B395FA6494073B9C15087595C40297B4B395FA64940
73769	8833	114.075351	114.105948	51.998367000000002	51.973768999999997	Шоссейная	0103000020E61000000100000005000000232E008DD2845C40E76D6C76A4FC4940232E008DD2845C40EC33677DCAFF4940E7C41EDAC7865C40EC33677DCAFF4940E7C41EDAC7865C40E76D6C76A4FC4940232E008DD2845C40E76D6C76A4FC4940
73628	60051	113.73924599999999	113.829401	51.826371000000002	51.743729999999999	Рабочая	0103000020E61000000100000005000000B96C74CE4F6F5C40EC866D8B32DF4940B96C74CE4F6F5C4071AE6186C6E949404391EEE714755C4071AE6186C6E949404391EEE714755C40EC866D8B32DF4940B96C74CE4F6F5C40EC866D8B32DF4940
27013	51414	113.73924599999999	113.829401	51.826371000000002	51.743729999999999	Фабричная	0103000020E61000000100000005000000B96C74CE4F6F5C40EC866D8B32DF4940B96C74CE4F6F5C4071AE6186C6E949404391EEE714755C4071AE6186C6E949404391EEE714755C40EC866D8B32DF4940B96C74CE4F6F5C40EC866D8B32DF4940
27002	51414	113.73924599999999	113.829401	51.826371000000002	51.743729999999999	Ленинградская	0103000020E61000000100000005000000B96C74CE4F6F5C40EC866D8B32DF4940B96C74CE4F6F5C4071AE6186C6E949404391EEE714755C4071AE6186C6E949404391EEE714755C40EC866D8B32DF4940B96C74CE4F6F5C40EC866D8B32DF4940
33999	51414	113.73924599999999	113.829401	51.826371000000002	51.743729999999999	Заводская	0103000020E61000000100000005000000B96C74CE4F6F5C40EC866D8B32DF4940B96C74CE4F6F5C4071AE6186C6E949404391EEE714755C4071AE6186C6E949404391EEE714755C40EC866D8B32DF4940B96C74CE4F6F5C40EC866D8B32DF4940
67634	51414	113.73924599999999	113.829401	51.826371000000002	51.743729999999999	Дорожная	0103000020E61000000100000005000000B96C74CE4F6F5C40EC866D8B32DF4940B96C74CE4F6F5C4071AE6186C6E949404391EEE714755C4071AE6186C6E949404391EEE714755C40EC866D8B32DF4940B96C74CE4F6F5C40EC866D8B32DF4940
73573	8241	113.041696	113.072957	51.806722999999998	51.782069	микрорайон Забайкальская птицефабрика	0103000020E61000000100000005000000F017B325AB425C40931B45D61AE44940F017B325AB425C402BF702B342E74940EA40D653AB445C402BF702B342E74940EA40D653AB445C40931B45D61AE44940F017B325AB425C40931B45D61AE44940
34005	51867	113.90084400000001	113.974569	51.765552	51.740819000000002	Советская	0103000020E6100000010000000500000010B3976DA7795C40B2A03028D3DE494010B3976DA7795C4096B1A19BFDE1494082ACA7565F7E5C4096B1A19BFDE1494082ACA7565F7E5C40B2A03028D3DE494010B3976DA7795C40B2A03028D3DE4940
28439	51867	113.90084400000001	113.974569	51.765552	51.740819000000002	Бутина	0103000020E6100000010000000500000010B3976DA7795C40B2A03028D3DE494010B3976DA7795C4096B1A19BFDE1494082ACA7565F7E5C4096B1A19BFDE1494082ACA7565F7E5C40B2A03028D3DE494010B3976DA7795C40B2A03028D3DE4940
23414	50697	113.05073299999999	113.088902	51.743284000000003	51.715693999999999	Трактовая	0103000020E61000000100000005000000FDF49F353F435C40C2F869DC9BDB4940FDF49F353F435C40EED11BEE23DF494023A30392B0455C40EED11BEE23DF494023A30392B0455C40C2F869DC9BDB4940FDF49F353F435C40C2F869DC9BDB4940
73723	4189	112.99436300000001	113.024394	51.778976999999998	51.762245999999998	Таежная	0103000020E610000001000000050000008F56B5A4A33F5C40DFC0E44691E149408F56B5A4A33F5C4008ABB184B5E34940FE0DDAAB8F415C4008ABB184B5E34940FE0DDAAB8F415C40DFC0E44691E149408F56B5A4A33F5C40DFC0E44691E14940
27321	47729	113.06851	113.087609	51.135323	51.128754999999998	Первомайская	0103000020E61000000100000005000000BC5CC47762445C402619390B7B904940BC5CC47762445C40C4B29943529149407575C7629B455C40C4B29943529149407575C7629B455C402619390B7B904940BC5CC47762445C402619390B7B904940
73996	7781	112.575048	112.586699	51.989100999999998	51.974938999999999	Центральная	0103000020E6100000010000000500000055682096CD245C40274C18CDCAFC494055682096CD245C406FB88FDC9AFE49402366F6798C255C406FB88FDC9AFE49402366F6798C255C40274C18CDCAFC494055682096CD245C40274C18CDCAFC4940
73801	8340	113.08906399999999	113.113435	51.864244999999997	51.837674999999997	Центральная	0103000020E610000001000000050000000FD07D39B3455C40A1D634EF38EB49400FD07D39B3455C40A25D85949FEE494031CEDF8442475C40A25D85949FEE494031CEDF8442475C40A1D634EF38EB49400FD07D39B3455C40A1D634EF38EB4940
28306	8799	114.161598	114.19020999999999	52.074412000000002	52.053820000000002	Набережная	0103000020E610000001000000050000005646239F578A5C4074EFE192E3064A405646239F578A5C400937195586094A40D15790662C8C5C400937195586094A40D15790662C8C5C4074EFE192E3064A405646239F578A5C4074EFE192E3064A40
73845	7587	112.97455600000001	113.021762	52.275835999999998	52.249599000000003	Центральная	0103000020E61000000100000005000000B80721205F3E5C40A20E2BDCF21F4A40B80721205F3E5C409C8713984E234A40EA92718C64415C409C8713984E234A40EA92718C64415C40A20E2BDCF21F4A40B80721205F3E5C40A20E2BDCF21F4A40
73689	60060	113.410167	113.42627299999999	52.014023000000002	52.006357000000001	Школьная	0103000020E6100000010000000500000080B9162D405A5C40E38C614ED0004A4080B9162D405A5C4027327381CB014A40BD8A8C0E485B5C4027327381CB014A40BD8A8C0E485B5C40E38C614ED0004A4080B9162D405A5C40E38C614ED0004A40
73921	8284	112.99861199999999	113.02393600000001	51.810644000000003	51.797516999999999	Школьная	0103000020E6100000010000000500000029594E42E93F5C4084807C0915E6494029594E42E93F5C406D59BE2EC3E749409D4CDC2A88415C406D59BE2EC3E749409D4CDC2A88415C4084807C0915E6494029594E42E93F5C4084807C0915E64940
24526	8720	113.331852	113.348551	51.961928	51.953758000000001	Центральная	0103000020E610000001000000050000002EC72B103D555C403126FDBD14FA49402EC72B103D555C40A88DEA7420FB49403D7FDAA84E565C40A88DEA7420FB49403D7FDAA84E565C403126FDBD14FA49402EC72B103D555C403126FDBD14FA4940
73733	9358	113.596711	113.616995	51.667651999999997	51.651159	Пионерская	0103000020E61000000100000005000000768A558330665C407FBF982D59D34940768A558330665C40F38DE89E75D54940EAB298D87C675C40F38DE89E75D54940EAB298D87C675C407FBF982D59D34940768A558330665C407FBF982D59D34940
73945	8385	112.981194	113.00985900000001	51.974694999999997	51.952964000000001	Партизанская	0103000020E610000001000000050000000342EBE1CB3E5C40F7216FB9FAF949400342EBE1CB3E5C40904946CEC2FC494090A4A487A1405C40904946CEC2FC494090A4A487A1405C40F7216FB9FAF949400342EBE1CB3E5C40F7216FB9FAF94940
73712	59034	113.13146399999999	113.179919	51.916888	51.879269999999998	Центральная	0103000020E610000001000000050000007C26FBE769485C404D2D5BEB8BF049407C26FBE769485C40240C03965CF54940753BFBCA834B5C40240C03965CF54940753BFBCA834B5C404D2D5BEB8BF049407C26FBE769485C404D2D5BEB8BF04940
67330	59034	113.13146399999999	113.179919	51.916888	51.879269999999998	Геологическая	0103000020E610000001000000050000007C26FBE769485C404D2D5BEB8BF049407C26FBE769485C40240C03965CF54940753BFBCA834B5C40240C03965CF54940753BFBCA834B5C404D2D5BEB8BF049407C26FBE769485C404D2D5BEB8BF04940
27671	9452	113.424504	113.458595	51.587448999999999	51.576608999999998	Зеленая	0103000020E610000001000000050000005B41D3122B5B5C4025CADE52CEC949405B41D3122B5B5C40B188618731CB4940FCC6D79E595D5C40B188618731CB4940FCC6D79E595D5C4025CADE52CEC949405B41D3122B5B5C4025CADE52CEC94940
28150	51816	113.491958	113.52401	52.245238000000001	52.217945	Центральная	0103000020E610000001000000050000005B40683D7C5F5C40D2A92B9FE51B4A405B40683D7C5F5C4044DE72F5631F4A40BA313D6189615C4044DE72F5631F4A40BA313D6189615C40D2A92B9FE51B4A405B40683D7C5F5C40D2A92B9FE51B4A40
74020	7159	113.764956	113.78965100000001	52.430183999999997	52.413773999999997	Школьная	0103000020E6100000010000000500000041B8020AF5705C40B1F7E28BF6344A4041B8020AF5705C4098A1F14410374A403D1059A489725C4098A1F14410374A403D1059A489725C40B1F7E28BF6344A4041B8020AF5705C40B1F7E28BF6344A40
67867	7733	112.662571	112.694102	52.130488999999997	52.108263999999998	Бурлова	0103000020E61000000100000005000000CB113290672A5C40C5AA4198DB0D4A40CB113290672A5C406EBE11DDB3104A40A585CB2A6C2C5C406EBE11DDB3104A40A585CB2A6C2C5C40C5AA4198DB0D4A40CB113290672A5C40C5AA4198DB0D4A40
73588	60044	113.608694	113.665306	51.951982000000001	51.906292999999998	Матюгина	0103000020E610000001000000050000005FD1ADD7F4665C40FFCBB56801F449405FD1ADD7F4665C40BA30D28BDAF9494049F59D5F946A5C40BA30D28BDAF9494049F59D5F946A5C40FFCBB56801F449405FD1ADD7F4665C40FFCBB56801F44940
27796	40314	113.608694	113.665306	51.951982000000001	51.906292999999998	Рабочая	0103000020E610000001000000050000005FD1ADD7F4665C40FFCBB56801F449405FD1ADD7F4665C40BA30D28BDAF9494049F59D5F946A5C40BA30D28BDAF9494049F59D5F946A5C40FFCBB56801F449405FD1ADD7F4665C40FFCBB56801F44940
9797	40314	113.608694	113.665306	51.951982000000001	51.906292999999998	Заводская	0103000020E610000001000000050000005FD1ADD7F4665C40FFCBB56801F449405FD1ADD7F4665C40BA30D28BDAF9494049F59D5F946A5C40BA30D28BDAF9494049F59D5F946A5C40FFCBB56801F449405FD1ADD7F4665C40FFCBB56801F44940
73919	7699	112.826199	112.847615	52.166972999999999	52.158703000000003	Центральная	0103000020E610000001000000050000003A3FC571E0345C407863416150144A403A3FC571E0345C4052280B5F5F154A405726FC523F365C4052280B5F5F154A405726FC523F365C407863416150144A403A3FC571E0345C407863416150144A40
28257	7254	113.630487	113.642426	52.375228999999997	52.365105999999997	Весенняя	0103000020E61000000100000005000000676325E659685C4064C91CCBBB2E4A40676325E659685C4061C1FD8007304A406806F1811D695C4061C1FD8007304A406806F1811D695C4064C91CCBBB2E4A40676325E659685C4064C91CCBBB2E4A40
67714	59093	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	Молодежная	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
73683	51513	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	Центральная	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
27167	51513	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	Лазо	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
73901	51513	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	Железнодорожная	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
27418	51648	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	Первомайская	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
28585	51648	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	Партизанская	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
71530	51648	116.99592699999999	117.04583700000001	52.548437999999997	52.496338999999999	Журавлева	0103000020E61000000100000005000000048D9944BD3F5D405B5D4E09883F4A40048D9944BD3F5D401BF1643733464A4098FC4FFEEE425D401BF1643733464A4098FC4FFEEE425D405B5D4E09883F4A40048D9944BD3F5D405B5D4E09883F4A40
71573	59482	116.97152	116.99457	52.584806999999998	52.560533	Погодаева	0103000020E610000001000000050000003CDA38622D3E5D4015AA9B8BBF474A403CDA38622D3E5D4066BCADF4DA4A4A404BE5ED08A73F5D4066BCADF4DA4A4A404BE5ED08A73F5D4015AA9B8BBF474A403CDA38622D3E5D4015AA9B8BBF474A40
73848	51731	118.09264400000001	118.12521700000001	53.176653000000002	53.161354000000003	Папанина	0103000020E61000000100000005000000EC8A19E1ED855D40168A743FA7944A40EC8A19E1ED855D40C2DEC4909C964A40CFF9298E03885D40C2DEC4909C964A40CFF9298E03885D40168A743FA7944A40EC8A19E1ED855D40168A743FA7944A40
73767	60088	117.00381400000001	117.033333	52.356186000000001	52.339027000000002	Транспортная	0103000020E610000001000000050000001651137D3E405D4002BB9A3C652B4A401651137D3E405D4083A5BA80972D4A402A38BC2022425D4083A5BA80972D4A402A38BC2022425D4002BB9A3C652B4A401651137D3E405D4002BB9A3C652B4A40
23464	50725	116.64819799999999	116.687535	52.463562000000003	52.444859000000001	 Ленина	0103000020E6100000010000000500000049D576137C295D40672AC423F1384A4049D576137C295D408DD5E6FF553B4A40BEF6CC92002C5D408DD5E6FF553B4A40BEF6CC92002C5D40672AC423F1384A4049D576137C295D40672AC423F1384A40
73939	60153	116.509426	116.525542	52.619259	52.594856999999998	Партизанская	0103000020E61000000100000005000000DB6E826F9A205D40F9653046244C4A40DB6E826F9A205D40786000E1434F4A402AABE97AA2215D40786000E1434F4A402AABE97AA2215D40F9653046244C4A40DB6E826F9A205D40F9653046244C4A40
73925	60153	116.509426	116.525542	52.619259	52.594856999999998	Журавлёво	0103000020E61000000100000005000000DB6E826F9A205D40F9653046244C4A40DB6E826F9A205D40786000E1434F4A402AABE97AA2215D40786000E1434F4A402AABE97AA2215D40F9653046244C4A40DB6E826F9A205D40F9653046244C4A40
74009	60192	116.752025	116.779127	52.524478999999999	52.501306	Ленина	0103000020E610000001000000050000009031772D21305D40F0A485CB2A404A409031772D21305D402A38BC2022434A408F1B7E37DD315D402A38BC2022434A408F1B7E37DD315D40F0A485CB2A404A409031772D21305D40F0A485CB2A404A40
73821	60114	116.914108	116.932712	52.668692999999998	52.649898	Молодежная	0103000020E61000000100000005000000C440D7BE803A5D402FDE8FDB2F534A40C440D7BE803A5D40350873BB97554A408D25AC8DB13B5D40350873BB97554A408D25AC8DB13B5D402FDE8FDB2F534A40C440D7BE803A5D402FDE8FDB2F534A40
27828	51750	117.239721	117.258765	52.382309999999997	52.367030999999997	Школьная	0103000020E6100000010000000500000086CABF96574F5D4020CF2EDFFA2E4A4086CABF96574F5D408577B988EF304A405D16139B8F505D408577B988EF304A405D16139B8F505D4020CF2EDFFA2E4A4086CABF96574F5D4020CF2EDFFA2E4A40
28513	51887	116.853247	116.882712	52.360436999999997	52.340451999999999	Набережная 	0103000020E610000001000000050000003F1A4E999B365D40CCED5EEE932B4A403F1A4E999B365D4059A2B3CC222E4A405AF2785A7E385D4059A2B3CC222E4A405AF2785A7E385D40CCED5EEE932B4A403F1A4E999B365D40CCED5EEE932B4A40
74014	51887	116.853247	116.882712	52.360436999999997	52.340451999999999	Базарная	0103000020E610000001000000050000003F1A4E999B365D40CCED5EEE932B4A403F1A4E999B365D4059A2B3CC222E4A405AF2785A7E385D4059A2B3CC222E4A405AF2785A7E385D40CCED5EEE932B4A403F1A4E999B365D40CCED5EEE932B4A40
74012	60193	117.015232	117.032848	52.451813999999999	52.437156999999999	Центральная	0103000020E610000001000000050000009276A38FF9405D40D61BB5C2F4374A409276A38FF9405D40FEEF880AD5394A404C6F7F2E1A425D40FEEF880AD5394A404C6F7F2E1A425D40D61BB5C2F4374A409276A38FF9405D40D61BB5C2F4374A40
23706	50810	117.26389399999999	117.28395399999999	52.755138000000002	52.734192999999998	Железнодорожная	0103000020E6100000010000000500000014E7A8A3E3505D40DFF94509FA5D4A4014E7A8A3E3505D40C2FBAA5CA8604A4060E4654D2C525D40C2FBAA5CA8604A4060E4654D2C525D40DFF94509FA5D4A4014E7A8A3E3505D40DFF94509FA5D4A40
73972	60177	116.884158	116.971924	53.008625000000002	52.948830000000001	Вокзальная	0103000020E61000000100000005000000CB9F6F0B96385D405ABBED4273794A40CB9F6F0B96385D40C976BE9F1A814A40A48CB800343E5D40C976BE9F1A814A40A48CB800343E5D405ABBED4273794A40CB9F6F0B96385D405ABBED4273794A40
27667	50921	116.884158	116.971924	53.008625000000002	52.948830000000001	Центральная	0103000020E61000000100000005000000CB9F6F0B96385D405ABBED4273794A40CB9F6F0B96385D40C976BE9F1A814A40A48CB800343E5D40C976BE9F1A814A40A48CB800343E5D405ABBED4273794A40CB9F6F0B96385D405ABBED4273794A40
74023	50921	116.884158	116.971924	53.008625000000002	52.948830000000001	Фабричный переулок	0103000020E61000000100000005000000CB9F6F0B96385D405ABBED4273794A40CB9F6F0B96385D40C976BE9F1A814A40A48CB800343E5D40C976BE9F1A814A40A48CB800343E5D405ABBED4273794A40CB9F6F0B96385D405ABBED4273794A40
73713	50921	116.884158	116.971924	53.008625000000002	52.948830000000001	Клубный проспект	0103000020E61000000100000005000000CB9F6F0B96385D405ABBED4273794A40CB9F6F0B96385D40C976BE9F1A814A40A48CB800343E5D40C976BE9F1A814A40A48CB800343E5D405ABBED4273794A40CB9F6F0B96385D405ABBED4273794A40
73717	60067	116.741353	116.761044	52.251539999999999	52.241433000000001	Советская	0103000020E61000000100000005000000A872DA53722F5D406C96CB46E71E4A40A872DA53722F5D4063D1747632204A404AB4E4F1B4305D4063D1747632204A404AB4E4F1B4305D406C96CB46E71E4A40A872DA53722F5D406C96CB46E71E4A40
27366	51624	116.790401	116.80652600000001	52.412785	52.401853000000003	Набережная	0103000020E61000000100000005000000726E13EE95325D4056664AEB6F334A40726E13EE95325D40C2A38D23D6344A40EB573A1F9E335D40C2A38D23D6344A40EB573A1F9E335D4056664AEB6F334A40726E13EE95325D4056664AEB6F334A40
27173	51518	117.042118	117.074682	52.559930999999999	52.545009999999998	Кирова	0103000020E61000000100000005000000AB24B20FB2425D4019FF3EE3C2454A40AB24B20FB2425D401F82AAD1AB474A4064E60297C7445D401F82AAD1AB474A4064E60297C7445D4019FF3EE3C2454A40AB24B20FB2425D4019FF3EE3C2454A40
73850	60081	117.47456699999999	117.531583	53.088827000000002	53.059466999999998	Октябрьская	0103000020E61000000100000005000000B130444E5F5E5D407A185A9D9C874A40B130444E5F5E5D403B00E2AE5E8B4A400307B47405625D403B00E2AE5E8B4A400307B47405625D407A185A9D9C874A40B130444E5F5E5D407A185A9D9C874A40
73755	60081	117.47456699999999	117.531583	53.088827000000002	53.059466999999998	Западная	0103000020E61000000100000005000000B130444E5F5E5D407A185A9D9C874A40B130444E5F5E5D403B00E2AE5E8B4A400307B47405625D403B00E2AE5E8B4A400307B47405625D407A185A9D9C874A40B130444E5F5E5D407A185A9D9C874A40
73711	60063	110.908987	110.937698	51.445627999999999	51.418204000000003	Центральная	0103000020E610000001000000050000004E5FCFD72CBA5B4038876BB587B549404E5FCFD72CBA5B4048179B560AB9494093E1783E03BC5B4048179B560AB9494093E1783E03BC5B4038876BB587B549404E5FCFD72CBA5B4038876BB587B54940
73556	50925	110.406649	110.499257	51.378261999999999	51.336348999999998	Новая	0103000020E61000000100000005000000DFFC8689069A5B406A85E97B0DAB4940DFFC8689069A5B40E7A8A3E36AB0494024D3A1D3F39F5B40E7A8A3E36AB0494024D3A1D3F39F5B406A85E97B0DAB4940DFFC8689069A5B406A85E97B0DAB4940
67556	50925	110.406649	110.499257	51.378261999999999	51.336348999999998	Кирова	0103000020E61000000100000005000000DFFC8689069A5B406A85E97B0DAB4940DFFC8689069A5B40E7A8A3E36AB0494024D3A1D3F39F5B40E7A8A3E36AB0494024D3A1D3F39F5B406A85E97B0DAB4940DFFC8689069A5B406A85E97B0DAB4940
24069	50925	110.406649	110.499257	51.378261999999999	51.336348999999998	Калинина	0103000020E61000000100000005000000DFFC8689069A5B406A85E97B0DAB4940DFFC8689069A5B40E7A8A3E36AB0494024D3A1D3F39F5B40E7A8A3E36AB0494024D3A1D3F39F5B406A85E97B0DAB4940DFFC8689069A5B406A85E97B0DAB4940
27283	50925	110.406649	110.499257	51.378261999999999	51.336348999999998	 Ленина	0103000020E61000000100000005000000DFFC8689069A5B406A85E97B0DAB4940DFFC8689069A5B40E7A8A3E36AB0494024D3A1D3F39F5B40E7A8A3E36AB0494024D3A1D3F39F5B406A85E97B0DAB4940DFFC8689069A5B406A85E97B0DAB4940
27953	50925	110.406649	110.499257	51.378261999999999	51.336348999999998	 Карла Маркса	0103000020E61000000100000005000000DFFC8689069A5B406A85E97B0DAB4940DFFC8689069A5B40E7A8A3E36AB0494024D3A1D3F39F5B40E7A8A3E36AB0494024D3A1D3F39F5B406A85E97B0DAB4940DFFC8689069A5B406A85E97B0DAB4940
27212	51545	111.15463200000001	111.196951	51.565837999999999	51.542419000000002	Шоссеная	0103000020E6100000010000000500000091BA9D7DE5C95B4051DD5CFC6DC5494091BA9D7DE5C95B40C26A2C616DC8494087FA5DD89ACC5B40C26A2C616DC8494087FA5DD89ACC5B4051DD5CFC6DC5494091BA9D7DE5C95B4051DD5CFC6DC54940
73764	51545	111.15463200000001	111.196951	51.565837999999999	51.542419000000002	Вокзальная	0103000020E6100000010000000500000091BA9D7DE5C95B4051DD5CFC6DC5494091BA9D7DE5C95B40C26A2C616DC8494087FA5DD89ACC5B40C26A2C616DC8494087FA5DD89ACC5B4051DD5CFC6DC5494091BA9D7DE5C95B4051DD5CFC6DC54940
28566	51009	111.94682	111.997485	51.755389000000001	51.718935999999999	Советская	0103000020E61000000100000005000000B8CCE9B298FC5B4062F5471806DC4940B8CCE9B298FC5B400B613596B0E04940095053CBD6FF5B400B613596B0E04940095053CBD6FF5B4062F5471806DC4940B8CCE9B298FC5B4062F5471806DC4940
73795	51009	111.94682	111.997485	51.755389000000001	51.718935999999999	Комсомольская	0103000020E61000000100000005000000B8CCE9B298FC5B4062F5471806DC4940B8CCE9B298FC5B400B613596B0E04940095053CBD6FF5B400B613596B0E04940095053CBD6FF5B4062F5471806DC4940B8CCE9B298FC5B4062F5471806DC4940
24351	51009	111.94682	111.997485	51.755389000000001	51.718935999999999	 Деповская	0103000020E61000000100000005000000B8CCE9B298FC5B4062F5471806DC4940B8CCE9B298FC5B400B613596B0E04940095053CBD6FF5B400B613596B0E04940095053CBD6FF5B4062F5471806DC4940B8CCE9B298FC5B4062F5471806DC4940
67320	59031	110.63071600000001	110.67338599999999	51.372132999999998	51.347431999999998	Хлуднева	0103000020E610000001000000050000001844A4A65DA85B40BCCADAA678AC49401844A4A65DA85B409561DC0DA2AF494064E597C118AB5B409561DC0DA2AF494064E597C118AB5B40BCCADAA678AC49401844A4A65DA85B40BCCADAA678AC4940
73837	51543	109.730344	109.746801	51.366021000000003	51.353963	Школьная	0103000020E610000001000000050000001CB5C2F4BD6E5B403D7FDAA84EAD49401CB5C2F4BD6E5B401A53B0C6D9AE4940B0E76B96CB6F5B401A53B0C6D9AE4940B0E76B96CB6F5B403D7FDAA84EAD49401CB5C2F4BD6E5B403D7FDAA84EAD4940
73648	60053	110.158373	110.17973499999999	51.468671000000001	51.446660999999999	Таёжная	0103000020E6100000010000000500000071E481C8228A5B4007B309302CB9494071E481C8228A5B40B4CA4C69FDBB494094BC3AC7808B5B40B4CA4C69FDBB494094BC3AC7808B5B4007B309302CB9494071E481C8228A5B4007B309302CB94940
73750	6576	110.64961700000001	110.670772	51.405884	51.392105999999998	Первомайская	0103000020E610000001000000050000003E7B2E5393A95B405E48878730B249403E7B2E5393A95B401EFCC401F4B34940A4C4AEEDEDAA5B401EFCC401F4B34940A4C4AEEDEDAA5B405E48878730B249403E7B2E5393A95B405E48878730B24940
67155	58981	109.827416	109.909019	51.402619999999999	51.375056999999998	Пионерская	0103000020E61000000100000005000000FA0B3D62F4745B40649126DE01B04940FA0B3D62F4745B40965B5A0D89B34940541C075E2D7A5B40965B5A0D89B34940541C075E2D7A5B40649126DE01B04940FA0B3D62F4745B40649126DE01B04940
67855	58981	109.827416	109.909019	51.402619999999999	51.375056999999998	Лесная	0103000020E61000000100000005000000FA0B3D62F4745B40649126DE01B04940FA0B3D62F4745B40965B5A0D89B34940541C075E2D7A5B40965B5A0D89B34940541C075E2D7A5B40649126DE01B04940FA0B3D62F4745B40649126DE01B04940
73984	5408	111.92465900000001	111.94462799999999	51.041420000000002	51.021515000000001	Школьная	0103000020E61000000100000005000000EF3CF19C2DFB5B40CDAFE600C1824940EF3CF19C2DFB5B403EB324404D854940B2B8FFC874FC5B403EB324404D854940B2B8FFC874FC5B40CDAFE600C1824940EF3CF19C2DFB5B40CDAFE600C1824940
24263	48451	112.704172	112.735298	51.465097	51.454003	Чехова	0103000020E6100000010000000500000092B06F27112D5C4098A432C51CBA494092B06F27112D5C40DE3B6A4C88BB49401CB4571F0F2F5C40DE3B6A4C88BB49401CB4571F0F2F5C4098A432C51CBA494092B06F27112D5C4098A432C51CBA4940
73738	21534	112.55022700000001	112.587247	51.432957000000002	51.417754000000002	Большая	0103000020E6100000010000000500000014984EEB36235C40F8E28BF678B5494014984EEB36235C4082C98D226BB7494025EB707495255C4082C98D226BB7494025EB707495255C40F8E28BF678B5494014984EEB36235C40F8E28BF678B54940
34034	3267	112.46444700000001	112.505608	51.383563000000002	51.332099999999997	Лазо	0103000020E610000001000000050000006CEEE87FB91D5C403480B74082AA49406CEEE87FB91D5C40537AA69718B149402426A8E15B205C40537AA69718B149402426A8E15B205C403480B74082AA49406CEEE87FB91D5C403480B74082AA4940
67423	3267	112.46444700000001	112.505608	51.383563000000002	51.332099999999997	Кооперативная	0103000020E610000001000000050000006CEEE87FB91D5C403480B74082AA49406CEEE87FB91D5C40537AA69718B149402426A8E15B205C40537AA69718B149402426A8E15B205C403480B74082AA49406CEEE87FB91D5C403480B74082AA4940
73639	3267	112.46444700000001	112.505608	51.383563000000002	51.332099999999997	Дорожная	0103000020E610000001000000050000006CEEE87FB91D5C403480B74082AA49406CEEE87FB91D5C40537AA69718B149402426A8E15B205C40537AA69718B149402426A8E15B205C403480B74082AA49406CEEE87FB91D5C403480B74082AA4940
73794	45427	112.91534799999999	112.946214	51.614553999999998	51.586308000000002	Кирова	0103000020E61000000100000005000000601DC70F953A5C400CB1FA230CCB4940601DC70F953A5C4020D099B4A9CE49401C412AC58E3C5C4020D099B4A9CE49401C412AC58E3C5C400CB1FA230CCB4940601DC70F953A5C400CB1FA230CCB4940
73752	5249	111.524666	111.58344200000001	50.993279000000001	50.965854999999998	Партизанская	0103000020E61000000100000005000000AED4B32094E15B40CBD6FA22A17B4940AED4B32094E15B40DC662AC4237F494039471D1D57E55B40DC662AC4237F494039471D1D57E55B40CBD6FA22A17B4940AED4B32094E15B40CBD6FA22A17B4940
27286	5181	111.407364	111.431421	50.981202000000003	50.973246000000003	Центральная	0103000020E610000001000000050000005664744012DA5B403E7B2E53937C49405664744012DA5B408962F206987D4940B073D3669CDB5B408962F206987D4940B073D3669CDB5B403E7B2E53937C49405664744012DA5B403E7B2E53937C4940
67145	47814	111.744861	111.79872400000001	51.071725000000001	51.042206999999998	Октябрьская	0103000020E6100000010000000500000037C478CDABEF5B40C554FA096785494037C478CDABEF5B401EA7E8482E894940F1A1444B1EF35B401EA7E8482E894940F1A1444B1EF35B40C554FA096785494037C478CDABEF5B40C554FA0967854940
27254	51571	111.4892	111.52819599999999	50.849221999999997	50.828454999999998	Ленина	0103000020E61000000100000005000000014D840D4FDF5B40959A3DD00A6A4940014D840D4FDF5B409885764EB36C4940317898F6CDE15B409885764EB36C4940317898F6CDE15B40959A3DD00A6A4940014D840D4FDF5B40959A3DD00A6A4940
73934	47888	113.052089	113.06417999999999	51.646549	51.633927999999997	Совхозная	0103000020E61000000100000005000000CEDE196D55435C4064027E8D24D14940CEDE196D55435C4079211D1EC2D24940AA436E861B445C4079211D1EC2D24940AA436E861B445C4064027E8D24D14940CEDE196D55435C4064027E8D24D14940
67745	23431	113.023038	113.062303	51.614950999999998	51.507660000000001	Кирова	0103000020E610000001000000050000002D24607479415C4062BEBC00FBC049402D24607479415C403DD2E0B6B6CE494055DCB8C5FC435C403DD2E0B6B6CE494055DCB8C5FC435C4062BEBC00FBC049402D24607479415C4062BEBC00FBC04940
28043	811	112.12403999999999	112.184622	51.133248999999999	51.116160000000001	Пионерская	0103000020E6100000010000000500000055D97745F0075C403B8DB454DE8E494055D97745F0075C40C39CA04D0E914940D107CBD8D00B5C40C39CA04D0E914940D107CBD8D00B5C403B8DB454DE8E494055D97745F0075C403B8DB454DE8E4940
73985	5287	111.759512	111.795669	50.986781999999998	50.973256999999997	Октябрьская	0103000020E61000000100000005000000DA3A38D89BF05B4031CD74AF937C4940DA3A38D89BF05B40072461DF4E7E49403A5CAB3DECF25B40072461DF4E7E49403A5CAB3DECF25B4031CD74AF937C4940DA3A38D89BF05B4031CD74AF937C4940
67527	59072	113.023172	113.04961	51.566521000000002	51.545409999999997	Площадь Тюрина	0103000020E61000000100000005000000B58B69A67B415C40A774B0FECFC54940B58B69A67B415C40A5BF97C283C849407EE36BCF2C435C40A5BF97C283C849407EE36BCF2C435C40A774B0FECFC54940B58B69A67B415C40A774B0FECFC54940
73772	58976	113.023172	113.04961	51.566521000000002	51.545409999999997	Таёжная	0103000020E61000000100000005000000B58B69A67B415C40A774B0FECFC54940B58B69A67B415C40A5BF97C283C849407EE36BCF2C435C40A5BF97C283C849407EE36BCF2C435C40A774B0FECFC54940B58B69A67B415C40A774B0FECFC54940
67142	58976	113.023172	113.04961	51.566521000000002	51.545409999999997	Молодежная	0103000020E61000000100000005000000B58B69A67B415C40A774B0FECFC54940B58B69A67B415C40A5BF97C283C849407EE36BCF2C435C40A5BF97C283C849407EE36BCF2C435C40A774B0FECFC54940B58B69A67B415C40A774B0FECFC54940
28540	4612	111.927632	111.960438	51.131802	51.114745999999997	Шоссейная	0103000020E6100000010000000500000047AE9B525EFB5B4064AC36FFAF8E494047AE9B525EFB5B4011C64FE3DE9049407BF5F1D077FD5B4011C64FE3DE9049407BF5F1D077FD5B4064AC36FFAF8E494047AE9B525EFB5B4064AC36FFAF8E4940
73916	5449	111.97575500000001	111.995913	51.083739000000001	51.064270999999998	Школьная	0103000020E61000000100000005000000257A19C572FE5B40658A39083A884940257A19C572FE5B402B33A5F5B78A4940522AE109BDFF5B402B33A5F5B78A4940522AE109BDFF5B40658A39083A884940257A19C572FE5B40658A39083A884940
73989	5533	113.044687	113.049987	51.624977000000001	51.621203000000001	Набережная	0103000020E610000001000000050000009BE3DC26DC425C40AB96749483CF49409BE3DC26DC425C4048E00F3FFFCF4940698EACFC32435C4048E00F3FFFCF4940698EACFC32435C40AB96749483CF49409BE3DC26DC425C40AB96749483CF4940
73749	1414	112.38642	112.414573	51.261048000000002	51.240499999999997	Советская	0103000020E610000001000000050000004DA1F31ABB185C40105839B4C89E49404DA1F31ABB185C40D65757056AA149407F33315D881A5C40D65757056AA149407F33315D881A5C40105839B4C89E49404DA1F31ABB185C40105839B4C89E4940
74000	47696	111.229973	111.252791	50.980873000000003	50.966411000000001	Школьная	0103000020E61000000100000005000000A27DACE0B7CE5B4051BF0B5BB37B4940A27DACE0B7CE5B40C443183F8D7D4940486E4DBA2DD05B40C443183F8D7D4940486E4DBA2DD05B4051BF0B5BB37B4940A27DACE0B7CE5B4051BF0B5BB37B4940
27438	31045	112.109065	112.134523	51.251173000000001	51.240765000000003	Трудовая	0103000020E61000000100000005000000D908C4EBFA065C40BF823463D19E4940D908C4EBFA065C40B151D66F26A04940D4635B069C085C40B151D66F26A04940D4635B069C085C40BF823463D19E4940D908C4EBFA065C40BF823463D19E4940
27374	29767	112.20752	112.232996	51.191952000000001	51.182468	Центральная	0103000020E610000001000000050000000551F701480D5C408448861C5B9749400551F701480D5C406E3315E29198494053060E68E90E5C406E3315E29198494053060E68E90E5C408448861C5B9749400551F701480D5C408448861C5B974940
73932	60159	115.240583	115.27280500000001	52.659042999999997	52.644784000000001	Советская	0103000020E610000001000000050000004F3E3DB665CF5C40F67D384888524A404F3E3DB665CF5C4030D461855B544A40DC4B1AA375D15C4030D461855B544A40DC4B1AA375D15C40F67D384888524A404F3E3DB665CF5C40F67D384888524A40
73758	60082	115.5946	115.635276	53.538542	53.522511999999999	Центральная	0103000020E61000000100000005000000E78C28ED0DE65C403FE257ACE1C24A40E78C28ED0DE65C40DFC2BAF1EEC44A40C2FBAA5CA8E85C40DFC2BAF1EEC44A40C2FBAA5CA8E85C403FE257ACE1C24A40E78C28ED0DE65C403FE257ACE1C24A40
73822	60115	113.775026	118.23339199999999	56.000698	52.156095000000001	Клубная	0103000020E610000001000000050000002EE3A6069A715C40D908C4EBFA134A402EE3A6069A715C4018963FDF16004C4079C9FFE4EF8E5D4018963FDF16004C4079C9FFE4EF8E5D40D908C4EBFA134A402EE3A6069A715C40D908C4EBFA134A40
73702	60056	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	Центральная	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
73753	60056	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	Рабочая	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
73785	60056	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	Подгорная	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
73665	60056	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	Лесная	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
73624	51774	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	Центральная	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
28062	51774	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	Дарасунская	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
33992	54085	115.49530900000001	115.575987	52.377549000000002	52.350872000000003	Цыборо	0103000020E61000000100000005000000871A8524B3DF5C40838AAA5FE92C4A40871A8524B3DF5C409AD18F8653304A40F4FA93F8DCE45C409AD18F8653304A40F4FA93F8DCE45C40838AAA5FE92C4A40871A8524B3DF5C40838AAA5FE92C4A40
28434	51866	115.165223	115.211028	52.701872999999999	52.677593999999999	Кооперативная	0103000020E6100000010000000500000002637D0393CA5C40A0FB7266BB564A4002637D0393CA5C40037976F9D6594A4094A2957B81CD5C40037976F9D6594A4094A2957B81CD5C40A0FB7266BB564A4002637D0393CA5C40A0FB7266BB564A40
67537	51866	115.165223	115.211028	52.701872999999999	52.677593999999999	Клубная	0103000020E6100000010000000500000002637D0393CA5C40A0FB7266BB564A4002637D0393CA5C40037976F9D6594A4094A2957B81CD5C40037976F9D6594A4094A2957B81CD5C40A0FB7266BB564A4002637D0393CA5C40A0FB7266BB564A40
73751	60078	119.920985	119.954016	54.439543999999998	54.420772999999997	Нагорная	0103000020E61000000100000005000000D2C6116BF1FA5D401805C1E3DB354B40D2C6116BF1FA5D40969350FA42384B4016F71F990EFD5D40969350FA42384B4016F71F990EFD5D401805C1E3DB354B40D2C6116BF1FA5D401805C1E3DB354B40
73986	21883	119.924453	119.940479	54.463115999999999	54.453699999999998	Центральная	0103000020E610000001000000050000001A6CEA3C2AFB5D40FC1873D7123A4B401A6CEA3C2AFB5D408E209562473B4B40C9E4D4CE30FC5D408E209562473B4B40C9E4D4CE30FC5D40FC1873D7123A4B401A6CEA3C2AFB5D40FC1873D7123A4B40
27743	51732	118.649734	118.68791299999999	52.585687999999998	52.559384000000001	Центральная	0103000020E610000001000000050000005A46EA3D95A95D40EDF318E599474A405A46EA3D95A95D406FD40AD3F74A4A40915F3FC406AC5D406FD40AD3F74A4A40915F3FC406AC5D40EDF318E599474A405A46EA3D95A95D40EDF318E599474A40
27522	51690	117.485652	117.499172	52.374481000000003	52.360844	Титкова	0103000020E610000001000000050000002B4F20EC145F5D409A7ADD22302E4A402B4F20EC145F5D4098FC4FFEEE2F4A400DC51D6FF25F5D4098FC4FFEEE2F4A400DC51D6FF25F5D409A7ADD22302E4A402B4F20EC145F5D409A7ADD22302E4A40
73870	52248	118.617296	118.633196	52.453811000000002	52.449359999999999	Луговая	0103000020E61000000100000005000000E7FC14C781A75D40B610E4A084394A40E7FC14C781A75D4054C8957A163A4A4050FD834886A85D4054C8957A163A4A4050FD834886A85D40B610E4A084394A40E7FC14C781A75D40B610E4A084394A40
73910	60146	118.095941	118.149283	52.320281999999999	52.310586999999998	Набережная	0103000020E610000001000000050000001D56B8E523865D4008C89750C1274A401D56B8E523865D40ADBF2500FF284A4052B648DA8D895D40ADBF2500FF284A4052B648DA8D895D4008C89750C1274A401D56B8E523865D4008C89750C1274A40
73928	60156	117.340799	117.373165	52.273516000000001	52.25826	Центральная	0103000020E610000001000000050000009CE09BA6CF555D40B7EEE6A90E214A409CE09BA6CF555D406477819202234A40C2C073EFE1575D406477819202234A40C2C073EFE1575D40B7EEE6A90E214A409CE09BA6CF555D40B7EEE6A90E214A40
73893	60139	117.45331299999999	117.465692	52.166719000000001	52.159913000000003	Школьная	0103000020E6100000010000000500000081768714035D5D40469A780778144A4081768714035D5D40984F560C57154A409180D1E5CD5D5D40984F560C57154A409180D1E5CD5D5D40469A780778144A4081768714035D5D40469A780778144A40
27492	51678	118.765311	118.82964	52.735050000000001	52.693758000000003	Киргизова	0103000020E610000001000000050000003811FDDAFAB05D4050ABE80FCD584A403811FDDAFAB05D4060764F1E165E4A4005DD5ED218B55D4060764F1E165E4A4005DD5ED218B55D4050ABE80FCD584A403811FDDAFAB05D4050ABE80FCD584A40
73786	60096	118.765311	118.82964	52.735050000000001	52.693758000000003	Советская	0103000020E610000001000000050000003811FDDAFAB05D4050ABE80FCD584A403811FDDAFAB05D4060764F1E165E4A4005DD5ED218B55D4060764F1E165E4A4005DD5ED218B55D4050ABE80FCD584A403811FDDAFAB05D4050ABE80FCD584A40
73976	52244	118.25161	118.29320199999999	52.333233	52.330342999999999	Набережная	0103000020E610000001000000050000002E56D4601A905D4034BBEEAD482A4A402E56D4601A905D4057790261A72A4A40CB4752D2C3925D4057790261A72A4A40CB4752D2C3925D4034BBEEAD482A4A402E56D4601A905D4034BBEEAD482A4A40
73899	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Энергетиков	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
73827	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Фабричная	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
73895	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Сельская	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
28578	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Партизанская	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
27760	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Набережная	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
74008	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Молодежная	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
73808	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Луначарского	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
28504	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Клубная	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
73866	50855	117.62009399999999	117.750844	52.259290999999997	52.202725000000001	Вокзальная	0103000020E61000000100000005000000889CBE9EAF675D40728A8EE4F2194A40889CBE9EAF675D40D5928E7230214A407619FED30D705D40D5928E7230214A407619FED30D705D40728A8EE4F2194A40889CBE9EAF675D40728A8EE4F2194A40
73997	52227	117.01413599999999	117.034842	52.098793999999998	52.084623000000001	Нагорная	0103000020E610000001000000050000008F6CAE9AE7405D40A5BE2CEDD40A4A408F6CAE9AE7405D4040852348A50C4A40BEA1F0D93A425D4040852348A50C4A40BEA1F0D93A425D40A5BE2CEDD40A4A408F6CAE9AE7405D40A5BE2CEDD40A4A40
27381	51629	117.855435	117.89535600000001	52.273935000000002	52.248949000000003	Набережная	0103000020E61000000100000005000000A4367172BF765D409BAF928FDD1F4A40A4367172BF765D40691D554D10234A40C19140834D795D40691D554D10234A40C19140834D795D409BAF928FDD1F4A40A4367172BF765D409BAF928FDD1F4A40
27148	51504	117.982349	118.01978200000001	52.289312000000002	52.282547000000001	Молодежная	0103000020E61000000100000005000000881057CEDE7E5D409D4A06802A244A40881057CEDE7E5D40912BF52C08254A402BC3B81B44815D40912BF52C08254A402BC3B81B44815D409D4A06802A244A40881057CEDE7E5D409D4A06802A244A40
74006	52240	117.34500300000001	117.359071	52.408467999999999	52.394781000000002	Новая	0103000020E610000001000000050000006781768714565D40850A0E2F88324A406781768714565D4034BBEEAD48344A404A7CEE04FB565D4034BBEEAD48344A404A7CEE04FB565D40850A0E2F88324A406781768714565D40850A0E2F88324A40
73868	52245	118.15797000000001	118.169854	52.390839999999997	52.382787999999998	Нижняя	0103000020E61000000100000005000000F2EF332E1C8A5D408FA67A32FF304A40F2EF332E1C8A5D40FCFB8C0B07324A4011C64FE3DE8A5D40FCFB8C0B07324A4011C64FE3DE8A5D408FA67A32FF304A40F2EF332E1C8A5D408FA67A32FF304A40
74063	54087	117.522043	117.592884	52.223281	52.194197000000003	Новая	0103000020E61000000100000005000000C4060B2769615D409CFD8172DB184A40C4060B2769615D40BA68C878941C4A409694BBCFF1655D40BA68C878941C4A409694BBCFF1655D409CFD8172DB184A40C4060B2769615D409CFD8172DB184A40
73582	54087	117.522043	117.592884	52.223281	52.194197000000003	Заводская	0103000020E61000000100000005000000C4060B2769615D409CFD8172DB184A40C4060B2769615D40BA68C878941C4A409694BBCFF1655D40BA68C878941C4A409694BBCFF1655D409CFD8172DB184A40C4060B2769615D409CFD8172DB184A40
28292	51843	117.522043	117.592884	52.223281	52.194197000000003	2-Набережная	0103000020E61000000100000005000000C4060B2769615D409CFD8172DB184A40C4060B2769615D40BA68C878941C4A409694BBCFF1655D40BA68C878941C4A409694BBCFF1655D409CFD8172DB184A40C4060B2769615D409CFD8172DB184A40
73812	51843	117.522043	117.592884	52.223281	52.194197000000003	1-Луговая	0103000020E61000000100000005000000C4060B2769615D409CFD8172DB184A40C4060B2769615D40BA68C878941C4A409694BBCFF1655D40BA68C878941C4A409694BBCFF1655D409CFD8172DB184A40C4060B2769615D409CFD8172DB184A40
73867	50914	117.04059100000001	117.07091800000001	52.079028000000001	52.060260999999997	Школьная	0103000020E61000000100000005000000C460FE0A99425D40B41CE8A1B6074A40C460FE0A99425D40F1BBE9961D0A4A40A8ACA6EB89445D40F1BBE9961D0A4A40A8ACA6EB89445D40B41CE8A1B6074A40C460FE0A99425D40B41CE8A1B6074A40
24055	50914	117.04059100000001	117.07091800000001	52.079028000000001	52.060260999999997	Нагорная	0103000020E61000000100000005000000C460FE0A99425D40B41CE8A1B6074A40C460FE0A99425D40F1BBE9961D0A4A40A8ACA6EB89445D40F1BBE9961D0A4A40A8ACA6EB89445D40B41CE8A1B6074A40C460FE0A99425D40B41CE8A1B6074A40
74002	52234	117.443459	117.454921	52.215865000000001	52.202874999999999	Центральная	0103000020E610000001000000050000007B87DBA1615C5D408716D9CEF7194A407B87DBA1615C5D40EFACDD76A11B4A40DF50F86C1D5D5D40EFACDD76A11B4A40DF50F86C1D5D5D408716D9CEF7194A407B87DBA1615C5D408716D9CEF7194A40
27009	51422	119.205073	119.23151900000001	53.107551999999998	53.094056999999999	Набережная	0103000020E61000000100000005000000BA1281EA1FCD5D40DD7A4D0F0A8C4A40BA1281EA1FCD5D40484F9143C48D4A40C5591135D1CE5D40484F9143C48D4A40C5591135D1CE5D40DD7A4D0F0A8C4A40BA1281EA1FCD5D40DD7A4D0F0A8C4A40
27890	51762	117.049916	117.06402799999999	52.142567	52.118589999999998	Центральная	0103000020E6100000010000000500000004E3E0D231435D40FAD005F52D0F4A4004E3E0D231435D40923EADA23F124A40CF81E50819445D40923EADA23F124A40CF81E50819445D40FAD005F52D0F4A4004E3E0D231435D40FAD005F52D0F4A40
74034	60204	118.935363	118.95023	52.837788000000003	52.821150000000003	Молодежная	0103000020E61000000100000005000000DCB8C5FCDCBB5D40228E75711B694A40DCB8C5FCDCBB5D409A7D1EA33C6B4A40666B7D91D0BC5D409A7D1EA33C6B4A40666B7D91D0BC5D40228E75711B694A40DCB8C5FCDCBB5D40228E75711B694A40
73987	60183	116.896897	119.905292	53.374496999999998	51.900396999999998	Шилкинская	0103000020E610000001000000050000005AB8ACC266395D4050357A3540F349405AB8ACC266395D409DB98784EFAF4A402655DB4DF0F95D409DB98784EFAF4A402655DB4DF0F95D4050357A3540F349405AB8ACC266395D4050357A3540F34940
27905	51764	118.10355	118.12230599999999	52.482565000000001	52.467123000000001	Центральная	0103000020E610000001000000050000000DE02D90A0865D40CE1ABCAFCA3B4A400DE02D90A0865D40DD989EB0C43D4A40B1868BDCD3875D40DD989EB0C43D4A40B1868BDCD3875D40CE1ABCAFCA3B4A400DE02D90A0865D40CE1ABCAFCA3B4A40
27146	51503	117.231375	117.24581999999999	52.091988999999998	52.081358000000002	Центральная	0103000020E610000001000000050000002B8716D9CE4E5D404DA25EF0690A4A402B8716D9CE4E5D40BE4BA94BC60B4A40F92CCF83BB4F5D40BE4BA94BC60B4A40F92CCF83BB4F5D404DA25EF0690A4A402B8716D9CE4E5D404DA25EF0690A4A40
27432	51654	117.607392	117.633308	52.331923000000003	52.302315999999998	Красноармейская	0103000020E6100000010000000500000088F6B182DF665D405D876A4AB2264A4088F6B182DF665D4026E5EE737C2A4A40E412471E88685D4026E5EE737C2A4A40E412471E88685D405D876A4AB2264A4088F6B182DF665D405D876A4AB2264A40
74011	52238	117.50282799999999	117.52130699999999	52.442625	52.430799	Зеленая	0103000020E61000000100000005000000D6E07D552E605D402313F06B24374A40D6E07D552E605D402DB29DEFA7384A40410B09185D615D402DB29DEFA7384A40410B09185D615D402313F06B24374A40D6E07D552E605D402313F06B24374A40
73831	60121	119.069607	119.11287	50.376370999999999	50.354098999999998	Магистральная	0103000020E61000000100000005000000A724EB7074C45D40ED45B41D532D4940A724EB7074C45D40D714C8EC2C304940C5AC174339C75D40D714C8EC2C304940C5AC174339C75D40ED45B41D532D4940A724EB7074C45D40ED45B41D532D4940
73887	27033	118.396355	118.42415800000001	50.364179	50.352404	Советская	0103000020E61000000100000005000000CAA65CE15D995D40637D03931B2D4940CAA65CE15D995D40EB71DF6A9D2E49408E959867259B5D40EB71DF6A9D2E49408E959867259B5D40637D03931B2D4940CAA65CE15D995D40637D03931B2D4940
24522	51042	118.50247299999999	118.526081	50.473211999999997	50.459215999999998	Аксенова	0103000020E61000000100000005000000DF87838428A05D4064E60297C73A4940DF87838428A05D409109F835923C49400283A44FABA15D409109F835923C49400283A44FABA15D4064E60297C73A4940DF87838428A05D4064E60297C73A4940
73890	27743	118.920181	118.937096	50.480778000000001	50.473613	Юбилейная	0103000020E61000000100000005000000A359D93EE4BA5D40F0FACC599F3C4940A359D93EE4BA5D4072512D228A3D4940984D8061F9BB5D4072512D228A3D4940984D8061F9BB5D40F0FACC599F3C4940A359D93EE4BA5D40F0FACC599F3C4940
73862	27760	118.83194	118.848855	50.564819	50.555320000000002	Юбилейная	0103000020E61000000100000005000000FE0E45813EB55D404968CBB914474940FE0E45813EB55D4068942EFD4B484940F302ECA353B65D4068942EFD4B484940F302ECA353B65D404968CBB914474940FE0E45813EB55D404968CBB914474940
73825	60119	119.31463100000001	119.337053	50.203226999999998	50.193193000000001	Колхозная	0103000020E61000000100000005000000B3D30FEA22D45D407768588CBA184940B3D30FEA22D45D400455A357031A49403201BF4692D55D400455A357031A49403201BF4692D55D407768588CBA184940B3D30FEA22D45D407768588CBA184940
73967	27018	118.317519	118.33615899999999	50.569921999999998	50.560344000000001	Нагорная	0103000020E61000000100000005000000F436363B52945D404241295AB9474940F436363B52945D40ADA23F34F348494063D009A183955D40ADA23F34F348494063D009A183955D404241295AB9474940F436363B52945D404241295AB9474940
27534	51696	119.069607	119.11287	50.376370999999999	50.354098999999998	Ленина	0103000020E61000000100000005000000A724EB7074C45D40ED45B41D532D4940A724EB7074C45D40D714C8EC2C304940C5AC174339C75D40D714C8EC2C304940C5AC174339C75D40ED45B41D532D4940A724EB7074C45D40ED45B41D532D4940
27439	27899	119.069607	119.11287	50.376370999999999	50.354098999999998	Строительная	0103000020E61000000100000005000000A724EB7074C45D40ED45B41D532D4940A724EB7074C45D40D714C8EC2C304940C5AC174339C75D40D714C8EC2C304940C5AC174339C75D40ED45B41D532D4940A724EB7074C45D40ED45B41D532D4940
23903	27899	119.069607	119.11287	50.376370999999999	50.354098999999998	Декабристов	0103000020E61000000100000005000000A724EB7074C45D40ED45B41D532D4940A724EB7074C45D40D714C8EC2C304940C5AC174339C75D40D714C8EC2C304940C5AC174339C75D40ED45B41D532D4940A724EB7074C45D40ED45B41D532D4940
27410	51645	118.950068	118.97188800000001	50.596535000000003	50.585915999999997	Школьная	0103000020E61000000100000005000000793E03EACDBC5D40001AA54BFF4A4940793E03EACDBC5D40AEF545425B4C4940FED7B96933BE5D40AEF545425B4C4940FED7B96933BE5D40001AA54BFF4A4940793E03EACDBC5D40001AA54BFF4A4940
24745	27371	118.660568	118.678956	50.337268000000002	50.325135000000003	Советская	0103000020E610000001000000050000002F3201BF46AA5D407AE40F069E2949402F3201BF46AA5D4061FE0A992B2B494012DBDD0374AB5D4061FE0A992B2B494012DBDD0374AB5D407AE40F069E2949402F3201BF46AA5D407AE40F069E294940
28453	51869	119.101551	119.13204	50.401629	50.380501000000002	Федорова	0103000020E6100000010000000500000012F8C3CF7FC65D40338CBB41B430494012F8C3CF7FC65D4006103E9468334940E370E65773C85D4006103E9468334940E370E65773C85D40338CBB41B430494012F8C3CF7FC65D40338CBB41B4304940
74032	51869	119.101551	119.13204	50.401629	50.380501000000002	Лазо	0103000020E6100000010000000500000012F8C3CF7FC65D40338CBB41B430494012F8C3CF7FC65D4006103E9468334940E370E65773C85D4006103E9468334940E370E65773C85D40338CBB41B430494012F8C3CF7FC65D40338CBB41B4304940
28297	27819	118.14631799999999	118.166872	50.382224000000001	50.370171999999997	Советская	0103000020E610000001000000050000003B342C465D895D408CF2CCCB612F49403B342C465D895D4087DF4DB7EC3049408FA7E507AE8A5D4087DF4DB7EC3049408FA7E507AE8A5D408CF2CCCB612F49403B342C465D895D408CF2CCCB612F4940
27664	51720	118.97788	119.00328399999999	50.290501999999996	50.276480999999997	Молодежная	0103000020E6100000010000000500000066DAFE9595BE5D40917BBABA6323494066DAFE9595BE5D4017B6662B2F254940672618CE35C05D4017B6662B2F254940672618CE35C05D40917BBABA6323494066DAFE9595BE5D40917BBABA63234940
24408	27632	119.177953	119.183594	50.098412000000003	50.093938999999999	Молодежная	0103000020E6100000010000000500000068CEFA9463CB5D40D3687231060C494068CEFA9463CB5D4059C4B0C3980C49407A6F0C01C0CB5D4059C4B0C3980C49407A6F0C01C0CB5D40D3687231060C494068CEFA9463CB5D40D3687231060C4940
73783	28111	117.981522	118.016161	50.453125	50.407043000000002	Социалистическая	0103000020E610000001000000050000007D93A641D17E5D406A882AFC193449407D93A641D17E5D4000000000003A49401F9E25C808815D4000000000003A49401F9E25C808815D406A882AFC193449407D93A641D17E5D406A882AFC19344940
73688	28111	117.981522	118.016161	50.453125	50.407043000000002	Ленина	0103000020E610000001000000050000007D93A641D17E5D406A882AFC193449407D93A641D17E5D4000000000003A49401F9E25C808815D4000000000003A49401F9E25C808815D406A882AFC193449407D93A641D17E5D406A882AFC19344940
27488	27304	119.252854	119.28103400000001	50.611645000000003	50.602274999999999	Пешкова	0103000020E610000001000000050000006B2A8BC22ED05D406519E258174D49406B2A8BC22ED05D4087E123624A4E49401AC40776FCD15D4087E123624A4E49401AC40776FCD15D406519E258174D49406B2A8BC22ED05D406519E258174D4940
28316	27256	118.92190600000001	118.94026700000001	50.021312000000002	50.001572000000003	Баженова	0103000020E610000001000000050000001EFF058200BB5D406F4BE482330049401EFF058200BB5D409581035ABA02494084A0A3552DBC5D409581035ABA02494084A0A3552DBC5D406F4BE482330049401EFF058200BB5D406F4BE48233004940
28094	27684	118.61620000000001	118.65904999999999	50.403179000000002	50.385153000000003	Юбилейная	0103000020E61000000100000005000000E5F21FD26FA75D40687A89B14C314940E5F21FD26FA75D408DB7955E9B334940711B0DE02DAA5D408DB7955E9B334940711B0DE02DAA5D40687A89B14C314940E5F21FD26FA75D40687A89B14C314940
27406	27390	118.882874	118.890052	50.172179999999997	50.165002000000001	Школьная	0103000020E61000000100000005000000471FF30181B85D4026E318C91E154940471FF30181B85D403C8386FE0916494052EFA99CF6B85D403C8386FE0916494052EFA99CF6B85D4026E318C91E154940471FF30181B85D4026E318C91E154940
73897	27111	118.322469	118.352069	50.434981000000001	50.424796000000001	Ленина	0103000020E61000000100000005000000533E0455A3945D405EBC1FB75F364940533E0455A3945D40D1B01875AD374940DE3B6A4C88965D40D1B01875AD374940DE3B6A4C88965D405EBC1FB75F364940533E0455A3945D405EBC1FB75F364940
74004	27477	119.113328	119.12355100000001	50.593167000000001	50.586618999999999	Новая	0103000020E61000000100000005000000266E15C440C75D402A1BD654164B4940266E15C440C75D40810871E5EC4B4940D7187442E8C75D40810871E5EC4B4940D7187442E8C75D402A1BD654164B4940266E15C440C75D402A1BD654164B4940
27451	26869	118.524967	118.57351199999999	50.657761000000001	50.631829000000003	Новая	0103000020E61000000100000005000000AC1E300F99A15D400BD5CDC5DF504940AC1E300F99A15D40C9CA2F833154494044F7AC6BB4A45D40C9CA2F833154494044F7AC6BB4A45D400BD5CDC5DF504940AC1E300F99A15D400BD5CDC5DF504940
24434	26869	118.524967	118.57351199999999	50.657761000000001	50.631829000000003	Кооперативная	0103000020E61000000100000005000000AC1E300F99A15D400BD5CDC5DF504940AC1E300F99A15D40C9CA2F833154494044F7AC6BB4A45D40C9CA2F833154494044F7AC6BB4A45D400BD5CDC5DF504940AC1E300F99A15D400BD5CDC5DF504940
73605	3605	109.552415	109.588176	51.296137999999999	51.275745000000001	Кооперативная	0103000020E6100000010000000500000078B471C45A635B408C84B69C4BA3494078B471C45A635B402A8D98D9E7A54940B212F3ACA4655B402A8D98D9E7A54940B212F3ACA4655B408C84B69C4BA3494078B471C45A635B408C84B69C4BA34940
73740	52246	108.45737699999999	108.49128	51.253754999999998	51.236558000000002	Нагорная	0103000020E61000000100000005000000533C2EAA451D5B40B8CD5488479E4940533C2EAA451D5B402619390B7BA04940734BAB21711F5B402619390B7BA04940734BAB21711F5B40B8CD5488479E4940533C2EAA451D5B40B8CD5488479E4940
73814	52239	108.559444	108.580752	50.941161000000001	50.922427999999996	Клубная	0103000020E6100000010000000500000061FC34EECD235B401475E61E1276494061FC34EECD235B40A5A2B1F6777849408BC56F0A2B255B40A5A2B1F6777849408BC56F0A2B255B401475E61E1276494061FC34EECD235B401475E61E12764940
73992	3572	109.31529500000001	109.33893	51.211134999999999	51.202027000000001	Почтовая	0103000020E61000000100000005000000E96514CB2D545B405AF44E05DC994940E96514CB2D545B403E05C078069B494088687407B1555B403E05C078069B494088687407B1555B405AF44E05DC994940E96514CB2D545B405AF44E05DC994940
73735	60072	109.07293900000001	109.113623	51.187527000000003	51.164160000000003	Кооперативная	0103000020E6100000010000000500000097E65608AB445B40DBA7E3310395494097E65608AB445B40FA0E7EE200984940B344679945475B40FA0E7EE200984940B344679945475B40DBA7E3310395494097E65608AB445B40DBA7E33103954940
73762	60085	109.07293900000001	109.113623	51.187527000000003	51.164160000000003	Заводская	0103000020E6100000010000000500000097E65608AB445B40DBA7E3310395494097E65608AB445B40FA0E7EE200984940B344679945475B40FA0E7EE200984940B344679945475B40DBA7E3310395494097E65608AB445B40DBA7E33103954940
73824	50784	108.109594	108.128675	50.777585999999999	50.760376000000001	Вакарина	0103000020E610000001000000050000009F758D9603075B40E7543200546149409F758D9603075B40EAE923F087634940053411363C085B40EAE923F087634940053411363C085B40E7543200546149409F758D9603075B40E754320054614940
73973	52242	108.79936600000001	108.814943	50.962775000000001	50.952471000000003	Трактовая	0103000020E6100000010000000500000033E202D028335B40B8B1D991EA79494033E202D028335B40053411363C7B4940AA46AF0628345B40053411363C7B4940AA46AF0628345B40B8B1D991EA79494033E202D028335B40B8B1D991EA794940
73991	52241	108.54128	108.55179	50.978225000000002	50.961067	 Центральная	0103000020E61000000100000005000000A67EDE54A4225B40E621533E047B4940A67EDE54A4225B4097900F7A367D4940A110018750235B4097900F7A367D4940A110018750235B40E621533E047B4940A67EDE54A4225B40E621533E047B4940
73614	60041	109.182075	109.253761	51.230212999999999	51.199984000000001	Советская	0103000020E61000000100000005000000D49AE61DA74B5B4094DC611399994940D49AE61DA74B5B40990E9D9E779D49400400C79E3D505B40990E9D9E779D49400400C79E3D505B4094DC611399994940D49AE61DA74B5B4094DC611399994940
73577	60041	109.182075	109.253761	51.230212999999999	51.199984000000001	Заводская	0103000020E61000000100000005000000D49AE61DA74B5B4094DC611399994940D49AE61DA74B5B40990E9D9E779D49400400C79E3D505B40990E9D9E779D49400400C79E3D505B4094DC611399994940D49AE61DA74B5B4094DC611399994940
73863	52230	108.15557	108.170734	50.795279000000001	50.785570999999997	Центральная	0103000020E61000000100000005000000478FDFDBF4095B40CFD72C978D644940478FDFDBF4095B400919C8B3CB6549402D944C4EED0A5B400919C8B3CB6549402D944C4EED0A5B40CFD72C978D644940478FDFDBF4095B40CFD72C978D644940
28396	51858	108.40398999999999	108.443561	50.846741999999999	50.8245	Пионерская	0103000020E610000001000000050000004E7ADFF8DA195B40A8C64B37896949404E7ADFF8DA195B402713B70A626C4940FD31AD4D631C5B402713B70A626C4940FD31AD4D631C5B40A8C64B37896949404E7ADFF8DA195B40A8C64B3789694940
73601	51858	108.40398999999999	108.443561	50.846741999999999	50.8245	Комсомольская	0103000020E610000001000000050000004E7ADFF8DA195B40A8C64B37896949404E7ADFF8DA195B402713B70A626C4940FD31AD4D631C5B402713B70A626C4940FD31AD4D631C5B40A8C64B37896949404E7ADFF8DA195B40A8C64B3789694940
73920	52243	108.983197	109.00310399999999	51.002257999999998	50.994663000000003	Нагаева	0103000020E610000001000000050000009F211CB3EC3E5B4048C5FF1D517F49409F211CB3EC3E5B40C2137AFD49804940279F1EDB32405B40C2137AFD49804940279F1EDB32405B4048C5FF1D517F49409F211CB3EC3E5B4048C5FF1D517F4940
24171	50967	109.023972	109.055224	51.152935999999997	51.129466999999998	Шахтовая	0103000020E610000001000000050000004301DBC188415B40A374E95F929049404301DBC188415B40C630276893934940137D3ECA88435B40C630276893934940137D3ECA88435B40A374E95F929049404301DBC188415B40A374E95F92904940
24043	50905	108.953427	108.969228	51.014794999999999	51.008000000000003	 Центральная	0103000020E61000000100000005000000E607AEF2043D5B401B2FDD2406814940E607AEF2043D5B40799274CDE48149408597E0D4073E5B40799274CDE48149408597E0D4073E5B401B2FDD2406814940E607AEF2043D5B401B2FDD2406814940
27369	51626	108.648404	108.670395	50.956856999999999	50.939895999999997	Центральная	0103000020E610000001000000050000001EA67D737F295B4013D21A834E7849401EA67D737F295B406EF9484A7A7A4940B9196EC0E72A5B406EF9484A7A7A4940B9196EC0E72A5B4013D21A834E7849401EA67D737F295B4013D21A834E784940
27134	3490	109.203087	109.22039700000001	51.188293999999999	51.181983000000002	Колхозная,	0103000020E6100000010000000500000089CF9D60FF4C5B40C8B60C384B97494089CF9D60FF4C5B403A048E041A984940BDC804FC1A4E5B403A048E041A984940BDC804FC1A4E5B40C8B60C384B97494089CF9D60FF4C5B40C8B60C384B974940
27241	51556	108.969255	108.98424799999999	51.112653999999999	51.107484999999997	Улан-Туя	0103000020E61000000100000005000000029F1F46083E5B40C0E78711C28D4940029F1F46083E5B40BDE13E726B8E4940D1C952EBFD3E5B40BDE13E726B8E4940D1C952EBFD3E5B40C0E78711C28D4940029F1F46083E5B40C0E78711C28D4940
27919	51767	108.882756	108.949941	51.179904999999998	51.140985999999998	Шоссейная	0103000020E61000000100000005000000429605137F385B40D09849D40B924940429605137F385B4085B18520079749404A0856D5CB3C5B4085B18520079749404A0856D5CB3C5B40D09849D40B924940429605137F385B40D09849D40B924940
37941	51767	108.882756	108.949941	51.179904999999998	51.140985999999998	Клубная	0103000020E61000000100000005000000429605137F385B40D09849D40B924940429605137F385B4085B18520079749404A0856D5CB3C5B4085B18520079749404A0856D5CB3C5B40D09849D40B924940429605137F385B40D09849D40B924940
73857	50749	115.401381	115.419617	50.580916999999999	50.570157000000002	Солнечная	0103000020E61000000100000005000000170FEF39B0D95C40F14A92E7FA484940170FEF39B0D95C406058FE7C5B4A49401FF64201DBDA5C406058FE7C5B4A49401FF64201DBDA5C40F14A92E7FA484940170FEF39B0D95C40F14A92E7FA484940
73942	50749	115.401381	115.419617	50.580916999999999	50.570157000000002	Нагорная	0103000020E61000000100000005000000170FEF39B0D95C40F14A92E7FA484940170FEF39B0D95C406058FE7C5B4A49401FF64201DBDA5C406058FE7C5B4A49401FF64201DBDA5C40F14A92E7FA484940170FEF39B0D95C40F14A92E7FA484940
23524	50749	115.401381	115.419617	50.580916999999999	50.570157000000002	Васильева	0103000020E61000000100000005000000170FEF39B0D95C40F14A92E7FA484940170FEF39B0D95C406058FE7C5B4A49401FF64201DBDA5C406058FE7C5B4A49401FF64201DBDA5C40F14A92E7FA484940170FEF39B0D95C40F14A92E7FA484940
23726	50813	115.76001599999999	115.77709299999999	50.495123	50.486172000000003	Молодежная	0103000020E61000000100000005000000F31B261AA4F05C408F1D54E23A3E4940F31B261AA4F05C40AB3FC230603F4940D53C47E4BBF15C40AB3FC230603F4940D53C47E4BBF15C408F1D54E23A3E4940F31B261AA4F05C408F1D54E23A3E4940
27436	50813	115.76001599999999	115.77709299999999	50.495123	50.486172000000003	Кушурская	0103000020E61000000100000005000000F31B261AA4F05C408F1D54E23A3E4940F31B261AA4F05C40AB3FC230603F4940D53C47E4BBF15C40AB3FC230603F4940D53C47E4BBF15C408F1D54E23A3E4940F31B261AA4F05C408F1D54E23A3E4940
73891	51819	114.161248	114.17413000000001	50.466796000000002	50.447338000000002	Школьная	0103000020E61000000100000005000000E8A221E3518A5C400821205F42394940E8A221E3518A5C40AAF3A8F8BF3B494029D027F2248B5C40AAF3A8F8BF3B494029D027F2248B5C400821205F42394940E8A221E3518A5C400821205F42394940
28167	51819	114.161248	114.17413000000001	50.466796000000002	50.447338000000002	Ленина	0103000020E61000000100000005000000E8A221E3518A5C400821205F42394940E8A221E3518A5C40AAF3A8F8BF3B494029D027F2248B5C40AAF3A8F8BF3B494029D027F2248B5C400821205F42394940E8A221E3518A5C400821205F42394940
24373	51016	114.39607700000001	114.43589900000001	50.351863000000002	50.340440999999998	Центральная	0103000020E61000000100000005000000A96C585359995C40D89B1892932B4940A96C585359995C4013D6C6D8092D4940FC56EBC4E59B5C4013D6C6D8092D4940FC56EBC4E59B5C40D89B1892932B4940A96C585359995C40D89B1892932B4940
73684	51016	114.39607700000001	114.43589900000001	50.351863000000002	50.340440999999998	Ветрова	0103000020E61000000100000005000000A96C585359995C40D89B1892932B4940A96C585359995C4013D6C6D8092D4940FC56EBC4E59B5C4013D6C6D8092D4940FC56EBC4E59B5C40D89B1892932B4940A96C585359995C40D89B1892932B4940
73775	60092	115.54433	115.57257300000001	50.369827000000001	50.355500999999997	Центральная	0103000020E61000000100000005000000D40E7F4DD6E25C40FF58880E812D4940D40E7F4DD6E25C40C216BB7D562F4940A6643909A5E45C40C216BB7D562F4940A6643909A5E45C40FF58880E812D4940D40E7F4DD6E25C40FF58880E812D4940
68023	59128	115.12079199999999	115.140367	50.518524999999997	50.504416999999997	Комсомольская	0103000020E6100000010000000500000094675E0EBBC75C40F1457BBC9040494094675E0EBBC75C404694F6065F424940029CDEC5FBC85C404694F6065F424940029CDEC5FBC85C40F1457BBC9040494094675E0EBBC75C40F1457BBC90404940
27978	51785	115.67287899999999	115.687028	50.237214999999999	50.226652999999999	Казачий переулок	0103000020E6100000010000000500000092CA147310EB5C4028452BF7021D494092CA147310EB5C40718FA50F5D1E4940ECDB4944F8EB5C40718FA50F5D1E4940ECDB4944F8EB5C4028452BF7021D494092CA147310EB5C4028452BF7021D4940
28488	51878	115.301857	115.31896999999999	50.264436000000003	50.258983000000001	Молодежная	0103000020E6100000010000000500000065C405A051D35C40289CDD5A2621494065C405A051D35C404AF1F109D9214940ED9925016AD45C404AF1F109D9214940ED9925016AD45C40289CDD5A2621494065C405A051D35C40289CDD5A26214940
74018	60195	113.969691	115.924695	50.652695999999999	49.904651000000001	Ленина	0103000020E610000001000000050000006F0ED76A0F7E5C4098A59D9ACBF348406F0ED76A0F7E5C40711DE38A8B53494095F1EF332EFB5C40711DE38A8B53494095F1EF332EFB5C4098A59D9ACBF348406F0ED76A0F7E5C4098A59D9ACBF34840
73607	60048	115.07914700000001	115.121188	50.515759000000003	50.501730000000002	Григорьева	0103000020E61000000100000005000000E62494BE10C55C4007B64AB038404940E62494BE10C55C4010CF126404424940BB2A508BC1C75C4010CF126404424940BB2A508BC1C75C4007B64AB038404940E62494BE10C55C4007B64AB038404940
73851	51882	114.85755	114.888335	50.248154999999997	50.241916000000003	Центральная	0103000020E61000000100000005000000D42B6519E2B65C4088307E1AF71E4940D42B6519E2B65C4060AB048BC31F494019390B7BDAB85C4060AB048BC31F494019390B7BDAB85C4088307E1AF71E4940D42B6519E2B65C4088307E1AF71E4940
73892	51639	114.648467	114.67344900000001	50.495260999999999	50.478668999999996	Школьная	0103000020E610000001000000050000004162BB7B80A95C40F44D9A06453D49404162BB7B80A95C40FCFD62B6643F494088A1D5C919AB5C40FCFD62B6643F494088A1D5C919AB5C40F44D9A06453D49404162BB7B80A95C40F44D9A06453D4940
73888	51639	114.648467	114.67344900000001	50.495260999999999	50.478668999999996	Центральная	0103000020E610000001000000050000004162BB7B80A95C40F44D9A06453D49404162BB7B80A95C40FCFD62B6643F494088A1D5C919AB5C40FCFD62B6643F494088A1D5C919AB5C40F44D9A06453D49404162BB7B80A95C40F44D9A06453D4940
27395	51639	114.648467	114.67344900000001	50.495260999999999	50.478668999999996	Ленина	0103000020E610000001000000050000004162BB7B80A95C40F44D9A06453D49404162BB7B80A95C40FCFD62B6643F494088A1D5C919AB5C40FCFD62B6643F494088A1D5C919AB5C40F44D9A06453D49404162BB7B80A95C40F44D9A06453D4940
73941	60165	118.83979100000001	120.76719799999999	52.642696000000001	50.914937999999999	Балябина	0103000020E61000000100000005000000691EC022BFB55D400FEF39B01C754940691EC022BFB55D4090A2CEDC43524A409FE3A3C519315E4090A2CEDC43524A409FE3A3C519315E400FEF39B01C754940691EC022BFB55D400FEF39B01C754940
74005	60190	119.588357	119.60485	51.372470999999997	51.366155999999997	Садовая	0103000020E61000000100000005000000DA571EA4A7E55D40F99D2633DEAE4940DA571EA4A7E55D40ADDA3521ADAF4940143FC6DCB5E65D40ADDA3521ADAF4940143FC6DCB5E65D40F99D2633DEAE4940DA571EA4A7E55D40F99D2633DEAE4940
28012	51795	119.250501	119.268638	51.077905000000001	51.062804999999997	Мира	0103000020E6100000010000000500000061A7583508D05D403C8386FE0988494061A7583508D05D40F29881CAF88949409F1D705D31D15D40F29881CAF88949409F1D705D31D15D403C8386FE0988494061A7583508D05D403C8386FE09884940
74041	60211	119.457463	119.476795	51.698447999999999	51.684925999999997	Новая	0103000020E610000001000000050000005308E41247DD5D400D17B9A7ABD749405308E41247DD5D4072FA7ABE66D949405DF92CCF83DE5D4072FA7ABE66D949405DF92CCF83DE5D400D17B9A7ABD749405308E41247DD5D400D17B9A7ABD74940
73917	60150	119.89469099999999	119.904968	51.357270999999997	51.347911000000003	Набережная	0103000020E61000000100000005000000A2410A9E42F95D409775FF5888AC4940A2410A9E42F95D4094675E0EBBAD49404CFBE6FEEAF95D4094675E0EBBAD49404CFBE6FEEAF95D409775FF5888AC4940A2410A9E42F95D409775FF5888AC4940
67802	59106	119.57953500000001	119.63465600000001	51.317494000000003	51.299624000000001	Булгаковой	0103000020E61000000100000005000000CBF8F71917E55D40618C48145AA64940CBF8F71917E55D408F56B5A4A3A84940740D33349EE85D408F56B5A4A3A84940740D33349EE85D40618C48145AA64940CBF8F71917E55D40618C48145AA64940
73840	22247	119.42029100000001	119.440539	51.124243999999997	51.106931000000003	Перфильева	0103000020E6100000010000000500000067F3380CE6DA5D40DCF63DEAAF8D494067F3380CE6DA5D40B35C363AE78F494034677DCA31DC5D40B35C363AE78F494034677DCA31DC5D40DCF63DEAAF8D494067F3380CE6DA5D40DCF63DEAAF8D4940
73884	22247	119.42029100000001	119.440539	51.124243999999997	51.106931000000003	Молодежная	0103000020E6100000010000000500000067F3380CE6DA5D40DCF63DEAAF8D494067F3380CE6DA5D40B35C363AE78F494034677DCA31DC5D40B35C363AE78F494034677DCA31DC5D40DCF63DEAAF8D494067F3380CE6DA5D40DCF63DEAAF8D4940
73876	60133	119.96457100000001	119.97377	51.486497999999997	51.475729000000001	Центральная	0103000020E61000000100000005000000E2EA0088BBFD5D40206118B0E4BC4940E2EA0088BBFD5D40E2C8039145BE4940DCF4673F52FE5D40E2C8039145BE4940DCF4673F52FE5D40206118B0E4BC4940E2EA0088BBFD5D40206118B0E4BC4940
28475	51872	119.45070800000001	119.478071	51.265416000000002	51.253641999999999	Молодежная	0103000020E61000000100000005000000EB025E66D8DC5D402E724F5777A04940EB025E66D8DC5D40E6EAC726F9A14940A08A1BB798DE5D40E6EAC726F9A14940A08A1BB798DE5D402E724F5777A04940EB025E66D8DC5D402E724F5777A04940
73968	51872	119.45070800000001	119.478071	51.265416000000002	51.253641999999999	Конторская	0103000020E61000000100000005000000EB025E66D8DC5D402E724F5777A04940EB025E66D8DC5D40E6EAC726F9A14940A08A1BB798DE5D40E6EAC726F9A14940A08A1BB798DE5D402E724F5777A04940EB025E66D8DC5D402E724F5777A04940
27688	51725	119.503969	119.535725	51.224314	51.196711000000001	Пушкина	0103000020E61000000100000005000000A94C310741E05D40B9E177D32D994940A94C310741E05D4079043752B69C494093A9825149E25D4079043752B69C494093A9825149E25D40B9E177D32D994940A94C310741E05D40B9E177D32D994940
73952	60168	119.749245	119.771038	51.233383000000003	51.225284000000002	Центральная	0103000020E6100000010000000500000042EC4CA1F3EF5D40F2272A1BD69C494042EC4CA1F3EF5D40A038807EDF9D49404A7EC4AF58F15D40A038807EDF9D49404A7EC4AF58F15D40F2272A1BD69C494042EC4CA1F3EF5D40F2272A1BD69C4940
73995	60187	119.43525699999999	119.451831	51.372093999999997	51.365673000000001	Клубная	0103000020E61000000100000005000000B9162D40DBDB5D40DE03745FCEAE4940B9162D40DBDB5D40D784B4C6A0AF49406A1492CCEADC5D40D784B4C6A0AF49406A1492CCEADC5D40DE03745FCEAE4940B9162D40DBDB5D40DE03745FCEAE4940
73990	60185	119.652497	119.671559	51.027718	51.015411999999998	Солнечная	0103000020E610000001000000050000003DEFC682C2E95D40A4FB3905F98149403DEFC682C2E95D4059C16F438C834940689599D2FAEA5D4059C16F438C834940689599D2FAEA5D40A4FB3905F98149403DEFC682C2E95D40A4FB3905F9814940
76429	60185	119.652497	119.671559	51.027718	51.015411999999998	Верхняя	0103000020E610000001000000050000003DEFC682C2E95D40A4FB3905F98149403DEFC682C2E95D4059C16F438C834940689599D2FAEA5D4059C16F438C834940689599D2FAEA5D40A4FB3905F98149403DEFC682C2E95D40A4FB3905F9814940
73933	60103	119.20601600000001	119.23614499999999	51.372329999999998	51.358187000000001	Центральная	0103000020E61000000100000005000000FA9CBB5D2FCD5D401A6D5512D9AD4940FA9CBB5D2FCD5D40EBA86A82A8AF49404A07EBFF1CCF5D40EBA86A82A8AF49404A07EBFF1CCF5D401A6D5512D9AD4940FA9CBB5D2FCD5D401A6D5512D9AD4940
73796	60103	119.20601600000001	119.23614499999999	51.372329999999998	51.358187000000001	Советский переулок	0103000020E61000000100000005000000FA9CBB5D2FCD5D401A6D5512D9AD4940FA9CBB5D2FCD5D40EBA86A82A8AF49404A07EBFF1CCF5D40EBA86A82A8AF49404A07EBFF1CCF5D401A6D5512D9AD4940FA9CBB5D2FCD5D401A6D5512D9AD4940
24108	50685	120.007277	120.02704900000001	51.583879000000003	51.571452999999998	Сурина	0103000020E61000000100000005000000D540F33977005E40BD19355F25C94940D540F33977005E401DE90C8CBCCA4940EE98BA2BBB015E401DE90C8CBCCA4940EE98BA2BBB015E40BD19355F25C94940D540F33977005E40BD19355F25C94940
27661	50685	120.007277	120.02704900000001	51.583879000000003	51.571452999999998	Советская	0103000020E61000000100000005000000D540F33977005E40BD19355F25C94940D540F33977005E401DE90C8CBCCA4940EE98BA2BBB015E401DE90C8CBCCA4940EE98BA2BBB015E40BD19355F25C94940D540F33977005E40BD19355F25C94940
23386	50685	120.007277	120.02704900000001	51.583879000000003	51.571452999999998	Дорожная	0103000020E61000000100000005000000D540F33977005E40BD19355F25C94940D540F33977005E401DE90C8CBCCA4940EE98BA2BBB015E401DE90C8CBCCA4940EE98BA2BBB015E40BD19355F25C94940D540F33977005E40BD19355F25C94940
73820	60113	115.837998	117.08119499999999	52.906894999999999	51.567495999999998	Тетерина-Петрова	0103000020E6100000010000000500000042075DC2A1F55C402F4E7CB5A3C8494042075DC2A1F55C40F5F3A62215744A405166834C32455D40F5F3A62215744A405166834C32455D402F4E7CB5A3C8494042075DC2A1F55C402F4E7CB5A3C84940
24078	22335	116.695126	116.713092	51.922747999999999	51.912709999999997	Верхняя	0103000020E610000001000000050000005B26C3F17C2C5D40B75D68AED3F449405B26C3F17C2C5D408639419B1CF6494083C2A04CA32D5D408639419B1CF6494083C2A04CA32D5D40B75D68AED3F449405B26C3F17C2C5D40B75D68AED3F44940
27539	22451	116.50122500000001	116.52211	51.875321999999997	51.860446000000003	Центральная,	0103000020E6100000010000000500000002BC051214205D40ADFC321823EE494002BC051214205D4012BC218D0AF0494088BA0F406A215D4012BC218D0AF0494088BA0F406A215D40ADFC321823EE494002BC051214205D40ADFC321823EE4940
67996	22181	116.61205	116.63369899999999	51.929606999999997	51.911087999999999	Центральная	0103000020E610000001000000050000001361C3D32B275D4097E315889EF449401361C3D32B275D40FB90B75CFDF64940812040868E285D40FB90B75CFDF64940812040868E285D4097E315889EF449401361C3D32B275D4097E315889EF44940
27634	21796	116.347092	116.36345900000001	52.079774999999998	52.068344000000003	Центральная	0103000020E61000000100000005000000022D5DC136165D405D70067FBF084A40022D5DC136165D40EA043411360A4A40F69B89E942175D40EA043411360A4A40F69B89E942175D405D70067FBF084A40022D5DC136165D405D70067FBF084A40
27544	22470	116.44156700000001	116.479782	51.830055999999999	51.815297999999999	Центральная	0103000020E610000001000000050000008BFF3BA2421C5D40423F53AF5BE849408BFF3BA2421C5D409EEC66463FEA494068CD8FBFB41E5D409EEC66463FEA494068CD8FBFB41E5D40423F53AF5BE849408BFF3BA2421C5D40423F53AF5BE84940
27700	21457	116.19628299999999	116.221858	52.407814000000002	52.383606999999998	Рабочая	0103000020E61000000100000005000000B07092E68F0C5D4022C2BF081A314A40B07092E68F0C5D40EC6CC83F33344A40C896E5EB320E5D40EC6CC83F33344A40C896E5EB320E5D4022C2BF081A314A40B07092E68F0C5D4022C2BF081A314A40
73737	21524	116.046623	116.08575399999999	52.372886999999999	52.360568999999998	Молодёжная	0103000020E61000000100000005000000730F09DFFB025D40C879FF1F272E4A40730F09DFFB025D40410DDFC2BA2F4A40136058FE7C055D40410DDFC2BA2F4A40136058FE7C055D40C879FF1F272E4A40730F09DFFB025D40C879FF1F272E4A40
73828	22109	116.80808	116.833377	51.995572000000003	51.973396999999999	Советская	0103000020E610000001000000050000004F232D95B7335D402383DC4598FC49404F232D95B7335D401B683EE76EFF4940450F7C0C56355D401B683EE76EFF4940450F7C0C56355D402383DC4598FC49404F232D95B7335D402383DC4598FC4940
73676	40367	116.5086	116.610891	52.007510000000003	51.924886000000001	Студгородок	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
27155	40367	116.5086	116.610891	52.007510000000003	51.924886000000001	Советская	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
9958	40367	116.5086	116.610891	52.007510000000003	51.924886000000001	Рабочая	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
23611	40367	116.5086	116.610891	52.007510000000003	51.924886000000001	Пушкинская	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
73804	40367	116.5086	116.610891	52.007510000000003	51.924886000000001	Первомайская	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
27188	40367	116.5086	116.610891	52.007510000000003	51.924886000000001	Достовалова	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
24166	40367	116.5086	116.610891	52.007510000000003	51.924886000000001	Дорожная	0103000020E61000000100000005000000B8AF03E78C205D409E4319AA62F64940B8AF03E78C205D404D327216F6004A40ED9A90D618275D404D327216F6004A40ED9A90D618275D409E4319AA62F64940B8AF03E78C205D409E4319AA62F64940
73889	60138	116.55736	116.57408700000001	52.021134000000004	52.015791	Октябрьская	0103000020E610000001000000050000004F0647C9AB235D401B49827005024A404F0647C9AB235D40B66AD784B4024A40C38366D7BD245D40B66AD784B4024A40C38366D7BD245D401B49827005024A404F0647C9AB235D401B49827005024A40
73947	21851	116.367825	116.38342	52.066682999999998	52.051611000000001	Набережная	0103000020E61000000100000005000000AD69DE718A175D40938E72309B064A40AD69DE718A175D407E198C1189084A4078280AF489185D407E198C1189084A4078280AF489185D40938E72309B064A40AD69DE718A175D40938E72309B064A40
73880	21404	116.17139899999999	116.18362500000001	52.481395999999997	52.468747	Советская	0103000020E610000001000000050000004BE48233F80A5D408F8CD5E6FF3B4A404BE48233F80A5D406D3656629E3D4A40986E1283C00B5D406D3656629E3D4A40986E1283C00B5D408F8CD5E6FF3B4A404BE48233F80A5D408F8CD5E6FF3B4A40
73829	21692	116.32179499999999	116.336932	52.250034999999997	52.239700999999997	Центральная	0103000020E610000001000000050000000B410E4A98145D40C4E8B985AE1E4A400B410E4A98145D407CED992501204A40753E3C4B90155D407CED992501204A40753E3C4B90155D40C4E8B985AE1E4A400B410E4A98145D40C4E8B985AE1E4A40
24065	22268	116.644542	116.671375	51.905399000000003	51.893994999999997	Новая	0103000020E6100000010000000500000080B9162D40295D40CDE49B6D6EF2494080B9162D40295D40626A4B1DE4F349408716D9CEF72A5D40626A4B1DE4F349408716D9CEF72A5D40CDE49B6D6EF2494080B9162D40295D40CDE49B6D6EF24940
73789	21539	116.029268	116.075181	52.214810999999997	52.205556999999999	Советская	0103000020E6100000010000000500000070B4E386DF015D40603B18B14F1A4A4070B4E386DF015D4018E945ED7E1B4A40F511F8C3CF045D4018E945ED7E1B4A40F511F8C3CF045D40603B18B14F1A4A4070B4E386DF015D40603B18B14F1A4A40
27699	21304	116.188602	116.220636	52.544758000000002	52.519804999999998	К-Маркса	0103000020E61000000100000005000000747D1F0E120C5D400DA661F888424A40747D1F0E120C5D40001E51A1BA454A407F1475E61E0E5D40001E51A1BA454A407F1475E61E0E5D400DA661F888424A40747D1F0E120C5D400DA661F888424A40
27717	21604	116.27474100000001	116.30527499999999	52.198669000000002	52.168447999999998	Школьная	0103000020E61000000100000005000000B477465B95115D40CE893DB48F154A40B477465B95115D4051DD5CFC6D194A40545227A089135D4051DD5CFC6D194A40545227A089135D40CE893DB48F154A40B477465B95115D40CE893DB48F154A40
27095	51479	116.493149	116.522649	52.035668999999999	52.025489999999998	Набережная	0103000020E6100000010000000500000087C3D2C08F1F5D4001309E4143034A4087C3D2C08F1F5D40923D42CD90044A406092CA1473215D40923D42CD90044A406092CA1473215D4001309E4143034A4087C3D2C08F1F5D4001309E4143034A40
23579	22024	116.540921	116.54631999999999	52.142606000000001	52.134171000000002	Центральная	0103000020E610000001000000050000000E2E1D739E225D402B89EC832C114A400E2E1D739E225D40501BD5E940124A40A54929E8F6225D40501BD5E940124A40A54929E8F6225D402B89EC832C114A400E2E1D739E225D402B89EC832C114A40
24604	22125	116.75785500000001	116.770477	51.971333000000001	51.958663999999999	Центральная	0103000020E610000001000000050000000C0742B280305D4020ED7F80B5FA49400C0742B280305D404643C6A354FC49407E54C37E4F315D404643C6A354FC49407E54C37E4F315D4020ED7F80B5FA49400C0742B280305D4020ED7F80B5FA4940
24404	51023	116.420682	116.462166	51.859555999999998	51.849805000000003	Набережная	0103000020E6100000010000000500000004013274EC1A5D40187D0569C6EC494004013274EC1A5D40508A56EE05EE4940AED4B320941D5D40508A56EE05EE4940AED4B320941D5D40187D0569C6EC494004013274EC1A5D40187D0569C6EC4940
74052	21765	116.443292	116.46557	52.160283	52.149619000000001	Казанушка	0103000020E6100000010000000500000005A568E55E1C5D401CEE23B726134A4005A568E55E1C5D40698D412784144A40EBFF1CE6CB1D5D40698D412784144A40EBFF1CE6CB1D5D401CEE23B726134A4005A568E55E1C5D401CEE23B726134A40
27074	21625	116.271795	116.28323899999999	52.176152000000002	52.165177	Центральная	0103000020E61000000100000005000000D80DDB1665115D4094861A8524154A40D80DDB1665115D40009013268C164A40E97C789620125D40009013268C164A40E97C789620125D4094861A8524154A40D80DDB1665115D4094861A8524154A40
73861	60129	116.303371	116.324849	51.732871000000003	51.722434	Луговая	0103000020E6100000010000000500000082E3326E6A135D405DC2A1B778DC494082E3326E6A135D40EA9788B7CEDD4940DAC87553CA145D40EA9788B7CEDD4940DAC87553CA145D405DC2A1B778DC494082E3326E6A135D405DC2A1B778DC4940
73983	21066	119.21199	119.227791	53.786715000000001	53.777835000000003	Набережная	0103000020E610000001000000050000000F45813E91CD5D409357E71890E34A400F45813E91CD5D40E622BE13B3E44A40AED4B32094CE5D40E622BE13B3E44A40AED4B32094CE5D409357E71890E34A400F45813E91CD5D409357E71890E34A40
28547	20992	120.038404	120.078154	53.689112999999999	53.676676	Школьная	0103000020E6100000010000000500000047020D3675025E407AFEB4519DD64A4047020D3675025E40CD1FD3DA34D84A404D83A27900055E40CD1FD3DA34D84A404D83A27900055E407AFEB4519DD64A4047020D3675025E407AFEB4519DD64A40
73791	20928	120.349535	120.379907	53.718162999999997	53.701396000000003	Советская	0103000020E61000000100000005000000AC730CC85E165E40CAC51858C7D94A40AC730CC85E165E403F19E3C3ECDB4A406021736550185E403F19E3C3ECDB4A406021736550185E40CAC51858C7D94A40AC730CC85E165E40CAC51858C7D94A40
67201	21235	118.49604100000001	118.532235	53.325487000000003	53.303888000000001	Центральная	0103000020E61000000100000005000000691EC022BF9F5D40CCD24ECDE5A64A40691EC022BF9F5D40F722DA8EA9A94A4057B2632310A25D40F722DA8EA9A94A4057B2632310A25D40CCD24ECDE5A64A40691EC022BF9F5D40CCD24ECDE5A64A40
73777	20325	119.725898	119.802318	53.768208999999999	53.715834000000001	Шулешко	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
67382	20325	119.725898	119.802318	53.768208999999999	53.715834000000001	Советская	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
73741	20325	119.725898	119.802318	53.768208999999999	53.715834000000001	Промышленная	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
37931	20325	119.725898	119.802318	53.768208999999999	53.715834000000001	Красноармейская	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
67993	20325	119.725898	119.802318	53.768208999999999	53.715834000000001	Комсомольская	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
67190	20325	119.725898	119.802318	53.768208999999999	53.715834000000001	Клубная	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
67193	20325	119.725898	119.802318	53.768208999999999	53.715834000000001	Березовая	0103000020E61000000100000005000000D68EE21C75EE5D40B4AED172A0DB4A40D68EE21C75EE5D4016BF29AC54E24A407FBF982D59F35D4016BF29AC54E24A407FBF982D59F35D40B4AED172A0DB4A40D68EE21C75EE5D40B4AED172A0DB4A40
73881	20821	119.285481	119.310957	53.472563000000001	53.456690000000002	Школьная	0103000020E6100000010000000500000048A8195245D25D40833463D174BA4A4048A8195245D25D405B26C3F17CBC4A40965D30B8E6D35D405B26C3F17CBC4A40965D30B8E6D35D40833463D174BA4A4048A8195245D25D40833463D174BA4A40
73803	60059	118.698836	118.749843	53.569963000000001	53.545321000000001	Приисковая	0103000020E610000001000000050000001E51A1BAB9AC5D4038691A14CDC54A401E51A1BAB9AC5D400C772E8CF4C84A409C887E6DFDAF5D400C772E8CF4C84A409C887E6DFDAF5D4038691A14CDC54A401E51A1BAB9AC5D4038691A14CDC54A40
73675	60058	118.698836	118.749843	53.569963000000001	53.545321000000001	Камерона	0103000020E610000001000000050000001E51A1BAB9AC5D4038691A14CDC54A401E51A1BAB9AC5D400C772E8CF4C84A409C887E6DFDAF5D400C772E8CF4C84A409C887E6DFDAF5D4038691A14CDC54A401E51A1BAB9AC5D4038691A14CDC54A40
27679	20886	119.430352	119.476418	53.544004999999999	53.527158	Школьная	0103000020E610000001000000050000002A711DE38ADB5D4092E9D0E979C34A402A711DE38ADB5D4024EEB1F4A1C54A40724EECA17DDE5D4024EEB1F4A1C54A40724EECA17DDE5D4092E9D0E979C34A402A711DE38ADB5D4092E9D0E979C34A40
73776	60094	119.29851600000001	119.333505	53.561824000000001	53.528727000000003	Октябрьская	0103000020E610000001000000050000004C55DAE21AD35D4090C18A53ADC34A404C55DAE21AD35D40D00D4DD9E9C74A405C035B2558D55D40D00D4DD9E9C74A405C035B2558D55D4090C18A53ADC34A404C55DAE21AD35D4090C18A53ADC34A40
67199	58993	120.83926099999999	120.89162399999999	53.87574	53.847085999999997	Клубная	0103000020E61000000100000005000000BAF3C473B6355E40217365506DEC4A40BAF3C473B6355E4047E6913F18F04A4009151C5E10395E4047E6913F18F04A4009151C5E10395E40217365506DEC4A40BAF3C473B6355E40217365506DEC4A40
67408	59059	114.902789	114.954487	51.302219999999998	51.259993999999999	Гагарина	0103000020E61000000100000005000000118C834BC7B95C40FF93BF7B47A14940118C834BC7B95C403B191C25AFA64940425DA45016BD5C403B191C25AFA64940425DA45016BD5C40FF93BF7B47A14940118C834BC7B95C40FF93BF7B47A14940
34031	54089	114.902789	114.954487	51.302219999999998	51.259993999999999	переулок Черемушки	0103000020E61000000100000005000000118C834BC7B95C40FF93BF7B47A14940118C834BC7B95C403B191C25AFA64940425DA45016BD5C403B191C25AFA64940425DA45016BD5C40FF93BF7B47A14940118C834BC7B95C40FF93BF7B47A14940
73681	51842	114.902789	114.954487	51.302219999999998	51.259993999999999	Ленина	0103000020E61000000100000005000000118C834BC7B95C40FF93BF7B47A14940118C834BC7B95C403B191C25AFA64940425DA45016BD5C403B191C25AFA64940425DA45016BD5C40FF93BF7B47A14940118C834BC7B95C40FF93BF7B47A14940
73560	51842	114.902789	114.954487	51.302219999999998	51.259993999999999	Зугалайская	0103000020E61000000100000005000000118C834BC7B95C40FF93BF7B47A14940118C834BC7B95C403B191C25AFA64940425DA45016BD5C403B191C25AFA64940425DA45016BD5C40FF93BF7B47A14940118C834BC7B95C40FF93BF7B47A14940
73816	60109	112.75494399999999	112.77335100000001	49.864193999999998	49.848415000000003	Богомолова	0103000020E61000000100000005000000EE93A30051305C40CA37DBDC98EC4840EE93A30051305C4020B3B3E89DEE48400D5531957E315C4020B3B3E89DEE48400D5531957E315C40CA37DBDC98EC4840EE93A30051305C40CA37DBDC98EC4840
73842	51002	112.388881	112.416837	49.574584999999999	49.556075	Молодежная	0103000020E610000001000000050000004A42226DE3185C40C58F31772DC748404A42226DE3185C40D6E253008CC94840D1B01875AD1A5C40D6E253008CC94840D1B01875AD1A5C40C58F31772DC748404A42226DE3185C40C58F31772DC74840
73988	60184	112.50238299999999	112.525937	49.739769000000003	49.732717999999998	Пионерская	0103000020E610000001000000050000003FC4060B27205C40639813B4C9DD48403FC4060B27205C401DCC26C0B0DE484068B0A9F3A8215C401DCC26C0B0DE484068B0A9F3A8215C40639813B4C9DD48403FC4060B27205C40639813B4C9DD4840
73869	60132	112.002156	112.05725	49.704546000000001	49.683667	Центральная	0103000020E610000001000000050000005F5FEB5223005C405E2D776682D748405F5FEB5223005C40894336902EDA48408B6CE7FBA9035C40894336902EDA48408B6CE7FBA9035C405E2D776682D748405F5FEB5223005C405E2D776682D74840
73974	60178	109.36179199999999	113.30949200000001	50.393596000000002	49.154963000000002	Дзержинского	0103000020E6100000010000000500000015FDA19927575B40878BDCD3D593484015FDA19927575B4010EB8D5A61324940EA9788B7CE535C4010EB8D5A61324940EA9788B7CE535C40878BDCD3D593484015FDA19927575B40878BDCD3D5934840
27082	51472	112.657405	112.689269	49.706083999999997	49.685811000000001	Колхозная	0103000020E6100000010000000500000085CE6BEC122A5C40581EA4A7C8D7484085CE6BEC122A5C404B1DE4F560DA48406249B9FB1C2C5C404B1DE4F560DA48406249B9FB1C2C5C40581EA4A7C8D7484085CE6BEC122A5C40581EA4A7C8D74840
73583	60043	112.14116199999999	112.163296	49.647773000000001	49.632716000000002	Клубная	0103000020E61000000100000005000000075C57CC08095C40F6D37FD6FCD04840075C57CC08095C40AC1DC539EAD2484054E41071730A5C40AC1DC539EAD2484054E41071730A5C40F6D37FD6FCD04840075C57CC08095C40F6D37FD6FCD04840
67520	51591	111.951842	111.98969700000001	49.587842999999999	49.570144999999997	Профсоюзная	0103000020E61000000100000005000000643DB5FAEAFC5B402C7DE882FAC84840643DB5FAEAFC5B405D177E703ECB4840C2FC153257FF5B405D177E703ECB4840C2FC153257FF5B402C7DE882FAC84840643DB5FAEAFC5B402C7DE882FAC84840
27289	51591	111.951842	111.98969700000001	49.587842999999999	49.570144999999997	Горького	0103000020E61000000100000005000000643DB5FAEAFC5B402C7DE882FAC84840643DB5FAEAFC5B405D177E703ECB4840C2FC153257FF5B405D177E703ECB4840C2FC153257FF5B402C7DE882FAC84840643DB5FAEAFC5B402C7DE882FAC84840
73779	51591	111.951842	111.98969700000001	49.587842999999999	49.570144999999997	Балуева	0103000020E61000000100000005000000643DB5FAEAFC5B402C7DE882FAC84840643DB5FAEAFC5B405D177E703ECB4840C2FC153257FF5B405D177E703ECB4840C2FC153257FF5B402C7DE882FAC84840643DB5FAEAFC5B402C7DE882FAC84840
74043	60213	112.161266	112.182259	49.473728000000001	49.458967999999999	Новая	0103000020E610000001000000050000003BFDA02E520A5C408CF4A276BFBA48403BFDA02E520A5C4089997D1EA3BC4840B519A721AA0B5C4089997D1EA3BC4840B519A721AA0B5C408CF4A276BFBA48403BFDA02E520A5C408CF4A276BFBA4840
73787	60097	112.530204	112.55285000000001	49.595388	49.565365	Ленина	0103000020E61000000100000005000000560DC2DCEE215C40CAA65CE15DC84840560DC2DCEE215C4026378AAC35CC4840FE65F7E461235C4026378AAC35CC4840FE65F7E461235C40CAA65CE15DC84840560DC2DCEE215C40CAA65CE15DC84840
73721	51588	111.68130499999999	111.701427	49.592526999999997	49.579883000000002	Пионерская	0103000020E610000001000000050000007B6649809AEB5B40D1402C9B39CA48407B6649809AEB5B409D7FBBECD7CB48400262122EE4EC5B409D7FBBECD7CB48400262122EE4EC5B40D1402C9B39CA48407B6649809AEB5B40D1402C9B39CA4840
27182	51523	111.519204	111.551885	49.521554000000002	49.502806999999997	Трактовая	0103000020E61000000100000005000000F4FC69A33AE15B409599D2FA5BC04840F4FC69A33AE15B408B8C0E48C2C24840CA89761552E35B408B8C0E48C2C24840CA89761552E35B409599D2FA5BC04840F4FC69A33AE15B409599D2FA5BC04840
27630	51714	110.243444	110.253702	50.619858000000001	50.611055999999998	Центральная	0103000020E61000000100000005000000139A2496948F5B4025034015374E4940139A2496948F5B40FD14C781574F4940823B50A73C905B40FD14C781574F4940823B50A73C905B4025034015374E4940139A2496948F5B4025034015374E4940
73835	52148	110.335566	110.348457	50.608541000000002	50.600200000000001	Центральная	0103000020E6100000010000000500000092E9D0E979955B409487855AD34C494092E9D0E979955B4038A3E6ABE44D4940FCC3961E4D965B4038A3E6ABE44D4940FCC3961E4D965B409487855AD34C494092E9D0E979955B409487855AD34C4940
74015	52194	108.469055	108.487776	50.302166	50.290272000000002	Советская	0103000020E610000001000000050000009E4143FF041E5B40E67805A2272549409E4143FF041E5B4048FB1F60AD26494084F1D3B8371F5B4048FB1F60AD26494084F1D3B8371F5B40E67805A2272549409E4143FF041E5B40E67805A227254940
73900	60142	109.549684	109.607814	50.567439	50.553037000000003	Центральная	0103000020E610000001000000050000009BC8CC052E635B402E3D9AEAC94649409BC8CC052E635B40CBBC55D7A14849404303B16CE6665B40CBBC55D7A14849404303B16CE6665B402E3D9AEAC94649409BC8CC052E635B402E3D9AEAC9464940
27536	51698	110.12986100000001	110.186832	50.585607000000003	50.573881	Центральная	0103000020E61000000100000005000000A80183A44F885B40DC65BFEE74494940A80183A44F885B4083A7902BF54A49402976340EF58B5B4083A7902BF54A49402976340EF58B5B40DC65BFEE74494940A80183A44F885B40DC65BFEE74494940
73819	50737	108.070994	108.109801	49.928716999999999	49.911340000000003	Набережная	0103000020E61000000100000005000000950D6B2A8B045B40B1C403CAA6F44840950D6B2A8B045B409F1EDB32E0F648405C04C6FA06075B409F1EDB32E0F648405C04C6FA06075B40B1C403CAA6F44840950D6B2A8B045B40B1C403CAA6F44840
74010	52169	109.254623	109.273568	50.513227000000001	50.503317000000003	Центральная	0103000020E61000000100000005000000CD7344BE4B505B40AB4203B16C404940CD7344BE4B505B404C361E6CB1414940DB4E5B2382515B404C361E6CB1414940DB4E5B2382515B40AB4203B16C404940CD7344BE4B505B40AB4203B16C404940
73971	52213	107.79934299999999	107.812692	49.947983000000001	49.938319	Вторая	0103000020E6100000010000000500000056D28A6F28F35A40931B45D61AF8484056D28A6F28F35A40FD14C78157F94840226E4E2503F45A40FD14C78157F94840226E4E2503F45A40931B45D61AF8484056D28A6F28F35A40931B45D61AF84840
28022	51797	107.84834600000001	107.94751100000001	50.075611000000002	50.038150999999999	Школьная	0103000020E61000000100000005000000516C054D4BF65A40A4A7C821E2044940516C054D4BF65A40E31B0A9FAD0949406B662D05A4FC5A40E31B0A9FAD0949406B662D05A4FC5A40A4A7C821E2044940516C054D4BF65A40A4A7C821E2044940
73911	52160	109.44672799999999	109.47666	50.561185999999999	50.552373000000003	Центральная	0103000020E61000000100000005000000478D0931975C5B40C2189128B4464940478D0931975C5B408D7C5EF1D4474940EDD3F198815E5B408D7C5EF1D4474940EDD3F198815E5B40C2189128B4464940478D0931975C5B40C2189128B4464940
27684	51724	108.232331	108.261625	50.111382999999996	50.075611000000002	Центральная	0103000020E6100000010000000500000035B6D782DE0E5B40E31B0A9FAD09494035B6D782DE0E5B40492A53CC410E494039B4C876BE105B40492A53CC410E494039B4C876BE105B40E31B0A9FAD09494035B6D782DE0E5B40E31B0A9FAD094940
28253	51834	108.80470200000001	108.875013	50.413122000000001	50.386330999999998	Центральная	0103000020E61000000100000005000000A741D13C80335B402A37514B73314940A741D13C80335B400AA1832EE1344940CAA4863600385B400AA1832EE1344940CAA4863600385B402A37514B73314940A741D13C80335B402A37514B73314940
67311	59029	108.72089800000001	108.779854	50.388357999999997	50.348672999999998	Первомайская	0103000020E610000001000000050000001E705D31232E5B40C5FF1D51A12C49401E705D31232E5B40EA9106B7B5314940E869C020E9315B40EA9106B7B5314940E869C020E9315B40C5FF1D51A12C49401E705D31232E5B40C5FF1D51A12C4940
28386	51856	107.73453000000001	111.145595	50.796799	49.316797999999999	Первомайская	0103000020E6100000010000000500000094FB1D8A02EF5A4017B83CD68CA8484094FB1D8A02EF5A40253E7782FD65494083DDB06D51C95B40253E7782FD65494083DDB06D51C95B4017B83CD68CA8484094FB1D8A02EF5A4017B83CD68CA84840
28535	51891	108.938838	108.997094	50.449706999999997	50.433563999999997	Советская	0103000020E610000001000000050000007E8FFAEB153C5B40895C70067F3749407E8FFAEB153C5B4021E4BCFF8F3949406C425A63D03F5B4021E4BCFF8F3949406C425A63D03F5B40895C70067F3749407E8FFAEB153C5B40895C70067F374940
73805	60106	109.363598	109.405486	50.547272999999997	50.528672999999998	Центральная	0103000020E6100000010000000500000006B98B3045575B409CA38E8EAB43494006B98B3045575B40ED7DAA0A0D464940183F8D7BF3595B40ED7DAA0A0D464940183F8D7BF3595B409CA38E8EAB43494006B98B3045575B409CA38E8EAB434940
23894	50858	108.045931	108.062307	50.083212000000003	50.067031	Транспортная	0103000020E61000000100000005000000D8B79388F0025B40BA68C87894084940D8B79388F0025B404051D9B0A60A4940F6D37FD6FC035B404051D9B0A60A4940F6D37FD6FC035B40BA68C87894084940D8B79388F0025B40BA68C87894084940
73898	60141	107.956198	107.974209	49.947448999999999	49.941107000000002	Советская	0103000020E610000001000000050000000AA0185932FD5A40B284B53176F848400AA0185932FD5A405FD0420246F94840029EB47059FE5A405FD0420246F94840029EB47059FE5A40B284B53176F848400AA0185932FD5A40B284B53176F84840
73878	52208	108.185664	108.209236	50.007477000000002	49.982761000000004	Центральная	0103000020E61000000100000005000000DA0242EBE10B5B406364C91CCBFD4840DA0242EBE10B5B40713C9F01F50049405649641F640D5B40713C9F01F50049405649641F640D5B406364C91CCBFD4840DA0242EBE10B5B406364C91CCBFD4840
27595	51707	108.31963	108.328181	50.204731000000002	50.179904000000001	Центральная	0103000020E61000000100000005000000833463D174145B40B535221807174940833463D174145B401BBD1AA0341A4940CA8AE1EA00155B401BBD1AA0341A4940CA8AE1EA00155B40B535221807174940833463D174145B40B535221807174940
73961	52175	109.00848499999999	109.03052	50.423240999999997	50.414121000000002	Заречная	0103000020E610000001000000050000006B60AB048B405B401DCBBBEA013549406B60AB048B405B40C5A9D6C22C364940EE77280AF4415B40C5A9D6C22C364940EE77280AF4415B401DCBBBEA013549406B60AB048B405B401DCBBBEA01354940
73964	52198	108.25550800000001	108.273411	50.185550999999997	50.174360999999998	Новая	0103000020E6100000010000000500000073F7393E5A105B40535914765116494073F7393E5A105B40BB5E9A22C017494077D7D9907F115B40BB5E9A22C017494077D7D9907F115B40535914765116494073F7393E5A105B405359147651164940
73726	60070	108.45457399999999	108.477401	50.137002000000003	50.127341000000001	Советская	0103000020E6100000010000000500000029E78BBD171D5B405038BBB54C10494029E78BBD171D5B4049BE124889114940F984ECBC8D1E5B4049BE124889114940F984ECBC8D1E5B405038BBB54C10494029E78BBD171D5B405038BBB54C104940
73962	52179	108.87340500000001	108.94296199999999	50.437407999999998	50.407083	Октябрьская	0103000020E610000001000000050000006DCA15DEE5375B40F8E0B54B1B3449406DCA15DEE5375B401F813FFCFC374940BAD7497D593C5B401F813FFCFC374940BAD7497D593C5B40F8E0B54B1B3449406DCA15DEE5375B40F8E0B54B1B344940
27582	51706	108.568804	108.599428	50.300013999999997	50.292406999999997	Центральная	0103000020E610000001000000050000006075E44867245B408C0FB3976D2549406075E44867245B40CB2BD7DB66264940A11342075D265B40CB2BD7DB66264940A11342075D265B408C0FB3976D2549406075E44867245B408C0FB3976D254940
73908	52164	109.53804100000001	109.562116	50.49926	50.476101	Горная	0103000020E610000001000000050000000FBA84436F625B40E44BA8E0F03C49400FBA84436F625B40B9196EC0E73F4940BC2363B5F9635B40B9196EC0E73F4940BC2363B5F9635B40E44BA8E0F03C49400FBA84436F625B40E44BA8E0F03C4940
24425	51027	110.100728	110.126124	50.576735999999997	50.568424	Шоссейная	0103000020E61000000100000005000000A872DA5372865B4079211D1EC2484940A872DA5372865B408236397CD249494068CF656A12885B408236397CD249494068CF656A12885B4079211D1EC2484940A872DA5372865B4079211D1EC2484940
27899	51763	107.73453000000001	111.145595	50.796799	49.316797999999999	Колхозная	0103000020E6100000010000000500000094FB1D8A02EF5A4017B83CD68CA8484094FB1D8A02EF5A40253E7782FD65494083DDB06D51C95B40253E7782FD65494083DDB06D51C95B4017B83CD68CA8484094FB1D8A02EF5A4017B83CD68CA84840
28558	51900	108.217096	108.24445	50.148935000000002	50.129939999999998	Адрияновская	0103000020E61000000100000005000000EA059FE6E40D5B409B38B9DFA1104940EA059FE6E40D5B40691D554D1013494076E09C11A50F5B40691D554D1013494076E09C11A50F5B409B38B9DFA1104940EA059FE6E40D5B409B38B9DFA1104940
73923	52183	107.73453000000001	111.145595	50.796799	49.316797999999999	Центральная	0103000020E6100000010000000500000094FB1D8A02EF5A4017B83CD68CA8484094FB1D8A02EF5A40253E7782FD65494083DDB06D51C95B40253E7782FD65494083DDB06D51C95B4017B83CD68CA8484094FB1D8A02EF5A4017B83CD68CA84840
28553	51899	114.77446500000001	114.816749	51.783673999999998	51.752054999999999	Центральная	0103000020E6100000010000000500000063B9A5D590B15C408AE5965643E0494063B9A5D590B15C40DD5CFC6D4FE449409B02999D45B45C40DD5CFC6D4FE449409B02999D45B45C408AE5965643E0494063B9A5D590B15C408AE5965643E04940
67358	51899	114.77446500000001	114.816749	51.783673999999998	51.752054999999999	Забелина	0103000020E6100000010000000500000063B9A5D590B15C408AE5965643E0494063B9A5D590B15C40DD5CFC6D4FE449409B02999D45B45C40DD5CFC6D4FE449409B02999D45B45C408AE5965643E0494063B9A5D590B15C408AE5965643E04940
27818	51746	113.78030800000001	113.807941	51.450775	51.431187999999999	Центральная	0103000020E61000000100000005000000A933F790F0715C40BD361B2B31B74940A933F790F0715C405D6DC5FEB2B949403E062B4EB5735C405D6DC5FEB2B949403E062B4EB5735C40BD361B2B31B74940A933F790F0715C40BD361B2B31B74940
73978	60180	113.85722199999999	113.873814	51.541853000000003	51.527169000000001	Центральная	0103000020E6100000010000000500000059DAA9B9DC765C40863B17467AC3494059DAA9B9DC765C40A81E69705BC549405D328E91EC775C40A81E69705BC549405D328E91EC775C40863B17467AC3494059DAA9B9DC765C40863B17467AC34940
23832	50837	114.851388	114.871447	51.936492999999999	51.921582000000001	Школьная	0103000020E610000001000000050000003D0D18247DB65C40884A2366F6F549403D0D18247DB65C406AF7AB00DFF74940A14CA3C9C5B75C406AF7AB00DFF74940A14CA3C9C5B75C40884A2366F6F549403D0D18247DB65C40884A2366F6F54940
74029	50837	114.851388	114.871447	51.936492999999999	51.921582000000001	Центральная	0103000020E610000001000000050000003D0D18247DB65C40884A2366F6F549403D0D18247DB65C406AF7AB00DFF74940A14CA3C9C5B75C406AF7AB00DFF74940A14CA3C9C5B75C40884A2366F6F549403D0D18247DB65C40884A2366F6F54940
73886	50837	114.851388	114.871447	51.936492999999999	51.921582000000001	Иландинская	0103000020E610000001000000050000003D0D18247DB65C40884A2366F6F549403D0D18247DB65C406AF7AB00DFF74940A14CA3C9C5B75C406AF7AB00DFF74940A14CA3C9C5B75C40884A2366F6F549403D0D18247DB65C40884A2366F6F54940
27132	51498	114.311446	114.33738099999999	51.487766000000001	51.465344000000002	Никифорова	0103000020E61000000100000005000000151E34BBEE935C40E6B1666490BB4940151E34BBEE935C40E50CC51D6FBE4940AC527AA697955C40E50CC51D6FBE4940AC527AA697955C40E6B1666490BB4940151E34BBEE935C40E6B1666490BB4940
67988	59127	114.292546	114.369693	51.646174000000002	51.611275999999997	Ангарская	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
28590	51903	114.292546	114.369693	51.646174000000002	51.611275999999997	Торговый переулок	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
67372	51903	114.292546	114.369693	51.646174000000002	51.611275999999997	Ленинградская	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
73596	60035	114.292546	114.369693	51.646174000000002	51.611275999999997	Ленинградская	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
73562	60035	114.292546	114.369693	51.646174000000002	51.611275999999997	Верхняя	0103000020E61000000100000005000000D7A4DB12B9925C40336ABE4A3ECE4940D7A4DB12B9925C4044C362D4B5D24940D923D40CA9975C4044C362D4B5D24940D923D40CA9975C40336ABE4A3ECE4940D7A4DB12B9925C40336ABE4A3ECE4940
24300	51000	114.55985699999999	114.595422	51.655583999999998	51.625675999999999	Телевизионная	0103000020E61000000100000005000000F25B74B2D4A35C4030F2B22616D04940F25B74B2D4A35C40F3E32F2DEAD349406954E0641BA65C40F3E32F2DEAD349406954E0641BA65C4030F2B22616D04940F25B74B2D4A35C4030F2B22616D04940
73806	51000	114.55985699999999	114.595422	51.655583999999998	51.625675999999999	Советская	0103000020E61000000100000005000000F25B74B2D4A35C4030F2B22616D04940F25B74B2D4A35C40F3E32F2DEAD349406954E0641BA65C40F3E32F2DEAD349406954E0641BA65C4030F2B22616D04940F25B74B2D4A35C4030F2B22616D04940
28521	51000	114.55985699999999	114.595422	51.655583999999998	51.625675999999999	Вокзальная	0103000020E61000000100000005000000F25B74B2D4A35C4030F2B22616D04940F25B74B2D4A35C40F3E32F2DEAD349406954E0641BA65C40F3E32F2DEAD349406954E0641BA65C4030F2B22616D04940F25B74B2D4A35C4030F2B22616D04940
27139	51500	114.237865	114.261222	51.619928000000002	51.606029999999997	Советская	0103000020E610000001000000050000003CF71E2E398F5C408B321B6492CD49403CF71E2E398F5C40F6EFFACC59CF4940BABF7ADCB7905C40F6EFFACC59CF4940BABF7ADCB7905C408B321B6492CD49403CF71E2E398F5C408B321B6492CD4940
74037	60209	113.992293	114.02607	51.521582000000002	51.508533999999997	Новая	0103000020E610000001000000050000002FC37FBA817F5C40B87361A417C149402FC37FBA817F5C405517F032C3C24940085A8121AB815C405517F032C3C24940085A8121AB815C40B87361A417C149402FC37FBA817F5C40B87361A417C14940
67187	51508	113.940352	113.998276	51.682457999999997	51.624065999999999	Транспортная	0103000020E610000001000000050000009BAE27BA2E7C5C40D4450A65E1CF49409BAE27BA2E7C5C406072A3C85AD749406E1805C1E37F5C406072A3C85AD749406E1805C1E37F5C40D4450A65E1CF49409BAE27BA2E7C5C40D4450A65E1CF4940
73673	51508	113.940352	113.998276	51.682457999999997	51.624065999999999	Почтовая	0103000020E610000001000000050000009BAE27BA2E7C5C40D4450A65E1CF49409BAE27BA2E7C5C406072A3C85AD749406E1805C1E37F5C406072A3C85AD749406E1805C1E37F5C40D4450A65E1CF49409BAE27BA2E7C5C40D4450A65E1CF4940
73549	51508	113.940352	113.998276	51.682457999999997	51.624065999999999	Нагорная	0103000020E610000001000000050000009BAE27BA2E7C5C40D4450A65E1CF49409BAE27BA2E7C5C406072A3C85AD749406E1805C1E37F5C406072A3C85AD749406E1805C1E37F5C40D4450A65E1CF49409BAE27BA2E7C5C40D4450A65E1CF4940
27153	51508	113.940352	113.998276	51.682457999999997	51.624065999999999	Дорожная	0103000020E610000001000000050000009BAE27BA2E7C5C40D4450A65E1CF49409BAE27BA2E7C5C406072A3C85AD749406E1805C1E37F5C406072A3C85AD749406E1805C1E37F5C40D4450A65E1CF49409BAE27BA2E7C5C40D4450A65E1CF4940
23743	50819	114.05838199999999	114.11538899999999	51.637543999999998	51.612015	Железнодорожная	0103000020E61000000100000005000000342BDB87BC835C40AAD4EC8156CE4940342BDB87BC835C4069E1B20A9BD149405C548B8862875C4069E1B20A9BD149405C548B8862875C40AAD4EC8156CE4940342BDB87BC835C40AAD4EC8156CE4940
73800	60105	114.50553600000001	114.531516	51.573911000000003	51.549936000000002	Школьная	0103000020E61000000100000005000000D8BCAAB35AA05C405072874D64C64940D8BCAAB35AA05C4047E867EA75C949403F53AF5B04A25C4047E867EA75C949403F53AF5B04A25C405072874D64C64940D8BCAAB35AA05C405072874D64C64940
23956	50877	119.07594899999999	119.09617	51.040678	51.032322999999998	Советская	0103000020E610000001000000050000007DCA3159DCC45D404DF4F928238449407DCA3159DCC45D4056D5CBEF34854940CE3637A627C65D4056D5CBEF34854940CE3637A627C65D404DF4F928238449407DCA3159DCC45D404DF4F92823844940
73844	51058	119.10867500000001	119.12817699999999	50.889485000000001	50.882159999999999	Гагарина	0103000020E6100000010000000500000024B9FC87F4C65D4070EB6E9EEA70494024B9FC87F4C65D402BA4FCA4DA7149405CC64D0D34C85D402BA4FCA4DA7149405CC64D0D34C85D4070EB6E9EEA70494024B9FC87F4C65D4070EB6E9EEA704940
23533	50754	118.984042	119.008584	50.995598000000001	50.977040000000002	Школьная	0103000020E61000000100000005000000FDF84B8BFABE5D4022718FA50F7D4940FDF84B8BFABE5D4044FB58C16F7F494035D1E7A38CC05D4044FB58C16F7F494035D1E7A38CC05D4022718FA50F7D4940FDF84B8BFABE5D4022718FA50F7D4940
74042	60212	119.02798799999999	119.042154	50.801889000000003	50.789015999999997	Новая	0103000020E610000001000000050000008C2B2E8ECAC15D40A702EE79FE6449408C2B2E8ECAC15D40D6027B4CA466494051D9B0A6B2C25D40D6027B4CA466494051D9B0A6B2C25D40A702EE79FE6449408C2B2E8ECAC15D40A702EE79FE644940
24162	50960	119.47848399999999	119.49681	50.917295000000003	50.906959000000001	Советская	0103000020E6100000010000000500000031EA5A7B9FDE5D400CE8853B1774494031EA5A7B9FDE5D4065E42CEC69754940D9942BBCCBDF5D4065E42CEC69754940D9942BBCCBDF5D400CE8853B1774494031EA5A7B9FDE5D400CE8853B17744940
73809	60107	118.881652	118.92888600000001	50.753276	50.735447999999998	Центральная	0103000020E61000000100000005000000FE9C82FC6CB85D404DF4F928235E4940FE9C82FC6CB85D404C6E14596B60494096ED43DE72BB5D404C6E14596B60494096ED43DE72BB5D404DF4F928235E4940FE9C82FC6CB85D404DF4F928235E4940
27793	51743	118.921331	118.94122900000001	51.210362000000003	51.202455999999998	Валько	0103000020E610000001000000050000009F724C16F7BA5D4082700514EA9949409F724C16F7BA5D401C295B24ED9A4940FF428F183DBC5D401C295B24ED9A4940FF428F183DBC5D4082700514EA9949409F724C16F7BA5D4082700514EA994940
27774	51739	118.86453899999999	118.931293	50.945219000000002	50.913178000000002	Гаражная	0103000020E6100000010000000500000075C7629B54B75D409EB64604E374494075C7629B54B75D406747AAEFFC784940997FF44D9ABB5D406747AAEFFC784940997FF44D9ABB5D409EB64604E374494075C7629B54B75D409EB64604E3744940
73771	60090	119.276713	119.30713900000001	50.940497000000001	50.926749000000001	Советская	0103000020E61000000100000005000000325871AAB5D15D40E44C13B69F764940325871AAB5D15D40397EA83462784940E014562AA8D35D40397EA83462784940E014562AA8D35D40E44C13B69F764940325871AAB5D15D40E44C13B69F764940
73742	60074	118.575084	118.611358	50.906306000000001	50.878892	Нагорная	0103000020E61000000100000005000000FC1C1F2DCEA45D40A75B76887F704940FC1C1F2DCEA45D409415C3D50174494078094E7D20A75D409415C3D50174494078094E7D20A75D40A75B76887F704940FC1C1F2DCEA45D40A75B76887F704940
24589	51047	118.77411499999999	118.79601599999999	50.821944999999999	50.811917999999999	Молодёжная,	0103000020E61000000100000005000000F415A4198BB15D405184D4EDEC674940F415A4198BB15D402C0E677E35694940EFC517EDF1B25D402C0E677E35694940EFC517EDF1B25D405184D4EDEC674940F415A4198BB15D405184D4EDEC674940
73977	60179	119.438581	119.45575700000001	50.758884000000002	50.747258000000002	В. Козлова	0103000020E6100000010000000500000068E90AB611DC5D4052D66F26A65F494068E90AB611DC5D4095BA641C23614940147B681F2BDD5D4095BA641C23614940147B681F2BDD5D4052D66F26A65F494068E90AB611DC5D4052D66F26A65F4940
28313	31392	118.240803	118.306245	56.929048999999999	56.889001999999998	Озерная	0103000020E61000000100000005000000D671FC50698F5D400F0A4AD1CA714C40D671FC50698F5D40D5B0DF13EB764C4011E4A08499935D40D5B0DF13EB764C4011E4A08499935D400F0A4AD1CA714C40D671FC50698F5D400F0A4AD1CA714C40
73757	31392	118.240803	118.306245	56.929048999999999	56.889001999999998	60 лет ВЛКСМ	0103000020E61000000100000005000000D671FC50698F5D400F0A4AD1CA714C40D671FC50698F5D40D5B0DF13EB764C4011E4A08499935D40D5B0DF13EB764C4011E4A08499935D400F0A4AD1CA714C40D671FC50698F5D400F0A4AD1CA714C40
73846	31436	118.810667	118.835111	57.076500000000003	57.069586999999999	Набережная	0103000020E61000000100000005000000923CD7F7E1B35D40069D103AE8884C40923CD7F7E1B35D406F1283C0CA894C40E961687572B55D406F1283C0CA894C40E961687572B55D40069D103AE8884C40923CD7F7E1B35D40069D103AE8884C40
73836	31183	118.299858	118.31407	56.756408999999998	56.747732999999997	Иркутская	0103000020E610000001000000050000006ADC9BDF30935D40EA9106B7B55F4C406ADC9BDF30935D4035B39602D2604C40E7A90EB919945D4035B39602D2604C40E7A90EB919945D40EA9106B7B55F4C406ADC9BDF30935D40EA9106B7B55F4C40
73763	60086	118.253649	118.287093	56.814084000000001	56.782483999999997	Магистральная	0103000020E6100000010000000500000070EA03C93B905D4056D28A6F28644C4070EA03C93B905D4033198EE733684C40467A51BB5F925D4033198EE733684C40467A51BB5F925D4056D28A6F28644C4070EA03C93B905D4056D28A6F28644C40
24597	30995	118.253649	118.287093	56.814084000000001	56.782483999999997	Центральная	0103000020E6100000010000000500000070EA03C93B905D4056D28A6F28644C4070EA03C93B905D4033198EE733684C40467A51BB5F925D4033198EE733684C40467A51BB5F925D4056D28A6F28644C4070EA03C93B905D4056D28A6F28644C40
28300	30995	118.253649	118.287093	56.814084000000001	56.782483999999997	 Юбилейная	0103000020E6100000010000000500000070EA03C93B905D4056D28A6F28644C4070EA03C93B905D4033198EE733684C40467A51BB5F925D4033198EE733684C40467A51BB5F925D4056D28A6F28644C4070EA03C93B905D4056D28A6F28644C40
73854	31641	118.310917	118.32794	56.970191	56.957776000000003	Беляева	0103000020E610000001000000050000004FB16A10E6935D4065726A67987A4C404FB16A10E6935D40D0EFFB372F7C4C4037C30DF8FC945D40D0EFFB372F7C4C4037C30DF8FC945D4065726A67987A4C404FB16A10E6935D4065726A67987A4C40
27516	31287	116.065173	116.133194	56.337046999999998	56.318390999999998	Энтузиастов	0103000020E6100000010000000500000043E55FCB2B045D409D2B4A09C1284C4043E55FCB2B045D40821B295B242B4C408081204086085D40821B295B242B4C408081204086085D409D2B4A09C1284C4043E55FCB2B045D409D2B4A09C1284C40
24266	31287	116.065173	116.133194	56.337046999999998	56.318390999999998	Советская	0103000020E6100000010000000500000043E55FCB2B045D409D2B4A09C1284C4043E55FCB2B045D40821B295B242B4C408081204086085D40821B295B242B4C408081204086085D409D2B4A09C1284C4043E55FCB2B045D409D2B4A09C1284C40
73896	31495	118.753939	118.782703	57.002951000000003	56.990375	1  микрорайон	0103000020E61000000100000005000000740B5D8940B05D4054E3A59BC47E4C40740B5D8940B05D40C93EC8B260804C40CADE52CE17B25D40C93EC8B260804C40CADE52CE17B25D4054E3A59BC47E4C40740B5D8940B05D4054E3A59BC47E4C40
23475	50730	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	Александро-Заводская	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
73728	51039	116.685936	116.701199	50.123725999999998	50.109718999999998	Совхозная	0103000020E610000001000000050000008AC91B60E62B5D40FA5FAE450B0E49408AC91B60E62B5D401BD5E940D60F49403A3FC571E02C5D401BD5E940D60F49403A3FC571E02C5D40FA5FAE450B0E49408AC91B60E62B5D40FA5FAE450B0E4940
73843	51044	117.88314800000001	117.89718000000001	49.710785000000001	49.696983000000003	имени молодой гвардии 	0103000020E61000000100000005000000C861307F85785D401A6F2BBD36D94840C861307F85785D4062BEBC00FBDA484005A8A9656B795D4062BEBC00FBDA484005A8A9656B795D401A6F2BBD36D94840C861307F85785D401A6F2BBD36D94840
23550	50761	117.05244	117.06567200000001	50.088558999999997	50.072181999999998	Центральная	0103000020E6100000010000000500000025404D2D5B435D4010AE80423D09494025404D2D5B435D401B62BCE6550B4940D41055F833445D401B62BCE6550B4940D41055F833445D4010AE80423D09494025404D2D5B435D4010AE80423D094940
23553	50761	117.05244	117.06567200000001	50.088558999999997	50.072181999999998	 Шоссейная	0103000020E6100000010000000500000025404D2D5B435D4010AE80423D09494025404D2D5B435D401B62BCE6550B4940D41055F833445D401B62BCE6550B4940D41055F833445D4010AE80423D09494025404D2D5B435D4010AE80423D094940
67667	51610	117.296755	117.383065	49.667000000000002	49.63156	Красноармейская	0103000020E610000001000000050000002BFBAE08FE525D401BBB44F5D6D048402BFBAE08FE525D404C37894160D5484081CF0F2384585D404C37894160D5484081CF0F2384585D401BBB44F5D6D048402BFBAE08FE525D401BBB44F5D6D04840
27340	51610	117.296755	117.383065	49.667000000000002	49.63156	Железнодорожная	0103000020E610000001000000050000002BFBAE08FE525D401BBB44F5D6D048402BFBAE08FE525D404C37894160D5484081CF0F2384585D404C37894160D5484081CF0F2384585D401BBB44F5D6D048402BFBAE08FE525D401BBB44F5D6D04840
73578	60042	117.296755	117.383065	49.667000000000002	49.63156	Красноармейская	0103000020E610000001000000050000002BFBAE08FE525D401BBB44F5D6D048402BFBAE08FE525D404C37894160D5484081CF0F2384585D404C37894160D5484081CF0F2384585D401BBB44F5D6D048402BFBAE08FE525D401BBB44F5D6D04840
73691	60042	117.296755	117.383065	49.667000000000002	49.63156	Дружбы	0103000020E610000001000000050000002BFBAE08FE525D401BBB44F5D6D048402BFBAE08FE525D404C37894160D5484081CF0F2384585D404C37894160D5484081CF0F2384585D401BBB44F5D6D048402BFBAE08FE525D401BBB44F5D6D04840
73817	60110	117.085354	117.115475	49.835349000000001	49.815154999999997	переулок Степной	0103000020E610000001000000050000004CA59F7076455D40DF15C1FF56E848404CA59F7076455D4087DF4DB7ECEA48405C2041F163475D4087DF4DB7ECEA48405C2041F163475D40DF15C1FF56E848404CA59F7076455D40DF15C1FF56E84840
73746	60076	117.825952	117.845392	49.590629	49.571266000000001	Пограничная	0103000020E610000001000000050000003604C765DC745D408BA8893E1FC948403604C765DC745D40DB8827BB99CB484034130CE71A765D40DB8827BB99CB484034130CE71A765D408BA8893E1FC948403604C765DC745D408BA8893E1FC94840
27354	4733	113.847296	113.90658500000001	50.587197000000003	50.562466999999998	Балданжабона	0103000020E61000000100000005000000068200193A765C40240A2DEBFE474940068200193A765C4098A77345294B4940D482177D057A5C4098A77345294B4940D482177D057A5C40240A2DEBFE474940068200193A765C40240A2DEBFE474940
24310	4778	113.596046	113.611749	50.586837000000003	50.570168000000002	Октябрьская 	0103000020E61000000100000005000000583A1F9E25665C40E59CD843FB484940583A1F9E25665C40988A8D791D4B4940161747E526675C40988A8D791D4B4940161747E526675C40E59CD843FB484940583A1F9E25665C40E59CD843FB484940
28121	4668	114.10893	114.147243	50.520203000000002	50.506450000000001	 Ленина	0103000020E6100000010000000500000069E388B5F8865C409487855AD340494069E388B5F8865C40FB230C03964249402864E76D6C895C40FB230C03964249402864E76D6C895C409487855AD340494069E388B5F8865C409487855AD3404940
22881	4554	113.80203899999999	113.81855	50.790922999999999	50.766266999999999	Калинина	0103000020E6100000010000000500000075C7629B54735C4084807C091562494075C7629B54735C40BD5301F73C65494003098A1F63745C40BD5301F73C65494003098A1F63745C4084807C091562494075C7629B54735C4084807C0915624940
73951	4455	113.520444	113.536039	50.960647000000002	50.955188999999997	Школьная	0103000020E6100000010000000500000090D959F44E615C40DD3F16A2437A494090D959F44E615C4011001C7BF67A49405B9885764E625C4011001C7BF67A49405B9885764E625C40DD3F16A2437A494090D959F44E615C40DD3F16A2437A4940
73906	4501	113.58479	113.597825	50.845326	50.830207000000001	Новая	0103000020E61000000100000005000000C84109336D655C4084F41439446A4940C84109336D655C40B03A72A4336C4940CCEEC9C342665C40B03A72A4336C4940CCEEC9C342665C4084F41439446A4940C84109336D655C4084F41439446A4940
28115	4610	114.169584	114.20383699999999	50.675916000000001	50.651428000000003	Ленина	0103000020E61000000100000005000000317BD976DA8A5C406FD921FE61534940317BD976DA8A5C40EC6B5D6A84564940BE2D58AA0B8D5C40EC6B5D6A84564940BE2D58AA0B8D5C406FD921FE61534940317BD976DA8A5C406FD921FE61534940
27478	4095	113.573031	113.62101	50.692819999999998	50.659719000000003	Энергетиков	0103000020E610000001000000050000000726378AAC645C4061C614AC715449400726378AAC645C40E2016553AE5849404B1FBAA0BE675C40E2016553AE5849404B1FBAA0BE675C4061C614AC715449400726378AAC645C4061C614AC71544940
27472	4095	113.573031	113.62101	50.692819999999998	50.659719000000003	Кирова	0103000020E610000001000000050000000726378AAC645C4061C614AC715449400726378AAC645C40E2016553AE5849404B1FBAA0BE675C40E2016553AE5849404B1FBAA0BE675C4061C614AC715449400726378AAC645C4061C614AC71544940
67728	4095	113.573031	113.62101	50.692819999999998	50.659719000000003	8 марта	0103000020E610000001000000050000000726378AAC645C4061C614AC715449400726378AAC645C40E2016553AE5849404B1FBAA0BE675C40E2016553AE5849404B1FBAA0BE675C4061C614AC715449400726378AAC645C4061C614AC71544940
73748	51046	113.579948	113.611847	51.053232000000001	51.038418	Чкалова	0103000020E610000001000000050000005C5837DE1D655C40F3C98AE1EA8449405C5837DE1D655C40E38C614ED0864940F7C9518028675C40E38C614ED0864940F7C9518028675C40F3C98AE1EA8449405C5837DE1D655C40F3C98AE1EA844940
73907	4337	113.26484600000001	113.29493100000001	50.945787000000003	50.927298999999998	Советская	0103000020E610000001000000050000007E1EA33CF3505C40874ECFBBB17649407E1EA33CF3505C40B1FD648C0F794940E7E44526E0525C40B1FD648C0F794940E7E44526E0525C40874ECFBBB17649407E1EA33CF3505C40874ECFBBB1764940
73784	4273	113.463365	113.485293	50.742801	50.717584000000002	Далаева	0103000020E610000001000000050000001B47ACC5A75D5C400211E2CAD95B49401B47ACC5A75D5C40D237691A145F494093FE5E0A0F5F5C40D237691A145F494093FE5E0A0F5F5C400211E2CAD95B49401B47ACC5A75D5C400211E2CAD95B4940
73944	16699	118.667224	118.70167499999999	51.603630000000003	51.590862999999999	Строительная	0103000020E61000000100000005000000CEC64ACCB3AA5D404EB51666A1CB4940CEC64ACCB3AA5D40377172BF43CD4940EE5A423EE8AC5D40377172BF43CD4940EE5A423EE8AC5D404EB51666A1CB4940CEC64ACCB3AA5D404EB51666A1CB4940
27397	16899	118.349113	118.370816	51.689883999999999	51.669490000000003	Заречная	0103000020E61000000100000005000000F1660DDE57965D40E17F2BD9B1D54940F1660DDE57965D404F04711E4ED8494059350873BB975D404F04711E4ED8494059350873BB975D40E17F2BD9B1D54940F1660DDE57965D40E17F2BD9B1D54940
27335	16184	118.188351	118.21397	51.420254	51.390537999999999	Центральная	0103000020E61000000100000005000000CF4A5AF10D8C5D4031EC3026FDB14940CF4A5AF10D8C5D40B00111E2CAB54940CF143AAFB18D5D40B00111E2CAB54940CF143AAFB18D5D4031EC3026FDB14940CF4A5AF10D8C5D4031EC3026FDB14940
73929	16631	118.434758	118.477734	51.599176999999997	51.58079	Центральная	0103000020E6100000010000000500000029EB3713D39B5D4003ECA35357CA494029EB3713D39B5D40F8C1F9D4B1CC4940FC8BA031939E5D40F8C1F9D4B1CC4940FC8BA031939E5D4003ECA35357CA494029EB3713D39B5D4003ECA35357CA4940
73778	16790	118.896349	118.90773900000001	51.537131000000002	51.513730000000002	Мира	0103000020E61000000100000005000000593332C85DB95D40AF7C96E7C1C14940593332C85DB95D407A5567B5C0C449407193516518BA5D407A5567B5C0C449407193516518BA5D40AF7C96E7C1C14940593332C85DB95D40AF7C96E7C1C14940
24381	17033	118.813659	118.82385499999999	52.062370000000001	52.047317999999997	Майская	0103000020E6100000010000000500000026C632FD12B45D408D4127840E064A4026C632FD12B45D4032207BBDFB074A405969520ABAB45D4032207BBDFB074A405969520ABAB45D408D4127840E064A4026C632FD12B45D408D4127840E064A40
73959	16941	118.43314100000001	118.448251	51.805526	51.796253	Центральная	0103000020E61000000100000005000000A2630795B89B5D40C32B499EEBE54940A2630795B89B5D40F209D9791BE749408E59F624B09C5D40F209D9791BE749408E59F624B09C5D40C32B499EEBE54940A2630795B89B5D40C32B499EEBE54940
23361	16289	118.28412	118.294792	51.530687999999998	51.523772999999998	Центральная,	0103000020E61000000100000005000000EE08A7052F925D408FC360FE0AC34940EE08A7052F925D4098309A95EDC34940D6C743DFDD925D4098309A95EDC34940D6C743DFDD925D408FC360FE0AC34940EE08A7052F925D408FC360FE0AC34940
74017	16852	118.35932699999999	118.37229000000001	51.637113999999997	51.62538	Центральная	0103000020E610000001000000050000007764AC36FF965D4047C9AB730CD049407764AC36FF965D4070E998F38CD149402FA86F99D3975D4070E998F38CD149402FA86F99D3975D4047C9AB730CD049407764AC36FF965D4047C9AB730CD04940
73966	16349	118.304143	118.32025	51.570909999999998	51.559674000000001	Центральная	0103000020E61000000100000005000000AB93331477935D40F435CB65A3C74940AB93331477935D40CC7A319413C94940D122DBF97E945D40CC7A319413C94940D122DBF97E945D40F435CB65A3C74940AB93331477935D40F435CB65A3C74940
23429	17171	119.530326	119.560267	52.039828999999997	52.028742999999999	Журавлева	0103000020E61000000100000005000000FC8D76DCF0E15D40957EC2D9AD034A40FC8D76DCF0E15D405837DE1D19054A40CB811E6ADBE35D405837DE1D19054A40CB811E6ADBE35D40957EC2D9AD034A40FC8D76DCF0E15D40957EC2D9AD034A40
23406	17154	118.909868	118.92761900000001	52.082375999999996	52.075645999999999	Журавлева	0103000020E6100000010000000500000053EBFD463BBA5D405F09A4C4AE094A4053EBFD463BBA5D40D6FCF84B8B0A4A407D09151C5EBB5D40D6FCF84B8B0A4A407D09151C5EBB5D405F09A4C4AE094A4053EBFD463BBA5D405F09A4C4AE094A40
24254	16221	118.21565	118.230329	51.498583000000004	51.491658000000001	Майская	0103000020E610000001000000050000007958A835CD8D5D408C683BA6EEBE49407958A835CD8D5D40B9AB5791D1BF49408194D8B5BD8E5D40B9AB5791D1BF49408194D8B5BD8E5D408C683BA6EEBE49407958A835CD8D5D408C683BA6EEBE4940
73954	16441	118.316378	118.366675	51.562882000000002	51.530889999999999	Рабочая	0103000020E6100000010000000500000021CB82893F945D4000E31934F4C3494021CB82893F945D40E8C072840CC84940B1506B9A77975D40E8C072840CC84940B1506B9A77975D4000E31934F4C3494021CB82893F945D4000E31934F4C34940
67184	16441	118.316378	118.366675	51.562882000000002	51.530889999999999	Журавлева	0103000020E6100000010000000500000021CB82893F945D4000E31934F4C3494021CB82893F945D40E8C072840CC84940B1506B9A77975D40E8C072840CC84940B1506B9A77975D4000E31934F4C3494021CB82893F945D4000E31934F4C34940
73736	16441	118.316378	118.366675	51.562882000000002	51.530889999999999	Волкова	0103000020E6100000010000000500000021CB82893F945D4000E31934F4C3494021CB82893F945D40E8C072840CC84940B1506B9A77975D40E8C072840CC84940B1506B9A77975D4000E31934F4C3494021CB82893F945D4000E31934F4C34940
24284	16125	118.171121	118.188036	51.363242999999997	51.355460000000001	Трактовая	0103000020E610000001000000050000002AAA7EA5F38A5D40A18499B67FAD49402AAA7EA5F38A5D401EC022BF7EAE49401F9E25C8088C5D401EC022BF7EAE49401F9E25C8088C5D40A18499B67FAD49402AAA7EA5F38A5D40A18499B67FAD4940
73957	16989	118.517709	118.536636	51.848151999999999	51.834235999999997	Школьная	0103000020E6100000010000000500000012F6ED2422A15D40AB92C83EC8EA494012F6ED2422A15D40BC04A73E90EC4940CD76853E58A25D40BC04A73E90EC4940CD76853E58A25D40AB92C83EC8EA494012F6ED2422A15D40AB92C83EC8EA4940
27337	17085	118.833889	118.87932600000001	52.07967	52.066623	Центральная	0103000020E61000000100000005000000A0DFF76F5EB55D40A9143B1A87084A40A0DFF76F5EB55D40753C66A0320A4A4071218FE046B85D40753C66A0320A4A4071218FE046B85D40A9143B1A87084A40A0DFF76F5EB55D40A9143B1A87084A40
74036	60208	117.26496299999999	117.292901	50.779806999999998	50.765498000000001	Нагорная	0103000020E610000001000000050000009AE95E27F5505D40A393A5D6FB6149409AE95E27F5505D408F183DB7D0634940CEFDD5E3BE525D408F183DB7D0634940CEFDD5E3BE525D40A393A5D6FB6149409AE95E27F5505D40A393A5D6FB614940
67925	59121	116.244702	116.409192	50.556550000000001	50.508082999999999	Оловянная	0103000020E6100000010000000500000003D19332A90F5D40A8531EDD0841494003D19332A90F5D405E4BC8073D4749403B72A433301A5D405E4BC8073D4749403B72A433301A5D40A8531EDD0841494003D19332A90F5D40A8531EDD08414940
73882	51516	116.244702	116.409192	50.556550000000001	50.508082999999999	Шоссейная	0103000020E6100000010000000500000003D19332A90F5D40A8531EDD0841494003D19332A90F5D405E4BC8073D4749403B72A433301A5D405E4BC8073D4749403B72A433301A5D40A8531EDD0841494003D19332A90F5D40A8531EDD08414940
28284	51516	116.244702	116.409192	50.556550000000001	50.508082999999999	Ленина	0103000020E6100000010000000500000003D19332A90F5D40A8531EDD0841494003D19332A90F5D405E4BC8073D4749403B72A433301A5D405E4BC8073D4749403B72A433301A5D40A8531EDD0841494003D19332A90F5D40A8531EDD08414940
73770	51516	116.244702	116.409192	50.556550000000001	50.508082999999999	Горького	0103000020E6100000010000000500000003D19332A90F5D40A8531EDD0841494003D19332A90F5D405E4BC8073D4749403B72A433301A5D405E4BC8073D4749403B72A433301A5D40A8531EDD0841494003D19332A90F5D40A8531EDD08414940
27169	51516	116.244702	116.409192	50.556550000000001	50.508082999999999	50 лет Октября	0103000020E6100000010000000500000003D19332A90F5D40A8531EDD0841494003D19332A90F5D405E4BC8073D4749403B72A433301A5D405E4BC8073D4749403B72A433301A5D40A8531EDD0841494003D19332A90F5D40A8531EDD08414940
27509	51685	117.11443300000001	117.135705	50.950786000000001	50.929904999999998	Матафонова	0103000020E610000001000000050000005325CADE52475D4085B18520077749405325CADE52475D4051BF0B5BB3794940D6390664AF485D4051BF0B5BB3794940D6390664AF485D4085B18520077749405325CADE52475D4085B1852007774940
23569	50772	117.463123	117.47841200000001	50.563949000000001	50.541051000000003	Центральная	0103000020E61000000100000005000000A0C1A6CEA35D5D40EB3BBF2841454940A0C1A6CEA35D5D4053CE177B2F484940E5805D4D9E5E5D4053CE177B2F484940E5805D4D9E5E5D40EB3BBF2841454940A0C1A6CEA35D5D40EB3BBF2841454940
23421	50701	116.843474	116.863156	50.386848000000001	50.368550999999997	Партизанская	0103000020E61000000100000005000000AF415F7AFB355D403CF4DDAD2C2F4940AF415F7AFB355D40F2423A3C8431494028D6A9F23D375D40F2423A3C8431494028D6A9F23D375D403CF4DDAD2C2F4940AF415F7AFB355D403CF4DDAD2C2F4940
73617	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Шамсутдинова	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
24042	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Советская	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
67173	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Свердлова	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
73666	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Савватеевская	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
28279	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Оздоровительная	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
24063	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Ленина	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
24688	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Лазо	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
73631	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Коновалова	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
67170	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Карла Маркса	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
27713	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Журавлева	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
34010	50776	116.481938	116.563253	50.424750000000003	50.360472000000001	Дзержинского	0103000020E61000000100000005000000C72C7B12D81E5D40D68F4DF2232E4940C72C7B12D81E5D40EE7C3F355E364940EE974F560C245D40EE7C3F355E364940EE974F560C245D40D68F4DF2232E4940C72C7B12D81E5D40D68F4DF2232E4940
73841	60124	116.909132	116.926334	50.727808000000003	50.712690000000002	Погодаева	0103000020E61000000100000005000000D0EFFB372F3A5D40D717096D395B4940D0EFFB372F3A5D4033E202D0285D494010CB660E493B5D4033E202D0285D494010CB660E493B5D40D717096D395B4940D0EFFB372F3A5D40D717096D395B4940
74019	60196	117.150554	117.17309299999999	50.771816000000001	50.752729000000002	Центральная	0103000020E610000001000000050000000C923EADA2495D401AE0826C596049400C923EADA2495D40C843DFDDCA624940A88AA9F4134B5D40C843DFDDCA624940A88AA9F4134B5D401AE0826C596049400C923EADA2495D401AE0826C59604940
73718	51060	116.214967	116.27139099999999	51.439509000000001	51.400433999999997	Советская	0103000020E6100000010000000500000008AEF204C20D5D406D1ADB6B41B3494008AEF204C20D5D401AA6B6D441B84940705B5B785E115D401AA6B6D441B84940705B5B785E115D406D1ADB6B41B3494008AEF204C20D5D406D1ADB6B41B34940
73765	60087	116.89006000000001	116.937545	51.718729000000003	51.702784999999999	Энергетиков	0103000020E6100000010000000500000094DE37BEF6385D40478FDFDBF4D9494094DE37BEF6385D40E9D7D64FFFDB4940D061BEBC003C5D40E9D7D64FFFDB4940D061BEBC003C5D40478FDFDBF4D9494094DE37BEF6385D40478FDFDBF4D94940
73924	51051	116.77966600000001	116.803121	51.659658	51.646749999999997	Школьная	0103000020E6100000010000000500000067F3380CE6315D40105839B4C8D2494067F3380CE6315D40BB4560AC6FD44940C66E9F5566335D40BB4560AC6FD44940C66E9F5566335D40105839B4C8D2494067F3380CE6315D40105839B4C8D24940
28077	51051	116.77966600000001	116.803121	51.659658	51.646749999999997	Центральная,	0103000020E6100000010000000500000067F3380CE6315D40105839B4C8D2494067F3380CE6315D40BB4560AC6FD44940C66E9F5566335D40BB4560AC6FD44940C66E9F5566335D40105839B4C8D2494067F3380CE6315D40105839B4C8D24940
24619	51051	116.77966600000001	116.803121	51.659658	51.646749999999997	Трактовая	0103000020E6100000010000000500000067F3380CE6315D40105839B4C8D2494067F3380CE6315D40BB4560AC6FD44940C66E9F5566335D40BB4560AC6FD44940C66E9F5566335D40105839B4C8D2494067F3380CE6315D40105839B4C8D24940
73960	51051	116.77966600000001	116.803121	51.659658	51.646749999999997	Советская	0103000020E6100000010000000500000067F3380CE6315D40105839B4C8D2494067F3380CE6315D40BB4560AC6FD44940C66E9F5566335D40BB4560AC6FD44940C66E9F5566335D40105839B4C8D2494067F3380CE6315D40105839B4C8D24940
73885	51051	116.77966600000001	116.803121	51.659658	51.646749999999997	Кирова	0103000020E6100000010000000500000067F3380CE6315D40105839B4C8D2494067F3380CE6315D40BB4560AC6FD44940C66E9F5566335D40BB4560AC6FD44940C66E9F5566335D40105839B4C8D2494067F3380CE6315D40105839B4C8D24940
27332	50880	116.61239999999999	116.625246	51.547834999999999	51.536687999999998	Школьный переулок	0103000020E610000001000000050000008104C58F31275D40EC134031B2C449408104C58F31275D40554D10751FC649401C7DCC0704285D40554D10751FC649401C7DCC0704285D40EC134031B2C449408104C58F31275D40EC134031B2C44940
74027	50880	116.61239999999999	116.625246	51.547834999999999	51.536687999999998	Первомайская	0103000020E610000001000000050000008104C58F31275D40EC134031B2C449408104C58F31275D40554D10751FC649401C7DCC0704285D40554D10751FC649401C7DCC0704285D40EC134031B2C449408104C58F31275D40EC134031B2C44940
23963	50880	116.61239999999999	116.625246	51.547834999999999	51.536687999999998	Колхозная	0103000020E610000001000000050000008104C58F31275D40EC134031B2C449408104C58F31275D40554D10751FC649401C7DCC0704285D40554D10751FC649401C7DCC0704285D40EC134031B2C449408104C58F31275D40EC134031B2C44940
73936	60158	117.14661	117.163157	51.621358999999998	51.600127999999998	Центральная	0103000020E610000001000000050000000FD1E80E62495D40FAB48AFED0CC49400FD1E80E62495D40A20914B188CF494043C70E2A714A5D40A20914B188CF494043C70E2A714A5D40FAB48AFED0CC49400FD1E80E62495D40FAB48AFED0CC4940
74033	60158	117.14661	117.163157	51.621358999999998	51.600127999999998	Специалистов	0103000020E610000001000000050000000FD1E80E62495D40FAB48AFED0CC49400FD1E80E62495D40A20914B188CF494043C70E2A714A5D40A20914B188CF494043C70E2A714A5D40FAB48AFED0CC49400FD1E80E62495D40FAB48AFED0CC4940
73931	60158	117.14661	117.163157	51.621358999999998	51.600127999999998	Кишиневская	0103000020E610000001000000050000000FD1E80E62495D40FAB48AFED0CC49400FD1E80E62495D40A20914B188CF494043C70E2A714A5D40A20914B188CF494043C70E2A714A5D40FAB48AFED0CC49400FD1E80E62495D40FAB48AFED0CC4940
74016	51520	116.972678	116.985417	51.202981000000001	51.187758000000002	Трактовая	0103000020E610000001000000050000007AE2395B403E5D40FCC74274089849407AE2395B403E5D40CD5A0A48FB99494009FB7612113F5D40CD5A0A48FB99494009FB7612113F5D40FCC74274089849407AE2395B403E5D40FCC7427408984940
27179	51520	116.972678	116.985417	51.202981000000001	51.187758000000002	Заречная	0103000020E610000001000000050000007AE2395B403E5D40FCC74274089849407AE2395B403E5D40CD5A0A48FB99494009FB7612113F5D40CD5A0A48FB99494009FB7612113F5D40FCC74274089849407AE2395B403E5D40FCC7427408984940
24240	50995	116.331371	116.362067	51.477697999999997	51.466174000000002	Центральная	0103000020E61000000100000005000000F1F5B52E35155D406D1FF296ABBB4940F1F5B52E35155D40ABAE433525BD49407EFD101B2C175D40ABAE433525BD49407EFD101B2C175D406D1FF296ABBB4940F1F5B52E35155D406D1FF296ABBB4940
27623	50995	116.331371	116.362067	51.477697999999997	51.466174000000002	Колхозная	0103000020E61000000100000005000000F1F5B52E35155D406D1FF296ABBB4940F1F5B52E35155D40ABAE433525BD49407EFD101B2C175D40ABAE433525BD49407EFD101B2C175D406D1FF296ABBB4940F1F5B52E35155D406D1FF296ABBB4940
27020	51432	117.013228	117.034132	51.782392999999999	51.762686000000002	Котовского	0103000020E610000001000000050000000ED940BAD8405D40FC8EE1B19FE149400ED940BAD8405D4046CF2D7425E44940D0EFFB372F425D4046CF2D7425E44940D0EFFB372F425D40FC8EE1B19FE149400ED940BAD8405D40FC8EE1B19FE14940
74038	60172	117.21219600000001	117.230109	51.777835000000003	51.761682999999998	Новая	0103000020E61000000100000005000000E415889E944D5D40A7751BD47EE14940E415889E944D5D409357E71890E34940FA60191BBA4E5D409357E71890E34940FA60191BBA4E5D40A7751BD47EE14940E415889E944D5D40A7751BD47EE14940
73958	60172	117.21219600000001	117.230109	51.777835000000003	51.761682999999998	Клубная	0103000020E61000000100000005000000E415889E944D5D40A7751BD47EE14940E415889E944D5D409357E71890E34940FA60191BBA4E5D409357E71890E34940FA60191BBA4E5D40A7751BD47EE14940E415889E944D5D40A7751BD47EE14940
28576	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Чернышевского	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
24119	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Советская	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
24232	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Пролетарская	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
73833	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Новоколхозная	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
28495	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Матросова	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
27209	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Ленина	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
27417	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Кирова	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
73686	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Дарасунская	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
73807	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Ведерникова	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
74007	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	Блюхера	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
67878	50945	116.58400399999999	116.722525	51.600928000000003	51.538722	5-ое Декабря	0103000020E61000000100000005000000EC2E505260255D405FD1ADD7F4C44940EC2E505260255D4017A06D35EBCC4940B7627FD93D2E5D4017A06D35EBCC4940B7627FD93D2E5D405FD1ADD7F4C44940EC2E505260255D405FD1ADD7F4C44940
73946	49682	117.35045599999999	117.38355900000001	50.937347000000003	50.926924999999997	Новая	0103000020E61000000100000005000000F7AB00DF6D565D40226C787AA5764940F7AB00DF6D565D407A008BFCFA77494089450C3B8C585D407A008BFCFA77494089450C3B8C585D40226C787AA5764940F7AB00DF6D565D40226C787AA5764940
28069	49682	117.35045599999999	117.38355900000001	50.937347000000003	50.926924999999997	Молодежная	0103000020E61000000100000005000000F7AB00DF6D565D40226C787AA5764940F7AB00DF6D565D407A008BFCFA77494089450C3B8C585D407A008BFCFA77494089450C3B8C585D40226C787AA5764940F7AB00DF6D565D40226C787AA5764940
73948	51433	118.223735	118.252347	50.773605000000003	50.754700999999997	Школьная	0103000020E610000001000000050000001EFE9AAC518E5D4016A1D80A9A6049401EFE9AAC518E5D40D482177D05634940990F087426905D40D482177D05634940990F087426905D4016A1D80A9A6049401EFE9AAC518E5D4016A1D80A9A604940
27022	51433	118.223735	118.252347	50.773605000000003	50.754700999999997	Центральная	0103000020E610000001000000050000001EFE9AAC518E5D4016A1D80A9A6049401EFE9AAC518E5D40D482177D05634940990F087426905D40D482177D05634940990F087426905D4016A1D80A9A6049401EFE9AAC518E5D4016A1D80A9A604940
73839	51579	118.335162	118.357755	50.713295000000002	50.693294000000002	Школьная	0103000020E610000001000000050000002A37514B73955D40AB4198DBBD5849402A37514B73955D403EB324404D5B4940C03E3A75E5965D403EB324404D5B4940C03E3A75E5965D40AB4198DBBD5849402A37514B73955D40AB4198DBBD584940
24199	50980	117.313652	117.336343	51.071385999999997	51.058508000000003	Лесная	0103000020E61000000100000005000000CD94D6DF12545D40F646AD307D874940CD94D6DF12545D4035B22B2D23894940444FCAA486555D4035B22B2D23894940444FCAA486555D40F646AD307D874940CD94D6DF12545D40F646AD307D874940
73940	60071	117.76310599999999	117.78525	51.066597000000002	51.042789999999997	Центральная	0103000020E6100000010000000500000068588CBAD6705D40444C89247A85494068588CBAD6705D408081204086884940C74B378941725D408081204086884940C74B378941725D40444C89247A85494068588CBAD6705D40444C89247A854940
73731	60071	117.76310599999999	117.78525	51.066597000000002	51.042789999999997	Лунина	0103000020E6100000010000000500000068588CBAD6705D40444C89247A85494068588CBAD6705D408081204086884940C74B378941725D408081204086884940C74B378941725D40444C89247A85494068588CBAD6705D40444C89247A854940
73879	60135	117.637953	117.66987899999999	51.020392999999999	51.008510000000001	Центральная	0103000020E61000000100000005000000A5D8D138D4685D4030D80DDB16814940A5D8D138D4685D409E08E23C9C824940BD512B4CDF6A5D409E08E23C9C824940BD512B4CDF6A5D4030D80DDB16814940A5D8D138D4685D4030D80DDB16814940
73864	60130	117.70251500000001	117.72577200000001	50.865380999999999	50.845354999999998	Кооперативная	0103000020E61000000100000005000000C47C7901F66C5D404A41B797346C4940C47C7901F66C5D4036CAFACDC46E49409016670C736E5D4036CAFACDC46E49409016670C736E5D404A41B797346C4940C47C7901F66C5D404A41B797346C4940
73955	60125	117.89929100000001	117.925692	50.661214999999999	50.648287000000003	Центральная	0103000020E6100000010000000500000094A5D6FB8D795D4003B68311FB52494094A5D6FB8D795D40F44F70B1A2544940CE8AA8893E7B5D40F44F70B1A2544940CE8AA8893E7B5D4003B68311FB52494094A5D6FB8D795D4003B68311FB524940
73853	60125	117.89929100000001	117.925692	50.661214999999999	50.648287000000003	Садовая	0103000020E6100000010000000500000094A5D6FB8D795D4003B68311FB52494094A5D6FB8D795D40F44F70B1A2544940CE8AA8893E7B5D40F44F70B1A2544940CE8AA8893E7B5D4003B68311FB52494094A5D6FB8D795D4003B68311FB524940
24303	49681	117.357418	117.382122	50.859025000000003	50.846020000000003	Центральная	0103000020E610000001000000050000001C40BFEFDF565D4087E123624A6C49401C40BFEFDF565D4024B9FC87F46D49404145D5AF74585D4024B9FC87F46D49404145D5AF74585D4087E123624A6C49401C40BFEFDF565D4087E123624A6C4940
27771	51738	118.304323	118.331497	51.118178	51.084225000000004	Школьная	0103000020E61000000100000005000000EB1A2D077A935D40B84082E2C78A4940EB1A2D077A935D40A88DEA74208F4940376E313F37955D40A88DEA74208F4940376E313F37955D40B84082E2C78A4940EB1A2D077A935D40B84082E2C78A4940
73826	50677	117.988421	118.011095	51.060665	51.046017999999997	Молодежная	0103000020E610000001000000050000007F6B274A427F5D407F83F6EAE38549407F6B274A427F5D408481E7DEC38749408B89CDC7B5805D408481E7DEC38749408B89CDC7B5805D407F83F6EAE38549407F6B274A427F5D407F83F6EAE3854940
73956	60171	118.34128	118.365202	51.185600999999998	51.172485000000002	Центральная	0103000020E61000000100000005000000D9B11188D7955D4079060DFD13964940D9B11188D7955D406D8D08C6C1974940C39B35785F975D406D8D08C6C1974940C39B35785F975D4079060DFD13964940D9B11188D7955D4079060DFD13964940
28123	51813	117.453412	117.47483699999999	50.999094999999997	50.986719999999998	Нагорная	0103000020E610000001000000050000004BE7C3B3045D5D40912749D74C7E49404BE7C3B3045D5D406E4C4F58E27F4940917BBABA635E5D406E4C4F58E27F4940917BBABA635E5D40912749D74C7E49404BE7C3B3045D5D40912749D74C7E4940
27245	51562	118.110224	118.128226	50.662512	50.650450999999997	Школьная	0103000020E61000000100000005000000FFCEF6E80D875D40435376FA41534940FFCEF6E80D875D40919A7631CD544940CD1FD3DA34885D40919A7631CD544940CD1FD3DA34885D40435376FA41534940FFCEF6E80D875D40435376FA41534940
73950	51562	118.110224	118.128226	50.662512	50.650450999999997	Молодежная	0103000020E61000000100000005000000FFCEF6E80D875D40435376FA41534940FFCEF6E80D875D40919A7631CD544940CD1FD3DA34885D40919A7631CD544940CD1FD3DA34885D40435376FA41534940FFCEF6E80D875D40435376FA41534940
27708	51727	118.143174	118.192168	51.069178000000001	51.057398999999997	Центральная	0103000020E61000000100000005000000CDE847C329895D405BE9B5D958874940CDE847C329895D4025CD1FD3DA8849409DD5027B4C8C5D4025CD1FD3DA8849409DD5027B4C8C5D405BE9B5D958874940CDE847C329895D405BE9B5D958874940
27706	51727	118.143174	118.192168	51.069178000000001	51.057398999999997	Нагорная	0103000020E61000000100000005000000CDE847C329895D405BE9B5D958874940CDE847C329895D4025CD1FD3DA8849409DD5027B4C8C5D4025CD1FD3DA8849409DD5027B4C8C5D405BE9B5D958874940CDE847C329895D405BE9B5D958874940
73860	51712	117.90734	117.95828299999999	50.933062	50.909849999999999	Школьная	0103000020E610000001000000050000009296CADB117A5D40FF21FDF6757449409296CADB117A5D40F7915B936E77494004543882547D5D40F7915B936E77494004543882547D5D40FF21FDF6757449409296CADB117A5D40FF21FDF675744940
67954	51712	117.90734	117.95828299999999	50.933062	50.909849999999999	Советская	0103000020E610000001000000050000009296CADB117A5D40FF21FDF6757449409296CADB117A5D40F7915B936E77494004543882547D5D40F7915B936E77494004543882547D5D40FF21FDF6757449409296CADB117A5D40FF21FDF675744940
27617	51712	117.90734	117.95828299999999	50.933062	50.909849999999999	Нагорная	0103000020E610000001000000050000009296CADB117A5D40FF21FDF6757449409296CADB117A5D40F7915B936E77494004543882547D5D40F7915B936E77494004543882547D5D40FF21FDF6757449409296CADB117A5D40FF21FDF675744940
73938	60164	113.702658	113.732204	50.403982999999997	50.39649	Школьная	0103000020E6100000010000000500000075914259F86C5C4074982F2FC032494075914259F86C5C40EA9106B7B533494006802A6EDC6E5C40EA9106B7B533494006802A6EDC6E5C4074982F2FC032494075914259F86C5C4074982F2FC0324940
73799	60104	113.194059	113.24054700000001	50.304704000000001	50.293080000000003	Партизанская	0103000020E61000000100000005000000A59F70766B4C5C404C8E3BA583254940A59F70766B4C5C40EE7A698A00274940A9893E1F654F5C40EE7A698A00274940A9893E1F654F5C404C8E3BA583254940A59F70766B4C5C404C8E3BA583254940
28269	51839	113.259304	113.28646000000001	50.410625000000003	50.396540999999999	Центральная	0103000020E6100000010000000500000035EECD6F98505C40F64201DBC132494035EECD6F98505C40C3F5285C8F3449402EE7525C55525C40C3F5285C8F3449402EE7525C55525C40F64201DBC132494035EECD6F98505C40F64201DBC1324940
24393	51021	113.617929	113.637422	50.112070000000003	50.101041000000002	Мира	0103000020E61000000100000005000000009013268C675C400F4757E9EE0C4940009013268C675C406E6E4C4F580E49400FF0A485CB685C406E6E4C4F580E49400FF0A485CB685C400F4757E9EE0C4940009013268C675C400F4757E9EE0C4940
73823	60116	113.339254	113.369958	50.085419999999999	50.071685000000002	Лесная	0103000020E6100000010000000500000061C26856B6555C40904E5DF92C09494061C26856B6555C405036E50AEF0A494030B95164AD575C405036E50AEF0A494030B95164AD575C40904E5DF92C09494061C26856B6555C40904E5DF92C094940
73847	30695	113.289011	113.300231	50.471595000000001	50.461990999999998	Школьная	0103000020E61000000100000005000000CB4BFE277F525C40EE056685223B4940CB4BFE277F525C4083FA96395D3C4940B48F15FC36535C4083FA96395D3C4940B48F15FC36535C40EE056685223B4940CB4BFE277F525C40EE056685223B4940
73980	60182	113.72619400000001	113.748733	50.172848999999999	50.163277000000001	Молодёжная	0103000020E610000001000000050000004B2366F6796E5C403198BF42E61449404B2366F6796E5C40BA1281EA1F164940E71BD13DEB6F5C40BA1281EA1F164940E71BD13DEB6F5C403198BF42E61449404B2366F6796E5C403198BF42E6144940
24384	51018	113.434538	113.480487	50.320177999999999	50.305163999999998	Центральная	0103000020E61000000100000005000000A2B77878CF5B5C4051F52B9D0F274940A2B77878CF5B5C400873BB97FB284940CDC98B4CC05E5C400873BB97FB284940CDC98B4CC05E5C4051F52B9D0F274940A2B77878CF5B5C4051F52B9D0F274940
73849	30530	113.533469	113.548265	50.409970000000001	50.407364000000001	им. братьев Макаровых	0103000020E61000000100000005000000821B295B24625C40ACC8E88024344940821B295B24625C40AA2B9FE579344940A72215C616635C40AA2B9FE579344940A72215C616635C40ACC8E88024344940821B295B24625C40ACC8E88024344940
73768	60089	112.967827	112.991893	50.100088	50.077432000000002	Ленина	0103000020E61000000100000005000000E44BA8E0F03D5C40FAD4B14AE9094940E44BA8E0F03D5C406C5CFFAECF0C49406808C72C7B3F5C406C5CFFAECF0C49406808C72C7B3F5C40FAD4B14AE9094940E44BA8E0F03D5C40FAD4B14AE9094940
28234	51830	113.818011	113.844933	50.364167000000002	50.339889999999997	Школьная	0103000020E610000001000000050000002B31CF4A5A745C40641EF983812B49402B31CF4A5A745C4027A435069D2E4940EA93DC6113765C4027A435069D2E4940EA93DC6113765C40641EF983812B49402B31CF4A5A745C40641EF983812B4940
27404	51644	112.754396	112.76955100000001	50.124516999999997	50.111699999999999	 Центральная	0103000020E61000000100000005000000ED0E290648305C404A7B832F4C0E4940ED0E290648305C40E4654D2CF00F4940AA66D65240315C40E4654D2CF00F4940AA66D65240315C404A7B832F4C0E4940ED0E290648305C404A7B832F4C0E4940
73834	30347	113.16848400000001	113.184842	50.317445999999997	50.312286	Центральная	0103000020E610000001000000050000008E791D71C84A5C40D47FD6FCF82749408E791D71C84A5C407D1F0E12A2284940583B8A73D44B5C407D1F0E12A2284940583B8A73D44B5C40D47FD6FCF82749408E791D71C84A5C40D47FD6FCF8274940
24359	51013	113.111926	113.145173	50.156703	50.147571999999997	Школьная	0103000020E610000001000000050000009D64ABCB29475C4014E7A8A3E31249409D64ABCB29475C40B1170AD80E144940C8D0B1834A495C40B1170AD80E144940C8D0B1834A495C4014E7A8A3E31249409D64ABCB29475C4014E7A8A3E3124940
67773	51637	113.266149	113.30718400000001	50.297297999999998	50.257657999999999	Партизанская	0103000020E610000001000000050000003DB7D09508515C40C1C6F5EFFA2049403DB7D09508515C40469561DC0D264940B07614E7A8535C40469561DC0D264940B07614E7A8535C40C1C6F5EFFA2049403DB7D09508515C40C1C6F5EFFA204940
27393	51637	113.266149	113.30718400000001	50.297297999999998	50.257657999999999	Карла Маркса	0103000020E610000001000000050000003DB7D09508515C40C1C6F5EFFA2049403DB7D09508515C40469561DC0D264940B07614E7A8535C40469561DC0D264940B07614E7A8535C40C1C6F5EFFA2049403DB7D09508515C40C1C6F5EFFA204940
24387	51019	114.351457	114.381156	51.231476999999998	51.204526999999999	Центральная	0103000020E61000000100000005000000D13C80457E965C401213D4F02D9A4940D13C80457E965C405A63D009A19D494026AB22DC64985C405A63D009A19D494026AB22DC64985C401213D4F02D9A4940D13C80457E965C401213D4F02D9A4940
73792	60102	114.07256599999999	114.096462	51.102158000000003	51.085436000000001	Ленина	0103000020E610000001000000050000004C33DDEBA4845C4056F31C91EF8A49404C33DDEBA4845C402C836A83138D4940A2D3F36E2C865C402C836A83138D4940A2D3F36E2C865C4056F31C91EF8A49404C33DDEBA4845C4056F31C91EF8A4940
27754	50706	114.267123	114.297774	51.014676000000001	50.991885000000003	Ленина	0103000020E610000001000000050000009A40118B18915C404D327216F67E49409A40118B18915C409F0436E7E081494058E6ADBA0E935C409F0436E7E081494058E6ADBA0E935C404D327216F67E49409A40118B18915C404D327216F67E4940
73788	60099	114.44928400000001	114.47909900000001	50.767122000000001	50.744084000000001	Школьная	0103000020E610000001000000050000006EA7AD11C19C5C400ABDFE243E5F49406EA7AD11C19C5C406405BF0D31624940F722DA8EA99E5C406405BF0D31624940F722DA8EA99E5C400ABDFE243E5F49406EA7AD11C19C5C400ABDFE243E5F4940
73818	60111	113.770696	115.40399499999999	51.427194999999998	50.4587	Ленина	0103000020E610000001000000050000001DCA501553715C406D567DAEB63A49401DCA501553715C40E2016553AEB64940D72FD80DDBD95C40E2016553AEB64940D72FD80DDBD95C406D567DAEB63A49401DCA501553715C406D567DAEB63A4940
73813	60108	115.154506	115.177216	50.589021000000002	50.575020000000002	Школьная	0103000020E610000001000000050000004A42226DE3C95C40E1455F419A4949404A42226DE3C95C4020D4450A654B4940FD14C78157CB5C4020D4450A654B4940FD14C78157CB5C40E1455F419A4949404A42226DE3C95C40E1455F419A494940
73602	59488	114.456479	114.485845	51.091721999999997	51.073197	переулок Клубный	0103000020E61000000100000005000000E413B2F3369D5C402995F0845E894940E413B2F3369D5C406F29E78BBD8B4940357BA015189F5C406F29E78BBD8B4940357BA015189F5C402995F0845E894940E413B2F3369D5C402995F0845E894940
24047	50842	114.486932	114.57574	51.128608	51.083919999999999	Ранжурова	0103000020E610000001000000050000000ED8D5E4299F5C407BBDFBE3BD8A49400ED8D5E4299F5C408200193A76904940F0BF95ECD8A45C408200193A76904940F0BF95ECD8A45C407BBDFBE3BD8A49400ED8D5E4299F5C407BBDFBE3BD8A4940
67380	50842	114.486932	114.57574	51.128608	51.083919999999999	Ленина	0103000020E610000001000000050000000ED8D5E4299F5C407BBDFBE3BD8A49400ED8D5E4299F5C408200193A76904940F0BF95ECD8A45C408200193A76904940F0BF95ECD8A45C407BBDFBE3BD8A49400ED8D5E4299F5C407BBDFBE3BD8A4940
23842	50842	114.486932	114.57574	51.128608	51.083919999999999	Комсомольская	0103000020E610000001000000050000000ED8D5E4299F5C407BBDFBE3BD8A49400ED8D5E4299F5C408200193A76904940F0BF95ECD8A45C408200193A76904940F0BF95ECD8A45C407BBDFBE3BD8A49400ED8D5E4299F5C407BBDFBE3BD8A4940
73621	60050	114.486932	114.57574	51.128608	51.083919999999999	Комсомольская	0103000020E610000001000000050000000ED8D5E4299F5C407BBDFBE3BD8A49400ED8D5E4299F5C408200193A76904940F0BF95ECD8A45C408200193A76904940F0BF95ECD8A45C407BBDFBE3BD8A49400ED8D5E4299F5C407BBDFBE3BD8A4940
70092	59381	83.672085999999993	83.721862000000002	53.212274999999998	53.184579999999997	Отечественная	0103000020E610000001000000050000005D86FF7403EB544072BF4351A0974A405D86FF7403EB54401361C3D32B9B4A40698EACFC32EE54401361C3D32B9B4A40698EACFC32EE544072BF4351A0974A405D86FF7403EB544072BF4351A0974A40
69841	1063	78.545472000000004	78.600071999999997	52.945709999999998	52.906227000000001	квартал В	0103000020E610000001000000050000008F386403E9A2534048E00F3FFF734A408F386403E9A2534005C078060D794A40B3CF639467A6534005C078060D794A40B3CF639467A6534048E00F3FFF734A408F386403E9A2534048E00F3FFF734A40
70028	1063	78.545472000000004	78.600071999999997	52.945709999999998	52.906227000000001	квартал Б	0103000020E610000001000000050000008F386403E9A2534048E00F3FFF734A408F386403E9A2534005C078060D794A40B3CF639467A6534005C078060D794A40B3CF639467A6534048E00F3FFF734A408F386403E9A2534048E00F3FFF734A40
69997	1063	78.545472000000004	78.600071999999997	52.945709999999998	52.906227000000001	квартал А	0103000020E610000001000000050000008F386403E9A2534048E00F3FFF734A408F386403E9A2534005C078060D794A40B3CF639467A6534005C078060D794A40B3CF639467A6534048E00F3FFF734A408F386403E9A2534048E00F3FFF734A40
70128	1063	78.545472000000004	78.600071999999997	52.945709999999998	52.906227000000001	Ленина	0103000020E610000001000000050000008F386403E9A2534048E00F3FFF734A408F386403E9A2534005C078060D794A40B3CF639467A6534005C078060D794A40B3CF639467A6534048E00F3FFF734A408F386403E9A2534048E00F3FFF734A40
69695	1063	78.545472000000004	78.600071999999997	52.945709999999998	52.906227000000001	Гагарина	0103000020E610000001000000050000008F386403E9A2534048E00F3FFF734A408F386403E9A2534005C078060D794A40B3CF639467A6534005C078060D794A40B3CF639467A6534048E00F3FFF734A408F386403E9A2534048E00F3FFF734A40
69714	1063	78.545472000000004	78.600071999999997	52.945709999999998	52.906227000000001	40 лет Октября	0103000020E610000001000000050000008F386403E9A2534048E00F3FFF734A408F386403E9A2534005C078060D794A40B3CF639467A6534005C078060D794A40B3CF639467A6534048E00F3FFF734A408F386403E9A2534048E00F3FFF734A40
69763	59358	80.173839999999998	80.208145999999999	51.373741000000003	51.344946	Ленина	0103000020E6100000010000000500000025AFCE31200B54406971C63027AC494025AFCE31200B54405116BEBED6AF4940C4B29943520D54405116BEBED6AF4940C4B29943520D54406971C63027AC494025AFCE31200B54406971C63027AC4940
69775	59359	84.644233999999997	84.706863999999996	52.999028000000003	52.960667999999998	Рабочая	0103000020E61000000100000005000000293E3E213B2955402828452BF77A4A40293E3E213B295540E7E44526E07F4A4010AE80423D2D5540E7E44526E07F4A4010AE80423D2D55402828452BF77A4A40293E3E213B2955402828452BF77A4A40
69782	59357	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Юбилейная	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
70064	59357	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Мехзаводская	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69756	59357	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Кирова	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69752	59356	86.457967999999994	86.492311000000001	52.856746999999999	52.818978999999999	Демьяна Бедного	0103000020E6100000010000000500000054A703594F9D55402E8ECA4DD4684A4054A703594F9D55401AF9BCE2A96D4A40821DFF05829F55401AF9BCE2A96D4A40821DFF05829F55402E8ECA4DD4684A4054A703594F9D55402E8ECA4DD4684A40
70572	59374	84.267021999999997	84.343800999999999	51.673532999999999	51.637253999999999	Партизанская	0103000020E61000000100000005000000005471E316115540629F008A91D14940005471E3161155406DE34F5436D6494041D5E8D5001655406DE34F5436D6494041D5E8D500165540629F008A91D14940005471E316115540629F008A91D14940
70023	59374	84.267021999999997	84.343800999999999	51.673532999999999	51.637253999999999	Красноармейская	0103000020E61000000100000005000000005471E316115540629F008A91D14940005471E3161155406DE34F5436D6494041D5E8D5001655406DE34F5436D6494041D5E8D500165540629F008A91D14940005471E316115540629F008A91D14940
69692	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	микрорайон 3	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
69925	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	микрорайон 2	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
69644	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Энгельса	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70126	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Титова	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70783	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Советская	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70123	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Розы Люксембург	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
69969	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Первомайская	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70930	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Новая	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70097	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Ленина	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70241	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Ленина	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70040	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Космонавтов	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
70550	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Кооперативный	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
69671	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	Карла Маркса	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
69691	902	78.611992999999998	78.676635000000005	53.032772999999999	52.973754999999997	2-ая вокзальная	0103000020E610000001000000050000006118B0E42AA7534082A8FB00A47C4A406118B0E42AA753408D98D9E731844A400E15E3FC4DAB53408D98D9E731844A400E15E3FC4DAB534082A8FB00A47C4A406118B0E42AA7534082A8FB00A47C4A40
69811	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	тр.Новоегорьевский	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69680	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	проспект Ленина	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69989	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	пр.Рубцовский	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69672	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	пр.Ленина	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
70089	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	переулок Пионерский	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69865	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	пер.Станционный	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69681	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Федоренко	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69688	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Тракторная	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69994	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Степана Разина	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69986	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Сельмашская	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69685	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Светлова	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69683	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Рихарда Зорге	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69871	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Рихарада Зорге	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69995	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Районная	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69807	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Пролетарская	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69821	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Осипенко	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69833	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Октябрьская	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
70131	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Одесская	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
70120	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Красная	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69686	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Кондратюка	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69676	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Комсомольская	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69991	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Карла Маркса	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69863	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Дзержинского	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69658	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Громова	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69992	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Гражданский переулок	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69990	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Бульвар Победы	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69862	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Брусилова	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
69669	576	81.148079999999993	81.253866000000002	51.568319000000002	51.465618999999997	Алтайская	0103000020E61000000100000005000000444C89247A495440B7B2446799BB4940444C89247A49544004594FADBEC849403FE42D573F50544004594FADBEC849403FE42D573F505440B7B2446799BB4940444C89247A495440B7B2446799BB4940
70015	59370	81.986011000000005	82.011450999999994	52.381095000000002	52.366399000000001	Рабочий	0103000020E61000000100000005000000C39FE1CD1A7F5440C0249529E62E4A40C39FE1CD1A7F5440A6D590B8C7304A406AA0F99CBB805440A6D590B8C7304A406AA0F99CBB805440C0249529E62E4A40C39FE1CD1A7F5440C0249529E62E4A40
69742	59353	81.802736999999993	83.157684000000003	52.007581999999999	51.773482000000001	8 Марта	0103000020E610000001000000050000008192020B60735440B8054B7501E349408192020B60735440E6046D72F8004A408FC6A17E17CA5440E6046D72F8004A408FC6A17E17CA5440B8054B7501E349408192020B60735440B8054B7501E34940
70121	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Энгельса	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
70124	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Трактовая	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
70011	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Союза Республик	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69690	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Прудская	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
70127	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Попова	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69677	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Мерзликина	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69689	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Менделеева	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
70116	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Майская	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69870	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Космонавтов	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69858	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Анатолия	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69783	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	8-й микрорайон	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69977	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	22 Партсъезда	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
70425	59344	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	2-Залинейная	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69731	59351	79.645954000000003	79.775526999999997	51.832676999999997	51.800446999999998	К.Маркса	0103000020E610000001000000050000001B2E724F57E9534035971B0C75E649401B2E724F57E95340D190F12895EA49408F8AFF3BA2F15340D190F12895EA49408F8AFF3BA2F1534035971B0C75E649401B2E724F57E9534035971B0C75E64940
70811	59412	79.756670999999997	79.783827000000002	52.433418000000003	52.420256000000002	Новая	0103000020E6100000010000000500000039B5334C6DF0534051F9D7F2CA354A4039B5334C6DF05340B6BFB33D7A374A4032AEB8382AF25340B6BFB33D7A374A4032AEB8382AF2534051F9D7F2CA354A4039B5334C6DF0534051F9D7F2CA354A40
70191	59390	81.537194999999997	81.599798000000007	52.443756	52.411664999999999	Новая	0103000020E61000000100000005000000C82423676162544034F44F70B1344A40C824236761625440AFB321FFCC384A40338D261763665440AFB321FFCC384A40338D26176366544034F44F70B1344A40C82423676162544034F44F70B1344A40
69917	59342	82.704582000000002	82.773662999999999	51.682608999999999	51.652650999999999	Молодежная	0103000020E610000001000000050000006BD619DF17AD5440D15966118AD349406BD619DF17AD5440467A51BB5FD7494004C8D0B183B15440467A51BB5FD7494004C8D0B183B15440D15966118AD349406BD619DF17AD5440D15966118AD34940
69893	59369	79.133967999999996	79.209138999999993	52.271642999999997	52.227395999999999	Центральная	0103000020E6100000010000000500000079AD84EE92C85340E09EE74F1B1D4A4079AD84EE92C85340FA97A432C5224A405C548B8862CD5340FA97A432C5224A405C548B8862CD5340E09EE74F1B1D4A4079AD84EE92C85340E09EE74F1B1D4A40
70295	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Томская	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69653	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Терешковой	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69655	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Новоярковский тракт	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70645	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Николаева	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69982	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Некрасова	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70114	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Мира	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70111	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Мамонтова	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69854	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Ленина	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70050	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Куйбышева	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69642	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Карла Маркса	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69830	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Громова	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69650	59340	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Гагарина	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70070	19902	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	Шумакова	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
69834	19902	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	Чернышевского	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
70910	19902	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	Центральная	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
69851	19902	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	Семипалатинская	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
69840	19902	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	Пугачева	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
69641	19902	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	Ленина	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
69959	19902	82.160202999999996	82.219825	51.185805000000002	51.134039999999999	Барнаульский тракт	0103000020E61000000100000005000000266E15C4408A54408C2D043928914940266E15C4408A544076374F75C8974940F775E09C118E544076374F75C8974940F775E09C118E54408C2D043928914940266E15C4408A54408C2D043928914940
69675	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	пер.2-й Железнодорожный	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
70066	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Центральная	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
69832	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Таратынова	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
70048	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Сыркина	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
69643	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Строителей	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
69646	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Союза Республик	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
69960	59341	84.873987	85.005787999999995	53.742463999999998	53.664257999999997	Заринская	0103000020E6100000010000000500000044882B67EF3755409D0DF96706D54A4044882B67EF3755408A3A730F09DF4A4064ADA1D45E4055408A3A730F09DF4A4064ADA1D45E4055409D0DF96706D54A4044882B67EF3755409D0DF96706D54A40
69958	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	40 лет Победы	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
69956	59341	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	25 Партсъезда	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
70012	59372	80.879242000000005	80.947478000000004	52.854832999999999	52.820698	Дорожная	0103000020E6100000010000000500000042D13C804538544041F2CEA10C694A4042D13C80453854405245F12A6B6D4A407DEBC37AA33C54405245F12A6B6D4A407DEBC37AA33C544041F2CEA10C694A4042D13C804538544041F2CEA10C694A40
70086	59380	79.337445000000002	79.370960999999994	53.351455999999999	53.334575000000001	Ленина	0103000020E61000000100000005000000B8CCE9B298D553409487855AD3AA4A40B8CCE9B298D55340D2FD9C82FCAC4A40DAC534D3BDD75340D2FD9C82FCAC4A40DAC534D3BDD753409487855AD3AA4A40B8CCE9B298D553409487855AD3AA4A40
69929	59355	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Элеваторная	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
69927	59355	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Первомайская	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
69923	59355	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Островского	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
69748	59355	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Ленина	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
71216	59355	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Заводская	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
70167	59355	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Больничная	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
69859	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	улица Кутузова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69651	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Чайковского	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70045	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Центральный	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70387	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Урожайная	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70054	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Ударная	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69591	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Тургенева	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69635	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Трофимова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69605	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Телеграфный	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69639	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Социалистическая	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69637	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Советская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69874	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Смольный переулок	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69813	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Севастопольская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69806	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Самарская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69774	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Давыдова	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
70599	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Революции	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69920	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Разина	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70605	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Раздольная	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69831	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Радищева	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
9837	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Пушкина	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69623	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Промышленная	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69953	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Приречная	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69837	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Прибыткова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69804	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Подгорная	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69809	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Петрова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69633	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Нефтебаза	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69933	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Мухачева	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69611	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Муромцевский	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69631	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Моторный	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69946	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Можайского	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70100	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Мерлина	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69815	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Мартьянова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70058	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Майская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69628	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Льнокомбинат	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69607	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Льва Толстого	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70051	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Луговая	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69827	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Липового	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70065	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Лермонтова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70056	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Ленинградская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69930	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Ленина	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69939	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Л.Толстого	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69797	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Кулундинская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70281	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Куйбышева	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70049	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Крылова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69814	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Красноярский	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69626	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Красильникова	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69934	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Короленко	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69616	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Железнодорожный	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70094	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Динамовская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
70098	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Декабристов	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69937	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Горького	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69825	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Горно-Алтайская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69948	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Гайдара	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69608	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Волочаевская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69819	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Воинов-Интернационалистов	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69636	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Васильева	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69613	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Вали Максимовой	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69817	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	Вагонная	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69829	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	8 Марта	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69938	15194	85.130204000000006	85.313263000000006	52.567183999999997	52.485587000000002	3-я Мало-Угреневская	0103000020E61000000100000005000000BD732843554855406F2EFEB6273E4A40BD7328435548554040683D7C99484A40000341800C54554040683D7C99484A40000341800C5455406F2EFEB6273E4A40BD732843554855406F2EFEB6273E4A40
69621	59333	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	Академика Мясникова	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
1961	573	83.749663999999996	83.793475000000001	53.353777999999998	53.334918999999999	улица Шевченко	0103000020E6100000010000000500000044BFB67EFAEF54408EE733A0DEAA4A4044BFB67EFAEF5440AB05F69848AD4A4064CC5D4BC8F25440AB05F69848AD4A4064CC5D4BC8F254408EE733A0DEAA4A4044BFB67EFAEF54408EE733A0DEAA4A40
2241	573	83.699106999999998	83.740250000000003	53.357239	53.340209999999999	улица Советской Армии	0103000020E61000000100000005000000E659492BBEEC5440D6E253008CAB4A40E659492BBEEC544089EDEE01BAAD4A404C37894160EF544089EDEE01BAAD4A404C37894160EF5440D6E253008CAB4A40E659492BBEEC5440D6E253008CAB4A40
2962	573	83.620541000000003	83.684060000000002	53.391990999999997	53.317672000000002	улица Попова	0103000020E61000000100000005000000F03499F1B6E754406E6DE179A9A84A40F03499F1B6E75440C5A9D6C22CB24A401D2098A3C7EB5440C5A9D6C22CB24A401D2098A3C7EB54406E6DE179A9A84A40F03499F1B6E754406E6DE179A9A84A40
3382	573	83.713175000000007	83.741077000000004	53.380659000000001	53.376446999999999	улица Петра Сухова	0103000020E61000000100000005000000CA54C1A8A4ED5440B2D6506A2FB04A40CA54C1A8A4ED5440CBF6216FB9B04A4057B439CE6DEF5440CBF6216FB9B04A4057B439CE6DEF5440B2D6506A2FB04A40CA54C1A8A4ED5440B2D6506A2FB04A40
15456	573	83.756536999999994	83.798828999999998	53.327610999999997	53.314594	улица Мамонтова	0103000020E61000000100000005000000B14D2A1A6BF0544048C2BE9D44A84A40B14D2A1A6BF05440A9674128EFA94A402B86AB0320F35440A9674128EFA94A402B86AB0320F3544048C2BE9D44A84A40B14D2A1A6BF0544048C2BE9D44A84A40
189	573	83.754147000000003	83.756438000000003	53.359941999999997	53.358679000000002	улица Зеленая Роща	0103000020E610000001000000050000001958C7F143F0544089618731E9AD4A401958C7F143F05440793A579412AE4A40E8DCED7A69F05440793A579412AE4A40E8DCED7A69F0544089618731E9AD4A401958C7F143F0544089618731E9AD4A40
3043	573	83.665322000000003	83.748649	53.378611999999997	53.356797999999998	улица Гущина	0103000020E61000000100000005000000CCD3B9A294EA54409CA38E8EABAD4A40CCD3B9A294EA5440C3EFA65B76B04A40B8CB7EDDE9EF5440C3EFA65B76B04A40B8CB7EDDE9EF54409CA38E8EABAD4A40CCD3B9A294EA54409CA38E8EABAD4A40
2287	573	83.650301999999996	83.753176999999994	53.369259	53.350315999999999	улица Георгия Исакова	0103000020E610000001000000050000007FA1478C9EE95440FDA19927D7AC4A407FA1478C9EE95440786000E143AF4A405CC64D0D34F05440786000E143AF4A405CC64D0D34F05440FDA19927D7AC4A407FA1478C9EE95440FDA19927D7AC4A40
29015	573	83.742613000000006	83.769858999999997	53.354680999999999	53.339151000000001	проспект Строителей	0103000020E610000001000000050000006825ADF886EF5440EEB3CA4C69AB4A406825ADF886EF54409CC1DF2F66AD4A4000E2AE5E45F154409CC1DF2F66AD4A4000E2AE5E45F15440EEB3CA4C69AB4A406825ADF886EF5440EEB3CA4C69AB4A40
28957	573	83.742613000000006	83.769858999999997	53.354680999999999	53.339151000000001	проспект Строителей	0103000020E610000001000000050000006825ADF886EF5440EEB3CA4C69AB4A406825ADF886EF54409CC1DF2F66AD4A4000E2AE5E45F154409CC1DF2F66AD4A4000E2AE5E45F15440EEB3CA4C69AB4A406825ADF886EF5440EEB3CA4C69AB4A40
2089	573	83.735291000000004	83.797804999999997	53.387355999999997	53.328687000000002	проспект Ленина	0103000020E61000000100000005000000C382FB010FEF544068CF656A12AA4A40C382FB010FEF544066F4A3E194B14A4075E5B33C0FF3544066F4A3E194B14A4075E5B33C0FF3544068CF656A12AA4A40C382FB010FEF544068CF656A12AA4A40
3519	573	83.625660999999994	83.743520000000004	53.390217999999997	53.38458	проспект Космонавтов	0103000020E610000001000000050000007D586FD40AE854400C59DDEA39B14A407D586FD40AE85440BF27D6A9F2B14A4001FBE8D495EF5440BF27D6A9F2B14A4001FBE8D495EF54400C59DDEA39B14A407D586FD40AE854400C59DDEA39B14A40
2227	573	83.730225000000004	83.753743	53.360118999999997	53.342058999999999	проспект Коммунаров	0103000020E610000001000000050000002F6EA301BCEE5440B726DD96C8AB4A402F6EA301BCEE544088D51F6118AE4A40B1A547533DF0544088D51F6118AE4A40B1A547533DF05440B726DD96C8AB4A402F6EA301BCEE5440B726DD96C8AB4A40
70082	573	83.505350000000007	83.864953999999997	53.452658	53.184579999999997	просп.Дзержинского	0103000020E6100000010000000500000027C286A757E0544072BF4351A0974A4027C286A757E05440EA2285B2F0B94A40D7A205685BF75440EA2285B2F0B94A40D7A205685BF7544072BF4351A0974A4027C286A757E0544072BF4351A0974A40
7102	573	83.758135999999993	83.762016000000003	53.350794999999998	53.348494000000002	площадь Победы	0103000020E61000000100000005000000E57ADB4C85F05440166D8E739BAC4A40E57ADB4C85F05440D74CBED9E6AC4A40D7C1C1DEC4F05440D74CBED9E6AC4A40D7C1C1DEC4F05440166D8E739BAC4A40E57ADB4C85F05440166D8E739BAC4A40
3693	573	83.755593000000005	83.775328999999999	53.343629	53.324593999999998	переулок Ядринцева	0103000020E610000001000000050000008A05BEA25BF05440293DD34B8CA94A408A05BEA25BF05440857AFA08FCAB4A40FCA886FD9EF15440857AFA08FCAB4A40FCA886FD9EF15440293DD34B8CA94A408A05BEA25BF05440293DD34B8CA94A40
28918	573	83.772643000000002	83.781671000000003	53.334876000000001	53.326836999999998	переулок Радищева	0103000020E61000000100000005000000EF1EA0FB72F15440B60F79CBD5A94A40EF1EA0FB72F154408F1B7E37DDAA4A40D34ECDE506F254408F1B7E37DDAA4A40D34ECDE506F25440B60F79CBD5A94A40EF1EA0FB72F15440B60F79CBD5A94A40
3588	573	83.785686999999996	83.798488000000006	53.350827000000002	53.339269000000002	переулок Некрасова	0103000020E610000001000000050000001C7920B248F25440F8C5A52A6DAB4A401C7920B248F25440E3C62DE6E7AC4A40E78F696D1AF35440E3C62DE6E7AC4A40E78F696D1AF35440F8C5A52A6DAB4A401C7920B248F25440F8C5A52A6DAB4A40
3314	573	83.787079000000006	83.787834000000004	53.367798000000001	53.351664999999997	бульвар 9 Января	0103000020E61000000100000005000000941799805FF25440EC12D55B03AD4A40941799805FF2544061C43E0114AF4A40522B4CDF6BF2544061C43E0114AF4A40522B4CDF6BF25440EC12D55B03AD4A40941799805FF25440EC12D55B03AD4A40
70233	573	83.655107999999998	83.755971000000002	53.376313000000003	53.353605999999999	Юрина	0103000020E6100000010000000500000045D61A4AEDE95440AED51EF642AD4A4045D61A4AEDE95440A3073E062BB04A405D6E30D461F05440A3073E062BB04A405D6E30D461F05440AED51EF642AD4A4045D61A4AEDE95440AED51EF642AD4A40
70262	573	83.648882	83.689458999999999	53.357905000000002	53.354475999999998	Энтузиастов	0103000020E61000000100000005000000A33D5E4887E95440C39B35785FAD4A40A33D5E4887E954409609BFD4CFAD4A40B43BA41820EC54409609BFD4CFAD4A40B43BA41820EC5440C39B35785FAD4A40A33D5E4887E95440C39B35785FAD4A40
70263	573	83.683530000000005	83.738731999999999	53.382866	53.379289	Эмилии Алексеевой	0103000020E610000001000000050000006FF59CF4BEEB5440C45DBD8A8CB04A406FF59CF4BEEB54400B60CAC001B14A408E20956247EF54400B60CAC001B14A408E20956247EF5440C45DBD8A8CB04A406FF59CF4BEEB5440C45DBD8A8CB04A40
69599	573	83.505350000000007	83.864953999999997	53.452658	53.184579999999997	Э.Алексеевой	0103000020E6100000010000000500000027C286A757E0544072BF4351A0974A4027C286A757E05440EA2285B2F0B94A40D7A205685BF75440EA2285B2F0B94A40D7A205685BF7544072BF4351A0974A4027C286A757E0544072BF4351A0974A40
70261	573	83.675534999999996	83.679371000000003	53.343677999999997	53.328918000000002	Шумакова	0103000020E610000001000000050000006A1327F73BEB54406A882AFC19AA4A406A1327F73BEB5440662D05A4FDAB4A4074B680D07AEB5440662D05A4FDAB4A4074B680D07AEB54406A882AFC19AA4A406A1327F73BEB54406A882AFC19AA4A40
70217	573	83.667406	83.670029	53.373106	53.362794999999998	Шукшина	0103000020E61000000100000005000000DEC9A7C7B6EA54407F130A1170AE4A40DEC9A7C7B6EA54407FF8F9EFC1AF4A40C89750C1E1EA54407FF8F9EFC1AF4A40C89750C1E1EA54407F130A1170AE4A40DEC9A7C7B6EA54407F130A1170AE4A40
15899	573	83.791634000000002	83.802655999999999	53.370893000000002	53.367707000000003	Школьная улица	0103000020E61000000100000005000000B519A721AAF2544051C1E10511AF4A40B519A721AAF254405DA8FC6B79AF4A400B7C45B75EF354405DA8FC6B79AF4A400B7C45B75EF3544051C1E10511AF4A40B519A721AAF2544051C1E10511AF4A40
70091	573	83.791634000000002	83.802655999999999	53.370893000000002	53.367707000000003	Школьная	0103000020E61000000100000005000000B519A721AAF2544051C1E10511AF4A40B519A721AAF254405DA8FC6B79AF4A400B7C45B75EF354405DA8FC6B79AF4A400B7C45B75EF3544051C1E10511AF4A40B519A721AAF2544051C1E10511AF4A40
70212	573	83.791634000000002	83.802655999999999	53.370893000000002	53.367707000000003	Школьная	0103000020E61000000100000005000000B519A721AAF2544051C1E10511AF4A40B519A721AAF254405DA8FC6B79AF4A400B7C45B75EF354405DA8FC6B79AF4A400B7C45B75EF3544051C1E10511AF4A40B519A721AAF2544051C1E10511AF4A40
70593	573	83.791634000000002	83.802655999999999	53.370893000000002	53.367707000000003	Школьная	0103000020E61000000100000005000000B519A721AAF2544051C1E10511AF4A40B519A721AAF254405DA8FC6B79AF4A400B7C45B75EF354405DA8FC6B79AF4A400B7C45B75EF3544051C1E10511AF4A40B519A721AAF2544051C1E10511AF4A40
70276	573	83.713220000000007	83.742801	53.379047	53.373519999999999	Чудненко	0103000020E610000001000000050000009AB67F65A5ED54407233DC80CFAF4A409AB67F65A5ED5440CE52B29C84B04A40E99B340D8AEF5440CE52B29C84B04A40E99B340D8AEF54407233DC80CFAF4A409AB67F65A5ED54407233DC80CFAF4A40
70236	573	83.752601999999996	83.797149000000005	53.346887000000002	53.329901999999997	Чкалова	0103000020E61000000100000005000000DE3994A12AF0544047718E3A3AAA4A40DE3994A12AF054402B3410CB66AC4A4081423D7D04F354402B3410CB66AC4A4081423D7D04F3544047718E3A3AAA4A40DE3994A12AF0544047718E3A3AAA4A40
70257	573	83.730763999999994	83.754559999999998	53.368169000000002	53.351235000000003	Червонная	0103000020E6100000010000000500000006465ED6C4EE5440F41ABB44F5AC4A4006465ED6C4EE544055336B2920AF4A40AAB706B64AF0544055336B2920AF4A40AAB706B64AF05440F41ABB44F5AC4A4006465ED6C4EE5440F41ABB44F5AC4A40
70239	573	83.686441000000002	83.700436999999994	53.257461999999997	53.252307000000002	Чайковского	0103000020E610000001000000050000008C683BA6EEEB5440A4C684984BA04A408C683BA6EEEB54403BFBCA83F4A04A4022FAB5F5D3EC54403BFBCA83F4A04A4022FAB5F5D3EC5440A4C684984BA04A408C683BA6EEEB5440A4C684984BA04A40
70269	573	83.686441000000002	83.700436999999994	53.257461999999997	53.252307000000002	Чайковского	0103000020E610000001000000050000008C683BA6EEEB5440A4C684984BA04A408C683BA6EEEB54403BFBCA83F4A04A4022FAB5F5D3EC54403BFBCA83F4A04A4022FAB5F5D3EC5440A4C684984BA04A408C683BA6EEEB5440A4C684984BA04A40
70282	573	83.686441000000002	83.700436999999994	53.257461999999997	53.252307000000002	Чайковского	0103000020E610000001000000050000008C683BA6EEEB5440A4C684984BA04A408C683BA6EEEB54403BFBCA83F4A04A4022FAB5F5D3EC54403BFBCA83F4A04A4022FAB5F5D3EC5440A4C684984BA04A408C683BA6EEEB5440A4C684984BA04A40
70709	573	83.639441000000005	83.683655999999999	53.255274999999997	53.238926999999997	Центральная	0103000020E610000001000000050000002EAEF199ECE85440D190F128959E4A402EAEF199ECE85440423EE8D9ACA04A40B56D1805C1EB5440423EE8D9ACA04A40B56D1805C1EB5440D190F128959E4A402EAEF199ECE85440D190F128959E4A40
70210	573	83.639441000000005	83.683655999999999	53.255274999999997	53.238926999999997	Центральная	0103000020E610000001000000050000002EAEF199ECE85440D190F128959E4A402EAEF199ECE85440423EE8D9ACA04A40B56D1805C1EB5440423EE8D9ACA04A40B56D1805C1EB5440D190F128959E4A402EAEF199ECE85440D190F128959E4A40
70215	573	83.596222999999995	83.609562999999994	53.403153000000003	53.399379000000003	Цветущая	0103000020E61000000100000005000000DF87838428E65440C7DADFD91EB34A40DF87838428E6544064247B849AB34A408176871403E7544064247B849AB34A408176871403E75440C7DADFD91EB34A40DF87838428E65440C7DADFD91EB34A40
70255	573	83.710992000000005	83.735157000000001	53.339542999999999	53.335386999999997	Фурманова	0103000020E61000000100000005000000EEED96E480ED5440744012F6EDAA4A40EEED96E480ED5440F94A202576AB4A403B1BF2CF0CEF5440F94A202576AB4A403B1BF2CF0CEF5440744012F6EDAA4A40EEED96E480ED5440744012F6EDAA4A40
70244	573	83.761441000000005	83.780405000000002	53.320689000000002	53.305362000000002	Фомина	0103000020E6100000010000000500000059350873BBF0544078B81D1A16A74A4059350873BBF05440EE974F560CA94A40A228D027F2F15440EE974F560CA94A40A228D027F2F1544078B81D1A16A74A4059350873BBF0544078B81D1A16A74A40
70235	573	83.724520999999996	83.724601000000007	53.386051000000002	53.373615999999998	Тимуровская	0103000020E61000000100000005000000F910548D5EEE544094A12AA6D2AF4A40F910548D5EEE544047CB811E6AB14A408869DFDC5FEE544047CB811E6AB14A408869DFDC5FEE544094A12AA6D2AF4A40F910548D5EEE544094A12AA6D2AF4A40
2290	573	83.726308000000003	83.741839999999996	53.363816	53.346026999999999	Телефонная улица	0103000020E61000000100000005000000AFB48CD47BEE54403944DC9C4AAC4A40AFB48CD47BEE54407AE1CE8591AE4A4056B77A4E7AEF54407AE1CE8591AE4A4056B77A4E7AEF54403944DC9C4AAC4A40AFB48CD47BEE54403944DC9C4AAC4A40
70253	573	83.771259999999998	83.783755999999997	53.354303999999999	53.349505000000001	Союза Республик	0103000020E61000000100000005000000A12DE7525CF15440ED647094BCAC4A40A12DE7525CF15440C66B5ED559AD4A40CD02ED0E29F25440C66B5ED559AD4A40CD02ED0E29F25440ED647094BCAC4A40A12DE7525CF15440ED647094BCAC4A40
2064	573	83.762304	83.793115999999998	53.349950999999997	53.326712999999998	Социалистический проспект	0103000020E610000001000000050000000A67B796C9F05440CA1649BBD1A94A400A67B796C9F05440EB19C231CBAC4A40CC7B9C69C2F25440EB19C231CBAC4A40CC7B9C69C2F25440CA1649BBD1A94A400A67B796C9F05440CA1649BBD1A94A40
69795	573	83.566227999999995	83.581473000000003	53.348934999999997	53.348025999999997	Соловьиная	0103000020E6100000010000000500000016855D143DE454402F14B01D8CAC4A4016855D143DE4544002B7EEE6A9AC4A4073A087DA36E5544002B7EEE6A9AC4A4073A087DA36E554402F14B01D8CAC4A4016855D143DE454402F14B01D8CAC4A40
70242	573	83.652879999999996	83.666148000000007	53.389268000000001	53.351418000000002	Солнечная Поляна	0103000020E61000000100000005000000990D32C9C8E95440E59CD843FBAC4A40990D32C9C8E954408EB0A888D3B14A40EF92382BA2EA54408EB0A888D3B14A40EF92382BA2EA5440E59CD843FBAC4A40990D32C9C8E95440E59CD843FBAC4A40
70225	573	83.699106999999998	83.740250000000003	53.357239	53.340209999999999	Советской Армии	0103000020E61000000100000005000000E659492BBEEC5440D6E253008CAB4A40E659492BBEEC544089EDEE01BAAD4A404C37894160EF544089EDEE01BAAD4A404C37894160EF5440D6E253008CAB4A40E659492BBEEC5440D6E253008CAB4A40
3276	573	83.787699000000003	83.798236000000003	53.365245999999999	53.362515999999999	Смольная улица	0103000020E61000000100000005000000E20511A969F254406C239EEC66AE4A40E20511A969F25440567F8461C0AE4A405A9F724C16F35440567F8461C0AE4A405A9F724C16F354406C239EEC66AE4A40E20511A969F254406C239EEC66AE4A40
2188	573	83.718457000000001	83.775931	53.384483000000003	53.348579999999998	Северо-Западная улица	0103000020E6100000010000000500000044A51133FBED54401405FA449EAC4A4044A51133FBED54401A6F2BBD36B14A40F73C7FDAA8F154401A6F2BBD36B14A40F73C7FDAA8F154401405FA449EAC4A4044A51133FBED54401405FA449EAC4A40
2676	573	83.667693	83.692316000000005	53.331724999999999	53.329090000000001	Северный Власихинский проезд	0103000020E6100000010000000500000029B16B7BBBEA544067B8019F1FAA4A4029B16B7BBBEA5440FF21FDF675AA4A40D89FC4E74EEC5440FF21FDF675AA4A40D89FC4E74EEC544067B8019F1FAA4A4029B16B7BBBEA544067B8019F1FAA4A40
16178	573	83.560623000000007	83.563569000000001	53.297052999999998	53.292425000000001	Ракитная улица	0103000020E61000000100000005000000AB984A3FE1E3544033C4B12E6EA54A40AB984A3FE1E35440DF162CD505A64A408602B68311E45440DF162CD505A64A408602B68311E4544033C4B12E6EA54A40AB984A3FE1E3544033C4B12E6EA54A40
70268	573	83.640501	83.652394999999999	53.291294000000001	53.287590999999999	Радужная	0103000020E610000001000000050000008A03E8F7FDE85440DDCF29C8CFA44A408A03E8F7FDE85440B1C22D1F49A54A40BB44F5D6C0E95440B1C22D1F49A54A40BB44F5D6C0E95440DDCF29C8CFA44A408A03E8F7FDE85440DDCF29C8CFA44A40
70207	573	83.779138000000003	83.791067999999996	53.356551000000003	53.353762000000003	Путиловская	0103000020E610000001000000050000008944A165DDF15440A648BE1248AD4A408944A165DDF15440952D9276A3AD4A40603AADDBA0F25440952D9276A3AD4A40603AADDBA0F25440A648BE1248AD4A408944A165DDF15440A648BE1248AD4A40
70252	573	83.762690000000006	83.778446000000002	53.358345999999997	53.35145	Профинтерна	0103000020E610000001000000050000001FBFB7E9CFF05440F0164850FCAC4A401FBFB7E9CFF0544082531F48DEAD4A40EEEC2B0FD2F1544082531F48DEAD4A40EEEC2B0FD2F15440F0164850FCAC4A401FBFB7E9CFF05440F0164850FCAC4A40
70326	573	83.749125000000006	83.799467000000007	53.343736999999997	53.324314000000001	Пролетарская	0103000020E610000001000000050000006DE7FBA9F1EF544046D1031F83A94A406DE7FBA9F1EF54406BB6F292FFAB4A40CDCEA2772AF354406BB6F292FFAB4A40CDCEA2772AF3544046D1031F83A94A406DE7FBA9F1EF544046D1031F83A94A40
70219	573	83.713175000000007	83.741077000000004	53.380659000000001	53.376446999999999	Петра Сухова	0103000020E61000000100000005000000CA54C1A8A4ED5440B2D6506A2FB04A40CA54C1A8A4ED5440CBF6216FB9B04A4057B439CE6DEF5440CBF6216FB9B04A4057B439CE6DEF5440B2D6506A2FB04A40CA54C1A8A4ED5440B2D6506A2FB04A40
70505	573	83.505350000000007	83.864953999999997	53.452658	53.184579999999997	Первомайская	0103000020E6100000010000000500000027C286A757E0544072BF4351A0974A4027C286A757E05440EA2285B2F0B94A40D7A205685BF75440EA2285B2F0B94A40D7A205685BF7544072BF4351A0974A4027C286A757E0544072BF4351A0974A40
1540	573	83.752683000000005	83.798578000000006	53.344698999999999	53.327111000000002	Партизанская улица	0103000020E61000000100000005000000555051F52BF05440B894F3C5DEA94A40555051F52BF0544061FBC9181FAC4A408753E6E61BF3544061FBC9181FAC4A408753E6E61BF35440B894F3C5DEA94A40555051F52BF05440B894F3C5DEA94A40
70250	573	83.675059000000005	83.677880000000002	53.355384999999998	53.344608000000001	Панфиловцев	0103000020E61000000100000005000000B6F7A92A34EB544051F86C1D1CAC4A40B6F7A92A34EB5440963E74417DAD4A4033A7CB6262EB5440963E74417DAD4A4033A7CB6262EB544051F86C1D1CAC4A40B6F7A92A34EB544051F86C1D1CAC4A40
2455	573	83.510667999999995	83.742658000000006	53.356250000000003	53.339049000000003	Павловский тракт	0103000020E6100000010000000500000047C7D5C8AEE05440EA5E27F565AB4A4047C7D5C8AEE054409A99999999AD4A4038876BB587EF54409A99999999AD4A4038876BB587EF5440EA5E27F565AB4A4047C7D5C8AEE05440EA5E27F565AB4A40
69921	573	83.690905999999998	83.822705999999997	53.391646999999999	53.312787	Опытная станция	0103000020E610000001000000050000000DA7CCCD37EC544096CE876709A84A400DA7CCCD37EC5440CB49287D21B24A40450E1137A7F45440CB49287D21B24A40450E1137A7F4544096CE876709A84A400DA7CCCD37EC544096CE876709A84A40
70103	573	83.591453000000001	83.622767999999994	53.311528000000003	53.299410000000002	Новосибирская улица	0103000020E61000000100000005000000C007AF5DDAE55440350C1F1153A64A40C007AF5DDAE55440E7E44526E0A74A40B33F506EDBE75440E7E44526E0A74A40B33F506EDBE75440350C1F1153A64A40C007AF5DDAE55440350C1F1153A64A40
70256	573	83.591453000000001	83.622767999999994	53.311528000000003	53.299410000000002	Новосибирская	0103000020E61000000100000005000000C007AF5DDAE55440350C1F1153A64A40C007AF5DDAE55440E7E44526E0A74A40B33F506EDBE75440E7E44526E0A74A40B33F506EDBE75440350C1F1153A64A40C007AF5DDAE55440350C1F1153A64A40
70222	573	83.689144999999996	83.702539000000002	53.255108	53.249408000000003	Мусоргского	0103000020E61000000100000005000000EC4CA1F31AEC54402EAEF199EC9F4A40EC4CA1F31AEC544057790261A7A04A40884A2366F6EC544057790261A7A04A40884A2366F6EC54402EAEF199EC9F4A40EC4CA1F31AEC54402EAEF199EC9F4A40
70274	573	83.678005999999996	83.682246000000006	53.383429999999997	53.378971999999997	Монтажников	0103000020E61000000100000005000000791F477364EB5440C30C8D2782B04A40791F477364EB54401327F73B14B14A40EB7420EBA9EB54401327F73B14B14A40EB7420EBA9EB5440C30C8D2782B04A40791F477364EB5440C30C8D2782B04A40
15989	573	83.747777999999997	83.784636000000006	53.351987999999999	53.337429999999998	Молодежная улица	0103000020E61000000100000005000000C5AA4198DBEF54403A58FFE730AB4A40C5AA4198DBEF5440CF4A5AF10DAD4A40EAD0E97937F25440CF4A5AF10DAD4A40EAD0E97937F254403A58FFE730AB4A40C5AA4198DBEF54403A58FFE730AB4A40
70254	573	83.747777999999997	83.784636000000006	53.351987999999999	53.337429999999998	Молодежная	0103000020E61000000100000005000000C5AA4198DBEF54403A58FFE730AB4A40C5AA4198DBEF5440CF4A5AF10DAD4A40EAD0E97937F25440CF4A5AF10DAD4A40EAD0E97937F254403A58FFE730AB4A40C5AA4198DBEF54403A58FFE730AB4A40
70199	573	83.787582	83.792828	53.357362999999999	53.357035000000003	Мира	0103000020E61000000100000005000000C53A55BE67F254408143A852B3AD4A40C53A55BE67F2544075E61E12BEAD4A4099D6A6B1BDF2544075E61E12BEAD4A4099D6A6B1BDF254408143A852B3AD4A40C53A55BE67F254408143A852B3AD4A40
70238	573	83.781644	83.790664000000007	53.386797999999999	53.378155999999997	Маяковского	0103000020E6100000010000000500000056478E7406F25440A164726A67B04A4056478E7406F254404014CC9882B14A40F9872D3D9AF254404014CC9882B14A40F9872D3D9AF25440A164726A67B04A4056478E7406F25440A164726A67B04A40
70137	573	83.794589000000002	83.796610000000001	53.302003999999997	53.300916999999998	Матросская улица	0103000020E61000000100000005000000BA30D28BDAF25440BCE7C07284A64A40BA30D28BDAF254406EA12B11A8A64A40A96A82A8FBF254406EA12B11A8A64A40A96A82A8FBF25440BCE7C07284A64A40BA30D28BDAF25440BCE7C07284A64A40
70285	573	83.691857999999996	83.713256000000001	53.393881	53.327266999999999	Малахова	0103000020E6100000010000000500000076DEC66647EC5440AF0793E2E3A94A4076DEC66647EC544005C24EB16AB24A40406B7EFCA5ED544005C24EB16AB24A40406B7EFCA5ED5440AF0793E2E3A94A4076DEC66647EC5440AF0793E2E3A94A40
70719	573	83.468456000000003	83.486250999999996	53.261539999999997	53.250678999999998	Лесной поселок	0103000020E610000001000000050000005CE7DF2EFBDD5440A165DD3F16A04A405CE7DF2EFBDD5440444C89247AA14A406DA983BC1EDF5440444C89247AA14A406DA983BC1EDF5440A165DD3F16A04A405CE7DF2EFBDD5440A165DD3F16A04A40
70213	573	83.677897999999999	83.681815	53.361269	53.355449	Ленинградская	0103000020E6100000010000000500000086014BAE62EB5440AD32535A7FAD4A4086014BAE62EB5440810706103EAE4A4006BB61DBA2EB5440810706103EAE4A4006BB61DBA2EB5440AD32535A7FAD4A4086014BAE62EB5440AD32535A7FAD4A40
70266	573	83.708414000000005	83.746178999999998	53.319704999999999	53.311151000000002	Кутузова	0103000020E61000000100000005000000D481ACA756ED5440118FC4CBD3A74A40D481ACA756ED544010AFEB17ECA84A40917D9065C1EF544010AFEB17ECA84A40917D9065C1EF5440118FC4CBD3A74A40D481ACA756ED5440118FC4CBD3A74A40
70706	573	83.642981000000006	83.653544999999994	53.311539000000003	53.309052999999999	Куета	0103000020E61000000100000005000000C3BCC79926E9544087DD770C8FA74A40C3BCC79926E95440DB368C82E0A74A40B75D68AED3E95440DB368C82E0A74A40B75D68AED3E9544087DD770C8FA74A40C3BCC79926E9544087DD770C8FA74A40
2002	573	83.761369000000002	83.786306999999994	53.349170999999998	53.326734999999999	Красноармейский проспект	0103000020E610000001000000050000000CCC0A45BAF05440B2BAD573D2A94A400CCC0A45BAF0544016DBA4A2B1AC4A406A6798DA52F2544016DBA4A2B1AC4A406A6798DA52F25440B2BAD573D2A94A400CCC0A45BAF05440B2BAD573D2A94A40
70267	573	83.759932000000006	83.802691999999993	53.339559000000001	53.322943000000002	Короленко	0103000020E61000000100000005000000C5CBD3B9A2F054406FBC3B3256A94A40C5CBD3B9A2F05440FF0758AB76AB4A40B130444E5FF35440FF0758AB76AB4A40B130444E5FF354406FBC3B3256A94A40C5CBD3B9A2F054406FBC3B3256A94A40
3238	573	83.777996999999999	83.800949000000003	53.364268000000003	53.333649999999999	Комсомольский проспект	0103000020E61000000100000005000000B6D8EDB3CAF15440BB270F0BB5AA4A40B6D8EDB3CAF154405B7D7555A0AE4A40E43098BF42F354405B7D7555A0AE4A40E43098BF42F35440BB270F0BB5AA4A40B6D8EDB3CAF15440BB270F0BB5AA4A40
70243	573	83.745459999999994	83.800419000000005	53.342790999999998	53.321609000000002	Интернациональная	0103000020E61000000100000005000000791EDC9DB5EF5440B58CD47B2AA94A40791EDC9DB5EF54407B2E5393E0AB4A4036069D103AF354407B2E5393E0AB4A4036069D103AF35440B58CD47B2AA94A40791EDC9DB5EF5440B58CD47B2AA94A40
3926	573	83.693888000000001	83.771583000000007	53.30724	53.236156999999999	Змеиногорский тракт	0103000020E610000001000000050000008FC536A968EC544059DC7F643A9E4A408FC536A968EC5440F302ECA353A74A4093C9A99D61F15440F302ECA353A74A4093C9A99D61F1544059DC7F643A9E4A408FC536A968EC544059DC7F643A9E4A40
70198	573	83.693888000000001	83.771583000000007	53.30724	53.236156999999999	Змеиногорский тракт	0103000020E610000001000000050000008FC536A968EC544059DC7F643A9E4A408FC536A968EC5440F302ECA353A74A4093C9A99D61F15440F302ECA353A74A4093C9A99D61F1544059DC7F643A9E4A408FC536A968EC544059DC7F643A9E4A40
2114	573	83.764252999999997	83.773380000000003	53.356136999999997	53.347676999999997	Деповская улица	0103000020E61000000100000005000000AC376A85E9F05440234910AE80AC4A40AC376A85E9F05440A1F2AFE595AD4A405AD8D30E7FF15440A1F2AFE595AD4A405AD8D30E7FF15440234910AE80AC4A40AC376A85E9F05440234910AE80AC4A40
70271	573	83.764252999999997	83.773380000000003	53.356136999999997	53.347676999999997	Деповская	0103000020E61000000100000005000000AC376A85E9F05440234910AE80AC4A40AC376A85E9F05440A1F2AFE595AD4A405AD8D30E7FF15440A1F2AFE595AD4A405AD8D30E7FF15440234910AE80AC4A40AC376A85E9F05440234910AE80AC4A40
70232	573	83.665322000000003	83.748649	53.378611999999997	53.356797999999998	Гущина	0103000020E61000000100000005000000CCD3B9A294EA54409CA38E8EABAD4A40CCD3B9A294EA5440C3EFA65B76B04A40B8CB7EDDE9EF5440C3EFA65B76B04A40B8CB7EDDE9EF54409CA38E8EABAD4A40CCD3B9A294EA54409CA38E8EABAD4A40
3362	573	83.729326999999998	83.746753999999996	53.375351999999999	53.368636000000002	Горно-Алтайская улица	0103000020E61000000100000005000000BF45274BADEE54406B10E6762FAF4A40BF45274BADEE54407D3ECA880BB04A400F0A4AD1CAEF54407D3ECA880BB04A400F0A4AD1CAEF54406B10E6762FAF4A40BF45274BADEE54406B10E6762FAF4A40
70501	573	83.729326999999998	83.746753999999996	53.375351999999999	53.368636000000002	Горно-Алтайская	0103000020E61000000100000005000000BF45274BADEE54406B10E6762FAF4A40BF45274BADEE54407D3ECA880BB04A400F0A4AD1CAEF54407D3ECA880BB04A400F0A4AD1CAEF54406B10E6762FAF4A40BF45274BADEE54406B10E6762FAF4A40
70246	573	83.650301999999996	83.753176999999994	53.369259	53.350315999999999	Георгия Исакова	0103000020E610000001000000050000007FA1478C9EE95440FDA19927D7AC4A407FA1478C9EE95440786000E143AF4A405CC64D0D34F05440786000E143AF4A405CC64D0D34F05440FDA19927D7AC4A407FA1478C9EE95440FDA19927D7AC4A40
70248	573	83.737168999999994	83.740403000000001	53.364074000000002	53.362628999999998	Воронежская	0103000020E6100000010000000500000000A8E2C62DEF544064CA87A06AAE4A4000A8E2C62DEF544076A911FA99AE4A400FB743C362EF544076A911FA99AE4A400FB743C362EF544064CA87A06AAE4A4000A8E2C62DEF544064CA87A06AAE4A40
70264	573	83.779875000000004	83.803842000000003	53.372402000000001	53.367159000000001	Водопроводная	0103000020E61000000100000005000000F4FDD478E9F154404EB7EC10FFAE4A40F4FDD478E9F15440857B65DEAAAF4A40AE49B72572F35440857B65DEAAAF4A40AE49B72572F354404EB7EC10FFAE4A40F4FDD478E9F154404EB7EC10FFAE4A40
70249	573	83.643456999999998	83.694400000000002	53.342317000000001	53.337876999999999	Взлетная	0103000020E6100000010000000500000077D844662EE954400989B48D3FAB4A4077D844662EE95440B3EE1F0BD1AB4A40EA95B20C71EC5440B3EE1F0BD1AB4A40EA95B20C71EC54400989B48D3FAB4A4077D844662EE954400989B48D3FAB4A40
2588	573	83.733476999999993	83.746618999999995	53.318403000000004	53.314939000000003	Боровая улица	0103000020E6100000010000000500000090D78349F1EE5440139ED0EB4FA84A4090D78349F1EE544062F9F36DC1A84A409FE40E9BC8EF544062F9F36DC1A84A409FE40E9BC8EF5440139ED0EB4FA84A4090D78349F1EE5440139ED0EB4FA84A40
70071	573	83.613919999999993	83.619534000000002	53.304468999999997	53.302681999999997	Благовещенская	0103000020E610000001000000050000000F971C774AE754403F8BA548BEA64A400F971C774AE75440AAD216D7F8A64A40A530EF71A6E75440AAD216D7F8A64A40A530EF71A6E754403F8BA548BEA64A400F971C774AE754403F8BA548BEA64A40
70226	573	83.642594000000003	83.745191000000005	53.364977000000003	53.347048000000001	Антона Петрова	0103000020E61000000100000005000000C6A6954220E954403412A1116CAC4A40C6A6954220E954406765FB90B7AE4A4082919735B1EF54406765FB90B7AE4A4082919735B1EF54403412A1116CAC4A40C6A6954220E954403412A1116CAC4A40
70220	573	83.747437000000005	83.801379999999995	53.341800999999997	53.320576000000003	Анатолия	0103000020E6100000010000000500000081B4FF01D6EF5440F6F065A208A94A4081B4FF01D6EF5440BB5E9A22C0AB4A40C8EA56CF49F35440BB5E9A22C0AB4A40C8EA56CF49F35440F6F065A208A94A4081B4FF01D6EF5440F6F065A208A94A40
70259	573	83.771583000000007	83.792845999999997	53.323540000000001	53.30724	Аванесова	0103000020E6100000010000000500000093C9A99D61F15440F302ECA353A74A4093C9A99D61F1544053793BC269A94A40EC3026FDBDF2544053793BC269A94A40EC3026FDBDF25440F302ECA353A74A4093C9A99D61F15440F302ECA353A74A40
3152	573	83.678060000000002	83.727225000000004	53.394154999999998	53.391534	9-й Заводской проезд	0103000020E61000000100000005000000732EC55565EB5440D3A23EC91DB24A40732EC55565EB54400647C9AB73B24A405AF5B9DA8AEE54400647C9AB73B24A405AF5B9DA8AEE5440D3A23EC91DB24A40732EC55565EB5440D3A23EC91DB24A40
70231	573	83.505350000000007	83.864953999999997	53.452658	53.184579999999997	80 Гвардейской Дивизии	0103000020E6100000010000000500000027C286A757E0544072BF4351A0974A4027C286A757E05440EA2285B2F0B94A40D7A205685BF75440EA2285B2F0B94A40D7A205685BF7544072BF4351A0974A4027C286A757E0544072BF4351A0974A40
70251	573	83.505350000000007	83.864953999999997	53.452658	53.184579999999997	50 лет СССР	0103000020E6100000010000000500000027C286A757E0544072BF4351A0974A4027C286A757E05440EA2285B2F0B94A40D7A205685BF75440EA2285B2F0B94A40D7A205685BF7544072BF4351A0974A4027C286A757E0544072BF4351A0974A40
70258	573	83.505350000000007	83.864953999999997	53.452658	53.184579999999997	42 Краснознаменной Бригады	0103000020E6100000010000000500000027C286A757E0544072BF4351A0974A4027C286A757E05440EA2285B2F0B94A40D7A205685BF75440EA2285B2F0B94A40D7A205685BF7544072BF4351A0974A4027C286A757E0544072BF4351A0974A40
70245	573	83.755126000000004	83.795955000000006	53.350580000000001	53.334822000000003	 Папанинцев	0103000020E61000000100000005000000FF9600FC53F054409CFD8172DBAA4A40FF9600FC53F05440DB5031CEDFAC4A409D853DEDF0F25440DB5031CEDFAC4A409D853DEDF0F254409CFD8172DBAA4A40FF9600FC53F054409CFD8172DBAA4A40
69844	59365	80.731226000000007	80.803010999999998	53.282536	53.253039000000001	Терешковой	0103000020E6100000010000000500000009FF2268CC2E544068CEFA9463A04A4009FF2268CC2E5440A9F8BF232AA44A4002D53F8864335440A9F8BF232AA44A4002D53F886433544068CEFA9463A04A4009FF2268CC2E544068CEFA9463A04A40
69866	59368	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	Карла Маркса	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
69652	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	пер.Пляжный	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
70518	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Энергетиков	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
69786	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Школьная	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
70061	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Ширшова	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
69598	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Ульяновский	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
69594	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Первомайская	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
69919	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Партизанская	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
69596	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Комсомольская	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
70418	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Дорожная	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
70060	5685	82.739230000000006	82.819593999999995	52.510038999999999	52.456890000000001	Ветеранов	0103000020E61000000100000005000000378E588B4FAF54404AEF1B5F7B3A4A40378E588B4FAF54409F573CF548414A40DC7F643A74B454409F573CF548414A40DC7F643A74B454404AEF1B5F7B3A4A40378E588B4FAF54404AEF1B5F7B3A4A40
70658	5032	85.863309999999998	85.904238000000007	54.037139000000003	54.020617000000001	Ленина	0103000020E61000000100000005000000D313967840775540EE5EEE93A3024B40D313967840775540FD3383F8C0044B403B730F09DF795540FD3383F8C0044B403B730F09DF795540EE5EEE93A3024B40D313967840775540EE5EEE93A3024B40
71065	23902	82.533067000000003	82.561059	51.903286999999999	51.895828999999999	Мира	0103000020E61000000100000005000000EBE40CC51DA2544079E75086AAF24940EBE40CC51DA2544073F38DE89EF3494018080264E8A3544073F38DE89EF3494018080264E8A3544079E75086AAF24940EBE40CC51DA2544079E75086AAF24940
70038	24969	82.205595000000002	82.258280999999997	52.168779000000001	52.149757000000001	Южный	0103000020E61000000100000005000000274EEE77288D54406DACC43C2B134A40274EEE77288D544034A0DE8C9A154A40670B08AD8790544034A0DE8C9A154A40670B08AD879054406DACC43C2B134A40274EEE77288D54406DACC43C2B134A40
70696	24969	82.205595000000002	82.258280999999997	52.168779000000001	52.149757000000001	Школьная	0103000020E61000000100000005000000274EEE77288D54406DACC43C2B134A40274EEE77288D544034A0DE8C9A154A40670B08AD8790544034A0DE8C9A154A40670B08AD879054406DACC43C2B134A40274EEE77288D54406DACC43C2B134A40
70592	24969	82.205595000000002	82.258280999999997	52.168779000000001	52.149757000000001	Целинная	0103000020E61000000100000005000000274EEE77288D54406DACC43C2B134A40274EEE77288D544034A0DE8C9A154A40670B08AD8790544034A0DE8C9A154A40670B08AD879054406DACC43C2B134A40274EEE77288D54406DACC43C2B134A40
69769	24969	82.205595000000002	82.258280999999997	52.168779000000001	52.149757000000001	Совхозный	0103000020E61000000100000005000000274EEE77288D54406DACC43C2B134A40274EEE77288D544034A0DE8C9A154A40670B08AD8790544034A0DE8C9A154A40670B08AD879054406DACC43C2B134A40274EEE77288D54406DACC43C2B134A40
70633	24969	82.205595000000002	82.258280999999997	52.168779000000001	52.149757000000001	Мостовая	0103000020E61000000100000005000000274EEE77288D54406DACC43C2B134A40274EEE77288D544034A0DE8C9A154A40670B08AD8790544034A0DE8C9A154A40670B08AD879054406DACC43C2B134A40274EEE77288D54406DACC43C2B134A40
70096	24969	82.205595000000002	82.258280999999997	52.168779000000001	52.149757000000001	Луначарского	0103000020E61000000100000005000000274EEE77288D54406DACC43C2B134A40274EEE77288D544034A0DE8C9A154A40670B08AD8790544034A0DE8C9A154A40670B08AD879054406DACC43C2B134A40274EEE77288D54406DACC43C2B134A40
70635	24923	82.000420000000005	82.039918999999998	52.079951999999999	52.065117000000001	Мамонтова	0103000020E61000000100000005000000EB909BE106805440F2B4FCC055084A40EB909BE106805440F99FFCDD3B0A4A404CDF6B088E825440F99FFCDD3B0A4A404CDF6B088E825440F2B4FCC055084A40EB909BE106805440F2B4FCC055084A40
71237	23709	82.810691000000006	82.834864999999994	52.134977999999997	52.118817	Центральная	0103000020E61000000100000005000000570A815CE2B35440BB9A3C65350F4A40570A815CE2B35440F9D687F546114A40CDE49B6D6EB55440F9D687F546114A40CDE49B6D6EB55440BB9A3C65350F4A40570A815CE2B35440BB9A3C65350F4A40
70517	24886	81.986774999999994	82.031124000000005	52.581316000000001	52.560395999999997	Фрунзе	0103000020E61000000100000005000000AA605452277F544094675E0EBB474A40AA605452277F54401E520C90684A4A40BA8784EFFD8154401E520C90684A4A40BA8784EFFD81544094675E0EBB474A40AA605452277F544094675E0EBB474A40
70044	24804	82.573194999999998	82.618146999999993	52.083826000000002	52.064613000000001	Ползунова	0103000020E61000000100000005000000C4CE143AAFA45440BFF2203D45084A40C4CE143AAFA45440FA4674CFBA0A4A40B6476FB88FA75440FA4674CFBA0A4A40B6476FB88FA75440BFF2203D45084A40C4CE143AAFA45440BFF2203D45084A40
70628	24744	82.68844	82.713106999999994	52.138123	52.119092999999999	Октябрьская	0103000020E610000001000000050000008750A5660FAC54405D177E703E0F4A408750A5660FAC5440A7E9B303AE114A401DE38A8BA3AD5440A7E9B303AE114A401DE38A8BA3AD54405D177E703E0F4A408750A5660FAC54405D177E703E0F4A40
69816	24653	81.986011000000005	82.011450999999994	52.381095000000002	52.366399000000001	Мамонтовская	0103000020E61000000100000005000000C39FE1CD1A7F5440C0249529E62E4A40C39FE1CD1A7F5440A6D590B8C7304A406AA0F99CBB805440A6D590B8C7304A406AA0F99CBB805440C0249529E62E4A40C39FE1CD1A7F5440C0249529E62E4A40
9880	40339	81.911253000000002	81.938832000000005	52.275494000000002	52.260945	Центральная	0103000020E6100000010000000500000071581AF8517A5440018750A566214A4071581AF8517A5440431F2C6343234A400D1CD0D2157C5440431F2C6343234A400D1CD0D2157C5440018750A566214A4071581AF8517A5440018750A566214A40
70380	24549	82.148031000000003	82.173587999999995	52.314678000000001	52.300669999999997	Тарасова	0103000020E61000000100000005000000D4F2035779895440B471C45A7C264A40D4F2035779895440A662635E47284A4098BED7101C8B5440A662635E47284A4098BED7101C8B5440B471C45A7C264A40D4F2035779895440B471C45A7C264A40
71245	23845	82.396423999999996	82.413878999999994	51.809730000000002	51.792760000000001	Сергея Качусова	0103000020E610000001000000050000005ED6C4025F995440DAC9E02879E549405ED6C4025F995440884B8E3BA5E74940136058FE7C9A5440884B8E3BA5E74940136058FE7C9A5440DAC9E02879E549405ED6C4025F995440DAC9E02879E54940
71240	24295	82.445894999999993	82.452343999999997	52.172694999999997	52.167216000000003	Весенняя	0103000020E61000000100000005000000CB9C2E8B899C544019AF795567154A40CB9C2E8B899C54406397A8DE1A164A40ADA23F34F39C54406397A8DE1A164A40ADA23F34F39C544019AF795567154A40CB9C2E8B899C544019AF795567154A40
71059	24843	82.548392000000007	82.575727999999998	52.051327999999998	52.040156000000003	Целинная	0103000020E61000000100000005000000D658C2DA18A354407D5EF1D423054A40D658C2DA18A354403EAF78EA91064A400ED940BAD8A454403EAF78EA91064A400ED940BAD8A454407D5EF1D423054A40D658C2DA18A354407D5EF1D423054A40
71064	24503	81.995012000000003	82.011792999999997	52.328313000000001	52.314430000000002	Советская	0103000020E610000001000000050000002AC8CF46AE7F5440CE70033E3F284A402AC8CF46AE7F544003ED0E29062A4A4097546D37C180544003ED0E29062A4A4097546D37C1805440CE70033E3F284A402AC8CF46AE7F5440CE70033E3F284A40
70629	24444	82.388681000000005	82.411938000000006	52.274602000000002	52.256292000000002	1-е Черемушки	0103000020E61000000100000005000000E7E44526E0985440FC1C1F2DCE204A40E7E44526E098544046B5882826234A40B37E33315D9A544046B5882826234A40B37E33315D9A5440FC1C1F2DCE204A40E7E44526E0985440FC1C1F2DCE204A40
71443	23423	82.473742000000001	82.490405999999993	52.080128999999999	52.072412999999997	Майская	0103000020E61000000100000005000000772FF7C9519E5440126745D444094A40772FF7C9519E5440083BC5AA410A4A40C7F0D8CF629F5440083BC5AA410A4A40C7F0D8CF629F5440126745D444094A40772FF7C9519E5440126745D444094A40
71244	24336	82.479420000000005	82.497619999999998	52.001106	51.987675000000003	Новая	0103000020E61000000100000005000000184339D1AE9E5440D50968226CFE4940184339D1AE9E544029EACC3D24004A4079758E01D99F544029EACC3D24004A4079758E01D99F5440D50968226CFE4940184339D1AE9E5440D50968226CFE4940
70478	24238	82.345319000000003	82.374433999999994	52.199359000000001	52.184679000000003	Садовая	0103000020E61000000100000005000000FFEBDCB41996544006A1BC8FA3174A40FFEBDCB419965440E694809884194A40AB2006BAF6975440E694809884194A40AB2006BAF697544006A1BC8FA3174A40FFEBDCB41996544006A1BC8FA3174A40
70881	23666	82.850711000000004	82.868506999999994	52.064684999999997	52.052751999999998	Центральная	0103000020E610000001000000050000003DD68C0C72B654403866D993C0064A403DD68C0C72B6544058C51B9947084A403656629E95B7544058C51B9947084A403656629E95B754403866D993C0064A403DD68C0C72B654403866D993C0064A40
71451	23995	81.678769000000003	81.708279000000005	52.418937	52.402813999999999	Школьная	0103000020E61000000100000005000000792288F3706B54407B2FBE688F334A40792288F3706B5440CC0A45BA9F354A40645C7171546D5440CC0A45BA9F354A40645C7171546D54407B2FBE688F334A40792288F3706B54407B2FBE688F334A40
70469	24196	82.688359000000005	82.743595999999997	51.936804000000002	51.909059999999997	Дубинина	0103000020E61000000100000005000000113AE8120EAC5440060DFD135CF44940113AE8120EAC544089618731E9F74940EE5BAD1397AF544089618731E9F74940EE5BAD1397AF5440060DFD135CF44940113AE8120EAC5440060DFD135CF44940
71061	24401	82.446900999999997	82.467454000000004	51.954312999999999	51.944853999999999	Школьная	0103000020E610000001000000050000002EE3A6069A9C544055BFD2F9F0F849402EE3A6069A9C5440E692AAED26FA49409A982EC4EA9D5440E692AAED26FA49409A982EC4EA9D544055BFD2F9F0F849402EE3A6069A9C544055BFD2F9F0F84940
71242	24144	82.356126000000003	82.379041999999998	51.963099	51.9437	Школьный	0103000020E6100000010000000500000057D0B4C4CA9654401B9E5E29CBF8494057D0B4C4CA965440B8E7F9D346FB4940DE73603942985440B8E7F9D346FB4940DE736039429854401B9E5E29CBF8494057D0B4C4CA9654401B9E5E29CBF84940
70588	23944	81.819597999999999	81.847786999999997	52.493527	52.477128999999998	Центральная	0103000020E610000001000000050000007D772B4B74745440917C2590123D4A407D772B4B74745440B4588AE42B3F4A4055BE672442765440B4588AE42B3F4A4055BE672442765440917C2590123D4A407D772B4B74745440917C2590123D4A40
69972	2677	82.385276000000005	82.408604999999994	51.922758999999999	51.891677000000001	им.Рыжакова	0103000020E61000000100000005000000C2FBAA5CA898544036CCD07822F24940C2FBAA5CA89854407A8B87F71CF64940DAFE9595269A54407A8B87F71CF64940DAFE9595269A544036CCD07822F24940C2FBAA5CA898544036CCD07822F24940
70589	2677	82.385276000000005	82.408604999999994	51.922758999999999	51.891677000000001	Советская	0103000020E61000000100000005000000C2FBAA5CA898544036CCD07822F24940C2FBAA5CA89854407A8B87F71CF64940DAFE9595269A54407A8B87F71CF64940DAFE9595269A544036CCD07822F24940C2FBAA5CA898544036CCD07822F24940
70036	23758	81.526692999999995	83.045492999999993	52.636696000000001	51.742396999999997	Октябрьская	0103000020E610000001000000050000000E828E56B561544002D369DD06DF49400E828E56B56154403CBF28417F514A409ACC785BE9C254403CBF28417F514A409ACC785BE9C2544002D369DD06DF49400E828E56B561544002D369DD06DF4940
71382	29253	82.133362000000005	82.157786999999999	51.980280999999998	51.961117000000002	Молодёжная	0103000020E61000000100000005000000DE21C500898854409850C1E105FB4940DE21C50089885440F1F109D979FD4940F92EA52E198A5440F1F109D979FD4940F92EA52E198A54409850C1E105FB4940DE21C500898854409850C1E105FB4940
71295	23627	82.969127	82.989546000000004	52.069583999999999	52.061584000000003	Центральная	0103000020E61000000100000005000000EBAA402D06BE54407BFA08FCE1074A40EBAA402D06BE54409529E620E8084A40CFF8BEB854BF54409529E620E8084A40CFF8BEB854BF54407BFA08FCE1074A40EBAA402D06BE54407BFA08FCE1074A40
70372	23535	82.162602000000007	82.190664999999996	52.145843999999997	52.128233000000002	Главный	0103000020E61000000100000005000000E9103812688A54404DA25EF069104A40E9103812688A5440AE282504AB124A407ADFF8DA338C5440AE282504AB124A407ADFF8DA338C54404DA25EF069104A40E9103812688A54404DA25EF069104A40
70717	23473	82.111551000000006	82.158801999999994	52.422215999999999	52.403413	Молодежная 	0103000020E610000001000000050000008335CEA62387544000E48409A3334A408335CEA62387544089EC832C0B364A408522DDCF298A544089EC832C0B364A408522DDCF298A544000E48409A3334A408335CEA62387544000E48409A3334A40
71452	24096	82.461965000000006	82.478755000000007	52.048554000000003	52.025086000000002	Набережная	0103000020E6100000010000000500000063B9A5D5909D544032CB9E0436034A4063B9A5D5909D5440850B790437064A40FAF202ECA39E5440850B790437064A40FAF202ECA39E544032CB9E0436034A4063B9A5D5909D544032CB9E0436034A40
70373	23378	82.553844999999995	82.587019999999995	52.124684000000002	52.106284000000002	Комарова	0103000020E6100000010000000500000066834C3272A35440460BD0B69A0D4A4066834C3272A35440D02A33A5F50F4A40448655BC91A55440D02A33A5F50F4A40448655BC91A55440460BD0B69A0D4A4066834C3272A35440460BD0B69A0D4A40
71239	23338	81.857579000000001	81.890251000000006	52.223075999999999	52.209442000000003	Рукина	0103000020E6100000010000000500000021AF0793E27654405534D6FECE1A4A4021AF0793E2765440E1421EC18D1C4A40CE8E54DFF9785440E1421EC18D1C4A40CE8E54DFF97854405534D6FECE1A4A4021AF0793E27654405534D6FECE1A4A40
71438	24047	81.719076999999999	81.748082999999994	52.439106000000002	52.423231999999999	Центральная	0103000020E610000001000000050000009293895B056E5440724F57772C364A409293895B056E54401BBD1AA034384A4063EC8497E06F54401BBD1AA034384A4063EC8497E06F5440724F57772C364A409293895B056E5440724F57772C364A40
70190	22635	82.581630000000004	82.651357000000004	53.425474000000001	53.401525999999997	Пушкина	0103000020E61000000100000005000000D717096D39A55440313F373465B34A40D717096D39A554402FA699EE75B64A40534145D5AFA954402FA699EE75B64A40534145D5AFA95440313F373465B34A40D717096D39A55440313F373465B34A40
70187	22635	82.581630000000004	82.651357000000004	53.425474000000001	53.401525999999997	Ленина	0103000020E61000000100000005000000D717096D39A55440313F373465B34A40D717096D39A554402FA699EE75B64A40534145D5AFA954402FA699EE75B64A40534145D5AFA95440313F373465B34A40D717096D39A55440313F373465B34A40
71235	23282	81.867478000000006	81.893296000000007	53.504809999999999	53.494452000000003	Набережная	0103000020E61000000100000005000000F8FF71C2847754408DB800344ABF4A40F8FF71C284775440CD58349D9DC04A407369FCC22B795440CD58349D9DC04A407369FCC22B7954408DB800344ABF4A40F8FF71C2847754408DB800344ABF4A40
71448	23102	82.152576999999994	82.173677999999995	53.500360000000001	53.492426999999999	Советская	0103000020E61000000100000005000000CB4752D2C38954406D5512D907BF4A40CB4752D2C3895440001DE6CB0BC04A403882548A1D8B5440001DE6CB0BC04A403882548A1D8B54406D5512D907BF4A40CB4752D2C38954406D5512D907BF4A40
71523	59476	81.663596999999996	82.683893999999995	53.680399000000001	53.248593999999997	Школьная улица	0103000020E61000000100000005000000512E8D5F786A5440ACFD9DEDD19F4A40512E8D5F786A5440959D7E5017D74A408FFB56EBC4AB5440959D7E5017D74A408FFB56EBC4AB5440ACFD9DEDD19F4A40512E8D5F786A5440ACFD9DEDD19F4A40
71441	23067	82.203474999999997	82.238446999999994	53.492491000000001	53.471378999999999	Цветочная	0103000020E610000001000000050000006EA301BC058D5440B682A62556BC4A406EA301BC058D54408449F1F109BF4A4013B534B7428F54408449F1F109BF4A4013B534B7428F5440B682A62556BC4A406EA301BC058D5440B682A62556BC4A40
70564	59400	81.663596999999996	82.683893999999995	53.680399000000001	53.248593999999997	Садовая	0103000020E61000000100000005000000512E8D5F786A5440ACFD9DEDD19F4A40512E8D5F786A5440959D7E5017D74A408FFB56EBC4AB5440959D7E5017D74A408FFB56EBC4AB5440ACFD9DEDD19F4A40512E8D5F786A5440ACFD9DEDD19F4A40
71321	22969	81.964873999999995	82.007238000000001	53.303167000000002	53.277728000000003	Орловская	0103000020E61000000100000005000000AFB0E07EC07D54407D9752978CA34A40AFB0E07EC07D5440FC1C1F2DCEA64A4076525F9676805440FC1C1F2DCEA64A4076525F96768054407D9752978CA34A40AFB0E07EC07D54407D9752978CA34A40
70621	22787	82.449757000000005	82.484396000000004	53.452396	53.433188999999999	Михайлова	0103000020E610000001000000050000006A8995D1C89C544054FEB5BC72B74A406A8995D1C89C5440AD6BB41CE8B94A400C941458009F5440AD6BB41CE8B94A400C941458009F544054FEB5BC72B74A406A8995D1C89C544054FEB5BC72B74A40
70465	23194	81.806950000000001	81.844184999999996	53.470134999999999	53.452523999999997	Совхозная	0103000020E6100000010000000500000076E09C11A5735440DA53724EECB94A4076E09C11A57354403CDA38622DBC4A4085B18520077654403CDA38622DBC4A4085B1852007765440DA53724EECB94A4076E09C11A5735440DA53724EECB94A40
69802	23147	82.055136000000005	82.086577000000005	53.537166999999997	53.519916000000002	Советская	0103000020E6100000010000000500000044352559878354406555849B8CC24A404435255987835440C6BE64E3C1C44A407EE5417A8A855440C6BE64E3C1C44A407EE5417A8A8554406555849B8CC24A4044352559878354406555849B8CC24A40
71454	59449	81.663596999999996	82.683893999999995	53.680399000000001	53.248593999999997	Нагорная	0103000020E61000000100000005000000512E8D5F786A5440ACFD9DEDD19F4A40512E8D5F786A5440959D7E5017D74A408FFB56EBC4AB5440959D7E5017D74A408FFB56EBC4AB5440ACFD9DEDD19F4A40512E8D5F786A5440ACFD9DEDD19F4A40
70284	23011	82.309899000000001	82.335222000000002	53.458754999999996	53.448357999999999	Школьная	0103000020E610000001000000050000000A849D62D5935440327381CB63B94A400A849D62D593544030F0DC7BB8BA4A4095B9F9467495544030F0DC7BB8BA4A4095B9F94674955440327381CB63B94A400A849D62D5935440327381CB63B94A40
71215	22916	82.166932000000003	82.182903999999994	53.380487000000002	53.369227000000002	пер. Клубный	0103000020E61000000100000005000000FA298E03AF8A54406DE690D442AF4A40FA298E03AF8A5440CEC64ACCB3B04A40AF93FAB2B48B5440CEC64ACCB3B04A40AF93FAB2B48B54406DE690D442AF4A40FA298E03AF8A54406DE690D442AF4A40
70598	22879	82.214830000000006	82.249289000000005	53.362161	53.345053999999998	Центральная	0103000020E61000000100000005000000C80C54C6BF8D54404FADBEBA2AAC4A40C80C54C6BF8D54407E71A94A5BAE4A402A90D959F48F54407E71A94A5BAE4A402A90D959F48F54404FADBEBA2AAC4A40C80C54C6BF8D54404FADBEBA2AAC4A40
71440	22826	82.385266999999999	82.412953000000002	53.432025000000003	53.417769	Новая	0103000020E61000000100000005000000984EEB36A89854402D24607479B54A40984EEB36A8985440F7065F984CB74A403F726BD26D9A5440F7065F984CB74A403F726BD26D9A54402D24607479B54A40984EEB36A89854402D24607479B54A40
70890	59417	82.924598000000003	84.588313999999997	51.803899999999999	50.639975999999997	Кузнечная	0103000020E610000001000000050000009CFC169D2CBB5440C91CCBBBEA5149409CFC169D2CBB544090A0F831E6E64940DA71C3EFA625554090A0F831E6E64940DA71C3EFA6255540C91CCBBBEA5149409CFC169D2CBB5440C91CCBBBEA514940
70876	22020	83.404127000000003	83.422883999999996	51.477910999999999	51.466977	Центральная	0103000020E610000001000000050000008F1B7E37DDD95440FA7DFFE6C5BB49408F1B7E37DDD9544007B309302CBD49401B800D8810DB544007B309302CBD49401B800D8810DB5440FA7DFFE6C5BB49408F1B7E37DDD95440FA7DFFE6C5BB4940
70037	21788	83.540959000000001	83.573451000000006	51.423186000000001	51.385506999999997	Центральная	0103000020E61000000100000005000000855E7F129FE2544085B01A4B58B14940855E7F129FE25440021077F52AB64940F2B6D26BB3E45440021077F52AB64940F2B6D26BB3E4544085B01A4B58B14940855E7F129FE2544085B01A4B58B14940
70879	22352	83.595585	83.634985999999998	51.628376000000003	51.619598000000003	Сосновская	0103000020E610000001000000050000003E3F8C101EE654406155BDFC4ECF49403E3F8C101EE65440B0CBF09F6ED04940BEDA519CA3E85440B0CBF09F6ED04940BEDA519CA3E854406155BDFC4ECF49403E3F8C101EE654406155BDFC4ECF4940
71433	21680	83.389790000000005	83.411000000000001	51.423802999999999	51.404710000000001	Центральная	0103000020E61000000100000005000000B493C151F2D854409D2E8B89CDB34940B493C151F2D854402D793C2D3FB64940FCA9F1D24DDA54402D793C2D3FB64940FCA9F1D24DDA54409D2E8B89CDB34940B493C151F2D854409D2E8B89CDB34940
9883	40342	83.560102000000001	83.568922999999998	51.702679000000003	51.695160000000001	Садовая	0103000020E61000000100000005000000261B0FB6D8E3544062BEBC00FBD84940261B0FB6D8E35440024BAE62F1D949404DBC033C69E45440024BAE62F1D949404DBC033C69E4544062BEBC00FBD84940261B0FB6D8E3544062BEBC00FBD84940
70442	21591	83.411250999999993	83.436260000000004	51.331086999999997	51.302878999999997	Центральная	0103000020E61000000100000005000000A0DCB6EF51DA544095D233BDC4A64940A0DCB6EF51DA5440BC900E0F61AA4940642310AFEBDB5440BC900E0F61AA4940642310AFEBDB544095D233BDC4A64940A0DCB6EF51DA544095D233BDC4A64940
71432	22258	83.597830999999999	83.619499000000005	51.561526999999998	51.555340000000001	Лиственная	0103000020E610000001000000050000003D62F4DC42E654409014916115C749403D62F4DC42E654401669E21DE0C74940E73922DFA5E754401669E21DE0C74940E73922DFA5E754409014916115C749403D62F4DC42E654409014916115C74940
70436	21305	83.724287000000004	83.771179000000004	51.208691999999999	51.198341999999997	Центральная	0103000020E61000000100000005000000C07ADCB75AEE54402CB6494563994940C07ADCB75AEE5440EA77616BB69A49402B172AFF5AF15440EA77616BB69A49402B172AFF5AF154402CB6494563994940C07ADCB75AEE54402CB6494563994940
71431	21427	83.666436000000004	83.675669999999997	51.140070000000001	51.127574000000003	Рабочая	0103000020E6100000010000000500000022382EE3A6EA5440F3E846585490494022382EE3A6EA54404B9352D0ED914940DA38622D3EEB54404B9352D0ED914940DA38622D3EEB5440F3E846585490494022382EE3A6EA5440F3E8465854904940
71063	22088	83.421914000000001	83.436197000000007	51.519699000000003	51.508690999999999	Коммунистическая	0103000020E610000001000000050000005FEE93A300DB5440806264C91CC149405FEE93A300DB5440C861307F85C249404167D2A6EADB5440C861307F85C249404167D2A6EADB5440806264C91CC149405FEE93A300DB5440806264C91CC14940
71066	22237	83.427008000000001	83.441721999999999	51.624032	51.606388000000003	Советская	0103000020E6100000010000000500000058C85C1954DB5440EB573A1F9ECD494058C85C1954DB544028D4D347E0CF49401EFB592C45DC544028D4D347E0CF49401EFB592C45DC5440EB573A1F9ECD494058C85C1954DB5440EB573A1F9ECD4940
71427	21363	83.853122999999997	83.865080000000006	51.256534000000002	51.253889999999998	Мараловодов	0103000020E61000000100000005000000C91D369199F654400664AF777FA04940C91D369199F65440F2272A1BD6A049401E1B81785DF75440F2272A1BD6A049401E1B81785DF754400664AF777FA04940C91D369199F654400664AF777FA04940
71439	22484	83.486313999999993	83.506715	51.738917000000001	51.723427000000001	Луговая	0103000020E610000001000000050000009065C1C41FDF54408E05854199DC49409065C1C41FDF5440AEBA0ED594DE49402159C0046EE05440AEBA0ED594DE49402159C0046EE054408E05854199DC49409065C1C41FDF54408E05854199DC4940
70445	22389	83.352339999999998	83.377492000000004	51.712423999999999	51.683295000000001	Центральная	0103000020E61000000100000005000000A64412BD8CD654409A42E73576D74940A64412BD8CD654405871AAB530DB49401BA034D428D854405871AAB530DB49401BA034D428D854409A42E73576D74940A64412BD8CD654409A42E73576D74940
70461	21835	83.788588000000004	83.838553000000005	51.499166000000002	51.479481999999997	Центральная	0103000020E610000001000000050000002881CD3978F25440A5828AAA5FBD49402881CD3978F2544038A3E6ABE4BF49409DBD33DAAAF5544038A3E6ABE4BF49409DBD33DAAAF55440A5828AAA5FBD49402881CD3978F25440A5828AAA5FBD4940
71435	22532	83.593869999999995	83.608673999999993	51.777878999999999	51.770204999999997	Лесная	0103000020E61000000100000005000000D50451F701E654409B1BD31396E24940D50451F701E65440629F008A91E349403BFBCA83F4E65440629F008A91E349403BFBCA83F4E654409B1BD31396E24940D50451F701E654409B1BD31396E24940
70900	21438	83.503058999999993	83.515670999999998	51.243262999999999	51.233507000000003	Центральная	0103000020E61000000100000005000000573D601E32E054408C31B08EE39D4940573D601E32E05440D6A9F23D239F4940B81FF0C000E15440D6A9F23D239F4940B81FF0C000E154408C31B08EE39D4940573D601E32E054408C31B08EE39D4940
70035	21754	83.569632999999996	83.590841999999995	51.386265999999999	51.365656000000001	Центральная	0103000020E610000001000000050000003B6EF8DD74E4544008CBD8D0CDAE49403B6EF8DD74E4544043C70E2A71B149409BC6F65AD0E5544043C70E2A71B149409BC6F65AD0E5544008CBD8D0CDAE49403B6EF8DD74E4544008CBD8D0CDAE4940
71316	22312	83.488515000000007	83.506238999999994	51.599462000000003	51.587992	Речная	0103000020E61000000100000005000000C0266BD443DF5440A227655243CB4940C0266BD443DF5440EE98BA2BBBCC49406C3D433866E05440EE98BA2BBBCC49406C3D433866E05440A227655243CB4940C0266BD443DF5440A227655243CB4940
70873	21536	83.588470999999998	83.601118999999997	51.343933	51.331605000000003	Центральная	0103000020E610000001000000050000003EE94482A9E5544055185B0872AA49403EE94482A9E55440F1811DFF05AC49404580D3BB78E65440F1811DFF05AC49404580D3BB78E6544055185B0872AA49403EE94482A9E5544055185B0872AA4940
71060	21909	83.812968999999995	83.828203999999999	51.543500000000002	51.536923999999999	Центральная	0103000020E610000001000000050000005BEA20AF07F454400038F6ECB9C449405BEA20AF07F4544021B0726891C54940A69A594B01F5544021B0726891C54940A69A594B01F554400038F6ECB9C449405BEA20AF07F454400038F6ECB9C44940
70882	21658	83.423378	83.436942999999999	51.389015000000001	51.379424999999998	Центральная	0103000020E6100000010000000500000023F609A018DB5440742497FF90B0494023F609A018DB5440A453573ECBB14940D5CDC5DFF6DB5440A453573ECBB14940D5CDC5DFF6DB5440742497FF90B0494023F609A018DB5440742497FF90B04940
70980	21929	83.743995999999996	83.767739000000006	51.407727000000001	51.402102999999997	Центральная	0103000020E61000000100000005000000B51666A19DEF5440CE4F711C78B34940B51666A19DEF54401D59F96530B449404837C2A222F154401D59F96530B449404837C2A222F15440CE4F711C78B34940B51666A19DEF5440CE4F711C78B34940
70874	22004	83.949189000000004	83.977476999999993	51.541674	51.528911999999998	Подгорная	0103000020E61000000100000005000000452E3883BFFC5440213B6F63B3C34940452E3883BFFC5440F88BD99255C54940E6E5B0FB8EFE5440F88BD99255C54940E6E5B0FB8EFE5440213B6F63B3C34940452E3883BFFC5440213B6F63B3C34940
71469	59457	82.924598000000003	84.588313999999997	51.803899999999999	50.639975999999997	переулок Клубный	0103000020E610000001000000050000009CFC169D2CBB5440C91CCBBBEA5149409CFC169D2CBB544090A0F831E6E64940DA71C3EFA625554090A0F831E6E64940DA71C3EFA6255540C91CCBBBEA5149409CFC169D2CBB5440C91CCBBBEA514940
70438	21515	83.602952000000002	83.621071000000001	51.284922999999999	51.264412999999998	Центральная	0103000020E61000000100000005000000B343FCC396E6544091D10149D8A14940B343FCC396E6544069705B5B78A449409E5F94A0BFE7544069705B5B78A449409E5F94A0BFE7544091D10149D8A14940B343FCC396E6544091D10149D8A14940
71208	22144	83.390203999999997	83.408277999999996	51.577773000000001	51.564506000000002	Центральная	0103000020E610000001000000050000002DB1321AF9D85440A9328CBB41C849402DB1321AF9D8544083C13577F4C94940486B0C3A21DA544083C13577F4C94940486B0C3A21DA5440A9328CBB41C849402DB1321AF9D85440A9328CBB41C84940
71056	21280	83.801002999999994	83.816121999999993	51.300699000000002	51.293564000000003	Набережная	0103000020E61000000100000005000000DD3F16A243F3544038A4518193A54940DD3F16A243F354404F78094E7DA64940F3E2C4573BF454404F78094E7DA64940F3E2C4573BF4544038A4518193A54940DD3F16A243F3544038A4518193A54940
70647	20523	85.804004000000006	85.868063000000006	53.124161000000001	53.104584000000003	Ленина	0103000020E610000001000000050000009B7631CD74735540AAD72D02638D4A409B7631CD747355402638F581E48F4A4088F71C588E7755402638F581E48F4A4088F71C588E775540AAD72D02638D4A409B7631CD74735540AAD72D02638D4A40
70923	21057	86.083810999999997	86.107769000000005	53.089286999999999	53.071928999999997	Первомайская	0103000020E61000000100000005000000E202D0285D85554026512FF834894A40E202D0285D8555409E7AA4C16D8B4A4073A1F2AFE58655409E7AA4C16D8B4A4073A1F2AFE586554026512FF834894A40E202D0285D85554026512FF834894A40
70033	20138	85.632667999999995	85.686603000000005	53.097468999999997	53.056193	Советская	0103000020E61000000100000005000000724EECA17D685540CFA10C5531874A40724EECA17D685540D9AF3BDD798C4A407995B54DF16B5540D9AF3BDD798C4A407995B54DF16B5540CFA10C5531874A40724EECA17D685540CFA10C5531874A40
70194	20138	85.632667999999995	85.686603000000005	53.097468999999997	53.056193	Победы	0103000020E61000000100000005000000724EECA17D685540CFA10C5531874A40724EECA17D685540D9AF3BDD798C4A407995B54DF16B5540D9AF3BDD798C4A407995B54DF16B5540CFA10C5531874A40724EECA17D685540CFA10C5531874A40
69803	20138	85.632667999999995	85.686603000000005	53.097468999999997	53.056193	Ленина	0103000020E61000000100000005000000724EECA17D685540CFA10C5531874A40724EECA17D685540D9AF3BDD798C4A407995B54DF16B5540D9AF3BDD798C4A407995B54DF16B5540CFA10C5531874A40724EECA17D685540CFA10C5531874A40
71204	20382	85.391434000000004	85.416848000000002	53.177920999999998	53.149895999999998	Зеленая	0103000020E61000000100000005000000B82231410D5955408EE6C8CA2F934A40B82231410D595540C422861DC6964A40CBD93BA3AD5A5540C422861DC6964A40CBD93BA3AD5A55408EE6C8CA2F934A40B82231410D5955408EE6C8CA2F934A40
70530	21141	85.372254999999996	85.411969999999997	52.732098999999998	52.714941000000003	Молодежная	0103000020E6100000010000000500000070B1A206D3575540E7C8CA2F835B4A4070B1A206D35755409737876BB55D4A40B83B6BB75D5A55409737876BB55D4A40B83B6BB75D5A5540E7C8CA2F835B4A4070B1A206D3575540E7C8CA2F835B4A40
71437	21191	85.350211000000002	85.370405000000005	52.786782000000002	52.767792	Советская	0103000020E61000000100000005000000C4EC65DB69565540B2101D0247624A40C4EC65DB695655406E8AC745B5644A4098512CB7B45755406E8AC745B5644A4098512CB7B4575540B2101D0247624A40C4EC65DB69565540B2101D0247624A40
71461	59453	86.244986999999995	86.280219000000002	53.021405000000001	52.993088	Центральная	0103000020E610000001000000050000007D3CF4DDAD8F55406806F1811D7F4A407D3CF4DDAD8F5540467C2766BD824A40F12DAC1BEF915540467C2766BD824A40F12DAC1BEF9155406806F1811D7F4A407D3CF4DDAD8F55406806F1811D7F4A40
70595	20980	86.014218	86.063141000000002	53.127948000000004	53.112687000000001	Ленина	0103000020E61000000100000005000000EE409DF2E880554099D711876C8E4A40EE409DF2E880554058CB9D9960904A405A828C800A84554058CB9D9960904A405A828C800A84554099D711876C8E4A40EE409DF2E880554099D711876C8E4A40
70617	20815	86.061640999999995	86.125978000000003	52.940559999999998	52.917614999999998	Школьная	0103000020E61000000100000005000000EFC517EDF1835540D6A8876874754A40EFC517EDF18355407FF6234564784A40FE800706108855407FF6234564784A40FE80070610885540D6A8876874754A40EFC517EDF1835540D6A8876874754A40
70427	20773	85.466102000000006	85.514449999999997	52.884338999999997	52.858890000000002	Советская	0103000020E610000001000000050000006AA67B9DD45D5540446E861BF06D4A406AA67B9DD45D5540E6C9350532714A40575BB1BFEC605540E6C9350532714A40575BB1BFEC605540446E861BF06D4A406AA67B9DD45D5540446E861BF06D4A40
71049	20876	86.207051000000007	86.222583	53.060338000000002	53.041155000000003	Лесная	0103000020E61000000100000005000000AA66D652408D55409088299144854A40AA66D652408D5540605AD427B9874A405169C4CC3E8E5540605AD427B9874A405169C4CC3E8E55409088299144854A40AA66D652408D55409088299144854A40
70402	21069	85.426378999999997	85.469740999999999	52.850569999999998	52.826895999999998	Советская	0103000020E61000000100000005000000E02C25CB495B5540BB9866BAD7694A40E02C25CB495B5540B77A4E7ADF6C4A40C8258E3C105E5540B77A4E7ADF6C4A40C8258E3C105E5540BB9866BAD7694A40E02C25CB495B5540BB9866BAD7694A40
70620	20622	85.703743000000003	85.768107000000001	53.200215	53.177073	Коммунистическая	0103000020E610000001000000050000007E7214200A6D55409700FC53AA964A407E7214200A6D5540969526A5A0994A40093543AA28715540969526A5A0994A40093543AA287155409700FC53AA964A407E7214200A6D55409700FC53AA964A40
70618	20673	85.509770000000003	85.531006000000005	52.907259000000003	52.893993999999999	Центральная	0103000020E61000000100000005000000D89E5912A0605540FD6838656E724A40D89E5912A060554037001B1021744A40B5FE9600FC61554037001B1021744A40B5FE9600FC615540FD6838656E724A40D89E5912A0605540FD6838656E724A40
69776	20541	85.581265999999999	85.625095000000002	52.806078999999997	52.777549	пер.Магистральный	0103000020E61000000100000005000000B6114F7633655540CD04C3B986634A40B6114F7633655540067FBF982D674A402979758E01685540067FBF982D674A402979758E01685540CD04C3B986634A40B6114F7633655540CD04C3B986634A40
71436	21220	85.794571000000005	85.806483	52.999597000000001	52.991624000000002	Бийская	0103000020E6100000010000000500000067D65240DA725540E0F60489ED7E4A4067D65240DA725540011764CBF27F4A40EB71DF6A9D735540011764CBF27F4A40EB71DF6A9D735540E0F60489ED7E4A4067D65240DA725540E0F60489ED7E4A40
70371	20309	85.609959000000003	85.639756000000006	52.924021000000003	52.909122000000004	Центральная	0103000020E61000000100000005000000A8397991096755407D09151C5E744A40A8397991096755409BE8F35146764A40DE5A26C3F16855409BE8F35146764A40DE5A26C3F16855407D09151C5E744A40A8397991096755407D09151C5E744A40
69805	20450	85.755593000000005	85.790807000000001	52.901935999999999	52.874186999999999	Пушкина	0103000020E610000001000000050000008A05BEA25B7055404FCB0F5CE56F4A408A05BEA25B705540E38A8BA372734A40AA9CF6949C725540E38A8BA372734A40AA9CF6949C7255404FCB0F5CE56F4A408A05BEA25B7055404FCB0F5CE56F4A40
70615	19035	79.508296000000001	79.569892999999993	53.638593	53.597738999999997	Южная	0103000020E61000000100000005000000022CF2EB87E05340994528B682CC4A40022CF2EB87E053402E3A596ABDD14A40094E7D2079E453402E3A596ABDD14A40094E7D2079E45340994528B682CC4A40022CF2EB87E05340994528B682CC4A40
69767	19035	79.508296000000001	79.569892999999993	53.638593	53.597738999999997	Ленина	0103000020E61000000100000005000000022CF2EB87E05340994528B682CC4A40022CF2EB87E053402E3A596ABDD14A40094E7D2079E453402E3A596ABDD14A40094E7D2079E45340994528B682CC4A40022CF2EB87E05340994528B682CC4A40
70183	19035	79.508296000000001	79.569892999999993	53.638593	53.597738999999997	Кайгородова	0103000020E61000000100000005000000022CF2EB87E05340994528B682CC4A40022CF2EB87E053402E3A596ABDD14A40094E7D2079E453402E3A596ABDD14A40094E7D2079E45340994528B682CC4A40022CF2EB87E05340994528B682CC4A40
70424	19226	79.426989000000006	79.477394000000004	53.615865999999997	53.588279	Гагарина	0103000020E610000001000000050000001DB0ABC953DB534038F6ECB94CCB4A401DB0ABC953DB5340F25B74B2D4CE4A40A053909F8DDE5340F25B74B2D4CE4A40A053909F8DDE534038F6ECB94CCB4A401DB0ABC953DB534038F6ECB94CCB4A40
70872	20036	79.717692999999997	79.748019999999997	53.669027	53.657215000000001	Молодежная	0103000020E610000001000000050000005CE49EAEEEED534067B8019F1FD44A405CE49EAEEEED53400C923EADA2D54A404030478FDFEF53400C923EADA2D54A404030478FDFEF534067B8019F1FD44A405CE49EAEEEED534067B8019F1FD44A40
71424	19433	78.869315	78.895780000000002	53.559086000000001	53.537337999999998	Ломоносова	0103000020E6100000010000000500000006BB61DBA2B75340F372D87DC7C44A4006BB61DBA2B7534063D34A2190C74A404C1AA37554B9534063D34A2190C74A404C1AA37554B95340F372D87DC7C44A4006BB61DBA2B75340F372D87DC7C44A40
70405	19602	79.650471999999993	79.687095999999997	53.332973000000003	53.322620000000001	переулок Школьный	0103000020E61000000100000005000000ADBD4F55A1E953408C84B69C4BA94A40ADBD4F55A1E95340BBB9F8DB9EAA4A40984D8061F9EB5340BBB9F8DB9EAA4A40984D8061F9EB53408C84B69C4BA94A40ADBD4F55A1E953408C84B69C4BA94A40
71422	19470	79.313083000000006	79.332684	53.508805000000002	53.496974999999999	Школьная	0103000020E61000000100000005000000C07B478D09D45340FDF675E09CBF4A40C07B478D09D453404985B18520C14A40C2F9D4B14AD553404985B18520C14A40C2F9D4B14AD55340FDF675E09CBF4A40C07B478D09D45340FDF675E09CBF4A40
71047	19788	79.826740000000001	79.841858000000002	53.472878999999999	53.461612000000002	Центральная	0103000020E61000000100000005000000E292E34EE9F4534078B81D1A16BB4A40E292E34EE9F453408BFB8F4C87BC4A4010786000E1F553408BFB8F4C87BC4A4010786000E1F5534078B81D1A16BB4A40E292E34EE9F4534078B81D1A16BB4A40
69941	22634	79.217564999999993	79.248683	53.394019999999998	53.373525000000001	Молодежная	0103000020E6100000010000000500000045F0BF95ECCD5340849ECDAACFAF4A4045F0BF95ECCD534026FC523F6FB24A408E041A6CEACF534026FC523F6FB24A408E041A6CEACF5340849ECDAACFAF4A4045F0BF95ECCD5340849ECDAACFAF4A40
71051	19948	79.896169999999998	79.932669000000004	53.648617000000002	53.618617	Центральная	0103000020E61000000100000005000000016A6AD95AF95340F4DF83D72ECF4A40016A6AD95AF953409850C1E105D34A408E3F51D9B0FB53409850C1E105D34A408E3F51D9B0FB5340F4DF83D72ECF4A40016A6AD95AF95340F4DF83D72ECF4A40
71052	19373	79.076476	79.098646000000002	53.549992000000003	53.542448	Черемушки	0103000020E6100000010000000500000073BB97FBE4C45340EBE3A1EF6EC54A4073BB97FBE4C45340E4874A2366C64A4066F84F3750C65340E4874A2366C64A4066F84F3750C65340EBE3A1EF6EC54A4073BB97FBE4C45340EBE3A1EF6EC54A40
69788	22574	79.224069	79.255635999999996	53.327154	53.310451999999998	Ленина	0103000020E6100000010000000500000009C3802557CE5340287D21E4BCA74A4009C3802557CE5340B760A92EE0A94A4089EB18575CD05340B760A92EE0A94A4089EB18575CD05340287D21E4BCA74A4009C3802557CE5340287D21E4BCA74A40
71426	19749	79.746223999999998	79.763507000000004	53.522207000000002	53.506101000000001	Школьная	0103000020E6100000010000000500000061DF4E22C2EF534088BCE5EAC7C04A4061DF4E22C2EF5340035FD1ADD7C24A4018D1764CDDF05340035FD1ADD7C24A4018D1764CDDF0534088BCE5EAC7C04A4061DF4E22C2EF534088BCE5EAC7C04A40
69796	19290	79.244001999999995	79.308150999999995	53.581313999999999	53.554673000000001	Славгородская	0103000020E61000000100000005000000268A90BA9DCF5340B37C5D86FFC64A40268A90BA9DCF53407D5A457F68CA4A40B3CEF8BEB8D353407D5A457F68CA4A40B3CEF8BEB8D35340B37C5D86FFC64A40268A90BA9DCF5340B37C5D86FFC64A40
70429	19706	79.725876999999997	79.739063999999999	53.483398999999999	53.467595000000003	50 лет Октября	0103000020E61000000100000005000000CAFACDC474EE5340F6622827DABB4A40CAFACDC474EE5340A5F5B704E0BD4A40A96917D34CEF5340A5F5B704E0BD4A40A96917D34CEF5340F6622827DABB4A40CAFACDC474EE5340F6622827DABB4A40
70370	19540	79.500876000000005	79.532964000000007	53.453211000000003	53.434981000000001	Ленина	0103000020E610000001000000050000007CD6355A0EE05340D1B01875ADB74A407CD6355A0EE05340FF976BD102BA4A40817C09151CE25340FF976BD102BA4A40817C09151CE25340D1B01875ADB74A407CD6355A0EE05340D1B01875ADB74A40
71201	19633	79.616309000000001	79.644767999999999	53.439605	53.424599999999998	Центральная	0103000020E61000000100000005000000C0CE4D9B71E75340D8F0F44A59B64A40C0CE4D9B71E753403C1405FA44B84A40786000E143E953403C1405FA44B84A40786000E143E95340D8F0F44A59B64A40C0CE4D9B71E75340D8F0F44A59B64A40
70807	22432	79.208383999999995	79.228236999999993	53.249353999999997	53.239364000000002	Мира	0103000020E610000001000000050000009E40D82956CD53407DEBC37AA39E4A409E40D82956CD53403A90F5D4EA9F4A402DAF5C6F9BCE53403A90F5D4EA9F4A402DAF5C6F9BCE53407DEBC37AA39E4A409E40D82956CD53407DEBC37AA39E4A40
69798	20060	79.656931	79.689199000000002	53.764510000000001	53.739801	Вокзальная	0103000020E61000000100000005000000A12E52280BEA5340284696CCB1DE4A40A12E52280BEA534084BBB376DBE14A40E65B1FD61BEC534084BBB376DBE14A40E65B1FD61BEC5340284696CCB1DE4A40A12E52280BEA5340284696CCB1DE4A40
70729	59408	79.927476999999996	79.957193000000004	53.485205000000001	53.462679000000001	Юбилейная	0103000020E61000000100000005000000B3B27DC85BFB5340E3C5C21039BB4A40B3B27DC85BFB5340876D8B321BBE4A4073BD6DA642FD5340876D8B321BBE4A4073BD6DA642FD5340E3C5C21039BB4A40B3B27DC85BFB5340E3C5C21039BB4A40
71421	19894	79.822023000000002	79.840421000000006	53.588524999999997	53.572871999999997	пер. Южный	0103000020E61000000100000005000000D4635B069CF45340A565A4DE53C94A40D4635B069CF453406FF085C954CB4A40C9772975C9F553406FF085C954CB4A40C9772975C9F55340A565A4DE53C94A40D4635B069CF45340A565A4DE53C94A40
71153	19347	79.032736999999997	79.060045000000002	53.473367000000003	53.457500000000003	Коваленко	0103000020E61000000100000005000000A017EE5C18C25340C3F5285C8FBA4A40A017EE5C18C25340B900344A97BC4A4074D2FBC6D7C35340B900344A97BC4A4074D2FBC6D7C35340C3F5285C8FBA4A40A017EE5C18C25340C3F5285C8FBA4A40
71453	59448	83.207801000000003	84.122995000000003	52.668998999999999	51.925097000000001	Центральная	0103000020E61000000100000005000000DFC4909C4CCD54405950189469F64940DFC4909C4CCD544042075DC2A1554A4094A46B26DF07554042075DC2A1554A4094A46B26DF0755405950189469F64940DFC4909C4CCD54405950189469F64940
71279	18900	83.836225999999996	83.865106999999995	52.372579000000002	52.360959999999999	Центральная	0103000020E6100000010000000500000027840EBA84F554400395F1EF332E4A4027840EBA84F5544094162EABB02F4A409A22C0E95DF7544094162EABB02F4A409A22C0E95DF754400395F1EF332E4A4027840EBA84F554400395F1EF332E4A40
69818	59363	83.631985	83.681042000000005	52.411279999999998	52.38165	Пятилетка	0103000020E6100000010000000500000001A4367172E854405B423EE8D9304A4001A4367172E85440DBBFB2D2A4344A40F54C2F3196EB5440DBBFB2D2A4344A40F54C2F3196EB54405B423EE8D9304A4001A4367172E854405B423EE8D9304A40
70214	59363	83.631985	83.681042000000005	52.411279999999998	52.38165	Пушкина	0103000020E6100000010000000500000001A4367172E854405B423EE8D9304A4001A4367172E85440DBBFB2D2A4344A40F54C2F3196EB5440DBBFB2D2A4344A40F54C2F3196EB54405B423EE8D9304A4001A4367172E854405B423EE8D9304A40
70193	59363	83.631985	83.681042000000005	52.411279999999998	52.38165	Краснооктябрьская	0103000020E6100000010000000500000001A4367172E854405B423EE8D9304A4001A4367172E85440DBBFB2D2A4344A40F54C2F3196EB5440DBBFB2D2A4344A40F54C2F3196EB54405B423EE8D9304A4001A4367172E854405B423EE8D9304A40
71420	18396	83.738722999999993	83.755746000000002	52.340792999999998	52.325049	Молодежная	0103000020E610000001000000050000006473D53C47EF54407B4CA4349B294A406473D53C47EF544055DAE21A9F2B4A404D8578245EF0544055DAE21A9F2B4A404D8578245EF054407B4CA4349B294A406473D53C47EF54407B4CA4349B294A40
71423	18577	83.374949999999998	83.412940000000006	52.230010999999998	52.216842	Комсомольская	0103000020E61000000100000005000000A7E8482EFFD754401A33897AC11B4A40A7E8482EFFD75440315C1D00711D4A4075CDE49B6DDA5440315C1D00711D4A4075CDE49B6DDA54401A33897AC11B4A40A7E8482EFFD754401A33897AC11B4A40
71194	18172	83.207801000000003	84.122995000000003	52.668998999999999	51.925097000000001	Комсомольская	0103000020E61000000100000005000000DFC4909C4CCD54405950189469F64940DFC4909C4CCD544042075DC2A1554A4094A46B26DF07554042075DC2A1554A4094A46B26DF0755405950189469F64940DFC4909C4CCD54405950189469F64940
71184	18126	83.356993000000003	83.375389999999996	52.423282	52.410978	Пушкина	0103000020E61000000100000005000000A9F92AF9D8D6544010B056ED9A344A40A9F92AF9D8D65440247EC51A2E364A40B54FC76306D85440247EC51A2E364A40B54FC76306D8544010B056ED9A344A40A9F92AF9D8D6544010B056ED9A344A40
70368	18664	83.365409999999997	83.389718000000002	52.311599999999999	52.291272999999997	Кирова	0103000020E6100000010000000500000068E89FE062D75440999A046F48254A4068E89FE062D7544080B74082E2274A40672AC423F1D8544080B74082E2274A40672AC423F1D85440999A046F48254A4068E89FE062D75440999A046F48254A40
70586	18824	83.722769	83.777117000000004	52.227330000000002	52.209172000000002	Юбилейная	0103000020E610000001000000050000000264E8D841EE5440959EE925C61A4A400264E8D841EE544029B34126191D4A409A0AF148BCF1544029B34126191D4A409A0AF148BCF15440959EE925C61A4A400264E8D841EE5440959EE925C61A4A40
70419	18567	83.455483999999998	83.490761000000006	52.232934	52.219180999999999	50 лет Октября	0103000020E610000001000000050000007BF65CA626DD5440C9737D1F0E1C4A407BF65CA626DD5440301004C8D01D4A40BF49D3A068DF5440301004C8D01D4A40BF49D3A068DF5440C9737D1F0E1C4A407BF65CA626DD5440C9737D1F0E1C4A40
71214	18885	83.783145000000005	83.805188999999999	52.122548999999999	52.109408999999999	Комсомольская	0103000020E61000000100000005000000A9C1340C1FF25440AC71361D010E4A40A9C1340C1FF25440299485AFAF0F4A405586713788F35440299485AFAF0F4A405586713788F35440AC71361D010E4A40A9C1340C1FF25440AC71361D010E4A40
69765	18718	83.683565999999999	83.733341999999993	52.203355000000002	52.177841999999998	Комсомольская	0103000020E6100000010000000500000015AA9B8BBFEB544078EDD286C3164A4015AA9B8BBFEB5440323D6189071A4A4020B24813EFEE5440323D6189071A4A4020B24813EFEE544078EDD286C3164A4015AA9B8BBFEB544078EDD286C3164A40
71071	18965	83.745217999999994	83.779713000000001	52.548766999999998	52.528483999999999	Советская	0103000020E61000000100000005000000FE98D6A6B1EF5440C93A1C5DA5434A40FE98D6A6B1EF5440E00F3FFF3D464A4007D15AD1E6F15440E00F3FFF3D464A4007D15AD1E6F15440C93A1C5DA5434A40FE98D6A6B1EF5440C93A1C5DA5434A40
70413	18422	83.595280000000002	83.620029000000002	52.236663	52.221547999999999	Новая	0103000020E61000000100000005000000A0FD481119E65440423F53AF5B1C4A40A0FD481119E654402D9622F94A1E4A4095641D8EAEE754402D9622F94A1E4A4095641D8EAEE75440423F53AF5B1C4A40A0FD481119E65440423F53AF5B1C4A40
70590	18041	83.603131000000005	83.639889999999994	52.545442000000001	52.506810000000002	Целинная	0103000020E610000001000000050000000B0DC4B299E6544094A46B26DF404A400B0DC4B299E65440B3EE1F0BD1454A4065C22FF5F3E85440B3EE1F0BD1454A4065C22FF5F3E8544094A46B26DF404A400B0DC4B299E6544094A46B26DF404A40
70597	18090	83.429388000000003	83.469443999999996	52.450902999999997	52.430728000000002	Пушкина	0103000020E61000000100000005000000DF52CE177BDB54405ABC581822374A40DF52CE177BDB54408A558330B7394A406BD3D85E0BDE54408A558330B7394A406BD3D85E0BDE54405ABC581822374A40DF52CE177BDB54405ABC581822374A40
70870	17976	83.614163000000005	83.634743	52.630766000000001	52.617859000000003	Школьная	0103000020E6100000010000000500000073DA53724EE754400745F300164F4A4073DA53724EE75440E1B6B6F0BC504A405B971AA19FE85440E1B6B6F0BC504A405B971AA19FE854400745F300164F4A4073DA53724EE754400745F300164F4A40
71169	17591	83.182297000000005	83.219380000000001	52.058228999999997	52.048836000000001	Центральная	0103000020E610000001000000050000002C4A09C1AACB5440096F0F4240064A402C4A09C1AACB5440E256410C74074A40605969520ACE5440E256410C74074A40605969520ACE5440096F0F4240064A402C4A09C1AACB5440096F0F4240064A40
70034	16734	83.281220000000005	83.333143000000007	52.138665000000003	52.101382999999998	Партизанская	0103000020E61000000100000005000000CBBE2B82FFD1544068AF3E1EFA0C4A40CBBE2B82FFD15440C80C54C6BF114A400C79043752D55440C80C54C6BF114A400C79043752D5544068AF3E1EFA0C4A40CBBE2B82FFD1544068AF3E1EFA0C4A40
70041	16734	83.281220000000005	83.333143000000007	52.138665000000003	52.101382999999998	Ленина	0103000020E61000000100000005000000CBBE2B82FFD1544068AF3E1EFA0C4A40CBBE2B82FFD15440C80C54C6BF114A400C79043752D55440C80C54C6BF114A400C79043752D5544068AF3E1EFA0C4A40CBBE2B82FFD1544068AF3E1EFA0C4A40
70203	16734	83.281220000000005	83.333143000000007	52.138665000000003	52.101382999999998	Горького	0103000020E61000000100000005000000CBBE2B82FFD1544068AF3E1EFA0C4A40CBBE2B82FFD15440C80C54C6BF114A400C79043752D55440C80C54C6BF114A400C79043752D5544068AF3E1EFA0C4A40CBBE2B82FFD1544068AF3E1EFA0C4A40
70868	17444	82.871803999999997	82.891898999999995	52.025424000000001	52.018169	Центральная	0103000020E61000000100000005000000682101A3CBB7544088669E5C53024A40682101A3CBB754404A44F81741034A4072158BDF14B954404A44F81741034A4072158BDF14B9544088669E5C53024A40682101A3CBB7544088669E5C53024A40
71425	17138	83.176360000000003	83.194640000000007	52.161178	52.156283000000002	Овражная	0103000020E61000000100000005000000A514747B49CB5440DCF5D21401144A40A514747B49CB5440D76A0F7BA1144A40959F54FB74CC5440D76A0F7BA1144A40959F54FB74CC5440DCF5D21401144A40A514747B49CB5440DCF5D21401144A40
70869	17892	83.651200000000003	83.665447	51.890231999999997	51.876601000000001	Центральная	0103000020E61000000100000005000000EFC9C342ADE954400952297634F04940EFC9C342ADE9544024ED461FF3F149402A8E03AF96EA544024ED461FF3F149402A8E03AF96EA54400952297634F04940EFC9C342ADE954400952297634F04940
71046	16986	83.484337999999994	83.506473	52.167028000000002	52.153984000000001	Школьная	0103000020E61000000100000005000000718DCF64FFDE5440BB0D6ABFB5134A40718DCF64FFDE544016C26A2C61154A40A6D3BA0D6AE0544016C26A2C61154A40A6D3BA0D6AE05440BB0D6ABFB5134A40718DCF64FFDE5440BB0D6ABFB5134A40
71419	17176	83.131264000000002	83.177706999999998	52.077655	52.066882999999997	переулок Школьный	0103000020E6100000010000000500000019C91EA166C8544045D4449F8F084A4019C91EA166C8544079AF5A99F0094A404C512E8D5FCB544079AF5A99F0094A404C512E8D5FCB544045D4449F8F084A4019C91EA166C8544045D4449F8F084A40
70583	17746	83.517082000000002	83.560156000000006	51.933554999999998	51.897691000000002	Партизанская	0103000020E610000001000000050000006BD619DF17E15440EF74E789E7F249406BD619DF17E154403602F1BA7EF74940202A8D98D9E354403602F1BA7EF74940202A8D98D9E35440EF74E789E7F249406BD619DF17E15440EF74E789E7F24940
70878	16890	83.359796000000003	83.383942000000005	52.181061999999997	52.169746000000004	Школьная	0103000020E61000000100000005000000D34ECDE506D754403C50A73CBA154A40D34ECDE506D754403046240A2D174A40E563778192D854403046240A2D174A40E563778192D854403C50A73CBA154A40D34ECDE506D754403C50A73CBA154A40
71456	59450	83.308277000000004	83.330555000000004	51.847183999999999	51.83128	Центральная	0103000020E61000000100000005000000FA4674CFBAD35440D1E80E6267EA4940FA4674CFBAD35440E4D87A8670EC4940E0A128D027D55440E4D87A8670EC4940E0A128D027D55440D1E80E6267EA4940FA4674CFBAD35440D1E80E6267EA4940
70582	17635	83.352052	83.378929999999997	51.966211999999999	51.938369999999999	Школьная	0103000020E61000000100000005000000739F1C0588D6544015C616821CF84940739F1C0588D654405A80B6D5ACFB49404A5E9D6340D854405A80B6D5ACFB49404A5E9D6340D8544015C616821CF84940739F1C0588D6544015C616821CF84940
70584	17473	83.027500000000003	83.050612999999998	51.952719999999999	51.935437999999998	Октябрьская	0103000020E61000000100000005000000F6285C8FC2C15440C3B7B06EBCF74940F6285C8FC2C15440601F9DBAF2F9494028F04E3E3DC35440601F9DBAF2F9494028F04E3E3DC35440C3B7B06EBCF74940F6285C8FC2C15440C3B7B06EBCF74940
70362	17796	83.771142999999995	83.837734999999995	51.972237	51.942250999999999	Ленина	0103000020E6100000010000000500000084622B685AF15440C8CF46AE9BF8494084622B685AF15440077B134372FC4940BBED42739DF55440077B134372FC4940BBED42739DF55440C8CF46AE9BF8494084622B685AF15440C8CF46AE9BF84940
70616	17287	83.082116999999997	83.12415	52.048692000000003	52.033203	Ползунова	0103000020E61000000100000005000000855CA96741C554408690F3FE3F044A40855CA96741C55440D6C9198A3B064A401973D712F2C75440D6C9198A3B064A401973D712F2C754408690F3FE3F044A40855CA96741C554408690F3FE3F044A40
70889	17239	83.048179000000005	83.059102999999993	52.136045000000003	52.126801	Центральная	0103000020E61000000100000005000000A8565F5D15C35440D00CE2033B104A40A8565F5D15C3544065E42CEC69114A401C06F357C8C3544065E42CEC69114A401C06F357C8C35440D00CE2033B104A40A8565F5D15C35440D00CE2033B104A40
71053	17544	83.176288	83.21002	51.966151000000004	51.949789000000003	Центральная	0103000020E6100000010000000500000058AB764D48CB5440DF8C9AAF92F9494058AB764D48CB5440B5FF01D6AAFB494061E0B9F770CD5440B5FF01D6AAFB494061E0B9F770CD5440DF8C9AAF92F9494058AB764D48CB5440DF8C9AAF92F94940
71272	17084	83.293301999999997	83.310370000000006	52.240682999999997	52.236282000000003	Центральная	0103000020E610000001000000050000007D76C075C5D254401651137D3E1E4A407D76C075C5D2544001DA56B3CE1E4A4036EA211ADDD3544001DA56B3CE1E4A4036EA211ADDD354401651137D3E1E4A407D76C075C5D254401651137D3E1E4A40
70867	16966	83.498513000000003	83.518393000000003	52.057647000000003	52.046869999999998	Школьная	0103000020E6100000010000000500000060E811A3E7DF5440EE940ED6FF054A4060E811A3E7DF544034DB15FA60074A406C5ED5592DE1544034DB15FA60074A406C5ED5592DE15440EE940ED6FF054A4060E811A3E7DF5440EE940ED6FF054A40
71417	17963	83.753842000000006	83.799843999999993	51.797601	51.782192000000002	Большевистская	0103000020E610000001000000050000007B1684F23EF05440AF9811DE1EE449407B1684F23EF05440E22021CA17E64940B779E3A430F35440E22021CA17E64940B779E3A430F35440AF9811DE1EE449407B1684F23EF05440AF9811DE1EE44940
71414	17331	82.926564999999997	82.949130999999994	52.025052000000002	52.015836	Нагорная	0103000020E61000000100000005000000912749D74CBB5440BB0CFFE906024A40912749D74CBB5440865968E734034A40AA27F38FBEBC5440865968E734034A40AA27F38FBEBC5440BB0CFFE906024A40912749D74CBB5440BB0CFFE906024A40
71163	16017	79.953456000000003	79.972204000000005	51.181716999999999	51.149151000000003	Кооперативная	0103000020E61000000100000005000000338B506C05FD53403695456117934940338B506C05FD53404910AE80429749409642209738FE53404910AE80429749409642209738FE53403695456117934940338B506C05FD53403695456117934940
70178	16245	80.173839999999998	80.208145999999999	51.373741000000003	51.344946	Калинина	0103000020E6100000010000000500000025AFCE31200B54406971C63027AC494025AFCE31200B54405116BEBED6AF4940C4B29943520D54405116BEBED6AF4940C4B29943520D54406971C63027AC494025AFCE31200B54406971C63027AC4940
70360	16715	80.093512000000004	80.120290999999995	50.953215	50.922989999999999	Кооперативная	0103000020E610000001000000050000002672C119FC0554407C444C89247649402672C119FC0554404087F9F2027A494033C005D9B20754404087F9F2027A494033C005D9B20754407C444C89247649402672C119FC0554407C444C8924764940
70608	15636	80.373121999999995	80.396558999999996	51.693575000000003	51.676091	Центральная	0103000020E61000000100000005000000C2DA183BE11754405A0F5F268AD64940C2DA183BE11754405F29CB10C7D84940CEFBFF38611954405F29CB10C7D84940CEFBFF38611954405A0F5F268AD64940C2DA183BE11754405A0F5F268AD64940
70585	15945	79.780907999999997	79.810372000000001	51.408087000000002	51.386406999999998	Кооперативная	0103000020E61000000100000005000000D34B8C65FAF1534005F9D9C875B14940D34B8C65FAF153401D76DF313CB4494006668522DDF353401D76DF313CB4494006668522DDF3534005F9D9C875B14940D34B8C65FAF1534005F9D9C875B14940
71470	59458	79.539323999999993	80.704393999999994	51.818098999999997	50.737842000000001	Центральная 	0103000020E61000000100000005000000AA7CCF4884E25340C0CE4D9B715E4940AA7CCF4884E25340F5F1D077B7E84940E95F92CA142D5440F5F1D077B7E84940E95F92CA142D5440C0CE4D9B715E4940AA7CCF4884E25340C0CE4D9B715E4940
69800	15861	80.327973	80.375636999999998	51.525297999999999	51.481372	Советская	0103000020E61000000100000005000000253E7782FD145440E59A02999DBD4940253E7782FD145440BD5301F73CC34940B98AC56F0A185440BD5301F73CC34940B98AC56F0A185440E59A02999DBD4940253E7782FD145440E59A02999DBD4940
71416	16329	80.278664000000006	80.291168999999996	51.450572999999999	51.443792999999999	Школьная	0103000020E61000000100000005000000A5A487A1D5115440CC988235CEB84940A5A487A1D5115440F5BA4560ACB94940FA264D83A2125440F5BA4560ACB94940FA264D83A2125440CC988235CEB84940A5A487A1D5115440CC988235CEB84940
71165	16481	80.430550999999994	80.458094000000003	51.036639999999998	51.023904999999999	С.Платонова	0103000020E61000000100000005000000A510C8258E1B5440FE9AAC510F834940A510C8258E1B5440DBDC989EB08449409B1F7F69511D5440DBDC989EB08449409B1F7F69511D5440FE9AAC510F834940A510C8258E1B5440FE9AAC510F834940
70613	16093	79.950743000000003	79.979247000000001	51.435298000000003	51.417310999999998	Комсомольская	0103000020E61000000100000005000000A9F92AF9D8FC53406AA164726AB54940A9F92AF9D8FC5340D20149D8B7B7494031ED9BFBABFE5340D20149D8B7B7494031ED9BFBABFE53406AA164726AB54940A9F92AF9D8FC53406AA164726AB54940
70933	16172	80.124684000000002	80.149620999999996	51.298976000000003	51.284585	Школьная	0103000020E61000000100000005000000689599D2FA07544051F701486DA44940689599D2FA075440FB2477D844A64940DE72F56393095440FB2477D844A64940DE72F5639309544051F701486DA44940689599D2FA07544051F701486DA44940
70358	16572	80.159305000000003	80.204408999999998	51.075924000000001	51.039555999999997	Кооперативная	0103000020E61000000100000005000000B745990D320A5440272EC72B10854940B745990D320A5440A27DACE0B789494084807C09150D5440A27DACE0B789494084807C09150D5440272EC72B10854940B745990D320A5440272EC72B10854940
70986	32500	80.561848999999995	80.585457000000005	51.359520000000003	51.345565000000001	Центральная	0103000020E6100000010000000500000094128255F523544035D252793BAC494094128255F5235440042159C004AE4940B70DA32078255440042159C004AE4940B70DA3207825544035D252793BAC494094128255F523544035D252793BAC4940
70385	16393	80.420364000000006	80.461426000000003	51.296683999999999	51.278061000000001	Ленина	0103000020E610000001000000050000009C1A683EE71A544083A5BA8097A349409C1A683EE71A54408C9FC6BDF9A549408BE1EA00881D54408C9FC6BDF9A549408BE1EA00881D544083A5BA8097A349409C1A683EE71A544083A5BA8097A34940
71415	15742	79.539323999999993	80.704393999999994	51.818098999999997	50.737842000000001	Центральная	0103000020E61000000100000005000000AA7CCF4884E25340C0CE4D9B715E4940AA7CCF4884E25340F5F1D077B7E84940E95F92CA142D5440F5F1D077B7E84940E95F92CA142D5440C0CE4D9B715E4940AA7CCF4884E25340C0CE4D9B715E4940
70942	15707	80.35812	80.372052999999994	51.789116999999997	51.769364000000003	Центральная	0103000020E61000000100000005000000C9022670EB165440215C01857AE24940C9022670EB165440DBDB2DC901E549403CD862B7CF175440DBDB2DC901E549403CD862B7CF175440215C01857AE24940C9022670EB165440215C01857AE24940
70796	16554	80.221351999999996	80.239444000000006	51.135961999999999	51.120609000000002	Молодежная	0103000020E61000000100000005000000DE3994A12A0E5440384D9F1D708F4940DE3994A12A0E5440D7BFEB33679149404D4EED0C530F5440D7BFEB33679149404D4EED0C530F5440384D9F1D708F4940DE3994A12A0E5440384D9F1D708F4940
70953	16116	79.823694000000003	79.834016000000005	51.416384000000001	51.410856000000003	Лесная	0103000020E6100000010000000500000055FA0967B7F45340C5AEEDED96B4494055FA0967B7F45340F14927124CB54940CF15A58460F55340F14927124CB54940CF15A58460F55340C5AEEDED96B4494055FA0967B7F45340C5AEEDED96B44940
71418	16651	80.119923	80.136021	50.999696	50.982903	Кооперативная	0103000020E6100000010000000500000072C284D1AC075440F511F8C3CF7D494072C284D1AC07544094F8DC09F67F49406EA46C91B408544094F8DC09F67F49406EA46C91B4085440F511F8C3CF7D494072C284D1AC075440F511F8C3CF7D4940
71166	15985	79.704470000000001	79.723882000000003	51.381314000000003	51.3703	Степная	0103000020E61000000100000005000000D7C0560916ED5340BADA8AFD65AF4940D7C0560916ED5340E4C0ABE5CEB04940700A2B1554EE5340E4C0ABE5CEB04940700A2B1554EE5340BADA8AFD65AF4940D7C0560916ED5340BADA8AFD65AF4940
71407	15602	81.931043000000003	81.954121000000001	53.437862000000003	53.422747999999999	Кузнецова	0103000020E61000000100000005000000DD0A6135967B54408639419B1CB64A40DD0A6135967B5440A114ADDC0BB84A4051DB8651107D5440A114ADDC0BB84A4051DB8651107D54408639419B1CB64A40DD0A6135967B54408639419B1CB64A40
69964	15163	81.723873999999995	81.778661999999997	53.152099999999997	53.127965000000003	Ульяновская	0103000020E610000001000000050000002E1B9DF3536E54402E04392861904A402E1B9DF3536E54405DDC460378934A40D4282499D57154405DDC460378934A40D4282499D57154402E04392861904A402E1B9DF3536E54402E04392861904A40
71411	15001	81.235800999999995	81.269191000000006	53.266348999999998	53.254143999999997	Центральный переулок	0103000020E610000001000000050000004DD7135D174F5440C03C64CA87A04A404DD7135D174F544041295AB917A24A402A58E36C3A51544041295AB917A24A402A58E36C3A515440C03C64CA87A04A404DD7135D174F5440C03C64CA87A04A40
71491	59467	81.760552000000004	81.783665999999997	53.051153999999997	53.034965999999997	Центральная	0103000020E6100000010000000500000013BA4BE2AC705440683C11C479844A4013BA4BE2AC705440A087DA368C864A402D3F709527725440A087DA368C864A402D3F709527725440683C11C479844A4013BA4BE2AC705440683C11C479844A40
69793	14678	81.478561999999997	81.525310000000005	53.334682999999998	53.298457999999997	Октябрьская	0103000020E61000000100000005000000EFC682C2A05E5440629D2ADF33A64A40EFC682C2A05E54407AC37DE4D6AA4A40C190D5AD9E6154407AC37DE4D6AA4A40C190D5AD9E615440629D2ADF33A64A40EFC682C2A05E5440629D2ADF33A64A40
70032	14678	81.478561999999997	81.525310000000005	53.334682999999998	53.298457999999997	Ленина	0103000020E61000000100000005000000EFC682C2A05E5440629D2ADF33A64A40EFC682C2A05E54407AC37DE4D6AA4A40C190D5AD9E6154407AC37DE4D6AA4A40C190D5AD9E615440629D2ADF33A64A40EFC682C2A05E5440629D2ADF33A64A40
70030	14678	81.478561999999997	81.525310000000005	53.334682999999998	53.298457999999997	Барнаульская	0103000020E61000000100000005000000EFC682C2A05E5440629D2ADF33A64A40EFC682C2A05E54407AC37DE4D6AA4A40C190D5AD9E6154407AC37DE4D6AA4A40C190D5AD9E615440629D2ADF33A64A40EFC682C2A05E5440629D2ADF33A64A40
71323	15208	81.596457000000001	81.622686999999999	53.104351000000001	53.093429	Центральная	0103000020E61000000100000005000000191EFB592C665440BEBF417BF58B4A40191EFB592C6654400727A25F5B8D4A403D29931ADA6754400727A25F5B8D4A403D29931ADA675440BEBF417BF58B4A40191EFB592C665440BEBF417BF58B4A40
70864	15364	81.598882000000003	81.618078999999994	53.299754999999998	53.287633999999997	Заводская	0103000020E61000000100000005000000700A2B1554665440DC9BDF30D1A44A40700A2B1554665440FFE7305F5EA64A400AD6389B8E675440FFE7305F5EA64A400AD6389B8E675440DC9BDF30D1A44A40700A2B1554665440DC9BDF30D1A44A40
70877	15552	81.678527000000003	81.715951000000004	53.361414000000003	53.352687000000003	Центральная	0103000020E61000000100000005000000FE9C82FC6C6B5440B85CFDD824AD4A40FE9C82FC6C6B544085285FD042AE4A4077A22424D26D544085285FD042AE4A4077A22424D26D5440B85CFDD824AD4A40FE9C82FC6C6B5440B85CFDD824AD4A40
70775	15035	81.167312999999993	81.186349000000007	53.234744999999997	53.221673000000003	Кулундинская	0103000020E6100000010000000500000085CC9541B54A5440FFB3E6C75F9C4A4085CC9541B54A544023F3C81F0C9E4A401C295B24ED4B544023F3C81F0C9E4A401C295B24ED4B5440FFB3E6C75F9C4A4085CC9541B54A5440FFB3E6C75F9C4A40
70581	15059	81.445414	81.465688999999998	53.183598000000003	53.170817999999997	Центральный	0103000020E610000001000000050000008ECBB8A9815C5440B8C83D5DDD954A408ECBB8A9815C544036CEA62380974A40D8463CD9CD5D544036CEA62380974A40D8463CD9CD5D5440B8C83D5DDD954A408ECBB8A9815C5440B8C83D5DDD954A40
71145	14840	81.402716999999996	81.436197000000007	53.451242999999998	53.438918000000001	Запорожская	0103000020E61000000100000005000000C422861DC659544018D00B772EB84A40C422861DC659544043C6A354C2B94A404167D2A6EA5B544043C6A354C2B94A404167D2A6EA5B544018D00B772EB84A40C422861DC659544018D00B772EB84A40
70866	15412	81.588740000000001	81.625867	53.213918999999997	53.199406000000003	Центральная	0103000020E61000000100000005000000367689EAAD6554402750C42286994A40367689EAAD6554401B7FA2B2619B4A40522976340E6854401B7FA2B2619B4A40522976340E6854402750C42286994A40367689EAAD6554402750C42286994A40
70947	15305	81.635210000000001	81.658152999999999	53.307702999999997	53.290787999999999	Центральная	0103000020E61000000100000005000000E605D847A7685440DD088B8A38A54A40E605D847A7685440C7F0D8CF62A74A40EAB0C22D1F6A5440C7F0D8CF62A74A40EAB0C22D1F6A5440DD088B8A38A54A40E605D847A7685440DD088B8A38A54A40
70779	14907	81.248889000000005	81.284695999999997	53.389423999999998	53.376517	Центральная	0103000020E6100000010000000500000063D520CCED4F5440ABB184B531B04A4063D520CCED4F5440852348A5D8B14A405453927538525440852348A5D8B14A405453927538525440ABB184B531B04A4063D520CCED4F5440ABB184B531B04A40
70182	15110	81.402861000000001	81.456607000000005	53.094251	53.064922000000003	Центральный	0103000020E610000001000000050000005EF58079C85954403D65355D4F884A405EF58079C8595440C24EB16A108C4A40FB07910C395D5440C24EB16A108C4A40FB07910C395D54403D65355D4F884A405EF58079C85954403D65355D4F884A40
70578	15453	81.798524	81.831680000000006	53.252926000000002	53.237918999999998	Молодежная	0103000020E610000001000000050000008D4468041B7354406B0C3A21749E4A408D4468041B735440702711E15FA04A40302FC03E3A755440702711E15FA04A40302FC03E3A7554406B0C3A21749E4A408D4468041B7354406B0C3A21749E4A40
71403	14925	81.172118999999995	81.194721000000001	53.328035999999997	53.311188999999999	Центральная	0103000020E610000001000000050000004B0169FF034B5440FEEF880AD5A74A404B0169FF034B544090F46915FDA94A400BB6114F764C544090F46915FDA94A400BB6114F764C5440FEEF880AD5A74A404B0169FF034B5440FEEF880AD5A74A40
71109	14589	84.459423000000001	84.488761999999994	52.809035000000002	52.785539999999997	Рабочая	0103000020E61000000100000005000000EF01BA2F671D554094D920938C644A40EF01BA2F671D5540E12879758E674A40C36169E0471F5540E12879758E674A40C36169E0471F554094D920938C644A40EF01BA2F671D554094D920938C644A40
71084	13102	84.059386000000003	84.078484000000003	52.604571	52.597783	Центральная	0103000020E61000000100000005000000C7F5EFFACC035540698D4127844C4A40C7F5EFFACC035540158E2095624D4A409850C1E105055540158E2095624D4A409850C1E105055540698D4127844C4A40C7F5EFFACC035540698D4127844C4A40
70921	13668	84.896749999999997	84.939492000000001	52.974654999999998	52.950208000000003	Советская	0103000020E6100000010000000500000008AC1C5A64395540E4326E6AA0794A4008AC1C5A6439554002F1BA7EC17C4A40A2B60DA3203C554002F1BA7EC17C4A40A2B60DA3203C5540E4326E6AA0794A4008AC1C5A64395540E4326E6AA0794A40
71090	13120	84.595248999999995	84.616314000000003	52.722065000000001	52.712015999999998	Центральная	0103000020E6100000010000000500000082FE428F18265540471D1D57235B4A4082FE428F182655400A4B3CA06C5C4A40498446B0712755400A4B3CA06C5C4A40498446B071275540471D1D57235B4A4082FE428F18265540471D1D57235B4A40
70985	13683	85.008617000000001	85.053668000000002	52.945107999999998	52.934019999999997	Школьная	0103000020E61000000100000005000000234C512E8D405540ABE7A4F78D774A40234C512E8D4055400F98874CF9784A40DF35E84B6F4355400F98874CF9784A40DF35E84B6F435540ABE7A4F78D774A40234C512E8D405540ABE7A4F78D774A40
71275	13247	84.584351999999996	84.611535000000003	52.951467000000001	52.927712999999997	Набережная	0103000020E610000001000000050000008A56EE05662555407A89B14CBF764A408A56EE0566255540931CB0ABC9794A400057B26323275540931CB0ABC9794A400057B263232755407A89B14CBF764A408A56EE05662555407A89B14CBF764A40
70184	12871	84.644233999999997	84.706863999999996	52.999028000000003	52.960667999999998	пер. Лермонтова	0103000020E61000000100000005000000293E3E213B2955402828452BF77A4A40293E3E213B295540E7E44526E07F4A4010AE80423D2D5540E7E44526E07F4A4010AE80423D2D55402828452BF77A4A40293E3E213B2955402828452BF77A4A40
70025	12871	84.644233999999997	84.706863999999996	52.999028000000003	52.960667999999998	Комсомольская	0103000020E61000000100000005000000293E3E213B2955402828452BF77A4A40293E3E213B295540E7E44526E07F4A4010AE80423D2D5540E7E44526E07F4A4010AE80423D2D55402828452BF77A4A40293E3E213B2955402828452BF77A4A40
70755	13885	85.073233000000002	85.091891000000004	53.138294000000002	53.122495999999998	Центральная	0103000020E610000001000000050000003BFF76D9AF44554006F2ECF2AD8F4A403BFF76D9AF445540D49D279EB3914A40FEF2C98AE1455540D49D279EB3914A40FEF2C98AE145554006F2ECF2AD8F4A403BFF76D9AF44554006F2ECF2AD8F4A40
70778	13464	84.754222999999996	84.767967999999996	52.87135	52.860298	Молодежная	0103000020E6100000010000000500000006B98B30453055403868AF3E1E6E4A4006B98B30453055404FAF9465886F4A40F8174163263155404FAF9465886F4A40F8174163263155403868AF3E1E6E4A4006B98B30453055403868AF3E1E6E4A40
71137	10579	84.880392000000001	84.892985999999993	53.140087999999999	53.131540999999999	переулок Школьный	0103000020E610000001000000050000003EEAAF5758385540A48AE255D6904A403EEAAF5758385540F1475167EE914A404B72C0AE26395540F1475167EE914A404B72C0AE26395540A48AE255D6904A403EEAAF5758385540A48AE255D6904A40
70408	14087	84.612343999999993	84.653836999999996	53.081125	53.052723	50 лет Алтая	0103000020E61000000100000005000000B779E3A4302755409E5F94A0BF864A40B779E3A430275540AAF1D24D628A4A408BFA2477D8295540AAF1D24D628A4A408BFA2477D82955409E5F94A0BF864A40B779E3A4302755409E5F94A0BF864A40
71128	14162	84.538501999999994	84.558560999999997	53.119897000000002	53.111660000000001	Школьная	0103000020E6100000010000000500000028B517D176225540BC22F8DF4A8E4A4028B517D176225540BBF1EEC8588F4A408CF4A276BF235540BBF1EEC8588F4A408CF4A276BF235540BC22F8DF4A8E4A4028B517D176225540BC22F8DF4A8E4A40
70789	14317	84.673788000000002	84.699561000000003	53.133146000000004	53.116168000000002	Юбилейная	0103000020E61000000100000005000000FC1BB4571F2B5540BE6BD097DE8E4A40FC1BB4571F2B5540EFCB99ED0A914A40A723809BC52C5540EFCB99ED0A914A40A723809BC52C5540BE6BD097DE8E4A40FC1BB4571F2B5540BE6BD097DE8E4A40
71466	59456	84.280955000000006	84.321405999999996	52.959279000000002	52.938254000000001	Линейная	0103000020E610000001000000050000007429AE2AFB115540ACAB02B518784A407429AE2AFB115540AB5E7EA7C97A4A403EAF78EA91145540AB5E7EA7C97A4A403EAF78EA91145540ACAB02B518784A407429AE2AFB115540ACAB02B518784A40
71120	13741	84.934505999999999	84.996823000000006	53.064137000000002	53.051034999999999	Елютина	0103000020E610000001000000050000009CFA40F2CE3B5540C6F99B5088864A409CFA40F2CE3B554056BB26A435884A40A439B2F2CB3F554056BB26A435884A40A439B2F2CB3F5540C6F99B5088864A409CFA40F2CE3B5540C6F99B5088864A40
70927	14551	84.358722	84.397295999999997	52.744166	52.727186000000003	Октябрьская	0103000020E61000000100000005000000C4961E4DF5165540F60D4C6E145D4A40C4961E4DF5165540C765DCD4405F4A4039B5334C6D195540C765DCD4405F4A4039B5334C6D195540F60D4C6E145D4A40C4961E4DF5165540F60D4C6E145D4A40
71404	14637	84.479913999999994	84.486705000000001	52.853000999999999	52.838887	Заречная	0103000020E610000001000000050000001FB935E9B61E5540100533A6606B4A401FB935E9B61E5540473A03232F6D4A402E73BA2C261F5540473A03232F6D4A402E73BA2C261F5540100533A6606B4A401FB935E9B61E5540100533A6606B4A40
70904	13317	84.525090000000006	84.549632000000003	52.769601000000002	52.739263999999999	Коммунарская	0103000020E610000001000000050000003A5D16139B215540198EE733A05E4A403A5D16139B21554005FC1A4982624A407235B22B2D23554005FC1A4982624A407235B22B2D235540198EE733A05E4A403A5D16139B215540198EE733A05E4A40
70579	13956	85.280581999999995	85.306866999999997	53.171207000000003	53.157677999999997	переулок Парковый	0103000020E610000001000000050000002976340EF55155403BA6EECA2E944A402976340EF551554053EC681CEA954A402F4E7CB5A353554053EC681CEA954A402F4E7CB5A35355403BA6EECA2E944A402976340EF55155403BA6EECA2E944A40
71151	14372	84.942430000000002	84.956092999999996	53.177785999999998	53.152591000000001	Центральная	0103000020E610000001000000050000003C31EBC5503C5540FC54151A88934A403C31EBC5503C5540E4D70FB1C1964A40CFBBB1A0303D5540E4D70FB1C1964A40CFBBB1A0303D5540FC54151A88934A403C31EBC5503C5540FC54151A88934A40
71397	13598	84.800487000000004	84.824184000000002	52.947701000000002	52.936087999999998	Сибирская	0103000020E61000000100000005000000E277D32D3B335540CA1649BBD1774A40E277D32D3B33554079B130444E794A40BC783F6EBF34554079B130444E794A40BC783F6EBF345540CA1649BBD1774A40E277D32D3B335540CA1649BBD1774A40
70355	13401	84.729788999999997	84.762855999999999	52.891359000000001	52.879159999999999	Школьная	0103000020E61000000100000005000000C1FEEBDCB42E5540C6F99B5088704A40C1FEEBDCB42E554065FF3C0D18724A40ACE3F8A1D230554065FF3C0D18724A40ACE3F8A1D2305540C6F99B5088704A40C1FEEBDCB42E5540C6F99B5088704A40
9952	13383	84.496964000000006	84.552955999999995	52.876041000000001	52.854669999999999	Школьная	0103000020E6100000010000000500000085D21742CE1F5540A86F99D3656D4A4085D21742CE1F5540427A8A1C22704A40200890A163235540427A8A1C22704A40200890A163235540A86F99D3656D4A4085D21742CE1F5540A86F99D3656D4A40
70185	14401	84.401302000000001	84.447727	53.079751000000002	53.060344000000001	50 лет Октября	0103000020E61000000100000005000000717495EEAE1955404241295AB9874A40717495EEAE1955406269E047358A4A4051A2258FA71C55406269E047358A4A4051A2258FA71C55404241295AB9874A40717495EEAE1955404241295AB9874A40
70784	13975	85.226772999999994	85.243077999999997	53.166494	53.156025	Школьная	0103000020E6100000010000000500000069A7E672834E5540E02D90A0F8934A4069A7E672834E5540787DE6AC4F954A40221807978E4F5540787DE6AC4F954A40221807978E4F5540E02D90A0F8934A4069A7E672834E5540E02D90A0F8934A40
70363	13827	85.092978000000002	85.143103999999994	53.064348000000003	53.047044999999997	Ленина	0103000020E61000000100000005000000D74FFF59F34555405C38109205864A40D74FFF59F345554011C8258E3C884A4050FBAD9D2849554011C8258E3C884A4050FBAD9D284955405C38109205864A40D74FFF59F34555405C38109205864A40
70357	14038	85.312922	85.365966999999998	53.083683999999998	53.065424999999998	Молодежная	0103000020E61000000100000005000000BB0CFFE9065455409FABADD85F884A40BB0CFFE90654554067994528B68A4A40931ADA006C57554067994528B68A4A40931ADA006C5755409FABADD85F884A40BB0CFFE9065455409FABADD85F884A40
69764	14263	84.665102000000005	84.694952999999998	53.119729	53.099556	Зеленая	0103000020E6100000010000000500000045A0FA07912A55406F0F4240BE8C4A4045A0FA07912A5540FFB0A547538F4A4074D0251C7A2C5540FFB0A547538F4A4074D0251C7A2C55406F0F4240BE8C4A4045A0FA07912A55406F0F4240BE8C4A40
70922	13798	84.923115999999993	84.966873000000007	53.087189000000002	53.071939999999998	Алтайская	0103000020E61000000100000005000000849A2155143B55401AA3755435894A40849A2155143B554015C95702298B4A40AB984A3FE13D554015C95702298B4A40AB984A3FE13D55401AA3755435894A40849A2155143B55401AA3755435894A40
71413	13516	84.659621999999999	84.693703999999997	52.732945000000001	52.71613	Центральная	0103000020E61000000100000005000000376E313F372A55409DD7D825AA5B4A40376E313F372A554024624A24D15D4A40AE4676A5652C554024624A24D15D4A40AE4676A5652C55409DD7D825AA5B4A40376E313F372A55409DD7D825AA5B4A40
70919	13274	84.687092000000007	84.704654000000005	52.869979999999998	52.857275000000001	Боровлянская	0103000020E61000000100000005000000F855B950F92B5540D656EC2FBB6D4A40F855B950F92B5540481630815B6F4A40B83F170D192D5540481630815B6F4A40B83F170D192D5540D656EC2FBB6D4A40F855B950F92B5540D656EC2FBB6D4A40
70417	12990	84.421919000000003	84.471874	52.645007999999997	52.619351999999999	Фефелова	0103000020E61000000100000005000000E8A38CB8001B5540295B24ED464F4A40E8A38CB8001B554045D4449F8F524A404B75012F331E554045D4449F8F524A404B75012F331E5540295B24ED464F4A40E8A38CB8001B5540295B24ED464F4A40
70609	12990	84.421919000000003	84.471874	52.645007999999997	52.619351999999999	Октябрьская	0103000020E61000000100000005000000E8A38CB8001B5540295B24ED464F4A40E8A38CB8001B554045D4449F8F524A404B75012F331E554045D4449F8F524A404B75012F331E5540295B24ED464F4A40E8A38CB8001B5540295B24ED464F4A40
70818	13549	84.694637999999998	84.763045000000005	52.933700000000002	52.912466999999999	40 лет Победы	0103000020E61000000100000005000000C423F1F2742C5540F1D6F9B7CB744A40C423F1F2742C55403A234A7B83774A401618B2BAD53055403A234A7B83774A401618B2BAD5305540F1D6F9B7CB744A40C423F1F2742C5540F1D6F9B7CB744A40
69792	13188	84.613826000000003	84.670176999999995	52.906351999999998	52.883986	Советская	0103000020E61000000100000005000000CFDBD8EC48275540990F087426714A40CFDBD8EC482755400455A35703744A400262122EE42A55400455A35703744A400262122EE42A5540990F087426714A40CFDBD8EC48275540990F087426714A40
71086	12666	82.369339999999994	82.394277000000002	50.948715	50.922468000000002	Михайлова	0103000020E61000000100000005000000B2463D44A3975440A3CD716E13764940B2463D44A3975440C11C3D7E6F794940292499D53B995440C11C3D7E6F794940292499D53B995440A3CD716E13764940B2463D44A3975440A3CD716E13764940
70416	12402	81.886324999999999	81.910381999999998	50.879347000000003	50.851058999999999	Центральная	0103000020E6100000010000000500000024287E8CB9785440B5FB5580EF6C494024287E8CB9785440F96A47718E7049407E37DDB2437A5440F96A47718E7049407E37DDB2437A5440B5FB5580EF6C494024287E8CB9785440B5FB5580EF6C4940
70885	25566	81.880539999999996	81.892208999999994	50.977238	50.968418999999997	Западная	0103000020E6100000010000000500000078B471C45A7854409AE95E27F57B494078B471C45A78544048348122167D4940990CC7F31979544048348122167D4940990CC7F3197954409AE95E27F57B494078B471C45A7854409AE95E27F57B4940
70270	12125	81.965654999999998	82.020408000000003	51.025022	50.987746000000001	Колхозная	0103000020E61000000100000005000000020EA14ACD7D54409E60FF756E7E4940020EA14ACD7D54401BD7BFEB33834940EA245B5D4E8154401BD7BFEB33834940EA245B5D4E8154409E60FF756E7E4940020EA14ACD7D54409E60FF756E7E4940
69789	12125	81.965654999999998	82.020408000000003	51.025022	50.987746000000001	Калашникова	0103000020E61000000100000005000000020EA14ACD7D54409E60FF756E7E4940020EA14ACD7D54401BD7BFEB33834940EA245B5D4E8154401BD7BFEB33834940EA245B5D4E8154409E60FF756E7E4940020EA14ACD7D54409E60FF756E7E4940
71305	12691	82.463258999999994	82.491654999999994	50.972859999999997	50.949475	Центральная	0103000020E61000000100000005000000F8A41309A69D54404FAF946588794940F8A41309A69D544014CB2DAD867C49408D7A8846779F544014CB2DAD867C49408D7A8846779F54404FAF946588794940F8A41309A69D54404FAF946588794940
70610	12206	81.911019999999994	81.931967999999998	50.990025000000003	50.977215999999999	Дорожная	0103000020E610000001000000050000001F80D4264E7A54406090F469157D49401F80D4264E7A5440789CA223B97E4940C93A1C5DA57B5440789CA223B97E4940C93A1C5DA57B54406090F469157D49401F80D4264E7A54406090F469157D4940
70607	12848	82.138823000000002	82.161891999999995	50.860066000000003	50.840041999999997	Центральная	0103000020E61000000100000005000000B03BDD79E28854401AA20A7F866B4940B03BDD79E2885440663387A4166E4940FA5E43705C8A5440663387A4166E4940FA5E43705C8A54401AA20A7F866B4940B03BDD79E28854401AA20A7F866B4940
70580	12530	81.915627999999998	81.943161000000003	50.885558000000003	50.873759999999997	Центральная	0103000020E6100000010000000500000052D32EA6997A5440C746205ED76F494052D32EA6997A5440085BECF6597149403677F4BF5C7C5440085BECF6597149403677F4BF5C7C5440C746205ED76F494052D32EA6997A5440C746205ED76F4940
70561	12639	82.250259	82.297475000000006	50.979636999999997	50.955075999999998	Советская	0103000020E61000000100000005000000E621533E04905440E5982CEE3F7A4940E621533E04905440CC79C6BE647D49402B1895D409935440CC79C6BE647D49402B1895D409935440E5982CEE3F7A4940E621533E04905440E5982CEE3F7A4940
71320	12378	82.093872000000005	82.129273999999995	50.941370999999997	50.926976000000003	Советская	0103000020E61000000100000005000000A680B4FF01865440A5164A26A7764940A680B4FF018654408F334DD87E784940478E7406468854408F334DD87E784940478E740646885440A5164A26A7764940A680B4FF01865440A5164A26A7764940
71089	12748	82.399928000000003	82.418549999999996	50.862988000000001	50.826098999999999	Центральная	0103000020E610000001000000050000004D309C6B989954401021AE9CBD6949404D309C6B98995440946B0A64766E4940696FF085C99A5440946B0A64766E4940696FF085C99A54401021AE9CBD6949404D309C6B989954401021AE9CBD694940
70752	12462	81.952754999999996	81.968072000000006	50.824506	50.803158000000003	Центральная	0103000020E610000001000000050000006E861BF0F97C5440A9C29FE1CD6649406E861BF0F97C54408AADA06989694940180B43E4F47D54408AADA06989694940180B43E4F47D5440A9C29FE1CD6649406E861BF0F97C5440A9C29FE1CD664940
69794	12293	81.956798000000006	81.974018999999998	51.112496	51.092807999999998	Кирова	0103000020E6100000010000000500000035B8AD2D3C7D54405167EE21E18B494035B8AD2D3C7D54402577D844668E4940B0ABC953567E54402577D844668E4940B0ABC953567E54405167EE21E18B494035B8AD2D3C7D54405167EE21E18B4940
69791	12299	82.006024999999994	82.028779999999998	50.922814000000002	50.895927	Титова	0103000020E61000000100000005000000567DAEB6628054403C4D66BCAD724940567DAEB6628054403E25E7C41E764940D9B11188D78154403E25E7C41E764940D9B11188D78154403C4D66BCAD724940567DAEB6628054403C4D66BCAD724940
71479	59461	82.438654	82.450997000000001	50.859428999999999	50.849739	Центральная	0103000020E610000001000000050000009D103AE8129C544060915F3FC46C49409D103AE8129C5440F31DFCC4016E494006668522DD9C5440F31DFCC4016E494006668522DD9C544060915F3FC46C49409D103AE8129C544060915F3FC46C4940
70122	12062	83.187301000000005	83.238110000000006	52.689489999999999	52.667765000000003	Партизанская	0103000020E61000000100000005000000856055BDFCCB5440EC34D25279554A40856055BDFCCB5440A375543541584A4070B6B9313DCF5440A375543541584A4070B6B9313DCF5440EC34D25279554A40856055BDFCCB5440EC34D25279554A40
70914	12054	82.337593999999996	84.194699	53.049795000000003	52.413998999999997	Лесная	0103000020E61000000100000005000000DA54DD239B955440D1C952EBFD344A40DA54DD239B9554408E40BCAE5F864A401764CBF2750C55408E40BCAE5F864A401764CBF2750C5540D1C952EBFD344A40DA54DD239B955440D1C952EBFD344A40
71292	11967	83.364160999999996	83.393535999999997	52.75244	52.735686999999999	Гагарина	0103000020E61000000100000005000000A25EF0694ED75440D28BDAFD2A5E4A40A25EF0694ED75440E31934F44F604A401D739EB12FD95440E31934F44F604A401D739EB12FD95440D28BDAFD2A5E4A40A25EF0694ED75440D28BDAFD2A5E4A40
70026	11911	83.001178999999993	83.071085999999994	52.80039	52.771453000000001	Юбилейная	0103000020E61000000100000005000000499C155113C0544057B3CEF8BE624A40499C155113C05440D105F52D73664A40054D4BAC8CC45440D105F52D73664A40054D4BAC8CC4544057B3CEF8BE624A40499C155113C0544057B3CEF8BE624A40
70739	11589	83.208806999999993	83.230860000000007	52.884399000000002	52.871850000000002	Центральная	0103000020E61000000100000005000000410B09185DCD54404182E2C7986F4A40410B09185DCD5440BCCE86FC33714A40187D0569C6CE5440BCCE86FC33714A40187D0569C6CE54404182E2C7986F4A40410B09185DCD54404182E2C7986F4A40
70090	10885	83.080348000000001	83.144137000000001	52.838887	52.795037000000001	Партизанская	0103000020E610000001000000050000002313F06B24C55440130EBDC5C3654A402313F06B24C55440100533A6606B4A403049658A39C95440100533A6606B4A403049658A39C95440130EBDC5C3654A402313F06B24C55440130EBDC5C3654A40
69784	10885	83.080348000000001	83.144137000000001	52.838887	52.795037000000001	Куйбышева	0103000020E610000001000000050000002313F06B24C55440130EBDC5C3654A402313F06B24C55440100533A6606B4A403049658A39C95440100533A6606B4A403049658A39C95440130EBDC5C3654A402313F06B24C55440130EBDC5C3654A40
70745	11197	83.254638999999997	83.268832000000003	52.471972999999998	52.463403	Центральная	0103000020E61000000100000005000000505260014CD0544024EF1CCA503B4A40505260014CD0544029CC7B9C693C4A409207228B34D1544029CC7B9C693C4A409207228B34D1544024EF1CCA503B4A40505260014CD0544024EF1CCA503B4A40
70352	11895	82.977095000000006	83.004655999999997	53.003574999999998	52.990448000000001	Октябрьская	0103000020E61000000100000005000000738577B988BE5440BE310400C77E4A40738577B988BE5440A60A462575804A40BBEEAD484CC05440A60A462575804A40BBEEAD484CC05440BE310400C77E4A40738577B988BE5440BE310400C77E4A40
70915	11833	83.369488000000004	83.393580999999998	52.719118999999999	52.706947999999997	Школьная	0103000020E61000000100000005000000ED10FFB0A5D754407EFCA5457D5A4A40ED10FFB0A5D75440537765170C5C4A40EDD45C6E30D95440537765170C5C4A40EDD45C6E30D954407EFCA5457D5A4A40ED10FFB0A5D754407EFCA5457D5A4A40
70287	11625	82.990883999999994	83.012049000000005	52.668404000000002	52.656584000000002	Ленина	0103000020E610000001000000050000004C88B9A46ABF5440D789CBF10A544A404C88B9A46ABF5440FF4124438E554A40C53C2B69C5C05440FF4124438E554A40C53C2B69C5C05440D789CBF10A544A404C88B9A46ABF5440D789CBF10A544A40
70887	11497	82.485016000000002	82.522925000000001	52.797024999999998	52.784412000000003	Школьная	0103000020E610000001000000050000005A828C800A9F5440844BC79C67644A405A828C800A9F5440158C4AEA04664A40B1506B9A77A15440158C4AEA04664A40B1506B9A77A15440844BC79C67644A405A828C800A9F5440844BC79C67644A40
70577	11541	83.086402000000007	83.117637000000002	52.890690999999997	52.872703000000001	Губина	0103000020E61000000100000005000000C713419C87C55440800F5EBBB46F4A40C713419C87C55440B7EBA52902724A402CF3565D87C75440B7EBA52902724A402CF3565D87C75440800F5EBBB46F4A40C713419C87C55440800F5EBBB46F4A40
69785	11451	82.696011999999996	82.766557000000006	52.820360999999998	52.797508999999998	Школьная	0103000020E61000000100000005000000E867EA758BAC544001A260C614664A40E867EA758BAC5440F9F4D89601694A40466117450FB15440F9F4D89601694A40466117450FB1544001A260C614664A40E867EA758BAC544001A260C614664A40
70428	11418	83.026214999999993	83.052014999999997	52.879474999999999	52.866767000000003	Центральная	0103000020E6100000010000000500000089EAAD81ADC1544043209738F26E4A4089EAAD81ADC15440265305A392704A40B1F9B83654C35440265305A392704A40B1F9B83654C3544043209738F26E4A4089EAAD81ADC1544043209738F26E4A40
71082	11352	83.946844999999996	84.006474999999995	52.759127999999997	52.747076999999997	Центральная	0103000020E610000001000000050000006458C51B99FC5440014C1938A05F4A406458C51B99FC54402BBD361B2B614A40764F1E166A0055402BBD361B2B614A40764F1E166A005540014C1938A05F4A406458C51B99FC5440014C1938A05F4A40
71265	11296	83.452313000000004	83.483870999999994	52.760305000000002	52.747807000000002	Центральная	0103000020E6100000010000000500000090A339B2F2DC5440255CC823B85F4A4090A339B2F2DC54401EFE9AAC51614A40E61E12BEF7DE54401EFE9AAC51614A40E61E12BEF7DE5440255CC823B85F4A4090A339B2F2DC5440255CC823B85F4A40
71290	11746	83.020932999999999	83.042996000000002	52.628711000000003	52.608010999999998	Центральная	0103000020E610000001000000050000000F9A5DF756C15440DB4DF04DD34D4A400F9A5DF756C1544057D11F9A79504A40F7764B72C0C2544057D11F9A79504A40F7764B72C0C25440DB4DF04DD34D4A400F9A5DF756C15440DB4DF04DD34D4A40
70603	11260	83.381058999999993	83.401072999999997	52.624217000000002	52.612129000000003	Молодежная	0103000020E610000001000000050000002CB6494563D8544073F7393E5A4E4A402CB6494563D85440BA4DB857E64F4A40C093162EABD95440BA4DB857E64F4A40C093162EABD9544073F7393E5A4E4A402CB6494563D8544073F7393E5A4E4A40
70570	59401	83.153739999999999	83.177499999999995	52.557478000000003	52.537654000000003	Садовая	0103000020E6100000010000000500000092054CE0D6C954402448A5D8D1444A4092054CE0D6C95440A81E69705B474A408FC2F5285CCB5440A81E69705B474A408FC2F5285CCB54402448A5D8D1444A4092054CE0D6C954402448A5D8D1444A40
70354	11132	83.133357000000004	83.182485999999997	52.638635999999998	52.613332	Партизанская	0103000020E61000000100000005000000556CCCEB88C854408ECBB8A9814E4A40556CCCEB88C854402D060FD3BE514A40957EC2D9ADCB54402D060FD3BE514A40957EC2D9ADCB54408ECBB8A9814E4A40556CCCEB88C854408ECBB8A9814E4A40
70734	11694	82.968677999999997	82.985017999999997	52.691383999999999	52.676507000000001	Московская	0103000020E61000000100000005000000B39602D2FEBD5440EE4108C897564A40B39602D2FEBD5440247D5A457F584A402AFEEF880ABF5440247D5A457F584A402AFEEF880ABF5440EE4108C897564A40B39602D2FEBD5440EE4108C897564A40
70908	11789	83.045124999999999	83.067905999999994	52.699891999999998	52.680864	Садовая	0103000020E61000000100000005000000D9CEF753E3C254400A83328D26574A40D9CEF753E3C25440B35DA10F96594A40F04C689258C45440B35DA10F96594A40F04C689258C454400A83328D26574A40D9CEF753E3C254400A83328D26574A40
70604	11088	83.601218000000003	83.637608999999998	52.727392999999999	52.695548000000002	Володарского	0103000020E610000001000000050000000FF10F5B7AE654402C6684B707594A400FF10F5B7AE654406F2BBD361B5D4A40A8A8FA95CEE854406F2BBD361B5D4A40A8A8FA95CEE854402C6684B707594A400FF10F5B7AE654402C6684B707594A40
70400	11014	83.149553999999995	83.181551999999996	52.775730000000003	52.765051	Гагарина	0103000020E610000001000000050000001ABFF04A92C95440D462F030ED614A401ABFF04A92C954405743E21E4B634A407FA1478C9ECB54405743E21E4B634A407FA1478C9ECB5440D462F030ED614A401ABFF04A92C95440D462F030ED614A40
70912	10453	85.988355999999996	86.004300999999998	53.622275000000002	53.613505000000004	Новаря	0103000020E610000001000000050000008B338639417F55405C77F35487CE4A408B338639417F5540280F0BB5A6CF4A40C495B37746805540280F0BB5A6CF4A40C495B377468055405C77F35487CE4A408B338639417F55405C77F35487CE4A40
70733	10712	86.002180999999993	86.026381999999998	53.504516000000002	53.487518999999999	Кузнецкая	0103000020E610000001000000050000000BEBC6BB23805540DD96C80567BE4A400BEBC6BB238055408527F4FA93C04A40FFCC203EB08155408527F4FA93C04A40FFCC203EB0815540DD96C80567BE4A400BEBC6BB23805540DD96C80567BE4A40
71300	10662	86.084160999999995	86.107212000000004	53.377811999999999	53.369731999999999	Новая	0103000020E6100000010000000500000050A6D1E4628555407024D06053AF4A4050A6D1E462855540A704C4245CB04A40486FB88FDC865540A704C4245CB04A40486FB88FDC8655407024D06053AF4A4050A6D1E4628555407024D06053AF4A40
70073	10158	85.883505	85.936702999999994	53.485982	53.449719999999999	Школьная	0103000020E610000001000000050000008F368E588B785540B62DCA6C90B94A408F368E588B785540EB387EA834BE4A402AC423F1F27B5540EB387EA834BE4A402AC423F1F27B5540B62DCA6C90B94A408F368E588B785540B62DCA6C90B94A40
70361	10158	85.883505	85.936702999999994	53.485982	53.449719999999999	Совхозная	0103000020E610000001000000050000008F368E588B785540B62DCA6C90B94A408F368E588B785540EB387EA834BE4A402AC423F1F27B5540EB387EA834BE4A402AC423F1F27B5540B62DCA6C90B94A408F368E588B785540B62DCA6C90B94A40
70545	10158	85.883505	85.936702999999994	53.485982	53.449719999999999	Пролетарская	0103000020E610000001000000050000008F368E588B785540B62DCA6C90B94A408F368E588B785540EB387EA834BE4A402AC423F1F27B5540EB387EA834BE4A402AC423F1F27B5540B62DCA6C90B94A408F368E588B785540B62DCA6C90B94A40
69781	10158	85.883505	85.936702999999994	53.485982	53.449719999999999	Октябрьская	0103000020E610000001000000050000008F368E588B785540B62DCA6C90B94A408F368E588B785540EB387EA834BE4A402AC423F1F27B5540EB387EA834BE4A402AC423F1F27B5540B62DCA6C90B94A408F368E588B785540B62DCA6C90B94A40
71250	10439	85.749206000000001	85.770370999999997	53.418320999999999	53.405585000000002	Центральная	0103000020E61000000100000005000000E3FDB8FDF26F5540C45F9335EAB34A40E3FDB8FDF26F5540711DE38A8BB54A405BB22AC24D715540711DE38A8BB54A405BB22AC24D715540C45F9335EAB34A40E3FDB8FDF26F5540C45F9335EAB34A40
70611	10728	85.880621000000005	85.912880000000001	53.443300000000001	53.419497	Центральная	0103000020E61000000100000005000000EFCA2E185C78554093E2E313B2B54A40EFCA2E185C7855408D28ED0DBEB84A400A4B3CA06C7A55408D28ED0DBEB84A400A4B3CA06C7A554093E2E313B2B54A40EFCA2E185C78554093E2E313B2B54A40
70769	10535	85.800787999999997	85.825429	53.643450000000001	53.619781000000003	Центральная	0103000020E61000000100000005000000DFC14F1C4073554052D7DAFB54CF4A40DFC14F1C407355403C4ED1915CD24A40E10A28D4D37455403C4ED1915CD24A40E10A28D4D374554052D7DAFB54CF4A40DFC14F1C4073554052D7DAFB54CF4A40
70983	10365	85.947149999999993	85.956601000000006	53.462223000000002	53.453200000000002	Заводская	0103000020E61000000100000005000000029A081B9E7C55400B46257502BA4A40029A081B9E7C5540C13A8E1F2ABB4A408A9466F3387D5540C13A8E1F2ABB4A408A9466F3387D55400B46257502BA4A40029A081B9E7C55400B46257502BA4A40
70917	10825	85.861918000000003	85.879228999999995	53.332611999999997	53.321990999999997	Бийская	0103000020E610000001000000050000005C751DAA297755409C4D470037A94A405C751DAA29775540EA20AF0793AA4A40772CB64945785540EA20AF0793AA4A40772CB649457855409C4D470037A94A405C751DAA297755409C4D470037A94A40
71459	59452	86.182508999999996	86.198535000000007	53.472810000000003	53.461703	Лесная	0103000020E61000000100000005000000718E3A3AAE8B554088BB7A1519BB4A40718E3A3AAE8B5540639CBF0985BC4A40210725CCB48C5540639CBF0985BC4A40210725CCB48C554088BB7A1519BB4A40718E3A3AAE8B554088BB7A1519BB4A40
71078	10857	85.795074	85.824242999999996	53.39969	53.374712000000002	Молодежная	0103000020E6100000010000000500000098F90E7EE27255409AB51490F6AF4A4098F90E7EE2725540E544BB0A29B34A403E3DB665C0745540E544BB0A29B34A403E3DB665C07455409AB51490F6AF4A4098F90E7EE27255409AB51490F6AF4A40
69762	10741	85.828528000000006	85.85369	53.316606	53.286180999999999	Мокарова	0103000020E6100000010000000500000080F44D9A0675554048DE3994A1A44A4080F44D9A06755540D3DB9F8B86A84A4006BB61DBA2765540D3DB9F8B86A84A4006BB61DBA276554048DE3994A1A44A4080F44D9A0675554048DE3994A1A44A40
70110	59384	83.625392000000005	83.757192000000003	53.708964999999999	53.630696	Калинина	0103000020E6100000010000000500000086CB2A6C06E85440E8DB82A5BAD04A4086CB2A6C06E854401B81785DBFDA4A40BE326FD575F054401B81785DBFDA4A40BE326FD575F05440E8DB82A5BAD04A4086CB2A6C06E85440E8DB82A5BAD04A40
71288	9474	83.166739000000007	83.201468000000006	53.604204000000003	53.580827999999997	Центральная	0103000020E61000000100000005000000F0FD0DDAABCA5440F04C689258CA4A40F0FD0DDAABCA5440630E828E56CD4A4032CC09DAE4CC5440630E828E56CD4A4032CC09DAE4CC5440F04C689258CA4A40F0FD0DDAABCA5440F04C689258CA4A40
70905	9423	83.213172999999998	83.231965000000002	53.643433999999999	53.624901999999999	Советская	0103000020E61000000100000005000000F9D85DA0A4CD54403D9AEAC9FCCF4A40F9D85DA0A4CD54403691990B5CD24A404434BA83D8CE54403691990B5CD24A404434BA83D8CE54403D9AEAC9FCCF4A40F9D85DA0A4CD54403D9AEAC9FCCF4A40
70821	8659	83.110881000000006	83.136105999999998	53.617109999999997	53.598075000000001	Школьная	0103000020E61000000100000005000000DC2F9FAC18C7544011C7BAB88DCC4A40DC2F9FAC18C754406C04E275FDCE4A4085B2F0F5B5C854406C04E275FDCE4A4085B2F0F5B5C8544011C7BAB88DCC4A40DC2F9FAC18C7544011C7BAB88DCC4A40
70627	9351	83.943961000000002	83.979651000000004	53.953842000000002	53.937626000000002	Садовая	0103000020E61000000100000005000000C4EC65DB69FC54408DF0F62004F84A40C4EC65DB69FC54408FC6A17E17FA4A40999F1B9AB2FE54408FC6A17E17FA4A40999F1B9AB2FE54408DF0F62004F84A40C4EC65DB69FC54408DF0F62004F84A40
71286	8983	83.672354999999996	83.694767999999996	53.865456999999999	53.848723	Клубная	0103000020E61000000100000005000000551344DD07EB5440772E8CF4A2EC4A40551344DD07EB5440118C834BC7EE4A40AB93331477EC5440118C834BC7EE4A40AB93331477EC5440772E8CF4A2EC4A40551344DD07EB5440772E8CF4A2EC4A40
69779	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Учительская	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69979	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Партизанская	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
70068	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Парковая	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69757	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Октябрьская	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
70057	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Лисавенко	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69759	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Куйбышева	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69755	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Кирова	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69777	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	Анисимовская	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69758	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	60 лет СССР	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
69770	9490	83.506777999999997	83.625238999999993	53.836221999999999	53.799734999999998	30 лет ВЛКСМ	0103000020E610000001000000050000004415FE0C6FE05440B83B6BB75DE64A404415FE0C6FE054400D198F5209EB4A40C24B70EA03E854400D198F5209EB4A40C24B70EA03E85440B83B6BB75DE64A404415FE0C6FE05440B83B6BB75DE64A40
71072	9348	83.450767999999997	83.476954000000006	53.779974000000003	53.764563000000003	Советская	0103000020E6100000010000000500000055850662D9DC5440A75D4C33DDE14A4055850662D9DC54407BDD2230D6E34A4092EC116A86DE54407BDD2230D6E34A4092EC116A86DE5440A75D4C33DDE14A4055850662D9DC5440A75D4C33DDE14A40
69771	9287	83.625355999999996	83.656806000000003	53.766240000000003	53.734026999999998	Юбилейная	0103000020E61000000100000005000000DF162CD505E85440C4B0C398F4DD4A40DF162CD505E854408B71FE2614E24A404374081C09EA54408B71FE2614E24A404374081C09EA5440C4B0C398F4DD4A40DF162CD505E85440C4B0C398F4DD4A40
70920	8606	83.000236000000001	83.014519000000007	53.749285	53.739753	Новая	0103000020E610000001000000050000000A12DBDD03C05440170FEF39B0DE4A400A12DBDD03C0544012312592E8DF4A40EC8A19E1EDC0544012312592E8DF4A40EC8A19E1EDC05440170FEF39B0DE4A400A12DBDD03C05440170FEF39B0DE4A40
70735	9230	83.333250000000007	83.349671999999998	53.502876999999998	53.490391000000002	Школьная	0103000020E6100000010000000500000017D9CEF753D554405AA0DD21C5BE4A4017D9CEF753D554408E7406465EC04A40EC14AB0661D654408E7406465EC04A40EC14AB0661D654405AA0DD21C5BE4A4017D9CEF753D554405AA0DD21C5BE4A40
69754	9045	83.684438	83.726623000000004	53.640236999999999	53.615155000000001	Юбилейная	0103000020E61000000100000005000000F0880AD5CDEB5440467C2766BDCE4A40F0880AD5CDEB544036583849F3D14A405F61C1FD80EE544036583849F3D14A405F61C1FD80EE5440467C2766BDCE4A40F0880AD5CDEB5440467C2766BDCE4A40
70052	9045	83.684438	83.726623000000004	53.640236999999999	53.615155000000001	Промышленная	0103000020E61000000100000005000000F0880AD5CDEB5440467C2766BDCE4A40F0880AD5CDEB544036583849F3D14A405F61C1FD80EE544036583849F3D14A405F61C1FD80EE5440467C2766BDCE4A40F0880AD5CDEB5440467C2766BDCE4A40
70046	9045	83.684438	83.726623000000004	53.640236999999999	53.615155000000001	Новая	0103000020E61000000100000005000000F0880AD5CDEB5440467C2766BDCE4A40F0880AD5CDEB544036583849F3D14A405F61C1FD80EE544036583849F3D14A405F61C1FD80EE5440467C2766BDCE4A40F0880AD5CDEB5440467C2766BDCE4A40
70531	8927	83.713488999999996	83.759276	53.906793	53.883451999999998	Советская	0103000020E610000001000000050000009143C4CDA9ED5440FBCA83F414F14A409143C4CDA9ED5440F19E03CB11F44A40D0285DFA97F05440F19E03CB11F44A40D0285DFA97F05440FBCA83F414F14A409143C4CDA9ED5440FBCA83F414F14A40
69768	8876	83.486340999999996	83.521428999999998	53.888897	53.861856000000003	Зеленая	0103000020E610000001000000050000000D6D003620DF544042EE224C51EE4A400D6D003620DF54409A417C60C7F14A40E78BBD175FE154409A417C60C7F14A40E78BBD175FE1544042EE224C51EE4A400D6D003620DF544042EE224C51EE4A40
71280	8524	83.310666999999995	83.340301999999994	53.919611000000003	53.901201999999998	Школьная	0103000020E61000000100000005000000923CD7F7E1D354407E8B4E965AF34A40923CD7F7E1D354405C0531D0B5F54A40DB300A82C7D554405C0531D0B5F54A40DB300A82C7D554407E8B4E965AF34A40923CD7F7E1D354407E8B4E965AF34A40
71087	8454	83.565770000000001	83.588363000000001	53.786639999999998	53.774285999999996	Октябрьская	0103000020E61000000100000005000000B5C35F9335E4544015E0BBCD1BE34A40B5C35F9335E45440DBDC989EB0E44A404BCB48BDA7E55440DBDC989EB0E44A404BCB48BDA7E5544015E0BBCD1BE34A40B5C35F9335E4544015E0BBCD1BE34A40
71282	8794	83.506302000000005	83.529567999999998	54.03275	54.003675000000001	Советская	0103000020E6100000010000000500000090F9804067E054400A68226C78004B4090F9804067E05440D578E92631044B4085402E71E4E15440D578E92631044B4085402E71E4E154400A68226C78004B4090F9804067E054400A68226C78004B40
70399	8731	83.595388	83.646915000000007	53.801490000000001	53.782735000000002	Центральная	0103000020E61000000100000005000000931B45D61AE65440A03715A930E44A40931B45D61AE6544018096D3997E64A40AE122C0E67E9544018096D3997E64A40AE122C0E67E95440A03715A930E44A40931B45D61AE65440A03715A930E44A40
71213	27730	83.707480000000004	83.724520999999996	53.574235999999999	53.566135000000003	Центральная	0103000020E61000000100000005000000BEA4315A47ED54407C0F971C77C84A40BEA4315A47ED5440CA17B49080C94A40F910548D5EEE5440CA17B49080C94A40F910548D5EEE54407C0F971C77C84A40BEA4315A47ED54407C0F971C77C84A40
69751	8577	83.022281000000007	83.063395999999997	53.77816	53.765999999999998	Строительная	0103000020E610000001000000050000009F94490D6DC15440355EBA490CE24A409F94490D6DC15440168733BF9AE34A409FAC18AE0EC45440168733BF9AE34A409FAC18AE0EC45440355EBA490CE24A409F94490D6DC15440355EBA490CE24A40
70396	8459	83.309741000000002	83.343608000000003	53.888737999999996	53.850141000000001	Школьная	0103000020E61000000100000005000000BE4EEACBD2D354408FFE976BD1EC4A40BE4EEACBD2D35440315BB22AC2F14A4037A968ACFDD55440315BB22AC2F14A4037A968ACFDD554408FFE976BD1EC4A40BE4EEACBD2D354408FFE976BD1EC4A40
70724	8838	83.517908000000006	83.537985000000006	53.971307000000003	53.956878000000003	Школьная	0103000020E610000001000000050000008E95986725E15440862172FA7AFA4A408E95986725E154401DB0ABC953FC4A40452FA3586EE254401DB0ABC953FC4A40452FA3586EE25440862172FA7AFA4A408E95986725E15440862172FA7AFA4A40
70391	8371	83.445351000000002	83.501728999999997	53.737580000000001	53.717992000000002	Советская	0103000020E610000001000000050000006B0F7BA180DC544013656F29E7DB4A406B0F7BA180DC544083177D0569DE4A401B9DF3531CE0544083177D0569DE4A401B9DF3531CE0544013656F29E7DB4A406B0F7BA180DC544013656F29E7DB4A40
70952	8366	83.251917000000006	83.298323999999994	54.038915000000003	54.007829000000001	Центральная	0103000020E610000001000000050000009D137B681FD05440EE7A698A00014B409D137B681FD054407429AE2AFB044B4029E78BBD17D354407429AE2AFB044B4029E78BBD17D35440EE7A698A00014B409D137B681FD05440EE7A698A00014B40
70601	8295	83.305097000000004	83.335684999999998	53.702553000000002	53.677748000000001	Центральная	0103000020E61000000100000005000000E54691B586D35440F7764B72C0D64A40E54691B586D35440755AB741EDD94A407F30F0DC7BD55440755AB741EDD94A407F30F0DC7BD55440F7764B72C0D64A40E54691B586D35440F7764B72C0D64A40
71147	8222	83.785551999999996	83.860399999999998	54.086342999999999	54.051513	Центральная	0103000020E61000000100000005000000AC53E57B46F25440D0285DFA97064B40AC53E57B46F25440889E94490D0B4B409E5E29CB10F75440889E94490D0B4B409E5E29CB10F75440D0285DFA97064B40AC53E57B46F25440D0285DFA97064B40
70738	8201	83.659321000000006	83.672507999999993	53.811114000000003	53.797879000000002	микрорайон Черемушки	0103000020E610000001000000050000003A24B55032EA5440259529E620E64A403A24B55032EA5440F4A96395D2E74A401893FE5E0AEB5440F4A96395D2E74A401893FE5E0AEB5440259529E620E64A403A24B55032EA5440259529E620E64A40
70902	8746	83.723928000000001	83.752189000000001	53.853555999999998	53.831556999999997	Центральная	0103000020E61000000100000005000000282A1BD654EE544043E1B37570EA4A40282A1BD654EE5440FCA6B05241ED4A404DDA54DD23F05440FCA6B05241ED4A404DDA54DD23F0544043E1B37570EA4A40282A1BD654EE544043E1B37570EA4A40
70723	9209	83.813077000000007	83.829480000000004	53.735162000000003	53.727336999999999	Береговая	0103000020E610000001000000050000004F081D7409F45440DB15FA6019DD4A404F081D7409F4544088A1D5C919DE4A40E92B483316F5544088A1D5C919DE4A40E92B483316F55440DB15FA6019DD4A404F081D7409F45440DB15FA6019DD4A40
69987	8144	83.591103000000004	83.641893999999994	54.041110000000003	54.003860000000003	Тальменская	0103000020E610000001000000050000005264ADA1D4E554409CE1067C7E004B405264ADA1D4E55440F0C4AC1743054B40E95F92CA14E95440F0C4AC1743054B40E95F92CA14E954409CE1067C7E004B405264ADA1D4E554409CE1067C7E004B40
70897	7869	79.205670999999995	79.218382000000005	52.946067999999997	52.934095999999997	Молодежная	0103000020E6100000010000000500000014AFB2B629CD534086A92D7590774A4014AFB2B629CD534064E597C118794A403F027FF8F9CD534064E597C118794A403F027FF8F9CD534086A92D7590774A4014AFB2B629CD534086A92D7590774A40
70891	7774	79.335002000000003	79.353965000000002	52.932191000000003	52.917870000000001	Комсомольская	0103000020E610000001000000050000000E863AAC70D5534061FD9FC37C754A400E863AAC70D553401250E10852774A406FBBD05CA7D653401250E10852774A406FBBD05CA7D6534061FD9FC37C754A400E863AAC70D5534061FD9FC37C754A40
71255	7441	78.852920999999995	78.870788000000005	52.823653	52.815342999999999	Мира	0103000020E610000001000000050000009544F64196B65340E202D0285D684A409544F64196B653404B2025766D694A40F46F97FDBAB753404B2025766D694A40F46F97FDBAB75340E202D0285D684A409544F64196B65340E202D0285D684A40
70527	7304	78.762513999999996	78.803145000000001	52.787712999999997	52.757651000000003	Московская	0103000020E610000001000000050000007F2F8507CDB053400F643DB5FA604A407F2F8507CDB0534028D192C7D3644A408A3C49BA66B3534028D192C7D3644A408A3C49BA66B353400F643DB5FA604A407F2F8507CDB053400F643DB5FA604A40
69905	7304	78.762513999999996	78.803145000000001	52.787712999999997	52.757651000000003	Ленина	0103000020E610000001000000050000007F2F8507CDB053400F643DB5FA604A407F2F8507CDB0534028D192C7D3644A408A3C49BA66B3534028D192C7D3644A408A3C49BA66B353400F643DB5FA604A407F2F8507CDB053400F643DB5FA604A40
70384	7693	79.187939	79.220124999999996	52.889952000000001	52.880991999999999	Ленина	0103000020E6100000010000000500000026A94C3107CC5340D1048A58C4704A4026A94C3107CC5340418177F2E9714A400C022B8716CE5340418177F2E9714A400C022B8716CE5340D1048A58C4704A4026A94C3107CC5340D1048A58C4704A40
71077	7746	79.111949999999993	79.130267000000003	52.882888000000001	52.876291000000002	Целинная	0103000020E61000000100000005000000613255302AC75340BB63B14D2A704A40613255302AC75340F303577902714A40E02F664B56C85340F303577902714A40E02F664B56C85340BB63B14D2A704A40613255302AC75340BB63B14D2A704A40
71276	7378	78.889365999999995	78.896247000000002	52.782158000000003	52.765993999999999	пер.Центральный	0103000020E61000000100000005000000280B5F5FEBB85340537765170C624A40280B5F5FEBB853400327DBC01D644A40D788601C5CB953400327DBC01D644A40D788601C5CB95340537765170C624A40280B5F5FEBB85340537765170C624A40
71241	16383	78.582033999999993	78.603566999999998	52.615879999999997	52.606349000000002	Озерная	0103000020E610000001000000050000003ECA880B40A553402D7B12D89C4D4A403ECA880B40A553405721E527D54E4A40787C7BD7A0A653405721E527D54E4A40787C7BD7A0A653402D7B12D89C4D4A403ECA880B40A553402D7B12D89C4D4A40
70892	7588	78.709019999999995	78.725269999999995	52.736804999999997	52.729748999999998	Свердлова	0103000020E610000001000000050000006F0D6C9560AD5340F4A44C6A685D4A406F0D6C9560AD5340BF4351A04F5E4A4046B1DCD26AAE5340BF4351A04F5E4A4046B1DCD26AAE5340F4A44C6A685D4A406F0D6C9560AD5340F4A44C6A685D4A40
71270	7851	79.116864000000007	79.127274999999997	52.952612000000002	52.942290999999997	Лермонтова	0103000020E610000001000000050000001B8524B37AC753405628D2FD9C784A401B8524B37AC753407AE3A430EF794A404CA60A4625C853407AE3A430EF794A404CA60A4625C853405628D2FD9C784A401B8524B37AC753405628D2FD9C784A40
71160	8020	79.284048999999996	79.307432000000006	52.792625000000001	52.779406999999999	Ленина	0103000020E61000000100000005000000895DDBDB2DD2534001A3CB9BC3634A40895DDBDB2DD25340FA7E6ABC74654A409C6F44F7ACD35340FA7E6ABC74654A409C6F44F7ACD3534001A3CB9BC3634A40895DDBDB2DD2534001A3CB9BC3634A40
70901	7968	78.866405	78.879312999999996	52.896830000000001	52.889045000000003	Ленина	0103000020E61000000100000005000000D105F52D73B753400FD6FF39CC714A40D105F52D73B753402D095053CB724A40A67C08AA46B853402D095053CB724A40A67C08AA46B853400FD6FF39CC714A40D105F52D73B753400FD6FF39CC714A40
70893	7663	78.431017999999995	78.452181999999993	52.763117000000001	52.753242	Гагарина	0103000020E61000000100000005000000307F85CC959B5340A0FCDD3B6A604A40307F85CC959B5340C5025FD1AD614A40C075C58CF09C5340C5025FD1AD614A40C075C58CF09C5340A0FCDD3B6A604A40307F85CC959B5340A0FCDD3B6A604A40
70710	7489	78.780319000000006	78.797754999999995	52.834688	52.822254999999998	пер.Школьный	0103000020E61000000100000005000000A35C1ABFF0B153407AFCDEA63F694A40A35C1ABFF0B153408C2E6F0ED76A4A401CCEFC6A0EB353408C2E6F0ED76A4A401CCEFC6A0EB353407AFCDEA63F694A40A35C1ABFF0B153407AFCDEA63F694A40
70596	7934	78.839949000000004	78.873554999999996	53.005932000000001	52.984533999999996	Ленина	0103000020E61000000100000005000000B55373B9C1B5534068E6C935057E4A40B55373B9C1B55340FCFF3861C2804A4077103B53E8B75340FCFF3861C2804A4077103B53E8B7534068E6C935057E4A40B55373B9C1B5534068E6C935057E4A40
69965	7512	78.745751999999996	78.772009999999995	52.792963	52.778170000000003	Гагарина	0103000020E610000001000000050000004DBB9866BAAF53403A5D16139B634A404DBB9866BAAF534012F8C3CF7F654A40D68BA19C68B1534012F8C3CF7F654A40D68BA19C68B153403A5D16139B634A404DBB9866BAAF53403A5D16139B634A40
71068	7597	78.686733000000004	78.706100000000006	52.719692000000002	52.708627999999997	Центральная	0103000020E610000001000000050000006005F86EF3AB5340D3838252B45A4A406005F86EF3AB5340AF9811DE1E5C4A4029ED0DBE30AD5340AF9811DE1E5C4A4029ED0DBE30AD5340D3838252B45A4A406005F86EF3AB5340D3838252B45A4A40
71134	7055	79.704650000000001	79.716318999999999	53.241529999999997	53.231758999999997	Ленина	0103000020E61000000100000005000000174850FC18ED5340DEC66647AA9D4A40174850FC18ED53405E807D74EA9E4A4038A0A52BD8ED53405E807D74EA9E4A4038A0A52BD8ED5340DEC66647AA9D4A40174850FC18ED5340DEC66647AA9D4A40
70978	7243	80.015079999999998	80.032049999999998	53.256525000000003	53.248578000000002	Ленина	0103000020E61000000100000005000000B7B41A12F7005440A7406667D19F4A40B7B41A12F70054409FCDAACFD5A04A408E75711B0D0254409FCDAACFD5A04A408E75711B0D025440A7406667D19F4A40B7B41A12F7005440A7406667D19F4A40
71396	7206	79.916886000000005	79.931025000000005	53.325679999999998	53.313341000000001	Школьная	0103000020E61000000100000005000000420A9E42AEFA53407BBFD18E1BA84A40420A9E42AEFA53400B7BDAE1AFA94A408AB0E1E995FB53400B7BDAE1AFA94A408AB0E1E995FB53407BBFD18E1BA84A40420A9E42AEFA53407BBFD18E1BA84A40
70192	7161	79.872617000000005	79.918152000000006	53.232275999999999	53.212479999999999	Школьная	0103000020E61000000100000005000000C13BF9F4D8F75340EC866D8B329B4A40C13BF9F4D8F75340A6D24F38BB9D4A4073309B00C3FA5340A6D24F38BB9D4A4073309B00C3FA5340EC866D8B329B4A40C13BF9F4D8F75340EC866D8B329B4A40
71327	31655	79.950878000000003	79.968844000000004	53.157921000000002	53.144689999999997	Мичурина	0103000020E61000000100000005000000191F662FDBFC53407407B13385924A40191F662FDBFC5340022D5DC136944A4041BB438A01FE5340022D5DC136944A4041BB438A01FE53407407B13385924A40191F662FDBFC53407407B13385924A40
70024	7000	80.026004	80.069940000000003	53.321258999999998	53.283903000000002	Целинная	0103000020E610000001000000050000002C64AE0CAA0154403F1EFAEE56A44A402C64AE0CAA015440D845D1031FA94A40AA2B9FE579045440D845D1031FA94A40AA2B9FE5790454403F1EFAEE56A44A402C64AE0CAA0154403F1EFAEE56A44A40
70859	6967	80.081214000000003	80.098561000000004	53.177073	53.165652000000001	Центральная	0103000020E610000001000000050000008D7E349C320554402D42B11534954A408D7E349C320554409700FC53AA964A404FEACBD24E0654409700FC53AA964A404FEACBD24E0654402D42B11534954A408D7E349C320554402D42B11534954A40
71464	59454	86.550709999999995	86.564158000000006	52.862189999999998	52.855741000000002	Центральная	0103000020E6100000010000000500000021E527D53EA35540556CCCEB886D4A4021E527D53EA355401878EE3D5C6E4A40B7F1272A1BA455401878EE3D5C6E4A40B7F1272A1BA45540556CCCEB886D4A4021E527D53EA35540556CCCEB886D4A40
71243	6566	86.629779999999997	86.653765000000007	52.531677999999999	52.522374999999997	Заводская	0103000020E6100000010000000500000031EBC5504EA85540BE9F1A2FDD424A4031EBC5504EA85540580053060E444A403F912749D7A95540580053060E444A403F912749D7A95540BE9F1A2FDD424A4031EBC5504EA85540BE9F1A2FDD424A40
70713	6668	86.524092999999993	86.543307999999996	52.898834000000001	52.879964999999999	Школьная	0103000020E6100000010000000500000000C45DBD8AA15540F44F70B1A2704A4000C45DBD8AA15540354415FE0C734A40EEE9EA8EC5A25540354415FE0C734A40EEE9EA8EC5A25540F44F70B1A2704A4000C45DBD8AA15540F44F70B1A2704A40
70975	6861	86.517437000000001	86.538269	52.752822000000002	52.741134000000002	Центральная	0103000020E61000000100000005000000622F14B01DA1554012FA997ADD5E4A40622F14B01DA15540CBDAA6785C604A40D7DCD1FF72A25540CBDAA6785C604A40D7DCD1FF72A2554012FA997ADD5E4A40622F14B01DA1554012FA997ADD5E4A40
70350	6803	86.615658999999994	86.641647000000006	52.791639000000004	52.770553999999997	Центральная	0103000020E610000001000000050000003C9F01F566A75540A7E67283A1624A403C9F01F566A755407C9E3F6D54654A40E62494BE10A955407C9E3F6D54654A40E62494BE10A95540A7E67283A1624A403C9F01F566A75540A7E67283A1624A40
69903	3147	86.457967999999994	86.492311000000001	52.856746999999999	52.818978999999999	Ленина	0103000020E6100000010000000500000054A703594F9D55402E8ECA4DD4684A4054A703594F9D55401AF9BCE2A96D4A40821DFF05829F55401AF9BCE2A96D4A40821DFF05829F55402E8ECA4DD4684A4054A703594F9D55402E8ECA4DD4684A40
71231	6511	86.564876999999996	86.578792000000007	52.582607000000003	52.556787999999997	Центральная	0103000020E61000000100000005000000CE50DCF126A45540126745D444474A40CE50DCF126A45540D9B5BDDD924A4A40EFCB99ED0AA55540D9B5BDDD924A4A40EFCB99ED0AA55540126745D444474A40CE50DCF126A45540126745D444474A40
71494	32835	86.730867000000003	86.751644999999996	52.794139000000001	52.786563999999998	Центральная	0103000020E6100000010000000500000071AE6186C6AE5540001B1021AE644A4071AE6186C6AE554034BDC458A6654A40EC4CA1F31AB0554034BDC458A6654A40EC4CA1F31AB05540001B1021AE644A4071AE6186C6AE5540001B1021AE644A40
70862	6339	86.314965000000001	86.330344999999994	52.557194000000003	52.544483999999997	Боровая	0103000020E610000001000000050000009E98F56228945540FE98D6A6B1454A409E98F5622894554083C30B2252474A406AD95A5F2495554083C30B2252474A406AD95A5F24955540FE98D6A6B1454A409E98F56228945540FE98D6A6B1454A40
70576	6430	86.384198999999995	86.421829000000002	52.743980000000001	52.717422999999997	Жданова	0103000020E61000000100000005000000FA0967B796985540F8325184D45B4A40FA0967B796985540657094BC3A5F4A4048E00F3FFF9A5540657094BC3A5F4A4048E00F3FFF9A5540F8325184D45B4A40FA0967B796985540F8325184D45B4A40
70714	6326	86.175061999999997	86.217534000000001	52.681781999999998	52.661861000000002	Октябрьская	0103000020E610000001000000050000006E313F37348B5540BABF7ADCB7544A406E313F37348B55403080F0A144574A4028F1B913EC8D55403080F0A144574A4028F1B913EC8D5540BABF7ADCB7544A406E313F37348B5540BABF7ADCB7544A40
71238	6263	86.530659999999997	86.573239999999998	52.995348	52.986446999999998	Полевая	0103000020E61000000100000005000000E7525C55F6A15540601E32E5437E4A40E7525C55F6A15540CB113290677F4A409430D3F6AFA45540CB113290677F4A409430D3F6AFA45540601E32E5437E4A40E7525C55F6A15540601E32E5437E4A40
71042	6110	86.336471000000003	86.367445000000004	52.807059000000002	52.800503999999997	Нагорная	0103000020E610000001000000050000005B43A9BD88955540992842EA76664A405B43A9BD88955540A37895B54D674A400A85083884975540A37895B54D674A400A85083884975540992842EA76664A405B43A9BD88955540992842EA76664A40
70494	6129	86.213194999999999	86.278602000000006	52.700242000000003	52.676720000000003	50 лет Победы	0103000020E61000000100000005000000ED2AA4FCA48D55404A46CEC29E564A40ED2AA4FCA48D554090A4A487A1594A406AA67B9DD491554090A4A487A1594A406AA67B9DD49155404A46CEC29E564A40ED2AA4FCA48D55404A46CEC29E564A40
71394	6216	86.611868000000001	86.625720000000001	52.925905	52.904820000000001	Центральная	0103000020E61000000100000005000000035E66D828A7554024624A24D1734A40035E66D828A75540F819170E84764A40001DE6CB0BA85540F819170E84764A40001DE6CB0BA8554024624A24D1734A40035E66D828A7554024624A24D1734A40
71048	15514	86.690533000000002	86.694764000000006	52.789597000000001	52.786895999999999	Луговая	0103000020E61000000100000005000000C3F352B131AC554036AD1402B9644A40C3F352B131AC55408602B68311654A400B9C6C0377AC55408602B68311654A400B9C6C0377AC554036AD1402B9644A40C3F352B131AC554036AD1402B9644A40
70858	6040	86.298328999999995	86.331207000000006	52.88767	52.876007999999999	Центральная	0103000020E61000000100000005000000B29C84D2179355406684B70721704A40B29C84D217935540F6D1A92B9F714A40344DD87E32955540F6D1A92B9F714A40344DD87E329555406684B70721704A40B29C84D2179355406684B70721704A40
70860	6489	86.451365999999993	86.468756999999997	52.77646	52.770026000000001	Береговая	0103000020E61000000100000005000000AF21382EE39C5540EC88433690624A40AF21382EE39C55407A53910A63634A4059315C1D009E55407A53910A63634A4059315C1D009E5540EC88433690624A40AF21382EE39C5540EC88433690624A40
71230	5028	84.221279999999993	84.246225999999993	51.824044000000001	51.80424	Советская	0103000020E6100000010000000500000091D09673290E554049111956F1E6494091D09673290E5540863B17467AE94940315BB22AC20F5540863B17467AE94940315BB22AC20F554049111956F1E6494091D09673290E554049111956F1E64940
70817	5206	84.276157999999995	84.303439999999995	51.759090999999998	51.739241	Октябрьская	0103000020E61000000100000005000000D7A19A92AC115540616EF7729FDE4940D7A19A92AC1155400ED8D5E429E1494016139B8F6B1355400ED8D5E429E1494016139B8F6B135540616EF7729FDE4940D7A19A92AC115540616EF7729FDE4940
71234	5738	84.637460000000004	84.659369999999996	51.607875999999997	51.584372000000002	Советская	0103000020E6100000010000000500000086200725CC2855405C59A2B3CCCA494086200725CC285540FB027AE1CECD4940AA7D3A1E332A5540FB027AE1CECD4940AA7D3A1E332A55405C59A2B3CCCA494086200725CC2855405C59A2B3CCCA4940
70571	5944	84.455444	84.513834000000003	51.520198000000001	51.499395999999997	Виталия Табачкова	0103000020E61000000100000005000000344A97FE251D554069E04735ECBF4940344A97FE251D5540E9B81AD995C24940AA6400A8E2205540E9B81AD995C24940AA6400A8E220554069E04735ECBF4940344A97FE251D554069E04735ECBF4940
71310	5448	84.271675000000002	84.302964000000003	51.544167000000002	51.517933999999997	Петра Сухова	0103000020E6100000010000000500000003098A1F6311554044BE4BA94BC2494003098A1F63115540FE47A643A7C5494062F71DC363135540FE47A643A7C5494062F71DC36313554044BE4BA94BC2494003098A1F6311554044BE4BA94BC24940
70808	5134	84.098202000000001	84.127082999999999	51.635196999999998	51.626536999999999	Центральная	0103000020E61000000100000005000000B7990AF148065540F25D4A5D32D04940B7990AF14806554037C2A2224ED149402A38BC202208554037C2A2224ED149402A38BC2022085540F25D4A5D32D04940B7990AF148065540F25D4A5D32D04940
71139	5880	84.609604000000004	84.631990000000002	51.511465999999999	51.491809000000003	Центральная	0103000020E61000000100000005000000B1E07EC0032755407270E998F3BE4940B1E07EC0032755400A82C7B777C149408A592F86722855400A82C7B777C149408A592F86722855407270E998F3BE4940B1E07EC0032755407270E998F3BE4940
70177	5236	84.267021999999997	84.343800999999999	51.673532999999999	51.637253999999999	Советская	0103000020E61000000100000005000000005471E316115540629F008A91D14940005471E3161155406DE34F5436D6494041D5E8D5001655406DE34F5436D6494041D5E8D500165540629F008A91D14940005471E316115540629F008A91D14940
70656	5078	84.040108000000004	84.072573000000006	51.760139000000002	51.730612000000001	Советская	0103000020E61000000100000005000000B6132521910255405708ABB184DD4940B61325219102554003B5183C4CE14940A6643909A504554003B5183C4CE14940A6643909A50455405708ABB184DD4940B6132521910255405708ABB184DD4940
71041	6001	84.404347999999999	84.420265999999998	51.386794999999999	51.377839999999999	Школьная	0103000020E61000000100000005000000FE0C6FD6E0195540718FA50F5DB04940FE0C6FD6E0195540CFA0A17F82B14940BA675DA3E51A5540CFA0A17F82B14940BA675DA3E51A5540718FA50F5DB04940FE0C6FD6E0195540718FA50F5DB04940
71188	5692	84.688242000000002	84.695589999999996	51.704090999999998	51.697761	Коммунарская	0103000020E61000000100000005000000F46E2C280C2C55404EB6813B50D94940F46E2C280C2C5540373465A71FDA49402D5BEB8B842C5540373465A71FDA49402D5BEB8B842C55404EB6813B50D94940F46E2C280C2C55404EB6813B50D94940
71311	5535	84.403970000000001	84.442965999999998	51.894973	51.875695	Центральная	0103000020E610000001000000050000002BA4FCA4DA195540A72215C616F049402BA4FCA4DA195540C9E6AA798EF249405BCF108E591C5540C9E6AA798EF249405BCF108E591C5540A72215C616F049402BA4FCA4DA195540A72215C616F04940
71133	5556	84.54992	84.581765000000004	51.863683000000002	51.818677999999998	Набережная	0103000020E61000000100000005000000A5DAA7E33123554033FAD170CAE84940A5DAA7E3312355403B8E1F2A8DEE4940473D44A33B2555403B8E1F2A8DEE4940473D44A33B25554033FAD170CAE84940A5DAA7E33123554033FAD170CAE84940
71233	5392	84.396046999999996	84.412693000000004	51.571021999999999	51.557574000000002	Школьная	0103000020E61000000100000005000000732B84D558195540CA8CB7955EC74940732B84D558195540F4A5B73F17C949407192E68F691A5540F4A5B73F17C949407192E68F691A5540CA8CB7955EC74940732B84D558195540CA8CB7955EC74940
71146	5848	84.732915000000006	84.75788	51.569074000000001	51.554645000000001	Кокорина	0103000020E61000000100000005000000DDEF5014E82E5540E9F17B9BFEC64940DDEF5014E82E55408080B56AD7C84940B8921D1B813055408080B56AD7C84940B8921D1B81305540E9F17B9BFEC64940DDEF5014E82E5540E9F17B9BFEC64940
71117	5633	84.658212000000006	84.670815000000005	51.796731999999999	51.785601999999997	Советская	0103000020E610000001000000050000006D753925202A55400AD6389B8EE449406D753925202A55409DD66D50FBE54940A4AA09A2EE2A55409DD66D50FBE54940A4AA09A2EE2A55400AD6389B8EE449406D753925202A55400AD6389B8EE44940
70972	4985	84.031125000000003	84.065835000000007	51.847279	51.824261	Восточная	0103000020E61000000100000005000000A245B6F3FD015540232F6B6281E94940A245B6F3FD01554036CB65A373EC4940A9FB00A43604554036CB65A373EC4940A9FB00A436045540232F6B6281E94940A245B6F3FD015540232F6B6281E94940
70351	32610	83.942676000000006	83.967828999999995	51.682262000000001	51.662970000000001	Победы	0103000020E6100000010000000500000058AEB7CD54FC5440541D7233DCD4494058AEB7CD54FC5440DBA6785C54D74940B4C70BE9F0FD5440DBA6785C54D74940B4C70BE9F0FD5440541D7233DCD4494058AEB7CD54FC5440541D7233DCD44940
70348	4513	85.843879999999999	85.860472000000001	52.187682000000002	52.154608000000003	Школьная	0103000020E61000000100000005000000E76F42210276554099D9E731CA134A40E76F4221027655402106BAF605184A40EBC726F9117755402106BAF605184A40EBC726F91177554099D9E731CA134A40E76F42210276554099D9E731CA134A40
71271	4613	85.794597999999993	85.815376000000001	52.270468999999999	52.248578999999999	Центральная	0103000020E61000000100000005000000E3DD91B1DA72554077BCC96FD11F4A40E3DD91B1DA72554079CA6ABA9E224A405F7CD11E2F74554079CA6ABA9E224A405F7CD11E2F74554077BCC96FD11F4A40E3DD91B1DA72554077BCC96FD11F4A40
69962	4544	85.636647999999994	85.657857000000007	52.310718999999999	52.300058	Автозаводская	0103000020E6100000010000000500000015C440D7BE6855409B73F04C68264A4015C440D7BE685540779FE3A3C5274A40761C3F541A6A5540779FE3A3C5274A40761C3F541A6A55409B73F04C68264A4015C440D7BE6855409B73F04C68264A40
71045	4731	85.651425000000003	85.684850999999995	52.397001000000003	52.386135000000003	Сибирская	0103000020E61000000100000005000000FFB27BF2B0695540A56B26DF6C314A40FFB27BF2B06955405ABDC3EDD0324A4081E84999D46B55405ABDC3EDD0324A4081E84999D46B5540A56B26DF6C314A40FFB27BF2B0695540A56B26DF6C314A40
70021	3992	85.395027999999996	85.437392000000003	52.302950000000003	52.267256000000003	Октябрьская	0103000020E61000000100000005000000464085234859554074D4D17135224A4046408523485955405F29CB10C7264A400DE2033BFE5B55405F29CB10C7264A400DE2033BFE5B554074D4D17135224A40464085234859554074D4D17135224A40
70569	4287	85.450255999999996	85.508431000000002	52.214387000000002	52.18215	Советская	0103000020E61000000100000005000000FAB48AFED05C5540B37BF2B050174A40FAB48AFED05C554002D88008711B4A4072512D228A60554002D88008711B4A4072512D228A605540B37BF2B050174A40FAB48AFED05C5540B37BF2B050174A40
71043	4649	85.608350999999999	85.627915999999999	52.304479999999998	52.295271999999997	Садовая	0103000020E610000001000000050000004A5F0839EF66554056B60F79CB254A404A5F0839EF6655409E245D33F9264A40A62897C62F6855409E245D33F9264A40A62897C62F68554056B60F79CB254A404A5F0839EF66554056B60F79CB254A40
70707	4354	85.591866999999993	85.636441000000005	52.194721999999999	52.181150000000002	Центральная	0103000020E6100000010000000500000039252026E1655540D0D556EC2F174A4039252026E1655540E6E786A6EC184A4059350873BB685540E6E786A6EC184A4059350873BB685540D0D556EC2F174A4039252026E1655540D0D556EC2F174A40
71227	4465	85.895703999999995	85.909789000000004	52.091773000000003	52.065885999999999	Молодежная	0103000020E610000001000000050000005EB9DE3653795540D3A1D3F36E084A405EB9DE3653795540F2D3B837BF0B4A40AD50A4FB397A5540F2D3B837BF0B4A40AD50A4FB397A5540D3A1D3F36E084A405EB9DE3653795540D3A1D3F36E084A40
70349	4128	85.252869000000004	85.278705000000002	52.219754999999999	52.200119999999998	пер.Школьный	0103000020E61000000100000005000000064B75012F50554044A33B889D194A40064B75012F505540F5108DEE201C4A40D40E7F4DD6515540F5108DEE201C4A40D40E7F4DD651554044A33B889D194A40064B75012F50554044A33B889D194A40
70950	3474	85.295610999999994	85.309921000000003	52.293939000000002	52.287258000000001	Красноярская	0103000020E610000001000000050000009F55664AEB525540D7C1C1DEC4244A409F55664AEB5255406D020CCB9F254A40FED5E3BED55355406D020CCB9F254A40FED5E3BED5535540D7C1C1DEC4244A409F55664AEB525540D7C1C1DEC4244A40
70575	4881	85.315832	85.363093000000006	52.368625999999999	52.345927000000003	Центральная	0103000020E61000000100000005000000F0C16B9736545540D6E6FF55472C4A40F0C16B9736545540473A03232F2F4A40051A6CEA3C575540473A03232F2F4A40051A6CEA3C575540D6E6FF55472C4A40F0C16B9736545540D6E6FF55472C4A40
71402	4368	85.611925999999997	85.634887000000006	52.094555999999997	52.075701000000002	Советская	0103000020E610000001000000050000009D64ABCB2967554023A30392B0094A409D64ABCB29675540FED137691A0C4A40F56915FDA1685540FED137691A0C4A40F56915FDA168554023A30392B0094A409D64ABCB2967554023A30392B0094A40
71033	4173	85.245763999999994	85.268158999999997	52.174616999999998	52.152071999999997	Молодежная	0103000020E610000001000000050000002FA2ED98BA4F55409351651877134A402FA2ED98BA4F5540AE2990D959164A4032C85D8429515540AE2990D959164A4032C85D84295155409351651877134A402FA2ED98BA4F55409351651877134A40
70623	4789	85.519220000000004	85.560929000000002	52.399918999999997	52.365622999999999	Советская	0103000020E6100000010000000500000077DB85E63A6155402CD505BCCC2E4A4077DB85E63A6155404606B98B30334A403198BF42E66355404606B98B30334A403198BF42E66355402CD505BCCC2E4A4077DB85E63A6155402CD505BCCC2E4A40
71254	4818	85.576909999999998	85.607613999999998	52.389505	52.380291999999997	Ветеранов	0103000020E6100000010000000500000010AFEB17EC64554018778368AD304A4010AFEB17EC6455407250C24CDB314A40DFA5D425E36655407250C24CDB314A40DFA5D425E366554018778368AD304A4010AFEB17EC64554018778368AD304A40
70766	4218	85.330583000000004	85.339619999999996	52.207064000000003	52.185462999999999	Центральная	0103000020E6100000010000000500000045679945285555401CCF6740BD174A404567994528555540E816BA12811A4A4052448655BC555540E816BA12811A4A4052448655BC5555401CCF6740BD174A4045679945285555401CCF6740BD174A40
71112	3390	84.791242999999994	84.801636999999999	52.145119999999999	52.139907999999998	Советская	0103000020E61000000100000005000000170CAEB9A332554071395E81E8114A40170CAEB9A33255406DFFCA4A93124A40DE9046054E3355406DFFCA4A93124A40DE9046054E33554071395E81E8114A40170CAEB9A332554071395E81E8114A40
71054	3903	84.745931999999996	84.758221000000006	51.978650999999999	51.952165000000001	Нагорная	0103000020E610000001000000050000008D429259BD2F5540ABB2EF8AE0F949408D429259BD2F55404E999B6F44FD4940FD885FB1863055404E999B6F44FD4940FD885FB186305540ABB2EF8AE0F949408D429259BD2F5540ABB2EF8AE0F94940
71389	2762	85.047963999999993	85.067285999999996	52.421897999999999	52.415768	Комсомольская	0103000020E61000000100000005000000A9D898D711435540965CC5E237354A40A9D898D711435540B81FF0C000364A40A25EF0694E445540B81FF0C000364A40A25EF0694E445540965CC5E237354A40A9D898D711435540965CC5E237354A40
69848	3869	85.015579000000002	85.058132999999998	52.171816999999997	52.141129999999997	Школьная	0103000020E6100000010000000500000048E00F3FFF405540033E3F8C10124A4048E00F3FFF405540CBF27519FE154A4060747973B8435540CBF27519FE154A4060747973B8435540033E3F8C10124A4048E00F3FFF405540033E3F8C10124A40
70020	3784	84.738861999999997	84.806145999999998	52.066850000000002	52.035252999999997	Центральная	0103000020E610000001000000050000007590D783492F5540FE0A992B83044A407590D783492F55406ADE718A8E084A40477364E5973355406ADE718A8E084A40477364E597335540FE0A992B83044A407590D783492F5540FE0A992B83044A40
71303	2985	84.891800000000003	84.903037999999995	52.192540999999999	52.187572000000003	Озерная	0103000020E61000000100000005000000A9A44E40133955409AD2FA5B02184A40A9A44E4013395540CF11F92EA5184A40E542E55FCB395540CF11F92EA5184A40E542E55FCB3955409AD2FA5B02184A40A9A44E40133955409AD2FA5B02184A40
71399	2666	84.812299999999993	84.835216000000003	52.360002999999999	52.341816999999999	Каньшакова	0103000020E610000001000000050000009CA223B9FC335540C11BD2A8C02B4A409CA223B9FC3355401FBB0B94142E4A402446CF2D743555401FBB0B94142E4A402446CF2D74355540C11BD2A8C02B4A409CA223B9FC335540C11BD2A8C02B4A40
69852	3780	84.591241999999994	84.663888999999998	52.015559000000003	51.984214000000001	Советская	0103000020E610000001000000050000006281AFE8D6255540F7216FB9FAFD49406281AFE8D625554049145AD6FD014A4025CB49287D2A554049145AD6FD014A4025CB49287D2A5540F7216FB9FAFD49406281AFE8D6255540F7216FB9FAFD4940
69906	3577	85.047972999999999	85.124634999999998	52.317425	52.282184000000001	Энергетическая	0103000020E61000000100000005000000D38558FD114355402CBAF59A1E244A40D38558FD1143554066F7E461A1284A40F73B1405FA47554066F7E461A1284A40F73B1405FA4755402CBAF59A1E244A40D38558FD114355402CBAF59A1E244A40
69673	3577	85.047972999999999	85.124634999999998	52.317425	52.282184000000001	Советская	0103000020E61000000100000005000000D38558FD114355402CBAF59A1E244A40D38558FD1143554066F7E461A1284A40F73B1405FA47554066F7E461A1284A40F73B1405FA4755402CBAF59A1E244A40D38558FD114355402CBAF59A1E244A40
71391	3577	85.047972999999999	85.124634999999998	52.317425	52.282184000000001	Песчаная	0103000020E61000000100000005000000D38558FD114355402CBAF59A1E244A40D38558FD1143554066F7E461A1284A40F73B1405FA47554066F7E461A1284A40F73B1405FA4755402CBAF59A1E244A40D38558FD114355402CBAF59A1E244A40
69778	3577	85.047972999999999	85.124634999999998	52.317425	52.282184000000001	Красноярская	0103000020E61000000100000005000000D38558FD114355402CBAF59A1E244A40D38558FD1143554066F7E461A1284A40F73B1405FA47554066F7E461A1284A40F73B1405FA4755402CBAF59A1E244A40D38558FD114355402CBAF59A1E244A40
71236	3135	84.860701000000006	84.889545999999996	52.399864000000001	52.383453000000003	Онухова	0103000020E610000001000000050000009CA8A5B915375540CC46E7FC14314A409CA8A5B915375540836C59BE2E334A4068925852EE385540836C59BE2E334A4068925852EE385540CC46E7FC14314A409CA8A5B915375540CC46E7FC14314A40
71390	3470	85.199922999999998	85.226934999999997	52.290298	52.276860999999997	Совхозная	0103000020E61000000100000005000000F7ADD689CB4C5540D844662E70234A40F7ADD689CB4C55400F0C207C28254A4056D4601A864E55400F0C207C28254A4056D4601A864E5540D844662E70234A40F7ADD689CB4C5540D844662E70234A40
70107	1978	84.884838999999999	84.940956	52.100968000000002	52.074444999999997	Советская	0103000020E610000001000000050000006CCEC133A1385540E42CEC6987094A406CCEC133A1385540A5F8F884EC0C4A4066BE839F383C5540A5F8F884EC0C4A4066BE839F383C5540E42CEC6987094A406CCEC133A1385540E42CEC6987094A40
71119	3037	84.961393000000001	84.986618000000007	52.371853000000002	52.358539999999998	им.Волкова	0103000020E610000001000000050000009D668176873D5540672783A3E42D4A409D668176873D5540B2F50CE1982F4A4047E9D2BF243F5540B2F50CE1982F4A4047E9D2BF243F5540672783A3E42D4A409D668176873D5540672783A3E42D4A40
70529	3037	84.961393000000001	84.986618000000007	52.371853000000002	52.358539999999998	Скорикова	0103000020E610000001000000050000009D668176873D5540672783A3E42D4A409D668176873D5540B2F50CE1982F4A4047E9D2BF243F5540B2F50CE1982F4A4047E9D2BF243F5540672783A3E42D4A409D668176873D5540672783A3E42D4A40
71458	59451	84.656576999999999	84.665604999999999	51.985407000000002	51.972548000000003	Центральная	0103000020E610000001000000050000009293895B052A554026E5EE737CFC49409293895B052A5540EF1F0BD121FE494076C3B645992A5540EF1F0BD121FE494076C3B645992A554026E5EE737CFC49409293895B052A554026E5EE737CFC4940
69668	1868	85.014878999999993	85.035889999999995	52.299700000000001	52.286189	Нагорная	0103000020E610000001000000050000006B990CC7F3405540CBBC55D7A1244A406B990CC7F34055403C4ED1915C264A40381092054C4255403C4ED1915C264A40381092054C425540CBBC55D7A1244A406B990CC7F3405540CBBC55D7A1244A40
70704	2821	85.095124999999996	85.132199	52.416871999999998	52.402698999999998	Мальцева	0103000020E610000001000000050000000C022B8716465540E2900DA48B334A400C022B87164655401E4FCB0F5C354A401764CBF2754855401E4FCB0F5C354A401764CBF275485540E2900DA48B334A400C022B8716465540E2900DA48B334A40
69901	2676	84.996840000000006	85.032189000000002	52.423408000000002	52.413533000000001	Центральная	0103000020E610000001000000050000000FD6FF39CC3F55408C683BA6EE344A400FD6FF39CC3F5540B16EBC3B32364A409F9273620F425540B16EBC3B32364A409F9273620F4255408C683BA6EE344A400FD6FF39CC3F55408C683BA6EE344A40
70095	8225	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	Шукшина	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
70390	8225	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	Соболева	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
70077	8225	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	Объездная	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
70076	8225	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	Бийская	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
69600	8225	84.904646	85.022998999999999	52.013041999999999	51.965673000000002	Академика Мясникова	0103000020E61000000100000005000000431D56B8E5395540ABD0402C9BFB4940431D56B8E5395540BABC395CAB014A40CE35CCD078415540BABC395CAB014A40CE35CCD078415540ABD0402C9BFB4940431D56B8E5395540ABD0402C9BFB4940
70703	2579	84.845528000000002	84.875675999999999	52.313851999999997	52.287576999999999	Центральная	0103000020E610000001000000050000008CF678211D365540780AB952CF244A408CF678211D36554060E4654D2C284A40187959130B38554060E4654D2C284A40187959130B385540780AB952CF244A408CF678211D365540780AB952CF244A40
71040	2930	85.038864000000004	85.054125999999997	52.233144000000003	52.218916999999998	Зеленая	0103000020E61000000100000005000000793F6EBF7C425540EBC4E578051C4A40793F6EBF7C4255401BA19FA9D71D4A4040F7E5CC764355401BA19FA9D71D4A4040F7E5CC76435540EBC4E578051C4A40793F6EBF7C425540EBC4E578051C4A40
70508	59397	78.190996999999996	79.633197999999993	53.377397999999999	52.802497000000002	Кулундинская	0103000020E6100000010000000500000095287B4B398C5340AE11C138B8664A4095287B4B398C5340B4C9E1934EB04A402079E75086E85340B4C9E1934EB04A402079E75086E85340AE11C138B8664A4095287B4B398C5340AE11C138B8664A40
71430	59397	78.190996999999996	79.633197999999993	53.377397999999999	52.802497000000002	Гагарина	0103000020E6100000010000000500000095287B4B398C5340AE11C138B8664A4095287B4B398C5340B4C9E1934EB04A402079E75086E85340B4C9E1934EB04A402079E75086E85340AE11C138B8664A4095287B4B398C5340AE11C138B8664A40
70029	59375	78.581136000000001	78.613906	52.986593999999997	52.972242000000001	Молодежная	0103000020E61000000100000005000000CFA10C5531A5534019E6046D727C4A40CFA10C5531A55340043752B6487E4A405D34643C4AA75340043752B6487E4A405D34643C4AA7534019E6046D727C4A40CFA10C5531A5534019E6046D727C4A40
71314	59435	78.396710999999996	78.415091000000004	52.866441000000002	52.858373	Первомайская	0103000020E61000000100000005000000A9BD88B6639953407C629D2ADF6D4A40A9BD88B663995340EF74E789E76E4A404B77D7D9909A5340EF74E789E76E4A404B77D7D9909A53407C629D2ADF6D4A40A9BD88B6639953407C629D2ADF6D4A40
70346	32590	78.395041000000006	78.408047999999994	52.973066000000003	52.959463	Школьная	0103000020E6100000010000000500000011E50B5A489953406C5CFFAECF7A4A4011E50B5A48995340BE6C3B6D8D7C4A40AFCC5B751D9A5340BE6C3B6D8D7C4A40AFCC5B751D9A53406C5CFFAECF7A4A4011E50B5A489953406C5CFFAECF7A4A40
70880	59416	78.756478000000001	78.785061999999996	53.092861999999997	53.087750999999997	Центральная	0103000020E610000001000000050000002F89B3226AB053407C98BD6C3B8B4A402F89B3226AB053404485EAE6E28B4A4045D5AF743EB253404485EAE6E28B4A4045D5AF743EB253407C98BD6C3B8B4A402F89B3226AB053407C98BD6C3B8B4A40
69588	22318	78.740784000000005	78.765353000000005	53.156391999999997	53.143610000000002	Ленина	0103000020E610000001000000050000009B594B0169AF534075B0FECF61924A409B594B0169AF534092AD2EA704944A405039268BFBB0534092AD2EA704944A405039268BFBB0534075B0FECF61924A409B594B0169AF534075B0FECF61924A40
71055	59424	78.637235000000004	78.651634999999999	53.091839999999998	53.083711000000001	Красных Партизан	0103000020E6100000010000000500000076374F75C8A8534061A8C30AB78A4A4076374F75C8A85340793BC269C18B4A40747B4963B4A95340793BC269C18B4A40747B4963B4A9534061A8C30AB78A4A4076374F75C8A8534061A8C30AB78A4A40
71277	1974	81.311834000000005	81.331669000000005	51.814368999999999	51.795022000000003	Центральная	0103000020E61000000100000005000000FAF19716F5535440DECCE847C3E54940FAF19716F553544028F04E3E3DE8494036069D103A55544028F04E3E3DE8494036069D103A555440DECCE847C3E54940FAF19716F5535440DECCE847C3E54940
70622	1875	81.635784999999998	81.652277999999995	51.387963999999997	51.375805	Новая	0103000020E61000000100000005000000649291B3B06854402E56D4601AB04940649291B3B06854403E03EACDA8B149409E7939ECBE6954403E03EACDA8B149409E7939ECBE6954402E56D4601AB04940649291B3B06854402E56D4601AB04940
70573	1824	81.250623000000004	81.280608999999998	51.381449000000003	51.364514	Ленина	0103000020E6100000010000000500000007280D350A50544092770E65A8AE494007280D350A505440C40B2252D3B04940A67D737FF5515440C40B2252D3B04940A67D737FF551544092770E65A8AE494007280D350A50544092770E65A8AE4940
70865	1295	81.501486999999997	81.513255000000001	51.389212000000001	51.373353000000002	Молодежная	0103000020E61000000100000005000000A017EE5C18605440876EF607CAAF4940A017EE5C18605440FA9AE5B2D1B149408BE07F2BD9605440FA9AE5B2D1B149408BE07F2BD9605440876EF607CAAF4940A017EE5C18605440876EF607CAAF4940
70493	1777	80.680642000000006	80.718936999999997	51.457757000000001	51.424886999999998	Октябрьская	0103000020E610000001000000050000002E9276A38F2B54406EBF7CB262B649402E9276A38F2B5440EE4108C897BA494099B85510032E5440EE4108C897BA494099B85510032E54406EBF7CB262B649402E9276A38F2B54406EBF7CB262B64940
70903	1728	81.110979999999998	81.122425000000007	51.534565000000001	51.524317000000003	Новая	0103000020E61000000100000005000000A5A0DB4B1A47544051DEC7D11CC34940A5A0DB4B1A4754400A4B3CA06CC449409FCDAACFD54754400A4B3CA06CC449409FCDAACFD547544051DEC7D11CC34940A5A0DB4B1A47544051DEC7D11CC34940
70884	25670	81.195188000000002	81.206964999999997	51.576866000000003	51.569907999999998	Школьная	0103000020E610000001000000050000009624CFF57D4C544048DDCEBEF2C849409624CFF57D4C54405116BEBED6C94940AA9A20EA3E4D54405116BEBED6C94940AA9A20EA3E4D544048DDCEBEF2C849409624CFF57D4C544048DDCEBEF2C84940
70279	1486	81.226979999999998	81.241065000000006	51.433889000000001	51.407632	Советская	0103000020E6100000010000000500000026361FD7864E5440CB660E492DB4494026361FD7864E54400D8CBCAC89B7494075CDE49B6D4F54400D8CBCAC89B7494075CDE49B6D4F5440CB660E492DB4494026361FD7864E5440CB660E492DB44940
70705	1436	81.393778999999995	81.413720999999995	51.550524000000003	51.535634999999999	Мира	0103000020E6100000010000000500000080B6D5AC33595440E6CB0BB08FC4494080B6D5AC33595440E1D4079277C64940C72AA5677A5A5440E1D4079277C64940C72AA5677A5A5440E6CB0BB08FC4494080B6D5AC33595440E6CB0BB08FC44940
70174	1284	81.464404000000002	81.490005999999994	51.373100000000001	51.337502000000001	Вовченко	0103000020E610000001000000050000006C088ECBB85D5440D42AFA4333AB49406C088ECBB85D54409D11A5BDC1AF4940003620425C5F54409D11A5BDC1AF4940003620425C5F5440D42AFA4333AB49406C088ECBB85D5440D42AFA4333AB4940
69746	1182	81.153057000000004	81.183105999999995	51.388311999999999	51.359599000000003	Центральная	0103000020E61000000100000005000000215B96AFCB49544050560C5707AE4940215B96AFCB4954407A522635B4B14940E36C3A02B84B54407A522635B4B14940E36C3A02B84B544050560C5707AE4940215B96AFCB49544050560C5707AE4940
71223	1630	81.148511999999997	81.161734999999993	51.468183000000003	51.461337999999998	Центральная	0103000020E6100000010000000500000011C47938814954407633A31F0DBB494011C479388149544087C5A86BEDBB494096E7C1DD594A544087C5A86BEDBB494096E7C1DD594A54407633A31F0DBB494011C47938814954407633A31F0DBB4940
69730	1169	81.391569000000004	81.413505999999998	51.760033	51.744304999999997	Советская	0103000020E6100000010000000500000028486C770F595440E89FE06245DF494028486C770F595440BD70E7C248E14940C9ACDEE1765A5440BD70E7C248E14940C9ACDEE1765A5440E89FE06245DF494028486C770F595440E89FE06245DF4940
69734	1169	81.391569000000004	81.413505999999998	51.760033	51.744304999999997	Партизанская	0103000020E6100000010000000500000028486C770F595440E89FE06245DF494028486C770F595440BD70E7C248E14940C9ACDEE1765A5440BD70E7C248E14940C9ACDEE1765A5440E89FE06245DF494028486C770F595440E89FE06245DF4940
71038	1169	81.391569000000004	81.413505999999998	51.760033	51.744304999999997	Комсомольская	0103000020E6100000010000000500000028486C770F595440E89FE06245DF494028486C770F595440BD70E7C248E14940C9ACDEE1765A5440BD70E7C248E14940C9ACDEE1765A5440E89FE06245DF494028486C770F595440E89FE06245DF4940
69722	1169	81.391569000000004	81.413505999999998	51.760033	51.744304999999997	Захарова	0103000020E6100000010000000500000028486C770F595440E89FE06245DF494028486C770F595440BD70E7C248E14940C9ACDEE1765A5440BD70E7C248E14940C9ACDEE1765A5440E89FE06245DF494028486C770F595440E89FE06245DF4940
70359	1052	81.121526000000003	81.146122000000005	51.587394000000003	51.574958000000002	Центральная	0103000020E6100000010000000500000047E7FC14C74754406B49473998C9494047E7FC14C7475440EEEE01BA2FCB494079CE16105A495440EEEE01BA2FCB494079CE16105A4954406B49473998C9494047E7FC14C74754406B49473998C94940
71228	1645	81.133787999999996	81.142825000000002	51.426465	51.420417	Топольная	0103000020E6100000010000000500000039268BFB8F4854405AD76839D0B5494039268BFB8F485440BFF1B56796B649404703780B24495440BFF1B56796B649404703780B244954405AD76839D0B5494039268BFB8F4854405AD76839D0B54940
71032	720	81.440050999999997	81.470082000000005	51.658507	51.652248999999998	Баталова	0103000020E610000001000000050000009D64ABCB295C5440A2EC2DE57CD349409D64ABCB295C5440F29716F549D449400D1CD0D2155E5440F29716F549D449400D1CD0D2155E5440A2EC2DE57CD349409D64ABCB295C5440A2EC2DE57CD34940
70347	1537	81.176942999999994	81.194136999999998	51.463526000000002	51.450248000000002	Топольная	0103000020E610000001000000050000006490BB08534B5440728BF9B9A1B949406490BB08534B5440406CE9D154BB4940637C98BD6C4C5440406CE9D154BB4940637C98BD6C4C5440728BF9B9A1B949406490BB08534B5440728BF9B9A1B94940
70852	471	81.317960999999997	81.349913999999998	51.665014999999997	51.644877999999999	Ленина	0103000020E61000000100000005000000D21918795954544077F4BF5C8BD24940D219187959545440BA2C26361FD54940679AB0FD64565440BA2C26361FD54940679AB0FD6456544077F4BF5C8BD24940D21918795954544077F4BF5C8BD24940
70699	1046	81.681445999999994	81.694785999999993	51.485736000000003	51.472968999999999	Центральный	0103000020E610000001000000050000005CFFAECF9C6B5440CB82893F8ABC49405CFFAECF9C6B5440B43EE5982CBE4940FEEDB25F776C5440B43EE5982CBE4940FEEDB25F776C5440CB82893F8ABC49405CFFAECF9C6B5440CB82893F8ABC4940
70565	961	81.531121999999996	81.542207000000005	51.367224999999998	51.350645	Молодежная	0103000020E61000000100000005000000E90B21E7FD615440C2C073EFE1AC4940E90B21E7FD61544005A3923A01AF4940632AFD84B362544005A3923A01AF4940632AFD84B3625440C2C073EFE1AC4940E90B21E7FD615440C2C073EFE1AC4940
69907	841	81.076286999999994	81.134669000000002	51.312387999999999	51.252153999999997	Центральный	0103000020E610000001000000050000000987DEE2E14454401DC70F9546A049400987DEE2E1445440D8D47954FCA749403EB2B96A9E485440D8D47954FCA749403EB2B96A9E4854401DC70F9546A049400987DEE2E14454401DC70F9546A04940
70175	841	81.076286999999994	81.134669000000002	51.312387999999999	51.252153999999997	Куйбышева	0103000020E610000001000000050000000987DEE2E14454401DC70F9546A049400987DEE2E1445440D8D47954FCA749403EB2B96A9E485440D8D47954FCA749403EB2B96A9E4854401DC70F9546A049400987DEE2E14454401DC70F9546A04940
70701	788	80.636077	80.662926999999996	51.429003999999999	51.410350999999999	Советская	0103000020E61000000100000005000000382F4E7CB5285440C170AE6186B44940382F4E7CB528544035ED629AE9B64940AA285E656D2A544035ED629AE9B64940AA285E656D2A5440C170AE6186B44940382F4E7CB5285440C170AE6186B44940
70489	683	81.383887999999999	81.412229999999994	51.678888999999998	51.660584999999998	Новая	0103000020E61000000100000005000000EB54F99E91585440349D9D0C8ED44940EB54F99E915854409C4EB2D5E5D64940861BF0F9615A54409C4EB2D5E5D64940861BF0F9615A5440349D9D0C8ED44940EB54F99E91585440349D9D0C8ED44940
70566	570	81.288899999999998	81.305367000000004	51.567137000000002	51.555984000000002	Молодежная	0103000020E610000001000000050000001FF46C567D525440B58CD47B2AC749401FF46C567D52544000ADF9F197C84940C59107228B53544000ADF9F197C84940C59107228B535440B58CD47B2AC749401FF46C567D525440B58CD47B2AC74940
70181	565	81.265435999999994	81.294011999999995	51.600955999999996	51.570143999999999	Советская	0103000020E6100000010000000500000096CB46E7FC5054405C01857AFAC8494096CB46E7FC505440E02A4F20ECCC49406B28B517D1525440E02A4F20ECCC49406B28B517D15254405C01857AFAC8494096CB46E7FC5054405C01857AFAC84940
70563	411	80.976421000000002	80.994792000000004	52.661320000000003	52.645783000000002	Центральная	0103000020E610000001000000050000002B8881AE7D3E544009A87004A9524A402B8881AE7D3E54406A183E22A6544A40A39410ACAA3F54406A183E22A6544A40A39410ACAA3F544009A87004A9524A402B8881AE7D3E544009A87004A9524A40
70018	334	80.730714000000006	80.774489000000003	52.565581000000002	52.530434	Советская	0103000020E61000000100000005000000AE2EA704C42E5440DE57E542E5434A40AE2EA704C42E5440971E4DF564484A4027874F3A91315440971E4DF564484A4027874F3A91315440DE57E542E5434A40AE2EA704C42E5440DE57E542E5434A40
69899	180	81.190211000000005	81.272640999999993	52.635739999999998	52.606774999999999	Советская	0103000020E61000000100000005000000BA15C26A2C4C5440E4839ECDAA4D4A40BA15C26A2C4C54402861A6ED5F514A401EA33CF3725154402861A6ED5F514A401EA33CF372515440E4839ECDAA4D4A40BA15C26A2C4C5440E4839ECDAA4D4A40
69753	180	81.190211000000005	81.272640999999993	52.635739999999998	52.606774999999999	Мамонтовская	0103000020E61000000100000005000000BA15C26A2C4C5440E4839ECDAA4D4A40BA15C26A2C4C54402861A6ED5F514A401EA33CF3725154402861A6ED5F514A401EA33CF372515440E4839ECDAA4D4A40BA15C26A2C4C5440E4839ECDAA4D4A40
70925	51	81.428768000000005	81.453767999999997	52.742322999999999	52.729204000000003	Школьная	0103000020E61000000100000005000000916456EF705B5440630E828E565D4A40916456EF705B5440C808A870045F4A402AFEEF880A5D5440C808A870045F4A402AFEEF880A5D5440630E828E565D4A40916456EF705B5440630E828E565D4A40
71387	32442	81.199635000000001	81.223376999999999	52.462119000000001	52.444732999999999	Захарова	0103000020E61000000100000005000000C408E1D1C64C5440DA39CD02ED384A40C408E1D1C64C54401CEE23B7263B4A406E6B0BCF4B4E54401CEE23B7263B4A406E6B0BCF4B4E5440DA39CD02ED384A40C408E1D1C64C5440DA39CD02ED384A40
71224	32339	81.344560000000001	81.359751000000003	52.774459999999998	52.760914999999997	пер.Школьный	0103000020E61000000100000005000000A0E062450D5654409604A8A965614A40A0E062450D565440B3075A8121634A4003ED0E2906575440B3075A8121634A4003ED0E29065754409604A8A965614A40A0E062450D5654409604A8A965614A40
71035	32371	81.418859999999995	81.450210999999996	52.668022000000001	52.654896000000001	Школьная	0103000020E6100000010000000500000090662C9ACE5A5440FF23D3A1D3534A4090662C9ACE5A54401781B1BE81554A402A53CC41D05C54401781B1BE81554A402A53CC41D05C5440FF23D3A1D3534A4090662C9ACE5A5440FF23D3A1D3534A40
70401	32313	80.977877000000007	81.016226000000003	52.599556	52.572159999999997	Советская	0103000020E61000000100000005000000AEA06989953E5440280AF4893C494A40AEA06989953E54406F0F4240BE4C4A4013D6C6D8094154406F0F4240BE4C4A4013D6C6D809415440280AF4893C494A40AEA06989953E5440280AF4893C494A40
70863	32265	80.863539000000003	80.893848000000006	52.690516000000002	52.663941999999999	Советская	0103000020E6100000010000000500000084F41439443754406D382C0DFC544A4084F4143944375440B0AE0AD462584A4015E63DCE34395440B0AE0AD462584A4015E63DCE343954406D382C0DFC544A4084F41439443754406D382C0DFC544A40
70344	32199	81.335639999999998	81.397120000000001	52.569504999999999	52.532865999999999	30 лет Победы	0103000020E61000000100000005000000AFCE31207B5554403E93FDF334444A40AFCE31207B55544049F4328AE5484A409A25016A6A59544049F4328AE5484A409A25016A6A5954403E93FDF334444A40AFCE31207B5554403E93FDF334444A40
71385	32181	80.949319000000003	80.985414000000006	52.415520999999998	52.404677	Титова	0103000020E610000001000000050000002C9E7AA4C13C5440C138B874CC334A402C9E7AA4C13C54408EE6C8CA2F354A4051C1E105113F54408EE6C8CA2F354A4051C1E105113F5440C138B874CC334A402C9E7AA4C13C5440C138B874CC334A40
70379	32127	81.060046	81.106847999999999	52.789923999999999	52.756385999999999	Советская	0103000020E610000001000000050000005C902DCBD74354407D93A641D1604A405C902DCBD7435440AA29C93A1C654A402769FE98D6465440AA29C93A1C654A402769FE98D64654407D93A641D1604A405C902DCBD74354407D93A641D1604A40
70854	32457	81.143013999999994	81.166837000000001	52.442701999999997	52.429789	Молодежная	0103000020E61000000100000005000000B0373124274954401C97715303374A40B037312427495440D8EF8975AA384A40D1B01875AD4A5440D8EF8975AA384A40D1B01875AD4A54401C97715303374A40B0373124274954401C97715303374A40
70378	32072	80.071422999999996	80.115331999999995	52.280127999999998	52.258001	Ленина	0103000020E61000000100000005000000A94BC63192045440EBAA402D06214A40A94BC63192045440D158FB3BDB234A40AA0B789961075440D158FB3BDB234A40AA0B789961075440EBAA402D06214A40A94BC63192045440EBAA402D06214A40
70341	32050	79.947176999999996	79.975320999999994	52.408627000000003	52.393571999999999	Садовая	0103000020E610000001000000050000007FA1478C9EFC5340874F3A9160324A407FA1478C9EFC53409DA1B8E34D344A408786C5A86BFE53409DA1B8E34D344A408786C5A86BFE5340874F3A9160324A407FA1478C9EFC5340874F3A9160324A40
70558	31941	80.396118999999999	80.415406000000004	52.306953	52.294699000000001	Школьная	0103000020E61000000100000005000000C09481035A195440FB9463B2B8254A40C09481035A1954405D34643C4A274A40FB230C03961A54405D34643C4A274A40FB230C03961A5440FB9463B2B8254A40C09481035A195440FB9463B2B8254A40
71221	31790	79.833072999999999	79.862825000000001	52.595978000000002	52.587995999999997	Комсомольская	0103000020E610000001000000050000008F8B6A1151F55340E316F373434B4A408F8B6A1151F553405891D101494C4A40F54A598638F753405891D101494C4A40F54A598638F75340E316F373434B4A408F8B6A1151F55340E316F373434B4A40
70340	31865	80.325269000000006	80.373760000000004	52.608705999999998	52.585287999999998	Гагарина	0103000020E61000000100000005000000C5591135D1145440E15E99B7EA4A4A40C5591135D114544082700514EA4D4A40642310AFEB17544082700514EA4D4A40642310AFEB175440E15E99B7EA4A4A40C5591135D1145440E15E99B7EA4A4A40
70017	31929	80.459100000000007	80.497853000000006	52.642018999999998	52.626370999999999	Садовая	0103000020E61000000100000005000000FE65F7E4611D5440D714C8EC2C504A40FE65F7E4611D54408F34B8AD2D524A40CB4DD4D2DC1F54408F34B8AD2D524A40CB4DD4D2DC1F5440D714C8EC2C504A40FE65F7E4611D5440D714C8EC2C504A40
69889	22233	80.165970000000002	80.243109000000004	52.514806999999998	52.472988000000001	Шевченко	0103000020E610000001000000050000007F87A2409F0A544042B3EBDE8A3C4A407F87A2409F0A54403D601E32E5414A4040170D198F0F54403D601E32E5414A4040170D198F0F544042B3EBDE8A3C4A407F87A2409F0A544042B3EBDE8A3C4A40
69900	22233	80.165970000000002	80.243109000000004	52.514806999999998	52.472988000000001	Мелиораторов	0103000020E610000001000000050000007F87A2409F0A544042B3EBDE8A3C4A407F87A2409F0A54403D601E32E5414A4040170D198F0F54403D601E32E5414A4040170D198F0F544042B3EBDE8A3C4A407F87A2409F0A544042B3EBDE8A3C4A40
69944	22233	80.165970000000002	80.243109000000004	52.514806999999998	52.472988000000001	Ленина	0103000020E610000001000000050000007F87A2409F0A544042B3EBDE8A3C4A407F87A2409F0A54403D601E32E5414A4040170D198F0F54403D601E32E5414A4040170D198F0F544042B3EBDE8A3C4A407F87A2409F0A544042B3EBDE8A3C4A40
71018	31721	79.715536999999998	79.743752999999998	52.567551000000002	52.547314999999998	Ленина	0103000020E61000000100000005000000FD84B35BCBED53401CCEFC6A0E464A40FD84B35BCBED5340F3E7DB82A5484A4052D32EA699EF5340F3E7DB82A5484A4052D32EA699EF53401CCEFC6A0E464A40FD84B35BCBED53401CCEFC6A0E464A40
70634	567	79.934680999999998	79.965592000000001	52.498838999999997	52.487391000000002	Детсадовская	0103000020E6100000010000000500000053CC41D0D1FB5340B0AE0AD4623E4A4053CC41D0D1FB5340137CD3F4D93F4A40DF516342CCFD5340137CD3F4D93F4A40DF516342CCFD5340B0AE0AD4623E4A4053CC41D0D1FB5340B0AE0AD4623E4A40
70697	31591	80.370759000000007	80.397125000000003	52.772106999999998	52.760326999999997	Аврамкова	0103000020E61000000100000005000000A7ECF483BA17544005A2276552614A40A7ECF483BA1754409F01F566D4624A4023DBF97E6A1954409F01F566D4624A4023DBF97E6A19544005A2276552614A40A7ECF483BA17544005A2276552614A40
70816	27453	80.135795999999999	80.160921999999999	52.660834000000001	52.645296999999999	Первомайская	0103000020E610000001000000050000005EBBB4E1B00854407C9A931799524A405EBBB4E1B0085440DD0A613596544A403ECDC98B4C0A5440DD0A613596544A403ECDC98B4C0A54407C9A931799524A405EBBB4E1B00854407C9A931799524A40
69745	31514	80.148928999999995	80.179902999999996	52.567945000000002	52.549199000000002	Ленина	0103000020E61000000100000005000000431B800D880954407AFF1F274C464A40431B800D880954409F76F86BB2484A40F25CDF87830B54409F76F86BB2484A40F25CDF87830B54407AFF1F274C464A40431B800D880954407AFF1F274C464A40
71480	59462	80.291905	80.307041999999996	52.294671999999998	52.280149999999999	Новая	0103000020E610000001000000050000007D224F92AE125440B9FC87F4DB234A407D224F92AE1254400186E5CFB7254A40E61F7D93A61354400186E5CFB7254A40E61F7D93A6135440B9FC87F4DB234A407D224F92AE125440B9FC87F4DB234A40
70491	31435	80.635339999999999	80.673725000000005	52.406818999999999	52.372529	Партизанская	0103000020E61000000100000005000000CD751A69A9285440E2E7BF07AF2F4A40CD751A69A92854401A321EA512344A40D95F764F1E2B54401A321EA512344A40D95F764F1E2B5440E2E7BF07AF2F4A40CD751A69A9285440E2E7BF07AF2F4A40
70846	31337	80.440782999999996	80.470095000000001	52.507139000000002	52.479877000000002	Ленина	0103000020E610000001000000050000007F68E6C9351C5440228D0A9C6C3D4A407F68E6C9351C544059C345EEE9404A40D7C05609161E544059C345EEE9404A40D7C05609161E5440228D0A9C6C3D4A407F68E6C9351C5440228D0A9C6C3D4A40
71030	31272	80.126902999999999	80.155693999999997	52.381436000000001	52.360447999999998	Школьная	0103000020E61000000100000005000000EAB0C22D1F0854404DF4F928232E4A40EAB0C22D1F0854402FC214E5D2304A40BD8BF7E3F60954402FC214E5D2304A40BD8BF7E3F60954404DF4F928232E4A40EAB0C22D1F0854404DF4F928232E4A40
71308	28349	80.584010000000006	80.592751000000007	52.494990999999999	52.481737000000003	пер. Восточный	0103000020E610000001000000050000005EA27A6B60255440F722DA8EA93D4A405EA27A6B602554403C6876DD5B3F4A40F7EAE3A1EF2554403C6876DD5B3F4A40F7EAE3A1EF255440F722DA8EA93D4A405EA27A6B60255440F722DA8EA93D4A40
71039	31660	79.620495000000005	80.850199000000003	52.857199000000001	52.208995000000002	Советская	0103000020E610000001000000050000003815A930B6E7534086032159C01A4A403815A930B6E75340FB9463B2B86D4A40E20511A969365440FB9463B2B86D4A40E20511A96936544086032159C01A4A403815A930B6E7534086032159C01A4A40
71383	31237	80.432571999999993	80.465478000000004	52.353788000000002	52.321966000000003	Сухова	0103000020E61000000100000005000000944A7842AF1B54404436902E36294A40944A7842AF1B5440CFDBD8EC482D4A407BC03C64CA1D5440CFDBD8EC482D4A407BC03C64CA1D54404436902E36294A40944A7842AF1B54404436902E36294A40
70031	59377	82.238338999999996	82.370140000000006	53.049757	52.970261999999998	Касмалинская	0103000020E61000000100000005000000209738F2408F54409946938B317C4A40209738F2408F5440A0DFF76F5E864A4041BCAE5FB0975440A0DFF76F5E864A4041BCAE5FB09754409946938B317C4A40209738F2408F54409946938B317C4A40
70643	328	82.222762000000003	82.235123000000002	53.230988000000004	53.216082	Комсомольская	0103000020E61000000100000005000000A9328CBB418E54408CA03193A89B4A40A9328CBB418E54405DE2C803919D4A4065E256410C8F54405DE2C803919D4A4065E256410C8F54408CA03193A89B4A40A9328CBB418E54408CA03193A89B4A40
70292	276	81.936514000000003	81.961083000000002	53.132416999999997	53.109428000000001	Ленина	0103000020E61000000100000005000000C18F6AD8EF7B544023A298BC018E4A40C18F6AD8EF7B54409B374E0AF3904A40766F4562827D54409B374E0AF3904A40766F4562827D544023A298BC018E4A40C18F6AD8EF7B544023A298BC018E4A40
69976	27345	81.996898999999999	82.061209000000005	53.273738000000002	53.235990000000001	Центральная	0103000020E61000000100000005000000919A7631CD7F54406E179AEB349E4A40919A7631CD7F544013D6C6D809A34A40234E27D9EA83544013D6C6D809A34A40234E27D9EA8354406E179AEB349E4A40919A7631CD7F54406E179AEB349E4A40
70410	27397	82.412943999999996	82.489984000000007	52.868772999999997	52.857846000000002	Ленина	0103000020E6100000010000000500000015C5ABAC6D9A54409180D1E5CD6D4A4015C5ABAC6D9A5440EB5223F4336F4A400DE4D9E55B9F5440EB5223F4336F4A400DE4D9E55B9F54409180D1E5CD6D4A4015C5ABAC6D9A54409180D1E5CD6D4A40
70345	29957	82.300923999999995	82.386678000000003	53.092433999999997	53.055056	проспект Победы	0103000020E6100000010000000500000037A5BC56429354406BB933130C874A4037A5BC5642935440EC8497E0D48B4A404B051555BF985440EC8497E0D48B4A404B051555BF9854406BB933130C874A4037A5BC56429354406BB933130C874A40
69760	29957	82.300923999999995	82.386678000000003	53.092433999999997	53.055056	пр-т Победы	0103000020E6100000010000000500000037A5BC56429354406BB933130C874A4037A5BC5642935440EC8497E0D48B4A404B051555BF985440EC8497E0D48B4A404B051555BF9854406BB933130C874A4037A5BC56429354406BB933130C874A40
70186	29957	82.300923999999995	82.386678000000003	53.092433999999997	53.055056	Партизанская	0103000020E6100000010000000500000037A5BC56429354406BB933130C874A4037A5BC5642935440EC8497E0D48B4A404B051555BF985440EC8497E0D48B4A404B051555BF9854406BB933130C874A4037A5BC56429354406BB933130C874A40
70332	29957	82.300923999999995	82.386678000000003	53.092433999999997	53.055056	Максима Горького	0103000020E6100000010000000500000037A5BC56429354406BB933130C874A4037A5BC5642935440EC8497E0D48B4A404B051555BF985440EC8497E0D48B4A404B051555BF9854406BB933130C874A4037A5BC56429354406BB933130C874A40
70014	29957	82.300923999999995	82.386678000000003	53.092433999999997	53.055056	Ленина	0103000020E6100000010000000500000037A5BC56429354406BB933130C874A4037A5BC5642935440EC8497E0D48B4A404B051555BF985440EC8497E0D48B4A404B051555BF9854406BB933130C874A4037A5BC56429354406BB933130C874A40
70490	30368	82.054075999999995	82.123220000000003	52.979871000000003	52.947158999999999	50 лет ВЛКСМ	0103000020E61000000100000005000000E7DF2EFB75835440588E90813C794A40E7DF2EFB7583544040A6B5696C7D4A40A48D23D6E287544040A6B5696C7D4A40A48D23D6E2875440588E90813C794A40E7DF2EFB75835440588E90813C794A40
70839	31119	82.478018000000006	82.504554999999996	53.004707000000003	52.989597000000003	Школьная	0103000020E610000001000000050000008F39CFD8979E5440209C4F1DAB7E4A408F39CFD8979E5440F9872D3D9A804A4021020EA14AA05440F9872D3D9A804A4021020EA14AA05440209C4F1DAB7E4A408F39CFD8979E5440209C4F1DAB7E4A40
71131	31202	82.388339000000002	82.403493999999995	52.943116000000003	52.933456	переулок Степной	0103000020E61000000100000005000000BA30D28BDA985440A320787C7B774A40BA30D28BDA985440CC2A6C06B8784A4076887FD8D2995440CC2A6C06B8784A4076887FD8D2995440A320787C7B774A40BA30D28BDA985440A320787C7B774A40
70648	27305	82.122653999999997	82.170874999999995	52.997635000000002	52.976422999999997	Кузбасс	0103000020E610000001000000050000004FAE2990D9875440F607CA6DFB7C4A404FAE2990D9875440282CF180B27F4A400E2DB29DEF8A5440282CF180B27F4A400E2DB29DEF8A5440F607CA6DFB7C4A404FAE2990D9875440F607CA6DFB7C4A40
70836	30834	82.613016999999999	82.626636000000005	53.122512	53.108108999999999	Почтовая	0103000020E6100000010000000500000017B9A7AB3BA754409EB30584D68D4A4017B9A7AB3BA754400CAF2479AE8F4A40C39FE1CD1AA854400CAF2479AE8F4A40C39FE1CD1AA854409EB30584D68D4A4017B9A7AB3BA754409EB30584D68D4A40
71220	30501	82.126687000000004	82.145740000000004	53.001553000000001	52.995260999999999	Ленина	0103000020E610000001000000050000000475CAA31B885440FCFD62B6647F4A400475CAA31B885440F81A82E332804A40056EDDCD53895440F81A82E332804A40056EDDCD53895440FCFD62B6647F4A400475CAA31B885440FCFD62B6647F4A40
71091	59426	81.837196000000006	82.797297999999998	53.336897999999998	52.695799000000001	Партизанская	0103000020E61000000100000005000000E415889E9475544075CB0EF10F594A40E415889E947554403D0B42791FAB4A40A3CA30EE06B354403D0B42791FAB4A40A3CA30EE06B3544075CB0EF10F594A40E415889E9475544075CB0EF10F594A40
71248	30960	82.416268000000002	82.427307999999996	53.030287000000001	53.020847000000003	Центральная	0103000020E61000000100000005000000C4978922A49A5440209C4F1DAB824A40C4978922A49A54403A3FC571E0834A406D54A703599B54403A3FC571E0834A406D54A703599B5440209C4F1DAB824A40C4978922A49A5440209C4F1DAB824A40
70334	30820	82.552102000000005	82.596622999999994	53.187947000000001	53.164524	Павловская	0103000020E610000001000000050000009983A0A355A354401CB4571F0F954A409983A0A355A35440CF30B5A50E984A40A6423C122FA65440CF30B5A50E984A40A6423C122FA654401CB4571F0F954A409983A0A355A354401CB4571F0F954A40
70298	476	82.687370999999999	82.723823999999993	52.968716999999998	52.939946999999997	Центральная	0103000020E61000000100000005000000014EEFE2FDAB5440957CEC2E50784A40014EEFE2FDAB5440240A2DEBFE7B4A40D503E62153AE5440240A2DEBFE7B4A40D503E62153AE5440957CEC2E50784A40014EEFE2FDAB5440957CEC2E50784A40
70841	59413	82.494943000000006	82.533407999999994	53.083868000000002	53.055515999999997	Зеленорощинская	0103000020E6100000010000000500000096986725AD9F5440CE33F6251B874A4096986725AD9F54402997C62FBC8A4A402FDB4E5B23A254402997C62FBC8A4A402FDB4E5B23A25440CE33F6251B874A4096986725AD9F5440CE33F6251B874A40
70625	30349	82.018404000000004	82.069446999999997	52.869979999999998	52.842483000000001	Комсомольская	0103000020E610000001000000050000006687F8872D815440CE37A27BD66B4A406687F8872D815440481630815B6F4A408A73D4D171845440481630815B6F4A408A73D4D171845440CE37A27BD66B4A406687F8872D815440CE37A27BD66B4A40
70415	27263	82.189659000000006	82.243639000000002	52.766494999999999	52.747354999999999	Советская	0103000020E610000001000000050000001899805F238C544044C02154A95F4A401899805F238C544015C616821C624A40EE4108C8978F544015C616821C624A40EE4108C8978F544044C02154A95F4A401899805F238C544044C02154A95F4A40
70526	401	82.441824999999994	82.473247999999998	53.199675999999997	53.174213000000002	Школьная	0103000020E6100000010000000500000088635DDC469C5440DFC4909C4C964A4088635DDC469C5440E6E5B0FB8E994A406FB9FAB1499E5440E6E5B0FB8E994A406FB9FAB1499E5440DFC4909C4C964A4088635DDC469C5440DFC4909C4C964A40
69853	213	82.234575000000007	82.286866000000003	52.966996999999999	52.92812	Быкова	0103000020E61000000100000005000000645DDC46038F5440BB61DBA2CC764A40645DDC46038F5440412AC58EC67B4A40661536035C925440412AC58EC67B4A40661536035C925440BB61DBA2CC764A40645DDC46038F5440BB61DBA2CC764A40
70557	29701	81.713768000000002	81.732883999999999	52.014594000000002	51.998528	Садовая	0103000020E610000001000000050000009B3BFA5FAE6D5440F511F8C3CFFF49409B3BFA5FAE6D5440E25B5837DE014A40BFF04A92E76E5440E25B5837DE014A40BFF04A92E76E5440F511F8C3CFFF49409B3BFA5FAE6D5440F511F8C3CFFF4940
71384	29864	81.880826999999996	81.901677000000007	52.000269000000003	51.989283999999998	Молодежная	0103000020E61000000100000005000000C39B35785F785440603AADDBA0FE4940C39B35785F785440F01989D008004A408CA37213B5795440F01989D008004A408CA37213B5795440603AADDBA0FE4940C39B35785F785440603AADDBA0FE4940
70338	29343	81.838336999999996	81.864056000000005	51.881199000000002	51.867849	Школьная	0103000020E61000000100000005000000B6813B50A7755440E36E10AD15EF4940B6813B50A77554404B22FB20CBF04940687A89B14C7754404B22FB20CBF04940687A89B14C775440E36E10AD15EF4940B6813B50A7755440E36E10AD15EF4940
69761	29002	81.802736999999993	83.157684000000003	52.007581999999999	51.773482000000001	Целинная	0103000020E610000001000000050000008192020B60735440B8054B7501E349408192020B60735440E6046D72F8004A408FC6A17E17CA5440E6046D72F8004A408FC6A17E17CA5440B8054B7501E349408192020B60735440B8054B7501E34940
69749	29002	81.802736999999993	83.157684000000003	52.007581999999999	51.773482000000001	Кондратюка	0103000020E610000001000000050000008192020B60735440B8054B7501E349408192020B60735440E6046D72F8004A408FC6A17E17CA5440E6046D72F8004A408FC6A17E17CA5440B8054B7501E349408192020B60735440B8054B7501E34940
69975	29002	81.802736999999993	83.157684000000003	52.007581999999999	51.773482000000001	Коммунистическая	0103000020E610000001000000050000008192020B60735440B8054B7501E349408192020B60735440E6046D72F8004A408FC6A17E17CA5440E6046D72F8004A408FC6A17E17CA5440B8054B7501E349408192020B60735440B8054B7501E34940
69978	29002	81.802736999999993	83.157684000000003	52.007581999999999	51.773482000000001	Гончарова	0103000020E610000001000000050000008192020B60735440B8054B7501E349408192020B60735440E6046D72F8004A408FC6A17E17CA5440E6046D72F8004A408FC6A17E17CA5440B8054B7501E349408192020B60735440B8054B7501E34940
70948	29579	81.658719000000005	81.677287000000007	51.814881	51.801366000000002	Школьная	0103000020E610000001000000050000003F90BC73286A54402C103D2993E649403F90BC73286A5440DE9046054EE8494062C092AB586B5440DE9046054EE8494062C092AB586B54402C103D2993E649403F90BC73286A54402C103D2993E64940
70523	29605	81.525605999999996	81.559455	51.855791000000004	51.839149999999997	Центральная	0103000020E6100000010000000500000035255987A36154401D38674469EB494035255987A3615440079B3A8F8AED49405B25581CCE635440079B3A8F8AED49405B25581CCE6354401D38674469EB494035255987A36154401D38674469EB4940
70353	1388	81.368329000000003	81.391506000000007	51.847830000000002	51.834564	Центральный	0103000020E61000000100000005000000C74ACCB392575440A0353FFED2EA4940C74ACCB392575440AA4885B185EC4940058C2E6F0E595440AA4885B185EC4940058C2E6F0E595440A0353FFED2EA4940C74ACCB392575440A0353FFED2EA4940
69988	29227	82.044185999999996	82.080585999999997	51.892589000000001	51.862599000000003	Ленинская	0103000020E610000001000000050000003A3C84F1D3825440FA47DFA469EE49403A3C84F1D38254407AE2395B40F24940FDA02E52288554407AE2395B40F24940FDA02E5228855440FA47DFA469EE49403A3C84F1D3825440FA47DFA469EE4940
69949	59371	81.306794999999994	82.396091999999996	52.229796	51.529898000000003	Лермонтова	0103000020E61000000100000005000000E2E47E87A2535440A01B9AB2D3C34940E2E47E87A2535440356090F4691D4A40438D429259995440356090F4691D4A40438D429259995440A01B9AB2D3C34940E2E47E87A2535440A01B9AB2D3C34940
70522	26688	81.578965999999994	81.613219000000001	51.758996000000003	51.740206000000001	Советская	0103000020E61000000100000005000000BDDF68C70D655440C826F911BFDE4940BDDF68C70D655440BDE5EAC726E149404B92E7FA3E675440BDE5EAC726E149404B92E7FA3E675440C826F911BFDE4940BDDF68C70D655440C826F911BFDE4940
71034	29770	81.835955999999996	81.866804999999999	52.116992000000003	52.105344000000002	Центральная	0103000020E610000001000000050000004739984D80755440386A85E97B0D4A404739984D8075544063F20698F90E4A4098C0ADBB7977544063F20698F90E4A4098C0ADBB79775440386A85E97B0D4A404739984D80755440386A85E97B0D4A40
70009	29799	81.657128999999998	81.739648000000003	52.166034000000003	52.141561000000003	Парковый переулок	0103000020E610000001000000050000003410CB660E6A5440CDB1BCAB1E124A403410CB660E6A54401503249A40154A4051A39064566F54401503249A40154A4051A39064566F5440CDB1BCAB1E124A403410CB660E6A5440CDB1BCAB1E124A40
70088	29308	82.256826000000004	82.303628000000003	51.907331999999997	51.875788999999997	Трактовая	0103000020E61000000100000005000000CDB051D66F90544028999CDA19F04940CDB051D66F905440A04E797423F44940988922A46E935440A04E797423F44940988922A46E93544028999CDA19F04940CDB051D66F90544028999CDA19F04940
71126	174	81.894615999999999	81.925113999999994	51.965152000000003	51.954779000000002	Дорожная	0103000020E610000001000000050000009D9E7763417954402CF4C13236FA49409D9E776341795440A2D5C9198AFB494097C45911357B5440A2D5C9198AFB494097C45911357B54402CF4C13236FA49409D9E7763417954402CF4C13236FA4940
70842	29379	81.731752	81.741624000000002	51.849843999999997	51.839160999999997	Алейская	0103000020E6100000010000000500000016325706D56E5440118AADA069EB494016325706D56E5440D5592DB0C7EC4940707B82C4766F5440D5592DB0C7EC4940707B82C4766F5440118AADA069EB494016325706D56E5440118AADA069EB4940
70487	29420	81.809877999999998	81.839710999999994	51.726216000000001	51.704470999999998	Школьная	0103000020E61000000100000005000000FEEF880AD57354407EFD101B2CDA4940FEEF880AD57354407DEA58A5F4DC4940DAC534D3BD7554407DEA58A5F4DC4940DAC534D3BD7554407EFD101B2CDA4940FEEF880AD57354407EFD101B2CDA4940
70698	28952	84.09742	84.161219000000003	51.979222	51.959330000000001	Ленина	0103000020E610000001000000050000007C7E18213C0655402D095053CBFA49407C7E18213C06554009C3802557FD49409B1F7F69510A554009C3802557FD49409B1F7F69510A55402D095053CBFA49407C7E18213C0655402D095053CBFA4940
69974	28864	84.072689999999994	84.135679999999994	52.089089000000001	52.060039000000003	Партизанская	0103000020E61000000100000005000000C22FF5F3A604554006BEA25BAF074A40C22FF5F3A604554078B7B244670B4A4029AE2AFBAE08554078B7B244670B4A4029AE2AFBAE08554006BEA25BAF074A40C22FF5F3A604554006BEA25BAF074A40
69743	28864	84.072689999999994	84.135679999999994	52.089089000000001	52.060039000000003	Ленина	0103000020E61000000100000005000000C22FF5F3A604554006BEA25BAF074A40C22FF5F3A604554078B7B244670B4A4029AE2AFBAE08554078B7B244670B4A4029AE2AFBAE08554006BEA25BAF074A40C22FF5F3A604554006BEA25BAF074A40
70337	28823	84.231161	84.296279999999996	52.224736999999998	52.203806999999998	Комсомольская	0103000020E6100000010000000500000015C78157CB0E554012D90759161A4A4015C78157CB0E5540BF99982EC41C4A405E9D6340F6125540BF99982EC41C4A405E9D6340F612554012D90759161A4A4015C78157CB0E554012D90759161A4A40
70331	28750	83.997203999999996	84.090153000000001	52.241852000000002	52.217498999999997	Советская	0103000020E610000001000000050000002FDCB930D2FF5440D3F4D901D71B4A402FDCB930D2FF5440713C9F01F51E4A40B9A81611C5055540713C9F01F51E4A40B9A81611C5055540D3F4D901D71B4A402FDCB930D2FF5440D3F4D901D71B4A40
70486	28730	84.105811000000003	84.145705000000007	52.200899	52.179394000000002	Советская	0103000020E61000000100000005000000A723809BC5065540A08CF161F6164A40A723809BC50655404966F50EB7194A404777103B530955404966F50EB7194A404777103B53095540A08CF161F6164A40A723809BC5065540A08CF161F6164A40
69957	28682	84.363788999999997	84.427065999999996	52.025101999999997	51.992539000000001	Советская	0103000020E610000001000000050000004069A85148175540958098840BFF49404069A851481755403788D68A36034A40F2CEA10C551B55403788D68A36034A40F2CEA10C551B5540958098840BFF49404069A85148175540958098840BFF4940
70180	28626	84.120892999999995	84.152953999999994	52.131185000000002	52.109011000000002	Фрунзе	0103000020E610000001000000050000002E54FEB5BC075540BFF38B12F40D4A402E54FEB5BC075540E65C8AABCA104A40B6F292FFC9095540E65C8AABCA104A40B6F292FFC9095540BFF38B12F40D4A402E54FEB5BC075540BFF38B12F40D4A40
69954	28557	83.962070999999995	83.999279000000001	52.027695999999999	51.977097000000001	Советская	0103000020E61000000100000005000000855B3E9292FD54408602B68311FD4940855B3E9292FD5440711DE38A8B034A401825E82FF4FF5440711DE38A8B034A401825E82FF4FF54408602B68311FD4940855B3E9292FD54408602B68311FD4940
69898	28541	84.085409999999996	84.147681000000006	52.072589999999998	52.046138999999997	Колхозная	0103000020E610000001000000050000001630815B77055540FA08FCE1E7054A401630815B7705554021020EA14A094A40664F029B7309554021020EA14A094A40664F029B73095540FA08FCE1E7054A401630815B77055540FA08FCE1E7054A40
70483	28193	83.932677999999996	83.971575000000001	53.319920000000003	53.313313999999998	Центральная	0103000020E61000000100000005000000B7EC10FFB0FB544081B053AC1AA84A40B7EC10FFB0FB54400DAB7823F3A84A401EA7E8482EFE54400DAB7823F3A84A401EA7E8482EFE544081B053AC1AA84A40B7EC10FFB0FB544081B053AC1AA84A40
70831	27044	84.115538999999998	84.136568999999994	53.766314000000001	53.760300000000001	Парковая	0103000020E61000000100000005000000679AB0FD640755400C93A98251E14A40679AB0FD64075540C53BC09316E24A406F29E78BBD085540C53BC09316E24A406F29E78BBD0855400C93A98251E14A40679AB0FD640755400C93A98251E14A40
71393	26477	83.891436999999996	83.916822999999994	53.906675999999997	53.896282999999997	Центральная	0103000020E61000000100000005000000705CC64D0DF95440FA7ABE66B9F24A40705CC64D0DF95440B7088CF50DF44A401E4E603AADFA5440B7088CF50DF44A401E4E603AADFA5440FA7ABE66B9F24A40705CC64D0DF95440FA7ABE66B9F24A40
71026	28354	84.025599999999997	84.035355999999993	53.125067999999999	53.117108000000002	Лесная	0103000020E61000000100000005000000C4B12E6EA3015540CC0C1B65FD8E4A40C4B12E6EA301554058E36C3A02904A40E9EDCF454302554058E36C3A02904A40E9EDCF4543025540CC0C1B65FD8E4A40C4B12E6EA3015540CC0C1B65FD8E4A40
70169	27492	84.133694000000006	84.173507999999998	53.585836	53.567695999999998	Центральная	0103000020E61000000100000005000000F96A47718E085540F6083543AAC84A40F96A47718E085540E4688EACFCCA4A400A664CC11A0B5540E4688EACFCCA4A400A664CC11A0B5540F6083543AAC84A40F96A47718E085540F6083543AAC84A40
71380	28116	83.991804999999999	84.002899999999997	53.393622999999998	53.388010999999999	Первая	0103000020E6100000010000000500000098C0ADBB79FF54407FBE2D58AAB14A4098C0ADBB79FF544009FA0B3D62B24A40234A7B832F00554009FA0B3D62B24A40234A7B832F0055407FBE2D58AAB14A4098C0ADBB79FF54407FBE2D58AAB14A40
69738	25361	83.744956999999999	83.776488000000001	53.584169000000003	53.572615999999996	Советская	0103000020E6100000010000000500000048FB1F60ADEF54404A95287B4BC94A4048FB1F60ADEF5440242BBF0CC6CA4A40226FB9FAB1F15440242BBF0CC6CA4A40226FB9FAB1F154404A95287B4BC94A4048FB1F60ADEF54404A95287B4BC94A40
70229	25361	83.744956999999999	83.776488000000001	53.584169000000003	53.572615999999996	Кедровая	0103000020E6100000010000000500000048FB1F60ADEF54404A95287B4BC94A4048FB1F60ADEF5440242BBF0CC6CA4A40226FB9FAB1F15440242BBF0CC6CA4A40226FB9FAB1F154404A95287B4BC94A4048FB1F60ADEF54404A95287B4BC94A40
70043	25361	83.744956999999999	83.776488000000001	53.584169000000003	53.572615999999996	40 лет РВСН	0103000020E6100000010000000500000048FB1F60ADEF54404A95287B4BC94A4048FB1F60ADEF5440242BBF0CC6CA4A40226FB9FAB1F15440242BBF0CC6CA4A40226FB9FAB1F154404A95287B4BC94A4048FB1F60ADEF54404A95287B4BC94A40
70165	26621	83.980863999999997	84.006798000000003	53.837088000000001	53.821469999999998	Ленина	0103000020E61000000100000005000000B874CC79C6FE54409352D0ED25E94A40B874CC79C6FE5440E1EF17B325EB4A4068EBE0606F005540E1EF17B325EB4A4068EBE0606F0055409352D0ED25E94A40B874CC79C6FE54409352D0ED25E94A40
69744	28163	83.950348000000005	83.984915000000001	53.356852000000003	53.336537999999997	Новый переулок	0103000020E610000001000000050000006BF46A80D2FC54403DEE5BAD13AB4A406BF46A80D2FC544090C18A53ADAD4A40C095ECD808FF544090C18A53ADAD4A40C095ECD808FF54403DEE5BAD13AB4A406BF46A80D2FC54403DEE5BAD13AB4A40
71354	59437	83.705476000000004	84.439858000000001	53.942847	52.909480000000002	Школьная	0103000020E610000001000000050000003A07CF8426ED5440DC2E34D769744A403A07CF8426ED5440DC10E335AFF84A4093382BA2261C5540DC10E335AFF84A4093382BA2261C5540DC2E34D769744A403A07CF8426ED5440DC2E34D769744A40
70833	28440	83.825158999999999	83.856654000000006	53.105525	53.075899999999997	Гуляева-Сусанина	0103000020E6100000010000000500000001C0B167CFF4544019E25817B7894A4001C0B167CFF4544088F4DBD7818D4A40357F4C6BD3F6544088F4DBD7818D4A40357F4C6BD3F6544019E25817B7894A4001C0B167CFF4544019E25817B7894A40
71020	26533	84.074127000000004	84.103133999999997	53.942847	53.930576000000002	Молодежная	0103000020E610000001000000050000000A302C7FBE045540A438471D1DF74A400A302C7FBE045540DC10E335AFF84A40C34659BF99065540DC10E335AFF84A40C34659BF99065540A438471D1DF74A400A302C7FBE045540A438471D1DF74A40
71225	28083	84.119977000000006	84.141976999999997	53.439321	53.431859000000003	Школьная	0103000020E610000001000000050000006CD102B4AD075540DCBDDC2747B74A406CD102B4AD07554017B9A7AB3BB84A4030F2B2261609554017B9A7AB3BB84A4030F2B22616095540DCBDDC2747B74A406CD102B4AD075540DCBDDC2747B74A40
69736	27177	83.750078000000002	83.795218000000006	53.528410999999998	53.492747999999999	Школьная	0103000020E61000000100000005000000BEDC274701F05440AF95D05D12BF4A40BEDC274701F054405FECBDF8A2C34A4032CC09DAE4F254405FECBDF8A2C34A4032CC09DAE4F25440AF95D05D12BF4A40BEDC274701F05440AF95D05D12BF4A40
70168	26763	83.993063000000006	84.043953000000002	53.735492000000001	53.708655999999998	Центральная	0103000020E6100000010000000500000088F71C588EFF54409D0E643DB5DA4A4088F71C588EFF54401D3C139A24DE4A40E9633E20D00255401D3C139A24DE4A40E9633E20D00255409D0E643DB5DA4A4088F71C588EFF54409D0E643DB5DA4A40
69952	26763	83.993063000000006	84.043953000000002	53.735492000000001	53.708655999999998	Молодежная	0103000020E6100000010000000500000088F71C588EFF54409D0E643DB5DA4A4088F71C588EFF54401D3C139A24DE4A40E9633E20D00255401D3C139A24DE4A40E9633E20D00255409D0E643DB5DA4A4088F71C588EFF54409D0E643DB5DA4A40
71222	27766	83.839730000000003	83.868223999999998	53.578304000000003	53.564942000000002	Приозерная	0103000020E6100000010000000500000016DEE522BEF554408411FB0450C84A4016DEE522BEF55440B0928FDD05CA4A408C6665FB90F75440B0928FDD05CA4A408C6665FB90F754408411FB0450C84A4016DEE522BEF554408411FB0450C84A40
71029	27906	83.705476000000004	84.439858000000001	53.942847	52.909480000000002	Центральная	0103000020E610000001000000050000003A07CF8426ED5440DC2E34D769744A403A07CF8426ED5440DC10E335AFF84A4093382BA2261C5540DC10E335AFF84A4093382BA2261C5540DC2E34D769744A403A07CF8426ED5440DC2E34D769744A40
71027	26916	84.075546000000003	84.112403999999998	53.747107	53.721145999999997	Школьная	0103000020E61000000100000005000000FED5E3BED504554013D21A834EDC4A40FED5E3BED50455406CCEC133A1DF4A4022FC8BA0310755406CCEC133A1DF4A4022FC8BA03107554013D21A834EDC4A40FED5E3BED504554013D21A834EDC4A40
70830	26683	83.923479	83.958001999999993	53.779038	53.764026000000001	Школьная	0103000020E61000000100000005000000BDE2A9471AFB544098A59D9ACBE14A40BDE2A9471AFB5440AE2B6684B7E34A402AE09EE74FFD5440AE2B6684B7E34A402AE09EE74FFD544098A59D9ACBE14A40BDE2A9471AFB544098A59D9ACBE14A40
70895	27869	84.313222999999994	84.347026	53.511198999999998	53.497225999999998	Лесная	0103000020E61000000100000005000000B8567BD80B145540465C001AA5BF4A40B8567BD80B145540BB5F05F86EC14A4026378AAC35165540BB5F05F86EC14A4026378AAC35165540465C001AA5BF4A40B8567BD80B145540465C001AA5BF4A40
70856	27085	83.989883000000006	84.021692000000002	53.415295	53.394486999999998	Интернациональная	0103000020E6100000010000000500000073F7393E5AFF54403CD9CD8C7EB24A4073F7393E5AFF54409E98F56228B54A406EA5D766630155409E98F56228B54A406EA5D766630155403CD9CD8C7EB24A4073F7393E5AFF54403CD9CD8C7EB24A40
69857	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	переулок Профсоюзный	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69670	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Прудская	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69856	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Парковая	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69667	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	П. Корчагина	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
70074	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Крылова	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
70072	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Коммунистическая	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69985	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Деповская	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69678	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Геологов	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
69981	21432	83.879902000000001	84.049539999999993	53.476754	53.370474000000002	Белоярская	0103000020E61000000100000005000000D76B7A5050F85440580229B16BAF4A40D76B7A5050F854405C1E6B4606BD4A4001F6D1A92B0355405C1E6B4606BD4A4001F6D1A92B035540580229B16BAF4A40D76B7A5050F85440580229B16BAF4A40
71218	28486	83.837412	83.855395999999999	52.918809000000003	52.909480000000002	Школьная	0103000020E61000000100000005000000CA51802898F55440DC2E34D769744A40CA51802898F554409F2287889B754A404548DDCEBEF654409F2287889B754A404548DDCEBEF65440DC2E34D769744A40CA51802898F55440DC2E34D769744A40
71444	59444	83.705476000000004	84.439858000000001	53.942847	52.909480000000002	Центральная	0103000020E610000001000000050000003A07CF8426ED5440DC2E34D769744A403A07CF8426ED5440DC10E335AFF84A4093382BA2261C5540DC10E335AFF84A4093382BA2261C5540DC2E34D769744A403A07CF8426ED5440DC2E34D769744A40
69951	27550	84.185310999999999	84.216060999999996	53.505394000000003	53.492127000000004	Титова	0103000020E61000000100000005000000B325AB22DC0B5540433D7D04FEBE4A40B325AB22DC0B55401DCC26C0B0C04A403A3C84F1D30D55401DCC26C0B0C04A403A3C84F1D30D5540433D7D04FEBE4A40B325AB22DC0B5540433D7D04FEBE4A40
71028	28404	83.959222999999994	83.987600999999998	53.251142999999999	53.234000999999999	Центральная	0103000020E610000001000000050000008BA4DDE863FD54409B1DA9BEF39D4A408BA4DDE863FD544046CF2D7425A04A40CD1FD3DA34FF544046CF2D7425A04A40CD1FD3DA34FF54409B1DA9BEF39D4A408BA4DDE863FD54409B1DA9BEF39D4A40
71024	26727	84.131296000000006	84.149405999999999	53.839739000000002	53.831445000000002	Зеленая	0103000020E610000001000000050000001F865627670855401CB62DCA6CEA4A401F865627670855407F164B917CEB4A40E0F42EDE8F0955407F164B917CEB4A40E0F42EDE8F0955401CB62DCA6CEA4A401F865627670855401CB62DCA6CEA4A40
70555	27294	83.827189000000004	83.858765000000005	53.539495000000002	53.527849000000003	Ленина	0103000020E610000001000000050000001AA721AAF0F45440F81C588E90C34A401AA721AAF0F4544082AD122C0EC54A40C47C7901F6F6544082AD122C0EC54A40C47C7901F6F65440F81C588E90C34A401AA721AAF0F45440F81C588E90C34A40
71409	27457	83.705476000000004	84.439858000000001	53.942847	52.909480000000002	Калинина	0103000020E610000001000000050000003A07CF8426ED5440DC2E34D769744A403A07CF8426ED5440DC10E335AFF84A4093382BA2261C5540DC10E335AFF84A4093382BA2261C5540DC2E34D769744A403A07CF8426ED5440DC2E34D769744A40
69839	27347	83.867729999999995	83.914935999999997	53.505538999999999	53.471020000000003	Пионерская	0103000020E6100000010000000500000084F068E388F7544087E123624ABC4A4084F068E388F7544020ED7F80B5C04A40B77BB94F8EFA544020ED7F80B5C04A40B77BB94F8EFA544087E123624ABC4A4084F068E388F7544087E123624ABC4A40
70700	26993	84.211236999999997	84.258937000000003	53.789678000000002	53.772190000000002	Молодежная	0103000020E6100000010000000500000021AD31E8840D55402D26361FD7E24A4021AD31E8840D5540732F302B14E54A405CAE7E6C92105540732F302B14E54A405CAE7E6C921055402D26361FD7E24A4021AD31E8840D55402D26361FD7E24A40
70333	27822	84.280551000000003	84.324757000000005	53.411150999999997	53.395325	Ленина	0103000020E610000001000000050000000C772E8CF4115540462575029AB24A400C772E8CF4115540DD5B9198A0B44A406A8995D1C8145540DD5B9198A0B44A406A8995D1C8145540462575029AB24A400C772E8CF4115540462575029AB24A40
71210	26856	83.912367000000003	83.930234999999996	53.686419999999998	53.673592999999997	Плотникова	0103000020E61000000100000005000000C7BC8E3864FA544042E8A04B38D64A40C7BC8E3864FA544000A94D9CDCD74A400DA661F888FB544000A94D9CDCD74A400DA661F888FB544042E8A04B38D64A40C7BC8E3864FA544042E8A04B38D64A40
71449	59446	83.978662999999997	84.001022000000006	53.634107999999998	53.627695000000003	Рабочая	0103000020E6100000010000000500000089B3226AA2FE54406E6E4C4F58D04A4089B3226AA2FE5440E41071732AD14A40E62494BE10005540E41071732AD14A40E62494BE100055406E6E4C4F58D04A4089B3226AA2FE54406E6E4C4F58D04A40
69896	27213	83.810875999999993	83.862258999999995	53.520043999999999	53.492083999999998	Рабочая	0103000020E610000001000000050000001F477364E5F354404371C79BFCBE4A401F477364E5F35440923D42CD90C24A40A06B5F402FF75440923D42CD90C24A40A06B5F402FF754404371C79BFCBE4A401F477364E5F354404371C79BFCBE4A40
69737	27213	83.810875999999993	83.862258999999995	53.520043999999999	53.492083999999998	Вокзальная	0103000020E610000001000000050000001F477364E5F354404371C79BFCBE4A401F477364E5F35440923D42CD90C24A40A06B5F402FF75440923D42CD90C24A40A06B5F402FF754404371C79BFCBE4A401F477364E5F354404371C79BFCBE4A40
69740	28260	83.857129999999998	83.906330999999994	53.196331000000001	53.161850999999999	Майская	0103000020E61000000100000005000000E99AC937DBF6544096E99788B7944A40E99AC937DBF654407218CC5F21994A407616BD5301FA54407218CC5F21994A407616BD5301FA544096E99788B7944A40E99AC937DBF6544096E99788B7944A40
69741	28260	83.857129999999998	83.906330999999994	53.196331000000001	53.161850999999999	Ленина	0103000020E61000000100000005000000E99AC937DBF6544096E99788B7944A40E99AC937DBF654407218CC5F21994A407616BD5301FA54407218CC5F21994A407616BD5301FA544096E99788B7944A40E99AC937DBF6544096E99788B7944A40
71212	27598	84.163230999999996	84.193549000000004	53.520890000000001	53.514273000000003	Буферная	0103000020E6100000010000000500000060AC6F60720A5540A01B9AB2D3C14A4060AC6F60720A55401F680586ACC24A401B4B581B630C55401F680586ACC24A401B4B581B630C5540A01B9AB2D3C14A4060AC6F60720A5540A01B9AB2D3C14A40
70173	27959	84.155990000000003	84.214991999999995	53.341140000000003	53.320360999999998	Центральная	0103000020E6100000010000000500000032207BBDFB095540F9F4D89601A94A4032207BBDFB095540C1ADBB79AAAB4A40B439CE6DC20D5540C1ADBB79AAAB4A40B439CE6DC20D5540F9F4D89601A94A4032207BBDFB095540F9F4D89601A94A40
70485	26444	83.995129000000006	84.042901999999998	53.922007999999998	53.912097000000003	Ленина	0103000020E6100000010000000500000047938B31B0FF5440CEE33098BFF44A4047938B31B0FF54403F53AF5B04F64A40B6BB07E8BE0255403F53AF5B04F64A40B6BB07E8BE025540CEE33098BFF44A4047938B31B0FF5440CEE33098BFF44A40
71014	26117	79.919949000000003	79.955010000000001	53.807605000000002	53.782597000000003	Ленина	0103000020E610000001000000050000003A3FC571E0FA53404F7974232CE44A403A3FC571E0FA5340058BC3995FE74A40975643E21EFD5340058BC3995FE74A40975643E21EFD53404F7974232CE44A403A3FC571E0FA53404F7974232CE44A40
71127	25961	80.482285000000005	80.532995	53.975310999999998	53.959198999999998	Школьная	0103000020E610000001000000050000007D96E7C1DD1E54408EAD6708C7FA4A407D96E7C1DD1E5440EB36A8FDD6FC4A409E7B0F971C225440EB36A8FDD6FC4A409E7B0F971C2254408EAD6708C7FA4A407D96E7C1DD1E54408EAD6708C7FA4A40
70329	25671	80.446855999999997	80.494906	53.873998999999998	53.853290000000001	Советская	0103000020E610000001000000050000005E81E849991C54407E00529B38ED4A405E81E849991C54404CDE0033DFEF4A400726378AAC1F54404CDE0033DFEF4A400726378AAC1F54407E00529B38ED4A405E81E849991C54407E00529B38ED4A40
70857	25733	80.638035000000002	80.660268000000002	53.734315000000002	53.724263000000001	пер.Школьный	0103000020E6100000010000000500000004ADC090D5285440F75965A6B4DC4A4004ADC090D52854402BFBAE08FEDD4A401AA6B6D4412A54402BFBAE08FEDD4A401AA6B6D4412A5440F75965A6B4DC4A4004ADC090D5285440F75965A6B4DC4A40
70164	25529	80.308352999999997	80.381611000000007	53.840243999999998	53.812156000000002	Ленина	0103000020E61000000100000005000000E7A7380EBC13544006A051BAF4E74A40E7A7380EBC13544082548A1D8DEB4A40CF328B506C18544082548A1D8DEB4A40CF328B506C18544006A051BAF4E74A40E7A7380EBC13544006A051BAF4E74A40
69897	25529	80.308352999999997	80.381611000000007	53.840243999999998	53.812156000000002	Зеленая	0103000020E61000000100000005000000E7A7380EBC13544006A051BAF4E74A40E7A7380EBC13544082548A1D8DEB4A40CF328B506C18544082548A1D8DEB4A40CF328B506C18544006A051BAF4E74A40E7A7380EBC13544006A051BAF4E74A40
70689	25859	80.253906000000001	80.282966999999999	53.926451	53.908203999999998	Ленинская	0103000020E610000001000000050000008690F3FE3F105440560C570740F44A408690F3FE3F1054405A2C45F295F64A4039B69E211C1254405A2C45F295F64A4039B69E211C125440560C570740F44A408690F3FE3F105440560C570740F44A40
70814	25902	80.131843000000003	80.144437999999994	54.012369	54.001975999999999	Школьная	0103000020E61000000100000005000000384D9F1D700854403EB0E3BF40004B40384D9F1D70085440FB3DB14E95014B402D93E1783E095440FB3DB14E95014B402D93E1783E0954403EB0E3BF40004B40384D9F1D700854403EB0E3BF40004B40
71211	26004	80.414857999999995	80.425591999999995	53.995905999999998	53.988241000000002	Центральная	0103000020E61000000100000005000000F99E91088D1A54407EC85BAE7EFE4A40F99E91088D1A5440F1F109D979FF4A401C5C3AE63C1B5440F1F109D979FF4A401C5C3AE63C1B54407EC85BAE7EFE4A40F99E91088D1A54407EC85BAE7EFE4A40
70828	26340	80.139415999999997	80.170516000000006	53.692824000000002	53.676217999999999	Центральная	0103000020E6100000010000000500000081221631EC085440B77BB94F8ED64A4081221631EC08544024F1F274AED84A4077DCF0BBE90A544024F1F274AED84A4077DCF0BBE90A5440B77BB94F8ED64A4081221631EC085440B77BB94F8ED64A40
70827	25810	80.542769000000007	80.568406999999993	53.873548	53.863216000000001	Центральная	0103000020E61000000100000005000000171230BABC22544025B1A4DC7DEE4A40171230BABC2254403CBEBD6BD0EF4A4051F4C0C7602454403CBEBD6BD0EF4A4051F4C0C76024544025B1A4DC7DEE4A40171230BABC22544025B1A4DC7DEE4A40
70496	26195	80.323131000000004	80.359530000000007	53.608632999999998	53.583308000000002	Новостройка	0103000020E61000000100000005000000B954A52DAE14544062BF27D6A9CA4A40B954A52DAE1454401822A7AFE7CD4A4094FB1D8A021754401822A7AFE7CD4A4094FB1D8A0217544062BF27D6A9CA4A40B954A52DAE14544062BF27D6A9CA4A40
71232	26159	80.060580000000002	80.090395000000001	53.830111000000002	53.816552999999999	Школьная	0103000020E61000000100000005000000ABB2EF8AE0035440B03907CF84E84A40ABB2EF8AE00354406286C61341EA4A40342E1C08C90554406286C61341EA4A40342E1C08C9055440B03907CF84E84A40ABB2EF8AE0035440B03907CF84E84A40
71309	1972	80.429303000000004	80.436605999999998	53.816488999999997	53.811497000000003	Центральная	0103000020E61000000100000005000000C8444AB3791B5440ACE63922DFE74A40C8444AB3791B5440994528B682E84A4031CF4A5AF11B5440994528B682E84A4031CF4A5AF11B5440ACE63922DFE74A40C8444AB3791B5440ACE63922DFE74A40
71378	25785	80.613978000000003	80.661248000000001	53.925237000000003	53.909880000000001	Центральная	0103000020E61000000100000005000000AA9D616A4B2754406AA4A5F276F44A40AA9D616A4B2754404B06802A6EF64A40E8A221E3512A54404B06802A6EF64A40E8A221E3512A54406AA4A5F276F44A40AA9D616A4B2754406AA4A5F276F44A40
70694	26044	80.144679999999994	80.182777999999999	53.879413	53.854607999999999	Центральная	0103000020E61000000100000005000000A818E76F42095440327381CB63ED4A40A818E76F42095440B056ED9A90F04A40691B7FA2B20B5440B056ED9A90F04A40691B7FA2B20B5440327381CB63ED4A40A818E76F42095440327381CB63ED4A40
71025	26289	80.168225000000007	80.188186000000002	53.562871999999999	53.551442000000002	Кузнецова	0103000020E61000000100000005000000A857CA32C40A544007D2C5A695C64A40A857CA32C40A5440C4EA8F300CC84A402AE44A3D0B0C5440C4EA8F300CC84A402AE44A3D0B0C544007D2C5A695C64A40A857CA32C40A544007D2C5A695C64A40
70512	25628	80.253871000000004	80.276589000000001	53.753241000000003	53.74306	пер.Школьный	0103000020E61000000100000005000000C899266C3F1054409E7B0F971CDF4A40C899266C3F105440D0807A336AE04A40BC5B59A2B3115440D0807A336AE04A40BC5B59A2B31154409E7B0F971CDF4A40C899266C3F1054409E7B0F971CDF4A40
70949	26399	80.120489000000006	80.144411000000005	53.769002	53.756898	Клубная	0103000020E61000000100000005000000C7A17E17B607544033349E08E2E04A40C7A17E17B6075440804754A86EE24A40B18BA2073E095440804754A86EE24A40B18BA2073E09544033349E08E2E04A40C7A17E17B607544033349E08E2E04A40
70939	26092	80.018494000000004	80.025994999999995	53.928614000000003	53.918948999999998	Центральная	0103000020E61000000100000005000000064B75012F01544090D8EE1EA0F54A40064B75012F015440CB4DD4D2DCF64A4002B7EEE6A9015440CB4DD4D2DCF64A4002B7EEE6A901544090D8EE1EA0F54A40064B75012F01544090D8EE1EA0F54A40
71259	24509	82.800082000000003	82.809118999999995	53.099615	53.090282000000002	Центральная	0103000020E610000001000000050000009207228B34B3544070B54E5C8E8B4A409207228B34B3544074982F2FC08C4A409FE40E9BC8B3544074982F2FC08C4A409FE40E9BC8B3544070B54E5C8E8B4A409207228B34B3544070B54E5C8E8B4A40
70166	25142	83.350910999999996	83.375973999999999	53.345166999999996	53.328563000000003	Загайнова	0103000020E61000000100000005000000A033695375D654407CD6355A0EAA4A40A033695375D654404754A86E2EAC4A405D8940F50FD854404754A86E2EAC4A405D8940F50FD854407CD6355A0EAA4A40A033695375D654407CD6355A0EAA4A40
70482	25272	83.156507000000005	83.188298000000003	53.403910000000003	53.377789999999997	Молодежная	0103000020E6100000010000000500000016A6EF3504CA5440BF60376C5BB04A4016A6EF3504CA54408143A852B3B34A40BEF90D130DCC54408143A852B3B34A40BEF90D130DCC5440BF60376C5BB04A4016A6EF3504CA5440BF60376C5BB04A40
69947	24747	83.168508000000003	83.241828999999996	53.184407	53.152456000000001	Школьная	0103000020E610000001000000050000005247C7D5C8CA54401C0A9FAD83934A405247C7D5C8CA5440A51309A69A974A405C8E57207ACF5440A51309A69A974A405C8E57207ACF54401C0A9FAD83934A405247C7D5C8CA54401C0A9FAD83934A40
70688	24747	83.168508000000003	83.241828999999996	53.184407	53.152456000000001	Центральная	0103000020E610000001000000050000005247C7D5C8CA54401C0A9FAD83934A405247C7D5C8CA5440A51309A69A974A405C8E57207ACF5440A51309A69A974A405C8E57207ACF54401C0A9FAD83934A405247C7D5C8CA54401C0A9FAD83934A40
69943	24747	83.168508000000003	83.241828999999996	53.184407	53.152456000000001	Ленина	0103000020E610000001000000050000005247C7D5C8CA54401C0A9FAD83934A405247C7D5C8CA5440A51309A69A974A405C8E57207ACF5440A51309A69A974A405C8E57207ACF54401C0A9FAD83934A405247C7D5C8CA54401C0A9FAD83934A40
71017	25063	83.152240000000006	83.171428000000006	53.279541999999999	53.268956000000003	Целинная	0103000020E610000001000000050000002849D74CBEC95440100874266DA24A402849D74CBEC95440E1ED4108C8A34A40996725ADF8CA5440E1ED4108C8A34A40996725ADF8CA5440100874266DA24A402849D74CBEC95440100874266DA24A40
70481	24887	83.308205000000001	83.363757000000007	53.226562999999999	53.197285999999998	Центральная	0103000020E61000000100000005000000ADDD76A1B9D35440B5FAEAAA40994A40ADDD76A1B9D35440E8BD3104009D4A403BAC70CB47D75440E8BD3104009D4A403BAC70CB47D75440B5FAEAAA40994A40ADDD76A1B9D35440B5FAEAAA40994A40
71202	24551	82.897379000000001	82.907925000000006	53.157721000000002	53.148735000000002	Центральная	0103000020E61000000100000005000000804754A86EB95440A2629CBF09934A40804754A86EB954403B72A43330944A40228E75711BBA54403B72A43330944A40228E75711BBA5440A2629CBF09934A40804754A86EB95440A2629CBF09934A40
70484	25431	83.026124999999993	83.045331000000004	53.314987000000002	53.300857999999998	Майская	0103000020E61000000100000005000000E9263108ACC15440B75ED38382A64A40E9263108ACC1544024D5777E51A84A40AE9FFEB3E6C2544024D5777E51A84A40AE9FFEB3E6C25440B75ED38382A64A40E9263108ACC15440B75ED38382A64A40
70813	24929	83.244290000000007	83.275425999999996	53.194513000000001	53.179366999999999	Сарайская	0103000020E610000001000000050000005A2F8672A2CF5440A67D737FF5964A405A2F8672A2CF5440CCD24ECDE5984A40F59D5F94A0D15440CCD24ECDE5984A40F59D5F94A0D15440A67D737FF5964A405A2F8672A2CF5440A67D737FF5964A40
70642	24195	82.744459000000006	82.805068000000006	53.266914999999997	53.244332	Школьная	0103000020E61000000100000005000000A08D5C37A5AF5440E2AE5E45469F4A40A08D5C37A5AF5440EAE74D452AA24A4098C3EE3B86B35440EAE74D452AA24A4098C3EE3B86B35440E2AE5E45469F4A40A08D5C37A5AF5440E2AE5E45469F4A40
69973	25231	83.218373999999997	83.251566999999994	53.320022000000002	53.305394	Центральная	0103000020E61000000100000005000000FD12F1D6F9CD544083328D2617A74A40FD12F1D6F9CD544011001C7BF6A84A402E7079AC19D0544011001C7BF6A84A402E7079AC19D0544083328D2617A74A40FD12F1D6F9CD544083328D2617A74A40
69891	23716	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	Студенческая	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
69890	23716	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	Свирина	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
69894	23716	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	Пионерская	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
70170	23716	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	Малахова	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
69664	23716	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	Ленина	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
70083	23716	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	Красный Алтай	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
69904	23716	82.930042	83.006936999999994	53.349639000000003	53.284426000000003	Заводская	0103000020E61000000100000005000000037AE1CE85BB5440E910381268A44A40037AE1CE85BB5440FD3383F8C0AC4A407808E3A771C05440FD3383F8C0AC4A407808E3A771C05440E910381268A44A40037AE1CE85BB5440E910381268A44A40
70800	25107	83.053927999999999	83.063873000000001	53.226734999999998	53.218654000000001	Озерная	0103000020E61000000100000005000000AD156D8E73C35440DE91B1DAFC9B4A40AD156D8E73C35440E5ED08A7059D4A403C86C77E16C45440E5ED08A7059D4A403C86C77E16C45440DE91B1DAFC9B4A40AD156D8E73C35440DE91B1DAFC9B4A40
70899	25175	83.255519000000007	83.272839000000005	53.437367999999999	53.429755999999998	Партизанская	0103000020E610000001000000050000006D205D6C5AD0544040A19E3E02B74A406D205D6C5AD054409128B4ACFBB74A40B284B53176D154409128B4ACFBB74A40B284B53176D1544040A19E3E02B74A406D205D6C5AD0544040A19E3E02B74A40
70967	24705	82.727470999999994	82.741906999999998	53.061275000000002	53.052793999999999	Школьная	0103000020E61000000100000005000000757286E28EAE544067B62BF4C1864A40757286E28EAE5440FD87F4DBD7874A401A6B7F677BAF5440FD87F4DBD7874A401A6B7F677BAF544067B62BF4C1864A40757286E28EAE544067B62BF4C1864A40
70551	24294	82.774184000000005	82.801653999999999	53.185578	53.143149999999999	Центральная	0103000020E6100000010000000500000089450C3B8CB1544011363CBD52924A4089450C3B8CB15440B56D1805C1974A40492D944C4EB35440B56D1805C1974A40492D944C4EB3544011363CBD52924A4089450C3B8CB1544011363CBD52924A40
71297	22434	83.101179999999999	83.115444999999994	53.341844000000002	53.335419000000002	Совхозная	0103000020E6100000010000000500000098C0ADBB79C6544080BA8102EFAA4A4098C0ADBB79C65440BB2A508BC1AB4A4026DF6C7363C75440BB2A508BC1AB4A4026DF6C7363C7544080BA8102EFAA4A4098C0ADBB79C6544080BA8102EFAA4A40
71379	22434	83.101179999999999	83.115444999999994	53.341844000000002	53.335419000000002	Майская	0103000020E6100000010000000500000098C0ADBB79C6544080BA8102EFAA4A4098C0ADBB79C65440BB2A508BC1AB4A4026DF6C7363C75440BB2A508BC1AB4A4026DF6C7363C7544080BA8102EFAA4A4098C0ADBB79C6544080BA8102EFAA4A40
71012	24137	82.811733000000004	82.830104000000006	53.287644999999998	53.274293	Ленина	0103000020E610000001000000050000006005F86EF3B35440C84274081CA34A406005F86EF3B35440D0ED258DD1A44A40D811876C20B55440D0ED258DD1A44A40D811876C20B55440C84274081CA34A406005F86EF3B35440C84274081CA34A40
69739	25007	83.369389999999996	83.402518999999998	53.277653000000001	53.260855999999997	Московская	0103000020E610000001000000050000000B5EF415A4D75440917BBABA63A14A400B5EF415A4D7544072512D228AA34A4031410DDFC2D9544072512D228AA34A4031410DDFC2D95440917BBABA63A14A400B5EF415A4D75440917BBABA63A14A40
69733	24647	82.858553999999998	82.913089999999997	53.043503999999999	53.016795000000002	Гагарина	0103000020E6100000010000000500000066F6798CF2B6544040DEAB5626824A4066F6798CF2B65440629F008A91854A407F130A1170BA5440629F008A91854A407F130A1170BA544040DEAB5626824A4066F6798CF2B6544040DEAB5626824A40
71205	25338	83.237741999999997	83.254818	53.444588000000003	53.435431999999999	Калинина	0103000020E61000000100000005000000AEB8382A37CF5440E1D05B3CBCB74A40AEB8382A37CF5440D7187442E8B84A40A81B28F04ED05440D7187442E8B84A40A81B28F04ED05440E1D05B3CBCB74A40AEB8382A37CF5440E1D05B3CBCB74A40
70820	25475	82.974480999999997	82.985547999999994	53.209411000000003	53.198591	Октябрьская	0103000020E61000000100000005000000B2648EE55DBE5440D5230D6E6B994A40B2648EE55DBE54401A36CAFACD9A4A40D828EB3713BF54401A36CAFACD9A4A40D828EB3713BF5440D5230D6E6B994A40B2648EE55DBE5440D5230D6E6B994A40
70479	24102	82.984973999999994	83.011627000000004	53.445262999999997	53.429057999999998	Чкалова	0103000020E61000000100000005000000425A63D009BF5440280B5F5FEBB64A40425A63D009BF5440368FC360FEB84A400A302C7FBEC05440368FC360FEB84A400A302C7FBEC05440280B5F5FEBB64A40425A63D009BF5440280B5F5FEBB64A40
70480	24246	82.721489000000005	82.749865999999997	53.246400999999999	53.229889	Школьная	0103000020E610000001000000050000001FDB32E02CAE5440E65AB4006D9D4A401FDB32E02CAE5440D15966118A9F4A407898F6CDFDAF5440D15966118A9F4A407898F6CDFDAF5440E65AB4006D9D4A401FDB32E02CAE5440E65AB4006D9D4A40
71302	24048	82.839905000000002	82.859900999999994	53.414167999999997	53.405127999999998	Партизанская	0103000020E61000000100000005000000CDAFE600C1B55440D158FB3BDBB34A40CDAFE600C1B554405D86FF7403B54A400D33349E08B754405D86FF7403B54A400D33349E08B75440D158FB3BDBB34A40CDAFE600C1B55440D158FB3BDBB34A40
71446	59415	82.515091999999996	83.474492999999995	53.744796000000001	52.983699000000001	Центральная	0103000020E61000000100000005000000999B6F44F7A05440D00D4DD9E97D4A40999B6F44F7A054408718AF7955DF4A40944BE3175EDE54408718AF7955DF4A40944BE3175EDE5440D00D4DD9E97D4A40999B6F44F7A05440D00D4DD9E97D4A40
70875	59415	82.515091999999996	83.474492999999995	53.744796000000001	52.983699000000001	Молодежная	0103000020E61000000100000005000000999B6F44F7A05440D00D4DD9E97D4A40999B6F44F7A054408718AF7955DF4A40944BE3175EDE54408718AF7955DF4A40944BE3175EDE5440D00D4DD9E97D4A40999B6F44F7A05440D00D4DD9E97D4A40
71099	59415	82.515091999999996	83.474492999999995	53.744796000000001	52.983699000000001	Ленина	0103000020E61000000100000005000000999B6F44F7A05440D00D4DD9E97D4A40999B6F44F7A054408718AF7955DF4A40944BE3175EDE54408718AF7955DF4A40944BE3175EDE5440D00D4DD9E97D4A40999B6F44F7A05440D00D4DD9E97D4A40
70328	23415	81.194164000000001	81.242934000000005	52.078429999999997	52.047141000000003	Садовая	0103000020E61000000100000005000000E083D72E6D4C54407FA65EB708064A40E083D72E6D4C54403C8386FE090A4A4089450C3B8C4F54403C8386FE090A4A4089450C3B8C4F54407FA65EB708064A40E083D72E6D4C54407FA65EB708064A40
70687	23382	81.383043999999998	81.416865000000001	51.995832999999998	51.974733999999998	Школьная	0103000020E61000000100000005000000753BFBCA835854404E266E15C4FC4940753BFBCA8358544087A3AB7477FF4940367689EAAD5A544087A3AB7477FF4940367689EAAD5A54404E266E15C4FC4940753BFBCA835854404E266E15C4FC4940
70335	23009	81.470269999999999	81.510209000000003	52.294738000000002	52.269311000000002	Школьная	0103000020E610000001000000050000008E9257E7185E5440FEB968C878224A408E9257E7185E5440B9718BF9B9254A40FE47A643A7605440B9718BF9B9254A40FE47A643A7605440FEB968C878224A408E9257E7185E5440FEB968C878224A40
70823	23104	81.621223000000001	81.633287999999993	52.262703000000002	52.256998000000003	Центральная	0103000020E6100000010000000500000079211D1EC267544097917A4FE5204A4079211D1EC2675440D2C77C40A0214A40C03C64CA87685440D2C77C40A0214A40C03C64CA8768544097917A4FE5204A4079211D1EC267544097917A4FE5204A40
71374	23242	81.490185999999994	81.532990999999996	52.086931	52.071472	Центральная	0103000020E6100000010000000500000040BD19355F5F5440344A97FE25094A4040BD19355F5F54401901158E200B4A40FD8348861C6254401901158E200B4A40FD8348861C625440344A97FE25094A4040BD19355F5F5440344A97FE25094A40
69732	22880	81.363648999999995	81.405511000000004	52.221283	52.190012000000003	Морозова	0103000020E61000000100000005000000478E7406465754407DEC2E5052184A40478E74064657544094145800531C4A40C5CA68E4F359544094145800531C4A40C5CA68E4F35954407DEC2E5052184A40478E7406465754407DEC2E5052184A40
70179	22880	81.363648999999995	81.405511000000004	52.221283	52.190012000000003	Красноармейская	0103000020E61000000100000005000000478E7406465754407DEC2E5052184A40478E74064657544094145800531C4A40C5CA68E4F359544094145800531C4A40C5CA68E4F35954407DEC2E5052184A40478E7406465754407DEC2E5052184A40
71200	23155	81.702556999999999	81.715214000000003	52.303384999999999	52.291305999999999	Партизанская	0103000020E61000000100000005000000DBA4A2B1F66C54407590D78349254A40DBA4A2B1F66C5440698CD651D5264A400CE9F010C66D5440698CD651D5264A400CE9F010C66D54407590D78349254A40DBA4A2B1F66C54407590D78349254A40
70554	23469	81.189627999999999	81.230994999999993	52.217024000000002	52.193778000000002	Ленинская	0103000020E61000000100000005000000FA997ADD224C54409757AEB7CD184A40FA997ADD224C54403B394371C71B4A4087A2409FC84E54403B394371C71B4A4087A2409FC84E54409757AEB7CD184A40FA997ADD224C54409757AEB7CD184A40
71264	23203	81.551333999999997	81.559886000000006	52.157609000000001	52.148530000000001	Барнаульская	0103000020E6100000010000000500000010CB660E49635440C93CF20703134A4010CB660E4963544013471E882C144A4040DF162CD563544013471E882C144A4040DF162CD5635440C93CF20703134A4010CB660E49635440C93CF20703134A40
71075	23057	81.692234999999997	81.709356999999997	52.241168000000002	52.224229999999999	Октябрьская	0103000020E61000000100000005000000618907944D6C54401B649291B31C4A40618907944D6C5440BE6BD097DE1E4A40130CE71A666D5440BE6BD097DE1E4A40130CE71A666D54401B649291B31C4A40618907944D6C54401B649291B31C4A40
71375	23278	81.449465000000004	81.468528000000006	52.093167000000001	52.085348000000003	Школьная	0103000020E6100000010000000500000096ECD808C45C5440B763EAAEEC0A4A4096ECD808C45C5440810871E5EC0B4A40A950DD5CFC5D5440810871E5EC0B4A40A950DD5CFC5D5440B763EAAEEC0A4A4096ECD808C45C5440B763EAAEEC0A4A40
71206	23623	81.222515000000001	81.245762999999997	52.390483000000003	52.373117999999998	Центральная	0103000020E61000000100000005000000A5F78DAF3D4E544043C6A354C22F4A40A5F78DAF3D4E54406E52D158FB314A4047E4BB94BA4F54406E52D158FB314A4047E4BB94BA4F544043C6A354C22F4A40A5F78DAF3D4E544043C6A354C22F4A40
70474	23572	81.173062999999999	81.209767999999997	52.357269000000002	52.333849000000001	Кооперативная	0103000020E610000001000000050000007349D576134B5440B2666490BB2A4A407349D576134B5440F46F97FDBA2D4A40D4EFC2D66C4D5440F46F97FDBA2D4A40D4EFC2D66C4D5440B2666490BB2A4A407349D576134B5440B2666490BB2A4A40
70815	23335	81.477394000000004	81.508304999999993	52.016916999999999	52.006135	Островского	0103000020E61000000100000005000000A053909F8D5E5440342E1C08C9004A40A053909F8D5E54408BDF14562A024A402BD9B111886054408BDF14562A024A402BD9B11188605440342E1C08C9004A40A053909F8D5E5440342E1C08C9004A40
70702	59405	78.715271999999999	78.738007999999994	53.228886000000003	53.214081	Садова	0103000020E61000000100000005000000A6EF3504C7AD5340F5D89601679B4A40A6EF3504C7AD53409241EE224C9D4A40ED0BE8853BAF53409241EE224C9D4A40ED0BE8853BAF5340F5D89601679B4A40A6EF3504C7AD5340F5D89601679B4A40
70685	22785	78.910044999999997	78.936077999999995	53.265202000000002	53.253740000000001	Ленина	0103000020E61000000100000005000000DA38622D3EBA5340F1D7648D7AA04A40DA38622D3EBA5340BA6A9E23F2A14A405320B3B3E8BB5340BA6A9E23F2A14A405320B3B3E8BB5340F1D7648D7AA04A40DA38622D3EBA5340F1D7648D7AA04A40
70159	22749	79.033904000000007	79.057862999999998	53.289124999999999	53.269311999999999	Октябрьская	0103000020E6100000010000000500000008CDAE7B2BC25340CE35CCD078A24A4008CDAE7B2BC253405EBA490C02A54A4080290307B4C353405EBA490C02A54A4080290307B4C35340CE35CCD078A24A4008CDAE7B2BC25340CE35CCD078A24A40
70533	59399	78.557591000000002	79.371195	53.426295000000003	53.128300000000003	Школьная	0103000020E61000000100000005000000D0622992AFA35340D50968226C904A40D0622992AFA3534063B9A5D590B64A40145CACA8C1D7534063B9A5D590B64A40145CACA8C1D75340D50968226C904A40D0622992AFA35340D50968226C904A40
69942	22711	78.901725999999996	78.934048000000004	53.383735999999999	53.362521000000001	Гагарина	0103000020E61000000100000005000000FCFCF7E0B5B953407E8E8F1667AE4A40FCFCF7E0B5B953402026E1421EB14A403B394371C7BB53402026E1421EB14A403B394371C7BB53407E8E8F1667AE4A40FCFCF7E0B5B953407E8E8F1667AE4A40
69888	22394	78.923716999999996	78.945852000000002	53.229069000000003	53.215591000000003	Энгельса	0103000020E610000001000000050000009770E82D1EBB5340EE27637C989B4A409770E82D1EBB534083C30B22529D4A40CCB6D3D688BC534083C30B22529D4A40CCB6D3D688BC5340EE27637C989B4A409770E82D1EBB5340EE27637C989B4A40
71372	22469	78.769108000000003	78.801186999999999	53.340662000000002	53.330305000000003	Луговая	0103000020E61000000100000005000000E3C5C21039B15340475A2A6F47AA4A40E3C5C21039B15340B77EFACF9AAB4A40BEBED6A546B35340B77EFACF9AAB4A40BEBED6A546B35340475A2A6F47AA4A40E3C5C21039B15340475A2A6F47AA4A40
69648	22261	78.978477999999996	78.998429999999999	53.236258999999997	53.216783	Клубная	0103000020E61000000100000005000000C07630629FBE534015AA9B8BBF9B4A40C07630629FBE53405D3123BC3D9E4A401956F146E6BF53405D3123BC3D9E4A401956F146E6BF534015AA9B8BBF9B4A40C07630629FBE534015AA9B8BBF9B4A40
69940	21911	79.862088	79.911890999999997	51.856324999999998	51.834308	Украинская	0103000020E610000001000000050000008A9125732CF753404565C39ACAEA49408A9125732CF75340A4DFBE0E9CED494012A1116C5CFA5340A4DFBE0E9CED494012A1116C5CFA53404565C39ACAEA49408A9125732CF753404565C39ACAEA4940
70684	21926	79.678085999999993	79.716641999999993	52.084761999999998	52.062514	Советская	0103000020E610000001000000050000000778D2C265EB534065C5707500084A400778D2C265EB5340C6F8307BD90A4A40293C6876DDED5340C6F8307BD90A4A40293C6876DDED534065C5707500084A400778D2C265EB534065C5707500084A40
70471	22147	79.398414000000002	79.429063999999997	51.934565999999997	51.917577000000001	Лисевцева	0103000020E6100000010000000500000030116F9D7FD95340E947C32973F5494030116F9D7FD953400DFAD2DB9FF7494005F9D9C875DB53400DFAD2DB9FF7494005F9D9C875DB5340E947C32973F5494030116F9D7FD95340E947C32973F54940
71373	22163	79.212534000000005	79.247380000000007	51.966056000000002	51.956299999999999	Кравченко	0103000020E6100000010000000500000070D234289ACD53401895D40968FA494070D234289ACD5340630D17B9A7FB4940CF6BEC12D5CF5340630D17B9A7FB4940CF6BEC12D5CF53401895D40968FA494070D234289ACD53401895D40968FA4940
70806	21995	79.625050000000002	79.653248000000005	52.033320000000003	52.019643000000002	Ленина	0103000020E610000001000000050000005917B7D100E85340344C6DA983024A405917B7D100E85340C0266BD443044A405B0BB3D0CEE95340C0266BD443044A405B0BB3D0CEE95340344C6DA983024A405917B7D100E85340344C6DA983024A40
69970	21649	79.645954000000003	79.775526999999997	51.832676999999997	51.800446999999998	Шоссейная	0103000020E610000001000000050000001B2E724F57E9534035971B0C75E649401B2E724F57E95340D190F12895EA49408F8AFF3BA2F15340D190F12895EA49408F8AFF3BA2F1534035971B0C75E649401B2E724F57E9534035971B0C75E64940
69935	21649	79.645954000000003	79.775526999999997	51.832676999999997	51.800446999999998	Крупской	0103000020E610000001000000050000001B2E724F57E9534035971B0C75E649401B2E724F57E95340D190F12895EA49408F8AFF3BA2F15340D190F12895EA49408F8AFF3BA2F1534035971B0C75E649401B2E724F57E9534035971B0C75E64940
69887	21649	79.645954000000003	79.775526999999997	51.832676999999997	51.800446999999998	К.Маркса	0103000020E610000001000000050000001B2E724F57E9534035971B0C75E649401B2E724F57E95340D190F12895EA49408F8AFF3BA2F15340D190F12895EA49408F8AFF3BA2F1534035971B0C75E649401B2E724F57E9534035971B0C75E64940
70715	59391	79.758279000000002	79.821251000000004	51.683172999999996	51.663902999999998	Советская	0103000020E61000000100000005000000978FA4A487F05340AF5B04C6FAD44940978FA4A487F053404E417E3672D74940ABB35A608FF453404E417E3672D74940ABB35A608FF45340AF5B04C6FAD44940978FA4A487F05340AF5B04C6FAD44940
70223	59391	79.758279000000002	79.821251000000004	51.683172999999996	51.663902999999998	Мамонтова	0103000020E61000000100000005000000978FA4A487F05340AF5B04C6FAD44940978FA4A487F053404E417E3672D74940ABB35A608FF453404E417E3672D74940ABB35A608FF45340AF5B04C6FAD44940978FA4A487F05340AF5B04C6FAD44940
70548	22094	79.461853000000005	79.494022000000001	51.868766000000001	51.845654000000003	Горького	0103000020E61000000100000005000000CFA3E2FF8EDD5340A5DDE8633EEC4940CFA3E2FF8EDD534039F06AB933EF49404A60730E9EDF534039F06AB933EF49404A60730E9EDF5340A5DDE8633EEC4940CFA3E2FF8EDD5340A5DDE8633EEC4940
71368	22019	79.766003999999995	79.788408000000004	52.135956	52.122256	Ленина	0103000020E61000000100000005000000BB26A43506F15340B1DEA815A60F4A40BB26A43506F15340F5D8960167114A40E8F9D34675F25340F5D8960167114A40E8F9D34675F25340B1DEA815A60F4A40BB26A43506F15340B1DEA815A60F4A40
70544	21514	81.484319999999997	81.522875999999997	52.566484000000003	52.539155000000001	Новая	0103000020E610000001000000050000001E335019FF5E5440C93CF20703454A401E335019FF5E544088DA368C82484A4040F7E5CC7661544088DA368C82484A4040F7E5CC76615440C93CF20703454A401E335019FF5E5440C93CF20703454A40
70801	21440	81.463093000000001	81.485648999999995	52.854719000000003	52.836592000000003	Центральная	0103000020E610000001000000050000006B80D250A35D5440310C5872156B4A406B80D250A35D54408A22A46E676D4A4072158BDF145F54408A22A46E676D4A4072158BDF145F5440310C5872156B4A406B80D250A35D5440310C5872156B4A40
71015	21429	81.850554000000002	81.895460999999997	52.593265000000002	52.573172	Молодежная	0103000020E61000000100000005000000D95E0B7A6F765440D07D39B35D494A40D95E0B7A6F765440446E861BF04B4A40FB75A73B4F795440446E861BF04B4A40FB75A73B4F795440D07D39B35D494A40D95E0B7A6F765440D07D39B35D494A40
70541	21359	81.632667999999995	81.675157999999996	52.620379999999997	52.591617999999997	Партизанская	0103000020E61000000100000005000000724EECA17D685440CADC7C23BA4B4A40724EECA17D685440D68BA19C684F4A407F68E6C9356B5440D68BA19C684F4A407F68E6C9356B5440CADC7C23BA4B4A40724EECA17D685440CADC7C23BA4B4A40
70468	21275	81.85633	81.900788000000006	52.784941000000003	52.764642000000002	Победы	0103000020E610000001000000050000005B25581CCE765440F392FFC9DF614A405B25581CCE76544010255AF278644A404628B682A679544010255AF278644A404628B682A6795440F392FFC9DF614A405B25581CCE765440F392FFC9DF614A40
70472	21298	81.652097999999995	81.672499000000002	52.922365999999997	52.910555000000002	Магистральная	0103000020E610000001000000050000005EF23FF9BB695440CA1AF5108D744A405EF23FF9BB6954409E78CE1610764A40EFE53E390A6B54409E78CE1610764A40EFE53E390A6B5440CA1AF5108D744A405EF23FF9BB695440CA1AF5108D744A40
70162	21222	81.257998000000001	82.103699000000006	53.079897000000003	52.360399000000001	Гребенникова	0103000020E61000000100000005000000BD1B0B0A835054406C41EF8D212E4A40BD1B0B0A8350544036069D103A8A4A4030682101A386544036069D103A8A4A4030682101A38654406C41EF8D212E4A40BD1B0B0A835054406C41EF8D212E4A40
70339	21184	81.646771000000001	81.679218000000006	52.740785000000002	52.722718999999998	Советская	0103000020E61000000100000005000000144031B2646954405299620E825C4A40144031B264695440062FFA0AD25E4A40B136C64E786B5440062FFA0AD25E4A40B136C64E786B54405299620E825C4A40144031B2646954405299620E825C4A40
69883	20873	82.010992999999999	82.058396999999999	52.678271000000002	52.651023000000002	Советская	0103000020E6100000010000000500000009DFFB1BB4805440CFF8BEB854534A4009DFFB1BB4805440A1698995D1564A40CF4BC5C6BC835440A1698995D1564A40CF4BC5C6BC835440CFF8BEB854534A4009DFFB1BB4805440CFF8BEB854534A40
70106	20772	81.666416999999996	81.703373999999997	52.996361	52.976097000000003	Комсомольская	0103000020E61000000100000005000000E61F7D93A66A5440A35C1ABFF07C4A40E61F7D93A66A54404301DBC1887F4A40D4B66114046D54404301DBC1887F4A40D4B66114046D5440A35C1ABFF07C4A40E61F7D93A66A5440A35C1ABFF07C4A40
70397	20819	81.600481000000002	81.648927	52.977739999999997	52.963700000000003	Октябрьская	0103000020E61000000100000005000000A437DC476E665440DE9387855A7B4A40A437DC476E665440DAFE9595267D4A40739F1C0588695440DAFE9595267D4A40739F1C0588695440DE9387855A7B4A40A437DC476E665440DE9387855A7B4A40
70680	20672	81.900032999999993	81.960669999999993	52.889892000000003	52.855708999999997	Партизанская	0103000020E61000000100000005000000871403249A79544049F25CDF876D4A40871403249A7954406C7C26FBE7714A40E40F069E7B7D54406C7C26FBE7714A40E40F069E7B7D544049F25CDF876D4A40871403249A79544049F25CDF876D4A40
70794	20628	81.615761000000006	81.655942999999994	53.043596000000001	53.016112	Мира	0103000020E61000000100000005000000BF49D3A0686754405D8940F50F824A40BF49D3A068675440431EC18D94854A40914259F8FA695440431EC18D94854A40914259F8FA6954405D8940F50F824A40BF49D3A0686754405D8940F50F824A40
70466	20549	81.415167999999994	81.478211000000002	53.021768000000002	52.994833	Центральная	0103000020E610000001000000050000002096CD1C925A5440A4FD0FB0567F4A402096CD1C925A5440B70C384BC9824A4099654F029B5E5440B70C384BC9824A4099654F029B5E5440A4FD0FB0567F4A402096CD1C925A5440A4FD0FB0567F4A40
70646	20517	81.775778000000003	81.820344000000006	52.814129000000001	52.790719000000003	Победы	0103000020E6100000010000000500000034BDC458A6715440B5A9BA4736654A4034BDC458A6715440D3DC0A6135684A4012DE1E8480745440D3DC0A6135684A4012DE1E8480745440B5A9BA4736654A4034BDC458A6715440B5A9BA4736654A40
70692	20259	81.586539000000002	81.620028000000005	51.156923999999997	51.12988	Кирова	0103000020E6100000010000000500000007B5DFDA89655440C63368E89F90494007B5DFDA896554408FFAEB1516944940ADA6EB89AE6754408FFAEB1516944940ADA6EB89AE675440C63368E89F90494007B5DFDA89655440C63368E89F904940
70278	19547	81.525318999999996	81.545298000000003	50.978718000000001	50.956290000000003	Юбилейная	0103000020E61000000100000005000000EA3D95D39E615440F5BEF1B5677A4940EA3D95D39E615440D600A5A1467D4940C0249529E6625440D600A5A1467D4940C0249529E6625440F5BEF1B5677A4940EA3D95D39E615440F5BEF1B5677A4940
70477	19952	81.266469000000001	81.293841	51.136696000000001	51.126387000000001	Школьная	0103000020E610000001000000050000007619FED30D515440DDD1FF722D9049407619FED30D5154403CBF28417F914940554E7B4ACE5254403CBF28417F914940554E7B4ACE525440DDD1FF722D9049407619FED30D515440DDD1FF722D904940
70676	19645	81.525812999999999	81.546662999999995	50.915052000000003	50.897416	Центральная	0103000020E61000000100000005000000F2B391EBA66154401D740987DE724940F2B391EBA6615440D811876C20754940BABBCE86FC625440D811876C20754940BABBCE86FC6254401D740987DE724940F2B391EBA66154401D740987DE724940
70467	20005	81.216684999999998	81.239709000000005	51.133164000000001	51.119087999999998	Гагарина	0103000020E610000001000000050000002922C32ADE4D54404BAC8C463E8F49402922C32ADE4D5440958098840B914940A4E36A64574F5440958098840B914940A4E36A64574F54404BAC8C463E8F49402922C32ADE4D54404BAC8C463E8F4940
70679	20190	81.409319999999994	81.461924999999994	51.194457999999997	51.172817999999999	Школьная	0103000020E610000001000000050000005166834C325A54407F1475E61E9649405166834C325A54400839EFFFE39849401B0DE02D905D54400839EFFFE39849401B0DE02D905D54407F1475E61E9649405166834C325A54407F1475E61E964940
71016	20075	81.128461000000001	81.167978000000005	51.068080000000002	51.035376999999997	Школьная	0103000020E61000000100000005000000EF737CB438485440EA03C93B87844940EF737CB4384854407FC16ED8B6884940A41CCC26C04A54407FC16ED8B6884940A41CCC26C04A5440EA03C93B87844940EF737CB438485440EA03C93B87844940
70812	19901	81.391919000000001	81.425147999999993	51.090499999999999	51.059894999999997	Клочкова	0103000020E6100000010000000500000096EB6D3315595440D218ADA3AA87494096EB6D3315595440DD240681958B49406DFDF49F355B5440DD240681958B49406DFDF49F355B5440D218ADA3AA87494096EB6D3315595440D218ADA3AA874940
69932	19737	81.766058999999998	81.808531000000002	50.974668999999999	50.948965000000001	Советская	0103000020E610000001000000050000009DF3531C077154403A0664AF777949409DF3531C0771544067B62BF4C17C494057B3CEF8BE73544067B62BF4C17C494057B3CEF8BE7354403A0664AF777949409DF3531C077154403A0664AF77794940
69931	20142	81.183357000000001	81.207539999999995	51.203279999999999	51.174523999999998	Советская	0103000020E61000000100000005000000889FFF1EBC4B5440FD2E6CCD56964940889FFF1EBC4B544027F73B14059A49402827DA55484D544027F73B14059A49402827DA55484D5440FD2E6CCD56964940889FFF1EBC4B5440FD2E6CCD56964940
71307	12544	81.792001999999997	81.803472999999997	50.857365000000001	50.836942000000001	Центральная	0103000020E6100000010000000500000076172829B07254400D535BEA206B494076172829B072544016DEE522BE6D4940048E041A6C73544016DEE522BE6D4940048E041A6C7354400D535BEA206B494076172829B07254400D535BEA206B4940
70538	19479	81.489512000000005	81.516174000000007	51.017747	51.001153000000002	Школьная	0103000020E61000000100000005000000F9BF232A545F54406AA510C825804940F9BF232A545F5440124DA08845824940EA42ACFE08615440124DA08845824940EA42ACFE086154406AA510C825804940F9BF232A545F54406AA510C825804940
70327	19708	81.520459000000002	81.537716000000003	50.829126000000002	50.798096999999999	Молодежная	0103000020E610000001000000050000002BFA43334F6154409204E10A286649402BFA43334F615440B421FFCC206A49404DA25EF069625440B421FFCC206A49404DA25EF0696254409204E10A286649402BFA43334F6154409204E10A28664940
71193	19796	81.684572000000003	81.710812000000004	50.788868000000001	50.778446000000002	Школьная	0103000020E6100000010000000500000078F01307D06B5440DCD9571EA463494078F01307D06B5440336E6AA0F9644940AE669DF17D6D5440336E6AA0F9644940AE669DF17D6D5440DCD9571EA463494078F01307D06B5440DCD9571EA4634940
69886	19074	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Усадебная	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
69729	19074	81.436565000000002	81.547129999999996	51.012816999999998	50.965752999999999	Островского	0103000020E61000000100000005000000026553AEF05B5440C78157CB9D7B4940026553AEF05B54409AEAC9FCA3814940452A8C2D046354409AEAC9FCA3814940452A8C2D04635440C78157CB9D7B4940026553AEF05B5440C78157CB9D7B4940
70540	20442	81.770100999999997	81.811154000000002	51.142946000000002	51.117041999999998	Школьная	0103000020E610000001000000050000007B67B455497154401421753BFB8E49407B67B45549715440098CF50D4C924940418177F2E9735440098CF50D4C924940418177F2E97354401421753BFB8E49407B67B455497154401421753BFB8E4940
71199	19844	81.493662	81.527321999999998	51.150213000000001	51.131433999999999	Емцева	0103000020E61000000100000005000000CA518028985F54408ECA4DD4D2904940CA518028985F54408F37F92D3A934940861DC6A4BF6154408F37F92D3A934940861DC6A4BF6154408ECA4DD4D2904940CA518028985F54408ECA4DD4D2904940
70323	20391	81.736980000000003	81.765780000000007	51.065556000000001	51.041012000000002	Трибунского	0103000020E61000000100000005000000977329AE2A6F54402D5F97E13F854940977329AE2A6F54403E0796236488494094FB1D8A027154403E0796236488494094FB1D8A027154402D5F97E13F854940977329AE2A6F54402D5F97E13F854940
70695	20303	81.678822999999994	81.705701000000005	51.141421000000001	51.129201999999999	Советская	0103000020E61000000100000005000000723106D6716B5440F549EEB089904940723106D6716B5440DBFB54151A9249404AF086342A6D5440DBFB54151A9249404AF086342A6D5440F549EEB089904940723106D6716B5440F549EEB089904940
70888	18478	85.259957	85.288784000000007	53.262649000000003	53.256923	Центральная	0103000020E610000001000000050000007157AF22A35055408C4B55DAE2A04A407157AF22A3505540DFA9807B9EA14A40EBE6E26F7B525540DFA9807B9EA14A40EBE6E26F7B5255408C4B55DAE2A04A407157AF22A35055408C4B55DAE2A04A40
70376	18169	84.987219999999994	85.030051	53.496760000000002	53.471330999999999	Молодежная	0103000020E61000000100000005000000417DCB9C2E3F5540A54BFF9254BC4A40417DCB9C2E3F554001FBE8D495BF4A40938D075BEC41554001FBE8D495BF4A40938D075BEC415540A54BFF9254BC4A40417DCB9C2E3F5540A54BFF9254BC4A40
71367	18040	85.567216999999999	85.589522000000002	53.409385	53.398524999999999	Новая	0103000020E610000001000000050000000E2F88484D645540B7D100DE02B34A400E2F88484D6455408A3C49BA66B44A4071917BBABA6555408A3C49BA66B44A4071917BBABA655540B7D100DE02B34A400E2F88484D645540B7D100DE02B34A40
71371	18596	85.460217999999998	85.490662	53.587204999999997	53.569347999999998	Молодежная	0103000020E61000000100000005000000F4C13236745D554081053065E0C84A40F4C13236745D55401A868F8829CB4A40F5D89601675F55401A868F8829CB4A40F5D89601675F554081053065E0C84A40F4C13236745D554081053065E0C84A40
70321	18795	85.460380000000001	85.496033999999995	53.473083000000003	53.461210000000001	Лесная	0103000020E61000000100000005000000E1EEACDD765D5540494BE5ED08BB4A40E1EEACDD765D554094A5D6FB8DBC4A400FED6305BF5F554094A5D6FB8DBC4A400FED6305BF5F5540494BE5ED08BB4A40E1EEACDD765D5540494BE5ED08BB4A40
70318	18553	85.526864000000003	85.550777999999994	53.655838000000003	53.642964999999997	Максакова	0103000020E61000000100000005000000255CC823B86155407FBC57AD4CD24A40255CC823B8615540AEBCE47FF2D34A40CD565EF23F635540AEBCE47FF2D34A40CD565EF23F6355407FBC57AD4CD24A40255CC823B86155407FBC57AD4CD24A40
71105	17983	85.462311999999997	85.513731000000007	53.407625000000003	53.394835999999998	Черемнова	0103000020E6100000010000000500000018231285965D554048A46DFC89B24A4018231285965D55401904560E2DB44A4040FCFCF7E06055401904560E2DB44A4040FCFCF7E060554048A46DFC89B24A4018231285965D554048A46DFC89B24A40
71296	19015	85.426675000000003	85.455663999999999	53.337784999999997	53.319291	Садовая	0103000020E6100000010000000500000055C1A8A44E5B55401D740987DEA84A4055C1A8A44E5B5540280AF4893CAB4A40BB7D5699295D5540280AF4893CAB4A40BB7D5699295D55401D740987DEA84A4055C1A8A44E5B55401D740987DEA84A40
70799	18657	85.599044000000006	85.623586000000003	53.565716999999999	53.554485999999997	Черемушки	0103000020E610000001000000050000005D37A5BC56665540800BB265F9C64A405D37A5BC5666554047E5266A69C84A40950F41D5E867554047E5266A69C84A40950F41D5E8675540800BB265F9C64A405D37A5BC56665540800BB265F9C64A40
70795	18366	85.113945000000001	85.151926000000003	53.234864000000002	53.223807999999998	Центральная	0103000020E61000000100000005000000BC22F8DF4A475540A54A94BDA59C4A40BC22F8DF4A475540FE800706109E4A40605AD427B9495540FE800706109E4A40605AD427B9495540A54A94BDA59C4A40BC22F8DF4A475540A54A94BDA59C4A40
71195	18080	85.337023000000002	85.351467999999997	53.507460999999999	53.490332000000002	Школьная	0103000020E61000000100000005000000FDBFEAC8915555405517F032C3BE4A40FDBFEAC8915555406B7F677BF4C04A40CB65A3737E5655406B7F677BF4C04A40CB65A3737E5655405517F032C3BE4A40FDBFEAC8915555405517F032C3BE4A40
70788	18270	85.645325	85.670038000000005	53.691091	53.680937999999998	Черемушки	0103000020E61000000100000005000000A3923A014D695540444DF4F928D74A40A3923A014D695540ACC77DAB75D84A40F24410E7E16A5540ACC77DAB75D84A40F24410E7E16A5540444DF4F928D74A40A3923A014D695540444DF4F928D74A40
69928	18439	85.316820000000007	85.349159999999998	53.292979000000003	53.277915999999998	Советская	0103000020E6100000010000000500000000AE64C7465455407F8461C092A34A4000AE64C74654554018B5FB5580A54A4091442FA35856554018B5FB5580A54A4091442FA3585655407F8461C092A34A4000AE64C7465455407F8461C092A34A40
71349	6723	85.195511999999994	85.213361000000006	53.686697000000002	53.668013999999999	Пушкина	0103000020E610000001000000050000006F7EC344834C554094A2957B81D54A406F7EC344834C554073A1F2AFE5D74A407B4FE5B4A74D554073A1F2AFE5D74A407B4FE5B4A74D554094A2957B81D54A406F7EC344834C554094A2957B81D54A40
71481	59463	85.690537000000006	85.709860000000006	53.624935000000001	53.612378	Новая	0103000020E6100000010000000500000064EB19C2316C55401B65FD6662CE4A4064EB19C2316C55401990BDDEFDCF4A40452FA3586E6D55401990BDDEFDCF4A40452FA3586E6D55401B65FD6662CE4A4064EB19C2316C55401B65FD6662CE4A40
70790	18972	85.609447000000003	85.623864999999995	53.486319000000002	53.472803999999996	Центральная	0103000020E610000001000000050000004D69FD2D0167554080B56AD784BC4A404D69FD2D01675540333674B33FBE4A409E077767ED675540333674B33FBE4A409E077767ED67554080B56AD784BC4A404D69FD2D0167554080B56AD784BC4A40
70342	18228	85.253704999999997	85.305914999999999	53.387458000000002	53.373379999999997	Целинная	0103000020E610000001000000050000003A75E5B33C505540807D74EACAAF4A403A75E5B33C5055406B49473998B14A40C616821C945355406B49473998B14A40C616821C94535540807D74EACAAF4A403A75E5B33C505540807D74EACAAF4A40
71369	18868	85.432191000000003	85.450605999999993	53.478045999999999	53.46969	Республики	0103000020E6100000010000000500000009A87004A95B55400EA14ACD1EBC4A4009A87004A95B5540E7FD7F9C30BD4A4068588CBAD65C5540E7FD7F9C30BD4A4068588CBAD65C55400EA14ACD1EBC4A4009A87004A95B55400EA14ACD1EBC4A40
70084	17874	85.422794999999994	85.474564999999998	53.468034000000003	53.448079	Советская	0103000020E61000000100000005000000637AC2120F5B55401F8315A75AB94A40637AC2120F5B554042B5C189E8BB4A40E1B4E0455F5E554042B5C189E8BB4A40E1B4E0455F5E55401F8315A75AB94A40637AC2120F5B55401F8315A75AB94A40
69912	17874	85.422794999999994	85.474564999999998	53.468034000000003	53.448079	Комсомольская	0103000020E61000000100000005000000637AC2120F5B55401F8315A75AB94A40637AC2120F5B554042B5C189E8BB4A40E1B4E0455F5E554042B5C189E8BB4A40E1B4E0455F5E55401F8315A75AB94A40637AC2120F5B55401F8315A75AB94A40
71190	18147	85.359418000000005	85.378812999999994	53.480693000000002	53.469571999999999	Весенняя	0103000020E6100000010000000500000000E65AB400575540048F6FEF1ABC4A4000E65AB4005755404435255987BD4A402D93E1783E5855404435255987BD4A402D93E1783E585540048F6FEF1ABC4A4000E65AB400575540048F6FEF1ABC4A40
71097	18761	85.700643999999997	85.729920000000007	53.547626999999999	53.532639000000003	Школьная	0103000020E61000000100000005000000DF88EE59D76C55407EC9C6832DC44A40DF88EE59D76C55400BB43BA418C64A40912C6002B76E55400BB43BA418C64A40912C6002B76E55407EC9C6832DC44A40DF88EE59D76C55407EC9C6832DC44A40
70776	17782	85.332127999999997	85.342979	53.544925999999997	53.534930000000003	Чумышская	0103000020E610000001000000050000007F85CC95415555401CD3139678C44A407F85CC9541555540BB5E9A22C0C54A40BF0D315EF3555540BB5E9A22C0C54A40BF0D315EF35555401CD3139678C44A407F85CC95415555401CD3139678C44A40
70562	5462	85.500731999999999	85.538632000000007	53.797890000000002	53.775249000000002	Ленина	0103000020E61000000100000005000000E2033BFE0B605540DCA0F65B3BE34A40E2033BFE0B60554019E76F4221E64A4010255AF27862554019E76F4221E64A4010255AF278625540DCA0F65B3BE34A40E2033BFE0B605540DCA0F65B3BE34A40
70464	17741	85.223144000000005	85.250919999999994	53.596696000000001	53.570236000000001	Целинная	0103000020E610000001000000050000001D93C5FD474E55403D80457EFDC84A401D93C5FD474E5540B7D3D68860CC4A40637AC2120F505540B7D3D68860CC4A40637AC2120F5055403D80457EFDC84A401D93C5FD474E55403D80457EFDC84A40
70780	18906	85.388334999999998	85.408349999999999	53.490380000000002	53.477397000000003	Западная	0103000020E6100000010000000500000019390B7BDA585540B11A4B581BBD4A4019390B7BDA585540664E97C5C4BE4A4095D40968225A5540664E97C5C4BE4A4095D40968225A5540B11A4B581BBD4A4019390B7BDA585540B11A4B581BBD4A40
71197	17003	82.626042999999996	82.641807999999997	51.311239999999998	51.294944000000001	Центральная	0103000020E61000000100000005000000F1B8A81611A85440621399B9C0A54940F1B8A81611A85440809A5AB6D6A74940EA93DC6113A95440809A5AB6D6A74940EA93DC6113A95440621399B9C0A54940F1B8A81611A85440621399B9C0A54940
70460	17284	82.277154999999993	82.300188000000006	51.506807000000002	51.463890999999997	Полевая	0103000020E61000000100000005000000103B53E8BC91544051F4C0C760BB4940103B53E8BC9154402331410DDFC04940B5A9BA47369354402331410DDFC04940B5A9BA473693544051F4C0C760BB4940103B53E8BC91544051F4C0C760BB4940
70315	17348	82.463995999999995	82.505928999999995	51.714889999999997	51.698402999999999	Сибирская	0103000020E61000000100000005000000635E471CB29D5440D236FE4465D94940635E471CB29D5440641EF98381DB49404546072461A05440641EF98381DB49404546072461A05440D236FE4465D94940635E471CB29D5440D236FE4465D94940
71366	17229	82.328027000000006	82.351552999999996	51.415075000000002	51.390329999999999	Центральная	0103000020E610000001000000050000001F4DF564FE945440E7525C55F6B149401F4DF564FE9454409031772D21B54940E27327D87F9654409031772D21B54940E27327D87F965440E7525C55F6B149401F4DF564FE945440E7525C55F6B14940
70777	17090	82.530012999999997	82.539660999999995	51.335380999999998	51.328887000000002	Центральная	0103000020E610000001000000050000001C5DA5BBEBA154402F8A1EF818AA49401C5DA5BBEBA154409259BDC3EDAA49404E7B4ACE89A254409259BDC3EDAA49404E7B4ACE89A254402F8A1EF818AA49401C5DA5BBEBA154402F8A1EF818AA4940
70320	17529	82.181681999999995	82.203421000000006	51.760992000000002	51.739007000000001	Локтевская	0103000020E6100000010000000500000066118AADA08B5440EE4108C897DE494066118AADA08B54404242942F68E14940759483D9048D54404242942F68E14940759483D9048D5440EE4108C897DE494066118AADA08B5440EE4108C897DE4940
70804	17665	82.274595000000005	82.283361999999997	51.663556999999997	51.655523000000002	Краснознаменская	0103000020E610000001000000050000004A29E8F6929154404E637B2DE8D349404A29E8F69291544014048F6FEFD4494077BB5E9A2292544014048F6FEFD4494077BB5E9A229254404E637B2DE8D349404A29E8F6929154404E637B2DE8D34940
69727	17185	82.270409000000001	82.311192000000005	51.620604	51.578713	Советская	0103000020E61000000100000005000000D2E28C614E9154409162804413CA4940D2E28C614E91544026E2ADF36FCF4940B8B1D991EA93544026E2ADF36FCF4940B8B1D991EA9354409162804413CA4940D2E28C614E9154409162804413CA4940
70156	17185	82.270409000000001	82.311192000000005	51.620604	51.578713	Гагарина	0103000020E61000000100000005000000D2E28C614E9154409162804413CA4940D2E28C614E91544026E2ADF36FCF4940B8B1D991EA93544026E2ADF36FCF4940B8B1D991EA9354409162804413CA4940D2E28C614E9154409162804413CA4940
70317	17490	81.998480000000001	82.029938999999999	51.695276999999997	51.662925999999999	Центральная	0103000020E61000000100000005000000726DA818E77F544084D558C2DAD44940726DA818E77F54409B5434D6FED84940FF774485EA8154409B5434D6FED84940FF774485EA81544084D558C2DAD44940726DA818E77F544084D558C2DAD44940
70462	17582	82.260706999999996	82.271765000000002	51.691212999999998	51.678029000000002	Коммунистическая	0103000020E61000000100000005000000A6B5696CAF905440AB5E7EA7C9D64940A6B5696CAF905440F7C8E6AA79D84940A3CC069964915440F7C8E6AA79D84940A3CC069964915440AB5E7EA7C9D64940A6B5696CAF905440AB5E7EA7C9D64940
70158	17035	82.346146000000005	82.594511999999995	51.330855999999997	51.084961	Ломоносова	0103000020E610000001000000050000000A698D4127965440BD378600E08A49400A698D4127965440BAD7497D59AA494017450F7C0CA65440BAD7497D59AA494017450F7C0CA65440BD378600E08A49400A698D4127965440BD378600E08A4940
71362	17125	82.357805999999997	82.376383000000004	51.372757999999997	51.358840000000001	Школьная	0103000020E610000001000000050000000114234BE6965440923F1878EEAD49400114234BE696544043A9BD88B6AF49404EF1B8A81698544043A9BD88B6AF49404EF1B8A816985440923F1878EEAD49400114234BE6965440923F1878EEAD4940
70669	17369	82.000024999999994	82.035373000000007	51.579335	51.544234000000003	Парковый переулок	0103000020E61000000100000005000000AC8BDB680080544086AFAF75A9C54940AC8BDB6800805440CE3637A627CA4940558A1D8D43825440CE3637A627CA4940558A1D8D4382544086AFAF75A9C54940AC8BDB680080544086AFAF75A9C54940
71363	17439	82.087440000000001	82.104759000000001	51.507693000000003	51.500360000000001	Центральная	0103000020E610000001000000050000002F17F19D98855440001DE6CB0BC049402F17F19D988554403EB48F15FCC049408CBD175FB48654403EB48F15FCC049408CBD175FB4865440001DE6CB0BC049402F17F19D98855440001DE6CB0BC04940
71006	16955	82.775406000000004	82.796058000000002	51.284281	51.273739999999997	Алтайская	0103000020E61000000100000005000000D2C77C40A0B15440B3CD8DE909A34940D2C77C40A0B15440E5EFDE5163A4494007EE409DF2B25440E5EFDE5163A4494007EE409DF2B25440B3CD8DE909A34940D2C77C40A0B15440B3CD8DE909A34940
71196	16456	78.767831999999999	78.785008000000005	52.626306	52.610498999999997	Молодежная	0103000020E61000000100000005000000A034D42824B15340CF9ECBD4244E4A40A034D42824B15340F0A485CB2A504A404CC631923DB25340F0A485CB2A504A404CC631923DB25340CF9ECBD4244E4A40A034D42824B15340CF9ECBD4244E4A40
70898	16258	79.233868999999999	79.258402000000004	52.534427999999998	52.519832000000001	Ленина	0103000020E6100000010000000500000016A3AEB5F7CE534007B5DFDA89424A4016A3AEB5F7CE53408908FF2268444A4025CE8AA889D053408908FF2268444A4025CE8AA889D0534007B5DFDA89424A4016A3AEB5F7CE534007B5DFDA89424A40
71180	16021	79.301180000000002	79.320565999999999	52.657299999999999	52.645029000000001	Юбилейная	0103000020E61000000100000005000000658D7A8846D353405DFC6D4F90524A40658D7A8846D3534095D4096822544A40698D412784D4534095D4096822544A40698D412784D453405DFC6D4F90524A40658D7A8846D353405DFC6D4F90524A40
71183	16246	79.314700000000002	79.329783000000006	52.567283000000003	52.549045999999997	Центральная	0103000020E610000001000000050000004703780B24D45340F3FFAA2347464A404703780B24D45340D449B6BA9C484A40B7F1272A1BD55340D449B6BA9C484A40B7F1272A1BD55340F3FFAA2347464A404703780B24D45340F3FFAA2347464A40
71019	16178	78.709146000000004	78.730418	52.472619999999999	52.463568000000002	Попасновская	0103000020E61000000100000005000000B685E7A562AD53406FBC3B32563B4A40B685E7A562AD5340BFB7E9CF7E3C4A40399A232BBFAE5340BFB7E9CF7E3C4A40399A232BBFAE53406FBC3B32563B4A40B685E7A562AD53406FBC3B32563B4A40
70157	16326	78.865595999999996	78.887119999999996	52.575887000000002	52.559252000000001	Советская	0103000020E6100000010000000500000019E3C3EC65B753407E1CCD9195474A4019E3C3EC65B7534085984BAAB6494A4029E8F692C6B8534085984BAAB6494A4029E8F692C6B853407E1CCD9195474A4019E3C3EC65B753407E1CCD9195474A40
71022	16472	78.903791999999996	78.925702000000001	52.546126999999998	52.526265000000002	Восточная	0103000020E61000000100000005000000BB9866BAD7B95340C503CAA65C434A40BB9866BAD7B95340363B527DE7454A40E0F599B33EBB5340363B527DE7454A40E0F599B33EBB5340C503CAA65C434A40BB9866BAD7B95340C503CAA65C434A40
71011	16861	79.016701999999995	79.028199999999998	52.570014	52.558902000000003	Садовая	0103000020E61000000100000005000000C7F143A511C15340A2D5C9198A474A40C7F143A511C153408E210038F6484A40D26F5F07CEC153408E210038F6484A40D26F5F07CEC15340A2D5C9198A474A40C7F143A511C15340A2D5C9198A474A40
70672	16094	78.90249	78.936886000000001	52.451791999999998	52.436537000000001	Ленина	0103000020E61000000100000005000000E4BD6A65C2B953403A3FC571E0374A40E4BD6A65C2B95340164CFC51D4394A402385B2F0F5BB5340164CFC51D4394A402385B2F0F5BB53403A3FC571E0374A40E4BD6A65C2B953403A3FC571E0374A40
69725	15736	78.904591999999994	78.964995000000002	52.585124	52.550770999999997	Советская	0103000020E61000000100000005000000490ED8D5E4B95340E84A04AA7F464A40490ED8D5E4B95340670DDE57E54A4A406D73637AC2BD5340670DDE57E54A4A406D73637AC2BD5340E84A04AA7F464A40490ED8D5E4B95340E84A04AA7F464A40
70188	15736	78.904591999999994	78.964995000000002	52.585124	52.550770999999997	Пушкина	0103000020E61000000100000005000000490ED8D5E4B95340E84A04AA7F464A40490ED8D5E4B95340670DDE57E54A4A406D73637AC2BD5340670DDE57E54A4A406D73637AC2BD5340E84A04AA7F464A40490ED8D5E4B95340E84A04AA7F464A40
70294	15736	78.904591999999994	78.964995000000002	52.585124	52.550770999999997	Песчаная	0103000020E61000000100000005000000490ED8D5E4B95340E84A04AA7F464A40490ED8D5E4B95340670DDE57E54A4A406D73637AC2BD5340670DDE57E54A4A406D73637AC2BD5340E84A04AA7F464A40490ED8D5E4B95340E84A04AA7F464A40
69823	15736	78.904591999999994	78.964995000000002	52.585124	52.550770999999997	Октябрьская	0103000020E61000000100000005000000490ED8D5E4B95340E84A04AA7F464A40490ED8D5E4B95340670DDE57E54A4A406D73637AC2BD5340670DDE57E54A4A406D73637AC2BD5340E84A04AA7F464A40490ED8D5E4B95340E84A04AA7F464A40
69718	15736	78.904591999999994	78.964995000000002	52.585124	52.550770999999997	Ломоносова	0103000020E61000000100000005000000490ED8D5E4B95340E84A04AA7F464A40490ED8D5E4B95340670DDE57E54A4A406D73637AC2BD5340670DDE57E54A4A406D73637AC2BD5340E84A04AA7F464A40490ED8D5E4B95340E84A04AA7F464A40
69885	15736	78.904591999999994	78.964995000000002	52.585124	52.550770999999997	Ленина	0103000020E61000000100000005000000490ED8D5E4B95340E84A04AA7F464A40490ED8D5E4B95340670DDE57E54A4A406D73637AC2BD5340670DDE57E54A4A406D73637AC2BD5340E84A04AA7F464A40490ED8D5E4B95340E84A04AA7F464A40
71008	16710	79.052778000000004	79.083967999999999	52.621822999999999	52.610773000000002	Центральная	0103000020E61000000100000005000000B1FCF9B660C35340D12346CF2D4E4A40B1FCF9B660C35340477364E5974F4A40467A51BB5FC55340477364E5974F4A40467A51BB5FC55340D12346CF2D4E4A40B1FCF9B660C35340D12346CF2D4E4A40
71185	16874	79.072640000000007	79.086600000000004	52.521602000000001	52.515064000000002	Амангельды	0103000020E610000001000000050000006A183E22A6C4534069ACFD9DED414A406A183E22A6C453409CC3B5DAC3424A405AF5B9DA8AC553409CC3B5DAC3424A405AF5B9DA8AC5534069ACFD9DED414A406A183E22A6C4534069ACFD9DED414A40
70319	15990	79.246437	79.278605999999996	52.638826999999999	52.622534000000002	Партизанская	0103000020E610000001000000050000008FE1B19FC5CF5340F452B131AF4F4A408FE1B19FC5CF5340A1664815C5514A400A9E42AED4D15340A1664815C5514A400A9E42AED4D15340F452B131AF4F4A408FE1B19FC5CF5340F452B131AF4F4A40
71186	16599	79.602044000000006	79.619812999999994	52.571809999999999	52.562733999999999	Центральная	0103000020E6100000010000000500000032B08EE387E65340732CEFAA07484A4032B08EE387E653404CC3F01131494A40AE282504ABE753404CC3F01131494A40AE282504ABE75340732CEFAA07484A4032B08EE387E65340732CEFAA07484A40
70943	16808	78.973896999999994	78.983518000000004	52.712479999999999	52.701518	Молодежная	0103000020E610000001000000050000000A2B155454BE534015C78157CB594A400A2B155454BE5340EC866D8B325B4A40C0417BF5F1BE5340EC866D8B325B4A40C0417BF5F1BE534015C78157CB594A400A2B155454BE534015C78157CB594A40
71010	16738	79.057377000000002	79.079952000000006	52.766593	52.750456	Советская	0103000020E61000000100000005000000BAA29410ACC35340228B34F10E604A40BAA29410ACC35340D82B2CB81F624A40FD4FFEEE1DC55340D82B2CB81F624A40FD4FFEEE1DC55340228B34F10E604A40BAA29410ACC35340228B34F10E604A40
70924	16122	79.065938000000003	79.090804000000006	52.465170000000001	52.457987000000003	Центральная	0103000020E610000001000000050000001364045438C45340207F69519F3A4A401364045438C45340488AC8B08A3B4A40259694BBCFC55340488AC8B08A3B4A40259694BBCFC55340207F69519F3A4A401364045438C45340207F69519F3A4A40
71187	16635	79.237596999999994	79.259534000000002	52.732579000000001	52.724361000000002	Целинная	0103000020E610000001000000050000002C280CCA34CF5340BABF7ADCB75C4A402C280CCA34CF5340425E0F26C55D4A40CE8C7E349CD05340425E0F26C55D4A40CE8C7E349CD05340BABF7ADCB75C4A402C280CCA34CF5340BABF7ADCB75C4A40
71299	16540	79.567808999999997	79.588820999999996	52.586432000000002	52.570272000000003	Восточная	0103000020E61000000100000005000000F7578FFB56E453408AE942ACFE484A40F7578FFB56E45340F8A92A34104B4A40AC8C463EAFE55340F8A92A34104B4A40AC8C463EAFE553408AE942ACFE484A40F7578FFB56E453408AE942ACFE484A40
71284	15648	81.081999999999994	81.099230000000006	53.954307999999997	53.945554999999999	Михайловичей	0103000020E610000001000000050000006891ED7C3F455440DEC83CF207F94A406891ED7C3F455440D427B9C326FA4A400E32C9C859465440D427B9C326FA4A400E32C9C859465440DEC83CF207F94A406891ED7C3F455440DEC83CF207F94A40
70324	15160	80.781388000000007	80.829061999999993	53.973452000000002	53.951256999999998	Крутихинская	0103000020E61000000100000005000000295FD04202325440A88B14CAC2F94A40295FD04202325440E71C3C139AFC4A40CE16105A0F355440E71C3C139AFC4A40CE16105A0F355440A88B14CAC2F94A40295FD04202325440A88B14CAC2F94A40
70782	15418	80.995249999999999	81.009478999999999	54.009352999999997	53.992427999999997	Центральная	0103000020E6100000010000000500000004560E2DB23F54403DD175E107FF4A4004560E2DB23F54404B8FA67A32014B40ECBFCE4D9B4054404B8FA67A32014B40ECBFCE4D9B4054403DD175E107FF4A4004560E2DB23F54403DD175E107FF4A40
71104	15607	80.617553000000001	80.636624999999995	54.012644000000002	54.003552999999997	Центральная	0103000020E61000000100000005000000FDA204FD85275440BE66B96C74004B40FDA204FD85275440CD3E8F519E014B4039B4C876BE285440CD3E8F519E014B4039B4C876BE285440BE66B96C74004B40FDA204FD85275440BE66B96C74004B40
71182	15557	81.248853999999994	81.272012000000004	54.059986000000002	54.048304999999999	Зеленая	0103000020E61000000100000005000000A4DE5339ED4F5440DC9DB5DB2E064B40A4DE5339ED4F5440E31B0A9FAD074B40A70705A568515440E31B0A9FAD074B40A70705A568515440DC9DB5DB2E064B40A4DE5339ED4F5440DC9DB5DB2E064B40
70314	15517	80.882925	80.935610999999994	54.085656999999998	54.059114000000001	Ленина	0103000020E6100000010000000500000088F4DBD7813854402D5E2C0C91074B4088F4DBD78138544034D6FECEF60A4B40C8B1F50CE13B544034D6FECEF60A4B40C8B1F50CE13B54402D5E2C0C91074B4088F4DBD7813854402D5E2C0C91074B40
69728	15460	81.187731999999997	81.232270999999997	53.989173000000001	53.945687	Ленинградская	0103000020E61000000100000005000000691A14CD034C54404DA088450CF94A40691A14CD034C5440098B8A389DFE4A40CA332F87DD4E5440098B8A389DFE4A40CA332F87DD4E54404DA088450CF94A40691A14CD034C54404DA088450CF94A40
71003	15362	81.224553999999998	81.249734000000004	53.848042999999997	53.828989999999997	Карасевская	0103000020E61000000100000005000000E78BBD175F4E5440035B25581CEA4A40E78BBD175F4E5440054D4BAC8CEC4A40C1AC50A4FB4F5440054D4BAC8CEC4A40C1AC50A4FB4F5440035B25581CEA4A40E78BBD175F4E5440035B25581CEA4A40
9771	15300	81.178830000000005	81.210494999999995	53.906326	53.879668000000002	Садовая	0103000020E61000000100000005000000CC6262F3714B54403BAB05F698F04A40CC6262F3714B5440DBC1887D02F44A402D3E05C0784D5440DBC1887D02F44A402D3E05C0784D54403BAB05F698F04A40CC6262F3714B54403BAB05F698F04A40
69882	15249	81.024005000000002	81.064590999999993	54.150758000000003	54.106197000000002	Гагарина	0103000020E61000000100000005000000317C444C8941544077F700DD970D4B40317C444C8941544021CEC3094C134B406B274A422244544021CEC3094C134B406B274A422244544077F700DD970D4B40317C444C8941544077F700DD970D4B40
69720	15207	80.749731999999995	80.811526999999998	54.065840999999999	54.028185999999998	Бурлинская	0103000020E61000000100000005000000F030ED9BFB2F54403F1A4E999B034B40F030ED9BFB2F544033DE567A6D084B408B34F10EF033544033DE567A6D084B408B34F10EF03354403F1A4E999B034B40F030ED9BFB2F54403F1A4E999B034B40
70644	1816	80.996086000000005	81.017295000000004	53.829165000000003	53.812454000000002	Целинная	0103000020E6100000010000000500000039807EDFBF3F544090C01F7EFEE74A4039807EDFBF3F544072FE261422EA4A4099D87C5C1B41544072FE261422EA4A4099D87C5C1B41544090C01F7EFEE74A4039807EDFBF3F544090C01F7EFEE74A40
71009	15057	81.177167999999995	81.194541000000001	54.037455999999999	54.025187000000003	Советская	0103000020E61000000100000005000000747973B8564B544066A4DE5339034B40747973B8564B5440FD84B35BCB044B40CB2E185C734C5440FD84B35BCB044B40CB2E185C734C544066A4DE5339034B40747973B8564B544066A4DE5339034B40
71304	1768	81.080904000000004	81.102059999999994	53.882741000000003	53.879157999999997	Большелоговская	0103000020E610000001000000050000006687F8872D4554402502D53F88F04A406687F8872D4554404FEB36A8FDF04A40B48EAA26884654404FEB36A8FDF04A40B48EAA26884654402502D53F88F04A406687F8872D4554402502D53F88F04A40
70291	14924	83.036886999999993	83.066468999999998	51.345767000000002	51.318952000000003	Березовая	0103000020E6100000010000000500000071A94A5B5CC25440357F4C6BD3A8494071A94A5B5CC254409D84D21742AC4940A94C310741C454409D84D21742AC4940A94C310741C45440357F4C6BD3A8494071A94A5B5CC25440357F4C6BD3A84940
69711	14456	82.838836000000001	82.883536000000007	51.698352999999997	51.672058999999997	Колхозная	0103000020E6100000010000000500000047AD307DAFB55440C1FD800706D6494047AD307DAFB55440200890A163D94940AD3594DA8BB85440200890A163D94940AD3594DA8BB85440C1FD800706D6494047AD307DAFB55440C1FD800706D64940
71365	14995	83.110844999999998	83.141064999999998	51.435242000000002	51.426442999999999	Молодежная	0103000020E61000000100000005000000357BA01518C75440D74D29AF95B64940357BA01518C754403EEC8502B6B749400E677E3507C954403EEC8502B6B749400E677E3507C95440D74D29AF95B64940357BA01518C75440D74D29AF95B64940
70770	14901	83.178254999999993	83.205663000000001	51.477573999999997	51.458201000000003	Самакаева	0103000020E610000001000000050000004DD6A88768CB54404CFF9254A6BA49404DD6A88768CB5440BFB5132521BD4940D3BF249529CD5440BFB5132521BD4940D3BF249529CD54404CFF9254A6BA49404DD6A88768CB54404CFF9254A6BA4940
70539	14680	83.11063	83.165543999999997	51.63532	51.608099000000003	Советская	0103000020E6100000010000000500000037FDD98F14C754407BDD2230D6CD494037FDD98F14C75440533F6F2A52D149402383DC4598CA5440533F6F2A52D149402383DC4598CA54407BDD2230D6CD494037FDD98F14C754407BDD2230D6CD4940
70803	1532	82.928073999999995	82.951286999999994	51.468290000000003	51.453491999999997	Школьная	0103000020E6100000010000000500000025917D9065BB5440B27F9E060CBA494025917D9065BB54409D853DEDF0BB49400987DEE2E1BC54409D853DEDF0BB49400987DEE2E1BC5440B27F9E060CBA494025917D9065BB5440B27F9E060CBA4940
70305	1479	82.678072999999998	82.717392000000004	51.471628000000003	51.451622999999998	Советская	0103000020E610000001000000050000003DD34B8C65AB54408A8F4FC8CEB949403DD34B8C65AB54405FF0694E5EBC49405F9A22C0E9AD54405FF0694E5EBC49405F9A22C0E9AD54408A8F4FC8CEB949403DD34B8C65AB54408A8F4FC8CEB94940
70104	1731	83.237067999999994	83.280313000000007	51.710352999999998	51.677052000000003	Мира	0103000020E6100000010000000500000066BB421F2CCF544080D8D2A3A9D6494066BB421F2CCF5440C8CEDBD8ECDA494032E9EFA5F0D15440C8CEDBD8ECDA494032E9EFA5F0D1544080D8D2A3A9D6494066BB421F2CCF544080D8D2A3A9D64940
70172	14735	82.922872999999996	82.967276999999996	51.630048000000002	51.592042999999997	Ленина	0103000020E610000001000000050000002157EA5910BB5440B169A510C8CB49402157EA5910BB54408274B169A5D04940124BCADDE7BD54408274B169A5D04940124BCADDE7BD5440B169A510C8CB49402157EA5910BB5440B169A510C8CB4940
70290	14844	82.978729999999999	83.006873999999996	51.564791	51.548938999999997	Школьный переулок	0103000020E610000001000000050000004D672783A3BE5440DD3F16A243C649404D672783A3BE54409E094D124BC84940554CA59F70C054409E094D124BC84940554CA59F70C05440DD3F16A243C649404D672783A3BE5440DD3F16A243C64940
69918	1434	82.704582000000002	82.773662999999999	51.682608999999999	51.652650999999999	Садовая	0103000020E610000001000000050000006BD619DF17AD5440D15966118AD349406BD619DF17AD5440467A51BB5FD7494004C8D0B183B15440467A51BB5FD7494004C8D0B183B15440D15966118AD349406BD619DF17AD5440D15966118AD34940
69659	1434	82.704582000000002	82.773662999999999	51.682608999999999	51.652650999999999	Ленина	0103000020E610000001000000050000006BD619DF17AD5440D15966118AD349406BD619DF17AD5440467A51BB5FD7494004C8D0B183B15440467A51BB5FD7494004C8D0B183B15440D15966118AD349406BD619DF17AD5440D15966118AD34940
69665	14364	82.638052999999999	82.656585000000007	51.726835999999999	51.714348999999999	Школьная	0103000020E61000000100000005000000570740DCD5A854401477BCC96FDB4940570740DCD5A8544019C748F608DD4940D482177D05AA544019C748F608DD4940D482177D05AA54401477BCC96FDB4940570740DCD5A854401477BCC96FDB4940
70146	1649	82.932449000000005	82.983176999999998	51.870607	51.821818	Гагарина	0103000020E61000000100000005000000070C923EADBB5440CFA10C5531E94940070C923EADBB54409755D80C70EF49407B4B395FECBE54409755D80C70EF49407B4B395FECBE5440CFA10C5531E94940070C923EADBB5440CFA10C5531E94940
69909	1649	82.932449000000005	82.983176999999998	51.870607	51.821818	40 лет Победы	0103000020E61000000100000005000000070C923EADBB5440CFA10C5531E94940070C923EADBB54409755D80C70EF49407B4B395FECBE54409755D80C70EF49407B4B395FECBE5440CFA10C5531E94940070C923EADBB5440CFA10C5531E94940
70682	14234	82.572539000000006	82.599911000000006	51.598013000000002	51.574812000000001	Новая	0103000020E61000000100000005000000D02B9E7AA4A4544097AC8A7093C94940D02B9E7AA4A454409BCAA2B08BCC4940AF601BF164A654409BCAA2B08BCC4940AF601BF164A6544097AC8A7093C94940D02B9E7AA4A4544097AC8A7093C94940
71178	14035	86.329383000000007	86.344690999999997	52.590961999999998	52.578459000000002	Центральная	0103000020E61000000100000005000000F0366F9C14955540D789CBF10A4A4A40F0366F9C14955540E1968FA4A44B4A406F0ED76A0F965540E1968FA4A44B4A406F0ED76A0F965540D789CBF10A4A4A40F0366F9C14955540D789CBF10A4A4A40
70520	1379	86.314642000000006	86.358444000000006	52.557099999999998	52.535096000000003	Центральная	0103000020E61000000100000005000000ADFC321823945540371C96067E444A40ADFC321823945540014D840D4F474A40A35C1ABFF0965540014D840D4F474A40A35C1ABFF0965540371C96067E444A40ADFC321823945540371C96067E444A40
69845	1293	85.951273999999998	85.980406000000002	52.193882000000002	52.163454000000002	Советская	0103000020E610000001000000050000003FE257ACE17C55404033880FEC144A403FE257ACE17C55403CA41820D1184A4057B3CEF8BE7E55403CA41820D1184A4057B3CEF8BE7E55404033880FEC144A403FE257ACE17C55404033880FEC144A40
71080	13240	86.183479000000005	86.202370999999999	52.255536999999997	52.246715999999999	Дорожная	0103000020E610000001000000050000002E20B41EBE8B554031B3CF63941F4A402E20B41EBE8B55407FF5B86FB5204A402AAA7EA5F38C55407FF5B86FB5204A402AAA7EA5F38C554031B3CF63941F4A402E20B41EBE8B554031B3CF63941F4A40
70767	13387	86.034817000000004	86.055119000000005	52.323799000000001	52.316896	Центральная	0103000020E61000000100000005000000121615713A825540DA1D520C90284A40121615713A8255401FBDE13E72294A40D998D711878355401FBDE13E72294A40D998D71187835540DA1D520C90284A40121615713A825540DA1D520C90284A40
71004	13320	86.332294000000005	86.354752000000005	52.199948999999997	52.179929999999999	Заречная	0103000020E610000001000000050000000DAA0D4E44955540DEC83CF207174A400DAA0D4E4495554017EFC7ED97194A40338CBB41B496554017EFC7ED97194A40338CBB41B4965540DEC83CF207174A400DAA0D4E44955540DEC83CF207174A40
71083	12956	85.873047999999997	85.882238000000001	52.239016999999997	52.226309000000001	Центральная	0103000020E61000000100000005000000A5F5B704E07755402EE57CB1F71C4A40A5F5B704E07755401118EB1B981E4A4076525F96767855401118EB1B981E4A4076525F96767855402EE57CB1F71C4A40A5F5B704E07755402EE57CB1F71C4A40
70382	1279	85.950896	85.9726	52.576931999999999	52.550809000000001	Центральная	0103000020E610000001000000050000006C79E57ADB7C5540D6ABC8E880464A406C79E57ADB7C5540080264E8D8494A40BC0512143F7E5540080264E8D8494A40BC0512143F7E5540D6ABC8E880464A406C79E57ADB7C5540D6ABC8E880464A40
71412	59442	85.779793999999995	86.805598000000003	52.630099000000001	52.014899	Центральная	0103000020E610000001000000050000007DE71725E87155401EDFDE35E8014A407DE71725E8715540041F8315A7504A4046EEE9EA8EB35540041F8315A7504A4046EEE9EA8EB355401EDFDE35E8014A407DE71725E87155401EDFDE35E8014A40
70374	831	86.171028000000007	86.199208999999996	52.163083999999998	52.152099999999997	Центральная	0103000020E61000000100000005000000D2AC6C1FF28A55405DDC460378134A40D2AC6C1FF28A55401C40BFEFDF144A4068041BD7BF8C55401C40BFEFDF144A4068041BD7BF8C55405DDC460378134A40D2AC6C1FF28A55405DDC460378134A40
70918	12985	85.938715000000002	85.962277999999998	52.228785999999999	52.219909999999999	Береговая	0103000020E61000000100000005000000F05014E8137C55401C08C902261C4A40F05014E8137C55402EE411DC481D4A4042EA76F6957D55402EE411DC481D4A4042EA76F6957D55401C08C902261C4A40F05014E8137C55401C08C902261C4A40
70764	12914	85.881096999999997	85.895075000000006	52.209271000000001	52.203795999999997	Автомобилистов	0103000020E61000000100000005000000A3E6ABE4637855401E87C1FC151A4A40A3E6ABE46378554028806264C91A4A40E71DA7E84879554028806264C91A4A40E71DA7E8487955401E87C1FC151A4A40A3E6ABE4637855401E87C1FC151A4A40
70774	13405	86.115486000000004	86.130649000000005	52.313834999999997	52.304541	переулок Клубный	0103000020E610000001000000050000005649641F6487554044A51133FB264A405649641F648755408AABCABE2B284A4054909F8D5C8855408AABCABE2B284A4054909F8D5C88554044A51133FB264A405649641F6487554044A51133FB264A40
70805	13883	86.448562999999993	86.469798999999995	52.558464000000001	52.542243999999997	Центральная	0103000020E6100000010000000500000085CC9541B59C5540E2395B4068454A4085CC9541B59C554026FF93BF7B474A40622CD32F119E554026FF93BF7B474A40622CD32F119E5540E2395B4068454A4085CC9541B59C5540E2395B4068454A40
70765	13465	86.114487999999994	86.144429000000002	52.345283000000002	52.339440000000003	Зеленая	0103000020E6100000010000000500000034F279C553875540257A19C5722B4A4034F279C553875540B16EBC3B322C4A4004E621533E895540B16EBC3B322C4A4004E621533E895540257A19C5722B4A4034F279C553875540257A19C5722B4A40
71173	13599	86.119600000000005	86.143907999999996	52.60642	52.580112	Центральная	0103000020E610000001000000050000008126C286A787554032022A1C414A4A408126C286A7875540F6D1A92B9F4D4A407F68E6C935895540F6D1A92B9F4D4A407F68E6C93589554032022A1C414A4A408126C286A787554032022A1C414A4A40
69881	13036	86.161164999999997	86.222797999999997	52.314000999999998	52.279164000000002	пер.Рабочий	0103000020E61000000100000005000000A1100187508A55403B1C5DA5BB234A40A1100187508A5540A5F44C2F31284A404FE78A52428E5540A5F44C2F31284A404FE78A52428E55403B1C5DA5BB234A40A1100187508A55403B1C5DA5BB234A40
69713	13036	86.161164999999997	86.222797999999997	52.314000999999998	52.279164000000002	Юбилейная	0103000020E61000000100000005000000A1100187508A55403B1C5DA5BB234A40A1100187508A5540A5F44C2F31284A404FE78A52428E5540A5F44C2F31284A404FE78A52428E55403B1C5DA5BB234A40A1100187508A55403B1C5DA5BB234A40
69911	13036	86.161164999999997	86.222797999999997	52.314000999999998	52.279164000000002	Советская	0103000020E61000000100000005000000A1100187508A55403B1C5DA5BB234A40A1100187508A5540A5F44C2F31284A404FE78A52428E5540A5F44C2F31284A404FE78A52428E55403B1C5DA5BB234A40A1100187508A55403B1C5DA5BB234A40
71005	13749	86.071612000000002	86.090727999999999	52.152304000000001	52.128205999999999	Алтухова	0103000020E6100000010000000500000013807F4A958455405393E00D69104A4013807F4A9584554066868DB27E134A403735D07CCE85554066868DB27E134A403735D07CCE8555405393E00D69104A4013807F4A958455405393E00D69104A40
71268	13181	86.296936000000002	86.313428999999999	52.257168999999998	52.245547000000002	переулок Школьный	0103000020E610000001000000050000005340DAFF00935540C25087156E1F4A405340DAFF00935540C345EEE9EA204A408D2782380F945540C345EEE9EA204A408D2782380F945540C25087156E1F4A405340DAFF00935540C25087156E1F4A40
71001	13543	86.071109000000007	86.085239000000001	52.479992000000003	52.467435999999999	Центральная	0103000020E61000000100000005000000E25CC30C8D8455408D7C5EF1D43B4A40E25CC30C8D845540BB2BBB60703D4A400056478E74855540BB2BBB60703D4A400056478E748555408D7C5EF1D43B4A40E25CC30C8D8455408D7C5EF1D43B4A40
71002	13821	86.380875000000003	86.412764999999993	52.467517999999998	52.450524000000001	Центральная	0103000020E610000001000000050000004C3789416098554014083BC5AA394A404C378941609855404A253CA1D73B4A40BDFBE3BD6A9A55404A253CA1D73B4A40BDFBE3BD6A9A554014083BC5AA394A404C3789416098554014083BC5AA394A40
71176	13684	86.061892	86.071871999999999	52.163504000000003	52.158239000000002	Советская	0103000020E6100000010000000500000094F8DC09F6835540D3F9F02C41144A4094F8DC09F6835540F261F6B2ED144A40E15F048D99845540F261F6B2ED144A40E15F048D99845540D3F9F02C41144A4094F8DC09F6835540D3F9F02C41144A40
69661	12862	85.818089000000001	85.853257999999997	52.30312	52.263761000000002	Победы	0103000020E61000000100000005000000E90DF7915B745540EA7AA2EBC2214A40E90DF7915B745540BB61DBA2CC264A40394371C79B765540BB61DBA2CC264A40394371C79B765540EA7AA2EBC2214A40E90DF7915B745540EA7AA2EBC2214A40
69846	778	85.803805999999994	85.846539000000007	52.359507999999998	52.337254999999999	Советская	0103000020E610000001000000050000000795B88E71735540CCB4FD2B2B2B4A400795B88E717355403F53AF5B042E4A4078F2E9B12D7655403F53AF5B042E4A4078F2E9B12D765540CCB4FD2B2B2B4A400795B88E71735540CCB4FD2B2B2B4A40
71361	13971	86.551034000000001	86.569422000000003	52.554898999999999	52.533683000000003	Центральная	0103000020E61000000100000005000000FB3E1C2444A3554031B77BB94F444A40FB3E1C2444A35540A3CA30EE06474A40DEE7F86871A45540A3CA30EE06474A40DEE7F86871A4554031B77BB94F444A40FB3E1C2444A3554031B77BB94F444A40
71386	59439	84.206097999999997	85.125793999999999	53.557695000000002	53.090795999999997	Центральная	0103000020E610000001000000050000005871AAB5300D5540C64D0D349F8B4A405871AAB5300D55404512BD8C62C74A401D0247020D4855404512BD8C62C74A401D0247020D485540C64D0D349F8B4A405871AAB5300D5540C64D0D349F8B4A40
70322	12178	84.322888000000006	84.348769000000004	53.314073	53.302149999999997	Центральная	0103000020E6100000010000000500000056116E32AA145540423EE8D9ACA64A4056116E32AA1455403FC7478B33A84A40F436363B521655403FC7478B33A84A40F436363B52165540423EE8D9ACA64A4056116E32AA145540423EE8D9ACA64A40
71505	59471	84.851376000000002	84.872729000000007	53.321275	53.306297999999998	Советская	0103000020E610000001000000050000005B26C3F17C365540446ADAC534A74A405B26C3F17C365540DE02098A1FA94A405551BCCADA375540DE02098A1FA94A405551BCCADA375540446ADAC534A74A405B26C3F17C365540446ADAC534A74A40
70995	12687	84.351015000000004	84.379069000000001	53.251573999999998	53.242747999999999	Советская	0103000020E61000000100000005000000F3599E0777165540AF95D05D129F4A40F3599E07771655400F43AB9333A04A405B7B9FAA421855400F43AB9333A04A405B7B9FAA42185540AF95D05D129F4A40F3599E0777165540AF95D05D129F4A40
70761	11786	84.476913999999994	84.498616999999996	53.361097000000001	53.351132999999997	Центральная	0103000020E610000001000000050000004A404CC2851E5540EFC517EDF1AC4A404A404CC2851E554084D72E6D38AE4A40B20E4757E91F554084D72E6D38AE4A40B20E4757E91F5540EFC517EDF1AC4A404A404CC2851E5540EFC517EDF1AC4A40
70678	11902	84.620590000000007	84.670293999999998	53.223894000000001	53.197194000000003	Школьная	0103000020E61000000100000005000000618E1EBFB7275540D57B2AA73D994A40618E1EBFB7275540A4E2FF8EA89C4A401F2DCE18E62A5540A4E2FF8EA89C4A401F2DCE18E62A5540D57B2AA73D994A40618E1EBFB7275540D57B2AA73D994A40
70997	12672	84.728711000000004	84.763026999999994	53.424084999999998	53.410904000000002	Верхняя	0103000020E61000000100000005000000124F7633A32E5540D6E5948098B44A40124F7633A32E5540B1DCD26A48B64A40C2BD326FD5305540B1DCD26A48B64A40C2BD326FD5305540D6E5948098B44A40124F7633A32E5540D6E5948098B44A40
71358	12139	84.346801999999997	84.384862999999996	53.183258000000002	53.167529999999999	Школьная	0103000020E61000000100000005000000FE0B040132165540A88C7F9F71954A40FE0B0401321655407D5D86FF74974A40309C6B98A11855407D5D86FF74974A40309C6B98A1185540A88C7F9F71954A40FE0B040132165540A88C7F9F71954A40
70990	12065	84.489453999999995	84.515495999999999	53.221344000000002	53.208359000000002	Центральная	0103000020E610000001000000050000005EB9DE36531F5540E469F981AB9A4A405EB9DE36531F55403A950C00559C4A40014EEFE2FD2055403A950C00559C4A40014EEFE2FD205540E469F981AB9A4A405EB9DE36531F5540E469F981AB9A4A40
69666	685	84.574838999999997	84.615560000000002	53.212964999999997	53.186290999999997	Тельмана	0103000020E61000000100000005000000C85D8429CA24554002452C62D8974A40C85D8429CA245540A818E76F429B4A40732EC55565275540A818E76F429B4A40732EC5556527554002452C62D8974A40C85D8429CA24554002452C62D8974A40
69712	685	84.574838999999997	84.615560000000002	53.212964999999997	53.186290999999997	Республики	0103000020E61000000100000005000000C85D8429CA24554002452C62D8974A40C85D8429CA245540A818E76F429B4A40732EC55565275540A818E76F429B4A40732EC5556527554002452C62D8974A40C85D8429CA24554002452C62D8974A40
70514	11973	84.379688999999999	84.423805000000002	53.364401999999998	53.345827999999997	Кооперативная	0103000020E61000000100000005000000A96917D34C1855404205871744AC4A40A96917D34C1855406A4C88B9A4AE4A4067B8019F1F1B55406A4C88B9A4AE4A4067B8019F1F1B55404205871744AC4A40A96917D34C1855404205871744AC4A40
71364	12536	84.668442999999996	84.681612999999999	53.330998999999998	53.324641999999997	Центральная	0103000020E610000001000000050000005E0F26C5C72A55403A747ADE8DA94A405E0F26C5C72A55401D01DC2C5EAA4A40D2E1218C9F2B55401D01DC2C5EAA4A40D2E1218C9F2B55403A747ADE8DA94A405E0F26C5C72A55403A747ADE8DA94A40
70534	12302	84.941917000000004	84.993148000000005	53.394396	53.379224999999998	Победы	0103000020E61000000100000005000000F9A23D5E483C5540AD69DE718AB04A40F9A23D5E483C55402CD670917BB24A409F05A1BC8F3F55402CD670917BB24A409F05A1BC8F3F5540AD69DE718AB04A40F9A23D5E483C5540AD69DE718AB04A40
71094	12297	84.366690000000006	84.380902000000006	53.291370000000001	53.284441999999999	Садовая	0103000020E610000001000000050000004C7155D977175540EECD6F9868A44A404C7155D9771755408C84B69C4BA54A40C93EC8B2601855408C84B69C4BA54A40C93EC8B260185540EECD6F9868A44A404C7155D977175540EECD6F9868A44A40
70311	11629	84.548616999999993	84.613061999999999	53.379680999999998	53.341709999999999	Рабочая	0103000020E61000000100000005000000E5417A8A1C235540AB5B3D27BDAB4A40E5417A8A1C235540CFF4126399B04A40E71A66683C275540CFF4126399B04A40E71A66683C275540AB5B3D27BDAB4A40E5417A8A1C235540AB5B3D27BDAB4A40
70404	11629	84.548616999999993	84.613061999999999	53.379680999999998	53.341709999999999	Луговая	0103000020E61000000100000005000000E5417A8A1C235540AB5B3D27BDAB4A40E5417A8A1C235540CFF4126399B04A40E71A66683C275540CFF4126399B04A40E71A66683C275540AB5B3D27BDAB4A40E5417A8A1C235540AB5B3D27BDAB4A40
70152	11629	84.548616999999993	84.613061999999999	53.379680999999998	53.341709999999999	Комсомольская	0103000020E61000000100000005000000E5417A8A1C235540AB5B3D27BDAB4A40E5417A8A1C235540CFF4126399B04A40E71A66683C275540CFF4126399B04A40E71A66683C275540AB5B3D27BDAB4A40E5417A8A1C235540AB5B3D27BDAB4A40
70459	12042	84.408497999999994	84.440989999999999	53.225177000000002	53.213267000000002	Центральная	0103000020E61000000100000005000000CF9ECBD4241A5540742843554C9B4A40CF9ECBD4241A5540DC679599D29C4A403CF71E2E391C5540DC679599D29C4A403CF71E2E391C5540742843554C9B4A40CF9ECBD4241A5540742843554C9B4A40
71172	12405	84.763225000000006	84.800647999999995	53.346193	53.334290000000003	Рабочая	0103000020E61000000100000005000000569FABADD83055409FB0C403CAAA4A40569FABADD8305540548D5E0D50AC4A40E6E61BD13D335540548D5E0D50AC4A40E6E61BD13D3355409FB0C403CAAA4A40569FABADD83055409FB0C403CAAA4A40
70999	12778	84.483732000000003	84.536696000000006	53.466346000000001	53.449193999999999	Садовая	0103000020E61000000100000005000000D6011077F51E55409BC761307FB94A40D6011077F51E55406A4FC939B1BB4A4038F92D3A592255406A4FC939B1BB4A4038F92D3A592255409BC761307FB94A40D6011077F51E55409BC761307FB94A40
71168	12207	84.353601999999995	84.370633999999995	53.345574999999997	53.338538	Школьная	0103000020E610000001000000050000003673486AA1165540043A933655AB4A403673486AA116554058A835CD3BAC4A404832AB77B817554058A835CD3BAC4A404832AB77B8175540043A933655AB4A403673486AA1165540043A933655AB4A40
70993	12539	84.621947000000006	84.668137999999999	53.503304999999997	53.479101	Молодежная	0103000020E610000001000000050000001A36CAFACD2755408E3D7B2E53BD4A401A36CAFACD275540E674594C6CC04A40C0CDE2C5C22A5540E674594C6CC04A40C0CDE2C5C22A55408E3D7B2E53BD4A401A36CAFACD2755408E3D7B2E53BD4A40
70763	12640	84.747620999999995	84.792518999999999	53.198306000000002	53.178401000000001	Центральная	0103000020E610000001000000050000006133C005D92F55406F490ED8D5964A406133C005D92F5540E04C4C1762994A405A9D9CA1B8325540E04C4C1762994A405A9D9CA1B83255406F490ED8D5964A406133C005D92F55406F490ED8D5964A40
70996	12744	84.304293000000001	84.328897999999995	53.288048000000003	53.280074999999997	Элеваторная	0103000020E61000000100000005000000B6D9588979135540AEB6627FD9A34A40B6D9588979135540D0D6C1C1DEA44A40116E32AA0C155540D0D6C1C1DEA44A40116E32AA0C155540AEB6627FD9A34A40B6D9588979135540AEB6627FD9A34A40
69708	10995	79.222874000000004	79.246292999999994	52.262587000000003	52.246533999999997	Пушкина	0103000020E610000001000000050000003D484F9143CE534010AD156D8E1F4A403D484F9143CE534069AD68739C214A40F50EB743C3CF534069AD68739C214A40F50EB743C3CF534010AD156D8E1F4A403D484F9143CE534010AD156D8E1F4A40
69656	11018	79.243841000000003	79.292529000000002	52.140084999999999	52.120266000000001	Октябрьская	0103000020E61000000100000005000000221B48179BCF53400E6954E0640F4A40221B48179BCF534080D4264EEE114A406C088ECBB8D2534080D4264EEE114A406C088ECBB8D253400E6954E0640F4A40221B48179BCF53400E6954E0640F4A40
70994	11586	79.335145999999995	79.395476000000002	52.056224	52.038964999999997	Пролетарская	0103000020E61000000100000005000000A758350873D5534025581CCEFC044A40A758350873D553400AA0185932074A409696917A4FD953400AA0185932074A409696917A4FD9534025581CCEFC044A40A758350873D5534025581CCEFC044A40
71150	11139	79.051691000000005	79.061841999999999	52.356675000000003	52.347009999999997	Восточная	0103000020E61000000100000005000000D89FC4E74EC3534046B1DCD26A2C4A40D89FC4E74EC353408126C286A72D4A403BE12538F5C353408126C286A72D4A403BE12538F5C3534046B1DCD26A2C4A40D89FC4E74EC3534046B1DCD26A2C4A40
70662	11484	79.524186999999998	79.560074999999998	52.250669000000002	52.231361999999997	Кирова	0103000020E61000000100000005000000417FA1478CE15340C1C41F459D1D4A40417FA1478CE153407E8FFAEB15204A40A913D044D8E353407E8FFAEB15204A40A913D044D8E35340C1C41F459D1D4A40417FA1478CE15340C1C41F459D1D4A40
71281	11263	79.324572000000003	79.338667000000001	52.463892000000001	52.451808	Чапаева	0103000020E61000000100000005000000A14CA3C9C5D453401C0934D8D4394A40A14CA3C9C5D45340227024D0603B4A40014F5AB8ACD55340227024D0603B4A40014F5AB8ACD553401C0934D8D4394A40A14CA3C9C5D453401C0934D8D4394A40
70510	11195	79.326324	79.347730999999996	52.430294000000004	52.402495999999999	Пролетарская	0103000020E6100000010000000500000098F90E7EE2D45340AA622AFD84334A4098F90E7EE2D4534020D5B0DF13374A408B33863941D6534020D5B0DF13374A408B33863941D65340AA622AFD84334A4098F90E7EE2D45340AA622AFD84334A40
71155	11358	79.592764000000003	79.611647000000005	52.465933	52.453119999999998	Западная	0103000020E61000000100000005000000C18F6AD8EFE55340EE940ED6FF394A40C18F6AD8EFE5534047904AB1A33B4A40946C753925E7534047904AB1A33B4A40946C753925E75340EE940ED6FF394A40C18F6AD8EFE55340EE940ED6FF394A40
69996	10859	79.133967999999996	79.209138999999993	52.271642999999997	52.227395999999999	Урицкого	0103000020E6100000010000000500000079AD84EE92C85340E09EE74F1B1D4A4079AD84EE92C85340FA97A432C5224A405C548B8862CD5340FA97A432C5224A405C548B8862CD5340E09EE74F1B1D4A4079AD84EE92C85340E09EE74F1B1D4A40
69910	10859	79.133967999999996	79.209138999999993	52.271642999999997	52.227395999999999	Делегатская	0103000020E6100000010000000500000079AD84EE92C85340E09EE74F1B1D4A4079AD84EE92C85340FA97A432C5224A405C548B8862CD5340FA97A432C5224A405C548B8862CD5340E09EE74F1B1D4A4079AD84EE92C85340E09EE74F1B1D4A40
70663	11448	79.766560999999996	79.808269999999993	52.259776000000002	52.235405	Центральная	0103000020E61000000100000005000000E658DE550FF153404E2844C0211E4A40E658DE550FF153409224085740214A40A01518B2BAF353409224085740214A40A01518B2BAF353404E2844C0211E4A40E658DE550FF153404E2844C0211E4A40
70509	11158	79.279037000000002	79.307962000000003	52.379005999999997	52.359909000000002	Кирова	0103000020E61000000100000005000000EF5701BEDBD153409E44847F112E4A40EF5701BEDBD153406F7EC34483304A404A9A3FA6B5D353406F7EC34483304A404A9A3FA6B5D353409E44847F112E4A40EF5701BEDBD153409E44847F112E4A40
71252	11295	79.628337999999999	79.645270999999994	52.406325000000002	52.395819000000003	Школьный	0103000020E61000000100000005000000613596B036E8534056116E32AA324A40613596B036E853400B46257502344A40A983BC1E4CE953400B46257502344A40A983BC1E4CE9534056116E32AA324A40613596B036E8534056116E32AA324A40
70758	11534	79.567072999999993	79.583566000000005	52.130947999999997	52.123871000000001	Центральная	0103000020E61000000100000005000000745C8DEC4AE453401FF64201DB0F4A40745C8DEC4AE4534001BD70E7C2104A40AF43352559E5534001BD70E7C2104A40AF43352559E553401FF64201DB0F4A40745C8DEC4AE453401FF64201DB0F4A40
70150	11087	78.928712000000004	78.974005000000005	52.283251999999997	52.260503999999997	Центральная	0103000020E61000000100000005000000C7D9740470BB5340143DF03158214A40C7D9740470BB53406743FE9941244A40FE48111956BE53406743FE9941244A40FE48111956BE5340143DF03158214A40C7D9740470BB5340143DF03158214A40
71356	10614	80.672332999999995	80.695536000000004	53.637065999999997	53.625895999999997	Сибирская	0103000020E6100000010000000500000061C1FD80072B54403E59315C1DD04A4061C1FD80072B54405FB2F1608BD14A40344C6DA9832C54405FB2F1608BD14A40344C6DA9832C54403E59315C1DD04A4061C1FD80072B54403E59315C1DD04A40
70398	10746	80.914321000000001	80.954663999999994	53.689357999999999	53.666434000000002	Центральная	0103000020E61000000100000005000000F2423A3C843A5440A37895B54DD54A40F2423A3C843A5440349E08E23CD84A40C9AA0837193D5440349E08E23CD84A40C9AA0837193D5440A37895B54DD54A40F2423A3C843A5440A37895B54DD54A40
71370	10827	80.876115999999996	80.898060999999998	53.717928000000001	53.710084000000002	Тамбовская	0103000020E6100000010000000500000026E0D74812385440D9B45208E4DA4A4026E0D74812385440FC709010E5DB4A400934D8D479395440FC709010E5DB4A400934D8D479395440D9B45208E4DA4A4026E0D74812385440D9B45208E4DA4A40
70312	9826	81.444299999999998	81.497524999999996	53.932876999999998	53.911772999999997	Мичурина	0103000020E61000000100000005000000386744696F5C54401A3048FAB4F44A40386744696F5C54406518778368F74A4050FC1873D75F54406518778368F74A4050FC1873D75F54401A3048FAB4F44A40386744696F5C54401A3048FAB4F44A40
71143	10360	81.314960999999997	81.340903999999995	53.522266000000002	53.506438000000003	Центральная	0103000020E61000000100000005000000FDA02E5228545440D0B9DBF5D2C04A40FDA02E522854544008E8BE9CD9C24A40D6C4025FD155544008E8BE9CD9C24A40D6C4025FD1555440D0B9DBF5D2C04A40FDA02E5228545440D0B9DBF5D2C04A40
70502	10297	81.383430000000004	81.429226	53.580117000000001	53.553190999999998	Гагарина	0103000020E610000001000000050000008A93FB1D8A58544084B872F6CEC64A408A93FB1D8A585440446D1B4641CA4A40F2255470785B5440446D1B4641CA4A40F2255470785B544084B872F6CEC64A408A93FB1D8A58544084B872F6CEC64A40
70693	10538	80.744637999999995	80.789400999999998	53.568401999999999	53.550811000000003	Центральная	0103000020E61000000100000005000000F7562426A82F544077A38FF980C64A40F7562426A82F5440917D9065C1C84A40809BC58B85325440917D9065C1C84A40809BC58B8532544077A38FF980C64A40F7562426A82F544077A38FF980C64A40
71359	10281	81.513596000000007	81.533314000000004	53.547958999999999	53.538012000000002	Совхозная	0103000020E61000000100000005000000D0D6C1C1DE605440836DC493DDC44A40D0D6C1C1DE6054404146408523C64A40EF1F0BD1216254404146408523C64A40EF1F0BD121625440836DC493DDC44A40D0D6C1C1DE605440836DC493DDC44A40
70973	9744	81.110710999999995	81.132890000000003	53.723495999999997	53.708570000000002	Центральная	0103000020E61000000100000005000000AD1397E3154754409F76F86BB2DA4A40AD1397E315475440B66455849BDC4A40CAFD0E4581485440B66455849BDC4A40CAFD0E45814854409F76F86BB2DA4A40AD1397E3154754409F76F86BB2DA4A40
70989	10059	81.667710999999997	81.687545999999998	53.664306000000003	53.649540999999999	Озерная	0103000020E610000001000000050000007C0BEBC6BB6A5440A034D42824D34A407C0BEBC6BB6A5440AF44A0FA07D54A40B81FF0C0006C5440AF44A0FA07D54A40B81FF0C0006C5440A034D42824D34A407C0BEBC6BB6A5440A034D42824D34A40
69709	10726	80.849714000000006	80.890344999999996	53.609091999999997	53.586044999999999	Центральная	0103000020E61000000100000005000000043DD4B661365440FE7DC68503CB4A40043DD4B661365440AB2006BAF6CD4A400E4A9869FB385440AB2006BAF6CD4A400E4A9869FB385440FE7DC68503CB4A40043DD4B661365440FE7DC68503CB4A40
71135	10108	81.532452000000006	81.547264999999996	53.694823	53.684170000000002	юбилейная	0103000020E6100000010000000500000026AC8DB113625440C173EFE192D74A4026AC8DB1136254401AC1C6F5EFD84A40B54FC763066354401AC1C6F5EFD84A40B54FC76306635440C173EFE192D74A4026AC8DB113625440C173EFE192D74A40
71352	9967	81.386628000000002	81.412966999999995	54.045603	54.036408999999999	Январская	0103000020E61000000100000005000000F2ED5D83BE585440D923D40CA9044B40F2ED5D83BE585440BCCCB051D6054B40F1D4230D6E5A5440BCCCB051D6054B40F1D4230D6E5A5440D923D40CA9044B40F2ED5D83BE585440D923D40CA9044B40
70394	10159	81.606894999999994	81.632891999999998	53.518973000000003	53.505367	Школьная	0103000020E61000000100000005000000C746205ED766544023BDA8DDAFC04A40C746205ED7665440E6400FB56DC24A409A79724D81685440E6400FB56DC24A409A79724D8168544023BDA8DDAFC04A40C746205ED766544023BDA8DDAFC04A40
70155	10447	81.050200000000004	81.100335000000001	53.539757000000002	53.496980000000001	Каменская	0103000020E6100000010000000500000097900F7A364354400F62670A9DBF4A4097900F7A36435440BF64E3C116C54A403AE97DE36B465440BF64E3C116C54A403AE97DE36B4654400F62670A9DBF4A4097900F7A364354400F62670A9DBF4A40
70756	9899	81.469345000000004	81.487634999999997	53.977122000000001	53.962361000000001	Центральная	0103000020E61000000100000005000000A2629CBF095E544012F92EA52EFB4A40A2629CBF095E5440DF196D5512FD4A40A3586E69355F5440DF196D5512FD4A40A3586E69355F544012F92EA52EFB4A40A2629CBF095E544012F92EA52EFB4A40
69980	20390	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Северная	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69950	20390	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Пушкина	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
69961	20390	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Первомайская	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70108	20390	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Ленина	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70421	20390	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Кондратюка	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70552	20390	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Колесникова	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
70105	20390	81.263676000000004	81.367745999999997	53.827348000000001	53.751722999999998	Гоголя	0103000020E610000001000000050000005E2F4D11E05054405453927538E04A405E2F4D11E05054409C340D8AE6E94A4007CF8426895754409C340D8AE6E94A4007CF8426895754405453927538E04A405E2F4D11E05054405453927538E04A40
71141	10199	81.565338999999994	81.576676000000006	53.466661999999999	53.461300999999999	Рабочая	0103000020E61000000100000005000000D009A1832E645440594E42E90BBB4A40D009A1832E6454409A249694BBBB4A40D7187442E86454409A249694BBBB4A40D7187442E8645440594E42E90BBB4A40D009A1832E645440594E42E90BBB4A40
71269	10656	80.701284999999999	80.717095999999998	53.683518999999997	53.676403999999998	Центральная	0103000020E61000000100000005000000390B7BDAE12C54401971016894D64A40390B7BDAE12C5440E998F38C7DD74A40EA059FE6E42D5440E998F38C7DD74A40EA059FE6E42D54401971016894D64A40390B7BDAE12C54401971016894D64A40
71346	9598	81.685874999999996	81.698361000000006	53.801900000000003	53.796953999999999	Весенняя	0103000020E6100000010000000500000037894160E56B54404C35B39602E64A4037894160E56B5440CA54C1A8A4E64A4052F355F2B16C5440CA54C1A8A4E64A4052F355F2B16C54404C35B39602E64A4037894160E56B54404C35B39602E64A40
70969	9871	81.323646999999994	81.353211000000002	53.890107	53.866889999999998	школьная	0103000020E61000000100000005000000B41CE8A1B65454405E9D6340F6EE4A40B41CE8A1B65454406878B306EFF14A4099654F029B5654406878B306EFF14A4099654F029B5654405E9D6340F6EE4A40B41CE8A1B65454405E9D6340F6EE4A40
70637	10016	81.517027999999996	81.564081000000002	53.652172	53.636189999999999	Советская	0103000020E6100000010000000500000071C79BFC16615440680586AC6ED14A4071C79BFC16615440F7AE415F7AD34A40E1D231E719645440F7AE415F7AD34A40E1D231E719645440680586AC6ED14A4071C79BFC16615440680586AC6ED14A40
71447	59445	81.16328	81.194801999999996	53.464582	53.454262	Центральная	0103000020E61000000100000005000000D105F52D734A544064E8D84125BA4A40D105F52D734A5440B727486C77BB4A4081CCCEA2774C5440B727486C77BB4A4081CCCEA2774C544064E8D84125BA4A40D105F52D734A544064E8D84125BA4A40
71144	9665	81.645002000000005	81.677197000000007	53.898623000000001	53.880007999999997	Школьная	0103000020E61000000100000005000000B2F677B647695440F31B261AA4F04A40B2F677B6476954407A37161406F34A40C2FC1532576B54407A37161406F34A40C2FC1532576B5440F31B261AA4F04A40B2F677B647695440F31B261AA4F04A40
70660	9558	81.514439999999993	81.548406	53.810205000000003	53.789304999999999	Тамбовская	0103000020E6100000010000000500000045F0BF95EC605440DEC83CF207E54A4045F0BF95EC605440210725CCB4E74A4088BB7A1519635440210725CCB4E74A4088BB7A1519635440DEC83CF207E54A4045F0BF95EC605440DEC83CF207E54A40
71345	9712	81.582209000000006	81.604343999999998	53.882699000000002	53.876429999999999	Интернациональная	0103000020E61000000100000005000000F69B89E942655440DC9DB5DB2EF04A40F69B89E942655440209BE447FCF04A402AE27492AD665440209BE447FCF04A402AE27492AD665440DC9DB5DB2EF04A40F69B89E942655440DC9DB5DB2EF04A40
70792	9499	83.232864000000006	83.274977000000007	52.933950000000003	52.921442999999996	Школьная	0103000020E610000001000000050000009C1A683EE7CE544066101FD8F1754A409C1A683EE7CE5440B30C71AC8B774A40BE89213999D15440B30C71AC8B774A40BE89213999D1544066101FD8F1754A409C1A683EE7CE544066101FD8F1754A40
70759	9473	83.607174000000001	83.653373999999999	53.124749999999999	53.105680999999997	Кировская	0103000020E61000000100000005000000D13E56F0DBE654407F677BF4868D4A40D13E56F0DBE654408716D9CEF78F4A40A1832EE1D0E954408716D9CEF78F4A40A1832EE1D0E954407F677BF4868D4A40D13E56F0DBE654407F677BF4868D4A40
70313	9422	83.566687000000002	83.594246999999996	52.831848000000001	52.813923000000003	Партизанская	0103000020E6100000010000000500000060048D9944E454402A3BFDA02E684A4060048D9944E454401B9FC9FE796A4A40C0AF912408E654401B9FC9FE796A4A40C0AF912408E654402A3BFDA02E684A4060048D9944E454402A3BFDA02E684A40
70504	9349	83.530762999999993	83.567109000000002	52.896211000000001	52.877822999999999	Большевистская	0103000020E6100000010000000500000051BB5F05F8E154409B560A815C704A4051BB5F05F8E1544061A8C30AB7724A401B118C834BE4544061A8C30AB7724A401B118C834BE454409B560A815C704A4051BB5F05F8E154409B560A815C704A40
71357	9293	83.337068000000002	83.378551999999999	53.157083999999998	53.137813999999999	Пензенская	0103000020E61000000100000005000000CD21A98592D5544029779FE3A3914A40CD21A98592D55440C85C19541B944A4077F52A323AD85440C85C19541B944A4077F52A323AD8544029779FE3A3914A40CD21A98592D5544029779FE3A3914A40
70039	24977	83.414008999999993	83.465905000000006	53.254385999999997	53.234189999999998	Комсомольская	0103000020E61000000100000005000000FACF9A1F7FDA54406E861BF0F99D4A40FACF9A1F7FDA5440B6476FB88FA04A40BF823463D1DD5440B6476FB88FA04A40BF823463D1DD54406E861BF0F99D4A40FACF9A1F7FDA54406E861BF0F99D4A40
9874	9210	83.355249999999998	83.389099000000002	53.107146	53.073514000000003	Школьная	0103000020E61000000100000005000000DBF97E6ABCD654402AE620E868894A40DBF97E6ABCD65440D8F2CAF5B68D4A4001FA7DFFE6D85440D8F2CAF5B68D4A4001FA7DFFE6D854402AE620E868894A40DBF97E6ABCD654402AE620E868894A40
71467	9210	83.355249999999998	83.389099000000002	53.107146	53.073514000000003	Строителшьная	0103000020E61000000100000005000000DBF97E6ABCD654402AE620E868894A40DBF97E6ABCD65440D8F2CAF5B68D4A4001FA7DFFE6D85440D8F2CAF5B68D4A4001FA7DFFE6D854402AE620E868894A40DBF97E6ABCD654402AE620E868894A40
69710	9210	83.355249999999998	83.389099000000002	53.107146	53.073514000000003	Коммунистическая	0103000020E61000000100000005000000DBF97E6ABCD654402AE620E868894A40DBF97E6ABCD65440D8F2CAF5B68D4A4001FA7DFFE6D85440D8F2CAF5B68D4A4001FA7DFFE6D854402AE620E868894A40DBF97E6ABCD654402AE620E868894A40
71247	9173	83.069396999999995	83.096948999999995	53.045572	53.034039999999997	Новобарнаульская	0103000020E61000000100000005000000315C1D0071C45440BF60376C5B844A40315C1D0071C4544081CEA44DD5854A405018946934C6544081CEA44DD5854A405018946934C65440BF60376C5B844A40315C1D0071C45440BF60376C5B844A40
70762	9107	83.359481000000002	83.376009999999994	52.859161999999998	52.853284000000002	Логовская	0103000020E6100000010000000500000023A298BC01D754409C19FD68386D4A4023A298BC01D75440A4FB3905F96D4A40033E3F8C10D85440A4FB3905F96D4A40033E3F8C10D854409C19FD68386D4A4023A298BC01D754409C19FD68386D4A40
70506	9097	83.346446999999998	83.375489000000002	52.830063000000003	52.81906	Центральная	0103000020E6100000010000000500000007B309302CD654401BBB44F5D6684A4007B309302CD65440514F1F813F6A4A407FC0030308D85440514F1F813F6A4A407FC0030308D854401BBB44F5D6684A4007B309302CD654401BBB44F5D6684A40
70411	8970	83.503652000000002	83.575795999999997	52.913362999999997	52.890549999999998	Чаузова	0103000020E61000000100000005000000292499D53BE05440F5B9DA8AFD714A40292499D53BE054402F302B14E9744A40BA4A77D7D9E454402F302B14E9744A40BA4A77D7D9E45440F5B9DA8AFD714A40292499D53BE05440F5B9DA8AFD714A40
69836	8970	83.503652000000002	83.575795999999997	52.913362999999997	52.890549999999998	Ленина	0103000020E61000000100000005000000292499D53BE05440F5B9DA8AFD714A40292499D53BE054402F302B14E9744A40BA4A77D7D9E454402F302B14E9744A40BA4A77D7D9E45440F5B9DA8AFD714A40292499D53BE05440F5B9DA8AFD714A40
70395	9040	83.567091000000005	83.611305999999999	52.997450999999998	52.976325000000003	Школьная	0103000020E61000000100000005000000C8B60C384BE4544034A2B437F87C4A40C8B60C384BE45440662E7079AC7F4A404F7633A31FE75440662E7079AC7F4A404F7633A31FE7544034A2B437F87C4A40C8B60C384BE4544034A2B437F87C4A40
70965	8929	83.173745999999994	83.193714999999997	53.013007999999999	53.005465999999998	Ивановская	0103000020E61000000100000005000000E4F38AA71ECB5440B69E211CB3804A40E4F38AA71ECB54400E4B033FAA814A40A86F99D365CC54400E4B033FAA814A40A86F99D365CC5440B69E211CB3804A40E4F38AA71ECB5440B69E211CB3804A40
70503	8883	83.447830999999994	83.479460000000003	53.192279999999997	53.178778999999999	Центральная	0103000020E61000000100000005000000A3C85A43A9DC5440151BF33AE2964A40A3C85A43A9DC544062D68BA19C984A405FEFFE78AFDE544062D68BA19C984A405FEFFE78AFDE5440151BF33AE2964A40A3C85A43A9DC5440151BF33AE2964A40
70309	8848	83.576137000000003	83.620971999999995	53.061101000000001	53.037672999999998	Ерушева	0103000020E61000000100000005000000FF40B96DDFE454409A780778D2844A40FF40B96DDFE454405F605628D2874A40D4EE5701BEE754405F605628D2874A40D4EE5701BEE754409A780778D2844A40FF40B96DDFE454409A780778D2844A40
70732	59410	83.367997000000003	83.392674	53.009431999999997	52.996968000000003	Советская	0103000020E61000000100000005000000AC014A438DD754404B94BDA59C7F4A40AC014A438DD7544097C4591135814A4054FF209221D9544097C4591135814A4054FF209221D954404B94BDA59C7F4A40AC014A438DD754404B94BDA59C7F4A40
71129	8743	83.382766000000004	83.411277999999996	53.054952999999998	53.044981999999997	Молодежная	0103000020E610000001000000050000005401F73C7FD854404F745DF8C1854A405401F73C7FD8544096E82CB308874A401DE4F56052DA544096E82CB308874A401DE4F56052DA54404F745DF8C1854A405401F73C7FD854404F745DF8C1854A40
70451	1170	85.080940999999996	85.124446000000006	52.669234000000003	52.632941000000002	Ленина	0103000020E61000000100000005000000F4F928232E45554016A6EF3504514A40F4F928232E45554086AFAF75A9554A408E075BECF647554086AFAF75A9554A408E075BECF647554016A6EF3504514A40F4F928232E45554016A6EF3504514A40
71123	8286	84.919037000000003	84.932053999999994	52.714858999999997	52.708573999999999	Школьная	0103000020E6100000010000000500000018B49080D13A5540E065868DB25A4A4018B49080D13A55402920ED7F805B4A40C806D2C5A63B55402920ED7F805B4A40C806D2C5A63B5540E065868DB25A4A4018B49080D13A5540E065868DB25A4A40
69884	8602	84.751069999999999	84.810799000000003	52.544134	52.518265	Кирова	0103000020E610000001000000050000006EC0E78711305540AAD4EC8156424A406EC0E787113055402252D32EA6454A404A287D21E43355402252D32EA6454A404A287D21E4335540AAD4EC8156424A406EC0E78711305540AAD4EC8156424A40
71351	8585	84.843892999999994	84.871821999999995	52.521383	52.510762	Садовая	0103000020E61000000100000005000000B114C95702365540100533A660414A40B114C957023655405ED89AADBC424A40BB7B80EECB3755405ED89AADBC424A40BB7B80EECB375540100533A660414A40B114C95702365540100533A660414A40
69706	8461	84.766890000000004	84.828218000000007	52.752713	52.735644000000001	Почтовый	0103000020E610000001000000050000004968CBB914315540D3BF2495295E4A404968CBB91431554014234BE658604A4059FD11860135554014234BE658604A4059FD118601355540D3BF2495295E4A404968CBB914315540D3BF2495295E4A40
70389	8455	84.472700000000003	85.357397000000006	52.9955	52.425099000000003	Советская	0103000020E610000001000000050000006E3480B7401E5540FA47DFA469364A406E3480B7401E55408195438B6C7F4A4011ACAA97DF5655408195438B6C7F4A4011ACAA97DF565540FA47DFA469364A406E3480B7401E5540FA47DFA469364A40
69880	8368	85.022299000000004	85.068481000000006	52.623604999999998	52.585720000000002	Бийская	0103000020E61000000100000005000000F2EEC8586D4155407B4E7ADFF84A4A40F2EEC8586D415540A04FE449D24F4A406FD921FE61445540A04FE449D24F4A406FD921FE614455407B4E7ADFF84A4A40F2EEC8586D4155407B4E7ADFF84A4A40
71132	8226	84.843462000000002	84.870339999999999	52.664088999999997	52.653289999999998	Школьная	0103000020E61000000100000005000000CD5A0A48FB355540E466B8019F534A40CD5A0A48FB35554011514CDE00554A40A4198BA6B337554011514CDE00554A40A4198BA6B3375540E466B8019F534A40CD5A0A48FB355540E466B8019F534A40
69971	2531	85.010513000000003	85.035871999999998	52.590589999999999	52.564003999999997	Ленина	0103000020E61000000100000005000000B4CBB73EAC4055401668774831484A40B4CBB73EAC4055401DACFF73984B4A40E5B512BA4B4255401DACFF73984B4A40E5B512BA4B4255401668774831484A40B4CBB73EAC4055401668774831484A40
70149	8354	85.146220999999997	85.194864999999993	52.774977999999997	52.748249000000001	Парковая	0103000020E61000000100000005000000423F53AF5B495540E2218C9FC65F4A40423F53AF5B4955404B8FA67A32634A40A4880CAB784C55404B8FA67A32634A40A4880CAB784C5540E2218C9FC65F4A40423F53AF5B495540E2218C9FC65F4A40
70754	8527	84.714374000000007	84.737452000000005	52.570031	52.552945000000001	Школьная	0103000020E6100000010000000500000037C7B94DB82D55404DBED9E6C6464A4037C7B94DB82D5540645A9BC6F6484A40AB97DF69322F5540645A9BC6F6484A40AB97DF69322F55404DBED9E6C6464A4037C7B94DB82D55404DBED9E6C6464A40
70151	8199	84.918443999999994	84.954350000000005	52.678472999999997	52.654753999999997	Ленина	0103000020E6100000010000000500000046CD57C9C73A55406C76A4FACE534A4046CD57C9C73A5540081C0934D8564A4002BC0512143D5540081C0934D8564A4002BC0512143D55406C76A4FACE534A4046CD57C9C73A55406C76A4FACE534A40
69715	8133	84.908158999999998	84.960773000000003	52.820915999999997	52.782609999999998	Советская	0103000020E610000001000000050000005B24ED461F3A5540E3C281902C644A405B24ED461F3A5540AE6186C613694A404F78094E7D3D5540AE6186C613694A404F78094E7D3D5540E3C281902C644A405B24ED461F3A5540E3C281902C644A40
71465	59455	82.297044	82.337260999999998	51.198393000000003	51.177612000000003	Центральная	0103000020E61000000100000005000000465ED6C40293544047B071FDBB964940465ED6C402935440AF601BF164994940D74D29AF95955440AF601BF164994940D74D29AF9595544047B071FDBB964940465ED6C40293544047B071FDBB964940
71116	7585	82.050178000000002	82.062521000000004	51.342256999999996	51.327108000000003	Речная	0103000020E61000000100000005000000A33EC91D368354404721C9ACDEA94940A33EC91D36835440DDE9CE13CFAB49400C94145800845440DDE9CE13CFAB49400C941458008454404721C9ACDEA94940A33EC91D368354404721C9ACDEA94940
71350	7689	81.707740000000001	81.716328000000004	51.264825000000002	51.253844999999998	Пролетарская	0103000020E610000001000000050000008C84B69C4B6D544066A032FE7DA049408C84B69C4B6D5440E4141DC9E5A14940624D6551D86D5440E4141DC9E5A14940624D6551D86D544066A032FE7DA049408C84B69C4B6D544066A032FE7DA04940
70641	56	81.898353	81.930027999999993	51.468671000000001	51.429751000000003	Советская	0103000020E61000000100000005000000DDD0949D7E7954402F36AD1402B74940DDD0949D7E795440B4CA4C69FDBB494050172994857B5440B4CA4C69FDBB494050172994857B54402F36AD1402B74940DDD0949D7E7954402F36AD1402B74940
69826	7864	82.134349999999998	82.159107000000006	51.36777	51.340601999999997	Центральная	0103000020E61000000100000005000000ED0DBE3099885440E179A9D898AB4940ED0DBE309988544097395D1613AF4940246420CF2E8A544097395D1613AF4940246420CF2E8A5440E179A9D898AB4940ED0DBE3099885440E179A9D898AB4940
70749	7595	81.891831999999994	81.904084999999995	51.232717999999998	51.225312000000002	Декабристов	0103000020E61000000100000005000000AE6186C613795440BCB20B06D79C4940AE6186C613795440639813B4C99D494077F35487DC795440639813B4C99D494077F35487DC795440BCB20B06D79C4940AE6186C613795440BCB20B06D79C4940
70751	7841	81.790043999999995	81.803375000000003	51.310974999999999	51.298603999999997	Зеленая	0103000020E61000000100000005000000AA99B51490725440363AE7A738A64940AA99B51490725440D26F5F07CEA7494023DBF97E6A735440D26F5F07CEA7494023DBF97E6A735440363AE7A738A64940AA99B51490725440363AE7A738A64940
70636	7738	81.697535000000002	81.725005999999993	51.287131000000002	51.275024000000002	40 лет Победы	0103000020E610000001000000050000002F34D769A46C5440BCCE86FC33A349402F34D769A46C54407A5567B5C0A44940D7D9907F666E54407A5567B5C0A44940D7D9907F666E5440BCCE86FC33A349402F34D769A46C5440BCCE86FC33A34940
70787	7939	82.144679999999994	82.159844000000007	51.304679999999998	51.295310000000001	Школьная	0103000020E61000000100000005000000A818E76F428954404417D4B7CCA54940A818E76F4289544065DF15C1FFA649408F1D54E23A8A544065DF15C1FFA649408F1D54E23A8A54404417D4B7CCA54940A818E76F428954404417D4B7CCA54940
70744	7447	82.055864	82.064739000000003	51.239230999999997	51.227218000000001	Центральная	0103000020E6100000010000000500000085419946938354400188BB7A159D494085419946938354403D98141F9F9E4940A6F10BAF248454403D98141F9F9E4940A6F10BAF248454400188BB7A159D494085419946938354400188BB7A159D4940
71335	3943	81.899484999999999	81.916669999999996	51.362248000000001	51.346594000000003	Центральная	0103000020E61000000100000005000000868F882991795440B37E33315DAC4940868F8829917954404D8578245EAE49405BCEA5B8AA7A54404D8578245EAE49405BCEA5B8AA7A5440B37E33315DAC4940868F882991795440B37E33315DAC4940
70964	3943	81.899484999999999	81.916669999999996	51.362248000000001	51.346594000000003	Парковая	0103000020E61000000100000005000000868F882991795440B37E33315DAC4940868F8829917954404D8578245EAE49405BCEA5B8AA7A54404D8578245EAE49405BCEA5B8AA7A5440B37E33315DAC4940868F882991795440B37E33315DAC4940
70946	7776	81.814666000000003	81.824969999999993	51.26173	51.253456	Новая	0103000020E6100000010000000500000071CADC7C23745440CC7C073F71A0494071CADC7C23745440E8305F5E80A14940978BF84ECC745440E8305F5E80A14940978BF84ECC745440CC7C073F71A0494071CADC7C23745440CC7C073F71A04940
70500	7514	81.939145999999994	81.958674999999999	51.322003000000002	51.305852000000002	Центральная 	0103000020E61000000100000005000000D40AD3F71A7C544046B5882826A74940D40AD3F71A7C5440611BF16437A949408A1F63EE5A7D5440611BF16437A949408A1F63EE5A7D544046B5882826A74940D40AD3F71A7C544046B5882826A74940
70079	7368	82.072688999999997	82.098084999999998	51.185245999999999	51.167271999999997	Советская	0103000020E61000000100000005000000DA71C3EFA6845440ACC43C2B69954940DA71C3EFA68454407FDB1324B69749409ACE4E06478654407FDB1324B69749409ACE4E0647865440ACC43C2B69954940DA71C3EFA6845440ACC43C2B69954940
70742	7309	82.325439000000003	82.353458000000003	51.070292999999999	51.060603	Косачева	0103000020E61000000100000005000000F37519FED39454400E85CFD6C1874940F37519FED3945440A1116C5CFF8849409DA04D0E9F965440A1116C5CFF8849409DA04D0E9F9654400E85CFD6C1874940F37519FED39454400E85CFD6C1874940
71342	7492	82.004570000000001	82.016041999999999	51.203133000000001	51.185212	Центральная	0103000020E61000000100000005000000BC22F8DF4A805440D369DD06B5974940BC22F8DF4A80544083DE1B43009A4940325706D50681544083DE1B43009A4940325706D506815440D369DD06B5974940BC22F8DF4A805440D369DD06B5974940
70638	8017	82.233479000000003	82.259924999999996	51.207320000000003	51.190502000000002	Центральная	0103000020E610000001000000050000006153E751F18E54404BE9995E629849406153E751F18E544043E73576899A49406B9A779CA290544043E73576899A49406B9A779CA29054404BE9995E629849406153E751F18E54404BE9995E62984940
70743	7380	82.077702000000002	82.086577000000005	51.151710000000001	51.141285000000003	Молодежная	0103000020E610000001000000050000005D35CF11F98454402B357BA0159249405D35CF11F9845440F33CB83B6B9349407EE5417A8A855440F33CB83B6B9349407EE5417A8A8554402B357BA0159249405D35CF11F98454402B357BA015924940
69968	7241	82.189408	82.221530999999999	51.071373999999999	51.037517000000001	Центральная	0103000020E610000001000000050000007366BB421F8C5440A305685BCD8449407366BB421F8C544071E481C82289494036035C902D8E544071E481C82289494036035C902D8E5440A305685BCD8449407366BB421F8C5440A305685BCD844940
71114	59428	84.455076000000005	84.586876000000004	53.585034999999998	53.506535	Привокзальная	0103000020E61000000100000005000000734C16F71F1D5540C2A38D23D6C04A40734C16F71F1D5540F701486DE2CA4A40ABB35A608F255540F701486DE2CA4A40ABB35A608F255540C2A38D23D6C04A40734C16F71F1D5540C2A38D23D6C04A40
71344	7165	85.204001000000005	85.226836000000006	53.907037000000003	53.887118999999998	Центральная	0103000020E610000001000000050000007CD6355A0E4D554082548A1D8DF14A407CD6355A0E4D554088A1D5C919F44A408D63247B844E554088A1D5C919F44A408D63247B844E554082548A1D8DF14A407CD6355A0E4D554082548A1D8DF14A40
71258	6439	84.537369999999996	84.569117000000006	53.595835999999998	53.577100999999999	Центральная	0103000020E610000001000000050000007FF623456422554094BE1072DEC94A407FF6234564225540C5E3A25A44CC4A4040A6B5696C245540C5E3A25A44CC4A4040A6B5696C24554094BE1072DEC94A407FF623456422554094BE1072DEC94A40
70906	5847	84.997191000000001	85.005787999999995	53.866481	53.856504000000001	Победы	0103000020E61000000100000005000000653733FAD13F554054724EECA1ED4A40653733FAD13F55407DCD72D9E8EE4A4064ADA1D45E4055407DCD72D9E8EE4A4064ADA1D45E40554054724EECA1ED4A40653733FAD13F554054724EECA1ED4A40
70377	6920	85.167762999999994	85.201449999999994	53.965978999999997	53.941813000000003	Коммунистическая	0103000020E61000000100000005000000A59E05A1BC4A55404DF910548DF84A40A59E05A1BC4A5540B7CF2A33A5FB4A40DE718A8EE44C5540B7CF2A33A5FB4A40DE718A8EE44C55404DF910548DF84A40A59E05A1BC4A55404DF910548DF84A40
70963	6802	85.636189000000002	85.704632000000004	53.982142000000003	53.935462999999999	Титова	0103000020E61000000100000005000000CC441152B76855401CCF6740BDF74A40CC441152B768554097033DD4B6FD4A40C4EDD0B0186D554097033DD4B6FD4A40C4EDD0B0186D55401CCF6740BDF74A40CC441152B76855401CCF6740BDF74A40
69914	6802	85.636189000000002	85.704632000000004	53.982142000000003	53.935462999999999	Советская	0103000020E61000000100000005000000CC441152B76855401CCF6740BDF74A40CC441152B768554097033DD4B6FD4A40C4EDD0B0186D554097033DD4B6FD4A40C4EDD0B0186D55401CCF6740BDF74A40CC441152B76855401CCF6740BDF74A40
70928	5883	84.781217999999996	84.801249999999996	53.802670999999997	53.789544999999997	Мира	0103000020E61000000100000005000000FA42C879FF31554033DC80CF0FE54A40FA42C879FF3155404B395FECBDE64A40E17A14AE473355404B395FECBDE64A40E17A14AE4733554033DC80CF0FE54A40FA42C879FF31554033DC80CF0FE54A40
70454	6654	85.055141000000006	85.089258999999998	53.694870999999999	53.670921	Ленина	0103000020E61000000100000005000000CDEA1D6E874355408D9944BDE0D54A40CDEA1D6E874355402BF86D88F1D84A40EA77616BB64555402BF86D88F1D84A40EA77616BB64555408D9944BDE0D54A40CDEA1D6E874355408D9944BDE0D54A40
70962	5301	84.669953000000007	84.703873000000002	53.800064999999996	53.789715000000001	Центральная	0103000020E61000000100000005000000DB368C82E02A55409014916115E54A40DB368C82E02A55404DD6A88768E64A4065E256410C2D55404DD6A88768E64A4065E256410C2D55409014916115E54A40DB368C82E02A55409014916115E54A40
70726	5237	84.592202999999998	84.611984000000007	53.804569000000001	53.783369	Центральная	0103000020E61000000100000005000000F56569A7E6255540A1D9756F45E44A40F56569A7E62555400E30F31DFCE64A40386BF0BE2A2755400E30F31DFCE64A40386BF0BE2A275540A1D9756F45E44A40F56569A7E6255540A1D9756F45E44A40
71111	6481	85.367818	85.388397999999995	53.891646000000001	53.871763999999999	Фрунзе	0103000020E61000000100000005000000543882548A57554042EA76F695EF4A40543882548A575540FBCDC47421F24A403CF54883DB585540FBCDC47421F24A403CF54883DB58554042EA76F695EF4A40543882548A57554042EA76F695EF4A40
70712	6223	84.656306999999998	84.679969	53.695568999999999	53.674463000000003	Лесная	0103000020E61000000100000005000000B24813EF002A554058AEB7CD54D64A40B24813EF002A5540438EAD6708D94A40CE52B29C842B5540438EAD6708D94A40CE52B29C842B554058AEB7CD54D64A40B24813EF002A554058AEB7CD54D64A40
70078	59379	85.184319000000002	85.217691000000002	53.847245999999998	53.833193000000001	Первая Майская	0103000020E610000001000000050000000342EBE1CB4B5540C9207711A6EA4A400342EBE1CB4B55405AD5928E72EC4A408C683BA6EE4D55405AD5928E72EC4A408C683BA6EE4D5540C9207711A6EA4A400342EBE1CB4B5540C9207711A6EA4A40
70307	6252	84.477641000000006	84.506970999999993	53.629756999999998	53.605898000000003	Молодежная	0103000020E61000000100000005000000A48E8EAB911E55401D5BCF108ECD4A40A48E8EAB911E5540AAB69BE09BD04A404E417E3672205540AAB69BE09BD04A404E417E36722055401D5BCF108ECD4A40A48E8EAB911E55401D5BCF108ECD4A40
71278	5376	84.717132000000007	84.740990999999994	53.781522000000002	53.762061000000003	Зелёная	0103000020E6100000010000000500000091BA9D7DE52D55404E4700378BE14A4091BA9D7DE52D5540618DB3E908E44A4057E883656C2F5540618DB3E908E44A4057E883656C2F55404E4700378BE14A4091BA9D7DE52D55404E4700378BE14A40
70652	6137	84.730767999999998	84.758041000000006	53.678137999999997	53.651958	Центральная	0103000020E61000000100000005000000A73D25E7C42E5540CB2E185C73D34A40A73D25E7C42E55406116DA39CDD64A40BD0166BE833055406116DA39CDD64A40BD0166BE83305540CB2E185C73D34A40A73D25E7C42E5540CB2E185C73D34A40
71338	5778	84.885548	84.939796999999999	53.817158999999997	53.799931999999998	Калинина	0103000020E6100000010000000500000072C284D1AC3855400E83F92B64E64A4072C284D1AC385540E75086AA98E84A4040F850A2253C5540E75086AA98E84A4040F850A2253C55400E83F92B64E64A4072C284D1AC3855400E83F92B64E64A40
70961	6959	85.162830999999997	85.181057999999993	53.991045999999997	53.982089000000002	Новодресвянская	0103000020E6100000010000000500000099F1B6D26B4A55407461A417B5FD4A4099F1B6D26B4A5540726A6798DAFE4A40772B4B74964B5540726A6798DAFE4A40772B4B74964B55407461A417B5FD4A4099F1B6D26B4A55407461A417B5FD4A40
70386	5935	85.105896000000001	85.129080999999999	53.804558	53.786071	Центральная	0103000020E61000000100000005000000BE310400C7465540C1AA7AF99DE44A40BE310400C74655401ADEACC1FBE64A403D62F4DC424855401ADEACC1FBE64A403D62F4DC42485540C1AA7AF99DE44A40BE310400C7465540C1AA7AF99DE44A40
71471	59459	85.416318000000004	85.436897999999999	53.764913999999997	53.742325000000001	Партизанская	0103000020E610000001000000050000001DAF40F4A45A554069006F8104DF4A401DAF40F4A45A55405320B3B3E8E14A40056C0723F65B55405320B3B3E8E14A40056C0723F65B554069006F8104DF4A401DAF40F4A45A554069006F8104DF4A40
70711	5681	85.432244999999995	85.456436999999994	53.818344000000003	53.800894999999997	Школьная	0103000020E6100000010000000500000002B7EEE6A95B5540D44334BA83E64A4002B7EEE6A95B55405D70067FBFE84A40CCEB8843365D55405D70067FBFE84A40CCEB8843365D5540D44334BA83E64A4002B7EEE6A95B5540D44334BA83E64A40
71103	6573	85.395332999999994	85.413370999999998	53.917256999999999	53.908611999999998	Центральная	0103000020E61000000100000005000000E481C8224D5955406760E4654DF44A40E481C8224D595540778368AD68F54A405987A3AB745A5540778368AD68F54A405987A3AB745A55406760E4654DF44A40E481C8224D5955406760E4654DF44A40
70498	5739	85.073143000000002	85.102374999999995	53.648083	53.633904999999999	Молодежная	0103000020E610000001000000050000009B3BFA5FAE445540ACE28DCC23D14A409B3BFA5FAE445540FA0B3D62F4D24A40643BDF4F8D465540FA0B3D62F4D24A40643BDF4F8D465540ACE28DCC23D14A409B3BFA5FAE445540ACE28DCC23D14A40
71118	6667	85.027158999999997	85.040687000000005	53.750483000000003	53.742047999999997	Новая	0103000020E61000000100000005000000B1321AF9BC415540F607CA6DFBDE4A40B1321AF9BC4155401C9AB2D30FE04A40D597A59D9A4255401C9AB2D30FE04A40D597A59D9A425540F607CA6DFBDE4A40B1321AF9BC415540F607CA6DFBDE4A40
70940	7004	85.258303999999995	85.264520000000005	54.076169999999998	54.066819000000002	Лесная	0103000020E61000000100000005000000431B800D885055402FE065868D084B40431B800D88505540D97745F0BF094B40D4484BE5ED505540D97745F0BF094B40D4484BE5ED5055402FE065868D084B40431B800D885055402FE065868D084B40
71115	7214	85.141469000000001	85.153327000000004	53.907980999999999	53.898363000000003	Школьная	0103000020E610000001000000050000007619FED30D495540DE770C8FFDF24A407619FED30D495540D731AEB838F44A4001A60C1CD0495540D731AEB838F44A4001A60C1CD0495540DE770C8FFDF24A407619FED30D495540DE770C8FFDF24A40
70720	6045	85.195780999999997	85.206048999999993	53.868609999999997	53.849497999999997	Центральная	0103000020E61000000100000005000000670B08AD874C55403A02B859BCEC4A40670B08AD874C5540417DCB9C2EEF4A40E71725E82F4D5540417DCB9C2EEF4A40E71725E82F4D55403A02B859BCEC4A40670B08AD874C55403A02B859BCEC4A40
71260	6317	84.332159000000004	84.352334999999997	53.640065999999997	53.630488	Центральная	0103000020E610000001000000050000009D84D217421555409E42AED4B3D04A409D84D2174215554009A4C4AEEDD14A401D8F19A88C16554009A4C4AEEDD14A401D8F19A88C1655409E42AED4B3D04A409D84D217421555409E42AED4B3D04A40
71174	5554	85.408754000000002	85.426890999999998	53.787438000000002	53.767676999999999	Советская	0103000020E61000000100000005000000FD868906295A554019726C3D43E24A40FD868906295A554057D0B4C4CAE44A403BFDA02E525B554057D0B4C4CAE44A403BFDA02E525B554019726C3D43E24A40FD868906295A554019726C3D43E24A40
70791	6122	85.205798000000001	85.227474000000001	53.812995999999998	53.805616999999998	Новая	0103000020E6100000010000000500000043E55FCB2B4D5540020D36751EE74A4043E55FCB2B4D5540B0E3BF4010E84A402EAC1BEF8E4E5540B0E3BF4010E84A402EAC1BEF8E4E5540020D36751EE74A4043E55FCB2B4D5540020D36751EE74A40
69638	19237	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Союза Республик	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
69963	19237	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Мира	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
69589	19237	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	Комсомольская	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
70063	19237	84.863862999999995	85.01849	53.769784000000001	53.667591999999999	25 Партсъезда	0103000020E610000001000000050000005D4E0988493755401E8997A773D54A405D4E098849375540F67D384888E24A406553AEF02E415540F67D384888E24A406553AEF02E4155401E8997A773D54A405D4E0988493755401E8997A773D54A40
70725	5395	84.895250000000004	84.934578000000002	53.593494999999997	53.576005000000002	Центральная	0103000020E610000001000000050000009EEFA7C64B3955408FAA2688BAC94A409EEFA7C64B39554075ABE7A4F7CB4A40E9633E20D03B554075ABE7A4F7CB4A40E9633E20D03B55408FAA2688BAC94A409EEFA7C64B3955408FAA2688BAC94A40
71108	5203	84.791099000000003	84.816585000000003	53.774206	53.755460999999997	Новая	0103000020E610000001000000050000007E39B35DA1325540A43330F2B2E04A407E39B35DA1325540F92EA52E19E34A40DE59BBED42345540F92EA52E19E34A40DE59BBED42345540A43330F2B2E04A407E39B35DA1325540A43330F2B2E04A40
69849	5540	85.419049000000001	85.457972999999996	53.851458000000001	53.837572000000002	Привокзальная	0103000020E61000000100000005000000FA9AE5B2D15A5540CD052E8F35EB4A40FA9AE5B2D15A554073F56393FCEC4A40DD5CFC6D4F5D554073F56393FCEC4A40DD5CFC6D4F5D5540CD052E8F35EB4A40FA9AE5B2D15A5540CD052E8F35EB4A40
70931	6337	84.372152	84.386758999999998	53.569310999999999	53.557608999999999	Центральная	0103000020E6100000010000000500000006499F56D1175540467A51BB5FC74A4006499F56D11755406420CF2EDFC84A40C11BD2A8C01855406420CF2EDFC84A40C11BD2A8C0185540467A51BB5FC74A4006499F56D1175540467A51BB5FC74A40
70913	5138	84.985727999999995	85.013495000000006	53.921090999999997	53.896528000000004	Германа Титова	0103000020E6100000010000000500000018B0E42A163F554062F9F36DC1F24A4018B0E42A163F5540E9D1544FE6F54A4036EA211ADD405540E9D1544FE6F54A4036EA211ADD40554062F9F36DC1F24A4018B0E42A163F554062F9F36DC1F24A40
70536	5073	84.785269	84.825198999999998	53.604722000000002	53.585093000000001	Юбилейная	0103000020E610000001000000050000000264E8D8413255402C0FD253E4CA4A400264E8D841325540FB95CE8767CD4A40486C770FD0345540FB95CE8767CD4A40486C770FD03455402C0FD253E4CA4A400264E8D8413255402C0FD253E4CA4A40
70306	5073	84.785269	84.825198999999998	53.604722000000002	53.585093000000001	Центральная	0103000020E610000001000000050000000264E8D8413255402C0FD253E4CA4A400264E8D841325540FB95CE8767CD4A40486C770FD0345540FB95CE8767CD4A40486C770FD03455402C0FD253E4CA4A400264E8D8413255402C0FD253E4CA4A40
70519	5073	84.785269	84.825198999999998	53.604722000000002	53.585093000000001	Молодежная	0103000020E610000001000000050000000264E8D8413255402C0FD253E4CA4A400264E8D841325540FB95CE8767CD4A40486C770FD0345540FB95CE8767CD4A40486C770FD03455402C0FD253E4CA4A400264E8D8413255402C0FD253E4CA4A40
70716	6506	85.451244000000003	85.489008999999996	53.882826000000001	53.867432000000001	Центральная	0103000020E610000001000000050000000AA1832EE15C55407FC0030308EF4A400AA1832EE15C55407D073F7100F14A40C79C67EC4B5F55407D073F7100F14A40C79C67EC4B5F55407FC0030308EF4A400AA1832EE15C55407FC0030308EF4A40
71113	7075	84.810789999999997	84.827571000000006	53.668407999999999	53.661552999999998	Школьная	0103000020E61000000100000005000000207BBDFBE33355400CC9C9C4ADD44A40207BBDFBE33355404031B2648ED54A408E075BECF63455404031B2648ED54A408E075BECF63455400CC9C9C4ADD44A40207BBDFBE33355400CC9C9C4ADD44A40
70785	5990	85.230222999999995	85.261106999999996	53.774344999999997	53.762455000000003	Центральная	0103000020E610000001000000050000005EF23FF9BB4E5540FAD51C2098E14A405EF23FF9BB4E55401A69A9BC1DE34A406D7022FAB55055401A69A9BC1DE34A406D7022FAB5505540FAD51C2098E14A405EF23FF9BB4E5540FAD51C2098E14A40
70649	4944	84.503342000000004	84.545993999999993	53.912897999999998	53.890351000000003	Партизанская	0103000020E61000000100000005000000022D5DC136205540FF7A8505F7F14A40022D5DC136205540BA4A77D7D9F44A40FB73D190F1225540BA4A77D7D9F44A40FB73D190F1225540FF7A8505F7F14A40022D5DC136205540FF7A8505F7F14A40
70393	4796	84.269439000000006	84.320875999999998	54.022838	54.002198999999997	Николаева	0103000020E610000001000000050000001651137D3E115540BD8A8C0E48004B401651137D3E115540938D075BEC024B4090847D3B89145540938D075BEC024B4090847D3B89145540BD8A8C0E48004B401651137D3E115540BD8A8C0E48004B40
70849	4604	84.525423000000004	84.563007999999996	54.001474000000002	53.988394	Комсомольская	0103000020E610000001000000050000003D64CA87A021554004C8D0B183FE4A403D64CA87A0215540ACE5CE4C30004B40BAD8B45208245540ACE5CE4C30004B40BAD8B4520824554004C8D0B183FE4A403D64CA87A021554004C8D0B183FE4A40
70850	3873	84.297546999999994	84.324155000000005	54.108888999999998	54.092326999999997	Центральная	0103000020E61000000100000005000000778192020B135540D6C4025FD10B4B40778192020B13554073F22213F00D4B406FF59CF4BE14554073F22213F00D4B406FF59CF4BE145540D6C4025FD10B4B40778192020B135540D6C4025FD10B4B40
71337	3988	84.838441000000003	84.859228000000002	54.017305	54.006563999999997	Мира	0103000020E6100000010000000500000009A87004A93555405CAAD216D7004B4009A87004A93555405587DC0C37024B40AEF36F97FD3655405587DC0C37024B40AEF36F97FD3655405CAAD216D7004B4009A87004A93555405CAAD216D7004B40
70683	4516	84.755257	84.823815999999994	54.099961999999998	54.083708000000001	Совхозная	0103000020E61000000100000005000000CEC4742156305540F03499F1B60A4B40CEC4742156305540DF6B088ECB0C4B40FA7ABE66B9345540DF6B088ECB0C4B40FA7ABE66B9345540F03499F1B60A4B40CEC4742156305540F03499F1B60A4B40
71355	4379	84.718487999999994	84.731657999999996	53.898803999999998	53.887528000000003	Центральная	0103000020E6100000010000000500000061A417B5FB2D554064247B849AF14A4061A417B5FB2D5540CAC16C020CF34A40D576137CD32E5540CAC16C020CF34A40D576137CD32E554064247B849AF14A4061A417B5FB2D554064247B849AF14A40
71263	4886	84.166922999999997	84.180541000000005	53.996816000000003	53.986631000000003	Молодежная	0103000020E61000000100000005000000D07CCEDDAE0A5540221CB3EC49FE4A40D07CCEDDAE0A55409510ACAA97FF4A4094A5D6FB8D0B55409510ACAA97FF4A4094A5D6FB8D0B5540221CB3EC49FE4A40D07CCEDDAE0A5540221CB3EC49FE4A40
70458	4458	84.949399999999997	84.986321000000004	54.193891000000001	54.173394999999999	Школьная	0103000020E61000000100000005000000A2B437F8C23C55401C25AFCE31164B40A2B437F8C23C55408FFE976BD1184B40EA961DE21F3F55408FFE976BD1184B40EA961DE21F3F55401C25AFCE31164B40A2B437F8C23C55401C25AFCE31164B40
70935	4993	84.553881000000004	84.564975000000004	53.865482999999998	53.855637999999999	Коммунаров	0103000020E610000001000000050000000D384BC972235540809BC58B85ED4A400D384BC9722355403A1F9E25C8EE4A40B003E78C282455403A1F9E25C8EE4A40B003E78C28245540809BC58B85ED4A400D384BC972235540809BC58B85ED4A40
71339	4654	84.567076999999998	84.583014000000006	53.943503999999997	53.930486000000002	50 лет Алтая	0103000020E61000000100000005000000155454FD4A24554064B14D2A1AF74A40155454FD4A24554095D233BDC4F84A400DC7F3195025554095D233BDC4F84A400DC7F3195025554064B14D2A1AF74A40155454FD4A24554064B14D2A1AF74A40
69843	4123	84.680616000000001	84.769405000000006	54.008940000000003	53.966625000000001	пер. Школьный	0103000020E61000000100000005000000994869368F2B55407D3F355EBAFB4A40994869368F2B554029D027F224014B40401878EE3D31554029D027F224014B40401878EE3D3155407D3F355EBAFB4A40994869368F2B55407D3F355EBAFB4A40
70013	4123	84.680616000000001	84.769405000000006	54.008940000000003	53.966625000000001	Партизанская	0103000020E61000000100000005000000994869368F2B55407D3F355EBAFB4A40994869368F2B554029D027F224014B40401878EE3D31554029D027F224014B40401878EE3D3155407D3F355EBAFB4A40994869368F2B55407D3F355EBAFB4A40
69705	4123	84.680616000000001	84.769405000000006	54.008940000000003	53.966625000000001	Ленинская	0103000020E61000000100000005000000994869368F2B55407D3F355EBAFB4A40994869368F2B554029D027F224014B40401878EE3D31554029D027F224014B40401878EE3D3155407D3F355EBAFB4A40994869368F2B55407D3F355EBAFB4A40
70998	4123	84.680616000000001	84.769405000000006	54.008940000000003	53.966625000000001	Крупской	0103000020E61000000100000005000000994869368F2B55407D3F355EBAFB4A40994869368F2B554029D027F224014B40401878EE3D31554029D027F224014B40401878EE3D3155407D3F355EBAFB4A40994869368F2B55407D3F355EBAFB4A40
70148	4123	84.680616000000001	84.769405000000006	54.008940000000003	53.966625000000001	Коммунистическая	0103000020E61000000100000005000000994869368F2B55407D3F355EBAFB4A40994869368F2B554029D027F224014B40401878EE3D31554029D027F224014B40401878EE3D3155407D3F355EBAFB4A40994869368F2B55407D3F355EBAFB4A40
70639	4085	84.263266999999999	84.308550999999994	53.964337	53.947076000000003	Школьная	0103000020E610000001000000050000006DC7D45DD9105540CB694FC939F94A406DC7D45DD910554050A912656FFB4A407A89B14CBF13554050A912656FFB4A407A89B14CBF135540CB694FC939F94A406DC7D45DD9105540CB694FC939F94A40
71287	4542	84.633571000000003	84.661238999999995	54.208964999999999	54.188955	Октябрьская	0103000020E610000001000000050000006B2C616D8C28554035B56CAD2F184B406B2C616D8C2855401B81785DBF1A4B40BEF561BD512A55401B81785DBF1A4B40BEF561BD512A554035B56CAD2F184B406B2C616D8C28554035B56CAD2F184B40
70736	4820	84.048929000000001	84.063473000000002	53.996149000000003	53.971364999999999	Заречная	0103000020E61000000100000005000000DDB419A72103554051BD35B055FC4A40DDB419A721035540B87878CF81FF4A4075CB0EF10F045540B87878CF81FF4A4075CB0EF10F04554051BD35B055FC4A40DDB419A72103554051BD35B055FC4A40
70455	3909	84.984416999999993	85.017393999999996	54.044583000000003	54.026927000000001	Коммунистическая	0103000020E61000000100000005000000172829B0003F554090300C5872034B40172829B0003F5540927A4FE5B4054B406249B9FB1C415540927A4FE5B4054B406249B9FB1C41554090300C5872034B40172829B0003F554090300C5872034B40
70848	3779	84.225879000000006	84.274693999999997	54.139038999999997	54.118484000000002	Нагорная	0103000020E610000001000000050000009B7631CD740E5540B58CD47B2A0F4B409B7631CD740E55402CEFAA07CC114B40139A2496941155402CEFAA07CC114B40139A249694115540B58CD47B2A0F4B409B7631CD740E5540B58CD47B2A0F4B40
70234	59393	80.434197999999995	81.481993000000003	53.134599000000001	52.584297999999997	Советская	0103000020E61000000100000005000000457F68E6C91B5440218FE046CA4A4A40457F68E6C91B544083893F8A3A914A40A9F92AF9D85E544083893F8A3A914A40A9F92AF9D85E5440218FE046CA4A4A40457F68E6C91B5440218FE046CA4A4A40
70675	3255	80.598087000000007	80.621298999999993	52.670222000000003	52.655852000000003	Юбилейная	0103000020E610000001000000050000006B4AB20E47265440138255F5F2534A406B4AB20E47265440A587A1D5C9554A406682E15CC3275440A587A1D5C9554A406682E15CC3275440138255F5F2534A406B4AB20E47265440138255F5F2534A40
69701	3482	80.927221000000003	80.955302000000003	53.049568000000001	53.020299999999999	Советская	0103000020E6100000010000000500000086CABF96573B5440ED0DBE3099824A4086CABF96573B5440CD76853E58864A406BF3FFAA233D5440CD76853E58864A406BF3FFAA233D5440ED0DBE3099824A4086CABF96573B5440ED0DBE3099824A40
71330	3335	80.674929000000006	80.701922999999994	52.862265999999998	52.849362999999997	Молодежная	0103000020E61000000100000005000000CF876709322B54405AB741EDB76C4A40CF876709322B5440F33977BB5E6E4A40DA53724EEC2C5440F33977BB5E6E4A40DA53724EEC2C54405AB741EDB76C4A40CF876709322B54405AB741EDB76C4A40
70731	59409	81.044252999999998	81.073196999999993	52.916148999999997	52.898878000000003	Центральная	0103000020E61000000100000005000000FEEF880AD5425440058C2E6F0E734A40FEEF880AD5425440ADA1D45E44754A40944A7842AF445440ADA1D45E44754A40944A7842AF445440058C2E6F0E734A40FEEF880AD5425440058C2E6F0E734A40
70473	3573	81.191666999999995	81.237363999999999	53.006241000000003	52.987575	Центральная	0103000020E610000001000000050000003C2EAA45444C544071AC8BDB687E4A403C2EAA45444C54407A724D81CC804A40DB4FC6F8304F54407A724D81CC804A40DB4FC6F8304F544071AC8BDB687E4A403C2EAA45444C544071AC8BDB687E4A40
70145	3391	80.789930999999996	80.844791000000001	52.970326999999997	52.953083999999997	Целинная	0103000020E610000001000000050000002EC6C03A8E325440A12B11A8FE794A402EC6C03A8E32544080B6D5AC337C4A40213D450E1136544080B6D5AC337C4A40213D450E11365440A12B11A8FE794A402EC6C03A8E325440A12B11A8FE794A40
70567	3146	80.585457000000005	80.622332	52.713527999999997	52.694451000000001	Куйбышева	0103000020E61000000100000005000000B70DA3207825544056D636C5E3584A40B70DA32078255440E063B0E2545B4A4046D09849D4275440E063B0E2545B4A4046D09849D427544056D636C5E3584A40B70DA3207825544056D636C5E3584A40
70959	3040	80.879242000000005	80.947478000000004	52.854832999999999	52.820698	Школьный переулок	0103000020E6100000010000000500000042D13C804538544041F2CEA10C694A4042D13C80453854405245F12A6B6D4A407DEBC37AA33C54405245F12A6B6D4A407DEBC37AA33C544041F2CEA10C694A4042D13C804538544041F2CEA10C694A40
69878	3040	80.879242000000005	80.947478000000004	52.854832999999999	52.820698	Центральная	0103000020E6100000010000000500000042D13C804538544041F2CEA10C694A4042D13C80453854405245F12A6B6D4A407DEBC37AA33C54405245F12A6B6D4A407DEBC37AA33C544041F2CEA10C694A4042D13C804538544041F2CEA10C694A40
69702	3040	80.879242000000005	80.947478000000004	52.854832999999999	52.820698	Комунаров	0103000020E6100000010000000500000042D13C804538544041F2CEA10C694A4042D13C80453854405245F12A6B6D4A407DEBC37AA33C54405245F12A6B6D4A407DEBC37AA33C544041F2CEA10C694A4042D13C804538544041F2CEA10C694A40
69810	3664	81.268185000000003	81.330393999999998	52.962370999999997	52.926839000000001	Центральная	0103000020E61000000100000005000000C7116BF12951544024D40CA9A2764A40C7116BF12951544035CF11F92E7B4A40DB32E02C2555544035CF11F92E7B4A40DB32E02C2555544024D40CA9A2764A40C7116BF12951544024D40CA9A2764A40
70047	3467	80.654231999999993	80.712371000000005	53.005828999999999	52.972718999999998	Центральная	0103000020E61000000100000005000000C9FFE4EFDE2954405299620E827C4A40C9FFE4EFDE295440272F3201BF804A409BE7887C972D5440272F3201BF804A409BE7887C972D54405299620E827C4A40C9FFE4EFDE2954405299620E827C4A40
70007	3702	81.076673	81.126987999999997	52.873432000000001	52.852652999999997	Центральная	0103000020E610000001000000050000001EDFDE35E84454400BEBC6BB236D4A401EDFDE35E8445440D3A3A99ECC6F4A4001BF469220485440D3A3A99ECC6F4A4001BF4692204854400BEBC6BB236D4A401EDFDE35E84454400BEBC6BB236D4A40
70845	2827	86.129813999999996	86.182400999999999	53.212392999999999	53.19126	Береговая	0103000020E61000000100000005000000072461DF4E88554038842A357B984A40072461DF4E8855401D739EB12F9B4A407E703E75AC8B55401D739EB12F9B4A407E703E75AC8B554038842A357B984A40072461DF4E88554038842A357B984A40
70673	2917	86.411794999999998	86.453035999999997	53.213147999999997	53.189214999999997	Советская	0103000020E61000000100000005000000016A6AD95A9A5540D174763238984A40016A6AD95A9A5540999A046F489B4A4048FAB48AFE9C5540999A046F489B4A4048FAB48AFE9C5540D174763238984A40016A6AD95A9A5540D174763238984A40
70988	2877	86.293432999999993	86.331700999999995	53.375019000000002	53.351854000000003	Новая	0103000020E610000001000000050000004CA4349BC7925540C07B478D09AD4A404CA4349BC79255407730629F00B04A403BC3D4963A9555407730629F00B04A403BC3D4963A955540C07B478D09AD4A404CA4349BC7925540C07B478D09AD4A40
69662	2772	85.884583000000006	85.938697000000005	53.273113000000002	53.244396999999999	пер.Партизанский	0103000020E610000001000000050000003FE603029D785540C91EA166489F4A403FE603029D785540658EE55DF5A24A409DF6949C137C5540658EE55DF5A24A409DF6949C137C5540C91EA166489F4A403FE603029D785540C91EA166489F4A40
70797	2993	86.417220999999998	86.445248000000007	53.080508999999999	53.064857000000003	им.Леухина	0103000020E61000000100000005000000158DB5BFB39A554056F5F23B4D884A40158DB5BFB39A55404F04711E4E8A4A4001A777F17E9C55404F04711E4E8A4A4001A777F17E9C554056F5F23B4D884A40158DB5BFB39A554056F5F23B4D884A40
70524	2185	80.503899000000004	81.276494999999997	52.102296000000003	51.335498999999999	Молодежная	0103000020E610000001000000050000002D5F97E13F2054409C6B98A1F1AA49402D5F97E13F2054407D410B09180D4A407BA01518B25154407D410B09180D4A407BA01518B25154409C6B98A1F1AA49402D5F97E13F2054409C6B98A1F1AA4940
70671	2661	81.115021999999996	81.170250999999993	52.027273999999998	51.982166999999997	Советская	0103000020E6100000010000000500000083143C855C475440EF1AF4A5B7FD494083143C855C475440FB03E5B67D034A401F477364E54A5440FB03E5B67D034A401F477364E54A5440EF1AF4A5B7FD494083143C855C475440EF1AF4A5B7FD4940
69967	2582	80.986833000000004	81.037730999999994	51.903326	51.865830000000003	Советская	0103000020E6100000010000000500000045679945283F5440A6F27684D3EE494045679945283F544031D0B52FA0F34940E7C2482F6A42544031D0B52FA0F34940E7C2482F6A425440A6F27684D3EE494045679945283F5440A6F27684D3EE4940
71329	2324	80.831173000000007	80.853100999999995	51.736798	51.715235999999997	Лесхозная	0103000020E610000001000000050000005E143DF031355440FF756EDA8CDB49405E143DF0313554400DE198654FDE4940D5CBEF34993654400DE198654FDE4940D5CBEF3499365440FF756EDA8CDB49405E143DF031355440FF756EDA8CDB4940
70343	2475	81.17989	81.203372000000002	51.743524000000001	51.733255999999997	Ленина	0103000020E6100000010000000500000028B85851834B544042CC2555DBDD494028B85851834B544043E55FCB2BDF4940043BFE0B044D544043E55FCB2BDF4940043BFE0B044D544042CC2555DBDD494028B85851834B544042CC2555DBDD4940
70142	2336	80.868928999999994	80.919647999999995	51.781160999999997	51.732208	Машинцева	0103000020E61000000100000005000000F16261889C3754404EEFE2FDB8DD4940F16261889C37544090F46915FDE349403CF54883DB3A544090F46915FDE349403CF54883DB3A54404EEFE2FDB8DD4940F16261889C3754404EEFE2FDB8DD4940
70896	59419	80.503899000000004	81.276494999999997	52.102296000000003	51.335498999999999	Центральная	0103000020E610000001000000050000002D5F97E13F2054409C6B98A1F1AA49402D5F97E13F2054407D410B09180D4A407BA01518B25154407D410B09180D4A407BA01518B25154409C6B98A1F1AA49402D5F97E13F2054409C6B98A1F1AA4940
70560	2134	80.742643999999999	80.760413	51.509144999999997	51.484983999999997	Масловского	0103000020E610000001000000050000008524B37A872F5440A88AA9F413BE49408524B37A872F544001F6D1A92BC14940029D499BAA30544001F6D1A92BC14940029D499BAA305440A88AA9F413BE49408524B37A872F5440A88AA9F413BE4940
70141	2235	80.831648999999999	80.860754	51.714677999999999	51.668199000000001	Молодежная	0103000020E610000001000000050000001230BABC39355440261C7A8B87D549401230BABC39355440D99596917ADB4940ADF9F19716375440D99596917ADB4940ADF9F19716375440261C7A8B87D549401230BABC39355440261C7A8B87D54940
71079	1981	80.888700999999998	80.903334000000001	51.541477999999998	51.521521	Центральная	0103000020E610000001000000050000000ABB287AE0385440AF963B33C1C249400ABB287AE038544072C0AE264FC549405AD76839D039544072C0AE264FC549405AD76839D0395440AF963B33C1C249400ABB287AE0385440AF963B33C1C24940
71069	2092	80.765810999999999	80.781721000000005	51.566090000000003	51.540346	Центральная	0103000020E61000000100000005000000B1FA230C033154402043C70E2AC54940B1FA230C03315440DC4B1AA375C849402C6684B707325440DC4B1AA375C849402C6684B7073254402043C70E2AC54940B1FA230C033154402043C70E2AC54940
70937	1973	80.347879000000006	80.365404999999996	51.828648000000001	51.822180000000003	Набережная	0103000020E61000000100000005000000C6FD47A64316544070B6B9313DE94940C6FD47A643165440AAF23D2311EA4940DF32A7CB62175440AAF23D2311EA4940DF32A7CB6217544070B6B9313DE94940C6FD47A64316544070B6B9313DE94940
70674	1863	80.243269999999995	80.274827999999999	51.906882000000003	51.887169999999998	Почтовая	0103000020E61000000100000005000000448655BC910F544004FF5BC98EF14940448655BC910F544061AA99B514F449409B012EC89611544061AA99B514F449409B012EC89611544004FF5BC98EF14940448655BC910F544004FF5BC98EF14940
70553	1424	80.788152999999994	80.823232000000004	52.229145000000003	52.203951000000004	Мамонтова	0103000020E61000000100000005000000A2CF471971325440467EFD101B1A4A40A2CF4719713254405E85949F541D4A40534145D5AF3454405E85949F541D4A40534145D5AF345440467EFD101B1A4A40A2CF471971325440467EFD101B1A4A40
70450	1540	79.915197000000006	81.136994999999999	52.399298000000002	51.651795999999997	Центральная	0103000020E610000001000000050000006E19709692FA5340F1D4230D6ED349406E19709692FA5340DAAD65321C334A40CB2DAD86C4485440DAAD65321C334A40CB2DAD86C4485440F1D4230D6ED349406E19709692FA5340F1D4230D6ED34940
71328	1635	80.271153999999996	80.293521999999996	52.236750999999998	52.216450000000002	Ленина	0103000020E610000001000000050000007E8B4E965A1154400F9C33A2B41B4A407E8B4E965A115440CC2555DB4D1E4A4004AA7F10C9125440CC2555DB4D1E4A4004AA7F10C91254400F9C33A2B41B4A407E8B4E965A1154400F9C33A2B41B4A40
70757	1385	80.667392000000007	80.690515000000005	52.163469999999997	52.146861000000001	Партизанская	0103000020E610000001000000050000002C67EF8CB62A544068075C57CC124A402C67EF8CB62A544045F0BF95EC144A407099D365312C544045F0BF95EC144A407099D365312C544068075C57CC124A402C67EF8CB62A544068075C57CC124A40
70630	1274	80.491178000000005	80.517741999999998	52.09496	52.085000000000001	Береговая	0103000020E61000000100000005000000F1A0D9756F1F54407B14AE47E10A4A40F1A0D9756F1F5440CE3637A6270C4A40007157AF22215440CE3637A6270C4A40007157AF222154407B14AE47E10A4A40F1A0D9756F1F54407B14AE47E10A4A40
71472	26199	80.291555000000002	80.300601	52.000014	51.992378000000002	Молодежная	0103000020E610000001000000050000000F7F4DD6A81254408CA2073E06FF49400F7F4DD6A812544065C5707500004A404609FA0B3D13544065C5707500004A404609FA0B3D1354408CA2073E06FF49400F7F4DD6A81254408CA2073E06FF4940
70308	1733	80.069374999999994	80.111164000000002	52.177014	52.151006000000002	Центральная	0103000020E610000001000000050000003D0AD7A370045440F9BF232A54134A403D0AD7A37004544092770E65A8164A40861F9C4F1D07544092770E65A8164A40861F9C4F1D075440F9BF232A54134A403D0AD7A370045440F9BF232A54134A40
70668	1476	80.890839	80.931021000000001	52.180681	52.148558000000001	Октябрьская	0103000020E6100000010000000500000016C094810339544093C7D3F203134A4016C09481033954401901158E20174A40E9B81AD9953B54401901158E20174A40E9B81AD9953B544093C7D3F203134A4016C094810339544093C7D3F203134A40
71007	1640	80.206529000000003	80.220669000000001	52.185805000000002	52.171081999999998	Гагарина	0103000020E610000001000000050000003D2B69C5370D54409677D503E6154A403D2B69C5370D544076374F75C8174A406D8FDE701F0E544076374F75C8174A406D8FDE701F0E54409677D503E6154A403D2B69C5370D54409677D503E6154A40
69877	1297	80.605821000000006	80.649291000000005	52.149878000000001	52.128255000000003	Советская	0103000020E61000000100000005000000B98E71C5C52654403546EBA86A104A40B98E71C5C5265440E831CA332F134A4094A5D6FB8D295440E831CA332F134A4094A5D6FB8D2954403546EBA86A104A40B98E71C5C52654403546EBA86A104A40
70006	960	80.335239999999999	80.394439000000006	52.036665999999997	51.999935999999998	Свердлова	0103000020E61000000100000005000000E813799274155440E90B21E7FDFF4940E8137992741554400470B378B1044A401651137D3E1954400470B378B1044A401651137D3E195440E90B21E7FDFF4940E813799274155440E90B21E7FDFF4940
70143	960	80.335239999999999	80.394439000000006	52.036665999999997	51.999935999999998	Матросова	0103000020E61000000100000005000000E813799274155440E90B21E7FDFF4940E8137992741554400470B378B1044A401651137D3E1954400470B378B1044A401651137D3E195440E90B21E7FDFF4940E813799274155440E90B21E7FDFF4940
70144	960	80.335239999999999	80.394439000000006	52.036665999999997	51.999935999999998	Ленина	0103000020E61000000100000005000000E813799274155440E90B21E7FDFF4940E8137992741554400470B378B1044A401651137D3E1954400470B378B1044A401651137D3E195440E90B21E7FDFF4940E813799274155440E90B21E7FDFF4940
70139	960	80.335239999999999	80.394439000000006	52.036665999999997	51.999935999999998	30 лет Октября	0103000020E61000000100000005000000E813799274155440E90B21E7FDFF4940E8137992741554400470B378B1044A401651137D3E1954400470B378B1044A401651137D3E195440E90B21E7FDFF4940E813799274155440E90B21E7FDFF4940
71406	59440	81.026565000000005	81.051709000000002	52.273549000000003	52.260767999999999	Боровская	0103000020E61000000100000005000000F88DAF3DB3415440F2EB87D860214A40F88DAF3DB3415440406D54A703234A402BFA43334F435440406D54A703234A402BFA43334F435440F2EB87D860214A40F88DAF3DB3415440F2EB87D860214A40
70456	1823	80.096853999999993	80.134924999999996	51.882606000000003	51.862609999999997	Сидорова	0103000020E61000000100000005000000279F1EDB32065440ED9925016AEE4940279F1EDB320654406FA0C03BF9F049406B9A779CA20854406FA0C03BF9F049406B9A779CA2085440ED9925016AEE4940279F1EDB32065440ED9925016AEE4940
71333	1785	80.098498000000006	80.118369000000001	52.080610999999998	52.068238999999998	Кошевого	0103000020E610000001000000050000002C2E8ECA4D065440E7A7380EBC084A402C2E8ECA4D06544053591476510A4A400EF7915B9307544053591476510A4A400EF7915B93075440E7A7380EBC084A402C2E8ECA4D065440E7A7380EBC084A40
70138	840	84.616269000000003	84.648617999999999	52.221575999999999	52.210000000000001	Целинная	0103000020E61000000100000005000000792288F3702755407B14AE47E11A4A40792288F3702755400CCA349A5C1C4A40346612F5822955400CCA349A5C1C4A40346612F5822955407B14AE47E11A4A40792288F3702755407B14AE47E11A4A40
71331	901	84.749381999999997	84.776223000000002	52.403374999999997	52.37303	Центральная	0103000020E61000000100000005000000828DEBDFF52F5540A4367172BF2F4A40828DEBDFF52F55401283C0CAA1334A40CBD93BA3AD3155401283C0CAA1334A40CBD93BA3AD315540A4367172BF2F4A40828DEBDFF52F5540A4367172BF2F4A40
70718	59406	84.446640000000002	84.469268999999997	52.351345000000002	52.340027999999997	Молодежная	0103000020E610000001000000050000007845F0BF951C5540B5DC9909862B4A407845F0BF951C55407B4E7ADFF82C4A40B401D880081E55407B4E7ADFF82C4A40B401D880081E5540B5DC9909862B4A407845F0BF951C5540B5DC9909862B4A40
70667	734	84.395356000000007	84.470337999999998	52.227032000000001	52.213929	Советская	0103000020E61000000100000005000000C19140834D1955403F558506621B4A40C19140834D1955409F9273620F1D4A403A048E041A1E55409F9273620F1D4A403A048E041A1E55403F558506621B4A40C19140834D1955403F558506621B4A40
70840	675	84.255075000000005	84.285510000000002	52.335748000000002	52.319136999999998	Центральная	0103000020E61000000100000005000000BEC1172653105540C6F8307BD9284A40BEC117265310554045D95BCAF92A4A40952BBCCB4512554045D95BCAF92A4A40952BBCCB45125540C6F8307BD9284A40BEC1172653105540C6F8307BD9284A40
70004	792	84.563861000000003	84.610763000000006	52.224108000000001	52.196261999999997	Советская	0103000020E610000001000000050000005A9F724C1624554049B9FB1C1F194A405A9F724C16245540D0622992AF1C4A40D7A6B1BD16275540D0622992AF1C4A40D7A6B1BD1627554049B9FB1C1F194A405A9F724C1624554049B9FB1C1F194A40
69586	415	84.295192999999998	84.423732999999999	52.385399	52.357649000000002	Советская	0103000020E6100000010000000500000085402E71E41255403B394371C72D4A4085402E71E41255409F7422C154314A401A4F04711E1B55409F7422C154314A401A4F04711E1B55403B394371C72D4A4085402E71E41255403B394371C72D4A40
70453	339	84.433121	84.492517000000007	52.444749999999999	52.424644000000001	Коммунистическая	0103000020E610000001000000050000007E8D2441B81B5540A8380EBC5A364A407E8D2441B81B5540B0726891ED384A4057EE0566851F5540B0726891ED384A4057EE0566851F5540A8380EBC5A364A407E8D2441B81B5540A8380EBC5A364A40
71246	32129	78.144796999999997	78.167596000000003	53.177559000000002	53.170957999999999	Центральная	0103000020E61000000100000005000000C5E3A25A44895340AA7EA5F3E1954A40C5E3A25A44895340240ED940BA964A4030BC92E4B98A5340240ED940BA964A4030BC92E4B98A5340AA7EA5F3E1954A40C5E3A25A44895340AA7EA5F3E1954A40
70835	32047	78.233576999999997	78.254113000000004	53.202060000000003	53.189917000000001	Центральная	0103000020E610000001000000050000004206F2ECF28E53402BFA43334F984A404206F2ECF28E534036EA211ADD994A40431F2C634390534036EA211ADD994A40431F2C63439053402BFA43334F984A404206F2ECF28E53402BFA43334F984A40
70452	212	78.725926000000001	78.760592000000003	53.460261000000003	53.442425999999998	Советская	0103000020E610000001000000050000003B54539275AE53403673486AA1B84A403B54539275AE5340E84F1BD5E9BA4A405A66118AADB05340E84F1BD5E9BA4A405A66118AADB053403673486AA1B84A403B54539275AE53403673486AA1B84A40
70945	31940	78.225950999999995	78.247169	53.271158999999997	53.261533999999997	Набережная	0103000020E61000000100000005000000E7DF2EFB758E5340626534F279A14A40E7DF2EFB758E53400E828E56B5A24A4071E5EC9DD18F53400E828E56B5A24A4071E5EC9DD18F5340626534F279A14A40E7DF2EFB758E5340626534F279A14A40
71347	32302	78.050995	78.061739000000003	53.369968999999998	53.351424000000002	Школьный переулок	0103000020E610000001000000050000009C50888043835340C7832D76FBAC4A409C5088804383534054C4E9245BAF4A40D1782288F383534054C4E9245BAF4A40D1782288F3835340C7832D76FBAC4A409C50888043835340C7832D76FBAC4A40
71167	22170	78.241940999999997	78.257643000000002	53.359898999999999	53.347875999999999	Школьная	0103000020E61000000100000005000000F0A31AF67B8F53401A88653387AC4A40F0A31AF67B8F53407A6EA12B11AE4A40C6C210397D9053407A6EA12B11AE4A40C6C210397D9053401A88653387AC4A40F0A31AF67B8F53401A88653387AC4A40
70825	32370	78.349703000000005	78.359099000000001	53.338436000000002	53.333891999999999	Жуковского	0103000020E610000001000000050000000A14B18861965340B1321AF9BCAA4A400A14B1886196534000E5EFDE51AB4A40AF415F7AFB96534000E5EFDE51AB4A40AF415F7AFB965340B1321AF9BCAA4A400A14B18861965340B1321AF9BCAA4A40
70670	32070	78.194913999999997	78.223202000000001	53.140180000000001	53.123415000000001	Чапаева	0103000020E6100000010000000500000015E29178798C5340FD6A0E10CC8F4A4015E29178798C5340D2C6116BF1914A40B7990AF1488E5340D2C6116BF1914A40B7990AF1488E5340FD6A0E10CC8F4A4015E29178798C5340FD6A0E10CC8F4A40
70310	32198	78.136765999999994	78.155064999999993	53.528052000000002	53.511476999999999	Гагарина	0103000020E610000001000000050000001A4D2EC6C0885340FED30D1478C14A401A4D2EC6C0885340304B3B3597C34A4045F0BF95EC895340304B3B3597C34A4045F0BF95EC895340FED30D1478C14A401A4D2EC6C0885340FED30D1478C14A40
70304	32456	78.499578	78.536921000000007	53.436520999999999	53.394213999999998	Центральная	0103000020E6100000010000000500000045F30016F99F53400BD0B69A75B24A4045F30016F99F534034828DEBDFB74A4048E2E5E95CA2534034828DEBDFB74A4048E2E5E95CA253400BD0B69A75B24A4045F30016F99F53400BD0B69A75B24A40
71267	32178	78.364892999999995	78.389973999999995	53.046357	53.032404	Вишневская	0103000020E6100000010000000500000084622B685A9753403A2174D025844A4084622B685A9753406878B306EF854A4094128255F59853406878B306EF854A4094128255F59853403A2174D025844A4084622B685A9753403A2174D025844A40
70987	170	78.561732000000006	78.590046999999998	53.389997999999999	53.379370000000002	Школьная	0103000020E610000001000000050000007847C66AF3A35340B18A37328FB04A407847C66AF3A35340B1C05774EBB14A4096067E54C3A55340B1C05774EBB14A4096067E54C3A55340B18A37328FB04A407847C66AF3A35340B18A37328FB04A40
70302	31998	78.129193000000001	78.16977	53.256869000000002	53.239660000000001	Ленина	0103000020E61000000100000005000000D177B7B2448853406614CB2DAD9E4A40D177B7B244885340992D5915E1A04A40E275FD82DD8A5340992D5915E1A04A40E275FD82DD8A53406614CB2DAD9E4A40D177B7B2448853406614CB2DAD9E4A40
71336	288	78.691844000000003	78.725476999999998	53.536181999999997	53.520960000000002	Школьная	0103000020E61000000100000005000000C47B0E2C47AC5340184339D1AEC24A40C47B0E2C47AC5340185A9D9CA1C44A40034015376EAE5340185A9D9CA1C44A40034015376EAE5340184339D1AEC24A40C47B0E2C47AC5340184339D1AEC24A40
70834	32445	78.387107999999998	78.401751000000004	53.412944000000003	53.400351000000001	переулок Школьный	0103000020E610000001000000050000004701A260C6985340E0F599B33EB34A404701A260C69853402B8A5759DBB44A40A988D349B69953402B8A5759DBB44A40A988D349B6995340E0F599B33EB34A404701A260C6985340E0F599B33EB34A40
70003	31801	78.318180999999996	78.361604999999997	53.350580000000001	53.318219999999997	Первомайская	0103000020E61000000100000005000000594DD7135D9453407077D66EBBA84A40594DD7135D945340DB5031CEDFAC4A407C444C8924975340DB5031CEDFAC4A407C444C89249753407077D66EBBA84A40594DD7135D9453407077D66EBBA84A40
69879	31801	78.318180999999996	78.361604999999997	53.350580000000001	53.318219999999997	Ленина	0103000020E61000000100000005000000594DD7135D9453407077D66EBBA84A40594DD7135D945340DB5031CEDFAC4A407C444C8924975340DB5031CEDFAC4A407C444C89249753407077D66EBBA84A40594DD7135D9453407077D66EBBA84A40
70665	31801	78.318180999999996	78.361604999999997	53.350580000000001	53.318219999999997	Гоголя	0103000020E61000000100000005000000594DD7135D9453407077D66EBBA84A40594DD7135D945340DB5031CEDFAC4A407C444C8924975340DB5031CEDFAC4A407C444C89249753407077D66EBBA84A40594DD7135D9453407077D66EBBA84A40
71171	32335	78.458983000000003	78.477137999999997	53.277555999999997	53.257914999999997	Титова	0103000020E61000000100000005000000E19A3BFA5F9D5340EC12D55B03A14A40E19A3BFA5F9D53407F677BF486A34A40726BD26D899E53407F677BF486A34A40726BD26D899E5340EC12D55B03A14A40E19A3BFA5F9D5340EC12D55B03A14A40
70559	31673	79.611863	79.649448000000007	52.755099999999999	52.738948000000001	Мира	0103000020E610000001000000050000007AA86DC328E75340E9B81AD9955E4A407AA86DC328E75340D49AE61DA7604A40F81C588E90E95340D49AE61DA7604A40F81C588E90E95340E9B81AD9955E4A407AA86DC328E75340E9B81AD9955E4A40
70632	31583	79.964648999999994	79.988040999999996	53.012937000000001	52.991596999999999	Центральная	0103000020E610000001000000050000009FC728CFBCFD5340E6E786A6EC7E4A409FC728CFBCFD534045F46BEBA7814A40DB8651103CFF534045F46BEBA7814A40DB8651103CFF5340E6E786A6EC7E4A409FC728CFBCFD5340E6E786A6EC7E4A40
70851	31728	79.535083999999998	79.554908999999995	52.801282999999998	52.79372	Калинина	0103000020E610000001000000050000003927F6D03EE253402F17F19D98654A403927F6D03EE253409EEBFB7090664A4063D009A183E353409EEBFB7090664A4063D009A183E353402F17F19D98654A403927F6D03EE253402F17F19D98654A40
70982	31336	80.227414999999993	80.242200999999994	52.990414999999999	52.975999999999999	Комсомольская	0103000020E61000000100000005000000ABE7A4F78D0E5440B0726891ED7C4A40ABE7A4F78D0E5440E23B31EBC57E4A40BE839F38800F5440E23B31EBC57E4A40BE839F38800F5440B0726891ED7C4A40ABE7A4F78D0E5440B0726891ED7C4A40
70449	31530	80.112870999999998	80.137251000000006	52.811669000000002	52.791378000000002	Советская	0103000020E61000000100000005000000AD6A4947390754400F63D2DF4B654A40AD6A494739075440A91611C5E4674A40F9156BB8C8085440A91611C5E4674A40F9156BB8C80854400F63D2DF4B654A40AD6A4947390754400F63D2DF4B654A40
69875	59347	79.841821999999993	79.868853000000001	52.786459999999998	52.768124	Химиков	0103000020E6100000010000000500000069C36169E0F55340E8A221E351624A4069C36169E0F553405BCEA5B8AA644A4004029D499BF753405BCEA5B8AA644A4004029D499BF75340E8A221E351624A4069C36169E0F55340E8A221E351624A40
70273	59347	79.841821999999993	79.868853000000001	52.786459999999998	52.768124	Мира	0103000020E6100000010000000500000069C36169E0F55340E8A221E351624A4069C36169E0F553405BCEA5B8AA644A4004029D499BF753405BCEA5B8AA644A4004029D499BF75340E8A221E351624A4069C36169E0F55340E8A221E351624A40
70209	59347	79.841821999999993	79.868853000000001	52.786459999999998	52.768124	Мира	0103000020E6100000010000000500000069C36169E0F55340E8A221E351624A4069C36169E0F553405BCEA5B8AA644A4004029D499BF753405BCEA5B8AA644A4004029D499BF75340E8A221E351624A4069C36169E0F55340E8A221E351624A40
69699	59347	79.841821999999993	79.868853000000001	52.786459999999998	52.768124	Микитона	0103000020E6100000010000000500000069C36169E0F55340E8A221E351624A4069C36169E0F553405BCEA5B8AA644A4004029D499BF753405BCEA5B8AA644A4004029D499BF75340E8A221E351624A4069C36169E0F55340E8A221E351624A40
70822	31442	79.578256999999994	79.609589999999997	52.692065999999997	52.676850999999999	Ленина	0103000020E61000000100000005000000B7EBA52902E55340E8A1B60DA3564A40B7EBA52902E553403656629E95584A40FE7DC68503E753403656629E95584A40FE7DC68503E75340E8A1B60DA3564A40B7EBA52902E55340E8A1B60DA3564A40
70447	31387	80.135543999999996	80.180342999999993	53.054526000000003	53.034802999999997	Мира	0103000020E61000000100000005000000D1CABDC0AC085440BE66B96C74844A40D1CABDC0AC0854400F643DB5FA864A4000C45DBD8A0B54400F643DB5FA864A4000C45DBD8A0B5440BE66B96C74844A40D1CABDC0AC085440BE66B96C74844A40
70448	31278	80.159754000000007	80.183100999999994	52.965099000000002	52.952010000000001	Школьный	0103000020E61000000100000005000000EF59D768390A544084BBB376DB794A40EF59D768390A54407F33315D887B4A405AB741EDB70B54407F33315D887B4A405AB741EDB70B544084BBB376DB794A40EF59D768390A544084BBB376DB794A40
70798	31247	79.923514999999995	79.960623999999996	52.719042999999999	52.691951000000003	Центральная	0103000020E610000001000000050000006397A8DE1AFB53409EB7B1D991584A406397A8DE1AFB534078B5DC99095C4A402CF015DD7AFD534078B5DC99095C4A402CF015DD7AFD53409EB7B1D991584A406397A8DE1AFB53409EB7B1D991584A40
70299	30378	80.406422000000006	80.489992999999998	52.955204999999999	52.917354000000003	Центральная	0103000020E61000000100000005000000FF976BD1021A54406A6D1ADB6B754A40FF976BD1021A5440E3FC4D28447A4A403691990B5C1F5440E3FC4D28447A4A403691990B5C1F54406A6D1ADB6B754A40FF976BD1021A54406A6D1ADB6B754A40
70444	30378	80.406422000000006	80.489992999999998	52.955204999999999	52.917354000000003	Маяковского	0103000020E61000000100000005000000FF976BD1021A54406A6D1ADB6B754A40FF976BD1021A5440E3FC4D28447A4A403691990B5C1F5440E3FC4D28447A4A403691990B5C1F54406A6D1ADB6B754A40FF976BD1021A54406A6D1ADB6B754A40
70002	30378	80.406422000000006	80.489992999999998	52.955204999999999	52.917354000000003	Ленина	0103000020E61000000100000005000000FF976BD1021A54406A6D1ADB6B754A40FF976BD1021A5440E3FC4D28447A4A403691990B5C1F5440E3FC4D28447A4A403691990B5C1F54406A6D1ADB6B754A40FF976BD1021A54406A6D1ADB6B754A40
71073	8064	79.357845999999995	79.378012999999996	52.788970999999997	52.781052000000003	Интернациональная	0103000020E6100000010000000500000048C0E8F2E6D65340DA3C0E83F9634A4048C0E8F2E6D65340073F7100FD644A409F1D705D31D85340073F7100FD644A409F1D705D31D85340DA3C0E83F9634A4048C0E8F2E6D65340DA3C0E83F9634A40
69704	30978	80.244913999999994	80.272897	52.772815000000001	52.757536000000002	Школьный	0103000020E610000001000000050000004815C5ABAC0F544076C58CF0F6604A404815C5ABAC0F5440DB6D179AEB624A404C8BFA2477115440DB6D179AEB624A404C8BFA247711544076C58CF0F6604A404815C5ABAC0F544076C58CF0F6604A40
69698	29803	79.843384999999998	79.949387000000002	52.851042999999997	52.811680000000003	Урицкого	0103000020E61000000100000005000000F73B1405FAF553409D685721E5674A40F73B1405FAF55340AF3E1EFAEE6C4A40D80FB1C1C2FC5340AF3E1EFAEE6C4A40D80FB1C1C2FC53409D685721E5674A40F73B1405FAF553409D685721E5674A40
70136	29803	79.843384999999998	79.949387000000002	52.851042999999997	52.811680000000003	Советская	0103000020E61000000100000005000000F73B1405FAF553409D685721E5674A40F73B1405FAF55340AF3E1EFAEE6C4A40D80FB1C1C2FC5340AF3E1EFAEE6C4A40D80FB1C1C2FC53409D685721E5674A40F73B1405FAF553409D685721E5674A40
69700	29803	79.843384999999998	79.949387000000002	52.851042999999997	52.811680000000003	Ленина	0103000020E61000000100000005000000F73B1405FAF553409D685721E5674A40F73B1405FAF55340AF3E1EFAEE6C4A40D80FB1C1C2FC5340AF3E1EFAEE6C4A40D80FB1C1C2FC53409D685721E5674A40F73B1405FAF553409D685721E5674A40
70102	29803	79.843384999999998	79.949387000000002	52.851042999999997	52.811680000000003	Колхозный переулок	0103000020E61000000100000005000000F73B1405FAF553409D685721E5674A40F73B1405FAF55340AF3E1EFAEE6C4A40D80FB1C1C2FC5340AF3E1EFAEE6C4A40D80FB1C1C2FC53409D685721E5674A40F73B1405FAF553409D685721E5674A40
69707	29803	79.843384999999998	79.949387000000002	52.851042999999997	52.811680000000003	Клубная	0103000020E61000000100000005000000F73B1405FAF553409D685721E5674A40F73B1405FAF55340AF3E1EFAEE6C4A40D80FB1C1C2FC5340AF3E1EFAEE6C4A40D80FB1C1C2FC53409D685721E5674A40F73B1405FAF553409D685721E5674A40
71192	31506	79.696295000000006	79.707460999999995	52.644329999999997	52.636685	Абая	0103000020E610000001000000050000009357E71890EC5340486DE2E47E514A409357E71890EC534074EACA6779524A40828C800A47ED534074EACA6779524A40828C800A47ED5340486DE2E47E514A409357E71890EC5340486DE2E47E514A40
70443	30962	80.525243000000003	80.552532999999997	52.900523999999997	52.889538999999999	Центральная	0103000020E61000000100000005000000FDDCD0949D2154401EC2F869DC714A40FDDCD0949D215440ADA1D45E44734A407D3D5FB35C235440ADA1D45E44734A407D3D5FB35C2354401EC2F869DC714A40FDDCD0949D2154401EC2F869DC714A40
70970	29764	85.427619000000007	85.443383999999995	52.683086000000003	52.677348000000002	Школьная	0103000020E610000001000000050000007D09151C5E5B55406901DA56B3564A407D09151C5E5B5540802DAF5C6F574A4075E44867605C5540802DAF5C6F574A4075E44867605C55406901DA56B3564A407D09151C5E5B55406901DA56B3564A40
69876	30022	85.763337000000007	85.823307999999997	52.726165999999999	52.702959	Ленина	0103000020E61000000100000005000000EAB46E83DA705540E5B67D8FFA594A40EAB46E83DA705540CBBBEA01F35C4A4040A20914B1745540CBBBEA01F35C4A4040A20914B1745540E5B67D8FFA594A40EAB46E83DA705540E5B67D8FFA594A40
70750	28997	85.487482	85.498531999999997	52.443376999999998	52.439013000000003	Центральная	0103000020E61000000100000005000000E0D8B3E7325F55406AC2F69331384A40E0D8B3E7325F55403866D993C0384A409B00C3F2E75F55403866D993C0384A409B00C3F2E75F55406AC2F69331384A40E0D8B3E7325F55406AC2F69331384A40
70440	30359	85.733980000000003	85.805341999999996	52.574047999999998	52.555759000000002	Советская	0103000020E61000000100000005000000C2FA3F87F96E554095BA641C23474A40C2FA3F87F96E5540C72AA5677A494A4018062CB98A735540C72AA5677A494A4018062CB98A73554095BA641C23474A40C2FA3F87F96E554095BA641C23474A40
71262	29099	85.159400000000005	85.180267000000001	52.463847999999999	52.452762999999997	Школьный	0103000020E61000000100000005000000E0BE0E9C334A55405FEB5223F4394A40E0BE0E9C334A554052280B5F5F3B4A401363997E894B554052280B5F5F3B4A401363997E894B55405FEB5223F4394A40E0BE0E9C334A55405FEB5223F4394A40
71157	29259	85.200659000000002	85.206048999999993	52.607638999999999	52.605277000000001	Фермерская	0103000020E610000001000000050000007AA9D898D74C5540B0027CB7794D4A407AA9D898D74C55401763601DC74D4A40E71725E82F4D55401763601DC74D4A40E71725E82F4D5540B0027CB7794D4A407AA9D898D74C5540B0027CB7794D4A40
70968	29235	85.171229999999994	85.200911000000005	52.667017000000001	52.641576000000001	Советская	0103000020E610000001000000050000000586AC6EF54A554002F390291F524A400586AC6EF54A5540227024D060554A40079ACFB9DB4C5540227024D060554A40079ACFB9DB4C554002F390291F524A400586AC6EF54A554002F390291F524A40
70771	29319	85.604828999999995	85.636989	52.613807999999999	52.593577000000003	Колхозная	0103000020E6100000010000000500000008ABB184B56655403354C554FA4B4A4008ABB184B5665540F702B342914E4A405ABA826DC4685540F702B342914E4A405ABA826DC46855403354C554FA4B4A4008ABB184B56655403354C554FA4B4A40
69869	29949	85.677385999999998	85.716965999999999	52.431260999999999	52.404544999999999	Советская	0103000020E610000001000000050000002B31CF4A5A6B554052616C21C8334A402B31CF4A5A6B55402785798F33374A4003965CC5E26D55402785798F33374A4003965CC5E26D554052616C21C8334A402B31CF4A5A6B554052616C21C8334A40
71343	29493	85.410739000000007	85.426935999999998	52.550229000000002	52.544561000000002	Латунина	0103000020E61000000100000005000000460C3B8C495A5540AAD6C22CB4454A40460C3B8C495A5540C82764E76D464A400B5F5FEB525B5540C82764E76D464A400B5F5FEB525B5540AAD6C22CB4454A40460C3B8C495A5540AAD6C22CB4454A40
69822	29766	85.512258000000003	85.548343000000003	52.533743000000001	52.520620999999998	Центральная	0103000020E610000001000000050000005247C7D5C86055402F4E7CB5A3424A405247C7D5C860554006BCCCB051444A4065FF3C0D1863554006BCCCB051444A4065FF3C0D186355402F4E7CB5A3424A405247C7D5C86055402F4E7CB5A3424A40
71377	29614	85.241603999999995	85.250624000000002	52.575859999999999	52.571354999999997	Новая	0103000020E610000001000000050000004CA59F70764F5540FAB31F2922494A404CA59F70764F55408B89CDC7B5494A40EFE53E390A5055408B89CDC7B5494A40EFE53E390A505540FAB31F2922494A404CA59F70764F5540FAB31F2922494A40
70907	28038	85.561971	85.580099000000004	52.430508000000003	52.418667999999997	Трактовая	0103000020E610000001000000050000003A933655F7635540DCF0BBE996354A403A933655F76355404C55DAE21A374A404F5C8E57206555404C55DAE21A374A404F5C8E5720655540DCF0BBE996354A403A933655F7635540DCF0BBE996354A40
69868	29861	85.241577000000007	85.270566000000002	52.604045999999997	52.582754999999999	Степная	0103000020E61000000100000005000000D09D60FF754F55404D4A41B7974A4A40D09D60FF754F5540CAA31B61514D4A40365A0EF450515540CAA31B61514D4A40365A0EF4505155404D4A41B7974A4A40D09D60FF754F55404D4A41B7974A4A40
69647	29861	85.241577000000007	85.270566000000002	52.604045999999997	52.582754999999999	Мира	0103000020E61000000100000005000000D09D60FF754F55404D4A41B7974A4A40D09D60FF754F5540CAA31B61514D4A40365A0EF450515540CAA31B61514D4A40365A0EF4505155404D4A41B7974A4A40D09D60FF754F55404D4A41B7974A4A40
69872	29667	85.950796999999994	85.986101000000005	52.624715000000002	52.605988000000004	Советская	0103000020E61000000100000005000000A208A9DBD97C55405DE2C803914D4A40A208A9DBD97C55400B293FA9F64F4A4063635E471C7F55400B293FA9F64F4A4063635E471C7F55405DE2C803914D4A40A208A9DBD97C55405DE2C803914D4A40
70826	30287	85.686818000000002	85.710193000000004	52.582371999999999	52.57349	Озерная	0103000020E6100000010000000500000077137CD3F46B5540A14ACD1E68494A4077137CD3F46B5540950D6B2A8B4A4A40483657CD736D5540950D6B2A8B4A4A40483657CD736D5540A14ACD1E68494A4077137CD3F46B5540A14ACD1E68494A40
70133	59386	85.008195000000001	86.114596000000006	52.884399000000002	52.357599	пл.Щигорева	0103000020E61000000100000005000000683F524486405540890AD5CDC52D4A40683F524486405540BCCE86FC33714A402810768A55875540BCCE86FC33714A402810768A55875540890AD5CDC52D4A40683F524486405540890AD5CDC52D4A40
70134	29424	85.476613	85.531356000000002	52.572958999999997	52.561118999999998	Советская	0103000020E610000001000000050000004DF6CFD3805E5540051555BFD2474A404DF6CFD3805E5540747973B856494A4023A298BC01625540747973B856494A4023A298BC01625540051555BFD2474A404DF6CFD3805E5540051555BFD2474A40
70130	29339	85.240356000000006	85.263703000000007	52.475456000000001	52.461582	Советская	0103000020E610000001000000050000006FD921FE614F55400D36751E153B4A406FD921FE614F5540EF5701BEDB3C4A40DB368C82E0505540EF5701BEDB3C4A40DB368C82E05055400D36751E153B4A406FD921FE614F55400D36751E153B4A40
70976	30220	85.635704000000004	85.658152999999999	52.598422999999997	52.583756000000001	Советская	0103000020E61000000100000005000000EE7BD45FAF685540016C4084B84A4A40EE7BD45FAF6855404C16F71F994C4A40EAB0C22D1F6A55404C16F71F994C4A40EAB0C22D1F6A5540016C4084B84A4A40EE7BD45FAF685540016C4084B84A4A40
70543	29176	85.165625000000006	85.182216999999994	52.599944000000001	52.593380000000003	Центральная	0103000020E610000001000000050000009A999999994A5540DD0C37E0F34B4A409A999999994A554039B709F7CA4C4A409DF17D71A94B554039B709F7CA4C4A409DF17D71A94B5540DD0C37E0F34B4A409A999999994A5540DD0C37E0F34B4A40
70916	30098	85.479380000000006	85.495091000000002	52.534855	52.531633999999997	Лесная	0103000020E61000000100000005000000D1967329AE5E554088B839950C444A40D1967329AE5E5540118DEE2076444A40D0622992AF5F5540118DEE2076444A40D0622992AF5F554088B839950C444A40D1967329AE5E554088B839950C444A40
69873	29124	85.470675	85.531401000000002	52.585135000000001	52.570075000000003	В.Максимовой	0103000020E61000000100000005000000DE02098A1F5E554034A2B437F8484A40DE02098A1F5E55405B5F24B4E54A4A40F3035779026255405B5F24B4E54A4A40F30357790262554034A2B437F8484A40DE02098A1F5E554034A2B437F8484A40
71161	29801	85.349806999999998	85.361035000000001	52.639789	52.633285999999998	Школьная	0103000020E610000001000000050000005C3AE63C63565540E08101840F514A405C3AE63C6356554097AB1F9BE4514A40876D8B321B57554097AB1F9BE4514A40876D8B321B575540E08101840F514A405C3AE63C63565540E08101840F514A40
69998	29040	85.38494	85.468239999999994	52.466343999999999	52.433166	Ленина	0103000020E6100000010000000500000006BB61DBA25855409CDEC5FB71374A4006BB61DBA2585540C9570229B13B4A4075ABE7A4F75D5540C9570229B13B4A4075ABE7A4F75D55409CDEC5FB71374A4006BB61DBA25855409CDEC5FB71374A40
70303	28956	85.882075999999998	85.929569999999998	52.773800999999999	52.752499999999998	Советский	0103000020E610000001000000050000008925E5EE73785540B81E85EB51604A408925E5EE73785540594E42E90B634A40EF552B137E7B5540594E42E90B634A40EF552B137E7B5540B81E85EB51604A408925E5EE73785540B81E85EB51604A40
70793	32506	85.298548999999994	85.318150000000003	52.575963999999999	52.568886999999997	Пионерская	0103000020E6100000010000000500000039D0436D1B5355404D0F0A4AD1484A4039D0436D1B53554030D63730B9494A403C4ED1915C54554030D63730B9494A403C4ED1915C5455404D0F0A4AD1484A4039D0436D1B5355404D0F0A4AD1484A40
70549	28917	85.740195999999997	85.776658999999995	52.611483999999997	52.593916	Смирнова	0103000020E6100000010000000500000052280B5F5F6F55401B498270054C4A4052280B5F5F6F55407D03931B454E4A403849F3C7B47155407D03931B454E4A403849F3C7B47155401B498270054C4A4052280B5F5F6F55401B498270054C4A40
71273	33048	85.788219999999995	85.813722999999996	52.657874	52.649821000000003	Аникинская	0103000020E6100000010000000500000066834C327272554084A0A3552D534A4066834C3272725540C171193735544A403140A20914745540C171193735544A403140A2091474554084A0A3552D534A4066834C327272554084A0A3552D534A40
71162	29395	85.298530999999997	85.314430999999999	52.484620999999997	52.477508	Катунская	0103000020E61000000100000005000000E675C4211B53554008CA6DFB1E3D4A40E675C4211B53554037FA980F083E4A404F7633A31F54554037FA980F083E4A404F7633A31F54554008CA6DFB1E3D4A40E675C4211B53554008CA6DFB1E3D4A40
70958	28866	80.447134000000005	80.479922999999999	53.517940000000003	53.500976000000001	Ленина	0103000020E6100000010000000500000080BBECD79D1C54405B0A48FB1FC04A4080BBECD79D1C544027A5A0DB4BC24A404966F50EB71E544027A5A0DB4BC24A404966F50EB71E54405B0A48FB1FC04A4080BBECD79D1C54405B0A48FB1FC04A40
70661	28481	80.917079000000001	80.970411999999996	53.142805000000003	53.124198	Почтовая	0103000020E610000001000000050000004C361E6CB13A5440431D56B8E58F4A404C361E6CB13A5440475A2A6F47924A4057E9EE3A1B3E5440475A2A6F47924A4057E9EE3A1B3E5440431D56B8E58F4A404C361E6CB13A5440431D56B8E58F4A40
70977	28444	81.095833999999996	81.129790999999997	53.198591	53.184353000000002	Школьная	0103000020E6100000010000000500000012F6ED2422465440B2F50CE198974A4012F6ED2422465440D5230D6E6B994A402B14E97E4E485440D5230D6E6B994A402B14E97E4E485440B2F50CE198974A4012F6ED2422465440B2F50CE198974A40
70431	28348	80.951151999999993	80.982566000000006	53.347386999999998	53.329380999999998	Центральная	0103000020E610000001000000050000009961A3ACDF3C54403E76172829AA4A409961A3ACDF3C54401C075E2D77AC4A40570A815CE23E54401C075E2D77AC4A40570A815CE23E54403E76172829AA4A409961A3ACDF3C54403E76172829AA4A40
70740	28563	80.477012000000002	80.497304999999997	53.134464000000001	53.124523000000003	Центральная	0103000020E610000001000000050000002CF3565D871E5440C74CA25EF08F4A402CF3565D871E5440A33EC91D36914A40C9C859D8D31F5440A33EC91D36914A40C9C859D8D31F5440C74CA25EF08F4A402CF3565D871E5440C74CA25EF08F4A40
70664	28822	80.709603999999999	80.756388000000001	53.472836999999998	53.451838000000002	Центральная	0103000020E610000001000000050000001747E5266A2D5440878BDCD3D5B94A401747E5266A2D54405CAB3DEC85BC4A408FC536A9683054405CAB3DEC85BC4A408FC536A968305440878BDCD3D5B94A401747E5266A2D5440878BDCD3D5B94A40
70979	28409	81.084560999999994	81.122136999999995	53.152461000000002	53.132205999999996	Береговая	0103000020E6100000010000000500000017618A7269455440E02A4F20EC904A4017618A72694554402E7590D783934A406B28B517D14754402E7590D783934A406B28B517D1475440E02A4F20EC904A4017618A7269455440E02A4F20EC904A40
70746	28628	80.365889999999993	80.383713	53.237499	53.227085000000002	Пушкина	0103000020E61000000100000005000000BDFBE3BD6A175440C2340C1F119D4A40BDFBE3BD6A17544096EA025E669E4A403483F8C08E18544096EA025E669E4A403483F8C08E185440C2340C1F119D4A40BDFBE3BD6A175440C2340C1F119D4A40
70532	28543	80.576222000000001	80.602425999999994	53.227651000000002	53.209508	Кулундинская	0103000020E61000000100000005000000164F3DD2E02454400C207C28D19A4A40164F3DD2E02454406BF3FFAA239D4A40A510C8258E2654406BF3FFAA239D4A40A510C8258E2654400C207C28D19A4A40164F3DD2E02454400C207C28D19A4A40
70781	28680	80.330533000000003	80.369204999999994	53.327703	53.30809	Центральный переулок	0103000020E61000000100000005000000EC4FE27327155440C11C3D7E6FA74A40EC4FE273271554408AE6012CF2A94A404221020EA11754408AE6012CF2A94A404221020EA1175440C11C3D7E6FA74A40EC4FE27327155440C11C3D7E6FA74A40
70666	28756	80.573212999999996	80.611210999999997	53.410158000000003	53.387957999999998	Набережная	0103000020E6100000010000000500000017299485AF2454405C1C959BA8B14A4017299485AF245440AD18AE0E80B44A4026FDBD141E275440AD18AE0E80B44A4026FDBD141E2754405C1C959BA8B14A4017299485AF2454405C1C959BA8B14A40
70446	28735	80.287036000000001	80.320291999999995	53.415643000000003	53.39387	Советская	0103000020E6100000010000000500000094313ECC5E125440117008556AB24A4094313ECC5E125440DAE731CA33B54A40E84A04AA7F145440DAE731CA33B54A40E84A04AA7F145440117008556AB24A4094313ECC5E125440117008556AB24A40
69847	28199	80.731226000000007	80.803010999999998	53.282536	53.253039000000001	Терешковой	0103000020E6100000010000000500000009FF2268CC2E544068CEFA9463A04A4009FF2268CC2E5440A9F8BF232AA44A4002D53F8864335440A9F8BF232AA44A4002D53F886433544068CEFA9463A04A4009FF2268CC2E544068CEFA9463A04A40
70005	28199	80.731226000000007	80.803010999999998	53.282536	53.253039000000001	Мира	0103000020E6100000010000000500000009FF2268CC2E544068CEFA9463A04A4009FF2268CC2E5440A9F8BF232AA44A4002D53F8864335440A9F8BF232AA44A4002D53F886433544068CEFA9463A04A4009FF2268CC2E544068CEFA9463A04A40
71257	28119	84.999651999999998	85.024463999999995	51.586129	51.558715999999997	Центральная	0103000020E6100000010000000500000062D8614CFA3F55403FE0810184C7494062D8614CFA3F55405C1E6B4606CB49407AFB73D1904155405C1E6B4606CB49407AFB73D1904155403FE0810184C7494062D8614CFA3F55403FE0810184C74940
70129	27637	85.052464000000001	85.125928000000002	52.067863000000003	52.046427000000001	Советская	0103000020E61000000100000005000000E90DF7915B4355406153E751F1054A40E90DF7915B435540E2CD1ABCAF084A40A56950340F485540E2CD1ABCAF084A40A56950340F4855406153E751F1054A40E90DF7915B4355406153E751F1054A40
70432	28029	85.342009000000004	85.370143999999996	51.888370000000002	51.840640999999998	Кузьмина	0103000020E61000000100000005000000037CB779E35555409F56D11F9AEB4940037CB779E3555540AF5FB01BB6F14940E1B37570B0575540AF5FB01BB6F14940E1B37570B05755409F56D11F9AEB4940037CB779E35555409F56D11F9AEB4940
70300	27592	85.220674000000002	85.256894000000003	52.097228000000001	52.073054999999997	Ленина	0103000020E61000000100000005000000F644D7851F4E554096E7C1DD59094A40F644D7851F4E5540B42094F7710C4A40792288F370505540B42094F7710C4A40792288F37050554096E7C1DD59094A40F644D7851F4E554096E7C1DD59094A40
71324	28007	85.355232000000001	85.366748999999999	51.807274999999997	51.789262000000001	Школьная	0103000020E61000000100000005000000889FFF1EBC565540DFFC868906E54940889FFF1EBC5655406FF085C954E74940CE35CCD0785755406FF085C954E74940CE35CCD078575540DFFC868906E54940889FFF1EBC565540DFFC868906E54940
70960	27862	85.699466999999999	85.726918999999995	51.875472000000002	51.848297000000002	Школьная	0103000020E6100000010000000500000066683C11C46C5540C02500FF94EC494066683C11C46C554028486C770FF04940D3F544D7856E554028486C770FF04940D3F544D7856E5540C02500FF94EC494066683C11C46C5540C02500FF94EC4940
69654	27549	85.355339999999998	85.402806999999996	52.069197000000003	52.014073000000003	60 лет октября	0103000020E610000001000000050000007BBDFBE3BD565540D960E124CD014A407BBDFBE3BD5655409CFD8172DB084A4064E60297C75955409CFD8172DB084A4064E60297C7595540D960E124CD014A407BBDFBE3BD565540D960E124CD014A40
71315	27678	85.213721000000007	85.242502999999999	51.992362	51.973303000000001	Центральная	0103000020E61000000100000005000000FB5DD89AAD4D5540A20C553195FC4940FB5DD89AAD4D554086E5CFB705FF4940A48B4D2B854F554086E5CFB705FF4940A48B4D2B854F5540A20C553195FC4940FB5DD89AAD4D5540A20C553195FC4940
71325	28168	85.065731999999997	85.116972000000004	51.680252000000003	51.653315999999997	Центральная	0103000020E610000001000000050000003E93FDF3344455400DFAD2DB9FD349403E93FDF334445540F1845E7F12D749400EA320787C475540F1845E7F12D749400EA320787C4755400DFAD2DB9FD349403E93FDF3344455400DFAD2DB9FD34940
70537	28084	84.895518999999993	84.932008999999994	51.716318999999999	51.681553000000001	Октябрьская	0103000020E61000000100000005000000957CEC2E50395540CFBEF2203DD74940957CEC2E5039554070404B57B0DB4940F8A41309A63B554070404B57B0DB4940F8A41309A63B5540CFBEF2203DD74940957CEC2E50395540CFBEF2203DD74940
70721	27961	85.376846	85.405501999999998	51.726685000000003	51.702551	Кедровая	0103000020E610000001000000050000003868AF3E1E585540D462F030EDD949403868AF3E1E58554034BF9A0304DD49409B1DA9BEF359554034BF9A0304DD49409B1DA9BEF3595540D462F030EDD949403868AF3E1E585540D462F030EDD94940
71319	27770	85.843035	85.860579999999999	51.917949	51.909770999999999	Центральная	0103000020E6100000010000000500000089981249F4755540B3EC496073F4494089981249F4755540AD32535A7FF54940DEE522BE13775540AD32535A7FF54940DEE522BE13775540B3EC496073F4494089981249F4755540B3EC496073F44940
70974	27820	85.656689	85.683871999999994	51.961190000000002	51.952604000000001	Школьная	0103000020E6100000010000000500000026A94C31076A5540F70489EDEEF9494026A94C31076A5540029F1F4608FB49409BA9108FC46B5540029F1F4608FB49409BA9108FC46B5540F70489EDEEF9494026A94C31076A5540F70489EDEEF94940
70941	27908	85.328875999999994	85.363523999999998	51.633440999999998	51.616588999999998	Центральная	0103000020E610000001000000050000001D1CEC4D0C55554063096B63ECCE49401D1CEC4D0C55554007793D9814D14940E9D32AFA4357554007793D9814D14940E9D32AFA4357554063096B63ECCE49401D1CEC4D0C55554063096B63ECCE4940
70301	2181	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	Целинная	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
69867	2181	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	Советская	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
70936	2181	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	Лесная	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
70001	2181	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	Ленина	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
69850	2181	85.301925999999995	85.363290000000006	52.000058000000003	51.879725999999998	Автомобильный переулок	0103000020E61000000100000005000000F9F36DC1525355406FB88FDC9AF04940F9F36DC152535540350D8AE601004A40B03DB32440575540350D8AE601004A40B03DB324405755406FB88FDC9AF04940F9F36DC1525355406FB88FDC9AF04940
71159	26816	82.339192999999995	82.360635000000002	52.619959000000001	52.612341999999998	Степная	0103000020E610000001000000050000000E828E56B5955440CEFBFF38614E4A400E828E56B595544031EE06D15A4F4A40C0B2D2A41497544031EE06D15A4F4A40C0B2D2A414975440CEFBFF38614E4A400E828E56B5955440CEFBFF38614E4A40
70441	27046	82.669279000000003	82.714374000000007	52.432319999999997	52.412537999999998	Школьная	0103000020E6100000010000000500000093399677D5AA5440BA2D910BCE344A4093399677D5AA54400FB4024356374A4037C7B94DB8AD54400FB4024356374A4037C7B94DB8AD5440BA2D910BCE344A4093399677D5AA5440BA2D910BCE344A40
70730	26157	83.021417999999997	83.048537999999994	52.250211	52.231670999999999	Садовая	0103000020E61000000100000005000000ED629AE95EC154403F373465A71D4A40ED629AE95EC15440BB0CFFE906204A403FA7203F1BC35440BB0CFFE906204A403FA7203F1BC354403F373465A71D4A40ED629AE95EC154403F373465A71D4A40
70938	26293	82.679151000000005	82.704627000000002	52.599763000000003	52.587657	Молодежная	0103000020E61000000100000005000000ED82C13577AB5440FB213658384B4A40ED82C13577AB5440E92CB308C54C4A403B38D89B18AD5440E92CB308C54C4A403B38D89B18AD5440FB213658384B4A40ED82C13577AB5440FB213658384B4A40
71124	27604	83.150550999999993	83.184911999999997	52.270677999999997	52.251897999999997	Молодежная	0103000020E610000001000000050000005358A9A0A2C95440C2F693313E204A405358A9A0A2C9544093DFA293A5224A40D4282499D5CB544093DFA293A5224A40D4282499D5CB5440C2F693313E204A405358A9A0A2C95440C2F693313E204A40
70433	26245	82.746965000000003	82.787199999999999	52.518675999999999	52.507905999999998	Школьная	0103000020E610000001000000050000006D904946CEAF544099B8551003414A406D904946CEAF54402C9CA4F963424A4051DA1B7C61B254402C9CA4F963424A4051DA1B7C61B2544099B8551003414A406D904946CEAF544099B8551003414A40
70737	26996	82.817914000000002	82.841243000000006	52.384920999999999	52.375470999999997	Гагарина	0103000020E61000000100000005000000323CF6B358B4544057CC086F0F304A40323CF6B358B454409545611745314A404B3FE1ECD6B554409545611745314A404B3FE1ECD6B5544057CC086F0F304A40323CF6B358B4544057CC086F0F304A40
70992	25958	82.283794	82.375871000000004	52.740665	52.700383000000002	Садовая	0103000020E6100000010000000500000044334FAE2992544052D66F26A6594A4044334FAE299254405B25581CCE5E4A40F3203D450E9854405B25581CCE5E4A40F3203D450E98544052D66F26A6594A4044334FAE2992544052D66F26A6594A40
70956	2093	82.002296999999999	83.317701	52.789396000000004	52.143197000000001	Центральная	0103000020E6100000010000000500000040F850A22580544052F17F4754124A4040F850A225805440EFCB99ED0A654A40043A933655D45440EFCB99ED0A654A40043A933655D4544052F17F4754124A4040F850A22580544052F17F4754124A40
70926	26119	83.074374000000006	83.096688	52.223064999999998	52.203668999999998	Центральная	0103000020E610000001000000050000000E6B2A8BC2C45440C11A67D3111A4A400E6B2A8BC2C45440EDF0D7648D1C4A409A7ADD2230C65440EDF0D7648D1C4A409A7ADD2230C65440C11A67D3111A4A400E6B2A8BC2C45440C11A67D3111A4A40
70934	26913	82.753011000000001	82.780409000000006	52.291648000000002	52.280844999999999	Советская	0103000020E61000000100000005000000CFA10C5531B05440601F9DBAF2234A40CFA10C5531B05440CFF8BEB854254A4043209738F2B15440CFF8BEB854254A4043209738F2B15440601F9DBAF2234A40CFA10C5531B05440601F9DBAF2234A40
71152	25673	82.618307999999999	82.632879000000003	52.493350999999997	52.485576000000002	Луговая	0103000020E61000000100000005000000BBB6B75B92A754407BDCB75A273E4A40BBB6B75B92A7544075392520263F4A40D0D4EB1681A8544075392520263F4A40D0D4EB1681A854407BDCB75A273E4A40BBB6B75B92A754407BDCB75A273E4A40
70657	26846	83.146957999999998	83.180160000000001	52.333292999999998	52.307426	Советская	0103000020E61000000100000005000000ADF886C267C9544055F833BC59274A40ADF886C267C954402C7E5358A92A4A400803CFBD87CB54402C7E5358A92A4A400803CFBD87CB544055F833BC59274A40ADF886C267C9544055F833BC59274A40
70911	25630	82.755731999999995	82.769306	52.346668999999999	52.341068	Мира	0103000020E610000001000000050000009A22C0E95DB0544027DBC01DA82B4A409A22C0E95DB05440BDC458A65F2C4A4076A73B4F3CB15440BDC458A65F2C4A4076A73B4F3CB1544027DBC01DA82B4A409A22C0E95DB0544027DBC01DA82B4A40
71317	26615	82.818281999999996	82.846363999999994	52.768909000000001	52.760899000000002	Береговая	0103000020E61000000100000005000000F33977BB5EB454409147702365614A40F33977BB5EB45440CF4C309C6B624A40C020E9D32AB65440CF4C309C6B624A40C020E9D32AB654409147702365614A40F33977BB5EB454409147702365614A40
71313	25858	82.963953000000004	82.991414000000006	52.571945999999997	52.558146000000001	Приозерная	0103000020E610000001000000050000006478EC67B1BD54405532005471474A406478EC67B1BD5440FC89CA8635494A40FBB2B45373BF5440FC89CA8635494A40FBB2B45373BF54405532005471474A406478EC67B1BD54405532005471474A40
70654	26768	82.455498000000006	82.501904999999994	52.631526000000001	52.609149000000002	Центральная	0103000020E610000001000000050000002E5915E1269D544010B22C98F84D4A402E5915E1269D54406F490ED8D5504A40BA2C26361FA054406F490ED8D5504A40BA2C26361FA0544010B22C98F84D4A402E5915E1269D544010B22C98F84D4A40
70955	25569	82.696776	82.704213999999993	52.329501	52.323953000000003	Мира	0103000020E61000000100000005000000D0285DFA97AC54407638BA4A77294A40D0285DFA97AC5440E97FB9162D2A4A40A9D898D711AD5440E97FB9162D2A4A40A9D898D711AD54407638BA4A77294A40D0285DFA97AC54407638BA4A77294A40
70944	26735	82.214264	82.268315999999999	52.484172000000001	52.471561999999999	Центральная	0103000020E61000000100000005000000732D5A80B68D5440A704C4245C3C4A40732D5A80B68D5440C8D11C59F93D4A40963FDF162C915440C8D11C59F93D4A40963FDF162C915440A704C4245C3C4A40732D5A80B68D5440A704C4245C3C4A40
71318	25521	82.739123000000006	82.758544000000001	52.414175	52.404269999999997	Школьный	0103000020E610000001000000050000002C2E8ECA4DAF544080608E1EBF334A402C2E8ECA4DAF544010E9B7AF03354A40EE2422FC8BB0544010E9B7AF03354A40EE2422FC8BB0544080608E1EBF334A402C2E8ECA4DAF544080608E1EBF334A40
71093	2138	82.603306000000003	82.631018999999995	52.395961999999997	52.376047999999997	Молодежная	0103000020E61000000100000005000000C2DEC4909CA65440F4DC425722304A40C2DEC4909CA65440B83A00E2AE324A40E509849D62A85440B83A00E2AE324A40E509849D62A85440F4DC425722304A40C2DEC4909CA65440F4DC425722304A40
70951	26582	82.740183000000002	82.766863000000001	52.703325	52.678674999999998	Юбилейная	0103000020E61000000100000005000000888384285FAF544070CE88D2DE564A40888384285FAF5440C7BAB88D065A4A40CC608C4814B15440C7BAB88D065A4A40CC608C4814B1544070CE88D2DE564A40888384285FAF544070CE88D2DE564A40
71107	26531	82.846552000000003	82.872720000000001	52.717112	52.706063999999998	Первомайская	0103000020E61000000100000005000000429770E82DB6544004711E4E605A4A40429770E82DB65440DAC87553CA5B4A402BA4FCA4DAB75440DAC87553CA5B4A402BA4FCA4DAB7544004711E4E605A4A40429770E82DB6544004711E4E605A4A40
71154	26441	82.716898	82.744125999999994	52.737312000000003	52.724497	Советская	0103000020E61000000100000005000000572426A8E1AD54406A865451BC5C4A40572426A8E1AD54406479573D605E4A409C86A8C29FAF54406479573D605E4A409C86A8C29FAF54406A865451BC5C4A40572426A8E1AD54406A865451BC5C4A40
70650	26403	82.536147999999997	82.587586000000002	52.379567000000002	52.357923999999997	Октябрьская	0103000020E610000001000000050000003674B33F50A254400C3A2174D02D4A403674B33F50A2544007D2C5A695304A4099654F029BA5544007D2C5A695304A4099654F029BA554400C3A2174D02D4A403674B33F50A254400C3A2174D02D4A40
70297	26345	82.471281000000005	82.510052000000002	52.315123999999997	52.299866000000002	Центральная	0103000020E610000001000000050000007A8EC877299E54405797530262264A407A8EC877299E5440A417B5FB55284A409AD024B1A4A05440A417B5FB55284A409AD024B1A4A054405797530262264A407A8EC877299E54405797530262264A40
70655	26193	82.679653999999999	82.701744000000005	52.514642000000002	52.503148000000003	Школьная	0103000020E610000001000000050000001EA67D737FAB54401F86562767404A401EA67D737FAB5440F392FFC9DF414A40838AAA5FE9AC5440F392FFC9DF414A40838AAA5FE9AC54401F86562767404A401EA67D737FAB54401F86562767404A40
71000	1185	82.843597000000003	82.861608000000004	52.658659999999998	52.645837999999998	Центральная	0103000020E610000001000000050000003D80457EFDB55440CC41D0D1AA524A403D80457EFDB5544078978BF84E544A40357EE19524B7544078978BF84E544A40357EE19524B75440CC41D0D1AA524A403D80457EFDB55440CC41D0D1AA524A40
70132	26038	82.488186999999996	82.517688000000007	52.582661999999999	52.570785999999998	Пионерская	0103000020E6100000010000000500000045D5AF743E9F5440E08101840F494A4045D5AF743E9F54409C4F1DAB944A4A400762D9CC21A154409C4F1DAB944A4A400762D9CC21A15440E08101840F494A4045D5AF743E9F5440E08101840F494A40
70954	26007	82.889465000000001	82.909002999999998	52.236275999999997	52.212967999999996	Центральная	0103000020E61000000100000005000000F27B9BFEECB85440198C1189421B4A40F27B9BFEECB85440336ABE4A3E1E4A40D13DEB1A2DBA5440336ABE4A3E1E4A40D13DEB1A2DBA5440198C1189421B4A40F27B9BFEECB85440198C1189421B4A40
70659	59403	82.002296999999999	83.317701	52.789396000000004	52.143197000000001	Комсомольская	0103000020E6100000010000000500000040F850A22580544052F17F4754124A4040F850A225805440EFCB99ED0A654A40043A933655D45440EFCB99ED0A654A40043A933655D4544052F17F4754124A4040F850A22580544052F17F4754124A40
70528	25904	82.154759999999996	82.207831999999996	52.665182000000001	52.636536999999997	Кирова	0103000020E61000000100000005000000A7AE7C96E7895440D3D85E0B7A514A40A7AE7C96E7895440A6F10BAF24554A40FCC3961E4D8D5440A6F10BAF24554A40FCC3961E4D8D5440D3D85E0B7A514A40A7AE7C96E7895440D3D85E0B7A514A40
70296	26685	82.635035000000002	82.663493000000003	52.296709999999997	52.278326999999997	Центральная	0103000020E610000001000000050000002F34D769A4A85440014C1938A0234A402F34D769A4A85440B532E197FA254A40FF0758AB76AA5440B532E197FA254A40FF0758AB76AA5440014C1938A0234A402F34D769A4A85440014C1938A0234A40
70932	25807	82.853442000000001	82.883679999999998	52.525903	52.510421999999998	Садовая	0103000020E610000001000000050000001AC231CB9EB654405794128255414A401AC231CB9EB6544024EF1CCA50434A4046088F368EB8544024EF1CCA50434A4046088F368EB854405794128255414A401AC231CB9EB654405794128255414A40
70546	25783	82.950523000000004	82.989483000000007	52.537846000000002	52.505774000000002	Центральная	0103000020E6100000010000000500000022C66B5ED5BC54406495D233BD404A4022C66B5ED5BC544068244223D8444A40AC3C81B053BF544068244223D8444A40AC3C81B053BF54406495D233BD404A4022C66B5ED5BC54406495D233BD404A40
71156	25727	82.916684000000004	82.943184000000002	52.396577999999998	52.380265000000001	Центральная	0103000020E610000001000000050000000E315EF3AABA54401F680586AC304A400E315EF3AABA544013286211C3324A4012876C205DBC544013286211C3324A4012876C205DBC54401F680586AC304A400E315EF3AABA54401F680586AC304A40
70288	1173	82.675207	82.736723999999995	52.483024999999998	52.465207999999997	Мира	0103000020E61000000100000005000000F0C16B9736AB544035EB8CEF8B3B4A40F0C16B9736AB5440401361C3D33D4A40698B6B7C26AF5440401361C3D33D4A40698B6B7C26AF544035EB8CEF8B3B4A40F0C16B9736AB544035EB8CEF8B3B4A40
61441	57828	44.833398000000003	46.660426999999999	44.009798000000004	42.475405000000002	К.Л. Тепсуева	0103000020E61000000100000005000000A24621C9AC6A46406DAD2F12DA3C4540A24621C9AC6A46407AC8940F410146409C3237DF885447407AC8940F410146409C3237DF885447406DAD2F12DA3C4540A24621C9AC6A46406DAD2F12DA3C4540
61169	57767	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	С.Абуева	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61181	57768	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	пр-кт им.А-Х.Кадырова	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61224	57768	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Школьная	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61252	57768	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Свободы	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61211	57768	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Партизанская	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61182	57768	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Нурадилова	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
62330	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	проспект Кадырова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61101	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	гор.Маяковского	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61281	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	г-к. Маяковского	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61261	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	г-к Нефтемайск	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61064	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	г-к Маяковского	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61255	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Яблочная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60989	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Школьная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61019	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Шерипова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61070	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Ш.А.Митаева	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61076	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Ц.Уадьба	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
75505	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Ханкальская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61059	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Фонтанная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61015	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Фасадная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61012	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Ученическая	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61020	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Урожайная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60999	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Угольная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61100	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Турбинная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61074	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Трудовая	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61053	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Субботников	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61241	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Сторителей	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61039	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Старопромысловское шоссе	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60972	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Социалистическая	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61077	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Советская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61161	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Сайханова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61150	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Нурадилова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61063	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Новаторов	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61091	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Николаева	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60997	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Нахимова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61050	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Моздокская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61022	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Митаева	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60987	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Маяковского	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61118	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Майская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61276	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	М.Х. Митаева	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61096	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Ляпидевского	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61085	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Лермонтова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61287	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Л. Яшина	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61097	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Кутузова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61027	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Крупская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61117	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Коперника	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61202	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Комсомольская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61216	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Кольцова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61036	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Кирова пр	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61024	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Кадырова пр	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61120	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Кадырова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61309	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Заветы Ильича	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61009	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	З.Умаровой	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61288	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	З. Умаровой	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60998	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Донецкая	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60995	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Дарвина	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61017	28733	45.525270999999996	45.745026000000003	43.398195999999999	43.253554000000001	Д.Бедного	0103000020E61000000100000005000000C34483143CC346408FE21C7574A04540C34483143CC34640F2B22616F8B24540B95510035DDF4640F2B22616F8B24540B95510035DDF46408FE21C7574A04540C34483143CC346408FE21C7574A04540
60992	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Гурьевская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61095	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Грибоедова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61031	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Галкина	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61079	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Ворошилова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61090	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Воронежская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61160	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Возрождения	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61016	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Верхоянская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61029	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Буровиков	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
75576	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Батумская	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61108	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Баррикадная	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61056	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Алексеева	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
60993	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Агрономическая	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61094	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	Абухова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61275	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	А. Айдамирова	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61026	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	8-Марта	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61061	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	56-участок	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61060	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	20-й участок	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
61098	28733	45.524768000000002	45.746786999999998	43.398221999999997	43.253560999999998	12-участок	0103000020E6100000010000000500000061FE0A992BC346404145D5AF74A0454061FE0A992BC346401B4641F0F8B24540FA0967B796DF46401B4641F0F8B24540FA0967B796DF46404145D5AF74A0454061FE0A992BC346404145D5AF74A04540
75551	60679	45.441772999999998	45.453065000000002	43.944901999999999	43.940696000000003	Центральная Усадьба	0103000020E61000000100000005000000BEA085048CB8464030BDFDB968F84540BEA085048CB8464066F6798CF2F845402BFBAE08FEB9464066F6798CF2F845402BFBAE08FEB9464030BDFDB968F84540BEA085048CB8464030BDFDB968F84540
61073	32988	45.852024	45.913694	43.312002999999997	43.258360000000003	пер. Свободы	0103000020E610000001000000050000001CB4571F0FED46401B4CC3F011A145401CB4571F0FED46407FA0DCB6EFA745409546CCECF3F446407FA0DCB6EFA745409546CCECF3F446401B4CC3F011A145401CB4571F0FED46401B4CC3F011A14540
61213	32988	45.852024	45.913694	43.312002999999997	43.258360000000003	Шоссейная	0103000020E610000001000000050000001CB4571F0FED46401B4CC3F011A145401CB4571F0FED46407FA0DCB6EFA745409546CCECF3F446407FA0DCB6EFA745409546CCECF3F446401B4CC3F011A145401CB4571F0FED46401B4CC3F011A14540
61034	32988	45.852024	45.913694	43.312002999999997	43.258360000000003	Титова	0103000020E610000001000000050000001CB4571F0FED46401B4CC3F011A145401CB4571F0FED46407FA0DCB6EFA745409546CCECF3F446407FA0DCB6EFA745409546CCECF3F446401B4CC3F011A145401CB4571F0FED46401B4CC3F011A14540
60963	32988	45.852024	45.913694	43.312002999999997	43.258360000000003	Ленина	0103000020E610000001000000050000001CB4571F0FED46401B4CC3F011A145401CB4571F0FED46407FA0DCB6EFA745409546CCECF3F446407FA0DCB6EFA745409546CCECF3F446401B4CC3F011A145401CB4571F0FED46401B4CC3F011A14540
61200	32988	45.852024	45.913694	43.312002999999997	43.258360000000003	Кутузова	0103000020E610000001000000050000001CB4571F0FED46401B4CC3F011A145401CB4571F0FED46407FA0DCB6EFA745409546CCECF3F446407FA0DCB6EFA745409546CCECF3F446401B4CC3F011A145401CB4571F0FED46401B4CC3F011A14540
61013	32988	45.852024	45.913694	43.312002999999997	43.258360000000003	А.Х. Кадырова	0103000020E610000001000000050000001CB4571F0FED46401B4CC3F011A145401CB4571F0FED46407FA0DCB6EFA745409546CCECF3F446407FA0DCB6EFA745409546CCECF3F446401B4CC3F011A145401CB4571F0FED46401B4CC3F011A14540
61001	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Школьная	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61214	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Ткачева	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61221	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Советской	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61028	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Советская	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61313	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Орджоникидзе	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61032	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Октябрская	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61054	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Озерная	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61460	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Мира	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61268	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	Ленина	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61058	57745	46.303823000000001	46.357757999999997	43.521236000000002	43.495671000000002	 Маркелова	0103000020E61000000100000005000000E5620CACE3264740AE49B72572BF4540E5620CACE3264740BABF7ADCB7C24540F1F09E03CB2D4740BABF7ADCB7C24540F1F09E03CB2D4740AE49B72572BF4540E5620CACE3264740AE49B72572BF4540
61203	32589	46.331463999999997	46.341048999999998	43.484147	43.468131999999997	 Советская	0103000020E6100000010000000500000092E68F696D2A4740041BD7BFEBBB454092E68F696D2A47406FBA6587F8BD4540B0AA5E7EA72B47406FBA6587F8BD4540B0AA5E7EA72B4740041BD7BFEBBB454092E68F696D2A4740041BD7BFEBBB4540
61092	57754	46.099671999999998	46.115976000000003	43.47334	43.461131000000002	Советская	0103000020E61000000100000005000000D829560DC20C4740FD15325706BB4540D829560DC20C4740BFF1B56796BC45407A8F334DD80E4740BFF1B56796BC45407A8F334DD80E4740FD15325706BB4540D829560DC20C4740FD15325706BB4540
61339	57806	46.406086999999999	46.42841	43.642477999999997	43.630532000000002	Советская	0103000020E61000000100000005000000562AA8A8FA3347406E8AC745B5D04540562AA8A8FA334740223317B83CD24540C2A38D23D6364740223317B83CD24540C2A38D23D63647406E8AC745B5D04540562AA8A8FA3347406E8AC745B5D04540
61010	8126	45.708294000000002	46.658836999999998	44.00902	43.414791999999998	Ленина	0103000020E61000000100000005000000FDF9B660A9DA46403B527DE717B54540FDF9B660A9DA464045813E9127014640873254C55454474045813E9127014640873254C5545447403B527DE717B54540FDF9B660A9DA46403B527DE717B54540
61153	8126	45.708294000000002	46.658836999999998	44.00902	43.414791999999998	 Ленина	0103000020E61000000100000005000000FDF9B660A9DA46403B527DE717B54540FDF9B660A9DA464045813E9127014640873254C55454474045813E9127014640873254C5545447403B527DE717B54540FDF9B660A9DA46403B527DE717B54540
61234	32597	46.233898000000003	46.252232999999997	43.512442999999998	43.504387999999999	Хетагурова	0103000020E61000000100000005000000C74CA25EF01D4740573F36C98FC04540C74CA25EF01D4740350873BB97C1454069FCC22B49204740350873BB97C1454069FCC22B49204740573F36C98FC04540C74CA25EF01D4740573F36C98FC04540
61164	24966	46.535210999999997	46.568385999999997	43.799348000000002	43.784238000000002	Дружбы	0103000020E61000000100000005000000CFBA46CB81444740E62329E961E44540CFBA46CB81444740BF0F070951E645408BC058DFC0484740BF0F070951E645408BC058DFC0484740E62329E961E44540CFBA46CB81444740E62329E961E44540
61233	32548	46.380710000000001	46.390124	43.560156999999997	43.548639000000001	Комарова	0103000020E610000001000000050000004DA1F31ABB304740B32781CD39C645404DA1F31ABB3047400FD07D39B3C745403EB14E95EF3147400FD07D39B3C745403EB14E95EF314740B32781CD39C645404DA1F31ABB304740B32781CD39C64540
61154	57766	45.771858999999999	45.786141999999998	43.865158000000001	43.852826999999998	Школьная	0103000020E61000000100000005000000C70F9546CCE24640A912656F29ED4540C70F9546CCE24640B7EF517FBDEE45408A01124DA0E44640B7EF517FBDEE45408A01124DA0E44640A912656F29ED4540C70F9546CCE24640A912656F29ED4540
61171	24245	45.719549999999998	45.750864999999997	42.856985000000002	42.845782	Шатойская	0103000020E610000001000000050000001CEBE2361ADC4640D2C5A695426C45401CEBE2361ADC4640CF143AAFB16D4540035B25581CE04640CF143AAFB16D4540035B25581CE04640D2C5A695426C45401CEBE2361ADC4640D2C5A695426C4540
61408	57821	45.759793999999999	45.762714000000003	42.627276999999999	42.624032999999997	Школьная	0103000020E6100000010000000500000038D906EE40E14640F84F3750E04F454038D906EE40E146403944DC9C4A504540C619C39CA0E146403944DC9C4A504540C619C39CA0E14640F84F3750E04F454038D906EE40E14640F84F3750E04F4540
61302	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Эштиева	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61262	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Школьная	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61320	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Центральная	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61314	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Халида Асуева	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61037	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Советская	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61305	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Подгорная	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61282	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Лесная	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61300	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Ленина	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61315	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Заречная	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61317	23937	45.681784999999998	45.702733000000002	42.886223000000001	42.865330999999998	Ахмадова	0103000020E61000000100000005000000A1F31ABB44D74640849B8C2AC36E4540A1F31ABB44D7464044FB58C16F714540F568AA27F3D9464044FB58C16F714540F568AA27F3D94640849B8C2AC36E4540A1F31ABB44D74640849B8C2AC36E4540
61217	23536	45.805140999999999	45.810988999999999	42.63147	42.628397999999997	Кадырова	0103000020E6100000010000000500000099D53BDC0EE74640976F7D586F50454099D53BDC0EE74640DB334B02D45045403735D07CCEE74640DB334B02D45045403735D07CCEE74640976F7D586F50454099D53BDC0EE74640976F7D586F504540
61312	23536	45.805140999999999	45.810988999999999	42.63147	42.628397999999997	А-Кадырова	0103000020E6100000010000000500000099D53BDC0EE74640976F7D586F50454099D53BDC0EE74640DB334B02D45045403735D07CCEE74640DB334B02D45045403735D07CCEE74640976F7D586F50454099D53BDC0EE74640976F7D586F504540
61226	23628	45.749509000000003	45.756335999999997	42.557265000000001	42.552396999999999	Эрзи-Ара	0103000020E61000000100000005000000628731E9EFDF46404AB4E4F1B4464540628731E9EFDF46404C1AA37554474540CB64389ECFE046404C1AA37554474540CB64389ECFE046404AB4E4F1B4464540628731E9EFDF46404AB4E4F1B4464540
61267	23477	45.822667000000003	45.831929000000002	42.626919000000001	42.621319999999997	Центральная	0103000020E61000000100000005000000CD3FFA264DE94640E42CEC69874F4540CD3FFA264DE94640DA1EBDE13E50454008CC43A67CEA4640DA1EBDE13E50454008CC43A67CEA4640E42CEC69874F4540CD3FFA264DE94640E42CEC69874F4540
61333	57803	45.693849	45.710718999999997	42.846766000000002	42.837955000000001	Школьная	0103000020E6100000010000000500000060AE450BD0D846408542041C426B454060AE450BD0D84640B0AE0AD4626C4540AAD216D7F8DA4640B0AE0AD4626C4540AAD216D7F8DA46408542041C426B454060AE450BD0D846408542041C426B4540
75486	60633	45.758536999999997	45.771543999999999	42.990670999999999	42.984709000000002	Ленина	0103000020E6100000010000000500000029E78BBD17E14640D789CBF10A7E454029E78BBD17E146403D0CAD4ECE7E454067B62BF4C1E246403D0CAD4ECE7E454067B62BF4C1E24640D789CBF10A7E454029E78BBD17E14640D789CBF10A7E4540
61156	24097	45.688980000000001	45.698034999999997	42.860461000000001	42.848941000000003	Центральная	0103000020E610000001000000050000008ECC237F30D84640E59D4319AA6C45408ECC237F30D84640E23D0796236E45404F3BFC3559D94640E23D0796236E45404F3BFC3559D94640E59D4319AA6C45408ECC237F30D84640E59D4319AA6C4540
61129	24448	45.770125	45.774787000000003	42.836545999999998	42.831144999999999	А. Агаевой	0103000020E610000001000000050000007F6ABC7493E24640F19D98F5626A45407F6ABC7493E24640C0CC77F0136B4540D82E6D382CE34640C0CC77F0136B4540D82E6D382CE34640F19D98F5626A45407F6ABC7493E24640F19D98F5626A4540
61205	23674	45.907783000000002	45.921419	42.678249000000001	42.670645999999998	Мира	0103000020E61000000100000005000000B16EBC3B32F44640BB9866BAD7554540B16EBC3B32F44640B9C5FCDCD0564540DE74CB0EF1F54640B9C5FCDCD0564540DE74CB0EF1F54640BB9866BAD7554540B16EBC3B32F44640BB9866BAD7554540
61189	23753	45.943939999999998	45.952689999999997	42.643932	42.637239999999998	Школьная	0103000020E6100000010000000500000070B1A206D3F84640FDD98F149151454070B1A206D3F84640876C205D6C524540F59CF4BEF1F94640876C205D6C524540F59CF4BEF1F94640FDD98F149151454070B1A206D3F84640FDD98F1491514540
61277	23753	45.943939999999998	45.952689999999997	42.643932	42.637239999999998	Подгорная	0103000020E6100000010000000500000070B1A206D3F84640FDD98F149151454070B1A206D3F84640876C205D6C524540F59CF4BEF1F94640876C205D6C524540F59CF4BEF1F94640FDD98F149151454070B1A206D3F84640FDD98F1491514540
61434	23753	45.943939999999998	45.952689999999997	42.643932	42.637239999999998	Ахмата Кадырова	0103000020E6100000010000000500000070B1A206D3F84640FDD98F149151454070B1A206D3F84640876C205D6C524540F59CF4BEF1F94640876C205D6C524540F59CF4BEF1F94640FDD98F149151454070B1A206D3F84640FDD98F1491514540
61175	57772	45.976010000000002	45.986367000000001	42.663035999999998	42.659421999999999	Мира	0103000020E61000000100000005000000D4484BE5EDFC4640A721AAF067544540D4484BE5EDFC46400B09185DDE544540446D1B4641FE46400B09185DDE544540446D1B4641FE4640A721AAF067544540D4484BE5EDFC4640A721AAF067544540
61199	24881	45.611877999999997	45.642214000000003	42.847242000000001	42.831581	В. Мучарова	0103000020E610000001000000050000002992AF0452CE4640CC7C073F716A45402992AF0452CE464019E6046D726C454045847F1134D2464019E6046D726C454045847F1134D24640CC7C073F716A45402992AF0452CE4640CC7C073F716A4540
61552	57795	45.805140999999999	45.810988999999999	42.63147	42.628397999999997	Мира	0103000020E6100000010000000500000099D53BDC0EE74640976F7D586F50454099D53BDC0EE74640DB334B02D45045403735D07CCEE74640DB334B02D45045403735D07CCEE74640976F7D586F50454099D53BDC0EE74640976F7D586F504540
61005	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Школьная	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61007	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Учительская	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61148	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Терская	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61084	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Речная	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61008	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Моздокская	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61055	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Ленина	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61030	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Кирова	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
60990	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Кадырова	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61065	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	Баумана	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61000	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	А-Х.Кадырова	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
61062	23331	45.835163000000001	45.923611000000001	43.174953000000002	43.097935	А-Х. Кадырова	0103000020E6100000010000000500000025EA059FE6EA46401F115322898C454025EA059FE6EA464026AB22DC64964540E99C9FE238F6464026AB22DC64964540E99C9FE238F646401F115322898C454025EA059FE6EA46401F115322898C4540
75495	60634	45.983860999999997	46.017090000000003	43.256345000000003	43.224637000000001	Гагарина	0103000020E61000000100000005000000A9674128EFFD46405C3CBCE7C09C4540A9674128EFFD46401FBFB7E9CFA04540598B4F01300247401FBFB7E9CFA04540598B4F01300247405C3CBCE7C09C4540A9674128EFFD46405C3CBCE7C09C4540
75490	60634	45.983860999999997	46.017090000000003	43.256345000000003	43.224637000000001	А-Х. Кадырова	0103000020E61000000100000005000000A9674128EFFD46405C3CBCE7C09C4540A9674128EFFD46401FBFB7E9CFA04540598B4F01300247401FBFB7E9CFA04540598B4F01300247405C3CBCE7C09C4540A9674128EFFD46405C3CBCE7C09C4540
61170	57770	45.717699000000003	46.361091000000002	43.352496000000002	42.988295999999998	Сакказова	0103000020E610000001000000050000009BAF928FDDDB46404162BB7B807E45409BAF928FDDDB464044FCC3961EAD4540A2F0D93A382E474044FCC3961EAD4540A2F0D93A382E47404162BB7B807E45409BAF928FDDDB46404162BB7B807E4540
60980	10997	45.840246999999998	45.844200000000001	43.264079000000002	43.260120000000001	Южная	0103000020E61000000100000005000000F3C7B4368DEB46408C84B69C4BA14540F3C7B4368DEB4640BB473657CDA1454040A4DFBE0EEC4640BB473657CDA1454040A4DFBE0EEC46408C84B69C4BA14540F3C7B4368DEB46408C84B69C4BA14540
61111	10997	45.840246999999998	45.844200000000001	43.264079000000002	43.260120000000001	 Южная	0103000020E61000000100000005000000F3C7B4368DEB46408C84B69C4BA14540F3C7B4368DEB4640BB473657CDA1454040A4DFBE0EEC4640BB473657CDA1454040A4DFBE0EEC46408C84B69C4BA14540F3C7B4368DEB46408C84B69C4BA14540
75493	60636	45.760091000000003	45.799256999999997	43.149951000000001	43.115602000000003	А-К. Кадырова	0103000020E61000000100000005000000F27D71A94AE1464015ADDC0BCC8E4540F27D71A94AE146405280289831934540AE0CAA0D4EE646405280289831934540AE0CAA0D4EE6464015ADDC0BCC8E4540F27D71A94AE1464015ADDC0BCC8E4540
61082	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	Школьная	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61128	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	Шидиева	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61310	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	Центральная	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61138	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	Майская	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61442	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	М.Шатаева	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61331	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	Восточная	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61176	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	Ахмада Кадырова	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61048	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	А.Х.Кадырова	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61038	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	А.Р.Кадырова	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61179	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	А.Кадырова	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61035	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	А-Х.Кадырова	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61193	57747	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	А-Х..Кадырова	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
61112	57757	45.343406999999999	45.370123	43.108994000000003	43.072988000000002	Л.Д.Магомадова	0103000020E61000000100000005000000D61BB5C2F4AB46400F80B8AB57894540D61BB5C2F4AB4640E9BAF083F38D4540AB3FC23060AF4640E9BAF083F38D4540AB3FC23060AF46400F80B8AB57894540D61BB5C2F4AB46400F80B8AB57894540
61244	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	пер.Школьный	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61046	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Эльсанукаева	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61047	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Школьная	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61240	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Степная	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61049	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Сайдаева	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61206	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Сааева	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61167	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Пролетарская	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61114	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Надречная	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61044	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Маяковского	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61145	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	М. Мерзоева	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61239	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Куйбышева	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
60985	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Кирова	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
60986	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Калинина	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
60984	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Каланчакская	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61089	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Кадырова	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61142	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Кавказская	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61105	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Дадарова	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61196	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Героев	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61143	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Ганчарова	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61045	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	Вахитова	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
60982	22260	45.505750999999997	45.567438000000003	43.153891000000002	43.090806000000001	1-я А.Шерипова	0103000020E61000000100000005000000AB75E272BCC04640EA23F0879F8B4540AB75E272BCC046400A1346B3B2934540FB40F2CEA1C846400A1346B3B2934540FB40F2CEA1C84640EA23F0879F8B4540AB75E272BCC04640EA23F0879F8B4540
61124	57760	45.591728000000003	45.608392000000002	43.105071000000002	43.073923000000001	М.Дадаева	0103000020E6100000010000000500000052103CBEBDCB46400BB6114F7689454052103CBEBDCB464007616EF7728D4540F392FFC9DFCD464007616EF7728D4540F392FFC9DFCD46400BB6114F7689454052103CBEBDCB46400BB6114F76894540
61499	57835	45.446561000000003	45.490758	43.177996999999998	43.142907000000001	Эльдарханова	0103000020E61000000100000005000000A4552DE928B946404BAFCDC64A924540A4552DE928B946409FE40E9BC89645400C207C28D1BE46409FE40E9BC89645400C207C28D1BE46404BAFCDC64A924540A4552DE928B946404BAFCDC64A924540
61232	32698	45.540489000000001	45.580373999999999	43.240820999999997	43.219940000000001	Х.Нурадилова	0103000020E61000000100000005000000836C59BE2EC54640878A71FE269C4540836C59BE2EC546405298F738D39E45406FB9FAB149CA46405298F738D39E45406FB9FAB149CA4640878A71FE269C4540836C59BE2EC54640878A71FE269C4540
75501	60645	45.630220999999999	45.671956999999999	43.076945000000002	43.048662	А. Кадырова	0103000020E610000001000000050000004F20EC14ABD046406B47718E3A8645404F20EC14ABD046409D4B7155D9894540BDA8DDAF02D646409D4B7155D9894540BDA8DDAF02D646406B47718E3A8645404F20EC14ABD046406B47718E3A864540
61350	57812	46.314576000000002	46.325885999999997	43.117891999999998	43.107545999999999	Молодежная	0103000020E61000000100000005000000A20DC0064428474066683C11C48D4540A20DC00644284740E23AC615178F4540B41CE8A1B6294740E23AC615178F4540B41CE8A1B629474066683C11C48D4540A20DC0064428474066683C11C48D4540
61107	18796	46.390042999999999	46.402090000000001	43.088811	43.073698999999998	Школьная	0103000020E610000001000000050000005184D4EDEC314740BB5F05F86E8945405184D4EDEC3147403543AA285E8B45403A0664AF773347403543AA285E8B45403A0664AF77334740BB5F05F86E8945405184D4EDEC314740BB5F05F86E894540
61229	40437	46.209437000000001	46.234796000000003	43.017266999999997	42.997475999999999	А. Митаева	0103000020E6100000010000000500000043C9E4D4CE1A4740BF45274BAD7F454043C9E4D4CE1A4740672618CE35824540A69D9ACB0D1E4740672618CE35824540A69D9ACB0D1E4740BF45274BAD7F454043C9E4D4CE1A4740BF45274BAD7F4540
75517	60658	46.313066999999997	46.328015000000001	43.060110999999999	43.043543	Речная	0103000020E61000000100000005000000793A579412284740207C28D192854540793A5794122847409F909DB7B187454079CC4065FC2947409F909DB7B187454079CC4065FC294740207C28D192854540793A579412284740207C28D192854540
75519	60660	46.263047999999998	46.280870999999998	43.099449999999997	43.086862000000004	Кункуева	0103000020E610000001000000050000009CA38E8EAB214740F1A1444B1E8B45409CA38E8EAB21474029CB10C7BA8C454089B2B794F323474029CB10C7BA8C454089B2B794F3234740F1A1444B1E8B45409CA38E8EAB214740F1A1444B1E8B4540
61321	57796	46.059122000000002	46.532156999999998	43.202007999999999	42.841498000000001	А.А. Кадырова	0103000020E61000000100000005000000B03C484F9107474020D3DA34B66B4540B03C484F91074740E3C3EC65DB99454032AB77B81D444740E3C3EC65DB99454032AB77B81D44474020D3DA34B66B4540B03C484F9107474020D3DA34B66B4540
61246	40443	46.277977999999997	46.292656999999998	43.069602000000003	43.051594000000001	А.А. Кадырова	0103000020E61000000100000005000000F58079C894234740BD55D7A19A864540F58079C8942347403CDEE4B7E888454005F9D9C8752547403CDEE4B7E888454005F9D9C875254740BD55D7A19A864540F58079C894234740BD55D7A19A864540
61163	40445	46.341444000000003	46.354722000000002	43.083734	43.068246000000002	А.А. Кадырова	0103000020E610000001000000050000002DB5DE6FB42B47409A0AF148BC8845402DB5DE6FB42B474019C8B3CBB78A4540FB95CE87672D474019C8B3CBB78A4540FB95CE87672D47409A0AF148BC8845402DB5DE6FB42B47409A0AF148BC884540
61264	57748	46.361297	46.391274000000003	43.107703999999998	43.083879000000003	Нурадилова	0103000020E610000001000000050000004B92E7FA3E2E47401DE90C8CBC8A45404B92E7FA3E2E4740FED2A23EC98D454037E3344415324740FED2A23EC98D454037E33444153247401DE90C8CBC8A45404B92E7FA3E2E47401DE90C8CBC8A4540
61260	57748	46.361297	46.391274000000003	43.107703999999998	43.083879000000003	Кадырова	0103000020E610000001000000050000004B92E7FA3E2E47401DE90C8CBC8A45404B92E7FA3E2E4740FED2A23EC98D454037E3344415324740FED2A23EC98D454037E33444153247401DE90C8CBC8A45404B92E7FA3E2E47401DE90C8CBC8A4540
61266	57748	46.361297	46.391274000000003	43.107703999999998	43.083879000000003	Гези-Хаджи	0103000020E610000001000000050000004B92E7FA3E2E47401DE90C8CBC8A45404B92E7FA3E2E4740FED2A23EC98D454037E3344415324740FED2A23EC98D454037E33444153247401DE90C8CBC8A45404B92E7FA3E2E47401DE90C8CBC8A4540
61042	57748	46.361297	46.391274000000003	43.107703999999998	43.083879000000003	А.А.Кадырова	0103000020E610000001000000050000004B92E7FA3E2E47401DE90C8CBC8A45404B92E7FA3E2E4740FED2A23EC98D454037E3344415324740FED2A23EC98D454037E33444153247401DE90C8CBC8A45404B92E7FA3E2E47401DE90C8CBC8A4540
61137	57763	46.088208999999999	46.111277999999999	43.092537	43.080745	М.Кишиева	0103000020E610000001000000050000003F1BB96E4A0B4740632827DA558A45403F1BB96E4A0B4740C1559E40D88B4540D461855B3E0E4740C1559E40D88B4540D461855B3E0E4740632827DA558A45403F1BB96E4A0B4740632827DA558A4540
61259	40448	46.347651999999997	46.372669999999999	43.172671999999999	43.146017999999998	А.А. Кадырова	0103000020E61000000100000005000000CA3159DC7F2C47404C50C3B7B0924540CA3159DC7F2C4740AB77B81D1A964540A4198BA6B32F4740AB77B81D1A964540A4198BA6B32F47404C50C3B7B0924540CA3159DC7F2C47404C50C3B7B0924540
61174	14507	46.229982	46.243555000000001	43.081206000000002	43.066414999999999	Дружбы	0103000020E610000001000000050000009755D80C701D47405F7B6649808845409755D80C701D4740971E4DF5648A45407EE36BCF2C1F4740971E4DF5648A45407EE36BCF2C1F47405F7B6649808845409755D80C701D47405F7B664980884540
61197	14507	46.229982	46.243555000000001	43.081206000000002	43.066414999999999	А.А. Кадырова	0103000020E610000001000000050000009755D80C701D47405F7B6649808845409755D80C701D4740971E4DF5648A45407EE36BCF2C1F4740971E4DF5648A45407EE36BCF2C1F47405F7B6649808845409755D80C701D47405F7B664980884540
75499	60641	46.059122000000002	46.532156999999998	43.202007999999999	42.841498000000001	А.А. Кадырова	0103000020E61000000100000005000000B03C484F9107474020D3DA34B66B4540B03C484F91074740E3C3EC65DB99454032AB77B81D444740E3C3EC65DB99454032AB77B81D44474020D3DA34B66B4540B03C484F9107474020D3DA34B66B4540
61204	40438	46.366840000000003	46.384796999999999	43.157383000000003	43.143709000000001	И. Цабаева	0103000020E61000000100000005000000AD6EF59CF42E47400892770E65924540AD6EF59CF42E474023F94A2025944540A94C31074131474023F94A2025944540A94C3107413147400892770E65924540AD6EF59CF42E47400892770E65924540
61147	16542	46.096977000000003	46.112876999999997	43.115411000000002	43.098087	Центральная	0103000020E610000001000000050000006BBB09BE690C4740D594641D8E8C45406BBB09BE690C4740A14CA3C9C58E45403CBCE7C0720E4740A14CA3C9C58E45403CBCE7C0720E4740D594641D8E8C45406BBB09BE690C4740D594641D8E8C4540
61254	57784	46.385516000000003	46.415923999999997	43.027799999999999	42.996116999999998	А.А. Кадырова	0103000020E61000000100000005000000D90A9A9658314740ACFE08C3807F4540D90A9A9658314740166A4DF38E8345408DCF64FF3C354740166A4DF38E8345408DCF64FF3C354740ACFE08C3807F4540D90A9A9658314740ACFE08C3807F4540
61210	13734	46.218581999999998	46.235030000000002	43.052028	43.032215000000001	Мамакаева	0103000020E6100000010000000500000044BFB67EFA1B474067B8019F1F84454044BFB67EFA1B4740F73C7FDAA886454019CA8976151E4740F73C7FDAA886454019CA8976151E474067B8019F1F84454044BFB67EFA1B474067B8019F1F844540
61183	13734	46.218581999999998	46.235030000000002	43.052028	43.032215000000001	А.А. Кадырова	0103000020E6100000010000000500000044BFB67EFA1B474067B8019F1F84454044BFB67EFA1B4740F73C7FDAA886454019CA8976151E4740F73C7FDAA886454019CA8976151E474067B8019F1F84454044BFB67EFA1B474067B8019F1F844540
61289	19286	46.327582999999997	46.340825000000002	43.029967999999997	43.017676000000002	А.А. Кадырова	0103000020E61000000100000005000000DFDC5F3DEE29474049F6083543824540DFDC5F3DEE29474098F6CDFDD583454061545227A02B474098F6CDFDD583454061545227A02B474049F6083543824540DFDC5F3DEE29474049F6083543824540
61251	40441	46.230286999999997	46.250903000000001	43.132519000000002	43.116464000000001	А.А. Кадырова	0103000020E61000000100000005000000D3D85E0B7A1D4740A794D74AE88E4540D3D85E0B7A1D4740A08CF161F6904540F1BBE9961D204740A08CF161F6904540F1BBE9961D204740A794D74AE88E4540D3D85E0B7A1D4740A794D74AE88E4540
61177	40450	46.381087000000001	46.399009	43.179890999999998	43.168365000000001	А.А. Кадырова	0103000020E6100000010000000500000023F77475C73047404165FCFB8C95454023F77475C730474020EC14AB06974540A3E716BA1233474020EC14AB06974540A3E716BA123347404165FCFB8C95454023F77475C73047404165FCFB8C954540
61110	57756	46.360058000000002	46.384079	42.991950000000003	42.971786999999999	Школьная	0103000020E61000000100000005000000E3546B61162E4740C7D63384637C4540E3546B61162E474034A2B437F87E45404A0A2C802931474034A2B437F87E45404A0A2C8029314740C7D63384637C4540E3546B61162E4740C7D63384637C4540
61410	57822	46.338794	46.356957999999999	43.061771	43.050434000000003	Школьная	0103000020E610000001000000050000005F0A0F9A5D2B4740A14D0E9F748645405F0A0F9A5D2B4740AD6BB41CE8874540D505BCCCB02D4740AD6BB41CE8874540D505BCCCB02D4740A14D0E9F748645405F0A0F9A5D2B4740A14D0E9F74864540
61355	57814	46.300302000000002	46.308152999999997	43.128124	43.12182	Кадырова	0103000020E610000001000000050000003276C24B70264740D6FF39CC978F45403276C24B7026474096EA025E669045400795B88E7127474096EA025E669045400795B88E71274740D6FF39CC978F45403276C24B70264740D6FF39CC978F4540
61236	40449	46.332056999999999	46.339657000000003	43.119537000000001	43.105499000000002	А.А. Кадырова	0103000020E6100000010000000500000035B401D8802A47405F61C1FD808D454035B401D8802A4740BBD408FD4C8F4540C26D6DE1792B4740BBD408FD4C8F4540C26D6DE1792B47405F61C1FD808D454035B401D8802A47405F61C1FD808D4540
61173	40451	46.267916999999997	46.291497999999997	42.972005000000003	42.935845	А.А. Кадырова	0103000020E610000001000000050000006E85B01A4B2247400490DAC4C97745406E85B01A4B2247403546EBA86A7C4540B96C74CE4F2547403546EBA86A7C4540B96C74CE4F2547400490DAC4C97745406E85B01A4B2247400490DAC4C9774540
61429	57825	46.289935	46.328904000000001	42.994680000000002	42.960175999999997	А.А. Кадырова	0103000020E610000001000000050000009E7B0F971C254740B933130CE77A45409E7B0F971C2547401EFE9AAC517F454005C3B986192A47401EFE9AAC517F454005C3B986192A4740B933130CE77A45409E7B0F971C254740B933130CE77A4540
61159	20308	46.380907000000001	46.398110000000003	43.125433000000001	43.114916999999998	А.А. Кадырова	0103000020E61000000100000005000000A3E8818FC13047409160AA99B58E4540A3E8818FC13047406A6B44300E904540F41ABB44F53247406A6B44300E904540F41ABB44F53247409160AA99B58E4540A3E8818FC13047409160AA99B58E4540
61178	40439	46.293779999999998	46.309491000000001	43.095360999999997	43.080956	Аллероева	0103000020E61000000100000005000000041C42959A2547401E3526C45C8A4540041C42959A2547402C280CCA348C454003B4AD669D2747402C280CCA348C454003B4AD669D2747401E3526C45C8A4540041C42959A2547401E3526C45C8A4540
61230	40446	46.340896000000001	46.353822999999998	43.094926999999998	43.085287999999998	А.А. Кадырова	0103000020E610000001000000050000002AABE97AA22B4740E15E99B7EA8A45402AABE97AA22B4740F2406491268C45404BC972124A2D4740F2406491268C45404BC972124A2D4740E15E99B7EA8A45402AABE97AA22B4740E15E99B7EA8A4540
61043	9930	45.441772999999998	45.453065000000002	43.944901999999999	43.940696000000003	Центральная	0103000020E61000000100000005000000BEA085048CB8464030BDFDB968F84540BEA085048CB8464066F6798CF2F845402BFBAE08FEB9464066F6798CF2F845402BFBAE08FEB9464030BDFDB968F84540BEA085048CB8464030BDFDB968F84540
61225	32961	45.656253999999997	45.670358	43.641857999999999	43.631405999999998	Гагарина	0103000020E6100000010000000500000041EF8D2100D44640C43F6CE9D1D0454041EF8D2100D446408656276728D24540554E7B4ACED546408656276728D24540554E7B4ACED54640C43F6CE9D1D0454041EF8D2100D44640C43F6CE9D1D04540
61209	57777	45.442841999999999	45.480769000000002	43.640161999999997	43.614973999999997	Бектамирова	0103000020E61000000100000005000000CAA5F10BAFB84640F5F1D077B7CE4540CAA5F10BAFB846402B1213D4F0D145401FF7ADD689BD46402B1213D4F0D145401FF7ADD689BD4640F5F1D077B7CE4540CAA5F10BAFB84640F5F1D077B7CE4540
75508	60650	45.581828999999999	45.608347000000002	43.609699999999997	43.595658	Победы	0103000020E61000000100000005000000A46E675F79CA4640E6CC76853ECC4540A46E675F79CA4640832F4CA60ACE454053CF8250DECD4640832F4CA60ACE454053CF8250DECD4640E6CC76853ECC4540A46E675F79CA4640E6CC76853ECC4540
75491	60635	45.053314	45.854692	44.009810999999999	43.508899	Чехова	0103000020E61000000100000005000000A0353FFED2864640CAFB389A23C14540A0353FFED28646400E12A27C410146409013268C66ED46400E12A27C410146409013268C66ED4640CAFB389A23C14540A0353FFED2864640CAFB389A23C14540
61195	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Советская	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61093	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Северная	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61135	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Пролетарская	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61099	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Октябрьская	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61140	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Мира	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61075	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Ленина	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61152	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Кооперативная	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61192	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Гагарина	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
61155	57751	45.286875999999999	45.333489999999998	43.658575999999996	43.641824999999997	Алленова	0103000020E61000000100000005000000EF004F5AB8A44640AA60545227D24540EF004F5AB8A446401AF7E6374CD4454082C5E1CCAFAA46401AF7E6374CD4454082C5E1CCAFAA4640AA60545227D24540EF004F5AB8A44640AA60545227D24540
75509	60651	45.113923999999997	45.154401999999997	43.728248000000001	43.707320000000003	Л. Голикова	0103000020E61000000100000005000000601DC70F958E464043E7357689DA4540601DC70F958E46404FB0FF3A37DD4540EF37DA71C39346404FB0FF3A37DD4540EF37DA71C393464043E7357689DA4540601DC70F958E464043E7357689DA4540
61257	57785	45.231549000000001	45.268092000000003	43.719258000000004	43.688302	Клубная	0103000020E61000000100000005000000F435CB65A39D4640BDE2A9471AD84540F435CB65A39D464075B169A510DC4540DD28B2D650A2464075B169A510DC4540DD28B2D650A24640BDE2A9471AD84540F435CB65A39D4640BDE2A9471AD84540
61003	57746	44.833398000000003	45.489096000000004	43.728698000000001	43.446399999999997	им. Лаудаева	0103000020E61000000100000005000000A24621C9AC6A46409A779CA223B94540A24621C9AC6A46408F54DFF945DD45405E4D9EB29ABE46408F54DFF945DD45405E4D9EB29ABE46409A779CA223B94540A24621C9AC6A46409A779CA223B94540
61191	57774	45.227263999999998	45.273428000000003	43.626367999999999	43.598505000000003	А.А.Кадырова	0103000020E6100000010000000500000071C79BFC169D46400ABFD4CF9BCC454071C79BFC169D464066A19DD32CD04540C5E74EB0FFA2464066A19DD32CD04540C5E74EB0FFA246400ABFD4CF9BCC454071C79BFC169D46400ABFD4CF9BCC4540
61228	57774	45.227263999999998	45.273428000000003	43.626367999999999	43.598505000000003	 А.А.Кадырова	0103000020E6100000010000000500000071C79BFC169D46400ABFD4CF9BCC454071C79BFC169D464066A19DD32CD04540C5E74EB0FFA2464066A19DD32CD04540C5E74EB0FFA246400ABFD4CF9BCC454071C79BFC169D46400ABFD4CF9BCC4540
61369	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	Школьная	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61072	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	Центральная	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61127	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	Пионерская	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61290	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	Новый городок	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61041	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	Московская	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61303	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	Мира	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61109	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	Ленина	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61186	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	А.А.Кадырова	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61131	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	А-Х.Кадырова	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61258	45555	45.101509	45.145921999999999	43.693888000000001	43.663682000000001	40 лет Победы	0103000020E61000000100000005000000F59F353FFE8C4640D1782288F3D44540F59F353FFE8C46401E8B6D52D1D845402AE27492AD9246401E8B6D52D1D845402AE27492AD924640D1782288F3D44540F59F353FFE8C4640D1782288F3D44540
61494	57833	45.069529000000003	45.116008000000001	43.514032	43.463270999999999	Центральная	0103000020E61000000100000005000000D28F8653E6884640B517D1764CBB4540D28F8653E68846407A8CF2CCCBC145408509A359D98E46407A8CF2CCCBC145408509A359D98E4640B517D1764CBB4540D28F8653E6884640B517D1764CBB4540
75565	60688	44.833398000000003	45.489096000000004	43.728698000000001	43.446399999999997	Лаудаева	0103000020E61000000100000005000000A24621C9AC6A46409A779CA223B94540A24621C9AC6A46408F54DFF945DD45405E4D9EB29ABE46408F54DFF945DD45405E4D9EB29ABE46409A779CA223B94540A24621C9AC6A46409A779CA223B94540
75483	60630	45.032249	45.067247000000002	43.700347000000001	43.681978999999998	Х. Исаева	0103000020E61000000100000005000000132A38BC2084464086C77E164BD74540132A38BC20844640056D72F8A4D9454087E0B88C9B884640056D72F8A4D9454087E0B88C9B88464086C77E164BD74540132A38BC2084464086C77E164BD74540
61051	57749	45.089641999999998	45.109727999999997	43.567297000000003	43.554910999999997	Ленина	0103000020E610000001000000050000008C2C9963798B46406798DA5207C745408C2C9963798B4640390F27309DC845404DBA2D910B8E4640390F27309DC845404DBA2D910B8E46406798DA5207C745408C2C9963798B46406798DA5207C74540
61136	14831	45.561140999999999	45.589976999999998	42.755657999999997	42.747177999999998	А. Кадырова	0103000020E61000000100000005000000EDB8E177D3C7464035255987A35F4540EDB8E177D3C74640FA7ABE66B96045403332C85D84CB4640FA7ABE66B96045403332C85D84CB464035255987A35F4540EDB8E177D3C7464035255987A35F4540
61292	57790	45.563800000000001	45.586545000000001	42.743760999999999	42.721623000000001	Ченты-Аргунская	0103000020E610000001000000050000000EBE30992AC846404D8578245E5C45400EBE30992AC846402785798F335F4540F05014E813CB46402785798F335F4540F05014E813CB46404D8578245E5C45400EBE30992AC846404D8578245E5C4540
61278	57790	45.563800000000001	45.586545000000001	42.743760999999999	42.721623000000001	Хачероева	0103000020E610000001000000050000000EBE30992AC846404D8578245E5C45400EBE30992AC846402785798F335F4540F05014E813CB46402785798F335F4540F05014E813CB46404D8578245E5C45400EBE30992AC846404D8578245E5C4540
61293	57790	45.563800000000001	45.586545000000001	42.743760999999999	42.721623000000001	Ушкалоевская	0103000020E610000001000000050000000EBE30992AC846404D8578245E5C45400EBE30992AC846402785798F335F4540F05014E813CB46402785798F335F4540F05014E813CB46404D8578245E5C45400EBE30992AC846404D8578245E5C4540
61286	57790	45.563800000000001	45.586545000000001	42.743760999999999	42.721623000000001	М.Я.Узуева	0103000020E610000001000000050000000EBE30992AC846404D8578245E5C45400EBE30992AC846402785798F335F4540F05014E813CB46402785798F335F4540F05014E813CB46404D8578245E5C45400EBE30992AC846404D8578245E5C4540
61316	57790	45.563800000000001	45.586545000000001	42.743760999999999	42.721623000000001	Дадаева	0103000020E610000001000000050000000EBE30992AC846404D8578245E5C45400EBE30992AC846402785798F335F4540F05014E813CB46402785798F335F4540F05014E813CB46404D8578245E5C45400EBE30992AC846404D8578245E5C4540
61294	57790	45.563800000000001	45.586545000000001	42.743760999999999	42.721623000000001	А.Кадырова	0103000020E610000001000000050000000EBE30992AC846404D8578245E5C45400EBE30992AC846402785798F335F4540F05014E813CB46402785798F335F4540F05014E813CB46404D8578245E5C45400EBE30992AC846404D8578245E5C4540
61299	13878	46.346528999999997	46.371932999999999	43.336590999999999	43.314495999999998	Школьная	0103000020E61000000100000005000000CB0EF10F5B2C4740855CA96741A84540CB0EF10F5B2C47406090F46915AB4540CEA623809B2F47406090F46915AB4540CEA623809B2F4740855CA96741A84540CB0EF10F5B2C4740855CA96741A84540
61188	13878	46.346528999999997	46.371932999999999	43.336590999999999	43.314495999999998	А. Кадырова	0103000020E61000000100000005000000CB0EF10F5B2C4740855CA96741A84540CB0EF10F5B2C47406090F46915AB4540CEA623809B2F47406090F46915AB4540CEA623809B2F4740855CA96741A84540CB0EF10F5B2C4740855CA96741A84540
61342	57807	46.230350000000001	46.242728999999997	43.418458999999999	43.409467999999997	Терская	0103000020E610000001000000050000001A51DA1B7C1D474017618A7269B445401A51DA1B7C1D4740C2DB831090B5454038656EBE111F4740C2DB831090B5454038656EBE111F474017618A7269B445401A51DA1B7C1D474017618A7269B44540
75522	60662	45.915301999999997	46.422446000000001	43.462898000000003	43.176597000000001	Мартовская	0103000020E6100000010000000500000050FBAD9D28F546402EC901BB9A96454050FBAD9D28F5464021B1DD3D40BB4540BB29E5B51236474021B1DD3D40BB4540BB29E5B5123647402EC901BB9A96454050FBAD9D28F546402EC901BB9A964540
61345	57810	46.234617	46.260210000000001	43.275264	43.253863000000003	Жукова	0103000020E61000000100000005000000F60A0BEE071E47400D5531957EA04540F60A0BEE071E474011E2CAD93BA34540CC0BB08F4E21474011E2CAD93BA34540CC0BB08F4E2147400D5531957EA04540F60A0BEE071E47400D5531957EA04540
61198	13656	46.340052	46.369598000000003	43.260677999999999	43.247362000000003	Х. Нурадилова	0103000020E610000001000000050000003E78EDD2862B4740F722DA8EA99F45403E78EDD2862B4740B2648EE55DA145406155BDFC4E2F4740B2648EE55DA145406155BDFC4E2F4740F722DA8EA99F45403E78EDD2862B4740F722DA8EA99F4540
61158	13656	46.340052	46.369598000000003	43.260677999999999	43.247362000000003	А. Кадырова	0103000020E610000001000000050000003E78EDD2862B4740F722DA8EA99F45403E78EDD2862B4740B2648EE55DA145406155BDFC4E2F4740B2648EE55DA145406155BDFC4E2F4740F722DA8EA99F45403E78EDD2862B4740F722DA8EA99F4540
61223	48959	46.150812999999999	46.168770000000002	43.395083999999997	43.382812999999999	А.А. Кадырова	0103000020E61000000100000005000000E46723D74D134740E8BD310400B14540E46723D74D1347402096CD1C92B24540E1455F419A1547402096CD1C92B24540E1455F419A154740E8BD310400B14540E46723D74D134740E8BD310400B14540
61212	13848	46.302951999999998	46.322884999999999	43.322898000000002	43.312640000000002	Школьная	0103000020E61000000100000005000000FF209221C7264740F2B5679604A84540FF209221C7264740CFF8BEB854A945403AAFB14B54294740CFF8BEB854A945403AAFB14B54294740F2B5679604A84540FF209221C7264740F2B5679604A84540
61220	57779	46.379021000000002	46.403365000000001	43.227953999999997	43.202388999999997	М. Эсембаева	0103000020E61000000100000005000000A5BF97C283304740FA08FCE1E7994540A5BF97C283304740067FBF982D9D4540EFACDD76A1334740067FBF982D9D4540EFACDD76A1334740FA08FCE1E7994540A5BF97C283304740FA08FCE1E7994540
61194	14290	45.978884000000001	45.997928999999999	43.326695000000001	43.314495999999998	А. Кадырова	0103000020E61000000100000005000000F14927124CFD4640855CA96741A84540F14927124CFD464024624A24D1A94540705D3123BCFF464024624A24D1A94540705D3123BCFF4640855CA96741A84540F14927124CFD4640855CA96741A84540
61081	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	пр. А. Кадырова	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
60970	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Школьная	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61023	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Центральная	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61604	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Победы	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
60979	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Октябрьская	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61080	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Котовского	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61078	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Кирова	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61025	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	Интернациональная	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61243	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	А. Кадырова	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61033	13174	46.057765000000003	46.141066000000002	43.373057000000003	43.333824	84-й Морской бригады	0103000020E610000001000000050000003EEDF0D764074740594FADBEBAAA45403EEDF0D7640747409E45EF54C0AF4540ED4960730E1247409E45EF54C0AF4540ED4960730E124740594FADBEBAAA45403EEDF0D764074740594FADBEBAAA4540
61272	11207	46.395451000000001	46.409500999999999	43.253698999999997	43.241458000000002	Мира	0103000020E61000000100000005000000D3156C239E324740C5AD8218E89E4540D3156C239E3247409203763579A04540F3565D876A3447409203763579A04540F3565D876A344740C5AD8218E89E4540D3156C239E324740C5AD8218E89E4540
61387	57817	46.277484000000001	46.296708000000002	43.260933999999999	43.247611999999997	Школьная	0103000020E61000000100000005000000E6948098842347406F0C01C0B19F4540E6948098842347400D350A4966A14540153B1A87FA2547400D350A4966A14540153B1A87FA2547406F0C01C0B19F4540E6948098842347406F0C01C0B19F4540
61283	14559	46.080798000000001	46.111142999999998	43.443486999999998	43.432765000000003	Химикова	0103000020E6100000010000000500000086CABF96570A47403EEDF0D764B7454086CABF96570A4740BF99982EC4B84540F4160FEF390E4740BF99982EC4B84540F4160FEF390E47403EEDF0D764B7454086CABF96570A47403EEDF0D764B74540
61291	14420	46.276010999999997	46.293025	43.421438000000002	43.413697999999997	Кадырова	0103000020E610000001000000050000000A2B155454234740D6355A0EF4B445400A2B15545423474055A52DAEF1B5454088F4DBD78125474055A52DAEF1B5454088F4DBD781254740D6355A0EF4B445400A2B155454234740D6355A0EF4B44540
61448	57830	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Заводская	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
75496	57830	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Бакина	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
75510	60646	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Гагарина	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
75502	60646	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Бр. Гайтукаевых	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
75531	60646	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	2-ой пер. Мичурина	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61218	27326	45.725721	45.761006999999999	43.343423000000001	43.325600000000001	У.Р. Даудова	0103000020E610000001000000050000009D82FC6CE4DC4640EFC9C342ADA945409D82FC6CE4DC4640DCD8EC48F5AB4540778368AD68E14640DCD8EC48F5AB4540778368AD68E14640EFC9C342ADA945409D82FC6CE4DC4640EFC9C342ADA94540
61284	27326	45.725721	45.761006999999999	43.343423000000001	43.325600000000001	И.Х. Хаджиханова	0103000020E610000001000000050000009D82FC6CE4DC4640EFC9C342ADA945409D82FC6CE4DC4640DCD8EC48F5AB4540778368AD68E14640DCD8EC48F5AB4540778368AD68E14640EFC9C342ADA945409D82FC6CE4DC4640EFC9C342ADA94540
75515	60656	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Кадырова	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61068	57750	45.588197999999998	45.603290000000001	43.413317999999997	43.403606000000003	Черкаская	0103000020E610000001000000050000004BC972124ACB4640153C855CA9B345404BC972124ACB46408F6CAE9AE7B445407E00529B38CD46408F6CAE9AE7B445407E00529B38CD4640153C855CA9B345404BC972124ACB4640153C855CA9B34540
60978	12524	45.379114999999999	45.410007999999998	43.411518000000001	43.397095	Шоссейная	0103000020E6100000010000000500000026361FD786B04640DB334B02D4B2454026361FD786B0464090DB2F9FACB44540978C63247BB4464090DB2F9FACB44540978C63247BB44640DB334B02D4B2454026361FD786B04640DB334B02D4B24540
75511	60653	45.745628000000004	45.772739000000001	43.260874999999999	43.246842999999998	Шефская	0103000020E61000000100000005000000AF7D01BD70DF46408E1F2A8D989F4540AF7D01BD70DF464008AC1C5A64A1454000AC8E1CE9E2464008AC1C5A64A1454000AC8E1CE9E246408E1F2A8D989F4540AF7D01BD70DF46408E1F2A8D989F4540
9646	40254	45.411454999999997	45.453325	43.406992000000002	43.394088000000004	Школьный	0103000020E610000001000000050000004963B48EAAB446407FDFBF7971B245404963B48EAAB44640E8DD585018B44540C7BAB88D06BA4640E8DD585018B44540C7BAB88D06BA46407FDFBF7971B245404963B48EAAB446407FDFBF7971B24540
61122	9453	45.554098000000003	45.581612999999997	43.320393000000003	43.301678000000003	Береговая	0103000020E61000000100000005000000B763EAAEECC646401BF67B629DA64540B763EAAEECC64640056F48A302A94540D7F6764B72CA4640056F48A302A94540D7F6764B72CA46401BF67B629DA64540B763EAAEECC646401BF67B629DA64540
61104	12652	45.170140000000004	45.190451000000003	43.423160000000003	43.410966999999999	Тракторная	0103000020E61000000100000005000000E8DEC325C79546401C5E10919AB44540E8DEC325C7954640D97C5C1B2AB64540C93EC8B260984640D97C5C1B2AB64540C93EC8B2609846401C5E10919AB44540E8DEC325C79546401C5E10919AB44540
61126	57761	45.298617	45.314194000000001	43.405053000000002	43.396106000000003	Школьная	0103000020E61000000100000005000000CB83F41439A64640ECDFF599B3B24540CB83F41439A64640C712D6C6D8B34540BA4C4D8237A84640C712D6C6D8B34540BA4C4D8237A84640ECDFF599B3B24540CB83F41439A64640ECDFF599B3B24540
61102	12556	45.370797000000003	45.396631999999997	43.409880000000001	43.401910000000001	Молодежная	0103000020E610000001000000050000003B3AAE4676AF4640BAF770C971B345403B3AAE4676AF46406AA4A5F276B4454006465ED6C4B246406AA4A5F276B4454006465ED6C4B24640BAF770C971B345403B3AAE4676AF4640BAF770C971B34540
61103	57755	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Школьная	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61113	57755	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Нурадилова	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61151	57755	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Нагорная	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61125	57755	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Кадырова	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61242	57755	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	Арсаханова	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61245	57755	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	50-лет Октября	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
61247	57783	45.708851000000003	45.744791999999997	43.241314000000003	43.218094000000001	Октябрьская	0103000020E61000000100000005000000535E2BA1BBDA464017BA1281EA9B4540535E2BA1BBDA464092088D60E39E45404529215855DF464092088D60E39E45404529215855DF464017BA1281EA9B4540535E2BA1BBDA464017BA1281EA9B4540
61088	57753	45.847524	45.872138	43.471488999999998	43.458775000000003	Ленина	0103000020E610000001000000050000009D499BAA7BEC4640789CA223B9BA45409D499BAA7BEC46403DB665C059BC4540A7CCCD37A2EF46403DB665C059BC4540A7CCCD37A2EF4640789CA223B9BA45409D499BAA7BEC4640789CA223B9BA4540
61304	57794	45.713028000000001	45.724131	43.371569000000001	43.364727000000002	Садовая 	0103000020E61000000100000005000000EF90628044DB4640EE7BD45FAFAE4540EF90628044DB46408D9AAF928FAF454088821953B0DC46408D9AAF928FAF454088821953B0DC4640EE7BD45FAFAE4540EF90628044DB4640EE7BD45FAFAE4540
61166	12221	45.492465000000003	45.564402000000001	43.266756999999998	43.250566999999997	Шерипова	0103000020E610000001000000050000005BB6D61709BF4640793A579412A045405BB6D61709BF4640527DE71725A2454004E621533EC84640527DE71725A2454004E621533EC84640793A579412A045405BB6D61709BF4640793A579412A04540
61168	12221	45.492465000000003	45.564402000000001	43.266756999999998	43.250566999999997	Нурадилова	0103000020E610000001000000050000005BB6D61709BF4640793A579412A045405BB6D61709BF4640527DE71725A2454004E621533EC84640527DE71725A2454004E621533EC84640793A579412A045405BB6D61709BF4640793A579412A04540
61165	57769	46.043886999999998	46.063738999999998	42.970871000000002	42.956243999999998	Школьная	0103000020E610000001000000050000001ADCD6169E054740847F1134667A45401ADCD6169E05474042D13C80457C4540683D7C992808474042D13C80457C4540683D7C9928084740847F1134667A45401ADCD6169E054740847F1134667A4540
61172	57771	46.139333000000001	46.154612999999998	43.00103	42.992398000000001	Школьная	0103000020E610000001000000050000007520EBA9D5114740D34ECDE5067F45407520EBA9D51147404E2844C021804540AA44D95BCA1347404E2844C021804540AA44D95BCA134740D34ECDE5067F45407520EBA9D5114740D34ECDE5067F4540
61157	9844	46.036071	46.071095999999997	43.032901000000003	43.001854000000002	Центральная	0103000020E61000000100000005000000C1AA7AF99D044740F3AE7AC03C804540C1AA7AF99D044740BB809719368445402E7079AC19094740BB809719368445402E7079AC19094740F3AE7AC03C804540C1AA7AF99D044740F3AE7AC03C804540
61121	9844	46.036071	46.071095999999997	43.032901000000003	43.001854000000002	А.А.Кадырова	0103000020E61000000100000005000000C1AA7AF99D044740F3AE7AC03C804540C1AA7AF99D044740BB809719368445402E7079AC19094740BB809719368445402E7079AC19094740F3AE7AC03C804540C1AA7AF99D044740F3AE7AC03C804540
60969	57741	45.921320000000001	45.945565999999999	42.993915000000001	42.974471999999999	Школьная	0103000020E610000001000000050000004B9352D0EDF54640116F9D7FBB7C45404B9352D0EDF546407E00529B387F4540D21A834E08F946407E00529B387F4540D21A834E08F94640116F9D7FBB7C45404B9352D0EDF54640116F9D7FBB7C4540
61069	10457	45.900478999999997	45.916145999999998	42.982340999999998	42.972599000000002	Школьная	0103000020E610000001000000050000000DDE57E542F34640A88FC01F7E7C45400DDE57E542F346408D429259BD7D45403C2EAA4544F546408D429259BD7D45403C2EAA4544F54640A88FC01F7E7C45400DDE57E542F34640A88FC01F7E7C4540
61123	10555	45.842179000000002	45.875380999999997	42.957649000000004	42.923797999999998	А.А.Кадырова	0103000020E6100000010000000500000062307F85CCEB46401B0E4B033F76454062307F85CCEB46400806103E947A454017450F7C0CF046400806103E947A454017450F7C0CF046401B0E4B033F76454062307F85CCEB46401B0E4B033F764540
61133	10036	46.063271999999998	46.087482000000001	43.048622000000002	43.033526999999999	Школьная	0103000020E610000001000000050000005260014C190847403944DC9C4A8445405260014C19084740DDEEE53E398645408D7E349C320B4740DDEEE53E398645408D7E349C320B47403944DC9C4A8445405260014C190847403944DC9C4A844540
61295	10748	46.159768999999997	46.175201999999999	43.034232000000003	43.022165000000001	Новая	0103000020E6100000010000000500000012F5824F73144740D40E7F4DD682454012F5824F73144740043DD4B661844540CE18E6046D164740043DD4B661844540CE18E6046D164740D40E7F4DD682454012F5824F73144740D40E7F4DD6824540
61144	9526	46.080249999999999	46.090761000000001	42.961773000000001	42.951518999999998	Школьная	0103000020E6100000010000000500000083C0CAA1450A4740E542E55FCB79454083C0CAA1450A47408196AE601B7B45404A60730E9E0B47408196AE601B7B45404A60730E9E0B4740E542E55FCB79454083C0CAA1450A4740E542E55FCB794540
60977	9684	46.11647	46.133071000000001	42.970356000000002	42.940677000000001	Х.Бекбулатова	0103000020E61000000100000005000000897B2C7DE80E4740B98C9B1A68784540897B2C7DE80E47401BBD1AA0347C4540E4857478081147401BBD1AA0347C4540E485747808114740B98C9B1A68784540897B2C7DE80E4740B98C9B1A68784540
61002	9684	46.11647	46.133071000000001	42.970356000000002	42.940677000000001	А.А.Кадырова	0103000020E61000000100000005000000897B2C7DE80E4740B98C9B1A68784540897B2C7DE80E47401BBD1AA0347C4540E4857478081147401BBD1AA0347C4540E485747808114740B98C9B1A68784540897B2C7DE80E4740B98C9B1A68784540
61115	10650	46.227474999999998	46.256858999999999	42.980975999999998	42.929085999999998	А.А.Кадырова	0103000020E610000001000000050000002CD49AE61D1D4740F295404AEC7645402CD49AE61D1D474098141F9F907D4540755776C1E020474098141F9F907D4540755776C1E0204740F295404AEC7645402CD49AE61D1D4740F295404AEC764540
61146	10152	46.094110999999998	46.113218000000003	43.063904999999998	43.046402	Школьная	0103000020E61000000100000005000000D09849D40B0C4740083C3080F0854540D09849D40B0C47408386FE092E884540C6A86BED7D0E47408386FE092E884540C6A86BED7D0E4740083C3080F0854540D09849D40B0C4740083C3080F0854540
61559	9416	46.085028999999999	46.122641999999999	42.977111000000001	42.946088000000003	с.Дуц-Хутор	0103000020E61000000100000005000000151BF33AE20A4740AC915D6919794540151BF33AE20A4740EBC726F9117D4540DA8EA9BBB20F4740EBC726F9117D4540DA8EA9BBB20F4740AC915D6919794540151BF33AE20A4740AC915D6919794540
61271	9416	46.085028999999999	46.122641999999999	42.977111000000001	42.946088000000003	Школьная	0103000020E61000000100000005000000151BF33AE20A4740AC915D6919794540151BF33AE20A4740EBC726F9117D4540DA8EA9BBB20F4740EBC726F9117D4540DA8EA9BBB20F4740AC915D6919794540151BF33AE20A4740AC915D6919794540
61066	9416	46.085028999999999	46.122641999999999	42.977111000000001	42.946088000000003	Ш.Мугуева	0103000020E61000000100000005000000151BF33AE20A4740AC915D6919794540151BF33AE20A4740EBC726F9117D4540DA8EA9BBB20F4740EBC726F9117D4540DA8EA9BBB20F4740AC915D6919794540151BF33AE20A4740AC915D6919794540
61134	9416	46.085028999999999	46.122641999999999	42.977111000000001	42.946088000000003	Х.Нурадилова	0103000020E61000000100000005000000151BF33AE20A4740AC915D6919794540151BF33AE20A4740EBC726F9117D4540DA8EA9BBB20F4740EBC726F9117D4540DA8EA9BBB20F4740AC915D6919794540151BF33AE20A4740AC915D6919794540
60975	9416	46.085028999999999	46.122641999999999	42.977111000000001	42.946088000000003	А.А.Кадырова	0103000020E61000000100000005000000151BF33AE20A4740AC915D6919794540151BF33AE20A4740EBC726F9117D4540DA8EA9BBB20F4740EBC726F9117D4540DA8EA9BBB20F4740AC915D6919794540151BF33AE20A4740AC915D6919794540
61130	9959	46.012993000000002	46.020881000000003	43.066118000000003	43.055124999999997	Кадырова	0103000020E61000000100000005000000D9092FC1A9014740931804560E874540D9092FC1A9014740A6D6FB8D76884540CC0D863AAC024740A6D6FB8D76884540CC0D863AAC024740931804560E874540D9092FC1A9014740931804560E874540
61139	10271	46.099958999999998	46.115931000000003	43.017629999999997	43.007404999999999	Центральная	0103000020E610000001000000050000006EF8DD74CB0C4740D769A4A5F28045406EF8DD74CB0C4740D8B628B341824540DACBB6D3D60E4740D8B628B341824540DACBB6D3D60E4740D769A4A5F28045406EF8DD74CB0C4740D769A4A5F2804540
61141	57764	45.355508	45.383769000000001	43.18515	43.150399	А.Кадырова	0103000020E61000000100000005000000B2BB404981AD4640F12C414640934540B2BB404981AD46405D6DC5FEB2974540FC1BB4571FB146405D6DC5FEB2974540FC1BB4571FB14640F12C414640934540B2BB404981AD4640F12C414640934540
61116	57758	45.404789000000001	45.434092	43.268425000000001	43.253613000000001	 Школьная	0103000020E61000000100000005000000E9633E20D0B34640946B0A6476A04540E9633E20D0B34640E3361AC05BA2454045BA9F5390B74640E3361AC05BA2454045BA9F5390B74640946B0A6476A04540E9633E20D0B34640946B0A6476A04540
61201	57775	45.18074	45.224578000000001	43.191637	43.131518999999997	Школьная	0103000020E610000001000000050000001E8A027D22974640BCE6559DD59045401E8A027D229746400EDAAB8F8798454057B3CEF8BE9C46400EDAAB8F8798454057B3CEF8BE9C4640BCE6559DD59045401E8A027D22974640BCE6559DD5904540
61018	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Школьная	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61011	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Шерипова	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61021	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Чапаева	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61256	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Х.Нурадилова	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61250	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Садовая	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61040	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Орджоникидзе	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61087	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Мамакаева	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61083	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Им.Кунтаева	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61106	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Грейдерная	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61067	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Гайрбекова	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61307	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Гагарина	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61190	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	Ахмата Кадырова	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
60991	33028	45.256810000000002	45.309126999999997	43.214592000000003	43.176577000000002	А.Кадырова	0103000020E6100000010000000500000094A46B26DFA04640E71C3C139A96454094A46B26DFA04640DBFD2AC0779B4540C1A7397991A74640DBFD2AC0779B4540C1A7397991A74640E71C3C139A96454094A46B26DFA04640E71C3C139A964540
61149	57765	46.072910999999998	46.107154999999999	43.212547999999998	43.191650000000003	М.Даудова	0103000020E610000001000000050000006342CC2555094740A323B9FC879845406342CC2555094740446ADAC5349B45402B4D4A41B70D4740446ADAC5349B45402B4D4A41B70D4740A323B9FC879845406342CC2555094740A323B9FC87984540
60614	57688	44.650284999999997	44.696494000000001	43.773954000000003	43.752867000000002	Кирова	0103000020E61000000100000005000000280AF4893C5346406B9E23F25DE04540280AF4893C534640E04DB7EC10E345401CEE23B726594640E04DB7EC10E345401CEE23B7265946406B9E23F25DE04540280AF4893C5346406B9E23F25DE04540
60604	57686	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Мира	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60669	57686	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Кирова	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60730	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	проспект Коста	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60683	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	проспект Доватора	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60733	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	площадь Победы	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60720	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Шмулевича	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60648	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Чкалова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60773	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Церетели	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60804	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Церетели	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60653	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Цейская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60768	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Тогоева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60697	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Тельмана	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60721	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Тамаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60657	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Севастопольская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60799	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Революции	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60647	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Пушкинская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60798	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Пушкинская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60820	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Пролетарская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60695	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Пожарского	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60684	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Павленко	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60689	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Осетинская горка	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60770	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Осетинская горка	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60788	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Огурцова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60722	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Николаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60625	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Московская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60726	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Молодежная	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60821	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Мичурина /Остаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60676	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Миллеров	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60816	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Миллера	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60698	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Маркова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60737	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	М. Пехотинцев	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60703	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Леонова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60755	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Ленина	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60655	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Леваневского	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60782	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Кырджалийская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60690	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Кутузова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60642	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Куйбышева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60658	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Коцоева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60706	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Коста проспект	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60753	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Коста Хетагурова/Кантемирова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60693	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Коблова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60811	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Кирова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60738	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Кесаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60785	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Калоева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60659	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Калинина	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60823	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	К. Хетагурова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60727	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	К. Маркса	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60702	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Иристонская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60734	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Иристонская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60724	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Интернациональная	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60660	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	З. Космодемьянской	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60680	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Доватора проспект	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60650	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Доватора пр	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60709	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Дзусова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60825	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Джимиева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60644	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Джанаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60640	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Гэсовская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60641	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Гугкаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60675	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Грибоедова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60756	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Герцена	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60701	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Гастелло	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60707	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Галковского	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60646	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Гадиева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60643	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Гагарина	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60679	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Владикавказская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60708	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Весенняя	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60776	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Ватутина	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60774	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	В. Баллаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60665	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Бибилова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60781	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Бзарова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60652	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Барбашова	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60656	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	Армянская	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60661	1856	44.618780999999998	44.741554000000001	43.087612999999997	42.949672	А. Кесаева	0103000020E610000001000000050000006E313F37344F4640A5F622DA8E7945406E313F37344F46402BDA1CE7368B4540E71BD13DEB5E46402BDA1CE7368B4540E71BD13DEB5E4640A5F622DA8E7945406E313F37344F4640A5F622DA8E794540
60618	57689	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Ленина	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60834	32573	44.694473000000002	44.737223999999998	43.166674999999998	43.117879000000002	Орджоникидзе	0103000020E610000001000000050000003E7AC37DE45846404EF1B8A8168F45403E7AC37DE4584640C8073D9B55954540C4E9245B5D5E4640C8073D9B55954540C4E9245B5D5E46404EF1B8A8168F45403E7AC37DE45846404EF1B8A8168F4540
60817	57707	44.796126999999998	44.844672000000003	43.080007000000002	43.044524000000003	Бибилова	0103000020E61000000100000005000000363B527DE76546408DF161F6B2854540363B527DE7654640BD395CAB3D8A454068EC4B361E6C4640BD395CAB3D8A454068EC4B361E6C46408DF161F6B2854540363B527DE76546408DF161F6B2854540
60754	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Ю. Кучиева	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60758	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Школьная	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60747	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Ф. Кастро	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60793	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Терешковой	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60751	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Р. Люксембург	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60735	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Пролетарская	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60682	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Павла Тедеева	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60766	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Октябрьская	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60796	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Мира	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60778	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Маяковского	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60704	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Ленина	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60771	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Коммунальная	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60760	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Кирова	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60744	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Калинина	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60784	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Гагарина	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60822	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Владикавказская	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60792	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	Вильямса	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60743	57693	44.732050000000001	44.758190999999997	43.074607999999998	43.034982999999997	50 Лет Октября	0103000020E61000000100000005000000B6847CD0B35D46403E75AC527A844540B6847CD0B35D46408E0244C18C8945408E8F16670C6146408E0244C18C8945408E8F16670C6146403E75AC527A844540B6847CD0B35D46403E75AC527A844540
60849	57695	44.740287000000002	44.771521999999997	43.090311999999997	43.048839999999998	Ю. Кучиева	0103000020E61000000100000005000000B55373B9C15E46404A5E9D6340864540B55373B9C15E4640DA37F7578F8B45407F129F3BC1624640DA37F7578F8B45407F129F3BC16246404A5E9D6340864540B55373B9C15E46404A5E9D6340864540
60678	57692	44.313192000000001	44.957554000000002	43.27852	42.697687000000002	Некрасова	0103000020E6100000010000000500000036AFEAAC1628464014ECBFCE4D59454036AFEAAC1628464016A4198BA6A34540B6132521917A464016A4198BA6A34540B6132521917A464014ECBFCE4D59454036AFEAAC1628464014ECBFCE4D594540
60713	57692	44.313192000000001	44.957554000000002	43.27852	42.697687000000002	Комсомольская	0103000020E6100000010000000500000036AFEAAC1628464014ECBFCE4D59454036AFEAAC1628464016A4198BA6A34540B6132521917A464016A4198BA6A34540B6132521917A464014ECBFCE4D59454036AFEAAC1628464014ECBFCE4D594540
60688	57692	44.313192000000001	44.957554000000002	43.27852	42.697687000000002	Коминтерна	0103000020E6100000010000000500000036AFEAAC1628464014ECBFCE4D59454036AFEAAC1628464016A4198BA6A34540B6132521917A464016A4198BA6A34540B6132521917A464014ECBFCE4D59454036AFEAAC1628464014ECBFCE4D594540
60673	57692	44.313192000000001	44.957554000000002	43.27852	42.697687000000002	Калоева	0103000020E6100000010000000500000036AFEAAC1628464014ECBFCE4D59454036AFEAAC1628464016A4198BA6A34540B6132521917A464016A4198BA6A34540B6132521917A464014ECBFCE4D59454036AFEAAC1628464014ECBFCE4D594540
60845	32826	44.551730999999997	44.564981000000003	43.020589000000001	43.003402999999999	Губа Губиева	0103000020E610000001000000050000003D98141F9F464640A9DA6E826F8045403D98141F9F46464024D40CA9A282454042EE224C5148464024D40CA9A282454042EE224C51484640A9DA6E826F8045403D98141F9F464640A9DA6E826F804540
60870	57734	44.493564999999997	44.541660999999998	43.120247999999997	43.098461999999998	Крупской	0103000020E61000000100000005000000A1B94E232D3F46400AF31E679A8C4540A1B94E232D3F464067B45549648F45406342CC255545464067B45549648F45406342CC25554546400AF31E679A8C4540A1B94E232D3F46400AF31E679A8C4540
60840	57713	44.456122999999998	44.493861000000003	43.250396000000002	43.228400999999998	Советская	0103000020E6100000010000000500000009FA0B3D623A4640D5AF743E3C9D454009FA0B3D623A46404D86E3F90CA045408BE255D6363F46404D86E3F90CA045408BE255D6363F4640D5AF743E3C9D454009FA0B3D623A4640D5AF743E3C9D4540
60938	57738	44.466498999999999	44.476604999999999	43.363829000000003	43.352313000000002	Ленина	0103000020E61000000100000005000000F04E3E3DB63B4640537AA69718AD4540F04E3E3DB63B46400F2BDCF291AE4540170E8464013D46400F2BDCF291AE4540170E8464013D4640537AA69718AD4540F04E3E3DB63B4640537AA69718AD4540
60749	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Школьная	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60731	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Цаликова	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60759	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Хлебный	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60752	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Суджаева	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60729	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Сигова	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60757	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Привокзальная	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60630	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Подгорная	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60662	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Октябрьская	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60635	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Окружная	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60671	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Ленина	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60623	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Котовского	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60622	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Кооперативная	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60633	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Коминтерна	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60674	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Иристонская	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60677	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Дзарахохова	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60772	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Джимиева	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60636	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Гагарина	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60626	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Вокзальная	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60654	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Братьев Ногаевых	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60769	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Бзарова	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60637	33012	44.478544999999997	44.564649000000003	43.209355000000002	43.165925999999999	Бесланская	0103000020E6100000010000000500000008556AF6403D46402EC72B103D95454008556AF6403D464086200725CC9A45400C5C1E6B4648464086200725CC9A45400C5C1E6B464846402EC72B103D95454008556AF6403D46402EC72B103D954540
60837	57712	44.524728000000003	44.548901000000001	43.389575000000001	43.366889999999998	Плиева	0103000020E61000000100000005000000D3A57F492A4346405E9D6340F6AE4540D3A57F492A4346406B2BF697DDB14540F0DE5163424646406B2BF697DDB14540F0DE5163424646405E9D6340F6AE4540D3A57F492A4346405E9D6340F6AE4540
60802	47622	44.336601999999999	44.357156000000003	43.767653000000003	43.757770000000001	Красная	0103000020E6100000010000000500000054E23AC6152B4640E9F17B9BFEE0454054E23AC6152B464091D6187442E24540FCC8AD49B72D464091D6187442E24540FCC8AD49B72D4640E9F17B9BFEE0454054E23AC6152B4640E9F17B9BFEE04540
60803	30409	44.451110999999997	44.467927000000003	43.468229999999998	43.442675999999999	Гагарина	0103000020E61000000100000005000000D4EE5701BE394640AF5C6F9BA9B84540D4EE5701BE394640C780ECF5EEBB45402CF52C08E53B4640C780ECF5EEBB45402CF52C08E53B4640AF5C6F9BA9B84540D4EE5701BE394640AF5C6F9BA9B84540
60627	47239	44.650284999999997	44.696494000000001	43.773954000000003	43.752867000000002	Октябрьская	0103000020E61000000100000005000000280AF4893C5346406B9E23F25DE04540280AF4893C534640E04DB7EC10E345401CEE23B726594640E04DB7EC10E345401CEE23B7265946406B9E23F25DE04540280AF4893C5346406B9E23F25DE04540
60628	47239	44.650284999999997	44.696494000000001	43.773954000000003	43.752867000000002	Виноградная	0103000020E61000000100000005000000280AF4893C5346406B9E23F25DE04540280AF4893C534640E04DB7EC10E345401CEE23B726594640E04DB7EC10E345401CEE23B7265946406B9E23F25DE04540280AF4893C5346406B9E23F25DE04540
60603	47321	44.711495999999997	44.739550999999999	43.728319999999997	43.712643999999997	Ленина	0103000020E610000001000000050000000E9E094D125B464066D828EB37DB45400E9E094D125B4640E882FA9639DD4540AF5C6F9BA95E4640E882FA9639DD4540AF5C6F9BA95E464066D828EB37DB45400E9E094D125B464066D828EB37DB4540
60835	57710	44.325059000000003	44.340223000000002	43.807434999999998	43.800936	Никулиной	0103000020E610000001000000050000009F2287889B2946403318231285E645409F2287889B294640A852B3075AE745406B2C616D8C2B4640A852B3075AE745406B2C616D8C2B46403318231285E645409F2287889B2946403318231285E64540
60801	30258	44.430098999999998	44.449942999999998	43.684950999999998	43.670197000000002	Садовая	0103000020E610000001000000050000006A85E97B0D3746404C70EA03C9D545406A85E97B0D374640662E7079ACD74540350873BB97394640662E7079ACD74540350873BB973946404C70EA03C9D545406A85E97B0D3746404C70EA03C9D54540
60852	30936	44.541490000000003	44.555145000000003	43.734462000000001	43.724926000000004	Центральная	0103000020E61000000100000005000000378E588B4F45464093020B60CADC4540378E588B4F454640CF13CFD902DE4540DBC4C9FD0E474640CF13CFD902DE4540DBC4C9FD0E47464093020B60CADC4540378E588B4F45464093020B60CADC4540
60789	32974	44.562924000000002	44.572122999999998	43.820132999999998	43.817076	Театральная	0103000020E610000001000000050000001711C5E40D4846405A2C45F295E845401711C5E40D48464068AF3E1EFAE845400B2593533B49464068AF3E1EFAE845400B2593533B4946405A2C45F295E845401711C5E40D4846405A2C45F295E84540
60795	57704	44.523631999999999	44.543447999999998	43.704765999999999	43.686945999999999	Октябрьская	0103000020E61000000100000005000000CD91955F064346401B0FB6D8EDD74540CD91955F0643464097AAB4C535DA4540CE893DB48F45464097AAB4C535DA4540CE893DB48F4546401B0FB6D8EDD74540CD91955F064346401B0FB6D8EDD74540
60750	30620	44.289485999999997	44.315806000000002	43.748705999999999	43.736469	Кирова	0103000020E610000001000000050000002E5393E00D25464048C2BE9D44DE45402E5393E00D254640D4282499D5DF4540B7F0BC546C284640D4282499D5DF4540B7F0BC546C28464048C2BE9D44DE45402E5393E00D25464048C2BE9D44DE4540
60794	32969	44.687682000000002	44.700788000000003	43.572671999999997	43.555563999999997	Коркмасова	0103000020E610000001000000050000002106BAF605584640DF6A9DB81CC745402106BAF605584640DEAAEB504DC94540F2B6D26BB3594640DEAAEB504DC94540F2B6D26BB3594640DF6A9DB81CC745402106BAF605584640DF6A9DB81CC74540
60664	30124	44.455863000000001	44.499296000000001	43.729610000000001	43.711426000000003	Уварова пер	0103000020E610000001000000050000006D3A02B8593A464016C3D50110DB45406D3A02B8593A4640D36A48DC63DD454006836BEEE83F4640D36A48DC63DD454006836BEEE83F464016C3D50110DB45406D3A02B8593A464016C3D50110DB4540
60765	30124	44.455863000000001	44.499296000000001	43.729610000000001	43.711426000000003	К. Хетагурова пер	0103000020E610000001000000050000006D3A02B8593A464016C3D50110DB45406D3A02B8593A4640D36A48DC63DD454006836BEEE83F4640D36A48DC63DD454006836BEEE83F464016C3D50110DB45406D3A02B8593A464016C3D50110DB4540
60800	57705	44.373496000000003	44.411952999999997	43.708883999999998	43.697864000000003	Октябрьская	0103000020E61000000100000005000000EA9788B7CE2F46402387889B53D94540EA9788B7CE2F46402E54FEB5BCDA45409A3E3BE0BA3446402E54FEB5BCDA45409A3E3BE0BA3446402387889B53D94540EA9788B7CE2F46402387889B53D94540
60717	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	пл. 50 лет Октября	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60620	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Юбилейная	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60814	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Элеваторная	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60716	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Чкалова	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60718	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Фрунзе	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60719	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Первомайская	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60686	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Лебедева-Кумача	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60715	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Кирова	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60681	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Гастелло	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60761	28278	44.598900999999998	44.706394000000003	43.783574000000002	43.726255000000002	Вокзальная	0103000020E610000001000000050000005645B8C9A84C46403BC780ECF5DC45405645B8C9A84C46407AFF1F274CE445409A0B5C1E6B5A46407AFF1F274CE445409A0B5C1E6B5A46403BC780ECF5DC45405645B8C9A84C46403BC780ECF5DC4540
60815	30322	44.444544	44.462384	43.624841000000004	43.609183999999999	Советская	0103000020E6100000010000000500000007D15AD1E63846408C9FC6BDF9CD454007D15AD1E6384640981936CAFACF4540CA181F662F3B4640981936CAFACF4540CA181F662F3B46408C9FC6BDF9CD454007D15AD1E63846408C9FC6BDF9CD4540
60762	47207	44.623668000000002	44.647734	43.737648	43.718378000000001	Усанова	0103000020E61000000100000005000000E7C75F5AD44F46403C1570CFF3DB4540E7C75F5AD44F4640DBFAE93F6BDE4540EE409DF2E8524640DBFAE93F6BDE4540EE409DF2E85246403C1570CFF3DB4540E7C75F5AD44F46403C1570CFF3DB4540
60745	19306	44.552143999999998	44.618133999999998	43.714117000000002	43.695557000000001	Первомайская	0103000020E61000000100000005000000605793A7AC4646407FC0030308D94540605793A7AC4646404242942F68DB4540D845D1031F4F46404242942F68DB4540D845D1031F4F46407FC0030308D94540605793A7AC4646407FC0030308D94540
60629	19306	44.552143999999998	44.618133999999998	43.714117000000002	43.695557000000001	Мира	0103000020E61000000100000005000000605793A7AC4646407FC0030308D94540605793A7AC4646404242942F68DB4540D845D1031F4F46404242942F68DB4540D845D1031F4F46407FC0030308D94540605793A7AC4646407FC0030308D94540
60741	29837	44.633271000000001	44.656609000000003	43.716202000000003	43.698027000000003	Кирова	0103000020E61000000100000005000000AB402D060F514640CD5CE0F258D94540AB402D060F51464037AAD381ACDB454030A182C30B54464037AAD381ACDB454030A182C30B544640CD5CE0F258D94540AB402D060F514640CD5CE0F258D94540
60739	47299	44.675510000000003	44.696449999999999	43.733778999999998	43.718677999999997	Береговая	0103000020E610000001000000050000007C0F971C77564640662D05A4FDDB45407C0F971C77564640ECBE6378ECDD45404CA60A4625594640ECBE6378ECDD45404CA60A4625594640662D05A4FDDB45407C0F971C77564640662D05A4FDDB4540
60843	30567	44.353140000000003	44.376010999999998	43.808371999999999	43.802061999999999	Бегиева	0103000020E61000000100000005000000697407B1332D4640A3AEB5F7A9E64540697407B1332D46404580D3BB78E74540D7F7E120213046404580D3BB78E74540D7F7E12021304640A3AEB5F7A9E64540697407B1332D4640A3AEB5F7A9E64540
60746	47519	44.468780000000002	44.507480000000001	43.705131000000002	43.689475000000002	Советская	0103000020E610000001000000050000006B82A8FB003C46406E3480B740D845406B82A8FB003C4640A9328CBB41DA4540E2AFC91AF5404640A9328CBB41DA4540E2AFC91AF54046406E3480B740D845406B82A8FB003C46406E3480B740D84540
60763	57698	44.705962999999997	44.745938000000002	43.776935999999999	43.763415000000002	Х. Хугаева	0103000020E61000000100000005000000D097DEFE5C5A46404F232D95B7E14540D097DEFE5C5A4640E38A8BA372E34540FD6B79E57A5F4640E38A8BA372E34540FD6B79E57A5F46404F232D95B7E14540D097DEFE5C5A46404F232D95B7E14540
60742	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	Школьный переулок	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
60740	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	Чшиева	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
41481	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	Мира	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
60819	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	Ленина	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
60826	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	Ленина	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
60732	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	Зортова	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
60645	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	Бр. Бароевых	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
60723	55030	44.186008999999999	44.226837000000003	43.364524000000003	43.315165	А.Карсанова	0103000020E610000001000000050000007EE19524CF17464003ECA35357A845407EE19524CF174640B64DF1B8A8AE4540EA42ACFE081D4640B64DF1B8A8AE4540EA42ACFE081D464003ECA35357A845407EE19524CF17464003ECA35357A84540
60839	32728	44.282406999999999	44.305072000000003	43.379131000000001	43.364550000000001	Ленина	0103000020E61000000100000005000000AB949EE925244640DFE00B93A9AE4540AB949EE9252446402CF3565D87B0454071766B990C2746402CF3565D87B0454071766B990C274640DFE00B93A9AE4540AB949EE925244640DFE00B93A9AE4540
60853	57728	44.076576000000003	44.094532999999998	43.314712999999998	43.302214999999997	Плиева	0103000020E610000001000000050000004AD40B3ECD09464029AE2AFBAEA645404AD40B3ECD0946402250FD8348A8454046B247A8190C46402250FD8348A8454046B247A8190C464029AE2AFBAEA645404AD40B3ECD09464029AE2AFBAEA64540
60854	57729	44.141191999999997	44.174779999999998	43.358972000000001	43.322026000000001	Таболова	0103000020E61000000100000005000000793A579412124640193BE12538A94540793A579412124640011764CBF2AD454058FFE7305F164640011764CBF2AD454058FFE7305F164640193BE12538A94540793A579412124640193BE12538A94540
60880	57729	44.141191999999997	44.174779999999998	43.358972000000001	43.322026000000001	Ленина	0103000020E61000000100000005000000793A579412124640193BE12538A94540793A579412124640011764CBF2AD454058FFE7305F164640011764CBF2AD454058FFE7305F164640193BE12538A94540793A579412124640193BE12538A94540
75470	57729	44.141191999999997	44.174779999999998	43.358972000000001	43.322026000000001	Бондаря	0103000020E61000000100000005000000793A579412124640193BE12538A94540793A579412124640011764CBF2AD454058FFE7305F164640011764CBF2AD454058FFE7305F164640193BE12538A94540793A579412124640193BE12538A94540
60841	26067	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	Хидирова	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
60807	26067	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	Хасцаева	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
60809	26067	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	М.Будтуева	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
60806	26067	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	М.Баликоева	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
60787	26067	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	Ленина	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
60847	26067	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	Дедегкаева	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
60812	26067	43.895654999999998	43.96125	43.215221999999997	43.175235999999998	Бр.Албегоновых	0103000020E61000000100000005000000DBBFB2D2A4F245407A8A1C226E964540DBBFB2D2A4F245409AB0FD648C9B4540D7A3703D0AFB45409AB0FD648C9B4540D7A3703D0AFB45407A8A1C226E964540DBBFB2D2A4F245407A8A1C226E964540
60651	52154	43.884605999999998	43.902599000000002	43.197446999999997	43.187904000000003	Советская	0103000020E6100000010000000500000035ECF7C43AF14540D064FF3C0D98454035ECF7C43AF14540BED87BF1459945407F33315D88F34540BED87BF1459945407F33315D88F34540D064FF3C0D98454035ECF7C43AF14540D064FF3C0D984540
60810	32596	43.799813999999998	43.842044000000001	43.289459999999998	43.259621000000003	Тубеева	0103000020E6100000010000000500000004711E4E60E645406B2DCC423BA1454004711E4E60E6454005C078060DA5454082E50819C8EB454005C078060DA5454082E50819C8EB45406B2DCC423BA1454004711E4E60E645406B2DCC423BA14540
60838	33098	44.008806999999997	44.043132	43.135539000000001	43.115107999999999	Маяковского	0103000020E61000000100000005000000E97C78962001464005C1E3DBBB8E4540E97C789620014640912A8A57599145409EB4705985054640912A8A57599145409EB470598505464005C1E3DBBB8E4540E97C78962001464005C1E3DBBB8E4540
60670	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Сталина	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60824	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Плиева	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60692	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Партизанская	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60829	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Мира	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60851	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Ленина	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60621	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Кокиева	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60712	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Кесаева	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60613	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Калицова	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60714	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	К. Маркса	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60828	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Дзотова	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60827	26265	44.140509000000002	44.178579999999997	43.177892	43.135176999999999	Бр. Тахоховых	0103000020E6100000010000000500000097E5EB32FC114640F015DD7A4D91454097E5EB32FC1146402A1C412AC59645401EDC9DB5DB1646402A1C412AC59645401EDC9DB5DB164640F015DD7A4D91454097E5EB32FC114640F015DD7A4D914540
60705	52304	44.633378999999998	44.672635	43.113877000000002	43.082134000000003	Эльхотовская	0103000020E61000000100000005000000917C259012514640E1F1ED5D838A4540917C25901251464020628385938E45408E9257E71856464020628385938E45408E9257E718564640E1F1ED5D838A4540917C259012514640E1F1ED5D838A4540
60775	52304	44.633378999999998	44.672635	43.113877000000002	43.082134000000003	Остаева	0103000020E61000000100000005000000917C259012514640E1F1ED5D838A4540917C25901251464020628385938E45408E9257E71856464020628385938E45408E9257E718564640E1F1ED5D838A4540917C259012514640E1F1ED5D838A4540
60649	52304	44.633378999999998	44.672635	43.113877000000002	43.082134000000003	Бульварная	0103000020E61000000100000005000000917C259012514640E1F1ED5D838A4540917C25901251464020628385938E45408E9257E71856464020628385938E45408E9257E718564640E1F1ED5D838A4540917C259012514640E1F1ED5D838A4540
60850	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Хетагурова	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60736	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Тогузова	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60668	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Советов	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60609	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Пролетарская	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60767	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Мамиева	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60610	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Ленина	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60666	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Кирова	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60608	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Зангиева	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60848	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Бритаева	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60748	33055	44.265591000000001	44.322606999999998	43.191861000000003	43.150964000000002	Абациевых	0103000020E61000000100000005000000548EC9E2FE214640CA6FD1C952934540548EC9E2FE2146405E30B8E68E984540F73AA92F4B2946405E30B8E68E984540F73AA92F4B294640CA6FD1C952934540548EC9E2FE214640CA6FD1C952934540
60842	57714	44.259391999999998	44.274330999999997	43.074205999999997	43.061388999999998	Комсомольская	0103000020E61000000100000005000000096CCEC133214640C5AA4198DB874540096CCEC1332146405F950B957F894540B5A338471D2346405F950B957F894540B5A338471D234640C5AA4198DB874540096CCEC133214640C5AA4198DB874540
60805	32899	44.348739000000002	44.376280999999999	43.042310000000001	43.024386	Кцоева	0103000020E610000001000000050000007DEBC37AA32C4640793D98141F8345407DEBC37AA32C46409A25016A6A854540978DCEF9293046409A25016A6A854540978DCEF929304640793D98141F8345407DEBC37AA32C4640793D98141F834540
60833	32913	44.469248	44.488174999999998	43.027681000000001	43.010793999999997	Дзуцева	0103000020E6100000010000000500000051DB8651103C46401B7FA2B26181454051DB8651103C46403CDC0E0D8B834540C6DCB5847C3E46403CDC0E0D8B834540C6DCB5847C3E46401B7FA2B26181454051DB8651103C46401B7FA2B261814540
60779	5321	44.278292999999998	44.307442999999999	42.928314	42.918602	Карцинская	0103000020E6100000010000000500000055DAE21A9F234640250516C09475454055DAE21A9F234640A0353FFED27645402B31CF4A5A274640A0353FFED27645402B31CF4A5A274640250516C09475454055DAE21A9F234640250516C094754540
60725	5321	44.278292999999998	44.307442999999999	42.928314	42.918602	Дружбы	0103000020E6100000010000000500000055DAE21A9F234640250516C09475454055DAE21A9F234640A0353FFED27645402B31CF4A5A274640A0353FFED27645402B31CF4A5A274640250516C09475454055DAE21A9F234640250516C094754540
60836	57711	44.327691000000002	44.336441000000001	42.849919	42.842080000000003	Бр.Газдановых	0103000020E61000000100000005000000C61858C7F1294640CF4E0647C96B4540C61858C7F1294640E09F5225CA6C45404B04AA7F102B4640E09F5225CA6C45404B04AA7F102B4640CF4E0647C96B4540C61858C7F1294640CF4E0647C96B4540
60813	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Цаликова	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60615	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Сталина	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60632	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Ленина	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60611	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	ЛЕНИНА	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60667	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Л.Толстого	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60710	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Комсомольская	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60832	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Кирова	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60711	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Калаева	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60616	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	К.Хетагурова	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
60846	32857	44.190508999999999	44.240977000000001	43.068080999999999	42.998016	Алагирская	0103000020E61000000100000005000000FD4B5299621846403F7100FDBE7F4540FD4B5299621846404F3DD2E0B68845404A0B9755D81E46404F3DD2E0B68845404A0B9755D81E46403F7100FDBE7F4540FD4B5299621846403F7100FDBE7F4540
61594	57861	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Космонавтов	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61533	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Фабричная	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61587	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Тургеневская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61566	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Тихая	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61676	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Строителей	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61584	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Ставропольская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61689	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Советская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61530	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Подгорная	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61531	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Первомайская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61534	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Парковая	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61577	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Октябрьская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61640	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Международная	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61667	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Леонова	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61529	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Ленина	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61527	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Крупской	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61657	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Красноармейская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61532	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Кочубея	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61600	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Космонавтов	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61681	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Кирова	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61694	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Карла Маркса	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61582	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Кавказская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61535	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Доватора	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61631	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Демиденко	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61654	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Гутякулова	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61693	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Горького	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61664	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Ворошилова	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61690	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	Балахонова	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61732	188	42.026001000000001	42.091650000000001	44.268731000000002	44.170903000000003	 Кавказская	0103000020E61000000100000005000000E754320054034540E7E44526E0154640E754320054034540F03504C765224640D656EC2FBB0B4540F03504C765224640D656EC2FBB0B4540E7E44526E0154640E754320054034540E7E44526E0154640
61560	57856	41.752248000000002	41.781075000000001	44.063034999999999	44.023851999999998	Хабекова	0103000020E610000001000000050000009F3D97A949E04440DBF813950D0346409F3D97A949E044406EC0E78711084640925CFE43FAE344406EC0E78711084640925CFE43FAE34440DBF813950D0346409F3D97A949E04440DBF813950D034640
61624	57854	40.693035999999999	42.679578999999997	44.496468999999998	43.187358000000003	м-н Московский	0103000020E61000000100000005000000AF795567B55844406E52D158FB974540AF795567B5584440293DD34B8C3F46403106D671FC564540293DD34B8C3F46403106D671FC5645406E52D158FB974540AF795567B55844406E52D158FB974540
61718	57854	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Школьная	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61717	57854	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Первомайская	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61699	57854	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Морозова	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61556	57854	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Курортная	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61715	57854	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Коммунистическая	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61716	57854	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Богатырева	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61714	57854	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Балахонова	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61537	57851	41.729565999999998	41.753937000000001	43.480300999999997	43.420928000000004	Тебердинская	0103000020E6100000010000000500000003232F6B62DD444040FCFCF7E0B5454003232F6B62DD4440389ECF807ABD4540471FF30181E04440389ECF807ABD4540471FF30181E0444040FCFCF7E0B5454003232F6B62DD444040FCFCF7E0B54540
61744	57851	41.729565999999998	41.753937000000001	43.480300999999997	43.420928000000004	Орджоникидзе	0103000020E6100000010000000500000003232F6B62DD444040FCFCF7E0B5454003232F6B62DD4440389ECF807ABD4540471FF30181E04440389ECF807ABD4540471FF30181E0444040FCFCF7E0B5454003232F6B62DD444040FCFCF7E0B54540
61695	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Эркенова	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61719	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Советская	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61733	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Речной	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61746	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Пушкина	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61756	3363	41.881875000000001	41.943589000000003	43.862766000000001	43.747396999999999	Пихтовый Мыс	0103000020E610000001000000050000007B14AE47E1F04440731074B4AADF45407B14AE47E1F04440E50CC51D6FEE4540C4EE3B86C7F84440E50CC51D6FEE4540C4EE3B86C7F84440731074B4AADF45407B14AE47E1F04440731074B4AADF4540
61688	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Мира	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
9872	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Магометова	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61536	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Ленина	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61761	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Курортная	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61745	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Курджиева	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61760	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Колиева	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61692	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Калинина	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
61777	3363	41.881866000000002	41.964942000000001	43.799796999999998	43.747404000000003	Гагарина	0103000020E6100000010000000500000028BA2EFCE0F0444026732CEFAADF454028BA2EFCE0F044402E3883BF5FE64540B7442E3883FB44402E3883BF5FE64540B7442E3883FB444026732CEFAADF454028BA2EFCE0F0444026732CEFAADF4540
62382	4338	41.787084999999998	41.818418000000001	44.096390999999997	44.066630000000004	Ленина	0103000020E6100000010000000500000009168733BFE444405C77F3548708464009168733BFE444407A50508A560C4640973AC8EBC1E844407A50508A560C4640973AC8EBC1E844405C77F3548708464009168733BFE444405C77F35487084640
61682	57870	41.752248000000002	41.781075000000001	44.063034999999999	44.023851999999998	Советская	0103000020E610000001000000050000009F3D97A949E04440DBF813950D0346409F3D97A949E044406EC0E78711084640925CFE43FAE344406EC0E78711084640925CFE43FAE34440DBF813950D0346409F3D97A949E04440DBF813950D034640
61683	57871	41.869532	41.891953999999998	44.229627000000001	44.203242000000003	Школьная 	0103000020E61000000100000005000000A96917D34CEF44403A9677D5031A4640A96917D34CEF4440A9A3E36A641D4640A8C4758C2BF24440A9A3E36A641D4640A8C4758C2BF244403A9677D5031A4640A96917D34CEF44403A9677D5031A4640
62484	57962	41.894891999999999	41.901952000000001	44.227980000000002	44.215628000000002	Хапсирокова	0103000020E61000000100000005000000DCB930D28BF244400B0DC4B2991B4640DCB930D28BF244403012DA722E1D4640E947C32973F344403012DA722E1D4640E947C32973F344400B0DC4B2991B4640DCB930D28BF244400B0DC4B2991B4640
61561	57857	41.853003000000001	41.879790999999997	44.171064999999999	44.146619999999999	Калмыкова	0103000020E61000000100000005000000E831CA332FED44404278B471C4124640E831CA332FED4440C03E3A75E51546405628D2FD9CF04440C03E3A75E51546405628D2FD9CF044404278B471C4124640E831CA332FED44404278B471C4124640
62561	57988	41.865616000000003	41.878399000000002	44.187427	44.174013000000002	Булатукова	0103000020E610000001000000050000007A724D81CCEE4440180AD80E461646407A724D81CCEE444096B1A19BFD17464068EBE0606FF0444096B1A19BFD17464068EBE0606FF04440180AD80E461646407A724D81CCEE4440180AD80E46164640
61643	57867	41.836627	41.860405	44.148902999999997	44.130861000000003	хАБЕКОВА	0103000020E61000000100000005000000ADF9F19716EB444033A9A10DC0104640ADF9F19716EB44405DA3E5400F1346404E2844C021EE44405DA3E5400F1346404E2844C021EE444033A9A10DC0104640ADF9F19716EB444033A9A10DC0104640
61753	4266	41.774697000000003	41.792565000000003	44.068410999999998	44.033172	С.Дерева	0103000020E6100000010000000500000098A7734529E344404B92E7FA3E04464098A7734529E34440E4D70FB1C1084640257A19C572E54440E4D70FB1C1084640257A19C572E544404B92E7FA3E04464098A7734529E344404B92E7FA3E044640
62411	4266	41.774697000000003	41.792565000000003	44.068410999999998	44.033172	Ленина	0103000020E6100000010000000500000098A7734529E344404B92E7FA3E04464098A7734529E34440E4D70FB1C1084640257A19C572E54440E4D70FB1C1084640257A19C572E544404B92E7FA3E04464098A7734529E344404B92E7FA3E044640
61710	57881	41.815480999999998	41.839295	44.131960999999997	44.100534000000003	Атажукина	0103000020E6100000010000000500000033C170AE61E844406B11514CDE0C464033C170AE61E8444079AC1919E41046402159C0046EEB444079AC1919E41046402159C0046EEB44406B11514CDE0C464033C170AE61E844406B11514CDE0C4640
61709	57880	41.725847000000002	41.750272000000002	43.966025000000002	43.945771999999998	Акова	0103000020E610000001000000050000002A73F38DE8DC44407BBC900E0FF945402A73F38DE8DC4440280F0BB5A6FB4540618DB3E908E04440280F0BB5A6FB4540618DB3E908E044407BBC900E0FF945402A73F38DE8DC44407BBC900E0FF94540
61685	57873	41.727338000000003	41.750208999999998	44.260086999999999	44.229356000000003	Гутякулова	0103000020E61000000100000005000000AC915D6919DD4440199293895B1D4640AC915D6919DD4440B08EE3874A2146401A1538D906E04440B08EE3874A2146401A1538D906E04440199293895B1D4640AC915D6919DD4440199293895B1D4640
62442	12562	41.883761	41.900604999999999	44.214866000000001	44.197439000000003	Набережная	0103000020E61000000100000005000000793D98141FF144403CFA5FAE45194640793D98141FF14440DC82A5BA801B46409ACE4E0647F34440DC82A5BA801B46409ACE4E0647F344403CFA5FAE45194640793D98141FF144403CFA5FAE45194640
61558	57855	41.728191000000002	41.755625999999999	44.008409999999998	43.97287	Ленина	0103000020E61000000100000005000000EB1ED95C35DD444038A1100187FC4540EB1ED95C35DD4440CC7A319413014640EF004F5AB8E04440CC7A319413014640EF004F5AB8E0444038A1100187FC4540EB1ED95C35DD444038A1100187FC4540
61557	57855	41.728191000000002	41.755625999999999	44.008409999999998	43.97287	Кушхова	0103000020E61000000100000005000000EB1ED95C35DD444038A1100187FC4540EB1ED95C35DD4440CC7A319413014640EF004F5AB8E04440CC7A319413014640EF004F5AB8E0444038A1100187FC4540EB1ED95C35DD444038A1100187FC4540
62553	57981	41.887830999999998	41.908195999999997	44.261958999999997	44.244714000000002	Центральная	0103000020E61000000100000005000000FFAF3A72A4F14440CA6FD1C9521F4640FFAF3A72A4F1444049F25CDF87214640D32D3BC43FF4444049F25CDF87214640D32D3BC43FF44440CA6FD1C9521F4640FFAF3A72A4F14440CA6FD1C9521F4640
61570	32983	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Морозова	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61743	32983	41.956588000000004	42.015588999999999	44.131495000000001	44.044978999999998	Краснопартизанская	0103000020E610000001000000050000007FDFBF7971FA4440DE0033DFC10546407FDFBF7971FA4440344B02D4D4104640B39602D2FE014540344B02D4D4104640B39602D2FE014540DE0033DFC10546407FDFBF7971FA4440DE0033DFC1054640
61696	57876	41.935927	41.962282999999999	44.076151000000003	44.043016000000001	Джегутанова	0103000020E61000000100000005000000C138B874CCF74440359A5C8C81054640C138B874CCF744406347E350BF094640963FDF162CFB44406347E350BF094640963FDF162CFB4440359A5C8C81054640C138B874CCF74440359A5C8C81054640
61726	10328	41.136166000000003	41.173392	43.860602	43.817486000000002	Красная	0103000020E61000000100000005000000E06932E36D9144400C789961A3E84540E06932E36D914440A46FD23428EE4540ABB184B531964440A46FD23428EE4540ABB184B5319644400C789961A3E84540E06932E36D9144400C789961A3E84540
62435	10675	40.939219000000001	40.95158	43.595286000000002	43.585329000000002	Центральная	0103000020E6100000010000000500000013640454387844404033880FECCA4540136404543878444022E2E65432CC45408BC3995FCD79444022E2E65432CC45408BC3995FCD7944404033880FECCA454013640454387844404033880FECCA4540
62453	10757	40.962943000000003	40.997987000000002	43.996096999999999	43.963579000000003	Ставропольская	0103000020E61000000100000005000000C1745AB7417B4440630E828E56FB4540C1745AB7417B44406552431B80FF4540A56ABB09BE7F44406552431B80FF4540A56ABB09BE7F4440630E828E56FB4540C1745AB7417B4440630E828E56FB4540
62439	10941	40.929481000000003	40.943046000000002	44.071545999999998	44.056083999999998	Садовая	0103000020E610000001000000050000006FA0C03BF976444018EAB0C22D0746406FA0C03BF97644406E14596B28094640D34F38BBB57844406E14596B28094640D34F38BBB578444018EAB0C22D0746406FA0C03BF976444018EAB0C22D074640
62491	10410	41.159944000000003	41.214219999999997	43.981005000000003	43.917693999999997	Прогонная	0103000020E610000001000000050000008198840B7994444022DE3AFF76F545408198840B79944440331B649291FD454016139B8F6B9B4440331B649291FD454016139B8F6B9B444022DE3AFF76F545408198840B7994444022DE3AFF76F54540
61528	10410	41.159944000000003	41.214219999999997	43.981005000000003	43.917693999999997	Подгорная	0103000020E610000001000000050000008198840B7994444022DE3AFF76F545408198840B79944440331B649291FD454016139B8F6B9B4440331B649291FD454016139B8F6B9B444022DE3AFF76F545408198840B7994444022DE3AFF76F54540
61554	10410	41.159944000000003	41.214219999999997	43.981005000000003	43.917693999999997	Пионерская	0103000020E610000001000000050000008198840B7994444022DE3AFF76F545408198840B79944440331B649291FD454016139B8F6B9B4440331B649291FD454016139B8F6B9B444022DE3AFF76F545408198840B7994444022DE3AFF76F54540
61553	10410	41.159944000000003	41.214219999999997	43.981005000000003	43.917693999999997	Красная	0103000020E610000001000000050000008198840B7994444022DE3AFF76F545408198840B79944440331B649291FD454016139B8F6B9B4440331B649291FD454016139B8F6B9B444022DE3AFF76F545408198840B7994444022DE3AFF76F54540
61565	5609	41.174900999999998	41.191861000000003	43.922784999999998	43.909129	Спортивная	0103000020E61000000100000005000000D384ED27639644402F6CCD565EF44540D384ED2763964440A31EA2D11DF645405E30B8E68E984440A31EA2D11DF645405E30B8E68E9844402F6CCD565EF44540D384ED27639644402F6CCD565EF44540
61708	5609	41.174900999999998	41.191861000000003	43.922784999999998	43.909129	Бардина	0103000020E61000000100000005000000D384ED27639644402F6CCD565EF44540D384ED2763964440A31EA2D11DF645405E30B8E68E984440A31EA2D11DF645405E30B8E68E9844402F6CCD565EF44540D384ED27639644402F6CCD565EF44540
61741	57890	41.211606000000003	41.236120999999997	44.013584000000002	43.999896999999997	Пионерская	0103000020E6100000010000000500000096D1C8E7159B44402B2FF99FFCFF454096D1C8E7159B4440DBDFD91EBD0146400C738236399E4440DBDFD91EBD0146400C738236399E44402B2FF99FFCFF454096D1C8E7159B44402B2FF99FFCFF4540
61555	57853	40.929616000000003	40.962575000000001	44.041338000000003	43.950172000000002	Н. Василенко	0103000020E610000001000000050000004FEB36A8FD76444097C9703C9FF945404FEB36A8FD764440810A47904A0546403E7958A8357B4440810A47904A0546403E7958A8357B444097C9703C9FF945404FEB36A8FD76444097C9703C9FF94540
62455	10706	40.929616000000003	40.962575000000001	44.041338000000003	43.950172000000002	Школьная	0103000020E610000001000000050000004FEB36A8FD76444097C9703C9FF945404FEB36A8FD764440810A47904A0546403E7958A8357B4440810A47904A0546403E7958A8357B444097C9703C9FF945404FEB36A8FD76444097C9703C9FF94540
9934	10706	40.929616000000003	40.962575000000001	44.041338000000003	43.950172000000002	Крайняя	0103000020E610000001000000050000004FEB36A8FD76444097C9703C9FF945404FEB36A8FD764440810A47904A0546403E7958A8357B4440810A47904A0546403E7958A8357B444097C9703C9FF945404FEB36A8FD76444097C9703C9FF94540
62548	10706	40.929616000000003	40.962575000000001	44.041338000000003	43.950172000000002	Гагарина	0103000020E610000001000000050000004FEB36A8FD76444097C9703C9FF945404FEB36A8FD764440810A47904A0546403E7958A8357B4440810A47904A0546403E7958A8357B444097C9703C9FF945404FEB36A8FD76444097C9703C9FF94540
61706	10226	42.039169999999999	42.076881	44.333198000000003	44.267516999999998	Центральная	0103000020E61000000100000005000000FE7DC68503054540E00F3FFF3D224640FE7DC68503054540DB8B683BA62A46408657923CD7094540DB8B683BA62A46408657923CD7094540E00F3FFF3D224640FE7DC68503054540E00F3FFF3D224640
61720	9686	42.236072	42.307532999999999	44.142854999999997	44.116677000000003	Садовая	0103000020E610000001000000050000002BC0779B371E454003999D45EF0E46402BC0779B371E4540F8889812491246406BB8C83D5D274540F8889812491246406BB8C83D5D27454003999D45EF0E46402BC0779B371E454003999D45EF0E4640
61739	9444	42.497588999999998	42.521906999999999	44.358584	44.342205	Мира	0103000020E61000000100000005000000B7EC10FFB03F45408BC3995FCD2B4640B7EC10FFB03F4540376F9C14E62D4640D8463CD9CD424540376F9C14E62D4640D8463CD9CD4245408BC3995FCD2B4640B7EC10FFB03F45408BC3995FCD2B4640
61740	32680	42.329236000000002	42.361953	44.156773999999999	44.145960000000002	Шоссейная	0103000020E610000001000000050000003B55BE67242A4540184339D1AE1246403B55BE67242A45407A6EA12B1114464034D8D479542E45407A6EA12B1114464034D8D479542E4540184339D1AE1246403B55BE67242A4540184339D1AE124640
61550	9766	42.248486	42.296196000000002	44.177013000000002	44.146982000000001	Школьная	0103000020E61000000100000005000000C6C1A563CE1F4540E38C614ED0124640C6C1A563CE1F4540C2FBAA5CA81646405F9A22C0E9254540C2FBAA5CA81646405F9A22C0E9254540E38C614ED0124640C6C1A563CE1F4540E38C614ED0124640
62541	9563	42.460112000000002	42.475617	44.217883	44.206001000000001	Луговая	0103000020E61000000100000005000000A33F34F3E43A4540BEF8A23D5E1A4640A33F34F3E43A45405CAD1397E31B4640F8359204E13C45405CAD1397E31B4640F8359204E13C4540BEF8A23D5E1A4640A33F34F3E43A4540BEF8A23D5E1A4640
61722	9823	42.200291999999997	42.248531	44.166001999999999	44.144162000000001	Байчорова	0103000020E6100000010000000500000041D3122BA3194540B9A981E67312464041D3122BA31945400989B48D3F154640668522DDCF1F45400989B48D3F154640668522DDCF1F4540B9A981E67312464041D3122BA3194540B9A981E673124640
62538	9436	42.361342	42.408458000000003	44.300001999999999	44.279367000000001	Лесная	0103000020E61000000100000005000000EB556474402E4540734A404CC2234640EB556474402E4540075E2D776626464011E50B5A48344540075E2D776626464011E50B5A48344540734A404CC2234640EB556474402E4540734A404CC2234640
61774	4451	42.010728999999998	42.028821000000001	44.262805	44.217683000000001	Кунижева	0103000020E61000000100000005000000340F60915F01454095F25A09DD1B4640340F60915F014540D61C2098A321464011381268B0034540D61C2098A321464011381268B003454095F25A09DD1B4640340F60915F01454095F25A09DD1B4640
61747	9934	42.184058999999998	42.210056999999999	44.109350999999997	44.096209999999999	Джегутинская	0103000020E6100000010000000500000069C4CC3E8F1745402AC6F99B500C464069C4CC3E8F1745407764AC36FF0D4640DFA5D425E31A45407764AC36FF0D4640DFA5D425E31A45402AC6F99B500C464069C4CC3E8F1745402AC6F99B500C4640
61730	10042	42.109014000000002	42.136062000000003	44.242885999999999	44.233722	Центральная	0103000020E610000001000000050000003067B62BF40D4540882D3D9AEA1D46403067B62BF40D4540005471E3161F46403B1DC87A6A114540005471E3161F46403B1DC87A6A114540882D3D9AEA1D46403067B62BF40D4540882D3D9AEA1D4640
61750	57891	42.138675999999997	42.163766000000003	44.165678999999997	44.153579000000001	Космонавтов	0103000020E61000000100000005000000BB5E9A22C01145401B2D077AA8134640BB5E9A22C011454026512FF8341546402F19C748F614454026512FF8341546402F19C748F61445401B2D077AA8134640BB5E9A22C01145401B2D077AA8134640
61705	9509	42.472365000000003	42.500123000000002	44.265205999999999	44.243977999999998	Интернациональная	0103000020E610000001000000050000003563D174763C4540C478CDAB3A1F46403563D174763C4540FB592C45F22146401C7DCC0704404540FB592C45F22146401C7DCC0704404540C478CDAB3A1F46403563D174763C4540C478CDAB3A1F4640
62635	40393	\N	\N	\N	\N	Дружбы	\N
61551	9947	42.101253	42.150075999999999	44.130240000000001	44.107731999999999	Школьная	0103000020E610000001000000050000009ACFB9DBF50C4540C85D8429CA0D46409ACFB9DBF50C4540C6504EB4AB1046400EF5BBB035134540C6504EB4AB1046400EF5BBB035134540C85D8429CA0D46409ACFB9DBF50C4540C85D8429CA0D4640
61731	9295	42.307577999999999	42.325068000000002	44.283206999999997	44.268794999999997	Центральная	0103000020E610000001000000050000000B7C45B75E274540062AE3DF672246400B7C45B75E274540C77F812040244640F27C06D49B294540C77F812040244640F27C06D49B294540062AE3DF672246400B7C45B75E274540062AE3DF67224640
61729	9368	42.403157999999998	42.442746999999997	44.307969	44.295931000000003	Шоссейная	0103000020E61000000100000005000000758F6CAE9A334540B16F2711E1254640758F6CAE9A334540469737876B27464078B306EFAB384540469737876B27464078B306EFAB384540B16F2711E1254640758F6CAE9A334540B16F2711E1254640
62564	4406	41.935279999999999	41.950029999999998	44.138081	44.124941	Колмсомольская	0103000020E610000001000000050000002B4D4A41B7F74440FB761211FE0F46402B4D4A41B7F74440789961A3AC114640041C42959AF94440789961A3AC114640041C42959AF94440FB761211FE0F46402B4D4A41B7F74440FB761211FE0F4640
61680	9231	42.217063000000003	42.242998	44.274887999999997	44.261920000000003	Татаркулова	0103000020E61000000100000005000000F9156BB8C81B45408C15359886214640F9156BB8C81B45400B08AD872F234640287FF78E1A1F45400B08AD872F234640287FF78E1A1F45408C15359886214640F9156BB8C81B45408C15359886214640
61724	10075	42.139825999999999	42.154603999999999	44.196075	44.181299000000003	Школьная	0103000020E61000000100000005000000B49080D1E511454015E63DCE34174640B49080D1E5114540174850FC1819464057EA5910CA134540174850FC1819464057EA5910CA13454015E63DCE34174640B49080D1E511454015E63DCE34174640
61704	10109	42.041370999999998	42.075471	44.151955999999998	44.138055000000001	Мира	0103000020E610000001000000050000005C001AA54B0545404F0647C9AB1146405C001AA54B0545402A37514B73134640F165A208A90945402A37514B73134640F165A208A90945404F0647C9AB1146405C001AA54B0545404F0647C9AB114640
61687	10167	42.007548999999997	42.028362999999999	44.218089999999997	44.178809999999999	50 лет Октября	0103000020E610000001000000050000000A0F9A5DF70045405019FF3EE31646400A0F9A5DF7004540D5CA845FEA1B46404EB51666A1034540D5CA845FEA1B46404EB51666A10345405019FF3EE31646400A0F9A5DF70045405019FF3EE3164640
62448	9323	42.332909999999998	42.356966999999997	44.256419999999999	44.241149	Советская	0103000020E6100000010000000500000074417DCB9C2A4540473B6EF8DD1E464074417DCB9C2A45402905DD5ED220464028603B18B12D45402905DD5ED220464028603B18B12D4540473B6EF8DD1E464074417DCB9C2A4540473B6EF8DD1E4640
62916	58036	41.935442000000002	41.976162000000002	44.389884000000002	44.357635999999999	Некрасова	0103000020E6100000010000000500000005A73E90BCF74440A6EF3504C72D464005A73E90BCF74440E99D0AB8E73146408ACC5CE0F2FC4440E99D0AB8E73146408ACC5CE0F2FC4440A6EF3504C72D464005A73E90BCF74440A6EF3504C72D4640
62488	8148	42.631940999999998	42.650069000000002	43.871130000000001	43.856538999999998	Центральная	0103000020E6100000010000000500000032005471E3504540D05FE811A3ED454032005471E35045404148163081EF45405C920376355345404148163081EF45405C92037635534540D05FE811A3ED454032005471E3504540D05FE811A3ED4540
61546	8343	42.485678	42.552396000000002	43.962398	43.912920999999997	Школьная	0103000020E610000001000000050000007F315BB22A3E4540726A6798DAF445407F315BB22A3E45402FDE8FDB2FFB45407A3881E9B44645402FDE8FDB2FFB45407A3881E9B4464540726A6798DAF445407F315BB22A3E4540726A6798DAF44540
61703	8343	42.485678	42.552396000000002	43.962398	43.912920999999997	Хабова	0103000020E610000001000000050000007F315BB22A3E4540726A6798DAF445407F315BB22A3E45402FDE8FDB2FFB45407A3881E9B44645402FDE8FDB2FFB45407A3881E9B4464540726A6798DAF445407F315BB22A3E4540726A6798DAF44540
61609	8343	42.485678	42.552396000000002	43.962398	43.912920999999997	Ленина	0103000020E610000001000000050000007F315BB22A3E4540726A6798DAF445407F315BB22A3E45402FDE8FDB2FFB45407A3881E9B44645402FDE8FDB2FFB45407A3881E9B4464540726A6798DAF445407F315BB22A3E4540726A6798DAF44540
61547	8343	42.485678	42.552396000000002	43.962398	43.912920999999997	Ижаева	0103000020E610000001000000050000007F315BB22A3E4540726A6798DAF445407F315BB22A3E45402FDE8FDB2FFB45407A3881E9B44645402FDE8FDB2FFB45407A3881E9B4464540726A6798DAF445407F315BB22A3E4540726A6798DAF44540
61549	8670	42.422679000000002	42.458027000000001	43.942214999999997	43.920636000000002	Ленина	0103000020E610000001000000050000005EDA70581A36454098C28366D7F545405EDA70581A3645407B6649809AF84540AED7F4A0A03A45407B6649809AF84540AED7F4A0A03A454098C28366D7F545405EDA70581A36454098C28366D7F54540
61652	57869	42.498344000000003	42.532209999999999	43.960244000000003	43.945486000000002	Школьная	0103000020E61000000100000005000000341477BCC93F4540B6696CAF05F94540341477BCC93F454012178046E9FA4540554D10751F44454012178046E9FA4540554D10751F444540B6696CAF05F94540341477BCC93F4540B6696CAF05F94540
61679	8575	42.435606	42.495370000000001	43.946745999999997	43.928213	Шоссейная	0103000020E610000001000000050000007FF8F9EFC13745406C5CFFAECFF645407FF8F9EFC137454035CF11F92EF94540B3B5BE48683F454035CF11F92EF94540B3B5BE48683F45406C5CFFAECFF645407FF8F9EFC13745406C5CFFAECFF64540
61548	8575	42.435606	42.495370000000001	43.946745999999997	43.928213	Совхозная	0103000020E610000001000000050000007FF8F9EFC13745406C5CFFAECFF645407FF8F9EFC137454035CF11F92EF94540B3B5BE48683F454035CF11F92EF94540B3B5BE48683F45406C5CFFAECFF645407FF8F9EFC13745406C5CFFAECFF64540
61728	57886	42.308906999999998	42.337563000000003	43.934848000000002	43.923558	Советская	0103000020E61000000100000005000000B340BB438A274540C6FA062637F64540B340BB438A274540925D6919A9F745407AABAE43352B4540925D6919A9F745407AABAE43352B4540C6FA062637F64540B340BB438A274540C6FA062637F64540
61650	49683	42.587493000000002	42.628079	43.950685	43.936275999999999	Боташева	0103000020E6100000010000000500000081D07AF8324B4540CD0358E4D7F7454081D07AF8324B45401DE6CB0BB0F94540F62686E4645045401DE6CB0BB0F94540F62686E464504540CD0358E4D7F7454081D07AF8324B4540CD0358E4D7F74540
62400	57946	42.275480999999999	42.316946999999999	43.986485999999999	43.945447999999999	Школьная	0103000020E61000000100000005000000AED51EF642234540C808A87004F94540AED51EF6422345401EFB592C45FE45405CC823B8912845401EFB592C45FE45405CC823B891284540C808A87004F94540AED51EF642234540C808A87004F94540
62390	57946	42.275480999999999	42.316946999999999	43.986485999999999	43.945447999999999	Макова	0103000020E61000000100000005000000AED51EF642234540C808A87004F94540AED51EF6422345401EFB592C45FE45405CC823B8912845401EFB592C45FE45405CC823B891284540C808A87004F94540AED51EF642234540C808A87004F94540
62565	8063	42.642226999999998	42.661378999999997	43.800572000000003	43.780613000000002	Центральная	0103000020E61000000100000005000000D9CD8C7E345245408EEA7420EBE34540D9CD8C7E34524540F20BAF2479E645406EA12B11A8544540F20BAF2479E645406EA12B11A85445408EEA7420EBE34540D9CD8C7E345245408EEA7420EBE34540
61702	8238	42.541921000000002	42.575544999999998	43.957901	43.946556999999999	Школьная	0103000020E610000001000000050000000002D6AA5D45454062669FC728F945400002D6AA5D45454021E7FD7F9CFA45402B306475AB49454021E7FD7F9CFA45402B306475AB49454062669FC728F945400002D6AA5D45454062669FC728F94540
62485	3259	42.128633000000001	42.141776	43.600364999999996	43.553185999999997	Горняцкая	0103000020E61000000100000005000000DB17D00B77104540724D81CCCEC64540DB17D00B77104540DE54A4C2D8CC4540C9AD49B725124540DE54A4C2D8CC4540C9AD49B725124540724D81CCCEC64540DB17D00B77104540724D81CCCEC64540
62609	58010	42.135855999999997	42.166514999999997	43.442427000000002	43.422871999999998	Дж.Байрамукова	0103000020E61000000100000005000000917BBABA63114540723271AB20B64540917BBABA6311454007EFAB72A1B845408FA50F5D5015454007EFAB72A1B845408FA50F5D50154540723271AB20B64540917BBABA63114540723271AB20B64540
62590	58001	42.037823000000003	42.111151999999997	43.478245999999999	43.433413000000002	Учкуланская	0103000020E61000000100000005000000B0045262D7044540A454C2137AB74540B0045262D7044540AEB8382A37BD454047718E3A3A0E4540AEB8382A37BD454047718E3A3A0E4540A454C2137AB74540B0045262D7044540A454C2137AB74540
62368	57943	41.894775000000003	41.916271999999999	43.830824999999997	43.806114999999998	Тоторкулова	0103000020E61000000100000005000000A323B9FC87F2444053E8BCC62EE74540A323B9FC87F244407FD93D7958EA4540C91EA16648F544407FD93D7958EA4540C91EA16648F5444053E8BCC62EE74540A323B9FC87F2444053E8BCC62EE74540
61721	33063	41.888972000000003	41.902168000000003	43.680622999999997	43.665331999999999	Шоссейная	0103000020E61000000100000005000000A587A1D5C9F14440BB7D569929D54540A587A1D5C9F14440E4F38AA71ED74540B6BFB33D7AF34440E4F38AA71ED74540B6BFB33D7AF34440BB7D569929D54540A587A1D5C9F14440BB7D569929D54540
62940	33063	41.888972000000003	41.902168000000003	43.680622999999997	43.665331999999999	Центральная	0103000020E61000000100000005000000A587A1D5C9F14440BB7D569929D54540A587A1D5C9F14440E4F38AA71ED74540B6BFB33D7AF34440E4F38AA71ED74540B6BFB33D7AF34440BB7D569929D54540A587A1D5C9F14440BB7D569929D54540
62584	33082	42.073953000000003	42.094802999999999	43.768186999999998	43.756318	Хапаева	0103000020E610000001000000050000007638BA4A7709454025B03907CFE045407638BA4A770945402E1B9DF353E2454006483481220C45402E1B9DF353E2454006483481220C454025B03907CFE045407638BA4A7709454025B03907CFE04540
75518	60659	41.510052999999999	42.436881	43.928179999999998	43.187358000000003	Комсомольская	0103000020E61000000100000005000000041DAD6A49C144406E52D158FB974540041DAD6A49C1444090662C9ACEF64540349F73B7EB37454090662C9ACEF64540349F73B7EB3745406E52D158FB974540041DAD6A49C144406E52D158FB974540
62487	7892	41.928398999999999	41.936115000000001	43.840598	43.835897000000003	Садовая	0103000020E61000000100000005000000CE5147C7D5F644408AE942ACFEEA4540CE5147C7D5F64440A08A1BB798EB4540C425C79DD2F74440A08A1BB798EB4540C425C79DD2F744408AE942ACFEEA4540CE5147C7D5F644408AE942ACFEEA4540
62894	58034	42.094515000000001	42.132469	43.540770999999999	43.480587999999997	Алиева	0103000020E61000000100000005000000A0FD4811190C4540CE6C57E883BD4540A0FD4811190C454007D0EFFB37C54540EE5D83BEF410454007D0EFFB37C54540EE5D83BEF4104540CE6C57E883BD4540A0FD4811190C4540CE6C57E883BD4540
75525	60665	41.880806	41.895843999999997	43.747228	43.724879999999999	Центральная	0103000020E610000001000000050000006F0F4240BEF0444022C32ADEC8DC45406F0F4240BEF04440E753C72AA5DF4540AE282504ABF24440E753C72AA5DF4540AE282504ABF2444022C32ADEC8DC45406F0F4240BEF0444022C32ADEC8DC4540
62579	57995	41.563493999999999	41.584847000000003	43.794474999999998	43.778472000000001	Октябрьская	0103000020E6100000010000000500000001BF469220C84440056D72F8A4E3454001BF469220C84440AB3E575BB1E54540F5143944DCCA4440AB3E575BB1E54540F5143944DCCA4440056D72F8A4E3454001BF469220C84440056D72F8A4E34540
62506	7194	41.660341000000003	41.676763000000001	43.723830999999997	43.703704000000002	Надежды Кецеровой	0103000020E610000001000000050000009E9ACB0D86D444403E0801F912DA45409E9ACB0D86D444405D6A847EA6DC45404912842BA0D644405D6A847EA6DC45404912842BA0D644403E0801F912DA45409E9ACB0D86D444403E0801F912DA4540
62503	57969	41.683346999999998	41.702849999999998	44.169519999999999	44.155687999999998	Шоссейная	0103000020E61000000100000005000000EC681CEA77D7444098309A95ED134640EC681CEA77D744404B02D4D4B21546402EFF21FDF6D944404B02D4D4B21546402EFF21FDF6D9444098309A95ED134640EC681CEA77D7444098309A95ED134640
61780	57888	41.423357000000003	41.472296999999998	43.906427000000001	43.855623000000001	Горная	0103000020E610000001000000050000002FC4EA8F30B644404B5AF10D85ED45402FC4EA8F30B644400F9BC8CC05F44540DC7F643A74BC44400F9BC8CC05F44540DC7F643A74BC44404B5AF10D85ED45402FC4EA8F30B644404B5AF10D85ED4540
61542	6009	41.423357000000003	41.472296999999998	43.906427000000001	43.855623000000001	Ленина	0103000020E610000001000000050000002FC4EA8F30B644404B5AF10D85ED45402FC4EA8F30B644400F9BC8CC05F44540DC7F643A74BC44400F9BC8CC05F44540DC7F643A74BC44404B5AF10D85ED45402FC4EA8F30B644404B5AF10D85ED4540
61541	6009	41.423357000000003	41.472296999999998	43.906427000000001	43.855623000000001	Карачаевская	0103000020E610000001000000050000002FC4EA8F30B644404B5AF10D85ED45402FC4EA8F30B644400F9BC8CC05F44540DC7F643A74BC44400F9BC8CC05F44540DC7F643A74BC44404B5AF10D85ED45402FC4EA8F30B644404B5AF10D85ED4540
61700	6009	41.423357000000003	41.472296999999998	43.906427000000001	43.855623000000001	Заводская	0103000020E610000001000000050000002FC4EA8F30B644404B5AF10D85ED45402FC4EA8F30B644400F9BC8CC05F44540DC7F643A74BC44400F9BC8CC05F44540DC7F643A74BC44404B5AF10D85ED45402FC4EA8F30B644404B5AF10D85ED4540
62663	58015	41.063932000000001	41.795565000000003	44.169519999999999	43.334093000000003	Октябрьская	0103000020E610000001000000050000007D957CEC2E8844404969368FC3AA45407D957CEC2E8844404B02D4D4B2154640CF6BEC12D5E544404B02D4D4B2154640CF6BEC12D5E544404969368FC3AA45407D957CEC2E8844404969368FC3AA4540
62508	6845	41.502867000000002	41.521245999999998	43.768610000000002	43.727961999999998	Асфальтная	0103000020E610000001000000050000006B9E23F25DC04440895DDBDB2DDD45406B9E23F25DC0444075B0FECF61E24540DD955D30B8C2444075B0FECF61E24540DD955D30B8C24440895DDBDB2DDD45406B9E23F25DC04440895DDBDB2DDD4540
61701	7104	41.612335999999999	41.657350000000001	43.790278000000001	43.739569000000003	Белана	0103000020E61000000100000005000000EC14AB0661CE444056116E32AADE4540EC14AB0661CE4440C85F5AD427E545404703780B24D44440C85F5AD427E545404703780B24D4444056116E32AADE4540EC14AB0661CE444056116E32AADE4540
62581	57996	41.443533000000002	41.458930000000002	43.804586	43.779032000000001	Школьная	0103000020E6100000010000000500000030D978B0C5B84440CC441152B7E3454030D978B0C5B84440E4688EACFCE645409F93DE37BEBA4440E4688EACFCE645409F93DE37BEBA4440CC441152B7E3454030D978B0C5B84440CC441152B7E34540
61776	57896	41.772908999999999	41.795565000000003	43.839830999999997	43.803674999999998	Школьная	0103000020E610000001000000050000005CE49EAEEEE2444070CE88D2DEE645405CE49EAEEEE244405F950B957FEB4540CF6BEC12D5E544405F950B957FEB4540CF6BEC12D5E5444070CE88D2DEE645405CE49EAEEEE2444070CE88D2DEE64540
62398	57896	41.772908999999999	41.795565000000003	43.839830999999997	43.803674999999998	Алиева	0103000020E610000001000000050000005CE49EAEEEE2444070CE88D2DEE645405CE49EAEEEE244405F950B957FEB4540CF6BEC12D5E544405F950B957FEB4540CF6BEC12D5E5444070CE88D2DEE645405CE49EAEEEE2444070CE88D2DEE64540
61752	57892	41.300575000000002	41.335160000000002	43.940313000000003	43.922863	Школьная	0103000020E61000000100000005000000637FD93D79A644401FD8F15F20F64540637FD93D79A644407880272D5CF84540B476DB85E6AA44407880272D5CF84540B476DB85E6AA44401FD8F15F20F64540637FD93D79A644401FD8F15F20F64540
61675	6233	41.689886999999999	41.741325000000003	43.887478999999999	43.840527000000002	Советская	0103000020E61000000100000005000000C0779B374ED84440D733846396EB4540C0779B374ED84440827170E998F14540865AD3BCE3DE4440827170E998F14540865AD3BCE3DE4440D733846396EB4540C0779B374ED84440D733846396EB4540
61603	6233	41.689886999999999	41.741325000000003	43.887478999999999	43.840527000000002	Октябрьская	0103000020E61000000100000005000000C0779B374ED84440D733846396EB4540C0779B374ED84440827170E998F14540865AD3BCE3DE4440827170E998F14540865AD3BCE3DE4440D733846396EB4540C0779B374ED84440D733846396EB4540
61543	6233	41.689886999999999	41.741325000000003	43.887478999999999	43.840527000000002	Ленина	0103000020E61000000100000005000000C0779B374ED84440D733846396EB4540C0779B374ED84440827170E998F14540865AD3BCE3DE4440827170E998F14540865AD3BCE3DE4440D733846396EB4540C0779B374ED84440D733846396EB4540
61674	6233	41.689886999999999	41.741325000000003	43.887478999999999	43.840527000000002	Красная	0103000020E61000000100000005000000C0779B374ED84440D733846396EB4540C0779B374ED84440827170E998F14540865AD3BCE3DE4440827170E998F14540865AD3BCE3DE4440D733846396EB4540C0779B374ED84440D733846396EB4540
61698	6233	41.689886999999999	41.741325000000003	43.887478999999999	43.840527000000002	Заводская	0103000020E61000000100000005000000C0779B374ED84440D733846396EB4540C0779B374ED84440827170E998F14540865AD3BCE3DE4440827170E998F14540865AD3BCE3DE4440D733846396EB4540C0779B374ED84440D733846396EB4540
61737	6553	41.584847000000003	41.630706000000004	44.106476999999998	44.037073999999997	Красная	0103000020E61000000100000005000000F5143944DCCA444015C440D7BE044640F5143944DCCA44405A63D009A10D46400CB265F9BAD044405A63D009A10D46400CB265F9BAD0444015C440D7BE044640F5143944DCCA444015C440D7BE044640
61544	6553	41.584847000000003	41.630706000000004	44.106476999999998	44.037073999999997	Кооперативная	0103000020E61000000100000005000000F5143944DCCA444015C440D7BE044640F5143944DCCA44405A63D009A10D46400CB265F9BAD044405A63D009A10D46400CB265F9BAD0444015C440D7BE044640F5143944DCCA444015C440D7BE044640
61742	6553	41.584847000000003	41.630706000000004	44.106476999999998	44.037073999999997	Казачья	0103000020E61000000100000005000000F5143944DCCA444015C440D7BE044640F5143944DCCA44405A63D009A10D46400CB265F9BAD044405A63D009A10D46400CB265F9BAD0444015C440D7BE044640F5143944DCCA444015C440D7BE044640
62523	57978	41.522889999999997	41.533095000000003	43.960211999999999	43.943838	Красноармейская	0103000020E61000000100000005000000E5B33C0FEEC244406C5CFFAECFF84540E5B33C0FEEC24440069D103AE8FA4540A054FB743CC44440069D103AE8FA4540A054FB743CC444406C5CFFAECFF84540E5B33C0FEEC244406C5CFFAECFF84540
61697	5280	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	Советская	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
61601	5280	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	Набережная	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
61540	5280	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	Ленина	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
61725	5280	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	Красноармейская	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
62496	5280	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	Карбышева	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
61564	5280	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	Калинина	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
61539	5280	41.551420999999998	41.618282000000001	43.891091000000003	43.827756000000001	Заводская	0103000020E61000000100000005000000EFA99CF694C64440AD889AE8F3E94540EFA99CF694C64440466117450FF245404DDA54DD23CF4440466117450FF245404DDA54DD23CF4440AD889AE8F3E94540EFA99CF694C64440AD889AE8F3E94540
61545	6766	41.535466999999997	41.567501	43.811045999999997	43.784433999999997	Юрия Хатуевва	0103000020E610000001000000050000002A8BC22E8AC444406BEF535568E445402A8BC22E8AC444409BC6F65AD0E7454041B96DDFA3C844409BC6F65AD0E7454041B96DDFA3C844406BEF535568E445402A8BC22E8AC444406BEF535568E44540
62446	6898	41.271461000000002	41.288294999999998	43.570321	43.558706999999998	Мостовая	0103000020E61000000100000005000000DA91EA3BBFA24440EC8502B683C74540DA91EA3BBFA244406B9C4D4700C94540D74CBED9E6A444406B9C4D4700C94540D74CBED9E6A44440EC8502B683C74540DA91EA3BBFA24440EC8502B683C74540
61712	5121	41.759273	41.784857000000002	44.444153999999997	44.417414999999998	улица Ленина	0103000020E610000001000000050000002FDE8FDB2FE144400FEECEDA6D3546402FDE8FDB2FE144409C31CC09DA384640B284B53176E444409C31CC09DA384640B284B53176E444400FEECEDA6D3546402FDE8FDB2FE144400FEECEDA6D354640
61686	57874	41.903739999999999	41.923727999999997	44.468423000000001	44.429935999999998	Ленина	0103000020E61000000100000005000000240B98C0ADF34440C0AF912408374640240B98C0ADF34440DCD8EC48F53B4640223317B83CF64440DCD8EC48F53B4640223317B83CF64440C0AF912408374640240B98C0ADF34440C0AF912408374640
62574	57994	41.935442000000002	41.976162000000002	44.389884000000002	44.357635999999999	К.Мижевой	0103000020E6100000010000000500000005A73E90BCF74440A6EF3504C72D464005A73E90BCF74440E99D0AB8E73146408ACC5CE0F2FC4440E99D0AB8E73146408ACC5CE0F2FC4440A6EF3504C72D464005A73E90BCF74440A6EF3504C72D4640
61738	57889	41.933591	41.946292999999997	44.383778	44.360201000000004	Ахлова	0103000020E61000000100000005000000836BEEE87FF74440467EFD101B2E4640836BEEE87FF744404F7633A31F31464084B7072120F944404F7633A31F31464084B7072120F94440467EFD101B2E4640836BEEE87FF74440467EFD101B2E4640
62575	24644	41.659891999999999	41.679718000000001	44.354664999999997	44.345517999999998	Ворошилова	0103000020E610000001000000050000002E724F5777D44440F4160FEF392C46402E724F5777D444409604A8A9652D46405340DAFF00D744409604A8A9652D46405340DAFF00D74440F4160FEF392C46402E724F5777D44440F4160FEF392C4640
61795	57898	41.759596000000002	41.793059	44.362541	44.328923000000003	Октябрьская улица	0103000020E61000000100000005000000121615713AE144407CF31B261A2A4640121615713AE14440C53A55BE672E4640346612F582E54440C53A55BE672E4640346612F582E544407CF31B261A2A4640121615713AE144407CF31B261A2A4640
62543	4844	41.793238000000002	41.807737000000003	44.426692000000003	44.404761999999998	Кирова	0103000020E61000000100000005000000E4F8A1D288E54440EF54C03DCF334640E4F8A1D288E5444080BBECD79D36464074620FED63E7444080BBECD79D36464074620FED63E74440EF54C03DCF334640E4F8A1D288E54440EF54C03DCF334640
61723	57885	42.024535999999998	42.053677999999998	44.349572999999999	44.304879	Полевая	0103000020E610000001000000050000008EC9E2FE230345405C1E6B46062746408EC9E2FE230345404548DDCEBE2C4640E141B3EBDE0645404548DDCEBE2C4640E141B3EBDE0645405C1E6B46062746408EC9E2FE230345405C1E6B4606274640
62596	58004	41.773412	41.788252999999997	44.410352000000003	44.390954000000001	Широкая	0103000020E61000000100000005000000BF2A172AFFE24440C51EDAC70A324640BF2A172AFFE2444092EC116A86344640A8FC6B79E5E4444092EC116A86344640A8FC6B79E5E44440C51EDAC70A324640BF2A172AFFE24440C51EDAC70A324640
61754	57893	41.782342	41.796706	44.338227000000003	44.321688000000002	Победы	0103000020E61000000100000005000000C4245CC823E4444001C287122D294640C4245CC823E44440E6CFB7054B2B464074435376FAE54440E6CFB7054B2B464074435376FAE5444001C287122D294640C4245CC823E4444001C287122D294640
62591	58002	41.776521000000002	41.790382000000001	44.47081	44.458767000000002	Школьная	0103000020E6100000010000000500000020D4450A65E34440F5BD86E0B83A464020D4450A65E344409C508880433C46406DACC43C2BE544409C508880433C46406DACC43C2BE54440F5BD86E0B83A464020D4450A65E34440F5BD86E0B83A4640
75529	60670	41.898232999999998	41.928192000000003	44.326994999999997	44.290349999999997	Ленина	0103000020E610000001000000050000000F98874CF9F24440613255302A2546400F98874CF9F244404E7ADFF8DA2946405534D6FECEF644404E7ADFF8DA2946405534D6FECEF64440613255302A2546400F98874CF9F24440613255302A254640
62534	57980	41.910854999999998	41.920467000000002	44.496468999999998	44.485847	Гагарина	0103000020E61000000100000005000000F4328AE596F444400BEE073C303E4640F4328AE596F44440293DD34B8C3F46400C06D7DCD1F54440293DD34B8C3F46400C06D7DCD1F544400BEE073C303E4640F4328AE596F444400BEE073C303E4640
62572	4937	41.792394000000002	41.815831000000003	44.483345	44.463771999999999	Школьная	0103000020E61000000100000005000000F8C5A52A6DE54440776682E15C3B4640F8C5A52A6DE54440B2D7BB3FDE3D4640100874266DE84440B2D7BB3FDE3D4640100874266DE84440776682E15C3B4640F8C5A52A6DE54440776682E15C3B4640
62570	3594	41.655203	41.663243000000001	44.379159000000001	44.371065999999999	Гагарина	0103000020E61000000100000005000000DC9E20B1DDD344402A5437177F2F4640DC9E20B1DDD34440F67D38488830464085268925E5D44440F67D38488830464085268925E5D444402A5437177F2F4640DC9E20B1DDD344402A5437177F2F4640
61749	5103	41.732647	41.753739000000003	44.31729	44.293382999999999	Первомайская	0103000020E610000001000000050000009A417C60C7DD4440E719FB928D2546409A417C60C7DD444086AC6EF59C284640215C01857AE0444086AC6EF59C284640215C01857AE04440E719FB928D2546409A417C60C7DD4440E719FB928D254640
62567	4866	41.795996000000002	41.809327000000003	44.361032999999999	44.344326000000002	Октябрьская	0103000020E6100000010000000500000098DF6932E3E54440CD94D6DF122C464098DF6932E3E544406DE34F54362E46408962F20698E744406DE34F54362E46408962F20698E74440CD94D6DF122C464098DF6932E3E54440CD94D6DF122C4640
61751	4776	41.787264	41.810395999999997	44.457827000000002	44.441476999999999	Школьная	0103000020E61000000100000005000000B9A81611C5E44440D5777E5182384640B9A81611C5E44440E71C3C139A3A464094675E0EBBE74440E71C3C139A3A464094675E0EBBE74440D5777E5182384640B9A81611C5E44440D5777E5182384640
61538	4684	41.928569000000003	41.952598999999999	44.343881000000003	44.320140000000002	Советская	0103000020E610000001000000050000002B8A5759DBF644401B12F758FA2846402B8A5759DBF644409F5BE84A042C4640E59997C3EEF944409F5BE84A042C4640E59997C3EEF944401B12F758FA2846402B8A5759DBF644401B12F758FA284640
62597	58005	41.916055999999998	41.932144999999998	44.366213999999999	44.342295	Джелябиева	0103000020E61000000100000005000000FCA6B05241F54440CB4A9352D02B4640FCA6B05241F544402EABB019E02E4640A110018750F744402EABB019E02E4640A110018750F74440CB4A9352D02B4640FCA6B05241F54440CB4A9352D02B4640
62573	4989	41.626106999999998	41.649669000000003	44.374519999999997	44.367677	Первомайская	0103000020E61000000100000005000000F965304624D04440E63E390A102F4640F965304624D0444055D97745F02F4640CE1C925A28D3444055D97745F02F4640CE1C925A28D34440E63E390A102F4640F965304624D04440E63E390A102F4640
62707	58021	42.010728999999998	42.028821000000001	44.262805	44.217683000000001	Кунижева	0103000020E61000000100000005000000340F60915F01454095F25A09DD1B4640340F60915F014540D61C2098A321464011381268B0034540D61C2098A321464011381268B003454095F25A09DD1B4640340F60915F01454095F25A09DD1B4640
62482	57961	42.398083	44.475527	44.020572000000001	42.888719000000002	Октябрьская	0103000020E61000000100000005000000FA0B3D62F4324540BB2A508BC1714540FA0B3D62F43245404E9B711AA2024640B8AE9811DE3C46404E9B711AA2024640B8AE9811DE3C4640BB2A508BC1714540FA0B3D62F4324540BB2A508BC1714540
62371	57944	43.563647000000003	43.591064000000003	43.448743	43.423375999999998	Дружбы	0103000020E6100000010000000500000088BEBB9525C84540A5F44C2F31B6454088BEBB9525C845408BA71E6970B94540E6EB32FCA7CB45408BA71E6970B94540E6EB32FCA7CB4540A5F44C2F31B6454088BEBB9525C84540A5F44C2F31B64540
62345	57837	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	Эльбрусский	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62457	57837	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	Баксанская	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62432	57845	44.120790999999997	44.154747	43.499307000000002	43.459777000000003	Теунова	0103000020E6100000010000000500000058535914760F4640FC3905F9D9BA454058535914760F4640FAD4B14AE9BF4540BA13ECBFCE134640FAD4B14AE9BF4540BA13ECBFCE134640FC3905F9D9BA454058535914760F4640FC3905F9D9BA4540
61518	57845	44.120790999999997	44.154747	43.499307000000002	43.459777000000003	Терская	0103000020E6100000010000000500000058535914760F4640FC3905F9D9BA454058535914760F4640FAD4B14AE9BF4540BA13ECBFCE134640FAD4B14AE9BF4540BA13ECBFCE134640FC3905F9D9BA454058535914760F4640FC3905F9D9BA4540
62396	57845	44.120790999999997	44.154747	43.499307000000002	43.459777000000003	Ленина	0103000020E6100000010000000500000058535914760F4640FC3905F9D9BA454058535914760F4640FAD4B14AE9BF4540BA13ECBFCE134640FAD4B14AE9BF4540BA13ECBFCE134640FC3905F9D9BA454058535914760F4640FC3905F9D9BA4540
62550	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	разъезд Шарданово	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
61514	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Строительная	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62369	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Остапенко	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62374	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Ленина	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62388	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Кавказская	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62427	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Дзержинского	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62428	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Головко	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
61515	57836	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Агрономический переулок	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62537	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	им. братьев Кушховых	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61379	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Эльбрусская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62511	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Щорса	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62422	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Шортанова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61383	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Шогенцукова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61378	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Шогенова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62370	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Чеченская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61463	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Чернышевского	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61457	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Чайковского	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62414	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Ульбашева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61353	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Тырныаузская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61462	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Туриста	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62566	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Тимошенко	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62425	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Тимирязева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61384	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Тепличный	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61373	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Тарчокова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62418	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Революционная	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62355	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Пушкина	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61461	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Профсоюзная	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61464	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Пачева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61466	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Огоньянца	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62373	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Неделина	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61335	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Мусукаева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62339	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Московская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62352	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Мечникова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61456	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Матросова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62358	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Мальбахова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61382	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Ленина	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61374	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Кулиева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62357	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Коммунаров	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61380	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Комарова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62365	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Коллонтай	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61455	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Кирова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62340	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Катханова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62409	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Карашаева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61471	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Канкошева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61453	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Каменская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61465	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Калюжного	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61459	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Калмыкова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62367	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Калинина	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62356	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Кабардинская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62576	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Инессы Арманд	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61386	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Ингушская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61385	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Идарова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62350	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Захарова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62417	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Залиханова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61376	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Заводская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61377	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Дагестанская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61458	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Горького	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62429	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Головко	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61469	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Гагарина	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61375	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Ватутина	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62354	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Будаева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61454	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Байсултанова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61371	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Бабаева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61467	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Б. Хмельницкого	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61470	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Ашурова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62361	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Ахметова	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61372	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Аттоева	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62366	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	9-е Января	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61472	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	2-я Надречная	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
61419	32538	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	2-ой Таманской дивизии	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62403	57824	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Ленина	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
61422	57824	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Железнодорожная	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
62468	57824	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Горького	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
61447	57824	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	9 Мая	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
62346	57839	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	переулок Куашева	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
61505	57839	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Эльбрусская	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
61507	57839	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Шукова	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62462	57839	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Кокова	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62464	57839	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Баксанова	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62547	52917	42.636944999999997	42.661577000000001	43.262424000000003	43.250743999999997	Эльбрусская	0103000020E61000000100000005000000E42CEC698751454088D51F6118A04540E42CEC6987514540BFD7101C97A1454095641D8EAE544540BFD7101C97A1454095641D8EAE54454088D51F6118A04540E42CEC698751454088D51F6118A04540
62412	32613	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	проспект Эльбрусский	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
61492	32613	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	пр. Эльбрусский	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62404	32613	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	Энеева	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62454	32613	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	Мичурина	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62490	32613	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	Мизиева	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62515	32613	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	Гызыева	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62549	32613	42.908487999999998	42.947825000000002	43.425922999999997	43.373856000000004	Автогаражная	0103000020E610000001000000050000007B67B45549744540EAB46E83DAAF45407B67B455497445409ECE15A584B6454065AA6054527945409ECE15A584B6454065AA605452794540EAB46E83DAAF45407B67B45549744540EAB46E83DAAF4540
62569	57992	42.398083	43.271496999999997	43.662194999999997	43.133940000000003	Ленина	0103000020E61000000100000005000000FA0B3D62F432454029D027F224914540FA0B3D62F4324540904946CEC2D4454026FBE769C0A24540904946CEC2D4454026FBE769C0A2454029D027F224914540FA0B3D62F432454029D027F224914540
62520	57976	42.398083	43.271496999999997	43.662194999999997	43.133940000000003	Энеева	0103000020E61000000100000005000000FA0B3D62F432454029D027F224914540FA0B3D62F4324540904946CEC2D4454026FBE769C0A24540904946CEC2D4454026FBE769C0A2454029D027F224914540FA0B3D62F432454029D027F224914540
62571	57976	42.398083	43.271496999999997	43.662194999999997	43.133940000000003	Ленина	0103000020E61000000100000005000000FA0B3D62F432454029D027F224914540FA0B3D62F4324540904946CEC2D4454026FBE769C0A24540904946CEC2D4454026FBE769C0A2454029D027F224914540FA0B3D62F432454029D027F224914540
62524	57979	43.144303999999998	43.217652000000001	43.608981999999997	43.582977999999997	800-Погибших	0103000020E610000001000000050000004B57B08D78924540CC24EA059FCA45404B57B08D7892454024ED461FF3CD45405AF44E05DC9B454024ED461FF3CD45405AF44E05DC9B4540CC24EA059FCA45404B57B08D78924540CC24EA059FCA4540
62557	57984	42.741742000000002	42.760508000000002	43.315165	43.300443999999999	Школьная	0103000020E61000000100000005000000EA08E066F15E4540C423F1F274A64540EA08E066F15E454003ECA35357A84540562C7E535861454003ECA35357A84540562C7E5358614540C423F1F274A64540EA08E066F15E4540C423F1F274A64540
62397	52890	43.024594999999998	43.055200999999997	43.467668000000003	43.441870999999999	Тебердиева	0103000020E610000001000000050000009352D0ED2583454081069B3A8FB845409352D0ED2583454060B1868BDCBB45406EDA8CD31087454060B1868BDCBB45406EDA8CD31087454081069B3A8FB845409352D0ED2583454081069B3A8FB84540
62545	52889	43.141869999999997	43.159422999999997	43.515529000000001	43.508507000000002	Байсултанова	0103000020E610000001000000050000004A24D1CB28924540BF64E3C116C145404A24D1CB28924540DE91B1DAFCC14540779D0DF967944540DE91B1DAFCC14540779D0DF967944540BF64E3C116C145404A24D1CB28924540BF64E3C116C14540
62563	57990	43.589509	43.624068000000001	43.325468999999998	43.305489000000001	Угнич	0103000020E610000001000000050000004DD9E90775CB4540D52478431AA745404DD9E90775CB4540506EDBF7A8A94540753DD175E1CF4540506EDBF7A8A94540753DD175E1CF4540D52478431AA745404DD9E90775CB4540D52478431AA74540
62519	57958	43.589509	43.624068000000001	43.325468999999998	43.305489000000001	Мечиева К.Б.	0103000020E610000001000000050000004DD9E90775CB4540D52478431AA745404DD9E90775CB4540506EDBF7A8A94540753DD175E1CF4540506EDBF7A8A94540753DD175E1CF4540D52478431AA745404DD9E90775CB4540D52478431AA74540
62472	57958	43.589509	43.624068000000001	43.325468999999998	43.305489000000001	Мечиева К.Б	0103000020E610000001000000050000004DD9E90775CB4540D52478431AA745404DD9E90775CB4540506EDBF7A8A94540753DD175E1CF4540506EDBF7A8A94540753DD175E1CF4540D52478431AA745404DD9E90775CB4540D52478431AA74540
62362	57942	43.016483000000001	43.789994999999998	43.506093999999997	42.888725999999998	Мечиева К.Б	0103000020E6100000010000000500000051F86C1D1C8245406D8D08C6C171454051F86C1D1C824540D5592DB0C7C045407380608E1EE54540D5592DB0C7C045407380608E1EE545406D8D08C6C171454051F86C1D1C8245406D8D08C6C1714540
62556	52886	43.405265	43.428117999999998	43.301434999999998	43.291257999999999	Школьная	0103000020E61000000100000005000000529B38B9DFB34540645930F147A54540529B38B9DFB34540546F0D6C95A645401A6A1492CCB64540546F0D6C95A645401A6A1492CCB64540645930F147A54540529B38B9DFB34540645930F147A54540
62461	52831	43.693866999999997	43.725568000000003	43.342728000000001	43.324084999999997	Ленина	0103000020E61000000100000005000000066344A2D0D84540E40F069E7BA94540066344A2D0D8454035B6D782DEAB454017838769DFDC454035B6D782DEAB454017838769DFDC4540E40F069E7BA94540066344A2D0D84540E40F069E7BA94540
62394	52834	43.630122	43.675496000000003	43.297432000000001	43.267118000000004	Сталина	0103000020E61000000100000005000000BC3E73D6A7D04540231631EC30A24540BC3E73D6A7D045405664744012A64540174A26A776D645405664744012A64540174A26A776D64540231631EC30A24540BC3E73D6A7D04540231631EC30A24540
62459	52834	43.630122	43.675496000000003	43.297432000000001	43.267118000000004	Ленина	0103000020E61000000100000005000000BC3E73D6A7D04540231631EC30A24540BC3E73D6A7D045405664744012A64540174A26A776D645405664744012A64540174A26A776D64540231631EC30A24540BC3E73D6A7D04540231631EC30A24540
62499	33089	43.647226000000003	43.664025000000002	43.379393	43.366962000000001	Холамкая	0103000020E610000001000000050000007A8F334DD8D24540F86F5E9CF8AE45407A8F334DD8D2454069AA27F38FB04540FB5C6DC5FED4454069AA27F38FB04540FB5C6DC5FED44540F86F5E9CF8AE45407A8F334DD8D24540F86F5E9CF8AE4540
61421	32774	43.660719	43.680059999999997	43.247473999999997	43.22354	Настуева	0103000020E61000000100000005000000446CB07092D4454086AC6EF59C9C4540446CB07092D445401E4E603AAD9F4540ACA8C1340CD745401E4E603AAD9F4540ACA8C1340CD7454086AC6EF59C9C4540446CB07092D4454086AC6EF59C9C4540
62516	33122	43.426186999999999	43.483392000000002	43.154693000000002	43.097434999999997	Таулуева	0103000020E610000001000000050000007C7DAD4B8DB645402D3E05C0788C45407C7DAD4B8DB64540C7F5EFFACC934540F392FFC9DFBD4540C7F5EFFACC934540F392FFC9DFBD45402D3E05C0788C45407C7DAD4B8DB645402D3E05C0788C4540
62477	33122	43.426186999999999	43.483392000000002	43.154693000000002	43.097434999999997	Настуева	0103000020E610000001000000050000007C7DAD4B8DB645402D3E05C0788C45407C7DAD4B8DB64540C7F5EFFACC934540F392FFC9DFBD4540C7F5EFFACC934540F392FFC9DFBD45402D3E05C0788C45407C7DAD4B8DB645402D3E05C0788C4540
62530	33122	43.426186999999999	43.483392000000002	43.154693000000002	43.097434999999997	Асанова	0103000020E610000001000000050000007C7DAD4B8DB645402D3E05C0788C45407C7DAD4B8DB64540C7F5EFFACC934540F392FFC9DFBD4540C7F5EFFACC934540F392FFC9DFBD45402D3E05C0788C45407C7DAD4B8DB645402D3E05C0788C4540
62525	33144	43.275432000000002	43.295831999999997	43.220359999999999	43.209538999999999	Османова Э.Х.	0103000020E61000000100000005000000CD22145B41A34540471E882CD29A4540CD22145B41A345405CACA8C1349C45401D8EAED2DDA545405CACA8C1349C45401D8EAED2DDA54540471E882CD29A4540CD22145B41A34540471E882CD29A4540
62433	52864	43.534568999999998	43.562649999999998	43.282668000000001	43.261609999999997	Тогузаева	0103000020E610000001000000050000004B3ACAC16CC445403D27BD6F7CA145404B3ACAC16CC4454018D00B772EA44540158C4AEA04C8454018D00B772EA44540158C4AEA04C845403D27BD6F7CA145404B3ACAC16CC445403D27BD6F7CA14540
61490	52864	43.534568999999998	43.562649999999998	43.282668000000001	43.261609999999997	Мокаева	0103000020E610000001000000050000004B3ACAC16CC445403D27BD6F7CA145404B3ACAC16CC4454018D00B772EA44540158C4AEA04C8454018D00B772EA44540158C4AEA04C845403D27BD6F7CA145404B3ACAC16CC445403D27BD6F7CA14540
61489	33092	43.712381000000001	43.758420000000001	43.412852999999998	43.375323999999999	Кушхова	0103000020E6100000010000000500000059A5F44C2FDB4540B3B3E89D0AB0454059A5F44C2FDB45401A87FA5DD8B44540F05014E813E145401A87FA5DD8B44540F05014E813E14540B3B3E89D0AB0454059A5F44C2FDB4540B3B3E89D0AB04540
62470	33092	43.712381000000001	43.758420000000001	43.412852999999998	43.375323999999999	Бицуева	0103000020E6100000010000000500000059A5F44C2FDB4540B3B3E89D0AB0454059A5F44C2FDB45401A87FA5DD8B44540F05014E813E145401A87FA5DD8B44540F05014E813E14540B3B3E89D0AB0454059A5F44C2FDB4540B3B3E89D0AB04540
62395	52841	43.484712000000002	43.522917	43.554611000000001	43.529400000000003	Ленина	0103000020E6100000010000000500000048FDF50A0BBE45404F401361C3C3454048FDF50A0BBE45403D80457EFDC64540DFC2BAF1EEC245403D80457EFDC64540DFC2BAF1EEC245404F401361C3C3454048FDF50A0BBE45404F401361C3C34540
62444	52801	43.533329000000002	43.601331000000002	43.541823999999998	43.518535999999997	переулок Колхозный	0103000020E610000001000000050000001381EA1F44C445403AE63C635FC245401381EA1F44C445400D18247D5AC545401689096AF8CC45400D18247D5AC545401689096AF8CC45403AE63C635FC245401381EA1F44C445403AE63C635FC24540
61415	52801	43.533329000000002	43.601331000000002	43.541823999999998	43.518535999999997	Ленина	0103000020E610000001000000050000001381EA1F44C445403AE63C635FC245401381EA1F44C445400D18247D5AC545401689096AF8CC45400D18247D5AC545401689096AF8CC45403AE63C635FC245401381EA1F44C445403AE63C635FC24540
61418	52801	43.533329000000002	43.601331000000002	43.541823999999998	43.518535999999997	А.Г.Юанова	0103000020E610000001000000050000001381EA1F44C445403AE63C635FC245401381EA1F44C445400D18247D5AC545401689096AF8CC45400D18247D5AC545401689096AF8CC45403AE63C635FC245401381EA1F44C445403AE63C635FC24540
62385	52792	43.577714999999998	43.619253	43.59919	43.579020999999997	Ленина	0103000020E610000001000000050000004EB4AB90F2C945403E59315C1DCA45404EB4AB90F2C945408D0B0742B2CC45409679ABAE43CF45408D0B0742B2CC45409679ABAE43CF45403E59315C1DCA45404EB4AB90F2C945403E59315C1DCA4540
61413	33017	43.549669000000002	43.618488999999997	43.579047000000003	43.556204999999999	Свободы	0103000020E610000001000000050000000150C58D5BC64540936FB6B931C745400150C58D5BC6454068EC4B361ECA4540C6F7C5A52ACF454068EC4B361ECA4540C6F7C5A52ACF4540936FB6B931C745400150C58D5BC64540936FB6B931C74540
62492	33017	43.549669000000002	43.618488999999997	43.579047000000003	43.556204999999999	Кулиева	0103000020E610000001000000050000000150C58D5BC64540936FB6B931C745400150C58D5BC6454068EC4B361ECA4540C6F7C5A52ACF454068EC4B361ECA4540C6F7C5A52ACF4540936FB6B931C745400150C58D5BC64540936FB6B931C74540
61486	33017	43.058416999999999	43.444980000000001	43.559261999999997	43.210669000000003	Баксанское шоссе	0103000020E61000000100000005000000E54350357A874540F9A3A833F79A4540E54350357A874540A1F2AFE595C74540E2AFC91AF5B84540A1F2AFE595C74540E2AFC91AF5B84540F9A3A833F79A4540E54350357A874540F9A3A833F79A4540
61414	33017	43.058416999999999	43.444980000000001	43.559261999999997	43.210669000000003	Баксанское Шоссе	0103000020E61000000100000005000000E54350357A874540F9A3A833F79A4540E54350357A874540A1F2AFE595C74540E2AFC91AF5B84540A1F2AFE595C74540E2AFC91AF5B84540F9A3A833F79A4540E54350357A874540F9A3A833F79A4540
61412	33017	42.862313999999998	43.806793999999996	43.647297999999999	43.088396000000003	А.С. Кярова	0103000020E6100000010000000500000004711E4E606E4540728C648F508B454004711E4E606E454013622EA9DAD24540F44D9A0645E7454013622EA9DAD24540F44D9A0645E74540728C648F508B454004711E4E606E4540728C648F508B4540
62510	57972	43.230730999999999	43.244044000000002	43.443075	43.425963000000003	Балкарская	0103000020E610000001000000050000003196E997889D45402D27A1F485B645403196E997889D45406D567DAEB6B845407C6473D53C9F45406D567DAEB6B845407C6473D53C9F45402D27A1F485B645403196E997889D45402D27A1F485B64540
62440	57951	42.862313999999998	43.806793999999996	43.647297999999999	43.088396000000003	Ленина	0103000020E6100000010000000500000004711E4E606E4540728C648F508B454004711E4E606E454013622EA9DAD24540F44D9A0645E7454013622EA9DAD24540F44D9A0645E74540728C648F508B454004711E4E606E4540728C648F508B4540
61409	52790	43.282662999999999	43.310026000000001	43.510697	43.482047000000001	К.Кулиева	0103000020E6100000010000000500000006651A4D2EA44540451152B7B3BD454006651A4D2EA445402995F0845EC14540717495EEAEA745402995F0845EC14540717495EEAEA74540451152B7B3BD454006651A4D2EA44540451152B7B3BD4540
61487	52814	43.670762000000003	43.738630000000001	43.533144999999998	43.491118999999998	Ленина	0103000020E6100000010000000500000025B37A87DBD54540DCB8C5FCDCBE454025B37A87DBD54540518369183EC4454018EC866D8BDE4540518369183EC4454018EC866D8BDE4540DCB8C5FCDCBE454025B37A87DBD54540DCB8C5FCDCBE4540
61493	52814	43.670762000000003	43.738630000000001	43.533144999999998	43.491118999999998	А.Тухужева	0103000020E6100000010000000500000025B37A87DBD54540DCB8C5FCDCBE454025B37A87DBD54540518369183EC4454018EC866D8BDE4540518369183EC4454018EC866D8BDE4540DCB8C5FCDCBE454025B37A87DBD54540DCB8C5FCDCBE4540
62443	52791	43.408597999999998	43.467742999999999	43.568818999999998	43.556739999999998	Канукоева Н.Т	0103000020E61000000100000005000000029B73F04CB4454001309E4143C74540029B73F04CB44540F52B9D0FCFC845406AF7AB00DFBB4540F52B9D0FCFC845406AF7AB00DFBB454001309E4143C74540029B73F04CB4454001309E4143C74540
62401	57948	42.862313999999998	43.806793999999996	43.647297999999999	43.088396000000003	Нарткалинское шоссе	0103000020E6100000010000000500000004711E4E606E4540728C648F508B454004711E4E606E454013622EA9DAD24540F44D9A0645E7454013622EA9DAD24540F44D9A0645E74540728C648F508B454004711E4E606E4540728C648F508B4540
62531	32900	43.790695999999997	43.803102000000003	43.561967000000003	43.545397999999999	Мира	0103000020E61000000100000005000000FC89CA8635E54540E3A6069ACFC54540FC89CA8635E545403337DF88EEC7454015ADDC0BCCE645403337DF88EEC7454015ADDC0BCCE64540E3A6069ACFC54540FC89CA8635E54540E3A6069ACFC54540
62436	16753	43.820870999999997	43.856856999999998	43.614752000000003	43.597676	Ленина	0103000020E610000001000000050000000E9E094D12E9454053CDACA580CC45400E9E094D12E9454047938B31B0CE4540A12C7C7DADED454047938B31B0CE4540A12C7C7DADED454053CDACA580CC45400E9E094D12E9454053CDACA580CC4540
62402	52372	44.007773999999998	44.027582000000002	43.361567999999998	43.320962999999999	Бараова	0103000020E610000001000000050000002AE109BDFE004640EF1CCA5015A945402AE109BDFE004640DBA337DC47AE4540A9FA95CE87034640DBA337DC47AE4540A9FA95CE87034640EF1CCA5015A945402AE109BDFE004640EF1CCA5015A94540
62333	52374	44.012948000000002	44.037965999999997	43.312455999999997	43.276058999999997	Кирова	0103000020E610000001000000050000003946B247A80146401B62BCE655A345403946B247A801464030B8E68EFEA74540122EE411DC04464030B8E68EFEA74540122EE411DC0446401B62BCE655A345403946B247A80146401B62BCE655A34540
61478	52741	43.749374000000003	43.775748	43.504165	43.474589999999999	Школьная	0103000020E61000000100000005000000823CBB7CEBDF45401B81785DBFBC4540823CBB7CEBDF4540D8648D7A88C04540FDF7E0B54BE34540D8648D7A88C04540FDF7E0B54BE345401B81785DBFBC4540823CBB7CEBDF45401B81785DBFBC4540
62392	52741	43.749374000000003	43.775748	43.504165	43.474589999999999	Братьев Кафоевых	0103000020E61000000100000005000000823CBB7CEBDF45401B81785DBFBC4540823CBB7CEBDF4540D8648D7A88C04540FDF7E0B54BE34540D8648D7A88C04540FDF7E0B54BE345401B81785DBFBC4540823CBB7CEBDF45401B81785DBFBC4540
62540	52369	43.685063	43.710287999999998	43.149498000000001	43.141604000000001	Ленина	0103000020E610000001000000050000008E59F624B0D74540CC7D7214209245408E59F624B0D74540A1681EC022934540E15E99B7EADA4540A1681EC022934540E15E99B7EADA4540CC7D7214209245408E59F624B0D74540CC7D721420924540
62450	52752	43.828541999999999	43.882728999999998	43.490079000000001	43.451720999999999	Ленина	0103000020E6100000010000000500000064AE0CAA0DEA45404DF564FED1B9454064AE0CAA0DEA45406BBA9EE8BABE45408A1D8D43FDF045406BBA9EE8BABE45408A1D8D43FDF045404DF564FED1B9454064AE0CAA0DEA45404DF564FED1B94540
62452	52752	43.828541999999999	43.882728999999998	43.490079000000001	43.451720999999999	Куашева	0103000020E6100000010000000500000064AE0CAA0DEA45404DF564FED1B9454064AE0CAA0DEA45406BBA9EE8BABE45408A1D8D43FDF045406BBA9EE8BABE45408A1D8D43FDF045404DF564FED1B9454064AE0CAA0DEA45404DF564FED1B94540
61406	52762	43.908374999999999	43.931283000000001	43.542490000000001	43.530112000000003	Пролетарская	0103000020E6100000010000000500000083C0CAA145F44540CC9BC3B5DAC3454083C0CAA145F445401A34F44F70C545400F29064834F745401A34F44F70C545400F29064834F74540CC9BC3B5DAC3454083C0CAA145F44540CC9BC3B5DAC34540
61404	52759	43.989753999999998	44.000658999999999	43.608989000000001	43.599269	Ленина	0103000020E61000000100000005000000E78A5242B0FE4540D940BAD8B4CC4540E78A5242B0FE4540D74FFF59F3CD45405AB9179815004640D74FFF59F3CD45405AB9179815004640D940BAD8B4CC4540E78A5242B0FE4540D940BAD8B4CC4540
61402	52747	43.769235000000002	43.807423	43.435049999999997	43.391547000000003	Ленина	0103000020E6100000010000000500000023F8DF4A76E2454068EC4B361EB2454023F8DF4A76E24540F90FE9B7AFB74540E48409A359E74540F90FE9B7AFB74540E48409A359E7454068EC4B361EB2454023F8DF4A76E2454068EC4B361EB24540
61479	52747	43.769235000000002	43.807423	43.435049999999997	43.391547000000003	Грейдерная	0103000020E6100000010000000500000023F8DF4A76E2454068EC4B361EB2454023F8DF4A76E24540F90FE9B7AFB74540E48409A359E74540F90FE9B7AFB74540E48409A359E7454068EC4B361EB2454023F8DF4A76E2454068EC4B361EB24540
62480	32932	44.009822	44.028714000000001	43.411785999999999	43.395235	Кабалоева	0103000020E610000001000000050000000264E8D841014640069E7B0F97B245400264E8D841014640AF795567B5B44540FB777DE6AC034640AF795567B5B44540FB777DE6AC034640069E7B0F97B245400264E8D841014640069E7B0F97B24540
61403	52755	43.901727999999999	43.944605000000003	43.520294	43.498443999999999	Ленина	0103000020E6100000010000000500000099F1B6D26BF3454097715303CDBF454099F1B6D26BF345400B2769FE98C24540AD510FD1E8F845400B2769FE98C24540AD510FD1E8F8454097715303CDBF454099F1B6D26BF3454097715303CDBF4540
62387	57832	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	Тарчокова	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
61485	57832	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	Пушкина	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
62437	57832	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	Массаева	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
62463	57832	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	Ленина	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
62434	57832	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	Кабардинская	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
62447	57832	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	Жамборова	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
61483	57832	43.833986000000003	43.876890000000003	43.573723999999999	43.531948999999997	Гурфова	0103000020E6100000010000000500000033A9A10DC0EA4540E811A3E716C4454033A9A10DC0EA45401477BCC96FC94540401878EE3DF045401477BCC96FC94540401878EE3DF04540E811A3E716C4454033A9A10DC0EA4540E811A3E716C44540
62505	32881	43.835279999999997	43.846868000000001	43.573357999999999	43.560777999999999	Комсомольская	0103000020E610000001000000050000005E807D74EAEA45407C28D192C7C745405E807D74EAEA4540327381CB63C94540B403AE2B66EC4540327381CB63C94540B403AE2B66EC45407C28D192C7C745405E807D74EAEA45407C28D192C7C74540
62384	52764	43.857126999999998	43.899267000000002	43.553055999999998	43.520693000000001	Октябрьская	0103000020E6100000010000000500000061C26856B6ED4540C9207711A6C2454061C26856B6ED4540A46DFC89CAC645409FAF592E1BF34540A46DFC89CAC645409FAF592E1BF34540C9207711A6C2454061C26856B6ED4540C9207711A6C24540
61480	52764	43.857126999999998	43.899267000000002	43.553055999999998	43.520693000000001	Кирова	0103000020E6100000010000000500000061C26856B6ED4540C9207711A6C2454061C26856B6ED4540A46DFC89CAC645409FAF592E1BF34540A46DFC89CAC645409FAF592E1BF34540C9207711A6C2454061C26856B6ED4540C9207711A6C24540
62478	32884	43.869307999999997	43.888083000000002	43.325291999999997	43.30894	Массаева	0103000020E6100000010000000500000059130B7C45EF45408F368E588BA7454059130B7C45EF454041D3122BA3A94540199128B4ACF1454041D3122BA3A94540199128B4ACF145408F368E588BA7454059130B7C45EF45408F368E588BA74540
61401	52733	43.744782999999998	43.788108999999999	43.598590000000002	43.577368	Центральная	0103000020E61000000100000005000000F2CEA10C55DF4540E3E0D231E7C94540F2CEA10C55DF454038DBDC989ECC4540755776C1E0E4454038DBDC989ECC4540755776C1E0E44540E3E0D231E7C94540F2CEA10C55DF4540E3E0D231E7C94540
62546	40382	43.729700999999999	43.750639999999997	43.222087999999999	43.211734	Ленина	0103000020E61000000100000005000000E36DA5D766DD4540C3B986191A9B4540E36DA5D766DD4540C26A2C616D9C4540E388B5F814E04540C26A2C616D9C4540E388B5F814E04540C3B986191A9B4540E36DA5D766DD4540C3B986191A9B4540
61370	52367	43.880070000000003	43.934587999999998	43.437359999999998	43.396008000000002	Суншева	0103000020E610000001000000050000006A183E22A6F04540297AE063B0B245406A183E22A6F045400E4A9869FBB74540F59D5F94A0F745400E4A9869FBB74540F59D5F94A0F74540297AE063B0B245406A183E22A6F04540297AE063B0B24540
61431	52367	43.880070000000003	43.934587999999998	43.437359999999998	43.396008000000002	Жигунова	0103000020E610000001000000050000006A183E22A6F04540297AE063B0B245406A183E22A6F045400E4A9869FBB74540F59D5F94A0F745400E4A9869FBB74540F59D5F94A0F74540297AE063B0B245406A183E22A6F04540297AE063B0B24540
62405	52370	43.91178	43.964215000000003	43.370488000000002	43.340394000000003	Хамгокова	0103000020E61000000100000005000000CD920035B5F4454098E0D40792AB4540CD920035B5F44540BDC799266CAF454005A8A9656BFB4540BDC799266CAF454005A8A9656BFB454098E0D40792AB4540CD920035B5F4454098E0D40792AB4540
61443	52370	43.91178	43.964215000000003	43.370488000000002	43.340394000000003	Степная	0103000020E61000000100000005000000CD920035B5F4454098E0D40792AB4540CD920035B5F44540BDC799266CAF454005A8A9656BFB4540BDC799266CAF454005A8A9656BFB454098E0D40792AB4540CD920035B5F4454098E0D40792AB4540
62386	52722	44.193896000000002	44.232576999999999	43.706597000000002	43.693021000000002	Ленина	0103000020E61000000100000005000000A1698995D11846407A3881E9B4D84540A1698995D1184640D2393FC571DA4540A1664815C51D4640D2393FC571DA4540A1664815C51D46407A3881E9B4D84540A1698995D11846407A3881E9B4D84540
62393	52726	44.289476999999998	44.319021999999997	43.681717999999996	43.665163	Ленина	0103000020E61000000100000005000000DBF813950D2546402FC1A90F24D54540DBF813950D254640198C118942D745402D5A80B6D5284640198C118942D745402D5A80B6D52846402FC1A90F24D54540DBF813950D2546402FC1A90F24D54540
62378	57819	44.120790999999997	44.154747	43.499307000000002	43.459777000000003	Ленина	0103000020E6100000010000000500000058535914760F4640FC3905F9D9BA454058535914760F4640FAD4B14AE9BF4540BA13ECBFCE134640FAD4B14AE9BF4540BA13ECBFCE134640FC3905F9D9BA454058535914760F4640FC3905F9D9BA4540
62430	57819	44.120790999999997	44.154747	43.499307000000002	43.459777000000003	Карданова	0103000020E6100000010000000500000058535914760F4640FC3905F9D9BA454058535914760F4640FAD4B14AE9BF4540BA13ECBFCE134640FAD4B14AE9BF4540BA13ECBFCE134640FC3905F9D9BA454058535914760F4640FC3905F9D9BA4540
61398	52696	44.201244000000003	44.216417	43.517358999999999	43.496135000000002	Дружбы	0103000020E610000001000000050000001442075DC219464053B3075A81BF45401442075DC219464048A5D8D138C2454033A6608DB31B464048A5D8D138C2454033A6608DB31B464053B3075A81BF45401442075DC219464053B3075A81BF4540
62517	57974	44.070692000000001	44.475518000000001	43.730696999999999	43.350391999999999	Ногмова	0103000020E610000001000000050000005F0B7A6F0C094640D86322A5D9AC45405F0B7A6F0C0946408524B37A87DD4540655419C6DD3C46408524B37A87DD4540655419C6DD3C4640D86322A5D9AC45405F0B7A6F0C094640D86322A5D9AC4540
61520	52681	44.182496	44.210496999999997	43.416356999999998	43.376719999999999	Гагарина	0103000020E610000001000000050000004ED367075C174640E3DF675C38B045404ED367075C174640F73AA92F4BB54540FB73D190F11A4640F73AA92F4BB54540FB73D190F11A4640E3DF675C38B045404ED367075C174640E3DF675C38B04540
62451	32864	44.346680999999997	44.363793999999999	43.622413999999999	43.602428000000003	Кудаева	0103000020E610000001000000050000008192020B602C4640EC18575C1CCD45408192020B602C464049490F43ABCF4540923D42CD902E464049490F43ABCF4540923D42CD902E4640EC18575C1CCD45408192020B602C4640EC18575C1CCD4540
62500	57966	44.070692000000001	44.475518000000001	43.730696999999999	43.350391999999999	Матросова	0103000020E610000001000000050000005F0B7A6F0C094640D86322A5D9AC45405F0B7A6F0C0946408524B37A87DD4540655419C6DD3C46408524B37A87DD4540655419C6DD3C4640D86322A5D9AC45405F0B7A6F0C094640D86322A5D9AC4540
62479	32837	44.163882999999998	44.183458000000002	43.657153999999998	43.645432999999997	Центральная	0103000020E6100000010000000500000068AF3E1EFA1446402C616D8C9DD2454068AF3E1EFA144640C1374D9F1DD4454044183F8D7B174640C1374D9F1DD4454044183F8D7B1746402C616D8C9DD2454068AF3E1EFA1446402C616D8C9DD24540
62383	52711	44.111699999999999	44.131489999999999	43.643853999999997	43.628163000000001	Центральная	0103000020E610000001000000050000004A7B832F4C0E464054C72AA567D045404A7B832F4C0E46400BB3D0CE69D2454022E010AAD41046400BB3D0CE69D2454022E010AAD410464054C72AA567D045404A7B832F4C0E464054C72AA567D04540
9948	40363	44.070692000000001	44.475518000000001	43.730696999999999	43.350391999999999	Парковая	0103000020E610000001000000050000005F0B7A6F0C094640D86322A5D9AC45405F0B7A6F0C0946408524B37A87DD4540655419C6DD3C46408524B37A87DD4540655419C6DD3C4640D86322A5D9AC45405F0B7A6F0C094640D86322A5D9AC4540
62497	32804	44.400202999999998	44.417881999999999	43.570993999999999	43.540208999999997	Дышекова	0103000020E610000001000000050000006B6116DA393346409F008A9125C545406B6116DA393346402A1BD65416C9454025CB49287D3546402A1BD65416C9454025CB49287D3546409F008A9125C545406B6116DA393346409F008A9125C54540
62529	52714	44.085811	44.094956000000003	43.617102000000003	43.612755	Сибилова	0103000020E610000001000000050000008B51D7DAFB0A4640F1BA7EC16ECE45408B51D7DAFB0A4640EA25C632FDCE45408D47A984270C4640EA25C632FDCE45408D47A984270C4640F1BA7EC16ECE45408B51D7DAFB0A4640F1BA7EC16ECE4540
62381	52677	44.152636000000001	44.175111999999999	43.499222000000003	43.451740999999998	Мальбахова	0103000020E610000001000000050000009C1892938913464094A12AA6D2B945409C18929389134640CCB8A981E6BF45408E91EC116A164640CCB8A981E6BF45408E91EC116A16464094A12AA6D2B945409C1892938913464094A12AA6D2B94540
62458	52698	44.353158000000001	44.387599999999999	43.500562000000002	43.456288999999998	Ашхотова	0103000020E610000001000000050000000F290648342D464024438EAD67BA45400F290648342D464068CF656A12C04540FDF675E09C31464068CF656A12C04540FDF675E09C31464024438EAD67BA45400F290648342D464024438EAD67BA4540
61476	52692	44.219991999999998	44.247238000000003	43.487200999999999	43.458388999999997	Ленина	0103000020E61000000100000005000000D9B0A6B2281C46404EECA17DACBA4540D9B0A6B2281C46400CCA349A5CBE45400B2AAA7EA51F46400CCA349A5CBE45400B2AAA7EA51F46404EECA17DACBA4540D9B0A6B2281C46404EECA17DACBA4540
62528	52692	44.219991999999998	44.247238000000003	43.487200999999999	43.458388999999997	Гоголя	0103000020E61000000100000005000000D9B0A6B2281C46404EECA17DACBA4540D9B0A6B2281C46400CCA349A5CBE45400B2AAA7EA51F46400CCA349A5CBE45400B2AAA7EA51F46404EECA17DACBA4540D9B0A6B2281C46404EECA17DACBA4540
62527	52685	44.205745	44.217081999999998	43.463022000000002	43.451321999999998	Пачева	0103000020E61000000100000005000000632827DA551A46408FFB56EBC4B94540632827DA551A46400DAA0D4E44BB45406F46CD57C91B46400DAA0D4E44BB45406F46CD57C91B46408FFB56EBC4B94540632827DA551A46408FFB56EBC4B94540
61338	52705	44.095889999999997	44.149231999999998	43.593764999999998	43.566074999999998	Дружбы	0103000020E61000000100000005000000B8019F1F460C4640A60A462575C84540B8019F1F460C46403541D47D00CC454022C2BF081A1346403541D47D00CC454022C2BF081A134640A60A462575C84540B8019F1F460C4640A60A462575C84540
62535	13408	43.831829999999997	43.844487000000001	43.846411000000003	43.837587999999997	Зенковского	0103000020E6100000010000000500000074EACA6779EA4540D2C2651536EB454074EACA6779EA4540C2FC153257EC4540D672672618EC4540C2FC153257EC4540D672672618EC4540D2C2651536EB454074EACA6779EA4540D2C2651536EB4540
62639	58011	43.639195000000001	44.419220000000003	44.019671000000002	43.636096999999999	Интернациональная	0103000020E6100000010000000500000024624A24D1D14540B70A62A06BD1454024624A24D1D14540FED64E948402464021EA3E00A9354640FED64E948402464021EA3E00A9354640B70A62A06BD1454024624A24D1D14540B70A62A06BD14540
62502	57968	43.868895000000002	43.893453999999998	43.766025999999997	43.752130999999999	Ленина	0103000020E6100000010000000500000037548CF337EF454065A71FD445E0454037548CF337EF45405EF1D4230DE245407D3D5FB35CF245405EF1D4230DE245407D3D5FB35CF2454065A71FD445E0454037548CF337EF454065A71FD445E04540
62558	57985	43.838379000000003	43.863945000000001	43.769371999999997	43.756174999999999	Кравченко	0103000020E610000001000000050000009C53C90050EB4540C286A757CAE045409C53C90050EB4540A33A1DC87AE245407845F0BF95EE4540A33A1DC87AE245407845F0BF95EE4540C286A757CAE045409C53C90050EB4540C286A757CAE04540
62513	57973	43.922379999999997	43.933554999999998	43.781336000000003	43.772495999999997	Школьная	0103000020E61000000100000005000000033E3F8C10F6454039252026E1E24540033E3F8C10F64540FF976BD102E445403602F1BA7EF74540FF976BD102E445403602F1BA7EF7454039252026E1E24540033E3F8C10F6454039252026E1E24540
62603	57997	44.106400000000001	44.122281999999998	43.883912000000002	43.872377999999998	Школьная	0103000020E61000000100000005000000AF25E4839E0D4640FCDF1115AAEF4540AF25E4839E0D46405F45460724F14540DA71C3EFA60F46405F45460724F14540DA71C3EFA60F4640FCDF1115AAEF4540AF25E4839E0D4640FCDF1115AAEF4540
61513	57844	43.796894999999999	43.847011999999999	43.822916999999997	43.798366000000001	Пилипенко	0103000020E6100000010000000500000047ACC5A700E64540821E6ADB30E6454047ACC5A700E645404529215855E94540E7A8A3E36AEC45404529215855E94540E7A8A3E36AEC4540821E6ADB30E6454047ACC5A700E64540821E6ADB30E64540
62348	57940	43.831829999999997	43.844487000000001	43.846411000000003	43.837587999999997	Пилипенко	0103000020E6100000010000000500000074EACA6779EA4540D2C2651536EB454074EACA6779EA4540C2FC153257EC4540D672672618EC4540C2FC153257EC4540D672672618EC4540D2C2651536EB454074EACA6779EA4540D2C2651536EB4540
62539	48293	43.767924000000001	43.788773999999997	43.735517999999999	43.725610000000003	Садовая	0103000020E6100000010000000500000021E868554BE2454046D3D9C9E0DC454021E868554BE2454046CF2D7425DE4540B1F7E28BF6E4454046CF2D7425DE4540B1F7E28BF6E4454046D3D9C9E0DC454021E868554BE2454046D3D9C9E0DC4540
62568	57991	43.707197999999998	43.722836999999998	43.760497999999998	43.752938999999998	Центральная	0103000020E61000000100000005000000F7E5CC7685DA454004711E4E60E04540F7E5CC7685DA454032569BFF57E145405CAB3DEC85DC454032569BFF57E145405CAB3DEC85DC454004711E4E60E04540F7E5CC7685DA454004711E4E60E04540
61389	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Строительная	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
61337	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Свободы	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62380	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Пролетарская	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62431	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Привокзальная площадь	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62331	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Привокзальная Площадь	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
61395	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Петренко	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
61474	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Овчарова	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62389	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Ленина	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62379	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Головко	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
61439	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Гагарина переулок	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62376	14545	43.962777000000003	44.075668999999998	43.779136000000001	43.734169000000001	Боронтова	0103000020E61000000100000005000000A62BD8463CFB4540575EF23FF9DD4540A62BD8463CFB454071917BBABAE3454017299485AF09464071917BBABAE3454017299485AF094640575EF23FF9DD4540A62BD8463CFB4540575EF23FF9DD4540
62493	57964	44.014242000000003	44.068553999999999	43.857104999999997	43.841366000000001	Ленина	0103000020E61000000100000005000000651D8EAED2014640B1FB8EE1B1EB4540651D8EAED2014640791EDC9DB5ED45404701A260C6084640791EDC9DB5ED45404701A260C6084640B1FB8EE1B1EB4540651D8EAED2014640B1FB8EE1B1EB4540
62481	57947	43.989950999999998	44.025606000000003	43.753219000000001	43.738858999999998	Октябрьская	0103000020E610000001000000050000003DD2E0B6B6FE454079AD84EE92DE45403DD2E0B6B6FE4540E8DCED7A69E045406B4AB20E47034640E8DCED7A69E045406B4AB20E4703464079AD84EE92DE45403DD2E0B6B6FE454079AD84EE92DE4540
62391	57947	43.989950999999998	44.025606000000003	43.753219000000001	43.738858999999998	Кныш	0103000020E610000001000000050000003DD2E0B6B6FE454079AD84EE92DE45403DD2E0B6B6FE4540E8DCED7A69E045406B4AB20E47034640E8DCED7A69E045406B4AB20E4703464079AD84EE92DE45403DD2E0B6B6FE454079AD84EE92DE4540
62416	8924	44.108601	44.138325999999999	43.779246000000001	43.759729999999998	Кооперативный	0103000020E610000001000000050000000DA837A3E60D464021E527D53EE145400DA837A3E60D4640F8C43A55BEE34540DF1797AAB4114640F8C43A55BEE34540DF1797AAB411464021E527D53EE145400DA837A3E60D464021E527D53EE14540
62504	57970	43.948538999999997	43.988568000000001	43.698307	43.685139999999997	Третьякова	0103000020E6100000010000000500000082FDD7B969F945403997E2AAB2D7454082FDD7B969F94540B0C8AF1F62D94540A2EF6E6589FE4540B0C8AF1F62D94540A2EF6E6589FE45403997E2AAB2D7454082FDD7B969F945403997E2AAB2D74540
62486	57963	44.034067999999998	44.046940999999997	43.744160000000001	43.735523999999998	Широкий переулок	0103000020E6100000010000000500000089EB18575C04464028B682A625DE454089EB18575C044640E57E87A240DF4540B7EBA52902064640E57E87A240DF4540B7EBA5290206464028B682A625DE454089EB18575C04464028B682A625DE4540
62494	57965	43.881371999999999	43.905949999999997	43.782032000000001	43.769176000000002	Ивановского	0103000020E6100000010000000500000018CE35CCD0F045401E6FF25B74E2454018CE35CCD0F045407636E49F19E44540D5E76A2BF6F345407636E49F19E44540D5E76A2BF6F345401E6FF25B74E2454018CE35CCD0F045401E6FF25B74E24540
62467	57955	44.024591000000001	44.043751999999998	43.941727999999998	43.927570000000003	Театральная	0103000020E61000000100000005000000526342CC2503464018601F9DBAF64540526342CC250346401EDD088B8AF845403A9160AA990546401EDD088B8AF845403A9160AA9905464018601F9DBAF64540526342CC2503464018601F9DBAF64540
62562	57989	43.922739999999997	43.943112999999997	43.865769	43.859217000000001	Виноградная	0103000020E61000000100000005000000035B25581CF64540689599D2FAED4540035B25581CF645400072C284D1EE45405AB741EDB7F845400072C284D1EE45405AB741EDB7F84540689599D2FAED4540035B25581CF64540689599D2FAED4540
62342	57939	43.750335	43.802042	43.812750000000001	43.793335999999996	Абубекирова	0103000020E61000000100000005000000A7052FFA0AE04540A65EB7088CE54540A7052FFA0AE0454079E9263108E845405C02F04FA9E6454079E9263108E845405C02F04FA9E64540A65EB7088CE54540A7052FFA0AE04540A65EB7088CE54540
62521	57977	43.849724000000002	43.862948000000003	43.941572999999998	43.929679999999998	Зеленая	0103000020E610000001000000050000002B508BC1C3EC454065DF15C1FFF645402B508BC1C3EC4540F7E5CC7685F8454006137F1475EE4540F7E5CC7685F8454006137F1475EE454065DF15C1FFF645402B508BC1C3EC454065DF15C1FFF64540
62332	12835	44.210155999999998	44.247211	43.779474	43.751792999999999	Ленина	0103000020E6100000010000000500000072874D64E61A46404D2EC6C03AE0454072874D64E61A4640890AD5CDC5E34540111B2C9CA41F4640890AD5CDC5E34540111B2C9CA41F46404D2EC6C03AE0454072874D64E61A46404D2EC6C03AE04540
62518	57975	44.278877000000001	44.403185999999998	44.009338	43.921292000000001	Школьная	0103000020E61000000100000005000000A54DD53DB2234640810871E5ECF54540A54DD53DB2234640164ED2FC310146403F1A4E999B334640164ED2FC310146403F1A4E999B334640810871E5ECF54540A54DD53DB2234640810871E5ECF54540
62585	57998	44.025354	44.042825999999998	43.960451999999997	43.948594999999997	Свободы	0103000020E610000001000000050000005169C4CC3E03464016139B8F6BF945405169C4CC3E0346405BB05417F0FA454091B586527B0546405BB05417F0FA454091B586527B05464016139B8F6BF945405169C4CC3E03464016139B8F6BF94540
62526	13777	43.732987999999999	43.750585999999998	43.679259999999999	43.673496	Красноармейская	0103000020E61000000100000005000000232E008DD2DD454050FEEE1D35D64540232E008DD2DD454090BDDEFDF1D64540F06AB93313E0454090BDDEFDF1D64540F06AB93313E0454050FEEE1D35D64540232E008DD2DD454050FEEE1D35D64540
62559	57986	44.099797000000002	44.116030000000002	43.928731999999997	43.919383000000003	Центральная	0103000020E61000000100000005000000959EE925C60C4640CBBF9657AEF54540959EE925C60C4640D45FAFB0E0F645406DAD2F12DA0E4640D45FAFB0E0F645406DAD2F12DA0E4640CBBF9657AEF54540959EE925C60C4640CBBF9657AEF54540
62554	57982	44.095396000000001	44.126944999999999	43.851930000000003	43.838687	Мира	0103000020E61000000100000005000000A915A6EF350C4640494A7A185AEB4540A915A6EF350C46409B3DD00A0CED454003B2D7BB3F1046409B3DD00A0CED454003B2D7BB3F104640494A7A185AEB4540A915A6EF350C4640494A7A185AEB4540
62512	57967	43.759821000000002	43.773718000000002	43.692722000000003	43.688563000000002	Ленина	0103000020E6100000010000000500000032E884D041E145402A1E17D522D8454032E884D041E14540209C4F1DABD84540CC29013109E34540209C4F1DABD84540CC29013109E345402A1E17D522D8454032E884D041E145402A1E17D522D84540
62469	57956	43.846580000000003	43.896966999999997	43.731530999999997	43.702759	Комсомольская	0103000020E610000001000000050000004EB9C2BB5CEC45401EFCC401F4D945404EB9C2BB5CEC45404D81CCCEA2DD4540AD4B8DD0CFF245404D81CCCEA2DD4540AD4B8DD0CFF245401EFCC401F4D945404EB9C2BB5CEC45401EFCC401F4D94540
62473	57956	43.846580000000003	43.896966999999997	43.731530999999997	43.702759	Аптечная	0103000020E610000001000000050000004EB9C2BB5CEC45401EFCC401F4D945404EB9C2BB5CEC45404D81CCCEA2DD4540AD4B8DD0CFF245404D81CCCEA2DD4540AD4B8DD0CFF245401EFCC401F4D945404EB9C2BB5CEC45401EFCC401F4D94540
62423	57950	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Кабардинская	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62360	57938	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Ю. Фучика	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62364	57938	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	Неделина	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
62349	57938	43.468083999999998	43.693651000000003	43.547089999999997	43.421064999999999	Инессы Арманд	0103000020E61000000100000005000000F3E32F2DEABB4540C03E3A75E5B54540F3E32F2DEABB4540FCFB8C0B07C645403AEB538EC9D84540FCFB8C0B07C645403AEB538EC9D84540C03E3A75E5B54540F3E32F2DEABB4540C03E3A75E5B54540
62363	57938	43.468083999999998	43.693651000000003	43.547089999999997	43.421064999999999	Балкарская	0103000020E61000000100000005000000F3E32F2DEABB4540C03E3A75E5B54540F3E32F2DEABB4540FCFB8C0B07C645403AEB538EC9D84540FCFB8C0B07C645403AEB538EC9D84540C03E3A75E5B54540F3E32F2DEABB4540C03E3A75E5B54540
62344	57938	43.468083999999998	43.693651000000003	43.547089999999997	43.421064999999999	Аттоева	0103000020E61000000100000005000000F3E32F2DEABB4540C03E3A75E5B54540F3E32F2DEABB4540FCFB8C0B07C645403AEB538EC9D84540FCFB8C0B07C645403AEB538EC9D84540C03E3A75E5B54540F3E32F2DEABB4540C03E3A75E5B54540
9620	40233	44.065939999999998	44.066192000000001	43.621637	43.619875	Лебедевых	0103000020E61000000100000005000000C6BFCFB870084640D34D621058CF4540C6BFCFB870084640E57D1CCD91CF4540E0A0BDFA78084640E57D1CCD91CF4540E0A0BDFA78084640D34D621058CF4540C6BFCFB870084640D34D621058CF4540
62552	7785	44.088326000000002	44.111862000000002	43.723531999999999	43.713569999999997	Мичурина	0103000020E6100000010000000500000079B130444E0B46400FB4024356DB454079B130444E0B464003CE52B29CDC454024D5777E510E464003CE52B29CDC454024D5777E510E46400FB4024356DB454079B130444E0B46400FB4024356DB4540
61346	45731	43.934821999999997	43.979962	43.646515999999998	43.633865999999998	Ленина	0103000020E6100000010000000500000068CA4E3FA8F74540EE05668522D1454068CA4E3FA8F745409D2B4A09C1D2454050A912656FFD45409D2B4A09C1D2454050A912656FFD4540EE05668522D1454068CA4E3FA8F74540EE05668522D14540
62507	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Трудовая	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
61348	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Октябрьская	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
61481	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Медведева	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
61436	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Кирова	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
61482	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Калинина	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
62359	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Горького	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
62335	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	Гагарина	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
61424	1725	44.031390999999999	44.089286999999999	43.661602000000002	43.598629000000003	9 Мая	0103000020E61000000100000005000000C231CB9E04044640F6B704E09FCC4540C231CB9E04044640EE7BD45FAFD445409E7AA4C16D0B4640EE7BD45FAFD445409E7AA4C16D0B4640F6B704E09FCC4540C231CB9E04044640F6B704E09FCC4540
62555	57983	43.916316999999999	43.929251999999998	43.624384999999997	43.615222000000003	Центральная	0103000020E6100000010000000500000069E21DE049F54540CEE33098BFCE454069E21DE049F54540758E01D9EBCF45400DDFC2BAF1F64540758E01D9EBCF45400DDFC2BAF1F64540CEE33098BFCE454069E21DE049F54540CEE33098BFCE4540
61526	57850	43.896248	43.925192000000003	43.365763000000001	43.337744999999998	Шортанова	0103000020E610000001000000050000007E8D2441B8F245409AB1683A3BAB45407E8D2441B8F245401E8B6D52D1AE4540AB4203B16CF645401E8B6D52D1AE4540AB4203B16CF645409AB1683A3BAB45407E8D2441B8F245409AB1683A3BAB4540
62466	32651	43.162593999999999	43.186013000000003	43.948258000000003	43.943019999999997	Школьный	0103000020E610000001000000050000004E4354E1CF944540A9BC1DE1B4F845404E4354E1CF944540CF15A58460F94540C0D02346CF974540CF15A58460F94540C0D02346CF974540A9BC1DE1B4F845404E4354E1CF944540A9BC1DE1B4F84540
62476	57960	43.077407000000001	43.130605000000003	43.886192000000001	43.870071000000003	Ленина	0103000020E61000000100000005000000A1BDFA78E889454059198D7C5EEF4540A1BDFA78E889454009FD4CBD6EF14540D8D825AAB790454009FD4CBD6EF14540D8D825AAB790454059198D7C5EEF4540A1BDFA78E889454059198D7C5EEF4540
62410	32800	42.908811	42.954005000000002	43.733823999999998	43.723668000000004	Ленина	0103000020E610000001000000050000005E9F39EB53744540B4942C27A1DC45405E9F39EB537445408C82E0F1EDDD4540399CF9D51C7A45408C82E0F1EDDD4540399CF9D51C7A4540B4942C27A1DC45405E9F39EB53744540B4942C27A1DC4540
62551	32788	43.139606000000001	43.155192	43.810141999999999	43.793576999999999	Школьная	0103000020E61000000100000005000000A629029CDE914540CCED5EEE93E54540A629029CDE914540DA8EA9BBB2E74540E84CDA54DD934540DA8EA9BBB2E74540E84CDA54DD934540CCED5EEE93E54540A629029CDE914540CCED5EEE93E54540
62471	57957	42.404766000000002	43.418999999999997	43.960296	43.345796	Школьная	0103000020E6100000010000000500000031444E5FCF334540378B170B43AC454031444E5FCF334540643DB5FAEAFA45401283C0CAA1B54540643DB5FAEAFA45401283C0CAA1B54540378B170B43AC454031444E5FCF334540378B170B43AC4540
61364	52314	43.159432000000002	43.215676000000002	43.901522999999997	43.885789000000003	Октябрьская	0103000020E61000000100000005000000CBF78C44689445400A14B18861F14540CBF78C4468944540C0CB0C1B65F345401C446B459B9B4540C0CB0C1B65F345401C446B459B9B45400A14B18861F14540CBF78C44689445400A14B18861F14540
61366	32710	43.156674000000002	43.240684999999999	43.755822999999999	43.721434000000002	Ленина	0103000020E610000001000000050000001711C5E40D9445407A1C06F357DC45401711C5E40D9445404548DDCEBEE04540A2D11DC4CE9E45404548DDCEBEE04540A2D11DC4CE9E45407A1C06F357DC45401711C5E40D9445407A1C06F357DC4540
62475	57959	43.223562999999999	43.266817000000003	43.866757	43.853529000000002	Ленина	0103000020E610000001000000050000003ECC5EB69D9C45400398327040ED45403ECC5EB69D9C45401F4AB4E4F1EE45402882380F27A245401F4AB4E4F1EE45402882380F27A245400398327040ED45403ECC5EB69D9C45400398327040ED4540
62489	32730	43.290953999999999	43.318479000000004	43.813225000000003	43.790154000000001	Буденного	0103000020E61000000100000005000000F8510DFB3DA54540DC662AC423E54540F8510DFB3DA5454012A5BDC117E845403DBB7CEBC3A8454012A5BDC117E845403DBB7CEBC3A84540DC662AC423E54540F8510DFB3DA54540DC662AC423E54540
62509	57971	43.137019000000002	43.167661000000003	43.896470000000001	43.887712999999998	 50 Лет Октября	0103000020E610000001000000050000001FF7ADD689914540F59D5F94A0F145401FF7ADD6899145402DEC6987BFF2454047E867EA759545402DEC6987BFF2454047E867EA75954540F59D5F94A0F145401FF7ADD689914540F59D5F94A0F14540
61365	52335	43.281567000000003	43.363169999999997	43.823925000000003	43.772854000000002	Ленина	0103000020E61000000100000005000000015130630AA44540994A3FE1ECE24540015130630AA44540ACADD85F76E94540B471C45A7CAE4540ACADD85F76E94540B471C45A7CAE4540994A3FE1ECE24540015130630AA44540994A3FE1ECE24540
61367	52362	42.920228999999999	42.966572999999997	43.802101	43.782330999999999	Чкалова	0103000020E6100000010000000500000057EA5910CA754540D0D2156C23E4454057EA5910CA754540618BDD3EABE645402A1900AAB87B4540618BDD3EABE645402A1900AAB87B4540D0D2156C23E4454057EA5910CA754540D0D2156C23E44540
62399	32726	43.016222999999997	43.086435000000002	43.745260999999999	43.724345999999997	Ленина	0103000020E61000000100000005000000B438639813824540847EA65EB7DC4540B438639813824540FCFD62B664DF4540691D554D108B4540FCFD62B664DF4540691D554D108B4540847EA65EB7DC4540B438639813824540847EA65EB7DC4540
61427	32726	43.016222999999997	43.086435000000002	43.745260999999999	43.724345999999997	Кумыкова	0103000020E61000000100000005000000B438639813824540847EA65EB7DC4540B438639813824540FCFD62B664DF4540691D554D108B4540FCFD62B664DF4540691D554D108B4540847EA65EB7DC4540B438639813824540847EA65EB7DC4540
61428	32726	43.016222999999997	43.086435000000002	43.745260999999999	43.724345999999997	Куважукова	0103000020E61000000100000005000000B438639813824540847EA65EB7DC4540B438639813824540FCFD62B664DF4540691D554D108B4540FCFD62B664DF4540691D554D108B4540847EA65EB7DC4540B438639813824540847EA65EB7DC4540
62483	32708	43.187846	43.216385000000002	43.849361999999999	43.830779999999997	Советская	0103000020E610000001000000050000009B5775560B984540DF15C1FF56EA45409B5775560B9845408A3BDEE4B7EC4540282CF180B29B45408A3BDEE4B7EC4540282CF180B29B4540DF15C1FF56EA45409B5775560B984540DF15C1FF56EA4540
62413	57849	43.202668000000003	43.233831000000002	43.907674	43.893442	Пятигорская	0103000020E610000001000000050000000EF96706F1994540B96FB54E5CF245400EF96706F1994540FAB660A92EF445403FE5982CEE9D4540FAB660A92EF445403FE5982CEE9D4540B96FB54E5CF245400EF96706F1994540B96FB54E5CF24540
62408	57849	43.202668000000003	43.233831000000002	43.907674	43.893442	Комсомольская	0103000020E610000001000000050000000EF96706F1994540B96FB54E5CF245400EF96706F1994540FAB660A92EF445403FE5982CEE9D4540FAB660A92EF445403FE5982CEE9D4540B96FB54E5CF245400EF96706F1994540B96FB54E5CF24540
61525	57849	43.202668000000003	43.233831000000002	43.907674	43.893442	Кавказская	0103000020E610000001000000050000000EF96706F1994540B96FB54E5CF245400EF96706F1994540FAB660A92EF445403FE5982CEE9D4540FAB660A92EF445403FE5982CEE9D4540B96FB54E5CF245400EF96706F1994540B96FB54E5CF24540
61420	52324	43.133893	43.173931000000003	43.839838	43.820737999999999	Школьная	0103000020E61000000100000005000000E814E46723914540CF4A5AF10DE94540E814E4672391454012F8C3CF7FEB45405B61FA5E4396454012F8C3CF7FEB45405B61FA5E43964540CF4A5AF10DE94540E814E46723914540CF4A5AF10DE94540
62542	52319	43.104661999999998	43.118828000000001	43.829245	43.818292	Центральная	0103000020E6100000010000000500000025917D90658D45400A4AD1CABDE8454025917D90658D45408EAF3DB324EA4540AFEC82C1358F45408EAF3DB324EA4540AFEC82C1358F45400A4AD1CABDE8454025917D90658D45400A4AD1CABDE84540
9625	40234	43.010482000000003	43.034602	43.885931999999997	43.877693999999998	Центральная	0103000020E610000001000000050000002D996379578145409DF2E84658F045402D996379578145406C3D433866F1454027309DD66D8445406C3D433866F1454027309DD66D8445409DF2E84658F045402D996379578145409DF2E84658F04540
62533	32748	43.519494999999999	43.529673000000003	43.720723999999997	43.712806999999998	Ленина	0103000020E61000000100000005000000BFB7E9CF7EC2454010AE80423DDB4540BFB7E9CF7EC245409DB81CAF40DC454080492A53CCC345409DB81CAF40DC454080492A53CCC3454010AE80423DDB4540BFB7E9CF7EC2454010AE80423DDB4540
61435	32740	43.539878000000002	43.597324999999998	43.843263999999998	43.830669	Катханова	0103000020E610000001000000050000003AEAE8B81AC5454088669E5C53EA45403AEAE8B81AC5454073F22213F0EB4540A60A462575CC454073F22213F0EB4540A60A462575CC454088669E5C53EA45403AEAE8B81AC5454088669E5C53EA4540
62343	52275	43.305157000000001	43.386868	43.777521	43.701475000000002	Октябрьская	0103000020E610000001000000050000009F9273620FA7454016FBCBEEC9D945409F9273620FA74540037AE1CE85E3454039EFFFE384B14540037AE1CE85E3454039EFFFE384B1454016FBCBEEC9D945409F9273620FA7454016FBCBEEC9D94540
62522	32588	43.198059999999998	43.225234	43.563423	43.545547999999997	Мира	0103000020E61000000100000005000000A852B3075A994540F8325184D4C54540A852B3075A9945403868AF3E1EC8454040F9BB77D49C45403868AF3E1EC8454040F9BB77D49C4540F8325184D4C54540A852B3075A994540F8325184D4C54540
62474	32700	43.414706000000002	43.468848000000001	43.786028000000002	43.767691999999997	Советская	0103000020E610000001000000050000003DBA111615B545404EB340BB43E245403DBA111615B54540C2DEC4909CE44540C365153603BC4540C2DEC4909CE44540C365153603BC45404EB340BB43E245403DBA111615B545404EB340BB43E24540
61473	32759	43.427247000000001	43.480454000000002	43.864500999999997	43.853341	Комсомольская	0103000020E6100000010000000500000035289A07B0B6454000AB23473AED454035289A07B0B64540FD2D01F8A7EE4540BF9D44847FBD4540FD2D01F8A7EE4540BF9D44847FBD454000AB23473AED454035289A07B0B6454000AB23473AED4540
61357	52293	43.618875000000003	43.674759999999999	43.802171999999999	43.781986000000003	Садовая	0103000020E61000000100000005000000F0A7C64B37CF454006F7031E18E44540F0A7C64B37CF45402AE27492ADE64540115322895ED645402AE27492ADE64540115322895ED6454006F7031E18E44540F0A7C64B37CF454006F7031E18E44540
61358	32705	43.618121000000002	43.673394000000002	43.653520999999998	43.642184	Школьная	0103000020E6100000010000000500000044FCC3961ECF4540DA01D71533D2454044FCC3961ECF4540E61F7D93A6D345404CA94BC631D64540E61F7D93A6D345404CA94BC631D64540DA01D71533D2454044FCC3961ECF4540DA01D71533D24540
62419	52250	43.408436000000002	43.493453000000002	43.683464999999998	43.660753999999997	переулок Алихбердова	0103000020E6100000010000000500000029417FA147B44540C0594A9693D4454029417FA147B44540F67AF7C77BD745407A8EC87729BF4540F67AF7C77BD745407A8EC87729BF4540C0594A9693D4454029417FA147B44540C0594A9693D44540
61425	52250	43.408436000000002	43.493453000000002	43.683464999999998	43.660753999999997	Эльбрусская	0103000020E6100000010000000500000029417FA147B44540C0594A9693D4454029417FA147B44540F67AF7C77BD745407A8EC87729BF4540F67AF7C77BD745407A8EC87729BF4540C0594A9693D4454029417FA147B44540C0594A9693D44540
61433	52250	43.408436000000002	43.493453000000002	43.683464999999998	43.660753999999997	Надречная	0103000020E6100000010000000500000029417FA147B44540C0594A9693D4454029417FA147B44540F67AF7C77BD745407A8EC87729BF4540F67AF7C77BD745407A8EC87729BF4540C0594A9693D4454029417FA147B44540C0594A9693D44540
61352	52257	43.262891000000003	43.377488999999997	43.641095	43.597734000000003	Кирова	0103000020E61000000100000005000000D5B48B69A6A1454088DA368C82CC4540D5B48B69A6A145408750A5660FD24540C4CC3E8F51B045408750A5660FD24540C4CC3E8F51B0454088DA368C82CC4540D5B48B69A6A1454088DA368C82CC4540
61468	52257	43.262891000000003	43.377488999999997	43.641095	43.597734000000003	Казаноко	0103000020E61000000100000005000000D5B48B69A6A1454088DA368C82CC4540D5B48B69A6A145408750A5660FD24540C4CC3E8F51B045408750A5660FD24540C4CC3E8F51B0454088DA368C82CC4540D5B48B69A6A1454088DA368C82CC4540
62338	52257	43.262891000000003	43.377488999999997	43.641095	43.597734000000003	Дикинова	0103000020E61000000100000005000000D5B48B69A6A1454088DA368C82CC4540D5B48B69A6A145408750A5660FD24540C4CC3E8F51B045408750A5660FD24540C4CC3E8F51B0454088DA368C82CC4540D5B48B69A6A1454088DA368C82CC4540
62514	32681	43.198751000000001	43.224192000000002	43.571882000000002	43.553486999999997	Пролетарская	0103000020E610000001000000050000000E863AAC709945406DE179A9D8C645400E863AAC70994540E695EB6D33C945402E03CE52B29C4540E695EB6D33C945402E03CE52B29C45406DE179A9D8C645400E863AAC709945406DE179A9D8C64540
62498	33139	43.24868	43.309370000000001	43.708655999999998	43.676737000000003	Октябрьская	0103000020E61000000100000005000000AB9509BFD49F4540207F69519FD64540AB9509BFD49F45409D0E643DB5DA4540882EA86F99A745409D0E643DB5DA4540882EA86F99A74540207F69519FD64540AB9509BFD49F4540207F69519FD64540
62438	52263	43.624589	43.685476999999999	43.691977999999999	43.677415000000003	Березгова	0103000020E610000001000000050000007E384888F2CF4540F168E388B5D645407E384888F2CF454097C62FBC92D845408194D8B5BDD7454097C62FBC92D845408194D8B5BDD74540F168E388B5D645407E384888F2CF4540F168E388B5D64540
62420	52263	43.624589	43.685476999999999	43.691977999999999	43.677415000000003	Баксанская	0103000020E610000001000000050000007E384888F2CF4540F168E388B5D645407E384888F2CF454097C62FBC92D845408194D8B5BDD7454097C62FBC92D845408194D8B5BDD74540F168E388B5D645407E384888F2CF4540F168E388B5D64540
62334	52263	43.624589	43.685476999999999	43.691977999999999	43.677415000000003	Ахметова	0103000020E610000001000000050000007E384888F2CF4540F168E388B5D645407E384888F2CF454097C62FBC92D845408194D8B5BDD7454097C62FBC92D845408194D8B5BDD74540F168E388B5D645407E384888F2CF4540F168E388B5D64540
61362	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Угнич	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62341	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Р.Калмыкова	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
61445	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Панаиоти	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
61444	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Николаева	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62329	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Ленина	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
61477	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Иванова переулок	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62336	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Бесланеева	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62460	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Баксанова	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
61450	3280	43.500145000000003	43.583590000000001	43.698945999999999	43.672302999999999	Апанасова	0103000020E61000000100000005000000042159C004C04540580053060ED64540042159C004C04540C3D5011077D94540E622BE13B3CA4540C3D5011077D94540E622BE13B3CA4540580053060ED64540042159C004C04540580053060ED64540
62445	52269	43.379258999999998	43.418847999999997	43.659678	43.629787999999998	Катанчиева	0103000020E6100000010000000500000059DB148F8BB04540E5B4A7E49CD0454059DB148F8BB0454002F2255470D445405CFFAECF9CB5454002F2255470D445405CFFAECF9CB54540E5B4A7E49CD0454059DB148F8BB04540E5B4A7E49CD04540
61354	52269	43.379258999999998	43.418847999999997	43.659678	43.629787999999998	Апшева	0103000020E6100000010000000500000059DB148F8BB04540E5B4A7E49CD0454059DB148F8BB0454002F2255470D445405CFFAECF9CB5454002F2255470D445405CFFAECF9CB54540E5B4A7E49CD0454059DB148F8BB04540E5B4A7E49CD04540
60950	57730	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Осканова 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60961	57730	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Обороны Кавказа	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60859	57730	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Нурадилова 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60905	57730	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Калинина 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60913	57730	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Гоголя 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60858	57730	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Гарданова 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60964	52961	45.112855000000003	45.137262	43.194693999999998	43.170430000000003	Широкая	0103000020E6100000010000000500000055185B08728E4640EF2076A6D095454055185B08728E46401C5DA5BBEB984540E57D1CCD919146401C5DA5BBEB984540E57D1CCD91914640EF2076A6D095454055185B08728E4640EF2076A6D0954540
60958	52932	44.950879	45.023876000000001	43.320019000000002	43.291822000000003	Шоссейная	0103000020E6100000010000000500000002BA2F67B67946406D205D6C5AA5454002BA2F67B6794640A08CF161F6A845406494675E0E834640A08CF161F6A845406494675E0E8346406D205D6C5AA5454002BA2F67B67946406D205D6C5AA54540
60923	52932	44.950879	45.023876000000001	43.320019000000002	43.291822000000003	Ленина	0103000020E6100000010000000500000002BA2F67B67946406D205D6C5AA5454002BA2F67B6794640A08CF161F6A845406494675E0E834640A08CF161F6A845406494675E0E8346406D205D6C5AA5454002BA2F67B67946406D205D6C5AA54540
60924	52932	44.950879	45.023876000000001	43.320019000000002	43.291822000000003	Колхозная	0103000020E6100000010000000500000002BA2F67B67946406D205D6C5AA5454002BA2F67B6794640A08CF161F6A845406494675E0E834640A08CF161F6A845406494675E0E8346406D205D6C5AA5454002BA2F67B67946406D205D6C5AA54540
60902	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Энгельса	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60973	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Шерипова	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60932	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Трудовая	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60916	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Рабочая	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60945	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Осканова	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60988	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Новая Кирова	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60927	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Мира	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60885	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Менделеева	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60895	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Ленина	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60922	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Демченко	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60983	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Грозненская	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60933	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	Висаитова	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60886	57736	45.024127999999997	45.110267	43.338827000000002	43.292878999999999	 Ленина	0103000020E610000001000000050000007D7555A016834640B4571F0F7DA545407D7555A0168346403B00E2AE5EAB4540FD69A33A1D8E46403B00E2AE5EAB4540FD69A33A1D8E4640B4571F0F7DA545407D7555A016834640B4571F0F7DA54540
60908	52940	45.022080000000003	45.071595000000002	43.250309999999999	43.218631999999999	 Шоссейная	0103000020E61000000100000005000000A6F27684D3824640F6ED2422FC9B4540A6F27684D38246404EEE77280AA0454050C763062A8946404EEE77280AA0454050C763062A894640F6ED2422FC9B4540A6F27684D3824640F6ED2422FC9B4540
60909	5003	44.875923999999998	44.942588000000001	43.317244000000002	43.293981000000002	Фрунзе	0103000020E6100000010000000500000008E412471E7046409C525E2BA1A5454008E412471E704640166D8E739BA8454010CD3CB9A6784640166D8E739BA8454010CD3CB9A67846409C525E2BA1A5454008E412471E7046409C525E2BA1A54540
60877	5003	44.875923999999998	44.942588000000001	43.317244000000002	43.293981000000002	Осканова	0103000020E6100000010000000500000008E412471E7046409C525E2BA1A5454008E412471E704640166D8E739BA8454010CD3CB9A6784640166D8E739BA8454010CD3CB9A67846409C525E2BA1A5454008E412471E7046409C525E2BA1A54540
60872	5003	44.875923999999998	44.942588000000001	43.317244000000002	43.293981000000002	Джабагиева	0103000020E6100000010000000500000008E412471E7046409C525E2BA1A5454008E412471E704640166D8E739BA8454010CD3CB9A6784640166D8E739BA8454010CD3CB9A67846409C525E2BA1A5454008E412471E7046409C525E2BA1A54540
60952	57740	45.092013999999999	45.107447000000001	43.033678000000002	43.027009	Кавказская	0103000020E610000001000000050000001763601DC78B46404DD9E907758345401763601DC78B46401F4C8A8F4F844540D386C3D2C08D46401F4C8A8F4F844540D386C3D2C08D46404DD9E907758345401763601DC78B46404DD9E90775834540
60947	32554	44.975251	44.995409000000002	43.125498999999998	43.066270000000003	Шоссейная	0103000020E6100000010000000500000016325706D57C46405C5A0D897B88454016325706D57C46402157EA59109045407192E68F697F46402157EA59109045407192E68F697F46405C5A0D897B88454016325706D57C46405C5A0D897B884540
60906	32554	44.975251	44.995409000000002	43.125498999999998	43.066270000000003	Школьная	0103000020E6100000010000000500000016325706D57C46405C5A0D897B88454016325706D57C46402157EA59109045407192E68F697F46402157EA59109045407192E68F697F46405C5A0D897B88454016325706D57C46405C5A0D897B884540
60953	32554	44.975251	44.995409000000002	43.125498999999998	43.066270000000003	 Исламская	0103000020E6100000010000000500000016325706D57C46405C5A0D897B88454016325706D57C46402157EA59109045407192E68F697F46402157EA59109045407192E68F697F46405C5A0D897B88454016325706D57C46405C5A0D897B884540
60962	52956	45.017409000000001	45.026688	42.972335000000001	42.961911999999998	Мира	0103000020E61000000100000005000000FAD346753A824640A2D0B2EE1F7B4540FAD346753A824640CAE02879757C45400B992B836A834640CAE02879757C45400B992B836A834640A2D0B2EE1F7B4540FAD346753A824640A2D0B2EE1F7B4540
60976	57743	44.833694000000001	45.277524999999997	43.521791	42.823905000000003	6-Линия	0103000020E610000001000000050000008B6F287CB66A4640650113B8756945408B6F287CB66A46406F2C280CCAC2454044696FF085A346406F2C280CCAC2454044696FF085A34640650113B8756945408B6F287CB66A4640650113B875694540
60867	57733	44.896388000000002	44.933999999999997	43.289768000000002	43.252845000000001	Орджоникидзе	0103000020E6100000010000000500000070438CD7BC72464083FA96395DA0454070438CD7BC724640B3B6291E17A54540643BDF4F8D774640B3B6291E17A54540643BDF4F8D77464083FA96395DA0454070438CD7BC72464083FA96395DA04540
60912	57733	44.896388000000002	44.933999999999997	43.289768000000002	43.252845000000001	Мальсагова	0103000020E6100000010000000500000070438CD7BC72464083FA96395DA0454070438CD7BC724640B3B6291E17A54540643BDF4F8D774640B3B6291E17A54540643BDF4F8D77464083FA96395DA0454070438CD7BC72464083FA96395DA04540
60864	9289	44.806502000000002	44.836973	43.223067	43.188009000000001	Осканова	0103000020E610000001000000050000004D1421753B674640452DCDAD109845404D1421753B6746408EE89E758D9C4540485167EE216B46408EE89E758D9C4540485167EE216B4640452DCDAD109845404D1421753B674640452DCDAD10984540
60869	9289	44.806502000000002	44.836973	43.223067	43.188009000000001	Ингушская	0103000020E610000001000000050000004D1421753B674640452DCDAD109845404D1421753B6746408EE89E758D9C4540485167EE216B46408EE89E758D9C4540485167EE216B4640452DCDAD109845404D1421753B674640452DCDAD10984540
60981	9289	44.806502000000002	44.836973	43.223067	43.188009000000001	Бекова	0103000020E610000001000000050000004D1421753B674640452DCDAD109845404D1421753B6746408EE89E758D9C4540485167EE216B46408EE89E758D9C4540485167EE216B4640452DCDAD109845404D1421753B674640452DCDAD10984540
60929	32980	44.884816999999998	44.928106999999997	43.201338	43.168469999999999	Школьная	0103000020E61000000100000005000000F0F8F6AE41714640B62DCA6C90954540F0F8F6AE4171464095B88E71C59945402618CE35CC76464095B88E71C59945402618CE35CC764640B62DCA6C90954540F0F8F6AE41714640B62DCA6C90954540
60934	32980	44.884816999999998	44.928106999999997	43.201338	43.168469999999999	Т.Аушева	0103000020E61000000100000005000000F0F8F6AE41714640B62DCA6C90954540F0F8F6AE4171464095B88E71C59945402618CE35CC76464095B88E71C59945402618CE35CC764640B62DCA6C90954540F0F8F6AE41714640B62DCA6C90954540
60926	52894	44.816411000000002	44.859997	43.295181999999997	43.265667000000001	Осканова	0103000020E610000001000000050000001E8CD827806846402F50526001A245401E8CD82780684640162F1686C8A545403DD4B661146E4640162F1686C8A545403DD4B661146E46402F50526001A245401E8CD827806846402F50526001A24540
61057	52651	44.753788999999998	44.760212000000003	42.803865000000002	42.795391000000002	Путина	0103000020E61000000100000005000000D28A6F287C60464031444E5FCF654540D28A6F287C60464014B35E0CE56645406D0377A04E61464014B35E0CE56645406D0377A04E61464031444E5FCF654540D28A6F287C60464031444E5FCF654540
60893	57731	44.795712999999999	44.815243000000002	43.221943000000003	43.190900999999997	Почтовая	0103000020E61000000100000005000000430070ECD965464008E3A7716F984540430070ECD9654640BF49D3A0689C45407FA5F3E159684640BF49D3A0689C45407FA5F3E15968464008E3A7716F984540430070ECD965464008E3A7716F984540
60897	57731	44.795712999999999	44.815243000000002	43.221943000000003	43.190900999999997	Партизанская	0103000020E61000000100000005000000430070ECD965464008E3A7716F984540430070ECD9654640BF49D3A0689C45407FA5F3E159684640BF49D3A0689C45407FA5F3E15968464008E3A7716F984540430070ECD965464008E3A7716F984540
60861	57731	44.795712999999999	44.815243000000002	43.221943000000003	43.190900999999997	Муталиева	0103000020E61000000100000005000000430070ECD965464008E3A7716F984540430070ECD9654640BF49D3A0689C45407FA5F3E159684640BF49D3A0689C45407FA5F3E15968464008E3A7716F984540430070ECD965464008E3A7716F984540
60868	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Эсмурзиева	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60889	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Школьная	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60875	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Фабричная	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60873	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Т.Аушева	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60888	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Суворова	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60876	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Осканова	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60862	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Муталиева	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60874	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Московская	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60910	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Коммунальная	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60896	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Картоева	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60898	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Кавказская	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60863	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Ингушская	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60904	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Зязикова	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60879	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Джабагиева	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60878	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Дахкильгова	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60894	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Базоркино	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60871	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Базоркина	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60887	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	Албогачиева	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60918	7390	44.748345	44.789174000000003	43.241549999999997	43.203960000000002	 Осканова	0103000020E610000001000000050000000490DAC4C95F464099D87C5C1B9A45400490DAC4C95F4640A52C431CEB9E4540406D54A703654640A52C431CEB9E4540406D54A70365464099D87C5C1B9A45400490DAC4C95F464099D87C5C1B9A4540
60957	5358	44.810527	44.822806999999997	43.177549999999997	43.168595000000003	Зязикова	0103000020E6100000010000000500000033C34659BF67464073A25D859495454033C34659BF674640D0B359F5B9964540BEF561BD51694640D0B359F5B9964540BEF561BD5169464073A25D859495454033C34659BF67464073A25D8594954540
60856	5358	44.810527	44.822806999999997	43.177549999999997	43.168595000000003	А.Бокова	0103000020E6100000010000000500000033C34659BF67464073A25D859495454033C34659BF674640D0B359F5B9964540BEF561BD51694640D0B359F5B9964540BEF561BD5169464073A25D859495454033C34659BF67464073A25D8594954540
60967	52647	44.726112000000001	44.739469999999997	42.810771000000003	42.806061	Точиева	0103000020E61000000100000005000000D89DEE3CF15C464060CAC0012D674540D89DEE3CF15C4640CAC51858C7674540C22FF5F3A65E4640CAC51858C7674540C22FF5F3A65E464060CAC0012D674540D89DEE3CF15C464060CAC0012D674540
60935	52857	44.597464000000002	44.678142000000001	43.242483	43.210807000000003	Школьная	0103000020E61000000100000005000000C8444AB3794C46404A6249B9FB9A4540C8444AB3794C4640016BD5AE099F4540A305685BCD564640016BD5AE099F4540A305685BCD5646404A6249B9FB9A4540C8444AB3794C46404A6249B9FB9A4540
61006	52857	44.597464000000002	44.678142000000001	43.242483	43.210807000000003	Шерипова	0103000020E61000000100000005000000C8444AB3794C46404A6249B9FB9A4540C8444AB3794C4640016BD5AE099F4540A305685BCD564640016BD5AE099F4540A305685BCD5646404A6249B9FB9A4540C8444AB3794C46404A6249B9FB9A4540
60928	52857	44.597464000000002	44.678142000000001	43.242483	43.210807000000003	Дзаурова	0103000020E61000000100000005000000C8444AB3794C46404A6249B9FB9A4540C8444AB3794C4640016BD5AE099F4540A305685BCD564640016BD5AE099F4540A305685BCD5646404A6249B9FB9A4540C8444AB3794C46404A6249B9FB9A4540
60949	33110	44.791339000000001	44.805765000000001	42.813462000000001	42.808072000000003	Укурова	0103000020E610000001000000050000005186AA984A6546401B683EE76E6745405186AA984A654640F644D7851F68454077A1B94E23674640F644D7851F68454077A1B94E236746401B683EE76E6745405186AA984A6546401B683EE76E674540
60907	57737	44.767425000000003	44.817523999999999	43.254945999999997	43.197014000000003	Албогачиева	0103000020E6100000010000000500000000917EFB3A624640556D37C13799454000917EFB3A6246407D1F0E12A2A04540F9D85DA0A46846407D1F0E12A2A04540F9D85DA0A4684640556D37C13799454000917EFB3A624640556D37C137994540
75500	60643	44.590403000000002	44.601515999999997	43.403042999999997	43.397455000000001	Центральная	0103000020E61000000100000005000000EB3A5453924B4640DB5031CEDFB24540EB3A5453924B4640DCF0BBE996B34540A702EE79FE4C4640DCF0BBE996B34540A702EE79FE4C4640DB5031CEDFB24540EB3A5453924B4640DB5031CEDFB24540
60955	32968	44.830469000000001	44.848731999999998	43.266756999999998	43.253613000000001	Школьная	0103000020E61000000100000005000000C1ABE5CE4C6A4640946B0A6476A04540C1ABE5CE4C6A4640527DE71725A24540CA880B40A36C4640527DE71725A24540CA880B40A36C4640946B0A6476A04540C1ABE5CE4C6A4640946B0A6476A04540
60960	52649	44.712879999999998	44.721215999999998	42.837062000000003	42.831316999999999	Центральная	0103000020E610000001000000050000007AFCDEA63F5B4640EECD6F98686A45407AFCDEA63F5B4640B85CFDD8246B45400CAD4ECE505C4640B85CFDD8246B45400CAD4ECE505C4640EECD6F98686A45407AFCDEA63F5B4640EECD6F98686A4540
60943	33062	44.794500999999997	44.827145000000002	43.272258000000001	43.250317000000003	Левобережная	0103000020E61000000100000005000000D4D17135B2654640015130630AA04540D4D17135B26546408509A359D9A2454064062AE3DF6946408509A359D9A2454064062AE3DF694640015130630AA04540D4D17135B2654640015130630AA04540
60940	57739	44.763635000000001	44.797142000000001	43.245885000000001	43.227291000000001	Школьная	0103000020E610000001000000050000005D8AABCABE6146406BD619DF179D45405D8AABCABE614640DAC9E028799F45404F22C2BF08664640DAC9E028799F45404F22C2BF086646406BD619DF179D45405D8AABCABE6146406BD619DF179D4540
60925	52853	44.84442	44.863500000000002	43.152766	43.130775999999997	Ахриева	0103000020E610000001000000050000004E0B5EF4156C4640048D9944BD9045404E0B5EF4156C46406AF816D68D9345404A0C022B876E46406AF816D68D9345404A0C022B876E4640048D9944BD9045404E0B5EF4156C4640048D9944BD904540
60968	52761	44.720677000000002	44.752882	43.523439000000003	43.511037000000002	Базоркина	0103000020E610000001000000050000005DFDD8243F5C4640E20511A969C145405DFDD8243F5C4640B939950C00C34540A0DFF76F5E604640B939950C00C34540A0DFF76F5E604640E20511A969C145405DFDD8243F5C4640E20511A969C14540
60941	32767	44.724603000000002	44.743099000000001	43.378017	43.361784	Школьная	0103000020E61000000100000005000000B0CA85CABF5C4640A81B28F04EAE4540B0CA85CABF5C4640802A6EDC62B045405C5837DE1D5F4640802A6EDC62B045405C5837DE1D5F4640A81B28F04EAE4540B0CA85CABF5C4640A81B28F04EAE4540
60901	32767	44.724603000000002	44.743099000000001	43.378017	43.361784	Рабочая	0103000020E61000000100000005000000B0CA85CABF5C4640A81B28F04EAE4540B0CA85CABF5C4640802A6EDC62B045405C5837DE1D5F4640802A6EDC62B045405C5837DE1D5F4640A81B28F04EAE4540B0CA85CABF5C4640A81B28F04EAE4540
60911	52734	44.577423000000003	44.607579000000001	43.494677000000003	43.470913000000003	Школьная	0103000020E61000000100000005000000A77A32FFE849464071218FE046BC4540A77A32FFE8494640AD8A709351BF4540425E0F26C54D4640AD8A709351BF4540425E0F26C54D464071218FE046BC4540A77A32FFE849464071218FE046BC4540
60921	52734	44.577423000000003	44.607579000000001	43.494677000000003	43.470913000000003	Гарданова	0103000020E61000000100000005000000A77A32FFE849464071218FE046BC4540A77A32FFE8494640AD8A709351BF4540425E0F26C54D4640AD8A709351BF4540425E0F26C54D464071218FE046BC4540A77A32FFE849464071218FE046BC4540
60951	52742	44.557633000000003	44.582346000000001	43.480823999999998	43.452204999999999	Фрунзе	0103000020E61000000100000005000000CF15A58460474640390B7BDAE1B94540CF15A58460474640E2900DA48BBD45406C7A50508A4A4640E2900DA48BBD45406C7A50508A4A4640390B7BDAE1B94540CF15A58460474640390B7BDAE1B94540
60915	52766	44.796872	44.822141999999999	43.479953999999999	43.463355999999997	Шоссейная	0103000020E610000001000000050000008F8CD5E6FF654640E333D93F4FBB45408F8CD5E6FF654640CDCAF6216FBD45408255F5F23B694640CDCAF6216FBD45408255F5F23B694640E333D93F4FBB45408F8CD5E6FF654640E333D93F4FBB4540
60899	52767	44.747914000000002	44.773408000000003	43.415899000000003	43.386063	Шоссейная	0103000020E610000001000000050000003B1C5DA5BB5F46400B992B836AB145403B1C5DA5BB5F464035B8AD2D3CB545407E3B8908FF62464035B8AD2D3CB545407E3B8908FF6246400B992B836AB145403B1C5DA5BB5F46400B992B836AB14540
60900	52767	44.747914000000002	44.773408000000003	43.415899000000003	43.386063	Кооперативная	0103000020E610000001000000050000003B1C5DA5BB5F46400B992B836AB145403B1C5DA5BB5F464035B8AD2D3CB545407E3B8908FF62464035B8AD2D3CB545407E3B8908FF6246400B992B836AB145403B1C5DA5BB5F46400B992B836AB14540
60939	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	пер.Осканова	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60936	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Эсамбаева	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60920	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Шоссейная	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60855	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Школьная	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60890	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Укурова	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60954	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Пушкина	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60903	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Орджоникидзе 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60930	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Оздоева	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60866	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Нурадилова	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60974	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Молодежная	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60882	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Кавказская	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60881	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Кабардинская	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60931	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Железнодорожная	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60884	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Горданова 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60944	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Гарданова 	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60942	5401	44.566822999999999	44.611333999999999	43.520778	43.494860000000003	Вокзальная	0103000020E6100000010000000500000070CFF3A78D4846409E0C8E9257BF454070CFF3A78D484640F73C7FDAA8C2454068774831404E4640F73C7FDAA8C2454068774831404E46409E0C8E9257BF454070CFF3A78D4846409E0C8E9257BF4540
60966	52751	44.525509	44.557884000000001	43.480654000000001	43.460856	Укурова	0103000020E61000000100000005000000786000E1434346402B155454FDBA4540786000E1434346408658FD1186BD4540187B2FBE684746408658FD1186BD4540187B2FBE684746402B155454FDBA4540786000E1434346402B155454FDBA4540
60917	52777	44.676901999999998	44.727027999999997	43.361634000000002	43.329009999999997	Чапанова	0103000020E610000001000000050000006A4C88B9A45646404A07EBFF1CAA45406A4C88B9A4564640938FDD054AAE45405DA3E5400F5D4640938FDD054AAE45405DA3E5400F5D46404A07EBFF1CAA45406A4C88B9A45646404A07EBFF1CAA4540
60956	52785	44.565682000000002	44.583010000000002	43.602148	43.592967999999999	Советская	0103000020E61000000100000005000000CBF78C44684846408AC91B60E6CB4540CBF78C446848464008AD872F13CD4540D89E5912A04A464008AD872F13CD4540D89E5912A04A46408AC91B60E6CB4540CBF78C44684846408AC91B60E6CB4540
61132	57762	44.665664	44.690672999999997	42.828884000000002	42.816603999999998	Льянова	0103000020E61000000100000005000000F10F5B7A3455464032E4D87A86684540F10F5B7A34554640BE16F4DE186A4540779D0DF967584640BE16F4DE186A4540779D0DF96758464032E4D87A86684540F10F5B7A3455464032E4D87A86684540
60971	57742	44.477305000000001	45.293892	43.615417999999998	42.614910999999999	Льянова	0103000020E61000000100000005000000D09B8A54183D4640AF795567B54E4540D09B8A54183D464053AF5B04C6CE45402C47C8409EA5464053AF5B04C6CE45402C47C8409EA54640AF795567B54E4540D09B8A54183D4640AF795567B54E4540
33051	16348	45.625523000000001	45.668138999999996	44.676462000000001	44.648836000000003	площадь Имама Шамиля	0103000020E61000000100000005000000AAF23D2311D04640D63BDC0E0D534640AAF23D2311D046404E7E8B4E965646405017299485D546404E7E8B4E965646405017299485D54640D63BDC0E0D534640AAF23D2311D04640D63BDC0E0D534640
32989	16348	45.625523000000001	45.668138999999996	44.676462000000001	44.648836000000003	Комарова	0103000020E61000000100000005000000AAF23D2311D04640D63BDC0E0D534640AAF23D2311D046404E7E8B4E965646405017299485D546404E7E8B4E965646405017299485D54640D63BDC0E0D534640AAF23D2311D04640D63BDC0E0D534640
33091	16348	45.625523000000001	45.668138999999996	44.676462000000001	44.648836000000003	Горького	0103000020E61000000100000005000000AAF23D2311D04640D63BDC0E0D534640AAF23D2311D046404E7E8B4E965646405017299485D546404E7E8B4E965646405017299485D54640D63BDC0E0D534640AAF23D2311D04640D63BDC0E0D534640
33037	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	фабричная	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
32968	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Ярыксувская	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33006	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Хизроева	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33001	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Тотурбиева	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33159	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Стальского	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33049	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Нурадилова	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33161	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Новая	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33089	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Махачкалинское шоссе	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
32962	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Коркмасова	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33136	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Кандуровская	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33050	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Кандауровская	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33073	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Калинина	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33138	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Казбекова	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33114	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Имама Шамиля	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33017	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Заречная проез1	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33113	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Завокзальная	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33158	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Даибова	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33088	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Буйнакская	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33162	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Бригадная	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33077	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Батырмурзаева	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33139	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	Автобусная	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
33140	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	40 лет Октября	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
32967	953	46.548641000000003	46.624251999999998	43.288784	43.217843999999999	 Датуева	0103000020E61000000100000005000000541F48DE394647409ED0EB4FE29B4540541F48DE39464740D5CDC5DFF6A44540363B527DE74F4740D5CDC5DFF6A44540363B527DE74F47409ED0EB4FE29B4540541F48DE394647409ED0EB4FE29B4540
32943	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	проспект Акушинского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33098	6655	47.551808000000001	47.553029000000002	42.899776000000003	42.896177000000002	п.Тарки	0103000020E61000000100000005000000E9D500A5A1C64740B5368DEDB5724540E9D500A5A1C64740E4DC26DC2B734540AB5E7EA7C9C64740E4DC26DC2B734540AB5E7EA7C9C64740B5368DEDB5724540E9D500A5A1C64740B5368DEDB5724540
32937	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	Ярагского	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
32936	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Ярагского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32938	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	ЮСУПОВА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33028	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Энгельса	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33130	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Эмирова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32928	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Школьная	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32999	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Шамиля	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32944	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	ШАМИЛЯ	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33003	6655	47.547406000000002	47.559874000000001	42.909134000000002	42.888792000000002	Хушет	0103000020E610000001000000050000002DD1596611C647402579AEEFC37145402DD1596611C6474041D7BE805E744540BBF083F3A9C7474041D7BE805E744540BBF083F3A9C747402579AEEFC37145402DD1596611C647402579AEEFC3714540
33069	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Хуршилова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33071	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	Хуршилова	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
33148	6655	47.547406000000002	47.559874000000001	42.909134000000002	42.888792000000002	ХУШЕТ	0103000020E610000001000000050000002DD1596611C647402579AEEFC37145402DD1596611C6474041D7BE805E744540BBF083F3A9C7474041D7BE805E744540BBF083F3A9C747402579AEEFC37145402DD1596611C647402579AEEFC3714540
33103	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Танкаева	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33075	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Североосетинская	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33085	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	СТУДЕНЧЕСКИЙ ПЕРЕУЛОК	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33150	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Проспект шамиля	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32994	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Проспект Шамиля	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33121	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Островского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33147	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	О.КОШЕВОГО	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33142	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	НИКОЛАЕВА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32972	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	НАСРУТДИНОВА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32984	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Н-КЯХУЛАЙ	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32909	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Маяковского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33149	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Ляхова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32992	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Ломоносова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32911	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Ленина	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33166	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Левина	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33031	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Лаптиева	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33035	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	ЛАПТИЕВА	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
33033	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	ЛАПТИЕВА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33122	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Л.Чайкиной	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32985	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Коркмасова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33167	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Каммаева	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32970	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Казбекова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33123	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	И.Казака	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33068	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	И-Казака	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33144	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	И-КАЗАКА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33141	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Дзержинского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32986	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Дахадаева	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32932	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	Даниялова	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
33101	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Горького	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33039	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Гамидова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32979	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Гаджиева	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33133	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	Гаджиева	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
32934	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Гагарина	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33108	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	Гагарина	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
33027	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	ГАМИДОВА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33066	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	ГАГАРИНА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33090	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Г.Цадасы	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33014	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Г. Омарова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33025	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Г. Омарова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33164	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Буйнакского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33131	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Бейбулатова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32948	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Батырая	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33048	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Акушинского 1-а 	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32947	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Акушинского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33134	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Айвазовского	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33110	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	Агасиева	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
33100	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	Абубакарова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33067	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	АКАЕВА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32976	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	А-Султана	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33020	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	А-СУЛТАНА	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
32950	6655	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	А-Алиева	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
33046	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	6-магистральная	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33082	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	 Громова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33104	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	 Аскерханова	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33109	6655	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	 А-Султана	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
33087	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Циолковского	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
32974	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Победы	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33061	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Октябрьская	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33060	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Набережная	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33002	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Мичурина	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33076	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Махачкалинская	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33120	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Коммунистическая	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
32963	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Грозненская	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
32966	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Горького	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33074	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Герцена	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33165	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	Багратиона	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
33129	28634	46.671368999999999	46.740278000000004	43.865723000000003	43.826000000000001	40 лет Дагестана	0103000020E610000001000000050000002C465D6BEF5547407D3F355EBAE945402C465D6BEF5547409032E202D0EE454062F9F36DC15E47409032E202D0EE454062F9F36DC15E47407D3F355EBAE945402C465D6BEF5547407D3F355EBAE94540
32945	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Омара Чохского	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
32988	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Молодёжная	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
33026	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Магомедгаджиева	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
33172	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Ленина 	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
33163	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Заводская	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
33119	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Дахадаева	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
32919	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Гамзата Цадаса	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
33059	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Газимагомедова	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
32990	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Гагарина	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
33022	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Вишневского	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
33160	25217	46.842264	46.895211000000003	43.215057999999999	43.183295999999999	Алиева	0103000020E61000000100000005000000904C874ECF6B47406ABE4A3E76974540904C874ECF6B4740205F4205879B45407E02284696724740205F4205879B45407E022846967247406ABE4A3E76974540904C874ECF6B47406ABE4A3E76974540
32915	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Хизроева	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
32949	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	ХАЛИЛОВА	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
32980	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	ТРУДОВАЯ	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33125	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Орджоникидзе	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33012	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	ОРДЖОНИКИДЗЕ	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33070	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	ОКТЯБРЬСКАЯ	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33127	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Назарова	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
32921	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Мира	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33058	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	МАТРОСОВА	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
32917	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Ленина	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33157	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Дахадаева	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
32931	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Гамзатова	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
32935	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	Буйнакского	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33118	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	АЛФЕРОВА	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
32975	18679	47.616010000000003	47.663333000000002	42.896996000000001	42.860453999999997	АБДУЛМАНАПОВА	0103000020E6100000010000000500000026016A6AD9CE47402FDB4E5B236E454026016A6AD9CE47404852D2C3D0724540C5AD8218E8D447404852D2C3D0724540C5AD8218E8D447402FDB4E5B236E454026016A6AD9CE47402FDB4E5B236E4540
33156	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	пр.Ленина	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33064	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	пл.Ленина	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
32991	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Шевченко	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33124	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Свободы	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33044	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Октябрьская	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33063	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Нефтяников	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
32995	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Маяковского	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33065	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Дербентская	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33023	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Гамидова	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
32978	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Буйнакского	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33045	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	Абубакарова	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
32927	15675	47.849716000000001	47.905195999999997	42.591644000000002	42.540095999999998	 Геолога Брода	0103000020E61000000100000005000000A8716F7EC3EC4740A759A0DD21454540A8716F7EC3EC4740F46F97FDBA4B4540293C6876DDF34740F46F97FDBA4B4540293C6876DDF34740A759A0DD21454540A8716F7EC3EC4740A759A0DD21454540
33081	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Шахбазова	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33043	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Х.Тагиева	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33143	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Тахо-Годи	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
32918	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Таги-Заде	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33097	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Советская	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33030	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Свердлова	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33019	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Сальмана	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
32983	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	С.Габиева	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33018	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Приморская	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33021	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Оскара	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33032	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Новокарьерная	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33062	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Маскина	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
32933	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Ленина	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
32926	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Крупской	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
32981	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Красноармейский	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33145	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Гоголя	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33155	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Генриха Гасанова	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33042	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Вокзальная	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
32987	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Буйнакского	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33005	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	345 ДСД	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33029	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	3 Интернационала	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
32941	12017	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	 пл. Свободы	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
12140	41025	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Кирова	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
32907	41025	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	 Аллея Дружбы	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33128	8650	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Революции	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33099	8650	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Некрасова	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33054	8650	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	М.Горького	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33154	8650	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Лермонтова	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33053	8650	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Леваневского переулок	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33055	8650	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Козленко	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33096	8650	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Кирова площадь	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
33000	53419	48.172821999999996	48.225014000000002	42.127032999999997	42.104968	Школьная	0103000020E61000000100000005000000C00303081F164840329067976F0D4540C00303081F164840A2410A9E4210454032923D42CD1C4840A2410A9E4210454032923D42CD1C4840329067976F0D4540C00303081F164840329067976F0D4540
32997	53419	48.203023000000002	48.206895000000003	42.122787000000002	42.121595999999997	М.Гаджиева	0103000020E61000000100000005000000FCAA5CA8FC19484086A92D75900F4540FCAA5CA8FC194840DEAF027CB70F45405C5A0D897B1A4840DEAF027CB70F45405C5A0D897B1A484086A92D75900F4540FCAA5CA8FC19484086A92D75900F4540
33084	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Ярагского	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
32969	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Шамхалова	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33016	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Чкалова	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33011	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Циалковского	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33146	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Хизроева	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33117	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Фрунзе	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33151	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Салаватова	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33126	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Мр. Дружба	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33015	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Ленина	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33040	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Имама Шамиля	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33004	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Имама Газимагомеда	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33008	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Дж. Казикумухского	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33052	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Буйнакского	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
33095	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	Аскерханова	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
32973	2445	47.077443000000002	47.141312999999997	42.838397000000001	42.798560000000002	 Гамзата Цадаса	0103000020E61000000100000005000000EE26F8A6E989474067F2CD3637664540EE26F8A6E98947404208C897506B4540F4BF5C8B169247404208C897506B4540F4BF5C8B1692474067F2CD3637664540EE26F8A6E989474067F2CD3637664540
32965	25739	46.705199	46.715727999999999	43.986472999999997	43.970281	с-с Уллубиевский	0103000020E610000001000000050000000116F9F5435A47401077F52A32FC45400116F9F5435A474089B14CBF44FE45406E6AA0F99C5B474089B14CBF44FE45406E6AA0F99C5B47401077F52A32FC45400116F9F5435A47401077F52A32FC4540
75520	25270	46.529308999999998	46.598309	44.403230000000001	44.371414000000001	Зона Отдыха	0103000020E610000001000000050000003E3DB665C043474066A3737E8A2F46403E3DB665C04347400F62670A9D33464084F3A963954C47400F62670A9D33464084F3A963954C474066A3737E8A2F46403E3DB665C043474066A3737E8A2F4640
33153	19801	48.128804000000002	48.190320999999997	41.687797000000003	41.670178999999997	Школьная	0103000020E6100000010000000500000008CC43A67C104840A5BBEB6CC8D5444008CC43A67C104840BAA46ABB09D84440FA5E43705C184840BAA46ABB09D84440FA5E43705C184840A5BBEB6CC8D5444008CC43A67C104840A5BBEB6CC8D54440
33078	19801	48.128804000000002	48.190320999999997	41.687797000000003	41.670178999999997	Мира	0103000020E6100000010000000500000008CC43A67C104840A5BBEB6CC8D5444008CC43A67C104840BAA46ABB09D84440FA5E43705C184840BAA46ABB09D84440FA5E43705C184840A5BBEB6CC8D5444008CC43A67C104840A5BBEB6CC8D54440
32925	19801	48.128804000000002	48.190320999999997	41.687797000000003	41.670178999999997	Ленина	0103000020E6100000010000000500000008CC43A67C104840A5BBEB6CC8D5444008CC43A67C104840BAA46ABB09D84440FA5E43705C184840BAA46ABB09D84440FA5E43705C184840A5BBEB6CC8D5444008CC43A67C104840A5BBEB6CC8D54440
33111	19801	48.128804000000002	48.190320999999997	41.687797000000003	41.670178999999997	Аминова	0103000020E6100000010000000500000008CC43A67C104840A5BBEB6CC8D5444008CC43A67C104840BAA46ABB09D84440FA5E43705C184840BAA46ABB09D84440FA5E43705C184840A5BBEB6CC8D5444008CC43A67C104840A5BBEB6CC8D54440
32908	19250	47.653092999999998	47.679817	42.458306	42.439771	Матросова	0103000020E610000001000000050000008E1F2A8D98D34740575D876A4A3845408E1F2A8D98D34740C1C760C5A93A4540E621533E04D74740C1C760C5A93A4540E621533E04D74740575D876A4A3845408E1F2A8D98D34740575D876A4A384540
33152	19250	47.653092999999998	47.679817	42.458306	42.439771	Буйнакского	0103000020E610000001000000050000008E1F2A8D98D34740575D876A4A3845408E1F2A8D98D34740C1C760C5A93A4540E621533E04D74740C1C760C5A93A4540E621533E04D74740575D876A4A3845408E1F2A8D98D34740575D876A4A384540
33169	19250	47.653092999999998	47.679817	42.458306	42.439771	Буденного	0103000020E610000001000000050000008E1F2A8D98D34740575D876A4A3845408E1F2A8D98D34740C1C760C5A93A4540E621533E04D74740C1C760C5A93A4540E621533E04D74740575D876A4A3845408E1F2A8D98D34740575D876A4A384540
32939	19250	47.653092999999998	47.679817	42.458306	42.439771	50 лет Октября	0103000020E610000001000000050000008E1F2A8D98D34740575D876A4A3845408E1F2A8D98D34740C1C760C5A93A4540E621533E04D74740C1C760C5A93A4540E621533E04D74740575D876A4A3845408E1F2A8D98D34740575D876A4A384540
33047	19250	47.653092999999998	47.679817	42.458306	42.439771	50 Лет Октября	0103000020E610000001000000050000008E1F2A8D98D34740575D876A4A3845408E1F2A8D98D34740C1C760C5A93A4540E621533E04D74740C1C760C5A93A4540E621533E04D74740575D876A4A3845408E1F2A8D98D34740575D876A4A384540
32940	19250	47.653092999999998	47.679817	42.458306	42.439771	317 стрелковой дивизии	0103000020E610000001000000050000008E1F2A8D98D34740575D876A4A3845408E1F2A8D98D34740C1C760C5A93A4540E621533E04D74740C1C760C5A93A4540E621533E04D74740575D876A4A3845408E1F2A8D98D34740575D876A4A384540
33135	53719	47.486697999999997	47.536400999999998	42.959713999999998	42.900323999999998	Лесная	0103000020E61000000100000005000000A983BC1E4CBE4740E6E61BD13D734540A983BC1E4CBE4740B5C189E8D77A45405645B8C9A8C44740B5C189E8D77A45405645B8C9A8C44740E6E61BD13D734540A983BC1E4CBE4740E6E61BD13D734540
33137	53720	47.486697999999997	47.536400999999998	42.959713999999998	42.900323999999998	Лесная	0103000020E61000000100000005000000A983BC1E4CBE4740E6E61BD13D734540A983BC1E4CBE4740B5C189E8D77A45405645B8C9A8C44740B5C189E8D77A45405645B8C9A8C44740E6E61BD13D734540A983BC1E4CBE4740E6E61BD13D734540
32916	53428	47.277974	47.300305999999999	43.033856	43.018037999999997	Свердлова	0103000020E61000000100000005000000B491EBA694A34740E90AB6114F824540B491EBA694A34740FE62B664558445407365506D70A64740FE62B664558445407365506D70A64740E90AB6114F824540B491EBA694A34740E90AB6114F824540
33079	53685	46.691795999999997	46.704704999999997	43.985967000000002	43.967607999999998	Советская	0103000020E6100000010000000500000076C075C58C5847408AAC3594DAFB454076C075C58C584740B6F7A92A34FE4540F12900C6335A4740B6F7A92A34FE4540F12900C6335A47408AAC3594DAFB454076C075C58C5847408AAC3594DAFB4540
33174	22875	47.954397	47.998342000000001	42.395780999999999	42.378152999999998	мкр.Гоктёбе	0103000020E6100000010000000500000044334FAE29FA474030F147516730454044334FAE29FA474068B0A9F3A8324540931CB0ABC9FF474068B0A9F3A8324540931CB0ABC9FF474030F147516730454044334FAE29FA474030F1475167304540
33171	22875	47.954397	47.998342000000001	42.395780999999999	42.378152999999998	мкр. Сельхозтехника	0103000020E6100000010000000500000044334FAE29FA474030F147516730454044334FAE29FA474068B0A9F3A8324540931CB0ABC9FF474068B0A9F3A8324540931CB0ABC9FF474030F147516730454044334FAE29FA474030F1475167304540
33038	22875	47.954397	47.998342000000001	42.395780999999999	42.378152999999998	Новая	0103000020E6100000010000000500000044334FAE29FA474030F147516730454044334FAE29FA474068B0A9F3A8324540931CB0ABC9FF474068B0A9F3A8324540931CB0ABC9FF474030F147516730454044334FAE29FA474030F1475167304540
33007	20782	47.338287000000001	47.363422	42.746211000000002	42.734332000000002	изиева	0103000020E61000000100000005000000BBD408FD4CAB474001344A97FE5D4540BBD408FD4CAB47402E7590D7835F4540CE52B29C84AE47402E7590D7835F4540CE52B29C84AE474001344A97FE5D4540BBD408FD4CAB474001344A97FE5D4540
33115	20782	47.338287000000001	47.363422	42.746211000000002	42.734332000000002	Изиева	0103000020E61000000100000005000000BBD408FD4CAB474001344A97FE5D4540BBD408FD4CAB47402E7590D7835F4540CE52B29C84AE47402E7590D7835F4540CE52B29C84AE474001344A97FE5D4540BBD408FD4CAB474001344A97FE5D4540
33036	20322	47.544316000000002	47.585791	42.717309999999998	42.691577000000002	Дахадаева	0103000020E6100000010000000500000043588D25ACC5474039D55A988558454043588D25ACC54740008C67D0D05B454044A51133FBCA4740008C67D0D05B454044A51133FBCA474039D55A988558454043588D25ACC5474039D55A9885584540
33168	20322	47.544316000000002	47.585791	42.717309999999998	42.691577000000002	Дауда Карабудахкентского	0103000020E6100000010000000500000043588D25ACC5474039D55A988558454043588D25ACC54740008C67D0D05B454044A51133FBCA4740008C67D0D05B454044A51133FBCA474039D55A988558454043588D25ACC5474039D55A9885584540
33034	20322	47.544316000000002	47.585791	42.717309999999998	42.691577000000002	Гамзатова	0103000020E6100000010000000500000043588D25ACC5474039D55A988558454043588D25ACC54740008C67D0D05B454044A51133FBCA4740008C67D0D05B454044A51133FBCA474039D55A988558454043588D25ACC5474039D55A9885584540
33102	20322	47.544316000000002	47.585791	42.717309999999998	42.691577000000002	Абдуллаева	0103000020E6100000010000000500000043588D25ACC5474039D55A988558454043588D25ACC54740008C67D0D05B454044A51133FBCA4740008C67D0D05B454044A51133FBCA474039D55A988558454043588D25ACC5474039D55A9885584540
33057	20322	47.544316000000002	47.585791	42.717309999999998	42.691577000000002	Абакарова А	0103000020E6100000010000000500000043588D25ACC5474039D55A988558454043588D25ACC54740008C67D0D05B454044A51133FBCA4740008C67D0D05B454044A51133FBCA474039D55A988558454043588D25ACC5474039D55A9885584540
33132	53716	48.269435999999999	48.327350000000003	42.102279000000003	42.022413	Буйнакского	0103000020E61000000100000005000000BA2EFCE07C224840AC00DF6DDE024540BA2EFCE07C224840A708707A170D45403D2CD49AE6294840A708707A170D45403D2CD49AE6294840AC00DF6DDE024540BA2EFCE07C224840AC00DF6DDE024540
33056	9178	47.620914999999997	47.640965000000001	42.174748000000001	42.152599000000002	Пироговский	0103000020E61000000100000005000000444C89247ACF47407F33315D88134540444C89247ACF47404D8578245E164540B97020240BD247404D8578245E164540B97020240BD247407F33315D88134540444C89247ACF47407F33315D88134540
33094	11596	47.592492	47.612290999999999	42.097575999999997	42.080835	Новый	0103000020E61000000100000005000000219221C7D6CB4740A3AF20CD580A4540219221C7D6CB4740EF6FD05E7D0C45404C512E8D5FCE4740EF6FD05E7D0C45404C512E8D5FCE4740A3AF20CD580A4540219221C7D6CB4740A3AF20CD580A4540
32920	53432	46.952765999999997	46.966115000000002	42.391452000000001	42.382682000000003	Площадь Шамиля	0103000020E61000000100000005000000D05E7D3CF47947404A6249B9FB304540D05E7D3CF479474016FA60191B324540689604A8A97B474016FA60191B324540689604A8A97B47404A6249B9FB304540D05E7D3CF47947404A6249B9FB304540
32924	53432	46.952765999999997	46.966115000000002	42.391452000000001	42.382682000000003	Пирогова	0103000020E61000000100000005000000D05E7D3CF47947404A6249B9FB304540D05E7D3CF479474016FA60191B324540689604A8A97B474016FA60191B324540689604A8A97B47404A6249B9FB304540D05E7D3CF47947404A6249B9FB304540
75513	29708	46.75705	46.797986000000002	43.617244999999997	43.593145	улица Зона Отдыха	0103000020E61000000100000005000000E9B7AF03E76047409964E42CECCB4540E9B7AF03E76047404C4F58E201CF45403B55BE67246647404C4F58E201CF45403B55BE67246647409964E42CECCB4540E9B7AF03E76047409964E42CECCB4540
33083	29708	46.75705	46.797986000000002	43.617244999999997	43.593145	Мира	0103000020E61000000100000005000000E9B7AF03E76047409964E42CECCB4540E9B7AF03E76047404C4F58E201CF45403B55BE67246647404C4F58E201CF45403B55BE67246647409964E42CECCB4540E9B7AF03E76047409964E42CECCB4540
33093	29708	46.75705	46.797986000000002	43.617244999999997	43.593145	Ленина	0103000020E61000000100000005000000E9B7AF03E76047409964E42CECCB4540E9B7AF03E76047404C4F58E201CF45403B55BE67246647404C4F58E201CF45403B55BE67246647409964E42CECCB4540E9B7AF03E76047409964E42CECCB4540
33013	29708	46.75705	46.797986000000002	43.617244999999997	43.593145	Ирчи-Казака 	0103000020E61000000100000005000000E9B7AF03E76047409964E42CECCB4540E9B7AF03E76047404C4F58E201CF45403B55BE67246647404C4F58E201CF45403B55BE67246647409964E42CECCB4540E9B7AF03E76047409964E42CECCB4540
33024	29708	46.75705	46.797986000000002	43.617244999999997	43.593145	Дж. Алиева	0103000020E61000000100000005000000E9B7AF03E76047409964E42CECCB4540E9B7AF03E76047404C4F58E201CF45403B55BE67246647404C4F58E201CF45403B55BE67246647409964E42CECCB4540E9B7AF03E76047409964E42CECCB4540
33080	29708	46.75705	46.797986000000002	43.617244999999997	43.593145	Алиева	0103000020E61000000100000005000000E9B7AF03E76047409964E42CECCB4540E9B7AF03E76047404C4F58E201CF45403B55BE67246647404C4F58E201CF45403B55BE67246647409964E42CECCB4540E9B7AF03E76047409964E42CECCB4540
33170	27823	47.700029999999998	47.761806999999997	41.475186000000001	41.443174999999997	Самурского	0103000020E61000000100000005000000041C42959AD94740D0B359F5B9B84440041C42959AD947402FC214E5D2BC4440936E4BE482E147402FC214E5D2BC4440936E4BE482E14740D0B359F5B9B84440041C42959AD94740D0B359F5B9B84440
32923	27823	47.700029999999998	47.761806999999997	41.475186000000001	41.443174999999997	Ленина	0103000020E61000000100000005000000041C42959AD94740D0B359F5B9B84440041C42959AD947402FC214E5D2BC4440936E4BE482E147402FC214E5D2BC4440936E4BE482E14740D0B359F5B9B84440041C42959AD94740D0B359F5B9B84440
32982	27823	47.700029999999998	47.761806999999997	41.475186000000001	41.443174999999997	Байрамова	0103000020E61000000100000005000000041C42959AD94740D0B359F5B9B84440041C42959AD947402FC214E5D2BC4440936E4BE482E147402FC214E5D2BC4440936E4BE482E14740D0B359F5B9B84440041C42959AD94740D0B359F5B9B84440
32977	27823	47.700029999999998	47.761806999999997	41.475186000000001	41.443174999999997	Аливердиева	0103000020E61000000100000005000000041C42959AD94740D0B359F5B9B84440041C42959AD947402FC214E5D2BC4440936E4BE482E147402FC214E5D2BC4440936E4BE482E14740D0B359F5B9B84440041C42959AD94740D0B359F5B9B84440
32946	25213	47.407618999999997	47.432844000000003	42.304918999999998	42.287466000000002	Кутан Аралык	0103000020E61000000100000005000000361D01DC2CB44740215B96AFCB244540361D01DC2CB44740EA76F695072745408A22A46E67B74740EA76F695072745408A22A46E67B74740215B96AFCB244540361D01DC2CB44740215B96AFCB244540
5785	818	41.915463000000003	41.953516	45.021856999999997	45.019086000000001	улица Шпаковская	0103000020E610000001000000050000005AD93EE42DF54440DEE7F868718246405AD93EE42DF544402618CE35CC8246403B1BF2CF0CFA44402618CE35CC8246403B1BF2CF0CFA4440DEE7F868718246405AD93EE42DF54440DEE7F86871824640
7276	818	42.018644000000002	42.019677000000001	45.039617	45.032922999999997	улица Широкая	0103000020E61000000100000005000000212235ED62024540A22424D236844640212235ED62024540CDAE7B2B12854640E0BDA3C684024540CDAE7B2B12854640E0BDA3C684024540A22424D236844640212235ED62024540A22424D236844640
1125	818	41.942411999999997	41.943705999999999	45.024711000000003	45.018213000000003	улица Чайковского	0103000020E61000000100000005000000D1ADD7F4A0F8444058AEB7CD54824640D1ADD7F4A0F84440FD6CE4BA29834640FD84B35BCBF84440FD6CE4BA29834640FD84B35BCBF8444058AEB7CD54824640D1ADD7F4A0F8444058AEB7CD54824640
4689	818	41.967106999999999	41.973548000000001	45.047272	45.046317000000002	улица Советская	0103000020E61000000100000005000000C85D8429CAFB4440DA1F28B7ED854640C85D8429CAFB44401D0247020D864640098B8A389DFC44401D0247020D864640098B8A389DFC4440DA1F28B7ED854640C85D8429CAFB4440DA1F28B7ED854640
4041	818	41.935163000000003	42.027824000000003	45.033152000000001	45.024348000000003	улица Серова	0103000020E61000000100000005000000F2B6D26BB3F744408CDCD3D51D834640F2B6D26BB3F7444004E621533E8446409F05A1BC8F03454004E621533E8446409F05A1BC8F0345408CDCD3D51D834640F2B6D26BB3F744408CDCD3D51D834640
1616	818	41.906291000000003	41.911268	45.005111999999997	45.002485999999998	улица Сельская	0103000020E610000001000000050000005FD4EE5701F4444053591476518046405FD4EE5701F4444098689082A780464017F2086EA4F4444098689082A780464017F2086EA4F4444053591476518046405FD4EE5701F444405359147651804640
5348	818	41.972335000000001	41.998818	45.072248999999999	45.066526000000003	улица Репина	0103000020E61000000100000005000000CAE0287975FC4440B72A89EC83884640CAE0287975FC444098158A743F894640FC53AA44D9FF444098158A743F894640FC53AA44D9FF4440B72A89EC83884640CAE0287975FC4440B72A89EC83884640
913	818	41.962508	41.965957000000003	45.043916000000003	45.023640999999998	улица Пушкина	0103000020E61000000100000005000000B6114F7633FB444020EC14AB06834640B6114F7633FB4440B5E21B0A9F854640D02B9E7AA4FB4440B5E21B0A9F854640D02B9E7AA4FB444020EC14AB06834640B6114F7633FB444020EC14AB06834640
60220	818	41.962508	41.965957000000003	45.043916000000003	45.023640999999998	Пушкина	0103000020E61000000100000005000000B6114F7633FB444020EC14AB06834640B6114F7633FB4440B5E21B0A9F854640D02B9E7AA4FB4440B5E21B0A9F854640D02B9E7AA4FB444020EC14AB06834640B6114F7633FB444020EC14AB06834640
3647	818	41.973511999999999	42.014843999999997	45.076124999999998	45.069071999999998	улица Пригородная	0103000020E61000000100000005000000BC218D0A9CFC4440DF88EE59D7884640BC218D0A9CFC444039B4C876BE8946405A457F68E601454039B4C876BE8946405A457F68E6014540DF88EE59D7884640BC218D0A9CFC4440DF88EE59D7884640
4970	818	41.963532000000001	42.003219000000001	45.030534000000003	45.022666000000001	улица Пономарева	0103000020E6100000010000000500000022533E0455FB4440965D30B8E682464022533E0455FB444042B5C189E8834640E8DCED7A6900454042B5C189E8834640E8DCED7A69004540965D30B8E682464022533E0455FB4440965D30B8E6824640
5942	818	41.909292000000001	41.916145999999998	45.021163000000001	44.995404999999998	улица Пирогова	0103000020E61000000100000005000000D94125AE63F444402FA3586E697F4640D94125AE63F4444050711C78B58246403C2EAA4544F5444050711C78B58246403C2EAA4544F544402FA3586E697F4640D94125AE63F444402FA3586E697F4640
583	818	41.938927	41.970861999999997	45.080376999999999	45.059275	улица Октябрьская	0103000020E610000001000000050000006B2A8BC22EF84440363CBD52968746406B2A8BC22EF84440E02C25CB498A4640EE76BD3445FC4440E02C25CB498A4640EE76BD3445FC4440363CBD52968746406B2A8BC22EF84440363CBD5296874640
5380	818	41.977212999999999	41.980663	45.074908999999998	45.070459999999997	улица Огородная	0103000020E61000000100000005000000EF1CCA5015FD44408CD651D504894640EF1CCA5015FD444089963C9E96894640D9B27C5D86FD444089963C9E96894640D9B27C5D86FD44408CD651D504894640EF1CCA5015FD44408CD651D504894640
4755	818	42.005958999999997	42.030132999999999	45.054225000000002	45.045577999999999	улица Объездная	0103000020E61000000100000005000000F50EB743C300454063B5F97FD5854640F50EB743C300454014D044D8F0864640E3C3EC65DB03454014D044D8F0864640E3C3EC65DB03454063B5F97FD5854640F50EB743C300454063B5F97FD5854640
15855	818	41.945413000000002	41.969676	45.042203000000001	45.03933	улица Михаила Морозова	0103000020E610000001000000050000004C1B0E4B03F9444037E0F3C3088546404C1B0E4B03F9444084656CE866854640A9DBD9571EFC444084656CE866854640A9DBD9571EFC444037E0F3C3088546404C1B0E4B03F9444037E0F3C308854640
1720	818	41.932172000000001	42.019649999999999	45.042610000000003	45.033776000000003	улица Мира	0103000020E610000001000000050000009B1F7F6951F74440E2B19FC5528446409B1F7F6951F74440C53D963E74854640E6AE25E483024540C53D963E74854640E6AE25E483024540E2B19FC5528446409B1F7F6951F74440E2B19FC552844640
4893	818	41.985056	41.986547000000002	45.042610000000003	45.035935000000002	улица Маяковского	0103000020E61000000100000005000000425DA45016FE444011E4A08499844640425DA45016FE4440C53D963E74854640C47B0E2C47FE4440C53D963E74854640C47B0E2C47FE444011E4A08499844640425DA45016FE444011E4A08499844640
4635	818	41.968868000000001	41.970771999999997	45.046571	45.035004999999998	улица Маршала Жукова	0103000020E610000001000000050000000A12DBDD03FC44402619390B7B8446400A12DBDD03FC444094F8DC09F6854640AEEFC34142FC444094F8DC09F6854640AEEFC34142FC44402619390B7B8446400A12DBDD03FC44402619390B7B844640
4027	818	41.956471000000001	41.960352	45.042935	45.022176000000002	улица Ломоносова	0103000020E61000000100000005000000454948A46DFA4440C860C5A9D6824640454948A46DFA4440486DE2E47E854640F85278D0ECFA4440486DE2E47E854640F85278D0ECFA4440C860C5A9D6824640454948A46DFA4440C860C5A9D6824640
595	818	41.901502999999998	42.012652000000003	45.051881999999999	45.035254000000002	улица Ленина	0103000020E61000000100000005000000791F477364F34440CF86FC3383844640791F477364F3444023A0C211A4864640501DAB949E01454023A0C211A4864640501DAB949E014540CF86FC3383844640791F477364F34440CF86FC3383844640
213	818	41.988019999999999	41.992699999999999	45.074024999999999	45.062496000000003	улица Красная	0103000020E610000001000000050000009FE5797077FE4440BF1072DEFF8746409FE5797077FE44400F0BB5A6798946409E5E29CB10FF44400F0BB5A6798946409E5E29CB10FF4440BF1072DEFF8746409FE5797077FE4440BF1072DEFF874640
3778	818	41.973153000000003	41.994137000000002	45.043674000000003	45.041170999999999	улица Комсомольская	0103000020E610000001000000050000008D800A4790FC444095456117458546408D800A4790FC4440BFD7101C978546402D5F97E13FFF4440BFD7101C978546402D5F97E13FFF444095456117458546408D800A4790FC44409545611745854640
5867	818	41.919991000000003	41.941217999999999	45.036878000000002	44.988674000000003	улица Доваторцев	0103000020E61000000100000005000000A3CEDC43C2F54440E833A0DE8C7E4640A3CEDC43C2F5444090F8156BB88446400934D8D479F8444090F8156BB88446400934D8D479F84440E833A0DE8C7E4640A3CEDC43C2F54440E833A0DE8C7E4640
643	818	41.941775	41.994289999999999	45.050168999999997	45.040711999999999	улица Дзержинского	0103000020E610000001000000050000005F984C158CF844400247020D368546405F984C158CF84440F22213F06B864640B35E0CE544FF4440F22213F06B864640B35E0CE544FF44400247020D368546405F984C158CF844400247020D36854640
5400	818	41.969352999999998	41.974598999999998	45.059593	45.056671000000001	улица Гоголя	0103000020E61000000100000005000000C6A354C213FC4440D9D0CDFE40874640C6A354C213FC4440070951BEA08746406EDBF7A8BFFC4440070951BEA08746406EDBF7A8BFFC4440D9D0CDFE40874640C6A354C213FC4440D9D0CDFE40874640
4693	818	41.980356999999998	41.986367000000001	45.054938999999997	45.042782000000003	улица Геннадия Голенева	0103000020E61000000100000005000000CCB392567CFD4440C26D6DE179854640CCB392567CFD44403123BC3D08874640446D1B4641FE44403123BC3D08874640446D1B4641FE4440C26D6DE179854640CCB392567CFD4440C26D6DE179854640
2289	818	41.930950000000003	41.938800999999998	45.039152000000001	45.037649000000002	улица Гагарина	0103000020E61000000100000005000000091B9E5E29F7444012DDB3AED1844640091B9E5E29F7444058C9C7EE02854640DE3994A12AF8444058C9C7EE02854640DE3994A12AF8444012DDB3AED1844640091B9E5E29F7444012DDB3AED1844640
5174	818	41.968131	41.974096000000003	45.057377000000002	45.053072999999998	улица Вавилова	0103000020E61000000100000005000000349F73B7EBFB44407AA69718CB864640349F73B7EBFB444074452921588746400C957F2DAFFC444074452921588746400C957F2DAFFC44407AA69718CB864640349F73B7EBFB44407AA69718CB864640
5523	818	41.924805999999997	41.935324999999999	45.065067999999997	45.063488999999997	улица Бруснева	0103000020E610000001000000050000008192020B60F64440EF535568208846408192020B60F644401002F22554884640CB10C7BAB8F744401002F22554884640CB10C7BAB8F74440EF535568208846408192020B60F64440EF53556820884640
5101	818	41.997892	42.012382000000002	45.033126000000003	45.024973000000003	улица Биологическая	0103000020E610000001000000050000005378D0ECBAFF44403A24B550328346405378D0ECBAFF4440DB5207793D8446409087BEBB95014540DB5207793D8446409087BEBB950145403A24B550328346405378D0ECBAFF44403A24B55032834640
5023	818	41.978721999999998	41.980536999999998	45.029279000000002	45.020054000000002	улица Ашихина	0103000020E6100000010000000500000017F032C346FD4440B61325219182464017F032C346FD4440D4BA0D6ABF8346404CC2853C82FD4440D4BA0D6ABF8346404CC2853C82FD4440B61325219182464017F032C346FD4440B613252191824640
5868	818	41.919595000000001	41.926575	45.020417000000002	44.998904000000003	улица 50 Лет ВЛКСМ	0103000020E610000001000000050000005648F949B5F54440FBEB1516DC7F46405648F949B5F5444027A435069D824640462575029AF6444027A435069D824640462575029AF64440FBEB1516DC7F46405648F949B5F54440FBEB1516DC7F4640
6092	818	41.905752	41.925047999999997	45.001078	44.998018000000002	улица 45-я Параллель	0103000020E61000000100000005000000AF2479AEEFF34440E068C70DBF7F4640AF2479AEEFF344405F5FEB5223804640779D0DF967F644405F5FEB5223804640779D0DF967F64440E068C70DBF7F4640AF2479AEEFF34440E068C70DBF7F4640
5535	818	41.922514999999997	41.936250000000001	45.063488999999997	45.059389000000003	Юности проспект	0103000020E61000000100000005000000E388B5F814F64440FF5E0A0F9A874640E388B5F814F64440EF53556820884640A4703D0AD7F74440EF53556820884640A4703D0AD7F74440FF5E0A0F9A874640E388B5F814F64440FF5E0A0F9A874640
60262	818	41.915463000000003	41.953516	45.021856999999997	45.019086000000001	Шпаковская	0103000020E610000001000000050000005AD93EE42DF54440DEE7F868718246405AD93EE42DF544402618CE35CC8246403B1BF2CF0CFA44402618CE35CC8246403B1BF2CF0CFA4440DEE7F868718246405AD93EE42DF54440DEE7F86871824640
60605	818	41.992485000000002	41.997039000000001	45.074196000000001	45.065660000000001	Шевченко	0103000020E61000000100000005000000A2629CBF09FF4440E353008C67884640A2629CBF09FF44403CBF28417F89464014EB54F99EFF44403CBF28417F89464014EB54F99EFF4440E353008C67884640A2629CBF09FF4440E353008C67884640
828	818	41.993831999999998	41.995449000000001	45.044972999999999	45.037419	Чкалова переулок	0103000020E61000000100000005000000F0DB10E335FF4440E09F5225CA844640F0DB10E335FF4440FC19DEACC1854640FFEA71DF6AFF4440FC19DEACC1854640FFEA71DF6AFF4440E09F5225CA844640F0DB10E335FF4440E09F5225CA844640
4973	818	41.974375000000002	41.974778999999998	45.030552999999998	45.026578000000001	Черняховского проезд	0103000020E610000001000000050000001F85EB51B8FC444084656CE8668346401F85EB51B8FC4440B8E52329E9834640EEE9EA8EC5FC4440B8E52329E9834640EEE9EA8EC5FC444084656CE8668346401F85EB51B8FC444084656CE866834640
5325	818	42.014071000000001	42.015940000000001	45.078957000000003	45.065418000000001	Чапаевский проезд	0103000020E6100000010000000500000038691A14CD014540ED48F59D5F88464038691A14CD014540286552431B8A4640605969520A024540286552431B8A4640605969520A024540ED48F59D5F88464038691A14CD014540ED48F59D5F884640
60167	818	42.015130999999997	42.036932999999998	45.080224000000001	45.076856999999997	Чапаева	0103000020E61000000100000005000000F01307D0EF014540FDBB3E73D6894640F01307D0EF0145405A2DB0C7448A464053927538BA0445405A2DB0C7448A464053927538BA044540FDBB3E73D6894640F01307D0EF014540FDBB3E73D6894640
5844	818	41.932558	41.937984	45.017677999999997	45.017116999999999	Фестивальный переулок	0103000020E61000000100000005000000C4CF7F0F5EF74440529ACDE330824640C4CF7F0F5EF74440E9EDCF4543824640EC1516DC0FF84440E9EDCF4543824640EC1516DC0FF84440529ACDE330824640C4CF7F0F5EF74440529ACDE330824640
60178	818	41.910307000000003	41.929872000000003	45.015104000000001	45.012121999999998	Тухачевского	0103000020E61000000100000005000000F22895F084F44440F3C7B4368D814640F22895F084F44440F70489EDEE814640AABBB20B06F74440F70489EDEE814640AABBB20B06F74440F3C7B4368D814640F22895F084F44440F3C7B4368D814640
60249	818	42.009238000000003	42.016002	45.046565000000001	45.044508	Туапсинская	0103000020E61000000100000005000000B3F0F5B52E01454087342A70B2854640B3F0F5B52E014540B21188D7F5854640D655815A0C024540B21188D7F5854640D655815A0C02454087342A70B2854640B3F0F5B52E01454087342A70B2854640
60232	818	41.980663	41.983680999999997	45.070459999999997	45.055912999999997	Трунова	0103000020E61000000100000005000000D9B27C5D86FD4440EB353D2828874640D9B27C5D86FD44408CD651D50489464029594E42E9FD44408CD651D50489464029594E42E9FD4440EB353D2828874640D9B27C5D86FD4440EB353D2828874640
59945	818	41.935163000000003	42.027824000000003	45.033152000000001	45.024348000000003	Серова	0103000020E61000000100000005000000F2B6D26BB3F744408CDCD3D51D834640F2B6D26BB3F7444004E621533E8446409F05A1BC8F03454004E621533E8446409F05A1BC8F0345408CDCD3D51D834640F2B6D26BB3F744408CDCD3D51D834640
60184	818	41.979844999999997	41.983429999999998	45.048144000000001	45.037056	Розы Люксембург	0103000020E6100000010000000500000016139B8F6BFD44406F0F4240BE84464016139B8F6BFD4440D3BF249529864640E0F3C308E1FD4440D3BF249529864640E0F3C308E1FD44406F0F4240BE84464016139B8F6BFD44406F0F4240BE844640
60258	818	41.973511999999999	42.014843999999997	45.076124999999998	45.069071999999998	Пригородная	0103000020E61000000100000005000000BC218D0A9CFC4440DF88EE59D7884640BC218D0A9CFC444039B4C876BE8946405A457F68E601454039B4C876BE8946405A457F68E6014540DF88EE59D7884640BC218D0A9CFC4440DF88EE59D7884640
5465	818	41.945988	41.956175000000002	45.062922999999998	45.055149	Попова переулок	0103000020E610000001000000050000004834812216F944401CB4571F0F8746404834812216F94440469561DC0D8846405C2041F163FA4440469561DC0D8846405C2041F163FA44401CB4571F0F8746404834812216F944401CB4571F0F874640
60234	818	41.964421000000002	41.975453000000002	45.053072999999998	45.050334999999997	Победы	0103000020E61000000100000005000000AE49B72572FB44400D6C956071864640AE49B72572FB44407AA69718CB8646407EE4D6A4DBFC44407AA69718CB8646407EE4D6A4DBFC44400D6C956071864640AE49B72572FB44400D6C956071864640
60256	818	41.909292000000001	41.916145999999998	45.021163000000001	44.995404999999998	Пирогова	0103000020E61000000100000005000000D94125AE63F444402FA3586E697F4640D94125AE63F4444050711C78B58246403C2EAA4544F5444050711C78B58246403C2EAA4544F544402FA3586E697F4640D94125AE63F444402FA3586E697F4640
60264	818	41.909292000000001	41.916145999999998	45.021163000000001	44.995404999999998	Пирогова	0103000020E61000000100000005000000D94125AE63F444402FA3586E697F4640D94125AE63F4444050711C78B58246403C2EAA4544F5444050711C78B58246403C2EAA4544F544402FA3586E697F4640D94125AE63F444402FA3586E697F4640
60244	818	41.931973999999997	41.935620999999998	45.039942000000003	45.039566000000001	Осетинская	0103000020E61000000100000005000000745C8DEC4AF744404B04AA7F10854640745C8DEC4AF7444051DEC7D11C854640B439CE6DC2F7444051DEC7D11C854640B439CE6DC2F744404B04AA7F10854640745C8DEC4AF744404B04AA7F10854640
4650	818	41.972928000000003	41.973629000000003	45.047272	45.037877999999999	Октябрьской Революции проспект	0103000020E610000001000000050000006DAE9AE788FC4440739EB12FD98446406DAE9AE788FC44401D0247020D864640F6B704E09FFC44401D0247020D864640F6B704E09FFC4440739EB12FD98446406DAE9AE788FC4440739EB12FD9844640
60259	818	41.938927	41.970861999999997	45.080376999999999	45.059275	Октябрьская	0103000020E610000001000000050000006B2A8BC22EF84440363CBD52968746406B2A8BC22EF84440E02C25CB498A4640EE76BD3445FC4440E02C25CB498A4640EE76BD3445FC4440363CBD52968746406B2A8BC22EF84440363CBD5296874640
60200	818	41.938927	41.970861999999997	45.080376999999999	45.059275	Октябрьская	0103000020E610000001000000050000006B2A8BC22EF84440363CBD52968746406B2A8BC22EF84440E02C25CB498A4640EE76BD3445FC4440E02C25CB498A4640EE76BD3445FC4440363CBD52968746406B2A8BC22EF84440363CBD5296874640
60218	818	42.005958999999997	42.030132999999999	45.054225000000002	45.045577999999999	Объездная	0103000020E61000000100000005000000F50EB743C300454063B5F97FD5854640F50EB743C300454014D044D8F0864640E3C3EC65DB03454014D044D8F0864640E3C3EC65DB03454063B5F97FD5854640F50EB743C300454063B5F97FD5854640
60195	818	41.932172000000001	42.019649999999999	45.042610000000003	45.033776000000003	Мира	0103000020E610000001000000050000009B1F7F6951F74440E2B19FC5528446409B1F7F6951F74440C53D963E74854640E6AE25E483024540C53D963E74854640E6AE25E483024540E2B19FC5528446409B1F7F6951F74440E2B19FC552844640
5502	818	41.935324999999999	41.942915999999997	45.068511999999998	45.063488999999997	Макарова переулок	0103000020E61000000100000005000000CB10C7BAB8F74440EF53556820884640CB10C7BAB8F7444018B14F00C58846400470B378B1F8444018B14F00C58846400470B378B1F84440EF53556820884640CB10C7BAB8F74440EF53556820884640
59951	818	41.887462999999997	42.134444999999999	45.121214999999999	44.968142999999998	Магистральная	0103000020E610000001000000050000007CB4386398F14440F86C1D1CEC7B46407CB4386398F144406F641EF9838F46402C0E677E351145406F641EF9838F46402C0E677E35114540F86C1D1CEC7B46407CB4386398F14440F86C1D1CEC7B4640
60224	818	41.937975000000002	41.991945999999999	45.039285999999997	45.031190000000002	Лермонтова	0103000020E6100000010000000500000099BB96900FF844402BFBAE08FE83464099BB96900FF844406798DA5207854640F2B22616F8FE44406798DA5207854640F2B22616F8FE44402BFBAE08FE83464099BB96900FF844402BFBAE08FE834640
60182	818	41.901502999999998	42.012652000000003	45.051881999999999	45.035254000000002	Ленина	0103000020E61000000100000005000000791F477364F34440CF86FC3383844640791F477364F3444023A0C211A4864640501DAB949E01454023A0C211A4864640501DAB949E014540CF86FC3383844640791F477364F34440CF86FC3383844640
3672	818	41.9116	41.939897000000002	45.081338000000002	45.039209	Кулакова проспект	0103000020E610000001000000050000004D840D4FAFF44440BC5AEECC048546404D840D4FAFF4444006F69848698A4640E44D7E8B4EF8444006F69848698A4640E44D7E8B4EF84440BC5AEECC048546404D840D4FAFF44440BC5AEECC04854640
28735	818	41.968184999999998	41.968885999999998	45.034337000000001	45.033216000000003	Крылова переулок	0103000020E6100000010000000500000027BD6F7CEDFB44401BDA006C4084464027BD6F7CEDFB44407905A22765844640B0C6D97404FC44407905A22765844640B0C6D97404FC44401BDA006C4084464027BD6F7CEDFB44401BDA006C40844640
4996	818	41.981884000000001	41.984310000000001	45.037056	45.020653000000003	Крупской переулок	0103000020E610000001000000050000009B3BFA5FAEFD44403BC8EBC1A48246409B3BFA5FAEFD44406F0F4240BE8446401990BDDEFDFD44406F0F4240BE8446401990BDDEFDFD44403BC8EBC1A48246409B3BFA5FAEFD44403BC8EBC1A4824640
60197	818	41.943652	41.948503000000002	45.044201999999999	45.024138000000001	Краснофлотская	0103000020E610000001000000050000000A67B796C9F84440A14B38F4168346400A67B796C9F844407A354069A88546403694DA8B68F944407A354069A88546403694DA8B68F94440A14B38F4168346400A67B796C9F84440A14B38F416834640
7445	818	41.939376000000003	41.945880000000002	45.066175999999999	45.061566999999997	Кочубея проезд	0103000020E61000000100000005000000DB5207793DF84440A4C16D6DE1874640DB5207793DF84440DAE385747888464062F8889812F94440DAE385747888464062F8889812F94440A4C16D6DE1874640DB5207793DF84440A4C16D6DE1874640
60235	818	41.973153000000003	41.994137000000002	45.043674000000003	45.041170999999999	Комсомольская	0103000020E610000001000000050000008D800A4790FC444095456117458546408D800A4790FC4440BFD7101C978546402D5F97E13FFF4440BFD7101C978546402D5F97E13FFF444095456117458546408D800A4790FC44409545611745854640
1057	818	41.973287999999997	41.999589999999998	45.055613999999998	45.046214999999997	Карла Маркса проспект	0103000020E610000001000000050000006CCB80B394FC4440D5CA845FEA8546406CCB80B394FC444091990B5C1E8746404EB4AB90F2FF444091990B5C1E8746404EB4AB90F2FF4440D5CA845FEA8546406CCB80B394FC4440D5CA845FEA854640
60238	818	41.973287999999997	41.999589999999998	45.055613999999998	45.046214999999997	Карла Маркса проспект	0103000020E610000001000000050000006CCB80B394FC4440D5CA845FEA8546406CCB80B394FC444091990B5C1E8746404EB4AB90F2FF444091990B5C1E8746404EB4AB90F2FF4440D5CA845FEA8546406CCB80B394FC4440D5CA845FEA854640
4802	818	41.959893999999998	41.960576000000003	45.041176999999998	45.036445000000001	Зоотехнический переулок	0103000020E6100000010000000500000035D07CCEDDFA4440268DD13AAA84464035D07CCEDDFA4440772CB6494585464048A98427F4FA4440772CB6494585464048A98427F4FA4440268DD13AAA84464035D07CCEDDFA4440268DD13AAA844640
60227	818	41.919991000000003	41.941217999999999	45.036878000000002	44.988674000000003	Доваторцев	0103000020E61000000100000005000000A3CEDC43C2F54440E833A0DE8C7E4640A3CEDC43C2F5444090F8156BB88446400934D8D479F8444090F8156BB88446400934D8D479F84440E833A0DE8C7E4640A3CEDC43C2F54440E833A0DE8C7E4640
60363	818	41.990796000000003	41.993715000000002	45.04524	45.037114000000003	Добролюбова	0103000020E61000000100000005000000FA804067D2FE4440A41CCC26C0844640FA804067D2FE44404B3CA06CCA854640B745990D32FF44404B3CA06CCA854640B745990D32FF4440A41CCC26C0844640FA804067D2FE4440A41CCC26C0844640
60236	818	41.941775	41.994289999999999	45.050168999999997	45.040711999999999	Дзержинского	0103000020E610000001000000050000005F984C158CF844400247020D368546405F984C158CF84440F22213F06B864640B35E0CE544FF4440F22213F06B864640B35E0CE544FF44400247020D368546405F984C158CF844400247020D36854640
60233	818	41.941775	41.994289999999999	45.050168999999997	45.040711999999999	Дзержинского	0103000020E610000001000000050000005F984C158CF844400247020D368546405F984C158CF84440F22213F06B864640B35E0CE544FF4440F22213F06B864640B35E0CE544FF44400247020D368546405F984C158CF844400247020D36854640
4736	818	42.000703999999999	42.001809000000002	45.045316999999997	45.038801999999997	Гризодубовой переулок	0103000020E61000000100000005000000FA7C9411170045407B82C476F7844640FA7C941117004540F6798CF2CC85464053EBFD463B004540F6798CF2CC85464053EBFD463B0045407B82C476F7844640FA7C9411170045407B82C476F7844640
4716	818	41.990904	41.996454999999997	45.044908999999997	45.044271999999999	Готвальда проезд	0103000020E61000000100000005000000E0BC38F1D5FE4440731074B4AA854640E0BC38F1D5FE4440E525FF93BF854640C47762D68BFF4440E525FF93BF854640C47762D68BFF4440731074B4AA854640E0BC38F1D5FE4440731074B4AA854640
60229	818	41.980356999999998	41.986367000000001	45.054938999999997	45.042782000000003	Геннадия Голенева	0103000020E61000000100000005000000CCB392567CFD4440C26D6DE179854640CCB392567CFD44403123BC3D08874640446D1B4641FE44403123BC3D08874640446D1B4641FE4440C26D6DE179854640CCB392567CFD4440C26D6DE179854640
60361	818	41.930950000000003	41.938800999999998	45.039152000000001	45.037649000000002	Гагарина	0103000020E61000000100000005000000091B9E5E29F7444012DDB3AED1844640091B9E5E29F7444058C9C7EE02854640DE3994A12AF8444058C9C7EE02854640DE3994A12AF8444012DDB3AED1844640091B9E5E29F7444012DDB3AED1844640
5902	818	41.917897000000004	41.920197000000002	45.021093	45.01388	Ворошилова проспект	0103000020E610000001000000050000005B0C1EA67DF54440C408E1D1C68146405B0C1EA67DF544405796E82CB38246404C70EA03C9F544405796E82CB38246404C70EA03C9F54440C408E1D1C68146405B0C1EA67DF54440C408E1D1C6814640
60228	818	41.933160000000001	41.955751999999997	45.056862000000002	45.054926000000002	Васякина	0103000020E61000000100000005000000BAF770C971F744409DD9AED007874640BAF770C971F744404D31074147874640158BDF1456FA44404D31074147874640158BDF1456FA44409DD9AED007874640BAF770C971F744409DD9AED007874640
60242	818	41.924805999999997	41.935324999999999	45.065067999999997	45.063488999999997	Бруснева	0103000020E610000001000000050000008192020B60F64440EF535568208846408192020B60F644401002F22554884640CB10C7BAB8F744401002F22554884640CB10C7BAB8F74440EF535568208846408192020B60F64440EF53556820884640
5627	818	41.913091000000001	41.921624999999999	45.038361999999999	45.034477000000003	Ботанический проезд	0103000020E61000000100000005000000CFA2772AE0F444406BBB09BE69844640CFA2772AE0F444405FB4C70BE98446408716D9CEF7F544405FB4C70BE98446408716D9CEF7F544406BBB09BE69844640CFA2772AE0F444406BBB09BE69844640
60255	818	41.997892	42.012382000000002	45.033126000000003	45.024973000000003	Биологическая	0103000020E610000001000000050000005378D0ECBAFF44403A24B550328346405378D0ECBAFF4440DB5207793D8446409087BEBB95014540DB5207793D8446409087BEBB950145403A24B550328346405378D0ECBAFF44403A24B55032834640
60241	818	42.007657000000002	42.015040999999997	45.058414999999997	45.057561999999997	Бабушкина	0103000020E61000000100000005000000F14A92E7FA00454005BF0D315E874640F14A92E7FA004540444C89247A874640B08C0DDDEC014540444C89247A874640B08C0DDDEC01454005BF0D315E874640F14A92E7FA00454005BF0D315E874640
60246	818	41.887462999999997	42.134444999999999	45.121214999999999	44.968142999999998	50 Лет ВЛКСМ	0103000020E610000001000000050000007CB4386398F14440F86C1D1CEC7B46407CB4386398F144406F641EF9838F46402C0E677E351145406F641EF9838F46402C0E677E35114540F86C1D1CEC7B46407CB4386398F14440F86C1D1CEC7B4640
60237	818	41.887462999999997	42.134444999999999	45.121214999999999	44.968142999999998	50 Лет ВЛКСМ	0103000020E610000001000000050000007CB4386398F14440F86C1D1CEC7B46407CB4386398F144406F641EF9838F46402C0E677E351145406F641EF9838F46402C0E677E35114540F86C1D1CEC7B46407CB4386398F14440F86C1D1CEC7B4640
60223	818	41.905752	41.925047999999997	45.001078	44.998018000000002	45-я Параллель	0103000020E61000000100000005000000AF2479AEEFF34440E068C70DBF7F4640AF2479AEEFF344405F5FEB5223804640779D0DF967F644405F5FEB5223804640779D0DF967F64440E068C70DBF7F4640AF2479AEEFF34440E068C70DBF7F4640
60254	818	41.975453000000002	41.981048999999999	45.052582999999998	45.051672000000003	 Фрунзе	0103000020E610000001000000050000007EE4D6A4DBFC4440390F27309D8646407EE4D6A4DBFC4440ACA92C0ABB86464002637D0393FD4440ACA92C0ABB86464002637D0393FD4440390F27309D8646407EE4D6A4DBFC4440390F27309D864640
59935	818	41.935163000000003	42.027824000000003	45.033152000000001	45.024348000000003	 Серова	0103000020E61000000100000005000000F2B6D26BB3F744408CDCD3D51D834640F2B6D26BB3F7444004E621533E8446409F05A1BC8F03454004E621533E8446409F05A1BC8F0345408CDCD3D51D834640F2B6D26BB3F744408CDCD3D51D834640
60600	818	41.901781999999997	41.906291000000003	45.003576000000002	45.002875000000003	 Родосская	0103000020E610000001000000050000008C0FB3976DF34440EE7C3F355E8046408C0FB3976DF344407786A92D758046405FD4EE5701F444407786A92D758046405FD4EE5701F44440EE7C3F355E8046408C0FB3976DF34440EE7C3F355E804640
60240	818	41.938927	41.970861999999997	45.080376999999999	45.059275	 Октябрьская	0103000020E610000001000000050000006B2A8BC22EF84440363CBD52968746406B2A8BC22EF84440E02C25CB498A4640EE76BD3445FC4440E02C25CB498A4640EE76BD3445FC4440363CBD52968746406B2A8BC22EF84440363CBD5296874640
60239	818	41.963613000000002	41.982225999999997	45.022469000000001	45.017294999999997	 Мичурина	0103000020E610000001000000050000000F80B8AB57FB444031B1F9B8368246400F80B8AB57FB44404016A243E0824640F4A3E194B9FD44404016A243E0824640F4A3E194B9FD444031B1F9B8368246400F80B8AB57FB444031B1F9B836824640
60192	818	41.945413000000002	41.969676	45.042203000000001	45.03933	 Михаила Морозова	0103000020E610000001000000050000004C1B0E4B03F9444037E0F3C3088546404C1B0E4B03F9444084656CE866854640A9DBD9571EFC444084656CE866854640A9DBD9571EFC444037E0F3C3088546404C1B0E4B03F9444037E0F3C308854640
60151	818	42.028247	42.028596999999998	45.040661	45.035648999999999	 Мимоз	0103000020E61000000100000005000000E59A02999D0345404B917C2590844640E59A02999D034540809C306134854640C1E10511A9034540809C306134854640C1E10511A90345404B917C2590844640E59A02999D0345404B917C2590844640
60217	818	41.919991000000003	41.941217999999999	45.036878000000002	44.988674000000003	 Доваторцев	0103000020E61000000100000005000000A3CEDC43C2F54440E833A0DE8C7E4640A3CEDC43C2F5444090F8156BB88446400934D8D479F8444090F8156BB88446400934D8D479F84440E833A0DE8C7E4640A3CEDC43C2F54440E833A0DE8C7E4640
60230	818	41.954531000000003	41.962947999999997	45.024602999999999	45.022990999999998	 Абрамовой	0103000020E61000000100000005000000540262122EFA4440198D7C5EF1824640540262122EFA44401631EC3026834640D2DF4BE141FB44401631EC3026834640D2DF4BE141FB4440198D7C5EF1824640540262122EFA4440198D7C5EF1824640
59696	57588	43.015467999999998	43.073571000000001	44.030191000000002	44.016993999999997	Калинина	0103000020E610000001000000050000003811FDDAFA814540361D01DC2C0246403811FDDAFA81454018D1764CDD0346408E7747C66A89454018D1764CDD0346408E7747C66A894540361D01DC2C0246403811FDDAFA814540361D01DC2C024640
59642	57585	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Тургенева	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60110	57585	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Кузнечная	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59828	57585	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Гагарина	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59840	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	проспект Калинина	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59844	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Шоссейная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59936	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Школьная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59837	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Фучика	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59847	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Февральская	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59652	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Университетская	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60171	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Украинская	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59883	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Теплосерная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59659	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Советская	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60366	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Прогонная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59654	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Подстанционная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59932	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Пестова	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59925	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Панагюриште	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59689	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Нежнова	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60211	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Московская	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60187	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Мира	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60410	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Механизаторов	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60160	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Матвеева	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59698	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Маршала Жукова	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60546	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Лесная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60144	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Ленина	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59655	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Ленина	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60248	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Кучуры	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60250	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Куйбышева	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59704	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Крутой переулок	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60147	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Краснознаменная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59842	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Кочубея	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59661	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Комарова	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60162	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Коллективная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59890	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Кирова	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60188	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Калинина	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59653	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Зорге	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60124	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Железнодорожная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60163	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Ессентукская	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59964	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Ермолова	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60210	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Дзержинского	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
9886	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Бештаугорская	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59971	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Аллея Строителей	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59947	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	Адмиральского	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59766	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	5-й переулок	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59933	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	40 лет Октября	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60002	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	295 стрелковой дивизии	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
59658	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	1-я Набережная	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
9705	2177	42.953727000000001	43.098185000000001	44.078670000000002	44.027014999999999	 50 лет ВЛКСМ	0103000020E61000000100000005000000F627F1B9137A45402FC03E3A75034640F627F1B9137A45409296CADB110A464098FA7953918C45409296CADB110A464098FA7953918C45402FC03E3A75034640F627F1B9137A45402FC03E3A75034640
60064	57604	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	Комсомольская	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
59852	57596	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	 м-он № 2	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
60528	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	пер. Садовый	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59814	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	бульвар Мира	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59624	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Школьная	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59996	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Шевченко	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60077	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Чкалова	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59578	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Чапаева	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59874	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Чайковского	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60444	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Центральная	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60430	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Центральная	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59625	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Социалистическая	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59813	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Северная	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60412	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Садовая	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60092	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Революционная	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59623	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Пушкина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60094	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Павлова	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60447	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Молодежный переулок 	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60091	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Мичурина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59816	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Мира б-р	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60456	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Мира	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59855	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Менделеева	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59871	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Маяковского	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59626	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Матросова	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59875	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Луначарского	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59877	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Ленина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60305	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Ленина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60343	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Кумукова	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60342	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Королева	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59873	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Кооперативная	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59818	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Калинина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59876	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Зои Космодемьянской	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60428	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Гайнулина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59621	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Гагарина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60093	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Апанасенко	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59586	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	60 лет Октября	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59812	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	30 лет Победы	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60095	6327	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	 Ленина	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
59680	57587	41.956516000000001	42.094282	45.161014000000002	45.105764999999998	Транспортный пер	0103000020E61000000100000005000000E50CC51D6FFA4440DD0720B5898D4640E50CC51D6FFA44405D19541B9C944640FD4CBD6E110C45405D19541B9C944640FD4CBD6E110C4540DD0720B5898D4640E50CC51D6FFA4440DD0720B5898D4640
59991	57587	41.956516000000001	42.094282	45.161014000000002	45.105764999999998	Войкова	0103000020E61000000100000005000000E50CC51D6FFA4440DD0720B5898D4640E50CC51D6FFA44405D19541B9C944640FD4CBD6E110C45405D19541B9C944640FD4CBD6E110C4540DD0720B5898D4640E50CC51D6FFA4440DD0720B5898D4640
59865	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	проспект 22 партсъезда	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59866	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	пр-т К. Маркса	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59841	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	пр-т 22 партсъезда	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59612	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Фрунзе	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59577	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Толстого	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59804	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Ставропольская	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
60073	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Советская	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59614	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Пушкина	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59809	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Новоселов	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59995	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Новая	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59803	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Московская	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
60090	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Линейная	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59806	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Красная	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59613	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Калинина	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59864	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Железноводская	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
60086	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Желатиновая	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59616	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Дружбы	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59805	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Гагарина	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59810	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	Анджиевского	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59992	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	50 лет Октября	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59620	13776	43.096631000000002	43.178997000000003	44.232598000000003	44.165917999999998	5 км	0103000020E61000000100000005000000D06394675E8C4540ABE80FCD3C154640D06394675E8C4540B98E71C5C51D4640838AAA5FE9964540B98E71C5C51D4640838AAA5FE9964540ABE80FCD3C154640D06394675E8C4540ABE80FCD3C154640
59863	13776	43.096631000000002	43.178978999999998	44.233147000000002	44.165911999999999	 Ленина	0103000020E61000000100000005000000D06394675E8C4540C901BB9A3C154640D06394675E8C45408C14CAC2D71D4640DCD5ABC8E89645408C14CAC2D71D4640DCD5ABC8E8964540C901BB9A3C154640D06394675E8C4540C901BB9A3C154640
59860	19616	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	Химиков проезд	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
59610	19616	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	Решетника	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
59859	19616	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	Нагорная	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
59715	19616	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	Ленина	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
59611	19616	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	Комсомольская	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
59609	19616	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	Горняков	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
59807	19616	42.928896999999999	43.040467999999997	44.121026000000001	44.079557000000001	Гагарина	0103000020E610000001000000050000001F2DCE18E67645407D957CEC2E0A46401F2DCE18E67645409CFBABC77D0F46406B44300E2E8545409CFBABC77D0F46406B44300E2E8545407D957CEC2E0A46401F2DCE18E67645407D957CEC2E0A4640
60257	57620	43.102623000000001	43.178933999999998	44.055942000000002	44.036600999999997	Ленина	0103000020E61000000100000005000000A1681EC0228D45401D007157AF044640A1681EC0228D4540863C821B290746403C122F4FE7964540863C821B290746403C122F4FE79645401D007157AF044640A1681EC0228D45401D007157AF044640
60158	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	улица Горького	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60263	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	улица Вокзальная	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60075	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	проспект Победы	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60006	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	проезд Цандера	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60070	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	пр.Победы	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59811	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	пр.Мира	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60401	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	пр.Ленина	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59854	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	пер.Саперный	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59573	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Щербакова	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60071	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Школьная	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60177	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Чкалова	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60069	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Челюскинцев	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59782	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Чапаева	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60537	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Урицкого	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59785	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	У.Алиева	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59570	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Терская	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59784	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Седлогорская	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60375	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Пятигорская	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60551	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Прудная	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60493	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Профинтерна	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60003	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Островского	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60131	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Ольховская	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60000	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Октябрьская	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59574	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Одесская	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60023	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Нелюбина	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60005	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Набережная	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59703	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Ленинградская	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60165	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Кутузова	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60490	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Коминтерна	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59572	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Кирова	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60477	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	К.Цеткин	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59575	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Зеркальный переулок	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60559	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Дзержинского пр	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60524	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Герцена	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60355	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Б.Хмельницкого	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59795	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Андрея Губина	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59988	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	Авиации	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59571	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	8 Марта	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60016	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	40 лет Октября	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59706	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	 Ярошенко	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60216	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	 Мира	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
59990	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	 М.Расковой	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60193	10968	42.695416000000002	42.752746999999999	43.947479000000001	43.876010999999998	 Жуковского	0103000020E61000000100000005000000BD8E386403594540D7F7E12021F04540BD8E386403594540CA52EBFD46F94540C09481035A604540CA52EBFD46F94540C09481035A604540D7F7E12021F04540BD8E386403594540D7F7E12021F04540
60405	57586	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Степная	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59665	57586	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Советская	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59727	57586	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Первомайская	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59663	57586	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Мельничная	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59718	57586	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	З.Космодемьянской	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59956	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Юбилейная	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60207	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Энгельса	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
59551	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Шоссейная	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60203	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Чапаева	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
59556	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Суворова	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60587	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Спортивная	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60507	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Семашко	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60599	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Свободы	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60307	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Свободы	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60592	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Свердлова	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
59972	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Проскурина	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60278	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Октябрьская	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60538	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Лермонтова	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60531	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Ленина	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60155	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Космонавтов	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60040	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Колхозная	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60251	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Клары Цеткин	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60536	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Кирова	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60373	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	Глинки	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
59999	3652	42.983964	43.047080000000001	44.162232000000003	44.126668000000002	 Шоссейная	0103000020E610000001000000050000007E384888F27D454091B932A8361046407E384888F27D4540AE2EA704C4144640D925AAB706864540AE2EA704C4144640D925AAB70686454091B932A8361046407E384888F27D454091B932A836104640
60039	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Ямпольского	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59700	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Энгельса	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59961	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Шоссейная	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59765	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Чкалова	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60485	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Пятигорская	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60253	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Пушкина	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60464	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Привокзальная площадь	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59774	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Правды	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59767	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Первомайская	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59912	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Октябрьская,	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59549	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Октябрьская	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59963	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Оборонная	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59955	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Маркова	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60517	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Ленина	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59548	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Кисловодская	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60042	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Иглина	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59958	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Ермолова	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60038	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Долина Роз	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59950	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Гагарина	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59949	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Вокзальная	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60046	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Буачидзе	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60011	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Большая Боргустанская	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
59959	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Белоугольная	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60487	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Баталинская	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60518	1708	42.813490999999999	42.915574999999997	44.066099000000001	44.019879000000003	Анджиевского	0103000020E61000000100000005000000904B1C7920684540487023658B024640904B1C79206845402FA699EE750846408104C58F317545402FA699EE750846408104C58F31754540487023658B024640904B1C7920684540487023658B024640
60008	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Шоссейная	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59720	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Чугурина	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59927	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Урицкого	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
60050	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Тургенева/Гагарина	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59535	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Тургенева	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59697	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Тронина	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
60049	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Тимирязева	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59760	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Советская	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
60031	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Салогубова	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59684	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Пушкина	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
60149	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Луначарского	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59537	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Кочубея	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59753	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Кирова	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59534	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Калинина	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
60033	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Ермолова	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59929	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Дружбы	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59892	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Горийская/Пушкина	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59536	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Гагарина	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
60032	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Володарского	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59754	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	Быкова	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
59755	16251	43.434567999999999	43.493507000000001	44.180931000000001	44.117046000000002	 Батакская	0103000020E61000000100000005000000AEF199EC9FB745405610035DFB0E4640AEF199EC9FB7454092EA3BBF281746406DACC43C2BBF454092EA3BBF281746406DACC43C2BBF45405610035DFB0E4640AEF199EC9FB745405610035DFB0E4640
60170	57610	41.964637000000003	41.981920000000002	45.050894999999997	45.047508000000001	 Подгорная	0103000020E610000001000000050000007BC1A73979FB44403126FDBD148646407BC1A73979FB4440D44334BA83864640E8A4F78DAFFD4440D44334BA83864640E8A4F78DAFFD44403126FDBD148646407BC1A73979FB44403126FDBD14864640
60024	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	проспект Космонавтов	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59970	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	пер.Центральный	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59976	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	парк им. Гагарина	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
60030	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	микрорайон 8	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
60025	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	микрорайон 7Менделеева	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59761	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	микрорайон	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59921	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Пушкинская	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59917	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Прикумская	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59525	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Октябрьская	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59924	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Микрорайон 1МУП	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59691	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Льва Толстого	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59523	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Лопатина	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59783	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Кумская	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59533	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Кирова	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59748	25611	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	 Водопроводная	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59560	57578	44.110559000000002	44.195368999999999	44.826577	44.760365999999998	Менделеева	0103000020E61000000100000005000000A5A31CCC260E4640C37E4FAC53614640A5A31CCC260E46401A506F46CD6946407CD3F4D9011946401A506F46CD6946407CD3F4D901194640C37E4FAC53614640A5A31CCC260E4640C37E4FAC53614640
59717	57589	41.762579000000002	41.796652000000002	44.804895000000002	44.748959999999997	Первомайская	0103000020E61000000100000005000000E6CE4C309CE144408E01D9EBDD5F4640E6CE4C309CE1444062DBA2CC06674640812557B1F8E5444062DBA2CC06674640812557B1F8E544408E01D9EBDD5F4640E6CE4C309CE144408E01D9EBDD5F4640
60139	12540	42.117485000000002	42.167000000000002	44.892417000000002	44.870517	Школьная	0103000020E61000000100000005000000A2629CBF090F454057CEDE196D6F4640A2629CBF090F45407DB262B83A7246404C378941601545407DB262B83A7246404C3789416015454057CEDE196D6F4640A2629CBF090F454057CEDE196D6F4640
60496	11472	42.090885999999998	42.111763000000003	44.965586000000002	44.951853999999997	Подгорная	0103000020E6100000010000000500000006D50627A20B45408C48145AD679464006D50627A20B4540DCBC7152987B464091F3FE3F4E0E4540DCBC7152987B464091F3FE3F4E0E45408C48145AD679464006D50627A20B45408C48145AD6794640
60316	12354	41.919244999999997	41.929046	44.884115000000001	44.865214999999999	Невинномысская	0103000020E610000001000000050000007901F6D1A9F544401B81785DBF6E46407901F6D1A9F54440977329AE2A714640643DB5FAEAF64440977329AE2A714640643DB5FAEAF644401B81785DBF6E46407901F6D1A9F544401B81785DBF6E4640
59687	12482	42.017223999999999	42.084822000000003	44.883955999999998	44.832546999999998	Центральная	0103000020E61000000100000005000000685A62653402454003B16CE6906A4640685A6265340245402E8D5F78257146409CFD8172DB0A45402E8D5F78257146409CFD8172DB0A454003B16CE6906A4640685A62653402454003B16CE6906A4640
60411	11720	42.108089	42.144983000000003	45.084792999999998	45.076692000000001	Центральная	0103000020E61000000100000005000000570740DCD50D4540B3EE1F0BD1894640570740DCD50D454001F73C7FDA8A4640EDBC8DCD8E12454001F73C7FDA8A4640EDBC8DCD8E124540B3EE1F0BD1894640570740DCD50D4540B3EE1F0BD1894640
59789	12254	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Ленина	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59989	12254	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	З. Космодемьянской	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59747	12117	41.594962000000002	41.630535000000002	45.057746999999999	45.037036999999998	Пирогова	0103000020E610000001000000050000006F2EFEB627CC4440F8DEDFA0BD8446406F2EFEB627CC44409738F24064874640DFFDF15EB5D044409738F24064874640DFFDF15EB5D04440F8DEDFA0BD8446406F2EFEB627CC4440F8DEDFA0BD844640
60522	57675	41.748637000000002	41.765058000000003	44.987972999999997	44.97401	 Островского	0103000020E61000000100000005000000ACC95356D3DF44400DFD135CAC7C4640ACC95356D3DF44405E2A36E6757E464087C5A86BEDE144405E2A36E6757E464087C5A86BEDE144400DFD135CAC7C4640ACC95356D3DF44400DFD135CAC7C4640
60429	12156	41.659137999999999	41.668596999999998	45.023322999999998	45.012650000000001	Школьная	0103000020E6100000010000000500000082C64CA25ED44440AF25E4839E81464082C64CA25ED444404F1F813FFC824640139A249694D544404F1F813FFC824640139A249694D54440AF25E4839E81464082C64CA25ED44440AF25E4839E814640
60498	11718	42.117781999999998	42.135477999999999	45.296151999999999	45.270780000000002	Октябрьская	0103000020E610000001000000050000005B07077B130F4540983446EBA8A246405B07077B130F45408F52094FE8A54640EBA9D557571145408F52094FE8A54640EBA9D55757114540983446EBA8A246405B07077B130F4540983446EBA8A24640
59987	11999	41.970117000000002	42.050085000000003	45.252344000000001	45.184099000000003	Школьная	0103000020E6100000010000000500000096253ACB2CFC4440F81C588E9097464096253ACB2CFC4440C1ABE5CE4CA0464095826E2F69064540C1ABE5CE4CA0464095826E2F69064540F81C588E9097464096253ACB2CFC4440F81C588E90974640
59683	11999	41.970117000000002	42.050085000000003	45.252344000000001	45.184099000000003	Садовая	0103000020E6100000010000000500000096253ACB2CFC4440F81C588E9097464096253ACB2CFC4440C1ABE5CE4CA0464095826E2F69064540C1ABE5CE4CA0464095826E2F69064540F81C588E9097464096253ACB2CFC4440F81C588E90974640
59692	11999	41.970117000000002	42.050085000000003	45.252344000000001	45.184099000000003	Партизанская	0103000020E6100000010000000500000096253ACB2CFC4440F81C588E9097464096253ACB2CFC4440C1ABE5CE4CA0464095826E2F69064540C1ABE5CE4CA0464095826E2F69064540F81C588E9097464096253ACB2CFC4440F81C588E90974640
60397	12605	42.354443000000003	42.372489999999999	44.949621999999998	44.936990000000002	Школьная	0103000020E61000000100000005000000E8A562635E2D4540EB56CF49EF774640E8A562635E2D4540F3C7B4368D794640240B98C0AD2F4540F3C7B4368D794640240B98C0AD2F4540EB56CF49EF774640E8A562635E2D4540EB56CF49EF774640
59745	11903	41.787354000000001	41.837355000000002	45.146872000000002	45.121813000000003	Свердлова	0103000020E61000000100000005000000F92F1004C8E44440249D8191978F4640F92F1004C8E444405C59A2B3CC9246403012DA722EEB44405C59A2B3CC9246403012DA722EEB4440249D8191978F4640F92F1004C8E44440249D8191978F4640
59714	11321	41.838189999999997	41.891927000000003	45.180579000000002	45.150469999999999	Центральная	0103000020E61000000100000005000000C8EA56CF49EB4440BA83D89942934640C8EA56CF49EB444015AC71361D974640AFB5F7A92AF2444015AC71361D974640AFB5F7A92AF24440BA83D89942934640C8EA56CF49EB4440BA83D89942934640
59682	11781	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Раздольная	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
60585	11781	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Рабочая	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59994	11781	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Комсомольская	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59721	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Шпака	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59742	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Розы Люксембург	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
60143	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Пушкина	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
60191	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Орджоникидзе	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59679	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Октябрьская	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59979	10340	\N	\N	\N	\N	Новая	\N
60548	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Никонова	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59738	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Ленина	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
60137	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Кузьминовская	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59677	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Кирова	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
59733	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Гагарина	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
60020	10340	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	Вокзальная	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
60549	57681	42.069020999999999	42.082163000000001	44.822727999999998	44.808636	Лесная	0103000020E610000001000000050000005DDE1CAED5084540232F6B62816746405DDE1CAED508454072C0AE264F6946407BF83251840A454072C0AE264F6946407BF83251840A4540232F6B62816746405DDE1CAED5084540232F6B6281674640
60461	57657	42.217314999999999	42.257550000000002	45.215148999999997	45.202080000000002	Кавказская	0103000020E6100000010000000500000012F758FAD01B45407D96E7C1DD99464012F758FAD01B454030629F008A9B4640DB8AFD65F720454030629F008A9B4640DB8AFD65F72045407D96E7C1DD99464012F758FAD01B45407D96E7C1DD994640
59981	11658	42.193572000000003	42.214646999999999	45.315252000000001	45.280571999999999	Ленина	0103000020E61000000100000005000000EEB5A0F7C61845402F1686C8E9A34640EEB5A0F7C6184540D2FF722D5AA846409E978A8D791B4540D2FF722D5AA846409E978A8D791B45402F1686C8E9A34640EEB5A0F7C61845402F1686C8E9A34640
60566	11476	42.138145999999999	42.192458999999999	45.233305000000001	45.210101000000002	Кирова	0103000020E610000001000000050000005F09A4C4AE114540AFEDED96E49A46405F09A4C4AE114540247F30F0DC9D464012691B7FA2184540247F30F0DC9D464012691B7FA2184540AFEDED96E49A46405F09A4C4AE114540AFEDED96E49A4640
59681	11388	42.024383999999998	42.041542	44.989387999999998	44.977879999999999	переулок Школьный	0103000020E61000000100000005000000D845D1031F034540CCB4FD2B2B7D4640D845D1031F03454005871744A47E464089B48D3F5105454005871744A47E464089B48D3F51054540CCB4FD2B2B7D4640D845D1031F034540CCB4FD2B2B7D4640
60161	11342	41.594962000000002	42.385201000000002	45.341137000000003	44.782328	заезд Весенний	0103000020E610000001000000050000006F2EFEB627CC44405F5FEB52236446406F2EFEB627CC4440503A9160AAAB464079B130444E314540503A9160AAAB464079B130444E3145405F5FEB52236446406F2EFEB627CC44405F5FEB5223644640
60602	57685	41.844423999999997	41.874257	44.923243999999997	44.913944999999998	Шолохова	0103000020E610000001000000050000008FFAEB1516EC4440DEAB5626FC7446408FFAEB1516EC4440361D01DC2C76464048A643A7E7EF4440361D01DC2C76464048A643A7E7EF4440DEAB5626FC7446408FFAEB1516EC4440DEAB5626FC744640
60399	11577	42.279164000000002	42.296295000000001	45.248497999999998	45.236358000000003	Ленина	0103000020E610000001000000050000003B1C5DA5BB234540F1129CFA409E46403B1C5DA5BB2345408A8F4FC8CE9F4640F27B9BFEEC2545408A8F4FC8CE9F4640F27B9BFEEC254540F1129CFA409E46403B1C5DA5BB234540F1129CFA409E4640
60360	46379	43.527247000000003	43.547001000000002	45.619331000000003	45.610284999999998	Школьная	0103000020E6100000010000000500000002F566D47CC34540A31EA2D11DCE464002F566D47CC345401233FB3C46CF46408DF0F62004C645401233FB3C46CF46408DF0F62004C64540A31EA2D11DCE464002F566D47CC34540A31EA2D11DCE4640
60169	57608	43.689976999999999	43.716639000000001	45.422662000000003	45.404617000000002	Краснознаменская	0103000020E6100000010000000500000000FF942A51D84540EC33677DCAB3464000FF942A51D8454088A1D5C919B64640E204A6D3BADB454088A1D5C919B64640E204A6D3BADB4540EC33677DCAB3464000FF942A51D84540EC33677DCAB34640
60376	57642	43.415999999999997	43.427506999999999	45.416519000000001	45.404839000000003	Советская	0103000020E610000001000000050000006891ED7C3FB545409B92ACC3D1B346406891ED7C3FB54540D1949D7E50B54640D1E7A38CB8B64540D1949D7E50B54640D1E7A38CB8B645409B92ACC3D1B346406891ED7C3FB545409B92ACC3D1B34640
60572	10099	43.769351999999998	43.781219	45.321747999999999	45.308951999999998	Западная	0103000020E610000001000000050000005C8E57207AE24540530438BD8BA746405C8E57207AE24540D6C6D8092FA94640C501F4FBFEE34540D6C6D8092FA94640C501F4FBFEE34540530438BD8BA746405C8E57207AE24540530438BD8BA74640
60595	10202	43.579763	43.59975	45.301782000000003	45.284244000000001	Победы	0103000020E6100000010000000500000026378AAC35CA4540C80A7E1B62A4464026378AAC35CA4540C042E6CAA0A6464054E3A59BC4CC4540C042E6CAA0A6464054E3A59BC4CC4540C80A7E1B62A4464026378AAC35CA4540C80A7E1B62A44640
60362	57636	43.824427999999997	43.847020999999998	45.505173999999997	45.500625999999997	Мира	0103000020E610000001000000050000000EF450DB86E945407EC3448314C046400EF450DB86E945400E65A88AA9C046403A03232F6BEC45400E65A88AA9C046403A03232F6BEC45407EC3448314C046400EF450DB86E945407EC3448314C04640
60497	48160	43.249882999999997	43.265011000000001	45.424230999999999	45.420068000000001	Набережная	0103000020E61000000100000005000000C669882AFC9F45404E0CC9C9C4B54640C669882AFC9F454085798F334DB64640460A65E1EBA1454085798F334DB64640460A65E1EBA145404E0CC9C9C4B54640C669882AFC9F45404E0CC9C9C4B54640
59820	26077	43.298347999999997	43.341304999999998	45.386060999999998	45.351627000000001	Красная	0103000020E61000000100000005000000DB696B4430A64540FFB1101D02AD4640DB696B4430A645406AA164726AB146400B7BDAE1AFAB45406AA164726AB146400B7BDAE1AFAB4540FFB1101D02AD4640DB696B4430A64540FFB1101D02AD4640
60435	135	43.770178999999999	43.787624000000001	45.580669999999998	45.570860000000003	Школьная	0103000020E610000001000000050000007288B83995E245401B4CC3F011C946407288B83995E2454058E2016553CA4640B9C5FCDCD0E4454058E2016553CA4640B9C5FCDCD0E445401B4CC3F011C946407288B83995E245401B4CC3F011C94640
59636	28935	42.984493999999998	43.047313000000003	45.452784000000001	45.431776999999997	Пионерская	0103000020E61000000100000005000000DA8D3EE6037E45401E15FF7744B74640DA8D3EE6037E454077137CD3F4B946407CD6355A0E86454077137CD3F4B946407CD6355A0E8645401E15FF7744B74640DA8D3EE6037E45401E15FF7744B74640
59716	4357	43.424148000000002	43.463521	45.444248000000002	45.415640000000003	Советская	0103000020E61000000100000005000000F8544E7B4AB64540697407B133B54640F8544E7B4AB645401EA8531EDDB846402E01F8A754BB45401EA8531EDDB846402E01F8A754BB4540697407B133B54640F8544E7B4AB64540697407B133B54640
60138	10041	43.663980000000002	43.710242999999998	45.383629999999997	45.352381000000001	Стадионная	0103000020E610000001000000050000005B99F04BFDD44540AB5D13D21AAD46405B99F04BFDD44540DAE1AFC91AB14640419B1C3EE9DA4540DAE1AFC91AB14640419B1C3EE9DA4540AB5D13D21AAD46405B99F04BFDD44540AB5D13D21AAD4640
60196	57615	43.552247000000001	43.581290000000003	45.325791000000002	45.308881999999997	Горького	0103000020E6100000010000000500000035289A07B0C645405A29047289A7464035289A07B0C64540632AFD84B3A94640F5BEF1B567CA4540632AFD84B3A94640F5BEF1B567CA45405A29047289A7464035289A07B0C645405A29047289A74640
59942	5710	43.889052999999997	43.906759000000001	45.580159000000002	45.566374000000003	Школьная	0103000020E6100000010000000500000091B41B7DCCF1454001A777F17EC8464091B41B7DCCF1454073BD6DA642CA4640452DCDAD10F4454073BD6DA642CA4640452DCDAD10F4454001A777F17EC8464091B41B7DCCF1454001A777F17EC84640
60511	57670	43.377820999999997	43.395589999999999	45.343449999999997	45.327883	Степная	0103000020E61000000100000005000000FA5E43705CB045400AF5F411F8A94640FA5E43705CB04540D5E76A2BF6AB4640F44F70B1A2B24540D5E76A2BF6AB4640F44F70B1A2B245400AF5F411F8A94640FA5E43705CB045400AF5F411F8A94640
60336	7758	43.789411999999999	43.830492	45.479016999999999	45.451892999999998	Ленина	0103000020E61000000100000005000000F488D1730BE545404A253CA1D7B94640F488D1730BE54540309DD66D50BD464079CBD58F4DEA4540309DD66D50BD464079CBD58F4DEA45404A253CA1D7B94640F488D1730BE545404A253CA1D7B94640
59632	49222	43.035384000000001	43.088366000000001	45.398308	45.360075999999999	Свободы	0103000020E610000001000000050000009D6681768784454089096AF816AE46409D668176878445401ADEACC1FBB24640070ABC934F8B45401ADEACC1FBB24640070ABC934F8B454089096AF816AE46409D6681768784454089096AF816AE4640
59639	29550	43.199568999999997	43.261831000000001	45.516018000000003	45.493575	Ленина	0103000020E61000000100000005000000D0251C7A8B994540C58F31772DBF4640D0251C7A8B994540DC12B9E00CC246401C0A9FAD83A14540DC12B9E00CC246401C0A9FAD83A14540C58F31772DBF4640D0251C7A8B994540C58F31772DBF4640
60481	47683	43.327120999999998	43.340406999999999	45.482998000000002	45.473050999999998	Советская	0103000020E61000000100000005000000DB6AD619DFA94540882B67EF8CBC4640DB6AD619DFA945404704E3E0D2BD46402C2AE27492AB45404704E3E0D2BD46402C2AE27492AB4540882B67EF8CBC4640DB6AD619DFA94540882B67EF8CBC4640
59975	9307	42.071472999999997	42.181814000000003	45.521576000000003	45.460003999999998	ленина	0103000020E6100000010000000500000004C6FA0626094540BC033C69E1BA464004C6FA062609454073309B00C3C246403CFA5FAE4517454073309B00C3C246403CFA5FAE45174540BC033C69E1BA464004C6FA0626094540BC033C69E1BA4640
60136	9307	42.071472999999997	42.181814000000003	45.521576000000003	45.460003999999998	Ленина	0103000020E6100000010000000500000004C6FA0626094540BC033C69E1BA464004C6FA062609454073309B00C3C246403CFA5FAE4517454073309B00C3C246403CFA5FAE45174540BC033C69E1BA464004C6FA0626094540BC033C69E1BA4640
60554	9307	42.071472999999997	42.181814000000003	45.521576000000003	45.460003999999998	Гагарина	0103000020E6100000010000000500000004C6FA0626094540BC033C69E1BA464004C6FA062609454073309B00C3C246403CFA5FAE4517454073309B00C3C246403CFA5FAE45174540BC033C69E1BA464004C6FA0626094540BC033C69E1BA4640
60395	9894	42.243572999999998	42.253076999999998	45.433743999999997	45.420423	Спортивная	0103000020E6100000010000000500000024986A662D1F45403CBEBD6BD0B5464024986A662D1F4540096B63EC84B74640552FBFD364204540096B63EC84B74640552FBFD3642045403CBEBD6BD0B5464024986A662D1F45403CBEBD6BD0B54640
60473	9737	42.322417999999999	42.338802999999999	45.594816999999999	45.588403	Советская	0103000020E6100000010000000500000024D236FE4429454024EF1CCA50CB464024D236FE442945406B0DA5F622CC4640B2648EE55D2B45406B0DA5F622CC4640B2648EE55D2B454024EF1CCA50CB464024D236FE4429454024EF1CCA50CB4640
59946	6563	42.082199000000003	42.122956000000002	45.773080999999998	45.739181000000002	Садовая	0103000020E61000000100000005000000C861307F850A45408C69A67B9DDE4640C861307F850A454059147651F4E246406A6CAF05BD0F454059147651F4E246406A6CAF05BD0F45408C69A67B9DDE4640C861307F850A45408C69A67B9DDE4640
60415	9810	42.272894000000001	42.285451999999999	45.559527000000003	45.547826000000001	Зои Комодемьянской	0103000020E6100000010000000500000027A3CA30EE22454002F390291FC6464027A3CA30EE224540501DAB949EC74640F549EEB089244540501DAB949EC74640F549EEB08924454002F390291FC6464027A3CA30EE22454002F390291FC64640
60484	9887	42.321879000000003	42.329343999999999	45.497202000000001	45.486221	Луговая	0103000020E610000001000000050000007522C1543329454070D05E7D3CBE46407522C15433294540BEC0AC50A4BF46402191B6F1272A4540BEC0AC50A4BF46402191B6F1272A454070D05E7D3CBE46407522C1543329454070D05E7D3CBE4640
60475	8960	41.963244000000003	41.977257999999999	45.534455999999999	45.514471	Невдахина	0103000020E61000000100000005000000BC0853944BFB4440C6DE8B2FDAC14640BC0853944BFB44405393E00D69C446408FE046CA16FD44405393E00D69C446408FE046CA16FD4440C6DE8B2FDAC14640BC0853944BFB4440C6DE8B2FDAC14640
60540	9229	42.086025999999997	42.118572	45.369309000000001	45.348396999999999	Ленина	0103000020E61000000100000005000000874D64E6020B45402383DC4598AC4640874D64E6020B45402A8F6E8445AF4640541C075E2D0F45402A8F6E8445AF4640541C075E2D0F45402383DC4598AC4640874D64E6020B45402383DC4598AC4640
59678	9730	42.239871999999998	42.253185000000002	45.514843999999997	45.491824999999999	Комарова	0103000020E61000000100000005000000F19C2D20B41E4540772D211FF4BE4640F19C2D20B41E45405A457F68E6C146403C6BB75D682045405A457F68E6C146403C6BB75D68204540772D211FF4BE4640F19C2D20B41E4540772D211FF4BE4640
59675	8965	41.932898999999999	42.019891999999999	45.496139999999997	45.383541000000001	Трунова	0103000020E610000001000000050000004DBC033C69F744406BD619DF17B146404DBC033C69F74440641EF98381BF4640DCB930D28B024540641EF98381BF4640DCB930D28B0245406BD619DF17B146404DBC033C69F744406BD619DF17B14640
59671	8965	41.932898999999999	42.019891999999999	45.496139999999997	45.383541000000001	Садовая	0103000020E610000001000000050000004DBC033C69F744406BD619DF17B146404DBC033C69F74440641EF98381BF4640DCB930D28B024540641EF98381BF4640DCB930D28B0245406BD619DF17B146404DBC033C69F744406BD619DF17B14640
60571	8965	41.932898999999999	42.019891999999999	45.496139999999997	45.383541000000001	Пролетарская	0103000020E610000001000000050000004DBC033C69F744406BD619DF17B146404DBC033C69F74440641EF98381BF4640DCB930D28B024540641EF98381BF4640DCB930D28B0245406BD619DF17B146404DBC033C69F744406BD619DF17B14640
59673	8965	41.932898999999999	42.019891999999999	45.496139999999997	45.383541000000001	Первомайская	0103000020E610000001000000050000004DBC033C69F744406BD619DF17B146404DBC033C69F74440641EF98381BF4640DCB930D28B024540641EF98381BF4640DCB930D28B0245406BD619DF17B146404DBC033C69F744406BD619DF17B14640
59763	8965	41.932898999999999	42.019891999999999	45.496139999999997	45.383541000000001	Ленина	0103000020E610000001000000050000004DBC033C69F744406BD619DF17B146404DBC033C69F74440641EF98381BF4640DCB930D28B024540641EF98381BF4640DCB930D28B0245406BD619DF17B146404DBC033C69F744406BD619DF17B14640
59672	8965	41.932898999999999	42.019891999999999	45.496139999999997	45.383541000000001	Комарова	0103000020E610000001000000050000004DBC033C69F744406BD619DF17B146404DBC033C69F74440641EF98381BF4640DCB930D28B024540641EF98381BF4640DCB930D28B0245406BD619DF17B146404DBC033C69F744406BD619DF17B14640
60486	9487	41.901386000000002	41.968139999999998	45.680349999999997	45.588169999999998	переулок Степной	0103000020E610000001000000050000004089CF9D60F34440813E912749CB46404089CF9D60F34440B3EA73B515D7464087F9F202ECFB4440B3EA73B515D7464087F9F202ECFB4440813E912749CB46404089CF9D60F34440813E912749CB4640
60338	9487	41.901386000000002	41.968139999999998	45.680349999999997	45.588169999999998	Ставропольская	0103000020E610000001000000050000004089CF9D60F34440813E912749CB46404089CF9D60F34440B3EA73B515D7464087F9F202ECFB4440B3EA73B515D7464087F9F202ECFB4440813E912749CB46404089CF9D60F34440813E912749CB4640
60313	9487	41.901386000000002	41.968139999999998	45.680349999999997	45.588169999999998	Партизанская	0103000020E610000001000000050000004089CF9D60F34440813E912749CB46404089CF9D60F34440B3EA73B515D7464087F9F202ECFB4440B3EA73B515D7464087F9F202ECFB4440813E912749CB46404089CF9D60F34440813E912749CB4640
59730	9487	41.901386000000002	41.968139999999998	45.680349999999997	45.588169999999998	Ленина 	0103000020E610000001000000050000004089CF9D60F34440813E912749CB46404089CF9D60F34440B3EA73B515D7464087F9F202ECFB4440B3EA73B515D7464087F9F202ECFB4440813E912749CB46404089CF9D60F34440813E912749CB4640
59676	9487	41.901386000000002	41.968139999999998	45.680349999999997	45.588169999999998	Ленина	0103000020E610000001000000050000004089CF9D60F34440813E912749CB46404089CF9D60F34440B3EA73B515D7464087F9F202ECFB4440B3EA73B515D7464087F9F202ECFB4440813E912749CB46404089CF9D60F34440813E912749CB4640
60440	8217	44.800331	44.807381999999997	44.197335000000002	44.178429000000001	Лысенко	0103000020E61000000100000005000000CC7C073F7166464039D4EFC2D6164640CC7C073F7166464097ADF5454219464085B01A4B5867464097ADF5454219464085B01A4B5867464039D4EFC2D6164640CC7C073F7166464039D4EFC2D6164640
60150	8770	44.538229000000001	44.619149	44.288981999999997	44.253844000000001	пл. Ленина	0103000020E61000000100000005000000206118B0E44446409624CFF57D204640206118B0E4444640FB90B75CFD244640F12C4146404F4640FB90B75CFD244640F12C4146404F46409624CFF57D204640206118B0E44446409624CFF57D204640
60576	8770	44.538229000000001	44.619149	44.288981999999997	44.253844000000001	Садовая	0103000020E61000000100000005000000206118B0E44446409624CFF57D204640206118B0E4444640FB90B75CFD244640F12C4146404F4640FB90B75CFD244640F12C4146404F46409624CFF57D204640206118B0E44446409624CFF57D204640
59728	8770	44.538229000000001	44.619149	44.288981999999997	44.253844000000001	Додонова	0103000020E61000000100000005000000206118B0E44446409624CFF57D204640206118B0E4444640FB90B75CFD244640F12C4146404F4640FB90B75CFD244640F12C4146404F46409624CFF57D204640206118B0E44446409624CFF57D204640
60135	8698	44.314467999999998	44.387284999999999	44.223922999999999	44.204689999999999	Административная пл	0103000020E61000000100000005000000BBD1C77C40284640BCE82B48331A4640BBD1C77C402846403EE94482A91C46409D9D0C8E923146403EE94482A91C46409D9D0C8E92314640BCE82B48331A4640BBD1C77C40284640BCE82B48331A4640
59977	8600	44.387779000000002	44.422158000000003	44.346916999999998	44.317767000000003	Шоссейная	0103000020E61000000100000005000000AD8905BEA2314640C05FCC96AC284640AD8905BEA231464095B6B8C6672C464055DFF9450936464095B6B8C6672C464055DFF94509364640C05FCC96AC284640AD8905BEA2314640C05FCC96AC284640
60597	8499	44.324601000000001	44.332056999999999	44.105291999999999	44.093587999999997	Мира	0103000020E61000000100000005000000DC9F8B868C29464026A60BB1FA0B4640DC9F8B868C294640E54350357A0D464035B401D8802A4640E54350357A0D464035B401D8802A464026A60BB1FA0B4640DC9F8B868C29464026A60BB1FA0B4640
60459	8373	44.352781	44.365861000000002	44.388989000000002	44.374597000000001	Центральная	0103000020E6100000010000000500000039D384ED272D4640011764CBF22F464039D384ED272D46407BC03C64CA314640E1F08288D42E46407BC03C64CA314640E1F08288D42E4640011764CBF22F464039D384ED272D4640011764CBF22F4640
60403	8595	44.688786999999998	44.708595000000003	44.358666999999997	44.350720000000003	Мира	0103000020E610000001000000050000007974232C2A584640CD069964E42C46407974232C2A584640C493DDCCE82D4640F88DAF3DB35A4640C493DDCCE82D4640F88DAF3DB35A4640CD069964E42C46407974232C2A584640CD069964E42C4640
60564	8367	44.259877000000003	44.291094000000001	44.439990000000002	44.421799	Шоссейная	0103000020E61000000100000005000000C6FD47A643214640253E7782FD354640C6FD47A6432146409548A29751384640EA077591422546409548A29751384640EA07759142254640253E7782FD354640C6FD47A643214640253E7782FD354640
60133	8504	44.729418000000003	44.767111	44.371524000000001	44.335526000000002	Молодежная	0103000020E610000001000000050000008F8EAB915D5D4640967A1684F22A46408F8EAB915D5D4640EDD632198E2F464070B378B130624640EDD632198E2F464070B378B130624640967A1684F22A46408F8EAB915D5D4640967A1684F22A4640
60331	8661	44.424475999999999	44.446269000000001	44.298886000000003	44.281070999999997	пер. Школьный	0103000020E61000000100000005000000ECF7C43A55364640506D7022FA234640ECF7C43A55364640BB9D7DE541264640FC1BB4571F394640BB9D7DE541264640FC1BB4571F394640506D7022FA234640ECF7C43A55364640506D7022FA234640
59670	8432	44.413597000000003	44.438319	44.197187	44.180374999999998	пл. Ленина	0103000020E61000000100000005000000A35C1ABFF03446400C022B8716174640A35C1ABFF03446402219726C3D194640931B45D61A3846402219726C3D194640931B45D61A3846400C022B8716174640A35C1ABFF03446400C022B8716174640
60312	8306	44.292530999999997	44.380718999999999	44.470320999999998	44.450653000000003	Школьный пер	0103000020E610000001000000050000007808E3A771254640126C5CFFAE3946407808E3A7712546409ECF807A333C4640A0FB7266BB3046409ECF807A333C4640A0FB7266BB304640126C5CFFAE3946407808E3A771254640126C5CFFAE394640
60311	8210	44.717129	44.733164000000002	44.152338	44.133623999999998	Мира	0103000020E61000000100000005000000B00111E2CA5B4640F8FA5A971A114640B00111E2CA5B464012F8C3CF7F134640624D6551D85D464012F8C3CF7F134640624D6551D85D4640F8FA5A971A114640B00111E2CA5B4640F8FA5A971A114640
59669	7756	43.706847000000003	43.789250000000003	44.287931	44.250047000000002	Пролетарская	0103000020E610000001000000050000004B2366F679DA454041BB438A012046404B2366F679DA454096404AECDA2446401B2FDD2406E5454096404AECDA2446401B2FDD2406E5454041BB438A012046404B2366F679DA454041BB438A01204640
59724	7756	43.706847000000003	43.789250000000003	44.287931	44.250047000000002	Ленина пл	0103000020E610000001000000050000004B2366F679DA454041BB438A012046404B2366F679DA454096404AECDA2446401B2FDD2406E5454096404AECDA2446401B2FDD2406E5454041BB438A012046404B2366F679DA454041BB438A01204640
59674	7756	43.706847000000003	43.789250000000003	44.287931	44.250047000000002	Культурная	0103000020E610000001000000050000004B2366F679DA454041BB438A012046404B2366F679DA454096404AECDA2446401B2FDD2406E5454096404AECDA2446401B2FDD2406E5454041BB438A012046404B2366F679DA454041BB438A01204640
60308	7756	43.706847000000003	43.789250000000003	44.287931	44.250047000000002	25 партсъезда	0103000020E610000001000000050000004B2366F679DA454041BB438A012046404B2366F679DA454096404AECDA2446401B2FDD2406E5454096404AECDA2446401B2FDD2406E5454041BB438A012046404B2366F679DA454041BB438A01204640
60148	7756	43.706847000000003	43.789250000000003	44.287931	44.250047000000002	17 партсъезда	0103000020E610000001000000050000004B2366F679DA454041BB438A012046404B2366F679DA454096404AECDA2446401B2FDD2406E5454096404AECDA2446401B2FDD2406E5454041BB438A012046404B2366F679DA454041BB438A01204640
60334	7630	44.009704999999997	44.048360000000002	44.508755000000001	44.488675999999998	Шоссейная	0103000020E61000000100000005000000C8CD70033E014640882B67EF8C3E4640C8CD70033E014640975643E21E414640A03715A930064640975643E21E414640A03715A930064640882B67EF8C3E4640C8CD70033E014640882B67EF8C3E4640
59960	7683	44.072758	44.104469000000002	44.386380000000003	44.371324000000001	Ленина	0103000020E61000000100000005000000DD42572250094640261C7A8B872F4640DD425722500946400CEA5BE67431464011397D3D5F0D46400CEA5BE67431464011397D3D5F0D4640261C7A8B872F4640DD42572250094640261C7A8B872F4640
59723	7637	43.825631999999999	43.872047999999999	44.352440999999999	44.304563000000002	Мостовая	0103000020E61000000100000005000000FA43334FAEE945402C499EEBFB264640FA43334FAEE94540806264C91C2D46406745D4449FEF4540806264C91C2D46406745D4449FEF45402C499EEBFB264640FA43334FAEE945402C499EEBFB264640
60619	7508	43.916936	43.970709999999997	44.502949999999998	44.469079000000001	Октябрьская	0103000020E610000001000000050000003543AA285EF54540C51EDAC70A3C46403543AA285EF54540F8C264AA6040464038F3AB3940FC4540F8C264AA6040464038F3AB3940FC4540C51EDAC70A3C46403543AA285EF54540C51EDAC70A3C4640
60132	7508	43.916936	43.970709999999997	44.502949999999998	44.469079000000001	Кирова	0103000020E610000001000000050000003543AA285EF54540C51EDAC70A3C46403543AA285EF54540F8C264AA6040464038F3AB3940FC4540F8C264AA6040464038F3AB3940FC4540C51EDAC70A3C46403543AA285EF54540C51EDAC70A3C4640
60340	8045	43.703451999999999	43.729241999999999	44.224479000000002	44.211713000000003	Шоссейная	0103000020E61000000100000005000000242713B70ADA4540AC915D69191B4640242713B70ADA4540C4D155BABB1C4640506F46CD57DD4540C4D155BABB1C4640506F46CD57DD4540AC915D69191B4640242713B70ADA4540AC915D69191B4640
60521	57668	44.171950000000002	44.200749999999999	44.239643999999998	44.227553999999998	Школьная	0103000020E610000001000000050000000B4625750216464078094E7D201D46400B46257502164640605793A7AC1E464004560E2DB2194640605793A7AC1E464004560E2DB219464078094E7D201D46400B4625750216464078094E7D201D4640
60442	57651	43.78642	43.807009999999998	44.255980999999998	44.241962999999998	пер.1-й Ленинский	0103000020E61000000100000005000000CD751A69A9E44540C8EBC1A4F81E4640CD751A69A9E44540DDB243FCC3204640C1C58A1A4CE74540DDB243FCC3204640C1C58A1A4CE74540C8EBC1A4F81E4640CD751A69A9E44540C8EBC1A4F81E4640
60404	57646	43.772298999999997	43.782522	44.377715000000002	44.369242999999997	Фестивальная	0103000020E61000000100000005000000E3DD91B1DAE2454072A3C85A432F4640E3DD91B1DAE24540B51A12F75830464044334FAE29E44540B51A12F75830464044334FAE29E4454072A3C85A432F4640E3DD91B1DAE2454072A3C85A432F4640
60129	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	площадь Ленина	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
60125	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	пл.Ленина	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
60128	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	пл.1 Мая	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59957	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Семенова	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59701	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Пугачева	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59954	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Ленина	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59666	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Кумской пер	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
75119	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Крайнева	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
9822	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	Ессентукская	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
59667	6603	43.829062999999998	43.915031999999997	44.436585000000001	44.373494999999998	50 лет Октября	0103000020E610000001000000050000006DA983BC1EEA4540191C25AFCE2F46406DA983BC1EEA45404B766C04E23746409065C1C41FF545404B766C04E23746409065C1C41FF54540191C25AFCE2F46406DA983BC1EEA4540191C25AFCE2F4640
60130	6499	43.949536000000002	44.004809999999999	44.283000999999999	44.255083999999997	Октябрьская	0103000020E61000000100000005000000F52F49658AF94540CEDDAE97A6204640F52F49658AF945401EDE736039244640CD58349D9D0046401EDE736039244640CD58349D9D004640CEDDAE97A6204640F52F49658AF94540CEDDAE97A6204640
60134	6406	44.174743999999997	44.204577	44.323152	44.308408	Октябрьская	0103000020E610000001000000050000000B96EA025E16464092E9D0E9792746400B96EA025E16464089D1730B5D294640C44142942F1A464089D1730B5D294640C44142942F1A464092E9D0E9792746400B96EA025E16464092E9D0E979274640
60323	8122	43.614635	43.637425999999998	44.230913000000001	44.221390999999997	Школьная	0103000020E610000001000000050000000DFD135CACCE45407A50508A561C46400DFD135CACCE4540529CA38E8E1D46405FCFD72C97D14540529CA38E8E1D46405FCFD72C97D145407A50508A561C46400DFD135CACCE45407A50508A561C4640
59872	4599	43.015467999999998	43.073571000000001	44.030191000000002	44.016993999999997	Энгельса	0103000020E610000001000000050000003811FDDAFA814540361D01DC2C0246403811FDDAFA81454018D1764CDD0346408E7747C66A89454018D1764CDD0346408E7747C66A894540361D01DC2C0246403811FDDAFA814540361D01DC2C024640
60096	4599	43.015467999999998	43.073571000000001	44.030191000000002	44.016993999999997	Пащенко	0103000020E610000001000000050000003811FDDAFA814540361D01DC2C0246403811FDDAFA81454018D1764CDD0346408E7747C66A89454018D1764CDD0346408E7747C66A894540361D01DC2C0246403811FDDAFA814540361D01DC2C024640
59868	57598	43.015467999999998	43.073571000000001	44.030191000000002	44.016993999999997	Энгельса	0103000020E610000001000000050000003811FDDAFA814540361D01DC2C0246403811FDDAFA81454018D1764CDD0346408E7747C66A89454018D1764CDD0346408E7747C66A894540361D01DC2C0246403811FDDAFA814540361D01DC2C024640
59907	2411	43.197978999999997	43.226491000000003	44.084251999999999	44.068463000000001	Зубалова	0103000020E61000000100000005000000BB2539605799454037FE4465C3084640BB25396057994540B14F00C5C80A46404FEB36A8FD9C4540B14F00C5C80A46404FEB36A8FD9C454037FE4465C3084640BB2539605799454037FE4465C3084640
60194	57614	43.102623000000001	43.178933999999998	44.055942000000002	44.036600999999997	Октябрьская	0103000020E61000000100000005000000A1681EC0228D45401D007157AF044640A1681EC0228D4540863C821B290746403C122F4FE7964540863C821B290746403C122F4FE79645401D007157AF044640A1681EC0228D45401D007157AF044640
59657	3540	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	Советская	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
59836	3540	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	Ленина	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
59930	3540	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	Кабардинская	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
59845	3540	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	Георгиевская	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
59693	3540	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	8-я линия	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
60127	57595	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	Советской Армии	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
59931	57595	43.070894000000003	43.126679000000003	44.041007	44.003073999999998	Больничная	0103000020E61000000100000005000000C7BDF90D13894540E4BB94BA64004640C7BDF90D138945401BF4A5B73F054640850B7904379045401BF4A5B73F054640850B790437904540E4BB94BA64004640C7BDF90D13894540E4BB94BA64004640
59922	1982	42.727037000000003	42.767937000000003	44.032330000000002	44.017797999999999	Спортивная	0103000020E61000000100000005000000B1FD648C0F5D454094F7713447024640B1FD648C0F5D45400057B26323044640B63176C24B6245400057B26323044640B63176C24B62454094F7713447024640B1FD648C0F5D454094F7713447024640
60004	1749	42.944546000000003	43.031520999999998	43.985999	43.934887000000003	Почтовый переулок	0103000020E61000000100000005000000A8C821E2E6784540503A9160AAF74540A8C821E2E6784540C171193735FE4540901150E108844540C171193735FE4540901150E108844540503A9160AAF74540A8C821E2E6784540503A9160AAF74540
60118	1749	42.944546000000003	43.031520999999998	43.985999	43.934887000000003	Луценко	0103000020E61000000100000005000000A8C821E2E6784540503A9160AAF74540A8C821E2E6784540C171193735FE4540901150E108844540C171193735FE4540901150E108844540503A9160AAF74540A8C821E2E6784540503A9160AAF74540
59713	1749	42.944546000000003	43.031520999999998	43.985999	43.934887000000003	Канищева	0103000020E61000000100000005000000A8C821E2E6784540503A9160AAF74540A8C821E2E6784540C171193735FE4540901150E108844540C171193735FE4540901150E108844540503A9160AAF74540A8C821E2E6784540503A9160AAF74540
59650	1589	43.006610999999999	43.107024000000003	43.925479000000003	43.909745999999998	50 лет Октября	0103000020E610000001000000050000009D6516A1D88045405AD5928E72F445409D6516A1D880454041118B1876F645408DF161F6B28D454041118B1876F645408DF161F6B28D45405AD5928E72F445409D6516A1D88045405AD5928E72F44540
60306	1357	42.757714	42.770363000000003	44.121381999999997	44.109642000000001	переулок Садовый	0103000020E6100000010000000500000055DCB8C5FC6045404F22C2BF080E464055DCB8C5FC6045405A290472890F4640348639419B6245405A290472890F4640348639419B6245404F22C2BF080E464055DCB8C5FC6045404F22C2BF080E4640
60281	1517	43.131027000000003	43.150708999999999	43.937469999999998	43.923285	Кирова	0103000020E610000001000000050000004EF2237EC590454095F1EF332EF645404EF2237EC5904540957D5704FFF745403F1BB96E4A934540957D5704FFF745403F1BB96E4A93454095F1EF332EF645404EF2237EC590454095F1EF332EF64540
60116	894	42.587825000000002	42.730117999999997	44.210084999999999	44.158805000000001	Шоссейная	0103000020E61000000100000005000000B7627FD93D4B45407CB8E4B853144640B7627FD93D4B4540A930B610E41A4640471CB281745D4540A930B610E41A4640471CB281745D45407CB8E4B853144640B7627FD93D4B45407CB8E4B853144640
59664	894	42.587825000000002	42.730117999999997	44.210084999999999	44.158805000000001	Советская	0103000020E61000000100000005000000B7627FD93D4B45407CB8E4B853144640B7627FD93D4B4540A930B610E41A4640471CB281745D4540A930B610E41A4640471CB281745D45407CB8E4B853144640B7627FD93D4B45407CB8E4B853144640
60117	894	42.587825000000002	42.730117999999997	44.210084999999999	44.158805000000001	Нагорная	0103000020E61000000100000005000000B7627FD93D4B45407CB8E4B853144640B7627FD93D4B4540A930B610E41A4640471CB281745D4540A930B610E41A4640471CB281745D45407CB8E4B853144640B7627FD93D4B45407CB8E4B853144640
59904	894	42.587825000000002	42.730117999999997	44.210084999999999	44.158805000000001	Карла Маркса	0103000020E61000000100000005000000B7627FD93D4B45407CB8E4B853144640B7627FD93D4B4540A930B610E41A4640471CB281745D4540A930B610E41A4640471CB281745D45407CB8E4B853144640B7627FD93D4B45407CB8E4B853144640
59649	894	42.587825000000002	42.730117999999997	44.210084999999999	44.158805000000001	Заводская	0103000020E61000000100000005000000B7627FD93D4B45407CB8E4B853144640B7627FD93D4B4540A930B610E41A4640471CB281745D4540A930B610E41A4640471CB281745D45407CB8E4B853144640B7627FD93D4B45407CB8E4B853144640
60328	1177	42.761532000000003	42.774019000000003	44.165272000000002	44.143664000000001	Гагарина	0103000020E61000000100000005000000C26D6DE17961454068CEFA9463124640C26D6DE179614540E67805A227154640C7BDF90D13634540E67805A227154640C7BDF90D1363454068CEFA9463124640C26D6DE17961454068CEFA9463124640
60557	1296	42.844078000000003	42.867021000000001	44.081409000000001	44.070186	Тельмана	0103000020E61000000100000005000000F5A276BF0A6C45408B51D7DAFB084640F5A276BF0A6C4540CF4C309C6B0A4640FDF84B8BFA6E4540CF4C309C6B0A4640FDF84B8BFA6E45408B51D7DAFB084640F5A276BF0A6C45408B51D7DAFB084640
60120	1938	42.950699999999998	42.995831000000003	44.019308000000002	44.012754000000001	Мира	0103000020E610000001000000050000005227A089B079454054724EECA10146405227A089B07945408D463EAF78024640E7ABE463777F45408D463EAF78024640E7ABE463777F454054724EECA10146405227A089B079454054724EECA1014640
60115	652	43.245885999999999	43.275809000000002	43.991278000000001	43.964441999999998	Красноармейская	0103000020E61000000100000005000000AA454431799F4540C571E0D572FB4540AA454431799F4540459F8F32E2FE4540A37895B54DA34540459F8F32E2FE4540A37895B54DA34540C571E0D572FB4540AA454431799F4540C571E0D572FB4540
60452	57655	42.935023999999999	42.947591000000003	44.010550000000002	44.000455000000002	Школьная	0103000020E61000000100000005000000D07CCEDDAE774540520FD1E80E004640D07CCEDDAE774540857CD0B359014640F27D71A94A794540857CD0B359014640F27D71A94A794540520FD1E80E004640D07CCEDDAE774540520FD1E80E004640
59858	443	42.753869999999999	42.787852999999998	43.989994000000003	43.947764999999997	Крупской	0103000020E61000000100000005000000BFB7E9CF7E6045408FA50F5D50F94540BFB7E9CF7E6045403D9E961FB8FE45401A87FA5DD86445403D9E961FB8FE45401A87FA5DD86445408FA50F5D50F94540BFB7E9CF7E6045408FA50F5D50F94540
60460	1474	42.635596999999997	42.665295999999998	44.056077999999999	44.049962000000001	Кубанская	0103000020E61000000100000005000000C537143E5B5145407905A22765064640C537143E5B51454036035C902D0746406E14596B2855454036035C902D0746406E14596B285545407905A22765064640C537143E5B5145407905A22765064640
59694	396	42.865412999999997	42.893099999999997	44.161695999999999	44.127018	Ленина	0103000020E6100000010000000500000041446ADAC56E45406D0036204210464041446ADAC56E45406FF25B74B21446405F07CE19517245406FF25B74B21446405F07CE19517245406D0036204210464041446ADAC56E45406D00362042104640
60458	768	43.363214999999997	43.386606999999998	44.013137	43.993988999999999	Шоссейная	0103000020E61000000100000005000000543541D47DAE4540B8CA13083BFF4540543541D47DAE45400CAF2479AE014640CCB392567CB145400CAF2479AE014640CCB392567CB14540B8CA13083BFF4540543541D47DAE4540B8CA13083BFF4540
59647	179	42.621125999999997	42.687348999999998	43.950665999999998	43.934958000000002	Шоссейная	0103000020E61000000100000005000000FF58880E814F4540199128B4ACF74540FF58880E814F4540A6B5696CAFF945401AF8510DFB574540A6B5696CAFF945401AF8510DFB574540199128B4ACF74540FF58880E814F4540199128B4ACF74540
60434	1404	42.698380999999998	42.718099000000002	44.101692999999997	44.089120999999999	Якорная	0103000020E61000000100000005000000EA92718C6459454083312251680B4640EA92718C64594540B69DB646040D4640292504ABEA5B4540B69DB646040D4640292504ABEA5B454083312251680B4640EA92718C6459454083312251680B4640
60122	32237	42.845236999999997	42.897205	44.038972000000001	44.012605000000001	Юцкий переулок	0103000020E61000000100000005000000402FDCB9306C45400F62670A9D014640402FDCB9306C4540D8BAD408FD04464062670A9DD7724540D8BAD408FD04464062670A9DD77245400F62670A9D014640402FDCB9306C45400F62670A9D014640
60112	32237	42.845236999999997	42.897205	44.038972000000001	44.012605000000001	Этокская	0103000020E61000000100000005000000402FDCB9306C45400F62670A9D014640402FDCB9306C4540D8BAD408FD04464062670A9DD7724540D8BAD408FD04464062670A9DD77245400F62670A9D014640402FDCB9306C45400F62670A9D014640
59908	32237	42.845236999999997	42.897205	44.038972000000001	44.012605000000001	Садовое Кольцо	0103000020E61000000100000005000000402FDCB9306C45400F62670A9D014640402FDCB9306C4540D8BAD408FD04464062670A9DD7724540D8BAD408FD04464062670A9DD77245400F62670A9D014640402FDCB9306C45400F62670A9D014640
59648	32237	42.845236999999997	42.897205	44.038972000000001	44.012605000000001	Гагарина	0103000020E61000000100000005000000402FDCB9306C45400F62670A9D014640402FDCB9306C4540D8BAD408FD04464062670A9DD7724540D8BAD408FD04464062670A9DD77245400F62670A9D014640402FDCB9306C45400F62670A9D014640
59835	32237	42.845236999999997	42.897205	44.038972000000001	44.012605000000001	 Гагарина	0103000020E61000000100000005000000402FDCB9306C45400F62670A9D014640402FDCB9306C4540D8BAD408FD04464062670A9DD7724540D8BAD408FD04464062670A9DD77245400F62670A9D014640402FDCB9306C45400F62670A9D014640
59651	1707	43.013061	43.042237999999998	43.996298000000003	43.984994	Ореховая	0103000020E6100000010000000500000031ED9BFBAB814540CC608C4814FE454031ED9BFBAB814540FD885FB186FF45400053060E68854540FD885FB186FF45400053060E68854540CC608C4814FE454031ED9BFBAB814540CC608C4814FE4540
59685	13717	42.939515	42.978555999999998	44.093938000000001	44.064233000000002	Ленина	0103000020E61000000100000005000000FC8C0B0742784540782975C938084640FC8C0B074278454003ED0E29060C4640FCA6B052417D454003ED0E29060C4640FCA6B052417D4540782975C938084640FC8C0B0742784540782975C938084640
60466	696	43.314399999999999	43.336077000000003	43.988185000000001	43.977359	Зеленая	0103000020E6100000010000000500000063EE5A423EA84540C3B986191AFD454063EE5A423EA84540EAB298D87CFE45400AF8359204AB4540EAB298D87CFE45400AF8359204AB4540C3B986191AFD454063EE5A423EA84540C3B986191AFD4540
59833	580	42.93497	42.973418000000002	44.18777	44.174064999999999	Кошевого	0103000020E61000000100000005000000DD5ED218AD7745406A300DC347164640DD5ED218AD774540C095ECD8081846403BAB05F6987C4540C095ECD8081846403BAB05F6987C45406A300DC347164640DD5ED218AD7745406A300DC347164640
59834	31982	42.495908999999997	42.566507999999999	44.066941	44.036782000000002	Кооперативная	0103000020E61000000100000005000000626534F2793F45406E8AC745B5044640626534F2793F45407AE1CE859108464010768A55834845407AE1CE859108464010768A55834845406E8AC745B5044640626534F2793F45406E8AC745B5044640
59897	31982	42.495908999999997	42.566507999999999	44.066941	44.036782000000002	Буденного	0103000020E61000000100000005000000626534F2793F45406E8AC745B5044640626534F2793F45407AE1CE859108464010768A55834845407AE1CE859108464010768A55834845406E8AC745B5044640626534F2793F45406E8AC745B5044640
60598	13675	42.394039999999997	42.471673000000003	44.132964000000001	44.091898	Московская	0103000020E610000001000000050000006DA818E76F324540AE484C50C30B46406DA818E76F324540CEC5DFF604114640FFB3E6C75F3C4540CEC5DFF604114640FFB3E6C75F3C4540AE484C50C30B46406DA818E76F324540AE484C50C30B4640
60109	31434	42.845965	42.923858000000003	45.426437999999997	45.391858999999997	Ленина	0103000020E61000000100000005000000C347C494486C454056D28A6F28B24640C347C494486C4540C5E2378595B64640F1129CFA40764540C5E2378595B64640F1129CFA4076454056D28A6F28B24640C347C494486C454056D28A6F28B24640
59645	31310	42.644832000000001	42.686791999999997	45.540219999999998	45.512103000000003	60 лет Октября	0103000020E6100000010000000500000007B5DFDA895245407D9752978CC1464007B5DFDA895245409352D0ED25C54640C493DDCCE85745409352D0ED25C54640C493DDCCE85745407D9752978CC1464007B5DFDA895245407D9752978CC14640
60114	31663	42.954230000000003	43.033650000000002	45.171371999999998	45.141441999999998	Красная	0103000020E61000000100000005000000596E6935247A4540F2237EC51A924640596E6935247A45409DB98784EF95464055C1A8A44E8445409DB98784EF95464055C1A8A44E844540F2237EC51A924640596E6935247A4540F2237EC51A924640
60282	57622	42.827917999999997	42.866042	45.272993	45.252051999999999	Курортная	0103000020E6100000010000000500000086E28E37F969454019726C3D43A0464086E28E37F9694540BA84436FF1A24640317BD976DA6E4540BA84436FF1A24640317BD976DA6E454019726C3D43A0464086E28E37F969454019726C3D43A04640
59887	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	площадь Выставочная	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60145	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	площадь 50-лет Октября	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59831	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Транспортная	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59878	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Садовая	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60146	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Матросова	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60104	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Малыгина	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60103	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Комсомольская	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59891	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Коминтерна	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59884	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Кисличанская	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60565	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Горная	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59731	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Выставочная площадь	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59641	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Высотная	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
59838	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	Бассейная	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60580	13588	42.802612000000003	42.938473000000002	45.366149	45.281275999999998	60 лет Октября	0103000020E6100000010000000500000047B071FDBB66454029931ADA00A4464047B071FDBB664540473B6EF8DDAE4640EA961DE21F784540473B6EF8DDAE4640EA961DE21F78454029931ADA00A4464047B071FDBB66454029931ADA00A44640
60108	31525	43.017767999999997	43.069349000000003	45.214711000000001	45.187973999999997	Первомайская	0103000020E610000001000000050000002975C93846824540C83F33880F9846402975C93846824540B58B69A67B9B46405281936DE0884540B58B69A67B9B46405281936DE0884540C83F33880F9846402975C93846824540C83F33880F984640
60503	31527	43.120499000000002	43.141097000000002	45.197940000000003	45.182650000000002	Пролетарская	0103000020E61000000100000005000000B119E0826C8F4540A54E401361974640B119E0826C8F4540FE4811195699464028486C770F924540FE4811195699464028486C770F924540A54E401361974640B119E0826C8F4540A54E401361974640
60113	31934	42.833640000000003	42.860922000000002	45.131219000000002	45.113965	Мира	0103000020E6100000010000000500000098512CB7B46A4540BFF1B567968E464098512CB7B46A454092CEC0C8CB90464016342DB1326E454092CEC0C8CB90464016342DB1326E4540BFF1B567968E464098512CB7B46A4540BFF1B567968E4640
59899	31321	42.803249999999998	42.824226000000003	45.484104000000002	45.473669999999998	Почтовая	0103000020E61000000100000005000000894160E5D0664540548CF337A1BC4640894160E5D066454070EEAF1EF7BD4640A741D13C8069454070EEAF1EF7BD4640A741D13C80694540548CF337A1BC4640894160E5D0664540548CF337A1BC4640
59646	31797	42.926426999999997	42.963068999999997	45.054690000000001	45.014135000000003	Толстого	0103000020E61000000100000005000000D190F128957645404F5DF92CCF814640D190F1289576454089B5F814008746404D6551D8457B454089B5F814008746404D6551D8457B45404F5DF92CCF814640D190F128957645404F5DF92CCF814640
60413	30928	42.722940999999999	42.766005999999997	45.447043000000001	45.438859999999998	Урожайная	0103000020E6100000010000000500000001F8A754895C4540E3C281902CB8464001F8A754895C4540EF737CB438B9464017450F7C0C624540EF737CB438B9464017450F7C0C624540E3C281902CB8464001F8A754895C4540E3C281902CB84640
59898	31366	42.847949999999997	42.893351000000003	45.476874000000002	45.449648000000003	Шоссейная	0103000020E61000000100000005000000545227A0896C45401D5BCF108EB94640545227A0896C454007280D350ABD4640A96C58535972454007280D350ABD4640A96C5853597245401D5BCF108EB94640545227A0896C45401D5BCF108EB94640
60454	31135	42.649979000000002	42.681564000000002	45.230341000000003	45.214005999999998	Железнодорожная	0103000020E610000001000000050000001C0B0A8332534540EA92718C649B46401C0B0A8332534540C7F65AD07B9D4640C310397D3D574540C7F65AD07B9D4640C310397D3D574540EA92718C649B46401C0B0A8332534540EA92718C649B4640
59926	31022	42.595092000000001	42.666922	45.316215999999997	45.281098999999998	Октябрьская	0103000020E610000001000000050000003D0E83F92B4C45401AF8510DFBA346403D0E83F92B4C4540683C11C479A84640D07D39B35D554540683C11C479A84640D07D39B35D5545401AF8510DFBA346403D0E83F92B4C45401AF8510DFBA34640
59893	31022	42.595092000000001	42.666922	45.316215999999997	45.281098999999998	Ленина	0103000020E610000001000000050000003D0E83F92B4C45401AF8510DFBA346403D0E83F92B4C4540683C11C479A84640D07D39B35D554540683C11C479A84640D07D39B35D5545401AF8510DFBA346403D0E83F92B4C45401AF8510DFBA34640
59643	31022	42.595092000000001	42.666922	45.316215999999997	45.281098999999998	Ледовского	0103000020E610000001000000050000003D0E83F92B4C45401AF8510DFBA346403D0E83F92B4C4540683C11C479A84640D07D39B35D554540683C11C479A84640D07D39B35D5545401AF8510DFBA346403D0E83F92B4C45401AF8510DFBA34640
59711	31884	42.852065000000003	42.897483000000001	45.212513999999999	45.176653000000002	Ленина	0103000020E610000001000000050000007B884677106D4540C2DEC4909C9646407B884677106D454098F8A3A8339B4640A5DB12B9E072454098F8A3A8339B4640A5DB12B9E0724540C2DEC4909C9646407B884677106D4540C2DEC4909C964640
60111	31666	43.005560000000003	43.067382000000002	45.091214000000001	45.063986	Советская	0103000020E610000001000000050000003815A930B680454070B378B1308846403815A930B6804540FB777DE6AC8B4640672B2FF99F884540FB777DE6AC8B4640672B2FF99F88454070B378B1308846403815A930B680454070B378B130884640
59644	31666	43.005560000000003	43.067382000000002	45.091214000000001	45.063986	Ленина	0103000020E610000001000000050000003815A930B680454070B378B1308846403815A930B6804540FB777DE6AC8B4640672B2FF99F884540FB777DE6AC8B4640672B2FF99F88454070B378B1308846403815A930B680454070B378B130884640
60391	31614	43.129770000000001	43.144016999999998	45.335631999999997	45.32479	Степная	0103000020E610000001000000050000003F00A94D9C904540AF08FEB792A946403F00A94D9C904540DBBE47FDF5AA4640B58828266F924540DBBE47FDF5AA4640B58828266F924540AF08FEB792A946403F00A94D9C904540AF08FEB792A94640
59832	31796	42.871513	42.925628000000003	45.036025000000002	45.011719999999997	Центральная	0103000020E61000000100000005000000F984ECBC8D6F4540C45A7C0A80814640F984ECBC8D6F4540516B9A779C844640862172FA7A764540516B9A779C844640862172FA7A764540C45A7C0A80814640F984ECBC8D6F4540C45A7C0A80814640
60106	31209	42.557740000000003	42.613363999999997	45.421770000000002	45.375134000000003	Советская	0103000020E61000000100000005000000E5D539066447454010CF126404B04640E5D53906644745408B37328FFCB54640994528B6824E45408B37328FFCB54640994528B6824E454010CF126404B04640E5D539066447454010CF126404B04640
60126	31209	42.557740000000003	42.613363999999997	45.421770000000002	45.375134000000003	Петровская	0103000020E61000000100000005000000E5D539066447454010CF126404B04640E5D53906644745408B37328FFCB54640994528B6824E45408B37328FFCB54640994528B6824E454010CF126404B04640E5D539066447454010CF126404B04640
60332	29603	43.438808000000002	43.472737000000002	44.890022999999999	44.878227000000003	Школьная	0103000020E61000000100000005000000919C4CDC2AB845406BBB09BE69704640919C4CDC2AB845400AD80E46EC714640F94D61A582BC45400AD80E46EC714640F94D61A582BC45406BBB09BE69704640919C4CDC2AB845406BBB09BE69704640
59870	29381	43.673735999999998	43.745403000000003	44.736367000000001	44.697276000000002	Ленина	0103000020E61000000100000005000000A51133FB3CD645409224085740594640A51133FB3CD64540446D1B46415E46408FAB915D69DF4540446D1B46415E46408FAB915D69DF45409224085740594640A51133FB3CD645409224085740594640
59824	29381	43.673735999999998	43.745403000000003	44.736367000000001	44.697276000000002	Карла Маркса пер	0103000020E61000000100000005000000A51133FB3CD645409224085740594640A51133FB3CD64540446D1B46415E46408FAB915D69DF4540446D1B46415E46408FAB915D69DF45409224085740594640A51133FB3CD645409224085740594640
59640	29734	43.129078	43.183982999999998	44.851534999999998	44.836261	Красная	0103000020E610000001000000050000000951BEA085904540CBF5B6990A6B46400951BEA0859045401E335019FF6C46408E0244C18C9745401E335019FF6C46408E0244C18C974540CBF5B6990A6B46400951BEA085904540CBF5B6990A6B4640
60352	29833	43.173751000000003	43.224649999999997	44.832017	44.808897999999999	Школьная	0103000020E61000000100000005000000DB5207793D96454060E63BF889674640DB5207793D964540A75B76887F6A4640F085C954C19C4540A75B76887F6A4640F085C954C19C454060E63BF889674640DB5207793D96454060E63BF889674640
59637	29284	43.398446999999997	43.470995000000002	44.769627	44.737462000000001	Шоссейная	0103000020E610000001000000050000003B18B14F00B345407905A227655E46403B18B14F00B345402E8F3523836246402ECA6C9049BC45402E8F3523836246402ECA6C9049BC45407905A227655E46403B18B14F00B345407905A227655E4640
59829	29284	43.398446999999997	43.470995000000002	44.769627	44.737462000000001	Школьная	0103000020E610000001000000050000003B18B14F00B345407905A227655E46403B18B14F00B345402E8F3523836246402ECA6C9049BC45402E8F3523836246402ECA6C9049BC45407905A227655E46403B18B14F00B345407905A227655E4640
60099	29284	43.398446999999997	43.470995000000002	44.769627	44.737462000000001	Ставропольская	0103000020E610000001000000050000003B18B14F00B345407905A227655E46403B18B14F00B345402E8F3523836246402ECA6C9049BC45402E8F3523836246402ECA6C9049BC45407905A227655E46403B18B14F00B345407905A227655E4640
59826	29567	43.296039	43.353090999999999	44.793253999999997	44.774214999999998	Ленина	0103000020E6100000010000000500000097AB1F9BE4A545404C89247A1963464097AB1F9BE4A54540E9B5D9588965464087C1FC1532AD4540E9B5D9588965464087C1FC1532AD45404C89247A1963464097AB1F9BE4A545404C89247A19634640
60101	29657	43.268675999999999	43.327579	44.857976000000001	44.829389999999997	Шоссейная	0103000020E610000001000000050000002C9CA4F963A2454091D09673296A46402C9CA4F963A245405F605628D26D46409EEDD11BEEA945405F605628D26D46409EEDD11BEEA9454091D09673296A46402C9CA4F963A2454091D09673296A4640
60451	29843	43.138294999999999	43.157698000000003	44.774304000000001	44.763547000000003	Веселая	0103000020E61000000100000005000000A4198BA6B3914540BEFA78E8BB614640A4198BA6B3914540BC94BA641C6346408352B4722F944540BC94BA641C6346408352B4722F944540BEFA78E8BB614640A4198BA6B3914540BEFA78E8BB614640
60102	29470	43.335951000000001	43.418559999999999	44.615499999999997	44.597248999999998	Байрамова	0103000020E610000001000000050000007D073F7100AB4540CB48BDA7724C46407D073F7100AB4540105839B4C84E4640F6B4C35F93B54540105839B4C84E4640F6B4C35F93B54540CB48BDA7724C46407D073F7100AB4540CB48BDA7724C4640
60393	29731	43.345419	43.366053999999998	44.857911999999999	44.843725999999997	Веселая	0103000020E61000000100000005000000613596B036AC45407764AC36FF6B4640613596B036AC4540486C770FD06D4640F54883DBDAAE4540486C770FD06D4640F54883DBDAAE45407764AC36FF6B4640613596B036AC45407764AC36FF6B4640
60432	28570	41.165208	41.203592999999998	45.417366999999999	45.399979000000002	Заречная	0103000020E61000000100000005000000CF842689259544401C0B0A8332B34640CF84268925954440FEB627486CB54640E658DE550F9A4440FEB627486CB54640E658DE550F9A44401C0B0A8332B34640CF842689259544401C0B0A8332B34640
60279	28032	41.168882000000004	41.247790000000002	45.356712999999999	45.338337000000003	Ленина	0103000020E610000001000000050000000971E5EC9D9544406D0377A04EAB46400971E5EC9D9544406E8786C5A8AD46404F232D95B79F44406E8786C5A8AD46404F232D95B79F44406D0377A04EAB46400971E5EC9D9544406D0377A04EAB4640
60499	27657	41.285527999999999	41.301122999999997	45.412742000000001	45.403756999999999	Центральная	0103000020E61000000100000005000000D00B772E8CA44440FA43334FAEB34640D00B772E8CA44440C3D7D7BAD4B446406589CE328BA64440C3D7D7BAD4B446406589CE328BA64440FA43334FAEB34640D00B772E8CA44440FA43334FAEB34640
59635	28858	41.021845999999996	41.058945999999999	45.457545000000003	45.434654999999999	Момотова	0103000020E6100000010000000500000032C687D9CB8244407D0569C6A2B7464032C687D9CB82444063B9A5D590BA4640711DE38A8B87444063B9A5D590BA4640711DE38A8B8744407D0569C6A2B7464032C687D9CB8244407D0569C6A2B74640
59825	27426	41.304034000000001	41.331890000000001	45.555065999999997	45.538502999999999	оветская	0103000020E61000000100000005000000A06F0B96EAA6444021E692AAEDC44640A06F0B96EAA644408E8F16670CC746404AEF1B5F7BAA44408E8F16670CC746404AEF1B5F7BAA444021E692AAEDC44640A06F0B96EAA6444021E692AAEDC44640
60433	27940	41.331710999999999	41.361148999999997	45.256112999999999	45.242660000000001	Южная	0103000020E610000001000000050000009A5C8C8175AA444010069E7B0F9F46409A5C8C8175AA44404C8A8F4FC8A04640D6FD63213AAE44404C8A8F4FC8A04640D6FD63213AAE444010069E7B0F9F46409A5C8C8175AA444010069E7B0F9F4640
60491	27846	41.471164999999999	41.481352000000001	45.268895999999998	45.254786000000003	Степная	0103000020E610000001000000050000008A027D224FBC444045BDE0D39CA046408A027D224FBC44403A03232F6BA246409EEE3CF19CBD44403A03232F6BA246409EEE3CF19CBD444045BDE0D39CA046408A027D224FBC444045BDE0D39CA04640
60154	29031	41.001041000000001	41.068027999999998	45.606723000000002	45.556277000000001	Советская	0103000020E61000000100000005000000427A8A1C228044402D42B11534C74640427A8A1C22804440925D6919A9CD46402C9B3924B5884440925D6919A9CD46402C9B3924B58844402D42B11534C74640427A8A1C228044402D42B11534C74640
59638	29031	41.001041000000001	41.068027999999998	45.606723000000002	45.556277000000001	Ленина	0103000020E61000000100000005000000427A8A1C228044402D42B11534C74640427A8A1C22804440925D6919A9CD46402C9B3924B5884440925D6919A9CD46402C9B3924B58844402D42B11534C74640427A8A1C228044402D42B11534C74640
60388	29197	41.182167999999997	41.204490999999997	45.646014999999998	45.625666000000002	Красная	0103000020E610000001000000050000005930F147519744400D1CD0D215D046405930F14751974440DBDC989EB0D24640C5A9D6C22C9A4440DBDC989EB0D24640C5A9D6C22C9A44400D1CD0D215D046405930F147519744400D1CD0D215D04640
59888	27989	41.279958999999998	41.313448000000001	45.341904	45.319960999999999	Ленина	0103000020E61000000100000005000000459C4EB2D5A344406B7F677BF4A84640459C4EB2D5A34440902FA182C3AB4640917F66101FA84440902FA182C3AB4640917F66101FA844406B7F677BF4A84640459C4EB2D5A344406B7F677BF4A84640
60105	28946	40.90025	40.911605000000002	45.581659999999999	45.562246999999999	Ленина	0103000020E61000000100000005000000AC1C5A643B73444016A3AEB5F7C74640AC1C5A643B73444018B2BAD573CA46405FEFFE78AF74444018B2BAD573CA46405FEFFE78AF74444016A3AEB5F7C74640AC1C5A643B73444016A3AEB5F7C74640
60327	27768	41.382007000000002	41.402112000000002	45.279209000000002	45.266618000000001	Молодежная	0103000020E61000000100000005000000EAEBF99AE5B044403143E38920A24640EAEBF99AE5B04440DBDFD91EBDA3464022AAF06778B34440DBDFD91EBDA3464022AAF06778B344403143E38920A24640EAEBF99AE5B044403143E38920A24640
60304	27576	41.297440000000002	41.322189000000002	45.458126999999998	45.446424	Школьная	0103000020E61000000100000005000000D942908312A644402313F06B24B94640D942908312A644401135D1E7A3BA4640C310397D3DA944401135D1E7A3BA4640C310397D3DA944402313F06B24B94640D942908312A644402313F06B24B94640
60431	46644	41.030298999999999	41.060195	45.427532999999997	45.415101999999997	Школьная	0103000020E61000000100000005000000FE0C6FD6E08344408940F50F22B54640FE0C6FD6E0834440FA7ABE66B9B64640FD304278B4874440FA7ABE66B9B64640FD304278B48744408940F50F22B54640FE0C6FD6E08344408940F50F22B54640
60533	46644	41.030298999999999	41.060195	45.427532999999997	45.415101999999997	Широкая	0103000020E61000000100000005000000FE0C6FD6E08344408940F50F22B54640FE0C6FD6E0834440FA7ABE66B9B64640FD304278B4874440FA7ABE66B9B64640FD304278B48744408940F50F22B54640FE0C6FD6E08344408940F50F22B54640
59823	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	пер.Красноармейский	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
60152	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	пер. Энгельса	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
59889	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Тургенева	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
59886	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Советская	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
59634	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Мичурина	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
59885	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Лермонтова	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
59633	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Ленина	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
59822	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Калинина	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
59882	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Железнодорожная	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
60553	15684	41.175009000000003	41.267068000000002	45.516227000000001	45.472880000000004	Ворошилова	0103000020E61000000100000005000000BAC0E5B1669644405C77F35487BC4640BAC0E5B166964440F627F1B913C2464071E7C2482FA24440F627F1B913C2464071E7C2482FA244405C77F35487BC4640BAC0E5B1669644405C77F35487BC4640
60390	27483	41.350485999999997	41.382708000000001	45.495066000000001	45.482480000000002	Центральная	0103000020E6100000010000000500000059DAA9B9DCAC4440AF7C96E7C1BD464059DAA9B9DCAC444047AE9B525EBF464073F56393FCB0444047AE9B525EBF464073F56393FCB04440AF7C96E7C1BD464059DAA9B9DCAC4440AF7C96E7C1BD4640
60450	29023	40.917749000000001	40.922528	45.548690999999998	45.532682000000001	Карла Маркса	0103000020E61000000100000005000000E6779ACC787544407D957CEC2EC44640E6779ACC78754440054EB6813BC6464078D2C26515764440054EB6813BC6464078D2C265157644407D957CEC2EC44640E6779ACC787544407D957CEC2EC44640
60387	28100	41.202559999999998	41.213915	45.287211999999997	45.280673999999998	Социалистическая	0103000020E6100000010000000500000027BD6F7CED994440336B2920EDA3464027BD6F7CED9944406682E15CC3A44640DA8F1491619B44406682E15CC3A44640DA8F1491619B4440336B2920EDA3464027BD6F7CED994440336B2920EDA34640
59843	28512	41.124792999999997	41.163986000000001	45.455415000000002	45.425021999999998	Ленина	0103000020E6100000010000000500000086E28E37F98F44404E0AF31E67B6464086E28E37F98F4440CE8DE9094BBA46403D80457EFD944440CE8DE9094BBA46403D80457EFD9444404E0AF31E67B6464086E28E37F98F44404E0AF31E67B64640
60354	27713	41.355111999999998	41.384289000000003	45.368251000000001	45.355103999999997	Юбилейный переулок	0103000020E6100000010000000500000065355D4F74AD4440E256410C74AD464065355D4F74AD444012DC48D922AF4640359BC76130B1444012DC48D922AF4640359BC76130B14440E256410C74AD464065355D4F74AD4440E256410C74AD4640
60453	28107	41.206701000000002	41.230947	45.398744999999998	45.386194000000003	Калинина	0103000020E610000001000000050000007786A92D759A4440AAF413CE6EB146407786A92D759A4440C5387F130AB34640FE0DDAAB8F9D4440C5387F130AB34640FE0DDAAB8F9D4440AAF413CE6EB146407786A92D759A4440AAF413CE6EB14640
60389	28375	41.008380000000002	41.038491999999998	45.362437999999997	45.347763	Заводская	0103000020E6100000010000000500000062F888981281444022E17B7F83AC464062F8889812814440F0694E5E64AE46402D944C4EED844440F0694E5E64AE46402D944C4EED84444022E17B7F83AC464062F888981281444022E17B7F83AC4640
59827	27673	41.340487000000003	41.371550999999997	45.440739000000001	45.388737999999996	Красная	0103000020E6100000010000000500000049DBF81395AB4440315BB22AC2B1464049DBF81395AB44402F89B3226AB84640E6E5B0FB8EAF44402F89B3226AB84640E6E5B0FB8EAF4440315BB22AC2B1464049DBF81395AB4440315BB22AC2B14640
60492	29196	41.282366000000003	41.300080999999999	45.647658999999997	45.637419999999999	Восточная	0103000020E610000001000000050000004DC0AF9124A444407DE882FA96D146404DC0AF9124A44440E3FA777DE6D246405393E00D69A64440E3FA777DE6D246405393E00D69A644407DE882FA96D146404DC0AF9124A444407DE882FA96D14640
60098	28188	41.030506000000003	41.085545000000003	45.323238000000003	45.276100999999997	Шмидта	0103000020E61000000100000005000000782AE09EE78344404AB20E4757A34640782AE09EE78344408869DFDC5FA946400DAB7823F38A44408869DFDC5FA946400DAB7823F38A44404AB20E4757A34640782AE09EE78344404AB20E4757A34640
60121	28188	41.030506000000003	41.085545000000003	45.323238000000003	45.276100999999997	Тимирязева	0103000020E61000000100000005000000782AE09EE78344404AB20E4757A34640782AE09EE78344408869DFDC5FA946400DAB7823F38A44408869DFDC5FA946400DAB7823F38A44404AB20E4757A34640782AE09EE78344404AB20E4757A34640
60100	28188	41.030506000000003	41.085545000000003	45.323238000000003	45.276100999999997	Р.Люксембург	0103000020E61000000100000005000000782AE09EE78344404AB20E4757A34640782AE09EE78344408869DFDC5FA946400DAB7823F38A44408869DFDC5FA946400DAB7823F38A44404AB20E4757A34640782AE09EE78344404AB20E4757A34640
60298	28188	41.030506000000003	41.085545000000003	45.323238000000003	45.276100999999997	Демьяна Бедного	0103000020E61000000100000005000000782AE09EE78344404AB20E4757A34640782AE09EE78344408869DFDC5FA946400DAB7823F38A44408869DFDC5FA946400DAB7823F38A44404AB20E4757A34640782AE09EE78344404AB20E4757A34640
60346	29127	41.186669000000002	41.206395999999998	45.665815000000002	45.646929	Комсомольская	0103000020E61000000100000005000000A91611C5E4974440C0EAC891CED24640A91611C5E4974440D717096D39D546403A03232F6B9A4440D717096D39D546403A03232F6B9A4440C0EAC891CED24640A91611C5E4974440C0EAC891CED24640
60386	27948	41.280624000000003	41.306648000000003	45.27657	45.256993999999999	Школьная	0103000020E61000000100000005000000823CBB7CEBA3444055A2EC2DE5A04640823CBB7CEBA34440018750A566A3464021B1DD3D40A74440018750A566A3464021B1DD3D40A7444055A2EC2DE5A04640823CBB7CEBA3444055A2EC2DE5A04640
60624	57690	40.983254000000002	41.018836999999998	45.423091999999997	45.414026	Школьный переулок	0103000020E61000000100000005000000A2D45E44DB7D4440CBD8D0CDFEB44640A2D45E44DB7D44408099EFE027B64640357A3540698244408099EFE027B64640357A354069824440CBD8D0CDFEB44640A2D45E44DB7D4440CBD8D0CDFEB44640
60385	27573	41.279896000000001	41.283489000000003	45.483232000000001	45.478915999999998	Заречная	0103000020E61000000100000005000000FF23D3A1D3A34440FCC3961E4DBD4640FF23D3A1D3A34440BA30D28BDABD46404CE3175E49A44440BA30D28BDABD46404CE3175E49A44440FCC3961E4DBD4640FF23D3A1D3A34440FCC3961E4DBD4640
60532	57679	44.829715	44.858694	44.421497000000002	44.405084000000002	Ленина	0103000020E610000001000000050000001500E319346A46400211E2CAD93346401500E319346A46405A2E1B9DF3354640BEA25BAFE96D46405A2E1B9DF3354640BEA25BAFE96D46400211E2CAD93346401500E319346A46400211E2CAD9334640
60545	57680	44.998956999999997	45.022233	44.405599000000002	44.391759	Ленина	0103000020E610000001000000050000001D8EAED2DD7F4640F374AE28253246401D8EAED2DD7F4640292504ABEA3346402CF2EB87D8824640292504ABEA3346402CF2EB87D8824640F374AE28253246401D8EAED2DD7F4640F374AE2825324640
60309	57629	44.977001999999999	44.995103	44.481641000000003	44.473672000000001	60-лет Октября	0103000020E610000001000000050000003410CB660E7D4640F583BA48A13C46403410CB660E7D4640D5B48B69A63D46406493FC885F7F4640D5B48B69A63D46406493FC885F7F4640F583BA48A13C46403410CB660E7D4640F583BA48A13C4640
59895	57599	45.163843	45.206944	44.341631	44.323829000000003	Эдиге	0103000020E61000000100000005000000DA56B3CEF89446408A3F8A3A73294640DA56B3CEF89446405F268A90BA2B46403D0D18247D9A46405F268A90BA2B46403D0D18247D9A46408A3F8A3A73294640DA56B3CEF89446408A3F8A3A73294640
60341	25751	45.105955999999999	45.149954999999999	44.84395	44.801977999999998	О.Сеитова	0103000020E61000000100000005000000516859F78F8D4640450E1137A7664640516859F78F8D4640C7BAB88D066C4640936FB6B931934640C7BAB88D066C4640936FB6B931934640450E1137A7664640516859F78F8D4640450E1137A7664640
60462	25751	45.105955999999999	45.149954999999999	44.84395	44.801977999999998	Мира	0103000020E61000000100000005000000516859F78F8D4640450E1137A7664640516859F78F8D4640C7BAB88D066C4640936FB6B931934640C7BAB88D066C4640936FB6B931934640450E1137A7664640516859F78F8D4640450E1137A7664640
60172	57609	44.759808	44.787269000000002	44.461101999999997	44.419539999999998	Кирова	0103000020E610000001000000050000009D9E77634161464092AE997CB33546409D9E776341614640620FED63053B4640CB13083BC5644640620FED63053B4640CB13083BC564464092AE997CB33546409D9E77634161464092AE997CB3354640
59879	25044	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	пл.Ленина	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
59821	25044	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	м-он № 2	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
59881	25044	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	м-он № 1	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
59627	25044	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	Ленина	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
59628	25044	44.958506	45.007472999999997	44.769984999999998	44.708897999999998	Анны Шилиной	0103000020E6100000010000000500000088821953B07A464093196F2BBD5A464088821953B07A46408DB454DE8E6246402F4D11E0F48046408DB454DE8E6246402F4D11E0F480464093196F2BBD5A464088821953B07A464093196F2BBD5A4640
60179	57613	45.189363999999998	45.220706	44.452531999999998	44.428173000000001	Советская	0103000020E6100000010000000500000016855D143D984640DE03745FCE36464016855D143D9846405D328E91EC394640F7031E18409C46405D328E91EC394640F7031E18409C4640DE03745FCE36464016855D143D984640DE03745FCE364640
60438	57650	45.098121999999996	45.111417000000003	44.410487000000003	44.404755999999999	Степная	0103000020E610000001000000050000005182FE428F8C46400D6E6B0BCF3346405182FE428F8C4640723788D68A344640F69B89E9428E4640723788D68A344640F69B89E9428E46400D6E6B0BCF3346405182FE428F8C46400D6E6B0BCF334640
60525	57674	44.758828999999999	44.765593000000003	44.403480999999999	44.397337	Ленина	0103000020E61000000100000005000000D120054F21614640D13E56F0DB324640D120054F2161464058C7F143A5334640F58590F3FE61464058C7F143A5334640F58590F3FE614640D13E56F0DB324640D120054F21614640D13E56F0DB324640
59710	26511	44.973095000000001	45.016097000000002	44.338524	44.313277999999997	Советская	0103000020E61000000100000005000000587380608E7C46403447567E19284640587380608E7C46409F7422C1542B464028486C770F8246409F7422C1542B464028486C770F8246403447567E19284640587380608E7C46403447567E19284640
60221	57618	44.619104999999998	44.700133000000001	44.537495	44.512740000000001	Ленина	0103000020E6100000010000000500000021E527D53E4F4640EFACDD76A141464021E527D53E4F4640BB61DBA2CC444640D9EC48F59D594640BB61DBA2CC444640D9EC48F59D594640EFACDD76A141464021E527D53E4F4640EFACDD76A1414640
60292	26417	44.880892000000003	44.899684000000001	44.308698	44.299919000000003	Молодежная	0103000020E610000001000000050000006EA7AD11C17046407A39ECBE632646406EA7AD11C1704640992B836A83274640035E66D828734640992B836A83274640035E66D8287346407A39ECBE632646406EA7AD11C17046407A39ECBE63264640
60535	13858	45.320976000000002	45.336688000000002	44.920302	44.909686999999998	Новая	0103000020E610000001000000050000008466D7BD15A94640554CA59F707446408466D7BD15A94640C138B874CC754640537AA69718AB4640C138B874CC754640537AA69718AB4640554CA59F707446408466D7BD15A94640554CA59F70744640
59819	25456	45.190863999999998	45.236696000000002	44.803621999999997	44.780811	Строительная	0103000020E61000000100000005000000EBFD463B6E984640B4AD669DF1634640EBFD463B6E9846404D2CF015DD664640098CF50D4C9E46404D2CF015DD664640098CF50D4C9E4640B4AD669DF1634640EBFD463B6E984640B4AD669DF1634640
60337	25456	45.190863999999998	45.236696000000002	44.803621999999997	44.780811	Котельная	0103000020E61000000100000005000000EBFD463B6E984640B4AD669DF1634640EBFD463B6E9846404D2CF015DD664640098CF50D4C9E46404D2CF015DD664640098CF50D4C9E4640B4AD669DF1634640EBFD463B6E984640B4AD669DF1634640
59630	25456	45.190863999999998	45.236696000000002	44.803621999999997	44.780811	Комсомольская	0103000020E61000000100000005000000EBFD463B6E984640B4AD669DF1634640EBFD463B6E9846404D2CF015DD664640098CF50D4C9E46404D2CF015DD664640098CF50D4C9E4640B4AD669DF1634640EBFD463B6E984640B4AD669DF1634640
59629	25456	45.190863999999998	45.236696000000002	44.803621999999997	44.780811	Горького	0103000020E61000000100000005000000EBFD463B6E984640B4AD669DF1634640EBFD463B6E9846404D2CF015DD664640098CF50D4C9E46404D2CF015DD664640098CF50D4C9E4640B4AD669DF1634640EBFD463B6E984640B4AD669DF1634640
60383	57643	44.690206000000003	44.710661000000002	44.602454000000002	44.593333999999999	Степная	0103000020E6100000010000000500000062C092AB585846406CCD565EF24B464062C092AB5858464015AC71361D4D464076C58CF0F65A464015AC71361D4D464076C58CF0F65A46406CCD565EF24B464062C092AB585846406CCD565EF24B4640
60419	57647	44.923471999999997	44.940809000000002	44.414904	44.407473000000003	А.Шабанова	0103000020E61000000100000005000000C7629B54347646406380441328344640C7629B5434764640637D03931B3546402864E76D6C784640637D03931B3546402864E76D6C7846406380441328344640C7629B54347646406380441328344640
59910	13868	44.807139999999997	44.862665	44.565944000000002	44.531654000000003	площадь Ленина	0103000020E610000001000000050000008FA50F5D50674640D064FF3C0D4446408FA50F5D5067464008AF5DDA70484640B13385CE6B6E464008AF5DDA70484640B13385CE6B6E4640D064FF3C0D4446408FA50F5D50674640D064FF3C0D444640
59880	13868	44.807139999999997	44.862665	44.565944000000002	44.531654000000003	пл.Ленина	0103000020E610000001000000050000008FA50F5D50674640D064FF3C0D4446408FA50F5D5067464008AF5DDA70484640B13385CE6B6E464008AF5DDA70484640B13385CE6B6E4640D064FF3C0D4446408FA50F5D50674640D064FF3C0D444640
60579	13868	44.807139999999997	44.862665	44.565944000000002	44.531654000000003	Червонная	0103000020E610000001000000050000008FA50F5D50674640D064FF3C0D4446408FA50F5D5067464008AF5DDA70484640B13385CE6B6E464008AF5DDA70484640B13385CE6B6E4640D064FF3C0D4446408FA50F5D50674640D064FF3C0D444640
60534	57677	44.751373000000001	44.765493999999997	44.518352	44.507373000000001	Ленина	0103000020E61000000100000005000000780C8FFD2C604640CCEF3499F1404640780C8FFD2C60464079E8BB5B5942464061A417B5FB61464079E8BB5B5942464061A417B5FB614640CCEF3499F1404640780C8FFD2C604640CCEF3499F1404640
59631	25935	44.881726999999998	44.898902999999997	44.623821999999997	44.597377000000002	Правобережная	0103000020E6100000010000000500000006802A6EDC704640F9307BD9764C464006802A6EDC7046403D433866D94F46405DA3E5400F7346403D433866D94F46405DA3E5400F734640F9307BD9764C464006802A6EDC704640F9307BD9764C4640
60351	57633	45.265002000000003	45.289031999999999	44.311059	44.300828000000003	Курманалиева	0103000020E61000000100000005000000F3AFE595EBA146404DDC2A8881264640F3AFE595EBA14640301004C8D0274640ADBF2500FFA44640301004C8D0274640ADBF2500FFA446404DDC2A8881264640F3AFE595EBA146404DDC2A8881264640
60501	57666	45.104869000000001	45.115487000000002	44.733165	44.726703999999998	А.Эюпова	0103000020E610000001000000050000009FAEEE586C8D4640AAEFFCA2045D46409FAEEE586C8D464032C9C859D85D46407C0E2C47C88E464032C9C859D85D46407C0E2C47C88E4640AAEFFCA2045D46409FAEEE586C8D4640AAEFFCA2045D4640
60275	15597	41.941191000000003	41.962291999999998	44.546360999999997	44.530310999999998	Набережная	0103000020E6100000010000000500000010255AF278F84440C2DA183BE143464010255AF278F84440A9674128EF454640E9995E622CFB4440A9674128EF454640E9995E622CFB4440C2DA183BE143464010255AF278F84440C2DA183BE1434640
60468	57662	41.560502999999997	41.599075999999997	44.670378999999997	44.636125	Центральная	0103000020E61000000100000005000000AA27F38FBEC744408195438B6C514640AA27F38FBEC744406C76A4FACE554640C4E8B985AECC44406C76A4FACE554640C4E8B985AECC44408195438B6C514640AA27F38FBEC744408195438B6C514640
60368	15204	42.118878000000002	42.149833000000001	44.727786000000002	44.715131	Ленина	0103000020E61000000100000005000000611BF164370F45408AADA069895B4640611BF164370F45404B3E7617285D4640486E4DBA2D1345404B3E7617285D4640486E4DBA2D1345408AADA069895B4640611BF164370F45408AADA069895B4640
60494	15098	41.891818999999998	41.902104999999999	44.749523000000003	44.739421	Казачья	0103000020E61000000100000005000000C879FF1F27F24440E17CEA58A55E4640C879FF1F27F24440C74CA25EF05F46406F47382D78F34440C74CA25EF05F46406F47382D78F34440E17CEA58A55E4640C879FF1F27F24440E17CEA58A55E4640
60523	57676	41.761285000000001	41.779161999999999	44.589391999999997	44.576282999999997	Мира	0103000020E61000000100000005000000BAF770C971E14440D11E2FA4C3494640BAF770C971E1444013437232714B46409A249694BBE3444013437232714B46409A249694BBE34440D11E2FA4C3494640BAF770C971E14440D11E2FA4C3494640
60437	15406	42.118248999999999	42.189107999999997	44.399242999999998	44.369171999999999	Мира	0103000020E6100000010000000500000071E481C8220F4540A94C3107412F464071E481C8220F4540161406651A334640BBB4E1B034184540161406651A334640BBB4E1B034184540A94C3107412F464071E481C8220F4540A94C3107412F4640
60457	825	42.004190000000001	42.028992000000002	44.529958000000001	44.506962000000001	Шоссейная	0103000020E61000000100000005000000317C444C890045404A287D21E4404640317C444C890045407520EBA9D54346403EEC8502B60345407520EBA9D54346403EEC8502B60345404A287D21E4404640317C444C890045404A287D21E4404640
60505	57667	41.801557000000003	41.815759	44.535997999999999	44.523114	40 лет Победы	0103000020E61000000100000005000000A070766B99E64440350A4966F5424640A070766B99E64440575C1C959B444640763579CA6AE84440575C1C959B444640763579CA6AE84440350A4966F5424640A070766B99E64440350A4966F5424640
60315	57631	\N	\N	\N	\N	 Ленина	\N
59576	57579	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	Вокзальная	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
60288	14932	41.674219999999998	41.708033	44.880366000000002	44.863591999999997	Ленина	0103000020E61000000100000005000000912749D74CD644402A8BC22E8A6E4640912749D74CD64440534145D5AF70464090BE49D3A0DA4440534145D5AF70464090BE49D3A0DA44402A8BC22E8A6E4640912749D74CD644402A8BC22E8A6E4640
60079	13025	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Фабричная	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
60074	13025	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Скрипникова	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
60089	13025	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Партизанская	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
59851	13025	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Октябрьской революции	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
59690	13025	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Гагарина	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
59791	13025	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Бульварная	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
59786	13025	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Балахонова	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
59923	14246	41.652841000000002	41.705212000000003	44.605798	44.566778999999997	Советская	0103000020E61000000100000005000000753E3C4B90D34440A087DA368C484640753E3C4B90D34440B9FDF2C98A4D4640965F066344DA4440B9FDF2C98A4D4640965F066344DA4440A087DA368C484640753E3C4B90D34440A087DA368C484640
59850	14246	41.652841000000002	41.705212000000003	44.605798	44.566778999999997	Революционная	0103000020E61000000100000005000000753E3C4B90D34440A087DA368C484640753E3C4B90D34440B9FDF2C98A4D4640965F066344DA4440B9FDF2C98A4D4640965F066344DA4440A087DA368C484640753E3C4B90D34440A087DA368C484640
59849	14640	41.584254000000001	41.655490999999998	44.764443	44.724738000000002	Баркова	0103000020E610000001000000050000005247C7D5C8CA44409015FC36C45C46405247C7D5C8CA4440FC53AA44D961464042E90B21E7D34440FC53AA44D961464042E90B21E7D344409015FC36C45C46405247C7D5C8CA44409015FC36C45C4640
60333	15681	41.912489999999998	41.935153999999997	44.546610999999999	44.534917999999998	Ленина	0103000020E61000000100000005000000A9F6E978CCF4444057056A3178444640A9F6E978CCF4444022516859F74546409E5C5320B3F7444022516859F74546409E5C5320B3F7444057056A3178444640A9F6E978CCF4444057056A3178444640
60322	15451	42.082414999999997	42.119847999999998	44.463489000000003	44.413789999999999	Молодежная	0103000020E6100000010000000500000094D920938C0A4540B7B41A12F734464094D920938C0A45402387889B533B4640D93EE42D570F45402387889B533B4640D93EE42D570F4540B7B41A12F734464094D920938C0A4540B7B41A12F7344640
60076	14074	41.79278	41.816504999999999	44.513010000000001	44.486226000000002	Зеленая	0103000020E610000001000000050000002176A6D079E54440823B50A73C3E46402176A6D079E54440AF42CA4FAA4146409F02603C83E84440AF42CA4FAA4146409F02603C83E84440823B50A73C3E46402176A6D079E54440823B50A73C3E4640
60422	14296	41.645707999999999	41.669612000000001	44.647931999999997	44.624341000000001	Центральная	0103000020E61000000100000005000000FE614B8FA6D24440A646E867EA4F4640FE614B8FA6D2444014048F6FEF5246402C8194D8B5D5444014048F6FEF5246402C8194D8B5D54440A646E867EA4F4640FE614B8FA6D24440A646E867EA4F4640
60425	15288	42.094676999999997	42.147803000000003	44.637324	44.624764999999996	Центральная	0103000020E6100000010000000500000079573D601E0C4540BC57AD4CF84F464079573D601E0C45405B7A34D59351464017A06D35EB1245405B7A34D59351464017A06D35EB124540BC57AD4CF84F464079573D601E0C4540BC57AD4CF84F4640
60291	57625	41.794010999999998	41.837336999999998	44.787227999999999	44.741252000000003	Ленина	0103000020E6100000010000000500000006D50627A2E544401C0C7558E15E464006D50627A2E544406C3F19E3C3644640895DDBDB2DEB44406C3F19E3C3644640895DDBDB2DEB44401C0C7558E15E464006D50627A2E544401C0C7558E15E4640
60080	14724	41.762579000000002	41.796652000000002	44.804895000000002	44.748959999999997	пл. Гетало	0103000020E61000000100000005000000E6CE4C309CE144408E01D9EBDD5F4640E6CE4C309CE1444062DBA2CC06674640812557B1F8E5444062DBA2CC06674640812557B1F8E544408E01D9EBDD5F4640E6CE4C309CE144408E01D9EBDD5F4640
60423	14434	41.639688999999997	41.657952000000002	44.710397	44.696795999999999	Центральная	0103000020E61000000100000005000000334E4354E1D14440E7FD7F9C30594640334E4354E1D144409816F549EE5A46403D2B69C537D444409816F549EE5A46403D2B69C537D44440E7FD7F9C30594640334E4354E1D14440E7FD7F9C30594640
59856	57597	41.523420000000002	41.548949999999998	44.714950999999999	44.687043000000003	Почтовая	0103000020E610000001000000050000004209336DFFC244400EF96706F15746404209336DFFC244400A9FAD83835B4640D1915CFE43C644400A9FAD83835B4640D1915CFE43C644400EF96706F15746404209336DFFC244400EF96706F1574640
60556	15728	42.733666999999997	42.74494	44.255108999999997	44.249712000000002	Королева	0103000020E61000000100000005000000C493DDCCE85D45409AB51490F61F4640C493DDCCE85D454027F56569A7204640BABDA4315A5F454027F56569A7204640BABDA4315A5F45409AB51490F61F4640C493DDCCE85D45409AB51490F61F4640
60578	13965	42.888015000000003	42.919069999999998	44.243912999999999	44.230389000000002	Ленина	0103000020E61000000100000005000000C1ADBB79AA714540D82D02637D1D4640C1ADBB79AA714540DD088B8A381F46400B5EF415A4754540DD088B8A381F46400B5EF415A4754540D82D02637D1D4640C1ADBB79AA714540D82D02637D1D4640
60339	21822	43.105839000000003	43.132877999999998	44.244152	44.223658999999998	Московская	0103000020E6100000010000000500000018D2E1218C8D4540603AADDBA01C464018D2E1218C8D454062A06B5F401F4640CF2D74250291454062A06B5F401F4640CF2D742502914540603AADDBA01C464018D2E1218C8D4540603AADDBA01C4640
59619	21626	43.125584000000003	43.157356999999998	44.240470999999999	44.223568	Степная	0103000020E610000001000000050000005073F22213904540503750E09D1C46405073F222139045407651F4C0C71E4640F9653046249445407651F4C0C71E4640F965304624944540503750E09D1C46405073F22213904540503750E09D1C4640
59867	21626	43.125584000000003	43.157356999999998	44.240470999999999	44.223568	Мостовая	0103000020E610000001000000050000005073F22213904540503750E09D1C46405073F222139045407651F4C0C71E4640F9653046249445407651F4C0C71E4640F965304624944540503750E09D1C46405073F22213904540503750E09D1C4640
59622	22513	43.095534999999998	43.112872000000003	44.205491000000002	44.194122999999998	9 Мая	0103000020E61000000100000005000000CA4FAA7D3A8C45406133C005D9184640CA4FAA7D3A8C4540A94F72874D1A46402B51F696728E4540A94F72874D1A46402B51F696728E45406133C005D9184640CA4FAA7D3A8C45406133C005D9184640
60508	22730	43.009017999999998	43.045839999999998	44.264631999999999	44.249447000000004	ул.Шоссейная	0103000020E61000000100000005000000A489778027814540EC8A19E1ED1F4640A489778027814540CFBC1C76DF214640A06CCA15DE854540CFBC1C76DF214640A06CCA15DE854540EC8A19E1ED1F4640A489778027814540EC8A19E1ED1F4640
60583	14015	42.743772999999997	42.813975999999997	44.248142999999999	44.212637000000001	Пролетарская	0103000020E61000000100000005000000EB5223F4335F4540B47570B0371B4640EB5223F4335F45409CDD5A26C31F46404CDD955D306845409CDD5A26C31F46404CDD955D30684540B47570B0371B4640EB5223F4335F4540B47570B0371B4640
60277	21528	43.068962999999997	43.107069000000003	44.245424	44.229129999999998	Береговая	0103000020E6100000010000000500000028D192C7D38845402844C021541D464028D192C7D3884540A6D3BA0D6A1F46402DB5DE6FB48D4540A6D3BA0D6A1F46402DB5DE6FB48D45402844C021541D464028D192C7D38845402844C021541D4640
59817	57593	42.973489999999998	42.993899999999996	44.125942999999999	44.112935999999998	Комсомольская	0103000020E61000000100000005000000D47D00529B7C45404145D5AF740E4640D47D00529B7C45407F1475E61E10464048BF7D1D387F45407F1475E61E10464048BF7D1D387F45404145D5AF740E4640D47D00529B7C45404145D5AF740E4640
60085	19010	44.897888000000002	44.941088000000001	44.799529	44.780414999999998	площадь Ленина	0103000020E6100000010000000500000045BC75FEED724640672783A3E463464045BC75FEED7246400F9A5DF7566646403B545392757846400F9A5DF7566646403B54539275784640672783A3E463464045BC75FEED724640672783A3E4634640
59606	19203	44.867570000000001	44.892533999999998	45.225909999999999	45.209110000000003	Шоссейная	0103000020E61000000100000005000000D07EA4880C6F46401FA2D11DC49A4640D07EA4880C6F464070EB6E9EEA9C4640B648DA8D3E72464070EB6E9EEA9C4640B648DA8D3E7246401FA2D11DC49A4640D07EA4880C6F46401FA2D11DC49A4640
59607	19211	44.807544	44.839066000000003	45.260604000000001	45.236649999999997	Мира	0103000020E610000001000000050000005F0A0F9A5D674640984C158C4A9E46405F0A0F9A5D674640789ACC785BA14640C097C283666B4640789ACC785BA14640C097C283666B4640984C158C4A9E46405F0A0F9A5D674640984C158C4A9E4640
60088	18894	44.625185999999999	44.672438	44.789408999999999	44.754266000000001	Советская	0103000020E6100000010000000500000062F54718065046400C3ECDC98B60464062F54718065046408315A75A0B654640384BC972125646408315A75A0B654640384BC972125646400C3ECDC98B60464062F54718065046400C3ECDC98B604640
59602	18894	44.625185999999999	44.672438	44.789408999999999	44.754266000000001	Гагарина	0103000020E6100000010000000500000062F54718065046400C3ECDC98B60464062F54718065046408315A75A0B654640384BC972125646408315A75A0B654640384BC972125646400C3ECDC98B60464062F54718065046400C3ECDC98B604640
59798	18797	44.686881999999997	44.713166999999999	44.804977999999998	44.789498999999999	Мичурина	0103000020E61000000100000005000000041BD7BFEB574640C39CA04D0E654640041BD7BFEB574640EFFFE3840967464010CB660E495B4640EFFFE3840967464010CB660E495B4640C39CA04D0E654640041BD7BFEB574640C39CA04D0E654640
60019	19352	44.486891	44.558593999999999	44.966211000000001	44.914372999999998	Кооперативная	0103000020E61000000100000005000000BEDBBC71523E464036ACA92C0A754640BEDBBC71523E46408A0453CDAC7B4640F4DE1802804746408A0453CDAC7B4640F4DE18028047464036ACA92C0A754640BEDBBC71523E464036ACA92C0A754640
60663	13304	44.507651000000003	44.533566999999998	45.108068000000003	45.094541999999997	Мира	0103000020E610000001000000050000000F643DB5FA404640990CC7F3198C46400F643DB5FA40464040DF162CD58D4640C79C67EC4B44464040DF162CD58D4640C79C67EC4B444640990CC7F3198C46400F643DB5FA404640990CC7F3198C4640
59601	18579	44.635652	44.686694000000003	44.838344999999997	44.806660000000001	Пролетарская	0103000020E6100000010000000500000089D1730B5D514640E57E87A24067464089D1730B5D514640EFE192E34E6B4640022EC896E5574640EFE192E34E6B4640022EC896E5574640E57E87A24067464089D1730B5D514640E57E87A240674640
59857	18579	44.635652	44.686694000000003	44.838344999999997	44.806660000000001	Комсомольская	0103000020E6100000010000000500000089D1730B5D514640E57E87A24067464089D1730B5D514640EFE192E34E6B4640022EC896E5574640EFE192E34E6B4640022EC896E5574640E57E87A24067464089D1730B5D514640E57E87A240674640
60087	18579	44.635652	44.686694000000003	44.838344999999997	44.806660000000001	Борцов Революции	0103000020E6100000010000000500000089D1730B5D514640E57E87A24067464089D1730B5D514640EFE192E34E6B4640022EC896E5574640EFE192E34E6B4640022EC896E5574640E57E87A24067464089D1730B5D514640E57E87A240674640
59608	13306	44.405799999999999	44.43309	44.831364999999998	44.82253	Гагарина	0103000020E61000000100000005000000C05B2041F13346404CFDBCA948694640C05B2041F1334640FF04172B6A6A4640C11C3D7E6F374640FF04172B6A6A4640C11C3D7E6F3746404CFDBCA948694640C05B2041F13346404CFDBCA948694640
59861	19526	44.510983000000003	44.530450000000002	44.828161999999999	44.809269	Красная	0103000020E61000000100000005000000EFE714E4674146405455682096674640EFE714E4674146401DE56036016A4640E4141DC9E54346401DE56036016A4640E4141DC9E54346405455682096674640EFE714E4674146405455682096674640
59604	18996	44.757688000000002	44.794114	44.758721000000001	44.736418	Лыхова	0103000020E610000001000000050000002C499EEBFB604640C617EDF1425E46402C499EEBFB604640EBE40CC51D614640DBA50D87A5654640EBE40CC51D614640DBA50D87A5654640C617EDF1425E46402C499EEBFB604640C617EDF1425E4640
60159	18996	44.757688000000002	44.794114	44.758721000000001	44.736418	Ленина	0103000020E610000001000000050000002C499EEBFB604640C617EDF1425E46402C499EEBFB604640EBE40CC51D614640DBA50D87A5654640EBE40CC51D614640DBA50D87A5654640C617EDF1425E46402C499EEBFB604640C617EDF1425E4640
59799	19055	45.109827000000003	45.167462999999998	44.962530999999998	44.935642999999999	Сестер Антоновых	0103000020E61000000100000005000000E19BA6CF0E8E46409CDD5A26C3774640E19BA6CF0E8E46406E313F37347B46402025766D6F9546406E313F37347B46402025766D6F9546409CDD5A26C3774640E19BA6CF0E8E46409CDD5A26C3774640
60084	19055	45.109827000000003	45.167462999999998	44.962530999999998	44.935642999999999	Пушкина	0103000020E61000000100000005000000E19BA6CF0E8E46409CDD5A26C3774640E19BA6CF0E8E46406E313F37347B46402025766D6F9546406E313F37347B46402025766D6F9546409CDD5A26C3774640E19BA6CF0E8E46409CDD5A26C3774640
60296	19515	44.460408000000001	44.494841000000001	44.834637999999998	44.822217000000002	Ленина	0103000020E610000001000000050000008C683BA6EE3A46408D9B1A683E6946408C683BA6EE3A4640DAFF006BD56A464027DC2BF3563F4640DAFF006BD56A464027DC2BF3563F46408D9B1A683E6946408C683BA6EE3A46408D9B1A683E694640
59808	17585	44.524996999999999	44.57056	44.055546	44.030554000000002	Свердлова	0103000020E61000000100000005000000C2BF081A3343464089618731E9034640C2BF081A3343464039B69E211C074640F0332E1C0849464039B69E211C074640F0332E1C0849464089618731E9034640C2BF081A3343464089618731E9034640
60067	17585	44.524996999999999	44.57056	44.055546	44.030554000000002	Исаакяна	0103000020E61000000100000005000000C2BF081A3343464089618731E9034640C2BF081A3343464039B69E211C074640F0332E1C0849464039B69E211C074640F0332E1C0849464089618731E9034640C2BF081A3343464089618731E9034640
60290	17768	44.380476000000002	44.494562000000002	43.821226000000003	43.807487000000002	Колхозная	0103000020E61000000100000005000000DA740470B3304640FB78E8BB5BE74540DA740470B3304640FD4FFEEE1DE9454014ECBFCE4D3F4640FD4FFEEE1DE9454014ECBFCE4D3F4640FB78E8BB5BE74540DA740470B3304640FB78E8BB5BE74540
59800	18064	44.824648000000003	44.853510999999997	43.730052999999998	43.713321999999998	Советская	0103000020E610000001000000050000001D5BCF108E69464037C2A2224EDB45401D5BCF108E69464060AC6F6072DD45405CE333D93F6D464060AC6F6072DD45405CE333D93F6D464037C2A2224EDB45401D5BCF108E69464037C2A2224EDB4540
60326	17977	44.757004999999999	44.819446999999997	43.866809000000003	43.853411999999999	Октябрьская	0103000020E6100000010000000500000049F4328AE5604640C901BB9A3CED454049F4328AE56046407270E998F3EE454014E7A8A3E36846407270E998F3EE454014E7A8A3E3684640C901BB9A3CED454049F4328AE5604640C901BB9A3CED4540
59600	17777	44.522508999999999	44.627872000000004	43.848173000000003	43.820861999999998	Школьная	0103000020E61000000100000005000000CE6E2D93E1424640BB438A0112E94540CE6E2D93E1424640D42CD0EE90EC45407D09151C5E504640D42CD0EE90EC45407D09151C5E504640BB438A0112E94540CE6E2D93E1424640BB438A0112E94540
59599	17777	44.522508999999999	44.627872000000004	43.848173000000003	43.820861999999998	Кооперативная	0103000020E61000000100000005000000CE6E2D93E1424640BB438A0112E94540CE6E2D93E1424640D42CD0EE90EC45407D09151C5E504640D42CD0EE90EC45407D09151C5E504640BB438A0112E94540CE6E2D93E1424640BB438A0112E94540
60276	18576	45.190918000000003	45.213160000000002	44.152861000000001	44.145999000000003	Ленина	0103000020E61000000100000005000000DF1B430070984640D61F6118B0124640DF1B430070984640BCEA01F3901346405E68AED3489B4640BCEA01F3901346405E68AED3489B4640D61F6118B0124640DF1B430070984640D61F6118B0124640
59597	17456	44.207748000000002	44.257199999999997	43.990591000000002	43.970306999999998	Ленина	0103000020E610000001000000050000009BE7887C971A4640390A100533FC45409BE7887C971A4640215B96AFCBFE4540FE43FAEDEB204640215B96AFCBFE4540FE43FAEDEB204640390A100533FC45409BE7887C971A4640390A100533FC4540
60371	17363	44.468358000000002	44.483567000000001	43.986466	43.974226000000002	Крестьянская	0103000020E61000000100000005000000F568AA27F33B4640DA740470B3FC4540F568AA27F33B4640D74E948444FE454061360186E53D4640D74E948444FE454061360186E53D4640DA740470B3FC4540F568AA27F33B4640DA740470B3FC4540
60205	57616	44.098197999999996	44.130107000000002	44.013727000000003	44.000241000000003	Мира	0103000020E610000001000000050000002C4487C0910C4640268FA7E5070046402C4487C0910C46403E096CCEC101464087FD9E58A71046403E096CCEC101464087FD9E58A7104640268FA7E5070046402C4487C0910C4640268FA7E507004640
60446	57653	44.614721000000003	44.636432999999997	44.042692000000002	44.030994999999997	Центральная	0103000020E610000001000000050000000C957F2DAF4E464075ABE7A4F70346400C957F2DAF4E464082E673EE760546402E8CF4A27651464082E673EE760546402E8CF4A27651464075ABE7A4F70346400C957F2DAF4E464075ABE7A4F7034640
59797	18256	44.743881000000002	44.779345999999997	44.031131000000002	44.009351000000002	Кооперативная	0103000020E61000000100000005000000D28E1B7E375F4640AB97DF6932014640D28E1B7E375F46402672C119FC0346405B22179CC16346402672C119FC0346405B22179CC1634640AB97DF6932014640D28E1B7E375F4640AB97DF6932014640
60359	57635	\N	\N	\N	\N	Зеленого	\N
59862	18365	44.939515999999998	44.961452999999999	44.094093000000001	44.074815999999998	Мира	0103000020E61000000100000005000000CC086F0F42784640D89B189293094640CC086F0F427846402AE44A3D0B0C46400FD253E4107B46402AE44A3D0B0C46400FD253E4107B4640D89B189293094640CC086F0F42784640D89B189293094640
59594	16928	44.423828999999998	44.505189000000001	44.057892000000002	44.027287999999999	Школьный переулок	0103000020E61000000100000005000000560C57074036464060C9552C7E034640560C5707403646409B594B016907464044A67C08AA4046409B594B016907464044A67C08AA40464060C9552C7E034640560C57074036464060C9552C7E034640
59595	16928	44.423828999999998	44.505189000000001	44.057892000000002	44.027287999999999	Титова	0103000020E61000000100000005000000560C57074036464060C9552C7E034640560C5707403646409B594B016907464044A67C08AA4046409B594B016907464044A67C08AA40464060C9552C7E034640560C57074036464060C9552C7E034640
59869	16928	44.423828999999998	44.505189000000001	44.057892000000002	44.027287999999999	Кондратенко	0103000020E61000000100000005000000560C57074036464060C9552C7E034640560C5707403646409B594B016907464044A67C08AA4046409B594B016907464044A67C08AA40464060C9552C7E034640560C57074036464060C9552C7E034640
59802	16928	44.423828999999998	44.505189000000001	44.057892000000002	44.027287999999999	Калинина	0103000020E61000000100000005000000560C57074036464060C9552C7E034640560C5707403646409B594B016907464044A67C08AA4046409B594B016907464044A67C08AA40464060C9552C7E034640560C57074036464060C9552C7E034640
59801	16928	44.423828999999998	44.505189000000001	44.057892000000002	44.027287999999999	Акулова	0103000020E61000000100000005000000560C57074036464060C9552C7E034640560C5707403646409B594B016907464044A67C08AA4046409B594B016907464044A67C08AA40464060C9552C7E034640560C57074036464060C9552C7E034640
60398	13212	44.722546000000001	44.732363999999997	44.115977999999998	44.107143000000001	Комсомольская	0103000020E6100000010000000500000085ED27637C5C4640677FA0DCB60D464085ED27637C5C46401A87FA5DD80E46404562821ABE5D46401A87FA5DD80E46404562821ABE5D4640677FA0DCB60D464085ED27637C5C4640677FA0DCB60D4640
60066	17524	44.310884000000001	44.340564000000001	44.023398999999998	44.008462000000002	Ленина	0103000020E61000000100000005000000C26C020CCB2746401FA1664815014640C26C020CCB2746402AE109BDFE024640F418E599972B46402AE109BDFE024640F418E599972B46401FA1664815014640C26C020CCB2746401FA1664815014640
60465	57661	44.258665000000001	44.296816	44.005136	43.990358000000001	Школьная	0103000020E6100000010000000500000057CF49EF1B2146407EAA0A0DC4FE454057CF49EF1B2146402104E44BA8004640FB761211FE2546402104E44BA8004640FB761211FE2546407EAA0A0DC4FE454057CF49EF1B2146407EAA0A0DC4FE4540
60347	18261	44.831394000000003	44.850295000000003	43.953943000000002	43.935029	Тивилева	0103000020E610000001000000050000009A0B5C1E6B6A4640E2E7BF07AFF745409A0B5C1E6B6A4640C39FE1CD1AFA4540E6797077D66C4640C39FE1CD1AFA4540E6797077D66C4640E2E7BF07AFF745409A0B5C1E6B6A4640E2E7BF07AFF74540
60502	17270	44.512672000000002	44.528661999999997	44.139608000000003	44.124662000000001	Миропольская	0103000020E6100000010000000500000097C9703C9F414640E886A6ECF40F464097C9703C9F4146404721C9ACDE114640A8514832AB4346404721C9ACDE114640A8514832AB434640E886A6ECF40F464097C9703C9F414640E886A6ECF40F4640
60319	17967	44.693601999999998	44.747895999999997	43.872508000000003	43.853588000000002	Школьная	0103000020E61000000100000005000000583849F3C75846400821205F42ED4540583849F3C7584640CBBF9657AEEF454094675E0EBB5F4640CBBF9657AEEF454094675E0EBB5F46400821205F42ED4540583849F3C75846400821205F42ED4540
59707	18077	44.911856999999998	44.953609999999998	43.705952000000003	43.684938000000002	Бражненко	0103000020E6100000010000000500000078D0ECBAB7744640D2E4620CACD7454078D0ECBAB7744640DD4598A25CDA4540BC9179E40F7A4640DD4598A25CDA4540BC9179E40F7A4640D2E4620CACD7454078D0ECBAB7744640D2E4620CACD74540
60381	18419	45.047286999999997	45.055281999999998	44.045971000000002	44.038038999999998	Кооперативная	0103000020E6100000010000000500000052431B800D8646407C7C4276DE04464052431B800D8646403FC8B260E20546405B07077B138746403FC8B260E20546405B07077B138746407C7C4276DE04464052431B800D8646407C7C4276DE044640
60335	17876	44.664703000000003	44.680872999999998	43.860517000000002	43.854947000000003	Школьная	0103000020E61000000100000005000000CC46E7FC145546401B683EE76EED4540CC46E7FC145546407653CA6B25EE45405DDDB1D8265746407653CA6B25EE45405DDDB1D8265746401B683EE76EED4540CC46E7FC145546401B683EE76EED4540
60445	18480	45.052416000000001	45.077694999999999	44.255200000000002	44.242434000000003	Школьная	0103000020E61000000100000005000000C1E44691B586464020B8CA13081F4640C1E44691B586464038F8C264AA2046400708E6E8F189464038F8C264AA2046400708E6E8F189464020B8CA13081F4640C1E44691B586464020B8CA13081F4640
59598	17674	44.307955	44.332838000000002	43.877616000000003	43.852592999999999	Школьная	0103000020E61000000100000005000000E1D1C6116B27464036E675C421ED4540E1D1C6116B274640223999B855F04540DB6E826F9A2A4640223999B855F04540DB6E826F9A2A464036E675C421ED4540E1D1C6116B27464036E675C421ED4540
60274	18353	44.804704999999998	44.830585999999997	44.019106999999998	44.004519999999999	Южная	0103000020E61000000100000005000000BEF6CC9200674640C616821C94004640BEF6CC9200674640F50F221972024640FA415DA4506A4640F50F221972024640FA415DA4506A4640C616821C94004640BEF6CC9200674640C616821C94004640
60320	16882	41.224138000000004	45.019502000000003	45.983241	44.085481999999999	Партизанская	0103000020E610000001000000050000003BE5D18DB09C4440C632FD12F10A46403BE5D18DB09C44400D8B51D7DAFD4640721AA20A7F8246400D8B51D7DAFD4640721AA20A7F824640C632FD12F10A46403BE5D18DB09C4440C632FD12F10A4640
60514	57673	41.804997	41.833078999999998	45.977260000000001	45.967951999999997	60 лет Октября	0103000020E61000000100000005000000663046240AE74440840CE4D9E5FB4640663046240AE7444030D80DDB16FD464000FE2955A2EA444030D80DDB16FD464000FE2955A2EA4440840CE4D9E5FB4640663046240AE74440840CE4D9E5FB4640
59593	16473	41.930275999999999	41.979970999999999	45.962570999999997	45.930812000000003	Памяти	0103000020E610000001000000050000007920B24813F74440B85CFDD824F746407920B24813F74440FC89CA8635FB4640A30392B06FFD4440FC89CA8635FB4640A30392B06FFD4440B85CFDD824F746407920B24813F74440B85CFDD824F74640
59591	5220	41.279347999999999	41.333202	45.939793999999999	45.900244999999998	Шоссейная	0103000020E61000000100000005000000FC19DEACC1A344409AB1683A3BF34640FC19DEACC1A344400F7D772B4BF846401C7BF65CA6AA44400F7D772B4BF846401C7BF65CA6AA44409AB1683A3BF34640FC19DEACC1A344409AB1683A3BF34640
59592	5220	41.279347999999999	41.333202	45.939793999999999	45.900244999999998	Пролетарская	0103000020E61000000100000005000000FC19DEACC1A344409AB1683A3BF34640FC19DEACC1A344400F7D772B4BF846401C7BF65CA6AA44400F7D772B4BF846401C7BF65CA6AA44409AB1683A3BF34640FC19DEACC1A344409AB1683A3BF34640
59794	13159	41.702005	41.775730000000003	45.828988000000003	45.80162	Красная	0103000020E610000001000000050000007250C24CDBD94440E6E8F17B9BE646407250C24CDBD9444063635E471CEA46405743E21E4BE3444063635E471CEA46405743E21E4BE34440E6E8F17B9BE646407250C24CDBD94440E6E8F17B9BE64640
60081	16786	41.554600999999998	41.615434999999998	45.983241	45.969737000000002	Шоссейная	0103000020E6100000010000000500000019AA622AFDC644404F5C8E5720FC464019AA622AFDC644400D8B51D7DAFD464029E8F692C6CE44400D8B51D7DAFD464029E8F692C6CE44404F5C8E5720FC464019AA622AFDC644404F5C8E5720FC4640
59853	16773	41.436678999999998	41.475710999999997	45.732726999999997	45.699092	Ленина	0103000020E61000000100000005000000CCECF318E5B744409772BED87BD94640CCECF318E5B74440B6F292FFC9DD464079AC1919E4BC4440B6F292FFC9DD464079AC1919E4BC44409772BED87BD94640CCECF318E5B744409772BED87BD94640
59993	16680	41.590237000000002	41.612577999999999	45.737005000000003	45.721710999999999	Красногвардейская	0103000020E61000000100000005000000D0F1D1E28CCB4440EC14AB0661DC4640D0F1D1E28CCB444087FE092E56DE4640E21FB6F468CE444087FE092E56DE4640E21FB6F468CE4440EC14AB0661DC4640D0F1D1E28CCB4440EC14AB0661DC4640
59590	16261	41.351635000000002	41.436508000000003	45.653196999999999	45.602656000000003	Мира	0103000020E6100000010000000500000082902C6002AD44407D5EF1D423CD464082902C6002AD4440336C94F59BD34640A038807EDFB74440336C94F59BD34640A038807EDFB744407D5EF1D423CD464082902C6002AD44407D5EF1D423CD4640
59790	16261	41.351635000000002	41.436508000000003	45.653196999999999	45.602656000000003	Кооперативная	0103000020E6100000010000000500000082902C6002AD44407D5EF1D423CD464082902C6002AD4440336C94F59BD34640A038807EDFB74440336C94F59BD34640A038807EDFB744407D5EF1D423CD464082902C6002AD44407D5EF1D423CD4640
59589	12811	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	Ярмарочная	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
59585	12811	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	Школьная	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
59584	12811	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	Первомайская	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
59793	12811	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	Микояна	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
59788	12811	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	Ленина	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
59588	12811	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	Красная	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
60356	12811	41.473627	41.554654999999997	45.870508000000001	45.819360000000003	Колпаковская	0103000020E6100000010000000500000055C03DCF9FBC444046D3D9C9E0E8464055C03DCF9FBC444004745FCE6CEF46400CC85EEFFEC6444004745FCE6CEF46400CC85EEFFEC6444046D3D9C9E0E8464055C03DCF9FBC444046D3D9C9E0E84640
59796	16871	41.259971	41.283642	45.868889000000003	45.846204999999998	Мира	0103000020E610000001000000050000004774CFBA46A14440185B087250EC46404774CFBA46A14440556D37C137EF4640D2E28C614EA44440556D37C137EF4640D2E28C614EA44440185B087250EC46404774CFBA46A14440185B087250EC4640
59792	16578	41.850181999999997	41.929152999999999	45.832265999999997	45.792678000000002	Октябрьская	0103000020E61000000100000005000000EDD286C3D2EC44401D21037976E54640EDD286C3D2EC44404FC939B187EA46407AFD497CEEF644404FC939B187EA46407AFD497CEEF644401D21037976E54640EDD286C3D2EC44401D21037976E54640
60606	57687	40.90025	45.717699000000003	46.236939	43.658569	Садовая	0103000020E61000000100000005000000AC1C5A643B73444068942EFD4BD44540AC1C5A643B734440CF126404541E47409BAF928FDDDB4640CF126404541E47409BAF928FDDDB464068942EFD4BD44540AC1C5A643B73444068942EFD4BD44540
60463	57658	43.320903999999999	43.338017000000001	43.820594999999997	43.808574	Мира	0103000020E61000000100000005000000EA93DC6113A94540AD32535A7FE74540EA93DC6113A945406C21C84109E94540FB3E1C2444AB45406C21C84109E94540FB3E1C2444AB4540AD32535A7FE74540EA93DC6113A94540AD32535A7FE74540
59603	57582	41.523420000000002	42.343617999999999	44.931182999999997	44.315258	Красная	0103000020E610000001000000050000004209336DFFC24440B4E6C75F5A2846404209336DFFC24440ABCB2901317746409128B4ACFB2B4540ABCB2901317746409128B4ACFB2B4540B4E6C75F5A2846404209336DFFC24440B4E6C75F5A284640
59617	57581	41.802166999999997	41.867232000000001	44.713779000000002	44.627113000000001	Восточная	0103000020E6100000010000000500000018778368ADE64440BFF2203D4550464018778368ADE644402AC93A1C5D5B4640B8054B7501EF44402AC93A1C5D5B4640B8054B7501EF4440BFF2203D4550464018778368ADE64440BFF2203D45504640
60119	57606	41.841478000000002	41.898018	44.591569	44.562984	Калинина	0103000020E61000000100000005000000D926158DB5EB4440EC1516DC0F484640D926158DB5EB4440E9297288B84B4640139CFA40F2F24440E9297288B84B4640139CFA40F2F24440EC1516DC0F484640D926158DB5EB4440EC1516DC0F484640
59618	57584	41.584254000000001	41.655490999999998	44.764443	44.724738000000002	Почтовая	0103000020E610000001000000050000005247C7D5C8CA44409015FC36C45C46405247C7D5C8CA4440FC53AA44D961464042E90B21E7D34440FC53AA44D961464042E90B21E7D344409015FC36C45C46405247C7D5C8CA44409015FC36C45C4640
60300	57627	41.818786000000003	41.842573999999999	44.541716000000001	44.514243999999998	Школьный переулок	0103000020E610000001000000050000001A36CAFACDE84440051555BFD24146401A36CAFACDE8444027DC2BF356454640DE3AFF76D9EB444027DC2BF356454640DE3AFF76D9EB4440051555BFD24146401A36CAFACDE84440051555BFD2414640
60260	57621	41.794010999999998	41.837336999999998	44.787227999999999	44.741252000000003	Ленина	0103000020E6100000010000000500000006D50627A2E544401C0C7558E15E464006D50627A2E544406C3F19E3C3644640895DDBDB2DEB44406C3F19E3C3644640895DDBDB2DEB44401C0C7558E15E464006D50627A2E544401C0C7558E15E4640
60009	12255	42.679057999999998	42.690753999999998	43.916778999999998	43.908979000000002	Прямая	0103000020E61000000100000005000000280B5F5FEB5645401AE0826C59F44540280B5F5FEB5645406D54A70359F5454064CA87A06A5845406D54A70359F5454064CA87A06A5845401AE0826C59F44540280B5F5FEB5645401AE0826C59F44540
60286	10961	43.578899999999997	43.600568000000003	44.056376	44.020015000000001	Рабочая	0103000020E61000000100000005000000C3D32B6519CA4540F836FDD98F024640C3D32B6519CA4540C0232A543707464017838769DFCC4540C0232A543707464017838769DFCC4540F836FDD98F024640C3D32B6519CA4540F836FDD98F024640
59569	10497	43.618955999999997	43.652535	43.851872	43.838901	Ленинская	0103000020E61000000100000005000000DCD440F339CF454075CAA31B61EB4540DCD440F339CF4540663046240AED4540683F524486D34540663046240AED4540683F524486D3454075CAA31B61EB4540DCD440F339CF454075CAA31B61EB4540
60007	57602	44.013263000000002	44.082360999999999	44.035744999999999	44.009357000000001	Шилиной переулок	0103000020E61000000100000005000000999F1B9AB20146408D7E349C32014640999F1B9AB20146406DFFCA4A93044640A1BB24CE8A0A46406DFFCA4A93044640A1BB24CE8A0A46408D7E349C32014640999F1B9AB20146408D7E349C32014640
60212	57602	44.013263000000002	44.082360999999999	44.035744999999999	44.009357000000001	Кирова	0103000020E61000000100000005000000999F1B9AB20146408D7E349C32014640999F1B9AB20146406DFFCA4A93044640A1BB24CE8A0A46406DFFCA4A93044640A1BB24CE8A0A46408D7E349C32014640999F1B9AB20146408D7E349C32014640
60325	10870	43.320903999999999	43.338017000000001	43.820594999999997	43.808574	Зеленый переулок	0103000020E61000000100000005000000EA93DC6113A94540AD32535A7FE74540EA93DC6113A945406C21C84109E94540FB3E1C2444AB45406C21C84109E94540FB3E1C2444AB4540AD32535A7FE74540EA93DC6113A94540AD32535A7FE74540
59983	10398	43.764519	43.801879999999997	43.997717999999999	43.976308000000003	Октябрьская	0103000020E61000000100000005000000D71533C2DBE145405E6919A9F7FC4540D71533C2DBE14540B5503239B5FF454082A8FB00A4E64540B5503239B5FF454082A8FB00A4E645405E6919A9F7FC4540D71533C2DBE145405E6919A9F7FC4540
59780	9803	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	пл.Ленина	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
60062	9803	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	Центральная	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
60550	9803	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	Садовая	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
59787	9803	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	Октябрьская	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
59778	9803	43.609963999999998	43.674211999999997	43.976573999999999	43.945810999999999	Кирова	0103000020E6100000010000000500000061DEE34C13CE45403999B85510F9454061DEE34C13CE4540DC0F786000FD45400E492D944CD64540DC0F786000FD45400E492D944CD645403999B85510F9454061DEE34C13CE45403999B85510F94540
59986	10547	43.456316000000001	43.510295999999997	43.896631999999997	43.86506	Победы	0103000020E610000001000000050000001E520C9068BA4540F4893C49BAEE45401E520C9068BA454006465ED6C4F24540CAA31B6151C1454006465ED6C4F24540CAA31B6151C14540F4893C49BAEE45401E520C9068BA4540F4893C49BAEE4540
60065	10547	43.456316000000001	43.510295999999997	43.896631999999997	43.86506	Кутузова	0103000020E610000001000000050000001E520C9068BA4540F4893C49BAEE45401E520C9068BA454006465ED6C4F24540CAA31B6151C1454006465ED6C4F24540CAA31B6151C14540F4893C49BAEE45401E520C9068BA4540F4893C49BAEE4540
60068	10874	43.541198000000001	43.582861999999999	44.032271999999999	44.000416000000001	Клубная	0103000020E610000001000000050000008F54DFF945C545409432A9A10D0046408F54DFF945C54540CB49287D21044640630AD6389BCA4540CB49287D21044640630AD6389BCA45409432A9A10D0046408F54DFF945C545409432A9A10D004640
59568	10399	43.846193999999997	43.872452000000003	44.115803	44.095982999999997	Ленина	0103000020E610000001000000050000002409C21550EC454069FCC22B490C46402409C21550EC4540ACE3F8A1D20E464037AAD381ACEF4540ACE3F8A1D20E464037AAD381ACEF454069FCC22B490C46402409C21550EC454069FCC22B490C4640
60588	10685	43.268380000000001	43.327857000000002	43.914206999999998	43.895767999999997	Первомайская	0103000020E6100000010000000500000043739D465AA24540D3669C86A8F2454043739D465AA245401B6327BC04F54540E161DA37F7A945401B6327BC04F54540E161DA37F7A94540D3669C86A8F2454043739D465AA24540D3669C86A8F24540
60590	10685	43.268380000000001	43.327857000000002	43.914206999999998	43.895767999999997	Октябрьская	0103000020E6100000010000000500000043739D465AA24540D3669C86A8F2454043739D465AA245401B6327BC04F54540E161DA37F7A945401B6327BC04F54540E161DA37F7A94540D3669C86A8F2454043739D465AA24540D3669C86A8F24540
60558	10685	43.268380000000001	43.327857000000002	43.914206999999998	43.895767999999997	30 лет Победы	0103000020E6100000010000000500000043739D465AA24540D3669C86A8F2454043739D465AA245401B6327BC04F54540E161DA37F7A945401B6327BC04F54540E161DA37F7A94540D3669C86A8F2454043739D465AA24540D3669C86A8F24540
59982	10338	43.922308000000001	43.96125	44.037916000000003	44.014887000000002	Калинина	0103000020E610000001000000050000006A6B44300EF645405A1135D1E70146406A6B44300EF6454061FF756EDA044640D7A3703D0AFB454061FF756EDA044640D7A3703D0AFB45405A1135D1E70146406A6B44300EF645405A1135D1E7014640
60350	57632	43.153044999999999	43.197952000000001	45.634143000000002	45.626094999999999	Центральная	0103000020E610000001000000050000007DE882FA96934540359886E123D046407DE882FA9693454061FE0A992BD14640C216BB7D5699454061FE0A992BD14640C216BB7D56994540359886E123D046407DE882FA96934540359886E123D04640
59566	9738	42.092098999999997	42.163111000000001	45.914530999999997	45.889726000000003	Ленина	0103000020E61000000100000005000000457F68E6C90B45405133A48AE2F14640457F68E6C90B4540CE16105A0FF54640164F3DD2E0144540CE16105A0FF54640164F3DD2E01445405133A48AE2F14640457F68E6C90B45405133A48AE2F14640
60593	9055	42.369273999999997	42.387492000000002	45.699179999999998	45.691052999999997	Дорожный	0103000020E61000000100000005000000ADA1D45E442F4540BE66B96C74D84640ADA1D45E442F45403602F1BA7ED9464017BB7D56993145403602F1BA7ED9464017BB7D5699314540BE66B96C74D84640ADA1D45E442F4540BE66B96C74D84640
60380	8963	42.441929999999999	42.510696000000003	45.686526000000001	45.656706	Пролетарская	0103000020E61000000100000005000000868F882991384540228B34F10ED44640868F88299138454046ED7E15E0D7464059198D7C5E41454046ED7E15E0D7464059198D7C5E414540228B34F10ED44640868F882991384540228B34F10ED44640
60051	9731	43.221074000000002	43.241439	45.721169000000003	45.706803000000001	Центральная площадь	0103000020E610000001000000050000007AFF1F274C9C45407BDB4C8578DA46407AFF1F274C9C4540CCF10A444FDC46404E7D2079E79E4540CCF10A444FDC46404E7D2079E79E45407BDB4C8578DA46407AFF1F274C9C45407BDB4C8578DA4640
60402	8875	42.553275999999997	42.592218000000003	45.6357	45.618341999999998	Новая	0103000020E61000000100000005000000B2D47ABFD146454022DFA5D425CF4640B2D47ABFD14645409A081B9E5ED14640200DA7CCCD4B45409A081B9E5ED14640200DA7CCCD4B454022DFA5D425CF4640B2D47ABFD146454022DFA5D425CF4640
60060	9642	42.182290000000002	42.256813999999999	46.075170999999997	46.037309	Попова	0103000020E61000000100000005000000A5315A4755174540596C938AC6044740A5315A4755174540C64D0D349F094740D593F947DF204540C64D0D349F094740D593F947DF204540596C938AC6044740A5315A4755174540596C938AC6044740
59779	9586	42.787314000000002	42.864012000000002	45.635618000000001	45.613733000000003	Калинина	0103000020E610000001000000050000006BD784B4C6644540EDBC8DCD8ECE46406BD784B4C6644540DD5F3DEE5BD1464000ADF9F1976E4540DD5F3DEE5BD1464000ADF9F1976E4540EDBC8DCD8ECE46406BD784B4C6644540EDBC8DCD8ECE4640
60372	57641	42.967759000000001	42.982813999999998	45.626404000000001	45.616658999999999	Буденного	0103000020E6100000010000000500000070B4E386DF7B45405CE49EAEEECE464070B4E386DF7B4540B30A9B012ED04640850662D9CC7D4540B30A9B012ED04640850662D9CC7D45405CE49EAEEECE464070B4E386DF7B45405CE49EAEEECE4640
60471	9309	42.951839999999997	42.965701000000003	45.653815000000002	45.641018000000003	Шоссейная	0103000020E610000001000000050000002783A3E4D5794540DC12B9E00CD246402783A3E4D57945402F51BD35B0D34640755B22179C7B45402F51BD35B0D34640755B22179C7B4540DC12B9E00CD246402783A3E4D5794540DC12B9E00CD24640
60357	57634	43.047699999999999	43.088250000000002	45.592230999999998	45.582852000000003	Центральная	0103000020E6100000010000000500000075029A081B8645404034F3E49ACA464075029A081B864540B456B439CECB46409EEFA7C64B8B4540B456B439CECB46409EEFA7C64B8B45404034F3E49ACA464075029A081B8645404034F3E49ACA4640
59565	9225	42.994563999999997	43.034818000000001	45.752307000000002	45.729286000000002	Ленина	0103000020E61000000100000005000000B4E386DF4D7F454020B75F3E59DD4640B4E386DF4D7F4540A4C684984BE04640F4A78DEA74844540A4C684984BE04640F4A78DEA7484454020B75F3E59DD4640B4E386DF4D7F454020B75F3E59DD4640
60489	9148	42.219318000000001	42.233961000000001	45.804510000000001	45.796813	Мира	0103000020E610000001000000050000004AB6BA9C121C45408A03E8F7FDE546404AB6BA9C121C454009A7052FFAE646400DC51D6FF21D454009A7052FFAE646400DC51D6FF21D45408A03E8F7FDE546404AB6BA9C121C45408A03E8F7FDE54640
60467	9488	42.908290000000001	42.936101999999998	45.583098	45.562196999999998	Почтовая	0103000020E6100000010000000500000055A4C2D84274454064744012F6C7464055A4C2D842744540772E8CF4A2CA46402FDCB930D2774540772E8CF4A2CA46402FDCB930D277454064744012F6C7464055A4C2D84274454064744012F6C74640
59563	9112	42.499583999999999	42.545425000000002	45.836303999999998	45.815139000000002	Центральная	0103000020E610000001000000050000006CCD565EF23F4540DA58897956E846406CCD565EF23F4540CAC16C020CEB4640DDB5847CD0454540CAC16C020CEB4640DDB5847CD0454540DA58897956E846406CCD565EF23F4540DA58897956E84640
60382	9214	42.062013999999998	42.098045999999997	45.829270999999999	45.814323000000002	Ленина	0103000020E6100000010000000500000073F22213F0074540B8B06EBC3BE8464073F22213F0074540B742588D25EA464076C075C58C0C4540B742588D25EA464076C075C58C0C4540B8B06EBC3BE8464073F22213F0074540B8B06EBC3BE84640
59562	9060	42.646197999999998	42.730477999999998	45.816307999999999	45.783628	Ленина	0103000020E61000000100000005000000CC5EB69DB65245406D1D1CEC4DE44640CC5EB69DB652454049BBD1C77CE846404739984D805D454049BBD1C77CE846404739984D805D45406D1D1CEC4DE44640CC5EB69DB65245406D1D1CEC4DE44640
60057	8050	42.850195999999997	42.943944000000002	45.734180000000002	45.685437	Орджоникидзе	0103000020E610000001000000050000005298F738D36C4540F33B4D66BCD746405298F738D36C45404BB0389CF9DD4640B2A03028D37845404BB0389CF9DD4640B2A03028D3784540F33B4D66BCD746405298F738D36C4540F33B4D66BCD74640
59559	8050	42.850195999999997	42.943944000000002	45.734180000000002	45.685437	Ленина	0103000020E610000001000000050000005298F738D36C4540F33B4D66BCD746405298F738D36C45404BB0389CF9DD4640B2A03028D37845404BB0389CF9DD4640B2A03028D3784540F33B4D66BCD746405298F738D36C4540F33B4D66BCD74640
60123	8050	42.850195999999997	42.943944000000002	45.734180000000002	45.685437	Заречная	0103000020E610000001000000050000005298F738D36C4540F33B4D66BCD746405298F738D36C45404BB0389CF9DD4640B2A03028D37845404BB0389CF9DD4640B2A03028D3784540F33B4D66BCD746405298F738D36C4540F33B4D66BCD74640
59978	8050	42.850195999999997	42.943944000000002	45.734180000000002	45.685437	Голубовского	0103000020E610000001000000050000005298F738D36C4540F33B4D66BCD746405298F738D36C45404BB0389CF9DD4640B2A03028D37845404BB0389CF9DD4640B2A03028D3784540F33B4D66BCD746405298F738D36C4540F33B4D66BCD74640
60324	8958	42.516337	42.562502000000002	45.653103000000002	45.634912	Юбилейная	0103000020E610000001000000050000007D5BB0541742454042EBE1CB44D146407D5BB05417424540B2F50CE198D34640A1F7C61000484540B2F50CE198D34640A1F7C6100048454042EBE1CB44D146407D5BB0541742454042EBE1CB44D14640
60426	8817	42.891680000000001	42.911479	45.870251000000003	45.859419000000003	Новая	0103000020E61000000100000005000000A73FFB9122724540D047197101EE4640A73FFB9122724540D927806264EF4640D2FE0758AB744540D927806264EF4640D2FE0758AB744540D047197101EE4640A73FFB9122724540D047197101EE4640
60310	8819	42.386980000000001	42.416705	45.603740000000002	45.585059999999999	Ленина	0103000020E61000000100000005000000611A868F883145405019FF3EE3CA4640611A868F88314540BEA4315A47CD4640338AE59656354540BEA4315A47CD4640338AE596563545405019FF3EE3CA4640611A868F883145405019FF3EE3CA4640
59776	8769	43.029356	43.055855999999999	45.825296000000002	45.811219000000001	Советская	0103000020E610000001000000050000007FF8F9EFC183454069723106D6E746407FF8F9EFC183454083C2A04CA3E9464087A4164A2687454083C2A04CA3E9464087A4164A2687454069723106D6E746407FF8F9EFC183454069723106D6E74640
60495	9396	43.023256000000003	43.040190000000003	45.602473000000003	45.592199999999998	Гагарина	0103000020E61000000100000005000000C8B7770DFA8245407958A835CDCB4640C8B7770DFA8245408CDCD3D51DCD464029D027F2248545408CDCD3D51DCD464029D027F2248545407958A835CDCB4640C8B7770DFA8245407958A835CDCB4640
59567	8695	42.517055999999997	42.563426999999997	45.922324000000003	45.894989000000002	Музыкальный	0103000020E61000000100000005000000AC1919E42E424540CFA3E2FF8EF24640AC1919E42E42454070287CB60EF6464079573D601E48454070287CB60EF6464079573D601E484540CFA3E2FF8EF24640AC1919E42E424540CFA3E2FF8EF24640
59985	8596	42.292064000000003	42.328130999999999	45.872290999999997	45.837170999999998	Ленина	0103000020E61000000100000005000000632B685A622545406E14596B28EB4640632B685A622545402DCC423BA7EF4640E2E65432002A45402DCC423BA7EF4640E2E65432002A45406E14596B28EB4640632B685A622545406E14596B28EB4640
60272	8599	42.650671000000003	42.721746000000003	45.994154999999999	45.948599000000002	Ленина	0103000020E6100000010000000500000052BAF42F49534540580229B16BF9464052BAF42F49534540D313967840FF46406902452C625C4540D313967840FF46406902452C625C4540580229B16BF9464052BAF42F49534540580229B16BF94640
60058	8599	42.650671000000003	42.721746000000003	45.994154999999999	45.948599000000002	Базарная	0103000020E6100000010000000500000052BAF42F49534540580229B16BF9464052BAF42F49534540D313967840FF46406902452C625C4540D313967840FF46406902452C625C4540580229B16BF9464052BAF42F49534540580229B16BF94640
60267	6880	41.762821000000002	41.779412999999998	45.349809	45.337057000000001	Победы	0103000020E61000000100000005000000DCD9571EA4E14440A6F10BAF24AB4640DCD9571EA4E14440596C938AC6AC4640E38920CEC3E34440596C938AC6AC4640E38920CEC3E34440A6F10BAF24AB4640DCD9571EA4E14440A6F10BAF24AB4640
60271	7502	41.642527999999999	41.672235000000001	45.163333999999999	45.13682	Пушкина	0103000020E61000000100000005000000D461855B3ED2444028B8585183914640D461855B3ED244409529E620E8944640001DE6CB0BD644409529E620E8944640001DE6CB0BD6444028B8585183914640D461855B3ED2444028B8585183914640
59967	6952	41.639868999999997	41.687730999999999	45.477044999999997	45.443964000000001	Мира	0103000020E61000000100000005000000B35C363AE7D14440F94CF6CFD3B84640B35C363AE7D1444033DC80CF0FBD464002B9C49107D8444033DC80CF0FBD464002B9C49107D84440F94CF6CFD3B84640B35C363AE7D14440F94CF6CFD3B84640
60500	57665	41.644917	41.702382999999998	45.277901999999997	45.262317000000003	Тюльпина	0103000020E6100000010000000500000035D1E7A38CD24440A9177C9A93A1464035D1E7A38CD244401ABFF04A92A346401822A7AFE7D944401ABFF04A92A346401822A7AFE7D94440A9177C9A93A1464035D1E7A38CD24440A9177C9A93A14640
60594	7507	41.64922	41.699086000000001	45.306562	45.279761000000001	Мира	0103000020E610000001000000050000005EF415A419D344401FD95C35CFA346405EF415A419D344402219726C3DA74640B58B69A67BD944402219726C3DA74640B58B69A67BD944401FD95C35CFA346405EF415A419D344401FD95C35CFA34640
60231	57619	41.754835	41.788989000000001	45.331583000000002	45.295676999999998	Мира	0103000020E610000001000000050000002670EB6E9EE04440F69672BED8A546402670EB6E9EE044406D74CE4F71AA4640AEF36F97FDE444406D74CE4F71AA4640AEF36F97FDE44440F69672BED8A546402670EB6E9EE04440F69672BED8A54640
60053	6407	41.483651999999999	41.549174999999998	45.322755999999998	45.290762999999998	б-р Школьный	0103000020E610000001000000050000008F52094FE8BD444084F1D3B837A546408F52094FE8BD44403C4B901150A94640F163CC5D4BC644403C4B901150A94640F163CC5D4BC6444084F1D3B837A546408F52094FE8BD444084F1D3B837A54640
59555	6407	41.483651999999999	41.549174999999998	45.322755999999998	45.290762999999998	Школьный б-р	0103000020E610000001000000050000008F52094FE8BD444084F1D3B837A546408F52094FE8BD44403C4B901150A94640F163CC5D4BC644403C4B901150A94640F163CC5D4BC6444084F1D3B837A546408F52094FE8BD444084F1D3B837A54640
59557	6407	41.483651999999999	41.549174999999998	45.322755999999998	45.290762999999998	Молодежная	0103000020E610000001000000050000008F52094FE8BD444084F1D3B837A546408F52094FE8BD44403C4B901150A94640F163CC5D4BC644403C4B901150A94640F163CC5D4BC6444084F1D3B837A546408F52094FE8BD444084F1D3B837A54640
60488	7563	41.535952000000002	41.558014	45.274363000000001	45.262856999999997	Центральная	0103000020E61000000100000005000000E71C3C139AC444402843554CA5A14640E71C3C139AC44440C11DA8531EA34640E65AB4006DC74440C11DA8531EA34640E65AB4006DC744402843554CA5A14640E71C3C139AC444402843554CA5A14640
60054	6700	41.828470000000003	41.856965000000002	45.288176	45.257241999999998	Южная	0103000020E61000000100000005000000CBDB114E0BEA44402D944C4EEDA04640CBDB114E0BEA4440FDBE7FF3E2A4464088687407B1ED4440FDBE7FF3E2A4464088687407B1ED44402D944C4EEDA04640CBDB114E0BEA44402D944C4EEDA04640
59968	6700	41.828470000000003	41.856965000000002	45.288176	45.257241999999998	Советская	0103000020E61000000100000005000000CBDB114E0BEA44402D944C4EEDA04640CBDB114E0BEA4440FDBE7FF3E2A4464088687407B1ED4440FDBE7FF3E2A4464088687407B1ED44402D944C4EEDA04640CBDB114E0BEA44402D944C4EEDA04640
59973	6700	41.828470000000003	41.856965000000002	45.288176	45.257241999999998	Восточная	0103000020E61000000100000005000000CBDB114E0BEA44402D944C4EEDA04640CBDB114E0BEA4440FDBE7FF3E2A4464088687407B1ED4440FDBE7FF3E2A4464088687407B1ED44402D944C4EEDA04640CBDB114E0BEA44402D944C4EEDA04640
59558	7681	41.773772000000001	41.855823999999998	45.252127999999999	45.194623999999997	Ленина	0103000020E61000000100000005000000BF47FDF50AE3444023827170E9984640BF47FDF50AE34440F433F5BA45A04640E2900DA48BED4440F433F5BA45A04640E2900DA48BED444023827170E9984640BF47FDF50AE3444023827170E9984640
60289	7027	41.686599000000001	41.743983999999998	45.542057	45.504125000000002	Кошевого	0103000020E61000000100000005000000B03BDD79E2D744404A0C022B87C04640B03BDD79E2D74440B0C8AF1F62C54640A65F22DE3ADF4440B0C8AF1F62C54640A65F22DE3ADF44404A0C022B87C04640B03BDD79E2D744404A0C022B87C04640
60056	7027	41.686599000000001	41.743983999999998	45.542057	45.504125000000002	Карла Маркса	0103000020E61000000100000005000000B03BDD79E2D744404A0C022B87C04640B03BDD79E2D74440B0C8AF1F62C54640A65F22DE3ADF4440B0C8AF1F62C54640A65F22DE3ADF44404A0C022B87C04640B03BDD79E2D744404A0C022B87C04640
59775	7762	41.944074000000001	41.996895000000002	45.292855000000003	45.257894999999998	Калинина	0103000020E610000001000000050000008080B56AD7F84440A5660FB402A146408080B56AD7F844402CBCCB457CA54640E1455F419AFF44402CBCCB457CA54640E1455F419AFF4440A5660FB402A146408080B56AD7F84440A5660FB402A14640
59770	7128	41.503135999999998	41.568291000000002	45.451242000000001	45.435053000000003	Октября	0103000020E610000001000000050000005AB8ACC266C044406B8313D1AFB746405AB8ACC266C04440734A404CC2B946403ACE6DC2BDC84440734A404CC2B946403ACE6DC2BDC844406B8313D1AFB746405AB8ACC266C044406B8313D1AFB74640
60055	7234	41.498950000000001	41.564922000000003	45.419770999999997	45.307690000000001	Шоссейная	0103000020E610000001000000050000006B2BF697DDBF444033A7CB6262A746406B2BF697DDBF444094675E0EBBB546403D65355D4FC8444094675E0EBBB546403D65355D4FC8444033A7CB6262A746406B2BF697DDBF444033A7CB6262A74640
59773	7234	41.498950000000001	41.564922000000003	45.419770999999997	45.307690000000001	Первомайская	0103000020E610000001000000050000006B2BF697DDBF444033A7CB6262A746406B2BF697DDBF444094675E0EBBB546403D65355D4FC8444094675E0EBBB546403D65355D4FC8444033A7CB6262A746406B2BF697DDBF444033A7CB6262A74640
59777	7234	41.498950000000001	41.564922000000003	45.419770999999997	45.307690000000001	Мещерякова	0103000020E610000001000000050000006B2BF697DDBF444033A7CB6262A746406B2BF697DDBF444094675E0EBBB546403D65355D4FC8444094675E0EBBB546403D65355D4FC8444033A7CB6262A746406B2BF697DDBF444033A7CB6262A74640
60273	7234	41.498950000000001	41.564922000000003	45.419770999999997	45.307690000000001	Ленина	0103000020E610000001000000050000006B2BF697DDBF444033A7CB6262A746406B2BF697DDBF444094675E0EBBB546403D65355D4FC8444094675E0EBBB546403D65355D4FC8444033A7CB6262A746406B2BF697DDBF444033A7CB6262A74640
60269	6877	41.704889000000001	41.722028999999999	45.426760999999999	45.412919000000002	Школьная	0103000020E61000000100000005000000B32781CD39DA4440D272A087DAB44640B32781CD39DA4440A81ABD1AA0B64640BDE13E726BDC4440A81ABD1AA0B64640BDE13E726BDC4440D272A087DAB44640B32781CD39DA4440D272A087DAB44640
60561	57682	41.797811000000003	41.815561000000002	45.347591999999999	45.323700000000002	Ленина	0103000020E61000000100000005000000CDB1BCAB1EE644408CDB68006FA94640CDB1BCAB1EE64440F52C08E57DAC46405072874D64E84440F52C08E57DAC46405072874D64E844408CDB68006FA94640CDB1BCAB1EE644408CDB68006FA94640
59974	7820	41.889412	41.968885999999998	45.328592	45.246955999999997	Мира	0103000020E61000000100000005000000C1559E40D8F1444086C613419C9F4640C1559E40D8F1444016DD7A4D0FAA4640B0C6D97404FC444016DD7A4D0FAA4640B0C6D97404FC444086C613419C9F4640C1559E40D8F1444086C613419C9F4640
60083	7820	41.889412	41.968885999999998	45.328592	45.246955999999997	Ленина	0103000020E61000000100000005000000C1559E40D8F1444086C613419C9F4640C1559E40D8F1444016DD7A4D0FAA4640B0C6D97404FC444016DD7A4D0FAA4640B0C6D97404FC444086C613419C9F4640C1559E40D8F1444086C613419C9F4640
60470	7820	41.889412	41.968885999999998	45.328592	45.246955999999997	Гоголя	0103000020E61000000100000005000000C1559E40D8F1444086C613419C9F4640C1559E40D8F1444016DD7A4D0FAA4640B0C6D97404FC444016DD7A4D0FAA4640B0C6D97404FC444086C613419C9F4640C1559E40D8F1444086C613419C9F4640
59702	7091	41.960656999999998	41.984076000000002	45.309483999999998	45.285246000000001	Красная	0103000020E6100000010000000500000034D6FECEF6FA44404CA8E0F082A4464034D6FECEF6FA44405051F52B9DA74640A663CE33F6FD44405051F52B9DA74640A663CE33F6FD44404CA8E0F082A4464034D6FECEF6FA44404CA8E0F082A44640
60001	7415	41.491916000000003	41.540802999999997	45.203496999999999	45.163645000000002	Мира	0103000020E6100000010000000500000088307E1AF7BE4440B493C151F294464088307E1AF7BE4440C4EA8F300C9A4640124A5F0839C54440C4EA8F300C9A4640124A5F0839C54440B493C151F294464088307E1AF7BE4440B493C151F2944640
60555	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Южная	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
59550	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Электронная	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60044	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Школьная	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60048	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Промышленная	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60575	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Привокзальная площадь	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
59554	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Новотроицкое шоссе	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
59552	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Ленина	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60047	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Крупской	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
59969	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Красноармейская	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60059	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Красная	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60034	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Колхозная	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
59762	31885	43.350144	43.436104	44.129412000000002	44.095756999999999	Школьная	0103000020E610000001000000050000000072C284D1AC454079AEEFC3410C46400072C284D1AC4540E0DA899290104640D0D38041D2B74540E0DA899290104640D0D38041D2B7454079AEEFC3410C46400072C284D1AC454079AEEFC3410C4640
59772	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Заводская	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
59771	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Доватора	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60052	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	Бонивура	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
59553	5219	41.676709000000002	41.739896000000002	45.392263999999997	45.349037000000003	50 лет Октября	0103000020E6100000010000000500000056F487669ED64440070C923EADAC464056F487669ED64440F6B2EDB435B246407A3881E9B4DE4440F6B2EDB435B246407A3881E9B4DE4440070C923EADAC464056F487669ED64440070C923EADAC4640
60406	7216	41.470905000000002	41.495742999999997	45.561672999999999	45.544770999999997	Красная	0103000020E61000000100000005000000EE42739D46BC444094675E0EBBC54640EE42739D46BC4440EA059FE6E4C74640471CB28174BF4440EA059FE6E4C74640471CB28174BF444094675E0EBBC54640EE42739D46BC444094675E0EBBC54640
60476	57663	41.841890999999997	41.877023999999999	45.373893000000002	45.333869999999997	Пролетарская	0103000020E61000000100000005000000FBE59315C3EB4440C98E8D40BCAA4640FBE59315C3EB4440079ACFB9DBAF46404FE78A5242F04440079ACFB9DBAF46404FE78A5242F04440C98E8D40BCAA4640FBE59315C3EB4440C98E8D40BCAA4640
60570	4767	43.046495999999998	43.142310000000002	44.125076	44.069375999999998	8 марта	0103000020E6100000010000000500000089B2B794F38545404B901150E108464089B2B794F3854540DBC1887D0210464067F2CD3637924540DBC1887D0210464067F2CD36379245404B901150E108464089B2B794F38545404B901150E1084640
59948	1644	42.211520999999998	42.276046999999998	45.350411000000001	45.314535999999997	Гагарина	0103000020E6100000010000000500000067B5C01E131B454013B534B742A8464067B5C01E131B45404F948444DAAC464057941282552345404F948444DAAC4640579412825523454013B534B742A8464067B5C01E131B454013B534B742A84640
59941	1401	42.187562999999997	42.292386999999998	45.107801000000002	45.069422000000003	Свердлова	0103000020E6100000010000000500000046787B1002184540BCCFF1D1E288464046787B1002184540F1BC546CCC8D46404563EDEF6C254540F1BC546CCC8D46404563EDEF6C254540BCCFF1D1E288464046787B1002184540BCCFF1D1E2884640
60377	1401	42.187562999999997	42.292386999999998	45.107801000000002	45.069422000000003	Красная	0103000020E6100000010000000500000046787B1002184540BCCFF1D1E288464046787B1002184540F1BC546CCC8D46404563EDEF6C254540F1BC546CCC8D46404563EDEF6C254540BCCFF1D1E288464046787B1002184540BCCFF1D1E2884640
60303	1401	42.187562999999997	42.292386999999998	45.107801000000002	45.069422000000003	Войкова	0103000020E6100000010000000500000046787B1002184540BCCFF1D1E288464046787B1002184540F1BC546CCC8D46404563EDEF6C254540F1BC546CCC8D46404563EDEF6C254540BCCFF1D1E288464046787B1002184540BCCFF1D1E2884640
60061	1254	42.481302999999997	42.532094000000001	45.135433999999997	45.109467000000002	площадь Революции	0103000020E61000000100000005000000BC3B32569B3D4540E17EC003038E4640BC3B32569B3D45401B62BCE655914640EC32FCA71B4445401B62BCE655914640EC32FCA71B444540E17EC003038E4640BC3B32569B3D4540E17EC003038E4640
59943	1127	42.681061	42.718153000000001	44.977032000000001	44.933684	Карла Маркса	0103000020E6100000010000000500000060CAC0012D574540346612F58277464060CAC0012D5745409F9273620F7D46401C430070EC5B45409F9273620F7D46401C430070EC5B4540346612F58277464060CAC0012D574540346612F582774640
60512	57671	42.791096000000003	42.816364999999998	45.020577000000003	45.001140999999997	Садовая	0103000020E610000001000000050000008BFF3BA242654540A5D76663258046408BFF3BA24265454060066344A2824640AD4CF8A57E68454060066344A2824640AD4CF8A57E684540A5D76663258046408BFF3BA242654540A5D7666325804640
60420	1358	42.644221000000002	42.654318000000004	45.115980999999998	45.106096000000001	Центральная	0103000020E61000000100000005000000BE326FD575524540431EC18D948D4640BE326FD5755245408BFA2477D88E4640929735B1C05345408BFA2477D88E4640929735B1C0534540431EC18D948D4640BE326FD575524540431EC18D948D4640
60479	891	42.400877000000001	42.413282000000002	45.080415000000002	45.069422000000003	Октябрьская	0103000020E61000000100000005000000FB5B02F04F334540BCCFF1D1E2884640FB5B02F04F334540CE8DE9094B8A46404303B16CE6344540CE8DE9094B8A46404303B16CE6344540BCCFF1D1E2884640FB5B02F04F334540BCCFF1D1E2884640
59764	941	42.352341000000003	42.421655000000001	45.382358000000004	45.345742999999999	Советская	0103000020E610000001000000050000001D058882192D454014E97E4E41AC46401D058882192D454097AE601BF1B04640F29881CAF835454097AE601BF1B04640F29881CAF835454014E97E4E41AC46401D058882192D454014E97E4E41AC4640
59781	941	42.352341000000003	42.421655000000001	45.382358000000004	45.345742999999999	Красная	0103000020E610000001000000050000001D058882192D454014E97E4E41AC46401D058882192D454097AE601BF1B04640F29881CAF835454097AE601BF1B04640F29881CAF835454014E97E4E41AC46401D058882192D454014E97E4E41AC4640
60416	1585	42.191048000000002	42.234076999999999	45.162087999999997	45.151614000000002	Центральная	0103000020E61000000100000005000000ADFBC74274184540D1CE691668934640ADFBC742741845407A89B14CBF94464076DF313CF61D45407A89B14CBF94464076DF313CF61D4540D1CE691668934640ADFBC74274184540D1CE691668934640
59688	569	42.381993999999999	42.445092000000002	45.213935999999997	45.191263999999997	Шоссейная	0103000020E6100000010000000500000055A2EC2DE53045407973B8567B98464055A2EC2DE5304540F1B73D41629B46400ADB4FC6F8384540F1B73D41629B46400ADB4FC6F83845407973B8567B98464055A2EC2DE53045407973B8567B984640
59944	569	42.381993999999999	42.445092000000002	45.213935999999997	45.191263999999997	Ставропольская	0103000020E6100000010000000500000055A2EC2DE53045407973B8567B98464055A2EC2DE5304540F1B73D41629B46400ADB4FC6F8384540F1B73D41629B46400ADB4FC6F83845407973B8567B98464055A2EC2DE53045407973B8567B984640
60036	569	42.381993999999999	42.445092000000002	45.213935999999997	45.191263999999997	Советская	0103000020E6100000010000000500000055A2EC2DE53045407973B8567B98464055A2EC2DE5304540F1B73D41629B46400ADB4FC6F8384540F1B73D41629B46400ADB4FC6F83845407973B8567B98464055A2EC2DE53045407973B8567B984640
59547	1055	42.374799000000003	42.394686999999998	45.350873999999997	45.341327	Ленина	0103000020E6100000010000000500000069C9E369F92F4540F31E679AB0AB464069C9E369F92F454023827170E9AC46400394861A8532454023827170E9AC46400394861A85324540F31E679AB0AB464069C9E369F92F4540F31E679AB0AB4640
59546	451	42.346133000000002	42.401513999999999	45.044590999999997	44.998368999999997	Ленина	0103000020E610000001000000050000007F880D164E2C45408C2B2E8ECA7F46407F880D164E2C454014596B28B58546406D718DCF6433454014596B28B58546406D718DCF643345408C2B2E8ECA7F46407F880D164E2C45408C2B2E8ECA7F4640
60513	57672	42.450392000000001	42.486477000000001	45.055480000000003	45.042158000000001	Красная	0103000020E61000000100000005000000A530EF71A6394540E4A1EF6E65854640A530EF71A639454082CAF8F719874640CBA0DAE0443E454082CAF8F719874640CBA0DAE0443E4540E4A1EF6E65854640A530EF71A6394540E4A1EF6E65854640
59545	315	43.519790999999998	43.558292999999999	44.1723	44.150708000000002	Советская	0103000020E61000000100000005000000A8E0F08288C245406F9F55664A134640A8E0F08288C24540E78C28ED0D164640F94A202576C74540E78C28ED0D164640F94A202576C745406F9F55664A134640A8E0F08288C245406F9F55664A134640
59940	186	43.649050000000003	43.687516000000002	44.164462999999998	44.139995999999996	Ленина	0103000020E6100000010000000500000002BC051214D3454010C99063EB11464002BC051214D345407633A31F0D15464006BD378600D845407633A31F0D15464006BD378600D8454010C99063EB11464002BC051214D3454010C99063EB114640
60482	32202	43.425567000000001	43.435277999999997	43.983987999999997	43.974089999999997	Центральная	0103000020E61000000100000005000000E0A0BDFA78B6454029AE2AFBAEFC4540E0A0BDFA78B6454006D49B51F3FD45408A558330B7B7454006D49B51F3FD45408A558330B7B7454029AE2AFBAEFC4540E0A0BDFA78B6454029AE2AFBAEFC4540
59686	8	43.394961000000002	43.448994999999996	44.210420999999997	44.189740999999998	Ленина	0103000020E61000000100000005000000051901158EB24540ECDADE6E49184640051901158EB2454020B24813EF1A4640A4880CAB78B9454020B24813EF1A4640A4880CAB78B94540ECDADE6E49184640051901158EB24540ECDADE6E49184640
60045	8	43.394961000000002	43.448994999999996	44.210420999999997	44.189740999999998	 Ленина	0103000020E61000000100000005000000051901158EB24540ECDADE6E49184640051901158EB2454020B24813EF1A4640A4880CAB78B9454020B24813EF1A4640A4880CAB78B94540ECDADE6E49184640051901158EB24540ECDADE6E49184640
59757	31674	43.278413999999998	43.303018999999999	44.397632999999999	44.379049000000002	40 лет Победы	0103000020E61000000100000005000000D05FE811A3A345406F4A79AD84304640D05FE811A3A34540BA675DA3E532464087889B53C9A64540BA675DA3E532464087889B53C9A645406F4A79AD84304640D05FE811A3A345406F4A79AD84304640
59934	32365	43.512298999999999	43.589661999999997	44.267498000000003	44.223058000000002	Советская	0103000020E6100000010000000500000002637D0393C145403B8E1F2A8D1C464002637D0393C145406ADFDC5F3D224640D3D85E0B7ACB45406ADFDC5F3D224640D3D85E0B7ACB45403B8E1F2A8D1C464002637D0393C145403B8E1F2A8D1C4640
59543	32365	43.512298999999999	43.589661999999997	44.267498000000003	44.223058000000002	Ленина	0103000020E6100000010000000500000002637D0393C145403B8E1F2A8D1C464002637D0393C145406ADFDC5F3D224640D3D85E0B7ACB45406ADFDC5F3D224640D3D85E0B7ACB45403B8E1F2A8D1C464002637D0393C145403B8E1F2A8D1C4640
60301	57628	43.421577999999997	43.461544000000004	44.180923999999997	44.132323	60 лет СССР	0103000020E61000000100000005000000465B9544F6B545401AC1C6F5EF104640465B9544F6B54540DF8783842817464020D5B0DF13BB4540DF8783842817464020D5B0DF13BB45401AC1C6F5EF104640465B9544F6B545401AC1C6F5EF104640
59984	124	43.370311999999998	43.419710000000002	44.465927000000001	44.446503	Кооперативная	0103000020E610000001000000050000007EA8346266AF45406F48A302273946407EA8346266AF454065A9F57EA33B4640EFE6A90EB9B5454065A9F57EA33B4640EFE6A90EB9B545406F48A302273946407EA8346266AF45406F48A30227394640
60414	389	43.565317999999998	43.585825999999997	44.197529000000003	44.191007999999997	Продольная	0103000020E6100000010000000500000089EB18575CC845401EA33CF37218464089EB18575CC845407C8159A148194640C092AB58FCCA45407C8159A148194640C092AB58FCCA45401EA33CF37218464089EB18575CC845401EA33CF372184640
59542	32283	43.608212000000002	43.670313	44.270479999999999	44.246025000000003	Школьная	0103000020E6100000010000000500000073840CE4D9CD4540CC7F48BF7D1F464073840CE4D9CD45406D1CB1169F224640B58AFED0CCD545406D1CB1169F224640B58AFED0CCD54540CC7F48BF7D1F464073840CE4D9CD4540CC7F48BF7D1F4640
59938	32283	43.608212000000002	43.670313	44.270479999999999	44.246025000000003	Кооперативная	0103000020E6100000010000000500000073840CE4D9CD4540CC7F48BF7D1F464073840CE4D9CD45406D1CB1169F224640B58AFED0CCD545406D1CB1169F224640B58AFED0CCD54540CC7F48BF7D1F464073840CE4D9CD4540CC7F48BF7D1F4640
60299	270	43.622199000000002	43.653928000000001	44.124721000000001	44.112670999999999	Школьная	0103000020E610000001000000050000004D4D8237A4CF4540931ADA006C0E46404D4D8237A4CF4540ED0F94DBF60F464027F8A6E9B3D34540ED0F94DBF60F464027F8A6E9B3D34540931ADA006C0E46404D4D8237A4CF4540931ADA006C0E4640
60035	31885	43.350144	43.436104	44.129412000000002	44.095756999999999	Юбилейная	0103000020E610000001000000050000000072C284D1AC454079AEEFC3410C46400072C284D1AC4540E0DA899290104640D0D38041D2B74540E0DA899290104640D0D38041D2B7454079AEEFC3410C46400072C284D1AC454079AEEFC3410C4640
59965	31885	43.350144	43.436104	44.129412000000002	44.095756999999999	Упорная	0103000020E610000001000000050000000072C284D1AC454079AEEFC3410C46400072C284D1AC4540E0DA899290104640D0D38041D2B74540E0DA899290104640D0D38041D2B7454079AEEFC3410C46400072C284D1AC454079AEEFC3410C4640
59541	31885	43.350144	43.436104	44.129412000000002	44.095756999999999	Степная	0103000020E610000001000000050000000072C284D1AC454079AEEFC3410C46400072C284D1AC4540E0DA899290104640D0D38041D2B74540E0DA899290104640D0D38041D2B7454079AEEFC3410C46400072C284D1AC454079AEEFC3410C4640
59937	31885	43.350144	43.436104	44.129412000000002	44.095756999999999	Незлобненская	0103000020E610000001000000050000000072C284D1AC454079AEEFC3410C46400072C284D1AC4540E0DA899290104640D0D38041D2B74540E0DA899290104640D0D38041D2B7454079AEEFC3410C46400072C284D1AC454079AEEFC3410C4640
59564	31885	43.350144	43.436104	44.129412000000002	44.095756999999999	Ленина	0103000020E610000001000000050000000072C284D1AC454079AEEFC3410C46400072C284D1AC4540E0DA899290104640D0D38041D2B74540E0DA899290104640D0D38041D2B7454079AEEFC3410C46400072C284D1AC454079AEEFC3410C4640
59540	31748	43.232537000000001	43.325539999999997	44.120190999999998	44.083253999999997	Школьная	0103000020E61000000100000005000000130EBDC5C39D45406EA12B11A80A4640130EBDC5C39D454003232F6B620F464019C5724BABA9454003232F6B620F464019C5724BABA945406EA12B11A80A4640130EBDC5C39D45406EA12B11A80A4640
59759	31748	43.232537000000001	43.325539999999997	44.120190999999998	44.083253999999997	Ленина	0103000020E61000000100000005000000130EBDC5C39D45406EA12B11A80A4640130EBDC5C39D454003232F6B620F464019C5724BABA9454003232F6B620F464019C5724BABA945406EA12B11A80A4640130EBDC5C39D45406EA12B11A80A4640
59758	31425	43.453532000000003	43.509037999999997	44.191744999999997	44.155208999999999	Юбилейная	0103000020E6100000010000000500000041D829560DBA4540BE8575E3DD13464041D829560DBA4540F415A4198B184640EB353D2828C14540F415A4198B184640EB353D2828C14540BE8575E3DD13464041D829560DBA4540BE8575E3DD134640
59538	31425	43.453532000000003	43.509037999999997	44.191744999999997	44.155208999999999	Пионерская	0103000020E6100000010000000500000041D829560DBA4540BE8575E3DD13464041D829560DBA4540F415A4198B184640EB353D2828C14540F415A4198B184640EB353D2828C14540BE8575E3DD13464041D829560DBA4540BE8575E3DD134640
59928	31425	43.453532000000003	43.509037999999997	44.191744999999997	44.155208999999999	Курченко	0103000020E6100000010000000500000041D829560DBA4540BE8575E3DD13464041D829560DBA4540F415A4198B184640EB353D2828C14540F415A4198B184640EB353D2828C14540BE8575E3DD13464041D829560DBA4540BE8575E3DD134640
59544	31425	43.453532000000003	43.509037999999997	44.191744999999997	44.155208999999999	Кирова	0103000020E6100000010000000500000041D829560DBA4540BE8575E3DD13464041D829560DBA4540F415A4198B184640EB353D2828C14540F415A4198B184640EB353D2828C14540BE8575E3DD13464041D829560DBA4540BE8575E3DD134640
60567	16014	43.431863999999997	43.504044	44.122449000000003	44.100133	Кооперативный	0103000020E61000000100000005000000ED28CE5147B745400C207C28D10C4640ED28CE5147B74540C636A968AC0F46405DDF878384C04540C636A968AC0F46405DDF878384C045400C207C28D10C4640ED28CE5147B745400C207C28D10C4640
60043	16014	43.431863999999997	43.504044	44.122449000000003	44.100133	Выгонная	0103000020E61000000100000005000000ED28CE5147B745400C207C28D10C4640ED28CE5147B74540C636A968AC0F46405DDF878384C04540C636A968AC0F46405DDF878384C045400C207C28D10C4640ED28CE5147B745400C207C28D10C4640
60297	31313	43.494674000000003	43.512030000000003	44.528461	44.511178000000001	Новая	0103000020E610000001000000050000003C17467A51BF4540A437DC476E4146403C17467A51BF4540111B2C9CA44346401349F4328AC14540111B2C9CA44346401349F4328AC14540A437DC476E4146403C17467A51BF4540A437DC476E414640
59539	31121	43.301068999999998	43.382151	44.238216999999999	44.206589000000001	Комсомольский	0103000020E61000000100000005000000726BD26D89A645404F5B2382711A4640726BD26D89A64540F52C08E57D1E46401D91EF52EAB04540F52C08E57D1E46401D91EF52EAB045404F5B2382711A4640726BD26D89A645404F5B2382711A4640
59769	31121	43.301068999999998	43.382151	44.238216999999999	44.206589000000001	Гагарина	0103000020E61000000100000005000000726BD26D89A645404F5B2382711A4640726BD26D89A64540F52C08E57D1E46401D91EF52EAB04540F52C08E57D1E46401D91EF52EAB045404F5B2382711A4640726BD26D89A645404F5B2382711A4640
60480	29654	43.897658999999997	43.937435999999998	44.689081000000002	44.673378999999997	Октябрьская	0103000020E61000000100000005000000E3FA777DE6F245401668774831564640E3FA777DE6F24540C2A563CE33584640E90B21E7FDF74540C2A563CE33584640E90B21E7FDF745401668774831564640E3FA777DE6F245401668774831564640
60293	29925	44.132962999999997	44.172372000000003	45.020819000000003	44.989617000000003	 Школьная	0103000020E61000000100000005000000FD497CEE04114640674815C5AB7E4640FD497CEE0411464056116E32AA824640815F23491016464056116E32AA824640815F234910164640674815C5AB7E4640FD497CEE04114640674815C5AB7E4640
60544	15148	44.023099000000002	44.047758000000002	44.598334000000001	44.573162000000004	Школьная	0103000020E6100000010000000500000000C974E8F4024640ADA7565F5D49464000C974E8F4024640DD0A6135964C4640AA0F24EF1C064640DD0A6135964C4640AA0F24EF1C064640ADA7565F5D49464000C974E8F4024640ADA7565F5D494640
60568	16978	43.955204999999999	43.998404999999998	44.695872999999999	44.671647999999998	Артезианская	0103000020E61000000100000005000000E3FC4D2844FA45403F36C98FF8554640E3FC4D2844FA4540AF95D05D12594640D9942BBCCBFF4540AF95D05D12594640D9942BBCCBFF45403F36C98FF8554640E3FC4D2844FA45403F36C98FF8554640
60589	15101	44.181508000000001	44.235973000000001	44.765191999999999	44.717911000000001	Ленина	0103000020E610000001000000050000002FFB75A73B1746402638F581E45B46402FFB75A73B1746409694BBCFF161464098DEFE5C341E46409694BBCFF161464098DEFE5C341E46402638F581E45B46402FFB75A73B1746402638F581E45B4640
59751	15101	44.181508000000001	44.235973000000001	44.765191999999999	44.717911000000001	Дзержинского	0103000020E610000001000000050000002FFB75A73B1746402638F581E45B46402FFB75A73B1746409694BBCFF161464098DEFE5C341E46409694BBCFF161464098DEFE5C341E46402638F581E45B46402FFB75A73B1746402638F581E45B4640
60563	15101	44.181508000000001	44.235973000000001	44.765191999999999	44.717911000000001	Борцов Революции	0103000020E610000001000000050000002FFB75A73B1746402638F581E45B46402FFB75A73B1746409694BBCFF161464098DEFE5C341E46409694BBCFF161464098DEFE5C341E46402638F581E45B46402FFB75A73B1746402638F581E45B4640
60478	29976	43.844935999999997	43.867026000000003	44.687106999999997	44.681646999999998	Октябрьская	0103000020E61000000100000005000000459BE3DC26EC454050357A3540574640459BE3DC26EC454024ED461FF35746400F643DB5FAEE454024ED461FF35746400F643DB5FAEE454050357A3540574640459BE3DC26EC454050357A3540574640
60384	29836	44.023432	44.030707999999997	44.636465000000001	44.619889000000001	Железнодорожная	0103000020E6100000010000000500000006D7DCD1FF0246403813D385584F464006D7DCD1FF0246403A0664AF77514640DFDC5F3DEE0346403A0664AF77514640DFDC5F3DEE0346403813D385584F464006D7DCD1FF0246403813D385584F4640
60199	57591	44.105601	44.106544	44.754337	44.753498	Советская	0103000020E6100000010000000500000063B66455840D4640FBCC599F7260464063B66455840D4640D594641D8E604640E2CAD93BA30D4640D594641D8E604640E2CAD93BA30D4640FBCC599F7260464063B66455840D4640FBCC599F72604640
59756	57591	44.105601	44.106544	44.754337	44.753498	Почтовая	0103000020E6100000010000000500000063B66455840D4640FBCC599F7260464063B66455840D4640D594641D8E604640E2CAD93BA30D4640D594641D8E604640E2CAD93BA30D4640FBCC599F7260464063B66455840D4640FBCC599F72604640
59997	57591	44.105601	44.106544	44.754337	44.753498	Кировская	0103000020E6100000010000000500000063B66455840D4640FBCC599F7260464063B66455840D4640D594641D8E604640E2CAD93BA30D4640D594641D8E604640E2CAD93BA30D4640FBCC599F7260464063B66455840D4640FBCC599F72604640
75526	60666	44.084778	44.093724999999999	44.575878000000003	44.548865999999997	Советская	0103000020E61000000100000005000000CCB56801DA0A464073F1B73D41464640CCB56801DA0A4640323ECC5EB6494640A7E8482EFF0B4640323ECC5EB6494640A7E8482EFF0B464073F1B73D41464640CCB56801DA0A464073F1B73D41464640
59749	45588	44.068815000000001	44.117404000000001	44.640531000000003	44.596491999999998	Советская	0103000020E61000000100000005000000B43C0FEECE084640AE2990D9594C4640B43C0FEECE0846407F8978EBFC514640B5352218070F46407F8978EBFC514640B5352218070F4640AE2990D9594C4640B43C0FEECE084640AE2990D9594C4640
60266	45588	44.068815000000001	44.117404000000001	44.640531000000003	44.596491999999998	 Румянцева	0103000020E61000000100000005000000B43C0FEECE084640AE2990D9594C4640B43C0FEECE0846407F8978EBFC514640B5352218070F46407F8978EBFC514640B5352218070F4640AE2990D9594C4640B43C0FEECE084640AE2990D9594C4640
60396	57611	44.145009999999999	44.145989	44.786408999999999	44.785597000000003	Совхозная	0103000020E61000000100000005000000E6CB0BB08F124640F96A47718E644640E6CB0BB08F124640D923D40CA9644640B2497EC4AF124640D923D40CA9644640B2497EC4AF124640F96A47718E644640E6CB0BB08F124640F96A47718E644640
60174	57611	44.145009999999999	44.145989	44.786408999999999	44.785597000000003	Советская	0103000020E61000000100000005000000E6CB0BB08F124640F96A47718E644640E6CB0BB08F124640D923D40CA9644640B2497EC4AF124640D923D40CA9644640B2497EC4AF124640F96A47718E644640E6CB0BB08F124640F96A47718E644640
60181	57611	44.145009999999999	44.145989	44.786408999999999	44.785597000000003	Ленина	0103000020E61000000100000005000000E6CB0BB08F124640F96A47718E644640E6CB0BB08F124640D923D40CA9644640B2497EC4AF124640D923D40CA9644640B2497EC4AF124640F96A47718E644640E6CB0BB08F124640F96A47718E644640
60607	57611	44.145009999999999	44.145989	44.786408999999999	44.785597000000003	Виноградная	0103000020E61000000100000005000000E6CB0BB08F124640F96A47718E644640E6CB0BB08F124640D923D40CA9644640B2497EC4AF124640D923D40CA9644640B2497EC4AF124640F96A47718E644640E6CB0BB08F124640F96A47718E644640
59939	57577	44.145009999999999	44.145989	44.786408999999999	44.785597000000003	микрорайон 833-А	0103000020E61000000100000005000000E6CB0BB08F124640F96A47718E644640E6CB0BB08F124640D923D40CA9644640B2497EC4AF124640D923D40CA9644640B2497EC4AF124640F96A47718E644640E6CB0BB08F124640F96A47718E644640
60284	57624	43.873080999999999	43.897047999999998	45.327539999999999	45.319239000000003	Манкаева	0103000020E6100000010000000500000026E1421EC1EF4540CB4DD4D2DCA8464026E1421EC1EF4540E010AAD4ECA946409A780778D2F24540E010AAD4ECA946409A780778D2F24540CB4DD4D2DCA8464026E1421EC1EF4540CB4DD4D2DCA84640
60348	27850	43.147115999999997	43.184027999999998	45.101425999999996	45.085054	Дьякова	0103000020E61000000100000005000000F25B74B2D49245406E32AA0CE38A4640F25B74B2D4924540677BF486FB8C46402EC6C03A8E974540677BF486FB8C46402EC6C03A8E9745406E32AA0CE38A4640F25B74B2D49245406E32AA0CE38A4640
59962	27844	43.541539	43.570419999999999	44.951228999999998	44.937538000000004	Советская	0103000020E610000001000000050000001841632651C54540EE60C43E017846401841632651C54540DE0033DFC1794640FE7DC68503C94540DE0033DFC1794640FE7DC68503C94540EE60C43E017846401841632651C54540EE60C43E01784640
59530	27771	43.658769999999997	43.723528999999999	45.081681000000003	45.064430999999999	Красная	0103000020E61000000100000005000000FFCA4A9352D445409EEC66463F884640FFCA4A9352D4454030DAE385748A4640925A28999CDC454030DAE385748A4640925A28999CDC45409EEC66463F884640FFCA4A9352D445409EEC66463F884640
60541	15588	43.744971999999997	43.813864000000002	45.022399	44.984887000000001	Советская	0103000020E61000000100000005000000C537143E5BDF4540B6A0F7C6107E4640C537143E5BDF4540473B6EF8DD82464025B20FB22CE84540473B6EF8DD82464025B20FB22CE84540B6A0F7C6107E4640C537143E5BDF4540B6A0F7C6107E4640
59744	15588	43.744971999999997	43.813864000000002	45.022399	44.984887000000001	Красная	0103000020E61000000100000005000000C537143E5BDF4540B6A0F7C6107E4640C537143E5BDF4540473B6EF8DD82464025B20FB22CE84540473B6EF8DD82464025B20FB22CE84540B6A0F7C6107E4640C537143E5BDF4540B6A0F7C6107E4640
60321	27662	43.670771000000002	43.702849999999998	45.303012000000003	45.266485000000003	Красная	0103000020E61000000100000005000000780DFAD2DBD54540F2EF332E1CA24640780DFAD2DBD54540D525E318C9A646402EFF21FDF6D94540D525E318C9A646402EFF21FDF6D94540F2EF332E1CA24640780DFAD2DBD54540F2EF332E1CA24640
60026	27571	43.336751	43.360421000000002	45.259284999999998	45.243853000000001	Школьная	0103000020E6100000010000000500000099F221A81AAB454008043A93369F464099F221A81AAB4540F3AB394030A1464054E57B4622AE4540F3AB394030A1464054E57B4622AE454008043A93369F464099F221A81AAB454008043A93369F4640
59915	27486	43.32103	43.394880000000001	45.018385000000002	44.996290999999999	Ленина	0103000020E610000001000000050000007784D38217A945404A26A776867F46407784D38217A9454055DE8E705A82464018EC866D8BB2454055DE8E705A82464018EC866D8BB245404A26A776867F46407784D38217A945404A26A776867F4640
60027	27431	43.618929000000001	43.665605999999997	45.067863000000003	45.050640999999999	Красная	0103000020E61000000100000005000000E3C5C21039CF45401A6B7F677B864640E3C5C21039CF4540E2CD1ABCAF884640BC02D19332D54540E2CD1ABCAF884640BC02D19332D545401A6B7F677B864640E3C5C21039CF45401A6B7F677B864640
60365	57638	43.198239000000001	43.220095000000001	45.019869	45.009661999999999	Зеленая Роща бульвар	0103000020E6100000010000000500000058E542E55F994540C901BB9A3C81464058E542E55F994540249A40118B824640AE81AD122C9C4540249A40118B824640AE81AD122C9C4540C901BB9A3C81464058E542E55F994540C901BB9A3C814640
59529	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	пл.Строителей	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
59528	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	пер.Школьный	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
59531	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	пер.Кочубея	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
59527	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	Советская	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
59532	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	Первомайская	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
60573	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	Московская	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
59918	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	Ленина	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
60029	12647	43.379555000000003	43.47916	45.129292	45.080905000000001	 Комсомольская	0103000020E6100000010000000500000043041C4295B045409C8A54185B8A464043041C4295B0454035D1E7A38C90464093C6681D55BD454035D1E7A38C90464093C6681D55BD45409C8A54185B8A464043041C4295B045409C8A54185B8A4640
60268	27578	43.225413000000003	43.251348	45.179561999999997	45.168582999999998	Чапаева	0103000020E61000000100000005000000F08B4B55DA9C4540AED4B32094954640F08B4B55DA9C45405BCD3AE3FB9646401FF5D72B2CA045405BCD3AE3FB9646401FF5D72B2CA04540AED4B32094954640F08B4B55DA9C4540AED4B32094954640
59743	27378	43.549840000000003	43.615901999999998	45.227383000000003	45.183171000000002	Ленина	0103000020E610000001000000050000002E04392861C64540AE49B725729746402E04392861C645404C55DAE21A9D46403FC571E0D5CE45404C55DAE21A9D46403FC571E0D5CE4540AE49B725729746402E04392861C64540AE49B72572974640
59914	15508	43.214750000000002	43.273212999999998	45.102915000000003	45.064928000000002	Пролетарская	0103000020E61000000100000005000000736891ED7C9B45401F4C8A8F4F884640736891ED7C9B454049A297512C8D4640C8EBC1A4F8A2454049A297512C8D4640C8EBC1A4F8A245401F4C8A8F4F884640736891ED7C9B45401F4C8A8F4F884640
60560	15508	43.214750000000002	43.273212999999998	45.102915000000003	45.064928000000002	Красная	0103000020E61000000100000005000000736891ED7C9B45401F4C8A8F4F884640736891ED7C9B454049A297512C8D4640C8EBC1A4F8A2454049A297512C8D4640C8EBC1A4F8A245401F4C8A8F4F884640736891ED7C9B45401F4C8A8F4F884640
60344	26751	44.567585999999999	44.590555999999999	45.353425999999999	45.340648999999999	переулок Сквозной	0103000020E610000001000000050000006FD575A8A64846402235ED629AAB46406FD575A8A64846402EC72B103DAD4640713AC956974B46402EC72B103DAD4640713AC956974B46402235ED629AAB46406FD575A8A64846402235ED629AAB4640
59695	26661	43.893113	43.946455	45.234219000000003	45.194668999999998	Ленина	0103000020E61000000100000005000000F450DB8651F24540C345EEE9EA984640F450DB8651F24540098D60E3FA9D46405E11FC6F25F94540098D60E3FA9D46405E11FC6F25F94540C345EEE9EA984640F450DB8651F24540C345EEE9EA984640
59916	26652	44.642425000000003	44.664873999999998	45.295847999999999	45.270336	Школьная	0103000020E6100000010000000500000000917EFB3A5246403A77BB5E9AA2464000917EFB3A524640234BE658DEA54640F8FA5A971A554640234BE658DEA54640F8FA5A971A5546403A77BB5E9AA2464000917EFB3A5246403A77BB5E9AA24640
60349	26566	44.077258999999998	44.110793000000001	45.445753000000003	45.431252000000001	Бульварная	0103000020E610000001000000050000002C29779FE3094640D42AFA4333B746402C29779FE3094640058C2E6F0EB9464018D00B772E0E4640058C2E6F0EB9464018D00B772E0E4640D42AFA4333B746402C29779FE3094640D42AFA4333B74640
59740	32517	44.248271000000003	44.321734999999997	45.101286000000002	45.073101999999999	Студенческая	0103000020E61000000100000005000000CAC51858C71F4640D7A205685B894640CAC51858C71F464076C58CF0F68C4640417DCB9C2E29464076C58CF0F68C4640417DCB9C2E294640D7A205685B894640CAC51858C71F4640D7A205685B894640
59737	26501	44.367801	44.442990000000002	45.052155999999997	44.993901000000001	Ленина	0103000020E61000000100000005000000D237691A142F4640193BE125387F4640D237691A142F464024253D0CAD8646403F3A75E5B338464024253D0CAD8646403F3A75E5B3384640193BE125387F4640D237691A142F4640193BE125387F4640
60317	26419	43.968760000000003	43.994954999999997	45.551979000000003	45.542019000000003	Бульварная	0103000020E6100000010000000500000024D6E25300FC4540C367EBE060C5464024D6E25300FC4540168A743FA7C64640EFFE78AF5AFF4540168A743FA7C64640EFFE78AF5AFF4540C367EBE060C5464024D6E25300FC4540C367EBE060C54640
60427	57648	44.089717999999998	44.102213999999996	45.271014000000001	45.259500000000003	Оджаева	0103000020E6100000010000000500000067EE21E17B0B4640F0A7C64B37A1464067EE21E17B0B46400B613596B0A24640BF982D59150D46400B613596B0A24640BF982D59150D4640F0A7C64B37A1464067EE21E17B0B4640F0A7C64B37A14640
59911	26190	44.177402999999998	44.259813999999999	45.395947	45.353540000000002	имени Оджаева	0103000020E610000001000000050000002C9B3924B5164640F7E978CC40AD46402C9B3924B516464083F92B64AEB246407F85CC954121464083F92B64AEB246407F85CC9541214640F7E978CC40AD46402C9B3924B5164640F7E978CC40AD4640
59909	26190	44.177402999999998	44.259813999999999	45.395947	45.353540000000002	Энгельса	0103000020E610000001000000050000002C9B3924B5164640F7E978CC40AD46402C9B3924B516464083F92B64AEB246407F85CC954121464083F92B64AEB246407F85CC9541214640F7E978CC40AD46402C9B3924B5164640F7E978CC40AD4640
59524	26190	44.177402999999998	44.259813999999999	45.395947	45.353540000000002	Пети Базалеева	0103000020E610000001000000050000002C9B3924B5164640F7E978CC40AD46402C9B3924B516464083F92B64AEB246407F85CC954121464083F92B64AEB246407F85CC9541214640F7E978CC40AD46402C9B3924B5164640F7E978CC40AD4640
59736	26190	44.177402999999998	44.259813999999999	45.395947	45.353540000000002	Горького	0103000020E610000001000000050000002C9B3924B5164640F7E978CC40AD46402C9B3924B516464083F92B64AEB246407F85CC954121464083F92B64AEB246407F85CC9541214640F7E978CC40AD46402C9B3924B5164640F7E978CC40AD4640
60472	25368	43.391278	43.399740000000001	45.658135999999999	45.648415999999997	Каменная	0103000020E6100000010000000500000078D2C26515B24540001AA54BFFD2464078D2C26515B24540FE28EACC3DD44640977329AE2AB34540FE28EACC3DD44640977329AE2AB34540001AA54BFFD2464078D2C26515B24540001AA54BFFD24640
60574	26150	43.684002999999997	43.750064999999999	45.664498000000002	45.625660000000003	Советская	0103000020E61000000100000005000000D5AE09698DD745402B357BA015D04640D5AE09698DD74540F3203D450ED54640E76F422102E04540F3203D450ED54640E76F422102E045402B357BA015D04640D5AE09698DD745402B357BA015D04640
59952	26076	43.071396999999997	43.114507000000003	46.098267999999997	46.053598000000001	Октябрьская	0103000020E610000001000000050000002904728923894540C5909C4CDC0647402904728923894540251FBB0B940C4740E014562AA88E4540251FBB0B940C4740E014562AA88E4540C5909C4CDC0647402904728923894540C5909C4CDC064740
60577	17360	42.747824000000001	42.795524999999998	46.031196000000001	45.976188999999998	Красная	0103000020E61000000100000005000000FB9463B2B85F454083DBDAC2F3FC4640FB9463B2B85F45400DE2033BFE034740401361C3D36545400DE2033BFE034740401361C3D365454083DBDAC2F3FC4640FB9463B2B85F454083DBDAC2F3FC4640
59719	32516	42.908208999999999	42.945982999999998	46.100223999999997	46.061208999999998	Октябрьская	0103000020E610000001000000050000006877483140744540459C4EB2D507474068774831407445401C23D923D40C474036C98FF8157945401C23D923D40C474036C98FF815794540459C4EB2D50747406877483140744540459C4EB2D5074740
60022	15783	43.290218000000003	43.399588000000001	45.943235000000001	45.890892999999998	Советская	0103000020E61000000100000005000000F35A09DD25A545401F9E25C808F24640F35A09DD25A54540A6B8AAECBBF84640E1EF17B325B34540A6B8AAECBBF84640E1EF17B325B345401F9E25C808F24640F35A09DD25A545401F9E25C808F24640
60601	15783	43.290218000000003	43.399588000000001	45.943235000000001	45.890892999999998	О.Кошевого	0103000020E61000000100000005000000F35A09DD25A545401F9E25C808F24640F35A09DD25A54540A6B8AAECBBF84640E1EF17B325B34540A6B8AAECBBF84640E1EF17B325B345401F9E25C808F24640F35A09DD25A545401F9E25C808F24640
60596	15783	43.290218000000003	43.399588000000001	45.943235000000001	45.890892999999998	Кашубы	0103000020E61000000100000005000000F35A09DD25A545401F9E25C808F24640F35A09DD25A54540A6B8AAECBBF84640E1EF17B325B34540A6B8AAECBBF84640E1EF17B325B345401F9E25C808F24640F35A09DD25A545401F9E25C808F24640
60021	15783	43.290218000000003	43.399588000000001	45.943235000000001	45.890892999999998	Вокзальная	0103000020E61000000100000005000000F35A09DD25A545401F9E25C808F24640F35A09DD25A54540A6B8AAECBBF84640E1EF17B325B34540A6B8AAECBBF84640E1EF17B325B345401F9E25C808F24640F35A09DD25A545401F9E25C808F24640
60569	15783	43.290218000000003	43.399588000000001	45.943235000000001	45.890892999999998	8 марта	0103000020E61000000100000005000000F35A09DD25A545401F9E25C808F24640F35A09DD25A54540A6B8AAECBBF84640E1EF17B325B34540A6B8AAECBBF84640E1EF17B325B345401F9E25C808F24640F35A09DD25A545401F9E25C808F24640
60017	25665	43.045183999999999	43.132060000000003	45.815623000000002	45.795462000000001	Красная	0103000020E61000000100000005000000B726DD96C8854540FA9AE5B2D1E54640B726DD96C8854540C66E9F5566E846400D8E9257E7904540C66E9F5566E846400D8E9257E7904540FA9AE5B2D1E54640B726DD96C8854540FA9AE5B2D1E54640
59903	25560	43.386580000000002	43.439580999999997	45.822777000000002	45.800224999999998	Шоссейная	0103000020E61000000100000005000000D3A414747BB145408638D6C56DE64640D3A414747BB145405473B9C150E94640B378B13044B845405473B9C150E94640B378B13044B845408638D6C56DE64640D3A414747BB145408638D6C56DE64640
60562	17172	43.633463999999996	43.707925000000003	45.838406999999997	45.821829000000001	Октябрьская	0103000020E61000000100000005000000BF982D5915D14540C3F352B131E94640BF982D5915D1454065DEAAEB50EB4640AA8251499DDA454065DEAAEB50EB4640AA8251499DDA4540C3F352B131E94640BF982D5915D14540C3F352B131E94640
60418	25308	43.365802000000002	43.386355000000002	45.683107999999997	45.668906999999997	Пушкина	0103000020E61000000100000005000000DC679599D2AE454061889CBE9ED54640DC679599D2AE454067D13B1570D74640B3D2A41474B1454067D13B1570D74640B3D2A41474B1454061889CBE9ED54640DC679599D2AE454061889CBE9ED54640
60141	25455	43.013303000000001	43.027163999999999	45.971235	45.945678999999998	Советская	0103000020E6100000010000000500000027F8A6E9B3814540CAC16C020CF9464027F8A6E9B381454083DDB06D51FC464074D0251C7A83454083DDB06D51FC464074D0251C7A834540CAC16C020CF9464027F8A6E9B3814540CAC16C020CF94640
60014	25450	43.537587000000002	43.580705999999999	45.769723999999997	45.740313	Комсомольский пер	0103000020E610000001000000050000009CE09BA6CFC44540DEE68D93C2DE46409CE09BA6CFC445402079E75086E24640A54BFF9254CA45402079E75086E24640A54BFF9254CA4540DEE68D93C2DE46409CE09BA6CFC44540DEE68D93C2DE4640
60261	25263	43.315100999999999	43.341188000000002	45.682327000000001	45.670293000000001	Садовая	0103000020E61000000100000005000000ECF7C43A55A845406EDE3829CCD54640ECF7C43A55A84540C216BB7D56D74640D2E4620CACAB4540C216BB7D56D74640D2E4620CACAB45406EDE3829CCD54640ECF7C43A55A845406EDE3829CCD54640
59739	24913	42.503500000000003	42.582256000000001	44.674706	44.654696999999999	пер. Клубный	0103000020E610000001000000050000009CC420B07240454008E57D1CCD5346409CC420B0724045401E3526C45C5646402CF3565D874A45401E3526C45C5646402CF3565D874A454008E57D1CCD5346409CC420B07240454008E57D1CCD534640
60345	24323	42.451577999999998	42.478966999999997	44.485004000000004	44.471369000000003	Горького	0103000020E61000000100000005000000EACBD24ECD39454093ACC3D1553C4640EACBD24ECD394540F0366F9C143E46407E6E68CA4E3D4540F0366F9C143E46407E6E68CA4E3D454093ACC3D1553C4640EACBD24ECD39454093ACC3D1553C4640
60283	25038	42.628653	42.690097999999999	44.603372	44.576751000000002	Ленина	0103000020E6100000010000000500000022C495B377504540B8770DFAD249464022C495B3775045403BA92F4B3B4D46407B849A21555845403BA92F4B3B4D46407B849A2155584540B8770DFAD249464022C495B377504540B8770DFAD2494640
60015	25160	42.692101999999998	42.751759	44.421233000000001	44.383752000000001	Совхозная	0103000020E6100000010000000500000083BF5FCC9658454026E318C91E31464083BF5FCC965845407C7F83F6EA354640A1BC8FA3396045407C7F83F6EA354640A1BC8FA33960454026E318C91E31464083BF5FCC9658454026E318C91E314640
60018	25160	42.692101999999998	42.751759	44.421233000000001	44.383752000000001	Советская	0103000020E6100000010000000500000083BF5FCC9658454026E318C91E31464083BF5FCC965845407C7F83F6EA354640A1BC8FA3396045407C7F83F6EA354640A1BC8FA33960454026E318C91E31464083BF5FCC9658454026E318C91E314640
60469	24727	42.235317000000002	42.270792	44.518492999999999	44.504601999999998	Цветочная	0103000020E61000000100000005000000AF9811DE1E1E454083BF5FCC96404640AF9811DE1E1E45403B1A87FA5D4246405C02F04FA92245403B1A87FA5D4246405C02F04FA922454083BF5FCC96404640AF9811DE1E1E454083BF5FCC96404640
60013	24999	42.503490999999997	42.522598000000002	44.782986999999999	44.771469000000003	Победы	0103000020E61000000100000005000000486AA164724045405D70067FBF624640486AA16472404540B91803EB386446403E7AC37DE4424540B91803EB386446403E7AC37DE44245405D70067FBF624640486AA164724045405D70067FBF624640
60417	24995	42.372750000000003	42.423056000000003	44.696399	44.679358999999998	Центральная	0103000020E61000000100000005000000C1CAA145B62F4540239F573CF5564640C1CAA145B62F4540CAFB389A235946403430F2B226364540CAFB389A235946403430F2B226364540239F573CF5564640C1CAA145B62F4540239F573CF5564640
59905	25253	42.53698	42.610283000000003	44.442416000000001	44.421362000000002	Красная	0103000020E61000000100000005000000944DB9C2BB4445407AE3A430EF354640944DB9C2BB444540139D6516A13846400327DBC01D4E4540139D6516A13846400327DBC01D4E45407AE3A430EF354640944DB9C2BB4445407AE3A430EF354640
60318	23003	42.462268000000002	42.551811999999998	44.472810000000003	44.442056000000001	Октябрьская	0103000020E6100000010000000500000061FE0A992B3B454013807F4A9538464061FE0A992B3B4540639CBF09853C46402AC58EC6A1464540639CBF09853C46402AC58EC6A146454013807F4A9538464061FE0A992B3B454013807F4A95384640
59734	23003	42.462268000000002	42.551811999999998	44.472810000000003	44.442056000000001	Красная	0103000020E6100000010000000500000061FE0A992B3B454013807F4A9538464061FE0A992B3B4540639CBF09853C46402AC58EC6A1464540639CBF09853C46402AC58EC6A146454013807F4A9538464061FE0A992B3B454013807F4A95384640
59906	23003	42.462268000000002	42.551811999999998	44.472810000000003	44.442056000000001	Войтика	0103000020E6100000010000000500000061FE0A992B3B454013807F4A9538464061FE0A992B3B4540639CBF09853C46402AC58EC6A1464540639CBF09853C46402AC58EC6A146454013807F4A9538464061FE0A992B3B454013807F4A95384640
59913	23003	42.462268000000002	42.551811999999998	44.472810000000003	44.442056000000001	1-е Мая	0103000020E6100000010000000500000061FE0A992B3B454013807F4A9538464061FE0A992B3B4540639CBF09853C46402AC58EC6A1464540639CBF09853C46402AC58EC6A146454013807F4A9538464061FE0A992B3B454013807F4A95384640
59902	25093	42.685445000000001	42.762079999999997	44.555334999999999	44.517214000000003	Кирова	0103000020E61000000100000005000000761A69A9BC57454045847F1134424640761A69A9BC5745407EA99F3715474640C47762D68B6145407EA99F3715474640C47762D68B61454045847F1134424640761A69A9BC57454045847F1134424640
60295	24630	42.341588000000002	42.382317	44.456147999999999	44.434558000000003	Подтенная	0103000020E61000000100000005000000605AD427B92B45408B1BB7989F374640605AD427B92B45406211C30E633A464038DA71C3EF3045406211C30E633A464038DA71C3EF3045408B1BB7989F374640605AD427B92B45408B1BB7989F374640
60441	24914	42.415365999999999	42.468528999999997	44.630383999999999	44.620319000000002	Титова	0103000020E6100000010000000500000067EF8CB62A354540310BED9C664F464067EF8CB62A354540F9F5436CB0504640211D1EC2F83B4540F9F5436CB0504640211D1EC2F83B4540310BED9C664F464067EF8CB62A354540310BED9C664F4640
60591	14930	42.220495	42.240392999999997	44.613433999999998	44.599065000000003	Центральная	0103000020E610000001000000050000003CF71E2E391C4540D1967329AE4C46403CF71E2E391C454092205C01854E4640FA97A432C51E454092205C01854E4640FA97A432C51E4540D1967329AE4C46403CF71E2E391C4540D1967329AE4C4640
60584	17068	42.278221000000002	42.312429000000002	44.481395999999997	44.452809000000002	Школьная	0103000020E61000000100000005000000BC07E8BE9C234540D02A33A5F5394640BC07E8BE9C2345406D3656629E3D464037A968ACFD2745406D3656629E3D464037A968ACFD274540D02A33A5F5394640BC07E8BE9C234540D02A33A5F5394640
60581	17163	42.396797999999997	42.421914999999998	44.562578999999999	44.550651999999999	Школьная	0103000020E61000000100000005000000218FE046CA3245400EBDC5C37B464640218FE046CA3245404C35B396024846408E588B4F013645404C35B396024846408E588B4F013645400EBDC5C37B464640218FE046CA3245400EBDC5C37B464640
60012	24435	42.374673000000001	42.441921000000001	44.407068000000002	44.355277000000001	Красная	0103000020E61000000100000005000000DCD8EC48F52F4540B0027CB7792D4640DCD8EC48F52F4540C39FE1CD1A344640333509DE90384540C39FE1CD1A344640333509DE90384540B0027CB7792D4640DCD8EC48F52F4540B0027CB7792D4640
60409	24435	42.374673000000001	42.441921000000001	44.407068000000002	44.355277000000001	Грековская	0103000020E61000000100000005000000DCD8EC48F52F4540B0027CB7792D4640DCD8EC48F52F4540C39FE1CD1A344640333509DE90384540C39FE1CD1A344640333509DE90384540B0027CB7792D4640DCD8EC48F52F4540B0027CB7792D4640
59735	24736	42.349941999999999	42.373550000000002	44.530991999999998	44.502031000000002	Школьная	0103000020E6100000010000000500000098BF42E6CA2C4540024A438D4240464098BF42E6CA2C45400438BD8BF7434640DDB5847CD02F45400438BD8BF7434640DDB5847CD02F4540024A438D4240464098BF42E6CA2C4540024A438D42404640
60367	24545	42.366785999999998	42.408943999999998	44.427785999999998	44.409939999999999	Красная	0103000020E61000000100000005000000B950F9D7F22E45403FA9F6E978344640B950F9D7F22E4540E4D70FB1C13646409DF2E84658344540E4D70FB1C13646409DF2E846583445403FA9F6E978344640B950F9D7F22E45403FA9F6E978344640
60028	57603	42.931897999999997	42.981071999999998	44.566766000000001	44.541947	 Клубная	0103000020E61000000100000005000000999A046F487745402995F0845E454640999A046F487745400C3ECDC98B484640BA826DC4937D45400C3ECDC98B484640BA826DC4937D45402995F0845E454640999A046F487745402995F0845E454640
59521	23744	42.821629999999999	42.876399999999997	44.850149000000002	44.814039000000001	Мира	0103000020E61000000100000005000000CCB4FD2B2B6945409355116E32684640CCB4FD2B2B69454012DDB3AED16C4640711B0DE02D70454012DDB3AED16C4640711B0DE02D7045409355116E32684640CCB4FD2B2B6945409355116E32684640
60037	48223	42.785947999999998	42.865000000000002	44.683852000000002	44.656998999999999	Ленина	0103000020E61000000100000005000000A52DAEF1996445409A40118B18544640A52DAEF199644540F0A65B76885746401F85EB51B86E4540F0A65B76885746401F85EB51B86E45409A40118B18544640A52DAEF1996445409A40118B18544640
59522	24032	43.190666	43.253737000000001	44.537373000000002	44.500745000000002	Октябрьская	0103000020E61000000100000005000000C53A55BE679845405951836918404640C53A55BE67984540706072A3C844464080643A747AA04540706072A3C844464080643A747AA045405951836918404640C53A55BE679845405951836918404640
59732	24034	43.107607999999999	43.141438999999998	44.594135999999999	44.574978999999999	Средняя	0103000020E61000000100000005000000DC645419C68D4540827170E998494640DC645419C68D454029B000A60C4C464081B053AC1A92454029B000A60C4C464081B053AC1A924540827170E998494640DC645419C68D4540827170E998494640
59896	24130	42.776831000000001	42.856896999999996	44.678468000000002	44.647790999999998	Советская	0103000020E610000001000000050000006EC2BD326F63454052D2C3D0EA5246406EC2BD326F634540F7B0170AD85646402F8507CDAE6D4540F7B0170AD85646402F8507CDAE6D454052D2C3D0EA5246406EC2BD326F63454052D2C3D0EA524640
59729	23823	42.906771999999997	43.028503000000001	44.878999999999998	44.854506999999998	Глазкова	0103000020E61000000100000005000000D976DA1A11744540FE99417C606D4640D976DA1A117445408D976E1283704640406B7EFCA58345408D976E1283704640406B7EFCA5834540FE99417C606D4640D976DA1A11744540FE99417C606D4640
60439	23735	42.844374999999999	42.8658	44.734599000000003	44.707771000000001	Маяковского	0103000020E61000000100000005000000AE47E17A146C45405307793D985A4640AE47E17A146C454050560C57075E46403B70CE88D26E454050560C57075E46403B70CE88D26E45405307793D985A4640AE47E17A146C45405307793D985A4640
59900	23876	43.008038999999997	43.063645000000001	44.954788000000001	44.928413999999997	Кирова	0103000020E61000000100000005000000D80B056C0781454003931B45D6764640D80B056C078145407F4E417E367A4640E7C6F484258845407F4E417E367A4640E7C6F4842588454003931B45D6764640D80B056C0781454003931B45D6764640
60408	23936	43.292230000000004	43.306961999999999	44.611944999999999	44.596626000000001	60 лет Октября	0103000020E610000001000000050000007E74EACA67A54540BEF8A23D5E4C46407E74EACA67A54540B1F9B836544E4640B08EE3874AA74540B1F9B836544E4640B08EE3874AA74540BEF8A23D5E4C46407E74EACA67A54540BEF8A23D5E4C4640
59741	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Энгельса	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
60265	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Щорса	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
59722	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Речной переулок	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
60010	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Р.Люксембург	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
59901	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Ленинская	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
59517	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Красноармейская	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
59520	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Калинина	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
59519	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	К.Маркса	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
59518	23101	42.867407999999998	43.047843	44.768870999999997	44.695898999999997	Виноградная	0103000020E61000000100000005000000F624B039076F4540D828EB3713594640F624B039076F4540E1EB6B5D6A624640D82B2CB81F864540E1EB6B5D6A624640D82B2CB81F864540D828EB3713594640F624B039076F4540D828EB3713594640
57509	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	проспект Ленина	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57615	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	проспект Космонавтов	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57623	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	набережная Нефтяников	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57511	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	набережная Газовиков	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57567	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Юбилейная	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57628	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Школьная	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57518	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Тихоновича	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57513	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Строителей проезд	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57617	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Совхозная	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57514	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Советская	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57662	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Сенюкова	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57559	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Севастопольская	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57572	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Пионергорский проезд	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57660	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Первомайская	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57560	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Оплеснина	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57512	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Октябрьская	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57508	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Озерная	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57565	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Ленина проспект	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57583	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Кольцевая	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57611	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Кирпичная	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57566	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Интернациональная	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57659	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Дзержинского	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
79468	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Дежнева	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57661	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Горького	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57507	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Бушуева	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57522	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	Авиационная	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57568	19420	53.630535999999999	53.824150000000003	63.622107	63.533467999999999	30 лет Октября	0103000020E61000000100000005000000AF795567B5D04A4034BBEEAD48C44F40AF795567B5D04A406CCEC133A1CF4F40CC7F48BF7DE94A406CCEC133A1CF4F40CC7F48BF7DE94A4034BBEEAD48C44F40AF795567B5D04A4034BBEEAD48C44F40
57490	16244	57.372090999999998	57.573799000000001	66.008602999999994	65.978600999999998	Строителей	0103000020E6100000010000000500000066118AADA0AF4C404EB51666A17E504066118AADA0AF4C4070E998F38C8050401FBDE13E72C94C4070E998F38C8050401FBDE13E72C94C404EB51666A17E504066118AADA0AF4C404EB51666A17E5040
57556	16244	57.372090999999998	57.573799000000001	66.008602999999994	65.978600999999998	Нефтяников	0103000020E6100000010000000500000066118AADA0AF4C404EB51666A17E504066118AADA0AF4C4070E998F38C8050401FBDE13E72C94C4070E998F38C8050401FBDE13E72C94C404EB51666A17E504066118AADA0AF4C404EB51666A17E5040
57491	16244	57.372090999999998	57.573799000000001	66.008602999999994	65.978600999999998	Молодежная	0103000020E6100000010000000500000066118AADA0AF4C404EB51666A17E504066118AADA0AF4C4070E998F38C8050401FBDE13E72C94C4070E998F38C8050401FBDE13E72C94C404EB51666A17E504066118AADA0AF4C404EB51666A17E5040
57489	16244	57.372090999999998	57.573799000000001	66.008602999999994	65.978600999999998	Комсомольская	0103000020E6100000010000000500000066118AADA0AF4C404EB51666A17E504066118AADA0AF4C4070E998F38C8050401FBDE13E72C94C4070E998F38C8050401FBDE13E72C94C404EB51666A17E504066118AADA0AF4C404EB51666A17E5040
57492	16244	57.372090999999998	57.573799000000001	66.008602999999994	65.978600999999998	Возейская	0103000020E6100000010000000500000066118AADA0AF4C404EB51666A17E504066118AADA0AF4C4070E998F38C8050401FBDE13E72C94C4070E998F38C8050401FBDE13E72C94C404EB51666A17E504066118AADA0AF4C404EB51666A17E5040
57545	16244	57.372090999999998	57.573799000000001	66.008602999999994	65.978600999999998	60 лет Октября	0103000020E6100000010000000500000066118AADA0AF4C404EB51666A17E504066118AADA0AF4C4070E998F38C8050401FBDE13E72C94C4070E998F38C8050401FBDE13E72C94C404EB51666A17E504066118AADA0AF4C404EB51666A17E5040
1157	669	50.875914999999999	50.881385999999999	61.658279	61.649163999999999	улица Школьная	0103000020E61000000100000005000000B58993FB1D704940CADE52CE17D34E40B58993FB1D70494061527C7C42D44E407D93A641D170494061527C7C42D44E407D93A641D1704940CADE52CE17D34E40B58993FB1D704940CADE52CE17D34E40
2076	669	50.836047999999998	50.850709000000002	61.676220999999998	61.664394999999999	улица Советская	0103000020E610000001000000050000006FF1F09E036B49401E5036E50AD54E406FF1F09E036B494028EFE3688ED64E40D9B45208E46C494028EFE3688ED64E40D9B45208E46C49401E5036E50AD54E406FF1F09E036B49401E5036E50AD54E40
2155	669	50.789012	50.815638	61.672187000000001	61.639678000000004	улица Морозова	0103000020E6100000010000000500000066136058FE64494040FCFCF7E0D14E4066136058FE644940EFE53E390AD64E40FBAF73D366684940EFE53E390AD64E40FBAF73D36668494040FCFCF7E0D14E4066136058FE64494040FCFCF7E0D14E40
2408	669	50.807355999999999	50.839264	61.676907999999997	61.673993000000003	улица Красных Партизан	0103000020E610000001000000050000005C1D007157674940D15D126745D64E405C1D0071576749404C33DDEBA4D64E40E65AB4006D6B49404C33DDEBA4D64E40E65AB4006D6B4940D15D126745D64E405C1D007157674940D15D126745D64E40
2198	669	50.793261000000001	50.842587999999999	61.670296	61.656156000000003	улица Коммунистическая	0103000020E610000001000000050000009C189293896549407F8978EBFCD34E409C18929389654940DF516342CCD54E40430070ECD96B4940DF516342CCD54E40430070ECD96B49407F8978EBFCD34E409C189293896549407F8978EBFCD34E40
2236	669	50.789029999999997	50.812880999999997	61.667122999999997	61.664287999999999	улица Катаева	0103000020E610000001000000050000000CC85EEFFE6449400890A16307D54E400CC85EEFFE64494067B4554964D54E4017450F7C0C68494067B4554964D54E4017450F7C0C6849400890A16307D54E400CC85EEFFE6449400890A16307D54E40
57686	669	50.816070000000003	50.818046000000002	61.674548000000001	61.669117	Юхнина	0103000020E61000000100000005000000959F54FB746849404C1938A0A5D54E40959F54FB7468494086CABF9657D64E40D34F38BBB568494086CABF9657D64E40D34F38BBB56849404C1938A0A5D54E40959F54FB746849404C1938A0A5D54E40
57638	669	50.716276000000001	50.916933	61.723374	61.62189	Юности	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57684	669	50.833559999999999	50.848427000000001	61.661307000000001	61.657420999999999	Южная	0103000020E610000001000000050000007BA01518B26A4940105A0F5F26D44E407BA01518B26A4940D5CE30B5A5D44E408E058541996C4940D5CE30B5A5D44E408E058541996C4940105A0F5F26D44E407BA01518B26A4940105A0F5F26D44E40
57598	669	50.716276000000001	50.916933	61.723374	61.62189	Школьный переулок	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57690	669	50.875914999999999	50.881385999999999	61.658279	61.649163999999999	Школьная	0103000020E61000000100000005000000B58993FB1D704940CADE52CE17D34E40B58993FB1D70494061527C7C42D44E407D93A641D170494061527C7C42D44E407D93A641D1704940CADE52CE17D34E40B58993FB1D704940CADE52CE17D34E40
57672	669	50.817830000000001	50.824038000000002	61.667828	61.664740999999999	Чернова	0103000020E6100000010000000500000006D847A7AE684940B9A7AB3B16D54E4006D847A7AE68494032AD4D637BD54E40A454C2137A69494032AD4D637BD54E40A454C2137A694940B9A7AB3B16D54E4006D847A7AE684940B9A7AB3B16D54E40
57558	669	50.716276000000001	50.916933	61.723374	61.62189	Ухтинская	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57688	669	50.796567000000003	50.83135	61.713450000000002	61.681283000000001	Тентюковская	0103000020E6100000010000000500000053094FE8F56549400F29064834D74E4053094FE8F565494065AA605452DB4E40CAC342AD696A494065AA605452DB4E40CAC342AD696A49400F29064834D74E4053094FE8F56549400F29064834D74E40
57678	669	50.800691	50.807706000000003	61.671756000000002	61.657378000000001	Старовского	0103000020E61000000100000005000000CC99ED0A7D664940118E59F624D44E40CC99ED0A7D6649402672C119FCD54E40396403E9626749402672C119FCD54E40396403E962674940118E59F624D44E40CC99ED0A7D664940118E59F624D44E40
57773	669	50.850709000000002	50.857913000000003	61.683045999999997	61.674824999999998	Сплавная	0103000020E61000000100000005000000D9B45208E46C4940F8C264AA60D64E40D9B45208E46C4940F1D4230D6ED74E4019E8DA17D06D4940F1D4230D6ED74E4019E8DA17D06D4940F8C264AA60D64E40D9B45208E46C4940F8C264AA60D64E40
57674	669	50.864542999999998	50.875807999999999	61.642420999999999	61.635193999999998	Снежная	0103000020E610000001000000050000002C7E5358A96E4940C64E78094ED14E402C7E5358A96E4940BEA1F0D93AD24E409FC9FE791A704940BEA1F0D93AD24E409FC9FE791A704940C64E78094ED14E402C7E5358A96E4940C64E78094ED14E40
57530	669	50.716276000000001	50.916933	61.723374	61.62189	Славы	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57689	669	50.771647999999999	50.786371000000003	61.671056	61.663258999999996	Ручейная	0103000020E610000001000000050000000C03965CC56249408AE3C0ABE5D44E400C03965CC56249406DE4BA29E5D54E40ECC20FCEA76449406DE4BA29E5D54E40ECC20FCEA76449408AE3C0ABE5D44E400C03965CC56249408AE3C0ABE5D44E40
57687	669	50.818783000000003	50.848193000000002	61.669052999999998	61.643135000000001	Пушкина	0103000020E61000000100000005000000A9C29FE1CD684940DCF4673F52D24E40A9C29FE1CD68494035255987A3D54E401BD99596916C494035255987A3D54E401BD99596916C4940DCF4673F52D24E40A9C29FE1CD684940DCF4673F52D24E40
57683	669	50.795489000000003	50.821539999999999	61.685080999999997	61.684462000000003	Печорская	0103000020E61000000100000005000000F4A96395D265494069AD68739CD74E40F4A96395D2654940340EF5BBB0D74E408C2D043928694940340EF5BBB0D74E408C2D04392869494069AD68739CD74E40F4A96395D265494069AD68739CD74E40
57680	669	50.799568000000001	50.822465999999999	61.69652	61.684462000000003	Петрозаводская	0103000020E61000000100000005000000CD76853E5866494069AD68739CD74E40CD76853E5866494045813E9127D94E403509DE904669494045813E9127D94E403509DE904669494069AD68739CD74E40CD76853E5866494069AD68739CD74E40
57691	669	50.823965999999999	50.850034999999998	61.677292000000001	61.659419999999997	Первомайская	0103000020E610000001000000050000000A82C7B777694940062AE3DF67D44E400A82C7B777694940D5EB1681B1D64E4049BA66F2CD6C4940D5EB1681B1D64E4049BA66F2CD6C4940062AE3DF67D44E400A82C7B777694940062AE3DF67D44E40
57693	669	50.802191000000001	50.840423000000001	61.673369000000001	61.67109	Орджоникидзе	0103000020E61000000100000005000000A112D731AE6649401956F146E6D54E40A112D731AE664940F39194F430D64E4032E719FB926B4940F39194F430D64E4032E719FB926B49401956F146E6D54E40A112D731AE6649401956F146E6D54E40
57706	669	50.716276000000001	50.916933	61.723374	61.62189	Олега Кошевого	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
2338	669	50.794958999999999	50.832697000000003	61.715722	61.658326000000002	Октябрьский проспект	0103000020E6100000010000000500000097546D37C1654940A20DC00644D44E4097546D37C16549408C834BC79CDB4E40193DB7D0956A49408C834BC79CDB4E40193DB7D0956A4940A20DC00644D44E4097546D37C1654940A20DC00644D44E40
57579	669	50.716276000000001	50.916933	61.723374	61.62189	Набережный проезд	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57682	669	50.789012	50.815638	61.672187000000001	61.639678000000004	Морозова	0103000020E6100000010000000500000066136058FE64494040FCFCF7E0D14E4066136058FE644940EFE53E390AD64E40FBAF73D366684940EFE53E390AD64E40FBAF73D36668494040FCFCF7E0D14E4066136058FE64494040FCFCF7E0D14E40
57487	669	50.716276000000001	50.916933	61.723374	61.62189	Мира	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57685	669	50.806052999999999	50.836604999999999	61.656908000000001	61.647275	Маркова	0103000020E61000000100000005000000DDEBA4BE2C6749405B423EE8D9D24E40DDEBA4BE2C6749408A3DB48F15D44E40C55565DF156B49408A3DB48F15D44E40C55565DF156B49405B423EE8D9D24E40DDEBA4BE2C6749405B423EE8D9D24E40
57677	669	50.808433999999998	50.822294999999997	61.690061	61.689718999999997	Малышева	0103000020E61000000100000005000000BB7CEBC37A674940043752B648D84E40BB7CEBC37A6749405E9F39EB53D84E4008556AF6406949405E9F39EB53D84E4008556AF640694940043752B648D84E40BB7CEBC37A674940043752B648D84E40
57502	669	50.716276000000001	50.916933	61.723374	61.62189	Магистральная	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57694	669	50.82826	50.838366000000001	61.680233000000001	61.679673999999999	Кутузова	0103000020E61000000100000005000000E04A766C046A494083F8C08EFFD64E40E04A766C046A49407A54FCDF11D74E40070ABC934F6B49407A54FCDF11D74E40070ABC934F6B494083F8C08EFFD64E40E04A766C046A494083F8C08EFFD64E40
57497	669	50.716276000000001	50.916933	61.723374	61.62189	Корабельная	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57673	669	50.793261000000001	50.842587999999999	61.670296	61.656156000000003	Коммунистическая	0103000020E610000001000000050000009C189293896549407F8978EBFCD34E409C18929389654940DF516342CCD54E40430070ECD96B4940DF516342CCD54E40430070ECD96B49407F8978EBFCD34E409C189293896549407F8978EBFCD34E40
57599	669	50.716276000000001	50.916933	61.723374	61.62189	Комарова	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57675	669	50.789029999999997	50.812880999999997	61.667122999999997	61.664287999999999	Катаева	0103000020E610000001000000050000000CC85EEFFE6449400890A16307D54E400CC85EEFFE64494067B4554964D54E4017450F7C0C68494067B4554964D54E4017450F7C0C6849400890A16307D54E400CC85EEFFE6449400890A16307D54E40
57679	669	50.813302999999998	50.825986999999998	61.687632999999998	61.659655000000001	Карла Маркса	0103000020E610000001000000050000008D5E0D501A6849404AD235936FD44E408D5E0D501A6849403F53AF5B04D84E40E8F527F1B96949403F53AF5B04D84E40E8F527F1B96949404AD235936FD44E408D5E0D501A6849404AD235936FD44E40
57692	669	50.826050000000002	50.847484000000001	61.681283000000001	61.661025000000002	Интернациональная	0103000020E610000001000000050000002F6EA301BC694940516B9A779CD44E402F6EA301BC6949400F29064834D74E400FF10F5B7A6C49400F29064834D74E400FF10F5B7A6C4940516B9A779CD44E402F6EA301BC694940516B9A779CD44E40
57483	669	50.716276000000001	50.916933	61.723374	61.62189	Дырнос	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57671	669	50.796737999999998	50.819546000000003	61.660640999999998	61.654333000000001	Димитрова	0103000020E610000001000000050000007FBDC282FB654940C7D8092FC1D34E407FBDC282FB654940C8B260E28FD44E40A8C821E2E6684940C8B260E28FD44E40A8C821E2E6684940C7D8092FC1D34E407FBDC282FB654940C7D8092FC1D34E40
57640	669	50.716276000000001	50.916933	61.723374	61.62189	Верхний Чов	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57493	669	50.716276000000001	50.916933	61.723374	61.62189	Большая	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57582	669	50.716276000000001	50.916933	61.723374	61.62189	Белинского	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57591	669	50.716276000000001	50.916933	61.723374	61.62189	Банбана	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57681	669	50.826607000000003	50.841051999999998	61.671824000000001	61.669804999999997	Бабушкина	0103000020E6100000010000000500000085D21742CE69494040D9942BBCD54E4085D21742CE6949407E552E54FED54E40211E8997A76B49407E552E54FED54E40211E8997A76B494040D9942BBCD54E4085D21742CE69494040D9942BBCD54E40
57616	669	50.716276000000001	50.916933	61.723374	61.62189	 Лесовозная	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57622	669	50.716276000000001	50.916933	61.723374	61.62189	 Космонавтов	0103000020E61000000100000005000000717495EEAE5B4940CFDA6D179ACF4E40717495EEAE5B49406B63EC8497DC4E40C4CF7F0F5E7549406B63EC8497DC4E40C4CF7F0F5E754940CFDA6D179ACF4E40717495EEAE5B4940CFDA6D179ACF4E40
57554	57211	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	Пионерская	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57663	57211	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	Первомайская	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57606	57211	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	Орджоникидзе	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57550	57211	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	Лермонтова	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57505	57211	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	6 микрорайон	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57495	57211	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	5 микрорайон	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57541	57207	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Советская	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57654	57207	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Совесткая	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57488	57207	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Печорский проспект	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57479	57207	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Московская	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57657	57207	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Ленина	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57482	57207	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Гагарина	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57484	57207	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Булгаковой	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57534	57206	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Южная	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57475	57206	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Куратова	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57766	57206	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Коммунистическая	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57767	57206	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Восточная	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57577	57225	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	Пионерская	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
9788	15656	57.290246000000003	57.336742999999998	63.882719000000002	63.838240999999996	Коммунистическая	0103000020E61000000100000005000000BDE5EAC726A54C404A95287B4BEB4F40BDE5EAC726A54C406747AAEFFCF04F40161406651AAB4C406747AAEFFCF04F40161406651AAB4C404A95287B4BEB4F40BDE5EAC726A54C404A95287B4BEB4F40
57543	40318	57.290246000000003	57.336742999999998	63.882719000000002	63.838240999999996	Таёжная	0103000020E61000000100000005000000BDE5EAC726A54C404A95287B4BEB4F40BDE5EAC726A54C406747AAEFFCF04F40161406651AAB4C406747AAEFFCF04F40161406651AAB4C404A95287B4BEB4F40BDE5EAC726A54C404A95287B4BEB4F40
57542	40318	57.290246000000003	57.336742999999998	63.882719000000002	63.838240999999996	Комсомольская	0103000020E61000000100000005000000BDE5EAC726A54C404A95287B4BEB4F40BDE5EAC726A54C406747AAEFFCF04F40161406651AAB4C406747AAEFFCF04F40161406651AAB4C404A95287B4BEB4F40BDE5EAC726A54C404A95287B4BEB4F40
9811	40318	57.290246000000003	57.336742999999998	63.882719000000002	63.838240999999996	Коммунистическая	0103000020E61000000100000005000000BDE5EAC726A54C404A95287B4BEB4F40BDE5EAC726A54C406747AAEFFCF04F40161406651AAB4C406747AAEFFCF04F40161406651AAB4C404A95287B4BEB4F40BDE5EAC726A54C404A95287B4BEB4F40
57645	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Яновского	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57532	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Шахтерская набережная	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57587	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Чернова	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57646	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Центральная площадь	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57539	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Тиманская	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57586	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Суворова	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57925	27629	57.537804000000001	57.552194999999998	62.628124	62.625281999999999	Попова	0103000020E6100000010000000500000039D4EFC2D6C44C408463963D09504F4039D4EFC2D6C44C4096EA025E66504F40E2016553AEC64C4096EA025E66504F40E2016553AEC64C408463963D09504F4039D4EFC2D6C44C408463963D09504F40
57641	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Строительная	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57652	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Привокзальный переулок	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57593	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Пищевиков бульвар	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57473	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Пирогова	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57650	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Пионерская	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57648	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Парковая	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57588	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Московская	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57651	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Матвеева	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57592	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Ломоносова	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57585	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Лермонтова	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57478	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Ленина	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57581	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Коммунальная	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57643	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Дончука	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57474	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Димитрова	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57639	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	Возейская	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57647	3457	63.939988999999997	64.113731999999999	67.539045999999999	67.463111999999995	3-я Линейная	0103000020E61000000100000005000000C4CC3E8F51F84F40A69883A0A3DD5040C4CC3E8F51F84F408942CBBA7FE250408E209562470750408942CBBA7FE250408E20956247075040A69883A0A3DD5040C4CC3E8F51F84F40A69883A0A3DD5040
57516	57218	53.548178999999998	53.617125000000001	63.442883000000002	63.423532000000002	Шахтинская	0103000020E610000001000000050000004FADBEBA2AC64A409D67EC4B36B64F404FADBEBA2AC64A40297AE063B0B84F40A245B6F3FDCE4A40297AE063B0B84F40A245B6F3FDCE4A409D67EC4B36B64F404FADBEBA2AC64A409D67EC4B36B64F40
57665	57218	53.548178999999998	53.617125000000001	63.442883000000002	63.423532000000002	Строительная	0103000020E610000001000000050000004FADBEBA2AC64A409D67EC4B36B64F404FADBEBA2AC64A40297AE063B0B84F40A245B6F3FDCE4A40297AE063B0B84F40A245B6F3FDCE4A409D67EC4B36B64F404FADBEBA2AC64A409D67EC4B36B64F40
57649	57218	53.548178999999998	53.617125000000001	63.442883000000002	63.423532000000002	Советская	0103000020E610000001000000050000004FADBEBA2AC64A409D67EC4B36B64F404FADBEBA2AC64A40297AE063B0B84F40A245B6F3FDCE4A40297AE063B0B84F40A245B6F3FDCE4A409D67EC4B36B64F404FADBEBA2AC64A409D67EC4B36B64F40
57525	57218	53.548178999999998	53.617125000000001	63.442883000000002	63.423532000000002	Октябрьская	0103000020E610000001000000050000004FADBEBA2AC64A409D67EC4B36B64F404FADBEBA2AC64A40297AE063B0B84F40A245B6F3FDCE4A40297AE063B0B84F40A245B6F3FDCE4A409D67EC4B36B64F404FADBEBA2AC64A409D67EC4B36B64F40
57515	57217	53.586618000000001	53.622892	63.540010000000002	63.519080000000002	Шахтинская	0103000020E610000001000000050000005A9F724C16CB4A40FC00A43671C24F405A9F724C16CB4A40A9C1340C1FC54F405378D0ECBACF4A40A9C1340C1FC54F405378D0ECBACF4A40FC00A43671C24F405A9F724C16CB4A40FC00A43671C24F40
57733	57217	53.586618000000001	53.622892	63.540010000000002	63.519080000000002	Павлова	0103000020E610000001000000050000005A9F724C16CB4A40FC00A43671C24F405A9F724C16CB4A40A9C1340C1FC54F405378D0ECBACF4A40A9C1340C1FC54F405378D0ECBACF4A40FC00A43671C24F405A9F724C16CB4A40FC00A43671C24F40
57771	57254	53.941425000000002	53.979173000000003	63.407848000000001	63.389791000000002	Центральная	0103000020E610000001000000050000008351499D80F84A4038A3E6ABE4B14F408351499D80F84A4098DEFE5C34B44F402810768A55FD4A4098DEFE5C34B44F402810768A55FD4A4038A3E6ABE4B14F408351499D80F84A4038A3E6ABE4B14F40
57891	57307	53.548233000000003	53.591270999999999	64.231223999999997	64.219620000000006	Центральная	0103000020E6100000010000000500000043CBBA7F2CC64A400B630B410E0E504043CBBA7F2CC64A403883BF5FCC0E50405F09A4C4AECB4A403883BF5FCC0E50405F09A4C4AECB4A400B630B410E0E504043CBBA7F2CC64A400B630B410E0E5040
57618	57224	53.387183	53.435808999999999	63.518040999999997	63.489432000000001	Октябрьская	0103000020E61000000100000005000000994869368FB14A40D5CE30B5A5BE4F40994869368FB14A405A7EE02A4FC24F40B726DD96C8B74A405A7EE02A4FC24F40B726DD96C8B74A40D5CE30B5A5BE4F40994869368FB14A40D5CE30B5A5BE4F40
57569	57224	53.387183	53.435808999999999	63.518040999999997	63.489432000000001	Ленина	0103000020E61000000100000005000000994869368FB14A40D5CE30B5A5BE4F40994869368FB14A405A7EE02A4FC24F40B726DD96C8B74A405A7EE02A4FC24F40B726DD96C8B74A40D5CE30B5A5BE4F40994869368FB14A40D5CE30B5A5BE4F40
57664	27900	52.876041000000001	52.911740000000002	63.242688999999999	63.221687000000003	Советская	0103000020E61000000100000005000000427A8A1C22704A406479573D609C4F40427A8A1C22704A40AA0CE36E109F4F403F3A75E5B3744A40AA0CE36E109F4F403F3A75E5B3744A406479573D609C4F40427A8A1C22704A406479573D609C4F40
57760	57253	48.999389000000001	53.786116	67.099691000000007	64.390798000000004	Сельхозтехника	0103000020E61000000100000005000000B77D8FFAEB7F4840E7559DD502195040B77D8FFAEB7F4840282D5C5661C65040616EF7729FE44A40282D5C5661C65040616EF7729FE44A40E7559DD502195040B77D8FFAEB7F4840E7559DD502195040
57602	5484	52.134535999999997	52.192298000000001	65.456581	65.422713000000002	Советская 	0103000020E610000001000000050000003C11C47938114A4005A6D3BA0D5B50403C11C47938114A4066BE839F385D5040098B8A389D184A4066BE839F385D5040098B8A389D184A4005A6D3BA0D5B50403C11C47938114A4005A6D3BA0D5B5040
57551	5484	52.134535999999997	52.192298000000001	65.456581	65.422713000000002	Батманова	0103000020E610000001000000050000003C11C47938114A4005A6D3BA0D5B50403C11C47938114A4066BE839F385D5040098B8A389D184A4066BE839F385D5040098B8A389D184A4005A6D3BA0D5B50403C11C47938114A4005A6D3BA0D5B5040
57776	57257	52.211323999999998	52.240250000000003	65.427631000000005	65.419144000000003	Школьная	0103000020E61000000100000005000000116E32AA0C1B4A4023145B41D35A5040116E32AA0C1B4A405FF0694E5E5B5040986E1283C01E4A405FF0694E5E5B5040986E1283C01E4A4023145B41D35A5040116E32AA0C1B4A4023145B41D35A5040
57753	29908	54.350499999999997	54.372680000000003	62.094515000000001	62.088042999999999	Центральная	0103000020E61000000100000005000000BE9F1A2FDD2C4B4024D236FE440B4F40BE9F1A2FDD2C4B40A0FD4811190C4F40C8EF6DFAB32F4B40A0FD4811190C4F40C8EF6DFAB32F4B4024D236FE440B4F40BE9F1A2FDD2C4B4024D236FE440B4F40
57831	30234	54.202008999999997	54.223379999999999	62.295825999999998	62.284339000000003	Парковая	0103000020E61000000100000005000000B33F506EDB194B401AFD683865244F40B33F506EDB194B403BA759A0DD254F404D4A41B7971C4B403BA759A0DD254F404D4A41B7971C4B401AFD683865244F40B33F506EDB194B401AFD683865244F40
57576	29271	54.903036	54.965217000000003	61.642263	61.620533999999999	Комсомольская	0103000020E610000001000000050000002A8E03AF96734B402D077AA86DCF4E402A8E03AF96734B4026378AAC35D24E4089450C3B8C7B4B4026378AAC35D24E4089450C3B8C7B4B402D077AA86DCF4E402A8E03AF96734B402D077AA86DCF4E40
57781	29499	54.320082999999997	54.339306999999998	61.601221000000002	61.595354	Центральная	0103000020E61000000100000005000000B680D07AF8284B407AC5538F34CC4E40B680D07AF8284B408F554ACFF4CC4E40E5266A696E2B4B408F554ACFF4CC4E40E5266A696E2B4B407AC5538F34CC4E40B680D07AF8284B407AC5538F34CC4E40
57711	29353	54.837862999999999	54.901096000000003	61.650602999999997	61.620936	Совхозная	0103000020E61000000100000005000000A4C343183F6B4B405C74B2D47ACF4E40A4C343183F6B4B40F9D687F546D34E4039471D1D57734B40F9D687F546D34E4039471D1D57734B405C74B2D47ACF4E40A4C343183F6B4B405C74B2D47ACF4E40
57529	28967	53.651215999999998	53.767043999999999	61.703927999999998	61.679400999999999	Советская	0103000020E61000000100000005000000E350BF0B5BD34A4052EFA99CF6D64E40E350BF0B5BD34A408D5E0D501ADA4E40E84B6F7F2EE24A408D5E0D501ADA4E40E84B6F7F2EE24A4052EFA99CF6D64E40E350BF0B5BD34A4052EFA99CF6D64E40
57633	28967	53.651215999999998	53.767043999999999	61.703927999999998	61.679400999999999	Ленина	0103000020E61000000100000005000000E350BF0B5BD34A4052EFA99CF6D64E40E350BF0B5BD34A408D5E0D501ADA4E40E84B6F7F2EE24A408D5E0D501ADA4E40E84B6F7F2EE24A4052EFA99CF6D64E40E350BF0B5BD34A4052EFA99CF6D64E40
57744	29695	55.099955999999999	55.131144999999997	61.906700000000001	61.890911000000003	Советская	0103000020E61000000100000005000000FD84B35BCB8C4B40C652245F09F24E40FD84B35BCB8C4B4040A4DFBE0EF44E405704FF5BC9904B4040A4DFBE0EF44E405704FF5BC9904B40C652245F09F24E40FD84B35BCB8C4B40C652245F09F24E40
57728	29297	54.793557999999997	54.820723000000001	61.611215000000001	61.591839999999998	Школьная	0103000020E6100000010000000500000055BDFC4E93654B40793BC269C1CB4E4055BDFC4E93654B408EE9094B3CCE4E409A0986730D694B408EE9094B3CCE4E409A0986730D694B40793BC269C1CB4E4055BDFC4E93654B40793BC269C1CB4E40
57702	28582	53.139302000000001	53.215676000000002	61.82714	61.789377000000002	Центральная	0103000020E610000001000000050000003A22DFA5D4914A40789B374E0AE54E403A22DFA5D4914A40529B38B9DFE94E401C446B459B9B4A40529B38B9DFE94E401C446B459B9B4A40789B374E0AE54E403A22DFA5D4914A40789B374E0AE54E40
57782	30403	54.647042999999996	54.697744	62.435138999999999	62.423442999999999	Г.Тимушева	0103000020E61000000100000005000000880D164ED2524B402D5C566133364F40880D164ED2524B40691B7FA2B2374F40787DE6AC4F594B40691B7FA2B2374F40787DE6AC4F594B402D5C566133364F40880D164ED2524B402D5C566133364F40
57635	30035	54.169632999999997	54.195397	62.205571999999997	62.184393	В.Т.Чисталева	0103000020E6100000010000000500000043A9BD88B6154B40404E98309A174F4043A9BD88B6154B40957CEC2E501A4F40465ED6C402194B40957CEC2E501A4F40465ED6C402194B40404E98309A174F4043A9BD88B6154B40404E98309A174F40
57887	29842	54.320954999999998	54.342388	62.010809999999999	62.001828000000003	Центральная	0103000020E610000001000000050000006C3EAE0D15294B40CA1B60E63B004F406C3EAE0D15294B40213CDA3862014F407C45B75ED32B4B40213CDA3862014F407C45B75ED32B4B40CA1B60E63B004F406C3EAE0D15294B40CA1B60E63B004F40
57747	29830	54.318241999999998	54.357740999999997	61.982961000000003	61.965625000000003	Школьная	0103000020E61000000100000005000000581B6327BC284B409A99999999FB4E40581B6327BC284B402A1F82AAD1FD4E401BB80375CA2D4B402A1F82AAD1FD4E401BB80375CA2D4B409A99999999FB4E40581B6327BC284B409A99999999FB4E40
57851	28896	53.599598	53.618741	61.684787	61.671325000000003	Школьная	0103000020E610000001000000050000009E5F94A0BFCC4A405DFE43FAEDD54E409E5F94A0BFCC4A40ECDCB419A7D74E40E0D8B3E732CF4A40ECDCB419A7D74E40E0D8B3E732CF4A405DFE43FAEDD54E409E5F94A0BFCC4A405DFE43FAEDD54E40
57888	29400	54.686731000000002	54.734377000000002	61.612288999999997	61.602606999999999	Сельская	0103000020E610000001000000050000001F1329CDE6574B409BABE63922CD4E401F1329CDE6574B40AB59677C5FCE4E40A1F7C610005E4B40AB59677C5FCE4E40A1F7C610005E4B409BABE63922CD4E401F1329CDE6574B409BABE63922CD4E40
57854	28775	53.429628000000001	53.457771999999999	61.830440000000003	61.815916000000001	Школьная	0103000020E6100000010000000500000013B9E00CFEB64A403E247CEF6FE84E4013B9E00CFEB64A4027A5A0DB4BEA4E402383DC4598BA4A4027A5A0DB4BEA4E402383DC4598BA4A403E247CEF6FE84E4013B9E00CFEB64A403E247CEF6FE84E40
57890	28861	53.615938999999997	53.646633999999999	61.713389999999997	61.701399000000002	Совхозная	0103000020E610000001000000050000005CAAD216D7CE4A403B394371C7D94E405CAAD216D7CE4A408FA50F5D50DB4E40A73D25E7C4D24A408FA50F5D50DB4E40A73D25E7C4D24A403B394371C7D94E405CAAD216D7CE4A403B394371C7D94E40
57885	29188	54.159481999999997	54.188965000000003	61.215575000000001	61.196463000000001	Центральная	0103000020E610000001000000050000007C26FBE769144B40E1EF17B325994E407C26FBE769144B40E86A2BF6979B4E40598B4F0130184B40E86A2BF6979B4E40598B4F0130184B40E1EF17B325994E407C26FBE769144B40E1EF17B325994E40
57799	29561	54.882491000000002	54.922699999999999	61.774760000000001	61.722700000000003	Центральная	0103000020E61000000100000005000000D6011077F5704B40DC68006F81DC4E40D6011077F5704B40DE1FEF552BE34E4075029A081B764B40DE1FEF552BE34E4075029A081B764B40DC68006F81DC4E40D6011077F5704B40DC68006F81DC4E40
57834	29670	55.180849000000002	55.206243999999998	61.749591000000002	61.739373000000001	Комсомольская	0103000020E61000000100000005000000D5415E0F26974B40D04543C6A3DE4E40D5415E0F26974B401F300F99F2DF4E40847F1134669A4B401F300F99F2DF4E40847F1134669A4B40D04543C6A3DE4E40D5415E0F26974B40D04543C6A3DE4E40
57950	57341	52.542864999999999	56.348632000000002	62.754502000000002	60.831910000000001	Центральная	0103000020E610000001000000050000004F92AE997C454A40919BE1067C6A4E404F92AE997C454A402062838593604F40672B2FF99F2C4C402062838593604F40672B2FF99F2C4C40919BE1067C6A4E404F92AE997C454A40919BE1067C6A4E40
57883	28715	53.706291	53.724994000000002	61.762895	61.750115000000001	Центральная	0103000020E61000000100000005000000C53A55BE67DA4A40999EB0C403E04E40C53A55BE67DA4A4016A4198BA6E14E40EBE5779ACCDC4A4016A4198BA6E14E40EBE5779ACCDC4A40999EB0C403E04E40C53A55BE67DA4A40999EB0C403E04E40
57743	6314	53.865554000000003	53.970764000000003	61.507224000000001	61.451838000000002	Центральная	0103000020E6100000010000000500000004763579CAEE4A40878BDCD3D5B94E4004763579CAEE4A4087DF4DB7ECC04E402C11A8FE41FC4A4087DF4DB7ECC04E402C11A8FE41FC4A40878BDCD3D5B94E4004763579CAEE4A40878BDCD3D5B94E40
57536	57220	53.677850999999997	53.743122	61.740102	61.714669000000001	Гагарина	0103000020E61000000100000005000000CB4752D2C3D64A40863B17467ADB4E40CB4752D2C3D64A4023DA8EA9BBDE4E401478279F1EDF4A4023DA8EA9BBDE4E401478279F1EDF4A40863B17467ADB4E40CB4752D2C3D64A40863B17467ADB4E40
57669	29117	53.839888999999999	53.881929999999997	61.266255999999998	61.251685000000002	Интернациональная	0103000020E6100000010000000500000094A2957B81EB4A4067F2CD3637A04E4094A2957B81EB4A40902E36AD14A24E403EAE0D15E3F04A40902E36AD14A24E403EAE0D15E3F04A4067F2CD3637A04E4094A2957B81EB4A4067F2CD3637A04E40
57777	57258	53.873899000000002	53.910829	61.640891000000003	61.629837999999999	Центральная	0103000020E61000000100000005000000E98024ECDBEF4A4097E315889ED04E40E98024ECDBEF4A407FA65EB708D24E40CB9F6F0B96F44A407FA65EB708D24E40CB9F6F0B96F44A4097E315889ED04E40E98024ECDBEF4A4097E315889ED04E40
57855	30114	53.769666999999998	53.801549000000001	62.384144999999997	62.372011999999998	Школьный переулок	0103000020E61000000100000005000000BCE7C07284E24A401ADCD6169E2F4F40BCE7C07284E24A4001F6D1A92B314F401D925A2899E64A4001F6D1A92B314F401D925A2899E64A401ADCD6169E2F4F40BCE7C07284E24A401ADCD6169E2F4F40
57928	29211	53.650343999999997	53.673493999999998	60.896442	60.886392999999998	Центральная	0103000020E610000001000000050000002D93E1783ED34A40A033695375714E402D93E1783ED34A406361889CBE724E40AF06280D35D64A406361889CBE724E40AF06280D35D64A40A033695375714E402D93E1783ED34A40A033695375714E40
57774	28615	53.262137000000003	53.376978000000001	61.772399	61.749215999999997	Центральная	0103000020E61000000100000005000000290989B48DA14A40E9D1544FE6DF4E40290989B48DA14A40473B6EF8DDE24E40DFA7AAD040B04A40473B6EF8DDE24E40DFA7AAD040B04A40E9D1544FE6DF4E40290989B48DA14A40E9D1544FE6DF4E40
57828	28615	53.262137000000003	53.376978000000001	61.772399	61.749215999999997	Подгорная	0103000020E61000000100000005000000290989B48DA14A40E9D1544FE6DF4E40290989B48DA14A40473B6EF8DDE24E40DFA7AAD040B04A40473B6EF8DDE24E40DFA7AAD040B04A40E9D1544FE6DF4E40290989B48DA14A40E9D1544FE6DF4E40
57857	30152	54.166220000000003	54.200049999999997	62.269143	62.249085000000001	Центральная	0103000020E6100000010000000500000077F86BB246154B404B766C04E21F4F4077F86BB246154B4042791F4773224F404BC8073D9B194B4042791F4773224F404BC8073D9B194B404B766C04E21F4F4077F86BB246154B404B766C04E21F4F40
57816	28520	52.986156999999999	53.025674000000002	61.879976999999997	61.863826000000003	Центральная	0103000020E6100000010000000500000059DC7F643A7E4A409EB7B1D991EE4E4059DC7F643A7E4A40B81D1A16A3F04E40C32D1F4949834A40B81D1A16A3F04E40C32D1F4949834A409EB7B1D991EE4E4059DC7F643A7E4A409EB7B1D991EE4E40
57838	57281	49.039102999999997	50.709583000000002	62.77102	61.618729999999999	Молодежная	0103000020E610000001000000050000007616BD5301854840EC866D8B32CF4E407616BD5301854840ED478AC8B0624F401766A19DD35A4940ED478AC8B0624F401766A19DD35A4940EC866D8B32CF4E407616BD5301854840EC866D8B32CF4E40
57772	26963	50.374187999999997	50.423729999999999	62.235923999999997	62.219819000000001	Центральная	0103000020E610000001000000050000001F477364E52F49400C056C07231C4F401F477364E52F4940B62BF4C1321E4F40C32ADEC83C364940B62BF4C1321E4F40C32ADEC83C3649400C056C07231C4F401F477364E52F49400C056C07231C4F40
57827	27127	50.236790999999997	50.300705999999998	62.168928000000001	62.154218999999998	Школьная	0103000020E610000001000000050000005A7EE02A4F1E4940FEB5BC72BD134F405A7EE02A4F1E494079B0C56E9F154F4001DBC1887D26494079B0C56E9F154F4001DBC1887D264940FEB5BC72BD134F405A7EE02A4F1E4940FEB5BC72BD134F40
57731	26991	50.487816000000002	50.521270000000001	62.172825000000003	62.160812	Клубная	0103000020E61000000100000005000000973B33C1703E4940F566D47C95144F40973B33C1703E494032772D211F164F406631B1F9B842494032772D211F164F406631B1F9B8424940F566D47C95144F40973B33C1703E4940F566D47C95144F40
57875	27220	50.121214000000002	50.167701999999998	62.186402999999999	62.177112000000001	Береговая	0103000020E610000001000000050000009FE8BAF0830F494055DD239BAB164F409FE8BAF0830F49402A70B20DDC174F40A5BC5642771549402A70B20DDC174F40A5BC56427715494055DD239BAB164F409FE8BAF0830F494055DD239BAB164F40
57626	27248	50.039144	50.114369000000003	62.389794999999999	62.340882999999998	Пионерская	0103000020E61000000100000005000000D5EAABAB020549409561DC0DA22B4F40D5EAABAB02054940799274CDE4314F408F56B5A4A30E4940799274CDE4314F408F56B5A4A30E49409561DC0DA22B4F40D5EAABAB020549409561DC0DA22B4F40
57580	27248	50.039144	50.114369000000003	62.389794999999999	62.340882999999998	Комсомольская	0103000020E61000000100000005000000D5EAABAB020549409561DC0DA22B4F40D5EAABAB02054940799274CDE4314F408F56B5A4A30E4940799274CDE4314F408F56B5A4A30E49409561DC0DA22B4F40D5EAABAB020549409561DC0DA22B4F40
57575	27248	50.039144	50.114369000000003	62.389794999999999	62.340882999999998	Гоголя	0103000020E61000000100000005000000D5EAABAB020549409561DC0DA22B4F40D5EAABAB02054940799274CDE4314F408F56B5A4A30E4940799274CDE4314F408F56B5A4A30E49409561DC0DA22B4F40D5EAABAB020549409561DC0DA22B4F40
57726	26322	49.290937	49.342607999999998	62.035836000000003	62.017716	Школьная	0103000020E610000001000000050000002219726C3DA54840D74E948444024F402219726C3DA548407E02284696044F408AAC3594DAAB48407E02284696044F408AAC3594DAAB4840D74E948444024F402219726C3DA54840D74E948444024F40
57923	27074	50.231256999999999	50.289935	62.147575000000003	62.138806000000002	Центральная	0103000020E610000001000000050000004CFC51D4991D49408A3E1F65C4114F404CFC51D4991D4940865AD3BCE3124F409E7B0F971C254940865AD3BCE3124F409E7B0F971C2549408A3E1F65C4114F404CFC51D4991D49408A3E1F65C4114F40
57765	26428	49.313673000000001	49.349955999999999	62.115341000000001	62.097867000000001	Центральная	0103000020E61000000100000005000000B151D66F26A84840C72DE6E7860C4F40B151D66F26A84840A8716F7EC30E4F40FD84B35BCBAC4840A8716F7EC30E4F40FD84B35BCBAC4840C72DE6E7860C4F40B151D66F26A84840C72DE6E7860C4F40
57884	26796	49.764429999999997	49.803128999999998	62.223827	62.207875000000001	Центральная	0103000020E61000000100000005000000670A9DD7D8E14840F853E3A59B1A4F40670A9DD7D8E148401C7BF65CA61C4F400EBC5AEECCE648401C7BF65CA61C4F400EBC5AEECCE64840F853E3A59B1A4F40670A9DD7D8E14840F853E3A59B1A4F40
57666	26498	49.532718000000003	49.624561999999997	62.106782000000003	62.038321000000003	Свердлова	0103000020E61000000100000005000000CAFE791A30C4484001E0D8B3E7044F40CAFE791A30C4484097E65608AB0D4F408429CAA5F1CF484097E65608AB0D4F408429CAA5F1CF484001E0D8B3E7044F40CAFE791A30C4484001E0D8B3E7044F40
57624	26498	49.532718000000003	49.624561999999997	62.106782000000003	62.038321000000003	Первомайская	0103000020E61000000100000005000000CAFE791A30C4484001E0D8B3E7044F40CAFE791A30C4484097E65608AB0D4F408429CAA5F1CF484097E65608AB0D4F408429CAA5F1CF484001E0D8B3E7044F40CAFE791A30C4484001E0D8B3E7044F40
57625	26498	49.532718000000003	49.624561999999997	62.106782000000003	62.038321000000003	Мира	0103000020E61000000100000005000000CAFE791A30C4484001E0D8B3E7044F40CAFE791A30C4484097E65608AB0D4F408429CAA5F1CF484097E65608AB0D4F408429CAA5F1CF484001E0D8B3E7044F40CAFE791A30C4484001E0D8B3E7044F40
57929	57325	49.404358000000002	49.432268999999998	62.104331999999999	62.089604999999999	Северная	0103000020E6100000010000000500000020F0C000C2B348406F47382D780B4F4020F0C000C2B3484090F63FC05A0D4F408D09319754B7484090F63FC05A0D4F408D09319754B748406F47382D780B4F4020F0C000C2B348406F47382D780B4F40
57898	26773	49.862149000000002	49.901260999999998	62.173211000000002	62.157291000000001	Центральная	0103000020E61000000100000005000000BAA3FFE55AEE4840427A8A1C22144F40BAA3FFE55AEE48405B272EC72B164F4083143C855CF348405B272EC72B164F4083143C855CF34840427A8A1C22144F40BAA3FFE55AEE4840427A8A1C22144F40
57876	5910	49.728963999999998	49.751323999999997	62.574671000000002	62.552495	Станционная	0103000020E610000001000000050000000DFB3DB14EDD48400D1AFA27B8464F400DFB3DB14EDD4840D57ABFD18E494F40965984622BE04840D57ABFD18E494F40965984622BE048400D1AFA27B8464F400DFB3DB14EDD48400D1AFA27B8464F40
57821	26713	49.813567999999997	49.842485000000003	62.131923	62.119177999999998	пер.Клубный	0103000020E610000001000000050000003B8908FF22E848408B338639410F4F403B8908FF22E848408C4B55DAE2104F406F2F698CD6EB48408C4B55DAE2104F406F2F698CD6EB48408B338639410F4F403B8908FF22E848408B338639410F4F40
57630	26864	49.957540999999999	50.040913000000003	62.234219000000003	62.203214000000003	Центральная	0103000020E6100000010000000500000021CA17B490FA4840700B96EA021A4F4021CA17B490FA4840098D60E3FA1D4F409A7D1EA33C054940098D60E3FA1D4F409A7D1EA33C054940700B96EA021A4F4021CA17B490FA4840700B96EA021A4F40
57913	57316	56.443862000000003	56.468988000000003	66.296079000000006	66.283556000000004	Центральная	0103000020E61000000100000005000000F5F75278D0384C406AA510C825925040F5F75278D0384C40138255F5F2925040B51B7DCC073C4C40138255F5F2925040B51B7DCC073C4C406AA510C825925040F5F75278D0384C406AA510C825925040
57740	57250	56.890602999999999	56.939050000000002	65.989485999999999	65.974723999999995	Советская	0103000020E61000000100000005000000185C7347FF714C4015A8C5E0617E5040185C7347FF714C40647616BD537F504087A757CA32784C40647616BD537F504087A757CA32784C4015A8C5E0617E5040185C7347FF714C4015A8C5E0617E5040
57823	57278	56.662638000000001	56.685195	65.690669999999997	65.675381999999999	Центральная	0103000020E610000001000000050000001E8B6D52D1544C40A7936C75396B50401E8B6D52D1544C400395F1EF336C5040FD304278B4574C400395F1EF336C5040FD304278B4574C40A7936C75396B50401E8B6D52D1544C40A7936C75396B5040
57549	57222	57.416567000000001	57.498116000000003	65.973922000000002	65.940175999999994	Школьная	0103000020E61000000100000005000000E2CB441152B54C40FB1EF5D72B7C5040E2CB441152B54C40B7B6F0BC547E5040A3CEDC43C2BF4C40B7B6F0BC547E5040A3CEDC43C2BF4C40FB1EF5D72B7C5040E2CB441152B54C40FB1EF5D72B7C5040
57798	57268	56.875934000000001	56.895302000000001	66.036129000000003	66.023386000000002	Школьная	0103000020E610000001000000050000002CBAF59A1E704C40CB4BFE277F8150402CBAF59A1E704C40FB5B02F04F8250408E05854199724C40FB5B02F04F8250408E05854199724C40CB4BFE277F8150402CBAF59A1E704C40CB4BFE277F815040
57750	57252	55.097431	55.168757999999997	65.964729000000005	65.938034999999999	Центральная	0103000020E61000000100000005000000EC4E779E788C4B4037E0F3C3087C5040EC4E779E788C4B402E20B41EBE7D50401C78B5DC99954B402E20B41EBE7D50401C78B5DC99954B4037E0F3C3087C5040EC4E779E788C4B4037E0F3C3087C5040
57916	57318	57.346893999999999	57.372827999999998	65.969753999999995	65.961579	Центральная	0103000020E61000000100000005000000DD96C80567AC4C404E61A5828A7D5040DD96C80567AC4C4092CA1473107E50403C84F1D3B8AF4C4092CA1473107E50403C84F1D3B8AF4C404E61A5828A7D5040DD96C80567AC4C404E61A5828A7D5040
57783	57261	55.849778999999998	55.881912	66.334739999999996	66.327577000000005	Школьный переулок	0103000020E61000000100000005000000EEE9EA8EC5EC4B40FF7A8505F7945040EEE9EA8EC5EC4B406F2A52616C95504098F90E7EE2F04B406F2A52616C95504098F90E7EE2F04B40FF7A8505F7945040EEE9EA8EC5EC4B40FF7A8505F7945040
57865	25291	48.887	48.901418	63.451922000000003	63.446899999999999	Лесная	0103000020E61000000100000005000000A8C64B37897148408C4AEA0434B94F40A8C64B3789714840E52B8194D8B94F404B033FAA61734840E52B8194D8B94F404B033FAA617348408C4AEA0434B94F40A8C64B37897148408C4AEA0434B94F40
57814	5333	48.221069999999997	48.249034999999999	63.435586000000001	63.421591999999997	Школьный переулок	0103000020E61000000100000005000000381092054C1C4840AB2006BAF6B54F40381092054C1C4840384C3448C1B74F409947FE60E01F4840384C3448C1B74F409947FE60E01F4840AB2006BAF6B54F40381092054C1C4840AB2006BAF6B54F40
57869	25875	48.648282000000002	48.729041000000002	63.448891000000003	63.423865999999997	Привокзальная	0103000020E61000000100000005000000F14A92E7FA52484073F1B73D41B64F40F14A92E7FA524840003CA24275B94F40B9382A37515D4840003CA24275B94F40B9382A37515D484073F1B73D41B64F40F14A92E7FA52484073F1B73D41B64F40
57574	25875	48.648282000000002	48.729041000000002	63.448891000000003	63.423865999999997	Ленина	0103000020E61000000100000005000000F14A92E7FA52484073F1B73D41B64F40F14A92E7FA524840003CA24275B94F40B9382A37515D4840003CA24275B94F40B9382A37515D484073F1B73D41B64F40F14A92E7FA52484073F1B73D41B64F40
57573	25875	48.648282000000002	48.729041000000002	63.448891000000003	63.423865999999997	Дружбы	0103000020E61000000100000005000000F14A92E7FA52484073F1B73D41B64F40F14A92E7FA524840003CA24275B94F40B9382A37515D4840003CA24275B94F40B9382A37515D484073F1B73D41B64F40F14A92E7FA52484073F1B73D41B64F40
57815	26084	47.925137999999997	47.952986000000003	63.453028000000003	63.443007000000001	Таежная	0103000020E61000000100000005000000B72407EC6AF6474015731074B4B84F40B72407EC6AF647400E164ED2FCB94F40DFC5FB71FBF947400E164ED2FCB94F40DFC5FB71FBF9474015731074B4B84F40B72407EC6AF6474015731074B4B84F40
57812	5774	48.530844999999999	48.539999000000002	63.308427999999999	63.302508000000003	Привокзальная	0103000020E61000000100000005000000601F9DBAF2434840A2630795B8A64F40601F9DBAF2434840D99596917AA74F40B56FEEAF1E454840D99596917AA74F40B56FEEAF1E454840A2630795B8A64F40601F9DBAF2434840A2630795B8A64F40
57810	26243	49.175736999999998	49.210231999999998	62.939551000000002	62.916727000000002	Ленина	0103000020E610000001000000050000003CD9CD8C7E9648401B2E724F57754F403CD9CD8C7E96484049F6083543784F404D49D6E1E89A484049F6083543784F404D49D6E1E89A48401B2E724F57754F403CD9CD8C7E9648401B2E724F57754F40
57668	7035	48.550257999999999	48.575060000000001	63.229239999999997	63.214889999999997	5Интернациональная	0103000020E61000000100000005000000622EA9DA6E464840641EF983819B4F40622EA9DA6E464840AF777FBC579D4F406F9EEA909B494840AF777FBC579D4F406F9EEA909B494840641EF983819B4F40622EA9DA6E464840641EF983819B4F40
57520	25164	48.859287000000002	48.927838000000001	63.465536	63.452264	Центральная	0103000020E610000001000000050000006170CD1DFD6D48403E9468C9E3B94F406170CD1DFD6D48402A8E03AF96BB4F4037FE4465C37648402A8E03AF96BB4F4037FE4465C37648403E9468C9E3B94F406170CD1DFD6D48403E9468C9E3B94F40
57768	5499	48.866402000000001	48.890476999999997	63.070214	63.053004000000001	Комсомольская	0103000020E610000001000000050000003198BF42E66E48405247C7D5C8864F403198BF42E66E484055DCB8C5FC884F408B6B7C26FB71484055DCB8C5FC884F408B6B7C26FB7148405247C7D5C8864F403198BF42E66E48405247C7D5C8864F40
57924	26302	49.284486999999999	49.331307000000002	62.840600999999999	62.821131000000001	Административный переулок	0103000020E610000001000000050000008E91EC116AA44840AB5D13D21A694F408E91EC116AA4484011FE45D0986B4F40CBF78C4468AA484011FE45D0986B4F40CBF78C4468AA4840AB5D13D21A694F408E91EC116AA44840AB5D13D21A694F40
57880	25413	48.816338999999999	48.845103000000002	64.174627000000001	64.160094000000001	Центральная	0103000020E6100000010000000500000084B9DDCB7D6848404B92E7FA3E0A504084B9DDCB7D684840E97FB9162D0B50403160C9552C6C4840E97FB9162D0B50403160C9552C6C48404B92E7FA3E0A504084B9DDCB7D6848404B92E7FA3E0A5040
57477	26054	47.935622000000002	47.967674000000002	63.432501000000002	63.415706999999998	Дружбы	0103000020E6100000010000000500000085B53176C2F74740F0DB10E335B54F4085B53176C2F74740603E59315CB74F404298DBBDDCFB4740603E59315CB74F404298DBBDDCFB4740F0DB10E335B54F4085B53176C2F74740F0DB10E335B54F40
57754	32658	56.815136000000003	56.849685000000001	61.831246999999998	61.812885999999999	Школьная	0103000020E6100000010000000500000069E55E6056684C4029B000A60CE84E4069E55E6056684C40F5F23B4D66EA4E406D73637AC26C4C40F5F23B4D66EA4E406D73637AC26C4C4029B000A60CE84E4069E55E6056684C4029B000A60CE84E40
57868	57297	56.719214000000001	56.768566999999997	62.520764999999997	62.513392000000003	Центральная	0103000020E61000000100000005000000A56950340F5C4C4097033DD4B6414F40A56950340F5C4C4062F3716DA8424F4075E4486760624C4062F3716DA8424F4075E4486760624C4097033DD4B6414F40A56950340F5C4C4097033DD4B6414F40
57670	6027	56.042270000000002	56.227916	62.751730000000002	62.678887000000003	кв.южный	0103000020E610000001000000050000000CCD751A69054C40FC56EBC4E5564F400CCD751A69054C4007B64AB038604F40191EFB592C1D4C4007B64AB038604F40191EFB592C1D4C40FC56EBC4E5564F400CCD751A69054C40FC56EBC4E5564F40
57813	6027	56.042270000000002	56.227916	62.751730000000002	62.678887000000003	кв.Южный	0103000020E610000001000000050000000CCD751A69054C40FC56EBC4E5564F400CCD751A69054C4007B64AB038604F40191EFB592C1D4C4007B64AB038604F40191EFB592C1D4C40FC56EBC4E5564F400CCD751A69054C40FC56EBC4E5564F40
57667	6027	56.042270000000002	56.227916	62.751730000000002	62.678887000000003	Портовая	0103000020E610000001000000050000000CCD751A69054C40FC56EBC4E5564F400CCD751A69054C4007B64AB038604F40191EFB592C1D4C4007B64AB038604F40191EFB592C1D4C40FC56EBC4E5564F400CCD751A69054C40FC56EBC4E5564F40
57945	57339	55.969802999999999	55.981158000000001	63.132016999999998	63.123190000000001	Лесная	0103000020E610000001000000050000000648348122FC4B40DD989EB0C48F4F400648348122FC4B400DC2DCEEE5904F40B91AD99596FD4B400DC2DCEEE5904F40B91AD99596FD4B40DD989EB0C48F4F400648348122FC4B40DD989EB0C48F4F40
57935	57331	56.161351000000003	56.183539000000003	62.934995999999998	62.923566000000001	Школьная	0103000020E61000000100000005000000A5164A26A7144C4049D9226937764F40A5164A26A7144C4006F2ECF2AD774F403145B9347E174C4006F2ECF2AD774F403145B9347E174C4049D9226937764F40A5164A26A7144C4049D9226937764F40
57941	57335	57.446634000000003	57.481219000000003	62.632247	62.612811999999998	Лесная	0103000020E610000001000000050000000EA48B4D2BB94C40554CA59F704E4F400EA48B4D2BB94C403FFF3D78ED504F405F9B8D9598BD4C403FFF3D78ED504F405F9B8D9598BD4C40554CA59F704E4F400EA48B4D2BB94C40554CA59F704E4F40
57877	28346	56.110156000000003	56.126145999999999	62.951186999999997	62.938462000000001	Центральная	0103000020E61000000100000005000000A6BA8097190E4C40F644D7851F784F40A6BA8097190E4C40AFB0E07EC0794F40B742588D25104C40AFB0E07EC0794F40B742588D25104C40F644D7851F784F40A6BA8097190E4C40F644D7851F784F40
57942	57336	56.858668000000002	56.882330000000003	62.515920999999999	62.509464000000001	Школьная	0103000020E61000000100000005000000950F41D5E86D4C40A33EC91D36414F40950F41D5E86D4C40E92807B309424F40CD237F30F0704C40E92807B309424F40CD237F30F0704C40A33EC91D36414F40950F41D5E86D4C40A33EC91D36414F40
57735	32803	55.809741000000002	55.861134	62.764564999999997	62.750127999999997	Советская	0103000020E610000001000000050000007C9DD497A5E74B402DE8BD3104604F407C9DD497A5E74B4047551344DD614F40A1BC8FA339EE4B4047551344DD614F40A1BC8FA339EE4B402DE8BD3104604F407C9DD497A5E74B402DE8BD3104604F40
57879	27444	57.234146000000003	57.254223000000003	61.688375000000001	61.675477999999998	Школьная	0103000020E610000001000000050000009F3E027FF89D4C407095271076D64E409F3E027FF89D4C40273108AC1CD84E400D7217618AA04C40273108AC1CD84E400D7217618AA04C407095271076D64E409F3E027FF89D4C407095271076D64E40
57758	32664	56.593189000000002	56.624944999999997	62.150072000000002	62.129601999999998	Комсомольская	0103000020E6100000010000000500000069ACFD9DED4B4C4083BF5FCC96104F4069ACFD9DED4B4C40CD052E8F35134F403C66A032FE4F4C40CD052E8F35134F403C66A032FE4F4C4083BF5FCC96104F4069ACFD9DED4B4C4083BF5FCC96104F40
57938	57334	56.841340000000002	56.867201999999999	61.975856	61.965252999999997	Сплавная	0103000020E6100000010000000500000088687407B16B4C40D5AE09698DFB4E4088687407B16B4C407DCD72D9E8FC4E404D83A279006F4C407DCD72D9E8FC4E404D83A279006F4C40D5AE09698DFB4E4088687407B16B4C40D5AE09698DFB4E40
57944	57338	56.391534999999998	56.412547000000004	62.562972000000002	62.545718999999998	Комсомольская	0103000020E61000000100000005000000A31EA2D11D324C4025E7C41EDA454F40A31EA2D11D324C4028486C770F484F400E881057CE344C4028486C770F484F400E881057CE344C4025E7C41EDA454F40A31EA2D11D324C4025E7C41EDA454F40
81134	62096	55.629188999999997	55.650803000000003	62.775111000000003	62.764960000000002	улица Почтовая	0103000020E610000001000000050000006000E14389D04B40C45F9335EA614F406000E14389D04B408BE255D636634F40C19140834DD34B408BE255D636634F40C19140834DD34B40C45F9335EA614F406000E14389D04B40C45F9335EA614F40
57527	57219	56.042270000000002	56.227916	62.751730000000002	62.678887000000003	Ленина	0103000020E610000001000000050000000CCD751A69054C40FC56EBC4E5564F400CCD751A69054C4007B64AB038604F40191EFB592C1D4C4007B64AB038604F40191EFB592C1D4C40FC56EBC4E5564F400CCD751A69054C40FC56EBC4E5564F40
57895	1602	49.435009000000001	49.459425000000003	60.957411	60.948141	Центральная	0103000020E610000001000000050000009B3BFA5FAEB74840957F2DAF5C794E409B3BFA5FAEB7484053EA92718C7A4E407FFB3A70CEBA484053EA92718C7A4E407FFB3A70CEBA4840957F2DAF5C794E409B3BFA5FAEB74840957F2DAF5C794E40
57921	756	50.176056000000003	50.188426	61.225143000000003	61.219439000000001	местечко Чоййыв	0103000020E61000000100000005000000DE21C50089164940C53BC093169C4E40DE21C5008916494030F65E7CD19C4E40A9DBD9571E18494030F65E7CD19C4E40A9DBD9571E184940C53BC093169C4E40DE21C50089164940C53BC093169C4E40
57708	1032	50.256625999999997	50.303455	61.132688000000002	61.108018999999999	Центральная	0103000020E61000000100000005000000D2A6EA1ED92049405E2C0C91D38D4E40D2A6EA1ED92049402C499EEBFB904E4062670A9DD72649402C499EEBFB904E4062670A9DD72649405E2C0C91D38D4E40D2A6EA1ED92049405E2C0C91D38D4E40
57785	2037	50.265438000000003	50.281509	60.714677000000002	60.708703999999997	Большая	0103000020E61000000100000005000000CE8E54DFF9214940AE450BD0B65A4E40CE8E54DFF9214940091A33897A5B4E40CC43A67C08244940091A33897A5B4E40CC43A67C08244940AE450BD0B65A4E40CE8E54DFF9214940AE450BD0B65A4E40
57784	1804	50.328688999999997	50.344113	61.002389999999998	60.994808999999997	Центральная	0103000020E6100000010000000500000008C72C7B122A49401B62BCE6557F4E4008C72C7B122A494031EBC5504E804E40719010E50B2C494031EBC5504E804E40719010E50B2C49401B62BCE6557F4E4008C72C7B122A49401B62BCE6557F4E40
57718	1792	50.281339000000003	50.322212	60.923493999999998	60.895654999999998	Центральная	0103000020E61000000100000005000000700B96EA02244940DBBFB2D2A4724E40700B96EA02244940AF06280D35764E407B30293E3E294940AF06280D35764E407B30293E3E294940DBBFB2D2A4724E40700B96EA02244940DBBFB2D2A4724E40
57870	874	50.130377000000003	50.145755999999999	61.315530000000003	61.304614999999998	Новосельская	0103000020E6100000010000000500000047938B31B01049407E6FD39FFDA64E4047938B31B010494015747B4963A84E400F99F221A812494015747B4963A84E400F99F221A81249407E6FD39FFDA64E4047938B31B01049407E6FD39FFDA64E40
57871	57299	50.208961000000002	50.219759000000003	61.219988999999998	61.214413	Центральная	0103000020E61000000100000005000000DA91EA3BBF1A49402B6B9BE2719B4E40DA91EA3BBF1A4940683D7C99289C4E4037001B10211C4940683D7C99289C4E4037001B10211C49402B6B9BE2719B4E40DA91EA3BBF1A49402B6B9BE2719B4E40
57899	1556	49.68121	49.704754999999999	60.972206	60.963456000000001	Комсомольская	0103000020E61000000100000005000000A5DAA7E331D748404791B586527B4E40A5DAA7E331D74840CC7C073F717C4E40A3586E6935DA4840CC7C073F717C4E40A3586E6935DA48404791B586527B4E40A5DAA7E331D748404791B586527B4E40
57535	1156	50.06259	50.136288	61.087929000000003	61.057003999999999	Советская	0103000020E610000001000000050000004087F9F202084940DFDE35E84B874E404087F9F2020849405CAFE941418B4E402B6B9BE2711149405CAFE941418B4E402B6B9BE271114940DFDE35E84B874E404087F9F202084940DFDE35E84B874E40
57555	1156	50.06259	50.136288	61.087929000000003	61.057003999999999	Оплеснина	0103000020E610000001000000050000004087F9F202084940DFDE35E84B874E404087F9F2020849405CAFE941418B4E402B6B9BE2711149405CAFE941418B4E402B6B9BE271114940DFDE35E84B874E404087F9F202084940DFDE35E84B874E40
57896	1905	50.194364	50.217567000000003	60.919659000000003	60.908268999999997	Центральная	0103000020E6100000010000000500000087C267EBE01849403D7C992842744E4087C267EBE01849406D3CD862B7754E402CD8463CD91B49406D3CD862B7754E402CD8463CD91B49403D7C992842744E4087C267EBE01849403D7C992842744E40
57748	32624	50.611775000000002	50.651201999999998	61.185459000000002	61.174222	Ленина	0103000020E6100000010000000500000055C1A8A44E4E4940321F10E84C964E4055C1A8A44E4E4940DBDFD91EBD974E407E8B4E965A534940DBDFD91EBD974E407E8B4E965A534940321F10E84C964E4055C1A8A44E4E4940321F10E84C964E40
57737	57240	49.361913000000001	51.577382999999998	62.219696999999996	60.925697	м.Погост	0103000020E61000000100000005000000A67F492A53AE4840AE80423D7D764E40A67F492A53AE4840C00303081F1C4F401822A7AFE7C94940C00303081F1C4F401822A7AFE7C94940AE80423D7D764E40A67F492A53AE4840AE80423D7D764E40
57863	6237	50.701929999999997	50.729391	61.516509999999997	61.486693000000002	Педегрезд	0103000020E61000000100000005000000670A9DD7D85949409818CBF44BBE4E40670A9DD7D85949404A07EBFF1CC24E40957F2DAF5C5D49404A07EBFF1CC24E40957F2DAF5C5D49409818CBF44BBE4E40670A9DD7D85949409818CBF44BBE4E40
57752	371	50.641626000000002	50.677495999999998	62.020775999999998	62.006169	Береговая	0103000020E61000000100000005000000B421FFCC20524940E09F5225CA004F40B421FFCC205249405645B8C9A8024F40DD955D30B85649405645B8C9A8024F40DD955D30B8564940E09F5225CA004F40B421FFCC20524940E09F5225CA004F40
57713	598	50.169452999999997	50.189808999999997	61.958542000000001	61.945253999999998	Новоселов	0103000020E61000000100000005000000C39ACAA2B0154940E3344415FEF84E40C39ACAA2B0154940D5EB1681B1FA4E4044BE4BA94B184940D5EB1681B1FA4E4044BE4BA94B184940E3344415FEF84E40C39ACAA2B0154940E3344415FEF84E40
57864	240	50.761749000000002	50.789892999999999	61.944273000000003	61.920026	Боровая	0103000020E610000001000000050000005F61C1FD806149401FBC7669C3F54E405F61C1FD8061494077BF0AF0DDF84E406F2BBD361B65494077BF0AF0DDF84E406F2BBD361B6549401FBC7669C3F54E405F61C1FD806149401FBC7669C3F54E40
57757	551	50.328113999999999	50.386864000000003	61.999243	61.988796000000001	Набережная	0103000020E610000001000000050000000CAEB9A3FF294940333509DE90FE4E400CAEB9A3FF294940E3E0D231E7FF4E40F8FF71C284314940E3E0D231E7FF4E40F8FF71C284314940333509DE90FE4E400CAEB9A3FF294940333509DE90FE4E40
57637	6227	50.562511000000001	50.596701000000003	61.397903999999997	61.381360000000001	1 микрорайон	0103000020E61000000100000005000000F451465C0048494054008C67D0B04E40F451465C004849404A79AD84EEB24E40C93EC8B2604C49404A79AD84EEB24E40C93EC8B2604C494054008C67D0B04E40F451465C0048494054008C67D0B04E40
57841	31960	51.077057000000003	51.093801999999997	61.777214999999998	61.771070999999999	Озёльская	0103000020E61000000100000005000000C576F700DD8949406FF25B74B2E24E40C576F700DD894940F67AF7C77BE34E40522635B4018C4940F67AF7C77BE34E40522635B4018C49406FF25B74B2E24E40C576F700DD8949406FF25B74B2E24E40
57946	57340	50.727621999999997	50.759134000000003	61.404893999999999	61.386251000000001	Первомайская	0103000020E61000000100000005000000D0ECBAB7225D49400E863AAC70B14E40D0ECBAB7225D49405E2C0C91D3B34E400EA48B4D2B6149405E2C0C91D3B34E400EA48B4D2B6149400E863AAC70B14E40D0ECBAB7225D49400E863AAC70B14E40
57926	57323	50.165025	50.192988999999997	61.696392000000003	61.688102000000001	Лесная	0103000020E61000000100000005000000DE02098A1F154940F627F1B913D84E40DE02098A1F1549401899805F23D94E406EBE11DDB31849401899805F23D94E406EBE11DDB3184940F627F1B913D84E40DE02098A1F154940F627F1B913D84E40
57893	506	50.437789000000002	50.464261999999998	62.002977000000001	61.994909	Северная	0103000020E6100000010000000500000037C64E78093849407FBF982D59FF4E4037C64E7809384940F2D1E28C61004F404563EDEF6C3B4940F2D1E28C61004F404563EDEF6C3B49407FBF982D59FF4E4037C64E78093849407FBF982D59FF4E40
57524	110	50.714812000000002	50.768450000000001	61.901887000000002	61.877614999999999	2 квартал	0103000020E61000000100000005000000E964A9F57E5B494051BD35B055F04E40E964A9F57E5B494002D8800871F34E403C4ED1915C62494002D8800871F34E403C4ED1915C62494051BD35B055F04E40E964A9F57E5B494051BD35B055F04E40
57528	103	50.703133000000001	50.812207000000001	61.641514999999998	61.595396999999998	Тимирязева	0103000020E6100000010000000500000083DE1B43005A4940799109F835CC4E4083DE1B43005A49405C72DC291DD24E40884A2366F66749405C72DC291DD24E40884A2366F6674940799109F835CC4E4083DE1B43005A4940799109F835CC4E40
57749	103	50.703133000000001	50.812207000000001	61.641514999999998	61.595396999999998	Северная	0103000020E6100000010000000500000083DE1B43005A4940799109F835CC4E4083DE1B43005A49405C72DC291DD24E40884A2366F66749405C72DC291DD24E40884A2366F6674940799109F835CC4E4083DE1B43005A4940799109F835CC4E40
57546	103	50.703133000000001	50.812207000000001	61.641514999999998	61.595396999999998	Домны Каликовой	0103000020E6100000010000000500000083DE1B43005A4940799109F835CC4E4083DE1B43005A49405C72DC291DD24E40884A2366F66749405C72DC291DD24E40884A2366F6674940799109F835CC4E4083DE1B43005A4940799109F835CC4E40
57732	57245	53.858646	53.894649999999999	63.627198	63.612022000000003	Лесная	0103000020E61000000100000005000000AD6BB41CE8ED4A405D37A5BC56CE4F40AD6BB41CE8ED4A40ED0E290648D04F40E6AE25E483F24A40ED0E290648D04F40E6AE25E483F24A405D37A5BC56CE4F40AD6BB41CE8ED4A405D37A5BC56CE4F40
79494	6907	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	Спортивная	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57610	6907	53.826666000000003	54.013668000000003	63.613194	63.535876999999999	Куратова	0103000020E610000001000000050000008A5B0531D0E94A40DCD6169E97C44F408A5B0531D0E94A403D0D18247DCE4F4039807EDFBF014B403D0D18247DCE4F4039807EDFBF014B40DCD6169E97C44F408A5B0531D0E94A40DCD6169E97C44F40
57742	57251	54.060918999999998	54.086359999999999	63.549402999999998	63.538803000000001	Мира	0103000020E610000001000000050000003E5A9C31CC074B404CFE277FF7C44F403E5A9C31CC074B4082A966D652C64F405ED72FD80D0B4B4082A966D652C64F405ED72FD80D0B4B404CFE277FF7C44F403E5A9C31CC074B404CFE277FF7C44F40
57621	57215	54.774028999999999	54.887746999999997	63.659548999999998	63.628656999999997	площадь Ленина	0103000020E61000000100000005000000EA93DC6113634B4063B323D577D04F40EA93DC6113634B40048E041A6CD44F40A10F96B1A1714B40048E041A6CD44F40A10F96B1A1714B4063B323D577D04F40EA93DC6113634B4063B323D577D04F40
57504	57215	54.774028999999999	54.887746999999997	63.659548999999998	63.628656999999997	Северная	0103000020E61000000100000005000000EA93DC6113634B4063B323D577D04F40EA93DC6113634B40048E041A6CD44F40A10F96B1A1714B40048E041A6CD44F40A10F96B1A1714B4063B323D577D04F40EA93DC6113634B4063B323D577D04F40
57607	57215	54.774028999999999	54.887746999999997	63.659548999999998	63.628656999999997	Пионерская	0103000020E61000000100000005000000EA93DC6113634B4063B323D577D04F40EA93DC6113634B40048E041A6CD44F40A10F96B1A1714B40048E041A6CD44F40A10F96B1A1714B4063B323D577D04F40EA93DC6113634B4063B323D577D04F40
57510	57215	54.774028999999999	54.887746999999997	63.659548999999998	63.628656999999997	Ленина	0103000020E61000000100000005000000EA93DC6113634B4063B323D577D04F40EA93DC6113634B40048E041A6CD44F40A10F96B1A1714B40048E041A6CD44F40A10F96B1A1714B4063B323D577D04F40EA93DC6113634B4063B323D577D04F40
57557	57223	54.813958999999997	54.853431	64.187072999999998	64.174364999999995	Советская	0103000020E6100000010000000500000076A4FACE2F684B404A24D1CB280B504076A4FACE2F684B40BC3D0801F90B504040321D3A3D6D4B40BC3D0801F90B504040321D3A3D6D4B404A24D1CB280B504076A4FACE2F684B404A24D1CB280B5040
58319	57369	\N	\N	\N	\N	Новая	\N
57724	57242	54.173577000000002	54.216849000000003	63.737445000000001	63.712744999999998	Лесная	0103000020E610000001000000050000003D2B69C537164B409AB1683A3BDB4F403D2B69C537164B40A3CC069964DE4F40CD9541B5C11B4B40A3CC069964DE4F40CD9541B5C11B4B409AB1683A3BDB4F403D2B69C537164B409AB1683A3BDB4F40
57725	57243	55.177416999999998	55.222171000000003	64.417846999999995	64.394604000000001	40 лет Победы	0103000020E610000001000000050000009160AA99B5964B40BBB72231411950409160AA99B5964B40D4EE5701BE1A5040508F6D19709C4B40D4EE5701BE1A5040508F6D19709C4B40BBB72231411950409160AA99B5964B40BBB7223141195040
57722	57237	54.938124000000002	55.020715000000003	62.907063999999998	62.883336999999997	Октябрьская	0103000020E61000000100000005000000DECB7D7214784B40622CD32F11714F40DECB7D7214784B4081B053AC1A744F40B1C403CAA6824B4081B053AC1A744F40B1C403CAA6824B40622CD32F11714F40DECB7D7214784B40622CD32F11714F40
57704	57237	54.938124000000002	55.020715000000003	62.907063999999998	62.883336999999997	Кирова	0103000020E61000000100000005000000DECB7D7214784B40622CD32F11714F40DECB7D7214784B4081B053AC1A744F40B1C403CAA6824B4081B053AC1A744F40B1C403CAA6824B40622CD32F11714F40DECB7D7214784B40622CD32F11714F40
57701	57236	54.426039000000003	54.473354	63.925438	63.903032000000003	Ленина	0103000020E6100000010000000500000008E9297288364B40E99E758D96F34F4008E9297288364B40E23C9CC074F64F4024B726DD963C4B40E23C9CC074F64F4024B726DD963C4B40E99E758D96F34F4008E9297288364B40E99E758D96F34F40
57738	57249	54.675268000000003	54.731009	63.009712	62.985807000000001	Садовая	0103000020E6100000010000000500000086048C2E6F564B407D957CEC2E7E4F4086048C2E6F564B407B30293E3E814F40740AF2B3915D4B407B30293E3E814F40740AF2B3915D4B407D957CEC2E7E4F4086048C2E6F564B407D957CEC2E7E4F40
57500	57213	53.969389999999997	53.970064000000001	63.557091	63.556649999999998	Гоголя	0103000020E61000000100000005000000E388B5F814FC4A40C1A8A44E40C74F40E388B5F814FC4A40AEF204C24EC74F407383A10E2BFC4A40AEF204C24EC74F407383A10E2BFC4A40C1A8A44E40C74F40E388B5F814FC4A40C1A8A44E40C74F40
57931	57327	49.764294999999997	49.789223	59.38776	59.368706000000003	Первомайская	0103000020E6100000010000000500000087BF266BD4E1484064EB19C231AF4D4087BF266BD4E148403659A31EA2B14D4021205F4205E548403659A31EA2B14D4021205F4205E5484064EB19C231AF4D4087BF266BD4E1484064EB19C231AF4D40
57881	3520	49.546075999999999	49.580714999999998	60.480629999999998	60.466971999999998	Центральная	0103000020E61000000100000005000000B49080D1E5C54840E8120EBDC53B4E40B49080D1E5C54840FDBCA948853D4E40F8A57EDE54CA4840FDBCA948853D4E40F8A57EDE54CA4840E8120EBDC53B4E40B49080D1E5C54840E8120EBDC53B4E40
57911	4062	49.596158000000003	49.616988999999997	60.231600999999998	60.200282000000001	Центральная	0103000020E61000000100000005000000D89FC4E74ECC48401EFD2FD7A2194E40D89FC4E74ECC4840465C001AA51D4E40F17EDC7EF9CE4840465C001AA51D4E40F17EDC7EF9CE48401EFD2FD7A2194E40D89FC4E74ECC48401EFD2FD7A2194E40
57908	4804	49.454044000000003	49.519441	59.554068000000001	59.504890000000003	Центральная	0103000020E61000000100000005000000F778211D1EBA4840EA094B3CA0C04D40F778211D1EBA48404CE141B3EBC64D40CC99ED0A7DC248404CE141B3EBC64D40CC99ED0A7DC24840EA094B3CA0C04D40F778211D1EBA4840EA094B3CA0C04D40
57709	4804	49.454044000000003	49.519441	59.554068000000001	59.504890000000003	Октябрьская	0103000020E61000000100000005000000F778211D1EBA4840EA094B3CA0C04D40F778211D1EBA48404CE141B3EBC64D40CC99ED0A7DC248404CE141B3EBC64D40CC99ED0A7DC24840EA094B3CA0C04D40F778211D1EBA4840EA094B3CA0C04D40
57846	57287	49.514060000000001	49.532431000000003	60.162393000000002	60.153075000000001	Центральная	0103000020E610000001000000050000004417D4B7CCC14840E86A2BF697134E404417D4B7CCC14840B70C384BC9144E403430F2B226C44840B70C384BC9144E403430F2B226C44840E86A2BF697134E404417D4B7CCC14840E86A2BF697134E40
57900	57309	49.624149000000003	49.645439000000003	60.230144000000003	60.222901999999998	Центральная	0103000020E61000000100000005000000626A4B1DE4CF4840431B800D881C4E40626A4B1DE4CF484071AFCC5B751D4E400F48C2BE9DD2484071AFCC5B751D4E400F48C2BE9DD24840431B800D881C4E40626A4B1DE4CF4840431B800D881C4E40
57714	3408	49.0242	49.062970999999997	60.657682999999999	60.632205999999996	Лобанова	0103000020E61000000100000005000000174850FC18834840E02A4F20EC504E40174850FC188348404D11E0F42E544E4057CC086F0F8848404D11E0F42E544E4057CC086F0F884840E02A4F20EC504E40174850FC18834840E02A4F20EC504E40
57796	5178	49.703183000000003	49.726619999999997	59.393433000000002	59.373845000000003	Центральная	0103000020E61000000100000005000000350D8AE601DA4840F6622827DAAF4D40350D8AE601DA4840661536035CB24D404C4F58E201DD4840661536035CB24D404C4F58E201DD4840F6622827DAAF4D40350D8AE601DA4840F6622827DAAF4D40
57795	5247	49.661726000000002	49.690382	59.288395000000001	59.273124000000003	Центральная	0103000020E61000000100000005000000DA740470B3D4484059E02BBAF5A24D40DA740470B3D448403BAA9A20EAA44D40A0DFF76F5ED848403BAA9A20EAA44D40A0DFF76F5ED8484059E02BBAF5A24D40DA740470B3D4484059E02BBAF5A24D40
57847	57289	49.505310999999999	49.535359999999997	59.536841000000003	59.517277	Центральная	0103000020E610000001000000050000008FA7E507AEC048408BFCFA2136C24D408FA7E507AEC048407313B534B7C44D4014CB2DAD86C448407313B534B7C44D4014CB2DAD86C448408BFCFA2136C24D408FA7E507AEC048408BFCFA2136C24D40
57839	57282	49.382905999999998	49.398079000000003	60.188394000000002	60.179540000000003	Центральная	0103000020E6100000010000000500000099B8551003B148407429AE2AFB164E4099B8551003B148409E616A4B1D184E40B91CAF40F4B248409E616A4B1D184E40B91CAF40F4B248407429AE2AFB164E4099B8551003B148407429AE2AFB164E40
57907	57313	48.838087000000002	48.853079999999999	59.932842999999998	59.924438000000002	Лесная	0103000020E61000000100000005000000F419506F466B4840FF9600FC53F64D40F419506F466B4840B9A6406667F74D40936FB6B9316D4840B9A6406667F74D40936FB6B9316D4840FF9600FC53F64D40F419506F466B4840FF9600FC53F64D40
57526	2257	49.572719999999997	49.644137000000001	60.353696999999997	60.321697999999998	Центральная	0103000020E61000000100000005000000EFE192E34EC9484024986A662D294E40EFE192E34EC94840BED87BF1452D4E406092CA1473D24840BED87BF1452D4E406092CA1473D2484024986A662D294E40EFE192E34EC9484024986A662D294E40
57629	2257	49.572719999999997	49.644137000000001	60.353696999999997	60.321697999999998	Мира	0103000020E61000000100000005000000EFE192E34EC9484024986A662D294E40EFE192E34EC94840BED87BF1452D4E406092CA1473D24840BED87BF1452D4E406092CA1473D2484024986A662D294E40EFE192E34EC9484024986A662D294E40
57717	4237	49.480328999999998	49.525396999999998	60.156514000000001	60.138271000000003	Советская	0103000020E610000001000000050000000229B16B7BBD48401C7E37DDB2114E400229B16B7BBD4840DEAE97A608144E4050357A3540C34840DEAE97A608144E4050357A3540C348401C7E37DDB2114E400229B16B7BBD48401C7E37DDB2114E40
57910	4237	49.480328999999998	49.525396999999998	60.156514000000001	60.138271000000003	Калинина	0103000020E610000001000000050000000229B16B7BBD48401C7E37DDB2114E400229B16B7BBD4840DEAE97A608144E4050357A3540C34840DEAE97A608144E4050357A3540C348401C7E37DDB2114E400229B16B7BBD48401C7E37DDB2114E40
57882	4960	49.503900999999999	49.542717000000003	59.489204999999998	59.471139999999998	Дуговая	0103000020E61000000100000005000000FAB5F5D37FC0484031EBC5504EBC4D40FAB5F5D37FC048401405FA449EBE4D40DBFD2AC077C548401405FA449EBE4D40DBFD2AC077C5484031EBC5504EBC4D40FAB5F5D37FC0484031EBC5504EBC4D40
57906	3210	48.802225999999997	48.821513000000003	60.556134999999998	60.546089000000002	Центральная	0103000020E610000001000000050000001D007157AF66484049DA8D3EE6454E401D007157AF6648409A94826E2F474E40931E8656276948409A94826E2F474E40931E86562769484049DA8D3EE6454E401D007157AF66484049DA8D3EE6454E40
57934	57330	49.344988999999998	49.387596000000002	60.154606999999999	60.135502000000002	Школьная	0103000020E61000000100000005000000683D7C9928AC48407445292158114E40683D7C9928AC4840C85D8429CA134E40BC07E8BE9CB14840C85D8429CA134E40BC07E8BE9CB148407445292158114E40683D7C9928AC48407445292158114E40
57631	4683	49.398474	49.447971000000003	59.644877000000001	59.579000999999998	Советская	0103000020E6100000010000000500000035272F3201B34840F7AC6BB41CCA4D4035272F3201B34840A7785C548BD24D4039471D1D57B94840A7785C548BD24D4039471D1D57B94840F7AC6BB41CCA4D4035272F3201B34840F7AC6BB41CCA4D40
57905	57312	49.577534999999997	49.609138000000002	60.497405999999998	60.487504999999999	Гагарина	0103000020E61000000100000005000000CEA5B8AAECC9484078D15790663E4E40CEA5B8AAECC94840C66AF3FFAA3F4E401C60E63BF8CD4840C66AF3FFAA3F4E401C60E63BF8CD484078D15790663E4E40CEA5B8AAECC9484078D15790663E4E40
57903	57311	48.563194000000003	48.584592000000001	60.418337999999999	60.409514999999999	Лесная	0103000020E61000000100000005000000D7A6B1BD16484840581CCEFC6A344E40D7A6B1BD1648484047567E198C354E406AC020E9D34A484047567E198C354E406AC020E9D34A4840581CCEFC6A344E40D7A6B1BD16484840581CCEFC6A344E40
57790	3438	49.383966000000001	49.398465000000002	60.647663999999999	60.637059000000001	Центральная	0103000020E61000000100000005000000526342CC25B14840AD4F39268B514E40526342CC25B14840F56569A7E6524E40E2CCAFE600B34840F56569A7E6524E40E2CCAFE600B34840AD4F39268B514E40526342CC25B14840AD4F39268B514E40
57850	57292	49.707619999999999	49.721525999999997	60.215924999999999	60.209054999999999	Мира	0103000020E610000001000000050000006DFFCA4A93DA48405B087250C21A4E406DFFCA4A93DA4840C4B12E6EA31B4E405A9BC6F65ADC4840C4B12E6EA31B4E405A9BC6F65ADC48405B087250C21A4E406DFFCA4A93DA48405B087250C21A4E40
57751	5065	49.584586999999999	49.610019000000001	59.437365	59.420307000000001	Школьная	0103000020E6100000010000000500000058552FBFD3CA4840D3A3A99ECCB54D4058552FBFD3CA484020B58993FBB74D402578431A15CE484020B58993FBB74D402578431A15CE4840D3A3A99ECCB54D4058552FBFD3CA4840D3A3A99ECCB54D40
57840	57283	49.650038000000002	49.677545000000002	60.463295000000002	60.44256	Центральная	0103000020E610000001000000050000002194F77134D3484046425BCEA5384E402194F77134D348403EB324404D3B4E40BF4868CBB9D648403EB324404D3B4E40BF4868CBB9D6484046425BCEA5384E402194F77134D3484046425BCEA5384E40
57940	57283	49.650038000000002	49.677545000000002	60.463295000000002	60.44256	Спортивная	0103000020E610000001000000050000002194F77134D3484046425BCEA5384E402194F77134D348403EB324404D3B4E40BF4868CBB9D648403EB324404D3B4E40BF4868CBB9D6484046425BCEA5384E402194F77134D3484046425BCEA5384E40
57878	4577	48.687997000000003	48.706905999999996	59.922404	59.896056999999999	Центральная	0103000020E61000000100000005000000815F2349105848400A2DEBFEB1F24D40815F2349105848408CD9925511F64D404FAC53E57B5A48408CD9925511F64D404FAC53E57B5A48400A2DEBFEB1F24D40815F2349105848400A2DEBFEB1F24D40
57792	57266	49.088501999999998	49.097628	60.058385000000001	60.050668000000002	Молодежная	0103000020E61000000100000005000000B7D09508548B4840147AFD497C064E40B7D09508548B4840DAC9E02879074E40429605137F8C4840DAC9E02879074E40429605137F8C4840147AFD497C064E40B7D09508548B4840147AFD497C064E40
57930	57326	49.217193999999999	49.235143000000001	60.137034999999997	60.125715	Школьная	0103000020E6100000010000000500000097715303CD9B4840EECEDA6D17104E4097715303CD9B484024B4E55C8A114E401171732A199E484024B4E55C8A114E401171732A199E4840EECEDA6D17104E4097715303CD9B4840EECEDA6D17104E40
57852	3918	49.630788000000003	49.647630999999997	60.319318000000003	60.301679	51	0103000020E61000000100000005000000C95A43A9BDD04840EB71DF6A9D264E40C95A43A9BDD0484017838769DF284E4019709692E5D2484017838769DF284E4019709692E5D24840EB71DF6A9D264E40C95A43A9BDD04840EB71DF6A9D264E40
57886	5036	49.420904999999998	49.456595	59.509360000000001	59.489260000000002	Школьная	0103000020E6100000010000000500000087DC0C37E0B54840D89E5912A0BE4D4087DC0C37E0B54840FEF15EB532C14D40314278B471BA4840FEF15EB532C14D40314278B471BA4840D89E5912A0BE4D4087DC0C37E0B54840D89E5912A0BE4D40
57943	57337	54.521782000000002	60.221367999999998	65.829621000000003	64.203012999999999	Лесная	0103000020E610000001000000050000001CD2A8C0C9424B406CEA3C2AFE0C50401CD2A8C0C9424B40CAC4AD8218755040C23060C9551C4E40CAC4AD8218755040C23060C9551C4E406CEA3C2AFE0C50401CD2A8C0C9424B406CEA3C2AFE0C5040
57719	57239	56.398927999999998	56.441527000000001	64.91583	64.885889000000006	Центральная	0103000020E61000000100000005000000B6BA9C1210334C40B7B8C667B2385040B6BA9C1210334C4086AC6EF59C3A504087A6ECF483384C4086AC6EF59C3A504087A6ECF483384C40B7B8C667B2385040B6BA9C1210334C40B7B8C667B2385040
57817	57273	56.983687000000003	57.014643	65.149255999999994	65.138542000000001	Речная	0103000020E610000001000000050000000C40A374E97D4C40D6C743DFDD4850400C40A374E97D4C40D5AE09698D495040C30E63D2DF814C40D5AE09698D495040C30E63D2DF814C40D6C743DFDD4850400C40A374E97D4C40D6C743DFDD485040
57849	57291	55.669308000000001	55.695449000000004	64.621091000000007	64.606966	Центральная	0103000020E61000000100000005000000C07971E2ABD54B402CF2EB87D8265040C07971E2ABD54B40C23577F4BF27504099840B7904D94B40C23577F4BF27504099840B7904D94B402CF2EB87D8265040C07971E2ABD54B402CF2EB87D8265040
57919	57320	58.018456	58.138210999999998	65.376740999999996	65.344811000000007	Восточная	0103000020E610000001000000050000001E3526C45C024D4045132862115650401E3526C45C024D40FD8348861C5850404679E6E5B0114D40FD8348861C5850404679E6E5B0114D4045132862115650401E3526C45C024D404513286211565040
57845	57286	57.004950000000001	57.022996999999997	65.351254999999995	65.339599000000007	Центральная	0103000020E61000000100000005000000BF0E9C33A2804C4047B071FDBB555040BF0E9C33A2804C409D6340F67A565040FB73D190F1824C409D6340F67A565040FB73D190F1824C4047B071FDBB555040BF0E9C33A2804C4047B071FDBB555040
57822	57277	55.462955999999998	55.493912000000002	64.561623999999995	64.548455000000004	Лесная	0103000020E6100000010000000500000055BE672442BB4B40F91400E31923504055BE672442BB4B408429CAA5F12350400D8D278238BF4B408429CAA5F12350400D8D278238BF4B40F91400E31923504055BE672442BB4B40F91400E319235040
57698	57235	57.073267000000001	57.106755999999997	65.181348999999997	65.167702000000006	Парковая	0103000020E61000000100000005000000227024D060894C40535E2BA1BB4A5040227024D060894C40630AD6389B4B50406D533C2EAA8D4C40630AD6389B4B50406D533C2EAA8D4C40535E2BA1BB4A5040227024D060894C40535E2BA1BB4A5040
57819	57275	56.293745000000001	56.344230000000003	64.573239000000001	64.562706000000006	Набережная	0103000020E61000000100000005000000882EA86F99254C40D5D0066003245040882EA86F99254C40AC72A1F2AF245040AB2688BA0F2C4C40AC72A1F2AF245040AB2688BA0F2C4C40D5D0066003245040882EA86F99254C40D5D0066003245040
57909	57314	57.860137000000002	57.879541000000003	64.739007999999998	64.723059000000006	Школьная	0103000020E610000001000000050000002F8A1EF818EE4C4006854199462E50402F8A1EF818EE4C40DFDE35E84B2F5040DE3EABCC94F04C40DFDE35E84B2F5040DE3EABCC94F04C4006854199462E50402F8A1EF818EE4C4006854199462E5040
57548	13361	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Советская	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57481	13361	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Печорский проспект	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
79429	13361	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Набережная	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57594	13361	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Ленинградская	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57547	13361	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Комсомольская	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57729	13361	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Деповская	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57730	57244	57.150567000000002	57.176402000000003	65.096082999999993	65.086393000000001	Центральная	0103000020E61000000100000005000000AD6D8AC745934C409D66817687455040AD6D8AC745934C40E6AC4F392646504079793A5794964C40E6AC4F392646504079793A5794964C409D66817687455040AD6D8AC745934C409D66817687455040
57820	57276	57.024388999999999	57.053980000000003	65.137597	65.123424	Школьная	0103000020E61000000100000005000000EAB0C22D1F834C40A8E2C62DE6475040EAB0C22D1F834C40C6C1A563CE485040AD510FD1E8864C40C6C1A563CE485040AD510FD1E8864C40A8E2C62DE6475040EAB0C22D1F834C40A8E2C62DE6475040
57917	57319	57.570160999999999	57.586222999999997	64.944626	64.940557999999996	Молодежная	0103000020E61000000100000005000000323A2009FBC84C406F7F2E1A323C5040323A2009FBC84C40E23C9CC0743C5040DD94F25A09CB4C40E23C9CC0743C5040DD94F25A09CB4C406F7F2E1A323C5040323A2009FBC84C406F7F2E1A323C5040
57848	57290	57.096057000000002	57.124920000000003	65.169129999999996	65.143106000000003	Русанова	0103000020E61000000100000005000000A4C684984B8C4C40217711A628495040A4C684984B8C4C4070B1A206D34A5040E44EE960FD8F4C4070B1A206D34A5040E44EE960FD8F4C40217711A628495040A4C684984B8C4C40217711A628495040
57779	57260	57.278737999999997	57.301851999999997	65.091564000000005	65.068826999999999	Свободы	0103000020E610000001000000050000008313D1AFADA34C403C855CA9674450408313D1AFADA34C406C5F402FDC455040B81D1A16A3A64C406C5F402FDC455040B81D1A16A3A64C403C855CA9674450408313D1AFADA34C403C855CA967445040
57835	57280	58.955148000000001	58.972503000000003	65.616722999999993	65.607393999999999	Лесная	0103000020E610000001000000050000007F6B274A427A4D405872158BDF6650407F6B274A427A4D4039ECBE6378675040862172FA7A7C4D4039ECBE6378675040862172FA7A7C4D405872158BDF6650407F6B274A427A4D405872158BDF665040
57912	57315	57.723207000000002	57.739331999999997	64.848977000000005	64.840676999999999	Почтовая	0103000020E61000000100000005000000809E060C92DC4C40F65FE7A6CD355040809E060C92DC4C409983A0A3553650407171546EA2DE4C409983A0A3553650407171546EA2DE4C40F65FE7A6CD355040809E060C92DC4C40F65FE7A6CD355040
57595	57227	57.017338000000002	57.101590999999999	65.123417000000003	65.095602	Мира	0103000020E61000000100000005000000317DAF2138824C40A9DBD9571E465040317DAF2138824C404FB16A10E6475040B24813EF008D4C404FB16A10E6475040B24813EF008D4C40A9DBD9571E465040317DAF2138824C40A9DBD9571E465040
57843	57285	57.602392000000002	57.636834	64.890004000000005	64.882227999999998	Речная	0103000020E610000001000000050000009FAF592E1BCD4C4064E76D6C763850409FAF592E1BCD4C40CA5356D3F53850408D7DC9C683D14C40CA5356D3F53850408D7DC9C683D14C4064E76D6C763850409FAF592E1BCD4C4064E76D6C76385040
57486	57209	55.866262999999996	55.936807999999999	64.700744	64.680926999999997	Театральная	0103000020E610000001000000050000000F5EBBB4E1EE4B40A8FDD64E942B50400F5EBBB4E1EE4B4091B75CFDD82C5040CA501553E9F74B4091B75CFDD82C5040CA501553E9F74B40A8FDD64E942B50400F5EBBB4E1EE4B40A8FDD64E942B5040
57485	57208	56.961409000000003	57.008139	65.120018999999999	65.093288000000001	Центральная	0103000020E61000000100000005000000408A3A730F7B4C40FE463B6EF8455040408A3A730F7B4C4083F92B64AE4750403C69E1B20A814C4083F92B64AE4750403C69E1B20A814C40FE463B6EF8455040408A3A730F7B4C40FE463B6EF8455040
57797	57267	55.285009000000002	55.319701000000002	64.486590000000007	64.473371999999998	Рабочая	0103000020E610000001000000050000006808C72C7BA44B40E5B512BA4B1E50406808C72C7BA44B40E223624A241F5040CFBF5DF6EBA84B40E223624A241F5040CFBF5DF6EBA84B40E5B512BA4B1E50406808C72C7BA44B40E5B512BA4B1E5040
57892	57308	57.853903000000003	57.872031	64.715354000000005	64.692625000000007	Центральная	0103000020E61000000100000005000000687A89B14CED4C4017D9CEF7532C5040687A89B14CED4C4005C4245CC82D5040910C39B69EEF4C4005C4245CC82D5040910C39B69EEF4C4017D9CEF7532C5040687A89B14CED4C4017D9CEF7532C5040
57786	57262	57.367330000000003	57.389733999999997	65.023723000000004	65.014955999999998	Совхозная	0103000020E610000001000000050000007B6B60AB04AF4C4041B8020AF54050407B6B60AB04AF4C406F4A79AD84415040D311C0CDE2B14C406F4A79AD84415040D311C0CDE2B14C4041B8020AF54050407B6B60AB04AF4C4041B8020AF5405040
57794	57264	56.508918000000001	56.595650999999997	65.030113	65.007679999999993	Таежная	0103000020E61000000100000005000000412C9B3924414C40543541D47D405040412C9B3924414C40CE8B135FED415040336ABE4A3E4C4C40CE8B135FED415040336ABE4A3E4C4C40543541D47D405040412C9B3924414C40543541D47D405040
57793	57263	57.113835000000002	57.134613000000002	65.279617999999999	65.273114000000007	Лесная	0103000020E61000000100000005000000F1113125928E4C401B8524B37A515040F1113125928E4C40DE57E542E5515040E84EB0FF3A914C40DE57E542E5515040E84EB0FF3A914C401B8524B37A515040F1113125928E4C401B8524B37A515040
57818	57274	57.834921000000001	57.853067000000003	64.834719000000007	64.829042999999999	Центральная	0103000020E610000001000000050000002FDFFAB0DEEA4C4093FE5E0A0F3550402FDFFAB0DEEA4C4064963D096C355040FF25A94C31ED4C4064963D096C355040FF25A94C31ED4C4093FE5E0A0F3550402FDFFAB0DEEA4C4093FE5E0A0F355040
57506	57216	57.116557	57.412111000000003	65.184991999999994	65.103803999999997	Спортивная	0103000020E61000000100000005000000588FFB56EB8E4C406A4C88B9A4465040588FFB56EB8E4C406281AFE8D64B504033A9A10DC0B44C406281AFE8D64B504033A9A10DC0B44C406A4C88B9A4465040588FFB56EB8E4C406A4C88B9A4465040
57705	30702	51.682755	51.716622000000001	61.785961	61.775559999999999	Школьная	0103000020E610000001000000050000001A170E8464D74940FA0AD28C45E34E401A170E8464D749403A77BB5E9AE44E400CCC0A45BADB49403A77BB5E9AE44E400CCC0A45BADB4940FA0AD28C45E34E401A170E8464D74940FA0AD28C45E34E40
57947	31545	52.484313	52.507795000000002	61.843013999999997	61.830902999999999	Центральная	0103000020E610000001000000050000008A03E8F7FD3D4A40FB928D075BEA4E408A03E8F7FD3D4A40FA08FCE1E7EB4E404209336DFF404A40FA08FCE1E7EB4E404209336DFF404A40FB928D075BEA4E408A03E8F7FD3D4A40FB928D075BEA4E40
57627	6539	52.272714999999998	52.368242000000002	61.957095000000002	61.922795000000001	Дружбы	0103000020E6100000010000000500000077103B53E8224A40C7F484251EF64E4077103B53E8224A402315C61682FA4E40BF81C98D222F4A402315C61682FA4E40BF81C98D222F4A40C7F484251EF64E4077103B53E8224A40C7F484251EF64E40
57712	31203	51.803085000000003	51.833123999999998	61.844712000000001	61.833201000000003	Центральная	0103000020E610000001000000050000003F74417DCBE649404CFF9254A6EA4E403F74417DCBE64940F644D7851FEC4E40A0C1A6CEA3EA4940F644D7851FEC4E40A0C1A6CEA3EA49404CFF9254A6EA4E403F74417DCBE649404CFF9254A6EA4E40
57856	30622	51.535736999999997	51.556452	61.570743999999998	61.561410000000002	Светлая	0103000020E61000000100000005000000EA20AF0793C44940DDD26A48DCC74E40EA20AF0793C44940B131AF230EC94E409BE5B2D139C74940B131AF230EC94E409BE5B2D139C74940DDD26A48DCC74E40EA20AF0793C44940DDD26A48DCC74E40
57755	31452	52.678673000000003	52.714011999999997	61.929332000000002	61.908881999999998	Восточная	0103000020E61000000100000005000000D0D6C1C1DE564A4027F6D03E56F44E40D0D6C1C1DE564A402A90D959F4F64E40CC79C6BE645B4A402A90D959F4F64E40CC79C6BE645B4A4027F6D03E56F44E40D0D6C1C1DE564A4027F6D03E56F44E40
57540	31628	52.837772999999999	52.905129000000002	61.917425999999999	61.901290000000003	Центральная	0103000020E61000000100000005000000643C4A253C6B4A401E1B81785DF34E40643C4A253C6B4A40034015376EF54E40A2D45E44DB734A40034015376EF54E40A2D45E44DB734A401E1B81785DF34E40643C4A253C6B4A401E1B81785DF34E40
57853	31149	51.684049000000002	51.74597	61.829633000000001	61.821333000000003	Братьев Покровских	0103000020E6100000010000000500000046EEE9EA8ED749401310937021E94E4046EEE9EA8ED749405857056A31EA4E4008E6E8F17BDF49405857056A31EA4E4008E6E8F17BDF49401310937021E94E4046EEE9EA8ED749401310937021E94E40
57833	31293	52.104514000000002	52.146878999999998	61.917709000000002	61.902988999999998	Центральная	0103000020E61000000100000005000000B1FCF9B6600D4A40E9D2BF2495F34E40B1FCF9B6600D4A40581F0F7D77F54E400EBC5AEECC124A40581F0F7D77F54E400EBC5AEECC124A40E9D2BF2495F34E40B1FCF9B6600D4A40E9D2BF2495F34E40
57745	30477	52.087339	52.120027999999998	61.191733999999997	61.173336999999997	Школьная	0103000020E610000001000000050000002A55A2EC2D0B4A40E71725E82F964E402A55A2EC2D0B4A4000C45DBD8A984E40594DD7135D0F4A4000C45DBD8A984E40594DD7135D0F4A40E71725E82F964E402A55A2EC2D0B4A40E71725E82F964E40
57634	30543	51.889898000000002	51.911484000000002	61.361665000000002	61.353400999999998	Пушкина	0103000020E610000001000000050000004E637B2DE8F14940D5AF743E3CAD4E404E637B2DE8F14940CE8DE9094BAE4E40E469F981ABF44940CE8DE9094BAE4E40E469F981ABF44940D5AF743E3CAD4E404E637B2DE8F14940D5AF743E3CAD4E40
57780	31053	51.451421000000003	51.484361999999997	61.855682999999999	61.845497000000002	Центральная	0103000020E6100000010000000500000023DDCF29C8B94940DDEEE53E39EC4E4023DDCF29C8B94940205F420587ED4E406BB6F292FFBD4940205F420587ED4E406BB6F292FFBD4940DDEEE53E39EC4E4023DDCF29C8B94940DDEEE53E39EC4E40
57746	30754	51.542949999999998	51.603093000000001	61.820874000000003	61.794015999999999	Советская	0103000020E610000001000000050000007DAEB6627FC549401840F850A2E54E407DAEB6627FC549408011346612E94E4028B9C32632CD49408011346612E94E4028B9C32632CD49401840F850A2E54E407DAEB6627FC549401840F850A2E54E40
57533	30754	51.542949999999998	51.603093000000001	61.820874000000003	61.794015999999999	Набережная	0103000020E610000001000000050000007DAEB6627FC549401840F850A2E54E407DAEB6627FC549408011346612E94E4028B9C32632CD49408011346612E94E4028B9C32632CD49401840F850A2E54E407DAEB6627FC549401840F850A2E54E40
57830	30754	51.542949999999998	51.603093000000001	61.820874000000003	61.794015999999999	Дорожная	0103000020E610000001000000050000007DAEB6627FC549401840F850A2E54E407DAEB6627FC549408011346612E94E4028B9C32632CD49408011346612E94E4028B9C32632CD49401840F850A2E54E407DAEB6627FC549401840F850A2E54E40
57741	31486	52.644661999999997	52.696261999999997	61.873268000000003	61.858122999999999	Центральная	0103000020E61000000100000005000000AA7CCF4884524A40037976F9D6ED4E40AA7CCF4884524A405952EE3EC7EF4E4049B9FB1C1F594A405952EE3EC7EF4E4049B9FB1C1F594A40037976F9D6ED4E40AA7CCF4884524A40037976F9D6ED4E40
57858	30933	51.339993999999997	51.371102999999998	61.780866000000003	61.775010999999999	Центральная	0103000020E61000000100000005000000096B63EC84AB49402785798F33E34E40096B63EC84AB49407847C66AF3E34E404739984D80AF49407847C66AF3E34E404739984D80AF49402785798F33E34E40096B63EC84AB49402785798F33E34E40
57710	31019	51.203783000000001	51.262532	61.754513000000003	61.740169999999999	Школьная	0103000020E610000001000000050000008A3DB48F159A49407BBDFBE3BDDE4E408A3DB48F159A494014B4C9E193E04E40A51309A69AA1494014B4C9E193E04E40A51309A69AA149407BBDFBE3BDDE4E408A3DB48F159A49407BBDFBE3BDDE4E40
57894	30600	51.569693000000001	51.595267999999997	61.474051000000003	61.467300000000002	Советская	0103000020E610000001000000050000004CE141B3EBC84940DDB5847CD0BB4E404CE141B3EBC849406CD102B4ADBC4E407B2DE8BD31CC49406CD102B4ADBC4E407B2DE8BD31CC4940DDB5847CD0BB4E404CE141B3EBC84940DDB5847CD0BB4E40
57763	31597	52.483567000000001	52.528672	62.135136000000003	62.123600000000003	Центральная	0103000020E6100000010000000500000061360186E53D4A408FE4F21FD20F4F4061360186E53D4A409241EE224C114F40CC272B86AB434A409241EE224C114F40CC272B86AB434A408FE4F21FD20F4F4061360186E53D4A408FE4F21FD20F4F40
57889	5602	52.477082000000003	52.499450000000003	62.264105999999998	62.251728	Школьная	0103000020E6100000010000000500000051C1E105113D4A4066BE839F38204F4051C1E105113D4A40B456B439CE214F405DFE43FAED3F4A40B456B439CE214F405DFE43FAED3F4A4066BE839F38204F4051C1E105113D4A4066BE839F38204F40
57707	31099	51.643202000000002	51.718058999999997	61.864068000000003	61.841303000000003	Школьная	0103000020E61000000100000005000000645C717154D249406B8313D1AFEB4E40645C717154D2494094C2BCC799EE4E409ACC785BE9DB494094C2BCC799EE4E409ACC785BE9DB49406B8313D1AFEB4E40645C717154D249406B8313D1AFEB4E40
57901	2393	51.012512999999998	51.089543999999997	60.525880999999998	60.501539999999999	Ягдорская	0103000020E610000001000000050000002EE3A6069A81494063D1747632404E402EE3A6069A8149403C4B901150434E40C9C6832D768B49403C4B901150434E40C9C6832D768B494063D1747632404E402EE3A6069A81494063D1747632404E40
57867	2495	50.973148999999999	50.997574	60.566625000000002	60.549393999999999	Центральная	0103000020E610000001000000050000004B917C25907C49402F4FE78A52464E404B917C25907C49404A0C022B87484E4082AB3C81B07F49404A0C022B87484E4082AB3C81B07F49402F4FE78A52464E404B917C25907C49402F4FE78A52464E40
57756	2154	50.341624000000003	50.365484000000002	60.677553000000003	60.667721	Советская	0103000020E61000000100000005000000ADC3D155BA2B49401CEDB8E177554E40ADC3D155BA2B49404227840EBA564E400B9B012EC82E49404227840EBA564E400B9B012EC82E49401CEDB8E177554E40ADC3D155BA2B49401CEDB8E177554E40
57897	2608	51.464635000000001	51.495277000000002	60.686293999999997	60.675217000000004	Центральная	0103000020E61000000100000005000000DAC9E02879BB4940045ABA826D564E40DAC9E02879BB494073B8567BD8574E4002BB9A3C65BF494073B8567BD8574E4002BB9A3C65BF4940045ABA826D564E40DAC9E02879BB4940045ABA826D564E40
57788	3058	52.045341999999998	52.081473000000003	60.340826999999997	60.330927000000003	Заречная	0103000020E610000001000000050000004F9143C4CD054A40842EE1D05B2A4E404F9143C4CD054A40014C1938A02B4E40E6400FB56D0A4A40014C1938A02B4E40E6400FB56D0A4A40842EE1D05B2A4E404F9143C4CD054A40842EE1D05B2A4E40
57844	2837	50.767569999999999	50.798363999999999	60.352294999999998	60.341538999999997	Смоленская	0103000020E6100000010000000500000003B2D7BB3F6249407EA7C98CB72B4E4003B2D7BB3F624940ACC5A700182D4E40E126A3CA30664940ACC5A700182D4E40E126A3CA306649407EA7C98CB72B4E4003B2D7BB3F6249407EA7C98CB72B4E40
57802	57270	49.940283999999998	52.371889000000003	60.984197000000002	59.748517999999997	Центральная	0103000020E61000000100000005000000DD79E2395BF84840D13B1570CFDF4D40DD79E2395BF8484021E9D32AFA7D4E40FF5E0A0F9A2F4A4021E9D32AFA7D4E40FF5E0A0F9A2F4A40D13B1570CFDF4D40DD79E2395BF84840D13B1570CFDF4D40
57632	2727	50.973356000000003	50.993944999999997	60.436309999999999	60.401662999999999	Центральная	0103000020E61000000100000005000000C5AEEDED967C4940B28174B169334E40C5AEEDED967C494079758E01D9374E40E882FA96397F494079758E01D9374E40E882FA96397F4940B28174B169334E40C5AEEDED967C4940B28174B169334E40
57644	2631	50.970337000000001	51.029186000000003	60.463596000000003	60.435053000000003	Советская	0103000020E61000000100000005000000A48CB800347C49406B8313D1AF374E40A48CB800347C494039471D1D573B4E4023C0E95DBC83494039471D1D573B4E4023C0E95DBC8349406B8313D1AF374E40A48CB800347C49406B8313D1AF374E40
57874	2631	50.970337000000001	51.029186000000003	60.463596000000003	60.435053000000003	Интернациональная	0103000020E61000000100000005000000A48CB800347C49406B8313D1AF374E40A48CB800347C494039471D1D573B4E4023C0E95DBC83494039471D1D573B4E4023C0E95DBC8349406B8313D1AF374E40A48CB800347C49406B8313D1AF374E40
57715	2954	51.526538000000002	51.558069000000003	60.341174000000002	60.324255000000001	Набережная	0103000020E61000000100000005000000F60CE19865C349404148163081294E40F60CE19865C349406D1FF296AB2B4E40AAF413CE6EC749406D1FF296AB2B4E40AAF413CE6EC749404148163081294E40F60CE19865C349404148163081294E40
57836	2060	50.430844999999998	50.448084000000001	60.678333000000002	60.671123000000001	Центральная	0103000020E610000001000000050000009352D0ED25374940F54BC45BE7554E409352D0ED253749401766A19DD3564E4031EE06D15A3949401766A19DD3564E4031EE06D15A394940F54BC45BE7554E409352D0ED25374940F54BC45BE7554E40
57837	2160	50.565798999999998	50.583207999999999	60.568083999999999	60.560938	Ленина	0103000020E61000000100000005000000048E041A6C484940B58AFED0CC474E40048E041A6C484940C0B0FCF9B6484E40FE614B8FA64A4940C0B0FCF9B6484E40FE614B8FA64A4940B58AFED0CC474E40048E041A6C484940B58AFED0CC474E40
57902	2272	50.873176000000001	50.900906999999997	60.587223000000002	60.571975000000002	Советская	0103000020E6100000010000000500000078D32D3BC46F494097900F7A36494E4078D32D3BC46F4940C13A8E1F2A4B4E4065DEAAEB50734940C13A8E1F2A4B4E4065DEAAEB5073494097900F7A36494E4078D32D3BC46F494097900F7A36494E40
57866	57296	51.132114999999999	51.149299999999997	60.653075000000001	60.644275999999998	Пушкина	0103000020E61000000100000005000000D027F224E990494081CCCEA277524E40D027F224E9904940E86A2BF697534E407AA52C431C934940E86A2BF697534E407AA52C431C93494081CCCEA277524E40D027F224E990494081CCCEA277524E40
57918	24147	50.680478000000001	50.719168000000003	62.702800000000003	62.690824999999997	Центральная	0103000020E61000000100000005000000E1D231E7195749402D211FF46C584F40E1D231E7195749407DD0B359F5594F40352A70B20D5C49407DD0B359F5594F40352A70B20D5C49402D211FF46C584F40E1D231E7195749402D211FF46C584F40
57597	57228	52.650348999999999	52.691113999999999	63.228706000000003	63.199821999999998	Дзержинского	0103000020E610000001000000050000003FFED2A23E534A40BA826DC493994F403FFED2A23E534A401233FB3C469D4F4064E76D6C76584A401233FB3C469D4F4064E76D6C76584A40BA826DC493994F403FFED2A23E534A40BA826DC493994F40
57826	32953	51.442985999999998	51.526763000000003	62.775370000000002	62.750799000000001	Клубный переулок	0103000020E61000000100000005000000FD4AE7C3B3B849404C6F7F2E1A604F40FD4AE7C3B3B849405726FC523F634F4016DF50F86CC349405726FC523F634F4016DF50F86CC349404C6F7F2E1A604F40FD4AE7C3B3B849404C6F7F2E1A604F40
57775	57255	51.264482000000001	51.303145000000001	62.707977	62.691267000000003	Лесная	0103000020E61000000100000005000000BA30D28BDAA14940EBE6E26F7B584F40BA30D28BDAA14940FCA886FD9E5A4F4014799274CDA64940FCA886FD9E5A4F4014799274CDA64940EBE6E26F7B584F40BA30D28BDAA14940EBE6E26F7B584F40
57517	24343	51.866326000000001	51.995908	62.873527000000003	62.807139999999997	Строителей	0103000020E6100000010000000500000056D636C5E3EE49408FA50F5D50674F4056D636C5E3EE4940259694BBCF6F4F4092E9D0E979FF4940259694BBCF6F4F4092E9D0E979FF49408FA50F5D50674F4056D636C5E3EE49408FA50F5D50674F40
57762	25003	50.683092000000002	50.722034000000001	62.338034	62.315167000000002	Советская	0103000020E610000001000000050000006214048F6F574940A4E36A6457284F406214048F6F574940D177B7B2442B4F40CF4C309C6B5C4940D177B7B2442B4F40CF4C309C6B5C4940A4E36A6457284F406214048F6F574940A4E36A6457284F40
57811	32964	51.093558999999999	51.119458000000002	62.687188999999996	62.675707000000003	Дзержинского	0103000020E610000001000000050000008C9FC6BDF98B4940D25625917D564F408C9FC6BDF98B4940E19524CFF5574F406F9F55664A8F4940E19524CFF5574F406F9F55664A8F4940D25625917D564F408C9FC6BDF98B4940D25625917D564F40
57936	57332	50.900807999999998	50.920813000000003	63.352034000000003	63.328870000000002	Пионерская	0103000020E61000000100000005000000D2FC31AD4D7349405951836918AA4F40D2FC31AD4D734940408A3A730FAD4F40A75D4C33DD754940408A3A730FAD4F40A75D4C33DD7549405951836918AA4F40D2FC31AD4D7349405951836918AA4F40
57920	57322	50.658577000000001	50.692523999999999	62.294479000000003	62.266832000000001	Центральная	0103000020E61000000100000005000000EB724A404C5449405DC30C8D27224F40EB724A404C544940ED2DE57CB1254F40F9D85DA0A4584940ED2DE57CB1254F40F9D85DA0A45849405DC30C8D27224F40EB724A404C5449405DC30C8D27224F40
57807	24179	50.843271000000001	50.863061000000002	62.605553	62.598011	Центральная	0103000020E610000001000000050000002655DB4DF06B4940FAD2DB9F8B4C4F402655DB4DF06B4940527FBDC2824D4F40FEB968C8786E4940527FBDC2824D4F40FEB968C8786E4940FAD2DB9F8B4C4F402655DB4DF06B4940FAD2DB9F8B4C4F40
57873	57303	52.160524000000002	52.198397	63.000884999999997	62.975313	Центральная	0103000020E610000001000000050000008F1CE90C8C144A408C2E6F0ED77C4F408F1CE90C8C144A404A07EBFF1C804F40F04FA91265194A404A07EBFF1C804F40F04FA91265194A408C2E6F0ED77C4F408F1CE90C8C144A408C2E6F0ED77C4F40
57570	24632	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	Чапаева	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
57519	24632	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	Московская	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
57619	24632	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	Коммунистическая	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
57620	24632	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	Дзержинского	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
57769	24632	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	Волгоградская	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
57521	24632	50.815458999999997	50.946055999999999	62.622580999999997	62.537886999999998	60 лет Октября	0103000020E610000001000000050000004B1DE4F560684940C6F8307BD9444F404B1DE4F560684940340EF5BBB04F4F40A017EE5C18794940340EF5BBB04F4F40A017EE5C18794940C6F8307BD9444F404B1DE4F560684940C6F8307BD9444F40
57939	57333	50.773445000000002	50.808101999999998	62.949959999999997	62.937565999999997	Школьная	0103000020E610000001000000050000009B20EA3E00634940B7EBA52902784F409B20EA3E006349400B410E4A98794F4085EAE6E26F6749400B410E4A98794F4085EAE6E26F674940B7EBA52902784F409B20EA3E00634940B7EBA52902784F40
57778	57259	60.718387999999997	60.748157999999997	66.478931000000003	66.466553000000005	Центральная	0103000020E610000001000000050000005FEB5223F45B4E4072361D01DC9D50405FEB5223F45B4E40998235CEA69E5040D11E2FA4C35F4E40998235CEA69E5040D11E2FA4C35F4E4072361D01DC9D50405FEB5223F45B4E4072361D01DC9D5040
57476	12419	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Мира	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57537	12419	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Куратова	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57589	12419	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Кирова	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57564	12419	60.049700000000001	60.253042000000001	66.063028000000003	65.994249999999994	Горького	0103000020E610000001000000050000003C4ED1915C064E401283C0CAA17F50403C4ED1915C064E40DEAE97A608845040D94125AE63204E40DEAE97A608845040D94125AE63204E401283C0CAA17F50403C4ED1915C064E401283C0CAA17F5040
57603	57229	60.295136999999997	60.354705000000003	66.005578999999997	65.975335000000001	Советской армии	0103000020E61000000100000005000000766B990CC7254E403AE97DE36B7E5040766B990CC7254E40D7A205685B805040255D33F9662D4E40D7A205685B805040255D33F9662D4E403AE97DE36B7E5040766B990CC7254E403AE97DE36B7E5040
57860	19292	53.399984000000003	53.431766000000003	65.268945000000002	65.258999000000003	Центральная	0103000020E610000001000000050000002E76FBAC32B34A4097AC8A70935050402E76FBAC32B34A400EDB1665365150402BC3B81B44B74A400EDB1665365150402BC3B81B44B74A4097AC8A70935050402E76FBAC32B34A4097AC8A7093505040
57809	19631	52.912351000000001	52.929912999999999	65.313614999999999	65.296936000000002	Центральная	0103000020E6100000010000000500000088BCE5EAC7744A405340DAFF0053504088BCE5EAC7744A403E22A644125450400890A16307774A403E22A644125450400890A16307774A405340DAFF0053504088BCE5EAC7744A405340DAFF00535040
57700	18807	53.345627	53.379286999999998	64.507234999999994	64.485044000000002	Речная	0103000020E61000000100000005000000ABCE6A813DAC4A40BF47FDF50A1F5040ABCE6A813DAC4A40BD18CA89762050402366F6798CB04A40BD18CA89762050402366F6798CB04A40BF47FDF50A1F5040ABCE6A813DAC4A40BF47FDF50A1F5040
57761	19094	53.837724000000001	53.878103000000003	65.073243000000005	65.058595999999994	60 лет Октября	0103000020E6100000010000000500000083893F8A3AEB4A404AEB6F09C043504083893F8A3AEB4A404D6A6803B04450407FC2D9AD65F04A404D6A6803B04450407FC2D9AD65F04A404AEB6F09C043504083893F8A3AEB4A404AEB6F09C0435040
57803	19728	53.584606000000001	53.605742999999997	65.435955000000007	65.424657999999994	Центральная	0103000020E61000000100000005000000CF85915ED4CA4A40067FBF982D5B5040CF85915ED4CA4A40C6E1CCAFE65B5040F56393FC88CD4A40C6E1CCAFE65B5040F56393FC88CD4A40067FBF982D5B5040CF85915ED4CA4A40067FBF982D5B5040
57703	19810	53.822254999999998	53.859768000000003	65.472009	65.458049000000003	Центральная	0103000020E610000001000000050000007AFCDEA63FE94A40CBBDC0AC505D50407AFCDEA63FE94A40BB9A3C65355E5040DC12B9E00CEE4A40BB9A3C65355E5040DC12B9E00CEE4A40CBBDC0AC505D50407AFCDEA63FE94A40CBBDC0AC505D5040
57697	18959	53.810612999999996	53.845503000000001	65.015119999999996	64.989144999999994	Центральная	0103000020E61000000100000005000000315BB22AC2E74A401F80D4264E3F5040315BB22AC2E74A40FE60E0B9F7405040BFD53A7139EC4A40FE60E0B9F7405040BFD53A7139EC4A401F80D4264E3F5040315BB22AC2E74A401F80D4264E3F5040
57806	19587	52.928251000000003	52.945822	65.289947999999995	65.282954000000004	Центральная	0103000020E610000001000000050000005ABDC3EDD0764A406F1118EB1B5250405ABDC3EDD0764A4099620E828E5250402DEBFEB110794A4099620E828E5250402DEBFEB110794A406F1118EB1B5250405ABDC3EDD0764A406F1118EB1B525040
57800	19103	53.801125999999996	53.816972999999997	64.931180999999995	64.923428999999999	Центральная	0103000020E61000000100000005000000D6FCF84B8BE64A4064CBF275193B5040D6FCF84B8BE64A40056A3178983B5040855B3E9292E84A40056A3178983B5040855B3E9292E84A4064CBF275193B5040D6FCF84B8BE64A4064CBF275193B5040
57829	19383	53.264383000000002	53.309496000000003	65.299867000000006	65.285515000000004	им.братьев Семяшкиных	0103000020E61000000100000005000000274F594DD7A14A401EE1B4E045525040274F594DD7A14A4094895B0531535040151F9F909DA74A4094895B0531535040151F9F909DA74A401EE1B4E045525040274F594DD7A14A401EE1B4E045525040
57805	18700	53.638055000000001	53.665300999999999	64.350313	64.341893999999996	Центральная	0103000020E610000001000000050000004F0647C9ABD14A40B62C5F97E11550404F0647C9ABD14A40469737876B165040807F4A9528D54A40469737876B165040807F4A9528D54A40B62C5F97E11550404F0647C9ABD14A40B62C5F97E1155040
57727	19931	54.473300000000002	54.541536000000001	65.678715999999994	65.651302999999999	Лесная	0103000020E6100000010000000500000031992A18953C4B405932C7F2AE69504031992A18953C4B4067D13B15706B5040A7CD380D51454B4067D13B15706B5040A7CD380D51454B405932C7F2AE69504031992A18953C4B405932C7F2AE695040
57825	19532	52.975386	53.016080000000002	65.282422999999994	65.270582000000005	Центральная	0103000020E61000000100000005000000F67CCD72D97C4A40B9382A3751515040F67CCD72D97C4A40D828EB3713525040520FD1E80E824A40D828EB3713525040520FD1E80E824A40B9382A3751515040F67CCD72D97C4A40B9382A3751515040
57801	18753	53.311176000000003	53.338664999999999	64.531008999999997	64.514852000000005	Лесная	0103000020E610000001000000050000006AA67B9DD4A74A40EF91CD55F32050406AA67B9DD4A74A406D382C0DFC21504061A6ED5F59AB4A406D382C0DFC21504061A6ED5F59AB4A40EF91CD55F32050406AA67B9DD4A74A40EF91CD55F3205040
57658	19188	53.888846999999998	53.939565999999999	65.030060000000006	64.994270999999998	Советская	0103000020E61000000100000005000000E8120EBDC5F14A401E17D522A23F5040E8120EBDC5F14A40BD3AC780EC4150407E37DDB243F84A40BD3AC780EC4150407E37DDB243F84A401E17D522A23F5040E8120EBDC5F14A401E17D522A23F5040
57861	19318	53.346201999999998	53.380913	65.280133000000006	65.271353000000005	Клубная	0103000020E61000000100000005000000A7E7DD5850AC4A40FA2AF9D85D515040A7E7DD5850AC4A40F261F6B2ED51504085CFD6C1C1B04A40F261F6B2ED51504085CFD6C1C1B04A40FA2AF9D85D515040A7E7DD5850AC4A40FA2AF9D85D515040
57915	18908	53.786195999999997	53.815750999999999	64.992384999999999	64.977309000000005	Центральная	0103000020E610000001000000050000007D1F0E12A2E44A4089450C3B8C3E50407D1F0E12A2E44A409F02603C833F5040F3565D876AE84A409F02603C833F5040F3565D876AE84A4089450C3B8C3E50407D1F0E12A2E44A4089450C3B8C3E5040
57764	18056	53.188817	53.222152999999999	65.308257999999995	65.293447	Школьная	0103000020E61000000100000005000000E4F6CB272B984A40FF06EDD5C7525040E4F6CB272B984A40BE2EC37FBA535040A9DA6E826F9C4A40BE2EC37FBA535040A9DA6E826F9C4A40FF06EDD5C7525040E4F6CB272B984A40FF06EDD5C7525040
57904	19831	54.249609999999997	54.294257000000002	65.482057999999995	65.467618000000002	Набережная	0103000020E6100000010000000500000095607138F31F4B4057410C74ED5D504095607138F31F4B409C31CC09DA5E50403ECF9F36AA254B409C31CC09DA5E50403ECF9F36AA254B4057410C74ED5D504095607138F31F4B4057410C74ED5D5040
57804	19487	53.093648999999999	53.117184999999999	65.290093999999996	65.278616999999997	Центральная	0103000020E61000000100000005000000CC26C0B0FC8B4A4004C765DCD4515040CC26C0B0FC8B4A4003B16CE690525040774A07EBFF8E4A4003B16CE690525040774A07EBFF8E4A4004C765DCD4515040CC26C0B0FC8B4A4004C765DCD4515040
57723	19034	53.838712000000001	53.865203000000001	65.049199999999999	65.041686999999996	Центральная	0103000020E61000000100000005000000A26131EA5AEB4A40C66AF3FFAA425040A26131EA5AEB4A40A5BDC1172643504057B3CEF8BEEE4A40A5BDC1172643504057B3CEF8BEEE4A40C66AF3FFAA425040A26131EA5AEB4A40C66AF3FFAA425040
57824	57279	56.447868999999997	56.468843999999997	63.482239999999997	63.468276000000003	Мира	0103000020E6100000010000000500000034F279C553394C4038C0CC77F0BB4F4034F279C553394C405969520ABABD4F4081768714033C4C405969520ABABD4F4081768714033C4C4038C0CC77F0BB4F4034F279C553394C4038C0CC77F0BB4F40
57808	57271	57.678021999999999	57.696131999999999	64.365337999999994	64.356947000000005	Школьная	0103000020E61000000100000005000000F8FBC56CC9D64C40F1D93A38D8165040F8FBC56CC9D64C401B7FA2B2611750407BD976DA1AD94C401B7FA2B2611750407BD976DA1AD94C40F1D93A38D8165040F8FBC56CC9D64C40F1D93A38D8165040
57721	57241	57.550730000000001	57.575541999999999	63.949399	63.930914000000001	Зарубина	0103000020E610000001000000050000008A7615527EC64C40BCB1A03028F74F408A7615527EC64C4074ED0BE885F94F40BABC395CABC94C4074ED0BE885F94F40BABC395CABC94C40BCB1A03028F74F408A7615527EC64C40BCB1A03028F74F40
57859	57293	56.934989000000002	56.952478999999997	63.862751000000003	63.853779000000003	Лесная	0103000020E61000000100000005000000548F34B8AD774C407C8159A148ED4F40548F34B8AD774C40B0CBF09F6EEE4F403A90F5D4EA794C40B0CBF09F6EEE4F403A90F5D4EA794C407C8159A148ED4F40548F34B8AD774C407C8159A148ED4F40
57914	57317	56.828763000000002	56.843828000000002	63.875222000000001	63.865532999999999	40 лет Победы	0103000020E610000001000000050000004391EEE7146A4C40EC4D0CC9C9EE4F404391EEE7146A4C40AF5E454607F04F407CB94F8E026C4C40AF5E454607F04F407CB94F8E026C4C40EC4D0CC9C9EE4F404391EEE7146A4C40EC4D0CC9C9EE4F40
57695	57232	56.684027	56.713482999999997	63.816871999999996	63.781509999999997	Советская	0103000020E610000001000000050000005E4A5D328E574C409CBF098508E44F405E4A5D328E574C405182FE428FE84F4040A03369535B4C405182FE428FE84F4040A03369535B4C409CBF098508E44F405E4A5D328E574C409CBF098508E44F40
57562	40316	57.289779000000003	57.334470000000003	63.882655	63.838251999999997	Комсомольская	0103000020E61000000100000005000000A708707A17A54C403EE76ED74BEB4F40A708707A17A54C405053CBD6FAF04F401FBFB7E9CFAA4C405053CBD6FAF04F401FBFB7E9CFAA4C403EE76ED74BEB4F40A708707A17A54C403EE76ED74BEB4F40
57696	57233	62.54486	62.585858999999999	66.680010999999993	66.66498	Лесная	0103000020E610000001000000050000000473F4F8BD454F409F1F46088FAA50400473F4F8BD454F40E57ADB4C85AB50409C887E6DFD4A4F40E57ADB4C85AB50409C887E6DFD4A4F409F1F46088FAA50400473F4F8BD454F409F1F46088FAA5040
57503	57214	64.066677999999996	64.137573000000003	67.609491000000006	67.590271000000001	Юго-Западная	0103000020E610000001000000050000003657CD7344045040BE310400C7E550403657CD7344045040350D8AE601E7504002F4FBFECD085040350D8AE601E7504002F4FBFECD085040BE310400C7E550403657CD7344045040BE310400C7E55040
57720	57214	64.066677999999996	64.137573000000003	67.609491000000006	67.590271000000001	Спортивная	0103000020E610000001000000050000003657CD7344045040BE310400C7E550403657CD7344045040350D8AE601E7504002F4FBFECD085040350D8AE601E7504002F4FBFECD085040BE310400C7E550403657CD7344045040BE310400C7E55040
57614	57214	64.066677999999996	64.137573000000003	67.609491000000006	67.590271000000001	Карла Маркса	0103000020E610000001000000050000003657CD7344045040BE310400C7E550403657CD7344045040350D8AE601E7504002F4FBFECD085040350D8AE601E7504002F4FBFECD085040BE310400C7E550403657CD7344045040BE310400C7E55040
57642	57231	63.757154999999997	63.827331000000001	67.573705000000004	67.537290999999996	Свердлова	0103000020E610000001000000050000005E807D74EAE04F40D95BCAF962E250405E807D74EAE04F404F232D95B7E45040C6FB71FBE5E94F404F232D95B7E45040C6FB71FBE5E94F40D95BCAF962E250405E807D74EAE04F40D95BCAF962E25040
57590	57226	63.710712000000001	63.755806999999997	67.499379000000005	67.487027999999995	Фрунзе	0103000020E61000000100000005000000F86F5E9CF8DA4F401F0F7D772BDF5040F86F5E9CF8DA4F40CA5356D3F5DF50403F8BA548BEE04F40CA5356D3F5DF50403F8BA548BEE04F401F0F7D772BDF5040F86F5E9CF8DA4F401F0F7D772BDF5040
57842	57284	64.201695000000001	64.230710999999999	67.049049999999994	67.037592000000004	Школьная	0103000020E6100000010000000500000012312592E80C5040D7A546E867C2504012312592E80C50409A779CA223C35040F5F411F8C30E50409A779CA223C35040F5F411F8C30E5040D7A546E867C2504012312592E80C5040D7A546E867C25040
57494	57210	63.77478	63.821860000000001	67.592201000000003	67.573451000000006	Юбилейный переулок	0103000020E6100000010000000500000025CCB4FD2BE34F40F2B6D26BB3E4504025CCB4FD2BE34F4025EA059FE6E55040FEF15EB532E94F4025EA059FE6E55040FEF15EB532E94F40F2B6D26BB3E4504025CCB4FD2BE34F40F2B6D26BB3E45040
57499	57210	63.77478	63.821860000000001	67.592201000000003	67.573451000000006	Энтузиастов	0103000020E6100000010000000500000025CCB4FD2BE34F40F2B6D26BB3E4504025CCB4FD2BE34F4025EA059FE6E55040FEF15EB532E94F4025EA059FE6E55040FEF15EB532E94F40F2B6D26BB3E4504025CCB4FD2BE34F40F2B6D26BB3E45040
57584	57210	63.77478	63.821860000000001	67.592201000000003	67.573451000000006	Ленинского Комсомола	0103000020E6100000010000000500000025CCB4FD2BE34F40F2B6D26BB3E4504025CCB4FD2BE34F4025EA059FE6E55040FEF15EB532E94F4025EA059FE6E55040FEF15EB532E94F40F2B6D26BB3E4504025CCB4FD2BE34F40F2B6D26BB3E45040
57608	57210	63.77478	63.821860000000001	67.592201000000003	67.573451000000006	Катаева	0103000020E6100000010000000500000025CCB4FD2BE34F40F2B6D26BB3E4504025CCB4FD2BE34F4025EA059FE6E55040FEF15EB532E94F4025EA059FE6E55040FEF15EB532E94F40F2B6D26BB3E4504025CCB4FD2BE34F40F2B6D26BB3E45040
57613	57210	63.77478	63.821860000000001	67.592201000000003	67.573451000000006	Есенина	0103000020E6100000010000000500000025CCB4FD2BE34F40F2B6D26BB3E4504025CCB4FD2BE34F4025EA059FE6E55040FEF15EB532E94F4025EA059FE6E55040FEF15EB532E94F40F2B6D26BB3E4504025CCB4FD2BE34F40F2B6D26BB3E45040
57601	57210	63.77478	63.821860000000001	67.592201000000003	67.573451000000006	Воргашорская	0103000020E6100000010000000500000025CCB4FD2BE34F40F2B6D26BB3E4504025CCB4FD2BE34F4025EA059FE6E55040FEF15EB532E94F4025EA059FE6E55040FEF15EB532E94F40F2B6D26BB3E4504025CCB4FD2BE34F40F2B6D26BB3E45040
59133	57535	34.250911000000002	34.250928999999999	61.940556999999998	61.940019999999997	 Петровское шоссе	0103000020E61000000100000005000000749A05DA1D204140FFCA4A9352F84E40749A05DA1D2041400E83F92B64F84E401A4F04711E2041400E83F92B64F84E401A4F04711E204140FFCA4A9352F84E40749A05DA1D204140FFCA4A9352F84E40
59436	26698	34.474448000000002	34.494444999999999	61.726647	61.716800999999997	Центральная	0103000020E6100000010000000500000089D349B6BA3C4140BB5E9A22C0DB4E4089D349B6BA3C4140465ED6C402DD4E40DA5548F9493F4140465ED6C402DD4E40DA5548F9493F4140BB5E9A22C0DB4E4089D349B6BA3C4140BB5E9A22C0DB4E40
59111	57532	32.330357999999997	32.388506	62.103154000000004	62.073005000000002	Суоярвское шоссе	0103000020E6100000010000000500000069FCC22B492A4040E5B8533A58094F4069FCC22B492A4040CE397826340D4F405F268A90BA314040CE397826340D4F405F268A90BA314040E5B8533A58094F4069FCC22B492A4040E5B8533A58094F40
59161	57532	32.330357999999997	32.388506	62.103154000000004	62.073005000000002	Ленина	0103000020E6100000010000000500000069FCC22B492A4040E5B8533A58094F4069FCC22B492A4040CE397826340D4F405F268A90BA314040CE397826340D4F405F268A90BA314040E5B8533A58094F4069FCC22B492A4040E5B8533A58094F40
59342	57530	30.030526999999999	31.0915	62.248289	61.538068000000003	Школьная	0103000020E610000001000000050000001EA5129ED0073E4017838769DFC44E401EA5129ED0073E40707A17EFC71F4F408195438B6C173F40707A17EFC71F4F408195438B6C173F4017838769DFC44E401EA5129ED0073E4017838769DFC44E40
59367	57530	30.030526999999999	31.0915	62.248289	61.538068000000003	Центральная	0103000020E610000001000000050000001EA5129ED0073E4017838769DFC44E401EA5129ED0073E40707A17EFC71F4F408195438B6C173F40707A17EFC71F4F408195438B6C173F4017838769DFC44E401EA5129ED0073E4017838769DFC44E40
59229	57530	30.030526999999999	31.0915	62.248289	61.538068000000003	Мира	0103000020E610000001000000050000001EA5129ED0073E4017838769DFC44E401EA5129ED0073E40707A17EFC71F4F408195438B6C173F40707A17EFC71F4F408195438B6C173F4017838769DFC44E401EA5129ED0073E4017838769DFC44E40
59432	3053	30.594048999999998	30.635165000000001	61.822459000000002	61.802804000000002	поселок Рюттю	0103000020E61000000100000005000000B438639813983E408B8C0E48C2E64E40B438639813983E4083A6255646E94E405890662C9AA23E4083A6255646E94E405890662C9AA23E408B8C0E48C2E64E40B438639813983E408B8C0E48C2E64E40
59086	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Промышленная	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59087	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Победы	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59088	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Набережная Ладожской флотилии	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59462	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Локомотивная	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59320	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Комсомольская	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59189	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Карельская	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59285	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Выборгское шоссе	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59170	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Выборгское Шоссе	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59141	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	Бондарева	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59085	3053	30.637105999999999	30.726846999999999	61.732536000000003	61.683655999999999	 Гагарина	0103000020E61000000100000005000000DB15FA6019A33E406ADB300A82D74E40DB15FA6019A33E40439259BDC3DD4E401A321EA512BA3E40439259BDC3DD4E401A321EA512BA3E406ADB300A82D74E40DB15FA6019A33E406ADB300A82D74E40
59214	57538	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Строителей	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59303	57538	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Лейгубская	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59171	57538	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Кирова	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59315	57538	34.314880000000002	34.337831999999999	63.729125000000003	63.716059000000001	Гористая	0103000020E610000001000000050000000E15E3FC4D284140D48041D2A7DB4F400E15E3FC4D28414017D9CEF753DD4F4069C537143E2B414017D9CEF753DD4F4069C537143E2B4140D48041D2A7DB4F400E15E3FC4D284140D48041D2A7DB4F40
59169	57537	36.489288000000002	36.557920000000003	61.822561	61.791379999999997	Комсомольская	0103000020E61000000100000005000000A2293BFDA03E4240AF5A99F04BE54E40A2293BFDA03E424087FBC8AD49E94E4065E42CEC6947424087FBC8AD49E94E4065E42CEC69474240AF5A99F04BE54E40A2293BFDA03E4240AF5A99F04BE54E40
59184	57527	31.425861999999999	31.506368999999999	61.596598999999998	61.541420000000002	Ленина	0103000020E61000000100000005000000F19BC24A056D3F403EB324404DC54E40F19BC24A056D3F40C4E9245B5DCC4E404EB51666A1813F40C4E9245B5DCC4E404EB51666A1813F403EB324404DC54E40F19BC24A056D3F403EB324404DC54E40
59192	57527	31.425861999999999	31.506368999999999	61.596598999999998	61.541420000000002	Горького	0103000020E61000000100000005000000F19BC24A056D3F403EB324404DC54E40F19BC24A056D3F40C4E9245B5DCC4E404EB51666A1813F40C4E9245B5DCC4E404EB51666A1813F403EB324404DC54E40F19BC24A056D3F403EB324404DC54E40
59094	57527	31.425861999999999	31.506368999999999	61.596598999999998	61.541420000000002	Гоголя	0103000020E61000000100000005000000F19BC24A056D3F403EB324404DC54E40F19BC24A056D3F40C4E9245B5DCC4E404EB51666A1813F40C4E9245B5DCC4E404EB51666A1813F403EB324404DC54E40F19BC24A056D3F403EB324404DC54E40
747	1518	34.338883000000003	34.345773000000001	61.794241999999997	61.793092999999999	улица Железнодорожная	0103000020E61000000100000005000000CF15A584602B4140E0D7481284E54E40CF15A584602B4140088ECBB8A9E54E407F6B274A422C4140088ECBB8A9E54E407F6B274A422C4140E0D7481284E54E40CF15A584602B4140E0D7481284E54E40
59278	1518	34.396357000000002	34.407577000000003	61.778615000000002	61.775288000000003	Чернышевского	0103000020E61000000100000005000000354580D3BB3241409A7D1EA33CE34E40354580D3BB324140689604A8A9E34E4008CDAE7B2B344140689604A8A9E34E4008CDAE7B2B3441409A7D1EA33CE34E40354580D3BB3241409A7D1EA33CE34E40
67651	1518	34.340114	34.398539999999997	61.799228999999997	61.772683999999998	ЦЕНТРАЛЬНАЯ	0103000020E61000000100000005000000B47405DB882B41403C122F4FE7E24E40B47405DB882B4140E481C8224DE64E40EC12D55B03334140E481C8224DE64E40EC12D55B033341403C122F4FE7E24E40B47405DB882B41403C122F4FE7E24E40
59279	1518	34.337221	34.342610999999998	61.849992	61.847797999999997	Трудовых Резервов	0103000020E610000001000000050000002043C70E2A2B41409ECE15A584EC4E402043C70E2A2B41404AEEB089CCEC4E40FB1F60ADDA2B41404AEEB089CCEC4E40FB1F60ADDA2B41409ECE15A584EC4E402043C70E2A2B41409ECE15A584EC4E40
59283	1518	34.203516	34.230015999999999	61.844410000000003	61.8367	Сулажгорского Кирпичного Завода	0103000020E610000001000000050000003B1BF2CF0C1A4140174850FC18EB4E403B1BF2CF0C1A41402B357BA015EC4E4043C70E2A711D41402B357BA015EC4E4043C70E2A711D4140174850FC18EB4E403B1BF2CF0C1A4140174850FC18EB4E40
3956	1518	34.341228000000001	34.347839	61.791006000000003	61.788576999999997	Студенческий переулок	0103000020E61000000100000005000000603DEE5BAD2B41405BB05417F0E44E40603DEE5BAD2B41404B7842AF3FE54E40FDA204FD852C41404B7842AF3FE54E40FDA204FD852C41405BB05417F0E44E40603DEE5BAD2B41405BB05417F0E44E40
59254	1518	34.317583999999997	34.351621000000002	61.805249000000003	61.793995000000002	Советская	0103000020E61000000100000005000000CEDDAE97A62841400118CFA0A1E54E40CEDDAE97A62841408011346612E74E401DCBBBEA012D41408011346612E74E401DCBBBEA012D41400118CFA0A1E54E40CEDDAE97A62841400118CFA0A1E54E40
59253	1518	34.431392000000002	34.447192999999999	61.728206	61.723182000000001	Птицефабрика	0103000020E61000000100000005000000C6E061DA3737414027874F3A91DC4E40C6E061DA373741402060ADDA35DD4E400400C79E3D3941402060ADDA35DD4E400400C79E3D39414027874F3A91DC4E40C6E061DA3737414027874F3A91DC4E40
59465	1518	34.390833000000001	34.398620999999999	61.779181000000001	61.776879000000001	Промышленная	0103000020E610000001000000050000004A99D4D0063241407FF964C570E34E404A99D4D0063241401155F833BCE34E40D93F4F03063341401155F833BCE34E40D93F4F03063341407FF964C570E34E404A99D4D0063241407FF964C570E34E40
3844	1518	34.300398999999999	34.307333999999997	61.768701	61.766815999999999	Попова переулок	0103000020E6100000010000000500000024607479732641405706D50627E24E40246074797326414085B35BCB64E24E40747973B85627414085B35BCB64E24E40747973B8562741405706D50627E24E4024607479732641405706D50627E24E40
59240	1518	34.438291	34.446196	61.759144999999997	61.753504	Петрова	0103000020E61000000100000005000000C99063EB19384140DDB3AED172E04E40C99063EB1938414001F6D1A92BE14E4092CD55F31C39414001F6D1A92BE14E4092CD55F31C394140DDB3AED172E04E40C99063EB19384140DDB3AED172E04E40
3658	1518	34.290922000000002	34.347929000000001	61.808253999999998	61.788865999999999	Первомайский проспект	0103000020E61000000100000005000000EDD79DEE3C2541409276A38FF9E44E40EDD79DEE3C2541403B6EF8DD74E74E403D2AFEEF882C41403B6EF8DD74E74E403D2AFEEF882C41409276A38FF9E44E40EDD79DEE3C2541409276A38FF9E44E40
59257	1518	34.315427999999997	34.335208999999999	61.786169999999998	61.777968000000001	Пархоменко	0103000020E61000000100000005000000101FD8F15F284140D2AA967494E34E40101FD8F15F284140548CF337A1E44E409529E620E82A4140548CF337A1E44E409529E620E82A4140D2AA967494E34E40101FD8F15F284140D2AA967494E34E40
59277	1518	34.37867	34.379010999999998	61.768887999999997	61.765619999999998	Парфёнова	0103000020E61000000100000005000000F8FC304278304140EE940ED6FFE14E40F8FC304278304140B72407EC6AE24E4081E9B46E83304140B72407EC6AE24E4081E9B46E83304140EE940ED6FFE14E40F8FC304278304140EE940ED6FFE14E40
3816	1518	34.315716000000002	34.355466	61.809477999999999	61.796087	Октябрьский проспект	0103000020E610000001000000050000007769C36169284140A8E2C62DE6E54E407769C361692841406E6AA0F99CE74E40836BEEE87F2D41406E6AA0F99CE74E40836BEEE87F2D4140A8E2C62DE6E54E407769C36169284140A8E2C62DE6E54E40
59263	1518	34.432541999999998	34.449959999999997	61.763039999999997	61.754874999999998	Нойбранденбургская	0103000020E61000000100000005000000BE1248895D374140B4C876BE9FE04E40BE1248895D37414019C5724BABE14E400B410E4A9839414019C5724BABE14E400B410E4A98394140B4C876BE9FE04E40BE1248895D374140B4C876BE9FE04E40
59265	1518	34.326647999999999	34.340643999999998	61.806514999999997	61.796908000000002	Мурманская	0103000020E61000000100000005000000E3A6069ACF294140DCF5D21401E64E40E3A6069ACF294140E15D2EE23BE74E4010CAFB389A2B4140E15D2EE23BE74E4010CAFB389A2B4140DCF5D21401E64E40E3A6069ACF294140DCF5D21401E64E40
4285	1518	34.271222000000002	34.343536999999998	61.777819999999998	61.747819	Лососинское шоссе	0103000020E6100000010000000500000055FA0967B7224140E9297288B8DF4E4055FA0967B72241405D16139B8FE34E40A4FB3905F92B41405D16139B8FE34E40A4FB3905F92B4140E9297288B8DF4E4055FA0967B7224140E9297288B8DF4E40
59238	1518	34.388758000000003	34.400283000000002	61.768062	61.762878000000001	Ломоносова	0103000020E61000000100000005000000790778D2C2314140406B7EFCA5E14E40790778D2C231414072A609DB4FE24E4088122D793C33414072A609DB4FE24E4088122D793C334140406B7EFCA5E14E40790778D2C2314140406B7EFCA5E14E40
59236	1518	34.306598000000001	34.317827000000001	61.796078000000001	61.793272000000002	Локомотивная	0103000020E610000001000000050000006F826F9A3E274140906AD8EF89E54E406F826F9A3E274140558847E2E5E54E4095641D8EAE284140558847E2E5E54E4095641D8EAE284140906AD8EF89E54E406F826F9A3E274140906AD8EF89E54E40
59284	1518	34.357810999999998	34.365006000000001	61.776674999999997	61.771602999999999	Лесная	0103000020E61000000100000005000000149337C0CC2D41406C3F19E3C3E24E40149337C0CC2D4140764F1E166AE34E40016C4084B82E4140764F1E166AE34E40016C4084B82E41406C3F19E3C3E24E40149337C0CC2D41406C3F19E3C3E24E40
59250	1518	34.347884000000001	34.359895000000002	61.799807000000001	61.792569999999998	Ленинградская	0103000020E610000001000000050000009D668176872C414036E50AEF72E54E409D668176872C4140520E661360E64E40397F130A112E4140520E661360E64E40397F130A112E414036E50AEF72E54E409D668176872C414036E50AEF72E54E40
4020	1518	34.347579000000003	34.377007999999996	61.794347999999999	61.785175000000002	Ленина проспект	0103000020E6100000010000000500000061E3FA777D2C41408351499D80E44E4061E3FA777D2C41404ED2FC31ADE54E40492A53CC413041404ED2FC31ADE54E40492A53CC413041408351499D80E44E4061E3FA777D2C41408351499D80E44E40
4163	1518	34.356014000000002	34.365734000000003	61.779125999999998	61.776139000000001	Ла-Рошель набережная	0103000020E610000001000000050000008675E3DD912D41403813D38558E34E408675E3DD912D41404DBB9866BAE34E408484285FD02E41404DBB9866BAE34E408484285FD02E41403813D38558E34E408675E3DD912D41403813D38558E34E40
59244	1518	34.372498	34.389045000000003	61.779108999999998	61.774070999999999	Кузьмина	0103000020E61000000100000005000000A7E9B303AE2F414019E42EC214E34E40A7E9B303AE2F41407782FDD7B9E34E400FD6FF39CC3141407782FDD7B9E34E400FD6FF39CC31414019E42EC214E34E40A7E9B303AE2F414019E42EC214E34E40
59268	1518	34.347121000000001	34.355134	61.78463	61.778024000000002	Красноармейская	0103000020E610000001000000050000009E60FF756E2C414066C0594A96E34E409E60FF756E2C4140F1BA7EC16EE44E404DD9E907752D4140F1BA7EC16EE44E404DD9E907752D414066C0594A96E34E409E60FF756E2C414066C0594A96E34E40
59270	1518	34.345090999999996	34.364933999999998	61.792268999999997	61.786157000000003	Красная	0103000020E610000001000000050000006C921FF12B2C4140C042E6CAA0E44E406C921FF12B2C41403B51121269E54E4067994528B62E41403B51121269E54E4067994528B62E4140C042E6CAA0E44E406C921FF12B2C4140C042E6CAA0E44E40
4342	1518	34.355528999999997	34.359876999999997	61.777155999999998	61.757660000000001	Комсомольский проспект	0103000020E61000000100000005000000C9E369F9812D414062BEBC00FBE04E40C9E369F9812D4140F1F109D979E34E4092CA1473102E4140F1F109D979E34E4092CA1473102E414062BEBC00FBE04E40C9E369F9812D414062BEBC00FBE04E40
59264	1518	34.388120000000001	34.399942000000003	61.783864999999999	61.774943	Коммунистов	0103000020E61000000100000005000000367689EAAD314140CFA10C5531E34E40367689EAAD31414051BD35B055E44E40FF25A94C3133414051BD35B055E44E40FF25A94C31334140CFA10C5531E34E40367689EAAD314140CFA10C5531E34E40
59262	1518	34.428435999999998	34.446474000000002	61.763215000000002	61.755598999999997	Ключевая	0103000020E61000000100000005000000EB36A8FDD6364140F5F1D077B7E04E40EB36A8FDD636414088687407B1E14E40D5415E0F2639414088687407B1E14E40D5415E0F26394140F5F1D077B7E04E40EB36A8FDD6364140F5F1D077B7E04E40
59274	1518	34.359374000000003	34.375615000000003	61.800407	61.787748000000001	Кирова	0103000020E6100000010000000500000030849CF7FF2D4140A5BE2CEDD4E44E4030849CF7FF2D4140A73E90BC73E64E408B71FE2614304140A73E90BC73E64E408B71FE2614304140A5BE2CEDD4E44E4030849CF7FF2D4140A5BE2CEDD4E44E40
59276	1518	34.368904999999998	34.392772999999998	61.785505999999998	61.771577999999998	Калинина	0103000020E610000001000000050000005A2A6F47382F414013286211C3E24E405A2A6F47382F4140E867EA758BE44E403BE0BA6246324140E867EA758BE44E403BE0BA624632414013286211C3E24E405A2A6F47382F414013286211C3E24E40
4252	1518	34.313955	34.316039000000004	61.764381	61.758434000000001	Интернационалистов бульвар	0103000020E6100000010000000500000035B56CAD2F2841405516855D14E14E4035B56CAD2F2841408657923CD7E14E405AA148F7732841408657923CD7E14E405AA148F7732841405516855D14E14E4035B56CAD2F2841405516855D14E14E40
59243	1518	34.313065999999999	34.341515000000001	61.816940000000002	61.804313	Зайцева	0103000020E61000000100000005000000A9BEF38B12284140B35F77BAF3E64E40A9BEF38B12284140AA656B7D91E84E40F60B76C3B62B4140AA656B7D91E84E40F60B76C3B62B4140B35F77BAF3E64E40A9BEF38B12284140B35F77BAF3E64E40
59256	1518	34.258583000000002	34.274726000000001	61.813749000000001	61.810339999999997	Жуковского	0103000020E610000001000000050000009A266C3F1921414000529B38B9E74E409A266C3F192141408C135FED28E84E4032AEB8382A2341408C135FED28E84E4032AEB8382A23414000529B38B9E74E409A266C3F1921414000529B38B9E74E40
4085	1518	34.384490999999997	34.393850999999998	61.786383000000001	61.782617999999999	Гюллинга набережная	0103000020E610000001000000050000009C4D47003731414066A19DD32CE44E409C4D470037314140B090B932A8E44E409A3FA6B569324140B090B932A8E44E409A3FA6B56932414066A19DD32CE44E409C4D47003731414066A19DD32CE44E40
59249	1518	34.367468000000002	34.373837000000002	61.767108999999998	61.764601999999996	Генерала Фролова	0103000020E61000000100000005000000CC290131092F4140643A747ADEE14E40CC290131092F4140CFBBB1A030E24E4073840CE4D92F4140CFBBB1A030E24E4073840CE4D92F4140643A747ADEE14E40CC290131092F4140643A747ADEE14E40
59269	1518	34.376936000000001	34.392781999999997	61.781440000000003	61.773569000000002	Варламова	0103000020E61000000100000005000000B05758703F30414087191A4F04E34E40B05758703F304140A4E4D53906E44E408E3A3AAE46324140A4E4D53906E44E408E3A3AAE4632414087191A4F04E34E40B05758703F30414087191A4F04E34E40
3782	1518	34.328642000000002	34.359786999999997	61.810169999999999	61.799807000000001	Варкауса набережная	0103000020E61000000100000005000000C80BE9F0102A4140520E661360E64E40C80BE9F0102A4140A4198BA6B3E74E4052431B800D2E4140A4198BA6B3E74E4052431B800D2E4140520E661360E64E40C80BE9F0102A4140520E661360E64E40
59245	1518	34.305888000000003	34.314475999999999	61.771611999999998	61.764845000000001	Берёзовая Аллея	0103000020E61000000100000005000000931E8656272741402BC1E270E6E14E40931E865627274140BF99982EC4E24E403EB0E3BF40284140BF99982EC4E24E403EB0E3BF402841402BC1E270E6E14E40931E8656272741402BC1E270E6E14E40
59247	1518	34.305888000000003	34.314475999999999	61.771611999999998	61.764845000000001	Березовая Аллея	0103000020E61000000100000005000000931E8656272741402BC1E270E6E14E40931E865627274140BF99982EC4E24E403EB0E3BF40284140BF99982EC4E24E403EB0E3BF402841402BC1E270E6E14E40931E8656272741402BC1E270E6E14E40
59289	1518	34.359095000000003	34.388255000000001	61.769708999999999	61.765138999999998	Балтийская	0103000020E610000001000000050000001D9430D3F62D414073F22213F0E14E401D9430D3F62D4140EB3713D385E24E4016C1FF56B2314140EB3713D385E24E4016C1FF56B231414073F22213F0E14E401D9430D3F62D414073F22213F0E14E40
59261	1518	34.424689999999998	34.438839000000002	61.766146999999997	61.759822	Антонова	0103000020E610000001000000050000001878EE3D5C3641400264E8D841E14E401878EE3D5C364140D976DA1A11E24E40CC9A58E02B384140D976DA1A11E24E40CC9A58E02B3841400264E8D841E14E401878EE3D5C3641400264E8D841E14E40
59260	1518	34.347929000000001	34.359158000000001	61.788865999999999	61.779819000000003	Анохина	0103000020E610000001000000050000003D2AFEEF882C414054E6E61BD1E34E403D2AFEEF882C41409276A38FF9E44E40630CACE3F82D41409276A38FF9E44E40630CACE3F82D414054E6E61BD1E34E403D2AFEEF882C414054E6E61BD1E34E40
4076	1518	34.358772000000002	34.396186999999998	61.784902000000002	61.773144000000002	Александра Невского проспект	0103000020E610000001000000050000003A5CAB3DEC2D4140A08CF161F6E24E403A5CAB3DEC2D4140524832AB77E44E40D80C7041B6324140524832AB77E44E40D80C7041B6324140A08CF161F6E24E403A5CAB3DEC2D4140A08CF161F6E24E40
59224	1518	34.305610000000001	34.325220000000002	61.762099999999997	61.758426	 Хейкконена	0103000020E6100000010000000500000050AA7D3A1E274140D237691A14E14E4050AA7D3A1E2741400B24287E8CE14E40A80018CFA02941400B24287E8CE14E40A80018CFA0294140D237691A14E14E4050AA7D3A1E274140D237691A14E14E40
59248	1518	34.366480000000003	34.367440999999999	61.762521	61.757289	 Сортавальская	0103000020E61000000100000005000000AD510FD1E82E41406E4F90D8EEE04E40AD510FD1E82E4140B1C1C2499AE14E40D21A834E082F4140B1C1C2499AE14E40D21A834E082F41406E4F90D8EEE04E40AD510FD1E82E41406E4F90D8EEE04E40
59239	1518	34.317583999999997	34.351621000000002	61.805249000000003	61.793995000000002	 Советская	0103000020E61000000100000005000000CEDDAE97A62841400118CFA0A1E54E40CEDDAE97A62841408011346612E74E401DCBBBEA012D41408011346612E74E401DCBBBEA012D41400118CFA0A1E54E40CEDDAE97A62841400118CFA0A1E54E40
59258	1518	34.376432999999999	34.384858999999999	61.794144000000003	61.788029000000002	 Пушкинская	0103000020E610000001000000050000004D11E0F42E30414059A65F22DEE44E404D11E0F42E3041404628B682A6E54E401F49490F433141404628B682A6E54E401F49490F4331414059A65F22DEE44E404D11E0F42E30414059A65F22DEE44E40
59237	1518	34.328229	34.341946999999998	61.787734999999998	61.777641000000003	 Островского	0103000020E61000000100000005000000A54C6A68032A4140AE8383BD89E34E40A54C6A68032A414010751F80D4E44E408FFB56EBC42B414010751F80D4E44E408FFB56EBC42B4140AE8383BD89E34E40A54C6A68032A4140AE8383BD89E34E40
59233	1518	34.31223	34.328812999999997	61.787008	61.782125000000001	 Олонецкая	0103000020E61000000100000005000000406A1327F7274140273108AC1CE44E40406A1327F72741405ED89AADBCE44E40F4BF5C8B162A41405ED89AADBCE44E40F4BF5C8B162A4140273108AC1CE44E40406A1327F7274140273108AC1CE44E40
59222	1518	34.279944999999998	34.299365999999999	61.808500000000002	61.803221000000001	 Новосулажгорская	0103000020E61000000100000005000000E0D6DD3CD5234140EF3A1BF2CFE64E40E0D6DD3CD5234140736891ED7CE74E4065C405A051264140736891ED7CE74E4065C405A051264140EF3A1BF2CFE64E40E0D6DD3CD5234140EF3A1BF2CFE64E40
59230	1518	34.339134999999999	34.349456000000004	61.803412000000002	61.796410000000002	 Московская	0103000020E61000000100000005000000E8F692C6682B41408B1A4CC3F0E54E40E8F692C6682B4140639B5434D6E64E400CB265F9BA2C4140639B5434D6E64E400CB265F9BA2C41408B1A4CC3F0E54E40E8F692C6682B41408B1A4CC3F0E54E40
59353	1518	34.259041000000003	34.260855999999997	61.814565000000002	61.812848000000002	 Клубная	0103000020E610000001000000050000005DA96741282141403C4F3C670BE84E405DA9674128214140AEBB79AA43E84E40917BBABA63214140AEBB79AA43E84E40917BBABA632141403C4F3C670BE84E405DA96741282141403C4F3C670BE84E40
59235	1518	34.310622000000002	34.312527000000003	61.787560999999997	61.781328999999999	 Зелёная	0103000020E6100000010000000500000085B53176C22741404C35B39602E44E4085B53176C2274140724D81CCCEE44E40FA0E7EE200284140724D81CCCEE44E40FA0E7EE2002841404C35B39602E44E4085B53176C22741404C35B39602E44E40
59241	1518	34.347237999999997	34.363999999999997	61.793135999999997	61.780405999999999	 Антикайнена	0103000020E61000000100000005000000D7F6764B722C414014CD0358E4E34E40D7F6764B722C4140DFA3FE7A85E54E403BDF4F8D972E4140DFA3FE7A85E54E403BDF4F8D972E414014CD0358E4E34E40D7F6764B722C414014CD0358E4E34E40
59259	1518	34.347929000000001	34.359158000000001	61.788865999999999	61.779819000000003	 Анохина	0103000020E610000001000000050000003D2AFEEF882C414054E6E61BD1E34E403D2AFEEF882C41409276A38FF9E44E40630CACE3F82D41409276A38FF9E44E40630CACE3F82D414054E6E61BD1E34E403D2AFEEF882C414054E6E61BD1E34E40
59127	26478	34.169668000000001	34.182397000000002	61.819459000000002	61.811743	Нововилговское шоссе	0103000020E61000000100000005000000C09657AEB7154140E3E0D231E7E74E40C09657AEB7154140D9B45208E4E84E40BBF1EEC858174140D9B45208E4E84E40BBF1EEC858174140E3E0D231E7E74E40C09657AEB7154140E3E0D231E7E74E40
59118	3356	34.235793000000001	34.250138999999997	61.867907000000002	61.86036	Петрозаводская	0103000020E6100000010000000500000018D00B772E1E4140AE64C74620EE4E4018D00B772E1E4140187C9A9317EF4E40213A048E04204140187C9A9317EF4E40213A048E04204140AE64C74620EE4E4018D00B772E1E4140AE64C74620EE4E40
59121	57528	34.397587999999999	34.514341999999999	62.943748999999997	62.891162999999999	Советская	0103000020E610000001000000050000001AA4E029E4324140DF3312A111724F401AA4E029E4324140FC5069C4CC784F40C87A6AF5D5414140FC5069C4CC784F40C87A6AF5D5414140DF3312A111724F401AA4E029E4324140DF3312A111724F40
59103	57528	34.397587999999999	34.514341999999999	62.943748999999997	62.891162999999999	Куйбышева	0103000020E610000001000000050000001AA4E029E4324140DF3312A111724F401AA4E029E4324140FC5069C4CC784F40C87A6AF5D5414140FC5069C4CC784F40C87A6AF5D5414140DF3312A111724F401AA4E029E4324140DF3312A111724F40
59099	57528	34.397587999999999	34.514341999999999	62.943748999999997	62.891162999999999	К.Либкнехта	0103000020E610000001000000050000001AA4E029E4324140DF3312A111724F401AA4E029E4324140FC5069C4CC784F40C87A6AF5D5414140FC5069C4CC784F40C87A6AF5D5414140DF3312A111724F401AA4E029E4324140DF3312A111724F40
59098	57528	34.397587999999999	34.514341999999999	62.943748999999997	62.891162999999999	Дзержинского	0103000020E610000001000000050000001AA4E029E4324140DF3312A111724F401AA4E029E4324140FC5069C4CC784F40C87A6AF5D5414140FC5069C4CC784F40C87A6AF5D5414140DF3312A111724F401AA4E029E4324140DF3312A111724F40
59185	57536	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	Фанерная	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
59327	57536	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	Садовая	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
59288	57536	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	Ленинградское шоссе	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
59286	57536	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	Ленина	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
59148	57536	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	Ладожской флотилии	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
59345	57536	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	Заходского	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
59139	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Строителей	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59175	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Советская	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59419	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Перттунена	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59216	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Первооткрывателей	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59151	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Первомайская	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
9648	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Октябрьская	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59217	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Ленина пл.	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59150	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Ленина	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59176	3252	30.555627999999999	30.614602999999999	64.594381999999996	64.569130000000001	Калевала	0103000020E61000000100000005000000ECBDF8A23D8E3E400A4B3CA06C245040ECBDF8A23D8E3E4030D5CC5A0A2650400306499F569D3E4030D5CC5A0A2650400306499F569D3E400A4B3CA06C245040ECBDF8A23D8E3E400A4B3CA06C245040
59157	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	пр.Калинина	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59114	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	пр. Калинина 	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59179	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	б.Юности	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59156	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Советов	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59455	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Сандальская набережная	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59153	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Пролетарская	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59435	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Кондопожская	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59113	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Комсомольская	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59116	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Заводская	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59115	57533	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Б.Юности	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59201	57539	34.527943	34.661935	64.965517000000006	64.941023000000001	Пролетарский пр.	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59195	57539	34.527943	34.661935	64.965517000000006	64.941023000000001	Пролетарский пр	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59182	57539	34.527943	34.661935	64.965517000000006	64.941023000000001	Кирова пл	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59108	57531	30.484302	30.507532999999999	61.905624000000003	61.897717999999998	40 лет Победы	0103000020E610000001000000050000002C634337FB7B3E40E883656CE8F24E402C634337FB7B3E40823CBB7CEBF34E4009A4C4AEED813E40823CBB7CEBF34E4009A4C4AEED813E40E883656CE8F24E402C634337FB7B3E40E883656CE8F24E40
59198	57541	34.722248	34.815745	64.552330999999995	64.505497000000005	Мерецкова	0103000020E61000000100000005000000FBCC599F725C414079CE16105A205040FBCC599F725C414049641F6459235040117008556A68414049641F6459235040117008556A68414079CE16105A205040FBCC599F725C414079CE16105A205040
59418	30949	32.594642	32.616723	62.330620000000003	62.317002000000002	Школьная	0103000020E61000000100000005000000FD69A33A1D4C40402062838593284F40FD69A33A1D4C4040A7B393C1512A4F4073D87DC7F04E4040A7B393C1512A4F4073D87DC7F04E40402062838593284F40FD69A33A1D4C40402062838593284F40
59220	30637	32.330357999999997	32.388506	62.103154000000004	62.073005000000002	Суоярвское шоссе	0103000020E6100000010000000500000069FCC22B492A4040E5B8533A58094F4069FCC22B492A4040CE397826340D4F405F268A90BA314040CE397826340D4F405F268A90BA314040E5B8533A58094F4069FCC22B492A4040E5B8533A58094F40
59142	30637	32.330357999999997	32.388506	62.103154000000004	62.073005000000002	Гагарина	0103000020E6100000010000000500000069FCC22B492A4040E5B8533A58094F4069FCC22B492A4040CE397826340D4F405F268A90BA314040CE397826340D4F405F268A90BA314040E5B8533A58094F4069FCC22B492A4040E5B8533A58094F40
59420	30886	32.601703000000001	32.618214000000002	62.203395	62.197701000000002	Ленина	0103000020E61000000100000005000000DA73999A044D404079B130444E194F40DA73999A044D4040C095ECD8081A4F40F5F6E7A2214F4040C095ECD8081A4F40F5F6E7A2214F404079B130444E194F40DA73999A044D404079B130444E194F40
59306	31424	31.552992	31.575728000000002	61.931097999999999	61.920178	Советская	0103000020E610000001000000050000001BF33AE2908D3F40D53F8864C8F54E401BF33AE2908D3F407DAF21382EF74E40396403E962933F407DAF21382EF74E40396403E962933F40D53F8864C8F54E401BF33AE2908D3F40D53F8864C8F54E40
59149	31138	32.636719999999997	32.762987000000003	62.728746999999998	62.684187999999999	Заводская	0103000020E61000000100000005000000C45A7C0A805140406728EE7893574F40C45A7C0A805140407007EA94475D4F40F722DA8EA96140407007EA94475D4F40F722DA8EA96140406728EE7893574F40C45A7C0A805140406728EE7893574F40
59215	31138	32.636719999999997	32.762987000000003	62.728746999999998	62.684187999999999	Больничная	0103000020E61000000100000005000000C45A7C0A805140406728EE7893574F40C45A7C0A805140407007EA94475D4F40F722DA8EA96140407007EA94475D4F40F722DA8EA96140406728EE7893574F40C45A7C0A805140406728EE7893574F40
59316	31578	32.087499000000001	32.113909	62.040577999999996	62.019595000000002	Центральная	0103000020E6100000010000000500000063B7CF2A330B40402315C61682024F4063B7CF2A330B4040F277EFA831054F402BDCF291940E4040F277EFA831054F402BDCF291940E40402315C61682024F4063B7CF2A330B40402315C61682024F40
59112	30980	32.668664	32.695954	62.310518999999999	62.295102	Заводская	0103000020E610000001000000050000009B012EC896554040FA7DFFE6C5254F409B012EC896554040B0E42A16BF274F409CC24A0515594040B0E42A16BF274F409CC24A0515594040FA7DFFE6C5254F409B012EC896554040FA7DFFE6C5254F40
59334	31405	31.713090000000001	31.763601999999999	61.989834999999999	61.966647999999999	Суоярское шоссе	0103000020E61000000100000005000000CA1AF5108DB63F40355F251FBBFB4E40CA1AF5108DB63F40D4B7CCE9B2FE4E400229B16B7BC33F40D4B7CCE9B2FE4E400229B16B7BC33F40355F251FBBFB4E40CA1AF5108DB63F40355F251FBBFB4E40
59387	31496	31.339561	31.376213	61.86347	61.851956999999999	Центральная	0103000020E610000001000000050000003FFF3D78ED563F40944C4EED0CED4E403FFF3D78ED563F40DF89592F86EE4E407E54C37E4F603F40DF89592F86EE4E407E54C37E4F603F40944C4EED0CED4E403FFF3D78ED563F40944C4EED0CED4E40
59355	57553	30.646744999999999	30.701218000000001	61.757570000000001	61.732858999999998	Центральная	0103000020E61000000100000005000000FDD98F1491A53E4025CADE52CEDD4E40FDD98F1491A53E402237C30DF8E04E40D55DD90583B33E402237C30DF8E04E40D55DD90583B33E4025CADE52CEDD4E40FDD98F1491A53E4025CADE52CEDD4E40
59440	30051	33.650855	33.676582000000003	63.999419000000003	63.990403000000001	Болотная	0103000020E6100000010000000500000013B875374FD340401E6E8786C5FE4F4013B875374FD34040220038F6ECFF4F40F9872D3D9AD64040220038F6ECFF4F40F9872D3D9AD640401E6E8786C5FE4F4013B875374FD340401E6E8786C5FE4F40
59172	29216	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	пр-д Бумажников	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59110	29216	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Спиридонова	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59135	29216	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Советская	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59140	29216	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Монтажников пр-д	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59136	29216	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Мира	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59137	29216	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Лесокультурная	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59389	29216	34.329056000000001	34.371411000000002	63.755298000000003	63.728642999999998	Анохина	0103000020E61000000100000005000000BB46CB811E2A4140CBBA7F2C44DD4F40BB46CB811E2A4140FB5DD89AADE04F40F52F49658A2F4140FB5DD89AADE04F40F52F49658A2F4140CBBA7F2C44DD4F40BB46CB811E2A4140CBBA7F2C44DD4F40
59395	29886	34.311368000000002	34.334660999999997	63.867846	63.856203999999998	Набережная	0103000020E61000000100000005000000AE8218E8DA274140295AB91798ED4F40AE8218E8DA27414072FBE59315EF4F40921FF12BD62A414072FBE59315EF4F40921FF12BD62A4140295AB91798ED4F40AE8218E8DA274140295AB91798ED4F40
59394	30373	34.005994999999999	34.022047000000001	63.412334000000001	63.404989	Кирова	0103000020E610000001000000050000004278B471C4004140B01EF7ADD6B34F404278B471C4004140B2834A5CC7B44F40CAFCA36FD2024140B2834A5CC7B44F40CAFCA36FD2024140B01EF7ADD6B34F404278B471C4004140B01EF7ADD6B34F40
59451	2102	34.872878	34.925052000000001	63.700899	63.686388999999998	Центральная	0103000020E61000000100000005000000EEB25F77BA6F4140C5AA4198DBD74F40EEB25F77BA6F41404966F50EB7D94F40B98C9B1A687641404966F50EB7D94F40B98C9B1A68764140C5AA4198DBD74F40EEB25F77BA6F4140C5AA4198DBD74F40
59469	57571	32.947797000000001	36.256974999999997	64.231694000000005	63.142496000000001	Набережная	0103000020E610000001000000050000009B1F7F6951794040C9E7154F3D924F409B1F7F69517940407C2B1213D40E5040DE718A8EE42042407C2B1213D40E5040DE718A8EE4204240C9E7154F3D924F409B1F7F6951794040C9E7154F3D924F40
59174	48411	34.237121999999999	34.276414000000003	63.910411000000003	63.885094000000002	Ленина	0103000020E61000000100000005000000C09481035A1E414063F19BC24AF14F40C09481035A1E41409775FF5888F44F400A14B188612341409775FF5888F44F400A14B1886123414063F19BC24AF14F40C09481035A1E414063F19BC24AF14F40
59165	48411	34.237121999999999	34.276414000000003	63.910411000000003	63.885094000000002	 Строителей	0103000020E61000000100000005000000C09481035A1E414063F19BC24AF14F40C09481035A1E41409775FF5888F44F400A14B188612341409775FF5888F44F400A14B1886123414063F19BC24AF14F40C09481035A1E414063F19BC24AF14F40
59160	29744	34.319910999999998	34.329836999999998	63.878624000000002	63.870913000000002	Строителей	0103000020E61000000100000005000000B950F9D7F2284140A454C2137AEF4F40B950F9D7F228414088BD50C076F04F4060014C19382A414088BD50C076F04F4060014C19382A4140A454C2137AEF4F40B950F9D7F2284140A454C2137AEF4F40
59450	30335	34.205699000000003	34.255699	64.042767999999995	64.028858999999997	Центральная	0103000020E61000000100000005000000F3E84658541A41407F4C6BD3D8015040F3E84658541A41402E54FEB5BC025040594FADBEBA2041402E54FEB5BC025040594FADBEBA2041407F4C6BD3D8015040F3E84658541A41407F4C6BD3D8015040
59308	29946	34.168536000000003	34.196275999999997	63.933664999999998	63.920985999999999	Комсомольская	0103000020E610000001000000050000006E19709692154140740987DEE2F54F406E19709692154140BD35B05582F74F40AE7E6C921F194140BD35B05582F74F40AE7E6C921F194140740987DEE2F54F406E19709692154140740987DEE2F54F40
59391	30240	34.221905	34.277662999999997	64.143073999999999	64.121424000000005	Школьная	0103000020E61000000100000005000000D1E80E62671C4140C53C2B69C5075040D1E80E62671C41401BBAD91F28095040952710768A2341401BBAD91F28095040952710768A234140C53C2B69C5075040D1E80E62671C4140C53C2B69C5075040
59449	30435	33.987876	34.004387000000001	63.725358	63.715302000000001	Центральная	0103000020E610000001000000050000006C4084B872FE4040B76114048FDB4F406C4084B872FE40402CF2EB87D8DC4F4087C3D2C08F0041402CF2EB87D8DC4F4087C3D2C08F004140B76114048FDB4F406C4084B872FE4040B76114048FDB4F40
59400	48510	33.454411	33.478772999999997	63.981724	63.969842	Центральная	0103000020E61000000100000005000000A9F8BF232ABA4040C4245CC823FC4F40A9F8BF232ABA404062D9CC21A9FD4F40999A046F48BD404062D9CC21A9FD4F40999A046F48BD4040C4245CC823FC4F40A9F8BF232ABA4040C4245CC823FC4F40
59173	30528	35.498086999999998	35.524588000000001	63.441353999999997	63.421740999999997	Школьная	0103000020E6100000010000000500000008C89750C1BF4140F030ED9BFBB54F4008C89750C1BF4140B9FAB1497EB84F40E1EF17B325C34140B9FAB1497EB84F40E1EF17B325C34140F030ED9BFBB54F4008C89750C1BF4140F030ED9BFBB54F40
59347	28532	35.963918	36.042501999999999	61.806634000000003	61.792136999999997	Стеклянская	0103000020E610000001000000050000004B033FAA61FB4140CC79C6BE64E54E404B033FAA61FB4140BCEB6CC83FE74E40DE019EB470054240BCEB6CC83FE74E40DE019EB470054240CC79C6BE64E54E404B033FAA61FB4140CC79C6BE64E54E40
59131	28532	35.963918	36.042501999999999	61.806634000000003	61.792136999999997	Октябрьская	0103000020E610000001000000050000004B033FAA61FB4140CC79C6BE64E54E404B033FAA61FB4140BCEB6CC83FE74E40DE019EB470054240BCEB6CC83FE74E40DE019EB470054240CC79C6BE64E54E404B033FAA61FB4140CC79C6BE64E54E40
59370	28924	36.101522000000003	36.112526000000003	62.670347	62.662652000000001	Центральная	0103000020E610000001000000050000008AE942ACFE0C42408350DEC7D1544F408AE942ACFE0C424061FC34EECD554F4090F98040670E424061FC34EECD554F4090F98040670E42408350DEC7D1544F408AE942ACFE0C42408350DEC7D1544F40
59444	28851	36.143877000000003	36.169147000000002	62.496487999999999	62.487774999999999	Школьная	0103000020E61000000100000005000000C4D2C08F6A124240386744696F3E4F40C4D2C08F6A124240A06D35EB8C3F4F40B79BE09BA6154240A06D35EB8C3F4F40B79BE09BA6154240386744696F3E4F40C4D2C08F6A124240386744696F3E4F40
59369	28160	36.423189999999998	36.434517999999997	62.010112999999997	62.001688999999999	Школьная	0103000020E6100000010000000500000043FF04172B364240A8E15B5837004F4043FF04172B364240D921FE614B014F40FCC22B499E374240D921FE614B014F40FCC22B499E374240A8E15B5837004F4043FF04172B364240A8E15B5837004F40
59132	47966	35.838889999999999	35.928713000000002	62.463422000000001	62.429053000000003	Школьная	0103000020E6100000010000000500000081785DBF60EB414017A06D35EB364F4081785DBF60EB41409B1F7F69513B4F405E2F4D11E0F641409B1F7F69513B4F405E2F4D11E0F6414017A06D35EB364F4081785DBF60EB414017A06D35EB364F40
59333	28836	35.915695999999997	35.943435999999998	62.324114999999999	62.313231999999999	Молодежная	0103000020E61000000100000005000000FC89CA8635F54140C40776FC17284F40FC89CA8635F541404F92AE997C294F403DEFC682C2F841404F92AE997C294F403DEFC682C2F84140C40776FC17284F40FC89CA8635F54140C40776FC17284F40
59212	27864	36.489288000000002	36.557920000000003	61.822561	61.791379999999997	Пионерская	0103000020E61000000100000005000000A2293BFDA03E4240AF5A99F04BE54E40A2293BFDA03E424087FBC8AD49E94E4065E42CEC6947424087FBC8AD49E94E4065E42CEC69474240AF5A99F04BE54E40A2293BFDA03E4240AF5A99F04BE54E40
59109	27864	36.489288000000002	36.557920000000003	61.822561	61.791379999999997	К.Маркса	0103000020E61000000100000005000000A2293BFDA03E4240AF5A99F04BE54E40A2293BFDA03E424087FBC8AD49E94E4065E42CEC6947424087FBC8AD49E94E4065E42CEC69474240AF5A99F04BE54E40A2293BFDA03E4240AF5A99F04BE54E40
59392	48145	37.592914	37.620995000000001	61.801827000000003	61.795121999999999	Центральная	0103000020E6100000010000000500000097AB1F9BE4CB4240412AC58EC6E54E4097AB1F9BE4CB424060066344A2E64E4061FD9FC37CCF424060066344A2E64E4061FD9FC37CCF4240412AC58EC6E54E4097AB1F9BE4CB4240412AC58EC6E54E40
59332	32531	36.357540999999998	36.382119000000003	61.830576000000001	61.817335	Школьная	0103000020E6100000010000000500000054FD4AE7C32D42402670EB6E9EE84E4054FD4AE7C32D4240D76B7A5050EA4E4012178046E9304240D76B7A5050EA4E4012178046E93042402670EB6E9EE84E4054FD4AE7C32D42402670EB6E9EE84E40
59417	28667	35.881075000000003	35.903424999999999	61.991132999999998	61.981152000000002	Советская	0103000020E610000001000000050000005F29CB10C7F04140D733846396FD4E405F29CB10C7F04140417E3672DDFE4E40C4B12E6EA3F34140417E3672DDFE4E40C4B12E6EA3F34140D733846396FD4E405F29CB10C7F04140D733846396FD4E40
59313	32615	37.159117000000002	37.194232	61.954476999999997	61.945169999999997	Победы	0103000020E610000001000000050000006B9E23F25D94424085949F54FBF84E406B9E23F25D94424060E4654D2CFA4E4018EB1B98DC98424060E4654D2CFA4E4018EB1B98DC98424085949F54FBF84E406B9E23F25D94424085949F54FBF84E40
59134	48029	36.942622999999998	36.976768	61.815328999999998	61.795594000000001	Горького	0103000020E610000001000000050000008CBAD6DEA778424069723106D6E54E408CBAD6DEA77842407D3D5FB35CE84E40C1E3DBBB067D42407D3D5FB35CE84E40C1E3DBBB067D424069723106D6E54E408CBAD6DEA778424069723106D6E54E40
59388	47821	36.339188999999998	36.356158000000001	61.657485000000001	61.653708999999999	Центральная	0103000020E61000000100000005000000DB148F8B6A2B4240E90C8CBCACD34E40DB148F8B6A2B4240274EEE7728D44E40B91AD995962D4240274EEE7728D44E40B91AD995962D4240E90C8CBCACD34E40DB148F8B6A2B4240E90C8CBCACD34E40
59305	33132	36.656671000000003	36.804175000000001	61.815448000000004	61.795641000000003	Школьная	0103000020E61000000100000005000000A69D9ACB0D544240AA2D7590D7E54E40A69D9ACB0D54424058CB9D9960E84E4062A1D634EF66424058CB9D9960E84E4062A1D634EF664240AA2D7590D7E54E40A69D9ACB0D544240AA2D7590D7E54E40
59438	28382	36.284922000000002	36.316336	61.690679000000003	61.668711999999999	Школьная	0103000020E6100000010000000500000099F4F75278244240AC38D55A98D54E4099F4F752782442405A84622B68D84E401346B3B27D2842405A84622B68D84E401346B3B27D284240AC38D55A98D54E4099F4F75278244240AC38D55A98D54E40
59167	46963	37.739995	37.761923000000003	61.780439999999999	61.774267000000002	Центральная	0103000020E610000001000000050000000D1AFA27B8DE42409FAF592E1BE34E400D1AFA27B8DE4240C03E3A75E5E34E40FD885FB186E14240C03E3A75E5E34E40FD885FB186E142409FAF592E1BE34E400D1AFA27B8DE42409FAF592E1BE34E40
59314	29081	37.437432999999999	37.464302000000004	62.088476999999997	62.052984000000002	Комсомольская	0103000020E610000001000000050000007898F6CDFDB742400B9B012EC8064F407898F6CDFDB742405EB9DE36530B4F40D4BB783F6EBB42405EB9DE36530B4F40D4BB783F6EBB42400B9B012EC8064F407898F6CDFDB742400B9B012EC8064F40
59439	28358	36.204217	36.257899999999999	61.853723000000002	61.837006000000002	Лесная	0103000020E61000000100000005000000C4245CC8231A424024473A0323EB4E40C4245CC8231A4240E86B96CB46ED4E40B7D100DE02214240E86B96CB46ED4E40B7D100DE0221424024473A0323EB4E40C4245CC8231A424024473A0323EB4E40
59158	27355	33.136111	33.223050000000001	61.856188000000003	61.842180999999997	Октябрьская	0103000020E610000001000000050000001CD0D2156C91404002284696CCEB4E401CD0D2156C914040249D819197ED4E40B8AF03E78C9C4040249D819197ED4E40B8AF03E78C9C404002284696CCEB4E401CD0D2156C91404002284696CCEB4E40
59107	27001	34.040498999999997	34.094928000000003	61.89228	61.874786999999998	Школьная	0103000020E61000000100000005000000A6423C122F054140A4FB3905F9EF4E40A6423C122F054140FC6F253B36F24E40C3BCC799260C4140FC6F253B36F24E40C3BCC799260C4140A4FB3905F9EF4E40A6423C122F054140A4FB3905F9EF4E40
59354	27496	33.363366999999997	33.380856999999999	61.927016999999999	61.917662999999997	Школьная	0103000020E610000001000000050000000AB952CF82AE4040E7DF2EFB75F54E400AB952CF82AE404003EB387EA8F64E40F1B913ECBFB0404003EB387EA8F64E40F1B913ECBFB04040E7DF2EFB75F54E400AB952CF82AE4040E7DF2EFB75F54E40
59371	27408	32.841571000000002	32.852558000000002	61.813828999999998	61.803778000000001	Школьная	0103000020E610000001000000050000008A213999B86B4040459F8F32E2E64E408A213999B86B4040A8C4758C2BE84E40BAF8DB9E206D4040A8C4758C2BE84E40BAF8DB9E206D4040459F8F32E2E64E408A213999B86B4040459F8F32E2E64E40
59309	27199	33.599085000000002	33.633104000000003	61.566974999999999	61.550521000000003	Олонецкая	0103000020E61000000100000005000000184339D1AECC40407061DD7877C64E40184339D1AECC4040265305A392C84E40C07B478D09D14040265305A392C84E40C07B478D09D140407061DD7877C64E40184339D1AECC40407061DD7877C64E40
59106	26908	33.605426999999999	33.641053999999997	61.717154999999998	61.675640000000001	Советская	0103000020E61000000100000005000000C58EC6A17ECD40404AEF1B5F7BD64E40C58EC6A17ECD4040D9942BBCCBDB4E40287CB60E0ED24040D9942BBCCBDB4E40287CB60E0ED240404AEF1B5F7BD64E40C58EC6A17ECD40404AEF1B5F7BD64E40
59291	27186	33.788342	33.832422000000001	61.786723000000002	61.774450000000002	Пряжинское шоссе	0103000020E6100000010000000500000018080264E8E440409031772D21E34E4018080264E8E440406901DA56B3E44E40473CD9CD8CEA40406901DA56B3E44E40473CD9CD8CEA40409031772D21E34E4018080264E8E440409031772D21E34E40
59356	3398	33.135356000000002	33.149469000000003	62.027473999999998	62.015090999999998	Пионерская	0103000020E61000000100000005000000A0A86C585391404062BB7B80EE014F40A0A86C5853914040C2BE9D4484034F400762D9CC21934040C2BE9D4484034F400762D9CC2193404062BB7B80EE014F40A0A86C585391404062BB7B80EE014F40
59396	27291	33.158883000000003	33.186425999999997	61.651282000000002	61.625712	Магистральная	0103000020E61000000100000005000000F8713447569440407D5BB05417D04E40F8713447569440409B3C65355DD34E40E28FA2CEDC9740409B3C65355DD34E40E28FA2CEDC9740407D5BB05417D04E40F8713447569440407D5BB05417D04E40
59373	27780	32.432541000000001	32.4709	61.528007000000002	61.515618000000003	Гагарина	0103000020E61000000100000005000000EE96E4805D3740404E9D47C5FFC14E40EE96E4805D3740409087BEBB95C34E40DCD78173463C40409087BEBB95C34E40DCD78173463C40404E9D47C5FFC14E40EE96E4805D3740404E9D47C5FFC14E40
59384	27739	32.582110999999998	32.634438000000003	61.394803000000003	61.384419999999999	Центральная	0103000020E6100000010000000500000028D2FD9C824A4040D3F6AFAC34B14E4028D2FD9C824A40406DAE9AE788B24E407AABAE43355140406DAE9AE788B24E407AABAE4335514040D3F6AFAC34B14E4028D2FD9C824A4040D3F6AFAC34B14E40
59456	31332	32.802162000000003	32.838723999999999	61.923439000000002	61.913237000000002	Стойкина	0103000020E61000000100000005000000070C923EAD664040A33F34F3E4F44E40070C923EAD664040EC6CC83F33F64E40662FDB4E5B6B4040EC6CC83F33F64E40662FDB4E5B6B4040A33F34F3E4F44E40070C923EAD664040A33F34F3E4F44E40
59348	57552	32.805503999999999	32.861567999999998	61.579402999999999	61.562385999999996	Школьная	0103000020E610000001000000050000000A664CC11A67404037DDB243FCC74E400A664CC11A674040261AA4E029CA4E40DBA337DC476E4040261AA4E029CA4E40DBA337DC476E404037DDB243FCC74E400A664CC11A67404037DDB243FCC74E40
59202	49590	34.146895000000001	34.276575999999999	61.959760000000003	61.855077000000001	Школьная	0103000020E6100000010000000500000014799274CD124140E947C32973ED4E4014799274CD12414026016A6AD9FA4E40E36DA5D76623414026016A6AD9FA4E40E36DA5D766234140E947C32973ED4E4014799274CD124140E947C32973ED4E40
59330	26824	35.332438000000003	35.373365	61.383251999999999	61.360931000000001	Лисицыной	0103000020E610000001000000050000004DF910548DAA4140698EACFC32AE4E404DF910548DAA41403410CB660EB14E404B3CA06CCAAF41403410CB660EB14E404B3CA06CCAAF4140698EACFC32AE4E404DF910548DAA4140698EACFC32AE4E40
59385	26632	34.676704000000001	34.697015	61.545270000000002	61.535941000000001	Радиоцентр	0103000020E610000001000000050000004489963C9E564140F3CAF5B699C44E404489963C9E564140B6BE4868CBC54E4025E99AC937594140B6BE4868CBC54E4025E99AC937594140F3CAF5B699C44E404489963C9E564140F3CAF5B699C44E40
59350	26200	34.414755	34.461601999999999	61.213842	61.198808	Кировская	0103000020E610000001000000050000001E6D1CB1163541407217618A72994E401E6D1CB1163541407041B62C5F9B4E4054E23AC6153B41407041B62C5F9B4E4054E23AC6153B41407217618A72994E401E6D1CB1163541407217618A72994E40
59206	3262	34.421322000000004	34.475472000000003	61.367325999999998	61.342461	Молодежная	0103000020E61000000100000005000000EC8A19E1ED354140E69315C3D5AB4E40EC8A19E1ED354140397CD28904AF4E40F5143944DC3C4140397CD28904AF4E40F5143944DC3C4140E69315C3D5AB4E40EC8A19E1ED354140E69315C3D5AB4E40
59209	26128	34.590843	34.694302	61.371071999999998	61.346184999999998	Советская	0103000020E61000000100000005000000070951BEA04B4140D1AE42CA4FAC4E40070951BEA04B41400C3B8C497FAF4E4011C64FE3DE5841400C3B8C497FAF4E4011C64FE3DE584140D1AE42CA4FAC4E40070951BEA04B4140D1AE42CA4FAC4E40
59129	26580	34.621071000000001	34.659644999999998	61.629461999999997	61.609037999999998	Набережная	0103000020E610000001000000050000003CBF28417F4F4140B8020AF5F4CD4E403CBF28417F4F41409109F83592D04E4026FC523F6F5441409109F83592D04E4026FC523F6F544140B8020AF5F4CD4E403CBF28417F4F4140B8020AF5F4CD4E40
59312	26558	34.058196000000002	34.103560999999999	61.833354	61.814331000000003	Прионежское шоссе	0103000020E6100000010000000500000007616EF7720741403B8F8AFF3BE84E4007616EF772074140D2FE0758ABEA4E400E12A27C410D4140D2FE0758ABEA4E400E12A27C410D41403B8F8AFF3BE84E4007616EF7720741403B8F8AFF3BE84E40
59390	57558	30.722697	32.320791	61.911898000000001	61.213087999999999	Совхозная	0103000020E61000000100000005000000D5EAABAB02B93E40C495B377469B4E40D5EAABAB02B93E40D7A4DB12B9F44E40F2ECF2AD0F294040D7A4DB12B9F44E40F2ECF2AD0F294040C495B377469B4E40D5EAABAB02B93E40C495B377469B4E40
59467	57570	30.722697	32.320791	61.911898000000001	61.213087999999999	Полевая	0103000020E61000000100000005000000D5EAABAB02B93E40C495B377469B4E40D5EAABAB02B93E40D7A4DB12B9F44E40F2ECF2AD0F294040D7A4DB12B9F44E40F2ECF2AD0F294040C495B377469B4E40D5EAABAB02B93E40C495B377469B4E40
59352	57549	30.722697	32.320791	61.911898000000001	61.213087999999999	Ладожская	0103000020E61000000100000005000000D5EAABAB02B93E40C495B377469B4E40D5EAABAB02B93E40D7A4DB12B9F44E40F2ECF2AD0F294040D7A4DB12B9F44E40F2ECF2AD0F294040C495B377469B4E40D5EAABAB02B93E40C495B377469B4E40
59362	57555	30.91826	30.961811000000001	61.820084000000001	61.800879000000002	2-Речная	0103000020E6100000010000000500000097395D1613EB3E40CF86FC3383E64E4097395D1613EB3E4087FC3383F8E84E40DDEEE53E39F63E4087FC3383F8E84E40DDEEE53E39F63E40CF86FC3383E64E4097395D1613EB3E40CF86FC3383E64E40
59374	17675	31.599443999999998	31.608174999999999	61.499184	61.492722000000001	Геологическая	0103000020E610000001000000050000008EC8772975993F408602B68311BF4E408EC8772975993F40DE57E542E5BF4E40AB3E575BB19B3F40DE57E542E5BF4E40AB3E575BB19B3F408602B68311BF4E408EC8772975993F408602B68311BF4E40
59322	1507	31.752884999999999	31.768588000000001	61.352522	61.346184999999998	Свирских дивизий	0103000020E6100000010000000500000022A64412BDC03F40D1AE42CA4FAC4E4022A64412BDC03F406D8FDE701FAD4E401A19E42EC2C43F406D8FDE701FAD4E401A19E42EC2C43F40D1AE42CA4FAC4E4022A64412BDC03F40D1AE42CA4FAC4E40
59375	18081	30.881285999999999	30.906672	61.761907999999998	61.753290999999997	Центральная	0103000020E61000000100000005000000336C94F59BE13E4081AFE8D66BE04E40336C94F59BE13E40C7478B3386E14E40EC32FCA71BE83E40C7478B3386E14E40EC32FCA71BE83E4081AFE8D66BE04E40336C94F59BE13E4081AFE8D66BE04E40
59365	2906	31.864348	31.903721000000001	61.354129999999998	61.333652999999998	Совхозная	0103000020E61000000100000005000000EE5C18E945DD3F402C9B3924B5AA4E40EE5C18E945DD3F402844C02154AD4E405BB56B425AE73F402844C02154AD4E405BB56B425AE73F402C9B3924B5AA4E40EE5C18E945DD3F402C9B3924B5AA4E40
59341	17864	30.992236999999999	31.038805	61.774309000000002	61.752806	Советская	0103000020E6100000010000000500000093E1783E03FE3E40C51D6FF25BE04E4093E1783E03FE3E40CEFFAB8E1CE34E40D9EBDD1FEF093F40CEFFAB8E1CE34E40D9EBDD1FEF093F40C51D6FF25BE04E4093E1783E03FE3E40C51D6FF25BE04E40
59321	17764	31.147241000000001	31.168593999999999	61.680050000000001	61.663181999999999	Советская	0103000020E610000001000000050000005EA10F96B1253F40DFA5D425E3D44E405EA10F96B1253F4089D2DEE00BD74E40444DF4F9282B3F4089D2DEE00BD74E40444DF4F9282B3F40DFA5D425E3D44E405EA10F96B1253F40DFA5D425E3D44E40
59300	25747	32.372264999999999	32.394255000000001	61.187615000000001	61.175150000000002	Привокзальная	0103000020E6100000010000000500000004392861A62F40407CF2B0506B964E4004392861A62F4040999EB0C403984E406AA4A5F276324040999EB0C403984E406AA4A5F2763240407CF2B0506B964E4004392861A62F40407CF2B0506B964E40
59404	25281	32.559472999999997	32.574314000000001	61.121501000000002	61.115748000000004	Мурзанова	0103000020E610000001000000050000005CFFAECF9C474040E94999D4D08E4E405CFFAECF9C47404035B742588D8F4E4046D1031F8349404035B742588D8F4E4046D1031F83494040E94999D4D08E4E405CFFAECF9C474040E94999D4D08E4E40
59128	25533	32.823963999999997	32.856762000000003	61.032196999999996	60.987870999999998	Новая	0103000020E61000000100000005000000698A00A7776940405AD5928E727E4E40698A00A777694040C00303081F844E40503A9160AA6D4040C00303081F844E40503A9160AA6D40405AD5928E727E4E40698A00A7776940405AD5928E727E4E40
59125	24984	32.942964000000003	33.010193999999998	60.988312000000001	60.965333000000001	Урицкого	0103000020E6100000010000000500000016A75A0BB3784040F25F2008907B4E4016A75A0BB3784040471FF301817E4E40C64E78094E814040471FF301817E4E40C64E78094E814040F25F2008907B4E4016A75A0BB3784040F25F2008907B4E40
59433	24984	32.942964000000003	33.010193999999998	60.988312000000001	60.965333000000001	Полевая	0103000020E6100000010000000500000016A75A0BB3784040F25F2008907B4E4016A75A0BB3784040471FF301817E4E40C64E78094E814040471FF301817E4E40C64E78094E814040F25F2008907B4E4016A75A0BB3784040F25F2008907B4E40
59126	24984	32.942964000000003	33.010193999999998	60.988312000000001	60.965333000000001	Красноармейская	0103000020E6100000010000000500000016A75A0BB3784040F25F2008907B4E4016A75A0BB3784040471FF301817E4E40C64E78094E814040471FF301817E4E40C64E78094E814040F25F2008907B4E4016A75A0BB3784040F25F2008907B4E40
59210	24984	32.942964000000003	33.010193999999998	60.988312000000001	60.965333000000001	Карла Маркса	0103000020E6100000010000000500000016A75A0BB3784040F25F2008907B4E4016A75A0BB3784040471FF301817E4E40C64E78094E814040471FF301817E4E40C64E78094E814040F25F2008907B4E4016A75A0BB3784040F25F2008907B4E40
59386	46789	33.723025	33.772280000000002	61.019013000000001	60.999471999999997	Новая	0103000020E610000001000000050000005F984C158CDC404044A2D0B2EE7F4E405F984C158CDC404074999A046F824E406DAD2F12DAE2404074999A046F824E406DAD2F12DAE2404044A2D0B2EE7F4E405F984C158CDC404044A2D0B2EE7F4E40
59317	26102	33.07658	33.122276999999997	60.940721000000003	60.923642000000001	Школьный пер	0103000020E610000001000000050000008BC3995FCD894040249BABE639764E408BC3995FCD89404089D4B48B69784E40C806D2C5A68F404089D4B48B69784E40C806D2C5A68F4040249BABE639764E408BC3995FCD894040249BABE639764E40
59349	26015	33.197555999999999	33.230415999999998	61.002516999999997	60.985374999999998	Ленина	0103000020E610000001000000050000007590D78349994040E3A59BC4207E4E407590D783499940408E57207A52804E40D13C80457E9D40408E57207A52804E40D13C80457E9D4040E3A59BC4207E4E407590D78349994040E3A59BC4207E4E40
59299	25894	33.172798	33.222116	61.294024999999998	61.254860999999998	Олонецкая	0103000020E610000001000000050000003868AF3E1E9640404F0306499FA04E403868AF3E1E9640406B9A779CA2A54E408CF50D4C6E9C40406B9A779CA2A54E408CF50D4C6E9C40404F0306499FA04E403868AF3E1E9640404F0306499FA04E40
59363	25874	33.013958000000002	33.031402999999997	61.145356	61.137461999999999	60-летия Великого Октября	0103000020E6100000010000000500000040C23060C9814040AC38D55A98914E4040C23060C9814040812381069B924E4086FF740305844040812381069B924E4086FF740305844040AC38D55A98914E4040C23060C9814040AC38D55A98914E40
59307	32716	32.650446000000002	32.724080999999998	61.023052999999997	60.999690000000001	Леселидзе	0103000020E6100000010000000500000032E884D041534040B21188D7F57F4E4032E884D0415340408F899466F3824E40D653ABAFAE5C40408F899466F3824E40D653ABAFAE5C4040B21188D7F57F4E4032E884D041534040B21188D7F57F4E40
59166	32716	32.650446000000002	32.724080999999998	61.023052999999997	60.999690000000001	Заводская	0103000020E6100000010000000500000032E884D041534040B21188D7F57F4E4032E884D0415340408F899466F3824E40D653ABAFAE5C40408F899466F3824E40D653ABAFAE5C4040B21188D7F57F4E4032E884D041534040B21188D7F57F4E40
59211	25579	32.378686999999999	32.420028000000002	61.208151999999998	61.181156999999999	Школьная	0103000020E61000000100000005000000CE35CCD07830404082380F2730974E40CE35CCD0783040406A4C88B9A49A4E40C0B33D7AC33540406A4C88B9A49A4E40C0B33D7AC335404082380F2730974E40CE35CCD07830404082380F2730974E40
59434	25967	33.242030999999997	33.258901999999999	61.463006	61.455810999999997	Школьная	0103000020E6100000010000000500000020CF2EDFFA9E40401A14CD0358BA4E4020CF2EDFFA9E404007EDD5C743BB4E403B6F63B323A1404007EDD5C743BB4E403B6F63B323A140401A14CD0358BA4E4020CF2EDFFA9E40401A14CD0358BA4E40
59428	24537	32.014491999999997	32.034956000000001	63.254196	63.248375000000003	Первомайская	0103000020E61000000100000005000000DD06B5DFDA0140406F1283C0CA9F4F40DD06B5DFDA0140401363997E89A04F4045662E70790440401363997E89A04F4045662E70790440406F1283C0CA9F4F40DD06B5DFDA0140406F1283C0CA9F4F40
59431	24855	32.395172000000002	32.432702999999997	64.121804999999995	64.101417999999995	Школьная	0103000020E61000000100000005000000C02500FF94324040724EECA17D065040C02500FF9432404050DF32A7CB075040C7F0D8CF6237404050DF32A7CB075040C7F0D8CF62374040724EECA17D065040C02500FF94324040724EECA17D065040
59122	24386	32.299249000000003	32.363155999999996	63.176941999999997	63.162581000000003	Советская	0103000020E610000001000000050000002C2E8ECA4D264040BAF94674CF944F402C2E8ECA4D264040F8A41309A6964F404FAC53E57B2E4040F8A41309A6964F404FAC53E57B2E4040BAF94674CF944F402C2E8ECA4D264040BAF94674CF944F40
59329	24924	32.767910000000001	32.793368000000001	64.090781000000007	64.073875999999998	Еремеева	0103000020E61000000100000005000000BC22F8DF4A62404065FD6662BA045040BC22F8DF4A62404049861C5BCF055040B2D826158D65404049861C5BCF055040B2D826158D65404065FD6662BA045040BC22F8DF4A62404065FD6662BA045040
59346	24797	30.760956	30.835436000000001	63.845984999999999	63.820217999999997	Моккиева	0103000020E61000000100000005000000EAB12D03CEC23E4096CB46E7FCE84F40EAB12D03CEC23E400AF4893C49EC4F40ACE63922DFD53E400AF4893C49EC4F40ACE63922DFD53E4096CB46E7FCE84F40EAB12D03CEC23E4096CB46E7FCE84F40
59340	24352	32.030096	32.084812999999997	63.559766000000003	63.530079999999998	Ленина	0103000020E61000000100000005000000C6DE8B2FDA034040C02154A9D9C34F40C6DE8B2FDA034040D5B48B69A6C74F4048A30227DB0A4040D5B48B69A6C74F4048A30227DB0A4040C02154A9D9C34F40C6DE8B2FDA034040C02154A9D9C34F40
59399	24447	33.099532000000004	33.124333999999998	63.880873999999999	63.870271000000002	Рабочая	0103000020E61000000100000005000000E773EE76BD8C404020D4450A65EF4F40E773EE76BD8C4040C7F2AE7AC0F04F40F3E32F2DEA8F4040C7F2AE7AC0F04F40F3E32F2DEA8F404020D4450A65EF4F40E773EE76BD8C404020D4450A65EF4F40
59162	24209	31.971903000000001	32.014924000000001	63.971159999999998	63.953949000000001	Октябрьская	0103000020E6100000010000000500000061E28FA2CEF83F40A58636001BFA4F4061E28FA2CEF83F4078978BF84EFC4F4077F69507E901404078978BF84EFC4F4077F69507E9014040A58636001BFA4F4061E28FA2CEF83F40A58636001BFA4F40
59361	24621	31.707951000000001	31.737397999999999	63.295067000000003	63.288687000000003	Комсомольская	0103000020E61000000100000005000000A62BD8463CB53F40E3E313B2F3A44F40A62BD8463CB53F407E9065C1C4A54F40C422861DC6BC3F407E9065C1C4A54F40C422861DC6BC3F40E3E313B2F3A44F40A62BD8463CB53F40E3E313B2F3A44F40
59204	24637	31.156610000000001	31.284026999999998	63.432537000000004	63.390968000000001	Первомайская	0103000020E61000000100000005000000003ACC9717283F402AE44A3D0BB24F40003ACC9717283F40ADA7565F5DB74F40552E54FEB5483F40ADA7565F5DB74F40552E54FEB5483F402AE44A3D0BB24F40003ACC9717283F402AE44A3D0BB24F40
59207	24877	32.014761999999997	32.043318999999997	64.260223999999994	64.243393999999995	50 лет ВЛКСМ	0103000020E610000001000000050000009D9CA1B8E3014040BA826DC4930F50409D9CA1B8E301404098689082A7105040D0251C7A8B05404098689082A7105040D0251C7A8B054040BA826DC4930F50409D9CA1B8E3014040BA826DC4930F5040
59415	24755	31.031061999999999	31.056080000000001	63.647959999999998	63.640600999999997	Советская	0103000020E61000000100000005000000FA25E2ADF3073F407764AC36FFD14F40FA25E2ADF3073F40DE8E705AF0D24F40AEF545425B0E3F40DE8E705AF0D24F40AEF545425B0E3F407764AC36FFD14F40FA25E2ADF3073F407764AC36FFD14F40
59416	24521	32.517136000000001	32.546565000000001	62.942297000000003	62.929333999999997	Ленина	0103000020E61000000100000005000000C9CA2F8331424040CA87A06AF4764F40C9CA2F8331424040390F27309D784F40B21188D7F5454040390F27309D784F40B21188D7F5454040CA87A06AF4764F40C9CA2F8331424040CA87A06AF4764F40
59105	24298	31.907198000000001	31.951377000000001	63.749757000000002	63.738447999999998	23 съезда	0103000020E6100000010000000500000022FFCC203EE83F40F7E5CC7685DE4F4022FFCC203EE83F403A799109F8DF4F40A62A6D718DF33F403A799109F8DF4F40A62A6D718DF33F40F7E5CC7685DE4F4022FFCC203EE83F40F7E5CC7685DE4F40
59311	32581	34.920820999999997	34.953906000000003	62.601016000000001	62.584867000000003	Совхозная	0103000020E61000000100000005000000293C6876DD7541403CC1FEEBDC4A4F40293C6876DD754140B62FA017EE4C4F40A6BA8097197A4140B62FA017EE4C4F40A6BA8097197A41403CC1FEEBDC4A4F40293C6876DD7541403CC1FEEBDC4A4F40
59360	23765	33.242885000000001	33.292993000000003	63.542960000000001	63.507505999999999	Советская	0103000020E6100000010000000500000030D80DDB169F40400B43E4F4F5C04F4030D80DDB169F4040A18499B67FC54F407D7A6CCB80A54040A18499B67FC54F407D7A6CCB80A540400B43E4F4F5C04F4030D80DDB169F40400B43E4F4F5C04F40
59351	23542	35.573258000000003	35.608302000000002	62.594175999999997	62.576619000000001	Гагарина	0103000020E61000000100000005000000CF15A58460C9414049A0C1A6CE494F40CF15A58460C94140B7088CF50D4C4F40B30B06D7DCCD4140B7088CF50D4C4F40B30B06D7DCCD414049A0C1A6CE494F40CF15A58460C9414049A0C1A6CE494F40
59358	23630	34.144900999999997	34.163972000000001	62.917619000000002	62.909337000000001	Центральная	0103000020E610000001000000050000002F14B01D8C1241407905A22765744F402F14B01D8C1241401898158A74754F40D8BAD408FD1441401898158A74754F40D8BAD408FD1441407905A22765744F402F14B01D8C1241407905A22765744F40
59102	23981	35.269888000000002	35.312828000000003	62.517829999999996	62.498026000000003	Гористая	0103000020E610000001000000050000009BCAA2B08BA241406347E350BF3F4F409BCAA2B08BA241409F71E14048424F40F5A276BF0AA841409F71E14048424F40F5A276BF0AA841406347E350BF3F4F409BCAA2B08BA241406347E350BF3F4F40
59430	57562	35.482788999999997	35.697073000000003	62.980986000000001	62.910074999999999	Конституции	0103000020E610000001000000050000002CEFAA07CCBD41401FF46C567D744F402CEFAA07CCBD4140BCEA01F3907D4F405AF624B039D94140BCEA01F3907D4F405AF624B039D941401FF46C567D744F402CEFAA07CCBD41401FF46C567D744F40
59413	45696	36.001035999999999	36.028281999999997	62.908738999999997	62.897049000000003	Гагарина	0103000020E61000000100000005000000300F99F2210042406BF46A80D2724F40300F99F221004240C4CC3E8F51744F4061889CBE9E034240C4CC3E8F51744F4061889CBE9E0342406BF46A80D2724F40300F99F2210042406BF46A80D2724F40
59164	23185	34.807813000000003	34.857238000000002	62.885739000000001	62.834764999999997	Копейкина	0103000020E610000001000000050000004F24986A66674140376C5B94D96A4F404F24986A6667414058E542E55F714F40B9718BF9B96D414058E542E55F714F40B9718BF9B96D4140376C5B94D96A4F404F24986A66674140376C5B94D96A4F40
59100	23058	34.560685999999997	34.590313000000002	62.9435	62.911212999999996	Ленина	0103000020E610000001000000050000009BA9108FC44741405358A9A0A2744F409BA9108FC447414054E3A59BC4784F40ABB35A608F4B414054E3A59BC4784F40ABB35A608F4B41405358A9A0A2744F409BA9108FC44741405358A9A0A2744F40
59205	23058	34.560685999999997	34.590313000000002	62.9435	62.911212999999996	Конституции	0103000020E610000001000000050000009BA9108FC44741405358A9A0A2744F409BA9108FC447414054E3A59BC4784F40ABB35A608F4B414054E3A59BC4784F40ABB35A608F4B41405358A9A0A2744F409BA9108FC44741405358A9A0A2744F40
59123	23706	33.394933999999999	33.429167999999997	63.297176999999998	63.279029999999999	Гористая	0103000020E610000001000000050000000B0A83328DB240402B4D4A41B7A34F400B0A83328DB24040CB0F5CE509A64F40AF3E1EFAEEB64040CB0F5CE509A64F40AF3E1EFAEEB640402B4D4A41B7A34F400B0A83328DB240402B4D4A41B7A34F40
59410	45647	35.693866	35.717995000000002	63.018059999999998	63.006022000000002	Центральная	0103000020E6100000010000000500000036E7E099D0D841403C873254C5804F4036E7E099D0D84140D1AE42CA4F824F4084D89942E7DB4140D1AE42CA4F824F4084D89942E7DB41403C873254C5804F4036E7E099D0D841403C873254C5804F40
59425	23334	35.074002	35.095354999999998	62.814731999999999	62.794649	Дорожная	0103000020E6100000010000000500000057EBC4E5788941404966F50EB7654F4057EBC4E57889414099805F2349684F404A41B797348C414099805F2349684F404A41B797348C41404966F50EB7654F4057EBC4E5788941404966F50EB7654F40
59097	22739	34.397587999999999	34.514341999999999	62.943748999999997	62.891162999999999	К.Либкнехта	0103000020E610000001000000050000001AA4E029E4324140DF3312A111724F401AA4E029E4324140FC5069C4CC784F40C87A6AF5D5414140FC5069C4CC784F40C87A6AF5D5414140DF3312A111724F401AA4E029E4324140DF3312A111724F40
59402	23816	32.845461	32.857534000000001	63.532586000000002	63.526302999999999	Школьная	0103000020E610000001000000050000009085E810386C4040B2648EE55DC34F409085E810386C40405B272EC72BC44F40A29A92ACC36D40405B272EC72BC44F40A29A92ACC36D4040B2648EE55DC34F409085E810386C4040B2648EE55DC34F40
59295	23161	34.515672000000002	34.589962	62.931126999999996	62.900213000000001	Совхозная	0103000020E6100000010000000500000041BB438A014241408F37F92D3A734F4041BB438A0142414017B6662B2F774F40FEF0F3DF834B414017B6662B2F774F40FEF0F3DF834B41408F37F92D3A734F4041BB438A014241408F37F92D3A734F40
59336	24138	34.865690999999998	34.885705999999999	62.294696999999999	62.280878000000001	Школьная	0103000020E6100000010000000500000084B872F6CE6E41403C1570CFF3234F4084B872F6CE6E41405A9D9CA1B8254F407CEF6FD05E7141405A9D9CA1B8254F407CEF6FD05E7141403C1570CFF3234F4084B872F6CE6E41403C1570CFF3234F40
59429	23688	33.794620999999999	33.814411	62.958917999999997	62.945647999999998	Лесная	0103000020E610000001000000050000007FDB1324B6E540408FC360FE0A794F407FDB1324B6E54040DAC534D3BD7A4F405740A19E3EE84040DAC534D3BD7A4F405740A19E3EE840408FC360FE0A794F407FDB1324B6E540408FC360FE0A794F40
59426	23391	35.406413999999998	35.425189000000003	62.777023999999997	62.768908000000003	Центральная	0103000020E610000001000000050000007A51BB5F05B44140FFD0CC936B624F407A51BB5F05B44140821ABE8575634F403ACFD8976CB64140821ABE8575634F403ACFD8976CB64140FFD0CC936B624F407A51BB5F05B44140FFD0CC936B624F40
59427	45864	35.209449999999997	35.220292000000001	62.361500999999997	62.354852999999999	Ригачина	0103000020E61000000100000005000000D712F241CF9A414099F1B6D26B2D4F40D712F241CF9A4140533C2EAA452E4F4004C93B87329C4140533C2EAA452E4F4004C93B87329C414099F1B6D26B2D4F40D712F241CF9A414099F1B6D26B2D4F40
59124	24082	35.058630999999998	35.093414000000003	62.259923999999998	62.236761999999999	Рябова	0103000020E6100000010000000500000011C4793881874140C0779B374E1E4F4011C479388187414006B98B3045214F40897E6DFDF48B414006B98B3045214F40897E6DFDF48B4140C0779B374E1E4F4011C4793881874140C0779B374E1E4F40
59292	22105	33.918956999999999	33.951754000000001	65.797479999999993	65.780861999999999	Советская	0103000020E6100000010000000500000013B70A62A0F540401B2C9CA4F971504013B70A62A0F54040B3CD8DE90973504029EB3713D3F94040B3CD8DE90973504029EB3713D3F940401B2C9CA4F971504013B70A62A0F540401B2C9CA4F9715040
59219	57543	32.956851999999998	33.095435000000002	66.279740000000004	66.259125999999995	Пионерская	0103000020E610000001000000050000005C8E57207A7A4040C5E23785959050405C8E57207A7A404084D89942E791504067F2CD36378C404084D89942E791504067F2CD36378C4040C5E23785959050405C8E57207A7A4040C5E2378595905040
59319	57543	32.956851999999998	33.095435000000002	66.279740000000004	66.259125999999995	Коргуева	0103000020E610000001000000050000005C8E57207A7A4040C5E23785959050405C8E57207A7A404084D89942E791504067F2CD36378C404084D89942E791504067F2CD36378C4040C5E23785959050405C8E57207A7A4040C5E2378595905040
59422	49502	33.384208000000001	33.398069	66.298978000000005	66.295413999999994	Набережная	0103000020E61000000100000005000000486E4DBA2DB14040F4311F10E8925040486E4DBA2DB140404E0E9F74229350409546CCECF3B240404E0E9F74229350409546CCECF3B24040F4311F10E8925040486E4DBA2DB14040F4311F10E8925040
59401	22725	33.272978000000002	33.303745999999997	66.361288999999999	66.348585999999997	Новая	0103000020E6100000010000000500000085436FF1F0A24040FB75A73B4F96504085436FF1F0A24040E4D9E55B1F97504039252026E1A64040E4D9E55B1F97504039252026E1A64040FB75A73B4F96504085436FF1F0A24040FB75A73B4F965040
59424	22462	32.733530999999999	32.758620999999998	66.471562000000006	66.462835999999996	Слюдяная	0103000020E6100000010000000500000014CD0358E45D404055DAE21A9F9D504014CD0358E45D4040540262122E9E50408787307E1A614040540262122E9E50408787307E1A61404055DAE21A9F9D504014CD0358E45D404055DAE21A9F9D5040
59382	22199	31.290261999999998	31.312467999999999	65.756139000000005	65.749823000000006	Комсомольская	0103000020E610000001000000050000008445459C4E4A3F4079B29B19FD6F50408445459C4E4A3F40BB0ED59464705040E90B21E7FD4F3F40BB0ED59464705040E90B21E7FD4F3F4079B29B19FD6F50408445459C4E4A3F4079B29B19FD6F5040
59421	22276	31.395220999999999	31.436696000000001	65.808505999999994	65.797421	Центральная	0103000020E6100000010000000500000042B115342D653F40310917F20873504042B115342D653F40AA27F38FBE735040454B1E4FCB6F3F40AA27F38FBE735040454B1E4FCB6F3F40310917F20873504042B115342D653F40310917F208735040
59310	57548	32.307523000000003	32.330897	66.003647999999998	65.997073999999998	Школьная	0103000020E6100000010000000500000048E2E5E95C274040486C770FD07F504048E2E5E95C274040882CD2C43B80504019AC38D55A2A4040882CD2C43B80504019AC38D55A2A4040486C770FD07F504048E2E5E95C274040486C770FD07F5040
59120	22183	31.053843000000001	31.100735	65.770205000000004	65.758543000000003	Дружбы	0103000020E61000000100000005000000581EA4A7C80D3F400667F0F78B705040581EA4A7C80D3F40CE8DE9094B7150400490DAC4C9193F40CE8DE9094B7150400490DAC4C9193F400667F0F78B705040581EA4A7C80D3F400667F0F78B705040
59383	49509	33.339274000000003	33.376491000000001	66.201678000000001	66.193612999999999	Клубная	0103000020E610000001000000050000000A3197546DAB404026C5C727648C50400A3197546DAB4040A794D74AE88C5040821E6ADB30B04040A794D74AE88C5040821E6ADB30B0404026C5C727648C50400A3197546DAB404026C5C727648C5040
59445	20276	33.184556999999998	33.223292000000001	66.303999000000005	66.288781999999998	Слюдяная	0103000020E61000000100000005000000BA9F53909F9740401A6B7F677B925040BA9F53909F97404012C138B874935040AEBA0ED5949C404012C138B874935040AEBA0ED5949C40401A6B7F677B925040BA9F53909F9740401A6B7F677B925040
59117	21975	32.932336999999997	33.078071000000001	66.082099999999997	66.063074999999998	Советская	0103000020E61000000100000005000000E5EC9DD1567740407E8CB96B09845040E5EC9DD1567740401AC05B20418550400DE2033BFE8940401AC05B20418550400DE2033BFE8940407E8CB96B09845040E5EC9DD1567740407E8CB96B09845040
59159	21975	32.932336999999997	33.078071000000001	66.082099999999997	66.063074999999998	Железнодорожная	0103000020E61000000100000005000000E5EC9DD1567740407E8CB96B09845040E5EC9DD1567740401AC05B20418550400DE2033BFE8940401AC05B20418550400DE2033BFE8940407E8CB96B09845040E5EC9DD1567740407E8CB96B09845040
59304	21975	32.932336999999997	33.078071000000001	66.082099999999997	66.063074999999998	Дачный переулок	0103000020E61000000100000005000000E5EC9DD1567740407E8CB96B09845040E5EC9DD1567740401AC05B20418550400DE2033BFE8940401AC05B20418550400DE2033BFE8940407E8CB96B09845040E5EC9DD1567740407E8CB96B09845040
59095	22329	31.790694999999999	31.877832000000001	65.902685000000005	65.88167	Набережная	0103000020E61000000100000005000000581CCEFC6ACA3F4051F701486D785040581CCEFC6ACA3F40BF654E97C5795040DD611399B9E03F40BF654E97C5795040DD611399B9E03F4051F701486D785040581CCEFC6ACA3F4051F701486D785040
59318	22124	33.696705000000001	33.737461000000003	65.902916000000005	65.891035000000002	Ленина	0103000020E61000000100000005000000D7FA22A12DD94040D925AAB706795040D7FA22A12DD9404040C23060C9795040A9893E1F65DE404040C23060C9795040A9893E1F65DE4040D925AAB706795040D7FA22A12DD94040D925AAB706795040
59411	21408	29.731145999999999	29.750594	61.412329	61.400509999999997	Центральная	0103000020E61000000100000005000000E9995E622CBB3D4048DC63E943B34E40E9995E622CBB3D40A0185932C7B44E40E692AAED26C03D40A0185932C7B44E40E692AAED26C03D4048DC63E943B34E40E9995E622CBB3D4048DC63E943B34E40
59331	21372	29.7501	29.800532	61.419057000000002	61.400509999999997	Петровского	0103000020E61000000100000005000000C7BAB88D06C03D4048DC63E943B34E40C7BAB88D06C03D407714E7A8A3B54E40C76647AAEFCC3D407714E7A8A3B54E40C76647AAEFCC3D4048DC63E943B34E40C7BAB88D06C03D4048DC63E943B34E40
59357	21721	30.096122000000001	30.106263999999999	61.397590000000001	61.392003000000003	Центральная	0103000020E61000000100000005000000166D8E739B183E408A7780272DB24E40166D8E739B183E40BB9BA73AE4B24E40FDBD141E341B3E40BB9BA73AE4B24E40FDBD141E341B3E408A7780272DB24E40166D8E739B183E408A7780272DB24E40
59290	21801	29.667822999999999	29.712226999999999	61.250118000000001	61.227879999999999	Ленина	0103000020E610000001000000050000004084B872F6AA3D40CCB4FD2B2B9D4E404084B872F6AA3D400A12DBDD03A04E400454388254B63D400A12DBDD03A04E400454388254B63D40CCB4FD2B2B9D4E404084B872F6AA3D40CCB4FD2B2B9D4E40
59381	21855	29.530398999999999	29.555309000000001	61.321679000000003	61.308709999999998	Правды	0103000020E61000000100000005000000C3D4963AC8873D405DF92CCF83A74E40C3D4963AC8873D40AE6708C72CA94E40AA2C0ABB288E3D40AE6708C72CA94E40AA2C0ABB288E3D405DF92CCF83A74E40C3D4963AC8873D405DF92CCF83A74E40
59359	21879	29.855895	29.872945000000001	61.219954000000001	61.212186000000003	Солнечная	0103000020E6100000010000000500000057CF49EF1BDB3D40A4552DE9289B4E4057CF49EF1BDB3D40EC4FE273279C4E40EC34D25279DF3D40EC4FE273279C4E40EC34D25279DF3D40A4552DE9289B4E4057CF49EF1BDB3D40A4552DE9289B4E40
59398	21713	30.105905	30.121616	61.314419999999998	61.309880999999997	Школьная	0103000020E610000001000000050000009E7B0F971C1B3E406D533C2EAAA74E409E7B0F971C1B3E40AA9A20EA3EA84E409BABE639221F3E40AA9A20EA3EA84E409BABE639221F3E406D533C2EAAA74E409E7B0F971C1B3E406D533C2EAAA74E40
59377	21317	30.212706000000001	30.228166000000002	61.537827	61.529302000000001	Центральная	0103000020E61000000100000005000000B9A981E673363E408CDAFD2AC0C34E40B9A981E673363E40F1F3DF83D7C44E40240F4416693A3E40F1F3DF83D7C44E40240F4416693A3E408CDAFD2AC0C34E40B9A981E673363E408CDAFD2AC0C34E40
59453	21155	30.305537000000001	30.330825000000001	61.557279000000001	61.547258999999997	Школьная	0103000020E61000000100000005000000CCB73EAC374E3E4088B839950CC64E40CCB73EAC374E3E40B1DF13EB54C74E40FFB27BF2B0543E40B1DF13EB54C74E40FFB27BF2B0543E4088B839950CC64E40CCB73EAC374E3E4088B839950CC64E40
59448	21242	30.139313000000001	30.151817999999999	61.446699000000002	61.431213999999997	Центральная	0103000020E610000001000000050000005CE84A04AA233E40E6C9350532B74E405CE84A04AA233E40F513CE6E2DB94E40B2F1608BDD263E40F513CE6E2DB94E40B2F1608BDD263E40E6C9350532B74E405CE84A04AA233E40E6C9350532B74E40
59093	20760	30.132100000000001	30.223521000000002	61.554588000000003	61.501043000000003	Трубачева	0103000020E6100000010000000500000036CD3B4ED1213E40E371512D22C04E4036CD3B4ED1213E40856055BDFCC64E401FF818AC38393E40856055BDFCC64E401FF818AC38393E40E371512D22C04E4036CD3B4ED1213E40E371512D22C04E40
59407	21614	29.841422999999999	29.863727999999998	61.273300999999996	61.268098000000002	Ленинградская	0103000020E610000001000000050000002A1A6B7F67D73D40BF0F070951A24E402A1A6B7F67D73D40677BF486FBA24E40B5A338471DDD3D40677BF486FBA24E40B5A338471DDD3D40BF0F070951A24E402A1A6B7F67D73D40BF0F070951A24E40
59335	21553	29.864374999999999	29.903756999999999	61.311073	61.293753000000002	Ленина	0103000020E61000000100000005000000E17A14AE47DD3D400B0DC4B299A54E40E17A14AE47DD3D4095D5743DD1A74E40F487669E5CE73D4095D5743DD1A74E40F487669E5CE73D400B0DC4B299A54E40E17A14AE47DD3D400B0DC4B299A54E40
59380	21954	29.718658999999999	29.765165	61.207286000000003	61.183998000000003	Ленина	0103000020E61000000100000005000000DFF94509FAB73D40C443183F8D974E40DFF94509FAB73D409775FF58889A4E40390B7BDAE1C33D409775FF58889A4E40390B7BDAE1C33D40C443183F8D974E40DFF94509FAB73D40C443183F8D974E40
59325	21261	29.988925999999999	30.013180999999999	61.504215000000002	61.492907000000002	Центральная	0103000020E61000000100000005000000022A1C412AFD3D40187C9A9317BF4E40022A1C412AFD3D408A93FB1D8AC04E40B7ED7BD45F033E408A93FB1D8AC04E40B7ED7BD45F033E40187C9A9317BF4E40022A1C412AFD3D40187C9A9317BF4E40
59423	21458	29.817698	29.830400999999998	61.442343000000001	61.435172000000001	Зеленая	0103000020E610000001000000050000002E01F8A754D13D40451152B7B3B74E402E01F8A754D13D40A94E07B29EB84E40D190F12895D43D40A94E07B29EB84E40D190F12895D43D40451152B7B3B74E402E01F8A754D13D40451152B7B3B74E40
59406	21627	29.710574000000001	29.737748	61.327942999999998	61.312657999999999	Лесная	0103000020E610000001000000050000004E637B2DE8B53D40986A662D05A84E404E637B2DE8B53D40DFF94509FAA94E407DB08C0DDDBC3D40DFF94509FAA94E407DB08C0DDDBC3D40986A662D05A84E404E637B2DE8B53D40986A662D05A84E40
59405	1210	34.351782999999998	34.477888999999998	62.742902000000001	62.588408000000001	Заречная	0103000020E61000000100000005000000F624B039072D4140365A0EF4504B4F40F624B039072D41400611A969175F4F401F0F7D772B3D41400611A969175F4F401F0F7D772B3D4140365A0EF4504B4F40F624B039072D4140365A0EF4504B4F40
59178	24	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Строительная	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59163	24	34.213200000000001	34.313236000000003	62.233431000000003	62.160601999999997	Пролетарская	0103000020E61000000100000005000000ECC039234A1B41400AD6389B8E144F40ECC039234A1B4140B16F2711E11D4F4006F7031E18284140B16F2711E11D4F4006F7031E182841400AD6389B8E144F40ECC039234A1B41400AD6389B8E144F40
59091	20488	34.738686999999999	34.76455	64.989085000000003	64.978131000000005	Советская	0103000020E610000001000000050000007C7DAD4B8D5E41400B0DC4B2993E50407C7DAD4B8D5E4140B5FD2B2B4D3F504012143FC6DC614140B5FD2B2B4D3F504012143FC6DC6141400B0DC4B2993E50407C7DAD4B8D5E41400B0DC4B2993E5040
59457	20600	32.853527999999997	32.909447999999998	64.977401	64.967975999999993	Ленина	0103000020E61000000100000005000000321CCF67406D404006D49B51F33D5040321CCF67406D4040F984ECBC8D3E5040D0B4C4CA68744040F984ECBC8D3E5040D0B4C4CA6874404006D49B51F33D5040321CCF67406D404006D49B51F33D5040
59368	3156	34.220278999999998	34.271743000000001	65.367529000000005	65.352058	Вокзальная	0103000020E610000001000000050000006F7F2E1A321C4140E412471E885650406F7F2E1A321C414039D55A98855750405EF58079C822414039D55A98855750405EF58079C8224140E412471E885650406F7F2E1A321C4140E412471E88565040
59144	20554	33.650019	33.657663999999997	65.036647000000002	65.034649999999999	Кольцевая	0103000020E61000000100000005000000AA6395D233D340409C33A2B437425040AA6395D233D34040C79FA86C58425040D6E07D552ED44040C79FA86C58425040D6E07D552ED440409C33A2B437425040AA6395D233D340409C33A2B437425040
59393	3106	34.527943	34.661935	64.965517000000006	64.941023000000001	шоссе 1 Мая	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59200	3106	34.527943	34.661935	64.965517000000006	64.941023000000001	пр. Пролетарский	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59146	3106	34.527943	34.661935	64.965517000000006	64.941023000000001	Пролетарский пр	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59188	3106	34.527943	34.661935	64.965517000000006	64.941023000000001	Октябрьская	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59090	3106	34.527943	34.661935	64.965517000000006	64.941023000000001	Каменева	0103000020E610000001000000050000007993DFA2934341402A7288B8393C50407993DFA293434140DAAED007CB3D5040F4893C49BA544140DAAED007CB3D5040F4893C49BA5441402A7288B8393C50407993DFA2934341402A7288B8393C5040
59447	57567	34.627808000000002	34.662061000000001	64.948328000000004	64.944157000000004	Ломоносова	0103000020E61000000100000005000000661536035C50414087527B116D3C5040661536035C5041406478EC67B13C5040817A336ABE5441406478EC67B13C5040817A336ABE54414087527B116D3C5040661536035C50414087527B116D3C5040
59328	57550	34.685488999999997	34.726506000000001	64.975246999999996	64.962970999999996	Ручьевая	0103000020E610000001000000050000004562821ABE574140C5FF1D51A13D50404562821ABE5741406AA164726A3E5040842C0B26FE5C41406AA164726A3E5040842C0B26FE5C4140C5FF1D51A13D50404562821ABE574140C5FF1D51A13D5040
59460	1747	32.090463	32.229512999999997	64.781853999999996	64.738462999999996	Советская	0103000020E61000000100000005000000C03FA54A940B4040969350FA422F5040C03FA54A940B4040CB0F5CE509325040E08096AE601D4040CB0F5CE509325040E08096AE601D4040969350FA422F5040C03FA54A940B4040969350FA422F5040
59458	57568	31.548760999999999	31.582636000000001	65.062642999999994	65.052887999999996	Советская	0103000020E61000000100000005000000FC51D4997B8C3F407496598462435040FC51D4997B8C3F40B114C95702445040E67805A227953F40B114C95702445040E67805A227953F407496598462435040FC51D4997B8C3F407496598462435040
59376	1744	31.453405	31.482771	65.176777000000001	65.169666000000007	Набережная	0103000020E61000000100000005000000C7D79E5912743F40904FC8CEDB4A5040C7D79E5912743F40D76B7A50504B50400C7558E1967B3F40D76B7A50504B50400C7558E1967B3F40904FC8CEDB4A5040C7D79E5912743F40904FC8CEDB4A5040
59442	19734	32.151916999999997	32.182997999999998	65.158147999999997	65.148391000000004	Карельская	0103000020E610000001000000050000006C5A2904721340405401F73C7F4950406C5A29047213404061FBC9181F4A5040E09D7C7A6C17404061FBC9181F4A5040E09D7C7A6C1740405401F73C7F4950406C5A2904721340405401F73C7F495040
59194	2777	31.135949	31.226203000000002	65.216735999999997	65.182319000000007	Советская	0103000020E6100000010000000500000085ECBC8DCD223F40209C4F1DAB4B504085ECBC8DCD223F406AF7AB00DF4D5040D1419770E8393F406AF7AB00DF4D5040D1419770E8393F40209C4F1DAB4B504085ECBC8DCD223F40209C4F1DAB4B5040
59186	2777	31.135949	31.226203000000002	65.216735999999997	65.182319000000007	Ленина	0103000020E6100000010000000500000085ECBC8DCD223F40209C4F1DAB4B504085ECBC8DCD223F406AF7AB00DF4D5040D1419770E8393F406AF7AB00DF4D5040D1419770E8393F40209C4F1DAB4B504085ECBC8DCD223F40209C4F1DAB4B5040
59089	2788	32.214995999999999	32.253678000000001	64.626386999999994	64.599552000000003	Советская	0103000020E61000000100000005000000AA622AFD841B404017105A0F5F265040AA622AFD841B4040EEE87FB9162850407BDB4C8578204040EEE87FB9162850407BDB4C857820404017105A0F5F265040AA622AFD841B404017105A0F5F265040
59403	19331	34.654353999999998	34.722940000000001	64.755341999999999	64.738420000000005	Советская	0103000020E61000000100000005000000DE0033DFC153414097ADF545422F5040DE0033DFC1534140E5D2F88557305040317C444C895C4140E5D2F88557305040317C444C895C414097ADF545422F5040DE0033DFC153414097ADF545422F5040
59441	48471	35.177461000000001	35.198453999999998	64.046681000000007	64.032749999999993	Набережная	0103000020E6100000010000000500000061A8C30AB79641406ABC74931802504061A8C30AB79641400E164ED2FC02504054E1CFF0669941400E164ED2FC02504054E1CFF0669941406ABC74931802504061A8C30AB79641406ABC749318025040
59412	18870	35.381270000000001	35.429582000000003	64.261652999999995	64.223094000000003	Школьная	0103000020E6100000010000000500000014799274CDB04140C47B0E2C470E504014799274CDB041409E7939ECBE105040A379008BFCB641409E7939ECBE105040A379008BFCB64140C47B0E2C470E504014799274CDB04140C47B0E2C470E5040
59397	18870	35.381270000000001	35.429582000000003	64.261652999999995	64.223094000000003	Набережная	0103000020E6100000010000000500000014799274CDB04140C47B0E2C470E504014799274CDB041409E7939ECBE105040A379008BFCB641409E7939ECBE105040A379008BFCB64140C47B0E2C470E504014799274CDB04140C47B0E2C470E5040
59183	48524	34.446097000000002	34.506410000000002	64.437353000000002	64.413330000000002	Кирова	0103000020E61000000100000005000000FFEBDCB4193941402A1DACFF731A5040FFEBDCB419394140AEF36F97FD1B5040062FFA0AD2404140AEF36F97FD1B5040062FFA0AD24041402A1DACFF731A5040FFEBDCB4193941402A1DACFF731A5040
59366	48517	34.130671999999997	34.154522	64.404779000000005	64.396721999999997	Пионерская	0103000020E610000001000000050000005F402FDCB9104140A3E6ABE4631950405F402FDCB9104140E3C62DE6E71950409A417C60C7134140E3C62DE6E71950409A417C60C7134140A3E6ABE4631950405F402FDCB9104140A3E6ABE463195040
59408	19259	33.405372	33.421478999999998	64.413803999999999	64.404612	Почтовая	0103000020E61000000100000005000000685BCD3AE3B340406DE4BA29E5195040685BCD3AE3B340400EBDC5C37B1A5040B3791C06F3B540400EBDC5C37B1A5040B3791C06F3B540406DE4BA29E5195040685BCD3AE3B340406DE4BA29E5195040
59464	57569	36.432352999999999	36.509276	63.845655999999998	63.831581	Школьная	0103000020E61000000100000005000000EBA9D55757374240CC7C073F71EA4F40EBA9D5575737424045D5AF743EEC4F40A051BAF42F41424045D5AF743EEC4F40A051BAF42F414240CC7C073F71EA4F40EBA9D55757374240CC7C073F71EA4F40
59143	19119	34.363883000000001	34.425400000000003	64.311510999999996	64.266582	Школьная	0103000020E610000001000000050000000249D8B7932E4140F2ECF2AD0F1150400249D8B7932E41400856D5CBEF135040F5DBD781733641400856D5CBEF135040F5DBD78173364140F2ECF2AD0F1150400249D8B7932E4140F2ECF2AD0F115040
59301	18659	34.638876000000003	34.658341999999998	64.495073000000005	64.485866000000001	Центральная	0103000020E61000000100000005000000831953B0C6514140410FB56D181F5040831953B0C65141407D08AA46AF1F5040A7CAF78C445441407D08AA46AF1F5040A7CAF78C44544140410FB56D181F5040831953B0C6514140410FB56D181F5040
59343	18688	35.918795000000003	36.017043999999999	64.048711999999995	64.003936999999993	Советская	0103000020E610000001000000050000003A5D16139BF54140A38FF980400050403A5D16139BF541400EBBEF181E035040E84B6F7F2E0242400EBBEF181E035040E84B6F7F2E024240A38FF980400050403A5D16139BF54140A38FF98040005040
59446	2679	34.722248	34.815745	64.552330999999995	64.505497000000005	Школьный переулок	0103000020E61000000100000005000000FBCC599F725C414079CE16105A205040FBCC599F725C414049641F6459235040117008556A68414049641F6459235040117008556A68414079CE16105A205040FBCC599F725C414079CE16105A205040
59180	2679	34.722248	34.815745	64.552330999999995	64.505497000000005	Строительная	0103000020E61000000100000005000000FBCC599F725C414079CE16105A205040FBCC599F725C414049641F6459235040117008556A68414049641F6459235040117008556A68414079CE16105A205040FBCC599F725C414079CE16105A205040
59193	2679	34.722248	34.815745	64.552330999999995	64.505497000000005	Ленинская	0103000020E61000000100000005000000FBCC599F725C414079CE16105A205040FBCC599F725C414049641F6459235040117008556A68414049641F6459235040117008556A68414079CE16105A205040FBCC599F725C414079CE16105A205040
59339	2679	34.722248	34.815745	64.552330999999995	64.505497000000005	Водников	0103000020E61000000100000005000000FBCC599F725C414079CE16105A205040FBCC599F725C414049641F6459235040117008556A68414049641F6459235040117008556A68414079CE16105A205040FBCC599F725C414079CE16105A205040
58416	57387	28.458053	28.507344	56.305993000000001	56.266751999999997	Шоссейная	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
58507	57387	28.458053	28.507344	56.305993000000001	56.266751999999997	Первомайская	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
58361	51947	28.249420000000001	28.270045	57.841479999999997	57.825629999999997	Школьная	0103000020E61000000100000005000000E4F736FDD93F3C40594C6C3EAEE94C40E4F736FDD93F3C40791EDC9DB5EB4C40C5724BAB21453C40791EDC9DB5EB4C40C5724BAB21453C40594C6C3EAEE94C40E4F736FDD93F3C40594C6C3EAEE94C40
58468	57373	27.890173999999998	27.944181	57.078394000000003	57.053710000000002	Победы	0103000020E61000000100000005000000DFBF7971E2E33B40EDBB22F8DF864C40DFBF7971E2E33B40F01989D0088A4C402C8194D8B5F13B40F01989D0088A4C402C8194D8B5F13B40EDBB22F8DF864C40DFBF7971E2E33B40EDBB22F8DF864C40
58351	57373	27.890173999999998	27.944181	57.078394000000003	57.053710000000002	М.Горького	0103000020E61000000100000005000000DFBF7971E2E33B40EDBB22F8DF864C40DFBF7971E2E33B40F01989D0088A4C402C8194D8B5F13B40F01989D0088A4C402C8194D8B5F13B40EDBB22F8DF864C40DFBF7971E2E33B40EDBB22F8DF864C40
58501	57373	27.890173999999998	27.944181	57.078394000000003	57.053710000000002	Красноармейская	0103000020E61000000100000005000000DFBF7971E2E33B40EDBB22F8DF864C40DFBF7971E2E33B40F01989D0088A4C402C8194D8B5F13B40F01989D0088A4C402C8194D8B5F13B40EDBB22F8DF864C40DFBF7971E2E33B40EDBB22F8DF864C40
58479	57373	27.890173999999998	27.944181	57.078394000000003	57.053710000000002	Белорусская	0103000020E61000000100000005000000DFBF7971E2E33B40EDBB22F8DF864C40DFBF7971E2E33B40F01989D0088A4C402C8194D8B5F13B40F01989D0088A4C402C8194D8B5F13B40EDBB22F8DF864C40DFBF7971E2E33B40EDBB22F8DF864C40
2020	4697	28.292593	28.334848999999998	57.824474000000002	57.802616999999998	улица Юбилейная	0103000020E61000000100000005000000DD09F65FE74A3C40581B6327BCE64C40DD09F65FE74A3C407F33315D88E94C402A1900AAB8553C407F33315D88E94C402A1900AAB8553C40581B6327BCE64C40DD09F65FE74A3C40581B6327BCE64C40
1621	4697	28.331686999999999	28.345845000000001	57.819245000000002	57.799245999999997	улица Советская	0103000020E6100000010000000500000023827170E9543C40BABA63B14DE64C4023827170E9543C40AD342905DDE84C40317C444C89583C40AD342905DDE84C40317C444C89583C40BABA63B14DE64C4023827170E9543C40BABA63B14DE64C40
1774	4697	28.401064000000002	28.423674999999999	57.804228999999999	57.798982000000002	улица Пригородная	0103000020E610000001000000050000005B9A5B21AC663C40DD0BCC0A45E64C405B9A5B21AC663C4055BFD2F9F0E64C40FF21FDF6756C3C4055BFD2F9F0E64C40FF21FDF6756C3C40DD0BCC0A45E64C405B9A5B21AC663C40DD0BCC0A45E64C40
2760	4697	28.340976000000001	28.349339000000001	57.828989	57.826008000000002	улица Пионерская	0103000020E610000001000000050000008DB800344A573C40001E51A1BAE94C408DB800344A573C4033DFC14F1CEA4C40A437DC476E593C4033DFC14F1CEA4C40A437DC476E593C40001E51A1BAE94C408DB800344A573C40001E51A1BAE94C40
16191	4697	28.314889000000001	28.318598999999999	57.825462000000002	57.809969000000002	улица Петровская	0103000020E61000000100000005000000C2DEC4909C503C400DE36E10ADE74C40C2DEC4909C503C409E0B23BDA8E94C40CE893DB48F513C409E0B23BDA8E94C40CE893DB48F513C400DE36E10ADE74C40C2DEC4909C503C400DE36E10ADE74C40
2001	4697	28.3049	28.309094999999999	57.822136	57.809502999999999	улица Народная	0103000020E61000000100000005000000E78C28ED0D4E3C40C78157CB9DE74C40E78C28ED0D4E3C40A06EA0C03BE94C406C5B94D9204F3C40A06EA0C03BE94C406C5B94D9204F3C40C78157CB9DE74C40E78C28ED0D4E3C40C78157CB9DE74C40
2059	4697	28.270655999999999	28.323907999999999	57.821666	57.813147000000001	улица Коммунальная	0103000020E6100000010000000500000057772CB649453C4096EB6D3315E84C4057772CB649453C40191EFB592CE94C40ABE97AA2EB523C40191EFB592CE94C40ABE97AA2EB523C4096EB6D3315E84C4057772CB649453C4096EB6D3315E84C40
1896	4697	28.318967000000001	28.319668	57.807648	57.802684999999997	улица Комдива Кирсанова	0103000020E61000000100000005000000D48041D2A7513C40B0FECF61BEE64C40D48041D2A7513C400457790261E74C40E69315C3D5513C400457790261E74C40E69315C3D5513C40B0FECF61BEE64C40D48041D2A7513C40B0FECF61BEE64C40
1660	4697	28.354136	28.355429999999998	57.809350000000002	57.807892000000002	улица Заводская	0103000020E6100000010000000500000015562AA8A85A3C409B594B0169E74C4015562AA8A85A3C404182E2C798E74C406C04E275FD5A3C404182E2C798E74C406C04E275FD5A3C409B594B0169E74C4015562AA8A85A3C409B594B0169E74C40
1693	4697	28.340886000000001	28.368123000000001	57.812821	57.798143000000003	улица Вокзальная	0103000020E610000001000000050000000DAA0D4E44573C400344C18C29E64C400DAA0D4E44573C404240BE840AE84C40C9E7154F3D5E3C404240BE840AE84C40C9E7154F3D5E3C400344C18C29E64C400DAA0D4E44573C400344C18C29E64C40
58365	4697	28.326073000000001	28.350714	57.803423000000002	57.775112999999997	Яна Райниса	0103000020E61000000100000005000000CE1B278579533C402BDA1CE736E34C40CE1B278579533C4057ED9A90D6E64C40D53F8864C8593C4057ED9A90D6E64C40D53F8864C8593C402BDA1CE736E34C40CE1B278579533C402BDA1CE736E34C40
58386	4697	28.255474	28.460272	57.859220000000001	57.743735000000001	Я.Фабрициуса	0103000020E6100000010000000500000072FA7ABE66413C40FEF15EB532DF4C4072FA7ABE66413C40D908C4EBFAED4C40B743C362D4753C40D908C4EBFAED4C40B743C362D4753C40FEF15EB532DF4C4072FA7ABE66413C40FEF15EB532DF4C40
58438	4697	28.354406000000001	28.359068000000001	57.810093000000002	57.805571	Юрия Гагарина	0103000020E610000001000000050000009581035ABA5A3C4092CD55F31CE74C409581035ABA5A3C40F9DB9E20B1E74C40460A65E1EB5B3C40F9DB9E20B1E74C40460A65E1EB5B3C4092CD55F31CE74C409581035ABA5A3C4092CD55F31CE74C40
58443	4697	28.292593	28.334848999999998	57.824474000000002	57.802616999999998	Юбилейная	0103000020E61000000100000005000000DD09F65FE74A3C40581B6327BCE64C40DD09F65FE74A3C407F33315D88E94C402A1900AAB8553C407F33315D88E94C402A1900AAB8553C40581B6327BCE64C40DD09F65FE74A3C40581B6327BCE64C40
58563	4697	28.328893999999998	28.341415999999999	57.827336000000003	57.823726999999998	Школьная	0103000020E61000000100000005000000C2D9AD6532543C4085EAE6E26FE94C40C2D9AD6532543C40D8666325E6E94C40C554FA0967573C40D8666325E6E94C40C554FA0967573C4085EAE6E26FE94C40C2D9AD6532543C4085EAE6E26FE94C40
58432	4697	28.333034999999999	28.353669	57.841738999999997	57.822513999999998	Труда	0103000020E61000000100000005000000616C21C841553C404640852348E94C40616C21C841553C404562821ABEEB4C40E99B340D8A5A3C404562821ABEEB4C40E99B340D8A5A3C404640852348E94C40616C21C841553C404640852348E94C40
58461	4697	28.340661000000001	28.352349	57.834825000000002	57.831111999999997	Текстильная	0103000020E61000000100000005000000CD052E8F35573C4015A8C5E061EA4C40CD052E8F35573C400D71AC8BDBEA4C403FC7478B335A3C400D71AC8BDBEA4C403FC7478B335A3C4015A8C5E061EA4C40CD052E8F35573C4015A8C5E061EA4C40
58436	4697	28.342843999999999	28.380600999999999	57.796228999999997	57.755032	Советской Армии	0103000020E610000001000000050000003CA1D79FC4573C407CB779E3A4E04C403CA1D79FC4573C403A90F5D4EAE54C402CD32F116F613C403A90F5D4EAE54C402CD32F116F613C407CB779E3A4E04C403CA1D79FC4573C407CB779E3A4E04C40
58455	4697	28.331686999999999	28.345845000000001	57.819245000000002	57.799245999999997	Советская	0103000020E6100000010000000500000023827170E9543C40BABA63B14DE64C4023827170E9543C40AD342905DDE84C40317C444C89583C40AD342905DDE84C40317C444C89583C40BABA63B14DE64C4023827170E9543C40BABA63B14DE64C40
2325	4697	28.336880000000001	28.340140000000002	57.838662999999997	57.834763000000002	Сиреневый бульвар	0103000020E610000001000000050000002EAD86C43D563C4097749483D9EA4C402EAD86C43D563C40C0AE264F59EB4C40BB0F406A13573C40C0AE264F59EB4C40BB0F406A13573C4097749483D9EA4C402EAD86C43D563C4097749483D9EA4C40
58437	4697	28.332801	28.351423	57.820653999999998	57.805647999999998	Свердлова	0103000020E610000001000000050000007B13437232553C403D0B42791FE74C407B13437232553C4071AAB5300BE94C40ED0F94DBF6593C4071AAB5300BE94C40ED0F94DBF6593C403D0B42791FE74C407B13437232553C403D0B42791FE74C40
58373	4697	28.309094999999999	28.326756	57.815463000000001	57.814110999999997	Розы Люксембург	0103000020E610000001000000050000006C5B94D9204F3C402C280CCA34E84C406C5B94D9204F3C408D0C721761E84C4093C5FD47A6533C408D0C721761E84C4093C5FD47A6533C402C280CCA34E84C406C5B94D9204F3C402C280CCA34E84C40
2150	4697	28.257145000000001	28.331983999999999	57.819245000000002	57.804377000000002	Рижский проспект	0103000020E6100000010000000500000076543541D4413C40CA5356D3F5E64C4076543541D4413C40AD342905DDE84C4096CB46E7FC543C40AD342905DDE84C4096CB46E7FC543C40CA5356D3F5E64C4076543541D4413C40CA5356D3F5E64C40
58425	4697	28.366271999999999	28.369713000000001	57.807077	57.803418000000001	Рельсовая	0103000020E61000000100000005000000C5707500C45D3C404582A966D6E64C40C5707500C45D3C40492D944C4EE74C40F3E7DB82A55E3C40492D944C4EE74C40F3E7DB82A55E3C404582A966D6E64C40C5707500C45D3C404582A966D6E64C40
1615	4697	27.812380000000001	28.867038000000001	58.087983000000001	57.525021000000002	Победы площадь	0103000020E61000000100000005000000ABECBB22F8CF3B404B5B5CE333C34C40ABECBB22F8CF3B404FCDE506430B4D40A663CE33F6DD3C404FCDE506430B4D40A663CE33F6DD3C404B5B5CE333C34C40ABECBB22F8CF3B404B5B5CE333C34C40
58444	4697	28.277464999999999	28.281337000000001	57.814915999999997	57.810749999999999	Печорская	0103000020E61000000100000005000000DEC83CF207473C40B29DEFA7C6E74C40DEC83CF207473C405A7EE02A4FE84C409E279EB305483C405A7EE02A4FE84C409E279EB305483C40B29DEFA7C6E74C40DEC83CF207473C40B29DEFA7C6E74C40
58445	4697	28.307881999999999	28.324770000000001	57.819992999999997	57.818488000000002	Пароменская	0103000020E61000000100000005000000EE06D15AD14E3C409015FC36C4E84C40EE06D15AD14E3C4076F9D687F5E84C40D0B8702024533C4076F9D687F5E84C40D0B8702024533C409015FC36C4E84C40EE06D15AD14E3C409015FC36C4E84C40
58560	4697	28.390903999999999	28.397327000000001	57.800866999999997	57.799188000000001	Островская	0103000020E6100000010000000500000026E0D74812643C4086ADD9CA4BE64C4026E0D74812643C400AB952CF82E64C405BD1E638B7653C400AB952CF82E64C405BD1E638B7653C4086ADD9CA4BE64C4026E0D74812643C4086ADD9CA4BE64C40
1956	4697	28.320494	28.327186999999999	57.824708999999999	57.812677000000001	Ольгинская набережная	0103000020E61000000100000005000000719010E50B523C400F9BC8CC05E84C40719010E50B523C40C2DB831090E94C4025ADF886C2533C40C2DB831090E94C4025ADF886C2533C400F9BC8CC05E84C40719010E50B523C400F9BC8CC05E84C40
58440	4697	28.381309999999999	28.414449000000001	57.828304000000003	57.812173999999999	Николая Васильева	0103000020E6100000010000000500000044A33B889D613C40AC545051F5E74C4044A33B889D613C40B0928FDD05EA4C4023DC6454196A3C40B0928FDD05EA4C4023DC6454196A3C40AC545051F5E74C4044A33B889D613C40AC545051F5E74C40
58451	4697	28.3049	28.309094999999999	57.822136	57.809502999999999	Народная	0103000020E61000000100000005000000E78C28ED0D4E3C40C78157CB9DE74C40E78C28ED0D4E3C40A06EA0C03BE94C406C5B94D9204F3C40A06EA0C03BE94C406C5B94D9204F3C40C78157CB9DE74C40E78C28ED0D4E3C40C78157CB9DE74C40
58460	4697	28.326630000000002	28.329756	57.828198	57.825845000000001	Набат	0103000020E610000001000000050000007AE40F069E533C405648F949B5E94C407AE40F069E533C406A4E5E6402EA4C40E7A8A3E36A543C406A4E5E6402EA4C40E7A8A3E36A543C405648F949B5E94C407AE40F069E533C405648F949B5E94C40
58447	4697	28.318356000000001	28.325030999999999	57.825975	57.805950000000003	Максима Горького	0103000020E61000000100000005000000427C60C77F513C40091B9E5E29E74C40427C60C77F513C4024287E8CB9E94C40A92F4B3B35533C4024287E8CB9E94C40A92F4B3B35533C40091B9E5E29E74C40427C60C77F513C40091B9E5E29E74C40
58439	4697	28.347083999999999	28.381309999999999	57.814331000000003	57.810735999999999	Льва Толстого	0103000020E6100000010000000500000001F73C7FDA583C404DD87E32C6E74C4001F73C7FDA583C403B8F8AFF3BE84C4044A33B889D613C403B8F8AFF3BE84C4044A33B889D613C404DD87E32C6E74C4001F73C7FDA583C404DD87E32C6E74C40
58452	4697	28.275964999999999	28.333214000000002	57.860540999999998	57.819220999999999	Леона Поземского	0103000020E6100000010000000500000034D769A4A5463C402499D53BDCE84C4034D769A4A5463C40FEEE1D3526EE4C40C19140834D553C40FEEE1D3526EE4C40C19140834D553C402499D53BDCE84C4034D769A4A5463C402499D53BDCE84C40
1791	4697	28.366828999999999	28.447991999999999	57.829098999999999	57.740670999999999	Ленинградское шоссе	0103000020E6100000010000000500000071395E81E85D3C403D0CAD4ECEDE4C4071395E81E85D3C40BA1281EA1FEA4C40A0DE8C9AAF723C40BA1281EA1FEA4C40A0DE8C9AAF723C403D0CAD4ECEDE4C4071395E81E85D3C403D0CAD4ECEDE4C40
58417	4697	28.333583000000001	28.341298999999999	57.818818999999998	57.816032999999997	Ленина	0103000020E6100000010000000500000067800BB265553C4077BAF3C473E84C4067800BB265553C40F52B9D0FCFE84C4052280B5F5F573C40F52B9D0FCFE84C4052280B5F5F573C4077BAF3C473E84C4067800BB265553C4077BAF3C473E84C40
58472	4697	28.336772	28.358744999999999	57.821258	57.804904999999998	Кузнецкая	0103000020E61000000100000005000000613596B036563C4085B1852007E74C40613596B036563C4008CA6DFB1EE94C40809A5AB6D65B3C4008CA6DFB1EE94C40809A5AB6D65B3C4085B1852007E74C40613596B036563C4085B1852007E74C40
58441	4697	28.306103	28.326962000000002	57.814025000000001	57.809182	Красноармейская	0103000020E610000001000000050000001E3526C45C4E3C408541994693E74C401E3526C45C4E3C402E90A0F831E84C40E60819C8B3533C402E90A0F831E84C40E60819C8B3533C408541994693E74C401E3526C45C4E3C408541994693E74C40
58450	4697	28.312957000000001	28.323225000000001	57.817068999999996	57.816259000000002	Конная	0103000020E61000000100000005000000E50D30F31D503C406808C72C7BE84C40E50D30F31D503C40A7C98CB795E84C40E63FA4DFBE523C40A7C98CB795E84C40E63FA4DFBE523C406808C72C7BE84C40E50D30F31D503C406808C72C7BE84C40
58431	4697	28.308053000000001	28.314035000000001	57.826884999999997	57.812221999999998	Киселёва	0103000020E61000000100000005000000486FB88FDC4E3C40BD8BF7E3F6E74C40486FB88FDC4E3C40C746205ED7E94C40A3CC069964503C40C746205ED7E94C40A3CC069964503C40BD8BF7E3F6E74C40486FB88FDC4E3C40BD8BF7E3F6E74C40
58442	4697	28.371131999999999	28.40596	57.758868	57.754018000000002	Карбышева	0103000020E61000000100000005000000C37FBA81025F3C40344C6DA983E04C40C37FBA81025F3C408FFD2C9622E14C40F27B9BFEEC673C408FFD2C9622E14C40F27B9BFEEC673C40344C6DA983E04C40C37FBA81025F3C40344C6DA983E04C40
58422	4697	28.333637	28.336772	57.812390000000001	57.804904999999998	Калинина	0103000020E610000001000000050000004DBC033C69553C4085B1852007E74C404DBC033C69553C4079CC4065FCE74C40613596B036563C4079CC4065FCE74C40613596B036563C4085B1852007E74C404DBC033C69553C4085B1852007E74C40
58454	4697	28.354593999999999	28.368607999999998	57.841422999999999	57.812868999999999	Инженерная	0103000020E610000001000000050000009A5B21ACC65A3C40537765170CE84C409A5B21ACC65A3C40158DB5BFB3EB4C40410B09185D5E3C40158DB5BFB3EB4C40410B09185D5E3C40537765170CE84C409A5B21ACC65A3C40537765170CE84C40
58456	4697	28.355277000000001	28.393276	57.830435999999999	57.820698	Индустриальная	0103000020E610000001000000050000006005F86EF35A3C4041F2CEA10CE94C406005F86EF35A3C40E5B512BA4BEA4C403C4D66BCAD643C40E5B512BA4BEA4C403C4D66BCAD643C4041F2CEA10CE94C406005F86EF35A3C4041F2CEA10CE94C40
1738	4697	28.387104000000001	28.424537000000001	57.814906999999998	57.804122999999997	Зональное шоссе	0103000020E610000001000000050000009A266C3F19633C400F7BA180EDE64C409A266C3F19633C40072461DF4EE84C4024F1F274AE6C3C40072461DF4EE84C4024F1F274AE6C3C400F7BA180EDE64C409A266C3F19633C400F7BA180EDE64C40
58449	4697	28.341542	28.358457000000001	57.840057000000002	57.835816999999999	Звёздная	0103000020E61000000100000005000000DF35E84B6F573C406D382C0DFCEA4C40DF35E84B6F573C4050E3DEFC86EB4C40B40584D6C35B3C4050E3DEFC86EB4C40B40584D6C35B3C406D382C0DFCEA4C40DF35E84B6F573C406D382C0DFCEA4C40
58458	4697	28.276522	28.287894000000001	57.822015999999998	57.812514	Западная	0103000020E61000000100000005000000E09F5225CA463C4065C5707500E84C40E09F5225CA463C40F564FED137E94C40F2B6D26BB3493C40F564FED137E94C40F2B6D26BB3493C4065C5707500E84C40E09F5225CA463C4065C5707500E84C40
58457	4697	28.267133999999999	28.278022	57.819853999999999	57.816949000000001	Байкова	0103000020E6100000010000000500000050A6D1E462443C40FDBFEAC891E84C4050A6D1E462443C4055BFD2F9F0E84C408A9125732C473C4055BFD2F9F0E84C408A9125732C473C40FDBFEAC891E84C4050A6D1E462443C40FDBFEAC891E84C40
58459	4697	28.352349	28.360811000000002	57.831111999999997	57.830249000000002	Алтаева	0103000020E610000001000000050000003FC7478B335A3C40B344679945EA4C403FC7478B335A3C4015A8C5E061EA4C407D09151C5E5C3C4015A8C5E061EA4C407D09151C5E5C3C40B344679945EA4C403FC7478B335A3C40B344679945EA4C40
58448	4697	28.288001999999999	28.295791000000001	57.839587999999999	57.836008999999997	Алексея Алёхина	0103000020E61000000100000005000000BE2EC37FBA493C40B114C95702EB4C40BE2EC37FBA493C40990E9D9E77EB4C407E737FF5B84B3C40990E9D9E77EB4C407E737FF5B84B3C40B114C95702EB4C40BE2EC37FBA493C40B114C95702EB4C40
58342	4697	28.255474	28.460272	57.859220000000001	57.743735000000001	23 июля	0103000020E6100000010000000500000072FA7ABE66413C40FEF15EB532DF4C4072FA7ABE66413C40D908C4EBFAED4C40B743C362D4753C40D908C4EBFAED4C40B743C362D4753C40FEF15EB532DF4C4072FA7ABE66413C40FEF15EB532DF4C40
58429	4697	28.343858999999998	28.350245999999999	57.797398999999999	57.796132999999998	1-я Посёлочная	0103000020E610000001000000050000006D6FB72407583C401822A7AFE7E54C406D6FB72407583C407A6EA12B11E64C40088ECBB8A9593C407A6EA12B11E64C40088ECBB8A9593C401822A7AFE7E54C406D6FB72407583C401822A7AFE7E54C40
58421	57388	29.514526	29.581863999999999	57.782330999999999	57.750681	Ленина	0103000020E6100000010000000500000013F1D6F9B7833D40425DA45016E04C4013F1D6F9B7833D40D0D2156C23E44C4041B8020AF5943D40D0D2156C23E44C4041B8020AF5943D40425DA45016E04C4013F1D6F9B7833D40425DA45016E04C40
58526	57376	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Свободы	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58369	57376	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Вокзальная	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58401	57384	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	25 Октября	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58505	57391	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Пролетарская	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58381	57378	29.311606000000001	29.368307000000001	57.039374000000002	57.021731000000003	Германа	0103000020E61000000100000005000000C53C2B69C54F3D409A27D714C8824C40C53C2B69C54F3D4007280D350A854C404CE3175E495E3D4007280D350A854C404CE3175E495E3D409A27D714C8824C40C53C2B69C54F3D409A27D714C8824C40
58384	57377	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	Урицкого	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
58374	57377	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	Ленина	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
58366	57375	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	Петрова	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
1154	4310	28.357658000000001	28.415984999999999	57.85163	57.816507999999999	улица Парковая	0103000020E610000001000000050000001C2785798F5B3C4010768A5583E84C401C2785798F5B3C4070253B3602ED4C4066A032FE7D6A3C4070253B3602ED4C4066A032FE7D6A3C4010768A5583E84C401C2785798F5B3C4010768A5583E84C40
58561	4310	28.357658000000001	28.415984999999999	57.85163	57.816507999999999	Парковая	0103000020E610000001000000050000001C2785798F5B3C4010768A5583E84C401C2785798F5B3C4070253B3602ED4C4066A032FE7D6A3C4070253B3602ED4C4066A032FE7D6A3C4010768A5583E84C401C2785798F5B3C4010768A5583E84C40
58497	57400	27.800864000000001	27.839464	58.753315000000001	58.728565000000003	Школьный переулок	0103000020E61000000100000005000000338B506C05CD3B405001309E415D4D40338B506C05CD3B400A4B3CA06C604D405A2BDA1CE7D63B400A4B3CA06C604D405A2BDA1CE7D63B405001309E415D4D40338B506C05CD3B405001309E415D4D40
58339	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	пр.Гагарина	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58399	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	пр. Гагарина	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58398	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	площадь Юбилейная	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58327	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	площадь Калинина	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58344	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	переулок Некрасова	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58462	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	пер.Некрасова	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58334	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	наб.Новослоболдская	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58418	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Юбилейная	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58360	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Щорса	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58329	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Фурманова	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58324	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Третьей Ударной Армии	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58371	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Половская	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58435	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Первомайская	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58363	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Парковая	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58446	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Октябрьский проспект	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58508	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Новосокольническая	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58359	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Малышева	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58362	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	М.Кузьмина	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58464	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Ленина площадь	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58328	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	К.Зверева	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58453	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Зелёная	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58326	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Заслонова	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58419	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Дружбы	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58396	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Горная	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58372	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Глинки	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58394	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Гастелло	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58397	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Гагарина проспект	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58356	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Витебская	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58370	9096	30.471896000000001	30.605449	56.370170000000002	56.313263999999997	Винатовского	0103000020E61000000100000005000000FC1C1F2DCE783E40CF81E50819284C40FC1C1F2DCE783E40ECFA05BB612F4C405A65A6B4FE9A3E40ECFA05BB612F4C405A65A6B4FE9A3E40CF81E50819284C40FC1C1F2DCE783E40CF81E50819284C40
58411	2271	30.718951000000001	30.814181999999999	55.761178000000001	55.717638999999998	Карла Маркса	0103000020E610000001000000050000002F6D382C0DB83E40C5AA4198DBDB4B402F6D382C0DB83E40A437DC476EE14B40EBFD463B6ED03E40A437DC476EE14B40EBFD463B6ED03E40C5AA4198DBDB4B402F6D382C0DB83E40C5AA4198DBDB4B40
58536	2271	30.718951000000001	30.814181999999999	55.761178000000001	55.717638999999998	25 Октября	0103000020E610000001000000050000002F6D382C0DB83E40C5AA4198DBDB4B402F6D382C0DB83E40A437DC476EE14B40EBFD463B6ED03E40A437DC476EE14B40EBFD463B6ED03E40C5AA4198DBDB4B402F6D382C0DB83E40C5AA4198DBDB4B40
58547	28613	28.930899	28.956268000000001	58.054797999999998	58.037483999999999	Новосельская	0103000020E610000001000000050000000DE198654FEE3C40C70F9546CC044D400DE198654FEE3C406FF1F09E03074D401A36CAFACDF43C406FF1F09E03074D401A36CAFACDF43C40C70F9546CC044D400DE198654FEE3C40C70F9546CC044D40
58538	28831	29.404427999999999	29.423705999999999	58.124597999999999	58.103276000000001	Заречная	0103000020E610000001000000050000003196E99788673D40193BE125380D4D403196E99788673D40D192C7D3F20F4D40751E15FF776C3D40D192C7D3F20F4D40751E15FF776C3D40193BE125380D4D403196E99788673D40193BE125380D4D40
58558	57389	29.058703000000001	29.128682000000001	58.313997999999998	58.247152	Сосновая	0103000020E61000000100000005000000562DE928070F3D400C923EADA21F4D40562DE928070F3D403481221631284D407995B54DF1203D403481221631284D407995B54DF1203D400C923EADA21F4D40562DE928070F3D400C923EADA21F4D40
58426	57389	29.058703000000001	29.128682000000001	58.313997999999998	58.247152	Советская	0103000020E61000000100000005000000562DE928070F3D400C923EADA21F4D40562DE928070F3D403481221631284D407995B54DF1203D403481221631284D407995B54DF1203D400C923EADA21F4D40562DE928070F3D400C923EADA21F4D40
58424	57389	29.058703000000001	29.128682000000001	58.313997999999998	58.247152	Мира	0103000020E61000000100000005000000562DE928070F3D400C923EADA21F4D40562DE928070F3D403481221631284D407995B54DF1203D403481221631284D407995B54DF1203D400C923EADA21F4D40562DE928070F3D400C923EADA21F4D40
58495	57389	29.058703000000001	29.128682000000001	58.313997999999998	58.247152	Жертв Революции	0103000020E61000000100000005000000562DE928070F3D400C923EADA21F4D40562DE928070F3D403481221631284D407995B54DF1203D403481221631284D407995B54DF1203D400C923EADA21F4D40562DE928070F3D400C923EADA21F4D40
58535	28459	28.684842	28.701982000000001	58.438564	58.421672000000001	Центральная	0103000020E610000001000000050000005FED28CE51AF3C40C8D11C59F9354D405FED28CE51AF3C40FA997ADD22384D407461A417B5B33C40FA997ADD22384D407461A417B5B33C40C8D11C59F9354D405FED28CE51AF3C40C8D11C59F9354D40
58550	57438	28.786756	28.811845999999999	58.348390999999999	58.336153000000003	Народная	0103000020E6100000010000000500000089EE59D768C93C40E5B9BE0F072B4D4089EE59D768C93C40419C8713982C4D406F63B323D5CF3C40419C8713982C4D406F63B323D5CF3C40E5B9BE0F072B4D4089EE59D768C93C40E5B9BE0F072B4D40
58556	46524	29.214614000000001	29.237017999999999	58.380104000000003	58.370401999999999	Владимира Ислентьева	0103000020E6100000010000000500000085436FF1F0363D40BE2F2E55692F4D4085436FF1F0363D40168A743FA7304D4036902E36AD3C3D40168A743FA7304D4036902E36AD3C3D40BE2F2E55692F4D4085436FF1F0363D40BE2F2E55692F4D40
58502	46594	28.848614000000001	28.89847	58.121536999999996	58.088383	Евстафьева	0103000020E6100000010000000500000081ED60C43ED93C40DD425722500B4D4081ED60C43ED93C40812040868E0F4D40E76F422102E63C40812040868E0F4D40E76F422102E63C40DD425722500B4D4081ED60C43ED93C40DD425722500B4D40
58565	49214	28.698136999999999	28.728967000000001	58.026466999999997	58.018560000000001	Молодейская	0103000020E61000000100000005000000A7203F1BB9B23C40C381902C60024D40A7203F1BB9B23C402CB6494563034D40FDDCD0949DBA3C402CB6494563034D40FDDCD0949DBA3C40C381902C60024D40A7203F1BB9B23C40C381902C60024D40
58542	28779	29.325161000000001	29.375754000000001	58.232906999999997	58.211584000000002	Школьная	0103000020E6100000010000000500000046EF54C03D533D40AE2D3C2F151B4D4046EF54C03D533D40360186E5CF1D4D405857056A31603D40360186E5CF1D4D405857056A31603D40AE2D3C2F151B4D4046EF54C03D533D40AE2D3C2F151B4D40
58567	46615	28.942578000000001	28.957939	58.260263999999999	58.25356	Школьная	0103000020E61000000100000005000000D9EDB3CA4CF13C4071C971A774204D40D9EDB3CA4CF13C40BF29AC5450214D401D90847D3BF53C40BF29AC5450214D401D90847D3BF53C4071C971A774204D40D9EDB3CA4CF13C4071C971A774204D40
58533	46556	28.942613999999999	28.965215000000001	58.406258000000001	58.393988	Труда	0103000020E6100000010000000500000072C0AE264FF13C401B82E3326E324D4072C0AE264FF13C4083DE1B4300344D40D09B8A5418F73C4083DE1B4300344D40D09B8A5418F73C401B82E3326E324D4072C0AE264FF13C401B82E3326E324D40
58475	31561	28.458053	28.507344	56.305993000000001	56.266751999999997	переулок Почтовый	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
58483	31561	28.458053	28.507344	56.305993000000001	56.266751999999997	Ленинская	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
58498	31561	28.458053	28.507344	56.305993000000001	56.266751999999997	Красноармейская	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
57957	31561	28.458053	28.507344	56.305993000000001	56.266751999999997	7-го Ноября	0103000020E61000000100000005000000AED51EF642753C404012F6ED24224C40AED51EF642753C4008E753C72A274C4063D2DF4BE1813C4008E753C72A274C4063D2DF4BE1813C404012F6ED24224C40AED51EF642753C404012F6ED24224C40
58471	191	28.867370999999999	28.901399000000001	56.343563000000003	56.32208	Островского	0103000020E61000000100000005000000B27F9E060CDE3C400C59DDEA39294C40B27F9E060CDE3C40CE8E54DFF92B4C40A9A5B915C2E63C40CE8E54DFF92B4C40A9A5B915C2E63C400C59DDEA39294C40B27F9E060CDE3C400C59DDEA39294C40
58415	191	28.867370999999999	28.901399000000001	56.343563000000003	56.32208	Ленина	0103000020E61000000100000005000000B27F9E060CDE3C400C59DDEA39294C40B27F9E060CDE3C40CE8E54DFF92B4C40A9A5B915C2E63C40CE8E54DFF92B4C40A9A5B915C2E63C400C59DDEA39294C40B27F9E060CDE3C400C59DDEA39294C40
58572	45659	28.623981000000001	28.653033000000001	56.397005999999998	56.381853	Центральная	0103000020E610000001000000050000004C530438BD9F3C409370218FE0304C404C530438BD9F3C406B28B517D1324C407235B22B2DA73C406B28B517D1324C407235B22B2DA73C409370218FE0304C404C530438BD9F3C409370218FE0304C40
58513	48631	28.776174000000001	28.787448000000001	56.272015000000003	56.267992	Ленина	0103000020E610000001000000050000006901DA56B3C63C4079CBD58F4D224C406901DA56B3C63C40BF823463D1224C40F54C2F3196C93C40BF823463D1224C40F54C2F3196C93C4079CBD58F4D224C406901DA56B3C63C4079CBD58F4D224C40
58469	19855	27.890173999999998	27.944181	57.078394000000003	57.053710000000002	Пушкинская	0103000020E61000000100000005000000DFBF7971E2E33B40EDBB22F8DF864C40DFBF7971E2E33B40F01989D0088A4C402C8194D8B5F13B40F01989D0088A4C402C8194D8B5F13B40EDBB22F8DF864C40DFBF7971E2E33B40EDBB22F8DF864C40
58529	45615	28.644984000000001	28.649826000000001	56.917087000000002	56.914414000000001	Лесная	0103000020E610000001000000050000007A71E2AB1DA53C40958098840B754C407A71E2AB1DA53C401B4B581B63754C402B172AFF5AA63C401B4B581B63754C402B172AFF5AA63C40958098840B754C407A71E2AB1DA53C40958098840B754C40
58540	20226	28.876165	28.945964	57.030377000000001	57.011989	Совхозный переулок	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
58474	20226	28.876165	28.945964	57.030377000000001	57.011989	Садовая	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
58482	20226	28.876165	28.945964	57.030377000000001	57.011989	Пушкинская	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
58480	20226	28.876165	28.945964	57.030377000000001	57.011989	Новоржевская	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
58466	20226	28.876165	28.945964	57.030377000000001	57.011989	Лермонтова	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
58467	20226	28.876165	28.945964	57.030377000000001	57.011989	Ленина	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
58504	20226	28.876165	28.945964	57.030377000000001	57.011989	Больничный городок	0103000020E610000001000000050000005CE674594CE03C40B47405DB88814C405CE674594CE03C407AC6BE64E3834C407F315BB22AF23C407AC6BE64E3834C407F315BB22AF23C40B47405DB88814C405CE674594CE03C40B47405DB88814C40
58524	21337	28.87595	28.917542000000001	56.893289000000003	56.869377	Советская	0103000020E6100000010000000500000063EE5A423EE03C408272DBBE476F4C4063EE5A423EE03C403370404B57724C40D9B45208E4EA3C403370404B57724C40D9B45208E4EA3C408272DBBE476F4C4063EE5A423EE03C408272DBBE476F4C40
58551	48069	28.655988000000001	28.688184	56.921228999999997	56.908881000000001	Центральная	0103000020E6100000010000000500000086915ED4EEA73C40577A6D3656744C4086915ED4EEA73C403A90F5D4EA754C4066A19DD32CB03C403A90F5D4EA754C4066A19DD32CB03C40577A6D3656744C4086915ED4EEA73C40577A6D3656744C40
58407	5169	29.334071999999999	29.397772	56.351160999999998	56.318052000000002	Октябрьская 	0103000020E6100000010000000500000062821ABE85553D40B5368DEDB5284C4062821ABE85553D40B950F9D7F22C4C40B743C362D4653D40B950F9D7F22C4C40B743C362D4653D40B5368DEDB5284C4062821ABE85553D40B5368DEDB5284C40
58509	5169	29.334071999999999	29.397772	56.351160999999998	56.318052000000002	Октябрьская	0103000020E6100000010000000500000062821ABE85553D40B5368DEDB5284C4062821ABE85553D40B950F9D7F22C4C40B743C362D4653D40B950F9D7F22C4C40B743C362D4653D40B5368DEDB5284C4062821ABE85553D40B5368DEDB5284C40
58380	52044	28.137129999999999	28.159040000000001	57.750652000000002	57.736721000000003	Солнечная	0103000020E61000000100000005000000EC4CA1F31A233C4062A3ACDF4CDE4C40EC4CA1F31A233C40A8565F5D15E04C407FC16ED8B6283C40A8565F5D15E04C407FC16ED8B6283C4062A3ACDF4CDE4C40EC4CA1F31A233C4062A3ACDF4CDE4C40
58377	52044	28.137129999999999	28.159040000000001	57.750652000000002	57.736721000000003	Молодежная	0103000020E61000000100000005000000EC4CA1F31A233C4062A3ACDF4CDE4C40EC4CA1F31A233C40A8565F5D15E04C407FC16ED8B6283C40A8565F5D15E04C407FC16ED8B6283C4062A3ACDF4CDE4C40EC4CA1F31A233C4062A3ACDF4CDE4C40
58470	52026	28.160639	28.208653999999999	58.175049999999999	58.145274999999998	Родионова	0103000020E610000001000000050000004F7633A31F293C4094F6065F98124D404F7633A31F293C401895D40968164D40F92D3A596A353C401895D40968164D40F92D3A596A353C4094F6065F98124D404F7633A31F293C4094F6065F98124D40
58330	52026	28.160639	28.208653999999999	58.175049999999999	58.145274999999998	Пушкинская	0103000020E610000001000000050000004F7633A31F293C4094F6065F98124D404F7633A31F293C401895D40968164D40F92D3A596A353C401895D40968164D40F92D3A596A353C4094F6065F98124D404F7633A31F293C4094F6065F98124D40
58378	48560	28.238002000000002	28.282261999999999	57.839688000000002	57.820084000000001	Юбилейная	0103000020E61000000100000005000000F261F6B2ED3C3C4087FC3383F8E84C40F261F6B2ED3C3C40FD6B79E57AEB4C404FE78A5242483C40FD6B79E57AEB4C404FE78A5242483C4087FC3383F8E84C40F261F6B2ED3C3C4087FC3383F8E84C40
58382	48560	28.238002000000002	28.282261999999999	57.839688000000002	57.820084000000001	Владимирская	0103000020E61000000100000005000000F261F6B2ED3C3C4087FC3383F8E84C40F261F6B2ED3C3C40FD6B79E57AEB4C404FE78A5242483C40FD6B79E57AEB4C404FE78A5242483C4087FC3383F8E84C40F261F6B2ED3C3C4087FC3383F8E84C40
58333	51988	28.193904	28.209866999999999	57.805643000000003	57.789110000000001	Юбилейная	0103000020E6100000010000000500000047904AB1A3313C402979758E01E54C4047904AB1A3313C402CA0504F1FE74C407782FDD7B9353C402CA0504F1FE74C407782FDD7B9353C402979758E01E54C4047904AB1A3313C402979758E01E54C40
58520	48663	28.744966000000002	28.777674000000001	57.770356999999997	57.752366000000002	Советская	0103000020E61000000100000005000000C7A17E17B6BE3C40A94F72874DE04C40C7A17E17B6BE3C40519FE40E9BE24C4013F3ACA415C73C40519FE40E9BE24C4013F3ACA415C73C40A94F72874DE04C40C7A17E17B6BE3C40A94F72874DE04C40
58403	57385	28.202383999999999	28.251459000000001	57.950037000000002	57.936593999999999	Коровина	0103000020E61000000100000005000000D13B1570CF333C409ED0EB4FE2F74C40D13B1570CF333C40B77EFACF9AF94C40ED48F59D5F403C40B77EFACF9AF94C40ED48F59D5F403C409ED0EB4FE2F74C40D13B1570CF333C409ED0EB4FE2F74C40
58553	52015	28.371734	28.382073999999999	58.125030000000002	58.110004000000004	Центральная	0103000020E61000000100000005000000AFCF9CF5295F3C40F0366F9C140E4D40AFCF9CF5295F3C406B82A8FB00104D40E3A6069ACF613C406B82A8FB00104D40E3A6069ACF613C40F0366F9C140E4D40AFCF9CF5295F3C40F0366F9C140E4D40
58527	57417	28.952898999999999	28.973721999999999	57.757489999999997	57.752313999999998	Центральная	0103000020E610000001000000050000001F645930F1F33C4056293DD34BE04C401F645930F1F33C400586AC6EF5E04C404D6551D845F93C400586AC6EF5E04C404D6551D845F93C4056293DD34BE04C401F645930F1F33C4056293DD34BE04C40
58485	52011	28.244523999999998	28.265913000000001	58.024813000000002	58.015861000000001	Красных Партизан	0103000020E610000001000000050000004C16F71F993E3C401424B6BB07024D404C16F71F993E3C4001C287122D034D40CD94D6DF12443C4001C287122D034D40CD94D6DF12443C401424B6BB07024D404C16F71F993E3C401424B6BB07024D40
58514	52005	28.308168999999999	28.330331000000001	57.877538999999999	57.867747000000001	Строителей	0103000020E610000001000000050000001AA4E029E44E3C40DF196D5512EF4C401AA4E029E44E3C4076FBAC3253F04C40E0DA899290543C4076FBAC3253F04C40E0DA899290543C40DF196D5512EF4C401AA4E029E44E3C40DF196D5512EF4C40
58528	52049	27.999661	28.008922999999999	57.721978	57.712637999999998	Школьная	0103000020E610000001000000050000002F1686C8E9FF3B4084F1D3B837DB4C402F1686C8E9FF3B403B376DC669DC4C40A52E19C748023C403B376DC669DC4C40A52E19C748023C4084F1D3B837DB4C402F1686C8E9FF3B4084F1D3B837DB4C40
58463	57371	29.514526	29.581863999999999	57.782330999999999	57.750681	Порховская	0103000020E6100000010000000500000013F1D6F9B7833D40425DA45016E04C4013F1D6F9B7833D40D0D2156C23E44C4041B8020AF5943D40D0D2156C23E44C4041B8020AF5943D40425DA45016E04C4013F1D6F9B7833D40425DA45016E04C40
58364	57371	29.514526	29.581863999999999	57.782330999999999	57.750681	Плеханова	0103000020E6100000010000000500000013F1D6F9B7833D40425DA45016E04C4013F1D6F9B7833D40D0D2156C23E44C4041B8020AF5943D40D0D2156C23E44C4041B8020AF5943D40425DA45016E04C4013F1D6F9B7833D40425DA45016E04C40
58343	57371	29.514526	29.581863999999999	57.782330999999999	57.750681	Мебельная	0103000020E6100000010000000500000013F1D6F9B7833D40425DA45016E04C4013F1D6F9B7833D40D0D2156C23E44C4041B8020AF5943D40D0D2156C23E44C4041B8020AF5943D40425DA45016E04C4013F1D6F9B7833D40425DA45016E04C40
58428	57371	29.514526	29.581863999999999	57.782330999999999	57.750681	Ленина	0103000020E6100000010000000500000013F1D6F9B7833D40425DA45016E04C4013F1D6F9B7833D40D0D2156C23E44C4041B8020AF5943D40D0D2156C23E44C4041B8020AF5943D40425DA45016E04C4013F1D6F9B7833D40425DA45016E04C40
58481	29783	29.349658000000002	29.410672000000002	58.442332	58.411881999999999	Победы	0103000020E61000000100000005000000E7C8CA2F83593D40D1E7A38CB8344D40E7C8CA2F83593D40B5FCC0559E384D400762D9CC21693D40B5FCC0559E384D400762D9CC21693D40D1E7A38CB8344D40E7C8CA2F83593D40D1E7A38CB8344D40
58346	29783	29.349658000000002	29.410672000000002	58.442332	58.411881999999999	Ленина	0103000020E61000000100000005000000E7C8CA2F83593D40D1E7A38CB8344D40E7C8CA2F83593D40B5FCC0559E384D400762D9CC21693D40B5FCC0559E384D400762D9CC21693D40D1E7A38CB8344D40E7C8CA2F83593D40D1E7A38CB8344D40
58534	29947	29.357914000000001	29.375350000000001	58.391247	58.383685	Центральная	0103000020E61000000100000005000000D2C77C40A05B3D409E7B0F971C314D40D2C77C40A05B3D403DD4B66114324D40B98D06F016603D403DD4B66114324D40B98D06F016603D409E7B0F971C314D40D2C77C40A05B3D409E7B0F971C314D40
58389	2921	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Свободы	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58405	2921	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Мира	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58506	2921	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Мелиораторов	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58331	2921	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Ленина	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58325	2921	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Индустриальная	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58388	2921	27.585861000000001	27.644304999999999	57.826079999999997	57.795965000000002	Заводская	0103000020E610000001000000050000007A008BFCFA953B405DE15D2EE2E54C407A008BFCFA953B4099F04BFDBCE94C4037A6272CF1A43B4099F04BFDBCE94C4037A6272CF1A43B405DE15D2EE2E54C407A008BFCFA953B405DE15D2EE2E54C40
58517	57379	27.95806	27.987624	57.780189999999997	57.763933999999999	Октябрьская	0103000020E61000000100000005000000139B8F6B43F53B40B726DD96C8E14C40139B8F6B43F53B4047551344DDE34C40A5BE2CEDD4FC3B4047551344DDE34C40A5BE2CEDD4FC3B40B726DD96C8E14C40139B8F6B43F53B40B726DD96C8E14C40
58489	49287	27.466978000000001	27.492381999999999	57.584558999999999	57.570014999999998	Комсомольская	0103000020E6100000010000000500000095F3C5DE8B773B405E9D6340F6C84C4095F3C5DE8B773B408ECA4DD4D2CA4C409A232BBF0C7E3B408ECA4DD4D2CA4C409A232BBF0C7E3B405E9D6340F6C84C4095F3C5DE8B773B405E9D6340F6C84C40
58427	57390	27.846084999999999	27.881577	57.718108999999998	57.700650000000003	Псковская	0103000020E61000000100000005000000DBA2CC0699D83B40A1F831E6AED94C40DBA2CC0699D83B404CFBE6FEEADB4C40E2E7BF07AFE13B404CFBE6FEEADB4C40E2E7BF07AFE13B40A1F831E6AED94C40DBA2CC0699D83B40A1F831E6AED94C40
58515	48096	27.799012999999999	27.806891	57.640825999999997	57.638778000000002	Центральная	0103000020E610000001000000050000002F14B01D8CCC3B40C0B33D7AC3D14C402F14B01D8CCC3B4097361C9606D24C40CE6F986890CE3B4097361C9606D24C40CE6F986890CE3B40C0B33D7AC3D14C402F14B01D8CCC3B40C0B33D7AC3D14C40
58465	57392	27.992788999999998	28.028047999999998	57.548848	57.533183000000001	Островская	0103000020E610000001000000050000001BD47E6B27FE3B403FE42D573FC44C401BD47E6B27FE3B40CD3CB9A640C64C40DCB75A272E073C40CD3CB9A640C64C40DCB75A272E073C403FE42D573FC44C401BD47E6B27FE3B403FE42D573FC44C40
58340	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	Фестивальная	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58347	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	Тимура Апакидзе	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58402	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	Пригородная	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58367	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	Освобождения	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58539	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	Ветеранов войны	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58395	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	Б.Пионерская	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58376	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	Авиационная	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58406	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	25 Октября	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58368	15838	28.277464999999999	28.403921	57.366604000000002	57.330070999999997	 Б.Пионерская	0103000020E61000000100000005000000DEC83CF207473C40D32D3BC43FAA4C40DEC83CF207473C40994A3FE1ECAE4C40E92ADD5D67673C40994A3FE1ECAE4C40E92ADD5D67673C40D32D3BC43FAA4C40DEC83CF207473C40D32D3BC43FAA4C40
58345	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Стученко	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58516	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Набережная	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58420	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Ленина	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58486	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Красногородская	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58430	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Коммунальная	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58352	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Дзержинского	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58522	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Гагарина	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58488	57372	28.625993000000001	28.727647000000001	56.728262000000001	56.696742999999998	Басковская	0103000020E610000001000000050000006286C61341A03C40C45BE7DF2E594C406286C61341A03C40B47570B0375D4C405308E41247BA3C40B47570B0375D4C405308E41247BA3C40C45BE7DF2E594C406286C61341A03C40C45BE7DF2E594C40
58385	57381	30.135998000000001	30.173736999999999	56.356127999999998	56.317912	Тихмянова	0103000020E610000001000000050000004852D2C3D0223E40C3802557B1284C404852D2C3D0223E404E98309A952D4C40EB1A2D077A2C3E404E98309A952D4C40EB1A2D077A2C3E40C3802557B1284C404852D2C3D0223E40C3802557B1284C40
58433	57381	30.135998000000001	30.173736999999999	56.356127999999998	56.317912	Партизанская	0103000020E610000001000000050000004852D2C3D0223E40C3802557B1284C404852D2C3D0223E404E98309A952D4C40EB1A2D077A2C3E404E98309A952D4C40EB1A2D077A2C3E40C3802557B1284C404852D2C3D0223E40C3802557B1284C40
58500	57381	30.135998000000001	30.173736999999999	56.356127999999998	56.317912	Загородная	0103000020E610000001000000050000004852D2C3D0223E40C3802557B1284C404852D2C3D0223E404E98309A952D4C40EB1A2D077A2C3E404E98309A952D4C40EB1A2D077A2C3E40C3802557B1284C404852D2C3D0223E40C3802557B1284C40
58423	57381	30.135998000000001	30.173736999999999	56.356127999999998	56.317912	Воровского	0103000020E610000001000000050000004852D2C3D0223E40C3802557B1284C404852D2C3D0223E404E98309A952D4C40EB1A2D077A2C3E404E98309A952D4C40EB1A2D077A2C3E40C3802557B1284C404852D2C3D0223E40C3802557B1284C40
58337	18720	29.311606000000001	29.368307000000001	57.039374000000002	57.021731000000003	Некрасова	0103000020E61000000100000005000000C53C2B69C54F3D409A27D714C8824C40C53C2B69C54F3D4007280D350A854C404CE3175E495E3D4007280D350A854C404CE3175E495E3D409A27D714C8824C40C53C2B69C54F3D409A27D714C8824C40
58350	2162	29.631316000000002	29.667840999999999	56.143749	56.126168	Ленинградская	0103000020E610000001000000050000000971E5EC9DA13D409FE6E44526104C400971E5EC9DA13D4096EA025E66124C408DEDB5A0F7AA3D4096EA025E66124C408DEDB5A0F7AA3D409FE6E44526104C400971E5EC9DA13D409FE6E44526104C40
58476	2110	29.554447	29.586175999999998	55.862094999999997	55.851818000000002	Центральная	0103000020E61000000100000005000000855D143DF08D3D4073124A5F08ED4B40855D143DF08D3D40C685032159EE4B4039B35DA10F963D40C685032159EE4B4039B35DA10F963D4073124A5F08ED4B40855D143DF08D3D4073124A5F08ED4B40
58499	1694	29.690874000000001	29.725603	55.947364	55.925778000000001	Ленина	0103000020E610000001000000050000001EA8531EDDB03D409BADBCE47FF64B401EA8531EDDB03D4031B43A3943F94B4026E1421EC1B93D4031B43A3943F94B4026E1421EC1B93D409BADBCE47FF64B401EA8531EDDB03D409BADBCE47FF64B40
58357	833	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	М.Маметовой	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
58358	833	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	Ленина	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
58341	833	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	Красный переулок	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
58412	833	29.883239	29.967178000000001	56.049199000000002	55.996997999999998	Комсомольская	0103000020E610000001000000050000003F8D7BF31BE23D40B51666A19DFF4B403F8D7BF31BE23D407AFF1F274C064C40236937FA98F73D407AFF1F274C064C40236937FA98F73D40B51666A19DFF4B403F8D7BF31BE23D40B51666A19DFF4B40
58557	57450	30.354675	30.379487000000001	55.875591999999997	55.863155999999996	Центральная	0103000020E6100000010000000500000074B515FBCB5A3E404FAC53E57BEE4B4074B515FBCB5A3E40D2510E6613F04B40D5415E0F26613E40D2510E6613F04B40D5415E0F26613E404FAC53E57BEE4B4074B515FBCB5A3E404FAC53E57BEE4B40
58353	24813	30.127707000000001	30.170655	56.838754999999999	56.811748999999999	Социалистическая	0103000020E610000001000000050000006478EC67B1203E40C5C72764E7674C406478EC67B1203E40A12DE7525C6B4C401DE6CB0BB02B3E40A12DE7525C6B4C401DE6CB0BB02B3E40C5C72764E7674C406478EC67B1203E40C5C72764E7674C40
58409	24813	30.127707000000001	30.170655	56.838754999999999	56.811748999999999	Первомайская	0103000020E610000001000000050000006478EC67B1203E40C5C72764E7674C406478EC67B1203E40A12DE7525C6B4C401DE6CB0BB02B3E40A12DE7525C6B4C401DE6CB0BB02B3E40C5C72764E7674C406478EC67B1203E40C5C72764E7674C40
58408	24813	30.127707000000001	30.170655	56.838754999999999	56.811748999999999	Октябрьская	0103000020E610000001000000050000006478EC67B1203E40C5C72764E7674C406478EC67B1203E40A12DE7525C6B4C401DE6CB0BB02B3E40A12DE7525C6B4C401DE6CB0BB02B3E40C5C72764E7674C406478EC67B1203E40C5C72764E7674C40
58543	48147	30.013100000000001	30.017861	56.594231000000001	56.591976000000003	Центральная	0103000020E61000000100000005000000DE9387855A033E402A029CDEC54B4C40DE9387855A033E407BA2EBC20F4C4C40B5DFDA8992043E407BA2EBC20F4C4C40B5DFDA8992043E402A029CDEC54B4C40DE9387855A033E402A029CDEC54B4C40
58523	27045	30.945119999999999	30.997456	56.303261999999997	56.265447000000002	переулок Новый	0103000020E61000000100000005000000A7CB6262F3F13E4021E9D32AFA214C40A7CB6262F3F13E404D0F0A4AD1264C40F032C34659FF3E404D0F0A4AD1264C40F032C34659FF3E4021E9D32AFA214C40A7CB6262F3F13E4021E9D32AFA214C40
58532	27045	30.945119999999999	30.997456	56.303261999999997	56.265447000000002	Полевая	0103000020E61000000100000005000000A7CB6262F3F13E4021E9D32AFA214C40A7CB6262F3F13E404D0F0A4AD1264C40F032C34659FF3E404D0F0A4AD1264C40F032C34659FF3E4021E9D32AFA214C40A7CB6262F3F13E4021E9D32AFA214C40
58473	27045	30.945119999999999	30.997456	56.303261999999997	56.265447000000002	Дзержинского	0103000020E61000000100000005000000A7CB6262F3F13E4021E9D32AFA214C40A7CB6262F3F13E404D0F0A4AD1264C40F032C34659FF3E404D0F0A4AD1264C40F032C34659FF3E4021E9D32AFA214C40A7CB6262F3F13E4021E9D32AFA214C40
58494	27045	30.945119999999999	30.997456	56.303261999999997	56.265447000000002	Больничная	0103000020E61000000100000005000000A7CB6262F3F13E4021E9D32AFA214C40A7CB6262F3F13E404D0F0A4AD1264C40F032C34659FF3E404D0F0A4AD1264C40F032C34659FF3E4021E9D32AFA214C40A7CB6262F3F13E4021E9D32AFA214C40
58510	46897	28.299634999999999	28.332388000000002	56.82405	56.709116999999999	Центральная	0103000020E61000000100000005000000A9BC1DE1B44C3C40D1048A58C45A4C40A9BC1DE1B44C3C4068226C787A694C403695456117553C4068226C787A694C403695456117553C40D1048A58C45A4C40A9BC1DE1B44C3C40D1048A58C45A4C40
58530	19302	28.265329000000001	28.308529	56.847326000000002	56.821686	Школьная	0103000020E610000001000000050000002EAEF199EC433C4060CAC0012D694C402EAEF199EC433C407786A92D756C4C401ADEACC1FB4E3C407786A92D756C4C401ADEACC1FB4E3C4060CAC0012D694C402EAEF199EC433C4060CAC0012D694C40
58348	19302	28.265329000000001	28.308529	56.847326000000002	56.821686	Советская	0103000020E610000001000000050000002EAEF199EC433C4060CAC0012D694C402EAEF199EC433C407786A92D756C4C401ADEACC1FB4E3C407786A92D756C4C401ADEACC1FB4E3C4060CAC0012D694C402EAEF199EC433C4060CAC0012D694C40
58390	19302	28.265329000000001	28.308529	56.847326000000002	56.821686	Синерецкая	0103000020E610000001000000050000002EAEF199EC433C4060CAC0012D694C402EAEF199EC433C407786A92D756C4C401ADEACC1FB4E3C407786A92D756C4C401ADEACC1FB4E3C4060CAC0012D694C402EAEF199EC433C4060CAC0012D694C40
58335	6658	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	Энергетиков	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
58332	6658	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	Омельянюка	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
58383	6658	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	Ленина	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
58552	6658	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	Космонавтов	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
58392	6658	29.939392999999999	29.989304000000001	57.839171	57.811177000000001	Бисениек	0103000020E610000001000000050000006117450F7CF03D403A22DFA5D4E74C406117450F7CF03D40356090F469EB4C404FCDE50643FD3D40356090F469EB4C404FCDE50643FD3D403A22DFA5D4E74C406117450F7CF03D403A22DFA5D4E74C40
58554	45435	29.99879	30.031929000000002	57.826841999999999	57.811225	Шоссейная	0103000020E61000000100000005000000649291B3B0FF3D404B598638D6E74C40649291B3B0FF3D40C87A6AF5D5E94C4043CBBA7F2C083E40C87A6AF5D5E94C4043CBBA7F2C083E404B598638D6E74C40649291B3B0FF3D404B598638D6E74C40
58545	15523	30.104216000000001	30.133662999999999	57.556628000000003	57.543593000000001	 пер.Школьный	0103000020E610000001000000050000004EB857E6AD1A3E40D2AA967494C54C404EB857E6AD1A3E40DA0418963FC74C406CAF05BD37223E40DA0418963FC74C406CAF05BD37223E40D2AA967494C54C404EB857E6AD1A3E40D2AA967494C54C40
58546	45749	30.338964000000001	30.362670000000001	57.558236000000001	57.549079999999996	Центральная	0103000020E6100000010000000500000077853E58C6563E409F71E14048C64C4077853E58C6563E4095B9F94674C74C40863DEDF0D75C3E4095B9F94674C74C40863DEDF0D75C3E409F71E14048C64C4077853E58C6563E409F71E14048C64C40
58490	15272	29.783455	29.803936	57.472113	57.451605999999998	1-ая Советская	0103000020E610000001000000050000003FE3C28190C83D40B456B439CEB94C403FE3C28190C83D401B82E3326EBC4C40BA13ECBFCECD3D401B82E3326EBC4C40BA13ECBFCECD3D40B456B439CEB94C403FE3C28190C83D40B456B439CEB94C40
58531	45844	29.859829000000001	29.874562000000001	57.565950000000001	57.559804999999997	Мира	0103000020E610000001000000050000000327DBC01DDC3D409291B3B0A7C74C400327DBC01DDC3D40EA95B20C71C84C400953944BE3DF3D40EA95B20C71C84C400953944BE3DF3D409291B3B0A7C74C400327DBC01DDC3D409291B3B0A7C74C40
58537	15052	29.483533999999999	29.498635	57.393115000000002	57.379401000000001	Центральная	0103000020E610000001000000050000000A815CE2C87B3D40EC88433690B04C400A815CE2C87B3D409548A29751B24C4016A4198BA67F3D409548A29751B24C4016A4198BA67F3D40EC88433690B04C400A815CE2C87B3D40EC88433690B04C40
58574	45788	30.054548	30.097639999999998	57.633232999999997	57.621141999999999	Центральная	0103000020E61000000100000005000000ED0F94DBF60D3E400516C09481CF4C40ED0F94DBF60D3E40BDDF68C70DD14C400CC85EEFFE183E40BDDF68C70DD14C400CC85EEFFE183E400516C09481CF4C40ED0F94DBF60D3E400516C09481CF4C40
58511	45873	29.904026000000002	29.920905999999999	57.532637000000001	57.522629000000002	Советской Армии	0103000020E61000000100000005000000D4BB783F6EE73D407978CF81E5C24C40D4BB783F6EE73D40DDD1FF722DC44C40AFB0E07EC0EB3D40DDD1FF722DC44C40AFB0E07EC0EB3D407978CF81E5C24C40D4BB783F6EE73D407978CF81E5C24C40
58562	57457	29.946095	29.966602999999999	57.597275000000003	57.587989999999998	Центральная	0103000020E61000000100000005000000BCE82B4833F23D4001309E4143CB4C40BCE82B4833F23D40F5DBD78173CC4C402A37514B73F73D40F5DBD78173CC4C402A37514B73F73D4001309E4143CB4C40BCE82B4833F23D4001309E4143CB4C40
58414	14954	29.923466000000001	29.968283	57.561374000000001	57.534520999999998	Энергетиков	0103000020E61000000100000005000000CBF78C4468EC3D403A03232F6BC44C40CBF78C4468EC3D4090696D1ADBC74C40D4450A65E1F73D4090696D1ADBC74C40D4450A65E1F73D403A03232F6BC44C40CBF78C4468EC3D403A03232F6BC44C40
58400	14954	29.923466000000001	29.968283	57.561374000000001	57.534520999999998	Пионерская	0103000020E61000000100000005000000CBF78C4468EC3D403A03232F6BC44C40CBF78C4468EC3D4090696D1ADBC74C40D4450A65E1F73D4090696D1ADBC74C40D4450A65E1F73D403A03232F6BC44C40CBF78C4468EC3D403A03232F6BC44C40
58336	14954	29.923466000000001	29.968283	57.561374000000001	57.534520999999998	Октябрьская	0103000020E61000000100000005000000CBF78C4468EC3D403A03232F6BC44C40CBF78C4468EC3D4090696D1ADBC74C40D4450A65E1F73D4090696D1ADBC74C40D4450A65E1F73D403A03232F6BC44C40CBF78C4468EC3D403A03232F6BC44C40
58559	57453	29.561758999999999	29.576411	57.523881000000003	57.518718999999997	Озёрная	0103000020E61000000100000005000000D13B1570CF8F3D402B685A6265C24C40D13B1570CF8F3D4076FF58880EC34C40FE0DDAAB8F933D4076FF58880EC34C40FE0DDAAB8F933D402B685A6265C24C40D13B1570CF8F3D402B685A6265C24C40
58555	15354	30.122226999999999	30.141784000000001	57.403740999999997	57.388317999999998	Торфяников	0103000020E610000001000000050000002DB0C7444A1F3E405C397B67B4B14C402DB0C7444A1F3E40F486FBC8ADB34C409818CBF44B243E40F486FBC8ADB34C409818CBF44B243E405C397B67B4B14C402DB0C7444A1F3E405C397B67B4B14C40
58519	57411	29.816161999999998	29.833822999999999	57.637878000000001	57.629783000000003	Школьная	0103000020E61000000100000005000000EA3C2AFEEFD03D40D449B6BA9CD04C40EA3C2AFEEFD03D40406B7EFCA5D14C4011A7936C75D53D40406B7EFCA5D14C4011A7936C75D53D40D449B6BA9CD04C40EA3C2AFEEFD03D40D449B6BA9CD04C40
58410	28860	27.800864000000001	27.839464	58.753315000000001	58.728565000000003	Ленина	0103000020E61000000100000005000000338B506C05CD3B405001309E415D4D40338B506C05CD3B400A4B3CA06C604D405A2BDA1CE7D63B400A4B3CA06C604D405A2BDA1CE7D63B405001309E415D4D40338B506C05CD3B405001309E415D4D40
58355	28860	27.800864000000001	27.839464	58.753315000000001	58.728565000000003	Колхозная	0103000020E61000000100000005000000338B506C05CD3B405001309E415D4D40338B506C05CD3B400A4B3CA06C604D405A2BDA1CE7D63B400A4B3CA06C604D405A2BDA1CE7D63B405001309E415D4D40338B506C05CD3B405001309E415D4D40
58413	28860	27.800864000000001	27.839464	58.753315000000001	58.728565000000003	Карла Маркса	0103000020E61000000100000005000000338B506C05CD3B405001309E415D4D40338B506C05CD3B400A4B3CA06C604D405A2BDA1CE7D63B400A4B3CA06C604D405A2BDA1CE7D63B405001309E415D4D40338B506C05CD3B405001309E415D4D40
58484	46456	30.603283999999999	30.608754999999999	56.496026000000001	56.490813000000003	Центральная	0103000020E610000001000000050000003733FAD1709A3E40D0B9DBF5D23E4C403733FAD1709A3E409CFBABC77D3F4C40C746205ED79B3E409CFBABC77D3F4C40C746205ED79B3E40D0B9DBF5D23E4C403733FAD1709A3E40D0B9DBF5D23E4C40
58493	18628	29.886581	29.924893999999998	57.292845	57.272829999999999	Первомайская	0103000020E610000001000000050000004641F0F8F6E23D4010AFEB17ECA24C404641F0F8F6E23D4008E6E8F17BA54C4041446ADAC5EC3D4008E6E8F17BA54C4041446ADAC5EC3D4010AFEB17ECA24C404641F0F8F6E23D4010AFEB17ECA24C40
58521	18558	30.271841999999999	30.289439999999999	57.052574999999997	57.040098999999998	Советская	0103000020E61000000100000005000000E2ADF36F97453E4018CDCAF621854C40E2ADF36F97453E4029CB10C7BA864C407C2766BD184A3E4029CB10C7BA864C407C2766BD184A3E4018CDCAF621854C40E2ADF36F97453E4018CDCAF621854C40
58544	15333	29.974993000000001	30.002777999999999	57.431125999999999	57.415743999999997	Центральная	0103000020E6100000010000000500000035D4282499F93D400DC1711937B54C4035D4282499F93D40473A03232FB74C40F6251B0FB6003E40473A03232FB74C40F6251B0FB6003E400DC1711937B54C4035D4282499F93D400DC1711937B54C40
58492	18333	29.898682000000001	29.908041999999998	57.014684000000003	57.010312999999996	Октябрьская	0103000020E61000000100000005000000FE80070610E63D40A0DCB6EF51814C40FE80070610E63D4022E3512AE1814C40F964C57075E83D4022E3512AE1814C40F964C57075E83D40A0DCB6EF51814C40FE80070610E63D40A0DCB6EF51814C40
58512	18278	29.398606999999998	29.422250999999999	56.782159	56.763449999999999	Школьная	0103000020E61000000100000005000000E8F4BC1B0B663D40CB10C7BAB8614C40E8F4BC1B0B663D40D3A23EC91D644C400BB43BA4186C3D40D3A23EC91D644C400BB43BA4186C3D40CB10C7BAB8614C40E8F4BC1B0B663D40CB10C7BAB8614C40
58491	18248	30.059920000000002	30.108546	57.078951000000004	57.057513999999998	Советская	0103000020E610000001000000050000005760C8EA560F3E40F487669E5C874C405760C8EA560F3E40467EFD101B8A4C40931CB0ABC91B3E40467EFD101B8A4C40931CB0ABC91B3E40F487669E5C874C405760C8EA560F3E40F487669E5C874C40
58338	17910	29.863216000000001	29.923124999999999	57.021220999999997	56.967066000000003	Смольная	0103000020E610000001000000050000004A6249B9FBDC3D406A8995D1C87B4C404A6249B9FBDC3D40847EA65EB7824C40B81E85EB51EC3D40847EA65EB7824C40B81E85EB51EC3D406A8995D1C87B4C404A6249B9FBDC3D406A8995D1C87B4C40
58404	17910	29.863216000000001	29.923124999999999	57.021220999999997	56.967066000000003	Лары Михеенко	0103000020E610000001000000050000004A6249B9FBDC3D406A8995D1C87B4C404A6249B9FBDC3D40847EA65EB7824C40B81E85EB51EC3D40847EA65EB7824C40B81E85EB51EC3D406A8995D1C87B4C404A6249B9FBDC3D406A8995D1C87B4C40
58379	17910	29.863216000000001	29.923124999999999	57.021220999999997	56.967066000000003	Зеленая	0103000020E610000001000000050000004A6249B9FBDC3D406A8995D1C87B4C404A6249B9FBDC3D40847EA65EB7824C40B81E85EB51EC3D40847EA65EB7824C40B81E85EB51EC3D406A8995D1C87B4C404A6249B9FBDC3D406A8995D1C87B4C40
15850	15086	31.229275000000001	31.239865999999999	58.585540000000002	58.572567999999997	улица Центральная	0103000020E6100000010000000500000058CA32C4B13A3F40395E81E849494D4058CA32C4B13A3F40FB3F87F9F24A4D401E6CB1DB673D3F40FB3F87F9F24A4D401E6CB1DB673D3F40395E81E849494D4058CA32C4B13A3F40395E81E849494D40
4231	15086	31.225152000000001	31.233812	58.579582000000002	58.577851000000003	улица Пролетарская	0103000020E6100000010000000500000006A1BC8FA3393F40FF7A8505F7494D4006A1BC8FA3393F40D6AC33BE2F4A4D4090696D1ADB3B3F40D6AC33BE2F4A4D4090696D1ADB3B3F40FF7A8505F7494D4006A1BC8FA3393F40FF7A8505F7494D40
57985	57344	31.313717	31.39134	58.015914000000002	57.968438999999996	Пищевиков переулок	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58038	57344	31.313717	31.39134	58.015914000000002	57.968438999999996	Ленинградская	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58037	57344	31.313717	31.39134	58.015914000000002	57.968438999999996	Клары Цеткин	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58040	57344	31.313717	31.39134	58.015914000000002	57.968438999999996	Карла Маркса	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
57993	57344	31.313717	31.39134	58.015914000000002	57.968438999999996	Карла Либкнехта	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58113	57344	31.313717	31.39134	58.015914000000002	57.968438999999996	Володарского	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58118	57350	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	проспект Советский	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
58032	57345	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	Устюженское шоссе	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
58224	870	32.317287999999998	32.338729999999998	57.422485999999999	57.406165000000001	Школьная	0103000020E61000000100000005000000E5B4A7E49C284040D2E3F736FDB34C40E5B4A7E49C2840404982700514B64C40481630815B2B40404982700514B64C40481630815B2B4040D2E3F736FDB34C40E5B4A7E49C284040D2E3F736FDB34C40
57987	57345	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	Новгородская	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
57989	57345	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	Боровичская	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
58029	57347	33.25273	33.341628	58.427219000000001	58.365101000000003	Театральная	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
58012	57347	33.25273	33.341628	58.427219000000001	58.365101000000003	Советская	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
58028	57347	33.25273	33.341628	58.427219000000001	58.365101000000003	Николая Николаева	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
58116	57343	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	Карла Маркса	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
4201	14948	31.211919999999999	31.218917999999999	58.551777999999999	58.546970000000002	улица Центральная	0103000020E610000001000000050000004A5E9D6340363F4052F2EA1C03464D404A5E9D6340363F407E5358A9A0464D40778192020B383F407E5358A9A0464D40778192020B383F4052F2EA1C03464D404A5E9D6340363F4052F2EA1C03464D40
3698	1808	31.221647999999998	31.260285	58.524445	58.501990999999997	улица Псковская	0103000020E610000001000000050000004B395FECBD383F4073F1B73D41404D404B395FECBD383F407EC6850321434D40ADA3AA09A2423F407EC6850321434D40ADA3AA09A2423F4073F1B73D41404D404B395FECBD383F4073F1B73D41404D40
3384	1808	31.216276000000001	31.224011000000001	58.548299	58.538722999999997	улица Коровникова	0103000020E61000000100000005000000E2E82ADD5D373F402F4D11E0F4444D40E2E82ADD5D373F40FAB660A92E464D40BBF1EEC858393F40FAB660A92E464D40BBF1EEC858393F402F4D11E0F4444D40E2E82ADD5D373F402F4D11E0F4444D40
3224	1808	31.262135000000001	31.289156999999999	58.577269000000001	58.525587000000002	улица Большая Санкт-Петербургская	0103000020E61000000100000005000000102384471B433F40F419506F46434D40102384471B433F4050FF59F3E3494D40D3687231064A3F4050FF59F3E3494D40D3687231064A3F40F419506F46434D40102384471B433F40F419506F46434D40
3143	1808	31.285339	31.287755000000001	58.523581	58.520187999999997	улица Большая Дворцовая	0103000020E61000000100000005000000FA4509FA0B493F40C5E2378595424D40FA4509FA0B493F404BE7C3B304434D40AF42CA4FAA493F404BE7C3B304434D40AF42CA4FAA493F40C5E2378595424D40FA4509FA0B493F40C5E2378595424D40
58322	1808	31.352011999999998	31.424461000000001	58.650545999999999	58.586835000000001	микрорайон Кречевицы	0103000020E61000000100000005000000AFCC5B751D5A3F40F792C6681D4B4D40AFCC5B751D5A3F409545611745534D406E6DE179A96C3F409545611745534D406E6DE179A96C3F40F792C6681D4B4D40AFCC5B751D5A3F40F792C6681D4B4D40
58084	1808	31.352011999999998	31.424461000000001	58.650545999999999	58.586835000000001	микрорайон Кречевицы	0103000020E61000000100000005000000AFCC5B751D5A3F40F792C6681D4B4D40AFCC5B751D5A3F409545611745534D406E6DE179A96C3F409545611745534D406E6DE179A96C3F40F792C6681D4B4D40AFCC5B751D5A3F40F792C6681D4B4D40
58309	1808	31.284538999999999	31.327909999999999	58.54898	58.530769999999997	микрорайон Антоново	0103000020E61000000100000005000000C16F438CD7483F4055D97745F0434D40C16F438CD7483F403C1405FA44464D400708E6E8F1533F403C1405FA44464D400708E6E8F1533F4055D97745F0434D40C16F438CD7483F4055D97745F0434D40
58069	1808	31.271585999999999	31.283173999999999	58.529007999999997	58.528866999999998	Яковлева	0103000020E610000001000000050000002C0DFCA886453F408177F2E9B1434D402C0DFCA886453F4043A9BD88B6434D40D7135D177E483F4043A9BD88B6434D40D7135D177E483F408177F2E9B1434D402C0DFCA886453F408177F2E9B1434D40
58070	1808	31.279976000000001	31.289552	58.566138000000002	58.562322000000002	Щусева	0103000020E6100000010000000500000037AAD381AC473F4021E9D32AFA474D4037AAD381AC473F40ED82C13577484D40CC7D7214204A3F40ED82C13577484D40CC7D7214204A3F4021E9D32AFA474D4037AAD381AC473F4021E9D32AFA474D40
58071	1808	31.264614999999999	31.270921000000001	58.539540000000002	58.5383	Чудовская	0103000020E61000000100000005000000F20703CFBD433F40E9B7AF03E7444D40F20703CFBD433F4022718FA50F454D40B4CC22145B453F4022718FA50F454D40B4CC22145B453F40E9B7AF03E7444D40F20703CFBD433F40E9B7AF03E7444D40
58062	1808	31.261561	31.269124000000001	58.523758999999998	58.522193999999999	Чудинцева	0103000020E61000000100000005000000B8E864A9F5423F406E15C440D7424D40B8E864A9F5423F402AFEEF880A434D4097917A4FE5443F402AFEEF880A434D4097917A4FE5443F406E15C440D7424D40B8E864A9F5423F406E15C440D7424D40
58068	1808	31.286929000000001	31.298552999999998	58.524154000000003	58.522038999999999	Фёдоровский Ручей	0103000020E610000001000000050000002446CF2D74493F40471E882CD2424D402446CF2D74493F40A708707A17434D40681F2BF86D4C3F40A708707A17434D40681F2BF86D4C3F40471E882CD2424D402446CF2D74493F40471E882CD2424D40
58063	1808	31.262495000000001	31.273130999999999	58.515844999999999	58.509278000000002	Троицкая	0103000020E61000000100000005000000105D50DF32433F404149810530414D40105D50DF32433F400E677E3507424D401686C8E9EB453F400E677E3507424D401686C8E9EB453F404149810530414D40105D50DF32433F404149810530414D40
58048	1808	31.288302999999999	31.308920000000001	58.538051000000003	58.533836999999998	Студенческая	0103000020E61000000100000005000000B456B439CE493F40873254C554444D40B456B439CE493F40414AECDADE444D4090149161154F3F40414AECDADE444D4090149161154F3F40873254C554444D40B456B439CE493F40873254C554444D40
58065	1808	31.225484000000002	31.244357999999998	58.541611000000003	58.540492999999998	Свободы	0103000020E6100000010000000500000072C5C551B9393F40C45BE7DF2E454D4072C5C551B9393F40B2135E8253454D401684F23E8E3E3F40B2135E8253454D401684F23E8E3E3F40C45BE7DF2E454D4072C5C551B9393F40C45BE7DF2E454D40
58045	1808	31.288599999999999	31.300187999999999	58.521034	58.518777999999998	Рогатица	0103000020E6100000010000000500000027A089B0E1493F4030F1475167424D4027A089B0E1493F40520DFB3DB1424D40D2A6EA1ED94C3F40520DFB3DB1424D40D2A6EA1ED94C3F4030F1475167424D4027A089B0E1493F4030F1475167424D40
58074	1808	31.303439999999998	31.312100000000001	58.541879000000002	58.538356	Рахманинова	0103000020E61000000100000005000000594C6C3EAE4D3F407DCD72D9E8444D40594C6C3EAE4D3F40D1B1834A5C454D40E4141DC9E54F3F40D1B1834A5C454D40E4141DC9E54F3F407DCD72D9E8444D40594C6C3EAE4D3F407DCD72D9E8444D40
58055	1808	31.221647999999998	31.260285	58.524445	58.501990999999997	Псковская	0103000020E610000001000000050000004B395FECBD383F4073F1B73D41404D404B395FECBD383F407EC6850321434D40ADA3AA09A2423F407EC6850321434D40ADA3AA09A2423F4073F1B73D41404D404B395FECBD383F4073F1B73D41404D40
58059	1808	31.252362000000002	31.268927000000001	58.520094	58.516945	Прусская	0103000020E61000000100000005000000CFC0C8CB9A403F40556AF6402B424D40CFC0C8CB9A403F40446CB07092424D40EB025E66D8443F40446CB07092424D40EB025E66D8443F40556AF6402B424D40CFC0C8CB9A403F40556AF6402B424D40
58053	1808	31.291663	31.298490000000001	58.547336000000001	58.537384000000003	Парковая	0103000020E610000001000000050000000874266DAA4A3F4064B2B8FFC8444D400874266DAA4A3F4034F6251B0F464D40DC2E34D7694C3F4034F6251B0F464D40DC2E34D7694C3F4064B2B8FFC8444D400874266DAA4A3F4064B2B8FFC8444D40
58060	1808	31.211604999999999	31.258111	58.530309000000003	58.498303999999997	Октябрьская	0103000020E610000001000000050000008AABCABE2B363F40A5BBEB6CC83F4D408AABCABE2B363F4022E3512AE1434D40E4BCFF8F13423F4022E3512AE1434D40E4BCFF8F13423F40A5BBEB6CC83F4D408AABCABE2B363F40A5BBEB6CC83F4D40
58078	1808	31.256584	31.272089000000001	58.533653999999999	58.524557999999999	Новолучанская	0103000020E6100000010000000500000047AD307DAF413F40766D6FB724434D4047AD307DAF413F4096B036C64E444D40F299EC9FA7453F4096B036C64E444D40F299EC9FA7453F40766D6FB724434D4047AD307DAF413F40766D6FB724434D40
58043	1808	31.311983000000001	31.312719999999999	58.580815999999999	58.579456	Новгородская	0103000020E6100000010000000500000071E82D1EDE4F3F4049BC3C9D2B4A4D4071E82D1EDE4F3F402C7FBE2D584A4D401CCEFC6A0E503F402C7FBE2D584A4D401CCEFC6A0E503F4049BC3C9D2B4A4D4071E82D1EDE4F3F4049BC3C9D2B4A4D40
58077	1808	31.169267999999999	31.250098000000001	58.525333000000003	58.515867999999998	Нехинская	0103000020E610000001000000050000006342CC25552B3F40C6866EF607424D406342CC25552B3F403A419B1C3E434D4086CB2A6C06403F403A419B1C3E434D4086CB2A6C06403F40C6866EF607424D406342CC25552B3F40C6866EF607424D40
58066	1808	31.297376	31.332643999999998	58.5334	58.532972999999998	Московская	0103000020E61000000100000005000000849D62D5204C3F405453927538444D40849D62D5204C3F40DCD7817346444D40EB353D2828553F40DCD7817346444D40EB353D2828553F405453927538444D40849D62D5204C3F405453927538444D40
58075	1808	31.251705999999999	31.253062	58.543306999999999	58.537717999999998	Менделеева	0103000020E61000000100000005000000FC34EECD6F403F403A3C84F1D3444D40FC34EECD6F403F400C5872158B454D4040DCD5ABC8403F400C5872158B454D4040DCD5ABC8403F403A3C84F1D3444D40FC34EECD6F403F403A3C84F1D3444D40
58123	1808	31.262682999999999	31.270192999999999	58.525235000000002	58.523628000000002	Людогоща	0103000020E6100000010000000500000015376E313F433F408CA2073E06434D4015376E313F433F4077DB85E63A434D40AE9B525E2B453F4077DB85E63A434D40AE9B525E2B453F408CA2073E06434D4015376E313F433F408CA2073E06434D40
58079	1808	31.237908000000001	31.245049000000002	58.544176	58.524403	Ломоносова	0103000020E61000000100000005000000EF74E789E73C3F404F7633A31F434D40EF74E789E73C3F4051A2258FA7454D40E2EA0088BB3E3F4051A2258FA7454D40E2EA0088BB3E3F404F7633A31F434D40EF74E789E73C3F404F7633A31F434D40
58046	1808	31.218612	31.232527000000001	58.549270999999997	58.525004000000003	Кочетова	0103000020E610000001000000050000005E83BEF4F6373F407522C15433434D405E83BEF4F6373F4013D21A834E464D40DF6FB4E3863B3F4013D21A834E464D40DF6FB4E3863B3F407522C15433434D405E83BEF4F6373F407522C15433434D40
58131	1808	31.252766000000001	31.255659000000001	58.543076999999997	58.532015000000001	Космонавтов	0103000020E610000001000000050000006E8AC745B5403F40A0FD481119444D406E8AC745B5403F40DA1A118C83454D4096ED43DE72413F40DA1A118C83454D4096ED43DE72413F40A0FD481119444D406E8AC745B5403F40A0FD481119444D40
58050	1808	31.216276000000001	31.224011000000001	58.548299	58.538722999999997	Коровникова	0103000020E61000000100000005000000E2E82ADD5D373F402F4D11E0F4444D40E2E82ADD5D373F40FAB660A92E464D40BBF1EEC858393F40FAB660A92E464D40BBF1EEC858393F402F4D11E0F4444D40E2E82ADD5D373F402F4D11E0F4444D40
58051	1808	31.216618	31.253	58.538722999999997	58.532080000000001	Зелинского	0103000020E6100000010000000500000095B9F94674373F40876D8B321B444D4095B9F94674373F402F4D11E0F4444D4054E3A59BC4403F402F4D11E0F4444D4054E3A59BC4403F40876D8B321B444D4095B9F94674373F40876D8B321B444D40
58082	1808	31.267022000000001	31.326319999999999	58.550482000000002	58.534269999999999	Державина	0103000020E610000001000000050000000150C58D5B443F40F19D98F562444D400150C58D5B443F40B284B53176464D40DD0720B589533F40B284B53176464D40DD0720B589533F40F19D98F562444D400150C58D5B443F40F19D98F562444D40
58085	1808	31.258111	31.266214000000002	58.536172000000001	58.525202	Германа	0103000020E61000000100000005000000E4BCFF8F13423F409BE5B2D139434D40E4BCFF8F13423F40F583BA48A1444D40C3BCC79926443F40F583BA48A1444D40C3BCC79926443F409BE5B2D139434D40E4BCFF8F13423F409BE5B2D139434D40
58064	1808	31.251742	31.253637000000001	58.525488000000003	58.522936999999999	Великолукская	0103000020E610000001000000050000009607E92972403F40266F8099EF424D409607E92972403F406138D73043434D40390EBC5AEE403F406138D73043434D40390EBC5AEE403F40266F8099EF424D409607E92972403F40266F8099EF424D40
58073	1808	31.263159999999999	31.280237	58.543067000000001	58.525765999999997	Великая	0103000020E61000000100000005000000889D29745E433F40A3ACDF4C4C434D40889D29745E433F40B7442E3883454D401021AE9CBD473F40B7442E3883454D401021AE9CBD473F40A3ACDF4C4C434D40889D29745E433F40A3ACDF4C4C434D40
58080	1808	31.262135000000001	31.289156999999999	58.577269000000001	58.525587000000002	Большая Санкт-Петербургская	0103000020E61000000100000005000000102384471B433F40F419506F46434D40102384471B433F4050FF59F3E3494D40D3687231064A3F4050FF59F3E3494D40D3687231064A3F40F419506F46434D40102384471B433F40F419506F46434D40
58057	1808	31.284872	31.30583	58.545133999999997	58.51576	Большая Московская	0103000020E61000000100000005000000CE8B135FED483F40E04A766C04424D40CE8B135FED483F4005F86EF3C6454D40BC22F8DF4A4E3F4005F86EF3C6454D40BC22F8DF4A4E3F40E04A766C04424D40CE8B135FED483F40E04A766C04424D40
58083	1808	31.304572	31.338069999999998	58.574731	58.563749000000001	Береговая	0103000020E61000000100000005000000FE463B6EF84D3F408C135FED28484D40FE463B6EF84D3F40AA7F10C990494D403BC269C18B563F40AA7F10C990494D403BC269C18B563F408C135FED28484D40FE463B6EF84D3F408C135FED28484D40
3338	1808	31.218917999999999	31.262170999999999	58.550158000000003	58.542451999999997	Александра Корсунова проспект	0103000020E61000000100000005000000778192020B383F402CD32F116F454D40778192020B383F40FFD0CC936B464D40A9F57EA31D433F40FFD0CC936B464D40A9F57EA31D433F402CD32F116F454D40778192020B383F402CD32F116F454D40
58067	1808	31.312369	31.321702999999999	58.563749000000001	58.560952	20-го Января	0103000020E61000000100000005000000C3482F6AF74F3F401A506F46CD474D40C3482F6AF74F3F408C135FED28484D406C06B8205B523F408C135FED28484D406C06B8205B523F401A506F46CD474D40C3482F6AF74F3F401A506F46CD474D40
58030	57346	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	просп.Комсомольский	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58047	57346	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Студгородок	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58143	57346	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Озёрная	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58027	57346	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Молотковская	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58112	57346	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Комсомольский	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58021	57346	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Васильева проспект	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58008	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	пл.им.Кирова	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58018	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	пл.Спасская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58090	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	пл.Володарского	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58106	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Школьный Бульвар	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58014	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	С.Перовской	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57972	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Пушкинская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57995	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Новгородская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57958	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Ленинградская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58103	57342	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Коммунарная	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57997	25098	30.695038	30.731555	58.222036000000003	58.202319000000003	Ленина	0103000020E610000001000000050000002D7AA702EEB13E40022EC896E5194D402D7AA702EEB13E407044F7AC6B1C4D40AC39403047BB3E407044F7AC6B1C4D40AC39403047BB3E40022EC896E5194D402D7AA702EEB13E40022EC896E5194D40
58317	57367	30.223890000000001	30.261565000000001	58.288933999999998	58.270702999999997	Пионерская	0103000020E61000000100000005000000C5E6E3DA50393E40ECF65965A6224D40C5E6E3DA50393E40EA5910CAFB244D403BC780ECF5423E40EA5910CAFB244D403BC780ECF5423E40ECF65965A6224D40C5E6E3DA50393E40ECF65965A6224D40
58240	2159	30.225614	30.244236000000001	58.374237999999998	58.366588	Молодежная	0103000020E610000001000000050000000E85CFD6C1393E40938D075BEC2E4D400E85CFD6C1393E40D175E107E72F4D4080812040863E3E40D175E107E72F4D4080812040863E3E40938D075BEC2E4D400E85CFD6C1393E40938D075BEC2E4D40
58298	6948	30.723963999999999	30.753276	58.169178000000002	58.154877999999997	Заречная	0103000020E61000000100000005000000397B67B455B93E40586FD40AD3134D40397B67B455B93E40F299EC9FA7154D4098DC28B2D6C03E40F299EC9FA7154D4098DC28B2D6C03E40586FD40AD3134D40397B67B455B93E40586FD40AD3134D40
58257	1904	30.579515000000001	30.603014999999999	58.207687	58.197951000000003	Никольская	0103000020E610000001000000050000009C8A54185B943E40F29A577556194D409C8A54185B943E40F566D47C951A4D4058FFE7305F9A3E40F566D47C951A4D4058FFE7305F9A3E40F29A577556194D409C8A54185B943E40F29A577556194D40
58274	1958	30.498864000000001	30.525660999999999	58.311407000000003	58.292893999999997	Театральная	0103000020E61000000100000005000000D926158DB57F3E40E998F38C7D254D40D926158DB57F3E406C5F402FDC274D405CC823B891863E406C5F402FDC274D405CC823B891863E40E998F38C7D254D40D926158DB57F3E40E998F38C7D254D40
58302	7016	30.610389999999999	30.628491	58.105671999999998	58.092308000000003	Солецкая	0103000020E6100000010000000500000031CEDF84429C3E406094A0BFD00B4D4031CEDF84429C3E402C0DFCA8860D4D4091D442C9E4A03E402C0DFCA8860D4D4091D442C9E4A03E406094A0BFD00B4D4031CEDF84429C3E406094A0BFD00B4D40
58196	25077	30.647490000000001	30.667514000000001	58.192397	58.184013999999998	Центральная	0103000020E61000000100000005000000AF7C96E7C1A53E40C90050C58D174D40AF7C96E7C1A53E409C6C0377A0184D40459F8F32E2AA3E409C6C0377A0184D40459F8F32E2AA3E40C90050C58D174D40AF7C96E7C1A53E40C90050C58D174D40
58291	6860	30.969725	30.996441000000001	58.191192000000001	58.183225999999998	Садовая	0103000020E61000000100000005000000151DC9E53FF83E4071E316F373174D40151DC9E53FF83E40E0A0BDFA78184D40BF64E3C116FF3E40E0A0BDFA78184D40BF64E3C116FF3E4071E316F373174D40151DC9E53FF83E4071E316F373174D40
58316	2153	30.388829000000001	30.411259999999999	58.349845999999999	58.336945999999998	Новая	0103000020E6100000010000000500000084BC1E4C8A633E404E42E90B212B4D4084BC1E4C8A633E407651F4C0C72C4D402827DA5548693E407651F4C0C72C4D402827DA5548693E404E42E90B212B4D4084BC1E4C8A633E404E42E90B212B4D40
58200	6922	30.995398999999999	31.009951000000001	58.164099	58.154817000000001	Центральная	0103000020E610000001000000050000009A780778D2FE3E40B3EE1F0BD1134D409A780778D2FE3E4035272F3201154D40009013268C023F4035272F3201154D40009013268C023F40B3EE1F0BD1134D409A780778D2FE3E40B3EE1F0BD1134D40
58320	57370	30.658315000000002	30.679514999999999	58.203010999999996	58.199652999999998	Сосновая	0103000020E610000001000000050000005C77F35487A83E402EC6C03A8E194D405C77F35487A83E4037DDB243FC194D403524EEB1F4AD3E4037DDB243FC194D403524EEB1F4AD3E402EC6C03A8E194D405C77F35487A83E402EC6C03A8E194D40
58264	2263	30.110423000000001	30.127869	58.276836000000003	58.263176000000001	Центральная	0103000020E61000000100000005000000E9B985AE441C3E40CA8B4CC0AF214D40E9B985AE441C3E40802DAF5C6F234D40172CD505BC203E40802DAF5C6F234D40172CD505BC203E40CA8B4CC0AF214D40E9B985AE441C3E40CA8B4CC0AF214D40
41857	24483	31.648167999999998	31.73208	59.140804000000003	59.111291000000001	Титова	0103000020E6100000010000000500000050508A56EEA53F4069AB92C83E8E4D4050508A56EEA53F40B0928FDD05924D40410E4A9869BB3F40B0928FDD05924D40410E4A9869BB3F4069AB92C83E8E4D4050508A56EEA53F4069AB92C83E8E4D40
41864	24483	31.648167999999998	31.73208	59.140804000000003	59.111291000000001	Новопарковая	0103000020E6100000010000000500000050508A56EEA53F4069AB92C83E8E4D4050508A56EEA53F40B0928FDD05924D40410E4A9869BB3F40B0928FDD05924D40410E4A9869BB3F4069AB92C83E8E4D4050508A56EEA53F4069AB92C83E8E4D40
41859	24483	31.648167999999998	31.73208	59.140804000000003	59.111291000000001	Некрасова	0103000020E6100000010000000500000050508A56EEA53F4069AB92C83E8E4D4050508A56EEA53F40B0928FDD05924D40410E4A9869BB3F40B0928FDD05924D40410E4A9869BB3F4069AB92C83E8E4D4050508A56EEA53F4069AB92C83E8E4D40
41869	24483	31.648167999999998	31.73208	59.140804000000003	59.111291000000001	Малый переулок	0103000020E6100000010000000500000050508A56EEA53F4069AB92C83E8E4D4050508A56EEA53F40B0928FDD05924D40410E4A9869BB3F40B0928FDD05924D40410E4A9869BB3F4069AB92C83E8E4D4050508A56EEA53F4069AB92C83E8E4D40
41867	24483	31.648167999999998	31.73208	59.140804000000003	59.111291000000001	Замкова	0103000020E6100000010000000500000050508A56EEA53F4069AB92C83E8E4D4050508A56EEA53F40B0928FDD05924D40410E4A9869BB3F40B0928FDD05924D40410E4A9869BB3F4069AB92C83E8E4D4050508A56EEA53F4069AB92C83E8E4D40
41851	24483	31.648167999999998	31.73208	59.140804000000003	59.111291000000001	Базовский переулок	0103000020E6100000010000000500000050508A56EEA53F4069AB92C83E8E4D4050508A56EEA53F40B0928FDD05924D40410E4A9869BB3F40B0928FDD05924D40410E4A9869BB3F4069AB92C83E8E4D4050508A56EEA53F4069AB92C83E8E4D40
58290	24470	31.637712000000001	31.659756999999999	59.127876999999998	59.105722999999998	Советская	0103000020E610000001000000050000004A44F81741A33F40AEB7CD54888D4D404A44F81741A33F408E7406465E904D409C4EB2D5E5A83F408E7406465E904D409C4EB2D5E5A83F40AEB7CD54888D4D404A44F81741A33F40AEB7CD54888D4D40
58242	4981	31.541115999999999	31.557366999999999	58.995083999999999	58.983085000000003	Школьная	0103000020E61000000100000005000000A3570394868A3F401618B2BAD57D4D40A3570394868A3F40ED629AE95E7F4D40A0DE8C9AAF8E3F40ED629AE95E7F4D40A0DE8C9AAF8E3F401618B2BAD57D4D40A3570394868A3F401618B2BAD57D4D40
58222	24063	31.851618999999999	31.863899	59.026707000000002	59.020370999999997	Советская	0103000020E61000000100000005000000F8A6E9B303DA3F40B66455849B824D40F8A6E9B303DA3F4082C98D226B834D400F0C207C28DD3F4082C98D226B834D400F0C207C28DD3F40B66455849B824D40F8A6E9B303DA3F40B66455849B824D40
58241	3195	31.506333000000001	31.519439999999999	58.930290999999997	58.917307999999998	Барсукова	0103000020E61000000100000005000000B5E21B0A9F813F40F92D3A596A754D40B5E21B0A9F813F40AE6186C613774D40F73B1405FA843F40AE6186C613774D40F73B1405FA843F40F92D3A596A754D40B5E21B0A9F813F40F92D3A596A754D40
58230	24214	31.661733000000002	31.674965	58.899614999999997	58.882615999999999	Школьная	0103000020E6100000010000000500000019AF795567A93F409276A38FF9704D4019AF795567A93F40DAFE959526734D40D4F19881CAAC3F40DAFE959526734D40D4F19881CAAC3F409276A38FF9704D4019AF795567A93F409276A38FF9704D40
58313	3045	32.072280999999997	32.098861999999997	59.282916999999998	59.270834000000001	Малая Набережная	0103000020E61000000100000005000000A38FF980400940408B5242B0AAA24D40A38FF98040094040C03DCF9F36A44D4098689082A70C4040C03DCF9F36A44D4098689082A70C40408B5242B0AAA24D40A38FF980400940408B5242B0AAA24D40
58220	3090	31.840498	31.875775000000001	59.148626999999998	59.121957000000002	Октябрьская	0103000020E61000000100000005000000795A7EE02AD73F40574277499C8F4D40795A7EE02AD73F40BB26A43506934D4087A757CA32E03F40BB26A43506934D4087A757CA32E03F40574277499C8F4D40795A7EE02AD73F40574277499C8F4D40
58306	24369	31.612622000000002	31.631307	59.262846000000003	59.248184999999999	Центральная	0103000020E6100000010000000500000064CF9ECBD49C3F40CB2DAD86C49F4D4064CF9ECBD49C3F4035F10EF0A4A14D4062BCE6559DA13F4035F10EF0A4A14D4062BCE6559DA13F40CB2DAD86C49F4D4064CF9ECBD49C3F40CB2DAD86C49F4D40
58293	24381	31.523437000000001	31.551779	59.193596999999997	59.181320999999997	Парковая	0103000020E6100000010000000500000030849CF7FF853F40FC89CA8635974D4030849CF7FF853F4046CD57C9C7984D409D9E7763418D3F4046CD57C9C7984D409D9E7763418D3F40FC89CA8635974D4030849CF7FF853F40FC89CA8635974D40
58199	2850	31.876968999999999	31.888943999999999	59.153154000000001	59.145280999999997	Школьная	0103000020E61000000100000005000000179B560A81E03F4076DD5B9198924D40179B560A81E03F4034A0DE8C9A934D40B5F97FD591E33F4034A0DE8C9A934D40B5F97FD591E33F4076DD5B9198924D40179B560A81E03F4076DD5B9198924D40
58205	2512	31.128816	31.140944000000001	57.199150000000003	57.190553000000001	Центральная	0103000020E610000001000000050000009833DB15FA203F40CD936B0A64984C409833DB15FA203F40CC7F48BF7D994C404391EEE714243F40CC7F48BF7D994C404391EEE714243F40CD936B0A64984C409833DB15FA203F40CD936B0A64984C40
58125	8724	31.155092	31.198803999999999	57.160916999999998	57.123373000000001	Старорусская	0103000020E6100000010000000500000009DFFB1BB4273F40CE1ABCAFCA8F4C4009DFFB1BB4273F406A2FA2ED98944C406150A6D1E4323F406A2FA2ED98944C406150A6D1E4323F40CE1ABCAFCA8F4C4009DFFB1BB4273F40CE1ABCAFCA8F4C40
58100	8724	31.155092	31.198803999999999	57.160916999999998	57.123373000000001	Октябрьская	0103000020E6100000010000000500000009DFFB1BB4273F40CE1ABCAFCA8F4C4009DFFB1BB4273F406A2FA2ED98944C406150A6D1E4323F406A2FA2ED98944C406150A6D1E4323F40CE1ABCAFCA8F4C4009DFFB1BB4273F40CE1ABCAFCA8F4C40
58098	8724	31.155092	31.198803999999999	57.160916999999998	57.123373000000001	Красноармейская	0103000020E6100000010000000500000009DFFB1BB4273F40CE1ABCAFCA8F4C4009DFFB1BB4273F406A2FA2ED98944C406150A6D1E4323F406A2FA2ED98944C406150A6D1E4323F40CE1ABCAFCA8F4C4009DFFB1BB4273F40CE1ABCAFCA8F4C40
58210	2700	31.533912000000001	31.565522999999999	57.044873000000003	57.034745999999998	Центральная	0103000020E6100000010000000500000024F1F274AE883F405AD5928E72844C4024F1F274AE883F4099BC0166BE854C40C422861DC6903F4099BC0166BE854C40C422861DC6903F405AD5928E72844C4024F1F274AE883F405AD5928E72844C40
58271	23880	31.707968999999999	31.714787999999999	57.101692	57.097174000000003	Молодежная	0103000020E61000000100000005000000F294D5743DB53F40C1029832708C4C40F294D5743DB53F40E621533E048D4C40C092AB58FCB63F40E621533E048D4C40C092AB58FCB63F40C1029832708C4C40F294D5743DB53F40C1029832708C4C40
58195	23577	30.906043	30.979489999999998	57.136386999999999	57.098816999999997	Центральная	0103000020E610000001000000050000000DC51D6FF2E73E40F8A41309A68C4C400DC51D6FF2E73E40BE4C142175914C4050C24CDBBFFA3E40BE4C142175914C4050C24CDBBFFA3E40F8A41309A68C4C400DC51D6FF2E73E40F8A41309A68C4C40
58246	23788	31.396317	31.412963000000001	57.167413000000003	57.158306000000003	Центральная	0103000020E610000001000000050000004DD9E90775653F405B61FA5E43944C404DD9E90775653F406FF607CA6D954C40437573F1B7693F406FF607CA6D954C40437573F1B7693F405B61FA5E43944C404DD9E90775653F405B61FA5E43944C40
58243	2647	31.285509999999999	31.302955000000001	57.010097000000002	56.999141999999999	Звездная	0103000020E6100000010000000500000053AEF02E17493F40AF0793E2E37F4C4053AEF02E17493F40D464C6DB4A814C40E12879758E4D3F40D464C6DB4A814C40E12879758E4D3F40AF0793E2E37F4C4053AEF02E17493F40AF0793E2E37F4C40
58201	23859	31.486481000000001	31.500862999999999	57.126558000000003	57.115138999999999	Молодежная	0103000020E610000001000000050000001920D1048A7C3F4040BFEFDFBC8E4C401920D1048A7C3F400A86730D33904C40C5C6BC8E38803F400A86730D33904C40C5C6BC8E38803F4040BFEFDFBC8E4C401920D1048A7C3F4040BFEFDFBC8E4C40
58284	23547	30.796637	30.822859000000001	56.997602999999998	56.985436999999997	Центральная	0103000020E6100000010000000500000097C80567F0CB3E4059A2B3CC227E4C4097C80567F0CB3E401CB28174B17F4C4022382EE3A6D23E401CB28174B17F4C4022382EE3A6D23E4059A2B3CC227E4C4097C80567F0CB3E4059A2B3CC227E4C40
58296	23779	31.215684	31.234566000000001	57.124569999999999	57.115872000000003	Комсомольская	0103000020E610000001000000050000003D450E1137373F40D542C9E4D48E4C403D450E1137373F400708E6E8F18F4C40E8C072840C3C3F400708E6E8F18F4C40E8C072840C3C3F40D542C9E4D48E4C403D450E1137373F40D542C9E4D48E4C40
58236	23345	34.987566000000001	35.007157999999997	58.843829999999997	58.828713	пер.Спортивный	0103000020E610000001000000050000001E520C90687E414091628044136A4D401E520C90687E41401CB1169F026C4D40CFF3A78DEA8041401CB1169F026C4D40CFF3A78DEA80414091628044136A4D401E520C90687E414091628044136A4D40
58192	7571	34.479909999999997	34.551541	58.910820999999999	58.881853	Советская	0103000020E61000000100000005000000FD82DDB06D3D41409370218FE0704D40FD82DDB06D3D414048C153C895744D409AB33EE59846414048C153C895744D409AB33EE5984641409370218FE0704D40FD82DDB06D3D41409370218FE0704D40
58213	7571	34.479909999999997	34.551541	58.910820999999999	58.881853	Связи	0103000020E61000000100000005000000FD82DDB06D3D41409370218FE0704D40FD82DDB06D3D414048C153C895744D409AB33EE59846414048C153C895744D409AB33EE5984641409370218FE0704D40FD82DDB06D3D41409370218FE0704D40
57968	7571	34.479909999999997	34.551541	58.910820999999999	58.881853	Денисова	0103000020E61000000100000005000000FD82DDB06D3D41409370218FE0704D40FD82DDB06D3D414048C153C895744D409AB33EE59846414048C153C895744D409AB33EE5984641409370218FE0704D40FD82DDB06D3D41409370218FE0704D40
58204	9392	34.167521000000001	34.172713000000002	58.920588000000002	58.916559999999997	пр.Школьный	0103000020E6100000010000000500000055320054711541402F698CD651754D405532005471154140878BDCD3D5754D400A4CA7751B164140878BDCD3D5754D400A4CA7751B1641402F698CD651754D4055320054711541402F698CD651754D40
58211	9383	34.504784000000001	34.519328000000002	58.930926999999997	58.925970999999997	Новая	0103000020E61000000100000005000000A4C519C39C404140AF05BD3786764D40A4C519C39C40414050FBAD9D28774D40D4F203577942414050FBAD9D28774D40D4F2035779424140AF05BD3786764D40A4C519C39C404140AF05BD3786764D40
58323	9329	34.738661	34.769508999999999	58.950696999999998	58.919806999999999	Первомайская	0103000020E6100000010000000500000053EA92718C5E4140E1D05B3CBC754D4053EA92718C5E4140E1B37570B0794D40247D5A457F624140E1B37570B0794D40247D5A457F624140E1D05B3CBC754D4053EA92718C5E4140E1D05B3CBC754D40
58202	9278	34.238199999999999	34.259284000000001	58.835458000000003	58.827641999999997	Денисова	0103000020E610000001000000050000001FF46C567D1E4140E4654D2CF0694D401FF46C567D1E41403E97A949F06A4D402330D637302141403E97A949F06A4D402330D63730214140E4654D2CF0694D401FF46C567D1E4140E4654D2CF0694D40
58244	23297	34.173333	34.191110000000002	58.943157999999997	58.934322000000002	Строительная	0103000020E61000000100000005000000A62897C62F16414077F700DD97774D40A62897C62F164140FA7ABE66B9784D4023F8DF4A76184140FA7ABE66B9784D4023F8DF4A7618414077F700DD97774D40A62897C62F16414077F700DD97774D40
58261	9263	35.015027000000003	35.045354000000003	58.832402000000002	58.806758000000002	Никольская	0103000020E610000001000000050000004CC79C67EC814140A8E49CD843674D404CC79C67EC814140009013268C6A4D40145FED28CE854140009013268C6A4D40145FED28CE854140A8E49CD843674D404CC79C67EC814140A8E49CD843674D40
58314	57366	34.652870999999998	34.691417999999999	58.871141000000001	58.796557999999997	Советская	0103000020E61000000100000005000000DFC0E44691534140FFAECF9CF5654D40DFC0E44691534140359A5C8C816F4D40D0EE906280584140359A5C8C816F4D40D0EE906280584140FFAECF9CF5654D40DFC0E44691534140FFAECF9CF5654D40
58081	57349	35.092902000000002	35.107778000000003	58.838908000000004	58.834344000000002	Московская	0103000020E61000000100000005000000D3DD7536E48B414092CEC0C8CB6A4D40D3DD7536E48B4140282D5C56616B4D40399D64ABCB8D4140282D5C56616B4D40399D64ABCB8D414092CEC0C8CB6A4D40D3DD7536E48B414092CEC0C8CB6A4D40
58289	45399	35.013562999999998	35.048723000000003	58.808658999999999	58.790753000000002	Линейная	0103000020E61000000100000005000000C3B7B06EBC814140611BF16437654D40C3B7B06EBC814140DB4E5B2382674D4011C8258E3C864140DB4E5B2382674D4011C8258E3C864140611BF16437654D40C3B7B06EBC814140611BF16437654D40
58189	22987	35.148535000000003	35.155693999999997	58.776415	58.769697000000001	Школьная	0103000020E61000000100000005000000DBA7E33103934140276A696E85624D40DBA7E33103934140DA8F149161634D407A17EFC7ED934140DA8F149161634D407A17EFC7ED934140276A696E85624D40DBA7E33103934140276A696E85624D40
58215	22856	34.672347000000002	34.685166000000002	58.815724000000003	58.805928000000002	Советская	0103000020E6100000010000000500000028486C770F564140217711A628674D4028486C770F564140FA47DFA469684D40632AFD84B3574140FA47DFA469684D40632AFD84B3574140217711A628674D4028486C770F564140217711A628674D40
58245	22753	33.824975000000002	33.835107999999998	58.963807000000003	58.955668000000003	Песчаная	0103000020E610000001000000050000004182E2C798E94040B8EA3A54537A4D404182E2C798E94040F4531C075E7B4D406150A6D1E4EA4040F4531C075E7B4D406150A6D1E4EA4040B8EA3A54537A4D404182E2C798E94040B8EA3A54537A4D40
58269	57361	35.235095999999999	35.259117000000003	58.763705000000002	58.753525000000003	Молодежная	0103000020E61000000100000005000000D0B52FA0179E4140F5DBD78173604D40D0B52FA0179E41405665DF15C1614D40386BF0BE2AA141405665DF15C1614D40386BF0BE2AA14140F5DBD78173604D40D0B52FA0179E4140F5DBD78173604D40
58239	22797	34.349268000000002	34.367970999999997	58.816656000000002	58.811259999999997	Молодежная	0103000020E6100000010000000500000009C556D0B42C4140C746205ED7674D4009C556D0B42C4140850A0E2F88684D402E7079AC192F4140850A0E2F88684D402E7079AC192F4140C746205ED7674D4009C556D0B42C4140C746205ED7674D40
58263	7648	33.976638000000001	33.984865999999997	58.940275	58.937136000000002	Октябрьская	0103000020E61000000100000005000000F303577902FD4040BFF38B12F4774D40F303577902FD40408A1F63EE5A784D409E78CE1610FE40408A1F63EE5A784D409E78CE1610FE4040BFF38B12F4774D40F303577902FD4040BFF38B12F4774D40
58283	57365	31.048919999999999	31.077199	57.966299999999997	57.947696000000001	Кольцевая	0103000020E61000000100000005000000CD1E6805860C3F4067463F1A4EF94C40CD1E6805860C3F40F90FE9B7AFFB4C40AE484C50C3133F40F90FE9B7AFFB4C40AE484C50C3133F4067463F1A4EF94C40CD1E6805860C3F4067463F1A4EF94C40
58044	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	пл.Революции	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58035	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	пер.Комсомольский	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
57994	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Якутских Стрелков	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58042	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Яковлева	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
57992	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Трибуны	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58141	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Строителей	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58036	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Пролетарской Победы	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58105	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Минеральная	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58235	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Володарского	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58115	4716	31.313717	31.39134	58.015914000000002	57.968438999999996	Возрождения	0103000020E610000001000000050000000133DFC14F503F40E19524CFF5FB4C400133DFC14F503F4037C64E7809024D40DC9DB5DB2E643F4037C64E7809024D40DC9DB5DB2E643F40E19524CFF5FB4C400133DFC14F503F40E19524CFF5FB4C40
58193	4548	31.593353	31.612838	57.664831999999997	57.647435000000002	Центральная	0103000020E61000000100000005000000C6FB71FBE5973F4094A46B26DFD24C40C6FB71FBE5973F40C9AA083719D54C40FDBE7FF3E29C3F40C9AA083719D54C40FDBE7FF3E29C3F4094A46B26DFD24C40C6FB71FBE5973F4094A46B26DFD24C40
58297	10982	31.169007000000001	31.190064	58.056212000000002	58.035659000000003	Школьная	0103000020E610000001000000050000008ACBF10A442B3F406F675F7990044D408ACBF10A442B3F4046D26EF431074D409E25C808A8303F4046D26EF431074D409E25C808A8303F406F675F7990044D408ACBF10A442B3F406F675F7990044D40
58209	21216	31.397772	31.423203000000001	57.987943000000001	57.976734	Молодежная	0103000020E61000000100000005000000B743C362D4653F401572A59E05FD4C40B743C362D4653F40F4A78DEA74FE4C40B0912408576C3F40F4A78DEA74FE4C40B0912408576C3F401572A59E05FD4C40B743C362D4653F401572A59E05FD4C40
58203	10860	31.652740999999999	31.668704000000002	57.786793000000003	57.774211000000001	Центральная	0103000020E6100000010000000500000022C2BF081AA73F400B9A965819E34C4022C2BF081AA73F4062DC0DA2B5E44C4053B4722F30AB3F4062DC0DA2B5E44C4053B4722F30AB3F400B9A965819E34C4022C2BF081AA73F400B9A965819E34C40
58286	21595	31.250188000000001	31.264372000000002	57.882612000000002	57.874040999999998	Центральная	0103000020E6100000010000000500000006DA1D520C403F407B2E5393E0EF4C4006DA1D520C403F405187156EF9F04C4066FA25E2AD433F405187156EF9F04C4066FA25E2AD433F407B2E5393E0EF4C4006DA1D520C403F407B2E5393E0EF4C40
58310	10791	31.748958999999999	31.779807999999999	57.676051999999999	57.661740999999999	Рендакова	0103000020E610000001000000050000007C0BEBC6BBBF3F400FB6D8EDB3D44C407C0BEBC6BBBF3F409C3237DF88D64C40BF28417FA1C73F409C3237DF88D64C40BF28417FA1C73F400FB6D8EDB3D44C407C0BEBC6BBBF3F400FB6D8EDB3D44C40
58253	22340	31.294150999999999	31.335079	58.013277000000002	57.993772999999997	Школьная	0103000020E61000000100000005000000F015DD7A4D4B3F40EB5223F433FF4C40F015DD7A4D4B3F40FE648C0FB3014D408E93C2BCC7553F40FE648C0FB3014D408E93C2BCC7553F40EB5223F433FF4C40F015DD7A4D4B3F40EB5223F433FF4C40
58294	10721	31.462837	31.482932000000002	58.164625999999998	58.155352999999998	Заводская	0103000020E61000000100000005000000F660527C7C763F40F12A6B9BE2134D40F660527C7C763F402009FB7612154D401F317A6EA17B3F402009FB7612154D401F317A6EA17B3F40F12A6B9BE2134D40F660527C7C763F40F12A6B9BE2134D40
58233	20892	31.040575	31.061730000000001	58.152684999999998	58.143698000000001	Соборная	0103000020E6100000010000000500000003098A1F630A3F40144031B264124D4003098A1F630A3F407DCB9C2E8B134D409D2E8B89CD0F3F407DCB9C2E8B134D409D2E8B89CD0F3F40144031B264124D4003098A1F630A3F40144031B264124D40
58260	20812	31.145723	31.171028	58.136321000000002	58.123784999999998	Центральная	0103000020E6100000010000000500000067463F1A4E253F40205ED72FD80F4D4067463F1A4E253F4007616EF772114D4046B3B27DC82B3F4007616EF772114D4046B3B27DC82B3F40205ED72FD80F4D4067463F1A4E253F40205ED72FD80F4D40
58305	20670	31.253250999999999	31.269366999999999	58.074278999999997	58.062534999999997	Центральная	0103000020E61000000100000005000000E6ADBA0ED5403F407CED992501084D40E6ADBA0ED5403F40C9E369F981094D40239F573CF5443F40C9E369F981094D40239F573CF5443F407CED992501084D40E6ADBA0ED5403F407CED992501084D40
58311	20509	31.452065999999999	31.457124	58.001137	57.998289999999997	Зеленая	0103000020E610000001000000050000002FA2ED98BA733F4040F67AF7C7FF4C402FA2ED98BA733F4064E8D84125004D407A37161406753F4064E8D84125004D407A37161406753F4040F67AF7C7FF4C402FA2ED98BA733F4040F67AF7C7FF4C40
58156	11289	30.065750000000001	30.082979999999999	58.177849999999999	58.168970000000002	Ветеранов	0103000020E6100000010000000500000046B6F3FDD4103E40A80018CFA0154D4046B6F3FDD4103E40FBCBEEC9C3164D40DA38622D3E153E40FBCBEEC9C3164D40DA38622D3E153E40A80018CFA0154D4046B6F3FDD4103E40A80018CFA0154D40
58094	7236	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	проспект Советский	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
58104	7236	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	Новгородская	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
58096	7236	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	Молодежная	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
58056	7236	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	Красных Партизан	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
58039	7236	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	Комсомола	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
58089	7236	30.283761999999999	30.376118000000002	58.131089000000003	58.107802999999997	А.Матросов	0103000020E61000000100000005000000F9D85DA0A4483E4091B41B7DCC0D4D40F9D85DA0A4483E40C4EE3B86C7104D40DB6FED4449603E40C4EE3B86C7104D40DB6FED4449603E4091B41B7DCC0D4D40F9D85DA0A4483E4091B41B7DCC0D4D40
58140	19586	30.354181000000001	30.363631999999999	58.011040999999999	58.002558000000001	Первомайская	0103000020E6100000010000000500000055DD239BAB5A3E40ED2B0FD253004D4055DD239BAB5A3E4023F59ECA69014D4071C79BFC165D3E4023F59ECA69014D4071C79BFC165D3E40ED2B0FD253004D4055DD239BAB5A3E40ED2B0FD253004D40
58191	19878	30.199258	30.211098	57.994726999999997	57.987557000000002	В.Козлова	0103000020E610000001000000050000006477819202333E40CBF78C4468FE4C406477819202333E405EB9DE3653FF4C404240BE840A363E405EB9DE3653FF4C404240BE840A363E40CBF78C4468FE4C406477819202333E40CBF78C4468FE4C40
58183	19953	30.508754	30.523216999999999	58.174441999999999	58.165546999999997	Молодёжная	0103000020E610000001000000050000008DB5BFB33D823E40B779E3A430154D408DB5BFB33D823E4040868E1D54164D4013B69F8CF1853E4040868E1D54164D4013B69F8CF1853E40B779E3A430154D408DB5BFB33D823E40B779E3A430154D40
58159	7202	30.426477999999999	30.456220999999999	58.131256	58.117714999999997	Невская	0103000020E61000000100000005000000A77686A92D6D3E40D39FFD48110F4D40A77686A92D6D3E40AFB321FFCC104D4098BF42E6CA743E40AFB321FFCC104D4098BF42E6CA743E40D39FFD48110F4D40A77686A92D6D3E40D39FFD48110F4D40
58162	19785	30.231587999999999	30.24756	58.066443999999997	58.058883999999999	Центральная	0103000020E610000001000000050000006325E659493B3E40FB20CB8289074D406325E659493B3E40F981AB3C81084D403ACC9717603F3E40F981AB3C81084D403ACC9717603F3E40FB20CB8289074D406325E659493B3E40FB20CB8289074D40
58138	19778	29.979897999999999	29.996462999999999	58.064787000000003	58.060326000000003	Центральная	0103000020E61000000100000005000000726A6798DAFA3D409C8C2AC3B8074D40726A6798DAFA3D405D1ABFF04A084D408EACFC3218FF3D405D1ABFF04A084D408EACFC3218FF3D409C8C2AC3B8074D40726A6798DAFA3D409C8C2AC3B8074D40
58174	7127	30.093561999999999	30.113468999999998	58.084453000000003	58.078181000000001	Ветеранов	0103000020E61000000100000005000000FA25E2ADF3173E409415C3D5010A4D40FA25E2ADF3173E4049861C5BCF0A4D401D1CEC4D0C1D3E4049861C5BCF0A4D401D1CEC4D0C1D3E409415C3D5010A4D40FA25E2ADF3173E409415C3D5010A4D40
58119	7118	30.032036000000002	30.054978999999999	57.993329000000003	57.981878999999999	Молодежная	0103000020E610000001000000050000006F4BE48233083E4089D00836AEFD4C406F4BE48233083E408E95986725FF4C407FF78E1A130E3E408E95986725FF4C407FF78E1A130E3E4089D00836AEFD4C406F4BE48233083E4089D00836AEFD4C40
58091	11357	30.419857	30.438828999999998	58.076563	58.060383000000002	Центральная	0103000020E6100000010000000500000026FF93BF7B6B3E40001E51A1BA074D4026FF93BF7B6B3E40B58AFED0CC094D405089EB1857703E40B58AFED0CC094D405089EB1857703E40001E51A1BA074D4026FF93BF7B6B3E40001E51A1BA074D40
58173	19444	29.862784999999999	29.878685000000001	58.147593000000001	58.135688999999999	Центральная	0103000020E61000000100000005000000B77A4E7ADFDC3D40A6B6D4415E114D40B77A4E7ADFDC3D402C0FD253E4124D405B7C0A80F1E03D402C0FD253E4124D405B7C0A80F1E03D40A6B6D4415E114D40B77A4E7ADFDC3D40A6B6D4415E114D40
58093	20004	30.242322999999999	30.259139000000001	58.122587000000003	58.118299999999998	Вольная	0103000020E61000000100000005000000901150E1083E3E40F38E5374240F4D40901150E1083E3E4017F549EEB00F4D403F1EFAEE56423E4017F549EEB00F4D403F1EFAEE56423E40F38E5374240F4D40901150E1083E3E40F38E5374240F4D40
58282	19382	31.391717	31.410250000000001	57.397799999999997	57.387386999999997	Комсомольская	0103000020E610000001000000050000008849B89047643F40A1F2AFE595B14C408849B89047643F40A52C431CEBB24C401B2FDD2406693F40A52C431CEBB24C401B2FDD2406693F40A1F2AFE595B14C408849B89047643F40A1F2AFE595B14C40
58214	11171	31.095524999999999	31.124891000000002	57.479647	57.460979999999999	Горького	0103000020E610000001000000050000004DF38E5374183F40170E846401BB4C404DF38E5374183F40F04FA91265BD4C40939048DBF81F3F40F04FA91265BD4C40939048DBF81F3F40170E846401BB4C404DF38E5374183F40170E846401BB4C40
58254	19081	30.722742	30.741417999999999	57.507131000000001	57.498519000000002	Центральная	0103000020E610000001000000050000001572A59E05B93E40A2B77878CFBF4C401572A59E05B93E40D6E429ABE9C04C406DAAEE91CDBD3E40D6E429ABE9C04C406DAAEE91CDBD3E40A2B77878CFBF4C401572A59E05B93E40A2B77878CFBF4C40
58255	11188	31.379213	31.397196999999998	57.453257000000001	57.442791	Центральная	0103000020E61000000100000005000000D237691A14613F4048FB1F60ADB84C40D237691A14613F406FD74B5304BA4C40BE11DDB3AE653F406FD74B5304BA4C40BE11DDB3AE653F4048FB1F60ADB84C40D237691A14613F4048FB1F60ADB84C40
58312	19238	30.917973	30.946574999999999	57.421652999999999	57.415221000000003	Новая	0103000020E610000001000000050000006B9C4D4700EB3E4064CE33F625B54C406B9C4D4700EB3E4051A1BAB9F8B54C4011363CBD52F23E4051A1BAB9F8B54C4011363CBD52F23E4064CE33F625B54C406B9C4D4700EB3E4064CE33F625B54C40
58218	19176	31.111425000000001	31.134943	57.470235000000002	57.459774000000003	Центральная	0103000020E61000000100000005000000F1F44A59861C3F408BC6DADFD9BA4C40F1F44A59861C3F40A03715A930BC4C40FAD2DB9F8B223F40A03715A930BC4C40FAD2DB9F8B223F408BC6DADFD9BA4C40F1F44A59861C3F408BC6DADFD9BA4C40
58208	19023	31.008576999999999	31.026992	57.675792000000001	57.668725999999999	Центральная	0103000020E610000001000000050000006F7F2E1A32023F4011FE45D098D54C406F7F2E1A32023F4000732D5A80D64C40EE409DF2E8063F4000732D5A80D64C40EE409DF2E8063F4011FE45D098D54C406F7F2E1A32023F4011FE45D098D54C40
58229	19122	31.14142	31.162557	57.590874999999997	57.582079	Октябрьская	0103000020E610000001000000050000001500E31934243F401D588E9081CA4C401500E31934243F401283C0CAA1CB4C4062BCE6559D293F401283C0CAA1CB4C4062BCE6559D293F401D588E9081CA4C401500E31934243F401D588E9081CA4C40
58285	9920	30.906295	30.962278000000001	57.588096	57.563077999999997	Советская	0103000020E610000001000000050000004087F9F202E83E406D8C9DF012C84C404087F9F202E83E404774CFBA46CB4C4009A9DBD957F63E404774CFBA46CB4C4009A9DBD957F63E406D8C9DF012C84C404087F9F202E83E406D8C9DF012C84C40
58095	18222	35.737704000000001	35.776412000000001	58.584963000000002	58.574143999999997	Лесная	0103000020E610000001000000050000006F10AD156DDE4140E998F38C7D494D406F10AD156DDE41405E2F4D11E04A4D40691CEA7761E341405E2F4D11E04A4D40691CEA7761E34140E998F38C7D494D406F10AD156DDE4140E998F38C7D494D40
58015	9620	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	Чапаева	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
57967	9620	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	Советская	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
57965	9620	35.773214000000003	35.853487999999999	58.612459999999999	58.574993999999997	Почтовая	0103000020E61000000100000005000000996725ADF8E24140B7B2446799494D40996725ADF8E24140D80DDB16654E4D40A4C343183FED4140D80DDB16654E4D40A4C343183FED4140B7B2446799494D40996725ADF8E24140B7B2446799494D40
58111	18192	35.620123	35.648159999999997	58.571550000000002	58.563856999999999	Центральная	0103000020E61000000100000005000000AB3FC23060CF4140724F57772C484D40AB3FC23060CF4140B003E78C28494D40A54929E8F6D24140B003E78C28494D40A54929E8F6D24140724F57772C484D40AB3FC23060CF4140724F57772C484D40
58158	18114	35.268450999999999	35.288716999999998	58.629385999999997	58.622194	Советская	0103000020E610000001000000050000000CCA349A5CA241403BE2900DA44F4D400CCA349A5CA24140B6476FB88F504D404D66BCADF4A44140B6476FB88F504D404D66BCADF4A441403BE2900DA44F4D400CCA349A5CA241403BE2900DA44F4D40
58142	18003	35.661203	35.688080999999997	58.475254	58.461751	Соловьева	0103000020E610000001000000050000003082C64CA2D4414099F221A81A3B4D403082C64CA2D4414087A5811FD53C4D40DEFFC70913D8414087A5811FD53C4D40DEFFC70913D8414099F221A81A3B4D403082C64CA2D4414099F221A81A3B4D40
58194	29438	36.095987999999998	36.121608000000002	58.561337000000002	58.552210000000002	Школьная	0103000020E610000001000000050000007B67B455490C4240184339D1AE464D407B67B455490C424073840CE4D9474D404B77D7D9900F424073840CE4D9474D404B77D7D9900F4240184339D1AE464D407B67B455490C4240184339D1AE464D40
58198	29396	35.397933999999999	35.431378000000002	58.773223999999999	58.761296999999999	Советская	0103000020E61000000100000005000000B5FB5580EFB241407EC51A2E72614D40B5FB5580EFB24140BC3D0801F9624D40611BF16437B74140BC3D0801F9624D40611BF16437B741407EC51A2E72614D40B5FB5580EFB241407EC51A2E72614D40
58126	18402	35.463844000000002	35.486516999999999	58.521225999999999	58.511096999999999	Молодежная	0103000020E6100000010000000500000011397D3D5FBB4140B70A62A06B414D4011397D3D5FBB414096E99788B7424D4059F9653046BE414096E99788B7424D4059F9653046BE4140B70A62A06B414D4011397D3D5FBB4140B70A62A06B414D40
58160	57352	35.376643999999999	35.451213000000003	58.725718999999998	58.707689999999999	Ветеранов	0103000020E61000000100000005000000081EDFDE35B0414066DAFE95955A4D40081EDFDE35B04140FC8A355CE45C4D40D943FB58C1B94140FC8A355CE45C4D40D943FB58C1B9414066DAFE95955A4D40081EDFDE35B0414066DAFE95955A4D40
58122	17225	31.609119	31.632349000000001	57.995508999999998	57.975627000000003	Старорусская	0103000020E610000001000000050000004A5F0839EF9B3F401C0C7558E1FC4C404A5F0839EF9B3F40D4EFC2D66CFF4C4087A8C29FE1A13F40D4EFC2D66CFF4C4087A8C29FE1A13F401C0C7558E1FC4C404A5F0839EF9B3F401C0C7558E1FC4C40
58086	17225	31.609119	31.632349000000001	57.995508999999998	57.975627000000003	Профсоюзная	0103000020E610000001000000050000004A5F0839EF9B3F401C0C7558E1FC4C404A5F0839EF9B3F40D4EFC2D66CFF4C4087A8C29FE1A13F40D4EFC2D66CFF4C4087A8C29FE1A13F401C0C7558E1FC4C404A5F0839EF9B3F401C0C7558E1FC4C40
58102	17195	31.602031	31.615127999999999	57.953719	57.945337000000002	Строительная	0103000020E610000001000000050000009D2D20B41E9A3F40715985CD00F94C409D2D20B41E9A3F407349D57613FA4C4098DA5207799D3F407349D57613FA4C4098DA5207799D3F40715985CD00F94C409D2D20B41E9A3F40715985CD00F94C40
58013	17501	31.812021000000001	31.847325000000001	57.947949999999999	57.922096000000003	Пионерская	0103000020E610000001000000050000004CAAB69BE0CF3F40DFE2E13D07F64C404CAAB69BE0CF3F40211FF46C56F94C404D158C4AEAD83F40211FF46C56F94C404D158C4AEAD83F40DFE2E13D07F64C404CAAB69BE0CF3F40DFE2E13D07F64C40
58009	17501	31.812021000000001	31.847325000000001	57.947949999999999	57.922096000000003	Мира	0103000020E610000001000000050000004CAAB69BE0CF3F40DFE2E13D07F64C404CAAB69BE0CF3F40211FF46C56F94C404D158C4AEAD83F40211FF46C56F94C404D158C4AEAD83F40DFE2E13D07F64C404CAAB69BE0CF3F40DFE2E13D07F64C40
58004	16903	31.627516	31.665649999999999	57.984135999999999	57.954129999999999	Мира	0103000020E610000001000000050000007CB779E3A4A03F40F5108DEE20FA4C407CB779E3A4A03F407B681F2BF8FD4C401895D40968AA3F407B681F2BF8FD4C401895D40968AA3F40F5108DEE20FA4C407CB779E3A4A03F40F5108DEE20FA4C40
57991	16903	31.627516	31.665649999999999	57.984135999999999	57.954129999999999	Крупнова	0103000020E610000001000000050000007CB779E3A4A03F40F5108DEE20FA4C407CB779E3A4A03F407B681F2BF8FD4C401895D40968AA3F407B681F2BF8FD4C401895D40968AA3F40F5108DEE20FA4C407CB779E3A4A03F40F5108DEE20FA4C40
57990	16903	31.627516	31.665649999999999	57.984135999999999	57.954129999999999	Карла Маркса	0103000020E610000001000000050000007CB779E3A4A03F40F5108DEE20FA4C407CB779E3A4A03F407B681F2BF8FD4C401895D40968AA3F407B681F2BF8FD4C401895D40968AA3F40F5108DEE20FA4C407CB779E3A4A03F40F5108DEE20FA4C40
58182	17606	\N	\N	\N	\N	Центральная	\N
58154	17441	31.812425000000001	31.837713000000001	58.160775999999998	58.150182000000001	Советская	0103000020E61000000100000005000000EB73B515FBCF3F405439ED2939134D40EB73B515FBCF3F40A8FDD64E94144D401E6FF25B74D63F40A8FDD64E94144D401E6FF25B74D63F405439ED2939134D40EB73B515FBCF3F405439ED2939134D40
58181	17392	31.607285999999998	31.621237000000001	58.049506999999998	58.041004000000001	Советская	0103000020E6100000010000000500000093516518779B3F40AA807B9E3F054D4093516518779B3F4027F6D03E56064D40AE105663099F3F4027F6D03E56064D40AE105663099F3F40AA807B9E3F054D4093516518779B3F40AA807B9E3F054D40
58172	17354	31.582716999999999	31.591718	58.041519000000001	58.033081000000003	Школьная	0103000020E61000000100000005000000BFD2F9F02C953F403B8F8AFF3B044D40BFD2F9F02C953F40D1949D7E50054D405C74B2D47A973F40D1949D7E50054D405C74B2D47A973F403B8F8AFF3B044D40BFD2F9F02C953F403B8F8AFF3B044D40
58272	57362	32.544193	33.732295999999998	58.748497	58.067028999999998	Мира	0103000020E6100000010000000500000027DBC01DA84540401971016894084D4027DBC01DA8454040BA13ECBFCE5F4D40ED7E15E0BBDD4040BA13ECBFCE5F4D40ED7E15E0BBDD40401971016894084D4027DBC01DA84540401971016894084D40
58153	57351	32.544193	33.732295999999998	58.748497	58.067028999999998	Новопокровская	0103000020E6100000010000000500000027DBC01DA84540401971016894084D4027DBC01DA8454040BA13ECBFCE5F4D40ED7E15E0BBDD4040BA13ECBFCE5F4D40ED7E15E0BBDD40401971016894084D4027DBC01DA84540401971016894084D40
57983	16083	33.488833999999997	33.526823999999998	58.245277000000002	58.226770999999999	Центральная	0103000020E610000001000000050000002096CD1C92BE4040325706D5061D4D402096CD1C92BE404002BB9A3C651F4D40BB5F05F86EC3404002BB9A3C651F4D40BB5F05F86EC34040325706D5061D4D402096CD1C92BE4040325706D5061D4D40
58117	16083	33.488833999999997	33.526823999999998	58.245277000000002	58.226770999999999	Молодежная	0103000020E610000001000000050000002096CD1C92BE4040325706D5061D4D402096CD1C92BE404002BB9A3C651F4D40BB5F05F86EC3404002BB9A3C651F4D40BB5F05F86EC34040325706D5061D4D402096CD1C92BE4040325706D5061D4D40
58188	57355	32.931592000000002	32.939712	58.646242999999998	58.642130999999999	Луначарского	0103000020E610000001000000050000008D9B1A683E774040B75F3E5931524D408D9B1A683E7740406C223317B8524D4052D4997B487840406C223317B8524D4052D4997B48784040B75F3E5931524D408D9B1A683E774040B75F3E5931524D40
58114	16758	33.465164000000001	33.495274999999999	58.557383999999999	58.541761999999999	Дзержинского	0103000020E6100000010000000500000066A3737E8ABB4040971B0C7558454D4066A3737E8ABB404026A8E15B58474D4061C3D32B65BF404026A8E15B58474D4061C3D32B65BF4040971B0C7558454D4066A3737E8ABB4040971B0C7558454D40
58152	16047	33.331764	33.347898000000001	58.449024000000001	58.444488999999997	Центральная	0103000020E61000000100000005000000BDFE243E77AA40404337FB03E5384D40BDFE243E77AA40403F8F519E79394D40022CF2EB87AC40403F8F519E79394D40022CF2EB87AC40404337FB03E5384D40BDFE243E77AA40404337FB03E5384D40
57962	15569	33.25273	33.341628	58.427219000000001	58.365101000000003	Парфенова	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
58010	15569	33.25273	33.341628	58.427219000000001	58.365101000000003	Новгородская	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
57980	15569	33.25273	33.341628	58.427219000000001	58.365101000000003	Ленина	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
58121	15569	33.25273	33.341628	58.427219000000001	58.365101000000003	Грибоедова	0103000020E61000000100000005000000EA5BE67459A04040535E2BA1BB2E4D40EA5BE67459A040406B9DB81CAF364D40EEB25F77BAAB40406B9DB81CAF364D40EEB25F77BAAB4040535E2BA1BB2E4D40EA5BE67459A04040535E2BA1BB2E4D40
58151	16821	33.276454999999999	33.284342000000002	58.256832000000003	58.252025000000003	Центральная	0103000020E6100000010000000500000068E89FE062A340402063EE5A42204D4068E89FE062A340407C48F8DEDF204D408B70935165A440407C48F8DEDF204D408B70935165A440402063EE5A42204D4068E89FE062A340402063EE5A42204D40
57963	15922	33.336615000000002	33.392302000000001	58.464345000000002	58.441690999999999	Кирова	0103000020E61000000100000005000000E92B483316AB404001F8A75489384D40E92B483316AB4040D3872EA86F3B4D40E413B2F336B24040D3872EA86F3B4D40E413B2F336B2404001F8A75489384D40E92B483316AB404001F8A75489384D40
58026	16694	33.464615999999999	33.524425999999998	58.491297000000003	58.475932	Ленина	0103000020E6100000010000000500000063997E8978BB4040588FFB56EB3C4D4063997E8978BB4040BCCFF1D1E23E4D400796236420C34040BCCFF1D1E23E4D400796236420C34040588FFB56EB3C4D4063997E8978BB4040588FFB56EB3C4D40
57966	16452	33.062322999999999	33.093603000000002	58.496442000000002	58.478374000000002	Кооперативная	0103000020E61000000100000005000000F1643733FA874040DCA0F65B3B3D4D40F1643733FA874040302E55698B3F4D405CE7DF2EFB8B4040302E55698B3F4D405CE7DF2EFB8B4040DCA0F65B3B3D4D40F1643733FA874040DCA0F65B3B3D4D40
58169	16345	33.196882000000002	33.210959000000003	58.383119000000001	58.37471	Центральная	0103000020E61000000100000005000000E695EB6D33994040F9BD4D7FF62F4D40E695EB6D33994040F5BC1B0B0A314D4000E65AB4009B4040F5BC1B0B0A314D4000E65AB4009B4040F9BD4D7FF62F4D40E695EB6D33994040F9BD4D7FF62F4D40
58267	60	32.054791000000002	32.079261000000002	58.613968999999997	58.609844000000002	Центральная	0103000020E61000000100000005000000BD8E386403074040B7D4415E0F4E4D40BD8E38640307404000E14389964E4D40946C7539250A404000E14389964E4D40946C7539250A4040B7D4415E0F4E4D40BD8E386403074040B7D4415E0F4E4D40
58250	15476	30.867028999999999	30.886927	58.796599999999998	58.786200999999998	Центральная	0103000020E61000000100000005000000FFAECF9CF5DD3E408F8AFF3BA2644D40FFAECF9CF5DD3E402EFF21FDF6654D407CF0DAA50DE33E402EFF21FDF6654D407CF0DAA50DE33E408F8AFF3BA2644D40FFAECF9CF5DD3E408F8AFF3BA2644D40
58212	15229	31.019805999999999	31.085086	58.953871999999997	58.876393	Советская	0103000020E61000000100000005000000BB438A0112053F40BFB854A52D704D40BB438A0112053F40F9484A7A187A4D40F3583332C8153F40F9484A7A187A4D40F3583332C8153F40BFB854A52D704D40BB438A0112053F40BFB854A52D704D40
58276	15229	31.019805999999999	31.085086	58.953871999999997	58.876393	Матросова	0103000020E61000000100000005000000BB438A0112053F40BFB854A52D704D40BB438A0112053F40F9484A7A187A4D40F3583332C8153F40F9484A7A187A4D40F3583332C8153F40BFB854A52D704D40BB438A0112053F40BFB854A52D704D40
58275	13947	31.221243999999999	31.240091	58.453305	58.4435	Школьная	0103000020E61000000100000005000000AC6F6072A3383F4054E3A59BC4384D40AC6F6072A3383F40800EF3E5053A4D405E10919A763D3F40800EF3E5053A4D405E10919A763D3F4054E3A59BC4384D40AC6F6072A3383F4054E3A59BC4384D40
58262	14577	31.441313000000001	31.453251999999999	58.547651000000002	58.542748000000003	Школьная	0103000020E61000000100000005000000B64C86E3F9703F4016FC36C478454D40B64C86E3F9703F40944F8F6D19464D40BAD8B45208743F40944F8F6D19464D40BAD8B45208743F4016FC36C478454D40B64C86E3F9703F4016FC36C478454D40
58277	14755	31.676303999999998	31.739526999999999	58.446331000000001	58.419057000000002	Парковая	0103000020E610000001000000050000006B274A4222AD3F407714E7A8A3354D406B274A4222AD3F407218CC5F21394D404D8237A451BD3F407218CC5F21394D404D8237A451BD3F407714E7A8A3354D406B274A4222AD3F407714E7A8A3354D40
58300	14755	31.676303999999998	31.739526999999999	58.446331000000001	58.419057000000002	Ленина	0103000020E610000001000000050000006B274A4222AD3F407714E7A8A3354D406B274A4222AD3F407218CC5F21394D404D8237A451BD3F407218CC5F21394D404D8237A451BD3F407714E7A8A3354D406B274A4222AD3F407714E7A8A3354D40
58206	15000	31.362656999999999	31.416744000000001	58.707326000000002	58.682912000000002	Центральная	0103000020E610000001000000050000005CAAD216D75C3F40E20511A969574D405CAAD216D75C3F4025CE8AA8895A4D40E2CD1ABCAF6A3F4025CE8AA8895A4D40E2CD1ABCAF6A3F40E20511A969574D405CAAD216D75C3F40E20511A969574D40
58251	57360	31.101355000000002	31.233892000000001	58.511107000000003	58.467323999999998	Пионерская	0103000020E610000001000000050000003D49BA66F2193F406551D845D13B4D403D49BA66F2193F40DBE044F46B414D40C9CB9A58E03B3F40DBE044F46B414D40C9CB9A58E03B3F406551D845D13B4D403D49BA66F2193F406551D845D13B4D40
58315	14049	31.101355000000002	31.233892000000001	58.511107000000003	58.467323999999998	Октябрьская	0103000020E610000001000000050000003D49BA66F2193F406551D845D13B4D403D49BA66F2193F40DBE044F46B414D40C9CB9A58E03B3F40DBE044F46B414D40C9CB9A58E03B3F406551D845D13B4D403D49BA66F2193F406551D845D13B4D40
58278	14473	31.682233	31.707888000000001	58.538120999999997	58.512065999999997	Школьная	0103000020E61000000100000005000000814067D2A6AE3F405FB2F1608B414D40814067D2A6AE3F4039252026E1444D40193BE12538B53F4039252026E1444D40193BE12538B53F405FB2F1608B414D40814067D2A6AE3F405FB2F1608B414D40
58288	263	31.742122999999999	31.753442	58.682200999999999	58.670017999999999	Евстигнеева	0103000020E61000000100000005000000029CDEC5FBBD3F409CDD5A26C3554D40029CDEC5FBBD3F403526C45C52574D40CE6E2D93E1C03F403526C45C52574D40CE6E2D93E1C03F409CDD5A26C3554D40029CDEC5FBBD3F409CDD5A26C3554D40
58258	13882	30.874718999999999	30.895488	58.311019999999999	58.292642999999998	60 лет СССР	0103000020E6100000010000000500000098309A95EDDF3E40A033695375254D4098309A95EDDF3E407233DC80CF274D40E0F599B33EE53E407233DC80CF274D40E0F599B33EE53E40A033695375254D4098309A95EDDF3E40A033695375254D40
58234	14871	31.802005000000001	31.857503000000001	58.409874000000002	58.396326999999999	Центральная	0103000020E610000001000000050000007E3A1E3350CD3F40CAC2D7D7BA324D407E3A1E3350CD3F4088BD50C076344D40CE380D5185DB3F4088BD50C076344D40CE380D5185DB3F40CAC2D7D7BA324D407E3A1E3350CD3F40CAC2D7D7BA324D40
58354	15307	31.087358999999999	31.106386000000001	58.913083999999998	58.903534000000001	Центральная	0103000020E61000000100000005000000E202D0285D163F407B698A00A7734D40E202D0285D163F401C40BFEFDF744D4094C0E61C3C1B3F401C40BFEFDF744D4094C0E61C3C1B3F407B698A00A7734D40E202D0285D163F407B698A00A7734D40
58265	14004	31.187180000000001	31.211874999999999	58.400830999999997	58.391077000000003	Зеленая	0103000020E610000001000000050000001D774A07EB2F3F40E19BA6CF0E324D401D774A07EB2F3F408A1C226E4E334D400AD7A3703D363F408A1C226E4E334D400AD7A3703D363F40E19BA6CF0E324D401D774A07EB2F3F40E19BA6CF0E324D40
58197	15028	31.552973999999999	31.576169	58.802418000000003	58.789180999999999	Рахманинова	0103000020E61000000100000005000000CE893DB48F8D3F40F2CF0CE203654D40CE893DB48F8D3F4062DC0DA2B5664D4012F8C3CF7F933F4062DC0DA2B5664D4012F8C3CF7F933F40F2CF0CE203654D40CE893DB48F8D3F40F2CF0CE203654D40
58301	14859	31.698931999999999	31.714113999999999	58.324911999999998	58.316006999999999	Школьная	0103000020E61000000100000005000000BC202235EDB23F404E27D9EA72284D40BC202235EDB23F40FA0967B796294D40A19DD32CD0B63F40FA0967B796294D40A19DD32CD0B63F404E27D9EA72284D40BC202235EDB23F404E27D9EA72284D40
58303	15383	31.050286	31.067820999999999	58.811796000000001	58.799382999999999	Черепанова	0103000020E610000001000000050000005872158BDF0C3F403BFDA02E52664D405872158BDF0C3F4006836BEEE8674D4065FB90B75C113F4006836BEEE8674D4065FB90B75C113F403BFDA02E52664D405872158BDF0C3F403BFDA02E52664D40
58279	57363	31.327604999999998	31.330757999999999	58.545209	58.544879999999999	Пионерстроя	0103000020E610000001000000050000008E01D9EBDD533F404B1FBAA0BE454D408E01D9EBDD533F40103E9468C9454D40EFE3688EAC543F40103E9468C9454D40EFE3688EAC543F404B1FBAA0BE454D408E01D9EBDD533F404B1FBAA0BE454D40
58299	14140	31.633661	31.687137	58.466099999999997	58.439723000000001	Бронницкая	0103000020E610000001000000050000002BC0779B37A23F404626E0D748384D402BC0779B37A23F403255302AA93B4D401EDFDE35E8AF3F403255302AA93B4D401EDFDE35E8AF3F404626E0D748384D402BC0779B37A23F404626E0D748384D40
58247	13655	30.999790999999998	31.018180000000001	58.386463999999997	58.373832999999998	Заверяжская	0103000020E61000000100000005000000CBD58F4DF2FF3E4031957EC2D92F4D40CBD58F4DF2FF3E40698A00A777314D40F870C971A7043F40698A00A777314D40F870C971A7043F4031957EC2D92F4D40CBD58F4DF2FF3E4031957EC2D92F4D40
58259	14555	31.638431000000001	31.669971	58.511938999999998	58.494283000000003	Новая	0103000020E61000000100000005000000A9C0C93670A33F4001FC53AA443F4D40A9C0C93670A33F400246973787414D40B7442E3883AB3F400246973787414D40B7442E3883AB3F4001FC53AA443F4D40A9C0C93670A33F4001FC53AA443F4D40
58273	9851	\N	\N	\N	\N	Молодежная	\N
58238	10137	34.573092000000003	34.601343999999997	58.518861999999999	58.500439	Советская	0103000020E61000000100000005000000B4CC22145B4941404C5299620E404D40B4CC22145B4941408E91EC116A424D40AAD216D7F84C41408E91EC116A424D40AAD216D7F84C41404C5299620E404D40B4CC22145B4941404C5299620E404D40
58307	1430	34.546691000000003	34.566696	58.430154000000002	58.421432000000003	Софьи Лешерн	0103000020E610000001000000050000003F027FF8F945414073BED87BF1354D403F027FF8F94541402E1F49490F374D401363997E894841402E1F49490F374D401363997E8948414073BED87BF1354D403F027FF8F945414073BED87BF1354D40
58207	1024	32.180537000000001	32.198484999999998	57.422790999999997	57.414988000000001	Центральная	0103000020E61000000100000005000000E65B1FD61B174040C11DA8531EB54C40E65B1FD61B1740408505F7031EB64C408FDFDBF4671940408505F7031EB64C408FDFDBF467194040C11DA8531EB54C40E65B1FD61B174040C11DA8531EB54C40
58227	9334	32.077356999999999	32.096212000000001	57.332324999999997	57.324069999999999	Садовая	0103000020E61000000100000005000000EF8E8CD5E6094040AFCE31207BA94C40EF8E8CD5E6094040545227A089AA4C40CBBDC0AC500C4040545227A089AA4C40CBBDC0AC500C4040AFCE31207BA94C40EF8E8CD5E6094040AFCE31207BA94C40
58268	518	32.066253000000003	32.091926999999998	57.321323999999997	57.303075999999997	Советов	0103000020E61000000100000005000000862172FA7A084040EB19C231CBA64C40862172FA7A084040BFB5132521A94C40484F9143C40B4040BFB5132521A94C40484F9143C40B4040EB19C231CBA64C40862172FA7A084040EB19C231CBA64C40
58295	518	32.066253000000003	32.091926999999998	57.321323999999997	57.303075999999997	Мудрова	0103000020E61000000100000005000000862172FA7A084040EB19C231CBA64C40862172FA7A084040BFB5132521A94C40484F9143C40B4040BFB5132521A94C40484F9143C40B4040EB19C231CBA64C40862172FA7A084040EB19C231CBA64C40
58281	966	32.556140999999997	32.570270999999998	57.351646000000002	57.346294999999998	Центральная	0103000020E610000001000000050000007C7BD7A02F47404058E2016553AC4C407C7BD7A02F47404076E272BC02AD4C40B96DDFA3FE48404076E272BC02AD4C40B96DDFA3FE48404058E2016553AC4C407C7BD7A02F47404058E2016553AC4C40
58292	640	32.195404000000003	32.214897999999998	57.343454000000001	57.337133999999999	Строителей	0103000020E61000000100000005000000F9C08EFF02194040512FF83427AB4C40F9C08EFF0219404017D7F84CF6AB4C40E7FC14C7811B404017D7F84CF6AB4C40E7FC14C7811B4040512FF83427AB4C40F9C08EFF02194040512FF83427AB4C40
58228	9454	32.379747000000002	32.394067	57.381287999999998	57.369632000000003	пер.Кленовый	0103000020E6100000010000000500000087E0B88C9B3040400DC7F31950AF4C4087E0B88C9B304040BA2D910BCEB04C4067B796C970324040BA2D910BCEB04C4067B796C9703240400DC7F31950AF4C4087E0B88C9B3040400DC7F31950AF4C40
58219	501	31.900127999999999	31.903639999999999	57.215387999999997	57.212600999999999	Советов	0103000020E61000000100000005000000C136E2C96EE63F40670C7382369B4C40C136E2C96EE63F40B5F97FD5919B4C40815B77F354E73F40B5F97FD5919B4C40815B77F354E73F40670C7382369B4C40C136E2C96EE63F40670C7382369B4C40
58287	737	32.349780000000003	32.359014000000002	57.316288999999998	57.310174000000004	Центральная	0103000020E61000000100000005000000BF654E97C52C4040E60819C8B3A74C40BF654E97C52C4040D28A6F287CA84C403067B62BF42D4040D28A6F287CA84C403067B62BF42D4040E60819C8B3A74C40BF654E97C52C4040E60819C8B3A74C40
58155	384	32.785265000000003	32.798183000000002	58.665300999999999	58.650517999999998	Советов	0103000020E61000000100000005000000C3D8429083644040CBBA7F2C44534D40C3D8429083644040807F4A9528554D40919C4CDC2A664040807F4A9528554D40919C4CDC2A664040CBBA7F2C44534D40C3D8429083644040CBBA7F2C44534D40
58170	8904	32.566938	32.597535000000001	58.696232000000002	58.680573000000003	Воровского	0103000020E61000000100000005000000096EA46C9148404033C51C041D574D40096EA46C91484040DF3653211E594D40919BE1067C4C4040DF3653211E594D40919BE1067C4C404033C51C041D574D40096EA46C9148404033C51C041D574D40
58024	8130	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	Московская	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
57978	8130	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	Заводской Домострой	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
57959	8130	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	Гагарина	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
58006	8130	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	50 Лет Октября	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
57977	8130	32.191558999999998	32.255797999999999	58.862839999999998	58.827185	 Школьная	0103000020E6100000010000000500000092205C0185184040F25EB532E1694D4092205C01851840401FD7868A716E4D40EC3026FDBD2040401FD7868A716E4D40EC3026FDBD204040F25EB532E1694D4092205C0185184040F25EB532E1694D40
58280	4158	32.358708999999998	32.375399999999999	58.780161	58.763472	Первомайская	0103000020E61000000100000005000000F3E32F2DEA2D4040B3B45373B9614D40F3E32F2DEA2D4040AD4ECE50DC634D408E75711B0D304040AD4ECE50DC634D408E75711B0D304040B3B45373B9614D40F3E32F2DEA2D4040B3B45373B9614D40
58150	4240	32.331104000000003	32.356580000000001	58.653312999999997	58.646079	Школьная	0103000020E6100000010000000500000093C9A99D612A4040F2D077B7B2524D4093C9A99D612A40409C86A8C29F534D402F34D769A42D40409C86A8C29F534D402F34D769A42D4040F2D077B7B2524D4093C9A99D612A4040F2D077B7B2524D40
58171	57353	31.945556	31.989591000000001	58.980386000000003	58.956432999999997	Ленинградская	0103000020E610000001000000050000005D8940F50FF23F4057E883656C7A4D405D8940F50FF23F4067BAD7497D7D4D407B6AF5D555FD3F4067BAD7497D7D4D407B6AF5D555FD3F4057E883656C7A4D405D8940F50FF23F4057E883656C7A4D40
58180	8548	32.195008999999999	32.211134000000001	58.812685999999999	58.805689999999998	Славная	0103000020E610000001000000050000007CB60E0EF61840406C5B94D920674D407CB60E0EF618404062F5471806684D406E895C70061B404062F5471806684D406E895C70061B40406C5B94D920674D407CB60E0EF61840406C5B94D920674D40
58256	8995	32.843502999999998	32.855773999999997	58.817625	58.810281000000003	Северная	0103000020E61000000100000005000000F88903E8F76B4040FCC8AD49B7674D40F88903E8F76B40402DB29DEFA7684D4030629F008A6D40402DB29DEFA7684D4030629F008A6D4040FCC8AD49B7674D40F88903E8F76B4040FCC8AD49B7674D40
58137	4396	32.678832999999997	32.715609999999998	58.688048000000002	58.669961999999998	1 Мая	0103000020E610000001000000050000000839EFFFE356404008C89750C1554D400839EFFFE3564040030AF5F411584D406458C51B995B4040030AF5F411584D406458C51B995B404008C89750C1554D400839EFFFE356404008C89750C1554D40
58087	8685	32.446348999999998	32.478831999999997	58.732160999999998	58.712139999999998	Новгородская	0103000020E6100000010000000500000018CDCAF62139404033164D67275B4D4018CDCAF6213940400D349F73B75D4D409E23F25D4A3D40400D349F73B75D4D409E23F25D4A3D404033164D67275B4D4018CDCAF62139404033164D67275B4D40
58011	8560	32.067646000000003	32.103596000000003	58.918965999999998	58.896737999999999	Поболотина	0103000020E6100000010000000500000045DAC69FA80840404C8A8F4FC8724D4045DAC69FA808404066118AADA0754D408BFF3BA2420D404066118AADA0754D408BFF3BA2420D40404C8A8F4FC8724D4045DAC69FA80840404C8A8F4FC8724D40
58031	8037	33.318702999999999	33.368423999999997	59.131261000000002	59.112917000000003	Комсомольская	0103000020E610000001000000050000008C118942CBA84040CB147310748E4D408C118942CBA84040C11E1329CD904D40DF87838428AF4040C11E1329CD904D40DF87838428AF4040CB147310748E4D408C118942CBA84040CB147310748E4D40
57961	3669	33.374569000000001	33.418486999999999	58.823869000000002	58.806472999999997	Советов	0103000020E61000000100000005000000378C82E0F1AF4040B20DDC813A674D40378C82E0F1AF40401898158A74694D408C6665FB90B540401898158A74694D408C6665FB90B54040B20DDC813A674D40378C82E0F1AF4040B20DDC813A674D40
58135	3669	33.374569000000001	33.418486999999999	58.823869000000002	58.806472999999997	Магистральная	0103000020E61000000100000005000000378C82E0F1AF4040B20DDC813A674D40378C82E0F1AF40401898158A74694D408C6665FB90B540401898158A74694D408C6665FB90B54040B20DDC813A674D40378C82E0F1AF4040B20DDC813A674D40
58185	7408	33.401392000000001	33.448635000000003	58.655022000000002	58.640979000000002	Речная	0103000020E61000000100000005000000227024D060B340401E3691990B524D40227024D060B340408C14CAC2D7534D40A56B26DF6CB940408C14CAC2D7534D40A56B26DF6CB940401E3691990B524D40227024D060B340401E3691990B524D40
58054	57348	33.458741000000003	33.492804999999997	58.744200999999997	58.727929000000003	Пролетарская	0103000020E61000000100000005000000CC2A6C06B8BA4040AE6708C72C5D4D40CC2A6C06B8BA4040435376FA415F4D401327F73B14BF4040435376FA415F4D401327F73B14BF4040AE6708C72C5D4D40CC2A6C06B8BA4040AE6708C72C5D4D40
58168	52399	33.389552999999999	33.406117999999999	59.046138999999997	59.038612000000001	Советская	0103000020E61000000100000005000000838769DFDCB14040D89DEE3CF1844D40838769DFDCB14040FA08FCE1E7854D409128B4ACFBB34040FA08FCE1E7854D409128B4ACFBB34040D89DEE3CF1844D40838769DFDCB14040D89DEE3CF1844D40
57982	6662	32.520072999999996	32.532533000000001	58.266967999999999	58.258569999999999	Ямская	0103000020E610000001000000050000002C4487C09142404005DD5ED218214D402C4487C0914240400D8AE6012C224D403885950A2A4440400D8AE6012C224D403885950A2A44404005DD5ED218214D402C4487C09142404005DD5ED218214D40
58178	6816	32.430143000000001	32.445998000000003	58.471592999999999	58.460648999999997	Советская	0103000020E610000001000000050000003ACD02ED0E374040B1F7E28BF63A4D403ACD02ED0E374040E202D0285D3C4D406C0A647616394040E202D0285D3C4D406C0A647616394040B1F7E28BF63A4D403ACD02ED0E374040B1F7E28BF63A4D40
58179	3309	32.771566	32.795703000000003	58.066392	58.057583999999999	Зеленая	0103000020E610000001000000050000004F5AB8ACC2624040ED629AE95E074D404F5AB8ACC2624040A75B76887F084D40202A8D98D9654040A75B76887F084D40202A8D98D9654040ED629AE95E074D404F5AB8ACC2624040ED629AE95E074D40
58133	6925	32.685865999999997	32.705908000000001	58.357840000000003	58.349936	Лесная	0103000020E610000001000000050000001BB80375CA574040B6D8EDB3CA2C4D401BB80375CA574040AF997CB3CD2D4D400DFE7E315B5A4040AF997CB3CD2D4D400DFE7E315B5A4040B6D8EDB3CA2C4D401BB80375CA574040B6D8EDB3CA2C4D40
58061	47070	32.483853000000003	32.551307999999999	58.268241000000003	58.228406	Строителей	0103000020E61000000100000005000000278925E5EE3D4040E71A66683C1D4D40278925E5EE3D4040223999B855224D40F702B34291464040223999B855224D40F702B34291464040E71A66683C1D4D40278925E5EE3D4040E71A66683C1D4D40
57976	47070	32.483853000000003	32.551307999999999	58.268241000000003	58.228406	Островская	0103000020E61000000100000005000000278925E5EE3D4040E71A66683C1D4D40278925E5EE3D4040223999B855224D40F702B34291464040223999B855224D40F702B34291464040E71A66683C1D4D40278925E5EE3D4040E71A66683C1D4D40
58052	47070	32.483853000000003	32.551307999999999	58.268241000000003	58.228406	Валдайская	0103000020E61000000100000005000000278925E5EE3D4040E71A66683C1D4D40278925E5EE3D4040223999B855224D40F702B34291464040223999B855224D40F702B34291464040E71A66683C1D4D40278925E5EE3D4040E71A66683C1D4D40
58110	6738	32.047981999999998	32.085934999999999	58.371783999999998	58.365290000000002	Молодежная	0103000020E61000000100000005000000F96530462406404026C79DD2C12E4D40F96530462406404089963C9E962F4D40774A07EBFF0A404089963C9E962F4D40774A07EBFF0A404026C79DD2C12E4D40F96530462406404026C79DD2C12E4D40
58148	6781	32.202914	32.237363999999999	58.364634000000002	58.354596000000001	Центральная	0103000020E6100000010000000500000045F30016F91940406EA5D766632D4D4045F30016F91940403D81B053AC2E4D40B69F8CF1611E40403D81B053AC2E4D40B69F8CF1611E40406EA5D766632D4D4045F30016F91940406EA5D766632D4D40
58097	6424	32.480134	32.502439000000003	57.847203999999998	57.836123999999998	Садовая	0103000020E610000001000000050000004DD9E907753D40404AB3791C06EB4C404DD9E907753D40402B85402E71EC4C40139ED0EB4F4040402B85402E71EC4C40139ED0EB4F4040404AB3791C06EB4C404DD9E907753D40404AB3791C06EB4C40
58136	6352	32.550131	32.572642999999999	57.597332999999999	57.587662000000002	Центральная	0103000020E6100000010000000500000005C24EB16A4640400D8D278238CB4C4005C24EB16A46404029E9616875CC4C4044A4A65D4C49404029E9616875CC4C4044A4A65D4C4940400D8D278238CB4C4005C24EB16A4640400D8D278238CB4C40
58147	6325	32.572158000000002	32.586638000000001	57.747078000000002	57.740530999999997	Центральная	0103000020E6100000010000000500000088122D793C4940404B5645B8C9DE4C4088122D793C494040D2C77C40A0DF4C40A14B38F4164B4040D2C77C40A0DF4C40A14B38F4164B40404B5645B8C9DE4C4088122D793C4940404B5645B8C9DE4C40
58177	6254	32.758809999999997	32.769167000000003	57.641409000000003	57.635623000000002	Центральная	0103000020E610000001000000050000005AF0A2AF20614040EFCA2E185CD14C405AF0A2AF20614040172EABB019D24C40CB14731074624040172EABB019D24C40CB14731074624040EFCA2E185CD14C405AF0A2AF20614040EFCA2E185CD14C40
58184	6123	32.601954999999997	32.616543	57.648504000000003	57.642265999999999	Центральная	0103000020E61000000100000005000000F35487DC0C4D404097AAB4C535D24C40F35487DC0C4D4040A0A9D72D02D34C40F3C98AE1EA4E4040A0A9D72D02D34C40F3C98AE1EA4E404097AAB4C535D24C40F35487DC0C4D404097AAB4C535D24C40
58166	6037	33.054634	33.068306	57.513410999999998	57.503982999999998	Береговая	0103000020E61000000100000005000000F59F353FFE864040B75ED38382C04C40F59F353FFE8640400D349F73B7C14C406F0F4240BE8840400D349F73B7C14C406F0F4240BE884040B75ED38382C04C40F59F353FFE864040B75ED38382C04C40
58165	5968	32.992514999999997	33.01182	57.733896000000001	57.723896000000003	Центральная	0103000020E610000001000000050000000CE544BB0A7F404045DAC69FA8DC4C400CE544BB0A7F40402655DB4DF0DD4C4028B85851838140402655DB4DF0DD4C4028B858518381404045DAC69FA8DC4C400CE544BB0A7F404045DAC69FA8DC4C40
58025	5963	32.382263000000002	32.421329999999998	57.927401000000003	57.898417999999999	1 Мая	0103000020E6100000010000000500000045BC75FEED304040A1116C5CFFF24C4045BC75FEED3040408CA37213B5F64C406E693524EE3540408CA37213B5F64C406E693524EE354040A1116C5CFFF24C4045BC75FEED304040A1116C5CFFF24C40
57955	5898	32.211888000000002	32.237076999999999	57.935752999999998	57.919142000000001	Центральная	0103000020E610000001000000050000001A355F251F1B4040A530EF71A6F54C401A355F251F1B404023111AC1C6F74C4020D1048A581E404023111AC1C6F74C4020D1048A581E4040A530EF71A6F54C401A355F251F1B4040A530EF71A6F54C40
58145	5818	32.645766000000002	32.658881000000001	57.584183000000003	57.577765999999997	Молодежная	0103000020E61000000100000005000000336FD575A8524040D05E7D3CF4C94C40336FD575A852404089F02F82C6CA4C40577A6D365654404089F02F82C6CA4C40577A6D3656544040D05E7D3CF4C94C40336FD575A8524040D05E7D3CF4C94C40
58157	5792	32.402430000000003	32.413623000000001	57.669255999999997	57.661929000000001	Центральная	0103000020E61000000100000005000000F37684D38233404012A3E716BAD44C40F37684D3823340406D533C2EAAD54C40CCEF3499F13440406D533C2EAAD54C40CCEF3499F134404012A3E716BAD44C40F37684D38233404012A3E716BAD44C40
58007	5626	32.439135	32.485497000000002	57.667532999999999	57.632944000000002	Ленина	0103000020E61000000100000005000000B5C35F933538404087191A4F04D14C40B5C35F93353840401900AAB871D54C402FA704C4243E40401900AAB871D54C402FA704C4243E404087191A4F04D14C40B5C35F933538404087191A4F04D14C40
58132	5553	32.70872	32.721178999999999	57.510815000000001	57.501483	переулок Школьный	0103000020E61000000100000005000000B4024356B75A4040FF3F4E9830C04C40B4024356B75A404033A7CB6262C14C40EFC7ED974F5C404033A7CB6262C14C40EFC7ED974F5C4040FF3F4E9830C04C40B4024356B75A4040FF3F4E9830C04C40
58216	57357	32.117116000000003	32.129890000000003	57.617227999999997	57.604683000000001	Центральная	0103000020E610000001000000050000004FEB36A8FD0E40403DB9A64066CD4C404FEB36A8FD0E40407616BD5301CF4C40EA094B3CA01040407616BD5301CF4C40EA094B3CA01040403DB9A64066CD4C404FEB36A8FD0E40403DB9A64066CD4C40
58130	5416	30.591597	30.612447	57.772291000000003	57.759371999999999	Зеленая	0103000020E610000001000000050000006669A7E672973E40C2BF081A33E14C406669A7E672973E4061FF756EDAE24C4087889B53C99C3E4061FF756EDAE24C4087889B53C99C3E40C2BF081A33E14C406669A7E672973E40C2BF081A33E14C40
58163	5307	30.686593999999999	30.706105000000001	57.821914999999997	57.811340000000001	Центральная	0103000020E610000001000000050000003CA1D79FC4AF3E40E4F736FDD9E74C403CA1D79FC4AF3E40C18BBE8234E94C40C68A1A4CC3B43E40C18BBE8234E94C40C68A1A4CC3B43E40E4F736FDD9E74C403CA1D79FC4AF3E40E4F736FDD9E74C40
58161	5050	30.731131999999999	30.752126000000001	57.963149000000001	57.949854999999999	Волотовская	0103000020E610000001000000050000001F0F7D772BBB3E40967840D994F94C401F0F7D772BBB3E406A16687748FB4C40A7785C548BC03E406A16687748FB4C40A7785C548BC03E40967840D994F94C401F0F7D772BBB3E40967840D994F94C40
58146	5231	30.538677	30.582927999999999	57.987217999999999	57.972481999999999	Центральная	0103000020E610000001000000050000007E1B62BCE6893E406EF9484A7AFC4C407E1B62BCE6893E40E202D0285DFE4C4035ECF7C43A953E40E202D0285DFE4C4035ECF7C43A953E406EF9484A7AFC4C407E1B62BCE6893E406EF9484A7AFC4C40
58217	57358	30.754021000000002	30.779408	57.997908000000002	57.980685999999999	Центральная	0103000020E610000001000000050000004A7F2F8507C13E4091D26C1E87FD4C404A7F2F8507C13E4059350873BBFF4C40A33D5E4887C73E4059350873BBFF4C40A33D5E4887C73E4091D26C1E87FD4C404A7F2F8507C13E4091D26C1E87FD4C40
58134	4899	30.690493	30.72391	57.937168	57.917239000000002	Победы	0103000020E61000000100000005000000EF1D3526C4B03E40D1CE691668F54C40EF1D3526C4B03E40CA6DFB1EF5F74C40533F6F2A52B93E40CA6DFB1EF5F74C40533F6F2A52B93E40D1CE691668F54C40EF1D3526C4B03E40D1CE691668F54C40
58005	4899	30.690493	30.72391	57.937168	57.917239000000002	Комсомольская	0103000020E61000000100000005000000EF1D3526C4B03E40D1CE691668F54C40EF1D3526C4B03E40CA6DFB1EF5F74C40533F6F2A52B93E40CA6DFB1EF5F74C40533F6F2A52B93E40D1CE691668F54C40EF1D3526C4B03E40D1CE691668F54C40
58022	4630	32.935212	32.979650999999997	58.041823999999998	58.028778000000003	Усадьба	0103000020E61000000100000005000000D369DD06B5774040126C5CFFAE034D40D369DD06B57740400D18247D5A054D40313F3734657D40400D18247D5A054D40313F3734657D4040126C5CFFAE034D40D369DD06B5774040126C5CFFAE034D40
58144	4520	32.695739000000003	32.712735000000002	57.929034999999999	57.919127000000003	Центральная	0103000020E61000000100000005000000A0C6BDF90D59404070EF1AF4A5F54C40A0C6BDF90D59404070EB6E9EEAF64C4077DB85E63A5B404070EB6E9EEAF64C4077DB85E63A5B404070EF1AF4A5F54C40A0C6BDF90D59404070EF1AF4A5F54C40
58176	4162	33.119995000000003	33.127155000000002	58.136535000000002	58.127676999999998	Центральная	0103000020E610000001000000050000007E5704FF5B8F4040C7B94DB857104D407E5704FF5B8F404033E197FA79114D40EE42739D4690404033E197FA79114D40EE42739D46904040C7B94DB857104D407E5704FF5B8F4040C7B94DB857104D40
58092	4245	32.688893999999998	32.711055000000002	57.977907999999999	57.960461000000002	Молодежная	0103000020E610000001000000050000008F34B8AD2D584040AF0AD462F0FA4C408F34B8AD2D584040963FDF162CFD4C402254A9D9035B4040963FDF162CFD4C402254A9D9035B4040AF0AD462F0FA4C408F34B8AD2D584040AF0AD462F0FA4C40
58139	4297	32.775401000000002	32.799574999999997	58.017395999999998	58.004255999999998	Школьная	0103000020E610000001000000050000009224085740634040E867EA758B004D409224085740634040658A39083A024D407FD93D7958664040658A39083A024D407FD93D7958664040E867EA758B004D409224085740634040E867EA758B004D40
58124	4137	33.030459999999998	33.054803999999997	58.125387000000003	58.118462000000001	Центральная	0103000020E6100000010000000500000007EBFF1CE6834040CDE847C3290F4D4007EBFF1CE6834040FA2B64AE0C104D4051D845D103874040FA2B64AE0C104D4051D845D103874040CDE847C3290F4D4007EBFF1CE6834040CDE847C3290F4D40
58164	4036	33.237665999999997	33.252181999999998	57.942723999999998	57.934458999999997	Центральная	0103000020E6100000010000000500000081AFE8D66B9E4040F7393E5A9CF74C4081AFE8D66B9E4040C093162EABF84C40E751F17F47A04040C093162EABF84C40E751F17F47A04040F7393E5A9CF74C4081AFE8D66B9E4040F7393E5A9CF74C40
58187	4025	33.138150000000003	33.153134000000001	57.798842999999998	57.790948	Зеленая	0103000020E61000000100000005000000A1F831E6AE914040166BB8C83DE54C40A1F831E6AE914040BBD1C77C40E64C40EDF318E599934040BBD1C77C40E64C40EDF318E599934040166BB8C83DE54C40A1F831E6AE914040166BB8C83DE54C40
58088	3707	33.259225000000001	33.290792000000003	57.960881000000001	57.952151999999998	Почтовая	0103000020E610000001000000050000001EA7E8482EA140401669E21DE0F94C401EA7E8482EA14040842C0B26FEFA4C401FF818AC38A54040842C0B26FEFA4C401FF818AC38A540401669E21DE0F94C401EA7E8482EA140401669E21DE0F94C40
57996	3751	33.590325999999997	33.638314000000001	57.925407999999997	57.901254000000002	Сосновая	0103000020E610000001000000050000003FFD67CD8FCB4040D1B1834A5CF34C403FFD67CD8FCB404077BAF3C473F64C401B4AED45B4D1404077BAF3C473F64C401B4AED45B4D14040D1B1834A5CF34C403FFD67CD8FCB4040D1B1834A5CF34C40
58120	3192	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Энергетиков	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
57998	3192	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Труда	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
57973	3192	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Молодежная	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58108	3192	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Мелиораторов	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
57986	3192	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Луначарского	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
57988	3192	33.217516000000003	33.282482000000002	57.999310000000001	57.960318000000001	Гагарина	0103000020E61000000100000005000000AA2D7590D79B40404CE141B3EBFA4C40AA2D7590D79B40406B48DC63E9FF4C40B6DAC35E28A440406B48DC63E9FF4C40B6DAC35E28A440404CE141B3EBFA4C40AA2D7590D79B40404CE141B3EBFA4C40
58149	4540	32.807380999999999	32.824224999999998	57.794128000000001	57.786140000000003	Четвертая	0103000020E61000000100000005000000B534B74258674040EA094B3CA0E44C40B534B74258674040406B7EFCA5E54C40D6C56D3480694040406B7EFCA5E54C40D6C56D3480694040EA094B3CA0E44C40B534B74258674040EA094B3CA0E44C40
58223	3093	34.306911999999997	34.325606000000001	58.662633	58.657096000000003	Садовая	0103000020E61000000100000005000000FE5F75E4482741408D2AC3B81B544D40FE5F75E4482741400C207C28D1544D40D1B01875AD2941400C207C28D1544D40D1B01875AD2941408D2AC3B81B544D40FE5F75E4482741408D2AC3B81B544D40
58266	2953	33.677166	33.711733000000002	58.319547	58.295811999999998	Новая	0103000020E6100000010000000500000048FB1F60ADD64040D6E1E82ADD254D4048FB1F60ADD64040784485EAE6284D40F33D23111ADB4040784485EAE6284D40F33D23111ADB4040D6E1E82ADD254D4048FB1F60ADD64040D6E1E82ADD254D40
58248	2605	33.930644000000001	33.943328000000001	58.405065	58.397835999999998	Зеленая	0103000020E61000000100000005000000FC1BB4571FF74040F295404AEC324D40FC1BB4571FF740408BE07F2BD9334D4057B3CEF8BEF840408BE07F2BD9334D4057B3CEF8BEF84040F295404AEC324D40FC1BB4571FF74040F295404AEC324D40
58109	2508	34.352026000000002	34.409346999999997	58.423383000000001	58.414347999999997	Советская	0103000020E61000000100000005000000BDAB1E300F2D4140DD94F25A09354D40BDAB1E300F2D41405857056A31364D409CDB847B653441405857056A31364D409CDB847B65344140DD94F25A09354D40BDAB1E300F2D4140DD94F25A09354D40
58308	2358	34.486620000000002	34.501154999999997	58.220776000000001	58.209274999999998	Новая	0103000020E610000001000000050000002ECA6C90493E4140696FF085C91A4D402ECA6C90493E4140F0DE5163421C4D400A9DD7D825404140F0DE5163421C4D400A9DD7D825404140696FF085C91A4D402ECA6C90493E4140696FF085C91A4D40
58270	2171	34.096041999999997	34.141955000000003	58.280754000000002	58.270744999999998	1 линия	0103000020E610000001000000050000006E85B01A4B0C41401B47ACC5A7224D406E85B01A4B0C4140501C40BFEF234D407940D9942B124140501C40BFEF234D407940D9942B1241401B47ACC5A7224D406E85B01A4B0C41401B47ACC5A7224D40
58321	41058	33.881757999999998	33.891998000000001	58.343313999999999	58.334952999999999	Новая	0103000020E61000000100000005000000417E3672DDF040403A596ABDDF2A4D40417E3672DDF04040252191B6F12B4D40780C8FFD2CF24040252191B6F12B4D40780C8FFD2CF240403A596ABDDF2A4D40417E3672DDF040403A596ABDDF2A4D40
58318	57368	34.062696000000003	34.080697999999998	58.660212999999999	58.649867	Молодёжная	0103000020E6100000010000000500000086CB2A6C06084140F4DF83D72E534D4086CB2A6C0608414070B20DDC81544D40226DE34F540A414070B20DDC81544D40226DE34F540A4140F4DF83D72E534D4086CB2A6C06084140F4DF83D72E534D40
58221	2742	33.865147999999998	33.902329000000002	58.429433000000003	58.417482	Центральная	0103000020E6100000010000000500000093196F2BBDEE40409755D80C70354D4093196F2BBDEE40405E6919A9F7364D40BF9D44847FF340405E6919A9F7364D40BF9D44847FF340409755D80C70354D4093196F2BBDEE40409755D80C70354D40
58304	2063	33.727390999999997	33.747819	58.594043999999997	58.581684000000003	Маяковского	0103000020E61000000100000005000000CE33F6251BDD4040A14D0E9F744A4D40CE33F6251BDD4040483140A2094C4D40E9297288B8DF4040483140A2094C4D40E9297288B8DF4040A14D0E9F744A4D40CE33F6251BDD4040A14D0E9F744A4D40
58226	1903	33.967860999999999	34.025748999999998	58.328262000000002	58.309181000000002	Советская	0103000020E61000000100000005000000740987DEE2FB4040B5C5353E93274D40740987DEE2FB404081423D7D042A4D40CD7344BE4B03414081423D7D042A4D40CD7344BE4B034140B5C5353E93274D40740987DEE2FB4040B5C5353E93274D40
58252	1798	33.750954	33.771112000000002	58.521315999999999	58.50855	Центральная	0103000020E610000001000000050000007366BB421FE04040BE30992A18414D407366BB421FE04040D670917BBA424D40CEC64ACCB3E24040D670917BBA424D40CEC64ACCB3E24040BE30992A18414D407366BB421FE04040BE30992A18414D40
58225	2838	33.863782	33.878397999999997	58.450978999999997	58.440721000000003	Центральная	0103000020E61000000100000005000000CE6F986890EE404089D4B48B69384D40CE6F986890EE404065170CAEB9394D40976F7D586FF0404065170CAEB9394D40976F7D586FF0404089D4B48B69384D40CE6F986890EE404089D4B48B69384D40
58019	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	площадь Труда	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57981	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	пл.Володарского	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57951	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Энгельса	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58017	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Школьный бульвар	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57956	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Сушанская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58107	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Советская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58002	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	С.Перовской	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58232	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Раздолье	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58034	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Р.Люксембург	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57979	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Подбельского	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58020	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Парковая	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58231	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Молодой Гвардии	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57960	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Ленинградская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57954	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Красноармейская	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57953	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Кооперативная	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57964	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Коммунарная	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57971	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Декабристов	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57969	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Гончарная	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58033	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	В.Бианки	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
57952	52	33.817976999999999	34.006399000000002	58.411405999999999	58.354441000000001	Ботаническая	0103000020E61000000100000005000000AAF06778B3E8404047AE9B525E2D4D40AAF06778B3E8404068B0A9F3A8344D4012DDB3AED100414068B0A9F3A8344D4012DDB3AED100414047AE9B525E2D4D40AAF06778B3E8404047AE9B525E2D4D40
58101	9502	30.286753999999998	30.297595999999999	58.494146999999998	58.489373000000001	Школьная	0103000020E6100000010000000500000047FFCBB568493E40D04543C6A33E4D4047FFCBB568493E4050357A35403F4D40A06B5F402F4C3E4050357A35403F4D40A06B5F402F4C3E40D04543C6A33E4D4047FFCBB568493E40D04543C6A33E4D40
58167	32042	30.617343000000002	30.643663	58.628725000000003	58.619776000000002	Ветеранов	0103000020E610000001000000050000001F6ADB300A9E3E40406CE9D1544F4D401F6ADB300A9E3E40BC96900F7A504D402FA52E19C7A43E40BC96900F7A504D402FA52E19C7A43E40406CE9D1544F4D401F6ADB300A9E3E40406CE9D1544F4D40
58128	7778	30.176898999999999	30.201764000000001	58.437748999999997	58.432580999999999	Молодежная	0103000020E61000000100000005000000F2B1BB40492D3E407CEF6FD05E374D40F2B1BB40492D3E40A86DC32808384D40998235CEA6333E40A86DC32808384D40998235CEA6333E407CEF6FD05E374D40F2B1BB40492D3E407CEF6FD05E374D40
58175	11611	30.447633	30.46471	58.478166999999999	58.470740999999997	Центральная	0103000020E61000000100000005000000419C871398723E4073F1B73D413C4D40419C871398723E4062838593343D4D40C91F0C3CF7763E4062838593343D4D40C91F0C3CF7763E4073F1B73D413C4D40419C871398723E4073F1B73D413C4D40
58129	31968	30.223790999999999	30.237292	58.685119999999998	58.677171999999999	Юбилейная	0103000020E610000001000000050000009E23F25D4A393E402AE27492AD564D409E23F25D4A393E40F2EA1C03B2574D40399A232BBF3C3E40F2EA1C03B2574D40399A232BBF3C3E402AE27492AD564D409E23F25D4A393E402AE27492AD564D40
58023	31839	30.284939000000001	30.323674	58.653477000000002	58.637438000000003	Советская	0103000020E61000000100000005000000DE5A26C3F1483E40249D819197514D40DE5A26C3F1483E4017D86322A5534D40C5909C4CDC523E4017D86322A5534D40C5909C4CDC523E40249D819197514D40DE5A26C3F1483E40249D819197514D40
57999	31839	30.284939000000001	30.323674	58.653477000000002	58.637438000000003	Первомайская	0103000020E61000000100000005000000DE5A26C3F1483E40249D819197514D40DE5A26C3F1483E4017D86322A5534D40C5909C4CDC523E4017D86322A5534D40C5909C4CDC523E40249D819197514D40DE5A26C3F1483E40249D819197514D40
39580	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	проезд капитана Матросова	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
39626	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	Юбилейная	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
39571	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	Студенческая	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
40318	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	Строительная	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
39604	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	Смидовича	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
39600	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	Рабочая	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
39566	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	Ленина	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
39598	5949	52.938501000000002	53.158417999999998	67.669635999999997	67.620894000000007	Заводская	0103000020E61000000100000005000000B421FFCC20784A40171230BABCE75040B421FFCC20784A405A0EF450DBEA5040828C800A47944A405A0EF450DBEA5040828C800A47944A40171230BABCE75040B421FFCC20784A40171230BABCE75040
40319	3080	53.082250000000002	53.170383000000001	67.684666000000007	67.664203000000001	Юбилейная	0103000020E610000001000000050000004A0C022B878A4A40EDB94C4D82EA50404A0C022B878A4A40B9AB5791D1EB5040AE65321CCF954A40B9AB5791D1EB5040AE65321CCF954A40EDB94C4D82EA50404A0C022B878A4A40EDB94C4D82EA5040
59468	3080	53.082250000000002	53.170383000000001	67.684666000000007	67.664203000000001	Тиманская	0103000020E610000001000000050000004A0C022B878A4A40EDB94C4D82EA50404A0C022B878A4A40B9AB5791D1EB5040AE65321CCF954A40B9AB5791D1EB5040AE65321CCF954A40EDB94C4D82EA50404A0C022B878A4A40EDB94C4D82EA5040
39577	3080	53.082250000000002	53.170383000000001	67.684666000000007	67.664203000000001	Ардалина	0103000020E610000001000000050000004A0C022B878A4A40EDB94C4D82EA50404A0C022B878A4A40B9AB5791D1EB5040AE65321CCF954A40B9AB5791D1EB5040AE65321CCF954A40EDB94C4D82EA50404A0C022B878A4A40EDB94C4D82EA5040
59470	3080	53.082250000000002	53.170383000000001	67.684666000000007	67.664203000000001	Академика Губкина	0103000020E610000001000000050000004A0C022B878A4A40EDB94C4D82EA50404A0C022B878A4A40B9AB5791D1EB5040AE65321CCF954A40B9AB5791D1EB5040AE65321CCF954A40EDB94C4D82EA50404A0C022B878A4A40EDB94C4D82EA5040
32738	1028	33.220148000000002	33.263106000000001	69.202822999999995	69.185440999999997	мкр.Скальный	0103000020E61000000100000005000000D12346CF2D9C40409A95ED43DE4B5140D12346CF2D9C40401AF8510DFB4C5140D1B01875ADA140401AF8510DFB4C5140D1B01875ADA140409A95ED43DE4B5140D12346CF2D9C40409A95ED43DE4B5140
32189	1028	33.220148000000002	33.263106000000001	69.202822999999995	69.185440999999997	Флотская	0103000020E61000000100000005000000D12346CF2D9C40409A95ED43DE4B5140D12346CF2D9C40401AF8510DFB4C5140D1B01875ADA140401AF8510DFB4C5140D1B01875ADA140409A95ED43DE4B5140D12346CF2D9C40409A95ED43DE4B5140
32156	1028	33.220148000000002	33.263106000000001	69.202822999999995	69.185440999999997	Павла Стеблина	0103000020E61000000100000005000000D12346CF2D9C40409A95ED43DE4B5140D12346CF2D9C40401AF8510DFB4C5140D1B01875ADA140401AF8510DFB4C5140D1B01875ADA140409A95ED43DE4B5140D12346CF2D9C40409A95ED43DE4B5140
32680	1028	33.220148000000002	33.263106000000001	69.202822999999995	69.185440999999997	Октябрьская	0103000020E61000000100000005000000D12346CF2D9C40409A95ED43DE4B5140D12346CF2D9C40401AF8510DFB4C5140D1B01875ADA140401AF8510DFB4C5140D1B01875ADA140409A95ED43DE4B5140D12346CF2D9C40409A95ED43DE4B5140
32712	1028	33.220148000000002	33.263106000000001	69.202822999999995	69.185440999999997	Мира	0103000020E61000000100000005000000D12346CF2D9C40409A95ED43DE4B5140D12346CF2D9C40401AF8510DFB4C5140D1B01875ADA140401AF8510DFB4C5140D1B01875ADA140409A95ED43DE4B5140D12346CF2D9C40409A95ED43DE4B5140
32811	1028	33.220148000000002	33.263106000000001	69.202822999999995	69.185440999999997	Валентина Бирюкова	0103000020E61000000100000005000000D12346CF2D9C40409A95ED43DE4B5140D12346CF2D9C40401AF8510DFB4C5140D1B01875ADA140401AF8510DFB4C5140D1B01875ADA140409A95ED43DE4B5140D12346CF2D9C40409A95ED43DE4B5140
32699	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Советская	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32809	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Северная Застава	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32746	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Саши Ковалева	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32184	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Полярная	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32162	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Падорина	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32770	358	33.326141	33.343173	69.068205000000006	69.062123	Кортик	0103000020E610000001000000050000003F7100FDBEA940401555BFD2F94351403F7100FDBEA940401E1B81785D44514063EFC517EDAB40401E1B81785D44514063EFC517EDAB40401555BFD2F94351403F7100FDBEA940401555BFD2F9435140
32177	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Комсомольская	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32682	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Колышкина	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32676	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Кирова	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32174	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Душенова	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32193	358	33.363168999999999	33.489714999999997	69.083922000000001	69.048934000000003	Гвардейская	0103000020E61000000100000005000000E4F560527CAE4040666A12BC21435140E4F560527CAE40408E5A61FA5E45514029AE2AFBAEBE40408E5A61FA5E45514029AE2AFBAEBE4040666A12BC21435140E4F560527CAE4040666A12BC21435140
32884	53417	33.062835	33.099063999999998	68.956874999999997	68.950253000000004	Кирова проспект	0103000020E61000000100000005000000A7052FFA0A884040427BF5F1D03C5140A7052FFA0A8840400AD7A3703D3D5140001B1021AE8C40400AD7A3703D3D5140001B1021AE8C4040427BF5F1D03C5140A7052FFA0A884040427BF5F1D03C5140
32185	30878	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	Лунина	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
32747	30878	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	Красный Горн	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
32801	30878	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	Котельникова	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
32683	30878	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	Душенова	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
32790	30878	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	Героев Североморцев	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
32202	30878	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	Гаджиева	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
32787	30878	33.403179999999999	33.484513999999997	69.213250000000002	69.184961000000001	Гагарина	0103000020E610000001000000050000005D33F9669BB340404582A966D64B51405D33F9669BB34040CFF753E3A54D5140213A048E04BE4040CFF753E3A54D5140213A048E04BE40404582A966D64B51405D33F9669BB340404582A966D64B5140
32843	53412	33.269376000000001	33.319367	69.220313000000004	69.210448	Строителей	0103000020E61000000100000005000000E529ABE97AA240408D60E3FA774D5140E529ABE97AA240408E78B29B194E5140F8359204E1A840408E78B29B194E5140F8359204E1A840408D60E3FA774D5140E529ABE97AA240408D60E3FA774D5140
32744	3431	33.221729000000003	33.326751000000002	68.152384999999995	68.123631000000003	Южная	0103000020E6100000010000000500000093C9A99D619C40406571FF91E907514093C9A99D619C4040A9D903ADC0095140B8770DFAD2A94040A9D903ADC0095140B8770DFAD2A940406571FF91E907514093C9A99D619C40406571FF91E9075140
32719	3431	33.221729000000003	33.326751000000002	68.152384999999995	68.123631000000003	Энергетиков	0103000020E6100000010000000500000093C9A99D619C40406571FF91E907514093C9A99D619C4040A9D903ADC0095140B8770DFAD2A94040A9D903ADC0095140B8770DFAD2A940406571FF91E907514093C9A99D619C40406571FF91E9075140
32167	3431	33.221729000000003	33.326751000000002	68.152384999999995	68.123631000000003	Строительная	0103000020E6100000010000000500000093C9A99D619C40406571FF91E907514093C9A99D619C4040A9D903ADC0095140B8770DFAD2A94040A9D903ADC0095140B8770DFAD2A940406571FF91E907514093C9A99D619C40406571FF91E9075140
32706	3431	33.221729000000003	33.326751000000002	68.152384999999995	68.123631000000003	Парковая	0103000020E6100000010000000500000093C9A99D619C40406571FF91E907514093C9A99D619C4040A9D903ADC0095140B8770DFAD2A94040A9D903ADC0095140B8770DFAD2A940406571FF91E907514093C9A99D619C40406571FF91E9075140
32168	3431	33.221729000000003	33.326751000000002	68.152384999999995	68.123631000000003	Мира	0103000020E6100000010000000500000093C9A99D619C40406571FF91E907514093C9A99D619C4040A9D903ADC0095140B8770DFAD2A94040A9D903ADC0095140B8770DFAD2A940406571FF91E907514093C9A99D619C40406571FF91E9075140
32170	3431	33.221729000000003	33.326751000000002	68.152384999999995	68.123631000000003	Ленинградский проспект	0103000020E6100000010000000500000093C9A99D619C40406571FF91E907514093C9A99D619C4040A9D903ADC0095140B8770DFAD2A94040A9D903ADC0095140B8770DFAD2A940406571FF91E907514093C9A99D619C40406571FF91E9075140
701	2533	33.076148000000003	33.106520000000003	69.028844000000007	69.012900000000002	улица адмирала Лобова	0103000020E61000000100000005000000F2D3B837BF8940409487855AD3405140F2D3B837BF894040E52B8194D84151405A2F8672A28D4040E52B8194D84151405A2F8672A28D40409487855AD3405140F2D3B837BF8940409487855AD3405140
4886	2533	33.081133999999999	33.098650999999997	68.999143000000004	68.994885999999994	улица Халатина	0103000020E61000000100000005000000FD4B5299628A4040E34F5436AC3F5140FD4B5299628A4040C0417BF5F13F5140DD5B9198A08C4040C0417BF5F13F5140DD5B9198A08C4040E34F5436AC3F5140FD4B5299628A4040E34F5436AC3F5140
5014	2533	33.082293	33.093387	68.986266000000001	68.982765000000001	улица Туристов	0103000020E6100000010000000500000049D8B793888A4040D2A92B9FE53E514049D8B793888A404008CA6DFB1E3F51408F6FEF1AF48B404008CA6DFB1E3F51408F6FEF1AF48B4040D2A92B9FE53E514049D8B793888A4040D2A92B9FE53E5140
647	2533	33.077342999999999	33.083218000000002	69.025915999999995	69.024725000000004	улица Торцева	0103000020E610000001000000050000008AC91B60E689404031992A18954151408AC91B60E68940405C1C959BA841514022382EE3A68A40405C1C959BA841514022382EE3A68A404031992A18954151408AC91B60E689404031992A1895415140
5212	2533	33.110292999999999	33.114677	68.976536999999993	68.971378999999999	улица Скальная	0103000020E6100000010000000500000026FDBD141E8E40405B41D3122B3E514026FDBD141E8E40405F950B957F3E51403C4D66BCAD8E40405F950B957F3E51403C4D66BCAD8E40405B41D3122B3E514026FDBD141E8E40405B41D3122B3E5140
5181	2533	33.092982999999997	33.097617999999997	68.980743000000004	68.968817000000001	улица Папанина	0103000020E61000000100000005000000BF0AF0DDE68B4040C4B30419013E5140BF0AF0DDE68B4040FBB1497EC43E51401EC022BF7E8C4040FBB1497EC43E51401EC022BF7E8C4040C4B30419013E5140BF0AF0DDE68B4040C4B30419013E5140
4759	2533	33.069195000000001	33.093513000000002	69.024512999999999	69.021000999999998	улица Нахимова	0103000020E61000000100000005000000FB05BB61DB884040BB0B941458415140FB05BB61DB884040EB54F99E914151401C60E63BF88B4040EB54F99E914151401C60E63BF88B4040BB0B941458415140FB05BB61DB884040BB0B941458415140
5830	2533	33.088625999999998	33.096854999999998	68.892278000000005	68.890011000000001	улица Крупской	0103000020E61000000100000005000000A3C9C518588B40402385B2F0F5385140A3C9C518588B40402E3C2F151B3951401FBAA0BE658C40402E3C2F151B3951401FBAA0BE658C40402385B2F0F5385140A3C9C518588B40402385B2F0F5385140
5169	2533	33.065359999999998	33.078223999999999	68.968374999999995	68.967945999999998	улица Комсомольская	0103000020E61000000100000005000000B83B6BB75D884040D192C7D3F23D5140B83B6BB75D884040E5D022DBF93D514093E1783E038A4040E5D022DBF93D514093E1783E038A4040D192C7D3F23D5140B83B6BB75D884040D192C7D3F23D5140
5119	2533	33.079796000000002	33.105091999999999	68.975714999999994	68.959380999999993	улица Карла Маркса	0103000020E61000000100000005000000022D5DC1368A4040D7D9907F663D5140022D5DC1368A4040DDCD531D723E51401E8997A7738D4040DDCD531D723E51401E8997A7738D4040D7D9907F663D5140022D5DC1368A4040D7D9907F663D5140
5039	2533	33.077074000000003	33.094582000000003	68.982771	68.976095000000001	улица Карла Либкнехта	0103000020E610000001000000050000009BAF928FDD89404081B22957783E51409BAF928FDD894040431D56B8E53E5140286552431B8C4040431D56B8E53E5140286552431B8C404081B22957783E51409BAF928FDD89404081B22957783E5140
5630	2533	33.110401000000003	33.119250000000001	68.940353000000002	68.929359000000005	улица Зои Космодемьянской	0103000020E610000001000000050000000D39B69E218E404092CF2B9E7A3B51400D39B69E218E4040836C59BE2E3C514025068195438F4040836C59BE2E3C514025068195438F404092CF2B9E7A3B51400D39B69E218E404092CF2B9E7A3B5140
4930	2533	33.065539000000001	33.094016000000003	68.999694000000005	68.995427000000007	улица Александрова	0103000020E6100000010000000500000068CEFA94638840408CA37213B53F514068CEFA94638840407A008BFCFA3F51407FA65EB7088C40407A008BFCFA3F51407FA65EB7088C40408CA37213B53F514068CEFA94638840408CA37213B53F5140
662	2533	33.067712999999998	33.098030999999999	69.013036	69.005902000000006	улица Александра Невского	0103000020E61000000100000005000000CC41D0D1AA884040C93EC8B260405140CC41D0D1AA884040EC6AF294D5405140417FA1478C8C4040EC6AF294D5405140417FA1478C8C4040C93EC8B260405140CC41D0D1AA884040C93EC8B260405140
28864	2533	33.062835	33.099063999999998	68.956874999999997	68.950253000000004	проспект Кирова	0103000020E61000000100000005000000A7052FFA0A884040427BF5F1D03C5140A7052FFA0A8840400AD7A3703D3D5140001B1021AE8C40400AD7A3703D3D5140001B1021AE8C4040427BF5F1D03C5140A7052FFA0A884040427BF5F1D03C5140
32859	2533	33.085787000000003	33.090719	68.966954999999999	68.965519	капитана Тарана	0103000020E6100000010000000500000003B68311FB8A4040AA2A3410CB3D514003B68311FB8A4040096D3997E23D51401B1021AE9C8B4040096D3997E23D51401B1021AE9C8B4040AA2A3410CB3D514003B68311FB8A4040AA2A3410CB3D5140
32892	2533	33.083964000000002	33.096873000000002	68.899015000000006	68.892461999999995	капитана Копытова	0103000020E610000001000000050000004B051555BF8A40400EBBEF181E3951404B051555BF8A404043E7357689395140C66E9F55668C404043E7357689395140C66E9F55668C40400EBBEF181E3951404B051555BF8A40400EBBEF181E395140
5752	2533	33.09442	33.106188000000003	68.911635000000004	68.911321000000001	Якорный переулок	0103000020E610000001000000050000004E0B5EF4158C40401DCA5015533A51404E0B5EF4158C4040E5B8533A583A5140249D8191978D4040E5B8533A583A5140249D8191978D40401DCA5015533A51404E0B5EF4158C40401DCA5015533A5140
32839	2533	33.06474	33.097240999999997	69.002020000000002	68.999844999999993	Чумбарова-Лучинского	0103000020E610000001000000050000001C5F7B66498840406C04E275FD3F51401C5F7B6649884040077C7E1821405140486AA164728C4040077C7E1821405140486AA164728C40406C04E275FD3F51401C5F7B66498840406C04E275FD3F5140
32858	2533	33.116097000000003	33.12039	68.954564000000005	68.952574999999996	Чехова	0103000020E61000000100000005000000F5143944DC8E40402EFF21FDF63C5140F5143944DC8E4040187C9A93173D5140FA6184F0688F4040187C9A93173D5140FA6184F0688F40402EFF21FDF63C5140F5143944DC8E40402EFF21FDF63C5140
32887	2533	33.076382000000002	33.098650999999997	68.990902000000006	68.974440999999999	Челюскинцев	0103000020E610000001000000050000006500A8E2C68940406BB8C83D5D3E51406500A8E2C6894040A0E238F06A3F5140DD5B9198A08C4040A0E238F06A3F5140DD5B9198A08C40406BB8C83D5D3E51406500A8E2C68940406BB8C83D5D3E5140
32881	2533	33.081133999999999	33.094016000000003	68.999143000000004	68.995801	Халатина	0103000020E61000000100000005000000FD4B5299628A4040BE141E34BB3F5140FD4B5299628A4040C0417BF5F13F51407FA65EB7088C4040C0417BF5F13F51407FA65EB7088C4040BE141E34BB3F5140FD4B5299628A4040BE141E34BB3F5140
32825	2533	33.077342999999999	33.083218000000002	69.025915999999995	69.024725000000004	Торцева	0103000020E610000001000000050000008AC91B60E689404031992A18954151408AC91B60E68940405C1C959BA841514022382EE3A68A40405C1C959BA841514022382EE3A68A404031992A18954151408AC91B60E689404031992A1895415140
32898	2533	33.049647999999998	33.063186000000002	68.955174	68.950672999999995	Спортивная	0103000020E61000000100000005000000E9279CDD5A8640402C0C91D3D73C5140E9279CDD5A86404054FF2092213D514054C8957A1688404054FF2092213D514054C8957A168840402C0C91D3D73C5140E9279CDD5A8640402C0C91D3D73C5140
32891	2533	33.114336000000002	33.120876000000003	68.932652000000004	68.931934999999996	Спартака	0103000020E61000000100000005000000B360E28FA28E4040DBBFB2D2A43B5140B360E28FA28E404023A30392B03B5140876F61DD788F404023A30392B03B5140876F61DD788F4040DBBFB2D2A43B5140B360E28FA28E4040DBBFB2D2A43B5140
32867	2533	33.078223999999999	33.097501000000001	68.973804999999999	68.967962	Софьи Перовской	0103000020E6100000010000000500000093E1783E038A40405471E316F33D514093E1783E038A40409AEB34D2523E5140E529ABE97A8C40409AEB34D2523E5140E529ABE97A8C40405471E316F33D514093E1783E038A40405471E316F33D5140
5232	2533	33.103887999999998	33.112692000000003	68.969808	68.966194000000002	Связи проезд	0103000020E610000001000000050000003239B5334C8D4040DAE55B1FD63D51403239B5334C8D40408CD99255113E5140AB4203B16C8E40408CD99255113E5140AB4203B16C8E4040DAE55B1FD63D51403239B5334C8D4040DAE55B1FD63D5140
32866	2533	33.077342999999999	33.087431000000002	69.024725000000004	69.016996000000006	Сафонова	0103000020E610000001000000050000008AC91B60E68940406C0A6476164151408AC91B60E689404031992A18954151400BD462F0308B404031992A18954151400BD462F0308B40406C0A6476164151408AC91B60E68940406C0A647616415140
32875	2533	33.069716	33.070956000000002	68.968924000000001	68.964382999999998	Самойловой	0103000020E6100000010000000500000004013274EC88404060747973B83D514004013274EC884040CF13CFD9023E51403DBA111615894040CF13CFD9023E51403DBA11161589404060747973B83D514004013274EC88404060747973B83D5140
32886	2533	33.115495000000003	33.117587999999998	68.953382000000005	68.952245000000005	Рылеева	0103000020E61000000100000005000000FFEC478AC88E4040E4310395F13C5140FFEC478AC88E404016A6EF35043D51407633A31F0D8F404016A6EF35043D51407633A31F0D8F4040E4310395F13C5140FFEC478AC88E4040E4310395F13C5140
32868	2533	33.077047	33.083810999999997	68.971143999999995	68.969037	Пушкинская	0103000020E61000000100000005000000A1A014ADDC8940404BE7C3B3043E5140A1A014ADDC89404039ED2939273E5140C405A051BA8A404039ED2939273E5140C405A051BA8A40404BE7C3B3043E5140A1A014ADDC8940404BE7C3B3043E5140
32821	2533	33.002603000000001	33.010958000000002	68.938785999999993	68.926938000000007	Прибрежная	0103000020E610000001000000050000008DEF8B4B55804040DCDAC2F3523B51408DEF8B4B5580404054FCDF11153C514096D05D126781404054FCDF11153C514096D05D1267814040DCDAC2F3523B51408DEF8B4B55804040DCDAC2F3523B5140
32872	2533	33.083021000000002	33.099342999999998	68.967906999999997	68.952832999999998	Полярные Зори	0103000020E61000000100000005000000CCF09F6EA08A40402C634337FB3C5140CCF09F6EA08A404072A43330F23D5140130B7C45B78C404072A43330F23D5140130B7C45B78C40402C634337FB3C5140CCF09F6EA08A40402C634337FB3C5140
32841	2533	33.066932000000001	33.072913999999997	68.956197000000003	68.953710999999998	Полярной Дивизии	0103000020E6100000010000000500000027874F3A9188404078B5DC99093D514027874F3A9188404022E2E654323D5140D4B5F63E5589404022E2E654323D5140D4B5F63E5589404078B5DC99093D514027874F3A9188404078B5DC99093D5140
32894	2533	33.102477999999998	33.113436999999998	68.996860999999996	68.996626000000006	Подстаницкого	0103000020E610000001000000050000009D47C5FF1D8D4040F9156BB8C83F51409D47C5FF1D8D40401A6A1492CC3F51400394861A858E40401A6A1492CC3F51400394861A858E4040F9156BB8C83F51409D47C5FF1D8D4040F9156BB8C83F5140
32829	2533	33.035491	33.060814000000001	68.962163000000004	68.943273000000005	Подгорная	0103000020E61000000100000005000000B32616F88A844040CA8CB7955E3C5140B32616F88A844040F69A1E14943D5140C991CEC0C8874040F69A1E14943D5140C991CEC0C8874040CA8CB7955E3C5140B32616F88A844040CA8CB7955E3C5140
32827	2533	33.102953999999997	33.113680000000002	68.995086000000001	68.994651000000005	Павлика Морозова	0103000020E61000000100000005000000067FBF982D8D4040C2FBAA5CA83F5140067FBF982D8D404047AD307DAF3F5140CA1AF5108D8E404047AD307DAF3F5140CA1AF5108D8E4040C2FBAA5CA83F5140067FBF982D8D4040C2FBAA5CA83F5140
32880	2533	33.109439999999999	33.116473999999997	68.939680999999993	68.935820000000007	Олега Кошевого	0103000020E61000000100000005000000E76F4221028E404056BC9179E43B5140E76F4221028E40400BEBC6BB233C5140CA6ABA9EE88E40400BEBC6BB233C5140CA6ABA9EE88E404056BC9179E43B5140E76F4221028E404056BC9179E43B5140
32879	2533	33.101688000000003	33.111803000000002	68.999967999999996	68.999432999999996	Миронова	0103000020E61000000100000005000000A532C51C048D4040C362D4B5F63F5140A532C51C048D4040FA42C879FF3F51401F4C8A8F4F8E4040FA42C879FF3F51401F4C8A8F4F8E4040C362D4B5F63F5140A532C51C048D4040C362D4B5F63F5140
32830	2533	33.104382000000001	33.115558	68.977665999999999	68.975088999999997	Мира	0103000020E610000001000000050000004225AE635C8D40401E6CB1DB673E51404225AE635C8D4040501A6A14923E51404565C39ACA8E4040501A6A14923E51404565C39ACA8E40401E6CB1DB673E51404225AE635C8D40401E6CB1DB673E5140
5272	2533	33.102128	33.112394999999999	68.944404000000006	68.943602999999996	Лыжный проезд	0103000020E61000000100000005000000C100C287128D4040145AD6FD633C5140C100C287128D40408B8D791D713C5140F19D98F5628E40408B8D791D713C5140F19D98F5628E4040145AD6FD633C5140C100C287128D4040145AD6FD633C5140
32834	2533	32.992336000000002	33.025303999999998	68.979033999999999	68.978582000000003	Лесная	0103000020E610000001000000050000005D52B5DD047F4040139D6516A13E51405D52B5DD047F404003EB387EA83E51409F3A56293D83404003EB387EA83E51409F3A56293D834040139D6516A13E51405D52B5DD047F4040139D6516A13E5140
5316	2533	33.071181000000003	33.097572999999997	68.977046999999999	68.950284999999994	Ленина проспект	0103000020E610000001000000050000005D8C81751C89404047382D78D13C51405D8C81751C894040EAE923F0873E51407EFCA5457D8C4040EAE923F0873E51407EFCA5457D8C404047382D78D13C51405D8C81751C89404047382D78D13C5140
32873	2533	33.071181000000003	33.097572999999997	68.976973000000001	68.950284999999994	Ленина	0103000020E610000001000000050000005D8C81751C89404047382D78D13C51405D8C81751C894040CD04C3B9863E51407EFCA5457D8C4040CD04C3B9863E51407EFCA5457D8C404047382D78D13C51405D8C81751C89404047382D78D13C5140
5722	2533	33.105308000000001	33.106988000000001	68.921055999999993	68.911602000000002	Ледокольный проезд	0103000020E61000000100000005000000EB0088BB7A8D4040F73DEAAF573A5140EB0088BB7A8D40403672DD94F23A5140408864C8B18D40403672DD94F23A5140408864C8B18D4040F73DEAAF573A5140EB0088BB7A8D4040F73DEAAF573A5140
32861	2533	33.087736999999997	33.096845999999999	68.889418000000006	68.887624000000002	Крупской	0103000020E6100000010000000500000017D34CF73A8B404043C9E4D4CE38514017D34CF73A8B4040529E7939EC385140CC5F2173658C4040529E7939EC385140CC5F2173658C404043C9E4D4CE38514017D34CF73A8B404043C9E4D4CE385140
57949	2533	33.065359999999998	33.076453999999998	68.974530999999999	68.968366000000003	Коминтерна	0103000020E61000000100000005000000B83B6BB75D884040BC2363B5F93D5140B83B6BB75D8840400B7C45B75E3E5140FED2A23EC98940400B7C45B75E3E5140FED2A23EC9894040BC2363B5F93D5140B83B6BB75D884040BC2363B5F93D5140
730	2533	33.072726000000003	33.112512000000002	68.950292000000005	68.896000999999998	Кольский проспект	0103000020E61000000100000005000000D2C8E7154F894040BB0B941458395140D2C8E7154F894040A1698995D13C51402B3410CB668E4040A1698995D13C51402B3410CB668E4040BB0B941458395140D2C8E7154F894040BB0B941458395140
32844	2533	33.063428000000002	33.103026	68.960729999999998	68.959380999999993	Книповича	0103000020E610000001000000050000004AD3A0681E884040D7D9907F663D51404AD3A0681E8840404F92AE997C3D5140A051BAF42F8D40404F92AE997C3D5140A051BAF42F8D4040D7D9907F663D51404AD3A0681E884040D7D9907F663D5140
712	2533	33.062835	33.099063999999998	68.956874999999997	68.950253000000004	Кирова проспект	0103000020E61000000100000005000000A7052FFA0A884040427BF5F1D03C5140A7052FFA0A8840400AD7A3703D3D5140001B1021AE8C40400AD7A3703D3D5140001B1021AE8C4040427BF5F1D03C5140A7052FFA0A884040427BF5F1D03C5140
32897	2533	33.062835	33.099063999999998	68.956874999999997	68.950253000000004	Кирова 	0103000020E61000000100000005000000A7052FFA0A884040427BF5F1D03C5140A7052FFA0A8840400AD7A3703D3D5140001B1021AE8C40400AD7A3703D3D5140001B1021AE8C4040427BF5F1D03C5140A7052FFA0A884040427BF5F1D03C5140
32855	2533	33.077827999999997	33.094582000000003	68.982771	68.976095000000001	Карла Либкнехта	0103000020E61000000100000005000000465B9544F689404081B22957783E5140465B9544F6894040431D56B8E53E5140286552431B8C4040431D56B8E53E5140286552431B8C404081B22957783E5140465B9544F689404081B22957783E5140
32876	2533	33.084268999999999	33.098840000000003	68.947973000000005	68.944096999999999	Капитана Орликовой	0103000020E6100000010000000500000087889B53C98A40401CD0D2156C3C514087889B53C98A40406D1FF296AB3C5140B1C403CAA68C40406D1FF296AB3C5140B1C403CAA68C40401CD0D2156C3C514087889B53C98A40401CD0D2156C3C5140
32856	2533	33.103287000000002	33.119708000000003	68.972865999999996	68.964331999999999	Капитана Маклакова	0103000020E610000001000000050000000D8D2782388D40401F9F909DB73D51400D8D2782388D4040FB58C16F433E5140E8887C97528F4040FB58C16F433E5140E8887C97528F40401F9F909DB73D51400D8D2782388D40401F9F909DB73D5140
32889	2533	33.06465	33.077477999999999	68.965474	68.965016000000006	Капитана Егорова	0103000020E61000000100000005000000DCD7817346884040790778D2C23D5140DCD7817346884040DAC87553CA3D51406A1492CCEA894040DAC87553CA3D51406A1492CCEA894040790778D2C23D5140DCD7817346884040790778D2C23D5140
32902	2533	33.077306999999998	33.097465	68.970076000000006	68.960210000000004	Капитана Буркова	0103000020E610000001000000050000003D601E32E5894040B3D2A414743D51403D601E32E58940409CA8A5B9153E514098C0ADBB798C40409CA8A5B9153E514098C0ADBB798C4040B3D2A414743D51403D601E32E5894040B3D2A414743D5140
4884	2533	33.078394000000003	33.086371	69.009297000000004	69.006062999999997	Казарменный переулок	0103000020E61000000100000005000000F01989D0088A4040CDAD105663405140F01989D0088A4040DCBC715298405140522976340E8B4040DCBC715298405140522976340E8B4040CDAD105663405140F01989D0088A4040CDAD105663405140
32885	2533	33.106555999999998	33.116275999999999	69.012935999999996	69.011007000000006	Ивченко	0103000020E61000000100000005000000A69883A0A38D4040BC41B456B4405140A69883A0A38D40403A3C84F1D3405140A4A7C821E28E40403A3C84F1D3405140A4A7C821E28E4040BC41B456B4405140A69883A0A38D4040BC41B456B4405140
32850	2533	33.110401000000003	33.119250000000001	68.940353000000002	68.929359000000005	Зои Космодемьянской	0103000020E610000001000000050000000D39B69E218E404092CF2B9E7A3B51400D39B69E218E4040836C59BE2E3C514025068195438F4040836C59BE2E3C514025068195438F404092CF2B9E7A3B51400D39B69E218E404092CF2B9E7A3B5140
32816	2533	33.047097000000001	33.054481000000003	68.948447999999999	68.945905999999994	Заречная	0103000020E61000000100000005000000AF5E454607864040C5C551B9893C5140AF5E454607864040397D3D5FB33C51406FA0C03BF9864040397D3D5FB33C51406FA0C03BF9864040C5C551B9893C5140AF5E454607864040C5C551B9893C5140
4819	2533	33.090980000000002	33.113661999999998	69.026173	68.983687000000003	Героев Североморцев проспект	0103000020E61000000100000005000000884B8E3BA58B404006A051BAF43E5140884B8E3BA58B404072C284D1AC4151402366F6798C8E404072C284D1AC4151402366F6798C8E404006A051BAF43E5140884B8E3BA58B404006A051BAF43E5140
32863	2533	33.089461	33.102271000000002	68.903189999999995	68.887207000000004	Героев Рыбачьего	0103000020E610000001000000050000003CA24275738B40401172DEFFC73851403CA24275738B4040C0046EDDCD395140242A5437178D4040C0046EDDCD395140242A5437178D40401172DEFFC73851403CA24275738B40401172DEFFC7385140
32895	2533	33.096738000000002	33.108632	68.983615999999998	68.978537000000003	Георгия Седова	0103000020E61000000100000005000000E62329E9618C4040433BA759A03E5140E62329E9618C4040A1F48590F33E514048A643A7E78D4040A1F48590F33E514048A643A7E78D4040433BA759A03E5140E62329E9618C4040433BA759A03E5140
32851	2533	33.062125999999999	33.069878000000003	68.952995000000001	68.949399999999997	Генералова	0103000020E610000001000000050000009B1DA9BEF3874040A2B437F8C23C51409B1DA9BEF38740401990BDDEFD3C5140DE5A26C3F18840401990BDDEFD3C5140DE5A26C3F1884040A2B437F8C23C51409B1DA9BEF3874040A2B437F8C23C5140
32899	2533	33.083443000000003	33.098894000000001	68.955978000000002	68.951383000000007	Гвардейская	0103000020E61000000100000005000000420A9E42AE8A40401BBE8575E33C5140420A9E42AE8A4040836C59BE2E3D5140A4E2FF8EA88C4040836C59BE2E3D5140A4E2FF8EA88C40401BBE8575E33C5140420A9E42AE8A40401BBE8575E33C5140
32835	2533	33.098587999999999	33.109368000000003	69.005476999999999	69.005081000000004	Гаджиева	0103000020E6100000010000000500000097E315889E8C40402F35423F5340514097E315889E8C404055F833BC594051404E9D47C5FF8D404055F833BC594051404E9D47C5FF8D40402F35423F5340514097E315889E8C40402F35423F53405140
32854	2533	33.099162999999997	33.103017000000001	69.005444999999995	68.992720000000006	Гагарина	0103000020E6100000010000000500000093FC885FB18C4040738577B9883F514093FC885FB18C40404F3BFC35594051404DF73AA92F8D40404F3BFC35594051404DF73AA92F8D4040738577B9883F514093FC885FB18C4040738577B9883F5140
32869	2533	33.078448000000002	33.090826999999997	68.978313999999997	68.973157	Володарского	0103000020E61000000100000005000000E33785950A8A4040E7374C34483E5140E33785950A8A404003CE52B29C3E5140014C1938A08B404003CE52B29C3E5140014C1938A08B4040E7374C34483E5140E33785950A8A4040E7374C34483E5140
32870	2533	33.069456000000002	33.085616999999999	68.915334999999999	68.911803000000006	Бочкова	0103000020E61000000100000005000000684128EFE38840404359F8FA5A3A5140684128EFE3884040967840D9943A5140A67D737FF58A4040967840D9943A5140A67D737FF58A40404359F8FA5A3A5140684128EFE38840404359F8FA5A3A5140
32888	2533	33.093091000000001	33.106988000000001	68.916784000000007	68.914899000000005	Беринга	0103000020E61000000100000005000000A646E867EA8B4040290989B48D3A5140A646E867EA8B4040C05FCC96AC3A5140408864C8B18D4040C05FCC96AC3A5140408864C8B18D4040290989B48D3A5140A646E867EA8B4040290989B48D3A5140
32819	2533	33.067551999999999	33.093127000000003	68.914969999999997	68.901302999999999	Баумана	0103000020E61000000100000005000000C3633F8BA58840405932C7F2AE395140C3633F8BA58840408DB454DE8E3A5140F3AFE595EB8B40408DB454DE8E3A5140F3AFE595EB8B40405932C7F2AE395140C3633F8BA58840405932C7F2AE395140
32901	2533	33.070911000000002	33.081619000000003	69.006062999999997	68.992442999999994	Аскольдовцев	0103000020E610000001000000050000009DF6949C138940403909A52F843F51409DF6949C13894040CDAD105663405140BADDCB7D728A4040CDAD105663405140BADDCB7D728A40403909A52F843F51409DF6949C138940403909A52F843F5140
32860	2533	33.076148000000003	33.106501999999999	69.028844000000007	69.012980999999996	Адмирала Лобова	0103000020E61000000100000005000000F2D3B837BF8940400A9E42AED4405140F2D3B837BF894040E52B8194D8415140B37A87DBA18D4040E52B8194D8415140B37A87DBA18D40400A9E42AED4405140F2D3B837BF8940400A9E42AED4405140
32806	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	пр.Металлургов	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
9789	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	пр. Металлургов	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32229	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Царевского	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32753	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Ферсмана	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32231	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Строительный проезд	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32767	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Строительная	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32180	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Проспект Кирова	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32765	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Новопроложенная	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32208	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Лесная	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32759	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Ленинградская наб	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32698	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Котульского	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32213	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Кондрикова	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32696	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Комсомольская	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32711	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Кирова	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32165	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	Бредова	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32758	3240	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	3-я Нагорная	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32831	1613	33.009951999999998	33.013041999999999	68.884726000000001	68.877478999999994	Победы	0103000020E61000000100000005000000D0436D1B4681404050FBAD9D28385140D0436D1B46814040F0FACC599F385140BABC395CAB814040F0FACC599F385140BABC395CAB81404050FBAD9D28385140D0436D1B4681404050FBAD9D28385140
6685	1613	33.003977999999996	33.02834	68.886374000000004	68.878117000000003	Защитников Заполярья проспект	0103000020E61000000100000005000000A5F3E15982804040F243A51133385140A5F3E159828040409581035ABA385140969526A5A08340409581035ABA385140969526A5A0834040F243A51133385140A5F3E15982804040F243A51133385140
32743	45752	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	проспект Ленина	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
32785	45752	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	Советской Конституции	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
32697	45752	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	Олимпийская	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
32737	45752	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	Мира	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
32774	45752	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	Ленинградская	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
32779	45752	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	Кондрикова	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
32161	45752	33.648015999999998	33.701897000000002	67.622613000000001	67.604212000000004	Кирова	0103000020E6100000010000000500000072A43330F2D2404073F6CE68ABE6504072A43330F2D24040204432E4D8E750408C14CAC2D7D94040204432E4D8E750408C14CAC2D7D9404073F6CE68ABE6504072A43330F2D2404073F6CE68ABE65040
32776	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Спекова	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32769	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Пронина	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32837	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Первомайская	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32865	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Новая	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32814	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Набережная	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
57948	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Мурманская	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32812	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Высокая	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32810	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Восточная	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32773	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Беломорская	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32761	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Аэронавтов	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32154	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	3-я Линия	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32730	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	2-я Парковая	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32905	2080	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	 Кировская аллея	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
9815	40322	32.804192	32.967201000000003	67.946804999999998	67.910673000000003	проспект Металлургов	0103000020E6100000010000000500000038DA71C3EF6640406A16687748FA504038DA71C3EF6640401DACFF7398FC50404AD40B3ECD7B40401DACFF7398FC50404AD40B3ECD7B40406A16687748FA504038DA71C3EF6640406A16687748FA5040
32757	621	33.291528	33.370669999999997	69.267718000000002	69.244327999999996	Советская	0103000020E6100000010000000500000024EF1CCA50A54040D05FE811A34F514024EF1CCA50A540403CA3AD4A22515140DDCD531D72AF40403CA3AD4A22515140DDCD531D72AF4040D05FE811A34F514024EF1CCA50A54040D05FE811A34F5140
32728	621	33.291528	33.370669999999997	69.267718000000002	69.244327999999996	Колышкина	0103000020E6100000010000000500000024EF1CCA50A54040D05FE811A34F514024EF1CCA50A540403CA3AD4A22515140DDCD531D72AF40403CA3AD4A22515140DDCD531D72AF4040D05FE811A34F514024EF1CCA50A54040D05FE811A34F5140
32687	621	33.291528	33.370669999999997	69.267718000000002	69.244327999999996	Душенова	0103000020E6100000010000000500000024EF1CCA50A54040D05FE811A34F514024EF1CCA50A540403CA3AD4A22515140DDCD531D72AF40403CA3AD4A22515140DDCD531D72AF4040D05FE811A34F514024EF1CCA50A54040D05FE811A34F5140
32144	621	33.291528	33.370669999999997	69.267718000000002	69.244327999999996	Гаджиева	0103000020E6100000010000000500000024EF1CCA50A54040D05FE811A34F514024EF1CCA50A540403CA3AD4A22515140DDCD531D72AF40403CA3AD4A22515140DDCD531D72AF4040D05FE811A34F514024EF1CCA50A54040D05FE811A34F5140
32141	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Ферсмана	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32685	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Строителей	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32677	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Сидоренко	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32183	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Ленина	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32191	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Космонавтов	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32708	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Кирова	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32718	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Зиновьева	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32750	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Жемчужная	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32150	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Дзержинского	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32748	2005	33.335735	33.440873000000003	67.594695999999999	67.557580000000002	Бредова	0103000020E61000000100000005000000B08F4E5DF9AA4040D6390664AFE35040B08F4E5DF9AA4040F8C3CF7F0FE650403F58C6866EB84040F8C3CF7F0FE650403F58C6866EB84040D6390664AFE35040B08F4E5DF9AA4040D6390664AFE35040
32818	53395	34.313039000000003	34.359302	66.705099000000004	66.668127999999996	Приморская	0103000020E61000000100000005000000B0AF75A911284140AE62F19BC2AA5040B0AF75A9112841404F5C8E5720AD504096B1A19BFD2D41404F5C8E5720AD504096B1A19BFD2D4140AE62F19BC2AA5040B0AF75A911284140AE62F19BC2AA5040
32764	53395	34.313039000000003	34.359302	66.705099000000004	66.668127999999996	Беломорская	0103000020E61000000100000005000000B0AF75A911284140AE62F19BC2AA5040B0AF75A9112841404F5C8E5720AD504096B1A19BFD2D41404F5C8E5720AD504096B1A19BFD2D4140AE62F19BC2AA5040B0AF75A911284140AE62F19BC2AA5040
32172	53301	34.29607	34.308250999999998	66.684966000000003	66.673670000000001	Совхозная	0103000020E61000000100000005000000D2A92B9FE5254140F792C6681DAB5040D2A92B9FE5254140CE37A27BD6AB5040CAFACDC474274140CE37A27BD6AB5040CAFACDC474274140F792C6681DAB5040D2A92B9FE5254140F792C6681DAB5040
32695	1480	36.580333000000003	36.60492	66.404568999999995	66.393288999999996	Успенская	0103000020E6100000010000000500000011E50B5A484A42401938A0A52B99504011E50B5A484A42406DFE5F75E49950402159C0046E4D42406DFE5F75E49950402159C0046E4D42401938A0A52B99504011E50B5A484A42401938A0A52B995040
32160	247	33.615704000000001	33.642797000000002	69.043566999999996	69.027405999999999	Агеева	0103000020E6100000010000000500000019028063CFCE4040B56D1805C141514019028063CFCE4040D40B3ECDC9425140C47B0E2C47D24040D40B3ECDC9425140C47B0E2C47D24040B56D1805C141514019028063CFCE4040B56D1805C1415140
32815	32341	33.271658000000002	33.308534000000002	69.071696000000003	69.024180999999999	Панина	0103000020E6100000010000000500000030D978B0C5A24040D00B772E8C41514030D978B0C5A2404042D0D1AA964451401FDAC70A7EA7404042D0D1AA964451401FDAC70A7EA74040D00B772E8C41514030D978B0C5A24040D00B772E8C415140
32190	63	33.186613999999999	33.244788999999997	69.060507000000001	69.037231000000006	Приморская	0103000020E61000000100000005000000E57CB1F7E29740406FD921FE61425140E57CB1F7E2974040768BC058DF435140D4B5F63E559F4040768BC058DF435140D4B5F63E559F40406FD921FE61425140E57CB1F7E29740406FD921FE61425140
32784	63	33.186613999999999	33.244788999999997	69.060507000000001	69.037231000000006	Молодежная,	0103000020E61000000100000005000000E57CB1F7E29740406FD921FE61425140E57CB1F7E2974040768BC058DF435140D4B5F63E559F4040768BC058DF435140D4B5F63E559F40406FD921FE61425140E57CB1F7E29740406FD921FE61425140
32778	63	33.186613999999999	33.244788999999997	69.060507000000001	69.037231000000006	Заводкая	0103000020E61000000100000005000000E57CB1F7E29740406FD921FE61425140E57CB1F7E2974040768BC058DF435140D4B5F63E559F4040768BC058DF435140D4B5F63E559F40406FD921FE61425140E57CB1F7E29740406FD921FE61425140
32717	26381	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	пр.Гвардейский	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
32679	26381	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	Спортивная	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
32700	26381	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	Сидоровича	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
32808	26381	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	Печенгская	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
32751	26381	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	Октябрьская	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
32723	26381	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	Гвардейский	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
32714	26381	30.176826999999999	30.255949999999999	69.424982	69.398332999999994	Бредова	0103000020E61000000100000005000000BF0CC688442D3E40B9FAB1497E595140BF0CC688442D3E40E0D8B3E7325B514044696FF085413E40E0D8B3E7325B514044696FF085413E40B9FAB1497E595140BF0CC688442D3E40B9FAB1497E595140
32681	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	Стрельцова	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32725	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	Сафонова	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32726	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	Мира	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32771	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	Ленинградская	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32722	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	Ленина	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32729	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	Крупской	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32800	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	Космонавтов	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32788	2388	30.788211	30.844373999999998	69.432158999999999	69.414591000000001	 Юбилейная	0103000020E61000000100000005000000F3583332C8C93E40D28DB0A8885A5140F3583332C8C93E4003EB387EA85B5140BB97FBE428D83E4003EB387EA85B5140BB97FBE428D83E40D28DB0A8885A5140F3583332C8C93E40D28DB0A8885A5140
32793	3611	33.389381999999998	33.440882000000002	68.149480999999994	68.127476999999999	Сыромятникова	0103000020E6100000010000000500000056D3F544D7B14040807F4A952808514056D3F544D7B14040E597C1189109514092B245D26EB84040E597C1189109514092B245D26EB84040807F4A952808514056D3F544D7B14040807F4A9528085140
32720	53382	32.931789000000002	32.97383	67.978720999999993	67.963845000000006	Октябрьская	0103000020E61000000100000005000000E3E2A8DC44774040715AF0A2AFFD5040E3E2A8DC4477404023BA675DA3FE50408DEE2076A67C404023BA675DA3FE50408DEE2076A67C4040715AF0A2AFFD5040E3E2A8DC44774040715AF0A2AFFD5040
32804	45970	34.529488000000001	34.573397	67.956282999999999	67.935768999999993	Победы	0103000020E61000000100000005000000EECF4543C643414014E7A8A3E3FB5040EECF4543C643414021AE9CBD33FD5040F04FA9126549414021AE9CBD33FD5040F04FA9126549414014E7A8A3E3FB5040EECF4543C643414014E7A8A3E3FB5040
32796	45970	34.529488000000001	34.573397	67.956282999999999	67.935768999999993	Металлургов	0103000020E61000000100000005000000EECF4543C643414014E7A8A3E3FB5040EECF4543C643414021AE9CBD33FD5040F04FA9126549414021AE9CBD33FD5040F04FA9126549414014E7A8A3E3FB5040EECF4543C643414014E7A8A3E3FB5040
32782	27552	35.002513999999998	35.032167000000001	68.012366999999998	67.996994000000001	Советская	0103000020E610000001000000050000001DE4F56052804140BA13ECBFCEFF50401DE4F560528041402D23F59ECA00514056815A0C1E8441402D23F59ECA00514056815A0C1E844140BA13ECBFCEFF50401DE4F56052804140BA13ECBFCEFF5040
32169	53300	28.433969000000001	36.187094999999999	69.588654000000005	67.669399999999996	Энергетиков	0103000020E61000000100000005000000537AA697186F3C4050FC1873D7EA5040537AA697186F3C4037AAD381AC655140601F9DBAF217424037AAD381AC655140601F9DBAF217424050FC1873D7EA5040537AA697186F3C4050FC1873D7EA5040
32826	53407	33.120452999999998	33.173741	68.768891999999994	68.738750999999993	Комсомольская	0103000020E6100000010000000500000040DAFF006B8F4040C93846B2472F514040DAFF006B8F4040FC89CA8635315140B77C24253D964040FC89CA8635315140B77C24253D964040C93846B2472F514040DAFF006B8F4040C93846B2472F5140
32731	27144	32.779471000000001	32.820407000000003	69.295962000000003	69.279971000000003	Рыбацкая	0103000020E610000001000000050000001897AAB4C563404005357C0BEB5151401897AAB4C5634040F6B6990AF15251406A34B91803694040F6B6990AF15251406A34B9180369404005357C0BEB5151401897AAB4C563404005357C0BEB515140
32686	2175	32.673074	32.700814000000001	68.821550000000002	68.814549	Мира	0103000020E61000000100000005000000DAE4F0492756404054FF209221345140DAE4F04927564040D8817346943451401B4AED45B4594040D8817346943451401B4AED45B459404054FF209221345140DAE4F0492756404054FF209221345140
32760	53393	33.719127	33.740237	68.894356000000002	68.861344000000003	Школьная	0103000020E61000000100000005000000D655815A0CDC4040C6A6954220375140D655815A0CDC4040CFBEF2203D39514003250516C0DE4040CFBEF2203D39514003250516C0DE4040C6A6954220375140D655815A0CDC4040C6A6954220375140
32195	53302	33.306279000000004	33.346389000000002	68.483957000000004	68.454153000000005	Центральная	0103000020E61000000100000005000000CE39782634A740405798BED7101D5140CE39782634A74040E6EAC726F91E5140DA58897956AC4040E6EAC726F91E5140DA58897956AC40405798BED7101D5140CE39782634A740405798BED7101D5140
32678	53371	33.187314999999998	33.280802999999999	68.499566000000002	68.466648000000006	Ткачёва	0103000020E610000001000000050000006E861BF0F99740409BAF928FDD1D51406E861BF0F9974040630CACE3F81F514031CF4A5AF1A34040630CACE3F81F514031CF4A5AF1A340409BAF928FDD1D51406E861BF0F99740409BAF928FDD1D5140
32739	25966	32.747787000000002	32.840035	68.832254000000006	68.802324999999996	Энергетиков	0103000020E61000000100000005000000DEAF027CB75F4040D8F0F44A59335140DEAF027CB75F4040C6FD47A643355140683F5244866B4040C6FD47A643355140683F5244866B4040D8F0F44A59335140DEAF027CB75F4040D8F0F44A59335140
32780	25966	32.747787000000002	32.840035	68.832254000000006	68.802324999999996	Советская	0103000020E61000000100000005000000DEAF027CB75F4040D8F0F44A59335140DEAF027CB75F4040C6FD47A643355140683F5244866B4040C6FD47A643355140683F5244866B4040D8F0F44A59335140DEAF027CB75F4040D8F0F44A59335140
32139	25966	32.747787000000002	32.840035	68.832254000000006	68.802324999999996	Причальная	0103000020E61000000100000005000000DEAF027CB75F4040D8F0F44A59335140DEAF027CB75F4040C6FD47A643355140683F5244866B4040C6FD47A643355140683F5244866B4040D8F0F44A59335140DEAF027CB75F4040D8F0F44A59335140
32704	25966	32.747787000000002	32.840035	68.832254000000006	68.802324999999996	Гвардейская	0103000020E61000000100000005000000DEAF027CB75F4040D8F0F44A59335140DEAF027CB75F4040C6FD47A643355140683F5244866B4040C6FD47A643355140683F5244866B4040D8F0F44A59335140DEAF027CB75F4040D8F0F44A59335140
32724	26225	33.009709000000001	33.024611999999998	68.858406000000002	68.851056999999997	Торговая	0103000020E610000001000000050000000ABDFE243E8140400A82C7B7773651400ABDFE243E8140402C2CB81FF0365140698B6B7C268340402C2CB81FF0365140698B6B7C268340400A82C7B7773651400ABDFE243E8140400A82C7B777365140
32703	53380	33.016303000000001	33.042354000000003	69.046664000000007	69.040032999999994	Почтовая	0103000020E61000000100000005000000D1E9793716824040B07092E68F425140D1E9793716824040A379008BFC4251406A6D1ADB6B854040A379008BFC4251406A6D1ADB6B854040B07092E68F425140D1E9793716824040B07092E68F425140
32221	26955	32.906115	32.959215	69.044313000000002	69.028191000000007	Строительная	0103000020E6100000010000000500000020B58993FB734040A9C29FE1CD41514020B58993FB73404069723106D6425140946A9F8EC77A404069723106D6425140946A9F8EC77A4040A9C29FE1CD41514020B58993FB734040A9C29FE1CD415140
32824	53406	33.117578999999999	33.134780999999997	68.688569999999999	68.678168999999997	Набережная	0103000020E6100000010000000500000023D923D40C8F40404E0AF31E672B514023D923D40C8F40406EC0E787112C5140A38FF980409140406EC0E787112C5140A38FF980409140404E0AF31E672B514023D923D40C8F40404E0AF31E672B5140
32862	53414	33.024602999999999	33.288366000000003	68.88297	68.332234999999997	Советский проспект	0103000020E610000001000000050000001631EC30268340408AE59656431551401631EC302683404058569A9482385140A1A3552DE9A4404058569A9482385140A1A3552DE9A440408AE59656431551401631EC30268340408AE5965643155140
32877	53414	33.024602999999999	33.288366000000003	68.88297	68.332234999999997	Приморская	0103000020E610000001000000050000001631EC30268340408AE59656431551401631EC302683404058569A9482385140A1A3552DE9A4404058569A9482385140A1A3552DE9A440408AE59656431551401631EC30268340408AE5965643155140
32833	53409	33.090935000000002	33.133676999999999	68.825912000000002	68.799567999999994	Советская улица	0103000020E61000000100000005000000E88711C2A38B404066BB421F2C335140E88711C2A38B4040EF5701BEDB3451401B9DF3531C914040EF5701BEDB3451401B9DF3531C91404066BB421F2C335140E88711C2A38B404066BB421F2C335140
32237	53310	32.406320000000001	32.435084000000003	69.100712000000001	69.084978000000007	Небольсина	0103000020E61000000100000005000000F9DA334B023440404AB8904770455140F9DA334B023440402594BE1072465140A6811FD5B03740402594BE1072465140A6811FD5B03740404AB8904770455140F9DA334B023440404AB8904770455140
32852	53411	33.075232	33.195481000000001	68.862249000000006	68.833817999999994	Зеленая	0103000020E610000001000000050000006CCEC133A18940403B342C465D3551406CCEC133A18940408F006E162F375140A4FE7A85059940408F006E162F375140A4FE7A85059940403B342C465D3551406CCEC133A18940403B342C465D355140
32236	22939	32.422265000000003	32.468626999999998	69.435854000000006	69.383370999999997	переулок Школьный	0103000020E610000001000000050000006B9F8EC70C36404007CF8426895851406B9F8EC70C3640402CF52C08E55B5140E48233F8FB3B40402CF52C08E55B5140E48233F8FB3B404007CF8426895851406B9F8EC70C36404007CF842689585140
32152	22939	32.422265000000003	32.468626999999998	69.435854000000006	69.383370999999997	Мира	0103000020E610000001000000050000006B9F8EC70C36404007CF8426895851406B9F8EC70C3640402CF52C08E55B5140E48233F8FB3B40402CF52C08E55B5140E48233F8FB3B404007CF8426895851406B9F8EC70C36404007CF842689585140
32794	22939	32.422265000000003	32.468626999999998	69.435854000000006	69.383370999999997	Колышкина	0103000020E610000001000000050000006B9F8EC70C36404007CF8426895851406B9F8EC70C3640402CF52C08E55B5140E48233F8FB3B40402CF52C08E55B5140E48233F8FB3B404007CF8426895851406B9F8EC70C36404007CF842689585140
32883	53416	32.789738999999997	32.835318999999998	69.333262000000005	69.316753000000006	Нагорная	0103000020E6100000010000000500000018B0E42A166540403CFA5FAE4554514018B0E42A16654040F9BF232A545551401C5DA5BBEB6A4040F9BF232A545551401C5DA5BBEB6A40403CFA5FAE4554514018B0E42A166540403CFA5FAE45545140
32734	53386	31.781172999999999	31.852409000000002	68.613217000000006	68.601177000000007	Дружбы	0103000020E61000000100000005000000A98427F4FAC73F40E08618AF79265140A98427F4FAC73F407B1684F23E275140EAD0E97937DA3F407B1684F23E275140EAD0E97937DA3F40E08618AF79265140A98427F4FAC73F40E08618AF79265140
32692	3071	31.296631000000001	31.337323999999999	67.500647999999998	67.490787999999995	Победы	0103000020E61000000100000005000000D3FA5B02F04B3F403B51121269DF5040D3FA5B02F04B3F40B3B3E89D0AE05040E9279CDD5A563F40B3B3E89D0AE05040E9279CDD5A563F403B51121269DF5040D3FA5B02F04B3F403B51121269DF5040
32713	2984	30.426029	30.534482000000001	67.583547999999993	67.541403000000003	Чехова	0103000020E61000000100000005000000C8258E3C106D3E4034BDC458A6E25040C8258E3C106D3E405BE9B5D958E55040F94CF6CFD3883E405BE9B5D958E55040F94CF6CFD3883E4034BDC458A6E25040C8258E3C106D3E4034BDC458A6E25040
32158	2984	30.426029	30.534482000000001	67.583547999999993	67.541403000000003	Комсомольская	0103000020E61000000100000005000000C8258E3C106D3E4034BDC458A6E25040C8258E3C106D3E405BE9B5D958E55040F94CF6CFD3883E405BE9B5D958E55040F94CF6CFD3883E4034BDC458A6E25040C8258E3C106D3E4034BDC458A6E25040
32159	2984	30.426029	30.534482000000001	67.583547999999993	67.541403000000003	Кирова	0103000020E61000000100000005000000C8258E3C106D3E4034BDC458A6E25040C8258E3C106D3E405BE9B5D958E55040F94CF6CFD3883E405BE9B5D958E55040F94CF6CFD3883E4034BDC458A6E25040C8258E3C106D3E4034BDC458A6E25040
32715	2984	30.426029	30.534482000000001	67.583547999999993	67.541403000000003	 Школьная	0103000020E61000000100000005000000C8258E3C106D3E4034BDC458A6E25040C8258E3C106D3E405BE9B5D958E55040F94CF6CFD3883E405BE9B5D958E55040F94CF6CFD3883E4034BDC458A6E25040C8258E3C106D3E4034BDC458A6E25040
32777	53398	32.352024999999998	32.470280000000002	67.197201000000007	67.128433999999999	Спекова	0103000020E61000000100000005000000EC2FBB270F2D4040726C3D4338C85040EC2FBB270F2D4040446FF1F09ECC504040FB9122323C4040446FF1F09ECC504040FB9122323C4040726C3D4338C85040EC2FBB270F2D4040726C3D4338C85040
32721	53383	29.033891000000001	33.324928	67.673147	66.344375999999997	Спекова	0103000020E61000000100000005000000F5A0A014AD083D40BF61A2410A965040F5A0A014AD083D40A29927D714EB504000C79E3D97A94040A29927D714EB504000C79E3D97A94040BF61A2410A965040F5A0A014AD083D40BF61A2410A965040
32817	53383	29.033891000000001	33.324928	67.673147	66.344375999999997	Первомайская	0103000020E61000000100000005000000F5A0A014AD083D40BF61A2410A965040F5A0A014AD083D40A29927D714EB504000C79E3D97A94040A29927D714EB504000C79E3D97A94040BF61A2410A965040F5A0A014AD083D40BF61A2410A965040
32882	53383	29.033891000000001	33.324928	67.673147	66.344375999999997	Комсомольская	0103000020E61000000100000005000000F5A0A014AD083D40BF61A2410A965040F5A0A014AD083D40A29927D714EB504000C79E3D97A94040A29927D714EB504000C79E3D97A94040BF61A2410A965040F5A0A014AD083D40BF61A2410A965040
32684	53372	32.350183999999999	32.406112999999998	66.867857999999998	66.840834999999998	Школьная	0103000020E610000001000000050000008ECA4DD4D22C404042959A3DD0B550408ECA4DD4D22C40409BE447FC8AB750407FBDC282FB3340409BE447FC8AB750407FBDC282FB33404042959A3DD0B550408ECA4DD4D22C404042959A3DD0B55040
32786	53372	32.350183999999999	32.406112999999998	66.867857999999998	66.840834999999998	Центральная	0103000020E610000001000000050000008ECA4DD4D22C404042959A3DD0B550408ECA4DD4D22C40409BE447FC8AB750407FBDC282FB3340409BE447FC8AB750407FBDC282FB33404042959A3DD0B550408ECA4DD4D22C404042959A3DD0B55040
32689	53374	31.416349	31.448077999999999	66.685592	66.676714000000004	Кумская	0103000020E61000000100000005000000E9B81AD9956A3F40B4AF3C484FAB5040E9B81AD9956A3F408D9944BDE0AB50409D0E643DB5723F408D9944BDE0AB50409D0E643DB5723F40B4AF3C484FAB5040E9B81AD9956A3F40B4AF3C484FAB5040
32694	53377	32.466453000000001	32.496996000000003	67.302785	67.294272000000007	 Букина	0103000020E61000000100000005000000800F5EBBB43B40403A083A5AD5D25040800F5EBBB43B40400A2E56D460D35040151F9F909D3F40400A2E56D460D35040151F9F909D3F40403A083A5AD5D25040800F5EBBB43B40403A083A5AD5D25040
32752	24107	32.697687999999999	32.718088999999999	67.107153999999994	67.099936	Молодежная	0103000020E61000000100000005000000E46723D74D5940405BECF65965C65040E46723D74D594040AD68739CDBC65040054F2157EA5B4040AD68739CDBC65040054F2157EA5B40405BECF65965C65040E46723D74D5940405BECF65965C65040
32736	24378	31.552227999999999	31.574003999999999	66.765928000000002	66.756788	Первомайская	0103000020E610000001000000050000007CEF6FD05E8D3F405680EF366FB050407CEF6FD05E8D3F40CEC5DFF604B15040EFC517EDF1923F40CEC5DFF604B15040EFC517EDF1923F405680EF366FB050407CEF6FD05E8D3F405680EF366FB05040
32799	53394	32.350183999999999	32.406112999999998	66.867857999999998	66.840834999999998	Энергетическая	0103000020E610000001000000050000008ECA4DD4D22C404042959A3DD0B550408ECA4DD4D22C40409BE447FC8AB750407FBDC282FB3340409BE447FC8AB750407FBDC282FB33404042959A3DD0B550408ECA4DD4D22C404042959A3DD0B55040
32762	53394	32.350183999999999	32.406112999999998	66.867857999999998	66.840834999999998	Озерная	0103000020E610000001000000050000008ECA4DD4D22C404042959A3DD0B550408ECA4DD4D22C40409BE447FC8AB750407FBDC282FB3340409BE447FC8AB750407FBDC282FB33404042959A3DD0B550408ECA4DD4D22C404042959A3DD0B55040
32789	53384	30.315930999999999	30.397390000000001	66.973568	66.956495000000004	Содружества	0103000020E61000000100000005000000E6CAA0DAE0503E4067F2CD3637BD5040E6CAA0DAE0503E40A81B28F04EBE5040E8C1DD59BB653E40A81B28F04EBE5040E8C1DD59BB653E4067F2CD3637BD5040E6CAA0DAE0503E4067F2CD3637BD5040
32832	53384	30.315930999999999	30.397390000000001	66.973568	66.956495000000004	Набережная	0103000020E61000000100000005000000E6CAA0DAE0503E4067F2CD3637BD5040E6CAA0DAE0503E40A81B28F04EBE5040E8C1DD59BB653E40A81B28F04EBE5040E8C1DD59BB653E4067F2CD3637BD5040E6CAA0DAE0503E4067F2CD3637BD5040
32187	31224	32.452188	32.514468000000001	67.469830999999999	67.362525000000005	Сивко	0103000020E6100000010000000500000063D2DF4BE1394040E0BE0E9C33D7504063D2DF4BE139404068E90AB611DE5040556B6116DA41404068E90AB611DE5040556B6116DA414040E0BE0E9C33D7504063D2DF4BE1394040E0BE0E9C33D75040
32705	31224	32.452188	32.514468000000001	67.469830999999999	67.362525000000005	Пушкина	0103000020E6100000010000000500000063D2DF4BE1394040E0BE0E9C33D7504063D2DF4BE139404068E90AB611DE5040556B6116DA41404068E90AB611DE5040556B6116DA414040E0BE0E9C33D7504063D2DF4BE1394040E0BE0E9C33D75040
32710	31224	32.452188	32.514468000000001	67.469830999999999	67.362525000000005	Партизан Заполярья	0103000020E6100000010000000500000063D2DF4BE1394040E0BE0E9C33D7504063D2DF4BE139404068E90AB611DE5040556B6116DA41404068E90AB611DE5040556B6116DA414040E0BE0E9C33D7504063D2DF4BE1394040E0BE0E9C33D75040
32149	31224	32.452188	32.514468000000001	67.469830999999999	67.362525000000005	Курчатова	0103000020E6100000010000000500000063D2DF4BE1394040E0BE0E9C33D7504063D2DF4BE139404068E90AB611DE5040556B6116DA41404068E90AB611DE5040556B6116DA414040E0BE0E9C33D7504063D2DF4BE1394040E0BE0E9C33D75040
32792	31224	32.452188	32.514468000000001	67.469830999999999	67.362525000000005	Белова	0103000020E6100000010000000500000063D2DF4BE1394040E0BE0E9C33D7504063D2DF4BE139404068E90AB611DE5040556B6116DA41404068E90AB611DE5040556B6116DA414040E0BE0E9C33D7504063D2DF4BE1394040E0BE0E9C33D75040
32749	31630	32.698065	32.717694000000002	67.432905000000005	67.428663	Советская	0103000020E61000000100000005000000BABDA4315A5940405680EF366FDB5040BABDA4315A59404098512CB7B4DB50408944A165DD5B404098512CB7B4DB50408944A165DD5B40405680EF366FDB5040BABDA4315A5940405680EF366FDB5040
67288	59022	30.074805000000001	30.091756	59.374037999999999	59.364226000000002	Большой пр.	0103000020E61000000100000005000000C993A46B26133E402C2D23F59EAE4D40C993A46B26133E400ABB287AE0AF4D4037363B527D173E400ABB287AE0AF4D4037363B527D173E402C2D23F59EAE4D40C993A46B26133E402C2D23F59EAE4D40
67507	59066	30.858639	30.867362	59.549567000000003	59.544804999999997	Чехова	0103000020E61000000100000005000000F511F8C3CFDB3E4040D9942BBCC54D40F511F8C3CFDB3E40FDFA213658C64D400CCB9F6F0BDE3E40FDFA213658C64D400CCB9F6F0BDE3E4040D9942BBCC54D40F511F8C3CFDB3E4040D9942BBCC54D40
67461	59066	30.853007000000002	30.854012999999998	59.550794000000003	59.548335000000002	Островского	0103000020E610000001000000050000005342B0AA5EDA3E4047205ED72FC64D405342B0AA5EDA3E40A16AF46A80C64D40DD5B9198A0DA3E40A16AF46A80C64D40DD5B9198A0DA3E4047205ED72FC64D405342B0AA5EDA3E4047205ED72FC64D40
67518	59066	30.808567	30.921341999999999	59.573673999999997	59.518796999999999	Октябрьская набережная 	0103000020E61000000100000005000000F59F353FFECE3E40A721AAF067C24D40F59F353FFECE3E4062484E266EC94D40656EBE11DDEB3E4062484E266EC94D40656EBE11DDEB3E40A721AAF067C24D40F59F353FFECE3E40A721AAF067C24D40
67560	59066	30.884312999999999	30.906006999999999	59.558892	59.543883999999998	Октябрьская 	0103000020E610000001000000050000007A6D365662E23E40A968ACFD9DC54D407A6D365662E23E407EFFE6C589C74D4073F22213F0E73E407EFFE6C589C74D4073F22213F0E73E40A968ACFD9DC54D407A6D365662E23E40A968ACFD9DC54D40
67494	59066	30.866230000000002	30.885068	59.543145000000003	59.534286000000002	Максима Горького	0103000020E6100000010000000500000068D0D03FC1DD3E40F75AD07B63C44D4068D0D03FC1DD3E4033FE7DC685C54D4073BC02D193E23E4033FE7DC685C54D4073BC02D193E23E40F75AD07B63C44D4068D0D03FC1DD3E40F75AD07B63C44D40
67607	59066	30.885068	30.890808	59.534286000000002	59.531210000000002	Гоголя	0103000020E6100000010000000500000073BC02D193E23E4072A774B0FEC34D4073BC02D193E23E40F75AD07B63C44D40E2033BFE0BE43E40F75AD07B63C44D40E2033BFE0BE43E4072A774B0FEC34D4073BC02D193E23E4072A774B0FEC34D40
67367	59047	33.490901000000001	33.503701999999997	59.621662999999998	59.620142999999999	Центролитовская	0103000020E610000001000000050000006F490ED8D5BE4040F2EB87D860CF4D406F490ED8D5BE40400E1137A792CF4D400377A04E79C040400E1137A792CF4D400377A04E79C04040F2EB87D860CF4D406F490ED8D5BE4040F2EB87D860CF4D40
67424	59047	33.510914999999997	33.584487000000003	59.646433000000002	59.641902999999999	Карла Маркса	0103000020E610000001000000050000009604A8A965C14040261AA4E029D24D409604A8A965C1404010070951BED24D40F5F75278D0CA404010070951BED24D40F5F75278D0CA4040261AA4E029D24D409604A8A965C14040261AA4E029D24D40
67473	59047	33.520626	33.531244000000001	59.650283999999999	59.643186	5 микрорайон	0103000020E6100000010000000500000041B96DDFA3C240405E9F39EB53D24D4041B96DDFA3C24040588E90813CD34D401E19ABCDFFC34040588E90813CD34D401E19ABCDFFC340405E9F39EB53D24D4041B96DDFA3C240405E9F39EB53D24D40
67483	59047	33.543407000000002	33.555121	59.650751999999997	59.643194999999999	1 микрорайон	0103000020E6100000010000000500000070B54E5C8EC54040B1F9B83654D24D4070B54E5C8EC540403EE76ED74BD34D40522976340EC740403EE76ED74BD34D40522976340EC74040B1F9B83654D24D4070B54E5C8EC54040B1F9B83654D24D40
67182	58989	32.489269999999998	32.601056	60.160046999999999	60.133983000000001	Кирова	0103000020E61000000100000005000000FB743C66A03E4040289CDD5A26114E40FB743C66A03E404055698B6B7C144E4044882B67EF4C404055698B6B7C144E4044882B67EF4C4040289CDD5A26114E40FB743C66A03E4040289CDD5A26114E40
1087	4047	29.067632	29.097241	59.912368000000001	59.902906999999999	проспект Героев	0103000020E61000000100000005000000BF29AC5450113D402C2AE27492F34D40BF29AC5450113D405EF58079C8F44D4091D442C9E4183D405EF58079C8F44D4091D442C9E4183D402C2AE27492F34D40BF29AC5450113D402C2AE27492F34D40
24369	4047	29.084008000000001	29.102505000000001	59.907964999999997	59.893808999999997	Солнечная	0103000020E61000000100000005000000359A5C8C81153D406BEF535568F24D40359A5C8C81153D40D174763238F44D402EAD86C43D1A3D40D174763238F44D402EAD86C43D1A3D406BEF535568F24D40359A5C8C81153D406BEF535568F24D40
66556	4047	29.077936000000001	29.102954	59.917834999999997	59.904572000000002	Молодежная	0103000020E610000001000000050000005A2E1B9DF3133D404C70EA03C9F34D405A2E1B9DF3133D40E40F069E7BF54D400DFE7E315B1A3D40E40F069E7BF54D400DFE7E315B1A3D404C70EA03C9F34D405A2E1B9DF3133D404C70EA03C9F34D40
67240	4047	29.088877	29.093944	59.910266	59.906227999999999	Малая Земля	0103000020E61000000100000005000000D95DA0A4C0163D40185C7347FFF34D40D95DA0A4C0163D409354A69883F44D40CAA7C7B60C183D409354A69883F44D40CAA7C7B60C183D40185C7347FFF34D40D95DA0A4C0163D40185C7347FFF34D40
1113	4047	29.063517999999998	29.074127000000001	59.907735000000002	59.905203999999998	Липовский проезд	0103000020E6100000010000000500000013B534B742103D40AC1A84B9DDF34D4013B534B742103D40A03715A930F44D4027C0B0FCF9123D40A03715A930F44D4027C0B0FCF9123D40AC1A84B9DDF34D4013B534B742103D40AC1A84B9DDF34D40
67156	4047	29.053259000000001	29.097097000000002	59.914907999999997	59.883457999999997	Ленинградская	0103000020E61000000100000005000000B937BF61A20D3D40DDB1D82615F14D40B937BF61A20D3D40A46C91B41BF54D402B8A5759DB183D40A46C91B41BF54D402B8A5759DB183D40DDB1D82615F14D40B937BF61A20D3D40DDB1D82615F14D40
66995	4047	29.07657	29.097446999999999	59.908785999999999	59.894694000000001	Космонавтов	0103000020E61000000100000005000000CFDA6D179A133D40B6F63E5585F24D40CFDA6D179A133D400588821953F44D40E3175E49F2183D400588821953F44D40E3175E49F2183D40B6F63E5585F24D40CFDA6D179A133D40B6F63E5585F24D40
66380	4047	29.087916	29.101391	59.900277000000003	59.886938999999998	Комсомольская	0103000020E610000001000000050000008ECBB8A981163D400246973787F14D408ECBB8A981163D40A62BD8463CF34D40D61BB5C2F4193D40A62BD8463CF34D40D61BB5C2F4193D400246973787F14D408ECBB8A981163D400246973787F14D40
67274	4047	29.067632	29.097241	59.912368000000001	59.902906999999999	 пр.Героев	0103000020E61000000100000005000000BF29AC5450113D402C2AE27492F34D40BF29AC5450113D405EF58079C8F44D4091D442C9E4183D405EF58079C8F44D4091D442C9E4183D402C2AE27492F34D40BF29AC5450113D402C2AE27492F34D40
67591	59004	28.169415999999998	28.171472999999999	59.089700000000001	59.089213999999998	площадь Ленина	0103000020E610000001000000050000004C6BD3D85E2B3C40342C465D6B8B4D404C6BD3D85E2B3C40C139234A7B8B4D40A2258FA7E52B3C40C139234A7B8B4D40A2258FA7E52B3C40342C465D6B8B4D404C6BD3D85E2B3C40342C465D6B8B4D40
67464	59004	28.089286000000001	28.098573999999999	59.120722999999998	59.111319000000002	Шахтёрской Славы	0103000020E610000001000000050000009CFD8172DB163C40333674B33F8E4D409CFD8172DB163C400070ECD9738F4D40643C4A253C193C400070ECD9738F4D40643C4A253C193C40333674B33F8E4D409CFD8172DB163C40333674B33F8E4D40
67490	59004	28.083016000000001	28.096965999999998	59.114894	59.113517999999999	Максима Горького	0103000020E61000000100000005000000740B5D8940153C40F0C000C2878E4D40740B5D8940153C40D940BAD8B48E4D40EDD286C3D2183C40D940BAD8B48E4D40EDD286C3D2183C40F0C000C2878E4D40740B5D8940153C40F0C000C2878E4D40
67554	59004	28.120304999999998	28.192447999999999	59.103819999999999	59.085436999999999	Ломоносова	0103000020E61000000100000005000000978BF84ECC1E3C40266F8099EF8A4D40978BF84ECC1E3C40DA5548F9498D4D403C2EAA4544313C40DA5548F9498D4D403C2EAA4544313C40266F8099EF8A4D40978BF84ECC1E3C40266F8099EF8A4D40
67612	59004	28.075514999999999	28.107171000000001	59.118335000000002	59.117364999999999	Ленина	0103000020E61000000100000005000000815B77F354133C40F758FAD0058F4D40815B77F354133C40707CED99258F4D406214048F6F1B3C40707CED99258F4D406214048F6F1B3C40F758FAD0058F4D40815B77F354133C40F758FAD0058F4D40
67431	59004	28.064043000000002	28.075541999999999	59.117874	59.081110000000002	Комсомольское шоссе	0103000020E61000000100000005000000A9893E1F65103C4075B0FECF618A4D40A9893E1F65103C403C86C77E168F4D40747973B856133C403C86C77E168F4D40747973B856133C4075B0FECF618A4D40A9893E1F65103C4075B0FECF618A4D40
67617	59004	28.163630000000001	28.169694	59.094914000000003	59.089556999999999	Декабристов	0103000020E61000000100000005000000FDA4DAA7E3293C405E10919A768B4D40FDA4DAA7E3293C405EF75624268C4D40D253E410712B3C405EF75624268C4D40D253E410712B3C405E10919A768B4D40FDA4DAA7E3293C405E10919A768B4D40
67541	59004	28.082782000000002	28.096616000000001	59.121892000000003	59.121827000000003	Грибоедова	0103000020E610000001000000050000008EB27E3331153C408962F206988F4D408EB27E3331153C4070D234289A8F4D40354580D3BB183C4070D234289A8F4D40354580D3BB183C408962F206988F4D408EB27E3331153C408962F206988F4D40
67465	59068	30.209211	30.225956	60.145944999999998	60.140537999999999	Молодцова	0103000020E61000000100000005000000A5F622DA8E353E4031EC3026FD114E40A5F622DA8E353E40E2016553AE124E40C1559E40D8393E40E2016553AE124E40C1559E40D8393E4031EC3026FD114E40A5F622DA8E353E4031EC3026FD114E40
67427	59015	30.126818	30.139213999999999	61.043011	61.029290000000003	Чапаева	0103000020E610000001000000050000004C8BFA2477203E40C80C54C6BF834E404C8BFA2477203E40232F6B6281854E4035255987A3233E40232F6B6281854E4035255987A3233E40C80C54C6BF834E404C8BFA2477203E40C80C54C6BF834E40
67501	59015	30.108339000000001	30.153919999999999	61.044103999999997	61.035147000000002	Ленина	0103000020E61000000100000005000000A0E1CD1ABC1B3E40B9C667B27F844E40A0E1CD1ABC1B3E40B7CF2A33A5854E404833164D67273E40B7CF2A33A5854E404833164D67273E40B9C667B27F844E40A0E1CD1ABC1B3E40B9C667B27F844E40
67272	59015	30.113406000000001	30.116191000000001	61.038418999999998	61.034319000000004	Исполкомская	0103000020E61000000100000005000000912BF52C081D3E40D350A39064844E40912BF52C081D3E40C345EEE9EA844E40EC1681B1BE1D3E40C345EEE9EA844E40EC1681B1BE1D3E40D350A39064844E40912BF52C081D3E40D350A39064844E40
67479	59015	30.122928000000002	30.127984999999999	61.042378999999997	61.034610999999998	Гастелло	0103000020E6100000010000000500000040C39B35781F3E407A8A1C226E844E4040C39B35781F3E40C284D1AC6C854E40E960FD9FC3203E40C284D1AC6C854E40E960FD9FC3203E407A8A1C226E844E4040C39B35781F3E407A8A1C226E844E40
67517	59057	34.177087999999998	34.17848	60.912329	60.903832999999999	Исакова	0103000020E61000000100000005000000CC41D0D1AA164140D505BCCCB0734E40CC41D0D1AA164140A0185932C7744E40BB7EC16ED8164140A0185932C7744E40BB7EC16ED8164140D505BCCCB0734E40CC41D0D1AA164140D505BCCCB0734E40
67476	59057	34.144568999999997	34.147551	60.921053999999998	60.913080999999998	Волкова	0103000020E61000000100000005000000F981AB3C81124140ABCC94D6DF744E40F981AB3C81124140CCECF318E5754E40FDBE7FF3E2124140CCECF318E5754E40FDBE7FF3E2124140ABCC94D6DF744E40F981AB3C81124140ABCC94D6DF744E40
67398	59057	34.145350000000001	34.157567	60.921897999999999	60.918596000000001	 Горького	0103000020E610000001000000050000009F3C2CD49A124140431EC18D94754E409F3C2CD49A124140B81FF0C000764E40E4F6CB272B144140B81FF0C000764E40E4F6CB272B144140431EC18D94754E409F3C2CD49A124140431EC18D94754E40
67381	59051	30.800930999999999	30.822644	59.788972999999999	59.778452000000001	1-й Советский проспект	0103000020E61000000100000005000000425A63D009CD3E40BEC0AC50A4E34D40425A63D009CD3E40A8363811FDE44D40294014CC98D23E40A8363811FDE44D40294014CC98D23E40BEC0AC50A4E34D40425A63D009CD3E40BEC0AC50A4E34D40
67368	59048	30.778914	30.784967999999999	59.695984000000003	59.695875000000001	Октябрьская	0103000020E6100000010000000500000084656CE866C73E40508D976E12D94D4084656CE866C73E400745F30016D94D401268B0A9F3C83E400745F30016D94D401268B0A9F3C83E40508D976E12D94D4084656CE866C73E40508D976E12D94D40
67321	58933	29.841612000000001	29.858518	58.751531999999997	58.717987000000001	проспект Кирова	0103000020E61000000100000005000000D1EB4FE273D73D4001FA7DFFE65B4D40D1EB4FE273D73D40E0F2583332604D40FF06EDD5C7DB3D40E0F2583332604D40FF06EDD5C7DB3D4001FA7DFFE65B4D40D1EB4FE273D73D4001FA7DFFE65B4D40
67350	58933	29.839760999999999	29.850514	58.735608999999997	58.710925000000003	проспект Володарского	0103000020E61000000100000005000000CD74AF93FAD63D4054742497FF5A4D40CD74AF93FAD63D4056D28A6F285E4D4047CA1649BBD93D4056D28A6F285E4D4047CA1649BBD93D4054742497FF5A4D40CD74AF93FAD63D4054742497FF5A4D40
67322	58933	29.845627	29.852354999999999	58.735374999999998	58.718594000000003	Красной Артиллерии	0103000020E61000000100000005000000569DD5027BD83D40098D60E3FA5B4D40569DD5027BD83D40E3A59BC4205E4D400395F1EF33DA3D40E3A59BC4205E4D400395F1EF33DA3D40098D60E3FA5B4D40569DD5027BD83D40098D60E3FA5B4D40
67458	58933	29.853344	29.877634	58.737126000000004	58.731704000000001	Комсомольский проспект	0103000020E61000000100000005000000E23C9CC074DA3D401B2D077AA85D4D40E23C9CC074DA3D4002840F255A5E4D4090DB2F9FACE03D4002840F255A5E4D4090DB2F9FACE03D401B2D077AA85D4D40E23C9CC074DA3D401B2D077AA85D4D40
67470	359	33.556539999999998	33.557851999999997	60.726998000000002	60.717990999999998	Свердлова	0103000020E610000001000000050000003A75E5B33CC7404042E90B21E75B4E403A75E5B33CC74040F3203D450E5D4E400C01C0B167C74040F3203D450E5D4E400C01C0B167C7404042E90B21E75B4E403A75E5B33CC7404042E90B21E75B4E40
267	359	33.538386000000003	33.579618000000004	60.725088999999997	60.723857000000002	Октябрьский проспект	0103000020E61000000100000005000000E84F1BD5E9C4404087FD9E58A75C4E40E84F1BD5E9C440403CD862B7CF5C4E40231631EC30CA40403CD862B7CF5C4E40231631EC30CA404087FD9E58A75C4E40E84F1BD5E9C4404087FD9E58A75C4E40
102	359	33.508723000000003	33.567337999999999	60.734797999999998	60.733213999999997	Ленина проспект	0103000020E610000001000000050000008CDCD3D51DC14040137CD3F4D95D4E408CDCD3D51DC14040469561DC0D5E4E4097E315889EC84040469561DC0D5E4E4097E315889EC84040137CD3F4D95D4E408CDCD3D51DC14040137CD3F4D95D4E40
66994	359	33.542931000000003	33.543596000000001	60.741970999999999	60.729308000000003	Гагарина	0103000020E61000000100000005000000077E54C37EC54040085BECF6595D4E40077E54C37EC540404BCADDE7F85E4E40431EC18D94C540404BCADDE7F85E4E40431EC18D94C54040085BECF6595D4E40077E54C37EC54040085BECF6595D4E40
67564	59067	30.987736000000002	30.999880999999998	59.886522999999997	59.883851	бульвар Партизанской Славы	0103000020E61000000100000005000000F5143944DCFC3E40B9C4910722F14D40F5143944DCFC3E406E13EE9579F14D404BE48233F8FF3E406E13EE9579F14D404BE48233F8FF3E40B9C4910722F14D40F5143944DCFC3E40B9C4910722F14D40
67457	59067	30.989811	31.001291999999999	59.889606999999998	59.885494000000001	Молодёжная	0103000020E610000001000000050000009738F24064FD3E40F1660DDE57F14D409738F24064FD3E4076A565A4DEF14D4016BF29AC54003F4076A565A4DEF14D4016BF29AC54003F40F1660DDE57F14D409738F24064FD3E40F1660DDE57F14D40
67386	59052	32.017294999999997	32.053434000000003	59.457794	59.440564000000002	проспект Победы	0103000020E6100000010000000500000031B1F9B836024040C1E5B16664B84D4031B1F9B8360240400B2769FE98BA4D404B3FE1ECD60640400B2769FE98BA4D404B3FE1ECD6064040C1E5B16664B84D4031B1F9B836024040C1E5B16664B84D40
67485	59052	32.018318999999998	32.035226000000002	59.452590000000001	59.437393	Строителей	0103000020E610000001000000050000009DF2E84658024040EA3F6B7EFCB74D409DF2E84658024040923F1878EEB94D4005FC1A4982044040923F1878EEB94D4005FC1A4982044040EA3F6B7EFCB74D409DF2E84658024040EA3F6B7EFCB74D40
67553	59052	32.018571000000001	32.023961	59.455938000000003	59.450678000000003	Пионерская	0103000020E61000000100000005000000B7D3D688600240406B8313D1AFB94D40B7D3D688600240407880272D5CBA4D4092B06F27110340407880272D5CBA4D4092B06F27110340406B8313D1AFB94D40B7D3D688600240406B8313D1AFB94D40
67539	59052	32.004800000000003	32.014761999999997	59.453792999999997	59.441299999999998	Молодёжный бульвар	0103000020E61000000100000005000000AA8251499D004040C6DCB5847CB84D40AA8251499D004040AD1397E315BA4D409D9CA1B8E3014040AD1397E315BA4D409D9CA1B8E3014040C6DCB5847CB84D40AA8251499D004040C6DCB5847CB84D40
67632	59052	32.004800000000003	32.014761999999997	59.453792999999997	59.441299999999998	Молодежный бульвар	0103000020E61000000100000005000000AA8251499D004040C6DCB5847CB84D40AA8251499D004040AD1397E315BA4D409D9CA1B8E3014040AD1397E315BA4D409D9CA1B8E3014040C6DCB5847CB84D40AA8251499D004040C6DCB5847CB84D40
67292	59024	29.098866000000001	29.150798000000002	60.968769999999999	60.942793000000002	Ленинградское шоссе	0103000020E61000000100000005000000B4AF3C484F193D40E9F2E670AD784E40B4AF3C484F193D4047ACC5A7007C4E405E4D9EB29A263D4047ACC5A7007C4E405E4D9EB29A263D40E9F2E670AD784E40B4AF3C484F193D40E9F2E670AD784E40
67516	59071	28.203758000000001	28.207647999999999	59.360171999999999	59.357599	Льнопрядильная	0103000020E61000000100000005000000624CFA7B29343C40890AD5CDC5AD4D40624CFA7B29343C40AB77B81D1AAE4D406E14596B28353C40AB77B81D1AAE4D406E14596B28353C40890AD5CDC5AD4D40624CFA7B29343C40890AD5CDC5AD4D40
67596	59064	30.132773	30.151575000000001	59.586368	59.555691000000003	Чехова	0103000020E61000000100000005000000B4CA4C69FD213E403DD7F7E120C74D40B4CA4C69FD213E40E1B54B1B0ECB4D4026E4839ECD263E40E1B54B1B0ECB4D4026E4839ECD263E403DD7F7E120C74D40B4CA4C69FD213E403DD7F7E120C74D40
67486	59064	30.083950000000002	30.097819999999999	59.559027999999998	59.555754999999998	Слепнева	0103000020E61000000100000005000000CC7F48BF7D153E4053CBD6FA22C74D40CC7F48BF7D153E402EC6C03A8EC74D400CE544BB0A193E402EC6C03A8EC74D400CE544BB0A193E4053CBD6FA22C74D40CC7F48BF7D153E4053CBD6FA22C74D40
67551	59064	30.124804999999999	30.131398999999998	59.574294000000002	59.568514999999998	Киргетова	0103000020E6100000010000000500000095607138F31F3E4089247A19C5C84D4095607138F31F3E40FF243E7782C94D4023BA675DA3213E40FF243E7782C94D4023BA675DA3213E4089247A19C5C84D4095607138F31F3E4089247A19C5C84D40
67463	59064	30.125443000000001	30.133258999999999	59.573419000000001	59.555691000000003	Карла Маркса	0103000020E610000001000000050000001B834E081D203E403DD7F7E120C74D401B834E081D203E40D8F335CB65C94D40CDE506431D223E40D8F335CB65C94D40CDE506431D223E403DD7F7E120C74D401B834E081D203E403DD7F7E120C74D40
67445	59064	30.088415000000001	30.106138000000001	59.563637999999997	59.554555999999998	Генерала Кныша	0103000020E61000000100000005000000D1798D5DA2163E4079E6E5B0FBC64D40D1798D5DA2163E4034643C4A25C84D40E4DC26DC2B1B3E4034643C4A25C84D40E4DC26DC2B1B3E4079E6E5B0FBC64D40D1798D5DA2163E4079E6E5B0FBC64D40
67547	59064	30.129638	30.138801000000001	59.570757	59.558686999999999	Володарского	0103000020E61000000100000005000000A051BAF42F213E40A5D93C0E83C74D40A051BAF42F213E40467BBC900EC94D40F0A65B7688233E40467BBC900EC94D40F0A65B7688233E40A5D93C0E83C74D40A051BAF42F213E40A5D93C0E83C74D40
67454	58966	28.229037000000002	29.283695000000002	60.967241999999999	60.450432999999997	пл. Школьная	0103000020E61000000100000005000000EF92382BA23A3C400305DEC9A7394E40EF92382BA23A3C40A8A8FA95CE7B4E40EA094B3CA0483D40A8A8FA95CE7B4E40EA094B3CA0483D400305DEC9A7394E40EF92382BA23A3C400305DEC9A7394E40
67404	58966	28.229037000000002	29.283695000000002	60.967241999999999	60.450432999999997	Школьная площадь	0103000020E61000000100000005000000EF92382BA23A3C400305DEC9A7394E40EF92382BA23A3C40A8A8FA95CE7B4E40EA094B3CA0483D40A8A8FA95CE7B4E40EA094B3CA0483D400305DEC9A7394E40EF92382BA23A3C400305DEC9A7394E40
67469	58966	28.767837	28.771691000000001	60.705036999999997	60.701695000000001	Сухова	0103000020E61000000100000005000000A4A833F790C43C4024624A24D1594E40A4A833F790C43C4027BC04A73E5A4E40179E978A8DC53C4027BC04A73E5A4E40179E978A8DC53C4024624A24D1594E40A4A833F790C43C4024624A24D1594E40
67107	58966	28.579470000000001	28.913733000000001	60.811289000000002	60.653542000000002	Суворова	0103000020E610000001000000050000005C035B2558943C40FE47A643A7534E405C035B2558943C40624D6551D8674E40A646E867EAE93C40624D6551D8674E40A646E867EAE93C40FE47A643A7534E405C035B2558943C40FE47A643A7534E40
67602	58966	28.762546	28.768232999999999	60.698141999999997	60.696697	Спортивная	0103000020E6100000010000000500000014B2F33636C33C40541C075E2D594E4014B2F33636C33C4065FB90B75C594E403DB5FAEAAAC43C4065FB90B75C594E403DB5FAEAAAC43C40541C075E2D594E4014B2F33636C33C40541C075E2D594E40
67511	58966	28.740276999999999	28.745432999999998	60.710481999999999	60.706462999999999	Советская	0103000020E6100000010000000500000022FB20CB82BD3C40C26A2C616D5A4E4022FB20CB82BD3C40C632FD12F15A4E40F25B74B2D4BE3C40C632FD12F15A4E40F25B74B2D4BE3C40C26A2C616D5A4E4022FB20CB82BD3C40C26A2C616D5A4E40
67521	58966	28.768384999999999	28.773973000000002	60.699379	60.691645999999999	Рубежная	0103000020E61000000100000005000000A9BC1DE1B4C43C4061342BDB87584E40A9BC1DE1B4C43C402D41464085594E40ADFC321823C63C402D41464085594E40ADFC321823C63C4061342BDB87584E40A9BC1DE1B4C43C4061342BDB87584E40
67378	58966	28.74193	28.745540999999999	60.708264	60.705846999999999	Пушкина	0103000020E61000000100000005000000D9EBDD1FEFBD3C40677DCA31595A4E40D9EBDD1FEFBD3C4092770E65A85A4E40BFD364C6DBBE3C4092770E65A85A4E40BFD364C6DBBE3C40677DCA31595A4E40D9EBDD1FEFBD3C40677DCA31595A4E40
67114	58966	28.579470000000001	28.913733000000001	60.811289000000002	60.653542000000002	Промышленная	0103000020E610000001000000050000005C035B2558943C40FE47A643A7534E405C035B2558943C40624D6551D8674E40A646E867EAE93C40624D6551D8674E40A646E867EAE93C40FE47A643A7534E405C035B2558943C40FE47A643A7534E40
67545	58966	28.755288	28.762771000000001	60.717388	60.714734	Офицерская	0103000020E61000000100000005000000AE0FEB8D5AC13C406DAB59677C5B4E40AE0FEB8D5AC13C407C45B75ED35B4E405456D3F544C33C407C45B75ED35B4E405456D3F544C33C406DAB59677C5B4E40AE0FEB8D5AC13C406DAB59677C5B4E40
67583	58966	28.751183000000001	28.811243999999999	60.711067999999997	60.687658999999996	Ленинградское шоссе	0103000020E61000000100000005000000A94F72874DC03C4068E6C93505584E40A94F72874DC03C40B69DB646045B4E408313D1AFADCF3C40B69DB646045B4E408313D1AFADCF3C4068E6C93505584E40A94F72874DC03C4068E6C93505584E40
67422	58966	28.755296999999999	28.761396000000001	60.719940999999999	60.716093999999998	Горная	0103000020E6100000010000000500000054C4E9245BC13C40506EDBF7A85B4E4054C4E9245BC13C405706D506275C4E40234E27D9EAC23C405706D506275C4E40234E27D9EAC23C40506EDBF7A85B4E4054C4E9245BC13C40506EDBF7A85B4E40
67562	58966	28.729766999999999	28.744813000000001	60.712406000000001	60.706617000000001	Выборгская	0103000020E6100000010000000500000035B39602D2BA3C4019E6046D725A4E4035B39602D2BA3C40B2BCAB1E305B4E40BAA29410ACBE3C40B2BCAB1E305B4E40BAA29410ACBE3C4019E6046D725A4E4035B39602D2BA3C4019E6046D725A4E40
67421	58966	28.786154	28.789981000000001	60.691887999999999	60.691676999999999	Аристарха Макарова	0103000020E610000001000000050000009D9E776341C93C409C3237DF88584E409D9E776341C93C40573F36C98F584E401D76DF313CCA3C40573F36C98F584E401D76DF313CCA3C409C3237DF88584E409D9E776341C93C409C3237DF88584E40
67523	59050	30.616346	30.641058000000001	60.026766000000002	60.023919999999997	Межевая	0103000020E610000001000000050000003A05F9D9C89D3E4033DC80CF0F034E403A05F9D9C89D3E4087527B116D034E40D4D688601CA43E4087527B116D034E40D4D688601CA43E4033DC80CF0F034E403A05F9D9C89D3E4033DC80CF0F034E40
67438	59050	30.622893999999999	30.640357999999999	60.028869	60.024419000000002	Ленинградская	0103000020E61000000100000005000000E7DF2EFB759F3E4055336B2920034E40E7DF2EFB759F3E40226FB9FAB1034E4062BB7B80EEA33E40226FB9FAB1034E4062BB7B80EEA33E4055336B2920034E40E7DF2EFB759F3E4055336B2920034E40
67575	59050	30.624645999999998	30.666301000000001	60.043655000000001	59.987506000000003	Колтушское шоссе	0103000020E61000000100000005000000C493DDCCE89F3E40494DBB9866FE4D40C493DDCCE89F3E4048A7AE7C96054E40C74ACCB392AA3E4048A7AE7C96054E40C74ACCB392AA3E40494DBB9866FE4D40C493DDCCE89F3E40494DBB9866FE4D40
67379	59050	30.611450000000001	30.643583	60.021546000000001	60.009723000000001	Бибиковская	0103000020E61000000100000005000000A323B9FC879C3E406F826F9A3E014E40A323B9FC879C3E4008AEF204C2024E40F64201DBC1A43E4008AEF204C2024E40F64201DBC1A43E406F826F9A3E014E40A323B9FC879C3E406F826F9A3E014E40
67574	59075	32.297874999999998	32.340347000000001	59.931305000000002	59.92662	проспект Державина	0103000020E61000000100000005000000E3A59BC420264040E6E8F17B9BF64D40E3A59BC420264040F7CC920035F74D405725917D902B4040F7CC920035F74D405725917D902B4040E6E8F17B9BF64D40E3A59BC420264040E6E8F17B9BF64D40
67616	59075	32.347884000000001	32.366047999999999	59.896101999999999	59.895465999999999	Ломоносова	0103000020E610000001000000050000009D668176872C4040085740A19EF24D409D668176872C4040AAF06778B3F24D4013622EA9DA2E4040AAF06778B3F24D4013622EA9DA2E4040085740A19EF24D409D668176872C4040085740A19EF24D40
67452	59062	33.837318000000003	33.855831999999999	59.471578999999998	59.470089000000002	Социалистическая	0103000020E61000000100000005000000132D793C2DEB4040CC9A58E02BBC4D40132D793C2DEB40407D3D5FB35CBC4D40656F29E78BED40407D3D5FB35CBC4D40656F29E78BED4040CC9A58E02BBC4D40132D793C2DEB4040CC9A58E02BBC4D40
67606	59062	33.839787999999999	33.866819	59.478470999999999	59.476492	Павлова	0103000020E6100000010000000500000060C9552C7EEB40401F679AB0FDBC4D4060C9552C7EEB4040CE8AA8893EBD4D409546CCECF3EE4040CE8AA8893EBD4D409546CCECF3EE40401F679AB0FDBC4D4060C9552C7EEB40401F679AB0FDBC4D40
67436	59062	33.845654000000003	33.855617000000002	59.484915000000001	59.471186000000003	Косомольская	0103000020E61000000100000005000000A5DDE8633EEC4040A22AA6D24FBC4D40A5DDE8633EEC4040802BD9B111BE4D4069739CDB84ED4040802BD9B111BE4D4069739CDB84ED4040A22AA6D24FBC4D40A5DDE8633EEC4040A22AA6D24FBC4D40
67333	3512	30.760292	30.763480999999999	59.642798999999997	59.640310999999997	Колпинская	0103000020E6100000010000000500000012691B7FA2C23E407022FAB5F5D14D4012691B7FA2C23E406473D53C47D24D400C1EA67D73C33E406473D53C47D24D400C1EA67D73C33E407022FAB5F5D14D4012691B7FA2C23E407022FAB5F5D14D40
67230	14227	31.111927999999999	31.140080999999999	59.424577999999997	59.407578000000001	Мысленская	0103000020E61000000100000005000000B6813B50A71C3F40D84812842BB44D40B6813B50A71C3F40F04C689258B64D407DCA3159DC233F40F04C689258B64D407DCA3159DC233F40D84812842BB44D40B6813B50A71C3F40D84812842BB44D40
67195	14945	31.160805	31.217093999999999	59.610526	59.585976000000002	Нины Куковеровой	0103000020E61000000100000005000000850838842A293F40D61EF64201CB4D40850838842A293F40C9AD49B725CE4D406728EE7893373F40C9AD49B725CE4D406728EE7893373F40D61EF64201CB4D40850838842A293F40D61EF64201CB4D40
24392	10993	31.409306000000001	31.426078	59.353732000000001	59.349319000000001	Новая	0103000020E610000001000000050000007C0E2C47C8683F408B6F287CB6AC4D407C0E2C47C8683F403BC6151747AD4D408B8BA372136D3F403BC6151747AD4D408B8BA372136D3F408B6F287CB6AC4D407C0E2C47C8683F408B6F287CB6AC4D40
67336	11076	30.528409	30.532506000000001	59.667085	59.654626	Шоссейная	0103000020E610000001000000050000007DE9EDCF45873E403F8EE6C8CAD34D407DE9EDCF45873E407A53910A63D54D407DEC2E5052883E407A53910A63D54D407DEC2E5052883E403F8EE6C8CAD34D407DE9EDCF45873E403F8EE6C8CAD34D40
67175	50500	30.535488000000001	30.560821000000001	59.582290999999998	59.556410999999997	Павловское шоссе	0103000020E610000001000000050000008466D7BD15893E403C11C47938C74D408466D7BD15893E40A8E0F08288CA4D40F7E80DF7918F3E40A8E0F08288CA4D40F7E80DF7918F3E403C11C47938C74D408466D7BD15893E403C11C47938C74D40
66285	13892	30.880962	30.924323999999999	59.522485000000003	59.509611999999997	пр.Кирова	0103000020E61000000100000005000000CD04C3B986E13E4017D34CF73AC14D40CD04C3B986E13E4046D3D9C9E0C24D406CE8667FA0EC3E4046D3D9C9E0C24D406CE8667FA0EC3E4017D34CF73AC14D40CD04C3B986E13E4017D34CF73AC14D40
67341	59038	30.758127000000002	30.790951	59.659680999999999	59.635967999999998	Советский проспект	0103000020E61000000100000005000000F0366F9C14C23E40B9A6406667D14D40F0366F9C14C23E407365506D70D44D400EBDC5C37BCA3E407365506D70D44D400EBDC5C37BCA3E40B9A6406667D14D40F0366F9C14C23E40B9A6406667D14D40
67113	58965	30.761136	30.790951	59.646341999999997	59.633425000000003	Володарский проспект	0103000020E61000000100000005000000EACE13CFD9C23E4002BC051214D14D40EACE13CFD9C23E40FF03AC55BBD24D400EBDC5C37BCA3E40FF03AC55BBD24D400EBDC5C37BCA3E4002BC051214D14D40EACE13CFD9C23E4002BC051214D14D40
67314	58965	30.744499000000001	30.753958000000001	59.642954000000003	59.636318000000003	2-я Футбольная улица	0103000020E610000001000000050000009BE7887C97BE3E4096ED43DE72D14D409BE7887C97BE3E408C6A11514CD24D40BD8E386403C13E408C6A11514CD24D40BD8E386403C13E4096ED43DE72D14D409BE7887C97BE3E4096ED43DE72D14D40
66443	10898	31.387073000000001	31.400431000000001	59.270769999999999	59.258932000000001	Мира	0103000020E61000000100000005000000242A543717633F40A6F10BAF24A14D40242A543717633F40745E6397A8A24D40F94D61A582663F40745E6397A8A24D40F94D61A582663F40A6F10BAF24A14D40242A543717633F40A6F10BAF24A14D40
3767	13080	30.866230000000002	30.885068	59.543145000000003	59.534286000000002	улица Максима Горького	0103000020E6100000010000000500000068D0D03FC1DD3E40F75AD07B63C44D4068D0D03FC1DD3E4033FE7DC685C54D4073BC02D193E23E4033FE7DC685C54D4073BC02D193E23E40F75AD07B63C44D4068D0D03FC1DD3E40F75AD07B63C44D40
3710	13080	30.861360999999999	30.906807000000001	59.549626000000004	59.524903999999999	проспект Ленина	0103000020E61000000100000005000000C30C8D2782DC3E4011C5E40D30C34D40C30C8D2782DC3E4002840F255AC64D40ACC8E88024E83E4002840F255AC64D40ACC8E88024E83E4011C5E40D30C34D40C30C8D2782DC3E4011C5E40D30C34D40
67598	13080	30.864469	30.883037000000002	59.543191	59.534491000000003	Советская	0103000020E61000000100000005000000E46723D74DDD3E40D0807A336AC44D40E46723D74DDD3E40A33D5E4887C54D4070287CB60EE23E40A33D5E4887C54D4070287CB60EE23E40D0807A336AC44D40E46723D74DDD3E40D0807A336AC44D40
3905	13080	30.897957999999999	30.90607	59.549261000000001	59.542893999999997	Пушкинская набережная	0103000020E610000001000000050000007B2E5393E0E53E40E998F38C7DC54D407B2E5393E0E53E40F0FB372F4EC64D4000E31934F4E73E40F0FB372F4EC64D4000E31934F4E73E40E998F38C7DC54D407B2E5393E0E53E40E998F38C7DC54D40
3692	13080	30.803149999999999	30.861360999999999	59.581657	59.549626000000004	Московское шоссе	0103000020E610000001000000050000004BC8073D9BCD3E4002840F255AC64D404BC8073D9BCD3E40A73E90BC73CA4D40C30C8D2782DC3E40A73E90BC73CA4D40C30C8D2782DC3E4002840F255AC64D404BC8073D9BCD3E4002840F255AC64D40
65892	11123	30.599287	30.640411	59.730978	59.706785000000004	Октябрьская	0103000020E61000000100000005000000FFEA71DF6A993E40D5264EEE77DA4D40FFEA71DF6A993E40390CE6AF90DD4D40A8FFACF9F1A33E40390CE6AF90DD4D40A8FFACF9F1A33E40D5264EEE77DA4D40FFEA71DF6A993E40D5264EEE77DA4D40
66555	11123	30.599287	30.640411	59.730978	59.706785000000004	Ленинградская	0103000020E61000000100000005000000FFEA71DF6A993E40D5264EEE77DA4D40FFEA71DF6A993E40390CE6AF90DD4D40A8FFACF9F1A33E40390CE6AF90DD4D40A8FFACF9F1A33E40D5264EEE77DA4D40FFEA71DF6A993E40D5264EEE77DA4D40
67123	11123	30.599287	30.640411	59.730978	59.706785000000004	Красноборская	0103000020E61000000100000005000000FFEA71DF6A993E40D5264EEE77DA4D40FFEA71DF6A993E40390CE6AF90DD4D40A8FFACF9F1A33E40390CE6AF90DD4D40A8FFACF9F1A33E40D5264EEE77DA4D40FFEA71DF6A993E40D5264EEE77DA4D40
67128	58970	31.111927999999999	31.140080999999999	59.424577999999997	59.407578000000001	Рычина	0103000020E61000000100000005000000B6813B50A71C3F40D84812842BB44D40B6813B50A71C3F40F04C689258B64D407DCA3159DC233F40F04C689258B64D407DCA3159DC233F40D84812842BB44D40B6813B50A71C3F40D84812842BB44D40
67164	14182	30.867038000000001	30.888445000000001	59.153799999999997	59.144506	Комсомольская	0103000020E61000000100000005000000A663CE33F6DD3E40B309302C7F924D40A663CE33F6DD3E40F90FE9B7AF934D40734BAB2171E33E40F90FE9B7AF934D40734BAB2171E33E40B309302C7F924D40A663CE33F6DD3E40B309302C7F924D40
24371	14797	31.304078000000001	31.325206000000001	59.311678999999998	59.301274999999997	Московское шоссе	0103000020E61000000100000005000000DF6E490ED84D3F401B0DE02D90A64D40DF6E490ED84D3F40CCECF318E5A74D4086764EB340533F40CCECF318E5A74D4086764EB340533F401B0DE02D90A64D40DF6E490ED84D3F401B0DE02D90A64D40
66440	13272	30.750042000000001	30.780638	59.573518999999997	59.554518999999999	Заводская	0103000020E610000001000000050000005EA0A4C002C03E405C01857AFAC64D405EA0A4C002C03E403B51121269C94D40CD0358E4D7C73E403B51121269C94D40CD0358E4D7C73E405C01857AFAC64D405EA0A4C002C03E405C01857AFAC64D40
67478	9079	30.787617999999998	30.793951	59.702981000000001	59.702663000000001	Школьная 	0103000020E61000000100000005000000ADBD4F55A1C93E40FC8D76DCF0D94D40ADBD4F55A1C93E40CD5A0A48FBD94D4062A06B5F40CB3E40CD5A0A48FBD94D4062A06B5F40CB3E40FC8D76DCF0D94D40ADBD4F55A1C93E40FC8D76DCF0D94D40
4446	9079	30.78407	30.799809	59.707918999999997	59.673265000000001	Советский проспект	0103000020E6100000010000000500000054C6BFCFB8C83E404E452A8C2DD64D4054C6BFCFB8C83E40C79BFC169DDA4D40E50B5A48C0CC3E40C79BFC169DDA4D40E50B5A48C0CC3E404E452A8C2DD64D4054C6BFCFB8C83E404E452A8C2DD64D40
2531	9079	30.774314	30.784196000000001	59.708241999999998	59.707478999999999	Первомайская улица	0103000020E61000000100000005000000BFD53A7139C63E40ABCDFFAB8EDA4D40BFD53A7139C63E40AAD381ACA7DA4D406EA7AD11C1C83E40AAD381ACA7DA4D406EA7AD11C1C83E40ABCDFFAB8EDA4D40BFD53A7139C63E40ABCDFFAB8EDA4D40
67369	9079	30.774314	30.784196000000001	59.708241999999998	59.707478999999999	Первомайская	0103000020E61000000100000005000000BFD53A7139C63E40ABCDFFAB8EDA4D40BFD53A7139C63E40AAD381ACA7DA4D406EA7AD11C1C83E40AAD381ACA7DA4D406EA7AD11C1C83E40ABCDFFAB8EDA4D40BFD53A7139C63E40ABCDFFAB8EDA4D40
67357	9079	30.778914	30.784967999999999	59.695984000000003	59.695875000000001	Октябрьская	0103000020E6100000010000000500000084656CE866C73E40508D976E12D94D4084656CE866C73E400745F30016D94D401268B0A9F3C83E400745F30016D94D401268B0A9F3C83E40508D976E12D94D4084656CE866C73E40508D976E12D94D40
67409	9079	30.784879	30.792981000000001	59.697409999999998	59.697291999999997	Дачная	0103000020E61000000100000005000000335184D4EDC83E4097E13FDD40D94D40335184D4EDC83E40A1F31ABB44D94D40715985CD00CB3E40A1F31ABB44D94D40715985CD00CB3E4097E13FDD40D94D40335184D4EDC83E4097E13FDD40D94D40
4063	14369	31.246701999999999	31.265198999999999	59.366352999999997	59.365591999999999	проспект Мельникова	0103000020E6100000010000000500000098DBBDDC273F3F40F1D6F9B7CBAE4D4098DBBDDC273F3F404FE5B4A7E4AE4D4091EEE714E4433F404FE5B4A7E4AE4D4091EEE714E4433F40F1D6F9B7CBAE4D4098DBBDDC273F3F40F1D6F9B7CBAE4D40
67416	14369	31.243648	31.270579999999999	59.374932000000001	59.362878000000002	Торговая улица	0103000020E610000001000000050000005EBC1FB75F3E3F400D384BC972AE4D405EBC1FB75F3E3F40A81C93C5FDAF4D40A1F31ABB44453F40A81C93C5FDAF4D40A1F31ABB44453F400D384BC972AE4D405EBC1FB75F3E3F400D384BC972AE4D40
67309	14369	31.243648	31.270579999999999	59.374932000000001	59.362878000000002	Заводская улица	0103000020E610000001000000050000005EBC1FB75F3E3F400D384BC972AE4D405EBC1FB75F3E3F40A81C93C5FDAF4D40A1F31ABB44453F40A81C93C5FDAF4D40A1F31ABB44453F400D384BC972AE4D405EBC1FB75F3E3F400D384BC972AE4D40
67592	14369	31.243648	31.270579999999999	59.374932000000001	59.362878000000002	Алексеенко	0103000020E610000001000000050000005EBC1FB75F3E3F400D384BC972AE4D405EBC1FB75F3E3F40A81C93C5FDAF4D40A1F31ABB44453F40A81C93C5FDAF4D40A1F31ABB44453F400D384BC972AE4D405EBC1FB75F3E3F400D384BC972AE4D40
67119	11202	30.636037000000002	30.712717000000001	59.692473999999997	59.647928999999998	пр. Советский	0103000020E61000000100000005000000C40B2252D3A23E40A3906456EFD24D40C40B2252D3A23E4047AAEFFCA2D84D40A14D0E9F74B63E4047AAEFFCA2D84D40A14D0E9F74B63E40A3906456EFD24D40C40B2252D3A23E40A3906456EFD24D40
67362	11202	30.665196000000002	30.699044000000001	59.680933000000003	59.675668000000002	Культуры	0103000020E61000000100000005000000166EF9484AAA3E40147AFD497CD64D40166EF9484AAA3E4033E202D028D74D400C772E8CF4B23E4033E202D028D74D400C772E8CF4B23E40147AFD497CD64D40166EF9484AAA3E40147AFD497CD64D40
3186	11202	30.694697000000001	30.701972999999999	59.677653999999997	59.667102999999997	Комсомольская улица	0103000020E610000001000000050000001BA19FA9D7B13E40200890A163D54D401BA19FA9D7B13E407500C45DBDD64D40CDACA580B4B33E407500C45DBDD64D40CDACA580B4B33E40200890A163D54D401BA19FA9D7B13E40200890A163D54D40
67030	58925	30.848129	30.862924	59.647770000000001	59.640183999999998	Школьная	0103000020E6100000010000000500000008CA6DFB1ED93E4013B69F8CF1D14D4008CA6DFB1ED93E403BAA9A20EAD24D40FAEE5696E8DC3E403BAA9A20EAD24D40FAEE5696E8DC3E4013B69F8CF1D14D4008CA6DFB1ED93E4013B69F8CF1D14D40
66986	15227	30.553678999999999	30.577251	59.697305999999998	59.684480999999998	3	0103000020E61000000100000005000000637B2DE8BD8D3E40DFDDCA129DD74D40637B2DE8BD8D3E40FCA6B05241D94D405395B6B8C6933E40FCA6B05241D94D405395B6B8C6933E40DFDDCA129DD74D40637B2DE8BD8D3E40DFDDCA129DD74D40
66981	10937	31.474191999999999	31.482285999999998	59.222495000000002	59.217581000000003	Московское шоссе	0103000020E610000001000000050000005B069CA564793F40919DB7B1D99B4D405B069CA564793F40034356B77A9C4D4093516518777B3F40034356B77A9C4D4093516518777B3F40919DB7B1D99B4D405B069CA564793F40919DB7B1D99B4D40
66992	12998	34.187823000000002	34.240724	59.936948999999998	59.918768999999998	Советская	0103000020E61000000100000005000000E33785950A18414010CAFB389AF54D40E33785950A1841408C82E0F1EDF74D4060AE450BD01E41408C82E0F1EDF74D4060AE450BD01E414010CAFB389AF54D40E33785950A18414010CAFB389AF54D40
3481	11445	33.510061999999998	33.514139999999998	59.647283000000002	59.645018	площадь Свободы	0103000020E6100000010000000500000057772CB649C1404069AA27F38FD24D4057772CB649C14040DE205A2BDAD24D4060C8EA56CFC14040DE205A2BDAD24D4060C8EA56CFC1404069AA27F38FD24D4057772CB649C1404069AA27F38FD24D40
3451	11445	33.512703000000002	33.519728000000001	59.645437000000001	59.639223999999999	Школьная улица	0103000020E61000000100000005000000D2C77C40A0C14040BE688F17D2D14D40D2C77C40A0C140406E50FBAD9DD24D406268757286C240406E50FBAD9DD24D406268757286C24040BE688F17D2D14D40D2C77C40A0C14040BE688F17D2D14D40
67550	11445	33.512703000000002	33.519728000000001	59.645437000000001	59.639223999999999	Школьная	0103000020E61000000100000005000000D2C77C40A0C14040BE688F17D2D14D40D2C77C40A0C140406E50FBAD9DD24D406268757286C240406E50FBAD9DD24D406268757286C24040BE688F17D2D14D40D2C77C40A0C14040BE688F17D2D14D40
67392	11445	33.499029999999998	33.514175999999999	59.644959	59.640566	Пролетарской Диктатуры	0103000020E6100000010000000500000087DC0C37E0BF4040FB761211FED14D4087DC0C37E0BF404064213A048ED24D40AD31E884D0C1404064213A048ED24D40AD31E884D0C14040FB761211FED14D4087DC0C37E0BF4040FB761211FED14D40
67373	11445	33.498553999999999	33.532232	59.640134000000003	59.639060999999998	Машиностроителей	0103000020E610000001000000050000001EA5129ED0BF4040149337C0CCD14D401EA5129ED0BF4040628731E9EFD14D403DF19C2D20C44040628731E9EFD14D403DF19C2D20C44040149337C0CCD14D401EA5129ED0BF4040149337C0CCD14D40
67595	11445	33.495975999999999	33.511184999999998	59.658822000000001	59.652726000000001	Зайцева	0103000020E61000000100000005000000EACC3D247CBF4040DC9F8B868CD34D40EACC3D247CBF404052F17F4754D44D40569A94826EC1404052F17F4754D44D40569A94826EC14040DC9F8B868CD34D40EACC3D247CBF4040DC9F8B868CD34D40
67471	11445	33.553612000000001	33.555121	59.648291999999998	59.639769999999999	Борисова	0103000020E610000001000000050000002A560DC2DCC64040207BBDFBE3D14D402A560DC2DCC640401421753BFBD24D40522976340EC740401421753BFBD24D40522976340EC74040207BBDFBE3D14D402A560DC2DCC64040207BBDFBE3D14D40
67544	11445	33.521299999999997	33.532232	59.643822	59.639060999999998	6 микрорайон	0103000020E61000000100000005000000D0B359F5B9C24040149337C0CCD14D40D0B359F5B9C24040003961C268D24D403DF19C2D20C44040003961C268D24D403DF19C2D20C44040149337C0CCD14D40D0B359F5B9C24040149337C0CCD14D40
67604	11445	33.531244000000001	33.543407000000002	59.644326999999997	59.639515000000003	3 микрорайон	0103000020E610000001000000050000001E19ABCDFFC340409626A5A0DBD14D401E19ABCDFFC340400377A04E79D24D4070B54E5C8EC540400377A04E79D24D4070B54E5C8EC540409626A5A0DBD14D401E19ABCDFFC340409626A5A0DBD14D40
67482	11445	33.543407000000002	33.555121	59.650751999999997	59.643194999999999	1 микрорайон	0103000020E6100000010000000500000070B54E5C8EC54040B1F9B83654D24D4070B54E5C8EC540403EE76ED74BD34D40522976340EC740403EE76ED74BD34D40522976340EC74040B1F9B83654D24D4070B54E5C8EC54040B1F9B83654D24D40
67291	12609	33.651178000000002	33.664167999999997	59.679203000000001	59.674236999999998	Лесная	0103000020E61000000100000005000000F6EFFACC59D340406760E4654DD64D40F6EFFACC59D340402C2CB81FF0D64D405D86FF7403D540402C2CB81FF0D64D405D86FF7403D540406760E4654DD64D40F6EFFACC59D340406760E4654DD64D40
67032	13050	34.592737999999997	34.635983000000003	60.034635999999999	60.026572000000002	Центральная	0103000020E61000000100000005000000588CBAD6DE4B4140A27E17B666034E40588CBAD6DE4B4140D3A1D3F36E044E40EFE714E467514140D3A1D3F36E044E40EFE714E467514140A27E17B666034E40588CBAD6DE4B4140A27E17B666034E40
67258	12513	33.581639000000003	33.599947	59.560560000000002	59.552790999999999	Комсомольская	0103000020E61000000100000005000000018A912573CA4040F64201DBC1C64D40018A912573CA40400FB9196EC0C74D40AA2A3410CBCC40400FB9196EC0C74D40AA2A3410CBCC4040F64201DBC1C64D40018A912573CA4040F64201DBC1C64D40
67298	12870	33.270857999999997	33.294708999999997	60.033121999999999	60.023668000000001	Школьная	0103000020E6100000010000000500000013EE9579ABA240401AFB928D07034E4013EE9579ABA24040996379573D044E401E6B4606B9A54040996379573D044E401E6B4606B9A540401AFB928D07034E4013EE9579ABA240401AFB928D07034E40
67174	58987	33.891719999999999	33.899023	59.991813	59.987893	Народная	0103000020E61000000100000005000000359886E123F2404042791F4773FE4D40359886E123F24040B35F77BAF3FE4D4008AD872F13F34040B35F77BAF3FE4D4008AD872F13F3404042791F4773FE4D40359886E123F2404042791F4773FE4D40
67221	12837	33.317427000000002	33.347368000000003	59.822127000000002	59.804658000000003	Центральная	0103000020E6100000010000000500000007EFAB72A1A840407E3B8908FFE64D4007EFAB72A1A840404D1421753BE94D40A6D6FB8D76AC40404D1421753BE94D40A6D6FB8D76AC40407E3B8908FFE64D4007EFAB72A1A840407E3B8908FFE64D40
67062	12913	33.784694999999999	33.811940999999997	59.899293	59.888519000000002	переулок Клубный	0103000020E61000000100000005000000D82AC1E270E44040F46F97FDBAF14D40D82AC1E270E44040C84274081CF34D4009A4C4AEEDE74040C84274081CF34D4009A4C4AEEDE74040F46F97FDBAF14D40D82AC1E270E44040F46F97FDBAF14D40
66386	12558	33.470283999999999	33.481828	59.691656999999999	59.688699999999997	Лесная	0103000020E6100000010000000500000081EA1F4432BC4040AA60545227D84D4081EA1F4432BC40405586713788D84D400726378AACBD40405586713788D84D400726378AACBD4040AA60545227D84D4081EA1F4432BC4040AA60545227D84D40
2953	10320	28.087902	28.098799	59.126080999999999	59.112312000000003	улица Кирова	0103000020E61000000100000005000000C440D7BE80163C406479573D608E4D40C440D7BE80163C40D0D2156C23904D40A4E029E44A193C40D0D2156C23904D40A4E029E44A193C406479573D608E4D40C440D7BE80163C406479573D608E4D40
3172	10320	28.159632999999999	28.169298999999999	59.093971000000003	59.085951000000001	улица Дзержинского	0103000020E61000000100000005000000C45C52B5DD283C407D073F71008B4D40C45C52B5DD283C40DFE2E13D078C4D40D93EE42D572B3C40DFE2E13D078C4D40D93EE42D572B3C407D073F71008B4D40C45C52B5DD283C407D073F71008B4D40
67477	10320	28.082953	28.087902	59.117697999999997	59.112487000000002	Спортивная	0103000020E61000000100000005000000E71A66683C153C40D21C59F9658E4D40E71A66683C153C40FD6662BA108F4D40C440D7BE80163C40FD6662BA108F4D40C440D7BE80163C40D21C59F9658E4D40E71A66683C153C40D21C59F9658E4D40
3148	10320	28.105563	28.107171000000001	59.117364999999999	59.107298999999998	Молодёжный проспект	0103000020E61000000100000005000000EBAA402D061B3C405EF23FF9BB8D4D40EBAA402D061B3C40F758FAD0058F4D406214048F6F1B3C40F758FAD0058F4D406214048F6F1B3C405EF23FF9BB8D4D40EBAA402D061B3C405EF23FF9BB8D4D40
67549	10320	28.083016000000001	28.096965999999998	59.114894	59.113517999999999	Максима Горького	0103000020E61000000100000005000000740B5D8940153C40F0C000C2878E4D40740B5D8940153C40D940BAD8B48E4D40EDD286C3D2183C40D940BAD8B48E4D40EDD286C3D2183C40F0C000C2878E4D40740B5D8940153C40F0C000C2878E4D40
67310	10320	28.075514999999999	28.107171000000001	59.118335000000002	59.117364999999999	Ленина	0103000020E61000000100000005000000815B77F354133C40F758FAD0058F4D40815B77F354133C40707CED99258F4D406214048F6F1B3C40707CED99258F4D406214048F6F1B3C40F758FAD0058F4D40815B77F354133C40F758FAD0058F4D40
67597	10320	28.08342	28.086402	59.111581999999999	59.111573	Климчука	0103000020E6100000010000000500000013D55B035B153C40ED0E2906488E4D4013D55B035B153C404069A851488E4D401A4F04711E163C404069A851488E4D401A4F04711E163C40ED0E2906488E4D4013D55B035B153C40ED0E2906488E4D40
67530	10320	28.087902	28.098799	59.126080999999999	59.112312000000003	Кирова	0103000020E61000000100000005000000C440D7BE80163C406479573D608E4D40C440D7BE80163C40D0D2156C23904D40A4E029E44A193C40D0D2156C23904D40A4E029E44A193C406479573D608E4D40C440D7BE80163C406479573D608E4D40
67491	10320	28.082782000000002	28.096616000000001	59.121892000000003	59.121827000000003	Грибоедова	0103000020E610000001000000050000008EB27E3331153C408962F206988F4D408EB27E3331153C4070D234289A8F4D40354580D3BB183C4070D234289A8F4D40354580D3BB183C408962F206988F4D408EB27E3331153C408962F206988F4D40
67498	10320	28.087893000000001	28.106829999999999	59.112487000000002	59.106369999999998	Гагарина	0103000020E610000001000000050000001E8CD82780163C4044A33B889D8D4D401E8CD82780163C40D21C59F9658E4D404F3BFC35591B3C40D21C59F9658E4D404F3BFC35591B3C4044A33B889D8D4D401E8CD82780163C4044A33B889D8D4D40
65951	11631	28.704183	28.728383000000001	59.159396000000001	59.146138999999998	Загорская	0103000020E6100000010000000500000030664B5645B43C40C7D5C8AEB4924D4030664B5645B43C407E8E8F1667944D405EF6EB4E77BA3C407E8E8F1667944D405EF6EB4E77BA3C40C7D5C8AEB4924D4030664B5645B43C40C7D5C8AEB4924D40
67323	59032	30.172281000000002	30.304082000000001	60.540553000000003	60.475561999999996	Заводская	0103000020E61000000100000005000000E1B88C9B1A2C3E40349C3237DF3C4E40E1B88C9B1A2C3E409A6038D730454E40624D6551D84D3E409A6038D730454E40624D6551D84D3E40349C3237DF3C4E40E1B88C9B1A2C3E40349C3237DF3C4E40
67237	9709	30.194963999999999	30.268616999999999	60.58287	60.539203999999998	Связи	0103000020E61000000100000005000000B8E52329E9313E40AAEFFCA204454E40B8E52329E9313E40E6E8F17B9B4A4E404E266E15C4443E40E6E8F17B9B4A4E404E266E15C4443E40AAEFFCA204454E40B8E52329E9313E40AAEFFCA204454E40
67244	9709	30.194963999999999	30.268616999999999	60.58287	60.539203999999998	Мичуринская	0103000020E61000000100000005000000B8E52329E9313E40AAEFFCA204454E40B8E52329E9313E40E6E8F17B9B4A4E404E266E15C4443E40E6E8F17B9B4A4E404E266E15C4443E40AAEFFCA204454E40B8E52329E9313E40AAEFFCA204454E40
67179	9709	30.194963999999999	30.268616999999999	60.58287	60.539203999999998	Механизаторов	0103000020E61000000100000005000000B8E52329E9313E40AAEFFCA204454E40B8E52329E9313E40E6E8F17B9B4A4E404E266E15C4443E40E6E8F17B9B4A4E404E266E15C4443E40AAEFFCA204454E40B8E52329E9313E40AAEFFCA204454E40
67039	9639	30.284552999999999	30.311826	60.558784000000003	60.54804	Центральная	0103000020E610000001000000050000008BFA2477D8483E402E73BA2C26464E408BFA2477D8483E4098C3EE3B86474E40E10A28D4D34F3E4098C3EE3B86474E40E10A28D4D34F3E402E73BA2C26464E408BFA2477D8483E402E73BA2C26464E40
67308	10020	29.785359	29.808778	61.061070000000001	61.052095999999999	Новая	0103000020E61000000100000005000000889E94490DC93D404F20EC14AB864E40889E94490DC93D4024624A24D1874E406BB933130CCF3D4024624A24D1874E406BB933130CCF3D404F20EC14AB864E40889E94490DC93D404F20EC14AB864E40
67157	9374	29.938404999999999	29.973143	60.733271000000002	60.708888999999999	Школьная	0103000020E610000001000000050000002367614F3BF03D4040BFEFDFBC5A4E402367614F3BF03D40780DFAD2DB5D4E40D2544FE61FF93D40780DFAD2DB5D4E40D2544FE61FF93D4040BFEFDFBC5A4E402367614F3BF03D4040BFEFDFBC5A4E40
66076	6612	29.793641000000001	29.819603000000001	60.722216000000003	60.707476	Новостроек	0103000020E61000000100000005000000C6C37B0E2CCB3D403A5AD5928E5A4E40C6C37B0E2CCB3D40F052EA92715C4E4018B49080D1D13D40F052EA92715C4E4018B49080D1D13D403A5AD5928E5A4E40C6C37B0E2CCB3D403A5AD5928E5A4E40
67558	125	30.128722	30.135936000000001	61.041350999999999	61.040201000000003	Северопарковая	0103000020E610000001000000050000009546CCECF3203E401D226E4E25854E409546CCECF3203E40155454FD4A854E405C59A2B3CC223E40155454FD4A854E405C59A2B3CC223E401D226E4E25854E409546CCECF3203E401D226E4E25854E40
67234	125	30.087031	30.18289	61.052970999999999	61.006320000000002	Леншоссе	0103000020E61000000100000005000000F9BCE2A947163E40C6A70018CF804E40F9BCE2A947163E407651F4C0C7864E40F4C308E1D12E3E407651F4C0C7864E40F4C308E1D12E3E40C6A70018CF804E40F9BCE2A947163E40C6A70018CF804E40
67414	125	30.108339000000001	30.153919999999999	61.044103999999997	61.035147000000002	Ленина	0103000020E61000000100000005000000A0E1CD1ABC1B3E40B9C667B27F844E40A0E1CD1ABC1B3E40B7CF2A33A5854E404833164D67273E40B7CF2A33A5854E404833164D67273E40B9C667B27F844E40A0E1CD1ABC1B3E40B9C667B27F844E40
67536	125	30.108744000000002	30.155042999999999	61.04298	61.034567000000003	Калинина	0103000020E61000000100000005000000E0A293A5D61B3E40AB4203B16C844E40E0A293A5D61B3E40E8305F5E80854E404679E6E5B0273E40E8305F5E80854E404679E6E5B0273E40AB4203B16C844E40E0A293A5D61B3E40AB4203B16C844E40
22371	6409	30.180392999999999	30.219532999999998	60.974108999999999	60.964613	Леншоссе	0103000020E61000000100000005000000656D533C2E2E3E40F2255470787B4E40656D533C2E2E3E40A0DE8C9AAF7C4E408C648F5033383E40A0DE8C9AAF7C4E408C648F5033383E40F2255470787B4E40656D533C2E2E3E40F2255470787B4E40
67268	6724	30.127330000000001	30.172605000000001	60.648902999999997	60.632019999999997	Шоссейная	0103000020E61000000100000005000000B8CCE9B298203E407E350708E6504E40B8CCE9B298203E405DA3E5400F534E4047205ED72F2C3E405DA3E5400F534E4047205ED72F2C3E407E350708E6504E40B8CCE9B298203E407E350708E6504E40
67146	9135	30.287103999999999	30.304316	60.966603999999997	60.953859999999999	Приладожское шоссе	0103000020E61000000100000005000000008DD2A57F493E40357BA015187A4E40008DD2A57F493E4065170CAEB97B4E4048A643A7E74D3E4065170CAEB97B4E4048A643A7E74D3E40357BA015187A4E40008DD2A57F493E40357BA015187A4E40
67271	9936	29.789176999999999	29.892500999999999	60.590431000000002	60.556666	Первомайская	0103000020E6100000010000000500000061C1FD8007CA3D40C765DCD440474E4061C1FD8007CA3D40B5C5353E934B4E40B5A50EF27AE43D40B5C5353E934B4E40B5A50EF27AE43D40C765DCD440474E4061C1FD8007CA3D40C765DCD440474E40
66265	6525	29.736194000000001	29.80911	60.933247000000001	60.900556000000002	Калинина	0103000020E61000000100000005000000ED82C13577BC3D40B91B446B45734E40ED82C13577BC3D40890B40A374774E40D7DD3CD521CF3D40890B40A374774E40D7DD3CD521CF3D40B91B446B45734E40ED82C13577BC3D40B91B446B45734E40
67229	6462	30.158169000000001	30.237580000000001	61.011073000000003	60.992753999999998	Ленинградская	0103000020E61000000100000005000000B43D7AC37D283E40917C2590127F4E40B43D7AC37D283E402F6F0ED76A814E40062FFA0AD23C3E402F6F0ED76A814E40062FFA0AD23C3E40917C2590127F4E40B43D7AC37D283E40917C2590127F4E40
67296	10082	29.853370000000002	29.887056999999999	61.128740000000001	61.110514000000002	Юбилейная	0103000020E610000001000000050000003563D17476DA3D4005E09F52258E4E403563D17476DA3D40F1D7648D7A904E4018B0E42A16E33D40F1D7648D7A904E4018B0E42A16E33D4005E09F52258E4E403563D17476DA3D4005E09F52258E4E40
65112	10082	29.853370000000002	29.887056999999999	61.128740000000001	61.110514000000002	Центральная	0103000020E610000001000000050000003563D17476DA3D4005E09F52258E4E403563D17476DA3D40F1D7648D7A904E4018B0E42A16E33D40F1D7648D7A904E4018B0E42A16E33D4005E09F52258E4E403563D17476DA3D4005E09F52258E4E40
67332	59035	29.853370000000002	29.887056999999999	61.128740000000001	61.110514000000002	Юбилейная	0103000020E610000001000000050000003563D17476DA3D4005E09F52258E4E403563D17476DA3D40F1D7648D7A904E4018B0E42A16E33D40F1D7648D7A904E4018B0E42A16E33D4005E09F52258E4E403563D17476DA3D4005E09F52258E4E40
67282	59019	30.235271000000001	30.270368000000001	60.599969000000002	60.579205999999999	Фестивальная	0103000020E610000001000000050000007DB262B83A3C3E40D0D2156C234A4E407DB262B83A3C3E4092CEC0C8CB4C4E408BE255D636453E4092CEC0C8CB4C4E408BE255D636453E40D0D2156C234A4E407DB262B83A3C3E40D0D2156C234A4E40
67228	9963	29.647566000000001	29.668479000000001	60.585774000000001	60.578446	Школьная	0103000020E610000001000000050000006500A8E2C6A53D404240BE840A4A4E406500A8E2C6A53D406E6C76A4FA4A4E401310937021AB3D406E6C76A4FA4A4E401310937021AB3D404240BE840A4A4E406500A8E2C6A53D404240BE840A4A4E40
66972	6369	30.053038999999998	30.081426	60.912219	60.901544999999999	Школьная	0103000020E610000001000000050000009C69C2F6930D3E40A86F99D365734E409C69C2F6930D3E4019E59997C3744E404A0B9755D8143E4019E59997C3744E404A0B9755D8143E40A86F99D365734E409C69C2F6930D3E40A86F99D365734E40
66426	1005	30.499842999999998	30.540061000000001	60.591963999999997	60.557679	Советская	0103000020E610000001000000050000007022FAB5F57F3E403F55850662474E407022FAB5F57F3E406534F279C54B4E4056D80C70418A3E406534F279C54B4E4056D80C70418A3E403F55850662474E407022FAB5F57F3E403F55850662474E40
67205	7607	34.056651000000002	34.077697999999998	60.920223	60.910595999999998	Новая	0103000020E61000000100000005000000922408574007414028EFE3688E744E409224085740074140750305DEC9754E40787B1002F2094140750305DEC9754E40787B1002F209414028EFE3688E744E40922408574007414028EFE3688E744E40
24357	8434	34.495674999999999	34.516461999999997	60.501725999999998	60.488551000000001	Школьная	0103000020E61000000100000005000000EF384547723F4140CCB6D3D6883E4E40EF384547723F4140C5C6BC8E38404E4039D0436D1B424140C5C6BC8E38404E4039D0436D1B424140CCB6D3D6883E4E40EF384547723F4140CCB6D3D6883E4E40
67226	2830	34.409427999999998	34.437508999999999	60.882654000000002	60.871602000000003	Деловая 	0103000020E610000001000000050000008908FF2268344140699082A7906F4E408908FF226834414080D767CEFA704E40535A7F4B0038414080D767CEFA704E40535A7F4B00384140699082A7906F4E408908FF2268344140699082A7906F4E40
66984	2738	34.378309999999999	34.411287000000002	61.108206000000003	61.091856999999997	Исакова 	0103000020E61000000100000005000000F8DF4A766C3041404F745DF8C18B4E40F8DF4A766C304140919DB7B1D98D4E408E226B0DA5344140919DB7B1D98D4E408E226B0DA53441404F745DF8C18B4E40F8DF4A766C3041404F745DF8C18B4E40
67222	7782	34.992327000000003	35.010930999999999	60.935896	60.922553999999998	Георгиевская	0103000020E610000001000000050000000AF83592047F4140A165DD3F16764E400AF83592047F4140863AAC70CB774E409CC1DF2F66814140863AAC70CB774E409CC1DF2F66814140A165DD3F16764E400AF83592047F4140A165DD3F16764E40
668	2412	34.114995999999998	34.17848	60.923634	60.912329	проспект Ленина	0103000020E61000000100000005000000DD955D30B80E4140A0185932C7744E40DD955D30B80E4140A1BC8FA339764E40BB7EC16ED8164140A1BC8FA339764E40BB7EC16ED8164140A0185932C7744E40DD955D30B80E4140A0185932C7744E40
67522	2412	34.169092999999997	34.169623000000001	60.909713000000004	60.904507000000002	Строителей	0103000020E61000000100000005000000C37DE4D6A41541406500A8E2C6734E40C37DE4D6A41541407FDFBF7971744E4020D3DA34B61541407FDFBF7971744E4020D3DA34B61541406500A8E2C6734E40C37DE4D6A41541406500A8E2C6734E40
67582	2412	34.146464000000002	34.182234999999999	60.936574	60.920647000000002	Северная	0103000020E610000001000000050000004B051555BF1241408C14CAC2D7754E404B051555BF124140572426A8E1774E40E197FA7953174140572426A8E1774E40E197FA79531741408C14CAC2D7754E404B051555BF1241408C14CAC2D7754E40
67504	2412	34.148997000000001	34.187634000000003	60.913020000000003	60.904401999999997	Свирская	0103000020E61000000100000005000000DF196D5512134140EF37DA71C3734E40DF196D5512134140064CE0D6DD744E4010CF126404184140064CE0D6DD744E4010CF126404184140EF37DA71C3734E40DF196D5512134140EF37DA71C3734E40
67295	2412	34.102375000000002	34.253228999999997	60.939051999999997	60.895935000000001	Промывные	0103000020E61000000100000005000000C976BE9F1A0D4140BF2B82FFAD724E40C976BE9F1A0D4140279F1EDB32784E400BB3D0CE69204140279F1EDB32784E400BB3D0CE69204140BF2B82FFAD724E40C976BE9F1A0D4140BF2B82FFAD724E40
67499	2412	34.180528000000002	34.186044000000003	60.909905000000002	60.906506	Гнаровской	0103000020E610000001000000050000009301A08A1B1741405BD07B6308744E409301A08A1B174140C3BB5CC477744E40FBCE2F4AD0174140C3BB5CC477744E40FBCE2F4AD01741405BD07B6308744E409301A08A1B1741405BD07B6308744E40
67096	58959	34.056651000000002	34.077697999999998	60.920223	60.910595999999998	Лисициной	0103000020E61000000100000005000000922408574007414028EFE3688E744E409224085740074140750305DEC9754E40787B1002F2094140750305DEC9754E40787B1002F209414028EFE3688E744E40922408574007414028EFE3688E744E40
67236	8237	34.822212999999998	34.841400999999998	60.462251999999999	60.456316000000001	Покровская 	0103000020E610000001000000050000004BAC8C463E6941401E520C90683A4E404BAC8C463E6941405B41D3122B3B4E402DE92807B36B41405B41D3122B3B4E402DE92807B36B41401E520C90683A4E404BAC8C463E6941401E520C90683A4E40
66361	7734	34.038989999999998	34.055940999999997	60.977431000000003	60.971643	Клубная	0103000020E610000001000000050000007E6FD39FFD04414094313ECC5E7C4E407E6FD39FFD0441405D8C81751C7D4E40B5C01E13290741405D8C81751C7D4E40B5C01E132907414094313ECC5E7C4E407E6FD39FFD04414094313ECC5E7C4E40
24376	8331	34.917918999999998	34.940466999999998	60.405298000000002	60.395783000000002	Школьная	0103000020E6100000010000000500000042B0AA5E7E75414009A87004A9324E4042B0AA5E7E7541402E910BCEE0334E40CEFBFF38617841402E910BCEE0334E40CEFBFF386178414009A87004A9324E4042B0AA5E7E75414009A87004A9324E40
9795	8477	34.589207999999999	34.602556999999997	60.549751999999998	60.542478000000003	Центральная	0103000020E610000001000000050000005245F12A6B4B414056664AEB6F454E405245F12A6B4B41408E7406465E464E40E97C7896204D41408E7406465E464E40E97C7896204D414056664AEB6F454E405245F12A6B4B414056664AEB6F454E40
67233	59001	35.392499000000001	35.450125999999997	61.059072	61.045067000000003	Школьная 	0103000020E610000001000000050000003A5B40683DB241407E9065C1C4854E403A5B40683DB24140FE0DDAAB8F874E40268A90BA9DB94140FE0DDAAB8F874E40268A90BA9DB941407E9065C1C4854E403A5B40683DB241407E9065C1C4854E40
66976	7829	35.419744999999999	35.439247999999999	60.946126999999997	60.939816999999998	Школьная	0103000020E610000001000000050000006BD44334BAB54140C79C67EC4B784E406BD44334BAB54140696E85B01A794E40AD6A494739B84140696E85B01A794E40AD6A494739B84140C79C67EC4B784E406BD44334BAB54140C79C67EC4B784E40
67224	58996	34.859098000000003	34.872805999999997	60.563304000000002	60.554264000000003	Немжинская	0103000020E610000001000000050000008E075BECF66D4140D2AC6C1FF2464E408E075BECF66D41405EDA70581A484E4054E0641BB86F41405EDA70581A484E4054E0641BB86F4140D2AC6C1FF2464E408E075BECF66D4140D2AC6C1FF2464E40
67238	8400	35.054336999999997	35.064048	60.398699000000001	60.394275999999998	Раздольная	0103000020E610000001000000050000003BFBCA83F486414081CCCEA277324E403BFBCA83F486414055F99E9108334E40E6AF90B93288414055F99E9108334E40E6AF90B93288414081CCCEA277324E403BFBCA83F486414081CCCEA277324E40
66406	7873	35.611939999999997	35.627166000000003	61.155810000000002	61.148001000000001	Петрозаводский тракт	0103000020E610000001000000050000009F8EC70C54CE41403D635FB2F1924E409F8EC70C54CE4140E4310395F1934E40E294B9F946D04140E4310395F1934E40E294B9F946D041403D635FB2F1924E409F8EC70C54CE41403D635FB2F1924E40
67081	58948	35.401491	35.507402999999996	61.051555999999998	60.992809999999999	Пионерская	0103000020E61000000100000005000000B5519D0E64B341402592E865147F4E40B5519D0E64B34140CFF4126399864E403672DD94F2C04140CFF4126399864E403672DD94F2C041402592E865147F4E40B5519D0E64B341402592E865147F4E40
67082	58948	35.401491	35.507402999999996	61.051555999999998	60.992809999999999	Лесозаводская	0103000020E61000000100000005000000B5519D0E64B341402592E865147F4E40B5519D0E64B34140CFF4126399864E403672DD94F2C04140CFF4126399864E403672DD94F2C041402592E865147F4E40B5519D0E64B341402592E865147F4E40
66061	8071	34.732883999999999	34.801596000000004	60.639949000000001	60.618929999999999	Советская	0103000020E610000001000000050000007EE19524CF5D4140B3412619394F4E407EE19524CF5D4140D00D4DD9E9514E405E4D9EB29A664140D00D4DD9E9514E405E4D9EB29A664140B3412619394F4E407EE19524CF5D4140B3412619394F4E40
66407	8071	34.732883999999999	34.801596000000004	60.639949000000001	60.618929999999999	Лесная	0103000020E610000001000000050000007EE19524CF5D4140B3412619394F4E407EE19524CF5D4140D00D4DD9E9514E405E4D9EB29A664140D00D4DD9E9514E405E4D9EB29A664140B3412619394F4E407EE19524CF5D4140B3412619394F4E40
66084	8071	34.732883999999999	34.801596000000004	60.639949000000001	60.618929999999999	Гражданская	0103000020E610000001000000050000007EE19524CF5D4140B3412619394F4E407EE19524CF5D4140D00D4DD9E9514E405E4D9EB29A664140D00D4DD9E9514E405E4D9EB29A664140B3412619394F4E407EE19524CF5D4140B3412619394F4E40
67204	7691	33.987749999999998	34.050362	60.970537999999998	60.953479999999999	Школьная	0103000020E61000000100000005000000DF4F8D976EFE4040EEB1F4A10B7A4E40DF4F8D976EFE40403BC3D4963A7C4E40077B1343720641403BC3D4963A7C4E40077B134372064140EEB1F4A10B7A4E40DF4F8D976EFE4040EEB1F4A10B7A4E40
67122	6168	29.864186	29.925784	58.870243000000002	58.838908000000004	Толмачёва 	0103000020E610000001000000050000003BA92F4B3BDD3D40282D5C56616B4D403BA92F4B3BDD3D405649641F646F4D40FA28232E00ED3D405649641F646F4D40FA28232E00ED3D40282D5C56616B4D403BA92F4B3BDD3D40282D5C56616B4D40
66978	6168	29.864186	29.925784	58.870243000000002	58.838908000000004	Прохорова	0103000020E610000001000000050000003BA92F4B3BDD3D40282D5C56616B4D403BA92F4B3BDD3D405649641F646F4D40FA28232E00ED3D405649641F646F4D40FA28232E00ED3D40282D5C56616B4D403BA92F4B3BDD3D40282D5C56616B4D40
67260	6470	29.965192999999999	29.988368999999999	59.109299999999998	59.089343999999997	Дзержинского	0103000020E61000000100000005000000005471E316F73D40020CCB9F6F8B4D40005471E316F73D40F5B9DA8AFD8D4D40566133C005FD3D40F5B9DA8AFD8D4D40566133C005FD3D40020CCB9F6F8B4D40005471E316F73D40020CCB9F6F8B4D40
67177	6034	30.572202000000001	30.590205000000001	58.898434999999999	58.889800999999999	Центральная	0103000020E61000000100000005000000AFB48CD47B923E405B79C9FFE4714D40AFB48CD47B923E40774A07EBFF724D4089EFC4AC17973E40774A07EBFF724D4089EFC4AC17973E405B79C9FFE4714D40AFB48CD47B923E405B79C9FFE4714D40
67242	1889	30.554299	30.580126	58.804212999999997	58.794790999999996	20-го съезда КПСС	0103000020E610000001000000050000009C340D8AE68D3E40DB1324B6BB654D409C340D8AE68D3E404F029B73F0664D402E8F352383943E404F029B73F0664D402E8F352383943E40DB1324B6BB654D409C340D8AE68D3E40DB1324B6BB654D40
67266	1562	30.104673999999999	30.118974999999999	58.573036999999999	58.560308999999997	Торговая	0103000020E61000000100000005000000D3BD4EEACB1A3E40C5538F34B8474D40D3BD4EEACB1A3E40F032C34659494D40A60A4625751E3E40F032C34659494D40A60A4625751E3E40C5538F34B8474D40D3BD4EEACB1A3E40C5538F34B8474D40
67297	59026	30.322282000000001	30.363406999999999	58.864128999999998	58.846930999999998	Стахановская	0103000020E61000000100000005000000E816BA1281523E40FA7B293C686C4D40E816BA1281523E40394371C79B6E4D403123BC3D085D3E40394371C79B6E4D403123BC3D085D3E40FA7B293C686C4D40E816BA1281523E40FA7B293C686C4D40
24361	1814	29.876709000000002	29.890552	58.608691	58.596420999999999	Центральная	0103000020E61000000100000005000000DF1B430070E03D40E5D2F885574C4D40DF1B430070E03D404D2F3196E94D4D402C634337FBE33D404D2F3196E94D4D402C634337FBE33D40E5D2F885574C4D40DF1B430070E03D40E5D2F885574C4D40
67003	6773	29.592230000000001	29.621372000000001	58.587491999999997	58.570535999999997	Совхозная	0103000020E61000000100000005000000C8B5A1629C973D406798DA5207494D40C8B5A1629C973D40B05417F0324B4D406EA6423C129F3D40B05417F0324B4D406EA6423C129F3D406798DA5207494D40C8B5A1629C973D406798DA5207494D40
67172	1674	30.018274000000002	30.032225	58.666545999999997	58.658008000000002	Нагорная	0103000020E61000000100000005000000FB5DD89AAD043E40D1402C9B39544D40FB5DD89AAD043E40CAA31B6151554D40151DC9E53F083E40CAA31B6151554D40151DC9E53F083E40D1402C9B39544D40FB5DD89AAD043E40D1402C9B39544D40
66348	6096	30.652906999999999	30.660309000000002	58.927090999999997	58.921145000000003	Центральная	0103000020E610000001000000050000005854C4E924A73E40DDEF5014E8754D405854C4E924A73E403DB5FAEAAA764D402541B8020AA93E403DB5FAEAAA764D402541B8020AA93E40DDEF5014E8754D405854C4E924A73E40DDEF5014E8754D40
66153	6586	30.037686999999998	30.056363000000001	58.985505000000003	58.976818999999999	1-а	0103000020E61000000100000005000000FE7BF0DAA5093E40438EAD67087D4D40FE7BF0DAA5093E40B2852007257E4D4057B439CE6D0E3E40B2852007257E4D4057B439CE6D0E3E40438EAD67087D4D40FE7BF0DAA5093E40438EAD67087D4D40
66553	2180	29.077289	29.108208999999999	59.020667000000003	59.004182	Ленина	0103000020E610000001000000050000002E573F36C9133D40AE9D280989804D402E573F36C9133D40A08D5C37A5824D400322C495B31B3D40A08D5C37A5824D400322C495B31B3D40AE9D280989804D402E573F36C9133D40AE9D280989804D40
67265	1789	30.325192999999999	30.359373999999999	58.829192999999997	58.806725	Комсомола	0103000020E610000001000000050000005CE333D93F533E40CCEEC9C342674D405CE333D93F533E403B8908FF226A4D405F0839EFFF5B3E403B8908FF226A4D405F0839EFFF5B3E40CCEEC9C342674D405CE333D93F533E40CCEEC9C342674D40
67290	6416	29.976161000000001	30.103767000000001	59.067762000000002	59.023659000000002	Пролетарская	0103000020E6100000010000000500000073A1F2AFE5F93D40C7A0134207834D4073A1F2AFE5F93D40AEF4DA6CAC884D406F675F79901A3E40AEF4DA6CAC884D406F675F79901A3E40C7A0134207834D4073A1F2AFE5F93D40C7A0134207834D40
802	1097	29.845627	29.852354999999999	58.735374999999998	58.718594000000003	улица Красной Артиллерии	0103000020E61000000100000005000000569DD5027BD83D40098D60E3FA5B4D40569DD5027BD83D40E3A59BC4205E4D400395F1EF33DA3D40E3A59BC4205E4D400395F1EF33DA3D40098D60E3FA5B4D40569DD5027BD83D40098D60E3FA5B4D40
1117	1097	29.839410999999998	29.854358999999999	58.749954000000002	58.718761999999998	проспект Урицкого	0103000020E6100000010000000500000014E7A8A3E3D63D40C4CDA964005C4D4014E7A8A3E3D63D4090C01F7EFE5F4D40130B7C45B7DA3D4090C01F7EFE5F4D40130B7C45B7DA3D40C4CDA964005C4D4014E7A8A3E3D63D40C4CDA964005C4D40
284	1097	29.841612000000001	29.858518	58.751531999999997	58.717987000000001	проспект Кирова	0103000020E61000000100000005000000D1EB4FE273D73D4001FA7DFFE65B4D40D1EB4FE273D73D40E0F2583332604D40FF06EDD5C7DB3D40E0F2583332604D40FF06EDD5C7DB3D4001FA7DFFE65B4D40D1EB4FE273D73D4001FA7DFFE65B4D40
831	1097	29.839760999999999	29.850514	58.735608999999997	58.710925000000003	проспект Володарского	0103000020E61000000100000005000000CD74AF93FAD63D4054742497FF5A4D40CD74AF93FAD63D4056D28A6F285E4D4047CA1649BBD93D4056D28A6F285E4D4047CA1649BBD93D4054742497FF5A4D40CD74AF93FAD63D4054742497FF5A4D40
67512	1097	29.830131000000002	29.842986	58.755934000000003	58.724421	Смоленская 	0103000020E610000001000000050000005265187783D43D408FC4CBD3B95C4D405265187783D43D409DF7FF71C2604D4061FC34EECDD73D409DF7FF71C2604D4061FC34EECDD73D408FC4CBD3B95C4D405265187783D43D408FC4CBD3B95C4D40
67565	1097	29.830131000000002	29.842986	58.755934000000003	58.724421	Смоленская	0103000020E610000001000000050000005265187783D43D408FC4CBD3B95C4D405265187783D43D409DF7FF71C2604D4061FC34EECDD73D409DF7FF71C2604D4061FC34EECDD73D408FC4CBD3B95C4D405265187783D43D408FC4CBD3B95C4D40
67620	1097	29.812999999999999	29.843543	58.743805000000002	58.738886999999998	Свободы	0103000020E61000000100000005000000E3A59BC420D03D40433866D9935E4D40E3A59BC420D03D40F7CC9200355F4D400DC51D6FF2D73D40F7CC9200355F4D400DC51D6FF2D73D40433866D9935E4D40E3A59BC420D03D40433866D9935E4D40
299	1097	29.826941999999999	29.839797000000001	58.752702999999997	58.721729000000003	Нижегородская улица	0103000020E6100000010000000500000057B08D78B2D33D4093C9A99D615C4D4057B08D78B2D33D40F04C689258604D406747AAEFFCD63D40F04C689258604D406747AAEFFCD63D4093C9A99D615C4D4057B08D78B2D33D4093C9A99D615C4D40
67439	1097	29.826241	29.83155	58.708041000000001	58.706296999999999	Мелиораторов	0103000020E61000000100000005000000459DB98784D33D40A721AAF0675A4D40459DB98784D33D40139D6516A15A4D4022FDF675E0D43D40139D6516A15A4D4022FDF675E0D43D40A721AAF0675A4D40459DB98784D33D40A721AAF0675A4D40
67355	1097	29.845627	29.852354999999999	58.735374999999998	58.718594000000003	Красной Артиллерии	0103000020E61000000100000005000000569DD5027BD83D40098D60E3FA5B4D40569DD5027BD83D40E3A59BC4205E4D400395F1EF33DA3D40E3A59BC4205E4D400395F1EF33DA3D40098D60E3FA5B4D40569DD5027BD83D40098D60E3FA5B4D40
67610	1097	29.837433999999998	29.848303999999999	58.754193000000001	58.728274999999996	Красноармейская	0103000020E61000000100000005000000F78E1A1362D63D4048BF7D1D385D4D40F78E1A1362D63D40A2EF6E6589604D40E41071732AD93D40A2EF6E6589604D40E41071732AD93D4048BF7D1D385D4D40F78E1A1362D63D4048BF7D1D385D4D40
760	1097	29.853344	29.877634	58.737126000000004	58.731704000000001	Комсомольский проспект	0103000020E61000000100000005000000E23C9CC074DA3D401B2D077AA85D4D40E23C9CC074DA3D4002840F255A5E4D4090DB2F9FACE03D4002840F255A5E4D4090DB2F9FACE03D401B2D077AA85D4D40E23C9CC074DA3D401B2D077AA85D4D40
67185	58988	30.089932999999998	30.115670000000001	58.821958000000002	58.816879999999998	микрорайон Центральный	0103000020E61000000100000005000000C7D45DD905173E40D4601A868F684D40C7D45DD905173E40C15774EB35694D40DA20938C9C1D3E40C15774EB35694D40DA20938C9C1D3E40D4601A868F684D40C7D45DD905173E40D4601A868F684D40
67434	1586	29.892519	29.908059999999999	58.729886999999998	58.723256999999997	Новая	0103000020E61000000100000005000000020F0C207CE43D4031CD74AF935C4D40020F0C207CE43D404563EDEF6C5D4D4046CEC29E76E83D404563EDEF6C5D4D4046CEC29E76E83D4031CD74AF935C4D40020F0C207CE43D4031CD74AF935C4D40
24362	1464	29.877911999999998	29.901592000000001	58.681874000000001	58.663198999999999	Центральная	0103000020E6100000010000000500000015C440D7BEE03D40B5DE6FB4E3544D4015C440D7BEE03D4011FFB0A547574D40D255BABBCEE63D4011FFB0A547574D40D255BABBCEE63D40B5DE6FB4E3544D4015C440D7BEE03D40B5DE6FB4E3544D40
67169	2061	29.291861000000001	29.31439	58.738686000000001	58.727148999999997	Школьная	0103000020E6100000010000000500000055FA0967B74A3D40D828EB37135D4D4055FA0967B74A3D40AC014A438D5E4D407F30F0DC7B503D40AC014A438D5E4D407F30F0DC7B503D40D828EB37135D4D4055FA0967B74A3D40D828EB37135D4D40
66007	2377	29.142479999999999	29.176749999999998	59.979303999999999	59.973289000000001	Ветеранов	0103000020E610000001000000050000008655BC9179243D403D47E4BB94FC4D408655BC9179243D40C66B5ED559FD4D406891ED7C3F2D3D40C66B5ED559FD4D406891ED7C3F2D3D403D47E4BB94FC4D408655BC9179243D403D47E4BB94FC4D40
67343	59039	29.637730000000001	29.643308000000001	59.917574000000002	59.916595000000001	Новая	0103000020E6100000010000000500000097ADF54542A33D40AC5626FC52F54D4097ADF54542A33D4078D4981073F54D40534145D5AFA43D4078D4981073F54D40534145D5AFA43D40AC5626FC52F54D4097ADF54542A33D40AC5626FC52F54D40
67267	59013	29.862012	29.881353000000001	59.842689	59.827165999999998	Центральная	0103000020E6100000010000000500000072C284D1ACDC3D407B2E5393E0E94D4072C284D1ACDC3D4077D9AF3BDDEB4D40433BA759A0E13D4077D9AF3BDDEB4D40433BA759A0E13D407B2E5393E0E94D4072C284D1ACDC3D407B2E5393E0E94D40
67349	59044	29.410789000000001	29.411380999999999	59.963290999999998	59.955584000000002	Степаняна	0103000020E610000001000000050000007A8EC87729693D405A4A969350FA4D407A8EC87729693D40FCC3961E4DFB4D401E32E54350693D40FCC3961E4DFB4D401E32E54350693D405A4A969350FA4D407A8EC87729693D405A4A969350FA4D40
66964	2942	29.847711	29.962067000000001	59.872371000000001	59.673074	Ропшинское шоссе	0103000020E610000001000000050000009F758D9603D93D40DAE4F04927D64D409F758D9603D93D404A7D59DAA9EF4D40938FDD054AF63D404A7D59DAA9EF4D40938FDD054AF63D40DAE4F04927D64D409F758D9603D93D40DAE4F04927D64D40
66271	3218	29.203206000000002	29.237818000000001	59.747366999999997	59.739341000000003	Школьная	0103000020E61000000100000005000000DA59F44E05343D40C5CBD3B9A2DE4D40DA59F44E05343D40088ECBB8A9DF4D406F66F4A3E13C3D40088ECBB8A9DF4D406F66F4A3E13C3D40C5CBD3B9A2DE4D40DA59F44E05343D40C5CBD3B9A2DE4D40
67348	2178	29.560385	29.568218000000002	59.945238000000003	59.942794999999997	Астанина	0103000020E61000000100000005000000412B3064758F3D4089EAAD81ADF84D40412B3064758F3D40DE770C8FFDF84D40A0FF1EBC76913D40DE770C8FFDF84D40A0FF1EBC76913D4089EAAD81ADF84D40412B3064758F3D4089EAAD81ADF84D40
67359	2410	30.038549	30.051970000000001	59.776069999999997	59.772460000000002	Садовая	0103000020E61000000100000005000000234BE658DE093E40EDBB22F8DFE24D40234BE658DE093E400FB4024356E34D40855FEAE74D0D3E400FB4024356E34D40855FEAE74D0D3E40EDBB22F8DFE24D40234BE658DE093E40EDBB22F8DFE24D40
67257	1354	33.696049000000002	33.715407999999996	60.751309999999997	60.739913000000001	Пионерская	0103000020E61000000100000005000000EEB4352218D9404050711C78B55E4E40EEB4352218D94040319413ED2A604E40FCA5457D92DB4040319413ED2A604E40FCA5457D92DB404050711C78B55E4E40EEB4352218D9404050711C78B55E4E40
67203	1888	33.745842000000003	33.766404999999999	60.395386999999999	60.386806999999997	Прудовая	0103000020E61000000100000005000000DBFD2AC077DF4040936E4BE482314E40DBFD2AC077DF4040BC218D0A9C324E40D53E1D8F19E24040BC218D0A9C324E40D53E1D8F19E24040936E4BE482314E40DBFD2AC077DF4040936E4BE482314E40
24344	1329	33.675396999999997	33.682772	60.756580999999997	60.753095000000002	Молодежная	0103000020E610000001000000050000008368AD6873D64040FCE3BD6A65604E408368AD6873D6404032E36DA5D7604E40F04FA91265D7404032E36DA5D7604E40F04FA91265D74040FCE3BD6A65604E408368AD6873D64040FCE3BD6A65604E40
67198	1444	34.090975	34.111635999999997	60.329382000000003	60.318778999999999	Центральная	0103000020E6100000010000000500000076E09C11A50B414067D311C0CD284E4076E09C11A50B41400FF27A30292A4E403387A4164A0E41400FF27A30292A4E403387A4164A0E414067D311C0CD284E4076E09C11A50B414067D311C0CD284E40
67415	59060	33.703577000000003	33.739607999999997	60.818821999999997	60.784923999999997	Кирова проспект	0103000020E61000000100000005000000E19BA6CF0EDA404039ECBE6378644E40E19BA6CF0EDA4040669FC728CF684E4013EE9579ABDE4040669FC728CF684E4013EE9579ABDE404039ECBE6378644E40E19BA6CF0EDA404039ECBE6378644E40
67533	59074	33.515729999999998	33.569180000000003	60.732348000000002	60.732137000000002	улица Титова	0103000020E6100000010000000500000075C8CD7003C2404085984BAAB65D4E4075C8CD7003C2404040A54A94BD5D4E40C6C4E6E3DAC8404040A54A94BD5D4E40C6C4E6E3DAC8404085984BAAB65D4E4075C8CD7003C2404085984BAAB65D4E40
67213	2145	33.086210000000001	33.093440999999999	60.473641999999998	60.465291000000001	Школьная	0103000020E61000000100000005000000494BE5ED088B4040C30FCEA78E3B4E40494BE5ED088B40408A01124DA03C4E40828DEBDFF58B40408A01124DA03C4E40828DEBDFF58B4040C30FCEA78E3B4E40494BE5ED088B4040C30FCEA78E3B4E40
67208	1700	33.813305999999997	33.886733999999997	60.415939000000002	60.397392000000004	Набережная	0103000020E61000000100000005000000FED137691AE8404095D8B5BDDD324E40FED137691AE84040C310397D3D354E402920ED7F80F14040C310397D3D354E402920ED7F80F1404095D8B5BDDD324E40FED137691AE8404095D8B5BDDD324E40
67216	1700	33.813305999999997	33.886733999999997	60.415939000000002	60.397392000000004	Лодейнопольское шоссе	0103000020E61000000100000005000000FED137691AE8404095D8B5BDDD324E40FED137691AE84040C310397D3D354E402920ED7F80F14040C310397D3D354E402920ED7F80F1404095D8B5BDDD324E40FED137691AE8404095D8B5BDDD324E40
67077	58946	31.858608	31.990409	59.924695	59.858466999999997	Волховская	0103000020E610000001000000050000007F15E0BBCDDB3F40FDD8243FE2ED4D407F15E0BBCDDB3F402AE3DF675CF64D4000AAB8718BFD3F402AE3DF675CF64D4000AAB8718BFD3F40FDD8243FE2ED4D407F15E0BBCDDB3F40FDD8243FE2ED4D40
62021	12357	31.029606999999999	31.082329000000001	59.762664000000001	59.733750000000001	Спортивная	0103000020E6100000010000000500000090BB085394073F4052B81E85EBDD4D4090BB085394073F4014EB54F99EE14D402C836A8313153F4014EB54F99EE14D402C836A8313153F4052B81E85EBDD4D4090BB085394073F4052B81E85EBDD4D40
67276	12357	31.029606999999999	31.082329000000001	59.762664000000001	59.733750000000001	Советский пр.	0103000020E6100000010000000500000090BB085394073F4052B81E85EBDD4D4090BB085394073F4014EB54F99EE14D402C836A8313153F4014EB54F99EE14D402C836A8313153F4052B81E85EBDD4D4090BB085394073F4052B81E85EBDD4D40
67338	11450	30.960688000000001	31.060894999999999	60.007843000000001	59.961215000000003	площадь Культуры	0103000020E61000000100000005000000DFA815A6EFF53E405BB6D61709FB4D40DFA815A6EFF53E405340DAFF00014E406B7D91D0960F3F405340DAFF00014E406B7D91D0960F3F405BB6D61709FB4D40DFA815A6EFF53E405BB6D61709FB4D40
67406	11450	31.031770999999999	31.045335999999999	59.975828	59.970533000000003	Хесина	0103000020E6100000010000000500000012F6ED2422083F402A58E36C3AFC4D4012F6ED2422083F40B34291EEE7FC4D40DA54DD239B0B3F40B34291EEE7FC4D40DA54DD239B0B3F402A58E36C3AFC4D4012F6ED2422083F402A58E36C3AFC4D40
67144	9510	31.766504000000001	31.795940999999999	59.879593	59.867981	Советская	0103000020E61000000100000005000000D1402C9B39C43F4052465C001AEF4D40D1402C9B39C43F403065E08096F04D40A88B14CAC2CB3F403065E08096F04D40A88B14CAC2CB3F4052465C001AEF4D40D1402C9B39C43F4052465C001AEF4D40
3563	12703	31.026229000000001	31.045309	59.941853000000002	59.937161000000003	улица Малоневский Канал	0103000020E61000000100000005000000F03499F1B6063F40180B43E4F4F74D40F03499F1B6063F40DB519CA38EF84D40E736E15E990B3F40DB519CA38EF84D40E736E15E990B3F40180B43E4F4F74D40F03499F1B6063F40180B43E4F4F74D40
3591	12703	31.025852	31.032696999999999	59.943643000000002	59.937544000000003	Красныйи проспект	0103000020E610000001000000050000004489963C9E063F40D047197101F84D404489963C9E063F40B70C384BC9F84D4064ADA1D45E083F40B70C384BC9F84D4064ADA1D45E083F40D047197101F84D404489963C9E063F40D047197101F84D40
67388	12703	31.029848999999999	31.035131	59.943778000000002	59.939523000000001	Затонная	0103000020E610000001000000050000007CD11E2FA4073F407F6B274A42F84D407CD11E2FA4073F409757AEB7CDF84D4066136058FE083F409757AEB7CDF84D4066136058FE083F407F6B274A42F84D407CD11E2FA4073F407F6B274A42F84D40
67466	12703	31.03885	31.041509000000001	59.938941999999997	59.938198	18-го Января	0103000020E610000001000000050000001973D712F2093F4018963FDF16F84D401973D712F2093F40A06B5F402FF84D405B7D7555A00A3F40A06B5F402FF84D405B7D7555A00A3F4018963FDF16F84D401973D712F2093F4018963FDF16F84D40
62013	12430	31.364578999999999	31.388276999999999	59.644213000000001	59.633043000000001	Новоселов	0103000020E61000000100000005000000F2CEA10C555D3F401AFB928D07D14D40F2CEA10C555D3F403B54539275D24D40FBC9181F66633F403B54539275D24D40FBC9181F66633F401AFB928D07D14D40F2CEA10C555D3F401AFB928D07D14D40
67600	12877	31.201741999999999	31.221568000000001	59.877457	59.868296999999998	Победы	0103000020E61000000100000005000000C93A1C5DA5333F40821B295B24EF4D40C93A1C5DA5333F40B952CF8250F04D4013D731AEB8383F40B952CF8250F04D4013D731AEB8383F40821B295B24EF4D40C93A1C5DA5333F40821B295B24EF4D40
67344	59041	31.056843000000001	31.086739000000001	59.912408999999997	59.903796	Лесная	0103000020E61000000100000005000000AC014A438D0E3F40B8205B96AFF34D40AC014A438D0E3F40BCC96FD1C9F44D40AA49F08634163F40BCC96FD1C9F44D40AA49F08634163F40B8205B96AFF34D40AC014A438D0E3F40B8205B96AFF34D40
22377	12960	31.421289999999999	31.461112	59.872819	59.863422999999997	Дорофеева	0103000020E61000000100000005000000C02154A9D96B3F409ECE15A584EE4D40C02154A9D96B3F40E9297288B8EF4D400CCB9F6F0B763F40E9297288B8EF4D400CCB9F6F0B763F409ECE15A584EE4D40C02154A9D96B3F409ECE15A584EE4D40
67180	12960	31.421289999999999	31.461112	59.872819	59.863422999999997	Братьев Пожарских	0103000020E61000000100000005000000C02154A9D96B3F409ECE15A584EE4D40C02154A9D96B3F40E9297288B8EF4D400CCB9F6F0B763F40E9297288B8EF4D400CCB9F6F0B763F409ECE15A584EE4D40C02154A9D96B3F409ECE15A584EE4D40
67080	58947	31.319717000000001	31.332194999999999	59.879407999999998	59.874972999999997	24 	0103000020E61000000100000005000000A9F92AF9D8513F4006F1811DFFEF4D40A9F92AF9D8513F409EEBFB7090F04D400CE544BB0A553F409EEBFB7090F04D400CE544BB0A553F4006F1811DFFEF4D40A9F92AF9D8513F4006F1811DFFEF4D40
67102	58963	30.855063999999999	30.933316000000001	59.815767000000001	59.801774999999999	Спортивная	0103000020E61000000100000005000000A8FC6B79E5DA3E400DE02D90A0E64D40A8FC6B79E5DA3E40F913950D6BE84D4063D520CCEDEE3E40F913950D6BE84D4063D520CCEDEE3E400DE02D90A0E64D40A8FC6B79E5DA3E400DE02D90A0E64D40
67513	14697	30.777135000000001	30.780736999999998	59.763452000000001	59.762424000000003	Комсомольская	0103000020E61000000100000005000000B493C151F2C63E40BFD7101C97E14D40B493C151F2C63E406C088ECBB8E14D40F3C64961DEC73E406C088ECBB8E14D40F3C64961DEC73E40BFD7101C97E14D40B493C151F2C63E40BFD7101C97E14D40
67410	14697	30.796368000000001	30.805648000000001	59.769587000000001	59.766587999999999	Железнодорожная 	0103000020E61000000100000005000000B894F3C5DECB3E40C6C03A8E1FE24D40B894F3C5DECB3E40A036AAD381E24D407B1684F23ECE3E40A036AAD381E24D407B1684F23ECE3E40C6C03A8E1FE24D40B894F3C5DECB3E40C6C03A8E1FE24D40
67335	14697	30.796368000000001	30.805648000000001	59.769587000000001	59.766587999999999	Железнодорожная	0103000020E61000000100000005000000B894F3C5DECB3E40C6C03A8E1FE24D40B894F3C5DECB3E40A036AAD381E24D407B1684F23ECE3E40A036AAD381E24D407B1684F23ECE3E40C6C03A8E1FE24D40B894F3C5DECB3E40C6C03A8E1FE24D40
67353	14697	30.77524	30.786989999999999	59.764436000000003	59.761558000000001	Дружбы	0103000020E61000000100000005000000118DEE2076C63E40EB0088BB7AE14D40118DEE2076C63E404AF1F109D9E14D406F47382D78C93E404AF1F109D9E14D406F47382D78C93E40EB0088BB7AE14D40118DEE2076C63E40EB0088BB7AE14D40
67401	14697	30.792829000000001	30.805648000000001	59.773496999999999	59.769587000000001	Гагарина	0103000020E61000000100000005000000055262D7F6CA3E40A036AAD381E24D40055262D7F6CA3E40ED461FF301E34D407B1684F23ECE3E40ED461FF301E34D407B1684F23ECE3E40A036AAD381E24D40055262D7F6CA3E40A036AAD381E24D40
67307	28422	31.328565999999999	31.356242999999999	59.902884999999998	59.893433999999999	Староладожский канал	0103000020E61000000100000005000000D993C0E61C543F403691990B5CF24D40D993C0E61C543F40448655BC91F34D40CE6DC2BD325B3F40448655BC91F34D40CE6DC2BD325B3F403691990B5CF24D40D993C0E61C543F403691990B5CF24D40
67138	28422	31.328565999999999	31.356242999999999	59.902884999999998	59.893433999999999	Комсомольский пр.	0103000020E61000000100000005000000D993C0E61C543F403691990B5CF24D40D993C0E61C543F40448655BC91F34D40CE6DC2BD325B3F40448655BC91F34D40CE6DC2BD325B3F403691990B5CF24D40D993C0E61C543F403691990B5CF24D40
67091	58956	31.328565999999999	31.356242999999999	59.902884999999998	59.893433999999999	Октябрская	0103000020E61000000100000005000000D993C0E61C543F403691990B5CF24D40D993C0E61C543F40448655BC91F34D40CE6DC2BD325B3F40448655BC91F34D40CE6DC2BD325B3F403691990B5CF24D40D993C0E61C543F403691990B5CF24D40
67097	58956	31.328565999999999	31.356242999999999	59.902884999999998	59.893433999999999	Волховское шоссе	0103000020E61000000100000005000000D993C0E61C543F403691990B5CF24D40D993C0E61C543F40448655BC91F34D40CE6DC2BD325B3F40448655BC91F34D40CE6DC2BD325B3F403691990B5CF24D40D993C0E61C543F403691990B5CF24D40
67270	59014	31.029606999999999	31.082329000000001	59.762664000000001	59.733750000000001	Комсомольский пр.	0103000020E6100000010000000500000090BB085394073F4052B81E85EBDD4D4090BB085394073F4014EB54F99EE14D402C836A8313153F4014EB54F99EE14D402C836A8313153F4052B81E85EBDD4D4090BB085394073F4052B81E85EBDD4D40
67165	277	31.570499999999999	31.597351	59.957389999999997	59.938743000000002	Староладожский канал	0103000020E61000000100000005000000355EBA490C923F40AA2C0ABB28F84D40355EBA490C923F403BC269C18BFA4D409F3BC1FEEB983F403BC269C18BFA4D409F3BC1FEEB983F40AA2C0ABB28F84D40355EBA490C923F40AA2C0ABB28F84D40
67303	84	31.731342999999999	31.746569999999998	59.882522999999999	59.876801999999998	Плитная	0103000020E6100000010000000500000095287B4B39BB3F40A088450C3BF04D4095287B4B39BB3F40E17B7F83F6F04D40BA2C26361FBF3F40E17B7F83F6F04D40BA2C26361FBF3F40A088450C3BF04D4095287B4B39BB3F40A088450C3BF04D40
3539	12502	30.993755	30.995677000000001	59.879787	59.871622000000002	улица Горького	0103000020E610000001000000050000008A3C49BA66FE3E40B03C484F91EF4D408A3C49BA66FE3E40153944DC9CF04D40206118B0E4FE3E40153944DC9CF04D40206118B0E4FE3E40B03C484F91EF4D408A3C49BA66FE3E40B03C484F91EF4D40
7204	12502	30.983854999999998	30.997347999999999	59.882198000000002	59.879384999999999	Новая улица	0103000020E610000001000000050000008E01D9EBDDFB3E40E6CB0BB08FF04D408E01D9EBDDFB3E405E4C33DDEBF04D4023BBD23252FF3E405E4C33DDEBF04D4023BBD23252FF3E40E6CB0BB08FF04D408E01D9EBDDFB3E40E6CB0BB08FF04D40
67363	12502	30.951461999999999	30.989757000000001	59.890048999999998	59.847828	Набережная	0103000020E6100000010000000500000002637D0393F33E400951BEA085EC4D4002637D0393F33E40336B2920EDF14D40B1FCF9B660FD3E40336B2920EDF14D40B1FCF9B660FD3E400951BEA085EC4D4002637D0393F33E400951BEA085EC4D40
67624	12502	30.981017000000001	31.001533999999999	59.875067999999999	59.870086000000001	Кирова	0103000020E61000000100000005000000EED11BEE23FB3E408E5A61FA5EEF4D40EED11BEE23FB3E4058E36C3A02F04D4002D53F8864003F4058E36C3A02F04D4002D53F8864003F408E5A61FA5EEF4D40EED11BEE23FB3E408E5A61FA5EEF4D40
66512	14403	32.072101000000004	32.092843999999999	59.625317000000003	59.602649999999997	Новая	0103000020E610000001000000050000002481069B3A0940409A779CA223CD4D402481069B3A094040015130630AD04D409ED0EB4FE20B4040015130630AD04D409ED0EB4FE20B40409A779CA223CD4D402481069B3A0940409A779CA223CD4D40
66000	30155	32.674557	32.687043000000003	59.249473000000002	59.243476999999999	Центральная	0103000020E61000000100000005000000D9243FE257564040022A1C412A9F4D40D9243FE257564040151E34BBEE9F4D400EF96706F1574040151E34BBEE9F4D400EF96706F1574040022A1C412A9F4D40D9243FE257564040022A1C412A9F4D40
65106	14375	32.319344999999998	32.369767000000003	59.364702999999999	59.35087	Клубная	0103000020E610000001000000050000001092054CE0284040E292E34EE9AC4D401092054CE028404065E08096AEAE4D40ED116A86542F404065E08096AEAE4D40ED116A86542F4040E292E34EE9AC4D401092054CE0284040E292E34EE9AC4D40
67293	59025	32.101737	32.109336999999996	59.565142000000002	59.556749000000003	Героев	0103000020E6100000010000000500000086E5CFB7050D4040558A1D8D43C74D4086E5CFB7050D40404BCCB39256C84D40129F3BC1FE0D40404BCCB39256C84D40129F3BC1FE0D4040558A1D8D43C74D4086E5CFB7050D4040558A1D8D43C74D40
67162	30228	32.471150999999999	32.480718000000003	59.317878999999998	59.313488999999997	Центральная 	0103000020E61000000100000005000000253D0CAD4E3C4040EF53556820A84D40253D0CAD4E3C4040E78A5242B0A84D409D4CDC2A883D4040E78A5242B0A84D409D4CDC2A883D4040EF53556820A84D40253D0CAD4E3C4040EF53556820A84D40
24377	14502	31.796866999999999	31.821650999999999	59.383851	59.371758999999997	Центральная	0103000020E61000000100000005000000FA42C879FFCB3F40307F85CC95AF4D40FA42C879FFCB3F40B9C4910722B14D40C7B94DB857D23F40B9C4910722B14D40C7B94DB857D23F40307F85CC95AF4D40FA42C879FFCB3F40307F85CC95AF4D40
67278	30206	32.519677999999999	32.545675000000003	59.355699999999999	59.348300999999999	Песочная	0103000020E61000000100000005000000B03907CF8442404001158E2095AC4D40B03907CF84424040F697DD9387AD4D40569FABADD8454040F697DD9387AD4D40569FABADD845404001158E2095AC4D40B03907CF8442404001158E2095AC4D40
3991	13736	32.008384	32.015822	59.457095000000002	59.438912000000002	проспект Ленина	0103000020E61000000100000005000000A3E716BA1201404036E9B6442EB84D40A3E716BA120140402315C61682BA4D4056478E74060240402315C61682BA4D4056478E740602404036E9B6442EB84D40A3E716BA1201404036E9B6442EB84D40
67212	13736	31.984031000000002	32.104422999999997	59.514085999999999	59.430062	площадь 60-летия Октября	0103000020E610000001000000050000000C40A374E9FB3F404DA088450CB74D400C40A374E9FB3F406DAAEE91CDC14D40A0F99CBB5D0D40406DAAEE91CDC14D40A0F99CBB5D0D40404DA088450CB74D400C40A374E9FB3F404DA088450CB74D40
67519	13736	32.024239000000001	32.040373000000002	59.450518000000002	59.438975999999997	Энергетиков	0103000020E61000000100000005000000D52478431A0340404CDD955D30B84D40D52478431A0340403221E692AAB94D401A5245F12A0540403221E692AAB94D401A5245F12A0540404CDD955D30B84D40D52478431A0340404CDD955D30B84D40
67384	13736	32.005087000000003	32.028219	59.450788000000003	59.446406000000003	Советская	0103000020E610000001000000050000004051D9B0A60040407D5EF1D423B94D404051D9B0A6004040F2B6D26BB3B94D401B1021AE9C034040F2B6D26BB3B94D401B1021AE9C0340407D5EF1D423B94D404051D9B0A60040407D5EF1D423B94D40
3889	13736	32.004800000000003	32.014761999999997	59.453792999999997	59.441299999999998	Молодёжный бульвар	0103000020E61000000100000005000000AA8251499D004040C6DCB5847CB84D40AA8251499D004040AD1397E315BA4D409D9CA1B8E3014040AD1397E315BA4D409D9CA1B8E3014040C6DCB5847CB84D40AA8251499D004040C6DCB5847CB84D40
67614	13736	32.023313999999999	32.026206999999999	59.455041000000001	59.449553000000002	Комсомольская	0103000020E61000000100000005000000FCC401F4FB024040CB68E4F38AB94D40FCC401F4FB02404069AB92C83EBA4D4090F63FC05A03404069AB92C83EBA4D4090F63FC05A034040CB68E4F38AB94D40FCC401F4FB024040CB68E4F38AB94D40
67605	13736	32.014816000000003	32.021940000000001	59.450581999999997	59.437393	Декабристов Бестужевых	0103000020E6100000010000000500000091BA9D7DE5014040EA3F6B7EFCB74D4091BA9D7DE50140404815C5ABACB94D40B43C0FEECE0240404815C5ABACB94D40B43C0FEECE024040EA3F6B7EFCB74D4091BA9D7DE5014040EA3F6B7EFCB74D40
3907	13736	32.000855999999999	32.009363	59.457255000000004	59.443181000000003	Волховская набережная	0103000020E61000000100000005000000B000A60C1C004040B39AAE27BAB84D40B000A60C1C0040405C77F35487BA4D406F6589CE320140405C77F35487BA4D406F6589CE32014040B39AAE27BAB84D40B000A60C1C004040B39AAE27BAB84D40
67186	58991	32.397677999999999	32.407091999999999	59.222104000000002	59.210718	Центральная	0103000020E610000001000000050000005A2BDA1CE7324040DA56B3CEF89A4D405A2BDA1CE7324040C82764E76D9C4D404B3B35971B344040C82764E76D9C4D404B3B35971B344040DA56B3CEF89A4D405A2BDA1CE7324040DA56B3CEF89A4D40
67135	58971	32.114978000000001	32.134219999999999	59.635854000000002	59.623311000000001	Песочная	0103000020E6100000010000000500000037E15E99B70E4040581EA4A7C8CF4D4037E15E99B70E4040F183F3A963D14D400C3CF71E2E114040F183F3A963D14D400C3CF71E2E114040581EA4A7C8CF4D4037E15E99B70E4040581EA4A7C8CF4D40
67329	59033	32.405520000000003	32.494759000000002	59.293869000000001	59.276145	Советская	0103000020E61000000100000005000000DDEF5014E83340401AFA27B858A34D40DDEF5014E83340407427D87F9DA54D406A334E43543F40407427D87F9DA54D406A334E43543F40401AFA27B858A34D40DDEF5014E83340401AFA27B858A34D40
67496	59033	32.405520000000003	32.494759000000002	59.293869000000001	59.276145	Исполкомская	0103000020E61000000100000005000000DDEF5014E83340401AFA27B858A34D40DDEF5014E83340407427D87F9DA54D406A334E43543F40407427D87F9DA54D406A334E43543F40401AFA27B858A34D40DDEF5014E83340401AFA27B858A34D40
67214	15830	28.245072	28.295449000000001	59.670769999999997	59.644218000000002	квартал Ленрыба	0103000020E61000000100000005000000522AE109BD3E3C404DBF44BC75D24D40522AE109BD3E3C40A79196CADBD54D40CBA2B08BA24B3C40A79196CADBD54D40CBA2B08BA24B3C404DBF44BC75D24D40522AE109BD3E3C404DBF44BC75D24D40
67370	59049	28.370512000000002	28.398675000000001	59.435676999999998	59.423718000000001	Парковая	0103000020E610000001000000050000008BC6DADFD95E3C40FF5C34643CB64D408BC6DADFD95E3C40484F9143C4B74D4099BB96900F663C40484F9143C4B74D4099BB96900F663C40FF5C34643CB64D408BC6DADFD95E3C40FF5C34643CB64D40
5224	15461	28.609743000000002	28.617621	59.390582999999999	59.388469999999998	улица Ковалевского	0103000020E6100000010000000500000006F7031E189C3C4012BD8C62B9B14D4006F7031E189C3C40D1AFAD9FFEB14D40A452EC681C9E3C40D1AFAD9FFEB14D40A452EC681C9E3C4012BD8C62B9B14D4006F7031E189C3C4012BD8C62B9B14D40
6309	15461	28.601109999999998	28.60782	59.375289000000002	59.370448000000003	улица Иванова	0103000020E610000001000000050000006E4C4F58E2993C402F6F0ED76AAF4D406E4C4F58E2993C4037C64E7809B04D40CFDA6D179A9B3C4037C64E7809B04D40CFDA6D179A9B3C402F6F0ED76AAF4D406E4C4F58E2993C402F6F0ED76AAF4D40
4339	15461	28.592441000000001	28.633161999999999	59.382165000000001	59.369777999999997	проспект Карла Маркса	0103000020E610000001000000050000003ECF9F36AA973C40E063B0E254AF4D403ECF9F36AA973C40825660C8EAB04D40E811A3E716A23C40825660C8EAB04D40E811A3E716A23C40E063B0E254AF4D403ECF9F36AA973C40E063B0E254AF4D40
67171	15461	28.559616999999999	28.664369000000001	59.398297999999997	59.327373999999999	Школьная	0103000020E610000001000000050000001F49490F438F3C40C5C72764E7A94D401F49490F438F3C40F607CA6DFBB24D40EA79371614AA3C40F607CA6DFBB24D40EA79371614AA3C40C5C72764E7A94D401F49490F438F3C40C5C72764E7A94D40
67437	15461	28.598980999999998	28.615708000000001	59.378456999999997	59.371026000000001	Октябрьская	0103000020E61000000100000005000000E5EC9DD156993C409CFBABC77DAF4D40E5EC9DD156993C409CF86A4771B04D40B5E21B0A9F9D3C409CF86A4771B04D40B5E21B0A9F9D3C409CFBABC77DAF4D40E5EC9DD156993C409CFBABC77DAF4D40
5307	15461	28.596662999999999	28.601388	59.372872999999998	59.369416000000001	Железнодорожная улица	0103000020E61000000100000005000000B6BB07E8BE983C40404F030649AF4D40B6BB07E8BE983C40DC476E4DBAAF4D40F4346090F4993C40DC476E4DBAAF4D40F4346090F4993C40404F030649AF4D40B6BB07E8BE983C40404F030649AF4D40
4357	15461	28.61692	28.624179000000002	59.391255999999998	59.384241000000003	Восточная улица	0103000020E61000000100000005000000923F1878EE9D3C40246420CF2EB14D40923F1878EE9D3C40902E36AD14B24D4099D9E731CA9F3C40902E36AD14B24D4099D9E731CA9F3C40246420CF2EB14D40923F1878EE9D3C40246420CF2EB14D40
5335	15461	28.601388	28.616579000000002	59.382252000000001	59.372872999999998	Большая Советская улица	0103000020E61000000100000005000000F4346090F4993C40DC476E4DBAAF4D40F4346090F4993C40516A2FA2EDB04D408066101FD89D3C40516A2FA2EDB04D408066101FD89D3C40DC476E4DBAAF4D40F4346090F4993C40DC476E4DBAAF4D40
65036	15461	28.601388	28.616579000000002	59.382252000000001	59.372872999999998	Большая Советская	0103000020E61000000100000005000000F4346090F4993C40DC476E4DBAAF4D40F4346090F4993C40516A2FA2EDB04D408066101FD89D3C40516A2FA2EDB04D408066101FD89D3C40DC476E4DBAAF4D40F4346090F4993C40DC476E4DBAAF4D40
67543	15461	28.607559999999999	28.610982	59.384363999999998	59.379547000000002	 Химиков	0103000020E61000000100000005000000965B5A0D899B3C40C02500FF94B04D40965B5A0D899B3C403FE1ECD632B14D40D671FC50699C3C403FE1ECD632B14D40D671FC50699C3C40C02500FF94B04D40965B5A0D899B3C40C02500FF94B04D40
67515	59070	28.594085	28.604775	59.373336000000002	59.368980999999998	Театральная 	0103000020E610000001000000050000004E0B5EF415983C4035ECF7C43AAF4D404E0B5EF415983C40B1355B79C9AF4D403B70CE88D29A3C40B1355B79C9AF4D403B70CE88D29A3C4035ECF7C43AAF4D404E0B5EF415983C4035ECF7C43AAF4D40
67453	16226	28.214331000000001	28.219550999999999	59.376275	59.361823000000001	Юрия Гагарина	0103000020E61000000100000005000000DC847B65DE363C4066F84F3750AE4D40DC847B65DE363C40B5A679C729B04D40D9CD8C7E34383C40B5A679C729B04D40D9CD8C7E34383C4066F84F3750AE4D40DC847B65DE363C4066F84F3750AE4D40
67538	16226	28.228515999999999	28.228919999999999	59.380963999999999	59.378405999999998	Восточная 	0103000020E61000000100000005000000DC9C4A06803A3C401A4E999B6FB04D40DC9C4A06803A3C40077AA86DC3B04D407B6649809A3A3C40077AA86DC3B04D407B6649809A3A3C401A4E999B6FB04D40DC9C4A06803A3C401A4E999B6FB04D40
67000	15907	28.471841999999999	28.486098999999999	59.786490999999998	59.772917	Ижорская	0103000020E6100000010000000500000015E126A3CA783C40DFC2BAF1EEE24D4015E126A3CA783C4096CCB1BCABE44D40499EEBFB707C3C4096CCB1BCABE44D40499EEBFB707C3C40DFC2BAF1EEE24D4015E126A3CA783C40DFC2BAF1EEE24D40
66399	24353	28.175362	28.198135000000001	59.595140999999998	59.570990000000002	микрорайон Центральный	0103000020E610000001000000050000000EF62686E42C3C40E92B483316C94D400EF62686E42C3C401EC18D942DCC4D406631B1F9B8323C401EC18D942DCC4D406631B1F9B8323C40E92B483316C94D400EF62686E42C3C40E92B483316C94D40
67275	59016	29.576591000000001	30.686091000000001	59.622655000000002	59.013782999999997	Введенского	0103000020E61000000100000005000000FE2AC0779B933D40D11E2FA4C3814D40FE2AC0779B933D406FD8B628B3CF4D407714E7A8A3AF3E406FD8B628B3CF4D407714E7A8A3AF3E40D11E2FA4C3814D40FE2AC0779B933D40D11E2FA4C3814D40
67149	19042	29.830562	29.856703	59.501666	59.491886999999998	им. Алексея Рыкунова	0103000020E61000000100000005000000E44C13B69FD43D40ED293927F6BE4D40E44C13B69FD43D40F0C16B9736C04D40956247E350DB3D40F0C16B9736C04D40956247E350DB3D40ED293927F6BE4D40E44C13B69FD43D40ED293927F6BE4D40
66269	47677	30.265895	30.273098999999998	59.158695000000002	59.156204000000002	Лесная	0103000020E61000000100000005000000802BD9B111443E4090C01F7EFE934D40802BD9B111443E40F584251E50944D40FF91E9D0E9453E40F584251E50944D40FF91E9D0E9453E4090C01F7EFE934D40802BD9B111443E4090C01F7EFE934D40
67356	27090	29.898619	29.904799000000001	59.673701000000001	59.665579999999999	Ленинградская	0103000020E61000000100000005000000719010E50BE63D40936FB6B931D54D40719010E50BE63D40292499D53BD64D40197442E8A0E73D40292499D53BD64D40197442E8A0E73D40936FB6B931D54D40719010E50BE63D40936FB6B931D54D40
7928	25821	30.103866	30.126656000000001	59.668692999999998	59.662903999999997	Советская улица	0103000020E61000000100000005000000952A51F6961A3E409C31CC09DAD44D40952A51F6961A3E40350873BB97D54D4099D711876C203E40350873BB97D54D4099D711876C203E409C31CC09DAD44D40952A51F6961A3E409C31CC09DAD44D40
67391	59055	30.126207000000001	30.131902	59.667302999999997	59.659807999999998	Комсомольская	0103000020E61000000100000005000000BA86191A4F203E40D0D1AA9674D44D40BA86191A4F203E40E7C2482F6AD54D40E9465854C4213E40E7C2482F6AD54D40E9465854C4213E40D0D1AA9674D44D40BA86191A4F203E40D0D1AA9674D44D40
66130	18770	30.333987	30.391255000000001	59.497368000000002	59.485444999999999	Петровский пр.	0103000020E61000000100000005000000064A0A2C80553E40DC80CF0F23BE4D40064A0A2C80553E40D9092FC1A9BF4D408065A54929643E40D9092FC1A9BF4D408065A54929643E40DC80CF0F23BE4D40064A0A2C80553E40DC80CF0F23BE4D40
67277	3726	30.118058999999999	30.125093	59.468826999999997	59.460180999999999	Центральная	0103000020E610000001000000050000009BFF571D391E3E40CB9E0436E7BA4D409BFF571D391E3E40AB3DEC8502BC4D4062F5471806203E40AB3DEC8502BC4D4062F5471806203E40CB9E0436E7BA4D409BFF571D391E3E40CB9E0436E7BA4D40
176	357	30.017088000000001	30.060009999999998	59.350572	59.343552000000003	проспект Героев	0103000020E61000000100000005000000702711E15F043E40DA3C0E83F9AB4D40702711E15F043E405872158BDFAC4D40D66EBBD05C0F3E405872158BDFAC4D40D66EBBD05C0F3E40DA3C0E83F9AB4D40702711E15F043E40DA3C0E83F9AB4D40
67385	357	30.061591	30.067430000000002	59.354782999999998	59.350535000000001	Строителей	0103000020E610000001000000050000005ABA826DC40F3E403B8DB454DEAC4D405ABA826DC40F3E40A016838769AD4D40F0C4AC1743113E40A016838769AD4D40F0C4AC1743113E403B8DB454DEAC4D405ABA826DC40F3E403B8DB454DEAC4D40
4794	357	30.066082999999999	30.082252	59.353856	59.338724999999997	Республиканский проспект	0103000020E6100000010000000500000052D2C3D0EA103E4036AB3E575BAB4D4052D2C3D0EA103E4027BF45274BAD4D40D50792770E153E4027BF45274BAD4D40D50792770E153E4036AB3E575BAB4D4052D2C3D0EA103E4036AB3E575BAB4D40
121	357	30.072856000000002	30.100407000000001	59.365721000000001	59.357098999999998	Красная улица	0103000020E610000001000000050000004051D9B0A6123E409737876BB5AD4D404051D9B0A6123E40EF3A1BF2CFAE4D401B4AED45B4193E40EF3A1BF2CFAE4D401B4AED45B4193E409737876BB5AD4D404051D9B0A6123E409737876BB5AD4D40
67005	357	30.086124000000002	30.105519000000001	59.373193999999998	59.364547000000002	Кезевская дорога	0103000020E610000001000000050000009566F3380C163E406E6DE179A9AE4D409566F3380C163E401E882CD2C4AF4D404C1B0E4B031B3E401E882CD2C4AF4D404C1B0E4B031B3E406E6DE179A9AE4D409566F3380C163E406E6DE179A9AE4D40
167	357	30.066908999999999	30.074805000000001	59.364226000000002	59.357764000000003	Заводская улица	0103000020E61000000100000005000000DDCEBEF220113E40D4D7F335CBAD4D40DDCEBEF220113E402C2D23F59EAE4D40C993A46B26133E402C2D23F59EAE4D40C993A46B26133E40D4D7F335CBAD4D40DDCEBEF220113E40D4D7F335CBAD4D40
66547	357	30.110009999999999	30.119433000000001	59.362914000000004	59.359997999999997	Достоевского	0103000020E61000000100000005000000A33B889D291C3E400D501A6A14AE4D40A33B889D291C3E405AA148F773AE4D402C103D29931E3E405AA148F773AE4D402C103D29931E3E400D501A6A14AE4D40A33B889D291C3E400D501A6A14AE4D40
4782	357	30.091819000000001	30.099114	59.352553	59.341281000000002	Восточная улица	0103000020E61000000100000005000000C426327381173E4083DF8618AFAB4D40C426327381173E40A88DEA7420AD4D406493FC885F193E40A88DEA7420AD4D406493FC885F193E4083DF8618AFAB4D40C426327381173E4083DF8618AFAB4D40
67118	357	30.074805000000001	30.091756	59.374037999999999	59.364226000000002	Большой проспект	0103000020E61000000100000005000000C993A46B26133E402C2D23F59EAE4D40C993A46B26133E400ABB287AE0AF4D4037363B527D173E400ABB287AE0AF4D4037363B527D173E402C2D23F59EAE4D40C993A46B26133E402C2D23F59EAE4D40
67376	357	30.066890999999998	30.069334000000001	59.357764000000003	59.355181999999999	123-й Дивизии	0103000020E610000001000000050000009065C1C41F113E405E10919A76AD4D409065C1C41F113E40D4D7F335CBAD4D4039807EDFBF113E40D4D7F335CBAD4D4039807EDFBF113E405E10919A76AD4D409065C1C41F113E405E10919A76AD4D40
67058	22048	30.368203999999999	30.395655999999999	59.550328	59.526811000000002	Большой проспект	0103000020E61000000100000005000000A2410A9E425E3E402716F88A6EC34D40A2410A9E425E3E405B09DD2571C64D4057772CB649653E405B09DD2571C64D4057772CB649653E402716F88A6EC34D40A2410A9E425E3E402716F88A6EC34D40
66996	19124	29.923870000000001	29.957727999999999	59.334162999999997	59.306443000000002	Большой пр	0103000020E610000001000000050000006AC18BBE82EC3D40488B338639A74D406AC18BBE82EC3D4041446ADAC5AA4D40A77686A92DF53D4041446ADAC5AA4D40A77686A92DF53D40488B338639A74D406AC18BBE82EC3D40488B338639A74D40
24368	27032	30.035081999999999	30.06222	59.619965999999998	59.611795999999998	Половинкиной	0103000020E61000000100000005000000A3AD4A22FB083E406CE9D1544FCE4D40A3AD4A22FB083E40E350BF0B5BCF4D40392861A6ED0F3E40E350BF0B5BCF4D40392861A6ED0F3E406CE9D1544FCE4D40A3AD4A22FB083E406CE9D1544FCE4D40
66435	3913	30.129799999999999	30.154540000000001	59.543081000000001	59.533454999999996	Садовая	0103000020E610000001000000050000005305A3923A213E409F71E14048C44D405305A3923A213E401C0A9FAD83C54D4081ECF5EE8F273E401C0A9FAD83C54D4081ECF5EE8F273E409F71E14048C44D405305A3923A213E409F71E14048C44D40
67253	3822	30.082557999999999	30.091100999999998	59.438581999999997	59.427453	Школьная	0103000020E61000000100000005000000EE05668522153E40DEC9A7C7B6B64D40EE05668522153E40A04E797423B84D4005A2276552173E40A04E797423B84D4005A2276552173E40DEC9A7C7B6B64D40EE05668522153E40DEC9A7C7B6B64D40
67366	23030	30.073440000000002	30.083618000000001	59.568123	59.565866999999997	Покровская	0103000020E61000000100000005000000DF37BEF6CC123E405C7171546EC84D40DF37BEF6CC123E407E8D2441B8C84D40605B3FFD67153E407E8D2441B8C84D40605B3FFD67153E405C7171546EC84D40DF37BEF6CC123E405C7171546EC84D40
66989	26349	29.928720999999999	29.942349	59.546306000000001	59.539983999999997	пл. Усова	0103000020E61000000100000005000000C11BD2A8C0ED3D407F2E1A321EC54D40C11BD2A8C0ED3D40E6CDE15AEDC54D40166BB8C83DF13D40E6CDE15AEDC54D40166BB8C83DF13D407F2E1A321EC54D40C11BD2A8C0ED3D407F2E1A321EC54D40
24342	23316	30.338757000000001	30.407478000000001	59.247715999999997	59.217511999999999	Вокзальная	0103000020E61000000100000005000000844A5CC7B8563E40683EE76ED79B4D40844A5CC7B8563E4014596B28B59F4D40E9D66B7A50683E4014596B28B59F4D40E9D66B7A50683E40683EE76ED79B4D40844A5CC7B8563E40683EE76ED79B4D40
66971	18701	29.984956	30.013908000000001	59.470120999999999	59.445601000000003	Шипунова	0103000020E61000000100000005000000BDFF8F1326FC3D404F081D7409B94D40BDFF8F1326FC3D40D714C8EC2CBC4D401C2785798F033E40D714C8EC2CBC4D401C2785798F033E404F081D7409B94D40BDFF8F1326FC3D404F081D7409B94D40
67393	59056	30.388919000000001	30.391866	59.424052000000003	59.422528	Школьная	0103000020E6100000010000000500000004CB113290633E4078D2C26515B64D4004CB113290633E40D6E6FF5547B64D40126A865451643E40D6E6FF5547B64D40126A865451643E4078D2C26515B64D4004CB113290633E4078D2C26515B64D40
67305	26116	30.054718999999999	30.093373	59.547418999999998	59.534719000000003	Западная	0103000020E6100000010000000500000046787B10020E3E4061C614AC71C44D4046787B10020E3E40C11A67D311C64D405454FD4AE7173E40C11A67D311C64D405454FD4AE7173E4061C614AC71C44D4046787B10020E3E4061C614AC71C44D40
24398	22850	30.151745999999999	30.178345	59.618049999999997	59.609287999999999	Кутышева	0103000020E610000001000000050000007F4C6BD3D8263E4031EC3026FDCD4D407F4C6BD3D8263E407AA52C431CCF4D40B6679604A82D3E407AA52C431CCF4D40B6679604A82D3E4031EC3026FDCD4D407F4C6BD3D8263E4031EC3026FDCD4D40
65121	22953	30.291964	30.299033999999999	59.59892	59.595232000000003	Школьная	0103000020E61000000100000005000000FE9B1727BE4A3E402FC4EA8F30CC4D40FE9B1727BE4A3E40CD751A69A9CC4D405E64027E8D4C3E40CD751A69A9CC4D405E64027E8D4C3E402FC4EA8F30CC4D40FE9B1727BE4A3E402FC4EA8F30CC4D40
66379	3654	30.054755	30.077842	59.301375999999998	59.282097999999998	Совхозная	0103000020E61000000100000005000000E04A766C040E3E402D228AC91BA44D40E04A766C040E3E404FE61F7D93A64D4057410C74ED133E404FE61F7D93A64D4057410C74ED133E402D228AC91BA44D40E04A766C040E3E402D228AC91BA44D40
844	236	30.386268999999999	30.393661999999999	59.619529	59.617289999999997	Садовая улица	0103000020E6100000010000000500000068757286E2623E40EC12D55B03CF4D4068757286E2623E4038F6ECB94CCF4D408EAD6708C7643E4038F6ECB94CCF4D408EAD6708C7643E40EC12D55B03CF4D4068757286E2623E40EC12D55B03CF4D40
66969	236	30.368402	30.435873999999998	59.660913000000001	59.609997999999997	Просвещения	0103000020E61000000100000005000000EFC7ED974F5E3E400D501A6A14CE4D40EFC7ED974F5E3E40294014CC98D44D403C2D3F70956F3E40294014CC98D44D403C2D3F70956F3E400D501A6A14CE4D40EFC7ED974F5E3E400D501A6A14CE4D40
2478	236	30.392341999999999	30.393841999999999	59.628093	59.619529	Ленинградское шоссе	0103000020E61000000100000005000000E4D87A8670643E4038F6ECB94CCF4D40E4D87A8670643E405BECF65965D04D408ECA4DD4D2643E405BECF65965D04D408ECA4DD4D2643E4038F6ECB94CCF4D40E4D87A8670643E4038F6ECB94CCF4D40
67360	236	30.401288999999998	30.408197000000001	59.629702999999999	59.626677999999998	Ижорская	0103000020E610000001000000050000009A3E3BE0BA663E40B48F15FC36D04D409A3E3BE0BA663E40B7989F1B9AD04D4048533D997F683E40B7989F1B9AD04D4048533D997F683E40B48F15FC36D04D409A3E3BE0BA663E40B48F15FC36D04D40
67534	236	30.385370999999999	30.386268999999999	59.624625999999999	59.617289999999997	Гатчинская	0103000020E61000000100000005000000AAD381ACA7623E40EC12D55B03CF4D40AAD381ACA7623E409B1DA9BEF3CF4D4068757286E2623E409B1DA9BEF3CF4D4068757286E2623E40EC12D55B03CF4D40AAD381ACA7623E40EC12D55B03CF4D40
6526	236	30.414242999999999	30.423791999999999	59.659522000000003	59.631942000000002	Антропшинская улица	0103000020E61000000100000005000000D09849D40B6A3E40037CB779E3D04D40D09849D40B6A3E400B7F86376BD44D40724EECA17D6C3E400B7F86376BD44D40724EECA17D6C3E40037CB779E3D04D40D09849D40B6A3E40037CB779E3D04D40
67412	16946	30.113935999999999	30.13775	59.431731999999997	59.415230000000001	Центральная	0103000020E6100000010000000500000049D6E1E82A1D3E40B728B34126B54D4049D6E1E82A1D3E407E5182FE42B74D402506819543233E407E5182FE42B74D402506819543233E40B728B34126B54D4049D6E1E82A1D3E40B728B34126B54D40
66988	727	30.374528000000002	30.409040999999998	59.595191	59.579543000000001	Центральная	0103000020E61000000100000005000000B16F2711E15F3E4018D00B772ECA4D40B16F2711E15F3E40D0EFFB372FCC4D401FB935E9B6683E40D0EFFB372FCC4D401FB935E9B6683E4018D00B772ECA4D40B16F2711E15F3E4018D00B772ECA4D40
65744	3749	30.051988000000001	30.090337000000002	59.415436	59.401262000000003	Красная	0103000020E61000000100000005000000D2C8E7154F0D3E4054909F8D5CB34D40D2C8E7154F0D3E4060CAC0012DB54D40679E5C5320173E4060CAC0012DB54D40679E5C5320173E4054909F8D5CB34D40D2C8E7154F0D3E4054909F8D5CB34D40
67160	58984	29.658283000000001	29.682456999999999	59.606479	59.597932	Поселковая	0103000020E610000001000000050000004583143C85A83D40AE9D280989CC4D404583143C85A83D40FB5A971AA1CD4D4020ED7F80B5AE3D40FB5A971AA1CD4D4020ED7F80B5AE3D40AE9D280989CC4D404583143C85A83D40AE9D280989CC4D40
67130	18936	29.762945999999999	29.804798999999999	59.498441	59.487606	пл.Дружбы	0103000020E61000000100000005000000309DD66D50C33D40ACAA97DF69BE4D40309DD66D50C33D4026FE28EACCBF4D407FDAA84E07CE3D4026FE28EACCBF4D407FDAA84E07CE3D40ACAA97DF69BE4D40309DD66D50C33D40ACAA97DF69BE4D40
67054	18936	29.762945999999999	29.804798999999999	59.498441	59.487606	Парковая 	0103000020E61000000100000005000000309DD66D50C33D40ACAA97DF69BE4D40309DD66D50C33D4026FE28EACCBF4D407FDAA84E07CE3D4026FE28EACCBF4D407FDAA84E07CE3D40ACAA97DF69BE4D40309DD66D50C33D40ACAA97DF69BE4D40
24353	51010	30.114968999999999	30.150641	59.285817000000002	59.269731	Введенского	0103000020E61000000100000005000000C70DBF9B6E1D3E40D3DB9F8B86A24D40C70DBF9B6E1D3E4007D2C5A695A44D40CE6F986890263E4007D2C5A695A44D40CE6F986890263E40D3DB9F8B86A24D40C70DBF9B6E1D3E40D3DB9F8B86A24D40
67218	27150	30.000892	30.023215	59.222757000000001	59.198753000000004	Володарского	0103000020E61000000100000005000000FAD346753A003E40AF7D01BD70994D40FAD346753A003E4040FA264D839C4D40D2C6116BF1053E4040FA264D839C4D40D2C6116BF1053E40AF7D01BD70994D40FAD346753A003E40AF7D01BD70994D40
5894	867	30.11814	30.131516000000001	59.564202999999999	59.550373999999998	улица Чкалова	0103000020E6100000010000000500000075594C6C3E1E3E40CB48BDA772C64D4075594C6C3E1E3E400DA7CCCD37C84D4097E65608AB213E400DA7CCCD37C84D4097E65608AB213E40CB48BDA772C64D4075594C6C3E1E3E40CB48BDA772C64D40
257	867	30.065427	30.079664999999999	59.571522999999999	59.567903999999999	улица Михаила Рысева	0103000020E610000001000000050000008046E9D2BF103E4040A20914B1C84D408046E9D2BF103E40B6F468AA27C94D40C6A2E9EC64143E40B6F468AA27C94D40C6A2E9EC64143E4040A20914B1C84D408046E9D2BF103E4040A20914B1C84D40
5537	867	30.117097999999999	30.122226999999999	59.580736999999999	59.571263000000002	улица Коли Подрядчикова	0103000020E61000000100000005000000506D7022FA1D3E401A355F251FC94D40506D7022FA1D3E40E0490B9755CA4D402DB0C7444A1F3E40E0490B9755CA4D402DB0C7444A1F3E401A355F251FC94D40506D7022FA1D3E401A355F251FC94D40
6142	867	30.124804999999999	30.131398999999998	59.574294000000002	59.568514999999998	улица Киргетова	0103000020E6100000010000000500000095607138F31F3E4089247A19C5C84D4095607138F31F3E40FF243E7782C94D4023BA675DA3213E40FF243E7782C94D4023BA675DA3213E4089247A19C5C84D4095607138F31F3E4089247A19C5C84D40
321	867	30.122226999999999	30.129359999999998	59.584924000000001	59.579875999999999	улица Изотова	0103000020E610000001000000050000002DB0C7444A1F3E401EDE736039CA4D402DB0C7444A1F3E40A05225CADECA4D401A69A9BC1D213E40A05225CADECA4D401A69A9BC1D213E401EDE736039CA4D402DB0C7444A1F3E401EDE736039CA4D40
330	867	30.115947999999999	30.137264999999999	59.579393000000003	59.562963000000003	проспект 25-го Октября	0103000020E610000001000000050000005F09A4C4AE1D3E40D5EDEC2B0FC84D405F09A4C4AE1D3E400344C18C29CA4D40ACE28DCC23233E400344C18C29CA4D40ACE28DCC23233E40D5EDEC2B0FC84D405F09A4C4AE1D3E40D5EDEC2B0FC84D40
220	867	30.101997000000001	30.10754	59.551856000000001	59.547094999999999	Школьная улица	0103000020E61000000100000005000000454AB3791C1A3E400E677E3507C64D40454AB3791C1A3E40FA0CA837A3C64D400803CFBD871B3E40FA0CA837A3C64D400803CFBD871B3E400E677E3507C64D40454AB3791C1A3E400E677E3507C64D40
67487	867	30.11814	30.131516000000001	59.564202999999999	59.550373999999998	Чкалова	0103000020E6100000010000000500000075594C6C3E1E3E40CB48BDA772C64D4075594C6C3E1E3E400DA7CCCD37C84D4097E65608AB213E400DA7CCCD37C84D4097E65608AB213E40CB48BDA772C64D4075594C6C3E1E3E40CB48BDA772C64D40
67586	867	30.083950000000002	30.097819999999999	59.559027999999998	59.555754999999998	Слепнева	0103000020E61000000100000005000000CC7F48BF7D153E4053CBD6FA22C74D40CC7F48BF7D153E402EC6C03A8EC74D400CE544BB0A193E402EC6C03A8EC74D400CE544BB0A193E4053CBD6FA22C74D40CC7F48BF7D153E4053CBD6FA22C74D40
300	867	30.118013999999999	30.143329000000001	59.582058000000004	59.571362999999998	Рощинская улица	0103000020E610000001000000050000005B785E2A361E3E407D923B6C22C94D405B785E2A361E3E40063065E080CA4D4082919735B1243E40063065E080CA4D4082919735B1243E407D923B6C22C94D405B785E2A361E3E407D923B6C22C94D40
67442	867	30.112902999999999	30.118013999999999	59.582058000000004	59.570715999999997	Крупской	0103000020E61000000100000005000000CB9E0436E71C3E40E7A6CD380DC94D40CB9E0436E71C3E40063065E080CA4D405B785E2A361E3E40063065E080CA4D405B785E2A361E3E40E7A6CD380DC94D40CB9E0436E71C3E40E7A6CD380DC94D40
5908	867	30.083563999999999	30.112714	59.570967000000003	59.560094999999997	Красноармейский проспект	0103000020E61000000100000005000000791F477364153E4099D36531B1C74D40791F477364153E40310C587215C94D4025CD1FD3DA1C3E40310C587215C94D4025CD1FD3DA1C3E4099D36531B1C74D40791F477364153E4099D36531B1C74D40
67529	867	30.117097999999999	30.122226999999999	59.580736999999999	59.571263000000002	Коли Подрядчикова	0103000020E61000000100000005000000506D7022FA1D3E401A355F251FC94D40506D7022FA1D3E40E0490B9755CA4D402DB0C7444A1F3E40E0490B9755CA4D402DB0C7444A1F3E401A355F251FC94D40506D7022FA1D3E401A355F251FC94D40
67443	867	30.129638	30.138801000000001	59.570757	59.558686999999999	Володарского	0103000020E61000000100000005000000A051BAF42F213E40A5D93C0E83C74D40A051BAF42F213E40467BBC900EC94D40F0A65B7688233E40467BBC900EC94D40F0A65B7688233E40A5D93C0E83C74D40A051BAF42F213E40A5D93C0E83C74D40
67514	867	30.067133999999999	30.074428000000001	59.574480999999999	59.570729999999998	Беляева	0103000020E610000001000000050000001D739EB12F113E404C6C3EAE0DC94D401D739EB12F113E403196E99788C94D401DE8A1B60D133E403196E99788C94D401DE8A1B60D133E404C6C3EAE0DC94D401D739EB12F113E404C6C3EAE0DC94D40
67206	867	30.084893000000001	30.095753999999999	59.560783999999998	59.551755999999997	Авиатриссы Зверевой	0103000020E61000000100000005000000CAA8328CBB153E4096AFCBF09FC64D40CAA8328CBB153E405E0F26C5C7C74D4010768A5583183E405E0F26C5C7C74D4010768A5583183E4096AFCBF09FC64D40CAA8328CBB153E4096AFCBF09FC64D40
67192	18704	30.085172	30.110792	59.490684999999999	59.464987000000001	Большой пр.	0103000020E61000000100000005000000F0880AD5CD153E405708ABB184BB4D40F0880AD5CD153E40A2D11DC4CEBE4D408FA850DD5C1C3E40A2D11DC4CEBE4D408FA850DD5C1C3E405708ABB184BB4D40F0880AD5CD153E405708ABB184BB4D40
4830	8475	30.294685999999999	30.319524000000001	59.401330999999999	59.356718000000001	проспект Урицкого	0103000020E61000000100000005000000CC96AC8A704B3E4080F277EFA8AD4D40CC96AC8A704B3E407CEF6FD05EB34D4080492A53CC513E407CEF6FD05EB34D4080492A53CC513E4080F277EFA8AD4D40CC96AC8A704B3E4080F277EFA8AD4D40
3496	8475	30.294218999999998	30.296859999999999	59.396489000000003	59.391215000000003	Ушаковская улица	0103000020E61000000100000005000000A0DCB6EF514B3E40325A475513B24D40A0DCB6EF514B3E40A41CCC26C0B24D40957D5704FF4B3E40A41CCC26C0B24D40957D5704FF4B3E40325A475513B24D40A0DCB6EF514B3E40325A475513B24D40
4719	8475	30.285173	30.393716000000001	59.418512999999997	59.396095000000003	Сиверское шоссе	0103000020E61000000100000005000000C4B3041901493E40F88DAF3DB3B24D40C4B3041901493E40B5F97FD591B54D4075E95F92CA643E40B5F97FD591B54D4075E95F92CA643E40F88DAF3DB3B24D40C4B3041901493E40F88DAF3DB3B24D40
6121	8475	30.358888	30.367521	59.432524000000001	59.420513	Павловский проспект	0103000020E6100000010000000500000046ED7E15E05B3E407C45B75ED3B54D4046ED7E15E05B3E40185E49F25CB74D40DD9733DB155E3E40185E49F25CB74D40DD9733DB155E3E407C45B75ED3B54D4046ED7E15E05B3E407C45B75ED3B54D40
6141	8475	30.303121000000001	30.320008999999999	59.407583000000002	59.398330000000001	Майский проспект	0103000020E6100000010000000500000017BB7D56994D3E400282397AFCB24D4017BB7D56994D3E40EAB303AE2BB44D40F86C1D1CEC513E40EAB303AE2BB44D40F86C1D1CEC513E400282397AFCB24D4017BB7D56994D3E400282397AFCB24D40
67566	8475	30.344290999999998	30.353202	59.418402999999998	59.404367000000001	Жертв Революции	0103000020E61000000100000005000000A04E797423583E40734A404CC2B34D40A04E797423583E402EC6C03A8EB54D40BDE13E726B5A3E402EC6C03A8EB54D40BDE13E726B5A3E40734A404CC2B34D40A04E797423583E40734A404CC2B34D40
67418	8475	30.336790000000001	30.343249	59.416846	59.406858999999997	Ефимова	0103000020E61000000100000005000000AE9E93DE37563E40A88AA9F413B44D40AE9E93DE37563E40F5BBB0355BB54D407C629D2ADF573E40F5BBB0355BB54D407C629D2ADF573E40A88AA9F413B44D40AE9E93DE37563E40A88AA9F413B44D40
67570	8475	30.344290999999998	30.353202	59.418402999999998	59.404367000000001	 Жертв Революции	0103000020E61000000100000005000000A04E797423583E40734A404CC2B34D40A04E797423583E402EC6C03A8EB54D40BDE13E726B5A3E402EC6C03A8EB54D40BDE13E726B5A3E40734A404CC2B34D40A04E797423583E40734A404CC2B34D40
67196	26290	29.915272999999999	29.982925999999999	59.541224999999997	59.516596999999997	Молодежная 	0103000020E610000001000000050000006CE9D1544FEA3D40191BBAD91FC24D406CE9D1544FEA3D4088635DDC46C54D405A63D009A1FB3D4088635DDC46C54D405A63D009A1FB3D40191BBAD91FC24D406CE9D1544FEA3D40191BBAD91FC24D40
67447	59065	30.100434	30.110755999999999	59.660899000000001	59.657926000000003	Ягодная	0103000020E610000001000000050000000E68E90AB6193E4014984EEB36D44D400E68E90AB6193E40C47AA35698D44D40F5D555815A1C3E40C47AA35698D44D40F5D555815A1C3E4014984EEB36D44D400E68E90AB6193E4014984EEB36D44D40
66987	18668	30.057736999999999	30.089834	59.535080000000001	59.520243999999998	Садовая	0103000020E61000000100000005000000E7C41EDAC70E3E4059F8FA5A97C24D40E7C41EDAC70E3E40315F5E807DC44D40A1116C5CFF163E40315F5E807DC44D40A1116C5CFF163E4059F8FA5A97C24D40E7C41EDAC70E3E4059F8FA5A97C24D40
66578	18668	30.057736999999999	30.089834	59.535080000000001	59.520243999999998	30 лет Победы	0103000020E61000000100000005000000E7C41EDAC70E3E4059F8FA5A97C24D40E7C41EDAC70E3E40315F5E807DC44D40A1116C5CFF163E40315F5E807DC44D40A1116C5CFF163E4059F8FA5A97C24D40E7C41EDAC70E3E4059F8FA5A97C24D40
65128	18668	30.057736999999999	30.089834	59.535080000000001	59.520243999999998	 Садовая	0103000020E61000000100000005000000E7C41EDAC70E3E4059F8FA5A97C24D40E7C41EDAC70E3E40315F5E807DC44D40A1116C5CFF163E40315F5E807DC44D40A1116C5CFF163E4059F8FA5A97C24D40E7C41EDAC70E3E4059F8FA5A97C24D40
67435	59063	30.135109	30.135576	59.351103999999999	59.347732000000001	Институтская	0103000020E610000001000000050000003065E08096223E40E7E26F7B82AC4D403065E08096223E4055BFD2F9F0AC4D405C1FD61BB5223E4055BFD2F9F0AC4D405C1FD61BB5223E40E7E26F7B82AC4D403065E08096223E40E7E26F7B82AC4D40
67235	22775	29.418137000000002	29.435205	60.179364999999997	60.170817999999997	Военных строителей	0103000020E61000000100000005000000603FC4060B6B3D40B8C83D5DDD154E40603FC4060B6B3D400586AC6EF5164E40410E4A98696F3D400586AC6EF5164E40410E4A98696F3D40B8C83D5DDD154E40603FC4060B6B3D40B8C83D5DDD154E40
66973	5400	28.812546000000001	28.926812000000002	60.684426000000002	60.643121000000001	Железнодорожная	0103000020E61000000100000005000000E17EC00303D03C40772FF7C951524E40E17EC00303D03C401C446B459B574E40558A1D8D43ED3C401C446B459B574E40558A1D8D43ED3C40772FF7C951524E40E17EC00303D03C40772FF7C951524E40
67262	4795	29.550153000000002	29.576447000000002	60.402205000000002	60.386558000000001	Центральная	0103000020E61000000100000005000000DACBB6D3D68C3D40EB0088BB7A314E40DACBB6D3D68C3D40D3A414747B334E4098E0D40792933D40D3A414747B334E4098E0D40792933D40EB0088BB7A314E40DACBB6D3D68C3D40EB0088BB7A314E40
66551	21229	28.772275	28.801102	60.533777999999998	60.514983000000001	уд. Кленовая	0103000020E61000000100000005000000B6847CD0B3C53C407C7F83F6EA414E40B6847CD0B3C53C4082A966D652444E409CC24A0515CD3C4082A966D652444E409CC24A0515CD3C407C7F83F6EA414E40B6847CD0B3C53C407C7F83F6EA414E40
67167	11753	28.732209999999998	28.773002999999999	60.663119000000002	60.646155	Приморская	0103000020E61000000100000005000000DDCD531D72BB3C40CD920035B5524E40DDCD531D72BB3C40992D5915E1544E40BBB54C86E3C53C40992D5915E1544E40BBB54C86E3C53C40CD920035B5524E40DDCD531D72BB3C40CD920035B5524E40
67446	21154	28.662061000000001	28.682721999999998	60.533591999999999	60.524875999999999	Школьная	0103000020E6100000010000000500000002F566D47CA93C40473A03232F434E4002F566D47CA93C4020B41EBE4C444E407C4276DEC6AE3C4020B41EBE4C444E407C4276DEC6AE3C40473A03232F434E4002F566D47CA93C40473A03232F434E40
67286	21154	28.664656999999998	28.687483	60.542160000000003	60.529736	Советская	0103000020E61000000100000005000000B60E0EF626AA3C40C6C1A563CE434E40B60E0EF626AA3C408599B67F65454E40548EC9E2FEAF3C408599B67F65454E40548EC9E2FEAF3C40C6C1A563CE434E40B60E0EF626AA3C40C6C1A563CE434E40
67347	21154	28.666525	28.683557	60.539996000000002	60.530768000000002	Садовая	0103000020E6100000010000000500000066F7E461A1AA3C40B5E1B034F0434E4066F7E461A1AA3C4044FCC3961E454E40AEF36F97FDAE3C4044FCC3961E454E40AEF36F97FDAE3C40B5E1B034F0434E4066F7E461A1AA3C40B5E1B034F0434E40
65805	22502	29.291259	29.303726999999999	60.323020999999997	60.316119	Центральная	0103000020E6100000010000000500000069AA27F38F4A3D4076525F9676284E4069AA27F38F4A3D40EA758BC058294E4085E97B0DC14D3D40EA758BC058294E4085E97B0DC14D3D4076525F9676284E4069AA27F38F4A3D4076525F9676284E40
67425	5980	28.860489999999999	28.871009000000001	61.116269000000003	61.111784	Рощинская	0103000020E61000000100000005000000F888981249DC3C40A81B28F04E8E4E40F888981249DC3C40F24410E7E18E4E408C852172FADE3C40F24410E7E18E4E408C852172FADE3C40A81B28F04E8E4E40F888981249DC3C40A81B28F04E8E4E40
67581	5980	28.862888000000002	28.877962	61.116568999999998	61.107332	Лесная	0103000020E61000000100000005000000611C5C3AE6DC3C403AE8120EBD8D4E40611C5C3AE6DC3C401C5DA5BBEB8E4E4079211D1EC2E03C401C5DA5BBEB8E4E4079211D1EC2E03C403AE8120EBD8D4E40611C5C3AE6DC3C403AE8120EBD8D4E40
1674	5980	28.867919000000001	28.886855000000001	61.108445000000003	61.104210999999999	Красноармейская улица	0103000020E61000000100000005000000B89388F02FDE3C4015713AC9568D4E40B89388F02FDE3C4016359886E18D4E40494BE5ED08E33C4016359886E18D4E40494BE5ED08E33C4015713AC9568D4E40B89388F02FDE3C4015713AC9568D4E40
66509	5980	28.818277999999999	28.904696000000001	61.127037000000001	61.073422999999998	Коробицына	0103000020E610000001000000050000004A09C1AA7AD13C4019E3C3EC65894E404A09C1AA7AD13C40E43098BF42904E4070D234289AE73C40E43098BF42904E4070D234289AE73C4019E3C3EC65894E404A09C1AA7AD13C4019E3C3EC65894E40
5950	4979	29.605022000000002	29.642265999999999	60.256663000000003	60.242959999999997	Социалистическая улица	0103000020E610000001000000050000004B5CC7B8E29A3D403A1E3350191F4E404B5CC7B8E29A3D40F08B4B55DA204E402E55698B6BA43D40F08B4B55DA204E402E55698B6BA43D403A1E3350191F4E404B5CC7B8E29A3D403A1E3350191F4E40
5910	4979	29.590218	29.629536999999999	60.261451999999998	60.255882	Советская улица	0103000020E61000000100000005000000B282DF8618973D404AD1CABDC0204E40B282DF8618973D40A5BC564277214E40389F3A5629A13D40A5BC564277214E40389F3A5629A13D404AD1CABDC0204E40B282DF8618973D404AD1CABDC0204E40
67488	4979	29.590218	29.629536999999999	60.261451999999998	60.255882	Советская	0103000020E61000000100000005000000B282DF8618973D404AD1CABDC0204E40B282DF8618973D40A5BC564277214E40389F3A5629A13D40A5BC564277214E40389F3A5629A13D404AD1CABDC0204E40B282DF8618973D404AD1CABDC0204E40
67526	4979	29.573177000000001	29.598267	60.257787999999998	60.249912999999999	Железнодорожная	0103000020E61000000100000005000000C4D155BABB923D4031EC3026FD1F4E40C4D155BABB923D408FA67A32FF204E40AA46AF0628993D408FA67A32FF204E40AA46AF0628993D4031EC3026FD1F4E40C4D155BABB923D4031EC3026FD1F4E40
67254	4833	29.449352999999999	29.481010000000001	60.411411999999999	60.389189999999999	Школьная	0103000020E61000000100000005000000075C57CC08733D4012F758FAD0314E40075C57CC08733D404A97FE25A9344E40890CAB78237B3D404A97FE25A9344E40890CAB78237B3D4012F758FAD0314E40075C57CC08733D4012F758FAD0314E40
5753	4242	28.606256999999999	28.620063999999999	60.366098999999998	60.362735000000001	набережная Лебедева	0103000020E6100000010000000500000098F8A3A8339B3C40AA0EB9196E2E4E4098F8A3A8339B3C40950C0055DC2E4E404C6DA983BC9E3C40950C0055DC2E4E404C6DA983BC9E3C40AA0EB9196E2E4E4098F8A3A8339B3C40AA0EB9196E2E4E40
67601	4242	28.611692000000001	28.617118000000001	60.372526999999998	60.36544	Школьная	0103000020E610000001000000050000008F39CFD8979C3C403B53E8BCC62E4E408F39CFD8979C3C4041F0F8F6AE2F4E40DFC5FB71FB9D3C4041F0F8F6AE2F4E40DFC5FB71FB9D3C403B53E8BCC62E4E408F39CFD8979C3C403B53E8BCC62E4E40
67139	58974	29.418137000000002	29.435205	60.179364999999997	60.170817999999997	Лесная	0103000020E61000000100000005000000603FC4060B6B3D40B8C83D5DDD154E40603FC4060B6B3D400586AC6EF5164E40410E4A98696F3D400586AC6EF5164E40410E4A98696F3D40B8C83D5DDD154E40603FC4060B6B3D40B8C83D5DDD154E40
67148	4938	29.245660000000001	29.291034	60.328197000000003	60.300939	Выборгское шоссе	0103000020E6100000010000000500000074EFE192E33E3D40A48B4D2B85264E4074EFE192E33E3D409AD2FA5B022A4E4029064834814A3D409AD2FA5B022A4E4029064834814A3D40A48B4D2B85264E4074EFE192E33E3D40A48B4D2B85264E40
65040	58443	28.512132000000001	28.533134	60.682214000000002	60.670295000000003	 Советская	0103000020E610000001000000050000002E3C2F151B833C400FD6FF39CC554E402E3C2F151B833C40CA6FD1C952574E40BB6246787B883C40CA6FD1C952574E40BB6246787B883C400FD6FF39CC554E402E3C2F151B833C400FD6FF39CC554E40
67232	5025	29.358048	29.374756999999999	60.170020999999998	60.163696000000002	Литвинова	0103000020E61000000100000005000000F165A208A95B3D40363E93FDF3144E40F165A208A95B3D400D51853FC3154E4073F22213F05F3D400D51853FC3154E4073F22213F05F3D40363E93FDF3144E40F165A208A95B3D40363E93FDF3144E40
67070	58943	29.725325000000002	29.757034999999998	60.367393	60.351599999999998	А122	0103000020E61000000100000005000000A1F831E6AEB93D4005A3923A012D4E40A1F831E6AEB93D40C1E3DBBB062F4E4067EDB60BCDC13D40C1E3DBBB062F4E4067EDB60BCDC13D4005A3923A012D4E40A1F831E6AEB93D4005A3923A012D4E40
67264	4628	29.725325000000002	29.757034999999998	60.367393	60.351599999999998	Ленина	0103000020E61000000100000005000000A1F831E6AEB93D4005A3923A012D4E40A1F831E6AEB93D40C1E3DBBB062F4E4067EDB60BCDC13D40C1E3DBBB062F4E4067EDB60BCDC13D4005A3923A012D4E40A1F831E6AEB93D4005A3923A012D4E40
65927	20150	29.386641999999998	29.419044	61.012652000000003	61.001416999999996	Новая	0103000020E61000000100000005000000914259F8FA623D404754A86E2E804E40914259F8FA623D40501DAB949E814E40C495B377466B3D40501DAB949E814E40C495B377466B3D404754A86E2E804E40914259F8FA623D404754A86E2E804E40
67354	59045	28.956430000000001	28.994796999999998	61.084989	61.074793999999997	Новая	0103000020E61000000100000005000000CDE9B298D8F43C40F0F78BD992894E40CDE9B298D8F43C4087C267EBE08A4E40AE282504ABFE3C4087C267EBE08A4E40AE282504ABFE3C40F0F78BD992894E40CDE9B298D8F43C40F0F78BD992894E40
1605	5882	28.902522000000001	28.90483	61.091130999999997	61.090134999999997	Школьный переулок	0103000020E61000000100000005000000A7EB89AE0BE73C40CB9C2E8B898B4E40A7EB89AE0BE73C406D533C2EAA8B4E408F705AF0A2E73C406D533C2EAA8B4E408F705AF0A2E73C40CB9C2E8B898B4E40A7EB89AE0BE73C40CB9C2E8B898B4E40
24356	5882	28.862493000000001	28.955603	61.074545999999998	61.022573999999999	Летчиков	0103000020E6100000010000000500000068075C57CCDC3C40B5DE6FB4E3824E4068075C57CCDC3C4018062CB98A894E40A1F5F065A2F43C4018062CB98A894E40A1F5F065A2F43C40B5DE6FB4E3824E4068075C57CCDC3C40B5DE6FB4E3824E40
5884	4666	29.853317000000001	29.855553	60.227915000000003	60.224013999999997	Заречная улица	0103000020E61000000100000005000000EF1EA0FB72DA3D404EECA17DAC1C4E40EF1EA0FB72DA3D4049A297512C1D4E40A4FE7A8505DB3D4049A297512C1D4E40A4FE7A8505DB3D404EECA17DAC1C4E40EF1EA0FB72DA3D404EECA17DAC1C4E40
66218	21756	29.470616	29.499991000000001	60.555985	60.536158999999998	Советская	0103000020E610000001000000050000006EF9484A7A783D40603AADDBA0444E406EF9484A7A783D40850838842A474E405A4B0169FF7F3D40850838842A474E405A4B0169FF7F3D40603AADDBA0444E406EF9484A7A783D40603AADDBA0444E40
67153	22766	29.160266	29.172394000000001	60.316265999999999	60.309050999999997	Центральная	0103000020E6100000010000000500000026A94C3107293D40E6E5B0FB8E274E4026A94C3107293D401A6B7F677B284E40D1066003222C3D401A6B7F677B284E40D1066003222C3D40E6E5B0FB8E274E4026A94C3107293D40E6E5B0FB8E274E40
24370	4564	29.357185999999999	29.374029	60.471978999999997	60.467007000000002	Комсомольская	0103000020E61000000100000005000000CC96AC8A705B3D406500A8E2C63B4E40CC96AC8A705B3D400BB3D0CE693C4E406EC1525DC05F3D400BB3D0CE693C4E406EC1525DC05F3D406500A8E2C63B4E40CC96AC8A705B3D406500A8E2C63B4E40
67269	21890	29.245902999999998	29.299586000000001	60.477339999999998	60.463245999999998	Советская	0103000020E6100000010000000500000000FDBE7FF33E3D405C001AA54B3B4E4000FDBE7FF33E3D404C89247A193D4E40E75608ABB14C3D404C89247A193D4E40E75608ABB14C3D405C001AA54B3B4E4000FDBE7FF33E3D405C001AA54B3B4E40
67251	5615	29.063590000000001	29.170552000000001	60.973126999999998	60.915000999999997	Ленинградское шоссе	0103000020E61000000100000005000000475A2A6F47103D405567B5C01E754E40475A2A6F47103D4063EDEF6C8F7C4E407444BE4BA92B3D4063EDEF6C8F7C4E407444BE4BA92B3D405567B5C01E754E40475A2A6F47103D405567B5C01E754E40
67223	4736	29.742895999999998	29.793246	60.273094999999998	60.257694000000001	Садовая	0103000020E610000001000000050000004754A86E2EBE3D400E30F31DFC204E404754A86E2EBE3D40BED9E6C6F4224E40CDAE7B2B12CB3D40BED9E6C6F4224E40CDAE7B2B12CB3D400E30F31DFC204E404754A86E2EBE3D400E30F31DFC204E40
66396	5083	29.422494	29.445302000000002	60.271636000000001	60.265318000000001	Центральная	0103000020E6100000010000000500000098C11891286C3D402385B2F0F5214E4098C11891286C3D404835ECF7C4224E40E9D7D64FFF713D404835ECF7C4224E40E9D7D64FFF713D402385B2F0F5214E4098C11891286C3D402385B2F0F5214E40
67302	6763	28.717648000000001	28.731617	60.457957999999998	60.446421000000001	Мира	0103000020E61000000100000005000000310A82C7B7B73C40B29FC55224394E40310A82C7B7B73C408578245E9E3A4E40983270404BBB3C408578245E9E3A4E40983270404BBB3C40B29FC55224394E40310A82C7B7B73C40B29FC55224394E40
67217	18461	29.023748999999999	29.055038	60.597476999999998	60.586454000000003	Центральная	0103000020E610000001000000050000000D501A6A14063D40E04DB7EC104B4E400D501A6A14063D405C8E57207A4C4E4089096AF8160E3D405C8E57207A4C4E4089096AF8160E3D40E04DB7EC104B4E400D501A6A14063D40E04DB7EC104B4E40
67561	11681	28.570352	28.573136000000002	60.629610999999997	60.622579999999999	Ленинская	0103000020E610000001000000050000004C35B39602923C40649291B3B04F4E404C35B39602923C40D619DF1797504E400729780AB9923C40D619DF1797504E400729780AB9923C40649291B3B04F4E404C35B39602923C40649291B3B04F4E40
1949	5146	28.752763999999999	28.769642999999999	60.705508000000002	60.691597000000002	улица Гагарина	0103000020E610000001000000050000002C9B3924B5C03C408081204086584E402C9B3924B5C03C407F880D164E5A4E406798DA5207C53C407F880D164E5A4E406798DA5207C53C408081204086584E402C9B3924B5C03C408081204086584E40
2960	5146	28.738965	28.758279000000002	60.713374000000002	60.706811000000002	проспект Ленина	0103000020E610000001000000050000007EE36BCF2CBD3C40FEB968C8785A4E407EE36BCF2CBD3C408AE8D7D64F5B4E405C3E92921EC23C408AE8D7D64F5B4E405C3E92921EC23C40FEB968C8785A4E407EE36BCF2CBD3C40FEB968C8785A4E40
67337	5146	28.597714	28.601047000000001	60.749864000000002	60.747089000000003	имени А.К. Харитонова	0103000020E61000000100000005000000815CE2C803993C40C619C39CA05F4E40815CE2C803993C405039268BFB5F4E40E25B5837DE993C405039268BFB5F4E40E25B5837DE993C40C619C39CA05F4E40815CE2C803993C40C619C39CA05F4E40
67407	5146	28.754237	28.756456	60.710324	60.709356	Школьная	0103000020E61000000100000005000000E36E10AD15C13C40569C6A2DCC5A4E40E36E10AD15C13C402EC896E5EB5A4E40ECDCB419A7C13C402EC896E5EB5A4E40ECDCB419A7C13C40569C6A2DCC5A4E40E36E10AD15C13C40569C6A2DCC5A4E40
67495	5146	28.69811	28.718115999999998	60.736113000000003	60.720771999999997	Шестакова	0103000020E61000000100000005000000B4024356B7B23C40AEEFC341425C4E40B4024356B7B23C408A9466F3385E4E40FDBB3E73D6B73C408A9466F3385E4E40FDBB3E73D6B73C40AEEFC341425C4E40B4024356B7B23C40AEEFC341425C4E40
67542	5146	28.767837	28.771691000000001	60.705036999999997	60.701695000000001	Сухова	0103000020E61000000100000005000000A4A833F790C43C4024624A24D1594E40A4A833F790C43C4027BC04A73E5A4E40179E978A8DC53C4027BC04A73E5A4E40179E978A8DC53C4024624A24D1594E40A4A833F790C43C4024624A24D1594E40
5162	5146	28.731366000000001	28.739243999999999	60.724907999999999	60.721119999999999	Судостроительная улица	0103000020E6100000010000000500000006685BCD3ABB3C40EA3E00A94D5C4E4006685BCD3ABB3C40EC4D0CC9C95C4E40A4C343183FBD3C40EC4D0CC9C95C4E40A4C343183FBD3C40EA3E00A94D5C4E4006685BCD3ABB3C40EA3E00A94D5C4E40
2055	5146	28.767496000000001	28.836297999999999	60.724767999999997	60.717317999999999	Смирновское шоссе	0103000020E6100000010000000500000092CF2B9E7AC43C40836A8313D15B4E4092CF2B9E7AC43C40FA97A432C55C4E40D0B52FA017D63C40FA97A432C55C4E40D0B52FA017D63C40836A8313D15B4E4092CF2B9E7AC43C40836A8313D15B4E40
67387	5146	28.768384999999999	28.773973000000002	60.699379	60.691645999999999	Рубежная	0103000020E61000000100000005000000A9BC1DE1B4C43C4061342BDB87584E40A9BC1DE1B4C43C402D41464085594E40ADFC321823C63C402D41464085594E40ADFC321823C63C4061342BDB87584E40A9BC1DE1B4C43C4061342BDB87584E40
67492	5146	28.73274	28.736782999999999	60.714668000000003	60.713118999999999	Прогонная	0103000020E61000000100000005000000967840D994BB3C40FF93BF7B475B4E40967840D994BB3C40B6BFB33D7A5B4E40AF3F89CF9DBC3C40B6BFB33D7A5B4E40AF3F89CF9DBC3C40FF93BF7B475B4E40967840D994BB3C40FF93BF7B475B4E40
5060	5146	28.734680000000001	28.769642999999999	60.700229	60.674891000000002	Приморское шоссе	0103000020E6100000010000000500000079060DFD13BC3C40B0AE0AD462564E4079060DFD13BC3C40FB5A971AA1594E406798DA5207C53C40FB5A971AA1594E406798DA5207C53C40B0AE0AD462564E4079060DFD13BC3C40B0AE0AD462564E40
67400	5146	28.761118	28.784178000000001	60.699643000000002	60.693992999999999	Приморская	0103000020E610000001000000050000009D6516A1D8C23C4093533BC3D4584E409D6516A1D8C23C400BF0DDE68D594E40213EB0E3BFC83C400BF0DDE68D594E40213EB0E3BFC83C4093533BC3D4584E409D6516A1D8C23C4093533BC3D4584E40
67433	5146	28.751380000000001	28.754542000000001	60.713841000000002	60.713687	Пограничная	0103000020E6100000010000000500000055DE8E705AC03C40494A7A185A5B4E4055DE8E705AC03C40A0C552245F5B4E405C751DAA29C13C40A0C552245F5B4E405C751DAA29C13C40494A7A185A5B4E4055DE8E705AC03C40494A7A185A5B4E40
67573	5146	28.757183000000001	28.762591	60.709693999999999	60.708483999999999	Первомайская	0103000020E610000001000000050000005116BEBED6C13C40A0DE8C9AAF5A4E405116BEBED6C13C406E15C440D75A4E405439ED2939C33C406E15C440D75A4E405439ED2939C33C40A0DE8C9AAF5A4E405116BEBED6C13C40A0DE8C9AAF5A4E40
2906	5146	28.738004	28.747948999999998	60.707278000000002	60.703637000000001	Морская набережная	0103000020E61000000100000005000000335184D4EDBC3C40B6A0F7C6105A4E40335184D4EDBC3C401497E315885A4E406E13EE9579BF3C401497E315885A4E406E13EE9579BF3C40B6A0F7C6105A4E40335184D4EDBC3C40B6A0F7C6105A4E40
2974	5146	28.751183000000001	28.811243999999999	60.711067999999997	60.687658999999996	Ленинградское шоссе	0103000020E61000000100000005000000A94F72874DC03C4068E6C93505584E40A94F72874DC03C40B69DB646045B4E408313D1AFADCF3C40B69DB646045B4E408313D1AFADCF3C4068E6C93505584E40A94F72874DC03C4068E6C93505584E40
67375	5146	28.754542000000001	28.758064000000001	60.746276000000002	60.736122000000002	Кировские Дачи	0103000020E610000001000000050000005C751DAA29C13C40DDEEE53E395E4E405C751DAA29C13C4015E5D2F8855F4E406346787B10C23C4015E5D2F8855F4E406346787B10C23C40DDEEE53E395E4E405C751DAA29C13C40DDEEE53E395E4E40
67456	5146	28.752763999999999	28.769642999999999	60.705508000000002	60.691597000000002	Гагарина	0103000020E610000001000000050000002C9B3924B5C03C408081204086584E402C9B3924B5C03C407F880D164E5A4E406798DA5207C53C407F880D164E5A4E406798DA5207C53C408081204086584E402C9B3924B5C03C408081204086584E40
67584	5146	28.785965000000001	28.790196000000002	60.698802000000001	60.691777999999999	Большая Каменная	0103000020E61000000100000005000000F7CC920035C93C40D00B772E8C584E40F7CC920035C93C4090300C5872594E40166EF9484ACA3C4090300C5872594E40166EF9484ACA3C40D00B772E8C584E40F7CC920035C93C40D00B772E8C584E40
67603	5146	28.716256000000001	28.723576999999999	60.730905	60.726399999999998	Большая Гвардейская 	0103000020E6100000010000000500000054909F8D5CB73C403EE8D9ACFA5C4E4054909F8D5CB73C40CFBD874B8E5D4E4046239F573CB93C40CFBD874B8E5D4E4046239F573CB93C403EE8D9ACFA5C4E4054909F8D5CB73C403EE8D9ACFA5C4E40
67125	58969	29.152442000000001	29.198938999999999	60.733165999999997	60.719549000000001	Воинской Славы	0103000020E610000001000000050000006E895C7006273D404C6F7F2E1A5C4E406E895C7006273D4002452C62D85D4E4021E692AAED323D4002452C62D85D4E4021E692AAED323D404C6F7F2E1A5C4E406E895C7006273D404C6F7F2E1A5C4E40
67285	20899	28.486951999999999	28.515976999999999	60.703544000000001	60.685589	Римского-Корсакова	0103000020E61000000100000005000000C7B8E2E2A87C3C40A9BF5E61C1574E40C7B8E2E2A87C3C4005A6D3BA0D5A4E40FA7C941117843C4005A6D3BA0D5A4E40FA7C941117843C40A9BF5E61C1574E40C7B8E2E2A87C3C40A9BF5E61C1574E40
67430	59061	30.875267000000001	30.939990999999999	59.898114999999997	59.849550999999998	Школьная 	0103000020E610000001000000050000009E44847F11E03E405DA45016BEEC4D409E44847F11E03E400586AC6EF5F24D40CA880B40A3F03E400586AC6EF5F24D40CA880B40A3F03E405DA45016BEEC4D409E44847F11E03E405DA45016BEEC4D40
67279	11783	30.695855000000002	30.706222	59.786790000000003	59.783729000000001	мкр-н №2	0103000020E6100000010000000500000012C2A38D23B23E40A1F65B3B51E44D4012C2A38D23B23E40F168E388B5E44D4039B709F7CAB43E40F168E388B5E44D4039B709F7CAB43E40A1F65B3B51E44D4012C2A38D23B23E40A1F65B3B51E44D40
67181	11783	30.590205000000001	30.755216000000001	59.821131999999999	59.777402000000002	мкр-н №1	0103000020E6100000010000000500000089EFC4AC17973E4029ECA2E881E34D4089EFC4AC17973E407BD976DA1AE94D407B6AF5D555C13E407BD976DA1AE94D407B6AF5D555C13E4029ECA2E881E34D4089EFC4AC17973E4029ECA2E881E34D40
67580	59076	29.937013	31.899014000000001	60.846325	59.801499	площадь Культуры	0103000020E6100000010000000500000046ED7E15E0EF3D406B63EC8497E64D4046ED7E15E0EF3D40C364AA60546C4E406AA510C825E63F40C364AA60546C4E406AA510C825E63F406B63EC8497E64D4046ED7E15E0EF3D406B63EC8497E64D40
67383	11916	30.55667	30.561	59.949185999999997	59.948549999999997	Новая	0103000020E6100000010000000500000011AAD4EC818E3E40764F1E166AF94D4011AAD4EC818E3E4018E945ED7EF94D40560E2DB29D8F3E4018E945ED7EF94D40560E2DB29D8F3E40764F1E166AF94D4011AAD4EC818E3E40764F1E166AF94D40
4796	17334	30.269514999999998	30.311143000000001	60.110944000000003	60.109141000000001	Ленинградское шоссе	0103000020E610000001000000050000000CC85EEFFE443E408DD31055F80D4E400CC85EEFFE443E40FED7B969330E4E401C615111A74F3E40FED7B969330E4E401C615111A74F3E408DD31055F80D4E400CC85EEFFE443E408DD31055F80D4E40
67509	13366	30.529505	30.536754999999999	60.161389999999997	60.158211000000001	Буланова	0103000020E610000001000000050000008811C2A38D873E40096F0F4240144E408811C2A38D873E4062F3716DA8144E40E8F692C668893E4062F3716DA8144E40E8F692C668893E40096F0F4240144E408811C2A38D873E40096F0F4240144E40
67371	13366	30.509446000000001	30.528230000000001	60.147199000000001	60.143450000000001	 Дорожников	0103000020E61000000100000005000000F913950D6B823E403C4ED1915C124E40F913950D6B823E408080B56AD7124E401EC4CE143A873E408080B56AD7124E401EC4CE143A873E403C4ED1915C124E40F913950D6B823E403C4ED1915C124E40
24366	11864	30.581329	30.630206999999999	59.950068999999999	59.934786000000003	Строителей	0103000020E61000000100000005000000653733FAD1943E401C615111A7F74D40653733FAD1943E40C2F869DC9BF94D40D4B5F63E55A13E40C2F869DC9BF94D40D4B5F63E55A13E401C615111A7F74D40653733FAD1943E401C615111A7F74D40
67316	52211	30.620954000000001	30.632605000000002	59.932270000000003	59.929921	Верхняя улица	0103000020E61000000100000005000000055262D7F69E3E408B6EBDA607F74D40055262D7F69E3E405E85949F54F74D403D49BA66F2A13E405E85949F54F74D403D49BA66F2A13E408B6EBDA607F74D40055262D7F69E3E408B6EBDA607F74D40
3622	12757	30.209211	30.225956	60.145944999999998	60.140537999999999	улица Молодцова	0103000020E61000000100000005000000A5F622DA8E353E4031EC3026FD114E40A5F622DA8E353E40E2016553AE124E40C1559E40D8393E40E2016553AE124E40C1559E40D8393E4031EC3026FD114E40A5F622DA8E353E4031EC3026FD114E40
66506	12757	30.142296000000002	30.235171999999999	60.167107000000001	60.123241	мкр-н Черная речка	0103000020E61000000100000005000000045ABA826D243E405F43705CC60F4E40045ABA826D243E4062F71DC363154E4056EF703B343C3E4062F71DC363154E4056EF703B343C3E405F43705CC60F4E40045ABA826D243E405F43705CC60F4E40
65017	12757	30.209211	30.225956	60.145944999999998	60.140537999999999	Молодцова	0103000020E61000000100000005000000A5F622DA8E353E4031EC3026FD114E40A5F622DA8E353E40E2016553AE124E40C1559E40D8393E40E2016553AE124E40C1559E40D8393E4031EC3026FD114E40A5F622DA8E353E4031EC3026FD114E40
67088	58952	30.813229	30.853176999999999	60.097655000000003	60.083804000000001	Севастьянова 	0103000020E61000000100000005000000A62897C62FD03E4012A3E716BA0A4E40A62897C62FD03E403CA583F57F0C4E400BB3D0CE69DA3E403CA583F57F0C4E400BB3D0CE69DA3E4012A3E716BA0A4E40A62897C62FD03E4012A3E716BA0A4E40
67028	58924	30.813229	30.853176999999999	60.097655000000003	60.083804000000001	Октябрьское шоссе	0103000020E61000000100000005000000A62897C62FD03E4012A3E716BA0A4E40A62897C62FD03E403CA583F57F0C4E400BB3D0CE69DA3E403CA583F57F0C4E400BB3D0CE69DA3E4012A3E716BA0A4E40A62897C62FD03E4012A3E716BA0A4E40
67345	14557	30.441784999999999	30.447596999999998	60.159728999999999	60.157338000000003	Овражная	0103000020E6100000010000000500000005DD5ED218713E408335CEA623144E4005DD5ED218713E40849CF7FF71144E40A7C98CB795723E40849CF7FF71144E40A7C98CB795723E408335CEA623144E4005DD5ED218713E408335CEA623144E40
67178	13278	30.407838000000002	30.452089000000001	60.267482000000001	60.250846000000003	Ленинградская	0103000020E61000000100000005000000E910381268683E408D2AC3B81B204E40E910381268683E406422A5D93C224E40A0E1CD1ABC733E406422A5D93C224E40A0E1CD1ABC733E408D2AC3B81B204E40E910381268683E408D2AC3B81B204E40
67246	13737	30.461296000000001	30.49051	60.064743999999997	60.047865000000002	Школьная	0103000020E610000001000000050000008FC6A17E17763E40C0CFB87020064E408FC6A17E17763E405D4E098849084E40685C3810927D3E405D4E098849084E40685C3810927D3E40C0CFB87020064E408FC6A17E17763E40C0CFB87020064E40
67525	15979	30.444139	30.458233	60.047136999999999	60.042369999999998	Центральная	0103000020E61000000100000005000000CEE0EF17B3713E406F2A52616C054E40CEE0EF17B3713E403DB7D09508064E40AEF204C24E753E403DB7D09508064E40AEF204C24E753E406F2A52616C054E40CEE0EF17B3713E406F2A52616C054E40
67444	15979	30.460784	30.466435000000001	60.047074000000002	60.035570999999997	Оборонная 	0103000020E610000001000000050000002385B2F0F5753E40CFD72C978D044E402385B2F0F5753E40F73E558506064E40B3B5BE4868773E40F73E558506064E40B3B5BE4868773E40CFD72C978D044E402385B2F0F5753E40CFD72C978D044E40
67450	15979	30.460784	30.466435000000001	60.047074000000002	60.035570999999997	Оборонная	0103000020E610000001000000050000002385B2F0F5753E40CFD72C978D044E402385B2F0F5753E40F73E558506064E40B3B5BE4868773E40F73E558506064E40B3B5BE4868773E40CFD72C978D044E402385B2F0F5753E40CFD72C978D044E40
67283	59020	30.269874000000002	30.296500000000002	60.155766999999997	60.151082000000002	Зелёная улица	0103000020E610000001000000050000006C0A647616453E40D481ACA756134E406C0A647616453E40E4654D2CF0134E4096438B6CE74B3E40E4654D2CF0134E4096438B6CE74B3E40D481ACA756134E406C0A647616453E40D481ACA756134E40
66145	13333	30.452286000000001	30.471941000000001	60.275612000000002	60.257854999999999	Красноборская	0103000020E610000001000000050000004C70EA03C9733E40170E846401214E404C70EA03C9733E404D31074147234E403CA41820D1783E404D31074147234E403CA41820D1783E40170E846401214E404C70EA03C9733E40170E846401214E40
67194	29981	30.439610999999999	30.455358	60.320489999999999	60.307937000000003	Александрова	0103000020E610000001000000050000003CF6B3588A703E403B1DC87A6A274E403CF6B3588A703E40F758FAD005294E40D3F8855792743E40F758FAD005294E40D3F8855792743E403B1DC87A6A274E403CF6B3588A703E403B1DC87A6A274E40
3830	13521	30.497237999999999	30.498505000000002	60.111499999999999	60.107180999999997	Школьная улица	0103000020E61000000100000005000000155454FD4A7F3E4054E0641BB80D4E40155454FD4A7F3E4083C0CAA1450E4E407AE40F069E7F3E4083C0CAA1450E4E407AE40F069E7F3E4054E0641BB80D4E40155454FD4A7F3E4054E0641BB80D4E40
67365	13521	30.484662	30.486189	60.110733000000003	60.108141000000003	Строителей	0103000020E610000001000000050000002C9D0FCF127C3E40AA2D7590D70D4E402C9D0FCF127C3E4043CBBA7F2C0E4E40C9ACDEE1767C3E4043CBBA7F2C0E4E40C9ACDEE1767C3E40AA2D7590D70D4E402C9D0FCF127C3E40AA2D7590D70D4E40
67313	13521	30.490959	30.491399000000001	60.10915	60.107666000000002	Спортивная	0103000020E6100000010000000500000047AD307DAF7D3E401172DEFFC70D4E4047AD307DAF7D3E40E02D90A0F80D4E4080492A53CC7D3E40E02D90A0F80D4E4080492A53CC7D3E401172DEFFC70D4E4047AD307DAF7D3E401172DEFFC70D4E40
67207	13521	30.500247000000002	30.501631	60.111657000000001	60.106935	Ленинградское шоссе	0103000020E6100000010000000500000010ECF82F10803E401DE6CB0BB00D4E4010ECF82F10803E404BAFCDC64A0E4E40E7A8A3E36A803E404BAFCDC64A0E4E40E7A8A3E36A803E401DE6CB0BB00D4E4010ECF82F10803E401DE6CB0BB00D4E40
67215	58995	30.485524000000002	30.50393	60.121972999999997	60.112701000000001	Заозерная	0103000020E61000000100000005000000516C054D4B7C3E40FE9C82FC6C0E4E40516C054D4B7C3E405CFFAECF9C0F4E402979758E01813E405CFFAECF9C0F4E402979758E01813E40FE9C82FC6C0E4E40516C054D4B7C3E40FE9C82FC6C0E4E40
67239	59003	30.90766	30.939236000000001	60.083193999999999	60.073507999999997	Ленинградское шоссе	0103000020E610000001000000050000002AE3DF675CE83E4047FFCBB568094E402AE3DF675CE83E40999CDA19A60A4E40D2393FC571F03E40999CDA19A60A4E40D2393FC571F03E4047FFCBB568094E402AE3DF675CE83E4047FFCBB568094E40
3471	9960	30.683153000000001	30.689755999999999	60.018780999999997	59.987797999999998	проспект Грибоедова	0103000020E610000001000000050000000F2A711DE3AE3E40F086342A70FE4D400F2A711DE3AE3E40A164726A67024E40433866D993B03E40A164726A67024E40433866D993B03E40F086342A70FE4D400F2A711DE3AE3E40F086342A70FE4D40
67500	9960	30.638407999999998	30.645676000000002	60.041969999999999	60.035679000000002	Шишканя	0103000020E610000001000000050000003881E9B46EA33E40B613252191044E403881E9B46EA33E40E1B4E0455F054E40E6CFB7054BA53E40E1B4E0455F054E40E6CFB7054BA53E40B613252191044E403881E9B46EA33E40B613252191044E40
4730	9960	30.646080000000001	30.710740999999999	60.008085999999999	60.007722000000001	Торговый проспект	0103000020E610000001000000050000008599B67F65A53E40D8BAD408FD004E408599B67F65A53E4019C748F608014E4024ED461FF3B53E4019C748F608014E4024ED461FF3B53E40D8BAD408FD004E408599B67F65A53E40D8BAD408FD004E40
67340	9960	30.666139000000001	30.698513999999999	60.023905999999997	60.013551	Пушкинская	0103000020E610000001000000050000001497E31588AA3E40FFE9060ABC014E401497E31588AA3E40CE16105A0F034E4053CC41D0D1B23E40CE16105A0F034E4053CC41D0D1B23E40FFE9060ABC014E401497E31588AA3E40FFE9060ABC014E40
67631	9960	30.590527999999999	30.598496000000001	60.012830999999998	60.009174999999999	Приютинская	0103000020E610000001000000050000004E5FCFD72C973E406C787AA52C014E404E5FCFD72C973E40FFAF3A72A4014E406DC9AA0837993E40FFAF3A72A4014E406DC9AA0837993E406C787AA52C014E404E5FCFD72C973E406C787AA52C014E40
67326	9960	30.650023000000001	30.650525999999999	59.995201000000002	59.990966999999998	Московская	0103000020E61000000100000005000000D7A546E867A63E402635B401D8FE4D40D7A546E867A63E4027F911BF62FF4D409C3237DF88A63E4027F911BF62FF4D409C3237DF88A63E402635B401D8FE4D40D7A546E867A63E402635B401D8FE4D40
3209	9960	30.616346	30.641058000000001	60.026766000000002	60.023919999999997	Межевая улица	0103000020E610000001000000050000003A05F9D9C89D3E4033DC80CF0F034E403A05F9D9C89D3E4087527B116D034E40D4D688601CA43E4087527B116D034E40D4D688601CA43E4033DC80CF0F034E403A05F9D9C89D3E4033DC80CF0F034E40
67559	9960	30.616346	30.641058000000001	60.026766000000002	60.023919999999997	Межевая	0103000020E610000001000000050000003A05F9D9C89D3E4033DC80CF0F034E403A05F9D9C89D3E4087527B116D034E40D4D688601CA43E4087527B116D034E40D4D688601CA43E4033DC80CF0F034E403A05F9D9C89D3E4033DC80CF0F034E40
65033	9960	30.628948999999999	30.635480000000001	60.031886	60.011215999999997	Александровская	0103000020E6100000010000000500000016DA39CD02A13E409198A0866F014E4016DA39CD02A13E40A29927D714044E40184339D1AEA23E40A29927D714044E40184339D1AEA23E409198A0866F014E4016DA39CD02A13E409198A0866F014E40
65921	13228	30.444254999999998	30.458915999999999	60.256123000000002	60.250846000000003	Ленинградская	0103000020E61000000100000005000000A01518B2BA713E408D2AC3B81B204E40A01518B2BA713E40706072A3C8204E40739CDB847B753E40706072A3C8204E40739CDB847B753E408D2AC3B81B204E40A01518B2BA713E408D2AC3B81B204E40
66552	13139	30.309273999999998	30.376100000000001	60.387869999999999	60.363278000000001	Коробицына	0103000020E61000000100000005000000CB80B3942C4F3E409BADBCE47F2E4E40CB80B3942C4F3E40BD8C62B9A5314E408E06F01648603E40BD8C62B9A5314E408E06F01648603E409BADBCE47F2E4E40CB80B3942C4F3E409BADBCE47F2E4E40
67069	58942	30.320709999999998	30.337040999999999	60.171252000000003	60.168185999999999	Токсовское шоссе	0103000020E610000001000000050000000A80F10C1A523E4091D26C1E87154E400A80F10C1A523E40F3AFE595EB154E404069A85148563E40F3AFE595EB154E404069A85148563E4091D26C1E87154E400A80F10C1A523E4091D26C1E87154E40
3772	13368	30.392225	30.397264	60.066719999999997	60.066194000000003	Полевая улица	0103000020E6100000010000000500000071AC8BDB68643E408198840B79084E4071AC8BDB68643E409BFEEC478A084E40CEE0EF17B3653E409BFEEC478A084E40CEE0EF17B3653E408198840B79084E4071AC8BDB68643E408198840B79084E40
67273	13553	30.929255999999999	30.982382000000001	60.105862999999999	60.086955000000003	Центральная	0103000020E610000001000000050000009D9CA1B8E3ED3E40A29C6857210B4E409D9CA1B8E3ED3E40A06D35EB8C0D4E40D82D02637DFB3E40A06D35EB8C0D4E40D82D02637DFB3E40A29C6857210B4E409D9CA1B8E3ED3E40A29C6857210B4E40
67022	7783	32.489269999999998	32.601056	60.160046999999999	60.133983000000001	Культуры	0103000020E61000000100000005000000FB743C66A03E4040289CDD5A26114E40FB743C66A03E404055698B6B7C144E4044882B67EF4C404055698B6B7C144E4044882B67EF4C4040289CDD5A26114E40FB743C66A03E4040289CDD5A26114E40
66127	7783	32.489269999999998	32.601056	60.160046999999999	60.133983000000001	Космонавтов	0103000020E61000000100000005000000FB743C66A03E4040289CDD5A26114E40FB743C66A03E404055698B6B7C144E4044882B67EF4C404055698B6B7C144E4044882B67EF4C4040289CDD5A26114E40FB743C66A03E4040289CDD5A26114E40
67037	7783	32.489269999999998	32.601056	60.160046999999999	60.133983000000001	25 Октября	0103000020E61000000100000005000000FB743C66A03E4040289CDD5A26114E40FB743C66A03E404055698B6B7C144E4044882B67EF4C404055698B6B7C144E4044882B67EF4C4040289CDD5A26114E40FB743C66A03E4040289CDD5A26114E40
64960	7783	32.489269999999998	32.601056	60.160046999999999	60.133983000000001	 Советская	0103000020E61000000100000005000000FB743C66A03E4040289CDD5A26114E40FB743C66A03E404055698B6B7C144E4044882B67EF4C404055698B6B7C144E4044882B67EF4C4040289CDD5A26114E40FB743C66A03E4040289CDD5A26114E40
24397	10324	32.285702999999998	32.298459000000001	60.009408000000001	59.991498	Советская	0103000020E610000001000000050000003EAF78EA9124404053060E68E9FE4D403EAF78EA912440400F29064834014E4033198EE7332640400F29064834014E4033198EE73326404053060E68E9FE4D403EAF78EA9124404053060E68E9FE4D40
67259	11752	33.472017999999998	33.489454000000002	60.235151999999999	60.228259000000001	Лесная	0103000020E61000000100000005000000C98FF8156BBC404043024697371D4E40C98FF8156BBC404064CBF275191E4E40BD72BD6DA6BE404064CBF275191E4E40BD72BD6DA6BE404043024697371D4E40C98FF8156BBC404043024697371D4E40
66241	12190	32.667217000000001	32.692559000000003	60.209457	60.198444000000002	Школьная	0103000020E61000000100000005000000E92ADD5D67554040310BED9C66194E40E92ADD5D675540408A75AA7CCF1A4E4076C6F7C5A55840408A75AA7CCF1A4E4076C6F7C5A5584040310BED9C66194E40E92ADD5D67554040310BED9C66194E40
67042	12708	32.891347000000003	32.935149000000003	60.470702000000003	60.454808	Новая Свирица	0103000020E61000000100000005000000A13193A817724040C6FA0626373A4E40A13193A817724040B61490F63F3C4E408DF161F6B2774040B61490F63F3C4E408DF161F6B2774040C6FA0626373A4E40A13193A817724040C6FA0626373A4E40
67289	11403	32.993099000000001	33.049855000000001	60.416739	60.377023999999999	Юбилейная	0103000020E610000001000000050000005C5837DE1D7F40404FE78A5242304E405C5837DE1D7F4040DFFB1BB457354E4063450DA661864040DFFB1BB457354E4063450DA6618640404FE78A5242304E405C5837DE1D7F40404FE78A5242304E40
24365	11403	32.993099000000001	33.049855000000001	60.416739	60.377023999999999	Советская	0103000020E610000001000000050000005C5837DE1D7F40404FE78A5242304E405C5837DE1D7F4040DFFB1BB457354E4063450DA661864040DFFB1BB457354E4063450DA6618640404FE78A5242304E405C5837DE1D7F40404FE78A5242304E40
24388	11257	32.283887999999997	32.324267999999996	60.115338000000001	60.088147999999997	проспект Карла Маркса	0103000020E6100000010000000500000009DD257156244040999A046F480B4E4009DD25715624404037FE4465C30E4E40D591239D8129404037FE4465C30E4E40D591239D81294040999A046F480B4E4009DD257156244040999A046F480B4E40
67104	11257	32.283887999999997	32.324267999999996	60.115338000000001	60.088147999999997	проспект К.Маркса	0103000020E6100000010000000500000009DD257156244040999A046F480B4E4009DD25715624404037FE4465C30E4E40D591239D8129404037FE4465C30E4E40D591239D81294040999A046F480B4E4009DD257156244040999A046F480B4E40
66338	11257	32.283887999999997	32.324267999999996	60.115338000000001	60.088147999999997	Ленинградская	0103000020E6100000010000000500000009DD257156244040999A046F480B4E4009DD25715624404037FE4465C30E4E40D591239D8129404037FE4465C30E4E40D591239D81294040999A046F480B4E4009DD257156244040999A046F480B4E40
66548	11940	32.328633000000004	32.361187999999999	60.112983999999997	60.102777000000003	Петровская	0103000020E6100000010000000500000075B169A5102A4040F8E3F6CB270D4E4075B169A5102A4040527C7C42760E4E4094DA8B683B2E4040527C7C42760E4E4094DA8B683B2E4040F8E3F6CB270D4E4075B169A5102A4040F8E3F6CB270D4E40
66090	8521	32.573577	32.599035000000001	60.048166000000002	60.003672999999999	Центральная	0103000020E61000000100000005000000705E9CF86A49404069705B5B78004E40705E9CF86A494040BB63B14D2A064E406614CB2DAD4C4040BB63B14D2A064E406614CB2DAD4C404069705B5B78004E40705E9CF86A49404069705B5B78004E40
67202	8521	32.573577	32.599035000000001	60.048166000000002	60.003672999999999	 м-н Алексино	0103000020E61000000100000005000000705E9CF86A49404069705B5B78004E40705E9CF86A494040BB63B14D2A064E406614CB2DAD4C4040BB63B14D2A064E406614CB2DAD4C404069705B5B78004E40705E9CF86A49404069705B5B78004E40
67248	11830	32.336440000000003	32.356974999999998	60.074275999999998	60.055681	микрорайон Центральный	0103000020E610000001000000050000007B884677102B40401901158E20074E407B884677102B404058703FE081094E40AB3E575BB12D404058703FE081094E40AB3E575BB12D40401901158E20074E407B884677102B40401901158E20074E40
65966	10371	32.348979999999997	32.359499	59.812288000000002	59.798651999999997	Школьная	0103000020E61000000100000005000000A27A6B60AB2C404047718E3A3AE64D40A27A6B60AB2C404075779D0DF9E74D40ECF82F10042E404075779D0DF9E74D40ECF82F10042E404047718E3A3AE64D40A27A6B60AB2C404047718E3A3AE64D40
67108	10401	32.297874999999998	32.340347000000001	59.931305000000002	59.92662	проспект Державина	0103000020E61000000100000005000000E3A59BC420264040E6E8F17B9BF64D40E3A59BC420264040F7CC920035F74D405725917D902B4040F7CC920035F74D405725917D902B4040E6E8F17B9BF64D40E3A59BC420264040E6E8F17B9BF64D40
3086	10401	31.824921	32.879579	60.164389999999997	59.634576000000003	площадь Ленина	0103000020E610000001000000050000009BC8CC052ED33F40CB694FC939D14D409BC8CC052ED33F400CE544BB0A154E40CB9F6F0B967040400CE544BB0A154E40CB9F6F0B96704040CB694FC939D14D409BC8CC052ED33F40CB694FC939D14D40
67577	10401	32.373953	32.385612999999999	59.940505999999999	59.933942999999999	Островского	0103000020E61000000100000005000000DC9E20B1DD2F404000AAB8718BF74D40DC9E20B1DD2F40408CD8278062F84D40CBF44BC45B3140408CD8278062F84D40CBF44BC45B31404000AAB8718BF74D40DC9E20B1DD2F404000AAB8718BF74D40
67590	10401	32.311377	32.315185999999997	59.933334000000002	59.923459000000001	Нахимова	0103000020E6100000010000000500000001DD9733DB27404033198EE733F64D4001DD9733DB274040581F0F7D77F74D401A14CD0358284040581F0F7D77F74D401A14CD035828404033198EE733F64D4001DD9733DB27404033198EE733F64D40
67508	10401	32.347479999999997	32.359040999999998	59.899802999999999	59.899442000000001	Лукьянова	0103000020E61000000100000005000000CD0182397A2C40400D535BEA20F34D40CD0182397A2C4040DDEBA4BE2CF34D402976340EF52D4040DDEBA4BE2CF34D402976340EF52D40400D535BEA20F34D40CD0182397A2C40400D535BEA20F34D40
67342	10401	32.299230999999999	32.309832	59.924695	59.923293000000001	Коммунаров	0103000020E6100000010000000500000085798F334D26404018D00B772EF64D4085798F334D2640402AE3DF675CF64D408CA03193A82740402AE3DF675CF64D408CA03193A827404018D00B772EF64D4085798F334D26404018D00B772EF64D40
3071	10401	32.346150000000002	32.352798	59.917524	59.900253999999997	Кировский проспект	0103000020E6100000010000000500000055C1A8A44E2C4040ED0BE8853BF34D4055C1A8A44E2C4040C6A52A6D71F54D400F0C207C282D4040C6A52A6D71F54D400F0C207C282D4040ED0BE8853BF34D4055C1A8A44E2C4040ED0BE8853BF34D40
67572	10401	32.347687000000001	32.369245999999997	59.898052	59.897384000000002	Калинина	0103000020E61000000100000005000000471FF301812C404012FA997ADDF24D40471FF301812C4040BF0D315EF3F24D40E316F373432F4040BF0D315EF3F24D40E316F373432F404012FA997ADDF24D40471FF301812C404012FA997ADDF24D40
67585	10401	32.330582999999997	32.333708999999999	59.920361	59.910817000000002	Зеленая	0103000020E6100000010000000500000089CE328B502A404007D2C5A695F44D4089CE328B502A4040C6C1A563CEF54D40C0B0FCF9B62A4040C6C1A563CEF54D40C0B0FCF9B62A404007D2C5A695F44D4089CE328B502A404007D2C5A695F44D40
67352	10401	32.289611000000001	32.296528000000002	59.931310000000003	59.926634	Воронежская	0103000020E61000000100000005000000EBC726F9112540404BAE62F19BF64D40EBC726F9112540400938842A35F74D40952C27A1F42540400938842A35F74D40952C27A1F42540404BAE62F19BF64D40EBC726F9112540404BAE62F19BF64D40
3130	10401	32.354171999999998	32.355483999999997	59.905194999999999	59.895735999999999	Волгоградская улица	0103000020E6100000010000000500000057941282552D4040C8EC2C7AA7F24D4057941282552D404059C0046EDDF34D402920ED7F802D404059C0046EDDF34D402920ED7F802D4040C8EC2C7AA7F24D4057941282552D4040C8EC2C7AA7F24D40
3155	10401	32.348422999999997	32.373316000000003	59.892589999999998	59.891804999999998	Авиационная улица	0103000020E610000001000000050000004C16F71F992C404063B48EAA26F24D404C16F71F992C40404A5E9D6340F24D406A8995D1C82F40404A5E9D6340F24D406A8995D1C82F404063B48EAA26F24D404C16F71F992C404063B48EAA26F24D40
24340	12019	32.323540000000001	32.339215000000003	59.758381	59.747430000000001	Песочная	0103000020E6100000010000000500000053793BC2692940404F0647C9ABDF4D4053793BC2692940403274ECA012E14D4005A8A9656B2B40403274ECA012E14D4005A8A9656B2B40404F0647C9ABDF4D4053793BC2692940404F0647C9ABDF4D40
67188	12681	32.568600000000004	32.584411000000003	60.101202999999998	60.095390000000002	Центральная	0103000020E61000000100000005000000B84082E2C7484040C72E51BD350C4E40B84082E2C7484040E8A04B38F40C4E401A36CAFACD4A4040E8A04B38F40C4E401A36CAFACD4A4040C72E51BD350C4E40B84082E2C7484040C72E51BD350C4E40
64969	9800	29.613061999999999	29.642634999999999	59.471528999999997	59.456834000000001	 Кикеринский дом культуры	0103000020E610000001000000050000009C6B98A1F19C3D40B6D9588979BA4D409C6B98A1F19C3D40CB0EF10F5BBC4D40D44334BA83A43D40CB0EF10F5BBC4D40D44334BA83A43D40B6D9588979BA4D409C6B98A1F19C3D40B6D9588979BA4D40
65048	8888	29.458696	29.521632	59.456569000000002	59.431246999999999	усадьба Сельхозтехники	0103000020E6100000010000000500000057CEDE196D753D40C2BF081A33B74D4057CEDE196D753D4008AF5DDA70BA4D400D8CBCAC89853D4008AF5DDA70BA4D400D8CBCAC89853D40C2BF081A33B74D4057CEDE196D753D40C2BF081A33B74D40
2534	8888	29.471074000000002	29.492697	59.455238000000001	59.440454000000003	проспект Вингиссара	0103000020E61000000100000005000000F4FE3F4E98783D403AB2F2CB60B84D40F4FE3F4E98783D40BFF2203D45BA4D405AD6FD63217E3D40BFF2203D45BA4D405AD6FD63217E3D403AB2F2CB60B84D40F4FE3F4E98783D403AB2F2CB60B84D40
65002	8888	29.487432999999999	29.499326	59.449750000000002	59.445317000000003	Красных партизан	0103000020E61000000100000005000000BDFDB968C87C3D402AADBF2500B94D40BDFDB968C87C3D4021B0726891B94D40E10A28D4D37F3D4021B0726891B94D40E10A28D4D37F3D402AADBF2500B94D40BDFDB968C87C3D402AADBF2500B94D40
65027	8888	29.491250999999998	29.499918999999998	59.453724000000001	59.450564	Красных командиров	0103000020E61000000100000005000000962023A0C27D3D40A260C614ACB94D40962023A0C27D3D4085B4C6A013BA4D4026A60BB1FA7F3D4085B4C6A013BA4D4026A60BB1FA7F3D40A260C614ACB94D40962023A0C27D3D40A260C614ACB94D40
2504	8888	29.492697	29.507411000000001	59.455238000000001	59.454543000000001	Гатчинское шоссе	0103000020E610000001000000050000005AD6FD63217E3D4018D00B772EBA4D405AD6FD63217E3D40BFF2203D45BA4D4073A1F2AFE5813D40BFF2203D45BA4D4073A1F2AFE5813D4018D00B772EBA4D405AD6FD63217E3D4018D00B772EBA4D40
67256	8399	35.449444	35.466161	59.519691999999999	59.514660999999997	Центральная	0103000020E6100000010000000500000014B1886187B9414069C36169E0C14D4014B1886187B9414015FF774485C24D40D8D5E429ABBB414015FF774485C24D40D8D5E429ABBB414069C36169E0C14D4014B1886187B9414069C36169E0C14D40
67176	7967	34.836613	34.884053000000002	59.349612999999998	59.338650999999999	Ярославская 	0103000020E6100000010000000500000048348122166B4140FCE07CEA58AB4D4048348122166B4140D3A0681EC0AC4D40217711A628714140D3A0681EC0AC4D40217711A628714140FCE07CEA58AB4D4048348122166B4140FCE07CEA58AB4D40
66133	7425	34.110962999999998	34.227500999999997	59.537224000000002	59.502949000000001	Школьная 	0103000020E6100000010000000500000074081C09340E4140284701A260C04D4074081C09340E41402B508BC1C3C44D405567B5C01E1D41402B508BC1C3C44D405567B5C01E1D4140284701A260C04D4074081C09340E4140284701A260C04D40
65674	7425	34.110962999999998	34.227500999999997	59.537224000000002	59.502949000000001	Советская 	0103000020E6100000010000000500000074081C09340E4140284701A260C04D4074081C09340E41402B508BC1C3C44D405567B5C01E1D41402B508BC1C3C44D405567B5C01E1D4140284701A260C04D4074081C09340E4140284701A260C04D40
67200	7425	34.110962999999998	34.227500999999997	59.537224000000002	59.502949000000001	Пл. Комсомола	0103000020E6100000010000000500000074081C09340E4140284701A260C04D4074081C09340E41402B508BC1C3C44D405567B5C01E1D41402B508BC1C3C44D405567B5C01E1D4140284701A260C04D4074081C09340E4140284701A260C04D40
65816	7425	34.110962999999998	34.227500999999997	59.537224000000002	59.502949000000001	Металлургов 	0103000020E6100000010000000500000074081C09340E4140284701A260C04D4074081C09340E41402B508BC1C3C44D405567B5C01E1D41402B508BC1C3C44D405567B5C01E1D4140284701A260C04D4074081C09340E4140284701A260C04D40
66376	7425	34.110962999999998	34.227500999999997	59.537224000000002	59.502949000000001	Заводская	0103000020E6100000010000000500000074081C09340E4140284701A260C04D4074081C09340E41402B508BC1C3C44D405567B5C01E1D41402B508BC1C3C44D405567B5C01E1D4140284701A260C04D4074081C09340E4140284701A260C04D40
67252	7425	34.110962999999998	34.227500999999997	59.537224000000002	59.502949000000001	5-й микрорайон	0103000020E6100000010000000500000074081C09340E4140284701A260C04D4074081C09340E41402B508BC1C3C44D405567B5C01E1D41402B508BC1C3C44D405567B5C01E1D4140284701A260C04D4074081C09340E4140284701A260C04D40
24395	8329	35.199263000000002	35.253583999999996	59.533245000000001	59.503135999999998	Школьная	0103000020E61000000100000005000000C4263273819941405AB8ACC266C04D40C426327381994140B5E0455F41C44D40F964C57075A04140B5E0455F41C44D40F964C57075A041405AB8ACC266C04D40C4263273819941405AB8ACC266C04D40
67006	8329	35.199263000000002	35.253583999999996	59.533245000000001	59.503135999999998	Киевская	0103000020E61000000100000005000000C4263273819941405AB8ACC266C04D40C426327381994140B5E0455F41C44D40F964C57075A04140B5E0455F41C44D40F964C57075A041405AB8ACC266C04D40C4263273819941405AB8ACC266C04D40
67247	59007	34.64873	34.690770999999998	59.509793999999999	59.483781	Школьная 	0103000020E6100000010000000500000090F7AA95095341408DB62A89ECBD4D4090F7AA950953414038D906EE40C14D403A03232F6B58414038D906EE40C14D403A03232F6B5841408DB62A89ECBD4D4090F7AA95095341408DB62A89ECBD4D40
67618	59007	34.64873	34.690770999999998	59.509793999999999	59.483781	Сенная	0103000020E6100000010000000500000090F7AA95095341408DB62A89ECBD4D4090F7AA950953414038D906EE40C14D403A03232F6B58414038D906EE40C14D403A03232F6B5841408DB62A89ECBD4D4090F7AA95095341408DB62A89ECBD4D40
24374	51017	34.64873	34.690770999999998	59.509793999999999	59.483781	Комсомольская	0103000020E6100000010000000500000090F7AA95095341408DB62A89ECBD4D4090F7AA950953414038D906EE40C14D403A03232F6B58414038D906EE40C14D403A03232F6B5841408DB62A89ECBD4D4090F7AA95095341408DB62A89ECBD4D40
1944	7109	33.850172999999998	33.854610000000001	59.469782000000002	59.469749999999998	Южная улица	0103000020E610000001000000050000009A780778D2EC4040E3A59BC420BC4D409A780778D2EC4040EF1F0BD121BC4D40D36A48DC63ED4040EF1F0BD121BC4D40D36A48DC63ED4040E3A59BC420BC4D409A780778D2EC4040E3A59BC420BC4D40
67608	7109	33.842097000000003	33.842500999999999	59.479942999999999	59.470737999999997	Школьная	0103000020E61000000100000005000000A587A1D5C9EB4040027E8D2441BC4D40A587A1D5C9EB4040D978B0C56EBD4D4074ECA012D7EB4040D978B0C56EBD4D4074ECA012D7EB4040027E8D2441BC4D40A587A1D5C9EB4040027E8D2441BC4D40
67535	7109	33.837919999999997	33.856084000000003	59.475637999999996	59.475422999999999	Вишнякова	0103000020E6100000010000000500000008556AF640EB404013622EA9DABC4D4008556AF640EB40400F5EBBB4E1BC4D407F50172994ED40400F5EBBB4E1BC4D407F50172994ED404013622EA9DABC4D4008556AF640EB404013622EA9DABC4D40
23161	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Школьная	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23018	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Чапаева	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23224	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Тургенева	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23201	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Тимирязева	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23200	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Победы	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23114	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Липовая	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23249	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Кировоградская	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23164	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Калининградское шоссе	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23302	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	К.Маркса	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23258	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	К.Лямина	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23041	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Искры	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23256	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Бурова	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23113	7525	21.807655	21.950369999999999	55.098196999999999	55.047626000000001	Баумана	0103000020E610000001000000050000006D73637AC2CE35403B38D89B18864B406D73637AC2CE35405CC823B8918C4B407A19C5724BF335405CC823B8918C4B407A19C5724BF335403B38D89B18864B406D73637AC2CE35403B38D89B18864B40
23223	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Советская	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23332	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Рыбацкая	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23071	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Пионерская	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23150	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Парковая	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23056	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Молодежная	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
24177	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Лопатина	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23259	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Коммунистическая	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23160	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Калининградская	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23040	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Калинина	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23331	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Заводская	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
23255	5894	20.117393	20.149086	54.692734000000002	54.667681000000002	Восточная	0103000020E6100000010000000500000082C7B7770D1E34408E942D9276554B4082C7B7770D1E3440E469F981AB584B409D4A06802A263440E469F981AB584B409D4A06802A2634408E942D9276554B4082C7B7770D1E34408E942D9276554B40
24334	50985	20.124517000000001	20.178308000000001	54.951715	54.936630999999998	Яблоневая	0103000020E61000000100000005000000C9CB9A58E01F3440BBB54C86E3774B40C9CB9A58E01F34406B0E10CCD1794B407C9DD497A52D34406B0E10CCD1794B407C9DD497A52D3440BBB54C86E3774B40C9CB9A58E01F3440BBB54C86E3774B40
24335	50985	20.124517000000001	20.178308000000001	54.951715	54.936630999999998	Новая	0103000020E61000000100000005000000C9CB9A58E01F3440BBB54C86E3774B40C9CB9A58E01F34406B0E10CCD1794B407C9DD497A52D34406B0E10CCD1794B407C9DD497A52D3440BBB54C86E3774B40C9CB9A58E01F3440BBB54C86E3774B40
67635	47440	19.998069999999998	20.012550999999998	54.742601000000001	54.728409999999997	Железнодорожная	0103000020E61000000100000005000000641EF98381FF3340280AF4893C5D4B40641EF98381FF33400B7DB08C0D5F4B403788D68A360334400B7DB08C0D5F4B403788D68A36033440280AF4893C5D4B40641EF98381FF3340280AF4893C5D4B40
23086	3708	20.212786000000001	20.249365000000001	54.9572	54.942686999999999	Флотская	0103000020E61000000100000005000000F20BAF2479363440A3AEB5F7A9784B40F20BAF247936344098DD9387857A4B405DC47762D63F344098DD9387857A4B405DC47762D63F3440A3AEB5F7A9784B40F20BAF2479363440A3AEB5F7A9784B40
22974	3708	20.212786000000001	20.249365000000001	54.9572	54.942686999999999	Рензаева	0103000020E61000000100000005000000F20BAF2479363440A3AEB5F7A9784B40F20BAF247936344098DD9387857A4B405DC47762D63F344098DD9387857A4B405DC47762D63F3440A3AEB5F7A9784B40F20BAF2479363440A3AEB5F7A9784B40
24332	3708	20.212786000000001	20.249365000000001	54.9572	54.942686999999999	Комсомольская	0103000020E61000000100000005000000F20BAF2479363440A3AEB5F7A9784B40F20BAF247936344098DD9387857A4B405DC47762D63F344098DD9387857A4B405DC47762D63F3440A3AEB5F7A9784B40F20BAF2479363440A3AEB5F7A9784B40
24257	3708	20.212786000000001	20.249365000000001	54.9572	54.942686999999999	Гагарина	0103000020E61000000100000005000000F20BAF2479363440A3AEB5F7A9784B40F20BAF247936344098DD9387857A4B405DC47762D63F344098DD9387857A4B405DC47762D63F3440A3AEB5F7A9784B40F20BAF2479363440A3AEB5F7A9784B40
23186	3708	20.212786000000001	20.249365000000001	54.9572	54.942686999999999	Армейская	0103000020E61000000100000005000000F20BAF2479363440A3AEB5F7A9784B40F20BAF247936344098DD9387857A4B405DC47762D63F344098DD9387857A4B405DC47762D63F3440A3AEB5F7A9784B40F20BAF2479363440A3AEB5F7A9784B40
24172	50968	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	Первомайская	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
23122	6464	20.279952999999999	20.290794999999999	54.759721999999996	54.747683000000002	Гарнизонная	0103000020E61000000100000005000000C66AF3FFAA47344039639813B45F4B40C66AF3FFAA4734409E060C923E614B401FD7868A714A34409E060C923E614B401FD7868A714A344039639813B45F4B40C66AF3FFAA47344039639813B45F4B40
55468	56665	19.868397999999999	19.88552	54.639721000000002	54.618769999999998	Школьная	0103000020E610000001000000050000006CE9D1544FDE33407ADFF8DA334F4B406CE9D1544FDE33403FC8B260E2514B4034F44F70B1E233403FC8B260E2514B4034F44F70B1E233407ADFF8DA334F4B406CE9D1544FDE33407ADFF8DA334F4B40
24181	1269	20.534355999999999	20.589089999999999	54.683225999999998	54.681778999999999	улица Емельянова	0103000020E61000000100000005000000DF6B088ECB883440BF0CC68844574B40DF6B088ECB88344071E316F373574B4090662C9ACE96344071E316F373574B4090662C9ACE963440BF0CC68844574B40DF6B088ECB883440BF0CC68844574B40
7195	1269	20.494164999999999	20.517440000000001	54.699627999999997	54.696938000000003	улица Багратиона	0103000020E61000000100000005000000EDD3F198817E34407AABAE4335594B40EDD3F198817E3440D5AE09698D594B406AA4A5F276843440D5AE09698D594B406AA4A5F2768434407AABAE4335594B40EDD3F198817E34407AABAE4335594B40
7491	1269	20.532306999999999	20.548342000000002	54.735427999999999	54.730119999999999	улица Артиллерийская	0103000020E610000001000000050000008F6E844545883440E8137992745D4B408F6E84454588344006483481225E4B40F3052D24608C344006483481225E4B40F3052D24608C3440E8137992745D4B408F6E844545883440E8137992745D4B40
7422	1269	20.525093999999999	20.547058	54.772016000000001	54.721223999999999	улица Александра Невского	0103000020E610000001000000050000006953758F6C8634408F8B6A11515C4B406953758F6C8634408FFE976BD1624B40E2033BFE0B8C34408FFE976BD1624B40E2033BFE0B8C34408F8B6A11515C4B406953758F6C8634408F8B6A11515C4B40
24238	1269	20.485271999999998	20.485783999999999	54.720002000000001	54.715482999999999	сержанта Колоскова	0103000020E610000001000000050000001DAA29C93A7C344007EC6AF2945B4B401DAA29C93A7C3440FD868906295C4B4089EB18575C7C3440FD868906295C4B4089EB18575C7C344007EC6AF2945B4B401DAA29C93A7C344007EC6AF2945B4B40
23334	1269	20.425128999999998	20.499483000000001	54.722814999999997	54.719123000000003	проспект Мира	0103000020E61000000100000005000000C8940F41D56C34409566F3380C5C4B40C8940F41D56C34407407B133855C4B4071E82D1EDE7F34407407B133855C4B4071E82D1EDE7F34409566F3380C5C4B40C8940F41D56C34409566F3380C5C4B40
24279	1269	20.501557999999999	20.506174999999999	54.744976000000001	54.744269000000003	полковника Ефремова	0103000020E61000000100000005000000130CE71A668034409C36E334445F4B40130CE71A668034400727A25F5B5F4B40840D4FAF948134400727A25F5B5F4B40840D4FAF948134409C36E334445F4B40130CE71A668034409C36E334445F4B40
24255	1269	20.505061000000001	20.506166	54.720438999999999	54.715915000000003	подполковника Иванникова	0103000020E610000001000000050000002D7C7DAD4B813440A1DB4B1AA35B4B402D7C7DAD4B813440A8E15B58375C4B40DE58501894813440A8E15B58375C4B40DE58501894813440A1DB4B1AA35B4B402D7C7DAD4B813440A1DB4B1AA35B4B40
7277	1269	20.490338000000001	20.506364000000001	54.709538000000002	54.706671999999998	маршала Баграмяна набережная	0103000020E610000001000000050000006EFC89CA867D3440DC7F643A745A4B406EFC89CA867D344077A22424D25A4B402BDF3312A181344077A22424D25A4B402BDF3312A1813440DC7F643A745A4B406EFC89CA867D3440DC7F643A745A4B40
24312	1269	20.463927999999999	20.490212	54.730733999999998	54.729267999999998	лейтенанта Яналова	0103000020E61000000100000005000000DDB243FCC3763440790261A7585D4B40DDB243FCC3763440A20914B1885D4B40541B9C887E7D3440A20914B1885D4B40541B9C887E7D3440790261A7585D4B40DDB243FCC3763440790261A7585D4B40
67678	1269	20.504539999999999	20.513380000000002	54.716934000000002	54.715155000000003	генерала Соммера	0103000020E610000001000000050000001A868F88298134401349F4328A5B4B401A868F8829813440FBB1497EC45B4B40A56B26DF6C833440FBB1497EC45B4B40A56B26DF6C8334401349F4328A5B4B401A868F88298134401349F4328A5B4B40
23244	1269	20.496231000000002	20.518409999999999	54.731471999999997	54.724618999999997	генерал-лейтенанта Озерова	0103000020E61000000100000005000000EA42ACFE087F3440B587BD50C05C4B40EA42ACFE087F344048F8DEDFA05D4B405BEB8B84B684344048F8DEDFA05D4B405BEB8B84B6843440B587BD50C05C4B40EA42ACFE087F3440B587BD50C05C4B40
24329	1269	20.536052999999999	20.589862	54.746206999999998	54.713309000000002	Юрия Гагарина	0103000020E6100000010000000500000035ECF7C43A893440A37895B54D5B4B4035ECF7C43A893440EC8502B6835F4B4035272F3201973440EC8502B6835F4B4035272F3201973440A37895B54D5B4B4035ECF7C43A893440A37895B54D5B4B40
24294	1269	20.513389	20.514196999999999	54.703639000000003	54.700955	Эпроновская	0103000020E610000001000000050000004B2025766D833440DD7BB8E4B8594B404B2025766D8334405798BED7105A4B4089B3226AA28334405798BED7105A4B4089B3226AA2833440DD7BB8E4B8594B404B2025766D833440DD7BB8E4B8594B40
24297	1269	20.523323999999999	20.533321999999998	54.686874000000003	54.686114000000003	Черниговская	0103000020E610000001000000050000003F36C98FF8853440F4A96395D2574B403F36C98FF8853440823CBB7CEB574B40C03C64CA87883440823CBB7CEB574B40C03C64CA87883440F4A96395D2574B403F36C98FF8853440F4A96395D2574B40
24285	1269	20.479019000000001	20.498594000000001	54.726979999999998	54.723762000000001	Чайковского	0103000020E61000000100000005000000A2293BFDA07A3440350BB43BA45C4B40A2293BFDA07A34404C6C3EAE0D5D4B4059FB3BDBA37F34404C6C3EAE0D5D4B4059FB3BDBA37F3440350BB43BA45C4B40A2293BFDA07A3440350BB43BA45C4B40
15846	1269	20.509167000000001	20.514610999999999	54.711269999999999	54.709443999999998	Центральная площадь	0103000020E61000000100000005000000D333BDC458823440F52B9D0FCF5A4B40D333BDC4588234401E5036E50A5B4B406F29E78BBD8334401E5036E50A5B4B406F29E78BBD833440F52B9D0FCF5A4B40D333BDC458823440F52B9D0FCF5A4B40
24256	1269	20.518563	20.536161	54.713521999999998	54.711633999999997	Фрунзе	0103000020E6100000010000000500000068EA758BC08434405F5CAAD2165B4B4068EA758BC0843440FE7C5BB0545B4B400264E8D841893440FE7C5BB0545B4B400264E8D8418934405F5CAAD2165B4B4068EA758BC08434405F5CAAD2165B4B40
23065	1269	20.498773	20.503012999999999	54.674804000000002	54.660536999999998	Ульяны Громовой	0103000020E61000000100000005000000B8205B96AF7F34402366F6798C544B40B8205B96AF7F3440E19A3BFA5F564B407D76C075C5803440E19A3BFA5F564B407D76C075C58034402366F6798C544B40B8205B96AF7F34402366F6798C544B40
2323	1269	20.445557000000001	20.450219000000001	54.695044000000003	54.693857999999999	Транспортный тупик	0103000020E61000000100000005000000FE80070610723440B308C556D0584B40FE80070610723440F9A3A833F7584B40AF09698D41733440F9A3A833F7584B40AF09698D41733440B308C556D0584B40FE80070610723440B308C556D0584B40
24280	1269	20.526054999999999	20.530294999999999	54.714432000000002	54.714010999999999	Томская	0103000020E61000000100000005000000B4E55C8AAB863440FCFD62B6645B4B40B4E55C8AAB863440A29BFD81725B4B40793BC269C1873440A29BFD81725B4B40793BC269C1873440FCFD62B6645B4B40B4E55C8AAB863440FCFD62B6645B4B40
7907	1269	20.404522	20.436851999999998	54.726928000000001	54.711737999999997	Тенистая аллея	0103000020E610000001000000050000003483F8C08E67344004A9143B1A5B4B403483F8C08E673440FA4509FA0B5D4B4033315D88D56F3440FA4509FA0B5D4B4033315D88D56F344004A9143B1A5B4B403483F8C08E67344004A9143B1A5B4B40
24293	1269	20.518409999999999	20.530177999999999	54.741073	54.731471999999997	Тельмана	0103000020E610000001000000050000005BEB8B84B684344048F8DEDFA05D4B405BEB8B84B68434406C79E57ADB5E4B40060FD3BEB98734406C79E57ADB5E4B40060FD3BEB987344048F8DEDFA05D4B405BEB8B84B684344048F8DEDFA05D4B40
24248	1269	20.482837	20.522227999999998	54.681840999999999	54.676074	Судостроительная	0103000020E610000001000000050000007B4CA4349B7B344084D6C39789564B407B4CA4349B7B34403509DE9046574B40340EF5BBB08534403509DE9046574B40340EF5BBB085344084D6C39789564B407B4CA4349B7B344084D6C39789564B40
23235	1269	20.306408000000001	20.494164999999999	54.696938000000003	54.630633000000003	Суворова	0103000020E61000000100000005000000973B33C1704E3440A2630795B8504B40973B33C1704E34407AABAE4335594B40EDD3F198817E34407AABAE4335594B40EDD3F198817E3440A2630795B8504B40973B33C1704E3440A2630795B8504B40
24220	1269	20.283932	20.648828000000002	54.778762	54.630732000000002	Старшего сержанта Карташева	0103000020E61000000100000005000000B2497EC4AF483440354580D3BB504B40B2497EC4AF4834400CAF2479AE634B40A6BA809719A634400CAF2479AE634B40A6BA809719A63440354580D3BB504B40B2497EC4AF483440354580D3BB504B40
24265	1269	20.457405999999999	20.460253000000002	54.731425000000002	54.723194999999997	Спортивная	0103000020E6100000010000000500000082FE428F18753440BBD05CA7915C4B4082FE428F18753440083D9B559F5D4B40CAE2FE23D3753440083D9B559F5D4B40CAE2FE23D3753440BBD05CA7915C4B4082FE428F18753440BBD05CA7915C4B40
24269	1269	20.479980000000001	20.483044	54.738500000000002	54.738162000000003	Солдатская	0103000020E61000000100000005000000EDBB22F8DF7A34403293A8177C5E4B40EDBB22F8DF7A34404A0C022B875E4B406E8786C5A87B34404A0C022B875E4B406E8786C5A87B34403293A8177C5E4B40EDBB22F8DF7A34403293A8177C5E4B40
24261	1269	20.489322999999999	20.495405000000002	54.747267000000001	54.740236000000003	Согласия	0103000020E610000001000000050000003C2EAA45447D344033A9A10DC05E4B403C2EAA45447D3440A530EF71A65F4B405F46B1DCD27E3440A530EF71A65F4B405F46B1DCD27E344033A9A10DC05E4B403C2EAA45447D344033A9A10DC05E4B40
2065	1269	20.422839	20.499563999999999	54.771948999999999	54.720193999999999	Советский проспект	0103000020E610000001000000050000002D793C2D3F6C3440416326512F5C4B402D793C2D3F6C344007978E39CF624B404A42226DE37F344007978E39CF624B404A42226DE37F3440416326512F5C4B402D793C2D3F6C3440416326512F5C4B40
7800	1269	20.510963	20.524528	54.694336999999997	54.655552999999998	Смелых аллея	0103000020E610000001000000050000004F779E78CE823440B8E52329E9534B404F779E78CE8234408DB3E908E0584B4017D68D77478634408DB3E908E0584B4017D68D7747863440B8E52329E9534B404F779E78CE823440B8E52329E9534B40
24323	1269	20.513856000000001	20.518743000000001	54.720657000000003	54.714885000000002	Сергеева	0103000020E6100000010000000500000077DA1A118C83344053B3075A815B4B4077DA1A118C8334401651137D3E5C4B4068075C57CC8434401651137D3E5C4B4068075C57CC84344053B3075A815B4B4077DA1A118C83344053B3075A815B4B40
24277	1269	20.566918999999999	20.569137999999999	54.713963999999997	54.708945	Свердлова	0103000020E61000000100000005000000247B849A21913440D4D4B2B5BE5A4B40247B849A21913440BB421F2C635B4B402DE92807B3913440BB421F2C635B4B402DE92807B3913440D4D4B2B5BE5A4B40247B849A21913440D4D4B2B5BE5A4B40
24326	1269	20.450983000000001	20.466208999999999	54.713329999999999	54.712159999999997	Радищева	0103000020E610000001000000050000004E0D349F737334407AC2120F285B4B404E0D349F73733440BAA0BE654E5B4B40D219187959773440BAA0BE654E5B4B40D2191879597734407AC2120F285B4B404E0D349F737334407AC2120F285B4B40
24301	1269	20.473458999999998	20.473728000000001	54.718837000000001	54.715561000000001	Пушкина	0103000020E6100000010000000500000032FFE89B3479344083A5BA80975B4B4032FFE89B34793440CF13CFD9025C4B401233FB3C46793440CF13CFD9025C4B401233FB3C4679344083A5BA80975B4B4032FFE89B3479344083A5BA80975B4B40
24317	1269	20.512499999999999	20.515940000000001	54.726252000000002	54.711160999999997	Пролетарская	0103000020E6100000010000000500000033333333338334406798DA52075B4B403333333333833440CA5356D3F55C4B40C0B2D2A414843440CA5356D3F55C4B40C0B2D2A4148434406798DA52075B4B4033333333338334406798DA52075B4B40
23127	1269	20.283932	20.648828000000002	54.778762	54.630732000000002	Подполковника Емельянова	0103000020E61000000100000005000000B2497EC4AF483440354580D3BB504B40B2497EC4AF4834400CAF2479AE634B40A6BA809719A634400CAF2479AE634B40A6BA809719A63440354580D3BB504B40B2497EC4AF483440354580D3BB504B40
24267	1269	20.526729	20.529235	54.719321000000001	54.712966000000002	Пионерская	0103000020E61000000100000005000000D3DA34B6D786344079944A78425B4B40D3DA34B6D7863440BB29E5B5125C4B4008E6E8F17B873440BB29E5B5125C4B4008E6E8F17B87344079944A78425B4B40D3DA34B6D786344079944A78425B4B40
16399	1269	20.468626	20.470934	54.680326999999998	54.677818000000002	Октябрьская площадь	0103000020E61000000100000005000000280EA0DFF7773440F0517FBDC2564B40280EA0DFF7773440FBCA83F414574B40109370218F783440FBCA83F414574B40109370218F783440F0517FBDC2564B40280EA0DFF7773440F0517FBDC2564B40
24324	1269	20.508987000000001	20.513594999999999	54.742714999999997	54.735407000000002	Озерная	0103000020E61000000100000005000000D316D7F84C823440EF1F0BD1215E4B40D316D7F84C823440D39FFD48115F4B409D6340F67A833440D39FFD48115F4B409D6340F67A833440EF1F0BD1215E4B40D316D7F84C823440EF1F0BD1215E4B40
24313	1269	20.509715	20.510164	54.704180000000001	54.699404000000001	Новый Вал	0103000020E61000000100000005000000D847A7AE7C8234408658FD1186594B40D847A7AE7C823440A73FFB91225A4B40B7989F1B9A823440A73FFB91225A4B40B7989F1B9A8234408658FD1186594B40D847A7AE7C8234408658FD1186594B40
24318	1269	20.500246000000001	20.516704000000001	54.666327000000003	54.665171999999998	Николая Карамзина	0103000020E610000001000000050000006FF4311F10803440821B295B24554B406FF4311F108034408DB800344A554B405FB69DB6468434408DB800344A554B405FB69DB646843440821B295B24554B406FF4311F10803440821B295B24554B40
7260	1269	20.495152999999998	20.611160999999999	54.710979000000002	54.703862999999998	Московский проспект	0103000020E610000001000000050000002B84D558C27E3440A6EECA2E185A4B402B84D558C27E34404792205C015B4B4035971B0C759C34404792205C015B4B4035971B0C759C3440A6EECA2E185A4B402B84D558C27E3440A6EECA2E185A4B40
24311	1269	20.557037999999999	20.560639999999999	54.727505000000001	54.723699000000003	Молодой Гвардии	0103000020E6100000010000000500000016A1D80A9A8E3440EF92382BA25C4B4016A1D80A9A8E3440975643E21E5D4B4056D4601A868F3440975643E21E5D4B4056D4601A868F3440EF92382BA25C4B4016A1D80A9A8E3440EF92382BA25C4B40
24305	1269	20.512346999999998	20.521706999999999	54.739216999999996	54.738852999999999	Молодежная	0103000020E610000001000000050000002634492C2983344097C62FBC925E4B402634492C29833440D8D2A3A99E5E4B40221807978E853440D8D2A3A99E5E4B40221807978E85344097C62FBC925E4B402634492C2983344097C62FBC925E4B40
24170	1269	20.425128999999998	20.499483000000001	54.722814999999997	54.719123000000003	Мира	0103000020E61000000100000005000000C8940F41D56C34409566F3380C5C4B40C8940F41D56C34407407B133855C4B4071E82D1EDE7F34407407B133855C4B4071E82D1EDE7F34409566F3380C5C4B40C8940F41D56C34409566F3380C5C4B40
24299	1269	20.494551000000001	20.505510999999998	54.679811000000001	54.678395999999999	Машиностроительная	0103000020E610000001000000050000004034F3E49A7E34405DDE1CAED5564B404034F3E49A7E3440043BFE0B04574B40ACC43C2B69813440043BFE0B04574B40ACC43C2B698134405DDE1CAED5564B404034F3E49A7E34405DDE1CAED5564B40
24328	1269	20.480402999999999	20.480447999999999	54.681471999999999	54.677228999999997	Маршала Новикова	0103000020E6100000010000000500000079E6E5B0FB7A34408E739B70AF564B4079E6E5B0FB7A3440E29178793A574B40B96DDFA3FE7A3440E29178793A574B40B96DDFA3FE7A34408E739B70AF564B4079E6E5B0FB7A34408E739B70AF564B40
23130	1269	20.283932	20.648828000000002	54.778762	54.630732000000002	Магнитогорская	0103000020E61000000100000005000000B2497EC4AF483440354580D3BB504B40B2497EC4AF4834400CAF2479AE634B40A6BA809719A634400CAF2479AE634B40A6BA809719A63440354580D3BB504B40B2497EC4AF483440354580D3BB504B40
2362	1269	20.500910999999999	20.511915999999999	54.671382999999999	54.671008	Любы Шевцовой бульвар	0103000020E61000000100000005000000E7340BB43B8034405CAD1397E3554B40E7340BB43B803440910BCEE0EF554B40944C4EED0C833440910BCEE0EF554B40944C4EED0C8334405CAD1397E3554B40E7340BB43B8034405CAD1397E3554B40
24258	1269	20.525964999999999	20.538021000000001	54.721198000000001	54.709646999999997	Литовский вал	0103000020E6100000010000000500000034D769A4A58634402D5A80B6D55A4B4034D769A4A586344066F84F37505C4B40AC8F87BEBB89344066F84F37505C4B40AC8F87BEBB8934402D5A80B6D55A4B4034D769A4A58634402D5A80B6D55A4B40
24249	1269	20.483906000000001	20.487185	54.678494000000001	54.671050000000001	Летняя	0103000020E6100000010000000500000093567C43E17B34408BFD65F7E4554B4093567C43E17B3440204432E4D8564B400D1AFA27B87C3440204432E4D8564B400D1AFA27B87C34408BFD65F7E4554B4093567C43E17B34408BFD65F7E4554B40
24252	1269	20.527446999999999	20.548998000000001	54.726880999999999	54.724182999999996	Куйбышева	0103000020E61000000100000005000000915F3FC406873440DAA84E07B25C4B40915F3FC406873440B98AC56F0A5D4B40C59107228B8C3440B98AC56F0A5D4B40C59107228B8C3440DAA84E07B25C4B40915F3FC406873440DAA84E07B25C4B40
24239	1269	20.469946	20.475066999999999	54.750266000000003	54.720495999999997	Красная	0103000020E61000000100000005000000D2E28C614E7834400C738236395C4B40D2E28C614E7834407FA65EB708604B40A968ACFD9D7934407FA65EB708604B40A968ACFD9D7934400C738236395C4B40D2E28C614E7834400C738236395C4B40
24302	1269	20.478390000000001	20.47945	54.736218000000001	54.720506	Комсомольская	0103000020E61000000100000005000000C3BB5CC4777A34403049658A395C4B40C3BB5CC4777A3440FF5C34643C5E4B403411363CBD7A3440FF5C34643C5E4B403411363CBD7A34403049658A395C4B40C3BB5CC4777A34403049658A395C4B40
24321	1269	20.518141	20.523880999999999	54.721457999999998	54.711972000000003	Клиническая	0103000020E610000001000000050000007CB779E3A484344078D503E6215B4B407CB779E3A484344002B859BC585C4B40EBFEB1101D86344002B859BC585C4B40EBFEB1101D86344078D503E6215B4B407CB779E3A484344078D503E6215B4B40
24229	1269	20.482558999999998	20.498000999999999	54.728310999999998	54.724474000000001	Кирова	0103000020E61000000100000005000000F56393FC887B3440B2666490BB5C4B40F56393FC887B344095287B4B395D4B40136058FE7C7F344095287B4B395D4B40136058FE7C7F3440B2666490BB5C4B40F56393FC887B3440B2666490BB5C4B40
24245	1269	20.460612999999999	20.504180999999999	54.694727	54.681170000000002	Киевская	0103000020E61000000100000005000000C91CCBBBEA75344017821C9430574B40C91CCBBBEA753440F85278D0EC584B40BB438A0112813440F85278D0EC584B40BB438A011281344017821C9430574B40C91CCBBBEA75344017821C9430574B40
24276	1269	20.463927999999999	20.466640999999999	54.735849000000002	54.711525000000002	Каштановая Аллея	0103000020E61000000100000005000000DDB243FCC3763440A9A44E40135B4B40DDB243FCC3763440ACE5CE4C305E4B4005F9D9C875773440ACE5CE4C305E4B4005F9D9C875773440A9A44E40135B4B40DDB243FCC3763440A9A44E40135B4B40
24325	1269	20.460963	20.487212	54.729205	54.722794	Карла Маркса	0103000020E6100000010000000500000082AAD1AB017634405DDF8783845C4B4082AAD1AB01763440338AE596565D4B400038F6ECB97C3440338AE596565D4B400038F6ECB97C34405DDF8783845C4B4082AAD1AB017634405DDF8783845C4B40
23335	1269	20.459624999999999	20.465517999999999	54.685687999999999	54.662421999999999	Камская	0103000020E610000001000000050000008B6CE7FBA975344051137D3ECA544B408B6CE7FBA97534403CA1D79FC4574B4007B309302C7734403CA1D79FC4574B4007B309302C77344051137D3ECA544B408B6CE7FBA975344051137D3ECA544B40
24272	1269	20.496051000000001	20.496815000000002	54.676188000000003	54.671461000000001	Иванихиной	0103000020E61000000100000005000000EA25C632FD7E34400DC51D6FF2554B40EA25C632FD7E34404DF910548D564B40892991442F7F34404DF910548D564B40892991442F7F34400DC51D6FF2554B40EA25C632FD7E34400DC51D6FF2554B40
24274	1269	20.484615999999999	20.485505	54.728648999999997	54.720356000000002	Зоологическая	0103000020E610000001000000050000004B1E4FCB0F7C34401BBD1AA0345C4B404B1E4FCB0F7C3440ADA1D45E445D4B40630B410E4A7C3440ADA1D45E445D4B40630B410E4A7C34401BBD1AA0345C4B404B1E4FCB0F7C34401BBD1AA0345C4B40
24307	1269	20.523028	20.53379	54.685021999999996	54.684772000000002	Зои Космодемьянской	0103000020E610000001000000050000006DE4BA29E5853440B79BE09BA6574B406DE4BA29E58534402F8507CDAE574B408DEE2076A68834402F8507CDAE574B408DEE2076A6883440B79BE09BA6574B406DE4BA29E5853440B79BE09BA6574B40
24264	1269	20.438388	20.441676000000001	54.678837999999999	54.676229999999997	Заводская	0103000020E6100000010000000500000077F52A323A7034407B4963B48E564B4077F52A323A7034401AA4E029E4564B40986DA7AD117134401AA4E029E4564B40986DA7AD117134407B4963B48E564B4077F52A323A7034407B4963B48E564B40
8084	1269	20.495054	20.500713999999999	54.727614000000003	54.725617999999997	Желябова переулок	0103000020E6100000010000000500000005C1E3DBBB7E3440C8B1F50CE15C4B4005C1E3DBBB7E34404E0E9F74225D4B403BA6EECA2E8034404E0E9F74225D4B403BA6EECA2E803440C8B1F50CE15C4B4005C1E3DBBB7E3440C8B1F50CE15C4B40
24268	1269	20.517288000000001	20.52318	54.686146000000001	54.685828000000001	Дюнная	0103000020E61000000100000005000000FE9C82FC6C8434402E573F36C9574B40FE9C82FC6C843440FF23D3A1D3574B40D9EBDD1FEF853440FF23D3A1D3574B40D9EBDD1FEF8534402E573F36C9574B40FE9C82FC6C8434402E573F36C9574B40
24250	1269	20.498639000000001	20.502331000000002	54.678972999999999	54.677256	Дрожжевая	0103000020E61000000100000005000000998235CEA67F344088821953B0564B40998235CEA67F3440FAEE5696E8564B4059C4B0C398803440FAEE5696E8564B4059C4B0C39880344088821953B0564B40998235CEA67F344088821953B0564B40
24291	1269	20.517313999999999	20.54598	54.698363999999998	54.644680999999999	Дзержинского	0103000020E6100000010000000500000050C3B7B06E84344021AD31E884524B4050C3B7B06E843440145AD6FD63594B4024456458C58B3440145AD6FD63594B4024456458C58B344021AD31E884524B4050C3B7B06E84344021AD31E884524B40
24271	1269	20.492925	20.510819999999999	54.768298000000001	54.719794	Горького	0103000020E610000001000000050000007C613255307E3440B3EDB435225C4B407C613255307E344086CABF9657624B4089247A19C582344086CABF9657624B4089247A19C5823440B3EDB435225C4B407C613255307E3440B3EDB435225C4B40
24270	1269	20.516883	20.535820000000001	54.755519	54.742823999999999	Герцена	0103000020E61000000100000005000000BEDBBC71528434408A5759DB145F4B40BEDBBC7152843440D940BAD8B4604B40F08AE07F2B893440D940BAD8B4604B40F08AE07F2B8934408A5759DB145F4B40BEDBBC71528434408A5759DB145F4B40
24330	1269	20.490212	20.508483999999999	54.742840000000001	54.730364000000002	Гайдара	0103000020E61000000100000005000000541B9C887E7D34407F164B917C5D4B40541B9C887E7D344090149161155F4B400D8AE6012C82344090149161155F4B400D8AE6012C8234407F164B917C5D4B40541B9C887E7D34407F164B917C5D4B40
24228	1269	20.499303000000001	20.509059000000001	54.712336000000001	54.711711999999999	Вагнера	0103000020E6100000010000000500000071CB4752D27F3440DB15FA60195B4B4071CB4752D27F3440B9E177D32D5B4B4006BCCCB051823440B9E177D32D5B4B4006BCCCB051823440DB15FA60195B4B4071CB4752D27F3440DB15FA60195B4B40
24202	1269	20.283932	20.648828000000002	54.778762	54.630732000000002	Березовая	0103000020E61000000100000005000000B2497EC4AF483440354580D3BB504B40B2497EC4AF4834400CAF2479AE634B40A6BA809719A634400CAF2479AE634B40A6BA809719A63440354580D3BB504B40B2497EC4AF483440354580D3BB504B40
24292	1269	20.492296	20.518167999999999	54.680669999999999	54.674554000000001	Батальная	0103000020E610000001000000050000009DF3531C077E344068B114C957564B409DF3531C077E344025AFCE3120574B406FD575A8A684344025AFCE3120574B406FD575A8A684344068B114C957564B409DF3531C077E344068B114C957564B40
24196	1269	20.283932	20.648828000000002	54.778762	54.630732000000002	Балтийское шоссе	0103000020E61000000100000005000000B2497EC4AF483440354580D3BB504B40B2497EC4AF4834400CAF2479AE634B40A6BA809719A634400CAF2479AE634B40A6BA809719A63440354580D3BB504B40B2497EC4AF483440354580D3BB504B40
24352	1269	20.561385999999999	20.563227000000001	54.708539000000002	54.704503000000003	Бакинская	0103000020E61000000100000005000000A86E2EFEB68F34408A7780272D5A4B40A86E2EFEB68F34406478EC67B15A4B40653909A52F9034406478EC67B15A4B40653909A52F9034408A7780272D5A4B40A86E2EFEB68F34408A7780272D5A4B40
24242	1269	20.525093999999999	20.547058	54.772016000000001	54.721223999999999	Александра Невского	0103000020E610000001000000050000006953758F6C8634408F8B6A11515C4B406953758F6C8634408FFE976BD1624B40E2033BFE0B8C34408FFE976BD1624B40E2033BFE0B8C34408F8B6A11515C4B406953758F6C8634408F8B6A11515C4B40
24309	1269	20.481273999999999	20.482531999999999	54.735827999999998	54.720855	 космонавта Леонова	0103000020E61000000100000005000000446ADAC5347B34403C1405FA445C4B40446ADAC5347B344094BDA59C2F5E4B4002469737877B344094BDA59C2F5E4B4002469737877B34403C1405FA445C4B40446ADAC5347B34403C1405FA445C4B40
24304	1269	20.536052999999999	20.589862	54.746206999999998	54.713309000000002	 Юрия Гагарина	0103000020E6100000010000000500000035ECF7C43A893440A37895B54D5B4B4035ECF7C43A893440EC8502B6835F4B4035272F3201973440EC8502B6835F4B4035272F3201973440A37895B54D5B4B4035ECF7C43A893440A37895B54D5B4B40
24315	1269	20.483125000000001	20.483716999999999	54.684021999999999	54.682116999999998	 Школьная	0103000020E6100000010000000500000048E17A14AE7B3440D7851F9C4F574B4048E17A14AE7B34404CDF6B088E574B40EC8497E0D47B34404CDF6B088E574B40EC8497E0D47B3440D7851F9C4F574B4048E17A14AE7B3440D7851F9C4F574B40
24289	1269	20.459706000000001	20.478919999999999	54.728233000000003	54.723975000000003	 Чернышевского	0103000020E6100000010000000500000065C6DB4AAF753440910F7A36AB5C4B4065C6DB4AAF7534401A6F2BBD365D4B407B6649809A7A34401A6F2BBD365D4B407B6649809A7A3440910F7A36AB5C4B4065C6DB4AAF753440910F7A36AB5C4B40
24316	1269	20.500651000000001	20.50366	54.704434999999997	54.698431999999997	 Серпуховская	0103000020E61000000100000005000000AFB5F7A92A8034406C3D433866594B40AFB5F7A92A803440319413ED2A5A4B40A94D9CDCEF803440319413ED2A5A4B40A94D9CDCEF8034406C3D433866594B40AFB5F7A92A8034406C3D433866594B40
67675	1269	20.520764	20.521374999999999	54.711978000000002	54.709575000000001	 Сергея Тюленина	0103000020E6100000010000000500000024EF1CCA508534409487855AD35A4B4024EF1CCA508534405ABC5818225B4B40B6F3FDD4788534405ABC5818225B4B40B6F3FDD4788534409487855AD35A4B4024EF1CCA508534409487855AD35A4B40
24314	1269	20.506184000000001	20.507297999999999	54.702063000000003	54.700158999999999	 Мореходная	0103000020E610000001000000050000002BC24D4695813440028063CF9E594B402BC24D4695813440A75D4C33DD594B4082531F48DE813440A75D4C33DD594B4082531F48DE813440028063CF9E594B402BC24D4695813440028063CF9E594B40
67679	1269	20.436843	20.439916	54.729543	54.711561000000003	 Менделеева	0103000020E610000001000000050000008D7C5EF1D46F3440F60D4C6E145B4B408D7C5EF1D46F34404B033FAA615D4B40B5FCC0559E7034404B033FAA615D4B40B5FCC0559E703440F60D4C6E145B4B408D7C5EF1D46F3440F60D4C6E145B4B40
24287	1269	20.527446999999999	20.548998000000001	54.726880999999999	54.724182999999996	 Куйбышева	0103000020E61000000100000005000000915F3FC406873440DAA84E07B25C4B40915F3FC406873440B98AC56F0A5D4B40C59107228B8C3440B98AC56F0A5D4B40C59107228B8C3440DAA84E07B25C4B40915F3FC406873440DAA84E07B25C4B40
24283	1269	20.469011999999999	20.470116999999998	54.729782	54.727733999999998	 Кропоткина	0103000020E610000001000000050000007A6EA12B11783440F8174163265D4B407A6EA12B11783440D09A1F7F695D4B402B4B749659783440D09A1F7F695D4B402B4B749659783440F8174163265D4B407A6EA12B11783440F8174163265D4B40
67672	1269	20.478390000000001	20.47945	54.736218000000001	54.720506	 Комсомольская	0103000020E61000000100000005000000C3BB5CC4777A34403049658A395C4B40C3BB5CC4777A3440FF5C34643C5E4B403411363CBD7A3440FF5C34643C5E4B403411363CBD7A34403049658A395C4B40C3BB5CC4777A34403049658A395C4B40
24290	1269	20.495162000000001	20.509516999999999	54.742677999999998	54.738702000000004	 Зеленая	0103000020E61000000100000005000000D238D4EFC27E3440B2BE81C98D5E4B40D238D4EFC27E3440B6BA9C12105F4B408BC1C3B46F823440B6BA9C12105F4B408BC1C3B46F823440B2BE81C98D5E4B40D238D4EFC27E3440B2BE81C98D5E4B40
24319	1269	20.481632999999999	20.486089	54.731668999999997	54.731544999999997	 Войнич	0103000020E61000000100000005000000A3ACDF4C4C7B3440B2463D44A35D4B40A3ACDF4C4C7B34409E3F6D54A75D4B4002F22554707C34409E3F6D54A75D4B4002F22554707C3440B2463D44A35D4B40A3ACDF4C4C7B3440B2463D44A35D4B40
24286	1269	20.503202000000002	20.516838	54.697240000000001	54.696871000000002	 Богдана Хмельницкого	0103000020E610000001000000050000002448A5D8D1803440F243A51133594B402448A5D8D180344045BB0A293F594B407E54C37E4F84344045BB0A293F594B407E54C37E4F843440F243A51133594B402448A5D8D1803440F243A51133594B40
24308	1269	20.452932000000001	20.455106000000001	54.725113	54.713954000000001	 Бассейная	0103000020E61000000100000005000000D74FFF59F3733440986C3CD8625B4B40D74FFF59F3733440C573B680D05C4B40A036AAD381743440C573B680D05C4B40A036AAD381743440986C3CD8625B4B40D74FFF59F3733440986C3CD8625B4B40
24251	1269	20.525093999999999	20.547058	54.772016000000001	54.721223999999999	 Александра Невского	0103000020E610000001000000050000006953758F6C8634408F8B6A11515C4B406953758F6C8634408FFE976BD1624B40E2033BFE0B8C34408FFE976BD1624B40E2033BFE0B8C34408F8B6A11515C4B406953758F6C8634408F8B6A11515C4B40
24180	50975	22.167556000000001	22.235989	54.616970999999999	54.5747	проспект Ленина	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
24184	50975	22.167556000000001	22.235989	54.616970999999999	54.5747	Победы	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
67658	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	пр.Ленина	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67652	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Ю.Иванова	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67630	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Чехова	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67623	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Ушакова	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67638	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Советская 	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67646	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Сенявина 	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67644	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Московская	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67629	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Мечникова	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67627	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Красной Армии	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
67625	7926	19.877139	19.962451999999999	54.666468000000002	54.638235999999999	Гоголя	0103000020E61000000100000005000000D00B772E8CE033409F909DB7B1514B40D00B772E8CE033404FEACBD24E554B4044F8174163F633404FEACBD24E554B4044F8174163F633409F909DB7B1514B40D00B772E8CE033409F909DB7B1514B40
23135	45690	22.048852	22.061105000000001	54.774197000000001	54.766443000000002	Школьная	0103000020E610000001000000050000001D588E90810C3640C39FE1CD1A624B401D588E90810C3640A6D425E318634B40419FC893A40F3640A6D425E318634B40419FC893A40F3640C39FE1CD1A624B401D588E90810C3640C39FE1CD1A624B40
23319	25139	21.892806	21.905787	54.621975999999997	54.617826000000001	Калининградское шоссе	0103000020E610000001000000050000002EAC1BEF8EE435402B4F20EC144F4B402EAC1BEF8EE43540CD72D9E89C4F4B40572426A8E1E73540CD72D9E89C4F4B40572426A8E1E735402B4F20EC144F4B402EAC1BEF8EE435402B4F20EC144F4B40
67621	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	пер. Советский	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23147	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Тольятти	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
22985	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Театральная площадь	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23070	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Суворова	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23140	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Победы	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23141	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Октябрьская	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
22983	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Ленинградская	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23126	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Ленина	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23208	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Курчатова	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23174	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Каретная	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23029	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Калининградская	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23024	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Горького	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23026	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	Гагарина	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23066	8015	21.779250000000001	21.861840999999998	54.665463000000003	54.605359999999997	2-й Дачный переулок	0103000020E61000000100000005000000736891ED7CC735403D27BD6F7C4D4B40736891ED7CC735405AD93EE42D554B40185A9D9CA1DC35405AD93EE42D554B40185A9D9CA1DC35403D27BD6F7C4D4B40736891ED7CC735403D27BD6F7C4D4B40
23030	45725	21.883068000000002	21.896992000000001	54.650651000000003	54.641373000000002	Центральная	0103000020E61000000100000005000000E62494BE10E23540CAC4AD8218524B40E62494BE10E235400B0E2F8848534B400DC68844A1E535400B0E2F8848534B400DC68844A1E53540CAC4AD8218524B40E62494BE10E23540CAC4AD8218524B40
24187	46718	21.675988	21.682967999999999	54.650208999999997	54.647083000000002	Центральная	0103000020E610000001000000050000000B7DB08C0DAD35401766A19DD3524B400B7DB08C0DAD35404D486B0C3A534B40EB36A8FDD6AE35404D486B0C3A534B40EB36A8FDD6AE35401766A19DD3524B400B7DB08C0DAD35401766A19DD3524B40
23303	45759	21.709378999999998	21.741152	54.550367999999999	54.527144999999997	Школьная	0103000020E610000001000000050000001C78B5DC99B53540FD9FC37C79434B401C78B5DC99B53540E961687572464B40705D3123BCBD3540E961687572464B40705D3123BCBD3540FD9FC37C79434B401C78B5DC99B53540FD9FC37C79434B40
23267	45813	21.611642	21.627084	54.572502999999998	54.566020999999999	Детский переулок	0103000020E610000001000000050000002BDCF291949C3540B3EC496073484B402BDCF291949C354052EE3EC747494B4049D8B79388A0354052EE3EC747494B4049D8B79388A03540B3EC496073484B402BDCF291949C3540B3EC496073484B40
24214	47098	21.519879	21.526239	54.712575999999999	54.710349999999998	Центральная	0103000020E610000001000000050000008FE046CA16853540575BB1BFEC5A4B408FE046CA168535400EF5BBB0355B4B4037E15E99B78635400EF5BBB0355B4B4037E15E99B7863540575BB1BFEC5A4B408FE046CA16853540575BB1BFEC5A4B40
24212	45843	21.514534000000001	21.525466999999999	54.626724000000003	54.616830999999998	Школьная	0103000020E6100000010000000500000019AE0E80B883354059147651F44E4B4019AE0E80B883354025CFF57D38504B4092205C018586354025CFF57D38504B4092205C018586354059147651F44E4B4019AE0E80B883354059147651F44E4B40
23067	9449	21.957295999999999	21.980651999999999	54.606000999999999	54.594755999999997	Молодежная	0103000020E610000001000000050000007497C45911F53540C58CF0F6204C4B407497C45911F53540F12BD670914D4B40CAC16C020CFB3540F12BD670914D4B40CAC16C020CFB3540C58CF0F6204C4B407497C45911F53540C58CF0F6204C4B40
23170	45560	21.526437000000001	21.558479999999999	54.671159000000003	54.651516000000001	Почтовая	0103000020E6100000010000000500000084674293C48635400E6954E064534B4084674293C486354042B5C189E8554B405778978BF88E354042B5C189E8554B405778978BF88E35400E6954E064534B4084674293C48635400E6954E064534B40
23134	9239	21.891351	21.957709000000001	54.831913999999998	54.778740999999997	Советская	0103000020E61000000100000005000000C44142942FE43540F486FBC8AD634B40C44142942FE43540D28A6F287C6A4B40BA15C26A2CF53540D28A6F287C6A4B40BA15C26A2CF53540F486FBC8AD634B40C44142942FE43540F486FBC8AD634B40
23266	45641	21.771156000000001	21.786256999999999	54.811264000000001	54.798015999999997	Черняховского	0103000020E610000001000000050000003B1DC87A6AC53540A5D7666325664B403B1DC87A6AC535400936AE7FD7674B404640852348C935400936AE7FD7674B404640852348C93540A5D7666325664B403B1DC87A6AC53540A5D7666325664B40
23137	9603	21.607213000000002	21.625610999999999	54.628179000000003	54.619323000000001	Калининградская	0103000020E61000000100000005000000C0B4A84F729B35408F54DFF9454F4B40C0B4A84F729B35405A84622B68504B409204E10A28A035405A84622B68504B409204E10A28A035408F54DFF9454F4B40C0B4A84F729B35408F54DFF9454F4B40
24210	48496	21.845383999999999	21.863924999999998	54.629575000000003	54.613478000000001	Коммунистическая	0103000020E61000000100000005000000C98FF8156BD8354062687572864E4B40C98FF8156BD835408AB0E1E995504B40613255302ADD35408AB0E1E995504B40613255302ADD354062687572864E4B40C98FF8156BD8354062687572864E4B40
23011	48496	21.845383999999999	21.863924999999998	54.629575000000003	54.613478000000001	Вокзальная	0103000020E61000000100000005000000C98FF8156BD8354062687572864E4B40C98FF8156BD835408AB0E1E995504B40613255302ADD35408AB0E1E995504B40613255302ADD354062687572864E4B40C98FF8156BD8354062687572864E4B40
22969	9041	21.702013000000001	21.756792000000001	54.674424000000002	54.648453000000003	Мира	0103000020E61000000100000005000000EA5DBC1FB7B335401EFF058200534B40EA5DBC1FB7B335409AD18F8653564B40DBDFD91EBDC135409AD18F8653564B40DBDFD91EBDC135401EFF058200534B40EA5DBC1FB7B335401EFF058200534B40
23171	45602	21.414794000000001	21.433084000000001	54.663313000000002	54.656526999999997	Советской Конституции	0103000020E61000000100000005000000B89388F02F6A354072F8A41309544B40B89388F02F6A35407E01BD70E7544B40BE6BD097DE6E35407E01BD70E7544B40BE6BD097DE6E354072F8A41309544B40B89388F02F6A354072F8A41309544B40
67642	59079	20.35887	20.509571000000001	54.778762	54.717047999999998	Лужская	0103000020E61000000100000005000000F98381E7DE5B3440C3D4963AC85B4B40F98381E7DE5B34400CAF2479AE634B4072FDBB3E738234400CAF2479AE634B4072FDBB3E73823440C3D4963AC85B4B40F98381E7DE5B3440C3D4963AC85B4B40
23091	6643	21.651122999999998	21.695571999999999	55.052902000000003	55.033800999999997	Советская	0103000020E6100000010000000500000064AC36FFAFA635403AC9569753844B4064AC36FFAFA635404EF2237EC5864B406803B00111B235404EF2237EC5864B406803B00111B235403AC9569753844B4064AC36FFAFA635403AC9569753844B40
24193	47914	21.756298000000001	21.764472999999999	55.071339999999999	55.067405999999998	Школьная	0103000020E61000000100000005000000BC07E8BE9CC13540EFC682C2A0884B40BC07E8BE9CC13540C5724BAB21894B40CDACA580B4C33540C5724BAB21894B40CDACA580B4C33540EFC682C2A0884B40BC07E8BE9CC13540EFC682C2A0884B40
24217	6896	21.658417	21.704841999999999	54.786586	54.768079	Центральная	0103000020E6100000010000000500000064213A048EA8354048DFA46950624B4064213A048EA83540E8BE9CD9AE644B40E4D87A8670B43540E8BE9CD9AE644B40E4D87A8670B4354048DFA46950624B4064213A048EA8354048DFA46950624B40
23025	6729	21.633462000000002	21.669287000000001	54.893943	54.867902000000001	Черняховского	0103000020E610000001000000050000003E42CD902AA235400611A969176F4B403E42CD902AA235407BBE66B96C724B4051A3906456AB35407BBE66B96C724B4051A3906456AB35400611A969176F4B403E42CD902AA235400611A969176F4B40
67639	6524	20.230599000000002	20.261455999999999	54.704138999999998	54.692270999999998	Советская	0103000020E61000000100000005000000857D3B89083B34400F7C0C569C584B40857D3B89083B3440486B0C3A215A4B40CD57C9C7EE423440486B0C3A215A4B40CD57C9C7EE4234400F7C0C569C584B40857D3B89083B34400F7C0C569C584B40
24211	50987	20.124517000000001	20.178308000000001	54.951715	54.936630999999998	Калининградский проспект	0103000020E61000000100000005000000C9CB9A58E01F3440BBB54C86E3774B40C9CB9A58E01F34406B0E10CCD1794B407C9DD497A52D34406B0E10CCD1794B407C9DD497A52D3440BBB54C86E3774B40C9CB9A58E01F3440BBB54C86E3774B40
24225	47873	20.093247000000002	20.123304000000001	54.946224000000001	54.937055000000001	Центральная	0103000020E610000001000000050000003B730F09DF173440D2C6116BF1774B403B730F09DF1734405C5837DE1D794B404B77D7D9901F34405C5837DE1D794B404B77D7D9901F3440D2C6116BF1774B403B730F09DF173440D2C6116BF1774B40
23013	4873	21.101254999999998	21.120353999999999	54.402543999999999	54.390949999999997	Центральная	0103000020E61000000100000005000000758E01D9EB193540832F4CA60A324B40758E01D9EB193540BB99D18F86334B405AF10D85CF1E3540BB99D18F86334B405AF10D85CF1E3540832F4CA60A324B40758E01D9EB193540832F4CA60A324B40
23222	4713	20.986827999999999	21.037860999999999	54.450192999999999	54.434474999999999	Кутузова	0103000020E61000000100000005000000EFC682C2A0FC3440FDF675E09C374B40EFC682C2A0FC3440AEF199EC9F394B403ACB2C42B1093540AEF199EC9F394B403ACB2C42B1093540FDF675E09C374B40EFC682C2A0FC3440FDF675E09C374B40
23143	4713	20.986827999999999	21.037860999999999	54.450192999999999	54.434474999999999	Дзержинского	0103000020E61000000100000005000000EFC682C2A0FC3440FDF675E09C374B40EFC682C2A0FC3440AEF199EC9F394B403ACB2C42B1093540AEF199EC9F394B403ACB2C42B1093540FDF675E09C374B40EFC682C2A0FC3440FDF675E09C374B40
24204	50981	21.297132999999999	21.342524999999998	54.512695999999998	54.501021999999999	Фрунзенская	0103000020E61000000100000005000000F78F85E8104C3540CB49287D21404B40F78F85E8104C35401F65C405A0414B40F90FE9B7AF5735401F65C405A0414B40F90FE9B7AF573540CB49287D21404B40F78F85E8104C3540CB49287D21404B40
23107	5292	21.4681	21.492668999999999	54.451166999999998	54.435825999999999	Октябрьская	0103000020E61000000100000005000000F241CF66D57735408D5F7825C9374B40F241CF66D577354068041BD7BF394B40C6C03A8E1F7E354068041BD7BF394B40C6C03A8E1F7E35408D5F7825C9374B40F241CF66D57735408D5F7825C9374B40
23247	5034	21.276229000000001	21.293745999999999	54.407266	54.398372000000002	Пионерская	0103000020E61000000100000005000000F03499F1B646354031D28BDAFD324B40F03499F1B6463540E962D34A21344B40B05417F0324B3540E962D34A21344B40B05417F0324B354031D28BDAFD324B40F03499F1B646354031D28BDAFD324B40
23159	48552	21.538259	21.559576	54.343420999999999	54.326107	Центральная	0103000020E6100000010000000500000015C78157CB89354093FFC9DFBD294B4015C78157CB8935403BE12538F52B4B4062A06B5F408F35403BE12538F52B4B4062A06B5F408F354093FFC9DFBD294B4015C78157CB89354093FFC9DFBD294B40
23062	48585	20.922922	20.944005000000001	54.418112000000001	54.396369999999997	Школьная	0103000020E6100000010000000500000048C2BE9D44EC3440C98E8D40BC324B4048C2BE9D44EC34405708ABB184354B40AF42CA4FAAF134405708ABB184354B40AF42CA4FAAF13440C98E8D40BC324B4048C2BE9D44EC3440C98E8D40BC324B40
23199	5182	20.819040999999999	20.840430000000001	54.434271000000003	54.420689000000003	Калининградская	0103000020E610000001000000050000004815C5ABACD13440BB641C23D9354B404815C5ABACD13440F54C2F3196374B40C993A46B26D73440F54C2F3196374B40C993A46B26D73440BB641C23D9354B404815C5ABACD13440BB641C23D9354B40
79590	61710	21.278977999999999	21.287089999999999	54.814853999999997	54.812410999999997	Центральная	0103000020E61000000100000005000000B14D2A1A6B47354090F46915FD674B40B14D2A1A6B473540E481C8224D684B403602F1BA7E493540E481C8224D684B403602F1BA7E49354090F46915FD674B40B14D2A1A6B47354090F46915FD674B40
24364	51015	21.225563999999999	21.240494000000002	54.835061000000003	54.823475999999999	Школьная	0103000020E61000000100000005000000AA27F38FBE3935403C855CA967694B40AA27F38FBE39354021956247E36A4B405DE2C803913D354021956247E36A4B405DE2C803913D35403C855CA967694B40AA27F38FBE3935403C855CA967694B40
23296	3974	21.087152	21.112206	54.873631000000003	54.855476000000003	Театральная	0103000020E61000000100000005000000EFC7ED974F163540A741D13C806D4B40EFC7ED974F163540CAE2FE23D36F4B403C6A4C88B91C3540CAE2FE23D36F4B403C6A4C88B91C3540A741D13C806D4B40EFC7ED974F163540A741D13C806D4B40
23329	3974	21.087152	21.112206	54.873631000000003	54.855476000000003	Советская	0103000020E61000000100000005000000EFC7ED974F163540A741D13C806D4B40EFC7ED974F163540CAE2FE23D36F4B403C6A4C88B91C3540CAE2FE23D36F4B403C6A4C88B91C3540A741D13C806D4B40EFC7ED974F163540A741D13C806D4B40
23104	3974	21.087152	21.112206	54.873631000000003	54.855476000000003	Калининградская	0103000020E61000000100000005000000EFC7ED974F163540A741D13C806D4B40EFC7ED974F163540CAE2FE23D36F4B403C6A4C88B91C3540CAE2FE23D36F4B403C6A4C88B91C3540A741D13C806D4B40EFC7ED974F163540A741D13C806D4B40
75636	60709	\N	\N	\N	\N	Гвардейская	\N
23198	4231	21.040053	21.064910000000001	54.813105999999998	54.788849999999996	Прохладная	0103000020E61000000100000005000000501BD5E9400A35408CB96B09F9644B40501BD5E9400A354037177FDB13684B40F12E17F19D10354037177FDB13684B40F12E17F19D1035408CB96B09F9644B40501BD5E9400A35408CB96B09F9644B40
22993	48290	21.092057	21.109923999999999	54.837601999999997	54.821339000000002	переулок Торговый	0103000020E610000001000000050000002D5E2C0C91173540F5F6E7A221694B402D5E2C0C911735403788D68A366B4B40A60BB1FA231C35403788D68A366B4B40A60BB1FA231C3540F5F6E7A221694B402D5E2C0C91173540F5F6E7A221694B40
23233	48375	21.046844	21.072087	54.901403999999999	54.890438000000003	переулок Школьный	0103000020E610000001000000050000008A03E8F7FD0B3540CE8E54DFF9714B408A03E8F7FD0B3540E63DCE3461734B407D772B4B74123540E63DCE3461734B407D772B4B74123540CE8E54DFF9714B408A03E8F7FD0B3540CE8E54DFF9714B40
23328	48398	21.507024000000001	21.54222	54.854185000000001	54.834516999999998	Большаковская	0103000020E6100000010000000500000080492A53CC8135405F7AFB73D16A4B4080492A53CC813540ECDD1FEF556D4B40B43C0FEECE8A3540ECDD1FEF556D4B40B43C0FEECE8A35405F7AFB73D16A4B4080492A53CC8135405F7AFB73D16A4B40
24194	7248	21.527183000000001	21.534054999999999	54.764293000000002	54.758636000000003	Полесская	0103000020E61000000100000005000000D6011077F5863540BDC804FC1A614B40D6011077F5863540E7C75F5AD4614B40E94317D4B7883540E7C75F5AD4614B40E94317D4B7883540BDC804FC1A614B40D6011077F5863540BDC804FC1A614B40
24190	47771	22.041575999999999	22.065085	54.426090000000002	54.418573000000002	Центральная	0103000020E610000001000000050000006A4C88B9A40A36408BFED0CC93354B406A4C88B9A40A36408A93FB1D8A364B40CD751A69A91036408A93FB1D8A364B40CD751A69A91036408BFED0CC93354B406A4C88B9A40A36408BFED0CC93354B40
23327	47861	21.815128999999999	21.832861000000001	54.395589000000001	54.38599	Суворова	0103000020E610000001000000050000006C054D4BACD03540A14ACD1E68314B406C054D4BACD0354024D40CA9A2324B40261DE56036D5354024D40CA9A2324B40261DE56036D53540A14ACD1E68314B406C054D4BACD03540A14ACD1E68314B40
23301	3590	22.000747	22.036149999999999	54.422742999999997	54.394996999999996	площадь Победы	0103000020E61000000100000005000000F39194F4300036405182FE428F324B40F39194F43000364074CE4F711C364B401AC05B204109364074CE4F711C364B401AC05B20410936405182FE428F324B40F39194F4300036405182FE428F324B40
23138	3590	22.000747	22.036149999999999	54.422742999999997	54.394996999999996	Московская	0103000020E61000000100000005000000F39194F4300036405182FE428F324B40F39194F43000364074CE4F711C364B401AC05B204109364074CE4F711C364B401AC05B20410936405182FE428F324B40F39194F4300036405182FE428F324B40
23008	3111	21.818892000000002	21.857385000000001	54.447187999999997	54.425052999999998	Центральная	0103000020E61000000100000005000000BFF4F6E7A2D135408908FF2268364B40BFF4F6E7A2D13540F294D5743D394B40BA1457957DDB3540F294D5743D394B40BA1457957DDB35408908FF2268364B40BFF4F6E7A2D135408908FF2268364B40
75564	60686	21.982762999999998	21.993497999999999	54.470247999999998	54.462707000000002	Гурьевская	0103000020E6100000010000000500000006B8205B96FB3540AD50A4FB393B4B4006B8205B96FB354034812216313C4B4033A48AE255FE354034812216313C4B4033A48AE255FE3540AD50A4FB393B4B4006B8205B96FB3540AD50A4FB393B4B40
23232	3376	21.658256000000002	21.672485000000002	54.389980000000001	54.380929999999999	Центральная	0103000020E610000001000000050000005265187783A835405B087250C2304B405265187783A835400B0C59DDEA314B40F20C1AFA27AC35400B0C59DDEA314B40F20C1AFA27AC35405B087250C2304B405265187783A835405B087250C2304B40
23157	47924	21.70955	21.733508	54.378151000000003	54.369686000000002	Советская	0103000020E6100000010000000500000076E09C11A5B5354000E5EFDE512F4B4076E09C11A5B5354090F9804067304B40B85A272EC7BB354090F9804067304B40B85A272EC7BB354000E5EFDE512F4B4076E09C11A5B5354000E5EFDE512F4B40
23193	47796	21.939087000000001	21.960647000000002	54.412564000000003	54.397512999999996	Центральная	0103000020E610000001000000050000004819710168F035400F5EBBB4E1324B404819710168F03540E4C0ABE5CE344B40220038F6ECF53540E4C0ABE5CE344B40220038F6ECF535400F5EBBB4E1324B404819710168F035400F5EBBB4E1324B40
23190	47972	21.935907	21.955814	54.526403000000002	54.519860999999999	Центральная	0103000020E61000000100000005000000F418E59997EF3540A1BB24CE8A424B40F418E59997EF354016C26A2C61434B40170FEF39B0F4354016C26A2C61434B40170FEF39B0F43540A1BB24CE8A424B40F418E59997EF3540A1BB24CE8A424B40
23283	47747	22.221032000000001	22.246525999999999	54.434354999999996	54.415827999999998	Садовая	0103000020E61000000100000005000000965E9B8D953836406B6116DA39354B40965E9B8D9538364052EDD3F198374B401B9DF3531C3F364052EDD3F198374B401B9DF3531C3F36406B6116DA39354B40965E9B8D953836406B6116DA39354B40
23102	47715	22.228228000000001	22.248277999999999	54.402329000000002	54.390604000000003	Дзержинского	0103000020E61000000100000005000000100874266D3A3640E9D7D64FFF314B40100874266D3A3640BF9D44847F334B40F850A2258F3F3640BF9D44847F334B40F850A2258F3F3640E9D7D64FFF314B40100874266D3A3640E9D7D64FFF314B40
23231	2794	22.103729999999999	22.12838	54.378570000000003	54.368814999999998	Центральная	0103000020E61000000100000005000000349D9D0C8E1A36401AA37554352F4B40349D9D0C8E1A3640959F54FB74304B40E275FD82DD203640959F54FB74304B40E275FD82DD2036401AA37554352F4B40349D9D0C8E1A36401AA37554352F4B40
23230	47658	22.432818999999999	22.465464000000001	54.575727999999998	54.555349999999997	Центральная	0103000020E610000001000000050000006116DA39CD6E3640B3EA73B515474B406116DA39CD6E36401CB28174B1494B40217711A6287736401CB28174B1494B40217711A628773640B3EA73B515474B406116DA39CD6E3640B3EA73B515474B40
24231	50991	22.418185999999999	22.448055	54.466448999999997	54.452449000000001	Центральная	0103000020E6100000010000000500000022A5D93C0E6B3640D00D4DD9E9394B4022A5D93C0E6B36403E20D099B43B4B402DCF83BBB37236403E20D099B43B4B402DCF83BBB3723640D00D4DD9E9394B4022A5D93C0E6B3640D00D4DD9E9394B40
23205	1971	22.717898999999999	22.746797999999998	54.643822	54.633848999999998	Калининградская	0103000020E61000000100000005000000C3D4963AC8B7364018CDCAF621514B40C3D4963AC8B73640003961C268524B40DCB75A272EBF3640003961C268524B40DCB75A272EBF364018CDCAF621514B40C3D4963AC8B7364018CDCAF621514B40
24227	47675	22.410226000000002	22.437004999999999	54.672721000000003	54.658234999999998	Центральная	0103000020E610000001000000050000000AF8359204693640910A630B41544B400AF83592046936408D2AC3B81B564B404030478FDF6F36408D2AC3B81B564B404030478FDF6F3640910A630B41544B400AF8359204693640910A630B41544B40
23050	1858	22.558143000000001	22.593851000000001	54.639350999999998	54.620849999999997	Черняховского	0103000020E61000000100000005000000C87DAB75E28E36405DDC4603784F4B40C87DAB75E28E36401BD5E940D6514B4068B27F9E069836401BD5E940D6514B4068B27F9E069836405DDC4603784F4B40C87DAB75E28E36405DDC4603784F4B40
23149	47579	22.642163	22.664045000000002	54.519762	54.501263000000002	Садовая	0103000020E6100000010000000500000085B35BCB64A43640F1D8CF6229404B4085B35BCB64A436400EDAAB8F87424B40841266DAFEA936400EDAAB8F87424B40841266DAFEA93640F1D8CF6229404B4085B35BCB64A43640F1D8CF6229404B40
24188	47518	22.676981000000001	22.692405000000001	54.676417000000001	54.667363999999999	Нестеровская	0103000020E610000001000000050000006D0377A04EAD36408D43FD2E6C554B406D0377A04EAD3640AEBA0ED594564B403E963E7441B13640AEBA0ED594564B403E963E7441B136408D43FD2E6C554B406D0377A04EAD36408D43FD2E6C554B40
23316	2443	22.362947999999999	22.383223000000001	54.399304999999998	54.388879000000003	Центральная	0103000020E610000001000000050000000B26FE28EA5C3640F48C7DC9C6314B400B26FE28EA5C36408C101E6D1C334B4034130CE71A6236408C101E6D1C334B4034130CE71A623640F48C7DC9C6314B400B26FE28EA5C3640F48C7DC9C6314B40
23228	47597	22.499115	22.527987	54.582836	54.545282	Коммунальная	0103000020E610000001000000050000006BF12900C67F36407A8CF2CCCB454B406BF12900C67F36403A77BB5E9A4A4B4091B6F1272A8736403A77BB5E9A4A4B4091B6F1272A8736407A8CF2CCCB454B406BF12900C67F36407A8CF2CCCB454B40
23105	48048	22.509733000000001	22.522542999999999	54.508958	54.499327999999998	Шоссейная	0103000020E6100000010000000500000025B1A4DC7D82364011FDDAFAE93F4B4025B1A4DC7D823640CF84268925414B40F4C0C760C5853640CF84268925414B40F4C0C760C585364011FDDAFAE93F4B4025B1A4DC7D82364011FDDAFAE93F4B40
23325	47539	22.622858000000001	22.638884000000001	54.688544999999998	54.677146	Куйбышева	0103000020E610000001000000050000004E0D349F739F3640014F5AB8AC564B404E0D349F739F36408369183E22584B400BF0DDE68DA336408369183E22584B400BF0DDE68DA33640014F5AB8AC564B404E0D349F739F3640014F5AB8AC564B40
24173	50969	22.566811999999999	22.587554000000001	54.461011999999997	54.441094	Центральная	0103000020E61000000100000005000000F8FA5A971A9136401D3BA8C475384B40F8FA5A971A9136402288F370023B4B404DA25EF0699636402288F370023B4B404DA25EF0699636401D3BA8C475384B40F8FA5A971A9136401D3BA8C475384B40
23279	1409	22.070636	22.108032999999999	54.832239999999999	54.819491999999997	Школьная	0103000020E6100000010000000500000096EB6D3315123640B4AA251DE5684B4096EB6D331512364026361FD7866A4B4086E3F90CA81B364026361FD7866A4B4086E3F90CA81B3640B4AA251DE5684B4096EB6D3315123640B4AA251DE5684B40
23139	1629	21.983167000000002	21.994800999999999	55.010916999999999	55.003590000000003	Центральная	0103000020E61000000100000005000000A6811FD5B0FB3540DC4B1AA375804B40A6811FD5B0FB354037FC6EBA65814B4031074147ABFE354037FC6EBA65814B4031074147ABFE3540DC4B1AA375804B40A6811FD5B0FB3540DC4B1AA375804B40
23163	1751	21.749534000000001	21.813089000000002	55.005057000000001	54.975656000000001	Катаева	0103000020E61000000100000005000000753DD175E1BF3540B612BA4BE27C4B40753DD175E1BF3540D5CE30B5A5804B40C3BCC79926D03540D5CE30B5A5804B40C3BCC79926D03540B612BA4BE27C4B40753DD175E1BF3540B612BA4BE27C4B40
22999	695	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	Черняховского	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
23093	695	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	Советская	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
23276	695	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	Полевая	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
23037	695	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	Победы	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
23204	695	22.005085999999999	22.076322999999999	55.045563000000001	55.020740000000004	Октябрьская	0103000020E61000000100000005000000DEAAEB504D0136400ADCBA9BA7824B40DEAAEB504D0136402E742502D5854B40BFEE74E7891336402E742502D5854B40BFEE74E7891336400ADCBA9BA7824B40DEAAEB504D0136400ADCBA9BA7824B40
23096	1395	22.270233000000001	22.274885999999999	54.932229	54.927976999999998	Центральная	0103000020E61000000100000005000000CB4C69FD2D453640583849F3C7764B40CB4C69FD2D453640FFB0A54753774B40D520CCED5E463640FFB0A54753774B40D520CCED5E463640583849F3C7764B40CB4C69FD2D453640583849F3C7764B40
23092	1498	22.068605999999999	22.097118999999999	54.922493000000003	54.899442000000001	Жилинская	0103000020E61000000100000005000000334FAE29901136400D535BEA20734B40334FAE2990113640FCE4284014764B40FAD170CADC183640FCE4284014764B40FAD170CADC1836400D535BEA20734B40334FAE29901136400D535BEA20734B40
23152	1843	21.815829000000001	21.841799999999999	54.959428000000003	54.938726000000003	Школьная	0103000020E61000000100000005000000DE205A2BDAD03540D4F36E2C28784B40DE205A2BDAD03540F06E6589CE7A4B40D6C56D3480D73540F06E6589CE7A4B40D6C56D3480D73540D4F36E2C28784B40DE205A2BDAD03540D4F36E2C28784B40
23001	1515	21.911051	21.940937999999999	54.924480000000003	54.900151000000001	Комсомольская	0103000020E61000000100000005000000F4FC69A33AE93540193BE12538734B40F4FC69A33AE935402EE7525C55764B404B901150E1F035402EE7525C55764B404B901150E1F03540193BE12538734B40F4FC69A33AE93540193BE12538734B40
24273	50998	\N	\N	\N	\N	Школьная	\N
23212	46944	22.453723	22.463757000000001	54.941048000000002	54.930424000000002	Молодежная	0103000020E610000001000000050000006971C63027743640EEB4352218774B406971C63027743640ADFBC74274784B40844A5CC7B8763640ADFBC74274784B40844A5CC7B8763640EEB4352218774B406971C63027743640EEB4352218774B40
24262	7517	22.280258	22.396401000000001	54.876334999999997	54.853760000000001	Советская	0103000020E610000001000000050000003F7100FDBE4736400551F701486D4B403F7100FDBE4736408AABCABE2B704B40091A33897A6536408AABCABE2B704B40091A33897A6536400551F701486D4B403F7100FDBE4736400551F701486D4B40
23146	47007	22.288433000000001	22.304736999999999	54.985472999999999	54.975858000000002	Садовая	0103000020E610000001000000050000005116BEBED64936401EC539EAE87C4B405116BEBED6493640A60BB1FA237E4B4093E1783E034E3640A60BB1FA237E4B4093E1783E034E36401EC539EAE87C4B405116BEBED64936401EC539EAE87C4B40
24223	46870	22.594839	22.609463999999999	54.846825000000003	54.836809000000002	Советская	0103000020E61000000100000005000000A662635E47983640CEFFAB8E1C6B4B40A662635E47983640B537F8C2646C4B40DF162CD5059C3640B537F8C2646C4B40DF162CD5059C3640CEFFAB8E1C6B4B40A662635E47983640CEFFAB8E1C6B4B40
79604	61724	22.715788	22.733727999999999	54.904251000000002	54.884177000000001	Победы	0103000020E6100000010000000500000087DEE2E13DB736400D7041B62C714B4087DEE2E13DB736400A302C7FBE734B40D4282499D5BB36400A302C7FBE734B40D4282499D5BB36400D7041B62C714B4087DEE2E13DB736400D7041B62C714B40
24288	50999	22.187328000000001	22.881195000000002	55.070045999999998	54.711399999999998	Краснознаменская	0103000020E6100000010000000500000006A051BAF42F3640EC2FBB270F5B4B4006A051BAF42F3640999B6F44F7884B401366DAFE95E13640999B6F44F7884B401366DAFE95E13640EC2FBB270F5B4B4006A051BAF42F3640EC2FBB270F5B4B40
9662	10710	22.505457	22.518581000000001	54.820228999999998	54.809666	Советская	0103000020E61000000100000005000000C68844A1658136407157AF22A3674B40C68844A1658136408A1D8D43FD684B40B55373B9C18436408A1D8D43FD684B40B55373B9C18436407157AF22A3674B40C68844A1658136407157AF22A3674B40
23295	582	22.37265	22.404261999999999	55.052875999999998	55.046512	Советская	0103000020E61000000100000005000000BADA8AFD655F36408F6FEF1AF4854B40BADA8AFD655F3640245F09A4C4864B40FB03E5B67D673640245F09A4C4864B40FB03E5B67D6736408F6FEF1AF4854B40BADA8AFD655F36408F6FEF1AF4854B40
22968	28	22.471302999999999	22.513272000000001	54.954563999999998	54.935312000000003	Калининградская	0103000020E61000000100000005000000B6813B50A778364037C7B94DB8774B40B6813B50A77836402FF834272F7A4B40D8F335CB658336402FF834272F7A4B40D8F335CB6583364037C7B94DB8774B40B6813B50A778364037C7B94DB8774B40
23110	690	22.494658999999999	22.501307000000001	54.762402000000002	54.756953000000003	площадь Героев	0103000020E610000001000000050000000CACE3F8A17E3640F7CDFDD5E3604B400CACE3F8A17E3640D733846396614B408141D2A755803640D733846396614B408141D2A755803640F7CDFDD5E3604B400CACE3F8A17E3640F7CDFDD5E3604B40
24407	7487	22.336231999999999	22.356795000000002	54.763638	54.752702999999997	Советская	0103000020E6100000010000000500000061DEE34C13563640F04C689258604B4061DEE34C13563640CEFDD5E3BE614B405760C8EA565B3640CEFDD5E3BE614B405760C8EA565B3640F04C689258604B4061DEE34C13563640F04C689258604B40
67654	8381	20.587724000000001	20.621115	54.730240000000002	54.710932	Бариновой	0103000020E6100000010000000500000006137F147596344006D7DCD1FF5A4B4006137F1475963440931D1B81785D4B40170E8464019F3440931D1B81785D4B40170E8464019F344006D7DCD1FF5A4B4006137F147596344006D7DCD1FF5A4B40
24192	5829	19.930149	19.951070000000001	54.880712000000003	54.865104000000002	Советская	0103000020E610000001000000050000003868AF3E1EEE3340C4D155BABB6E4B403868AF3E1EEE3340EE98BA2BBB704B40EC34D25279F33340EE98BA2BBB704B40EC34D25279F33340C4D155BABB6E4B403868AF3E1EEE3340C4D155BABB6E4B40
23175	26696	20.839925999999998	20.860821000000001	55.165672999999998	55.148256000000003	Победы	0103000020E61000000100000005000000620FED6305D73440C8B7770DFA924B40620FED6305D73440446ADAC534954B40C4B5DAC35EDC3440446ADAC534954B40C4B5DAC35EDC3440C8B7770DFA924B40620FED6305D73440C8B7770DFA924B40
23192	27181	20.269703	20.287391	54.900191999999997	54.890918999999997	Школьная	0103000020E6100000010000000500000012A27C410B453440483140A209724B4012A27C410B453440770FD07D39734B402C2AE27492493440770FD07D39734B402C2AE27492493440483140A209724B4012A27C410B453440483140A209724B40
24233	50992	20.026619	20.051772	54.946105000000003	54.936072000000003	Балтийский проспект	0103000020E61000000100000005000000C573B680D0063440C5591135D1774B40C573B680D006344082CAF8F719794B4038D906EE400D344082CAF8F719794B4038D906EE400D3440C5591135D1774B40C573B680D0063440C5591135D1774B40
24200	45669	20.617979999999999	20.628741999999999	54.909095000000001	54.902900000000002	Центральная	0103000020E610000001000000050000000395F1EF339E34407AC7293A92734B400395F1EF339E344083FA96395D744B40239F573CF5A0344083FA96395D744B40239F573CF5A034407AC7293A92734B400395F1EF339E34407AC7293A92734B40
23194	27352	20.002390999999999	20.015785000000001	54.839846999999999	54.828480999999996	Балтийская	0103000020E6100000010000000500000003CE52B29C003440BE2D58AA0B6A4B4003CE52B29C0034406552431B806B4B4072C45A7C0A0434406552431B806B4B4072C45A7C0A043440BE2D58AA0B6A4B4003CE52B29C003440BE2D58AA0B6A4B40
23052	27053	20.252213000000001	20.302634999999999	54.823475999999999	54.809857999999998	Гвардейская	0103000020E6100000010000000500000045A0FA0791403440B5334C6DA9674B4045A0FA07914034403C855CA967694B40FD9FC37C794D34403C855CA967694B40FD9FC37C794D3440B5334C6DA9674B4045A0FA0791403440B5334C6DA9674B40
23116	8061	20.336186999999999	20.346212000000001	54.813651	54.804602000000003	Прохладная	0103000020E610000001000000050000002157EA5910563440EA25C632FD664B402157EA5910563440C9AD49B725684B40967B8159A1583440C9AD49B725684B40967B8159A1583440EA25C632FD664B402157EA5910563440EA25C632FD664B40
24219	46940	20.586431000000001	20.593195000000001	54.910974000000003	54.903697000000001	Советская	0103000020E610000001000000050000004F5C8E5720963440253FE257AC734B404F5C8E5720963440CFC0C8CB9A744B409626A5A0DB973440CFC0C8CB9A744B409626A5A0DB973440253FE257AC734B404F5C8E5720963440253FE257AC734B40
23188	26836	20.485433	20.500641999999999	54.900486999999998	54.891955000000003	Садовая	0103000020E6100000010000000500000030664B56457C34407940D9942B724B4030664B56457C344090BC732843734B400801F9122A80344090BC732843734B400801F9122A8034407940D9942B724B4030664B56457C34407940D9942B724B40
23187	26820	20.472057	20.483825	54.931246000000002	54.918649000000002	Дорожная	0103000020E610000001000000050000000ED940BAD878344066C0594A96754B400ED940BAD8783440F243A51133774B40B9FC87F4DB7B3440F243A51133774B40B9FC87F4DB7B344066C0594A96754B400ED940BAD878344066C0594A96754B40
23289	26721	20.909106000000001	20.926542000000001	55.233285000000002	55.224659000000003	Дачная	0103000020E61000000100000005000000EE98BA2BBBE8344044E048A0C19C4B40EE98BA2BBBE83440DDD26A48DC9D4B40D55E44DB31ED3440DDD26A48DC9D4B40D55E44DB31ED344044E048A0C19C4B40EE98BA2BBBE8344044E048A0C19C4B40
23006	26936	20.439709000000001	20.476818000000002	54.879412000000002	54.871310000000001	Новая	0103000020E61000000100000005000000C2C1DEC490703440C1560916876F4B40C2C1DEC490703440E0DA899290704B40E62494BE107A3440E0DA899290704B40E62494BE107A3440C1560916876F4B40C2C1DEC490703440C1560916876F4B40
23101	26914	20.58953	20.597660000000001	54.913758000000001	54.904333000000001	Кольцевая	0103000020E61000000100000005000000C9022670EB963440C7D8092FC1734B40C9022670EB963440AC3AAB05F6744B409B20EA3E00993440AC3AAB05F6744B409B20EA3E00993440C7D8092FC1734B40C9022670EB963440C7D8092FC1734B40
23003	8018	20.198601	20.211447	54.770218999999997	54.762802000000001	Молодёжная	0103000020E61000000100000005000000F1F3DF83D732344065A9F57EA3614B40F1F3DF83D732344000E1438996624B405AD6FD632136344000E1438996624B405AD6FD632136344065A9F57EA3614B40F1F3DF83D732344065A9F57EA3614B40
23154	26622	20.599015999999999	20.621949999999998	55.016584999999999	55.006574999999998	Центральная	0103000020E61000000100000005000000DEC7D11C5999344050FC1873D7804B40DEC7D11C59993440554D10751F824B4048BF7D1D389F3440554D10751F824B4048BF7D1D389F344050FC1873D7804B40DEC7D11C5999344050FC1873D7804B40
23326	27283	20.014158999999999	20.023123999999999	54.900756000000001	54.890748000000002	Школьная	0103000020E61000000100000005000000AEF199EC9F0334401C7DCC0704724B40AEF199EC9F03344080D6FCF84B734B40B1C05774EB05344080D6FCF84B734B40B1C05774EB0534401C7DCC0704724B40AEF199EC9F0334401C7DCC0704724B40
23055	27407	20.084219000000001	20.098295	54.741998000000002	54.732261999999999	Школьная	0103000020E61000000100000005000000ABB35A608F153440410DDFC2BA5D4B40ABB35A608F15344045D95BCAF95E4B403E5C72DC2919344045D95BCAF95E4B403E5C72DC29193440410DDFC2BA5D4B40ABB35A608F153440410DDFC2BA5D4B40
23191	27119	20.291460000000001	20.317834999999999	54.804907999999998	54.794221999999998	Центральная	0103000020E610000001000000050000009817601F9D4A3440C1E10511A9654B409817601F9D4A3440F624B03907674B402F8672A25D513440F624B03907674B402F8672A25D513440C1E10511A9654B409817601F9D4A3440C1E10511A9654B40
23155	26765	20.393993999999999	20.409597000000002	54.922865000000002	54.906087999999997	Балтийская	0103000020E61000000100000005000000FAD170CADC64344026A60BB1FA734B40FAD170CADC643440C0CFB87020764B402B8A5759DB683440C0CFB87020764B402B8A5759DB68344026A60BB1FA734B40FAD170CADC64344026A60BB1FA734B40
23197	10052	20.450067000000001	20.495324	54.965299999999999	54.950871999999997	Тургенева	0103000020E6100000010000000500000043024697377334404F57772CB6794B404302469737733440166A4DF38E7B4B4085ECBC8DCD7E3440166A4DF38E7B4B4085ECBC8DCD7E34404F57772CB6794B4043024697377334404F57772CB6794B40
23196	10052	20.450067000000001	20.495324	54.965299999999999	54.950871999999997	Октябрьская	0103000020E6100000010000000500000043024697377334404F57772CB6794B404302469737733440166A4DF38E7B4B4085ECBC8DCD7E3440166A4DF38E7B4B4085ECBC8DCD7E34404F57772CB6794B4043024697377334404F57772CB6794B40
23179	10052	20.450067000000001	20.495324	54.965299999999999	54.950871999999997	Ленина	0103000020E6100000010000000500000043024697377334404F57772CB6794B404302469737733440166A4DF38E7B4B4085ECBC8DCD7E3440166A4DF38E7B4B4085ECBC8DCD7E34404F57772CB6794B4043024697377334404F57772CB6794B40
23153	10052	20.450067000000001	20.495324	54.965299999999999	54.950871999999997	Курортный проспект	0103000020E6100000010000000500000043024697377334404F57772CB6794B404302469737733440166A4DF38E7B4B4085ECBC8DCD7E3440166A4DF38E7B4B4085ECBC8DCD7E34404F57772CB6794B4043024697377334404F57772CB6794B40
23099	10052	20.450067000000001	20.495324	54.965299999999999	54.950871999999997	Крымская	0103000020E6100000010000000500000043024697377334404F57772CB6794B404302469737733440166A4DF38E7B4B4085ECBC8DCD7E3440166A4DF38E7B4B4085ECBC8DCD7E34404F57772CB6794B4043024697377334404F57772CB6794B40
23156	27202	20.247900999999999	20.284309	54.958756000000001	54.945309000000002	Пионерская	0103000020E610000001000000050000004CA59F70763F3440A7CEA3E2FF784B404CA59F70763F3440016C4084B87A4B405EF58079C8483440016C4084B87A4B405EF58079C8483440A7CEA3E2FF784B404CA59F70763F3440A7CEA3E2FF784B40
79554	61677	19.962586999999999	19.974606000000001	54.943716000000002	54.933346	Садовая	0103000020E61000000100000005000000048E041A6CF633401CEDB8E177774B40048E041A6CF63340215B96AFCB784B40427C60C77FF93340215B96AFCB784B40427C60C77FF933401CEDB8E177774B40048E041A6CF633401CEDB8E177774B40
23290	27265	20.116378000000001	20.133195000000001	54.904023000000002	54.896158999999997	Центральная	0103000020E6100000010000000500000051F9D7F2CA1D34400E828E56B5724B4051F9D7F2CA1D344079EA9106B7734B40A0FD48111922344079EA9106B7734B40A0FD4811192234400E828E56B5724B4051F9D7F2CA1D34400E828E56B5724B40
24205	50983	20.396903999999999	20.400110999999999	54.894936999999999	54.888480000000001	Западная	0103000020E61000000100000005000000CEA623809B65344036936FB6B9714B40CEA623809B6534407C7DAD4B8D724B4015C5ABAC6D6634407C7DAD4B8D724B4015C5ABAC6D66344036936FB6B9714B40CEA623809B65344036936FB6B9714B40
23145	46988	20.338792000000002	20.350335999999999	54.838120000000004	54.831420999999999	Шоссейная	0103000020E610000001000000050000007D259012BB563440931ADA006C6A4B407D259012BB563440D00F2384476B4B40889CBE9EAF593440D00F2384476B4B40889CBE9EAF593440931ADA006C6A4B407D259012BB563440931ADA006C6A4B40
24215	47820	22.235880999999999	22.244423999999999	54.644607999999998	54.635730000000002	Новая	0103000020E610000001000000050000006EBF7CB2623C3640058BC3995F514B406EBF7CB2623C3640B75ED38382524B40855B3E92923E3640B75ED38382524B40855B3E92923E3640058BC3995F514B406EBF7CB2623C3640058BC3995F514B40
23260	48526	22.147209	22.165382000000001	54.648667000000003	54.641863000000001	Героев	0103000020E6100000010000000500000047AD307DAF25364098C1189128524B4047AD307DAF2536404A7F2F8507534B40DA588979562A36404A7F2F8507534B40DA588979562A364098C1189128524B4047AD307DAF25364098C1189128524B40
23048	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	переулок Павлова	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
22975	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	Юрия Смирнова	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
23317	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	Ю. Смирнова	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
22997	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	Ульяновых	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
23082	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	Тимирязева	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
23036	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	Советская	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
23049	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	Железнодорожная	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
23098	10024	22.167556000000001	22.235989	54.616970999999999	54.5747	Артиллерийская	0103000020E61000000100000005000000A33F34F3E42A36406F8104C58F494B40A33F34F3E42A36404BCADDE7F84E4B403B376DC6693C36404BCADDE7F84E4B403B376DC6693C36406F8104C58F494B40A33F34F3E42A36406F8104C58F494B40
23280	25074	20.428111999999999	20.441514999999999	54.606642000000001	54.596066	Центральная	0103000020E6100000010000000500000070067FBF986D3440F72004E44B4C4B4070067FBF986D3440A530EF71A64D4B4085B1852007713440A530EF71A64D4B4085B1852007713440F72004E44B4C4B4070067FBF986D3440F72004E44B4C4B40
23020	7965	20.556894	20.588909999999998	54.906927000000003	54.889516	Александра Невского	0103000020E61000000100000005000000B056ED9A908E344066A208A9DB714B40B056ED9A908E3440016E162F16744B40904946CEC2963440016E162F16744B40904946CEC296344066A208A9DB714B40B056ED9A908E344066A208A9DB714B40
23185	25187	20.227616999999999	20.260486	54.617597000000004	54.603805999999999	Победы	0103000020E610000001000000050000007D03931B453A34407590D783494D4B407D03931B453A3440CA8D226B0D4F4B40DC10E335AF423440CA8D226B0D4F4B40DC10E335AF4234407590D783494D4B407D03931B453A34407590D783494D4B40
24224	48340	20.676586	20.685713	54.639491999999997	54.634551999999999	Центральная	0103000020E6100000010000000500000074EE76BD34AD344042CEFBFF38514B4074EE76BD34AD3440DD06B5DFDA514B402A711DE38AAF3440DD06B5DFDA514B402A711DE38AAF344042CEFBFF38514B4074EE76BD34AD344042CEFBFF38514B40
24189	25461	20.501961999999999	20.510522999999999	54.831026999999999	54.828226000000001	Мирная	0103000020E61000000100000005000000B2D5E5948080344034D93F4F036A4B40B2D5E59480803440E78BBD175F6A4B4016DBA4A2B1823440E78BBD175F6A4B4016DBA4A2B182344034D93F4F036A4B40B2D5E5948080344034D93F4F036A4B40
23000	24930	20.660335	20.681131000000001	54.711790000000001	54.700319999999998	Марьина	0103000020E610000001000000050000007767EDB60BA934400B5EF415A4594B407767EDB60BA9344057CF49EF1B5B4B40B24AE9995EAE344057CF49EF1B5B4B40B24AE9995EAE34400B5EF415A4594B407767EDB60BA934400B5EF415A4594B40
23271	24711	20.629352000000001	20.646259000000001	54.811248999999997	54.802588	Центральная	0103000020E6100000010000000500000015AC71361DA13440BE141E34BB664B4015AC71361DA13440D3F4D901D7674B40E4BED53A71A53440D3F4D901D7674B40E4BED53A71A53440BE141E34BB664B4015AC71361DA13440BE141E34BB664B40
23183	25366	20.400623	20.432711000000001	54.812176999999998	54.798752999999998	Октябрьская	0103000020E6100000010000000500000081069B3A8F6634407B4ACE893D664B4081069B3A8F6634401DC87A6AF5674B40959EE925C66E34401DC87A6AF5674B40959EE925C66E34407B4ACE893D664B4081069B3A8F6634407B4ACE893D664B40
23053	25323	20.521501000000001	20.548459000000001	54.798681000000002	54.788781999999998	Центральная	0103000020E61000000100000005000000D0D4EB168185344034D6FECEF6644B40D0D4EB1681853440E277D32D3B664B4066321CCF678C3440E277D32D3B664B4066321CCF678C344034D6FECEF6644B40D0D4EB168185344034D6FECEF6644B40
23219	24872	20.728311000000001	20.748173000000001	54.707535999999998	54.694440999999998	Калининградская	0103000020E610000001000000050000002B51F69672BA344032005471E3584B402B51F69672BA34400F5F268A905A4B400EC0064488BF34400F5F268A905A4B400EC0064488BF344032005471E3584B402B51F69672BA344032005471E3584B40
23038	8364	20.666785000000001	20.683332	54.907341000000002	54.897303000000001	Центральная	0103000020E610000001000000050000009F76F86BB2AA344025CD1FD3DA724B409F76F86BB2AA3440F4A8F8BF23744B406E4F90D8EEAE3440F4A8F8BF23744B406E4F90D8EEAE344025CD1FD3DA724B409F76F86BB2AA344025CD1FD3DA724B40
23218	24395	20.789145000000001	20.797256000000001	54.81832	54.813375999999998	Гурьева	0103000020E610000001000000050000004BCD1E6805CA3440F7AC6BB41C684B404BCD1E6805CA3440D4D4B2B5BE684B402F8A1EF818CC3440D4D4B2B5BE684B402F8A1EF818CC3440F7AC6BB41C684B404BCD1E6805CA3440F7AC6BB41C684B40
23045	25449	20.587114	20.604209000000001	54.864652999999997	54.856186000000001	Центральная	0103000020E610000001000000050000001406651A4D96344083A5BA80976D4B401406651A4D963440B3B112F3AC6E4B40E9F2E670AD9A3440B3B112F3AC6E4B40E9F2E670AD9A344083A5BA80976D4B401406651A4D96344083A5BA80976D4B40
23216	24535	20.729648999999998	20.754254	54.879644999999996	54.874527	Центральная	0103000020E61000000100000005000000218FE046CABA3440083C3080F06F4B40218FE046CABA3440828B153598704B408FE046CA16C13440828B153598704B408FE046CA16C13440083C3080F06F4B40218FE046CABA3440083C3080F06F4B40
23005	24998	20.602744000000001	20.618528000000001	54.749523000000003	54.740459000000001	Степная	0103000020E6100000010000000500000038DC476E4D9A3440B2834A5CC75E4B4038DC476E4D9A3440C74CA25EF05F4B4009A9DBD9579E3440C74CA25EF05F4B4009A9DBD9579E3440B2834A5CC75E4B4038DC476E4D9A3440B2834A5CC75E4B40
23315	24998	20.602744000000001	20.618528000000001	54.749523000000003	54.740459000000001	Западная	0103000020E6100000010000000500000038DC476E4D9A3440B2834A5CC75E4B4038DC476E4D9A3440C74CA25EF05F4B4009A9DBD9579E3440C74CA25EF05F4B4009A9DBD9579E3440B2834A5CC75E4B4038DC476E4D9A3440B2834A5CC75E4B40
23277	24763	20.740465	20.752528999999999	54.724994000000002	54.715820999999998	Молодежная	0103000020E6100000010000000500000028D53E1D8FBD34401F65C405A05B4B4028D53E1D8FBD3440EBE5779ACC5C4B40A54A94BDA5C03440EBE5779ACC5C4B40A54A94BDA5C034401F65C405A05B4B4028D53E1D8FBD34401F65C405A05B4B40
23100	25222	20.633088999999998	20.645817999999998	54.649890999999997	54.642893999999998	Центральная	0103000020E610000001000000050000001475E61E12A23440B665C0594A524B401475E61E12A234407C7BD7A02F534B400A2B155454A534407C7BD7A02F534B400A2B155454A53440B665C0594A524B401475E61E12A23440B665C0594A524B40
23002	25084	20.545027999999999	20.552662999999999	54.639310000000002	54.630763999999999	Багратионовская	0103000020E610000001000000050000007F677BF4868B344040BFEFDFBC504B407F677BF4868B3440BD00FBE8D4514B4091B586527B8D3440BD00FBE8D4514B4091B586527B8D344040BFEFDFBC504B407F677BF4868B344040BFEFDFBC504B40
23221	24643	20.682703	20.695298000000001	54.804181999999997	54.795462999999998	Зеленая	0103000020E610000001000000050000008FE1B19FC5AE3440CA1649BBD1654B408FE1B19FC5AE344014048F6FEF664B4066F9BA0CFFB1344014048F6FEF664B4066F9BA0CFFB13440CA1649BBD1654B408FE1B19FC5AE3440CA1649BBD1654B40
23042	24987	20.625489999999999	20.661054	54.730894999999997	54.712581	Центральная	0103000020E610000001000000050000009CF9D51C20A034402060ADDA355B4B409CF9D51C20A03440ABE7A4F78D5D4B40D6E3BED53AA93440ABE7A4F78D5D4B40D6E3BED53AA934402060ADDA355B4B409CF9D51C20A034402060ADDA355B4B40
23112	24627	20.798908999999998	20.837142	54.925773	54.904603000000002	Центральная	0103000020E61000000100000005000000E57ADB4C85CC3440876EF607CA734B40E57ADB4C85CC34408942CBBA7F764B40A81B28F04ED634408942CBBA7F764B40A81B28F04ED63440876EF607CA734B40E57ADB4C85CC3440876EF607CA734B40
22981	24443	20.863524999999999	20.869589000000001	54.812603000000003	54.809542	Калининградская	0103000020E61000000100000005000000454772F90FDD3440855E7F129F674B40454772F90FDD3440D5D0066003684B401BF67B629DDE3440D5D0066003684B401BF67B629DDE3440855E7F129F674B40454772F90FDD3440855E7F129F674B40
23108	24148	20.581948000000001	20.630709	54.792603	54.764589000000001	Садовая	0103000020E61000000100000005000000FDF84B8BFA943440D0F0660DDE614B40FDF84B8BFA94344012DBDD0374654B40F94A202576A1344012DBDD0374654B40F94A202576A13440D0F0660DDE614B40FDF84B8BFA943440D0F0660DDE614B40
23181	24148	20.581948000000001	20.630709	54.792603	54.764589000000001	Ленина	0103000020E61000000100000005000000FDF84B8BFA943440D0F0660DDE614B40FDF84B8BFA94344012DBDD0374654B40F94A202576A1344012DBDD0374654B40F94A202576A13440D0F0660DDE614B40FDF84B8BFA943440D0F0660DDE614B40
23330	24148	20.581948000000001	20.630709	54.792603	54.764589000000001	Заречная	0103000020E61000000100000005000000FDF84B8BFA943440D0F0660DDE614B40FDF84B8BFA94344012DBDD0374654B40F94A202576A1344012DBDD0374654B40F94A202576A13440D0F0660DDE614B40FDF84B8BFA943440D0F0660DDE614B40
22998	24852	20.798881999999999	20.808817999999999	54.705776999999998	54.700924000000001	Полевая	0103000020E61000000100000005000000F25CDF8783CC3440A27DACE0B7594B40F25CDF8783CC34406EA296E6565A4B40876A4AB20ECF34406EA296E6565A4B40876A4AB20ECF3440A27DACE0B7594B40F25CDF8783CC3440A27DACE0B7594B40
23103	47742	20.909662999999998	20.921305	54.706532000000003	54.702052999999999	Центральная	0103000020E610000001000000050000009961A3ACDFE83440838769DFDC594B409961A3ACDFE83440EBC9FCA36F5A4B402BA4FCA4DAEB3440EBC9FCA36F5A4B402BA4FCA4DAEB3440838769DFDC594B409961A3ACDFE83440838769DFDC594B40
24354	51011	21.329598000000001	21.348993	54.654541999999999	54.646014999999998	Мира	0103000020E61000000100000005000000B7D3D68860543540DBDC989EB0524B40B7D3D68860543540E1ED4108C8534B406E88F19A57593540E1ED4108C8534B406E88F19A57593540DBDC989EB0524B40B7D3D68860543540DBDC989EB0524B40
23180	23948	21.079283	21.091868000000002	54.754246000000002	54.746794000000001	Ст.Козака	0103000020E61000000100000005000000F72004E44B143540AD6C1FF2965F4B40F72004E44B143540C59107228B604B40878C47A984173540C59107228B604B40878C47A984173540AD6C1FF2965F4B40F72004E44B143540AD6C1FF2965F4B40
24222	1991	21.034807000000001	21.047518	54.665785999999997	54.660843999999997	Пригородная	0103000020E6100000010000000500000000AC8E1CE908354000E1438996544B4000AC8E1CE90835403C11C47938554B40A9F8BF232A0C35403C11C47938554B40A9F8BF232A0C354000E1438996544B4000AC8E1CE908354000E1438996544B40
23177	23686	20.857695	20.9194	54.633515000000003	54.609662	Школьная	0103000020E6100000010000000500000056F146E691DB344096CE8767094E4B4056F146E691DB34404243FF0417514B4041F163CC5DEB34404243FF0417514B4041F163CC5DEB344096CE8767094E4B4056F146E691DB344096CE8767094E4B40
23274	23686	20.857695	20.9194	54.633515000000003	54.609662	Садовая	0103000020E6100000010000000500000056F146E691DB344096CE8767094E4B4056F146E691DB34404243FF0417514B4041F163CC5DEB34404243FF0417514B4041F163CC5DEB344096CE8767094E4B4056F146E691DB344096CE8767094E4B40
23273	23854	21.347286	21.355937000000001	54.689638000000002	54.680743	Школьная	0103000020E61000000100000005000000D15B3CBCE75835408FFD2C9622574B40D15B3CBCE7583540180AD80E46584B40B56FEEAF1E5B3540180AD80E46584B40B56FEEAF1E5B35408FFD2C9622574B40D15B3CBCE75835408FFD2C9622574B40
23178	23703	20.735586999999999	20.787195000000001	54.635323999999997	54.619410999999999	Школьная	0103000020E61000000100000005000000DD5CFC6D4FBC34402EE411DC484F4B40DD5CFC6D4FBC3440942EFD4B52514B4021938C9C85C93440942EFD4B52514B4021938C9C85C934402EE411DC484F4B40DD5CFC6D4FBC34402EE411DC484F4B40
23034	23889	21.205414999999999	21.226057999999998	54.665323000000001	54.651308	Центральная	0103000020E610000001000000050000009B1BD31396343540C4CF7F0F5E534B409B1BD313963435406823D74D29554B40C9FFE4EFDE3935406823D74D29554B40C9FFE4EFDE393540C4CF7F0F5E534B409B1BD31396343540C4CF7F0F5E534B40
23313	23543	21.202082000000001	21.248453000000001	54.627105	54.598740999999997	Шоссейная	0103000020E610000001000000050000003B1C5DA5BB3335401DE38A8BA34C4B403B1C5DA5BB3335403C1405FA44504B40D597A59D9A3F35403C1405FA44504B40D597A59D9A3F35401DE38A8BA34C4B403B1C5DA5BB3335401DE38A8BA34C4B40
23169	23543	21.202082000000001	21.248453000000001	54.627105	54.598740999999997	Советская	0103000020E610000001000000050000003B1C5DA5BB3335401DE38A8BA34C4B403B1C5DA5BB3335403C1405FA44504B40D597A59D9A3F35403C1405FA44504B40D597A59D9A3F35401DE38A8BA34C4B403B1C5DA5BB3335401DE38A8BA34C4B40
23144	23543	21.202082000000001	21.248453000000001	54.627105	54.598740999999997	Железнодорожная	0103000020E610000001000000050000003B1C5DA5BB3335401DE38A8BA34C4B403B1C5DA5BB3335403C1405FA44504B40D597A59D9A3F35403C1405FA44504B40D597A59D9A3F35401DE38A8BA34C4B403B1C5DA5BB3335401DE38A8BA34C4B40
23132	23756	21.013715000000001	21.034457	54.621955	54.606413000000003	Центральная	0103000020E61000000100000005000000F37684D382033540446FF1F09E4D4B40F37684D382033540B64AB0389C4F4B40471E882CD2083540B64AB0389C4F4B40471E882CD2083540446FF1F09E4D4B40F37684D382033540446FF1F09E4D4B40
76482	60861	21.363060000000001	21.375834000000001	54.673054	54.663099000000003	Молодежная	0103000020E610000001000000050000005B7C0A80F15C35405281936DE0544B405B7C0A80F15C354093382BA226564B4091B932A83660354093382BA226564B4091B932A8366035405281936DE0544B405B7C0A80F15C35405281936DE0544B40
22984	9954	21.052772999999998	21.091518000000001	54.665047000000001	54.644848000000003	Юбилейная	0103000020E610000001000000050000009F1C0588820D35400D7217618A524B409F1C0588820D3540C6A6954220554B40CEFE40B96D173540C6A6954220554B40CEFE40B96D1735400D7217618A524B409F1C0588820D35400D7217618A524B40
23031	9954	21.052772999999998	21.091518000000001	54.665047000000001	54.644848000000003	Тельмана	0103000020E610000001000000050000009F1C0588820D35400D7217618A524B409F1C0588820D3540C6A6954220554B40CEFE40B96D173540C6A6954220554B40CEFE40B96D1735400D7217618A524B409F1C0588820D35400D7217618A524B40
23307	9954	21.052772999999998	21.091518000000001	54.665047000000001	54.644848000000003	Красноармейская	0103000020E610000001000000050000009F1C0588820D35400D7217618A524B409F1C0588820D3540C6A6954220554B40CEFE40B96D173540C6A6954220554B40CEFE40B96D1735400D7217618A524B409F1C0588820D35400D7217618A524B40
23173	9954	21.052772999999998	21.091518000000001	54.665047000000001	54.644848000000003	Калининградская	0103000020E610000001000000050000009F1C0588820D35400D7217618A524B409F1C0588820D3540C6A6954220554B40CEFE40B96D173540C6A6954220554B40CEFE40B96D1735400D7217618A524B409F1C0588820D35400D7217618A524B40
23033	9954	21.052772999999998	21.091518000000001	54.665047000000001	54.644848000000003	Вокзальная	0103000020E610000001000000050000009F1C0588820D35400D7217618A524B409F1C0588820D3540C6A6954220554B40CEFE40B96D173540C6A6954220554B40CEFE40B96D1735400D7217618A524B409F1C0588820D35400D7217618A524B40
23166	47000	20.703392000000001	20.735406999999999	54.548948000000003	54.528483000000001	Клубная	0103000020E610000001000000050000009E44847F11B43440F9BEB854A5434B409E44847F11B43440319A95ED43464B40DD3F16A243BC3440319A95ED43464B40DD3F16A243BC3440F9BEB854A5434B409E44847F11B43440F9BEB854A5434B40
24246	50996	20.752790000000001	20.772722999999999	54.501885000000001	54.491804000000002	Центральная	0103000020E610000001000000050000007FC16ED8B6C034406005F86EF33E4B407FC16ED8B6C034402EAD86C43D404B40F4DDAD2CD1C534402EAD86C43D404B40F4DDAD2CD1C534406005F86EF33E4B407FC16ED8B6C034406005F86EF33E4B40
23299	21806	20.438002000000001	20.448557000000001	54.501722999999998	54.488388999999998	Тхоржевского	0103000020E61000000100000005000000259529E620703440F25CDF87833E4B40259529E6207034405453927538404B405264ADA1D47234405453927538404B405264ADA1D4723440F25CDF87833E4B40259529E620703440F25CDF87833E4B40
23206	21493	20.087731000000002	20.110970999999999	54.508325999999997	54.493467000000003	Красноармейская	0103000020E610000001000000050000006BD8EF8975163440DF5339ED293F4B406BD8EF89751634406EDA8CD310414B40EECD6F98681C34406EDA8CD310414B40EECD6F98681C3440DF5339ED293F4B406BD8EF8975163440DF5339ED293F4B40
24186	47572	20.544839	20.555367	54.465538000000002	54.457641000000002	Центральная	0103000020E61000000100000005000000D99596917A8B34408527F4FA933A4B40D99596917A8B3440CB85CABF963B4B4013471E882C8E3440CB85CABF963B4B4013471E882C8E34408527F4FA933A4B40D99596917A8B34408527F4FA933A4B40
79547	61670	20.155186	20.451414	54.438282000000001	54.411929999999998	Молодежная	0103000020E610000001000000050000000CCC0A45BA273440E21E4B1FBA344B400CCC0A45BA2734407636E49F19384B40E0F42EDE8F7334407636E49F19384B40E0F42EDE8F733440E21E4B1FBA344B400CCC0A45BA273440E21E4B1FBA344B40
24306	51001	20.214672	20.255096000000002	54.598632000000002	54.566417000000001	 Школьная	0103000020E61000000100000005000000EE5D83BEF436344000732D5A80484B40EE5D83BEF4363440672B2FF99F4C4B402657B1F84D413440672B2FF99F4C4B402657B1F84D41344000732D5A80484B40EE5D83BEF436344000732D5A80484B40
23028	22202	20.544326999999999	20.585964000000001	54.590702999999998	54.570306000000002	Калининградская	0103000020E610000001000000050000006D54A703598B3440365B79C9FF484B406D54A703598B34401553E9279C4B4B4023A298BC019634401553E9279C4B4B4023A298BC01963440365B79C9FF484B406D54A703598B3440365B79C9FF484B40
23022	21725	20.345825999999999	20.383519	54.539980999999997	54.523806	Школьная	0103000020E61000000100000005000000431B800D885834406BB933130C434B40431B800D885834400EBBEF181E454B4006651A4D2E6234400EBBEF181E454B4006651A4D2E6234406BB933130C434B40431B800D885834406BB933130C434B40
23312	9827	19.917303	19.970922999999999	54.480705999999998	54.450476000000002	Центральная	0103000020E61000000100000005000000CF85915ED4EA334003D19332A9394B40CF85915ED4EA3340D87E32C6873D4B4028EFE3688EF83340D87E32C6873D4B4028EFE3688EF8334003D19332A9394B40CF85915ED4EA334003D19332A9394B40
23309	9827	19.917303	19.970922999999999	54.480705999999998	54.450476000000002	Калининградское шоссе	0103000020E61000000100000005000000CF85915ED4EA334003D19332A9394B40CF85915ED4EA3340D87E32C6873D4B4028EFE3688EF83340D87E32C6873D4B4028EFE3688EF8334003D19332A9394B40CF85915ED4EA334003D19332A9394B40
23167	9827	19.917303	19.970922999999999	54.480705999999998	54.450476000000002	Евсеева	0103000020E61000000100000005000000CF85915ED4EA334003D19332A9394B40CF85915ED4EA3340D87E32C6873D4B4028EFE3688EF83340D87E32C6873D4B4028EFE3688EF8334003D19332A9394B40CF85915ED4EA334003D19332A9394B40
24197	45609	20.054501999999999	20.062218999999999	54.448937000000001	54.445455000000003	Советская	0103000020E610000001000000050000000C91D3D7F30D34407B6B60AB04394B400C91D3D7F30D3440707B82C476394B4098309A95ED0F3440707B82C476394B4098309A95ED0F34407B6B60AB04394B400C91D3D7F30D34407B6B60AB04394B40
23261	22444	20.138494999999999	20.188136	54.589326	54.563197000000002	Сосновая	0103000020E61000000100000005000000D6A8876874233440481ADCD616484B40D6A88768742334405C57CC086F4B4B4044334FAE293034405C57CC086F4B4B4044334FAE29303440481ADCD616484B40D6A8876874233440481ADCD616484B40
23079	22444	20.138494999999999	20.188136	54.589326	54.563197000000002	Победы	0103000020E61000000100000005000000D6A8876874233440481ADCD616484B40D6A88768742334405C57CC086F4B4B4044334FAE293034405C57CC086F4B4B4044334FAE29303440481ADCD616484B40D6A8876874233440481ADCD616484B40
24218	48092	20.531966000000001	20.545377999999999	54.484915999999998	54.477043999999999	Центральная	0103000020E610000001000000050000007D957CEC2E88344063601DC70F3D4B407D957CEC2E88344050A73CBA113E4B4038F581E49D8B344050A73CBA113E4B4038F581E49D8B344063601DC70F3D4B407D957CEC2E88344063601DC70F3D4B40
23210	46784	20.27627	20.305185999999999	54.449413	54.436647999999998	Центральная	0103000020E61000000100000005000000ADDD76A1B946344091EEE714E4374B40ADDD76A1B9463440D9B27C5D86394B40723271AB204E3440D9B27C5D86394B40723271AB204E344091EEE714E4374B40ADDD76A1B946344091EEE714E4374B40
23119	47554	20.516542000000001	20.521896000000002	54.444890000000001	54.442402999999999	1-я Народная	0103000020E61000000100000005000000AC02B5183C8434407E5358A9A0384B40AC02B5183C843440A228D027F2384B40C9E9EBF99A853440A228D027F2384B40C9E9EBF99A8534407E5358A9A0384B40AC02B5183C8434407E5358A9A0384B40
23128	46951	20.627680999999999	20.644552000000001	54.494444999999999	54.480271000000002	Школьная	0103000020E610000001000000050000001152B7B3AFA03440CE1B2785793D4B401152B7B3AFA03440DA5548F9493F4B404792205C01A53440DA5548F9493F4B404792205C01A53440CE1B2785793D4B401152B7B3AFA03440CE1B2785793D4B40
22967	47082	20.521312000000002	20.546787999999999	54.568922999999998	54.559432999999999	Школьная	0103000020E610000001000000050000002A0307B474853440CEA623809B474B402A0307B4748534409A780778D2484B4062D8614CFA8B34409A780778D2484B4062D8614CFA8B3440CEA623809B474B402A0307B474853440CEA623809B474B40
23121	21847	20.61515	20.664162000000001	54.399410000000003	54.373598999999999	Пограничная	0103000020E6100000010000000500000068226C787A9D3440BE688F17D22F4B4068226C787A9D344002D9EBDD1F334B40F73E558506AA344002D9EBDD1F334B40F73E558506AA3440BE688F17D22F4B4068226C787A9D3440BE688F17D22F4B40
23125	21847	20.61515	20.664162000000001	54.399410000000003	54.373598999999999	Калининградская	0103000020E6100000010000000500000068226C787A9D3440BE688F17D22F4B4068226C787A9D344002D9EBDD1F334B40F73E558506AA344002D9EBDD1F334B40F73E558506AA3440BE688F17D22F4B4068226C787A9D3440BE688F17D22F4B40
32071	26113	37.909802999999997	37.912075999999999	59.154223999999999	59.152909000000001	Механизаторов	0103000020E61000000100000005000000BE66B96C74F44240CD21A98592934D40BE66B96C74F442401021AE9CBD934D40B6BB07E8BEF442401021AE9CBD934D40B6BB07E8BEF44240CD21A98592934D40BE66B96C74F44240CD21A98592934D40
7685	164	37.990696999999997	37.998054000000003	59.129621999999998	59.116188000000001	улица Юбилейная	0103000020E61000000100000005000000669FC728CFFE42400518963FDF8E4D40669FC728CFFE4240CA6B257497904D402DD2C43BC0FF4240CA6B257497904D402DD2C43BC0FF42400518963FDF8E4D40669FC728CFFE42400518963FDF8E4D40
6936	164	37.758077999999998	37.780786999999997	59.176535000000001	59.170558999999997	улица Центральная	0103000020E6100000010000000500000096E82CB308E14240EC8497E0D4954D4096E82CB308E14240B8CCE9B298964D402B1213D4F0E34240B8CCE9B298964D402B1213D4F0E34240EC8497E0D4954D4096E82CB308E14240EC8497E0D4954D40
7342	164	37.943382	37.949069000000001	59.150362000000001	59.141201000000002	улица Пионерская	0103000020E610000001000000050000004AD1CABDC0F84240CD94D6DF12924D404AD1CABDC0F84240D447E00F3F934D40DF52CE177BF94240D447E00F3F934D40DF52CE177BF94240CD94D6DF12924D404AD1CABDC0F84240CD94D6DF12924D40
31983	164	38.004925999999998	38.011924	59.138809999999999	59.113134000000002	улица Олимпийская	0103000020E610000001000000050000003673486AA10043406808C72C7B8E4D403673486AA1004340CB2DAD86C4914D40CD04C3B986014340CB2DAD86C4914D40CD04C3B9860143406808C72C7B8E4D403673486AA10043406808C72C7B8E4D40
6859	164	37.879458	37.913567	59.133408000000003	59.129091000000003	улица Металлургов	0103000020E61000000100000005000000501A6A1492F042409E9ACB0D86904D40501A6A1492F042402C836A8313914D4038DA71C3EFF442402C836A8313914D4038DA71C3EFF442409E9ACB0D86904D40501A6A1492F042409E9ACB0D86904D40
7045	164	37.876672999999997	37.937894	59.131160000000001	59.123429999999999	улица Ленина	0103000020E61000000100000005000000A22424D236F0424032ACE28DCC8F4D40A22424D236F042408D45D3D9C9904D40AC8E1CE90CF842408D45D3D9C9904D40AC8E1CE90CF8424032ACE28DCC8F4D40A22424D236F0424032ACE28DCC8F4D40
31715	164	37.960307	38.033627000000003	59.133190999999997	59.129016999999997	улица Краснодонцев	0103000020E61000000100000005000000588FFB56EBFA424063D009A183904D40588FFB56EBFA42408E8F16670C914D409DA1B8E34D0443408E8F16670C914D409DA1B8E34D04434063D009A183904D40588FFB56EBFA424063D009A183904D40
3250	164	37.981974000000001	38.025866000000001	59.127668999999997	59.118774000000002	улица Космонавта Беляева	0103000020E61000000100000005000000DBC2F352B1FD4240BCCE86FC338F4D40DBC2F352B1FD424044DB317557904D40070ABC934F03434044DB317557904D40070ABC934F034340BCCE86FC338F4D40DBC2F352B1FD4240BCCE86FC338F4D40
32028	164	37.916415000000001	37.919316000000002	59.103810000000003	59.099259000000004	улица Батюшкова	0103000020E610000001000000050000002C4833164DF54240B66AD784B48C4D402C4833164DF54240B77F65A5498D4D4043588D25ACF54240B77F65A5498D4D4043588D25ACF54240B66AD784B48C4D402C4833164DF54240B66AD784B48C4D40
31850	164	37.884380999999998	37.903838	59.124889000000003	59.122247000000002	проспект Строителей	0103000020E61000000100000005000000151A886533F142405E8429CAA58F4D40151A886533F14240A950DD5CFC8F4D40E770ADF6B0F34240A950DD5CFC8F4D40E770ADF6B0F342405E8429CAA58F4D40151A886533F142405E8429CAA58F4D40
26409	164	37.990696999999997	37.998054000000003	59.129621999999998	59.116188000000001	Юбилейная	0103000020E61000000100000005000000669FC728CFFE42400518963FDF8E4D40669FC728CFFE4240CA6B257497904D402DD2C43BC0FF4240CA6B257497904D402DD2C43BC0FF42400518963FDF8E4D40669FC728CFFE42400518963FDF8E4D40
32067	164	37.915346	37.935862999999998	59.094234999999998	59.091383	Шекснинский проспект	0103000020E610000001000000050000002043C70E2AF5424087342A70B28B4D402043C70E2AF54240BC9179E40F8C4D40AA44D95BCAF74240BC9179E40F8C4D40AA44D95BCAF7424087342A70B28B4D402043C70E2AF5424087342A70B28B4D40
31854	164	37.872217999999997	37.875694000000003	59.132153000000002	59.124326000000003	Чкалова	0103000020E61000000100000005000000C37DE4D6A4EF4240710514EAE98F4D40C37DE4D6A4EF4240BE88B663EA904D40D7A6B1BD16F04240BE88B663EA904D40D7A6B1BD16F04240710514EAE98F4D40C37DE4D6A4EF4240710514EAE98F4D40
26571	164	37.966755999999997	37.980778999999998	59.128542000000003	59.118054000000001	Суворова	0103000020E610000001000000050000001B9B1DA9BEFB4240BC94BA641C8F4D401B9B1DA9BEFB4240CB14731074904D4042CD902A8AFD4240CB14731074904D4042CD902A8AFD4240BC94BA641C8F4D401B9B1DA9BEFB4240BC94BA641C8F4D40
15975	164	37.880833000000003	37.883555000000001	59.126103999999998	59.124043999999998	Строителей площадь	0103000020E61000000100000005000000691EC022BFF04240ECA17DACE08F4D40691EC022BFF0424088F2052D24904D40D09B8A5418F1424088F2052D24904D40D09B8A5418F14240ECA17DACE08F4D40691EC022BFF04240ECA17DACE08F4D40
32065	164	37.902059999999999	37.918776999999999	59.139650000000003	59.118372000000001	Сталеваров	0103000020E61000000100000005000000CF83BBB376F342408D614ED0268F4D40CF83BBB376F3424076711B0DE0914D4093A8177C9AF5424076711B0DE0914D4093A8177C9AF542408D614ED0268F4D40CF83BBB376F342408D614ED0268F4D40
899	164	37.928398000000001	37.934883999999997	59.136105000000001	59.119808999999997	Советский проспект	0103000020E61000000100000005000000FED5E3BED5F642401B62BCE6558F4D40FED5E3BED5F642403AE97DE36B914D40DEC66647AAF742403AE97DE36B914D40DEC66647AAF742401B62BCE6558F4D40FED5E3BED5F642401B62BCE6558F4D40
7315	164	37.930805999999997	37.967816999999997	59.151871	59.144717999999997	Северное шоссе	0103000020E61000000100000005000000D575A8A624F742403E92921E86924D40D575A8A624F74240FC1A498270934D40A4C16D6DE1FB4240FC1A498270934D40A4C16D6DE1FB42403E92921E86924D40D575A8A624F742403E92921E86924D40
7129	164	37.894396999999998	38.008411000000002	59.135421000000001	59.119540999999998	Победы проспект	0103000020E61000000100000005000000FC51D4997BF24240FCC3961E4D8F4D40FC51D4997BF242408718AF7955914D409DF6949C130143408718AF7955914D409DF6949C13014340FCC3961E4D8F4D40FC51D4997BF24240FCC3961E4D8F4D40
31742	164	37.943382	37.949069000000001	59.150362000000001	59.141201000000002	Пионерская	0103000020E610000001000000050000004AD1CABDC0F84240CD94D6DF12924D404AD1CABDC0F84240D447E00F3F934D40DF52CE177BF94240D447E00F3F934D40DF52CE177BF94240CD94D6DF12924D404AD1CABDC0F84240CD94D6DF12924D40
32119	164	37.960352	37.968786999999999	59.125914000000002	59.115595999999996	Первомайская	0103000020E61000000100000005000000F85278D0ECFA424032C687D9CB8E4D40F85278D0ECFA4240E50D30F31D904D401DE5603601FC4240E50D30F31D904D401DE5603601FC424032C687D9CB8E4D40F85278D0ECFA424032C687D9CB8E4D40
31673	164	37.939959999999999	37.954225000000001	59.148701000000003	59.147486999999998	Партизана Окинина	0103000020E610000001000000050000002AC6F99B50F84240E6CAA0DAE0924D402AC6F99B50F84240F6F065A208934D404703780B24FA4240F6F065A208934D404703780B24FA4240E6CAA0DAE0924D402AC6F99B50F84240E6CAA0DAE0924D40
26737	164	38.004925999999998	38.011924	59.138809999999999	59.113134000000002	Олимпийская	0103000020E610000001000000050000003673486AA10043406808C72C7B8E4D403673486AA1004340CB2DAD86C4914D40CD04C3B986014340CB2DAD86C4914D40CD04C3B9860143406808C72C7B8E4D403673486AA10043406808C72C7B8E4D40
6923	164	37.905518000000001	37.923870999999998	59.106180999999999	59.080027999999999	Октябрьский проспект	0103000020E610000001000000050000003CF88903E8F34240D461855B3E8A4D403CF88903E8F34240713AC956978D4D40855CA96741F64240713AC956978D4D40855CA96741F64240D461855B3E8A4D403CF88903E8F34240D461855B3E8A4D40
31861	164	37.937291999999999	37.941980999999998	59.132309999999997	59.122011999999998	Набережная	0103000020E61000000100000005000000B6662B2FF9F742401ADCD6169E8F4D40B6662B2FF9F742408577B988EF904D40083A5AD592F842408577B988EF904D40083A5AD592F842401ADCD6169E8F4D40B6662B2FF9F742401ADCD6169E8F4D40
26506	164	37.954422999999998	37.963954000000001	59.145946000000002	59.143633000000001	Моченкова	0103000020E610000001000000050000006DC669882AFA42402DD0EE9062924D406DC669882AFA4240B37DC85BAE924D40986C3CD862FB4240B37DC85BAE924D40986C3CD862FB42402DD0EE9062924D406DC669882AFA42402DD0EE9062924D40
32109	164	37.929189000000001	37.954216000000002	59.145876000000001	59.143033000000003	Молодёжная	0103000020E61000000100000005000000C76647AAEFF64240D89FC4E74E924D40C76647AAEFF64240BAA29410AC924D40F4A8F8BF23FA4240BAA29410AC924D40F4A8F8BF23FA4240D89FC4E74E924D40C76647AAEFF64240D89FC4E74E924D40
31906	164	37.891559000000001	37.898618999999997	59.126292999999997	59.125425	Менделеева	0103000020E610000001000000050000002CBAF59A1EF24240E78C28ED0D904D402CBAF59A1EF242405B5B785E2A904D40384888F205F342405B5B785E2A904D40384888F205F34240E78C28ED0D904D402CBAF59A1EF24240E78C28ED0D904D40
31804	164	37.911447000000003	37.948690999999997	59.109216000000004	59.100386	Матуринская	0103000020E61000000100000005000000C784984BAAF44240F67CCD72D98C4D40C784984BAAF44240981936CAFA8D4D403881E9B46EF94240981936CAFA8D4D403881E9B46EF94240F67CCD72D98C4D40C784984BAAF44240F67CCD72D98C4D40
31737	164	37.916505000000001	37.926557000000003	59.139460999999997	59.116294000000003	Максима Горького	0103000020E610000001000000050000006CCF2C0950F542404B5CC7B8E28E4D406CCF2C0950F54240A208A9DBD9914D40A070766B99F64240A208A9DBD9914D40A070766B99F642404B5CC7B8E28E4D406CCF2C0950F542404B5CC7B8E28E4D40
26520	164	37.898519999999998	37.910772999999999	59.098329999999997	59.086075000000001	Любецкая	0103000020E61000000100000005000000A5660FB402F3424069006F81048B4D40A5660FB402F342409B1BD313968C4D40378AAC3594F442409B1BD313968C4D40378AAC3594F4424069006F81048B4D40A5660FB402F3424069006F81048B4D40
865	164	37.920915000000001	37.927625999999997	59.136381999999998	59.122123000000002	Луначарского проспект	0103000020E61000000100000005000000ABB2EF8AE0F54240728BF9B9A18F4D40ABB2EF8AE0F54240ACE122F774914D40AB75E272BCF64240ACE122F774914D40AB75E272BCF64240728BF9B9A18F4D40ABB2EF8AE0F54240728BF9B9A18F4D40
26523	164	37.911223	37.938208000000003	59.099319000000001	59.096462000000002	Ленинградская	0103000020E61000000100000005000000772E8CF4A2F4424044A7E7DD588C4D40772E8CF4A2F442408B6F287CB68C4D403C6C223317F842408B6F287CB68C4D403C6C223317F8424044A7E7DD588C4D40772E8CF4A2F4424044A7E7DD588C4D40
31734	164	37.876672999999997	37.937894	59.131160000000001	59.123429999999999	Ленина	0103000020E61000000100000005000000A22424D236F0424032ACE28DCC8F4D40A22424D236F042408D45D3D9C9904D40AC8E1CE90CF842408D45D3D9C9904D40AC8E1CE90CF8424032ACE28DCC8F4D40A22424D236F0424032ACE28DCC8F4D40
32127	164	37.987256000000002	37.990076999999999	59.136316999999998	59.126949000000003	Леднёва	0103000020E61000000100000005000000D06394675EFE424045A165DD3F904D40D06394675EFE4240C571E0D572914D40CAC2D7D7BAFE4240C571E0D572914D40CAC2D7D7BAFE424045A165DD3F904D40D06394675EFE424045A165DD3F904D40
31667	164	37.960307	38.033627000000003	59.133190999999997	59.129016999999997	Краснодонцев	0103000020E61000000100000005000000588FFB56EBFA424063D009A183904D40588FFB56EBFA42408E8F16670C914D409DA1B8E34D0443408E8F16670C914D409DA1B8E34D04434063D009A183904D40588FFB56EBFA424063D009A183904D40
31876	164	37.943724000000003	37.983510000000003	59.119832000000002	59.114145999999998	Красная	0103000020E61000000100000005000000A439B2F2CBF842400F7C0C569C8E4D40A439B2F2CBF84240D481ACA7568F4D40FDA4DAA7E3FD4240D481ACA7568F4D40FDA4DAA7E3FD42400F7C0C569C8E4D40A439B2F2CBF842400F7C0C569C8E4D40
31806	164	37.981974000000001	38.025866000000001	59.127668999999997	59.118774000000002	Космонавта Беляева	0103000020E61000000100000005000000DBC2F352B1FD4240BCCE86FC338F4D40DBC2F352B1FD424044DB317557904D40070ABC934F03434044DB317557904D40070ABC934F034340BCCE86FC338F4D40DBC2F352B1FD4240BCCE86FC338F4D40
32115	164	37.917178	37.93439	59.139907999999998	59.133814999999998	Комсомольская	0103000020E610000001000000050000002B4EB51666F542406C5B94D920914D402B4EB51666F5424071395E81E8914D40CFDA6D179AF7424071395E81E8914D40CFDA6D179AF742406C5B94D920914D402B4EB51666F542406C5B94D920914D40
31704	164	37.976063000000003	38.009103000000003	59.117213	59.113396999999999	Командарма Белова	0103000020E61000000100000005000000F7EAE3A1EFFC4240753BFBCA838E4D40F7EAE3A1EFFC424041D5E8D5008F4D40D3A57F492A01434041D5E8D5008F4D40D3A57F492A014340753BFBCA838E4D40F7EAE3A1EFFC4240753BFBCA838E4D40
31848	164	37.88306	37.888001000000003	59.127446999999997	59.126297999999998	Клубный проезд	0103000020E61000000100000005000000F0332E1C08F142406DC669882A904D40F0332E1C08F14240957CEC2E50904D405CE84A04AAF14240957CEC2E50904D405CE84A04AAF142406DC669882A904D40F0332E1C08F142406DC669882A904D40
31914	164	37.895960000000002	37.901144000000002	59.13062	59.119993999999998	Доменщиков бульвар	0103000020E61000000100000005000000184339D1AEF24240ADDBA0F65B8F4D40184339D1AEF242400D1AFA27B8904D404A7EC4AF58F342400D1AFA27B8904D404A7EC4AF58F34240ADDBA0F65B8F4D40184339D1AEF24240ADDBA0F65B8F4D40
32025	164	37.901575000000001	37.917017000000001	59.089460000000003	59.086708999999999	Городецкая	0103000020E6100000010000000500000013F241CF66F342406AA2CF47198B4D4013F241CF66F342406C26DF6C738B4D40227024D060F542406C26DF6C738B4D40227024D060F542406AA2CF47198B4D4013F241CF66F342406AA2CF47198B4D40
31999	164	37.951287999999998	37.960566999999998	59.137881999999998	59.118876	Гоголя	0103000020E61000000100000005000000E38920CEC3F94240C0232A54378F4D40E38920CEC3F94240815A0C1EA6914D40F44E05DCF3FA4240815A0C1EA6914D40F44E05DCF3FA4240C0232A54378F4D40E38920CEC3F94240C0232A54378F4D40
31793	164	37.886375000000001	37.889015999999998	59.135283000000001	59.129862000000003	Гагарина	0103000020E61000000100000005000000FA7E6ABC74F14240207F69519F904D40FA7E6ABC74F14240365A0EF450914D4074CFBA46CBF14240365A0EF450914D4074CFBA46CBF14240207F69519F904D40FA7E6ABC74F14240207F69519F904D40
31794	164	37.912399000000001	37.924841000000001	59.140070000000001	59.126561000000002	Вологодская	0103000020E6100000010000000500000099F38C7DC9F442407BF99D2633904D4099F38C7DC9F442404B9352D0ED914D40FE7F9C3061F642404B9352D0ED914D40FE7F9C3061F642407BF99D2633904D4099F38C7DC9F442407BF99D2633904D40
32014	164	37.974795999999998	37.982118	59.134386999999997	59.115084000000003	Архангельская	0103000020E61000000100000005000000C422861DC6FC42407D259012BB8E4D40C422861DC6FC4240F700DD9733914D400E68E90AB6FD4240F700DD9733914D400E68E90AB6FD42407D259012BB8E4D40C422861DC6FC42407D259012BB8E4D40
31736	164	37.879458	37.913567	59.133408000000003	59.129091000000003	 Металлургов	0103000020E61000000100000005000000501A6A1492F042409E9ACB0D86904D40501A6A1492F042402C836A8313914D4038DA71C3EFF442402C836A8313914D4038DA71C3EFF442409E9ACB0D86904D40501A6A1492F042409E9ACB0D86904D40
31872	53270	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Ленина	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
31887	53270	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Коммунистический переулок	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
31835	53263	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Суворова	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31833	53263	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Кооперативная	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
32048	53263	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Беляева	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31812	53266	45.429645000000001	45.492213	59.557451	59.498026000000003	25 Октября	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
26479	29401	39.808194999999998	39.825370999999997	59.268549	59.248672999999997	Дачная	0103000020E6100000010000000500000036E50AEF72E74340F8325184D49F4D4036E50AEF72E74340CF2F4AD05FA24D408D08C6C1A5E94340CF2F4AD05FA24D408D08C6C1A5E94340F8325184D49F4D4036E50AEF72E74340F8325184D49F4D40
31689	53249	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Румянцевой	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
31842	53249	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Комсомольская	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
31769	53249	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Газовиков	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
7716	17	39.850091999999997	39.875847	59.205447999999997	59.195532	улица Ярославская	0103000020E61000000100000005000000AD4B8DD0CFEC434026A94C3107994D40AD4B8DD0CFEC4340A983BC1E4C9A4D405DA626C11BF04340A983BC1E4C9A4D405DA626C11BF0434026A94C3107994D40AD4B8DD0CFEC434026A94C3107994D40
371	17	39.829053999999999	39.838521999999998	59.220142000000003	59.205854000000002	улица Щетинина	0103000020E610000001000000050000001A4F04711EEA43401AE0826C599A4D401A4F04711EEA4340EF3CF19C2D9C4D40FE7C5BB054EB4340EF3CF19C2D9C4D40FE7C5BB054EB43401AE0826C599A4D401A4F04711EEA43401AE0826C599A4D40
722	17	39.890372999999997	39.904404999999997	59.255381	59.222928000000003	улица Чернышевского	0103000020E61000000100000005000000E61E12BEF7F143406DAE9AE7889C4D40E61E12BEF7F1434088821953B0A04D4060AB048BC3F3434088821953B0A04D4060AB048BC3F343406DAE9AE7889C4D40E61E12BEF7F143406DAE9AE7889C4D40
341	17	39.836806000000003	39.845627999999998	59.210953000000003	59.205725000000001	улица Тендрякова	0103000020E610000001000000050000005D8C81751CEB43401C7C6132559A4D405D8C81751CEB43401EFF0582009B4D407B4ACE893DEC43401EFF0582009B4D407B4ACE893DEC43401C7C6132559A4D405D8C81751CEB43401C7C6132559A4D40
437	17	39.834381	39.848305000000003	59.214463000000002	59.208351	улица Солодунова	0103000020E61000000100000005000000AFB321FFCCEA4340618BDD3EAB9A4D40AFB321FFCCEA4340DD990986739B4D4043041C4295EC4340DD990986739B4D4043041C4295EC4340618BDD3EAB9A4D40AFB321FFCCEA4340618BDD3EAB9A4D40
41	17	39.908473999999998	39.944459999999999	59.215721000000002	59.210768999999999	улица Пугачева	0103000020E6100000010000000500000016A243E048F443405C01857AFA9A4D4016A243E048F44340BC07E8BE9C9B4D40A930B610E4F84340BC07E8BE9C9B4D40A930B610E4F843405C01857AFA9A4D4016A243E048F443405C01857AFA9A4D40
136	17	39.862067000000003	39.870654999999999	59.229899000000003	59.218226000000001	улица Пролетарская	0103000020E61000000100000005000000FDFA213658EE434086915ED4EE9B4D40FDFA213658EE43400A3197546D9D4D40A88C7F9F71EF43400A3197546D9D4D40A88C7F9F71EF434086915ED4EE9B4D40FDFA213658EE434086915ED4EE9B4D40
7661	17	39.902644000000002	39.914861000000002	59.195937999999998	59.192996999999998	улица Пригородная	0103000020E610000001000000050000001FF7ADD689F34340F19C2D20B4984D401FF7ADD689F343409605137F14994D4064B14D2A1AF543409605137F14994D4064B14D2A1AF54340F19C2D20B4984D401FF7ADD689F34340F19C2D20B4984D40
400	17	39.811751999999998	39.857089999999999	59.221367000000001	59.215558999999999	улица Преображенского	0103000020E61000000100000005000000363B527DE7E74340E2ADF36F979B4D40363B527DE7E74340F2B4FCC0559C4D4044DD0720B5ED4340F2B4FCC0559C4D4044DD0720B5ED4340E2ADF36F979B4D40363B527DE7E74340E2ADF36F979B4D40
7850	17	39.977339000000001	39.991765999999998	59.177877000000002	59.171729999999997	улица Пионерская	0103000020E610000001000000050000007C0DC17119FD4340FCDEA63FFB954D407C0DC17119FD4340F5DA6CACC4964D4072A43330F2FE4340F5DA6CACC4964D4072A43330F2FE4340FCDEA63FFB954D407C0DC17119FD4340FCDEA63FFB954D40
6061	17	39.892161000000002	39.903002999999998	59.212541999999999	59.207816000000001	улица Первомайская	0103000020E6100000010000000500000022E2E65432F24340F3CAF5B6999A4D4022E2E65432F2434062838593349B4D404E98309A95F3434062838593349B4D404E98309A95F34340F3CAF5B6999A4D4022E2E65432F24340F3CAF5B6999A4D40
392	17	39.811805999999997	39.849570999999997	59.217457000000003	59.215480999999997	улица Панкратова	0103000020E6100000010000000500000029594E42E9E7434066F4A3E1949B4D4029594E42E9E74340A5A487A1D59B4D40A45016BEBEEC4340A5A487A1D59B4D40A45016BEBEEC434066F4A3E1949B4D4029594E42E9E7434066F4A3E1949B4D40
8044	17	39.891074000000003	39.920268999999998	59.232793999999998	59.221361999999999	улица Некрасова	0103000020E6100000010000000500000070287CB60EF24340E0490B97559C4D4070287CB60EF243403E5A9C31CC9D4D40E542E55FCBF543403E5A9C31CC9D4D40E542E55FCBF54340E0490B97559C4D4070287CB60EF24340E0490B97559C4D40
7963	17	39.851852999999998	39.861581999999999	59.200324999999999	59.197408000000003	улица Медуницинская	0103000020E61000000100000005000000EFFFE38409ED434001FC53AA44994D40EFFFE38409ED43401DC9E53FA4994D404069A85148EE43401DC9E53FA4994D404069A85148EE434001FC53AA44994D40EFFFE38409ED434001FC53AA44994D40
958	17	39.839635999999999	39.849553	59.213777	59.209193999999997	улица Кирпичная	0103000020E61000000100000005000000AA45443179EB43407C4276DEC69A4D40AA45443179EB434089D1730B5D9B4D40FE9B1727BEEC434089D1730B5D9B4D40FE9B1727BEEC43407C4276DEC69A4D40AA45443179EB43407C4276DEC69A4D40
8091	17	39.900120000000001	39.936312999999998	59.232923	59.211266000000002	улица Карла Маркса	0103000020E61000000100000005000000DE3CD52137F34340DD60A8C30A9B4D40DE3CD52137F343403CBEBD6BD09D4D40EAE8B81AD9F743403CBEBD6BD09D4D40EAE8B81AD9F74340DD60A8C30A9B4D40DE3CD52137F34340DD60A8C30A9B4D40
460	17	39.789824000000003	39.821212000000003	59.210419000000002	59.209290000000003	улица Ильюшина	0103000020E6100000010000000500000047CCECF318E543409FB0C403CA9A4D4047CCECF318E5434080BA8102EF9A4D40988A8D791DE9434080BA8102EF9A4D40988A8D791DE943409FB0C403CA9A4D4047CCECF318E543409FB0C403CA9A4D40
2691	17	39.908859999999997	39.924768999999998	59.231983999999997	59.224888999999997	улица Заречная	0103000020E610000001000000050000003F52448655F44340751DAA29C99C4D403F52448655F44340FE98D6A6B19D4D4064ADA1D45EF64340FE98D6A6B19D4D4064ADA1D45EF64340751DAA29C99C4D403F52448655F44340751DAA29C99C4D40
238	17	39.840373	39.854764000000003	59.239210999999997	59.235114000000003	улица Залинейная	0103000020E6100000010000000500000080B8AB5791EB4340776A2E37189E4D4080B8AB5791EB4340F6EB4E779E9E4D402AE620E868ED4340F6EB4E779E9E4D402AE620E868ED4340776A2E37189E4D4080B8AB5791EB4340776A2E37189E4D40
7986	17	39.886105999999998	39.920358999999998	59.231036000000003	59.21181	улица Горького	0103000020E610000001000000050000000A65E1EB6BF143409E7B0F971C9B4D400A65E1EB6BF143406E197096929D4D4025CADE52CEF543406E197096929D4D4025CADE52CEF543409E7B0F971C9B4D400A65E1EB6BF143409E7B0F971C9B4D40
7729	17	39.883060999999998	39.912309999999998	59.218147999999999	59.198960999999997	улица Герцена	0103000020E61000000100000005000000C0AF912408F14340F816D68D77994D40C0AF912408F143400AD80E46EC9B4D4029E8F692C6F443400AD80E46EC9B4D4029E8F692C6F44340F816D68D77994D40C0AF912408F14340F816D68D77994D40
32104	17	39.860387000000003	39.889789	59.227297	59.220869	проспект Победы	0103000020E61000000100000005000000A873452921EE4340A1D9756F459C4D40A873452921EE43404DBD6E11189D4D4097AB1F9BE4F143404DBD6E11189D4D4097AB1F9BE4F14340A1D9756F459C4D40A873452921EE4340A1D9756F459C4D40
32120	17	39.909686999999998	39.931471000000002	59.197228000000003	59.191674999999996	космонавта Беляева	0103000020E61000000100000005000000554CA59F70F44340FB3A70CE88984D40554CA59F70F4434081ED60C43E994D40121615713AF7434081ED60C43E994D40121615713AF74340FB3A70CE88984D40554CA59F70F44340FB3A70CE88984D40
32112	17	39.850091999999997	39.875847	59.205447999999997	59.195532	Ярославская	0103000020E61000000100000005000000AD4B8DD0CFEC434026A94C3107994D40AD4B8DD0CFEC4340A983BC1E4C9A4D405DA626C11BF04340A983BC1E4C9A4D405DA626C11BF0434026A94C3107994D40AD4B8DD0CFEC434026A94C3107994D40
32107	17	39.927033000000002	39.953074999999998	59.204650999999998	59.200200000000002	Элеваторная	0103000020E6100000010000000500000009A87004A9F6434061545227A0994D4009A87004A9F64340FE0B0401329A4D404ED1915CFEF94340FE0B0401329A4D404ED1915CFEF9434061545227A0994D4009A87004A9F6434061545227A0994D40
32076	17	39.829053999999999	39.838521999999998	59.220142000000003	59.205854000000002	Щетинина	0103000020E610000001000000050000001A4F04711EEA43401AE0826C599A4D401A4F04711EEA4340EF3CF19C2D9C4D40FE7C5BB054EB4340EF3CF19C2D9C4D40FE7C5BB054EB43401AE0826C599A4D401A4F04711EEA43401AE0826C599A4D40
6048	17	39.872352999999997	39.876683	59.204683000000003	59.203006000000002	Школьный переулок	0103000020E61000000100000005000000A3C85A43A9EF43402672C119FC994D40A3C85A43A9EF43400A86730D339A4D40C6FA062637F043400A86730D339A4D40C6FA062637F043402672C119FC994D40A3C85A43A9EF43402672C119FC994D40
32053	17	39.890372999999997	39.904404999999997	59.255381	59.222928000000003	Чернышевского	0103000020E61000000100000005000000E61E12BEF7F143406DAE9AE7889C4D40E61E12BEF7F1434088821953B0A04D4060AB048BC3F3434088821953B0A04D4060AB048BC3F343406DAE9AE7889C4D40E61E12BEF7F143406DAE9AE7889C4D40
7704	17	39.887112000000002	39.887912	59.208323	59.206378999999998	Техникумовский переулок	0103000020E61000000100000005000000D0F1D1E28CF1434064CA87A06A9A4D40D0F1D1E28CF143409700FC53AA9A4D40ECDCB419A7F143409700FC53AA9A4D40ECDCB419A7F1434064CA87A06A9A4D40D0F1D1E28CF1434064CA87A06A9A4D40
32096	17	39.836806000000003	39.845627999999998	59.210953000000003	59.205725000000001	Тендрякова	0103000020E610000001000000050000005D8C81751CEB43401C7C6132559A4D405D8C81751CEB43401EFF0582009B4D407B4ACE893DEC43401EFF0582009B4D407B4ACE893DEC43401C7C6132559A4D405D8C81751CEB43401C7C6132559A4D40
32129	17	39.889024999999997	39.892152000000003	59.272024999999999	59.268180999999998	Строителей	0103000020E61000000100000005000000C7293A92CBF143404C3448C153A24D40C7293A92CBF14340E25817B7D1A24D40CF87670932F24340E25817B7D1A24D40CF87670932F243404C3448C153A24D40C7293A92CBF143404C3448C153A24D40
625	17	39.892806999999998	39.927204000000003	59.218635999999996	59.196992999999999	Советский проспект	0103000020E61000000100000005000000E751F17F47F243403D450E1137994D40E751F17F47F2434037DDB243FC9B4D40365CE49EAEF6434037DDB243FC9B4D40365CE49EAEF643403D450E1137994D40E751F17F47F243403D450E1137994D40
32132	17	39.921067999999998	39.959031000000003	59.223816999999997	59.215532000000003	Северная	0103000020E6100000010000000500000031B2648EE5F54340E99E758D969B4D4031B2648EE5F54340F8A41309A69C4D40D36C1E87C1FA4340F8A41309A69C4D40D36C1E87C1FA4340E99E758D969B4D4031B2648EE5F54340E99E758D969B4D40
32130	17	39.911537000000003	39.948081000000002	59.235934	59.224598999999998	Саммера	0103000020E61000000100000005000000070C923EADF443406EDBF7A8BF9C4D40070C923EADF44340DA01D715339E4D40C07ADCB75AF94340DA01D715339E4D40C07ADCB75AF943406EDBF7A8BF9C4D40070C923EADF443406EDBF7A8BF9C4D40
32087	17	39.862067000000003	39.870654999999999	59.229899000000003	59.218226000000001	Пролетарская	0103000020E61000000100000005000000FDFA213658EE434086915ED4EE9B4D40FDFA213658EE43400A3197546D9D4D40A88C7F9F71EF43400A3197546D9D4D40A88C7F9F71EF434086915ED4EE9B4D40FDFA213658EE434086915ED4EE9B4D40
32079	17	39.902644000000002	39.914861000000002	59.195937999999998	59.192996999999998	Пригородная	0103000020E610000001000000050000001FF7ADD689F34340F19C2D20B4984D401FF7ADD689F343409605137F14994D4064B14D2A1AF543409605137F14994D4064B14D2A1AF54340F19C2D20B4984D401FF7ADD689F34340F19C2D20B4984D40
756	17	39.828533	39.880859999999998	59.208590000000001	59.176580999999999	Пошехонское шоссе	0103000020E6100000010000000500000011548D5E0DEA4340280CCA349A964D4011548D5E0DEA4340E622BE13B39A4D40622D3E05C0F04340E622BE13B39A4D40622D3E05C0F04340280CCA349A964D4011548D5E0DEA4340280CCA349A964D40
156	17	39.860387000000003	39.889789	59.227297	59.220869	Победы проспект	0103000020E61000000100000005000000A873452921EE4340A1D9756F459C4D40A873452921EE43404DBD6E11189D4D4097AB1F9BE4F143404DBD6E11189D4D4097AB1F9BE4F14340A1D9756F459C4D40A873452921EE4340A1D9756F459C4D40
32105	17	39.894882000000003	39.905392999999997	59.211032000000003	59.206659999999999	Пирогова	0103000020E61000000100000005000000B9E34D7E8BF2434018B2BAD5739A4D40B9E34D7E8BF243406A34B918039B4D407F83F6EAE3F343406A34B918039B4D407F83F6EAE3F3434018B2BAD5739A4D40B9E34D7E8BF2434018B2BAD5739A4D40
32094	17	39.977339000000001	39.991765999999998	59.177877000000002	59.171729999999997	Пионерская	0103000020E610000001000000050000007C0DC17119FD4340FCDEA63FFB954D407C0DC17119FD4340F5DA6CACC4964D4072A43330F2FE4340F5DA6CACC4964D4072A43330F2FE4340FCDEA63FFB954D407C0DC17119FD4340FCDEA63FFB954D40
32110	17	39.925604999999997	39.932917000000003	59.193356999999999	59.185133999999998	Петрозаводская	0103000020E61000000100000005000000CD0182397AF6434057B08D78B2974D40CD0182397AF64340F1B913ECBF984D40F47002D369F74340F1B913ECBF984D40F47002D369F7434057B08D78B2974D40CD0182397AF6434057B08D78B2974D40
32116	17	39.814779999999999	39.823034999999997	59.215623999999998	59.210419000000002	Первый МКР ГПЗ-23	0103000020E61000000100000005000000AAB706B64AE8434080BA8102EF9A4D40AAB706B64AE84340C91D3691999B4D404F3BFC3559E94340C91D3691999B4D404F3BFC3559E9434080BA8102EF9A4D40AAB706B64AE8434080BA8102EF9A4D40
32092	17	39.892161000000002	39.903002999999998	59.212541999999999	59.207816000000001	Первомайская	0103000020E6100000010000000500000022E2E65432F24340F3CAF5B6999A4D4022E2E65432F2434062838593349B4D404E98309A95F3434062838593349B4D404E98309A95F34340F3CAF5B6999A4D4022E2E65432F24340F3CAF5B6999A4D40
32118	17	39.925604999999997	39.930338999999996	59.230018000000001	59.224953999999997	Открытая	0103000020E61000000100000005000000CD0182397AF643405C8DEC4ACB9C4D40CD0182397AF64340E4BED53A719D4D40BF982D5915F74340E4BED53A719D4D40BF982D5915F743405C8DEC4ACB9C4D40CD0182397AF643405C8DEC4ACB9C4D40
26527	17	39.886133000000001	39.897208999999997	59.183796999999998	59.176222000000003	Осаново	0103000020E6100000010000000500000004745FCE6CF14340F96A47718E964D4004745FCE6CF143402C0DFCA886974D40A35698BED7F243402C0DFCA886974D40A35698BED7F24340F96A47718E964D4004745FCE6CF14340F96A47718E964D40
520	17	39.811653999999997	39.849203000000003	59.215558999999999	59.188175999999999	Окружное шоссе	0103000020E6100000010000000500000073D53C47E4E7434030F2B22616984D4073D53C47E4E74340E2ADF36F979B4D40225514AFB2EC4340E2ADF36F979B4D40225514AFB2EC434030F2B22616984D4073D53C47E4E7434030F2B22616984D40
8064	17	39.903129	39.911456000000001	59.231085999999998	59.228881000000001	Некрасовский переулок	0103000020E61000000100000005000000DB8827BB99F3434080D6FCF84B9D4D40DB8827BB99F343401F48DE39949D4D401ADF1797AAF443401F48DE39949D4D401ADF1797AAF4434080D6FCF84B9D4D40DB8827BB99F3434080D6FCF84B9D4D40
7870	17	39.931471000000002	39.993580000000001	59.191674999999996	59.167878999999999	Московское шоссе	0103000020E61000000100000005000000121615713AF74340B4571F0F7D954D40121615713AF74340FB3A70CE88984D40D7FA22A12DFF4340FB3A70CE88984D40D7FA22A12DFF4340B4571F0F7D954D40121615713AF74340B4571F0F7D954D40
32099	17	39.873187999999999	39.932917000000003	59.205854000000002	59.193356999999999	Можайского	0103000020E610000001000000050000003CA1D79FC4EF4340F1B913ECBF984D403CA1D79FC4EF43401AE0826C599A4D40F47002D369F743401AE0826C599A4D40F47002D369F74340F1B913ECBF984D403CA1D79FC4EF4340F1B913ECBF984D40
32136	17	39.880851	39.891908999999998	59.222591999999999	59.209142999999997	Мира	0103000020E610000001000000050000000FD3BEB9BFF04340FA97A432C59A4D400FD3BEB9BFF04340F52C08E57D9C4D400801F9122AF24340F52C08E57D9C4D400801F9122AF24340FA97A432C59A4D400FD3BEB9BFF04340FA97A432C59A4D40
32089	17	39.908160000000002	39.923718000000001	59.215370999999998	59.209280999999997	Машиностроительная	0103000020E6100000010000000500000087C43D963EF443404B5645B8C99A4D4087C43D963EF44340DFC0E446919B4D40FF5C34643CF64340DFC0E446919B4D40FF5C34643CF643404B5645B8C99A4D4087C43D963EF443404B5645B8C99A4D40
6033	17	39.841450999999999	39.843848999999999	59.213389999999997	59.211979999999997	Майский переулок	0103000020E61000000100000005000000DF1797AAB4EB4340FAB31F29229B4D40DF1797AAB4EB43408FA50F5D509B4D4093E1783E03EC43408FA50F5D509B4D4093E1783E03EC4340FAB31F29229B4D40DF1797AAB4EB4340FAB31F29229B4D40
32101	17	39.819693000000001	39.878174000000001	59.225842999999998	59.198445	Ленинградская	0103000020E610000001000000050000004CE141B3EBE84340018750A566994D404CE141B3EBE84340E883656CE89C4D404819710168F04340E883656CE89C4D404819710168F04340018750A566994D404CE141B3EBE84340018750A566994D40
32091	17	39.892699999999998	39.900281	59.221620000000001	59.220381000000003	Ленина	0103000020E61000000100000005000000D1915CFE43F2434074D4D171359C4D40D1915CFE43F24340DC114E0B5E9C4D40E71A66683CF34340DC114E0B5E9C4D40E71A66683CF3434074D4D171359C4D40D1915CFE43F2434074D4D171359C4D40
32113	17	39.835251999999997	39.847037999999998	59.204318999999998	59.198048	Костромская	0103000020E6100000010000000500000094F59B89E9EA4340E48409A359994D4094F59B89E9EA4340C879FF1F279A4D40103CBEBD6BEC4340C879FF1F279A4D40103CBEBD6BEC4340E48409A359994D4094F59B89E9EA4340E48409A359994D40
32095	17	39.909686999999998	39.931471000000002	59.197228000000003	59.191674999999996	Космонавта Беляева	0103000020E61000000100000005000000554CA59F70F44340FB3A70CE88984D40554CA59F70F4434081ED60C43E994D40121615713AF7434081ED60C43E994D40121615713AF74340FB3A70CE88984D40554CA59F70F44340FB3A70CE88984D40
32090	17	39.886015999999998	39.925578000000002	59.219529000000001	59.196992999999999	Козленская	0103000020E61000000100000005000000CADDE7F868F143403D450E1137994D40CADDE7F868F1434005C3B986199C4D40D4F2035779F6434005C3B986199C4D40D4F2035779F643403D450E1137994D40CADDE7F868F143403D450E1137994D40
32134	17	39.862247000000004	39.879404000000001	59.222942000000003	59.216706000000002	Кирова	0103000020E610000001000000050000007D09151C5EEE43406A6CAF05BD9B4D407D09151C5EEE4340D2730B5D899C4D405DFC6D4F90F04340D2730B5D899C4D405DFC6D4F90F043406A6CAF05BD9B4D407D09151C5EEE43406A6CAF05BD9B4D40
32114	17	39.948259999999998	39.955195000000003	59.216116999999997	59.214785999999997	Канифольная	0103000020E610000001000000050000006F0D6C9560F94340BFD18E1B7E9B4D406F0D6C9560F94340088ECBB8A99B4D40C0266BD443FA4340088ECBB8A99B4D40C0266BD443FA4340BFD18E1B7E9B4D406F0D6C9560F94340BFD18E1B7E9B4D40
32126	17	39.789824000000003	39.821212000000003	59.210419000000002	59.209290000000003	Ильюшина	0103000020E6100000010000000500000047CCECF318E543409FB0C403CA9A4D4047CCECF318E5434080BA8102EF9A4D40988A8D791DE9434080BA8102EF9A4D40988A8D791DE943409FB0C403CA9A4D4047CCECF318E543409FB0C403CA9A4D40
32012	17	39.732394999999997	40.028049000000003	59.28396	59.167062999999999	Емельянова	0103000020E6100000010000000500000080608E1EBFDD434092AF045262954D4080608E1EBFDD4340A3AF20CD58A44D40BFD7101C97034440A3AF20CD58A44D40BFD7101C9703444092AF045262954D4080608E1EBFDD434092AF045262954D40
32131	17	39.930824000000001	39.943337999999997	59.231478000000003	59.219138000000001	Дальняя	0103000020E610000001000000050000007C2AA73D25F74340CAA7C7B60C9C4D407C2AA73D25F743402BDF3312A19D4D407A89B14CBFF843402BDF3312A19D4D407A89B14CBFF84340CAA7C7B60C9C4D407C2AA73D25F74340CAA7C7B60C9C4D40
32084	17	39.886105999999998	39.920358999999998	59.231036000000003	59.21181	Горького	0103000020E610000001000000050000000A65E1EB6BF143409E7B0F971C9B4D400A65E1EB6BF143406E197096929D4D4025CADE52CEF543406E197096929D4D4025CADE52CEF543409E7B0F971C9B4D400A65E1EB6BF143409E7B0F971C9B4D40
32123	17	39.920574000000002	39.921275000000001	59.216051999999998	59.21199	Городской Вал	0103000020E6100000010000000500000022C66B5ED5F543401E8A027D229B4D4022C66B5ED5F54340211E8997A79B4D40ABCFD556ECF54340211E8997A79B4D40ABCFD556ECF543401E8A027D229B4D4022C66B5ED5F543401E8A027D229B4D40
32103	17	39.883060999999998	39.912309999999998	59.218147999999999	59.198960999999997	Герцена	0103000020E61000000100000005000000C0AF912408F14340F816D68D77994D40C0AF912408F143400AD80E46EC9B4D4029E8F692C6F443400AD80E46EC9B4D4029E8F692C6F44340F816D68D77994D40C0AF912408F14340F816D68D77994D40
32122	17	39.800164000000002	39.857089999999999	59.22063	59.193587000000001	Гагарина	0103000020E61000000100000005000000E1B721C66BE6434023F77475C7984D40E1B721C66BE643401C42959A3D9C4D4044DD0720B5ED43401C42959A3D9C4D4044DD0720B5ED434023F77475C7984D40E1B721C66BE6434023F77475C7984D40
32088	17	39.829368000000002	39.834676999999999	59.248134	59.247140000000002	Вологодская	0103000020E61000000100000005000000AA2C0ABB28EA434048C49448A29F4D40AA2C0ABB28EA43404983DBDAC29F4D4098DC28B2D6EA43404983DBDAC29F4D4098DC28B2D6EA434048C49448A29F4D40AA2C0ABB28EA434048C49448A29F4D40
32124	17	39.830652999999998	39.856721999999998	59.209746000000003	59.193863999999998	Возрождения	0103000020E6100000010000000500000082A966D652EA434095EF1989D0984D4082A966D652EA4340C13BF9F4D89A4D40C1E10511A9ED4340C13BF9F4D89A4D40C1E10511A9ED434095EF1989D0984D4082A966D652EA434095EF1989D0984D40
32121	17	39.884678000000001	39.899436999999999	59.201965000000001	59.198554999999999	Болонина	0103000020E61000000100000005000000CFBEF2203DF1434088BA0F406A994D40CFBEF2203DF14340E4F736FDD9994D40FBE769C020F34340E4F736FDD9994D40FBE769C020F3434088BA0F406A994D40CFBEF2203DF1434088BA0F406A994D40
32055	17	39.883060999999998	39.883986	59.221896000000001	59.218147999999999	Батюшкова	0103000020E61000000100000005000000C0AF912408F143400AD80E46EC9B4D40C0AF912408F143407E8E8F16679C4D40990F087426F143407E8E8F16679C4D40990F087426F143400AD80E46EC9B4D40C0AF912408F143400AD80E46EC9B4D40
32125	17	39.860899000000003	39.906992000000002	59.221054000000002	59.183095999999999	Архангельская	0103000020E610000001000000050000005E143DF031EE4340A30392B06F974D405E143DF031EE434033535A7F4B9C4D40E8DD585018F4434033535A7F4B9C4D40E8DD585018F44340A30392B06F974D405E143DF031EE4340A30392B06F974D40
32054	17	39.748206000000003	39.790067000000001	59.237848999999997	59.227913999999998	Ананьинская	0103000020E61000000100000005000000E355D636C5DF4340782634492C9D4D40E355D636C5DF4340723106D6719E4D400D535BEA20E54340723106D6719E4D400D535BEA20E54340782634492C9D4D40E355D636C5DF4340782634492C9D4D40
32102	17	39.790067000000001	39.860387000000003	59.239201999999999	59.227297	Александра Клубова	0103000020E610000001000000050000000D535BEA20E543404DBD6E11189D4D400D535BEA20E54340A391CF2B9E9E4D40A873452921EE4340A391CF2B9E9E4D40A873452921EE43404DBD6E11189D4D400D535BEA20E543404DBD6E11189D4D40
31677	17	39.893292000000002	39.901502999999998	59.245037000000004	59.240831	6 Армии набережная	0103000020E61000000100000005000000A4E36A6457F24340766EDA8CD39E4D40A4E36A6457F24340ADA7565F5D9F4D40791F477364F34340ADA7565F5D9F4D40791F477364F34340766EDA8CD39E4D40A4E36A6457F24340766EDA8CD39E4D40
32106	17	39.886105999999998	39.920358999999998	59.231036000000003	59.21181	 Горького	0103000020E610000001000000050000000A65E1EB6BF143409E7B0F971C9B4D400A65E1EB6BF143406E197096929D4D4025CADE52CEF543406E197096929D4D4025CADE52CEF543409E7B0F971C9B4D400A65E1EB6BF143409E7B0F971C9B4D40
31695	53250	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	Мира	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
31825	32194	38.532273000000004	38.545523000000003	59.061951999999998	59.054053000000003	Школьная	0103000020E610000001000000050000009CC58B852144434017A06D35EB864D409CC58B8521444340FDF50A0BEE874D40A01B9AB2D3454340FDF50A0BEE874D40A01B9AB2D345434017A06D35EB864D409CC58B852144434017A06D35EB864D40
31941	53276	38.503337999999999	38.523676000000002	59.240242000000002	59.231445999999998	Юбилейная	0103000020E61000000100000005000000C26A2C616D4043401F65C405A09D4D40C26A2C616D4043401590F63FC09E4D409DD9AED0074343401590F63FC09E4D409DD9AED0074343401F65C405A09D4D40C26A2C616D4043401F65C405A09D4D40
31885	30890	38.488290999999997	38.551102	59.233826000000001	59.200564	Шлюзовая	0103000020E610000001000000050000002FF7C951803E4340A260C614AC994D402FF7C951803E43402D7AA702EE9D4D404E61A5828A4643402D7AA702EE9D4D404E61A5828A464340A260C614AC994D402FF7C951803E4340A260C614AC994D40
26607	30890	38.488290999999997	38.551102	59.233826000000001	59.200564	Труда	0103000020E610000001000000050000002FF7C951803E4340A260C614AC994D402FF7C951803E43402D7AA702EE9D4D404E61A5828A4643402D7AA702EE9D4D404E61A5828A464340A260C614AC994D402FF7C951803E4340A260C614AC994D40
31676	30890	38.488290999999997	38.551102	59.233826000000001	59.200564	Октябрьская	0103000020E610000001000000050000002FF7C951803E4340A260C614AC994D402FF7C951803E43402D7AA702EE9D4D404E61A5828A4643402D7AA702EE9D4D404E61A5828A464340A260C614AC994D402FF7C951803E4340A260C614AC994D40
31933	30890	38.488290999999997	38.551102	59.233826000000001	59.200564	Зеленая	0103000020E610000001000000050000002FF7C951803E4340A260C614AC994D402FF7C951803E43402D7AA702EE9D4D404E61A5828A4643402D7AA702EE9D4D404E61A5828A464340A260C614AC994D402FF7C951803E4340A260C614AC994D40
31950	30890	38.488290999999997	38.551102	59.233826000000001	59.200564	Дзержинского	0103000020E610000001000000050000002FF7C951803E4340A260C614AC994D402FF7C951803E43402D7AA702EE9D4D404E61A5828A4643402D7AA702EE9D4D404E61A5828A464340A260C614AC994D402FF7C951803E4340A260C614AC994D40
31934	30890	38.488290999999997	38.551102	59.233826000000001	59.200564	Гагарина	0103000020E610000001000000050000002FF7C951803E4340A260C614AC994D402FF7C951803E43402D7AA702EE9D4D404E61A5828A4643402D7AA702EE9D4D404E61A5828A464340A260C614AC994D402FF7C951803E4340A260C614AC994D40
31938	31236	38.753006999999997	38.760328000000001	59.147584000000002	59.144523999999997	Ленина	0103000020E610000001000000050000005C548B886260434059BE2EC37F924D405C548B8862604340D9B45208E4924D40D61D8B6D52614340D9B45208E4924D40D61D8B6D5261434059BE2EC37F924D405C548B886260434059BE2EC37F924D40
26445	31822	38.601021000000003	38.631464999999999	59.345644	59.333708000000001	Шоссейная	0103000020E61000000100000005000000C89A9141EE4C4340F03499F1B6AA4D40C89A9141EE4C4340810706103EAC4D40C9C859D8D3504340810706103EAC4D40C9C859D8D3504340F03499F1B6AA4D40C89A9141EE4C4340F03499F1B6AA4D40
31939	31647	38.701847999999998	38.720488000000003	59.419502000000001	59.409436999999997	Ветеранов	0103000020E61000000100000005000000AA61BF27D6594340DC627E6E68B44D40AA61BF27D6594340A54DD53DB2B54D408A9466F3385C4340A54DD53DB2B54D408A9466F3385C4340DC627E6E68B44D40AA61BF27D6594340DC627E6E68B44D40
31997	31305	38.500534999999999	38.514890999999999	59.195895999999998	59.191789999999997	Центральная	0103000020E610000001000000050000006EC0E7871140434094D920938C984D406EC0E7871140434067B5C01E13994D409B00C3F2E741434067B5C01E13994D409B00C3F2E741434094D920938C984D406EC0E7871140434094D920938C984D40
31869	31393	38.303390999999998	38.324016	59.182533999999997	59.176231000000001	Центральная	0103000020E610000001000000050000004B732B84D52643404CC5C6BC8E964D404B732B84D52643403B342C465D974D40BCB0355B792943403B342C465D974D40BCB0355B792943404CC5C6BC8E964D404B732B84D52643404CC5C6BC8E964D40
31903	31318	38.439521999999997	38.477161000000002	59.217055999999999	59.204172	Нифантовская	0103000020E61000000100000005000000AEEFC341423843402461DF4E229A4D40AEEFC3414238434046B3B27DC89B4D409DF6949C133D434046B3B27DC89B4D409DF6949C133D43402461DF4E229A4D40AEEFC341423843402461DF4E229A4D40
26413	30397	39.001660999999999	39.016303000000001	59.124755	59.119061000000002	Нестерово	0103000020E61000000100000005000000DE567A6D36804340529D0E643D8F4D40DE567A6D368043409981CAF8F78F4D40D1E97937168243409981CAF8F78F4D40D1E9793716824340529D0E643D8F4D40DE567A6D36804340529D0E643D8F4D40
26619	32115	38.754741000000003	38.768394999999998	59.108606999999999	59.098390000000002	Школьная	0103000020E61000000100000005000000A5F9635A9B6043407120240B988C4D40A5F9635A9B604340EF8E8CD5E68D4D4078B471C45A624340EF8E8CD5E68D4D4078B471C45A6243407120240B988C4D40A5F9635A9B6043407120240B988C4D40
32026	31713	38.619759999999999	38.636719999999997	59.386916999999997	59.379167000000002	Зеленая	0103000020E610000001000000050000003AAFB14B544F4340795C548B88B04D403AAFB14B544F43401AA20A7F86B14D40C45A7C0A805143401AA20A7F86B14D40C45A7C0A80514340795C548B88B04D403AAFB14B544F4340795C548B88B04D40
31757	32167	38.799709999999997	38.811594999999997	59.138851000000003	59.133653000000002	Центральная	0103000020E610000001000000050000005F24B4E55C6643409301A08A1B914D405F24B4E55C6643402A029CDEC5914D406E4C4F58E26743402A029CDEC5914D406E4C4F58E26743409301A08A1B914D405F24B4E55C6643409301A08A1B914D40
32004	32277	38.691319999999997	38.700823999999997	59.134193000000003	59.128999	Сосновая	0103000020E610000001000000050000000D897B2C7D584340BD1B0B0A83904D400D897B2C7D584340132D793C2D914D403E20D099B4594340132D793C2D914D403E20D099B4594340BD1B0B0A83904D400D897B2C7D584340BD1B0B0A83904D40
31961	26354	37.535052999999998	37.559837999999999	58.747587000000003	58.731788000000002	Журавлевская	0103000020E610000001000000050000003750E09D7CC4424079CDAB3AAB5D4D403750E09D7CC4424017F549EEB05F4D406E8786C5A8C7424017F549EEB05F4D406E8786C5A8C7424079CDAB3AAB5D4D403750E09D7CC4424079CDAB3AAB5D4D40
26509	26281	38.121032999999997	38.147748999999997	59.338724999999997	59.329025999999999	Центральная	0103000020E610000001000000050000004E5E64027E0F434050C422861DAA4D404E5E64027E0F434036AB3E575BAB4D4023827170E912434036AB3E575BAB4D4023827170E912434050C422861DAA4D404E5E64027E0F434050C422861DAA4D40
26507	26210	38.304406	38.326667	58.823948000000001	58.811236999999998	Рыбинская	0103000020E61000000100000005000000645A9BC6F62643400F27309DD6674D40645A9BC6F626434064CDC82077694D405AD76839D029434064CDC82077694D405AD76839D02943400F27309DD6674D40645A9BC6F62643400F27309DD6674D40
31878	24591	37.702579999999998	37.724643	59.236643000000001	59.223531000000001	Центральная	0103000020E610000001000000050000006E693524EED942403352EFA99C9C4D406E693524EED94240E6E95C514A9E4D403E23111AC1DC4240E6E95C514A9E4D403E23111AC1DC42403352EFA99C9C4D406E693524EED942403352EFA99C9C4D40
31956	25389	37.534064999999998	37.557727	59.210943999999998	59.198937999999998	Центральная	0103000020E610000001000000050000001878EE3D5CC4424040F7E5CC76994D401878EE3D5CC44240CAA48636009B4D40508C2C9963C74240CAA48636009B4D40508C2C9963C7424040F7E5CC76994D401878EE3D5CC4424040F7E5CC76994D40
32021	26173	38.60801	38.625059999999998	58.9664	58.961008999999997	Молодежная	0103000020E610000001000000050000000BD28C45D34D4340B114C957027B4D400BD28C45D34D43405D6DC5FEB27B4D40D50451F7015043405D6DC5FEB27B4D40D50451F701504340B114C957027B4D400BD28C45D34D4340B114C957027B4D40
31718	25047	37.203665000000001	37.238331000000002	58.932952	58.923231000000001	Центральная	0103000020E61000000100000005000000802BD9B1119A4240A2D3F36E2C764D40802BD9B1119A4240705E9CF86A774D40BE4F55A1819E4240705E9CF86A774D40BE4F55A1819E4240A2D3F36E2C764D40802BD9B1119A4240A2D3F36E2C764D40
31726	26045	37.943489999999997	37.957144999999997	59.202849999999998	59.188301000000003	Труда	0103000020E61000000100000005000000300DC347C4F84240ED66463F1A984D40300DC347C4F842402EFF21FDF6994D40D44334BA83FA42402EFF21FDF6994D40D44334BA83FA4240ED66463F1A984D40300DC347C4F84240ED66463F1A984D40
26446	26045	37.943489999999997	37.957144999999997	59.202849999999998	59.188301000000003	Рабочая	0103000020E61000000100000005000000300DC347C4F84240ED66463F1A984D40300DC347C4F842402EFF21FDF6994D40D44334BA83FA42402EFF21FDF6994D40D44334BA83FA4240ED66463F1A984D40300DC347C4F84240ED66463F1A984D40
26662	25918	38.322552000000002	38.339216	58.996524999999998	58.989153999999999	Центральная	0103000020E6100000010000000500000034A1496249294340925A28999C7E4D4034A1496249294340BD5296218E7F4D40D5230D6E6B2B4340BD5296218E7F4D40D5230D6E6B2B4340925A28999C7E4D4034A1496249294340925A28999C7E4D40
26660	25635	37.535781	37.614716000000001	59.171337999999999	59.131926	Пушкина	0103000020E61000000100000005000000BA68C87894C44240FDBE7FF3E2904D40BA68C87894C44240F1475167EE954D40FA298E03AFCE4240F1475167EE954D40FA298E03AFCE4240FDBE7FF3E2904D40BA68C87894C44240FDBE7FF3E2904D40
31774	25635	37.535781	37.614716000000001	59.171337999999999	59.131926	Заводская	0103000020E61000000100000005000000BA68C87894C44240FDBE7FF3E2904D40BA68C87894C44240F1475167EE954D40FA298E03AFCE4240F1475167EE954D40FA298E03AFCE4240FDBE7FF3E2904D40BA68C87894C44240FDBE7FF3E2904D40
26493	25635	37.535781	37.614716000000001	59.171337999999999	59.131926	Гагарина	0103000020E61000000100000005000000BA68C87894C44240FDBE7FF3E2904D40BA68C87894C44240F1475167EE954D40FA298E03AFCE4240F1475167EE954D40FA298E03AFCE4240FDBE7FF3E2904D40BA68C87894C44240FDBE7FF3E2904D40
26646	24694	37.949185	37.973314000000002	59.389212999999998	59.371406	Центральная	0103000020E61000000100000005000000486DE2E47EF94240E3C4573B8AAF4D40486DE2E47EF94240CA1649BBD1B14D40965E9B8D95FC4240CA1649BBD1B14D40965E9B8D95FC4240E3C4573B8AAF4D40486DE2E47EF94240E3C4573B8AAF4D40
31698	24156	38.039942000000003	38.068517999999997	59.028396999999998	59.014589000000001	Новая	0103000020E6100000010000000500000051DEC7D11C054340D0F0660DDE814D4051DEC7D11C054340FA264D83A2834D40FA97A432C5084340FA264D83A2834D40FA97A432C5084340D0F0660DDE814D4051DEC7D11C054340D0F0660DDE814D40
31920	21167	37.499471	37.526285999999999	59.505204999999997	59.492462000000003	Центральная	0103000020E6100000010000000500000074266DAAEEBF4240EA42ACFE08BF4D4074266DAAEEBF42404963B48EAAC04D40DC2BF3565DC342404963B48EAAC04D40DC2BF3565DC34240EA42ACFE08BF4D4074266DAAEEBF4240EA42ACFE08BF4D40
31952	25020	37.385429999999999	37.401941000000001	59.031920999999997	59.020069999999997	Березовая	0103000020E61000000100000005000000DA722EC555B14240BBD05CA791824D40DA722EC555B142401E87C1FC15844D40F5F57CCD72B342401E87C1FC15844D40F5F57CCD72B34240BBD05CA791824D40DA722EC555B14240BBD05CA791824D40
31721	25409	37.616278999999999	37.647413999999998	59.19473	59.186290999999997	Центральная	0103000020E61000000100000005000000151BF33AE2CE424002452C62D8974D40151BF33AE2CE424069C6A2E9EC984D407C7C4276DED2424069C6A2E9EC984D407C7C4276DED2424002452C62D8974D40151BF33AE2CE424002452C62D8974D40
26484	25259	38.180627000000001	38.213631999999997	58.895180000000003	58.883178999999998	Советская	0103000020E6100000010000000500000026E318C91E174340CAC16C020C714D4026E318C91E17434043041C4295724D4085B01A4B581B434043041C4295724D4085B01A4B581B4340CAC16C020C714D4026E318C91E174340CAC16C020C714D40
31841	26233	38.394157	38.404522999999998	58.768362000000003	58.762673999999997	Школьная	0103000020E61000000100000005000000A73E90BC7332434037C1374D9F614D40A73E90BC733243409DBE9EAF59624D406ABDDF68C73343409DBE9EAF59624D406ABDDF68C733434037C1374D9F614D40A73E90BC7332434037C1374D9F614D40
31813	24974	37.452210000000001	37.478639000000001	58.960155	58.947048000000002	Ленина	0103000020E610000001000000050000004B766C04E2B9424001DF6DDE38794D404B766C04E2B94240A20BEA5BE67A4D408ACBF10A44BD4240A20BEA5BE67A4D408ACBF10A44BD424001DF6DDE38794D404B766C04E2B9424001DF6DDE38794D40
31930	24830	38.079953000000003	38.135460000000002	59.119790000000002	59.109678000000002	Новая	0103000020E61000000100000005000000CA1B60E63B0A43409C8BBFED098E4D40CA1B60E63B0A4340A5315A47558F4D4045F5D6C056114340A5315A47558F4D4045F5D6C0561143409C8BBFED098E4D40CA1B60E63B0A43409C8BBFED098E4D40
31717	24811	37.948853	37.963298000000002	59.501269000000001	59.491909	Весенняя	0103000020E6100000010000000500000012DBDD0374F94240D5CDC5DFF6BE4D4012DBDD0374F94240D3BF249529C04D40AF264F594DFB4240D3BF249529C04D40AF264F594DFB4240D5CDC5DFF6BE4D4012DBDD0374F94240D5CDC5DFF6BE4D40
31784	23135	37.849696999999999	37.868364	59.063778999999997	59.056955000000002	Лесная	0103000020E6100000010000000500000031410DDFC2EC4240FE2B2B4D4A874D4031410DDFC2EC4240F69507E929884D400A83328D26EF4240F69507E929884D400A83328D26EF4240FE2B2B4D4A874D4031410DDFC2EC4240FE2B2B4D4A874D40
31780	25971	37.992007999999998	38.003703999999999	59.404325999999998	59.393459999999997	Старая Горка	0103000020E6100000010000000500000068AF3E1EFAFE42405F24B4E55CB24D4068AF3E1EFAFE4240147651F4C0B34D40A46E675F79004340147651F4C0B34D40A46E675F790043405F24B4E55CB24D4068AF3E1EFAFE42405F24B4E55CB24D40
31765	3019	37.890282999999997	37.944468999999998	59.440271000000003	59.423402000000003	Советская	0103000020E61000000100000005000000A69718CBF4F14240CF87670932B64D40A69718CBF4F142404930D5CC5AB84D40FC8A355CE4F842404930D5CC5AB84D40FC8A355CE4F84240CF87670932B64D40A69718CBF4F14240CF87670932B64D40
31847	26492	37.953398999999997	37.978389999999997	59.265034999999997	59.251088000000003	Ленина	0103000020E6100000010000000500000001857AFA08FA42408335CEA623A04D4001857AFA08FA4240CEA5B8AAECA14D40E15D2EE23BFD4240CEA5B8AAECA14D40E15D2EE23BFD42408335CEA623A04D4001857AFA08FA42408335CEA623A04D40
26670	26455	37.714123000000001	37.735117000000002	58.716169000000001	58.707315999999999	Центральная	0103000020E610000001000000050000002429E96168DB424001F8A754895A4D402429E96168DB42405BB4006DAB5B4D40E8DD585018DE42405BB4006DAB5B4D40E8DD585018DE424001F8A754895A4D402429E96168DB424001F8A754895A4D40
32017	25834	37.566135000000003	37.578909000000003	59.128177000000001	59.123328000000001	Большеновская	0103000020E610000001000000050000007C0F971C77C842402E573F36C98F4D407C0F971C77C84240B98C9B1A68904D40172EABB019CA4240B98C9B1A68904D40172EABB019CA42402E573F36C98F4D407C0F971C77C842402E573F36C98F4D40
32016	25478	37.382886999999997	37.413339999999998	59.204613999999999	59.188107000000002	Бумажников	0103000020E610000001000000050000002288F37002B142400893E2E313984D402288F37002B14240E126A3CA309A4D4077103B53E8B44240E126A3CA309A4D4077103B53E8B442400893E2E313984D402288F37002B142400893E2E313984D40
9742	24559	37.648887999999999	37.670411000000001	59.292554000000003	59.282319000000001	Школьная	0103000020E61000000100000005000000286211C30ED342400C056C0723A44D40286211C30ED342403128D36872A54D4078F01307D0D542403128D36872A54D4078F01307D0D542400C056C0723A44D40286211C30ED342400C056C0723A44D40
26483	23641	35.286211000000002	35.296028999999997	59.139654	59.134788999999998	Школьная	0103000020E61000000100000005000000B360E28FA2A44140266E15C440914D40B360E28FA2A44140B760A92EE0914D4073D53C47E4A54140B760A92EE0914D4073D53C47E4A54140266E15C440914D40B360E28FA2A44140266E15C440914D40
31898	23641	35.286211000000002	35.296028999999997	59.139654	59.134788999999998	Воззвания	0103000020E61000000100000005000000B360E28FA2A44140266E15C440914D40B360E28FA2A44140B760A92EE0914D4073D53C47E4A54140B760A92EE0914D4073D53C47E4A54140266E15C440914D40B360E28FA2A44140266E15C440914D40
31852	23926	35.281063000000003	35.371172999999999	59.180030000000002	59.149194000000001	Центральная	0103000020E61000000100000005000000CE8E54DFF9A341403561FBC918934D40CE8E54DFF9A34140422619390B974D404014CC9882AF4140422619390B974D404014CC9882AF41403561FBC918934D40CE8E54DFF9A341403561FBC918934D40
26460	23926	35.281063000000003	35.371172999999999	59.180030000000002	59.149194000000001	Кирова	0103000020E61000000100000005000000CE8E54DFF9A341403561FBC918934D40CE8E54DFF9A34140422619390B974D404014CC9882AF4140422619390B974D404014CC9882AF41403561FBC918934D40CE8E54DFF9A341403561FBC918934D40
31801	23926	35.281063000000003	35.371172999999999	59.180030000000002	59.149194000000001	Высоцкого	0103000020E61000000100000005000000CE8E54DFF9A341403561FBC918934D40CE8E54DFF9A34140422619390B974D404014CC9882AF4140422619390B974D404014CC9882AF41403561FBC918934D40CE8E54DFF9A341403561FBC918934D40
31948	24500	35.047258999999997	35.076005000000002	59.183765000000001	59.170369999999998	Центральная	0103000020E6100000010000000500000088B839950C864140191C25AFCE954D4088B839950C86414021938C9C85974D408FAA2688BA89414021938C9C85974D408FAA2688BA894140191C25AFCE954D4088B839950C864140191C25AFCE954D40
31697	24000	35.209260999999998	35.250044000000003	59.112478000000003	59.070205000000001	Строителей	0103000020E6100000010000000500000004AA7F10C99A41400282397AFC884D4004AA7F10C99A41407FC2D9AD658E4D40D047197101A041407FC2D9AD658E4D40D047197101A041400282397AFC884D4004AA7F10C99A41400282397AFC884D40
26603	24000	35.209260999999998	35.250044000000003	59.112478000000003	59.070205000000001	Советская	0103000020E6100000010000000500000004AA7F10C99A41400282397AFC884D4004AA7F10C99A41407FC2D9AD658E4D40D047197101A041407FC2D9AD658E4D40D047197101A041400282397AFC884D4004AA7F10C99A41400282397AFC884D40
31709	32351	35.554501000000002	35.589778000000003	58.961323999999998	58.947926000000002	Центральная	0103000020E61000000100000005000000B64C86E3F9C641409983A0A355794D40B64C86E3F9C64140116E32AA0C7B4D403DF372D87DCB4140116E32AA0C7B4D403DF372D87DCB41409983A0A355794D40B64C86E3F9C641409983A0A355794D40
31986	24432	35.114632	35.124622000000002	59.175811000000003	59.171739000000002	Центральная	0103000020E610000001000000050000009C89E942AC8E41405039268BFB954D409C89E942AC8E414077A38FF980964D405A2E1B9DF38F414077A38FF980964D405A2E1B9DF38F41405039268BFB954D409C89E942AC8E41405039268BFB954D40
32038	24402	35.578693000000001	35.593389999999999	59.149318999999998	59.144976	Северная	0103000020E610000001000000050000004AB6BA9C12CA41403A5AD5928E924D404AB6BA9C12CA4140F1D58EE21C934D4000E31934F4CB4140F1D58EE21C934D4000E31934F4CB41403A5AD5928E924D404AB6BA9C12CA41403A5AD5928E924D40
31763	24312	35.270634000000001	35.300566000000003	58.992302000000002	58.982857000000003	Набережная	0103000020E61000000100000005000000C4978922A4A2414085D21742CE7D4D40C4978922A4A24140B1E07EC0037F4D4010255AF278A64140B1E07EC0037F4D4010255AF278A6414085D21742CE7D4D40C4978922A4A2414085D21742CE7D4D40
31908	24244	35.366754	35.392426999999998	59.110990999999999	59.100524999999998	Спортивная	0103000020E61000000100000005000000AED689CBF1AE414017B7D100DE8C4D40AED689CBF1AE41403E93FDF3348E4D40A088450C3BB241403E93FDF3348E4D40A088450C3BB2414017B7D100DE8C4D40AED689CBF1AE414017B7D100DE8C4D40
31767	24184	35.212477	35.225529000000002	59.077840000000002	59.071629000000001	Кооперативная	0103000020E610000001000000050000007B134372329B4140FC389A232B894D407B134372329B41400B293FA9F6894D4059A65F22DE9C41400B293FA9F6894D4059A65F22DE9C4140FC389A232B894D407B134372329B4140FC389A232B894D40
26498	24328	35.312235000000001	35.334359999999997	58.891455999999998	58.881923	Мира	0103000020E6100000010000000500000052D50451F7A741408C4B55DAE2704D4052D50451F7A7414057E9EE3A1B724D40978BF84ECCAA414057E9EE3A1B724D40978BF84ECCAA41408C4B55DAE2704D4052D50451F7A741408C4B55DAE2704D40
31828	23587	39.852122999999999	39.878183	60.165782	60.148780000000002	Центральная	0103000020E61000000100000005000000AF95D05D12ED4340422619390B134E40AF95D05D12ED4340FB21365838154E409B73F04C68F04340FB21365838154E409B73F04C68F04340422619390B134E40AF95D05D12ED4340422619390B134E40
32066	51299	40.169829999999997	40.236897999999997	59.979177999999997	59.932743000000002	Энергетиков	0103000020E6100000010000000500000099F04BFDBC1544405649641F64F74D4099F04BFDBC154440397B67B455FD4D40703E75AC521E4440397B67B455FD4D40703E75AC521E44405649641F64F74D4099F04BFDBC1544405649641F64F74D40
32064	51299	40.169829999999997	40.236897999999997	59.979177999999997	59.932743000000002	Школьная	0103000020E6100000010000000500000099F04BFDBC1544405649641F64F74D4099F04BFDBC154440397B67B455FD4D40703E75AC521E4440397B67B455FD4D40703E75AC521E44405649641F64F74D4099F04BFDBC1544405649641F64F74D40
32052	51299	40.169829999999997	40.236897999999997	59.979177999999997	59.932743000000002	Свободы	0103000020E6100000010000000500000099F04BFDBC1544405649641F64F74D4099F04BFDBC154440397B67B455FD4D40703E75AC521E4440397B67B455FD4D40703E75AC521E44405649641F64F74D4099F04BFDBC1544405649641F64F74D40
26586	51299	40.169829999999997	40.236897999999997	59.979177999999997	59.932743000000002	Клубная	0103000020E6100000010000000500000099F04BFDBC1544405649641F64F74D4099F04BFDBC154440397B67B455FD4D40703E75AC521E4440397B67B455FD4D40703E75AC521E44405649641F64F74D4099F04BFDBC1544405649641F64F74D40
26451	23496	40.150049000000003	40.165626000000003	59.997810999999999	59.990462000000001	Мира	0103000020E6100000010000000500000015E63DCE3413444023F77475C7FE4D4015E63DCE34134440664B5645B8FF4D4004AF963B33154440664B5645B8FF4D4004AF963B3315444023F77475C7FE4D4015E63DCE3413444023F77475C7FE4D40
31943	23268	40.157065000000003	40.191218999999997	59.821947000000002	59.801639000000002	Спортивная	0103000020E61000000100000005000000522CB7B41A1444405D19541B9CE64D40522CB7B41A144440CD052E8F35E94D40D9AF3BDD79184440CD052E8F35E94D40D9AF3BDD791844405D19541B9CE64D40522CB7B41A1444405D19541B9CE64D40
31752	23268	40.157065000000003	40.191218999999997	59.821947000000002	59.801639000000002	Комсомольская	0103000020E61000000100000005000000522CB7B41A1444405D19541B9CE64D40522CB7B41A144440CD052E8F35E94D40D9AF3BDD79184440CD052E8F35E94D40D9AF3BDD791844405D19541B9CE64D40522CB7B41A1444405D19541B9CE64D40
32111	53296	39.384692999999999	41.008290000000002	60.403396000000001	59.721995999999997	Центральная	0103000020E610000001000000050000000400C79E3DB14340E1EB6B5D6ADC4D400400C79E3DB143402AABE97AA2334E4022718FA50F8144402AABE97AA2334E4022718FA50F814440E1EB6B5D6ADC4D400400C79E3DB14340E1EB6B5D6ADC4D40
32100	53295	39.942160999999999	39.959355000000002	59.978296	59.967975000000003	Торговая	0103000020E6100000010000000500000088484DBB98F843403D2CD49AE6FB4D4088484DBB98F8434060E7A6CD38FD4D4086200725CCFA434060E7A6CD38FD4D4086200725CCFA43403D2CD49AE6FB4D4088484DBB98F843403D2CD49AE6FB4D40
31705	3010	40.467001000000003	40.490268	59.972203999999998	59.961781999999999	Советская	0103000020E61000000100000005000000831953B0C63B4440D4F02DAC1BFB4D40831953B0C63B44402B85402E71FC4D403E23111AC13E44402B85402E71FC4D403E23111AC13E4440D4F02DAC1BFB4D40831953B0C63B4440D4F02DAC1BFB4D40
32003	23429	40.246923000000002	40.257945999999997	59.960661000000002	59.953046999999998	Лесная	0103000020E61000000100000005000000ABD0402C9B1F44408446B071FDF94D40ABD0402C9B1F444076C58CF0F6FA4D402711E15F0421444076C58CF0F6FA4D402711E15F042144408446B071FDF94D40ABD0402C9B1F44408446B071FDF94D40
31924	22551	36.142054000000002	36.167090000000002	58.821762999999997	58.815491000000002	Центральная	0103000020E610000001000000050000000C2252D32E1242405797530262684D400C2252D32E1242400B08AD872F694D408CBE8234631542400B08AD872F694D408CBE8234631542405797530262684D400C2252D32E1242405797530262684D40
31862	2932	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Терешковой	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
31754	2932	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Пролетарская	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
26663	2932	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Набережная Декабристов	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
26728	2932	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Ленина	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
31670	2932	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Карла Маркса	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
26404	2932	36.391874999999999	36.487617	58.854695999999997	58.828476000000002	Интернациональная	0103000020E610000001000000050000005C8FC2F528324240ADC266800B6A4D405C8FC2F528324240D102B4AD666D4D40A0FCDD3B6A3E4240D102B4AD666D4D40A0FCDD3B6A3E4240ADC266800B6A4D405C8FC2F528324240ADC266800B6A4D40
31981	21512	36.277707999999997	36.290607999999999	58.781849000000001	58.770536	Центральная	0103000020E6100000010000000500000035EB8CEF8B234240013274ECA0624D4035EB8CEF8B23424085B4C6A013644D405DFA97A43225424085B4C6A013644D405DFA97A432254240013274ECA0624D4035EB8CEF8B234240013274ECA0624D40
31925	22002	36.335515000000001	36.352106999999997	58.690452000000001	58.681663	Центральная	0103000020E61000000100000005000000A228D027F22A424056F2B1BB40574D40A228D027F22A424099BA2BBB60584D40A9D898D7112D424099BA2BBB60584D40A9D898D7112D424056F2B1BB40574D40A228D027F22A424056F2B1BB40574D40
31935	22238	36.535336000000001	36.564486000000002	58.832104000000001	58.824134000000001	Центральная	0103000020E610000001000000050000008C2FDAE385444240C6C210397D694D408C2FDAE385444240766F4562826A4D406286C61341484240766F4562826A4D406286C61341484240C6C210397D694D408C2FDAE385444240C6C210397D694D40
26421	21849	36.866472999999999	36.888958000000002	58.879573999999998	58.873443999999999	Школьная	0103000020E61000000100000005000000FAEE5696E86E424097715303CD6F4D40FAEE5696E86E4240B9347EE195704D4040C23060C9714240B9347EE195704D4040C23060C971424097715303CD6F4D40FAEE5696E86E424097715303CD6F4D40
31701	22263	36.793250999999998	36.819716	58.749822999999999	58.737000000000002	Центральная	0103000020E610000001000000050000007842AF3F8965424075931804565E4D407842AF3F89654240F1643733FA5F4D4004013274EC684240F1643733FA5F4D4004013274EC68424075931804565E4D407842AF3F8965424075931804565E4D40
31993	22128	36.294758000000002	36.314062999999997	58.557886000000003	58.549087999999998	Школьная	0103000020E61000000100000005000000001E51A1BA2542402250FD8348464D40001E51A1BA254240B972F6CE68474D401BF1643733284240B972F6CE68474D401BF16437332842402250FD8348464D40001E51A1BA2542402250FD8348464D40
31996	22346	36.583314999999999	36.600203	58.922701000000004	58.913642000000003	Центральная	0103000020E610000001000000050000001422E010AA4A424043209738F2744D401422E010AA4A4240467EFD101B764D4005FBAF73D34C4240467EFD101B764D4005FBAF73D34C424043209738F2744D401422E010AA4A424043209738F2744D40
31751	22099	36.381265999999997	36.400812999999999	58.555548000000002	58.533875000000002	Корелякова	0103000020E61000000100000005000000D2890453CD3042407593180456444D40D2890453CD304240DAAD65321C474D40E46723D74D334240DAAD65321C474D40E46723D74D3342407593180456444D40D2890453CD3042407593180456444D40
31688	21785	36.902099999999997	36.906987000000001	58.932056000000003	58.925590999999997	Центральная	0103000020E610000001000000050000005DDC460378734240683C11C479764D405DDC46037873424032056B9C4D774D40D67267261874424032056B9C4D774D40D672672618744240683C11C479764D405DDC460378734240683C11C479764D40
31685	21690	36.388902000000002	36.405844000000002	59.033856999999998	59.020750999999997	Школьная	0103000020E61000000100000005000000ACAC6D8AC7314240FD2D01F8A7824D40ACAC6D8AC7314240CEDE196D55844D4090A339B2F2334240CEDE196D55844D4090A339B2F2334240FD2D01F8A7824D40ACAC6D8AC7314240FD2D01F8A7824D40
31990	22017	36.341444000000003	36.362302999999997	58.669367000000001	58.657933	Административный	0103000020E610000001000000050000002DB5DE6FB42B4240C6FA062637544D402DB5DE6FB42B4240C5025FD1AD554D40101FD8F15F2E4240C5025FD1AD554D40101FD8F15F2E4240C6FA062637544D402DB5DE6FB42B4240C6FA062637544D40
26568	21535	36.591785999999999	36.624457999999997	58.973005999999998	58.960656	Советская	0103000020E61000000100000005000000861DC6A4BF4B4240645A9BC6F67A4D40861DC6A4BF4B4240E867EA758B7C4D40DFDC5F3DEE4F4240E867EA758B7C4D40DFDC5F3DEE4F4240645A9BC6F67A4D40861DC6A4BF4B4240645A9BC6F67A4D40
31936	22332	36.571969000000003	36.630682999999998	58.959566000000002	58.950051999999999	Советская	0103000020E61000000100000005000000B5A9BA4736494240ECBFCE4D9B794D40B5A9BA4736494240412D060FD37A4D4053927538BA504240412D060FD37A4D4053927538BA504240ECBFCE4D9B794D40B5A9BA4736494240ECBFCE4D9B794D40
26417	21752	35.936805999999997	35.992806999999999	58.978043999999997	58.959088000000001	Южный	0103000020E6100000010000000500000029594E42E9F7414037FE4465C37A4D4029594E42E9F741404606B98B307D4D40B41EBE4C14FF41404606B98B307D4D40B41EBE4C14FF414037FE4465C37A4D4029594E42E9F7414037FE4465C37A4D40
31922	21941	36.438021999999997	36.463749	58.719842	58.714658999999997	Центральная	0103000020E61000000100000005000000D976DA1A11384240626534F2795B4D40D976DA1A11384240C4245CC8235C4D40BF4692205C3B4240C4245CC8235C4D40BF4692205C3B4240626534F2795B4D40D976DA1A11384240626534F2795B4D40
31691	21885	36.481177000000002	36.493707999999998	58.673186000000001	58.661987000000003	Школьная	0103000020E61000000100000005000000304B3B35973D424047B071FDBB544D40304B3B35973D4240021077F52A564D4004E3E0D2313F4240021077F52A564D4004E3E0D2313F424047B071FDBB544D40304B3B35973D424047B071FDBB544D40
31945	21600	36.857059	36.892892000000003	58.944856999999999	58.932873000000001	Центральная	0103000020E6100000010000000500000009DFFB1BB46D42402429E96168774D4009DFFB1BB46D4240C632FD12F1784D40166EF9484A724240C632FD12F1784D40166EF9484A7242402429E96168774D4009DFFB1BB46D42402429E96168774D40
31998	22464	36.413964999999997	36.437033	58.757922000000001	58.749487000000002	Центральная	0103000020E6100000010000000500000025581CCEFC3442407AE3A430EF5F4D4025581CCEFC3442409F758D9603614D40EA2285B2F03742409F758D9603614D40EA2285B2F03742407AE3A430EF5F4D4025581CCEFC3442407AE3A430EF5F4D40
26395	20170	39.694468000000001	39.764257999999998	59.638997000000003	59.624257	Профсоюзная	0103000020E610000001000000050000002C0FD253E4D8434048A643A7E7CF4D402C0FD253E4D84340FE9E58A7CAD14D406ADAC534D3E14340FE9E58A7CAD14D406ADAC534D3E1434048A643A7E7CF4D402C0FD253E4D8434048A643A7E7CF4D40
26557	20170	39.694468000000001	39.764257999999998	59.638997000000003	59.624257	Первомайская	0103000020E610000001000000050000002C0FD253E4D8434048A643A7E7CF4D402C0FD253E4D84340FE9E58A7CAD14D406ADAC534D3E14340FE9E58A7CAD14D406ADAC534D3E1434048A643A7E7CF4D402C0FD253E4D8434048A643A7E7CF4D40
31744	20170	39.694468000000001	39.764257999999998	59.638997000000003	59.624257	Октябрьская	0103000020E610000001000000050000002C0FD253E4D8434048A643A7E7CF4D402C0FD253E4D84340FE9E58A7CAD14D406ADAC534D3E14340FE9E58A7CAD14D406ADAC534D3E1434048A643A7E7CF4D402C0FD253E4D8434048A643A7E7CF4D40
31978	20935	39.834749000000002	39.846471999999999	59.660699000000001	59.655648999999997	Полевая	0103000020E6100000010000000500000032AF230ED9EA4340DA53724EECD34D4032AF230ED9EA4340FDBFEAC891D44D40677DCA3159EC4340FDBFEAC891D44D40677DCA3159EC4340DA53724EECD34D4032AF230ED9EA4340DA53724EECD34D40
26559	20651	39.347197999999999	39.377479999999998	59.854241999999999	59.840397000000003	Садовая	0103000020E61000000100000005000000499EEBFB70AC43400954FF2092EB4D40499EEBFB70AC4340506F46CD57ED4D407172BF4351B04340506F46CD57ED4D407172BF4351B043400954FF2092EB4D40499EEBFB70AC43400954FF2092EB4D40
31977	20898	39.621319	39.634461000000002	59.697513999999998	59.691415999999997	Курлаково	0103000020E6100000010000000500000014B1886187CF43402FF7C95180D84D4014B1886187CF43404640852348D94D4032CB9E0436D143404640852348D94D4032CB9E0436D143402FF7C95180D84D4014B1886187CF43402FF7C95180D84D40
31974	20499	39.338484000000001	39.345329	60.134793999999999	60.131746999999997	Никольская	0103000020E61000000100000005000000111C977153AB43404D2CF015DD104E40111C977153AB434038D906EE40114E4021AE9CBD33AC434038D906EE40114E4021AE9CBD33AC43404D2CF015DD104E40111C977153AB43404D2CF015DD104E40
31805	20379	39.064498	39.268047000000003	60.071820000000002	59.989265000000003	Центральная	0103000020E610000001000000050000002654707841884340EA094B3CA0FE4D4026547078418843407099D36531094E403D65355D4FA243407099D36531094E403D65355D4FA24340EA094B3CA0FE4D402654707841884340EA094B3CA0FE4D40
31931	20728	39.659488000000003	39.670563999999999	59.878604000000003	59.874651999999998	Центральная	0103000020E610000001000000050000005F0D501A6AD44340C4B0C398F4EF4D405F0D501A6AD4434041118B1876F04D40FEEF880AD5D5434041118B1876F04D40FEEF880AD5D54340C4B0C398F4EF4D405F0D501A6AD44340C4B0C398F4EF4D40
31858	20575	39.683185000000002	39.714500999999998	59.776065000000003	59.766905000000001	Яковлева	0103000020E61000000100000005000000130F289B72D74340C7116BF129E24D40130F289B72D74340FE48111956E34D40CAFACDC474DB4340FE48111956E34D40CAFACDC474DB4340C7116BF129E24D40130F289B72D74340C7116BF129E24D40
26400	20820	39.826422000000001	39.860055000000003	59.636614000000002	59.623505999999999	Нагорная	0103000020E61000000100000005000000F3583332C8E943400D6E6B0BCFCF4D40F3583332C8E943407F164B917CD14D4072E1404816EE43407F164B917CD14D4072E1404816EE43400D6E6B0BCFCF4D40F3583332C8E943400D6E6B0BCFCF4D40
31976	20461	39.265208000000001	39.287396999999999	59.991813	59.982883000000001	Парковая	0103000020E610000001000000050000009C51F355F2A14340AE65321CCFFD4D409C51F355F2A14340B35F77BAF3FE4D40F8FBC56CC9A44340B35F77BAF3FE4D40F8FBC56CC9A44340AE65321CCFFD4D409C51F355F2A14340AE65321CCFFD4D40
31975	20783	39.272565999999998	39.281818000000001	59.911740999999999	59.904192999999999	Совхозная	0103000020E6100000010000000500000032005471E3A24340D522A298BCF34D4032005471E3A243400FB6D8EDB3F44D404AB6BA9C12A443400FB6D8EDB3F44D404AB6BA9C12A44340D522A298BCF34D4032005471E3A24340D522A298BCF34D40
31792	19476	42.044156000000001	42.066515000000003	59.672356000000001	59.665894000000002	Школьная	0103000020E610000001000000050000000AF65FE7A6054540234DBC033CD54D400AF65FE7A60545407BA2EBC20FD64D40C3D84290830845407BA2EBC20FD64D40C3D8429083084540234DBC033CD54D400AF65FE7A6054540234DBC033CD54D40
32045	19996	42.775393000000001	42.787745000000001	59.407912000000003	59.400153000000003	Центральная	0103000020E610000001000000050000000F46EC1340634540BA32A83638B34D400F46EC1340634540AFD2DD7536B44D40344B02D4D4644540AFD2DD7536B44D40344B02D4D4644540BA32A83638B34D400F46EC1340634540BA32A83638B34D40
31731	18374	42.737386000000001	42.788913000000001	59.985560999999997	59.955236999999997	Осипенко	0103000020E610000001000000050000009E4319AA625E4540EE76BD3445FA4D409E4319AA625E4540459BE3DC26FE4D40D331E719FB644540459BE3DC26FE4D40D331E719FB644540EE76BD3445FA4D409E4319AA625E4540EE76BD3445FA4D40
26712	18374	42.737386000000001	42.788913000000001	59.985560999999997	59.955236999999997	Набережная им. Кускова	0103000020E610000001000000050000009E4319AA625E4540EE76BD3445FA4D409E4319AA625E4540459BE3DC26FE4D40D331E719FB644540459BE3DC26FE4D40D331E719FB644540EE76BD3445FA4D409E4319AA625E4540EE76BD3445FA4D40
31788	18374	42.737386000000001	42.788913000000001	59.985560999999997	59.955236999999997	Ленина	0103000020E610000001000000050000009E4319AA625E4540EE76BD3445FA4D409E4319AA625E4540459BE3DC26FE4D40D331E719FB644540459BE3DC26FE4D40D331E719FB644540EE76BD3445FA4D409E4319AA625E4540EE76BD3445FA4D40
31787	18374	42.737386000000001	42.788913000000001	59.985560999999997	59.955236999999997	Загородная	0103000020E610000001000000050000009E4319AA625E4540EE76BD3445FA4D409E4319AA625E4540459BE3DC26FE4D40D331E719FB644540459BE3DC26FE4D40D331E719FB644540EE76BD3445FA4D409E4319AA625E4540EE76BD3445FA4D40
31907	18374	42.737386000000001	42.788913000000001	59.985560999999997	59.955236999999997	Володарского	0103000020E610000001000000050000009E4319AA625E4540EE76BD3445FA4D409E4319AA625E4540459BE3DC26FE4D40D331E719FB644540459BE3DC26FE4D40D331E719FB644540EE76BD3445FA4D409E4319AA625E4540EE76BD3445FA4D40
31913	19857	42.820650000000001	42.834997000000001	59.964210000000001	59.957034	Энергетиков	0103000020E6100000010000000500000030BB270F0B6945407D94111780FA4D4030BB270F0B694540F33CB83B6BFB4D400AA1832EE16A4540F33CB83B6BFB4D400AA1832EE16A45407D94111780FA4D4030BB270F0B6945407D94111780FA4D40
32044	52410	42.703420000000001	42.731358	59.932837999999997	59.919513000000002	Октябрьская	0103000020E6100000010000000500000019ADA3AA095A4540999F1B9AB2F54D4019ADA3AA095A4540A73B4F3C67F74D4080D591239D5D4540A73B4F3C67F74D4080D591239D5D4540999F1B9AB2F54D4019ADA3AA095A4540999F1B9AB2F54D40
31678	19556	42.031103000000002	42.054971000000002	59.713451999999997	59.702241000000001	Мира	0103000020E610000001000000050000005CE7DF2EFB03454086747808E3D94D405CE7DF2EFB03454005A2276552DB4D403D9D2B4A0907454005A2276552DB4D403D9D2B4A0907454086747808E3D94D405CE7DF2EFB03454086747808E3D94D40
31740	19804	42.674512	42.692523999999999	60.129573999999998	60.121685999999997	Механизаторов	0103000020E610000001000000050000003961C26856564540C6302768930F4E403961C26856564540B9347EE195104E40F9D85DA0A4584540B9347EE195104E40F9D85DA0A4584540C6302768930F4E403961C26856564540C6302768930F4E40
31675	20077	42.514774000000003	42.53584	59.496870000000001	59.486820000000002	Рубцова	0103000020E61000000100000005000000626A4B1DE4414540F584251E50BE4D40626A4B1DE4414540882EA86F99BF4D40BFF1B56796444540882EA86F99BF4D40BFF1B56796444540F584251E50BE4D40626A4B1DE4414540F584251E50BE4D40
31823	19732	42.798085	42.806348999999997	60.093223000000002	60.086936999999999	Садовая	0103000020E61000000100000005000000CE3637A627664540FBE769C0200B4E40CE3637A627664540151E34BBEE0B4E40C614AC7136674540151E34BBEE0B4E40C614AC7136674540FBE769C0200B4E40CE3637A627664540FBE769C0200B4E40
26582	51296	42.225929999999998	42.239449	59.871324000000001	59.864674000000001	Пролетарская	0103000020E61000000100000005000000B7973446EB1C4540CBD93BA3ADEE4D40B7973446EB1C4540261C7A8B87EF4D40AB07CC43A61E4540261C7A8B87EF4D40AB07CC43A61E4540CBD93BA3ADEE4D40B7973446EB1C4540CBD93BA3ADEE4D40
31912	19963	42.813527000000001	42.852468999999999	59.314320000000002	59.304918000000001	Пролетарская	0103000020E61000000100000005000000DDB419A7216845401AFB928D07A74D40DDB419A721684540473D44A33BA84D404AED45B41D6D4540473D44A33BA84D404AED45B41D6D45401AFB928D07A74D40DDB419A7216845401AFB928D07A74D40
31970	19170	43.148274999999998	43.184584999999998	60.053409000000002	60.041412999999999	Школьная	0103000020E610000001000000050000003EE8D9ACFA9245408B506C054D054E403EE8D9ACFA924540F2272A1BD6064E40842A357BA0974540F2272A1BD6064E40842A357BA09745408B506C054D054E403EE8D9ACFA9245408B506C054D054E40
32042	19658	42.722123000000003	42.736784	59.947445999999999	59.937309999999997	Школьная	0103000020E610000001000000050000003F58C6866E5C45405C1B2AC6F9F74D403F58C6866E5C4540EE5C18E945F94D40A81B28F04E5E4540EE5C18E945F94D40A81B28F04E5E45405C1B2AC6F9F74D403F58C6866E5C45405C1B2AC6F9F74D40
32074	53287	42.304307999999999	42.318573000000001	59.601188	59.590243999999998	Центральная	0103000020E61000000100000005000000A1F48590F326454082548A1D8DCB4D40A1F48590F3264540B35F77BAF3CC4D40BE310400C7284540B35F77BAF3CC4D40BE310400C728454082548A1D8DCB4D40A1F48590F326454082548A1D8DCB4D40
32082	53291	43.591028000000001	43.612344999999998	60.423032999999997	60.413811000000003	Центральная	0103000020E61000000100000005000000998235CEA6CB4540CFDC43C2F7344E40998235CEA6CB45407B1002F225364E403F6F2A5261CE45407B1002F225364E403F6F2A5261CE4540CFDC43C2F7344E40998235CEA6CB4540CFDC43C2F7344E40
32062	53283	43.556837999999999	43.599885	60.506819999999998	60.486060000000002	Советская	0103000020E61000000100000005000000C495B37746C7454067F2CD36373E4E40C495B37746C74540B77A4E7ADF404E40342E1C08C9CC4540B77A4E7ADF404E40342E1C08C9CC454067F2CD36373E4E40C495B37746C7454067F2CD36373E4E40
32022	17339	43.614958999999999	43.622306999999999	60.539588999999999	60.534021000000003	Центральная	0103000020E61000000100000005000000C0B0FCF9B6CE45404930D5CC5A444E40C0B0FCF9B6CE454003249A4011454E4033897AC1A7CF454003249A4011454E4033897AC1A7CF45404930D5CC5A444E40C0B0FCF9B6CE45404930D5CC5A444E40
26707	17980	43.336652000000001	43.345024000000002	60.500334000000002	60.496205000000003	Молодежная	0103000020E610000001000000050000000611A96917AB45404C8E3BA5833F4E400611A96917AB4540D789CBF10A404E40E52A16BF29AC4540D789CBF10A404E40E52A16BF29AC45404C8E3BA5833F4E400611A96917AB45404C8E3BA5833F4E40
31783	19717	43.642941	43.658634999999997	60.494746999999997	60.421998000000002	Центральная	0103000020E61000000100000005000000F72004E44BD245401C7DCC0704364E40F72004E44BD24540A565A4DE533F4E401F80D4264ED44540A565A4DE533F4E401F80D4264ED445401C7DCC0704364E40F72004E44BD245401C7DCC0704364E40
32034	17956	43.212674999999997	43.236013	60.515444000000002	60.507024000000001	Красная	0103000020E61000000100000005000000A1D634EF389B4540C0249529E6404E40A1D634EF389B4540B075A911FA414E4026378AAC359E4540B075A911FA414E4026378AAC359E4540C0249529E6404E40A1D634EF389B4540C0249529E6404E40
26521	17570	43.509163999999998	43.521892999999999	60.512211000000001	60.504852999999997	Центральная	0103000020E61000000100000005000000782634492CC14540CC24EA059F404E40782634492CC1454063D34A2190414E407381CB63CDC2454063D34A2190414E407381CB63CDC24540CC24EA059F404E40782634492CC14540CC24EA059F404E40
31844	17080	40.884717999999999	40.898300999999996	60.032259000000003	60.026491	Центральная	0103000020E610000001000000050000005D177E703E714440B5519D0E64034E405D177E703E71444037001B1021044E40677BF486FB72444037001B1021044E40677BF486FB724440B5519D0E64034E405D177E703E714440B5519D0E64034E40
31932	16369	40.940610999999997	40.966213000000003	59.889367	59.881104999999998	Центральная	0103000020E6100000010000000500000001A1F5F065784440C9AB730CC8F04D4001A1F5F065784440219221C7D6F14D402BFC19DEAC7B4440219221C7D6F14D402BFC19DEAC7B4440C9AB730CC8F04D4001A1F5F065784440C9AB730CC8F04D40
31845	17145	40.758343000000004	40.780765000000002	60.037165999999999	60.032263	Центральная	0103000020E61000000100000005000000451328621161444078EFA83121044E404513286211614440F64201DBC1044E40446E861BF0634440F64201DBC1044E40446E861BF063444078EFA83121044E40451328621161444078EFA83121044E40
26665	2701	41.046773999999999	41.108829999999998	60.024912999999998	60.004567999999999	Советская	0103000020E61000000100000005000000CC26C0B0FC854440D74D29AF95004E40CC26C0B0FC854440641F645930034E406E693524EE8D4440641F645930034E406E693524EE8D4440D74D29AF95004E40CC26C0B0FC854440D74D29AF95004E40
31725	2701	41.046773999999999	41.108829999999998	60.024912999999998	60.004567999999999	Славянская	0103000020E61000000100000005000000CC26C0B0FC854440D74D29AF95004E40CC26C0B0FC854440641F645930034E406E693524EE8D4440641F645930034E406E693524EE8D4440D74D29AF95004E40CC26C0B0FC854440D74D29AF95004E40
31843	2701	41.046773999999999	41.108829999999998	60.024912999999998	60.004567999999999	Парковая	0103000020E61000000100000005000000CC26C0B0FC854440D74D29AF95004E40CC26C0B0FC854440641F645930034E406E693524EE8D4440641F645930034E406E693524EE8D4440D74D29AF95004E40CC26C0B0FC854440D74D29AF95004E40
32015	16442	41.289651999999997	41.315586000000003	59.802208999999998	59.791978999999998	Школьная	0103000020E61000000100000005000000499C155113A54440340F60915FE54D40499C155113A5444047C7D5C8AEE64D40A9893E1F65A8444047C7D5C8AEE64D40A9893E1F65A84440340F60915FE54D40499C155113A54440340F60915FE54D40
32020	16787	41.088284999999999	41.100323000000003	60.248435000000001	60.240758	Молодежная	0103000020E610000001000000050000001ADD41EC4C8B44400C207C28D11E4E401ADD41EC4C8B44404417D4B7CC1F4E40B0045262D78C44404417D4B7CC1F4E40B0045262D78C44400C207C28D11E4E401ADD41EC4C8B44400C207C28D11E4E40
32019	16622	41.052703000000001	41.078709000000003	60.008395999999998	60.000478999999999	Поспелова	0103000020E6100000010000000500000057B3CEF8BE864440DAAA24B20F004E4057B3CEF8BE86444067B5C01E13014E405073F222138A444067B5C01E13014E405073F222138A4440DAAA24B20F004E4057B3CEF8BE864440DAAA24B20F004E40
31818	16280	41.711995000000002	41.729979	60.183217999999997	60.176873000000001	Подлесная	0103000020E6100000010000000500000030F5F3A622DB4440D04543C6A3164E4030F5F3A622DB4440EE04FBAF73174E4026E2ADF36FDD4440EE04FBAF73174E4026E2ADF36FDD4440D04543C6A3164E4030F5F3A622DB4440D04543C6A3164E40
31840	16902	41.616332999999997	41.626852	60.149442999999998	60.144461999999997	Центральная	0103000020E610000001000000050000000839EFFFE3CE4440E3C116BB7D124E400839EFFFE3CE4440DDCEBEF220134E4052B7B3AF3CD04440DDCEBEF220134E4052B7B3AF3CD04440E3C116BB7D124E400839EFFFE3CE4440E3C116BB7D124E40
31851	17170	40.794697999999997	40.804417999999998	60.095483999999999	60.085800999999996	Истоминская	0103000020E610000001000000050000002A1900AAB8654440677BF486FB0A4E402A1900AAB865444048A5D8D1380C4E402828452BF766444048A5D8D1380C4E402828452BF7664440677BF486FB0A4E402A1900AAB8654440677BF486FB0A4E40
31775	16355	41.091527999999997	41.116160000000001	59.912129	59.899762000000003	Зелёная	0103000020E610000001000000050000008A558330B78B44407F17B6662BF34D408A558330B78B4440D95DA0A4C0F44D403B8DB454DE8E4440D95DA0A4C0F44D403B8DB454DE8E44407F17B6662BF34D408A558330B78B44407F17B6662BF34D40
31724	16764	41.113393000000002	41.135581999999999	60.219214999999998	60.207579000000003	Набережная	0103000020E61000000100000005000000344C6DA9838E44400F2BDCF2911A4E40344C6DA9838E444075E5B33C0F1C4E4090F63FC05A91444075E5B33C0F1C4E4090F63FC05A9144400F2BDCF2911A4E40344C6DA9838E44400F2BDCF2911A4E40
26555	16764	41.113393000000002	41.135581999999999	60.219214999999998	60.207579000000003	Мира	0103000020E61000000100000005000000344C6DA9838E44400F2BDCF2911A4E40344C6DA9838E444075E5B33C0F1C4E4090F63FC05A91444075E5B33C0F1C4E4090F63FC05A9144400F2BDCF2911A4E40344C6DA9838E44400F2BDCF2911A4E40
31957	16527	41.577722999999999	41.590668000000001	60.016285000000003	60.011158000000002	Школьная	0103000020E61000000100000005000000D192C7D3F2C944405D8B16A06D014E40D192C7D3F2C944402B357BA015024E4099654F029BCB44402B357BA015024E4099654F029BCB44405D8B16A06D014E40D192C7D3F2C944405D8B16A06D014E40
26486	2554	41.234513	41.252398999999997	59.604125000000003	59.594602999999999	Сельская	0103000020E6100000010000000500000051BEA085049E44403F8D7BF31BCC4D4051BEA085049E444017D9CEF753CD4D408445459C4EA0444017D9CEF753CD4D408445459C4EA044403F8D7BF31BCC4D4051BEA085049E44403F8D7BF31BCC4D40
31895	15953	40.548838000000003	40.572248000000002	59.665053	59.652903000000002	Молодежная	0103000020E61000000100000005000000AA66D65240464440EB3A545392D34D40AA66D65240464440A88DEA7420D54D40C899266C3F494440A88DEA7420D54D40C899266C3F494440EB3A545392D34D40AA66D65240464440EB3A545392D34D40
31762	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Школьная	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
26640	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Шатенево	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
26490	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Советская	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31797	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Призводственная	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
32039	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Первая Глушицкая	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31711	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Мусинского	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31995	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Менделеева	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31919	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Колхозная	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
32011	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Кирова	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31894	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Калинина	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
31764	14256	40.017476000000002	40.191614000000001	59.514865999999998	59.433576000000002	Беднякова	0103000020E61000000100000005000000823B50A73C0244404E2A1A6B7FB74D40823B50A73C02444042E90B21E7C14D4056BABBCE8618444042E90B21E7C14D4056BABBCE861844404E2A1A6B7FB74D40823B50A73C0244404E2A1A6B7FB74D40
26475	15612	40.178463000000001	40.200094	59.627564999999997	59.611054000000003	Центральная	0103000020E61000000100000005000000E54526E0D7164440850B790437CE4D40E54526E0D71644409F8EC70C54D04D401B1021AE9C1944409F8EC70C54D04D401B1021AE9C194440850B790437CE4D40E54526E0D7164440850B790437CE4D40
26480	15824	40.446995999999999	40.472363999999999	59.436605999999998	59.427036000000001	Центральная	0103000020E61000000100000005000000AEB8382A373944407A1B9B1DA9B64D40AEB8382A37394440629E95B4E2B74D4064E76D6C763C4440629E95B4E2B74D4064E76D6C763C44407A1B9B1DA9B64D40AEB8382A373944407A1B9B1DA9B64D40
26644	15253	40.324044000000001	40.363182999999999	59.515276999999998	59.491928000000001	Розы Люксембург	0103000020E61000000100000005000000863B17467A2944404CFE277FF7BE4D40863B17467A294440C4B0C398F4C14D4049BBD1C77C2E4440C4B0C398F4C14D4049BBD1C77C2E44404CFE277FF7BE4D40863B17467A2944404CFE277FF7BE4D40
32008	15253	40.324044000000001	40.363182999999999	59.515276999999998	59.491928000000001	Р.Люксембург	0103000020E61000000100000005000000863B17467A2944404CFE277FF7BE4D40863B17467A294440C4B0C398F4C14D4049BBD1C77C2E4440C4B0C398F4C14D4049BBD1C77C2E44404CFE277FF7BE4D40863B17467A2944404CFE277FF7BE4D40
31832	15253	40.324044000000001	40.363182999999999	59.515276999999998	59.491928000000001	Парковая	0103000020E61000000100000005000000863B17467A2944404CFE277FF7BE4D40863B17467A294440C4B0C398F4C14D4049BBD1C77C2E4440C4B0C398F4C14D4049BBD1C77C2E44404CFE277FF7BE4D40863B17467A2944404CFE277FF7BE4D40
26655	15887	40.545119	40.561073	59.496678000000003	59.491809000000003	Школьная	0103000020E61000000100000005000000D0B69A75C64544407270E998F3BE4D40D0B69A75C645444044520B2593BF4D4095D5743DD147444044520B2593BF4D4095D5743DD14744407270E998F3BE4D40D0B69A75C64544407270E998F3BE4D40
31771	15960	40.878062	40.904651999999999	59.631382000000002	59.623387999999998	Центральная	0103000020E6100000010000000500000020EEEA5564704440035C902DCBCF4D4020EEEA55647044403CA41820D1D04D40682101A3CB7344403CA41820D1D04D40682101A3CB734440035C902DCBCF4D4020EEEA5564704440035C902DCBCF4D40
31951	15554	40.055591	40.068292999999997	59.641343999999997	59.632688000000002	Центральная	0103000020E61000000100000005000000D9791B9B1D0744402C499EEBFBD04D40D9791B9B1D0744402FBE688F17D24D40DAC534D3BD0844402FBE688F17D24D40DAC534D3BD0844402C499EEBFBD04D40D9791B9B1D0744402C499EEBFBD04D40
31874	16117	41.462657999999998	41.515039000000002	59.594161	59.577984999999998	Н.Рубцова	0103000020E61000000100000005000000CB9D996038BB44400E4A9869FBC94D40CB9D996038BB444082C7B7770DCC4D40109546CCECC1444082C7B7770DCC4D40109546CCECC144400E4A9869FBC94D40CB9D996038BB44400E4A9869FBC94D40
31758	13840	44.567307999999997	44.592748	60.475881000000001	60.467398000000003	Набережная	0103000020E610000001000000050000002C616D8C9D484640A01B9AB2D33B4E402C616D8C9D484640D6E429ABE93C4E407C629D2ADF4B4640D6E429ABE93C4E407C629D2ADF4B4640A01B9AB2D33B4E402C616D8C9D484640A01B9AB2D33B4E40
31782	2447	44.203660999999997	44.267296999999999	60.428913000000001	60.406075999999999	Юбилейная	0103000020E610000001000000050000003E3C4B90111A464062D8614CFA334E403E3C4B90111A464025EA059FE6364E40D2A8C0C93622464025EA059FE6364E40D2A8C0C93622464062D8614CFA334E403E3C4B90111A464062D8614CFA334E40
26551	2447	44.203660999999997	44.267296999999999	60.428913000000001	60.406075999999999	Школьная	0103000020E610000001000000050000003E3C4B90111A464062D8614CFA334E403E3C4B90111A464025EA059FE6364E40D2A8C0C93622464025EA059FE6364E40D2A8C0C93622464062D8614CFA334E403E3C4B90111A464062D8614CFA334E40
31879	2447	44.203660999999997	44.267296999999999	60.428913000000001	60.406075999999999	Советская	0103000020E610000001000000050000003E3C4B90111A464062D8614CFA334E403E3C4B90111A464025EA059FE6364E40D2A8C0C93622464025EA059FE6364E40D2A8C0C93622464062D8614CFA334E403E3C4B90111A464062D8614CFA334E40
31700	2447	44.203660999999997	44.267296999999999	60.428913000000001	60.406075999999999	Первомайская	0103000020E610000001000000050000003E3C4B90111A464062D8614CFA334E403E3C4B90111A464025EA059FE6364E40D2A8C0C93622464025EA059FE6364E40D2A8C0C93622464062D8614CFA334E403E3C4B90111A464062D8614CFA334E40
31708	2447	44.203660999999997	44.267296999999999	60.428913000000001	60.406075999999999	Культуры	0103000020E610000001000000050000003E3C4B90111A464062D8614CFA334E403E3C4B90111A464025EA059FE6364E40D2A8C0C93622464025EA059FE6364E40D2A8C0C93622464062D8614CFA334E403E3C4B90111A464062D8614CFA334E40
26583	13751	44.611944999999999	44.636324999999999	60.476196000000002	60.470781000000002	Школьная	0103000020E61000000100000005000000B1F9B836544E4640024A438D423C4E40B1F9B836544E4640363E93FDF33C4E404850FC1873514640363E93FDF33C4E404850FC1873514640024A438D423C4E40B1F9B836544E4640024A438D423C4E40
31759	14242	44.116883000000001	44.139530000000001	60.496169000000002	60.485647999999998	Лесная	0103000020E61000000100000005000000AC3AAB05F60E464014AFB2B6293E4E40AC3AAB05F60E4640FF243E77823F4E40CB67791EDC114640FF243E77823F4E40CB67791EDC11464014AFB2B6293E4E40AC3AAB05F60E464014AFB2B6293E4E40
31883	13287	44.875376000000003	44.893621000000003	60.525888999999999	60.516556000000001	Школьная	0103000020E6100000010000000500000006DA1D520C704640BB46CB811E424E4006DA1D520C704640BF29AC5450434E406902452C62724640BF29AC5450434E406902452C62724640BB46CB811E424E4006DA1D520C704640BB46CB811E424E40
32037	13775	44.472831999999997	44.485570000000003	60.468803000000001	60.465366000000003	Культуры	0103000020E610000001000000050000004A404CC2853C4640CE55F31C913B4E404A404CC2853C464023A298BC013C4E4099F56228273E464023A298BC013C4E4099F56228273E4640CE55F31C913B4E404A404CC2853C4640CE55F31C913B4E40
31822	13209	45.067517000000002	45.093074000000001	60.585189999999997	60.578552000000002	Молодежная	0103000020E610000001000000050000004776A565A48846408884EFFD0D4A4E404776A565A48846401EF98381E74A4E40D00D4DD9E98B46401EF98381E74A4E40D00D4DD9E98B46408884EFFD0D4A4E404776A565A48846408884EFFD0D4A4E40
32001	13659	43.760288000000003	43.792304000000001	60.176093999999999	60.161990000000003	Октябрьская	0103000020E6100000010000000500000048C5FF1D51E14540B8239C16BC144E4048C5FF1D51E14540CB82893F8A164E40B83EAC376AE54540CB82893F8A164E40B83EAC376AE54540B8239C16BC144E4048C5FF1D51E14540B8239C16BC144E40
31985	2359	44.351038000000003	44.375534999999999	60.238100000000003	60.225855000000003	Школьная	0103000020E610000001000000050000009ED32CD0EE2C4640AD510FD1E81C4E409ED32CD0EE2C4640BC96900F7A1E4E406EC0E78711304640BC96900F7A1E4E406EC0E78711304640AD510FD1E81C4E409ED32CD0EE2C4640AD510FD1E81C4E40
31772	2359	44.351038000000003	44.375534999999999	60.238100000000003	60.225855000000003	Октябрьская	0103000020E610000001000000050000009ED32CD0EE2C4640AD510FD1E81C4E409ED32CD0EE2C4640BC96900F7A1E4E406EC0E78711304640BC96900F7A1E4E406EC0E78711304640AD510FD1E81C4E409ED32CD0EE2C4640AD510FD1E81C4E40
26411	13197	44.920183999999999	44.935122999999997	60.541739	60.534557	Полевая	0103000020E61000000100000005000000B726DD96C8754640876C205D6C444E40B726DD96C8754640DFFB1BB457454E40635E471CB2774640DFFB1BB457454E40635E471CB2774640876C205D6C444E40B726DD96C8754640876C205D6C444E40
31824	2293	44.084139999999998	44.095773000000001	60.223987000000001	60.217883	Школьная	0103000020E6100000010000000500000089247A19C50A46405CAD1397E31B4E4089247A19C50A464055DD239BAB1C4E407F6B274A420C464055DD239BAB1C4E407F6B274A420C46405CAD1397E31B4E4089247A19C50A46405CAD1397E31B4E40
26449	13680	44.764918999999999	44.780603999999997	60.483626000000001	60.476993999999998	Болотная	0103000020E61000000100000005000000658BA4DDE8614640B131AF230E3D4E40658BA4DDE861464066BFEE74E73D4E403A90F5D4EA63464066BFEE74E73D4E403A90F5D4EA634640B131AF230E3D4E40658BA4DDE8614640B131AF230E3D4E40
31819	14131	44.271340000000002	44.289485999999997	60.424165000000002	60.415393000000002	Луговая	0103000020E610000001000000050000005F0CE544BB22464061FE0A992B354E405F0CE544BB224640CE8DE9094B364E402E5393E00D254640CE8DE9094B364E402E5393E00D25464061FE0A992B354E405F0CE544BB22464061FE0A992B354E40
26432	14160	44.154944999999998	44.170287999999999	60.397730000000003	60.387101000000001	Полевая	0103000020E61000000100000005000000E0D6DD3CD5134640DC9F8B868C314E40E0D6DD3CD5134640AD510FD1E8324E405C7347FFCB154640AD510FD1E8324E405C7347FFCB154640DC9F8B868C314E40E0D6DD3CD5134640DC9F8B868C314E40
26437	12850	45.425395999999999	45.451087999999999	59.385097999999999	59.373066000000001	Центральная	0103000020E61000000100000005000000B3EC496073B64640F19F6EA0C0AF4D40B3EC496073B64640A4E029E44AB14D401CCF6740BDB94640A4E029E44AB14D401CCF6740BDB94640F19F6EA0C0AF4D40B3EC496073B64640F19F6EA0C0AF4D40
31756	12786	45.411428000000001	45.429780000000001	59.474668999999999	59.466408999999999	Городской край	0103000020E61000000100000005000000505436ACA9B44640B0C7444AB3BB4D40505436ACA9B4464067B62BF4C1BC4D40C93CF20703B7464067B62BF4C1BC4D40C93CF20703B74640B0C7444AB3BB4D40505436ACA9B44640B0C7444AB3BB4D40
31750	12718	44.575958	44.596260000000001	59.387407000000003	59.37914	50-летия Победы	0103000020E610000001000000050000004EEFE2FDB84946407F4DD6A887B04D404EEFE2FDB8494640E99E758D96B14D40DCF4673F524C4640E99E758D96B14D40DCF4673F524C46407F4DD6A887B04D404EEFE2FDB84946407F4DD6A887B04D40
32060	53252	45.429645000000001	45.492213	59.557451	59.498026000000003	маршала Конева	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
32050	53252	45.429645000000001	45.492213	59.557451	59.498026000000003	Советская	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
31706	53252	45.429645000000001	45.492213	59.557451	59.498026000000003	Кузнецова	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
32051	53252	45.429645000000001	45.492213	59.557451	59.498026000000003	Володарского	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
32108	53252	45.429645000000001	45.492213	59.557451	59.498026000000003	Беляева	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
32069	53252	45.429645000000001	45.492213	59.557451	59.498026000000003	 Энергетиков	0103000020E61000000100000005000000E9F17B9BFEB646406347E350BFBF4D40E9F17B9BFEB64640AE0FEB8D5AC74D4041D5E8D500BF4640AE0FEB8D5AC74D4041D5E8D500BF46406347E350BFBF4D40E9F17B9BFEB646406347E350BFBF4D40
31692	12623	45.261265000000002	45.290334999999999	59.659253999999997	59.645232	Школьная	0103000020E61000000100000005000000734BAB2171A14640952A51F696D24D40734BAB2171A14640EBE0606F62D44D402CF180B229A54640EBE0606F62D44D402CF180B229A54640952A51F696D24D40734BAB2171A14640952A51F696D24D40
31687	12359	45.497163	45.521839999999997	59.481876	59.471820999999998	Школьная	0103000020E6100000010000000500000000E48409A3BF464073486AA164BC4D4000E48409A3BF4640185DDE1CAEBD4D4050DF32A7CBC24640185DDE1CAEBD4D4050DF32A7CBC2464073486AA164BC4D4000E48409A3BF464073486AA164BC4D40
31747	12123	45.856723000000002	45.875048	59.446185999999997	59.438093000000002	Молодежная	0103000020E61000000100000005000000925D6919A9ED4640A3CD716E13B84D40925D6919A9ED46406EF7729F1CB94D401137A79201F046406EF7729F1CB94D401137A79201F04640A3CD716E13B84D40925D6919A9ED4640A3CD716E13B84D40
31877	12242	45.849311	45.869262999999997	59.338797999999997	59.322797000000001	Центральная	0103000020E6100000010000000500000008910C39B6EC46409B1F7F6951A94D4008910C39B6EC4640A0F99CBB5DAB4D40B94F8E0244EF4640A0F99CBB5DAB4D40B94F8E0244EF46409B1F7F6951A94D4008910C39B6EC46409B1F7F6951A94D40
31982	12181	46.049672000000001	46.069730999999997	59.484895999999999	59.472900000000003	Центральная	0103000020E6100000010000000500000072C3EFA65B064740A323B9FC87BC4D4072C3EFA65B06474009FB761211BE4D40394206F2EC08474009FB761211BE4D40394206F2EC084740A323B9FC87BC4D4072C3EFA65B064740A323B9FC87BC4D40
31865	12023	44.748902000000001	44.783172999999998	59.506548000000002	59.496423	Советская	0103000020E610000001000000050000005AF44E05DC5F4640B9FDF2C98ABF4D405AF44E05DC5F464057ED9A90D6C04D401B0E4B033F64464057ED9A90D6C04D401B0E4B033F644640B9FDF2C98ABF4D405AF44E05DC5F4640B9FDF2C98ABF4D40
26593	11651	45.098832000000002	45.117068000000003	59.862045000000002	59.853808000000001	Березовая	0103000020E610000001000000050000002EE6E786A68C464016889E9449ED4D402EE6E786A68C46401557957D57EE4D403EB48F15FC8E46401557957D57EE4D403EB48F15FC8E464016889E9449ED4D402EE6E786A68C464016889E9449ED4D40
31730	9335	40.993226	41.045346000000002	59.384520000000002	59.36374	Советская	0103000020E61000000100000005000000B9C49107227F44409F1F46088FAE4D40B9C49107227F444037548CF337B14D409180D1E5CD85444037548CF337B14D409180D1E5CD8544409F1F46088FAE4D40B9C49107227F44409F1F46088FAE4D40
31681	2012	41.133462000000002	41.188249999999996	59.40025	59.388668000000003	Первомайская	0103000020E610000001000000050000001FA166481591444039807EDFBFB14D401FA1664815914440AC1C5A643BB34D406ABC749318984440AC1C5A643BB34D406ABC74931898444039807EDFBFB14D401FA166481591444039807EDFBFB14D40
26635	11264	40.912692	40.926974999999999	59.262340000000002	59.247449000000003	Шейбухтовская	0103000020E6100000010000000500000011A96917D3744440C636A968AC9F4D4011A96917D374444061376C5B94A14D40D49AE61DA776444061376C5B94A14D40D49AE61DA7764440C636A968AC9F4D4011A96917D3744440C636A968AC9F4D40
31926	11190	41.918185000000001	41.949249000000002	59.586942000000001	59.564002000000002	Комсомольская	0103000020E61000000100000005000000C156091687F544407670B03731C84D40C156091687F544400D535BEA20CB4D405F61C1FD80F944400D535BEA20CB4D405F61C1FD80F944407670B03731C84D40C156091687F544407670B03731C84D40
31859	11089	40.641534999999998	40.680621000000002	59.276186000000003	59.263903999999997	Кооперативная	0103000020E61000000100000005000000A31EA2D11D5244404CA4349BC7A14D40A31EA2D11D52444079CE16105AA34D4044FCC3961E57444079CE16105AA34D4044FCC3961E5744404CA4349BC7A14D40A31EA2D11D5244404CA4349BC7A14D40
31802	11027	40.704157000000002	40.720999999999997	59.28396	59.276516999999998	Новая	0103000020E61000000100000005000000EF1F0BD1215A4440DEE4B7E864A34D40EF1F0BD1215A4440A3AF20CD58A44D403F355EBA495C4440A3AF20CD58A44D403F355EBA495C4440DEE4B7E864A34D40EF1F0BD1215A4440DEE4B7E864A34D40
26397	809	40.898632999999997	40.908335000000001	59.310540000000003	59.304040999999998	Свободы	0103000020E610000001000000050000009D0DF9670673444052D2C3D0EAA64D409D0DF96706734440C80C54C6BFA74D40F5673F5244744440C80C54C6BFA74D40F5673F524474444052D2C3D0EAA64D409D0DF9670673444052D2C3D0EAA64D40
31679	10958	40.659914999999998	40.677387000000003	59.198855000000002	59.183230000000002	Юбилейная	0103000020E61000000100000005000000E6913F1878544440B3D2A41474974D40E6913F1878544440B3D2A41474994D4027DE019EB4564440B3D2A41474994D4027DE019EB4564440B3D2A41474974D40E6913F1878544440B3D2A41474974D40
31672	2109	40.889291	40.910482000000002	59.146813000000002	59.138182	Центральная	0103000020E6100000010000000500000046D09849D4714440AC72A1F2AF914D4046D09849D471444057D0B4C4CA924D4060CC96AC8A74444057D0B4C4CA924D4060CC96AC8A744440AC72A1F2AF914D4046D09849D4714440AC72A1F2AF914D40
31917	10971	41.073957	41.094366999999998	59.306452	59.298237999999998	Октябрьская	0103000020E61000000100000005000000B727486C778944405436ACA92CA64D40B727486C778944409BE5B2D139A74D402B69C537148C44409BE5B2D139A74D402B69C537148C44405436ACA92CA64D40B727486C778944405436ACA92CA64D40
26556	10915	45.937112999999997	45.964376999999999	59.972982999999999	59.955561000000003	Центральная	0103000020E6100000010000000500000006D49B51F3F74640A22AA6D24FFA4D4006D49B51F3F746403048FAB48AFC4D40DE019EB470FB46403048FAB48AFC4D40DE019EB470FB4640A22AA6D24FFA4D4006D49B51F3F74640A22AA6D24FFA4D40
31915	10830	45.455688000000002	45.474992	59.910387999999998	59.901665999999999	Центральная	0103000020E61000000100000005000000FF9600FC53BA464023F59ECA69F34D40FF9600FC53BA4640DE550F9887F44D404AEEB089CCBC4640DE550F9887F44D404AEEB089CCBC464023F59ECA69F34D40FF9600FC53BA464023F59ECA69F34D40
31699	10641	45.875155999999997	45.886906000000003	60.067070000000001	60.057357000000003	Спортивная	0103000020E61000000100000005000000F7729F1C05F046402D99637957074E40F7729F1C05F046407845F0BF95084E402750C42286F146407845F0BF95084E402750C42286F146402D99637957074E40F7729F1C05F046402D99637957074E40
26714	9907	46.386215999999997	46.414442000000001	60.000267000000001	59.983913999999999	Центральная	0103000020E610000001000000050000009198A0866F314740CC09DAE4F0FD4D409198A0866F3147404F22C2BF08004E405F0B7A6F0C3547404F22C2BF08004E405F0B7A6F0C354740CC09DAE4F0FD4D409198A0866F314740CC09DAE4F0FD4D40
31795	1019	45.975507	46.017090000000003	59.896075000000003	59.886830000000003	Почтовая	0103000020E610000001000000050000007102D369DDFC46404C8E3BA583F14D407102D369DDFC4640B1E1E995B2F24D40598B4F0130024740B1E1E995B2F24D40598B4F01300247404C8E3BA583F14D407102D369DDFC46404C8E3BA583F14D40
31911	10434	46.112886000000003	46.125821999999999	60.005212	60.000267000000001	Центральная	0103000020E610000001000000050000009016670C730E47404F22C2BF08004E409016670C730E4740FCC56CC9AA004E40048F6FEF1A104740FCC56CC9AA004E40048F6FEF1A1047404F22C2BF08004E409016670C730E47404F22C2BF08004E40
32164	53285	45.751376999999998	45.816459999999999	60.010613999999997	59.962871999999997	Центральная	0103000020E61000000100000005000000B9FB1C1F2DE04640F71DC3633FFB4D40B9FB1C1F2DE046409B70AFCC5B014E40FF3EE3C281E846409B70AFCC5B014E40FF3EE3C281E84640F71DC3633FFB4D40B9FB1C1F2DE04640F71DC3633FFB4D40
32073	53285	45.751376999999998	45.816459999999999	60.010613999999997	59.962871999999997	Лесная	0103000020E61000000100000005000000B9FB1C1F2DE04640F71DC3633FFB4D40B9FB1C1F2DE046409B70AFCC5B014E40FF3EE3C281E846409B70AFCC5B014E40FF3EE3C281E84640F71DC3633FFB4D40B9FB1C1F2DE04640F71DC3633FFB4D40
31674	1954	46.322679000000001	46.343493000000002	60.073898	60.059202999999997	Советская	0103000020E61000000100000005000000910DA48B4D2947409C69C2F693074E40910DA48B4D294740B29E5A7D75094E40D5B32094F72B4740B29E5A7D75094E40D5B32094F72B47409C69C2F693074E40910DA48B4D2947409C69C2F693074E40
32041	10318	45.815677999999998	45.841324999999998	59.807296000000001	59.796325000000003	Центральная	0103000020E610000001000000050000008908FF2268E846405DFE43FAEDE54D408908FF2268E846408718AF7955E74D405227A089B0EB46408718AF7955E74D405227A089B0EB46405DFE43FAEDE54D408908FF2268E846405DFE43FAEDE54D40
32072	53286	46.636792999999997	46.652441000000003	59.880468999999998	59.871856999999999	Центральная	0103000020E610000001000000050000002EA9DA6E82514740F3E49A0299EF4D402EA9DA6E8251474027124C35B3F04D40E7C8CA2F8353474027124C35B3F04D40E7C8CA2F83534740F3E49A0299EF4D402EA9DA6E82514740F3E49A0299EF4D40
31968	9549	45.802725000000002	45.816316	59.986308000000001	59.980370999999998	Дорожная	0103000020E610000001000000050000003F575BB1BFE64640317903CC7CFD4D403F575BB1BFE646403FE42D573FFE4D40CC99ED0A7DE846403FE42D573FFE4D40CC99ED0A7DE84640317903CC7CFD4D403F575BB1BFE64640317903CC7CFD4D40
26543	10490	46.148997999999999	46.171258999999999	60.039192999999997	60.033859	Центральная	0103000020E61000000100000005000000AF95D05D121347406FD6E07D55044E40AF95D05D12134740B69DB64604054E40A5129ED0EB154740B69DB64604054E40A5129ED0EB1547406FD6E07D55044E40AF95D05D121347406FD6E07D55044E40
31729	9191	38.624844000000003	38.653294000000002	60.463445999999998	60.452004000000002	Центральная	0103000020E61000000100000005000000098D60E3FA4F4340A2D45E44DB394E40098D60E3FA4F434023BBD232523B4E40265646239F53434023BBD232523B4E40265646239F534340A2D45E44DB394E40098D60E3FA4F4340A2D45E44DB394E40
31728	9109	38.553472999999997	38.585687	59.961440000000003	59.946004000000002	Слободская	0103000020E61000000100000005000000081C0934D84643404EF1B8A816F94D40081C0934D84643407B88467710FB4D409F58A7CAF74A43407B88467710FB4D409F58A7CAF74A43404EF1B8A816F94D40081C0934D84643404EF1B8A816F94D40
26700	8629	38.364935000000003	38.393383999999998	59.769506	59.756745000000002	Клубный переулок	0103000020E610000001000000050000003815A930B62E4340AD342905DDE04D403815A930B62E4340B309302C7FE24D4084622B685A324340B309302C7FE24D4084622B685A324340AD342905DDE04D403815A930B62E4340AD342905DDE04D40
32031	8990	38.783558999999997	38.816490999999999	59.654148999999997	59.636713999999998	Советская	0103000020E6100000010000000500000044BE4BA94B644340E27327D87FD14D4044BE4BA94B64434005DB8827BBD34D403A3DEFC68268434005DB8827BBD34D403A3DEFC682684340E27327D87FD14D4044BE4BA94B644340E27327D87FD14D40
32029	9095	38.479793000000001	38.498936	59.855172000000003	59.849857999999998	Центральная	0103000020E61000000100000005000000C4EC65DB693D43403A1F9E25C8EC4D40C4EC65DB693D43403B3AAE4676ED4D4006668522DD3F43403B3AAE4676ED4D4006668522DD3F43403A1F9E25C8EC4D40C4EC65DB693D43403A1F9E25C8EC4D40
31964	8732	38.454631999999997	38.462878000000003	59.995731999999997	59.992140999999997	Ленина	0103000020E6100000010000000500000087DBA161313A4340A702EE79FEFE4D4087DBA161313A434053CA6B2574FF4D40DA0418963F3B434053CA6B2574FF4D40DA0418963F3B4340A702EE79FEFE4D4087DBA161313A4340A702EE79FEFE4D40
31965	8835	38.759098000000002	38.793674000000003	59.884929999999997	59.862628000000001	Захарьинская	0103000020E61000000100000005000000C13A8E1F2A614340944E24986AEE4D40C13A8E1F2A614340E89FE06245F14D40BFD7101C97654340E89FE06245F14D40BFD7101C97654340944E24986AEE4D40C13A8E1F2A614340944E24986AEE4D40
26532	9249	38.668861999999997	38.675384000000001	60.302681999999997	60.299815000000002	Головинская	0103000020E61000000100000005000000C1C41F459D554340D5EC815660264E40C1C41F459D5543403F8BA548BE264E40EF1EA0FB725643403F8BA548BE264E40EF1EA0FB72564340D5EC815660264E40C1C41F459D554340D5EC815660264E40
31753	8124	38.554775999999997	38.581249	60.157755000000002	60.142679999999999	Центральная	0103000020E61000000100000005000000874D64E6024743408AE5965643124E40874D64E602474340E7E3DA5031144E4096EA025E664A4340E7E3DA5031144E4096EA025E664A43408AE5965643124E40874D64E6024743408AE5965643124E40
31680	8398	38.327080000000002	38.39987	59.876489999999997	59.829811999999997	Уверова	0103000020E610000001000000050000007D96E7C1DD29434007EA944737EA4D407D96E7C1DD294340B1A206D330F04D406553AEF02E334340B1A206D330F04D406553AEF02E33434007EA944737EA4D407D96E7C1DD29434007EA944737EA4D40
31849	8398	38.327080000000002	38.39987	59.876489999999997	59.829811999999997	Советская	0103000020E610000001000000050000007D96E7C1DD29434007EA944737EA4D407D96E7C1DD294340B1A206D330F04D406553AEF02E334340B1A206D330F04D406553AEF02E33434007EA944737EA4D407D96E7C1DD29434007EA944737EA4D40
26694	8398	38.327080000000002	38.39987	59.876489999999997	59.829811999999997	Гагарина	0103000020E610000001000000050000007D96E7C1DD29434007EA944737EA4D407D96E7C1DD294340B1A206D330F04D406553AEF02E334340B1A206D330F04D406553AEF02E33434007EA944737EA4D407D96E7C1DD29434007EA944737EA4D40
31808	8643	38.241362000000002	38.257801999999998	59.774684000000001	59.761938999999998	Центральная	0103000020E61000000100000005000000A33F34F3E41E43400246973787E14D40A33F34F3E41E4340035E66D828E34D40F46BEBA7FF204340035E66D828E34D40F46BEBA7FF2043400246973787E14D40A33F34F3E41E43400246973787E14D40
31723	7713	38.246645000000001	38.267054000000002	59.879714999999997	59.861426000000002	Центральная	0103000020E61000000100000005000000685C3810921F434049F6083543EE4D40685C3810921F43407B6649809AF04D400C2252D32E2243407B6649809AF04D400C2252D32E22434049F6083543EE4D40685C3810921F434049F6083543EE4D40
31967	8933	38.753959000000002	38.804479999999998	59.926656999999999	59.908749999999998	Преображенского	0103000020E610000001000000050000002FC37FBA81604340B81E85EB51F44D402FC37FBA8160434003CE52B29CF64D409E245D33F966434003CE52B29CF64D409E245D33F9664340B81E85EB51F44D402FC37FBA81604340B81E85EB51F44D40
31790	8766	38.152006999999998	38.164566000000001	59.981357000000003	59.973748000000001	Центральная	0103000020E61000000100000005000000ACE122F774134340D04543C6A3FC4D40ACE122F774134340B0592E1B9DFD4D404B04AA7F10154340B0592E1B9DFD4D404B04AA7F10154340D04543C6A3FC4D40ACE122F774134340D04543C6A3FC4D40
31873	7857	37.378881	37.418874000000002	59.155797999999997	59.140540999999999	Школьная площадь	0103000020E61000000100000005000000B309302C7FB04240A25F5B3FFD914D40B309302C7FB042401F645930F1934D408692C9A99DB542401F645930F1934D408692C9A99DB54240A25F5B3FFD914D40B309302C7FB04240A25F5B3FFD914D40
31900	8080	37.267158000000002	37.288933	59.283804000000003	59.272866999999998	Заводская	0103000020E61000000100000005000000B16EBC3B32A242402D944C4EEDA24D40B16EBC3B32A24240AC3C81B053A44D401ADEACC1FBA44240AC3C81B053A44D401ADEACC1FBA442402D944C4EEDA24D40B16EBC3B32A242402D944C4EEDA24D40
32078	53289	36.484752	36.506698	59.587429	59.578094	Центральная	0103000020E61000000100000005000000D655815A0C3E4240C501F4FBFEC94D40D655815A0C3E42406ADC9BDF30CB4D406C79E57ADB4042406ADC9BDF30CB4D406C79E57ADB404240C501F4FBFEC94D40D655815A0C3E4240C501F4FBFEC94D40
26672	8267	37.162531000000001	37.180084000000001	59.356226999999997	59.349397000000003	Городская	0103000020E6100000010000000500000008CBD8D0CD9442400729780AB9AC4D4008CBD8D0CD944240E179A9D898AD4D40354415FE0C974240E179A9D898AD4D40354415FE0C9742400729780AB9AC4D4008CBD8D0CD9442400729780AB9AC4D40
26517	8361	37.182366000000002	37.200592	59.199089999999998	59.192993000000001	переулок Рабочий	0103000020E6100000010000000500000080F3E2C457974240B0AD9FFEB3984D4080F3E2C457974240F67AF7C77B994D406CEBA7FFAC994240F67AF7C77B994D406CEBA7FFAC994240B0AD9FFEB3984D4080F3E2C457974240B0AD9FFEB3984D40
26671	8252	36.701146999999999	36.734636000000002	59.334429	59.321300000000001	Центральная	0103000020E610000001000000050000002158552FBF594240371AC05B20A94D402158552FBF594240C0EAC891CEAA4D406D3B6D8D085E4240C0EAC891CEAA4D406D3B6D8D085E4240371AC05B20A94D402158552FBF594240371AC05B20A94D40
31837	53267	37.092291000000003	37.103808000000001	59.215034000000003	59.207788999999998	Строителей	0103000020E610000001000000050000008A5B0531D08B4240F9BB77D4989A4D408A5B0531D08B424098C3EE3B869B4D4016889E94498D424098C3EE3B869B4D4016889E94498D4240F9BB77D4989A4D408A5B0531D08B4240F9BB77D4989A4D40
31777	52618	37.409962999999998	37.442419000000001	59.182017000000002	59.170720000000003	Новая	0103000020E61000000100000005000000F7C8E6AA79B44240F6622827DA954D40F7C8E6AA79B44240742843554C974D408410902FA1B84240742843554C974D408410902FA1B84240F6622827DA954D40F7C8E6AA79B44240F6622827DA954D40
26552	702	37.101759999999999	37.209243000000001	59.219330999999997	59.193204999999999	Энтузиастов	0103000020E610000001000000050000003E05C078068D42403B3602F1BA984D403E05C078068D4240DEFFC709139C4D405EF58079C89A4240DEFFC709139C4D405EF58079C89A42403B3602F1BA984D403E05C078068D42403B3602F1BA984D40
31937	702	37.101759999999999	37.209243000000001	59.219330999999997	59.193204999999999	Чехова	0103000020E610000001000000050000003E05C078068D42403B3602F1BA984D403E05C078068D4240DEFFC709139C4D405EF58079C89A4240DEFFC709139C4D405EF58079C89A42403B3602F1BA984D403E05C078068D42403B3602F1BA984D40
26461	702	37.101759999999999	37.209243000000001	59.219330999999997	59.193204999999999	Кирова	0103000020E610000001000000050000003E05C078068D42403B3602F1BA984D403E05C078068D4240DEFFC709139C4D405EF58079C89A4240DEFFC709139C4D405EF58079C89A42403B3602F1BA984D403E05C078068D42403B3602F1BA984D40
26668	8190	37.004733000000002	37.022474000000003	59.527692000000002	59.518906000000001	Ветеранов	0103000020E61000000100000005000000221B48179B8042405ED905836BC24D40221B48179B804240302E55698BC34D405281936DE0824240302E55698BC34D405281936DE08242405ED905836BC24D40221B48179B8042405ED905836BC24D40
26511	7999	37.339390999999999	37.358687000000003	59.288753999999997	59.280332999999999	Центральная	0103000020E6100000010000000500000043C70E2A71AB4240AA7EA5F3E1A34D4043C70E2A71AB42406A4B1DE4F5A44D400C40A374E9AD42406A4B1DE4F5A44D400C40A374E9AD4240AA7EA5F3E1A34D4043C70E2A71AB4240AA7EA5F3E1A34D40
26430	7940	36.500337999999999	36.527538999999997	59.548842	59.519043000000003	Центральная	0103000020E61000000100000005000000187959130B404240DF1B430070C24D40187959130B404240EB55647440C64D40A92EE06586434240EB55647440C64D40A92EE06586434240DF1B430070C24D40187959130B404240DF1B430070C24D40
31889	596	39.974859000000002	39.993831999999998	58.972045999999999	58.965235999999997	Центральная	0103000020E610000001000000050000000B9B012EC8FC4340FF756EDA8C7B4D400B9B012EC8FC4340931ADA006C7C4D40F0DB10E335FF4340931ADA006C7C4D40F0DB10E335FF4340FF756EDA8C7B4D400B9B012EC8FC4340FF756EDA8C7B4D40
31860	1551	40.263083999999999	40.277267999999999	59.023567	59.018796000000002	сосновая	0103000020E61000000100000005000000E90C8CBCAC214440D7A546E867824D40E90C8CBCAC214440E621533E04834D40191D90847D234440E621533E04834D40191D90847D234440D7A546E867824D40E90C8CBCAC214440D7A546E867824D40
31696	1551	40.263083999999999	40.277267999999999	59.023567	59.018796000000002	Сосновая	0103000020E61000000100000005000000E90C8CBCAC214440D7A546E867824D40E90C8CBCAC214440E621533E04834D40191D90847D234440E621533E04834D40191D90847D234440D7A546E867824D40E90C8CBCAC214440D7A546E867824D40
31890	692	40.039079999999998	40.050884000000003	58.936610999999999	58.930141999999996	Полевая	0103000020E61000000100000005000000BEF6CC920005444069519FE40E774D40BEF6CC9200054440740987DEE2774D40E1F1ED5D83064440740987DEE2774D40E1F1ED5D8306444069519FE40E774D40BEF6CC920005444069519FE40E774D40
32075	53288	40.216676999999997	40.237220999999998	58.969248999999998	58.950037999999999	Школьная	0103000020E61000000100000005000000CF656A12BC1B444087FA5DD89A794D40CF656A12BC1B44402157EA59107C4D405376FA415D1E44402157EA59107C4D405376FA415D1E444087FA5DD89A794D40CF656A12BC1B444087FA5DD89A794D40
26567	7354	40.009166	40.023359999999997	58.867199999999997	58.860574	Центральная	0103000020E61000000100000005000000191EFB592C014440DAE4F049276E4D40191EFB592C014440AC8BDB68006F4D406C04E275FD024440AC8BDB68006F4D406C04E275FD024440DAE4F049276E4D40191EFB592C014440DAE4F049276E4D40
26467	187	40.391461999999997	40.404415999999998	58.722827000000002	58.714748	Центральная	0103000020E6100000010000000500000039D0436D1B324440D270CADC7C5B4D4039D0436D1B32444039D55A98855C4D4054FD4AE7C333444039D55A98855C4D4054FD4AE7C3334440D270CADC7C5B4D4039D0436D1B324440D270CADC7C5B4D40
26628	410	40.96978	40.997070000000001	58.763976	58.751461999999997	Советская	0103000020E610000001000000050000004E2844C0217C4440E71725E82F604D404E2844C0217C4440E6762FF7C9614D404FE960FD9F7F4440E6762FF7C9614D404FE960FD9F7F4440E71725E82F604D404E2844C0217C4440E71725E82F604D40
31716	33	40.261161999999999	40.283377000000002	58.802376000000002	58.795164	Молодежная	0103000020E610000001000000050000009E7AA4C16D214440707A17EFC7654D409E7AA4C16D214440338CBB41B4664D4024B891B245244440338CBB41B4664D4024B891B245244440707A17EFC7654D409E7AA4C16D214440707A17EFC7654D40
26402	307	40.269705000000002	40.295620999999997	58.644379000000001	58.629835999999997	Школьная	0103000020E61000000100000005000000AA4885B185224440F6EB4E779E504D40AA4885B185224440569DD5027B524D406281AFE8D6254440569DD5027B524D406281AFE8D6254440F6EB4E779E504D40AA4885B185224440F6EB4E779E504D40
31888	1844	40.134517000000002	40.145809	59.010378000000003	59.005234000000002	Центральная	0103000020E61000000100000005000000C6E061DA37114440E469F981AB804D40C6E061DA37114440884CF91054814D40323B8BDEA9124440884CF91054814D40323B8BDEA9124440E469F981AB804D40C6E061DA37114440E469F981AB804D40
31761	548	39.755096000000002	39.767994999999999	58.967941000000003	58.962451999999999	Новая	0103000020E6100000010000000500000093AB58FCA6E0434022FC8BA0317B4D4093AB58FCA6E0434091BA9D7DE57B4D40EA3E00A94DE2434091BA9D7DE57B4D40EA3E00A94DE2434022FC8BA0317B4D4093AB58FCA6E0434022FC8BA0317B4D40
31980	53278	40.247238000000003	40.256166999999998	58.835076000000001	58.829445	Речная	0103000020E610000001000000050000000B2AAA7EA51F4440556AF6402B6A4D400B2AAA7EA51F444056D636C5E36A4D403FA88B14CA20444056D636C5E36A4D403FA88B14CA204440556AF6402B6A4D400B2AAA7EA51F4440556AF6402B6A4D40
31768	4103	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Революции	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
31960	4103	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Рабочая	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
31947	4103	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Карла Маркса	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
31738	4103	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	К.Маркса	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
26704	4103	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Горького	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
26528	4103	40.210720999999999	40.270127000000002	58.891134999999998	58.859935999999998	Гагарина	0103000020E610000001000000050000004BCADDE7F81A444097530262126E4D404BCADDE7F81A444015A930B610724D40206283859322444015A930B610724D40206283859322444097530262126E4D404BCADDE7F81A444097530262126E4D40
31962	4384	41.025188	41.074685000000002	58.835476	58.801130999999998	пер.Свободы	0103000020E610000001000000050000003620425C39834440E867EA758B664D403620425C39834440E44BA8E0F06A4D403A4030478F894440E44BA8E0F06A4D403A4030478F894440E867EA758B664D403620425C39834440E867EA758B664D40
26500	4384	41.025188	41.074685000000002	58.835476	58.801130999999998	Юбилейная	0103000020E610000001000000050000003620425C39834440E867EA758B664D403620425C39834440E44BA8E0F06A4D403A4030478F894440E44BA8E0F06A4D403A4030478F894440E867EA758B664D403620425C39834440E867EA758B664D40
31686	4384	41.025188	41.074685000000002	58.835476	58.801130999999998	24 Партсъезда	0103000020E610000001000000050000003620425C39834440E867EA758B664D403620425C39834440E44BA8E0F06A4D403A4030478F894440E44BA8E0F06A4D403A4030478F894440E867EA758B664D403620425C39834440E867EA758B664D40
31710	1669	40.447032	40.467567000000003	59.022492	59.017285999999999	Центральная	0103000020E61000000100000005000000FB21365838394440DE567A6D36824D40FB21365838394440F8359204E1824D402CD8463CD93B4440F8359204E1824D402CD8463CD93B4440DE567A6D36824D40FB21365838394440DE567A6D36824D40
31796	6985	40.786658000000003	40.810929999999999	58.803097999999999	58.794165999999997	Центральная	0103000020E6100000010000000500000082919735B16444402DCC423BA7654D4082919735B1644440D3BD4EEACB664D4032ACE28DCC674440D3BD4EEACB664D4032ACE28DCC6744402DCC423BA7654D4082919735B16444402DCC423BA7654D40
26696	3963	37.535950999999997	37.562362	61.226472999999999	61.219313	Школьная	0103000020E6100000010000000500000016A1D80A9AC44240384BC972129C4E4016A1D80A9AC44240A8363811FD9C4E40AF415F7AFBC74240A8363811FD9C4E40AF415F7AFBC74240384BC972129C4E4016A1D80A9AC44240384BC972129C4E40
31817	4293	36.533566	36.546348999999999	61.116186999999996	61.107711000000002	Молодёжная	0103000020E61000000100000005000000F72004E44B444240B1355B79C98D4E40F72004E44B444240349C3237DF8E4E40E59997C3EE454240349C3237DF8E4E40E59997C3EE454240B1355B79C98D4E40F72004E44B444240B1355B79C98D4E40
31749	4320	36.543546999999997	36.575139999999998	61.264006999999999	61.256622	Набережная	0103000020E61000000100000005000000616BB6F29245424091B75CFDD8A04E40616BB6F29245424021753BFBCAA14E408B4F01309E49424021753BFBCAA14E408B4F01309E49424091B75CFDD8A04E40616BB6F29245424091B75CFDD8A04E40
26454	5511	37.789563999999999	37.805391999999998	60.786020999999998	60.779257999999999	Архангельская	0103000020E61000000100000005000000AA0CE36E10E54240BC92E4B9BE634E40AA0CE36E10E542400F7C0C569C644E40E23AC61517E742400F7C0C569C644E40E23AC61517E74240BC92E4B9BE634E40AA0CE36E10E54240BC92E4B9BE634E40
31820	4111	36.144137999999998	36.155698999999998	61.013210000000001	61.007719999999999	Школьная	0103000020E61000000100000005000000300E2E1D7312424037C30DF8FC804E40300E2E1D7312424076FD82DDB0814E408C82E0F1ED13424076FD82DDB0814E408C82E0F1ED13424037C30DF8FC804E40300E2E1D7312424037C30DF8FC804E40
31741	4210	36.336888999999999	36.355950999999997	60.995956	60.989336999999999	Архангельский тракт	0103000020E61000000100000005000000EAB0C22D1F2B424083DC4598A27E4E40EAB0C22D1F2B4240A320787C7B7F4E403FFD67CD8F2D4240A320787C7B7F4E403FFD67CD8F2D424083DC4598A27E4E40EAB0C22D1F2B424083DC4598A27E4E40
31720	5391	37.059466999999998	37.089058000000001	60.846259000000003	60.834949000000002	Школьная	0103000020E610000001000000050000007A185A9D9C874240F969DC9BDF6A4E407A185A9D9C8742400C790437526C4E403DB9A640668B42400C790437526C4E403DB9A640668B4240F969DC9BDF6A4E407A185A9D9C874240F969DC9BDF6A4E40
31866	3694	35.550944000000001	35.572584999999997	60.859335999999999	60.845655000000001	Архангельский тракт	0103000020E61000000100000005000000B6F63E5585C6414075594C6C3E6C4E40B6F63E5585C641404223D8B8FE6D4E400F971C774AC941404223D8B8FE6D4E400F971C774AC9414075594C6C3E6C4E40B6F63E5585C6414075594C6C3E6C4E40
31669	4574	36.605502999999999	36.655081000000003	61.386522999999997	61.377473000000002	Гагарина	0103000020E61000000100000005000000A0504F1F814D4240BF0F070951B04E40A0504F1F814D42406E13EE9579B14E40919DB7B1D95342406E13EE9579B14E40919DB7B1D9534240BF0F070951B04E40A0504F1F814D4240BF0F070951B04E40
31707	5075	36.76296	36.775635000000001	60.756154000000002	60.749001999999997	Центральная	0103000020E61000000100000005000000FD135CACA8614240BD512B4CDF5F4E40FD135CACA8614240AB5E7EA7C9604E400551F70148634240AB5E7EA7C9604E400551F70148634240BD512B4CDF5F4E40FD135CACA8614240BD512B4CDF5F4E40
31703	3777	35.741081999999999	35.750864	60.834378999999998	60.827029000000003	Архангельский тракт	0103000020E61000000100000005000000BFD364C6DBDE4140FBEB1516DC694E40BFD364C6DBDE41400EBC5AEECC6A4E4033DFC14F1CE041400EBC5AEECC6A4E4033DFC14F1CE04140FBEB1516DC694E40BFD364C6DBDE4140FBEB1516DC694E40
31897	5478	37.658886000000003	37.695428999999997	60.851931	60.829493999999997	Калинина	0103000020E6100000010000000500000069E55E6056D44240361D01DC2C6A4E4069E55E6056D442406BB933130C6D4E4051D845D103D942406BB933130C6D4E4051D845D103D94240361D01DC2C6A4E4069E55E6056D44240361D01DC2C6A4E40
26441	4005	36.010271000000003	36.023997000000001	60.564078000000002	60.556316000000002	Почтовая	0103000020E61000000100000005000000728C648F50014240EB1ED95C35474E40728C648F50014240513239B533484E40DF196D5512034240513239B533484E40DF196D5512034240EB1ED95C35474E40728C648F50014240EB1ED95C35474E40
26614	3870	35.984417000000001	36.018040999999997	60.877422000000003	60.85718	Центральная	0103000020E610000001000000050000002F50526001FE414084640113B86D4E402F50526001FE41403D65355D4F704E405A7EE02A4F0242403D65355D4F704E405A7EE02A4F02424084640113B86D4E402F50526001FE414084640113B86D4E40
32000	4471	36.716633999999999	36.732731999999999	61.168326	61.160662000000002	Школьная	0103000020E61000000100000005000000D099B4A9BA5B4240E0DA899290944E40D099B4A9BA5B42408388D4B48B954E40C85D8429CA5D42408388D4B48B954E40C85D8429CA5D4240E0DA899290944E40D099B4A9BA5B4240E0DA899290944E40
31856	3957	35.983159999999998	36.003956000000002	60.700000000000003	60.694234999999999	Мира	0103000020E61000000100000005000000205ED72FD8FD4140895E46B1DC584E40205ED72FD8FD41409A99999999594E40BE4F55A1810042409A99999999594E40BE4F55A181004240895E46B1DC584E40205ED72FD8FD4140895E46B1DC584E40
32049	4056	36.077851000000003	36.091056000000002	60.934671999999999	60.924985	Центральная	0103000020E61000000100000005000000FF7A8505F7094240312592E865764E40FF7A8505F7094240533E0455A3774E40630D17B9A70B4240533E0455A3774E40630D17B9A70B4240312592E865764E40FF7A8505F7094240312592E865764E40
26610	4895	36.827916999999999	36.862341000000001	60.921998000000002	60.908155999999998	Спортивная	0103000020E61000000100000005000000B6662B2FF969424045D5AF743E744E40B6662B2FF96942401C7DCC0704764E40FE7F9C30616E42401C7DCC0704764E40FE7F9C30616E424045D5AF743E744E40B6662B2FF969424045D5AF743E744E40
26621	4895	36.827916999999999	36.862341000000001	60.921998000000002	60.908155999999998	Архангельский тракт	0103000020E61000000100000005000000B6662B2FF969424045D5AF743E744E40B6662B2FF96942401C7DCC0704764E40FE7F9C30616E42401C7DCC0704764E40FE7F9C30616E424045D5AF743E744E40B6662B2FF969424045D5AF743E744E40
31827	4837	36.742317	36.794707000000002	60.927027000000002	60.914459000000001	Архангельский тракт	0103000020E61000000100000005000000E621533E045F4240354415FE0C754E40E621533E045F424027C11BD2A8764E407E737FF5B865424027C11BD2A8764E407E737FF5B8654240354415FE0C754E40E621533E045F4240354415FE0C754E40
32093	53293	35.177739000000003	38.413722	61.604447	60.411296999999998	улица Школьная	0103000020E61000000100000005000000A41CCC26C0964140B1F84D61A5344E40A41CCC26C09641402995F0845ECD4E405FD1ADD7F43443402995F0845ECD4E405FD1ADD7F4344340B1F84D61A5344E40A41CCC26C0964140B1F84D61A5344E40
31702	51294	36.396617999999997	36.470460000000003	61.033639000000001	60.993940000000002	Шевченко	0103000020E61000000100000005000000A180ED60C4324240D717096D397F4E40A180ED60C4324240616F62484E844E40C0098508383C4240616F62484E844E40C0098508383C4240D717096D397F4E40A180ED60C4324240D717096D397F4E40
26578	51294	36.396617999999997	36.470460000000003	61.033639000000001	60.993940000000002	Проспект Ленина	0103000020E61000000100000005000000A180ED60C4324240D717096D397F4E40A180ED60C4324240616F62484E844E40C0098508383C4240616F62484E844E40C0098508383C4240D717096D397F4E40A180ED60C4324240D717096D397F4E40
32077	51294	36.396617999999997	36.470460000000003	61.033639000000001	60.993940000000002	Луначарского проспект	0103000020E61000000100000005000000A180ED60C4324240D717096D397F4E40A180ED60C4324240616F62484E844E40C0098508383C4240616F62484E844E40C0098508383C4240D717096D397F4E40A180ED60C4324240D717096D397F4E40
32063	51294	36.396617999999997	36.470460000000003	61.033639000000001	60.993940000000002	Ленинградский тракт	0103000020E61000000100000005000000A180ED60C4324240D717096D397F4E40A180ED60C4324240616F62484E844E40C0098508383C4240616F62484E844E40C0098508383C4240D717096D397F4E40A180ED60C4324240D717096D397F4E40
26473	51278	36.875061000000002	36.904535000000003	60.859265999999998	60.844952999999997	Болотная	0103000020E61000000100000005000000A680B4FF017042401BD47E6B276C4E40A680B4FF017042404948A46DFC6D4E402F8B89CDC77342404948A46DFC6D4E402F8B89CDC77342401BD47E6B276C4E40A680B4FF017042401BD47E6B276C4E40
26438	3883	36.038908999999997	36.050460999999999	60.900520999999998	60.888922999999998	Школьная	0103000020E61000000100000005000000914259F8FA044240C3D4963AC8714E40914259F8FA0442403C2EAA4544734E409A5C8C81750642403C2EAA4544734E409A5C8C8175064240C3D4963AC8714E40914259F8FA044240C3D4963AC8714E40
31743	4655	36.538238	36.557631999999998	60.959477	60.952894000000001	Школьная	0103000020E6100000010000000500000073BB97FBE4444240FE463B6EF8794E4073BB97FBE4444240D1217024D07A4E40FE99417C60474240D1217024D07A4E40FE99417C60474240FE463B6EF8794E4073BB97FBE4444240FE463B6EF8794E40
32058	53281	37.093395999999998	37.150817000000004	60.752616000000003	60.722185000000003	улица Лесная	0103000020E61000000100000005000000E2C96E66F48B4240B554DE8E705C4E40E2C96E66F48B4240223999B855604E402657B1F84D934240223999B855604E402657B1F84D934240B554DE8E705C4E40E2C96E66F48B4240B554DE8E705C4E40
32138	53281	37.093395999999998	37.150817000000004	60.752616000000003	60.722185000000003	Советский проспект	0103000020E61000000100000005000000E2C96E66F48B4240B554DE8E705C4E40E2C96E66F48B4240223999B855604E402657B1F84D934240223999B855604E402657B1F84D934240B554DE8E705C4E40E2C96E66F48B4240B554DE8E705C4E40
31942	4403	36.625320000000002	36.641831000000003	61.25609	61.243206999999998	Центральная	0103000020E6100000010000000500000072C45A7C0A50424042942F68219F4E4072C45A7C0A504240946A9F8EC7A04E408D47A98427524240946A9F8EC7A04E408D47A9842752424042942F68219F4E4072C45A7C0A50424042942F68219F4E40
31892	5284	37.112450000000003	37.132840999999999	60.800382999999997	60.795535999999998	Заречная	0103000020E61000000100000005000000B537F8C2648E42403465A71FD4654E40B537F8C2648E42401EA33CF372664E40B24813EF009142401EA33CF372664E40B24813EF009142403465A71FD4654E40B537F8C2648E42403465A71FD4654E40
32010	28957	39.436543999999998	39.448923000000001	59.559334	59.551974999999999	Школьная	0103000020E61000000100000005000000ECA17DACE0B74340D49AE61DA7C64D40ECA17DACE0B743403BC5AA4198C74D400BB6114F76B943403BC5AA4198C74D400BB6114F76B94340D49AE61DA7C64D40ECA17DACE0B74340D49AE61DA7C64D40
31773	29839	39.405273999999999	39.419924999999999	59.146366	59.135610999999997	Центральная	0103000020E61000000100000005000000A5F5B704E0B343402AFD84B35B914D40A5F5B704E0B34340889FFF1EBC924D40EBE2361AC0B54340889FFF1EBC924D40EBE2361AC0B543402AFD84B35B914D40A5F5B704E0B343402AFD84B35B914D40
26491	29723	39.287747000000003	39.30292	59.198666000000003	59.190845000000003	Зеленая	0103000020E61000000100000005000000D542C9E4D4A4434075CDE49B6D984D40D542C9E4D4A44340E06932E36D994D40F4A62215C6A64340E06932E36D994D40F4A62215C6A6434075CDE49B6D984D40D542C9E4D4A4434075CDE49B6D984D40
79358	61538	39.567850999999997	39.588825999999997	59.200761999999997	59.189287	Молодежная	0103000020E610000001000000050000001D007157AFC843406B47718E3A984D401D007157AFC84340C823B891B2994D406A847EA65ECB4340C823B891B2994D406A847EA65ECB43406B47718E3A984D401D007157AFC843406B47718E3A984D40
26650	29269	39.33887	39.344161	59.419758000000002	59.416887000000003	Первомайская	0103000020E610000001000000050000003ACC971760AB434054909F8D5CB54D403ACC971760AB4340001E51A1BAB54D4082C7B7770DAC4340001E51A1BAB54D4082C7B7770DAC434054909F8D5CB54D403ACC971760AB434054909F8D5CB54D40
26448	27721	39.059288000000002	39.088123000000003	59.418087	59.408704999999998	Центральная	0103000020E61000000100000005000000CB85CABF96874340185B087250B44D40CB85CABF96874340FEF0F3DF83B54D4041834D9D478B4340FEF0F3DF83B54D4041834D9D478B4340185B087250B44D40CB85CABF96874340185B087250B44D40
31834	29549	39.583022999999997	39.601295	59.151811000000002	59.144021000000002	Центральная	0103000020E610000001000000050000006CE8667FA0CA4340F777B6476F924D406CE8667FA0CA43402716F88A6E934D40C91F0C3CF7CC43402716F88A6E934D40C91F0C3CF7CC4340F777B6476F924D406CE8667FA0CA4340F777B6476F924D40
31896	29665	39.772252999999999	39.782252	59.050930000000001	59.043579000000001	Школьный переулок	0103000020E61000000100000005000000739EB12FD9E243406DE525FF93854D40739EB12FD9E243405131CEDF84864D40849D62D520E443405131CEDF84864D40849D62D520E443406DE525FF93854D40739EB12FD9E243406DE525FF93854D40
32005	28367	39.500208000000001	39.525190000000002	59.382334	59.372937	Центральная	0103000020E610000001000000050000004A99D4D006C04340F33B4D66BCAF4D404A99D4D006C043400E130D52F0B04D40D717096D39C343400E130D52F0B04D40D717096D39C34340F33B4D66BCAF4D404A99D4D006C04340F33B4D66BCAF4D40
31853	28758	39.321235999999999	39.350332999999999	59.624229999999997	59.611472999999997	Советская	0103000020E610000001000000050000002026E1421EA9434089B14CBF44CE4D402026E1421EA943404E97C5C4E6CF4D40D3DA34B6D7AC43404E97C5C4E6CF4D40D3DA34B6D7AC434089B14CBF44CE4D402026E1421EA9434089B14CBF44CE4D40
31830	28874	39.064928999999999	39.072088999999998	59.768504999999998	59.762405999999999	Центральная	0103000020E61000000100000005000000EFC7ED974F8843401823128596E14D40EFC7ED974F884340FFE7305F5EE24D405FB35C363A894340FFE7305F5EE24D405FB35C363A8943401823128596E14D40EFC7ED974F8843401823128596E14D40
31666	53246	39.660691999999997	39.694693000000001	59.301951000000003	59.281343999999997	Парковая	0103000020E610000001000000050000004A5D328E91D443408176871403A44D404A5D328E91D443404CFF9254A6A64D404CE141B3EBD843404CFF9254A6A64D404CE141B3EBD843408176871403A44D404A5D328E91D443408176871403A44D40
32137	53246	39.660691999999997	39.694693000000001	59.301951000000003	59.281343999999997	Мира	0103000020E610000001000000050000004A5D328E91D443408176871403A44D404A5D328E91D443404CFF9254A6A64D404CE141B3EBD843404CFF9254A6A64D404CE141B3EBD843408176871403A44D404A5D328E91D443408176871403A44D40
31839	53246	39.660691999999997	39.694693000000001	59.301951000000003	59.281343999999997	Емельянова	0103000020E610000001000000050000004A5D328E91D443408176871403A44D404A5D328E91D443404CFF9254A6A64D404CE141B3EBD843404CFF9254A6A64D404CE141B3EBD843408176871403A44D404A5D328E91D443408176871403A44D40
31959	28298	39.248157999999997	39.269871000000002	59.400061999999998	59.388209000000003	Центральная	0103000020E61000000100000005000000D11E2FA4C39F4340A6811FD5B0B14D40D11E2FA4C39F4340A92F4B3B35B34D40C59107228BA24340A92F4B3B35B34D40C59107228BA24340A6811FD5B0B14D40D11E2FA4C39F4340A6811FD5B0B14D40
31829	28527	39.617294000000001	39.660575000000001	59.374808000000002	59.355525999999998	Школьная	0103000020E610000001000000050000002E02637D03CF434058703FE081AD4D402E02637D03CF4340BC2363B5F9AF4D4011C7BAB88DD44340BC2363B5F9AF4D4011C7BAB88DD4434058703FE081AD4D402E02637D03CF434058703FE081AD4D40
26494	28181	39.656002000000001	39.688009000000001	59.444695000000003	59.423859999999998	Ленина	0103000020E61000000100000005000000280EA0DFF7D34340910A630B41B64D40280EA0DFF7D34340EDD808C4EBB84D40452DCDAD10D84340EDD808C4EBB84D40452DCDAD10D84340910A630B41B64D40280EA0DFF7D34340910A630B41B64D40
26658	29742	39.127612999999997	39.155785000000002	59.246814000000001	59.224378000000002	Железнодорожная	0103000020E61000000100000005000000B0C56E9F5590434090F8156BB89C4D40B0C56E9F55904340F418E599979F4D408B1A4CC3F0934340F418E599979F4D408B1A4CC3F093434090F8156BB89C4D40B0C56E9F5590434090F8156BB89C4D40
32006	28572	39.649894000000003	39.661734000000003	59.290095999999998	59.286335999999999	Садовая	0103000020E61000000100000005000000EEEE01BA2FD343406FD575A8A6A44D40EEEE01BA2FD34340A759A0DD21A54D405D5320B3B3D44340A759A0DD21A54D405D5320B3B3D443406FD575A8A6A44D40EEEE01BA2FD343406FD575A8A6A44D40
31735	28449	39.692402000000001	39.719684000000001	59.196620000000003	59.184516000000002	Строителей	0103000020E61000000100000005000000AED7F4A0A0D843405CCB64389E974D40AED7F4A0A0D84340A9DE1AD82A994D402CBAF59A1EDC4340A9DE1AD82A994D402CBAF59A1EDC43405CCB64389E974D40AED7F4A0A0D843405CCB64389E974D40
31954	29315	39.791620999999999	39.832000000000001	59.350020999999998	59.340311999999997	Центральная	0103000020E61000000100000005000000D5E940D653E54340DA37F7578FAB4D40D5E940D653E54340E4F4F57CCDAC4D40D122DBF97EEA4340E4F4F57CCDAC4D40D122DBF97EEA4340DA37F7578FAB4D40D5E940D653E54340DA37F7578FAB4D40
32007	28711	40.13749	40.187112999999997	59.101745000000001	59.073909	Торговая площадь	0103000020E6100000010000000500000076C3B64599114440A6F0A0D975894D4076C3B6459911444009C4EBFA058D4D4006D49B51F317444009C4EBFA058D4D4006D49B51F3174440A6F0A0D975894D4076C3B64599114440A6F0A0D975894D40
32083	53292	39.998457999999999	40.013792000000002	60.334102999999999	60.320481000000001	Октябрьская	0103000020E61000000100000005000000FC36C478CDFF4340A4FE7A8505294E40FC36C478CDFF43406C3F19E3C32A4E402579AEEFC30144406C3F19E3C32A4E402579AEEFC3014440A4FE7A8505294E40FC36C478CDFF4340A4FE7A8505294E40
26627	27853	40.732830999999997	40.773803000000001	60.469996000000002	60.461024000000002	Октябрьская	0103000020E610000001000000050000005B3FFD67CD5D4440E7559DD5023B4E405B3FFD67CD5D44401BA034D4283C4E40FA4509FA0B6344401BA034D4283C4E40FA4509FA0B634440E7559DD5023B4E405B3FFD67CD5D4440E7559DD5023B4E40
26452	27582	41.310502	41.326141	60.525981999999999	60.516285000000003	Центральная	0103000020E61000000100000005000000DAAB8F87BEA744402B357BA015424E40DAAB8F87BEA744407024D06053434E403F7100FDBEA944407024D06053434E403F7100FDBEA944402B357BA015424E40DAAB8F87BEA744402B357BA015424E40
31875	27334	40.239727999999999	40.288003000000003	60.326433000000002	60.309145000000001	Первомайская	0103000020E61000000100000005000000BEF73768AF1E4440685C381092274E40BEF73768AF1E4440E7AA798EC8294E4030134548DD244440E7AA798EC8294E4030134548DD244440685C381092274E40BEF73768AF1E4440685C381092274E40
26443	26984	40.180610000000001	40.247425999999997	60.489801	60.459457999999998	Советская	0103000020E6100000010000000500000050AA7D3A1E1744405AF10D85CF3A4E4050AA7D3A1E174440284696CCB13E4E400D17B9A7AB1F4440284696CCB13E4E400D17B9A7AB1F44405AF10D85CF3A4E4050AA7D3A1E1744405AF10D85CF3A4E40
31668	26984	40.180610000000001	40.247425999999997	60.489801	60.459457999999998	Свободы	0103000020E6100000010000000500000050AA7D3A1E1744405AF10D85CF3A4E4050AA7D3A1E174440284696CCB13E4E400D17B9A7AB1F4440284696CCB13E4E400D17B9A7AB1F44405AF10D85CF3A4E4050AA7D3A1E1744405AF10D85CF3A4E40
31821	26984	40.180610000000001	40.247425999999997	60.489801	60.459457999999998	Садовая	0103000020E6100000010000000500000050AA7D3A1E1744405AF10D85CF3A4E4050AA7D3A1E174440284696CCB13E4E400D17B9A7AB1F4440284696CCB13E4E400D17B9A7AB1F44405AF10D85CF3A4E4050AA7D3A1E1744405AF10D85CF3A4E40
32002	27314	39.642769999999999	39.661850000000001	60.439447999999999	60.432194000000003	Школьная	0103000020E61000000100000005000000CA6C904946D2434083C30B2252374E40CA6C904946D24340742502D53F384E40C66D3480B7D44340742502D53F384E40C66D3480B7D4434083C30B2252374E40CA6C904946D2434083C30B2252374E40
31955	28076	40.139242000000003	40.158330999999997	60.612630000000003	60.599817999999999	Советская	0103000020E61000000100000005000000651D8EAED2114440ACC612D6C64C4E40651D8EAED21144403546EBA86A4E4E40B378B130441444403546EBA86A4E4E40B378B13044144440ACC612D6C64C4E40651D8EAED2114440ACC612D6C64C4E40
31884	26956	41.660539	41.677346999999997	60.376348	60.364786000000002	Полевая	0103000020E61000000100000005000000C45DBD8A8CD44440F304C24EB12E4E40C45DBD8A8CD444401FF5D72B2C304E409885764EB3D644401FF5D72B2C304E409885764EB3D64440F304C24EB12E4E40C45DBD8A8CD44440F304C24EB12E4E40
26516	3602	41.749319999999997	41.771059000000001	60.507928	60.496493000000001	Восточная	0103000020E610000001000000050000008E1EBFB7E9DF4440B2D826158D3F4E408E1EBFB7E9DF4440815CE2C803414E40AB24B20FB2E24440815CE2C803414E40AB24B20FB2E24440B2D826158D3F4E408E1EBFB7E9DF4440B2D826158D3F4E40
31988	26109	42.915565999999998	42.935293000000001	60.63503	60.623908999999998	Школьная	0103000020E610000001000000050000002EAA4544317545400C570740DC4F4E402EAA4544317545404CFDBCA948514E40C09657AEB77745404CFDBCA948514E40C09657AEB77745400C570740DC4F4E402EAA4544317545400C570740DC4F4E40
31810	3563	42.586001000000003	42.605369000000003	60.716675000000002	60.703051000000002	Новая	0103000020E610000001000000050000002F36AD14024B4540C6353E93FD594E402F36AD14024B45402F6EA301BC5B4E4091813CBB7C4D45402F6EA301BC5B4E4091813CBB7C4D4540C6353E93FD594E402F36AD14024B4540C6353E93FD594E40
31778	53264	42.067799000000001	42.085405999999999	60.747968999999998	60.742164000000002	Новая	0103000020E61000000100000005000000CBD93BA3AD0845406022DE3AFF5E4E40CBD93BA3AD084540FEB5BC72BD5F4E40EB707495EE0A4540FEB5BC72BD5F4E40EB707495EE0A45406022DE3AFF5E4E40CBD93BA3AD0845406022DE3AFF5E4E40
31867	25920	41.821579999999997	41.845260000000003	60.644201000000002	60.628486000000002	Советская	0103000020E610000001000000050000001A868F8829E9444037FFAF3A72504E401A868F8829E944407786A92D75524E40F94ECC7A31EC44407786A92D75524E40F94ECC7A31EC444037FFAF3A72504E401A868F8829E9444037FFAF3A72504E40
31864	26669	42.573667999999998	42.593637000000001	60.498964999999998	60.488892	Лесная	0103000020E610000001000000050000008061F9F36D49454055A35703943E4E408061F9F36D494540A06CCA15DE3F4E400859164CFC4B4540A06CCA15DE3F4E400859164CFC4B454055A35703943E4E408061F9F36D49454055A35703943E4E40
26442	26917	41.778668000000003	41.790768	60.492224999999998	60.485045	Центральная	0103000020E610000001000000050000008B389D64ABE344404E0B5EF4153E4E408B389D64ABE3444005A3923A013F4E40965CC5E237E5444005A3923A013F4E40965CC5E237E544404E0B5EF4153E4E408B389D64ABE344404E0B5EF4153E4E40
26424	26240	41.719656999999998	41.742322000000001	60.859253000000002	60.846448000000002	Центральная	0103000020E6100000010000000500000032AB77B81DDC4440DFE17668586C4E4032AB77B81DDC4440B5FE9600FC6D4E40F88C446804DF4440B5FE9600FC6D4E40F88C446804DF4440DFE17668586C4E4032AB77B81DDC4440DFE17668586C4E40
26418	26098	42.701290999999998	42.721854	60.789306000000003	60.781602999999997	Центральная	0103000020E6100000010000000500000054FD4AE7C35945404DBA2D910B644E4054FD4AE7C3594540AF44A0FA07654E404F3E3DB6655C4540AF44A0FA07654E404F3E3DB6655C45404DBA2D910B644E4054FD4AE7C35945404DBA2D910B644E40
26576	26217	41.677751000000001	41.686374999999998	60.796120000000002	60.791769000000002	Мира	0103000020E6100000010000000500000068EA758BC0D644404A7EC4AF58654E4068EA758BC0D6444084D89942E7654E4060E5D022DBD7444084D89942E7654E4060E5D022DBD744404A7EC4AF58654E4068EA758BC0D644404A7EC4AF58654E40
31989	25977	41.900506	41.916882000000001	60.583303000000001	60.575378000000001	Центральная	0103000020E6100000010000000500000007EDD5C743F34440406B7EFCA5494E4007EDD5C743F34440505436ACA94A4E404225AE635CF54440505436ACA94A4E404225AE635CF54440406B7EFCA5494E4007EDD5C743F34440406B7EFCA5494E40
31809	26179	41.695833999999998	41.708258000000001	60.434876000000003	60.423841000000003	Центральная	0103000020E61000000100000005000000F1B8A81611D944401BDA006C40364E40F1B8A81611D944405CE84A04AA374E40B090B932A8DA44405CE84A04AA374E40B090B932A8DA44401BDA006C40364E40F1B8A81611D944401BDA006C40364E40
31719	26743	42.053947000000001	42.070233999999999	60.678623999999999	60.663497999999997	Куколовская	0103000020E61000000100000005000000D15B3CBCE70645400F7BA180ED544E40D15B3CBCE7064540EE23B726DD564E409C887E6DFD084540EE23B726DD564E409C887E6DFD0845400F7BA180ED544E40D15B3CBCE70645400F7BA180ED544E40
31871	26040	42.090383000000003	42.110917999999998	60.819656000000002	60.810389000000001	Стебенева	0103000020E61000000100000005000000A48E8EAB910B4540E204A6D3BA674E40A48E8EAB910B45402FFCE07CEA684E40D4449F8F320E45402FFCE07CEA684E40D4449F8F320E4540E204A6D3BA674E40A48E8EAB910B4540E204A6D3BA674E40
31940	26847	41.765740999999998	41.783437999999997	60.467725999999999	60.458703	переулок Школьный	0103000020E61000000100000005000000691A14CD03E24440DEC9A7C7B63A4E40691A14CD03E2444094BE1072DE3B4E40C93846B247E4444094BE1072DE3B4E40C93846B247E44440DEC9A7C7B63A4E40691A14CD03E24440DEC9A7C7B63A4E40
31748	25718	42.000056999999998	42.066541999999998	60.754260000000002	60.728907999999997	переулок Лесной	0103000020E61000000100000005000000649126DE0100454079E57ADB4C5D4E40649126DE010045402A5778978B604E40BCE7C072840845402A5778978B604E40BCE7C0728408454079E57ADB4C5D4E40649126DE0100454079E57ADB4C5D4E40
31684	25718	42.000056999999998	42.066541999999998	60.754260000000002	60.728907999999997	Стебенева	0103000020E61000000100000005000000649126DE0100454079E57ADB4C5D4E40649126DE010045402A5778978B604E40BCE7C072840845402A5778978B604E40BCE7C0728408454079E57ADB4C5D4E40649126DE0100454079E57ADB4C5D4E40
31746	25718	42.000056999999998	42.066541999999998	60.754260000000002	60.728907999999997	Пионерская	0103000020E61000000100000005000000649126DE0100454079E57ADB4C5D4E40649126DE010045402A5778978B604E40BCE7C072840845402A5778978B604E40BCE7C0728408454079E57ADB4C5D4E40649126DE0100454079E57ADB4C5D4E40
31870	25995	42.171159000000003	42.181238999999998	60.433464000000001	60.426999000000002	Центральная	0103000020E6100000010000000500000042B5C189E81545405D363AE7A7364E4042B5C189E815454026FF93BF7B374E403FE1ECD63217454026FF93BF7B374E403FE1ECD6321745405D363AE7A7364E4042B5C189E81545405D363AE7A7364E40
31979	25383	46.195512999999998	46.212356999999997	60.650494999999999	60.646186	Центральная	0103000020E61000000100000005000000AF78EA910619474008910C39B6524E40AF78EA9106194740139B8F6B43534E40D009A1832E1B4740139B8F6B43534E40D009A1832E1B474008910C39B6524E40AF78EA910619474008910C39B6524E40
31918	25407	46.472544999999997	46.508234999999999	60.479787000000002	60.450387999999997	Школьная	0103000020E61000000100000005000000B471C45A7C3C474063416150A6394E40B471C45A7C3C4740E20511A9693D4E405ED72FD80D414740E20511A9693D4E405ED72FD80D41474063416150A6394E40B471C45A7C3C474063416150A6394E40
31745	25265	46.670074999999997	46.694752000000001	60.461812999999999	60.455167000000003	Проезжая	0103000020E61000000100000005000000006F8104C5554740F69B89E9423A4E40006F8104C55547400FEF39B01C3B4E40516A2FA2ED5847400FEF39B01C3B4E40516A2FA2ED584740F69B89E9423A4E40006F8104C5554740F69B89E9423A4E40
31760	25184	47.032787999999996	47.067318999999998	60.826445999999997	60.808858000000001	пер.Советский	0103000020E61000000100000005000000C2D9AD6532844740D28DB0A888674E40C2D9AD65328447407BF486FBC8694E4020B3B3E89D8847407BF486FBC8694E4020B3B3E89D884740D28DB0A888674E40C2D9AD6532844740D28DB0A888674E40
31921	25254	46.945372999999996	46.963715999999998	60.782643999999998	60.772061999999998	Колотова	0103000020E61000000100000005000000BDC282FB01794740FF3D78EDD2624E40BDC282FB017947408F34B8AD2D644E40E350BF0B5B7B47408F34B8AD2D644E40E350BF0B5B7B4740FF3D78EDD2624E40BDC282FB01794740FF3D78EDD2624E40
26558	24751	45.379187000000002	45.404052	60.597937000000002	60.588478000000002	Гагарина	0103000020E61000000100000005000000C0081A3389B046402F35423F534B4E40C0081A3389B04640C0081A33894C4E4013F1D6F9B7B34640C0081A33894C4E4013F1D6F9B7B346402F35423F534B4E40C0081A3389B046402F35423F534B4E40
79386	61559	46.421790000000001	46.440511000000001	60.872433999999998	60.861688999999998	Рабочая	0103000020E61000000100000005000000D2E3F736FD35474056293DD34B6E4E40D2E3F736FD35474090F5D4EAAB6F4E409E4319AA6238474090F5D4EAAB6F4E409E4319AA6238474056293DD34B6E4E40D2E3F736FD35474056293DD34B6E4E40
31909	24248	46.854796	46.873004999999999	60.613672000000001	60.605949000000003	Полевая	0103000020E61000000100000005000000356090F4696D47409F05A1BC8F4D4E40356090F4696D4740473CD9CD8C4E4E404B1FBAA0BE6F4740473CD9CD8C4E4E404B1FBAA0BE6F47409F05A1BC8F4D4E40356090F4696D47409F05A1BC8F4D4E40
31857	24688	46.202215000000002	46.218330000000002	60.565064	60.55142	Центральная	0103000020E610000001000000050000005DE15D2EE21947401F2E39EE94464E405DE15D2EE2194740CF12640454484E402BDEC83CF21B4740CF12640454484E402BDEC83CF21B47401F2E39EE94464E405DE15D2EE21947401F2E39EE94464E40
31807	25023	46.195414	46.24183	60.755854999999997	60.738104999999997	Советская	0103000020E610000001000000050000001C97715303194740CD0182397A5E4E401C9771530319474050C24CDBBF604E4089981249F41E474050C24CDBBF604E4089981249F41E4740CD0182397A5E4E401C97715303194740CD0182397A5E4E40
31682	25346	46.272714000000001	46.315779999999997	60.721943000000003	60.705710000000003	Центральная	0103000020E61000000100000005000000A794D74AE8224740E73A8DB4545A4E40A794D74AE8224740BF49D3A0685C4E408D5DA27A6B284740BF49D3A0685C4E408D5DA27A6B284740E73A8DB4545A4E40A794D74AE8224740E73A8DB4545A4E40
32043	24505	45.507475999999997	45.547764999999998	61.140214999999998	61.120018999999999	Железнодорожная	0103000020E61000000100000005000000A0C03BF9F4C0464006F357C85C8F4E40A0C03BF9F4C046404EB4AB90F2914E405C72DC291DC646404EB4AB90F2914E405C72DC291DC6464006F357C85C8F4E40A0C03BF9F4C0464006F357C85C8F4E40
31973	23929	46.364387000000001	46.393340000000002	60.748742	60.719926999999998	Лермонтова	0103000020E61000000100000005000000350BB43BA42E4740F2406491265C4E40350BB43BA42E4740219221C7D65F4E40B51A12F758324740219221C7D65F4E40B51A12F758324740F2406491265C4E40350BB43BA42E4740F2406491265C4E40
31739	23999	46.447840999999997	46.506923	60.974926000000004	60.934327000000003	Текстильщиков	0103000020E610000001000000050000006A6798DA523947408962F20698774E406A6798DA5239474093020B60CA7C4E408C4B55DAE240474093020B60CA7C4E408C4B55DAE24047408962F20698774E406A6798DA523947408962F20698774E40
26727	23999	46.447840999999997	46.506923	60.974926000000004	60.934327000000003	Советский проспект	0103000020E610000001000000050000006A6798DA523947408962F20698774E406A6798DA5239474093020B60CA7C4E408C4B55DAE240474093020B60CA7C4E408C4B55DAE24047408962F20698774E406A6798DA523947408962F20698774E40
31958	23999	46.447840999999997	46.506923	60.974926000000004	60.934327000000003	Революции	0103000020E610000001000000050000006A6798DA523947408962F20698774E406A6798DA5239474093020B60CA7C4E408C4B55DAE240474093020B60CA7C4E408C4B55DAE24047408962F20698774E406A6798DA523947408962F20698774E40
26542	23999	46.447840999999997	46.506923	60.974926000000004	60.934327000000003	Культуры	0103000020E610000001000000050000006A6798DA523947408962F20698774E406A6798DA5239474093020B60CA7C4E408C4B55DAE240474093020B60CA7C4E408C4B55DAE24047408962F20698774E406A6798DA523947408962F20698774E40
26537	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Советский проспект	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
32036	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Площадь Коммуны	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31969	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	П.Покровского	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31994	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Набережная	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31863	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Московская	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
26534	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Кузнецова	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
26720	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Кооперативная	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31971	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Дежнёва	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31966	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Гледенская	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31800	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	Вторая	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
26715	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	А.Угловского	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31732	23172	46.248370000000001	46.351371	60.785139000000001	60.738545000000002	2-я Пролетарская	0103000020E610000001000000050000005DA79196CA1F4740EACF7EA4885E4E405DA79196CA1F474036E84B6F7F644E40A4E194B9F92C474036E84B6F7F644E40A4E194B9F92C4740EACF7EA4885E4E405DA79196CA1F4740EACF7EA4885E4E40
31803	24404	46.455745999999998	46.477063000000001	60.934387999999998	60.919618999999997	Парковая	0103000020E6100000010000000500000033A48AE2553A4740DEE34C13B6754E4033A48AE2553A47402EE3A6069A774E40DA907F66103D47402EE3A6069A774E40DA907F66103D4740DEE34C13B6754E4033A48AE2553A4740DEE34C13B6754E40
31855	24555	46.096302999999999	46.109535000000001	60.731222000000002	60.726506000000001	Школьная	0103000020E61000000100000005000000DBC01DA8530C4740842C0B26FE5C4E40DBC01DA8530C4740D00EB8AE985D4E4039622D3E050E4740D00EB8AE985D4E4039622D3E050E4740842C0B26FE5C4E40DBC01DA8530C4740842C0B26FE5C4E40
31683	25477	46.386333	46.413373	60.770176999999997	60.759459999999997	П.Виноградова	0103000020E61000000100000005000000CB2E185C73314740614F3BFC35614E40CB2E185C73314740D190F12895624E4053060E68E9344740D190F12895624E4053060E68E9344740614F3BFC35614E40CB2E185C73314740614F3BFC35614E40
31916	22721	37.701555999999997	37.715623000000001	60.334695000000004	60.327052000000002	Мира	0103000020E6100000010000000500000002284696CCD94240B30B06D7DC294E4002284696CCD942403F912749D72A4E40F9A1D28899DB42403F912749D72A4E40F9A1D28899DB4240B30B06D7DC294E4002284696CCD94240B30B06D7DC294E40
26450	23028	37.284261000000001	37.314785999999998	60.443350000000002	60.433960999999996	Набережная Кемы	0103000020E610000001000000050000009E4319AA62A44240A65EB7088C374E409E4319AA62A442403F575BB1BF384E408C9E5BE84AA842403F575BB1BF384E408C9E5BE84AA84240A65EB7088C374E409E4319AA62A44240A65EB7088C374E40
31904	22986	37.645150999999998	37.666513000000002	60.464314999999999	60.454377999999998	Молодёжная 	0103000020E61000000100000005000000A8FDD64E94D24240CD02ED0E293A4E40A8FDD64E94D24240680586AC6E3B4E40EFAD484C50D54240680586AC6E3B4E40EFAD484C50D54240CD02ED0E293A4E40A8FDD64E94D24240CD02ED0E293A4E40
26524	22440	37.950828999999999	37.971688	60.464115	60.454165000000003	Гагарина	0103000020E61000000100000005000000508BC1C3B4F9424072FE2614223A4E40508BC1C3B4F94240A14ACD1E683B4E4034F5BA4560FC4240A14ACD1E683B4E4034F5BA4560FC424072FE2614223A4E40508BC1C3B4F9424072FE2614223A4E40
32098	53294	37.873933999999998	37.888468000000003	60.558447999999999	60.549667999999997	Центральная	0103000020E61000000100000005000000656EBE11DDEF424030D461855B464E40656EBE11DDEF424020425C397B474E4072C5C551B9F1424020425C397B474E4072C5C551B9F1424030D461855B464E40656EBE11DDEF424030D461855B464E40
31785	22664	38.132334	38.146706999999999	60.645569000000002	60.639578	Лесная	0103000020E610000001000000050000000E130D52F0104340DC9E20B1DD514E400E130D52F0104340DD274701A2524E40118C834BC7124340DD274701A2524E40118C834BC7124340DC9E20B1DD514E400E130D52F0104340DC9E20B1DD514E40
32030	22762	37.235715999999996	37.259647999999999	60.360061000000002	60.346294	Чумакова	0103000020E610000001000000050000006C921FF12B9E424088669E5C532C4E406C921FF12B9E424054C8957A162E4E40643C4A253CA1424054C8957A162E4E40643C4A253CA1424088669E5C532C4E406C921FF12B9E424088669E5C532C4E40
32117	53280	37.950792999999997	37.996094999999997	60.270587999999996	60.249885999999996	Первомайская	0103000020E610000001000000050000000322C495B3F9424037DDB243FC1F4E400322C495B3F942405358A9A0A2224E40C45A7C0A80FF42405358A9A0A2224E40C45A7C0A80FF424037DDB243FC1F4E400322C495B3F9424037DDB243FC1F4E40
31786	22648	37.976089999999999	37.999006000000001	60.658228999999999	60.650804000000001	Советская	0103000020E61000000100000005000000F0F96184F0FC4240910DA48B4D534E40F0F96184F0FC4240AF230ED940544E40FF40B96DDFFF4240AF230ED940544E40FF40B96DDFFF4240910DA48B4D534E40F0F96184F0FC4240910DA48B4D534E40
32035	22890	37.988280000000003	38.002994999999999	60.276401999999997	60.269753000000001	Механизаторов	0103000020E610000001000000050000003CA583F57FFE4240BB7F2C4487224E403CA583F57FFE42404546072461234E409886E123620043404546072461234E409886E12362004340BB7F2C4487224E403CA583F57FFE4240BB7F2C4487224E40
31902	22525	38.010207999999999	38.021436999999999	60.280760000000001	60.272185	Центральная	0103000020E610000001000000050000002B14E97E4E0143401BBB44F5D6224E402B14E97E4E014340320395F1EF234E4051F69672BE024340320395F1EF234E4051F69672BE0243401BBB44F5D6224E402B14E97E4E0143401BBB44F5D6224E40
26711	23056	37.547378000000002	37.566952000000001	60.512844000000001	60.505052999999997	Юбилейная	0103000020E610000001000000050000006346787B10C6424093DFA293A5404E406346787B10C6424094F947DFA4414E406E3315E291C8424094F947DFA4414E406E3315E291C8424093DFA293A5404E406346787B10C6424093DFA293A5404E40
31727	22385	37.912579000000001	37.924688000000003	60.496035999999997	60.479179999999999	Центральная	0103000020E6100000010000000500000019028063CFF44240DA722EC5553D4E4019028063CFF44240BFD18E1B7E3F4E407880272D5CF64240BFD18E1B7E3F4E407880272D5CF64240DA722EC5553D4E4019028063CFF44240DA722EC5553D4E40
26692	22139	37.684677000000001	37.814366	59.880094	59.809953	Школьный переулок	0103000020E6100000010000000500000065A9F57EA3D742400726378AACE74D4065A9F57EA3D74240F2B391EBA6F04D40B77C24253DE84240F2B391EBA6F04D40B77C24253DE842400726378AACE74D4065A9F57EA3D742400726378AACE74D40
32023	22359	37.503216999999999	37.515084000000002	60.041592999999999	60.026041999999997	Советская	0103000020E6100000010000000500000047E5266A69C042404529215855034E4047E5266A69C042400B5F5FEB52054E40B058C345EEC142400B5F5FEB52054E40B058C345EEC142404529215855034E4047E5266A69C042404529215855034E40
26690	22081	37.111983000000002	37.145156999999998	60.187772000000002	60.177571	Центральная	0103000020E610000001000000050000009F5A7D75558E4240E8DB82A5BA164E409F5A7D75558E4240618DB3E908184E408AE42B8194924240618DB3E908184E408AE42B8194924240E8DB82A5BA164E409F5A7D75558E4240E8DB82A5BA164E40
31927	21417	37.692850999999997	37.741925999999999	60.036015999999996	60.023761999999998	Труда	0103000020E610000001000000050000001D007157AFD842409B711AA20A034E401D007157AFD84240FD101B2C9C044E40AB06616EF7DE4240FD101B2C9C044E40AB06616EF7DE42409B711AA20A034E401D007157AFD842409B711AA20A034E40
31901	22217	37.361930000000001	37.380865999999997	59.868302	59.855913999999999	Сельсоветская	0103000020E610000001000000050000007CB8E4B853AE4240221807978EED4D407CB8E4B853AE424094861A8524EF4D4044149337C0B0424094861A8524EF4D4044149337C0B04240221807978EED4D407CB8E4B853AE4240221807978EED4D40
32024	22308	37.621507000000001	37.646031000000001	60.026657999999998	60.005625000000002	Центральная	0103000020E61000000100000005000000179E978A8DCF42401F85EB51B8004E40179E978A8DCF4240A016838769034E40E199D024B1D24240A016838769034E40E199D024B1D242401F85EB51B8004E40179E978A8DCF42401F85EB51B8004E40
26594	21956	36.983389000000003	36.997411	59.907558999999999	59.898750999999997	Центральная	0103000020E61000000100000005000000821FD5B0DF7D4240A71FD4450AF34D40821FD5B0DF7D42406118B0E42AF44D40D8D5E429AB7F42406118B0E42AF44D40D8D5E429AB7F4240A71FD4450AF34D40821FD5B0DF7D4240A71FD4450AF34D40
32018	21259	36.946745999999997	37.022699000000003	60.325854	60.308988999999997	Спортивная	0103000020E6100000010000000500000035CF11F92E79424070E998F38C274E4035CF11F92E794240A9A27895B5294E40725303CDE7824240A9A27895B5294E40725303CDE782424070E998F38C274E4035CF11F92E79424070E998F38C274E40
31779	21259	36.946745999999997	37.022699000000003	60.325854	60.308988999999997	Набережная	0103000020E6100000010000000500000035CF11F92E79424070E998F38C274E4035CF11F92E794240A9A27895B5294E40725303CDE7824240A9A27895B5294E40725303CDE782424070E998F38C274E4035CF11F92E79424070E998F38C274E40
31928	22043	37.917088999999997	37.929602000000003	60.032097	60.024963	Молодежная	0103000020E61000000100000005000000BB421F2C63F54240164ED2FC31034E40BB421F2C63F542405DA626C11B044E40EA25C632FDF642405DA626C11B044E40EA25C632FDF64240164ED2FC31034E40BB421F2C63F54240164ED2FC31034E40
31814	3362	36.871682999999997	36.884402999999999	59.726346999999997	59.714672999999998	Центральная	0103000020E6100000010000000500000055BDFC4E936F4240C72AA5677ADB4D4055BDFC4E936F42401B4641F0F8DC4D40FDBD141E347142401B4641F0F8DC4D40FDBD141E34714240C72AA5677ADB4D4055BDFC4E936F4240C72AA5677ADB4D40
26667	3273	37.059198000000002	37.094906000000002	59.900740999999996	59.894658	Центральная	0103000020E610000001000000050000008BFED0CC93874240698D412784F24D408BFED0CC938742404A95287B4BF34D40DB183BE1258C42404A95287B4BF34D40DB183BE1258C4240698D412784F24D408BFED0CC93874240698D412784F24D40
31929	21828	37.662568999999998	37.684254000000003	59.739145999999998	59.730415999999998	Молодежная	0103000020E61000000100000005000000F52B9D0FCFD44240D13C80457EDD4D40F52B9D0FCFD442400F7C0C569CDE4D401F1494A295D742400F7C0C569CDE4D401F1494A295D74240D13C80457EDD4D40F52B9D0FCFD44240D13C80457EDD4D40
26427	22286	37.423653000000002	37.443578000000002	59.753999	59.747892999999998	Центральная	0103000020E6100000010000000500000018EDF1423AB6424023F433F5BADF4D4018EDF1423AB64240BD1B0B0A83E04D40D09CF529C7B84240BD1B0B0A83E04D40D09CF529C7B8424023F433F5BADF4D4018EDF1423AB6424023F433F5BADF4D40
31899	21350	37.755994000000001	37.821525999999999	60.038542	60.018844000000001	Энгельса	0103000020E6100000010000000500000072FC5069C4E04240E8DCED7A69024E4072FC5069C4E04240DFC2BAF1EE044E40276893C327E94240DFC2BAF1EE044E40276893C327E94240E8DCED7A69024E4072FC5069C4E04240E8DCED7A69024E40
31781	21350	37.755994000000001	37.821525999999999	60.038542	60.018844000000001	Фрунзе	0103000020E6100000010000000500000072FC5069C4E04240E8DCED7A69024E4072FC5069C4E04240DFC2BAF1EE044E40276893C327E94240DFC2BAF1EE044E40276893C327E94240E8DCED7A69024E4072FC5069C4E04240E8DCED7A69024E40
31992	21350	37.755994000000001	37.821525999999999	60.038542	60.018844000000001	Советский проспект	0103000020E6100000010000000500000072FC5069C4E04240E8DCED7A69024E4072FC5069C4E04240DFC2BAF1EE044E40276893C327E94240DFC2BAF1EE044E40276893C327E94240E8DCED7A69024E4072FC5069C4E04240E8DCED7A69024E40
31987	21350	37.755994000000001	37.821525999999999	60.038542	60.018844000000001	С.Дмитриева	0103000020E6100000010000000500000072FC5069C4E04240E8DCED7A69024E4072FC5069C4E04240DFC2BAF1EE044E40276893C327E94240DFC2BAF1EE044E40276893C327E94240E8DCED7A69024E4072FC5069C4E04240E8DCED7A69024E40
31846	21350	37.755994000000001	37.821525999999999	60.038542	60.018844000000001	Карла Маркса	0103000020E6100000010000000500000072FC5069C4E04240E8DCED7A69024E4072FC5069C4E04240DFC2BAF1EE044E40276893C327E94240DFC2BAF1EE044E40276893C327E94240E8DCED7A69024E4072FC5069C4E04240E8DCED7A69024E40
32009	19940	43.105111000000001	43.135654000000002	59.792513	59.771875000000001	Юрманга	0103000020E6100000010000000500000095B9F946748D4540CDCCCCCCCCE24D4095B9F946748D4540D253E41071E54D402AC93A1C5D914540D253E41071E54D402AC93A1C5D914540CDCCCCCCCCE24D4095B9F946748D4540CDCCCCCCCCE24D40
31722	21031	44.208466999999999	44.254855999999997	59.774583999999997	59.756413999999999	Советская	0103000020E61000000100000005000000CAA5F10BAF1A4640471E882CD2E04D40CAA5F10BAF1A46409F008A9125E34D403D98141F9F2046409F008A9125E34D403D98141F9F204640471E882CD2E04D40CAA5F10BAF1A4640471E882CD2E04D40
79365	61542	43.462280999999997	43.499220000000001	59.709476000000002	59.691884000000002	Советская	0103000020E61000000100000005000000F54718062CBB45401650A8A78FD84D40F54718062CBB454001A60C1CD0DA4D402BC1E270E6BF454001A60C1CD0DA4D402BC1E270E6BF45401650A8A78FD84D40F54718062CBB45401650A8A78FD84D40
32013	21000	44.172417000000003	44.182837999999997	59.758471999999998	59.751637000000002	Школьная	0103000020E610000001000000050000002123A0C21116464056BB26A435E04D402123A0C2111646404277499C15E14D40A73B4F3C671746404277499C15E14D40A73B4F3C6717464056BB26A435E04D402123A0C21116464056BB26A435E04D40
26642	19858	43.107455999999999	43.159486000000001	59.770294	59.744284	Бабушкина	0103000020E6100000010000000500000026E1421EC18D4540D177B7B244DF4D4026E1421EC18D45400B2769FE98E24D40BE1589096A9445400B2769FE98E24D40BE1589096A944540D177B7B244DF4D4026E1421EC18D4540D177B7B244DF4D40
31893	20211	43.143191000000002	43.165396999999999	59.342968999999997	59.329196000000003	Гагарина	0103000020E61000000100000005000000700A2B1554924540ADFC321823AA4D40700A2B15549245405A457F68E6AB4D40A2ED98BA2B9545405A457F68E6AB4D40A2ED98BA2B954540ADFC321823AA4D40700A2B1554924540ADFC321823AA4D40
26487	20939	44.111449	44.135820000000002	59.607230000000001	59.588445	Школьная	0103000020E610000001000000050000000116F9F5430E4640533F6F2A52CB4D400116F9F5430E464036936FB6B9CD4D404512BD8C6211464036936FB6B9CD4D404512BD8C62114640533F6F2A52CB4D400116F9F5430E4640533F6F2A52CB4D40
31714	20017	43.965983999999999	43.981202000000003	59.474576999999996	59.467222	Центральная	0103000020E61000000100000005000000C93A1C5DA5FB454061FC34EECDBB4D40C93A1C5DA5FB454086376BF0BEBC4D408962F20698FD454086376BF0BEBC4D408962F20698FD454061FC34EECDBB4D40C93A1C5DA5FB454061FC34EECDBB4D40
26636	19760	35.649183999999998	35.675944999999999	59.503027000000003	59.493431000000001	Западная	0103000020E61000000100000005000000118B187618D3414092EA3BBF28BF4D40118B187618D34140A400513063C04D408672A25D85D64140A400513063C04D408672A25D85D6414092EA3BBF28BF4D40118B187618D3414092EA3BBF28BF4D40
31770	18901	36.142611000000002	36.164043999999997	59.385959	59.378250000000001	Школьная	0103000020E610000001000000050000006286C6134112424023DBF97E6AB04D406286C61341124240664CC11A67B14D40718DCF64FF144240664CC11A67B14D40718DCF64FF14424023DBF97E6AB04D406286C6134112424023DBF97E6AB04D40
31946	19612	36.172992000000001	36.201908000000003	60.118445000000001	60.09901	Солнечная	0103000020E610000001000000050000001D3C139A241642400DFD135CAC0C4E401D3C139A24164240F7AFAC34290F4E408066101FD8194240F7AFAC34290F4E408066101FD81942400DFD135CAC0C4E401D3C139A241642400DFD135CAC0C4E40
31713	19683	35.648491999999997	35.675127000000003	59.494937999999998	59.485261999999999	Набережная	0103000020E61000000100000005000000DBDB2DC901D34140EBFEB1101DBE4D40DBDB2DC901D3414019C6DD205ABF4D40C4D2C08F6AD6414019C6DD205ABF4D40C4D2C08F6AD64140EBFEB1101DBE4D40DBDB2DC901D34140EBFEB1101DBE4D40
26464	19441	35.744971	35.772190000000002	60.152605000000001	60.143168000000003	Центральная	0103000020E61000000100000005000000F5BBB0355BDF4140B8EA3A5453124E40F5BBB0355BDF4140611A868F88134E402D26361FD7E24140611A868F88134E402D26361FD7E24140B8EA3A5453124E40F5BBB0355BDF4140B8EA3A5453124E40
32040	19267	36.088011000000002	36.114035000000001	59.962952999999999	59.948130999999997	Школьная	0103000020E610000001000000050000001958C7F1430B424071A94A5B5CF94D401958C7F1430B4240E44A3D0B42FB4D40B8CCE9B2980E4240E44A3D0B42FB4D40B8CCE9B2980E424071A94A5B5CF94D401958C7F1430B424071A94A5B5CF94D40
31712	18887	35.817106000000003	35.832943	59.413884000000003	59.398491	Набережная	0103000020E61000000100000005000000C5AEEDED96E841400B60CAC001B34D40C5AEEDED96E84140392BA226FAB44D40503750E09DEA4140392BA226FAB44D40503750E09DEA41400B60CAC001B34D40C5AEEDED96E841400B60CAC001B34D40
31991	18649	35.985377999999997	36.026817999999999	59.921484	59.872796000000001	Комсомольская	0103000020E610000001000000050000005419C6DD20FE4140310A82C7B7EF4D405419C6DD20FE4140C5E40D30F3F54D40D978B0C56E034240C5E40D30F3F54D40D978B0C56E034240310A82C7B7EF4D405419C6DD20FE4140310A82C7B7EF4D40
31886	18166	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	Ухтомского	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
31755	18166	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	Советская	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
31880	18166	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	Садовая	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
31826	18166	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	Производственный переулок	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
31944	18166	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	Интернациональная	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
26618	18166	35.902042000000002	35.976816999999997	59.416483999999997	59.377063	Гайдара	0103000020E6100000010000000500000029CFBC1C76F341400DC4B29943B04D4029CFBC1C76F3414054A703594FB54D40A296E65608FD414054A703594FB54D40A296E65608FD41400DC4B29943B04D4029CFBC1C76F341400DC4B29943B04D40
32178	53297	35.142417000000002	36.720092999999999	60.483696999999999	59.043393999999999	Железнодорожная	0103000020E610000001000000050000007DB262B83A924140DB6B41EF8D854D407DB262B83A9241402F1686C8E93D4E400D8AE6012C5C42402F1686C8E93D4E400D8AE6012C5C4240DB6B41EF8D854D407DB262B83A924140DB6B41EF8D854D40
59084	57526	42.881898	42.938231000000002	62.116292000000001	62.095112999999998	К.Либкнехта	0103000020E6100000010000000500000033349E08E27045405436ACA92C0C4F4033349E08E2704540AA6400A8E20E4F40F48B12F417784540AA6400A8E20E4F40F48B12F4177845405436ACA92C0C4F4033349E08E27045405436ACA92C0C4F40
58614	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	проспект Труда	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58651	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Юбилейная	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58723	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Тургенева	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58733	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Трухинова	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58689	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Труда проспект	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58649	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Торцева	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58731	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Строителей	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58617	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Советских Космонавтов	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
71953	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Республиканская	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58625	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Профсоюзная	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58712	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Приморский бульвар	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58732	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Полярная	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58660	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Орджоникидзе	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58618	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Октябрьская	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
56915	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Морской проспект	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
56907	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Мира	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58740	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Ломоносова	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58721	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Ленина проспект	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58658	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Лебедева	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58615	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Корабельная	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58613	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Комсомольская	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58666	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Кирилкина	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58571	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Карла Маркса	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58657	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Капитана Воронина	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
59062	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Железнодорожная	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58626	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Дзержинского	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58701	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Гоголя	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58634	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Гагарина	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58665	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	Арктическая	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
58703	9494	39.750999	39.914465999999997	64.603313999999997	64.544287999999995	 Коновалова	0103000020E61000000100000005000000132A38BC20E04340BCE6559DD5225040132A38BC20E0434003CE52B29C265040E7A6CD380DF5434003CE52B29C265040E7A6CD380DF54340BCE6559DD5225040132A38BC20E04340BCE6559DD5225040
59003	51983	40.611297999999998	40.618519999999997	64.639934999999994	64.631670999999997	70 лет Октября	0103000020E610000001000000050000001B0E4B033F4E444039B5334C6D2850401B0E4B033F4E44403524EEB1F428504001F6D1A92B4F44403524EEB1F428504001F6D1A92B4F444039B5334C6D2850401B0E4B033F4E444039B5334C6D285040
58643	57458	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	Матросова	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58642	57458	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	Коминтерна	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58564	57458	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	Гутина	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58640	57458	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	Архангельская	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58694	57467	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Строителей	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58637	57467	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Первомайская	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58696	57467	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Красноармейская	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58690	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Фронтовых бригад	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58624	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Уборевича	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58597	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Солнечная	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58616	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Советов	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58632	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Мельникова	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58633	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Космонавтов	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58691	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Двинская	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58708	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	Ворошилова	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58636	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	50 лет Октября	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58631	2333	40.783478000000002	40.841734000000002	64.422402000000005	64.403722000000002	3-й Пятилетки	0103000020E610000001000000050000005891D101496444403FABCC94D61950405891D10149644440F6F065A2081B504034F790F0BD6B4440F6F065A2081B504034F790F0BD6B44403FABCC94D61950405891D101496444403FABCC94D6195040
58635	57473	40.311638000000002	40.377844000000003	62.778320999999998	62.747137000000002	Овчинникова	0103000020E610000001000000050000006E1805C1E3274440D7506A2FA25F4F406E1805C1E32744401F65C405A0634F40B37E33315D3044401F65C405A0634F40B37E33315D304440D7506A2FA25F4F406E1805C1E3274440D7506A2FA25F4F40
58724	57473	40.311638000000002	40.377844000000003	62.778320999999998	62.747137000000002	Неделина	0103000020E610000001000000050000006E1805C1E3274440D7506A2FA25F4F406E1805C1E32744401F65C405A0634F40B37E33315D3044401F65C405A0634F40B37E33315D304440D7506A2FA25F4F406E1805C1E3274440D7506A2FA25F4F40
58756	57473	40.311638000000002	40.377844000000003	62.778320999999998	62.747137000000002	Ленина	0103000020E610000001000000050000006E1805C1E3274440D7506A2FA25F4F406E1805C1E32744401F65C405A0634F40B37E33315D3044401F65C405A0634F40B37E33315D304440D7506A2FA25F4F406E1805C1E3274440D7506A2FA25F4F40
58763	57473	40.311638000000002	40.377844000000003	62.778320999999998	62.747137000000002	Дзержинского проспект	0103000020E610000001000000050000006E1805C1E3274440D7506A2FA25F4F406E1805C1E32744401F65C405A0634F40B37E33315D3044401F65C405A0634F40B37E33315D304440D7506A2FA25F4F406E1805C1E3274440D7506A2FA25F4F40
58682	57475	40.617317	40.661397000000001	64.427807000000001	64.416876000000002	Лахтинское шоссе	0103000020E61000000100000005000000E621533E044F4440309FAC18AE1A5040E621533E044F4440FE7F9C30611B504015562AA8A8544440FE7F9C30611B504015562AA8A8544440309FAC18AE1A5040E621533E044F4440309FAC18AE1A5040
58729	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	им. 28-й Невельской дивизии	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58798	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Школьная	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58693	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Ушакова	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58674	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	С-Щедрина	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58650	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Мелентьева	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58588	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Маяковского	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58858	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Мартемьяновская	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58600	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Ленина	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58688	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Кузнецова	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58590	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Кедрова	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58736	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Карла Маркса	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58586	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Калинина	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58711	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Заполярная	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58595	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Герцена	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58677	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Володарского	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58623	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Виноградова	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58592	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	Багратиона	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58591	22794	46.616903999999998	46.732185000000001	61.283306000000003	61.177183999999997	70-летия Октября	0103000020E61000000100000005000000C362D4B5F64E4740EEAF1EF7AD964E40C362D4B5F64E47405B61FA5E43A44E4096CFF23CB85D47405B61FA5E43A44E4096CFF23CB85D4740EEAF1EF7AD964E40C362D4B5F64E4740EEAF1EF7AD964E40
58584	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	просп. Ленина	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58671	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	площадь им.В.И.Ленина	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58673	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Советская	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58589	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Пушкина	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58570	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Набережная им.Н.Островского	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58705	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Ленина проспект	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58704	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Кутузова	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58685	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Космонавтов	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58622	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Кирова	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58672	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Гоголя	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58655	15561	47.090674999999997	47.215496000000002	61.320340000000002	61.295101000000003	Архангельская	0103000020E610000001000000050000004BC8073D9B8B47402A029CDEC5A54E404BC8073D9B8B4740E2CCAFE600A94E409C35785F959B4740E2CCAFE600A94E409C35785F959B47402A029CDEC5A54E404BC8073D9B8B47402A029CDEC5A54E40
58700	12131	40.608414000000003	40.652709999999999	64.401506999999995	64.381197999999998	Катунина	0103000020E61000000100000005000000DB368C82E04D44403DD34B8C65185040DB368C82E04D44405D876A4AB2195040D6E253008C5344405D876A4AB2195040D6E253008C5344403DD34B8C65185040DB368C82E04D44403DD34B8C65185040
58743	57469	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	Ленинградская	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
58610	57469	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	Ленина	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
58684	57469	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	III Интернационала	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
59078	57465	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Некрасова	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58836	57465	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Заводская	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58579	57465	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Дзержинского	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58661	57465	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	 Климовского	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58747	1382	40.531976999999998	40.545172999999998	64.664350999999996	64.657145	улица Школьная	0103000020E61000000100000005000000B29C84D217444440B7EEE6A90E2A5040B29C84D21744444027840EBA842A5040C3D4963AC845444027840EBA842A5040C3D4963AC8454440B7EEE6A90E2A5040B29C84D217444440B7EEE6A90E2A5040
2901	1382	40.566246999999997	40.575868	64.539311999999995	64.528812000000002	улица Смольный Буян	0103000020E61000000100000005000000A33A1DC87A484440DF6E490ED8215040A33A1DC87A484440C8957A16842250400E68E90AB6494440C8957A16842250400E68E90AB6494440DF6E490ED8215040A33A1DC87A484440DF6E490ED8215040
15806	1382	40.515006999999997	40.548684999999999	64.551918000000001	64.548148999999995	улица Садовая	0103000020E61000000100000005000000041BD7BFEB41444072158BDF14235040041BD7BFEB414440B804E09F522350402367614F3B464440B804E09F522350402367614F3B46444072158BDF14235040041BD7BFEB41444072158BDF14235040
3581	1382	40.496915000000001	40.538642000000003	64.689599000000001	64.638779	улица Победы	0103000020E6100000010000000500000028F224E99A3F4440C89750C1E128504028F224E99A3F4440AD16D863222C504043209738F2444440AD16D863222C504043209738F2444440C89750C1E128504028F224E99A3F4440C89750C1E1285040
2843	1382	40.599853000000003	40.603347999999997	64.531407000000002	64.525291999999993	улица Первомайская	0103000020E6100000010000000500000029B4ACFBC74C44406D3656629E21504029B4ACFBC74C44406477819202225040B20DDC813A4D44406477819202225040B20DDC813A4D44406D3656629E21504029B4ACFBC74C44406D3656629E215040
2587	1382	40.597867999999998	40.599834999999999	64.490340000000003	64.476743999999997	улица Нахимова	0103000020E6100000010000000500000097A949F0864C44401C2444F9821E504097A949F0864C4440ECFA05BB611F504082FFAD64C74C4440ECFA05BB611F504082FFAD64C74C44401C2444F9821E504097A949F0864C44401C2444F9821E5040
3657	1382	40.597310999999998	40.634824999999999	64.708310999999995	64.697749999999999	улица Мудьюгская	0103000020E610000001000000050000004145D5AF744C44402DB29DEFA72C50404145D5AF744C44406919A9F7542D504073D712F2415144406919A9F7542D504073D712F2415144402DB29DEFA72C50404145D5AF744C44402DB29DEFA72C5040
3903	1382	40.501012000000003	40.529927999999998	64.583421000000001	64.577599000000006	улица Маяковского	0103000020E61000000100000005000000A873452921404440F3CCCB61F7245040A8734529214044402DB308C5562550400A9E42AED44344402DB308C5562550400A9E42AED4434440F3CCCB61F7245040A873452921404440F3CCCB61F7245040
4023	1382	40.493574000000002	40.524160999999999	64.632653000000005	64.619783999999996	улица Маймаксанская	0103000020E61000000100000005000000F513CE6E2D3F444061A5828AAA275040F513CE6E2D3F4440D82D02637D285040596B28B517434440D82D02637D285040596B28B51743444061A5828AAA275040F513CE6E2D3F444061A5828AAA275040
3891	1382	40.526209000000001	40.538606000000001	64.580586999999994	64.578104999999994	улица Литейная	0103000020E6100000010000000500000031EE06D15A434440DC291DACFF24504031EE06D15A434440E55E605628255040F6B6990AF1444440E55E605628255040F6B6990AF1444440DC291DACFF24504031EE06D15A434440DC291DACFF245040
369	1382	40.636144999999999	40.658746999999998	64.527462	64.516327000000004	улица Ленина	0103000020E61000000100000005000000C84109336D514440ADC266800B215040C84109336D5144407FF8F9EFC121504047AB5AD2515444407FF8F9EFC121504047AB5AD251544440ADC266800B215040C84109336D514440ADC266800B215040
3814	1382	40.586477000000002	40.589396999999998	64.593016000000006	64.588701	улица Кутузова	0103000020E61000000100000005000000986DA7AD114B4440D787F546AD255040986DA7AD114B44404E8061F9F325504025AE635C714B44404E8061F9F325504025AE635C714B4440D787F546AD255040986DA7AD114B4440D787F546AD255040
3397	1382	40.527996999999999	40.545335000000001	64.563655999999995	64.555964000000003	улица Комсомольская	0103000020E610000001000000050000006CB1DB6795434440377007EA942350406CB1DB67954344406D8C9DF0122450409D2E8B89CD4544406D8C9DF0122450409D2E8B89CD454440377007EA942350406CB1DB6795434440377007EA94235040
3779	1382	40.562618000000001	40.595488000000003	64.597066999999996	64.591453000000001	улица Кировская	0103000020E610000001000000050000000A12DBDD03484440C007AF5DDA2550400A12DBDD0348444055A18158362650408A9466F3384C444055A18158362650408A9466F3384C4440C007AF5DDA2550400A12DBDD03484440C007AF5DDA255040
4062	1382	40.701830000000001	40.703913999999997	64.491563999999997	64.488972000000004	улица Кирова	0103000020E6100000010000000500000004ADC090D5594440392A37514B1F504004ADC090D559444005F9D9C8751F504028999CDA195A444005F9D9C8751F504028999CDA195A4440392A37514B1F504004ADC090D5594440392A37514B1F5040
3948	1382	40.503473	40.526048000000003	64.587863999999996	64.586764000000002	улица Кедрова	0103000020E61000000100000005000000A2B5A2CD71404440179E978A8D255040A2B5A2CD71404440BA9F53909F2550402810768A55434440BA9F53909F2550402810768A55434440179E978A8D255040A2B5A2CD71404440179E978A8D255040
3652	1382	40.502834999999997	40.512627000000002	64.700072000000006	64.690268000000003	улица Капитана Хромцова	0103000020E610000001000000050000005F24B4E55C4044406C5ED5592D2C50405F24B4E55C4044401A36CAFACD2C5040F705F4C29D4144401A36CAFACD2C5040F705F4C29D4144406C5ED5592D2C50405F24B4E55C4044406C5ED5592D2C5040
58773	1382	40.4679	40.484375	64.628282999999996	64.612678000000002	Юнг ВМФ	0103000020E6100000010000000500000032E6AE25E43B4440A33EC91D3627504032E6AE25E43B44407F68E6C93528504000000000003E44407F68E6C93528504000000000003E4440A33EC91D3627504032E6AE25E43B4440A33EC91D36275040
59054	1382	40.486153999999999	40.486539999999998	64.679357999999993	64.675275999999997	Чупрова	0103000020E61000000100000005000000E868554B3A3E444084F1D3B8372B5040E868554B3A3E4440A911FA997A2B5040111956F1463E4440A911FA997A2B5040111956F1463E444084F1D3B8372B5040E868554B3A3E444084F1D3B8372B5040
58575	1382	40.517091999999998	40.538220000000003	64.540835000000001	64.531554	Чумбарова-Лучинского проспект	0103000020E61000000100000005000000F982161230424440B68311FB04225040F9821612304244400F62670A9D225040CD069964E44444400F62670A9D225040CD069964E4444440B68311FB04225040F982161230424440B68311FB04225040
58893	1382	40.587249999999997	40.592450999999997	64.620196000000007	64.616842000000005	Центральная	0103000020E61000000100000005000000BA490C022B4B44402733DE567A275040BA490C022B4B44400B47904AB1275040C2BD326FD54B44400B47904AB1275040C2BD326FD54B44402733DE567A275040BA490C022B4B44402733DE567A275040
58668	1382	40.601146999999997	40.625177000000001	64.527782999999999	64.523814000000002	Фёдора Абрамова	0103000020E61000000100000005000000548B8862F24C4440F7CB272B86215040548B8862F24C4440A0185932C72150400F9BC8CC05504440A0185932C72150400F9BC8CC05504440F7CB272B86215040548B8862F24C4440F7CB272B86215040
58776	1382	40.555135	40.570495999999999	64.540321000000006	64.526874000000007	Урицкого	0103000020E61000000100000005000000B7EEE6A90E47444037C7B94DB8215040B7EEE6A90E474440E415889E94225040D93F4F0306494440E415889E94225040D93F4F030649444037C7B94DB8215040B7EEE6A90E47444037C7B94DB8215040
3277	1382	40.514324999999999	40.536557999999999	64.564954	64.531024000000002	Троицкий проспект	0103000020E61000000100000005000000F241CF66D54144400859164CFC215040F241CF66D5414440A46FD234282450401E34BBEEAD444440A46FD234282450401E34BBEEAD4444400859164CFC215040F241CF66D54144400859164CFC215040
58772	1382	40.55368	40.575868	64.555964000000003	64.539311999999995	Тимме	0103000020E6100000010000000500000082397AFCDE464440C8957A168422504082397AFCDE464440377007EA942350400E68E90AB6494440377007EA942350400E68E90AB6494440C8957A168422504082397AFCDE464440C8957A1684225040
58761	1382	40.507848000000003	40.524709000000001	64.579995999999994	64.576764999999995	Терёхина	0103000020E6100000010000000500000065ABCB29014144408E1EBFB7E924504065ABCB2901414440E4F38AA71E2550405C751DAA29434440E4F38AA71E2550405C751DAA294344408E1EBFB7E924504065ABCB29014144408E1EBFB7E9245040
58880	1382	40.539999000000002	40.561576000000002	64.517143000000004	64.513997000000003	Сурповская	0103000020E61000000100000005000000B56FEEAF1E4544407F4FAC53E5205040B56FEEAF1E454440BE16F4DE18215040F81BEDB8E1474440BE16F4DE18215040F81BEDB8E14744407F4FAC53E5205040B56FEEAF1E4544407F4FAC53E5205040
58784	1382	40.522697000000001	40.542935999999997	64.561094999999995	64.554777999999999	Суворова	0103000020E61000000100000005000000D15B3CBCE742444094A2957B81235040D15B3CBCE7424440BEBC00FBE823504018E945ED7E454440BEBC00FBE823504018E945ED7E45444094A2957B81235040D15B3CBCE742444094A2957B81235040
58787	1382	40.325642999999999	40.333008999999997	64.538704999999993	64.534919000000002	Стивидорская	0103000020E61000000100000005000000EE9579ABAE29444094C0E61C3C225040EE9579ABAE294440444C89247A2250400723F609A02A4440444C89247A2250400723F609A02A444094C0E61C3C225040EE9579ABAE29444094C0E61C3C225040
59043	1382	40.417765000000003	40.418438999999999	64.698049999999995	64.696354999999997	Стадионная	0103000020E61000000100000005000000EC34D25279354440FDD98F14912C5040EC34D25279354440423EE8D9AC2C50407B2FBE688F354440423EE8D9AC2C50407B2FBE688F354440FDD98F14912C5040EC34D25279354440FDD98F14912C5040
3082	1382	40.531860000000002	40.549709	64.559247999999997	64.535781	Советских Космонавтов проспект	0103000020E6100000010000000500000079060DFD134444405D34643C4A22504079060DFD134444409E961FB8CA2350408FA850DD5C4644409E961FB8CA2350408FA850DD5C4644405D34643C4A22504079060DFD134444405D34643C4A225040
58754	1382	40.566246999999997	40.575868	64.539311999999995	64.528812000000002	Смольный Буян	0103000020E61000000100000005000000A33A1DC87A484440DF6E490ED8215040A33A1DC87A484440C8957A16842250400E68E90AB6494440C8957A16842250400E68E90AB6494440DF6E490ED8215040A33A1DC87A484440DF6E490ED8215040
58771	1382	40.770893000000001	40.781151000000001	64.481932999999998	64.481680999999995	Силикатчиков	0103000020E6100000010000000500000090DB2F9FAC624440B1868BDCD31E504090DB2F9FAC6244403E7782FDD71E50406D1E87C1FC6344403E7782FDD71E50406D1E87C1FC634440B1868BDCD31E504090DB2F9FAC624440B1868BDCD31E5040
58748	1382	40.348145000000002	40.352915000000003	64.527957000000001	64.524598999999995	Севстрой	0103000020E610000001000000050000000AA2EE03902C4440EA20AF07932150400AA2EE03902C44406F2C280CCA21504049A297512C2D44406F2C280CCA21504049A297512C2D4440EA20AF07932150400AA2EE03902C4440EA20AF0793215040
2979	1382	40.508665000000001	40.565178000000003	64.567226000000005	64.525047999999998	Северной Двины набережная	0103000020E6100000010000000500000057CF49EF1B4144402235ED629A21504057CF49EF1B41444038DC476E4D2450409835B1C05748444038DC476E4D2450409835B1C0574844402235ED629A21504057CF49EF1B4144402235ED629A215040
58769	1382	40.563400000000001	40.569257	64.533835999999994	64.532397000000003	Розы Шаниной	0103000020E610000001000000050000008048BF7D1D48444044DFDDCA122250408048BF7D1D4844405B5B785E2A2250407102D369DD4844405B5B785E2A2250407102D369DD48444044DFDDCA122250408048BF7D1D48444044DFDDCA12225040
58778	1382	40.493529000000002	40.500185000000002	64.687961000000001	64.685146000000003	Родионова	0103000020E61000000100000005000000555051F52B3F44400EBF9B6ED92B5040555051F52B3F44401AFB928D072C50409279E40F064044401AFB928D072C50409279E40F064044400EBF9B6ED92B5040555051F52B3F44400EBF9B6ED92B5040
58757	1382	40.650303000000001	40.665601000000002	64.462180000000004	64.455804999999998	Речников	0103000020E61000000100000005000000CFBEF2203D5344409C16BCE82B1D5040CFBEF2203D53444061376C5B941D5040AB97DF693255444061376C5B941D5040AB97DF69325544409C16BCE82B1D5040CFBEF2203D5344409C16BCE82B1D5040
58865	1382	40.628554999999999	40.634421000000003	64.527771000000001	64.526847000000004	Пугачева	0103000020E610000001000000050000005F5E807D74504440BABF7ADCB72150405F5E807D74504440BE310400C7215040A47213B534514440BE310400C7215040A47213B534514440BABF7ADCB72150405F5E807D74504440BABF7ADCB7215040
58653	1382	40.610408999999997	40.624583999999999	64.53546	64.523635999999996	Прокопия Галушина	0103000020E610000001000000050000008F17D2E1214E444087C09140832150408F17D2E1214E44403C1405FA442250406CCD565EF24F44403C1405FA442250406CCD565EF24F444087C09140832150408F17D2E1214E444087C0914083215040
3236	1382	40.548397999999999	40.550184999999999	64.550000999999995	64.546436999999997	Приорова проезд	0103000020E610000001000000050000008D98D9E731464440C214E5D2F82250408D98D9E7314644401BF1643733235040F8DF4A766C4644401BF1643733235040F8DF4A766C464440C214E5D2F82250408D98D9E731464440C214E5D2F8225040
58785	1382	40.468079000000003	40.472427000000003	64.588774999999998	64.581277999999998	Приморская	0103000020E61000000100000005000000E2783E03EA3B444098F8A3A833255040E2783E03EA3B4440F46C567DAE255040AB5FE97C783C4440F46C567DAE255040AB5FE97C783C444098F8A3A833255040E2783E03EA3B444098F8A3A833255040
58788	1382	40.525526999999997	40.527071999999997	64.594054	64.583416999999997	Полярная	0103000020E610000001000000050000001E15FF77444344408CBB41B4562550401E15FF7744434440B68311FB042650409351651877434440B68311FB0426504093516518774344408CBB41B4562550401E15FF77444344408CBB41B456255040
58864	1382	40.496915000000001	40.538642000000003	64.689599000000001	64.638779	Победы	0103000020E6100000010000000500000028F224E99A3F4440C89750C1E128504028F224E99A3F4440AD16D863222C504043209738F2444440AD16D863222C504043209738F2444440C89750C1E128504028F224E99A3F4440C89750C1E1285040
58871	1382	40.515034	40.536656999999998	64.518760999999998	64.513378000000003	Пирсовая	0103000020E61000000100000005000000FE2955A2EC414440191F662FDB205040FE2955A2EC4144402D5C566133215040B115342DB14444402D5C566133215040B115342DB1444440191F662FDB205040FE2955A2EC414440191F662FDB205040
58751	1382	40.422525999999998	40.436908000000003	64.544087000000005	64.538013000000007	Пионерская	0103000020E61000000100000005000000D7DAFB5415364440AAF413CE6E225040D7DAFB541536444071CB4752D22250402EAEF199EC37444071CB4752D22250402EAEF199EC374440AAF413CE6E225040D7DAFB5415364440AAF413CE6E225040
58792	1382	40.582659999999997	40.593331999999997	64.603590999999994	64.587345999999997	Партизанская	0103000020E61000000100000005000000FB57569A944A4440EE5BAD1397255040FB57569A944A44403C4A253CA1265040CBD58F4DF24B44403C4A253CA1265040CBD58F4DF24B4440EE5BAD1397255040FB57569A944A4440EE5BAD1397255040
2924	1382	40.536000999999999	40.571241999999998	64.561717000000002	64.534268999999995	Обводный Канал проспект	0103000020E61000000100000005000000C8CF46AE9B44444010919A7631225040C8CF46AE9B444440DD26DC2BF3235040020D36751E494440DD26DC2BF3235040020D36751E49444010919A7631225040C8CF46AE9B44444010919A7631225040
2830	1382	40.527853	40.562860999999998	64.553522000000001	64.531166999999996	Новгородский проспект	0103000020E61000000100000005000000390CE6AF90434440B96DDFA3FE215040390CE6AF9043444075E789E76C235040D09849D40B48444075E789E76C235040D09849D40B484440B96DDFA3FE215040390CE6AF90434440B96DDFA3FE215040
3969	1382	40.503168000000002	40.522283999999999	64.589090999999996	64.566322	Никольский проспект	0103000020E6100000010000000500000066321CCF674044405740A19E3E24504066321CCF674044408CD7BCAAB3255040AE9CBD33DA4244408CD7BCAAB3255040AE9CBD33DA4244405740A19E3E24504066321CCF674044405740A19E3E245040
58779	1382	40.665546999999997	40.675778999999999	64.512174000000002	64.507564000000002	Никитова	0103000020E61000000100000005000000B779E3A4305544402028B7ED7B205040B779E3A43055444023F77475C72050406B2920ED7F56444023F77475C72050406B2920ED7F5644402028B7ED7B205040B779E3A4305544402028B7ED7B205040
4220	1382	40.571241999999998	40.620047	64.534268999999995	64.531283000000002	Московский проспект	0103000020E61000000100000005000000020D36751E494440EE7A698A00225040020D36751E49444010919A7631225040D07D39B35D4F444010919A7631225040D07D39B35D4F4440EE7A698A00225040020D36751E494440EE7A698A00225040
58783	1382	40.526757000000003	40.541139000000001	64.644649999999999	64.642191999999994	Менделеева	0103000020E6100000010000000500000034F8FBC56C4344402E7079AC1929504034F8FBC56C43444073D712F2412950408ACBF10A4445444073D712F2412950408ACBF10A444544402E7079AC1929504034F8FBC56C4344402E7079AC19295040
58755	1382	40.332999999999998	40.345962	64.531519000000003	64.527890999999997	Матросова	0103000020E61000000100000005000000B4C876BE9F2A4440933655F7C8215040B4C876BE9F2A4440F88C44680422504052D4997B482C4440F88C44680422504052D4997B482C4440933655F7C8215040B4C876BE9F2A4440933655F7C8215040
58768	1382	40.494750000000003	40.500067999999999	64.619783999999996	64.605107000000004	Маслова	0103000020E6100000010000000500000017D9CEF7533F44402AE5B512BA26504017D9CEF7533F444061A5828AAA27504058E36C3A0240444061A5828AAA27504058E36C3A024044402AE5B512BA26504017D9CEF7533F44402AE5B512BA265040
58774	1382	40.579129000000002	40.599412999999998	64.601384999999993	64.597862000000006	Малиновского	0103000020E61000000100000005000000259529E6204A44405B61FA5E43265040259529E6204A444084D382177D2650400CE6AF90B94C444084D382177D2650400CE6AF90B94C44405B61FA5E43265040259529E6204A44405B61FA5E43265040
58758	1382	40.456859999999999	40.470981000000002	64.627084999999994	64.625095999999999	Луганская	0103000020E61000000100000005000000DF6C73637A3A44401137A79201285040DF6C73637A3A4440FAB31F2922285040C904FC1A493C4440FAB31F2922285040C904FC1A493C44401137A79201285040DF6C73637A3A44401137A79201285040
2889	1382	40.522032000000003	40.565834000000002	64.562753000000001	64.528486999999998	Ломоносова проспект	0103000020E6100000010000000500000095BBCFF1D14244401D5723BBD221504095BBCFF1D142444075AE282504245040817B9E3F6D48444075AE282504245040817B9E3F6D4844401D5723BBD221504095BBCFF1D14244401D5723BBD2215040
58770	1382	40.540635999999999	40.545577000000002	64.658797000000007	64.656779999999998	Лесотехническая	0103000020E610000001000000050000002785798F33454440AE2AFBAE082A50402785798F33454440FD6CE4BA292A504093399677D5454440FD6CE4BA292A504093399677D5454440AE2AFBAE082A50402785798F33454440AE2AFBAE082A5040
58749	1382	40.626246000000002	40.639037999999999	64.507075999999998	64.498526999999996	Лермонтова	0103000020E610000001000000050000001BA034D428504440124BCADDE71F50401BA034D4285044408925E5EE732050405C7347FFCB5144408925E5EE732050405C7347FFCB514440124BCADDE71F50401BA034D428504440124BCADDE71F5040
2862	1382	40.565834000000002	40.744526999999998	64.528486999999998	64.484392999999997	Ленинградский проспект	0103000020E61000000100000005000000817B9E3F6D484440535A7F4B001F5040817B9E3F6D4844401D5723BBD221504097FE25A94C5F44401D5723BBD221504097FE25A94C5F4440535A7F4B001F5040817B9E3F6D484440535A7F4B001F5040
15817	1382	40.515923999999998	40.520648999999999	64.540383000000006	64.537780999999995	Ленина площадь	0103000020E610000001000000050000005A9C31CC0942444040DAFF006B2250405A9C31CC094244401F1494A295225040F9D85DA0A44244401F1494A295225040F9D85DA0A442444040DAFF006B2250405A9C31CC0942444040DAFF006B225040
58752	1382	40.510705000000002	40.524673	64.576722000000004	64.573262	Краснофлотская	0103000020E61000000100000005000000AC730CC85E41444088821953B0245040AC730CC85E4144408F386403E92450400F0C207C284344408F386403E92450400F0C207C2843444088821953B0245040AC730CC85E41444088821953B0245040
58759	1382	40.621575	40.622481999999998	64.432205999999994	64.430001000000004	Клепача	0103000020E610000001000000050000006F8104C58F4F4440D40FEA22851B50406F8104C58F4F4440A3C85A43A91B5040A12C7C7DAD4F4440A3C85A43A91B5040A12C7C7DAD4F4440D40FEA22851B50406F8104C58F4F4440D40FEA22851B5040
58764	1382	40.326262	40.340733999999998	64.551198999999997	64.544190999999998	Кирпичного Завода	0103000020E61000000100000005000000BAF605F4C2294440C3F17C06D4225040BAF605F4C2294440A0A52BD8462350405051F52B9D2B4440A0A52BD8462350405051F52B9D2B4440C3F17C06D4225040BAF605F4C2294440C3F17C06D4225040
58780	1382	40.562618000000001	40.595488000000003	64.597066999999996	64.591453000000001	Кировская	0103000020E610000001000000050000000A12DBDD03484440C007AF5DDA2550400A12DBDD0348444055A18158362650408A9466F3384C444055A18158362650408A9466F3384C4440C007AF5DDA2550400A12DBDD03484440C007AF5DDA255040
58775	1382	40.503473	40.526048000000003	64.587863999999996	64.586764000000002	Кедрова	0103000020E61000000100000005000000A2B5A2CD71404440179E978A8D255040A2B5A2CD71404440BA9F53909F2550402810768A55434440BA9F53909F2550402810768A55434440179E978A8D255040A2B5A2CD71404440179E978A8D255040
59051	1382	40.392997999999999	40.434707000000003	64.541754999999995	64.534516999999994	Кегостровская	0103000020E610000001000000050000005BB22AC24D324440FC89CA86352250405BB22AC24D32444072DC291DAC225040D02B9E7AA437444072DC291DAC225040D02B9E7AA4374440FC89CA86352250405BB22AC24D324440FC89CA8635225040
58753	1382	40.686891000000003	40.693556999999998	64.505550999999997	64.502414999999999	Квартальная	0103000020E610000001000000050000005875560BEC57444045813E91272050405875560BEC57444072DD94F25A205040B874CC79C658444072DD94F25A205040B874CC79C658444045813E91272050405875560BEC57444045813E9127205040
58777	1382	40.641337999999998	40.651848000000001	64.518253999999999	64.513304000000005	Калинина	0103000020E610000001000000050000004DD7135D17524440FC3905F9D92050404DD7135D175244405B41D3122B21504044FB58C16F5344405B41D3122B21504044FB58C16F534440FC3905F9D92050404DD7135D17524440FC3905F9D9205040
58786	1382	40.573352999999997	40.581060999999998	64.603309999999993	64.587590000000006	Ильича	0103000020E61000000100000005000000200890A1634944403A5D16139B255040200890A16349444062D68BA19C26504093FDF334604A444062D68BA19C26504093FDF334604A44403A5D16139B255040200890A1634944403A5D16139B255040
58867	1382	40.420234999999998	40.435327000000001	64.515112000000002	64.514100999999997	Зеленец	0103000020E6100000010000000500000039D1AE42CA354440D175E107E720504039D1AE42CA354440BD715298F72050406C088ECBB8374440BD715298F72050406C088ECBB8374440D175E107E720504039D1AE42CA354440D175E107E7205040
59057	1382	40.606645	40.608127000000003	64.437984999999998	64.430828000000005	Железнодорожная	0103000020E6100000010000000500000016A4198BA64D4440DF8C9AAF921B504016A4198BA64D4440DEC83CF2071C50404568041BD74D4440DEC83CF2071C50404568041BD74D4440DF8C9AAF921B504016A4198BA64D4440DF8C9AAF921B5040
58767	1382	40.493547	40.507722000000001	64.649255999999994	64.645912999999993	Емецкая	0103000020E61000000100000005000000FB04508C2C3F4440EBC37AA356295040FB04508C2C3F4440D5AE09698D295040D8BAD408FD404440D5AE09698D295040D8BAD408FD404440EBC37AA356295040FB04508C2C3F4440EBC37AA356295040
58875	1382	40.543295000000001	40.590088999999999	64.518063999999995	64.498035999999999	Дрейера	0103000020E61000000100000005000000488AC8B08A454440C30E63D2DF1F5040488AC8B08A454440094FE8F5272150405B5D4E09884B4440094FE8F5272150405B5D4E09884B4440C30E63D2DF1F5040488AC8B08A454440C30E63D2DF1F5040
3173	1382	40.562519000000002	40.575724999999998	64.559673000000004	64.546865999999994	Дзержинского проспект	0103000020E610000001000000050000007730629F00484440D65240DAFF2250407730629F0048444012DDB3AED1235040AB3E575BB149444012DDB3AED1235040AB3E575BB1494440D65240DAFF2250407730629F00484440D65240DAFF225040
58760	1382	40.576523999999999	40.597867999999998	64.510243000000003	64.490340000000003	Дежнёвцев	0103000020E61000000100000005000000F7ADD689CB494440ECFA05BB611F5040F7ADD689CB494440D48041D2A720504097A949F0864C4440D48041D2A720504097A949F0864C4440ECFA05BB611F5040F7ADD689CB494440ECFA05BB611F5040
58789	1382	40.658253000000002	40.694750999999997	64.523470000000003	64.510107000000005	Дачная	0103000020E6100000010000000500000038BF61A2415444407C9DD497A520504038BF61A241544440FA9B50888021504080EECB99ED584440FA9B50888021504080EECB99ED5844407C9DD497A520504038BF61A2415444407C9DD497A5205040
58728	1382	40.499979000000003	40.503473	64.586764000000002	64.576258999999993	Георгия Седова набережная	0103000020E61000000100000005000000E9D7D64FFF3F4440A4C16D6DE1245040E9D7D64FFF3F4440179E978A8D255040A2B5A2CD71404440179E978A8D255040A2B5A2CD71404440A4C16D6DE1245040E9D7D64FFF3F4440A4C16D6DE1245040
58619	1382	40.533377999999999	40.566526000000003	64.566449000000006	64.554858999999993	Гагарина	0103000020E61000000100000005000000F433F5BA454444400AB952CF82235040F433F5BA4544444086764EB340245040B72A89EC8348444086764EB340245040B72A89EC834844400AB952CF82235040F433F5BA454444400AB952CF82235040
58766	1382	40.514747	40.570990000000002	64.549853999999996	64.538233000000005	Воскресенская	0103000020E61000000100000005000000685BCD3AE34144403128D36872225040685BCD3AE3414440C9E4D4CE30235040E92B483316494440C9E4D4CE30235040E92B4833164944403128D36872225040685BCD3AE34144403128D36872225040
58762	1382	40.661729000000001	40.689011000000001	64.518895999999998	64.501210999999998	Воронина	0103000020E610000001000000050000004BE82E89B35444404F594DD7132050404BE82E89B35444409D81919735215040C9CA2F83315844409D81919735215040C9CA2F83315844404F594DD7132050404BE82E89B35444404F594DD713205040
58781	1382	40.597678999999999	40.607678	64.485048000000006	64.465762999999995	Адмирала Макарова	0103000020E61000000100000005000000C440D7BE804C4440F52B9D0FCF1D5040C440D7BE804C4440603FC4060B1F5040D53F8864C84D4440603FC4060B1F5040D53F8864C84D4440F52B9D0FCF1D5040C440D7BE804C4440F52B9D0FCF1D5040
58702	1382	40.699458999999997	40.709851999999998	64.594992000000005	64.586555000000004	Авиационная	0103000020E6100000010000000500000049F25CDF875944408A93FB1D8A25504049F25CDF875944406D5853591426504006802A6EDC5A44406D5853591426504006802A6EDC5A44408A93FB1D8A25504049F25CDF875944408A93FB1D8A255040
58765	1382	40.557946999999999	40.575795999999997	64.546865999999994	64.542760999999999	23-й Гвардейской Дивизии	0103000020E610000001000000050000005EF3AACE6A474440D522A298BC2250405EF3AACE6A474440D65240DAFF2250407495EEAEB3494440D65240DAFF2250407495EEAEB3494440D522A298BC2250405EF3AACE6A474440D522A298BC225040
2678	1382	40.478985000000002	40.480502999999999	64.593433000000005	64.589404000000002	2-я линия	0103000020E61000000100000005000000252367614F3D44406C088ECBB8255040252367614F3D444080D767CEFA255040A0504F1F813D444080D767CEFA255040A0504F1F813D44406C088ECBB8255040252367614F3D44406C088ECBB8255040
58782	1382	40.622050999999999	40.636136	64.457138999999998	64.455363000000006	100-й Дивизии	0103000020E61000000100000005000000D8B8FE5D9F4F4440BE33DAAA241D5040D8B8FE5D9F4F444079AEEFC3411D504075E789E76C51444079AEEFC3411D504075E789E76C514440BE33DAAA241D5040D8B8FE5D9F4F4440BE33DAAA241D5040
3864	1382	40.51914	40.520442000000003	64.571382	64.570721000000006	1-й Банный переулок	0103000020E61000000100000005000000D105F52D73424440FD885FB186245040D105F52D734244407AE1CE859124504080BBECD79D4244407AE1CE859124504080BBECD79D424440FD885FB186245040D105F52D73424440FD885FB186245040
58811	19758	42.775320999999998	42.826391000000001	62.121547	62.095947000000002	Школьная	0103000020E610000001000000050000007573F1B73D6345401D93C5FD470C4F407573F1B73D634540A5F622DA8E0F4F40B85A272EC7694540A5F622DA8E0F4F40B85A272EC76945401D93C5FD470C4F407573F1B73D6345401D93C5FD470C4F40
58676	21176	42.881898	42.938231000000002	62.116292000000001	62.095112999999998	Мира	0103000020E6100000010000000500000033349E08E27045405436ACA92C0C4F4033349E08E2704540AA6400A8E20E4F40F48B12F417784540AA6400A8E20E4F40F48B12F4177845405436ACA92C0C4F4033349E08E27045405436ACA92C0C4F40
58663	21176	42.881898	42.938231000000002	62.116292000000001	62.095112999999998	Кудрявцева	0103000020E6100000010000000500000033349E08E27045405436ACA92C0C4F4033349E08E2704540AA6400A8E20E4F40F48B12F417784540AA6400A8E20E4F40F48B12F4177845405436ACA92C0C4F4033349E08E27045405436ACA92C0C4F40
58866	57483	42.714478999999997	42.738472999999999	61.967683999999998	61.950614999999999	Школьная	0103000020E61000000100000005000000E256410C745B4540240B98C0ADF94E40E256410C745B4540656EBE11DDFB4E4050FD8348865E4540656EBE11DDFB4E4050FD8348865E4540240B98C0ADF94E40E256410C745B4540240B98C0ADF94E40
58842	20986	42.936767000000003	42.968819000000003	62.382623000000002	62.366655000000002	Новая	0103000020E610000001000000050000006C7C26FBE77745401BF5108DEE2E4F406C7C26FBE777454045D95BCAF9304F40295FD042027C454045D95BCAF9304F40295FD042027C45401BF5108DEE2E4F406C7C26FBE77745401BF5108DEE2E4F40
58964	21043	42.936568999999999	42.953907000000001	62.307605000000002	62.300606000000002	Ивановская	0103000020E6100000010000000500000045B9347EE17745409E7DE5417A264F4045B9347EE1774540058BC3995F274F407636E49F197A4540058BC3995F274F407636E49F197A45409E7DE5417A264F4045B9347EE17745409E7DE5417A264F40
58909	20376	42.625535999999997	42.666176	61.916528	61.899068999999997	Новостроек	0103000020E610000001000000050000003E3C4B901150454078EC67B114F34E403E3C4B901150454024EF1CCA50F54E40A7B052414555454024EF1CCA50F54E40A7B052414555454078EC67B114F34E403E3C4B901150454078EC67B114F34E40
58963	19363	41.861033999999997	41.888351999999998	62.341692999999999	62.334242000000003	Школьная	0103000020E610000001000000050000003D5FB35C36EE44408E791D71C82A4F403D5FB35C36EE4440D522A298BC2B4F4008ABB184B5F14440D522A298BC2B4F4008ABB184B5F144408E791D71C82A4F403D5FB35C36EE44408E791D71C82A4F40
58795	21599	42.696511999999998	42.699953000000001	61.887045000000001	61.883628000000002	Набережная	0103000020E61000000100000005000000C2A2224E275945403AEAE8B81AF14E40C2A2224E27594540488AC8B08AF14E4059DE550F98594540488AC8B08AF14E4059DE550F985945403AEAE8B81AF14E40C2A2224E275945403AEAE8B81AF14E40
59069	19896	42.513139000000002	42.561450999999998	61.694225000000003	61.677194	Пионерская	0103000020E61000000100000005000000ADA6EB89AE4145401286014BAED64E40ADA6EB89AE4145406688635DDCD84E403BA759A0DD4745406688635DDCD84E403BA759A0DD4745401286014BAED64E40ADA6EB89AE4145401286014BAED64E40
58847	20660	42.968854	42.994509999999998	62.11721	62.106802999999999	Лесной переулок	0103000020E61000000100000005000000A54C6A68037C4540AE0E80B8AB0D4F40A54C6A68037C4540D061BEBC000F4F40C1C58A1A4C7F4540D061BEBC000F4F40C1C58A1A4C7F4540AE0E80B8AB0D4F40A54C6A68037C4540AE0E80B8AB0D4F40
58925	57493	41.218899999999998	44.083995999999999	62.704698	61.593997000000002	50 лет МТС	0103000020E61000000100000005000000158C4AEA049C44400876FC1708CC4E40158C4AEA049C44403FC7478B335A4F40567F8461C00A46403FC7478B335A4F40567F8461C00A46400876FC1708CC4E40158C4AEA049C44400876FC1708CC4E40
58725	17430	41.630175999999999	41.666046000000001	64.236710000000002	64.216200999999998	Октябрьская	0103000020E61000000100000005000000AF5C6F9BA9D044403317B83CD60D5040AF5C6F9BA9D04440B728B341260F5040D9D0CDFE40D54440B728B341260F5040D9D0CDFE40D544403317B83CD60D5040AF5C6F9BA9D044403317B83CD60D5040
58662	17835	41.643507	41.657879999999999	64.189657999999994	64.185948999999994	А.Д.Шиловского	0103000020E61000000100000005000000A0DFF76F5ED24440546EA296E60B5040A0DFF76F5ED244402FDB4E5B230C5040A3586E6935D444402FDB4E5B230C5040A3586E6935D44440546EA296E60B5040A0DFF76F5ED24440546EA296E60B5040
58970	20877	41.997900999999999	42.004702000000002	63.322983000000001	63.319037000000002	Сосновая	0103000020E61000000100000005000000A6D24F38BBFF4440639B5434D6A84F40A6D24F38BBFF4440FD14C78157A94F40E71C3C139A004540FD14C78157A94F40E71C3C139A004540639B5434D6A84F40A6D24F38BBFF4440639B5434D6A84F40
58967	18884	41.787317999999999	41.923394999999999	63.626866999999997	63.519241000000001	Почтовая	0103000020E61000000100000005000000ACC612D6C6E4444005DF347D76C24F40ACC612D6C6E4444087F8872D3DD04F401C25AFCE31F6444087F8872D3DD04F401C25AFCE31F6444005DF347D76C24F40ACC612D6C6E4444005DF347D76C24F40
58962	18499	41.471066	41.493470000000002	63.882460999999999	63.867454000000002	Кольцевая	0103000020E61000000100000005000000F72004E44BBC4440676490BB08EF4F40F72004E44BBC44406B7F677BF4F04F4050C763062ABF44406B7F677BF4F04F4050C763062ABF4440676490BB08EF4F40F72004E44BBC4440676490BB08EF4F40
58587	17696	41.910262000000003	41.932603	64.305479000000005	64.288482000000002	Советская	0103000020E610000001000000050000005265187783F4444005DF347D761250405265187783F4444059A7CAF78C1350406493FC885FF7444059A7CAF78C1350406493FC885FF7444005DF347D761250405265187783F4444005DF347D76125040
58961	18565	41.644494999999999	41.677230000000002	63.853850000000001	63.845156000000003	Гаражная	0103000020E61000000100000005000000BFB7E9CF7ED24440540262122EEC4F40BFB7E9CF7ED2444045D8F0F44AED4F405FEFFE78AFD6444045D8F0F44AED4F405FEFFE78AFD64440540262122EEC4F40BFB7E9CF7ED24440540262122EEC4F40
58620	18711	41.777545000000003	41.796301	63.479500999999999	63.469352999999998	Горончаровского	0103000020E610000001000000050000008C15359886E34440C6A354C213BC4F408C15359886E344401CB3EC4960BD4F40D462F030EDE544401CB3EC4960BD4F40D462F030EDE54440C6A354C213BC4F408C15359886E34440C6A354C213BC4F40
58846	19287	42.010083000000002	42.032755999999999	63.354317000000002	63.340355000000002	Лесная	0103000020E610000001000000050000006F9F55664A014540DA03ADC090AB4F406F9F55664A0145405BB56B425AAD4F40B75F3E59310445405BB56B425AAD4F40B75F3E5931044540DA03ADC090AB4F406F9F55664A014540DA03ADC090AB4F40
58790	18586	41.409728999999999	41.435510999999998	63.743307000000001	63.723343	Набережная	0103000020E61000000100000005000000849CF7FF71B444403065E08096DC4F40849CF7FF71B44440A6F10BAF24DF4F402D060FD3BEB74440A6F10BAF24DF4F402D060FD3BEB744403065E08096DC4F40849CF7FF71B444403065E08096DC4F40
58831	18095	42.319543000000003	42.357084	64.196854999999999	64.179716999999997	Советская	0103000020E610000001000000050000003755F7C8E62845404162BB7B800B50403755F7C8E628454076C3B645990C504062F6B2EDB42D454076C3B645990C504062F6B2EDB42D45404162BB7B800B50403755F7C8E62845404162BB7B800B5040
59050	57515	42.785293000000003	45.362046999999997	61.864997000000002	60.729216000000001	Центральная	0103000020E610000001000000050000008D63247B8464454027DC2BF3565D4E408D63247B84644540AE11C138B8EE4E40B54E5C8E57AE4640AE11C138B8EE4E40B54E5C8E57AE464027DC2BF3565D4E408D63247B8464454027DC2BF3565D4E40
58959	16718	43.645367	43.677194	61.043044999999999	61.032471999999999	Первомайская	0103000020E610000001000000050000007575C7629BD245409204E10A28844E407575C7629BD24540CFA0A17F82854E401286014BAED64540CFA0A17F82854E401286014BAED645409204E10A28844E407575C7629BD245409204E10A28844E40
58859	15947	43.324452999999998	43.344583999999998	61.136476000000002	61.12247	Ленина	0103000020E61000000100000005000000670B08AD87A94540DD5ED218AD8F4E40670B08AD87A945402E58AA0B78914E40C85C19541BAC45402E58AA0B78914E40C85C19541BAC4540DD5ED218AD8F4E40670B08AD87A94540DD5ED218AD8F4E40
58715	15947	43.324452999999998	43.344583999999998	61.136476000000002	61.12247	50 лет Октября	0103000020E61000000100000005000000670B08AD87A94540DD5ED218AD8F4E40670B08AD87A945402E58AA0B78914E40C85C19541BAC45402E58AA0B78914E40C85C19541BAC4540DD5ED218AD8F4E40670B08AD87A94540DD5ED218AD8F4E40
58808	16567	43.105874999999997	43.115442000000002	60.891995999999999	60.885525999999999	Строительная	0103000020E61000000100000005000000643BDF4F8D8D4540FCE07CEA58714E40643BDF4F8D8D4540D714C8EC2C724E40DC4AAFCDC68E4540D714C8EC2C724E40DC4AAFCDC68E4540FCE07CEA58714E40643BDF4F8D8D4540FCE07CEA58714E40
59030	15511	43.713872000000002	43.745789000000002	61.478033000000003	61.471885	Школьная	0103000020E61000000100000005000000DBC35E2860DB45408A3C49BA66BC4E40DBC35E2860DB454053B4722F30BD4E40B85B920376DF454053B4722F30BD4E40B85B920376DF45408A3C49BA66BC4E40DBC35E2860DB45408A3C49BA66BC4E40
58874	15610	43.695556000000003	43.722324999999998	61.410606999999999	61.397404000000002	Центральная	0103000020E61000000100000005000000AF44A0FA07D9454059A65F22DEB24E40AF44A0FA07D945401C412AC58EB44E40A60A462575DC45401C412AC58EB44E40A60A462575DC454059A65F22DEB24E40AF44A0FA07D9454059A65F22DEB24E40
58821	16025	43.272728000000001	43.294575000000002	61.115969	61.105536999999998	Набережная	0103000020E610000001000000050000000C5A48C0E8A245404CC2853C828D4E400C5A48C0E8A24540C72C7B12D88E4E400F9C33A2B4A54540C72C7B12D88E4E400F9C33A2B4A545404CC2853C828D4E400C5A48C0E8A245404CC2853C828D4E40
58741	16126	43.135734999999997	43.199137999999998	61.101381000000003	61.079858999999999	Магистральная	0103000020E6100000010000000500000016F6B4C35F91454048A5D8D1388A4E4016F6B4C35F914540C8B7770DFA8C4E4007B29E5A7D994540C8B7770DFA8C4E4007B29E5A7D99454048A5D8D1388A4E4016F6B4C35F91454048A5D8D1388A4E40
58678	16126	43.135734999999997	43.199137999999998	61.101381000000003	61.079858999999999	Ленина	0103000020E6100000010000000500000016F6B4C35F91454048A5D8D1388A4E4016F6B4C35F914540C8B7770DFA8C4E4007B29E5A7D994540C8B7770DFA8C4E4007B29E5A7D99454048A5D8D1388A4E4016F6B4C35F91454048A5D8D1388A4E40
59028	15852	43.367949000000003	43.386040999999999	61.100136999999997	61.090060999999999	Сосновая	0103000020E6100000010000000500000047CCECF318AF454091D26C1E878B4E4047CCECF318AF45404D0F0A4AD18C4E4023F59ECA69B145404D0F0A4AD18C4E4023F59ECA69B1454091D26C1E878B4E4047CCECF318AF454091D26C1E878B4E40
58966	16557	43.178556999999998	43.199928	60.925164000000002	60.916728999999997	Школьная	0103000020E6100000010000000500000066BCADF4DA964540BB25396057754E4066BCADF4DA964540E1B721C66B764E4000C79E3D97994540E1B721C66B764E4000C79E3D97994540BB25396057754E4066BCADF4DA964540BB25396057754E40
58861	17083	44.526910000000001	44.552152999999997	61.338766999999997	61.328111	Центральная	0103000020E61000000100000005000000BAF770C9714346409B3A8F8AFFA94E40BAF770C97143464065FB90B75CAB4E40B3B112F3AC46464065FB90B75CAB4E40B3B112F3AC4646409B3A8F8AFFA94E40BAF770C9714346409B3A8F8AFFA94E40
58827	16430	43.326104999999998	43.348284999999997	60.966180999999999	60.958455000000001	Центральная	0103000020E61000000100000005000000F20703CFBDA9454006D847A7AE7A4E40F20703CFBDA945401F82AAD1AB7B4E40FB57569A94AC45401F82AAD1AB7B4E40FB57569A94AC454006D847A7AE7A4E40F20703CFBDA9454006D847A7AE7A4E40
58706	16842	44.589253999999997	44.628473999999997	61.086311000000002	61.071359999999999	Садовая	0103000020E61000000100000005000000C284D1AC6C4B46400C1F115322894E40C284D1AC6C4B46407D24253D0C8B4E40723106D6715046407D24253D0C8B4E40723106D6715046400C1F115322894E40C284D1AC6C4B46400C1F115322894E40
59029	16078	43.201599000000002	43.256036999999999	61.074437000000003	61.064723000000001	Гайдара	0103000020E6100000010000000500000002F4FBFECD9945404626E0D748884E4002F4FBFECD994540624ED02687894E4071C806D2C5A04540624ED02687894E4071C806D2C5A045404626E0D748884E4002F4FBFECD9945404626E0D748884E40
58745	16894	44.782805000000003	44.842784999999999	61.133014000000003	61.092804999999998	Спортивная	0103000020E61000000100000005000000991249F432644640E0F3C308E18B4E40991249F43264464080F44D9A06914E409947FE60E06B464080F44D9A06914E409947FE60E06B4640E0F3C308E18B4E40991249F432644640E0F3C308E18B4E40
58904	16894	44.782805000000003	44.842784999999999	61.133014000000003	61.092804999999998	Советов	0103000020E61000000100000005000000991249F432644640E0F3C308E18B4E40991249F43264464080F44D9A06914E409947FE60E06B464080F44D9A06914E409947FE60E06B4640E0F3C308E18B4E40991249F432644640E0F3C308E18B4E40
58863	16894	44.782805000000003	44.842784999999999	61.133014000000003	61.092804999999998	Северная	0103000020E61000000100000005000000991249F432644640E0F3C308E18B4E40991249F43264464080F44D9A06914E409947FE60E06B464080F44D9A06914E409947FE60E06B4640E0F3C308E18B4E40991249F432644640E0F3C308E18B4E40
58960	17137	44.938077999999997	44.954211999999998	61.461188	61.451132999999999	Новая	0103000020E610000001000000050000006D8C9DF012784640BC92E4B9BEB94E406D8C9DF01278464061A7583508BB4E40B2B96A9E237A464061A7583508BB4E40B2B96A9E237A4640BC92E4B9BEB94E406D8C9DF012784640BC92E4B9BEB94E40
58915	15217	44.262455000000003	44.293340000000001	61.489522999999998	61.47625	Пионерская	0103000020E61000000100000005000000FAD51C2098214640295C8FC2F5BC4E40FAD51C2098214640E5D18DB0A8BE4E40E84D452A8C254640E5D18DB0A8BE4E40E84D452A8C254640295C8FC2F5BC4E40FAD51C2098214640295C8FC2F5BC4E40
58860	16739	43.865723000000003	43.918751	61.063882	61.038775999999999	Школьная	0103000020E610000001000000050000009032E202D0EE454052EFA99CF6844E409032E202D0EE4540CB660E492D884E406A15FDA199F54540CB660E492D884E406A15FDA199F5454052EFA99CF6844E409032E202D0EE454052EFA99CF6844E40
58902	16739	43.865723000000003	43.918751	61.063882	61.038775999999999	Комсомольская	0103000020E610000001000000050000009032E202D0EE454052EFA99CF6844E409032E202D0EE4540CB660E492D884E406A15FDA199F54540CB660E492D884E406A15FDA199F5454052EFA99CF6844E409032E202D0EE454052EFA99CF6844E40
58807	15644	43.701979000000001	43.718426999999998	61.314138999999997	61.304307999999999	Школьный переулок	0103000020E6100000010000000500000049BDA772DAD94540A1F48590F3A64E4049BDA772DAD94540F6B2EDB435A84E401DC87A6AF5DB4540F6B2EDB435A84E401DC87A6AF5DB4540A1F48590F3A64E4049BDA772DAD94540A1F48590F3A64E40
59008	15731	43.623618999999998	43.637281999999999	61.172066000000001	61.163054000000002	Орловская	0103000020E61000000100000005000000051555BFD2CF4540B2BD16F4DE944E40051555BFD2CF45407460394206964E402C2AE27492D145407460394206964E402C2AE27492D14540B2BD16F4DE944E40051555BFD2CF4540B2BD16F4DE944E40
59058	15355	43.996617000000001	44.054262000000001	61.583458	61.56467	Школьная	0103000020E610000001000000050000009ED1562591FF45402384471B47C84E409ED1562591FF4540774B72C0AECA4E4031B5A50EF2064640774B72C0AECA4E4031B5A50EF20646402384471B47C84E409ED1562591FF45402384471B47C84E40
58809	15706	43.611427999999997	43.630885999999997	61.240262999999999	61.227373	Центральная	0103000020E61000000100000005000000E9EDCF4543CE4540287FF78E1A9D4E40E9EDCF4543CE45402CB81FF0C09E4E408BC058DFC0D045402CB81FF0C09E4E408BC058DFC0D04540287FF78E1A9D4E40E9EDCF4543CE4540287FF78E1A9D4E40
58905	17045	44.688930999999997	44.705271000000003	61.238323999999999	61.230600000000003	Школьная	0103000020E61000000100000005000000AC1919E42E584640933A014D849D4E40AC1919E42E5846400BED9C66819E4E409BE8F351465A46400BED9C66819E4E409BE8F351465A4640933A014D849D4E40AC1919E42E584640933A014D849D4E40
59267	57545	35.502201999999997	35.880589999999998	65.172982000000005	64.954785999999999	Приморская	0103000020E610000001000000050000002EFEB62748C041406F2BBD361B3D50402EFEB62748C04140FD321823124B5040A297512CB7F04140FD321823124B5040A297512CB7F041406F2BBD361B3D50402EFEB62748C041406F2BBD361B3D5040
58906	11974	37.932952999999998	37.948160999999999	64.881808000000007	64.873354000000006	Пионерская	0103000020E6100000010000000500000040DAFF006BF742402CF52C08E537504040DAFF006BF742407A56D28A6F385040DC2BF3565DF942407A56D28A6F385040DC2BF3565DF942402CF52C08E537504040DAFF006BF742402CF52C08E5375040
58699	11490	40.783791999999998	40.897824999999997	64.489351999999997	64.462114	Заводская	0103000020E61000000100000005000000E76ED74B5364444085419946931D5040E76ED74B53644440DC0E0D8B511F5040FE43FAEDEB724440DC0E0D8B511F5040FE43FAEDEB72444085419946931D5040E76ED74B5364444085419946931D5040
59052	28114	38.396762000000003	38.425579999999997	64.800704999999994	64.788030000000006	Беломорская	0103000020E61000000100000005000000D525E318C9324340159161156F325040D525E318C9324340982F2FC03E33504074EACA6779364340982F2FC03E33504074EACA6779364340159161156F325040D525E318C9324340159161156F325040
59007	11906	37.684190999999998	37.696328000000001	64.978567999999996	64.966001000000006	Советская	0103000020E61000000100000005000000D89B189293D74240D0B9DBF5D23D5040D89B189293D74240603AADDBA03E504001A5A14621D94240603AADDBA03E504001A5A14621D94240D0B9DBF5D23D5040D89B189293D74240D0B9DBF5D23D5040
59079	12055	36.819284000000003	36.846395999999999	64.955472	64.945802999999998	Нижняя	0103000020E610000001000000050000006B11514CDE6842405B5D4E09883C50406B11514CDE684240990F0874263D50408CBB41B4566C4240990F0874263D50408CBB41B4566C42405B5D4E09883C50406B11514CDE6842405B5D4E09883C5040
58824	57479	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	Геологов	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
58903	12696	40.273009999999999	40.295862999999997	64.602514999999997	64.594436000000002	Северодвинская	0103000020E6100000010000000500000090BDDEFDF12244402AE44A3D0B26504090BDDEFDF12244405D16139B8F265040588CBAD6DE2544405D16139B8F265040588CBAD6DE2544402AE44A3D0B26504090BDDEFDF12244402AE44A3D0B265040
58843	11164	40.245531	40.259059000000001	64.541593000000006	64.531129000000007	Хуторская	0103000020E61000000100000005000000BC934F8F6D1F4440433D7D04FE215040BC934F8F6D1F444086AFAF75A9225040035E66D82821444086AFAF75A9225040035E66D828214440433D7D04FE215040BC934F8F6D1F4440433D7D04FE215040
58828	57482	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	Центральная	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
58958	9833	40.293320999999999	40.319893	62.901314999999997	62.889687000000002	Привокзальная	0103000020E61000000100000005000000711DE38A8B25444093567C43E1714F40711DE38A8B2544407632384A5E734F40139CFA40F22844407632384A5E734F40139CFA40F228444093567C43E1714F40711DE38A8B25444093567C43E1714F40
59067	10581	39.820411999999997	39.836528000000001	62.399057999999997	62.390596000000002	Чапыгина	0103000020E610000001000000050000007B9FAA4203E9434066F9BA0CFF314F407B9FAA4203E94340849A215514334F401A18795913EB4340849A215514334F401A18795913EB434066F9BA0CFF314F407B9FAA4203E9434066F9BA0CFF314F40
59027	11019	38.810409	38.841661999999999	62.695112999999999	62.685665999999998	Школьная	0103000020E6100000010000000500000029B16B7BBB67434054FD4AE7C3574F4029B16B7BBB67434021037976F9584F409A249694BB6B434021037976F9584F409A249694BB6B434054FD4AE7C3574F4029B16B7BBB67434054FD4AE7C3574F40
58823	11079	39.314517000000002	39.332797999999997	62.985284	62.963453000000001	Стахановская	0103000020E610000001000000050000009D84D21742A84340D61D8B6D527B4F409D84D21742A84340D3A23EC91D7E4F404C16F71F99AA4340D3A23EC91D7E4F404C16F71F99AA4340D61D8B6D527B4F409D84D21742A84340D61D8B6D527B4F40
58670	10460	39.838917000000002	39.856766999999998	62.594847000000001	62.587463	микрорайон	0103000020E610000001000000050000007B87DBA161EB4340164ED2FC314B4F407B87DBA161EB4340D68F4DF2234C4F4061A5828AAAED4340D68F4DF2234C4F4061A5828AAAED4340164ED2FC314B4F407B87DBA161EB4340164ED2FC314B4F40
58612	57470	40.456958	40.544966000000002	63.619430000000001	63.594582000000003	Самодедская	0103000020E61000000100000005000000A2D288997D3A4440286552431BCC4F40A2D288997D3A4440A514747B49CF4F404AB72572C1454440A514747B49CF4F404AB72572C1454440286552431BCC4F40A2D288997D3A4440286552431BCC4F40
58804	10864	38.682220000000001	38.704946999999997	62.150820000000003	62.139487000000003	Школьная	0103000020E61000000100000005000000AC5626FC52574340CC9BC3B5DA114F40AC5626FC5257434097CADB114E134F40E7340BB43B5A434097CADB114E134F40E7340BB43B5A4340CC9BC3B5DA114F40AC5626FC52574340CC9BC3B5DA114F40
58697	9595	40.109453999999999	40.159706	62.941800999999998	62.924940999999997	Цементников	0103000020E610000001000000050000004C35B396020E444061DD787764764F404C35B396020E4440882B67EF8C784F40CC7C073F71144440882B67EF8C784F40CC7C073F7114444061DD787764764F404C35B396020E444061DD787764764F40
58713	9595	40.109453999999999	40.159706	62.941800999999998	62.924940999999997	40 лет Победы	0103000020E610000001000000050000004C35B396020E444061DD787764764F404C35B396020E4440882B67EF8C784F40CC7C073F71144440882B67EF8C784F40CC7C073F7114444061DD787764764F404C35B396020E444061DD787764764F40
59001	9748	40.292315000000002	40.313820999999997	62.967260000000003	62.960791	Набережная	0103000020E61000000100000005000000AC90F2936A25444044A51133FB7A4F40AC90F2936A2544404F5DF92CCF7B4F4025E659492B2844404F5DF92CCF7B4F4025E659492B28444044A51133FB7A4F40AC90F2936A25444044A51133FB7A4F40
58611	10295	40.582031000000001	40.634034	62.610411999999997	62.574742000000001	Ленина	0103000020E610000001000000050000000C21E7FD7F4A44409ED1562591494F400C21E7FD7F4A4440008BFCFA214E4F40AA46AF0628514440008BFCFA214E4F40AA46AF06285144409ED1562591494F400C21E7FD7F4A44409ED1562591494F40
58900	10155	40.296348999999999	40.332928000000003	62.610002000000001	62.594487000000001	Центральная	0103000020E61000000100000005000000E59997C3EE254440D6726726184C4F40E59997C3EE2544404F3FA88B144E4F401BF67B629D2A44404F3FA88B144E4F401BF67B629D2A4440D6726726184C4F40E59997C3EE254440D6726726184C4F40
58901	10944	38.164969999999997	38.189304999999997	62.200890000000001	62.187176000000001	Школьная	0103000020E610000001000000050000001A69A9BC1D1543404D4C1762F5174F401A69A9BC1D154340F60B76C3B6194F4011FC6F253B184340F60B76C3B6194F4011FC6F253B1843404D4C1762F5174F401A69A9BC1D1543404D4C1762F5174F40
58698	9872	40.254882000000002	40.325794999999999	62.728395999999996	62.693742999999998	Южная	0103000020E61000000100000005000000672B2FF99F2044401A6A1492CC584F40672B2FF99F204440C34483143C5D4F40A4198BA6B3294440C34483143C5D4F40A4198BA6B32944401A6A1492CC584F40672B2FF99F2044401A6A1492CC584F40
58654	9872	40.254882000000002	40.325794999999999	62.728395999999996	62.693742999999998	Фокина	0103000020E61000000100000005000000672B2FF99F2044401A6A1492CC584F40672B2FF99F204440C34483143C5D4F40A4198BA6B3294440C34483143C5D4F40A4198BA6B32944401A6A1492CC584F40672B2FF99F2044401A6A1492CC584F40
9944	9872	40.254882000000002	40.325794999999999	62.728395999999996	62.693742999999998	Партизанская	0103000020E61000000100000005000000672B2FF99F2044401A6A1492CC584F40672B2FF99F204440C34483143C5D4F40A4198BA6B3294440C34483143C5D4F40A4198BA6B32944401A6A1492CC584F40672B2FF99F2044401A6A1492CC584F40
58628	9872	40.254882000000002	40.325794999999999	62.728395999999996	62.693742999999998	Ленина	0103000020E61000000100000005000000672B2FF99F2044401A6A1492CC584F40672B2FF99F204440C34483143C5D4F40A4198BA6B3294440C34483143C5D4F40A4198BA6B32944401A6A1492CC584F40672B2FF99F2044401A6A1492CC584F40
58680	10373	39.902858999999999	39.922317	62.605719000000001	62.596784999999997	Школьная	0103000020E610000001000000050000001BF33AE290F3434026DF6C73634C4F401BF33AE290F343406DC83F33884D4F40BDC5C37B0EF643406DC83F33884D4F40BDC5C37B0EF6434026DF6C73634C4F401BF33AE290F3434026DF6C73634C4F40
58647	9343	40.276297999999997	40.323045999999998	63.465926000000003	63.429065000000001	Школьная	0103000020E61000000100000005000000A0F99CBB5D234440DB6D179AEBB64F40A0F99CBB5D234440952D9276A3BB4F40438D429259294440952D9276A3BB4F40438D429259294440DB6D179AEBB64F40A0F99CBB5D234440DB6D179AEBB64F40
58645	9343	40.276297999999997	40.323045999999998	63.465926000000003	63.429065000000001	Ломоносова	0103000020E61000000100000005000000A0F99CBB5D234440DB6D179AEBB64F40A0F99CBB5D234440952D9276A3BB4F40438D429259294440952D9276A3BB4F40438D429259294440DB6D179AEBB64F40A0F99CBB5D234440DB6D179AEBB64F40
9868	10998	38.217646999999999	38.234616000000003	62.335828999999997	62.327232000000002	Набережная	0103000020E6100000010000000500000048895DDBDB1B4340331AF9BCE2294F4048895DDBDB1B43403106D671FC2A4F40268FA7E5071E43403106D671FC2A4F40268FA7E5071E4340331AF9BCE2294F4048895DDBDB1B4340331AF9BCE2294F40
59056	57517	40.630395999999998	40.666804999999997	64.017965000000004	64.004492999999997	Школьная	0103000020E61000000100000005000000BDC3EDD0B0504440E603029D49005040BDC3EDD0B050444040DEAB562601504096E7C1DD5955444040DEAB562601504096E7C1DD59554440E603029D49005040BDC3EDD0B0504440E603029D49005040
58857	10652	39.681964000000001	39.704179000000003	62.409754999999997	62.402892000000001	Октябрьская	0103000020E610000001000000050000005186AA984AD74340F7E80DF791334F405186AA984AD74340AD2F12DA72344F40D7C3978922DA4340AD2F12DA72344F40D7C3978922DA4340F7E80DF791334F405186AA984AD74340F7E80DF791334F40
58895	9430	40.333314000000001	40.374420999999998	63.407223999999999	63.367488999999999	Лесная	0103000020E6100000010000000500000044A67C08AA2A4440E3512AE109AF4F4044A67C08AA2A4440BA1281EA1FB44F40C2F7FE06ED2F4440BA1281EA1FB44F40C2F7FE06ED2F4440E3512AE109AF4F4044A67C08AA2A4440E3512AE109AF4F40
59002	10826	38.868656000000001	38.894635000000001	62.105187000000001	62.100797	Молодёжная	0103000020E61000000100000005000000B2BCAB1E306F4340784485EAE60C4F40B2BCAB1E306F4340707B82C4760D4F40B16D516683724340707B82C4760D4F40B16D516683724340784485EAE60C4F40B2BCAB1E306F4340784485EAE60C4F40
59073	10729	39.306548999999997	39.345185000000001	62.135821	62.113553000000003	Ленинградская	0103000020E610000001000000050000008DCF64FF3CA743406DAE9AE7880E4F408DCF64FF3CA74340158E209562114F40EE08A7052FAC4340158E209562114F40EE08A7052FAC43406DAE9AE7880E4F408DCF64FF3CA743406DAE9AE7880E4F40
58608	9556	40.313982000000003	40.355618999999997	63.087878000000003	63.062154999999997	Партизанская	0103000020E610000001000000050000002FC4EA8F302844403524EEB1F4874F402FC4EA8F30284440DA0418963F8B4F40096B63EC842D4440DA0418963F8B4F40096B63EC842D44403524EEB1F4874F402FC4EA8F302844403524EEB1F4874F40
59068	37018	40.110827999999998	40.130249999999997	63.196488000000002	63.185513	Островского	0103000020E6100000010000000500000094BDA59C2F0E4440CEFDD5E3BE974F4094BDA59C2F0E44403A07CF8426994F40E9263108AC1044403A07CF8426994F40E9263108AC104440CEFDD5E3BE974F4094BDA59C2F0E4440CEFDD5E3BE974F40
58917	10448	39.976261000000001	39.993724	62.618597000000001	62.611699000000002	Линейная	0103000020E610000001000000050000001DAED51EF6FC43407AFF1F274C4E4F401DAED51EF6FC4340AD33BE2F2E4F4F400AA0185932FF4340AD33BE2F2E4F4F400AA0185932FF43407AFF1F274C4E4F401DAED51EF6FC43407AFF1F274C4E4F40
58882	57486	41.756793999999999	47.233984	65.274698000000001	63.067297000000003	Советская	0103000020E610000001000000050000008EE733A0DEE04440390F27309D884F408EE733A0DEE04440B491EBA694515040C5E40D30F39D4740B491EBA694515040C5E40D30F39D4740390F27309D884F408EE733A0DEE04440390F27309D884F40
59082	8449	44.060847000000003	44.095278999999998	64.041231999999994	64.030631	Октября	0103000020E61000000100000005000000A587A1D5C90746409ACFB9DBF5015040A587A1D5C90746401DE38A8BA30250406F7F2E1A320C46401DE38A8BA30250406F7F2E1A320C46409ACFB9DBF5015040A587A1D5C90746409ACFB9DBF5015040
58862	7299	45.681353000000001	45.706541999999999	63.526772000000001	63.514203000000002	Строительная	0103000020E6100000010000000500000008043A9336D74640A7406667D1C14F4008043A9336D746406939D0436DC34F400EA0DFF76FDA46406939D0436DC34F400EA0DFF76FDA4640A7406667D1C14F4008043A9336D74640A7406667D1C14F40
59000	8581	44.161259999999999	44.201729	64.183927999999995	64.164786000000007	Центральная	0103000020E610000001000000050000009413ED2AA4144640AD3594DA8B0A50409413ED2AA41446406534F279C50B5040D0D38041D21946406534F279C50B5040D0D38041D2194640AD3594DA8B0A50409413ED2AA4144640AD3594DA8B0A5040
59034	8139	44.278787000000001	44.370451000000003	64.021002999999993	64.008005999999995	Боровая	0103000020E6100000010000000500000065C6DB4AAF234640FE0A992B8300504065C6DB4AAF2346408B87F71C58015040A0E238F06A2F46408B87F71C58015040A0E238F06A2F4640FE0A992B8300504065C6DB4AAF234640FE0A992B83005040
58890	8667	44.610219999999998	44.627504000000002	64.299773000000002	64.289910000000006	Центральная	0103000020E61000000100000005000000BCAE5FB01B4E46402332ACE28D125040BCAE5FB01B4E464053CE177B2F135040FA0D130D5250464053CE177B2F135040FA0D130D525046402332ACE28D125040BCAE5FB01B4E46402332ACE28D125040
58899	7859	44.569949000000001	44.625411	63.914766	63.900452000000001	Центральная	0103000020E61000000100000005000000A7B1BD16F448464014CFD90242F34F40A7B1BD16F448464012BF620D17F54F4082C7B7770D50464012BF620D17F54F4082C7B7770D50464014CFD90242F34F40A7B1BD16F448464014CFD90242F34F40
59026	8748	44.311610999999999	44.329586999999997	64.327399	64.311238000000003	Центральная	0103000020E61000000100000005000000740987DEE227464070D1C952EB135040740987DEE22746408F6FEF1AF4145040E71725E82F2A46408F6FEF1AF4145040E71725E82F2A464070D1C952EB135040740987DEE227464070D1C952EB135040
58891	8798	44.073467999999998	44.098377999999997	64.486749000000003	64.474686000000005	Центральная	0103000020E61000000100000005000000B9A64066670946409F776341611E5040B9A6406667094640161747E5261F5040AC527AA6970C4640161747E5261F5040AC527AA6970C46409F776341611E5040B9A64066670946409F776341611E5040
58892	8839	43.479053	43.493524000000001	64.774269000000004	64.764201	Лесная	0103000020E610000001000000050000007D06D49B51BD454083A44FABE83050407D06D49B51BD4540A053909F8D31504043E55FCB2BBF4540A053909F8D31504043E55FCB2BBF454083A44FABE83050407D06D49B51BD454083A44FABE8305040
58817	8288	43.642510000000001	43.684902000000001	63.830509999999997	63.818694000000001	Северная	0103000020E610000001000000050000002EAD86C43DD2454039B709F7CAE84F402EAD86C43DD245401F80D4264EEA4F40857B65DEAAD745401F80D4264EEA4F40857B65DEAAD7454039B709F7CAE84F402EAD86C43DD2454039B709F7CAE84F40
58816	7372	45.621066999999996	45.655895000000001	63.582723000000001	63.566285999999998	пер.Школьный	0103000020E61000000100000005000000FACF9A1F7FCF46406117450F7CC84F40FACF9A1F7FCF464042D0D1AA96CA4F40124E0B5EF4D3464042D0D1AA96CA4F40124E0B5EF4D346406117450F7CC84F40FACF9A1F7FCF46406117450F7CC84F40
58889	7212	45.980455999999997	46.009498999999998	63.447060999999998	63.438783999999998	Южная	0103000020E610000001000000050000005F950B957FFD46400801F9122AB84F405F950B957FFD464095287B4B39B94F401F2C63433701474095287B4B39B94F401F2C6343370147400801F9122AB84F405F950B957FFD46400801F9122AB84F40
58841	7076	46.133161000000001	46.157200000000003	63.422682999999999	63.413521000000003	Школьная	0103000020E61000000100000005000000240D6E6B0B114740C89A9141EEB44F40240D6E6B0B1147409FC9FE791AB64F4032772D211F1447409FC9FE791AB64F4032772D211F144740C89A9141EEB44F40240D6E6B0B114740C89A9141EEB44F40
58802	8372	44.115535999999999	44.136358999999999	63.899011999999999	63.893594	Пионерская	0103000020E610000001000000050000005DC136E2C90E46406FF3C64961F24F405DC136E2C90E4640145B41D312F34F40F4C1323674114640145B41D312F34F40F4C13236741146406FF3C64961F24F405DC136E2C90E46406FF3C64961F24F40
59048	57511	44.210828999999997	44.240222000000003	64.234692999999993	64.222549999999998	Школьная	0103000020E610000001000000050000003106D671FC1A464063EE5A423E0E50403106D671FC1A464068E6C935050F5040CEE33098BF1E464068E6C935050F5040CEE33098BF1E464063EE5A423E0E50403106D671FC1A464063EE5A423E0E5040
58644	8967	43.374318000000002	43.401456000000003	64.713528999999994	64.681262000000004	Первомайская	0103000020E61000000100000005000000EE26F8A6E9AF45407C80EECB992B5040EE26F8A6E9AF4540D8EF8975AA2D5040396403E962B34540D8EF8975AA2D5040396403E962B345407C80EECB992B5040EE26F8A6E9AF45407C80EECB992B5040
58898	57490	44.379524000000004	44.410902	63.629488000000002	63.613824999999999	Лесная	0103000020E610000001000000050000000806103E94304640CD3B4ED191CE4F400806103E94304640BB9C121093D04F4035EECD6F98344640BB9C121093D04F4035EECD6F98344640CD3B4ED191CE4F400806103E94304640CD3B4ED191CE4F40
59077	7442	45.502704999999999	45.553128000000001	63.623786000000003	63.603465999999997	Советская	0103000020E6100000010000000500000091442FA358C04640BC1FB75F3ECD4F4091442FA358C04640F1D93A38D8CF4F403E40F7E5CCC64640F1D93A38D8CF4F403E40F7E5CCC64640BC1FB75F3ECD4F4091442FA358C04640BC1FB75F3ECD4F40
58573	8198	44.397902999999999	44.455027000000001	64.055210000000002	64.044409000000002	Центральная	0103000020E610000001000000050000007AFD497CEE3246407AA9D898D70250407AFD497CEE324640611A868F8803504004E621533E3A4640611A868F8803504004E621533E3A46407AA9D898D70250407AFD497CEE3246407AA9D898D7025040
59023	7160	46.108718000000003	46.134149000000001	63.421245999999996	63.406689	Ленина	0103000020E61000000100000005000000473EAF78EA0D47404C5299620EB44F40473EAF78EA0D474010C99063EBB54F4043E55FCB2B11474010C99063EBB54F4043E55FCB2B1147404C5299620EB44F40473EAF78EA0D47404C5299620EB44F40
58999	7251	45.884777	45.909067	63.445714000000002	63.438462999999999	Садовая	0103000020E6100000010000000500000062A06B5F40F14640C6C03A8E1FB84F4062A06B5F40F1464047AF06280DB94F40B96FB54E5CF4464047AF06280DB94F40B96FB54E5CF44640C6C03A8E1FB84F4062A06B5F40F14640C6C03A8E1FB84F40
58896	8882	43.232689999999998	43.246586999999998	64.886431000000002	64.880139999999997	Центральная	0103000020E61000000100000005000000990D32C9C89D4540B1F9B83654385040990D32C9C89D454047CA1649BB385040334FAE29909F454047CA1649BB385040334FAE29909F4540B1F9B83654385040990D32C9C89D4540B1F9B83654385040
58606	8024	44.408495000000002	44.486629999999998	64.021782999999999	63.988723	Ф.Абрамова	0103000020E610000001000000050000002ECA6C9049344640C9E6AA798EFE4F402ECA6C9049344640F62686E46401504051A04FE4493E4640F62686E46401504051A04FE4493E4640C9E6AA798EFE4F402ECA6C9049344640C9E6AA798EFE4F40
58953	7057	46.532175000000002	46.550635	63.439014	63.430228	Школьная	0103000020E61000000100000005000000D95F764F1E44474068E90AB611B74F40D95F764F1E4447403A3E5A9C31B84F4038842A357B4647403A3E5A9C31B84F4038842A357B46474068E90AB611B74F40D95F764F1E44474068E90AB611B74F40
59024	7743	44.659680999999999	44.710706000000002	63.900329999999997	63.884259	Новая	0103000020E610000001000000050000007365506D70544640CA181F662FF14F407365506D70544640C8CD70033EF34F401689096AF85A4640C8CD70033EF34F401689096AF85A4640CA181F662FF14F407365506D70544640CA181F662FF14F40
59025	7357	45.684480000000001	45.704180000000001	63.577503999999998	63.563899999999997	Лесная	0103000020E610000001000000050000000F62670A9DD74640711B0DE02DC84F400F62670A9DD7464093A7ACA6EBC94F40A73FFB9122DA464093A7ACA6EBC94F40A73FFB9122DA4640711B0DE02DC84F400F62670A9DD74640711B0DE02DC84F40
58955	8925	43.395428000000003	43.407564999999998	64.728219999999993	64.713525000000004	Окружная	0103000020E610000001000000050000001BF67B629DB2454038F8C264AA2D50401BF67B629DB24540C2120F289B2E504043FF04172BB44540C2120F289B2E504043FF04172BB4454038F8C264AA2D50401BF67B629DB2454038F8C264AA2D5040
58919	7599	45.111229000000002	45.15645	63.817704999999997	63.794212000000002	Советская	0103000020E61000000100000005000000F3AE7AC03C8E46409E0B23BDA8E54F40F3AE7AC03C8E46404963B48EAAE84F40C7BAB88D069446404963B48EAAE84F40C7BAB88D069446409E0B23BDA8E54F40F3AE7AC03C8E46409E0B23BDA8E54F40
58819	7931	44.495415999999999	44.530817999999996	63.981977000000001	63.962684000000003	Гагарина	0103000020E6100000010000000500000023F59ECA693F4640F530B43A39FB4F4023F59ECA693F46404C361E6CB1FD4F4066101FD8F14346404C361E6CB1FD4F4066101FD8F1434640F530B43A39FB4F4023F59ECA693F4640F530B43A39FB4F40
58954	6115	39.141455999999998	39.170292000000003	63.182575	63.177534000000001	Комсомольская	0103000020E6100000010000000500000057E9EE3A1B924340CBF6216FB9964F4057E9EE3A1B9243409A081B9E5E974F409E62D520CC9543409A081B9E5E974F409E62D520CC954340CBF6216FB9964F4057E9EE3A1B924340CBF6216FB9964F40
58887	6321	37.824328999999999	37.853307999999998	63.713928000000003	63.700935000000001	Школьная	0103000020E610000001000000050000007B12D89C83E9424096CFF23CB8D94F407B12D89C83E942406FD921FE61DB4F4024B5503239ED42406FD921FE61DB4F4024B5503239ED424096CFF23CB8D94F407B12D89C83E9424096CFF23CB8D94F40
58894	5885	39.070013000000003	39.086039	63.420079000000001	63.406604000000002	Набережная	0103000020E61000000100000005000000BEA59C2FF68843401E3691990BB44F40BEA59C2FF6884340425E0F26C5B54F401C977153038B4340425E0F26C5B54F401C977153038B43401E3691990BB44F40BEA59C2FF68843401E3691990BB44F40
59018	5686	38.710327999999997	38.744957999999997	63.638544000000003	63.625804000000002	Школьная	0103000020E610000001000000050000006FB72407EC5A43405EDA70581AD04F406FB72407EC5A43404D874ECFBBD14F406072A3C85A5F43404D874ECFBBD14F406072A3C85A5F43405EDA70581AD04F406FB72407EC5A43405EDA70581AD04F40
58997	6670	36.608333000000002	36.807732000000001	63.915252000000002	63.769207999999999	Горная	0103000020E61000000100000005000000EE0912DBDD4D424029E9616875E24F40EE0912DBDD4D42409FCC3FFA26F54F4062F71DC3636742409FCC3FFA26F54F4062F71DC36367424029E9616875E24F40EE0912DBDD4D424029E9616875E24F40
58976	6791	38.019900999999997	38.039628	64.167393000000004	64.160011999999995	Мира	0103000020E610000001000000050000002F14B01D8C024340ECBDF8A23D0A50402F14B01D8C02434014252191B60A5040C100C2871205434014252191B60A5040C100C28712054340ECBDF8A23D0A50402F14B01D8C024340ECBDF8A23D0A5040
58998	6852	37.418640000000003	37.444978999999996	64.385227	64.377195999999998	Победы	0103000020E610000001000000050000001366DAFE95B54240A60BB1FA231850401366DAFE95B5424051A2258FA718504011346612F5B8424051A2258FA718504011346612F5B84240A60BB1FA231850401366DAFE95B54240A60BB1FA23185040
58884	6219	39.296469999999999	39.318325999999999	63.045009	63.037517999999999	Набережная	0103000020E61000000100000005000000601F9DBAF2A543407381CB63CD844F40601F9DBAF2A543404983DBDAC2854F40B6BB07E8BEA843404983DBDAC2854F40B6BB07E8BEA843407381CB63CD844F40601F9DBAF2A543407381CB63CD844F40
58886	6036	39.120210999999998	39.136524999999999	63.235253	63.227525999999997	Школьная	0103000020E610000001000000050000004ACFF412638F4340AE7E6C921F9D4F404ACFF412638F434098A432C51C9E4F400F0BB5A67991434098A432C51C9E4F400F0BB5A679914340AE7E6C921F9D4F404ACFF412638F4340AE7E6C921F9D4F40
59020	6136	39.194474999999997	39.247762999999999	63.136156	63.104677000000002	Молодежная	0103000020E61000000100000005000000DE718A8EE49843405BD2510E668D4F40DE718A8EE4984340BC934F8F6D914F405514AFB2B69F4340BC934F8F6D914F405514AFB2B69F43405BD2510E668D4F40DE718A8EE49843405BD2510E668D4F40
58974	52676	38.462060999999999	38.490940999999999	63.841346000000001	63.824649999999998	Победы	0103000020E61000000100000005000000E7E099D0243B4340BD5296218EE94F40E7E099D0243B43406A4FC939B1EB4F40FDA19927D73E43406A4FC939B1EB4F40FDA19927D73E4340BD5296218EE94F40E7E099D0243B4340BD5296218EE94F40
58933	6731	38.081848999999998	38.138370999999999	64.020014000000003	64.011781999999997	Усачёва	0103000020E61000000100000005000000EB1A2D077A0A43409D2B4A09C1005040EB1A2D077A0A434094DDCCE8470150407FDB1324B611434094DDCCE8470150407FDB1324B61143409D2B4A09C1005040EB1A2D077A0A43409D2B4A09C1005040
59063	6731	38.081848999999998	38.138370999999999	64.020014000000003	64.011781999999997	Мира	0103000020E61000000100000005000000EB1A2D077A0A43409D2B4A09C1005040EB1A2D077A0A434094DDCCE8470150407FDB1324B611434094DDCCE8470150407FDB1324B61143409D2B4A09C1005040EB1A2D077A0A43409D2B4A09C1005040
58605	4987	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	проспект Октябрьский	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58956	4987	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	Целинная	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58726	4987	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	Приморская	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58601	4987	38.004593999999997	38.173054999999998	63.950623	63.888832000000001	Онежская	0103000020E6100000010000000500000000E1438996004340B3D1393FC5F14F4000E1438996004340A7E9B303AEF94F4063B48EAA26164340A7E9B303AEF94F4063B48EAA26164340B3D1393FC5F14F4000E1438996004340B3D1393FC5F14F40
58805	6258	37.602426999999999	37.676546999999999	63.783751000000002	63.686416999999999	Центральная	0103000020E610000001000000050000001B9DF3531CCD42408F352383DCD74F401B9DF3531CCD4240899AE8F351E44F407C9A931799D64240899AE8F351E44F407C9A931799D642408F352383DCD74F401B9DF3531CCD42408F352383DCD74F40
58803	5454	39.224091999999999	39.268909000000001	63.788158000000003	63.772388999999997	Железнодорожная	0103000020E61000000100000005000000CAA5F10BAF9C434023658BA4DDE24F40CAA5F10BAF9C4340570A815CE2E44F40CF4C309C6BA24340570A815CE2E44F40CF4C309C6BA2434023658BA4DDE24F40CAA5F10BAF9C434023658BA4DDE24F40
58604	6434	37.433067000000001	37.485035000000003	63.729567000000003	63.684100000000001	Ленина	0103000020E6100000010000000500000009FD4CBD6EB74240C898BB9690D74F4009FD4CBD6EB74240D49E927362DD4F402B357BA015BE4240D49E927362DD4F402B357BA015BE4240C898BB9690D74F4009FD4CBD6EB74240C898BB9690D74F40
58907	6800	38.086879000000003	38.116919000000003	64.305693000000005	64.294529999999995	Школьная	0103000020E61000000100000005000000C7DADFD91E0B4340376C5B94D9125040C7DADFD91E0B43406F675F7990135040F9A3A833F70E43406F675F7990135040F9A3A833F70E4340376C5B94D9125040C7DADFD91E0B4340376C5B94D9125040
59021	6513	37.045974000000001	37.062818	63.726962999999998	63.716341999999997	Набережная	0103000020E61000000100000005000000B03BDD79E285424028603B18B1DB4F40B03BDD79E28542407633A31F0DDD4F40D1CC936B0A8842407633A31F0DDD4F40D1CC936B0A88424028603B18B1DB4F40B03BDD79E285424028603B18B1DB4F40
58638	5385	39.606389	39.679071	63.736930999999998	63.704545000000003	Пролетарская	0103000020E61000000100000005000000BBD39D279ECD4340B9C7D2872EDA4F40BBD39D279ECD43404C3448C153DE4F40BD546CCCEBD643404C3448C153DE4F40BD546CCCEBD64340B9C7D2872EDA4F40BBD39D279ECD4340B9C7D2872EDA4F40
59004	5938	39.110357	39.131008999999999	63.400072000000002	63.385914999999997	Первомайская	0103000020E610000001000000050000003DF19C2D208E43409604A8A965B14F403DF19C2D208E4340CD052E8F35B34F40A73D25E7C4904340CD052E8F35B34F40A73D25E7C49043409604A8A965B14F403DF19C2D208E43409604A8A965B14F40
59019	5994	39.116205000000001	39.135285000000003	63.276820999999998	63.269171	Набережная	0103000020E61000000100000005000000DB5031CEDF8E43400C04013274A24F40DB5031CEDF8E43404AECDADE6EA34F40D751D504519143404AECDADE6EA34F40D751D504519143400C04013274A24F40DB5031CEDF8E43400C04013274A24F40
58957	6653	36.889702999999997	36.935229999999997	63.704887999999997	63.688015999999998	Октябрьская	0103000020E610000001000000050000009813B4C9E1714240F78F85E810D84F409813B4C9E1714240E2AB1DC539DA4F40791EDC9DB5774240E2AB1DC539DA4F40791EDC9DB5774240F78F85E810D84F409813B4C9E1714240F78F85E810D84F40
59022	5538	38.969537000000003	39.012557000000001	63.79542	63.779197000000003	Центральная	0103000020E6100000010000000500000088A1D5C9197C4340171230BABCE34F4088A1D5C9197C4340CB4A9352D0E54F40FE2AC0779B814340CB4A9352D0E54F40FE2AC0779B814340171230BABCE34F4088A1D5C9197C4340171230BABCE34F40
58996	6331	37.659720999999998	37.698340000000002	63.897069000000002	63.886037000000002	Никольская	0103000020E6100000010000000500000001BEDBBC71D44240E20511A969F14F4001BEDBBC71D44240B2A03028D3F24F408CBE823463D94240B2A03028D3F24F408CBE823463D94240E20511A969F14F4001BEDBBC71D44240E20511A969F14F40
59017	5550	38.512366	38.553347000000002	63.870840999999999	63.842582999999998	Центральная	0103000020E610000001000000050000008ACA86359541434031957EC2D9EB4F408ACA8635954143400A82C7B777EF4F407C2B1213D44643400A82C7B777EF4F407C2B1213D446434031957EC2D9EB4F408ACA86359541434031957EC2D9EB4F40
58975	5735	39.108812	39.128557000000001	63.617131000000001	63.609160000000003	Школьна	0103000020E61000000100000005000000C8B4368DED8D4340040473F4F8CD4F40C8B4368DED8D4340842C0B26FECE4F400056478E74904340842C0B26FECE4F400056478E74904340040473F4F8CD4F40C8B4368DED8D4340040473F4F8CD4F40
58995	5782	39.003169999999997	39.037405	63.582270999999999	63.562717999999997	Придорожная	0103000020E61000000100000005000000062AE3DF678043406D6FB72407C84F40062AE3DF6780434061342BDB87CA4F407BDAE1AFC984434061342BDB87CA4F407BDAE1AFC98443406D6FB72407C84F40062AE3DF678043406D6FB72407C84F40
58951	6483	37.388151999999998	37.416826	63.753225	63.737707	Победы	0103000020E6100000010000000500000041F0F8F6AEB14240E083D72E6DDE4F4041F0F8F6AEB14240CAC342AD69E04F40AE0FEB8D5AB54240CAC342AD69E04F40AE0FEB8D5AB54240E083D72E6DDE4F4041F0F8F6AEB14240E083D72E6DDE4F40
59016	57507	40.244076	40.267189000000002	61.937264999999996	61.927346999999997	Школьная	0103000020E6100000010000000500000087DEE2E13D1F44409885764EB3F64E4087DEE2E13D1F4440BC57AD4CF8F74E40EC6CC83F33224440BC57AD4CF8F74E40EC6CC83F332244409885764EB3F64E4087DEE2E13D1F44409885764EB3F64E40
58948	3872	40.188281000000003	40.218572000000002	61.817259	61.802911000000002	Вокзальная	0103000020E61000000100000005000000A6BA809719184440A14CA3C9C5E64E40A6BA8097191844404BAE62F19BE84E4021E9D32AFA1B44404BAE62F19BE84E4021E9D32AFA1B4440A14CA3C9C5E64E40A6BA809719184440A14CA3C9C5E64E40
58710	4373	40.238954999999997	40.275049000000003	62.236849999999997	62.213918999999997	Заводская	0103000020E610000001000000050000009B1BD313961E44401B7FA2B2611B4F409B1BD313961E44405F07CE19511E4F4015E63DCE342344405F07CE19511E4F4015E63DCE342344401B7FA2B2611B4F409B1BD313961E44401B7FA2B2611B4F40
59013	4352	40.662258999999999	40.675643999999998	62.125689999999999	62.120769000000003	Центральная	0103000020E61000000100000005000000A73D25E7C454444071AFCC5B750F4F40A73D25E7C454444095B7239C16104F408BDEA9807B56444095B7239C16104F408BDEA9807B56444071AFCC5B750F4F40A73D25E7C454444071AFCC5B750F4F40
58883	57488	40.425651999999999	40.442171999999999	62.500892	62.491273999999997	Строителей	0103000020E610000001000000050000000EBDC5C37B36444003B00111E23E4F400EBDC5C37B364440FD69A33A1D404F407C9A931799384440FD69A33A1D404F407C9A93179938444003B00111E23E4F400EBDC5C37B36444003B00111E23E4F40
58950	4653	40.809348999999997	40.828493000000002	62.258294999999997	62.251944999999999	Советская	0103000020E6100000010000000500000070067FBF9867444003B2D7BB3F204F4070067FBF9867444033DC80CF0F214F4083FB010F0C6A444033DC80CF0F214F4083FB010F0C6A444003B2D7BB3F204F4070067FBF9867444003B2D7BB3F204F40
58812	3999	40.840682999999999	40.854705000000003	61.795228000000002	61.787089000000002	Школьная	0103000020E61000000100000005000000CEA623809B6B44404B051555BFE44E40CEA623809B6B4440876EF607CAE54E40255D33F9666D4440876EF607CAE54E40255D33F9666D44404B051555BFE44E40CEA623809B6B44404B051555BFE44E40
58609	3132	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Школьная	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58692	3132	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Советская	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58599	3132	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Североморская	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
59015	3132	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Песочная	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
79527	3132	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	П.Морозова	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58695	3132	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	Ленина	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58639	3132	40.159363999999997	40.253597999999997	61.685290000000002	61.649971000000001	60-летия Октября	0103000020E610000001000000050000007214200A66144440992CEE3F32D34E407214200A661444404F232D95B7D74E405E2A36E6752044404F232D95B7D74E405E2A36E675204440992CEE3F32D34E407214200A66144440992CEE3F32D34E40
58949	4181	40.879409000000003	40.892327000000002	61.882469999999998	61.876373000000001	Молодежная	0103000020E610000001000000050000006F675F7990704440780C8FFD2CF04E406F675F7990704440BED9E6C6F4F04E403D2B69C537724440BED9E6C6F4F04E403D2B69C537724440780C8FFD2CF04E406F675F7990704440780C8FFD2CF04E40
58870	57484	40.302250000000001	40.341695000000001	62.307768000000003	62.291998999999997	Советская	0103000020E61000000100000005000000A69BC420B02644407BBB253960254F40A69BC420B0264440AF601BF164274F40761A69A9BC2B4440AF601BF164274F40761A69A9BC2B44407BBB253960254F40A69BC420B02644407BBB253960254F40
58885	57489	40.229621999999999	40.251972000000002	62.050105000000002	62.038279000000003	Лесная	0103000020E610000001000000050000009738F240641D4440D28F8653E6044F409738F240641D4440DC2E34D769064F40FDC0559E40204440DC2E34D769064F40FDC0559E40204440D28F8653E6044F409738F240641D4440D28F8653E6044F40
58994	4546	40.357999999999997	40.394463000000002	62.418908000000002	62.405862999999997	пер.Клубный	0103000020E61000000100000005000000E7FBA9F1D22D444006D49B51F3334F40E7FBA9F1D22D4440320400C79E354F40B43D7AC37D324440320400C79E354F40B43D7AC37D32444006D49B51F3334F40E7FBA9F1D22D444006D49B51F3334F40
9757	40301	40.838051	40.845560999999996	61.838458000000003	61.833311000000002	Лесная	0103000020E61000000100000005000000A7B05241456B4440D33252EFA9EA4E40A7B05241456B4440E8887C9752EB4E40F3E2C4573B6C4440E8887C9752EB4E40F3E2C4573B6C4440D33252EFA9EA4E40A7B05241456B4440D33252EFA9EA4E40
58947	3908	40.977460000000001	40.984808000000001	61.692616000000001	61.687598999999999	Центральная	0103000020E61000000100000005000000F792C6681D7D444093E1783E03D84E40F792C6681D7D4440DA571EA4A7D84E406A6B44300E7E4440DA571EA4A7D84E406A6B44300E7E444093E1783E03D84E40F792C6681D7D444093E1783E03D84E40
58806	57477	40.204324999999997	40.235658000000001	61.516120000000001	61.50273	переулок Лесной	0103000020E61000000100000005000000AA605452271A4440EA5BE67459C04E40AA605452271A4440E0675C3810C24E403885950A2A1E4440E0675C3810C24E403885950A2A1E4440EA5BE67459C04E40AA605452271A4440EA5BE67459C04E40
58993	3950	40.939532999999997	40.955829000000001	61.758507000000002	61.753129000000001	Центральная	0103000020E61000000100000005000000A2410A9E42784440A855F48766E04E40A2410A9E42784440BF64E3C116E14E40C1C8CB9A587A4440BF64E3C116E14E40C1C8CB9A587A4440A855F48766E04E40A2410A9E42784440A855F48766E04E40
58920	3782	40.050640999999999	40.066488	61.617562	61.609414000000001	Новая	0103000020E610000001000000050000001A6B7F677B064440BEDC274701CE4E401A6B7F677B0644404DA088450CCF4E40C9C9C4AD820844404DA088450CCF4E40C9C9C4AD82084440BEDC274701CE4E401A6B7F677B064440BEDC274701CE4E40
58991	954	43.934201999999999	43.950515000000003	65.291233000000005	65.284074000000004	Центральная	0103000020E61000000100000005000000CCED5EEE93F7454036E9B6442E525040CCED5EEE93F7454006A1BC8FA3525040C1ADBB79AAF9454006A1BC8FA3525040C1ADBB79AAF9454036E9B6442E525040CCED5EEE93F7454036E9B6442E525040
58992	1061	43.372512	43.483643000000001	65.785193000000007	65.765210999999994	Октябрьская	0103000020E610000001000000050000000CAF2479AEAF454086E28E37F97050400CAF2479AEAF45401503249A407250403CF88903E8BD45401503249A407250403CF88903E8BD454086E28E37F97050400CAF2479AEAF454086E28E37F9705040
58990	905	47.680805999999997	47.696885000000002	65.673826000000005	65.666663999999997	Новая	0103000020E61000000100000005000000D575A8A624D74740EA5A7B9FAA6A5040D575A8A624D74740734C16F71F6B50405709168733D94740734C16F71F6B50405709168733D94740EA5A7B9FAA6A5040D575A8A624D74740EA5A7B9FAA6A5040
58946	1294	41.214120999999999	41.237963000000001	66.044025000000005	66.036322999999996	Советская	0103000020E6100000010000000500000083312251689B4440ED45B41D5382504083312251689B444036CD3B4ED18250403B545392759E444036CD3B4ED18250403B545392759E4440ED45B41D5382504083312251689B4440ED45B41D53825040
58596	32308	44.192853999999997	44.274330999999997	65.877829000000006	65.826823000000005	Садовая	0103000020E610000001000000050000008E739B70AF184640292504ABEA7450408E739B70AF184640BF9EAF592E785040B5A338471D234640BF9EAF592E785040B5A338471D234640292504ABEA7450408E739B70AF184640292504ABEA745040
58815	32308	44.192853999999997	44.274330999999997	65.877829000000006	65.826823000000005	Набережная	0103000020E610000001000000050000008E739B70AF184640292504ABEA7450408E739B70AF184640BF9EAF592E785040B5A338471D234640BF9EAF592E785040B5A338471D234640292504ABEA7450408E739B70AF184640292504ABEA745040
58988	468	44.880532000000002	44.903025999999997	65.515186	65.509996999999998	Набережная	0103000020E610000001000000050000006E8AC745B5704640B80375CAA36050406E8AC745B5704640DA56B3CEF860504006B8205B96734640DA56B3CEF860504006B8205B96734640B80375CAA36050406E8AC745B5704640B80375CAA3605040
58675	178	44.098188999999998	44.141578000000003	65.901245000000003	65.872032000000004	Федоркова	0103000020E61000000100000005000000D9E90775910C464031444E5FCF775040D9E90775910C4640BF2B82FFAD795040A3EA573A1F124640BF2B82FFAD795040A3EA573A1F12464031444E5FCF775040D9E90775910C464031444E5FCF775040
58854	178	44.098188999999998	44.141578000000003	65.901245000000003	65.872032000000004	Свободы	0103000020E61000000100000005000000D9E90775910C464031444E5FCF775040D9E90775910C4640BF2B82FFAD795040A3EA573A1F124640BF2B82FFAD795040A3EA573A1F12464031444E5FCF775040D9E90775910C464031444E5FCF775040
58945	422	44.687519999999999	44.703043000000001	65.575205999999994	65.566047999999995	Торцева	0103000020E6100000010000000500000047ACC5A700584640D6FD63213A64504047ACC5A700584640A19DD32CD064504043572250FD594640A19DD32CD064504043572250FD594640D6FD63213A64504047ACC5A700584640D6FD63213A645040
58916	285	44.478357000000003	44.519257000000003	65.610669999999999	65.600177000000002	Советская	0103000020E6100000010000000500000006685BCD3A3D4640EEB3CA4C6966504006685BCD3A3D46407EA99F37156750400B9C6C03774246407EA99F37156750400B9C6C0377424640EEB3CA4C6966504006685BCD3A3D4640EEB3CA4C69665040
58799	1048	43.429538000000001	43.471183000000003	66.052589999999995	66.034029000000004	Октябрьская	0103000020E61000000100000005000000D331E719FBB645406687F8872D825040D331E719FBB645402F8672A25D83504031B77BB94FBC45402F8672A25D83504031B77BB94FBC45406687F8872D825040D331E719FBB645406687F8872D825040
59014	794	45.036093999999999	45.064937999999998	65.796115999999998	65.783023999999997	Советская	0103000020E6100000010000000500000079CA6ABA9E844640EBFEB1101D72504079CA6ABA9E844640A1F48590F372504042226DE34F884640A1F48590F372504042226DE34F884640EBFEB1101D72504079CA6ABA9E844640EBFEB1101D725040
58989	564	44.984296999999998	45.002865	65.486352999999994	65.473259999999996	Набережная	0103000020E610000001000000050000008446B071FD7D464051A04FE4495E50408446B071FD7D4640EF535568205F5040CAA65CE15D804640EF535568205F5040CAA65CE15D80464051A04FE4495E50408446B071FD7D464051A04FE4495E5040
58978	57506	48.590853000000003	48.722653999999999	64.844764999999995	64.788612999999998	Центральная	0103000020E610000001000000050000002BDF3312A14B4840D40CA9A2783250402BDF3312A14B48408CF337A1103650406B2920ED7F5C48408CF337A1103650406B2920ED7F5C4840D40CA9A2783250402BDF3312A14B4840D40CA9A278325040
58569	29223	45.708429000000002	45.784973999999998	64.911028999999999	64.886542000000006	Победы	0103000020E61000000100000005000000DD442DCDADDA4640F321A81ABD385040DD442DCDADDA4640492D944C4E3A5040EB1A2D077AE44640492D944C4E3A5040EB1A2D077AE44640F321A81ABD385040DD442DCDADDA4640F321A81ABD385040
58576	29223	45.708429000000002	45.784973999999998	64.911028999999999	64.886542000000006	Октябрьская	0103000020E61000000100000005000000DD442DCDADDA4640F321A81ABD385040DD442DCDADDA4640492D944C4E3A5040EB1A2D077AE44640492D944C4E3A5040EB1A2D077AE44640F321A81ABD385040DD442DCDADDA4640F321A81ABD385040
58630	30037	49.065361000000003	49.108148	62.193908	62.164290000000001	Трудовая	0103000020E6100000010000000500000089B7CEBF5D884840A987687407154F4089B7CEBF5D884840653733FAD1184F405C902DCBD78D4840653733FAD1184F405C902DCBD78D4840A987687407154F4089B7CEBF5D884840A987687407154F40
58742	30037	49.065361000000003	49.108148	62.193908	62.164290000000001	Дубинина	0103000020E6100000010000000500000089B7CEBF5D884840A987687407154F4089B7CEBF5D884840653733FAD1184F405C902DCBD78D4840653733FAD1184F405C902DCBD78D4840A987687407154F4089B7CEBF5D884840A987687407154F40
58881	57468	48.369607000000002	48.375608	61.788730000000001	61.784064000000001	Нянда	0103000020E61000000100000005000000B4AF3C484F2F484048FC8A355CE44E40B4AF3C484F2F4840E2AFC91AF5E44E40D80E46EC13304840E2AFC91AF5E44E40D80E46EC1330484048FC8A355CE44E40B4AF3C484F2F484048FC8A355CE44E40
58607	57468	48.369607000000002	48.375608	61.788730000000001	61.784064000000001	Мира	0103000020E61000000100000005000000B4AF3C484F2F484048FC8A355CE44E40B4AF3C484F2F4840E2AFC91AF5E44E40D80E46EC13304840E2AFC91AF5E44E40D80E46EC1330484048FC8A355CE44E40B4AF3C484F2F484048FC8A355CE44E40
58714	30838	48.491813999999998	48.581249999999997	61.773815999999997	61.734892000000002	Вычегодская	0103000020E6100000010000000500000083DBDAC2F33E4840C80BE9F010DE4E4083DBDAC2F33E48408E8F16670CE34E4066666666664A48408E8F16670CE34E4066666666664A4840C80BE9F010DE4E4083DBDAC2F33E4840C80BE9F010DE4E40
58972	28871	48.914121000000002	48.942615000000004	62.236075	62.222439999999999	Центральная	0103000020E610000001000000050000001DCBBBEA017548403FA9F6E9781C4F401DCBBBEA017548409C33A2B4371E4F400ADCBA9BA77848409C33A2B4371E4F400ADCBA9BA77848403FA9F6E9781C4F401DCBBBEA017548403FA9F6E9781C4F40
58594	29763	45.230049000000001	45.292490999999998	61.795771999999999	61.766454000000003	Первомайская	0103000020E610000001000000050000001FBDE13E729D4640B7F1272A1BE24E401FBDE13E729D464048895DDBDBE54E40EAAF575870A5464048895DDBDBE54E40EAAF575870A54640B7F1272A1BE24E401FBDE13E729D4640B7F1272A1BE24E40
58856	29126	45.870942999999997	45.890507999999997	61.573695000000001	61.564647999999998	Придорожная	0103000020E610000001000000050000000ED76A0F7BEF46403BE0BA6246C84E400ED76A0F7BEF46407A7077D66EC94E40C669882AFCF146407A7077D66EC94E40C669882AFCF146403BE0BA6246C84E400ED76A0F7BEF46403BE0BA6246C84E40
58849	29342	46.668764000000003	46.706232	61.718344000000002	61.705134999999999	Центральная	0103000020E61000000100000005000000FF5E0A0F9A554740EA211ADD41DA4E40FF5E0A0F9A55474090A339B2F2DB4E40C0B167CF655A474090A339B2F2DB4E40C0B167CF655A4740EA211ADD41DA4E40FF5E0A0F9A554740EA211ADD41DA4E40
58709	29043	45.914690999999998	45.980770999999997	61.563367999999997	61.548498000000002	Плакидина	0103000020E6100000010000000500000007793D9814F54640F1F5B52E35C64E4007793D9814F5464074CE4F711CC84E40BFEE74E789FD464074CE4F711CC84E40BFEE74E789FD4640F1F5B52E35C64E4007793D9814F54640F1F5B52E35C64E40
58568	29043	45.914690999999998	45.980770999999997	61.563367999999997	61.548498000000002	Гагарина	0103000020E6100000010000000500000007793D9814F54640F1F5B52E35C64E4007793D9814F5464074CE4F711CC84E40BFEE74E789FD464074CE4F711CC84E40BFEE74E789FD4640F1F5B52E35C64E4007793D9814F54640F1F5B52E35C64E40
58986	29385	46.860545000000002	46.880235999999996	61.780622999999999	61.772731	Терешковой	0103000020E6100000010000000500000040DEAB56266E47407DCD72D9E8E24E4040DEAB56266E4740B1C05774EBE34E408461C092AB704740B1C05774EBE34E408461C092AB7047407DCD72D9E8E24E4040DEAB56266E47407DCD72D9E8E24E40
58800	29525	46.000703999999999	46.023854	61.546162000000002	61.527920999999999	Мира	0103000020E61000000100000005000000FA7C94111700474091EF52EA92C34E40FA7C941117004740B328ECA2E8C54E407CF0DAA50D034740B328ECA2E8C54E407CF0DAA50D03474091EF52EA92C34E40FA7C94111700474091EF52EA92C34E40
58985	29179	45.946930999999999	45.979846000000002	61.588433000000002	61.578020000000002	Первомайская	0103000020E61000000100000005000000C748F60835F946408B37328FFCC94E40C748F60835F946408F71C5C551CB4E40E78EFE976BFD46408F71C5C551CB4E40E78EFE976BFD46408B37328FFCC94E40C748F60835F946408B37328FFCC94E40
58944	29314	46.605792000000001	46.637799000000001	61.647283999999999	61.638129999999997	Центральная	0103000020E61000000100000005000000D7169E978A4D4740594C6C3EAED14E40D7169E978A4D4740AE9CBD33DAD24E40F435CB65A3514740AE9CBD33DAD24E40F435CB65A3514740594C6C3EAED14E40D7169E978A4D4740594C6C3EAED14E40
58987	29621	45.529483999999997	45.549193000000002	61.681286999999998	61.670355000000001	Быстрова	0103000020E61000000100000005000000ACE0B721C6C34640E4DA5031CED54E40ACE0B721C6C346405018946934D74E409818CBF44BC646405018946934D74E409818CBF44BC64640E4DA5031CED54E40ACE0B721C6C34640E4DA5031CED54E40
59081	57524	\N	\N	\N	\N	Советская	\N
58913	29254	46.375562000000002	46.393331000000003	61.612588000000002	61.601063000000003	Центральная	0103000020E6100000010000000500000068CF656A12304740F7EAE3A1EFCC4E4068CF656A1230474006F6984869CE4E4062C092AB5832474006F6984869CE4E4062C092AB58324740F7EAE3A1EFCC4E4068CF656A12304740F7EAE3A1EFCC4E40
59080	24650	46.486207999999998	46.538876000000002	61.294362	61.255111999999997	Первомайская	0103000020E61000000100000005000000DB8651103C3E474098689082A7A04E40DB8651103C3E4740B3976DA7ADA54E40B64C86E3F9444740B3976DA7ADA54E40B64C86E3F944474098689082A7A04E40DB8651103C3E474098689082A7A04E40
59075	22930	47.231648	47.279680999999997	61.285670000000003	61.254260000000002	Южная	0103000020E61000000100000005000000871744A4A69D47402A5778978BA04E40871744A4A69D474063B9A5D590A44E4002284696CCA3474063B9A5D590A44E4002284696CCA347402A5778978BA04E40871744A4A69D47402A5778978BA04E40
58669	28097	47.477013999999997	47.523726000000003	61.413018000000001	61.389991000000002	Кирова	0103000020E61000000100000005000000F8DD74CB0EBD4740FF5D9F39EBB14E40F8DD74CB0EBD4740655419C6DDB44E404F081D7409C34740655419C6DDB44E404F081D7409C34740FF5D9F39EBB14E40F8DD74CB0EBD4740FF5D9F39EBB14E40
58813	28736	46.251621999999998	46.282003000000003	61.411726999999999	61.401724000000002	Рубцова	0103000020E61000000100000005000000207A522635204740580229B16BB34E40207A522635204740AAF06778B3B44E40DC2F9FAC18244740AAF06778B3B44E40DC2F9FAC18244740580229B16BB34E40207A522635204740580229B16BB34E40
58797	28471	45.888387999999999	45.934696000000002	61.153601000000002	61.126693000000003	Советская	0103000020E610000001000000050000005514AFB2B6F14640EAD0E97937904E405514AFB2B6F1464003D19332A9934E40DCD9571EA4F7464003D19332A9934E40DCD9571EA4F74640EAD0E97937904E405514AFB2B6F14640EAD0E97937904E40
59076	22825	46.894680999999999	46.943603000000003	61.342132999999997	61.326751000000002	Ленина	0103000020E6100000010000000500000021AD31E884724740B8770DFAD2A94E4021AD31E884724740F1F09E03CBAB4E4029B4ACFBC7784740F1F09E03CBAB4E4029B4ACFBC7784740B8770DFAD2A94E4021AD31E884724740B8770DFAD2A94E40
58877	28468	46.342010000000002	46.374915999999999	61.161799999999999	61.149133999999997	Пролетарская	0103000020E61000000100000005000000D673D2FBC62B47405F5CAAD216934E40D673D2FBC62B4740143FC6DCB5944E40A25F5B3FFD2F4740143FC6DCB5944E40A25F5B3FFD2F47405F5CAAD216934E40D673D2FBC62B47405F5CAAD216934E40
58621	28299	46.479039	46.519032000000003	61.091357000000002	61.067991999999997	Рощинская	0103000020E6100000010000000500000018416326513D4740DF313CF6B3884E4018416326513D47405EA10F96B18B4E40EBC9FCA36F4247405EA10F96B18B4E40EBC9FCA36F424740DF313CF6B3884E4018416326513D4740DF313CF6B3884E40
58627	28299	46.479039	46.519032000000003	61.091357000000002	61.067991999999997	Мира	0103000020E6100000010000000500000018416326513D4740DF313CF6B3884E4018416326513D47405EA10F96B18B4E40EBC9FCA36F4247405EA10F96B18B4E40EBC9FCA36F424740DF313CF6B3884E4018416326513D4740DF313CF6B3884E40
58942	28663	46.331626	46.341391000000002	61.395923000000003	61.392144999999999	Южная	0103000020E610000001000000050000006C4084B8722A47401C25AFCE31B24E406C4084B8722A4740FB5DD89AADB24E400A1346B3B22B4740FB5DD89AADB24E400A1346B3B22B47401C25AFCE31B24E406C4084B8722A47401C25AFCE31B24E40
58878	28396	46.378149999999998	46.395567999999997	61.169063000000001	61.161690999999998	Центральная	0103000020E61000000100000005000000BF7D1D38673047405D876A4AB2944E40BF7D1D386730474059FB3BDBA3954E400CACE3F8A132474059FB3BDBA3954E400CACE3F8A13247405D876A4AB2944E40BF7D1D38673047405D876A4AB2944E40
58876	28345	46.53098	46.558180999999998	61.163631000000002	61.149636999999998	Центральная	0103000020E61000000100000005000000406A1327F7434740C2A2224E27934E40406A1327F74347404FCE50DCF1944E40D11F9A79724747404FCE50DCF1944E40D11F9A7972474740C2A2224E27934E40406A1327F7434740C2A2224E27934E40
58845	16644	46.535857999999998	46.565187999999999	61.187376	61.174035000000003	Школьная	0103000020E6100000010000000500000065A6B4FE9644474000AE64C746964E4065A6B4FE964447401407D0EFFB974E40BB0B9414584847401407D0EFFB974E40BB0B94145848474000AE64C746964E4065A6B4FE9644474000AE64C746964E40
58641	57474	46.825105999999998	46.960483000000004	61.263162999999999	61.234873	Ульянова	0103000020E61000000100000005000000DFDDCA129D69474051DB8651109E4E40DFDDCA129D69474035423F53AFA14E4097AE601BF17A474035423F53AFA14E4097AE601BF17A474051DB8651109E4E40DFDDCA129D69474051DB8651109E4E40
58681	57474	46.825105999999998	46.960483000000004	61.263162999999999	61.234873	Ленина	0103000020E61000000100000005000000DFDDCA129D69474051DB8651109E4E40DFDDCA129D69474035423F53AFA14E4097AE601BF17A474035423F53AFA14E4097AE601BF17A474051DB8651109E4E40DFDDCA129D69474051DB8651109E4E40
58707	57474	46.825105999999998	46.960483000000004	61.263162999999999	61.234873	 Медицинская	0103000020E61000000100000005000000DFDDCA129D69474051DB8651109E4E40DFDDCA129D69474035423F53AFA14E4097AE601BF17A474035423F53AFA14E4097AE601BF17A474051DB8651109E4E40DFDDCA129D69474051DB8651109E4E40
59041	24485	46.526128999999997	46.675401999999998	61.322443	61.089590999999999	Молодежная	0103000020E61000000100000005000000143DF031584347400A82C7B7778B4E40143DF031584347407DE9EDCF45A94E4095D39E92735647407DE9EDCF45A94E4095D39E92735647400A82C7B7778B4E40143DF031584347400A82C7B7778B4E40
58984	29014	47.344512000000002	47.363979	61.339820000000003	61.329445	Центральная	0103000020E610000001000000050000002F8A1EF818AC4740556AF6402BAA4E402F8A1EF818AC47406C43C5387FAB4E4024B726DD96AE47406C43C5387FAB4E4024B726DD96AE4740556AF6402BAA4E402F8A1EF818AC4740556AF6402BAA4E40
59011	24219	40.274942000000003	40.292225000000002	61.193823000000002	61.185046999999997	Школьная	0103000020E61000000100000005000000FF25A94C31234440889CBE9EAF974E40FF25A94C31234440371B2B31CF984E406C09F9A067254440371B2B31CF984E406C09F9A067254440889CBE9EAF974E40FF25A94C31234440889CBE9EAF974E40
59006	25156	40.084508	40.099375000000002	60.946475999999997	60.941049	Чкалова	0103000020E610000001000000050000000C207C28D10A44407D772B4B74784E400C207C28D10A44407539252026794E401F85EB51B80C44407539252026794E401F85EB51B80C44407D772B4B74784E400C207C28D10A44407D772B4B74784E40
58686	25462	40.827154	40.904938999999999	61.105615	61.079633000000001	Школьная	0103000020E61000000100000005000000B760A92EE06944405857056A318A4E40B760A92EE0694440C87BD5CA848D4E40FEEF880AD5734440C87BD5CA848D4E40FEEF880AD57344405857056A318A4E40B760A92EE06944405857056A318A4E40
58687	25462	40.827154	40.904938999999999	61.105615	61.079633000000001	Советская	0103000020E61000000100000005000000B760A92EE06944405857056A318A4E40B760A92EE0694440C87BD5CA848D4E40FEEF880AD5734440C87BD5CA848D4E40FEEF880AD57344405857056A318A4E40B760A92EE06944405857056A318A4E40
59053	57516	40.725625999999998	40.753447000000001	61.059210999999998	61.047866999999997	Центральная	0103000020E610000001000000050000004B901150E15C444060C77F8120864E404B901150E15C44401F48DE3994874E40792288F3706044401F48DE3994874E40792288F37060444060C77F8120864E404B901150E15C444060C77F8120864E40
59060	57520	\N	\N	\N	\N	Центральная	\N
58982	25563	40.913446	40.938302999999998	61.095506	61.086742000000001	Зеленая	0103000020E61000000100000005000000BD546CCCEB7444404698A25C1A8B4E40BD546CCCEB7444403049658A398C4E408D5E0D501A7844403049658A398C4E408D5E0D501A7844404698A25C1A8B4E40BD546CCCEB7444404698A25C1A8B4E40
58897	25090	40.057288999999997	40.081192999999999	61.073306000000002	61.064213000000002	Юношеская	0103000020E61000000100000005000000D4B5F63E55074440317DAF2138884E40D4B5F63E55074440E04C4C1762894E4002D53F88640A4440E04C4C1762894E4002D53F88640A4440317DAF2138884E40D4B5F63E55074440317DAF2138884E40
58929	24237	40.268904999999997	40.291659000000003	61.093096000000003	61.075704000000002	Школьная	0103000020E610000001000000050000008D5DA27A6B22444094162EABB0894E408D5DA27A6B224440B8B1D991EA8B4E40C34A051555254440B8B1D991EA8B4E40C34A05155525444094162EABB0894E408D5DA27A6B22444094162EABB0894E40
58646	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Тельмана	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58717	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Советская	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58834	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Садовая	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58719	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Октябрьский проспект	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58818	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Новолесная	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58716	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Молодежная	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58722	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Лесная	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58648	24562	40.221124000000003	40.292917000000003	60.986322000000001	60.960953000000003	Вологодская	0103000020E610000001000000050000002C2E8ECA4D1C44401EFF0582007B4E402C2E8ECA4D1C4440A4A99ECC3F7E4E40A2B8E34D7E254440A4A99ECC3F7E4E40A2B8E34D7E2544401EFF0582007B4E402C2E8ECA4D1C44401EFF0582007B4E40
58930	24456	39.505687000000002	39.524354000000002	60.869114000000003	60.859059999999999	Центральная	0103000020E610000001000000050000009581035ABAC04340A0A696ADF56D4E409581035ABAC04340753FA7203F6F4E406EC328081EC34340753FA7203F6F4E406EC328081EC34340A0A696ADF56D4E409581035ABAC04340A0A696ADF56D4E40
58918	24307	40.508521999999999	40.524906999999999	61.063437999999998	61.0578	Победы	0103000020E61000000100000005000000F4A5B73F17414440BADA8AFD65874E40F4A5B73F174144406DA983BC1E884E4082380F27304344406DA983BC1E884E4082380F2730434440BADA8AFD65874E40F4A5B73F17414440BADA8AFD65874E40
58931	24326	40.055393000000002	40.129828000000003	60.809182	60.786298000000002	Комсомольская	0103000020E61000000100000005000000B3B6291E170744408274B169A5644E40B3B6291E170744408541994693674E40740D33349E1044408541994693674E40740D33349E1044408274B169A5644E40B3B6291E170744408274B169A5644E40
58718	24326	40.055393000000002	40.129828000000003	60.809182	60.786298000000002	Гагарина	0103000020E61000000100000005000000B3B6291E170744408274B169A5644E40B3B6291E170744408541994693674E40740D33349E1044408541994693674E40740D33349E1044408274B169A5644E40B3B6291E170744408274B169A5644E40
58826	57480	40.058141999999997	40.106175	61.352530000000002	61.312485000000002	им. Павла Корякина	0103000020E610000001000000050000001343723271074440CBBE2B82FFA74E401343723271074440F06DFAB31FAD4E408F537424970D4440F06DFAB31FAD4E408F537424970D4440CBBE2B82FFA74E401343723271074440CBBE2B82FFA74E40
58928	57494	40.410884000000003	40.433278999999999	61.004004000000002	60.990830000000003	Бовы	0103000020E610000001000000050000008F39CFD897344440A6F27684D37E4E408F39CFD897344440CF86FC3383804E409485AFAF75374440CF86FC3383804E409485AFAF75374440A6F27684D37E4E408F39CFD897344440A6F27684D37E4E40
59012	25427	40.735849000000002	40.748353999999999	61.153300999999999	61.146998000000004	Новосельская	0103000020E61000000100000005000000ACE5CE4C305E4440E94999D4D0924E40ACE5CE4C305E4440D8B8FE5D9F934E4057EA5910CA5F4440D8B8FE5D9F934E4057EA5910CA5F4440E94999D4D0924E40ACE5CE4C305E4440E94999D4D0924E40
59070	57521	40.230367000000001	40.280323000000003	61.336174	61.321773999999998	Юбилейная	0103000020E61000000100000005000000F08975AA7C1D4440FF59F3E32FA94E40F08975AA7C1D4440FCE1E7BF07AB4E4087A8C29FE1234440FCE1E7BF07AB4E4087A8C29FE1234440FF59F3E32FA94E40F08975AA7C1D4440FF59F3E32FA94E40
59042	23751	38.762718	38.780189999999997	61.877313999999998	61.864963000000003	Центральная	0103000020E61000000100000005000000070951BEA061434002A08A1BB7EE4E40070951BEA061434056293DD34BF04E4047551344DD63434056293DD34BF04E4047551344DD63434002A08A1BB7EE4E40070951BEA061434002A08A1BB7EE4E40
58855	23594	39.09637	39.114426000000002	61.915706	61.905807000000003	Советская	0103000020E61000000100000005000000632827DA558C434073BED87BF1F34E40632827DA558C43402060ADDA35F54E40F3E7DB82A58E43402060ADDA35F54E40F3E7DB82A58E434073BED87BF1F34E40632827DA558C434073BED87BF1F34E40
58981	23670	39.231116999999998	39.243423999999997	61.724162	61.716813999999999	Молодёжная	0103000020E610000001000000050000005A46EA3D959D434050A8A78FC0DB4E405A46EA3D959D4340C3802557B1DC4E40DF878384289F4340C3802557B1DC4E40DF878384289F434050A8A78FC0DB4E405A46EA3D959D434050A8A78FC0DB4E40
59040	23723	39.160967999999997	39.173841000000003	61.792183000000001	61.785361999999999	Архангельская	0103000020E61000000100000005000000ECD973999A944340B5C2F4BD86E44E40ECD973999A9443403DB9A64066E54E401BDA006C409643403DB9A64066E54E401BDA006C40964340B5C2F4BD86E44E40ECD973999A944340B5C2F4BD86E44E40
59010	23369	38.876939	38.881798000000003	61.218953999999997	61.216523000000002	1-линия	0103000020E6100000010000000500000021CB82893F70434079EA9106B79B4E4021CB82893F70434008AA46AF069C4E40D0D6C1C1DE70434008AA46AF069C4E40D0D6C1C1DE70434079EA9106B79B4E4021CB82893F70434079EA9106B79B4E40
58924	23612	38.986891999999997	39.006152	61.951020999999997	61.940375000000003	пер.Садовый	0103000020E610000001000000050000008E57207A527E4340EE7C3F355EF84E408E57207A527E434094675E0EBBF94E400A67B796C980434094675E0EBBF94E400A67B796C9804340EE7C3F355EF84E408E57207A527E4340EE7C3F355EF84E40
59287	57546	37.759093	39.912894000000001	62.084598	60.709139999999998	Труда	0103000020E61000000100000005000000AFCF9CF529E1424089247A19C55A4E40AFCF9CF529E142404CA7751BD40A4F40795BE9B5D9F443404CA7751BD40A4F40795BE9B5D9F4434089247A19C55A4E40AFCF9CF529E1424089247A19C55A4E40
58923	23221	38.811137000000002	38.824953000000001	61.614769000000003	61.608592999999999	Петровская	0103000020E61000000100000005000000ACC95356D36743408AC91B60E6CD4E40ACC95356D36743401DCC26C0B0CE4E4059DE550F986943401DCC26C0B0CE4E4059DE550F986943408AC91B60E6CD4E40ACC95356D36743408AC91B60E6CD4E40
58853	23831	38.568987	38.576999999999998	61.191647000000003	61.185693999999998	Центральная	0103000020E61000000100000005000000B16CE690D44843401E882CD2C4974E40B16CE690D448434032B08EE387984E4060E5D022DB49434032B08EE387984E4060E5D022DB4943401E882CD2C4974E40B16CE690D44843401E882CD2C4974E40
58914	23531	38.876876000000003	38.886003000000002	61.222523000000002	61.218896999999998	Западная	0103000020E61000000100000005000000DB5207793D704340A41820D1049C4E40DB5207793D704340CDCD37A27B9C4E403694DA8B68714340CDCD37A27B9C4E403694DA8B68714340A41820D1049C4E40DB5207793D704340A41820D1049C4E40
59032	22964	38.724530000000001	38.734205000000003	61.135128999999999	61.131003	9 Мая	0103000020E61000000100000005000000467C2766BD5C4340C556D0B4C4904E40467C2766BD5C4340DFDE35E84B914E40A4C7EF6DFA5D4340DFDE35E84B914E40A4C7EF6DFA5D4340C556D0B4C4904E40467C2766BD5C4340C556D0B4C4904E40
58973	23287	39.475082	39.482951	61.488053999999998	61.479498	Береговая	0103000020E610000001000000050000008A75AA7CCFBC4340AB3FC23060BD4E408A75AA7CCFBC43404B57B08D78BE4E4006499F56D1BD43404B57B08D78BE4E4006499F56D1BD4340AB3FC23060BD4E408A75AA7CCFBC4340AB3FC23060BD4E40
58830	23964	38.498856000000004	38.518681000000001	60.952880999999998	60.943702000000002	Советская	0103000020E61000000100000005000000EAB46E83DA3F4340BC95253ACB784E40EAB46E83DA3F434069FD2D01F8794E403E0796236442434069FD2D01F8794E403E07962364424340BC95253ACB784E40EAB46E83DA3F4340BC95253ACB784E40
58744	22640	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	проспект Октябрьский	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
58840	22640	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	пр.Октябрьский	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
58593	22640	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	Чеснокова	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
58664	22640	38.900455999999998	38.967165000000001	61.523786000000001	61.489145000000001	Семенковская	0103000020E6100000010000000500000055BE6724427343403F00A94D9CBE4E4055BE672442734340240D6E6B0BC34E40FD6A0E10CC7B4340240D6E6B0BC34E40FD6A0E10CC7B43403F00A94D9CBE4E4055BE6724427343403F00A94D9CBE4E40
59009	23234	39.125934000000001	39.140289000000003	61.519634000000003	61.509867	Октябрьская	0103000020E610000001000000050000002CBAF59A1E904340A227655243C14E402CBAF59A1E904340E1F1ED5D83C24E40897E6DFDF4914340E1F1ED5D83C24E40897E6DFDF4914340A227655243C14E402CBAF59A1E904340A227655243C14E40
59033	23897	38.769948999999997	38.778789000000003	61.119042	61.114125999999999	Ишуковская	0103000020E61000000100000005000000404B57B08D624340C8CF46AE9B8E4E40404B57B08D624340DB6CACC43C8F4E4006BEA25BAF634340DB6CACC43C8F4E4006BEA25BAF634340C8CF46AE9B8E4E40404B57B08D624340C8CF46AE9B8E4E40
59035	24956	38.947285999999998	38.978259999999999	61.512597	61.489514	Заречная	0103000020E61000000100000005000000B5FAEAAA4079434092770E65A8BE4E40B5FAEAAA407943408C834BC79CC14E40137EA99F377D43408C834BC79CC14E40137EA99F377D434092770E65A8BE4E40B5FAEAAA4079434092770E65A8BE4E40
58971	23013	38.687223000000003	38.703079000000002	61.490141000000001	61.481461000000003	Молодёжная	0103000020E610000001000000050000008E075BECF657434055A69883A0BD4E408E075BECF6574340E1B6B6F0BCBE4E4090C01F7EFE594340E1B6B6F0BCBE4E4090C01F7EFE59434055A69883A0BD4E408E075BECF657434055A69883A0BD4E40
58910	23426	38.576227000000003	38.598047999999999	61.561053999999999	61.552947000000003	Центральная	0103000020E610000001000000050000003E096CCEC1494340EEB5A0F7C6C64E403E096CCEC14943401EA5129ED0C74E4017B83CD68C4C43401EA5129ED0C74E4017B83CD68C4C4340EEB5A0F7C6C64E403E096CCEC1494340EEB5A0F7C6C64E40
58911	23174	39.051561999999997	39.063589999999998	61.590153999999998	61.583748999999997	Центральная	0103000020E61000000100000005000000B1DB6795998643404E098849B8CA4E40B1DB67959986434042CD902A8ACB4E40232D95B72388434042CD902A8ACB4E40232D95B7238843404E098849B8CA4E40B1DB6795998643404E098849B8CA4E40
58869	22544	42.861353000000001	42.885176000000001	62.792946000000001	62.774464999999999	Сплавщиков	0103000020E61000000100000005000000DFA7AAD0406E4540C5724BAB21634F40DFA7AAD0406E45403CBF28417F654F40209A79724D7145403CBF28417F654F40209A79724D714540C5724BAB21634F40DFA7AAD0406E4540C5724BAB21634F40
58927	22086	42.338982999999999	42.358395000000002	63.036824000000003	63.030647999999999	Южная	0103000020E61000000100000005000000327381CB632B45400AD80E46EC834F40327381CB632B45409DDA19A6B6844F4064062AE3DF2D45409DDA19A6B6844F4064062AE3DF2D45400AD80E46EC834F40327381CB632B45400AD80E46EC834F40
58968	21943	42.603959000000003	42.657057999999999	63.015864000000001	62.995240000000003	Советская	0103000020E61000000100000005000000FC8F4C874E4D4540E5D53906647F4F40FC8F4C874E4D45408597E0D407824F409FC9FE791A5445408597E0D407824F409FC9FE791A544540E5D53906647F4F40FC8F4C874E4D4540E5D53906647F4F40
58820	21943	42.603959000000003	42.657057999999999	63.015864000000001	62.995240000000003	Песочная	0103000020E61000000100000005000000FC8F4C874E4D4540E5D53906647F4F40FC8F4C874E4D45408597E0D407824F409FC9FE791A5445408597E0D407824F409FC9FE791A544540E5D53906647F4F40FC8F4C874E4D4540E5D53906647F4F40
58912	22177	42.501325999999999	42.528185999999998	63.013876000000003	63.005842000000001	Новая	0103000020E6100000010000000500000037514B732B404540BC783F6EBF804F4037514B732B404540831953B0C6814F403F1A4E999B434540831953B0C6814F403F1A4E999B434540BC783F6EBF804F4037514B732B404540BC783F6EBF804F40
58969	22135	42.358341000000003	42.380952000000001	63.034238000000002	63.025723999999997	Центральная	0103000020E6100000010000000500000071E82D1EDE2D4540745C8DEC4A834F4071E82D1EDE2D4540E62329E961844F4043ACFE08C3304540E62329E961844F4043ACFE08C3304540745C8DEC4A834F4071E82D1EDE2D4540745C8DEC4A834F40
59071	21684	43.337200000000003	43.430219999999998	62.686754999999998	62.661535999999998	Комсомольская	0103000020E61000000100000005000000091B9E5E29AB454036902E36AD544F40091B9E5E29AB4540A7AE7C96E7574F40E50AEF7211B74540A7AE7C96E7574F40E50AEF7211B7454036902E36AD544F40091B9E5E29AB454036902E36AD544F40
58810	22219	42.587420999999999	42.613624999999999	62.974144000000003	62.952430999999997	Школьная	0103000020E61000000100000005000000E7FD7F9C304B454029594E42E9794F40E7FD7F9C304B45401DCC26C0B07C4F40068195438B4E45401DCC26C0B07C4F40068195438B4E454029594E42E9794F40E7FD7F9C304B454029594E42E9794F40
58921	21836	43.108471000000002	43.134422999999998	62.919142999999998	62.911954999999999	Зеленая	0103000020E610000001000000050000003FC8B260E28D45403B3602F1BA744F403FC8B260E28D454075AC527AA6754F40446ADAC53491454075AC527AA6754F40446ADAC5349145403B3602F1BA744F403FC8B260E28D45403B3602F1BA744F40
58908	21541	43.052307999999996	43.073543999999998	62.953052999999997	62.941032	Школьная	0103000020E61000000100000005000000DAA84E07B2864540A73E90BC73784F40DAA84E07B2864540662D05A4FD794F409468C9E369894540662D05A4FD794F409468C9E369894540A73E90BC73784F40DAA84E07B2864540A73E90BC73784F40
58825	22483	42.937942999999997	42.957087000000001	62.64873	62.639933999999997	Школьная	0103000020E610000001000000050000008D4127840E7845409ACC785BE9514F408D4127840E78454090F7AA9509534F40A036AAD3817A454090F7AA9509534F40A036AAD3817A45409ACC785BE9514F408D4127840E7845409ACC785BE9514F40
58583	22267	42.663345999999997	42.825797999999999	62.872698	62.829331000000003	П.Виноградова	0103000020E6100000010000000500000059F78F85E85445408D47A984276A4F4059F78F85E85445406EA46C91B46F4F40158DB5BFB36945406EA46C91B46F4F40158DB5BFB36945408D47A984276A4F4059F78F85E85445408D47A984276A4F40
59066	22267	42.663345999999997	42.825797999999999	62.872698	62.829331000000003	Восьмое Марта	0103000020E6100000010000000500000059F78F85E85445408D47A984276A4F4059F78F85E85445406EA46C91B46F4F40158DB5BFB36945406EA46C91B46F4F40158DB5BFB36945408D47A984276A4F4059F78F85E85445408D47A984276A4F40
58922	20725	48.832966999999996	48.861038999999998	61.128005000000002	61.116539000000003	Ленина	0103000020E61000000100000005000000D8D2A3A99E6A4840B2DAFCBFEA8E4E40D8D2A3A99E6A4840BC5CC47762904E404FCAA486366E4840BC5CC47762904E404FCAA486366E4840B2DAFCBFEA8E4E40D8D2A3A99E6A4840B2DAFCBFEA8E4E40
58980	21502	47.452472	47.472602999999999	61.209695000000004	61.198925000000003	Центральная	0103000020E61000000100000005000000882D3D9AEAB94740ACADD85F76994E40882D3D9AEAB947403F912749D79A4E40E97E4E417EBC47403F912749D79A4E40E97E4E417EBC4740ACADD85F76994E40882D3D9AEAB94740ACADD85F76994E40
58793	20559	48.658073999999999	48.687187999999999	61.273915000000002	61.259953000000003	Комсомольская	0103000020E61000000100000005000000882CD2C43B544840A1BFD02346A14E40882CD2C43B54484022718FA50FA34E40111AC1C6F557484022718FA50FA34E40111AC1C6F5574840A1BFD02346A14E40882CD2C43B544840A1BFD02346A14E40
58833	20662	48.363390000000003	48.497159000000003	61.294181000000002	61.258339999999997	Профсоюзная	0103000020E61000000100000005000000C3D84290832E4840D39FFD4811A14E40C3D84290832E4840630D17B9A7A54E40BFF4F6E7A23F4840630D17B9A7A54E40BFF4F6E7A23F4840D39FFD4811A14E40C3D84290832E4840D39FFD4811A14E40
58943	21142	47.952995000000001	47.975085	61.105066999999998	61.096380000000003	Южная	0103000020E6100000010000000500000032207BBDFBF9474087FE092E568C4E4032207BBDFBF94740C571E0D5728D4E40FBE8D495CFFC4740C571E0D5728D4E40FBE8D495CFFC474087FE092E568C4E4032207BBDFBF9474087FE092E568C4E40
58844	21316	47.702455	47.740157000000004	61.260264999999997	61.247163	Октябрьская	0103000020E61000000100000005000000B2F4A10BEAD9474000E48409A39F4E40B2F4A10BEAD947408FA50F5D50A14E40E773EE76BDDE47408FA50F5D50A14E40E773EE76BDDE474000E48409A39F4E40B2F4A10BEAD9474000E48409A39F4E40
58750	21232	47.936466000000003	47.997767000000003	61.128256999999998	61.113005000000001	Спортивная	0103000020E6100000010000000500000071E82D1EDEF747406AA4A5F2768E4E4071E82D1EDEF74740D53DB2B96A904E4097033DD4B6FF4740D53DB2B96A904E4097033DD4B6FF47406AA4A5F2768E4E4071E82D1EDEF747406AA4A5F2768E4E40
58941	21419	47.699615999999999	47.722594999999998	61.392795	61.381734999999999	Школьная	0103000020E6100000010000000500000011E15F048DD94740895E46B1DCB04E4011E15F048DD947402384471B47B24E4066A032FE7DDC47402384471B47B24E4066A032FE7DDC4740895E46B1DCB04E4011E15F048DD94740895E46B1DCB04E40
58582	21183	47.962122000000001	47.991973000000002	61.117263999999999	61.108750000000001	Советская	0103000020E610000001000000050000008D614ED026FB474052B81E85EB8D4E408D614ED026FB4740C37FBA81028F4E40ECC1A4F8F8FE4740C37FBA81028F4E40ECC1A4F8F8FE474052B81E85EB8D4E408D614ED026FB474052B81E85EB8D4E40
58952	19845	45.139741000000001	45.153520999999998	62.102127000000003	62.095306999999998	Северная	0103000020E6100000010000000500000086747808E3914640390A1005330C4F4086747808E3914640F1845E7F120D4F40E61F7D93A6934640F1845E7F120D4F40E61F7D93A6934640390A1005330C4F4086747808E3914640390A1005330C4F40
58940	19460	44.765979000000002	44.780667000000001	62.309299000000003	62.297640999999999	Двинская	0103000020E610000001000000050000001E3691990B6246407079AC1919264F401E3691990B624640BFD7101C97274F40810871E5EC634640BFD7101C97274F40810871E5EC6346407079AC1919264F401E3691990B6246407079AC1919264F40
59065	19202	46.174942000000001	46.204272000000003	62.679188000000003	62.670186000000001	Набережная	0103000020E610000001000000050000003259DC7F64164740581EA4A7C8554F403259DC7F64164740F7EAE3A1EF564F4088BEBB95251A4740F7EAE3A1EF564F4088BEBB95251A4740581EA4A7C8554F403259DC7F64164740581EA4A7C8554F40
59039	19132	46.142691999999997	46.157128	62.489820000000002	62.482754999999997	Лесная	0103000020E610000001000000050000004EB340BB43124740807D74EACA3D4F404EB340BB431247409F76F86BB23E4F4098A432C51C1447409F76F86BB23E4F4098A432C51C144740807D74EACA3D4F404EB340BB43124740807D74EACA3D4F40
58983	18974	46.845641999999998	46.874567999999996	62.746639000000002	62.732798000000003	Центральная	0103000020E61000000100000005000000E00F3FFF3D6C474080492A53CC5D4F40E00F3FFF3D6C47408675E3DD915F4F4066101FD8F16F47408675E3DD915F4F4066101FD8F16F474080492A53CC5D4F40E00F3FFF3D6C474080492A53CC5D4F40
58873	19229	45.921545000000002	45.950119999999998	62.587890000000002	62.579062999999998	Школьная	0103000020E610000001000000050000006B65C22FF5F546406DA983BC1E4A4F406B65C22FF5F546409ED2C1FA3F4B4F4044A33B889DF946409ED2C1FA3F4B4F4044A33B889DF946406DA983BC1E4A4F406B65C22FF5F546406DA983BC1E4A4F40
58939	20381	44.803645000000003	44.821826999999999	61.784208999999997	61.777560000000001	Центральная	0103000020E61000000100000005000000064CE0D6DD664640C156091687E34E40064CE0D6DD6646404B1DE4F560E44E4022FC8BA0316946404B1DE4F560E44E4022FC8BA031694640C156091687E34E40064CE0D6DD664640C156091687E34E40
58796	19947	44.650582	44.692722000000003	62.352887000000003	62.339421000000002	Набережная	0103000020E61000000100000005000000E2AE5E4546534640AE49B725722B4F40E2AE5E45465346407F17B6662B2D4F40209C4F1DAB5846407F17B6662B2D4F40209C4F1DAB584640AE49B725722B4F40E2AE5E4546534640AE49B725722B4F40
58738	19543	45.100448999999998	45.138843000000001	62.161921	62.147747000000003	Лесная	0103000020E610000001000000050000003CF54883DB8C4640838AAA5FE9124F403CF54883DB8C46408FC4CBD3B9144F40A723809BC59146408FC4CBD3B9144F40A723809BC5914640838AAA5FE9124F403CF54883DB8C4640838AAA5FE9124F40
58737	19281	44.979976000000001	45.017659999999999	62.25076	62.231377000000002	Ломоносова	0103000020E61000000100000005000000B56E83DA6F7D4640F705F4C29D1D4F40B56E83DA6F7D46408E9257E718204F404339D1AE428246408E9257E718204F404339D1AE42824640F705F4C29D1D4F40B56E83DA6F7D4640F705F4C29D1D4F40
58566	19281	44.979976000000001	45.017659999999999	62.25076	62.231377000000002	Кулижского	0103000020E61000000100000005000000B56E83DA6F7D4640F705F4C29D1D4F40B56E83DA6F7D46408E9257E718204F404339D1AE428246408E9257E718204F404339D1AE42824640F705F4C29D1D4F40B56E83DA6F7D4640F705F4C29D1D4F40
58829	20440	45.077461	45.099576999999996	62.001291999999999	61.989806000000002	Строительная	0103000020E6100000010000000500000094DBF63DEA8946403AB187F6B1FE4E4094DBF63DEA8946408BDF14562A004F4086376BF0BE8C46408BDF14562A004F4086376BF0BE8C46403AB187F6B1FE4E4094DBF63DEA8946403AB187F6B1FE4E40
58965	57499	42.911496999999997	42.918522000000003	60.987909999999999	60.982351000000001	Новинки	0103000020E6100000010000000500000078B306EFAB744540B11875ADBD7D4E4078B306EFAB74454018B2BAD5737E4E400954FF209275454018B2BAD5737E4E400954FF2092754540B11875ADBD7D4E4078B306EFAB744540B11875ADBD7D4E40
58839	18812	41.825127999999999	41.857368999999998	61.213894000000003	61.201504	Центральная	0103000020E61000000100000005000000C78157CB9DE94440B00111E2CA994E40C78157CB9DE94440C367EBE0609B4E4057CD7344BEED4440C367EBE0609B4E4057CD7344BEED4440B00111E2CA994E40C78157CB9DE94440B00111E2CA994E40
58872	17594	42.058619	42.067583999999997	61.420499	61.408088999999997	Центральная	0103000020E610000001000000050000004DF6CFD380074540BD6DA6423CB44E404DF6CFD380074540178046E9D2B54E40CEDDAE97A6084540178046E9D2B54E40CEDDAE97A6084540BD6DA6423CB44E404DF6CFD380074540BD6DA6423CB44E40
58794	18713	41.601258999999999	41.618462000000001	61.200364999999998	61.194881000000002	Центральная	0103000020E610000001000000050000007CB60E0EF6CC44404FCE50DCF1984E407CB60E0EF6CC4440AB21718FA5994E40CDE847C329CF4440AB21718FA5994E40CDE847C329CF44404FCE50DCF1984E407CB60E0EF6CC44404FCE50DCF1984E40
58938	17470	41.307699	41.397638000000001	61.153944000000003	61.136744999999998	переулок Торговый	0103000020E6100000010000000500000086014BAE62A744401D7233DC80914E4086014BAE62A744402DB5DE6FB4934E40CCD24ECDE5B244402DB5DE6FB4934E40CCD24ECDE5B244401D7233DC80914E4086014BAE62A744401D7233DC80914E40
58580	17470	41.307699	41.397638000000001	61.153944000000003	61.136744999999998	Ломоносова	0103000020E6100000010000000500000086014BAE62A744401D7233DC80914E4086014BAE62A744402DB5DE6FB4934E40CCD24ECDE5B244402DB5DE6FB4934E40CCD24ECDE5B244401D7233DC80914E4086014BAE62A744401D7233DC80914E40
58934	17286	41.958519000000003	41.973036	61.5199	61.512442	Советская	0103000020E610000001000000050000001DCC26C0B0FA4440658C0FB397C14E401DCC26C0B0FA44405F984C158CC24E4053EA92718CFC44405F984C158CC24E4053EA92718CFC4440658C0FB397C14E401DCC26C0B0FA4440658C0FB397C14E40
58832	17434	42.096977000000003	42.116442999999997	60.871071999999998	60.860331000000002	Дальняя	0103000020E610000001000000050000006BBB09BE690C4540145E82531F6E4E406BBB09BE690C45400C3B8C497F6F4E408F6CAE9AE70E45400C3B8C497F6F4E408F6CAE9AE70E4540145E82531F6E4E406BBB09BE690C4540145E82531F6E4E40
58851	18259	41.511040999999999	41.530462999999997	61.669052999999998	61.657946000000003	Мира	0103000020E6100000010000000500000023F59ECA69C144405B44149337D44E4023F59ECA69C1444035255987A3D54E40785E2A36E6C3444035255987A3D54E40785E2A36E6C344405B44149337D44E4023F59ECA69C144405B44149337D44E40
59036	16831	41.138294999999999	41.153485000000003	61.191412999999997	61.183824000000001	Гагарина	0103000020E61000000100000005000000A4198BA6B3914440261C7A8B87974E40A4198BA6B3914440BE839F3880984E409AB67F65A5934440BE839F3880984E409AB67F65A5934440261C7A8B87974E40A4198BA6B3914440261C7A8B87974E40
58735	18122	41.321632000000001	41.361077000000002	61.059198000000002	61.040165999999999	Советская	0103000020E610000001000000050000006DACC43C2BA94440A034D42824854E406DACC43C2BA944408BFED0CC93874E403D2B69C537AE44408BFED0CC93874E403D2B69C537AE4440A034D42824854E406DACC43C2BA94440A034D42824854E40
58937	18420	41.750523000000001	41.778156000000003	61.082900000000002	61.073737000000001	Школьная	0103000020E61000000100000005000000AAF23D2311E04440A9C0C93670894E40AAF23D2311E04440516B9A779C8A4E40D597A59D9AE34440516B9A779C8A4E40D597A59D9AE34440A9C0C93670894E40AAF23D2311E04440A9C0C93670894E40
58977	17833	42.882257000000003	42.897663000000001	61.664946	61.655439000000001	Центральная	0103000020E6100000010000000500000063D520CCED704540F0C2D66CE5D34E4063D520CCED70454092CD55F31CD54E4025EA059FE672454092CD55F31CD54E4025EA059FE6724540F0C2D66CE5D34E4063D520CCED704540F0C2D66CE5D34E40
59031	17650	41.767484000000003	41.779207	60.949320999999998	60.942321	Центральная	0103000020E61000000100000005000000051A6CEA3CE24440C1AA7AF99D784E40051A6CEA3CE24440F833BC5983794E403AE8120EBDE34440F833BC5983794E403AE8120EBDE34440C1AA7AF99D784E40051A6CEA3CE24440C1AA7AF99D784E40
59046	18380	41.966047000000003	41.976405	61.080629000000002	61.071896000000002	Солнечная	0103000020E6100000010000000500000010B3976DA7FB44404B5B5CE333894E4010B3976DA7FB4440FA0D130D528A4E405053CBD6FAFC4440FA0D130D528A4E405053CBD6FAFC44404B5B5CE333894E4010B3976DA7FB44404B5B5CE333894E40
58850	18170	42.378678999999998	42.385649999999998	61.284208999999997	61.274684999999998	Центральная	0103000020E610000001000000050000004B57B08D78304540D3D9C9E028A34E404B57B08D783045404B1DE4F560A44E40E8D9ACFA5C3145404B1DE4F560A44E40E8D9ACFA5C314540D3D9C9E028A34E404B57B08D78304540D3D9C9E028A34E40
9673	17690	41.741370000000003	41.812004000000002	61.021127	60.964146	Центральная	0103000020E61000000100000005000000261E5036E5DE4440DC48D922697B4E40261E5036E5DE444003081F4AB4824E40501C40BFEFE7444003081F4AB4824E40501C40BFEFE74440DC48D922697B4E40261E5036E5DE4440DC48D922697B4E40
59064	17750	42.702638999999998	42.738787000000002	61.590462000000002	61.57611	Свердлова	0103000020E6100000010000000500000073F22213F05945400473F4F8BDC94E4073F22213F0594540F0C3414294CB4E40E0DA8992905E4540F0C3414294CB4E40E0DA8992905E45400473F4F8BDC94E4073F22213F05945400473F4F8BDC94E40
58935	16241	41.635385999999997	41.647486999999998	61.039282	61.032406000000002	Железнодорожная	0103000020E610000001000000050000000A2B155454D14440DB183BE125844E400A2B155454D1444026A94C3107854E40E6CAA0DAE0D2444026A94C3107854E40E6CAA0DAE0D24440DB183BE125844E400A2B155454D14440DB183BE125844E40
59047	17233	41.849651999999999	41.882710000000003	61.509566999999997	61.502682	Школьная	0103000020E61000000100000005000000917D9065C1EC4440D9243FE257C04E40917D9065C1EC4440770FD07D39C14E4014ED2AA4FCF04440770FD07D39C14E4014ED2AA4FCF04440D9243FE257C04E40917D9065C1EC4440D9243FE257C04E40
58936	16740	41.371397999999999	41.378881	61.257029000000003	61.250551000000002	Новая	0103000020E6100000010000000500000060E63BF889AF4440747D1F0E12A04E4060E63BF889AF4440D28F8653E6A04E40B309302C7FB04440D28F8653E6A04E40B309302C7FB04440747D1F0E12A04E4060E63BF889AF4440747D1F0E12A04E40
58837	16889	42.436844999999998	42.532884000000003	61.041258999999997	61.022094000000003	Пионерская	0103000020E61000000100000005000000E7357689EA3745400BB8E7F9D3824E40E7357689EA37454034D593F947854E40E547FC8A3544454034D593F947854E40E547FC8A354445400BB8E7F9D3824E40E7357689EA3745400BB8E7F9D3824E40
58801	16889	42.436844999999998	42.532884000000003	61.041258999999997	61.022094000000003	Мира	0103000020E61000000100000005000000E7357689EA3745400BB8E7F9D3824E40E7357689EA37454034D593F947854E40E547FC8A3544454034D593F947854E40E547FC8A354445400BB8E7F9D3824E40E7357689EA3745400BB8E7F9D3824E40
58659	16889	42.436844999999998	42.532884000000003	61.041258999999997	61.022094000000003	Ленина	0103000020E61000000100000005000000E7357689EA3745400BB8E7F9D3824E40E7357689EA37454034D593F947854E40E547FC8A3544454034D593F947854E40E547FC8A354445400BB8E7F9D3824E40E7357689EA3745400BB8E7F9D3824E40
58683	16889	42.436844999999998	42.532884000000003	61.041258999999997	61.022094000000003	Комсомольская	0103000020E61000000100000005000000E7357689EA3745400BB8E7F9D3824E40E7357689EA37454034D593F947854E40E547FC8A3544454034D593F947854E40E547FC8A354445400BB8E7F9D3824E40E7357689EA3745400BB8E7F9D3824E40
58791	16801	41.128117000000003	41.151831999999999	61.329746999999998	61.316747999999997	Комсомольская	0103000020E61000000100000005000000E4874A23669044406589CE328BA84E40E4874A2366904440207A522635AA4E403E3E213B6F934440207A522635AA4E403E3E213B6F9344406589CE328BA84E40E4874A23669044406589CE328BA84E40
58879	18047	42.833703	42.848103000000002	61.107519000000003	61.098367000000003	Центральная	0103000020E61000000100000005000000DEC9A7C7B66A4540B900344A978C4E40DEC9A7C7B66A45406D59BE2EC38D4E40DB519CA38E6C45406D59BE2EC38D4E40DB519CA38E6C4540B900344A978C4E40DEC9A7C7B66A4540B900344A978C4E40
59038	17958	42.418475000000001	42.437536999999999	61.482939000000002	61.474277999999998	Почтовая	0103000020E61000000100000005000000C898BB96903545402C9B3924B5BC4E40C898BB9690354540427BF5F1D0BD4E401DE5603601384540427BF5F1D0BD4E401DE56036013845402C9B3924B5BC4E40C898BB96903545402C9B3924B5BC4E40
58979	17533	42.074761000000002	42.104962999999998	61.347323000000003	61.334826999999997	Почтовая	0103000020E610000001000000050000001502B9C491094540AD68739CDBAA4E401502B9C49109454006137F1475AC4E402025766D6F0D454006137F1475AC4E402025766D6F0D4540AD68739CDBAA4E401502B9C491094540AD68739CDBAA4E40
58852	17886	42.324995999999999	42.362222000000003	61.551129000000003	61.533800999999997	Партизанская	0103000020E6100000010000000500000058AA0B78992945403AC9569753C44E4058AA0B7899294540487023658BC64E4024F25D4A5D2E4540487023658BC64E4024F25D4A5D2E45403AC9569753C44E4058AA0B78992945403AC9569753C44E40
58734	17373	42.124510000000001	42.144435000000001	61.108832	61.098554	Школьная	0103000020E61000000100000005000000320395F1EF0F4540EB71DF6A9D8C4E40320395F1EF0F45400F61FC34EE8D4E40EAB298D87C1245400F61FC34EE8D4E40EAB298D87C124540EB71DF6A9D8C4E40320395F1EF0F4540EB71DF6A9D8C4E40
59045	17142	41.548357000000003	41.575944999999997	61.539327999999998	61.531751	Центральная	0103000020E610000001000000050000002FC4EA8F30C64440C24EB16A10C44E402FC4EA8F30C6444096E82CB308C54E40B9A5D590B8C9444096E82CB308C54E40B9A5D590B8C94440C24EB16A10C44E402FC4EA8F30C64440C24EB16A10C44E40
59037	18251	41.394413	41.418596000000001	61.610897999999999	61.601418000000002	Титова	0103000020E61000000100000005000000020F0C207CB24440E59CD843FBCC4E40020F0C207CB244408D98D9E731CE4E40431EC18D94B544408D98D9E731CE4E40431EC18D94B54440E59CD843FBCC4E40020F0C207CB24440E59CD843FBCC4E40
58667	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Школьный переулок	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58848	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Революционная	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58679	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Макаренко	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58578	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Ломоносова	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58835	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Кирова	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58581	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Дзержинского	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58577	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	Горького	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58720	15459	42.044578000000001	42.186143000000001	61.088469000000003	61.036476	 Дзержинского	0103000020E61000000100000005000000800F5EBBB4054540618BDD3EAB844E40800F5EBBB4054540DCDAC2F3528B4E408EB0A888D3174540DCDAC2F3528B4E408EB0A888D3174540618BDD3EAB844E40800F5EBBB4054540618BDD3EAB844E40
58926	17973	42.216020999999998	42.229971999999997	61.535271999999999	61.528444999999998	Школьная	0103000020E61000000100000005000000E61F7D93A61B45400B5EF415A4C34E40E61F7D93A61B4540753BFBCA83C44E40737FF5B86F1D4540753BFBCA83C44E40737FF5B86F1D45400B5EF415A4C34E40E61F7D93A61B45400B5EF415A4C34E40
59044	16422	42.754939	42.779975	61.362273000000002	61.356188000000003	Культурная	0103000020E61000000100000005000000CBBC55D7A1604540249D819197AD4E40CBBC55D7A1604540A69C2FF65EAE4E404B598638D6634540A69C2FF65EAE4E404B598638D6634540249D819197AD4E40CBBC55D7A1604540249D819197AD4E40
59074	16403	42.530853999999998	42.566203000000002	61.465409000000001	61.454706000000002	Центральная	0103000020E61000000100000005000000B3791C06F3434540C2A563CE33BA4E40B3791C06F3434540CD21A98592BB4E40D4F2035779484540CD21A98592BB4E40D4F2035779484540C2A563CE33BA4E40B3791C06F3434540C2A563CE33BA4E40
58838	16332	42.165832000000002	42.172803000000002	61.083579	61.078035999999997	60 лет Октября	0103000020E61000000100000005000000AD50A4FB3915454090F46915FD894E40AD50A4FB39154540F2D077B7B28A4E404AD3A0681E164540F2D077B7B28A4E404AD3A0681E16454090F46915FD894E40AD50A4FB3915454090F46915FD894E40
7112	2	30.406480999999999	30.482451999999999	59.967875999999997	59.958674000000002	шоссе Революции	0103000020E61000000100000005000000047289230F683E4044C362D4B5FA4D40047289230F683E40A94A5B5CE3FB4D40C9E369F9817B3E40A94A5B5CE3FB4D40C9E369F9817B3E4044C362D4B5FA4D40047289230F683E4044C362D4B5FA4D40
6013	2	30.379926999999999	30.423566999999998	59.841133999999997	59.829825	улица Ярослава Гашека	0103000020E610000001000000050000000DDE57E542613E409C33A2B437EA4D400DDE57E542613E40DEC66647AAEB4D4032AA0CE36E6C3E40DEC66647AAEB4D4032AA0CE36E6C3E409C33A2B437EA4D400DDE57E542613E409C33A2B437EA4D40
2389	2	30.293410000000002	30.304252999999999	59.934005999999997	59.930782000000001	улица Якубовича	0103000020E61000000100000005000000C251F2EA1C4B3E404DDA54DD23F74D40C251F2EA1C4B3E40462234828DF74D40BBB54C86E34D3E40462234828DF74D40BBB54C86E34D3E404DDA54DD23F74D40C251F2EA1C4B3E404DDA54DD23F74D40
4921	2	30.284130999999999	30.302662999999999	60.029094000000001	60.027296	улица Щербакова	0103000020E610000001000000050000009FC728CFBC483E40E3A7716F7E034E409FC728CFBC483E404241295AB9034E4091B586527B4D3E404241295AB9034E4091B586527B4D3E40E3A7716F7E034E409FC728CFBC483E40E3A7716F7E034E40
4589	2	30.325327000000001	30.33811	60.059378000000002	60.056795000000001	улица Шостаковича	0103000020E610000001000000050000007C8159A148533E40C5C9FD0E45074E407C8159A148533E400B0DC4B299074E40587380608E563E400B0DC4B299074E40587380608E563E40C5C9FD0E45074E407C8159A148533E40C5C9FD0E45074E40
3193	2	30.218993999999999	30.248072000000001	59.938685	59.932566999999999	улица Шкиперский Проток	0103000020E610000001000000050000002D05A4FD0F383E40172AFF5A5EF74D402D05A4FD0F383E40751F80D426F84D40A60D87A5813F3E40751F80D426F84D40A60D87A5813F3E40172AFF5A5EF74D402D05A4FD0F383E40172AFF5A5EF74D40
2761	2	30.290554	30.296105000000001	59.908591999999999	59.90099	улица Шкапина	0103000020E61000000100000005000000D4B837BF614A3E40F302ECA353F34D40D4B837BF614A3E4020B41EBE4CF44D409D2E8B89CD4B3E4020B41EBE4CF44D409D2E8B89CD4B3E40F302ECA353F34D40D4B837BF614A3E40F302ECA353F34D40
2764	2	30.439512000000001	30.463479	59.868350999999997	59.861756	улица Шелгунова	0103000020E610000001000000050000001633C2DB83703E40DE9046054EEE4D401633C2DB83703E407539252026EF4D40FE614B8FA6763E407539252026EF4D40FE614B8FA6763E40DE9046054EEE4D401633C2DB83703E40DE9046054EEE4D40
3137	2	30.238523000000001	30.247156	59.941406999999998	59.928514	улица Шевченко	0103000020E610000001000000050000000458E4D70F3D3E4067F0F78BD9F64D400458E4D70F3D3E40DC9C4A0680F84D409B02999D453F3E40DC9C4A0680F84D409B02999D453F3E4067F0F78BD9F64D400458E4D70F3D3E4067F0F78BD9F64D40
6844	2	30.355439000000001	30.360019999999999	59.921976000000001	59.914758999999997	улица Черняховского	0103000020E6100000010000000500000013B9E00CFE5A3E405F5CAAD216F54D4013B9E00CFE5A3E4034D93F4F03F64D40EAE74D452A5C3E4034D93F4F03F64D40EAE74D452A5C3E405F5CAAD216F54D4013B9E00CFE5A3E405F5CAAD216F54D40
5024	2	30.418607999999999	30.428068	60.031565999999998	60.022880999999998	улица Черкасова	0103000020E610000001000000050000000ED8D5E4296B3E409259BDC3ED024E400ED8D5E4296B3E4030D5CC5A0A044E40D1764CDD956D3E4030D5CC5A0A044E40D1764CDD956D3E409259BDC3ED024E400ED8D5E4296B3E409259BDC3ED024E40
8047	2	30.130338999999999	30.179881000000002	59.845089000000002	59.842291000000003	улица Чекистов	0103000020E61000000100000005000000B2648EE55D213E408A5B0531D0EB4D40B2648EE55D213E40CC9A58E02BEC4D40FA2B64AE0C2E3E40CC9A58E02BEC4D40FA2B64AE0C2E3E408A5B0531D0EB4D40B2648EE55D213E408A5B0531D0EB4D40
2712	2	30.281472000000001	30.288765999999999	59.915900000000001	59.909264999999998	улица Циолковского	0103000020E610000001000000050000005EBD8A8C0E483E40DF32A7CB62F44D405EBD8A8C0E483E40053411363CF54D405D328E91EC493E40053411363CF54D405D328E91EC493E40DF32A7CB62F44D405EBD8A8C0E483E40DF32A7CB62F44D40
3725	2	30.347335999999999	30.351054999999999	59.989683999999997	59.980649999999997	улица Харченко	0103000020E6100000010000000500000034B91803EB583E4044696FF085FD4D4034B91803EB583E40EEAF1EF7ADFE4D40E71890BDDE593E40EEAF1EF7ADFE4D40E71890BDDE593E4044696FF085FD4D4034B91803EB583E4044696FF085FD4D40
1172	2	30.314287	30.337095000000001	59.861842000000003	59.861530000000002	улица Фрунзе	0103000020E61000000100000005000000D68EE21C75503E40EE42739D46EE4D40D68EE21C75503E40DD28B2D650EE4D4027A5A0DB4B563E40DD28B2D650EE4D4027A5A0DB4B563E40EE42739D46EE4D40D68EE21C75503E40EE42739D46EE4D40
5372	2	30.377457	30.394991999999998	60.003079	60.000033999999999	улица Фаворского	0103000020E6100000010000000500000072A59E05A1603E40AC71361D01004E4072A59E05A1603E40F62686E464004E407F2E1A321E653E40F62686E464004E407F2E1A321E653E40AC71361D01004E4072A59E05A1603E40AC71361D01004E40
5072	2	30.403570999999999	30.417853999999998	60.045003000000001	60.027521	улица Ушинского	0103000020E61000000100000005000000309DD66D50673E40037AE1CE85034E40309DD66D50673E40679C86A8C2054E40B680D07AF86A3E40679C86A8C2054E40B680D07AF86A3E40037AE1CE85034E40309DD66D50673E40037AE1CE85034E40
5708	2	30.359570999999999	30.412599	59.868541	59.866070000000001	улица Турку	0103000020E610000001000000050000000B9755D80C5C3E40FB05BB61DBEE4D400B9755D80C5C3E40191EFB592CEF4D40C05C8B16A0693E40191EFB592CEF4D40C05C8B16A0693E40FB05BB61DBEE4D400B9755D80C5C3E40FB05BB61DBEE4D40
2631	2	30.418258000000002	30.436844000000001	59.894680000000001	59.890540999999999	улица Ткачей	0103000020E61000000100000005000000564ACFF4126B3E40A25F5B3FFDF14D40564ACFF4126B3E405131CEDF84F24D402E742502D56F3E405131CEDF84F24D402E742502D56F3E40A25F5B3FFDF14D40564ACFF4126B3E40A25F5B3FFDF14D40
1981	2	30.448467999999998	30.490860000000001	59.892865999999998	59.888334	улица Тельмана	0103000020E61000000100000005000000724D81CCCE723E4062F6B2EDB4F14D40724D81CCCE723E40ECDADE6E49F24D4021EA3E00A97D3E40ECDADE6E49F24D4021EA3E00A97D3E4062F6B2EDB4F14D40724D81CCCE723E4062F6B2EDB4F14D40
50	2	30.155958999999999	30.158374999999999	59.844175999999997	59.824745999999998	улица Тамбасова	0103000020E610000001000000050000005184D4EDEC273E40DFC0E44691E94D405184D4EDEC273E40B7088CF50DEC4D40068195438B283E40B7088CF50DEC4D40068195438B283E40DFC0E44691E94D405184D4EDEC273E40DFC0E44691E94D40
6369	2	30.189914999999999	30.221364999999999	59.828938999999998	59.827084999999997	улица Стойкости	0103000020E610000001000000050000001405FA449E303E408E01D9EBDDE94D401405FA449E303E4081B053AC1AEA4D40A27A6B60AB383E4081B053AC1AEA4D40A27A6B60AB383E408E01D9EBDDE94D401405FA449E303E408E01D9EBDDE94D40
7015	2	30.428498999999999	30.442629	59.968394000000004	59.967565	улица Стасовой	0103000020E61000000100000005000000635E471CB26D3E408BE07F2BD9FB4D40635E471CB26D3E4042D2A755F4FB4D40DD42572250713E4042D2A755F4FB4D40DD42572250713E408BE07F2BD9FB4D40635E471CB26D3E408BE07F2BD9FB4D40
2134	2	30.283833999999999	30.295503	59.924393000000002	59.921438999999999	улица Союза Печатников	0103000020E610000001000000050000002C7E5358A9483E40252191B6F1F54D402C7E5358A9483E405FD3838252F64D40B1DEA815A64B3E405FD3838252F64D40B1DEA815A64B3E40252191B6F1F54D402C7E5358A9483E40252191B6F1F54D40
4993	2	30.408519999999999	30.417359999999999	60.019086000000001	60.010272000000001	улица Софьи Ковалевской	0103000020E610000001000000050000000DC347C494683E404208C89750014E400DC347C494683E40DEE7F86871024E4097A8DE1AD86A3E40DEE7F86871024E4097A8DE1AD86A3E404208C89750014E400DC347C494683E404208C89750014E40
6338	2	30.208061000000001	30.223872	59.842689	59.825398	улица Солдата Корзуна	0103000020E61000000100000005000000B492567C43353E40871744A4A6E94D40B492567C43353E4077D9AF3BDDEB4D40787DE6AC4F393E4077D9AF3BDDEB4D40787DE6AC4F393E40871744A4A6E94D40B492567C43353E40871744A4A6E94D40
3671	2	30.336618999999999	30.348172000000002	59.971443000000001	59.969866000000003	улица Смолячкова	0103000020E610000001000000050000005436ACA92C563E404DC0AF9124FC4D405436ACA92C563E40CD76853E58FC4D400762D9CC21593E40CD76853E58FC4D400762D9CC21593E404DC0AF9124FC4D405436ACA92C563E404DC0AF9124FC4D40
4591	2	30.322120000000002	30.326998	60.061497000000003	60.055433999999998	улица Симонова	0103000020E610000001000000050000003563D17476523E40118B187618074E403563D17476523E40ACE63922DF074E407FDB1324B6533E40ACE63922DF074E407FDB1324B6533E40118B187618074E403563D17476523E40118B187618074E40
4094	2	30.321366000000001	30.343661999999998	60.035522	60.034447	улица Сикейроса	0103000020E61000000100000005000000DD0BCC0A45523E40003961C268044E40DD0BCC0A45523E40EE2422FC8B044E40C1E09A3BFA573E40EE2422FC8B044E40C1E09A3BFA573E40003961C268044E40DD0BCC0A45523E40003961C268044E40
2649	2	30.381149000000001	30.451253000000001	59.905565000000003	59.861024	улица Седова	0103000020E6100000010000000500000032E719FB92613E401A89D00836EE4D4032E719FB92613E407DB3CD8DE9F34D40CE380D5185733E407DB3CD8DE9F34D40CE380D5185733E401A89D00836EE4D4032E719FB92613E401A89D00836EE4D40
4145	2	30.354171999999998	30.356992999999999	60.037894999999999	60.031733000000003	улица Сантьяго-де-Куба	0103000020E61000000100000005000000AE282504AB5A3E401C9AB2D30F044E40AE282504AB5A3E4049D74CBED9044E40A3E6ABE4635B3E4049D74CBED9044E40A3E6ABE4635B3E401C9AB2D30F044E40AE282504AB5A3E401C9AB2D30F044E40
4192	2	30.189115999999999	30.302295000000001	59.990614999999998	59.983648000000002	улица Савушкина	0103000020E610000001000000050000007C26FBE769303E404E637B2DE8FD4D407C26FBE769303E40A9F6E978CCFE4D408CBE8234634D3E40A9F6E978CCFE4D408CBE8234634D3E404E637B2DE8FD4D407C26FBE769303E404E637B2DE8FD4D40
5562	2	30.431239000000001	30.438110999999999	60.042001999999997	59.996006999999999	улица Руставели	0103000020E610000001000000050000007FC2D9AD656E3E4025CB49287DFF4D407FC2D9AD656E3E40EC2E505260054E409204E10A28703E40EC2E505260054E409204E10A28703E4025CB49287DFF4D407FC2D9AD656E3E4025CB49287DFF4D40
3936	2	30.359221000000002	30.371949999999998	60.053148	60.037444999999998	улица Руднева	0103000020E6100000010000000500000053094FE8F55B3E4009336DFFCA044E4053094FE8F55B3E4085ECBC8DCD064E4048BF7D1D385F3E4085ECBC8DCD064E4048BF7D1D385F3E4009336DFFCA044E4053094FE8F55B3E4009336DFFCA044E40
7877	2	30.175712999999998	30.197451999999998	59.850648999999997	59.850219000000003	улица Рихарда Зорге	0103000020E61000000100000005000000677BF486FB2C3E400BB8E7F9D3EC4D40677BF486FB2C3E4003B00111E2EC4D40A087DA368C323E4003B00111E2EC4D40A087DA368C323E400BB8E7F9D3EC4D40677BF486FB2C3E400BB8E7F9D3EC4D40
3251	2	30.284535000000002	30.328678	59.972437999999997	59.970308000000003	улица Профессора Попова	0103000020E610000001000000050000003F912749D7483E400A86730D33FC4D403F912749D7483E409EB12FD978FC4D4029EACC3D24543E409EB12FD978FC4D4029EACC3D24543E400A86730D33FC4D403F912749D7483E400A86730D33FC4D40
6656	2	30.390096	30.390671000000001	59.950609	59.944490000000002	улица Пролетарской Диктатуры	0103000020E61000000100000005000000E84CDA54DD633E4014B35E0CE5F84D40E84CDA54DD633E404224438EADF94D40E17EC00303643E404224438EADF94D40E17EC00303643E4014B35E0CE5F84D40E84CDA54DD633E4014B35E0CE5F84D40
6090	2	30.272911000000001	30.280222999999999	59.871015999999997	59.867218000000001	улица Примакова	0103000020E61000000100000005000000FAB7CB7EDD453E405340DAFF00EF4D40FAB7CB7EDD453E407825C9737DEF4D404696CCB1BC473E407825C9737DEF4D404696CCB1BC473E405340DAFF00EF4D40FAB7CB7EDD453E405340DAFF00EF4D40
149	2	30.099733000000001	30.113235	59.780309000000003	59.779770999999997	улица Политрука Пасечника	0103000020E61000000100000005000000FC54151A88193E4042AF3F89CFE34D40FC54151A88193E4022E3512AE1E34D4037C30DF8FC1C3E4022E3512AE1E34D4037C30DF8FC1C3E4042AF3F89CFE34D40FC54151A88193E4042AF3F89CFE34D40
2371	2	30.450444999999998	30.501567999999999	59.918926999999996	59.906855	улица Подвойского	0103000020E610000001000000050000008FA50F5D50733E40679B1BD313F44D408FA50F5D50733E40A83462669FF54D405AB8ACC266803E40A83462669FF54D405AB8ACC266803E40679B1BD313F44D408FA50F5D50733E40679B1BD313F44D40
6205	2	30.256274000000001	30.272974000000001	59.847611999999998	59.839917999999997	улица Подводника Кузьмина	0103000020E61000000100000005000000ABD0402C9B413E402EA9DA6E82EB4D40ABD0402C9B413E403CD9CD8C7EEC4D4087A8C29FE1453E403CD9CD8C7EEC4D4087A8C29FE1453E402EA9DA6E82EB4D40ABD0402C9B413E402EA9DA6E82EB4D40
4	2	30.146401000000001	30.147155999999999	59.846792999999998	59.825347999999998	улица Пограничника Гарькавого	0103000020E61000000100000005000000091A33897A253E40D5E8D500A5E94D40091A33897A253E40A9BD88B663EC4D400169FF03AC253E40A9BD88B663EC4D400169FF03AC253E40D5E8D500A5E94D40091A33897A253E40D5E8D500A5E94D40
7013	2	30.127320999999998	30.130447	59.847118999999999	59.835355999999997	улица Пионерстроя	0103000020E610000001000000050000001118EB1B98203E40394206F2ECEA4D401118EB1B98203E40FD6838656EEC4D407FDC7EF964213E40FD6838656EEC4D407FDC7EF964213E40394206F2ECEA4D401118EB1B98203E40394206F2ECEA4D40
16098	2	30.232028	30.261619	60.080891999999999	60.073552999999997	улица Первого Мая	0103000020E610000001000000050000009CC1DF2F663B3E40E7C2482F6A094E409CC1DF2F663B3E40074147AB5A0A4E4021037976F9423E40074147AB5A0A4E4021037976F9423E40E7C2482F6A094E409CC1DF2F663B3E40E7C2482F6A094E40
7002	2	30.4102	30.419992000000001	59.952249999999999	59.951757999999998	улица Панфилова	0103000020E61000000100000005000000B7D100DE02693E406ADAC534D3F94D40B7D100DE02693E40D9CEF753E3F94D40E6948098846B3E40D9CEF753E3F94D40E6948098846B3E406ADAC534D3F94D40B7D100DE02693E406ADAC534D3F94D40
7352	2	30.481275	30.484500000000001	59.949131999999999	59.945017	улица Осипенко	0103000020E61000000100000005000000E561A1D6347B3E40FF942A51F6F84D40E561A1D6347B3E4025CB49287DF94D4079E92631087C3E4025CB49287DF94D4079E92631087C3E40FF942A51F6F84D40E561A1D6347B3E40FF942A51F6F84D40
1439	2	30.322641000000001	30.367737000000002	59.844397999999998	59.842579999999998	улица Орджоникидзе	0103000020E610000001000000050000004759BF9998523E40C02154A9D9EB4D404759BF9998523E406667D13B15EC4D4077871403245E3E406667D13B15EC4D4077871403245E3E40C02154A9D9EB4D404759BF9998523E40C02154A9D9EB4D40
3596	2	30.337733	30.341712999999999	60.007969000000003	59.996920000000003	улица Орбели	0103000020E61000000100000005000000ACC77DAB75563E403A5D16139BFF4D40ACC77DAB75563E40E030D12005014E40389ECF807A573E40E030D12005014E40389ECF807A573E403A5D16139BFF4D40ACC77DAB75563E403A5D16139BFF4D40
4127	2	30.195260000000001	30.255447	60.002980000000001	59.995170000000002	улица Оптиков	0103000020E610000001000000050000008B37328FFC313E40ECFA05BB61FF4D408B37328FFC313E4063450DA661004E407FDC7EF964413E4063450DA661004E407FDC7EF964413E40ECFA05BB61FF4D408B37328FFC313E40ECFA05BB61FF4D40
5241	2	30.387221	30.395593999999999	60.045605000000002	60.035355000000003	улица Ольги Форш	0103000020E610000001000000050000000D535BEA20633E4003603C8386044E400D535BEA20633E405DC47762D6054E406B7EFCA545653E405DC47762D6054E406B7EFCA545653E4003603C8386044E400D535BEA20633E4003603C8386044E40
2583	2	30.401729	30.432478	59.897365999999998	59.888356000000002	улица Ольги Берггольц	0103000020E61000000100000005000000D3DA34B6D7663E404A9A3FA6B5F14D40D3DA34B6D7663E406B459BE3DCF24D404F3DD2E0B66E3E406B459BE3DCF24D404F3DD2E0B66E3E404A9A3FA6B5F14D40D3DA34B6D7663E404A9A3FA6B5F14D40
6071	2	30.385487999999999	30.428697	59.835487000000001	59.827604999999998	улица Олеко Дундича	0103000020E610000001000000050000001D007157AF623E40C780ECF5EEE94D401D007157AF623E40D89DEE3CF1EA4D40B0E42A16BF6D3E40D89DEE3CF1EA4D40B0E42A16BF6D3E40C780ECF5EEE94D401D007157AF623E40C780ECF5EEE94D40
1861	2	30.451568000000002	30.489799999999999	59.887971999999998	59.88232	улица Новосёлов	0103000020E610000001000000050000008EEBDFF599733E40A94D9CDCEFF04D408EEBDFF599733E40C1E10511A9F14D40AF946588637D3E40C1E10511A9F14D40AF946588637D3E40A94D9CDCEFF04D408EEBDFF599733E40A94D9CDCEFF04D40
3248	2	30.218247999999999	30.237777999999999	59.944282999999999	59.939473999999997	улица Нахимова	0103000020E61000000100000005000000DB6AD619DF373E409DB81CAF40F84D40DB6AD619DF373E409A95ED43DEF84D4052B5DD04DF3C3E409A95ED43DEF84D4052B5DD04DF3C3E409DB81CAF40F84D40DB6AD619DF373E409DB81CAF40F84D40
6732	2	30.374223000000001	30.395764	59.937648000000003	59.937368999999997	улица Моисеенко	0103000020E6100000010000000500000038691A14CD5F3E4061A417B5FBF74D4038691A14CD5F3E40759483D904F84D4024EF1CCA50653E40759483D904F84D4024EF1CCA50653E4061A417B5FBF74D4038691A14CD5F3E4061A417B5FBF74D40
7000	2	30.413990999999999	30.431248	59.973360999999997	59.959859000000002	улица Маршала Тухачевского	0103000020E610000001000000050000009DD66D50FB693E40B9E2E2A8DCFA4D409DD66D50FB693E40D619DF1797FC4D402577D844666E3E40D619DF1797FC4D402577D844666E3E40B9E2E2A8DCFA4D409DD66D50FB693E40B9E2E2A8DCFA4D40
4738	2	30.265625	30.275866000000001	60.036259000000001	60.007137	улица Маршала Новикова	0103000020E610000001000000050000000000000000443E40B8CB7EDDE9004E400000000000443E40C4978922A4044E400E1478279F463E40C4978922A4044E400E1478279F463E40B8CB7EDDE9004E400000000000443E40B8CB7EDDE9004E40
7823	2	30.206184	30.253623999999999	59.859988999999999	59.858702000000001	улица Маршала Казакова	0103000020E610000001000000050000005EF58079C8343E40418177F2E9ED4D405EF58079C8343E40BAF59A1E14EE4D400F7BA180ED403E40BAF59A1E14EE4D400F7BA180ED403E40418177F2E9ED4D405EF58079C8343E40418177F2E9ED4D40
7669	2	30.157792000000001	30.216460999999999	59.859527999999997	59.848402999999998	улица Маршала Захарова	0103000020E610000001000000050000000892770E65283E40056A317898EC4D400892770E65283E4086FF740305EE4D4005DCF3FC69373E4086FF740305EE4D4005DCF3FC69373E40056A317898EC4D400892770E65283E40056A317898EC4D40
5973	2	30.262311	30.290554	59.903016000000001	59.873894	улица Маршала Говорова	0103000020E610000001000000050000008D614ED026433E40D71533C2DBEF4D408D614ED026433E40E3E13D0796F34D40D4B837BF614A3E40E3E13D0796F34D40D4B837BF614A3E40D71533C2DBEF4D408D614ED026433E40D71533C2DBEF4D40
6072	2	30.263477999999999	30.267889	59.870660000000001	59.867710000000002	улица Маринеско	0103000020E610000001000000050000002A37514B73433E40C2340C1F11EF4D402A37514B73433E40BAF770C971EF4D4049F59D5F94443E40BAF770C971EF4D4049F59D5F94443E40C2340C1F11EF4D402A37514B73433E40C2340C1F11EF4D40
8138	2	30.140229000000001	30.140373	59.845089000000002	59.825732000000002	улица Лётчика Пилютова	0103000020E6100000010000000500000067F3380CE6233E405EA10F96B1E94D4067F3380CE6233E40CC9A58E02BEC4D40CD3D247CEF233E40CC9A58E02BEC4D40CD3D247CEF233E405EA10F96B1E94D4067F3380CE6233E405EA10F96B1E94D40
6487	2	30.227886999999999	30.252303000000001	59.848357	59.831743000000003	улица Лёни Голикова	0103000020E61000000100000005000000FD2E6CCD563A3E40A6D6FB8D76EA4D40FD2E6CCD563A3E40952A51F696EC4D40C5AEEDED96403E40952A51F696EC4D40C5AEEDED96403E40A6D6FB8D76EA4D40FD2E6CCD563A3E40A6D6FB8D76EA4D40
1479	2	30.329333999999999	30.351271000000001	59.861719999999998	59.830142000000002	улица Ленсовета	0103000020E61000000100000005000000FB75A73B4F543E409D84D21742EA4D40FB75A73B4F543E40912749D74CEE4D40810871E5EC593E40912749D74CEE4D40810871E5EC593E409D84D21742EA4D40FB75A73B4F543E409D84D21742EA4D40
2426	2	30.444875	30.472318999999999	59.933176000000003	59.925654999999999	улица Латышских Стрелков	0103000020E61000000100000005000000D9CEF753E3713E407F30F0DC7BF64D40D9CEF753E3713E40C0B4A84F72F74D408847E2E5E9783E40C0B4A84F72F74D408847E2E5E9783E407F30F0DC7BF64D40D9CEF753E3713E407F30F0DC7BF64D40
2033	2	30.447075999999999	30.495557999999999	59.901757000000003	59.892806999999998	улица Крыленко	0103000020E6100000010000000500000095D39E9273723E40E751F17F47F24D4095D39E9273723E4034F8FBC56CF34D406B459BE3DC7E3E4034F8FBC56CF34D406B459BE3DC7E3E40E751F17F47F24D4095D39E9273723E40E751F17F47F24D40
7838	2	30.209040000000002	30.213774999999998	59.859881000000001	59.854576000000002	улица Котина	0103000020E610000001000000050000004C8E3BA583353E4027F911BF62ED4D404C8E3BA583353E40D4B9A29410EE4D40D0B359F5B9363E40D4B9A29410EE4D40D0B359F5B9363E4027F911BF62ED4D404C8E3BA583353E4027F911BF62ED4D40
1668	2	30.291919	30.314242	59.848180999999997	59.841237999999997	улица Костюшко	0103000020E61000000100000005000000BE141E34BB4A3E408313D1AFADEB4D40BE141E34BB4A3E40560BEC3191EC4D409607E92972503E40560BEC3191EC4D409607E92972503E408313D1AFADEB4D40BE141E34BB4A3E408313D1AFADEB4D40
3412	2	30.214053	30.235890999999999	59.956417000000002	59.940407	улица Кораблестроителей	0103000020E61000000100000005000000569C6A2DCC363E40F9F6AE415FF84D40569C6A2DCC363E40522B4CDF6BFA4D40B56B425A633C3E40522B4CDF6BFA4D40B56B425A633C3E40F9F6AE415FF84D40569C6A2DCC363E40F9F6AE415FF84D40
4667	2	30.313793	30.320809000000001	60.064861000000001	60.044387999999998	улица Композиторов	0103000020E61000000100000005000000B7B6F0BC54503E40DC2A8881AE054E40B7B6F0BC54503E4097E4805D4D084E403143E38920523E4097E4805D4D084E403143E38920523E40DC2A8881AE054E40B7B6F0BC54503E40DC2A8881AE054E40
16660	2	30.196194999999999	30.208088	60.105893999999999	60.098767000000002	улица Коммуны	0103000020E6100000010000000500000083A3E4D539323E404776A565A40C4E4083A3E4D539323E40DB6B41EF8D0D4E40A7B0524145353E40DB6B41EF8D0D4E40A7B0524145353E404776A565A40C4E4083A3E4D539323E404776A565A40C4E40
3644	2	30.344722000000001	30.356041000000001	59.962868	59.961754999999997	улица Комиссара Смирнова	0103000020E61000000100000005000000333674B33F583E40DAE1AFC91AFB4D40333674B33F583E40B62E35423FFB4D40FF08C380255B3E40B62E35423FFB4D40FF08C380255B3E40DAE1AFC91AFB4D40333674B33F583E40DAE1AFC91AFB4D40
6326	2	30.216847000000001	30.230626999999998	59.840845000000002	59.826799999999999	улица Козлова	0103000020E61000000100000005000000583CF54883373E40992A1895D4E94D40583CF54883373E40A80018CFA0EB4D401893FE5E0A3B3E40A80018CFA0EB4D401893FE5E0A3B3E40992A1895D4E94D40583CF54883373E40992A1895D4E94D40
2762	2	30.433592000000001	30.443626999999999	59.868459999999999	59.858759999999997	улица Кибальчича	0103000020E61000000100000005000000A7CEA3E2FF6E3E40758E01D9EBED4D40A7CEA3E2FF6E3E402CF180B229EF4D40629F008A91713E402CF180B229EF4D40629F008A91713E40758E01D9EBED4D40A7CEA3E2FF6E3E40758E01D9EBED4D40
5478	2	30.415904000000001	30.432371	60.014530999999998	60.001181000000003	улица Карпинского	0103000020E610000001000000050000008D463EAF786A3E403430F2B226004E408D463EAF786A3E409BE3DC26DC014E4023BDA8DDAF6E3E409BE3DC26DC014E4023BDA8DDAF6E3E403430F2B226004E408D463EAF786A3E403430F2B226004E40
6544	2	30.256274000000001	30.256381999999999	59.857377999999997	59.847611999999998	улица Зины Портновой	0103000020E61000000100000005000000ABD0402C9B413E403CD9CD8C7EEC4D40ABD0402C9B413E40AA27F38FBEED4D4077483140A2413E40AA27F38FBEED4D4077483140A2413E403CD9CD8C7EEC4D40ABD0402C9B413E403CD9CD8C7EEC4D40
71	2	30.159939000000001	30.163855000000002	59.841332999999999	59.824452000000001	улица Здоровцева	0103000020E61000000100000005000000DE5A26C3F1283E40978FA4A487E94D40DE5A26C3F1283E40D505BCCCB0EB4D403D49BA66F2293E40D505BCCCB0EB4D403D49BA66F2293E40978FA4A487E94D40DE5A26C3F1283E40978FA4A487E94D40
5984	2	30.259840000000001	30.275354	59.880811999999999	59.869987000000002	улица Зайцева	0103000020E610000001000000050000005131CEDF84423E40FB78E8BB5BEF4D405131CEDF84423E4051F69672BEF04D40A2D288997D463E4051F69672BEF04D40A2D288997D463E40FB78E8BB5BEF4D405131CEDF84423E40FB78E8BB5BEF4D40
4483	2	30.324824	30.347462	60.058143000000001	60.025551999999998	улица Есенина	0103000020E61000000100000005000000B6F468AA27533E40772CB64945034E40B6F468AA27533E40E4BED53A71074E404E9A0645F3583E40E4BED53A71074E404E9A0645F3583E40772CB64945034E40B6F468AA27533E40772CB64945034E40
2618	2	30.314026999999999	30.314233000000002	59.915985999999997	59.908872000000002	улица Егорова	0103000020E610000001000000050000009D0FCF1264503E400420EEEA55F44D409D0FCF1264503E4003CC7C073FF54D40F052EA9271503E4003CC7C073FF54D40F052EA9271503E400420EEEA55F44D409D0FCF1264503E400420EEEA55F44D40
2120	2	30.444381	30.500112999999999	59.912734	59.897911999999998	улица Дыбенко	0103000020E61000000100000005000000BAF605F4C2713E40CD57C9C7EEF24D40BAF605F4C2713E4040F9BB77D4F44D40F04DD36707803E4040F9BB77D4F44D40F04DD36707803E40CD57C9C7EEF24D40BAF605F4C2713E40CD57C9C7EEF24D40
7471	2	30.165239	30.167556000000001	59.844009	59.824308000000002	улица Добровольцев	0103000020E610000001000000050000001406651A4D2A3E4064EAAEEC82E94D401406651A4D2A3E40CC43A67C08EC4D40A33F34F3E42A3E40CC43A67C08EC4D40A33F34F3E42A3E4064EAAEEC82E94D401406651A4D2A3E4064EAAEEC82E94D40
5916	2	30.371518999999999	30.426379000000001	59.851905000000002	59.844650999999999	улица Димитрова	0103000020E61000000100000005000000B6D782DE1B5F3E4050C422861DEC4D40B6D782DE1B5F3E40422619390BED4D4081B3942C276D3E40422619390BED4D4081B3942C276D3E4050C422861DEC4D40B6D782DE1B5F3E4050C422861DEC4D40
2448	2	30.452007999999999	30.455753999999999	59.923220000000001	59.917591999999999	улица Джона Рида	0103000020E61000000100000005000000C687D9CBB6733E401E8997A773F54D40C687D9CBB6733E40AE81AD122CF64D406C054D4BAC743E40AE81AD122CF64D406C054D4BAC743E401E8997A773F54D40C687D9CBB6733E401E8997A773F54D40
5147	2	30.379235000000001	30.392925999999999	60.050206000000003	60.033360000000002	улица Демьяна Бедного	0103000020E61000000100000005000000A27F828B15613E404E7FF62345044E40A27F828B15613E40100874266D064E4083BF5FCC96643E40100874266D064E4083BF5FCC96643E404E7FF62345044E40A27F828B15613E404E7FF62345044E40
16580	2	29.714732999999999	29.720348000000001	60.012763999999997	60.008203000000002	улица Гидростроителей	0103000020E61000000100000005000000395FECBDF8B63D40535DC0CB0C014E40395FECBDF8B63D4077483140A2014E4030BDFDB968B83D4077483140A2014E4030BDFDB968B83D40535DC0CB0C014E40395FECBDF8B63D40535DC0CB0C014E40
6700	2	30.360101	30.360783999999999	59.943787	59.931052999999999	улица Восстания	0103000020E61000000100000005000000C44142942F5C3E40DDEBA4BE2CF74D40C44142942F5C3E40EAB12D03CEF84D4089EB18575C5C3E40EAB12D03CEF84D4089EB18575C5C3E40DDEBA4BE2CF74D40C44142942F5C3E40DDEBA4BE2CF74D40
5422	2	30.394659000000001	30.436826	60.009867	59.997855999999999	улица Верности	0103000020E6100000010000000500000073124A5F08653E40060FD3BEB9FF4D4073124A5F08653E40A227655243014E40E10A28D4D36F3E40A227655243014E40E10A28D4D36F3E40060FD3BEB9FF4D4073124A5F08653E40060FD3BEB9FF4D40
4923	2	30.385604000000001	30.395378000000001	60.025061999999998	60.015515999999998	улица Вавиловых	0103000020E61000000100000005000000F03499F1B6623E404948A46DFC014E40F03499F1B6623E40A92F4B3B35034E40D28E1B7E37653E40A92F4B3B35034E40D28E1B7E37653E404948A46DFC014E40F03499F1B6623E404948A46DFC014E40
5396	2	30.391327	30.40587	60.010928999999997	59.994576000000002	улица Бутлерова	0103000020E61000000100000005000000B30A9B012E643E4079B130444EFF4D40B30A9B012E643E40FBC9181F66014E40726DA818E7673E40FBC9181F66014E40726DA818E7673E4079B130444EFF4D40B30A9B012E643E4079B130444EFF4D40
6370	2	30.198988	30.209795	59.836137999999998	59.833416	улица Бурцева	0103000020E61000000100000005000000E44BA8E0F0323E4048FB1F60ADEA4D40E44BA8E0F0323E40AF78EA9106EB4D4044DD0720B5353E40AF78EA9106EB4D4044DD0720B5353E4048FB1F60ADEA4D40E44BA8E0F0323E4048FB1F60ADEA4D40
5293	2	30.401216999999999	30.409579999999998	60.042752	60.032496999999999	улица Брянцева	0103000020E6100000010000000500000067994528B6663E40EB1B98DC28044E4067994528B6663E4057EBC4E578054E407E18213CDA683E4057EBC4E578054E407E18213CDA683E40EB1B98DC28044E4067994528B6663E40EB1B98DC28044E40
2988	2	30.290814000000001	30.306201999999999	59.952573999999998	59.950443	улица Блохина	0103000020E610000001000000050000000D384BC9724A3E4027DBC01DA8F94D400D384BC9724A3E408C82E0F1EDF94D4044F81741634E3E408C82E0F1EDF94D4044F81741634E3E4027DBC01DA8F94D400D384BC9724A3E4027DBC01DA8F94D40
5585	2	30.370818	30.405187999999999	59.880943000000002	59.867592999999999	улица Белы Куна	0103000020E61000000100000005000000A4C4AEEDED5E3E40889E94490DEF4D40A4C4AEEDED5E3E40F0517FBDC2F04D404DBB9866BA673E40F0517FBDC2F04D404DBB9866BA673E40889E94490DEF4D40A4C4AEEDED5E3E40889E94490DEF4D40
2699	2	30.418887000000002	30.478607	59.898918000000002	59.859718000000001	улица Бабушкина	0103000020E6100000010000000500000035B8AD2D3C6B3E402AE44A3D0BEE4D4035B8AD2D3C6B3E4093E4B9BE0FF34D40FDA204FD857A3E4093E4B9BE0FF34D40FDA204FD857A3E402AE44A3D0BEE4D4035B8AD2D3C6B3E402AE44A3D0BEE4D40
4624	2	30.318473000000001	30.330735000000001	60.048391000000002	60.047074000000002	улица Асафьева	0103000020E61000000100000005000000B5A84F7287513E40F73E558506064E40B5A84F7287513E40DB3521AD31064E407FA4880CAB543E40DB3521AD31064E407FA4880CAB543E40F73E558506064E40B5A84F7287513E40F73E558506064E40
4874	2	30.378426999999999	30.385235999999999	60.024800999999997	60.016779999999997	улица Академика Константинова	0103000020E6100000010000000500000063EC8497E0603E400A9DD7D825024E4063EC8497E0603E403CF4DDAD2C034E40EA3D95D39E623E403CF4DDAD2C034E40EA3D95D39E623E400A9DD7D825024E4063EC8497E0603E400A9DD7D825024E40
4897	2	30.365158999999998	30.392800000000001	60.030137000000003	60.022691999999999	улица Академика Байкова	0103000020E610000001000000050000000ED76A0F7B5D3E40BFF04A92E7024E400ED76A0F7B5D3E4025B37A87DB034E406ADE718A8E643E4025B37A87DB034E406ADE718A8E643E40BFF04A92E7024E400ED76A0F7B5D3E40BFF04A92E7024E40
1264	2	30.332729	30.338325999999999	59.87603	59.837038	проспект Юрия Гагарина	0103000020E61000000100000005000000486E4DBA2D553E402FC1A90F24EB4D40486E4DBA2D553E404E2844C021F04D40F16261889C563E404E2844C021F04D40F16261889C563E402FC1A90F24EB4D40486E4DBA2D553E402FC1A90F24EB4D40
7492	2	30.462734000000001	30.497579000000002	59.953375999999999	59.944282999999999	проспект Энтузиастов	0103000020E610000001000000050000004DBF44BC75763E409A95ED43DEF84D404DBF44BC75763E4049658A3908FA4D40282D5C56617F3E4049658A3908FA4D40282D5C56617F3E409A95ED43DEF84D404DBF44BC75763E409A95ED43DEF84D40
7145	2	30.434949	30.438182999999999	59.976503999999998	59.933306999999999	проспект Энергетиков	0103000020E610000001000000050000008B6D52D1586F3E405E10919A76F74D408B6D52D1586F3E40E3344415FEFC4D40C5A9D6C22C703E40E3344415FEFC4D40C5A9D6C22C703E405E10919A76F74D408B6D52D1586F3E405E10919A76F74D40
3573	2	30.318778999999999	30.364008999999999	60.088555999999997	59.998018000000002	проспект Энгельса	0103000020E61000000100000005000000CEA623809B513E40E068C70DBFFF4D40CEA623809B513E40AAEE91CD550B4E401D739EB12F5D3E40AAEE91CD550B4E401D739EB12F5D3E40E068C70DBFFF4D40CEA623809B513E40E068C70DBFFF4D40
7238	2	30.412841	30.427906	59.941848999999998	59.921636999999997	проспект Шаумяна	0103000020E61000000100000005000000AC72A1F2AF693E404BE48233F8F54D40AC72A1F2AF693E4099620E828EF84D401EC3633F8B6D3E4099620E828EF84D401EC3633F8B6D3E404BE48233F8F54D40AC72A1F2AF693E404BE48233F8F54D40
4143	2	30.343599000000001	30.360523000000001	60.056575000000002	60.031224999999999	проспект Художников	0103000020E6100000010000000500000035F0A31AF6573E40A7E8482EFF034E4035F0A31AF6573E40B7627FD93D074E40B0743E3C4B5C3E40B7627FD93D074E40B0743E3C4B5C3E40A7E8482EFF034E4035F0A31AF6573E40A7E8482EFF034E40
7372	2	30.460927999999999	30.493815000000001	59.956958	59.948411	проспект Ударников	0103000020E6100000010000000500000089CF9D60FF753E4055151A8865F94D4089CF9D60FF753E40A2D288997DFA4D403546EBA86A7E3E40A2D288997DFA4D403546EBA86A7E3E4055151A8865F94D4089CF9D60FF753E4055151A8865F94D40
3807	2	30.319928000000001	30.363945999999999	60.03002	59.999079999999999	проспект Тореза	0103000020E610000001000000050000001F1329CDE6513E40390B7BDAE1FF4D401F1329CDE6513E40EB1C03B2D7034E409082A7902B5D3E40EB1C03B2D7034E409082A7902B5D3E40390B7BDAE1FF4D401F1329CDE6513E40390B7BDAE1FF4D40
6519	2	30.212237999999999	30.276216000000002	59.899906000000001	59.845519000000003	проспект Стачек	0103000020E61000000100000005000000ECF7C43A55363E40C59272F739EC4D40ECF7C43A55363E40B2BCAB1E30F34D40C7A17E17B6463E40B2BCAB1E30F34D40C7A17E17B6463E40C59272F739EC4D40ECF7C43A55363E40C59272F739EC4D40
2308	2	30.483789999999999	30.500112999999999	59.933622	59.912734	проспект Солидарности	0103000020E61000000100000005000000C02154A9D97B3E4040F9BB77D4F44D40C02154A9D97B3E40BE69FAEC80F74D40F04DD36707803E40BE69FAEC80F74D40F04DD36707803E4040F9BB77D4F44D40C02154A9D97B3E4040F9BB77D4F44D40
5786	2	30.366398	30.417027000000001	59.866295999999998	59.854187000000003	проспект Славы	0103000020E61000000100000005000000DF516342CC5D3E408DD5E6FF55ED4D40DF516342CC5D3E40EB538EC9E2EE4D408B8C0E48C26A3E40EB538EC9E2EE4D408B8C0E48C26A3E408DD5E6FF55ED4D40DF516342CC5D3E408DD5E6FF55ED4D40
15316	2	30.271473	30.278858	60.017166000000003	60.003596999999999	проспект Сизова	0103000020E610000001000000050000003CBF28417F453E408EAED2DD75004E403CBF28417F453E40344DD87E32024E405C3AE63C63473E40344DD87E32024E405C3AE63C63473E408EAED2DD75004E403CBF28417F453E408EAED2DD75004E40
13285	2	30.280491999999999	30.312041000000001	59.924329999999998	59.918028999999997	проспект Римского-Корсакова	0103000020E6100000010000000500000025CADE52CE473E40C9E369F981F54D4025CADE52CE473E40185B087250F64D40DA0242EBE14F3E40185B087250F64D40DA0242EBE14F3E40C9E369F981F54D4025CADE52CE473E40C9E369F981F54D40
3780	2	30.360541000000001	30.368652999999998	60.015929999999997	60.012332000000001	проспект Раевского	0103000020E61000000100000005000000FDDD3B6A4C5C3E40DE58501894014E40FDDD3B6A4C5C3E403C8386FE09024E408192020B605E3E403C8386FE09024E408192020B605E3E40DE58501894014E40FDDD3B6A4C5C3E40DE58501894014E40
2508	2	30.447444000000001	30.470548999999998	59.925258999999997	59.919688999999998	проспект Пятилеток	0103000020E610000001000000050000009BCAA2B08B723E40D7BE805EB8F54D409BCAA2B08B723E4032AA0CE36EF64D405E2A36E675783E4032AA0CE36EF64D405E2A36E675783E40D7BE805EB8F54D409BCAA2B08B723E40D7BE805EB8F54D40
4457	2	30.306103	30.432299	60.058703999999999	60.032924000000001	проспект Просвещения	0103000020E610000001000000050000001E3526C45C4E3E4073A087DA36044E401E3526C45C4E3E407B12D89C83074E40F017B325AB6E3E407B12D89C83074E40F017B325AB6E3E4073A087DA36044E401E3526C45C4E3E4073A087DA36044E40
62908	19847	47.814816	47.839393999999999	55.399228999999998	55.383592	Лесная	0103000020E61000000100000005000000F72004E44BE84740ED80EB8A19B14B40F72004E44BE84740B14E95EF19B34B40B43A394371EB4740B14E95EF19B34B40B43A394371EB4740ED80EB8A19B14B40F72004E44BE84740ED80EB8A19B14B40
3572	2	30.329090999999998	30.357496000000001	60.000307999999997	59.997540999999998	проспект Пархоменко	0103000020E610000001000000050000006E68CA4E3F543E40A6B5696CAFFF4D406E68CA4E3F543E40ADF6B0170A004E4069739CDB845B3E40ADF6B0170A004E4069739CDB845B3E40A6B5696CAFFF4D406E68CA4E3F543E40A6B5696CAFFF4D40
2860	2	30.387436999999998	30.486072	59.924686000000001	59.839683000000001	проспект Обуховской Обороны	0103000020E61000000100000005000000A6423C122F633E40EB0088BB7AEB4D40A6423C122F633E40D788601C5CF64D405680EF366F7C3E40D788601C5CF64D405680EF366F7C3E40EB0088BB7AEB4D40A6423C122F633E40EB0088BB7AEB4D40
4844	2	30.365176999999999	30.433340999999999	59.998054000000003	59.991501999999997	проспект Непокорённых	0103000020E610000001000000050000005B40683D7C5D3E4094F59B89E9FE4D405B40683D7C5D3E402DD2C43BC0FF4D4014048F6FEF6E3E402DD2C43BC0FF4D4014048F6FEF6E3E4094F59B89E9FE4D405B40683D7C5D3E4094F59B89E9FE4D40
4870	2	30.367799999999999	30.436295999999999	60.017494999999997	60.003214	проспект Науки	0103000020E6100000010000000500000003780B24285E3E40D671FC5069004E4003780B24285E3E40F86BB2463D024E4028603B18B16F3E40F86BB2463D024E4028603B18B16F3E40D671FC5069004E4003780B24285E3E40D671FC5069004E40
7308	2	30.478023	30.490967999999999	59.958700999999998	59.933622	проспект Наставников	0103000020E610000001000000050000005EBC1FB75F7A3E40BE69FAEC80F74D405EBC1FB75F7A3E403DD2E0B6B6FA4D40ED612F14B07D3E403DD2E0B6B6FA4D40ED612F14B07D3E40BE69FAEC80F74D405EBC1FB75F7A3E40BE69FAEC80F74D40
74851	2	30.478023	30.490967999999999	59.958700999999998	59.933622	проспект Наставников	0103000020E610000001000000050000005EBC1FB75F7A3E40BE69FAEC80F74D405EBC1FB75F7A3E403DD2E0B6B6FA4D40ED612F14B07D3E403DD2E0B6B6FA4D40ED612F14B07D3E40BE69FAEC80F74D405EBC1FB75F7A3E40BE69FAEC80F74D40
90	2	30.140229000000001	30.287185000000001	59.861345	59.823357999999999	проспект Народного Ополчения	0103000020E6100000010000000500000067F3380CE6233E40327381CB63E94D4067F3380CE6233E405CC98E8D40EE4D40DAE6C6F484493E405CC98E8D40EE4D40DAE6C6F484493E40327381CB63E94D4067F3380CE6233E40327381CB63E94D40
5680	2	30.394435000000001	30.424510000000001	59.988090999999997	59.983184000000001	проспект Мечникова	0103000020E61000000100000005000000D46531B1F9643E40A9F92AF9D8FD4D40D46531B1F9643E40683C11C479FE4D4031D3F6AFAC6C3E40683C11C479FE4D4031D3F6AFAC6C3E40A9F92AF9D8FD4D40D46531B1F9643E40A9F92AF9D8FD4D40
7133	2	30.383735999999999	30.422498000000001	59.974986000000001	59.942692000000001	проспект Металлистов	0103000020E61000000100000005000000404CC2853C623E40B519A721AAF84D40404CC2853C623E4068075C57CCFC4D401BA034D4286C3E4068075C57CCFC4D401BA034D4286C3E40B519A721AAF84D40404CC2853C623E40B519A721AAF84D40
7806	2	30.188639999999999	30.254943999999998	59.872714999999999	59.827424000000001	проспект Маршала Жукова	0103000020E61000000100000005000000AAB706B64A303E4077F69507E9E94D40AAB706B64A303E4044DD0720B5EF4D40B94F8E0244413E4044DD0720B5EF4D40B94F8E0244413E4077F69507E9E94D40AAB706B64A303E4077F69507E9E94D40
6982	2	30.357523	30.436844000000001	59.986488000000001	59.973415000000003	проспект Маршала Блюхера	0103000020E610000001000000050000005C9198A0865B3E40CA37DBDC98FC4D405C9198A0865B3E40BFF2203D45FE4D402E742502D56F3E40BFF2203D45FE4D402E742502D56F3E40CA37DBDC98FC4D405C9198A0865B3E40CA37DBDC98FC4D40
7513	2	30.315283999999998	30.43158	60.044643999999998	60.021766	проспект Луначарского	0103000020E61000000100000005000000BAF3C473B6503E401615713AC9024E40BAF3C473B6503E4037FB03E5B6054E40919BE1067C6E3E4037FB03E5B6054E40919BE1067C6E3E401615713AC9024E40BAF3C473B6503E401615713AC9024E40
13250	2	30.081012999999999	30.092438999999999	59.832652000000003	59.825606000000001	проспект Ленина	0103000020E61000000100000005000000048D9944BD143E40D1B01875ADE94D40048D9944BD143E4079793A5794EA4D40FCDF1115AA173E4079793A5794EA4D40FCDF1115AA173E40D1B01875ADE94D40048D9944BD143E40D1B01875ADE94D40
5170	2	30.364629000000001	30.385954999999999	60.078428000000002	60.032052	проспект Культуры	0103000020E61000000100000005000000562C7E53585D3E40BDE2A9471A044E40562C7E53585D3E409C8BBFED090A4E4049BA66F2CD623E409C8BBFED090A4E4049BA66F2CD623E40BDE2A9471A044E40562C7E53585D3E40BDE2A9471A044E40
7619	2	30.184785999999999	30.188846000000002	59.859161999999998	59.846933999999997	проспект Кузнецова	0103000020E6100000010000000500000037C2A2224E2F3E406BEF535568EC4D4037C2A2224E2F3E40A4FB3905F9ED4D40FDFA213658303E40A4FB3905F9ED4D40FDFA213658303E406BEF535568EC4D4037C2A2224E2F3E406BEF535568EC4D40
13270	2	30.094657999999999	30.116468999999999	59.729627000000001	59.710515999999998	проспект Красных Командиров	0103000020E61000000100000005000000054EB6813B183E4072A43330F2DA4D40054EB6813B183E40A9A3E36A64DD4D4071FF91E9D01D3E40A9A3E36A64DD4D4071FF91E9D01D3E4072A43330F2DA4D40054EB6813B183E4072A43330F2DA4D40
7350	2	30.447768	30.502834	59.945337000000002	59.936945000000001	проспект Косыгина	0103000020E61000000100000005000000013274ECA0723E404B9352D0EDF74D40013274ECA0723E40715985CD00F94D401E51A1BAB9803E40715985CD00F94D401E51A1BAB9803E404B9352D0EDF74D40013274ECA0723E404B9352D0EDF74D40
1262	2	30.344138000000001	30.362572	59.871920000000003	59.828885	проспект Космонавтов	0103000020E61000000100000005000000944F8F6D19583E408E9257E718EA4D40944F8F6D19583E403A5D16139BEF4D400072C284D15C3E403A5D16139BEF4D400072C284D15C3E408E9257E718EA4D40944F8F6D19583E408E9257E718EA4D40
4513	2	30.249922999999999	30.2958	60.024670999999998	60.009264000000002	проспект Королёва	0103000020E61000000100000005000000A98427F4FA3F3E40DC8310902F014E40A98427F4FA3F3E406E14596B28034E4024287E8CB94B3E406E14596B28034E4024287E8CB94B3E40DC8310902F014E40A98427F4FA3F3E40DC8310902F014E40
16861	2	30.249922999999999	30.2958	60.024670999999998	60.009264000000002	проспект Королёва	0103000020E61000000100000005000000A98427F4FA3F3E40DC8310902F014E40A98427F4FA3F3E406E14596B28034E4024287E8CB94B3E406E14596B28034E4024287E8CB94B3E40DC8310902F014E40A98427F4FA3F3E40DC8310902F014E40
3476	2	30.242063000000002	30.255115	59.955674000000002	59.947513999999998	проспект КИМа	0103000020E6100000010000000500000058923CD7F73D3E404640852348F94D4058923CD7F73D3E409AD18F8653FA4D4013B875374F413E409AD18F8653FA4D4013B875374F413E404640852348F94D4058923CD7F73D3E404640852348F94D40
2582	2	30.405025999999999	30.430537999999999	59.898584	59.892839000000002	проспект Елизарова	0103000020E610000001000000050000009A07B0C8AF673E40F3CB608C48F24D409A07B0C8AF673E40BC5AEECC04F34D406CAF05BD376E3E40BC5AEECC04F34D406CAF05BD376E3E40F3CB608C48F24D409A07B0C8AF673E40F3CB608C48F24D40
3449	2	30.270225	30.283177999999999	59.974314999999997	59.968190999999997	проспект Динамо	0103000020E61000000100000005000000C58F31772D453E4009A4C4AEEDFB4D40C58F31772D453E4049809A5AB6FC4D405AF2785A7E483E4049809A5AB6FC4D405AF2785A7E483E4009A4C4AEEDFB4D40C58F31772D453E4009A4C4AEEDFB4D40
6158	2	30.126619999999999	30.256274000000001	59.847611999999998	59.832928000000003	проспект Ветеранов	0103000020E61000000100000005000000FF04172B6A203E401BF67B629DEA4D40FF04172B6A203E403CD9CD8C7EEC4D40ABD0402C9B413E403CD9CD8C7EEC4D40ABD0402C9B413E401BF67B629DEA4D40FF04172B6A203E401BF67B629DEA4D40
2021	2	30.470548999999998	30.49174	59.919688999999998	59.870420000000003	проспект Большевиков	0103000020E610000001000000050000005E2A36E675783E4065E42CEC69EF4D405E2A36E675783E40D7BE805EB8F54D40922232ACE27D3E40D7BE805EB8F54D40922232ACE27D3E4065E42CEC69EF4D405E2A36E675783E4065E42CEC69EF4D40
2840	2	30.426379000000001	30.454595000000001	59.865962000000003	59.851905000000002	проспект Александровской Фермы	0103000020E6100000010000000500000081B3942C276D3E40422619390BED4D4081B3942C276D3E4015CAC2D7D7EE4D40D5EC815660743E4015CAC2D7D7EE4D40D5EC815660743E40422619390BED4D4081B3942C276D3E40422619390BED4D40
4555	2	30.217323	30.248484999999999	60.029561999999999	60.008302	проспект Авиаконструкторов	0103000020E610000001000000050000002AABE97AA2373E40E63E390A10014E402AABE97AA2373E40289A07B0C8034E40EB8B84B69C3F3E40289A07B0C8034E40EB8B84B69C3F3E40E63E390A10014E402AABE97AA2373E40E63E390A10014E40
16558	2	30.170169999999999	30.190149000000002	60.044096000000003	60.039993000000003	поселок Большая Каменка	0103000020E61000000100000005000000A4C2D842902B3E40D388997D1E054E40A4C2D842902B3E4035F10EF0A4054E40FB5DD89AAD303E4035F10EF0A4054E40FB5DD89AAD303E40D388997D1E054E40A4C2D842902B3E40D388997D1E054E40
13274	2	29.971256	29.975092	60.095035000000003	60.093527999999999	площадь Свободы	0103000020E61000000100000005000000350BB43BA4F83D4051A1BAB9F80B4E40350BB43BA4F83D40D97C5C1B2A0C4E405B971AA19FF93D40D97C5C1B2A0C4E405B971AA19FF93D4051A1BAB9F80B4E40350BB43BA4F83D4051A1BAB9F80B4E40
13284	2	29.777695999999999	29.779959999999999	59.995908	59.993073000000003	площадь Рошаля	0103000020E61000000100000005000000E23AC61517C73D4033C51C041DFF4D40E23AC61517C73D4092E9D0E979FF4D402B306475ABC73D4092E9D0E979FF4D402B306475ABC73D4033C51C041DFF4D40E23AC61517C73D4033C51C041DFF4D40
13300	2	30.329549	30.333942	59.938000000000002	59.936326999999999	площадь Искусств	0103000020E61000000100000005000000F46DC1525D543E404FAE2990D9F74D40F46DC1525D543E40F2D24D6210F84D40C6C210397D553E40F2D24D6210F84D40C6C210397D553E404FAE2990D9F74D40F46DC1525D543E404FAE2990D9F74D40
13287	2	30.082360000000001	30.088891	59.727035999999998	59.726405999999997	переулок Щуппа	0103000020E61000000100000005000000A27F828B15153E4020CF2EDFFADC4D40A27F828B15153E40E08101840FDD4D40A3E8818FC1163E40E08101840FDD4D40A3E8818FC1163E4020CF2EDFFADC4D40A27F828B15153E4020CF2EDFFADC4D40
3489	2	30.234238000000001	30.24624	59.952159000000002	59.951515000000001	переулок Каховского	0103000020E61000000100000005000000FF7A8505F73B3E40A453573ECBF94D40FF7A8505F73B3E40C9CB9A58E0F94D4090F7AA95093F3E40C9CB9A58E0F94D4090F7AA95093F3E40A453573ECBF94D40FF7A8505F73B3E40A453573ECBF94D40
13381	2	30.332118999999999	30.337778	59.926616000000003	59.924208	переулок Джамбула	0103000020E61000000100000005000000566133C005553E40CD599F724CF64D40566133C005553E40A5F9635A9BF64D40EC4E779E78563E40A5F9635A9BF64D40EC4E779E78563E40CD599F724CF64D40566133C005553E40CD599F724CF64D40
2159	2	30.309526000000002	30.310863999999999	59.923144000000001	59.920312000000003	переулок Бойцова	0103000020E61000000100000005000000FF428F183D4F3E40E50E9BC8CCF54D40FF428F183D4F3E40D3BF249529F64D40F58079C8944F3E40D3BF249529F64D40F58079C8944F3E40E50E9BC8CCF54D40FF428F183D4F3E40E50E9BC8CCF54D40
2192	2	30.268805	30.344929	59.947873999999999	59.915056999999997	набережная реки Фонтанки	0103000020E6100000010000000500000054008C67D0443E40E97C789620F54D4054008C67D0443E40465D6BEF53F94D40267156444D583E40465D6BEF53F94D40267156444D583E40E97C789620F54D4054008C67D0443E40E97C789620F54D40
2119	2	30.274878000000001	30.281831	59.927048999999997	59.919446000000001	набережная реки Пряжки	0103000020E61000000100000005000000D06394675E463E4011381268B0F54D40D06394675E463E400E65A88AA9F64D40BDFF8F1326483E400E65A88AA9F64D40BDFF8F1326483E4011381268B0F54D40D06394675E463E4011381268B0F54D40
2490	2	30.453130999999999	30.471025000000001	59.927121	59.921411999999997	набережная реки Оккервиль	0103000020E61000000100000005000000C4CDA96400743E402B1213D4F0F54D40C4CDA96400743E40A837A3E6ABF64D4031992A1895783E40A837A3E6ABF64D4031992A1895783E402B1213D4F0F54D40C4CDA96400743E402B1213D4F0F54D40
13299	2	30.276530999999999	30.337624999999999	59.942421000000003	59.926490000000001	набережная реки Мойки	0103000020E61000000100000005000000865451BCCA463E4018096D3997F64D40865451BCCA463E4025085740A1F84D40DF4F8D976E563E4025085740A1F84D40DF4F8D976E563E4018096D3997F64D40865451BCCA463E4018096D3997F64D40
3245	2	30.288765999999999	30.332595000000001	59.970320999999998	59.967163999999997	набережная реки Карповки	0103000020E610000001000000050000005D328E91EC493E402CEFAA07CCFB4D405D328E91EC493E409ECF807A33FC4D4029D027F224553E409ECF807A33FC4D4029D027F224553E402CEFAA07CCFB4D405D328E91EC493E402CEFAA07CCFB4D40
6432	2	30.280888000000001	30.329737999999999	59.941510999999998	59.916609000000001	набережная канала Грибоедова	0103000020E61000000100000005000000BFD6A546E8473E40111C977153F54D40BFD6A546E8473E4081E9B46E83F84D409A3FA6B569543E4081E9B46E83F84D409A3FA6B569543E40111C977153F54D40BFD6A546E8473E40111C977153F54D40
2939	2	30.268446000000001	30.285648999999999	59.936056999999998	59.928522999999998	набережная Лейтенанта Шмидта	0103000020E61000000100000005000000F5BD86E0B8443E40BA4A77D7D9F64D40F5BD86E0B8443E408F183DB7D0F74D409622F94A20493E408F183DB7D0F74D409622F94A20493E40BA4A77D7D9F64D40F5BD86E0B8443E40BA4A77D7D9F64D40
2083	2	30.292683	30.301468	59.930593000000002	59.918011	набережная Крюкова канала	0103000020E610000001000000050000005D18E945ED4A3E40232F6B6281F54D405D18E945ED4A3E407A71E2AB1DF74D4060CAC0012D4D3E407A71E2AB1DF74D4060CAC0012D4D3E40232F6B6281F54D405D18E945ED4A3E40232F6B6281F54D40
15321	2	30.56878	30.591992000000001	59.741813	59.734442999999999	бульвар Трудящихся	0103000020E610000001000000050000006F9EEA909B913E4058E36C3A02DE4D406F9EEA909B913E40B35F77BAF3DE4D405F7EA7C98C973E40B35F77BAF3DE4D405F7EA7C98C973E4058E36C3A02DE4D406F9EEA909B913E4058E36C3A02DE4D40
6135	2	30.245943	30.271312000000002	59.854191999999998	59.841169999999998	бульвар Новаторов	0103000020E610000001000000050000001DAED51EF63E3E402B306475ABEB4D401DAED51EF63E3E409E40D82956ED4D402A0307B474453E409E40D82956ED4D402A0307B474453E402B306475ABEB4D401DAED51EF63E3E402B306475ABEB4D40
2804	2	30.433592000000001	30.449753000000001	59.873555000000003	59.868459999999999	бульвар Красных Зорь	0103000020E61000000100000005000000A7CEA3E2FF6E3E402CF180B229EF4D40A7CEA3E2FF6E3E40EF2076A6D0EF4D4024473A0323733E40EF2076A6D0EF4D4024473A0323733E402CF180B229EF4D40A7CEA3E2FF6E3E402CF180B229EF4D40
15370	2	30.406499	30.422021999999998	59.734724999999997	59.72974	бульвар Алексея Толстого	0103000020E6100000010000000500000051DB865110683E40A14ACD1E68DD4D4051DB865110683E40DC4603780BDE4D40483140A2096C3E40DC4603780BDE4D40483140A2096C3E40A14ACD1E68DD4D4051DB865110683E40A14ACD1E68DD4D40
3726	2	30.282945000000002	30.296320999999999	60.008347000000001	60.006183	аллея Поликарпова	0103000020E61000000100000005000000159161156F483E404565C39ACA004E40159161156F483E408602B68311014E40361E6CB1DB4B3E408602B68311014E40361E6CB1DB4B3E404565C39ACA004E40159161156F483E404565C39ACA004E40
4093	2	30.213145999999998	30.226413999999998	60.008584999999997	59.982877999999999	Яхтенная улица	0103000020E61000000100000005000000F1457BBC90363E409CFA40F2CEFD4D40F1457BBC90363E403A1E335019014E40465B9544F6393E403A1E335019014E40465B9544F6393E409CFA40F2CEFD4D40F1457BBC90363E409CFA40F2CEFD4D40
4030	2	30.31514	30.323162	60.027957000000001	60.008369000000002	Ярославский проспект	0103000020E6100000010000000500000054A9D903AD503E406EA6423C12014E4054A9D903AD503E40DE58501894034E40594FADBEBA523E40DE58501894034E40594FADBEBA523E406EA6423C12014E4054A9D903AD503E406EA6423C12014E40
15304	2	30.379926999999999	30.423566999999998	59.841133999999997	59.829825	Ярослава Гашека	0103000020E610000001000000050000000DDE57E542613E409C33A2B437EA4D400DDE57E542613E40DEC66647AAEB4D4032AA0CE36E6C3E40DEC66647AAEB4D4032AA0CE36E6C3E409C33A2B437EA4D400DDE57E542613E409C33A2B437EA4D40
16588	2	29.899795000000001	29.918921000000001	59.873803000000002	59.869874000000003	Эрлеровский бульвар	0103000020E61000000100000005000000B51A12F758E63D4003D2FE0758EF4D40B51A12F758E63D40C712D6C6D8EF4D408D9B1A683EEB3D40C712D6C6D8EF4D408D9B1A683EEB3D4003D2FE0758EF4D40B51A12F758E63D4003D2FE0758EF4D40
6631	2	30.341819999999998	30.390526999999999	59.94905	59.947937000000003	Шпалерная улица	0103000020E61000000100000005000000641EF98381573E408DD5E6FF55F94D40641EF98381573E4068226C787AF94D407A34D593F9633E4068226C787AF94D407A34D593F9633E408DD5E6FF55F94D40641EF98381573E408DD5E6FF55F94D40
56765	2	30.559823999999999	30.623208999999999	59.822212999999998	59.793007000000003	Шлиссельбургское	0103000020E6100000010000000500000012842BA0508F3E40E23FDD4081E54D4012842BA0508F3E404BAC8C463EE94D40A79201A08A9F3E404BAC8C463EE94D40A79201A08A9F3E40E23FDD4081E54D4012842BA0508F3E40E23FDD4081E54D40
2897	2	30.484832000000001	30.527224	59.842843000000002	59.831318000000003	Шлиссельбургский проспект	0103000020E61000000100000005000000E50D30F31D7C3E40BF49D3A068EA4D40E50D30F31D7C3E40CE548847E2EB4D4093AAED26F8863E40CE548847E2EB4D4093AAED26F8863E40BF49D3A068EA4D40E50D30F31D7C3E40BF49D3A068EA4D40
16672	2	30.243455000000001	30.253443999999998	60.111575999999999	60.109777999999999	Школьный переулок (Осиновая Роща)	0103000020E61000000100000005000000350C1F11533E3E40FFE89B340D0E4E40350C1F11533E3E405E82531F480E4E400F5EBBB4E1403E405E82531F480E4E400F5EBBB4E1403E40FFE89B340D0E4E40350C1F11533E3E40FFE89B340D0E4E40
15288	2	30.243455000000001	30.253443999999998	60.111575999999999	60.109777999999999	Школьный переулок	0103000020E61000000100000005000000350C1F11533E3E40FFE89B340D0E4E40350C1F11533E3E405E82531F480E4E400F5EBBB4E1403E405E82531F480E4E400F5EBBB4E1403E40FFE89B340D0E4E40350C1F11533E3E40FFE89B340D0E4E40
13377	2	30.19023	30.300865999999999	59.992753	59.986789999999999	Школьная	0103000020E61000000100000005000000D4B7CCE9B2303E408A027D224FFE4D40D4B7CCE9B2303E40C100C28712FF4D40747ADE8D054D3E40C100C28712FF4D40747ADE8D054D3E408A027D224FFE4D40D4B7CCE9B2303E408A027D224FFE4D40
78837	2	30.19023	30.300865999999999	59.992753	59.986789999999999	Школьная	0103000020E61000000100000005000000D4B7CCE9B2303E408A027D224FFE4D40D4B7CCE9B2303E40C100C28712FF4D40747ADE8D054D3E40C100C28712FF4D40747ADE8D054D3E408A027D224FFE4D40D4B7CCE9B2303E408A027D224FFE4D40
7083	2	30.414242999999999	30.420746000000001	59.946955000000003	59.946351	Шепетовская улица	0103000020E61000000100000005000000D09849D40B6A3E40B9C4910722F94D40D09849D40B6A3E4050E449D235F94D403EEC8502B66B3E4050E449D235F94D403EEC8502B66B3E40B9C4910722F94D40D09849D40B6A3E40B9C4910722F94D40
13256	2	30.238523000000001	30.247156	59.941406999999998	59.928514	Шевченко	0103000020E610000001000000050000000458E4D70F3D3E4067F0F78BD9F64D400458E4D70F3D3E40DC9C4A0680F84D409B02999D453F3E40DC9C4A0680F84D409B02999D453F3E4067F0F78BD9F64D400458E4D70F3D3E4067F0F78BD9F64D40
7795	2	30.298808999999999	30.304279999999999	59.961210000000001	59.959052	Шамшева улица	0103000020E610000001000000050000001EC022BF7E4C3E40EA944737C2FA4D401EC022BF7E4C3E40494BE5ED08FB4D40AED3484BE54D3E40494BE5ED08FB4D40AED3484BE54D3E40EA944737C2FA4D401EC022BF7E4C3E40EA944737C2FA4D40
3291	2	30.286384999999999	30.304027999999999	59.969082999999998	59.957444000000002	Чкаловский проспект	0103000020E61000000100000005000000A110018750493E402FE065868DFA4D40A110018750493E40060E68E90AFC4D407B116DC7D44D3E40060E68E90AFC4D407B116DC7D44D3E402FE065868DFA4D40A110018750493E402FE065868DFA4D40
16556	2	30.292251	30.299697999999999	60.041471999999999	60.039180000000002	Чистяковская	0103000020E610000001000000050000002A3927F6D04A3E402254A9D903054E402A3927F6D04A3E4090D959F44E054E4036AD1402B94C3E4090D959F44E054E4036AD1402B94C3E402254A9D903054E402A3927F6D04A3E402254A9D903054E40
2560	2	30.397317999999999	30.405754000000002	59.914411999999999	59.905343999999999	Хрустальная улица	0103000020E61000000100000005000000B41CE8A1B6653E409ED0EB4FE2F34D40B41CE8A1B6653E40F488D1730BF54D40A038807EDF673E40F488D1730BF54D40A038807EDF673E409ED0EB4FE2F34D40B41CE8A1B6653E409ED0EB4FE2F34D40
16675	2	30.376207999999998	30.390177000000001	59.929974999999999	59.925949000000003	Херсонская 	0103000020E610000001000000050000005A7EE02A4F603E40C861307F85F64D405A7EE02A4F603E407E8CB96B09F74D40C2A6CEA3E2633E407E8CB96B09F74D40C2A6CEA3E2633E40C861307F85F64D405A7EE02A4F603E40C861307F85F64D40
7295	2	30.475785999999999	30.503239000000001	59.936971999999997	59.934933999999998	Хасанская улица	0103000020E6100000010000000500000008E57D1CCD793E4090F5D4EAABF74D4008E57D1CCD793E4044A2D0B2EEF74D405E126745D4803E4044A2D0B2EEF74D405E126745D4803E4090F5D4EAABF74D4008E57D1CCD793E4090F5D4EAABF74D40
67085	2	30.475785999999999	30.503239000000001	59.936971999999997	59.934933999999998	Хасанская 	0103000020E6100000010000000500000008E57D1CCD793E4090F5D4EAABF74D4008E57D1CCD793E4044A2D0B2EEF74D405E126745D4803E4044A2D0B2EEF74D405E126745D4803E4090F5D4EAABF74D4008E57D1CCD793E4090F5D4EAABF74D40
15325	2	30.475785999999999	30.503239000000001	59.936971999999997	59.934933999999998	Хасанская	0103000020E6100000010000000500000008E57D1CCD793E4090F5D4EAABF74D4008E57D1CCD793E4044A2D0B2EEF74D405E126745D4803E4044A2D0B2EEF74D405E126745D4803E4090F5D4EAABF74D4008E57D1CCD793E4090F5D4EAABF74D40
6830	2	30.370107999999998	30.373073000000002	59.927906	59.925826999999998	Харьковская улица	0103000020E61000000100000005000000EBFCDB65BF5E3E407C60C77F81F64D40EBFCDB65BF5E3E408FE1B19FC5F64D4047054EB6815F3E408FE1B19FC5F64D4047054EB6815F3E407C60C77F81F64D40EBFCDB65BF5E3E407C60C77F81F64D40
15919	2	29.847172	29.864348	59.884473999999997	59.880085000000001	Халтурина	0103000020E610000001000000050000004016A243E0D83D409F5912A0A6F04D404016A243E0D83D40C614AC7136F14D40EE5C18E945DD3D40C614AC7136F14D40EE5C18E945DD3D409F5912A0A6F04D404016A243E0D83D409F5912A0A6F04D40
6620	2	30.348755000000001	30.367539000000001	59.945219999999999	59.944972	Фурштатская улица	0103000020E610000001000000050000000551F70148593E405FD1ADD7F4F84D400551F70148593E4037C30DF8FCF84D402A013109175E3E4037C30DF8FCF84D402A013109175E3E405FD1ADD7F4F84D400551F70148593E405FD1ADD7F4F84D40
13297	2	30.314287	30.337095000000001	59.861842000000003	59.861530000000002	Фрунзе	0103000020E61000000100000005000000D68EE21C75503E40EE42739D46EE4D40D68EE21C75503E40DD28B2D650EE4D4027A5A0DB4B563E40DD28B2D650EE4D4027A5A0DB4B563E40EE42739D46EE4D40D68EE21C75503E40EE42739D46EE4D40
2346	2	30.304189999999998	30.305852000000002	59.930349	59.926845999999998	Фонарный переулок	0103000020E610000001000000050000002EC55565DF4D3E40D636C5E3A2F64D402EC55565DF4D3E40E36E10AD15F74D408C6A11514C4E3E40E36E10AD15F74D408C6A11514C4E3E40D636C5E3A2F64D402EC55565DF4D3E40D636C5E3A2F64D40
5545	2	30.352124	30.355771000000001	59.956921999999999	59.956339999999997	Финский переулок	0103000020E61000000100000005000000FF2268CC245A3E40A6ED5F5969FA4D40FF2268CC245A3E4055698B6B7CFA4D407FDDE9CE135B3E4055698B6B7CFA4D407FDDE9CE135B3E40A6ED5F5969FA4D40FF2268CC245A3E40A6ED5F5969FA4D40
16667	2	29.769629999999999	29.793928999999999	59.901712000000003	59.884225000000001	Федюнинского	0103000020E610000001000000050000003E05C07806C53D401EA7E8482EF14D403E05C07806C53D4094347F4C6BF34D40925852EE3ECB3D4094347F4C6BF34D40925852EE3ECB3D401EA7E8482EF14D403E05C07806C53D401EA7E8482EF14D40
15324	2	30.391659000000001	30.398028	59.976939999999999	59.970253999999997	Федосеенко	0103000020E610000001000000050000001F2FA4C343643E401668774831FC4D401F2FA4C343643E40BE13B35E0CFD4D406DE4BA29E5653E40BE13B35E0CFD4D406DE4BA29E5653E401668774831FC4D401F2FA4C343643E401668774831FC4D40
13253	2	30.403570999999999	30.417853999999998	60.045003000000001	60.027521	Ушинского	0103000020E61000000100000005000000309DD66D50673E40037AE1CE85034E40309DD66D50673E40679C86A8C2054E40B680D07AF86A3E40679C86A8C2054E40B680D07AF86A3E40037AE1CE85034E40309DD66D50673E40037AE1CE85034E40
5220	2	30.381786000000002	30.406732999999999	60.036451999999997	60.031373000000002	Учительская улица	0103000020E61000000100000005000000171230BABC613E401C7DCC0704044E40171230BABC613E40D8EF8975AA044E40373465A71F683E40D8EF8975AA044E40373465A71F683E401C7DCC0704044E40171230BABC613E401C7DCC0704044E40
4155	2	30.332118999999999	30.344417	60.039234	60.036740000000002	Учебный переулок	0103000020E61000000100000005000000566133C005553E403F3A75E5B3044E40566133C005553E401572A59E05054E40BA2F67B62B583E401572A59E05054E40BA2F67B62B583E403F3A75E5B3044E40566133C005553E403F3A75E5B3044E40
15290	2	30.322938000000001	30.328130000000002	59.954214	59.95129	Троицкая площадь	0103000020E61000000100000005000000BAA29410AC523E408481E7DEC3F94D40BAA29410AC523E4053B131AF23FA4D4024D6E25300543E4053B131AF23FA4D4024D6E25300543E408481E7DEC3F94D40BAA29410AC523E408481E7DEC3F94D40
6112	2	30.253623999999999	30.288487	59.858702000000001	59.854092000000001	Трамвайный проспект	0103000020E610000001000000050000000F7BA180ED403E403BE3FBE252ED4D400F7BA180ED403E40418177F2E9ED4D403752B648DA493E40418177F2E9ED4D403752B648DA493E403BE3FBE252ED4D400F7BA180ED403E403BE3FBE252ED4D40
16587	2	30.254998000000001	30.256184000000001	60.001154	59.988166999999997	Торфяная	0103000020E61000000100000005000000A08B868C47413E4043FE99417CFE4D40A08B868C47413E403A2174D025004E402BC24D4695413E403A2174D025004E402BC24D4695413E4043FE99417CFE4D40A08B868C47413E4043FE99417CFE4D40
16087	2	30.303013	30.322649999999999	59.992614000000003	59.986429999999999	Торжковская	0103000020E610000001000000050000004A438D42924D3E408AE5965643FE4D404A438D42924D3E40A0C6BDF90DFF4D40ED0DBE3099523E40A0C6BDF90DFF4D40ED0DBE3099523E408AE5965643FE4D404A438D42924D3E408AE5965643FE4D40
6453	2	30.328506999999998	30.334067999999998	59.928753	59.927106999999999	Торговый переулок	0103000020E61000000100000005000000CF81E50819543E4043723271ABF64D40CF81E50819543E40EC87D860E1F64D40DFA3FE7A85553E40EC87D860E1F64D40DFA3FE7A85553E4043723271ABF64D40CF81E50819543E4043723271ABF64D40
16668	2	29.953631000000001	29.955904	60.092581000000003	60.085518999999998	Токарева	0103000020E61000000100000005000000A873452921F43D40E3175E49F20A4E40A873452921F43D40919DB7B1D90B4E40971DE21FB6F43D40919DB7B1D90B4E40971DE21FB6F43D40E3175E49F20A4E40A873452921F43D40E3175E49F20A4E40
2344	2	30.472318999999999	30.491137999999999	59.925654999999999	59.908597	Товарищеский проспект	0103000020E610000001000000050000008847E2E5E9783E40321F10E84CF44D408847E2E5E9783E407F30F0DC7BF64D40A6D24F38BB7D3E407F30F0DC7BF64D40A6D24F38BB7D3E40321F10E84CF44D408847E2E5E9783E40321F10E84CF44D40
3674	2	30.340229999999998	30.347534	59.972856999999998	59.972163000000002	Тобольская улица	0103000020E610000001000000050000003A1E335019573E40CDB051D66FFC4D403A1E335019573E40A357039486FC4D40813FFCFCF7583E40A357039486FC4D40813FFCFCF7583E40CDB051D66FFC4D403A1E335019573E40CDB051D66FFC4D40
5264	2	30.390149999999998	30.415095999999998	60.046706	60.041629	Тимуровская улица	0103000020E61000000100000005000000CE88D2DEE0633E4058C85C1954054E40CE88D2DEE0633E4074435376FA054E404EB340BB436A3E4074435376FA054E404EB340BB436A3E4058C85C1954054E40CE88D2DEE0633E4058C85C1954054E40
67079	2	30.390149999999998	30.415095999999998	60.046706	60.041629	Тимуровская	0103000020E61000000100000005000000CE88D2DEE0633E4058C85C1954054E40CE88D2DEE0633E4074435376FA054E404EB340BB436A3E4074435376FA054E404EB340BB436A3E4058C85C1954054E40CE88D2DEE0633E4058C85C1954054E40
13288	2	30.275390000000002	30.281749999999999	59.979334999999999	59.976832000000002	Театральная аллея	0103000020E610000001000000050000003CA583F57F463E40D8D7BAD408FD4D403CA583F57F463E40016A6AD95AFD4D40E3A59BC420483E40016A6AD95AFD4D40E3A59BC420483E40D8D7BAD408FD4D403CA583F57F463E40D8D7BAD408FD4D40
13357	2	30.378193	30.390428	59.946820000000002	59.946711999999998	Тверская улица	0103000020E610000001000000050000007D93A641D1603E40895DDBDB2DF94D407D93A641D1603E407099D36531F94D405471E316F3633E407099D36531F94D405471E316F3633E40895DDBDB2DF94D407D93A641D1603E40895DDBDB2DF94D40
13373	2	30.378193	30.390428	59.946820000000002	59.946711999999998	Тверская	0103000020E610000001000000050000007D93A641D1603E40895DDBDB2DF94D407D93A641D1603E407099D36531F94D405471E316F3633E407099D36531F94D405471E316F3633E40895DDBDB2DF94D407D93A641D1603E40895DDBDB2DF94D40
7179	2	30.407001999999999	30.421465000000001	59.926448999999998	59.921740999999997	Таллинская улица	0103000020E610000001000000050000001668774831683E40F030ED9BFBF54D401668774831683E40B9347EE195F64D409D685721E56B3E40B9347EE195F64D409D685721E56B3E40F030ED9BFBF54D401668774831683E40F030ED9BFBF54D40
3105	2	30.305662999999999	30.312795999999999	59.958224000000001	59.957124	Сытнинская улица	0103000020E61000000100000005000000E5982CEE3F4E3E40BD1B0B0A83FA4D40E5982CEE3F4E3E40041F8315A7FA4D40D2510E6613503E40041F8315A7FA4D40D2510E6613503E40BD1B0B0A83FA4D40E5982CEE3F4E3E40BD1B0B0A83FA4D40
3042	2	30.293904000000001	30.306885000000001	59.954489000000002	59.953907999999998	Съезжинская улица	0103000020E61000000100000005000000E129E44A3D4B3E4046B247A819FA4D40E129E44A3D4B3E4025B20FB22CFA4D400AA2EE03904E3E4025B20FB22CFA4D400AA2EE03904E3E4046B247A819FA4D40E129E44A3D4B3E4046B247A819FA4D40
5295	2	30.299420000000001	30.431733000000001	60.067501	60.042001999999997	Суздальский проспект	0103000020E61000000100000005000000B1C403CAA64C3E40EC2E505260054E40B1C403CAA64C3E4041B96DDFA3084E409E9ACB0D866E3E4041B96DDFA3084E409E9ACB0D866E3E40EC2E505260054E40B1C403CAA64C3E40EC2E505260054E40
13303	2	30.405080000000002	30.411681999999999	59.930430000000001	59.923296999999998	Стахановцев	0103000020E610000001000000050000008143A852B3673E4059BF99982EF64D408143A852B3673E40D09B8A5418F74D40145AD6FD63693E40D09B8A5418F74D40145AD6FD63693E4059BF99982EF64D408143A852B3673E4059BF99982EF64D40
2775	2	30.274104999999999	30.279198999999998	59.916027	59.901232999999998	Старо-Петергофский проспект	0103000020E610000001000000050000008AABCABE2B463E40B9895A9A5BF34D408AABCABE2B463E4062A06B5F40F54D406E13EE9579473E4062A06B5F40F54D406E13EE9579473E40B9895A9A5BF34D408AABCABE2B463E40B9895A9A5BF34D40
15315	2	30.079592999999999	30.086114999999999	59.747435000000003	59.739826000000001	Спирина	0103000020E6100000010000000500000093FDF33460143E40815D4D9EB2DE4D4093FDF33460143E40617138F3ABDF4D40EEB1F4A10B163E40617138F3ABDF4D40EEB1F4A10B163E40815D4D9EB2DE4D4093FDF33460143E40815D4D9EB2DE4D40
16031	2	30.337347000000001	30.347200999999998	59.925358000000003	59.919891999999997	Социалистическая	0103000020E610000001000000050000005A677C5F5C563E400FED6305BFF54D405A677C5F5C563E40C68B852172F64D4074232C2AE2583E40C68B852172F64D4074232C2AE2583E400FED6305BFF54D405A677C5F5C563E400FED6305BFF54D40
16649	2	30.408519999999999	30.417359999999999	60.019086000000001	60.010272000000001	Софьи Ковалевской	0103000020E610000001000000050000000DC347C494683E404208C89750014E400DC347C494683E40DEE7F86871024E4097A8DE1AD86A3E40DEE7F86871024E4097A8DE1AD86A3E404208C89750014E400DC347C494683E404208C89750014E40
13247	2	30.410874	30.428238	59.722563000000001	59.711835999999998	Софийский бульвар	0103000020E61000000100000005000000D6C6D8092F693E40C70E2A711DDB4D40D6C6D8092F693E405B26C3F17CDC4D408AE76C01A16D3E405B26C3F17CDC4D408AE76C01A16D3E40C70E2A711DDB4D40D6C6D8092F693E40C70E2A711DDB4D40
13279	2	30.380493000000001	30.530925	59.889169000000003	59.748739999999998	Софийская	0103000020E61000000100000005000000605B3FFD67613E40809A5AB6D6DF4D40605B3FFD67613E40FBCE2F4AD0F14D40F9A067B3EA873E40FBCE2F4AD0F14D40F9A067B3EA873E40809A5AB6D6DF4D40605B3FFD67613E40809A5AB6D6DF4D40
16830	2	30.309830999999999	30.310002000000001	59.915928000000001	59.911520000000003	Советский переулок	0103000020E6100000010000000500000077499C15514F3E4031D3F6AFACF44D4077499C15514F3E40CFBEF2203DF54D40D1B1834A5C4F3E40CFBEF2203DF54D40D1B1834A5C4F3E4031D3F6AFACF44D4077499C15514F3E4031D3F6AFACF44D40
16630	2	30.593879000000001	30.596601	59.750998000000003	59.746782000000003	Советский бульвар	0103000020E61000000100000005000000FCC7427408983E40E99E758D96DF4D40FCC7427408983E4043AED4B320E04D40CAC2D7D7BA983E4043AED4B320E04D40CAC2D7D7BA983E40E99E758D96DF4D40FCC7427408983E40E99E758D96DF4D40
15300	2	29.770788	29.776897000000002	59.903849999999998	59.902804000000003	Скуридина	0103000020E610000001000000050000003526C45C52C53D405859DB148FF34D403526C45C52C53D40AB3E575BB1F34D404B5CC7B8E2C63D40AB3E575BB1F34D404B5CC7B8E2C63D405859DB148FF34D403526C45C52C53D405859DB148FF34D40
4055	2	30.223466999999999	30.25525	60.001139999999999	59.996965000000003	Ситцевая улица	0103000020E6100000010000000500000038BC202235393E40DA20938C9CFF4D4038BC202235393E40D55B035B25004E40D34D621058413E40D55B035B25004E40D34D621058413E40DA20938C9CFF4D4038BC202235393E40DA20938C9CFF4D40
4377	2	30.345216000000001	30.369686000000002	60.055340000000001	60.050362999999997	Сиреневый бульвар	0103000020E61000000100000005000000520E661360583E40D7F6764B72064E40520E661360583E409014916115074E4000CADFBDA35E3E409014916115074E4000CADFBDA35E3E40D7F6764B72064E40520E661360583E40D7F6764B72064E40
7061	2	30.410837999999998	30.417646999999999	59.957687	59.957552	Синявинская улица	0103000020E610000001000000050000003CF4DDAD2C693E40151C5E1091FA4D403CF4DDAD2C693E40F566D47C95FA4D40C345EEE9EA6A3E40F566D47C95FA4D40C345EEE9EA6A3E40151C5E1091FA4D403CF4DDAD2C693E40151C5E1091FA4D40
74860	2	30.320772999999999	30.327349000000002	59.917622999999999	59.911394000000001	Серпуховская	0103000020E610000001000000050000009770E82D1E523E40A4E2FF8EA8F44D409770E82D1E523E405987A3AB74F54D40D960E124CD533E405987A3AB74F54D40D960E124CD533E40A4E2FF8EA8F44D409770E82D1E523E40A4E2FF8EA8F44D40
4636	2	30.28087	30.287023000000001	60.015822	59.994396000000002	Серебристый бульвар	0103000020E61000000100000005000000726DA818E7473E40F9A23D5E48FF4D40726DA818E7473E4056478E7406024E402733DE567A493E4056478E7406024E402733DE567A493E40F9A23D5E48FF4D40726DA818E7473E40F9A23D5E48FF4D40
3947	2	30.328633	30.405456999999998	60.047654000000001	60.003785999999998	Светлановский проспект	0103000020E61000000100000005000000E962D34A21543E406117450F7C004E40E962D34A21543E4005C3B98619064E402CEFAA07CC673E4005C3B98619064E402CEFAA07CC673E406117450F7C004E40E962D34A21543E406117450F7C004E40
16596	2	29.779143000000001	29.783185	59.912283000000002	59.908921999999997	Сафронова	0103000020E6100000010000000500000047E867EA75C73D40B54E5C8E57F44D4047E867EA75C73D4030D978B0C5F44D40BFB7E9CF7EC83D4030D978B0C5F44D40BFB7E9CF7EC83D40B54E5C8E57F44D4047E867EA75C73D40B54E5C8E57F44D40
13364	2	29.945771000000001	30.102024	59.874651999999998	59.851232000000003	Санкт-Петербургское шоссе	0103000020E6100000010000000500000056815A0C1EF23D4083A7902BF5EC4D4056815A0C1EF23D40C4B0C398F4EF4D403868AF3E1E1A3E40C4B0C398F4EF4D403868AF3E1E1A3E4083A7902BF5EC4D4056815A0C1EF23D4083A7902BF5EC4D40
16590	2	29.877175999999999	29.945771000000001	59.888930000000002	59.874651999999998	Санкт-Петербургский проспект	0103000020E610000001000000050000000AD6389B8EE03D40C4B0C398F4EF4D400AD6389B8EE03D4076374F75C8F14D4056815A0C1EF23D4076374F75C8F14D4056815A0C1EF23D40C4B0C398F4EF4D400AD6389B8EE03D40C4B0C398F4EF4D40
77275	2	30.281749999999999	30.336808000000001	59.940862000000003	59.916680999999997	Садовая улица	0103000020E61000000100000005000000E3A59BC420483E40AAEE91CD55F54D40E3A59BC420483E404B06802A6EF84D40FB07910C39563E404B06802A6EF84D40FB07910C39563E40AAEE91CD55F54D40E3A59BC420483E40AAEE91CD55F54D40
74847	2	30.281749999999999	30.336808000000001	59.940862000000003	59.916680999999997	Садовая 	0103000020E61000000100000005000000E3A59BC420483E40AAEE91CD55F54D40E3A59BC420483E404B06802A6EF84D40FB07910C39563E404B06802A6EF84D40FB07910C39563E40AAEE91CD55F54D40E3A59BC420483E40AAEE91CD55F54D40
79417	2	30.281749999999999	30.336808000000001	59.940862000000003	59.916680999999997	Садовая	0103000020E61000000100000005000000E3A59BC420483E40AAEE91CD55F54D40E3A59BC420483E404B06802A6EF84D40FB07910C39563E404B06802A6EF84D40FB07910C39563E40AAEE91CD55F54D40E3A59BC420483E40AAEE91CD55F54D40
13268	2	30.281749999999999	30.336808000000001	59.940862000000003	59.916680999999997	Садовая	0103000020E61000000100000005000000E3A59BC420483E40AAEE91CD55F54D40E3A59BC420483E404B06802A6EF84D40FB07910C39563E404B06802A6EF84D40FB07910C39563E40AAEE91CD55F54D40E3A59BC420483E40AAEE91CD55F54D40
15313	2	30.189115999999999	30.302295000000001	59.990614999999998	59.983648000000002	Савушкина	0103000020E610000001000000050000007C26FBE769303E404E637B2DE8FD4D407C26FBE769303E40A9F6E978CCFE4D408CBE8234634D3E40A9F6E978CCFE4D408CBE8234634D3E404E637B2DE8FD4D407C26FBE769303E404E637B2DE8FD4D40
7569	2	30.488703999999998	30.533072000000001	59.991750000000003	59.961877000000001	Рябовское шоссе	0103000020E61000000100000005000000A46C91B41B7D3E4026E318C91EFB4D40A46C91B41B7D3E406DE7FBA9F1FE4D40CF69166877883E406DE7FBA9F1FE4D40CF69166877883E4026E318C91EFB4D40A46C91B41B7D3E4026E318C91EFB4D40
13376	2	30.353318999999999	30.363703000000001	59.942439	59.942231999999997	Рылеева	0103000020E61000000100000005000000300E2E1D735A3E40519FE40E9BF84D40300E2E1D735A3E40CBBC55D7A1F84D400475CAA31B5D3E40CBBC55D7A1F84D400475CAA31B5D3E40519FE40E9BF84D40300E2E1D735A3E40519FE40E9BF84D40
2948	2	30.483142999999998	30.519964999999999	59.847476	59.834800000000001	Рыбацкий проспект	0103000020E61000000100000005000000944A7842AF7B3E40B459F5B9DAEA4D40944A7842AF7B3E408C12F4177AEC4D408C101E6D1C853E408C12F4177AEC4D408C101E6D1C853E40B459F5B9DAEA4D40944A7842AF7B3E40B459F5B9DAEA4D40
8123	2	30.071346999999999	30.092438999999999	59.837418	59.832652000000003	Российский бульвар	0103000020E61000000100000005000000EFAA07CC43123E4079793A5794EA4D40EFAA07CC43123E40768A558330EB4D40FCDF1115AA173E40768A558330EB4D40FCDF1115AA173E4079793A5794EA4D40EFAA07CC43123E4079793A5794EA4D40
3614	2	29.847719999999999	29.961986	59.872286000000003	59.672964999999998	Ропшинское шоссе	0103000020E61000000100000005000000452A8C2D04D93D40232D95B723D64D40452A8C2D04D93D401C615111A7EF4D40B935E9B644F63D401C615111A7EF4D40B935E9B644F63D40232D95B723D64D40452A8C2D04D93D40232D95B723D64D40
77241	2	30.262553	30.297525	59.913862000000002	59.912716000000003	Рижский проспект	0103000020E61000000100000005000000797764AC36433E409A44BDE0D3F44D40797764AC36433E405187156EF9F44D400EBE30992A4C3E405187156EF9F44D400EBE30992A4C3E409A44BDE0D3F44D40797764AC36433E409A44BDE0D3F44D40
7603	2	30.496618000000002	30.511790999999999	59.989021999999999	59.976463000000003	Ржевская улица	0103000020E61000000100000005000000DD9A745B227F3E40856055BDFCFC4D40DD9A745B227F3E402383DC4598FE4D401B6327BC04833E402383DC4598FE4D401B6327BC04833E40856055BDFCFC4D40DD9A745B227F3E40856055BDFCFC4D40
13294	2	30.177716	30.181183999999998	59.817064999999999	59.810858000000003	Речная	0103000020E61000000100000005000000D7F9B7CB7E2D3E4099D9E731CAE74D40D7F9B7CB7E2D3E4066DAFE9595E84D40F78E1A13622E3E4066DAFE9595E84D40F78E1A13622E3E4099D9E731CAE74D40D7F9B7CB7E2D3E4099D9E731CAE74D40
16508	2	30.339368	30.357721000000002	59.909002999999998	59.904586000000002	Расстанная	0103000020E61000000100000005000000164F3DD2E0563E40B1355B79C9F34D40164F3DD2E0563E40A27BD6355AF44D40A9177C9A935B3E40A27BD6355AF44D40A9177C9A935B3E40B1355B79C9F34D40164F3DD2E0563E40B1355B79C9F34D40
16570	2	30.362158000000001	30.363810999999998	59.943750999999999	59.935704999999999	Радищева	0103000020E610000001000000050000001AFCFD62B65C3E4012DA722EC5F74D401AFCFD62B65C3E409D4830D5CCF84D40D0ECBAB7225D3E409D4830D5CCF84D40D0ECBAB7225D3E4012DA722EC5F74D401AFCFD62B65C3E4012DA722EC5F74D40
16046	2	30.355734999999999	30.358142999999998	59.931296000000003	59.926769	Пушкинская	0103000020E61000000100000005000000E50AEF72115B3E402BF9D85DA0F64D40E50AEF72115B3E40A47213B534F74D40944A7842AF5B3E40A47213B534F74D40944A7842AF5B3E402BF9D85DA0F64D40E50AEF72115B3E402BF9D85DA0F64D40
1522	2	30.309705999999998	30.332477999999998	59.841396000000003	59.744464999999998	Пулковское шоссе	0103000020E61000000100000005000000FE5F75E4484F3E4021020EA14ADF4D40FE5F75E4484F3E401C7E37DDB2EB4D40B5A338471D553E401C7E37DDB2EB4D40B5A338471D553E4021020EA14ADF4D40FE5F75E4484F3E4021020EA14ADF4D40
16656	2	29.712551000000001	29.715021	59.924709	59.919927999999999	Пулемётчиков	0103000020E610000001000000050000006BBB09BE69B63D405C566133C0F54D406BBB09BE69B63D408FA850DD5CF64D4006F4C29D0BB73D408FA850DD5CF64D4006F4C29D0BB73D405C566133C0F54D406BBB09BE69B63D405C566133C0F54D40
3477	2	30.291326000000002	30.295556999999999	59.965232	59.963683000000003	Пудожская улица	0103000020E6100000010000000500000079793A57944A3E40085BECF659FB4D4079793A57944A3E40BE86E0B88CFB4D40971AA19FA94B3E40BE86E0B88CFB4D40971AA19FA94B3E40085BECF659FB4D4079793A57944A3E40085BECF659FB4D40
13354	2	30.291326000000002	30.295556999999999	59.965232	59.963683000000003	Пудожская	0103000020E6100000010000000500000079793A57944A3E40085BECF659FB4D4079793A57944A3E40BE86E0B88CFB4D40971AA19FA94B3E40BE86E0B88CFB4D40971AA19FA94B3E40085BECF659FB4D4079793A57944A3E40085BECF659FB4D40
6769	2	30.365787000000001	30.367350999999999	59.936359000000003	59.935949000000001	Прудковский переулок	0103000020E610000001000000050000004D4D8237A45D3E40A9DC442DCDF74D404D4D8237A45D3E405B28999CDAF74D40242713B70A5E3E405B28999CDAF74D40242713B70A5E3E40A9DC442DCDF74D404D4D8237A45D3E40A9DC442DCDF74D40
13350	2	30.284535000000002	30.328678	59.972437999999997	59.970308000000003	Профессора Попова	0103000020E610000001000000050000003F912749D7483E400A86730D33FC4D403F912749D7483E409EB12FD978FC4D4029EACC3D24543E409EB12FD978FC4D4029EACC3D24543E400A86730D33FC4D403F912749D7483E400A86730D33FC4D40
16113	2	29.406863000000001	30.230205000000002	60.198681000000001	59.985156000000003	Приморское шоссе	0103000020E61000000100000005000000D4F36E2C28683D40A6BA809719FE4D40D4F36E2C28683D4015AB06616E194E402D6002B7EE3A3E4015AB06616E194E402D6002B7EE3A3E40A6BA809719FE4D40D4F36E2C28683D40A6BA809719FE4D40
4237	2	30.189574	30.296724999999999	59.989989999999999	59.982562999999999	Приморский проспект	0103000020E61000000100000005000000022CF2EB87303E403CA1D79FC4FD4D40022CF2EB87303E40FBAE08FEB7FE4D40D5E76A2BF64B3E40FBAE08FEB7FE4D40D5E76A2BF64B3E403CA1D79FC4FD4D40022CF2EB87303E403CA1D79FC4FD4D40
5571	2	30.380053	30.403454	59.881506999999999	59.862012999999997	Пражская улица	0103000020E6100000010000000500000027BF45274B613E4009DD257156EE4D4027BF45274B613E40F818AC38D5F04D40BD70E7C248673E40F818AC38D5F04D40BD70E7C248673E4009DD257156EE4D4027BF45274B613E4009DD257156EE4D40
13246	2	30.338163999999999	30.345161999999998	59.924925000000002	59.920830000000002	Правды	0103000020E610000001000000050000003EAF78EA91563E407D96E7C1DDF54D403EAF78EA91563E405C2041F163F64D406BD26D895C583E405C2041F163F64D406BD26D895C583E407D96E7C1DDF54D403EAF78EA91563E407D96E7C1DDF54D40
4294	2	30.337364999999998	30.361871000000001	60.045726999999999	60.040725999999999	Поэтический бульвар	0103000020E61000000100000005000000A6D0798D5D563E40670C738236054E40A6D0798D5D563E40A8C5E061DA054E40EE5EEE93A35C3E40A8C5E061DA054E40EE5EEE93A35C3E40670C738236054E40A6D0798D5D563E40670C738236054E40
78776	2	30.130769999999998	30.171329	60.002180000000003	59.993648999999998	Полевая	0103000020E61000000100000005000000444C89247A213E40FF59F3E32FFF4D40444C89247A213E40475A2A6F47004E403CDBA337DC2B3E40475A2A6F47004E403CDBA337DC2B3E40FF59F3E32FFF4D40444C89247A213E40FF59F3E32FFF4D40
78805	2	30.130769999999998	30.171329	60.002180000000003	59.993648999999998	Полевая	0103000020E61000000100000005000000444C89247A213E40FF59F3E32FFF4D40444C89247A213E40475A2A6F47004E403CDBA337DC2B3E40475A2A6F47004E403CDBA337DC2B3E40FF59F3E32FFF4D40444C89247A213E40FF59F3E32FFF4D40
16561	2	30.298504000000001	30.319928000000001	60.03002	60.021473999999998	Поклоногорская	0103000020E61000000100000005000000A6B915C26A4C3E406EDBF7A8BF024E40A6B915C26A4C3E40EB1C03B2D7034E401F1329CDE6513E40EB1C03B2D7034E401F1329CDE6513E406EDBF7A8BF024E40A6B915C26A4C3E406EDBF7A8BF024E40
4080	2	30.298504000000001	30.319928000000001	60.03002	60.021473999999998	Поклонногорская улица	0103000020E61000000100000005000000A6B915C26A4C3E406EDBF7A8BF024E40A6B915C26A4C3E40EB1C03B2D7034E401F1329CDE6513E40EB1C03B2D7034E401F1329CDE6513E406EDBF7A8BF024E40A6B915C26A4C3E406EDBF7A8BF024E40
13264	2	30.450444999999998	30.501567999999999	59.918926999999996	59.906855	Подвойского	0103000020E610000001000000050000008FA50F5D50733E40679B1BD313F44D408FA50F5D50733E40A83462669FF54D405AB8ACC266803E40A83462669FF54D405AB8ACC266803E40679B1BD313F44D408FA50F5D50733E40679B1BD313F44D40
13252	2	30.146401000000001	30.147155999999999	59.846792999999998	59.825347999999998	Пограничника Гарькавого	0103000020E61000000100000005000000091A33897A253E40D5E8D500A5E94D40091A33897A253E40A9BD88B663EC4D400169FF03AC253E40A9BD88B663EC4D400169FF03AC253E40D5E8D500A5E94D40091A33897A253E40D5E8D500A5E94D40
13317	2	30.283052999999999	30.298179999999999	60.082489000000002	60.078175999999999	Пляжевая	0103000020E61000000100000005000000E108522976483E4082AAD1AB010A4E40E108522976483E40CFA3E2FF8E0A4E403F524486554C3E40CFA3E2FF8E0A4E403F524486554C3E4082AAD1AB010A4E40E108522976483E4082AAD1AB010A4E40
3302	2	30.301729000000002	30.308816	59.966546999999998	59.963633000000002	Плуталова улица	0103000020E610000001000000050000003A419B1C3E4D3E40562C7E5358FB4D403A419B1C3E4D3E400186E5CFB7FB4D40467BBC900E4F3E400186E5CFB7FB4D40467BBC900E4F3E40562C7E5358FB4D403A419B1C3E4D3E40562C7E5358FB4D40
15309	2	30.377842999999999	30.392880999999999	59.842309	59.839537999999997	Пловдивская	0103000020E61000000100000005000000C405A051BA603E40E7DF2EFB75EB4D40C405A051BA603E40301004C8D0EB4D40433866D993643E40301004C8D0EB4D40433866D993643E40E7DF2EFB75EB4D40C405A051BA603E40E7DF2EFB75EB4D40
4845	2	30.209309999999999	30.236277000000001	60.027278000000003	59.985075000000002	Планерная улица	0103000020E61000000100000005000000CBB9145795353E40B98D06F016FE4D40CBB9145795353E403DF372D87D034E4008CC43A67C3C3E403DF372D87D034E4008CC43A67C3C3E40B98D06F016FE4D40CBB9145795353E40B98D06F016FE4D40
16616	2	30.209309999999999	30.236277000000001	60.027278000000003	59.985075000000002	Планерная	0103000020E61000000100000005000000CBB9145795353E40B98D06F016FE4D40CBB9145795353E403DF372D87D034E4008CC43A67C3C3E403DF372D87D034E4008CC43A67C3C3E40B98D06F016FE4D40CBB9145795353E40B98D06F016FE4D40
4615	2	30.403490000000001	30.464324000000001	60.020767999999997	59.957151000000003	Пискарёвский проспект	0103000020E610000001000000050000005743E21E4B673E40B72A89EC83FA4D405743E21E4B673E40D3669C86A8024E4077BF0AF0DD763E40D3669C86A8024E4077BF0AF0DD763E40B72A89EC83FA4D405743E21E4B673E40B72A89EC83FA4D40
15327	2	30.403490000000001	30.464324000000001	60.020767999999997	59.957151000000003	Пискаревский проспект	0103000020E610000001000000050000005743E21E4B673E40B72A89EC83FA4D405743E21E4B673E40D3669C86A8024E4077BF0AF0DD763E40D3669C86A8024E4077BF0AF0DD763E40B72A89EC83FA4D405743E21E4B673E40B72A89EC83FA4D40
7398	2	30.102024	30.213595000000002	59.853183999999999	59.845519000000003	Петергофское шоссе	0103000020E610000001000000050000003868AF3E1E1A3E40C59272F739EC4D403868AF3E1E1A3E4038BC202235ED4D40D1967329AE363E4038BC202235ED4D40D1967329AE363E40C59272F739EC4D403868AF3E1E1A3E40C59272F739EC4D40
77171	2	30.325659999999999	30.395073	59.778371	59.728824000000003	Петербургское шоссе	0103000020E61000000100000005000000889D29745E533E401C45D61A4ADD4D40889D29745E533E40D19332A9A1E34D4059880E8123653E40D19332A9A1E34D4059880E8123653E401C45D61A4ADD4D40889D29745E533E401C45D61A4ADD4D40
7161	2	30.405080000000002	30.415545000000002	59.932490999999999	59.930430000000001	Перевозный переулок	0103000020E610000001000000050000008143A852B3673E40D09B8A5418F74D408143A852B3673E403C6876DD5BF74D402E043928616A3E403C6876DD5BF74D402E043928616A3E40D09B8A5418F74D408143A852B3673E40D09B8A5418F74D40
16458	2	30.194002999999999	30.205798000000001	60.106554000000003	60.099516999999999	Первомайская	0103000020E610000001000000050000006D533C2EAA313E40B1321AF9BC0C4E406D533C2EAA313E4006A1BC8FA30D4E400C957F2DAF343E4006A1BC8FA30D4E400C957F2DAF343E40B1321AF9BC0C4E406D533C2EAA313E40B1321AF9BC0C4E40
3194	2	30.32433	30.328596999999998	59.961278	59.957768999999999	Певческий переулок	0103000020E61000000100000005000000971C774A07533E40B20FB22C98FA4D40971C774A07533E40A12E52280BFB4D404F90D8EE1E543E40A12E52280BFB4D404F90D8EE1E543E40B20FB22C98FA4D40971C774A07533E40B20FB22C98FA4D40
3531	2	30.344128999999999	30.346599000000001	59.989359999999998	59.982756999999999	Парголовская улица	0103000020E61000000100000005000000ED9A90D618583E4021753BFBCAFD4D40ED9A90D618583E403BFC3559A3FE4D4089D349B6BA583E403BFC3559A3FE4D4089D349B6BA583E4021753BFBCAFD4D40ED9A90D618583E4021753BFBCAFD4D40
13271	2	30.560884000000001	30.591830999999999	59.748590999999998	59.746841000000003	Павловская	0103000020E6100000010000000500000084D90418968F3E40EE27637C98DF4D4084D90418968F3E403B8A73D4D1DF4D404CC2853C82973E403B8A73D4D1DF4D404CC2853C82973E40EE27637C98DF4D4084D90418968F3E40EE27637C98DF4D40
7545	2	30.484508999999999	30.490887000000001	59.959805000000003	59.958056999999997	Отечественная улица	0103000020E610000001000000050000001F9E25C8087C3E40185A9D9CA1FA4D401F9E25C8087C3E40C6C4E6E3DAFA4D4014083BC5AA7D3E40C6C4E6E3DAFA4D4014083BC5AA7D3E40185A9D9CA1FA4D401F9E25C8087C3E40185A9D9CA1FA4D40
15331	2	30.165319	30.179504000000001	59.835785000000001	59.835721999999997	Отважных	0103000020E610000001000000050000004D689258522A3E401B4641F0F8EA4D404D689258522A3E4062BEBC00FBEA4D404E8061F9F32D3E4062BEBC00FBEA4D404E8061F9F32D3E401B4641F0F8EA4D404D689258522A3E401B4641F0F8EA4D40
3195	2	30.240562000000001	30.241236000000001	59.937967999999998	59.936498999999998	Остоумова улица	0103000020E610000001000000050000000DA9A278953D3E404CDE0033DFF74D400DA9A278953D3E40E658DE550FF84D402C9E7AA4C13D3E40E658DE550FF84D402C9E7AA4C13D3E404CDE0033DFF74D400DA9A278953D3E404CDE0033DFF74D40
13344	2	30.481275	30.484500000000001	59.949131999999999	59.945017	Осипенко	0103000020E61000000100000005000000E561A1D6347B3E40FF942A51F6F84D40E561A1D6347B3E4025CB49287DF94D4079E92631087C3E4025CB49287DF94D4079E92631087C3E40FF942A51F6F84D40E561A1D6347B3E40FF942A51F6F84D40
15289	2	30.084785	30.092079999999999	59.742170999999999	59.740392999999997	Освобождения	0103000020E61000000100000005000000FD304278B4153E40FA97A432C5DE4D40FD304278B4153E4012859675FFDE4D409D9D0C8E92173E4012859675FFDE4D409D9D0C8E92173E40FA97A432C5DE4D40FD304278B4153E40FA97A432C5DE4D40
13260	2	30.337733	30.341712999999999	60.007969000000003	59.996920000000003	Орбели	0103000020E61000000100000005000000ACC77DAB75563E403A5D16139BFF4D40ACC77DAB75563E40E030D12005014E40389ECF807A573E40E030D12005014E40389ECF807A573E403A5D16139BFF4D40ACC77DAB75563E403A5D16139BFF4D40
74857	2	30.403247	30.422021999999998	59.730080000000001	59.715204	Оранжерейная	0103000020E61000000100000005000000CA3505323B673E40F4FBFECD8BDB4D40CA3505323B673E405ABBED4273DD4D40483140A2096C3E405ABBED4273DD4D40483140A2096C3E40F4FBFECD8BDB4D40CA3505323B673E40F4FBFECD8BDB4D40
13312	2	30.236986999999999	30.241029000000001	59.934933999999998	59.926738	Опочинина	0103000020E61000000100000005000000C093162EAB3C3E40F0FACC599FF64D40C093162EAB3C3E4090F5D4EAABF74D4039639813B43D3E4090F5D4EAABF74D4039639813B43D3E40F0FACC599FF64D40C093162EAB3C3E40F0FACC599FF64D40
4376	2	30.311717999999999	30.321086999999999	59.999119999999998	59.991903000000001	Омская улица	0103000020E61000000100000005000000149337C0CC4F3E40F3E670ADF6FE4D40149337C0CC4F3E40C763062AE3FF4D40B62BF4C132523E40C763062AE3FF4D40B62BF4C132523E40F3E670ADF6FE4D40149337C0CC4F3E40F3E670ADF6FE4D40
1877	2	30.413316999999999	30.499887999999999	59.916477999999998	59.858393999999997	Октябрьская набережная	0103000020E610000001000000050000007EE19524CF693E40938AC6DADFED4D407EE19524CF693E4072C0AE264FF54D40B0A9F3A8F87F3E4072C0AE264FF54D40B0A9F3A8F87F3E40938AC6DADFED4D407EE19524CF693E40938AC6DADFED4D40
7197	2	30.407181999999999	30.423459000000001	59.942196000000003	59.919432	Новочеркасский проспект	0103000020E6100000010000000500000016855D143D683E40AC72A1F2AFF54D4016855D143D683E400536E7E099F84D4066321CCF676C3E400536E7E099F84D4066321CCF676C3E40AC72A1F2AFF54D4016855D143D683E40AC72A1F2AFF54D40
3599	2	30.329809999999998	30.379145000000001	59.998018000000002	59.991771999999997	Новороссийская улица	0103000020E61000000100000005000000CDE49B6D6E543E40548B8862F2FE4D40CDE49B6D6E543E40E068C70DBFFF4D4022718FA50F613E40E068C70DBFFF4D4022718FA50F613E40548B8862F2FE4D40CDE49B6D6E543E40548B8862F2FE4D40
3409	2	30.272084	30.276567	59.963093000000001	59.961201000000003	Новоладожская улица	0103000020E61000000100000005000000CEC3094CA7453E40F6F065A208FB4D40CEC3094CA7453E40D600A5A146FB4D4020274C18CD463E40D600A5A146FB4D4020274C18CD463E40F6F065A208FB4D40CEC3094CA7453E40F6F065A208FB4D40
4948	2	30.29279	30.297749	60.032635999999997	60.024189999999997	Новоколомяжский проспект	0103000020E6100000010000000500000089981249F44A3E40F3716DA818034E4089981249F44A3E400C569C6A2D044E40AD6A4947394C3E400C569C6A2D044E40AD6A4947394C3E40F3716DA818034E4089981249F44A3E40F3716DA818034E40
15829	2	29.958580999999999	29.966666	60.086331000000001	60.077736000000002	Ново-Гагаринская	0103000020E6100000010000000500000025917D9065F53D4066DCD440F3094E4025917D9065F53D40C4D0EAE40C0B4E40B727486C77F73D40C4D0EAE40C0B4E40B727486C77F73D4066DCD440F3094E4025917D9065F53D4066DCD440F3094E40
4871	2	30.222632000000001	30.235765000000001	60.032708	60.027754999999999	Нижне-Каменская улица	0103000020E61000000100000005000000070B2769FE383E4076A6D0798D034E40070B2769FE383E40A62897C62F044E409C8A54185B3C3E40A62897C62F044E409C8A54185B3C3E4076A6D0798D034E40070B2769FE383E4076A6D0798D034E40
15296	2	30.222632000000001	30.235765000000001	60.032708	60.027754999999999	Нижне-Каменская 	0103000020E61000000100000005000000070B2769FE383E4076A6D0798D034E40070B2769FE383E40A62897C62F044E409C8A54185B3C3E40A62897C62F044E409C8A54185B3C3E4076A6D0798D034E40070B2769FE383E4076A6D0798D034E40
3545	2	30.3428	30.354469000000002	59.967908000000001	59.966579000000003	Нейшлотский переулок	0103000020E610000001000000050000009D11A5BDC1573E400D0055DCB8FB4D409D11A5BDC1573E40B5C4CA68E4FB4D402272FA7ABE5A3E40B5C4CA68E4FB4D402272FA7ABE5A3E400D0055DCB8FB4D409D11A5BDC1573E400D0055DCB8FB4D40
6433	2	30.311817000000001	30.384831999999999	59.937255999999998	59.923698000000002	Невский проспект	0103000020E610000001000000050000003B56293DD34F3E40B8B06EBC3BF64D403B56293DD34F3E4069FD2D01F8F74D404B74965984623E4069FD2D01F8F74D404B74965984623E40B8B06EBC3BF64D403B56293DD34F3E40B8B06EBC3BF64D40
1959	2	30.459050999999999	30.491658999999999	59.885055999999999	59.879033	Народная улица	0103000020E610000001000000050000003332C85D84753E40698D412784F04D403332C85D84753E407590D78349F14D40B8C83D5DDD7D3E407590D78349F14D40B8C83D5DDD7D3E40698D412784F04D403332C85D84753E40698D412784F04D40
2807	2	30.273405	30.276206999999999	59.905976000000003	59.901733999999998	Нарвский проспект	0103000020E610000001000000050000001990BDDEFD453E407BD80B056CF34D401990BDDEFD453E40FF7A8505F7F34D4020ED7F80B5463E40FF7A8505F7F34D4020ED7F80B5463E407BD80B056CF34D401990BDDEFD453E407BD80B056CF34D40
3366	2	30.230366	30.239179	59.955309	59.926233000000003	Наличная улица	0103000020E610000001000000050000003F1C2444F93A3E40EDBC8DCD8EF64D403F1C2444F93A3E408849B89047FA4D40D6E3BED53A3D3E408849B89047FA4D40D6E3BED53A3D3E40EDBC8DCD8EF64D403F1C2444F93A3E40EDBC8DCD8EF64D40
79416	2	30.344999999999999	30.345414000000002	59.946486	59.938144000000001	Моховая	0103000020E61000000100000005000000B81E85EB51583E402578431A15F84D40B81E85EB51583E40990F087426F94D409F94490D6D583E40990F087426F94D409F94490D6D583E402578431A15F84D40B81E85EB51583E402578431A15F84D40
1052	2	30.317565999999999	30.321887	59.926029999999997	59.844324999999998	Московский проспект	0103000020E61000000100000005000000505260014C513E40FC1873D712EC4D40505260014C513E40B48EAA2688F64D40EF01BA2F67523E40B48EAA2688F64D40EF01BA2F67523E40FC1873D712EC4D40505260014C513E40FC1873D712EC4D40
3364	2	30.206247000000001	30.23678	59.960850000000001	59.932116999999998	Морская набережная	0103000020E61000000100000005000000EBE5779ACC343E40D7851F9C4FF74D40EBE5779ACC343E40492EFF21FDFA4D40CD58349D9D3C3E40492EFF21FDFA4D40CD58349D9D3C3E40D7851F9C4FF74D40EBE5779ACC343E40D7851F9C4FF74D40
13321	2	30.330573999999999	30.331427000000001	59.936557000000001	59.934736000000001	Михайловская	0103000020E610000001000000050000006CE8667FA0543E406A32E36DA5F74D406CE8667FA0543E4081EB8A19E1F74D40EB025E66D8543E4081EB8A19E1F74D40EB025E66D8543E406A32E36DA5F74D406CE8667FA0543E406A32E36DA5F74D40
15292	2	30.312391999999999	30.330393999999998	59.962651000000001	59.958880999999998	Мира	0103000020E6100000010000000500000033880FECF84F3E40BDE0D39CBCFA4D4033880FECF84F3E40193BE12538FB4D406CCB80B394543E40193BE12538FB4D406CCB80B394543E40BDE0D39CBCFA4D4033880FECF84F3E40BDE0D39CBCFA4D40
5763	2	30.422588000000001	30.432289999999998	59.998044999999998	59.988644000000001	Меншиковский проспект	0103000020E610000001000000050000009BAE27BA2E6C3E407DB1F7E28BFE4D409BAE27BA2E6C3E40D97745F0BFFF4D404963B48EAA6E3E40D97745F0BFFF4D404963B48EAA6E3E407DB1F7E28BFE4D409BAE27BA2E6C3E407DB1F7E28BFE4D40
5954	2	30.248646999999998	30.258096999999999	59.911023999999998	59.910545999999997	Межевой канал	0103000020E610000001000000050000009E3F6D54A73F3E4076C075C58CF44D409E3F6D54A73F3E4080EF366F9CF44D401A321EA512423E4080EF366F9CF44D401A321EA512423E4076C075C58CF44D409E3F6D54A73F3E4076C075C58CF44D40
16548	2	30.192250999999999	30.253399000000002	59.995134	59.990467000000002	Мебельная	0103000020E61000000100000005000000909F8D5C37313E403562669FC7FE4D40909F8D5C37313E409F91088D60FF4D40D0D6C1C1DE403E409F91088D60FF4D40D0D6C1C1DE403E403562669FC7FE4D40909F8D5C37313E403562669FC7FE4D40
15312	2	30.353912000000001	30.355484000000001	59.943880999999998	59.931823999999999	Маяковского	0103000020E6100000010000000500000076A911FA995A3E405FD0420246F74D4076A911FA995A3E406B28B517D1F84D405340DAFF005B3E406B28B517D1F84D405340DAFF005B3E405FD0420246F74D4076A911FA995A3E405FD0420246F74D40
13324	2	30.265625	30.275866000000001	60.036259000000001	60.007137	Маршала Новикова	0103000020E610000001000000050000000000000000443E40B8CB7EDDE9004E400000000000443E40C4978922A4044E400E1478279F463E40C4978922A4044E400E1478279F463E40B8CB7EDDE9004E400000000000443E40B8CB7EDDE9004E40
15328	2	30.157792000000001	30.216460999999999	59.859527999999997	59.848402999999998	Маршала Захарова	0103000020E610000001000000050000000892770E65283E40056A317898EC4D400892770E65283E4086FF740305EE4D4005DCF3FC69373E4086FF740305EE4D4005DCF3FC69373E40056A317898EC4D400892770E65283E40056A317898EC4D40
13329	2	30.262311	30.290554	59.903016000000001	59.873894	Маршала Говорова	0103000020E610000001000000050000008D614ED026433E40D71533C2DBEF4D408D614ED026433E40E3E13D0796F34D40D4B837BF614A3E40E3E13D0796F34D40D4B837BF614A3E40D71533C2DBEF4D408D614ED026433E40D71533C2DBEF4D40
566	2	30.353408999999999	30.360738999999999	59.943165	59.943002999999997	Манежный переулок	0103000020E61000000100000005000000B01C2103795A3E40D3838252B4F84D40B01C2103795A3E40ADDD76A1B9F84D4049641F64595C3E40ADDD76A1B9F84D4049641F64595C3E40D3838252B4F84D40B01C2103795A3E40D3838252B4F84D40
15731	2	30.288730000000001	30.309742	59.967714000000001	59.953001999999998	Малый проспект П.С.	0103000020E61000000100000005000000C45F9335EA493E40E48233F8FBF94D40C45F9335EA493E40D0F0660DDEFB4D40983270404B4F3E40D0F0660DDEFB4D40983270404B4F3E40E48233F8FBF94D40C45F9335EA493E40E48233F8FBF94D40
13375	2	30.233699000000001	30.280483	59.948675999999999	59.937336999999999	Малый проспект В.О.	0103000020E61000000100000005000000A01B9AB2D33B3E40562AA8A8FAF74D40A01B9AB2D33B3E40034015376EF94D407F15E0BBCD473E40034015376EF94D407F15E0BBCD473E40562AA8A8FAF74D40A01B9AB2D33B3E40562AA8A8FAF74D40
2492	2	30.318383000000001	30.330815999999999	59.914515999999999	59.910839000000003	Малодетскосельский проспект	0103000020E61000000100000005000000359A5C8C81513E40EF75525F96F44D40359A5C8C81513E4099D53BDC0EF54D4058FE7C5BB0543E4099D53BDC0EF54D4058FE7C5BB0543E40EF75525F96F44D40359A5C8C81513E40EF75525F96F44D40
6028	2	30.41038	30.417953000000001	59.851706	59.844230000000003	Малая Бухарестская улица	0103000020E61000000100000005000000B7EEE6A90E693E40AB2688BA0FEC4D40B7EEE6A90E693E404BE7C3B304ED4D40DD43C2F7FE6A3E404BE7C3B304ED4D40DD43C2F7FE6A3E40AB2688BA0FEC4D40B7EEE6A90E693E40AB2688BA0FEC4D40
13258	2	30.41038	30.417953000000001	59.851706	59.844230000000003	Малая Бухарестская 	0103000020E61000000100000005000000B7EEE6A90E693E40AB2688BA0FEC4D40B7EEE6A90E693E404BE7C3B304ED4D40DD43C2F7FE6A3E404BE7C3B304ED4D40DD43C2F7FE6A3E40AB2688BA0FEC4D40B7EEE6A90E693E40AB2688BA0FEC4D40
13249	2	30.41038	30.417953000000001	59.851706	59.844230000000003	Малая Бухарестская	0103000020E61000000100000005000000B7EEE6A90E693E40AB2688BA0FEC4D40B7EEE6A90E693E404BE7C3B304ED4D40DD43C2F7FE6A3E404BE7C3B304ED4D40DD43C2F7FE6A3E40AB2688BA0FEC4D40B7EEE6A90E693E40AB2688BA0FEC4D40
67084	2	30.373989000000002	30.434850000000001	59.844980999999997	59.824375000000003	Малая Балканская 	0103000020E6100000010000000500000052103CBEBD5F3E40EC51B81E85E94D4052103CBEBD5F3E40E55E605628EC4D4065AA6054526F3E40E55E605628EC4D4065AA6054526F3E40EC51B81E85E94D4052103CBEBD5F3E40EC51B81E85E94D40
15307	2	30.373989000000002	30.434850000000001	59.844980999999997	59.824375000000003	Малая Балканская	0103000020E6100000010000000500000052103CBEBD5F3E40EC51B81E85E94D4052103CBEBD5F3E40E55E605628EC4D4065AA6054526F3E40E55E605628EC4D4065AA6054526F3E40EC51B81E85E94D4052103CBEBD5F3E40EC51B81E85E94D40
67086	2	30.227886999999999	30.252303000000001	59.848357	59.831743000000003	Лёни Голикова	0103000020E61000000100000005000000FD2E6CCD563A3E40A6D6FB8D76EA4D40FD2E6CCD563A3E40952A51F696EC4D40C5AEEDED96403E40952A51F696EC4D40C5AEEDED96403E40A6D6FB8D76EA4D40FD2E6CCD563A3E40A6D6FB8D76EA4D40
16670	2	30.165544000000001	30.172165	59.994211	59.992865999999999	Луговая	0103000020E610000001000000050000008D0C7217612A3E40B9A7AB3B16FF4D408D0C7217612A3E406729594E42FF4D400E846401132C3E406729594E42FF4D400E846401132C3E40B9A7AB3B16FF4D408D0C7217612A3E40B9A7AB3B16FF4D40
79414	2	30.274878000000001	30.278372000000001	59.919446000000001	59.917361999999997	Лоцманская	0103000020E61000000100000005000000D06394675E463E40EC4B361E6CF54D40D06394675E463E4011381268B0F54D40431F2C6343473E4011381268B0F54D40431F2C6343473E40EC4B361E6CF54D40D06394675E463E40EC4B361E6CF54D40
15322	2	30.347982999999999	30.348980000000001	59.949703999999997	59.932566999999999	Литейный проспект	0103000020E610000001000000050000006090F46915593E40172AFF5A5EF74D406090F46915593E40B07092E68FF94D4045F5D6C056593E40B07092E68FF94D4045F5D6C056593E40172AFF5A5EF74D406090F46915593E40172AFF5A5EF74D40
5504	2	30.320045	30.365221999999999	59.938428000000002	59.892094	Лиговский проспект	0103000020E61000000100000005000000923F1878EE513E409A7ADD2230F24D40923F1878EE513E404AD3A0681EF84D409BC761307F5D3E404AD3A0681EF84D409BC761307F5D3E409A7ADD2230F24D40923F1878EE513E409A7ADD2230F24D40
1867	2	30.290365000000001	30.297740000000001	59.925114000000001	59.909137999999999	Лермонтовский проспект	0103000020E610000001000000050000002EE7525C554A3E4082C64CA25EF44D402EE7525C554A3E402F89B3226AF64D4007B64AB0384C3E402F89B3226AF64D4007B64AB0384C3E4082C64CA25EF44D402EE7525C554A3E4082C64CA25EF44D40
13358	2	30.072011	30.085971000000001	59.740194000000002	59.722490999999998	Лермонтова	0103000020E61000000100000005000000C7F319506F123E40C153C8957ADC4D40C7F319506F123E4004594FADBEDE4D408867093202163E4004594FADBEDE4D408867093202163E40C153C8957ADC4D40C7F319506F123E40C153C8957ADC4D40
15318	2	30.329333999999999	30.351271000000001	59.861719999999998	59.830142000000002	Ленсовета	0103000020E61000000100000005000000FB75A73B4F543E409D84D21742EA4D40FB75A73B4F543E40912749D74CEE4D40810871E5EC593E40912749D74CEE4D40810871E5EC593E409D84D21742EA4D40FB75A73B4F543E409D84D21742EA4D40
7323	2	30.477736	30.504245000000001	59.941299000000001	59.939256999999998	Ленская улица	0103000020E61000000100000005000000321F10E84C7A3E4000C5C89239F84D40321F10E84C7A3E40F660527C7CF84D40E92B483316813E40F660527C7CF84D40E92B483316813E4000C5C89239F84D40321F10E84C7A3E4000C5C89239F84D40
74863	2	30.477736	30.504245000000001	59.941299000000001	59.939256999999998	Ленская	0103000020E61000000100000005000000321F10E84C7A3E4000C5C89239F84D40321F10E84C7A3E40F660527C7CF84D40E92B483316813E40F660527C7CF84D40E92B483316813E4000C5C89239F84D40321F10E84C7A3E4000C5C89239F84D40
6100	2	30.179621000000001	30.321473999999998	59.861244999999997	59.851728999999999	Ленинский проспект	0103000020E61000000100000005000000C1AC50A4FB2D3E400307B47405ED4D40C1AC50A4FB2D3E40F86BB2463DEE4D40A983BC1E4C523E40F86BB2463DEE4D40A983BC1E4C523E400307B47405ED4D40C1AC50A4FB2D3E400307B47405ED4D40
13345	2	30.090237999999999	30.133590999999999	59.824185999999997	59.783836999999998	Ленинградская	0103000020E6100000010000000500000040DB6AD619173E40873254C554E44D4040DB6AD619173E4018E945ED7EE94D40390A100533223E4018E945ED7EE94D40390A100533223E40873254C554E44D4040DB6AD619173E40873254C554E44D40
3493	2	30.281714000000001	30.309543999999999	59.967925999999999	59.966164999999997	Левашовский проспект	0103000020E610000001000000050000004AD3A0681E483E4019C5724BABFB4D404AD3A0681E483E405B79C9FFE4FB4D404BAC8C463E4F3E405B79C9FFE4FB4D404BAC8C463E4F3E4019C5724BABFB4D404AD3A0681E483E4019C5724BABFB4D40
13352	2	30.615627	30.658459000000001	59.785083	59.748972000000002	Лагерное шоссе	0103000020E61000000100000005000000DB8827BB999D3E4053CF8250DEDF4D40DB8827BB999D3E40A2D288997DE44D40C2C1DEC490A83E40A2D288997DE44D40C2C1DEC490A83E4053CF8250DEDF4D40DB8827BB999D3E4053CF8250DEDF4D40
13356	2	30.356697	30.364476	60.051431999999998	60.041822000000003	Кустодиева	0103000020E61000000100000005000000D1949D7E505B3E406D205D6C5A054E40D1949D7E505B3E40E3FBE25295064E40492D944C4E5D3E40E3FBE25295064E40492D944C4E5D3E406D205D6C5A054E40D1949D7E505B3E406D205D6C5A054E40
2731	2	30.265741999999999	30.292449000000001	59.912053	59.911132000000002	Курляндская улица	0103000020E61000000100000005000000732CEFAA07443E40672B2FF99FF44D40732CEFAA07443E40FE9B1727BEF44D4077BF0AF0DD4A3E40FE9B1727BEF44D4077BF0AF0DD4A3E40672B2FF99FF44D40732CEFAA07443E40672B2FF99FF44D40
5970	2	30.379083000000001	30.397956000000001	59.846232999999998	59.824665000000003	Купчинская улица	0103000020E6100000010000000500000036785F950B613E40F3936A9F8EE94D4036785F950B613E40E2E5E95C51EC4D403A3FC571E0653E40E2E5E95C51EC4D403A3FC571E0653E40F3936A9F8EE94D4036785F950B613E40F3936A9F8EE94D40
15319	2	30.297595999999999	30.353408999999999	59.873085000000003	59.871495000000003	Кузнецовская	0103000020E61000000100000005000000A06B5F402F4C3E4053D0ED258DEF4D40A06B5F402F4C3E4068D0D03FC1EF4D40B01C2103795A3E4068D0D03FC1EF4D40B01C2103795A3E4053D0ED258DEF4D40A06B5F402F4C3E4053D0ED258DEF4D40
1564	2	30.291747999999998	30.322227999999999	59.877633000000003	59.830196000000001	Кубинская улица	0103000020E6100000010000000500000064AC36FFAF4A3E4090A2CEDC43EA4D4064AC36FFAF4A3E40F871344756F04D4001DBC1887D523E40F871344756F04D4001DBC1887D523E4090A2CEDC43EA4D4064AC36FFAF4A3E4090A2CEDC43EA4D40
13282	2	30.447075999999999	30.495557999999999	59.901757000000003	59.892806999999998	Крыленко	0103000020E6100000010000000500000095D39E9273723E40E751F17F47F24D4095D39E9273723E4034F8FBC56CF34D406B459BE3DC7E3E4034F8FBC56CF34D406B459BE3DC7E3E40E751F17F47F24D4095D39E9273723E40E751F17F47F24D40
16551	2	30.254270999999999	30.258412	59.877972	59.864747000000001	Кронштадтская	0103000020E610000001000000050000003B527DE717413E4035289A07B0EE4D403B527DE717413E40E066F16261F04D40DAE4F04927423E40E066F16261F04D40DAE4F04927423E4035289A07B0EE4D403B527DE717413E4035289A07B0EE4D40
16855	2	30.066675	30.154926	59.851553000000003	59.765523000000002	Красносельское шоссе	0103000020E61000000100000005000000F775E09C11113E40FCAA5CA8FCE14D40F775E09C11113E40C5E74EB0FFEC4D40D34CF73AA9273E40C5E74EB0FFEC4D40D34CF73AA9273E40FCAA5CA8FCE14D40F775E09C11113E40FCAA5CA8FCE14D40
13348	2	30.066675	30.154926	59.851553000000003	59.765523000000002	Красносельское шоссе	0103000020E61000000100000005000000F775E09C11113E40FCAA5CA8FCE14D40F775E09C11113E40C5E74EB0FFEC4D40D34CF73AA9273E40C5E74EB0FFEC4D40D34CF73AA9273E40FCAA5CA8FCE14D40F775E09C11113E40FCAA5CA8FCE14D40
1601	2	30.258277	30.321123	59.875884999999997	59.843330999999999	Краснопутиловская улица	0103000020E610000001000000050000001A4F04711E423E40FB592C45F2EB4D401A4F04711E423E404A07EBFF1CF04D4050FEEE1D35523E404A07EBFF1CF04D4050FEEE1D35523E40FB592C45F2EB4D401A4F04711E423E40FB592C45F2EB4D40
15710	2	30.071984	30.102671000000001	59.718943000000003	59.716800999999997	Красногородская	0103000020E61000000100000005000000D4D51D8B6D123E40BB5E9A22C0DB4D40D4D51D8B6D123E401558005306DC4D40643F8BA5481A3E401558005306DC4D40643F8BA5481A3E40BB5E9A22C0DB4D40D4D51D8B6D123E40BB5E9A22C0DB4D40
15297	2	30.273495	30.293904000000001	59.963177999999999	59.954489000000002	Красного Курсанта	0103000020E61000000100000005000000999EB0C403463E4025B20FB22CFA4D40999EB0C403463E40041DAD6A49FB4D40E129E44A3D4B3E40041DAD6A49FB4D40E129E44A3D4B3E4025B20FB22CFA4D40999EB0C403463E4025B20FB22CFA4D40
74859	2	30.209040000000002	30.213774999999998	59.859881000000001	59.854576000000002	Котина	0103000020E610000001000000050000004C8E3BA583353E4027F911BF62ED4D404C8E3BA583353E40D4B9A29410EE4D40D0B359F5B9363E40D4B9A29410EE4D40D0B359F5B9363E4027F911BF62ED4D404C8E3BA583353E4027F911BF62ED4D40
4054	2	30.313037999999999	30.319739999999999	60.027070999999999	60.011054999999999	Костромской проспект	0103000020E61000000100000005000000BE67244223503E4088BA0F406A014E40BE67244223503E40C3D5011077034E4019390B7BDA513E40C3D5011077034E4019390B7BDA513E4088BA0F406A014E40BE67244223503E4088BA0F406A014E40
13266	2	30.214053	30.235890999999999	59.956417000000002	59.940407	Кораблестроителей	0103000020E61000000100000005000000569C6A2DCC363E40F9F6AE415FF84D40569C6A2DCC363E40522B4CDF6BFA4D40B56B425A633C3E40522B4CDF6BFA4D40B56B425A633C3E40F9F6AE415FF84D40569C6A2DCC363E40F9F6AE415FF84D40
13276	2	30.324248999999998	30.328327999999999	59.941209000000001	59.940609000000002	Конюшенная	0103000020E61000000100000005000000BDC282FB01533E4061A92EE065F84D40BDC282FB01533E40B6D9588979F84D40705CC64D0D543E40B6D9588979F84D40705CC64D0D543E4061A92EE065F84D40BDC282FB01533E4061A92EE065F84D40
15317	2	30.340319999999998	30.353687000000001	59.921137000000002	59.916089999999997	Константина Заслонова	0103000020E61000000100000005000000BA2C26361F573E40A818E76F42F54D40BA2C26361F573E405A1135D1E7F54D403605323B8B5A3E405A1135D1E7F54D403605323B8B5A3E40A818E76F42F54D40BA2C26361F573E40A818E76F42F54D40
13316	2	30.372678000000001	30.401702	59.986874999999998	59.956803999999998	Кондратьевский проспект	0103000020E610000001000000050000004EF04DD3675F3E404B57B08D78FA4D404EF04DD3675F3E40B81E85EB51FE4D40E0BC38F1D5663E40B81E85EB51FE4D40E0BC38F1D5663E404B57B08D78FA4D404EF04DD3675F3E404B57B08D78FA4D40
15302	2	30.313793	30.320809000000001	60.064861000000001	60.044387999999998	Композиторов	0103000020E61000000100000005000000B7B6F0BC54503E40DC2A8881AE054E40B7B6F0BC54503E4097E4805D4D084E403143E38920523E4097E4805D4D084E403143E38920523E40DC2A8881AE054E40B7B6F0BC54503E40DC2A8881AE054E40
16615	2	30.196194999999999	30.208088	60.105893999999999	60.098767000000002	Коммуны	0103000020E6100000010000000500000083A3E4D539323E404776A565A40C4E4083A3E4D539323E40DB6B41EF8D0D4E40A7B0524145353E40DB6B41EF8D0D4E40A7B0524145353E404776A565A40C4E4083A3E4D539323E404776A565A40C4E40
74855	2	30.196194999999999	30.208088	60.105893999999999	60.098767000000002	Коммуны	0103000020E6100000010000000500000083A3E4D539323E404776A565A40C4E4083A3E4D539323E40DB6B41EF8D0D4E40A7B0524145353E40DB6B41EF8D0D4E40A7B0524145353E404776A565A40C4E4083A3E4D539323E404776A565A40C4E40
4745	2	30.235765000000001	30.268159000000001	60.027754999999999	60.000605	Комендантский проспект	0103000020E610000001000000050000009C8A54185B3C3E40679B1BD313004E409C8A54185B3C3E4076A6D0798D034E40C9207711A6443E4076A6D0798D034E40C9207711A6443E40679B1BD313004E409C8A54185B3C3E40679B1BD313004E40
16571	2	30.444569999999999	30.496942000000001	59.748468000000003	59.724628000000003	Колпинское шоссе	0103000020E6100000010000000500000060C8EA56CF713E4009E23C9CC0DC4D4060C8EA56CF713E40200DA7CCCDDF4D4043024697377F3E40200DA7CCCDDF4D4043024697377F3E4009E23C9CC0DC4D4060C8EA56CF713E4009E23C9CC0DC4D40
13331	2	30.439153000000001	30.501424	59.926994999999998	59.912260000000003	Коллонтай	0103000020E61000000100000005000000B7F0BC546C703E4078B988EFC4F44D40B7F0BC546C703E401B47ACC5A7F64D40F46DC1525D803E401B47ACC5A7F64D40F46DC1525D803E4078B988EFC4F44D40B7F0BC546C703E4078B988EFC4F44D40
6681	2	30.355142000000001	30.364664999999999	59.937291999999999	59.937134	Ковенский переулок	0103000020E61000000100000005000000A06F0B96EA5A3E401EFCC401F4F74D40A06F0B96EA5A3E40B6662B2FF9F74D40EFFE78AF5A5D3E40B6662B2FF9F74D40EFFE78AF5A5D3E401EFCC401F4F74D40A06F0B96EA5A3E401EFCC401F4F74D40
6621	2	30.348675	30.388569	59.943962999999997	59.939315999999998	Кирочная улица	0103000020E61000000100000005000000CCEEC9C342593E40054EB6813BF84D40CCEEC9C342593E4028D192C7D3F84D404B3D0B4279633E4028D192C7D3F84D404B3D0B4279633E40054EB6813BF84D40CCEEC9C342593E40054EB6813BF84D40
13304	2	30.348675	30.388569	59.943962999999997	59.939315999999998	Кирочная	0103000020E61000000100000005000000CCEEC9C342593E40054EB6813BF84D40CCEEC9C342593E4028D192C7D3F84D404B3D0B4279633E4028D192C7D3F84D404B3D0B4279633E40054EB6813BF84D40CCEEC9C342593E40054EB6813BF84D40
13339	2	30.409984999999999	30.422211000000001	59.700797000000001	59.699171999999997	Кедринская	0103000020E61000000100000005000000BED9E6C6F4683E40B323D5777ED94D40BED9E6C6F4683E40451152B7B3D94D40EF022505166C3E40451152B7B3D94D40EF022505166C3E40B323D5777ED94D40BED9E6C6F4683E40B323D5777ED94D40
13379	2	30.341075	30.341640999999999	59.937697999999997	59.933424000000002	Караванная	0103000020E61000000100000005000000B37BF2B050573E4098A608707AF74D40B37BF2B050573E4026C3F17C06F84D4005F9D9C875573E4026C3F17C06F84D4005F9D9C875573E4098A608707AF74D40B37BF2B050573E4098A608707AF74D40
2910	2	30.486072	30.523710999999999	59.839683000000001	59.827370000000002	Караваевская улица	0103000020E610000001000000050000005680EF366F7C3E4084D89942E7E94D405680EF366F7C3E40EB0088BB7AEB4D40328E91EC11863E40EB0088BB7AEB4D40328E91EC11863E4084D89942E7E94D405680EF366F7C3E4084D89942E7E94D40
13371	2	30.204567000000001	30.234804	59.913645000000002	59.892198	Канонерский остров	0103000020E6100000010000000500000041D7BE805E343E403FC7478B33F24D4041D7BE805E343E40B493C151F2F44D4051F86C1D1C3C3E40B493C151F2F44D4051F86C1D1C3C3E403FC7478B33F24D4041D7BE805E343E403FC7478B33F24D40
2032	2	30.286214999999999	30.294326999999999	59.920518999999999	59.918719000000003	Канонерская улица	0103000020E61000000100000005000000E89FE06245493E405F9B8D9598F54D40E89FE06245493E405E2C0C91D3F54D406D54A703594B3E405E2C0C91D3F54D406D54A703594B3E405F9B8D9598F54D40E89FE06245493E405F9B8D9598F54D40
3093	2	30.246455000000001	30.248836000000001	59.933447000000001	59.928997000000003	Канареечная улица	0103000020E6100000010000000500000089EFC4AC173F3E40838AAA5FE9F64D4089EFC4AC173F3E4050C6F8307BF74D40451152B7B33F3E4050C6F8307BF74D40451152B7B33F3E40838AAA5FE9F64D4089EFC4AC173F3E40838AAA5FE9F64D40
4083	2	30.205743999999999	30.257487000000001	60.011009999999999	60.004604	Камышовая улица	0103000020E61000000100000005000000255987A3AB343E4024B726DD96004E40255987A3AB343E40E8F692C668014E40292504ABEA413E40E8F692C668014E40292504ABEA413E4024B726DD96004E40255987A3AB343E4024B726DD96004E40
3227	2	30.299230999999999	30.323772999999999	59.981312000000003	59.953128	Каменноостровский проспект	0103000020E610000001000000050000000AF31E679A4C3E4071732A1900FA4D400AF31E679A4C3E401096B1A19BFD4D40EB538EC9E2523E401096B1A19BFD4D40EB538EC9E2523E4071732A1900FA4D400AF31E679A4C3E4071732A1900FA4D40
15310	2	30.282900000000001	30.293284	59.948008999999999	59.939190000000004	Кадетская линия	0103000020E61000000100000005000000D50968226C483E40795DBF6037F84D40D50968226C483E4026A8E15B58F94D40A87004A9144B3E4026A8E15B58F94D40A87004A9144B3E40795DBF6037F84D40D50968226C483E40795DBF6037F84D40
13322	2	30.382594999999998	30.383035	59.950294	59.942357999999999	Кавалергардская	0103000020E61000000100000005000000F59CF4BEF1613E40DE8FDB2F9FF84D40F59CF4BEF1613E40E2CAD93BA3F94D402E39EE940E623E40E2CAD93BA3F94D402E39EE940E623E40DE8FDB2F9FF84D40F59CF4BEF1613E40DE8FDB2F9FF84D40
7399	2	30.446833000000002	30.488703999999998	59.961877000000001	59.952876000000003	Ириновский проспект	0103000020E6100000010000000500000009C6C1A563723E4058923CD7F7F94D4009C6C1A563723E4026E318C91EFB4D40A46C91B41B7D3E4026E318C91EFB4D40A46C91B41B7D3E4058923CD7F7F94D4009C6C1A563723E4058923CD7F7F94D40
3856	2	30.332091999999999	30.343948999999999	59.996037999999999	59.992344000000003	Институтский переулок	0103000020E61000000100000005000000634337FB03553E40E030D12005FF4D40634337FB03553E4060C9552C7EFF4D40ED7DAA0A0D583E4060C9552C7EFF4D40ED7DAA0A0D583E40E030D12005FF4D40634337FB03553E40E030D12005FF4D40
7458	2	30.457317	30.47814	59.980668000000001	59.936971999999997	Индустриальный проспект	0103000020E61000000100000005000000A3E716BA12753E4044A2D0B2EEF74D40A3E716BA12753E40EB1D6E8786FD4D40D1E80E62677A3E40EB1D6E8786FD4D40D1E80E62677A3E4044A2D0B2EEF74D40A3E716BA12753E4044A2D0B2EEF74D40
2719	2	30.430520000000001	30.447399000000001	59.876170000000002	59.870741000000002	Ивановская улица	0103000020E610000001000000050000002046088F366E3E40A724EB7074EF4D402046088F366E3E4040DEAB5626F04D405B43A9BD88723E4040DEAB5626F04D405B43A9BD88723E40A724EB7074EF4D402046088F366E3E40A724EB7074EF4D40
15299	2	30.256274000000001	30.256381999999999	59.857377999999997	59.847611999999998	Зины Портновой	0103000020E61000000100000005000000ABD0402C9B413E403CD9CD8C7EEC4D40ABD0402C9B413E40AA27F38FBEED4D4077483140A2413E40AA27F38FBEED4D4077483140A2413E403CD9CD8C7EEC4D40ABD0402C9B413E403CD9CD8C7EEC4D40
15330	2	30.159939000000001	30.163855000000002	59.841332999999999	59.824452000000001	Здоровцева	0103000020E61000000100000005000000DE5A26C3F1283E40978FA4A487E94D40DE5A26C3F1283E40D505BCCCB0EB4D403D49BA66F2293E40D505BCCCB0EB4D403D49BA66F2293E40978FA4A487E94D40DE5A26C3F1283E40978FA4A487E94D40
1500	2	30.343581	30.371860000000002	59.835898	59.831209000000001	Звёздная улица	0103000020E61000000100000005000000E886A6ECF4573E400892770E65EA4D40E886A6ECF4573E405A65A6B4FEEA4D40C9B08A37325F3E405A65A6B4FEEA4D40C9B08A37325F3E400892770E65EA4D40E886A6ECF4573E400892770E65EA4D40
3004	2	30.292126	30.305789000000001	59.953408000000003	59.951596000000002	Зверинская улица	0103000020E61000000100000005000000B14F00C5C84A3E409180D1E5CDF94D40B14F00C5C84A3E4055DFF94509FA4D40FF791A30484E3E4055DFF94509FA4D40FF791A30484E3E409180D1E5CDF94D40B14F00C5C84A3E409180D1E5CDF94D40
15326	2	30.292126	30.305789000000001	59.953408000000003	59.951596000000002	Зверинская	0103000020E61000000100000005000000B14F00C5C84A3E409180D1E5CDF94D40B14F00C5C84A3E4055DFF94509FA4D40FF791A30484E3E4055DFF94509FA4D40FF791A30484E3E409180D1E5CDF94D40B14F00C5C84A3E409180D1E5CDF94D40
16554	2	30.335245	30.342755	59.923215999999996	59.917009999999998	Звенигородская улица	0103000020E61000000100000005000000C425C79DD2553E406F0D6C9560F54D40C425C79DD2553E406C921FF12BF64D405D8AABCABE573E406C921FF12BF64D405D8AABCABE573E406F0D6C9560F54D40C425C79DD2553E406F0D6C9560F54D40
13337	2	30.393194999999999	30.412248000000002	59.985245999999997	59.967055999999999	Замшина	0103000020E6100000010000000500000062F3716DA8643E4046B3B27DC8FB4D4062F3716DA8643E40E5417A8A1CFE4D4067D7BD1589693E40E5417A8A1CFE4D4067D7BD1589693E4046B3B27DC8FB4D4062F3716DA8643E4046B3B27DC8FB4D40
15329	2	30.259840000000001	30.275354	59.880811999999999	59.869987000000002	Зайцева	0103000020E610000001000000050000005131CEDF84423E40FB78E8BB5BEF4D405131CEDF84423E4051F69672BEF04D40A2D288997D463E4051F69672BEF04D40A2D288997D463E40FB78E8BB5BEF4D405131CEDF84423E40FB78E8BB5BEF4D40
2428	2	30.318104999999999	30.346995	59.927819999999997	59.916564000000001	Загородный проспект	0103000020E61000000100000005000000AFB14B546F513E4071581AF851F54D40AFB14B546F513E40904946CEC2F64D4022E010AAD4583E40904946CEC2F64D4022E010AAD4583E4071581AF851F54D40AFB14B546F513E4071581AF851F54D40
13286	2	30.559563000000001	30.587878	59.742134999999998	59.729967000000002	Заводской проспект	0103000020E61000000100000005000000390D51853F8F3E406214048F6FDD4D40390D51853F8F3E40C51B9947FEDE4D40B309302C7F963E40C51B9947FEDE4D40B309302C7F963E406214048F6FDD4D40390D51853F8F3E406214048F6FDD4D40
13311	2	29.811608	29.825523	59.903905000000002	59.899012999999997	Жоры Антоненко	0103000020E61000000100000005000000062CB98AC5CF3D40E4D6A4DB12F34D40062CB98AC5CF3D406FD8B628B3F34D408718AF7955D33D406FD8B628B3F34D408718AF7955D33D40E4D6A4DB12F34D40062CB98AC5CF3D40E4D6A4DB12F34D40
13360	2	30.303453000000001	30.315114000000001	60.066015	60.062309999999997	Жени Егоровой	0103000020E6100000010000000500000083DF8618AF4D3E405C1B2AC6F9074E4083DF8618AF4D3E40D105F52D73084E400283A44FAB503E40D105F52D73084E400283A44FAB503E405C1B2AC6F9074E4083DF8618AF4D3E405C1B2AC6F9074E40
13353	2	30.123566	30.181695999999999	59.822322	59.775807	Железнодорожная улица	0103000020E61000000100000005000000C5E57805A21F3E400281CEA44DE34D40C5E57805A21F3E400264E8D841E94D4063D009A1832E3E400264E8D841E94D4063D009A1832E3E400281CEA44DE34D40C5E57805A21F3E400281CEA44DE34D40
13280	2	30.123566	30.181695999999999	59.822322	59.775807	Железнодорожная	0103000020E61000000100000005000000C5E57805A21F3E400281CEA44DE34D40C5E57805A21F3E400264E8D841E94D4063D009A1832E3E400264E8D841E94D4063D009A1832E3E400281CEA44DE34D40C5E57805A21F3E400281CEA44DE34D40
15303	2	30.462644000000001	30.487069000000002	59.901229000000001	59.895465999999999	Евдокима Огнева	0103000020E61000000100000005000000CDB051D66F763E40085740A19EF24D40CDB051D66F763E40789ACC785BF34D403BE5D18DB07C3E40789ACC785BF34D403BE5D18DB07C3E40085740A19EF24D40CDB051D66F763E40085740A19EF24D40
13293	2	30.444381	30.500112999999999	59.912734	59.897911999999998	Дыбенко	0103000020E61000000100000005000000BAF605F4C2713E40CD57C9C7EEF24D40BAF605F4C2713E4040F9BB77D4F44D40F04DD36707803E4040F9BB77D4F44D40F04DD36707803E40CD57C9C7EEF24D40BAF605F4C2713E40CD57C9C7EEF24D40
5972	2	30.322227999999999	30.430762999999999	59.846350000000001	59.830281999999997	Дунайский проспект	0103000020E6100000010000000500000001DBC1887D523E408E3A3AAE46EA4D4001DBC1887D523E401C7C613255EC4D40AC53E57B466E3E401C7C613255EC4D40AC53E57B466E3E408E3A3AAE46EA4D4001DBC1887D523E408E3A3AAE46EA4D40
2685	2	30.292376999999998	30.292584000000002	59.913716999999998	59.909202000000001	Дровяная улица	0103000020E61000000100000005000000431A1538D94A3E4099BA2BBB60F44D40431A1538D94A3E404D66BCADF4F44D403755F7C8E64A3E404D66BCADF4F44D403755F7C8E64A3E4099BA2BBB60F44D40431A1538D94A3E4099BA2BBB60F44D40
3977	2	30.323962000000002	30.340589999999999	60.014747	60.012728000000003	Дрезденская улица	0103000020E610000001000000050000009225732CEF523E402BDF3312A1014E409225732CEF523E40685BCD3AE3014E403A58FFE730573E40685BCD3AE3014E403A58FFE730573E402BDF3312A1014E409225732CEF523E402BDF3312A1014E40
13365	2	30.683881	30.692990000000002	59.779254000000002	59.772790000000001	Дорожная	0103000020E61000000100000005000000145B41D312AF3E40825660C8EAE24D40145B41D312AF3E407BA35698BEE34D407E74EACA67B13E407BA35698BEE34D407E74EACA67B13E40825660C8EAE24D40145B41D312AF3E40825660C8EAE24D40
13261	2	30.165239	30.167556000000001	59.844009	59.824308000000002	Добровольцев	0103000020E610000001000000050000001406651A4D2A3E4064EAAEEC82E94D401406651A4D2A3E40CC43A67C08EC4D40A33F34F3E42A3E40CC43A67C08EC4D40A33F34F3E42A3E4064EAAEEC82E94D401406651A4D2A3E4064EAAEEC82E94D40
13363	2	30.371518999999999	30.426379000000001	59.851905000000002	59.844650999999999	Димитрова	0103000020E61000000100000005000000B6D782DE1B5F3E4050C422861DEC4D40B6D782DE1B5F3E40422619390BED4D4081B3942C276D3E40422619390BED4D4081B3942C276D3E4050C422861DEC4D40B6D782DE1B5F3E4050C422861DEC4D40
16340	2	30.393536000000001	30.417611000000001	59.742047999999997	59.740710999999997	Детскосельский бульвар	0103000020E6100000010000000500000075CC79C6BE643E40CB64389ECFDE4D4075CC79C6BE643E40F607CA6DFBDE4D402A73F38DE86A3E40F607CA6DFBDE4D402A73F38DE86A3E40CB64389ECFDE4D4075CC79C6BE643E40CB64389ECFDE4D40
13301	2	30.379235000000001	30.392925999999999	60.050206000000003	60.033360000000002	Демьяна Бедного	0103000020E61000000100000005000000A27F828B15613E404E7FF62345044E40A27F828B15613E40100874266D064E4083BF5FCC96643E40100874266D064E4083BF5FCC96643E404E7FF62345044E40A27F828B15613E404E7FF62345044E40
15293	2	30.281804000000001	30.308295000000001	59.929231000000001	59.923152999999999	Декабристов	0103000020E61000000100000005000000CAE1934E24483E40261AA4E029F64D40CAE1934E24483E40F6B6990AF1F64D403485CE6BEC4E3E40F6B6990AF1F64D403485CE6BEC4E3E40261AA4E029F64D40CAE1934E24483E40261AA4E029F64D40
6680	2	30.377635999999999	30.388235999999999	59.940055000000001	59.937593999999997	Дегтярный переулок	0103000020E61000000100000005000000D1CABDC0AC603E408176871403F84D40D1CABDC0AC603E407CB8E4B853F84D403E213B6F63633E407CB8E4B853F84D403E213B6F63633E408176871403F84D40D1CABDC0AC603E408176871403F84D40
16539	2	30.421339	30.436754000000001	59.951362000000003	59.949758000000003	Дегтярева	0103000020E61000000100000005000000838769DFDC6B3E40A48E8EAB91F94D40838769DFDC6B3E401E54E23AC6F94D40AE65321CCF6F3E401E54E23AC6F94D40AE65321CCF6F3E40A48E8EAB91F94D40838769DFDC6B3E40A48E8EAB91F94D40
16859	2	30.309760000000001	30.311996000000001	59.940004999999999	59.938518000000002	Дворцовый проезд	0103000020E61000000100000005000000E59B6D6E4C4F3E408A5A9A5B21F84D40E59B6D6E4C4F3E40CA89761552F84D409A7B48F8DE4F3E40CA89761552F84D409A7B48F8DE4F3E408A5A9A5B21F84D40E59B6D6E4C4F3E408A5A9A5B21F84D40
6236	2	30.237750999999999	30.268545	59.85134	59.835017000000001	Дачный проспект	0103000020E610000001000000050000005F97E13FDD3C3E40514D49D6E1EA4D405F97E13FDD3C3E4069E388B5F8EC4D401B81785DBF443E4069E388B5F8EC4D401B81785DBF443E40514D49D6E1EA4D405F97E13FDD3C3E40514D49D6E1EA4D40
13370	2	30.358331	30.363641000000001	59.941586999999998	59.941515000000003	Гродненский переулок	0103000020E610000001000000050000009A249694BB5B3E40C3D8429083F84D409A249694BB5B3E405CAB3DEC85F84D40187C9A93175D3E405CAB3DEC85F84D40187C9A93175D3E40C3D8429083F84D409A249694BB5B3E40C3D8429083F84D40
6714	2	30.364170999999999	30.370781999999998	59.939991999999997	59.933157999999999	Греческий проспект	0103000020E61000000100000005000000D026874F3A5D3E401900AAB871F74D40D026874F3A5D3E40354069A851F84D400AF2B391EB5E3E40354069A851F84D400AF2B391EB5E3E401900AAB871F74D40D026874F3A5D3E401900AAB871F74D40
4954	2	30.379145000000001	30.428418000000001	60.043080000000003	59.994463000000003	Гражданский проспект	0103000020E6100000010000000500000022718FA50F613E40810A47904AFF4D4022718FA50F613E404C8E3BA583054E408A0453CDAC6D3E404C8E3BA583054E408A0453CDAC6D3E40810A47904AFF4D4022718FA50F613E40810A47904AFF4D40
6408	2	30.310137000000001	30.331885	59.936371999999999	59.921840000000003	Гороховая улица	0103000020E6100000010000000500000091477023654F3E40841266DAFEF54D4091477023654F3E40EF71A609DBF74D407008556AF6543E40EF71A609DBF74D407008556AF6543E40841266DAFEF54D4091477023654F3E40841266DAFEF54D40
15465	2	30.292835	30.298504000000001	60.021473999999998	60.018433999999999	Горная улица	0103000020E61000000100000005000000C91F0C3CF74A3E403691990B5C024E40C91F0C3CF74A3E406EDBF7A8BF024E40A6B915C26A4C3E406EDBF7A8BF024E40A6B915C26A4C3E403691990B5C024E40C91F0C3CF74A3E403691990B5C024E40
6809	2	30.362949	30.370260999999999	59.930394	59.92754	Гончарная улица	0103000020E61000000100000005000000AC1DC539EA5C3E40ADDD76A1B9F64D40AC1DC539EA5C3E4083328D2617F74D40F8FBC56CC95E3E4083328D2617F74D40F8FBC56CC95E3E40ADDD76A1B9F64D40AC1DC539EA5C3E40ADDD76A1B9F64D40
15314	2	30.39836	30.407775000000001	59.983279000000003	59.9816	Герасимовская	0103000020E61000000100000005000000D908C4EBFA653E4076E09C11A5FD4D40D908C4EBFA653E40FBEB1516DCFD4D405C2041F163683E40FBEB1516DCFD4D405C2041F163683E4076E09C11A5FD4D40D908C4EBFA653E4076E09C11A5FD4D40
3999	2	30.323018999999999	30.333044000000001	60.016474000000002	60.015089000000003	Гданьская улица	0103000020E6100000010000000500000093FC885FB1523E40C2C3B46FEE014E4093FC885FB1523E40FE9DEDD11B024E400821205F42553E40FE9DEDD11B024E400821205F42553E40C2C3B46FEE014E4093FC885FB1523E40C2C3B46FEE014E40
67063	2	30.321149999999999	30.337895	59.858376	59.858083000000001	Гастелло	0103000020E61000000100000005000000431CEBE236523E407520EBA9D5ED4D40431CEBE236523E40EDD5C743DFED4D405F7B664980563E40EDD5C743DFED4D405F7B664980563E407520EBA9D5ED4D40431CEBE236523E407520EBA9D5ED4D40
4053	2	30.253318	30.258707999999999	60.007015000000003	59.990467000000002	Гаккелевская улица	0103000020E61000000100000005000000F67CCD72D9403E403562669FC7FE4D40F67CCD72D9403E406DCA15DEE5004E40AC36FFAF3A423E406DCA15DEE5004E40AC36FFAF3A423E403562669FC7FE4D40F67CCD72D9403E403562669FC7FE4D40
16658	2	30.341146999999999	30.343321	59.948830000000001	59.942511000000003	Гагаринская	0103000020E61000000100000005000000E620E86855573E40658F5033A4F84D40E620E86855573E405ABBED4273F94D40AF0793E2E3573E405ABBED4273F94D40AF0793E2E3573E40658F5033A4F84D40E620E86855573E40658F5033A4F84D40
3107	2	30.236968999999998	30.242547999999999	59.939753000000003	59.927166	Гаванская улица	0103000020E61000000100000005000000732A1900AA3C3E4048FB1F60ADF64D40732A1900AA3C3E40B1A888D349F84D40D0B52FA0173E3E40B1A888D349F84D40D0B52FA0173E3E4048FB1F60ADF64D40732A1900AA3C3E4048FB1F60ADF64D40
3510	2	30.29898	30.302033999999999	59.975639000000001	59.971162999999997	Вяземский переулок	0103000020E6100000010000000500000078280AF4894C3E40E90AB6114FFC4D4078280AF4894C3E40E0D91EBDE1FC4D40B247A819524D3E40E0D91EBDE1FC4D40B247A819524D3E40E90AB6114FFC4D4078280AF4894C3E40E90AB6114FFC4D40
3645	2	30.343634999999999	30.350884000000001	59.965313000000002	59.964565999999998	Выборгская улица	0103000020E61000000100000005000000CEC29E76F8573E40B16A10E676FB4D40CEC29E76F8573E40ABB35A608FFB4D408EB0A888D3593E40ABB35A608FFB4D408EB0A888D3593E40B16A10E676FB4D40CEC29E76F8573E40B16A10E676FB4D40
5527	2	30.342556999999999	30.350345000000001	59.919851999999999	59.908259000000001	Воронежская улица	0103000020E610000001000000050000001004C8D0B1573E401AA6B6D441F44D401004C8D0B1573E408194D8B5BDF54D402F51BD35B0593E408194D8B5BDF54D402F51BD35B0593E401AA6B6D441F44D401004C8D0B1573E401AA6B6D441F44D40
16633	2	30.035702000000001	30.309705999999998	59.841589999999997	59.744464999999998	Волхонское шоссе	0103000020E61000000100000005000000DC662AC423093E4021020EA14ADF4D40DC662AC423093E4000529B38B9EB4D40FE5F75E4484F3E4000529B38B9EB4D40FE5F75E4484F3E4021020EA14ADF4D40DC662AC423093E4021020EA14ADF4D40
15298	2	30.197201	30.215913	60.104325000000003	60.094254999999997	Володарского	0103000020E610000001000000050000000EBDC5C37B323E40033E3F8C100C4E400EBDC5C37B323E40DE9387855A0D4E4000C8091346373E40DE9387855A0D4E4000C8091346373E40033E3F8C100C4E400EBDC5C37B323E40033E3F8C100C4E40
5544	2	30.354927	30.363973000000001	59.901634999999999	59.879610999999997	Волковский проспект	0103000020E61000000100000005000000A777F17EDC5A3E40D619DF1797F04D40A777F17EDC5A3E40E8F692C668F34D4084A0A3552D5D3E40E8F692C668F34D4084A0A3552D5D3E40D619DF1797F04D40A777F17EDC5A3E40D619DF1797F04D40
15136	2	30.346995	30.347767000000001	59.928902000000001	59.927739000000003	Владимирская	0103000020E6100000010000000500000022E010AAD4583E40A41CCC26C0F64D4022E010AAD4583E403198BF42E6F64D40C7A0134207593E403198BF42E6F64D40C7A0134207593E40A41CCC26C0F64D4022E010AAD4583E40A41CCC26C0F64D40
1345	2	30.341532999999998	30.379505000000002	59.894807	59.821390000000001	Витебский проспект	0103000020E610000001000000050000003881E9B46E573E4077A1B94E23E94D403881E9B46E573E40AE9D280989F24D4022AB5B3D27613E40AE9D280989F24D4022AB5B3D27613E4077A1B94E23E94D403881E9B46E573E4077A1B94E23E94D40
67092	2	30.276028	30.283268	59.921745999999999	59.918765	Витебская	0103000020E61000000100000005000000C1C760C5A9463E40CFDA6D179AF54D40C1C760C5A9463E40029CDEC5FBF54D40DA006C4084483E40029CDEC5FBF54D40DA006C4084483E40CFDA6D179AF54D40C1C760C5A9463E40CFDA6D179AF54D40
1804	2	30.286673	30.289044000000001	59.815106	59.811962000000001	Взлётная улица	0103000020E610000001000000050000006EA5D76663493E4021CCED5EEEE74D406EA5D76663493E40FE62B66455E84D40E31A9FC9FE493E40FE62B66455E84D40E31A9FC9FE493E4021CCED5EEEE74D406EA5D76663493E4021CCED5EEEE74D40
7178	2	30.404917999999999	30.407712	59.935803999999997	59.935519999999997	Весенняя улица	0103000020E61000000100000005000000CD8FBFB4A8673E4080608E1EBFF74D40CD8FBFB4A8673E40A5BBEB6CC8F74D40CF2F4AD05F683E40A5BBEB6CC8F74D40CF2F4AD05F683E4080608E1EBFF74D40CD8FBFB4A8673E4080608E1EBFF74D40
2291	2	30.323108999999999	30.329819000000001	59.918484999999997	59.912278000000001	Верейская улица	0103000020E61000000100000005000000130B7C45B7523E401E6E8786C5F44D40130B7C45B7523E40EB6E9EEA90F54D4074999A046F543E40EB6E9EEA90F54D4074999A046F543E401E6E8786C5F44D40130B7C45B7523E401E6E8786C5F44D40
16673	2	30.569588	30.574763000000001	59.730021000000001	59.728138999999999	Веревская	0103000020E61000000100000005000000AD31E884D0913E4098F8A3A833DD4D40AD31E884D0913E405532005471DD4D406BF3FFAA23933E405532005471DD4D406BF3FFAA23933E4098F8A3A833DD4D40AD31E884D0913E4098F8A3A833DD4D40
3044	2	30.299088000000001	30.3079	59.957683000000003	59.954884999999997	Введенская улица	0103000020E6100000010000000500000045A0FA07914C3E407138F3AB39FA4D4045A0FA07914C3E40B477465B95FA4D403B70CE88D24E3E40B477465B95FA4D403B70CE88D24E3E407138F3AB39FA4D4045A0FA07914C3E407138F3AB39FA4D40
1111	2	30.312311000000001	30.315356000000001	59.884261000000002	59.841324	Варшавская улица	0103000020E610000001000000050000005A2E1B9DF34F3E4082AB3C81B0EB4D405A2E1B9DF34F3E406B10E6762FF14D40EE98BA2BBB503E406B10E6762FF14D40EE98BA2BBB503E4082AB3C81B0EB4D405A2E1B9DF34F3E4082AB3C81B0EB4D40
15306	2	30.312311000000001	30.315356000000001	59.884261000000002	59.841324	Варшавская	0103000020E610000001000000050000005A2E1B9DF34F3E4082AB3C81B0EB4D405A2E1B9DF34F3E406B10E6762FF14D40EE98BA2BBB503E406B10E6762FF14D40EE98BA2BBB503E4082AB3C81B0EB4D405A2E1B9DF34F3E4082AB3C81B0EB4D40
5561	2	30.357324999999999	30.424250000000001	59.893954000000001	59.828133999999999	Бухарестская улица	0103000020E610000001000000050000000F0BB5A6795B3E40535A7F4B00EA4D400F0BB5A6795B3E406F10AD156DF24D40F853E3A59B6C3E406F10AD156DF24D40F853E3A59B6C3E40535A7F4B00EA4D400F0BB5A6795B3E40535A7F4B00EA4D40
13320	2	30.357324999999999	30.424250000000001	59.893954000000001	59.828133999999999	Бухарестская	0103000020E610000001000000050000000F0BB5A6795B3E40535A7F4B00EA4D400F0BB5A6795B3E406F10AD156DF24D40F853E3A59B6C3E406F10AD156DF24D40F853E3A59B6C3E40535A7F4B00EA4D400F0BB5A6795B3E40535A7F4B00EA4D40
2823	2	30.267458000000001	30.273719	59.908853999999998	59.903142000000003	Бумажная улица	0103000020E61000000100000005000000B70DA32078443E4070D234289AF34D40B70DA32078443E405D6BEF5355F44D40384BC97212463E405D6BEF5355F44D40384BC97212463E4070D234289AF34D40B70DA32078443E4070D234289AF34D40
5606	2	30.364808	30.409552999999999	59.875528000000003	59.825817999999998	Будапештская улица	0103000020E61000000100000005000000B5519D0E645D3E405C397B67B4E94D40B5519D0E645D3E40BC5D2F4D11F04D408BFA2477D8683E40BC5D2F4D11F04D408BFA2477D8683E405C397B67B4E94D40B5519D0E645D3E405C397B67B4E94D40
13273	2	30.364808	30.409552999999999	59.875528000000003	59.825817999999998	Будапештская	0103000020E61000000100000005000000B5519D0E645D3E405C397B67B4E94D40B5519D0E645D3E40BC5D2F4D11F04D408BFA2477D8683E40BC5D2F4D11F04D408BFA2477D8683E405C397B67B4E94D40B5519D0E645D3E405C397B67B4E94D40
5725	2	30.411708999999998	30.427187	59.988202999999999	59.985245999999997	Брюсовская улица	0103000020E610000001000000050000000778D2C265693E40E5417A8A1CFE4D400778D2C265693E409067976F7DFE4D40BF4692205C6D3E409067976F7DFE4D40BF4692205C6D3E40E5417A8A1CFE4D400778D2C265693E40E5417A8A1CFE4D40
15320	2	30.319604999999999	30.326118000000001	59.917186000000001	59.910947	Бронницкая	0103000020E6100000010000000500000059A31EA2D1513E40D5B14AE999F44D4059A31EA2D1513E40AE2CD15966F54D400EA320787C533E40AE2CD15966F54D400EA320787C533E40D5B14AE999F44D4059A31EA2D1513E40D5B14AE999F44D40
7864	2	30.193867999999998	30.199860000000001	59.856673000000001	59.846775000000001	Брестский бульвар	0103000020E61000000100000005000000ADBD4F55A1313E4003098A1F63EC4D40ADBD4F55A1313E40E02EFB75A7ED4D4050C763062A333E40E02EFB75A7ED4D4050C763062A333E4003098A1F63EC4D40ADBD4F55A1313E4003098A1F63EC4D40
15308	2	29.81353	29.866638999999999	59.880648999999998	59.868341999999998	Ботаническая	0103000020E610000001000000050000009C50888043D03D4022DFA5D425EF4D409C50888043D03D40A7203F1BB9F04D402A70B20DDCDD3D40A7203F1BB9F04D402A70B20DDCDD3D4022DFA5D425EF4D409C50888043D03D4022DFA5D425EF4D40
67083	2	30.330466000000001	30.335837999999999	59.925975999999999	59.923450000000003	Бородинская	0103000020E61000000100000005000000A070766B99543E40E0BE0E9C33F64D40A070766B99543E40C170AE6186F64D4009C1AA7AF9553E40C170AE6186F64D4009C1AA7AF9553E40E0BE0E9C33F64D40A070766B99543E40E0BE0E9C33F64D40
16664	2	30.286771999999999	30.314133999999999	59.967695999999997	59.949776	Большой проспект П.С.	0103000020E610000001000000050000009468C9E369493E404A438D4292F94D409468C9E369493E40293C6876DDFB4D40C98FF8156B503E40293C6876DDFB4D40C98FF8156B503E404A438D4292F94D409468C9E369493E404A438D4292F94D40
16854	2	30.286771999999999	30.314133999999999	59.967695999999997	59.949776	Большой проспект П.С.	0103000020E610000001000000050000009468C9E369493E404A438D4292F94D409468C9E369493E40293C6876DDFB4D40C98FF8156B503E40293C6876DDFB4D40C98FF8156B503E404A438D4292F94D409468C9E369493E404A438D4292F94D40
13367	2	30.239179	30.290778	59.941339999999997	59.926233000000003	Большой проспект В.О	0103000020E61000000100000005000000D6E3BED53A3D3E40EDBC8DCD8EF64D40D6E3BED53A3D3E40543541D47DF84D407365506D704A3E40543541D47DF84D407365506D704A3E40EDBC8DCD8EF64D40D6E3BED53A3D3E40EDBC8DCD8EF64D40
3689	2	30.329809999999998	30.34553	59.998018000000002	59.955156000000002	Большой Сампсониевский проспект	0103000020E61000000100000005000000CDE49B6D6E543E40024A438D42FA4D40CDE49B6D6E543E40E068C70DBFFF4D4071C971A774583E40E068C70DBFFF4D4071C971A774583E40024A438D42FA4D40CDE49B6D6E543E40024A438D42FA4D40
7064	2	30.409320000000001	30.411072000000001	59.958998000000001	59.943719000000002	Большеохтинский проспект	0103000020E6100000010000000500000046990D32C9683E4092CEC0C8CBF84D4046990D32C9683E40F7764B72C0FA4D40234DBC033C693E40F7764B72C0FA4D40234DBC033C693E4092CEC0C8CBF84D4046990D32C9683E4092CEC0C8CBF84D40
3079	2	30.296177	30.312922	59.964449000000002	59.954124	Большая Пушкарская улица	0103000020E61000000100000005000000D0D38041D24B3E40132A38BC20FA4D40D0D38041D24B3E4078D4981073FB4D40EC32FCA71B503E4078D4981073FB4D40EC32FCA71B503E40132A38BC20FA4D40D0D38041D24B3E40132A38BC20FA4D40
3177	2	30.321608000000001	30.330978000000002	59.960538999999997	59.957683000000003	Большая Посадская улица	0103000020E61000000100000005000000C921E2E654523E40B477465B95FA4D40C921E2E654523E402AC423F1F2FA4D400CB265F9BA543E402AC423F1F2FA4D400CB265F9BA543E40B477465B95FA4D40C921E2E654523E40B477465B95FA4D40
2312	2	30.294074999999999	30.317737000000001	59.938111999999997	59.928086	Большая Морская улица	0103000020E610000001000000050000003A92CB7F484B3E400FF0A485CBF64D403A92CB7F484B3E4019FED30D14F84D40AABA473657513E4019FED30D14F84D40AABA473657513E400FF0A485CBF64D403A92CB7F484B3E400FF0A485CBF64D40
13251	2	30.294074999999999	30.317737000000001	59.938111999999997	59.928086	Большая Морская	0103000020E610000001000000050000003A92CB7F484B3E400FF0A485CBF64D403A92CB7F484B3E4019FED30D14F84D40AABA473657513E4019FED30D14F84D40AABA473657513E400FF0A485CBF64D403A92CB7F484B3E400FF0A485CBF64D40
3140	2	30.311654999999998	30.330044000000001	59.963742000000003	59.960228000000001	Большая Монетная улица	0103000020E6100000010000000500000087A2409FC84F3E400C5A48C0E8FA4D4087A2409FC84F3E400DE4D9E55BFB4D40B43D7AC37D543E400DE4D9E55BFB4D40B43D7AC37D543E400C5A48C0E8FA4D4087A2409FC84F3E400C5A48C0E8FA4D40
3448	2	30.281237999999998	30.296042	59.966524999999997	59.959183000000003	Большая Зеленина улица	0103000020E610000001000000050000007764AC36FF473E4089F02F82C6FA4D407764AC36FF473E4019E25817B7FB4D40103E9468C94B3E4019E25817B7FB4D40103E9468C94B3E4089F02F82C6FA4D407764AC36FF473E4089F02F82C6FA4D40
3758	2	30.351199000000001	30.357748000000001	60.003948000000001	59.996299	Болотная улица	0103000020E610000001000000050000004E637B2DE8593E40CD04C3B986FF4D404E637B2DE8593E403B71395E81004E409C35785F955B3E403B71395E81004E409C35785F955B3E40CD04C3B986FF4D404E637B2DE8593E40CD04C3B986FF4D40
2194	2	30.199877999999998	30.325157000000001	60.008077	59.998441	Богатырский проспект	0103000020E610000001000000050000009C3061342B333E4026FE28EACCFF4D409C3061342B333E40C66CC9AA08014E40C310397D3D533E40C66CC9AA08014E40C310397D3D533E4026FE28EACCFF4D409C3061342B333E4026FE28EACCFF4D40
1099	2	30.298549000000001	30.352394	59.878739000000003	59.875425	Благодатная улица	0103000020E61000000100000005000000E6400FB56D4C3E40E78C28ED0DF04D40E6400FB56D4C3E40215C01857AF04D407F4E417E365A3E40215C01857AF04D407F4E417E365A3E40E78C28ED0DF04D40E6400FB56D4C3E40E78C28ED0DF04D40
13313	2	30.298549000000001	30.352394	59.878739000000003	59.875425	Благодатная 	0103000020E61000000100000005000000E6400FB56D4C3E40E78C28ED0DF04D40E6400FB56D4C3E40215C01857AF04D407F4E417E365A3E40215C01857AF04D407F4E417E365A3E40E78C28ED0DF04D40E6400FB56D4C3E40E78C28ED0DF04D40
13295	2	30.298549000000001	30.352394	59.878739000000003	59.875425	Благодатная	0103000020E61000000100000005000000E6400FB56D4C3E40E78C28ED0DF04D40E6400FB56D4C3E40215C01857AF04D407F4E417E365A3E40215C01857AF04D407F4E417E365A3E40E78C28ED0DF04D40E6400FB56D4C3E40E78C28ED0DF04D40
15301	2	30.146014999999998	30.269973	59.992415999999999	59.988810999999998	Берёзовая	0103000020E61000000100000005000000B6B9313D61253E406876DD5B91FE4D40B6B9313D61253E407903CC7C07FF4D4092CD55F31C453E407903CC7C07FF4D4092CD55F31C453E406876DD5B91FE4D40B6B9313D61253E406876DD5B91FE4D40
13255	2	30.231121000000002	30.248072000000001	59.947068000000002	59.935146000000003	Беринга	0103000020E61000000100000005000000386BF0BE2A3B3E401C7E37DDB2F74D40386BF0BE2A3B3E40488B338639F94D40A60D87A5813F3E40488B338639F94D40A60D87A5813F3E401C7E37DDB2F74D40386BF0BE2A3B3E401C7E37DDB2F74D40
7279	2	30.500256	30.502538000000001	59.944828000000001	59.935119	Белорусская улица	0103000020E61000000100000005000000B6A0F7C610803E40226FB9FAB1F74D40B6A0F7C610803E402C2CB81FF0F84D404CFF9254A6803E402C2CB81FF0F84D404CFF9254A6803E40226FB9FAB1F74D40B6A0F7C610803E40226FB9FAB1F74D40
13259	2	30.500256	30.502538000000001	59.944828000000001	59.935119	Белорусская	0103000020E61000000100000005000000B6A0F7C610803E40226FB9FAB1F74D40B6A0F7C610803E402C2CB81FF0F84D404CFF9254A6803E402C2CB81FF0F84D404CFF9254A6803E40226FB9FAB1F74D40B6A0F7C610803E40226FB9FAB1F74D40
5795	2	30.352394	30.371518999999999	59.878739000000003	59.844650999999999	Белградская улица	0103000020E610000001000000050000007F4E417E365A3E4050C422861DEC4D407F4E417E365A3E40215C01857AF04D40B6D782DE1B5F3E40215C01857AF04D40B6D782DE1B5F3E4050C422861DEC4D407F4E417E365A3E4050C422861DEC4D40
13333	2	30.275919999999999	30.296158999999999	59.901882999999998	59.896540000000002	Балтийская	0103000020E61000000100000005000000F44F70B1A2463E4026C79DD2C1F24D40F44F70B1A2463E40C0E8F2E670F34D40836A8313D14B3E40C0E8F2E670F34D40836A8313D14B3E4026C79DD2C1F24D40F44F70B1A2463E4026C79DD2C1F24D40
4714	2	30.274474000000001	30.281103000000002	60.016865000000003	59.993653000000002	Байконурская улица	0103000020E61000000100000005000000319A95ED43463E404149810530FF4D40319A95ED43463E4039B9DFA128024E40B8CEBF5DF6473E4039B9DFA128024E40B8CEBF5DF6473E404149810530FF4D40319A95ED43463E404149810530FF4D40
4613	2	30.277419999999999	30.299375000000001	59.997306999999999	59.996236000000003	Аэродромная улица	0103000020E610000001000000050000009E4143FF04473E40878C47A984FF4D409E4143FF04473E4033897AC1A7FF4D40713D0AD7A34C3E4033897AC1A7FF4D40713D0AD7A34C3E40878C47A984FF4D409E4143FF04473E40878C47A984FF4D40
13325	2	30.277419999999999	30.299375000000001	59.997306999999999	59.996236000000003	Аэродромная	0103000020E610000001000000050000009E4143FF04473E40878C47A984FF4D409E4143FF04473E4033897AC1A7FF4D40713D0AD7A34C3E4033897AC1A7FF4D40713D0AD7A34C3E40878C47A984FF4D409E4143FF04473E40878C47A984FF4D40
16576	2	30.318473000000001	30.330735000000001	60.048391000000002	60.047074000000002	Асафьева	0103000020E61000000100000005000000B5A84F7287513E40F73E558506064E40B5A84F7287513E40DB3521AD31064E407FA4880CAB543E40DB3521AD31064E407FA4880CAB543E40F73E558506064E40B5A84F7287513E40F73E558506064E40
15146	2	30.350435000000001	30.355376	59.941744999999997	59.941678000000003	Артиллерийская	0103000020E61000000100000005000000AF5FB01BB6593E406DAE9AE788F84D40AF5FB01BB6593E40F415A4198BF84D4086C8E9EBF95A3E40F415A4198BF84D4086C8E9EBF95A3E406DAE9AE788F84D40AF5FB01BB6593E406DAE9AE788F84D40
5515	2	30.349976999999999	30.374573000000002	59.954737000000002	59.952705000000002	Арсенальная набережная	0103000020E61000000100000005000000295AB91798593E402BDEC83CF2F94D40295AB91798593E40FDA36FD234FA4D40F1F62004E45F3E40FDA36FD234FA4D40F1F62004E45F3E402BDEC83CF2F94D40295AB91798593E402BDEC83CF2F94D40
13326	2	30.399995000000001	30.409193999999999	59.973833999999997	59.971541999999999	Антоновская	0103000020E610000001000000050000004390831266663E406058FE7C5BFC4D404390831266663E40CEDDAE97A6FC4D402CB81FF0C0683E40CEDDAE97A6FC4D402CB81FF0C0683E406058FE7C5BFC4D404390831266663E406058FE7C5BFC4D40
15294	2	30.366865000000001	30.370117	59.900475	59.898941000000001	Андреевская	0103000020E610000001000000050000000B0C59DDEA5D3E404B04AA7F10F34D400B0C59DDEA5D3E40CCEEC9C342F34D4092B1DAFCBF5E3E40CCEEC9C342F34D4092B1DAFCBF5E3E404B04AA7F10F34D400B0C59DDEA5D3E404B04AA7F10F34D40
5901	2	30.367656	30.395809	59.854947000000003	59.850788999999999	Альпийский переулок	0103000020E610000001000000050000009D2D20B41E5E3E40F56569A7E6EC4D409D2D20B41E5E3E401B683EE76EED4D40647616BD53653E401B683EE76EED4D40647616BD53653E40F56569A7E6EC4D409D2D20B41E5E3E40F56569A7E6EC4D40
1432	2	30.321598999999999	30.337814000000002	59.849364999999999	59.849134999999997	Алтайская улица	0103000020E61000000100000005000000226DE34F54523E40C971A774B0EC4D40226DE34F54523E40FBAE08FEB7EC4D40862172FA7A563E40FBAE08FEB7EC4D40862172FA7A563E40C971A774B0EC4D40226DE34F54523E40C971A774B0EC4D40
16546	2	30.165966000000001	30.173081	59.991951999999998	59.991264000000001	Александровская	0103000020E61000000100000005000000793F6EBF7C2A3E40E0D91EBDE1FE4D40793F6EBF7C2A3E40D4997B48F8FE4D40198F52094F2C3E40D4997B48F8FE4D40198F52094F2C3E40E0D91EBDE1FE4D40793F6EBF7C2A3E40E0D91EBDE1FE4D40
2373	2	30.300884	30.309984	59.939852000000002	59.936453	Адмиралтейская набережная	0103000020E61000000100000005000000C1E3DBBB064D3E40DC9E20B1DDF74D40C1E3DBBB064D3E40448A01124DF84D408448861C5B4F3E40448A01124DF84D408448861C5B4F3E40DC9E20B1DDF74D40C1E3DBBB064D3E40DC9E20B1DDF74D40
6093	2	30.255600000000001	30.279917999999999	59.879033	59.864963000000003	Автовская улица	0103000020E610000001000000050000008CDB68006F413E4002A08A1BB7EE4D408CDB68006F413E40698D412784F04D40CD8FBFB4A8473E40698D412784F04D40CD8FBFB4A8473E4002A08A1BB7EE4D408CDB68006F413E4002A08A1BB7EE4D40
7239	2	30.179881000000002	30.185361	59.842368	59.823787000000003	Авангардная улица	0103000020E61000000100000005000000FA2B64AE0C2E3E405BEF37DA71E94D40FA2B64AE0C2E3E403599F1B6D2EB4D4030F488D1732F3E403599F1B6D2EB4D4030F488D1732F3E405BEF37DA71E94D40FA2B64AE0C2E3E405BEF37DA71E94D40
6725	2	30.369965000000001	30.379873	59.938688999999997	59.935665	9-я Советская улица	0103000020E6100000010000000500000026AAB706B65E3E408481E7DEC3F74D4026AAB706B65E3E40B60E0EF626F84D4027A25F5B3F613E40B60E0EF626F84D4027A25F5B3F613E408481E7DEC3F74D4026AAB706B65E3E408481E7DEC3F74D40
6758	2	30.369515	30.383538000000001	59.938009000000001	59.932896999999997	8-я Советская улица	0103000020E61000000100000005000000A661F888985E3E40ACC43C2B69F74D40A661F888985E3E40452DCDAD10F84D40F4C5DE8B2F623E40452DCDAD10F84D40F4C5DE8B2F623E40ACC43C2B69F74D40A661F888985E3E40ACC43C2B69F74D40
2540	2	30.297488999999999	30.307531999999998	59.914406999999997	59.914304000000001	8-я Красноармейская улица	0103000020E6100000010000000500000074EB353D284C3E400E4DD9E907F54D4074EB353D284C3E40E21DE0490BF54D403579CA6ABA4E3E40E21DE0490BF54D403579CA6ABA4E3E400E4DD9E907F54D4074EB353D284C3E400E4DD9E907F54D40
15311	2	30.271132000000001	30.286493	59.949523999999997	59.936269000000003	7-я линия ВО	0103000020E610000001000000050000002AE620E868453E401BA19FA9D7F74D402AE620E868453E4030629F008AF94D406E88F19A57493E4030629F008AF94D406E88F19A57493E401BA19FA9D7F74D402AE620E868453E401BA19FA9D7F74D40
15966	2	30.271132000000001	30.286493	59.949523999999997	59.936269000000003	7-я линия В.О.	0103000020E610000001000000050000002AE620E868453E401BA19FA9D7F74D402AE620E868453E4030629F008AF94D406E88F19A57493E4030629F008AF94D406E88F19A57493E401BA19FA9D7F74D402AE620E868453E401BA19FA9D7F74D40
67071	2	30.307442000000002	30.318338000000001	59.911619999999999	59.911498000000002	7-я Красноармейская 	0103000020E61000000100000005000000B66AD784B44E3E40492F6AF7ABF44D40B66AD784B44E3E409430D3F6AFF44D40F51263997E513E409430D3F6AFF44D40F51263997E513E40492F6AF7ABF44D40B66AD784B44E3E40492F6AF7ABF44D40
6760	2	30.367799999999999	30.377106000000001	59.936363	59.933140000000002	6-я Советская улица	0103000020E6100000010000000500000003780B24285E3E40734BAB2171F74D4003780B24285E3E409C1727BEDAF74D401920D1048A603E409C1727BEDAF74D401920D1048A603E40734BAB2171F74D4003780B24285E3E40734BAB2171F74D40
1776	2	30.310684999999999	30.312149000000002	59.841237999999997	59.822625000000002	5-й Предпортовый проезд	0103000020E61000000100000005000000965B5A0D894F3E409EEFA7C64BE94D40965B5A0D894F3E408313D1AFADEB4D40A77A32FFE84F3E408313D1AFADEB4D40A77A32FFE84F3E409EEFA7C64BE94D40965B5A0D894F3E409EEFA7C64BE94D40
4873	2	30.290669999999999	30.305133000000001	60.019365000000001	60.011662000000001	3-я линия 1-й половины	0103000020E61000000100000005000000A6ED5F59694A3E40904DF2237E014E40A6ED5F59694A3E40F1D7648D7A024E402DEE3F321D4E3E40F1D7648D7A024E402DEE3F321D4E3E40904DF2237E014E40A6ED5F59694A3E40904DF2237E014E40
13307	2	30.277456000000001	30.290796	59.949325000000002	59.938459000000002	2-я линия В.О.	0103000020E6100000010000000500000038143E5B07473E4085D1AC6C1FF84D4038143E5B07473E403A234A7B83F94D40C0CE4D9B714A3E403A234A7B83F94D40C0CE4D9B714A3E4085D1AC6C1FF84D4038143E5B07473E4085D1AC6C1FF84D40
6781	2	30.362705999999999	30.374151000000001	59.933636	59.929763000000001	2-я Советская улица	0103000020E610000001000000050000001F10E84CDA5C3E40F303577902F74D401F10E84CDA5C3E40232F6B6281F74D4005C4245CC85F3E40232F6B6281F74D4005C4245CC85F3E40F303577902F74D401F10E84CDA5C3E40F303577902F74D40
77293	2	30.307549999999999	30.318186000000001	59.915272999999999	59.915111000000003	2-я Красноармейская улица	0103000020E6100000010000000500000082E2C798BB4E3E40DD9A745B22F54D4082E2C798BB4E3E40B6F468AA27F54D40890B40A374513E40B6F468AA27F54D40890B40A374513E40DD9A745B22F54D4082E2C798BB4E3E40DD9A745B22F54D40
7962	2	30.143284000000001	30.146194000000001	59.846792999999998	59.825392999999998	2-я Комсомольская улица	0103000020E61000000100000005000000420A9E42AE243E4075AC527AA6E94D40420A9E42AE243E40A9BD88B663EC4D4016DF50F86C253E40A9BD88B663EC4D4016DF50F86C253E4075AC527AA6E94D40420A9E42AE243E4075AC527AA6E94D40
2871	2	30.468931999999999	30.475966	59.856369999999998	59.852885999999998	2-й Рабфаковский переулок	0103000020E61000000100000005000000410C74ED0B783E40AE9B525E2BED4D40410C74ED0B783E4044A33B889DED4D40080264E8D8793E4044A33B889DED4D40080264E8D8793E40AE9B525E2BED4D40410C74ED0B783E40AE9B525E2BED4D40
3895	2	30.328938999999998	30.362508999999999	60.003151000000003	59.998381999999999	2-й Муринский проспект	0103000020E610000001000000050000000261A75835543E4021753BFBCAFF4D400261A75835543E4090F9804067004E407381CB63CD5C3E4090F9804067004E407381CB63CD5C3E4021753BFBCAFF4D400261A75835543E4021753BFBCAFF4D40
13309	2	30.256957	30.274204000000001	59.946955000000003	59.932288	17-я линия В.О.	0103000020E61000000100000005000000707A17EFC7413E40043A933655F74D40707A17EFC7413E4050E449D235F94D40B16EBC3B32463E4050E449D235F94D40B16EBC3B32463E40043A933655F74D40707A17EFC7413E40043A933655F74D40
13310	2	30.256957	30.274204000000001	59.946955000000003	59.932288	16-я линия В.О.	0103000020E61000000100000005000000707A17EFC7413E40043A933655F74D40707A17EFC7413E4050E449D235F94D40B16EBC3B32463E4050E449D235F94D40B16EBC3B32463E40043A933655F74D40707A17EFC7413E40043A933655F74D40
13314	2	30.262948000000002	30.278606	59.947752999999999	59.934303	13-я линия В.О.	0103000020E61000000100000005000000728C648F50433E4000C79E3D97F74D40728C648F50433E40CBD765F84FF94D4029780AB952473E40CBD765F84FF94D4029780AB952473E4000C79E3D97F74D40728C648F50433E4000C79E3D97F74D40
15912	2	30.292439999999999	30.307469000000001	59.912940999999996	59.912647999999997	10-я Красноармейская	0103000020E61000000100000005000000D00A0C59DD4A3E40416150A6D1F44D40D00A0C59DD4A3E40B9162D40DBF44D40A988D349B64E3E40B9162D40DBF44D40A988D349B64E3E40416150A6D1F44D40D00A0C59DD4A3E40416150A6D1F44D40
16208	2	30.482299000000001	30.485847	59.964596999999998	59.963422000000001	1-я Жерновская	0103000020E61000000100000005000000BDE47FF2777B3E409B1F7F6951FB4D40BDE47FF2777B3E40EC681CEA77FB4D4016DC0F78607C3E40EC681CEA77FB4D4016DC0F78607C3E409B1F7F6951FB4D40BDE47FF2777B3E409B1F7F6951FB4D40
13359	2	30.560057	30.562778999999999	59.749809999999997	59.742134999999998	 Танкистов	0103000020E6100000010000000500000058E542E55F8F3E40C51B9947FEDE4D4058E542E55F8F3E405C1B2AC6F9DF4D4026E0D74812903E405C1B2AC6F9DF4D4026E0D74812903E40C51B9947FEDE4D4058E542E55F8F3E40C51B9947FEDE4D40
13332	2	30.255735000000001	30.274761000000002	59.878639999999997	59.872709999999998	 Новостроек	0103000020E610000001000000050000004C7155D977413E40327216F6B4EF4D404C7155D977413E408D7A884677F04D405D37A5BC56463E408D7A884677F04D405D37A5BC56463E40327216F6B4EF4D404C7155D977413E40327216F6B4EF4D40
13327	2	30.439153000000001	30.501424	59.926994999999998	59.912260000000003	 Коллонтай	0103000020E61000000100000005000000B7F0BC546C703E4078B988EFC4F44D40B7F0BC546C703E401B47ACC5A7F64D40F46DC1525D803E401B47ACC5A7F64D40F46DC1525D803E4078B988EFC4F44D40B7F0BC546C703E4078B988EFC4F44D40
13361	2	30.303453000000001	30.315114000000001	60.066015	60.062309999999997	 Жени Егоровой	0103000020E6100000010000000500000083DF8618AF4D3E405C1B2AC6F9074E4083DF8618AF4D3E40D105F52D73084E400283A44FAB503E40D105F52D73084E400283A44FAB503E405C1B2AC6F9074E4083DF8618AF4D3E405C1B2AC6F9074E40
62936	58046	47.155731000000003	47.166969000000002	56.112613000000003	56.111167999999999	Центральная	0103000020E6100000010000000500000098FC4FFEEE9347404D2EC6C03A0E4C4098FC4FFEEE9347405F0D501A6A0E4C4011397D3D5F9547405F0D501A6A0E4C4011397D3D5F9547404D2EC6C03A0E4C4098FC4FFEEE9347404D2EC6C03A0E4C40
61613	57863	46.180134000000002	46.217576000000001	55.959228000000003	55.928919999999998	Чапаева	0103000020E61000000100000005000000E77283A10E174740D74CBED9E6F64B40E77283A10E17474029B4ACFBC7FA4B407F32C687D91B474029B4ACFBC7FA4B407F32C687D91B4740D74CBED9E6F64B40E77283A10E174740D74CBED9E6F64B40
61758	57863	46.180134000000002	46.217576000000001	55.959228000000003	55.928919999999998	Ленина	0103000020E61000000100000005000000E77283A10E174740D74CBED9E6F64B40E77283A10E17474029B4ACFBC7FA4B407F32C687D91B474029B4ACFBC7FA4B407F32C687D91B4740D74CBED9E6F64B40E77283A10E174740D74CBED9E6F64B40
61611	57863	46.180134000000002	46.217576000000001	55.959228000000003	55.928919999999998	Карла Маркса	0103000020E61000000100000005000000E77283A10E174740D74CBED9E6F64B40E77283A10E17474029B4ACFBC7FA4B407F32C687D91B474029B4ACFBC7FA4B407F32C687D91B4740D74CBED9E6F64B40E77283A10E174740D74CBED9E6F64B40
61610	57863	46.180134000000002	46.217576000000001	55.959228000000003	55.928919999999998	50 лет Октября	0103000020E61000000100000005000000E77283A10E174740D74CBED9E6F64B40E77283A10E17474029B4ACFBC7FA4B407F32C687D91B474029B4ACFBC7FA4B407F32C687D91B4740D74CBED9E6F64B40E77283A10E174740D74CBED9E6F64B40
61641	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Щербакова	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61576	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Черняховского	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61596	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Францева	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61606	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Сурская	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61571	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Советская	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61827	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Радищева	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61605	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Пушкина	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61607	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Некрасова	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61595	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	МОПРа	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61608	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	М.Жукова	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61575	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Ленина	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61998	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Котовского	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61598	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Кирова	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61569	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Горького	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
61909	2126	46.365015999999997	46.470964000000002	55.517158999999999	55.454509000000002	Белинского	0103000020E61000000100000005000000244223D8B82E47406C5ED5592DBA4B40244223D8B82E474081EA1F4432C24B40F3CB608C483C474081EA1F4432C24B40F3CB608C483C47406C5ED5592DBA4B40244223D8B82E47406C5ED5592DBA4B40
2825	61	47.178890000000003	47.180857000000003	56.112036000000003	56.110790999999999	улица Школьная	0103000020E610000001000000050000006DCA15DEE596474077D844662E0E4C406DCA15DEE5964740C2FC1532570E4C4058207A5226974740C2FC1532570E4C4058207A522697474077D844662E0E4C406DCA15DEE596474077D844662E0E4C40
61775	61	47.263115999999997	47.277714000000003	56.109144999999998	56.101197999999997	улица Хевешская	0103000020E61000000100000005000000F486FBC8ADA14740D6355A0EF40C4C40F486FBC8ADA14740CEC29E76F80D4C4018D2E1218CA34740CEC29E76F80D4C4018D2E1218CA34740D6355A0EF40C4C40F486FBC8ADA14740D6355A0EF40C4C40
15761	61	47.211517000000001	47.221604999999997	56.072665000000001	56.067855999999999	улица Совхозная	0103000020E6100000010000000500000026C632FD129B47402F6B6281AF084C4026C632FD129B47402C4833164D094C40A6D0798D5D9C47402C4833164D094C40A6D0798D5D9C47402F6B6281AF084C4026C632FD129B47402F6B6281AF084C40
61818	61	47.211517000000001	47.221604999999997	56.072665000000001	56.067855999999999	улица Совхозная	0103000020E6100000010000000500000026C632FD129B47402F6B6281AF084C4026C632FD129B47402C4833164D094C40A6D0798D5D9C47402C4833164D094C40A6D0798D5D9C47402F6B6281AF084C4026C632FD129B47402F6B6281AF084C40
61784	61	47.274200999999998	47.282555000000002	56.132750000000001	56.130056000000003	улица Патриса Лумумбы	0103000020E61000000100000005000000E7C3B30419A347400553CDACA5104C40E7C3B30419A34740A245B6F3FD104C40202922C32AA44740A245B6F3FD104C40202922C32AA447400553CDACA5104C40E7C3B30419A347400553CDACA5104C40
2985	61	47.243271999999997	47.250647000000001	56.138402999999997	56.137044000000003	улица Кооперативная	0103000020E6100000010000000500000029047289239F4740780E65A88A114C4029047289239F47408A558330B7114C4096EB6D3315A047408A558330B7114C4096EB6D3315A04740780E65A88A114C4029047289239F4740780E65A88A114C40
2007	61	47.254564000000002	47.289473000000001	56.145510000000002	56.130803	улица Калинина	0103000020E61000000100000005000000965E9B8D95A04740FE9B1727BE104C40965E9B8D95A04740D89E5912A0124C409A0986730DA54740D89E5912A0124C409A0986730DA54740FE9B1727BE104C40965E9B8D95A04740FE9B1727BE104C40
655	61	47.179257999999997	47.225099	56.135036999999997	56.108767999999998	улица Гражданская	0103000020E61000000100000005000000EFC517EDF1964740F86C1D1CEC0D4C40EFC517EDF1964740FE5F75E448114C4060AE450BD09C4740FE5F75E448114C4060AE450BD09C4740F86C1D1CEC0D4C40EFC517EDF1964740F86C1D1CEC0D4C40
7702	61	47.284478	47.361696999999999	56.125666000000002	56.097648	проспект Тракторостроителей	0103000020E610000001000000050000003B376DC669A447408942CBBA7F0C4C403B376DC669A447400D1CD0D215104C40D90759164CAE47400D1CD0D215104C40D90759164CAE47408942CBBA7F0C4C403B376DC669A447408942CBBA7F0C4C40
2858	61	47.262146000000001	47.288296000000003	56.130051000000002	56.104340999999998	проспект Мира	0103000020E610000001000000050000007C6308008EA14740E350BF0B5B0D4C407C6308008EA14740F3E7DB82A5104C40A8C821E2E6A44740F3E7DB82A5104C40A8C821E2E6A44740E350BF0B5B0D4C407C6308008EA14740E350BF0B5B0D4C40
59234	61	47.171407000000002	47.203054999999999	56.148868999999998	56.146577999999998	проспект Максима Горького	0103000020E610000001000000050000001AA721AAF095474013286211C3124C401AA721AAF0954740B131AF230E134C400725CCB4FD994740B131AF230E134C400725CCB4FD99474013286211C3124C401AA721AAF095474013286211C3124C40
3045	61	47.246084000000003	47.263421000000001	56.131931999999999	56.113546999999997	проспект Ленина	0103000020E61000000100000005000000D10836AE7F9F47408AC745B5880E4C40D10836AE7F9F4740DFA5D425E3104C40310A82C7B7A14740DFA5D425E3104C40310A82C7B7A147408AC745B5880E4C40D10836AE7F9F47408AC745B5880E4C40
8024	61	47.257815999999998	47.278531000000001	56.114606000000002	56.072845999999998	проспект Ивана Яковлева	0103000020E6100000010000000500000059315C1D00A147407CD2890453094C4059315C1D00A1474073F6CE68AB0E4C400AF65FE7A6A3474073F6CE68AB0E4C400AF65FE7A6A347407CD2890453094C4059315C1D00A147407CD2890453094C40
7982	61	47.265613000000002	47.283526000000002	56.097492000000003	56.094951999999999	проспект 9-й Пятилетки	0103000020E610000001000000050000003C32569BFFA147404B581B63270C4C403C32569BFFA1474092CF2B9E7A0C4C4069C878944AA4474092CF2B9E7A0C4C4069C878944AA447404B581B63270C4C403C32569BFFA147404B581B63270C4C40
7939	61	47.258606	47.263601000000001	56.122940999999997	56.121637	проезд Школьный	0103000020E6100000010000000500000052465C001AA14740E57D1CCD910F4C4052465C001AA14740342BDB87BC0F4C40B11875ADBDA14740342BDB87BC0F4C40B11875ADBDA14740E57D1CCD910F4C4052465C001AA14740E57D1CCD910F4C40
7623	61	47.309289	47.318066000000002	56.139204999999997	56.131630999999999	проезд Соляное	0103000020E610000001000000050000009B012EC896A74740E411DC48D9104C409B012EC896A7474047382D78D1114C401AFCFD62B6A8474047382D78D1114C401AFCFD62B6A84740E411DC48D9104C409B012EC896A74740E411DC48D9104C40
313	61	47.171424999999999	47.173419000000003	56.108426999999999	56.107528000000002	площадь Победы	0103000020E61000000100000005000000C05B2041F1954740C0B33D7AC30D4C40C05B2041F19547406F8099EFE00D4C40A5C00298329647406F8099EFE00D4C40A5C0029832964740C0B33D7AC30D4C40C05B2041F1954740C0B33D7AC30D4C40
8100	61	47.215164000000001	47.229554999999998	56.115253000000003	56.112493000000001	переулок Ягодный	0103000020E6100000010000000500000066A3737E8A9B4740B403AE2B660E4C4066A3737E8A9B474009E23C9CC00E4C400FD1E80E629D474009E23C9CC00E4C400FD1E80E629D4740B403AE2B660E4C4066A3737E8A9B4740B403AE2B660E4C40
59223	61	47.182321000000002	47.195967000000003	56.117562	56.110410000000002	бульвар Анатолия Миттова	0103000020E61000000100000005000000E02F664B56974740609335EA210E4C40E02F664B569747404DA088450C0F4C40310C5872159947404DA088450C0F4C40310C587215994740609335EA210E4C40E02F664B56974740609335EA210E4C40
61779	61	47.177677000000003	47.207186999999998	56.129213	56.114108999999999	Энтузиастов	0103000020E610000001000000050000002E20B41EBE964740F296AB1F9B0E4C402E20B41EBE964740E99B340D8A104C400394861A859A4740E99B340D8A104C400394861A859A4740F296AB1F9B0E4C402E20B41EBE964740F296AB1F9B0E4C40
61800	61	47.250602000000001	47.266295999999997	56.131394999999998	56.114631000000003	Энгельса	0103000020E61000000100000005000000F627F1B913A04740CC0D863AAC0E4C40F627F1B913A04740D0ED258DD1104C401E87C1FC15A24740D0ED258DD1104C401E87C1FC15A24740CC0D863AAC0E4C40F627F1B913A04740CC0D863AAC0E4C40
61797	61	47.178037000000003	47.178279000000003	56.151145999999997	56.140399000000002	Эльгера	0103000020E610000001000000050000002E3D9AEAC996474010B22C98F8114C402E3D9AEAC9964740EA758BC058134C402448A5D8D1964740EA758BC058134C402448A5D8D196474010B22C98F8114C402E3D9AEAC996474010B22C98F8114C40
7596	61	47.266672999999997	47.288519999999998	56.113084999999998	56.089402999999997	Эгерский бульвар	0103000020E61000000100000005000000F4DC425722A247400795B88E710B4C40F4DC425722A247408655BC91790E4C40F71E2E39EEA447408655BC91790E4C40F71E2E39EEA447400795B88E710B4C40F4DC425722A247400795B88E710B4C40
61792	61	47.273122999999998	47.295222000000003	56.105525	56.100861000000002	Шумилова	0103000020E610000001000000050000008864C8B1F5A247408F386403E90C4C408864C8B1F5A2474088F4DBD7810D4C40A587A1D5C9A5474088F4DBD7810D4C40A587A1D5C9A547408F386403E90C4C408864C8B1F5A247408F386403E90C4C40
61763	61	47.174506000000001	47.185034000000002	56.121687000000001	56.112411999999999	Чернышевского	0103000020E61000000100000005000000577A6D3656964740C7D63384630E4C40577A6D365696474097AC8A70930F4C40F452B131AF97474097AC8A70930F4C40F452B131AF974740C7D63384630E4C40577A6D3656964740C7D63384630E4C40
61789	61	47.256118000000001	47.265819999999998	56.131571000000001	56.120322000000002	Чапаева	0103000020E610000001000000050000005EF58079C8A04740A27E17B6660F4C405EF58079C8A047400F0D8B51D7104C40B54FC76306A247400F0D8B51D7104C40B54FC76306A24740A27E17B6660F4C405EF58079C8A04740A27E17B6660F4C40
61956	61	47.134684	47.380229	56.199477000000002	56.059840999999999	Чандровская	0103000020E61000000100000005000000B1A547533D914740DFFAB0DEA8074C40B1A547533D914740F0A65B7688194C40D2FE0758ABB04740F0A65B7688194C40D2FE0758ABB04740DFFAB0DEA8074C40B1A547533D914740DFFAB0DEA8074C40
59372	61	47.134684	47.380229	56.199477000000002	56.059840999999999	Центральная	0103000020E61000000100000005000000B1A547533D914740DFFAB0DEA8074C40B1A547533D914740F0A65B7688194C40D2FE0758ABB04740F0A65B7688194C40D2FE0758ABB04740DFFAB0DEA8074C40B1A547533D914740DFFAB0DEA8074C40
61770	61	47.272378000000003	47.278675	56.102237000000002	56.087600000000002	Хузангая	0103000020E6100000010000000500000030134548DDA2474097900F7A360B4C4030134548DDA2474078B81D1A160D4C403D9B559FABA3474078B81D1A160D4C403D9B559FABA3474097900F7A360B4C4030134548DDA2474097900F7A360B4C40
61781	61	47.202713000000003	47.223526999999997	56.143644000000002	56.137645999999997	Урукова	0103000020E61000000100000005000000AEBCE47FF29947406D3656629E114C40AEBCE47FF2994740212235ED62124C40F16261889C9C4740212235ED62124C40F16261889C9C47406D3656629E114C40AEBCE47FF29947406D3656629E114C40
9	61	47.163114999999998	47.192742000000003	56.148814000000002	56.129454000000003	Университетская улица	0103000020E61000000100000005000000573ECBF3E09447400F2BDCF291104C40573ECBF3E0944740EE974F560C134C40674815C5AB984740EE974F560C134C40674815C5AB9847400F2BDCF291104C40573ECBF3E09447400F2BDCF291104C40
59251	61	47.190441999999997	47.198410000000003	56.148789000000001	56.140749999999997	Тимофея Кривова	0103000020E6100000010000000500000075E4486760984740BC74931804124C4075E4486760984740958098840B134C408599B67F65994740958098840B134C408599B67F65994740BC74931804124C4075E4486760984740BC74931804124C40
62932	61	47.235439	47.243505999999996	56.112938999999997	56.112357000000003	Строителей	0103000020E61000000100000005000000FA997ADD229E4740043DD4B6610E4C40FA997ADD229E4740B2B8FFC8740E4C409C3061342B9F4740B2B8FFC8740E4C409C3061342B9F4740043DD4B6610E4C40FA997ADD229E4740043DD4B6610E4C40
59296	61	47.213628	47.216709000000002	56.144893000000003	56.139963000000002	Спиридона Михайлова	0103000020E6100000010000000500000044C18C29589B474035D3BD4EEA114C4044C18C29589B4740AD3594DA8B124C40DBDFD91EBD9B4740AD3594DA8B124C40DBDFD91EBD9B474035D3BD4EEA114C4044C18C29589B474035D3BD4EEA114C40
61798	61	47.173409999999997	47.179257999999997	56.108772999999999	56.108432000000001	Социалистическая	0103000020E610000001000000050000005166834C3296474081EB8A19E10D4C405166834C329647400AD80E46EC0D4C40EFC517EDF19647400AD80E46EC0D4C40EFC517EDF196474081EB8A19E10D4C405166834C3296474081EB8A19E10D4C40
61866	61	47.134684	47.380229	56.199477000000002	56.059840999999999	Сосновская	0103000020E61000000100000005000000B1A547533D914740DFFAB0DEA8074C40B1A547533D914740F0A65B7688194C40D2FE0758ABB04740F0A65B7688194C40D2FE0758ABB04740DFFAB0DEA8074C40B1A547533D914740DFFAB0DEA8074C40
2957	61	47.238035000000004	47.248086999999998	56.146236999999999	56.138342999999999	Советская набережная	0103000020E61000000100000005000000D5264EEE779E4740B5503239B5114C40D5264EEE779E47408A3BDEE4B7124C4008C89750C19F47408A3BDEE4B7124C4008C89750C19F4740B5503239B5114C40D5264EEE779E4740B5503239B5114C40
61887	61	47.318874000000001	47.320788	56.082571999999999	56.081612	Скворцова площадь	0103000020E61000000100000005000000B9C5FCDCD0A84740077B1343720A4C40B9C5FCDCD0A847405CC823B8910A4C408179C8940FA947405CC823B8910A4C408179C8940FA94740077B1343720A4C40B9C5FCDCD0A84740077B1343720A4C40
61783	61	47.270338000000002	47.276681000000004	56.081437000000001	56.075504000000002	Сапожникова	0103000020E61000000100000005000000DB6E826F9AA24740CD5B751DAA094C40DB6E826F9AA2474099D711876C0A4C40593673486AA3474099D711876C0A4C40593673486AA34740CD5B751DAA094C40DB6E826F9AA24740CD5B751DAA094C40
61343	61	47.279806999999998	47.284747000000003	56.071714999999998	56.069021999999997	Розы Люксембург	0103000020E610000001000000050000008F183DB7D0A347402D5A80B6D5084C408F183DB7D0A34740FAD005F52D094C402B51F69672A44740FAD005F52D094C402B51F69672A447402D5A80B6D5084C408F183DB7D0A347402D5A80B6D5084C40
59414	61	47.134684	47.380229	56.199477000000002	56.059840999999999	Родниковая	0103000020E61000000100000005000000B1A547533D914740DFFAB0DEA8074C40B1A547533D914740F0A65B7688194C40D2FE0758ABB04740F0A65B7688194C40D2FE0758ABB04740DFFAB0DEA8074C40B1A547533D914740DFFAB0DEA8074C40
61411	61	47.275745999999998	47.282645000000002	56.078673999999999	56.073509000000001	Рихарда Зорге	0103000020E610000001000000050000005C001AA54BA34740187B2FBE68094C405C001AA54BA34740D38558FD110A4C4060B01BB62DA44740D38558FD110A4C4060B01BB62DA44740187B2FBE68094C405C001AA54BA34740187B2FBE68094C40
61399	61	47.274200999999998	47.282555000000002	56.132750000000001	56.130056000000003	Патриса Лумумбы	0103000020E61000000100000005000000E7C3B30419A347400553CDACA5104C40E7C3B30419A34740A245B6F3FD104C40202922C32AA44740A245B6F3FD104C40202922C32AA447400553CDACA5104C40E7C3B30419A347400553CDACA5104C40
61796	61	47.246487999999999	47.251069999999999	56.125926999999997	56.124701999999999	Николая Ильбекова	0103000020E61000000100000005000000A06D35EB8C9F474076DF313CF60F4C40A06D35EB8C9F474079573D601E104C40DC80CF0F23A0474079573D601E104C40DC80CF0F23A0474076DF313CF60F4C40A06D35EB8C9F474076DF313CF60F4C40
422	61	47.190820000000002	47.243856000000001	56.146276999999998	56.137926	Московский проспект	0103000020E610000001000000050000001CB62DCA6C98474051A2258FA7114C401CB62DCA6C98474018946934B9124C40797764AC369F474018946934B9124C40797764AC369F474051A2258FA7114C401CB62DCA6C98474051A2258FA7114C40
3192	61	47.148023999999999	47.254420000000003	56.156374999999997	56.150694999999999	Московская набережная	0103000020E61000000100000005000000F5824F73F2924740DA5548F949134C40F5824F73F2924740BC74931804144C4063B9A5D590A04740BC74931804144C4063B9A5D590A04740DA5548F949134C40F5824F73F2924740DA5548F949134C40
59218	61	47.179707000000001	47.189014	56.122449000000003	56.114986999999999	Мате Залка	0103000020E610000001000000050000005FEE93A3009747408A3BDEE4B70E4C405FEE93A300974740C636A968AC0F4C403A3E5A9C31984740C636A968AC0F4C403A3E5A9C319847408A3BDEE4B70E4C405FEE93A3009747408A3BDEE4B70E4C40
61793	61	47.268227000000003	47.311329000000001	56.089562999999998	56.080903999999997	Магницкого	0103000020E61000000100000005000000BD73284355A24740CB0EF10F5B0A4C40BD73284355A2474040F7E5CC760B4C40F0A5F0A0D9A7474040F7E5CC760B4C40F0A5F0A0D9A74740CB0EF10F5B0A4C40BD73284355A24740CB0EF10F5B0A4C40
61592	61	47.263708999999999	47.327938000000003	56.109957999999999	56.099440999999999	Ленинского Комсомола	0103000020E6100000010000000500000097546D37C1A14740D670917BBA0C4C4097546D37C1A147407FF78E1A130E4C40CE8E54DFF9A947407FF78E1A130E4C40CE8E54DFF9A94740D670917BBA0C4C4097546D37C1A14740D670917BBA0C4C40
62637	45611	47.413331999999997	47.426726000000002	55.695768000000001	55.688699999999997	Мира	0103000020E61000000100000005000000F4311F10E8B44740AA60545227D84B40F4311F10E8B447403ACD02ED0ED94B402C2D23F59EB647403ACD02ED0ED94B402C2D23F59EB64740AA60545227D84B40F4311F10E8B44740AA60545227D84B40
61788	61	47.246371000000003	47.249749000000001	56.146020999999998	56.137987000000003	Ленинградская	0103000020E6100000010000000500000067D7BD15899F4740F722DA8EA9114C4067D7BD15899F4740BDC3EDD0B0124C40B79A75C6F79F4740BDC3EDD0B0124C40B79A75C6F79F4740F722DA8EA9114C4067D7BD15899F4740F722DA8EA9114C40
61773	61	47.15981	47.171379999999999	56.149025000000002	56.140424000000003	Лебедева	0103000020E6100000010000000500000071C971A77494474069C9E369F9114C4071C971A774944740A9A44E4013134C402098A3C7EF954740A9A44E4013134C402098A3C7EF95474069C9E369F9114C4071C971A77494474069C9E369F9114C40
8027	61	47.267688	47.288269	56.089557999999997	56.086274000000003	Кукшумская улица	0103000020E610000001000000050000000DC4B29943A24740603FC4060B0B4C400DC4B29943A247402E8CF4A2760B4C40AEB9A3FFE5A447402E8CF4A2760B4C40AEB9A3FFE5A44740603FC4060B0B4C400DC4B29943A24740603FC4060B0B4C40
61764	61	47.267688	47.288269	56.089557999999997	56.086274000000003	Кукшумская	0103000020E610000001000000050000000DC4B29943A24740603FC4060B0B4C400DC4B29943A247402E8CF4A2760B4C40AEB9A3FFE5A447402E8CF4A2760B4C40AEB9A3FFE5A44740603FC4060B0B4C400DC4B29943A24740603FC4060B0B4C40
61790	61	47.286848999999997	47.292580999999998	56.086806000000003	56.079618000000004	Кременского	0103000020E61000000100000005000000F5F1D077B7A44740231631EC300A4C40F5F1D077B7A447405D8C81751C0B4C402A37514B73A547405D8C81751C0B4C402A37514B73A54740231631EC300A4C40F5F1D077B7A44740231631EC300A4C40
61767	61	47.254753000000001	47.284630999999997	56.132061999999998	56.117576999999997	Космонавта Николаева А.Г.	0103000020E6100000010000000500000069C70DBF9BA0474082E15CC30C0F4C4069C70DBF9BA04740AD855968E7104C40C136E2C96EA44740AD855968E7104C40C136E2C96EA4474082E15CC30C0F4C4069C70DBF9BA0474082E15CC30C0F4C40
62937	61	47.243271999999997	47.250647000000001	56.138402999999997	56.137044000000003	Кооперативная	0103000020E6100000010000000500000029047289239F4740780E65A88A114C4029047289239F47408A558330B7114C4096EB6D3315A047408A558330B7114C4096EB6D3315A04740780E65A88A114C4029047289239F4740780E65A88A114C40
62003	61	47.221173999999998	47.252183000000002	56.153351999999998	56.146106000000003	Константина Иванова	0103000020E61000000100000005000000DD5CFC6D4F9C4740ECDFF599B3124C40DD5CFC6D4F9C47405A63D009A1134C40B8CD548847A047405A63D009A1134C40B8CD548847A04740ECDFF599B3124C40DD5CFC6D4F9C4740ECDFF599B3124C40
59298	61	47.221173999999998	47.252183000000002	56.153351999999998	56.146106000000003	Константина Иванова	0103000020E61000000100000005000000DD5CFC6D4F9C4740ECDFF599B3124C40DD5CFC6D4F9C47405A63D009A1134C40B8CD548847A047405A63D009A1134C40B8CD548847A04740ECDFF599B3124C40DD5CFC6D4F9C4740ECDFF599B3124C40
59409	61	47.230103	47.236201999999999	56.136325999999997	56.133963999999999	Коммунальная Слобода	0103000020E6100000010000000500000012DBDD03749D4740B16B7BBB25114C4012DBDD03749D474018CC5F2173114C40F99FFCDD3B9E474018CC5F2173114C40F99FFCDD3B9E4740B16B7BBB25114C4012DBDD03749D4740B16B7BBB25114C40
61771	61	47.230103	47.236201999999999	56.136325999999997	56.133963999999999	Коммунальная Слобода	0103000020E6100000010000000500000012DBDD03749D4740B16B7BBB25114C4012DBDD03749D474018CC5F2173114C40F99FFCDD3B9E474018CC5F2173114C40F99FFCDD3B9E4740B16B7BBB25114C4012DBDD03749D4740B16B7BBB25114C40
61794	61	47.246084000000003	47.251230999999997	56.143408000000001	56.131922000000003	Карла Маркса	0103000020E61000000100000005000000D10836AE7F9F4740BCCFF1D1E2104C40D10836AE7F9F47400DFE7E315B124C40E55E605628A047400DFE7E315B124C40E55E605628A04740BCCFF1D1E2104C40D10836AE7F9F4740BCCFF1D1E2104C40
61765	61	47.289516999999996	47.312334999999997	56.107241999999999	56.101730000000003	Кадыкова	0103000020E6100000010000000500000069519FE40EA54740D482177D050D4C4069519FE40EA54740FA60191BBA0D4C40B532E197FAA74740FA60191BBA0D4C40B532E197FAA74740D482177D050D4C4069519FE40EA54740D482177D050D4C40
61632	61	47.260089000000001	47.272089999999999	56.147038999999999	56.145975999999997	Зои Яковлевой	0103000020E610000001000000050000005186AA984AA147401D007157AF124C405186AA984AA14740471E882CD2124C40C9C859D8D3A24740471E882CD2124C40C9C859D8D3A247401D007157AF124C405186AA984AA147401D007157AF124C40
61766	61	47.276958999999998	47.284073999999997	56.140850999999998	56.131881999999997	Декабристов	0103000020E610000001000000050000009BAA7B6473A347402D776682E1104C409BAA7B6473A34740F04DD36707124C406BD26D895CA44740F04DD36707124C406BD26D895CA447402D776682E1104C409BAA7B6473A347402D776682E1104C40
61791	61	47.179257999999997	47.225099	56.135036999999997	56.108767999999998	Гражданская	0103000020E61000000100000005000000EFC517EDF1964740F86C1D1CEC0D4C40EFC517EDF1964740FE5F75E448114C4060AE450BD09C4740FE5F75E448114C4060AE450BD09C4740F86C1D1CEC0D4C40EFC517EDF1964740F86C1D1CEC0D4C40
61782	61	47.265828999999997	47.267840999999997	56.145966000000001	56.140560000000001	Гайдара	0103000020E6100000010000000500000008AA46AF06A247401990BDDEFD114C4008AA46AF06A24740FA298E03AF124C4093C3279D48A24740FA298E03AF124C4093C3279D48A247401990BDDEFD114C4008AA46AF06A247401990BDDEFD114C40
61769	61	47.248545	47.273456000000003	56.138368	56.122123000000002	Гагарина	0103000020E61000000100000005000000CB4A9352D09F4740728BF9B9A10F4C40CB4A9352D09F47400E68E90AB6114C408F72309B00A347400E68E90AB6114C408F72309B00A34740728BF9B9A10F4C40CB4A9352D09F4740728BF9B9A10F4C40
61772	61	47.213745000000003	47.236767999999998	56.136150999999998	56.106800999999997	Богдана Хмельницкого	0103000020E610000001000000050000007E5704FF5B9B47400D17B9A7AB0D4C407E5704FF5B9B4740AA285E656D114C40A25EF0694E9E4740AA285E656D114C40A25EF0694E9E47400D17B9A7AB0D4C407E5704FF5B9B47400D17B9A7AB0D4C40
61787	61	47.305219999999998	47.309694	56.108978999999998	56.102879999999999	Баумана	0103000020E61000000100000005000000E50AEF7211A74740CCB4FD2B2B0D4C40E50AEF7211A74740B3791C06F30D4C403BE2900DA4A74740B3791C06F30D4C403BE2900DA4A74740CCB4FD2B2B0D4C40E50AEF7211A74740CCB4FD2B2B0D4C40
61768	61	47.270975999999997	47.312837999999999	56.086379000000001	56.079039999999999	Ашмарина	0103000020E610000001000000050000001D007157AFA24740B58993FB1D0A4C401D007157AFA24740D50792770E0B4C40187959130BA84740D50792770E0B4C40187959130BA84740B58993FB1D0A4C401D007157AFA24740B58993FB1D0A4C40
61778	61	47.168720999999998	47.178269999999998	56.145018	56.144430999999997	Ахазова	0103000020E61000000100000005000000FF9254A698954740A8C30AB77C124C40FF9254A69895474069AA27F38F124C40D0ED258DD196474069AA27F38F124C40D0ED258DD1964740A8C30AB77C124C40FF9254A698954740A8C30AB77C124C40
61799	61	47.219726999999999	47.220804999999999	56.155226999999996	56.146036000000002	Афанасьева	0103000020E610000001000000050000002B86AB03209C4740F304C24EB1124C402B86AB03209C4740643A747ADE134C408AE59656439C4740643A747ADE134C408AE59656439C4740F304C24EB1124C402B86AB03209C4740F304C24EB1124C40
58932	61	47.222296	47.224803000000001	56.121490999999999	56.120030999999997	Академика Павлова	0103000020E610000001000000050000000C040132749C4740CAC0012D5D0F4C400C040132749C474011E15F048D0F4C4077853E58C69C474011E15F048D0F4C4077853E58C69C4740CAC0012D5D0F4C400C040132749C4740CAC0012D5D0F4C40
61407	61	47.134684	47.380229	56.199477000000002	56.059840999999999	324 стрелковой дивизии	0103000020E61000000100000005000000B1A547533D914740DFFAB0DEA8074C40B1A547533D914740F0A65B7688194C40D2FE0758ABB04740F0A65B7688194C40D2FE0758ABB04740DFFAB0DEA8074C40B1A547533D914740DFFAB0DEA8074C40
61759	61	47.170535999999998	47.172718000000003	56.144441	56.139395999999998	139-й Стрелковой Дивизии	0103000020E610000001000000050000003465A71FD4954740BB9866BAD7114C403465A71FD4954740CC99ED0A7D124C401CB7989F1B964740CC99ED0A7D124C401CB7989F1B964740BB9866BAD7114C403465A71FD4954740BB9866BAD7114C40
59104	61	47.170535999999998	47.172718000000003	56.144441	56.139395999999998	139-й Стрелковой Дивизии	0103000020E610000001000000050000003465A71FD4954740BB9866BAD7114C403465A71FD4954740CC99ED0A7D124C401CB7989F1B964740CC99ED0A7D124C401CB7989F1B964740BB9866BAD7114C403465A71FD4954740BB9866BAD7114C40
61644	57859	47.450442000000002	47.499282999999998	55.882908999999998	55.851838999999998	Рогожкина	0103000020E61000000100000005000000575F5D15A8B947408A3A730F09ED4B40575F5D15A8B947400A2C802903F14B4071395E81E8BF47400A2C802903F14B4071395E81E8BF47408A3A730F09ED4B40575F5D15A8B947408A3A730F09ED4B40
61678	57859	47.450442000000002	47.499282999999998	55.882908999999998	55.851838999999998	П. Иванова	0103000020E61000000100000005000000575F5D15A8B947408A3A730F09ED4B40575F5D15A8B947400A2C802903F14B4071395E81E8BF47400A2C802903F14B4071395E81E8BF47408A3A730F09ED4B40575F5D15A8B947408A3A730F09ED4B40
61563	57859	47.450442000000002	47.499282999999998	55.882908999999998	55.851838999999998	Максима Горького	0103000020E61000000100000005000000575F5D15A8B947408A3A730F09ED4B40575F5D15A8B947400A2C802903F14B4071395E81E8BF47400A2C802903F14B4071395E81E8BF47408A3A730F09ED4B40575F5D15A8B947408A3A730F09ED4B40
61573	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	проезд Ельниковский	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61648	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	бульвар Зеленый	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61392	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Терешковой	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61628	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Строителей	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61673	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Солнечная	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61591	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Советская	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61671	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Силикатная	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61586	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Семенова	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61394	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Пионерская	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61574	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Первомайская	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61590	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Парковая	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
62762	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Ольдеевская	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61672	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Молодежная	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
9718	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Комсомольская	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61589	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Коммунистическая	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61627	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Жени Крутовой	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61630	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Винокурова	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61629	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	В-Интернационалистов	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61677	21149	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	10-й Пятилетки	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61890	57858	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Фурманова	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
61588	57858	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Николаева	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
61562	57858	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Ломоносова	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
61948	57858	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Ленинская	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
61808	57858	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Котовского	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
62011	12030	47.839151999999999	47.846634999999999	54.771459999999998	54.766250999999997	Канашская	0103000020E61000000100000005000000BE2F2E5569EB47407EC3448314624B40BE2F2E5569EB474009168733BF624B40115322895EEC474009168733BF624B40115322895EEC47407EC3448314624B40BE2F2E5569EB47407EC3448314624B40
61951	57914	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Школьная	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
61811	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	переулок Больничный	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61579	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	мкр Стрелка	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61651	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Южная	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61614	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Юбилейная	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61656	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Школьный Проезд	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61922	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Шаумяна	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61653	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Почтовая	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61621	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Первомайская	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61319	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Московская	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61645	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Ленина	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61619	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Комсомола	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61923	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Жуковского	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61620	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Димитрова	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61322	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Гончарова	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61580	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Гагарина	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61318	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Володарского	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61618	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Березовая	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61655	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	Артиллерийская	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61622	314	46.499035999999997	46.632840000000002	54.868403999999998	54.817458999999999	40 лет Победы	0103000020E6100000010000000500000069C36169E03F474012691B7FA2684B4069C36169E03F474098DBBDDC276F4B40E2CCAFE60051474098DBBDDC276F4B40E2CCAFE60051474012691B7FA2684B4069C36169E03F474012691B7FA2684B40
61916	20441	47.620412000000002	47.660620000000002	55.569713	55.553865000000002	Школьная	0103000020E61000000100000005000000E20511A969CF474014B35E0CE5C64B40E20511A969CF4740938D075BECC84B40B18A37328FD44740938D075BECC84B40B18A37328FD4474014B35E0CE5C64B40E20511A969CF474014B35E0CE5C64B40
61642	20068	47.763657000000002	47.787804000000001	55.532955999999999	55.505673999999999	проспект Ленина	0103000020E61000000100000005000000452E3883BFE147400038F6ECB9C04B40452E3883BFE147407E1AF7E637C44B4039D4EFC2D6E447407E1AF7E637C44B4039D4EFC2D6E447400038F6ECB9C04B40452E3883BFE147400038F6ECB9C04B40
61836	20068	47.763657000000002	47.787804000000001	55.532955999999999	55.505673999999999	Ленина	0103000020E61000000100000005000000452E3883BFE147400038F6ECB9C04B40452E3883BFE147407E1AF7E637C44B4039D4EFC2D6E447407E1AF7E637C44B4039D4EFC2D6E447400038F6ECB9C04B40452E3883BFE147400038F6ECB9C04B40
61915	19960	47.928570000000001	47.961852999999998	55.552199999999999	55.541311	Коммунистическая	0103000020E61000000100000005000000FB05BB61DBF6474087FBC8AD49C54B40FB05BB61DBF64740F46C567DAEC64B409D47C5FF1DFB4740F46C567DAEC64B409D47C5FF1DFB474087FBC8AD49C54B40FB05BB61DBF6474087FBC8AD49C54B40
62902	19179	47.820915999999997	47.844037999999998	55.527982999999999	55.517200000000003	Николаева	0103000020E61000000100000005000000AE6186C613E94740E0BE0E9C33C24B40AE6186C613E9474007EC6AF294C34B40664AEB6F09EC474007EC6AF294C34B40664AEB6F09EC4740E0BE0E9C33C24B40AE6186C613E94740E0BE0E9C33C24B40
62661	19020	47.718947999999997	47.744900000000001	55.576349999999998	55.565544000000003	Ильича	0103000020E6100000010000000500000026C3F17C06DC47407A39ECBE63C84B4026C3F17C06DC4740598638D6C5C94B402C6519E258DF4740598638D6C5C94B402C6519E258DF47407A39ECBE63C84B4026C3F17C06DC47407A39ECBE63C84B40
61898	19592	47.75665	47.790273999999997	55.449525999999999	55.429180000000002	Калинина	0103000020E610000001000000050000005B423EE8D9E04740740CC85EEFB64B405B423EE8D9E04740D15966118AB94B408670CCB227E54740D15966118AB94B408670CCB227E54740740CC85EEFB64B405B423EE8D9E04740740CC85EEFB64B40
61838	19488	47.645240999999999	47.683204000000003	55.521669000000003	55.504792000000002	Советская	0103000020E61000000100000005000000E884D04197D2474027A435069DC04B40E884D04197D24740242BBF0CC6C24B408A3F8A3A73D74740242BBF0CC6C24B408A3F8A3A73D7474027A435069DC04B40E884D04197D2474027A435069DC04B40
62095	19121	47.911996000000002	47.941721000000001	55.511012000000001	55.501849999999997	А. Егоровой	0103000020E610000001000000050000009A0AF148BCF44740B1BFEC9E3CC04B409A0AF148BCF4474089EE59D768C14B406C7A50508AF8474089EE59D768C14B406C7A50508AF84740B1BFEC9E3CC04B409A0AF148BCF44740B1BFEC9E3CC04B40
62660	19442	47.782836000000003	47.803066000000001	55.556089999999998	55.546379000000002	Ленина	0103000020E61000000100000005000000D41055F833E44740501C40BFEFC54B40D41055F833E44740FAD005F52DC74B40C843DFDDCAE64740FAD005F52DC74B40C843DFDDCAE64740501C40BFEFC54B40D41055F833E44740501C40BFEFC54B40
62778	20313	47.809049000000002	47.833483000000001	55.511088000000001	55.496766000000001	Родник	0103000020E6100000010000000500000046EEE9EA8EE74740E3E13D0796BF4B4046EEE9EA8EE7474064B0E2546BC14B40D0622992AFEA474064B0E2546BC14B40D0622992AFEA4740E3E13D0796BF4B4046EEE9EA8EE74740E3E13D0796BF4B40
62127	20263	47.723449000000002	47.743589	55.531993	55.525191	Центральная	0103000020E6100000010000000500000076A911FA99DC4740A7936C7539C34B4076A911FA99DC4740B859BC5818C44B402A55A2EC2DDF4740B859BC5818C44B402A55A2EC2DDF4740A7936C7539C34B4076A911FA99DC4740A7936C7539C34B40
62914	18971	47.755312000000004	47.774670999999998	55.612029	55.601593999999999	Гагарина	0103000020E6100000010000000500000060234910AEE0474023BC3D0801CD4B4060234910AEE047400F9A5DF756CE4B406E14596B28E347400F9A5DF756CE4B406E14596B28E3474023BC3D0801CD4B4060234910AEE0474023BC3D0801CD4B40
62096	20528	47.688073000000003	47.706093000000003	55.547865999999999	55.537785999999997	Центральная	0103000020E610000001000000050000005C21ACC612D84740921FF12BD6C44B405C21ACC612D84740904B1C7920C64B409F77634161DA4740904B1C7920C64B409F77634161DA4740921FF12BD6C44B405C21ACC612D84740921FF12BD6C44B40
62912	19908	47.775793	47.797550999999999	55.378129999999999	55.365524999999998	Ленина	0103000020E610000001000000050000009DBB5D2F4DE34740696FF085C9AE4B409DBB5D2F4DE3474078D1579066B04B4030F2B22616E6474078D1579066B04B4030F2B22616E64740696FF085C9AE4B409DBB5D2F4DE34740696FF085C9AE4B40
62903	19384	47.790193000000002	47.810800999999998	55.57009	55.557872000000003	Комсомольская	0103000020E610000001000000050000009A43520B25E5474054AD855968C74B409A43520B25E5474069E388B5F8C84B403448C153C8E7474069E388B5F8C84B403448C153C8E7474054AD855968C74B409A43520B25E5474054AD855968C74B40
62910	20021	47.875523999999999	47.902070000000002	55.574894999999998	55.556705999999998	Пролетарская	0103000020E610000001000000050000007A6EA12B11F0474055BE672442C74B407A6EA12B11F0474024D1CB2896C94B40F3599E0777F3474024D1CB2896C94B40F3599E0777F3474055BE672442C74B407A6EA12B11F0474055BE672442C74B40
62776	19239	47.803694999999998	47.833447	55.479168999999999	55.463549	Ленина	0103000020E61000000100000005000000B77A4E7ADFE64740F88BD99255BB4B40B77A4E7ADFE64740E620E86855BD4B4083F92B64AEEA4740E620E86855BD4B4083F92B64AEEA4740F88BD99255BB4B40B77A4E7ADFE64740F88BD99255BB4B40
62664	19551	47.690966000000003	47.718570999999997	55.51173	55.500106000000002	Ленина	0103000020E61000000100000005000000F052EA9271D847404644317903C04B40F052EA9271D84740E8305F5E80C14B40506D7022FADB4740E8305F5E80C14B40506D7022FADB47404644317903C04B40F052EA9271D847404644317903C04B40
62905	19329	47.895332000000003	47.913145999999998	55.469386999999998	55.454324999999997	Первомайская	0103000020E61000000100000005000000F9872D3D9AF24740AA60545227BA4B40F9872D3D9AF2474072158BDF14BC4B40923CD7F7E1F4474072158BDF14BC4B40923CD7F7E1F44740AA60545227BA4B40F9872D3D9AF24740AA60545227BA4B40
62030	19805	47.688836999999999	47.715777000000003	55.449409000000003	55.429496999999998	Советская	0103000020E610000001000000050000002BA391CF2BD84740745DF8C1F9B64B402BA391CF2BD8474098C3EE3B86B94B40501DAB949EDB474098C3EE3B86B94B40501DAB949EDB4740745DF8C1F9B64B402BA391CF2BD84740745DF8C1F9B64B40
62662	19086	47.856048999999999	47.882638999999998	55.525033000000001	55.510109	Чапаева	0103000020E6100000010000000500000002637D0393ED4740983270404BC14B4002637D0393ED47400F29064834C34B404A969350FAF047400F29064834C34B404A969350FAF04740983270404BC14B4002637D0393ED4740983270404BC14B40
62907	20184	47.735306000000001	47.752077999999997	55.508966999999998	55.500329999999998	Школьная	0103000020E61000000100000005000000BB46CB811EDE4740959A3DD00AC04B40BB46CB811EDE474022DFA5D425C14B404205871744E0474022DFA5D425C14B404205871744E04740959A3DD00AC04B40BB46CB811EDE4740959A3DD00AC04B40
62607	19283	47.872478999999998	47.897488000000003	55.484357000000003	55.473255000000002	Первомайская	0103000020E6100000010000000500000030B95164ADEF474091D5AD9E93BC4B4030B95164ADEF47405A4B0169FFBD4B40B74604E3E0F247405A4B0169FFBD4B40B74604E3E0F2474091D5AD9E93BC4B4030B95164ADEF474091D5AD9E93BC4B40
62904	18910	47.716154000000003	47.744388000000001	55.591813000000002	55.578319999999998	Ленина	0103000020E6100000010000000500000026732CEFAADB4740B54FC76306CA4B4026732CEFAADB4740802C4487C0CB4B4076C4211B48DF4740802C4487C0CB4B4076C4211B48DF4740B54FC76306CA4B4026732CEFAADB4740B54FC76306CA4B40
62665	19704	47.713217	47.740093999999999	55.463028000000001	55.450465999999999	Школьная	0103000020E61000000100000005000000C2F9D4B14ADB4740DFFAB0DEA8B94B40C2F9D4B14ADB4740EF90628044BB4B40A0FB7266BBDE4740EF90628044BB4B40A0FB7266BBDE4740DFFAB0DEA8B94B40C2F9D4B14ADB4740DFFAB0DEA8B94B40
62780	19640	47.844470000000001	47.866855999999999	55.428981	55.415835000000001	Ленина	0103000020E61000000100000005000000003ACC9717EC47401EC4CE143AB54B40003ACC9717EC47407DCD72D9E8B64B40B22B2D23F5EE47407DCD72D9E8B64B40B22B2D23F5EE47401EC4CE143AB54B40003ACC9717EC47401EC4CE143AB54B40
62128	18876	47.746597999999999	47.773879999999998	55.593353999999998	55.580207000000001	Воробьева	0103000020E6100000010000000500000027A1F48590DF474084F4143944CA4B4027A1F48590DF4740B3791C06F3CB4B40A583F57F0EE34740B3791C06F3CB4B40A583F57F0EE3474084F4143944CA4B4027A1F48590DF474084F4143944CA4B40
79402	61568	47.987841000000003	48.029207999999997	55.167574999999999	55.155546000000001	Центральная	0103000020E61000000100000005000000F052EA9271FE474006836BEEE8934B40F052EA9271FE47404850FC1873954B400A647616BD0348404850FC1873954B400A647616BD03484006836BEEE8934B40F052EA9271FE474006836BEEE8934B40
62682	16627	47.987841000000003	48.029207999999997	55.167574999999999	55.155546000000001	Юбилейная	0103000020E61000000100000005000000F052EA9271FE474006836BEEE8934B40F052EA9271FE47404850FC1873954B400A647616BD0348404850FC1873954B400A647616BD03484006836BEEE8934B40F052EA9271FE474006836BEEE8934B40
61578	16627	47.987841000000003	48.029207999999997	55.167574999999999	55.155546000000001	Иванова	0103000020E61000000100000005000000F052EA9271FE474006836BEEE8934B40F052EA9271FE47404850FC1873954B400A647616BD0348404850FC1873954B400A647616BD03484006836BEEE8934B40F052EA9271FE474006836BEEE8934B40
62924	52532	47.876665000000003	47.893211999999998	55.035524000000002	55.025435999999999	Больничная	0103000020E610000001000000050000002046088F36F047400E12A27C41834B402046088F36F047408F1CE90C8C844B40873254C554F247408F1CE90C8C844B40873254C554F247400E12A27C41834B402046088F36F047400E12A27C41834B40
62100	52504	47.741469000000002	47.756255000000003	55.229146999999998	55.222856999999998	Кооперативная	0103000020E61000000100000005000000B9FFC874E8DE4740A3570394869C4B40B9FFC874E8DE4740FE7C5BB0549D4B40DF37BEF6CCE04740FE7C5BB0549D4B40DF37BEF6CCE04740A3570394869C4B40B9FFC874E8DE4740A3570394869C4B40
62906	52514	47.888891000000001	47.927312000000001	54.979185000000001	54.965206999999999	Братьев Денисовых 	0103000020E61000000100000005000000B85A272EC7F14740656F29E78B7B4B40B85A272EC7F14740ECDD1FEF557D4B401C98DC28B2F64740ECDD1FEF557D4B401C98DC28B2F64740656F29E78B7B4B40B85A272EC7F14740656F29E78B7B4B40
61835	21314	47.965634000000001	47.989071000000003	55.201587000000004	55.183599999999998	Анаткасс	0103000020E61000000100000005000000EDF318E599FB4740D6C56D3480974B40EDF318E599FB47403E26529ACD994B400536E7E099FE47403E26529ACD994B400536E7E099FE4740D6C56D3480974B40EDF318E599FB4740D6C56D3480974B40
62923	52551	47.886609999999997	47.922111000000001	55.160308999999998	55.147196000000001	Центральная	0103000020E610000001000000050000003D27BD6F7CF147400F0D8B51D7924B403D27BD6F7CF1474092205C0185944B401424B6BB07F6474092205C0185944B401424B6BB07F647400F0D8B51D7924B403D27BD6F7CF147400F0D8B51D7924B40
62874	52502	47.798870999999998	47.811115000000001	55.255220999999999	55.243910999999997	Центральная	0103000020E61000000100000005000000855CA96741E647403C11C479389F4B40855CA96741E647404F20EC14ABA04B40C425C79DD2E747404F20EC14ABA04B40C425C79DD2E747403C11C479389F4B40855CA96741E647403C11C479389F4B40
62901	52167	47.853569999999998	47.876134999999998	55.178742999999997	55.169888999999998	Мостовая	0103000020E61000000100000005000000616C21C841ED47409E7939ECBE954B40616C21C841ED4740C8B1F50CE1964B40C3F0113125F04740C8B1F50CE1964B40C3F0113125F047409E7939ECBE954B40616C21C841ED47409E7939ECBE954B40
62769	52167	47.853569999999998	47.876134999999998	55.178742999999997	55.169888999999998	Ленина	0103000020E61000000100000005000000616C21C841ED47409E7939ECBE954B40616C21C841ED4740C8B1F50CE1964B40C3F0113125F04740C8B1F50CE1964B40C3F0113125F047409E7939ECBE954B40616C21C841ED47409E7939ECBE954B40
79399	58055	47.741819	47.759982999999998	55.181533999999999	55.168289999999999	Центральная	0103000020E610000001000000050000009546CCECF3DE4740361FD7868A954B409546CCECF3DE4740588E90813C974B400B42791F47E14740588E90813C974B400B42791F47E14740361FD7868A954B409546CCECF3DE4740361FD7868A954B40
63032	58055	47.741819	47.759982999999998	55.181533999999999	55.168289999999999	Полевая	0103000020E610000001000000050000009546CCECF3DE4740361FD7868A954B409546CCECF3DE4740588E90813C974B400B42791F47E14740588E90813C974B400B42791F47E14740361FD7868A954B409546CCECF3DE4740361FD7868A954B40
62829	58031	47.992089999999997	48.003453999999998	55.285687000000003	55.279262000000003	Садовая	0103000020E6100000010000000500000025581CCEFCFE4740FE8172DBBEA34B4025581CCEFCFE474039F2406491A44B402B85402E7100484039F2406491A44B402B85402E71004840FE8172DBBEA34B4025581CCEFCFE4740FE8172DBBEA34B40
79401	21749	48.001261999999997	48.012607000000003	55.115006999999999	55.106695999999999	Новая	0103000020E61000000100000005000000205D6C5A29004840984EEB36A88D4B40205D6C5A29004840D1E7A38CB88E4B40B0592E1B9D014840D1E7A38CB88E4B40B0592E1B9D014840984EEB36A88D4B40205D6C5A29004840984EEB36A88D4B40
62879	52508	47.806973999999997	47.827995000000001	55.168284999999997	55.158940000000001	Центральная	0103000020E61000000100000005000000745C8DEC4AE747405C035B2558944B40745C8DEC4AE7474024B4E55C8A954B4032207BBDFBE9474024B4E55C8A954B4032207BBDFBE947405C035B2558944B40745C8DEC4AE747405C035B2558944B40
61897	32750	47.815122000000002	47.843994000000002	55.205784000000001	55.192466000000003	Центральная	0103000020E610000001000000050000000420EEEA55E84740C5CBD3B9A2984B400420EEEA55E8474021054F21579A4B409702D2FE07EC474021054F21579A4B409702D2FE07EC4740C5CBD3B9A2984B400420EEEA55E84740C5CBD3B9A2984B40
62039	4927	47.890715	47.909219999999998	55.095455999999999	55.089556999999999	Восточная	0103000020E610000001000000050000004087F9F202F247405E10919A768B4B404087F9F202F247407E1AF7E6378C4B403F6F2A5261F447407E1AF7E6378C4B403F6F2A5261F447405E10919A768B4B404087F9F202F247405E10919A768B4B40
62650	52493	48.011817000000001	48.025606000000003	55.150123999999998	55.143321999999998	Центральная	0103000020E61000000100000005000000B7442E38830148400E66136058924B40B7442E38830148401F2C634337934B406B4AB20E470348401F2C634337934B406B4AB20E470348400E66136058924B40B7442E38830148400E66136058924B40
62920	52509	47.811942000000002	47.841118999999999	55.160730000000001	55.148215	Центральная	0103000020E61000000100000005000000DA1F28B7EDE7474069E388B5F8924B40DA1F28B7EDE7474038BEF6CC92944B40A98592C9A9EB474038BEF6CC92944B40A98592C9A9EB474069E388B5F8924B40DA1F28B7EDE7474069E388B5F8924B40
77546	52518	47.951431999999997	47.969551000000003	55.061157999999999	55.044165	Ленина	0103000020E61000000100000005000000162F1686C8F947405D50DF32A7854B40162F1686C8F94740C3F17C06D4874B40ED66463F1AFC4740C3F17C06D4874B40ED66463F1AFC47405D50DF32A7854B40162F1686C8F947405D50DF32A7854B40
61896	32529	47.947426	47.979028	55.229120999999999	55.212175000000002	Новая	0103000020E61000000100000005000000A7B0524145F94740B003E78C289B4B40A7B0524145F94740D5E940D6539D4B4024EF1CCA50FD4740D5E940D6539D4B4024EF1CCA50FD4740B003E78C289B4B40A7B0524145F94740B003E78C289B4B40
62601	32814	47.982640000000004	48.008457	55.039048000000001	55.014071000000001	Солдатская	0103000020E61000000100000005000000E8DEC325C7FD474038691A14CD814B40E8DEC325C7FD4740B37C5D86FF844B400D36751E15014840B37C5D86FF844B400D36751E1501484038691A14CD814B40E8DEC325C7FD474038691A14CD814B40
62775	32873	47.843876999999999	47.870888999999998	55.076731000000002	55.064483000000003	Кирова	0103000020E610000001000000050000005D6C5A2904EC4740F1129CFA40884B405D6C5A2904EC474071CB4752D2894B401BB96E4A79EF474071CB4752D2894B401BB96E4A79EF4740F1129CFA40884B405D6C5A2904EC4740F1129CFA40884B40
62777	52525	47.929675000000003	47.955312999999997	55.102739999999997	55.092489	Центральная	0103000020E6100000010000000500000054742497FFF64740B01EF7ADD68B4B4054742497FFF64740DAFE9595268D4B40C93846B247FA4740DAFE9595268D4B40C93846B247FA4740B01EF7ADD68B4B4054742497FFF64740B01EF7ADD68B4B40
61845	32653	48.041316999999999	48.075507000000002	55.182994000000001	55.161949	Кооперативная	0103000020E6100000010000000500000069E21DE049054840594FADBEBA944B4069E21DE0490548409FAEEE586C974B403ECF9F36AA0948409FAEEE586C974B403ECF9F36AA094840594FADBEBA944B4069E21DE049054840594FADBEBA944B40
62931	32692	47.913648999999999	47.938127999999999	55.252014000000003	55.236119000000002	Школьная	0103000020E61000000100000005000000F5824F73F2F447406C7BBB25399E4B40F5824F73F2F447402C11A8FE41A04B401FBB0B9414F847402C11A8FE41A04B401FBB0B9414F847406C7BBB25399E4B40F5824F73F2F447406C7BBB25399E4B40
62608	32692	47.913648999999999	47.938127999999999	55.252014000000003	55.236119000000002	Центральная	0103000020E61000000100000005000000F5824F73F2F447406C7BBB25399E4B40F5824F73F2F447402C11A8FE41A04B401FBB0B9414F847402C11A8FE41A04B401FBB0B9414F847406C7BBB25399E4B40F5824F73F2F447406C7BBB25399E4B40
77533	61200	47.883546000000003	47.898978999999997	55.290925999999999	55.280676999999997	Цетральная	0103000020E610000001000000050000007D410B0918F14740A4DE5339EDA34B407D410B0918F147402EC72B103DA54B4038656EBE11F347402EC72B103DA54B4038656EBE11F34740A4DE5339EDA34B407D410B0918F14740A4DE5339EDA34B40
63176	58073	47.892609999999998	47.915346999999997	55.315499000000003	55.300567000000001	Хурамакассы	0103000020E61000000100000005000000910A630B41F24740E0A0BDFA78A64B40910A630B41F24740DA756F4562A84B40F0BE2A172AF54740DA756F4562A84B40F0BE2A172AF54740E0A0BDFA78A64B40910A630B41F24740E0A0BDFA78A64B40
62759	25813	46.418322000000003	46.435929000000002	55.995463000000001	55.987734000000003	Шоссейная	0103000020E61000000100000005000000429946938B354740DA9255116EFE4B40429946938B35474064B0E2546BFF4B4062307F85CC37474064B0E2546BFF4B4062307F85CC374740DA9255116EFE4B40429946938B354740DA9255116EFE4B40
61900	9071	46.524593000000003	46.567442999999997	56.071725000000001	56.053995	Сюльдикасы	0103000020E61000000100000005000000F35A09DD25434740E292E34EE9064C40F35A09DD254347401EA7E8482E094C400CACE3F8A14847401EA7E8482E094C400CACE3F8A1484740E292E34EE9064C40F35A09DD25434740E292E34EE9064C40
61972	28913	46.341749999999998	46.390771000000001	55.989693000000003	55.963459999999998	Ленина	0103000020E6100000010000000500000039B4C876BE2B4740888043A852FB4B4039B4C876BE2B4740420A9E42AEFE4B40D49CBCC804324740420A9E42AEFE4B40D49CBCC804324740888043A852FB4B4039B4C876BE2B4740888043A852FB4B40
62688	15773	46.412196000000002	46.435479999999998	55.826256000000001	55.817819999999998	Березовая	0103000020E6100000010000000500000061C5A9D6C2344740E2016553AEE84B4061C5A9D6C2344740D80FB1C1C2E94B40F20703CFBD374740D80FB1C1C2E94B40F20703CFBD374740E2016553AEE84B4061C5A9D6C2344740E2016553AEE84B40
62018	15902	46.381833	46.405144	55.845986000000003	55.831260999999998	Калинина	0103000020E610000001000000050000004CC45BE7DF3047405AB8ACC266EA4B404CC45BE7DF304740DB6FED4449EC4B40D71533C2DB334740DB6FED4449EC4B40D71533C2DB3347405AB8ACC266EA4B404CC45BE7DF3047405AB8ACC266EA4B40
62126	15761	46.406796999999997	46.421143000000001	55.810622000000002	55.797331	Садовая	0103000020E61000000100000005000000328E91EC11344740228B34F10EE64B40328E91EC1134474085B53176C2E74B403CF88903E835474085B53176C2E74B403CF88903E8354740228B34F10EE64B40328E91EC11344740228B34F10EE64B40
62134	16457	46.193931999999997	46.220458999999998	55.832828999999997	55.817915999999997	30 лет Победы	0103000020E61000000100000005000000EDD286C3D21847400470B378B1E84B40EDD286C3D2184740871403249AEA4B40EF8D2100381C4740871403249AEA4B40EF8D2100381C47400470B378B1E84B40EDD286C3D21847400470B378B1E84B40
62000	14917	46.164026999999997	46.184904000000003	55.974111000000001	55.956707999999999	40 лет Победы	0103000020E610000001000000050000009B5434D6FE14474029E9616875FA4B409B5434D6FE14474041D653ABAFFC4B4026732CEFAA17474041D653ABAFFC4B4026732CEFAA17474029E9616875FA4B409B5434D6FE14474029E9616875FA4B40
61999	15567	46.483305999999999	46.500535999999997	55.840122999999998	55.834735000000002	Ленина	0103000020E61000000100000005000000F4FA93F8DC3D4740CDE9B298D8EA4B40F4FA93F8DC3D474007CF842689EB4B403E3C4B901140474007CF842689EB4B403E3C4B9011404740CDE9B298D8EA4B40F4FA93F8DC3D4740CDE9B298D8EA4B40
61856	57903	46.264161999999999	46.283107999999999	56.0458	56.040244000000001	Заводская	0103000020E61000000100000005000000486C770FD02147401CEE23B726054C40486C770FD021474012143FC6DC054C40349E08E23C24474012143FC6DC054C40349E08E23C2447401CEE23B726054C40486C770FD02147401CEE23B726054C40
61867	57906	46.534097000000003	46.561261999999999	55.866489999999999	55.851050000000001	Советская	0103000020E6100000010000000500000024F25D4A5D44474062A1D634EFEC4B4024F25D4A5D444740D027F224E9EE4B40683EE76ED7474740D027F224E9EE4B40683EE76ED747474062A1D634EFEC4B4024F25D4A5D44474062A1D634EFEC4B40
62125	15616	46.480755000000002	46.490969	55.859336999999996	55.848382000000001	Школьная	0103000020E61000000100000005000000BA313D61893D4740EE4108C897EC4B40BA313D61893D4740129F3BC1FEED4B40C72C7B12D83E4740129F3BC1FEED4B40C72C7B12D83E4740EE4108C897EC4B40BA313D61893D4740EE4108C897EC4B40
62133	16267	46.270316000000001	46.298101000000003	55.926923000000002	55.913974000000003	Шоссейная	0103000020E61000000100000005000000F3CAF5B69922474079B29B19FDF44B40F3CAF5B6992247408274B169A5F64B40D4F36E2C282647408274B169A5F64B40D4F36E2C2826474079B29B19FDF44B40F3CAF5B69922474079B29B19FDF44B40
62016	15693	46.425006000000003	46.444760000000002	55.786931000000003	55.777777999999998	Дружбы	0103000020E61000000100000005000000494DBB98663647402EC6C03A8EE34B40494DBB9866364740B39AAE27BAE44B40D4484BE5ED384740B39AAE27BAE44B40D4484BE5ED3847402EC6C03A8EE34B40494DBB98663647402EC6C03A8EE34B40
62130	26909	46.493583000000001	46.509608999999998	55.997447000000001	55.992598000000001	Новая	0103000020E61000000100000005000000486E4DBA2D3F47409A0986730DFF4B40486E4DBA2D3F4740253FE257ACFF4B40A65F22DE3A414740253FE257ACFF4B40A65F22DE3A4147409A0986730DFF4B40486E4DBA2D3F47409A0986730DFF4B40
62116	26342	46.404586999999999	46.435552000000001	56.032528999999997	56.016475999999997	Ленина	0103000020E6100000010000000500000081B1BE81C93347409E95B4E21B024C4081B1BE81C9334740F69507E929044C408CDAFD2AC0374740F69507E929044C408CDAFD2AC03747409E95B4E21B024C4081B1BE81C93347409E95B4E21B024C40
61912	16175	46.237670999999999	46.255197000000003	55.880853999999999	55.867373999999998	Шоссейная	0103000020E61000000100000005000000931ADA006C1E47404AB3791C06EF4B40931ADA006C1E47408046E9D2BFF04B40C784984BAA2047408046E9D2BFF04B40C784984BAA2047404AB3791C06EF4B40931ADA006C1E47404AB3791C06EF4B40
61831	15469	46.488444999999999	46.509250000000002	55.957040999999997	55.941954000000003	Школьная	0103000020E610000001000000050000008672A25D853E47400F2BDCF291F84B408672A25D853E47402FF7C95180FA4B4077BE9F1A2F4147402FF7C95180FA4B4077BE9F1A2F4147400F2BDCF291F84B408672A25D853E47400F2BDCF291F84B40
61834	33121	46.385471000000003	46.422769000000002	55.790666000000002	55.778623000000003	Ленина	0103000020E6100000010000000500000039471D1D57314740EB7420EBA9E34B4039471D1D573147409207228B34E54B409E616A4B1D3647409207228B34E54B409E616A4B1D364740EB7420EBA9E34B4039471D1D57314740EB7420EBA9E34B40
62804	48216	46.464782999999997	46.4846	55.899926000000001	55.889688999999997	Ленина	0103000020E610000001000000050000004E5E64027E3B4740334E4354E1F14B404E5E64027E3B4740F96871C630F34B4020D26F5F073E4740F96871C630F34B4020D26F5F073E4740334E4354E1F14B404E5E64027E3B4740334E4354E1F14B40
62124	15193	46.400148999999999	46.420011000000002	55.942281999999999	55.931148999999998	Садовая	0103000020E6100000010000000500000078431A1538334740FF59F3E32FF74B4078431A153833474003CE52B29CF84B40EA7AA2EBC235474003CE52B29CF84B40EA7AA2EBC2354740FF59F3E32FF74B4078431A1538334740FF59F3E32FF74B40
62801	15102	46.462536999999998	46.479793999999998	56.061051999999997	56.054040000000001	Школьная	0103000020E6100000010000000500000050189469343B4740825660C8EA064C4050189469343B47407DAD4B8DD0074C409468C9E3693D47407DAD4B8DD0074C409468C9E3693D4740825660C8EA064C4050189469343B4740825660C8EA064C40
62015	16378	46.279756999999996	46.292253000000002	55.827382999999998	55.814093	Шоссейная	0103000020E61000000100000005000000DDE9CE13CF23474086730D3334E84B40DDE9CE13CF2347401822A7AFE7E94B403694DA8B682547401822A7AFE7E94B403694DA8B6825474086730D3334E84B40DDE9CE13CF23474086730D3334E84B40
61895	15081	46.446044000000001	46.468969000000001	56.097422000000002	56.082867999999998	Центральная	0103000020E61000000100000005000000DC4944F81739474045F12A6B9B0A4C40DC4944F81739474099F4F752780C4C403EEB1A2D073C474099F4F752780C4C403EEB1A2D073C474045F12A6B9B0A4C40DC4944F81739474045F12A6B9B0A4C40
61911	15839	46.432561	46.453949000000001	55.861832999999997	55.844233000000003	Центральная	0103000020E610000001000000050000003543AA285E3747401C9AB2D30FEC4B403543AA285E37474089CE328B50EE4B40A58636001B3A474089CE328B50EE4B40A58636001B3A47401C9AB2D30FEC4B403543AA285E3747401C9AB2D30FEC4B40
61913	7574	46.315286	46.363506999999998	55.885962999999997	55.868991000000001	Шоссейная	0103000020E610000001000000050000007E71A94A5B28474059C2DA183BEF4B407E71A94A5B284740A73B4F3C67F14B40FC6EBA65872E4740A73B4F3C67F14B40FC6EBA65872E474059C2DA183BEF4B407E71A94A5B28474059C2DA183BEF4B40
62702	7574	46.315286	46.363506999999998	55.885962999999997	55.868991000000001	Ценральная	0103000020E610000001000000050000007E71A94A5B28474059C2DA183BEF4B407E71A94A5B284740A73B4F3C67F14B40FC6EBA65872E4740A73B4F3C67F14B40FC6EBA65872E474059C2DA183BEF4B407E71A94A5B28474059C2DA183BEF4B40
62797	15171	46.360570000000003	46.401271999999999	56.011847000000003	56.001091000000002	Первомайская	0103000020E6100000010000000500000099F56228272E4740F4A8F8BF23004C4099F56228272E474022C7D63384014C40776682E15C33474022C7D63384014C40776682E15C334740F4A8F8BF23004C4099F56228272E4740F4A8F8BF23004C40
62025	16531	46.570138	46.596018000000001	55.848872	55.831265999999999	Алины Ивановой	0103000020E610000001000000050000007A1A3048FA4847406C239EEC66EA4B407A1A3048FA484740BC3E73D6A7EC4B40E6E95C514A4C4740BC3E73D6A7EC4B40E6E95C514A4C47406C239EEC66EA4B407A1A3048FA4847406C239EEC66EA4B40
62022	16475	46.118589999999998	46.139736999999997	55.833531000000001	55.817900999999999	Мира	0103000020E61000000100000005000000FAD005F52D0F4740CF2EDFFAB0E84B40FAD005F52D0F4740E199D024B1EA4B404485EAE6E2114740E199D024B1EA4B404485EAE6E2114740CF2EDFFAB0E84B40FAD005F52D0F4740CF2EDFFAB0E84B40
62014	15293	46.422203000000003	46.449727000000003	55.971753	55.960251	Пролетарская	0103000020E61000000100000005000000F5A276BF0A364740C4793881E9FA4B40F5A276BF0A3647401B65FD6662FC4B40699082A7903947401B65FD6662FC4B40699082A790394740C4793881E9FA4B40F5A276BF0A364740C4793881E9FA4B40
62032	11292	46.499367999999997	46.517235999999997	56.082160000000002	56.072277999999997	Центральная	0103000020E610000001000000050000009F55664AEB3F4740321CCF6740094C409F55664AEB3F47400A850838840A4C402C280CCA344247400A850838840A4C402C280CCA34424740321CCF6740094C409F55664AEB3F4740321CCF6740094C40
62019	15978	46.339145000000002	46.368519999999997	55.817036000000002	55.801591999999999	Ленина	0103000020E610000001000000050000000CCD751A692B47401C5E10919AE64B400CCD751A692B4740CCD3B9A294E84B4001F6D1A92B2F4740CCD3B9A294E84B4001F6D1A92B2F47401C5E10919AE64B400CCD751A692B47401C5E10919AE64B40
62803	15370	46.465420999999999	46.499943000000002	55.929918999999998	55.915371999999998	пер.Школьный	0103000020E6100000010000000500000091EF52EA923B474049D6E1E82AF54B4091EF52EA923B4740EA76F69507F74B409C6ED921FE3F4740EA76F69507F74B409C6ED921FE3F474049D6E1E82AF54B4091EF52EA923B474049D6E1E82AF54B40
62810	16043	46.328167000000001	46.344462999999998	55.847568000000003	55.835169	Шоссейная	0103000020E610000001000000050000002F505260012A474007D15AD1E6EA4B402F505260012A47406D91B41B7DEC4B404DD7135D172C47406D91B41B7DEC4B404DD7135D172C474007D15AD1E6EA4B402F505260012A474007D15AD1E6EA4B40
62679	16220	46.278491000000002	46.304703000000003	55.884883000000002	55.875728000000002	Школьная	0103000020E610000001000000050000007C9DD497A52347408318E8DA17F04B407C9DD497A5234740A8E49CD843F14B401EFF058200274740A8E49CD843F14B401EFF0582002747408318E8DA17F04B407C9DD497A52347408318E8DA17F04B40
62811	16004	46.282749000000003	46.298684999999999	55.873390000000001	55.861656000000004	Молодежная	0103000020E6100000010000000500000005FD851E312447407B336ABE4AEE4B4005FD851E31244740A453573ECBEF4B402367614F3B264740A453573ECBEF4B402367614F3B2647407B336ABE4AEE4B4005FD851E312447407B336ABE4AEE4B40
62103	13658	46.625886999999999	46.646996999999999	55.606344	55.590713999999998	Комсомольская	0103000020E61000000100000005000000EBFEB1101D50474009A52F849CCB4B40EBFEB1101D5047401B1021AE9CCD4B4018CE35CCD05247401B1021AE9CCD4B4018CE35CCD052474009A52F849CCB4B40EBFEB1101D50474009A52F849CCB4B40
62118	57923	47.034889999999997	47.845044999999999	54.992899999999999	54.653542000000002	Центральная	0103000020E610000001000000050000008D7A884677844740FE47A643A7534B408D7A8846778447406519E258177F4B40FC523F6F2AEC47406519E258177F4B40FC523F6F2AEC4740FE47A643A7534B408D7A884677844740FE47A643A7534B40
61757	11874	47.488872000000001	47.539338999999998	54.895553	54.879447999999996	Советская	0103000020E610000001000000050000000EF7915B93BE47402C4487C091704B400EF7915B93BE4740D76A0F7BA1724B408A3A730F09C54740D76A0F7BA1724B408A3A730F09C547402C4487C091704B400EF7915B93BE47402C4487C091704B40
61893	11874	47.488872000000001	47.539338999999998	54.895553	54.879447999999996	Лесхозная	0103000020E610000001000000050000000EF7915B93BE47402C4487C091704B400EF7915B93BE4740D76A0F7BA1724B408A3A730F09C54740D76A0F7BA1724B408A3A730F09C547402C4487C091704B400EF7915B93BE47402C4487C091704B40
61908	12761	47.746077	47.768849000000003	54.905824000000003	54.889319	Чапаева	0103000020E610000001000000050000001EA67D737FDF4740105B7A34D5714B401EA67D737FDF474049F7730AF2734B40FA47DFA469E2474049F7730AF2734B40FA47DFA469E24740105B7A34D5714B401EA67D737FDF4740105B7A34D5714B40
62115	12707	47.575406000000001	47.607197999999997	54.861289999999997	54.843673000000003	переулок Центральный	0103000020E610000001000000050000000AF65FE7A6C9474055C2137AFD6B4B400AF65FE7A6C94740982F2FC03E6E4B402A1900AAB8CD4740982F2FC03E6E4B402A1900AAB8CD474055C2137AFD6B4B400AF65FE7A6C9474055C2137AFD6B4B40
61899	12659	47.652625	47.691719999999997	54.939774999999997	54.910958999999998	Спортивная	0103000020E61000000100000005000000A8C64B3789D34740997FF44D9A744B40A8C64B3789D34740984C158C4A784B409BFEEC478AD84740984C158C4A784B409BFEEC478AD84740997FF44D9A744B40A8C64B3789D34740997FF44D9A744B40
61983	12553	47.184882000000002	47.215280999999997	54.724162	54.702202999999997	Комсомольская	0103000020E610000001000000050000003ECF9F36AA9747409813B4C9E1594B403ECF9F36AA974740C3802557B15C4B409F39EB538E9B4740C3802557B15C4B409F39EB538E9B47409813B4C9E1594B403ECF9F36AA9747409813B4C9E1594B40
62677	12626	47.558957999999997	47.587327000000002	54.886615999999997	54.875481000000001	Чкалова	0103000020E6100000010000000500000035EB8CEF8BC747407BA2EBC20F704B4035EB8CEF8BC747401F0E12A27C714B406687F8872DCB47401F0E12A27C714B406687F8872DCB47407BA2EBC20F704B4035EB8CEF8BC747407BA2EBC20F704B40
61826	12771	47.149667999999998	47.169187999999998	54.705007000000002	54.69314	Октябрьская	0103000020E61000000100000005000000FDA02E522893474054C6BFCFB8584B40FDA02E5228934740BD395CAB3D5A4B401570CFF3A7954740BD395CAB3D5A4B401570CFF3A795474054C6BFCFB8584B40FDA02E522893474054C6BFCFB8584B40
62111	12138	47.525621999999998	47.551789999999997	54.882855999999997	54.871901000000001	Кудряшова	0103000020E610000001000000050000007007EA9447C34740C32CB4739A6F4B407007EA9447C34740E789E76C01714B404221020EA1C64740E789E76C01714B404221020EA1C64740C32CB4739A6F4B407007EA9447C34740C32CB4739A6F4B40
62795	12525	47.627795999999996	47.656703999999998	54.924221000000003	54.910269999999997	Карла Маркса	0103000020E61000000100000005000000A1478C9E5BD04740D44334BA83744B40A1478C9E5BD0474062A3ACDF4C764B4081936DE00ED4474062A3ACDF4C764B4081936DE00ED44740D44334BA83744B40A1478C9E5BD04740D44334BA83744B40
63116	58065	47.034889999999997	47.845044999999999	54.992899999999999	54.653542000000002	Овражная	0103000020E610000001000000050000008D7A884677844740FE47A643A7534B408D7A8846778447406519E258177F4B40FC523F6F2AEC47406519E258177F4B40FC523F6F2AEC4740FE47A643A7534B408D7A884677844740FE47A643A7534B40
61907	12463	47.628748000000002	47.650630999999997	54.880681000000003	54.863041000000003	Карла Маркса	0103000020E6100000010000000500000074B680D07AD04740B70DA320786E4B4074B680D07AD04740B39AAE27BA704B40C36169E047D34740B39AAE27BA704B40C36169E047D34740B70DA320786E4B4074B680D07AD04740B70DA320786E4B40
61568	12412	47.501987	47.531964000000002	54.972302999999997	54.958834000000003	Советская	0103000020E6100000010000000500000032022A1C41C047407D259012BB7A4B4032022A1C41C04740BE66B96C747C4B401E53776517C44740BE66B96C747C4B401E53776517C447407D259012BB7A4B4032022A1C41C047407D259012BB7A4B40
62789	12367	47.574902999999999	47.605401000000001	54.914281000000003	54.902962000000002	Ленина	0103000020E61000000100000005000000A7AFE76B96C94740F0C3414294734B40A7AFE76B96C94740562DE92807754B409CFBABC77DCD4740562DE92807754B409CFBABC77DCD4740F0C3414294734B40A7AFE76B96C94740F0C3414294734B40
62012	12313	47.598267999999997	47.624805000000002	54.903489999999998	54.890929999999997	Карла Маркса	0103000020E61000000100000005000000251FBB0B94CC47403C8386FE09724B40251FBB0B94CC4740AB21718FA5734B404BB0389CF9CF4740AB21718FA5734B404BB0389CF9CF47403C8386FE09724B40251FBB0B94CC47403C8386FE09724B40
61910	12286	47.288305000000001	47.325189999999999	54.769871000000002	54.751539000000001	Мичурина	0103000020E61000000100000005000000FB22A12DE7A447409355116E32604B40FB22A12DE7A44740C59107228B624B403D7E6FD39FA94740C59107228B624B403D7E6FD39FA947409355116E32604B40FB22A12DE7A447409355116E32604B40
62113	12215	47.703901000000002	47.746355999999999	54.952629999999999	54.935358999999998	Чапаева	0103000020E61000000100000005000000944F8F6D19DA47407782FDD7B9774B40944F8F6D19DA47402098A3C7EF794B403196E99788DF47402098A3C7EF794B403196E99788DF47407782FDD7B9774B40944F8F6D19DA47407782FDD7B9774B40
61997	12167	47.323329999999999	47.363098000000001	54.768453000000001	54.757908	Кирова	0103000020E6100000010000000500000068E89FE062A947403AB01C2103614B4068E89FE062A94740ADC1FBAA5C624B401B9FC9FE79AE4740ADC1FBAA5C624B401B9FC9FE79AE47403AB01C2103614B4068E89FE062A947403AB01C2103614B40
62675	11961	47.470196000000001	47.496031000000002	54.881064000000002	54.862206999999998	Гагарина	0103000020E61000000100000005000000E25AED612FBC4740EEB089CC5C6E4B40E25AED612FBC47406BD784B4C6704B40AE669DF17DBF47406BD784B4C6704B40AE669DF17DBF4740EEB089CC5C6E4B40E25AED612FBC4740EEB089CC5C6E4B40
61906	57911	47.443776	47.462721999999999	56.074066999999999	56.059880999999997	Школьная	0103000020E61000000100000005000000F65FE7A6CDB847406D533C2EAA074C40F65FE7A6CDB847403E5B07077B094C40E29178793ABB47403E5B07077B094C40E29178793ABB47406D533C2EAA074C40F65FE7A6CDB847406D533C2EAA074C40
61823	33097	47.093631000000002	47.114508000000001	56.094991999999998	56.085766	Садовая	0103000020E610000001000000050000002672C119FC8B4740EB8D5A61FA0A4C402672C119FC8B4740D9B0A6B2280C4C40B090B932A88E4740D9B0A6B2280C4C40B090B932A88E4740EB8D5A61FA0A4C402672C119FC8B4740EB8D5A61FA0A4C40
61902	33010	46.946936000000001	46.96669	55.934744000000002	55.920931000000003	Центральная	0103000020E61000000100000005000000D9B3E73235794740B16F2711E1F54B40D9B3E73235794740ED10FFB0A5F74B4064AF777FBC7B4740ED10FFB0A5F74B4064AF777FBC7B4740B16F2711E1F54B40D9B3E73235794740B16F2711E1F54B40
62674	52349	47.419333000000002	47.435071000000001	56.096378000000001	56.085369999999998	Магазинная	0103000020E61000000100000005000000199128B4ACB547409E077767ED0A4C40199128B4ACB54740E606431D560C4C4011381268B0B74740E606431D560C4C4011381268B0B747409E077767ED0A4C40199128B4ACB547409E077767ED0A4C40
61903	10433	47.114004999999999	47.145724000000001	56.018746	56.008470000000003	Школьная	0103000020E610000001000000050000004D4A41B7978E4740A27F828B15014C404D4A41B7978E47402577D84466024C40041F8315A79247402577D84466024C40041F8315A7924740A27F828B15014C404D4A41B7978E4740A27F828B15014C40
62028	52266	46.989282000000003	47.011308999999997	55.897801000000001	55.882711999999998	Октябрьская	0103000020E61000000100000005000000C042E6CAA07E4740B4E4F1B4FCF04B40C042E6CAA07E474076A8A624EBF24B404293C4927281474076A8A624EBF24B404293C49272814740B4E4F1B4FCF04B40C042E6CAA07E4740B4E4F1B4FCF04B40
61824	32540	47.455823000000002	47.49136	55.982199999999999	55.968730999999998	Шоссейная	0103000020E61000000100000005000000DFE1766858BA474089CF9D60FFFB4B40DFE1766858BA4740CB10C7BAB8FD4B4002486DE2E4BE4740CB10C7BAB8FD4B4002486DE2E4BE474089CF9D60FFFB4B40DFE1766858BA474089CF9D60FFFB4B40
61822	33081	47.183129999999998	47.201904999999996	55.994446000000003	55.981535000000001	Ворошилова	0103000020E610000001000000050000004F75C8CD709747408F705AF0A2FD4B404F75C8CD70974740ABD1AB014AFF4B400EF3E505D8994740ABD1AB014AFF4B400EF3E505D89947408F705AF0A2FD4B404F75C8CD709747408F705AF0A2FD4B40
62008	52270	47.030192	47.039777000000001	55.944904000000001	55.941001999999997	Солнечная	0103000020E61000000100000005000000E84CDA54DD8347403CBCE7C072F84B40E84CDA54DD83474007EE409DF2F84B400611A9691785474007EE409DF2F84B400611A969178547403CBCE7C072F84B40E84CDA54DD8347403CBCE7C072F84B40
61904	33146	47.339292999999998	47.362389	56.029612	56.019570999999999	Школьная	0103000020E610000001000000050000008061F9F36DAB47409A79724D81024C408061F9F36DAB4740DAC87553CA034C400FB743C362AE4740DAC87553CA034C400FB743C362AE47409A79724D81024C408061F9F36DAB47409A79724D81024C40
61821	9681	47.015962000000002	47.392724999999999	56.072951000000003	55.922656000000003	Школьный пер	0103000020E6100000010000000500000048FDF50A0B824740A6BA809719F64B4048FDF50A0B824740F29A577556094C402AA913D044B24740F29A577556094C402AA913D044B24740A6BA809719F64B4048FDF50A0B824740A6BA809719F64B40
61892	9681	47.015962000000002	47.392724999999999	56.072951000000003	55.922656000000003	11-ой Пятилетки	0103000020E6100000010000000500000048FDF50A0B824740A6BA809719F64B4048FDF50A0B824740F29A577556094C402AA913D044B24740F29A577556094C402AA913D044B24740A6BA809719F64B4048FDF50A0B824740A6BA809719F64B40
61905	11799	47.403216999999998	47.418326999999998	56.113726999999997	56.103597999999998	Магазинная	0103000020E610000001000000050000007A185A9D9CB347402BF702B3420D4C407A185A9D9CB347400AD6389B8E0E4C40530438BD8BB547400AD6389B8E0E4C40530438BD8BB547402BF702B3420D4C407A185A9D9CB347402BF702B3420D4C40
61816	9243	47.438198	47.456451000000001	55.998170999999999	55.986863	Ресторанная	0103000020E6100000010000000500000018963FDF16B84740F450DB8651FE4B4018963FDF16B8474066683C11C4FF4B40FE9C82FC6CBA474066683C11C4FF4B40FE9C82FC6CBA4740F450DB8651FE4B4018963FDF16B84740F450DB8651FE4B40
61995	9243	47.438198	47.456451000000001	55.998170999999999	55.986863	Молодежная	0103000020E6100000010000000500000018963FDF16B84740F450DB8651FE4B4018963FDF16B8474066683C11C4FF4B40FE9C82FC6CBA474066683C11C4FF4B40FE9C82FC6CBA4740F450DB8651FE4B4018963FDF16B84740F450DB8651FE4B40
62594	58003	47.414814	47.431370000000001	56.008142999999997	55.997084000000001	Молодежная	0103000020E6100000010000000500000023F609A018B54740B4AED172A0FF4B4023F609A018B547407D586FD40A014C40DE3CD52137B747407D586FD40A014C40DE3CD52137B74740B4AED172A0FF4B4023F609A018B54740B4AED172A0FF4B40
61755	33075	47.171461000000001	47.249282000000001	56.062313000000003	55.993701000000001	Школьная	0103000020E610000001000000050000000DC51D6FF29547405280289831FF4B400DC51D6FF2954740CE8E54DFF9074C40A1BDFA78E89F4740CE8E54DFF9074C40A1BDFA78E89F47405280289831FF4B400DC51D6FF29547405280289831FF4B40
61889	33075	47.171461000000001	47.249282000000001	56.062313000000003	55.993701000000001	Центральная	0103000020E610000001000000050000000DC51D6FF29547405280289831FF4B400DC51D6FF2954740CE8E54DFF9074C40A1BDFA78E89F4740CE8E54DFF9074C40A1BDFA78E89F47405280289831FF4B400DC51D6FF29547405280289831FF4B40
61901	9193	47.031089999999999	47.048597999999998	56.128565999999999	56.118862	Главная	0103000020E61000000100000005000000C79DD2C1FA8347405B5EB9DE360F4C40C79DD2C1FA83474053B0C6D974104C40545392753886474053B0C6D974104C4054539275388647405B5EB9DE360F4C40C79DD2C1FA8347405B5EB9DE360F4C40
61639	11734	47.265182000000003	47.381450999999998	56.087293000000003	56.028249000000002	Центральная	0103000020E6100000010000000500000073BED87BF1A147408692C9A99D034C4073BED87BF1A14740BA15C26A2C0B4C406403E962D3B04740BA15C26A2C0B4C406403E962D3B047408692C9A99D034C4073BED87BF1A147408692C9A99D034C40
62669	52256	47.088608999999998	47.104472999999999	56.072237999999999	56.060861000000003	Школьная	0103000020E61000000100000005000000CD902A8A578B47400A4D124BCA074C40CD902A8A578B4740A4C343183F094C4052280B5F5F8D4740A4C343183F094C4052280B5F5F8D47400A4D124BCA074C40CD902A8A578B47400A4D124BCA074C40
62005	57919	47.019151000000001	47.043585999999998	56.085434999999997	56.080531999999998	Медицинская	0103000020E61000000100000005000000C5573B8A73824740072461DF4E0A4C40C5573B8A738247408577B988EF0A4C401F48DE39948547408577B988EF0A4C401F48DE3994854740072461DF4E0A4C40C5573B8A73824740072461DF4E0A4C40
61817	57901	47.059764000000001	47.083739999999999	56.049601000000003	56.036724	Садовая	0103000020E6100000010000000500000034BDC458A6874740397D3D5FB3044C4034BDC458A6874740A96C585359064C40FBAE08FEB78A4740A96C585359064C40FBAE08FEB78A4740397D3D5FB3044C4034BDC458A6874740397D3D5FB3044C40
62793	52278	46.965117999999997	46.989426000000002	56.032589999999999	56.015127999999997	Лесная	0103000020E61000000100000005000000F56393FC887B47407FA0DCB6EF014C40F56393FC887B47409C16BCE82B044C40F3E7DB82A57E47409C16BCE82B044C40F3E7DB82A57E47407FA0DCB6EF014C40F56393FC887B47407FA0DCB6EF014C40
62112	52333	47.027982000000002	47.276662999999999	56.073563999999998	56.040410000000001	Октябрьская	0103000020E61000000100000005000000377007EA948347403737A6272C054C40377007EA94834740DB148F8B6A094C40B28174B169A34740DB148F8B6A094C40B28174B169A347403737A6272C054C40377007EA948347403737A6272C054C40
62911	52277	47.015450000000001	47.030496999999997	56.022725000000001	56.007252000000001	Речная	0103000020E61000000100000005000000925CFE43FA814740516A2FA2ED004C40925CFE43FA8147409BE61DA7E8024C4024D06053E78347409BE61DA7E8024C4024D06053E7834740516A2FA2ED004C40925CFE43FA814740516A2FA2ED004C40
62676	52296	47.165218000000003	47.183202000000001	56.058011	56.048751000000003	Заречная	0103000020E61000000100000005000000F35A09DD25954740DB5207793D064C40F35A09DD2595474075E789E76C074C40E947C3297397474075E789E76C074C40E947C32973974740DB5207793D064C40F35A09DD25954740DB5207793D064C40
61863	32958	46.953367999999998	46.978645999999998	56.064946999999997	56.053980000000003	Становая	0103000020E61000000100000005000000C6866EF6077A4740AD510FD1E8064C40C6866EF6077A4740957CEC2E50084C403C2EAA45447D4740957CEC2E50084C403C2EAA45447D4740AD510FD1E8064C40C6866EF6077A4740AD510FD1E8064C40
61440	52291	47.055596000000001	47.064615000000003	55.990841000000003	55.984582000000003	9-ой Пятилетки	0103000020E61000000100000005000000EBE40CC51D8747407A1D71C806FE4B40EBE40CC51D8747409A44BDE0D3FE4B4060EAE74D458847409A44BDE0D3FE4B4060EAE74D458847407A1D71C806FE4B40EBE40CC51D8747407A1D71C806FE4B40
61612	10047	47.283839999999998	47.31935	56.046619999999997	56.019123	Шоссейная	0103000020E61000000100000005000000F8A57EDE54A44740FBCC599F72024C40F8A57EDE54A4474075ABE7A4F7054C4022FDF675E0A8474075ABE7A4F7054C4022FDF675E0A84740FBCC599F72024C40F8A57EDE54A44740FBCC599F72024C40
61638	10047	47.283839999999998	47.31935	56.046619999999997	56.019123	Школьная	0103000020E61000000100000005000000F8A57EDE54A44740FBCC599F72024C40F8A57EDE54A4474075ABE7A4F7054C4022FDF675E0A8474075ABE7A4F7054C4022FDF675E0A84740FBCC599F72024C40F8A57EDE54A44740FBCC599F72024C40
61617	10047	47.283839999999998	47.31935	56.046619999999997	56.019123	Первомайская	0103000020E61000000100000005000000F8A57EDE54A44740FBCC599F72024C40F8A57EDE54A4474075ABE7A4F7054C4022FDF675E0A8474075ABE7A4F7054C4022FDF675E0A84740FBCC599F72024C40F8A57EDE54A44740FBCC599F72024C40
61891	33116	47.328997999999999	47.355885000000001	55.966887	55.952151999999998	Школьная	0103000020E610000001000000050000008639419B1CAA47401669E21DE0F94B408639419B1CAA4740BAF605F4C2FB4B408811C2A38DAD4740BAF605F4C2FB4B408811C2A38DAD47401669E21DE0F94B408639419B1CAA47401669E21DE0F94B40
61599	9764	47.033344999999997	47.069358000000001	56.029435999999997	56.017201	Советская	0103000020E61000000100000005000000183E22A644844740B03A72A433024C40183E22A6448447409BA9108FC4034C40A5DB12B9E08847409BA9108FC4034C40A5DB12B9E0884740B03A72A433024C40183E22A644844740B03A72A433024C40
61819	9415	47.057375	47.088861000000001	55.943800000000003	55.927169999999997	Ясельная	0103000020E61000000100000005000000D34D62105887474089EAAD81ADF64B40D34D6210588747407FFB3A70CEF84B40E77118CC5F8B47407FFB3A70CEF84B40E77118CC5F8B474089EAAD81ADF64B40D34D62105887474089EAAD81ADF64B40
62010	52340	47.342059999999996	47.357151999999999	56.065007000000001	56.049928000000001	Школьная	0103000020E6100000010000000500000087A2409FC8AB4740CD936B0A64064C4087A2409FC8AB47406B813D2652084C40BAD91F28B7AD47406B813D2652084C40BAD91F28B7AD4740CD936B0A64064C4087A2409FC8AB4740CD936B0A64064C40
61969	10824	47.225197999999999	47.254995000000001	55.982531999999999	55.967430999999998	Школьная	0103000020E61000000100000005000000F38FBE49D39C47407B116DC7D4FB4B40F38FBE49D39C474001A3CB9BC3FD4B405FD218ADA3A0474001A3CB9BC3FD4B405FD218ADA3A047407B116DC7D4FB4B40F38FBE49D39C47407B116DC7D4FB4B40
62785	52252	47.009422999999998	47.023660999999997	56.117843000000001	56.104199999999999	Приволжская	0103000020E61000000100000005000000446ADAC534814740211FF46C560D4C40446ADAC5348147400188BB7A150F4C406798DA52078347400188BB7A150F4C406798DA5207834740211FF46C560D4C40446ADAC534814740211FF46C560D4C40
61825	52252	47.009422999999998	47.023660999999997	56.117843000000001	56.104199999999999	2-ая Садовая	0103000020E61000000100000005000000446ADAC534814740211FF46C560D4C40446ADAC5348147400188BB7A150F4C406798DA52078347400188BB7A150F4C406798DA5207834740211FF46C560D4C40446ADAC534814740211FF46C560D4C40
62788	52265	47.042768000000002	47.060169000000002	55.895811999999999	55.888446999999999	Водопроводная	0103000020E610000001000000050000005DA8FC6B798547405A9D9CA1B8F14B405DA8FC6B79854740A3AEB5F7A9F24B40D49D279EB3874740A3AEB5F7A9F24B40D49D279EB38747405A9D9CA1B8F14B405DA8FC6B798547405A9D9CA1B8F14B40
62939	58048	47.397899000000002	47.416502999999999	56.061655000000002	56.051411000000002	Космонавта Николаева А.Г.	0103000020E61000000100000005000000390EBC5AEEB24740CCD3B9A294064C40390EBC5AEEB247404451A04FE4074C40CBD765F84FB547404451A04FE4074C40CBD765F84FB54740CCD3B9A294064C40390EBC5AEEB24740CCD3B9A294064C40
62109	52261	46.954661000000002	46.969465999999997	55.970660000000002	55.956994999999999	Школьная	0103000020E6100000010000000500000022E2E654327A4740BFB7E9CF7EFA4B4022E2E654327A474087C43D963EFC4B40BE4A3E76177C474087C43D963EFC4B40BE4A3E76177C4740BFB7E9CF7EFA4B4022E2E654327A4740BFB7E9CF7EFA4B40
61602	57862	46.920768000000002	47.597459999999998	56.300085000000003	55.871682999999997	Молодежная	0103000020E61000000100000005000000079ACFB9DB75474055BDFC4E93EF4B40079ACFB9DB75474095826E2F69264C408655BC9179CC474095826E2F69264C408655BC9179CC474055BDFC4E93EF4B40079ACFB9DB75474055BDFC4E93EF4B40
61996	32585	47.120534999999997	47.142167000000001	56.069957000000002	56.058427999999999	Школьная	0103000020E61000000100000005000000FD82DDB06D8F4740D99596917A074C40FD82DDB06D8F47402A90D959F4084C4004C93B87329247402A90D959F4084C4004C93B8732924740D99596917A074C40FD82DDB06D8F4740D99596917A074C40
62796	52312	47.427472000000002	47.456972	56.039585000000002	56.027805999999998	Школьная	0103000020E6100000010000000500000055FA0967B7B64740F850A2258F034C4055FA0967B7B64740C2340C1F11054C400798F90E7EBA4740C2340C1F11054C400798F90E7EBA4740F850A2258F034C4055FA0967B7B64740F850A2258F034C40
62110	52301	47.378000999999998	47.395294	55.970680000000002	55.958103999999999	Родниковая	0103000020E610000001000000050000007A6D365662B047405915E126A3FA4B407A6D365662B04740CE70033E3FFC4B400B2769FE98B24740CE70033E3FFC4B400B2769FE98B247405915E126A3FA4B407A6D365662B047405915E126A3FA4B40
62605	58006	47.539059999999999	47.567914000000002	56.021835000000003	56.000974999999997	Парковая	0103000020E61000000100000005000000774A07EBFFC447408A8EE4F21F004C40774A07EBFFC447403F74417DCB024C406478EC67B1C847403F74417DCB024C406478EC67B1C847408A8EE4F21F004C40774A07EBFFC447408A8EE4F21F004C40
62624	58006	47.539059999999999	47.567914000000002	56.021835000000003	56.000974999999997	Кудряшова	0103000020E61000000100000005000000774A07EBFFC447408A8EE4F21F004C40774A07EBFFC447403F74417DCB024C406478EC67B1C847403F74417DCB024C406478EC67B1C847408A8EE4F21F004C40774A07EBFFC447408A8EE4F21F004C40
62599	58006	47.539059999999999	47.567914000000002	56.021835000000003	56.000974999999997	70 Лет Октября	0103000020E61000000100000005000000774A07EBFFC447408A8EE4F21F004C40774A07EBFFC447403F74417DCB024C406478EC67B1C847403F74417DCB024C406478EC67B1C847408A8EE4F21F004C40774A07EBFFC447408A8EE4F21F004C40
62108	52258	47.105623000000001	47.127704000000001	55.926392999999997	55.910054000000002	Октябрьская	0103000020E610000001000000050000004B5AF10D858D474008CC43A67CF44B404B5AF10D858D4740251FBB0B94F64B40C1C8CB9A58904740251FBB0B94F64B40C1C8CB9A5890474008CC43A67CF44B404B5AF10D858D474008CC43A67CF44B40
63481	58108	46.920768000000002	47.597459999999998	56.300085000000003	55.871682999999997	Пионерская	0103000020E61000000100000005000000079ACFB9DB75474055BDFC4E93EF4B40079ACFB9DB75474095826E2F69264C408655BC9179CC474095826E2F69264C408655BC9179CC474055BDFC4E93EF4B40079ACFB9DB75474055BDFC4E93EF4B40
62673	11116	47.504807999999997	47.533617	55.991712	55.984712999999999	Аптечная	0103000020E610000001000000050000002C616D8C9DC04740187959130BFE4B402C616D8C9DC047407F86376BF0FE4B4079CBD58F4DC447407F86376BF0FE4B4079CBD58F4DC44740187959130BFE4B402C616D8C9DC04740187959130BFE4B40
61959	10632	47.343434000000002	47.369252000000003	55.994903999999998	55.982335999999997	Верхняя	0103000020E61000000100000005000000D02A33A5F5AB47407BD7A02FBDFD4B40D02A33A5F5AB47406D54A70359FF4B40C6FD47A643AF47406D54A70359FF4B40C6FD47A643AF47407BD7A02FBDFD4B40D02A33A5F5AB47407BD7A02FBDFD4B40
61426	8789	47.421902000000003	47.448312999999999	55.737805999999999	55.718044999999996	Ленина	0103000020E61000000100000005000000FA0E7EE200B64740350708E6E8DB4B40FA0E7EE200B647407365506D70DE4B4092AF045262B947407365506D70DE4B4092AF045262B94740350708E6E8DB4B40FA0E7EE200B64740350708E6E8DB4B40
62686	8562	47.623161000000003	47.64958	55.807648	55.799370000000003	Молодежная	0103000020E61000000100000005000000439259BDC3CF4740A7B393C151E64B40439259BDC3CF47400457790261E74B405E11FC6F25D347400457790261E74B405E11FC6F25D34740A7B393C151E64B40439259BDC3CF4740A7B393C151E64B40
62716	7835	47.439337999999999	47.456226999999998	55.793838999999998	55.783782000000002	Молодежная	0103000020E61000000100000005000000EDF1423A3CB84740C498F4F752E44B40EDF1423A3CB8474009A52F849CE54B40AE4676A565BA474009A52F849CE54B40AE4676A565BA4740C498F4F752E44B40EDF1423A3CB84740C498F4F752E44B40
62671	8232	47.749482	47.764726000000003	55.830958000000003	55.817839999999997	И. Викторова	0103000020E610000001000000050000006878B306EFDF474029AE2AFBAEE84B406878B306EFDF4740BF2CEDD45CEA4B405133A48AE2E14740BF2CEDD45CEA4B405133A48AE2E1474029AE2AFBAEE84B406878B306EFDF474029AE2AFBAEE84B40
62897	6972	47.208992000000002	47.235807000000001	55.866489999999999	55.858584	Дружбы	0103000020E610000001000000050000001590F63FC09A4740376F9C14E6ED4B401590F63FC09A4740D027F224E9EE4B407D957CEC2E9E4740D027F224E9EE4B407D957CEC2E9E4740376F9C14E6ED4B401590F63FC09A4740376F9C14E6ED4B40
62106	7971	47.356028999999999	47.369081000000001	55.727663	55.723176000000002	Животноводов	0103000020E61000000100000005000000BBB6B75B92AD474045A0FA0791DC4B40BBB6B75B92AD47402FC1A90F24DD4B409949D40B3EAF47402FC1A90F24DD4B409949D40B3EAF474045A0FA0791DC4B40BBB6B75B92AD474045A0FA0791DC4B40
62781	8462	47.524202000000002	47.549723	55.888831000000003	55.874647000000003	Новая	0103000020E61000000100000005000000B83F170D19C34740B345D26EF4EF4B40B83F170D19C34740E355D636C5F14B40F46DC1525DC64740E355D636C5F14B40F46DC1525DC64740B345D26EF4EF4B40B83F170D19C34740B345D26EF4EF4B40
62007	8282	47.462560000000003	47.504736000000001	55.917743000000002	55.903196000000001	Октября	0103000020E610000001000000050000000938842A35BB474063F030ED9BF34B400938842A35BB47400491459A78F54B40938E72309BC047400491459A78F54B40938E72309BC0474063F030ED9BF34B400938842A35BB474063F030ED9BF34B40
61858	8537	47.565308999999999	47.586060000000003	55.870142000000001	55.849857999999998	Школьная	0103000020E610000001000000050000003691990B5CC847403A1F9E25C8EC4B403691990B5CC84740227024D060EF4B4034BF9A0304CB4740227024D060EF4B4034BF9A0304CB47403A1F9E25C8EC4B403691990B5CC847403A1F9E25C8EC4B40
62687	8711	47.457546999999998	47.472172	55.705320999999998	55.696707000000004	Центральная	0103000020E6100000010000000500000003B16CE690BA474078F2E9B12DD94B4003B16CE690BA47404C1762F547DA4B40200BD12170BC47404C1762F547DA4B40200BD12170BC474078F2E9B12DD94B4003B16CE690BA474078F2E9B12DD94B40
62654	6891	47.337991000000002	47.351078999999999	55.872228	55.861449	Путёвая	0103000020E61000000100000005000000D2AB014A43AB47400116F9F543EE4B40D2AB014A43AB4740E753C72AA5EF4B40FCA71B28F0AC4740E753C72AA5EF4B40FCA71B28F0AC47400116F9F543EE4B40D2AB014A43AB47400116F9F543EE4B40
62668	8094	47.463880000000003	47.483949000000003	55.774993000000002	55.765659999999997	Молодежная	0103000020E610000001000000050000005EA27A6B60BB47407CED992501E24B405EA27A6B60BB474081D07AF832E34B4049F7730AF2BD474081D07AF832E34B4049F7730AF2BD47407CED992501E24B405EA27A6B60BB47407CED992501E24B40
62670	8026	47.522818999999998	47.547567000000001	55.752915999999999	55.744835000000002	Николаева	0103000020E610000001000000050000001C5DA5BBEBC2474045F5D6C056DF4B401C5DA5BBEBC247404C512E8D5FE04B4036AFEAAC16C647404C512E8D5FE04B4036AFEAAC16C6474045F5D6C056DF4B401C5DA5BBEBC2474045F5D6C056DF4B40
62009	8129	47.690193000000001	47.716692999999999	55.899839999999998	55.886215999999997	Центральная	0103000020E61000000100000005000000CD76853E58D847409198A0866FF14B40CD76853E58D84740FAD005F52DF34B40D522A298BCDB4740FAD005F52DF34B40D522A298BCDB47409198A0866FF14B40CD76853E58D847409198A0866FF14B40
62782	8328	47.193452000000001	47.211660000000002	55.893752999999997	55.886918000000001	Синьяльская	0103000020E6100000010000000500000043ACFE08C3984740EB1D6E8786F14B4043ACFE08C3984740D7D9907F66F24B4089EFC4AC179B4740D7D9907F66F24B4089EFC4AC179B4740EB1D6E8786F14B4043ACFE08C3984740EB1D6E8786F14B40
61992	7453	47.425235000000001	47.449174999999997	55.860267	55.846617999999999	Центральная	0103000020E61000000100000005000000AA0EB9196EB647403B1A87FA5DEC4B40AA0EB9196EB64740FD69A33A1DEE4B402497FF907EB94740FD69A33A1DEE4B402497FF907EB947403B1A87FA5DEC4B40AA0EB9196EB647403B1A87FA5DEC4B40
61861	8680	47.495078999999997	47.530652000000003	55.719703000000003	55.705157999999997	Школьная	0103000020E61000000100000005000000DBF7A8BF5EBF4740A2410A9E42DA4B40DBF7A8BF5EBF4740A3EA573A1FDC4B404CC79C67ECC34740A3EA573A1FDC4B404CC79C67ECC34740A2410A9E42DA4B40DBF7A8BF5EBF4740A2410A9E42DA4B40
62899	7340	47.342644	47.352885000000001	55.905093999999998	55.899532000000001	Рыбацкая	0103000020E61000000100000005000000D71533C2DBAB47404DDA54DD23F34B40D71533C2DBAB474025E7C41EDAF34B40DE1FEF552BAD474025E7C41EDAF34B40DE1FEF552BAD47404DDA54DD23F34B40D71533C2DBAB47404DDA54DD23F34B40
62900	7527	47.370896000000002	47.392958	55.872788999999997	55.859504000000001	Родниковая	0103000020E61000000100000005000000CE1B278579AF4740FE63213A04EE4B40CE1B278579AF47407EA7C98CB7EF4B40CD599F724CB247407EA7C98CB7EF4B40CD599F724CB24740FE63213A04EE4B40CE1B278579AF4740FE63213A04EE4B40
61423	7741	47.494486000000002	47.499912000000002	55.855258999999997	55.852030999999997	Дорожная	0103000020E61000000100000005000000392A37514BBF4740CE16105A0FED4B40392A37514BBF4740094E7D2079ED4B406170CD1DFDBF4740094E7D2079ED4B406170CD1DFDBF4740CE16105A0FED4B40392A37514BBF4740CE16105A0FED4B40
62783	8625	47.578595	47.599310000000003	55.818078	55.809995000000001	Советская	0103000020E610000001000000050000008750A5660FCA4740367689EAADE74B408750A5660FCA4740DEC9A7C7B6E84B403815A930B6CC4740DEC9A7C7B6E84B403815A930B6CC4740367689EAADE74B408750A5660FCA4740367689EAADE74B40
62893	7038	47.339491000000002	47.353530999999997	55.811528000000003	55.803443999999999	Центральная	0103000020E61000000100000005000000A724EB7074AB47406E15C440D7E64B40A724EB7074AB4740E7E44526E0E74B40A38FF98040AD4740E7E44526E0E74B40A38FF98040AD47406E15C440D7E64B40A724EB7074AB47406E15C440D7E64B40
62898	7471	47.341583999999997	47.362011000000003	55.850676	55.843313000000002	переулок Школьный	0103000020E610000001000000050000001E6B4606B9AB474055A52DAEF1EB4B401E6B4606B9AB4740FDBE7FF3E2EC4B4069E55E6056AE4740FDBE7FF3E2EC4B4069E55E6056AE474055A52DAEF1EB4B401E6B4606B9AB474055A52DAEF1EB4B40
62001	7692	47.603326000000003	47.622703000000001	55.785037000000003	55.763665000000003	Молодежная	0103000020E61000000100000005000000CB694FC939CD4740C80C54C6BFE14B40CB694FC939CD47403293A8177CE44B40800F5EBBB4CF47403293A8177CE44B40800F5EBBB4CF4740C80C54C6BFE14B40CB694FC939CD4740C80C54C6BFE14B40
61980	7003	47.373887000000003	47.388250999999997	55.829870999999997	55.820703000000002	Чапаева	0103000020E6100000010000000500000025B37A87DBAF4740535DC0CB0CE94B4025B37A87DBAF47400C73823639EA4B40D4D17135B2B147400C73823639EA4B40D4D17135B2B14740535DC0CB0CE94B4025B37A87DBAF4740535DC0CB0CE94B40
62656	7885	47.339894999999999	47.351985999999997	55.705021000000002	55.697122999999998	Просвещения	0103000020E610000001000000050000007689EAAD81AB47400B2593533BD94B407689EAAD81AB474022FFCC203EDA4B402E5393E00DAD474022FFCC203EDA4B402E5393E00DAD47400B2593533BD94B407689EAAD81AB47400B2593533BD94B40
62653	7096	47.296300000000002	47.311939000000002	55.90793	55.900027000000001	Солнечная	0103000020E6100000010000000500000004E78C28EDA547402D42B11534F34B4004E78C28EDA547405587DC0C37F44B4069ACFD9DEDA747405587DC0C37F44B4069ACFD9DEDA747402D42B11534F34B4004E78C28EDA547402D42B11534F34B40
61815	8186	47.704081000000002	47.720672999999998	55.867697999999997	55.861767	Школьная	0103000020E61000000100000005000000145E82531FDA4740D2E28C614EEE4B40145E82531FDA4740FD6662BA10EF4B401B0E4B033FDC4740FD6662BA10EF4B401B0E4B033FDC4740D2E28C614EEE4B40145E82531FDA4740D2E28C614EEE4B40
62822	8759	47.400226000000004	47.417734000000003	55.752327999999999	55.744048999999997	Шоссейная	0103000020E610000001000000050000002481069B3AB347408DCF64FF3CDF4B402481069B3AB34740BBEEAD484CE04B40B136C64E78B54740BBEEAD484CE04B40B136C64E78B547408DCF64FF3CDF4B402481069B3AB347408DCF64FF3CDF4B40
62655	7799	47.524723000000002	47.54383	55.800317	55.787568	переулок Клубный	0103000020E61000000100000005000000C13A8E1F2AC3474025B03907CFE44B40C13A8E1F2AC3474067B796C970E64B40B64AB0389CC5474067B796C970E64B40B64AB0389CC5474025B03907CFE44B40C13A8E1F2AC3474025B03907CFE44B40
62107	8467	47.653578000000003	47.671149	55.853409999999997	55.840108000000001	Центральная	0103000020E610000001000000050000004BB1A371A8D34740D28DB0A888EB4B404BB1A371A8D34740280AF4893CED4B401EDFDE35E8D54740280AF4893CED4B401EDFDE35E8D54740D28DB0A888EB4B404BB1A371A8D34740D28DB0A888EB4B40
62092	7668	47.638961999999999	47.669550000000001	55.783726000000001	55.771687	Молодежная	0103000020E6100000010000000500000081B1BE81C9D14740CADFBDA3C6E24B4081B1BE81C9D147403083312251E44B40B6847CD0B3D547403083312251E44B40B6847CD0B3D54740CADFBDA3C6E24B4081B1BE81C9D14740CADFBDA3C6E24B40
62767	7261	47.230947	47.257483999999998	55.932450000000003	55.921908999999999	Пушкина	0103000020E61000000100000005000000FE0DDAAB8F9D4740AC71361D01F64B40FE0DDAAB8F9D4740DE9387855AF74B40239F573CF5A04740DE9387855AF74B40239F573CF5A04740AC71361D01F64B40FE0DDAAB8F9D4740AC71361D01F64B40
62771	7580	47.590417000000002	47.605750999999998	55.938187999999997	55.924905000000003	Базовый проезд	0103000020E610000001000000050000005000C5C892CB474015747B4963F64B405000C5C892CB4740F4BF5C8B16F84B407842AF3F89CD4740F4BF5C8B16F84B407842AF3F89CD474015747B4963F64B405000C5C892CB474015747B4963F64B40
61894	57908	47.273833000000003	47.287864999999996	55.929091	55.919927000000001	Центральная	0103000020E6100000010000000500000065C8B1F50CA347408CDAFD2AC0F54B4065C8B1F50CA3474004013274ECF64B40DE54A4C2D8A4474004013274ECF64B40DE54A4C2D8A447408CDAFD2AC0F54B4065C8B1F50CA347408CDAFD2AC0F54B40
62657	7186	47.226995000000002	47.249093000000002	55.897765999999997	55.885378000000003	Советская	0103000020E6100000010000000500000082AD122C0E9D4740884CF91054F14B4082AD122C0E9D4740F9BA0CFFE9F24B40CE548847E29F4740F9BA0CFFE9F24B40CE548847E29F4740884CF91054F14B4082AD122C0E9D4740884CF91054F14B40
61994	7617	47.598959999999998	47.622891000000003	55.910719999999998	55.902278000000003	Садовая	0103000020E610000001000000050000005BCEA5B8AACC47403DF372D87DF34B405BCEA5B8AACC474014E8137992F44B4083FC6CE4BACF474014E8137992F44B4083FC6CE4BACF47403DF372D87DF34B405BCEA5B8AACC47403DF372D87DF34B40
62787	7950	47.388556999999999	47.401591000000003	55.704894000000003	55.698604000000003	Колхозная	0103000020E61000000100000005000000E1D05B3CBCB147406A6D1ADB6BD94B40E1D05B3CBCB14740C59272F739DA4B4019AF795567B34740C59272F739DA4B4019AF795567B347406A6D1ADB6BD94B40E1D05B3CBCB147406A6D1ADB6BD94B40
62770	6868	47.309477999999999	47.327337	55.818897	55.810778999999997	Молодежная	0103000020E610000001000000050000006E6AA0F99CA747404CA4349BC7E74B406E6AA0F99CA7474071E5EC9DD1E84B40A8E2C62DE6A9474071E5EC9DD1E84B40A8E2C62DE6A947404CA4349BC7E74B406E6AA0F99CA747404CA4349BC7E74B40
61976	6822	47.283472000000003	47.294933999999998	55.856012	55.847745000000003	Восточная	0103000020E6100000010000000500000076AA7CCF48A447407C2C7DE882EC4B4076AA7CCF48A44740E57D1CCD91ED4B403E3DB665C0A54740E57D1CCD91ED4B403E3DB665C0A547407C2C7DE882EC4B4076AA7CCF48A447407C2C7DE882EC4B40
62895	7172	47.307411999999999	47.327525000000001	55.926993000000003	55.913882999999998	Гагарина	0103000020E61000000100000005000000F032C34659A7474068AF3E1EFAF44B40F032C34659A747407B4FE5B4A7F64B40ABCFD556ECA947407B4FE5B4A7F64B40ABCFD556ECA9474068AF3E1EFAF44B40F032C34659A7474068AF3E1EFAF44B40
62024	8383	47.526789000000001	47.543094000000004	55.924562000000002	55.913252999999997	Средняя	0103000020E610000001000000050000003F726BD26DC34740A8FC6B79E5F44B403F726BD26DC34740EB8F300C58F64B40B153AC1A84C54740EB8F300C58F64B40B153AC1A84C54740A8FC6B79E5F44B403F726BD26DC34740A8FC6B79E5F44B40
62093	6202	47.939970000000002	47.952339000000002	55.717770999999999	55.708080000000002	Зеленая	0103000020E610000001000000050000004E9CDCEF50F84740D1798D5DA2DA4B404E9CDCEF50F8474034828DEBDFDB4B4049DA8D3EE6F9474034828DEBDFDB4B4049DA8D3EE6F94740D1798D5DA2DA4B404E9CDCEF50F84740D1798D5DA2DA4B40
61847	6626	47.733707000000003	47.772119000000004	55.657657	55.628219999999999	Центральная	0103000020E6100000010000000500000053EC681CEADD4740B858518369D04B4053EC681CEADD4740247EC51A2ED44B4064CF9ECBD4E24740247EC51A2ED44B4064CF9ECBD4E24740B858518369D04B4053EC681CEADD4740B858518369D04B40
61977	6458	47.831004	47.875380999999997	55.756872999999999	55.735048999999997	Новая	0103000020E610000001000000050000002F6CCD565EEA47408FFAEB1516DE4B402F6CCD565EEA4740DA1CE736E1E04B4017450F7C0CF04740DA1CE736E1E04B4017450F7C0CF047408FFAEB1516DE4B402F6CCD565EEA47408FFAEB1516DE4B40
61919	6350	48.005960000000002	48.058394	55.56588	55.542817999999997	Центральная	0103000020E61000000100000005000000C68A1A4CC30048400ED76A0F7BC54B40C68A1A4CC3004840F1BA7EC16EC84B402D24607479074840F1BA7EC16EC84B402D246074790748400ED76A0F7BC54B40C68A1A4CC30048400ED76A0F7BC54B40
62880	4769	47.688189999999999	47.718715000000003	55.758519	55.745199	Свердлова	0103000020E6100000010000000500000095B7239C16D8474086014BAE62DF4B4095B7239C16D8474083328D2617E14B40841266DAFEDB474083328D2617E14B40841266DAFEDB474086014BAE62DF4B4095B7239C16D8474086014BAE62DF4B40
61958	6246	47.860261999999999	47.881596999999999	55.678198999999999	55.665101	Школьная	0103000020E61000000100000005000000EBFEB1101DEE4740B9C4910722D54B40EBFEB1101DEE474007978E39CFD64B4038A0A52BD8F0474007978E39CFD64B4038A0A52BD8F04740B9C4910722D54B40EBFEB1101DEE4740B9C4910722D54B40
62646	5349	48.119947000000003	48.144236999999997	55.732214999999997	55.717908000000001	Ленина	0103000020E610000001000000050000006D205D6C5A0F4840B5C4CA68E4DB4B406D205D6C5A0F484000529B38B9DD4B40C3EFA65B7612484000529B38B9DD4B40C3EFA65B76124840B5C4CA68E4DB4B406D205D6C5A0F4840B5C4CA68E4DB4B40
61888	6024	47.894973	47.927106000000002	55.708384000000002	55.696711999999998	Улица К. Маркса	0103000020E61000000100000005000000C9E6AA798EF24740895DDBDB2DD94B40C9E6AA798EF247403D81B053ACDA4B4073F6CE68ABF647403D81B053ACDA4B4073F6CE68ABF64740895DDBDB2DD94B40C9E6AA798EF24740895DDBDB2DD94B40
62768	6759	47.637956000000003	47.661788000000001	55.68497	55.675280000000001	Зеленая	0103000020E61000000100000005000000BC24CE8AA8D147404AD235936FD64B40BC24CE8AA8D14740DD5ED218ADD74B4050711C78B5D44740DD5ED218ADD74B4050711C78B5D447404AD235936FD64B40BC24CE8AA8D147404AD235936FD64B40
61636	4449	47.925246000000001	47.960622000000001	55.695884999999997	55.670574000000002	Мира	0103000020E610000001000000050000009E60FF756EF6474022C66B5ED5D54B409E60FF756EF6474073637AC212D94B40B8E864A9F5FA474073637AC212D94B40B8E864A9F5FA474022C66B5ED5D54B409E60FF756EF6474022C66B5ED5D54B40
61634	4449	47.925246000000001	47.960622000000001	55.695884999999997	55.670574000000002	Ленина	0103000020E610000001000000050000009E60FF756EF6474022C66B5ED5D54B409E60FF756EF6474073637AC212D94B40B8E864A9F5FA474073637AC212D94B40B8E864A9F5FA474022C66B5ED5D54B409E60FF756EF6474022C66B5ED5D54B40
62122	5897	48.078256000000003	48.104002000000001	55.56024	55.54072	Школьная	0103000020E610000001000000050000009F5BE84A040A484085251E5036C54B409F5BE84A040A48409DF4BEF1B5C74B40FB5B02F04F0D48409DF4BEF1B5C74B40FB5B02F04F0D484085251E5036C54B409F5BE84A040A484085251E5036C54B40
62089	5662	47.979298	47.99624	55.762855000000002	55.748463000000001	Ленина	0103000020E61000000100000005000000E48409A359FD47400EA2B5A2CDDF4B40E48409A359FD4740884B8E3BA5E14B40C87BD5CA84FF4740884B8E3BA5E14B40C87BD5CA84FF47400EA2B5A2CDDF4B40E48409A359FD47400EA2B5A2CDDF4B40
62794	58027	47.992942999999997	48.018841999999999	55.653115999999997	55.641122000000003	Центральная	0103000020E6100000010000000500000064E597C118FF4740815F234910D24B4064E597C118FF4740463F1A4E99D34B4047E5266A69024840463F1A4E99D34B4047E5266A69024840815F234910D24B4064E597C118FF4740815F234910D24B40
61597	5825	47.970449000000002	48.010675999999997	55.693905999999998	55.67756	Школьная	0103000020E61000000100000005000000CCB73EAC37FC4740F4893C49BAD64B40CCB73EAC37FC4740C43F6CE9D1D84B40116DC7D45D014840C43F6CE9D1D84B40116DC7D45D014840F4893C49BAD64B40CCB73EAC37FC4740F4893C49BAD64B40
62090	6169	47.842959999999998	47.863990000000001	55.725118000000002	55.714871000000002	Гагарина	0103000020E6100000010000000500000007EBFF1CE6EB4740EEED96E480DB4B4007EBFF1CE6EB4740D7DEA7AAD0DC4B4018096D3997EE4740D7DEA7AAD0DC4B4018096D3997EE4740EEED96E480DB4B4007EBFF1CE6EB4740EEED96E480DB4B40
62891	5313	48.113407000000002	48.128059	55.675401999999998	55.664411000000001	Новая	0103000020E610000001000000050000009911DE1E840E4840240D6E6B0BD54B409911DE1E840E484095D39E9273D64B40AF7AC03C6410484095D39E9273D64B40AF7AC03C64104840240D6E6B0BD54B409911DE1E840E4840240D6E6B0BD54B40
62649	5634	47.923333	47.944065999999999	55.742955000000002	55.730218000000001	Школьная	0103000020E61000000100000005000000A62897C62FF64740AB798EC877DD4B40A62897C62FF6474029B3412619DF4B40FDA19927D7F8474029B3412619DF4B40FDA19927D7F84740AB798EC877DD4B40A62897C62FF64740AB798EC877DD4B40
62885	5257	48.078651000000001	48.098998000000002	55.732295999999998	55.724378000000002	Е. Степановой	0103000020E610000001000000050000001B66683C110A484090F8156BB8DC4B401B66683C110A4840ED7E15E0BBDD4B40492F6AF7AB0C4840ED7E15E0BBDD4B40492F6AF7AB0C484090F8156BB8DC4B401B66683C110A484090F8156BB8DC4B40
62714	6584	47.933214	47.947910999999998	55.798302999999997	55.789082000000001	Школьная	0103000020E61000000100000005000000AD156D8E73F747405FEE93A300E54B40AD156D8E73F747403BA6EECA2EE64B406342CC2555F947403BA6EECA2EE64B406342CC2555F947405FEE93A300E54B40AD156D8E73F747405FEE93A300E54B40
62884	5158	47.663226000000002	47.692824999999999	55.732149	55.717072000000002	Молодежная	0103000020E61000000100000005000000AFEDED96E4D447404C70EA03C9DB4B40AFEDED96E4D447404966F50EB7DD4B40F46C567DAED847404966F50EB7DD4B40F46C567DAED847404C70EA03C9DB4B40AFEDED96E4D447404C70EA03C9DB4B40
62088	5090	47.694361000000001	47.715066999999998	55.727429999999998	55.707507	Октябрьская	0103000020E61000000100000005000000164F3DD2E0D847407558E1968FDA4B40164F3DD2E0D847408C101E6D1CDD4B4073B9C15087DB47408C101E6D1CDD4B4073B9C15087DB47407558E1968FDA4B40164F3DD2E0D847407558E1968FDA4B40
62882	4935	\N	\N	\N	\N	Новая	\N
62890	5948	48.054549999999999	48.072282000000001	55.613346	55.600735	Кооперативная	0103000020E6100000010000000500000097FF907EFB06484002486DE2E4CC4B4097FF907EFB064840F390291F82CE4B40740B5D8940094840F390291F82CE4B40740B5D894009484002486DE2E4CC4B4097FF907EFB06484002486DE2E4CC4B40
62875	4670	47.916874	47.942314000000003	55.67492	55.666156999999998	Ленина	0103000020E61000000100000005000000BF4692205CF547403080F0A144D54B40BF4692205CF547404AB54FC763D64B400F48C2BE9DF847404AB54FC763D64B400F48C2BE9DF847403080F0A144D54B40BF4692205CF547403080F0A144D54B40
61975	5752	47.970063000000003	47.997605	55.631507999999997	55.613672000000001	Гагарина	0103000020E61000000100000005000000A3073E062BFC4740473CD9CD8CCE4B40A3073E062BFC4740C8940F41D5D04B40BDA94885B1FF4740C8940F41D5D04B40BDA94885B1FF4740473CD9CD8CCE4B40A3073E062BFC4740473CD9CD8CCE4B40
62888	5551	47.947893000000001	47.966596000000003	55.76999	55.749688999999996	Школьная	0103000020E61000000100000005000000BD8DCD8E54F94740E19524CFF5DF4B40BD8DCD8E54F947409F1F46088FE24B40E338F06AB9FB47409F1F46088FE24B40E338F06AB9FB4740E19524CFF5DF4B40BD8DCD8E54F94740E19524CFF5DF4B40
61886	5407	47.900784999999999	47.942169999999997	55.635071000000003	55.617204999999998	Виськил	0103000020E610000001000000050000001ADD41EC4CF34740BEF6CC9200CF4B401ADD41EC4CF34740ABD1AB014AD14B40DBA2CC0699F84740ABD1AB014AD14B40DBA2CC0699F84740BEF6CC9200CF4B401ADD41EC4CF34740BEF6CC9200CF4B40
61973	3354	48.036825999999998	48.067737000000001	55.686878	55.668045999999997	Ленина	0103000020E610000001000000050000003DD2E0B6B60448409F1C058882D54B403DD2E0B6B6044840C32B499EEBD74B4055DD239BAB084840C32B499EEBD74B4055DD239BAB0848409F1C058882D54B403DD2E0B6B60448409F1C058882D54B40
62652	6736	47.707827000000002	47.720179000000002	55.681086999999998	55.672823000000001	Центральная	0103000020E61000000100000005000000E71C3C139ADA4740917F66101FD64B40E71C3C139ADA4740895DDBDB2DD74B400C2252D32EDC4740895DDBDB2DD74B400C2252D32EDC4740917F66101FD64B40E71C3C139ADA4740917F66101FD64B40
62764	5444	47.977680999999997	47.992907000000002	55.658372999999997	55.647198000000003	Крупской	0103000020E61000000100000005000000D575A8A624FD4740B0045262D7D24B40D575A8A624FD4740E2C8039145D44B40187C9A9317FF4740E2C8039145D44B40187C9A9317FF4740B0045262D7D24B40D575A8A624FD4740B0045262D7D24B40
62892	6528	47.876593	47.904961999999998	55.778106999999999	55.768647999999999	Центральная	0103000020E6100000010000000500000086730D3334F047406211C30E63E24B4086730D3334F04740F3E49A0299E34B40B60F79CBD5F34740F3E49A0299E34B40B60F79CBD5F347406211C30E63E24B4086730D3334F047406211C30E63E24B40
62824	5180	48.074708000000001	48.101154000000001	55.707698999999998	55.698751000000001	И. Метри	0103000020E61000000100000005000000F25F2008900948400E863AAC70D94B40F25F200890094840B9347EE195DA4B4007EE409DF20C4840B9347EE195DA4B4007EE409DF20C48400E863AAC70D94B40F25F2008900948400E863AAC70D94B40
62883	5014	47.783518999999998	47.810864000000002	55.738742999999999	55.720945	К. Маркса	0103000020E61000000100000005000000B665C0594AE447407C9BFEEC47DC4B40B665C0594AE44740109370218FDE4B407BC03C64CAE74740109370218FDE4B407BC03C64CAE747407C9BFEEC47DC4B40B665C0594AE447407C9BFEEC47DC4B40
62692	4836	47.802365999999999	47.820799000000001	55.704408000000001	55.693972000000002	Школьная	0103000020E610000001000000050000000FB6D8EDB3E647407C2B1213D4D84B400FB6D8EDB3E647403885950A2ADA4B4075CB0EF10FE947403885950A2ADA4B4075CB0EF10FE947407C2B1213D4D84B400FB6D8EDB3E647407C2B1213D4D84B40
61885	4747	47.774903999999999	47.802329999999998	55.772669	55.760322000000002	Новая	0103000020E6100000010000000500000011C5E40D30E34740F436363B52E14B4011C5E40D30E3474007D15AD1E6E24B40C24CDBBFB2E6474007D15AD1E6E24B40C24CDBBFB2E64740F436363B52E14B4011C5E40D30E34740F436363B52E14B40
62651	6301	47.812966000000003	47.824382999999997	55.674382000000001	55.665756000000002	Гоголя	0103000020E61000000100000005000000466117450FE84740D28E1B7E37D54B40466117450FE847406B813D2652D64B406E30D46185E947406B813D2652D64B406E30D46185E94740D28E1B7E37D54B40466117450FE84740D28E1B7E37D54B40
61637	4591	47.886726000000003	47.922704000000003	55.653472000000001	55.636975999999997	Школьная	0103000020E61000000100000005000000A741D13C80F147401F2BF86D88D14B40A741D13C80F14740056D72F8A4D34B40B7F1272A1BF64740056D72F8A4D34B40B7F1272A1BF647401F2BF86D88D14B40A741D13C80F147401F2BF86D88D14B40
62091	6098	47.915534999999998	47.937157999999997	55.724843999999997	55.715327000000002	Школьная	0103000020E61000000100000005000000F3AB394030F547401079CBD58FDB4B40F3AB394030F54740D5592DB0C7DC4B40A69718CBF4F74740D5592DB0C7DC4B40A69718CBF4F747401079CBD58FDB4B40F3AB394030F547401079CBD58FDB4B40
62878	4215	46.388452999999998	46.426065999999999	55.081631999999999	55.062612000000001	Октябрьская	0103000020E610000001000000050000003C84F1D3B8314740282B86AB03884B403C84F1D3B83147404E27D9EA728A4B4001F8A754893647404E27D9EA728A4B4001F8A75489364740282B86AB03884B403C84F1D3B8314740282B86AB03884B40
62086	3890	46.477072	46.547015000000002	55.148477	55.135371999999997	Ленина	0103000020E610000001000000050000002DEBFEB1103D4740A565A4DE53914B402DEBFEB1103D4740A69A594B01934B40F2B5679604464740A69A594B01934B40F2B5679604464740A565A4DE53914B402DEBFEB1103D4740A565A4DE53914B40
62085	4099	46.194965000000003	46.228786999999997	55.114944999999999	55.097676999999997	Азина	0103000020E61000000100000005000000AD6EF59CF4184740234910AE808C4B40AD6EF59CF41847405BEB8B84B68E4B40FE5F75E4481D47405BEB8B84B68E4B40FE5F75E4481D4740234910AE808C4B40AD6EF59CF4184740234910AE808C4B40
62881	3248	46.264809	46.300589000000002	55.254482000000003	55.214244999999998	Ульянова	0103000020E61000000100000005000000DE57E542E52147406F2A52616C9B4B40DE57E542E5214740D9B5BDDD92A04B40C8444AB379264740D9B5BDDD92A04B40C8444AB3792647406F2A52616C9B4B40DE57E542E52147406F2A52616C9B4B40
62685	4390	46.295378999999997	46.320450999999998	55.088867	55.073458000000002	Кооперативная	0103000020E610000001000000050000006C76A4FACE25474096D05D1267894B406C76A4FACE254740C9586DFE5F8B4B40397CD28904294740C9586DFE5F8B4B40397CD2890429474096D05D1267894B406C76A4FACE25474096D05D1267894B40
62765	4323	46.329407000000003	46.3626	55.048012999999997	55.027541999999997	Курмыш	0103000020E61000000100000005000000680932022A2A47401AA20A7F86834B40680932022A2A474034643C4A25864B40CAC342AD692E474034643C4A25864B40CAC342AD692E47401AA20A7F86834B40680932022A2A47401AA20A7F86834B40
61884	3692	46.303579999999997	46.346088999999999	55.207500000000003	55.179842999999998	пер.Школьный	0103000020E610000001000000050000001EDC9DB5DB2647400FB56D1805974B401EDC9DB5DB264740C3F5285C8F9A4B40AF40F4A44C2C4740C3F5285C8F9A4B40AF40F4A44C2C47400FB56D1805974B401EDC9DB5DB2647400FB56D1805974B40
61957	3692	46.303579999999997	46.346088999999999	55.207500000000003	55.179842999999998	им.Крупской	0103000020E610000001000000050000001EDC9DB5DB2647400FB56D1805974B401EDC9DB5DB264740C3F5285C8F9A4B40AF40F4A44C2C4740C3F5285C8F9A4B40AF40F4A44C2C47400FB56D1805974B401EDC9DB5DB2647400FB56D1805974B40
61974	3692	46.303579999999997	46.346088999999999	55.207500000000003	55.179842999999998	Ленина	0103000020E610000001000000050000001EDC9DB5DB2647400FB56D1805974B401EDC9DB5DB264740C3F5285C8F9A4B40AF40F4A44C2C4740C3F5285C8F9A4B40AF40F4A44C2C47400FB56D1805974B401EDC9DB5DB2647400FB56D1805974B40
61846	3692	46.303579999999997	46.346088999999999	55.207500000000003	55.179842999999998	Комсомольская	0103000020E610000001000000050000001EDC9DB5DB2647400FB56D1805974B401EDC9DB5DB264740C3F5285C8F9A4B40AF40F4A44C2C4740C3F5285C8F9A4B40AF40F4A44C2C47400FB56D1805974B401EDC9DB5DB2647400FB56D1805974B40
62087	4193	46.174878999999997	46.202025999999996	55.090283999999997	55.072896	Панова	0103000020E61000000100000005000000EBE0606F621647402E01F8A754894B40EBE0606F6216474010AD156D8E8B4B408978EBFCDB19474010AD156D8E8B4B408978EBFCDB1947402E01F8A754894B40EBE0606F621647402E01F8A754894B40
62647	3584	46.050750000000001	46.076225999999998	55.165004000000003	55.145986999999998	Николаева	0103000020E61000000100000005000000D122DBF97E0647401152B7B3AF924B40D122DBF97E064740C7DADFD91E954B406D8D08C6C1094740C7DADFD91E954B406D8D08C6C10947401152B7B3AF924B40D122DBF97E0647401152B7B3AF924B40
62838	3989	46.578986	46.603257999999997	55.188246999999997	55.176254	Центральная	0103000020E61000000100000005000000C26B97361C4A474004E5B67D8F964B40C26B97361C4A4740F9484A7A18984B407286E28E374D4740F9484A7A18984B407286E28E374D474004E5B67D8F964B40C26B97361C4A474004E5B67D8F964B40
61633	3571	46.339872	46.378599000000001	55.141413	55.109949999999998	Ленина	0103000020E61000000100000005000000BE69FAEC802B4740FC1873D7128E4B40BE69FAEC802B4740581D39D219924B402FA699EE75304740581D39D219924B402FA699EE75304740FC1873D7128E4B40BE69FAEC802B4740FC1873D7128E4B40
62667	3471	46.135488000000002	46.159554	55.046187000000003	55.023052	Северная	0103000020E610000001000000050000000F80B8AB57114740BF0D315EF3824B400F80B8AB571147400C40A374E9854B4016F9F5436C1447400C40A374E9854B4016F9F5436C144740BF0D315EF3824B400F80B8AB57114740BF0D315EF3824B40
62869	4279	46.404183000000003	46.427377	55.057409	55.043571999999998	Мухоморова	0103000020E61000000100000005000000B24CBF44BC334740BA826DC493854B40B24CBF44BC3347407FBF982D59874B4003081F4AB43647407FBF982D59874B4003081F4AB4364740BA826DC493854B40B24CBF44BC334740BA826DC493854B40
62915	3367	46.399107000000001	46.436135999999998	55.23809	55.216349999999998	Советская	0103000020E61000000100000005000000664D2CF015334740AB3E575BB19B4B40664D2CF01533474098C0ADBB799E4B40DB4DF04DD337474098C0ADBB799E4B40DB4DF04DD3374740AB3E575BB19B4B40664D2CF015334740AB3E575BB19B4B40
62643	3136	46.260147000000003	46.281931	55.271343999999999	55.254092	Школьная	0103000020E610000001000000050000008693347F4C2147406E162F1686A04B408693347F4C214740A0FB7266BBA24B40425DA45016244740A0FB7266BBA24B40425DA450162447406E162F1686A04B408693347F4C2147406E162F1686A04B40
62909	3264	46.491840000000003	46.537222999999997	55.227684000000004	55.211146999999997	Чапаева	0103000020E61000000100000005000000AD6EF59CF43E474002D369DD069B4B40AD6EF59CF43E474047E9D2BF249D4B405AD427B9C344474047E9D2BF249D4B405AD427B9C344474002D369DD069B4B40AD6EF59CF43E474002D369DD069B4B40
62763	3475	46.148783000000002	46.171554999999998	55.027196000000004	55.015495000000001	Советская	0103000020E61000000100000005000000B39943520B13474032207BBDFB814B40B39943520B134740804A95287B834B408E3BA583F5154740804A95287B834B408E3BA583F515474032207BBDFB814B40B39943520B13474032207BBDFB814B40
62712	3956	46.569814000000001	46.591121999999999	55.112335000000002	55.093051000000003	Почтовая	0103000020E61000000100000005000000C76647AAEF48474018EE5C18E98B4B40C76647AAEF4847401C9947FE608E4B401AF9BCE2A94B47401C9947FE608E4B401AF9BCE2A94B474018EE5C18E98B4B40C76647AAEF48474018EE5C18E98B4B40
62084	4078	46.647365999999998	46.691229999999997	55.133642000000002	55.119692000000001	Гагарина	0103000020E610000001000000050000006B459BE3DC524740E2CB4411528F4B406B459BE3DC5247409FAF592E1B914B40CD0182397A5847409FAF592E1B914B40CD0182397A584740E2CB4411528F4B406B459BE3DC524740E2CB4411528F4B40
62081	3022	46.230744999999999	46.265248999999997	55.204279	55.185955	Бахмутово	0103000020E61000000100000005000000965B5A0D891D47408BC3995FCD974B40965B5A0D891D47403A2174D0259A4B40FA25E2ADF32147403A2174D0259A4B40FA25E2ADF32147408BC3995FCD974B40965B5A0D891D47408BC3995FCD974B40
62644	3680	46.229874000000002	46.258268999999999	55.146455000000003	55.124701999999999	Тракторная	0103000020E61000000100000005000000B119E0826C1D474076DF313CF68F4B40B119E0826C1D4740F8AA9509BF924B400A4966F50E214740F8AA9509BF924B400A4966F50E21474076DF313CF68F4B40B119E0826C1D474076DF313CF68F4B40
62083	3125	46.231499999999997	46.257173999999999	55.188822000000002	55.172131	Анастасово	0103000020E610000001000000050000001283C0CAA11D47405BD07B6308964B401283C0CAA11D4740F661BD512B984B40D5B0DF13EB204740F661BD512B984B40D5B0DF13EB2047405BD07B6308964B401283C0CAA11D47405BD07B6308964B40
10017	40483	47.440173999999999	47.556199999999997	56.128484999999998	56.057367999999997	Комсомольская	0103000020E610000001000000050000005646239F57B8474020EBA9D557074C405646239F57B8474066834C3272104C408104C58F31C7474066834C3272104C408104C58F31C7474020EBA9D557074C405646239F57B8474020EBA9D557074C40
61882	27391	46.593907000000002	46.625267000000001	55.997889999999998	55.983156999999999	Центральная	0103000020E61000000100000005000000C8EE0225054C4740AFEAAC16D8FD4B40C8EE0225054C4740B28009DCBAFF4B404F22C2BF08504740B28009DCBAFF4B404F22C2BF08504740AFEAAC16D8FD4B40C8EE0225054C4740AFEAAC16D8FD4B40
62004	57918	46.880451999999998	46.893621000000003	56.007066000000002	56.000335999999997	Молодежная	0103000020E6100000010000000500000051D9B0A6B2704740778192020B004C4051D9B0A6B2704740EF74E789E7004C406902452C62724740EF74E789E7004C406902452C62724740778192020B004C4051D9B0A6B2704740778192020B004C40
61968	27087	46.760804999999998	46.771009999999997	55.854284	55.847816000000002	Центральная	0103000020E610000001000000050000000FD1E80E626147404583143C85EC4B400FD1E80E626147407FBF982D59ED4B40C971A774B06247407FBF982D59ED4B40C971A774B06247404583143C85EC4B400FD1E80E626147404583143C85EC4B40
62868	27039	46.653033999999998	46.678069999999998	56.045237	56.035356	Ягодная	0103000020E6100000010000000500000089963C9E96534740D3DB9F8B86044C4089963C9E96534740DAC87553CA054C4009336DFFCA564740DAC87553CA054C4009336DFFCA564740D3DB9F8B86044C4089963C9E96534740D3DB9F8B86044C40
61967	26857	46.623542	46.663086	56.058960999999996	56.035581999999998	Центральная	0103000020E610000001000000050000005AD76839D04F4740C32973F38D044C405AD76839D04F4740A65EB7088C074C40BD378600E0544740A65EB7088C074C40BD378600E0544740C32973F38D044C405AD76839D04F4740C32973F38D044C40
62756	25269	46.676048999999999	46.859692000000003	56.090466999999997	55.902732	Центральная	0103000020E610000001000000050000002BBF0CC688564740BE86E0B88CF34B402BBF0CC688564740012F336C940B4C40015130630A6E4740012F336C940B4C40015130630A6E4740BE86E0B88CF34B402BBF0CC688564740BE86E0B88CF34B40
62758	25730	46.913913999999998	46.943683999999998	56.103186000000001	56.085706000000002	Шомиково	0103000020E61000000100000005000000A3AD4A22FB7447401689096AF80A4C40A3AD4A22FB744740D9B3E732350D4C4015E126A3CA784740D9B3E732350D4C4015E126A3CA7847401689096AF80A4C40A3AD4A22FB7447401689096AF80A4C40
61955	26771	46.876013999999998	46.904103999999997	55.884312000000001	55.875647000000001	Первомайская	0103000020E61000000100000005000000486B0C3A2170474096EB6D3315F04B40486B0C3A21704740EDBAB72231F14B4065170CAEB9734740EDBAB72231F14B4065170CAEB973474096EB6D3315F04B40486B0C3A2170474096EB6D3315F04B40
62755	25668	46.843314999999997	46.870274000000002	56.114519999999999	56.100304000000001	Центральная	0103000020E61000000100000005000000F59CF4BEF16B474039D4EFC2D60C4C40F59CF4BEF16B4740745E6397A80E4C4091477023656F4740745E6397A80E4C4091477023656F474039D4EFC2D60C4C40F59CF4BEF16B474039D4EFC2D60C4C40
62632	25532	46.831924999999998	46.857329	56.133909000000003	56.117440999999999	Советская	0103000020E61000000100000005000000C6DCB5847C6A4740D21A834E080F4C40C6DCB5847C6A4740EED11BEE23114C40C974E8F4BC6D4740EED11BEE23114C40C974E8F4BC6D4740D21A834E080F4C40C6DCB5847C6A4740D21A834E080F4C40
62102	27478	46.563104000000003	46.574629000000002	55.976205999999998	55.970453999999997	Центральная	0103000020E61000000100000005000000971FB8CA13484740DD2230D637FC4B40971FB8CA1348474059147651F4FC4B40A62A6D718D49474059147651F4FC4B40A62A6D718D494740DD2230D637FC4B40971FB8CA13484740DD2230D637FC4B40
61953	26616	46.712097999999997	46.752198999999997	55.999640999999997	55.985478000000001	Школьная	0103000020E6100000010000000500000004C6FA06265B4740B876A22424FE4B4004C6FA06265B4740D05E7D3CF4FF4B40BD8A8C0E48604740D05E7D3CF4FF4B40BD8A8C0E48604740B876A22424FE4B4004C6FA06265B4740B876A22424FE4B40
61954	25370	46.793233999999998	46.814183	56.169407999999997	56.157573999999997	Новая	0103000020E61000000100000005000000A20914B188654740965984622B144C40A20914B18865474023D74D29AF154C40C6FA06263768474023D74D29AF154C40C6FA062637684740965984622B144C40A20914B188654740965984622B144C40
62866	26275	46.596322999999998	46.609430000000003	55.947263	55.941147999999998	Школьная	0103000020E61000000100000005000000226DE34F544C47401059A48977F84B40226DE34F544C4740FDDAFAE93FF94B40C4995FCD014E4740FDDAFAE93FF94B40C4995FCD014E47401059A48977F84B40226DE34F544C47401059A48977F84B40
62634	26538	46.498990999999997	46.524915999999997	55.933509000000001	55.922192000000003	Володарского	0103000020E61000000100000005000000C9FFE4EFDE3F4740015130630AF64B40C9FFE4EFDE3F4740C6C210397DF74B40D5928E7230434740C6C210397DF74B40D5928E7230434740015130630AF64B40C9FFE4EFDE3F4740015130630AF64B40
62862	26589	46.645254999999999	46.656798000000002	55.948265999999997	55.941974999999999	Западная	0103000020E610000001000000050000004D4A41B797524740265305A392F84B404D4A41B79752474051F4C0C760F94B40030AF5F41154474051F4C0C760F94B40030AF5F411544740265305A392F84B404D4A41B797524740265305A392F84B40
62636	26813	46.928106999999997	46.956978999999997	55.864384000000001	55.851500000000001	Чебоксарская	0103000020E610000001000000050000002618CE35CC764740A245B6F3FDEC4B402618CE35CC764740C4978922A4EE4B40B9FAB1497E7A4740C4978922A4EE4B40B9FAB1497E7A4740A245B6F3FDEC4B402618CE35CC764740A245B6F3FDEC4B40
61979	26120	46.523316999999999	46.811281000000001	55.951219999999999	55.922609999999999	Школьная	0103000020E610000001000000050000006D382C0DFC424740357BA01518F64B406D382C0DFC4247408BA6B393C1F94B40DF6E490ED86747408BA6B393C1F94B40DF6E490ED8674740357BA01518F64B406D382C0DFC424740357BA01518F64B40
62658	58013	46.588571000000002	46.604300000000002	56.049208999999998	56.038654999999999	Эхменя	0103000020E61000000100000005000000E02F664B564B4740D769A4A5F2044C40E02F664B564B47409DD5027B4C064C40857CD0B3594D47409DD5027B4C064C40857CD0B3594D4740D769A4A5F2044C40E02F664B564B4740D769A4A5F2044C40
62638	26439	46.600357000000002	46.622725000000003	55.907035999999998	55.898052999999997	Озерная	0103000020E610000001000000050000005C76887FD84C47408F899466F3F24B405C76887FD84C4740B72572C119F44B4068B3EA73B54F4740B72572C119F44B4068B3EA73B54F47408F899466F3F24B405C76887FD84C47408F899466F3F24B40
62640	27298	46.891285000000003	46.907383000000003	56.032640000000001	56.023328999999997	Школьная	0103000020E610000001000000050000002B357BA0157247403106D671FC024C402B357BA0157247404E452A8C2D044C4023F94A20257447404E452A8C2D044C4023F94A20257447403106D671FC024C402B357BA0157247403106D671FC024C40
62817	27174	46.712521000000002	46.729993	55.847375999999997	55.835715	Школьная	0103000020E610000001000000050000004B5B5CE3335B474069E388B5F8EA4B404B5B5CE3335B474028B517D176EC4B408BA71E69705D474028B517D176EC4B408BA71E69705D474069E388B5F8EA4B404B5B5CE3335B474069E388B5F8EA4B40
62812	25862	46.846719999999998	46.862017999999999	56.055779000000001	56.045729999999999	Озерная	0103000020E610000001000000050000003F6F2A52616C474019390B7BDA054C403F6F2A52616C4740DC662AC423074C401B48179B566E4740DC662AC423074C401B48179B566E474019390B7BDA054C403F6F2A52616C474019390B7BDA054C40
61809	25910	46.751939	46.769384000000002	56.069293000000002	56.048836999999999	Молодежная	0103000020E6100000010000000500000021CB82893F604740D9EA724A40064C4021CB82893F604740BE6BD097DE084C406808C72C7B624740BE6BD097DE084C406808C72C7B624740D9EA724A40064C4021CB82893F604740D9EA724A40064C40
62857	26196	46.873786000000003	46.887557000000001	55.919356999999998	55.905174000000002	Победы	0103000020E61000000100000005000000F1D93A38D86F47404298DBBDDCF34B40F1D93A38D86F4740A12C7C7DADF54B40FE2AC0779B714740A12C7C7DADF54B40FE2AC0779B7147404298DBBDDCF34B40F1D93A38D86F47404298DBBDDCF34B40
61965	25962	46.802540999999998	46.817453	56.018363000000001	56.007755000000003	Центральная	0103000020E610000001000000050000007D59DAA9B9664740B4B0A71DFE004C407D59DAA9B96647406D3A02B859024C403082C64CA26847406D3A02B859024C403082C64CA2684740B4B0A71DFE004C407D59DAA9B9664740B4B0A71DFE004C40
62684	58017	46.630558000000001	46.642676999999999	56.105074000000002	56.099325	Социалистическая	0103000020E61000000100000005000000971DE21FB65047406D567DAEB60C4C40971DE21FB650474078D49810730D4C4019726C3D4352474078D49810730D4C4019726C3D435247406D567DAEB60C4C40971DE21FB65047406D567DAEB60C4C40
61881	26686	46.695605	46.720255000000002	55.917994999999998	55.902529999999999	Школьная	0103000020E6100000010000000500000090F7AA950959474056D4601A86F34B4090F7AA95095947401D7233DC80F54B40E7E3DA50315C47401D7233DC80F54B40E7E3DA50315C474056D4601A86F34B4090F7AA950959474056D4601A86F34B40
62773	27212	46.822842999999999	46.835966999999997	55.874597000000001	55.866146999999998	Центральная	0103000020E610000001000000050000000B5F5FEB52694740A643A7E7DDEE4B400B5F5FEB52694740011764CBF2EF4B4082C476F7006B4740011764CBF2EF4B4082C476F7006B4740A643A7E7DDEE4B400B5F5FEB52694740A643A7E7DDEE4B40
61952	25796	46.756798000000003	46.773453000000003	56.055276999999997	56.043084999999998	Московская	0103000020E61000000100000005000000D0D6C1C1DE6047405DF92CCF83054C40D0D6C1C1DE604740499C155113074C401EFF058200634740499C155113074C401EFF0582006347405DF92CCF83054C40D0D6C1C1DE6047405DF92CCF83054C40
61626	25012	46.762844000000001	46.792614	55.972056000000002	55.954486000000003	Чапаева	0103000020E6100000010000000500000094F947DFA4614740B43EE5982CFA4B4094F947DFA4614740B7F0BC546CFC4B40062D246074654740B7F0BC546CFC4B40062D246074654740B43EE5982CFA4B4094F947DFA4614740B43EE5982CFA4B40
61807	25012	46.762844000000001	46.792614	55.972056000000002	55.954486000000003	Красная Площадь	0103000020E6100000010000000500000094F947DFA4614740B43EE5982CFA4B4094F947DFA4614740B7F0BC546CFC4B40062D246074654740B7F0BC546CFC4B40062D246074654740B43EE5982CFA4B4094F947DFA4614740B43EE5982CFA4B40
61670	25012	46.762844000000001	46.792614	55.972056000000002	55.954486000000003	50 лет Октября	0103000020E6100000010000000500000094F947DFA4614740B43EE5982CFA4B4094F947DFA4614740B7F0BC546CFC4B40062D246074654740B7F0BC546CFC4B40062D246074654740B43EE5982CFA4B4094F947DFA4614740B43EE5982CFA4B40
62760	26097	46.828268000000001	46.849496000000002	56.020079000000003	56.009309999999999	Центральная	0103000020E61000000100000005000000632992AF046A47404CC3F01131014C40632992AF046A47400F2BDCF291024C409A0AF148BC6C47400F2BDCF291024C409A0AF148BC6C47404CC3F01131014C40632992AF046A47404CC3F01131014C40
62876	26947	46.604058000000002	46.630082000000002	56.081220999999999	56.061991999999996	Победы	0103000020E610000001000000050000008F71C5C5514D47408B4E965AEF074C408F71C5C5514D4740CC5F2173650A4C402EE6E786A6504740CC5F2173650A4C402EE6E786A65047408B4E965AEF074C408F71C5C5514D47408B4E965AEF074C40
61966	26160	46.795479999999998	46.838706999999999	55.965651999999999	55.947620999999998	Советская	0103000020E61000000100000005000000A04FE449D26547405C001AA54BF94B40A04FE449D265474093A8177C9AFB4B4090F63FC05A6B474093A8177C9AFB4B4090F63FC05A6B47405C001AA54BF94B40A04FE449D26547405C001AA54BF94B40
61950	25627	46.872996000000001	46.886496999999999	56.063825999999999	56.054492000000003	Молодежная	0103000020E61000000100000005000000F8C43A55BE6F474063F20698F9064C40F8C43A55BE6F474037514B732B084C404580D3BB7871474037514B732B084C404580D3BB7871474063F20698F9064C40F8C43A55BE6F474063F20698F9064C40
62082	25575	46.874217000000002	46.909520999999998	56.087991000000002	56.072544000000001	Ягодная	0103000020E61000000100000005000000BA4DB857E66F4740B1C22D1F49094C40BA4DB857E66F4740D2AB014A430B4C403A03232F6B744740D2AB014A430B4C403A03232F6B744740B1C22D1F49094C40BA4DB857E66F4740B1C22D1F49094C40
62641	26737	46.67436	46.693520999999997	55.876375000000003	55.862181	30 лет Победы	0103000020E6100000010000000500000083DDB06D51564740C51D6FF25BEE4B4083DDB06D515647401904560E2DF04B406B0BCF4BC55847401904560E2DF04B406B0BCF4BC5584740C51D6FF25BEE4B4083DDB06D51564740C51D6FF25BEE4B40
62645	25480	46.745919999999998	46.849333999999999	56.145634999999999	55.869607000000002	Центральная	0103000020E6100000010000000500000056B77A4E7A5F4740B4AF3C484FEF4B4056B77A4E7A5F47409413ED2AA4124C40C0B0FCF9B66C47409413ED2AA4124C40C0B0FCF9B66C4740B4AF3C484FEF4B4056B77A4E7A5F4740B4AF3C484FEF4B40
62642	25480	46.745919999999998	46.849333999999999	56.145634999999999	55.869607000000002	Антонова	0103000020E6100000010000000500000056B77A4E7A5F4740B4AF3C484FEF4B4056B77A4E7A5F47409413ED2AA4124C40C0B0FCF9B66C47409413ED2AA4124C40C0B0FCF9B66C4740B4AF3C484FEF4B4056B77A4E7A5F4740B4AF3C484FEF4B40
62094	24740	46.677064000000001	46.705074000000003	56.111991000000003	56.099431000000003	Хырлыхская	0103000020E6100000010000000500000044A67C08AA564740B39AAE27BA0C4C4044A67C08AA564740223999B8550E4C4045A165DD3F5A4740223999B8550E4C4045A165DD3F5A4740B39AAE27BA0C4C4044A67C08AA564740B39AAE27BA0C4C40
61963	25141	46.658011000000002	46.674934999999998	55.865813000000003	55.856648999999997	Ленина	0103000020E6100000010000000500000042B456B4395447405793A7ACA6ED4B4042B456B439544740D0B9DBF5D2EE4B407FF6234564564740D0B9DBF5D2EE4B407FF62345645647405793A7ACA6ED4B4042B456B4395447405793A7ACA6ED4B40
62754	25235	46.746206999999998	46.759943	56.096618999999997	56.084761999999998	Пакшандаева	0103000020E61000000100000005000000EC8502B6835F4740C6F8307BD90A4C40EC8502B6835F47400B96EA025E0C4C407DE9EDCF456147400B96EA025E0C4C407DE9EDCF45614740C6F8307BD90A4C40EC8502B6835F4740C6F8307BD90A4C40
62681	16323	46.724055	46.76182	56.120176000000001	56.101866000000001	Советская	0103000020E61000000100000005000000ADC090D5AD5C47408449F1F1090D4C40ADC090D5AD5C4740CEE15AED610F4C4028B8585183614740CEE15AED610F4C4028B85851836147408449F1F1090D4C40ADC090D5AD5C47408449F1F1090D4C40
61572	16323	46.724055	46.76182	56.120176000000001	56.101866000000001	Ленина	0103000020E61000000100000005000000ADC090D5AD5C47408449F1F1090D4C40ADC090D5AD5C4740CEE15AED610F4C4028B8585183614740CEE15AED610F4C4028B85851836147408449F1F1090D4C40ADC090D5AD5C47408449F1F1090D4C40
62852	26049	46.782733	46.791707000000002	56.005667000000003	56.000563	Главная	0103000020E61000000100000005000000FF3F4E9830644740384BC97212004C40FF3F4E98306447404ED53DB2B9004C40D481ACA7566547404ED53DB2B9004C40D481ACA756654740384BC97212004C40FF3F4E9830644740384BC97212004C40
62757	25421	46.763086999999999	46.783864999999999	56.140946	56.128901999999997	Центральная	0103000020E610000001000000050000005A80B6D5AC614740CA3159DC7F104C405A80B6D5AC6147404240BE840A124C4051BD35B0556447404240BE840A124C4051BD35B055644740CA3159DC7F104C405A80B6D5AC614740CA3159DC7F104C40
62761	26481	46.544759999999997	46.925628000000003	56.090035	55.926827000000003	Колхозная	0103000020E61000000100000005000000A01518B2BA45474060066344A2F64B40A01518B2BA454740683F5244860B4C40862172FA7A764740683F5244860B4C40862172FA7A76474060066344A2F64B40A01518B2BA45474060066344A2F64B40
61970	27343	46.867542999999998	46.885472999999998	55.972881999999998	55.957273000000001	Центральная	0103000020E61000000100000005000000D66F26A60B6F4740022CF2EB87FA4B40D66F26A60B6F4740FC6EBA6587FC4B40D93EE42D57714740FC6EBA6587FC4B40D93EE42D57714740022CF2EB87FA4B40D66F26A60B6F4740022CF2EB87FA4B40
62863	26010	46.822572999999998	46.831843999999997	55.989964999999998	55.980936	Школьная	0103000020E610000001000000050000004BC972124A6947400ABC934F8FFD4B404BC972124A694740A297512CB7FE4B40D9AF3BDD796A4740A297512CB7FE4B40D9AF3BDD796A47400ABC934F8FFD4B404BC972124A6947400ABC934F8FFD4B40
62813	52569	47.679692000000003	47.712443999999998	56.070695000000001	56.056914999999996	Кооперативная	0103000020E610000001000000050000002AADBF2500D747406FD39FFD48074C402AADBF2500D74740D07EA4880C094C409F1D705D31DB4740D07EA4880C094C409F1D705D31DB47406FD39FFD48074C402AADBF2500D747406FD39FFD48074C40
61880	32766	47.774141	47.806173999999999	55.972574000000002	55.960552999999997	Тогаевская	0103000020E6100000010000000500000012BF620D17E347408F899466F3FA4B4012BF620D17E347404F78094E7DFC4B405871AAB530E747404F78094E7DFC4B405871AAB530E747408F899466F3FA4B4012BF620D17E347408F899466F3FA4B40
62625	52506	48.042701000000001	48.057423999999997	55.910981999999997	55.903816999999997	Новая	0103000020E61000000100000005000000D540F33977054840CF488446B0F34B40D540F33977054840519FE40E9BF44B40B4006DAB59074840519FE40E9BF44B40B4006DAB59074840CF488446B0F34B40D540F33977054840CF488446B0F34B40
62753	52552	47.875255000000003	47.889727000000001	56.082777999999998	56.073810000000002	Почтовая	0103000020E610000001000000050000008B54185B08F04740130F289B72094C408B54185B08F04740056A3178980A4C4021AF0793E2F14740056A3178980A4C4021AF0793E2F14740130F289B72094C408B54185B08F04740130F289B72094C40
61878	24612	47.576555999999997	47.605714999999996	56.013159999999999	56.000774	30 лет Победы	0103000020E6100000010000000500000002284696CCC94740F357C85C19004C4002284696CCC94740C4CE143AAF014C402BD9B11188CD4740C4CE143AAF014C402BD9B11188CD4740F357C85C19004C4002284696CCC94740F357C85C19004C40
62921	23672	47.971122999999999	47.987374000000003	55.899698999999998	55.884782000000001	Малтикас	0103000020E610000001000000050000005BB22AC24DFC4740740B5D8940F14B405BB22AC24DFC4740389F3A5629F34B40DA756F4562FE4740389F3A5629F34B40DA756F4562FE4740740B5D8940F14B405BB22AC24DFC4740740B5D8940F14B40
61964	23895	47.661060999999997	47.687893000000003	55.950186000000002	55.939565000000002	Школьная	0103000020E610000001000000050000009DD497A59DD44740AEBB79AA43F84B409DD497A59DD44740FC8EE1B19FF94B40DC12B9E00CD84740FC8EE1B19FF94B40DC12B9E00CD84740AEBB79AA43F84B409DD497A59DD44740AEBB79AA43F84B40
62928	58043	47.866450999999998	47.876314999999998	55.886493999999999	55.872656999999997	Пионерская	0103000020E61000000100000005000000124BCADDE7EE47400FD07D39B3EF4B40124BCADDE7EE4740D40CA9A278F14B4043FF04172BF04740D40CA9A278F14B4043FF04172BF047400FD07D39B3EF4B40124BCADDE7EE47400FD07D39B3EF4B40
62628	52560	47.871634999999998	47.887894000000003	56.105074000000002	56.089813999999997	Смольникова	0103000020E61000000100000005000000448655BC91EF4740895C70067F0B4C40448655BC91EF474078D49810730D4C404628B682A6F1474078D49810730D4C404628B682A6F14740895C70067F0B4C40448655BC91EF4740895C70067F0B4C40
62080	24975	47.830832999999998	47.856794999999998	55.974176	55.960906000000001	Нагорная	0103000020E6100000010000000500000002B859BC58EA4740DD43C2F7FEFA4B4002B859BC58EA4740284696CCB1FC4B402B306475ABED4740284696CCB1FC4B402B306475ABED4740DD43C2F7FEFA4B4002B859BC58EA4740DD43C2F7FEFA4B40
62751	52547	47.777303000000003	47.793031999999997	56.073821000000002	56.062947000000001	Лесная	0103000020E61000000100000005000000960A2AAA7EE34740CF30B5A50E084C40960A2AAA7EE3474007616EF772094C403A57941282E5474007616EF772094C403A57941282E54740CF30B5A50E084C40960A2AAA7EE34740CF30B5A50E084C40
62075	52505	47.935909000000002	47.982056	55.926488999999997	55.912602	Центральная	0103000020E610000001000000050000001B84B9DDCBF74740D1217024D0F44B401B84B9DDCBF74740478D093197F64B40986BD102B4FD4740478D093197F64B40986BD102B4FD4740D1217024D0F44B401B84B9DDCBF74740D1217024D0F44B40
62629	52507	47.735844999999998	47.762768000000001	55.900637000000003	55.885933000000001	Кузнечная	0103000020E610000001000000050000006AF6402B30DE47403DB9A64066F14B406AF6402B30DE4740A648BE1248F34B40B937BF61A2E14740A648BE1248F34B40B937BF61A2E147403DB9A64066F14B406AF6402B30DE47403DB9A64066F14B40
62846	52565	47.685549000000002	47.706434999999999	56.086770999999999	56.077508000000002	Новая	0103000020E610000001000000050000001B67D311C0D74740D5963AC8EB094C401B67D311C0D74740E09EE74F1B0B4C40F8DF4A766CDA4740E09EE74F1B0B4C40F8DF4A766CDA4740D5963AC8EB094C401B67D311C0D74740D5963AC8EB094C40
62752	52581	47.771014000000001	47.781866000000001	55.939207000000003	55.927709999999998	Ленина	0103000020E610000001000000050000000B613596B0E2474009168733BFF64B400B613596B0E247404F965AEF37F84B405BED612F14E447404F965AEF37F84B405BED612F14E4474009168733BFF64B400B613596B0E2474009168733BFF64B40
62844	23375	47.766396999999998	47.791685000000001	56.030296	56.011750999999997	Магазинная	0103000020E610000001000000050000005260014C19E24740FF58880E81014C405260014C19E247408D9944BDE0034C40ECDD1FEF55E547408D9944BDE0034C40ECDD1FEF55E54740FF58880E81014C405260014C19E24740FF58880E81014C40
62938	58047	47.746437	47.759300000000003	55.953628999999999	55.942680000000003	Школьная	0103000020E610000001000000050000001EC3633F8BDF4740F14BFDBCA9F84B401EC3633F8BDF474033C2DB8310FA4B4029ED0DBE30E1474033C2DB8310FA4B4029ED0DBE30E14740F14BFDBCA9F84B401EC3633F8BDF4740F14BFDBCA9F84B40
62748	23526	47.911475000000003	47.954810000000002	55.948129999999999	55.930608999999997	Церковная	0103000020E61000000100000005000000910F7A36ABF447407F2E1A321EF74B40910F7A36ABF44740A12DE7525CF94B4067F2CD3637FA4740A12DE7525CF94B4067F2CD3637FA47407F2E1A321EF74B40910F7A36ABF447407F2E1A321EF74B40
62750	52529	47.793031999999997	47.80621	55.939332999999998	55.924244999999999	Нагорная	0103000020E610000001000000050000003A57941282E54740EA3E00A94DF64B403A57941282E54740DB8651103CF84B40A5DAA7E331E74740DB8651103CF84B40A5DAA7E331E74740EA3E00A94DF64B403A57941282E54740EA3E00A94DF64B40
61962	23759	47.806623999999999	47.824195000000003	55.910012999999999	55.897618999999999	Советская	0103000020E6100000010000000500000098158A743FE7474055A2EC2DE5F24B4098158A743FE74740A9F7544E7BF44B406C43C5387FE94740A9F7544E7BF44B406C43C5387FE9474055A2EC2DE5F24B4098158A743FE7474055A2EC2DE5F24B40
62078	52553	47.766728999999998	47.800704000000003	56.119202999999999	56.104596999999998	Луговая	0103000020E6100000010000000500000088F2052D24E247403E213B6F630D4C4088F2052D24E24740E44A3D0B420F4C4061E3FA777DE64740E44A3D0B420F4C4061E3FA777DE647403E213B6F630D4C4088F2052D24E247403E213B6F630D4C40
61879	22673	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Чкалова	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
61877	22673	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Новинская	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
61669	22673	47.663881000000003	47.782862999999999	56.125475000000002	56.080387000000002	Лазо	0103000020E61000000100000005000000C8B7770DFAD447400403081F4A0A4C40C8B7770DFAD4474099BB96900F104C40CD1FD3DA34E4474099BB96900F104C40CD1FD3DA34E447400403081F4A0A4C40C8B7770DFAD447400403081F4A0A4C40
62745	52511	47.681739999999998	47.708706999999997	56.028117999999999	56.016446000000002	Лесная	0103000020E6100000010000000500000001309E4143D7474034130CE71A024C4001309E4143D74740E736E15E99034C401FB935E9B6DA4740E736E15E99034C401FB935E9B6DA474034130CE71A024C4001309E4143D7474034130CE71A024C40
62631	52578	47.620770999999998	47.648663999999997	56.009366	56.001458999999997	Шоссейная	0103000020E6100000010000000500000011A7936C75CF474076A4FACE2F004C4011A7936C75CF4740E0D8B3E732014C40D80B056C07D34740E0D8B3E732014C40D80B056C07D3474076A4FACE2F004C4011A7936C75CF474076A4FACE2F004C40
62826	24339	47.875290999999997	47.896177000000002	56.065539999999999	56.046709999999997	Школьная	0103000020E61000000100000005000000D7BD158909F04740B532E197FA054C40D7BD158909F04740384A5E9D63084C40B5368DEDB5F24740384A5E9D63084C40B5368DEDB5F24740B532E197FA054C40D7BD158909F04740B532E197FA054C40
62079	52520	47.903317999999999	47.925632	55.868698000000002	55.851652000000001	Молодежная	0103000020E61000000100000005000000AEF199EC9FF3474058C9C7EE02ED4B40AEF199EC9FF34740E10CFE7E31EF4B40C710001C7BF64740E10CFE7E31EF4B40C710001C7BF6474058C9C7EE02ED4B40AEF199EC9FF3474058C9C7EE02ED4B40
62749	52537	47.708393000000001	47.738424000000002	55.959591000000003	55.940199999999997	Мокеева	0103000020E6100000010000000500000090DB2F9FACDA47407FD93D7958F84B4090DB2F9FACDA47409A44BDE0D3FA4B406F4A79AD84DE47409A44BDE0D3FA4B406F4A79AD84DE47407FD93D7958F84B4090DB2F9FACDA47407FD93D7958F84B40
62847	52533	47.670546999999999	47.682673999999999	55.924501999999997	55.918398000000003	Северная	0103000020E6100000010000000500000028B7ED7BD4D547401D5BCF108EF54B4028B7ED7BD4D54740158BDF1456F64B402DEA93DC61D74740158BDF1456F64B402DEA93DC61D747401D5BCF108EF54B4028B7ED7BD4D547401D5BCF108EF54B40
62850	52579	47.587488999999998	47.594234999999998	56.030397000000001	56.024656999999998	Главная	0103000020E610000001000000050000003FE1ECD632CB4740094FE8F527034C403FE1ECD632CB4740C172840CE4034C40BC9179E40FCC4740C172840CE4034C40BC9179E40FCC4740094FE8F527034C403FE1ECD632CB4740094FE8F527034C40
62633	52545	47.810054999999998	47.828974000000002	56.068967000000001	56.052286000000002	Украинская	0103000020E610000001000000050000000B7BDAE1AFE74740F304C24EB1064C400B7BDAE1AFE747406AC020E9D3084C40FE9DEDD11BEA47406AC020E9D3084C40FE9DEDD11BEA4740F304C24EB1064C400B7BDAE1AFE74740F304C24EB1064C40
62821	52517	47.764420999999999	47.777779000000002	56.007452999999998	55.994183999999997	Полевая	0103000020E6100000010000000500000014B01D8CD8E147406D1ADB6B41FF4B4014B01D8CD8E14740E8A04B38F4004C40FF4124438EE34740E8A04B38F4004C40FF4124438EE347406D1ADB6B41FF4B4014B01D8CD8E147406D1ADB6B41FF4B40
62123	52510	47.690767999999998	47.709012999999999	56.000014	55.991610999999999	Школьная	0103000020E61000000100000005000000C98FF8156BD847404BADF71BEDFE4B40C98FF8156BD8474065C5707500004C402CB81FF0C0DA474065C5707500004C402CB81FF0C0DA47404BADF71BEDFE4B40C98FF8156BD847404BADF71BEDFE4B40
62766	58025	47.651242000000003	47.671239	56.093721000000002	56.084375000000001	Большая	0103000020E610000001000000050000000DE4D9E55BD34740CDCCCCCCCC0A4C400DE4D9E55BD3474066F9BA0CFF0B4C405E66D828EBD5474066F9BA0CFF0B4C405E66D828EBD54740CDCCCCCCCC0A4C400DE4D9E55BD34740CDCCCCCCCC0A4C40
62705	52576	47.614249000000001	47.635027000000001	55.992769000000003	55.982531999999999	Центральная	0103000020E61000000100000005000000E44C13B69FCE474001A3CB9BC3FD4B40E44C13B69FCE4740C7BDF90D13FF4B40DB89929048D14740C7BDF90D13FF4B40DB89929048D1474001A3CB9BC3FD4B40E44C13B69FCE474001A3CB9BC3FD4B40
62814	23165	47.769208999999996	47.805995000000003	55.870890000000003	55.858018000000001	Новая	0103000020E61000000100000005000000F964C57075E247408EB0A888D3ED4B40F964C57075E24740EC34D25279EF4B40A9DE1AD82AE74740EC34D25279EF4B40A9DE1AD82AE747408EB0A888D3ED4B40F964C57075E247408EB0A888D3ED4B40
62630	52539	47.800192000000003	47.827832999999998	56.049565999999999	56.035240000000002	Мичуринская	0103000020E61000000100000005000000AB4203B16CE647406AC18BBE82044C40AB4203B16CE647402C7FBE2D58064C4058C6866EF6E947402C7FBE2D58064C4058C6866EF6E947406AC18BBE82044C40AB4203B16CE647406AC18BBE82044C40
62815	52513	47.698160999999999	47.722002000000003	56.040671000000003	56.030813999999999	Школьная	0103000020E61000000100000005000000DC2BF3565DD94740252191B6F1034C40DC2BF3565DD94740A47213B534054C40C4D2C08F6ADC4740A47213B534054C40C4D2C08F6ADC4740252191B6F1034C40DC2BF3565DD94740252191B6F1034C40
62816	52535	47.608122999999999	47.624417999999999	55.974992	55.969068	Октябрьская	0103000020E61000000100000005000000037976F9D6CD4740D1CC936B0AFC4B40037976F9D6CD47404AEEB089CCFC4B405184D4EDECCF47404AEEB089CCFC4B405184D4EDECCF4740D1CC936B0AFC4B40037976F9D6CD4740D1CC936B0AFC4B40
62845	52528	47.836492999999997	47.864969000000002	55.926609999999997	55.915841	Акшики	0103000020E610000001000000050000009D2ADF3312EB474000AB23473AF54B409D2ADF3312EB4740C2120F289BF64B40E486DF4DB7EE4740C2120F289BF64B40E486DF4DB7EE474000AB23473AF54B409D2ADF3312EB474000AB23473AF54B40
62786	52503	47.897533000000003	47.932037000000001	55.919922	55.904079000000003	Центральная усадьба	0103000020E61000000100000005000000570A815CE2F247400D0055DCB8F34B40570A815CE2F247407A6F0C01C0F54B40BBD408FD4CF747407A6F0C01C0F54B40BBD408FD4CF747400D0055DCB8F34B40570A815CE2F247400D0055DCB8F34B40
62746	52465	46.170468	46.186574999999998	55.707901999999997	55.688491999999997	Центральная	0103000020E61000000100000005000000DC813AE5D115474060C77F8120D84B40DC813AE5D1154740F16261889CDA4B4027A089B0E1174740F16261889CDA4B4027A089B0E117474060C77F8120D84B40DC813AE5D115474060C77F8120D84B40
62120	52420	46.108322999999999	46.131571000000001	55.742457999999999	55.731090000000002	Молодежная	0103000020E61000000100000005000000CA332F87DD0D474061376C5B94DD4B40CA332F87DD0D4740A8531EDD08DF4B400F0D8B51D7104740A8531EDD08DF4B400F0D8B51D710474061376C5B94DD4B40CA332F87DD0D474061376C5B94DD4B40
62114	52482	46.460991999999997	46.476613999999998	55.737561999999997	55.727865999999999	Вторая	0103000020E61000000100000005000000DBDB2DC9013B474067EF8CB62ADD4B40DBDB2DC9013B4740DC627E6E68DE4B406A6803B0013D4740DC627E6E68DE4B406A6803B0013D474067EF8CB62ADD4B40DBDB2DC9013B474067EF8CB62ADD4B40
62809	52496	46.322679000000001	46.351281	55.720925000000001	55.708875999999997	Новая	0103000020E61000000100000005000000910DA48B4D294740AB75E272BCDA4B40910DA48B4D29474035EF384547DC4B40645A9BC6F62C474035EF384547DC4B40645A9BC6F62C4740AB75E272BCDA4B40910DA48B4D294740AB75E272BCDA4B40
61870	22566	46.446421999999998	46.464863999999999	55.693728	55.680624999999999	Молодежная	0103000020E61000000100000005000000821B295B2439474085EB51B81ED74B40821B295B24394740E5284014CCD84B403B8BDEA9803B4740E5284014CCD84B403B8BDEA9803B474085EB51B81ED74B40821B295B2439474085EB51B81ED74B40
61946	33148	46.052132999999998	46.082011000000001	55.736477999999998	55.712791000000003	Чернореченская	0103000020E610000001000000050000006C054D4BAC0647400BF148BC3CDB4B406C054D4BAC0647409B1C3EE944DE4B40C57421567F0A47409B1C3EE944DE4B40C57421567F0A47400BF148BC3CDB4B406C054D4BAC0647400BF148BC3CDB4B40
61947	57913	46.114620000000002	46.147714000000001	55.718197000000004	55.703839000000002	Центральная	0103000020E61000000100000005000000D8BB3FDEAB0E47401E53776517DA4B40D8BB3FDEAB0E4740EC8A19E1EDDB4B40A794D74AE8124740EC8A19E1EDDB4B40A794D74AE81247401E53776517DA4B40D8BB3FDEAB0E47401E53776517DA4B40
62074	22472	46.360489000000001	46.379900999999997	55.730994000000003	55.720038000000002	Центральная	0103000020E61000000100000005000000ACC8E880242E47404AF086342ADC4B40ACC8E880242E47403FC91D3691DD4B40DD5B9198A03047403FC91D3691DD4B40DD5B9198A03047404AF086342ADC4B40ACC8E880242E47404AF086342ADC4B40
62747	52472	46.133178999999998	46.157181999999999	55.770142	55.743749999999999	Николаева	0103000020E61000000100000005000000CAC16C020C1147403333333333DF4B40CAC16C020C11474055A3570394E24B408BC22E8A1E14474055A3570394E24B408BC22E8A1E1447403333333333DF4B40CAC16C020C1147403333333333DF4B40
62741	52470	46.075147999999999	46.101343	55.774816000000001	55.760660999999999	Запрудная	0103000020E610000001000000050000000E2E1D739E094740DC2BF3565DE14B400E2E1D739E0947407235B22B2DE34B40DA56B3CEF80C47407235B22B2DE34B40DA56B3CEF80C4740DC2BF3565DE14B400E2E1D739E094740DC2BF3565DE14B40
62805	52450	46.217477000000002	46.236412999999999	55.772325000000002	55.760635999999998	Центральная	0103000020E61000000100000005000000EC504D49D61B474083143C855CE14B40EC504D49D61B47400D71AC8BDBE24B40B4ACFBC7421E47400D71AC8BDBE24B40B4ACFBC7421E474083143C855CE14B40EC504D49D61B474083143C855CE14B40
62099	52431	46.228265999999998	46.260568999999997	55.686112000000001	55.655366000000001	Шоссейная	0103000020E61000000100000005000000F564FED1371D474086747808E3D34B40F564FED1371D474053B29C84D2D74B40FBAC32535A21474053B29C84D2D74B40FBAC32535A21474086747808E3D34B40F564FED1371D474086747808E3D34B40
62077	52492	46.338273000000001	46.368501999999999	55.713202000000003	55.700273000000003	Ленина	0103000020E61000000100000005000000560F98874C2B4740CBA2B08BA2D94B40560F98874C2B47408DB800344ADB4B405B41D3122B2F47408DB800344ADB4B405B41D3122B2F4740CBA2B08BA2D94B40560F98874C2B4740CBA2B08BA2D94B40
62736	52430	46.173163000000002	46.193311999999999	55.676107999999999	55.650775000000003	Центральная	0103000020E610000001000000050000004AF086342A164740F7065F984CD34B404AF086342A1647403048FAB48AD64B4051F69672BE1847403048FAB48AD64B4051F69672BE184740F7065F984CD34B404AF086342A164740F7065F984CD34B40
62070	52476	46.375805	46.411422999999999	55.721680999999997	55.708013999999999	Центральная	0103000020E610000001000000050000002E56D4601A304740198EE733A0DA4B402E56D4601A3047408192020B60DC4B403EE94482A93447408192020B60DC4B403EE94482A9344740198EE733A0DA4B402E56D4601A304740198EE733A0DA4B40
62737	52425	46.193168999999997	46.210631999999997	55.681365999999997	55.673087000000002	Сосновая	0103000020E61000000100000005000000EECC04C3B91847406F2EFEB627D64B40EECC04C3B91847409C4D470037D74B40DBBE47FDF51A47409C4D470037D74B40DBBE47FDF51A47406F2EFEB627D64B40EECC04C3B91847406F2EFEB627D64B40
62006	52428	46.185586999999998	46.201791999999998	55.630313999999998	55.617927000000002	Центральная	0103000020E6100000010000000500000008C89750C11747405F28603B18CF4B4008C89750C1174740001B1021AED04B40164CFC51D4194740001B1021AED04B40164CFC51D41947405F28603B18CF4B4008C89750C11747405F28603B18CF4B40
62680	52486	46.301613000000003	46.334384	55.742812999999998	55.725737000000002	Ленина	0103000020E61000000100000005000000348639419B264740A33F34F3E4DC4B40348639419B2647409605137F14DF4B4020274C18CD2A47409605137F14DF4B4020274C18CD2A4740A33F34F3E4DC4B40348639419B264740A33F34F3E4DC4B40
61804	33039	46.111789999999999	46.161943000000001	55.687882999999999	55.668219000000001	Школьная	0103000020E610000001000000050000008A027D224F0E47406DC83F3388D54B408A027D224F0E4740B83CD68C0CD84B407768588CBA144740B83CD68C0CD84B407768588CBA1447406DC83F3388D54B408A027D224F0E47406DC83F3388D54B40
62627	33039	46.111789999999999	46.161943000000001	55.687882999999999	55.668219000000001	Новая	0103000020E610000001000000050000008A027D224F0E47406DC83F3388D54B408A027D224F0E4740B83CD68C0CD84B407768588CBA144740B83CD68C0CD84B407768588CBA1447406DC83F3388D54B408A027D224F0E47406DC83F3388D54B40
62742	21795	46.107486999999999	46.123136000000002	55.759850999999998	55.751229000000002	Ульянова	0103000020E6100000010000000500000061DF4E22C20D47404567994528E04B4061DF4E22C20D47409C6A2DCC42E14B40EA7AA2EBC20F47409C6A2DCC42E14B40EA7AA2EBC20F47404567994528E04B4061DF4E22C20D47404567994528E04B40
62743	52481	46.403427999999998	46.437806999999999	55.733562999999997	55.722968000000002	Школьная	0103000020E6100000010000000500000035255987A3334740FB0626378ADC4B4035255987A33347401F477364E5DD4B40DD7A4D0F0A3847401F477364E5DD4B40DD7A4D0F0A384740FB0626378ADC4B4035255987A3334740FB0626378ADC4B40
62626	52441	46.239432000000001	46.271942000000003	55.751528	55.737720000000003	Лесная	0103000020E61000000100000005000000D5CE30B5A51E474075CDE49B6DDE4B40D5CE30B5A51E47409F03CB1132E04B405534D6FECE2247409F03CB1132E04B405534D6FECE22474075CDE49B6DDE4B40D5CE30B5A51E474075CDE49B6DDE4B40
61960	33027	46.063119	46.078094	55.735402999999998	55.730918000000003	Ленина	0103000020E61000000100000005000000CC608C4814084740640795B88EDD4B40CC608C4814084740AD307DAF21DE4B40C501F4FBFE094740AD307DAF21DE4B40C501F4FBFE094740640795B88EDD4B40CC608C4814084740640795B88EDD4B40
62734	52447	46.265663000000004	46.287365999999999	55.791268000000002	55.771858999999999	Школьная	0103000020E61000000100000005000000EE60C43E01224740C70F9546CCE24B40EE60C43E01224740882F134548E54B40BDFDB968C8244740882F134548E54B40BDFDB968C8244740C70F9546CCE24B40EE60C43E01224740C70F9546CCE24B40
62119	52478	46.399538999999997	46.419938999999999	55.770558000000001	55.755834	Школьная	0103000020E61000000100000005000000FF3C0D1824334740399A232BBFE04B40FF3C0D1824334740E9D500A5A1E24B4050A8A78FC0354740E9D500A5A1E24B4050A8A78FC0354740399A232BBFE04B40FF3C0D1824334740399A232BBFE04B40
61585	21521	46.116757999999997	46.17407	55.710397999999998	55.685319999999997	площадь Победы	0103000020E61000000100000005000000EFC517EDF10E4740B9A5D590B8D74B40EFC517EDF10E474068925852EEDA4B407C9BFEEC4716474068925852EEDA4B407C9BFEEC47164740B9A5D590B8D74B40EFC517EDF10E4740B9A5D590B8D74B40
61616	21521	46.116757999999997	46.17407	55.710397999999998	55.685319999999997	Советская	0103000020E61000000100000005000000EFC517EDF10E4740B9A5D590B8D74B40EFC517EDF10E474068925852EEDA4B407C9BFEEC4716474068925852EEDA4B407C9BFEEC47164740B9A5D590B8D74B40EFC517EDF10E4740B9A5D590B8D74B40
62621	52448	46.157730000000001	46.180340999999999	55.775413	55.763756000000001	Центральная	0103000020E610000001000000050000008ECC237F30144740D80FB1C1C2E14B408ECC237F3014474056F2B1BB40E34B406090F4691517474056F2B1BB40E34B406090F46915174740D80FB1C1C2E14B408ECC237F30144740D80FB1C1C2E14B40
62683	16588	46.214441000000001	46.227808000000003	55.772309999999997	55.766364000000003	Прямая	0103000020E61000000100000005000000F5F57CCD721B4740776A2E3718E24B40F5F57CCD721B4740D72FD80DDBE24B4033E202D0281D4740D72FD80DDBE24B4033E202D0281D4740776A2E3718E24B40F5F57CCD721B4740776A2E3718E24B40
62618	16588	46.214441000000001	46.227808000000003	55.772309999999997	55.766364000000003	Новая	0103000020E61000000100000005000000F5F57CCD721B4740776A2E3718E24B40F5F57CCD721B4740D72FD80DDBE24B4033E202D0281D4740D72FD80DDBE24B4033E202D0281D4740776A2E3718E24B40F5F57CCD721B4740776A2E3718E24B40
62622	52457	46.209750999999997	46.224716999999998	55.721463	55.706710000000001	Центральная	0103000020E61000000100000005000000D2A6EA1ED91A4740CAE0287975DA4B40D2A6EA1ED91A474014234BE658DC4B4078EDD286C31C474014234BE658DC4B4078EDD286C31C4740CAE0287975DA4B40D2A6EA1ED91A4740CAE0287975DA4B40
62071	52488	46.340716999999998	46.367117999999998	55.745173999999999	55.732782999999998	Школьная	0103000020E610000001000000050000007A185A9D9C2B47404A0856D5CBDD4B407A185A9D9C2B47402DEA93DC61DF4B40EFE2FDB8FD2E47402DEA93DC61DF4B40EFE2FDB8FD2E47404A0856D5CBDD4B407A185A9D9C2B47404A0856D5CBDD4B40
62808	52487	46.352431000000003	46.375041000000003	55.764403999999999	55.750393000000003	Ленина	0103000020E610000001000000050000005D8C81751C2D4740DC12B9E00CE04B405D8C81751C2D47403E7782FDD7E14B405FD4EE57013047403E7782FDD7E14B405FD4EE5701304740DC12B9E00CE04B405D8C81751C2D4740DC12B9E00CE04B40
61803	32960	46.167476999999998	46.179558999999998	55.748133000000003	55.740085999999998	Молодежная	0103000020E6100000010000000500000085EAE6E26F1547401D1D5723BBDE4B4085EAE6E26F154740790778D2C2DF4B40EA5910CAFB164740790778D2C2DF4B40EA5910CAFB1647401D1D5723BBDE4B4085EAE6E26F1547401D1D5723BBDE4B40
62800	52424	46.191237000000001	46.208942999999998	55.606786999999997	55.595281999999997	Шоссейная	0103000020E6100000010000000500000080643A747A184740E0F2583332CC4B4080643A747A184740A8514832ABCD4B4033DDEBA4BE1A4740A8514832ABCD4B4033DDEBA4BE1A4740E0F2583332CC4B4080643A747A184740E0F2583332CC4B40
61961	20681	46.148262000000003	46.181337999999997	55.728681999999999	55.716118000000002	Колхозная	0103000020E61000000100000005000000AA9ECC3FFA124740D9092FC1A9DB4B40AA9ECC3FFA1247408997A77345DD4B40D2C26515361747408997A77345DD4B40D2C2651536174740D9092FC1A9DB4B40AA9ECC3FFA124740D9092FC1A9DB4B40
61860	20811	46.197436000000003	46.225498999999999	55.661256999999999	55.640411	Молодежная	0103000020E61000000100000005000000CB86359545194740D47FD6FCF8D14B40CB8635954519474023A0C211A4D44B40EE23B726DD1C474023A0C211A4D44B40EE23B726DD1C4740D47FD6FCF8D14B40CB86359545194740D47FD6FCF8D14B40
62072	22632	46.494742000000002	46.527836000000001	55.714576999999998	55.701830999999999	Николаева	0103000020E6100000010000000500000094FAB2B4533F4740D4282499D5D94B4094FAB2B4533F4740A5BC564277DB4B4063D34A2190434740A5BC564277DB4B4063D34A2190434740D4282499D5D94B4094FAB2B4533F4740D4282499D5D94B40
62069	52440	46.206615999999997	46.231158000000001	55.751638999999997	55.739767000000001	Солнечная	0103000020E61000000100000005000000486AA164721A47407CD45FAFB0DE4B40486AA164721A4740F6B2EDB435E04B40B91AD995961D4740F6B2EDB435E04B40B91AD995961D47407CD45FAFB0DE4B40486AA164721A47407CD45FAFB0DE4B40
62870	52416	46.109769	46.142817999999998	55.729000999999997	55.717968999999997	Васюкова	0103000020E61000000100000005000000AC8E1CE90C0E47405A457F68E6DB4B40AC8E1CE90C0E47402AE09EE74FDD4B40DBA337DC471247402AE09EE74FDD4B40DBA337DC471247405A457F68E6DB4B40AC8E1CE90C0E47405A457F68E6DB4B40
61945	57912	47.164005000000003	47.182482999999998	55.863869000000001	55.852899999999998	40 лет Победы	0103000020E61000000100000005000000B4B0A71DFE9447401361C3D32BED4B40B4B0A71DFE9447409D83674293EE4B40B9895A9A5B9747409D83674293EE4B40B9895A9A5B9747401361C3D32BED4B40B4B0A71DFE9447401361C3D32BED4B40
61941	19545	47.277695999999999	47.311706000000001	55.753995000000003	55.736939	Учительская	0103000020E61000000100000005000000711DE38A8BA34740CF12640454DE4B40711DE38A8BA347407C2C7DE882E04B40C6FB71FBE5A747407C2C7DE882E04B40C6FB71FBE5A74740CF12640454DE4B40711DE38A8BA34740CF12640454DE4B40
61990	19440	47.167859	47.183121	55.745508999999998	55.736012000000002	Н. Янгаса	0103000020E610000001000000050000006DAB59677C95474056BB26A435DE4B406DAB59677C954740D4EFC2D66CDF4B40FC1A498270974740D4EFC2D66CDF4B40FC1A49827097474056BB26A435DE4B406DAB59677C95474056BB26A435DE4B40
61918	19912	47.086157	47.120283999999998	55.792740999999999	55.781275999999998	Центральная	0103000020E6100000010000000500000026A94C31078B474029931ADA00E44B4026A94C31078B474063997E8978E54B40B41D5377658F474063997E8978E54B40B41D5377658F474029931ADA00E44B4026A94C31078B474029931ADA00E44B40
62076	57921	47.016348999999998	47.029150000000001	55.867541000000003	55.863191999999998	Каганович	0103000020E6100000010000000500000041295AB9178247409C1551137DEE4B4041295AB91782474036785F950BEF4B40D656EC2FBB83474036785F950BEF4B40D656EC2FBB8347409C1551137DEE4B4041295AB9178247409C1551137DEE4B40
62066	20078	47.084369000000002	47.103216000000003	55.841554000000002	55.833844999999997	Магазинная	0103000020E61000000100000005000000EBE5779ACC8A47407077D66EBBEA4B40EBE5779ACC8A4740B4E89D0AB8EB4B404436902E368D4740B4E89D0AB8EB4B404436902E368D47407077D66EBBEA4B40EBE5779ACC8A47407077D66EBBEA4B40
62738	20404	47.256801000000003	47.277740999999999	55.674747000000004	55.665222999999997	Центральная	0103000020E61000000100000005000000414AECDADEA0474004C6FA0626D54B40414AECDADEA047407D09151C5ED64B4011E15F048DA347407D09151C5ED64B4011E15F048DA3474004C6FA0626D54B40414AECDADEA0474004C6FA0626D54B40
62739	48165	47.188249999999996	47.200000000000003	55.737841000000003	55.731935999999997	Новая	0103000020E610000001000000050000006ABC749318984740ED612F14B0DD4B406ABC749318984740F052EA9271DE4B409A99999999994740F052EA9271DE4B409A99999999994740ED612F14B0DD4B406ABC749318984740ED612F14B0DD4B40
61944	20534	47.137557999999999	47.155327	55.714576999999998	55.705204000000002	Сапожникова	0103000020E61000000100000005000000CEA623809B9147401381EA1F44DA4B40CEA623809B914740A5BC564277DB4B40C89750C1E1934740A5BC564277DB4B40C89750C1E19347401381EA1F44DA4B40CEA623809B9147401381EA1F44DA4B40
62617	19594	47.348635999999999	47.369953000000002	55.757116000000003	55.745620000000002	Клубная	0103000020E61000000100000005000000A81ABD1AA0AC47402C9FE57970DF4B40A81ABD1AA0AC4740A1A3552DE9E04B404F07B29E5AAF4740A1A3552DE9E04B404F07B29E5AAF47402C9FE57970DF4B40A81ABD1AA0AC47402C9FE57970DF4B40
62735	19853	47.214517000000001	47.222772999999997	55.811163999999998	55.803621	Лесная	0103000020E61000000100000005000000D0B7054B759B47407DB08C0DDDE64B40D0B7054B759B4740A5D8D138D4E74B4045B75ED3839C4740A5D8D138D4E74B4045B75ED3839C47407DB08C0DDDE64B40D0B7054B759B47407DB08C0DDDE64B40
62615	19956	47.027676	47.040927000000003	55.854273999999997	55.850312000000002	Восточная	0103000020E610000001000000050000002A711DE38A834740BCB20B06D7EC4B402A711DE38A8347405BE9B5D958ED4B40FF428F183D8547405BE9B5D958ED4B40FF428F183D854740BCB20B06D7EC4B402A711DE38A834740BCB20B06D7EC4B40
62097	19381	47.253881	47.264400999999999	55.784298	55.777292000000003	Северная	0103000020E61000000100000005000000B309302C7FA04740A2B8E34D7EE34B40B309302C7FA04740BB287AE063E44B40CD0358E4D7A14740BB287AE063E44B40CD0358E4D7A14740A2B8E34D7EE34B40B309302C7FA04740A2B8E34D7EE34B40
61647	19282	47.132151	47.184773999999997	55.783686000000003	55.760601000000001	Ленина	0103000020E610000001000000050000001D91EF52EA9047400727A25F5BE14B401D91EF52EA904740A22AA6D24FE44B405793A7ACA6974740A22AA6D24FE44B405793A7ACA69747400727A25F5BE14B401D91EF52EA9047400727A25F5BE14B40
61583	19282	47.132151	47.184773999999997	55.783686000000003	55.760601000000001	Васильева	0103000020E610000001000000050000001D91EF52EA9047400727A25F5BE14B401D91EF52EA904740A22AA6D24FE44B405793A7ACA6974740A22AA6D24FE44B405793A7ACA69747400727A25F5BE14B401D91EF52EA9047400727A25F5BE14B40
62068	19736	47.037000999999997	47.058058000000003	55.795741999999997	55.785153999999999	Школьная	0103000020E61000000100000005000000AB75E272BC8447406B2920ED7FE44B40AB75E272BC844740DD06B5DFDAE54B40B6A2CD716E874740DD06B5DFDAE54B40B6A2CD716E8747406B2920ED7FE44B40AB75E272BC8447406B2920ED7FE44B40
62616	19703	47.010401999999999	47.023122000000001	55.809660999999998	55.801577000000002	Гаражная	0103000020E6100000010000000500000010E84CDA54814740E71C3C139AE64B4010E84CDA548147405FECBDF8A2E74B40B8E864A9F58247405FECBDF8A2E74B40B8E864A9F5824740E71C3C139AE64B4010E84CDA54814740E71C3C139AE64B40
61802	20449	47.023113000000002	47.039237999999997	55.757444999999997	55.747591	Центральная	0103000020E61000000100000005000000658EE55DF582474058E4D70FB1DF4B40658EE55DF582474065C22FF5F3E04B40566133C00585474065C22FF5F3E04B40566133C00585474058E4D70FB1DF4B40658EE55DF582474058E4D70FB1DF4B40
62732	19802	47.155138000000001	47.172969999999999	55.818052999999999	55.808877000000003	Садовая	0103000020E61000000100000005000000F52EDE8FDB93474049BE124889E74B40F52EDE8FDB93474085B2F0F5B5E84B40359886E12396474085B2F0F5B5E84B40359886E12396474049BE124889E74B40F52EDE8FDB93474049BE124889E74B40
62619	19481	47.296883999999999	47.316287000000003	55.794431000000003	55.780774999999998	переулок Центральный	0103000020E61000000100000005000000535A7F4B00A647406744696FF0E34B40535A7F4B00A64740DCF63DEAAFE54B403293A8177CA84740DCF63DEAAFE54B403293A8177CA847406744696FF0E34B40535A7F4B00A647406744696FF0E34B40
62823	20192	47.148105000000001	47.167265999999998	55.888271000000003	55.880707000000001	Школьная	0103000020E61000000100000005000000E2AFC91AF5924740DC2DC901BBF04B40E2AFC91AF59247401C7E37DDB2F14B40CADDE7F8689547401C7E37DDB2F14B40CADDE7F868954740DC2DC901BBF04B40E2AFC91AF5924740DC2DC901BBF04B40
61875	20542	47.083983000000003	47.107294000000003	55.724671999999998	55.708486000000001	пер. Зеленый	0103000020E61000000100000005000000C23577F4BF8A474041D653ABAFDA4B40C23577F4BF8A4740D829560DC2DC4B404D874ECFBB8D4740D829560DC2DC4B404D874ECFBB8D474041D653ABAFDA4B40C23577F4BF8A474041D653ABAFDA4B40
62067	19643	47.003745000000002	47.015962000000002	55.826352	55.818629000000001	Центральная	0103000020E61000000100000005000000034356B77A8047405247C7D5C8E84B40034356B77A804740FA7DFFE6C5E94B4048FDF50A0B824740FA7DFFE6C5E94B4048FDF50A0B8247405247C7D5C8E84B40034356B77A8047405247C7D5C8E84B40
62791	20269	47.208885000000002	47.227093000000004	55.703747999999997	55.688324000000001	Школьная	0103000020E61000000100000005000000FFCF61BEBC9A4740A58636001BD84B40FFCF61BEBC9A47400D501A6A14DA4B4045132862119D47400D501A6A14DA4B4045132862119D4740A58636001BD84B40FFCF61BEBC9A4740A58636001BD84B40
62798	20320	47.254832999999998	47.287945000000001	55.731332999999999	55.721091999999999	Вокзальная	0103000020E610000001000000050000008578245E9EA0474020B41EBE4CDC4B408578245E9EA0474027BEDA519CDD4B40FB05BB61DBA4474027BEDA519CDD4B40FB05BB61DBA4474020B41EBE4CDC4B408578245E9EA0474020B41EBE4CDC4B40
62723	18661	47.328198999999998	47.358893999999999	55.140343000000001	55.125988999999997	Зеленая	0103000020E610000001000000050000003ACAC16C02AA4740EF53556820904B403ACAC16C02AA47407C9C69C2F6914B40855D143DF0AD47407C9C69C2F6914B40855D143DF0AD4740EF53556820904B403ACAC16C02AA4740EF53556820904B40
62144	18593	47.358580000000003	47.379888000000001	55.136240999999998	55.125458000000002	Больничная	0103000020E61000000100000005000000F67F0EF3E5AD4740C382FB010F904B40F67F0EF3E5AD4740EAAF575870914B404912842BA0B04740EAAF575870914B404912842BA0B04740C382FB010F904B40F67F0EF3E5AD4740C382FB010F904B40
61991	18485	47.422082000000003	47.450009999999999	55.216909999999999	55.196793	Молодежная	0103000020E610000001000000050000007A1D71C806B64740768A558330994B407A1D71C806B647407216F6B4C39B4B40BD6F7CED99B947407216F6B4C39B4B40BD6F7CED99B94740768A558330994B407A1D71C806B64740768A558330994B40
61356	12948	47.488242999999997	47.518399000000002	55.246918000000001	55.218722999999997	Центральная	0103000020E610000001000000050000001EC022BF7EBE474006F1811DFF9B4B401EC022BF7EBE474099654F029B9F4B40BAA3FFE55AC2474099654F029B9F4B40BAA3FFE55AC2474006F1811DFF9B4B401EC022BF7EBE474006F1811DFF9B4B40
62922	58039	47.445276	47.461616999999997	55.260376999999998	55.249960999999999	Кооперативная	0103000020E61000000100000005000000CBD8D0CDFEB847404223D8B8FE9F4B40CBD8D0CDFEB84740B7D0950854A14B4089230F4416BB4740B7D0950854A14B4089230F4416BB47404223D8B8FE9F4B40CBD8D0CDFEB847404223D8B8FE9F4B40
62819	18966	47.333615999999999	47.360591999999997	55.206817000000001	55.191175999999999	Фрунзе	0103000020E610000001000000050000000FB6D8EDB3AA4740DAE3857478984B400FB6D8EDB3AA4740E0A0BDFA789A4B408099EFE027AE4740E0A0BDFA789A4B408099EFE027AE4740DAE3857478984B400FB6D8EDB3AA4740DAE3857478984B40
61381	18373	47.439005999999999	47.461967000000001	55.238104999999997	55.223734999999998	Зеленая	0103000020E61000000100000005000000B75F3E5931B847403BFC3559A39C4B40B75F3E5931B84740CD0182397A9E4B40666A12BC21BB4740CD0182397A9E4B40666A12BC21BB47403BFC3559A39C4B40B75F3E5931B847403BFC3559A39C4B40
62101	18794	47.391179999999999	47.417195	55.133204999999997	55.122971999999997	Центральная	0103000020E61000000100000005000000B56CAD2F12B247406F29E78BBD8F4B40B56CAD2F12B24740F35487DC0C914B40018750A566B54740F35487DC0C914B40018750A566B547406F29E78BBD8F4B40B56CAD2F12B247406F29E78BBD8F4B40
62029	19125	47.398114999999997	47.417096000000001	55.267004999999997	55.26108	Пожеданова	0103000020E610000001000000050000000586AC6EF5B24740E1D1C6116BA14B400586AC6EF5B247402A6F47382DA24B406EA5D76663B547402A6F47382DA24B406EA5D76663B54740E1D1C6116BA14B400586AC6EF5B24740E1D1C6116BA14B40
62064	17368	47.578586000000001	47.599345999999997	55.169370000000001	55.153858	Садовая	0103000020E6100000010000000500000034F6251B0FCA47402E1D739EB1934B4034F6251B0FCA4740367689EAAD954B40847EA65EB7CC4740367689EAAD954B40847EA65EB7CC47402E1D739EB1934B4034F6251B0FCA47402E1D739EB1934B40
62139	6205	47.439689000000001	47.453487000000003	55.178120999999997	55.167704000000001	Колхозная	0103000020E610000001000000050000009AB4A9BA47B8474046B41D5377954B409AB4A9BA47B847408BDD3EABCC964B40A114ADDC0BBA47408BDD3EABCC964B40A114ADDC0BBA474046B41D5377954B409AB4A9BA47B8474046B41D5377954B40
62129	19018	47.312334999999997	47.329231999999998	55.230446000000001	55.211969000000003	Калинина	0103000020E61000000100000005000000B532E197FAA747400762D9CC219B4B40B532E197FAA747403CBF28417F9D4B40F965304624AA47403CBF28417F9D4B40F965304624AA47400762D9CC219B4B40B532E197FAA747400762D9CC219B4B40
61932	11366	47.554825999999998	47.571139000000002	55.166794000000003	55.158349000000001	Мирная	0103000020E61000000100000005000000397CD28904C747405A2DB0C744944B40397CD28904C74740A3957B8159954B402E3C2F151BC94740A3957B8159954B402E3C2F151BC947405A2DB0C744944B40397CD28904C747405A2DB0C744944B40
62730	49516	47.639437999999998	47.666451000000002	55.253604000000003	55.235821000000001	Ленина	0103000020E61000000100000005000000EAE8B81AD9D14740E25AED612F9E4B40EAE8B81AD9D1474041118B1876A04B4079B130444ED5474041118B1876A04B4079B130444ED54740E25AED612F9E4B40EAE8B81AD9D14740E25AED612F9E4B40
62613	17946	47.656416	47.693004999999999	55.277256999999999	55.263582999999997	Комсомольская	0103000020E610000001000000050000001B49827005D447400A647616BDA14B401B49827005D4474025CB49287DA34B40747B4963B4D8474025CB49287DA34B40747B4963B4D847400A647616BDA14B401B49827005D447400A647616BDA14B40
62063	18082	47.621454	47.634030000000003	55.226723999999997	55.210382000000003	Московская	0103000020E61000000100000005000000F4FBFECD8BCF474063D520CCED9A4B40F4FBFECD8BCF4740F19BC24A059D4B40695721E527D14740F19BC24A059D4B40695721E527D1474063D520CCED9A4B40F4FBFECD8BCF474063D520CCED9A4B40
61848	817	47.480148999999997	47.497396999999999	55.184592000000002	55.171663000000002	Подгорная	0103000020E61000000100000005000000821ABE8575BD474075779D0DF9954B40821ABE8575BD4740378DEDB5A0974B40731074B4AABF4740378DEDB5A0974B40731074B4AABF474075779D0DF9954B40821ABE8575BD474075779D0DF9954B40
62733	18226	47.659246000000003	47.674922000000002	55.175657999999999	55.170059000000002	Набережная	0103000020E610000001000000050000006902452C62D44740FBB1497EC4954B406902452C62D44740F0A31AF67B964B40EBAC16D863D64740F0A31AF67B964B40EBAC16D863D64740FBB1497EC4954B406902452C62D44740FBB1497EC4954B40
62731	18174	47.611348	47.633806	55.198900000000002	55.188499	Кооперативная	0103000020E61000000100000005000000CD3CB9A640CE4740132A38BC20984B40CD3CB9A640CE47405396218E75994B401901158E20D147405396218E75994B401901158E20D14740132A38BC20984B40CD3CB9A640CE4740132A38BC20984B40
62790	19175	47.375881	47.400064	55.238449000000003	55.228746999999998	Колхозная	0103000020E6100000010000000500000009185DDE1CB047407007EA94479D4B4009185DDE1CB04740C861307F859E4B404A27124C35B34740C861307F859E4B404A27124C35B347407007EA94479D4B4009185DDE1CB047407007EA94479D4B40
61842	18276	47.691459999999999	47.719693999999997	55.161012999999997	55.147900999999997	Советская	0103000020E61000000100000005000000FF3EE3C281D84740D905836BEE924B40FF3EE3C281D847408C9DF0129C944B404F90D8EE1EDC47408C9DF0129C944B404F90D8EE1EDC4740D905836BEE924B40FF3EE3C281D84740D905836BEE924B40
61849	18872	47.288763000000003	47.324084999999997	55.196525999999999	55.179456999999999	Школьная	0103000020E61000000100000005000000BEA59C2FF6A44740E6046D72F8964B40BEA59C2FF6A44740276893C327994B40E40F069E7BA94740276893C327994B40E40F069E7BA94740E6046D72F8964B40BEA59C2FF6A44740E6046D72F8964B40
62117	49169	47.452247	47.468237000000002	55.159624000000001	55.149568000000002	Новая	0103000020E61000000100000005000000685BCD3AE3B947409A43520B25934B40685BCD3AE3B947400FD4298F6E944B407AE3A430EFBB47400FD4298F6E944B407AE3A430EFBB47409A43520B25934B40685BCD3AE3B947409A43520B25934B40
62040	6820	47.565471000000002	47.591163000000002	55.157268999999999	55.143794999999997	Центральная	0103000020E6100000010000000500000010EB8D5A61C84740062AE3DF67924B4010EB8D5A61C847405AD6FD6321944B4079CDAB3AABCB47405AD6FD6321944B4079CDAB3AABCB4740062AE3DF67924B4010EB8D5A61C84740062AE3DF67924B40
62065	17986	47.651564999999998	47.666612000000001	55.298476000000001	55.285896999999999	Смирнова	0103000020E61000000100000005000000EF1B5F7B66D347402383DC4598A44B40EF1B5F7B66D347400952297634A64B40828FC18A53D547400952297634A64B40828FC18A53D547402383DC4598A44B40EF1B5F7B66D347402383DC4598A44B40
62729	18694	47.361490000000003	47.388727000000003	55.113081000000001	55.101025	Центральная	0103000020E6100000010000000500000060EAE74D45AE4740098A1F63EE8C4B4060EAE74D45AE474045662E70798E4B403E096CCEC1B1474045662E70798E4B403E096CCEC1B14740098A1F63EE8C4B4060EAE74D45AE4740098A1F63EE8C4B40
61933	18548	47.372557999999998	47.401412000000001	55.191032	55.176665999999997	Школьная	0103000020E610000001000000050000007CEE04FBAFAF47405628D2FD9C964B407CEE04FBAFAF4740A73E90BC73984B40691CEA7761B34740A73E90BC73984B40691CEA7761B347405628D2FD9C964B407CEE04FBAFAF47405628D2FD9C964B40
61940	32522	47.487704000000001	47.516333000000003	55.271512999999999	55.263069999999999	Комсомольская	0103000020E610000001000000050000006F10AD156DBE474084471B47ACA14B406F10AD156DBE47402CB81FF0C0A24B403C6C223317C247402CB81FF0C0A24B403C6C223317C2474084471B47ACA14B406F10AD156DBE474084471B47ACA14B40
61668	49401	47.515380999999998	47.560692000000003	55.270071999999999	55.253348000000003	Шолохова	0103000020E6100000010000000500000069FD2D01F8C14740E6400FB56DA04B4069FD2D01F8C147405CC823B891A24B407E9065C1C4C747405CC823B891A24B407E9065C1C4C74740E6400FB56DA04B4069FD2D01F8C14740E6400FB56DA04B40
61666	49401	47.515380999999998	47.560692000000003	55.270071999999999	55.253348000000003	Ленина	0103000020E6100000010000000500000069FD2D01F8C14740E6400FB56DA04B4069FD2D01F8C147405CC823B891A24B407E9065C1C4C747405CC823B891A24B407E9065C1C4C74740E6400FB56DA04B4069FD2D01F8C14740E6400FB56DA04B40
61665	49401	47.515380999999998	47.560692000000003	55.270071999999999	55.253348000000003	Заводская	0103000020E6100000010000000500000069FD2D01F8C14740E6400FB56DA04B4069FD2D01F8C147405CC823B891A24B407E9065C1C4C747405CC823B891A24B407E9065C1C4C74740E6400FB56DA04B4069FD2D01F8C14740E6400FB56DA04B40
62887	18143	47.622146000000001	47.632207000000001	55.237679	55.229958000000003	Центральная	0103000020E610000001000000050000002AABE97AA2CF47400FBA84436F9D4B402AABE97AA2CF474016F9F5436C9E4B40B1A6B228ECD0474016F9F5436C9E4B40B1A6B228ECD047400FBA84436F9D4B402AABE97AA2CF47400FBA84436F9D4B40
62690	18751	47.398411000000003	47.413440000000001	55.118658000000003	55.110197999999997	Центральная	0103000020E61000000100000005000000EFAEB321FFB24740D40AD3F71A8E4B40EFAEB321FFB2474053B4722F308F4B40DB6D179AEBB4474053B4722F308F4B40DB6D179AEBB44740D40AD3F71A8E4B40EFAEB321FFB24740D40AD3F71A8E4B40
62917	49447	47.527723999999999	47.547882000000001	55.313699999999997	55.307414000000001	Овражная	0103000020E610000001000000050000003BA8C4758CC34740912A8A5759A74B403BA8C4758CC34740AA60545227A84B40960854FF20C64740AA60545227A84B40960854FF20C64740912A8A5759A74B403BA8C4758CC34740912A8A5759A74B40
62877	17784	47.535134999999997	47.548008000000003	55.217264999999998	55.209899	Комсомольская	0103000020E61000000100000005000000F4F8BD4D7FC44740473B6EF8DD9A4B40F4F8BD4D7FC4474060C8EA56CF9B4B4023F94A2025C6474060C8EA56CF9B4B4023F94A2025C64740473B6EF8DD9A4B40F4F8BD4D7FC44740473B6EF8DD9A4B40
61851	33147	47.381028999999998	47.421624000000001	55.322316999999998	55.304180000000002	Чапаева	0103000020E61000000100000005000000EEE9EA8EC5B04740740CC85EEFA64B40EEE9EA8EC5B04740F0F8F6AE41A94B40B79A75C6F7B54740F0F8F6AE41A94B40B79A75C6F7B54740740CC85EEFA64B40EEE9EA8EC5B04740740CC85EEFA64B40
61876	57907	47.571705000000001	47.613790999999999	55.272534	55.263931999999997	Комсомольская	0103000020E61000000100000005000000D7FA22A12DC94740162F1686C8A14B40D7FA22A12DC947402786E464E2A24B4021CA17B490CE47402786E464E2A24B4021CA17B490CE4740162F1686C8A14B40D7FA22A12DC94740162F1686C8A14B40
62160	14593	47.283714000000003	47.305463000000003	55.450476000000002	55.427678	Ленина	0103000020E610000001000000050000006CB587BD50A44740FE9B1727BEB64B406CB587BD50A4474003D19332A9B94B40AC915D6919A7474003D19332A9B94B40AC915D6919A74740FE9B1727BEB64B406CB587BD50A44740FE9B1727BEB64B40
62792	12628	47.209657	47.238816999999997	55.601939999999999	55.592047000000001	Сергеева	0103000020E610000001000000050000005130630AD69A4740F3583332C8CB4B405130630AD69A4740BE13B35E0CCD4B404A5D328E919E4740BE13B35E0CCD4B404A5D328E919E4740F3583332C8CB4B405130630AD69A4740F3583332C8CB4B40
62666	14030	47.633904999999999	47.655644000000002	55.362608000000002	55.349291000000001	Ленина	0103000020E61000000100000005000000ACE28DCC23D14740C1E44691B5AC4B40ACE28DCC23D147404DA25EF069AE4B40C9E88024ECD347404DA25EF069AE4B40C9E88024ECD34740C1E44691B5AC4B40ACE28DCC23D14740C1E44691B5AC4B40
62867	13944	47.571831000000003	47.600091999999997	55.440994000000003	55.425021000000001	Михайлова	0103000020E6100000010000000500000064EB19C231C947407E8E8F1667B64B4064EB19C231C94740BADDCB7D72B84B40AD4B8DD0CFCC4740BADDCB7D72B84B40AD4B8DD0CFCC47407E8E8F1667B64B4064EB19C231C947407E8E8F1667B64B40
62858	12833	47.358778000000001	47.375298000000001	55.670203999999998	55.661399000000003	Октябрьская	0103000020E610000001000000050000001C430070ECAD4740B64DF1B8A8D44B401C430070ECAD4740FED2A23EC9D54B408A20CEC309B04740FED2A23EC9D54B408A20CEC309B04740B64DF1B8A8D44B401C430070ECAD4740B64DF1B8A8D44B40
61581	12128	47.287343999999997	47.40408	55.570945000000002	55.536864000000001	Генерала Михайлова	0103000020E61000000100000005000000D5592DB0C7A447402B33A5F5B7C44B40D5592DB0C7A447404968CBB914C94B40DD7BB8E4B8B347404968CBB914C94B40DD7BB8E4B8B347402B33A5F5B7C44B40D5592DB0C7A447402B33A5F5B7C44B40
62149	13029	47.459145999999997	47.478217999999998	55.688628999999999	55.672646	Клубная	0103000020E610000001000000050000006B0BCF4BC5BA474082E49D4319D64B406B0BCF4BC5BA4740E109BDFE24D84B40E42D573F36BD4740E109BDFE24D84B40E42D573F36BD474082E49D4319D64B406B0BCF4BC5BA474082E49D4319D64B40
62057	12315	47.429690999999998	47.461410000000001	55.622003999999997	55.609603999999997	Павлова	0103000020E6100000010000000500000059315C1D00B7474061C1FD8007CE4B4059315C1D00B7474097FDBAD39DCF4B4010069E7B0FBB474097FDBAD39DCF4B4010069E7B0FBB474061C1FD8007CE4B4059315C1D00B7474061C1FD8007CE4B40
62865	13729	47.602967	47.628892	55.458925000000001	55.444813000000003	Южная	0103000020E610000001000000050000009BC8CC052ECD4740F7EAE3A1EFB84B409BC8CC052ECD47408D28ED0DBEBA4B40A75B76887FD047408D28ED0DBEBA4B40A75B76887FD04740F7EAE3A1EFB84B409BC8CC052ECD4740F7EAE3A1EFB84B40
62060	13451	47.460476	47.477274000000001	55.579098000000002	55.569218999999997	Ленина	0103000020E61000000100000005000000E44BA8E0F0BA474083A10E2BDCC84B40E44BA8E0F0BA4740EA961DE21FCA4B40959D7E5017BD4740EA961DE21FCA4B40959D7E5017BD474083A10E2BDCC84B40E44BA8E0F0BA474083A10E2BDCC84B40
61839	13227	47.579358999999997	47.599983999999999	55.626669999999997	55.612848	Гагарина	0103000020E6100000010000000500000056D28A6F28CA4740A2B5A2CD71CE4B4056D28A6F28CA474031B1F9B836D04B40C70F9546CCCC474031B1F9B836D04B40C70F9546CCCC4740A2B5A2CD71CE4B4056D28A6F28CA4740A2B5A2CD71CE4B40
61936	14425	47.331020000000002	47.366385999999999	55.476230000000001	55.466028999999999	Центральная	0103000020E61000000100000005000000352905DD5EAA474069FE98D6A6BB4B40352905DD5EAA4740E2AFC91AF5BC4B402BDB87BCE5AE4740E2AFC91AF5BC4B402BDB87BCE5AE474069FE98D6A6BB4B40352905DD5EAA474069FE98D6A6BB4B40
61935	13583	47.591459	47.609820999999997	55.524661000000002	55.51408	Школьная	0103000020E6100000010000000500000062F6B2EDB4CB47408BC3995FCDC14B4062F6B2EDB4CB47404B3E761728C34B40FEB4519D0ECE47404B3E761728C34B40FEB4519D0ECE47408BC3995FCDC14B4062F6B2EDB4CB47408BC3995FCDC14B40
61993	13429	47.494387000000003	47.522891000000001	55.579292000000002	55.558641000000001	Школьная	0103000020E61000000100000005000000A648BE1248BF4740359A5C8C81C74B40A648BE1248BF4740CF6A813D26CA4B40B62FA017EEC24740CF6A813D26CA4B40B62FA017EEC24740359A5C8C81C74B40A648BE1248BF4740359A5C8C81C74B40
62051	11619	47.300072999999998	47.322566000000002	55.529893999999999	55.517505	Ленина	0103000020E61000000100000005000000D0B4C4CA68A647401C42959A3DC24B40D0B4C4CA68A647405E2C0C91D3C34B409966BAD749A947405E2C0C91D3C34B409966BAD749A947401C42959A3DC24B40D0B4C4CA68A647401C42959A3DC24B40
61840	14001	47.567042999999998	47.616898999999997	55.368456000000002	55.352249999999998	Пушкина	0103000020E610000001000000050000007E3672DD94C847400C022B8716AD4B407E3672DD94C84740EB01F39029AF4B40B1F7E28BF6CE4740EB01F39029AF4B40B1F7E28BF6CE47400C022B8716AD4B407E3672DD94C847400C022B8716AD4B40
62727	14357	47.483302000000002	47.498466000000001	55.434925999999997	55.423789999999997	Карла Маркса	0103000020E61000000100000005000000B30B06D7DCBD4740982F2FC03EB64B40B30B06D7DCBD47400D17B9A7ABB74B407F15E0BBCDBF47400D17B9A7ABB74B407F15E0BBCDBF4740982F2FC03EB64B40B30B06D7DCBD4740982F2FC03EB64B40
61663	13507	47.482025999999998	47.524112000000002	55.54374	55.524701999999998	Сугай	0103000020E610000001000000050000002DE92807B3BD4740A912656F29C34B402DE92807B3BD474076C3B64599C54B4078B81D1A16C3474076C3B64599C54B4078B81D1A16C34740A912656F29C34B402DE92807B3BD4740A912656F29C34B40
62872	14083	47.478586	47.505383000000002	55.384645999999996	55.372799999999998	Кооперативная	0103000020E610000001000000050000006729594E42BD474072F90FE9B7AF4B406729594E42BD4740C34483143CB14B40297AE063B0C04740C34483143CB14B40297AE063B0C0474072F90FE9B7AF4B406729594E42BD474072F90FE9B7AF4B40
62820	13857	47.606434	47.633366000000002	55.478327	55.467331000000001	Канашская	0103000020E610000001000000050000005B971AA19FCD474018B49080D1BB4B405B971AA19FCD47409BE5B2D139BD4B40FD32182312D147409BE5B2D139BD4B40FD32182312D1474018B49080D1BB4B405B971AA19FCD474018B49080D1BB4B40
61873	14718	47.21387	47.233713999999999	55.455744000000003	55.441913	50 лет Победы	0103000020E610000001000000050000003ACC9717609B4740B056ED9A90B84B403ACC9717609B474093ACC3D155BA4B40054F2157EA9D474093ACC3D155BA4B40054F2157EA9D4740B056ED9A90B84B403ACC9717609B4740B056ED9A90B84B40
62055	12165	47.341377000000001	47.363844	55.575378000000001	55.564954	50 лет ВЛКСМ	0103000020E61000000100000005000000A54DD53DB2AB474048DFA46950C84B40A54DD53DB2AB4740406B7EFCA5C94B40446CB07092AE4740406B7EFCA5C94B40446CB07092AE474048DFA46950C84B40A54DD53DB2AB474048DFA46950C84B40
61988	12459	47.287936000000002	47.307608999999999	55.612126000000004	55.592728999999999	Школьная	0103000020E61000000100000005000000A8AB3B16DBA4474005323B8BDECB4B40A8AB3B16DBA4474002840F255ACE4B40467A51BB5FA7474002840F255ACE4B40467A51BB5FA7474005323B8BDECB4B40A8AB3B16DBA4474005323B8BDECB4B40
62848	11508	47.352381999999999	47.362506000000003	55.504986000000002	55.496547	Восточная	0103000020E610000001000000050000007BD976DA1AAD4740A5F622DA8EBF4B407BD976DA1AAD47400C789961A3C04B40494DBB9866AE47400C789961A3C04B40494DBB9866AE4740A5F622DA8EBF4B407BD976DA1AAD4740A5F622DA8EBF4B40
62151	13310	47.610152999999997	47.631264000000002	55.679448000000001	55.666868000000001	Ленина	0103000020E610000001000000050000003447567E19CE4740DD5F3DEE5BD54B403447567E19CE474093AAED26F8D64B4032923D42CDD0474093AAED26F8D64B4032923D42CDD04740DD5F3DEE5BD54B403447567E19CE4740DD5F3DEE5BD54B40
62053	11825	47.289732999999998	47.313519999999997	55.569921999999998	55.557367999999997	Клубная	0103000020E6100000010000000500000036C98FF815A5474020EBA9D557C74B4036C98FF815A54740ADA23F34F3C84B402A52616C21A84740ADA23F34F3C84B402A52616C21A8474020EBA9D557C74B4036C98FF815A5474020EBA9D557C74B40
62725	14139	47.470708000000002	47.499704999999999	55.36795	55.355018999999999	Спортивная	0103000020E6100000010000000500000098FBE42840BC4740B43A394371AD4B4098FBE42840BC4740174850FC18AF4B40E7525C55F6BF4740174850FC18AF4B40E7525C55F6BF4740B43A394371AD4B4098FBE42840BC4740B43A394371AD4B40
62713	11697	47.261122	47.279159999999997	55.535947	55.525685000000003	Николаева	0103000020E61000000100000005000000102219726CA14740B77F65A549C34B40102219726CA14740D5B14AE999C44B40F92CCF83BBA34740D5B14AE999C44B40F92CCF83BBA34740B77F65A549C34B40102219726CA14740B77F65A549C34B40
62612	12411	\N	\N	\N	\N	Новая	\N
62142	11533	47.358947999999998	47.379492999999997	55.530684000000001	55.426170999999997	Гагарина	0103000020E61000000100000005000000787B1002F2AD474076C075C58CB64B40787B1002F2AD474057410C74EDC34B40CC07043A93B0474057410C74EDC34B40CC07043A93B0474076C075C58CB64B40787B1002F2AD474076C075C58CB64B40
62726	14283	47.417212999999997	47.436967000000003	55.377245000000002	55.365571000000003	Советская	0103000020E61000000100000005000000A73B4F3C67B54740DAAED007CBAE4B40A73B4F3C67B547402ECA6C9049B04B403337DF88EEB747402ECA6C9049B04B403337DF88EEB74740DAAED007CBAE4B40A73B4F3C67B54740DAAED007CBAE4B40
62054	12038	47.196227	47.222161999999997	55.490181999999997	55.473286000000002	Молодежная	0103000020E61000000100000005000000CDCB61F71D994740CCD3B9A294BC4B40CDCB61F71D9947403F8BA548BEBE4B40FC34EECD6F9C47403F8BA548BEBE4B40FC34EECD6F9C4740CCD3B9A294BC4B40CDCB61F71D994740CCD3B9A294BC4B40
61872	14226	47.396417	47.425908999999997	55.391058000000001	55.378667	Кооперативная	0103000020E610000001000000050000000A4AD1CABDB247408789062978B04B400A4AD1CABDB247406A6B44300EB24B403909A52F84B647406A6B44300EB24B403909A52F84B647408789062978B04B400A4AD1CABDB247408789062978B04B40
62873	14657	47.330651000000003	47.349246000000001	55.415359000000002	55.403511999999999	Гагарина	0103000020E61000000100000005000000E2B19FC552AA474093C5FD47A6B34B40E2B19FC552AA4740B58CD47B2AB54B402121CA17B4AC4740B58CD47B2AB54B402121CA17B4AC474093C5FD47A6B34B40E2B19FC552AA474093C5FD47A6B34B40
62719	13164	47.544828000000003	47.563845000000001	55.629201000000002	55.617525000000001	Чапаева	0103000020E61000000100000005000000F9F884ECBCC5474030BB270F0BCF4B40F9F884ECBCC5474025CE8AA889D04B40AE81AD122CC8474025CE8AA889D04B40AE81AD122CC8474030BB270F0BCF4B40F9F884ECBCC5474030BB270F0BCF4B40
61978	11956	47.248069000000001	47.270176999999997	55.498184000000002	55.485264999999998	Советская	0103000020E61000000100000005000000621399B9C09F47405C72DC291DBE4B40621399B9C09F4740FBB1497EC4BF4B40D190F12895A24740FBB1497EC4BF4B40D190F12895A247405C72DC291DBE4B40621399B9C09F47405C72DC291DBE4B40
62871	14510	47.324281999999997	47.343550999999998	55.499203999999999	55.480893000000002	Спортивная	0103000020E610000001000000050000003A57941282A947400BF0DDE68DBD4B403A57941282A947402504ABEAE5BF4B4009C1AA7AF9AB47402504ABEAE5BF4B4009C1AA7AF9AB47400BF0DDE68DBD4B403A57941282A947400BF0DDE68DBD4B40
62156	14155	47.539715999999999	47.556882999999999	55.379429000000002	55.369551000000001	Шоссейная	0103000020E610000001000000050000006090F46915C54740209A79724DAF4B406090F46915C54740B613252191B04B40645930F147C74740B613252191B04B40645930F147C74740209A79724DAF4B406090F46915C54740209A79724DAF4B40
61989	13376	47.618067000000003	47.645950999999997	55.636687000000002	55.612257999999997	Центральная	0103000020E6100000010000000500000051DEC7D11CCF4740705B5B785ECE4B4051DEC7D11CCF4740E964A9F57ED14B40C4E8B985AED24740E964A9F57ED14B40C4E8B985AED24740705B5B785ECE4B4051DEC7D11CCF4740705B5B785ECE4B40
61869	13649	47.488045	47.520277	55.492207000000001	55.468862000000001	Канашская	0103000020E61000000100000005000000F8FC304278BE4740282B86AB03BC4B40F8FC304278BE47405FEE93A300BF4B4035EECD6F98C247405FEE93A300BF4B4035EECD6F98C24740282B86AB03BC4B40F8FC304278BE4740282B86AB03BC4B40
62143	11740	47.255004	47.266413	55.545976000000003	55.540948999999998	Гагарина	0103000020E61000000100000005000000B22C98F8A3A04740E6E61BD13DC54B40B22C98F8A3A047405133A48AE2C54B40581D39D219A247405133A48AE2C54B40581D39D219A24740E6E61BD13DC54B40B22C98F8A3A04740E6E61BD13DC54B40
62722	58022	47.250664999999998	47.268765999999999	55.637560999999998	55.627687000000002	Центральная	0103000020E610000001000000050000003CA06CCA15A04740EB8F300C58D04B403CA06CCA15A047403F1A4E999BD14B406C239EEC66A247403F1A4E999BD14B406C239EEC66A24740EB8F300C58D04B403CA06CCA15A04740EB8F300C58D04B40
62058	12376	47.428702000000001	47.438538999999999	55.638860999999999	55.631498000000001	Молодежная	0103000020E610000001000000050000006ADD06B5DFB64740A5BE2CEDD4D04B406ADD06B5DFB647404DD87E32C6D14B40A182C30B22B847404DD87E32C6D14B40A182C30B22B84740A5BE2CEDD4D04B406ADD06B5DFB64740A5BE2CEDD4D04B40
62148	13015	47.411490999999998	47.430875999999998	55.679797999999998	55.671711999999999	Ленина	0103000020E6100000010000000500000096CCB1BCABB44740562AA8A8FAD54B4096CCB1BCABB447406FF1F09E03D74B40CE50DCF126B747406FF1F09E03D74B40CE50DCF126B74740562AA8A8FAD54B4096CCB1BCABB44740562AA8A8FAD54B40
61871	11460	47.364913000000001	47.40549	55.506825999999997	55.435533999999997	Центральная	0103000020E6100000010000000500000050711C78B5AE4740E525FF93BFB74B4050711C78B5AE47409961A3ACDFC04B40726DA818E7B347409961A3ACDFC04B40726DA818E7B34740E525FF93BFB74B4050711C78B5AE4740E525FF93BFB74B40
62611	11460	47.364913000000001	47.40549	55.506825999999997	55.435533999999997	Лесная	0103000020E6100000010000000500000050711C78B5AE4740E525FF93BFB74B4050711C78B5AE47409961A3ACDFC04B40726DA818E7B347409961A3ACDFC04B40726DA818E7B34740E525FF93BFB74B4050711C78B5AE4740E525FF93BFB74B40
61934	13872	47.535063000000001	47.558743	55.440840000000001	55.430788999999997	Молодежная	0103000020E610000001000000050000005B26C3F17CC44740FF3C0D1824B74B405B26C3F17CC447406362F3716DB84B4039EFFFE384C747406362F3716DB84B4039EFFFE384C74740FF3C0D1824B74B405B26C3F17CC44740FF3C0D1824B74B40
62056	12211	47.368164999999998	47.383705999999997	55.613112000000001	55.607356000000003	Советская	0103000020E610000001000000050000001344DD0720AF4740C38366D7BDCD4B401344DD0720AF474080643A747ACE4B40B5A338471DB1474080643A747ACE4B40B5A338471DB14740C38366D7BDCD4B401344DD0720AF4740C38366D7BDCD4B40
62059	11919	47.215612999999998	47.232385000000001	55.51932	55.512836	Центральная	0103000020E61000000100000005000000D5CBEF34999B4740111B2C9CA4C14B40D5CBEF34999B47405114E81379C24B405D8AABCABE9D47405114E81379C24B405D8AABCABE9D4740111B2C9CA4C14B40D5CBEF34999B4740111B2C9CA4C14B40
62715	12715	47.227794000000003	47.243982000000003	55.589030000000001	55.580055000000002	Садовая	0103000020E61000000100000005000000CE1C925A289D4740CE70033E3FCA4B40CE1C925A289D4740732EC55565CB4B4006685BCD3A9F4740732EC55565CB4B4006685BCD3A9F4740CE70033E3FCA4B40CE1C925A289D4740CE70033E3FCA4B40
62062	13705	47.531443000000003	47.539231000000001	55.483938999999999	55.479030999999999	Центральная	0103000020E610000001000000050000001558005306C44740956247E350BD4B401558005306C44740252191B6F1BD4B40A4FE7A8505C54740252191B6F1BD4B40A4FE7A8505C54740956247E350BD4B401558005306C44740956247E350BD4B40
62721	13298	47.552202999999999	47.579521	55.685395999999997	55.674621000000002	Школьная	0103000020E6100000010000000500000065E08096AEC64740F0181EFB59D64B4065E08096AEC6474094675E0EBBD74B40302C7FBE2DCA474094675E0EBBD74B40302C7FBE2DCA4740F0181EFB59D64B4065E08096AEC64740F0181EFB59D64B40
62851	12079	47.191375999999998	47.218567999999998	55.463231999999998	55.449964999999999	Мира	0103000020E61000000100000005000000A19E3E027F9847401DACFF7398B94B40A19E3E027F984740F73AA92F4BBB4B40DFF94509FA9B4740F73AA92F4BBB4B40DFF94509FA9B47401DACFF7398B94B40A19E3E027F9847401DACFF7398B94B40
62860	13088	47.422324000000003	47.443282000000004	55.661485999999996	55.652155999999998	Шоссейная	0103000020E6100000010000000500000070287CB60EB64740F1F109D979D34B4070287CB60EB647408461C092ABD44B40E773EE76BDB847408461C092ABD44B40E773EE76BDB84740F1F109D979D34B4070287CB60EB64740F1F109D979D34B40
61841	14311	47.426780000000001	47.454402999999999	55.440283999999998	55.420817	Восточная	0103000020E610000001000000050000001F4B1FBAA0B64740E84CDA54DDB54B401F4B1FBAA0B64740DD79E2395BB84B40261AA4E029BA4740DD79E2395BB84B40261AA4E029BA4740E84CDA54DDB54B401F4B1FBAA0B64740E84CDA54DDB54B40
62147	12664	47.206288999999998	47.231648	55.628698	55.614327000000003	Ленина	0103000020E6100000010000000500000024438EAD679A474060066344A2CE4B4024438EAD679A4740C287122D79D04B40871744A4A69D4740C287122D79D04B40871744A4A69D474060066344A2CE4B4024438EAD679A474060066344A2CE4B40
62855	11802	47.222512000000002	47.240459999999999	55.552917999999998	55.540698999999996	Кооперативная	0103000020E61000000100000005000000D97BF1457B9C47406DFDF49F35C54B40D97BF1457B9C474053AF5B04C6C64B4082FFAD64C79E474053AF5B04C6C64B4082FFAD64C79E47406DFDF49F35C54B40D97BF1457B9C47406DFDF49F35C54B40
62864	14560	47.285806999999998	47.305723	55.484423	55.466636999999999	Чапаева	0103000020E61000000100000005000000E3FBE25295A44740410DDFC2BABB4B40E3FBE25295A447401137A79201BE4B40485167EE21A747401137A79201BE4B40485167EE21A74740410DDFC2BABB4B40E3FBE25295A44740410DDFC2BABB4B40
62061	13233	47.527040999999997	47.546993000000001	55.604066000000003	55.592931999999998	Школьная	0103000020E610000001000000050000005853591476C347403D601E32E5CB4B405853591476C347401250E10852CD4B400A12DBDD03C647401250E10852CD4B400A12DBDD03C647403D601E32E5CB4B405853591476C347403D601E32E5CB4B40
62098	12766	47.195832000000003	47.209153999999998	55.628290999999997	55.617880999999997	Центральная	0103000020E6100000010000000500000051C1E10511994740EEE87FB916CF4B4051C1E1051199474081AFE8D66BD04B40EEE9EA8EC59A474081AFE8D66BD04B40EEE9EA8EC59A4740EEE87FB916CF4B4051C1E10511994740EEE87FB916CF4B40
61868	32994	47.444046	47.467779	55.539043999999997	55.525399999999998	Ленина	0103000020E61000000100000005000000B6F5D37FD6B84740C1A8A44E40C34B40B6F5D37FD6B84740718DCF64FFC44B40B760A92EE0BB4740718DCF64FFC44B40B760A92EE0BB4740C1A8A44E40C34B40B6F5D37FD6B84740C1A8A44E40C34B40
62718	12898	47.369027000000003	47.395052	55.645074999999999	55.629994000000003	Театральная	0103000020E61000000100000005000000A62BD8463CAF47408F56B5A4A3D04B40A62BD8463CAF4740CD3B4ED191D24B40151C5E1091B24740CD3B4ED191D24B40151C5E1091B247408F56B5A4A3D04B40A62BD8463CAF47408F56B5A4A3D04B40
62849	11594	47.336454000000003	47.354869999999998	55.534418000000002	55.527411999999998	Волкова	0103000020E61000000100000005000000E04DB7EC10AB47404CC2853C82C34B40E04DB7EC10AB474066321CCF67C44B406F2A52616CAD474066321CCF67C44B406F2A52616CAD47404CC2853C82C34B40E04DB7EC10AB47404CC2853C82C34B40
62818	11876	47.153098999999997	47.179312000000003	55.503951000000001	55.490799000000003	Молодежная	0103000020E6100000010000000500000070067FBF989347406BF46A80D2BE4B4070067FBF98934740ACE4637781C04B40E3E313B2F3964740ACE4637781C04B40E3E313B2F39647406BF46A80D2BE4B4070067FBF989347406BF46A80D2BE4B40
62856	12514	47.276401999999997	47.295409999999997	55.637605999999998	55.623238999999998	Чкалова	0103000020E610000001000000050000004546072461A34740BE4BA94BC6CF4B404546072461A34740DFDDCA129DD14B40A774B0FECFA54740DFDDCA129DD14B40A774B0FECFA54740BE4BA94BC6CF4B404546072461A34740BE4BA94BC6CF4B40
61931	12287	47.428773999999997	47.468398999999998	55.588771000000001	55.577103000000001	Кирова	0103000020E6100000010000000500000003B00111E2B6474035B6D782DEC94B4003B00111E2B64740A7EA1ED95CCB4B40533D997FF4BB4740A7EA1ED95CCB4B40533D997FF4BB474035B6D782DEC94B4003B00111E2B6474035B6D782DEC94B40
61930	11294	47.423465	47.447217000000002	55.530949	55.514605000000003	Спортивная	0103000020E610000001000000050000001500E31934B64740D6AD9E93DEC14B401500E31934B64740056C0723F6C34B408D9B1A683EB94740056C0723F6C34B408D9B1A683EB94740D6AD9E93DEC14B401500E31934B64740D6AD9E93DEC14B40
62033	13788	47.641199	47.672460000000001	55.462961999999997	55.444628999999999	Шакуловская	0103000020E610000001000000050000002C9D0FCF12D2474035ED629AE9B84B402C9D0FCF12D2474037A5BC5642BB4B4020EF552B13D6474037A5BC5642BB4B4020EF552B13D6474035ED629AE9B84B402C9D0FCF12D2474035ED629AE9B84B40
62806	12549	47.262881999999998	47.280318999999999	55.611902000000001	55.601137000000001	Шелепи	0103000020E61000000100000005000000815A0C1EA6A1474031B5A50EF2CC4B40815A0C1EA6A14740B22D03CE52CE4B4045B9347EE1A34740B22D03CE52CE4B4045B9347EE1A3474031B5A50EF2CC4B40815A0C1EA6A1474031B5A50EF2CC4B40
62154	13593	47.571587999999998	47.576645999999997	55.543357999999998	55.539951000000002	Полевая	0103000020E610000001000000050000009D64ABCB29C94740A438471D1DC54B409D64ABCB29C947408E0244C18CC54B4042AF3F89CFC947408E0244C18CC54B4042AF3F89CFC94740A438471D1DC54B409D64ABCB29C94740A438471D1DC54B40
62859	12884	47.353316	47.370787999999997	55.688339999999997	55.678631000000003	Ленина	0103000020E61000000100000005000000A7936C7539AD4740A1866F61DDD64B40A7936C7539AD4740AA436E861BD84B40E7DF2EFB75AF4740AA436E861BD84B40E7DF2EFB75AF4740A1866F61DDD64B40A7936C7539AD4740A1866F61DDD64B40
79405	61570	47.046343	47.067059	55.286476	55.269948999999997	Школьная	0103000020E6100000010000000500000003B34291EE854740404B57B08DA24B4003B34291EE854740618BDD3EABA44B4084F3A96395884740618BDD3EABA44B4084F3A96395884740404B57B08DA24B4003B34291EE854740404B57B08DA24B40
62946	58049	47.242356000000001	47.274974	55.305123000000002	55.285507000000003	Школьная	0103000020E61000000100000005000000A4FE7A85059F4740B9E34D7E8BA44B40A4FE7A85059F4740F3203D450EA74B400AA0185932A34740F3203D450EA74B400AA0185932A34740B9E34D7E8BA44B40A4FE7A85059F4740B9E34D7E8BA44B40
79400	58049	47.242356000000001	47.274974	55.305123000000002	55.285507000000003	Центральная	0103000020E61000000100000005000000A4FE7A85059F4740B9E34D7E8BA44B40A4FE7A85059F4740F3203D450EA74B400AA0185932A34740F3203D450EA74B400AA0185932A34740B9E34D7E8BA44B40A4FE7A85059F4740B9E34D7E8BA44B40
79404	61569	46.703600000000002	47.404394000000003	55.430998000000002	55.083091000000003	Лесная	0103000020E6100000010000000500000099BB96900F5A4740C5CBD3B9A28A4B4099BB96900F5A47401A5245F12AB74B406D59BE2EC3B347401A5245F12AB74B406D59BE2EC3B34740C5CBD3B9A28A4B4099BB96900F5A4740C5CBD3B9A28A4B40
79451	61590	46.703600000000002	47.404394000000003	55.430998000000002	55.083091000000003	Школьная	0103000020E6100000010000000500000099BB96900F5A4740C5CBD3B9A28A4B4099BB96900F5A47401A5245F12AB74B406D59BE2EC3B347401A5245F12AB74B406D59BE2EC3B34740C5CBD3B9A28A4B4099BB96900F5A4740C5CBD3B9A28A4B40
61832	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Центральная	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
62610	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Солнечная	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
61833	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Свердлова	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
62744	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Октябрьская	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
61567	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Мира	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
61929	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Маресьева	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
61615	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Кооперативная	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
61857	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Комсомольская	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
61874	32799	47.015701999999997	47.059648000000003	55.318131999999999	55.280245999999998	Евсевьева	0103000020E61000000100000005000000AB3DEC8502824740DB6AD619DFA34B40AB3DEC8502824740D1E7A38CB8A84B40CBA2B08BA2874740D1E7A38CB8A84B40CBA2B08BA2874740DB6AD619DFA34B40AB3DEC8502824740DB6AD619DFA34B40
62991	58051	46.788662000000002	46.80847	55.330675999999997	55.314787000000003	Кирова	0103000020E610000001000000050000008ACC5CE0F26447405D1ABFF04AA84B408ACC5CE0F26447403AC9569753AA4B4008E6E8F17B6747403AC9569753AA4B4008E6E8F17B6747405D1ABFF04AA84B408ACC5CE0F26447405D1ABFF04AA84B40
79403	32854	47.016483000000001	47.046073999999997	55.394846999999999	55.371991000000001	Советская	0103000020E6100000010000000500000051F86C1D1C82474003B4AD669DAF4B4051F86C1D1C8247403CF6B3588AB24B401399B9C0E58547403CF6B3588AB24B401399B9C0E585474003B4AD669DAF4B4051F86C1D1C82474003B4AD669DAF4B40
62002	32854	47.016483000000001	47.046073999999997	55.394846999999999	55.371991000000001	Мирный	0103000020E6100000010000000500000051F86C1D1C82474003B4AD669DAF4B4051F86C1D1C8247403CF6B3588AB24B401399B9C0E58547403CF6B3588AB24B401399B9C0E585474003B4AD669DAF4B4051F86C1D1C82474003B4AD669DAF4B40
63338	58101	47.115198999999997	47.145463999999997	55.322927	55.314546	Молодежная	0103000020E6100000010000000500000015C440D7BE8E4740378B170B43A84B4015C440D7BE8E474069FF03AC55A94B40675F79909E92474069FF03AC55A94B40675F79909E924740378B170B43A84B4015C440D7BE8E4740378B170B43A84B40
62724	58023	47.332501999999998	47.360332	55.351430999999998	55.331290000000003	Центральная	0103000020E6100000010000000500000063EDEF6C8FAA4740F5BEF1B567AA4B4063EDEF6C8FAA474079E6E5B0FBAC4B40E4D9E55B1FAE474079E6E5B0FBAC4B40E4D9E55B1FAE4740F5BEF1B567AA4B4063EDEF6C8FAA4740F5BEF1B567AA4B40
62073	9189	47.171900999999998	47.193479000000004	55.638855999999997	55.627529000000003	Центральная	0103000020E6100000010000000500000029931ADA009647405325CADE52D04B4029931ADA009647403B6D8D08C6D14B403DBB7CEBC39847403B6D8D08C6D14B403DBB7CEBC39847405325CADE52D04B4029931ADA009647405325CADE52D04B40
61928	32768	47.096308000000001	47.130830000000003	55.544559999999997	55.533776000000003	Советская	0103000020E61000000100000005000000ED2B0FD2538C4740E2B19FC552C44B40ED2B0FD2538C4740D95A5F24B4C54B40F8AA9509BF904740D95A5F24B4C54B40F8AA9509BF904740E2B19FC552C44B40ED2B0FD2538C4740E2B19FC552C44B40
62031	52070	46.788338000000003	46.808028999999998	55.625211	55.608694	Центральная	0103000020E61000000100000005000000D7187442E8644740BEA25BAFE9CD4B40D7187442E8644740BB0CFFE906D04B401B9C887E6D674740BB0CFFE906D04B401B9C887E6D674740BEA25BAFE9CD4B40D7187442E8644740BEA25BAFE9CD4B40
62913	51990	46.738050999999999	46.757122000000003	55.648311	55.636285000000001	Заречная	0103000020E61000000100000005000000DAE38574785E4740BAF770C971D14B40DAE38574785E47408B51D7DAFBD24B40838AAA5FE96047408B51D7DAFBD24B40838AAA5FE9604740BAF770C971D14B40DAE38574785E4740BAF770C971D14B40
62843	52102	46.734456999999999	46.760491000000002	55.582039000000002	55.567652000000002	Клубная	0103000020E61000000100000005000000BDA8DDAF025E474027C11BD2A8C84B40BDA8DDAF025E47408FFF024180CA4B4080F3E2C4576147408FFF024180CA4B4080F3E2C45761474027C11BD2A8C84B40BDA8DDAF025E474027C11BD2A8C84B40
62699	58020	47.022250999999997	47.038780000000003	55.586475999999998	55.57949	Новая	0103000020E61000000100000005000000D2A6EA1ED9824740F52D73BA2CCA4B40D2A6EA1ED9824740C7F143A511CB4B4094DE37BEF6844740C7F143A511CB4B4094DE37BEF6844740F52D73BA2CCA4B40D2A6EA1ED9824740F52D73BA2CCA4B40
62052	57920	46.765880000000003	46.790880999999999	55.583668000000003	55.568145000000001	Парковая	0103000020E610000001000000050000008B54185B086247406631B1F9B8C84B408B54185B0862474062DC0DA2B5CA4B408E03AF963B65474062DC0DA2B5CA4B408E03AF963B6547406631B1F9B8C84B408B54185B086247406631B1F9B8C84B40
62720	8127	46.817677000000003	46.839739999999999	55.483443999999999	55.468871999999998	Гагарина	0103000020E6100000010000000500000080D8D2A3A96847404B0169FF03BC4B4080D8D2A3A968474045B9347EE1BD4B404F92AE997C6B474045B9347EE1BD4B404F92AE997C6B47404B0169FF03BC4B4080D8D2A3A96847404B0169FF03BC4B40
62145	57924	47.077883	47.095894999999999	55.548603999999997	55.537989000000003	Молодежная	0103000020E610000001000000050000000AF5F411F8894740CB4DD4D2DCC44B400AF5F411F8894740363AE7A738C64B40CA6C9049468C4740363AE7A738C64B40CA6C9049468C4740CB4DD4D2DCC44B400AF5F411F8894740CB4DD4D2DCC44B40
62105	52062	47.045796000000003	47.067202000000002	55.418109000000001	55.407131	Парковая	0103000020E61000000100000005000000D124B1A4DC85474009185DDE1CB44B40D124B1A4DC854740E694809884B54B40E71C3C139A884740E694809884B54B40E71C3C139A88474009185DDE1CB44B40D124B1A4DC85474009185DDE1CB44B40
62049	52100	47.116833999999997	47.150664999999996	55.520054000000002	55.508524000000001	Советская	0103000020E61000000100000005000000CA87A06AF48E4740959D7E5017C14B40CA87A06AF48E4740B613252191C24B406FD39FFD48934740B613252191C24B406FD39FFD48934740959D7E5017C14B40CA87A06AF48E4740959D7E5017C14B40
62918	58037	47.125340999999999	47.147880000000001	55.585199000000003	55.574263000000002	Школьная	0103000020E6100000010000000500000089EC832C0B904740C426327381C94B4089EC832C0B904740725303CDE7CA4B40C2DD59BBED924740725303CDE7CA4B40C2DD59BBED924740C426327381C94B4089EC832C0B904740C426327381C94B40
62711	52088	47.160438999999997	47.172772000000002	55.566608000000002	55.557988999999999	А.Иванова	0103000020E610000001000000050000006000E143899447408D43FD2E6CC74B406000E1438994474074D3669C86C84B400FD594641D96474074D3669C86C84B400FD594641D9647408D43FD2E6CC74B406000E143899447408D43FD2E6CC74B40
62141	52089	46.999226999999998	47.011614999999999	55.631635000000003	55.619436999999998	Шоссейная	0103000020E61000000100000005000000DD239BABE67F474057772CB649CF4B40DD239BABE67F474026016A6AD9D04B404F92AE997C81474026016A6AD9D04B404F92AE997C81474057772CB649CF4B40DD239BABE67F474057772CB649CF4B40
62050	52082	47.085923000000001	47.105865999999999	55.470362000000002	55.466346000000001	Цивильная	0103000020E61000000100000005000000B37C5D86FF8A47406A4FC939B1BB4B40B37C5D86FF8A4740FDA36FD234BC4B4011E15F048D8D4740FDA36FD234BC4B4011E15F048D8D47406A4FC939B1BB4B40B37C5D86FF8A47406A4FC939B1BB4B40
62841	52090	46.995615999999998	47.009287999999998	55.664700000000003	55.649931000000002	Школьная	0103000020E61000000100000005000000EAAF5758707F47400BD462F030D34B40EAAF5758707F47405BD3BCE314D54B40641F6459308147405BD3BCE314D54B40641F6459308147400BD462F030D34B40EAAF5758707F47400BD462F030D34B40
62836	52007	46.952531999999998	46.969923999999999	55.527219000000002	55.509619999999998	Новая	0103000020E610000001000000050000005D328E91EC7947409AB1683A3BC14B405D328E91EC794740386A85E97BC34B4081CD3978267C4740386A85E97BC34B4081CD3978267C47409AB1683A3BC14B405D328E91EC7947409AB1683A3BC14B40
62045	52034	47.047995999999998	47.065109	55.677467999999998	55.662019000000001	Советская	0103000020E610000001000000050000005E2BA1BB24864740522AE109BDD44B405E2BA1BB24864740130B7C45B7D64B406FD6E07D55884740130B7C45B7D64B406FD6E07D55884740522AE109BDD44B405E2BA1BB24864740522AE109BDD44B40
62046	52050	46.879257000000003	46.907949000000002	55.543413999999999	55.525236999999997	Центральная	0103000020E61000000100000005000000B9E34D7E8B70474017D34CF73AC34B40B9E34D7E8B704740221807978EC54B40CCB73EAC37744740221807978EC54B40CCB73EAC3774474017D34CF73AC34B40B9E34D7E8B70474017D34CF73AC34B40
62708	52075	46.867730999999999	46.881681999999998	55.658759000000003	55.645811999999999	Новая	0103000020E61000000100000005000000D95C35CF116F4740A3AEB5F7A9D24B40D95C35CF116F47400C79043752D44B4066BCADF4DA7047400C79043752D44B4066BCADF4DA704740A3AEB5F7A9D24B40D95C35CF116F4740A3AEB5F7A9D24B40
62842	33103	47.063411000000002	47.092571	55.509211999999998	55.493246999999997	Первомайская	0103000020E61000000100000005000000749A05DA1D884740D0ECBAB722BF4B40749A05DA1D884740895DDBDB2DC14B406DC7D45DD98B4740895DDBDB2DC14B406DC7D45DD98B4740D0ECBAB722BF4B40749A05DA1D884740D0ECBAB722BF4B40
62703	52033	47.071362000000001	47.087513000000001	55.658312000000002	55.646822999999998	Зеленая	0103000020E61000000100000005000000AD16D863228947407AA69718CBD24B40AD16D863228947403D484F9143D44B40C87C40A0338B47403D484F9143D44B40C87C40A0338B47407AA69718CBD24B40AD16D863228947407AA69718CBD24B40
61986	33119	46.974218	46.995148	55.521593000000003	55.506678000000001	40 лет Победы	0103000020E610000001000000050000005796E82CB37C474025CD1FD3DAC04B405796E82CB37C47404969368FC3C24B4004577902617F47404969368FC3C24B4004577902617F474025CD1FD3DAC04B405796E82CB37C474025CD1FD3DAC04B40
62710	52109	47.162514000000002	47.176437999999997	55.545777999999999	55.538961999999998	Дружбы	0103000020E6100000010000000500000032923D42CD944740B4E4F1B4FCC44B4032923D42CD9447402A70B20DDCC54B40C5E23785959647402A70B20DDCC54B40C5E2378595964740B4E4F1B4FCC44B4032923D42CD944740B4E4F1B4FCC44B40
62837	52080	47.036802999999999	47.057913999999997	55.457239999999999	55.444476000000002	Административная	0103000020E6100000010000000500000085B2F0F5B5844740AFEDED96E4B84B4085B2F0F5B584474026361FD786BA4B4082FDD7B96987474026361FD786BA4B4082FDD7B969874740AFEDED96E4B84B4085B2F0F5B5844740AFEDED96E4B84B40
62048	52083	47.088994999999997	47.110222999999998	55.610442999999997	55.594977	Центральная	0103000020E61000000100000005000000F6402B30648B4740A46FD23428CC4B40F6402B30648B47403B8908FF22CE4B402D228AC91B8E47403B8908FF22CE4B402D228AC91B8E4740A46FD23428CC4B40F6402B30648B4740A46FD23428CC4B40
62041	51986	46.781826000000002	46.807949000000001	55.646025000000002	55.631148000000003	Восточная	0103000020E61000000100000005000000CD94D6DF12644740C9772975C9D04B40CD94D6DF12644740FFB27BF2B0D24B40FFEA71DF6A674740FFB27BF2B0D24B40FFEA71DF6A674740C9772975C9D04B40CD94D6DF12644740C9772975C9D04B40
61829	32574	46.976849999999999	47.001094999999999	55.438231000000002	55.418246000000003	Школьная	0103000020E610000001000000050000007E8CB96B097D474067D7BD1589B54B407E8CB96B097D4740F48B12F417B84B40359886E123804740F48B12F417B84B40359886E12380474067D7BD1589B54B407E8CB96B097D474067D7BD1589B54B40
62709	52085	47.054122999999997	47.088636000000001	55.577815999999999	55.567036000000002	Кооперативная	0103000020E610000001000000050000000F7BA180ED864740CCD3B9A294C84B400F7BA180ED864740828DEBDFF5C94B40C79FA86C588B4740828DEBDFF5C94B40C79FA86C588B4740CCD3B9A294C84B400F7BA180ED864740CCD3B9A294C84B40
62047	52069	46.865701000000001	46.894554999999997	55.589965999999997	55.574354999999997	Победы	0103000020E61000000100000005000000A88E554ACF6E4740A4A5F27684C94B40A88E554ACF6E47403FE0810184CB4B4094BC3AC7807247403FE0810184CB4B4094BC3AC780724740A4A5F27684C94B40A88E554ACF6E4740A4A5F27684C94B40
62840	52078	47.085051999999997	47.113563999999997	55.432943999999999	55.419519000000001	Центральная	0103000020E61000000100000005000000CD3AE3FBE28A47407B8670CCB2B54B40CD3AE3FBE28A4740ED7F80B56AB74B406000E143898E4740ED7F80B56AB74B406000E143898E47407B8670CCB2B54B40CD3AE3FBE28A47407B8670CCB2B54B40
62853	52094	47.018360999999999	47.037467999999997	55.698872999999999	55.688308999999997	Новая	0103000020E61000000100000005000000CC423BA7598247406F4562821AD84B40CC423BA7598247405987A3AB74D94B40C1525DC0CB8447405987A3AB74D94B40C1525DC0CB8447406F4562821AD84B40CC423BA7598247406F4562821AD84B40
62717	52041	46.748282000000003	46.757472	55.510368999999997	55.504261999999997	Лесная	0103000020E61000000100000005000000BE175FB4C75F4740CA4E3FA88BC04B40BE175FB4C75F474034F279C553C14B405FD1ADD7F460474034F279C553C14B405FD1ADD7F4604740CA4E3FA88BC04B40BE175FB4C75F4740CA4E3FA88BC04B40
61830	8614	46.836191999999997	46.866815000000003	55.622033999999999	55.595384000000003	Гагарина	0103000020E61000000100000005000000A296E656086B4740E547FC8A35CC4B40A296E656086B4740028063CF9ECF4B4054573ECBF36E4740028063CF9ECF4B4054573ECBF36E4740E547FC8A35CC4B40A296E656086B4740E547FC8A35CC4B40
62839	8457	46.988303000000002	47.017687000000002	55.412568999999998	55.398328999999997	переулок Юбилейный	0103000020E61000000100000005000000F4C473B6807E47403106D671FCB24B40F4C473B6807E4740F52B9D0FCFB44B403D484F9143824740F52B9D0FCFB44B403D484F91438247403106D671FCB24B40F4C473B6807E47403106D671FCB24B40
61864	32697	46.914155999999998	46.926561999999997	55.667786999999997	55.658459000000001	Школьная	0103000020E6100000010000000500000099B8551003754740E1606F6248D44B4099B8551003754740D3D85E0B7AD54B40B1DB679599764740D3D85E0B7AD54B40B1DB679599764740E1606F6248D44B4099B8551003754740E1606F6248D44B40
61646	7034	46.925538000000003	47.006512000000001	55.504781999999999	55.467993999999997	Пионерская	0103000020E61000000100000005000000469A780778764740B35C363AE7BB4B40469A78077876474003CE52B29CC04B400A849D62D580474003CE52B29CC04B400A849D62D5804740B35C363AE7BB4B40469A780778764740B35C363AE7BB4B40
61661	7034	46.925538000000003	47.006512000000001	55.504781999999999	55.467993999999997	Ленина	0103000020E61000000100000005000000469A780778764740B35C363AE7BB4B40469A78077876474003CE52B29CC04B400A849D62D580474003CE52B29CC04B400A849D62D5804740B35C363AE7BB4B40469A780778764740B35C363AE7BB4B40
61341	7034	46.925538000000003	47.006512000000001	55.504781999999999	55.467993999999997	Карла Маркса	0103000020E61000000100000005000000469A780778764740B35C363AE7BB4B40469A78077876474003CE52B29CC04B400A849D62D580474003CE52B29CC04B400A849D62D5804740B35C363AE7BB4B40469A780778764740B35C363AE7BB4B40
61662	7034	46.925538000000003	47.006512000000001	55.504781999999999	55.467993999999997	К.Маркса	0103000020E61000000100000005000000469A780778764740B35C363AE7BB4B40469A78077876474003CE52B29CC04B400A849D62D580474003CE52B29CC04B400A849D62D5804740B35C363AE7BB4B40469A780778764740B35C363AE7BB4B40
61660	7034	46.925538000000003	47.006512000000001	55.504781999999999	55.467993999999997	Заводская	0103000020E61000000100000005000000469A780778764740B35C363AE7BB4B40469A78077876474003CE52B29CC04B400A849D62D580474003CE52B29CC04B400A849D62D5804740B35C363AE7BB4B40469A780778764740B35C363AE7BB4B40
62044	52047	46.831493000000002	46.862637999999997	55.558585000000001	55.536175999999998	Советская	0103000020E610000001000000050000002DEDD45C6E6A47403673486AA1C44B402DEDD45C6E6A4740A18499B67FC74B40B72407EC6A6E4740A18499B67FC74B40B72407EC6A6E47403673486AA1C44B402DEDD45C6E6A47403673486AA1C44B40
62604	58008	47.152569	47.168416000000001	55.632510000000003	55.619034999999997	Молодежная	0103000020E6100000010000000500000014B1886187934740280AF4893CCF4B4014B18861879347404D327216F6D04B40C30FCEA78E9547404D327216F6D04B40C30FCEA78E954740280AF4893CCF4B4014B1886187934740280AF4893CCF4B40
62153	57926	46.779139999999998	46.794015999999999	55.490009000000001	55.481560999999999	Коммунаров	0103000020E61000000100000005000000B28009DCBA634740B80375CAA3BD4B40B28009DCBA63474072DF6A9DB8BE4B401840F850A265474072DF6A9DB8BE4B401840F850A2654740B80375CAA3BD4B40B28009DCBA634740B80375CAA3BD4B40
61828	8234	46.841419999999999	46.877146000000003	55.508803999999998	55.483383000000003	пер.Школьный	0103000020E61000000100000005000000A4198BA6B36B4740A038807EDFBD4B40A4198BA6B36B474078094E7D20C14B409BE8F3514670474078094E7D20C14B409BE8F35146704740A038807EDFBD4B40A4198BA6B36B4740A038807EDFBD4B40
62043	52028	47.050179	47.077255000000001	55.646213000000003	55.629719000000001	Коммунальная	0103000020E6100000010000000500000016F9F5436C864740BD55D7A19AD04B4016F9F5436C86474002A08A1BB7D24B40EB39E97DE389474002A08A1BB7D24B40EB39E97DE3894740BD55D7A19AD04B4016F9F5436C864740BD55D7A19AD04B40
62807	58029	46.81147	46.827640000000002	55.655706000000002	55.648499000000001	Шоссейная	0103000020E61000000100000005000000B2D7BB3FDE6747408E3EE60302D34B40B2D7BB3FDE6747403FE5982CEED34B40446E861BF06947403FE5982CEED34B40446E861BF06947408E3EE60302D34B40B2D7BB3FDE6747408E3EE60302D34B40
62704	52012	46.981054	47.001589000000003	55.563386000000001	55.554450000000003	Здоровья	0103000020E6100000010000000500000014CE6E2D937D474034A2B437F8C64B4014CE6E2D937D47401B834E081DC84B4045847F11348047401B834E081DC84B4045847F113480474034A2B437F8C64B4014CE6E2D937D474034A2B437F8C64B40
62799	52001	46.923237999999998	46.947510999999999	55.513846000000001	55.499805000000002	Кузнецкая	0103000020E610000001000000050000005436ACA92C7647404BB0389CF9BF4B405436ACA92C7647401897AAB4C5C14B40D5CC5A0A487947401897AAB4C5C14B40D5CC5A0A487947404BB0389CF9BF4B405436ACA92C7647404BB0389CF9BF4B40
62835	52020	47.015692999999999	47.031925999999999	55.550722999999998	55.540322000000003	Центральная	0103000020E6100000010000000500000058E36C3A0282474098A7734529C54B4058E36C3A02824740D7135D177EC64B4030F2B22616844740D7135D177EC64B4030F2B2261684474098A7734529C54B4058E36C3A0282474098A7734529C54B40
62706	52091	46.917723000000002	46.936542000000003	55.655371000000002	55.638333000000003	Садовая	0103000020E61000000100000005000000BDE47FF277754740927A4FE5B4D14B40BDE47FF27775474098DF6932E3D34B404CAAB69BE077474098DF6932E3D34B404CAAB69BE0774740927A4FE5B4D14B40BDE47FF277754740927A4FE5B4D14B40
62701	51997	46.931144000000003	46.955632000000001	55.605759999999997	55.588867	Центральная	0103000020E61000000100000005000000EEEE01BA2F774740C9586DFE5FCB4B40EEEE01BA2F774740CB9C2E8B89CD4B406B813D26527A4740CB9C2E8B89CD4B406B813D26527A4740C9586DFE5FCB4B40EEEE01BA2F774740C9586DFE5FCB4B40
62140	51973	46.735022999999998	46.756304	55.621211000000002	55.608989000000001	Советская	0103000020E610000001000000050000006667D13B155E4740D74FFF59F3CD4B406667D13B155E47402E7590D783CF4B40C0EAC891CE6047402E7590D783CF4B40C0EAC891CE604740D74FFF59F3CD4B406667D13B155E4740D74FFF59F3CD4B40
61820	33102	46.909198000000004	46.935177000000003	55.541158000000003	55.529252	Солнечная	0103000020E6100000010000000500000058CB9D9960744740DAAB8F87BEC34B4058CB9D996074474001FC53AA44C54B40577C43E1B377474001FC53AA44C54B40577C43E1B3774740DAAB8F87BEC34B4058CB9D9960744740DAAB8F87BEC34B40
62138	51938	47.490155999999999	47.516764000000002	55.080246000000002	55.068210999999998	Центральная	0103000020E6100000010000000500000016F88A6EBDBE47401D1D5723BB884B4016F88A6EBDBE474042D13C80458A4B4005E09F5225C2474042D13C80458A4B4005E09F5225C247401D1D5723BB884B4016F88A6EBDBE47401D1D5723BB884B40
61328	4208	47.526116000000002	47.575127999999999	55.065503999999997	55.038026000000002	Ленина	0103000020E6100000010000000500000080F3E2C457C34740E8323509DE844B4080F3E2C457C34740EBE0606F62884B40C78157CB9DC94740EBE0606F62884B40C78157CB9DC94740E8323509DE844B4080F3E2C457C34740E8323509DE844B40
61659	4208	47.526116000000002	47.575127999999999	55.065503999999997	55.038026000000002	Вахитова	0103000020E6100000010000000500000080F3E2C457C34740E8323509DE844B4080F3E2C457C34740EBE0606F62884B40C78157CB9DC94740EBE0606F62884B40C78157CB9DC94740E8323509DE844B4080F3E2C457C34740E8323509DE844B40
61926	32855	47.363259999999997	47.388601999999999	55.034399000000001	55.016444999999997	Николаева	0103000020E61000000100000005000000F4F8BD4D7FAE47406397A8DE1A824B40F4F8BD4D7FAE4740EF01BA2F67844B408194D8B5BDB14740EF01BA2F67844B408194D8B5BDB147406397A8DE1A824B40F4F8BD4D7FAE47406397A8DE1A824B40
62035	52912	47.483904000000003	47.506461000000002	55.133946000000002	55.120474999999999	Куракова	0103000020E61000000100000005000000A933F790F0BD4740287E8CB96B8F4B40A933F790F0BD47400BB77C2425914B4088D9CBB6D3C047400BB77C2425914B4088D9CBB6D3C04740287E8CB96B8F4B40A933F790F0BD4740287E8CB96B8F4B40
62929	58044	47.333866999999998	47.354483999999999	54.957821000000003	54.937241	Николаева	0103000020E61000000100000005000000581B6327BCAA474034BC5983F7774B40581B6327BCAA47400536E7E0997A4B40467A51BB5FAD47400536E7E0997A4B40467A51BB5FAD474034BC5983F7774B40581B6327BCAA474034BC5983F7774B40
62779	6017	47.092813	47.118333999999997	55.080112	55.073247000000002	Советская	0103000020E6100000010000000500000063D2DF4BE18B4740DBC35E2860894B4063D2DF4BE18B474032022A1C418A4B409F008A91258F474032022A1C418A4B409F008A91258F4740DBC35E2860894B4063D2DF4BE18B4740DBC35E2860894B40
61971	4441	47.553074000000002	47.58032	55.076999000000001	55.068381000000002	Магистральная	0103000020E610000001000000050000004B22FB20CBC647407A5567B5C0884B404B22FB20CBC6474090696D1ADB894B407C9BFEEC47CA474090696D1ADB894B407C9BFEEC47CA47407A5567B5C0884B404B22FB20CBC647407A5567B5C0884B40
61981	4871	47.752788000000002	47.782854	55.081271999999998	55.069612999999997	Учительская	0103000020E610000001000000050000001F69705B5BE047402F302B14E9884B401F69705B5BE047404E0AF31E678A4B407AC5538F34E447404E0AF31E678A4B407AC5538F34E447402F302B14E9884B401F69705B5BE047402F302B14E9884B40
62833	51944	47.487335000000002	47.515811999999997	55.065519000000002	55.058332	Депутатская	0103000020E610000001000000050000001C9947FE60BE4740B727486C77874B401C9947FE60BE4740212235ED62884B403271AB2006C24740212235ED62884B403271AB2006C24740B727486C77874B401C9947FE60BE4740B727486C77874B40
62697	52915	47.626483999999998	47.661222000000002	55.126528999999998	55.118234999999999	Школьная	0103000020E61000000100000005000000CFBBB1A030D047400C1F1153228F4B40CFBBB1A030D047406F7F2E1A32904B40A7B228ECA2D447406F7F2E1A32904B40A7B228ECA2D447400C1F1153228F4B40CFBBB1A030D047400C1F1153228F4B40
62136	52931	47.816909000000003	47.827661999999997	55.090494999999997	55.079700000000003	Овражная	0103000020E610000001000000050000006F675F7990E84740E0BE0E9C338A4B406F675F7990E84740CBB91457958B4B402B1213D4F0E94740CBB91457958B4B402B1213D4F0E94740E0BE0E9C338A4B406F675F7990E84740E0BE0E9C338A4B40
61984	33035	47.684165	47.725084000000003	54.998519000000002	54.983204999999998	Школьная	0103000020E61000000100000005000000AF08FEB792D74740C02154A9D97D4B40AF08FEB792D74740A2B77878CF7F4B402B6D718DCFDC4740A2B77878CF7F4B402B6D718DCFDC4740C02154A9D97D4B40AF08FEB792D74740C02154A9D97D4B40
61862	5446	47.319960999999999	47.346156000000001	55.016919999999999	55.000038000000004	Кокеля	0103000020E610000001000000050000006B7F677BF4A84740EE60C43E01804B406B7F677BF4A84740FC523F6F2A824B4037A8FDD64EAC4740FC523F6F2A824B4037A8FDD64EAC4740EE60C43E01804B406B7F677BF4A84740EE60C43E01804B40
61330	6762	47.615102999999998	47.662317999999999	55.006749999999997	54.99024	Советская	0103000020E61000000100000005000000F355F2B1BBCE474074982F2FC07E4B40F355F2B1BBCE4740BE9F1A2FDD804B40ACC612D6C6D44740BE9F1A2FDD804B40ACC612D6C6D4474074982F2FC07E4B40F355F2B1BBCE474074982F2FC07E4B40
61982	32822	47.807862999999998	47.838540999999999	55.079529999999998	55.069077	Кооперативная	0103000020E610000001000000050000000053060E68E74740F1F3DF83D7884B400053060E68E747408386FE092E8A4B4075ADBD4F55EB47408386FE092E8A4B4075ADBD4F55EB4740F1F3DF83D7884B400053060E68E74740F1F3DF83D7884B40
62834	52923	47.709569999999999	47.741810000000001	55.078302999999998	55.068674999999999	Кооперативная	0103000020E61000000100000005000000821C9430D3DA4740C286A757CA884B40821C9430D3DA4740DF162CD5058A4B4042EC4CA1F3DE4740DF162CD5058A4B4042EC4CA1F3DE4740C286A757CA884B40821C9430D3DA4740C286A757CA884B40
62696	51922	47.281126999999998	47.305228999999997	55.089063000000003	55.077396	Пионерская	0103000020E61000000100000005000000E48233F8FBA34740AD6BB41CE8894B40E48233F8FBA347404F24986A668B4B4038656EBE11A747404F24986A668B4B4038656EBE11A74740AD6BB41CE8894B40E48233F8FBA34740AD6BB41CE8894B40
62037	52958	47.264561999999998	47.291431000000003	55.022376000000001	55.003878999999998	Победы	0103000020E61000000100000005000000D6E1E82ADDA147401212691B7F804B40D6E1E82ADDA147408F1B7E37DD824B4032056B9C4DA547408F1B7E37DD824B4032056B9C4DA547401212691B7F804B40D6E1E82ADDA147401212691B7F804B40
61814	32995	47.456747999999997	47.490155999999999	55.105207	55.083657000000002	Камалетдинова	0103000020E61000000100000005000000B741EDB776BA47406E8AC745B58A4B40B741EDB776BA4740B727486C778D4B4016F88A6EBDBE4740B727486C778D4B4016F88A6EBDBE47406E8AC745B58A4B40B741EDB776BA47406E8AC745B58A4B40
62698	51924	47.331235	47.355310000000003	55.074432000000002	55.067039999999999	Нижняя	0103000020E61000000100000005000000312592E865AA47400DC347C494884B40312592E865AA474050E3DEFC86894B408CF84ECC7AAD474050E3DEFC86894B408CF84ECC7AAD47400DC347C494884B40312592E865AA47400DC347C494884B40
61924	32852	47.423250000000003	47.449210999999998	55.024559000000004	55.007488000000002	Центральная	0103000020E610000001000000050000001904560E2DB64740658EE55DF5804B401904560E2DB6474047E9D2BF24834B407100FDBE7FB9474047E9D2BF24834B407100FDBE7FB94740658EE55DF5804B401904560E2DB64740658EE55DF5804B40
61813	6440	47.330274000000003	47.394089999999998	55.083596	55.071046000000003	Кирова	0103000020E610000001000000050000000C5C1E6B46AA47407D410B0918894B400C5C1E6B46AA4740C8091346B38A4B401FD7868A71B24740C8091346B38A4B401FD7868A71B247407D410B0918894B400C5C1E6B46AA47407D410B0918894B40
61987	57917	47.444826999999997	47.471705	55.041266	55.023124000000003	Главной дороги	0103000020E610000001000000050000005BB05417F0B8474059E02BBAF5824B405BB05417F0B84740E7374C3448854B400A2E56D460BC4740E7374C3448854B400A2E56D460BC474059E02BBAF5824B405BB05417F0B8474059E02BBAF5824B40
62036	52908	47.563468	47.593542999999997	55.104830999999997	55.096209000000002	Напольная	0103000020E61000000100000005000000D82B2CB81FC847405A4A9693508C4B40D82B2CB81FC84740B14D2A1A6B8D4B4086E28E37F9CB4740B14D2A1A6B8D4B4086E28E37F9CB47405A4A9693508C4B40D82B2CB81FC847405A4A9693508C4B40
62830	52934	47.735019000000001	47.760359999999999	55.090155000000003	55.080091000000003	Кирова	0103000020E610000001000000050000002578431A15DE47401BDA006C408A4B402578431A15DE47401349F4328A8B4B40E197FA7953E147401349F4328A8B4B40E197FA7953E147401BDA006C408A4B402578431A15DE47401BDA006C408A4B40
61812	4765	47.668903	47.711196000000001	55.094019000000003	55.080075999999998	Ленина	0103000020E6100000010000000500000020990E9D9ED54740E5982CEE3F8A4B4020990E9D9ED54740F01989D0088C4B40E485747808DB4740F01989D0088C4B40E485747808DB4740E5982CEE3F8A4B4020990E9D9ED54740E5982CEE3F8A4B40
61859	32867	47.339193999999999	47.359496	55.039929999999998	55.027360999999999	Школьная	0103000020E61000000100000005000000ED7F80B56AAB4740CA17B49080834B40ED7F80B56AAB47408C101E6D1C854B407B8505F703AE47408C101E6D1C854B407B8505F703AE4740CA17B49080834B40ED7F80B56AAB4740CA17B49080834B40
62831	51936	47.439779000000001	47.457610000000003	55.082214999999998	55.073773000000003	Садовая	0103000020E61000000100000005000000DA3BA3AD4AB84740F629C76471894B40DA3BA3AD4AB84740CD1E6805868A4B404A29E8F692BA4740CD1E6805868A4B404A29E8F692BA4740F629C76471894B40DA3BA3AD4AB84740F629C76471894B40
62034	52903	47.579115999999999	47.610988999999996	55.079152999999998	55.071216	Крепкова	0103000020E61000000100000005000000904B1C7920CA4740D9791B9B1D894B40904B1C7920CA4740AD307DAF218A4B409D9B36E334CE4740AD307DAF218A4B409D9B36E334CE4740D9791B9B1D894B40904B1C7920CA4740D9791B9B1D894B40
62038	6028	47.030937000000002	47.046684999999997	55.046455000000002	55.038010999999997	Набережная	0103000020E61000000100000005000000419E5DBEF5834740B2F1608BDD844B40419E5DBEF58347402BDEC83CF2854B405C1B2AC6F98547402BDEC83CF2854B405C1B2AC6F9854740B2F1608BDD844B40419E5DBEF5834740B2F1608BDD844B40
62832	51954	47.831533999999998	47.843535000000003	54.996924	54.977294000000001	Центральная	0103000020E610000001000000050000008BC1C3B46FEA4740DC4944F8177D4B408BC1C3B46FEA47407B4CA4349B7F4B40040473F4F8EB47407B4CA4349B7F4B40040473F4F8EB4740DC4944F8177D4B408BC1C3B46FEA4740DC4944F8177D4B40
62828	51933	47.387855999999999	47.416637999999999	55.070154000000002	55.065854999999999	Советская	0103000020E6100000010000000500000058C7F143A5B1474098A3C7EF6D884B4058C7F143A5B1474080D767CEFA884B40AB22DC6454B5474080D767CEFA884B40AB22DC6454B5474098A3C7EF6D884B4058C7F143A5B1474098A3C7EF6D884B40
9638	40245	47.793868000000003	47.817880000000002	55.000926	54.987068999999998	Центральная	0103000020E61000000100000005000000A4AB74779DE547409DF2E846587E4B40A4AB74779DE54740A9DBD9571E804B40B806B64AB0E84740A9DBD9571E804B40B806B64AB0E847409DF2E846587E4B40A4AB74779DE547409DF2E846587E4B40
62104	52898	47.566485999999998	47.591684000000001	55.001742	54.993555999999998	Школьная	0103000020E6100000010000000500000028D2FD9C82C847404E5FCFD72C7F4B4028D2FD9C82C84740CB83F41439804B4082C8224DBCCB4740CB83F41439804B4082C8224DBCCB47404E5FCFD72C7F4B4028D2FD9C82C847404E5FCFD72C7F4B40
62700	51942	47.438225000000003	47.458247999999998	55.072690000000001	55.064611999999997	Братьев Шигабетдиновых	0103000020E6100000010000000500000012A5BDC117B84740EE76BD3445884B4012A5BDC117B84740855FEAE74D894B408CBAD6DEA7BA4740855FEAE74D894B408CBAD6DEA7BA4740EE76BD3445884B4012A5BDC117B84740EE76BD3445884B40
61843	32755	47.518058000000003	47.559434000000003	55.124412999999997	55.110584000000003	Апанаева	0103000020E6100000010000000500000031B77BB94FC24740FEBAD39D278E4B4031B77BB94FC247403F19E3C3EC8F4B409F2287889BC747403F19E3C3EC8F4B409F2287889BC74740FEBAD39D278E4B4031B77BB94FC24740FEBAD39D278E4B40
62827	51929	47.309541000000003	47.327696000000003	55.103853000000001	55.097377999999999	Колхозная	0103000020E61000000100000005000000B5E21B0A9FA74740C9ACDEE1768C4B40B5E21B0A9FA74740B64B1B0E4B8D4B40D88349F1F1A94740B64B1B0E4B8D4B40D88349F1F1A94740C9ACDEE1768C4B40B5E21B0A9FA74740C9ACDEE1768C4B40
62135	52922	47.685772999999998	47.702382999999998	55.079121999999998	55.071226000000003	Канашская	0103000020E610000001000000050000006ABDDF68C7D74740FD4FFEEE1D894B406ABDDF68C7D74740723271AB208A4B401822A7AFE7D94740723271AB208A4B401822A7AFE7D94740FD4FFEEE1D894B406ABDDF68C7D74740FD4FFEEE1D894B40
62137	5749	47.231073000000002	47.261094999999997	55.033996999999999	55.016404000000001	Ф. Туптова	0103000020E610000001000000050000008BFED0CC939D474005C3B98619824B408BFED0CC939D4740C09481035A844B4016139B8F6BA14740C09481035A844B4016139B8F6BA1474005C3B98619824B408BFED0CC939D474005C3B98619824B40
62695	52960	47.166403000000003	47.205300000000001	55.096007999999998	55.087234000000002	Школьная	0103000020E61000000100000005000000687A89B14C954740B58CD47B2A8B4B40687A89B14C954740C2137AFD498C4B4035EF3845479A4740C2137AFD498C4B4035EF3845479A4740B58CD47B2A8B4B40687A89B14C954740B58CD47B2A8B4B40
61324	3993	47.576582999999999	47.640687	55.073720999999999	55.052200999999997	проспект Ленина	0103000020E61000000100000005000000FC36C478CDC94740C4E8B985AE864B40FC36C478CDC94740A30392B06F894B4076FC170802D24740A30392B06F894B4076FC170802D24740C4E8B985AE864B40FC36C478CDC94740C4E8B985AE864B40
61658	3993	47.576582999999999	47.640687	55.073720999999999	55.052200999999997	Советская	0103000020E61000000100000005000000FC36C478CDC94740C4E8B985AE864B40FC36C478CDC94740A30392B06F894B4076FC170802D24740A30392B06F894B4076FC170802D24740C4E8B985AE864B40FC36C478CDC94740C4E8B985AE864B40
62042	51917	47.227119999999999	47.249408000000003	55.110160999999998	55.095961000000003	Советская	0103000020E610000001000000050000003E22A644129D474082583673488C4B403E22A644129D4740B72572C1198E4B402EAEF199EC9F4740B72572C1198E4B402EAEF199EC9F474082583673488C4B403E22A644129D474082583673488C4B40
61865	6170	47.241484999999997	47.281469000000001	55.076267000000001	55.061013000000003	Кузнечная	0103000020E61000000100000005000000BEBC00FBE89E4740C0D02346CF874B40BEBC00FBE89E4740CC61F71DC3894B403EEB1A2D07A44740CC61F71DC3894B403EEB1A2D07A44740C0D02346CF874B40BEBC00FBE89E4740C0D02346CF874B40
62694	52957	47.217948999999997	47.241610000000001	55.034874000000002	55.020636000000003	Новая	0103000020E610000001000000050000001399B9C0E59B4740658F5033A4824B401399B9C0E59B474088BD50C076844B407B319413ED9E474088BD50C076844B407B319413ED9E4740658F5033A4824B401399B9C0E59B4740658F5033A4824B40
61927	6887	47.754117000000001	47.784982999999997	54.991501	54.976571	Центральная	0103000020E61000000100000005000000C72DE6E786E047406B9C4D47007D4B40C72DE6E786E04740C4793881E97E4B403E75AC527AE44740C4793881E97E4B403E75AC527AE447406B9C4D47007D4B40C72DE6E786E047406B9C4D47007D4B40
62672	52951	47.232367000000004	47.254223000000003	54.970576999999999	54.958011999999997	Центральная	0103000020E61000000100000005000000B7D5AC33BE9D474078962023A07A4B40B7D5AC33BE9D4740F99FFCDD3B7C4B400D7217618AA04740F99FFCDD3B7C4B400D7217618AA0474078962023A07A4B40B7D5AC33BE9D474078962023A07A4B40
61786	57897	46.731403	46.746215999999997	55.727322999999998	55.718927000000001	Баумана	0103000020E6100000010000000500000020990E9D9E5D47400F9BC8CC05DC4B4020990E9D9E5D4740765089EB18DD4B403FE08101845F4740765089EB18DD4B403FE08101845F47400F9BC8CC05DC4B4020990E9D9E5D47400F9BC8CC05DC4B40
61810	1859	46.730728999999997	46.772699000000003	55.744784000000003	55.730933	Советская	0103000020E61000000100000005000000909E2287885D4740994869368FDD4B40909E2287885D4740C34A051555DF4B40725303CDE7624740C34A051555DF4B40725303CDE7624740994869368FDD4B40909E2287885D4740994869368FDD4B40
62017	151	46.529874999999997	46.546072000000002	54.870803000000002	54.863435000000003	Озерная	0103000020E61000000100000005000000E7FBA9F1D2434740639CBF09856E4B40E7FBA9F1D24347401D210379766F4B4073A1F2AFE54547401D210379766F4B4073A1F2AFE5454740639CBF09856E4B40E7FBA9F1D2434740639CBF09856E4B40
62774	23998	46.557910999999997	46.585427000000003	54.924832000000002	54.903987000000001	Первомайская	0103000020E61000000100000005000000118AADA0694747402C8194D8B5734B40118AADA069474740AB251DE560764B4003999D45EF4A4740AB251DE560764B4003999D45EF4A47402C8194D8B5734B40118AADA0694747402C8194D8B5734B40
61853	32935	46.457597	46.558855000000001	54.880887999999999	54.854650999999997	Ворошилова	0103000020E61000000100000005000000B5DFDA89923A4740313F3734656D4B40B5DFDA89923A47402CB81FF0C0704B40611A868F884747402CB81FF0C0704B40611A868F88474740313F3734656D4B40B5DFDA89923A4740313F3734656D4B40
62023	29765	46.514980999999999	46.556868999999999	55.034238999999999	55.014659000000002	Чебоксарская	0103000020E61000000100000005000000DB87BCE5EA414740C9CB9A58E0814B40DB87BCE5EA414740B69F8CF161844B40FF93BF7B47474740B69F8CF161844B40FF93BF7B47474740C9CB9A58E0814B40DB87BCE5EA414740C9CB9A58E0814B40
61649	32497	46.596044999999997	46.687573999999998	54.804431000000001	54.770156999999998	Ленина	0103000020E61000000100000005000000DFF8DA334B4C47408AE42B8194624B40DFF8DA334B4C4740BD715298F7664B403ACAC16C02584740BD715298F7664B403ACAC16C025847408AE42B8194624B40DFF8DA334B4C47408AE42B8194624B40
61837	32410	47.024317000000003	47.060222000000003	54.958488000000003	54.941553999999996	Школьная	0103000020E6100000010000000500000051DEC7D11C83474080B56AD784784B4051DEC7D11C834740E2CD1ABCAF7A4B40F73FC05AB5874740E2CD1ABCAF7A4B40F73FC05AB587474080B56AD784784B4051DEC7D11C83474080B56AD784784B40
62691	47246	46.807329000000003	46.832185000000003	54.682606999999997	54.675953999999997	Верхнее-Иветская	0103000020E61000000100000005000000630E828E56674740D9CC21A985564B40630E828E56674740A5828AAA5F574B40639CBF09856A4740A5828AAA5F574B40639CBF09856A4740D9CC21A985564B40630E828E56674740D9CC21A985564B40
61854	32404	47.058847999999998	47.091430000000003	54.794969999999999	54.778793	К.Маркса	0103000020E61000000100000005000000AEB7CD548887474047AD307DAF634B40AEB7CD54888747408BA6B393C1654B40C8EF6DFAB38B47408BA6B393C1654B40C8EF6DFAB38B474047AD307DAF634B40AEB7CD548887474047AD307DAF634B40
38894	54713	46.923544	46.982294000000003	54.916992999999998	54.903354999999998	Ленина	0103000020E61000000100000005000000613596B036764740CBD6FA22A1734B40613596B03676474099D4D00660754B404D874ECFBB7D474099D4D00660754B404D874ECFBB7D4740CBD6FA22A1734B40613596B036764740CBD6FA22A1734B40
61920	28905	47.023158000000002	47.060115000000003	54.817810999999999	54.797175000000003	Ленина	0103000020E61000000100000005000000055262D7F68247402B1895D409664B40055262D7F68247408FA7E507AE684B40E17F2BD9B18747408FA7E507AE684B40E17F2BD9B18747402B1895D409664B40055262D7F68247402B1895D409664B40
61914	31541	46.374754000000003	46.407668000000001	54.908670999999998	54.890179000000003	Советская	0103000020E61000000100000005000000C90567F0F72F4740024BAE62F1714B40C90567F0F72F47406CE9D1544F744B4018D00B772E3447406CE9D1544F744B4018D00B772E344740024BAE62F1714B40C90567F0F72F4740024BAE62F1714B40
62121	27627	46.510274000000003	46.544319999999999	54.990777999999999	54.966540999999999	50 лет ЧАССР	0103000020E61000000100000005000000E3FF8EA8504147401F9F909DB77B4B40E3FF8EA85041474053CC41D0D17E4B4084471B47AC45474053CC41D0D17E4B4084471B47AC4547401F9F909DB77B4B40E3FF8EA8504147401F9F909DB77B4B40
62131	47259	46.391525999999999	46.429335999999999	54.988959000000001	54.968674999999998	Пролетарская	0103000020E6100000010000000500000050C422861D324740F5B9DA8AFD7B4B4050C422861D324740DD0A6135967E4B406B7F677BF4364740DD0A6135967E4B406B7F677BF4364740F5B9DA8AFD7B4B4050C422861D324740F5B9DA8AFD7B4B40
61855	205	46.840288000000001	46.881880000000002	55.094662999999997	55.068247	Сидорина	0103000020E61000000100000005000000529CA38E8E6B47406A865451BC884B40529CA38E8E6B47401492CCEA1D8C4B408D7F9F71E17047401492CCEA1D8C4B408D7F9F71E17047406A865451BC884B40529CA38E8E6B47406A865451BC884B40
61925	205	46.840288000000001	46.881880000000002	55.094662999999997	55.068247	Лермонтова	0103000020E61000000100000005000000529CA38E8E6B47406A865451BC884B40529CA38E8E6B47401492CCEA1D8C4B408D7F9F71E17047401492CCEA1D8C4B408D7F9F71E17047406A865451BC884B40529CA38E8E6B47406A865451BC884B40
62784	32230	46.456833000000003	46.490591999999999	54.987554000000003	54.967981999999999	Новая линия	0103000020E61000000100000005000000E65DF580793A4740EF8E8CD5E67B4B40E65DF580793A47405A84622B687E4B40F1D6F9B7CB3E47405A84622B687E4B40F1D6F9B7CB3E4740EF8E8CD5E67B4B40E65DF580793A4740EF8E8CD5E67B4B40
61852	32073	46.642057000000001	46.704633000000001	54.752988000000002	54.701205000000002	Пушкина	0103000020E610000001000000050000007D957CEC2E5247405665DF15C1594B407D957CEC2E524740E62329E961604B405857056A315A4740E62329E961604B405857056A315A47405665DF15C1594B407D957CEC2E5247405665DF15C1594B40
35834	54269	46.572724999999998	46.595433999999997	54.806905999999998	54.798805000000002	Садовая	0103000020E61000000100000005000000014D840D4F494740CE70033E3F664B40014D840D4F4947401C7920B248674B4096766A2E374C47401C7920B248674B4096766A2E374C4740CE70033E3F664B40014D840D4F494740CE70033E3F664B40
62132	32271	46.350203	46.375624999999999	54.974730999999998	54.955416999999997	Кооперативная	0103000020E6100000010000000500000005FBAF73D32C47406E85B01A4B7A4B4005FBAF73D32C4740DDB243FCC37C4B40AE47E17A14304740DDB243FCC37C4B40AE47E17A143047406E85B01A4B7A4B4005FBAF73D32C47406E85B01A4B7A4B40
38909	32002	46.396538	46.430045	54.858207	54.848877999999999	Ленина	0103000020E6100000010000000500000085CFD6C1C13247409E25C808A86C4B4085CFD6C1C132474061191BBAD96D4B407767EDB60B37474061191BBAD96D4B407767EDB60B3747409E25C808A86C4B4085CFD6C1C13247409E25C808A86C4B40
62689	31915	46.649683000000003	46.692847	55.017105999999998	55.000883999999999	Комсомольская	0103000020E6100000010000000500000033E202D0285347407A8B87F71C804B4033E202D0285347405E48878730824B40DC10E335AF5847405E48878730824B40DC10E335AF5847407A8B87F71C804B4033E202D0285347407A8B87F71C804B40
62027	31915	46.649683000000003	46.692847	55.017105999999998	55.000883999999999	Кирова	0103000020E6100000010000000500000033E202D0285347407A8B87F71C804B4033E202D0285347405E48878730824B40DC10E335AF5847405E48878730824B40DC10E335AF5847407A8B87F71C804B4033E202D0285347407A8B87F71C804B40
62026	47119	46.701867	46.712736	54.831249999999997	54.826292000000002	Молодежная	0103000020E61000000100000005000000219221C7D65947402579AEEFC3694B40219221C7D659474066666666666A4B404757E9EE3A5B474066666666666A4B404757E9EE3A5B47402579AEEFC3694B40219221C7D65947402579AEEFC3694B40
61917	32821	46.680486999999999	46.734034999999999	54.923786	54.888013999999998	Октябрьская	0103000020E61000000100000005000000342DB1321A574740F0315871AA714B40342DB1321A5747405740A19E3E764B40478FDFDBF45D47405740A19E3E764B40478FDFDBF45D4740F0315871AA714B40342DB1321A574740F0315871AA714B40
61921	32821	46.680486999999999	46.734034999999999	54.923786	54.888013999999998	Заводская	0103000020E61000000100000005000000342DB1321A574740F0315871AA714B40342DB1321A5747405740A19E3E764B40478FDFDBF45D47405740A19E3E764B40478FDFDBF45D4740F0315871AA714B40342DB1321A574740F0315871AA714B40
52895	56388	53.062432999999999	53.080973999999998	56.787770000000002	56.778944000000003	Центральная	0103000020E610000001000000050000007898F6CDFD874A402DB5DE6FB4634C407898F6CDFD874A408D62B9A5D5644C40C4E9245B5D8A4A408D62B9A5D5644C40C4E9245B5D8A4A402DB5DE6FB4634C407898F6CDFD874A402DB5DE6FB4634C40
52481	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Электрозаводская	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52655	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Школьная	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52618	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Чистякова	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52410	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Фурманова	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52576	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Фрунзе	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52408	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Фабричная	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52476	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Труда	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52573	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Степана Разина	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52404	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Советская	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52572	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Соболева	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52475	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Пугачева	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52387	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Первомайская	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52616	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Озерная	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52778	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Молодежная	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52479	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Мельникова	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52409	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Ленина	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52480	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Крылова	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52615	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Красноармейская	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52402	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Костычева	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52619	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Комсомольская	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52477	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Калинина	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52617	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Жуковского	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52391	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Горького	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52478	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Гончарова	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52405	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Гоголя	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52407	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Гагарина	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52577	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Вокзальная	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52406	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Азина	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52777	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	Tрактовая	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52581	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	5-й Зеленый проезд	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52654	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	20 лет Победы	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
52574	11375	53.716253999999999	53.835315999999999	56.498598999999999	56.432654999999997	 Сивкова	0103000020E6100000010000000500000089D00836AEDB4A40B6B9313D61374C4089D00836AEDB4A40BE688F17D23F4C40ABE97AA2EBEA4A40BE688F17D23F4C40ABE97AA2EBEA4A40B6B9313D61374C4089D00836AEDB4A40B6B9313D61374C40
28883	52432	53.140082999999997	53.164040999999997	56.783135000000001	56.778075999999999	Центральная улица	0103000020E61000000100000005000000DFDC5F3DEE914A40B8E68EFE97634C40DFDC5F3DEE914A402EAD86C43D644C40001AA54BFF944A402EAD86C43D644C40001AA54BFF944A40B8E68EFE97634C40DFDC5F3DEE914A40B8E68EFE97634C40
52442	56360	53.353046999999997	53.362281000000003	56.858271999999999	56.853532999999999	Сабурова	0103000020E61000000100000005000000B779E3A430AD4A404487C091406D4C40B779E3A430AD4A4048895DDBDB6D4C40297B4B395FAE4A4048895DDBDB6D4C40297B4B395FAE4A404487C091406D4C40B779E3A430AD4A404487C091406D4C40
52567	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Школьный переулок	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52398	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Фалалеева	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52569	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Спортивная	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52568	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Советская	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52395	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Свердловский бульвар	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52396	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Октябрьская	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52474	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Наговицына	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52397	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Короленко	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52471	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Кирова	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52472	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Дзержинского	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52403	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Горбунова	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52494	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Гагарина	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52614	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Вокзальная	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52613	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Водокачный переулок	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52401	11277	52.169193	52.267665999999998	56.476537999999998	56.422170999999999	Вешняковский микрорайон	0103000020E6100000010000000500000027DBC01DA8154A40E92807B309364C4027DBC01DA8154A408FA67A32FF3C4C40252026E142224A408FA67A32FF3C4C40252026E142224A40E92807B309364C4027DBC01DA8154A40E92807B309364C40
52635	28834	54.174968999999997	54.238982999999998	56.286762000000003	56.251871999999999	Уральский переулок	0103000020E610000001000000050000002B685A6265164B40996379573D204C402B685A6265164B4027DE019EB4244C4065A6B4FE961E4B4027DE019EB4244C4065A6B4FE961E4B40996379573D204C402B685A6265164B40996379573D204C40
52556	28834	54.174968999999997	54.238982999999998	56.286762000000003	56.251871999999999	Советская	0103000020E610000001000000050000002B685A6265164B40996379573D204C402B685A6265164B4027DE019EB4244C4065A6B4FE961E4B4027DE019EB4244C4065A6B4FE961E4B40996379573D204C402B685A6265164B40996379573D204C40
52498	28834	54.174968999999997	54.238982999999998	56.286762000000003	56.251871999999999	Первомайская	0103000020E610000001000000050000002B685A6265164B40996379573D204C402B685A6265164B4027DE019EB4244C4065A6B4FE961E4B4027DE019EB4244C4065A6B4FE961E4B40996379573D204C402B685A6265164B40996379573D204C40
52752	28834	54.174968999999997	54.238982999999998	56.286762000000003	56.251871999999999	Маяковского	0103000020E610000001000000050000002B685A6265164B40996379573D204C402B685A6265164B4027DE019EB4244C4065A6B4FE961E4B4027DE019EB4244C4065A6B4FE961E4B40996379573D204C402B685A6265164B40996379573D204C40
52496	28834	54.174968999999997	54.238982999999998	56.286762000000003	56.251871999999999	К.Маркса	0103000020E610000001000000050000002B685A6265164B40996379573D204C402B685A6265164B4027DE019EB4244C4065A6B4FE961E4B4027DE019EB4244C4065A6B4FE961E4B40996379573D204C402B685A6265164B40996379573D204C40
52571	28834	54.174968999999997	54.238982999999998	56.286762000000003	56.251871999999999	Азина	0103000020E610000001000000050000002B685A6265164B40996379573D204C402B685A6265164B4027DE019EB4244C4065A6B4FE961E4B4027DE019EB4244C4065A6B4FE961E4B40996379573D204C402B685A6265164B40996379573D204C40
52605	70	53.284101	53.289662	56.874758999999997	56.865716999999997	имени Петрова	0103000020E6100000010000000500000065E1EB6B5DA44A40AD4B8DD0CF6E4C4065E1EB6B5DA44A40DA70581AF86F4C406D72F8A413A54A40DA70581AF86F4C406D72F8A413A54A40AD4B8DD0CF6E4C4065E1EB6B5DA44A40AD4B8DD0CF6E4C40
52381	70	53.219476	53.221550999999998	56.824463999999999	56.818635999999998	Щедрина	0103000020E61000000100000005000000E22021CA179C4A4004AA7F10C9684C40E22021CA179C4A405B5D4E0988694C40B3B27DC85B9C4A405B5D4E0988694C40B3B27DC85B9C4A4004AA7F10C9684C40E22021CA179C4A4004AA7F10C9684C40
52536	70	53.183283000000003	53.190576999999998	56.881811999999996	56.868614999999998	Школьная	0103000020E61000000100000005000000D6743DD175974A4053E8BCC62E6F4C40D6743DD175974A40349C3237DF704C40552FBFD364984A40349C3237DF704C40552FBFD364984A4053E8BCC62E6F4C40D6743DD175974A4053E8BCC62E6F4C40
52352	70	53.227867000000003	53.247188999999999	56.864486999999997	56.860619	Шишкина	0103000020E61000000100000005000000386BF0BE2A9D4A407AA86DC3286E4C40386BF0BE2A9D4A4098689082A76E4C4029779FE3A39F4A4098689082A76E4C4029779FE3A39F4A407AA86DC3286E4C40386BF0BE2A9D4A407AA86DC3286E4C40
52454	70	53.193047999999997	53.230696000000002	56.858361000000002	56.856028000000002	Широкий переулок	0103000020E610000001000000050000007347FFCBB5984A40EB3A5453926D4C407347FFCBB5984A40B894F3C5DE6D4C40B5A84F72879D4A40B894F3C5DE6D4C40B5A84F72879D4A40EB3A5453926D4C407347FFCBB5984A40EB3A5453926D4C40
52588	70	53.115738999999998	53.119036000000001	56.841670000000001	56.836179999999999	Шевченко	0103000020E6100000010000000500000095EF1989D08E4A40DEC83CF2076B4C4095EF1989D08E4A401D03B2D7BB6B4C40F98557923C8F4A401D03B2D7BB6B4C40F98557923C8F4A40DEC83CF2076B4C4095EF1989D08E4A40DEC83CF2076B4C40
52849	70	53.109118000000002	53.119152	56.849511999999997	56.838095000000003	Чайковского	0103000020E61000000100000005000000D5B32094F78D4A4077F86BB2466B4C40D5B32094F78D4A409FC728CFBC6C4C4062A06B5F408F4A409FC728CFBC6C4C4062A06B5F408F4A4077F86BB2466B4C40D5B32094F78D4A4077F86BB2466B4C40
52346	70	53.207555999999997	53.232151999999999	56.877429999999997	56.875492000000001	Холмогорова	0103000020E61000000100000005000000560BEC31919A4A406FF4311F10704C40560BEC31919A4A40BF4351A04F704C40BAD91F28B79D4A40BF4351A04F704C40BAD91F28B79D4A406FF4311F10704C40560BEC31919A4A406FF4311F10704C40
52341	70	53.254680999999998	53.262172999999997	56.867921000000003	56.841102999999997	Халтурина	0103000020E61000000100000005000000CFF4126399A04A40A3C85A43A96B4C40CFF4126399A04A407D410B09186F4C40757286E28EA14A407D410B09186F4C40757286E28EA14A40A3C85A43A96B4C40CFF4126399A04A40A3C85A43A96B4C40
52517	70	53.222495000000002	53.224677999999997	56.849983999999999	56.849738000000002	Университетская	0103000020E61000000100000005000000034356B77A9C4A409015FC36C46C4C40034356B77A9C4A40C70F9546CC6C4C40BA10AB3FC29C4A40C70F9546CC6C4C40BA10AB3FC29C4A409015FC36C46C4C40034356B77A9C4A409015FC36C46C4C40
52579	70	53.220554	53.234074	56.883336999999997	56.823276999999997	Удмуртская 	0103000020E6100000010000000500000041800C1D3B9C4A404546072461694C4041800C1D3B9C4A40622CD32F11714C40056C0723F69D4A40622CD32F11714C40056C0723F69D4A404546072461694C4041800C1D3B9C4A404546072461694C40
52532	70	53.220554	53.234074	56.883336999999997	56.823276999999997	Удмуртская	0103000020E6100000010000000500000041800C1D3B9C4A404546072461694C4041800C1D3B9C4A40622CD32F11714C40056C0723F69D4A40622CD32F11714C40056C0723F69D4A404546072461694C4041800C1D3B9C4A404546072461694C40
52369	70	53.278270999999997	53.290793999999998	56.865716999999997	56.860211	Труда	0103000020E610000001000000050000006D3656629EA34A406954E0641B6E4C406D3656629EA34A40AD4B8DD0CF6E4C40BFEFDFBC38A54A40AD4B8DD0CF6E4C40BFEFDFBC38A54A406954E0641B6E4C406D3656629EA34A406954E0641B6E4C40
52523	70	53.234963	53.243344999999998	56.868609999999997	56.866903000000001	Тимирязева	0103000020E6100000010000000500000091628044139E4A40F3E670ADF66E4C4091628044139E4A40417DCB9C2E6F4C409352D0ED259F4A40417DCB9C2E6F4C409352D0ED259F4A40F3E670ADF66E4C4091628044139E4A40F3E670ADF66E4C40
52348	70	53.234333999999997	53.238852999999999	56.850712999999999	56.850096999999998	Тельмана	0103000020E61000000100000005000000A12B11A8FE9D4A40BFB67EFACF6C4C40A12B11A8FE9D4A401AA4E029E46C4C4097C62FBC929E4A401AA4E029E46C4C4097C62FBC929E4A40BFB67EFACF6C4C40A12B11A8FE9D4A40BFB67EFACF6C4C40
52534	70	53.109000999999999	53.114589000000002	56.854703999999998	56.854128000000003	Тверская	0103000020E610000001000000050000009B1DA9BEF38D4A40884CF910546D4C409B1DA9BEF38D4A4054E1CFF0666D4C409DBD33DAAA8E4A4054E1CFF0666D4C409DBD33DAAA8E4A40884CF910546D4C409B1DA9BEF38D4A40884CF910546D4C40
52599	70	53.277569999999997	53.289662	56.866145000000003	56.865716999999997	Татьяны Барамзиной	0103000020E61000000100000005000000E42CEC6987A34A40AD4B8DD0CF6E4C40E42CEC6987A34A40064CE0D6DD6E4C406D72F8A413A54A40064CE0D6DD6E4C406D72F8A413A54A40AD4B8DD0CF6E4C40E42CEC6987A34A40AD4B8DD0CF6E4C40
52361	70	53.169701000000003	53.180470999999997	56.876820000000002	56.869432000000003	Студенческая	0103000020E610000001000000050000009C8C2AC3B8954A40460C3B8C496F4C409C8C2AC3B8954A40473D44A33B704C402E7079AC19974A40473D44A33B704C402E7079AC19974A40460C3B8C496F4C409C8C2AC3B8954A40460C3B8C496F4C40
52583	70	53.174928999999999	53.18835	56.81568	56.795160000000003	Степная 	0103000020E610000001000000050000009D0FCF1264964A402F8B89CDC7654C409D0FCF1264964A402A00C63368684C40CE1951DA1B984A402A00C63368684C40CE1951DA1B984A402F8B89CDC7654C409D0FCF1264964A402F8B89CDC7654C40
52594	70	53.211832000000001	53.214077000000003	56.826113999999997	56.816916999999997	Степана Разина	0103000020E61000000100000005000000861F9C4F1D9B4A40F1457BBC90684C40861F9C4F1D9B4A404562821ABE694C40B4E908E0669B4A404562821ABE694C40B4E908E0669B4A40F1457BBC90684C40861F9C4F1D9B4A40F1457BBC90684C40
53163	70	53.013258999999998	53.389311999999997	56.987619000000002	56.723323999999998	Старосмирновская	0103000020E6100000010000000500000057B08D78B2814A40B9347EE1955C4C4057B08D78B2814A4041F4A44C6A7E4C405DF8C1F9D4B14A4041F4A44C6A7E4C405DF8C1F9D4B14A40B9347EE1955C4C4057B08D78B2814A40B9347EE1955C4C40
52461	70	53.308041000000003	53.351258999999999	56.889910999999998	56.883710000000001	Спортивная	0103000020E61000000100000005000000E06932E36DA74A40F792C6681D714C40E06932E36DA74A40E2AC889AE8714C407CB60E0EF6AC4A40E2AC889AE8714C407CB60E0EF6AC4A40F792C6681D714C40E06932E36DA74A40F792C6681D714C40
52462	70	53.298259000000002	53.305821999999999	56.873199999999997	56.839123999999998	Союзная	0103000020E610000001000000050000006C5ED5592DA64A40F4A44C6A686B4C406C5ED5592DA64A40006F8104C56F4C40DB32E02C25A74A40006F8104C56F4C40DB32E02C25A74A40F4A44C6A686B4C406C5ED5592DA64A40F4A44C6A686B4C40
52580	70	53.2258	53.229798000000002	56.867035999999999	56.861637999999999	Софьи Ковалевской	0103000020E61000000100000005000000E9B7AF03E79C4A40D47E6B274A6E4C40E9B7AF03E79C4A40323A2009FB6E4C40D65757056A9D4A40323A2009FB6E4C40D65757056A9D4A40D47E6B274A6E4C40E9B7AF03E79C4A40D47E6B274A6E4C40
52595	70	53.197656000000002	53.240882999999997	56.847665999999997	56.844352999999998	Советская 	0103000020E61000000100000005000000D9EDB3CA4C994A40C6A354C2136C4C40D9EDB3CA4C994A402FF7C951806C4C40C8940F41D59E4A402FF7C951806C4C40C8940F41D59E4A40C6A354C2136C4C40D9EDB3CA4C994A40C6A354C2136C4C40
52522	70	53.197656000000002	53.240882999999997	56.847665999999997	56.844352999999998	Советская	0103000020E61000000100000005000000D9EDB3CA4C994A40C6A354C2136C4C40D9EDB3CA4C994A402FF7C951806C4C40C8940F41D59E4A402FF7C951806C4C40C8940F41D59E4A40C6A354C2136C4C40D9EDB3CA4C994A40C6A354C2136C4C40
52834	70	53.222296999999998	53.232393999999999	56.948804000000003	56.885604000000001	Славянское шоссе	0103000020E61000000100000005000000DC7F643A749C4A40789ACC785B714C40DC7F643A749C4A403128D36872794C40B0E42A16BF9D4A403128D36872794C40B0E42A16BF9D4A40789ACC785B714C40DC7F643A749C4A40789ACC785B714C40
52465	70	53.258760000000002	53.264113999999999	56.921444999999999	56.920898999999999	Сельская	0103000020E61000000100000005000000A9C1340C1FA14A40A5F5B704E0754C40A9C1340C1FA14A400708E6E8F1754C403735D07CCEA14A400708E6E8F1754C403735D07CCEA14A40A5F5B704E0754C40A9C1340C1FA14A40A5F5B704E0754C40
52542	70	53.196784999999998	53.226537	56.867631000000003	56.866849000000002	Северный переулок	0103000020E61000000100000005000000F3AB394030994A4000C974E8F46E4C40F3AB394030994A4076FF58880E6F4C40BF2A172AFF9C4A4076FF58880E6F4C40BF2A172AFF9C4A4000C974E8F46E4C40F3AB394030994A4000C974E8F46E4C40
52529	70	53.169566000000003	53.178558000000002	56.824537999999997	56.822645999999999	Саратовская	0103000020E61000000100000005000000BC41B456B4954A40B517D1764C694C40BC41B456B4954A40952710768A694C40373811FDDA964A40952710768A694C40373811FDDA964A40B517D1764C694C40BC41B456B4954A40B517D1764C694C40
52370	70	53.293120000000002	53.301960000000001	56.880946999999999	56.872728000000002	Сабурова	0103000020E61000000100000005000000DAE6C6F484A54A40D926158DB56F4C40DAE6C6F484A54A4031410DDFC2704C409F5912A0A6A64A4031410DDFC2704C409F5912A0A6A64A40D926158DB56F4C40DAE6C6F484A54A40D926158DB56F4C40
52368	70	53.274507	53.296722000000003	56.833210000000001	56.830171999999997	Ракетная	0103000020E61000000100000005000000F4C29D0B23A34A4007077B13436A4C40F4C29D0B23A34A409F5912A0A66A4C407A008BFCFAA54A409F5912A0A66A4C407A008BFCFAA54A4007077B13436A4C40F4C29D0B23A34A4007077B13436A4C40
52453	70	53.207465999999997	53.220436999999997	56.875492000000001	56.825172999999999	Пушкинская 	0103000020E610000001000000050000001684F23E8E9A4A406745D4449F694C401684F23E8E9A4A406FF4311F10704C4007EA9447379C4A406FF4311F10704C4007EA9447379C4A406745D4449F694C401684F23E8E9A4A406745D4449F694C40
52460	70	53.207465999999997	53.220436999999997	56.875492000000001	56.825172999999999	Пушкинская	0103000020E610000001000000050000001684F23E8E9A4A406745D4449F694C401684F23E8E9A4A406FF4311F10704C4007EA9447379C4A406FF4311F10704C4007EA9447379C4A406745D4449F694C401684F23E8E9A4A406745D4449F694C40
52656	70	53.237603999999997	53.241259999999997	56.844712000000001	56.843091999999999	Прасовский переулок	0103000020E610000001000000050000000BB3D0CE699E4A4076C24B70EA6B4C400BB3D0CE699E4A40F644D7851F6C4C409EEA909BE19E4A40F644D7851F6C4C409EEA909BE19E4A4076C24B70EA6B4C400BB3D0CE699E4A4076C24B70EA6B4C40
28922	70	53.168551000000001	53.170921999999997	56.821109	56.807116999999998	Полевая улица	0103000020E61000000100000005000000A35A441493954A40D7851F9C4F674C40A35A441493954A40C3B986191A694C405D15A8C5E0954A40C3B986191A694C405D15A8C5E0954A40D7851F9C4F674C40A35A441493954A40D7851F9C4F674C40
52774	70	53.153359999999999	53.177408	56.876820000000002	56.857199000000001	Песочная	0103000020E61000000100000005000000DD41EC4CA1934A40FB9463B2B86D4C40DD41EC4CA1934A40473D44A33B704C403E062B4EB5964A40473D44A33B704C403E062B4EB5964A40FB9463B2B86D4C40DD41EC4CA1934A40FB9463B2B86D4C40
52353	70	53.147584000000002	53.154097	56.796052000000003	56.795372	Пермская	0103000020E61000000100000005000000D9B45208E4924A40BA13ECBFCE654C40D9B45208E4924A402CF52C08E5654C40B3B45373B9934A402CF52C08E5654C40B3B45373B9934A40BA13ECBFCE654C40D9B45208E4924A40BA13ECBFCE654C40
52440	70	53.247422999999998	53.249614999999999	56.860441999999999	56.851210000000002	Парковая	0103000020E610000001000000050000009CA38E8EAB9F4A409B030473F46C4C409CA38E8EAB9F4A406B0DA5F6226E4C40A7CB6262F39F4A406B0DA5F6226E4C40A7CB6262F39F4A409B030473F46C4C409CA38E8EAB9F4A409B030473F46C4C40
52539	70	53.132384999999999	53.148626	56.830660000000002	56.825418999999997	Оружейника Драгунова	0103000020E6100000010000000500000090BDDEFDF1904A409E3F6D54A7694C4090BDDEFDF1904A40350C1F11536A4C40EBAA402D06934A40350C1F11536A4C40EBAA402D06934A409E3F6D54A7694C4090BDDEFDF1904A409E3F6D54A7694C40
52587	70	53.121290000000002	53.122692000000001	56.841172	56.835673	Орсовская	0103000020E610000001000000050000007AAA436E868F4A403A933655F76A4C407AAA436E868F4A40CC272B86AB6B4C408CBD175FB48F4A40CC272B86AB6B4C408CBD175FB48F4A403A933655F76A4C407AAA436E868F4A403A933655F76A4C40
52366	70	53.233634000000002	53.278792000000003	56.847172999999998	56.831704000000002	Орджоникидзе	0103000020E61000000100000005000000E99D0AB8E79D4A40E8F9D346756A4C40E99D0AB8E79D4A40F086342A706C4C407731CD74AFA34A40F086342A706C4C407731CD74AFA34A40E8F9D346756A4C40E99D0AB8E79D4A40E8F9D346756A4C40
52770	70	53.239051000000003	53.241674000000003	56.930601000000003	56.930202999999999	Оранжерейная	0103000020E61000000100000005000000BE892139999E4A400FD253E410774C40BE892139999E4A40FD4FFEEE1D774C409225732CEF9E4A40FD4FFEEE1D774C409225732CEF9E4A400FD253E410774C40BE892139999E4A400FD253E410774C40
52533	70	53.141466999999999	53.142930999999997	56.834299000000001	56.826566999999997	Новостроительная	0103000020E610000001000000050000004B3B35971B924A40F6798CF2CC694C404B3B35971B924A40F20A444FCA6A4C40D34A21904B924A40F20A444FCA6A4C40D34A21904B924A40F6798CF2CC694C404B3B35971B924A40F6798CF2CC694C40
52467	70	53.288386000000003	53.292023999999998	56.860211	56.846913000000001	Молодежная	0103000020E61000000100000005000000E84F1BD5E9A44A4054C72AA5676C4C40E84F1BD5E9A44A406954E0641B6E4C40D4D2DC0A61A54A406954E0641B6E4C40D4D2DC0A61A54A4054C72AA5676C4C40E84F1BD5E9A44A4054C72AA5676C4C40
52431	70	53.188898000000002	53.189841000000001	56.876510000000003	56.867610999999997	Металлистов	0103000020E61000000100000005000000D12346CF2D984A402E5393E00D6F4C40D12346CF2D984A40F94ECC7A31704C405038BBB54C984A40F94ECC7A31704C405038BBB54C984A402E5393E00D6F4C40D12346CF2D984A402E5393E00D6F4C40
52543	70	53.201276	53.229933000000003	56.869686999999999	56.867035999999999	Майская	0103000020E610000001000000050000001FBC7669C3994A40323A2009FB6E4C401FBC7669C3994A40D06053E7516F4C40B6A2CD716E9D4A40D06053E7516F4C40B6A2CD716E9D4A40323A2009FB6E4C401FBC7669C3994A40323A2009FB6E4C40
52358	70	53.174236999999998	53.176043	56.795046999999997	56.789126000000003	Локомотивная	0103000020E610000001000000050000006760E4654D964A402F36AD1402654C406760E4654D964A4036E49F19C4654C4049D8B79388964A4036E49F19C4654C4049D8B79388964A402F36AD1402654C406760E4654D964A402F36AD1402654C40
52364	70	53.197611000000002	53.309477999999999	56.849310000000003	56.839478999999997	Ленина	0103000020E61000000100000005000000392A37514B994A40E256410C746B4C40392A37514B994A403815A930B66C4C406E6AA0F99CA74A403815A930B66C4C406E6AA0F99CA74A40E256410C746B4C40392A37514B994A40E256410C746B4C40
52350	70	53.178980000000003	53.185394000000002	56.809925999999997	56.788696999999999	Леваневского	0103000020E61000000100000005000000AD510FD1E8964A4006BAF605F4644C40AD510FD1E8964A400D17B9A7AB674C40F46F97FDBA974A400D17B9A7AB674C40F46F97FDBA974A4006BAF605F4644C40AD510FD1E8964A4006BAF605F4644C40
52948	70	53.271245999999998	53.274929	56.843836000000003	56.840591000000003	Курортная	0103000020E61000000100000005000000DD955D30B8A24A40EE27637C986B4C40DD955D30B8A24A40FF976BD1026C4C406ADC9BDF30A34A40FF976BD1026C4C406ADC9BDF30A34A40EE27637C986B4C40DD955D30B8A24A40EE27637C986B4C40
52820	70	53.203961999999997	53.241062999999997	56.851013000000002	56.848128000000003	Красногеройская улица	0103000020E6100000010000000500000039D0436D1B9A4A40346953758F6C4C4039D0436D1B9A4A4045BC75FEED6C4C4048A30227DB9E4A4045BC75FEED6C4C4048A30227DB9E4A40346953758F6C4C4039D0436D1B9A4A40346953758F6C4C40
52776	70	53.203961999999997	53.241062999999997	56.851013000000002	56.848128000000003	Красногеройская	0103000020E6100000010000000500000039D0436D1B9A4A40346953758F6C4C4039D0436D1B9A4A4045BC75FEED6C4C4048A30227DB9E4A4045BC75FEED6C4C4048A30227DB9E4A40346953758F6C4C4039D0436D1B9A4A40346953758F6C4C40
52455	70	53.205812999999999	53.213988000000001	56.866867999999997	56.825794000000002	Красноармейская	0103000020E61000000100000005000000BB0B9414589A4A40D49D279EB3694C40BB0B9414589A4A4076F9D687F56E4C4044DE72F5639B4A4076F9D687F56E4C4044DE72F5639B4A40D49D279EB3694C40BB0B9414589A4A40D49D279EB3694C40
52463	70	53.279538000000002	53.289104999999999	56.873367000000002	56.868063999999997	Короткова	0103000020E61000000100000005000000A0FEB3E6C7A34A40DF6A9DB81C6F4C40A0FEB3E6C7A34A40EC33677DCA6F4C40170E846401A54A40EC33677DCA6F4C40170E846401A54A40DF6A9DB81C6F4C40A0FEB3E6C7A34A40DF6A9DB81C6F4C40
52452	70	53.216988000000001	53.227362999999997	56.867508000000001	56.824365	Коммунаров	0103000020E61000000100000005000000EECF4543C69B4A40C87BD5CA84694C40EECF4543C69B4A405A828C800A6F4C4004A9143B1A9D4A405A828C800A6F4C4004A9143B1A9D4A40C87BD5CA84694C40EECF4543C69B4A40C87BD5CA84694C40
52342	70	53.127865999999997	53.162540999999997	56.832008999999999	56.829487	Клубная	0103000020E610000001000000050000009A22C0E95D904A4084BA48A12C6A4C409A22C0E95D904A40247D5A457F6A4C402BA1BB24CE944A40247D5A457F6A4C402BA1BB24CE944A4084BA48A12C6A4C409A22C0E95D904A4084BA48A12C6A4C40
52363	70	53.177309000000001	53.220931999999998	56.861564000000001	56.860137000000002	Кирова	0103000020E61000000100000005000000AB24B20FB2964A402F8A1EF8186E4C40AB24B20FB2964A409AB4A9BA476E4C40E751F17F479C4A409AB4A9BA476E4C40E751F17F479C4A402F8A1EF8186E4C40AB24B20FB2964A402F8A1EF8186E4C40
52362	70	53.201239999999999	53.208328000000002	56.876077000000002	56.819656000000002	Карла Маркса	0103000020E61000000100000005000000D252793BC2994A402FFCE07CEA684C40D252793BC2994A408FE3874A23704C40A96BED7DAA9A4A408FE3874A23704C40A96BED7DAA9A4A402FFCE07CEA684C40D252793BC2994A402FFCE07CEA684C40
52435	70	53.201222999999999	53.240946000000001	56.840851999999998	56.836981999999999	Карла Либкнехта	0103000020E61000000100000005000000FC19DEACC1994A409BABE639226B4C40FC19DEACC1994A405A63D009A16B4C400F0D8B51D79E4A405A63D009A16B4C400F0D8B51D79E4A409BABE639226B4C40FC19DEACC1994A409BABE639226B4C40
52602	70	53.241304999999997	53.267491	56.824922000000001	56.821818999999998	Камская	0103000020E610000001000000050000003EAE0D15E39E4A409F1D705D31694C403EAE0D15E39E4A401EE0490B97694C40B77C24253DA24A401EE0490B97694C40B77C24253DA24A409F1D705D31694C403EAE0D15E39E4A409F1D705D31694C40
52354	70	53.147826999999999	53.155714000000003	56.832447000000002	56.831688999999997	Зои Космодемьянской	0103000020E610000001000000050000009F3BC1FEEB924A40B2B8FFC8746A4C409F3BC1FEEB924A40A053909F8D6A4C40C2C3B46FEE934A40A053909F8D6A4C40C2C3B46FEE934A40B2B8FFC8746A4C409F3BC1FEEB924A40B2B8FFC8746A4C40
52355	70	53.134701999999997	53.147520999999998	56.839021000000002	56.838312000000002	Заречное шоссе	0103000020E61000000100000005000000575A46EA3D914A4014ECBFCE4D6B4C40575A46EA3D914A4020D4450A656B4C40923CD7F7E1924A4020D4450A656B4C40923CD7F7E1924A4014ECBFCE4D6B4C40575A46EA3D914A4014ECBFCE4D6B4C40
52351	70	53.238269000000003	53.258391000000003	56.886173999999997	56.880411000000002	Дзержинского	0103000020E6100000010000000500000048533D997F9E4A40F304C24EB1704C4048533D997F9E4A4062484E266E714C40564ACFF412A14A4062484E266E714C40564ACFF412A14A40F304C24EB1704C4048533D997F9E4A40F304C24EB1704C40
52550	70	53.243237000000001	53.243532999999999	56.801631999999998	56.795076000000002	Демократическая	0103000020E61000000100000005000000AD16D863229F4A40D1EAE40CC5654C40AD16D863229F4A40AAB69BE09B664C40963FDF162C9F4A40AAB69BE09B664C40963FDF162C9F4A40D1EAE40CC5654C40AD16D863229F4A40D1EAE40CC5654C40
52945	70	53.013258999999998	53.389311999999997	56.987619000000002	56.723323999999998	Гороховая	0103000020E6100000010000000500000057B08D78B2814A40B9347EE1955C4C4057B08D78B2814A4041F4A44C6A7E4C405DF8C1F9D4B14A4041F4A44C6A7E4C405DF8C1F9D4B14A40B9347EE1955C4C4057B08D78B2814A40B9347EE1955C4C40
53062	70	53.099704000000003	53.117849999999997	56.838681000000001	56.829616000000001	Городок Машиностроителей	0103000020E61000000100000005000000E4A3C519C38C4A40821E6ADB306A4C40E4A3C519C38C4A40676325E6596B4C40B3EA73B5158F4A40676325E6596B4C40B3EA73B5158F4A40821E6ADB306A4C40E4A3C519C38C4A40821E6ADB306A4C40
52349	70	53.172944000000001	53.190810999999997	56.815064999999997	56.780999999999999	Гагарина	0103000020E610000001000000050000000C056C0723964A408716D9CEF7634C400C056C0723964A409F8EC70C54684C40C85BAE7E6C984A409F8EC70C54684C40C85BAE7E6C984A408716D9CEF7634C400C056C0723964A408716D9CEF7634C40
9855	70	53.029069	53.314123000000002	56.939194999999998	56.763978000000002	Воткинское шоссе	0103000020E61000000100000005000000E9297288B8834A40876EF607CA614C40E9297288B8834A408AC8B08A37784C40F1F5B52E35A84A408AC8B08A37784C40F1F5B52E35A84A40876EF607CA614C40E9297288B8834A40876EF607CA614C40
52447	70	53.235691000000003	53.238771999999997	56.842225999999997	56.834560000000003	Восточная	0103000020E61000000100000005000000147B681F2B9E4A405F46B1DCD26A4C40147B681F2B9E4A40A2EBC20FCE6B4C40AA99B514909E4A40A2EBC20FCE6B4C40AA99B514909E4A405F46B1DCD26A4C40147B681F2B9E4A405F46B1DCD26A4C40
52365	70	53.258327999999999	53.282080000000001	56.877941999999997	56.874867000000002	Ворошилова	0103000020E610000001000000050000000FD253E410A14A40C1AC50A4FB6F4C400FD253E410A14A4075E4486760704C40876D8B321BA44A4075E4486760704C40876D8B321BA44A40C1AC50A4FB6F4C400FD253E410A14A40C1AC50A4FB6F4C40
52375	70	53.233184999999999	53.236032000000002	56.832112000000002	56.823213000000003	Володарского	0103000020E6100000010000000500000079758E01D99D4A402F52280B5F694C4079758E01D99D4A40F94D61A5826A4C409D67EC4B369E4A40F94D61A5826A4C409D67EC4B369E4A402F52280B5F694C4079758E01D99D4A402F52280B5F694C40
52544	70	53.221173999999998	53.237603999999997	56.843091999999999	56.84066	Владимира Краева	0103000020E61000000100000005000000DD5CFC6D4F9C4A40168733BF9A6B4C40DD5CFC6D4F9C4A4076C24B70EA6B4C400BB3D0CE699E4A4076C24B70EA6B4C400BB3D0CE699E4A40168733BF9A6B4C40DD5CFC6D4F9C4A40168733BF9A6B4C40
52441	70	53.226329999999997	53.250055000000003	56.883375999999998	56.872053999999999	Буммашевская	0103000020E61000000100000005000000450DA661F89C4A40492C29779F6F4C40450DA661F89C4A402009FB7612714C40C4995FCD01A04A402009FB7612714C40C4995FCD01A04A40492C29779F6F4C40450DA661F89C4A40492C29779F6F4C40
52450	70	53.177273	53.193047999999997	56.858139000000001	56.856028000000002	Береговая	0103000020E610000001000000050000005EBBB4E1B0964A40EB3A5453926D4C405EBBB4E1B0964A400936AE7FD76D4C407347FFCBB5984A400936AE7FD76D4C407347FFCBB5984A40EB3A5453926D4C405EBBB4E1B0964A40EB3A5453926D4C40
52367	70	53.294494999999998	53.296847999999997	56.872728000000002	56.861494999999998	Барышникова	0103000020E61000000100000005000000F2EA1C03B2A54A407155D977456E4C40F2EA1C03B2A54A40D926158DB56F4C4006F1811DFFA54A40D926158DB56F4C4006F1811DFFA54A407155D977456E4C40F2EA1C03B2A54A407155D977456E4C40
52585	70	53.157924000000001	53.185285999999998	56.831901000000002	56.790289000000001	Азина	0103000020E6100000010000000500000073A087DA36944A40BCB1A03028654C4073A087DA36944A403E4162BB7B6A4C400D349F73B7974A403E4162BB7B6A4C400D349F73B7974A40BCB1A03028654C4073A087DA36944A40BCB1A03028654C40
52457	70	53.137855000000002	53.187353000000002	56.817813999999998	56.811	Автономная улица	0103000020E61000000100000005000000884B8E3BA5914A402B8716D9CE674C40884B8E3BA5914A40001B1021AE684C405CE7DF2EFB974A40001B1021AE684C405CE7DF2EFB974A402B8716D9CE674C40884B8E3BA5914A402B8716D9CE674C40
52444	70	53.137855000000002	53.187353000000002	56.817813999999998	56.811	Автономная	0103000020E61000000100000005000000884B8E3BA5914A402B8716D9CE674C40884B8E3BA5914A40001B1021AE684C405CE7DF2EFB974A40001B1021AE684C405CE7DF2EFB974A402B8716D9CE674C40884B8E3BA5914A402B8716D9CE674C40
52345	70	53.2258	53.237316999999997	56.861637999999999	56.859324999999998	Авангардная	0103000020E61000000100000005000000E9B7AF03E79C4A404ED1915CFE6D4C40E9B7AF03E79C4A40D47E6B274A6E4C4075E44867609E4A40D47E6B274A6E4C4075E44867609E4A404ED1915CFE6D4C40E9B7AF03E79C4A404ED1915CFE6D4C40
52343	70	53.013258999999998	53.389311999999997	56.987619000000002	56.723323999999998	9 Января	0103000020E6100000010000000500000057B08D78B2814A40B9347EE1955C4C4057B08D78B2814A4041F4A44C6A7E4C405DF8C1F9D4B14A4041F4A44C6A7E4C405DF8C1F9D4B14A40B9347EE1955C4C4057B08D78B2814A40B9347EE1955C4C40
52449	70	53.173257999999997	53.193677000000001	56.867837999999999	56.867134	5-я Подлесная	0103000020E610000001000000050000009BE271512D964A40F59F353FFE6E4C409BE271512D964A40EF1CCA50156F4C40637E6E68CA984A40EF1CCA50156F4C40637E6E68CA984A40F59F353FFE6E4C409BE271512D964A40F59F353FFE6E4C40
52459	70	53.013258999999998	53.389311999999997	56.987619000000002	56.723323999999998	40 лет Победы	0103000020E6100000010000000500000057B08D78B2814A40B9347EE1955C4C4057B08D78B2814A4041F4A44C6A7E4C405DF8C1F9D4B14A4041F4A44C6A7E4C405DF8C1F9D4B14A40B9347EE1955C4C4057B08D78B2814A40B9347EE1955C4C40
52359	70	53.013258999999998	53.389311999999997	56.987619000000002	56.723323999999998	30 лет Победы	0103000020E6100000010000000500000057B08D78B2814A40B9347EE1955C4C4057B08D78B2814A4041F4A44C6A7E4C405DF8C1F9D4B14A4041F4A44C6A7E4C405DF8C1F9D4B14A40B9347EE1955C4C4057B08D78B2814A40B9347EE1955C4C40
52356	70	\N	\N	\N	\N	15-я	\N
52344	70	53.013258999999998	53.389311999999997	56.987619000000002	56.723323999999998	10 лет Октября	0103000020E6100000010000000500000057B08D78B2814A40B9347EE1955C4C4057B08D78B2814A4041F4A44C6A7E4C405DF8C1F9D4B14A4041F4A44C6A7E4C405DF8C1F9D4B14A40B9347EE1955C4C4057B08D78B2814A40B9347EE1955C4C40
52445	70	53.155453000000001	53.185240999999998	56.809762999999997	56.804884000000001	 Депутатская	0103000020E61000000100000005000000558847E2E5934A406E895C7006674C40558847E2E5934A4063416150A6674C406D7022FAB5974A4063416150A6674C406D7022FAB5974A406E895C7006674C40558847E2E5934A406E895C7006674C40
52443	70	53.226196000000002	53.415667999999997	56.914782000000002	56.883375999999998	 Воткинское шоссе	0103000020E61000000100000005000000363E93FDF39C4A402009FB7612714C40363E93FDF39C4A40187C9A9317754C4032FFE89B34B54A40187C9A9317754C4032FFE89B34B54A402009FB7612714C40363E93FDF39C4A402009FB7612714C40
52489	56364	53.342599	53.411850999999999	56.809072999999998	56.768166999999998	Чкалово	0103000020E610000001000000050000003752B648DAAB4A40E76ED74B53624C403752B648DAAB4A40CE893DB48F674C4096E99788B7B44A40CE893DB48F674C4096E99788B7B44A40E76ED74B53624C403752B648DAAB4A40E76ED74B53624C40
52565	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Циолковского	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52385	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Толстого	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52394	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Тани Барамзиной	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52470	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Советская	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52386	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Сибирская	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52448	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Революции	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52611	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Пионерская	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52389	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Пехтина	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52610	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Первомайская	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52555	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Парковая	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52606	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Мира	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52562	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Луначарского	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52557	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Короленко	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52564	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Колхозная	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52379	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Кирова	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52497	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Калинина	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52383	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	К.Маркса	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52390	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Драгунова	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52378	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Гайдара	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52608	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	Белинского	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52377	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	70 лет Победы	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52380	9492	52.551237999999998	52.723453999999997	58.166862000000002	58.108435	 Пряженникова	0103000020E61000000100000005000000FE277FF78E464A40F25EB532E10D4D40FE277FF78E464A40FB78E8BB5B154D40871403249A5C4A40FB78E8BB5B154D40871403249A5C4A40F25EB532E10D4D40FE277FF78E464A40F25EB532E10D4D40
52384	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Энтузиастов	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52371	8096	53.183283000000003	53.190576999999998	56.881811999999996	56.868614999999998	Школьная	0103000020E61000000100000005000000D6743DD175974A4053E8BCC62E6F4C40D6743DD175974A40349C3237DF704C40552FBFD364984A40349C3237DF704C40552FBFD364984A4053E8BCC62E6F4C40D6743DD175974A4053E8BCC62E6F4C40
52725	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Тихая	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52598	8096	53.239193999999998	53.246811999999998	56.871842000000001	56.861151	Серова	0103000020E6100000010000000500000020B3B3E89D9E4A4077F52A323A6E4C4020B3B3E89D9E4A40BEA3C684986F4C4053211E89979F4A40BEA3C684986F4C4053211E89979F4A4077F52A323A6E4C4020B3B3E89D9E4A4077F52A323A6E4C40
52601	8096	53.20946	53.218093000000003	56.850506000000003	56.825552000000002	Свободы	0103000020E61000000100000005000000FBE8D495CF9A4A40DE921CB0AB694C40FBE8D495CF9A4A40A1866F61DD6C4C40473EAF78EA9B4A40A1866F61DD6C4C40473EAF78EA9B4A40DE921CB0AB694C40FBE8D495CF9A4A40DE921CB0AB694C40
52551	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Расковой	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52552	8096	53.209622000000003	53.210610000000003	56.826050000000002	56.820321	Пугачева	0103000020E61000000100000005000000D542C9E4D49A4A406B9C4D4700694C40D542C9E4D49A4A402F6EA301BC694C40F41ABB44F59A4A402F6EA301BC694C40F41ABB44F59A4A406B9C4D4700694C40D542C9E4D49A4A406B9C4D4700694C40
52592	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Песчаная	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52464	8096	53.233634000000002	53.278792000000003	56.847172999999998	56.831704000000002	Орджоникидзе	0103000020E61000000100000005000000E99D0AB8E79D4A40E8F9D346756A4C40E99D0AB8E79D4A40F086342A706C4C407731CD74AFA34A40F086342A706C4C407731CD74AFA34A40E8F9D346756A4C40E99D0AB8E79D4A40E8F9D346756A4C40
52373	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Мира	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52372	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Луначарского	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52604	8096	53.182617999999998	53.188412999999997	56.814152999999997	56.796289000000002	Ленинградская	0103000020E6100000010000000500000099D4D00660974A40109546CCEC654C4099D4D00660974A405B785E2A36684C401492CCEA1D984A405B785E2A36684C401492CCEA1D984A40109546CCEC654C4099D4D00660974A40109546CCEC654C40
52612	8096	53.197611000000002	53.309477999999999	56.849310000000003	56.839478999999997	Ленина	0103000020E61000000100000005000000392A37514B994A40E256410C746B4C40392A37514B994A403815A930B66C4C406E6AA0F99CA74A403815A930B66C4C406E6AA0F99CA74A40E256410C746B4C40392A37514B994A40E256410C746B4C40
52376	8096	53.205812999999999	53.213988000000001	56.866867999999997	56.825794000000002	Красноармейская	0103000020E61000000100000005000000BB0B9414589A4A40D49D279EB3694C40BB0B9414589A4A4076F9D687F56E4C4044DE72F5639B4A4076F9D687F56E4C4044DE72F5639B4A40D49D279EB3694C40BB0B9414589A4A40D49D279EB3694C40
52339	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Королева	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52466	8096	53.177309000000001	53.220931999999998	56.861564000000001	56.860137000000002	Кирова	0103000020E61000000100000005000000AB24B20FB2964A402F8A1EF8186E4C40AB24B20FB2964A409AB4A9BA476E4C40E751F17F479C4A409AB4A9BA476E4C40E751F17F479C4A402F8A1EF8186E4C40AB24B20FB2964A402F8A1EF8186E4C40
52374	8096	53.172944000000001	53.190810999999997	56.815064999999997	56.780999999999999	Гагарина	0103000020E610000001000000050000000C056C0723964A408716D9CEF7634C400C056C0723964A409F8EC70C54684C40C85BAE7E6C984A409F8EC70C54684C40C85BAE7E6C984A408716D9CEF7634C400C056C0723964A408716D9CEF7634C40
52469	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Волгоградская	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52578	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	1905 года	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
52603	8096	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	1 Мая	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
53155	8096	53.890571999999999	54.031939999999999	57.083525000000002	57.022015000000003	 2-ой км.Чайковского тракта	0103000020E61000000100000005000000DD5D6743FEF14A40BF823463D1824C40DD5D6743FEF14A40FFB27BF2B08A4C4095B7239C16044B40FFB27BF2B08A4C4095B7239C16044B40BF823463D1824C40DD5D6743FEF14A40BF823463D1824C40
52511	56365	51.682423	52.431922999999998	58.489387000000001	58.000250000000001	Ф.Васильева	0103000020E61000000100000005000000E48409A359D7494079E9263108004D40E48409A359D74940350BB43BA43E4D40F2B1BB4049374A40350BB43BA43E4D40F2B1BB4049374A4079E9263108004D40E48409A359D7494079E9263108004D40
52653	56365	51.682423	52.431922999999998	58.489387000000001	58.000250000000001	Советская	0103000020E61000000100000005000000E48409A359D7494079E9263108004D40E48409A359D74940350BB43BA43E4D40F2B1BB4049374A40350BB43BA43E4D40F2B1BB4049374A4079E9263108004D40E48409A359D7494079E9263108004D40
52853	56365	51.682423	52.431922999999998	58.489387000000001	58.000250000000001	Максима Горького	0103000020E61000000100000005000000E48409A359D7494079E9263108004D40E48409A359D74940350BB43BA43E4D40F2B1BB4049374A40350BB43BA43E4D40F2B1BB4049374A4079E9263108004D40E48409A359D7494079E9263108004D40
53153	56406	51.682423	52.431922999999998	58.489387000000001	58.000250000000001	Жуйкова	0103000020E61000000100000005000000E48409A359D7494079E9263108004D40E48409A359D74940350BB43BA43E4D40F2B1BB4049374A40350BB43BA43E4D40F2B1BB4049374A4079E9263108004D40E48409A359D7494079E9263108004D40
52938	17515	51.948045999999998	51.971527999999999	58.255923000000003	58.238985999999997	Логовая	0103000020E61000000100000005000000438D429259F94940D619DF17971E4D40438D429259F94940A9A5B915C2204D40FB928D075BFC4940A9A5B915C2204D40FB928D075BFC4940D619DF17971E4D40438D429259F94940D619DF17971E4D40
53027	17917	52.051001999999997	52.070126999999999	58.321514000000001	58.309477999999999	Совхозная	0103000020E61000000100000005000000EA03C93B87064A406E6AA0F99C274D40EA03C93B87064A40639AE95E27294D4086C8E9EBF9084A40639AE95E27294D4086C8E9EBF9084A406E6AA0F99C274D40EA03C93B87064A406E6AA0F99C274D40
52724	18205	52.032164000000002	52.077492999999997	58.167929999999998	58.159593999999998	Школьная	0103000020E61000000100000005000000E50D30F31D044A40A45181936D144D40E50D30F31D044A403602F1BA7E154D409F55664AEB094A403602F1BA7E154D409F55664AEB094A40A45181936D144D40E50D30F31D044A40A45181936D144D40
52723	18210	52.121941999999997	52.203868	58.316239000000003	58.294313000000002	Кирова	0103000020E610000001000000050000002101A3CB9B0F4A40D2E4620CAC254D402101A3CB9B0F4A40215C01857A284D40B859BC58181A4A40215C01857A284D40B859BC58181A4A40D2E4620CAC254D402101A3CB9B0F4A40D2E4620CAC254D40
52657	18210	52.121941999999997	52.203868	58.316239000000003	58.294313000000002	Гагарина	0103000020E610000001000000050000002101A3CB9B0F4A40D2E4620CAC254D402101A3CB9B0F4A40215C01857A284D40B859BC58181A4A40215C01857A284D40B859BC58181A4A40D2E4620CAC254D402101A3CB9B0F4A40D2E4620CAC254D40
75049	18020	52.188363000000003	52.211917	58.256373000000004	58.239350999999999	Школьная	0103000020E6100000010000000500000063635E471C184A40E8A1B60DA31E4D4063635E471C184A40E94999D4D0204D40B43BA418201B4A40E94999D4D0204D40B43BA418201B4A40E8A1B60DA31E4D4063635E471C184A40E8A1B60DA31E4D40
53026	17722	52.240141999999999	52.266651000000003	58.195099999999996	58.185763999999999	Сибирская	0103000020E61000000100000005000000B1321AF9BC1E4A401763601DC7174D40B1321AF9BC1E4A408CB96B09F9184D400D39B69E21224A408CB96B09F9184D400D39B69E21224A401763601DC7174D40B1321AF9BC1E4A401763601DC7174D40
53141	17932	51.780205000000002	51.802025	58.200184999999998	58.187097999999999	Школьная	0103000020E610000001000000050000007D96E7C1DDE34940D192C7D3F2174D407D96E7C1DDE349402B137EA99F194D4086C954C1A8E649402B137EA99F194D4086C954C1A8E64940D192C7D3F2174D407D96E7C1DDE34940D192C7D3F2174D40
52510	17729	52.132199999999997	52.168788999999997	58.225572	58.207572999999996	Чепецкая	0103000020E61000000100000005000000FE43FAEDEB104A402C4487C0911A4D40FE43FAEDEB104A405872158BDF1C4D405776C1E09A154A405872158BDF1C4D405776C1E09A154A402C4487C0911A4D40FE43FAEDEB104A402C4487C0911A4D40
53241	17629	52.049987000000002	52.0625	58.072840999999997	58.065824999999997	Первомайская	0103000020E61000000100000005000000D21C59F965064A402D211FF46C084D40D21C59F965064A406A6798DA52094D400000000000084A406A6798DA52094D400000000000084A402D211FF46C084D40D21C59F965064A402D211FF46C084D40
52937	17543	51.900866000000001	51.929082000000001	58.282953999999997	58.268610000000002	Школьная	0103000020E61000000100000005000000070ABC934FF3494075B0FECF61224D40070ABC934FF34940DD2230D637244D40B1A6B228ECF64940DD2230D637244D40B1A6B228ECF6494075B0FECF61224D40070ABC934FF3494075B0FECF61224D40
52809	17414	52.078876000000001	52.093581999999998	58.262706999999999	58.255524999999999	Советская	0103000020E610000001000000050000003B38D89B180A4A40BB270F0BB5204D403B38D89B180A4A4013B70A62A0214D4044BFB67EFA0B4A4013B70A62A0214D4044BFB67EFA0B4A40BB270F0BB5204D403B38D89B180A4A40BB270F0BB5204D40
52935	16013	53.140980999999996	53.190676000000003	57.195526999999998	57.170478000000003	проезд Гребенщикова	0103000020E61000000100000005000000BE2D58AA0B924A4000581D39D2954C40BE2D58AA0B924A40143E5B0707994C40E910381268984A40143E5B0707994C40E910381268984A4000581D39D2954C40BE2D58AA0B924A4000581D39D2954C40
52429	16013	53.140980999999996	53.190676000000003	57.195526999999998	57.170478000000003	Пушиной	0103000020E61000000100000005000000BE2D58AA0B924A4000581D39D2954C40BE2D58AA0B924A40143E5B0707994C40E910381268984A40143E5B0707994C40E910381268984A4000581D39D2954C40BE2D58AA0B924A4000581D39D2954C40
52719	16013	53.140980999999996	53.190676000000003	57.195526999999998	57.170478000000003	Ленина	0103000020E61000000100000005000000BE2D58AA0B924A4000581D39D2954C40BE2D58AA0B924A40143E5B0707994C40E910381268984A40143E5B0707994C40E910381268984A4000581D39D2954C40BE2D58AA0B924A4000581D39D2954C40
52634	16203	53.155175	53.171227999999999	57.217503999999998	57.205317999999998	Юбилейная	0103000020E6100000010000000500000012143FC6DC934A40DBA337DC479A4C4012143FC6DC934A40E55FCB2BD79B4C406A1492CCEA954A40E55FCB2BD79B4C406A1492CCEA954A40DBA337DC479A4C4012143FC6DC934A40DBA337DC479A4C40
52722	16203	53.155175	53.171227999999999	57.217503999999998	57.205317999999998	Комсомольская	0103000020E6100000010000000500000012143FC6DC934A40DBA337DC479A4C4012143FC6DC934A40E55FCB2BD79B4C406A1492CCEA954A40E55FCB2BD79B4C406A1492CCEA954A40DBA337DC479A4C4012143FC6DC934A40DBA337DC479A4C40
52702	15919	52.952668000000003	52.987675000000003	57.121184	57.100332999999999	Коммунаров	0103000020E610000001000000050000000EF96706F1794A40D3DA34B6D78C4C400EF96706F1794A40346612F5828F4C40D50968226C7E4A40346612F5828F4C40D50968226C7E4A40D3DA34B6D78C4C400EF96706F1794A40D3DA34B6D78C4C40
52934	16410	52.910778999999998	52.934953	57.211089999999999	57.198160000000001	Пушкина	0103000020E610000001000000050000001971016894744A400CB08F4E5D994C401971016894744A409E4143FF049B4C400726378AAC774A409E4143FF049B4C400726378AAC774A400CB08F4E5D994C401971016894744A400CB08F4E5D994C40
52519	16415	52.628608999999997	52.665332999999997	57.362001999999997	57.334131999999997	Площадь Свободы 	0103000020E61000000100000005000000527C7C4276504A4006465ED6C4AA4C40527C7C4276504A40158BDF1456AE4C408BF9B9A129554A40158BDF1456AE4C408BF9B9A129554A4006465ED6C4AA4C40527C7C4276504A4006465ED6C4AA4C40
53023	16415	52.628608999999997	52.665332999999997	57.362001999999997	57.334131999999997	Октябрьская	0103000020E61000000100000005000000527C7C4276504A4006465ED6C4AA4C40527C7C4276504A40158BDF1456AE4C408BF9B9A129554A40158BDF1456AE4C408BF9B9A129554A4006465ED6C4AA4C40527C7C4276504A4006465ED6C4AA4C40
52518	16741	53.182761999999997	53.198016000000003	57.075062000000003	57.067160000000001	Школьная	0103000020E61000000100000005000000CC79C6BE64974A40B8CCE9B298884C40CC79C6BE64974A401096B1A19B894C40D90A9A9658994A401096B1A19B894C40D90A9A9658994A40B8CCE9B298884C40CC79C6BE64974A40B8CCE9B298884C40
53024	16816	53.24427	53.256532	57.212941999999998	57.201846000000003	Молодёжная	0103000020E610000001000000050000006CB2463D449F4A400A6AF816D6994C406CB2463D449F4A40F0F8F6AE419B4C405130630AD6A04A40F0F8F6AE419B4C405130630AD6A04A400A6AF816D6994C406CB2463D449F4A400A6AF816D6994C40
53137	16324	52.752298000000003	53.052219000000001	57.294026000000002	57.208896000000003	Молодёжная	0103000020E61000000100000005000000516C054D4B604A40F321A81ABD9A4C40516C054D4B604A403C16DBA4A2A54C406B9DB81CAF864A403C16DBA4A2A54C406B9DB81CAF864A40F321A81ABD9A4C40516C054D4B604A40F321A81ABD9A4C40
53025	16302	53.081890000000001	53.098329	57.210509000000002	57.198546	Молодежная	0103000020E610000001000000050000004AEF1B5F7B8A4A40356090F469994C404AEF1B5F7B8A4A40C0417BF5F19A4C40CB9F6F0B968C4A40C0417BF5F19A4C40CB9F6F0B968C4A40356090F469994C404AEF1B5F7B8A4A40356090F469994C40
52810	16929	53.387165000000003	53.408994	57.246046999999997	57.235770000000002	Советская	0103000020E61000000100000005000000F3936A9F8EB14A4060B01BB62D9E4C40F3936A9F8EB14A40B323D5777E9F4C404F2157EA59B44A40B323D5777E9F4C404F2157EA59B44A4060B01BB62D9E4C40F3936A9F8EB14A4060B01BB62D9E4C40
53240	16611	52.841329999999999	52.859251999999998	57.147336000000003	57.138795000000002	Молодежная	0103000020E61000000100000005000000649291B3B06B4A4096ECD808C4914C40649291B3B06B4A4001C3F2E7DB924C40E48233F8FB6D4A4001C3F2E7DB924C40E48233F8FB6D4A4096ECD808C4914C40649291B3B06B4A4096ECD808C4914C40
52701	16725	53.031486000000001	53.045769	57.019736000000002	57.009067999999999	Совхозная	0103000020E610000001000000050000001424B6BB07844A4056B8E52329814C401424B6BB07844A40E54691B586824C40D71533C2DB854A40E54691B586824C40D71533C2DB854A4056B8E52329814C401424B6BB07844A4056B8E52329814C40
52649	16206	53.007716000000002	53.046559999999999	57.304271999999997	57.285806000000001	Советская	0103000020E61000000100000005000000F6D37FD6FC804A4013807F4A95A44C40F6D37FD6FC804A40548B8862F2A64C40A0A696ADF5854A40548B8862F2A64C40A0A696ADF5854A4013807F4A95A44C40F6D37FD6FC804A4013807F4A95A44C40
53165	17011	53.410547999999999	53.445591	57.293185000000001	57.282017000000003	Советская	0103000020E6100000010000000500000017B83CD68CB44A4041F50F2219A44C4017B83CD68CB44A40C156091687A54C402B323A2009B94A40C156091687A54C402B323A2009B94A4041F50F2219A44C4017B83CD68CB44A4041F50F2219A44C40
53244	17210	52.970841	52.997565000000002	57.215626999999998	57.207278000000002	Советская	0103000020E61000000100000005000000D74E9484447C4A401497E315889A4C40D74E9484447C4A403A9160AA999B4C402F51BD35B07F4A403A9160AA999B4C402F51BD35B07F4A401497E315889A4C40D74E9484447C4A401497E315889A4C40
52936	17219	53.324894	53.361733000000001	57.144742999999998	57.134169	Пушиной	0103000020E610000001000000050000005455682096A94A408A9125732C914C405455682096A94A4097A949F086924C40267156444DAE4A4097A949F086924C40267156444DAE4A408A9125732C914C405455682096A94A408A9125732C914C40
53022	16534	52.566409999999998	52.592703999999998	57.319788000000003	57.309683	Центральная	0103000020E610000001000000050000004D10751F80484A4047904AB1A3A74C404D10751F80484A409ED32CD0EEA84C40AC1A84B9DD4B4A409ED32CD0EEA84C40AC1A84B9DD4B4A4047904AB1A3A74C404D10751F80484A4047904AB1A3A74C40
53242	17140	53.054222000000003	53.079914000000002	57.173932999999998	57.162146999999997	Ключевая	0103000020E61000000100000005000000A35C1ABFF0864A407F129F3BC1944C40A35C1ABFF0864A40FB58C16F43964C400C3F389F3A8A4A40FB58C16F43964C400C3F389F3A8A4A407F129F3BC1944C40A35C1ABFF0864A407F129F3BC1944C40
53019	15435	52.558424000000002	52.589084	57.282941000000001	57.274304999999998	Советская	0103000020E6100000010000000500000098A608707A474A408C101E6D1CA34C4098A608707A474A4049D9226937A44C40664CC11A674B4A4049D9226937A44C40664CC11A674B4A408C101E6D1CA34C4098A608707A474A408C101E6D1CA34C40
53135	16917	53.284829000000002	53.314500000000002	57.205508000000002	57.196340999999997	Центральная	0103000020E61000000100000005000000E8F9D34675A44A4095EEAEB321994C40E8F9D34675A44A407F880D164E9A4C40C74B378941A84A407F880D164E9A4C40C74B378941A84A4095EEAEB321994C40E8F9D34675A44A4095EEAEB321994C40
52931	16513	52.754399999999997	52.767426	57.277442999999998	57.269545999999998	Центральная	0103000020E610000001000000050000001B0DE02D90604A404162BB7B80A24C401B0DE02D90604A4087C0914083A34C40D00CE2033B624A4087C0914083A34C40D00CE2033B624A404162BB7B80A24C401B0DE02D90604A404162BB7B80A24C40
52698	14783	52.222230000000003	52.264217000000002	57.903775000000003	57.882860999999998	Первомайская	0103000020E6100000010000000500000055185B08721C4A40F9F4D89601F14C4055185B08721C4A40A1F831E6AEF34C400C06D7DCD1214A40A1F831E6AEF34C400C06D7DCD1214A40F9F4D89601F14C4055185B08721C4A40F9F4D89601F14C40
52721	14783	52.222230000000003	52.264217000000002	57.903775000000003	57.882860999999998	Майская	0103000020E6100000010000000500000055185B08721C4A40F9F4D89601F14C4055185B08721C4A40A1F831E6AEF34C400C06D7DCD1214A40A1F831E6AEF34C400C06D7DCD1214A40F9F4D89601F14C4055185B08721C4A40F9F4D89601F14C40
53235	14783	52.222230000000003	52.264217000000002	57.903775000000003	57.882860999999998	Вежеевская	0103000020E6100000010000000500000055185B08721C4A40F9F4D89601F14C4055185B08721C4A40A1F831E6AEF34C400C06D7DCD1214A40A1F831E6AEF34C400C06D7DCD1214A40F9F4D89601F14C4055185B08721C4A40F9F4D89601F14C40
53020	15456	52.128867999999997	52.153796	57.845148999999999	57.834513999999999	Центральная	0103000020E610000001000000050000001EC022BF7E104A40EE06D15AD1EA4C401EC022BF7E104A40A19FA9D72DEC4C40B8205B96AF134A40A19FA9D72DEC4C40B8205B96AF134A40EE06D15AD1EA4C401EC022BF7E104A40EE06D15AD1EA4C40
52862	15537	52.133889000000003	52.167316	58.028444999999998	58.006092000000002	Центральная	0103000020E61000000100000005000000A725564623114A403562669FC7004D40A725564623114A400B5EF415A4034D407C0C569C6A154A400B5EF415A4034D407C0C569C6A154A403562669FC7004D40A725564623114A403562669FC7004D40
52939	56392	52.246107000000002	52.27355	57.989260000000002	57.973416999999998	Новая	0103000020E610000001000000050000008928266F801F4A406A2FA2ED98FC4C408928266F801F4A40D89E5912A0FE4C4010E9B7AF03234A40D89E5912A0FE4C4010E9B7AF03234A406A2FA2ED98FC4C408928266F801F4A406A2FA2ED98FC4C40
52699	15238	51.937534999999997	51.985658000000001	57.907685999999998	57.890099999999997	Советская	0103000020E610000001000000050000007CED992501F84940B515FBCBEEF14C407CED992501F84940BE840A0E2FF44C403885950A2AFE4940BE840A0E2FF44C403885950A2AFE4940B515FBCBEEF14C407CED992501F84940B515FBCBEEF14C40
53237	15642	52.251685000000002	52.277458000000003	57.961956000000001	57.951278000000002	Средняя	0103000020E6100000010000000500000067F2CD3637204A40C0B33D7AC3F94C4067F2CD3637204A407218CC5F21FB4C40BD0166BE83234A407218CC5F21FB4C40BD0166BE83234A40C0B33D7AC3F94C4067F2CD3637204A40C0B33D7AC3F94C40
52720	15730	52.344859	52.375329000000001	57.962967999999996	57.945714000000002	Центральная	0103000020E610000001000000050000009A5DF756242C4A4047AF06280DF94C409A5DF756242C4A40198C118942FB4C40C51EDAC70A304A40198C118942FB4C40C51EDAC70A304A4047AF06280DF94C409A5DF756242C4A4047AF06280DF94C40
53248	56414	52.038542	52.052411999999997	57.985461999999998	57.972304999999999	Центральная	0103000020E61000000100000005000000DFC2BAF1EE044A405F5E807D74FC4C40DFC2BAF1EE044A40B2B96A9E23FE4C407FF5B86FB5064A40B2B96A9E23FE4C407FF5B86FB5064A405F5E807D74FC4C40DFC2BAF1EE044A405F5E807D74FC4C40
52959	15920	52.484771000000002	52.510722999999999	57.883310999999999	57.874333	Молодежная	0103000020E610000001000000050000004D86E3F90C3E4A402368CC24EAEF4C404D86E3F90C3E4A403999B85510F14C4052280B5F5F414A403999B85510F14C4052280B5F5F414A402368CC24EAEF4C404D86E3F90C3E4A402368CC24EAEF4C40
52930	15174	52.000328000000003	52.011178999999998	57.971021	57.959358000000002	Центральная	0103000020E61000000100000005000000F5A276BF0A004A40F793313ECCFA4C40F5A276BF0A004A40575D876A4AFC4C4074B33F506E014A40575D876A4AFC4C4074B33F506E014A40F793313ECCFA4C40F5A276BF0A004A40F793313ECCFA4C40
53021	14958	52.206186000000002	52.222372999999997	57.818913999999999	57.808190000000003	Молодежная	0103000020E610000001000000050000005072874D641A4A40257A19C572E74C405072874D641A4A40471E882CD2E84C40B741EDB7761C4A40471E882CD2E84C40B741EDB7761C4A40257A19C572E74C405072874D641A4A40257A19C572E74C40
53018	15340	51.931553000000001	51.952069999999999	57.837944999999998	57.831074000000001	Лесная	0103000020E61000000100000005000000CFBEF2203DF74940284701A260EA4C40CFBEF2203DF74940616C21C841EB4C4059C0046EDDF94940616C21C841EB4C4059C0046EDDF94940284701A260EA4C40CFBEF2203DF74940284701A260EA4C40
53238	15807	52.409689999999998	52.440314000000001	57.864615999999998	57.846127000000003	Школьная	0103000020E61000000100000005000000C6BFCFB870344A409DA1B8E34DEC4C40C6BFCFB870344A4096CCB1BCABEE4C4048FC8A355C384A4096CCB1BCABEE4C4048FC8A355C384A409DA1B8E34DEC4C40C6BFCFB870344A409DA1B8E34DEC4C40
53132	15837	52.323604000000003	52.343673000000003	57.827584999999999	57.816062000000002	Центральная	0103000020E610000001000000050000006A6D1ADB6B294A4012C138B874E84C406A6D1ADB6B294A4080D4264EEEE94C4055C2137AFD2B4A4080D4264EEEE94C4055C2137AFD2B4A4012C138B874E84C406A6D1ADB6B294A4012C138B874E84C40
53143	15259	52.049430000000001	52.071078999999997	57.894098999999997	57.882458999999997	Советская	0103000020E610000001000000050000007CB8E4B853064A40CA87A06AF4F04C407CB8E4B853064A40723106D671F24C405837DE1D19094A40723106D671F24C405837DE1D19094A40CA87A06AF4F04C407CB8E4B853064A40CA87A06AF4F04C40
52717	15634	52.217010000000002	52.234985999999999	58.038108000000001	58.019437000000003	Школьная	0103000020E61000000100000005000000D673D2FBC61B4A408BAA5FE97C024D40D673D2FBC61B4A40A5DB12B9E0044D4049827005141E4A40A5DB12B9E0044D4049827005141E4A408BAA5FE97C024D40D673D2FBC61B4A408BAA5FE97C024D40
53236	15346	52.084418999999997	52.107630999999998	57.816757000000003	57.805332	Молодежная	0103000020E610000001000000050000009C14E63DCE0A4A400D36751E15E74C409C14E63DCE0A4A40B9E34D7E8BE84C40948444DAC60D4A40B9E34D7E8BE84C40948444DAC60D4A400D36751E15E74C409C14E63DCE0A4A400D36751E15E74C40
53239	16001	52.385292	52.404525	57.897567000000002	57.882252999999999	Луговая	0103000020E6100000010000000500000089B48D3F51314A4021E692AAEDF04C4089B48D3F51314A40037CB779E3F24C400BB5A679C7334A40037CB779E3F24C400BB5A679C7334A4021E692AAEDF04C4089B48D3F51314A4021E692AAEDF04C40
52430	14120	53.849401999999998	53.888299000000004	57.320400999999997	57.279443000000001	Советская	0103000020E6100000010000000500000018946934B9EC4A404E0CC9C9C4A34C4018946934B9EC4A40874D64E602A94C40E60819C8B3F14A40874D64E602A94C40E60819C8B3F14A404E0CC9C9C4A34C4018946934B9EC4A404E0CC9C9C4A34C40
52648	14120	53.849401999999998	53.888299000000004	57.320400999999997	57.279443000000001	Ленина	0103000020E6100000010000000500000018946934B9EC4A404E0CC9C9C4A34C4018946934B9EC4A40874D64E602A94C40E60819C8B3F14A40874D64E602A94C40E60819C8B3F14A404E0CC9C9C4A34C4018946934B9EC4A404E0CC9C9C4A34C40
52509	14120	53.849401999999998	53.888299000000004	57.320400999999997	57.279443000000001	Коммунальная	0103000020E6100000010000000500000018946934B9EC4A404E0CC9C9C4A34C4018946934B9EC4A40874D64E602A94C40E60819C8B3F14A40874D64E602A94C40E60819C8B3F14A404E0CC9C9C4A34C4018946934B9EC4A404E0CC9C9C4A34C40
53126	13718	54.021653999999998	54.053319000000002	57.235332	57.215271999999999	Центральная	0103000020E61000000100000005000000EEE9EA8EC5024B404CDF6B088E9B4C40EEE9EA8EC5024B40E4D9E55B1F9E4C40B2A03028D3064B40E4D9E55B1F9E4C40B2A03028D3064B404CDF6B088E9B4C40EEE9EA8EC5024B404CDF6B088E9B4C40
53136	14692	53.946356999999999	53.966344999999997	57.306052000000001	57.295276000000001	Азина	0103000020E610000001000000050000009BABE63922F94A4098A59D9ACBA54C409BABE63922F94A400D7041B62CA74C4099D36531B1FB4A400D7041B62CA74C4099D36531B1FB4A4098A59D9ACBA54C409BABE63922F94A4098A59D9ACBA54C40
53131	14486	53.648781	53.669325999999998	57.405748000000003	57.391941000000003	Школьная	0103000020E6100000010000000500000012A27C410BD34A40147B681F2BB24C4012A27C410BD34A406E35EB8CEFB34C40662E7079ACD54A406E35EB8CEFB34C40662E7079ACD54A40147B681F2BB24C4012A27C410BD34A40147B681F2BB24C40
53140	14479	53.512856999999997	53.527597999999998	57.332538999999997	57.319861000000003	Молодежная	0103000020E610000001000000050000002843554CA5C14A4008228B34F1A84C402843554CA5C14A4080D250A390AA4C40AEB7CD5488C34A4080D250A390AA4C40AEB7CD5488C34A4008228B34F1A84C402843554CA5C14A4008228B34F1A84C40
52715	13255	53.748054000000003	53.770727000000001	57.223863000000001	57.211542999999999	Школьная	0103000020E610000001000000050000002DD2C43BC0DF4A404F594DD7139B4C402DD2C43BC0DF4A4069E4F38AA79C4C407592AD2EA7E24A4069E4F38AA79C4C407592AD2EA7E24A404F594DD7139B4C402DD2C43BC0DF4A404F594DD7139B4C40
53246	56412	53.757854999999999	53.777492000000002	57.353681000000002	57.340922999999997	Колхозная	0103000020E61000000100000005000000170E846401E14A4023BA675DA3AB4C40170E846401E14A40B91B446B45AD4C4069739CDB84E34A40B91B446B45AD4C4069739CDB84E34A4023BA675DA3AB4C40170E846401E14A4023BA675DA3AB4C40
52716	14098	53.497765000000001	53.544837000000001	57.268962000000002	57.247123000000002	Центральная	0103000020E61000000100000005000000F60B76C3B6BF4A40728BF9B9A19F4C40F60B76C3B6BF4A40F2EEC8586DA24C404C530438BDC54A40F2EEC8586DA24C404C530438BDC54A40728BF9B9A19F4C40F60B76C3B6BF4A40728BF9B9A19F4C40
75052	13814	53.915024000000003	53.932971999999999	57.244999999999997	57.228112000000003	Тамбырь	0103000020E610000001000000050000000E87A5811FF54A409FE925C6329D4C400E87A5811FF54A408FC2F5285C9F4C40B70A62A06BF74A408FC2F5285C9F4C40B70A62A06BF74A409FE925C6329D4C400E87A5811FF54A409FE925C6329D4C40
52828	13261	53.944308999999997	53.971411000000003	57.285223000000002	57.264090000000003	Центральная	0103000020E61000000100000005000000C328081EDFF84A40AF997CB3CDA14C40C328081EDFF84A409488F02F82A44C40C2FC153257FC4A409488F02F82A44C40C2FC153257FC4A40AF997CB3CDA14C40C328081EDFF84A40AF997CB3CDA14C40
53017	14036	53.654701000000003	53.682198	57.236510000000003	57.216504999999998	Школьная	0103000020E610000001000000050000004AD40B3ECDD34A40D235936FB69B4C404AD40B3ECDD34A40A796ADF5459E4C40C4B2994352D74A40A796ADF5459E4C40C4B2994352D74A40D235936FB69B4C404AD40B3ECDD34A40D235936FB69B4C40
53139	13626	54.076011000000001	54.101002000000001	57.332003999999998	57.314335	Садовая	0103000020E6100000010000000500000071917BBABA094B407C7E18213CA84C4071917BBABA094B401212691B7FAA4C40516A2FA2ED0C4B401212691B7FAA4C40516A2FA2ED0C4B407C7E18213CA84C4071917BBABA094B407C7E18213CA84C40
52806	14409	53.578730999999998	53.595250999999998	57.303027	57.286166000000001	Молодежная	0103000020E6100000010000000500000037177FDB13CA4A40139D6516A1A44C4037177FDB13CA4A400A67B796C9A64C40A5F44C2F31CC4A400A67B796C9A64C40A5F44C2F31CC4A40139D6516A1A44C4037177FDB13CA4A40139D6516A1A44C40
52932	13817	53.841245000000001	53.863128000000003	57.216450999999999	57.206741000000001	Камышево	0103000020E61000000100000005000000367689EAADEB4A4005DF347D769A4C40367689EAADEB4A40DF1797AAB49B4C40862172FA7AEE4A40DF1797AAB49B4C40862172FA7AEE4A4005DF347D769A4C40367689EAADEB4A4005DF347D769A4C40
52845	14319	53.822083999999997	53.841802000000001	57.371462000000001	57.355142000000001	Центральная	0103000020E610000001000000050000004D486B0C3AE94A40D0B7054B75AD4C404D486B0C3AE94A4077DA1A118CAF4C408CDAFD2AC0EB4A4077DA1A118CAF4C408CDAFD2AC0EB4A40D0B7054B75AD4C404D486B0C3AE94A40D0B7054B75AD4C40
53234	14587	53.587434999999999	53.612732000000001	57.355001000000001	57.343454000000001	Центральная	0103000020E610000001000000050000004CC3F01131CB4A4017D7F84CF6AB4C404CC3F01131CB4A400E863AAC70AD4C40399B8E006ECE4A400E863AAC70AD4C40399B8E006ECE4A4017D7F84CF6AB4C404CC3F01131CB4A4017D7F84CF6AB4C40
53230	13911	54.022489	54.046007000000003	57.315005999999997	57.300454999999999	Родниковая	0103000020E6100000010000000500000087C267EBE0024B40B875374F75A64C4087C267EBE0024B409A05DA1D52A84C408C31B08EE3054B409A05DA1D52A84C408C31B08EE3054B40B875374F75A64C4087C267EBE0024B40B875374F75A64C40
53014	13442	54.033088999999997	54.066237000000001	57.423372999999998	57.407691999999997	Школьный переулок	0103000020E61000000100000005000000BD6DA6423C044B40A06B5F402FB44C40BD6DA6423C044B403481221631B64C4080643A747A084B403481221631B64C4080643A747A084B40A06B5F402FB44C40BD6DA6423C044B40A06B5F402FB44C40
53228	13654	54.046196000000002	54.069471	57.282586000000002	57.264090000000003	Пушкинская	0103000020E610000001000000050000005F9A22C0E9054B40AF997CB3CDA14C405F9A22C0E9054B405B272EC72BA44C409D82FC6CE4084B405B272EC72BA44C409D82FC6CE4084B40AF997CB3CDA14C405F9A22C0E9054B40AF997CB3CDA14C40
52696	13443	54.015383999999997	54.044929000000003	57.482691000000003	57.466071999999997	Мира	0103000020E61000000100000005000000DA70581AF8014B4068CA4E3FA8BB4C40DA70581AF8014B406A8995D1C8BD4C402DD2C43BC0054B406A8995D1C8BD4C402DD2C43BC0054B4068CA4E3FA8BB4C40DA70581AF8014B4068CA4E3FA8BB4C40
52697	13936	53.561168000000002	53.595348999999999	57.202587999999999	57.188386999999999	Поселковская	0103000020E61000000100000005000000E7C75F5AD4C74A40EBFEB1101D984C40E7C75F5AD4C74A40F1475167EE994C40685A626534CC4A40F1475167EE994C40685A626534CC4A40EBFEB1101D984C40E7C75F5AD4C74A40EBFEB1101D984C40
52807	14705	53.710512999999999	53.730356999999998	57.313766000000001	57.297916999999998	Мира	0103000020E6100000010000000500000001310917F2DA4A4012F6ED2422A64C4001310917F2DA4A40624CFA7B29A84C40CCB392567CDD4A40624CFA7B29A84C40CCB392567CDD4A4012F6ED2422A64C4001310917F2DA4A4012F6ED2422A64C40
52994	13372	54.149808	54.178545	57.444690000000001	57.432347	Школьный переулок	0103000020E61000000100000005000000EF5696E82C134B4009C3802557B74C40EF5696E82C134B40DB6D179AEBB84C40A2EE0390DA164B40DB6D179AEBB84C40A2EE0390DA164B4009C3802557B74C40EF5696E82C134B4009C3802557B74C40
53130	14666	53.965221999999997	53.984949	57.367986999999999	57.355423999999999	Степанова	0103000020E610000001000000050000009AB0FD648CFB4A40541B9C887EAD4C409AB0FD648CFB4A40342DB1321AAF4C402C9D0FCF12FE4A40342DB1321AAF4C402C9D0FCF12FE4A40541B9C887EAD4C409AB0FD648CFB4A40541B9C887EAD4C40
53015	13530	54.081006000000002	54.104694000000002	57.500714000000002	57.491509999999998	Труда	0103000020E61000000100000005000000D06394675E0A4B4017D4B7CCE9BE4C40D06394675E0A4B401E53776517C04C40310BED9C660D4B401E53776517C04C40310BED9C660D4B4017D4B7CCE9BE4C40D06394675E0A4B4017D4B7CCE9BE4C40
52530	56367	53.298259000000002	53.305821999999999	56.873199999999997	56.839123999999998	Союзная	0103000020E610000001000000050000006C5ED5592DA64A40F4A44C6A686B4C406C5ED5592DA64A40006F8104C56F4C40DB32E02C25A74A40006F8104C56F4C40DB32E02C25A74A40F4A44C6A686B4C406C5ED5592DA64A40F4A44C6A686B4C40
53223	11941	52.208511999999999	52.233252	56.866101	56.856692000000002	Центральная	0103000020E610000001000000050000006A696E85B01A4A40575F5D15A86D4C406A696E85B01A4A403604C765DC6E4C4001DD9733DB1D4A403604C765DC6E4C4001DD9733DB1D4A40575F5D15A86D4C406A696E85B01A4A40575F5D15A86D4C40
53124	12460	52.647087999999997	52.674467999999997	57.121394000000002	57.106135999999999	Нагорная	0103000020E6100000010000000500000028D192C7D3524A40D1764CDD958D4C4028D192C7D3524A401FF7ADD6898F4C406919A9F754564A401FF7ADD6898F4C406919A9F754564A40D1764CDD958D4C4028D192C7D3524A40D1764CDD958D4C40
52714	12754	52.135722000000001	52.158107999999999	57.060156999999997	57.048124000000001	Пислегина	0103000020E6100000010000000500000082ACA7565F114A408C135FED28864C4082ACA7565F114A400FD07D39B3874C40349E08E23C144A400FD07D39B3874C40349E08E23C144A408C135FED28864C4082ACA7565F114A408C135FED28864C40
52802	12047	52.101685000000003	52.12567	56.980483	56.965344000000002	Добровольского	0103000020E6100000010000000500000034BF9A03040D4A40E6B16664907B4C4034BF9A03040D4A4059A48977807D4C404E0B5EF415104A4059A48977807D4C404E0B5EF415104A40E6B16664907B4C4034BF9A03040D4A40E6B16664907B4C40
52647	12832	52.151989999999998	52.211576000000001	57.011029000000001	56.964965999999997	Энгельса	0103000020E61000000100000005000000D6A8876874134A403FE08101847B4C40D6A8876874134A405F27F56569814C402B4F20EC141B4A405F27F56569814C402B4F20EC141B4A403FE08101847B4C40D6A8876874134A403FE08101847B4C40
52439	12832	52.151989999999998	52.211576000000001	57.011029000000001	56.964965999999997	Селтинская	0103000020E61000000100000005000000D6A8876874134A403FE08101847B4C40D6A8876874134A405F27F56569814C402B4F20EC141B4A405F27F56569814C402B4F20EC141B4A403FE08101847B4C40D6A8876874134A403FE08101847B4C40
52805	12832	52.151989999999998	52.211576000000001	57.011029000000001	56.964965999999997	Курчатова	0103000020E61000000100000005000000D6A8876874134A403FE08101847B4C40D6A8876874134A405F27F56569814C402B4F20EC141B4A405F27F56569814C402B4F20EC141B4A403FE08101847B4C40D6A8876874134A403FE08101847B4C40
52924	12832	52.151989999999998	52.211576000000001	57.011029000000001	56.964965999999997	Курортная	0103000020E61000000100000005000000D6A8876874134A403FE08101847B4C40D6A8876874134A405F27F56569814C402B4F20EC141B4A405F27F56569814C402B4F20EC141B4A403FE08101847B4C40D6A8876874134A403FE08101847B4C40
52506	12832	52.151989999999998	52.211576000000001	57.011029000000001	56.964965999999997	Калинина	0103000020E61000000100000005000000D6A8876874134A403FE08101847B4C40D6A8876874134A405F27F56569814C402B4F20EC141B4A405F27F56569814C402B4F20EC141B4A403FE08101847B4C40D6A8876874134A403FE08101847B4C40
52515	12832	52.151989999999998	52.211576000000001	57.011029000000001	56.964965999999997	Заводская	0103000020E61000000100000005000000D6A8876874134A403FE08101847B4C40D6A8876874134A405F27F56569814C402B4F20EC141B4A405F27F56569814C402B4F20EC141B4A403FE08101847B4C40D6A8876874134A403FE08101847B4C40
52923	12122	52.004334	52.021428999999998	57.053421999999998	57.041823000000001	Удмуртская	0103000020E6100000010000000500000064213A048E004A403D9CC0745A854C4064213A048E004A4086713788D6864C40CE177B2FBE024A4086713788D6864C40CE177B2FBE024A403D9CC0745A854C4064213A048E004A403D9CC0745A854C40
52695	12089	52.056356000000001	52.099133000000002	56.932304999999999	56.902054	Советская	0103000020E61000000100000005000000797764AC36074A40ED9C668176734C40797764AC36074A40DA722EC555774C40297AE063B00C4A40DA722EC555774C40297AE063B00C4A40ED9C668176734C40797764AC36074A40ED9C668176734C40
53233	12627	52.439208999999998	52.460912	57.124926000000002	57.111459000000004	Школьная	0103000020E61000000100000005000000EF8D210038384A4025ECDB49448E4C40EF8D210038384A40C6353E93FD8F4C40BF2A172AFF3A4A40C6353E93FD8F4C40BF2A172AFF3A4A4025ECDB49448E4C40EF8D210038384A4025ECDB49448E4C40
52712	12182	52.136611000000002	52.173262000000001	57.104948	57.084048000000003	Пислегина	0103000020E610000001000000050000000EA320787C114A40A9A5B915C28A4C400EA320787C114A40EBE3A1EF6E8D4C40DDD1FF722D164A40EBE3A1EF6E8D4C40DDD1FF722D164A40A9A5B915C28A4C400EA320787C114A40A9A5B915C28A4C40
53158	11593	52.492595000000001	52.509708000000003	56.702134999999998	56.691018999999997	Садовая	0103000020E6100000010000000500000029965B5A0D3F4A4012F5824F73584C4029965B5A0D3F4A404030478FDF594C403A419B1C3E414A404030478FDF594C403A419B1C3E414A4012F5824F73584C4029965B5A0D3F4A4012F5824F73584C40
52978	12341	52.218502000000001	52.242486999999997	57.143360999999999	57.133803	Труда	0103000020E61000000100000005000000280EA0DFF71B4A40A88DEA7420914C40280EA0DFF71B4A40CC423BA759924C40425A63D0091F4A40CC423BA759924C40425A63D0091F4A40A88DEA7420914C40280EA0DFF71B4A40A88DEA7420914C40
52928	12661	52.568072000000001	52.596916999999998	56.997951	56.970005	Линейная	0103000020E61000000100000005000000FCE25295B6484A406EFAB31F297C4C40FCE25295B6484A405801BEDBBC7F4C4095B6B8C6674C4A405801BEDBBC7F4C4095B6B8C6674C4A406EFAB31F297C4C40FCE25295B6484A406EFAB31F297C4C40
52822	11758	52.330539000000002	52.390179000000003	56.775052000000002	56.748280999999999	Садовая	0103000020E61000000100000005000000BA86191A4F2A4A40ED9BFBABC75F4C40BA86191A4F2A4A40865968E734634C40024BAE62F1314A40865968E734634C40024BAE62F1314A40ED9BFBABC75F4C40BA86191A4F2A4A40ED9BFBABC75F4C40
52645	11758	52.330539000000002	52.390179000000003	56.775052000000002	56.748280999999999	Переулок Школьный	0103000020E61000000100000005000000BA86191A4F2A4A40ED9BFBABC75F4C40BA86191A4F2A4A40865968E734634C40024BAE62F1314A40865968E734634C40024BAE62F1314A40ED9BFBABC75F4C40BA86191A4F2A4A40ED9BFBABC75F4C40
52826	12258	52.271906000000001	52.299259999999997	57.162712999999997	57.140234999999997	Советская	0103000020E6100000010000000500000008CBD8D0CD224A4095607138F3914C4008CBD8D0CD224A4028D192C7D3944C401F80D4264E264A4028D192C7D3944C401F80D4264E264A4095607138F3914C4008CBD8D0CD224A4095607138F3914C40
53229	12546	52.520614000000002	52.538570999999997	57.068970999999998	57.052824000000001	Школьная	0103000020E610000001000000050000007DEBC37AA3424A40D238D4EFC2864C407DEBC37AA3424A40ABAFAE0AD4884C4079C9FFE4EF444A40ABAFAE0AD4884C4079C9FFE4EF444A40D238D4EFC2864C407DEBC37AA3424A40D238D4EFC2864C40
53227	56411	51.952322000000002	51.978067000000003	57.109259000000002	57.093228000000003	Школьная	0103000020E6100000010000000500000073A1F2AFE5F94940278925E5EE8B4C4073A1F2AFE5F9494097E5EB32FC8D4C40FF25A94C31FD494097E5EB32FC8D4C40FF25A94C31FD4940278925E5EE8B4C4073A1F2AFE5F94940278925E5EE8B4C40
52925	12441	52.369131000000003	52.402943999999998	57.207135999999998	57.196195000000003	Центральная	0103000020E610000001000000050000004B7842AF3F2F4A40C251F2EA1C994C404B7842AF3F2F4A4081E9B46E839A4C40490F43AB93334A4081E9B46E839A4C40490F43AB93334A40C251F2EA1C994C404B7842AF3F2F4A40C251F2EA1C994C40
53161	11645	52.443843999999999	52.455863000000001	56.728228000000001	56.717450999999997	Зеленая	0103000020E610000001000000050000004E4354E1CF384A40C2BD326FD55B4C404E4354E1CF384A4008043A93365D4C406D3A02B8593A4A4008043A93365D4C406D3A02B8593A4A40C2BD326FD55B4C404E4354E1CF384A40C2BD326FD55B4C40
52668	11844	52.434690000000003	52.471089999999997	56.874429999999997	56.859650000000002	Школьная	0103000020E61000000100000005000000FAF202ECA3374A40D200DE02096E4C40FAF202ECA3374A4015527E52ED6F4C407FBC57AD4C3C4A4015527E52ED6F4C407FBC57AD4C3C4A40D200DE02096E4C40FAF202ECA3374A40D200DE02096E4C40
52988	11565	52.295299	52.319284000000003	56.813048999999999	56.801912999999999	Школьная	0103000020E6100000010000000500000050C58D5BCC254A405E9ECE15A5664C4050C58D5BCC254A40D38558FD11684C406B11514CDE284A40D38558FD11684C406B11514CDE284A405E9ECE15A5664C4050C58D5BCC254A405E9ECE15A5664C40
52713	11669	52.575609	52.596989000000001	56.751187999999999	56.724435	Советская	0103000020E610000001000000050000004224438EAD494A40F4893C49BA5C4C404224438EAD494A40E692AAED26604C402F89B3226A4C4A40E692AAED26604C402F89B3226A4C4A40F4893C49BA5C4C404224438EAD494A40F4893C49BA5C4C40
52922	11964	52.144255999999999	52.164206999999998	56.887594999999997	56.872137000000002	Школьная	0103000020E610000001000000050000003A2009FB76124A40D7506A2FA26F4C403A2009FB76124A40EB8B84B69C714C401B6327BC04154A40EB8B84B69C714C401B6327BC04154A40D7506A2FA26F4C403A2009FB76124A40D7506A2FA26F4C40
52711	12523	52.362231999999999	52.401246	56.989846	56.978937999999999	Азина	0103000020E6100000010000000500000047C8409E5D2E4A40E46723D74D7D4C4047C8409E5D2E4A40C8091346B37E4C404ED367075C334A40C8091346B37E4C404ED367075C334A40E46723D74D7D4C4047C8409E5D2E4A40E46723D74D7D4C40
53232	12807	52.09572	52.106355999999998	57.094763999999998	57.086064	Клубная	0103000020E610000001000000050000005CC98E8D400C4A4075AE2825048B4C405CC98E8D400C4A40486B0C3A218C4C40DFDDCA129D0D4A40486B0C3A218C4C40DFDDCA129D0D4A4075AE2825048B4C405CC98E8D400C4A4075AE2825048B4C40
53199	11868	52.473300000000002	52.491624999999999	56.915657000000003	56.902358999999997	Советская	0103000020E6100000010000000500000031992A18953C4A402920ED7F80734C4031992A18953C4A403FADA23F34754C40B0726891ED3E4A403FADA23F34754C40B0726891ED3E4A402920ED7F80734C4031992A18953C4A402920ED7F80734C40
52626	25825	52.305674000000003	52.335057999999997	56.687519000000002	56.674574999999997	Ленина	0103000020E61000000100000005000000679E5C5320274A407FD93D7958564C40679E5C5320274A407730629F00584C40AF21382EE32A4A407730629F00584C40AF21382EE32A4A407FD93D7958564C40679E5C5320274A407FD93D7958564C40
52801	11501	52.255521000000002	52.28716	56.722825	56.707935999999997	Клубная	0103000020E610000001000000050000007A3881E9B4204A409DD497A59D5A4C407A3881E9B4204A4098DD9387855C4C40145CACA8C1244A4098DD9387855C4C40145CACA8C1244A409DD497A59D5A4C407A3881E9B4204A409DD497A59D5A4C40
52929	56391	51.4236	51.460394999999998	56.952784999999999	56.93674	Первомайская	0103000020E61000000100000005000000F54A598638B64940726DA818E7774C40F54A598638B64940478FDFDBF4794C40F71E2E39EEBA4940478FDFDBF4794C40F71E2E39EEBA4940726DA818E7774C40F54A598638B64940726DA818E7774C40
52804	10389	51.581361999999999	51.657297	57.124189000000001	57.098157	Советская	0103000020E610000001000000050000008E91EC116ACA4940CE6F9868908C4C408E91EC116ACA4940F0C2D66CE58F4C402461DF4E22D44940F0C2D66CE58F4C402461DF4E22D44940CE6F9868908C4C408E91EC116ACA4940CE6F9868908C4C40
52512	10389	51.581361999999999	51.657297	57.124189000000001	57.098157	Партизанская	0103000020E610000001000000050000008E91EC116ACA4940CE6F9868908C4C408E91EC116ACA4940F0C2D66CE58F4C402461DF4E22D44940F0C2D66CE58F4C402461DF4E22D44940CE6F9868908C4C408E91EC116ACA4940CE6F9868908C4C40
52819	10389	51.581361999999999	51.657297	57.124189000000001	57.098157	Лесная	0103000020E610000001000000050000008E91EC116ACA4940CE6F9868908C4C408E91EC116ACA4940F0C2D66CE58F4C402461DF4E22D44940F0C2D66CE58F4C402461DF4E22D44940CE6F9868908C4C408E91EC116ACA4940CE6F9868908C4C40
52694	11120	51.427337000000001	51.442213000000002	57.120274999999999	57.110398000000004	пер. Торфяной	0103000020E6100000010000000500000075AF93FAB2B649409CC58B85218E4C4075AF93FAB2B6494061C3D32B658F4C40DB6E826F9AB8494061C3D32B658F4C40DB6E826F9AB849409CC58B85218E4C4075AF93FAB2B649409CC58B85218E4C40
53152	11097	51.401879000000001	51.420904999999998	56.959454999999998	56.947670000000002	Колхозная	0103000020E610000001000000050000007FF964C570B349403EB324404D794C407FF964C570B34940E97DE36BCF7A4C4087DC0C37E0B54940E97DE36BCF7A4C4087DC0C37E0B549403EB324404D794C407FF964C570B349403EB324404D794C40
52951	10654	51.749509000000003	51.769936999999999	57.170985000000002	57.164411999999999	Маркеловская	0103000020E61000000100000005000000628731E9EFDF4940F488D1730B954C40628731E9EFDF4940A48D23D6E2954C407C7DAD4B8DE24940A48D23D6E2954C407C7DAD4B8DE24940F488D1730B954C40628731E9EFDF4940F488D1730B954C40
53046	11284	51.516207999999999	51.532099000000002	57.347299999999997	57.339218000000002	Первомайская	0103000020E610000001000000050000007FF78E1A13C24940761BD47E6BAB4C407FF78E1A13C249404DF38E5374AC4C40FE9DEDD11BC449404DF38E5374AC4C40FE9DEDD11BC44940761BD47E6BAB4C407FF78E1A13C24940761BD47E6BAB4C40
53037	10739	51.830007000000002	51.869236999999998	57.152310999999997	57.137563999999998	Лекшурская	0103000020E61000000100000005000000BD395CAB3DEA4940B08D78B29B914C40BD395CAB3DEA494018E945ED7E934C4090BC732843EF494018E945ED7E934C4090BC732843EF4940B08D78B29B914C40BD395CAB3DEA4940B08D78B29B914C40
52428	11385	51.307304000000002	51.355265000000003	57.025188999999997	56.993749000000001	Пушкинская	0103000020E610000001000000050000000AF7CABC55A7494063B7CF2A337F4C400AF7CABC55A74940069CA56439834C40EC34D25279AD4940069CA56439834C40EC34D25279AD494063B7CF2A337F4C400AF7CABC55A7494063B7CF2A337F4C40
52927	11181	51.349777000000003	51.368119999999998	57.184972999999999	57.176602000000003	Школьная	0103000020E610000001000000050000004EF2237EC5AC49404034F3E49A964C404EF2237EC5AC49404ED2FC31AD974C407380608E1EAF49404ED2FC31AD974C407380608E1EAF49404034F3E49A964C404EF2237EC5AC49404034F3E49A964C40
53043	10932	51.575425000000003	51.590597000000002	56.980257999999999	56.968062000000003	Центральная	0103000020E610000001000000050000008126C286A7C949400C40A374E97B4C408126C286A7C9494039D21918797D4C40D00EB8AE98CB494039D21918797D4C40D00EB8AE98CB49400C40A374E97B4C408126C286A7C949400C40A374E97B4C40
53156	11456	51.357880000000002	51.379161000000003	57.034565000000001	57.024870999999997	Балминская	0103000020E610000001000000050000003DF20703CFAD494035CF11F92E834C403DF20703CFAD49400A4B3CA06C844C409775FF5888B049400A4B3CA06C844C409775FF5888B0494035CF11F92E834C403DF20703CFAD494035CF11F92E834C40
52926	10212	52.201335	52.234779000000003	57.249153	57.234361999999997	Родниковая	0103000020E6100000010000000500000024456458C5194A406BB6F292FF9D4C4024456458C5194A40A359D93EE49F4C40D064FF3C0D1E4A40A359D93EE49F4C40D064FF3C0D1E4A406BB6F292FF9D4C4024456458C5194A406BB6F292FF9D4C40
53056	9784	52.228400999999998	52.264864000000003	57.276435999999997	57.267116999999999	Молодежная	0103000020E61000000100000005000000D5AF743E3C1D4A40529ACDE330A24C40D5AF743E3C1D4A40F1B73D4162A34C40A2F14410E7214A40F1B73D4162A34C40A2F14410E7214A40529ACDE330A24C40D5AF743E3C1D4A40529ACDE330A24C40
52690	9679	51.900973999999998	51.930753000000003	57.217323	57.197330999999998	Советская	0103000020E61000000100000005000000ED45B41D53F3494055BE672442994C40ED45B41D53F3494095D5743DD19B4C40B3D30FEA22F7494095D5743DD19B4C40B3D30FEA22F7494055BE672442994C40ED45B41D53F3494055BE672442994C40
53260	56418	51.446075999999998	52.569563000000002	57.586995999999999	57.126299000000003	Школьная улица	0103000020E61000000100000005000000E7C3B30419B949403E42CD902A904C40E7C3B30419B94940007157AF22CB4C407E01BD70E7484A40007157AF22CB4C407E01BD70E7484A403E42CD902A904C40E7C3B30419B949403E42CD902A904C40
52921	10173	52.414828	52.447698000000003	57.363667	57.348771999999997	Советская	0103000020E6100000010000000500000088BB7A1519354A4058E1968FA4AC4C4088BB7A1519354A4035D1E7A38CAE4C40083E062B4E394A4035D1E7A38CAE4C40083E062B4E394A4058E1968FA4AC4C4088BB7A1519354A4058E1968FA4AC4C40
52949	9991	52.073442	52.097884999999998	57.235048999999997	57.225636999999999	Пушкинская	0103000020E610000001000000050000009013268C66094A403FE257ACE19C4C409013268C66094A408FFAEB15169E4C406DE2E47E870C4A408FFAEB15169E4C406DE2E47E870C4A403FE257ACE19C4C409013268C66094A403FE257ACE19C4C40
52818	555	51.764457	51.774769999999997	57.370356000000001	57.364255	Молодежная	0103000020E6100000010000000500000061191BBAD9E14940C63368E89FAE4C4061191BBAD9E149404EF04DD367AF4C4001F6D1A92BE349404EF04DD367AF4C4001F6D1A92BE34940C63368E89FAE4C4061191BBAD9E14940C63368E89FAE4C40
52425	10015	52.088991	52.151415	57.325750999999997	57.296477000000003	Юбилейная	0103000020E61000000100000005000000B5519D0E640B4A40138255F5F2A54C40B5519D0E640B4A40D4D17135B2A94C40DA8F149161134A40D4D17135B2A94C40DA8F149161134A40138255F5F2A54C40B5519D0E640B4A40138255F5F2A54C40
52643	10015	52.088991	52.151415	57.325750999999997	57.296477000000003	Ленина	0103000020E61000000100000005000000B5519D0E640B4A40138255F5F2A54C40B5519D0E640B4A40D4D17135B2A94C40DA8F149161134A40D4D17135B2A94C40DA8F149161134A40138255F5F2A54C40B5519D0E640B4A40138255F5F2A54C40
52691	9882	52.151541000000002	52.166732000000003	57.199911	57.187334	пер.Субботина	0103000020E6100000010000000500000067800BB265134A40E5B67D8FFA974C4067800BB265134A402A8E03AF96994C402D99637957154A402A8E03AF96994C402D99637957154A40E5B67D8FFA974C4067800BB265134A40E5B67D8FFA974C40
53175	10310	52.137625999999997	52.158099	57.285237000000002	57.272956999999998	Молодежная	0103000020E61000000100000005000000268A90BA9D114A406D1B4641F0A24C40268A90BA9D114A40F94D61A582A44C40E14389963C144A40F94D61A582A44C40E14389963C144A406D1B4641F0A24C40268A90BA9D114A406D1B4641F0A24C40
52800	9703	51.739592000000002	51.758581999999997	57.390152	57.371471999999997	Школьная	0103000020E610000001000000050000000E315EF3AADE49409AB0FD648CAF4C400E315EF3AADE4940083C3080F0B14C40C9AA083719E14940083C3080F0B14C40C9AA083719E149409AB0FD648CAF4C400E315EF3AADE49409AB0FD648CAF4C40
52710	9604	52.239136000000002	52.266651000000003	57.322588000000003	57.313172999999999	Карачева	0103000020E61000000100000005000000ECA529029C1E4A40BF7E880D16A84C40ECA529029C1E4A40810A47904AA94C400D39B69E21224A40810A47904AA94C400D39B69E21224A40BF7E880D16A84C40ECA529029C1E4A40BF7E880D16A84C40
52946	9900	52.048118000000002	52.068294000000002	57.161014999999999	57.151294999999998	70 лет Октября	0103000020E61000000100000005000000AA2C0ABB28064A402F8672A25D934C40AA2C0ABB28064A402D95B7239C944C40AB4198DBBD084A402D95B7239C944C40AB4198DBBD084A402F8672A25D934C40AA2C0ABB28064A402F8672A25D934C40
53036	9557	52.050732000000004	52.077421000000001	57.461255999999999	57.450347000000001	пер. Молодежный	0103000020E610000001000000050000002B6EDC627E064A40056D72F8A4B94C402B6EDC627E064A40B98AC56F0ABB4C4006836BEEE8094A40B98AC56F0ABB4C4006836BEEE8094A40056D72F8A4B94C402B6EDC627E064A40056D72F8A4B94C40
52920	10096	52.031193999999999	52.053148999999998	57.270125	57.260039999999996	Азина	0103000020E610000001000000050000006CEA3C2AFE034A406FD39FFD48A14C406CEA3C2AFE034A407F6ABC7493A24C4055682096CD064A407F6ABC7493A24C4055682096CD064A406FD39FFD48A14C406CEA3C2AFE034A406FD39FFD48A14C40
52917	8321	53.708348000000001	53.733843	56.622340000000001	56.614677999999998	Комсомольская	0103000020E61000000100000005000000F017B325ABDA4A400CC9C9C4AD4E4C40F017B325ABDA4A400F7F4DD6A84F4C4003B34291EEDD4A400F7F4DD6A84F4C4003B34291EEDD4A400CC9C9C4AD4E4C40F017B325ABDA4A400CC9C9C4AD4E4C40
53149	8945	53.363225	53.387963999999997	56.380178999999998	56.364077000000002	Советская	0103000020E61000000100000005000000780B24287EAE4A40E71C3C139A2E4C40780B24287EAE4A4020D099B4A9304C403E03EACDA8B14A4020D099B4A9304C403E03EACDA8B14A40E71C3C139A2E4C40780B24287EAE4A40E71C3C139A2E4C40
52705	8688	53.620601000000001	53.680715999999997	56.469183999999998	56.454946	Первомайская	0103000020E61000000100000005000000B56E83DA6FCF4A4017B9A7AB3B3A4C40B56E83DA6FCF4A403AE7A7380E3C4C4095EEAEB321D74A403AE7A7380E3C4C4095EEAEB321D74A4017B9A7AB3B3A4C40B56E83DA6FCF4A4017B9A7AB3B3A4C40
52692	9038	53.572667000000003	53.600838000000003	56.288665999999999	56.272385	Школьная	0103000020E61000000100000005000000CD3FFA264DC94A40E275FD82DD224C40CD3FFA264DC94A40CBBBEA01F3244C40D7187442E8CC4A40CBBBEA01F3244C40D7187442E8CC4A40E275FD82DD224C40CD3FFA264DC94A40E275FD82DD224C40
52817	9320	53.841092000000003	53.861817000000002	56.397669	56.387106000000003	Вечтомова	0103000020E61000000100000005000000B07614E7A8EB4A40EE0A7DB08C314C40B07614E7A8EB4A4007D15AD1E6324C408411FB0450EE4A4007D15AD1E6324C408411FB0450EE4A40EE0A7DB08C314C40B07614E7A8EB4A40EE0A7DB08C314C40
52548	284	53.500568000000001	53.544522999999998	56.493535999999999	56.483804999999997	Соскова	0103000020E610000001000000050000004AB6BA9C12C04A4015527E52ED3D4C404AB6BA9C12C04A4007B309302C3F4C40BC75FEEDB2C54A4007B309302C3F4C40BC75FEEDB2C54A4015527E52ED3D4C404AB6BA9C12C04A4015527E52ED3D4C40
52795	9215	54.101505000000003	54.120063999999999	56.264952000000001	56.243385000000004	Школьная	0103000020E61000000100000005000000B4B0A71DFE0C4B4022AB5B3D271F4C40B4B0A71DFE0C4B40418177F2E9214C40A6B6D4415E0F4B40418177F2E9214C40A6B6D4415E0F4B4022AB5B3D271F4C40B4B0A71DFE0C4B4022AB5B3D271F4C40
52709	9294	54.011493999999999	54.031778000000003	56.280586	56.263376999999998	Школьная	0103000020E61000000100000005000000D40CA9A278014B4061C26856B6214C40D40CA9A278014B4094DBF63DEA234C40BC5D2F4D11044B4094DBF63DEA234C40BC5D2F4D11044B4061C26856B6214C40D40CA9A278014B4061C26856B6214C40
52338	9384	53.755248999999999	53.789628	56.430917999999998	56.413606999999999	Советская	0103000020E6100000010000000500000019ABCDFFABE04A40C632FD12F1344C4019ABCDFFABE04A40FDA02E5228374C40C100C28712E54A40FDA02E5228374C40C100C28712E54A40C632FD12F1344C4019ABCDFFABE04A40C632FD12F1344C40
52641	9384	53.755248999999999	53.789628	56.430917999999998	56.413606999999999	Лермонтова	0103000020E6100000010000000500000019ABCDFFABE04A40C632FD12F1344C4019ABCDFFABE04A40FDA02E5228374C40C100C28712E54A40FDA02E5228374C40C100C28712E54A40C632FD12F1344C4019ABCDFFABE04A40C632FD12F1344C40
52916	8978	53.503003	53.522441999999998	56.285013999999997	56.273870000000002	Молодежная	0103000020E610000001000000050000001B65FD6662C04A4082AD122C0E234C401B65FD6662C04A407973B8567B244C4046072461DFC24A407973B8567B244C4046072461DFC24A4082AD122C0E234C401B65FD6662C04A4082AD122C0E234C40
53031	9136	53.777591000000001	53.796267	56.338448999999997	56.322094999999997	Сиреневая	0103000020E61000000100000005000000FC54151A88E34A40419AB1683A294C40FC54151A88E34A40942EFD4B522B4C4028F1B913ECE54A40942EFD4B522B4C4028F1B913ECE54A40419AB1683A294C40FC54151A88E34A40419AB1683A294C40
52796	8314	53.744199999999999	53.774509000000002	56.657395000000001	56.636738999999999	Юбилейная	0103000020E6100000010000000500000073D712F241DF4A403B8BDEA980514C4073D712F241DF4A40E7C6F48425544C4095BA641C23E34A40E7C6F48425544C4095BA641C23E34A403B8BDEA980514C4073D712F241DF4A403B8BDEA980514C40
52815	9063	53.688189999999999	53.737157000000003	56.286012999999997	56.271481000000001	Платова	0103000020E6100000010000000500000095B7239C16D84A40213EB0E3BF224C4095B7239C16D84A408C9DF0129C244C403D821B295BDE4A408C9DF0129C244C403D821B295BDE4A40213EB0E3BF224C4095B7239C16D84A40213EB0E3BF224C40
52708	9143	53.978876	54.011206000000001	56.330261	56.308191000000001	Ленина	0103000020E610000001000000050000006E6B0BCF4BFD4A40F5F57CCD72274C406E6B0BCF4BFD4A40771211FE452A4C406EC2BD326F014B40771211FE452A4C406EC2BD326F014B40F5F57CCD72274C406E6B0BCF4BFD4A40F5F57CCD72274C40
53030	8412	53.599103999999997	53.621741999999998	56.623488999999999	56.613173000000003	Школьная	0103000020E610000001000000050000008E739B70AFCC4A4026E5EE737C4E4C408E739B70AFCC4A403735D07CCE4F4C405A46EA3D95CF4A403735D07CCE4F4C405A46EA3D95CF4A4026E5EE737C4E4C408E739B70AFCC4A4026E5EE737C4E4C40
52919	9475	53.742952000000002	53.761474999999997	56.391680000000001	56.380408000000003	Полевая	0103000020E61000000100000005000000B83F170D19DF4A4082919735B1304C40B83F170D19DF4A40A73FFB9122324C405DDC460378E14A40A73FFB9122324C405DDC460378E14A4082919735B1304C40B83F170D19DF4A4082919735B1304C40
52639	8796	53.616486999999999	53.650604999999999	56.369526	56.356951000000002	Совхозная	0103000020E610000001000000050000005FB4C70BE9CE4A4023A30392B02D4C405FB4C70BE9CE4A40C782C2A04C2F4C409ACE4E0647D34A40C782C2A04C2F4C409ACE4E0647D34A4023A30392B02D4C405FB4C70BE9CE4A4023A30392B02D4C40
52687	8438	53.767871	53.785747000000001	56.557330999999998	56.542549999999999	Школьная	0103000020E61000000100000005000000FE45D09849E24A40EF38454772454C40FE45D09849E24A400306499F56474C400EF7915B93E44A400306499F56474C400EF7915B93E44A40EF38454772454C40FE45D09849E24A40EF38454772454C40
53151	8518	53.635226000000003	53.658591000000001	56.548653999999999	56.536107999999999	переулок Школьный	0103000020E61000000100000005000000D2C8E7154FD14A40DE8FDB2F9F444C40D2C8E7154FD14A40E868554B3A464C405038BBB54CD44A40E868554B3A464C405038BBB54CD44A40DE8FDB2F9F444C40D2C8E7154FD14A40DE8FDB2F9F444C40
53038	56401	53.315147000000003	54.198829000000003	56.759207000000004	56.170600999999998	Центральная	0103000020E610000001000000050000005D37A5BC56A84A401BD5E940D6154C405D37A5BC56A84A4078F2E9B12D614C408A3F8A3A73194B4078F2E9B12D614C408A3F8A3A73194B401BD5E940D6154C405D37A5BC56A84A401BD5E940D6154C40
53035	56400	53.812390999999998	53.830455999999998	56.520628000000002	56.502445000000002	Мира	0103000020E610000001000000050000004948A46DFCE74A40F584251E50404C404948A46DFCE74A40E2B034F0A3424C402C62D8614CEA4A40E2B034F0A3424C402C62D8614CEA4A40F584251E50404C404948A46DFCE74A40F584251E50404C40
52399	8709	53.730266999999998	53.749752000000001	56.467970999999999	56.459029000000001	Октябрьская	0103000020E610000001000000050000008C2C996379DD4A4032755776C13A4C408C2C996379DD4A40FB3C4679E63B4C40280EA0DFF7DF4A40FB3C4679E63B4C40280EA0DFF7DF4A4032755776C13A4C408C2C996379DD4A4032755776C13A4C40
52547	56369	53.196784999999998	53.201663000000003	56.870238000000001	56.833810999999997	Максима Горького	0103000020E61000000100000005000000F3AB394030994A40C405A051BA6A4C40F3AB394030994A4044DE72F5636F4C4019E8DA17D0994A4044DE72F5636F4C4019E8DA17D0994A40C405A051BA6A4C40F3AB394030994A40C405A051BA6A4C40
53032	56398	51.837077000000001	52.731619000000002	56.717796	56.184094999999999	з-д Полевой	0103000020E61000000100000005000000ED9DD15625EB4940B62DCA6C90174C40ED9DD15625EB49408D9944BDE05B4C40ED10FFB0A55D4A408D9944BDE05B4C40ED10FFB0A55D4A40B62DCA6C90174C40ED9DD15625EB4940B62DCA6C90174C40
52516	6971	52.347006	52.364029000000002	56.449607999999998	56.439373000000003	Заводская	0103000020E6100000010000000500000005C24EB16A2C4A406ADFDC5F3D384C4005C24EB16A2C4A408E0244C18C394C40D6E59480982E4A408E0244C18C394C40D6E59480982E4A406ADFDC5F3D384C4005C24EB16A2C4A406ADFDC5F3D384C40
53034	7348	52.329830000000001	52.350527	56.327640000000002	56.319429	Удмуртская	0103000020E61000000100000005000000AE9E93DE372A4A406E32AA0CE3284C40AE9E93DE372A4A40446E861BF0294C40B8AE9811DE2C4A40446E861BF0294C40B8AE9811DE2C4A406E32AA0CE3284C40AE9E93DE372A4A406E32AA0CE3284C40
52915	7188	52.429372000000001	52.457183999999998	56.338509000000002	56.325578999999998	Молодежная	0103000020E61000000100000005000000B8E864A9F5364A40D7A19A92AC294C40B8E864A9F5364A406A334E43542B4C4092205C01853A4A406A334E43542B4C4092205C01853A4A40D7A19A92AC294C40B8E864A9F5364A40D7A19A92AC294C40
53029	7406	52.295712000000002	52.320936000000003	56.300665000000002	56.283594999999998	Юберинская	0103000020E6100000010000000500000073840CE4D9254A40912749D74C244C4073840CE4D9254A40A306D3307C264C40F60D4C6E14294A40A306D3307C264C40F60D4C6E14294A40912749D74C244C4073840CE4D9254A40912749D74C244C40
52707	7478	52.248775000000002	52.265807000000002	56.270600999999999	56.259433000000001	Даниила Яшина	0103000020E61000000100000005000000FD87F4DBD71F4A406840BD1935214C40FD87F4DBD71F4A40E8A1B60DA3224C402106BAF605224A40E8A1B60DA3224C402106BAF605224A406840BD1935214C40FD87F4DBD71F4A406840BD1935214C40
53145	7898	52.060209	52.071879000000003	56.419522999999998	56.406984000000001	з-д Больничный	0103000020E6100000010000000500000062F6B2EDB4074A4065FF3C0D18344C4062F6B2EDB4074A40BC75FEEDB2354C407522C15433094A40BC75FEEDB2354C407522C15433094A4065FF3C0D18344C4062F6B2EDB4074A4065FF3C0D18344C40
53013	6685	52.502206999999999	52.527639000000001	56.662149999999997	56.645985000000003	Центральная	0103000020E610000001000000050000004069A85148404A40715AF0A2AF524C404069A85148404A40F085C954C1544C400D8CBCAC89434A40F085C954C1544C400D8CBCAC89434A40715AF0A2AF524C404069A85148404A40715AF0A2AF524C40
52426	6720	52.415466000000002	52.466104000000001	56.515354000000002	56.491340000000001	Садовая	0103000020E61000000100000005000000CB4C69FD2D354A40BB9BA73AE43E4C40CB4C69FD2D354A4070EEAF1EF7414C407444BE4BA93B4A4070EEAF1EF7414C407444BE4BA93B4A40BB9BA73AE43E4C40CB4C69FD2D354A40BB9BA73AE43E4C40
52566	6720	52.415466000000002	52.466104000000001	56.515354000000002	56.491340000000001	Переездная	0103000020E61000000100000005000000CB4C69FD2D354A40BB9BA73AE43E4C40CB4C69FD2D354A4070EEAF1EF7414C407444BE4BA93B4A4070EEAF1EF7414C407444BE4BA93B4A40BB9BA73AE43E4C40CB4C69FD2D354A40BB9BA73AE43E4C40
52861	7620	52.010891999999998	52.041884000000003	56.324680999999998	56.310682	Почтовая	0103000020E61000000100000005000000DEE4B7E864014A405ABA826DC4274C40DEE4B7E864014A40F850A2258F294C40E31C75745C054A40F850A2258F294C40E31C75745C054A405ABA826DC4274C40DEE4B7E864014A405ABA826DC4274C40
52703	8116	52.153976	52.193033999999997	56.631039999999999	56.615917000000003	Парковая	0103000020E61000000100000005000000382F4E7CB5134A407506465ED64E4C40382F4E7CB5134A40E23B31EBC5504C400E828E56B5184A40E23B31EBC5504C400E828E56B5184A407506465ED64E4C40382F4E7CB5134A407506465ED64E4C40
52683	7562	52.066740000000003	52.107191	56.355440000000002	56.341816999999999	Молодежная	0103000020E61000000100000005000000E3AAB2EF8A084A40C11BD2A8C02B4C40E3AAB2EF8A084A405AD8D30E7F2D4C4078B6476FB80D4A405AD8D30E7F2D4C4078B6476FB80D4A40C11BD2A8C02B4C40E3AAB2EF8A084A40C11BD2A8C02B4C40
52814	7537	51.939790000000002	51.959876999999999	56.228706000000003	56.215978999999997	 Центральная площадь	0103000020E61000000100000005000000CE8DE9094BF84940B7CF2A33A51B4C40CE8DE9094BF849401233FB3C461D4C405F97E13FDDFA49401233FB3C461D4C405F97E13FDDFA4940B7CF2A33A51B4C40CE8DE9094BF84940B7CF2A33A51B4C40
52812	7822	52.112966999999998	52.127538000000001	56.425924999999999	56.417700000000004	Ленина	0103000020E610000001000000050000007C43E1B3750E4A4005C58F3177354C407C43E1B3750E4A403FC6DCB584364C40A67F492A53104A403FC6DCB584364C40A67F492A53104A4005C58F3177354C407C43E1B3750E4A4005C58F3177354C40
53173	6812	52.471305000000001	52.493251000000001	56.506264999999999	56.495061999999997	Советская	0103000020E610000001000000050000007CB8E4B8533C4A4005BF0D315E3F4C407CB8E4B8533C4A40020EA14ACD404C4012DC48D9223F4A40020EA14ACD404C4012DC48D9223F4A4005BF0D315E3F4C407CB8E4B8533C4A4005BF0D315E3F4C40
53142	7275	52.280000000000001	52.319122	56.412770999999999	56.395710999999999	Школьная	0103000020E61000000100000005000000A4703D0AD7234A406FD575A8A6324C40A4703D0AD7234A405DDE1CAED5344C4091B75CFDD8284A405DDE1CAED5344C4091B75CFDD8284A406FD575A8A6324C40A4703D0AD7234A406FD575A8A6324C40
52682	7282	52.245972000000002	52.274583	56.381230000000002	56.369366999999997	Микрорайон	0103000020E61000000100000005000000A9DDAF027C1F4A405E9CF86A472F4C40A9DDAF027C1F4A4086200725CC304C40CF84268925234A4086200725CC304C40CF84268925234A405E9CF86A472F4C40A9DDAF027C1F4A405E9CF86A472F4C40
53225	6616	52.500518999999997	52.539613000000003	56.589587000000002	56.579177000000001	Нагорная	0103000020E610000001000000050000006803B00111404A4036CCD078224A4C406803B00111404A40C9923996774B4C408CBFED0912454A40C9923996774B4C408CBFED0912454A4036CCD078224A4C406803B00111404A4036CCD078224A4C40
52684	8023	52.173146000000003	52.197812999999996	56.513770000000001	56.503751000000001	Дубовская	0103000020E6100000010000000500000074B7EBA529164A40E529ABE97A404C4074B7EBA529164A403DD52137C3414C40A0DCB6EF51194A403DD52137C3414C40A0DCB6EF51194A40E529ABE97A404C4074B7EBA529164A40E529ABE97A404C40
52813	8103	52.276792999999998	52.309024999999998	56.625450000000001	56.614569000000003	Центральная площадь	0103000020E610000001000000050000008061F9F36D234A4056116E32AA4E4C408061F9F36D234A4040A4DFBE0E504C40BD5296218E274A4040A4DFBE0E504C40BD5296218E274A4056116E32AA4E4C408061F9F36D234A4056116E32AA4E4C40
52816	56381	51.939008999999999	51.955286000000001	56.436357000000001	56.424664999999997	Заводская	0103000020E6100000010000000500000028D3687231F84940BF60376C5B364C4028D3687231F84940BA30D28BDA374C40D029C8CF46FA4940BA30D28BDA374C40D029C8CF46FA4940BF60376C5B364C4028D3687231F84940BF60376C5B364C40
53144	8220	52.129460999999999	52.154316999999999	56.683548999999999	56.674000999999997	Клубная	0103000020E61000000100000005000000C18D942D92104A40533C2EAA45564C40C18D942D92104A40541B9C887E574C40C11BD2A8C0134A40541B9C887E574C40C11BD2A8C0134A40533C2EAA45564C40C18D942D92104A40533C2EAA45564C40
52913	7653	51.960819999999998	51.995081999999996	56.332621000000003	56.317517000000002	Советская	0103000020E61000000100000005000000DEAB5626FCFA49404776A565A4284C40DEAB5626FCFA49403E7B2E53932A4C404C6BD3D85EFF49403E7B2E53932A4C404C6BD3D85EFF49404776A565A4284C40DEAB5626FCFA49404776A565A4284C40
53250	56415	52.30359	52.319814000000001	56.467602999999997	56.460591000000001	Кирпичная 	0103000020E6100000010000000500000042B28009DC264A407DEA58A5F43A4C4042B28009DC264A407841446ADA3B4C40C76647AAEF284A407841446ADA3B4C40C76647AAEF284A407DEA58A5F43A4C4042B28009DC264A407DEA58A5F43A4C40
52680	7150	52.357039999999998	52.418636999999997	56.405569	56.393932	Центральная площадь	0103000020E6100000010000000500000092AE997CB32D4A40876C205D6C324C4092AE997CB32D4A40BEA25BAFE9334C40A1F2AFE595354A40BEA25BAFE9334C40A1F2AFE595354A40876C205D6C324C4092AE997CB32D4A40876C205D6C324C40
52846	6294	52.416193999999997	52.438715000000002	56.456144999999999	56.446981000000001	Коммунальная	0103000020E610000001000000050000004D6551D845354A40797764AC36394C404D6551D845354A40F19D98F5623A4C40E0A128D027384A40F19D98F5623A4C40E0A128D027384A40797764AC36394C404D6551D845354A40797764AC36394C40
52797	7113	52.542020999999998	52.586945999999998	56.440702000000002	56.41536	Юбилейная	0103000020E61000000100000005000000635FB2F160454A40850838842A354C40635FB2F160454A4012A452EC68384C404E42E90B214B4A4012A452EC68384C404E42E90B214B4A40850838842A354C40635FB2F160454A40850838842A354C40
52850	7460	52.226019999999998	52.271250999999999	56.339810999999997	56.328015000000001	Центральная	0103000020E61000000100000005000000F71E2E39EE1C4A4079CC4065FC294C40F71E2E39EE1C4A4018E945ED7E2B4C40EF004F5AB8224A4018E945ED7E2B4C40EF004F5AB8224A4079CC4065FC294C40F71E2E39EE1C4A4079CC4065FC294C40
52400	8195	52.052923999999997	52.100884999999998	56.620111999999999	56.598318999999996	 Садовая	0103000020E610000001000000050000003596B036C6064A40A7C98CB7954C4C403596B036C6064A40B7ED7BD45F4F4C4017D4B7CCE90C4A40B7ED7BD45F4F4C4017D4B7CCE90C4A40A7C98CB7954C4C403596B036C6064A40A7C98CB7954C4C40
52954	7930	52.099277000000001	52.121015999999997	56.492905	56.481791999999999	Центральная	0103000020E610000001000000050000005C1FD61BB50C4A40BABC395CAB3D4C405C1FD61BB50C4A407784D382173F4C407825C9737D0F4A407784D382173F4C407825C9737D0F4A40BABC395CAB3D4C405C1FD61BB50C4A40BABC395CAB3D4C40
52433	7073	52.580441999999998	52.623471000000002	56.375109999999999	56.364730000000002	Советская	0103000020E61000000100000005000000C79C67EC4B4A4A405FEFFE78AF2E4C40C79C67EC4B4A4A408733BF9A03304C409180D1E5CD4F4A408733BF9A03304C409180D1E5CD4F4A405FEFFE78AF2E4C40C79C67EC4B4A4A405FEFFE78AF2E4C40
52943	6899	52.564937	52.580728999999998	56.503548000000002	56.493485999999997	Труда	0103000020E6100000010000000500000072A609DB4F484A4055849B8C2A3F4C4072A609DB4F484A40ADFBC74274404C405D6BEF53554A4A40ADFBC74274404C405D6BEF53554A4A4055849B8C2A3F4C4072A609DB4F484A4055849B8C2A3F4C40
52422	5212	53.210600999999997	53.253611999999997	56.592199000000001	56.573867	Садовая	0103000020E61000000100000005000000A0C03BF9F49A4A4077A04E7974494C40A0C03BF9F49A4A40A9DC442DCD4B4C40C3EFA65B76A04A40A9DC442DCD4B4C40C3EFA65B76A04A4077A04E7974494C40A0C03BF9F49A4A4077A04E7974494C40
52526	4794	53.096156000000001	53.133794999999999	56.569378999999998	56.551085	Первомайская	0103000020E6100000010000000500000037A8FDD64E8C4A4078280AF489464C4037A8FDD64E8C4A40BC033C69E1484C4025AFCE3120914A40BC033C69E1484C4025AFCE3120914A4078280AF489464C4037A8FDD64E8C4A4078280AF489464C40
52852	5552	52.713957999999998	52.747430000000001	56.575200000000002	56.555242	Молодежная	0103000020E61000000100000005000000D95BCAF9625B4A40CDAE7B2B12474C40D95BCAF9625B4A4061545227A0494C404F0647C9AB5F4A4061545227A0494C404F0647C9AB5F4A40CDAE7B2B12474C40D95BCAF9625B4A40CDAE7B2B12474C40
52918	6260	52.627783000000001	52.646934999999999	56.493068999999998	56.482652000000002	Школьная	0103000020E610000001000000050000000DFE7E315B504A40ACAC6D8AC73D4C400DFE7E315B504A40F1D58EE21C3F4C40A2D11DC4CE524A40F1D58EE21C3F4C40A2D11DC4CE524A40ACAC6D8AC73D4C400DFE7E315B504A40ACAC6D8AC73D4C40
53008	5061	53.302534999999999	53.329797999999997	56.529817999999999	56.517122000000001	Колхозная	0103000020E610000001000000050000009B728577B9A64A406405BF0D31424C409B728577B9A64A40836A8313D1434C40A22424D236AA4A40836A8313D1434C40A22424D236AA4A406405BF0D31424C409B728577B9A64A406405BF0D31424C40
52507	6517	52.867193	52.909683000000001	56.447971000000003	56.432177000000003	Октябрьская	0103000020E61000000100000005000000FA28232E006F4A40AD8A709351374C40FA28232E006F4A4039471D1D57394C40145D177E70744A4039471D1D57394C40145D177E70744A40AD8A709351374C40FA28232E006F4A40AD8A709351374C40
52760	4857	53.200629999999997	53.221803000000001	56.533923999999999	56.522191999999997	Советская	0103000020E61000000100000005000000594C6C3EAE994A40CD1DFD2FD7424C40594C6C3EAE994A405646239F57444C40CD936B0A649C4A405646239F57444C40CD936B0A649C4A40CD1DFD2FD7424C40594C6C3EAE994A40CD1DFD2FD7424C40
53122	5871	52.672311999999998	52.691589999999998	56.646737000000002	56.635773	Трактовая	0103000020E61000000100000005000000AB5AD2510E564A400457790261514C40AB5AD2510E564A407C0E2C47C8524C40CD1E680586584A407C0E2C47C8524C40CD1E680586584A400457790261514C40AB5AD2510E564A400457790261514C40
52908	5318	53.390228	53.413547999999999	56.559612999999999	56.543652000000002	Мельничная	0103000020E61000000100000005000000E3FDB8FDF2B14A40D733846396454C40E3FDB8FDF2B14A404EB51666A1474C40C1A90F24EFB44A404EB51666A1474C40C1A90F24EFB44A40D733846396454C40E3FDB8FDF2B14A40D733846396454C40
52505	4695	53.053494999999998	53.087307000000003	56.625638000000002	56.589160999999997	Ленина	0103000020E61000000100000005000000F0BF95ECD8864A40118AADA0694B4C40F0BF95ECD8864A404391EEE714504C401FDB32E02C8B4A404391EEE714504C401FDB32E02C8B4A40118AADA0694B4C40F0BF95ECD8864A40118AADA0694B4C40
52679	5957	52.682814	52.724899999999998	56.677784000000003	56.663227999999997	Школьная	0103000020E610000001000000050000001FA0FB7266574A404FE5B4A7E4544C401FA0FB7266574A4044E048A0C1564C40696FF085C95C4A4044E048A0C1564C40696FF085C95C4A404FE5B4A7E4544C401FA0FB7266574A404FE5B4A7E4544C40
53010	6488	52.778556000000002	52.801903000000003	56.431539999999998	56.416296000000003	Школьная	0103000020E61000000100000005000000630D17B9A7634A4052BAF42F49354C40630D17B9A7634A403A75E5B33C374C403BC8EBC1A4664A403A75E5B33C374C403BC8EBC1A4664A4052BAF42F49354C40630D17B9A7634A4052BAF42F49354C40
52762	6411	52.705927000000003	52.735689000000001	56.418064000000001	56.401001999999998	Кировская	0103000020E61000000100000005000000842EE1D05B5A4A40B7D0950854334C40842EE1D05B5A4A4046D1031F83354C407383A10E2B5E4A4046D1031F83354C407383A10E2B5E4A40B7D0950854334C40842EE1D05B5A4A40B7D0950854334C40
52676	4581	53.001105000000003	53.014704999999999	56.579906000000001	56.570003999999997	Полевая	0103000020E61000000100000005000000596E693524804A406A4B1DE4F5484C40596E693524804A4089601C5C3A4A4C40390B7BDAE1814A4089601C5C3A4A4C40390B7BDAE1814A406A4B1DE4F5484C40596E693524804A406A4B1DE4F5484C40
52421	4188	52.964229000000003	53.018065	56.562677999999998	56.544659000000003	Школьная	0103000020E610000001000000050000006A6D1ADB6B7B4A406D3CD862B7454C406A6D1ADB6B7B4A40DF162CD505484C40E31934F44F824A40DF162CD505484C40E31934F44F824A406D3CD862B7454C406A6D1ADB6B7B4A406D3CD862B7454C40
52636	4188	52.964229000000003	53.018065	56.562677999999998	56.544659000000003	Советская	0103000020E610000001000000050000006A6D1ADB6B7B4A406D3CD862B7454C406A6D1ADB6B7B4A40DF162CD505484C40E31934F44F824A40DF162CD505484C40E31934F44F824A406D3CD862B7454C406A6D1ADB6B7B4A406D3CD862B7454C40
53116	4457	53.043909999999997	53.071353000000002	56.569577000000002	56.561715999999997	 Школьная	0103000020E61000000100000005000000D2FBC6D79E854A40E9D1544FE6474C40D2FBC6D79E854A40E3C62DE6E7484C405ABC581822894A40E3C62DE6E7484C405ABC581822894A40E9D1544FE6474C40D2FBC6D79E854A40E9D1544FE6474C40
53221	4142	52.965809999999998	52.982500999999999	56.608218999999998	56.597803999999996	Нарядная	0103000020E610000001000000050000002B137EA99F7B4A4080B56AD7844C4C402B137EA99F7B4A4025E7C41EDA4D4C40C6A4BF97C27D4A4025E7C41EDA4D4C40C6A4BF97C27D4A4080B56AD7844C4C402B137EA99F7B4A4080B56AD7844C4C40
53009	5397	52.894466000000001	52.911434999999997	56.543835000000001	56.532722	Школьная	0103000020E6100000010000000500000025B1A4DC7D724A400BEE073C30444C4025B1A4DC7D724A40C8B5A1629C454C4002B7EEE6A9744A40C8B5A1629C454C4002B7EEE6A9744A400BEE073C30444C4025B1A4DC7D724A400BEE073C30444C40
53041	5989	52.741483000000002	52.762180000000001	56.655298000000002	56.646414999999998	Школьная	0103000020E610000001000000050000001EC539EAE85E4A4069520ABABD524C401EC539EAE85E4A402E910BCEE0534C4028D53E1D8F614A402E910BCEE0534C4028D53E1D8F614A4069520ABABD524C401EC539EAE85E4A4069520ABABD524C40
53117	4409	52.873435999999998	52.894312999999997	56.612473999999999	56.604067000000001	Школьная	0103000020E61000000100000005000000149337C0CC6F4A40E2CB4411524D4C40149337C0CC6F4A403DD34B8C654E4C409EB12FD978724A403DD34B8C654E4C409EB12FD978724A40E2CB4411524D4C40149337C0CC6F4A40E2CB4411524D4C40
53115	4950	53.202049000000002	53.229376000000002	56.516719999999999	56.504313000000003	Клубная	0103000020E610000001000000050000004298DBBDDC994A404DF910548D404C404298DBBDDC994A40359886E123424C40603E59315C9D4A40359886E123424C40603E59315C9D4A404DF910548D404C404298DBBDDC994A404DF910548D404C40
52909	5629	52.711030000000001	52.733604	56.518920000000001	56.504958999999999	Центральная	0103000020E61000000100000005000000C93CF207035B4A4012691B7FA2404C40C93CF207035B4A40C39E76F86B424C407E1B62BCE65D4A40C39E76F86B424C407E1B62BCE65D4A4012691B7FA2404C40C93CF207035B4A4012691B7FA2404C40
53123	6073	52.732553000000003	52.765251999999997	56.708770999999999	56.696570000000001	Садовая	0103000020E6100000010000000500000019CBF44BC45D4A40F7AFAC3429594C4019CBF44BC45D4A4036AD1402B95A4C406B990CC7F3614A4036AD1402B95A4C406B990CC7F3614A40F7AFAC3429594C4019CBF44BC45D4A40F7AFAC3429594C40
53120	6607	52.892947999999997	52.912441000000001	56.425691	56.415847999999997	Центральная	0103000020E61000000100000005000000A983BC1E4C724A40B20DDC813A354C40A983BC1E4C724A40CC99ED0A7D364C40C843DFDDCA744A40CC99ED0A7D364C40C843DFDDCA744A40B20DDC813A354C40A983BC1E4C724A40B20DDC813A354C40
52424	5799	52.770237999999999	52.796216999999999	56.489566000000003	56.477766000000003	Советская	0103000020E610000001000000050000007711A62897624A400492B06F273D4C407711A62897624A40E59D4319AA3E4C4076C24B70EA654A40E59D4319AA3E4C4076C24B70EA654A400492B06F273D4C407711A62897624A400492B06F273D4C40
53127	6104	52.772852	52.804931000000003	56.703657	56.689624999999999	Центральная	0103000020E61000000100000005000000F85278D0EC624A4083C0CAA145584C40F85278D0EC624A40FD4CBD6E115A4C40AF44A0FA07674A40FD4CBD6E115A4C40AF44A0FA07674A4083C0CAA145584C40F85278D0EC624A4083C0CAA145584C40
52956	6175	52.713689000000002	52.729616	56.477313000000002	56.462226999999999	Центральная	0103000020E61000000100000005000000EA4141295A5B4A40022A1C412A3B4C40EA4141295A5B4A40537AA697183D4C40B5519D0E645D4A40537AA697183D4C40B5519D0E645D4A40022A1C412A3B4C40EA4141295A5B4A40022A1C412A3B4C40
52811	5475	52.832725000000003	52.874091999999997	56.552618000000002	56.530707	Молодежная	0103000020E61000000100000005000000E3C798BB966A4A400F61FC34EE434C40E3C798BB966A4A402997C62FBC464C40FDD8243FE26F4A402997C62FBC464C40FDD8243FE26F4A400F61FC34EE434C40E3C798BB966A4A400F61FC34EE434C40
53118	4966	53.210932999999997	53.230445000000003	56.501609999999999	56.491529	Пионерская	0103000020E61000000100000005000000D65240DAFF9A4A408E041A6CEA3E4C40D65240DAFF9A4A405CACA8C134404C406C43C5387F9D4A405CACA8C134404C406C43C5387F9D4A408E041A6CEA3E4C40D65240DAFF9A4A408E041A6CEA3E4C40
53114	4882	53.161194000000002	53.180678	56.512473999999997	56.5062	 Школьная	0103000020E61000000100000005000000DD274701A2944A401B9E5E29CB404C40DD274701A2944A4070067FBF98414C40A88DEA7420974A4070067FBF98414C40A88DEA7420974A401B9E5E29CB404C40DD274701A2944A401B9E5E29CB404C40
52678	5235	53.316521000000002	53.343381000000001	56.595196999999999	56.581428000000002	Школьная	0103000020E61000000100000005000000A5BF97C283A84A40467D923B6C4A4C40A5BF97C283A84A40B2D6506A2F4C4C40AD889AE8F3AB4A40B2D6506A2F4C4C40AD889AE8F3AB4A40467D923B6C4A4C40A5BF97C283A84A40467D923B6C4A4C40
52799	6191	52.673552000000001	52.710275000000003	56.493720000000003	56.477179	Азина	0103000020E61000000100000005000000E413B2F336564A4043AB9333143D4C40E413B2F336564A40C9B08A37323F4C404D158C4AEA5A4A40C9B08A37323F4C404D158C4AEA5A4A4043AB9333143D4C40E413B2F336564A4043AB9333143D4C40
53119	5141	53.307349000000002	53.329349000000001	56.472574999999999	56.463461000000002	Советская	0103000020E61000000100000005000000AABA473657A74A4059FCA6B0523B4C40AABA473657A74A401FF46C567D3C4C4033FCA71B28AA4A401FF46C567D3C4C4033FCA71B28AA4A4059FCA6B0523B4C40AABA473657A74A4059FCA6B0523B4C40
53121	5720	52.783838000000003	52.800772000000002	56.528174999999997	56.517018	Школьная	0103000020E6100000010000000500000058AEB7CD54644A40BFB854A52D424C4058AEB7CD54644A404BC8073D9B434C40B9C667B27F664A404BC8073D9B434C40B9C667B27F664A40BFB854A52D424C4058AEB7CD54644A40BFB854A52D424C40
53219	5518	52.810544999999998	52.833981999999999	56.573529000000001	56.563234000000001	Заречная	0103000020E61000000100000005000000D97745F0BF674A4065FF3C0D18484C40D97745F0BF674A405F27F56569494C40F1B913ECBF6A4A405F27F56569494C40F1B913ECBF6A4A4065FF3C0D18484C40D97745F0BF674A4065FF3C0D18484C40
52761	5106	53.179591000000002	53.206755999999999	56.452742000000001	56.432594999999999	Колхозная	0103000020E61000000100000005000000F6D37FD6FC964A40E1B4E0455F374C40F6D37FD6FC964A4048C32973F3394C403A2009FB769A4A4048C32973F3394C403A2009FB769A4A40E1B4E0455F374C40F6D37FD6FC964A40E1B4E0455F374C40
52689	56373	52.924514000000002	52.952784000000001	56.525385	56.511350999999998	Трактовая	0103000020E61000000100000005000000DA58897956764A4071E316F373414C40DA58897956764A408C67D0D03F434C4077137CD3F4794A408C67D0D03F434C4077137CD3F4794A4071E316F373414C40DA58897956764A4071E316F373414C40
53012	5869	52.822268000000001	52.845354999999998	56.495528999999998	56.485698999999997	Октябрьская	0103000020E610000001000000050000000F46EC1340694A40965984622B3E4C400F46EC1340694A401B9C887E6D3F4C404A41B797346C4A401B9C887E6D3F4C404A41B797346C4A40965984622B3E4C400F46EC1340694A40965984622B3E4C40
52607	40326	53.099704000000003	53.117849999999997	56.838681000000001	56.829616000000001	Городок Машиностроителей	0103000020E61000000100000005000000E4A3C519C38C4A40821E6ADB306A4C40E4A3C519C38C4A40676325E6596B4C40B3EA73B5158F4A40676325E6596B4C40B3EA73B5158F4A40821E6ADB306A4C40E4A3C519C38C4A40821E6ADB306A4C40
9826	40326	53.100692000000002	53.391072000000001	56.961770999999999	56.778869999999998	Баранова	0103000020E61000000100000005000000037CB779E38C4A40F2EA1C03B2634C40037CB779E38C4A40E09EE74F1B7B4C40CF30B5A50EB24A40E09EE74F1B7B4C40CF30B5A50EB24A40F2EA1C03B2634C40037CB779E38C4A40F2EA1C03B2634C40
53216	3861	52.224026000000002	52.247059	57.744235000000003	57.729883999999998	Черниговская	0103000020E6100000010000000500000013BA4BE2AC1C4A40D4EFC2D66CDD4C4013BA4BE2AC1C4A40F0C4AC1743DF4C405B971AA19F1F4A40F0C4AC1743DF4C405B971AA19F1F4A40D4EFC2D66CDD4C4013BA4BE2AC1C4A40D4EFC2D66CDD4C40
53113	3812	52.536577000000001	52.553555000000003	57.665211999999997	57.650517000000001	Центральная	0103000020E6100000010000000500000095641D8EAE444A40FB3E1C2444D34C4095641D8EAE444A401074B4AA25D54C40C6C4E6E3DA464A401074B4AA25D54C40C6C4E6E3DA464A40FB3E1C2444D34C4095641D8EAE444A40FB3E1C2444D34C40
52758	3761	52.051963000000001	52.094515999999999	57.718122999999999	57.705309999999997	Советская	0103000020E6100000010000000500000010CD3CB9A6064A4058C51B9947DA4C4010CD3CB9A6064A40B1C05774EBDB4C407079AC19190C4A40B1C05774EBDB4C407079AC19190C4A4058C51B9947DA4C4010CD3CB9A6064A4058C51B9947DA4C40
52504	3123	52.468386000000002	52.521377999999999	57.716858999999999	57.695264000000002	Ленина	0103000020E61000000100000005000000BFF38B12F43B4A40070B2769FED84C40BFF38B12F43B4A40F06B2409C2DB4C404C6DA983BC424A40F06B2409C2DB4C404C6DA983BC424A40070B2769FED84C40BFF38B12F43B4A40070B2769FED84C40
52637	3123	52.468386000000002	52.521377999999999	57.716858999999999	57.695264000000002	Глазовская	0103000020E61000000100000005000000BFF38B12F43B4A40070B2769FED84C40BFF38B12F43B4A40F06B2409C2DB4C404C6DA983BC424A40F06B2409C2DB4C404C6DA983BC424A40070B2769FED84C40BFF38B12F43B4A40070B2769FED84C40
53226	3667	52.355477	52.381886999999999	57.582548000000003	57.565781000000001	Центральная	0103000020E6100000010000000500000077BD3445802D4A405ED905836BC84C4077BD3445802D4A40D42CD0EE90CA4C403FE257ACE1304A40D42CD0EE90CA4C403FE257ACE1304A405ED905836BC84C4077BD3445802D4A405ED905836BC84C40
52686	3575	52.481392999999997	52.497725000000003	57.837857999999997	57.818421000000001	Школьная	0103000020E61000000100000005000000FCC22B499E3D4A4008AEF204C2E84C40FCC22B499E3D4A40925852EE3EEB4C4068B3EA73B53F4A40925852EE3EEB4C4068B3EA73B53F4A4008AEF204C2E84C40FCC22B499E3D4A4008AEF204C2E84C40
52914	3509	52.281734	52.30659	57.729716000000003	57.714739000000002	Школьная	0103000020E61000000100000005000000EC1516DC0F244A407F164B917CDB4C40EC1516DC0F244A4019AF795567DD4C40ECA353573E274A4019AF795567DD4C40ECA353573E274A407F164B917CDB4C40EC1516DC0F244A407F164B917CDB4C40
52756	3458	52.072794999999999	52.114324000000003	57.553446000000001	57.532626999999998	Карла Маркса	0103000020E61000000100000005000000FA27B85851094A40B9FB1C1F2DC44C40FA27B85851094A400F0D8B51D7C64C40EF92382BA20E4A400F0D8B51D7C64C40EF92382BA20E4A40B9FB1C1F2DC44C40FA27B85851094A40B9FB1C1F2DC44C40
53053	3970	51.911349999999999	51.9375	57.668408999999997	57.651605000000004	Советская	0103000020E61000000100000005000000D49AE61DA7F449407E74EACA67D34C40D49AE61DA7F4494010AD156D8ED54C400000000000F8494010AD156D8ED54C400000000000F849407E74EACA67D34C40D49AE61DA7F449407E74EACA67D34C40
53111	3406	52.734665	52.757060000000003	57.792386999999998	57.780138000000001	Советская	0103000020E610000001000000050000000742B280095E4A40F52EDE8FDBE34C400742B280095E4A404563EDEF6CE54C400D8E9257E7604A404563EDEF6CE54C400D8E9257E7604A40F52EDE8FDBE34C400742B280095E4A40F52EDE8FDBE34C40
52866	3339	52.542577999999999	52.570821000000002	57.773760000000003	57.759400999999997	Мира	0103000020E61000000100000005000000B9C3263273454A405CC64D0D34E14C40B9C3263273454A40FB7953910AE34C405D6F9BA910494A40FB7953910AE34C405D6F9BA910494A405CC64D0D34E14C40B9C3263273454A405CC64D0D34E14C40
53112	3281	52.663608000000004	52.695084999999999	57.793418000000003	57.781021000000003	Новая	0103000020E6100000010000000500000097AE601BF1544A409F3E027FF8E34C4097AE601BF1544A40640795B88EE54C405778978BF8584A40640795B88EE54C405778978BF8584A409F3E027FF8E34C4097AE601BF1544A409F3E027FF8E34C40
52910	3233	52.338569999999997	52.374045000000002	57.736961999999998	57.722185000000003	Ключевая	0103000020E610000001000000050000000FB40243562B4A40B554DE8E70DC4C400FB40243562B4A40873254C554DE4C40BD1DE1B4E02F4A40873254C554DE4C40BD1DE1B4E02F4A40B554DE8E70DC4C400FB40243562B4A40B554DE8E70DC4C40
52955	2248	53.259945000000002	53.277031000000001	56.404837000000001	56.382128000000002	Клубная	0103000020E610000001000000050000001EE1B4E045A14A406571FF91E9304C401EE1B4E045A14A40FA9AE5B2D1334C40357D76C075A34A40FA9AE5B2D1334C40357D76C075A34A406571FF91E9304C401EE1B4E045A14A406571FF91E9304C40
53222	2552	53.193820000000002	53.217123000000001	56.250501999999997	56.23415	Советская	0103000020E61000000100000005000000C6A70018CF984A40E02D90A0F81D4C40C6A70018CF984A4092CA147310204C40CE1ABCAFCA9B4A4092CA147310204C40CE1ABCAFCA9B4A40E02D90A0F81D4C40C6A70018CF984A40E02D90A0F81D4C40
53105	2750	53.059271000000003	53.077525000000001	56.221899999999998	56.208669999999998	Нагорная	0103000020E61000000100000005000000F54C2F3196874A4002D4D4B2B51A4C40F54C2F3196874A40BF7D1D38671C4C40ABCFD556EC894A40BF7D1D38671C4C40ABCFD556EC894A4002D4D4B2B51A4C40F54C2F3196874A4002D4D4B2B51A4C40
52765	2887	53.171712999999997	53.191018	56.185080999999997	56.166581000000001	Чистопольская	0103000020E6100000010000000500000026A60BB1FA954A404791B58652154C4026A60BB1FA954A40340EF5BBB0174C4042791F4773984A40340EF5BBB0174C4042791F4773984A404791B58652154C4026A60BB1FA954A404791B58652154C40
52755	1893	53.017983999999998	53.042211999999999	56.391694999999999	56.376584999999999	Школьная	0103000020E61000000100000005000000F6ECB94C4D824A400395F1EF33304C40F6ECB94C4D824A40DC80CF0F23324C40D7BFEB3367854A40DC80CF0F23324C40D7BFEB3367854A400395F1EF33304C40F6ECB94C4D824A400395F1EF33304C40
52824	2140	53.225729000000001	53.250422999999998	56.380611999999999	56.368035999999996	Октябрьская	0103000020E61000000100000005000000206118B0E49C4A4015E0BBCD1B2F4C40206118B0E49C4A408A3BDEE4B7304C40469561DC0DA04A408A3BDEE4B7304C40469561DC0DA04A4015E0BBCD1B2F4C40206118B0E49C4A4015E0BBCD1B2F4C40
53055	3001	53.256334000000003	53.272773000000001	56.187475999999997	56.175462000000003	Советская	0103000020E610000001000000050000002B6D718DCFA04A406BD8EF8975164C402B6D718DCFA04A407764AC36FF174C40AC1DC539EAA24A407764AC36FF174C40AC1DC539EAA24A406BD8EF8975164C402B6D718DCFA04A406BD8EF8975164C40
53220	2706	53.035905999999997	53.080219	56.246386000000001	56.228304999999999	Школьная	0103000020E6100000010000000500000076DD5B9198844A40B3412619391D4C4076DD5B9198844A409C189293891F4C4048C2BE9D448A4A409C189293891F4C4048C2BE9D448A4A40B3412619391D4C4076DD5B9198844A40B3412619391D4C40
53004	2318	53.284928000000001	53.300370000000001	56.306866999999997	56.297542999999997	Советская	0103000020E610000001000000050000007BDB4C8578A44A40AD1397E315264C407BDB4C8578A44A405E9CF86A47274C408A592F8672A64A405E9CF86A47274C408A592F8672A64A40AD1397E315264C407BDB4C8578A44A40AD1397E315264C40
52420	1949	53.106217000000001	53.142589000000001	56.355220000000003	56.333508999999999	Советская	0103000020E61000000100000005000000BEA3C684988D4A40F9F5436CB02A4C40BEA3C684988D4A404C7155D9772D4C407AE2395B40924A404C7155D9772D4C407AE2395B40924A40F9F5436CB02A4C40BEA3C684988D4A40F9F5436CB02A4C40
52794	2604	53.057626999999997	53.083157	56.316369000000002	56.295574999999999	Гагарина	0103000020E61000000100000005000000EC2E505260874A40F241CF66D5254C40EC2E505260874A40EF3B86C77E284C407CB779E3A48A4A40EF3B86C77E284C407CB779E3A48A4A40F241CF66D5254C40EC2E505260874A40F241CF66D5254C40
53007	2367	53.344009999999997	53.361283999999998	56.303975999999999	56.289520000000003	Советская	0103000020E610000001000000050000009CBF098508AC4A40DBC4C9FD0E254C409CBF098508AC4A406B6281AFE8264C40B648DA8D3EAE4A406B6281AFE8264C40B648DA8D3EAE4A40DBC4C9FD0E254C409CBF098508AC4A40DBC4C9FD0E254C40
52907	3068	53.306702999999999	53.328144999999999	56.122926	56.113712	Восточная	0103000020E61000000100000005000000E44A3D0B42A74A40D594641D8E0E4C40E44A3D0B42A74A40FFE9060ABC0F4C4047ACC5A700AA4A40FFE9060ABC0F4C4047ACC5A700AA4A40D594641D8E0E4C40E44A3D0B42A74A40D594641D8E0E4C40
52972	2472	53.235826000000003	53.263314000000001	56.27375	56.255107000000002	Суворова 	0103000020E61000000100000005000000F4C5DE8B2F9E4A4087FD9E58A7204C40F4C5DE8B2F9E4A40D7A3703D0A234C401B4AED45B4A14A40D7A3703D0A234C401B4AED45B4A14A4087FD9E58A7204C40F4C5DE8B2F9E4A4087FD9E58A7204C40
52906	2808	53.246308999999997	53.276249999999997	56.150429000000003	56.133015999999998	Школьная	0103000020E61000000100000005000000F0DAA50D879F4A4020EC14AB06114C40F0DAA50D879F4A405CAFE94141134C408FC2F5285CA34A405CAFE94141134C408FC2F5285CA34A4020EC14AB06114C40F0DAA50D879F4A4020EC14AB06114C40
53006	2429	53.330122000000003	53.350746999999998	56.271850000000001	56.262217	Центральная	0103000020E6100000010000000500000056D80C7041AA4A4045BA9F5390214C4056D80C7041AA4A4074B515FBCB224C40C6151747E5AC4A4074B515FBCB224C40C6151747E5AC4A4045BA9F5390214C4056D80C7041AA4A4045BA9F5390214C40
53109	2950	53.251680999999998	53.265416000000002	56.169623999999999	56.158299999999997	Новая	0103000020E610000001000000050000002503401537A04A40787AA52C43144C402503401537A04A40F04E3E3DB6154C40E6EAC726F9A14A40F04E3E3DB6154C40E6EAC726F9A14A40787AA52C43144C402503401537A04A40787AA52C43144C40
53110	2664	53.052380999999997	53.062379	56.284959000000001	56.278108000000003	Советская	0103000020E6100000010000000500000044F7AC6BB4864A40C460FE0A99234C4044F7AC6BB4864A40B6D9588979244C40857AFA08FC874A40B6D9588979244C40857AFA08FC874A40C460FE0A99234C4044F7AC6BB4864A40C460FE0A99234C40
53003	2079	53.109324999999998	53.136291999999997	56.445000999999998	56.425437000000002	Советская	0103000020E610000001000000050000004ED1915CFE8D4A4012C138B874364C404ED1915CFE8D4A40F9D7F2CAF5384C406C5A290472914A40F9D7F2CAF5384C406C5A290472914A4012C138B874364C404ED1915CFE8D4A4012C138B874364C40
53011	2207	53.163601	53.181576	56.400064999999998	56.391038000000002	Юбилейная	0103000020E61000000100000005000000E44BA8E0F0944A4023BF7E880D324C40E44BA8E0F0944A401AA3755435334C4087DEE2E13D974A401AA3755435334C4087DEE2E13D974A4023BF7E880D324C40E44BA8E0F0944A4023BF7E880D324C40
52677	1232	51.570349	51.593390999999997	56.359059999999999	56.335999000000001	Центральная	0103000020E6100000010000000500000035272F3201C949408E3EE603022B4C4035272F3201C94940A0A696ADF52D4C40D05E7D3CF4CB4940A0A696ADF52D4C40D05E7D3CF4CB49408E3EE603022B4C4035272F3201C949408E3EE603022B4C40
52952	233	51.547963000000003	51.570053000000001	56.037398000000003	56.022030999999998	Нагорная	0103000020E610000001000000050000008335CEA623C64940C43F6CE9D1024C408335CEA623C64940C9772975C9044C404CFE277FF7C84940C9772975C9044C404CFE277FF7C84940C43F6CE9D1024C408335CEA623C64940C43F6CE9D1024C40
52848	32398	51.821904000000004	51.846617000000002	56.184846	56.173693	Школьная	0103000020E61000000100000005000000CE39782634E94940A6457D923B164C40CE39782634E94940F165A208A9174C406B9E23F25DEC4940F165A208A9174C406B9E23F25DEC4940A6457D923B164C40CE39782634E94940A6457D923B164C40
53042	497	51.628622999999997	51.648287000000003	56.175536999999998	56.162080000000003	Центральная	0103000020E61000000100000005000000B741EDB776D04940F8AA9509BF144C40B741EDB776D04940751E15FF77164C4003B68311FBD24940751E15FF77164C4003B68311FBD24940F8AA9509BF144C40B741EDB776D04940F8AA9509BF144C40
52754	910	51.336481999999997	51.360494000000003	56.364919999999998	56.351021000000003	Аллейная	0103000020E61000000100000005000000A9D898D711AB4940C89A9141EE2C4C40A9D898D711AB494002D4D4B2B52E4C40BE33DAAA24AE494002D4D4B2B52E4C40BE33DAAA24AE4940C89A9141EE2C4C40A9D898D711AB4940C89A9141EE2C4C40
53107	1363	51.390542000000003	51.406585999999997	56.340834000000001	56.326827000000002	Нижняя	0103000020E6100000010000000500000073DBBE47FDB1494093399677D5294C4073DBBE47FDB14940B4AED172A02B4C40778192020BB44940B4AED172A02B4C40778192020BB4494093399677D5294C4073DBBE47FDB1494093399677D5294C40
53005	49997	51.688172000000002	51.712012999999999	56.371406	56.357255000000002	Молодежная	0103000020E61000000100000005000000EF02250516D849408FAA2688BA2D4C40EF02250516D84940E3C4573B8A2F4C40D6A9F23D23DB4940E3C4573B8A2F4C40D6A9F23D23DB49408FAA2688BA2D4C40EF02250516D849408FAA2688BA2D4C40
52996	672	51.489455999999997	51.520671999999998	56.562157999999997	56.539884999999998	Школьная	0103000020E610000001000000050000005D6A847EA6BE4940EC4CA1F31A454C405D6A847EA6BE4940A69718CBF4474C40B1F84D61A5C24940A69718CBF4474C40B1F84D61A5C24940EC4CA1F31A454C405D6A847EA6BE4940EC4CA1F31A454C40
52997	719	51.321489	51.346094000000001	56.596559999999997	56.583609000000003	Верхняя	0103000020E610000001000000050000000A83328D26A949405D5320B3B34A4C400A83328D26A94940060DFD135C4C4C40C1ABE5CE4CAC4940060DFD135C4C4C40C1ABE5CE4CAC49405D5320B3B34A4C400A83328D26A949405D5320B3B34A4C40
53102	353	51.418094000000004	51.440182999999998	56.005142999999997	55.991737000000001	Школьная	0103000020E61000000100000005000000B153AC1A84B54940D89DEE3CF1FE4B40B153AC1A84B54940D3669C86A8004C40A9A0A2EA57B84940D3669C86A8004C40A9A0A2EA57B84940D89DEE3CF1FE4B40B153AC1A84B54940D89DEE3CF1FE4B40
52904	852	51.757468000000003	51.782145	56.428578000000002	56.414234999999998	Короленко	0103000020E610000001000000050000001EE21FB6F4E04940E5ED08A705354C401EE21FB6F4E049407EE4D6A4DB364C406EDDCD531DE449407EE4D6A4DB364C406EDDCD531DE44940E5ED08A705354C401EE21FB6F4E04940E5ED08A705354C40
53138	1252	51.501142999999999	51.532629	56.322969000000001	56.305314000000003	Шумиловка	0103000020E6100000010000000500000046CF2D7425C049406781768714274C4046CF2D7425C04940984F560C57294C405AF3E32F2DC44940984F560C57294C405AF3E32F2DC449406781768714274C4046CF2D7425C049406781768714274C40
52501	1252	51.501142999999999	51.532629	56.322969000000001	56.305314000000003	Механизаторов	0103000020E6100000010000000500000046CF2D7425C049406781768714274C4046CF2D7425C04940984F560C57294C405AF3E32F2DC44940984F560C57294C405AF3E32F2DC449406781768714274C4046CF2D7425C049406781768714274C40
52417	1448	51.490479999999998	51.548420999999998	56.301673999999998	56.266407000000001	Школьная	0103000020E61000000100000005000000C9AB730CC8BE49407636E49F19224C40C9AB730CC8BE4940D906EE409D264C4045B8C9A832C64940D906EE409D264C4045B8C9A832C649407636E49F19224C40C9AB730CC8BE49407636E49F19224C40
52502	1448	51.490479999999998	51.548420999999998	56.301673999999998	56.266407000000001	Савина	0103000020E61000000100000005000000C9AB730CC8BE49407636E49F19224C40C9AB730CC8BE4940D906EE409D264C4045B8C9A832C64940D906EE409D264C4045B8C9A832C649407636E49F19224C40C9AB730CC8BE49407636E49F19224C40
52521	1448	51.490479999999998	51.548420999999998	56.301673999999998	56.266407000000001	Первомайская	0103000020E61000000100000005000000C9AB730CC8BE49407636E49F19224C40C9AB730CC8BE4940D906EE409D264C4045B8C9A832C64940D906EE409D264C4045B8C9A832C649407636E49F19224C40C9AB730CC8BE49407636E49F19224C40
52563	1448	51.490479999999998	51.548420999999998	56.301673999999998	56.266407000000001	Карла Маркса	0103000020E61000000100000005000000C9AB730CC8BE49407636E49F19224C40C9AB730CC8BE4940D906EE409D264C4045B8C9A832C64940D906EE409D264C4045B8C9A832C649407636E49F19224C40C9AB730CC8BE49407636E49F19224C40
52757	1448	51.490479999999998	51.548420999999998	56.301673999999998	56.266407000000001	Гоголя	0103000020E61000000100000005000000C9AB730CC8BE49407636E49F19224C40C9AB730CC8BE4940D906EE409D264C4045B8C9A832C64940D906EE409D264C4045B8C9A832C649407636E49F19224C40C9AB730CC8BE49407636E49F19224C40
52726	1448	51.490479999999998	51.548420999999998	56.301673999999998	56.266407000000001	Вокзальная	0103000020E61000000100000005000000C9AB730CC8BE49407636E49F19224C40C9AB730CC8BE4940D906EE409D264C4045B8C9A832C64940D906EE409D264C4045B8C9A832C649407636E49F19224C40C9AB730CC8BE49407636E49F19224C40
53002	990	51.398097	51.419756	56.420234999999998	56.409125000000003	Школьная	0103000020E610000001000000050000005FD1ADD7F4B24940EE7C3F355E344C405FD1ADD7F4B2494039D1AE42CA354C405F268A90BAB5494039D1AE42CA354C405F268A90BAB54940EE7C3F355E344C405FD1ADD7F4B24940EE7C3F355E344C40
52905	597	51.603361999999997	51.645932999999999	56.567459999999997	56.551864000000002	Центральная	0103000020E6100000010000000500000017D34CF73ACD49407DEBC37AA3464C4017D34CF73ACD4940E2E47E87A2484C401E34BBEEADD24940E2E47E87A2484C401E34BBEEADD249407DEBC37AA3464C4017D34CF73ACD49407DEBC37AA3464C40
52903	983	51.304259000000002	51.318829999999998	56.397055999999999	56.379714999999997	Школьная	0103000020E61000000100000005000000C0417BF5F1A649407B6649809A304C40C0417BF5F1A649401D5723BBD2324C40E97DE36BCFA849401D5723BBD2324C40E97DE36BCFA849407B6649809A304C40C0417BF5F1A649407B6649809A304C40
53104	32493	51.759920999999999	51.780735	56.306432999999998	56.298622000000002	Шанхайская	0103000020E610000001000000050000009545611745E14940DDEEE53E39264C409545611745E1494024B5503239274C40D9EBDD1FEFE3494024B5503239274C40D9EBDD1FEFE34940DDEEE53E39264C409545611745E14940DDEEE53E39264C40
53217	32424	51.702015000000003	51.726520999999998	56.231808000000001	56.223931999999998	Молодежная	0103000020E610000001000000050000009626A5A0DBD949409143C4CDA91C4C409626A5A0DBD94940C07971E2AB1D4C40B96DDFA3FEDC4940C07971E2AB1D4C40B96DDFA3FEDC49409143C4CDA91C4C409626A5A0DBD949409143C4CDA91C4C40
52792	160	51.707998000000003	51.736941999999999	56.165362999999999	56.129800000000003	Коммунальная	0103000020E6100000010000000500000014D1AFAD9FDA4940AA8251499D104C4014D1AFAD9FDA4940F67B629D2A154C4040868E1D54DE4940F67B629D2A154C4040868E1D54DE4940AA8251499D104C4014D1AFAD9FDA4940AA8251499D104C40
53101	1103	51.263052999999999	51.289760000000001	56.467111000000003	56.452454000000003	Полевая	0103000020E61000000100000005000000AE0E80B8ABA14940E2783E03EA394C40AE0E80B8ABA149400A4D124BCA3B4C4030D80DDB16A549400A4D124BCA3B4C4030D80DDB16A54940E2783E03EA394C40AE0E80B8ABA14940E2783E03EA394C40
53214	433	51.516603000000003	51.543399999999998	56.211924000000003	56.198891000000003	Центральная	0103000020E61000000100000005000000FC010F0C20C24940003CA24275194C40FC010F0C20C24940679E5C53201B4C40BD5296218EC54940679E5C53201B4C40BD5296218EC54940003CA24275194C40FC010F0C20C24940003CA24275194C40
53040	74	51.659695999999997	51.685468	56.211258000000001	56.202630999999997	Молодежная	0103000020E61000000100000005000000A8A624EB70D44940F01307D0EF194C40A8A624EB70D449405A828C800A1B4C402E3A596ABDD749405A828C800A1B4C402E3A596ABDD74940F01307D0EF194C40A8A624EB70D44940F01307D0EF194C40
52987	31005	53.762804000000003	53.785845999999999	57.941060999999998	57.923667999999999	Школьная	0103000020E6100000010000000500000006A1BC8FA3E14A404D2EC6C03AF64C4006A1BC8FA3E14A404145D5AF74F84C40A1D80A9A96E44A404145D5AF74F84C40A1D80A9A96E44A404D2EC6C03AF64C4006A1BC8FA3E14A404D2EC6C03AF64C40
52999	30919	53.759515999999998	53.778390000000002	57.986001000000002	57.978499999999997	Ю-Чабьинская	0103000020E61000000100000005000000F564FED137E14A406891ED7C3FFD4C40F564FED137E14A406269E04735FE4C4048C49448A2E34A406269E04735FE4C4048C49448A2E34A406891ED7C3FFD4C40F564FED137E14A406891ED7C3FFD4C40
52898	30852	53.781489000000001	53.813181999999998	58.035778000000001	58.027763	Центральная	0103000020E610000001000000050000008597E0D407E44A40F984ECBC8D034D408597E0D407E44A4049F59D5F94044D4012D9075916E84A4049F59D5F94044D4012D9075916E84A40F984ECBC8D034D408597E0D407E44A40F984ECBC8D034D40
52753	31722	53.372647999999998	53.428460000000001	57.899546999999998	57.876179999999998	Школьная	0103000020E61000000100000005000000BC75FEEDB2AF4A4063B48EAA26F04C40BC75FEEDB2AF4A40821B295B24F34C4074D2FBC6D7B64A40821B295B24F34C4074D2FBC6D7B64A4063B48EAA26F04C40BC75FEEDB2AF4A4063B48EAA26F04C40
52675	31722	53.372647999999998	53.428460000000001	57.899546999999998	57.876179999999998	Пионерская	0103000020E61000000100000005000000BC75FEEDB2AF4A4063B48EAA26F04C40BC75FEEDB2AF4A40821B295B24F34C4074D2FBC6D7B64A40821B295B24F34C4074D2FBC6D7B64A4063B48EAA26F04C40BC75FEEDB2AF4A4063B48EAA26F04C40
53108	30963	53.928400000000003	53.945701	57.983300999999997	57.973979999999997	Рабочая	0103000020E610000001000000050000009FCDAACFD5F64A40A27A6B60ABFC4C409FCDAACFD5F64A40E28FA2CEDCFD4C40B265F9BA0CF94A40E28FA2CEDCFD4C40B265F9BA0CF94A40A27A6B60ABFC4C409FCDAACFD5F64A40A27A6B60ABFC4C40
52992	31276	53.845844999999997	53.869138	57.867933000000001	57.856285	Школьная	0103000020E61000000100000005000000183E22A644EC4A40168733BF9AED4C40183E22A644EC4A40410FB56D18EF4C40FDDAFAE93FEF4A40410FB56D18EF4C40FDDAFAE93FEF4A40168733BF9AED4C40183E22A644EC4A40168733BF9AED4C40
52912	31239	53.923378	53.958205999999997	57.818655999999997	57.808318999999997	переулок Церковный	0103000020E6100000010000000500000046EC134031F64A4022DE3AFF76E74C4046EC134031F64A404B5645B8C9E84C405D6A847EA6FA4A404B5645B8C9E84C405D6A847EA6FA4A4022DE3AFF76E74C4046EC134031F64A4022DE3AFF76E74C40
52933	30665	53.489761000000001	53.507809000000002	58.260359000000001	58.248430999999997	Советская	0103000020E610000001000000050000009AED0A7DB0BE4A4002284696CC1F4D409AED0A7DB0BE4A40111C977153214D40A7CEA3E2FFC04A40111C977153214D40A7CEA3E2FFC04A4002284696CC1F4D409AED0A7DB0BE4A4002284696CC1F4D40
52901	31519	53.580886	53.598754	57.910646	57.903655000000001	Новая	0103000020E61000000100000005000000255AF2785ACA4A40F6EE8FF7AAF34C40255AF2785ACA4A40DA1D520C90F44C40B22C98F8A3CC4A40DA1D520C90F44C40B22C98F8A3CC4A40F6EE8FF7AAF34C40255AF2785ACA4A40F6EE8FF7AAF34C40
52860	30603	53.746940000000002	53.758195999999998	58.221083999999998	58.217300999999999	Советская	0103000020E610000001000000050000008109DCBA9BDF4A40AD31E884D01B4D408109DCBA9BDF4A409DD5027B4C1C4D40A0FA07910CE14A409DD5027B4C1C4D40A0FA07910CE14A40AD31E884D01B4D408109DCBA9BDF4A40AD31E884D01B4D40
53098	31461	53.601260000000003	53.629153000000002	57.854221000000003	57.837192000000002	Садовая	0103000020E610000001000000050000004D327216F6CC4A40863C821B29EB4C404D327216F6CC4A4039471D1D57ED4C401497E31588D04A4039471D1D57ED4C401497E31588D04A40863C821B29EB4C404D327216F6CC4A40863C821B29EB4C40
53103	31555	53.512847999999998	53.564096999999997	58.132058999999998	58.114763000000004	Центральная	0103000020E61000000100000005000000D5E8D500A5C14A403BE5D18DB00E4D40D5E8D500A5C14A403C122F4FE7104D40C7629B5434C84A403C122F4FE7104D40C7629B5434C84A403BE5D18DB00E4D40D5E8D500A5C14A403BE5D18DB00E4D40
52995	32064	53.530644000000002	53.550550000000001	57.934196	57.915703999999998	Комсомольская	0103000020E61000000100000005000000C9E88024ECC34A407F68E6C935F54C40C9E88024ECC34A40EA060ABC93F74C400A68226C78C64A40EA060ABC93F74C400A68226C78C64A407F68E6C935F54C40C9E88024ECC34A407F68E6C935F54C40
52899	31970	53.341287999999999	53.363809000000003	57.779384	57.766824	Школьная	0103000020E6100000010000000500000035423F53AFAB4A40DAE4F04927E24C4035423F53AFAB4A404983DBDAC2E34C40C87E164B91AE4A404983DBDAC2E34C40C87E164B91AE4A40DAE4F04927E24C4035423F53AFAB4A40DAE4F04927E24C40
53213	31923	53.438476999999999	53.477428000000003	57.780354000000003	57.766536000000002	Центральная	0103000020E610000001000000050000002B86AB0320B84A40749A05DA1DE24C402B86AB0320B84A40C2A6CEA3E2E34C40EC18575C1CBD4A40C2A6CEA3E2E34C40EC18575C1CBD4A40749A05DA1DE24C402B86AB0320B84A40749A05DA1DE24C40
53001	56397	53.625684999999997	53.655258000000003	57.984206999999998	57.972892000000002	Трактовая	0103000020E61000000100000005000000834C327216D04A4020459DB987FC4C40834C327216D04A4044BFB67EFAFD4C40A038807EDFD34A4044BFB67EFAFD4C40A038807EDFD34A4020459DB987FC4C40834C327216D04A4020459DB987FC4C40
52990	30764	53.840113000000002	53.857135999999997	58.139555999999999	58.132035000000002	Центральная	0103000020E61000000100000005000000E4F8A1D288EB4A40B476DB85E6104D40E4F8A1D288EB4A40F4FA93F8DC114D40B41CE8A1B6ED4A40F4FA93F8DC114D40B41CE8A1B6ED4A40B476DB85E6104D40E4F8A1D288EB4A40B476DB85E6104D40
53168	31346	53.709389999999999	53.728470999999999	57.806195000000002	57.791451000000002	Центральная	0103000020E61000000100000005000000020EA14ACDDA4A4079B130444EE54C40020EA14ACDDA4A407099D36531E74C40CE8AA8893EDD4A407099D36531E74C40CE8AA8893EDD4A4079B130444EE54C40020EA14ACDDA4A4079B130444EE54C40
52663	30689	53.743347	53.780051999999998	58.201132999999999	58.166943000000003	Советская	0103000020E61000000100000005000000344A97FE25DF4A40E8A562635E154D40344A97FE25DF4A40BC92E4B9BE194D40F69672BED8E34A40BC92E4B9BE194D40F69672BED8E34A40E8A562635E154D40344A97FE25DF4A40E8A562635E154D40
52789	31060	54.018348000000003	54.059697999999997	57.957959000000002	57.9313	Кооперативная	0103000020E6100000010000000500000038F92D3A59024B40E561A1D634F74C4038F92D3A59024B4056F487669EFA4C407CD11E2FA4074B4056F487669EFA4C407CD11E2FA4074B40E561A1D634F74C4038F92D3A59024B40E561A1D634F74C40
53209	30810	53.740104000000002	53.764851999999998	58.074036	58.061117000000003	Набережная	0103000020E61000000100000005000000C4D155BABBDE4A40651D8EAED2074D40C4D155BABBDE4A40035DFB027A094D40DD239BABE6E14A40035DFB027A094D40DD239BABE6E14A40651D8EAED2074D40C4D155BABBDE4A40651D8EAED2074D40
52559	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	Тургенева	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
52561	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	Некрасова	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
52633	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	Мира	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
52416	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	Малокезская	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
52632	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	Ленина	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
52503	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	Клубничная	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
53100	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	Ангарская	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
52500	31399	53.677249000000003	53.741909999999997	57.909910000000004	57.885142999999999	1-я Лесная	0103000020E61000000100000005000000D61F6118B0D64A4044A4A65D4CF14C40D61F6118B0D64A40D5264EEE77F44C40A54929E8F6DE4A40D5264EEE77F44C40A54929E8F6DE4A4044A4A65D4CF14C40D61F6118B0D64A4044A4A65D4CF14C40
53211	21224	53.849034000000003	53.886287000000003	57.928446999999998	57.917698000000001	Комсомольская	0103000020E6100000010000000500000096986725ADEC4A4064CDC82077F54C4096986725ADEC4A40DF88EE59D7F64C405BEF37DA71F14A40DF88EE59D7F64C405BEF37DA71F14A4064CDC82077F54C4096986725ADEC4A4064CDC82077F54C40
53215	21194	54.035181999999999	54.053607	57.966037999999998	57.960470999999998	Цветочная	0103000020E6100000010000000500000035B401D880044B40D2E0B6B6F0FA4C4035B401D880044B40BC581822A7FB4C4018EB1B98DC064B40BC581822A7FB4C4018EB1B98DC064B40D2E0B6B6F0FA4C4035B401D880044B40D2E0B6B6F0FA4C40
53054	31618	53.411231000000001	53.432502999999997	58.058244999999999	58.048354000000003	Родниковая	0103000020E61000000100000005000000FA0CA837A3B44A40BE50C07630064D40FA0CA837A3B44A40E813799274074D40003620425CB74A40E813799274074D40003620425CB74A40BE50C07630064D40FA0CA837A3B44A40BE50C07630064D40
53016	31859	53.448977999999997	53.474634000000002	57.951804000000003	57.942466000000003	Новая	0103000020E61000000100000005000000CE4F711C78B94A40C5CBD3B9A2F84C40CE4F711C78B94A40DB19A6B6D4F94C40EBC891CEC0BC4A40DB19A6B6D4F94C40EBC891CEC0BC4A40C5CBD3B9A2F84C40CE4F711C78B94A40C5CBD3B9A2F84C40
52847	31612	53.513449999999999	53.542923999999999	58.055174000000001	58.043247999999998	Клубный переулок	0103000020E61000000100000005000000CB10C7BAB8C14A4007CF842689054D40CB10C7BAB8C14A4075CB0EF10F074D40541B9C887EC54A4075CB0EF10F074D40541B9C887EC54A4007CF842689054D40CB10C7BAB8C14A4007CF842689054D40
53218	31691	53.548932999999998	53.573726999999998	58.040222999999997	58.024017000000001	Школьная	0103000020E61000000100000005000000FB58C16F43C64A4026C632FD12034D40FB58C16F43C64A4004C6FA0626054D4085EAE6E26FC94A4004C6FA0626054D4085EAE6E26FC94A4026C632FD12034D40FB58C16F43C64A4026C632FD12034D40
52842	30393	53.504925	53.542662999999997	55.960185000000003	55.948331000000003	Моргунова	0103000020E6100000010000000500000066F7E461A1C04A40396403E962F94B4066F7E461A1C04A400D8E9257E7FA4B40E7DF2EFB75C54A400D8E9257E7FA4B40E7DF2EFB75C54A40396403E962F94B4066F7E461A1C04A40396403E962F94B40
52894	30346	53.463099	53.483671000000001	56.081938999999998	56.068795999999999	В. Исенкова 	0103000020E61000000100000005000000B8E7F9D346BB4A403D0CAD4ECE084C40B8E7F9D346BB4A402BA226FA7C0A4C4006836BEEE8BD4A402BA226FA7C0A4C4006836BEEE8BD4A403D0CAD4ECE084C40B8E7F9D346BB4A403D0CAD4ECE084C40
53203	29774	53.659731999999998	53.673214999999999	56.208289000000001	56.192104	 Центральная	0103000020E61000000100000005000000F50F221972D44A4024B726DD96184C40F50F221972D44A40EB8EC536A91A4C409C16BCE82BD64A40EB8EC536A91A4C409C16BCE82BD64A4024B726DD96184C40F50F221972D44A4024B726DD96184C40
52844	30553	53.324551999999997	53.352713999999999	55.909125000000003	55.898522999999997	Князева	0103000020E61000000100000005000000FAEC80EB8AA94A4016DA39CD02F34B40FAEC80EB8AA94A40EE7C3F355EF44B40B16B7BBB25AD4A40EE7C3F355EF44B40B16B7BBB25AD4A4016DA39CD02F34B40FAEC80EB8AA94A4016DA39CD02F34B40
53247	56413	53.886789999999998	53.911664000000002	56.190336000000002	56.176929999999999	Садовая	0103000020E61000000100000005000000BD35B05582F14A4034D769A4A5164C40BD35B05582F14A4030A017EE5C184C406478EC67B1F44A4030A017EE5C184C406478EC67B1F44A4034D769A4A5164C40BD35B05582F14A4034D769A4A5164C40
53205	30269	53.558059999999998	53.575515000000003	56.065413999999997	56.047314	Школьная	0103000020E61000000100000005000000569A94826EC74A404C5299620E064C40569A94826EC74A40AB59677C5F084C40C1ADBB79AAC94A40AB59677C5F084C40C1ADBB79AAC94A404C5299620E064C40569A94826EC74A404C5299620E064C40
53204	29805	53.701917000000002	53.722361999999997	56.200747999999997	56.182305999999997	Мира	0103000020E61000000100000005000000D3C08F6AD8D94A40AAEE91CD55174C40D3C08F6AD8D94A40635E471CB2194C40C3EFA65B76DC4A40635E471CB2194C40C3EFA65B76DC4A40AAEE91CD55174C40D3C08F6AD8D94A40AAEE91CD55174C40
53207	30457	53.551690999999998	53.583967999999999	55.993926999999999	55.970039999999997	Комсомольская	0103000020E61000000100000005000000AF3F89CF9DC64A40EAE74D452AFC4B40AF3F89CF9DC64A4042CEFBFF38FF4B408CF4A276BFCA4A4042CEFBFF38FF4B408CF4A276BFCA4A40EAE74D452AFC4B40AF3F89CF9DC64A40EAE74D452AFC4B40
52751	20470	53.675829	53.741433000000001	56.025089999999999	56.001739999999998	Раскольникова	0103000020E610000001000000050000001D588E9081D64A402A8C2D0439004C401D588E9081D64A4073BA2C2636034C406C96CB46E7DE4A4073BA2C2636034C406C96CB46E7DE4A402A8C2D0439004C401D588E9081D64A402A8C2D0439004C40
52843	20470	53.675829	53.741433000000001	56.025089999999999	56.001739999999998	Кирьянова	0103000020E610000001000000050000001D588E9081D64A402A8C2D0439004C401D588E9081D64A4073BA2C2636034C406C96CB46E7DE4A4073BA2C2636034C406C96CB46E7DE4A402A8C2D0439004C401D588E9081D64A402A8C2D0439004C40
52790	20470	53.675829	53.741433000000001	56.025089999999999	56.001739999999998	Каманина	0103000020E610000001000000050000001D588E9081D64A402A8C2D0439004C401D588E9081D64A4073BA2C2636034C406C96CB46E7DE4A4073BA2C2636034C406C96CB46E7DE4A402A8C2D0439004C401D588E9081D64A402A8C2D0439004C40
52840	20470	53.675829	53.741433000000001	56.025089999999999	56.001739999999998	Девятьярова	0103000020E610000001000000050000001D588E9081D64A402A8C2D0439004C401D588E9081D64A4073BA2C2636034C406C96CB46E7DE4A4073BA2C2636034C406C96CB46E7DE4A402A8C2D0439004C401D588E9081D64A402A8C2D0439004C40
52893	29968	54.088515000000001	54.119067000000001	56.160635999999997	56.148549000000003	Камская	0103000020E610000001000000050000004C1AA375540B4B40406D54A703134C404C1AA375540B4B40B6476FB88F144C40348463963D0F4B40B6476FB88F144C40348463963D0F4B40406D54A703134C404C1AA375540B4B40406D54A703134C40
53206	30009	53.851567000000003	53.895108	56.074176999999999	56.050747000000001	Школьная	0103000020E610000001000000050000002AADBF2500ED4A4060AFB0E07E064C402AADBF2500ED4A40C58EC6A17E094C40A93121E692F24A40C58EC6A17E094C40A93121E692F24A4060AFB0E07E064C402AADBF2500ED4A4060AFB0E07E064C40
53097	30514	53.407718000000003	53.428837999999999	55.915624000000001	55.892646999999997	8-е Марта	0103000020E61000000100000005000000CAFE791A30B44A40AEEFC34142F24B40CAFE791A30B44A4063B7CF2A33F54B401AA4E029E4B64A4063B7CF2A33F54B401AA4E029E4B64A40AEEFC34142F24B40CAFE791A30B44A40AEEFC34142F24B40
52791	30056	54.014538999999999	54.038246000000001	56.063383999999999	56.051295000000003	Новая	0103000020E610000001000000050000001EC2F869DC014B4063B9A5D590064C401EC2F869DC014B407A8B87F71C084C40F699B33EE5044B407A8B87F71C084C40F699B33EE5044B4063B9A5D590064C401EC2F869DC014B4063B9A5D590064C40
52808	29713	53.687409000000002	53.709389999999999	56.155448	56.133557000000003	Ленина	0103000020E61000000100000005000000F0FCA204FDD74A407193516518114C40F0FCA204FDD74A40431D56B8E5134C40020EA14ACDDA4A40431D56B8E5134C40020EA14ACDDA4A407193516518114C40F0FCA204FDD74A407193516518114C40
52560	29528	54.044362999999997	54.075831000000001	56.363737999999998	56.341258000000003	Рейда	0103000020E610000001000000050000008313D1AFAD054B40CBBF9657AE2B4C408313D1AFAD054B40FE277FF78E2E4C40F18288D4B4094B40FE277FF78E2E4C40F18288D4B4094B40CBBF9657AE2B4C408313D1AFAD054B40CBBF9657AE2B4C40
52787	29592	53.968842000000002	53.989620000000002	56.453189999999999	56.438059000000003	Школьная	0103000020E61000000100000005000000E17EC00303FC4A40F75B3B5112384C40E17EC00303FC4A40E76F4221023A4C40D8BB3FDEABFE4A40E76F4221023A4C40D8BB3FDEABFE4A40F75B3B5112384C40E17EC00303FC4A40F75B3B5112384C40
53202	29305	54.262295000000002	54.287142000000003	56.420926999999999	56.405569	Юбилейная	0103000020E61000000100000005000000C173EFE192214B40BEA25BAFE9334C40C173EFE192214B406F8099EFE0354C406EA7AD11C1244B406F8099EFE0354C406EA7AD11C1244B40BEA25BAFE9334C40C173EFE192214B40BEA25BAFE9334C40
52558	29443	54.085290999999998	54.147202	56.321385999999997	56.280296999999997	Гагарина	0103000020E6100000010000000500000052D2C3D0EA0A4B405D15A8C5E0234C4052D2C3D0EA0A4B4035B22B2D23294C40F1F3DF83D7124B4035B22B2D23294C40F1F3DF83D7124B405D15A8C5E0234C4052D2C3D0EA0A4B405D15A8C5E0234C40
53095	22241	53.866757	53.889493999999999	56.468184999999998	56.442050000000002	Советская	0103000020E610000001000000050000001F4AB4E4F1EE4A4031992A1895384C401F4AB4E4F1EE4A4027BD6F7CED3B4C407EFE7BF0DAF14A4027BD6F7CED3B4C407EFE7BF0DAF14A4031992A1895384C401F4AB4E4F1EE4A4031992A1895384C40
52786	29673	53.889763000000002	53.903022	56.435447000000003	56.429693	Ленина	0103000020E610000001000000050000006E1805C1E3F14A40FA28232E00374C406E1805C1E3F14A40171230BABC374C40C5C8923996F34A40171230BABC374C40C5C8923996F34A40FA28232E00374C406E1805C1E3F14A40FA28232E00374C40
53000	29279	54.288040000000002	54.309618	56.338698999999998	56.320307999999997	пер. Клубный	0103000020E610000001000000050000004DF8A57EDE244B40D65240DAFF284C404DF8A57EDE244B400D18247D5A2B4C4060200890A1274B400D18247D5A2B4C4060200890A1274B40D65240DAFF284C404DF8A57EDE244B40D65240DAFF284C40
52456	40334	53.207555999999997	53.232151999999999	56.877429999999997	56.875492000000001	Холмогорова	0103000020E61000000100000005000000560BEC31919A4A406FF4311F10704C40560BEC31919A4A40BF4351A04F704C40BAD91F28B79D4A40BF4351A04F704C40BAD91F28B79D4A406FF4311F10704C40560BEC31919A4A406FF4311F10704C40
52782	28157	53.224471000000001	53.268416000000002	57.400550000000003	57.377431000000001	Совхозная	0103000020E6100000010000000500000041F33977BB9C4A4090BFB4A84FB04C4041F33977BB9C4A40D734EF3845B34C4090DC9A745BA24A40D734EF3845B34C4090DC9A745BA24A4090BFB4A84FB04C4041F33977BB9C4A4090BFB4A84FB04C40
52891	28252	53.076580999999997	53.154967999999997	57.582234	57.400500999999998	Труда	0103000020E610000001000000050000005B3FFD67CD894A40F581E49D43B34C405B3FFD67CD894A40444FCAA486CA4C4098F6CDFDD5934A40444FCAA486CA4C4098F6CDFDD5934A40F581E49D43B34C405B3FFD67CD894A40F581E49D43B34C40
52492	27514	53.010581999999999	53.042050000000003	57.645415999999997	57.620848000000002	Кирова	0103000020E6100000010000000500000090F63FC05A814A40BDE47FF277CF4C4090F63FC05A814A405628D2FD9CD24C40FE65F7E461854A405628D2FD9CD24C40FE65F7E461854A40BDE47FF277CF4C4090F63FC05A814A40BDE47FF277CF4C40
53169	28237	53.110608999999997	53.135798000000001	57.452176999999999	57.439405999999998	Трактовая	0103000020E6100000010000000500000056D28A6F288E4A4045D5AF743EB84C4056D28A6F288E4A406F8099EFE0B94C405D6E30D461914A406F8099EFE0B94C405D6E30D461914A4045D5AF743EB84C4056D28A6F288E4A4045D5AF743EB84C40
52783	28350	53.094925000000003	53.127721999999999	57.531632000000002	57.518743000000001	Сельская	0103000020E6100000010000000500000052499D80268C4A40B403AE2B66C24C4052499D80268C4A40E8C072840CC44C40677DCA3159904A40E8C072840CC44C40677DCA3159904A40B403AE2B66C24C4052499D80268C4A40B403AE2B66C24C40
53200	27710	53.231855000000003	53.256711000000003	57.607059999999997	57.598418000000002	 Молодежная	0103000020E610000001000000050000000135B56CAD9D4A403BAB05F698CC4C400135B56CAD9D4A40D95A5F24B4CD4C4001C3F2E7DBA04A40D95A5F24B4CD4C4001C3F2E7DBA04A403BAB05F698CC4C400135B56CAD9D4A403BAB05F698CC4C40
52749	27939	53.297055	53.329636999999998	57.532173	57.519477999999999	Труда	0103000020E61000000100000005000000800EF3E505A64A40E97E4E417EC24C40800EF3E505A64A403868AF3E1EC44C409946938B31AA4A403868AF3E1EC44C409946938B31AA4A40E97E4E417EC24C40800EF3E505A64A40E97E4E417EC24C40
52983	27836	53.458734	53.483131999999998	57.581972999999998	57.571381000000002	Молодежная	0103000020E6100000010000000500000019C8B3CBB7BA4A4024473A0323C94C4019C8B3CBB7BA4A40D7135D177ECA4C4056D3F544D7BD4A40D7135D177ECA4C4056D3F544D7BD4A4024473A0323C94C4019C8B3CBB7BA4A4024473A0323C94C40
52838	28684	52.54927	52.591831999999997	57.469586	57.448729	Центральная	0103000020E610000001000000050000004356B77A4E464A4026E2ADF36FB94C404356B77A4E464A406954E0641BBC4C40F65CA626C14B4A406954E0641BBC4C40F65CA626C14B4A4026E2ADF36FB94C404356B77A4E464A4026E2ADF36FB94C40
52863	28052	53.417015999999997	53.440964999999998	57.403319000000003	57.388066000000002	Вепревых	0103000020E6100000010000000500000051F4C0C760B54A4043588D25ACB14C4051F4C0C760B54A407F6DFDF49FB34C401FD7868A71B84A407F6DFDF49FB34C401FD7868A71B84A4043588D25ACB14C4051F4C0C760B54A4043588D25ACB14C40
52554	27624	53.076526999999999	53.119781000000003	57.648735000000002	57.625160999999999	Ленина	0103000020E61000000100000005000000682101A3CB894A4009DE904605D04C40682101A3CB894A40A2629CBF09D34C4052D7DAFB548F4A40A2629CBF09D34C4052D7DAFB548F4A4009DE904605D04C40682101A3CB894A4009DE904605D04C40
53167	28743	52.53443	52.556232000000001	57.541283999999997	57.52505	Железнодорожная	0103000020E610000001000000050000002A00C63368444A40E561A1D634C34C402A00C63368444A408DEC4ACB48C54C408D7E349C32474A408DEC4ACB48C54C408D7E349C32474A40E561A1D634C34C402A00C63368444A40E561A1D634C34C40
52890	28786	52.400168000000001	52.408819000000001	57.367240000000002	57.362721000000001	 Клубная	0103000020E61000000100000005000000EF737CB438334A40454948A46DAE4C40EF737CB438334A403BE466B801AF4C40E17D552E54344A403BE466B801AF4C40E17D552E54344A40454948A46DAE4C40EF737CB438334A40454948A46DAE4C40
53133	14006	53.241	53.252319	57.411521999999998	57.403987999999998	Центральная	0103000020E61000000100000005000000022B8716D99E4A40FCFCF7E0B5B34C40022B8716D99E4A40D1CABDC0ACB44C4068942EFD4BA04A40D1CABDC0ACB44C4068942EFD4BA04A40FCFCF7E0B5B34C40022B8716D99E4A40FCFCF7E0B5B34C40
52798	28508	53.178603000000003	53.205885000000002	57.479971999999997	57.466368000000003	Северная	0103000020E61000000100000005000000D7FB8D76DC964A4052F355F2B1BB4C40D7FB8D76DC964A40737FF5B86FBD4C4055DE8E705A9A4A40737FF5B86FBD4C4055DE8E705A9A4A4052F355F2B1BB4C40D7FB8D76DC964A4052F355F2B1BB4C40
52671	27722	53.283670000000001	53.297522000000001	57.684694	57.675263000000001	 Молодежная	0103000020E610000001000000050000009C6D6E4C4FA44A4074999A046FD64C409C6D6E4C4FA44A403BE2900DA4D74C4096EB6D3315A64A403BE2900DA4D74C4096EB6D3315A64A4074999A046FD64C409C6D6E4C4FA44A4074999A046FD64C40
52784	28325	53.000062999999997	53.071973	57.531202	57.34543	Советская	0103000020E6100000010000000500000046787B1002804A405587DC0C37AC4C4046787B1002804A40EFC8586DFEC34C40F698486936894A40EFC8586DFEC34C40F698486936894A405587DC0C37AC4C4046787B1002804A405587DC0C37AC4C40
53048	28448	53.106208000000002	53.133139	57.491089000000002	57.475954999999999	Труда	0103000020E610000001000000050000006B494739988D4A4010AFEB17ECBC4C406B494739988D4A4072361D01DCBE4C403C69E1B20A914A4072361D01DCBE4C403C69E1B20A914A4010AFEB17ECBC4C406B494739988D4A4010AFEB17ECBC4C40
53201	28518	53.084513000000001	53.122107999999997	57.463467999999999	57.446216	Советская	0103000020E610000001000000050000001E8B6D52D18A4A40D9791B9B1DB94C401E8B6D52D18A4A400B5F5FEB52BB4C403C4A253CA18F4A400B5F5FEB52BB4C403C4A253CA18F4A40D9791B9B1DB94C401E8B6D52D18A4A40D9791B9B1DB94C40
52985	28427	53.167490999999998	53.194234000000002	57.522174999999997	57.510509999999996	Мира	0103000020E61000000100000005000000EAAF575870954A40F623456458C14C40EAAF575870954A40F7E461A1D6C24C40B9E2E2A8DC984A40F7E461A1D6C24C40B9E2E2A8DC984A40F623456458C14C40EAAF575870954A40F623456458C14C40
52734	28597	53.024524	53.043523	57.534801000000002	57.521183999999998	Парковая	0103000020E61000000100000005000000CAFB389A23834A4067994528B6C24C40CAFB389A23834A401E6FF25B74C44C40D9CF622992854A401E6FF25B74C44C40D9CF622992854A4067994528B6C24C40CAFB389A23834A4067994528B6C24C40
52837	27640	53.160924000000001	53.182313000000001	57.588033000000003	57.579590000000003	Молодежная	0103000020E610000001000000050000001D925A2899944A40598B4F0130CA4C401D925A2899944A4001FC53AA44CB4C405D514A0856974A4001FC53AA44CB4C405D514A0856974A40598B4F0130CA4C401D925A2899944A40598B4F0130CA4C40
52491	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	мрн.Нефтяников	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52674	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Трактовая	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52414	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Пугачева	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52495	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Пионерская	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52490	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Мкр. Нефтяников	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52788	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Мира	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52418	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Ломоносова	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52493	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Лесная	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52419	21547	53.010088000000003	53.123437000000003	57.569904000000001	57.531635999999999	Коммунальная	0103000020E61000000100000005000000810A47904A814A4029B000A60CC44C40810A47904A814A4007EE409DF2C84C40E50E9BC8CC8F4A4007EE409DF2C84C40E50E9BC8CC8F4A4029B000A60CC44C40810A47904A814A4029B000A60CC44C40
52553	27790	53.360368000000001	53.433391999999998	57.619450000000001	57.590055	Льнозаводская	0103000020E610000001000000050000003143E38920AE4A40AFEB17EC86CB4C403143E38920AE4A40ECC039234ACF4C408C2C996379B74A40ECC039234ACF4C408C2C996379B74A40AFEB17EC86CB4C403143E38920AE4A40AFEB17EC86CB4C40
52640	27790	53.360368000000001	53.433391999999998	57.619450000000001	57.590055	Ленина	0103000020E610000001000000050000003143E38920AE4A40AFEB17EC86CB4C403143E38920AE4A40ECC039234ACF4C408C2C996379B74A40ECC039234ACF4C408C2C996379B74A40AFEB17EC86CB4C403143E38920AE4A40AFEB17EC86CB4C40
52986	28152	53.254492999999997	53.270949999999999	57.366729999999997	57.358429000000001	Центральная	0103000020E61000000100000005000000CC07043A93A04A4010786000E1AD4C40CC07043A93A04A40253B3602F1AE4C40F46C567DAEA24A40253B3602F1AE4C40F46C567DAEA24A4010786000E1AD4C40CC07043A93A04A4010786000E1AD4C40
53208	28012	53.484155999999999	53.498303999999997	57.530090000000001	57.524116999999997	Солнечная	0103000020E61000000100000005000000C214E5D2F8BD4A4089230F4416C34C40C214E5D2F8BD4A40E4F736FDD9C34C40A5BBEB6CC8BF4A40E4F736FDD9C34C40A5BBEB6CC8BF4A4089230F4416C34C40C214E5D2F8BD4A4089230F4416C34C40
53166	27973	53.454681999999998	53.467402	57.527572999999997	57.520226999999998	Центральная	0103000020E61000000100000005000000390A100533BA4A4083BF5FCC96C24C40390A100533BA4A4055A0168387C34C40E10A28D4D3BB4A4055A0168387C34C40E10A28D4D3BB4A4083BF5FCC96C24C40390A100533BA4A4083BF5FCC96C24C40
52902	28621	52.945813999999999	52.978557000000002	57.510984000000001	57.501927999999999	Сибирская	0103000020E61000000100000005000000AA0CE36E10794A402D793C2D3FC04C40AA0CE36E10794A40BF6378EC67C14C40CD22145B417D4A40BF6378EC67C14C40CD22145B417D4A402D793C2D3FC04C40AA0CE36E10794A402D793C2D3FC04C40
52499	26811	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Холмогорова	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52659	26338	53.059244	53.098491000000003	56.666468000000002	56.655144	 Школьная	0103000020E61000000100000005000000FB3DB14E95874A40D71533C2DB534C40FB3DB14E95874A404FEACBD24E554C40A5F9635A9B8C4A404FEACBD24E554C40A5F9635A9B8C4A40D71533C2DB534C40FB3DB14E95874A40D71533C2DB534C40
52779	26732	52.987226	53.010178000000003	56.928862000000002	56.904668999999998	Советская	0103000020E6100000010000000500000065E1EB6B5D7E4A403E5A9C31CC734C4065E1EB6B5D7E4A40A33F34F3E4764C40C19140834D814A40A33F34F3E4764C40C19140834D814A403E5A9C31CC734C4065E1EB6B5D7E4A403E5A9C31CC734C40
52979	24618	53.615355000000001	53.636949999999999	56.679375999999998	56.664099	Верхняя	0103000020E610000001000000050000000D37E0F3C3CE4A4035272F3201554C400D37E0F3C3CE4A40F9D7F2CAF5564C40F697DD9387D14A40F9D7F2CAF5564C40F697DD9387D14A4035272F3201554C400D37E0F3C3CE4A4035272F3201554C40
52651	26672	53.315694999999998	53.331766000000002	56.912875999999997	56.911687000000001	Тепличная	0103000020E610000001000000050000005F419AB168A84A401C98DC28B2744C405F419AB168A84A40D2A6EA1ED9744C405EF6EB4E77AA4A40D2A6EA1ED9744C405EF6EB4E77AA4A401C98DC28B2744C405F419AB168A84A401C98DC28B2744C40
53039	25392	53.499158000000001	53.521076999999998	56.800814000000003	56.790225	Лесная	0103000020E61000000100000005000000B5C4CA68E4BF4A40A5BDC11726654C40B5C4CA68E4BF4A40E816BA1281664C4051D9B0A6B2C24A40E816BA1281664C4051D9B0A6B2C24A40A5BDC11726654C40B5C4CA68E4BF4A40A5BDC11726654C40
52961	26926	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Совхозная	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52485	25120	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Центральная	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52780	26546	52.770533999999998	52.801938999999997	56.766523999999997	56.752955	Центральная	0103000020E61000000100000005000000603AADDBA0624A400A2E56D460604C40603AADDBA0624A40AFCC5B751D624C408731E9EFA5664A40AFCC5B751D624C408731E9EFA5664A400A2E56D460604C40603AADDBA0624A400A2E56D460604C40
52984	26960	53.360691000000003	53.376232000000002	57.05254	57.040911999999999	Кооперативная	0103000020E61000000100000005000000147B681F2BAE4A40C901BB9A3C854C40147B681F2BAE4A40ADDD76A1B9864C40B6DAC35E28B04A40ADDD76A1B9864C40B6DAC35E28B04A40C901BB9A3C854C40147B681F2BAE4A40C901BB9A3C854C40
52773	26316	53.096173999999998	53.121713	56.694375000000001	56.680765999999998	Восточная	0103000020E61000000100000005000000DD5CFC6D4F8C4A40471D1D5723574C40DD5CFC6D4F8C4A407B14AE47E1584C40C03FA54A948F4A407B14AE47E1584C40C03FA54A948F4A40471D1D5723574C40DD5CFC6D4F8C4A40471D1D5723574C40
53231	25553	53.343767	53.377831	56.730558000000002	56.716152000000001	Клубная	0103000020E61000000100000005000000D6389B8E00AC4A40857B65DEAA5B4C40D6389B8E00AC4A4064EAAEEC825D4C401E3526C45CB04A4064EAAEEC825D4C401E3526C45CB04A40857B65DEAA5B4C40D6389B8E00AC4A40857B65DEAA5B4C40
52897	26216	52.990020000000001	53.022584000000002	56.776029000000001	56.764071999999999	Центральная	0103000020E610000001000000050000006631B1F9B87E4A4008E57D1CCD614C406631B1F9B87E4A40B1DF13EB54634C40D9B45208E4824A40B1DF13EB54634C40D9B45208E4824A4008E57D1CCD614C406631B1F9B87E4A4008E57D1CCD614C40
53028	24565	53.489384000000001	53.513755000000003	56.687351	56.671390000000002	Шорболяк	0103000020E61000000100000005000000C4978922A4BE4A40446E861BF0554C40C4978922A4BE4A40BBEF181EFB574C4008944DB9C2C14A40BBEF181EFB574C4008944DB9C2C14A40446E861BF0554C40C4978922A4BE4A40446E861BF0554C40
53094	26880	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Молодежная	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52747	25056	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Центральная	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52631	26635	52.716850999999998	52.790019000000001	56.835608999999998	56.766820000000003	Станционная	0103000020E610000001000000050000006D8D08C6C15B4A4099F5622827624C406D8D08C6C15B4A40239F573CF56A4C40FC1BB4571F654A40239F573CF56A4C40FC1BB4571F654A4099F5622827624C406D8D08C6C15B4A4099F5622827624C40
52629	26131	52.937871999999999	52.985025	56.741548999999999	56.718359999999997	Зайцева	0103000020E61000000100000005000000C4EA8F300C784A4095607138F35B4C40C4EA8F300C784A40D5B0DF13EB5E4C40075F984C157E4A40D5B0DF13EB5E4C40075F984C157E4A4095607138F35B4C40C4EA8F300C784A4095607138F35B4C40
53089	24538	53.485053999999998	53.496732000000002	56.602015999999999	56.592619999999997	Комсомольская	0103000020E61000000100000005000000A165DD3F16BE4A404E7ADFF8DA4B4C40A165DD3F16BE4A4099D53BDC0E4D4C40377007EA94BF4A4099D53BDC0E4D4C40377007EA94BF4A404E7ADFF8DA4B4C40A165DD3F16BE4A404E7ADFF8DA4B4C40
53090	25759	52.840657	52.879257000000003	56.940865000000002	56.928170000000001	Клубная	0103000020E61000000100000005000000A51309A69A6B4A406D904946CE764C40A51309A69A6B4A40BC79AA436E784C40B9E34D7E8B704A40BC79AA436E784C40B9E34D7E8B704A406D904946CE764C40A51309A69A6B4A406D904946CE764C40
52981	25247	53.554332000000002	53.565831000000003	56.972762000000003	56.95355	Береговая	0103000020E610000001000000050000002A90D959F4C64A40E78C28ED0D7A4C402A90D959F4C64A4052651877837C4C40100874266DC84A4052651877837C4C40100874266DC84A40E78C28ED0D7A4C402A90D959F4C64A40E78C28ED0D7A4C40
52642	25273	53.518794999999997	53.548772	56.845681999999996	56.816065000000002	Сосунова	0103000020E61000000100000005000000062AE3DF67C24A40833463D174684C40062AE3DF67C24A406E68CA4E3F6C4C40F27A30293EC64A406E68CA4E3F6C4C40F27A30293EC64A40833463D174684C40062AE3DF67C24A40833463D174684C40
53096	26515	53.077272999999998	53.106935	56.712451000000001	56.700988000000002	Центральная	0103000020E6100000010000000500000091EEE714E4894A40B9718BF9B9594C4091EEE714E4894A4052802898315B4C401DE6CB0BB08D4A4052802898315B4C401DE6CB0BB08D4A40B9718BF9B9594C4091EEE714E4894A40B9718BF9B9594C40
52980	25486	53.298850999999999	53.325352000000002	56.746228000000002	56.737909999999999	Удмуртская	0103000020E610000001000000050000003EB0E3BF40A64A4018B2BAD5735E4C403EB0E3BF40A64A4004AE2B66845F4C4017D86322A5A94A4004AE2B66845F4C4017D86322A5A94A4018B2BAD5735E4C403EB0E3BF40A64A4018B2BAD5735E4C40
53187	24772	53.704143999999999	53.746203000000001	56.721170000000001	56.708153000000003	Центральная	0103000020E610000001000000050000005AD6FD6321DA4A403BC8EBC1A45A4C405AD6FD6321DA4A409C6D6E4C4F5C4C40AB96749483DF4A409C6D6E4C4F5C4C40AB96749483DF4A403BC8EBC1A45A4C405AD6FD6321DA4A403BC8EBC1A45A4C40
53092	24772	53.704143999999999	53.746203000000001	56.721170000000001	56.708153000000003	Свердлова	0103000020E610000001000000050000005AD6FD6321DA4A403BC8EBC1A45A4C405AD6FD6321DA4A409C6D6E4C4F5C4C40AB96749483DF4A409C6D6E4C4F5C4C40AB96749483DF4A403BC8EBC1A45A4C405AD6FD6321DA4A403BC8EBC1A45A4C40
52781	26785	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Вокзальная	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52672	25743	52.778134000000001	52.822017000000002	56.925590999999997	56.898446	Советская	0103000020E61000000100000005000000EDF318E599634A406B9C4D4700734C40EDF318E599634A40683C11C479764C40C6E061DA37694A40683C11C479764C40C6E061DA37694A406B9C4D4700734C40EDF318E599634A406B9C4D4700734C40
52771	26073	53.077030000000001	53.109954000000002	56.762765000000002	56.747511000000003	Школьная	0103000020E61000000100000005000000CB67791EDC894A403C33C170AE5F4C40CB67791EDC894A4048C49448A2614C403E0801F9128E4A4048C49448A2614C403E0801F9128E4A403C33C170AE5F4C40CB67791EDC894A403C33C170AE5F4C40
52976	26154	52.961525000000002	52.980874999999997	56.821804	56.810851999999997	Свободы	0103000020E61000000100000005000000A9A44E40137B4A40B6F292FFC9674C40A9A44E40137B4A406ADC9BDF30694C40643BDF4F8D7D4A406ADC9BDF30694C40643BDF4F8D7D4A40B6F292FFC9674C40A9A44E40137B4A40B6F292FFC9674C40
52748	25602	52.792112000000003	52.817785999999998	56.974415	56.963459	Школьная	0103000020E6100000010000000500000074620FED63654A40B804E09F527B4C4074620FED63654A40ADDD76A1B97C4C4036902E36AD684A40ADDD76A1B97C4C4036902E36AD684A40B804E09F527B4C4074620FED63654A40B804E09F527B4C40
52487	25351	53.271101999999999	53.305418000000003	56.738453	56.723733000000003	Молодежная	0103000020E61000000100000005000000AAF06778B3A24A409B046F48A35C4C40AAF06778B3A24A400951BEA0855E4C400CCEE0EF17A74A400951BEA0855E4C400CCEE0EF17A74A409B046F48A35C4C40AAF06778B3A24A409B046F48A35C4C40
52841	18952	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Чкалово	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52769	18952	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Прудовая	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52537	18952	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	Гольянская	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
52950	24801	53.647621999999998	53.671778000000003	56.791325000000001	56.773242000000003	Заречная	0103000020E61000000100000005000000C6151747E5D24A4063F20698F9624C40C6151747E5D24A40ECC039234A654C400E164ED2FCD54A40ECC039234A654C400E164ED2FCD54A4063F20698F9624C40C6151747E5D24A4063F20698F9624C40
53197	24717	53.729531000000001	53.759318999999998	56.821458999999997	56.805653	Пихтовая	0103000020E610000001000000050000008735954561DD4A404F7633A31F674C408735954561DD4A409F008A9125694C409F1D705D31E14A409F008A9125694C409F1D705D31E14A404F7633A31F674C408735954561DD4A404F7633A31F674C40
53099	25442	53.271354000000002	53.289023999999998	56.690613999999997	56.679965000000003	Шоссейная	0103000020E61000000100000005000000C4D155BABBA24A405BB6D61709574C40C4D155BABBA24A407214200A66584C402AE109BDFEA44A407214200A66584C402AE109BDFEA44A405BB6D61709574C40C4D155BABBA24A405BB6D61709574C40
52750	24070	53.707962000000002	53.750793999999999	56.769454000000003	56.746637999999997	Максима Горького	0103000020E61000000100000005000000C767B27F9EDA4A40B5F97FD5915F4C40C767B27F9EDA4A4061E3FA777D624C403A048E041AE04A4061E3FA777D624C403A048E041AE04A40B5F97FD5915F4C40C767B27F9EDA4A40B5F97FD5915F4C40
53210	56410	52.904904000000002	52.932383999999999	56.709744000000001	56.694167999999998	Школьная	0103000020E610000001000000050000008202EFE4D3734A4001F73C7FDA584C408202EFE4D3734A40204432E4D85A4C4026A8E15B58774A40204432E4D85A4C4026A8E15B58774A4001F73C7FDA584C408202EFE4D3734A4001F73C7FDA584C40
52982	56395	52.671297000000003	52.692210000000003	56.728465	56.716611	Школьная	0103000020E610000001000000050000009373620FED554A40187AC4E8B95B4C409373620FED554A40ECA353573E5D4C406AFB57569A584A40ECA353573E5D4C406AFB57569A584A40187AC4E8B95B4C409373620FED554A40187AC4E8B95B4C40
53093	25700	52.746063999999997	52.768818000000003	57.028402999999997	57.012929999999997	Советская	0103000020E61000000100000005000000895C70067F5F4A409291B3B0A7814C40895C70067F5F4A40DC0DA2B5A2834C40BF49D3A068624A40DC0DA2B5A2834C40BF49D3A068624A409291B3B0A7814C40895C70067F5F4A409291B3B0A7814C40
52704	33022	53.125557000000001	53.1584	56.738847999999997	56.727634999999999	Садовая	0103000020E610000001000000050000005664744012904A406536C824235D4C405664744012904A40855B3E92925E4C40DCD7817346944A40855B3E92925E4C40DCD7817346944A406536C824235D4C405664744012904A406536C824235D4C40
52627	24458	53.442931999999999	53.481434	56.664434999999997	56.642876000000001	Центральная	0103000020E610000001000000050000000A2DEBFEB1B84A4010B1C1C249524C400A2DEBFEB1B84A40ACA8C1340C554C405B971AA19FBD4A40ACA8C1340C554C405B971AA19FBD4A4010B1C1C249524C400A2DEBFEB1B84A4010B1C1C249524C40
52835	25648	52.699764999999999	52.716869000000003	56.977387999999998	56.968347000000001	Штабная	0103000020E6100000010000000500000056F146E691594A40011764CBF27B4C4056F146E691594A405DC0CB0C1B7D4C401442075DC25B4A405DC0CB0C1B7D4C401442075DC25B4A40011764CBF27B4C4056F146E691594A40011764CBF27B4C40
53091	24416	53.913837999999998	53.938757000000003	57.545216000000003	57.531056999999997	Школьная	0103000020E61000000100000005000000C8EBC1A4F8F44A40EBA7FFACF9C34C40C8EBC1A4F8F44A40C3A04CA3C9C54C400FF27A3029F84A40C3A04CA3C9C54C400FF27A3029F84A40EBA7FFACF9C34C40C8EBC1A4F8F44A40EBA7FFACF9C34C40
52974	23634	53.999969	54.023397000000003	57.663426000000001	57.652327999999997	Удлемская	0103000020E61000000100000005000000C501F4FBFEFF4A40EE21E17B7FD34C40C501F4FBFEFF4A4076A8A624EBD44C408AE942ACFE024B4076A8A624EBD44C408AE942ACFE024B40EE21E17B7FD34C40C501F4FBFEFF4A40EE21E17B7FD34C40
52746	24345	53.773592999999998	53.807684000000002	57.508557000000003	57.482351999999999	Кирова	0103000020E610000001000000050000000FB56D1805E34A408194D8B5BDBD4C400FB56D1805E34A407193516518C14C4051C0763062E74A407193516518C14C4051C0763062E74A408194D8B5BDBD4C400FB56D1805E34A408194D8B5BDBD4C40
53196	24172	53.800767	53.821886999999997	57.717094000000003	57.706685999999998	Турнесская	0103000020E61000000100000005000000A75B76887FE64A404145D5AF74DA4C40A75B76887FE64A40341477BCC9DB4C40F700DD9733E94A40341477BCC9DB4C40F700DD9733E94A404145D5AF74DA4C40A75B76887FE64A404145D5AF74DA4C40
53086	24318	53.674652999999999	53.707774000000001	57.718997999999999	57.703690000000002	Октябрьская	0103000020E61000000100000005000000FB928D075BD64A40D942908312DA4C40FB928D075BD64A40D8F15F2008DC4C40C47AA35698DA4A40D8F15F2008DC4C40C47AA35698DA4A40D942908312DA4C40FB928D075BD64A40D942908312DA4C40
53087	24019	53.689466000000003	53.727733999999998	57.578918999999999	57.566727999999998	Майская	0103000020E610000001000000050000001BDA006C40D84A401EDD088B8AC84C401BDA006C40D84A403A048E041ACA4C40F817416326DD4A403A048E041ACA4C40F817416326DD4A401EDD088B8AC84C401BDA006C40D84A401EDD088B8AC84C40
52766	24104	53.623322999999999	53.657764	57.626770999999998	57.615994000000001	Сибирская	0103000020E610000001000000050000001CEC4D0CC9CF4A40204432E4D8CE4C401CEC4D0CC9CF4A40658A39083AD04C403A3E5A9C31D44A40658A39083AD04C403A3E5A9C31D44A40204432E4D8CE4C401CEC4D0CC9CF4A40204432E4D8CE4C40
53194	23973	53.708151000000001	53.730967999999997	57.541201999999998	57.528066000000003	Центральная	0103000020E610000001000000050000009AD024B1A4DA4A409510ACAA97C34C409AD024B1A4DA4A40D0436D1B46C54C401536035C90DD4A40D0436D1B46C54C401536035C90DD4A409510ACAA97C34C409AD024B1A4DA4A409510ACAA97C34C40
53164	23804	53.978318999999999	54.014961	57.698971999999998	57.682966999999998	Молодежная	0103000020E610000001000000050000001807978E39FD4A40A59F70766BD74C401807978E39FD4A40EC681CEA77D94C4094DBF63DEA014B40EC681CEA77D94C4094DBF63DEA014B40A59F70766BD74C401807978E39FD4A40A59F70766BD74C40
52886	23339	53.755941	53.773314999999997	57.638773999999998	57.630707999999998	Сибирская	0103000020E610000001000000050000004F5AB8ACC2E04A40ACA92C0ABBD04C404F5AB8ACC2E04A407EC4AF58C3D14C40CC4065FCFBE24A407EC4AF58C3D14C40CC4065FCFBE24A40ACA92C0ABBD04C404F5AB8ACC2E04A40ACA92C0ABBD04C40
52975	24267	53.673017999999999	53.702221999999999	57.671754	57.653829999999999	Восточная	0103000020E6100000010000000500000046CF2D7425D64A40649291B3B0D34C4046CF2D7425D64A40857AFA08FCD54C400F441669E2D94A40857AFA08FCD54C400F441669E2D94A40649291B3B0D34C4046CF2D7425D64A40649291B3B0D34C40
53081	23764	53.521337000000003	53.540497999999999	57.684843000000001	57.671196000000002	Молодёжная	0103000020E61000000100000005000000EE98BA2BBBC24A405F9A22C0E9D54C40EE98BA2BBBC24A4080F277EFA8D74C40D6C6D8092FC54A4080F277EFA8D74C40D6C6D8092FC54A405F9A22C0E9D54C40EE98BA2BBBC24A405F9A22C0E9D54C40
52743	23731	53.911799000000002	53.934401000000001	57.630755999999998	57.613714000000002	Советская	0103000020E6100000010000000500000044C362D4B5F44A40768C2B2E8ECE4C4044C362D4B5F44A40BDE0D39CBCD04C40C32CB4739AF74A40BDE0D39CBCD04C40C32CB4739AF74A40768C2B2E8ECE4C4044C362D4B5F44A40768C2B2E8ECE4C40
52484	23383	53.771680000000003	53.837364000000001	57.666708999999997	57.635440000000003	Труда	0103000020E61000000100000005000000187D0569C6E24A40FE48111956D14C40187D0569C6E24A40747973B856D54C40836C59BE2EEB4A40747973B856D54C40836C59BE2EEB4A40FE48111956D14C40187D0569C6E24A40FE48111956D14C40
52742	23383	53.771680000000003	53.837364000000001	57.666708999999997	57.635440000000003	Советская	0103000020E61000000100000005000000187D0569C6E24A40FE48111956D14C40187D0569C6E24A40747973B856D54C40836C59BE2EEB4A40747973B856D54C40836C59BE2EEB4A40FE48111956D14C40187D0569C6E24A40FE48111956D14C40
52667	23383	53.771680000000003	53.837364000000001	57.666708999999997	57.635440000000003	Радищева	0103000020E61000000100000005000000187D0569C6E24A40FE48111956D14C40187D0569C6E24A40747973B856D54C40836C59BE2EEB4A40747973B856D54C40836C59BE2EEB4A40FE48111956D14C40187D0569C6E24A40FE48111956D14C40
52741	23383	53.771680000000003	53.837364000000001	57.666708999999997	57.635440000000003	Андронова	0103000020E61000000100000005000000187D0569C6E24A40FE48111956D14C40187D0569C6E24A40747973B856D54C40836C59BE2EEB4A40747973B856D54C40836C59BE2EEB4A40FE48111956D14C40187D0569C6E24A40FE48111956D14C40
52887	23896	53.617860999999998	53.638503999999998	57.497884999999997	57.485492000000001	Удмуртская	0103000020E61000000100000005000000A73CBA1116CF4A401D3C139A24BE4C40A73CBA1116CF4A40A01518B2BABF4C40BE2EC37FBAD14A40A01518B2BABF4C40BE2EC37FBAD14A401D3C139A24BE4C40A73CBA1116CF4A401D3C139A24BE4C40
52896	24189	53.734166000000002	53.75949	57.688192000000001	57.675604	Варнинская	0103000020E61000000100000005000000E6EAC726F9DD4A40FD851E317AD64C40E6EAC726F9DD4A4036AFEAAC16D84C40CCD1E3F736E14A4036AFEAAC16D84C40CCD1E3F736E14A40FD851E317AD64C40E6EAC726F9DD4A40FD851E317AD64C40
52884	23301	53.764026000000001	53.788685000000001	57.601790000000001	57.593449999999997	Центральная	0103000020E6100000010000000500000098A59D9ACBE14A40D5E76A2BF6CB4C4098A59D9ACBE14A40A987687407CD4C4042EC4CA1F3E44A40A987687407CD4C4042EC4CA1F3E44A40D5E76A2BF6CB4C4098A59D9ACBE14A40D5E76A2BF6CB4C40
53162	23696	54.041372000000003	54.070846000000003	57.622625999999997	57.609220000000001	Большекизнинская	0103000020E610000001000000050000002D7C7DAD4B054B40D908C4EBFACD4C402D7C7DAD4B054B40D4D17135B2CF4C40B686527B11094B40D4D17135B2CF4C40B686527B11094B40D908C4EBFACD4C402D7C7DAD4B054B40D908C4EBFACD4C40
52885	23874	53.903489	53.937131000000001	57.675133000000002	57.656343999999997	Центральная	0103000020E61000000100000005000000DBA50D87A5F34A408176871403D44C40DBA50D87A5F34A40A6B915C26AD64C40AD889AE8F3F74A40A6B915C26AD64C40AD889AE8F3F74A408176871403D44C40DBA50D87A5F34A408176871403D44C40
52882	22409	51.945450000000001	51.959580000000003	56.097447000000003	56.086689999999997	Осиновская	0103000020E6100000010000000500000069006F8104F94940F3716DA8180B4C4069006F8104F94940F20BAF24790C4C40A6F27684D3FA4940F20BAF24790C4C40A6F27684D3FA4940F3716DA8180B4C4069006F8104F94940F3716DA8180B4C40
52911	56390	51.646040999999997	51.669631000000003	56.010106	55.993876999999998	Староятчинская	0103000020E610000001000000050000000470B378B1D24940909F8D5C37FF4B400470B378B1D2494027BF45274B014C40A3B1F677B6D5494027BF45274B014C40A3B1F677B6D54940909F8D5C37FF4B400470B378B1D24940909F8D5C37FF4B40
53079	23143	52.136260999999998	52.15455	55.938889000000003	55.925052000000001	Удмуртская	0103000020E61000000100000005000000315C1D0071114A40B98C9B1A68F64B40315C1D0071114A407EC9C6832DF84B4064CC5D4BC8134A407EC9C6832DF84B4064CC5D4BC8134A40B98C9B1A68F64B40315C1D0071114A40B98C9B1A68F64B40
52881	22893	51.711843000000002	51.737876	56.057423	56.045192	Молодежная	0103000020E610000001000000050000007A71E2AB1DDB49403A05F9D9C8054C407A71E2AB1DDB4940E48409A359074C406C4084B872DE4940E48409A359074C406C4084B872DE49403A05F9D9C8054C407A71E2AB1DDB49403A05F9D9C8054C40
53085	22554	51.972695999999999	51.990689000000003	56.014603999999999	55.998916000000001	Центральная	0103000020E610000001000000050000009A79724D81FC4940BFB9BF7ADCFF4B409A79724D81FC494005323B8BDE014C40E4C0ABE5CEFE494005323B8BDE014C40E4C0ABE5CEFE4940BFB9BF7ADCFF4B409A79724D81FC4940BFB9BF7ADCFF4B40
53088	22841	51.692735999999996	51.713064000000003	56.033731000000003	56.023052	Тимофеева	0103000020E610000001000000050000008461C092ABD84940BF0D315EF3024C408461C092ABD8494042EE224C51044C403CFA5FAE45DB494042EE224C51044C403CFA5FAE45DB4940BF0D315EF3024C408461C092ABD84940BF0D315EF3024C40
52973	22927	52.147894000000001	52.190536999999999	56.093812	56.073348000000003	Школьная	0103000020E6100000010000000500000027A3CA30EE124A400F9D9E7763094C4027A3CA30EE124A4076FC1708020C4C40C7D6338463184A4076FC1708020C4C40C7D6338463184A400F9D9E7763094C4027A3CA30EE124A400F9D9E7763094C40
52970	22717	51.7624	51.786743999999999	55.971072999999997	55.963127999999998	Кирова	0103000020E61000000100000005000000363CBD5296E1494052EE3EC747FB4B40363CBD5296E14940A983BC1E4CFC4B4080290307B4E44940A983BC1E4CFC4B4080290307B4E4494052EE3EC747FB4B40363CBD5296E1494052EE3EC747FB4B40
53082	23257	52.073081999999999	52.09863	55.930790999999999	55.919851000000001	Колхозная	0103000020E6100000010000000500000090F63FC05A094A40B11875ADBDF54B4090F63FC05A094A40A034D42824F74B40C63368E89F0C4A40A034D42824F74B40C63368E89F0C4A40B11875ADBDF54B4090F63FC05A094A40B11875ADBDF54B40
53192	23080	52.095855	52.123117999999998	56.020220000000002	56.006366	Советская	0103000020E610000001000000050000003C1405FA440C4A4036E7E099D0004C403C1405FA440C4A40D15CA79196024C4043C6A354C20F4A40D15CA79196024C4043C6A354C20F4A4036E7E099D0004C403C1405FA440C4A4036E7E099D0004C40
52958	22765	51.842556999999999	51.858528999999997	55.978971000000001	55.967813999999997	Мичурина	0103000020E61000000100000005000000080264E8D8EB4940334E4354E1FB4B40080264E8D8EB4940C05DF6EB4EFD4B4073D53C47E4ED4940C05DF6EB4EFD4B4073D53C47E4ED4940334E4354E1FB4B40080264E8D8EB4940334E4354E1FB4B40
52965	18944	52.067943999999997	52.092979999999997	56.170344999999998	56.154680999999997	Школьная	0103000020E61000000100000005000000CEFA9463B2084A4002284696CC134C40CEFA9463B2084A40C0046EDDCD154C404E97C5C4E60B4A40C0046EDDCD154C404E97C5C4E60B4A4002284696CC134C40CEFA9463B2084A4002284696CC134C40
52833	22666	51.758572999999998	51.783087999999999	56.005248999999999	55.990982000000002	Советская	0103000020E61000000100000005000000765089EB18E149405C76887FD8FE4B40765089EB18E1494019ABCDFFAB004C40EDF1423A3CE4494019ABCDFFAB004C40EDF1423A3CE449405C76887FD8FE4B40765089EB18E149405C76887FD8FE4B40
53076	22319	51.999358000000001	52.023684000000003	56.119929999999997	56.113798000000003	Пионерская	0103000020E610000001000000050000007C7F83F6EAFF4940D42CD0EE900E4C407C7F83F6EAFF494096E7C1DD590F4C4020B8CA1308034A4096E7C1DD590F4C4020B8CA1308034A40D42CD0EE900E4C407C7F83F6EAFF4940D42CD0EE900E4C40
53077	22973	52.108898000000003	52.136960999999999	56.118820999999997	56.10181	Грузлёвская	0103000020E61000000100000005000000C74CA25EF00D4A40F0332E1C080D4C40C74CA25EF00D4A40FC89CA86350F4C40EAE923F087114A40FC89CA86350F4C40EAE923F087114A40F0332E1C080D4C40C74CA25EF00D4A40F0332E1C080D4C40
52888	20687	52.011485	52.033501999999999	56.046464	56.031945999999998	Советская	0103000020E6100000010000000500000081B2295778014A40779E78CE16044C4081B2295778014A407E384888F2054C40E02C25CB49044A407E384888F2054C40E02C25CB49044A40779E78CE16044C4081B2295778014A40779E78CE16044C40
52855	20217	52.058700000000002	52.075696000000001	56.040038000000003	56.030617999999997	Кооперативная	0103000020E610000001000000050000003A234A7B83074A409F55664AEB034C403A234A7B83074A40734C16F71F054C4011381268B0094A40734C16F71F054C4011381268B0094A409F55664AEB034C403A234A7B83074A409F55664AEB034C40
52968	18831	51.875596999999999	51.896940999999998	56.046846000000002	56.028258999999998	 Школьная	0103000020E61000000100000005000000E4BCFF8F13F04940A968ACFD9D034C40E4BCFF8F13F0494066F9BA0CFF054C4084B872F6CEF2494066F9BA0CFF054C4084B872F6CEF24940A968ACFD9D034C40E4BCFF8F13F04940A968ACFD9D034C40
52531	18728	51.946294000000002	51.983853000000003	56.055985	56.040249000000003	Колпакова	0103000020E6100000010000000500000055336B2920F949402E5915E126054C4055336B2920F94940850838842A074C40278925E5EEFD4940850838842A074C40278925E5EEFD49402E5915E126054C4055336B2920F949402E5915E126054C40
53193	23121	52.09422	52.118259000000002	55.952969000000003	55.943300999999998	10 Пятилетки	0103000020E610000001000000050000008750A5660F0C4A405DA45016BEF84B408750A5660F0C4A40098D60E3FAF94B4095BA641C230F4A40098D60E3FAF94B4095BA641C230F4A405DA45016BEF84B408750A5660F0C4A405DA45016BEF84B40
53083	23029	52.197085999999999	52.215347999999999	56.030335999999998	56.018821000000003	Гагарина	0103000020E61000000100000005000000EE3F321D3A194A4030BDFDB968024C40EE3F321D3A194A401BF2CF0CE2034C4027A1F485901B4A401BF2CF0CE2034C4027A1F485901B4A4030BDFDB968024C40EE3F321D3A194A4030BDFDB968024C40
52969	22624	51.861896999999999	51.881292000000002	56.007423000000003	55.990412999999997	Благодатновская	0103000020E61000000100000005000000A0C211A452EE494041446ADAC5FE4B40A0C211A452EE49407E1EA33CF3004C40FC1C1F2DCEF049407E1EA33CF3004C40FC1C1F2DCEF0494041446ADAC5FE4B40A0C211A452EE494041446ADAC5FE4B40
52967	23211	52.218375999999999	52.235335999999997	55.959394000000003	55.948982000000001	Центральная	0103000020E610000001000000050000009B1DA9BEF31B4A40103FFF3D78F94B409B1DA9BEF31B4A4044FD2E6CCDFA4B4025C9737D1F1E4A4044FD2E6CCDFA4B4025C9737D1F1E4A40103FFF3D78F94B409B1DA9BEF31B4A40103FFF3D78F94B40
52625	22240	52.643863000000003	52.674171999999999	58.118932000000001	58.103642000000001	Глазовская	0103000020E610000001000000050000005F0D501A6A524A40FB3E1C24440D4D405F0D501A6A524A405439ED29390F4D4080F0A1444B564A405439ED29390F4D4080F0A1444B564A40FB3E1C24440D4D405F0D501A6A524A40FB3E1C24440D4D40
53074	21647	52.501694999999998	52.515943	58.108781999999998	58.096935999999999	Центральная	0103000020E610000001000000050000008AC8B08A37404A400CE71A66680C4D408AC8B08A37404A405D328E91EC0D4D40D1CC936B0A424A405D328E91EC0D4D40D1CC936B0A424A400CE71A66680C4D408AC8B08A37404A400CE71A66680C4D40
52957	18929	52.705522999999999	52.725771000000002	58.336620000000003	58.325488	Школьная	0103000020E61000000100000005000000B4C9E1934E5A4A40C79E3D97A9294D40B4C9E1934E5A4A40FB96395D162B4D404FB16A10E65C4A40FB96395D162B4D404FB16A10E65C4A40C79E3D97A9294D40B4C9E1934E5A4A40C79E3D97A9294D40
53191	21420	52.451802999999998	52.472572	58.048606999999997	58.034215000000003	Школьная	0103000020E610000001000000050000000A9E42AED4394A402E04392861044D400A9E42AED4394A40A7AD11C138064D40AE80423D7D3C4A40A7AD11C138064D40AE80423D7D3C4A402E04392861044D400A9E42AED4394A402E04392861044D40
53084	21815	52.802289999999999	52.817901999999997	58.012157000000002	58.000487999999997	Школьная	0103000020E6100000010000000500000034F44F70B1664A402D05A4FD0F004D4034F44F70B1664A4070B54E5C8E014D409FAA4203B1684A4070B54E5C8E014D409FAA4203B1684A402D05A4FD0F004D4034F44F70B1664A402D05A4FD0F004D40
52880	22049	52.952801999999998	53.010798000000001	58.472821000000003	58.448957999999998	Горьковская	0103000020E610000001000000050000001DC87A6AF5794A4087A3AB7477394D401DC87A6AF5794A4057EE0566853C4D405D6E30D461814A4057EE0566853C4D405D6E30D461814A4087A3AB7477394D401DC87A6AF5794A4087A3AB7477394D40
53190	22141	52.707912999999998	52.741743	57.954630999999999	57.941094999999997	Школьная	0103000020E61000000100000005000000E5B4A7E49C5A4A40EDB60BCD75F84C40E5B4A7E49C5A4A40B75F3E5931FA4C40BA84436FF15E4A40B75F3E5931FA4C40BA84436FF15E4A40EDB60BCD75F84C40E5B4A7E49C5A4A40EDB60BCD75F84C40
52650	21944	52.796261999999999	52.825619000000003	58.257072999999998	58.240881000000002	Коммунальная	0103000020E610000001000000050000001686C8E9EB654A40289D4830D51E4D401686C8E9EB654A40A1D79FC4E7204D4066FA25E2AD694A40A1D79FC4E7204D4066FA25E2AD694A40289D4830D51E4D401686C8E9EB654A40289D4830D51E4D40
52669	21919	52.567802	52.597698000000001	57.949893000000003	57.932355999999999	Прудовая	0103000020E610000001000000050000003C4D66BCAD484A405C1D007157F74C403C4D66BCAD484A4084D9041896F94C403B71395E814C4A4084D9041896F94C403B71395E814C4A405C1D007157F74C403C4D66BCAD484A405C1D007157F74C40
52966	22102	52.635302000000003	52.663617000000002	57.891545000000001	57.878903000000001	Кирова	0103000020E61000000100000005000000AD8A709351514A409BADBCE47FF04C40AD8A709351514A40C7F484251EF24C40EA08E066F1544A40C7F484251EF24C40EA08E066F1544A409BADBCE47FF04C40AD8A709351514A409BADBCE47FF04C40
52486	8580	52.851571	52.883893	58.090494999999997	58.078913999999997	Центральная	0103000020E610000001000000050000006B9C4D47006D4A4028999CDA190A4D406B9C4D47006D4A40CBB91457950B4D40E814E46723714A40CBB91457950B4D40E814E46723714A4028999CDA190A4D406B9C4D47006D4A4028999CDA190A4D40
53157	8580	52.851571	52.883893	58.090494999999997	58.078913999999997	Пастухова	0103000020E610000001000000050000006B9C4D47006D4A4028999CDA190A4D406B9C4D47006D4A40CBB91457950B4D40E814E46723714A40CBB91457950B4D40E814E46723714A4028999CDA190A4D406B9C4D47006D4A4028999CDA190A4D40
52665	21378	52.446987999999997	52.478555	58.263010000000001	58.244661000000001	Люмская	0103000020E610000001000000050000002BDA1CE736394A40A7CD380D511F4D402BDA1CE736394A40AF42CA4FAA214D402C2B4D4A413D4A40AF42CA4FAA214D402C2B4D4A413D4A40A7CD380D511F4D402BDA1CE736394A40A7CD380D511F4D40
52624	21701	53.049497000000002	53.071559999999998	58.205604999999998	58.191799000000003	пер. Школьный	0103000020E610000001000000050000000420EEEA55864A40E833A0DE8C184D400420EEEA55864A407172BF43511A4D40D3D9C9E028894A407172BF43511A4D40D3D9C9E028894A40E833A0DE8C184D400420EEEA55864A40E833A0DE8C184D40
52857	56383	52.732616	52.755685	58.052168999999999	58.040452000000002	Ленина	0103000020E610000001000000050000005F43705CC65D4A406687F8872D054D405F43705CC65D4A40B96E4A79AD064D40F4893C49BA604A40B96E4A79AD064D40F4893C49BA604A406687F8872D054D405F43705CC65D4A406687F8872D054D40
52831	21557	52.344912000000001	52.468763000000003	58.177821000000002	58.137684	Кировская	0103000020E61000000100000005000000BDFF8F13262C4A405B971AA19F114D40BDFF8F13262C4A4061C5A9D6C2164D4095490D6D003C4A4061C5A9D6C2164D4095490D6D003C4A405B971AA19F114D40BDFF8F13262C4A405B971AA19F114D40
52413	21522	52.758460999999997	52.803511	58.111535000000003	58.096403000000002	Центральная	0103000020E610000001000000050000004E25034015614A403F1EFAEE560C4D404E25034015614A4000AE64C7460E4D40F67CCD72D9664A4000AE64C7460E4D40F67CCD72D9664A403F1EFAEE560C4D404E25034015614A403F1EFAEE560C4D40
52767	22003	52.821396999999997	52.845219999999998	58.318862000000003	58.308542000000003	Школьная	0103000020E610000001000000050000002904728923694A40A2B8E34D7E274D402904728923694A40F5F75278D0284D406AF6402B306C4A40F5F75278D0284D406AF6402B306C4A40A2B8E34D7E274D402904728923694A40A2B8E34D7E274D40
53075	21287	52.688355999999999	52.711433999999997	58.260156000000002	58.247422	Мира	0103000020E61000000100000005000000B000A60C1C584A40CC272B86AB1F4D40B000A60C1C584A40D9EDB3CA4C214D4098A1F144105B4A40D9EDB3CA4C214D4098A1F144105B4A40CC272B86AB1F4D40B000A60C1C584A40CC272B86AB1F4D40
52744	21608	52.307884000000001	52.359645	58.185665	58.174599000000001	Советская	0103000020E61000000100000005000000187B2FBE68274A400875914259164D40187B2FBE68274A408481E7DEC3174D40C095ECD8082E4A408481E7DEC3174D40C095ECD8082E4A400875914259164D40187B2FBE68274A400875914259164D40
52836	18655	52.437080000000002	52.459069999999997	58.004455999999998	57.989063999999999	Центральная	0103000020E610000001000000050000002BDEC83CF2374A4052D32EA699FE4C402BDEC83CF2374A40AF22A30392004D40904946CEC23A4A40AF22A30392004D40904946CEC23A4A4052D32EA699FE4C402BDEC83CF2374A4052D32EA699FE4C40
52832	21334	52.553187000000001	52.583872999999997	58.219866000000003	58.209848999999998	Садовая	0103000020E6100000010000000500000043C9E4D4CE464A40950C0055DC1A4D4043C9E4D4CE464A404DC0AF91241C4D403A02B859BC4A4A404DC0AF91241C4D403A02B859BC4A4A40950C0055DC1A4D4043C9E4D4CE464A40950C0055DC1A4D40
52666	21158	52.816735000000001	52.852091999999999	58.146585999999999	58.133612999999997	Советская	0103000020E61000000100000005000000D13FC1C58A684A4004A9143B1A114D40D13FC1C58A684A4096067E54C3124D407497C459116D4A4096067E54C3124D407497C459116D4A4004A9143B1A114D40D13FC1C58A684A4004A9143B1A114D40
52382	56358	52.580370000000002	52.723354999999998	58.166867000000003	58.112704999999998	Кирова	0103000020E610000001000000050000002ECA6C90494A4A403F8C101E6D0E4D402ECA6C90494A4A400DE4D9E55B154D40F4328AE5965C4A400DE4D9E55B154D40F4328AE5965C4A403F8C101E6D0E4D402ECA6C90494A4A403F8C101E6D0E4D40
53070	20158	53.636401999999997	53.667591999999999	57.167749999999998	57.152745000000003	Школьная	0103000020E61000000100000005000000F38DE89E75D14A4053D0ED258D934C40F38DE89E75D14A40B6F3FDD478954C401E8997A773D54A40B6F3FDD478954C401E8997A773D54A4053D0ED258D934C40F38DE89E75D14A4053D0ED258D934C40
53159	21088	53.493201999999997	53.520879000000001	57.068103999999998	57.049793999999999	Колхозная	0103000020E6100000010000000500000030293E3E21BF4A40BDC458A65F864C4030293E3E21BF4A40075DC2A1B7884C402B16BF29ACC24A40075DC2A1B7884C402B16BF29ACC24A40BDC458A65F864C4030293E3E21BF4A40BDC458A65F864C40
53068	20814	54.161414000000001	54.179371000000003	57.124032	57.110398000000004	Кокорина	0103000020E61000000100000005000000EB8EC536A9144B409CC58B85218E4C40EB8EC536A9144B4028D4D347E08F4C40E86C01A1F5164B4028D4D347E08F4C40E86C01A1F5164B409CC58B85218E4C40EB8EC536A9144B409CC58B85218E4C40
52839	21013	53.611510000000003	53.642178999999999	57.072298000000004	57.049205999999998	Октябрьский	0103000020E61000000100000005000000A796ADF545CE4A402C62D8614C864C40A796ADF545CE4A407AC8940F41894C40C896E5EB32D24A407AC8940F41894C40C896E5EB32D24A402C62D8614C864C40A796ADF545CE4A402C62D8614C864C40
52878	18614	54.138866	54.159706999999997	57.155743000000001	57.145895000000003	Центральная	0103000020E610000001000000050000005F43705CC6114B4031D3F6AFAC924C405F43705CC6114B405CCAF962EF934C409CF86A4771144B405CCAF962EF934C409CF86A4771144B4031D3F6AFAC924C405F43705CC6114B4031D3F6AFAC924C40
52528	20907	53.899779000000002	53.937930999999999	56.893441000000003	56.869441000000002	Советская	0103000020E61000000100000005000000555051F52BF34A409966BAD7496F4C40555051F52BF34A40E9F351465C724C40C9737D1F0EF84A40E9F351465C724C40C9737D1F0EF84A409966BAD7496F4C40555051F52BF34A409966BAD7496F4C40
52622	20801	54.111809000000001	54.147956999999998	57.077088000000003	57.054825999999998	Проезд Молодежный	0103000020E610000001000000050000000133DFC14F0E4B40397CD28904874C400133DFC14F0E4B4000750305DE894C406D1B4641F0124B4000750305DE894C406D1B4641F0124B40397CD28904874C400133DFC14F0E4B40397CD28904874C40
53073	20936	53.778452999999999	53.809508000000001	56.900106999999998	56.890510999999996	Молодежная	0103000020E610000001000000050000008E3C1059A4E34A4037DDB243FC714C408E3C1059A4E34A4049F3C7B436734C40D9EC48F59DE74A4049F3C7B436734C40D9EC48F59DE74A4037DDB243FC714C408E3C1059A4E34A4037DDB243FC714C40
52483	56362	\N	\N	\N	\N	Центральная	\N
53071	20363	53.626089999999998	53.655068999999997	56.879657999999999	56.862991000000001	Широкая	0103000020E61000000100000005000000232D95B723D04A4005DF347D766E4C40232D95B723D04A4017D522A298704C40CCCF0D4DD9D34A4017D522A298704C40CCCF0D4DD9D34A4005DF347D766E4C40232D95B723D04A4005DF347D766E4C40
52764	20720	53.793337999999999	53.814250999999999	57.007523999999997	56.995730000000002	Школьная	0103000020E6100000010000000500000047567E198CE54A40B3D2A414747F4C4047567E198CE54A40B1F7E28BF6804C401EDE736039E84A40B1F7E28BF6804C401EDE736039E84A40B3D2A414747F4C4047567E198CE54A40B3D2A414747F4C40
53186	21063	53.557862999999998	53.585045999999998	57.022103000000001	57.003048999999997	Гагарина	0103000020E610000001000000050000000053060E68C74A408BA4DDE863804C400053060E68C74A405E126745D4824C40EB538EC9E2CA4A405E126745D4824C40EB538EC9E2CA4A408BA4DDE863804C400053060E68C74A408BA4DDE863804C40
53188	19815	54.166812999999998	54.200930999999997	57.242930000000001	57.231693	Школьная	0103000020E6100000010000000500000019C6DD205A154B4027DBC01DA89D4C4019C6DD205A154B40D09B8A54189F4C4054E0641BB8194B40D09B8A54189F4C4054E0641BB8194B4027DBC01DA89D4C4019C6DD205A154B4027DBC01DA89D4C40
52514	20584	53.923620999999997	53.973325000000003	56.970990999999998	56.949722000000001	Советская	0103000020E610000001000000050000000C73823639F64A405725917D90794C400C73823639F64A40ECDADE6E497C4C408AB0E1E995FC4A40ECDADE6E497C4C408AB0E1E995FC4A405725917D90794C400C73823639F64A405725917D90794C40
52830	20496	54.197113000000002	54.227044999999997	57.043908999999999	57.021298999999999	Комсомольская	0103000020E61000000100000005000000E84EB0FF3A194B400038F6ECB9824C40E84EB0FF3A194B40028063CF9E854C4033DC80CF0F1D4B40028063CF9E854C4033DC80CF0F1D4B400038F6ECB9824C40E84EB0FF3A194B400038F6ECB9824C40
52673	20496	54.197113000000002	54.227044999999997	57.043908999999999	57.021298999999999	 Советская	0103000020E61000000100000005000000E84EB0FF3A194B400038F6ECB9824C40E84EB0FF3A194B40028063CF9E854C4033DC80CF0F1D4B40028063CF9E854C4033DC80CF0F1D4B400038F6ECB9824C40E84EB0FF3A194B400038F6ECB9824C40
52621	20388	53.579098999999999	53.630456000000002	56.936253999999998	56.907200000000003	Центральная	0103000020E61000000100000005000000BA1281EA1FCA4A4032772D211F744C40BA1281EA1FCA4A40E55FCB2BD7774C4093C83EC8B2D04A40E55FCB2BD7774C4093C83EC8B2D04A4032772D211F744C40BA1281EA1FCA4A4032772D211F744C40
52879	20388	53.579098999999999	53.630456000000002	56.936253999999998	56.907200000000003	Молодежная	0103000020E61000000100000005000000BA1281EA1FCA4A4032772D211F744C40BA1281EA1FCA4A40E55FCB2BD7774C4093C83EC8B2D04A40E55FCB2BD7774C4093C83EC8B2D04A4032772D211F744C40BA1281EA1FCA4A4032772D211F744C40
53072	20599	53.903920999999997	53.932828000000001	57.016041999999999	57.003053999999999	Коммунаров	0103000020E610000001000000050000007495EEAEB3F34A409D0FCF1264804C407495EEAEB3F34A4064AE0CAA0D824C4084656CE866F74A4064AE0CAA0D824C4084656CE866F74A409D0FCF1264804C407495EEAEB3F34A409D0FCF1264804C40
52660	20227	54.055844	54.082819999999998	57.040241000000002	57.027075000000004	Набережная	0103000020E61000000100000005000000C3D66CE525074B4005C58F3177834C40C3D66CE525074B40AB7AF99D26854C4034BA83D8990A4B40AB7AF99D26854C4034BA83D8990A4B4005C58F3177834C40C3D66CE525074B4005C58F3177834C40
52763	20079	53.727392999999999	53.768554000000002	57.079684999999998	57.063177000000003	Центральная	0103000020E610000001000000050000006F2BBD361BDD4A40016E162F16884C406F2BBD361BDD4A40AA7D3A1E338A4C40E19A3BFA5FE24A40AA7D3A1E338A4C40E19A3BFA5FE24A40016E162F16884C406F2BBD361BDD4A40016E162F16884C40
52859	56384	53.652231	53.678255	56.969397000000001	56.957020999999997	Школьная	0103000020E61000000100000005000000FC372F4E7CD34A40E84A04AA7F7A4C40FC372F4E7CD34A4096EB6D33157C4C409BAC510FD1D64A4096EB6D33157C4C409BAC510FD1D64A40E84A04AA7F7A4C40FC372F4E7CD34A40E84A04AA7F7A4C40
52825	19748	54.178167000000002	54.205044999999998	57.191616000000003	57.174200999999996	Новая	0103000020E61000000100000005000000FC1C1F2DCE164B401AF7E6374C964C40FC1C1F2DCE164B40F7B182DF86984C40AA9A20EA3E1A4B40F7B182DF86984C40AA9A20EA3E1A4B401AF7E6374C964C40FC1C1F2DCE164B401AF7E6374C964C40
52727	19663	53.751548	53.794209000000002	56.970353000000003	56.934033999999997	Школьная	0103000020E61000000100000005000000E6AF90B932E04A4010AD156D8E774C40E6AF90B932E04A40AA49F086347C4C402D98F8A3A8E54A40AA49F086347C4C402D98F8A3A8E54A4010AD156D8E774C40E6AF90B932E04A4010AD156D8E774C40
52964	20229	54.052888000000003	54.066498000000003	56.936650999999998	56.930954999999997	Юбилейная	0103000020E61000000100000005000000E92CB308C5064B401A868F8829774C40E92CB308C5064B400262122EE4774C40ED9FA70183084B400262122EE4774C40ED9FA70183084B401A868F8829774C40E92CB308C5064B401A868F8829774C40
52488	56363	53.894300000000001	54.032173	57.083809000000002	56.988987999999999	Освобождения	0103000020E610000001000000050000000A68226C78F24A407711A628977E4C400A68226C78F24A40240ED940BA8A4C403868AF3E1E044B40240ED940BA8A4C403868AF3E1E044B407711A628977E4C400A68226C78F24A407711A628977E4C40
53063	18858	52.105196999999997	52.122570000000003	56.740921999999998	56.731960999999998	Центральная	0103000020E6100000010000000500000093516518770D4A404679E6E5B05D4C4093516518770D4A4086713788D65E4C4041BCAE5FB00F4A4086713788D65E4C4041BCAE5FB00F4A404679E6E5B05D4C4093516518770D4A404679E6E5B05D4C40
53078	56403	51.999771000000003	52.023952999999999	56.752268999999998	56.741459999999996	Садовая	0103000020E610000001000000050000009F3E027FF8FF494065A54929E85E4C409F3E027FF8FF4940B665C0594A604C400FD253E410034A40B665C0594A604C400FD253E410034A4065A54929E85E4C409F3E027FF8FF494065A54929E85E4C40
53045	19235	51.731929000000001	51.751288000000002	56.572870000000002	56.556170000000002	Центральная	0103000020E610000001000000050000003BFF76D9AFDD494017821C9430474C403BFF76D9AFDD4940056EDDCD53494C404AF086342AE04940056EDDCD53494C404AF086342AE0494017821C9430474C403BFF76D9AFDD494017821C9430474C40
53065	19197	51.760064	51.791308000000001	56.611305000000002	56.602967	Евдокимова	0103000020E61000000100000005000000F86EF3C649E149409BC8CC052E4D4C40F86EF3C649E14940CE70033E3F4E4C4016889E9449E54940CE70033E3F4E4C4016889E9449E549409BC8CC052E4D4C40F86EF3C649E149409BC8CC052E4D4C40
52662	18611	51.858995999999998	51.881517000000002	56.812108000000002	56.798596000000003	Советская	0103000020E6100000010000000500000089B2B794F3ED4940B45BCB6438664C4089B2B794F3ED4940F568AA27F3674C401CEF8E8CD5F04940F568AA27F3674C401CEF8E8CD5F04940B45BCB6438664C4089B2B794F3ED4940B45BCB6438664C40
53060	19530	51.490498000000002	51.522640000000003	56.762354999999999	56.747180999999998	Центральная	0103000020E61000000100000005000000706072A3C8BE4940A69883A0A35F4C40706072A3C8BE4940967840D994614C406DCA15DEE5C24940967840D994614C406DCA15DEE5C24940A69883A0A35F4C40706072A3C8BE4940A69883A0A35F4C40
53059	18520	51.794811000000003	51.823512000000001	56.842644	56.834603999999999	 Новая	0103000020E6100000010000000500000023C0E95DBCE549402E8ECA4DD46A4C4023C0E95DBCE54940D71533C2DB6B4C4089EE59D768E94940D71533C2DB6B4C4089EE59D768E949402E8ECA4DD46A4C4023C0E95DBCE549402E8ECA4DD46A4C40
52872	18833	52.162950000000002	52.178733000000001	56.826231999999997	56.815094000000002	Садовая	0103000020E610000001000000050000000D71AC8BDB144A403A950C0055684C400D71AC8BDB144A404F745DF8C1694C40A5DB12B9E0164A404F745DF8C1694C40A5DB12B9E0164A403A950C0055684C400D71AC8BDB144A403A950C0055684C40
52740	18532	51.838317000000004	51.874797000000001	56.858189000000003	56.846563000000003	Поточная	0103000020E610000001000000050000002657B1F84DEB49407880272D5C6C4C402657B1F84DEB4940BB641C23D96D4C40C8D11C59F9EF4940BB641C23D96D4C40C8D11C59F9EF49407880272D5C6C4C402657B1F84DEB49407880272D5C6C4C40
52883	19446	51.609245999999999	51.632899000000002	56.766055000000001	56.752802000000003	Центральная 	0103000020E61000000100000005000000029CDEC5FBCD4940842EE1D05B604C40029CDEC5FBCD4940F9F719170E624C40E7559DD502D14940F9F719170E624C40E7559DD502D14940842EE1D05B604C40029CDEC5FBCD4940842EE1D05B604C40
53064	19143	51.740184999999997	51.762453999999998	56.728484000000002	56.716121999999999	Центральная	0103000020E61000000100000005000000B0FECF61BEDE49401AF9BCE2A95B4C40B0FECF61BEDE494063D4B5F63E5D4C40295AB91798E1494063D4B5F63E5D4C40295AB91798E149401AF9BCE2A95B4C40B0FECF61BEDE49401AF9BCE2A95B4C40
53185	54702	52.133457999999997	52.156365000000001	56.814424000000002	56.802695999999997	Новая	0103000020E61000000100000005000000DDB1D82615114A40A45016BEBE664C40DDB1D82615114A40EC89AE0B3F684C40999EB0C403144A40EC89AE0B3F684C40999EB0C403144A40A45016BEBE664C40DDB1D82615114A40A45016BEBE664C40
53069	18386	51.951225999999998	51.976055000000002	56.831536	56.822065000000002	Лермонтова	0103000020E610000001000000050000006D8D08C6C1F94940D717096D39694C406D8D08C6C1F949402CB98AC56F6A4C40740CC85EEFFC49402CB98AC56F6A4C40740CC85EEFFC4940D717096D39694C406D8D08C6C1F94940D717096D39694C40
53067	19299	51.772371	51.778739999999999	56.554478000000003	56.551248999999999	Новая	0103000020E610000001000000050000007DB08C0DDDE24940F279C5538F464C407DB08C0DDDE24940FE2C9622F9464C40240B98C0ADE34940FE2C9622F9464C40240B98C0ADE34940F279C5538F464C407DB08C0DDDE24940F279C5538F464C40
52738	19066	51.767718000000002	51.794946000000003	56.689289000000002	56.672102000000002	Советская	0103000020E6100000010000000500000078465B9544E24940C1C9367007564C4078465B9544E249400C3F389F3A584C40030B60CAC0E549400C3F389F3A584C40030B60CAC0E54940C1C9367007564C4078465B9544E24940C1C9367007564C40
52664	19402	51.604295999999998	51.640732	56.823912	56.806279000000004	Коммунальная	0103000020E61000000100000005000000438D429259CD4940CE39782634674C40438D429259CD49401764CBF275694C4016C0948103D249401764CBF275694C4016C0948103D24940CE39782634674C40438D429259CD4940CE39782634674C40
52524	18216	51.907262000000003	51.951585000000001	56.784891000000002	56.760959	Северная	0103000020E61000000100000005000000A873452921F44940664CC11A67614C40A873452921F449405EF6EB4E77644C409D2E8B89CDF949405EF6EB4E77644C409D2E8B89CDF94940664CC11A67614C40A873452921F44940664CC11A67614C40
52638	18216	51.907262000000003	51.951585000000001	56.784891000000002	56.760959	Интернациональная	0103000020E61000000100000005000000A873452921F44940664CC11A67614C40A873452921F449405EF6EB4E77644C409D2E8B89CDF949405EF6EB4E77644C409D2E8B89CDF94940664CC11A67614C40A873452921F44940664CC11A67614C40
52963	19498	51.479807999999998	51.514851	56.723719000000003	56.707935999999997	Молодежная	0103000020E61000000100000005000000F92D3A596ABD49409DD497A59D5A4C40F92D3A596ABD4940363FFED2A25C4C400DA837A3E6C14940363FFED2A25C4C400DA837A3E6C149409DD497A59D5A4C40F92D3A596ABD49409DD497A59D5A4C40
52870	18932	51.969721999999997	51.989018000000002	56.709175999999999	56.692219999999999	Центральная	0103000020E61000000100000005000000191BBAD91FFC49408DD13AAA9A584C40191BBAD91FFC4940D68D7747C65A4C40E2934E2498FE4940D68D7747C65A4C40E2934E2498FE49408DD13AAA9A584C40191BBAD91FFC49408DD13AAA9A584C40
53066	18410	51.920017999999999	51.948144999999997	56.871679999999998	56.856268999999998	Центральная	0103000020E610000001000000050000009CDD5A26C3F5494010CAFB389A6D4C409CDD5A26C3F54940E449D235936F4C40D66EBBD05CF94940E449D235936F4C40D66EBBD05CF9494010CAFB389A6D4C409CDD5A26C3F5494010CAFB389A6D4C40
52876	18631	52.068500999999998	52.089655999999998	56.779381999999998	56.764910999999998	Первомайская	0103000020E61000000100000005000000245F09A4C4084A40E2AC889AE8614C40245F09A4C4084A40A88B14CAC2634C40F1F109D9790B4A40A88B14CAC2634C40F1F109D9790B4A40E2AC889AE8614C40245F09A4C4084A40E2AC889AE8614C40
52875	19047	52.008564999999997	52.031706	56.677191000000001	56.663781999999998	Вишнёвая	0103000020E61000000100000005000000F3716DA818014A4034D6FECEF6544C40F3716DA818014A40A112D731AE564C40228B34F10E044A40A112D731AE564C40228B34F10E044A4034D6FECEF6544C40F3716DA818014A4034D6FECEF6544C40
53177	16613	52.869394	52.909799999999997	57.888789000000003	57.875683000000002	Центральная	0103000020E6100000010000000500000058AB764D486F4A40E3546B6116F04C4058AB764D486F4A40B40584D6C3F14C404DF38E5374744A40B40584D6C3F14C404DF38E5374744A40E3546B6116F04C4058AB764D486F4A40E3546B6116F04C40
52874	17232	53.178925999999997	53.194225000000003	58.06532	58.056074000000002	Центральная	0103000020E61000000100000005000000B933130CE7964A40F513CE6E2D074D40B933130CE7964A402AE3DF675C084D406688635DDC984A402AE3DF675C084D406688635DDC984A40F513CE6E2D074D40B933130CE7964A40F513CE6E2D074D40
52892	17903	53.433087	53.444343000000003	58.343190999999997	58.337017000000003	Школьная	0103000020E6100000010000000500000050A912656FB74A401899805F232B4D4050A912656FB74A4009A4C4AEED2B4D40709A3E3BE0B84A4009A4C4AEED2B4D40709A3E3BE0B84A401899805F232B4D4050A912656FB74A401899805F232B4D40
53179	16919	52.941313000000001	52.964058000000001	57.791609999999999	57.776471000000001	Центральная	0103000020E610000001000000050000005B26C3F17C784A406EA5D76663E34C405B26C3F17C784A40E197FA7953E54C403DB9A640667B4A40E197FA7953E54C403DB9A640667B4A406EA5D76663E34C405B26C3F17C784A406EA5D76663E34C40
53184	17112	53.234406	53.261975999999997	58.007852	57.999082000000001	Труда	0103000020E610000001000000050000003BFE0B04019E4A40DA0242EBE1FF4C403BFE0B04019E4A40A69A594B01014D401F2BF86D88A14A40A69A594B01014D401F2BF86D88A14A40DA0242EBE1FF4C403BFE0B04019E4A40DA0242EBE1FF4C40
53061	17821	53.519199	53.542268	58.412505000000003	58.401958	Советская	0103000020E61000000100000005000000D68EE21C75C24A40CB2E185C73334D40D68EE21C75C24A40DF37BEF6CC344D406BD5AE0969C54A40DF37BEF6CC344D406BD5AE0969C54A40CB2E185C73334D40D68EE21C75C24A40CB2E185C73334D40
52864	16503	53.201940999999998	53.230283	57.892803000000001	57.878985	Луговая	0103000020E610000001000000050000005B5CE333D9994A4058569A9482F04C405B5CE333D9994A40A662635E47F24C4092E9D0E9799D4A40A662635E47F24C4092E9D0E9799D4A4058569A9482F04C405B5CE333D9994A4058569A9482F04C40
52737	16191	52.895732000000002	52.913590999999997	57.998246999999999	57.979807999999998	Клубная	0103000020E6100000010000000500000087FD9E58A7724A40F92D3A596AFD4C4087FD9E58A7724A40412AC58EC6FF4C40C075C58CF0744A40412AC58EC6FF4C40C075C58CF0744A40F92D3A596AFD4C4087FD9E58A7724A40F92D3A596AFD4C40
53180	16228	52.968809999999998	52.987774000000002	58.091613000000002	58.081493000000002	Центральная	0103000020E61000000100000005000000D50451F7017C4A402DEDD45C6E0A4D40D50451F7017C4A40B9718BF9B90B4D4068EBE0606F7E4A40B9718BF9B90B4D4068EBE0606F7E4A402DEDD45C6E0A4D40D50451F7017C4A402DEDD45C6E0A4D40
53189	16721	52.931755000000003	52.972780999999998	57.921680000000002	57.907643	Центральная	0103000020E61000000100000005000000377172BF43774A40BFB854A52DF44C40377172BF43774A404BB0389CF9F54C40C8957A16847C4A404BB0389CF9F54C40C8957A16847C4A40BFB854A52DF44C40377172BF43774A40BFB854A52DF44C40
53051	17303	53.097377000000002	53.124155999999999	58.084729000000003	58.070656999999997	им.А.Русских	0103000020E61000000100000005000000F9307BD9768C4A40E21DE0490B094D40F9307BD9768C4A40EB025E66D80A4D4014CD0358E48F4A40EB025E66D80A4D4014CD0358E48F4A40E21DE0490B094D40F9307BD9768C4A40E21DE0490B094D40
52960	17017	53.075710000000001	53.098562999999999	57.844019000000003	57.821393	Волкова	0103000020E6100000010000000500000076FD82DDB0894A40E814E46723E94C4076FD82DDB0894A40F01989D008EC4C403ECC5EB69D8C4A40F01989D008EC4C403ECC5EB69D8C4A40E814E46723E94C4076FD82DDB0894A40E814E46723E94C40
53058	17019	53.069817	53.114894	57.733790999999997	57.718513000000002	Школьная 	0103000020E6100000010000000500000038DA71C3EF884A401C60E63BF8DB4C4038DA71C3EF884A40B08C0DDDECDD4C40D940BAD8B48E4A40B08C0DDDECDD4C40D940BAD8B48E4A401C60E63BF8DB4C4038DA71C3EF884A401C60E63BF8DB4C40
53195	17019	53.069817	53.114894	57.733790999999997	57.718513000000002	Школьная	0103000020E6100000010000000500000038DA71C3EF884A401C60E63BF8DB4C4038DA71C3EF884A40B08C0DDDECDD4C40D940BAD8B48E4A40B08C0DDDECDD4C40D940BAD8B48E4A401C60E63BF8DB4C4038DA71C3EF884A401C60E63BF8DB4C40
52977	56394	52.880955	52.901778	58.030155000000001	58.018512000000001	Полевая	0103000020E61000000100000005000000B41F2922C3704A40B24AE9995E024D40B41F2922C3704A40CB67791EDC034D404B2025766D734A40CB67791EDC034D404B2025766D734A40B24AE9995E024D40B41F2922C3704A40B24AE9995E024D40
53033	16818	52.797114999999998	52.824953999999998	57.917439999999999	57.903517000000001	Сепычевская	0103000020E61000000100000005000000551344DD07664A40A530EF71A6F34C40551344DD07664A40680586AC6EF54C40295AB91798694A40680586AC6EF54C40295AB91798694A40A530EF71A6F34C40551344DD07664A40A530EF71A6F34C40
52869	56385	53.344853999999998	53.362569000000001	58.139594000000002	58.129707000000003	Школьная	0103000020E6100000010000000500000088F2052D24AC4A40F9872D3D9A104D4088F2052D24AC4A40E25B5837DE114D408FC536A968AE4A40E25B5837DE114D408FC536A968AE4A40F9872D3D9A104D4088F2052D24AC4A40F9872D3D9A104D40
52732	16109	52.998463999999998	53.009898999999997	58.017519999999998	57.996018999999997	Советская	0103000020E61000000100000005000000DE1D19ABCD7F4A40E998F38C7DFF4C40DE1D19ABCD7F4A40518369183E024D40ADA1D45E44814A40518369183E024D40ADA1D45E44814A40E998F38C7DFF4C40DE1D19ABCD7F4A40E998F38C7DFF4C40
53183	17517	53.373429999999999	53.400092000000001	58.222937000000002	58.211404000000002	Новая	0103000020E6100000010000000500000032ACE28DCCAF4A402E1F49490F1B4D4032ACE28DCCAF4A40C0081A33891C4D4014B2F33636B34A40C0081A33891C4D4014B2F33636B34A402E1F49490F1B4D4032ACE28DCCAF4A402E1F49490F1B4D40
52962	18121	53.465121000000003	53.475721	58.422747000000001	58.413772999999999	Полевая	0103000020E6100000010000000500000067D7BD1589BB4A40E17B7F83F6344D4067D7BD1589BB4A40B6BDDD921C364D409D82FC6CE4BC4A40B6BDDD921C364D409D82FC6CE4BC4A40E17B7F83F6344D4067D7BD1589BB4A40E17B7F83F6344D40
52823	16307	52.955866	52.988087999999998	58.035383000000003	58.023544999999999	Школьная	0103000020E61000000100000005000000DEAD2CD1597A4A40FE7DC68503034D40DEAD2CD1597A4A40CDEA1D6E87044D40F7C8E6AA797E4A40CDEA1D6E87044D40F7C8E6AA797E4A40FE7DC68503034D40DEAD2CD1597A4A40FE7DC68503034D40
52735	17624	53.165227000000002	53.211373000000002	58.235242999999997	58.211674000000002	Первомайская	0103000020E6100000010000000500000046B5882826954A40EEB43522181B4D4046B5882826954A4074CE4F711C1E4D40F3203D450E9B4A4074CE4F711C1E4D40F3203D450E9B4A40EEB43522181B4D4046B5882826954A40EEB43522181B4D40
52868	17624	53.165227000000002	53.211373000000002	58.235242999999997	58.211674000000002	Механизаторов	0103000020E6100000010000000500000046B5882826954A40EEB43522181B4D4046B5882826954A4074CE4F711C1E4D40F3203D450E9B4A4074CE4F711C1E4D40F3203D450E9B4A40EEB43522181B4D4046B5882826954A40EEB43522181B4D40
53182	17119	53.203234999999999	53.222135000000002	57.942366	57.932155999999999	 Школьная	0103000020E610000001000000050000008733BF9A039A4A40956247E350F74C408733BF9A039A4A40616EF7729FF84C40032670EB6E9C4A40616EF7729FF84C40032670EB6E9C4A40956247E350F74C408733BF9A039A4A40956247E350F74C40
52739	16827	52.908686000000003	52.935302999999998	57.850188000000003	57.836454000000003	Школьная	0103000020E61000000100000005000000A22AA6D24F744A40E04DB7EC10EB4C40A22AA6D24F744A40D0B9DBF5D2EC4C40E36C3A02B8774A40D0B9DBF5D2EC4C40E36C3A02B8774A40E04DB7EC10EB4C40A22AA6D24F744A40E04DB7EC10EB4C40
52856	16424	53.124848	53.137037999999997	57.881774999999998	57.874845000000001	Больничная	0103000020E610000001000000050000004A7CEE04FB8F4A40D908C4EBFAEF4C404A7CEE04FB8F4A4017B7D100DEF04C40952710768A914A4017B7D100DEF04C40952710768A914A40D908C4EBFAEF4C404A7CEE04FB8F4A40D908C4EBFAEF4C40
53176	16315	52.986561000000002	53.011794999999999	58.075183000000003	58.063659000000001	Колхозная	0103000020E6100000010000000500000029417FA1477E4A404C8C65FA25084D4029417FA1477E4A408B1BB7989F094D40CFA0A17F82814A408B1BB7989F094D40CFA0A17F82814A404C8C65FA25084D4029417FA1477E4A404C8C65FA25084D40
52733	16399	53.062379	53.094476	57.891036999999997	57.878109000000002	Полевая	0103000020E61000000100000005000000857AFA08FC874A4061A92EE065F04C40857AFA08FC874A4052431B800DF24C40E22021CA178C4A4052431B800DF24C40E22021CA178C4A4061A92EE065F04C40857AFA08FC874A4061A92EE065F04C40
52858	17507	53.310457999999997	53.331999000000003	58.173392999999997	58.164009	Центральная	0103000020E610000001000000050000000A647616BDA74A40F59F353FFE144D400A647616BDA74A407B2DE8BD31164D4001A777F17EAA4A407B2DE8BD31164D4001A777F17EAA4A40F59F353FFE144D400A647616BDA74A40F59F353FFE144D40
52941	16522	52.987073000000002	53.002380000000002	57.915370000000003	57.904124000000003	Советская	0103000020E61000000100000005000000DFE17668587E4A40ADC3D155BAF34C40DFE17668587E4A40A9DE1AD82AF54C400E15E3FC4D804A40A9DE1AD82AF54C400E15E3FC4D804A40ADC3D155BAF34C40DFE17668587E4A40ADC3D155BAF34C40
52942	17206	53.058551999999999	53.084378999999998	57.986840999999998	57.974361999999999	Центральная	0103000020E61000000100000005000000C58EC6A17E874A408A3BDEE4B7FC4C40C58EC6A17E874A400CAD4ECE50FE4C400EBC5AEECC8A4A400CAD4ECE50FE4C400EBC5AEECC8A4A408A3BDEE4B7FC4C40C58EC6A17E874A408A3BDEE4B7FC4C40
52865	17431	53.144503	53.166476000000003	58.123010000000001	58.109039000000003	Центральная	0103000020E61000000100000005000000429605137F924A40897E6DFDF40D4D40429605137F924A405D8AABCABE0F4D40D2C8E7154F954A405D8AABCABE0F4D40D2C8E7154F954A40897E6DFDF40D4D40429605137F924A40897E6DFDF40D4D40
53172	16027	53.036102999999997	53.05583	58.030994	58.015880000000003	Школьная	0103000020E61000000100000005000000CC24EA059F844A408B54185B08024D40CC24EA059F844A40A52F849CF7034D405E11FC6F25874A40A52F849CF7034D405E11FC6F25874A408B54185B08024D40CC24EA059F844A408B54185B08024D40
52482	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Школьная	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52520	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Советская	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52411	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Сибирская	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52620	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Свердлова	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52415	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Московская	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52412	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Карла Маркса	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52434	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Калинина	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52768	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Заводская	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
52436	15239	52.974145999999998	53.033929000000001	58.003793000000002	57.953403999999999	Железнодорожная	0103000020E61000000100000005000000BDC3EDD0B07C4A4013F06B2409FA4C40BDC3EDD0B07C4A40147AFD497C004D4068B114C957844A40147AFD497C004D4068B114C957844A4013F06B2409FA4C40BDC3EDD0B07C4A4013F06B2409FA4C40
53057	17810	53.121262999999999	53.143658000000002	58.292831999999997	58.282603999999999	Солнечная	0103000020E61000000100000005000000809BC58B858F4A4001DC2C5E2C244D40809BC58B858F4A40739CDB847B254D4086E7A56263924A40739CDB847B254D4086E7A56263924A4001DC2C5E2C244D40809BC58B858F4A4001DC2C5E2C244D40
52827	16939	53.192042000000001	53.22739	57.790703000000001	57.777315999999999	Советская	0103000020E61000000100000005000000AEBA0ED594984A402A5437177FE34C40AEBA0ED594984A40AFEC82C135E54C40FEB7921D1B9D4A40AFEC82C135E54C40FEB7921D1B9D4A402A5437177FE34C40AEBA0ED594984A402A5437177FE34C40
52947	17731	53.248320999999997	53.264105000000001	58.279879000000001	58.267848000000001	Школьная	0103000020E610000001000000050000007BF486FBC89F4A404626E0D748224D407BF486FBC89F4A4029EB3713D3234D40E4DA5031CEA14A4029EB3713D3234D40E4DA5031CEA14A404626E0D748224D407BF486FBC89F4A404626E0D748224D40
52854	15452	52.441149000000003	52.482418000000003	56.267217000000002	56.252132000000003	Малая	0103000020E61000000100000005000000E1D4079277384A40362383DC45204C40E1D4079277384A40B6F7A92A34224C4039807EDFBF3D4A40B6F7A92A34224C4039807EDFBF3D4A40362383DC45204C40E1D4079277384A40362383DC45204C40
52730	15334	52.331096000000002	52.351469999999999	56.168877000000002	56.157398000000001	Молодежная	0103000020E6100000010000000500000010EB8D5A612A4A40583A1F9E25144C4010EB8D5A612A4A40F705F4C29D154C4037C30DF8FC2C4A40F705F4C29D154C4037C30DF8FC2C4A40583A1F9E25144C4010EB8D5A612A4A40583A1F9E25144C40
52940	14487	52.368465999999998	52.393197000000001	56.172865999999999	56.160806999999998	Поперечная	0103000020E610000001000000050000000ED8D5E4292F4A40E3FBE25295144C400ED8D5E4292F4A40904B1C7920164C4052F17F4754324A40904B1C7920164C4052F17F4754324A40E3FBE25295144C400ED8D5E4292F4A40E3FBE25295144C40
52829	15553	52.528922999999999	52.566257	56.307447000000003	56.292462999999998	Молодежный проезд	0103000020E61000000100000005000000158DB5BFB3434A402025766D6F254C40158DB5BFB3434A406D205D6C5A274C40C710001C7B484A406D205D6C5A274C40C710001C7B484A402025766D6F254C40158DB5BFB3434A402025766D6F254C40
53171	15076	52.394410000000001	52.412734999999998	56.111463999999998	56.102668999999999	Новая	0103000020E61000000100000005000000919BE1067C324A4011A8FE41240D4C40919BE1067C324A403657CD73440E4C4010751F80D4344A403657CD73440E4C4010751F80D4344A4011A8FE41240D4C40919BE1067C324A4011A8FE41240D4C40
52729	15142	52.490510999999998	52.519427999999998	56.092466000000002	56.079175999999997	Крылова	0103000020E6100000010000000500000004AA7F10C93E4A4065506D70220A4C4004AA7F10C93E4A40F8FE06EDD50B4C403750E09D7C424A40F8FE06EDD50B4C403750E09D7C424A4065506D70220A4C4004AA7F10C93E4A4065506D70220A4C40
52728	14975	52.685608000000002	52.715809	56.048993000000003	56.040058000000002	Фестивальная	0103000020E6100000010000000500000020F0C000C2574A40BAF8DB9E20054C4020F0C000C2574A40D15D126745064C405B971AA19F5B4A40D15D126745064C405B971AA19F5B4A40BAF8DB9E20054C4020F0C000C2574A40BAF8DB9E20054C40
52658	14888	52.689613999999999	52.718207	56.078839000000002	56.066800999999998	Центральная	0103000020E610000001000000050000008F6E844545584A40882B67EF8C084C408F6E844545584A401E537765170A4C400F61FC34EE5B4A401E537765170A4C400F61FC34EE5B4A40882B67EF8C084C408F6E844545584A40882B67EF8C084C40
52873	56386	52.567253999999998	52.585256999999999	56.079151000000003	56.066042000000003	Школьная	0103000020E61000000100000005000000394371C79B484A40CB14731074084C40394371C79B484A400D39B69E210A4C40A6608DB3E94A4A400D39B69E210A4C40A6608DB3E94A4A40CB14731074084C40394371C79B484A40CB14731074084C40
52392	14302	52.448954999999998	52.564127999999997	56.197037999999999	56.111921000000002	Комсомольская	0103000020E610000001000000050000001630815B77394A40295E656D530E4C401630815B77394A40DD088B8A38194C400261A75835484A40DD088B8A38194C400261A75835484A40295E656D530E4C401630815B77394A40295E656D530E4C40
52851	14302	52.448954999999998	52.564127999999997	56.197037999999999	56.111921000000002	 Лесная	0103000020E610000001000000050000001630815B77394A40295E656D530E4C401630815B77394A40DD088B8A38194C400261A75835484A40DD088B8A38194C400261A75835484A40295E656D530E4C401630815B77394A40295E656D530E4C40
79367	61544	49.155856999999997	49.157868999999998	55.774259000000001	55.772354999999997	Садовая	0103000020E6100000010000000500000024ED461FF393484077F35487DCE24B4024ED461FF39348401CD13DEB1AE34B40AF06280D359448401CD13DEB1AE34B40AF06280D3594484077F35487DCE24B4024ED461FF393484077F35487DCE24B40
79072	61375	53.687624	53.716424000000004	55.557785000000003	55.545228000000002	Центральная	0103000020E61000000100000005000000ECF82F1004D84A40876EF607CAC54B40ECF82F1004D84A408599B67F65C74B40E60819C8B3DB4A408599B67F65C74B40E60819C8B3DB4A40876EF607CAC54B40ECF82F1004D84A40876EF607CAC54B40
79167	61430	52.581636000000003	52.607562000000001	54.425750000000001	54.412097000000003	Школьная	0103000020E610000001000000050000009016670C734A4A40CEE33098BF344B409016670C734A4A40D122DBF97E364B406C257497C44D4A40D122DBF97E364B406C257497C44D4A40CEE33098BF344B409016670C734A4A40CEE33098BF344B40
78051	61272	47.257779999999997	54.268591999999998	56.675643000000001	53.974775999999999	60 Лет Октября	0103000020E610000001000000050000000CC85EEFFEA047407D76C075C5FC4A400CC85EEFFEA04740BB6246787B564C40CEFBFF3861224B40BB6246787B564C40CEFBFF3861224B407D76C075C5FC4A400CC85EEFFEA047407D76C075C5FC4A40
11620	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	Энгельса	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
11607	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	Чернышевского	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
11626	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	Полющенкова	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
11619	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	Зеленая	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
11616	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	Заводская	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
11590	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	Вотякова	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
11618	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	Виктора Ногина	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
11610	3607	50.584727000000001	50.693009000000004	55.390256000000001	55.338766	40 лет Победы	0103000020E610000001000000050000004A0B9755D84A4940957F2DAF5CAB4B404A0B9755D84A4940AD889AE8F3B14B40B66AD784B4584940AD889AE8F3B14B40B66AD784B4584940957F2DAF5CAB4B404A0B9755D84A4940957F2DAF5CAB4B40
12177	40967	49.294269999999997	49.317383	55.999696999999998	55.988695999999997	Дорожная	0103000020E61000000100000005000000D218ADA3AAA54840CFD72C978DFE4B40D218ADA3AAA5484064744012F6FF4B4037A79201A0A8484064744012F6FF4B4037A79201A0A84840CFD72C978DFE4B40D218ADA3AAA54840CFD72C978DFE4B40
78430	29378	48.931009000000003	48.961956000000001	55.784207000000002	55.768678999999999	Кирова	0103000020E610000001000000050000000EA48B4D2B7748409D0FCF1264E24B400EA48B4D2B774840AB251DE560E44B407218CC5F217B4840AB251DE560E44B407218CC5F217B48409D0FCF1264E24B400EA48B4D2B7748409D0FCF1264E24B40
11127	12275	50.771701999999998	50.834853000000003	54.438696	54.410697999999996	Линейная	0103000020E61000000100000005000000FF209221C76249402C4487C091344B40FF209221C76249406971C63027384B40D7FB8D76DC6A49406971C63027384B40D7FB8D76DC6A49402C4487C091344B40FF209221C76249402C4487C091344B40
11126	12275	50.771701999999998	50.834853000000003	54.438696	54.410697999999996	Заводская	0103000020E61000000100000005000000FF209221C76249402C4487C091344B40FF209221C76249406971C63027384B40D7FB8D76DC6A49406971C63027384B40D7FB8D76DC6A49402C4487C091344B40FF209221C76249402C4487C091344B40
10148	8108	48.956727999999998	48.96978	55.90249	55.889476999999999	Центральная	0103000020E6100000010000000500000070952710767A4840A8C5E061DAF14B4070952710767A4840C87BD5CA84F34B404E2844C0217C4840C87BD5CA84F34B404E2844C0217C4840A8C5E061DAF14B4070952710767A4840A8C5E061DAF14B40
12253	8191	48.832813999999999	48.850645999999998	55.873621999999997	55.860821999999999	Центральная	0103000020E6100000010000000500000052D32EA6996A4840B2D6506A2FEE4B4052D32EA6996A484076887FD8D2EF4B40923CD7F7E16C484076887FD8D2EF4B40923CD7F7E16C4840B2D6506A2FEE4B4052D32EA6996A4840B2D6506A2FEE4B40
79114	31212	48.945597999999997	48.979050999999998	55.707070999999999	55.682046999999997	Дзержинского	0103000020E61000000100000005000000DD94F25A09794840DEAAEB504DD74B40DD94F25A097948409A79724D81DA4B40DC0E0D8B517D48409A79724D81DA4B40DC0E0D8B517D4840DEAAEB504DD74B40DD94F25A09794840DEAAEB504DD74B40
79286	61520	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
11286	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	улица Шамиля Усманова	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11035	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	улица Ш. Усманова	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11054	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	улица Ш. Усманова	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
532	1104	52.337060999999999	52.352153000000001	55.701039000000002	55.686117000000003	улица Хади Такташа	0103000020E61000000100000005000000E7E099D0242B4A40651D8EAED2D74B40E7E099D0242B4A403B1C5DA5BBD94B401A187959132D4A403B1C5DA5BBD94B401A187959132D4A40651D8EAED2D74B40E7E099D0242B4A40651D8EAED2D74B40
77570	1104	52.417909999999999	52.439037999999996	55.773316999999999	55.761021	улица Татарстан	0103000020E61000000100000005000000EF552B137E354A40DC48D92269E14B40EF552B137E354A406D382C0DFCE24B40C2D9AD6532384A406D382C0DFCE24B40C2D9AD6532384A40DC48D92269E14B40EF552B137E354A40DC48D92269E14B40
932	1104	52.370190999999998	52.420954999999999	55.742083000000001	55.723804999999999	улица Раиса Беляева	0103000020E6100000010000000500000003232F6B622F4A4034D769A4A5DC4B4003232F6B622F4A4073F56393FCDE4B40390B7BDAE1354A4073F56393FCDE4B40390B7BDAE1354A4034D769A4A5DC4B4003232F6B622F4A4034D769A4A5DC4B40
11876	1104	52.371116000000001	52.373595999999999	55.739345999999998	55.733817000000002	улица Касымова	0103000020E61000000100000005000000DC82A5BA802F4A40DA1F28B7EDDD4B40DC82A5BA802F4A40D636C5E3A2DE4B404DF564FED12F4A40D636C5E3A2DE4B404DF564FED12F4A40DA1F28B7EDDD4B40DC82A5BA802F4A40DA1F28B7EDDD4B40
1044	1104	52.403015000000003	52.460031999999998	55.753898999999997	55.722340000000003	улица 40 Лет Победы	0103000020E610000001000000050000001366DAFE95334A40DC4B1AA375DC4B401366DAFE95334A4059BE2EC37FE04B40868E1D54E23A4A4059BE2EC37FE04B40868E1D54E23A4A40DC4B1AA375DC4B401366DAFE95334A40DC4B1AA375DC4B40
79290	1104	52.380090000000003	52.444374000000003	55.763680000000001	55.722776000000003	пр-т Мира	0103000020E61000000100000005000000B1C403CAA6304A40B72A89EC83DC4B40B1C403CAA6304A40FD4D2844C0E14B40AB984A3FE1384A40FD4D2844C0E14B40AB984A3FE1384A40B72A89EC83DC4B40B1C403CAA6304A40B72A89EC83DC4B40
11005	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	переулок Энергетиков	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11851	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	пер.Юности	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11023	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	бульвар Энтузиастов	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11030	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	бульвар Автомобилестроителей	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11887	1104	52.312393	52.314315999999998	55.694464000000004	55.693835	б-р Тичурина	0103000020E61000000100000005000000EA3F6B7EFC274A40FBE8D495CFD84B40EA3F6B7EFC274A40EB1F4432E4D84B40054EB6813B284A40EB1F4432E4D84B40054EB6813B284A40FBE8D495CFD84B40EA3F6B7EFC274A40FBE8D495CFD84B40
11010	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	б-р Корчагина 	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11325	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	б-р Автомобилестроителей	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11878	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	б-р 60 Лет Октября	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
499	1104	52.29325	52.308962000000001	55.694164999999998	55.686213000000002	Ямашева бульвар	0103000020E61000000100000005000000A8C64B3789254A40878BDCD3D5D74B40A8C64B3789254A4090831266DAD84B4077DA1A118C274A4090831266DAD84B4077DA1A118C274A40878BDCD3D5D74B40A8C64B3789254A40878BDCD3D5D74B40
77579	1104	52.435713999999997	52.450932000000002	55.758356999999997	55.755201	Юных Ленинцев бульвар	0103000020E610000001000000050000006534F279C5374A400874266DAAE04B406534F279C5374A40A9D898D711E14B40255CC823B8394A40A9D898D711E14B40255CC823B8394A400874266DAAE04B406534F279C5374A400874266DAAE04B40
77578	1104	52.435713999999997	52.450932000000002	55.758356999999997	55.755201	Юных Ленинцев бульвар	0103000020E610000001000000050000006534F279C5374A400874266DAAE04B406534F279C5374A40A9D898D711E14B40255CC823B8394A40A9D898D711E14B40255CC823B8394A400874266DAAE04B406534F279C5374A400874266DAAE04B40
1148	1104	52.404606000000001	52.410552000000003	55.747475000000001	55.745493000000003	Школьный бульвар	0103000020E61000000100000005000000F8E12021CA334A40CF328B506CDF4B40F8E12021CA334A40EFC9C342ADDF4B4059A7CAF78C344A40EFC9C342ADDF4B4059A7CAF78C344A40CF328B506CDF4B40F8E12021CA334A40CF328B506CDF4B40
1349	1104	52.425598999999998	52.435265000000001	55.753042999999998	55.745134	Шишкинский бульвар	0103000020E61000000100000005000000EB1A2D077A364A409F91088D60DF4B40EB1A2D077A364A40A9BD88B663E04B40F60B76C3B6374A40A9BD88B663E04B40F60B76C3B6374A409F91088D60DF4B40EB1A2D077A364A409F91088D60DF4B40
77561	1104	52.425598999999998	52.435265000000001	55.753042999999998	55.745134	Шишкинский бульвар	0103000020E61000000100000005000000EB1A2D077A364A409F91088D60DF4B40EB1A2D077A364A40A9BD88B663E04B40F60B76C3B6374A40A9BD88B663E04B40F60B76C3B6374A409F91088D60DF4B40EB1A2D077A364A409F91088D60DF4B40
11032	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	Шамиля Усманова	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
11013	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	Шамиля Усманова	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
835	1104	52.35642	52.428230999999997	55.779342	55.718435999999997	Чулман проспект	0103000020E61000000100000005000000F6D1A92B9F2D4A407022FAB5F5DB4B40F6D1A92B9F2D4A401A33897AC1E34B401211FE45D0364A401A33897AC1E34B401211FE45D0364A407022FAB5F5DB4B40F6D1A92B9F2D4A407022FAB5F5DB4B40
75464	1104	52.287779999999998	52.396403999999997	55.714880999999998	55.689186999999997	Центральная	0103000020E61000000100000005000000B0389CF9D5244A4007EA944737D84B40B0389CF9D5244A4011C4793881DB4B407500C45DBD324A4011C4793881DB4B407500C45DBD324A4007EA944737D84B40B0389CF9D5244A4007EA944737D84B40
1410	1104	52.414945000000003	52.431654000000002	55.760423000000003	55.751427	Цветочный бульвар	0103000020E61000000100000005000000C251F2EA1C354A406B2A8BC22EE04B40C251F2EA1C354A402810768A55E14B400398327040374A402810768A55E14B400398327040374A406B2A8BC22EE04B40C251F2EA1C354A406B2A8BC22EE04B40
77294	1104	52.337060999999999	52.352153000000001	55.701039000000002	55.686117000000003	Хади Такташа	0103000020E61000000100000005000000E7E099D0242B4A40651D8EAED2D74B40E7E099D0242B4A403B1C5DA5BBD94B401A187959132D4A403B1C5DA5BBD94B401A187959132D4A40651D8EAED2D74B40E7E099D0242B4A40651D8EAED2D74B40
77554	1104	52.417909999999999	52.439037999999996	55.773316999999999	55.761021	Татарстан	0103000020E61000000100000005000000EF552B137E354A40DC48D92269E14B40EF552B137E354A406D382C0DFCE24B40C2D9AD6532384A406D382C0DFCE24B40C2D9AD6532384A40DC48D92269E14B40EF552B137E354A40DC48D92269E14B40
1343	1104	52.389442000000003	52.442137000000002	55.769575000000003	55.729649999999999	Сююмбике проспект	0103000020E610000001000000050000002CD8463CD9314A4061C3D32B65DD4B402CD8463CD9314A40DC68006F81E24B4000ADF9F197384A40DC68006F81E24B4000ADF9F197384A4061C3D32B65DD4B402CD8463CD9314A4061C3D32B65DD4B40
77332	1104	52.404848000000001	52.411199000000003	55.736350999999999	55.733280000000001	Строителей бульвар	0103000020E61000000100000005000000EEEC2B0FD2334A40CB67791EDCDD4B40EEEC2B0FD2334A403EB0E3BF40DE4B40EF92382BA2344A403EB0E3BF40DE4B40EF92382BA2344A40CB67791EDCDD4B40EEEC2B0FD2334A40CB67791EDCDD4B40
77555	1104	52.404848000000001	52.411199000000003	55.736350999999999	55.733280000000001	Строителей бульвар	0103000020E61000000100000005000000EEEC2B0FD2334A40CB67791EDCDD4B40EEEC2B0FD2334A403EB0E3BF40DE4B40EF92382BA2344A403EB0E3BF40DE4B40EF92382BA2344A40CB67791EDCDD4B40EEEC2B0FD2334A40CB67791EDCDD4B40
77552	1104	52.320459999999997	52.335552	55.714146	55.708303000000001	Спартаковская	0103000020E610000001000000050000008CD651D504294A40505436ACA9DA4B408CD651D504294A40DC48D92269DB4B40BF0D315EF32A4A40DC48D92269DB4B40BF0D315EF32A4A40505436ACA9DA4B408CD651D504294A40505436ACA9DA4B40
1166	1104	52.400993999999997	52.408575999999996	55.745635	55.743040999999998	Солнечный бульвар	0103000020E6100000010000000500000034F279C553334A40274BADF71BDF4B4034F279C553334A4061E0B9F770DF4B401AF7E6374C344A4061E0B9F770DF4B401AF7E6374C344A40274BADF71BDF4B4034F279C553334A40274BADF71BDF4B40
11012	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	Сармановский тракт	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
75460	1104	52.349879999999999	52.352063000000001	55.694823999999997	55.691785000000003	Сайдашева	0103000020E6100000010000000500000022C32ADEC82C4A40836E2F698CD84B4022C32ADEC82C4A40EA3C2AFEEFD84B40DA907F66102D4A40EA3C2AFEEFD84B40DA907F66102D4A40836E2F698CD84B4022C32ADEC82C4A40836E2F698CD84B40
618	1104	52.345092000000001	52.354444000000001	55.701099999999997	55.697690999999999	Садовый переулок	0103000020E610000001000000050000003D0E83F92B2C4A4055DB4DF04DD94B403D0E83F92B2C4A40E09C11A5BDD94B40B821C66B5E2D4A40E09C11A5BDD94B40B821C66B5E2D4A4055DB4DF04DD94B403D0E83F92B2C4A4055DB4DF04DD94B40
77331	1104	52.362259000000002	52.373147000000003	55.747337999999999	55.721037000000003	Раскольникова	0103000020E6100000010000000500000041D7BE805E2E4A405D1ABFF04ADC4B4041D7BE805E2E4A406E8786C5A8DF4B40DECCE847C32F4A406E8786C5A8DF4B40DECCE847C32F4A405D1ABFF04ADC4B4041D7BE805E2E4A405D1ABFF04ADC4B40
11901	1104	52.370190999999998	52.420954999999999	55.742083000000001	55.723804999999999	Раиса Беляева	0103000020E6100000010000000500000003232F6B622F4A4034D769A4A5DC4B4003232F6B622F4A4073F56393FCDE4B40390B7BDAE1354A4073F56393FCDE4B40390B7BDAE1354A4034D769A4A5DC4B4003232F6B622F4A4034D769A4A5DC4B40
75365	1104	52.342837000000003	52.369337999999999	55.704058000000003	55.696275	Низаметдинова	0103000020E61000000100000005000000EC6D3315E22B4A40DE02098A1FD94B40EC6D3315E22B4A405C3E92921EDA4B40C495B377462F4A405C3E92921EDA4B40C495B377462F4A40DE02098A1FD94B40EC6D3315E22B4A40DE02098A1FD94B40
11014	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	Нариманова	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
352	1104	52.251424999999998	52.318187999999999	55.699269000000001	55.656351000000001	Мусы Джалиля проспект	0103000020E61000000100000005000000CA32C4B12E204A4034D93F4F03D44B40CA32C4B12E204A40A60D87A581D94B4065FD6662BA284A40A60D87A581D94B4065FD6662BA284A4034D93F4F03D44B40CA32C4B12E204A4034D93F4F03D44B40
993	1104	52.379227999999998	52.455072999999999	55.756999	55.715733	Московский проспект	0103000020E610000001000000050000001EDD088B8A304A4080D591239DDB4B401EDD088B8A304A40670DDE57E5E04B40742502D53F3A4A40670DDE57E5E04B40742502D53F3A4A4080D591239DDB4B401EDD088B8A304A4080D591239DDB4B40
859	1104	52.380090000000003	52.444374000000003	55.763680000000001	55.722776000000003	Мира проспект	0103000020E61000000100000005000000B1C403CAA6304A40B72A89EC83DC4B40B1C403CAA6304A40FD4D2844C0E14B40AB984A3FE1384A40FD4D2844C0E14B40AB984A3FE1384A40B72A89EC83DC4B40B1C403CAA6304A40B72A89EC83DC4B40
77540	1104	52.380090000000003	52.444374000000003	55.763680000000001	55.722776000000003	Мира проспект	0103000020E61000000100000005000000B1C403CAA6304A40B72A89EC83DC4B40B1C403CAA6304A40FD4D2844C0E14B40AB984A3FE1384A40FD4D2844C0E14B40AB984A3FE1384A40B72A89EC83DC4B40B1C403CAA6304A40B72A89EC83DC4B40
79366	1104	52.333899000000002	52.346646	55.702784000000001	55.694398	Маршала Жукова	0103000020E610000001000000050000006495D233BD2A4A4033349E08E2D84B406495D233BD2A4A4077137CD3F4D94B4005A568E55E2C4A4077137CD3F4D94B4005A568E55E2C4A4033349E08E2D84B406495D233BD2A4A4033349E08E2D84B40
75459	1104	52.337834000000001	52.356411000000001	55.703083999999997	55.693337999999997	Комарова	0103000020E610000001000000050000000ABDFE243E2B4A407A89B14CBFD84B400ABDFE243E2B4A40A12B11A8FED94B40A3772AE09E2D4A40A12B11A8FED94B40A3772AE09E2D4A407A89B14CBFD84B400ABDFE243E2B4A407A89B14CBFD84B40
11900	1104	52.394948999999997	52.403294000000002	55.721117999999997	55.715378000000001	Колгали бульвар	0103000020E61000000100000005000000404B57B08D324A4092239D8191DB4B40404B57B08D324A40494739984DDC4B40265646239F334A40494739984DDC4B40265646239F334A4092239D8191DB4B40404B57B08D324A4092239D8191DB4B40
11865	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	Касимова	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
328	1104	52.281860000000002	52.304918999999998	55.678787999999997	55.666421	Казанский проспект	0103000020E6100000010000000500000079060DFD13244A400E2F88484DD54B4079060DFD13244A4068757286E2D64B40EA76F69507274A4068757286E2D64B40EA76F69507274A400E2F88484DD54B4079060DFD13244A400E2F88484DD54B40
75461	1104	52.350033000000003	52.362825000000001	55.704697000000003	55.686892999999998	Железнодорожников	0103000020E61000000100000005000000A9C29FE1CD2C4A40F86C1D1CECD74B40A9C29FE1CD2C4A406F4BE48233DA4B40EA95B20C712E4A406F4BE48233DA4B40EA95B20C712E4A40F86C1D1CECD74B40A9C29FE1CD2C4A40F86C1D1CECD74B40
1029	1104	52.366408999999997	52.409798000000002	55.734029999999997	55.718395000000001	Дружбы Народов проспект	0103000020E61000000100000005000000E3FA777DE62E4A40124E0B5EF4DB4B40E3FA777DE62E4A403524EEB1F4DD4B40ADFBC74274344A403524EEB1F4DD4B40ADFBC74274344A40124E0B5EF4DB4B40E3FA777DE62E4A40124E0B5EF4DB4B40
11003	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	Грина	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
1130	1104	52.407120999999997	52.413553	55.749547	55.747221000000003	Главмосстроевцев бульвар	0103000020E61000000100000005000000E5417A8A1C344A4035F10EF0A4DF4B40E5417A8A1C344A404FE8F527F1DF4B40D314014EEF344A404FE8F527F1DF4B40D314014EEF344A4035F10EF0A4DF4B40E5417A8A1C344A4035F10EF0A4DF4B40
75469	1104	52.287779999999998	52.298101000000003	55.689186999999997	55.683508000000003	Гидростроителей	0103000020E61000000100000005000000B0389CF9D5244A40F646AD307DD74B40B0389CF9D5244A4007EA944737D84B40D4F36E2C28264A4007EA944737D84B40D4F36E2C28264A40F646AD307DD74B40B0389CF9D5244A40F646AD307DD74B40
75465	1104	52.282685999999998	52.292082999999998	55.672575000000002	55.667380999999999	Гвардейская	0103000020E61000000100000005000000BE840A0E2F244A40637C98BD6CD54B40BE840A0E2F244A40B98D06F016D64B40D95BCAF962254A40B98D06F016D64B40D95BCAF962254A40637C98BD6CD54B40BE840A0E2F244A40637C98BD6CD54B40
387	1104	52.292586	52.320245	55.698756000000003	55.672812999999998	Габдуллы Тукая набережная	0103000020E610000001000000050000003CA2427573254A406DA983BC1ED64B403CA2427573254A4020F12BD670D94B4090DAC4C9FD284A4020F12BD670D94B4090DAC4C9FD284A406DA983BC1ED64B403CA2427573254A406DA983BC1ED64B40
77814	1104	52.401156	52.440663999999998	55.758737000000004	55.735514999999999	Вахитова проспект	0103000020E610000001000000050000000E4C6E1459334A40D55B035B25DE4B400E4C6E1459334A40F1A1444B1EE14B4024438EAD67384A40F1A1444B1EE14B4024438EAD67384A40D55B035B25DE4B400E4C6E1459334A40D55B035B25DE4B40
77572	1104	52.401156	52.440663999999998	55.758737000000004	55.735514999999999	Вахитова проспект	0103000020E610000001000000050000000E4C6E1459334A40D55B035B25DE4B400E4C6E1459334A40F1A1444B1EE14B4024438EAD67384A40F1A1444B1EE14B4024438EAD67384A40D55B035B25DE4B400E4C6E1459334A40D55B035B25DE4B40
77559	1104	52.330252000000002	52.337249999999997	55.705108000000003	55.703935999999999	Бумажников переулок	0103000020E6100000010000000500000024B891B2452A4A40103D29931ADA4B4024B891B2452A4A40F1129CFA40DA4B40BA490C022B2B4A40F1129CFA40DA4B40BA490C022B2B4A40103D29931ADA4B4024B891B2452A4A40103D29931ADA4B40
12018	1104	52.370190999999998	52.420954999999999	55.742083000000001	55.723804999999999	Беляева Раиса	0103000020E6100000010000000500000003232F6B622F4A4034D769A4A5DC4B4003232F6B622F4A4073F56393FCDE4B40390B7BDAE1354A4073F56393FCDE4B40390B7BDAE1354A4034D769A4A5DC4B4003232F6B622F4A4034D769A4A5DC4B40
11006	1104	52.251747999999999	52.557085999999998	55.777681999999999	55.637810000000002	Батенчука	0103000020E61000000100000005000000AD6A494739204A40E88711C2A3D14B40AD6A494739204A400C5872158BE34B409C8713984E474A400C5872158BE34B409C8713984E474A40E88711C2A3D14B40AD6A494739204A40E88711C2A3D14B40
1477	1104	52.412070999999997	52.453429	55.764729000000003	55.740416000000003	Автозаводский проспект	0103000020E61000000100000005000000A45016BEBE344A40B3B794F3C5DE4B40A45016BEBE344A40C2A6CEA3E2E14B406C0723F6093A4A40C2A6CEA3E2E14B406C0723F6093A4A40B3B794F3C5DE4B40A45016BEBE344A40B3B794F3C5DE4B40
11872	1104	52.347588999999999	52.404452999999997	55.731546000000002	55.689146000000001	60 лет Октября	0103000020E6100000010000000500000084B9DDCB7D2C4A40A915A6EF35D84B4084B9DDCB7D2C4A4083C2A04CA3DD4B4071E2AB1DC5334A4083C2A04CA3DD4B4071E2AB1DC5334A40A915A6EF35D84B4084B9DDCB7D2C4A40A915A6EF35D84B40
10696	21814	52.402296999999997	52.504731999999997	54.620140999999997	54.563912000000002	Степана Разина	0103000020E61000000100000005000000B323D5777E334A4036E9B6442E484B40B323D5777E334A4051F4C0C7604F4B40519FE40E9B404A4051F4C0C7604F4B40519FE40E9B404A4036E9B6442E484B40B323D5777E334A4036E9B6442E484B40
79155	61420	48.439100000000003	49.493758999999997	55.967401000000002	55.371347	Центральная	0103000020E6100000010000000500000039D6C56D34384840DE3B6A4C88AF4B4039D6C56D34384840118FC4CBD3FB4B40868DB27E33BF4840118FC4CBD3FB4B40868DB27E33BF4840DE3B6A4C88AF4B4039D6C56D34384840DE3B6A4C88AF4B40
79297	61523	52.537880000000001	52.597760999999998	54.713147999999997	54.687764000000001	Вахитова	0103000020E6100000010000000500000014967840D9444A40DEAE97A608584B4014967840D9444A40999A046F485B4B4081E9B46E834C4A40999A046F485B4B4081E9B46E834C4A40DEAE97A608584B4014967840D9444A40DEAE97A608584B40
15339	134	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	улица Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
78520	134	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	улица Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
3897	134	49.133552000000002	49.149776000000003	55.842655999999998	55.80395	улица Фатыха Амирхана	0103000020E610000001000000050000005F28603B1891484042CF66D5E7E64B405F28603B189148409BE3DC26DCEB4B40E4DC26DC2B9348409BE3DC26DCEB4B40E4DC26DC2B93484042CF66D5E7E64B405F28603B1891484042CF66D5E7E64B40
3631	134	49.020417999999999	49.034252000000002	55.840457000000001	55.839021000000002	улица Рахимова	0103000020E61000000100000005000000F71F990E9D82484020D4450A65EB4B40F71F990E9D824840DE58501894EB4B404BE9995E62844840DE58501894EB4B404BE9995E6284484020D4450A65EB4B40F71F990E9D82484020D4450A65EB4B40
4974	134	49.220159000000002	49.224182999999996	55.866061000000002	55.858054000000003	улица Парковая	0103000020E61000000100000005000000C5758C2B2E9C4840DB19A6B6D4ED4B40C5758C2B2E9C4840A8AB3B16DBEE4B40DAA84E07B29C4840A8AB3B16DBEE4B40DAA84E07B29C4840DB19A6B6D4ED4B40C5758C2B2E9C4840DB19A6B6D4ED4B40
2782	134	49.039831	49.057986	55.831034000000002	55.823267000000001	улица Окольная	0103000020E61000000100000005000000F92EA52E19854840227024D060E94B40F92EA52E198548409AEE75525FEA4B401CD0D2156C8748409AEE75525FEA4B401CD0D2156C874840227024D060E94B40F92EA52E19854840227024D060E94B40
78413	134	49.090262000000003	49.093387999999997	55.813769000000001	55.809955000000002	улица Односторонняя Гривка	0103000020E61000000100000005000000290989B48D8B4840A81DFE9AACE74B40290989B48D8B4840D3BF249529E84B405FEB5223F48B4840D3BF249529E84B405FEB5223F48B4840A81DFE9AACE74B40290989B48D8B4840A81DFE9AACE74B40
4997	134	49.225431999999998	49.237388000000003	55.875900000000001	55.867328999999998	улица Начальная	0103000020E6100000010000000500000066BCADF4DA9C4840AAEFFCA204EF4B4066BCADF4DA9C48408048BF7D1DF04B403F3BE0BA629E48408048BF7D1DF04B403F3BE0BA629E4840AAEFFCA204EF4B4066BCADF4DA9C4840AAEFFCA204EF4B40
1785	134	49.073059999999998	49.083919999999999	55.852894999999997	55.852671999999998	улица Лядова	0103000020E61000000100000005000000A852B3075A894840821B295B24ED4B40A852B3075A89484001F6D1A92BED4B407BBDFBE3BD8A484001F6D1A92BED4B407BBDFBE3BD8A4840821B295B24ED4B40A852B3075A894840821B295B24ED4B40
2053	134	49.108417000000003	49.123168	55.796672999999998	55.790626000000003	улица Кремлевская	0103000020E610000001000000050000004CAAB69BE08D484004AF963B33E54B404CAAB69BE08D4840984D8061F9E54B40F5F411F8C38F4840984D8061F9E54B40F5F411F8C38F484004AF963B33E54B404CAAB69BE08D484004AF963B33E54B40
4168	134	49.114283	49.115549999999999	55.771068999999997	55.769706999999997	улица Красного Пожарника	0103000020E6100000010000000500000090BE49D3A08E48404A404CC285E24B4090BE49D3A08E4840CEFA9463B2E24B40C286A757CA8E4840CEFA9463B2E24B40C286A757CA8E48404A404CC285E24B4090BE49D3A08E48404A404CC285E24B40
3273	134	49.098714999999999	49.101581000000003	55.843367999999998	55.820464999999999	улица Короленко	0103000020E61000000100000005000000F44F70B1A28C48409E4143FF04E94B40F44F70B1A28C4840183F8D7BF3EB4B408F72309B008D4840183F8D7BF3EB4B408F72309B008D48409E4143FF04E94B40F44F70B1A28C48409E4143FF04E94B40
59005	134	49.125117000000003	49.143937000000001	55.794441999999997	55.793050000000001	улица Горького	0103000020E610000001000000050000003A9677D503904840E10B93A982E54B403A9677D503904840CF488446B0E54B4099D711876C924840CF488446B0E54B4099D711876C924840E10B93A982E54B403A9677D503904840E10B93A982E54B40
3347	134	49.042679	49.101517999999999	55.836049000000003	55.825639000000002	улица Восстания	0103000020E61000000100000005000000ED9C668176854840ADA6EB89AEE94B40ED9C668176854840406D54A703EB4B4048FAB48AFE8C4840406D54A703EB4B4048FAB48AFE8C4840ADA6EB89AEE94B40ED9C668176854840ADA6EB89AEE94B40
1865	134	49.000970000000002	49.086264999999997	55.867187000000001	55.863965	улица Беломорская	0103000020E610000001000000050000007923F3C81F804840BFF1B56796EE4B407923F3C81F8048401842CEFBFFEE4B400CE544BB0A8B48401842CEFBFFEE4B400CE544BB0A8B4840BFF1B56796EE4B407923F3C81F804840BFF1B56796EE4B40
3543	134	49.050305000000002	49.057302999999997	55.834663999999997	55.828622000000003	улица Бакалейная	0103000020E61000000100000005000000A3E9EC6470864840815F234910EA4B40A3E9EC647086484003931B45D6EA4B40397B67B45587484003931B45D6EA4B40397B67B455874840815F234910EA4B40A3E9EC6470864840815F234910EA4B40
4295	134	49.139032	49.139454000000001	55.748289999999997	55.742807999999997	улица Актайская	0103000020E610000001000000050000007A8CF2CCCB914840849A215514DF4B407A8CF2CCCB91484040F67AF7C7DF4B40F0A5F0A0D991484040F67AF7C7DF4B40F0A5F0A0D9914840849A215514DF4B407A8CF2CCCB914840849A215514DF4B40
3518	134	49.059880999999997	49.087575999999999	55.839779999999998	55.838597	улица Академика Королева	0103000020E610000001000000050000006D533C2EAA87484009C3802557EB4B406D533C2EAA874840DDEA39E97DEB4B400EF5BBB0358B4840DDEA39E97DEB4B400EF5BBB0358B484009C3802557EB4B406D533C2EAA87484009C3802557EB4B40
75232	134	48.827953999999998	49.329726000000001	55.939070999999998	55.668802999999997	проспект Альберта Камалеева	0103000020E61000000100000005000000D34B8C65FA694840BC3B32569BD54B40D34B8C65FA6948409ECF807A33F84B400952297634AA48409ECF807A33F84B400952297634AA4840BC3B32569BD54B40D34B8C65FA694840BC3B32569BD54B40
77607	134	49.179671999999997	49.219771999999999	55.809837999999999	55.734278000000003	пр.Победы	0103000020E61000000100000005000000E200FA7DFF9648400E164ED2FCDD4B40E200FA7DFF9648406E8786C5A8E74B40CB49287D219C48406E8786C5A8E74B40CB49287D219C48400E164ED2FCDD4B40E200FA7DFF9648400E164ED2FCDD4B40
3316	134	49.085842999999997	49.179518999999999	55.829329999999999	55.816920000000003	Ямашева проспект	0103000020E6100000010000000500000096CB46E7FC8A484063B9A5D590E84B4096CB46E7FC8A4840BCCB457C27EA4B405C01857AFA964840BCCB457C27EA4B405C01857AFA96484063B9A5D590E84B4096CB46E7FC8A484063B9A5D590E84B40
4249	134	49.148662000000002	49.151176999999997	55.727576999999997	55.726989000000003	Якты Юл переулок	0103000020E6100000010000000500000038143E5B07934840A0C6BDF90DDD4B4038143E5B0793484030293E3E21DD4B40257497C45993484030293E3E21DD4B40257497C459934840A0C6BDF90DDD4B4038143E5B07934840A0C6BDF90DDD4B40
77882	134	49.199686	49.231783	55.776192999999999	55.742472999999997	Юлиуса Фучика	0103000020E610000001000000050000000ABC934F8F994840DD94F25A09DF4B400ABC934F8F9948402B31CF4A5AE34B406762BA10AB9D48402B31CF4A5AE34B406762BA10AB9D4840DD94F25A09DF4B400ABC934F8F994840DD94F25A09DF4B40
75407	134	49.081567	49.101258000000001	55.733806999999999	55.726249000000003	Южно-Промышленная	0103000020E6100000010000000500000067B796C9708A484059E02BBAF5DC4B4067B796C9708A4840B6494563EDDD4B40AC3AAB05F68C4840B6494563EDDD4B40AC3AAB05F68C484059E02BBAF5DC4B4067B796C9708A484059E02BBAF5DC4B40
77763	134	49.126005999999997	49.145328999999997	55.777377999999999	55.767499000000001	Эсперанто	0103000020E61000000100000005000000C58CF0F6209048403A5B40683DE24B40C58CF0F620904840A0504F1F81E34B40871403249A924840A0504F1F81E34B40871403249A9248403A5B40683DE24B40C58CF0F6209048403A5B40683DE24B40
77942	134	49.078557000000004	49.078988000000003	55.829355	55.825527000000001	Энергетиков	0103000020E610000001000000050000009AEFE0270E8A4840857B65DEAAE94B409AEFE0270E8A484015E3FC4D28EA4B4063635E471C8A484015E3FC4D28EA4B4063635E471C8A4840857B65DEAAE94B409AEFE0270E8A4840857B65DEAAE94B40
78576	134	49.069133999999998	49.079571999999999	55.811199000000002	55.807729000000002	Энгельса	0103000020E6100000010000000500000055850662D9884840F183F3A963E74B4055850662D988484022C66B5ED5E74B40B2D6506A2F8A484022C66B5ED5E74B40B2D6506A2F8A4840F183F3A963E74B4055850662D9884840F183F3A963E74B40
77857	134	49.055497000000003	49.058686000000002	55.817314000000003	55.817011000000001	Шульгина	0103000020E61000000100000005000000580394861A87484073BC02D193E84B40580394861A8748400F48C2BE9DE84B40D55DD905838748400F48C2BE9DE84B40D55DD9058387484073BC02D193E84B40580394861A87484073BC02D193E84B40
77913	134	49.07526	49.090972000000001	55.808416999999999	55.807896	Шоссейная	0103000020E610000001000000050000003659A31EA2894840DC48D92269E74B403659A31EA2894840E54350357AE74B40056D72F8A48B4840E54350357AE74B40056D72F8A48B4840DC48D92269E74B403659A31EA2894840DC48D92269E74B40
78566	134	49.144485000000003	49.147108000000003	55.743521999999999	55.743188000000004	Школьная	0103000020E610000001000000050000009CE1067C7E924840CC63CDC820DF4B409CE1067C7E924840A2ED98BA2BDF4B40707D586FD4924840A2ED98BA2BDF4B40707D586FD4924840CC63CDC820DF4B409CE1067C7E924840CC63CDC820DF4B40
79191	134	49.144485000000003	49.147108000000003	55.743521999999999	55.743188000000004	Школьная	0103000020E610000001000000050000009CE1067C7E924840CC63CDC820DF4B409CE1067C7E924840A2ED98BA2BDF4B40707D586FD4924840A2ED98BA2BDF4B40707D586FD4924840CC63CDC820DF4B409CE1067C7E924840CC63CDC820DF4B40
69441	134	49.144485000000003	49.147108000000003	55.743521999999999	55.743188000000004	Школьная	0103000020E610000001000000050000009CE1067C7E924840CC63CDC820DF4B409CE1067C7E924840A2ED98BA2BDF4B40707D586FD4924840A2ED98BA2BDF4B40707D586FD4924840CC63CDC820DF4B409CE1067C7E924840CC63CDC820DF4B40
77732	134	49.115774000000002	49.127084000000004	55.782511	55.767837999999998	Шигабутдина Марджани	0103000020E6100000010000000500000012DDB3AED18E48402250FD8348E24B4012DDB3AED18E484050E1085229E44B4025ECDB494490484050E1085229E44B4025ECDB49449048402250FD8348E24B4012DDB3AED18E48402250FD8348E24B40
68514	134	49.061956000000002	49.081513000000001	55.832343000000002	55.829239000000001	Шамиля Усманова	0103000020E610000001000000050000003FE5982CEE874840ACC8E88024EA4B403FE5982CEE874840FB0626378AEA4B4074999A046F8A4840FB0626378AEA4B4074999A046F8A4840ACC8E88024EA4B403FE5982CEE874840ACC8E88024EA4B40
71062	134	49.061956000000002	49.081513000000001	55.832343000000002	55.829239000000001	Шамиля Усманова	0103000020E610000001000000050000003FE5982CEE874840ACC8E88024EA4B403FE5982CEE874840FB0626378AEA4B4074999A046F8A4840FB0626378AEA4B4074999A046F8A4840ACC8E88024EA4B403FE5982CEE874840ACC8E88024EA4B40
78017	134	49.219268999999997	49.231513	55.762439000000001	55.761749999999999	Чишмяле	0103000020E610000001000000050000006803B001119C48402FDD240681E14B406803B001119C4840F418E59997E14B40A7CCCD37A29D4840F418E59997E14B40A7CCCD37A29D48402FDD240681E14B406803B001119C48402FDD240681E14B40
77576	134	49.098050999999998	49.160671999999998	55.829329999999999	55.818058000000001	Чистопольская	0103000020E61000000100000005000000882B67EF8C8C4840971DE21FB6E84B40882B67EF8C8C4840BCCB457C27EA4B4003B16CE690944840BCCB457C27EA4B4003B16CE690944840971DE21FB6E84B40882B67EF8C8C4840971DE21FB6E84B40
77839	134	49.109962000000003	49.147323	55.823636	55.823611	Четаева	0103000020E61000000100000005000000C1E61C3C138E48401CD0D2156CE94B40C1E61C3C138E484075E789E76CE94B406C79E57ADB92484075E789E76CE94B406C79E57ADB9248401CD0D2156CE94B40C1E61C3C138E48401CD0D2156CE94B40
79101	134	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
79263	134	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
78730	134	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
77623	134	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
75189	134	49.188754000000003	49.19258	55.760570000000001	55.741459999999996	Хусаина Мавлютова	0103000020E610000001000000050000009E7E50172998484065A54929E8DE4B409E7E501729984840CC28965B5AE14B408DEE2076A6984840CC28965B5AE14B408DEE2076A698484065A54929E8DE4B409E7E50172998484065A54929E8DE4B40
77729	134	49.049954999999997	49.051195	55.850529999999999	55.840558000000001	Хлебозаводская	0103000020E61000000100000005000000C6A2E9EC648648401232906797EB4B40C6A2E9EC648648402922C32ADEEC4B40FF5BC98E8D8648402922C32ADEEC4B40FF5BC98E8D8648401232906797EB4B40C6A2E9EC648648401232906797EB4B40
77740	134	49.014885	49.016357999999997	55.87744	55.860346999999997	Химиков	0103000020E61000000100000005000000B9196EC0E7814840191BBAD91FEE4B40B9196EC0E7814840E31934F44FF04B409483D90418824840E31934F44FF04B409483D90418824840191BBAD91FEE4B40B9196EC0E7814840191BBAD91FEE4B40
77953	134	49.184873000000003	49.200305999999998	55.820065999999997	55.818022999999997	Халитова	0103000020E61000000100000005000000EB7420EBA99748401A3048FAB4E84B40EB7420EBA9974840E04735ECF7E84B40A69883A0A3994840E04735ECF7E84B40A69883A0A39948401A3048FAB4E84B40EB7420EBA99748401A3048FAB4E84B40
77992	134	49.211418000000002	49.226312	55.870278999999996	55.858877	Халезова	0103000020E6100000010000000500000093E4B9BE0F9B4840AF2479AEEFED4B4093E4B9BE0F9B4840A2B2614D65EF4B409F58A7CAF79C4840A2B2614D65EF4B409F58A7CAF79C4840AF2479AEEFED4B4093E4B9BE0F9B4840AF2479AEEFED4B40
77964	134	49.211418000000002	49.226312	55.870278999999996	55.858877	Халезова	0103000020E6100000010000000500000093E4B9BE0F9B4840AF2479AEEFED4B4093E4B9BE0F9B4840A2B2614D65EF4B409F58A7CAF79C4840A2B2614D65EF4B409F58A7CAF79C4840AF2479AEEFED4B4093E4B9BE0F9B4840AF2479AEEFED4B40
78025	134	49.223581000000003	49.230516000000001	55.792382000000003	55.782456000000003	Хайдара Бигичева	0103000020E61000000100000005000000E5805D4D9E9C48408D47A98427E44B40E5805D4D9E9C484034F8FBC56CE54B40359A5C8C819D484034F8FBC56CE54B40359A5C8C819D48408D47A98427E44B40E5805D4D9E9C48408D47A98427E44B40
77780	134	49.127830000000003	49.146605000000001	55.780790000000003	55.756092000000002	Хади Такташа	0103000020E610000001000000050000004EB9C2BB5C9048403562669FC7E04B404EB9C2BB5C9048409D853DEDF0E34B400D37E0F3C39248409D853DEDF0E34B400D37E0F3C39248403562669FC7E04B404EB9C2BB5C9048403562669FC7E04B40
75413	134	49.156010000000002	49.183705000000003	55.733573999999997	55.716970000000003	Ферма-2	0103000020E61000000100000005000000ABECBB22F8934840481B47ACC5DB4B40ABECBB22F89348401399B9C0E5DD4B404C8E3BA5839748401399B9C0E5DD4B404C8E3BA583974840481B47ACC5DB4B40ABECBB22F8934840481B47ACC5DB4B40
77795	134	49.133552000000002	49.149776000000003	55.842655999999998	55.80395	Фатыха Амирхана	0103000020E610000001000000050000005F28603B1891484042CF66D5E7E64B405F28603B189148409BE3DC26DCEB4B40E4DC26DC2B9348409BE3DC26DCEB4B40E4DC26DC2B93484042CF66D5E7E64B405F28603B1891484042CF66D5E7E64B40
77778	134	49.154654000000001	49.157482999999999	55.789816000000002	55.782532000000003	Товарищеская	0103000020E610000001000000050000000919C8B3CB934840680932022AE44B400919C8B3CB934840C4EDD0B018E54B408656276728944840C4EDD0B018E54B408656276728944840680932022AE44B400919C8B3CB934840680932022AE44B40
77934	134	49.080056999999996	49.084693000000001	55.826377000000001	55.824359000000001	Тверская	0103000020E610000001000000050000006E68CA4E3F8A4840E694809884E94B406E68CA4E3F8A48405395B6B8C6E94B409E996038D78A48405395B6B8C6E94B409E996038D78A4840E694809884E94B406E68CA4E3F8A4840E694809884E94B40
75390	134	49.102812	49.118927999999997	55.784875	55.773220999999999	Татарстан	0103000020E6100000010000000500000074D190F1288D48404BCADDE7F8E24B4074D190F1288D48405839B4C876E44B40124A5F08398F48405839B4C876E44B40124A5F08398F48404BCADDE7F8E24B4074D190F1288D48404BCADDE7F8E24B40
77670	134	49.074578000000002	49.084944	55.859610000000004	55.856107999999999	Социалистическая	0103000020E6100000010000000500000024809BC58B89484007EC6AF294ED4B4024809BC58B89484044A852B307EE4B40E7FEEA71DF8A484044A852B307EE4B40E7FEEA71DF8A484007EC6AF294ED4B4024809BC58B89484007EC6AF294ED4B40
77501	134	49.247520999999999	49.270679999999999	55.818159000000001	55.799674000000003	Советская	0103000020E610000001000000050000005F09A4C4AE9F484013BBB6B75BE64B405F09A4C4AE9F4840CBF6216FB9E84B4034D769A4A5A24840CBF6216FB9E84B4034D769A4A5A2484013BBB6B75BE64B405F09A4C4AE9F484013BBB6B75BE64B40
77574	134	49.079923000000001	49.098562999999999	55.867176999999998	55.863160999999998	Симонова	0103000020E610000001000000050000005F99B7EA3A8A48406117450F7CEE4B405F99B7EA3A8A4840F46BEBA7FFEE4B403ECC5EB69D8C4840F46BEBA7FFEE4B403ECC5EB69D8C48406117450F7CEE4B405F99B7EA3A8A48406117450F7CEE4B40
8208	134	49.17474	49.207653999999998	55.849352000000003	55.803235999999998	Сибирский тракт	0103000020E61000000100000005000000CAA65CE15D964840247CEF6FD0E64B40CAA65CE15D9648406765FB90B7EC4B4019710168949A48406765FB90B7EC4B4019710168949A4840247CEF6FD0E64B40CAA65CE15D964840247CEF6FD0E64B40
77762	134	49.058354000000001	49.078404999999997	55.832303000000003	55.822316000000001	Серова	0103000020E610000001000000050000009FCBD42478874840207D93A641E94B409FCBD424788748406DAE9AE788EA4B40E36BCF2C098A48406DAE9AE788EA4B40E36BCF2C098A4840207D93A641E94B409FCBD42478874840207D93A641E94B40
77894	134	49.216503000000003	49.233265000000003	55.755074	55.744996999999998	Сафиуллина	0103000020E61000000100000005000000323ECC5EB69B48401E4FCB0F5CDF4B40323ECC5EB69B4840AB07CC43A6E04B409626A5A0DB9D4840AB07CC43A6E04B409626A5A0DB9D48401E4FCB0F5CDF4B40323ECC5EB69B48401E4FCB0F5CDF4B40
77865	134	49.140191000000002	49.160114999999998	55.766571999999996	55.764029999999998	Роторная	0103000020E61000000100000005000000C61858C7F1914840D9942BBCCBE14B40C61858C7F1914840C00303081FE24B40AD4CF8A57E944840C00303081FE24B40AD4CF8A57E944840D9942BBCCBE14B40C61858C7F1914840D9942BBCCBE14B40
75199	134	49.181108999999999	49.225090000000002	55.766081	55.740541999999998	Рихарда Зорге	0103000020E61000000100000005000000710168942E9748403FA88B14CADE4B40710168942E974840228B34F10EE24B400D54C6BFCF9C4840228B34F10EE24B400D54C6BFCF9C48403FA88B14CADE4B40710168942E9748403FA88B14CADE4B40
75140	134	49.181108999999999	49.225090000000002	55.766081	55.740541999999998	Рихарда Зорге	0103000020E61000000100000005000000710168942E9748403FA88B14CADE4B40710168942E974840228B34F10EE24B400D54C6BFCF9C4840228B34F10EE24B400D54C6BFCF9C48403FA88B14CADE4B40710168942E9748403FA88B14CADE4B40
77691	134	48.886541999999999	48.918180999999997	55.818649999999998	55.817647999999998	Революционная	0103000020E61000000100000005000000E54350357A714840E5D18DB0A8E84B40E54350357A714840696FF085C9E84B407F677BF486754840696FF085C9E84B407F677BF486754840E5D18DB0A8E84B40E54350357A714840E5D18DB0A8E84B40
78027	134	49.225997999999997	49.233930000000001	55.784019999999998	55.782283999999997	Рашида Вагапова	0103000020E610000001000000050000000F7BA180ED9C48408F17D2E121E44B400F7BA180ED9C484078B471C45AE44B40D2C6116BF19D484078B471C45AE44B40D2C6116BF19D48408F17D2E121E44B400F7BA180ED9C48408F17D2E121E44B40
79355	134	49.118594999999999	49.126598999999999	55.801000000000002	55.784820000000003	Пушкина	0103000020E610000001000000050000000C3CF71E2E8F4840959F54FB74E44B400C3CF71E2E8F48404A0C022B87E64B40685A6265349048404A0C022B87E64B40685A626534904840959F54FB74E44B400C3CF71E2E8F4840959F54FB74E44B40
77688	134	49.093487000000003	49.102029999999999	55.720787999999999	55.706873000000002	Приволжская	0103000020E61000000100000005000000F3CCCB61F78B484074B680D07ADA4B40F3CCCB61F78B4840B4ACFBC742DC4B40FE9AAC510F8D4840B4ACFBC742DC4B40FE9AAC510F8D484074B680D07ADA4B40F3CCCB61F78B484074B680D07ADA4B40
78504	134	48.572778999999997	49.627437	56.084218999999997	55.489967999999998	Привокзальная	0103000020E61000000100000005000000F46A80D250494840130B7C45B7BE4B40F46A80D250494840D5592DB0C70A4C4072A609DB4FD04840D5592DB0C70A4C4072A609DB4FD04840130B7C45B7BE4B40F46A80D250494840130B7C45B7BE4B40
78573	134	49.080236999999997	49.104815000000002	55.751562999999997	55.737304000000002	Поперечно-Кукушкинская	0103000020E61000000100000005000000EE76BD34458A4840E19A3BFA5FDE4B40EE76BD34458A48401BF1643733E04B40AC90F2936A8D48401BF1643733E04B40AC90F2936A8D4840E19A3BFA5FDE4B40EE76BD34458A4840E19A3BFA5FDE4B40
79357	134	49.130938	49.151518000000003	55.804602000000003	55.799765000000001	Подлужная	0103000020E61000000100000005000000DEE68D93C290484023BE13B35EE64B40DEE68D93C2904840EA25C632FDE64B40AF601BF164934840EA25C632FDE64B40AF601BF16493484023BE13B35EE64B40DEE68D93C290484023BE13B35EE64B40
15884	134	49.179671999999997	49.219771999999999	55.809837999999999	55.734278000000003	Победы проспект	0103000020E61000000100000005000000E200FA7DFF9648400E164ED2FCDD4B40E200FA7DFF9648406E8786C5A8E74B40CB49287D219C48406E8786C5A8E74B40CB49287D219C48400E164ED2FCDD4B40E200FA7DFF9648400E164ED2FCDD4B40
77928	134	49.181513000000002	49.194682	55.808537999999999	55.805230000000002	Пионерская	0103000020E61000000100000005000000416667D13B97484009E1D1C611E74B40416667D13B97484060C9552C7EE74B40588FFB56EB98484060C9552C7EE74B40588FFB56EB98484009E1D1C611E74B40416667D13B97484009E1D1C611E74B40
77969	134	49.220159000000002	49.224182999999996	55.866061000000002	55.858054000000003	Парковая	0103000020E61000000100000005000000C5758C2B2E9C4840DB19A6B6D4ED4B40C5758C2B2E9C4840A8AB3B16DBEE4B40DAA84E07B29C4840A8AB3B16DBEE4B40DAA84E07B29C4840DB19A6B6D4ED4B40C5758C2B2E9C4840DB19A6B6D4ED4B40
77978	134	49.173976000000003	49.178539999999998	55.767727000000001	55.763432000000002	Отрадная	0103000020E61000000100000005000000FB2477D844964840255CC823B8E14B40FB2477D844964840CBA0DAE044E24B4090831266DA964840CBA0DAE044E24B4090831266DA964840255CC823B8E14B40FB2477D844964840255CC823B8E14B40
2684	134	48.892094	48.896289000000003	55.853309000000003	55.849857999999998	Осиновский переулок	0103000020E610000001000000050000009A7ADD22307248403A1F9E25C8EC4B409A7ADD2230724840F530B43A39ED4B40DD611399B9724840F530B43A39ED4B40DD611399B97248403A1F9E25C8EC4B409A7ADD22307248403A1F9E25C8EC4B40
69510	134	49.144627999999997	49.189742000000003	55.762292000000002	55.728220999999998	Оренбургский тракт	0103000020E61000000100000005000000FE0A992B8392484055A1815836DD4B40FE0A992B839248405000C5C892E14B40BD564277499848405000C5C892E14B40BD5642774998484055A1815836DD4B40FE0A992B8392484055A1815836DD4B40
75162	134	49.144627999999997	49.189742000000003	55.762292000000002	55.728220999999998	Оренбургский тракт	0103000020E61000000100000005000000FE0A992B8392484055A1815836DD4B40FE0A992B839248405000C5C892E14B40BD564277499848405000C5C892E14B40BD5642774998484055A1815836DD4B40FE0A992B8392484055A1815836DD4B40
78009	134	49.231603	49.247475999999999	55.772441000000001	55.766699000000003	Ноксинский Спуск	0103000020E61000000100000005000000E753C72AA59D48401E705D3123E24B40E753C72AA59D4840768BC058DFE24B40BF45274BAD9F4840768BC058DFE24B40BF45274BAD9F48401E705D3123E24B40E753C72AA59D48401E705D3123E24B40
77694	134	48.856744999999997	48.886201	55.828561000000001	55.825865999999998	Новороссийская	0103000020E610000001000000050000007901F6D1A96D48406D7022FAB5E94B407901F6D1A96D4840DBDE6E490EEA4B405C57CC086F714840DBDE6E490EEA4B405C57CC086F7148406D7022FAB5E94B407901F6D1A96D48406D7022FAB5E94B40
75118	134	49.128512999999998	49.151958999999998	55.718775000000001	55.693936000000001	Ново-Давликеевская	0103000020E61000000100000005000000300E2E1D739048402FC214E5D2D84B40300E2E1D739048405917B7D100DC4B409BAA7B64739348405917B7D100DC4B409BAA7B64739348402FC214E5D2D84B40300E2E1D739048402FC214E5D2D84B40
77683	134	49.148122999999998	49.185017000000002	55.802329999999998	55.79222	Николая Ершова	0103000020E610000001000000050000008864C8B1F59248405A9E077767E54B408864C8B1F5924840C24CDBBFB2E64B401E1A16A3AE974840C24CDBBFB2E64B401E1A16A3AE9748405A9E077767E54B408864C8B1F59248405A9E077767E54B40
75404	134	49.071173000000002	49.075296000000002	55.804606999999997	55.801369000000001	Несмелова	0103000020E61000000100000005000000DAAD65321C8948409D83674293E64B40DAAD65321C894840FB90B75CFDE64B4083C2A04CA3894840FB90B75CFDE64B4083C2A04CA38948409D83674293E64B40DAAD65321C8948409D83674293E64B40
77971	134	49.225431999999998	49.237388000000003	55.875900000000001	55.867328999999998	Начальная	0103000020E6100000010000000500000066BCADF4DA9C4840AAEFFCA204EF4B4066BCADF4DA9C48408048BF7D1DF04B403F3BE0BA629E48408048BF7D1DF04B403F3BE0BA629E4840AAEFFCA204EF4B4066BCADF4DA9C4840AAEFFCA204EF4B40
78564	134	48.827953999999998	49.329726000000001	55.939070999999998	55.668802999999997	Научный городок	0103000020E61000000100000005000000D34B8C65FA694840BC3B32569BD54B40D34B8C65FA6948409ECF807A33F84B400952297634AA48409ECF807A33F84B400952297634AA4840BC3B32569BD54B40D34B8C65FA694840BC3B32569BD54B40
77774	134	49.134585000000001	49.138016999999998	55.796370000000003	55.787244000000001	Муштари	0103000020E610000001000000050000001EC4CE143A91484072FC5069C4E44B401EC4CE143A914840FDC1C073EFE54B4061A5828AAA914840FDC1C073EFE54B4061A5828AAA91484072FC5069C4E44B401EC4CE143A91484072FC5069C4E44B40
77643	134	49.120148999999998	49.121057	55.839193000000002	55.819387999999996	Мусина	0103000020E61000000100000005000000D4D2DC0A618F48400F5EBBB4E1E84B40D4D2DC0A618F48401D041DAD6AEB4B40D7F9B7CB7E8F48401D041DAD6AEB4B40D7F9B7CB7E8F48400F5EBBB4E1E84B40D4D2DC0A618F48400F5EBBB4E1E84B40
77687	134	49.050718000000003	49.055039000000001	55.818917999999996	55.818382	Музыкальная	0103000020E61000000100000005000000C6A86BED7D8648404AD1CABDC0E84B40C6A86BED7D864840880D164ED2E84B40958098840B874840880D164ED2E84B40958098840B8748404AD1CABDC0E84B40C6A86BED7D8648404AD1CABDC0E84B40
77790	134	49.157860999999997	49.164175999999998	55.772354999999997	55.766015000000003	Моторная	0103000020E610000001000000050000002C280CCA349448406B9F8EC70CE24B402C280CCA3494484077F35487DCE24B40E0641BB80395484077F35487DCE24B40E0641BB8039548406B9F8EC70CE24B402C280CCA349448406B9F8EC70CE24B40
77610	134	49.031269999999999	49.032716000000001	55.826028000000001	55.822468000000001	Можайского	0103000020E6100000010000000500000047ACC5A700844840D600A5A146E94B4047ACC5A70084484047CA1649BBE94B402907B3093084484047CA1649BBE94B402907B30930844840D600A5A146E94B4047ACC5A700844840D600A5A146E94B40
77653	134	49.207653999999998	49.233156999999999	55.867227999999997	55.849352000000003	Мира	0103000020E6100000010000000500000019710168949A48406765FB90B7EC4B4019710168949A48407616BD5301EF4B40AFEAAC16D89D48407616BD5301EF4B40AFEAAC16D89D48406765FB90B7EC4B4019710168949A48406765FB90B7EC4B40
69533	134	49.207653999999998	49.233156999999999	55.867227999999997	55.849352000000003	Мира	0103000020E6100000010000000500000019710168949A48406765FB90B7EC4B4019710168949A48407616BD5301EF4B40AFEAAC16D89D48407616BD5301EF4B40AFEAAC16D89D48406765FB90B7EC4B4019710168949A48406765FB90B7EC4B40
77584	134	49.124147000000001	49.129095999999997	55.681401999999999	55.672274999999999	Матюшинская	0103000020E61000000100000005000000C172840CE48F48408E75711B0DD64B40C172840CE48F4840E9B6442E38D74B40AF05BD3786904840E9B6442E38D74B40AF05BD37869048408E75711B0DD64B40C172840CE48F48408E75711B0DD64B40
77806	134	49.101500000000001	49.159351999999998	55.836069000000002	55.835867	Маршала Чуйкова	0103000020E61000000100000005000000A245B6F3FD8C48401F679AB0FDEA4B40A245B6F3FD8C484087191A4F04EB4B40AE4676A56594484087191A4F04EB4B40AE4676A5659448401F679AB0FDEA4B40A245B6F3FD8C48401F679AB0FDEA4B40
75429	134	49.053260999999999	49.061705000000003	55.800336999999999	55.799622999999997	Мало-Московская	0103000020E610000001000000050000007D93A641D18648409010E50B5AE64B407D93A641D1864840AE635C7171E64B40F67F0EF3E5874840AE635C7171E64B40F67F0EF3E58748409010E50B5AE64B407D93A641D18648409010E50B5AE64B40
77599	134	49.064993000000001	49.068218000000002	55.884321999999997	55.859417999999998	Малая Армавирская	0103000020E6100000010000000500000006BCCCB051884840FFCBB56801EE4B4006BCCCB05188484010919A7631F14B40D07F0F5EBB88484010919A7631F14B40D07F0F5EBB884840FFCBB56801EE4B4006BCCCB051884840FFCBB56801EE4B40
77668	134	49.057257999999997	49.105794000000003	55.864216999999996	55.858108999999999	Максимова	0103000020E6100000010000000500000099B7EA3A548748409EB30584D6ED4B4099B7EA3A54874840D8D2A3A99EEE4B40780E65A88A8D4840D8D2A3A99EEE4B40780E65A88A8D48409EB30584D6ED4B4099B7EA3A548748409EB30584D6ED4B40
77744	134	49.102542	49.106898999999999	55.773342999999997	55.762960999999997	Мазита Гафури	0103000020E61000000100000005000000B43BA418208D4840CD8FBFB4A8E14B40B43BA418208D484096CB46E7FCE24B40D07CCEDDAE8D484096CB46E7FCE24B40D07CCEDDAE8D4840CD8FBFB4A8E14B40B43BA418208D4840CD8FBFB4A8E14B40
77676	134	49.073059999999998	49.083919999999999	55.852894999999997	55.852671999999998	Лядова	0103000020E61000000100000005000000A852B3075A894840821B295B24ED4B40A852B3075A89484001F6D1A92BED4B407BBDFBE3BD8A484001F6D1A92BED4B407BBDFBE3BD8A4840821B295B24ED4B40A852B3075A894840821B295B24ED4B40
79299	134	49.073059999999998	49.083919999999999	55.852894999999997	55.852671999999998	Лядова	0103000020E61000000100000005000000A852B3075A894840821B295B24ED4B40A852B3075A89484001F6D1A92BED4B407BBDFBE3BD8A484001F6D1A92BED4B407BBDFBE3BD8A4840821B295B24ED4B40A852B3075A894840821B295B24ED4B40
77741	134	49.034709999999997	49.071981999999998	55.877949999999998	55.875627000000001	Луначарского	0103000020E610000001000000050000000D6C9560718448404F3FA88B14F04B400D6C956071844840F8C264AA60F04B4049F3C7B436894840F8C264AA60F04B4049F3C7B4368948404F3FA88B14F04B400D6C9560718448404F3FA88B14F04B40
77606	134	49.218919	49.231603	55.767068000000002	55.766976999999997	Ломжинская	0103000020E610000001000000050000008CBCAC89059C484060E4654D2CE24B408CBCAC89059C484071E7C2482FE24B40E753C72AA59D484071E7C2482FE24B40E753C72AA59D484060E4654D2CE24B408CBCAC89059C484060E4654D2CE24B40
77979	134	49.211131000000002	49.226680000000002	55.874783999999998	55.863802999999997	Липатова	0103000020E61000000100000005000000FD153257069B4840E597C11891EE4B40FD153257069B484033880FECF8EF4B402254A9D9039D484033880FECF8EF4B402254A9D9039D4840E597C11891EE4B40FD153257069B4840E597C11891EE4B40
79724	134	49.107339000000003	49.116816	55.716199000000003	55.715581	Лесная	0103000020E61000000100000005000000ED4ACB48BD8D4840CA51802898DB4B40ED4ACB48BD8D4840C636A968ACDB4B4024D3A1D3F38E4840C636A968ACDB4B4024D3A1D3F38E4840CA51802898DB4B40ED4ACB48BD8D4840CA51802898DB4B40
77585	134	49.083848000000003	49.088906000000001	55.870874999999998	55.859281000000003	Ленинградская	0103000020E61000000100000005000000E2EA0088BB8A48407F8978EBFCED4B40E2EA0088BB8A4840B6F3FDD478EF4B4087359545618B4840B6F3FDD478EF4B4087359545618B48407F8978EBFCED4B40E2EA0088BB8A48407F8978EBFCED4B40
77692	134	48.892085000000002	48.917624000000004	55.821238999999998	55.819960000000002	Лейтенанта Красикова	0103000020E6100000010000000500000047205ED72F7248409B030473F4E84B4047205ED72F72484091990B5C1EE94B402A0307B47475484091990B5C1EE94B402A0307B4747548409B030473F4E84B4047205ED72F7248409B030473F4E84B40
77722	134	49.102857	49.118037999999999	55.796137000000002	55.784471000000003	Лево-Булачная	0103000020E6100000010000000500000014950D6B2A8D484089D4B48B69E44B4014950D6B2A8D48405A1135D1E7E54B40B6D782DE1B8F48405A1135D1E7E54B40B6D782DE1B8F484089D4B48B69E44B4014950D6B2A8D484089D4B48B69E44B40
77996	134	49.167284000000002	49.177731000000001	55.763756000000001	55.760013000000001	Латышских Стрелков	0103000020E610000001000000050000007192E68F6995484076C4211B48E14B407192E68F69954840D80FB1C1C2E14B40213EB0E3BF964840D80FB1C1C2E14B40213EB0E3BF96484076C4211B48E14B407192E68F6995484076C4211B48E14B40
77716	134	49.050018000000001	49.061965000000001	55.833091000000003	55.821669	Кулахметова	0103000020E610000001000000050000000D1B65FD668648408A9125732CE94B400D1B65FD66864840C5CBD3B9A2EA4B40923F1878EE874840C5CBD3B9A2EA4B40923F1878EE8748408A9125732CE94B400D1B65FD668648408A9125732CE94B40
77831	134	49.057698000000002	49.07535	55.818316000000003	55.804901000000001	Краснококшайская	0103000020E61000000100000005000000B685E7A56287484044C2F7FE06E74B40B685E7A56287484093E52494BEE84B4076E09C11A589484093E52494BEE84B4076E09C11A589484044C2F7FE06E74B40B685E7A56287484044C2F7FE06E74B40
77995	134	49.16272	49.171864999999997	55.793514999999999	55.777180000000001	Красной Позиции	0103000020E61000000100000005000000DB334B02D49448407A8D5DA27AE34B40DB334B02D494484056F146E691E54B40DC291DACFF95484056F146E691E54B40DC291DACFF9548407A8D5DA27AE34B40DB334B02D49448407A8D5DA27AE34B40
77701	134	49.031529999999997	49.031764000000003	55.87144	55.868789	Котовского	0103000020E61000000100000005000000E36BCF2C09844840F10F5B7A34EF4B40E36BCF2C098448408F368E588BEF4B405798BED7108448408F368E588BEF4B405798BED710844840F10F5B7A34EF4B40E36BCF2C09844840F10F5B7A34EF4B40
77704	134	49.098714999999999	49.101581000000003	55.843367999999998	55.820464999999999	Короленко	0103000020E61000000100000005000000F44F70B1A28C48409E4143FF04E94B40F44F70B1A28C4840183F8D7BF3EB4B408F72309B008D4840183F8D7BF3EB4B408F72309B008D48409E4143FF04E94B40F44F70B1A28C48409E4143FF04E94B40
77672	134	49.083677999999999	49.085393000000003	55.860398000000004	55.843474999999998	Копылова	0103000020E6100000010000000500000085B2F0F5B58A48402EFF21FDF6EB4B4085B2F0F5B58A48409CC58B8521EE4B4057276728EE8A48409CC58B8521EE4B4057276728EE8A48402EFF21FDF6EB4B4085B2F0F5B58A48402EFF21FDF6EB4B40
77673	134	49.083677999999999	49.085393000000003	55.860398000000004	55.843474999999998	Копылова	0103000020E6100000010000000500000085B2F0F5B58A48402EFF21FDF6EB4B4085B2F0F5B58A48409CC58B8521EE4B4057276728EE8A48409CC58B8521EE4B4057276728EE8A48402EFF21FDF6EB4B4085B2F0F5B58A48402EFF21FDF6EB4B40
77899	134	49.224893000000002	49.241242	55.758234999999999	55.740541999999998	Комиссара Габишева	0103000020E61000000100000005000000B70C384BC99C48403FA88B14CADE4B40B70C384BC99C48405ED72FD80DE14B40F8359204E19E48405ED72FD80DE14B40F8359204E19E48403FA88B14CADE4B40B70C384BC99C48403FA88B14CADE4B40
78000	134	49.164230000000003	49.174309000000001	55.759613000000002	55.752561	Комарова	0103000020E61000000100000005000000D482177D059548405E9F39EB53E04B40D482177D05954840E84EB0FF3AE14B400133DFC14F964840E84EB0FF3AE14B400133DFC14F9648405E9F39EB53E04B40D482177D059548405E9F39EB53E04B40
77611	134	49.050117	49.070275000000002	55.800756999999997	55.79766	Клары Цеткин	0103000020E61000000100000005000000A0FCDD3B6A864840E7A90EB919E64B40A0FCDD3B6A864840838593347FE64B40FB5C6DC5FE884840838593347FE64B40FB5C6DC5FE884840E7A90EB919E64B40A0FCDD3B6A864840E7A90EB919E64B40
77967	134	49.225637999999996	49.228765000000003	55.866031	55.862054999999998	Каштановая	0103000020E610000001000000050000000F5EBBB4E19C4840382D78D157EE4B400F5EBBB4E19C48403D29931ADAEE4B4017BCE82B489D48403D29931ADAEE4B4017BCE82B489D4840382D78D157EE4B400F5EBBB4E19C4840382D78D157EE4B40
77855	134	49.142194000000003	49.149776000000003	55.775438999999999	55.771889000000002	Качалова	0103000020E61000000100000005000000FED7B9693392484032923D42CDE24B40FED7B969339248407F85CC9541E34B40E4DC26DC2B9348407F85CC9541E34B40E4DC26DC2B93484032923D42CDE24B40FED7B9693392484032923D42CDE24B40
69766	134	49.131971	49.134909	55.787584000000003	55.786602000000002	Катановский переулок	0103000020E610000001000000050000009D82FC6CE4904840EE7BD45FAFE44B409D82FC6CE49048402B6D718DCFE44B40D177B7B2449148402B6D718DCFE44B40D177B7B244914840EE7BD45FAFE44B409D82FC6CE4904840EE7BD45FAFE44B40
77682	134	49.109360000000002	49.148176999999997	55.797645000000003	55.793312999999998	Карла Маркса	0103000020E61000000100000005000000CBBE2B82FF8D4840EE3EC7478BE54B40CBBE2B82FF8D4840B2683A3B19E64B407B82C476F7924840B2683A3B19E64B407B82C476F7924840EE3EC7478BE54B40CBBE2B82FF8D4840EE3EC7478BE54B40
77736	134	49.102929000000003	49.112980999999998	55.779919	55.770167999999998	Карима Тинчурина	0103000020E61000000100000005000000AE6708C72C8D48407E3672DD94E24B40AE6708C72C8D4840B743C362D4E34B40E1085229768E4840B743C362D4E34B40E1085229768E48407E3672DD94E24B40AE6708C72C8D48407E3672DD94E24B40
77768	134	49.142454000000001	49.146155	55.784419999999997	55.783256000000002	Зеленая	0103000020E610000001000000050000009A97C3EE3B924840A9328CBB41E44B409A97C3EE3B924840062AE3DF67E44B40CD920035B5924840062AE3DF67E44B40CD920035B5924840A9328CBB41E44B409A97C3EE3B924840A9328CBB41E44B40
77685	134	48.939390000000003	48.942453	55.810698000000002	55.809499000000002	Звездная	0103000020E61000000100000005000000401878EE3D7848408692C9A99DE74B40401878EE3D7848406077BAF3C4E74B403082C64CA27848406077BAF3C4E74B403082C64CA27848408692C9A99DE74B40401878EE3D7848408692C9A99DE74B40
78569	134	48.970740999999997	48.976733000000003	55.802289999999999	55.801333999999997	Затонская	0103000020E6100000010000000500000073F1B73D417C48402096CD1C92E64B4073F1B73D417C484034F44F70B1E64B4045F64196057D484034F44F70B1E64B4045F64196057D48402096CD1C92E64B4073F1B73D417C48402096CD1C92E64B40
77630	134	48.849207999999997	48.917138999999999	55.859068999999998	55.846936999999997	Залесная	0103000020E6100000010000000500000033C005D9B26C4840DC627E6E68EC4B4033C005D9B26C4840F30016F9F5ED4B406D718DCF64754840F30016F9F5ED4B406D718DCF64754840DC627E6E68EC4B4033C005D9B26C4840DC627E6E68EC4B40
78019	134	49.219081000000003	49.235430000000001	55.776229000000001	55.776147999999999	Закиева	0103000020E610000001000000050000006616A1D80A9C48408B6D52D158E34B406616A1D80A9C4840789ACC785BE34B40A73FFB91229E4840789ACC785BE34B40A73FFB91229E48408B6D52D158E34B406616A1D80A9C48408B6D52D158E34B40
77713	134	49.129033999999997	49.130938	55.799765000000001	55.794021000000001	Жуковского	0103000020E610000001000000050000003909A52F849048402AABE97AA2E54B403909A52F8490484023BE13B35EE64B40DEE68D93C290484023BE13B35EE64B40DEE68D93C29048402AABE97AA2E54B403909A52F849048402AABE97AA2E54B40
69422	134	49.068361000000003	49.073580999999997	55.863086000000003	55.862893999999997	Дунайская	0103000020E6100000010000000500000033A9A10DC088484012F5824F73EE4B4033A9A10DC088484057D11F9A79EE4B40B14D2A1A6B89484057D11F9A79EE4B40B14D2A1A6B89484012F5824F73EE4B4033A9A10DC088484012F5824F73EE4B40
77903	134	49.19258	49.225090000000002	55.741459999999996	55.737105999999997	Дубравная	0103000020E610000001000000050000008DEE2076A6984840BAD7497D59DE4B408DEE2076A698484065A54929E8DE4B400D54C6BFCF9C484065A54929E8DE4B400D54C6BFCF9C4840BAD7497D59DE4B408DEE2076A6984840BAD7497D59DE4B40
77921	134	49.177883999999999	49.183301	55.808047000000002	55.806443999999999	Дружбы	0103000020E61000000100000005000000A73D25E7C49648401807978E39E74B40A73D25E7C4964840C25087156EE74B407C293C6876974840C25087156EE74B407C293C68769748401807978E39E74B40A73D25E7C49648401807978E39E74B40
77626	134	49.140191000000002	49.160879000000001	55.788763000000003	55.787022	Достоевского	0103000020E61000000100000005000000C61858C7F1914840C39D0B23BDE44B40C61858C7F1914840BEA59C2FF6E44B407DCEDDAE97944840BEA59C2FF6E44B407DCEDDAE97944840C39D0B23BDE44B40C61858C7F1914840C39D0B23BDE44B40
77959	134	49.206352000000003	49.241582999999999	55.859019000000004	55.845815000000002	Дорожная	0103000020E610000001000000050000006BBB09BE699A4840AEBB79AA43EC4B406BBB09BE699A484042D2A755F4ED4B4081221631EC9E484042D2A755F4ED4B4081221631EC9E4840AEBB79AA43EC4B406BBB09BE699A4840AEBB79AA43EC4B40
78024	134	49.221882999999998	49.229564000000003	55.794027	55.788930000000001	Джаудата Файзи	0103000020E61000000100000005000000E94482A9669C4840A96A82A8FBE44B40E94482A9669C48400C923EADA2E54B40632B685A629D48400C923EADA2E54B40632B685A629D4840A96A82A8FBE44B40E94482A9669C4840A96A82A8FBE44B40
79326	134	48.827953999999998	49.329726000000001	55.939070999999998	55.668802999999997	Деревня Универсиады	0103000020E61000000100000005000000D34B8C65FA694840BC3B32569BD54B40D34B8C65FA6948409ECF807A33F84B400952297634AA48409ECF807A33F84B400952297634AA4840BC3B32569BD54B40D34B8C65FA694840BC3B32569BD54B40
77656	134	49.085070000000002	49.109907999999997	55.867804	55.846446	Дементьева	0103000020E6100000010000000500000074EFE192E38A48403EEAAF5758EC4B4074EFE192E38A484043AB933314EF4B40CDC82077118E484043AB933314EF4B40CDC82077118E48403EEAAF5758EC4B4074EFE192E38A48403EEAAF5758EC4B40
77634	134	49.080146999999997	49.102722	55.843535000000003	55.801005000000004	Декабристов	0103000020E61000000100000005000000AEEFC341428A48405C77F35487E64B40AEEFC341428A4840040473F4F8EB4B40344A97FE258D4840040473F4F8EB4B40344A97FE258D48405C77F35487E64B40AEEFC341428A48405C77F35487E64B40
78054	134	49.137234999999997	49.161183999999999	55.764040000000001	55.763179000000001	Даурская	0103000020E61000000100000005000000EB6E9EEA909148403BFF76D9AFE14B40EB6E9EEA90914840FD6A0E10CCE14B40B95164ADA1944840FD6A0E10CCE14B40B95164ADA19448403BFF76D9AFE14B40EB6E9EEA909148403BFF76D9AFE14B40
77998	134	49.137234999999997	49.161183999999999	55.764040000000001	55.763179000000001	Даурская	0103000020E61000000100000005000000EB6E9EEA909148403BFF76D9AFE14B40EB6E9EEA90914840FD6A0E10CCE14B40B95164ADA1944840FD6A0E10CCE14B40B95164ADA19448403BFF76D9AFE14B40EB6E9EEA909148403BFF76D9AFE14B40
77994	134	49.137234999999997	49.161183999999999	55.764040000000001	55.763179000000001	Даурская	0103000020E61000000100000005000000EB6E9EEA909148403BFF76D9AFE14B40EB6E9EEA90914840FD6A0E10CCE14B40B95164ADA1944840FD6A0E10CCE14B40B95164ADA19448403BFF76D9AFE14B40EB6E9EEA909148403BFF76D9AFE14B40
77618	134	49.257599999999996	49.264032	55.772638999999998	55.761051000000002	Грачиная	0103000020E610000001000000050000008CB96B09F9A0484047CB811E6AE14B408CB96B09F9A048409C4EB2D5E5E24B407A8CF2CCCBA148409C4EB2D5E5E24B407A8CF2CCCBA1484047CB811E6AE14B408CB96B09F9A0484047CB811E6AE14B40
75388	134	49.076815000000003	49.083874999999999	55.877566000000002	55.876925	Граничная	0103000020E61000000100000005000000CF6BEC12D5894840BC0512143FF04B40CF6BEC12D5894840700A2B1554F04B40DBF97E6ABC8A4840700A2B1554F04B40DBF97E6ABC8A4840BC0512143FF04B40CF6BEC12D5894840BC0512143FF04B40
77647	134	49.125117000000003	49.143937000000001	55.794441999999997	55.793050000000001	Горького	0103000020E610000001000000050000003A9677D503904840E10B93A982E54B403A9677D503904840CF488446B0E54B4099D711876C924840CF488446B0E54B4099D711876C924840E10B93A982E54B403A9677D503904840E10B93A982E54B40
68510	134	48.917138999999999	49.040962999999998	55.846936999999997	55.825026999999999	Горьковское шоссе	0103000020E610000001000000050000006D718DCF6475484093A8177C9AE94B406D718DCF64754840DC627E6E68EC4B404BAC8C463E854840DC627E6E68EC4B404BAC8C463E85484093A8177C9AE94B406D718DCF6475484093A8177C9AE94B40
77908	134	49.084009999999999	49.090764999999998	55.820197	55.815888000000001	Горсоветская	0103000020E61000000100000005000000BB44F5D6C08A484074999A046FE84B40BB44F5D6C08A48407FA31D37FCE84B408B4F01309E8B48407FA31D37FCE84B408B4F01309E8B484074999A046FE84B40BB44F5D6C08A484074999A046FE84B40
77958	134	49.066861000000003	49.073338	55.835028000000001	55.834910999999998	Городская	0103000020E610000001000000050000005E30B8E68E8848400B09185DDEEA4B405E30B8E68E884840459F8F32E2EA4B40EBC6BB2363894840459F8F32E2EA4B40EBC6BB23638948400B09185DDEEA4B405E30B8E68E8848400B09185DDEEA4B40
77752	134	49.101517999999999	49.129635	55.840249999999997	55.836049000000003	Голубятникова	0103000020E6100000010000000500000048FAB48AFE8C4840406D54A703EB4B4048FAB48AFE8C4840643BDF4F8DEB4B405FB532E197904840643BDF4F8DEB4B405FB532E197904840406D54A703EB4B4048FAB48AFE8C4840406D54A703EB4B40
77874	134	49.189076999999997	49.205570000000002	55.752181	55.750757999999998	Гарифьянова	0103000020E6100000010000000500000080B6D5AC33984840ED9A90D618E04B4080B6D5AC3398484017D68D7747E04B40F584251E509A484017D68D7747E04B40F584251E509A4840ED9A90D618E04B4080B6D5AC33984840ED9A90D618E04B40
75129	134	49.062828000000003	49.069375999999998	55.824990999999997	55.817298999999998	Галимджана Баруди	0103000020E61000000100000005000000F5A276BF0A884840D906EE409DE84B40F5A276BF0A884840463F1A4E99E94B404B901150E1884840463F1A4E99E94B404B901150E1884840D906EE409DE84B40F5A276BF0A884840D906EE409DE84B40
77930	134	49.173644000000003	49.180461999999999	55.803655999999997	55.799987999999999	Галеева	0103000020E61000000100000005000000C59272F739964840A298BC0166E64B40C59272F739964840F99D2633DEE64B40DB15FA6019974840F99D2633DEE64B40DB15FA6019974840A298BC0166E64B40C59272F739964840A298BC0166E64B40
77943	134	49.061318999999997	49.118164	55.842185999999998	55.834001999999998	Гагарина	0103000020E61000000100000005000000CCCF0D4DD98748403866D993C0EA4B40CCCF0D4DD9874840149337C0CCEB4B4043C879FF1F8F4840149337C0CCEB4B4043C879FF1F8F48403866D993C0EA4B40CCCF0D4DD98748403866D993C0EA4B40
77707	134	49.061318999999997	49.118164	55.842185999999998	55.834001999999998	Гагарина	0103000020E61000000100000005000000CCCF0D4DD98748403866D993C0EA4B40CCCF0D4DD9874840149337C0CCEB4B4043C879FF1F8F4840149337C0CCEB4B4043C879FF1F8F48403866D993C0EA4B40CCCF0D4DD98748403866D993C0EA4B40
77655	134	49.061318999999997	49.118164	55.842185999999998	55.834001999999998	Гагарина	0103000020E61000000100000005000000CCCF0D4DD98748403866D993C0EA4B40CCCF0D4DD9874840149337C0CCEB4B4043C879FF1F8F4840149337C0CCEB4B4043C879FF1F8F48403866D993C0EA4B40CCCF0D4DD98748403866D993C0EA4B40
77725	134	49.107950000000002	49.125171000000002	55.785387	55.767904000000001	Габдуллы Тукая	0103000020E6100000010000000500000036CD3B4ED18D4840DA3BA3AD4AE24B4036CD3B4ED18D48400EDAAB8F87E44B402DB4739A059048400EDAAB8F87E44B402DB4739A05904840DA3BA3AD4AE24B4036CD3B4ED18D4840DA3BA3AD4AE24B40
77940	134	49.178314999999998	49.187882000000002	55.813060999999998	55.811633999999998	Восьмого Марта	0103000020E6100000010000000500000070B1A206D39648402C29779FE3E74B4070B1A206D39648409753026212E84B40E8C072840C9848409753026212E84B40E8C072840C9848402C29779FE3E74B4070B1A206D39648402C29779FE3E74B40
77715	134	49.069375999999998	49.073805	55.841776000000003	55.824961000000002	Восход	0103000020E610000001000000050000004B901150E1884840DCBC715298E94B404B901150E18848406347E350BFEB4B4001A43671728948406347E350BFEB4B4001A4367172894840DCBC715298E94B404B901150E1884840DCBC715298E94B40
77639	134	49.042679	49.101517999999999	55.836049000000003	55.825639000000002	Восстания	0103000020E61000000100000005000000ED9C668176854840ADA6EB89AEE94B40ED9C668176854840406D54A703EB4B4048FAB48AFE8C4840406D54A703EB4B4048FAB48AFE8C4840ADA6EB89AEE94B40ED9C668176854840ADA6EB89AEE94B40
79359	134	49.075144000000002	49.147376999999999	55.843656000000003	55.840710000000001	Воровского	0103000020E61000000100000005000000CD3E8F519E894840C8B5A1629CEB4B40CD3E8F519E8948407F8978EBFCEB4B405F97E13FDD9248407F8978EBFCEB4B405F97E13FDD924840C8B5A1629CEB4B40CD3E8F519E894840C8B5A1629CEB4B40
77821	134	49.132950000000001	49.143748000000002	55.790565000000001	55.781585	Волкова	0103000020E6100000010000000500000069006F8104914840A7052FFA0AE44B4069006F81049148405E2EE23B31E54B40C66E9F55669248405E2EE23B31E54B40C66E9F5566924840A7052FFA0AE44B4069006F8104914840A7052FFA0AE44B40
77644	134	49.081378000000001	49.104959000000001	55.831538999999999	55.829239000000001	Волгоградская	0103000020E61000000100000005000000944E24986A8A4840ACC8E88024EA4B40944E24986A8A48409D2CB5DE6FEA4B40DF35E84B6F8D48409D2CB5DE6FEA4B40DF35E84B6F8D4840ACC8E88024EA4B40944E24986A8A4840ACC8E88024EA4B40
77847	134	49.104770000000002	49.144871000000002	55.743015	55.742204999999998	Владимира Кулагина	0103000020E610000001000000050000000CCD751A698D4840BEF6CC9200DF4B400CCD751A698D4840FEB7921D1BDF4B40C59107228B924840FEB7921D1BDF4B40C59107228B924840BEF6CC9200DF4B400CCD751A698D4840BEF6CC9200DF4B40
77590	134	49.179456000000002	49.218111	55.757136000000003	55.754978000000001	Братьев Касимовых	0103000020E610000001000000050000001689096AF896484089997D1EA3E04B401689096AF8964840E84F1BD5E9E04B40EDF2AD0FEB9B4840E84F1BD5E9E04B40EDF2AD0FEB9B484089997D1EA3E04B401689096AF896484089997D1EA3E04B40
77654	134	49.159027999999999	49.161363999999999	55.768709000000001	55.768005000000002	Братская	0103000020E61000000100000005000000FB928D075B9448400E15E3FC4DE24B40FB928D075B9448400892770E65E24B4039605793A79448400892770E65E24B4039605793A79448400E15E3FC4DE24B40FB928D075B9448400E15E3FC4DE24B40
77786	134	49.147305000000003	49.148850000000003	55.781301999999997	55.777261000000003	Бойничная	0103000020E61000000100000005000000C6C4E6E3DA92484067BAD7497DE34B40C6C4E6E3DA924840522635B401E44B403B014D840D934840522635B401E44B403B014D840D93484067BAD7497DE34B40C6C4E6E3DA92484067BAD7497DE34B40
77613	134	49.002164999999998	49.050117	55.801667999999999	55.79721	Боевая	0103000020E61000000100000005000000111956F146804840A7052FFA0AE64B40111956F146804840F71F990E9DE64B40A0FCDD3B6A864840F71F990E9DE64B40A0FCDD3B6A864840A7052FFA0AE64B40111956F146804840A7052FFA0AE64B40
77689	134	48.875242	48.892085000000002	55.820238000000003	55.819296999999999	Бирюзовая	0103000020E61000000100000005000000F60A0BEE07704840FF5A5EB9DEE84B40F60A0BEE07704840DE770C8FFDE84B4047205ED72F724840DE770C8FFDE84B4047205ED72F724840FF5A5EB9DEE84B40F60A0BEE07704840FF5A5EB9DEE84B40
77695	134	49.000970000000002	49.086264999999997	55.867187000000001	55.863965	Беломорская	0103000020E610000001000000050000007923F3C81F804840BFF1B56796EE4B407923F3C81F8048401842CEFBFFEE4B400CE544BB0A8B48401842CEFBFFEE4B400CE544BB0A8B4840BFF1B56796EE4B407923F3C81F804840BFF1B56796EE4B40
77684	134	49.067408999999998	49.084792	55.854298999999997	55.849170000000001	Белинского	0103000020E61000000100000005000000603AADDBA0884840465F419AB1EC4B40603AADDBA0884840B4006DAB59ED4B40317BD976DA8A4840B4006DAB59ED4B40317BD976DA8A4840465F419AB1EC4B40603AADDBA0884840465F419AB1EC4B40
77728	134	49.054023999999998	49.071981999999998	55.825127999999999	55.818392000000003	Батыршина	0103000020E610000001000000050000007C992842EA8648406EA7AD11C1E84B407C992842EA864840C78157CB9DE94B4049F3C7B436894840C78157CB9DE94B4049F3C7B4368948406EA7AD11C1E84B407C992842EA8648406EA7AD11C1E84B40
77738	134	49.111623999999999	49.120840999999999	55.77552	55.773696999999999	Ахтямова	0103000020E610000001000000050000006FB9FAB1498E4840B401D88008E34B406FB9FAB1498E48406CB2463D44E34B400A82C7B7778F48406CB2463D44E34B400A82C7B7778F4840B401D88008E34B406FB9FAB1498E4840B401D88008E34B40
77782	134	49.149343999999999	49.154654000000001	55.783791999999998	55.782451000000002	Амирхана Еники	0103000020E610000001000000050000004AED45B41D9348407BDCB75A27E44B404AED45B41D934840E76ED74B53E44B400919C8B3CB934840E76ED74B53E44B400919C8B3CB9348407BDCB75A27E44B404AED45B41D9348407BDCB75A27E44B40
77798	134	48.892856999999999	48.89893	55.845269000000002	55.844515999999999	Алтынова	0103000020E6100000010000000500000099805F23497248407079AC1919EC4B4099805F23497248404CA94BC631EC4B4057B26323107348404CA94BC631EC4B4057B26323107348407079AC1919EC4B4099805F23497248407079AC1919EC4B40
77925	134	49.178279000000003	49.190280999999999	55.810622000000002	55.808987999999999	Александра Попова	0103000020E610000001000000050000002448A5D8D1964840A06D35EB8CE74B402448A5D8D196484085B53176C2E74B406C06B8205B98484085B53176C2E74B406C06B8205B984840A06D35EB8CE74B402448A5D8D1964840A06D35EB8CE74B40
78013	134	49.219171000000003	49.231783	55.782460999999998	55.776192999999999	Академика Сахарова	0103000020E61000000100000005000000A69D9ACB0D9C48402B31CF4A5AE34B40A69D9ACB0D9C48409EB29AAE27E44B406762BA10AB9D48409EB29AAE27E44B406762BA10AB9D48402B31CF4A5AE34B40A69D9ACB0D9C48402B31CF4A5AE34B40
77809	134	49.133076000000003	49.152659	55.836029000000003	55.826523999999999	Академика Лаврентьева	0103000020E61000000100000005000000F6F065A208914840F7ADD689CBE94B40F6F065A208914840F9C08EFF02EB4B40543882548A934840F9C08EFF02EB4B40543882548A934840F7ADD689CBE94B40F6F065A208914840F7ADD689CBE94B40
77949	134	49.186759000000002	49.203899	55.811036999999999	55.803083999999998	Академика Губкина	0103000020E61000000100000005000000E99D0AB8E79748406EF8DD74CBE64B40E99D0AB8E7974840486C770FD0E74B40F357C85C199A4840486C770FD0E74B40F357C85C199A48406EF8DD74CBE64B40E99D0AB8E79748406EF8DD74CBE64B40
77651	134	49.041924000000002	49.093406000000002	55.870556000000001	55.867203000000003	Айдарова	0103000020E61000000100000005000000717500C45D8548401EFF058200EF4B40717500C45D85484015AB06616EEF4B4006A051BAF48B484015AB06616EEF4B4006A051BAF48B48401EFF058200EF4B40717500C45D8548401EFF058200EF4B40
77596	134	49.233156999999999	49.253504	55.876899999999999	55.867227999999997	Азина	0103000020E61000000100000005000000AFEAAC16D89D48407616BD5301EF4B40AFEAAC16D89D484063EE5A423EF04B40DDB3AED172A0484063EE5A423EF04B40DDB3AED172A048407616BD5301EF4B40AFEAAC16D89D48407616BD5301EF4B40
77803	134	49.147179999999999	49.147430999999997	55.846426000000001	55.823636	Адоратского	0103000020E61000000100000005000000095053CBD692484075E789E76CE94B40095053CBD6924840F73DEAAF57EC4B4052B5DD04DF924840F73DEAAF57EC4B4052B5DD04DF92484075E789E76CE94B40095053CBD692484075E789E76CE94B40
77985	134	49.160879000000001	49.199128999999999	55.789501999999999	55.762905000000003	Аделя Кутуя	0103000020E610000001000000050000007DCEDDAE979448403A7AFCDEA6E14B407DCEDDAE979448403410CB660EE54B40B4571F0F7D9948403410CB660EE54B40B4571F0F7D9948403A7AFCDEA6E14B407DCEDDAE979448403A7AFCDEA6E14B40
75127	134	48.827953999999998	49.329726000000001	55.939070999999998	55.668802999999997	Абдуллы Бичурина	0103000020E61000000100000005000000D34B8C65FA694840BC3B32569BD54B40D34B8C65FA6948409ECF807A33F84B400952297634AA48409ECF807A33F84B400952297634AA4840BC3B32569BD54B40D34B8C65FA694840BC3B32569BD54B40
77901	134	49.081567	49.089948	55.822974000000002	55.815949000000003	2-я Юго-Западная	0103000020E6100000010000000500000067B796C9708A48401A1A4F0471E84B4067B796C9708A4840AABA473657E94B40992B836A838B4840AABA473657E94B40992B836A838B48401A1A4F0471E84B4067B796C9708A48401A1A4F0471E84B40
77968	134	49.200333000000001	49.205120999999998	55.809615999999998	55.805619	2-я Азинская	0103000020E61000000100000005000000A0A70183A4994840A304FD851EE74B40A0A70183A4994840BF28417FA1E74B40855CA967419A4840BF28417FA1E74B40855CA967419A4840A304FD851EE74B40A0A70183A4994840A304FD851EE74B40
78008	134	49.199686	49.231783	55.776192999999999	55.742472999999997	 Юлиуса Фучика	0103000020E610000001000000050000000ABC934F8F994840DD94F25A09DF4B400ABC934F8F9948402B31CF4A5AE34B406762BA10AB9D48402B31CF4A5AE34B406762BA10AB9D4840DD94F25A09DF4B400ABC934F8F994840DD94F25A09DF4B40
77919	134	49.07526	49.090972000000001	55.808416999999999	55.807896	 Шоссейная	0103000020E610000001000000050000003659A31EA2894840DC48D92269E74B403659A31EA2894840E54350357AE74B40056D72F8A48B4840E54350357AE74B40056D72F8A48B4840DC48D92269E74B403659A31EA2894840DC48D92269E74B40
77852	134	49.057698000000002	49.062828000000003	55.822549000000002	55.818316000000003	 Чкалова	0103000020E61000000100000005000000B685E7A56287484093E52494BEE84B40B685E7A562874840C32D1F4949E94B40F5A276BF0A884840C32D1F4949E94B40F5A276BF0A88484093E52494BEE84B40B685E7A56287484093E52494BEE84B40
77832	134	49.109962000000003	49.147323	55.823636	55.823611	 Четаева	0103000020E61000000100000005000000C1E61C3C138E48401CD0D2156CE94B40C1E61C3C138E484075E789E76CE94B406C79E57ADB92484075E789E76CE94B406C79E57ADB9248401CD0D2156CE94B40C1E61C3C138E48401CD0D2156CE94B40
77749	134	49.014885	49.016357999999997	55.87744	55.860346999999997	 Химиков	0103000020E61000000100000005000000B9196EC0E7814840191BBAD91FEE4B40B9196EC0E7814840E31934F44FF04B409483D90418824840E31934F44FF04B409483D90418824840191BBAD91FEE4B40B9196EC0E7814840191BBAD91FEE4B40
77842	134	49.105372000000003	49.125242999999998	55.755524999999999	55.755038999999996	 Учительская	0103000020E6100000010000000500000002F566D47C8D48402E1A321EA5E04B4002F566D47C8D4840BB270F0BB5E04B40C6866EF607904840BB270F0BB5E04B40C6866EF6079048402E1A321EA5E04B4002F566D47C8D48402E1A321EA5E04B40
77980	134	49.181108999999999	49.225090000000002	55.766081	55.740541999999998	 Рихарда Зорге	0103000020E61000000100000005000000710168942E9748403FA88B14CADE4B40710168942E974840228B34F10EE24B400D54C6BFCF9C4840228B34F10EE24B400D54C6BFCF9C48403FA88B14CADE4B40710168942E9748403FA88B14CADE4B40
77660	134	49.057186000000002	49.095517000000001	55.863464	55.857407000000002	 Побежимова	0103000020E6100000010000000500000000E5EFDE51874840452E3883BFED4B4000E5EFDE51874840FDA204FD85EE4B40249BABE6398C4840FDA204FD85EE4B40249BABE6398C4840452E3883BFED4B4000E5EFDE51874840452E3883BFED4B40
77910	134	49.148122999999998	49.185017000000002	55.802329999999998	55.79222	 Николая Ершова	0103000020E610000001000000050000008864C8B1F59248405A9E077767E54B408864C8B1F5924840C24CDBBFB2E64B401E1A16A3AE974840C24CDBBFB2E64B401E1A16A3AE9748405A9E077767E54B408864C8B1F59248405A9E077767E54B40
77628	134	48.947007999999997	48.949370999999999	55.805613999999998	55.804633000000003	 Минусинская	0103000020E610000001000000050000007286E28E377948402524D236FEE64B407286E28E3779484091990B5C1EE74B40AA622AFD8479484091990B5C1EE74B40AA622AFD847948402524D236FEE64B407286E28E377948402524D236FEE64B40
77863	134	49.064686999999999	49.065074000000003	55.814528000000003	55.81297	 Лукницкого	0103000020E61000000100000005000000F9BCE2A9478848408750A5660FE84B40F9BCE2A94788484091D6187442E84B40F3E846585488484091D6187442E84B40F3E84658548848408750A5660FE84B40F9BCE2A9478848408750A5660FE84B40
77931	134	49.186436	49.195239000000001	55.802016999999999	55.796019999999999	 Космонавтов	0103000020E6100000010000000500000006668522DD974840207BBDFBE3E54B4006668522DD97484003EB387EA8E64B40AEF36F97FD98484003EB387EA8E64B40AEF36F97FD984840207BBDFBE3E54B4006668522DD974840207BBDFBE3E54B40
77698	134	49.098714999999999	49.101581000000003	55.843367999999998	55.820464999999999	 Короленко	0103000020E61000000100000005000000F44F70B1A28C48409E4143FF04E94B40F44F70B1A28C4840183F8D7BF3EB4B408F72309B008D4840183F8D7BF3EB4B408F72309B008D48409E4143FF04E94B40F44F70B1A28C48409E4143FF04E94B40
77897	134	49.224893000000002	49.241242	55.758234999999999	55.740541999999998	 Комиссара Габишева	0103000020E61000000100000005000000B70C384BC99C48403FA88B14CADE4B40B70C384BC99C48405ED72FD80DE14B40F8359204E19E48405ED72FD80DE14B40F8359204E19E48403FA88B14CADE4B40B70C384BC99C48403FA88B14CADE4B40
77869	134	49.177667999999997	49.179608999999999	55.767569999999999	55.750677000000003	 Карбышева	0103000020E61000000100000005000000DAC534D3BD964840016E162F16E04B40DAC534D3BD96484003B2D7BB3FE24B409C887E6DFD96484003B2D7BB3FE24B409C887E6DFD964840016E162F16E04B40DAC534D3BD964840016E162F16E04B40
77904	134	49.081080999999998	49.081682999999998	55.818573999999998	55.816141000000002	 Дежнева	0103000020E61000000100000005000000DAA9B9DC608A48405EF6EB4E77E84B40DAA9B9DC608A48408EAD6708C7E84B40D0D1AA96748A48408EAD6708C7E84B40D0D1AA96748A48405EF6EB4E77E84B40DAA9B9DC608A48405EF6EB4E77E84B40
77709	134	49.019331000000001	49.022637000000003	55.877496000000001	55.858271000000002	 Гудованцева	0103000020E6100000010000000500000045662E7079824840780DFAD2DBED4B4045662E7079824840772FF7C951F04B40FC56EBC4E5824840772FF7C951F04B40FC56EBC4E5824840780DFAD2DBED4B4045662E7079824840780DFAD2DBED4B40
77878	134	49.179456000000002	49.218111	55.757136000000003	55.754978000000001	 Братьев Касимовых	0103000020E610000001000000050000001689096AF896484089997D1EA3E04B401689096AF8964840E84F1BD5E9E04B40EDF2AD0FEB9B4840E84F1BD5E9E04B40EDF2AD0FEB9B484089997D1EA3E04B401689096AF896484089997D1EA3E04B40
77849	134	49.135007000000002	49.140191000000002	55.770572999999999	55.764536	 Ботаническая	0103000020E6100000010000000500000094DDCCE847914840AD4ECE50DCE14B4094DDCCE8479148401E17D522A2E24B40C61858C7F19148401E17D522A2E24B40C61858C7F1914840AD4ECE50DCE14B4094DDCCE847914840AD4ECE50DCE14B40
77973	134	49.160879000000001	49.199128999999999	55.789501999999999	55.762905000000003	 Аделя Кутуя	0103000020E610000001000000050000007DCEDDAE979448403A7AFCDEA6E14B407DCEDDAE979448403410CB660EE54B40B4571F0F7D9948403410CB660EE54B40B4571F0F7D9948403A7AFCDEA6E14B407DCEDDAE979448403A7AFCDEA6E14B40
77589	134	49.201537000000002	49.203620999999998	55.842255999999999	55.832873999999997	 Агрызская	0103000020E610000001000000050000008CF7E3F6CB99484027D87F9D9BEA4B408CF7E3F6CB9948400D6E6B0BCFEB4B40B0E3BF40109A48400D6E6B0BCFEB4B40B0E3BF40109A484027D87F9D9BEA4B408CF7E3F6CB99484027D87F9D9BEA4B40
78581	134	49.186014	49.194026999999998	55.855759999999997	55.849848000000001	 4-я Станционная	0103000020E61000000100000005000000904C874ECF9748401749BBD1C7EC4B40904C874ECF974840CB9C2E8B89ED4B403FC571E0D5984840CB9C2E8B89ED4B403FC571E0D59848401749BBD1C7EC4B40904C874ECF9748401749BBD1C7EC4B40
10193	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Юности	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10231	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Чапаева	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10128	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Чайковского	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10136	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Хазиева	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10325	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Украинская	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10130	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Тургенева	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10161	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Столичная	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10255	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Сайдашева	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10111	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Рогачева	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
12139	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Маршала Жукова	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
9942	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Ленина	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10175	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Космонавтов	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10244	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Королева	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10247	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Комарова	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10104	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Кирпичная	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
11330	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Каюма Насыри	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
11473	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Карла Маркса	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10266	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Жукова	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10141	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Дальняя	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10133	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Гоголя	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10190	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Гастелло	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10227	6600	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Гаринская	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
67377	3350	51.967629000000002	52.097614999999998	55.331950999999997	55.266455999999998	просп. Победы	0103000020E61000000100000005000000A2D45E44DBFB494057E9EE3A1BA24B40A2D45E44DBFB4940EF6FD05E7DAA4B40AD4CF8A57E0C4A40EF6FD05E7DAA4B40AD4CF8A57E0C4A4057E9EE3A1BA24B40A2D45E44DBFB494057E9EE3A1BA24B40
67250	141	51.993518000000002	52.110802999999997	55.772325000000002	55.737431000000001	просп. Мира	0103000020E6100000010000000500000061FE0A992BFF49403E07962364DE4B4061FE0A992BFF49400D71AC8BDBE24B403BA6EECA2E0E4A400D71AC8BDBE24B403BA6EECA2E0E4A403E07962364DE4B4061FE0A992BFF49403E07962364DE4B40
9578	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	пр.Нефтяников	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9594	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	пр.Нефтяников	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
12166	141	51.993518000000002	52.110802999999997	55.772325000000002	55.737431000000001	пр. Мира	0103000020E6100000010000000500000061FE0A992BFF49403E07962364DE4B4061FE0A992BFF49400D71AC8BDBE24B403BA6EECA2E0E4A400D71AC8BDBE24B403BA6EECA2E0E4A403E07962364DE4B4061FE0A992BFF49403E07962364DE4B40
11943	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	пр. Мира	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9593	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Тугарова	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
8271	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Тугарова	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
10073	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Строителей	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9572	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Разведчиков	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9577	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Пролетарская	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9640	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Набережная	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9579	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Молодежная	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9647	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Марджани	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
8273	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Казанская	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
8244	141	51.993518000000002	52.110802999999997	55.772325000000002	55.737431000000001	Горького	0103000020E6100000010000000500000061FE0A992BFF49403E07962364DE4B4061FE0A992BFF49400D71AC8BDBE24B403BA6EECA2E0E4A400D71AC8BDBE24B403BA6EECA2E0E4A403E07962364DE4B4061FE0A992BFF49403E07962364DE4B40
9627	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Говорова	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
9575	141	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Азина	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
75342	31939	49.287441999999999	49.335493	55.924567000000003	55.891905000000001	Полковая	0103000020E6100000010000000500000098BF42E6CAA44840C7116BF129F24B4098BF42E6CAA44840FDFA213658F64B40BA84436FF1AA4840FDFA213658F64B40BA84436FF1AA4840C7116BF129F24B4098BF42E6CAA44840C7116BF129F24B40
75341	31939	49.287441999999999	49.335493	55.924567000000003	55.891905000000001	Большая Красная	0103000020E6100000010000000500000098BF42E6CAA44840C7116BF129F24B4098BF42E6CAA44840FDFA213658F64B40BA84436FF1AA4840FDFA213658F64B40BA84436FF1AA4840C7116BF129F24B4098BF42E6CAA44840C7116BF129F24B40
78425	28941	48.954922000000003	48.995534999999997	55.784171999999998	55.751806999999999	Чехова	0103000020E610000001000000050000008F1D54E23A7A4840B2F336363BE04B408F1D54E23A7A48402E3883BF5FE44B40FD82DDB06D7F48402E3883BF5FE44B40FD82DDB06D7F4840B2F336363BE04B408F1D54E23A7A4840B2F336363BE04B40
69254	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Строительная	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
75332	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Советская	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
69205	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Розы Люксембург	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
75337	25001	48.249529000000003	48.320909	54.995415999999999	54.951352999999997	Р.Люксембург	0103000020E61000000100000005000000A933F790F01F4840CAF962EFC5794B40A933F790F01F484023F59ECA697F4B40FCFECD8B1329484023F59ECA697F4B40FCFECD8B13294840CAF962EFC5794B40A933F790F01F4840CAF962EFC5794B40
75334	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Космовского	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
75338	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Комсомольская	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
71721	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Карла Маркса	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
75333	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Железнодорожная	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
75336	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Ефремова	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
71698	25001	48.249133999999998	48.319454	54.995621999999997	54.952976999999997	Гаяза Исхаки	0103000020E610000001000000050000002C29779FE31F48408B6B7C26FB794B402C29779FE31F4840CC96AC8A707F4B40C74961DEE3284840CC96AC8A707F4B40C74961DEE32848408B6B7C26FB794B402C29779FE31F48408B6B7C26FB794B40
68985	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Ярослава Гашека	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
71641	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Чайковского	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
75326	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Тухачевского	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
78307	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Тупиковая	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
69098	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Оршанской Дивизии	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
75330	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Орджоникидзе	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
75319	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Матросова	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
69132	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Локомотивная	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
67691	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Ленина	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
79277	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Красноармейская 	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
68895	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Красноармейская	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
68936	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Комсомольская	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
71601	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Калинина	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
75318	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Казанская	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
75321	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Джалиля	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
69062	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Гоголя	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
9862	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Гафиатуллина	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
69040	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	Вахитова	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
75322	22026	52.735087	52.866250000000001	54.563431000000001	54.499809999999997	14 Павших	0103000020E610000001000000050000007D5BB054175E4A405C1B2AC6F93F4B407D5BB054175E4A40BB46CB811E484B407B14AE47E16E4A40BB46CB811E484B407B14AE47E16E4A405C1B2AC6F93F4B407D5BB054175E4A405C1B2AC6F93F4B40
71360	59436	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	площадь Победы	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
71460	59436	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Чапаева	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
71442	59436	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Салиха Сайдашева	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
71398	59436	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Куйбышева	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
71334	59436	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Горюнова	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
71455	59436	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Вахитова	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
75313	60571	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Татарстан	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
75311	60571	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Пионерская	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
75314	60571	53.217500000000001	53.322907999999998	54.415534000000001	54.378759000000002	Ленина	0103000020E61000000100000005000000A4703D0AD79B4A406808C72C7B304B40A4703D0AD79B4A402330D63730354B40F2CEA10C55A94A402330D63730354B40F2CEA10C55A94A406808C72C7B304B40A4703D0AD79B4A406808C72C7B304B40
71121	59161	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Советская площадь	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
79315	59161	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Молодежная	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
71253	59161	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Луговая	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
68629	59161	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Вагизовых	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
68690	59161	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Большая	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
70568	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	проспект Строителей	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
68303	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	просп. Тукая	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
77510	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	пр. Строителей	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
67754	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Шевченко	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
68404	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Чернышевского	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
78067	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Чапаева	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75278	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Фахретдина	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
68341	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Тимирязева	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
70053	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Тельмана	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75275	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Тагирова	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75281	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Сулеймановой	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75252	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Строителей	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
70027	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Советская	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
68261	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Полевая	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
70260	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Нефтяников	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
67882	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Мусы Джалиля	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
69660	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Мира	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75284	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Маяковского	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
67662	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Лермонтова	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
68372	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Ленина	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75268	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Кошевого	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
67935	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Клары Цеткин	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
69983	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Интернациональная	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75248	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Джалиля	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75291	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Грузинская	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
70117	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Герцена	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
70894	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Гафиатуллина	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
75269	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Волгоградская	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
67567	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Белоглазова	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
68017	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	Аминова	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
70075	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	8-го Марта	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
70984	4205	52.246465999999998	52.387861000000001	54.921432000000003	54.861123999999997	70 лет Октября	0103000020E61000000100000005000000B8C9A8328C1F4A407DE6AC4F396E4B40B8C9A8328C1F4A4073BED87BF1754B406A32E36DA5314A4073BED87BF1754B406A32E36DA5314A407DE6AC4F396E4B40B8C9A8328C1F4A407DE6AC4F396E4B40
79267	61508	49.153010000000002	49.155254999999997	55.782532000000003	55.777088999999997	Центральная	0103000020E6100000010000000500000001FBE8D495934840698A00A777E34B4001FBE8D495934840680932022AE44B402EC55565DF934840680932022AE44B402EC55565DF934840698A00A777E34B4001FBE8D495934840698A00A777E34B40
79333	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Школьная	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
75244	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Хасаншиной	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
68108	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Хасанова	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
67709	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Султангалиева	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
75235	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Пушкина	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
69687	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Лениногорский тракт	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
67628	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Ленина	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
69864	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Гагарина	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
69618	23555	53.043146	53.110142000000003	54.875158999999996	54.846384	Булгар	0103000020E61000000100000005000000037AE1CE85854A40C8ED974F566C4B40037AE1CE85854A4068E6C93505704B4041F50F22198E4A4068E6C93505704B4041F50F22198E4A40C8ED974F566C4B40037AE1CE85854A40C8ED974F566C4B40
79362	61539	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Гоголя	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
75448	60611	49.074658999999997	49.102237000000002	55.809176000000001	55.803807999999997	Пролетарская	0103000020E6100000010000000500000010AD156D8E894840AF21382EE3E64B4010AD156D8E894840A35A441493E74B4078B81D1A168D4840A35A441493E74B4078B81D1A168D4840AF21382EE3E64B4010AD156D8E894840AF21382EE3E64B40
12189	41030	53.029356999999997	53.640867	54.815285000000003	54.479497000000002	Пушкина	0103000020E610000001000000050000004F745DF8C1834A40DBC35E28603D4B404F745DF8C1834A40AEF545425B684B40F60A0BEE07D24A40AEF545425B684B40F60A0BEE07D24A40DBC35E28603D4B404F745DF8C1834A40DBC35E28603D4B40
11691	7466	53.320554999999999	53.345329999999997	54.583801000000001	54.578879999999998	Тукая	0103000020E61000000100000005000000DEC83CF207A94A407C2766BD184A4B40DEC83CF207A94A40A12FBDFDB94A4B40F12900C633AC4A40A12FBDFDB94A4B40F12900C633AC4A407C2766BD184A4B40DEC83CF207A94A407C2766BD184A4B40
11702	7925	53.249965000000003	53.278602999999997	54.598610999999998	54.581389999999999	Загот-Зерно	0103000020E61000000100000005000000841266DAFE9F4A40581CCEFC6A4A4B40841266DAFE9F4A404F0306499F4C4B40A3C85A43A9A34A404F0306499F4C4B40A3C85A43A9A34A40581CCEFC6A4A4B40841266DAFE9F4A40581CCEFC6A4A4B40
11705	40942	53.249965000000003	53.278602999999997	54.598610999999998	54.581389999999999	Дмитрова	0103000020E61000000100000005000000841266DAFE9F4A40581CCEFC6A4A4B40841266DAFE9F4A404F0306499F4C4B40A3C85A43A9A34A404F0306499F4C4B40A3C85A43A9A34A40581CCEFC6A4A4B40841266DAFE9F4A40581CCEFC6A4A4B40
12229	32544	53.416252	53.481892000000002	54.607413999999999	54.587828999999999	улица Пушкина	0103000020E610000001000000050000008272DBBE47B54A40F8510DFB3D4B4B408272DBBE47B54A40F790F0BDBF4D4B401E1A16A3AEBD4A40F790F0BDBF4D4B401E1A16A3AEBD4A40F8510DFB3D4B4B408272DBBE47B54A40F8510DFB3D4B4B40
11440	32544	53.416252	53.481892000000002	54.607413999999999	54.587828999999999	Уруссинская	0103000020E610000001000000050000008272DBBE47B54A40F8510DFB3D4B4B408272DBBE47B54A40F790F0BDBF4D4B401E1A16A3AEBD4A40F790F0BDBF4D4B401E1A16A3AEBD4A40F8510DFB3D4B4B408272DBBE47B54A40F8510DFB3D4B4B40
11273	32544	53.416252	53.481892000000002	54.607413999999999	54.587828999999999	Пушкина	0103000020E610000001000000050000008272DBBE47B54A40F8510DFB3D4B4B408272DBBE47B54A40F790F0BDBF4D4B401E1A16A3AEBD4A40F790F0BDBF4D4B401E1A16A3AEBD4A40F8510DFB3D4B4B408272DBBE47B54A40F8510DFB3D4B4B40
11632	32544	53.416252	53.481892000000002	54.607413999999999	54.587828999999999	Поэта Сирина	0103000020E610000001000000050000008272DBBE47B54A40F8510DFB3D4B4B408272DBBE47B54A40F790F0BDBF4D4B401E1A16A3AEBD4A40F790F0BDBF4D4B401E1A16A3AEBD4A40F8510DFB3D4B4B408272DBBE47B54A40F8510DFB3D4B4B40
11680	32544	53.416252	53.481892000000002	54.607413999999999	54.587828999999999	Мияссарова	0103000020E610000001000000050000008272DBBE47B54A40F8510DFB3D4B4B408272DBBE47B54A40F790F0BDBF4D4B401E1A16A3AEBD4A40F790F0BDBF4D4B401E1A16A3AEBD4A40F8510DFB3D4B4B408272DBBE47B54A40F8510DFB3D4B4B40
11707	32544	53.416252	53.481892000000002	54.607413999999999	54.587828999999999	Луговая	0103000020E610000001000000050000008272DBBE47B54A40F8510DFB3D4B4B408272DBBE47B54A40F790F0BDBF4D4B401E1A16A3AEBD4A40F790F0BDBF4D4B401E1A16A3AEBD4A40F8510DFB3D4B4B408272DBBE47B54A40F8510DFB3D4B4B40
11710	40943	53.118639999999999	53.138357999999997	54.692661000000001	54.683839999999996	Уральская	0103000020E61000000100000005000000ACFF73982F8F4A402BD9B11188574B40ACFF73982F8F4A407A1B9B1DA9584B40EA9106B7B5914A407A1B9B1DA9584B40EA9106B7B5914A402BD9B11188574B40ACFF73982F8F4A402BD9B11188574B40
11701	7726	53.582602000000001	53.614915000000003	54.771127999999997	54.745615000000001	Советская	0103000020E61000000100000005000000C74ACCB392CA4A401A34F44F705F4B40C74ACCB392CA4A40D3838252B4624B40F168E388B5CE4A40D3838252B4624B40F168E388B5CE4A401A34F44F705F4B40C74ACCB392CA4A401A34F44F705F4B40
78517	61310	53.384298999999999	53.403531999999998	54.611866999999997	54.596958000000001	Советская	0103000020E610000001000000050000005871AAB530B14A40F48AA71E694C4B405871AAB530B14A40354069A8514E4B40DA71C3EFA6B34A40354069A8514E4B40DA71C3EFA6B34A40F48AA71E694C4B405871AAB530B14A40F48AA71E694C4B40
11228	16532	53.252443999999997	53.259874000000003	54.646036000000002	54.643160000000002	Нариманова	0103000020E610000001000000050000002409C21550A04A40350C1F1153524B402409C21550A04A40F304C24EB1524B40558A1D8D43A14A40F304C24EB1524B40558A1D8D43A14A40350C1F1153524B402409C21550A04A40350C1F1153524B40
78538	61317	53.364662000000003	53.382061999999998	54.644373999999999	54.632159999999999	Советская	0103000020E61000000100000005000000070C923EADAE4A4070EB6E9EEA504B40070C923EADAE4A404432E4D87A524B40AD855968E7B04A404432E4D87A524B40AD855968E7B04A4070EB6E9EEA504B40070C923EADAE4A4070EB6E9EEA504B40
11706	32614	53.224120999999997	53.265272000000003	54.693331999999998	54.667624000000004	Мирфатиха Закиева	0103000020E6100000010000000500000064AC36FFAF9C4A402A0307B474554B4064AC36FFAF9C4A4098A25C1ABF584B40B345D26EF4A14A4098A25C1ABF584B40B345D26EF4A14A402A0307B474554B4064AC36FFAF9C4A402A0307B474554B40
11699	7393	53.342734	53.373969000000002	54.532620000000001	54.51914	Ленина	0103000020E61000000100000005000000179D2CB5DEAB4A40D105F52D73424B40179D2CB5DEAB4A40079964E42C444B40E25B5837DEAF4A40079964E42C444B40E25B5837DEAF4A40D105F52D73424B40179D2CB5DEAB4A40D105F52D73424B40
11693	7545	53.343093000000003	53.407862000000002	54.720630999999997	54.700684000000003	Октября	0103000020E61000000100000005000000473EAF78EAAB4A404D6A6803B0594B40473EAF78EAAB4A40ECBDF8A23D5C4B40FDA36FD234B44A40ECBDF8A23D5C4B40FDA36FD234B44A404D6A6803B0594B40473EAF78EAAB4A404D6A6803B0594B40
79268	7545	53.343093000000003	53.407862000000002	54.720630999999997	54.700684000000003	Новая	0103000020E61000000100000005000000473EAF78EAAB4A404D6A6803B0594B40473EAF78EAAB4A40ECBDF8A23D5C4B40FDA36FD234B44A40ECBDF8A23D5C4B40FDA36FD234B44A404D6A6803B0594B40473EAF78EAAB4A404D6A6803B0594B40
11700	7817	53.474733000000001	53.491199000000002	54.610109999999999	54.599336000000001	Тукая	0103000020E610000001000000050000007EAA0A0DC4BC4A4061A8C30AB74C4B407EAA0A0DC4BC4A40357BA015184E4B40F969DC9BDFBE4A40357BA015184E4B40F969DC9BDFBE4A4061A8C30AB74C4B407EAA0A0DC4BC4A4061A8C30AB74C4B40
79252	61494	53.133839999999999	53.145311	54.647931999999997	54.642539999999997	Зеленая	0103000020E61000000100000005000000C5724BAB21914A40982F2FC03E524B40C5724BAB21914A4014048F6FEF524B40E15F048D99924A4014048F6FEF524B40E15F048D99924A40982F2FC03E524B40C5724BAB21914A40982F2FC03E524B40
11689	40935	53.338476	53.345896000000003	54.509616999999999	54.505304000000002	Центральная	0103000020E610000001000000050000008E3D7B2E53AB4A40DD442DCDAD404B408E3D7B2E53AB4A40293E3E213B414B409BE8F35146AC4A40293E3E213B414B409BE8F35146AC4A40DD442DCDAD404B408E3D7B2E53AB4A40DD442DCDAD404B40
11683	32567	53.414122999999996	53.427723999999998	54.574522999999999	54.558351999999999	Советская	0103000020E61000000100000005000000BDC282FB01B54A40FED30D1478474B40BDC282FB01B54A4060E63BF889494B406EDBF7A8BFB64A4060E63BF889494B406EDBF7A8BFB64A40FED30D1478474B40BDC282FB01B54A40FED30D1478474B40
11634	5360	50.689138	50.723067	55.378369999999997	55.362214000000002	Полевая	0103000020E6100000010000000500000026378AAC35584940A11342075DAE4B4026378AAC35584940CDE49B6D6EB04B408EE89E758D5C4940CDE49B6D6EB04B408EE89E758D5C4940A11342075DAE4B4026378AAC35584940A11342075DAE4B40
11677	7153	50.577441	50.610247999999999	55.355331	55.343173999999998	Победы	0103000020E610000001000000050000004D2F3196E9494940336B2920EDAB4B404D2F3196E9494940A320787C7BAD4B408639419B1C4E4940A320787C7BAD4B408639419B1C4E4940336B2920EDAB4B404D2F3196E9494940336B2920EDAB4B40
11666	6596	50.638634000000003	50.657471999999999	55.151069999999997	55.139204999999997	Театральная	0103000020E610000001000000050000008D0E48C2BE51494047382D78D1914B408D0E48C2BE5149400FB4024356934B409204E10A285449400FB4024356934B409204E10A2854494047382D78D1914B408D0E48C2BE51494047382D78D1914B40
11659	6296	50.668844999999997	50.697015999999998	55.089793999999998	55.070354999999999	Школьная	0103000020E61000000100000005000000EB8B84B69C554940170E846401894B40EB8B84B69C55494042B0AA5E7E8B4B40F564FED13759494042B0AA5E7E8B4B40F564FED137594940170E846401894B40EB8B84B69C554940170E846401894B40
11696	7273	50.643683000000003	50.682777999999999	55.345381000000003	55.323146999999999	Чапаева	0103000020E61000000100000005000000DFFE5C3464524940776682E15CA94B40DFFE5C346452494074D4D17135AC4B40D236FE446557494074D4D17135AC4B40D236FE4465574940776682E15CA94B40DFFE5C3464524940776682E15CA94B40
11635	40924	50.290295	51.245285000000003	55.489998	55.034198000000004	Дорожная	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11637	5468	50.937477000000001	50.961506999999997	55.433771999999998	55.425123999999997	Зеленая	0103000020E6100000010000000500000048E00F3FFF774940525F96766AB64B4048E00F3FFF774940D3F544D785B74B4002F04FA9127B4940D3F544D785B74B4002F04FA9127B4940525F96766AB64B4048E00F3FFF774940525F96766AB64B40
11668	6710	50.499836000000002	50.527037	55.226416	55.213479	Школьная	0103000020E6100000010000000500000086AE44A0FA3F4940FFB0A547539B4B4086AE44A0FA3F494044A51133FB9C4B401764CBF27543494044A51133FB9C4B401764CBF275434940FFB0A547539B4B4086AE44A0FA3F4940FFB0A547539B4B40
11669	6782	50.457624000000003	50.481492000000003	55.193714999999997	55.177365000000002	Сатдарова	0103000020E61000000100000005000000AFEE586C933A49403F3A75E5B3964B40AFEE586C933A494050DF32A7CB984B4090A4A487A13D494050DF32A7CB984B4090A4A487A13D49403F3A75E5B3964B40AFEE586C933A49403F3A75E5B3964B40
11652	5973	50.662799	50.702460000000002	55.237940999999999	55.217111000000003	Советская	0103000020E610000001000000050000002769FE98D65449400A4D124BCA9B4B402769FE98D654494053B0C6D9749E4B40C45F9335EA59494053B0C6D9749E4B40C45F9335EA5949400A4D124BCA9B4B402769FE98D65449400A4D124BCA9B4B40
11649	5868	50.812288000000002	50.847250000000003	55.257406000000003	55.241632000000003	Центральная	0103000020E6100000010000000500000075779D0DF967494063D520CCED9E4B4075779D0DF9674940A8E507AEF2A04B409CC420B0726C4940A8E507AEF2A04B409CC420B0726C494063D520CCED9E4B4075779D0DF967494063D520CCED9E4B40
11656	6182	50.774918	50.820354999999999	55.128140000000002	55.111984	Кооперативная	0103000020E61000000100000005000000768A5583306349406FD6E07D558E4B40768A5583306349409CA73AE466904B40170E8464016949409CA73AE466904B40170E8464016949406FD6E07D558E4B40768A5583306349406FD6E07D558E4B40
11664	6512	50.561568000000001	50.590654999999998	55.154532000000003	55.136566000000002	Центральная	0103000020E61000000100000005000000753DD175E14749406EDFA3FE7A914B40753DD175E1474940BE175FB4C7934B40041C42959A4B4940BE175FB4C7934B40041C42959A4B49406EDFA3FE7A914B40753DD175E14749406EDFA3FE7A914B40
11645	5712	50.859099000000001	50.883946000000002	55.270240999999999	55.251947000000001	Центральная	0103000020E610000001000000050000005E83BEF4F66D4940A4A99ECC3FA04B405E83BEF4F66D4940E884D04197A24B400BB77C2425714940E884D04197A24B400BB77C2425714940A4A99ECC3FA04B405E83BEF4F66D4940A4A99ECC3FA04B40
11674	6892	50.414020000000001	50.433216999999999	55.319263999999997	55.306691000000001	Овражная	0103000020E61000000100000005000000E9F17B9BFE344940207D93A641A74B40E9F17B9BFE34494023658BA4DDA84B401E8997A77337494023658BA4DDA84B401E8997A773374940207D93A641A74B40E9F17B9BFE344940207D93A641A74B40
11662	6397	50.565367999999999	50.590421999999997	55.071885999999999	55.057702999999997	Комсомольская	0103000020E610000001000000050000003B1A87FA5D484940C7F0D8CF62874B403B1A87FA5D4849402785798F33894B40616BB6F2924B49402785798F33894B40616BB6F2924B4940C7F0D8CF62874B403B1A87FA5D484940C7F0D8CF62874B40
11670	6818	50.562286999999998	50.583360999999996	55.262141999999997	55.249206999999998	Центральная	0103000020E61000000100000005000000A4FB3905F94749409677D503E69F4B40A4FB3905F94749403A747ADE8DA14B408461C092AB4A49403A747ADE8DA14B408461C092AB4A49409677D503E69F4B40A4FB3905F94749409677D503E69F4B40
11665	6608	50.590789999999998	50.617415999999999	55.207197000000001	55.191690000000001	Пионерская	0103000020E61000000100000005000000E466B8019F4B4940317C444C89984B40E466B8019F4B4940276A696E859A4B407903CC7C074F4940276A696E859A4B407903CC7C074F4940317C444C89984B40E466B8019F4B4940317C444C89984B40
11643	5635	50.924981000000002	50.958317999999998	55.353482999999997	55.334465000000002	Центральная	0103000020E61000000100000005000000F03504C7657649400D54C6BFCFAA4B40F03504C765764940925852EE3EAD4B4085950A2AAA7A4940925852EE3EAD4B4085950A2AAA7A49400D54C6BFCFAA4B40F03504C7657649400D54C6BFCFAA4B40
11671	6866	50.369391	50.402242999999999	55.246122999999997	55.225461000000003	Клубная	0103000020E61000000100000005000000E7374C34482F494001C3F2E7DB9C4B40E7374C34482F49408EE55DF5809F4B40C005D9B27C3349408EE55DF5809F4B40C005D9B27C33494001C3F2E7DB9C4B40E7374C34482F494001C3F2E7DB9C4B40
11688	6993	50.379362999999998	50.404021	55.395333000000001	55.381484999999998	Центральная	0103000020E61000000100000005000000FE277FF78E30494010751F80D4B04B40FE277FF78E304940C90391459AB24B40D8F2CAF5B6334940C90391459AB24B40D8F2CAF5B633494010751F80D4B04B40FE277FF78E30494010751F80D4B04B40
11642	5549	51.212522999999997	51.227012999999999	55.392392999999998	55.381065999999997	Пришкольная	0103000020E61000000100000005000000EB5223F4339B49400BCF4BC5C6B04B40EB5223F4339B4940F4160FEF39B24B40286211C30E9D4940F4160FEF39B24B40286211C30E9D49400BCF4BC5C6B04B40EB5223F4339B49400BCF4BC5C6B04B40
11655	6056	50.685895000000002	50.712063000000001	55.269722999999999	55.249806999999997	Гиниятуллина	0103000020E61000000100000005000000B6BE4868CB574940EBA7FFACF99F4B40B6BE4868CB57494050FD834886A24B4088D860E1245B494050FD834886A24B4088D860E1245B4940EBA7FFACF99F4B40B6BE4868CB574940EBA7FFACF99F4B40
11653	6084	50.649386999999997	50.668889999999998	55.252172999999999	55.241579999999999	Зеленая	0103000020E6100000010000000500000049B9FB1C1F53494010AFEB17EC9E4B4049B9FB1C1F53494094F7713447A04B408B4F01309E55494094F7713447A04B408B4F01309E55494010AFEB17EC9E4B4049B9FB1C1F53494010AFEB17EC9E4B40
11648	5846	50.883020999999999	50.928629000000001	55.228115000000003	55.205697000000001	Чапаева	0103000020E61000000100000005000000325706D50671494052F17F47549A4B40325706D506714940105D50DF329D4B40008FA850DD764940105D50DF329D4B40008FA850DD76494052F17F47549A4B40325706D50671494052F17F47549A4B40
11660	6382	50.731313999999998	50.749530999999998	55.068798000000001	55.056037000000003	Красноармейская	0103000020E61000000100000005000000B08D78B29B5D4940D82E6D382C874B40B08D78B29B5D4940DE03745FCE884B40492BBEA1F05F4940DE03745FCE884B40492BBEA1F05F4940D82E6D382C874B40B08D78B29B5D4940D82E6D382C874B40
11647	5791	50.957706999999999	50.988644999999998	55.297691999999998	55.282989999999998	8 Марта	0103000020E610000001000000050000003C139A24967A49402A8C2D0439A44B403C139A24967A4940F2237EC51AA64B404D2D5BEB8B7E4940F2237EC51AA64B404D2D5BEB8B7E49402A8C2D0439A44B403C139A24967A49402A8C2D0439A44B40
11654	6177	50.773364000000001	50.805703000000001	55.175026000000003	55.165750000000003	Школьная	0103000020E61000000100000005000000AEF36F97FD624940F0A7C64B37954B40AEF36F97FD62494090F9804067964B4001A5A1462167494090F9804067964B4001A5A14621674940F0A7C64B37954B40AEF36F97FD624940F0A7C64B37954B40
11675	7054	50.541831999999999	50.565807999999997	55.37171	55.359890999999998	Центральная	0103000020E6100000010000000500000090F63FC05A454940F78F85E810AE4B4090F63FC05A4549404FCC7A3194AF4B4057E883656C4849404FCC7A3194AF4B4057E883656C484940F78F85E810AE4B4090F63FC05A454940F78F85E810AE4B40
11663	6478	50.578941	50.593044999999996	55.092010000000002	55.081947	Ивана Чалмаева	0103000020E6100000010000000500000022A81ABD1A4A4940AE80423D7D8A4B4022A81ABD1A4A4940D673D2FBC68B4B40350708E6E84B4940D673D2FBC68B4B40350708E6E84B4940AE80423D7D8A4B4022A81ABD1A4A4940AE80423D7D8A4B40
11636	5394	50.848553000000003	50.876984	55.427933000000003	55.408920000000002	Центральная	0103000020E610000001000000050000001BF67B629D6C49401557957D57B44B401BF67B629D6C494089F02F82C6B64B40C18EFF024170494089F02F82C6B64B40C18EFF02417049401557957D57B44B401BF67B629D6C49401557957D57B44B40
11640	5519	51.066772	51.095742000000001	55.358606000000002	55.344023999999997	Набережная	0103000020E61000000100000005000000EE2422FC8B88494001857AFA08AC4B40EE2422FC8B8849401F1329CDE6AD4B40446D1B46418C49401F1329CDE6AD4B40446D1B46418C494001857AFA08AC4B40EE2422FC8B88494001857AFA08AC4B40
11676	7102	50.489612999999999	50.511963000000002	55.297373999999998	55.283543000000002	Центральная	0103000020E61000000100000005000000255987A3AB3E49403F0114234BA44B40255987A3AB3E49402157EA5910A64B408BE1EA00884149402157EA5910A64B408BE1EA00884149403F0114234BA44B40255987A3AB3E49403F0114234BA44B40
11667	6684	50.553708	50.574745999999998	55.197476000000002	55.184541000000003	Широкая	0103000020E610000001000000050000004CC45BE7DF464940B5E21B0A9F974B404CC45BE7DF46494059DFC0E446994B40DFC0E4469149494059DFC0E446994B40DFC0E44691494940B5E21B0A9F974B404CC45BE7DF464940B5E21B0A9F974B40
11673	6964	50.358809000000001	50.375365000000002	55.363089000000002	55.353001999999996	Речная	0103000020E6100000010000000500000057410C74ED2D494017B6662B2FAD4B4057410C74ED2D4940C8444AB379AE4B401288D7F50B304940C8444AB379AE4B401288D7F50B30494017B6662B2FAD4B4057410C74ED2D494017B6662B2FAD4B40
11644	5702	50.772914999999998	50.797088000000002	55.351599999999998	55.337116999999999	Школьная	0103000020E610000001000000050000003ECBF3E0EE6249407BF65CA626AB4B403ECBF3E0EE62494005A3923A01AD4B405C04C6FA0666494005A3923A01AD4B405C04C6FA066649407BF65CA626AB4B403ECBF3E0EE6249407BF65CA626AB4B40
11657	6265	50.606951000000002	50.624772999999998	55.124856000000001	55.113714999999999	Октябрьская	0103000020E6100000010000000500000023A30392B04D494046088F368E8E4B4023A30392B04D4940CD5A0A48FB8F4B403F36C98FF84F4940CD5A0A48FB8F4B403F36C98FF84F494046088F368E8E4B4023A30392B04D494046088F368E8E4B40
11623	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Энгельса	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11608	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Чернышевского	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11602	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Урицкого	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11613	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Тукая	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11606	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Студенческая	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11591	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Мира	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11601	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Льва Толстого	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11615	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Крупской	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11598	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Карла Маркса	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11622	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Гуськова	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11594	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Бутлерова	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11597	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Бебеля	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11625	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Академика Королева	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
11617	40920	50.290295	51.245285000000003	55.489998	55.034198000000004	Айвазовского	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
79271	61511	51.728614	51.784615000000002	54.746701000000002	54.733848000000002	Комарова	0103000020E6100000010000000500000031B43A3943DD4940151E34BBEE5D4B4031B43A3943DD4940FC71FBE5935F4B40BC79AA436EE44940FC71FBE5935F4B40BC79AA436EE44940151E34BBEE5D4B4031B43A3943DD4940151E34BBEE5D4B40
11587	3555	51.720556000000002	51.740167	54.804555000000001	54.792945000000003	Ленина	0103000020E61000000100000005000000E277D32D3BDC49406C43C5387F654B40E277D32D3BDC4940A96A82A8FB664B400A4AD1CABDDE4940A96A82A8FB664B400A4AD1CABDDE49406C43C5387F654B40E277D32D3BDC49406C43C5387F654B40
11586	3454	51.544252999999998	51.569468999999998	54.832790000000003	54.815907000000003	Советская	0103000020E61000000100000005000000FCDF1115AAC54940EBC9FCA36F684B40FCDF1115AAC54940CA37DBDC986A4B40FC8A355CE4C84940CA37DBDC986A4B40FC8A355CE4C84940EBC9FCA36F684B40FCDF1115AAC54940EBC9FCA36F684B40
11581	3109	51.471193	51.521391000000001	54.665998999999999	54.638330000000003	Шешминская	0103000020E61000000100000005000000548D5E0D50BC4940210725CCB4514B40548D5E0D50BC494098158A743F554B40E1B6B6F0BCC2494098158A743F554B40E1B6B6F0BCC24940210725CCB4514B40548D5E0D50BC4940210725CCB4514B40
11585	3109	51.471193	51.521391000000001	54.665998999999999	54.638330000000003	Техническая	0103000020E61000000100000005000000548D5E0D50BC4940210725CCB4514B40548D5E0D50BC494098158A743F554B40E1B6B6F0BCC2494098158A743F554B40E1B6B6F0BCC24940210725CCB4514B40548D5E0D50BC4940210725CCB4514B40
11579	3109	51.471193	51.521391000000001	54.665998999999999	54.638330000000003	Советская	0103000020E61000000100000005000000548D5E0D50BC4940210725CCB4514B40548D5E0D50BC494098158A743F554B40E1B6B6F0BCC2494098158A743F554B40E1B6B6F0BCC24940210725CCB4514B40548D5E0D50BC4940210725CCB4514B40
11584	3109	51.471193	51.521391000000001	54.665998999999999	54.638330000000003	Молодежная	0103000020E61000000100000005000000548D5E0D50BC4940210725CCB4514B40548D5E0D50BC494098158A743F554B40E1B6B6F0BCC2494098158A743F554B40E1B6B6F0BCC24940210725CCB4514B40548D5E0D50BC4940210725CCB4514B40
11629	3109	51.471193	51.521391000000001	54.665998999999999	54.638330000000003	Гагарина	0103000020E61000000100000005000000548D5E0D50BC4940210725CCB4514B40548D5E0D50BC494098158A743F554B40E1B6B6F0BCC2494098158A743F554B40E1B6B6F0BCC24940210725CCB4514B40548D5E0D50BC4940210725CCB4514B40
79146	61412	51.009287999999998	51.913874	54.952697999999998	54.555365000000002	Советская	0103000020E61000000100000005000000641F645930814940E92B483316474B40641F645930814940787B1002F2794B401555BFD2F9F44940787B1002F2794B401555BFD2F9F44940E92B483316474B40641F645930814940E92B483316474B40
11577	3048	51.239347000000002	51.270356999999997	54.728701000000001	54.721333000000001	Центральная	0103000020E61000000100000005000000A7B228ECA29E49404643C6A3545C4B40A7B228ECA29E494000C80913465D4B40519FE40E9BA2494000C80913465D4B40519FE40E9BA249404643C6A3545C4B40A7B228ECA29E49404643C6A3545C4B40
11630	2990	51.530104999999999	51.558348000000002	54.795639000000001	54.784593000000001	Школьная	0103000020E6100000010000000500000019390B7BDAC34940D4D51D8B6D644B4019390B7BDAC349400936AE7FD7654B40BDE47FF277C749400936AE7FD7654B40BDE47FF277C74940D4D51D8B6D644B4019390B7BDAC34940D4D51D8B6D644B40
11576	2931	51.631523999999999	51.657539999999997	54.618118000000003	54.597458000000003	Мусы Джалиля	0103000020E61000000100000005000000CE5147C7D5D04940E65DF580794C4B40CE5147C7D5D04940D388997D1E4F4B40EAE74D452AD44940D388997D1E4F4B40EAE74D452AD44940E65DF580794C4B40CE5147C7D5D04940E65DF580794C4B40
11575	2875	51.091169999999998	51.135905999999999	54.706291999999998	54.684328999999998	Свежухина	0103000020E610000001000000050000002B306475AB8B4940295AB91798574B402B306475AB8B494095B6B8C6675A4B4043AA285E6591494095B6B8C6675A4B4043AA285E65914940295AB91798574B402B306475AB8B4940295AB91798574B40
11574	2815	51.159818999999999	51.192948999999999	54.755440999999998	54.733373999999998	Тукая	0103000020E61000000100000005000000C423F1F2749449404CDE0033DF5D4B40C423F1F2749449405D876A4AB2604B40E065868DB29849405D876A4AB2604B40E065868DB29849404CDE0033DF5D4B40C423F1F2749449404CDE0033DF5D4B40
11573	2751	51.309038000000001	51.335107000000001	54.758671999999997	54.745370999999999	Луговая	0103000020E61000000100000005000000529CA38E8EA7494083312251685F4B40529CA38E8EA749400932022A1C614B4091D442C9E4AA49400932022A1C614B4091D442C9E4AA494083312251685F4B40529CA38E8EA7494083312251685F4B40
11572	2692	51.711412000000003	51.749158999999999	54.614547000000002	54.605234000000003	Советская	0103000020E61000000100000005000000B1FD648C0FDB4940B136C64E784D4B40B1FD648C0FDB49406E6DE179A94E4B4085402E71E4DF49406E6DE179A94E4B4085402E71E4DF4940B136C64E784D4B40B1FD648C0FDB4940B136C64E784D4B40
11571	2584	51.370258	51.401330999999999	54.746679999999998	54.732148000000002	Ключевая	0103000020E610000001000000050000008B8A389D64AF494079EA9106B75D4B408B8A389D64AF4940E449D235935F4B407CEF6FD05EB34940E449D235935F4B407CEF6FD05EB3494079EA9106B75D4B408B8A389D64AF494079EA9106B75D4B40
79159	61423	51.541961999999998	51.572828000000001	54.650959	54.630946000000002	Советская	0103000020E610000001000000050000005ED6C4025FC5494061C5A9D6C2504B405ED6C4025FC54940B804E09F52534B40D61D8B6D52C94940B804E09F52534B40D61D8B6D52C9494061C5A9D6C2504B405ED6C4025FC5494061C5A9D6C2504B40
11570	2473	51.622236000000001	51.642789	54.796256999999997	54.779021	Ленина	0103000020E610000001000000050000006A32E36DA5CF4940D8F2CAF5B6634B406A32E36DA5CF4940041BD7BFEB654B40419DF2E846D24940041BD7BFEB654B40419DF2E846D24940D8F2CAF5B6634B406A32E36DA5CF4940D8F2CAF5B6634B40
11569	2427	51.454610000000002	51.480759999999997	54.866574999999997	54.849505000000001	Центральная	0103000020E61000000100000005000000A03715A930BA4940ED647094BC6C4B40A03715A930BA4940FE43FAEDEB6E4B40CB9C2E8B89BD4940FE43FAEDEB6E4B40CB9C2E8B89BD4940ED647094BC6C4B40A03715A930BA4940ED647094BC6C4B40
11568	2362	51.693562	51.715345999999997	54.699669999999998	54.682966	Цаплина	0103000020E61000000100000005000000CADFBDA3C6D84940D5230D6E6B574B40CADFBDA3C6D8494004FF5BC98E594B4086A92D7590DB494004FF5BC98E594B4086A92D7590DB4940D5230D6E6B574B40CADFBDA3C6D84940D5230D6E6B574B40
11566	2306	51.435170999999997	51.479574	54.749792999999997	54.725898999999998	Советская	0103000020E610000001000000050000007495EEAEB3B749407C992842EA5C4B407495EEAEB3B7494086E28E37F95F4B4086014BAE62BD494086E28E37F95F4B4086014BAE62BD49407C992842EA5C4B407495EEAEB3B749407C992842EA5C4B40
11567	2241	51.729647	51.748386000000004	54.673205000000003	54.656771999999997	Школьная	0103000020E61000000100000005000000F04FA91265DD4940D976DA1A11544B40F04FA91265DD49407940D9942B564B406364C91CCBDF49407940D9942B564B406364C91CCBDF4940D976DA1A11544B40F04FA91265DD4940D976DA1A11544B40
11565	2196	51.358437000000002	51.400441999999998	54.854854000000003	54.835346000000001	Клубная	0103000020E6100000010000000500000093567C43E1AD4940166C239EEC6A4B4093567C43E1AD49406A6D1ADB6B6D4B40F0F8F6AE41B349406A6D1ADB6B6D4B40F0F8F6AE41B34940166C239EEC6A4B4093567C43E1AD4940166C239EEC6A4B40
11564	2127	51.399687	51.448321999999997	54.907884000000003	54.895673000000002	Бари Габдрахманова	0103000020E6100000010000000500000074D190F128B349408274B169A5724B4074D190F128B34940E547FC8A35744B40E509849D62B94940E547FC8A35744B40E509849D62B949408274B169A5724B4074D190F128B349408274B169A5724B40
11563	2017	51.344459000000001	51.364868000000001	54.671196000000002	54.665191999999998	Школьная	0103000020E610000001000000050000000CE8853B17AC4940C9C7EE0225554B400CE8853B17AC49405F9A22C0E9554B40B0AD9FFEB3AE49405F9A22C0E9554B40B0AD9FFEB3AE4940C9C7EE0225554B400CE8853B17AC4940C9C7EE0225554B40
11562	1877	51.314993999999999	51.342393000000001	54.890106000000003	54.875619999999998	Центральная	0103000020E61000000100000005000000D63730B951A849409CDCEF5014704B40D63730B951A8494098FC4FFEEE714B408EB0A888D3AB494098FC4FFEEE714B408EB0A888D3AB49409CDCEF5014704B40D63730B951A849409CDCEF5014704B40
79129	61398	51.587057999999999	51.617142000000001	54.657682999999999	54.643134000000003	Советская	0103000020E61000000100000005000000766D6FB724CB49400C79043752524B40766D6FB724CB49404D11E0F42E544B40787E5182FECE49404D11E0F42E544B40787E5182FECE49400C79043752524B40766D6FB724CB49400C79043752524B40
11561	1766	51.571821999999997	51.591701999999998	54.755695000000003	54.739356999999998	Советская	0103000020E6100000010000000500000010919A7631C94940CA880B40A35E4B4010919A7631C9494018601F9DBA604B40287D21E4BCCB494018601F9DBA604B40287D21E4BCCB4940CA880B40A35E4B4010919A7631C94940CA880B40A35E4B40
11560	1721	51.456837999999998	51.481389	54.812857000000001	54.801716999999996	Дружбы	0103000020E61000000100000005000000F7C8E6AA79BA4940D8D2A3A99E664B40F7C8E6AA79BA49408FA9BBB20B684B40BBD39D279EBD49408FA9BBB20B684B40BBD39D279EBD4940D8D2A3A99E664B40F7C8E6AA79BA4940D8D2A3A99E664B40
11558	1679	51.613010000000003	51.645367	54.823563999999998	54.804347999999997	Ленина	0103000020E610000001000000050000007C0F971C77CE49402F4D11E0F4664B407C0F971C77CE4940DB148F8B6A694B407575C7629BD24940DB148F8B6A694B407575C7629BD249402F4D11E0F4664B407C0F971C77CE49402F4D11E0F4664B40
11559	1577	51.789861000000002	51.811357999999998	54.723387000000002	54.716523000000002	Высоцкого	0103000020E6100000010000000500000064B14D2A1AE5494079EA9106B75B4B4064B14D2A1AE5494000ADF9F1975C4B408AAC3594DAE7494000ADF9F1975C4B408AAC3594DAE7494079EA9106B75B4B4064B14D2A1AE5494079EA9106B75B4B40
11557	1568	51.482674000000003	51.499139999999997	54.753034999999997	54.740459000000001	Школьная	0103000020E610000001000000050000009450FA42C8BD4940B2834A5CC75E4B409450FA42C8BD494026DF6C7363604B400E10CCD1E3BF494026DF6C7363604B400E10CCD1E3BF4940B2834A5CC75E4B409450FA42C8BD4940B2834A5CC75E4B40
11555	1447	51.387829000000004	51.418380999999997	54.911642000000001	54.901031000000003	Школьная	0103000020E610000001000000050000005FB87361A4B1494052D7DAFB54734B405FB87361A4B149407CD45FAFB0744B40462234828DB549407CD45FAFB0744B40462234828DB5494052D7DAFB54734B405FB87361A4B1494052D7DAFB54734B40
12262	41034	49.938389000000001	50.604489000000001	56.036000000000001	55.609299	Школьная	0103000020E610000001000000050000008CF678211DF84840253E7782FDCD4B408CF678211DF84840F853E3A59B044C4058E542E55F4D4940F853E3A59B044C4058E542E55F4D4940253E7782FDCD4B408CF678211DF84840253E7782FDCD4B40
11539	219	50.237096000000001	50.267828000000002	55.827438999999998	55.810875000000003	Школьная	0103000020E6100000010000000500000097016729591E49406F1283C0CAE74B4097016729591E4940AC376A85E9E94B40FF791A3048224940AC376A85E9E94B40FF791A30482249406F1283C0CAE74B4097016729591E49406F1283C0CAE74B40
11542	419	50.185425000000002	50.218178000000002	55.732235000000003	55.709622000000003	Ленина	0103000020E610000001000000050000002F6EA301BC174940D542C9E4D4DA4B402F6EA301BC17494048FE60E0B9DD4B40755AB741ED1B494048FE60E0B9DD4B40755AB741ED1B4940D542C9E4D4DA4B402F6EA301BC174940D542C9E4D4DA4B40
79197	61452	50.284734	50.312258999999997	55.899254999999997	55.892288999999998	Верхняя	0103000020E610000001000000050000009607E929722449404FCAA48636F24B409607E92972244940DAE1AFC91AF34B40DA70581AF8274940DAE1AFC91AF34B40DA70581AF82749404FCAA48636F24B409607E929722449404FCAA48636F24B40
11536	44	50.259914000000002	50.292333999999997	55.871257999999997	55.858539	Татарстан	0103000020E61000000100000005000000E3E2A8DC4421494097AB1F9BE4ED4B40E3E2A8DC442149406E30D46185EF4B4022C154336B2549406E30D46185EF4B4022C154336B25494097AB1F9BE4ED4B40E3E2A8DC4421494097AB1F9BE4ED4B40
11537	44	50.259914000000002	50.292333999999997	55.871257999999997	55.858539	Каримовой	0103000020E61000000100000005000000E3E2A8DC4421494097AB1F9BE4ED4B40E3E2A8DC442149406E30D46185EF4B4022C154336B2549406E30D46185EF4B4022C154336B25494097AB1F9BE4ED4B40E3E2A8DC4421494097AB1F9BE4ED4B40
11526	32058	50.227241999999997	50.248685000000002	55.896701	55.882863	Школьная	0103000020E6100000010000000500000089230F44161D49409AEC9FA701F14B4089230F44161D49402FA52E19C7F24B40BD00FBE8D41F49402FA52E19C7F24B40BD00FBE8D41F49409AEC9FA701F14B4089230F44161D49409AEC9FA701F14B40
11525	32058	50.227241999999997	50.248685000000002	55.896701	55.882863	Ленина	0103000020E6100000010000000500000089230F44161D49409AEC9FA701F14B4089230F44161D49402FA52E19C7F24B40BD00FBE8D41F49402FA52E19C7F24B40BD00FBE8D41F49409AEC9FA701F14B4089230F44161D49409AEC9FA701F14B40
11550	993	50.105592000000001	50.128607000000002	55.941738000000001	55.928179	Центральная	0103000020E61000000100000005000000105CE509840D4940C0EAC891CEF64B40105CE509840D494042B3EBDE8AF84B40B284B5317610494042B3EBDE8AF84B40B284B53176104940C0EAC891CEF64B40105CE509840D4940C0EAC891CEF64B40
11532	32309	50.427854000000004	50.454479999999997	55.758710999999998	55.748032000000002	Ленина	0103000020E610000001000000050000003DBB7CEBC3364940452E3883BFDF4B403DBB7CEBC3364940C70E2A711DE14B40D15790662C3A4940C70E2A711DE14B40D15790662C3A4940452E3883BFDF4B403DBB7CEBC3364940452E3883BFDF4B40
11552	1228	50.376658999999997	50.386710999999998	55.732246000000004	55.724722999999997	Пушкина	0103000020E610000001000000050000003D5FB35C363049405AD427B9C3DC4B403D5FB35C363049403C50A73CBADD4B407100FDBE7F3149403C50A73CBADD4B407100FDBE7F3149405AD427B9C3DC4B403D5FB35C363049405AD427B9C3DC4B40
11535	32413	50.343232	50.369140000000002	55.878208000000001	55.862772	Школьная	0103000020E610000001000000050000006878B306EF2B4940C7F319506FEE4B406878B306EF2B4940F48AA71E69F04B409ED2C1FA3F2F4940F48AA71E69F04B409ED2C1FA3F2F4940C7F319506FEE4B406878B306EF2B4940C7F319506FEE4B40
11540	291	50.180323000000001	50.211620000000003	55.804783999999998	55.791091000000002	Сиразетдинова	0103000020E61000000100000005000000BADBF5D21417494079944A7842E54B40BADBF5D2141749400A2C802903E74B40FB96395D161B49400A2C802903E74B40FB96395D161B494079944A7842E54B40BADBF5D21417494079944A7842E54B40
12263	41035	50.263354	50.279496999999999	55.828673000000002	55.822750999999997	Нагуманова	0103000020E61000000100000005000000A9A27895B52149402AE09EE74FE94B40A9A27895B5214940030AF5F411EA4B40412AC58EC6234940030AF5F411EA4B40412AC58EC62349402AE09EE74FE94B40A9A27895B52149402AE09EE74FE94B40
79280	61516	50.194803999999998	50.208413	55.949964999999999	55.939176000000003	Малая 	0103000020E61000000100000005000000A3906456EF18494014984EEB36F84B40A3906456EF1849401DACFF7398F94B40D787F546AD1A49401DACFF7398F94B40D787F546AD1A494014984EEB36F84B40A3906456EF18494014984EEB36F84B40
11551	1100	50.098100000000002	50.119866000000002	56.008308999999997	55.995690000000003	Татарстан	0103000020E610000001000000050000006ADE718A8E0C4940257A19C572FF4B406ADE718A8E0C494098A1F14410014C4080F3E2C4570F494098A1F14410014C4080F3E2C4570F4940257A19C572FF4B406ADE718A8E0C4940257A19C572FF4B40
11549	783	50.005887999999999	50.023710999999999	55.937845000000003	55.928995999999998	Татарстан	0103000020E610000001000000050000002CB81FF0C0004940B20E4757E9F64B402CB81FF0C0004940CBDB114E0BF84B4019C748F608034940CBDB114E0BF84B4019C748F608034940B20E4757E9F64B402CB81FF0C0004940B20E4757E9F64B40
11543	538	50.144174999999997	50.171232000000003	55.870314	55.857881999999996	Шоссейная	0103000020E610000001000000050000004DF38E5374124940DDE9CE13CFED4B404DF38E53741249401FA0FB7266EF4B40AC0320EEEA1549401FA0FB7266EF4B40AC0320EEEA154940DDE9CE13CFED4B404DF38E5374124940DDE9CE13CFED4B40
79138	61406	50.136862000000001	50.161664999999999	55.983524000000003	55.972296999999998	Ленина	0103000020E610000001000000050000005708ABB184114940DC7F643A74FC4B405708ABB184114940626A4B1DE4FD4B4034F44F70B1144940626A4B1DE4FD4B4034F44F70B1144940DC7F643A74FC4B405708ABB184114940DC7F643A74FC4B40
11544	604	50.070971	50.097813000000002	55.893566	55.879353999999999	Фатиха Хусни	0103000020E6100000010000000500000072FBE59315094940ABCDFFAB8EF04B4072FBE59315094940A568E55E60F24B40D40FEA22850C4940A568E55E60F24B40D40FEA22850C4940ABCDFFAB8EF04B4072FBE59315094940ABCDFFAB8EF04B40
11530	32231	50.512312999999999	50.551597000000001	55.828713	55.811922000000003	Школьная	0103000020E610000001000000050000006728EE78934149409373620FEDE74B406728EE78934149409162804413EA4B402EC901BB9A4649409162804413EA4B402EC901BB9A4649409373620FEDE74B406728EE78934149409373620FEDE74B40
11533	32402	50.448506000000002	50.480395999999999	55.841462999999997	55.828172000000002	Ленина	0103000020E61000000100000005000000A70705A56839494041BB438A01EA4B40A70705A568394940A3E5400FB5EB4B408A90BA9D7D3D4940A3E5400FB5EB4B408A90BA9D7D3D494041BB438A01EA4B40A70705A56839494041BB438A01EA4B40
11529	32161	50.258944	50.27214	55.918478999999998	55.909720999999998	Ленина	0103000020E610000001000000050000006ABFB5132521494001BEDBBC71F44B406ABFB51325214940098849B890F54B407BF7C77BD5224940098849B890F54B407BF7C77BD522494001BEDBBC71F44B406ABFB5132521494001BEDBBC71F44B40
79206	61460	50.382426000000002	50.392235999999997	55.879626999999999	55.875262999999997	Октябрьская	0103000020E61000000100000005000000EF91CD55F33049400D33349E08F04B40EF91CD55F3304940DCD6169E97F04B402C280CCA34324940DCD6169E97F04B402C280CCA343249400D33349E08F04B40EF91CD55F33049400D33349E08F04B40
11531	32278	50.375087000000001	50.396628	55.769499000000003	55.758651	Ленина	0103000020E61000000100000005000000CF13CFD902304940F209D9791BE14B40CF13CFD90230494001A777F17EE24B40C556D0B4C432494001A777F17EE24B40C556D0B4C4324940F209D9791BE14B40CF13CFD902304940F209D9791BE14B40
11495	30663	52.585338	52.612313999999998	55.640421000000003	55.615822000000001	Школьная	0103000020E61000000100000005000000938D075BEC4A4A4023145B41D3CE4B40938D075BEC4A4A40F855B950F9D14B4004711E4E604E4A40F855B950F9D14B4004711E4E604E4A4023145B41D3CE4B40938D075BEC4A4A4023145B41D3CE4B40
11494	30663	52.585338	52.612313999999998	55.640421000000003	55.615822000000001	Советская	0103000020E61000000100000005000000938D075BEC4A4A4023145B41D3CE4B40938D075BEC4A4A40F855B950F9D14B4004711E4E604E4A40F855B950F9D14B4004711E4E604E4A4023145B41D3CE4B40938D075BEC4A4A4023145B41D3CE4B40
11496	30663	52.585338	52.612313999999998	55.640421000000003	55.615822000000001	Нагорная	0103000020E61000000100000005000000938D075BEC4A4A4023145B41D3CE4B40938D075BEC4A4A40F855B950F9D14B4004711E4E604E4A40F855B950F9D14B4004711E4E604E4A4023145B41D3CE4B40938D075BEC4A4A4023145B41D3CE4B40
79266	61507	52.460687	52.47869	55.445599999999999	55.434818999999997	Тукая	0103000020E610000001000000050000009F58A7CAF73A4A40F7562426A8B74B409F58A7CAF73A4A407E8CB96B09B94B400C76C3B6453D4A407E8CB96B09B94B400C76C3B6453D4A40F7562426A8B74B409F58A7CAF73A4A40F7562426A8B74B40
11522	31846	52.609341000000001	52.641922000000001	55.480347000000002	55.464548999999998	Татарстан	0103000020E61000000100000005000000548EC9E2FE4D4A40DB31755776BB4B40548EC9E2FE4D4A40A9DDAF027CBD4B409D4A06802A524A40A9DDAF027CBD4B409D4A06802A524A40DB31755776BB4B40548EC9E2FE4D4A40DB31755776BB4B40
11520	31832	52.501767000000001	52.526767	55.494633999999998	55.483320999999997	Тукая	0103000020E61000000100000005000000249BABE639404A40293C6876DDBD4B40249BABE639404A40ADBEBA2A50BF4B4057CEDE196D434A40ADBEBA2A50BF4B4057CEDE196D434A40293C6876DDBD4B40249BABE639404A40293C6876DDBD4B40
11508	31229	52.235013000000002	52.246394000000002	55.627797999999999	55.616829000000003	Центральная	0103000020E610000001000000050000004391EEE7141E4A40B91CAF40F4CE4B404391EEE7141E4A40423F53AF5BD04B401FF7ADD6891F4A40423F53AF5BD04B401FF7ADD6891F4A40B91CAF40F4CE4B404391EEE7141E4A40B91CAF40F4CE4B40
11517	31706	52.657068000000002	52.683999999999997	55.547066000000001	55.536470999999999	Центральная	0103000020E61000000100000005000000C39FE1CD1A544A404F20EC14ABC44B40C39FE1CD1A544A407460394206C64B40643BDF4F8D574A407460394206C64B40643BDF4F8D574A404F20EC14ABC44B40C39FE1CD1A544A404F20EC14ABC44B40
11515	31600	52.729688000000003	52.750996000000001	55.611775000000002	55.599381999999999	Биктимирова	0103000020E610000001000000050000004F24986A665D4A40D1E7A38CB8CC4B404F24986A665D4A4055C1A8A44ECE4B40A2B60DA320604A4055C1A8A44ECE4B40A2B60DA320604A40D1E7A38CB8CC4B404F24986A665D4A40D1E7A38CB8CC4B40
11516	31632	52.694356999999997	52.710877000000004	55.588140000000003	55.581153999999998	Торговая	0103000020E61000000100000005000000D45FAFB0E0584A4044F8174163CA4B40D45FAFB0E0584A4017BCE82B48CB4B40433D7D04FE5A4A4017BCE82B48CB4B40433D7D04FE5A4A4044F8174163CA4B40D45FAFB0E0584A4044F8174163CA4B40
77632	61217	\N	\N	\N	\N	Центральная	\N
11528	40917	51.935172999999999	52.909989000000003	55.861206000000003	55.362617999999998	Ленина	0103000020E61000000100000005000000158DB5BFB3F74940707841446AAE4B40158DB5BFB3F749403B8F8AFF3BEE4B40215C01857A744A403B8F8AFF3BEE4B40215C01857A744A40707841446AAE4B40158DB5BFB3F74940707841446AAE4B40
11512	31455	52.280126000000003	52.303885999999999	55.621602000000003	55.605240999999999	Центральная	0103000020E610000001000000050000003161342BDB234A4063997E8978CD4B403161342BDB234A40699082A790CF4B402BDB87BCE5264A40699082A790CF4B402BDB87BCE5264A4063997E8978CD4B403161342BDB234A4063997E8978CD4B40
11509	31281	52.385354999999997	52.417928000000003	55.520772000000001	55.504598000000001	Ленина	0103000020E61000000100000005000000CF2C095053314A4042D0D1AA96C04B40CF2C095053314A4015562AA8A8C24B40960A2AAA7E354A4015562AA8A8C24B40960A2AAA7E354A4042D0D1AA96C04B40CF2C095053314A4042D0D1AA96C04B40
11507	31192	52.165689999999998	52.192253000000001	55.608465000000002	55.585082	Центральная	0103000020E610000001000000050000001AA3755435154A4038BD8BF7E3CA4B401AA3755435154A405DE15D2EE2CD4B4069C70DBF9B184A405DE15D2EE2CD4B4069C70DBF9B184A4038BD8BF7E3CA4B401AA3755435154A4038BD8BF7E3CA4B40
11493	30544	52.783461000000003	52.797834000000002	55.804380000000002	55.791977000000003	Октябрьская	0103000020E610000001000000050000008258367348644A40941799805FE54B408258367348644A403BC780ECF5E64B4085D1AC6C1F664A403BC780ECF5E64B4085D1AC6C1F664A40941799805FE54B408258367348644A40941799805FE54B40
11502	31014	52.523614000000002	52.537663999999999	55.809114999999998	55.797077999999999	Центральная	0103000020E6100000010000000500000027DD96C805434A40382EE3A606E64B4027DD96C805434A40FDD98F1491E74B40471E882CD2444A40FDD98F1491E74B40471E882CD2444A40382EE3A606E64B4027DD96C805434A40382EE3A606E64B40
11511	31402	52.401991000000002	52.414980999999997	55.576655000000002	55.567672000000002	Большая	0103000020E61000000100000005000000A724EB7074334A406E6DE179A9C84B40A724EB7074334A409609BFD4CFC94B400EBBEF181E354A409609BFD4CFC94B400EBBEF181E354A406E6DE179A9C84B40A724EB7074334A406E6DE179A9C84B40
11500	30910	52.771208000000001	52.826310999999997	55.778860999999999	55.765503000000002	М. Джалиля	0103000020E61000000100000005000000F03499F1B6624A40B5FE9600FCE14B40F03499F1B6624A409F909DB7B1E34B409BA9108FC4694A409F909DB7B1E34B409BA9108FC4694A40B5FE9600FCE14B40F03499F1B6624A40B5FE9600FCE14B40
11514	31542	52.290421000000002	52.306285000000003	55.586395000000003	55.575077999999998	Центральная	0103000020E610000001000000050000002B89EC832C254A401553E9279CC94B402B89EC832C254A40DBC4C9FD0ECB4B40B020CD5834274A40DBC4C9FD0ECB4B40B020CD5834274A401553E9279CC94B402B89EC832C254A401553E9279CC94B40
11499	30857	52.165779000000001	52.185192000000001	55.660902	55.647066000000002	Гагарина	0103000020E610000001000000050000008AAE0B3F38154A40412D060FD3D24B408AAE0B3F38154A4035EECD6F98D44B408CBD175FB4174A4035EECD6F98D44B408CBD175FB4174A40412D060FD3D24B408AAE0B3F38154A40412D060FD3D24B40
11498	30819	52.482795000000003	52.512600999999997	55.588033000000003	55.580849000000001	Школьная	0103000020E610000001000000050000000FD6FF39CC3D4A400875914259CA4B400FD6FF39CC3D4A4001FC53AA44CB4B40CD72D9E89C414A4001FC53AA44CB4B40CD72D9E89C414A400875914259CA4B400FD6FF39CC3D4A400875914259CA4B40
11491	30504	52.746298000000003	52.772114999999999	55.814841000000001	55.804430000000004	Молодежная	0103000020E61000000100000005000000FD885FB1865F4A40EDF5EE8FF7E64B40FD885FB1865F4A405038BBB54CE84B4022E010AAD4624A405038BBB54CE84B4022E010AAD4624A40EDF5EE8FF7E64B40FD885FB1865F4A40EDF5EE8FF7E64B40
11490	30436	52.627009999999999	52.646441000000003	55.738601000000003	55.726233000000001	Центральная	0103000020E61000000100000005000000EA211ADD41504A405323F433F5DC4B40EA211ADD41504A407EE5417A8ADE4B4093E52494BE524A407EE5417A8ADE4B4093E52494BE524A405323F433F5DC4B40EA211ADD41504A405323F433F5DC4B40
11523	31914	52.607354999999998	52.623821	55.460603999999996	55.451987000000003	Шарипова	0103000020E61000000100000005000000F20703CFBD4D4A40CC9BC3B5DAB94B40F20703CFBD4D4A4011346612F5BA4B406DC7D45DD94F4A4011346612F5BA4B406DC7D45DD94F4A40CC9BC3B5DAB94B40F20703CFBD4D4A40CC9BC3B5DAB94B40
11497	32781	51.935172999999999	51.967809000000003	55.540170000000003	55.527890999999997	Центральная	0103000020E61000000100000005000000158DB5BFB3F74940266DAAEE91C34B40158DB5BFB3F74940E223624A24C54B4022E3512AE1FB4940E223624A24C54B4022E3512AE1FB4940266DAAEE91C34B40158DB5BFB3F74940266DAAEE91C34B40
11504	31107	52.561217999999997	52.580036999999997	55.789866000000004	55.781427999999998	Центральная	0103000020E6100000010000000500000098F6CDFDD5474A40DF162CD505E44B4098F6CDFDD5474A40761C3F541AE54B4027BC04A73E4A4A40761C3F541AE54B4027BC04A73E4A4A40DF162CD505E44B4098F6CDFDD5474A40DF162CD505E44B40
11513	31507	52.252934000000003	52.280817999999996	55.599646999999997	55.589224000000002	Центральная	0103000020E61000000100000005000000F3052D2460204A40580229B16BCB4B40F3052D2460204A407F129F3BC1CC4B4066101FD8F1234A407F129F3BC1CC4B4066101FD8F1234A40580229B16BCB4B40F3052D2460204A40580229B16BCB4B40
11501	30952	52.725951000000002	52.750141999999997	55.722943000000001	55.716306000000003	Советская	0103000020E61000000100000005000000CFBF5DF6EB5C4A40DCF63DEAAFDB4B40CFBF5DF6EB5C4A40A2EF6E6589DC4B4092AD2EA704604A40A2EF6E6589DC4B4092AD2EA704604A40DCF63DEAAFDB4B40CFBF5DF6EB5C4A40DCF63DEAAFDB4B40
11489	30275	52.328400999999999	52.346781	55.522489999999998	55.508488	Центральная	0103000020E61000000100000005000000A27C410B092A4A404834812216C14B40A27C410B092A4A40573ECBF3E0C24B40E5EFDE51632C4A40573ECBF3E0C24B40E5EFDE51632C4A404834812216C14B40A27C410B092A4A404834812216C14B40
11487	30254	52.275275000000001	52.303725	55.531947000000002	55.506061000000003	Центральная	0103000020E61000000100000005000000053411363C234A40FA635A9BC6C04B40053411363C234A40481ADCD616C44B4022FDF675E0264A40481ADCD616C44B4022FDF675E0264A40FA635A9BC6C04B40053411363C234A40FA635A9BC6C04B40
11503	31046	52.466867999999998	52.490772	55.797989000000001	55.788818999999997	Кирова	0103000020E6100000010000000500000043C6A354C23B4A4051BB5F05F8E44B4043C6A354C23B4A40ACC8E88024E64B4071E5EC9DD13E4A40ACC8E88024E64B4071E5EC9DD13E4A4051BB5F05F8E44B4043C6A354C23B4A4051BB5F05F8E44B40
11488	30188	52.810231000000002	52.827531999999998	55.84308	55.829450999999999	Тойгузино	0103000020E610000001000000050000004A9A3FA6B5674A4037514B732BEA4B404A9A3FA6B5674A40B2F4A10BEAEB4B405D328E91EC694A40B2F4A10BEAEB4B405D328E91EC694A4037514B732BEA4B404A9A3FA6B5674A4037514B732BEA4B40
11485	30140	52.122615000000003	52.155600999999997	55.630460999999997	55.613396999999999	Чкалова	0103000020E61000000100000005000000E17F2BD9B10F4A40753BFBCA83CE4B40E17F2BD9B10F4A40A43330F2B2D04B40C91CCBBBEA134A40A43330F2B2D04B40C91CCBBBEA134A40753BFBCA83CE4B40E17F2BD9B10F4A40753BFBCA83CE4B40
11486	29963	52.112850999999999	52.157677	55.680950000000003	55.667295000000003	Гагарина	0103000020E610000001000000050000001329CDE6710E4A4065E42CEC69D54B401329CDE6710E4A40091B9E5E29D74B406B2A8BC22E144A40091B9E5E29D74B406B2A8BC22E144A4065E42CEC69D54B401329CDE6710E4A4065E42CEC69D54B40
11505	31145	52.468133999999999	52.488239	55.861206000000003	55.853299	Центральная	0103000020E61000000100000005000000A5129ED0EB3B4A40D15AD1E638ED4B40A5129ED0EB3B4A403B8F8AFF3BEE4B40DDD0949D7E3E4A403B8F8AFF3BEE4B40DDD0949D7E3E4A40D15AD1E638ED4B40A5129ED0EB3B4A40D15AD1E638ED4B40
12260	41032	51.935172999999999	52.909989000000003	55.861206000000003	55.362617999999998	Сайдашева	0103000020E61000000100000005000000158DB5BFB3F74940707841446AAE4B40158DB5BFB3F749403B8F8AFF3BEE4B40215C01857A744A403B8F8AFF3BEE4B40215C01857A744A40707841446AAE4B40158DB5BFB3F74940707841446AAE4B40
11481	29817	48.44697	48.467793	54.798046999999997	54.787936000000002	Ленина	0103000020E6100000010000000500000085251E5036394840A8AB3B16DB644B4085251E5036394840E0D5726726664B401C261AA4E03B4840E0D5726726664B401C261AA4E03B4840A8AB3B16DB644B4085251E5036394840A8AB3B16DB644B40
79264	61505	48.396323000000002	48.414971999999999	54.785443999999998	54.776772999999999	Чапаева	0103000020E6100000010000000500000089D349B6BA32484039B5334C6D634B4089D349B6BA324840726BD26D89644B40BB6070CD1D354840726BD26D89644B40BB6070CD1D35484039B5334C6D634B4089D349B6BA32484039B5334C6D634B40
11479	29724	48.655262	48.684376	54.989387999999998	54.968581999999998	Школьная	0103000020E61000000100000005000000E1270EA0DF53484044BFB67EFA7B4B40E1270EA0DF53484005871744A47E4B406A15FDA19957484005871744A47E4B406A15FDA19957484044BFB67EFA7B4B40E1270EA0DF53484044BFB67EFA7B4B40
11478	29619	48.638885999999999	48.662565000000001	54.934888000000001	54.922606999999999	Школьная	0103000020E61000000100000005000000A6EF3504C7514840C40776FC17764B40A6EF3504C751484020B6F468AA774B40B43C0FEECE54484020B6F468AA774B40B43C0FEECE544840C40776FC17764B40A6EF3504C7514840C40776FC17764B40
11477	29583	48.741177	48.772286000000001	54.786306000000003	54.758266999999996	Чапаева	0103000020E6100000010000000500000011C64FE3DE5E484069519FE40E614B4011C64FE3DE5E48400553CDACA5644B404F948444DA6248400553CDACA5644B404F948444DA62484069519FE40E614B4011C64FE3DE5E484069519FE40E614B40
11476	29538	48.458280000000002	48.489792000000001	54.952877999999998	54.939397999999997	Ленина	0103000020E61000000100000005000000983446EBA83A4840C2F693313E784B40983446EBA83A4840F88903E8F7794B40D5EB1681B13E4840F88903E8F7794B40D5EB1681B13E4840C2F693313E784B40983446EBA83A4840C2F693313E784B40
11432	27321	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	Фрунзе	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
11433	27321	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	Свердлова	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
11439	27321	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	Малкина	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
11437	27321	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	Максима Горького	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
11436	27321	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	Ленина	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
11438	27321	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	Зеленая	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
11434	27321	48.803815999999998	48.851866999999999	54.954962000000002	54.908236000000002	200 лет Тетюшам	0103000020E6100000010000000500000032005471E36648406286C61341744B4032005471E36648401D76DF313C7A4B4054C554FA096D48401D76DF313C7A4B4054C554FA096D48406286C61341744B4032005471E36648406286C61341744B40
11447	28082	48.413310000000003	48.439604000000003	54.729424000000002	54.716669000000003	Вахитова	0103000020E610000001000000050000000D8E9257E73448404D874ECFBB5B4B400D8E9257E7344840717500C45D5D4B406C98A1F144384840717500C45D5D4B406C98A1F1443848404D874ECFBB5B4B400D8E9257E73448404D874ECFBB5B4B40
9900	29488	48.248936	48.285929000000003	54.718822000000003	54.699019	Тукая	0103000020E6100000010000000500000006668522DD1F48402D24607479594B4006668522DD1F48409AD2FA5B025C4B402FFD4B52992448409AD2FA5B025C4B402FFD4B52992448402D24607479594B4006668522DD1F48402D24607479594B40
11474	29402	48.768754999999999	48.798777000000001	54.812266000000001	54.798482999999997	Октябрьская	0103000020E6100000010000000500000078D1579066624840BBB4E1B034664B4078D15790666248408DD31055F8674B4004E621533E6648408DD31055F8674B4004E621533E664840BBB4E1B034664B4078D1579066624840BBB4E1B034664B40
79237	61486	48.515340000000002	48.525599	54.782609000000001	54.775604999999999	Центральная	0103000020E610000001000000050000000B293FA9F64148409ACE4E0647634B400B293FA9F641484013471E882C644B40B8E7F9D34643484013471E882C644B40B8E7F9D3464348409ACE4E0647634B400B293FA9F64148409ACE4E0647634B40
11472	29263	48.731313	48.750340000000001	54.960912	54.946586000000003	Школьная	0103000020E61000000100000005000000E01115AA9B5D4840FD6CE4BA29794B40E01115AA9B5D4840BF2A172AFF7A4B40B97020240B604840BF2A172AFF7A4B40B97020240B604840FD6CE4BA29794B40E01115AA9B5D4840FD6CE4BA29794B40
11471	29214	48.825349000000003	48.850538	55.052680000000002	55.032350999999998	Комсомольская	0103000020E61000000100000005000000A6643909A5694840177FDB1324844B40A6643909A56948409F93DE37BE864B40AC00DF6DDE6C48409F93DE37BE864B40AC00DF6DDE6C4840177FDB1324844B40A6643909A5694840177FDB1324844B40
11468	29083	48.760185	48.783703000000003	55.129170000000002	55.114615999999998	Зиганшина	0103000020E6100000010000000500000073F4F8BD4D61484096CCB1BCAB8E4B4073F4F8BD4D614840EACF7EA488904B407863416150644840EACF7EA488904B40786341615064484096CCB1BCAB8E4B4073F4F8BD4D61484096CCB1BCAB8E4B40
11470	29191	48.545434	48.567020999999997	55.071226000000003	55.056316000000002	Центральная	0103000020E61000000100000005000000301004C8D0454840EB1ED95C35874B40301004C8D0454840FD4FFEEE1D894B409692E52494484840FD4FFEEE1D894B409692E52494484840EB1ED95C35874B40301004C8D0454840EB1ED95C35874B40
11467	29060	48.697347999999998	48.717066000000003	55.034244000000001	55.018628999999997	Пролетарская	0103000020E610000001000000050000002BF702B342594840EBE0606F62824B402BF702B342594840C80A7E1B62844B406A8995D1C85B4840C80A7E1B62844B406A8995D1C85B4840EBE0606F62824B402BF702B342594840EBE0606F62824B40
11466	28988	48.865127000000001	48.889884000000002	55.124927999999997	55.112153999999997	Гагарина	0103000020E610000001000000050000007CF1457BBC6E4840CB0EF10F5B8E4B407CF1457BBC6E4840662D05A4FD8F4B40E99D0AB8E7714840662D05A4FD8F4B40E99D0AB8E7714840CB0EF10F5B8E4B407CF1457BBC6E4840CB0EF10F5B8E4B40
11464	28899	48.590341000000002	48.605963000000003	54.988520000000001	54.975113999999998	Ленина	0103000020E61000000100000005000000753E3C4B904B484095EF1989D07C4B40753E3C4B904B484091B8C7D2877E4B4004CB1132904D484091B8C7D2877E4B4004CB1132904D484095EF1989D07C4B40753E3C4B904B484095EF1989D07C4B40
11463	28888	48.494202999999999	48.530279	54.823382000000002	54.809728	Яковлева	0103000020E61000000100000005000000E44A3D0B423F4840E753C72AA5674B40E44A3D0B423F4840BB0ED59464694B40B760A92EE0434840BB0ED59464694B40B760A92EE0434840E753C72AA5674B40E44A3D0B423F4840E753C72AA5674B40
11462	28820	48.491965999999998	48.515385000000002	54.986103	54.975160000000002	Гагарина	0103000020E61000000100000005000000395FECBDF83E4840062FFA0AD27C4B40395FECBDF83E484066BE839F387E4B40ABECBB22F841484066BE839F387E4B40ABECBB22F8414840062FFA0AD27C4B40395FECBDF83E4840062FFA0AD27C4B40
11461	28766	48.615296000000001	48.632696000000003	54.748967	54.732075000000002	Гагарина	0103000020E6100000010000000500000008AEF204C24E48400F9C33A2B45D4B4008AEF204C24E484041649126DE5F4B40AF27BA2EFC50484041649126DE5F4B40AF27BA2EFC5048400F9C33A2B45D4B4008AEF204C24E48400F9C33A2B45D4B40
11460	28728	48.665349999999997	48.686729999999997	54.769913000000003	54.747444000000002	Молодежная	0103000020E61000000100000005000000613255302A554840B4CBB73EAC5F4B40613255302A554840F4E159828C624B404E97C5C4E6574840F4E159828C624B404E97C5C4E6574840B4CBB73EAC5F4B40613255302A554840B4CBB73EAC5F4B40
11457	28590	48.831062000000003	48.850385000000003	54.860818000000002	54.853247000000003	Центральная	0103000020E610000001000000050000006479573D606A48407F349C32376D4B406479573D606A484071E7C2482F6E4B4026016A6AD96C484071E7C2482F6E4B4026016A6AD96C48407F349C32376D4B406479573D606A48407F349C32376D4B40
11459	28686	48.665844	48.693539000000001	54.818770999999998	54.802779999999998	Первомайская	0103000020E61000000100000005000000711E4E603A55484002F1BA7EC1664B40711E4E603A554840E4F4F57CCD684B4012C0CDE2C5584840E4F4F57CCD684B4012C0CDE2C558484002F1BA7EC1664B40711E4E603A55484002F1BA7EC1664B40
11456	28521	48.621971000000002	48.645902	54.807476999999999	54.791347000000002	Верхняя	0103000020E61000000100000005000000BC07E8BE9C4F4840D464C6DB4A654B40BC07E8BE9C4F4840D7A205685B674B40E335AFEAAC524840D7A205685B674B40E335AFEAAC524840D464C6DB4A654B40BC07E8BE9C4F4840D464C6DB4A654B40
11455	28504	48.331266999999997	48.357174000000001	54.738140999999999	54.726424000000002	Центральная	0103000020E610000001000000050000003C9F01F5662A4840C7832D76FB5C4B403C9F01F5662A48401A6B7F677B5E4B40A27DACE0B72D48401A6B7F677B5E4B40A27DACE0B72D4840C7832D76FB5C4B403C9F01F5662A4840C7832D76FB5C4B40
11449	28158	48.488337000000001	48.511612	54.692265999999996	54.677900999999999	Ленина	0103000020E61000000100000005000000A036AAD3813E48407D76C075C5564B40A036AAD3813E4840FD101B2C9C584B40DE1E84807C414840FD101B2C9C584B40DE1E84807C4148407D76C075C5564B40A036AAD3813E48407D76C075C5564B40
11454	28407	48.604219999999998	48.642038999999997	55.047635999999997	55.029079000000003	Кутузова	0103000020E6100000010000000500000068CBB914574D48400D0055DCB8834B4068CBB914574D48405E0EBBEF18864B40D6E07D552E5248405E0EBBEF18864B40D6E07D552E5248400D0055DCB8834B4068CBB914574D48400D0055DCB8834B40
11451	28247	48.655262	48.680720000000001	55.016719000000002	55.008102999999998	Школьная	0103000020E61000000100000005000000E1270EA0DF534840EFFFE38409814B40E1270EA0DF534840651C23D923824B40D7DD3CD521574840651C23D923824B40D7DD3CD521574840EFFFE38409814B40E1270EA0DF534840EFFFE38409814B40
11444	27967	48.511909000000003	48.563741999999998	54.717770999999999	54.693154999999997	Горького	0103000020E6100000010000000500000098C3EE3B864148408907944DB9584B4098C3EE3B8641484034828DEBDF5B4B40D9B0A6B22848484034828DEBDF5B4B40D9B0A6B2284848408907944DB9584B4098C3EE3B864148408907944DB9584B40
11450	28228	48.759124999999997	48.780980999999997	55.111918000000003	55.093055999999997	Молодежная	0103000020E61000000100000005000000BA490C022B61484029594E42E98B4B40BA490C022B614840B8EA3A54538E4B4010E6762FF7634840B8EA3A54538E4B4010E6762FF763484029594E42E98B4B40BA490C022B61484029594E42E98B4B40
11452	28317	48.640880000000003	48.681213999999997	55.062899999999999	55.049410999999999	Мусина	0103000020E610000001000000050000008B54185B085248400588821953864B408B54185B085248408E75711B0D884B40E6C93505325748408E75711B0D884B40E6C93505325748400588821953864B408B54185B085248400588821953864B40
11448	28148	48.729013999999999	48.748893000000002	54.816509000000003	54.802874000000003	Гагарина	0103000020E61000000100000005000000BF29AC54505D484084674293C4664B40BF29AC54505D4840E1F1ED5D83684B40079ACFB9DB5F4840E1F1ED5D83684B40079ACFB9DB5F484084674293C4664B40BF29AC54505D484084674293C4664B40
11446	28044	48.445622	48.475634999999997	54.684896999999999	54.663936999999997	Стахановская	0103000020E61000000100000005000000663046240A3948405BCD3AE3FB544B40663046240A394840731074B4AA574B409EEA909BE13C4840731074B4AA574B409EEA909BE13C48405BCD3AE3FB544B40663046240A3948405BCD3AE3FB544B40
11445	28004	48.441436000000003	48.465960000000003	54.760688000000002	54.743623999999997	Гагарина	0103000020E6100000010000000500000077A38FF980384840A6423C122F5F4B4077A38FF980384840D63A71395E614B40419FC893A43B4840D63A71395E614B40419FC893A43B4840A6423C122F5F4B4077A38FF980384840A6423C122F5F4B40
11443	27926	48.625689999999999	48.641356000000002	55.118045000000002	55.106737000000003	М. Джалиля	0103000020E6100000010000000500000095B7239C16504840F722DA8EA98D4B4095B7239C16504840693A3B191C8F4B40F48B12F417524840693A3B191C8F4B40F48B12F417524840F722DA8EA98D4B4095B7239C16504840F722DA8EA98D4B40
11442	27871	48.620497	48.636218	54.881686000000002	54.869289999999999	Молодежная	0103000020E61000000100000005000000102219726C4F4840B35E0CE5446F4B40102219726C4F4840A8AB3B16DB704B40329067976F514840A8AB3B16DB704B40329067976F514840B35E0CE5446F4B40102219726C4F4840B35E0CE5446F4B40
11441	27837	48.699190000000002	48.715530000000001	55.101616999999997	55.082199000000003	Ленина	0103000020E610000001000000050000005AD8D30E7F594840C861307F858A4B405AD8D30E7F594840DBDB2DC9018D4B4048A7AE7C965B4840DBDB2DC9018D4B4048A7AE7C965B4840C861307F858A4B405AD8D30E7F594840C861307F858A4B40
11428	27060	49.644945	49.681192000000003	55.014293000000002	54.998829000000001	Центральная	0103000020E61000000100000005000000FF5BC98E8DD24840F0A5F0A0D97F4B40FF5BC98E8DD24840E7C75F5AD4814B40FF25A94C31D74840E7C75F5AD4814B40FF25A94C31D74840F0A5F0A0D97F4B40FF5BC98E8DD24840F0A5F0A0D97F4B40
79269	61509	48.861794000000003	49.837184000000001	55.245998999999998	54.555162000000003	Центральная	0103000020E61000000100000005000000CCF10A444F6E4840B1FD648C0F474B40CCF10A444F6E4840A2EC2DE57C9F4B40035E66D828EB4840A2EC2DE57C9F4B40035E66D828EB4840B1FD648C0F474B40CCF10A444F6E4840B1FD648C0F474B40
11406	26056	48.952145999999999	48.962432	54.915218000000003	54.904271000000001	Вахитова	0103000020E6100000010000000500000034828DEBDF79484051DCF126BF734B4034828DEBDF794840F35A09DD25754B40DB4FC6F8307B4840F35A09DD25754B40DB4FC6F8307B484051DCF126BF734B4034828DEBDF79484051DCF126BF734B40
12255	26629	49.508671	49.529924999999999	55.004317999999998	54.983840000000001	Г.Тукая	0103000020E6100000010000000500000039B69E211CC14840923F1878EE7D4B4039B69E211CC148405E64027E8D804B40992A1895D4C348405E64027E8D804B40992A1895D4C34840923F1878EE7D4B4039B69E211CC14840923F1878EE7D4B40
11405	25991	49.031269999999999	49.071739000000001	54.92136	54.896920000000001	Школьная	0103000020E6100000010000000500000047ACC5A7008448406D904946CE724B4047ACC5A700844840D9EBDD1FEF754B40836C59BE2E894840D9EBDD1FEF754B40836C59BE2E8948406D904946CE724B4047ACC5A7008448406D904946CE724B40
11422	26795	49.543596999999998	49.564177000000001	54.925446999999998	54.911797	Центральная	0103000020E61000000100000005000000139A249694C54840A3CB9BC3B5744B40139A249694C5484035971B0C75764B40E413B2F336C8484035971B0C75764B40E413B2F336C84840A3CB9BC3B5744B40139A249694C54840A3CB9BC3B5744B40
11409	26151	49.1083	49.130353999999997	54.826737999999999	54.814895999999997	70 лет Октября	0103000020E6100000010000000500000012143FC6DC8D484013D21A834E684B4012143FC6DC8D4840232E008DD2694B408E739B70AF904840232E008DD2694B408E739B70AF90484013D21A834E684B4012143FC6DC8D484013D21A834E684B40
11430	27184	49.482934	49.502741999999998	54.797373	54.781565999999998	Центральная	0103000020E61000000100000005000000301004C8D0BD484030D5CC5A0A644B40301004C8D0BD484051DB865110664B40AE2990D959C0484051DB865110664B40AE2990D959C0484030D5CC5A0A644B40301004C8D0BD484030D5CC5A0A644B40
11411	26310	49.071317000000001	49.091313	54.991573000000002	54.980932000000003	Школьная	0103000020E610000001000000050000000D535BEA20894840C9CC052E8F7D4B400D535BEA208948405E4C33DDEB7E4B408E59F624B08B48405E4C33DDEB7E4B408E59F624B08B4840C9CC052E8F7D4B400D535BEA20894840C9CC052E8F7D4B40
11407	26083	48.980882999999999	48.997529	54.838582000000002	54.816654999999997	Центральная	0103000020E61000000100000005000000E719FB928D7D4840B48EAA2688684B40E719FB928D7D4840D481ACA7566B4B40E2E7BF07AF7F4840D481ACA7566B4B40E2E7BF07AF7F4840B48EAA2688684B40E719FB928D7D4840B48EAA2688684B40
11413	26382	49.352992999999998	49.368219000000003	54.859988999999999	54.849198999999999	Клубная	0103000020E61000000100000005000000C45BE7DF2EAD4840E065868DB26C4B40C45BE7DF2EAD4840BAF59A1E146E4B400762D9CC21AF4840BAF59A1E146E4B400762D9CC21AF4840E065868DB26C4B40C45BE7DF2EAD4840E065868DB26C4B40
11412	26320	49.385142999999999	49.408867999999998	54.930976999999999	54.906362000000001	Буденного	0103000020E6100000010000000500000044A4A65D4CB14840282B86AB03744B4044A4A65D4CB14840022A1C412A774B40C23060C955B44840022A1C412A774B40C23060C955B44840282B86AB03744B4044A4A65D4CB14840282B86AB03744B40
11414	26493	49.423276999999999	49.442653	55.055129999999998	55.040940999999997	60 лет Октября	0103000020E610000001000000050000001213D4F02DB648406308008E3D854B401213D4F02DB64840A583F57F0E874B40F73C7FDAA8B84840A583F57F0E874B40F73C7FDAA8B848406308008E3D854B401213D4F02DB648406308008E3D854B40
11429	27068	49.589078999999998	49.638674999999999	54.731493	54.706437999999999	Советская	0103000020E6100000010000000500000054E1CFF066CB48406953758F6C5A4B4054E1CFF066CB484060200890A15D4B40EBE2361AC0D1484060200890A15D4B40EBE2361AC0D148406953758F6C5A4B4054E1CFF066CB48406953758F6C5A4B40
11410	26237	49.175485000000002	49.197009000000001	54.936202000000002	54.926822999999999	Новая	0103000020E6100000010000000500000023F8DF4A769648401E17D522A2764B4023F8DF4A7696484093399677D5774B40430246973799484093399677D5774B4043024697379948401E17D522A2764B4023F8DF4A769648401E17D522A2764B40
79242	61488	49.243335000000002	49.271434999999997	54.966856	54.953747	Школьная	0103000020E61000000100000005000000707CED99259F48403DD4B661147A4B40707CED99259F48407FF8F9EFC17B4B40B0FECF61BEA248407FF8F9EFC17B4B40B0FECF61BEA248403DD4B661147A4B40707CED99259F48403DD4B661147A4B40
78557	26587	49.390568999999999	49.419297	55.002113000000001	54.985053999999998	Клубная	0103000020E610000001000000050000006CEA3C2AFEB14840A165DD3F167E4B406CEA3C2AFEB14840BFF2203D45804B40CC272B86ABB54840BFF2203D45804B40CC272B86ABB54840A165DD3F167E4B406CEA3C2AFEB14840A165DD3F167E4B40
11424	26919	49.686151000000002	49.708689	55.143034	55.127028000000003	Советская	0103000020E61000000100000005000000118FC4CBD3D7484091D6187442904B40118FC4CBD3D74840A81B28F04E924B4079043752B6DA4840A81B28F04E924B4079043752B6DA484091D6187442904B40118FC4CBD3D7484091D6187442904B40
78590	61335	49.642662999999999	49.696032000000002	54.604368999999998	54.581938000000001	Ленина	0103000020E61000000100000005000000B4ACFBC742D248405B26C3F17C4A4B40B4ACFBC742D24840ADDBA0F65B4D4B40187C9A9317D94840ADDBA0F65B4D4B40187C9A9317D948405B26C3F17C4A4B40B4ACFBC742D248405B26C3F17C4A4B40
11425	26958	49.526232999999998	49.552266000000003	55.145328999999997	55.132849999999998	Школьная	0103000020E61000000100000005000000B9895A9A5BC3484005A3923A01914B40B9895A9A5BC34840871403249A924B40AC58FCA6B0C64840871403249A924B40AC58FCA6B0C6484005A3923A01914B40B9895A9A5BC3484005A3923A01914B40
11431	27218	49.551475000000003	49.572755999999998	54.836705000000002	54.821795000000002	Центральная	0103000020E61000000100000005000000E3C798BB96C6484017821C9430694B40E3C798BB96C6484029B34126196B4B403C4B901150C9484029B34126196B4B403C4B901150C9484017821C9430694B40E3C798BB96C6484017821C9430694B40
11415	26522	49.519934999999997	49.537452999999999	55.040605999999997	55.033237999999997	Центральная	0103000020E61000000100000005000000DB85E63A8DC24840027E8D2441844B40DB85E63A8DC24840BC02D19332854B408C118942CBC44840BC02D19332854B408C118942CBC44840027E8D2441844B40DB85E63A8DC24840027E8D2441844B40
11420	26726	49.517699	49.539501000000001	54.884461999999999	54.873181000000002	Школьная	0103000020E610000001000000050000000116F9F543C248408A3E1F65C46F4B400116F9F543C248400247020D36714B406494675E0EC548400247020D36714B406494675E0EC548408A3E1F65C46F4B400116F9F543C248408A3E1F65C46F4B40
11427	26990	49.56221	49.617088000000003	55.110469999999999	55.097166999999999	Бугровская	0103000020E61000000100000005000000F9BD4D7FF6C748400EA0DFF76F8C4B40F9BD4D7FF6C74840359886E1238E4B40856055BDFCCE4840359886E1238E4B40856055BDFCCE48400EA0DFF76F8C4B40F9BD4D7FF6C748400EA0DFF76F8C4B40
11423	26876	49.649428	49.669110000000003	55.130507999999999	55.122070999999998	Молодежная	0103000020E61000000100000005000000A88DEA7420D348401F65C405A08F4B40A88DEA7420D34840E5EE737CB4904B409AB67F65A5D54840E5EE737CB4904B409AB67F65A5D548401F65C405A08F4B40A88DEA7420D348401F65C405A08F4B40
9787	26426	49.306604	49.325018999999998	54.915796999999998	54.903396000000001	Спирькова	0103000020E610000001000000050000005169C4CC3EA748402AABE97AA2734B405169C4CC3EA7484030630AD638754B4010CAFB389AA9484030630AD638754B4010CAFB389AA948402AABE97AA2734B405169C4CC3EA748402AABE97AA2734B40
11400	25642	49.009692000000001	49.049720999999998	54.992224	54.959184999999998	Советская	0103000020E61000000100000005000000348463963D81484029E8F692C67A4B40348463963D81484035272F32017F4B405376FA415D86484035272F32017F4B405376FA415D86484029E8F692C67A4B40348463963D81484029E8F692C67A4B40
11404	25642	49.009692000000001	49.049720999999998	54.992224	54.959184999999998	Рабочая	0103000020E61000000100000005000000348463963D81484029E8F692C67A4B40348463963D81484035272F32017F4B405376FA415D86484035272F32017F4B405376FA415D86484029E8F692C67A4B40348463963D81484029E8F692C67A4B40
11399	25642	49.009692000000001	49.049720999999998	54.992224	54.959184999999998	Пионерская	0103000020E61000000100000005000000348463963D81484029E8F692C67A4B40348463963D81484035272F32017F4B405376FA415D86484035272F32017F4B405376FA415D86484029E8F692C67A4B40348463963D81484029E8F692C67A4B40
11403	25642	49.009692000000001	49.049720999999998	54.992224	54.959184999999998	Октябрьская	0103000020E61000000100000005000000348463963D81484029E8F692C67A4B40348463963D81484035272F32017F4B405376FA415D86484035272F32017F4B405376FA415D86484029E8F692C67A4B40348463963D81484029E8F692C67A4B40
11402	25642	49.009692000000001	49.049720999999998	54.992224	54.959184999999998	Ленина	0103000020E61000000100000005000000348463963D81484029E8F692C67A4B40348463963D81484035272F32017F4B405376FA415D86484035272F32017F4B405376FA415D86484029E8F692C67A4B40348463963D81484029E8F692C67A4B40
11401	25642	49.009692000000001	49.049720999999998	54.992224	54.959184999999998	Гордеева	0103000020E61000000100000005000000348463963D81484029E8F692C67A4B40348463963D81484035272F32017F4B405376FA415D86484035272F32017F4B405376FA415D86484029E8F692C67A4B40348463963D81484029E8F692C67A4B40
11408	26127	48.946666999999998	48.971837000000001	54.862617	54.848011999999997	Садовая	0103000020E61000000100000005000000E9995E622C794840CA4E3FA88B6C4B40E9995E622C794840A0FCDD3B6A6E4B407905A227657C4840A0FCDD3B6A6E4B407905A227657C4840CA4E3FA88B6C4B40E9995E622C794840CA4E3FA88B6C4B40
11419	26684	49.459712000000003	49.520519	54.922203000000003	54.902997999999997	Советская	0103000020E6100000010000000500000015CAC2D7D7BA48403C2D3F7095734B4015CAC2D7D7BA4840F5A276BF0A764B402BF9D85DA0C24840F5A276BF0A764B402BF9D85DA0C248403C2D3F7095734B4015CAC2D7D7BA48403C2D3F7095734B40
11421	26787	49.627554000000003	49.649715	54.951255000000003	54.93629	Куйбышева	0103000020E61000000100000005000000AC3C81B053D0484032C9C859D8774B40AC3C81B053D0484008944DB9C2794B403E5C72DC29D3484008944DB9C2794B403E5C72DC29D3484032C9C859D8774B40AC3C81B053D0484032C9C859D8774B40
79278	61515	52.859225000000002	52.880470000000003	55.154480999999997	55.141129999999997	Родниковая	0103000020E61000000100000005000000EB73B515FB6D4A40033E3F8C10924B40EB73B515FB6D4A403B6D8D08C6934B40F88DAF3DB3704A403B6D8D08C6934B40F88DAF3DB3704A40033E3F8C10924B40EB73B515FB6D4A40033E3F8C10924B40
11385	24870	52.597977	52.616374	55.322536999999997	55.304611000000001	Ленина	0103000020E610000001000000050000004E61A5828A4C4A403D80457EFDA64B404E61A5828A4C4A40FE5F75E448A94B40670DDE57E54E4A40FE5F75E448A94B40670DDE57E54E4A403D80457EFDA64B404E61A5828A4C4A403D80457EFDA64B40
79240	22882	52.596359999999997	52.616239999999998	55.368124000000002	55.358412000000001	Набережная	0103000020E610000001000000050000003F524486554C4A403A3FC571E0AD4B403F524486554C4A40B56FEEAF1EAF4B40573ECBF3E04E4A40B56FEEAF1EAF4B40573ECBF3E04E4A403A3FC571E0AD4B403F524486554C4A403A3FC571E0AD4B40
11343	22912	52.537402999999998	52.558585999999998	55.417377999999999	55.399785999999999	Шоссейная	0103000020E61000000100000005000000DAE21A9FC9444A4007B309302CB34B40DAE21A9FC9444A40F2086EA46CB54B407100FDBE7F474A40F2086EA46CB54B407100FDBE7F474A4007B309302CB34B40DAE21A9FC9444A4007B309302CB34B40
11369	24053	52.725008000000003	52.745874999999998	55.413116000000002	55.40522	Школьная	0103000020E6100000010000000500000050ABE80FCD5C4A40B2D7BB3FDEB34B4050ABE80FCD5C4A4028BA2EFCE0B44B40B6F3FDD4785F4A4028BA2EFCE0B44B40B6F3FDD4785F4A40B2D7BB3FDEB34B4050ABE80FCD5C4A40B2D7BB3FDEB34B40
11350	23329	52.788572000000002	52.814183	55.464334999999998	55.452517999999998	М. Джалиля	0103000020E610000001000000050000004A4563EDEF644A40F86C1D1CECB94B404A4563EDEF644A40AFB14B546FBB4B40C6FA062637684A40AFB14B546FBB4B40C6FA062637684A40F86C1D1CECB94B404A4563EDEF644A40F86C1D1CECB94B40
11383	24788	52.417181999999997	52.440655	55.291468999999999	55.277020999999998	Советская	0103000020E610000001000000050000006C3D433866354A4011A7936C75A34B406C3D433866354A401F662FDB4EA54B40D1E80E6267384A401F662FDB4EA54B40D1E80E6267384A4011A7936C75A34B406C3D433866354A4011A7936C75A34B40
79162	61426	52.730173000000001	52.750672000000002	55.373240000000003	55.361569000000003	К. Маркса	0103000020E610000001000000050000000BB6114F765D4A40AC1F9BE447AE4B400BB6114F765D4A408FC70C54C6AF4B40EF02250516604A408FC70C54C6AF4B40EF02250516604A40AC1F9BE447AE4B400BB6114F765D4A40AC1F9BE447AE4B40
11368	24003	52.762161999999996	52.785249	55.440514	55.431744000000002	Школьная	0103000020E61000000100000005000000812040868E614A40431F2C6343B74B40812040868E614A400FB743C362B84B40BD1B0B0A83644A400FB743C362B84B40BD1B0B0A83644A40431F2C6343B74B40812040868E614A40431F2C6343B74B40
11378	24446	52.850655000000003	52.866681	55.412114000000003	55.401330000000002	М.Джалиля	0103000020E61000000100000005000000E6965643E26C4A40AC730CC85EB34B40E6965643E26C4A40A41CCC26C0B44B4044882B67EF6E4A40A41CCC26C0B44B4044882B67EF6E4A40AC730CC85EB34B40E6965643E26C4A40AC730CC85EB34B40
11382	24771	52.672905	52.707526000000001	55.083235000000002	55.069319	50 лет Октября	0103000020E610000001000000050000004E2844C021564A40E7FEEA71DF884B404E2844C021564A40F870C971A78A4B40EC884336905A4A40F870C971A78A4B40EC884336905A4A40E7FEEA71DF884B404E2844C021564A40E7FEEA71DF884B40
11380	24657	52.532111999999998	52.56756	55.160442000000003	55.146250000000002	Комсомольская	0103000020E6100000010000000500000092E7FA3E1C444A401F85EB51B8924B4092E7FA3E1C444A40D2730B5D89944B4046425BCEA5484A40D2730B5D89944B4046425BCEA5484A401F85EB51B8924B4092E7FA3E1C444A401F85EB51B8924B40
11377	24519	52.777738999999997	52.806781000000001	55.367550999999999	55.355908999999997	М. Вахитова	0103000020E6100000010000000500000070E998F38C634A4010AD156D8EAD4B4070E998F38C634A40594E42E90BAF4B4060048D9944674A40594E42E90BAF4B4060048D9944674A4010AD156D8EAD4B4070E998F38C634A4010AD156D8EAD4B40
11379	24611	52.491643000000003	52.519877000000001	55.161172999999998	55.152732	Х. Такташа	0103000020E6100000010000000500000057276728EE3E4A40BE86E0B88C934B4057276728EE3E4A40C5FF1D51A1944B40A7785C548B424A40C5FF1D51A1944B40A7785C548B424A40BE86E0B88C934B4057276728EE3E4A40BE86E0B88C934B40
11389	24945	52.571198000000003	52.614946000000003	55.264947999999997	55.240169000000002	Энергетиков	0103000020E6100000010000000500000033C51C041D494A40AB4198DBBD9E4B4033C51C041D494A40FF91E9D0E9A14B402C67EF8CB64E4A40FF91E9D0E9A14B402C67EF8CB64E4A40AB4198DBBD9E4B4033C51C041D494A40AB4198DBBD9E4B40
11392	24945	52.571198000000003	52.614946000000003	55.264947999999997	55.240169000000002	Терешковой	0103000020E6100000010000000500000033C51C041D494A40AB4198DBBD9E4B4033C51C041D494A40FF91E9D0E9A14B402C67EF8CB64E4A40FF91E9D0E9A14B402C67EF8CB64E4A40AB4198DBBD9E4B4033C51C041D494A40AB4198DBBD9E4B40
11386	24945	52.571198000000003	52.614946000000003	55.264947999999997	55.240169000000002	Сельхозтехники	0103000020E6100000010000000500000033C51C041D494A40AB4198DBBD9E4B4033C51C041D494A40FF91E9D0E9A14B402C67EF8CB64E4A40FF91E9D0E9A14B402C67EF8CB64E4A40AB4198DBBD9E4B4033C51C041D494A40AB4198DBBD9E4B40
11393	24945	52.571198000000003	52.614946000000003	55.264947999999997	55.240169000000002	М. Джалиля	0103000020E6100000010000000500000033C51C041D494A40AB4198DBBD9E4B4033C51C041D494A40FF91E9D0E9A14B402C67EF8CB64E4A40FF91E9D0E9A14B402C67EF8CB64E4A40AB4198DBBD9E4B4033C51C041D494A40AB4198DBBD9E4B40
11388	24945	52.571198000000003	52.614946000000003	55.264947999999997	55.240169000000002	Ленина	0103000020E6100000010000000500000033C51C041D494A40AB4198DBBD9E4B4033C51C041D494A40FF91E9D0E9A14B402C67EF8CB64E4A40FF91E9D0E9A14B402C67EF8CB64E4A40AB4198DBBD9E4B4033C51C041D494A40AB4198DBBD9E4B40
11391	24945	52.571198000000003	52.614946000000003	55.264947999999997	55.240169000000002	Куйбышева	0103000020E6100000010000000500000033C51C041D494A40AB4198DBBD9E4B4033C51C041D494A40FF91E9D0E9A14B402C67EF8CB64E4A40FF91E9D0E9A14B402C67EF8CB64E4A40AB4198DBBD9E4B4033C51C041D494A40AB4198DBBD9E4B40
11356	23523	52.629821999999997	52.655577000000001	55.1539	55.138331000000001	М. Джалиля	0103000020E610000001000000050000009126DE019E504A40F18288D4B4914B409126DE019E504A405D6DC5FEB2934B40418177F2E9534A405D6DC5FEB2934B40418177F2E9534A40F18288D4B4914B409126DE019E504A40F18288D4B4914B40
11374	24338	52.870319000000002	52.891024999999999	55.390169	55.373438999999998	Ленина	0103000020E61000000100000005000000310BED9C666F4A40850662D9CCAF4B40310BED9C666F4A40DE74CB0EF1B14B408E75711B0D724A40DE74CB0EF1B14B408E75711B0D724A40850662D9CCAF4B40310BED9C666F4A40850662D9CCAF4B40
11373	24304	52.874146000000003	52.890557999999999	55.209713999999998	55.198524999999997	Вахитова	0103000020E61000000100000005000000F1F62004E46F4A401D38674469994B40F1F62004E46F4A40B5C189E8D79A4B407898F6CDFD714A40B5C189E8D79A4B407898F6CDFD714A401D38674469994B40F1F62004E46F4A401D38674469994B40
11375	24258	52.743952999999998	52.769995000000002	55.224848999999999	55.211886999999997	Советская	0103000020E610000001000000050000006B6116DA395F4A4049B9FB1C1F9B4B406B6116DA395F4A40E7C41EDAC79C4B40B18A37328F624A40E7C41EDAC79C4B40B18A37328F624A4049B9FB1C1F9B4B406B6116DA395F4A4049B9FB1C1F9B4B40
11370	24094	52.47842	52.508656999999999	55.326138	55.311523000000001	Поперечная	0103000020E610000001000000050000004CE0D6DD3C3D4A40D57954FCDFA74B404CE0D6DD3C3D4A40CEFDD5E3BEA94B40D4F02DAC1B414A40CEFDD5E3BEA94B40D4F02DAC1B414A40D57954FCDFA74B404CE0D6DD3C3D4A40D57954FCDFA74B40
11366	23887	52.434914999999997	52.456851999999998	55.126677999999998	55.111660000000001	М. Джалиля	0103000020E6100000010000000500000019C5724BAB374A40BC22F8DF4A8E4B4019C5724BAB374A40B48F15FC36904B405C8E57207A3A4A40B48F15FC36904B405C8E57207A3A4A40BC22F8DF4A8E4B4019C5724BAB374A40BC22F8DF4A8E4B40
11394	13155	52.588867999999998	52.606456999999999	55.279682000000001	55.269261	Ленина	0103000020E6100000010000000500000099D4D006604B4A404C8BFA2477A24B4099D4D006604B4A40D3A3A99ECCA34B4013B70A62A04D4A40D3A3A99ECCA34B4013B70A62A04D4A404C8BFA2477A24B4099D4D006604B4A404C8BFA2477A24B40
11354	23466	52.568072000000001	52.588500000000003	55.103836999999999	55.092709999999997	40 лет Победы	0103000020E61000000100000005000000FCE25295B6484A408E01D9EBDD8B4B40FCE25295B6484A40B08EE3874A8D4B4017D9CEF7534B4A40B08EE3874A8D4B4017D9CEF7534B4A408E01D9EBDD8B4B40FCE25295B6484A408E01D9EBDD8B4B40
11371	24165	52.361666	52.381366	55.331234000000002	55.32687	Октрябрьская	0103000020E610000001000000050000009E094D124B2E4A4092054CE0D6A94B409E094D124B2E4A4061A92EE065AA4B4036E7E099D0304A4061A92EE065AA4B4036E7E099D0304A4092054CE0D6A94B409E094D124B2E4A4092054CE0D6A94B40
11360	23687	52.591149999999999	52.614775000000002	55.22831	55.201900000000002	Советская	0103000020E61000000100000005000000E4839ECDAA4B4A40FD87F4DBD7994B40E4839ECDAA4B4A40C5AC1743399D4B40FFB27BF2B04E4A40C5AC1743399D4B40FFB27BF2B04E4A40FD87F4DBD7994B40E4839ECDAA4B4A40FD87F4DBD7994B40
11347	23199	52.544742999999997	52.572077999999998	55.225101000000002	55.213608000000001	Школьная	0103000020E61000000100000005000000CADC7C23BA454A40FD14C781579B4B40CADC7C23BA454A4001A60C1CD09C4B406B6116DA39494A4001A60C1CD09C4B406B6116DA39494A40FD14C781579B4B40CADC7C23BA454A40FD14C781579B4B40
11358	23609	52.461370000000002	52.487842999999998	55.353099999999998	55.338012999999997	Школьная	0103000020E6100000010000000500000082AD122C0E3B4A40B94F8E0244AB4B4082AD122C0E3B4A40DA1B7C6132AD4B40904AB1A3713E4A40DA1B7C6132AD4B40904AB1A3713E4A40B94F8E0244AB4B4082AD122C0E3B4A40B94F8E0244AB4B40
11353	23386	52.614488000000001	52.63832	55.122107	55.113503999999999	Советская	0103000020E6100000010000000500000069E4F38AA74E4A408BFB8F4C878E4B4069E4F38AA74E4A406CCEC133A18F4B40FD304278B4514A406CCEC133A18F4B40FD304278B4514A408BFB8F4C878E4B4069E4F38AA74E4A408BFB8F4C878E4B40
11351	23386	52.614488000000001	52.63832	55.122107	55.113503999999999	Молодежная	0103000020E6100000010000000500000069E4F38AA74E4A408BFB8F4C878E4B4069E4F38AA74E4A406CCEC133A18F4B40FD304278B4514A406CCEC133A18F4B40FD304278B4514A408BFB8F4C878E4B4069E4F38AA74E4A408BFB8F4C878E4B40
11365	23861	52.496026999999998	52.520794000000002	55.135212000000003	55.123269999999998	Гагарина	0103000020E610000001000000050000006C770FD07D3F4A40F949B54FC78F4B406C770FD07D3F4A406D0377A04E914B40FDF9B660A9424A406D0377A04E914B40FDF9B660A9424A40F949B54FC78F4B406C770FD07D3F4A40F949B54FC78F4B40
11362	23724	52.613346999999997	52.624279999999999	55.191201999999997	55.178198000000002	Хисамова	0103000020E61000000100000005000000C30C8D27824E4A40371B2B31CF964B40C30C8D27824E4A400377A04E79984B4000C63368E84F4A400377A04E79984B4000C63368E84F4A40371B2B31CF964B40C30C8D27824E4A40371B2B31CF964B40
11381	24706	52.605001999999999	52.626021999999999	55.090691	55.081049999999998	Советская	0103000020E61000000100000005000000DE019EB4704D4A409FABADD85F8A4B40DE019EB4704D4A4051853FC39B8B4B40CB49287D21504A4051853FC39B8B4B40CB49287D21504A409FABADD85F8A4B40DE019EB4704D4A409FABADD85F8A4B40
11384	24864	52.615682999999997	52.647509999999997	55.304606	55.289526000000002	Ленина	0103000020E6100000010000000500000001DA56B3CE4E4A40BDAB1E300FA54B4001DA56B3CE4E4A402B155454FDA64B409EEA909BE1524A402B155454FDA64B409EEA909BE1524A40BDAB1E300FA54B4001DA56B3CE4E4A40BDAB1E300FA54B40
11349	23292	52.820948000000001	52.851579999999998	55.480097000000001	55.466448	Ленина	0103000020E61000000100000005000000BADBF5D214694A406EA46C91B4BB4B40BADBF5D214694A4030F488D173BD4B40BEF6CC92006D4A4030F488D173BD4B40BEF6CC92006D4A406EA46C91B4BB4B40BADBF5D214694A406EA46C91B4BB4B40
11348	23245	52.798696	52.831780999999999	55.286557999999999	55.268912999999998	Советская	0103000020E6100000010000000500000017B9A7AB3B664A40103CBEBD6BA24B4017B9A7AB3B664A401E34BBEEADA44B409337C0CC776A4A401E34BBEEADA44B409337C0CC776A4A40103CBEBD6BA24B4017B9A7AB3B664A40103CBEBD6BA24B40
11345	23108	52.520873999999999	52.549799999999998	55.247923999999998	55.237124999999999	Комсомольская	0103000020E6100000010000000500000019ABCDFFAB424A403108AC1C5A9E4B4019ABCDFFAB424A405EF23FF9BB9F4B409FABADD85F464A405EF23FF9BB9F4B409FABADD85F464A403108AC1C5A9E4B4019ABCDFFAB424A403108AC1C5A9E4B40
11372	24176	52.531618000000002	52.553033999999997	55.299833999999997	55.284210000000002	Советская	0103000020E6100000010000000500000083FB010F0C444A401C9947FE60A44B4083FB010F0C444A404B1DE4F560A64B40BCC96FD1C9464A404B1DE4F560A64B40BCC96FD1C9464A401C9947FE60A44B4083FB010F0C444A401C9947FE60A44B40
11398	25227	52.728897000000003	52.749899999999997	55.032499999999999	55.016326999999997	Лесная	0103000020E610000001000000050000008693347F4C5D4A405985CD0017824B408693347F4C5D4A405C8FC2F528844B409CA223B9FC5F4A405C8FC2F528844B409CA223B9FC5F4A405985CD0017824B408693347F4C5D4A405985CD0017824B40
11396	25227	52.728897000000003	52.749899999999997	55.032499999999999	55.016326999999997	Ленина	0103000020E610000001000000050000008693347F4C5D4A405985CD0017824B408693347F4C5D4A405C8FC2F528844B409CA223B9FC5F4A405C8FC2F528844B409CA223B9FC5F4A405985CD0017824B408693347F4C5D4A405985CD0017824B40
11397	25227	52.728897000000003	52.749899999999997	55.032499999999999	55.016326999999997	Ахмадиева	0103000020E610000001000000050000008693347F4C5D4A405985CD0017824B408693347F4C5D4A405C8FC2F528844B409CA223B9FC5F4A405C8FC2F528844B409CA223B9FC5F4A405985CD0017824B408693347F4C5D4A405985CD0017824B40
11395	25227	52.728897000000003	52.749899999999997	55.032499999999999	55.016326999999997	30 лет Победы	0103000020E610000001000000050000008693347F4C5D4A405985CD0017824B408693347F4C5D4A405C8FC2F528844B409CA223B9FC5F4A405C8FC2F528844B409CA223B9FC5F4A405985CD0017824B408693347F4C5D4A405985CD0017824B40
11357	23602	52.466715000000001	52.488472000000002	55.38776	55.380226999999998	Ленина	0103000020E61000000100000005000000BDC62E51BD3B4A4031074147ABB04B40BDC62E51BD3B4A403659A31EA2B14B4080812040863E4A403659A31EA2B14B4080812040863E4A4031074147ABB04B40BDC62E51BD3B4A4031074147ABB04B40
11364	23806	52.479686999999998	52.493259999999999	55.088459999999998	55.081420999999999	Советская	0103000020E610000001000000050000007EA83462663D4A40931ADA006C8A4B407EA83462663D4A40888043A8528B4B406536C824233F4A40888043A8528B4B406536C824233F4A40931ADA006C8A4B407EA83462663D4A40931ADA006C8A4B40
11367	23963	52.643116999999997	52.686703000000001	55.388123	55.368020999999999	Школьная	0103000020E61000000100000005000000354069A851524A40E09EE74F1BAF4B40354069A851524A40A7E9B303AEB14B40558847E2E5574A40A7E9B303AEB14B40558847E2E5574A40E09EE74F1BAF4B40354069A851524A40E09EE74F1BAF4B40
11344	23065	52.705495999999997	52.733280999999998	55.260013000000001	55.245784	Ленина	0103000020E61000000100000005000000BABA63B14D5A4A40A6F0A0D9759F4B40BABA63B14D5A4A4076C4211B48A14B409BE3DC26DC5D4A4076C4211B48A14B409BE3DC26DC5D4A40A6F0A0D9759F4B40BABA63B14D5A4A40A6F0A0D9759F4B40
11342	22960	52.755946000000002	52.790207000000002	55.151837	55.132845000000003	Школьная	0103000020E6100000010000000500000061C5A9D6C2604A40F437A11001914B4061C5A9D6C2604A4050A912656F934B40FF08C38025654A4050A912656F934B40FF08C38025654A40F437A11001914B4061C5A9D6C2604A40F437A11001914B40
11340	22830	52.627746999999999	52.654679000000002	55.349189000000003	55.322937000000003	Советская	0103000020E61000000100000005000000C09481035A504A408DD5E6FF55A94B40C09481035A504A40BD8FA339B2AC4B4062307F85CC534A40BD8FA339B2AC4B4062307F85CC534A408DD5E6FF55A94B40C09481035A504A408DD5E6FF55A94B40
11352	22752	50.453761	50.479686999999998	55.960194999999999	55.943849999999998	Г.Тукая	0103000020E61000000100000005000000A29927D7143A4940302AA913D0F84B40A29927D7143A4940306475ABE7FA4B407EA83462663D4940306475ABE7FA4B407EA83462663D4940302AA913D0F84B40A29927D7143A4940302AA913D0F84B40
11328	22431	50.456735000000002	50.491517000000002	56.107894999999999	56.101429000000003	Школьная	0103000020E6100000010000000500000023F8DF4A763A4940D9EE1EA0FB0C4C4023F8DF4A763A49407233DC80CF0D4C40CA367007EA3E49407233DC80CF0D4C40CA367007EA3E4940D9EE1EA0FB0C4C4023F8DF4A763A4940D9EE1EA0FB0C4C40
11336	22481	50.379002999999997	50.424107999999997	56.197308	56.178994000000003	Х. Такташа	0103000020E61000000100000005000000FE0A992B8330494012178046E9164C40FE0A992B833049409D9E776341194C4069FCC22B493649409D9E776341194C4069FCC22B4936494012178046E9164C40FE0A992B8330494012178046E9164C40
11334	22481	50.379002999999997	50.424107999999997	56.197308	56.178994000000003	Фрунзе	0103000020E61000000100000005000000FE0A992B8330494012178046E9164C40FE0A992B833049409D9E776341194C4069FCC22B493649409D9E776341194C4069FCC22B4936494012178046E9164C40FE0A992B8330494012178046E9164C40
11329	22481	50.379002999999997	50.424107999999997	56.197308	56.178994000000003	Первомайская	0103000020E61000000100000005000000FE0A992B8330494012178046E9164C40FE0A992B833049409D9E776341194C4069FCC22B493649409D9E776341194C4069FCC22B4936494012178046E9164C40FE0A992B8330494012178046E9164C40
11331	22481	50.379002999999997	50.424107999999997	56.197308	56.178994000000003	Лермонтова	0103000020E61000000100000005000000FE0A992B8330494012178046E9164C40FE0A992B833049409D9E776341194C4069FCC22B493649409D9E776341194C4069FCC22B4936494012178046E9164C40FE0A992B8330494012178046E9164C40
11303	20921	50.274745000000003	50.297589000000002	55.955514000000001	55.943911	Ленина	0103000020E61000000100000005000000A9DE1AD82A234940D6AA5D13D2F84B40A9DE1AD82A234940616F62484EFA4B401E53776517264940616F62484EFA4B401E53776517264940D6AA5D13D2F84B40A9DE1AD82A234940D6AA5D13D2F84B40
11309	21357	50.523246	50.547285000000002	55.997205000000001	55.987684000000002	Советская	0103000020E61000000100000005000000A4E194B9F94249402864E76D6CFE4B40A4E194B9F94249402F34D769A4FF4B40B24B546F0D4649402F34D769A4FF4B40B24B546F0D4649402864E76D6CFE4B40A4E194B9F94249402864E76D6CFE4B40
11327	22316	50.329704	50.364387999999998	56.051949	56.039389	Пионерская	0103000020E6100000010000000500000021AE9CBD332A49403C69E1B20A054C4021AE9CBD332A4940AB07CC43A6064C4005871744A42E4940AB07CC43A6064C4005871744A42E49403C69E1B20A054C4021AE9CBD332A49403C69E1B20A054C40
11359	32987	50.606510999999998	50.636299000000001	55.877172000000002	55.86009	улица Пушкина	0103000020E6100000010000000500000006D50627A24D4940EECEDA6D17EE4B4006D50627A24D4940C47B0E2C47F04B401FBDE13E72514940C47B0E2C47F04B401FBDE13E72514940EECEDA6D17EE4B4006D50627A24D4940EECEDA6D17EE4B40
79234	61484	50.255789999999998	50.273136999999998	56.068142999999999	56.053015000000002	Школьная	0103000020E6100000010000000500000069520ABABD20494046990D32C9064C4069520ABABD204940C539EAE8B8084C40ED293927F6224940C539EAE8B8084C40ED293927F622494046990D32C9064C4069520ABABD20494046990D32C9064C40
11323	22180	50.413156999999998	50.436154000000002	55.938288999999997	55.923352000000001	Советская	0103000020E61000000100000005000000868E1D54E23449401D59F96530F64B40868E1D54E234494028999CDA19F84B408202EFE4D337494028999CDA19F84B408202EFE4D33749401D59F96530F64B40868E1D54E23449401D59F96530F64B40
11313	21641	50.596054000000002	50.615304999999999	56.037985999999997	56.027887	Школьная	0103000020E6100000010000000500000033535A7F4B4C4940E57D1CCD91034C4033535A7F4B4C494059DAA9B9DC044C405B087250C24E494059DAA9B9DC044C405B087250C24E4940E57D1CCD91034C4033535A7F4B4C4940E57D1CCD91034C40
11307	21223	50.410049000000001	50.426766999999998	56.143082	56.134098999999999	Ленина	0103000020E61000000100000005000000F660527C7C34494091B6F1272A114C40F660527C7C344940B952CF8250124C408A01124DA0364940B952CF8250124C408A01124DA036494091B6F1272A114C40F660527C7C34494091B6F1272A114C40
11311	21550	50.287922999999999	50.314585000000001	56.125349999999997	56.113838000000001	М. Джалиля	0103000020E6100000010000000500000013622EA9DA24494062855B3E920E4C4013622EA9DA244940DC4603780B104C40F5673F5244284940DC4603780B104C40F5673F524428494062855B3E920E4C4013622EA9DA24494062855B3E920E4C40
11316	21808	50.483711	50.508001	55.892890000000001	55.877395	Тукая	0103000020E6100000010000000500000094DBF63DEA3D49404356B77A4EF04B4094DBF63DEA3D4940757632384AF24B40EBAA402D06414940757632384AF24B40EBAA402D064149404356B77A4EF04B4094DBF63DEA3D49404356B77A4EF04B40
11337	22712	50.339818999999999	50.356212999999997	56.164029999999997	56.157758999999999	Советская	0103000020E610000001000000050000009BC761307F2B494028D3687231144C409BC761307F2B49400CC85EEFFE144C407CB43863982D49400CC85EEFFE144C407CB43863982D494028D3687231144C409BC761307F2B494028D3687231144C40
79232	61482	50.313479999999998	50.330601999999999	56.027112000000002	56.015856999999997	Татарстан	0103000020E610000001000000050000009CF9D51C20284940D234289A07024C409CF9D51C2028494022AAF06778034C4000FF942A512A494022AAF06778034C4000FF942A512A4940D234289A07024C409CF9D51C20284940D234289A07024C40
11324	22227	50.424925000000002	50.442414999999997	55.867494999999998	55.858694999999997	Чапаева	0103000020E610000001000000050000005C2041F1633649408E1EBFB7E9ED4B405C2041F163364940C5387F130AEF4B404221020EA1384940C5387F130AEF4B404221020EA13849408E1EBFB7E9ED4B405C2041F1633649408E1EBFB7E9ED4B40
11315	40912	50.682741999999998	50.702981000000001	56.053139999999999	56.035004000000001	Детсадовская	0103000020E6100000010000000500000085CD001764574940569DD5027B044C4085CD001764574940020EA14ACD064C40CD5A0A48FB594940020EA14ACD064C40CD5A0A48FB594940569DD5027B044C4085CD001764574940569DD5027B044C40
79142	22363	50.354632000000002	50.375490999999997	56.081788000000003	56.065952000000003	Ленина	0103000020E61000000100000005000000BB0ED594642D49408B8D791D71084C40BB0ED594642D4940469A7807780A4C409E78CE1610304940469A7807780A4C409E78CE16103049408B8D791D71084C40BB0ED594642D49408B8D791D71084C40
11314	21745	50.263947000000002	50.279677	56.097814	56.087207999999997	Школьная	0103000020E610000001000000050000004C70EA03C92149408BF9B9A1290B4C404C70EA03C9214940A48B4D2B850C4C40C138B874CC234940A48B4D2B850C4C40C138B874CC2349408BF9B9A1290B4C404C70EA03C92149408BF9B9A1290B4C40
11310	21453	50.284185999999998	50.303859000000003	56.153176999999999	56.143484000000001	Советская	0103000020E6100000010000000500000093FDF33460244940E8BF07AF5D124C4093FDF33460244940ECBFCE4D9B134C4032CC09DAE4264940ECBFCE4D9B134C4032CC09DAE4264940E8BF07AF5D124C4093FDF33460244940E8BF07AF5D124C40
79161	61425	50.166156999999998	50.187976999999997	56.116652999999999	56.105314999999997	Школьная	0103000020E610000001000000050000003080F0A1441549409D6340F67A0D4C403080F0A1441549407AFD497CEE0E4C4039B35DA10F1849407AFD497CEE0E4C4039B35DA10F1849409D6340F67A0D4C403080F0A1441549409D6340F67A0D4C40
11308	21321	50.556258999999997	50.580316000000003	56.026693999999999	56.017356999999997	Кооперативная	0103000020E61000000100000005000000868DB27E33474940A7AD11C138024C40868DB27E33474940ED7F80B56A034C403BAC70CB474A4940ED7F80B56A034C403BAC70CB474A4940A7AD11C138024C40868DB27E33474940A7AD11C138024C40
79122	61394	50.408208000000002	50.427520999999999	56.103397000000001	56.086319000000003	Восьмого Марта	0103000020E6100000010000000500000098FBE42840344940000341800C0B4C4098FBE4284034494094C0E61C3C0D4C4036AD1402B936494094C0E61C3C0D4C4036AD1402B9364940000341800C0B4C4098FBE42840344940000341800C0B4C40
79228	61479	50.381625999999997	50.403734	56.111449	56.101568999999998	Школьная	0103000020E61000000100000005000000D2A6EA1ED9304940CAA48636000D4C40D2A6EA1ED93049400116F9F5430E4C404224438EAD3349400116F9F5430E4C404224438EAD334940CAA48636000D4C40D2A6EA1ED9304940CAA48636000D4C40
11306	21082	50.533557999999999	50.565708999999998	56.116517999999999	56.109506000000003	Ш. Бариева	0103000020E610000001000000050000007442E8A04B4449409F5BE84A040E4C407442E8A04B4449409AB2D30FEA0E4C40C4060B27694849409AB2D30FEA0E4C40C4060B27694849409F5BE84A040E4C407442E8A04B4449409F5BE84A040E4C40
11299	20686	50.648668999999998	50.660868000000001	55.951118999999998	55.934244999999997	Школьная	0103000020E61000000100000005000000EA76F69507534940CBB9145795F74B40EA76F6950753494057CD7344BEF94B40897C97529754494057CD7344BEF94B40897C975297544940CBB9145795F74B40EA76F69507534940CBB9145795F74B40
11304	21048	50.169175000000003	50.202260000000003	56.061312999999998	56.048872000000003	Советская	0103000020E610000001000000050000008126C286A715494056D80C7041064C408126C286A7154940EAE8B81AD9074C40FDA4DAA7E3194940EAE8B81AD9074C40FDA4DAA7E319494056D80C7041064C408126C286A715494056D80C7041064C40
11317	21903	50.506366	50.529919999999997	55.912157999999998	55.898688999999997	Ленина	0103000020E6100000010000000500000036E7E099D04049403123BC3D08F34B4036E7E099D04049407364E597C1F44B4087BF266BD44349407364E597C1F44B4087BF266BD44349403123BC3D08F34B4036E7E099D04049403123BC3D08F34B40
11302	20903	50.258090000000003	50.277898	55.994903999999998	55.981157000000003	Кооперативная	0103000020E610000001000000050000005BB6D61709214940E99E758D96FD4B405BB6D617092149406D54A70359FF4B40D9CF6229922349406D54A70359FF4B40D9CF622992234940E99E758D96FD4B405BB6D61709214940E99E758D96FD4B40
11301	20809	50.704453999999998	50.723686999999998	55.973683000000001	55.958598000000002	М. Джалиля	0103000020E61000000100000005000000A8C4758C2B5A49406901DA56B3FA4B40A8C4758C2B5A4940E9D500A5A1FC4B402AC58EC6A15C4940E9D500A5A1FC4B402AC58EC6A15C49406901DA56B3FA4B40A8C4758C2B5A49406901DA56B3FA4B40
11300	20792	50.622518999999997	50.653699000000003	55.834026999999999	55.821032000000002	Ф. Энгельса	0103000020E61000000100000005000000BE11DDB3AE4F4940187C9A9317E94B40BE11DDB3AE4F4940917D9065C1EA4B40C636A968AC534940917D9065C1EA4B40C636A968AC534940187C9A9317E94B40BE11DDB3AE4F4940187C9A9317E94B40
11320	21946	50.427342000000003	50.46358	56.020626999999998	55.990729999999999	Школьная	0103000020E61000000100000005000000871A8524B336494042959A3DD0FE4B40871A8524B33649401135D1E7A3024C40338AE596563B49401135D1E7A3024C40338AE596563B494042959A3DD0FE4B40871A8524B336494042959A3DD0FE4B40
11322	21946	50.427342000000003	50.46358	56.020626999999998	55.990729999999999	М. Джалиля	0103000020E61000000100000005000000871A8524B336494042959A3DD0FE4B40871A8524B33649401135D1E7A3024C40338AE596563B49401135D1E7A3024C40338AE596563B494042959A3DD0FE4B40871A8524B336494042959A3DD0FE4B40
11321	21946	50.427342000000003	50.46358	56.020626999999998	55.990729999999999	Кол Гали	0103000020E61000000100000005000000871A8524B336494042959A3DD0FE4B40871A8524B33649401135D1E7A3024C40338AE596563B49401135D1E7A3024C40338AE596563B494042959A3DD0FE4B40871A8524B336494042959A3DD0FE4B40
11319	21946	50.427342000000003	50.46358	56.020626999999998	55.990729999999999	З. Юсупова	0103000020E61000000100000005000000871A8524B336494042959A3DD0FE4B40871A8524B33649401135D1E7A3024C40338AE596563B49401135D1E7A3024C40338AE596563B494042959A3DD0FE4B40871A8524B336494042959A3DD0FE4B40
11318	21946	50.427342000000003	50.46358	56.020626999999998	55.990729999999999	Г. Закирова	0103000020E61000000100000005000000871A8524B336494042959A3DD0FE4B40871A8524B33649401135D1E7A3024C40338AE596563B49401135D1E7A3024C40338AE596563B494042959A3DD0FE4B40871A8524B336494042959A3DD0FE4B40
11237	17139	50.188065999999999	50.208539000000002	55.567860000000003	55.554938999999997	40 лет Победы	0103000020E61000000100000005000000A9BEF38B121849403123BC3D08C74B40A9BEF38B12184940715AF0A2AFC84B406478EC67B11A4940715AF0A2AFC84B406478EC67B11A49403123BC3D08C74B40A9BEF38B121849403123BC3D08C74B40
11294	20489	50.435192999999998	50.457363000000001	55.640523000000002	55.626694999999998	Татарстан	0103000020E610000001000000050000005C397B67B43749408AC8B08A37D04B405C397B67B4374940FCAA5CA8FCD14B4042B3EBDE8A3A4940FCAA5CA8FCD14B4042B3EBDE8A3A49408AC8B08A37D04B405C397B67B43749408AC8B08A37D04B40
11292	20454	50.450921999999998	50.483162999999998	55.608047999999997	55.595602999999997	Татарстан	0103000020E610000001000000050000000186E5CFB7394940223317B83CCC4B400186E5CFB7394940F8325184D4CD4B4091D10149D83D4940F8325184D4CD4B4091D10149D83D4940223317B83CCC4B400186E5CFB7394940223317B83CCC4B40
11650	40909	49.782494999999997	49.803739999999998	55.610433	55.599662000000002	М.Джалиля	0103000020E610000001000000050000004A24D1CB28E44840B55373B9C1CC4B404A24D1CB28E4484018B325AB22CE4B40573ECBF3E0E6484018B325AB22CE4B40573ECBF3E0E64840B55373B9C1CC4B404A24D1CB28E44840B55373B9C1CC4B40
11291	20343	50.050004000000001	50.074618000000001	55.590271999999999	55.575760000000002	Центральная	0103000020E61000000100000005000000A855F48766064940282CF180B2C94B40A855F487660649404CDF6B088ECB4B40B2D826158D0949404CDF6B088ECB4B40B2D826158D094940282CF180B2C94B40A855F48766064940282CF180B2C94B40
11289	20131	50.666006000000003	50.696826999999999	55.573872000000001	55.556044	Советская	0103000020E610000001000000050000004B7842AF3F5549408A9125732CC74B404B7842AF3F554940890B40A374C94B4022FC8BA031594940890B40A374C94B4022FC8BA0315949408A9125732CC74B404B7842AF3F5549408A9125732CC74B40
11257	18101	49.875632000000003	49.889583000000002	55.597124000000001	55.589697000000001	Советская	0103000020E6100000010000000500000061AA99B514F0484050C6F8307BCB4B4061AA99B514F048400FD4298F6ECC4B40EE0912DBDDF148400FD4298F6ECC4B40EE0912DBDDF1484050C6F8307BCB4B4061AA99B514F0484050C6F8307BCB4B40
11281	19696	50.583936000000001	50.602728999999997	55.739676000000003	55.721730999999998	Советская	0103000020E61000000100000005000000817A336ABE4A494033C170AE61DC4B40817A336ABE4A49406CD102B4ADDE4B40E6AC4F39264D49406CD102B4ADDE4B40E6AC4F39264D494033C170AE61DC4B40817A336ABE4A494033C170AE61DC4B40
11278	19423	50.431142000000001	50.452880999999998	55.503492000000001	55.488616	Советская	0103000020E610000001000000050000004DF73AA92F374940B32616F88ABE4B404DF73AA92F37494019E6046D72C04B4069FD2D01F839494019E6046D72C04B4069FD2D01F8394940B32616F88ABE4B404DF73AA92F374940B32616F88ABE4B40
11276	19394	50.222966	50.251612999999999	55.461793	55.451185000000002	Прикамская	0103000020E610000001000000050000005A0F5F268A1C49400FB9196EC0B94B405A0F5F268A1C4940C84274081CBB4B40CD1FD3DA34204940C84274081CBB4B40CD1FD3DA342049400FB9196EC0B94B405A0F5F268A1C49400FB9196EC0B94B40
79303	61524	50.644078	50.666321000000003	55.650962999999997	55.641314999999999	Гагарина	0103000020E610000001000000050000005B09DD257152494095B7239C16D24B405B09DD2571524940F9F36DC152D34B40ABD1AB014A554940F9F36DC152D34B40ABD1AB014A55494095B7239C16D24B405B09DD257152494095B7239C16D24B40
11284	19850	50.579740999999999	50.600411000000001	55.702764000000002	55.688228000000002	Ленина	0103000020E610000001000000050000003E93FDF3344A49408318E8DA17D84B403E93FDF3344A49403067B62BF4D94B404F948444DA4C49403067B62BF4D94B404F948444DA4C49408318E8DA17D84B403E93FDF3344A49408318E8DA17D84B40
11235	17043	50.158287000000001	50.185434000000001	55.611998999999997	55.599260000000001	Центральная	0103000020E61000000100000005000000E43098BF4214494086E63A8DB4CC4B40E43098BF42144940A417B5FB55CE4B4082C8224DBC174940A417B5FB55CE4B4082C8224DBC17494086E63A8DB4CC4B40E43098BF4214494086E63A8DB4CC4B40
11295	40911	50.661451999999997	50.674782999999998	55.547611000000003	55.539924999999997	Лесная	0103000020E61000000100000005000000D8EF8975AA5449407AA52C431CC54B40D8EF8975AA54494006F7031E18C64B40C972124A5F56494006F7031E18C64B40C972124A5F5649407AA52C431CC54B40D8EF8975AA5449407AA52C431CC54B40
77573	40906	50.121133	50.167350999999996	55.469790000000003	55.452201000000002	Ленина	0103000020E61000000100000005000000B2BB4049810F4940F81BEDB8E1B94B40B2BB4049810F494072FE261422BC4B40F8F9EFC16B15494072FE261422BC4B40F8F9EFC16B154940F81BEDB8E1B94B40B2BB4049810F4940F81BEDB8E1B94B40
78548	40906	50.121133	50.167350999999996	55.469790000000003	55.452201000000002	Заводская	0103000020E61000000100000005000000B2BB4049810F4940F81BEDB8E1B94B40B2BB4049810F494072FE261422BC4B40F8F9EFC16B15494072FE261422BC4B40F8F9EFC16B154940F81BEDB8E1B94B40B2BB4049810F4940F81BEDB8E1B94B40
12183	40906	50.121133	50.167350999999996	55.469790000000003	55.452201000000002	З.Шаймарданова	0103000020E61000000100000005000000B2BB4049810F4940F81BEDB8E1B94B40B2BB4049810F494072FE261422BC4B40F8F9EFC16B15494072FE261422BC4B40F8F9EFC16B154940F81BEDB8E1B94B40B2BB4049810F4940F81BEDB8E1B94B40
78041	40906	50.121133	50.167350999999996	55.469790000000003	55.452201000000002	Больничный переулок	0103000020E61000000100000005000000B2BB4049810F4940F81BEDB8E1B94B40B2BB4049810F494072FE261422BC4B40F8F9EFC16B15494072FE261422BC4B40F8F9EFC16B154940F81BEDB8E1B94B40B2BB4049810F4940F81BEDB8E1B94B40
11277	40906	50.121133	50.167350999999996	55.469790000000003	55.452201000000002	60 лет Октября	0103000020E61000000100000005000000B2BB4049810F4940F81BEDB8E1B94B40B2BB4049810F494072FE261422BC4B40F8F9EFC16B15494072FE261422BC4B40F8F9EFC16B154940F81BEDB8E1B94B40B2BB4049810F4940F81BEDB8E1B94B40
79058	18939	50.012230000000002	50.043213000000002	55.48001	55.462609999999998	Хай Вахита	0103000020E61000000100000005000000DA03ADC090014940BA66F2CD36BB4B40DA03ADC09001494061E0B9F770BD4B408BE1EA008805494061E0B9F770BD4B408BE1EA0088054940BA66F2CD36BB4B40DA03ADC090014940BA66F2CD36BB4B40
11272	18939	50.012230000000002	50.043213000000002	55.48001	55.462609999999998	Профсоюзная	0103000020E61000000100000005000000DA03ADC090014940BA66F2CD36BB4B40DA03ADC09001494061E0B9F770BD4B408BE1EA008805494061E0B9F770BD4B408BE1EA0088054940BA66F2CD36BB4B40DA03ADC090014940BA66F2CD36BB4B40
11297	20597	50.100813000000002	50.114871999999998	55.472780999999998	55.464140999999998	Механизаторов	0103000020E610000001000000050000007E01BD70E70C4940CADDE7F868BB4B407E01BD70E70C4940C8957A1684BC4B40F19C2D20B40E4940C8957A1684BC4B40F19C2D20B40E4940CADDE7F868BB4B407E01BD70E70C4940CADDE7F868BB4B40
11241	17336	50.628582000000002	50.662224000000002	55.576976000000002	55.566527000000001	Калинина	0103000020E61000000100000005000000596DFE5F7550494087A6ECF483C84B40596DFE5F75504940D8497D59DAC94B402B508BC1C3544940D8497D59DAC94B402B508BC1C354494087A6ECF483C84B40596DFE5F7550494087A6ECF483C84B40
11270	18826	50.287239999999997	50.312078999999997	55.662557	55.645724999999999	Центральная	0103000020E61000000100000005000000300DC347C4244940D49AE61DA7D24B40300DC347C4244940315EF3AACED44B405A626534F2274940315EF3AACED44B405A626534F2274940D49AE61DA7D24B40300DC347C4244940D49AE61DA7D24B40
79120	61393	49.811627000000001	49.828372000000002	55.601213000000001	55.589345999999999	Школьная	0103000020E610000001000000050000007AC6BE64E3E74840A30392B06FCB4B407AC6BE64E3E748400C772E8CF4CC4B400876FC1708EA48400C772E8CF4CC4B400876FC1708EA4840A30392B06FCB4B407AC6BE64E3E74840A30392B06FCB4B40
11269	18725	50.393025999999999	50.410497999999997	55.583668000000003	55.569031000000003	Школьная	0103000020E61000000100000005000000253D0CAD4E32494081B4FF01D6C84B40253D0CAD4E32494062DC0DA2B5CA4B406589CE328B34494062DC0DA2B5CA4B406589CE328B34494081B4FF01D6C84B40253D0CAD4E32494081B4FF01D6C84B40
11279	19533	50.466983999999997	50.492811000000003	55.516103999999999	55.498801	Кирова	0103000020E61000000100000005000000ACE0B721C63B4940261B0FB6D8BF4B40ACE0B721C63B4940DAAA24B20FC24B40F60D4C6E143F4940DAAA24B20FC24B40F60D4C6E143F4940261B0FB6D8BF4B40ACE0B721C63B4940261B0FB6D8BF4B40
11265	18414	49.976441000000001	50.019784999999999	55.445079	55.423228000000002	Центральная	0103000020E610000001000000050000009DBCC804FCFC48403160C9552CB64B409DBCC804FCFC484075914259F8B84B40C6F99B508802494075914259F8B84B40C6F99B50880249403160C9552CB64B409DBCC804FCFC48403160C9552CB64B40
11263	18392	50.668225	50.690162000000001	55.656132999999997	55.641376000000001	Центральная	0103000020E610000001000000050000004FAF9465885549403B38D89B18D24B404FAF946588554940C669882AFCD34B409278793A57584940C669882AFCD34B409278793A575849403B38D89B18D24B404FAF9465885549403B38D89B18D24B40
11250	17745	49.975157000000003	49.993563000000002	55.526485000000001	55.512321999999998	Красноармейская	0103000020E6100000010000000500000095BBCFF1D1FC4840BA826DC493C14B4095BBCFF1D1FC4840D36A48DC63C34B4001C287122DFF4840D36A48DC63C34B4001C287122DFF4840BA826DC493C14B4095BBCFF1D1FC4840BA826DC493C14B40
11238	17211	50.143321	50.163336000000001	55.561273	55.550891	Гагарина	0103000020E610000001000000050000003EEAAF57581249409354A69883C64B403EEAAF57581249405C902DCBD7C74B403621AD31E81449405C902DCBD7C74B403621AD31E81449409354A69883C64B403EEAAF57581249409354A69883C64B40
11260	18209	50.600869000000003	50.665349999999997	55.644907000000003	55.622436	Советская	0103000020E6100000010000000500000012178046E94C494031ED9BFBABCF4B4012178046E94C494012FB04508CD24B40613255302A55494012FB04508CD24B40613255302A55494031ED9BFBABCF4B4012178046E94C494031ED9BFBABCF4B40
11296	20587	50.406185999999998	50.437761999999999	55.666716000000001	55.653334999999998	Н. Гиззатуллина	0103000020E61000000100000005000000E90B21E7FD334940842A357BA0D34B40E90B21E7FD33494027DC2BF356D54B403DB7D0950838494027DC2BF356D54B403DB7D09508384940842A357BA0D34B40E90B21E7FD334940842A357BA0D34B40
11258	18116	50.44997	50.481482999999997	55.560336	55.537591999999997	Советская	0103000020E610000001000000050000002F17F19D98394940AD4B8DD0CFC44B402F17F19D98394940BF620D17B9C74B403C4A253CA13D4940BF620D17B9C74B403C4A253CA13D4940AD4B8DD0CFC44B402F17F19D98394940AD4B8DD0CFC44B40
11256	18022	49.879055000000001	49.908169000000001	55.560386999999999	55.541702999999998	Совхозная	0103000020E610000001000000050000005131CEDF84F0484092921E8656C54B405131CEDF84F04840410DDFC2BAC74B40DA1EBDE13EF44840410DDFC2BAC74B40DA1EBDE13EF4484092921E8656C54B405131CEDF84F0484092921E8656C54B40
11253	17915	50.520325999999997	50.548802999999999	55.650906999999997	55.638668000000003	Иванова	0103000020E6100000010000000500000016A1D80A9A42494039807EDFBFD14B4016A1D80A9A42494065DEAAEB50D34B402D793C2D3F46494065DEAAEB50D34B402D793C2D3F46494039807EDFBFD14B4016A1D80A9A42494039807EDFBFD14B40
11280	40907	50.515861999999998	50.533765000000002	55.578125999999997	55.568420000000003	Г.Тукая	0103000020E61000000100000005000000E49F19C40742494038328FFCC1C84B40E49F19C407424940D07B630800CA4B40EE5F596952444940D07B630800CA4B40EE5F59695244494038328FFCC1C84B40E49F19C40742494038328FFCC1C84B40
11244	17513	50.237492000000003	50.261854	55.489702999999999	55.477077000000001	Садовый переулок	0103000020E61000000100000005000000E4874A23661E49403F56F0DB10BD4B40E4874A23661E494065E08096AEBE4B40D4298F6E8421494065E08096AEBE4B40D4298F6E842149403F56F0DB10BD4B40E4874A23661E49403F56F0DB10BD4B40
11268	18615	50.372751000000001	50.400706999999997	55.603816999999999	55.584384999999997	Советская	0103000020E610000001000000050000009146054EB62F4940F0A2AF20CDCA4B409146054EB62F494069E21DE049CD4B409E23F25D4A33494069E21DE049CD4B409E23F25D4A334940F0A2AF20CDCA4B409146054EB62F4940F0A2AF20CDCA4B40
11262	17818	49.922488999999999	49.940939999999998	55.622787000000002	55.610391999999997	Шарафеева	0103000020E61000000100000005000000BAF59A1E14F64840B9DE365321CE4B40BAF59A1E14F64840DEAF027CB7CF4B40C6BFCFB870F84840DEAF027CB7CF4B40C6BFCFB870F84840B9DE365321CE4B40BAF59A1E14F64840B9DE365321CE4B40
11249	17725	49.919542	49.951450000000001	55.530994	55.511949999999999	Г.Тукая	0103000020E6100000010000000500000033A6608DB3F54840F697DD9387C14B4033A6608DB3F54840A52F849CF7C34B40BDE3141DC9F94840A52F849CF7C34B40BDE3141DC9F94840F697DD9387C14B4033A6608DB3F54840F697DD9387C14B40
11246	17536	50.682381999999997	50.704040999999997	55.692582000000002	55.681559	Ленина	0103000020E6100000010000000500000085B01A4B58574940B1A547533DD74B4085B01A4B585749402EE6E786A6D84B408505F7031E5A49402EE6E786A6D84B408505F7031E5A4940B1A547533DD74B4085B01A4B58574940B1A547533DD74B40
11243	17432	50.346403000000002	50.372858999999998	55.520538000000002	55.509278000000002	Школьная	0103000020E610000001000000050000003F1EFAEE562C49404149810530C14B403F1EFAEE562C4940A2293BFDA0C24B407782FDD7B92F4940A2293BFDA0C24B407782FDD7B92F49404149810530C14B403F1EFAEE562C49404149810530C14B40
11242	17402	49.859166000000002	49.897381000000003	55.434313000000003	55.418390000000002	Октябрьская	0103000020E61000000100000005000000E6EAC726F9ED48409A7CB3CD8DB54B40E6EAC726F9ED4840249D819197B74B40A1866F61DDF24840249D819197B74B40A1866F61DDF248409A7CB3CD8DB54B40E6EAC726F9ED48409A7CB3CD8DB54B40
11247	17625	50.677225999999997	50.701382000000002	55.672296000000003	55.656300999999999	Горького	0103000020E610000001000000050000001D007157AF56494082AAD1AB01D44B401D007157AF564940A69D9ACB0DD64B406500A8E2C6594940A69D9ACB0DD64B406500A8E2C659494082AAD1AB01D44B401D007157AF56494082AAD1AB01D44B40
11240	17310	50.662430999999998	50.68797	55.616092000000002	55.599524000000002	Сафиуллина	0103000020E61000000100000005000000A46DFC89CA5449406495D233BDCC4B40A46DFC89CA544940E3A9471ADCCE4B408750A5660F584940E3A9471ADCCE4B408750A5660F5849406495D233BDCC4B40A46DFC89CA5449406495D233BDCC4B40
11236	17115	50.167485999999997	50.189242999999998	55.523370999999997	55.508549000000002	Мира	0103000020E61000000100000005000000D844662E70154940EEB4352218C14B40D844662E70154940605628D2FDC24B409BFF571D39184940605628D2FDC24B409BFF571D39184940EEB4352218C14B40D844662E70154940EEB4352218C14B40
11255	18010	50.585355	50.607911999999999	55.662526999999997	55.651302999999999	Школьная	0103000020E6100000010000000500000069C6A2E9EC4A4940B2648EE55DD34B4069C6A2E9EC4A4940C6DB4AAFCDD44B40486C770FD04D4940C6DB4AAFCDD44B40486C770FD04D4940B2648EE55DD34B4069C6A2E9EC4A4940B2648EE55DD34B40
11234	17018	50.102682000000001	50.118537000000003	55.597648	55.583072000000001	Центральная	0103000020E61000000100000005000000A6F10BAF240D49404E9B711AA2CA4B40A6F10BAF240D49408942CBBA7FCC4B40D82E6D382C0F49408942CBBA7FCC4B40D82E6D382C0F49404E9B711AA2CA4B40A6F10BAF240D49404E9B711AA2CA4B40
11233	16948	50.121025000000003	50.143662999999997	55.489356000000001	55.470331000000002	Клубная	0103000020E61000000100000005000000CC7F48BF7D0F4940C2A563CE33BC4B40CC7F48BF7D0F4940FA0CA837A3BE4B409752978C63124940FA0CA837A3BE4B409752978C63124940C2A563CE33BC4B40CC7F48BF7D0F4940C2A563CE33BC4B40
11283	19813	50.532623999999998	50.553311999999998	55.700811000000002	55.686259	Якова Емельянова	0103000020E610000001000000050000004888F2052D444940F7CABC55D7D74B404888F2052D444940AAD6C22CB4D94B40FF3D78EDD2464940AAD6C22CB4D94B40FF3D78EDD2464940F7CABC55D7D74B404888F2052D444940F7CABC55D7D74B40
11232	16920	50.118859999999998	50.149672000000002	55.770010999999997	55.758938999999998	Центральная	0103000020E61000000100000005000000BA66F2CD360F49405854C4E924E14B40BA66F2CD360F4940B6476FB88FE24B403F90BC7328134940B6476FB88FE24B403F90BC73281349405854C4E924E14B40BA66F2CD360F49405854C4E924E14B40
11230	16724	49.643183999999998	49.676188000000003	55.697462999999999	55.665649999999999	Хайруллина	0103000020E61000000100000005000000BDA772DA53D248408C4AEA0434D54B40BDA772DA53D24840C495B37746D94B404DF910548DD64840C495B37746D94B404DF910548DD648408C4AEA0434D54B40BDA772DA53D248408C4AEA0434D54B40
9720	16639	49.894120000000001	49.917313999999998	55.735312	55.719835000000003	Кооперативная	0103000020E610000001000000050000008A592F8672F2484012C2A38D23DC4B408A592F8672F248409D2D20B41EDE4B40DB148F8B6AF548409D2D20B41EDE4B40DB148F8B6AF5484012C2A38D23DC4B408A592F8672F2484012C2A38D23DC4B40
11229	16617	49.811357999999998	49.828408000000003	55.836154999999998	55.821133000000003	Советская	0103000020E610000001000000050000008AAC3594DAE748404C55DAE21AE94B408AAC3594DAE7484085B1852007EB4B4055DFF94509EA484085B1852007EB4B4055DFF94509EA48404C55DAE21AE94B408AAC3594DAE748404C55DAE21AE94B40
11231	16826	49.495716999999999	49.525280000000002	55.8371	55.818012000000003	Центральная	0103000020E610000001000000050000001E8997A773BF484027DE019EB4E84B401E8997A773BF4840A5BDC11726EB4B40179F02603CC34840A5BDC11726EB4B40179F02603CC3484027DE019EB4E84B401E8997A773BF484027DE019EB4E84B40
11226	16514	49.840705999999997	49.860801000000002	55.780912000000001	55.768875999999999	Советская	0103000020E6100000010000000500000086C613419CEB4840F3565D876AE24B4086C613419CEB4840E886A6ECF4E34B409BAE27BA2EEE4840E886A6ECF4E34B409BAE27BA2EEE4840F3565D876AE24B4086C613419CEB4840F3565D876AE24B40
11225	16225	49.633105	49.683546	55.765614999999997	55.742904000000003	Советская	0103000020E6100000010000000500000090F7AA9509D14840A708707A17DF4B4090F7AA9509D14840DC291DACFFE14B40E3A7716F7ED74840DC291DACFFE14B40E3A7716F7ED74840A708707A17DF4B4090F7AA9509D14840A708707A17DF4B40
11224	16225	49.633105	49.683546	55.765614999999997	55.742904000000003	Молодежная	0103000020E6100000010000000500000090F7AA9509D14840A708707A17DF4B4090F7AA9509D14840DC291DACFFE14B40E3A7716F7ED74840DC291DACFFE14B40E3A7716F7ED74840A708707A17DF4B4090F7AA9509D14840A708707A17DF4B40
11223	16225	49.633105	49.683546	55.765614999999997	55.742904000000003	Казанская	0103000020E6100000010000000500000090F7AA9509D14840A708707A17DF4B4090F7AA9509D14840DC291DACFFE14B40E3A7716F7ED74840DC291DACFFE14B40E3A7716F7ED74840A708707A17DF4B4090F7AA9509D14840A708707A17DF4B40
11222	16204	49.931139000000002	49.949654000000002	55.831474	55.820430000000002	Центральная	0103000020E61000000100000005000000DC8310902FF748402254A9D903E94B40DC8310902FF74840B6BC72BD6DEA4B40FF4124438EF94840B6BC72BD6DEA4B40FF4124438EF948402254A9D903E94B40DC8310902FF748402254A9D903E94B40
11221	16132	50.017611000000002	50.040742999999999	55.695210000000003	55.677838999999999	Центральная	0103000020E610000001000000050000006286C61341024940077AA86DC3D64B406286C6134102494014ED2AA4FCD84B403D450E113705494014ED2AA4FCD84B403D450E1137054940077AA86DC3D64B406286C61341024940077AA86DC3D64B40
11220	16110	49.743400000000001	49.755859999999998	55.860933000000003	55.851055000000002	Школьная	0103000020E6100000010000000500000057EC2FBB27DF4840740CC85EEFEC4B4057EC2FBB27DF48400A86730D33EE4B40622D3E05C0E048400A86730D33EE4B40622D3E05C0E04840740CC85EEFEC4B4057EC2FBB27DF4840740CC85EEFEC4B40
11218	16010	49.673332000000002	49.700802000000003	55.835169	55.819737000000003	Центральная	0103000020E61000000100000005000000D6AC33BE2FD648401C295B24EDE84B40D6AC33BE2FD6484007D15AD1E6EA4B40577C43E1B3D9484007D15AD1E6EA4B40577C43E1B3D948401C295B24EDE84B40D6AC33BE2FD648401C295B24EDE84B40
11219	16010	49.673332000000002	49.700802000000003	55.835169	55.819737000000003	Техническая	0103000020E61000000100000005000000D6AC33BE2FD648401C295B24EDE84B40D6AC33BE2FD6484007D15AD1E6EA4B40577C43E1B3D9484007D15AD1E6EA4B40577C43E1B3D948401C295B24EDE84B40D6AC33BE2FD648401C295B24EDE84B40
11217	15938	49.558303000000002	49.584721999999999	55.721229000000001	55.703626	Молодежная	0103000020E610000001000000050000001D21037976C74840C24EB16A10DA4B401D21037976C74840A1F65B3B51DC4B4038A0A52BD8CA4840A1F65B3B51DC4B4038A0A52BD8CA4840C24EB16A10DA4B401D21037976C74840C24EB16A10DA4B40
11216	15916	49.920171000000003	49.947308999999997	55.710600999999997	55.695377000000001	Татарстан	0103000020E6100000010000000500000023DDCF29C8F54840FFB1101D02D94B4023DDCF29C8F54840A0C03BF9F4DA4B406D1ADB6B41F94840A0C03BF9F4DA4B406D1ADB6B41F94840FFB1101D02D94B4023DDCF29C8F54840FFB1101D02D94B40
11215	15834	49.398322	49.411400999999998	55.818193999999998	55.807056000000003	Центральная	0103000020E610000001000000050000007FA31D37FCB2484032056B9C4DE74B407FA31D37FCB2484047E4BB94BAE84B405645B8C9A8B4484047E4BB94BAE84B405645B8C9A8B4484032056B9C4DE74B407FA31D37FCB2484032056B9C4DE74B40
11214	15809	49.704683000000003	49.730510000000002	55.729680999999999	55.705984999999998	Советская	0103000020E610000001000000050000000A86730D33DA4840B83B6BB75DDA4B400A86730D33DA48409CC1DF2F66DD4B4053B3075A81DD48409CC1DF2F66DD4B4053B3075A81DD4840B83B6BB75DDA4B400A86730D33DA4840B83B6BB75DDA4B40
11213	15746	50.036745000000003	50.057029	55.815372000000004	55.797325999999998	Школьная	0103000020E6100000010000000500000051A5660FB4044940102043C70EE64B4051A5660FB40449407D09151C5EE84B4038F6ECB94C0749407D09151C5EE84B4038F6ECB94C074940102043C70EE64B4051A5660FB4044940102043C70EE64B40
11212	15722	49.817278000000002	49.836815999999999	55.920915999999998	55.909967999999999	Тукая	0103000020E61000000100000005000000C2DEC4909CE848400934D8D479F44B40C2DEC4909CE848407B2E5393E0F54B40806264C91CEB48407B2E5393E0F54B40806264C91CEB48400934D8D479F44B40C2DEC4909CE848400934D8D479F44B40
11211	15651	49.969487999999998	49.990850000000002	55.763978999999999	55.746015	Пионерская	0103000020E61000000100000005000000A6EECA2E18FC4840A8A9656B7DDF4B40A6EECA2E18FC484057EA5910CAE14B40ED9E3C2CD4FE484057EA5910CAE14B40ED9E3C2CD4FE4840A8A9656B7DDF4B40A6EECA2E18FC4840A8A9656B7DDF4B40
11209	15565	49.523609999999998	49.536949999999997	55.662247000000001	55.652090000000001	Советская	0103000020E61000000100000005000000E5ED08A705C348403A0664AF77D34B40E5ED08A705C34840E36F7B82C4D44B4029CB10C7BAC44840E36F7B82C4D44B4029CB10C7BAC448403A0664AF77D34B40E5ED08A705C348403A0664AF77D34B40
11208	15543	49.360987999999999	49.385556000000001	55.814926999999997	55.805047000000002	Приозерная	0103000020E61000000100000005000000CD1FD3DA34AE4840185FB4C70BE74B40CD1FD3DA34AE48404ED026874FE84B40676325E659B148404ED026874FE84B40676325E659B14840185FB4C70BE74B40CD1FD3DA34AE4840185FB4C70BE74B40
11206	15466	49.821894999999998	49.835244000000003	55.659377999999997	55.651384	Школьная	0103000020E610000001000000050000007ADFF8DA33E948409F91088D60D34B407ADFF8DA33E94840D7D9907F66D44B4012178046E9EA4840D7D9907F66D44B4012178046E9EA48409F91088D60D34B407ADFF8DA33E948409F91088D60D34B40
11205	15444	49.366368000000001	49.400109	55.750109000000002	55.731966999999997	Центральная	0103000020E6100000010000000500000085268925E5AE484028603B18B1DD4B4085268925E5AE4840B7B75B9203E04B40EAEA8EC536B34840B7B75B9203E04B40EAEA8EC536B3484028603B18B1DD4B4085268925E5AE484028603B18B1DD4B40
11204	15369	49.862769	49.880375000000001	55.899042999999999	55.885235999999999	Школьная	0103000020E610000001000000050000005680EF366FEE4840F59ECA694FF14B405680EF366FEE48404F594DD713F34B40A69BC420B0F048404F594DD713F34B40A69BC420B0F04840F59ECA694FF14B405680EF366FEE4840F59ECA694FF14B40
11158	13177	50.6218	50.643718999999997	54.495182	54.480438999999997	Школьная	0103000020E610000001000000050000008F537424974F4940895C70067F3D4B408F537424974F4940B0C8AF1F623F4B402B685A6265524940B0C8AF1F623F4B402B685A6265524940895C70067F3D4B408F537424974F4940895C70067F3D4B40
11168	13813	50.388795000000002	50.426084000000003	54.496169999999999	54.480020000000003	Центральная	0103000020E6100000010000000500000096ECD808C431494085B69C4B713D4B4096ECD808C4314940CFA0A17F823F4B40A8ACA6EB89364940CFA0A17F823F4B40A8ACA6EB8936494085B69C4B713D4B4096ECD808C431494085B69C4B713D4B40
11201	15265	50.252744999999997	50.271977999999997	54.638299000000004	54.623378000000002	Центральная	0103000020E610000001000000050000001F9DBAF259204940E085ADD9CA4F4B401F9DBAF259204940E60819C8B3514B40A19DD32CD0224940E60819C8B3514B40A19DD32CD0224940E085ADD9CA4F4B401F9DBAF259204940E085ADD9CA4F4B40
11156	13065	50.732176000000003	50.750376000000003	54.466313	54.449066999999999	Шоссейная	0103000020E61000000100000005000000437573F1B75D49403E5B07077B394B40437573F1B75D49408E59F624B03B4B4006DA1D520C6049408E59F624B03B4B4006DA1D520C6049403E5B07077B394B40437573F1B75D49403E5B07077B394B40
11154	12970	50.727307000000003	50.740898999999999	54.421228999999997	54.411526000000002	Кооперативная	0103000020E6100000010000000500000071935165185D494013BA4BE2AC344B4071935165185D49403A90F5D4EA354B40CE5147C7D55E49403A90F5D4EA354B40CE5147C7D55E494013BA4BE2AC344B4071935165185D494013BA4BE2AC344B40
11166	13645	50.474044999999997	50.513454000000003	54.420543000000002	54.398980000000002	Школьная	0103000020E6100000010000000500000089EAAD81AD3C494009E1D1C611334B4089EAAD81AD3C4940E7C75F5AD4354B400D0055DCB8414940E7C75F5AD4354B400D0055DCB841494009E1D1C611334B4089EAAD81AD3C494009E1D1C611334B40
11188	14672	50.573435000000003	50.61562	54.608581999999998	54.578588000000003	Школьная	0103000020E61000000100000005000000DEB06D5166494940D5EDEC2B0F4A4B40DEB06D51664949409677D503E64D4B40BB61DBA2CC4E49409677D503E64D4B40BB61DBA2CC4E4940D5EDEC2B0F4A4B40DEB06D5166494940D5EDEC2B0F4A4B40
11200	15244	50.259698	50.284132	54.509089000000003	54.498705999999999	Лесная	0103000020E61000000100000005000000166BB8C83D214940D4282499D53F4B40166BB8C83D2149406EE00ED429414B40A0DFF76F5E2449406EE00ED429414B40A0DFF76F5E244940D4282499D53F4B40166BB8C83D214940D4282499D53F4B40
78539	61318	50.551399000000004	50.576399000000002	54.491647	54.472423999999997	Школьная	0103000020E610000001000000050000000806103E9446494039ECBE63783C4B400806103E944649409816F549EE3E4B403B394371C74949409816F549EE3E4B403B394371C749494039ECBE63783C4B400806103E9446494039ECBE63783C4B40
11185	14574	50.946837000000002	50.975278000000003	54.559719999999999	54.537770999999999	Ленина	0103000020E6100000010000000500000046D26EF4317949405DDE1CAED5444B4046D26EF4317949406475ABE7A4474B401041D5E8D57C49406475ABE7A4474B401041D5E8D57C49405DDE1CAED5444B4046D26EF4317949405DDE1CAED5444B40
11196	15051	50.339981000000002	50.362887999999998	54.788319999999999	54.775193999999999	Октябрьская	0103000020E610000001000000050000007521567F842B49401807978E39634B407521567F842B4940306475ABE7644B40300E2E1D732E4940306475ABE7644B40300E2E1D732E49401807978E39634B407521567F842B49401807978E39634B40
11194	14965	50.401029999999999	50.429695000000002	54.833095999999998	54.816234000000001	Карла Маркса	0103000020E61000000100000005000000815B77F3543349400FF10F5B7A684B40815B77F354334940D636C5E3A26A4B409B20EA3E00374940D636C5E3A26A4B409B20EA3E003749400FF10F5B7A684B40815B77F3543349400FF10F5B7A684B40
11181	14304	50.795318999999999	50.814191999999998	54.506610999999999	54.490439000000002	Школьная	0103000020E6100000010000000500000097715303CD6549406BD784B4C63E4B4097715303CD6549409D6516A1D8404B4019558671376849409D6516A1D8404B4019558671376849406BD784B4C63E4B4097715303CD6549406BD784B4C63E4B40
11190	14772	50.498479000000003	50.523614000000002	54.700200000000002	54.678998999999997	Гагарина	0103000020E61000000100000005000000145FED28CE3F494023827170E9564B40145FED28CE3F494061545227A0594B4027DD96C80543494061545227A0594B4027DD96C80543494023827170E9564B40145FED28CE3F494023827170E9564B40
11161	13350	50.564720999999999	50.595632000000002	54.541772000000002	54.528995000000002	Центральная	0103000020E61000000100000005000000A52E19C748484940AF5FB01BB6434B40A52E19C748484940BBF1EEC858454B40BD395CAB3D4C4940BBF1EEC858454B40BD395CAB3D4C4940AF5FB01BB6434B40A52E19C748484940AF5FB01BB6434B40
11176	14107	50.888869	50.910195000000002	54.612935999999998	54.596007999999998	Школьная	0103000020E61000000100000005000000D0B69A75C6714940C2137AFD494C4B40D0B69A75C67149404145D5AF744E4B40CAFD0E45817449404145D5AF744E4B40CAFD0E4581744940C2137AFD494C4B40D0B69A75C6714940C2137AFD494C4B40
11202	15170	50.370109999999997	50.38062	54.542164	54.529772999999999	Садовая	0103000020E6100000010000000500000016F6B4C35F2F4940E3A6069ACF434B4016F6B4C35F2F4940C68844A165454B400D1AFA27B8304940C68844A165454B400D1AFA27B8304940E3A6069ACF434B4016F6B4C35F2F4940E3A6069ACF434B40
11417	40898	50.785266	50.807490999999999	54.405819999999999	54.390037	Нурлатская	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11132	40898	50.785266	50.807490999999999	54.405819999999999	54.390037	Куйбышева	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11426	12908	50.892946999999999	50.919680999999997	54.417405000000002	54.401752999999999	Пушкина	0103000020E61000000100000005000000D90759164C724940F2086EA46C334B40D90759164C724940EC17EC866D354B4054E0641BB8754940EC17EC866D354B4054E0641BB8754940F2086EA46C334B40D90759164C724940F2086EA46C334B40
11203	15341	50.108170000000001	50.126406000000003	54.586848000000003	54.564528000000003	Шоссейная	0103000020E610000001000000050000004434BA83D80D494091D6187442484B404434BA83D80D49408CDCD3D51D4B4B40540262122E1049408CDCD3D51D4B4B40540262122E10494091D6187442484B404434BA83D80D494091D6187442484B40
11193	14893	50.433934999999998	50.465187999999998	54.830984999999998	54.817692000000001	Ленина	0103000020E610000001000000050000007DCB9C2E8B374940B519A721AA684B407DCB9C2E8B374940B83B6BB75D6A4B40EE3EC7478B3B4940B83B6BB75D6A4B40EE3EC7478B3B4940B519A721AA684B407DCB9C2E8B374940B519A721AA684B40
11187	14596	50.957464000000002	50.985590999999999	54.510302000000003	54.487018999999997	Ленина	0103000020E61000000100000005000000768C2B2E8E7A4940EBC37AA3563E4B40768C2B2E8E7A4940AD8A709351414B40B01D8CD8277E4940AD8A709351414B40B01D8CD8277E4940EBC37AA3563E4B40768C2B2E8E7A4940EBC37AA3563E4B40
11189	14693	50.578456000000003	50.619383999999997	54.646321999999998	54.626193000000001	Тельмана	0103000020E610000001000000050000006616A1D80A4A4940F8FD9B1727504B406616A1D80A4A4940B857E6ADBA524B4034D593F9474F4940B857E6ADBA524B4034D593F9474F4940F8FD9B1727504B406616A1D80A4A4940F8FD9B1727504B40
11184	14501	50.876787	50.903530000000003	54.565367999999999	54.543574	Клубная	0103000020E610000001000000050000006B47718E3A7049405B7A34D593454B406B47718E3A7049403B1A87FA5D484B403A7AFCDEA67349403B1A87FA5D484B403A7AFCDEA67349405B7A34D593454B406B47718E3A7049405B7A34D593454B40
11197	15074	50.286620999999997	50.310209999999998	54.846108999999998	54.823822999999997	Ленина	0103000020E6100000010000000500000064AC36FFAF244940A758350873694B4064AC36FFAF244940F6ECB94C4D6C4B40327216F6B4274940F6ECB94C4D6C4B40327216F6B4274940A758350873694B4064AC36FFAF244940A758350873694B40
79219	61470	50.527332999999999	50.560381999999997	54.528660000000002	54.523634000000001	Центральная	0103000020E61000000100000005000000008DD2A57F4349406E895C7006434B40008DD2A57F434940085A8121AB434B402FA2ED98BA474940085A8121AB434B402FA2ED98BA4749406E895C7006434B40008DD2A57F4349406E895C7006434B40
11191	14796	50.341382000000003	50.367469	54.743774999999999	54.729382000000001	Школьная	0103000020E61000000100000005000000B7B8C667B22B49404225AE635C5D4B40B7B8C667B22B49408C4AEA04345F4B409CA56439092F49408C4AEA04345F4B409CA56439092F49404225AE635C5D4B40B7B8C667B22B49404225AE635C5D4B40
11195	14986	50.553761999999999	50.579723000000001	54.850561999999996	54.842832999999999	Октябрьская	0103000020E610000001000000050000003FE257ACE1464940AA7EA5F3E16B4B403FE257ACE1464940349C3237DF6C4B4098DEFE5C344A4940349C3237DF6C4B4098DEFE5C344A4940AA7EA5F3E16B4B403FE257ACE1464940AA7EA5F3E16B4B40
11179	14220	50.667740000000002	50.693665000000003	54.540810999999998	54.523910999999998	Школьная	0103000020E61000000100000005000000931D1B8178554940E08101840F434B40931D1B817855494095287B4B39454B409FB0C403CA58494095287B4B39454B409FB0C403CA584940E08101840F434B40931D1B8178554940E08101840F434B40
11162	13456	50.567667999999998	50.582472000000003	54.424985	54.404860999999997	Клубная	0103000020E610000001000000050000002C7E5358A94849408236397CD2334B402C7E5358A9484940312592E865364B40F96A47718E4A4940312592E865364B40F96A47718E4A49408236397CD2334B402C7E5358A94849408236397CD2334B40
11171	13913	50.361925999999997	50.400734	54.510196999999998	54.493654999999997	Центральная	0103000020E610000001000000050000003AC95697532E4940E1404816303F4B403AC95697532E494037C2A2224E414B40983270404B33494037C2A2224E414B40983270404B334940E1404816303F4B403AC95697532E4940E1404816303F4B40
11167	13739	50.476435000000002	50.496789999999997	54.466355	54.448225000000001	Школьная	0103000020E61000000100000005000000BBD573D2FB3C4940F31FD26F5F394B40BBD573D2FB3C4940BDA94885B13B4B406B7D91D0963F4940BDA94885B13B4B406B7D91D0963F4940F31FD26F5F394B40BBD573D2FB3C4940F31FD26F5F394B40
11152	12996	50.673157000000003	50.68797	54.450946999999999	54.430275000000002	Кирова	0103000020E61000000100000005000000680932022A564940A9A44E4013374B40680932022A5649405A9D9CA1B8394B408750A5660F5849405A9D9CA1B8394B408750A5660F584940A9A44E4013374B40680932022A564940A9A44E4013374B40
11198	15143	50.352072	50.368789999999997	54.578974000000002	54.558503000000002	Центральная	0103000020E610000001000000050000002DEBFEB1102D4940E4DBBB067D474B402DEBFEB1102D4940FE9DEDD11B4A4B40C18BBE82342F4940FE9DEDD11B4A4B40C18BBE82342F4940E4DBBB067D474B402DEBFEB1102D4940E4DBBB067D474B40
11178	14199	50.698425999999998	50.722205000000002	54.507880999999998	54.486840999999998	Центральная	0103000020E610000001000000050000008A56EE05665949400CAD4ECE503E4B408A56EE056659494040A19E3E02414B40FC00A436715C494040A19E3E02414B40FC00A436715C49400CAD4ECE503E4B408A56EE05665949400CAD4ECE503E4B40
11164	13556	50.507876000000003	50.526713000000001	54.518262	54.502633000000003	Центральная	0103000020E610000001000000050000002F36AD1402414940F871344756404B402F36AD14024149403961C26856424B4064B0E2546B4349403961C26856424B4064B0E2546B434940F871344756404B402F36AD1402414940F871344756404B40
11182	14388	50.744087999999998	50.770992	54.552174999999998	54.533304999999999	Школьная	0103000020E610000001000000050000004BAC8C463E5F49408AE5965643444B404BAC8C463E5F49409B559FABAD464B4023BDA8DDAF6249409B559FABAD464B4023BDA8DDAF6249408AE5965643444B404BAC8C463E5F49408AE5965643444B40
11172	13934	50.448658999999999	50.468808000000003	54.642935999999999	54.629826000000001	Лесозаводская	0103000020E610000001000000050000002D077AA86D394940D3156C239E504B402D077AA86D394940E5B512BA4B524B40350D8AE6013C4940E5B512BA4B524B40350D8AE6013C4940D3156C239E504B402D077AA86D394940D3156C239E504B40
11183	14483	50.832895000000001	50.874657999999997	54.577513000000003	54.559480000000001	Центральная	0103000020E610000001000000050000003F00A94D9C6A49400F62670A9D474B403F00A94D9C6A4940E7012CF2EB494B40A69718CBF46F4940E7012CF2EB494B40A69718CBF46F49400F62670A9D474B403F00A94D9C6A49400F62670A9D474B40
11163	13537	50.449224999999998	50.492137	54.508749000000002	54.495454000000002	Зеленая	0103000020E61000000100000005000000D6C56D3480394940115663096B3F4B40D6C56D3480394940B56FEEAF1E414B4066136058FE3E4940B56FEEAF1E414B4066136058FE3E4940115663096B3F4B40D6C56D3480394940115663096B3F4B40
11165	13627	50.542074999999997	50.566994000000001	54.369853999999997	54.357998000000002	Школьная	0103000020E61000000100000005000000567DAEB6624549404704E3E0D22D4B40567DAEB662454940BB253960572F4B409D83674293484940BB253960572F4B409D836742934849404704E3E0D22D4B40567DAEB6624549404704E3E0D22D4B40
11177	40901	50.624620999999998	50.639702999999997	54.396521999999997	54.384841999999999	Центральная	0103000020E6100000010000000500000089B2B794F34F49404910AE8042314B4089B2B794F34F49407F129F3BC1324B409813B4C9E15149407F129F3BC1324B409813B4C9E15149404910AE8042314B4089B2B794F34F49404910AE8042314B40
11175	14010	50.981467000000002	51.016249999999999	54.644379000000001	54.629091000000003	Советская	0103000020E61000000100000005000000378DEDB5A07D49409E9ACB0D86504B40378DEDB5A07D4940569DD5027B524B40AE47E17A14824940569DD5027B524B40AE47E17A148249409E9ACB0D86504B40378DEDB5A07D49409E9ACB0D86504B40
11155	13084	50.607508000000003	50.631610000000002	54.467516000000003	54.445056999999998	Центральная	0103000020E61000000100000005000000790778D2C24D49408DEDB5A0F7384B40790778D2C24D4940AA2D7590D73B4B40CDE9B298D8504940AA2D7590D73B4B40CDE9B298D85049408DEDB5A0F7384B40790778D2C24D49408DEDB5A0F7384B40
11160	13279	50.585687999999998	50.598973999999998	54.515872999999999	54.49718	Гагарина	0103000020E610000001000000050000006FD40AD3F74A4940D61C2098A33F4B406FD40AD3F74A4940D8F15F2008424B40C093162EAB4C4940D8F15F2008424B40C093162EAB4C4940D61C2098A33F4B406FD40AD3F74A4940D61C2098A33F4B40
11138	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Школьная	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11141	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Самаренкина	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11148	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Нижненурлатская	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11134	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Мугинова	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11139	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Мира	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11150	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Клубная	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
12025	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Дружба	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11136	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Гиматдинова	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
11147	40899	50.785266	50.807490999999999	54.405819999999999	54.390037	Верхненурлатская	0103000020E610000001000000050000009354A698836449406F9D7FBBEC314B409354A698836449400708E6E8F1334B403C6876DD5B6749400708E6E8F1334B403C6876DD5B6749406F9D7FBBEC314B409354A698836449406F9D7FBBEC314B40
78532	61313	51.261840999999997	51.289661000000002	55.026159	55.003461000000001	Центральная	0103000020E610000001000000050000003FE0810184A14940DEE7F86871804B403FE0810184A149407FBF982D59834B409DF6949C13A549407FBF982D59834B409DF6949C13A54940DEE7F86871804B403FE0810184A14940DEE7F86871804B40
11123	12129	51.055300000000003	51.086669000000001	55.158831999999997	55.143053999999999	Центральная	0103000020E6100000010000000500000002BC051214874940EFC7ED974F924B4002BC05121487494075C7629B54944B40DC4944F8178B494075C7629B54944B40DC4944F8178B4940EFC7ED974F924B4002BC051214874940EFC7ED974F924B40
11122	11952	50.883695000000003	50.899253999999999	55.085166999999998	55.071478999999997	Чапаева	0103000020E61000000100000005000000C251F2EA1C714940E6AC4F3926894B40C251F2EA1C71494066D993C0E68A4B400A664CC11A73494066D993C0E68A4B400A664CC11A734940E6AC4F3926894B40C251F2EA1C714940E6AC4F3926894B40
11125	12249	51.005299999999998	51.032787999999996	55.167862999999997	55.15072	Центральная	0103000020E610000001000000050000009B559FABAD804940336DFFCA4A934B409B559FABAD804940AE9AE7887C954B40C2D9AD6532844940AE9AE7887C954B40C2D9AD6532844940336DFFCA4A934B409B559FABAD804940336DFFCA4A934B40
11120	11865	51.312846999999998	51.353046999999997	55.217875999999997	55.204042999999999	Центральная	0103000020E610000001000000050000006BD3D85E0BA8494026FDBD141E9A4B406BD3D85E0BA84940A94A5B5CE39B4B40B779E3A430AD4940A94A5B5CE39B4B40B779E3A430AD494026FDBD141E9A4B406BD3D85E0BA8494026FDBD141E9A4B40
78494	61307	51.116008000000001	51.164625000000001	54.966458000000003	54.944952000000001	Пролетарская	0103000020E610000001000000050000008509A359D98E49401825E82FF4784B408509A359D98E4940927A4FE5B47B4B40508D976E12954940927A4FE5B47B4B40508D976E129549401825E82FF4784B408509A359D98E49401825E82FF4784B40
78535	61316	51.349184000000001	51.393676999999997	55.072386000000002	55.047950999999998	Ленина	0103000020E61000000100000005000000AB24B20FB2AC4940BE67244223864B40AB24B20FB2AC49401958C7F143894B40FC17080264B249401958C7F143894B40FC17080264B24940BE67244223864B40AB24B20FB2AC4940BE67244223864B40
79115	61388	51.047431000000003	51.084325	55.021968000000001	55.006967000000003	Центральная	0103000020E6100000010000000500000086E81038128649405C936E4BE4804B4086E81038128649407EC7F0D8CF824B401B9E5E29CB8A49407EC7F0D8CF824B401B9E5E29CB8A49405C936E4BE4804B4086E81038128649405C936E4BE4804B40
79207	61461	51.265120000000003	51.288575000000002	54.950820999999998	54.921343999999998	Центральная	0103000020E61000000100000005000000FDC1C073EFA14940D32EA699EE754B40FDC1C073EFA14940CDACA580B4794B40BBB88D06F0A44940CDACA580B4794B40BBB88D06F0A44940D32EA699EE754B40FDC1C073EFA14940D32EA699EE754B40
79257	61499	51.243730999999997	51.274811999999997	55.168691000000003	55.149510999999997	Горького	0103000020E61000000100000005000000BC02D193329F494035B22B2D23934B40BC02D193329F49409510ACAA97954B403046240A2DA349409510ACAA97954B403046240A2DA3494035B22B2D23934B40BC02D193329F494035B22B2D23934B40
11121	11937	50.916896999999999	50.945661000000001	55.065607	55.049807999999999	Речная	0103000020E61000000100000005000000776682E15C754940228AC91B60864B40776682E15C754940C0B167CF65884B40240D6E6B0B794940C0B167CF65884B40240D6E6B0B794940228AC91B60864B40776682E15C754940228AC91B60864B40
11124	12185	51.024146000000002	51.050781000000001	55.141705999999999	55.123837000000002	Центральная	0103000020E61000000100000005000000242A54371783494073840CE4D98F4B40242A543717834940D0D2156C23924B400C21E7FD7F864940D0D2156C23924B400C21E7FD7F86494073840CE4D98F4B40242A54371783494073840CE4D98F4B40
11115	11494	51.201680000000003	51.280938999999996	55.07855	55.052782999999998	Школьная	0103000020E61000000100000005000000EF2076A6D09949407364E597C1864B40EF2076A6D0994940E78C28ED0D8A4B40E19524CFF5A34940E78C28ED0D8A4B40E19524CFF5A349407364E597C1864B40EF2076A6D09949407364E597C1864B40
11116	11494	51.201680000000003	51.280938999999996	55.07855	55.052782999999998	Набережная	0103000020E61000000100000005000000EF2076A6D09949407364E597C1864B40EF2076A6D0994940E78C28ED0D8A4B40E19524CFF5A34940E78C28ED0D8A4B40E19524CFF5A349407364E597C1864B40EF2076A6D09949407364E597C1864B40
81105	11494	51.201680000000003	51.280938999999996	55.07855	55.052782999999998	Молодежная	0103000020E61000000100000005000000EF2076A6D09949407364E597C1864B40EF2076A6D0994940E78C28ED0D8A4B40E19524CFF5A34940E78C28ED0D8A4B40E19524CFF5A349407364E597C1864B40EF2076A6D09949407364E597C1864B40
11118	11494	51.201680000000003	51.280938999999996	55.07855	55.052782999999998	Ленина	0103000020E61000000100000005000000EF2076A6D09949407364E597C1864B40EF2076A6D0994940E78C28ED0D8A4B40E19524CFF5A34940E78C28ED0D8A4B40E19524CFF5A349407364E597C1864B40EF2076A6D09949407364E597C1864B40
11117	11494	51.201680000000003	51.280938999999996	55.07855	55.052782999999998	Заливная	0103000020E61000000100000005000000EF2076A6D09949407364E597C1864B40EF2076A6D0994940E78C28ED0D8A4B40E19524CFF5A34940E78C28ED0D8A4B40E19524CFF5A349407364E597C1864B40EF2076A6D09949407364E597C1864B40
11111	11298	51.377983999999998	51.402023	54.981153999999997	54.960782999999999	Центральная	0103000020E61000000100000005000000A4349BC761B04940C1C6F5EFFA7A4B40A4349BC761B04940772B4B74967D4B40B29E5A7D75B34940772B4B74967D4B40B29E5A7D75B34940C1C6F5EFFA7A4B40A4349BC761B04940C1C6F5EFFA7A4B40
11109	11180	51.082205000000002	51.107187000000003	55.006967000000003	54.998302000000002	Молодежная	0103000020E61000000100000005000000AA4885B1858A494005C4245CC87F4B40AA4885B1858A49405C936E4BE4804B4037C7B94DB88D49405C936E4BE4804B4037C7B94DB88D494005C4245CC87F4B40AA4885B1858A494005C4245CC87F4B40
11113	11396	51.234999000000002	51.265146000000001	55.207680000000003	55.186813000000001	Центральная	0103000020E61000000100000005000000DECB7D72149E4940DCBB067DE9974B40DECB7D72149E494043041C42959A4B402655DB4DF0A1494043041C42959A4B402655DB4DF0A14940DCBB067DE9974B40DECB7D72149E4940DCBB067DE9974B40
11110	11196	51.409362000000002	51.447989999999997	55.185265999999999	55.168064000000001	Ленина	0103000020E61000000100000005000000D21C59F965B4494046D1031F83954B40D21C59F965B44940C687D9CBB6974B40AF777FBC57B94940C687D9CBB6974B40AF777FBC57B9494046D1031F83954B40D21C59F965B4494046D1031F83954B40
11112	11379	51.475082999999998	51.490085000000001	54.993054999999998	54.971857999999997	Центральная	0103000020E610000001000000050000005AF10D85CFBC4940902DCBD7657C4B405AF10D85CFBC49408C101E6D1C7F4B404DA1F31ABBBE49408C101E6D1C7F4B404DA1F31ABBBE4940902DCBD7657C4B405AF10D85CFBC4940902DCBD7657C4B40
11114	11469	51.190486999999997	51.219701000000001	55.235256	55.220685000000003	Луговая	0103000020E6100000010000000500000015A8C5E061984940E0DBF4673F9C4B4015A8C5E06198494009185DDE1C9E4B4002F390291F9C494009185DDE1C9E4B4002F390291F9C4940E0DBF4673F9C4B4015A8C5E061984940E0DBF4673F9C4B40
11119	11782	51.419693000000002	51.430194	55.035462000000003	55.030766999999997	Центральная	0103000020E6100000010000000500000019AE0E80B8B54940E4654D2CF0834B4019AE0E80B8B549401920D1048A844B40BC77D49810B749401920D1048A844B40BC77D49810B74940E4654D2CF0834B4019AE0E80B8B54940E4654D2CF0834B40
79200	61455	50.82199	51.580877000000001	55.270097	54.854298999999997	Комсомольская	0103000020E61000000100000005000000CCD1E3F736694940B4006DAB596D4B40CCD1E3F736694940B5DFDA8992A24B40D2FF722D5ACA4940B5DFDA8992A24B40D2FF722D5ACA4940B4006DAB596D4B40CCD1E3F736694940B4006DAB596D4B40
11108	10936	51.078547999999998	51.116799	55.214039	55.197184	Советская	0103000020E61000000100000005000000469561DC0D8A4940B1A547533D994B40469561DC0D8A4940C68844A1659B4B404E9A0645F38E4940C68844A1659B4B404E9A0645F38E4940B1A547533D994B40469561DC0D8A4940B1A547533D994B40
11074	9402	51.803201000000001	51.832999000000001	55.522368	55.508544000000001	Школьная	0103000020E61000000100000005000000A88E554ACFE64940DC4944F817C14B40A88E554ACFE649400C3D62F4DCC24B40E44C13B69FEA49400C3D62F4DCC24B40E44C13B69FEA4940DC4944F817C14B40A88E554ACFE64940DC4944F817C14B40
11090	10182	51.535162	51.572361000000001	55.393675999999999	55.369959999999999	Октябрьская площадь	0103000020E61000000100000005000000EE073C3080C44940016A6AD95AAF4B40EE073C3080C449402C9CA4F963B24B40C040102043C949402C9CA4F963B24B40C040102043C94940016A6AD95AAF4B40EE073C3080C44940016A6AD95AAF4B40
11078	9672	51.738990000000001	51.751935000000003	55.477082000000003	55.463973000000003	Чапаева	0103000020E6100000010000000500000018096D3997DE49400F9D9E7763BB4B4018096D3997DE494051C1E10511BD4B40E0DBF4673FE0494051C1E10511BD4B40E0DBF4673FE049400F9D9E7763BB4B4018096D3997DE49400F9D9E7763BB4B40
11088	10095	51.660603000000002	51.681767000000001	55.409681999999997	55.397449000000002	Школьная	0103000020E61000000100000005000000DB519CA38ED44940F969DC9BDFB24B40DB519CA38ED4494043E1B37570B44B40FB3E1C2444D7494043E1B37570B44B40FB3E1C2444D74940F969DC9BDFB24B40DB519CA38ED44940F969DC9BDFB24B40
11075	9464	51.795825999999998	51.816702999999997	55.507320999999997	55.493298000000003	Центральная	0103000020E610000001000000050000003BA759A0DDE5494053978C6324BF4B403BA759A0DDE5494079C9FFE4EFC04B40C5C551B989E8494079C9FFE4EFC04B40C5C551B989E8494053978C6324BF4B403BA759A0DDE5494053978C6324BF4B40
11080	9786	51.627229999999997	51.656658999999998	55.455708999999999	55.439737000000001	Пролетарская	0103000020E61000000100000005000000F888981249D04940ABEB504D49B84B40F888981249D0494016BF29AC54BA4B40E1CFF0660DD4494016BF29AC54BA4B40E1CFF0660DD44940ABEB504D49B84B40F888981249D04940ABEB504D49B84B40
11104	10772	51.230615	51.261158000000002	55.391033	55.368721999999998	Нижнекамская	0103000020E61000000100000005000000C87BD5CA849D494069A8514832AF4B40C87BD5CA849D494011548D5E0DB24B405D8B16A06DA1494011548D5E0DB24B405D8B16A06DA1494069A8514832AF4B40C87BD5CA849D494069A8514832AF4B40
11072	9240	51.954656999999997	51.995691999999998	55.664425999999999	55.648763000000002	Школьная	0103000020E61000000100000005000000E0F2583332FA49406CED7DAA0AD34B40E0F2583332FA4940594E42E90BD54B40C571E0D572FF4940594E42E90BD54B40C571E0D572FF49406CED7DAA0AD34B40E0F2583332FA49406CED7DAA0AD34B40
11095	10390	51.610495	51.653694999999999	55.354615000000003	55.339114000000002	Гагарина	0103000020E610000001000000050000008EAF3DB324CE4940D1CE691668AB4B408EAF3DB324CE4940E5D5390664AD4B4084471B47ACD34940E5D5390664AD4B4084471B47ACD34940D1CE691668AB4B408EAF3DB324CE4940D1CE691668AB4B40
11087	10017	51.831012999999999	51.850264000000003	55.405005000000003	55.392623	Красноармейская	0103000020E6100000010000000500000082C64CA25EEA49402654707841B24B4082C64CA25EEA4940B6DB2E34D7B34B40AB7B6473D5EC4940B6DB2E34D7B34B40AB7B6473D5EC49402654707841B24B4082C64CA25EEA49402654707841B24B40
11068	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	проспект Химиков	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11339	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	проспект Строителей	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11059	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	проспект Мира	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11333	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	проспект Вахитова	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11066	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	пр.Химиков	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11910	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	пр.Мира	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11053	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	пр. Шинников	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11036	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Юности	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11043	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Школьный бульвар	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11062	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Чулман	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11041	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Центральная	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11038	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Тукая	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11060	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Сююмбике	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11039	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Строителей	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11045	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Спортивная	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11044	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Сквер Лемаева	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11057	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Мурадьяна	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11048	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Менделеева	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11037	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Корабельная	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11049	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Кайманова	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11046	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Гагарина	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11047	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Вахитова	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11055	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Бызова	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11063	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Баки Урманче	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11040	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	Ахтубинская	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11067	6398	51.776584	52.012059999999998	55.668984999999999	55.597265999999998	30 лет Победы	0103000020E61000000100000005000000664CC11A67E34940A181583673CC4B40664CC11A67E34940DD41EC4CA1D54B407DCB9C2E8B014A40DD41EC4CA1D54B407DCB9C2E8B014A40A181583673CC4B40664CC11A67E34940A181583673CC4B40
11093	10278	51.467618000000002	51.487506000000003	55.394765	55.381286000000003	Центральная	0103000020E61000000100000005000000AE8218E8DABB49401A36CAFACDB04B40AE8218E8DABB49407F4DD6A887B24B40494DBB9866BE49407F4DD6A887B24B40494DBB9866BE49401A36CAFACDB04B40AE8218E8DABB49401A36CAFACDB04B40
11100	10631	51.255021999999997	51.274534000000003	55.275241999999999	55.260167000000003	Центральная	0103000020E6100000010000000500000058E1968FA4A04940CD3FFA264DA14B4058E1968FA4A04940293E3E213BA34B40EED11BEE23A34940293E3E213BA34B40EED11BEE23A34940CD3FFA264DA14B4058E1968FA4A04940CD3FFA264DA14B40
11073	9386	51.795988000000001	51.833815999999999	55.688751000000003	55.675773	Советская	0103000020E6100000010000000500000015014EEFE2E549408942CBBA7FD64B4015014EEFE2E549402D0B26FE28D84B40D670917BBAEA49402D0B26FE28D84B40D670917BBAEA49408942CBBA7FD64B4015014EEFE2E549408942CBBA7FD64B40
11085	9983	51.781947000000002	51.806201999999999	55.421486000000002	55.409421000000002	Ленина	0103000020E61000000100000005000000481ADCD616E44940D7A546E867B44B40481ADCD616E4494066DCD440F3B54B4022FC8BA031E7494066DCD440F3B54B4022FC8BA031E74940D7A546E867B44B40481ADCD616E44940D7A546E867B44B40
11101	10643	51.162208999999997	51.190199999999997	55.310108999999997	55.298383999999999	Пионерская	0103000020E61000000100000005000000F50EB743C394494028D3687231A64B40F50EB743C3944940FE98D6A6B1A74B407FD93D7958984940FE98D6A6B1A74B407FD93D795898494028D3687231A64B40F50EB743C394494028D3687231A64B40
11094	10309	51.485916000000003	51.506101999999998	55.355792000000001	55.342145000000002	Московская	0103000020E61000000100000005000000344DD87E32BE4940B6BE4868CBAB4B40344DD87E32BE4940D7169E978AAD4B40583849F3C7C04940D7169E978AAD4B40583849F3C7C04940B6BE4868CBAB4B40344DD87E32BE4940B6BE4868CBAB4B40
11106	10820	51.283363999999999	51.43535	55.470857000000002	55.423611000000001	4	0103000020E610000001000000050000008F6E844545A44940E99C9FE238B64B408F6E844545A44940DD0BCC0A45BC4B4024287E8CB9B74940DD0BCC0A45BC4B4024287E8CB9B74940E99C9FE238B64B408F6E844545A44940E99C9FE238B64B40
11107	10820	51.283363999999999	51.43535	55.470857000000002	55.423611000000001	2	0103000020E610000001000000050000008F6E844545A44940E99C9FE238B64B408F6E844545A44940DD0BCC0A45BC4B4024287E8CB9B74940DD0BCC0A45BC4B4024287E8CB9B74940E99C9FE238B64B408F6E844545A44940E99C9FE238B64B40
11105	10820	51.283363999999999	51.43535	55.470857000000002	55.423611000000001	1	0103000020E610000001000000050000008F6E844545A44940E99C9FE238B64B408F6E844545A44940DD0BCC0A45BC4B4024287E8CB9B74940DD0BCC0A45BC4B4024287E8CB9B74940E99C9FE238B64B408F6E844545A44940E99C9FE238B64B40
11077	9599	51.718274999999998	51.732773000000002	55.497072000000003	55.481602000000002	Ленина	0103000020E610000001000000050000006744696FF0DB494017D86322A5BD4B406744696FF0DB4940F0E0270EA0BF4B4027327381CBDD4940F0E0270EA0BF4B4027327381CBDD494017D86322A5BD4B406744696FF0DB494017D86322A5BD4B40
11099	10582	51.191619000000003	51.216458000000003	55.304220999999998	55.279615999999997	Нагорное	0103000020E610000001000000050000006825ADF8869849401BB80375CAA34B406825ADF886984940D2E0B6B6F0A64B40927A4FE5B49B4940D2E0B6B6F0A64B40927A4FE5B49B49401BB80375CAA34B406825ADF8869849401BB80375CAA34B40
11102	10722	51.144620000000003	51.166412999999999	55.301915000000001	55.283436000000002	Колхозная	0103000020E610000001000000050000007C2C7DE88292494029417FA147A44B407C2C7DE882924940FF959526A5A64B408B506C054D954940FF959526A5A64B408B506C054D95494029417FA147A44B407C2C7DE88292494029417FA147A44B40
11097	10468	51.739744000000002	51.766550000000002	55.263722000000001	55.248817000000003	Молодежная	0103000020E61000000100000005000000C4B46FEEAFDE49402CD8463CD99F4B40C4B46FEEAFDE49402C9E7AA4C1A14B40D95F764F1EE249402C9E7AA4C1A14B40D95F764F1EE249402CD8463CD99F4B40C4B46FEEAFDE49402CD8463CD99F4B40
11082	9874	51.762607000000003	51.798969999999997	55.381796999999999	55.360622999999997	Молодежная	0103000020E61000000100000005000000B0592E1B9DE14940BB97FBE428AE4B40B0592E1B9DE14940FF5A5EB9DEB04B40183E22A644E64940FF5A5EB9DEB04B40183E22A644E64940BB97FBE428AE4B40B0592E1B9DE14940BB97FBE428AE4B40
11939	9698	51.666891	51.690345999999998	55.553009000000003	55.540821999999999	М.Горького	0103000020E61000000100000005000000957F2DAF5CD54940897AC1A739C54B40957F2DAF5CD5494064B2B8FFC8C64B405376FA415DD8494064B2B8FFC8C64B405376FA415DD84940897AC1A739C54B40957F2DAF5CD54940897AC1A739C54B40
11069	9154	51.750937	51.822623	55.614409000000002	55.594330999999997	Молодежная	0103000020E610000001000000050000009D2D20B41EE04940DEFFC70913CC4B409D2D20B41EE049401DAF40F4A4CE4B40FDF7E0B54BE949401DAF40F4A4CE4B40FDF7E0B54BE94940DEFFC70913CC4B409D2D20B41EE04940DEFFC70913CC4B40
11103	40897	51.732512999999997	51.753722000000003	55.405755999999997	55.391938000000003	Красноармейская	0103000020E610000001000000050000008A7269FCC2DD4940A3073E062BB24B408A7269FCC2DD4940F01307D0EFB34B404B2366F679E04940F01307D0EFB34B404B2366F679E04940A3073E062BB24B408A7269FCC2DD4940A3073E062BB24B40
11081	9804	51.591729000000001	51.625532999999997	55.422201000000001	55.407254000000002	Ленина	0103000020E61000000100000005000000228C9FC6BDCB4940259529E620B44B40228C9FC6BDCB494054ABAFAE0AB64B40CDC8207711D0494054ABAFAE0AB64B40CDC8207711D04940259529E620B44B40228C9FC6BDCB4940259529E620B44B40
11098	10540	51.524248	51.545240999999997	55.143425000000001	55.131923	Мира	0103000020E61000000100000005000000287FF78E1AC349408C4B55DAE2904B40287FF78E1AC34940E3361AC05B924B401BB80375CAC54940E3361AC05B924B401BB80375CAC549408C4B55DAE2904B40287FF78E1AC349408C4B55DAE2904B40
11076	9571	51.795476000000001	51.827016	55.557943000000002	55.533562000000003	Терешковой	0103000020E610000001000000050000005F605628D2E54940B63176C24BC44B405F605628D2E549401D041DAD6AC74B4066A208A9DBE949401D041DAD6AC74B4066A208A9DBE94940B63176C24BC44B405F605628D2E54940B63176C24BC44B40
10967	40860	53.091501999999998	53.115011000000003	55.183256	55.164963	Ленина	0103000020E6100000010000000500000061C26856B68B4A406806F1811D954B4061C26856B68B4A40DC65BFEE74974B4013D731AEB88E4A40DC65BFEE74974B4013D731AEB88E4A406806F1811D954B4061C26856B68B4A406806F1811D954B40
10998	904	53.596966000000002	53.628532999999997	55.404012999999999	55.387157000000002	Школьная	0103000020E610000001000000050000007769C36169CC4A4070B54E5C8EB14B407769C36169CC4A405514AFB2B6B34B4077BAF3C473D04A405514AFB2B6B34B4077BAF3C473D04A4070B54E5C8EB14B407769C36169CC4A4070B54E5C8EB14B40
10996	790	53.012801000000003	53.03763	55.282313000000002	55.271005000000002	Центральная	0103000020E61000000100000005000000952D9276A3814A40B806B64AB0A24B40952D9276A3814A402A1E17D522A44B409BAC510FD1844A402A1E17D522A44B409BAC510FD1844A40B806B64AB0A24B40952D9276A3814A40B806B64AB0A24B40
10984	345	53.025305000000003	53.041052999999998	55.398885999999997	55.386850000000003	Вахитова	0103000020E6100000010000000500000070B6B9313D834A40933A014D84B14B4070B6B9313D834A40876A4AB20EB34B408B33863941854A40876A4AB20EB34B408B33863941854A40933A014D84B14B4070B6B9313D834A40933A014D84B14B40
10997	847	52.924002000000002	52.953332000000003	55.267943000000002	55.249622000000002	Урожайная	0103000020E6100000010000000500000024B891B245764A405A2E1B9DF39F4B4024B891B245764A409818CBF44BA24B407A1D71C8067A4A409818CBF44BA24B407A1D71C8067A4A405A2E1B9DF39F4B4024B891B245764A405A2E1B9DF39F4B40
10975	32349	53.264544999999998	53.288161000000002	55.412461999999998	55.400931	Лесная	0103000020E6100000010000000500000000A94D9CDCA14A40EE79FEB451B34B4000A94D9CDCA14A40DF6B088ECBB44B40C87DAB75E2A44A40DF6B088ECBB44B40C87DAB75E2A44A40EE79FEB451B34B4000A94D9CDCA14A40EE79FEB451B34B40
10971	32158	53.562992000000001	53.583204000000002	55.448974999999997	55.435870999999999	Дружбы	0103000020E610000001000000050000006FF4311F10C84A402D23F59ECAB74B406FF4311F10C84A405DDC460378B94B40BD72BD6DA6CA4A405DDC460378B94B40BD72BD6DA6CA4A402D23F59ECAB74B406FF4311F10C84A402D23F59ECAB74B40
11002	995	53.346317999999997	53.353513999999997	55.184541000000003	55.176994999999998	Ленинская	0103000020E610000001000000050000001002F22554AC4A401B47ACC5A7964B401002F22554AC4A40B5E21B0A9F974B40CD565EF23FAD4A40B5E21B0A9F974B40CD565EF23FAD4A401B47ACC5A7964B401002F22554AC4A401B47ACC5A7964B40
10968	40861	53.210690999999997	53.230193	55.332856999999997	55.320253000000001	Чишма	0103000020E61000000100000005000000E04735ECF79A4A4013B9E00CFEA84B40E04735ECF79A4A40519FE40E9BAA4B405262D7F6769D4A40519FE40E9BAA4B405262D7F6769D4A4013B9E00CFEA84B40E04735ECF79A4A4013B9E00CFEA84B40
10995	723	53.536060999999997	53.567051999999997	55.323956000000003	55.310313999999998	Кооперативная	0103000020E610000001000000050000009DD497A59DC44A40D7BE805EB8A74B409DD497A59DC44A40E7ABE46377A94B40D190F12895C84A40E7ABE46377A94B40D190F12895C84A40D7BE805EB8A74B409DD497A59DC44A40D7BE805EB8A74B40
10993	540	53.410871	53.427579999999999	55.414479999999998	55.401370999999997	Школьная	0103000020E61000000100000005000000FAEFC16B97B44A400A48FB1F60B34B40FAEFC16B97B44A404C6C3EAE0DB54B403B3602F1BAB64A404C6C3EAE0DB54B403B3602F1BAB64A400A48FB1F60B34B40FAEFC16B97B44A400A48FB1F60B34B40
10981	38	53.248429000000002	53.270797000000002	55.279589999999999	55.267204999999997	Кооперативная	0103000020E6100000010000000500000062307F85CC9F4A40F12900C633A24B4062307F85CC9F4A40F224E99AC9A34B406E6DE179A9A24A40F224E99AC9A34B406E6DE179A9A24A40F12900C633A24B4062307F85CC9F4A40F12900C633A24B40
11001	980	53.184873000000003	53.210932999999997	55.205280999999999	55.188246999999997	Ленина	0103000020E61000000100000005000000EB7420EBA9974A40F9484A7A18984B40EB7420EBA9974A40BEBED6A5469A4B40D65240DAFF9A4A40BEBED6A5469A4B40D65240DAFF9A4A40F9484A7A18984B40EB7420EBA9974A40F9484A7A18984B40
10990	481	53.599696999999999	53.634830000000001	55.333419999999997	55.323915	Центральная	0103000020E6100000010000000500000031410DDFC2CC4A4088D7F50B76A94B4031410DDFC2CC4A4089EAAD81ADAA4B408542041C42D14A4089EAAD81ADAA4B408542041C42D14A4088D7F50B76A94B4031410DDFC2CC4A4088D7F50B76A94B40
10985	420	53.338296	53.380921999999998	55.282974000000003	55.258012000000001	Советская	0103000020E610000001000000050000000E2F88484DAB4A40DFFC868906A14B400E2F88484DAB4A4025CFF57D38A44B40D829560DC2B04A4025CFF57D38A44B40D829560DC2B04A40DFFC868906A14B400E2F88484DAB4A40DFFC868906A14B40
10973	40864	53.513728	53.538639000000003	55.408056000000002	55.399438000000004	Мирная	0103000020E610000001000000050000000E85CFD6C1C14A40CC63CDC820B34B400E85CFD6C1C14A40E277D32D3BB44B40D2AC6C1FF2C44A40E277D32D3BB44B40D2AC6C1FF2C44A40CC63CDC820B34B400E85CFD6C1C14A40CC63CDC820B34B40
10983	287	53.027174000000002	53.042921	55.372114000000003	55.364552000000003	Школьная	0103000020E6100000010000000500000098A608707A834A4080D8D2A3A9AE4B4098A608707A834A401F317A6EA1AF4B40E3A7716F7E854A401F317A6EA1AF4B40E3A7716F7E854A4080D8D2A3A9AE4B4098A608707A834A4080D8D2A3A9AE4B40
10954	31500	53.172395999999999	53.219116999999997	55.315939	55.282569000000002	Пушкина	0103000020E6100000010000000500000009FB761211964A4085EE92382BA44B4009FB761211964A40F6436CB070A84B40B27F9E060C9C4A40F6436CB070A84B40B27F9E060C9C4A4085EE92382BA44B4009FB761211964A4085EE92382BA44B40
10955	31500	53.172395999999999	53.219116999999997	55.315939	55.282569000000002	Октябрьская	0103000020E6100000010000000500000009FB761211964A4085EE92382BA44B4009FB761211964A40F6436CB070A84B40B27F9E060C9C4A40F6436CB070A84B40B27F9E060C9C4A4085EE92382BA44B4009FB761211964A4085EE92382BA44B40
10957	31500	53.172395999999999	53.219116999999997	55.315939	55.282569000000002	Молодежная	0103000020E6100000010000000500000009FB761211964A4085EE92382BA44B4009FB761211964A40F6436CB070A84B40B27F9E060C9C4A40F6436CB070A84B40B27F9E060C9C4A4085EE92382BA44B4009FB761211964A4085EE92382BA44B40
10951	31500	53.172395999999999	53.219116999999997	55.315939	55.282569000000002	Кооперативная	0103000020E6100000010000000500000009FB761211964A4085EE92382BA44B4009FB761211964A40F6436CB070A84B40B27F9E060C9C4A40F6436CB070A84B40B27F9E060C9C4A4085EE92382BA44B4009FB761211964A4085EE92382BA44B40
10994	147	52.915370000000003	52.94849	55.249048000000002	55.232447999999998	Гагарина	0103000020E61000000100000005000000A9DE1AD82A754A40A30227DBC09D4B40A9DE1AD82A754A402E910BCEE09F4B40A14ACD1E68794A402E910BCEE09F4B40A14ACD1E68794A40A30227DBC09D4B40A9DE1AD82A754A40A30227DBC09D4B40
10979	32498	53.253954	53.283867999999998	55.309426999999999	55.292715000000001	Кооперативная	0103000020E610000001000000050000001D588E9081A04A403A0664AF77A54B401D588E9081A04A40ECBFCE4D9BA74B40C23060C955A44A40ECBFCE4D9BA74B40C23060C955A44A403A0664AF77A54B401D588E9081A04A403A0664AF77A54B40
78608	61338	53.083120999999998	53.111857999999998	55.331100999999997	55.304149000000002	Кооперативная	0103000020E610000001000000050000002F4E7CB5A38A4A40390EBC5AEEA64B402F4E7CB5A38A4A4021567F8461AA4B40E2E5E95C518E4A4021567F8461AA4B40E2E5E95C518E4A40390EBC5AEEA64B402F4E7CB5A38A4A40390EBC5AEEA64B40
10978	32276	53.471454000000001	53.491019000000001	55.420985000000002	55.409855	60 лет Октября	0103000020E61000000100000005000000C1C8CB9A58BC4A40118DEE2076B44B40C1C8CB9A58BC4A40A48D23D6E2B54B40795BE9B5D9BE4A40A48D23D6E2B54B40795BE9B5D9BE4A40118DEE2076B44B40C1C8CB9A58BC4A40118DEE2076B44B40
10976	32403	53.143298999999999	53.154375000000002	55.439292999999999	55.427075000000002	Центральная	0103000020E610000001000000050000005646239F57924A4038F8C264AAB64B405646239F57924A404D2EC6C03AB84B40F6285C8FC2934A404D2EC6C03AB84B40F6285C8FC2934A4038F8C264AAB64B405646239F57924A4038F8C264AAB64B40
11004	671	53.388745999999998	53.397593999999998	55.429516999999997	55.416586000000002	Колхозная	0103000020E61000000100000005000000B439CE6DC2B14A4059FCA6B052B54B40B439CE6DC2B14A40BB09BE69FAB64B40FC8A355CE4B24A40BB09BE69FAB64B40FC8A355CE4B24A4059FCA6B052B54B40B439CE6DC2B14A4059FCA6B052B54B40
10982	214	52.985025	53.014614999999999	55.367510000000003	55.354562999999999	Тукая	0103000020E61000000100000005000000075F984C157E4A4092AF045262AD4B40075F984C157E4A40FB7953910AAF4B40F98381E7DE814A40FB7953910AAF4B40F98381E7DE814A4092AF045262AD4B40075F984C157E4A4092AF045262AD4B40
10969	32078	53.242437000000002	53.266655999999998	55.369489999999999	55.352936	Кооперативная	0103000020E61000000100000005000000912BF52C089F4A4060CAC0012DAD4B40912BF52C089F4A407A19C5724BAF4B401EA4A7C821A24A407A19C5724BAF4B401EA4A7C821A24A4060CAC0012DAD4B40912BF52C089F4A4060CAC0012DAD4B40
79253	61495	53.147539000000002	53.168613999999998	55.236601	55.221845000000002	Центральная	0103000020E6100000010000000500000039F1D58EE2924A40FCE3BD6A659C4B4039F1D58EE2924A40B7990AF1489E4B40E9D2BF2495954A40B7990AF1489E4B40E9D2BF2495954A40FCE3BD6A659C4B4039F1D58EE2924A40FCE3BD6A659C4B40
79137	61405	53.571714999999998	53.609147	55.233763000000003	55.213500000000003	Советская	0103000020E61000000100000005000000FAD005F52DC94A4017D9CEF7539B4B40FAD005F52DC94A40E7012CF2EB9D4B406FBA6587F8CD4A40E7012CF2EB9D4B406FBA6587F8CD4A4017D9CEF7539B4B40FAD005F52DC94A4017D9CEF7539B4B40
10964	31844	53.020122000000001	53.058992000000003	55.199604000000001	55.184818999999997	Советская	0103000020E610000001000000050000000EF7915B93824A40F7562426A8974B400EF7915B93824A404D13B69F8C994B40E25CC30C8D874A404D13B69F8C994B40E25CC30C8D874A40F7562426A8974B400EF7915B93824A40F7562426A8974B40
10963	31831	53.693947999999999	53.728344999999997	55.373111999999999	55.359327999999998	Фаррахова	0103000020E61000000100000005000000F38FBE49D3D84A40BF44BC75FEAD4B40F38FBE49D3D84A4061DF4E22C2AF4B40419AB1683ADD4A4061DF4E22C2AF4B40419AB1683ADD4A40BF44BC75FEAD4B40F38FBE49D3D84A40BF44BC75FEAD4B40
10899	29484	52.912970999999999	52.928207	55.549138999999997	55.536746000000001	Галиева	0103000020E610000001000000050000002499D53BDC744A402121CA17B4C44B402499D53BDC744A40A4FACE2F4AC64B408A75AA7CCF764A40A4FACE2F4AC64B408A75AA7CCF764A402121CA17B4C44B402499D53BDC744A402121CA17B4C44B40
79245	61490	52.626364000000002	53.491943999999997	55.942397999999997	55.388900999999997	Лесная	0103000020E6100000010000000500000025B20FB22C504A40DB300A82C7B14B4025B20FB22C504A406CE8667FA0F84B4051BB5F05F8BE4A406CE8667FA0F84B4051BB5F05F8BE4A40DB300A82C7B14B4025B20FB22C504A40DB300A82C7B14B40
10924	30252	53.063583000000001	53.081665999999998	55.682051999999999	55.672915000000003	Тукая	0103000020E6100000010000000500000071CADC7C23884A4072FE261422D64B4071CADC7C23884A40F015DD7A4DD74B40FA980F08748A4A40F015DD7A4DD74B40FA980F08748A4A4072FE261422D64B4071CADC7C23884A4072FE261422D64B40
10901	29663	52.869501999999997	52.880325999999997	55.635299000000003	55.625231999999997	Школьная	0103000020E610000001000000050000003EE76ED74B6F4A40D234289A07D04B403EE76ED74B6F4A403C17467A51D14B40C4E8B985AE704A403C17467A51D14B40C4E8B985AE704A40D234289A07D04B403EE76ED74B6F4A40D234289A07D04B40
10929	30500	52.855308000000001	52.868397000000002	55.778101999999997	55.772021000000002	Дружбы	0103000020E61000000100000005000000EB0088BB7A6D4A40A1698995D1E24B40EB0088BB7A6D4A40E179A9D898E34B40E67805A2276F4A40E179A9D898E34B40E67805A2276F4A40A1698995D1E24B40EB0088BB7A6D4A40A1698995D1E24B40
10928	30396	52.826796000000002	52.846235	55.764718000000002	55.753418000000003	Социалистическая	0103000020E61000000100000005000000583B8A73D4694A40DF1B430070E04B40583B8A73D4694A40CE548847E2E14B4083DDB06D516C4A40CE548847E2E14B4083DDB06D516C4A40DF1B430070E04B40583B8A73D4694A40DF1B430070E04B40
10912	29580	52.937235000000001	52.948175999999997	55.638694000000001	55.614652999999997	Школьная	0103000020E6100000010000000500000052D50451F7774A40B3B112F3ACCE4B4052D50451F7774A40621399B9C0D14B40116DC7D45D794A40621399B9C0D14B40116DC7D45D794A40B3B112F3ACCE4B4052D50451F7774A40B3B112F3ACCE4B40
10881	40836	53.406353000000003	53.423096999999999	55.456847000000003	55.446437000000003	Алая заря	0103000020E61000000100000005000000D5D0066003B44A40B85CFDD824B94B40D5D0066003B44A404B2366F679BA4B409204E10A28B64A404B2366F679BA4B409204E10A28B64A40B85CFDD824B94B40D5D0066003B44A40B85CFDD824B94B40
10891	29464	53.264284000000004	53.286436999999999	55.502960999999999	55.491942000000002	Имянле	0103000020E61000000100000005000000946DE00ED4A14A40B1C398F4F7BE4B40946DE00ED4A14A40EC14AB0661C04B40A3AEB5F7A9A44A40EC14AB0661C04B40A3AEB5F7A9A44A40B1C398F4F7BE4B40946DE00ED4A14A40B1C398F4F7BE4B40
10922	30186	53.049605	53.069547	55.656184000000003	55.635879000000003	Ленина	0103000020E61000000100000005000000EA5BE67459864A404A9BAA7B64D14B40EA5BE67459864A4049145AD6FDD34B40784485EAE6884A4049145AD6FDD34B40784485EAE6884A404A9BAA7B64D14B40EA5BE67459864A404A9BAA7B64D14B40
10926	30272	53.270060000000001	53.305858000000001	55.546785999999997	55.528120999999999	Горького	0103000020E6100000010000000500000098FA795391A24A4058AA0B7899C34B4098FA795391A24A4090F46915FDC54B40289CDD5A26A74A4090F46915FDC54B40289CDD5A26A74A4058AA0B7899C34B4098FA795391A24A4058AA0B7899C34B40
10927	30351	53.356056000000002	53.378855000000001	55.585520000000002	55.573475000000002	Новая	0103000020E61000000100000005000000B5C5353E93AD4A406C09F9A067C94B40B5C5353E93AD4A40B493C151F2CA4B408A7615527EB04A40B493C151F2CA4B408A7615527EB04A406C09F9A067C94B40B5C5353E93AD4A406C09F9A067C94B40
10905	29887	53.117131000000001	53.141511000000001	55.533369	55.524543999999999	Октября	0103000020E61000000100000005000000842C0B26FE8E4A4011A8FE4124C34B40842C0B26FE8E4A40A1D9756F45C44B401B834E081D924A40A1D9756F45C44B401B834E081D924A4011A8FE4124C34B40842C0B26FE8E4A4011A8FE4124C34B40
10892	40842	52.706277999999998	52.734493999999998	55.676828999999998	55.657595999999998	Марса	0103000020E6100000010000000500000030F14751675A4A407EFD101B2CD44B4030F14751675A4A4000FE2955A2D64B40DA8D3EE6035E4A4000FE2955A2D64B40DA8D3EE6035E4A407EFD101B2CD44B4030F14751675A4A407EFD101B2CD44B40
10917	30097	52.979069000000003	52.993082999999999	55.762124999999997	55.756543000000001	Центральная	0103000020E6100000010000000500000083C30B22527D4A404582A966D6E04B4083C30B22527D4A40643BDF4F8DE14B40569BFF571D7F4A40643BDF4F8DE14B40569BFF571D7F4A404582A966D6E04B4083C30B22527D4A404582A966D6E04B40
10909	30010	53.280920999999999	53.331145999999997	55.701084999999999	55.690480999999998	Школьная	0103000020E610000001000000050000003BE12538F5A34A4033C170AE61D84B403BE12538F5A34A40AB5B3D27BDD94B40C119FCFD62AA4A40AB5B3D27BDD94B40C119FCFD62AA4A4033C170AE61D84B403BE12538F5A34A4033C170AE61D84B40
10906	29961	53.097107999999999	53.121918999999998	55.471311	55.453003000000002	Центральная	0103000020E610000001000000050000000917F2086E8C4A40B5FE9600FCB94B400917F2086E8C4A405E9F39EB53BC4B4069E1B20A9B8F4A405E9F39EB53BC4B4069E1B20A9B8F4A40B5FE9600FCB94B400917F2086E8C4A40B5FE9600FCB94B40
10902	29719	52.826329000000001	52.840620999999999	55.670087000000002	55.661999000000002	Первомайская	0103000020E61000000100000005000000425E0F26C5694A400B7E1B62BCD44B40425E0F26C5694A40C53C2B69C5D54B4058AA0B78996B4A40C53C2B69C5D54B4058AA0B78996B4A400B7E1B62BCD44B40425E0F26C5694A400B7E1B62BCD44B40
11885	29875	53.177309000000001	53.196973	55.535488000000001	55.523071000000002	Мираня	0103000020E61000000100000005000000AB24B20FB2964A40363E93FDF3C24B40AB24B20FB2964A4042B3EBDE8AC44B40F698486936994A4042B3EBDE8AC44B40F698486936994A40363E93FDF3C24B40AB24B20FB2964A40363E93FDF3C24B40
10925	29753	52.837826999999997	52.850501999999999	55.571637000000003	55.561385000000001	К.Маркса	0103000020E61000000100000005000000575A46EA3D6B4A4084BBB376DBC74B40575A46EA3D6B4A407F17B6662BC94B405F97E13FDD6C4A407F17B6662BC94B405F97E13FDD6C4A4084BBB376DBC74B40575A46EA3D6B4A4084BBB376DBC74B40
10945	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Шамова	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10939	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Чернышевского	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10942	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Челнинский Тракт	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10947	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Татарстан	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10933	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Строителей	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10941	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	М. Джалиля	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10948	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Ленина	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10940	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	К.Маркса	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10935	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Изыскателей	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10937	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Гурьянова	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10943	30688	53.069223999999998	53.135232000000002	55.74147	55.708860999999999	Головина	0103000020E61000000100000005000000950C0055DC884A4076340EF5BBDA4B40950C0055DC884A40897B2C7DE8DE4B40B4AF3C484F914A40897B2C7DE8DE4B40B4AF3C484F914A4076340EF5BBDA4B40950C0055DC884A4076340EF5BBDA4B40
10883	29139	53.342230999999998	53.359057	55.630206999999999	55.623930000000001	Советская	0103000020E61000000100000005000000B456B439CEAB4A40247F30F0DCCF4B40B456B439CEAB4A40EA5A7B9FAAD04B402F336C94F5AD4A40EA5A7B9FAAD04B402F336C94F5AD4A40247F30F0DCCF4B40B456B439CEAB4A40247F30F0DCCF4B40
10900	29618	52.743817999999997	52.776831000000001	55.636671	55.626247999999997	Советская	0103000020E610000001000000050000008B16A06D355F4A40BB97FBE428D04B408B16A06D355F4A40E3A7716F7ED14B406EC2BD326F634A40E3A7716F7ED14B406EC2BD326F634A40BB97FBE428D04B408B16A06D355F4A40BB97FBE428D04B40
10898	29533	52.934323999999997	52.960707999999997	55.698141999999997	55.687334999999997	Центральная	0103000020E6100000010000000500000017EFC7ED97774A40B532E197FAD74B4017EFC7ED97774A4065FB90B75CD94B40B680D07AF87A4A4065FB90B75CD94B40B680D07AF87A4A40B532E197FAD74B4017EFC7ED97774A40B532E197FAD74B40
10915	40852	53.296345000000002	53.315291000000002	55.486682999999999	55.474995	Гагарина	0103000020E61000000100000005000000A4AA09A2EEA54A40BB61DBA2CCBC4B40A4AA09A2EEA54A407442E8A04BBE4B4090DC9A745BA84A407442E8A04BBE4B4090DC9A745BA84A40BB61DBA2CCBC4B40A4AA09A2EEA54A40BB61DBA2CCBC4B40
79270	61510	53.329089000000003	53.346130000000002	55.444327999999999	55.433016000000002	Школьная	0103000020E61000000100000005000000973C9E961FAA4A4087527B116DB74B40973C9E961FAA4A403A596ABDDFB84B400E15E3FC4DAC4A403A596ABDDFB84B400E15E3FC4DAC4A4087527B116DB74B40973C9E961FAA4A4087527B116DB74B40
10896	29452	52.948175999999997	52.962575999999999	55.543104	55.521026999999997	Кирова	0103000020E61000000100000005000000116DC7D45D794A409FAA4203B1C24B40116DC7D45D794A40D4298F6E84C54B400EF5BBB0357B4A40D4298F6E84C54B400EF5BBB0357B4A409FAA4203B1C24B40116DC7D45D794A409FAA4203B1C24B40
79216	61467	53.153109000000001	53.178108999999999	55.720418000000002	55.691657999999997	Центральная	0103000020E6100000010000000500000094DC611399934A402502D53F88D84B4094DC611399934A4091B932A836DC4B40C70F9546CC964A4091B932A836DC4B40C70F9546CC964A402502D53F88D84B4094DC611399934A402502D53F88D84B40
10911	30041	53.340685999999998	53.365183000000002	55.701141	55.693793999999997	М. Джалиля	0103000020E610000001000000050000003F1A4E999BAB4A409C14E63DCED84B403F1A4E999BAB4A403F7100FDBED94B4010070951BEAE4A403F7100FDBED94B4010070951BEAE4A409C14E63DCED84B403F1A4E999BAB4A409C14E63DCED84B40
10944	29058	53.169969999999999	53.182941999999997	55.663871999999998	55.651653000000003	Школьная	0103000020E610000001000000050000008BA6B393C1954A408FAB915D69D34B408BA6B393C1954A40745DF8C1F9D44B404C88B9A46A974A40745DF8C1F9D44B404C88B9A46A974A408FAB915D69D34B408BA6B393C1954A408FAB915D69D34B40
10920	30139	52.896028999999999	52.916421	55.773150000000001	55.758761999999997	Советская	0103000020E6100000010000000500000040A20914B1724A4049B9FB1C1FE14B4040A20914B1724A4082734694F6E24B400E2F88484D754A4082734694F6E24B400E2F88484D754A4049B9FB1C1FE14B4040A20914B1724A4049B9FB1C1FE14B40
10931	30542	52.902101000000002	52.91554	55.802957999999997	55.794334999999997	Строительная	0103000020E610000001000000050000002E58AA0B78734A40B988EFC4ACE54B402E58AA0B78734A40E107E753C7E64B4005172B6A30754A40E107E753C7E64B4005172B6A30754A40B988EFC4ACE54B402E58AA0B78734A40B988EFC4ACE54B40
10886	40838	52.678223000000003	52.708703	55.658779000000003	55.645806999999998	М. Джалиля	0103000020E610000001000000050000009032E202D0564A409143C4CDA9D24B409032E202D0564A405325CADE52D44B40DEC9A7C7B65A4A405325CADE52D44B40DEC9A7C7B65A4A409143C4CDA9D24B409032E202D0564A409143C4CDA9D24B40
10932	30658	53.010393000000001	53.030920000000002	55.561925000000002	55.548777000000001	Новая	0103000020E61000000100000005000000BD8DCD8E54814A4004E621533EC64B40BD8DCD8E54814A4004E78C28EDC74B406B65C22FF5834A4004E78C28EDC74B406B65C22FF5834A4004E621533EC64B40BD8DCD8E54814A4004E621533EC64B40
10882	29077	53.418022000000001	53.459614000000002	55.662654000000003	55.637672000000002	Ленина	0103000020E610000001000000050000001781B1BE81B54A4097C9703C9FD14B401781B1BE81B54A402448A5D8D1D44B405264ADA1D4BA4A402448A5D8D1D44B405264ADA1D4BA4A4097C9703C9FD14B401781B1BE81B54A4097C9703C9FD14B40
10878	28884	53.343209999999999	53.355184999999999	55.471643	55.456561000000001	Центральная	0103000020E6100000010000000500000080D4264EEEAB4A4085D0419770BA4B4080D4264EEEAB4A4094313ECC5EBC4B40CF83BBB376AD4A4094313ECC5EBC4B40CF83BBB376AD4A4085D0419770BA4B4080D4264EEEAB4A4085D0419770BA4B40
10877	28814	52.564155	52.588158	55.956688	55.947177000000003	Центральная	0103000020E61000000100000005000000FC6F253B36484A40FF428F183DF94B40FC6F253B36484A40E23C9CC074FA4B40BD70E7C2484B4A40E23C9CC074FA4B40BD70E7C2484B4A40FF428F183DF94B40FC6F253B36484A40FF428F183DF94B40
10864	28312	52.385705000000002	52.403635000000001	56.020395999999998	56.005561	Вахитова	0103000020E61000000100000005000000AC730CC85E314A4008910C39B6004C40AC730CC85E314A400F7C0C569C024C40AF42CA4FAA334A400F7C0C569C024C40AF42CA4FAA334A4008910C39B6004C40AC730CC85E314A4008910C39B6004C40
10876	28762	52.444940000000003	52.491616	56.064298000000001	56.052923999999997	Центральная	0103000020E6100000010000000500000054573ECBF3384A403596B036C6064C4054573ECBF3384A405F99B7EA3A084C405D18E945ED3E4A405F99B7EA3A084C405D18E945ED3E4A403596B036C6064C4054573ECBF3384A403596B036C6064C40
10875	28725	52.226137000000001	52.239880999999997	55.808669999999999	55.798444000000003	Коммунистическая	0103000020E6100000010000000500000031B5A50EF21C4A40FED7B96933E64B4031B5A50EF21C4A40CFA0A17F82E74B4044F7AC6BB41E4A40CFA0A17F82E74B4044F7AC6BB41E4A40FED7B96933E64B4031B5A50EF21C4A40FED7B96933E64B40
10874	28677	52.213318000000001	52.228608000000001	55.864711999999997	55.854466000000002	Школьная	0103000020E61000000100000005000000F6D214014E1B4A40A0C552245FED4B40F6D214014E1B4A40B83A00E2AEEE4B404FCDE506431D4A40B83A00E2AEEE4B404FCDE506431D4A40A0C552245FED4B40F6D214014E1B4A40A0C552245FED4B40
10860	28079	52.248263000000001	52.273513999999999	55.943669	55.936998000000003	Молодежная	0103000020E6100000010000000500000047E7FC14C71F4A406E35EB8CEFF74B4047E7FC14C71F4A40E09F5225CAF84B40C37FBA8102234A40E09F5225CAF84B40C37FBA8102234A406E35EB8CEFF74B4047E7FC14C71F4A406E35EB8CEFF74B40
10861	28146	52.391300999999999	52.405718999999998	55.948633999999998	55.939832000000003	Дружбы	0103000020E6100000010000000500000030F2B22616324A40FDDD3B6A4CF84B4030F2B22616324A40D4EFC2D66CF94B40D32EA699EE334A40D4EFC2D66CF94B40D32EA699EE334A40FDDD3B6A4CF84B4030F2B22616324A40FDDD3B6A4CF84B40
10873	28608	52.503312000000001	52.529912000000003	55.975062999999999	55.964649999999999	Тукая	0103000020E6100000010000000500000099D711876C404A400F0BB5A679FB4B4099D711876C404A40134548DDCEFC4B4005E10A28D4434A40134548DDCEFC4B4005E10A28D4434A400F0BB5A679FB4B4099D711876C404A400F0BB5A679FB4B40
10872	28585	52.249510999999998	52.268025999999999	55.897830999999996	55.886144999999999	Ленина	0103000020E61000000100000005000000027FF8F9EF1F4A40C84109336DF14B40027FF8F9EF1F4A40E02A4F20ECF24B40253D0CAD4E224A40E02A4F20ECF24B40253D0CAD4E224A40C84109336DF14B40027FF8F9EF1F4A40C84109336DF14B40
10868	28428	52.280216000000003	52.306977000000003	56.04853	56.037588999999997	Школьная	0103000020E6100000010000000500000071E82D1EDE234A403CD862B7CF044C4071E82D1EDE234A40FC6F253B36064C40E6CFB7054B274A40FC6F253B36064C40E6CFB7054B274A403CD862B7CF044C4071E82D1EDE234A403CD862B7CF044C40
10855	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	бульвар Интернационалистов	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
11853	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	б-р Интернационалистов	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10854	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Юбилейная	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10852	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Фомина	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10857	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Тукая	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10858	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Татарстана	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10851	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Профсоюзная	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10856	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Набережная	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10850	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	М.Горького	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10849	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Зеленая	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10853	27253	52.277197000000001	52.343978	55.920028000000002	55.872394999999997	Бурмистрова	0103000020E6100000010000000500000050C6F8307B234A40D218ADA3AAEF4B4050C6F8307B234A40C0B33D7AC3F54B4091459A78072C4A40C0B33D7AC3F54B4091459A78072C4A40D218ADA3AAEF4B4050C6F8307B234A40D218ADA3AAEF4B40
10869	28405	52.317746999999997	52.347436999999999	56.013699000000003	56.001151999999998	Д.Сирая	0103000020E6100000010000000500000078B306EFAB284A409929ADBF25004C4078B306EFAB284A40747E8AE3C0014C40CE35CCD0782C4A40747E8AE3C0014C40CE35CCD0782C4A409929ADBF25004C4078B306EFAB284A409929ADBF25004C40
10870	28499	52.226630999999998	52.25385	56.024149000000001	56.009658000000002	Школьная	0103000020E6100000010000000500000040A19E3E021D4A4088122D793C014C4040A19E3E021D4A40959D7E5017034C40780B24287E204A40959D7E5017034C40780B24287E204A4088122D793C014C4040A19E3E021D4A4088122D793C014C40
10866	28336	52.622115000000001	52.639730999999998	55.969562000000003	55.960588000000001	Советская	0103000020E61000000100000005000000EFACDD76A14F4A400C772E8CF4FA4B40EFACDD76A14F4A40E1B88C9B1AFC4B40629E95B4E2514A40E1B88C9B1AFC4B40629E95B4E2514A400C772E8CF4FA4B40EFACDD76A14F4A400C772E8CF4FA4B40
10863	28244	52.322319999999998	52.338939000000003	55.987048999999999	55.973027999999999	Клубная	0103000020E61000000100000005000000616C21C841294A40D00B772E8CFC4B40616C21C841294A405646239F57FE4B40632B685A622B4A405646239F57FE4B40632B685A622B4A40D00B772E8CFC4B40616C21C841294A40D00B772E8CFC4B40
10862	40834	52.071879000000003	52.767766999999999	56.098832999999999	55.790098999999998	Заречная	0103000020E610000001000000050000007522C15433094A4018CDCAF621E54B407522C15433094A40FE614B8FA60C4C4059F9653046624A40FE614B8FA60C4C4059F9653046624A4018CDCAF621E54B407522C15433094A4018CDCAF621E54B40
10859	28039	52.444777999999999	52.461396999999998	55.934654000000002	55.917409999999997	Новая	0103000020E610000001000000050000007AFD497CEE384A40FD82DDB06DF54B407AFD497CEE384A40AD8905BEA2F74B407BBC900E0F3B4A40AD8905BEA2F74B407BBC900E0F3B4A40FD82DDB06DF54B407AFD497CEE384A40FD82DDB06DF54B40
79334	61529	51.278647999999997	51.292940000000002	55.633052999999997	55.621206000000001	Гагарина	0103000020E61000000100000005000000438CD7BCAAA349401C0A9FAD83CF4B40438CD7BCAAA349403DD175E107D14B405AD8D30E7FA549403DD175E107D14B405AD8D30E7FA549401C0A9FAD83CF4B40438CD7BCAAA349401C0A9FAD83CF4B40
79118	61391	51.408095000000003	51.421120999999999	55.665872999999998	55.654736	Садовая	0103000020E61000000100000005000000A054FB743CB44940C6C1A563CED34B40A054FB743CB449400B2593533BD54B405454FD4AE7B549400B2593533BD54B405454FD4AE7B54940C6C1A563CED34B40A054FB743CB44940C6C1A563CED34B40
77665	61226	51.352310000000003	51.377436000000003	55.714820000000003	55.702058999999998	 Мира	0103000020E61000000100000005000000E2067C7E18AD4940656EBE11DDD94B40E2067C7E18AD49406C43C5387FDB4B40A22AA6D24FB049406C43C5387FDB4B40A22AA6D24FB04940656EBE11DDD94B40E2067C7E18AD4940656EBE11DDD94B40
10846	27217	51.00441	51.034171999999998	55.915861	55.907021	Г. Тукая	0103000020E610000001000000050000003FE3C2819080494082E49D4319F44B403FE3C281908049404757E9EE3AF54B402E3883BF5F8449404757E9EE3AF54B402E3883BF5F84494082E49D4319F44B403FE3C2819080494082E49D4319F44B40
10845	27180	51.258921000000001	51.287388999999997	55.929837999999997	55.918691000000003	Молодежная	0103000020E61000000100000005000000B29FC55224A149409510ACAA97F54B40B29FC55224A14940FD497CEE04F74B40751DAA29C9A44940FD497CEE04F74B40751DAA29C9A449409510ACAA97F54B40B29FC55224A149409510ACAA97F54B40
10844	27136	51.108175000000003	51.122162000000003	55.818644999999997	55.806944999999999	Ленина	0103000020E61000000100000005000000569FABADD88D4940DA5548F949E74B40569FABADD88D49405704FF5BC9E84B4030682101A38F49405704FF5BC9E84B4030682101A38F4940DA5548F949E74B40569FABADD88D4940DA5548F949E74B40
10843	27067	50.843440999999999	50.868181	55.702120000000001	55.684874000000001	Центральная	0103000020E61000000100000005000000828DEBDFF56B4940BBF083F3A9D74B40828DEBDFF56B49400BEF7211DFD94B401901158E206F49400BEF7211DFD94B401901158E206F4940BBF083F3A9D74B40828DEBDFF56B4940BBF083F3A9D74B40
10842	27059	51.124991000000001	51.153188999999998	55.597200000000001	55.583534999999998	Центральная 	0103000020E61000000100000005000000ADA580B4FF8F494022895E46B1CA4B40ADA580B4FF8F4940EA95B20C71CC4B40B08D78B29B934940EA95B20C71CC4B40B08D78B29B93494022895E46B1CA4B40ADA580B4FF8F494022895E46B1CA4B40
10840	26986	51.056323999999996	51.073509000000001	55.916924999999999	55.904300999999997	Пионерская	0103000020E610000001000000050000006DFDF49F35874940BB5E9A22C0F34B406DFDF49F3587494041F163CC5DF54B40187B2FBE6889494041F163CC5DF54B40187B2FBE68894940BB5E9A22C0F34B406DFDF49F35874940BB5E9A22C0F34B40
10838	26948	50.973067999999998	51.013699000000003	55.871405000000003	55.856476999999998	Нагорная	0103000020E610000001000000050000005E64027E8D7C49405A63D009A1ED4B405E64027E8D7C49401349F4328AEF4B40747E8AE3C08149401349F4328AEF4B40747E8AE3C08149405A63D009A1ED4B405E64027E8D7C49405A63D009A1ED4B40
10837	26912	51.254744000000002	51.284109999999998	55.837130999999999	55.828136999999998	Школьная	0103000020E61000000100000005000000166D8E739BA04940C4CDA96400EA4B40166D8E739BA04940E0BBCD1B27EB4B40B83B6BB75DA44940E0BBCD1B27EB4B40B83B6BB75DA44940C4CDA96400EA4B40166D8E739BA04940C4CDA96400EA4B40
10841	26870	51.111975000000001	51.135223000000003	55.690040000000003	55.666339999999998	Ленина	0103000020E610000001000000050000001C7C6132558E494021020EA14AD54B401C7C6132558E49404777103B53D84B406155BDFC4E9149404777103B53D84B406155BDFC4E91494021020EA14AD54B401C7C6132558E494021020EA14AD54B40
10836	26791	51.497666000000002	51.515416999999999	55.560189000000001	55.534505000000003	Школьная	0103000020E61000000100000005000000632AFD84B3BF49403546EBA86AC44B40632AFD84B3BF49401B4AED45B4C74B40B6662B2FF9C149401B4AED45B4C74B40B6662B2FF9C149403546EBA86AC44B40632AFD84B3BF49403546EBA86AC44B40
10833	26719	51.294925999999997	51.332636999999998	55.559958999999999	55.546491000000003	Школьная	0103000020E61000000100000005000000BB5E9A22C0A549407847C66AF3C54B40BB5E9A22C0A54940E90C8CBCACC74B40433866D993AA4940E90C8CBCACC74B40433866D993AA49407847C66AF3C54B40BB5E9A22C0A549407847C66AF3C54B40
10834	26668	51.237344	51.265542000000003	55.540664	55.532043999999999	Новая	0103000020E610000001000000050000006FF3C649619E49403A048E041AC44B406FF3C649619E4940F10F5B7A34C54B4073DBBE47FDA14940F10F5B7A34C54B4073DBBE47FDA149403A048E041AC44B406FF3C649619E49403A048E041AC44B40
10829	26586	51.301806999999997	51.319763999999999	55.988449000000003	55.976775000000004	Октябрьская	0103000020E61000000100000005000000185A9D9CA1A64940744694F606FD4B40185A9D9CA1A64940C861307F85FE4B401538D906EEA84940C861307F85FE4B401538D906EEA84940744694F606FD4B40185A9D9CA1A64940744694F606FD4B40
10831	26521	51.419908	51.451017	55.632525000000001	55.615969999999997	Октябрьская	0103000020E6100000010000000500000015AA9B8BBFB5494097A8DE1AD8CE4B4015AA9B8BBFB5494082734694F6D04B405378D0ECBAB9494082734694F6D04B405378D0ECBAB9494097A8DE1AD8CE4B4015AA9B8BBFB5494097A8DE1AD8CE4B40
10827	26490	51.172710000000002	51.196389000000003	55.552205000000001	55.535147000000002	Школьная	0103000020E6100000010000000500000099D87C5C1B964940B9C667B27FC44B4099D87C5C1B96494006D847A7AEC64B40A72556462399494006D847A7AEC64B40A725564623994940B9C667B27FC44B4099D87C5C1B964940B9C667B27FC44B40
10824	26423	51.136867000000002	51.157933	55.917163000000002	55.903680999999999	Ш. Маннура	0103000020E6100000010000000500000069739CDB849149401F82AAD1ABF34B4069739CDB84914940F60CE19865F54B40C6FA062637944940F60CE19865F54B40C6FA0626379449401F82AAD1ABF34B4069739CDB849149401F82AAD1ABF34B40
78530	61311	\N	\N	\N	\N	Березовая	\N
10818	26309	50.869276999999997	50.912072999999999	55.852763000000003	55.838707999999997	К. Маркса	0103000020E610000001000000050000001E15FF77446F49406072A3C85AEB4B401E15FF77446F4940931E865627ED4B404548DDCEBE744940931E865627ED4B404548DDCEBE7449406072A3C85AEB4B401E15FF77446F49406072A3C85AEB4B40
10815	26209	51.016052999999999	51.033399000000003	55.980870000000003	55.972811	Первомайская	0103000020E61000000100000005000000580053060E8249403318231285FC4B40580053060E82494053D0ED258DFD4B400C5C1E6B4684494053D0ED258DFD4B400C5C1E6B468449403318231285FC4B40580053060E8249403318231285FC4B40
10808	26126	50.907221999999997	50.931646999999998	55.661490999999998	55.644607999999998	К. Маркса	0103000020E61000000100000005000000191BBAD91F744940B75ED38382D24B40191BBAD91F74494096CCB1BCABD44B4050357A354077494096CCB1BCABD44B4050357A3540774940B75ED38382D24B40191BBAD91F744940B75ED38382D24B40
11058	26079	51.270060000000001	51.321956	55.736184000000002	55.721634999999999	Советская	0103000020E6100000010000000500000098FA795391A24940115322895EDC4B4098FA795391A2494053EBFD463BDE4B402060ADDA35A9494053EBFD463BDE4B402060ADDA35A94940115322895EDC4B4098FA795391A24940115322895EDC4B40
10795	25411	51.171146999999998	51.194116999999999	55.908645999999997	55.899441000000003	Татарстан	0103000020E610000001000000050000007DE71725E89549403DD7F7E120F34B407DE71725E895494013D21A834EF44B407F4C6BD3D898494013D21A834EF44B407F4C6BD3D89849403DD7F7E120F34B407DE71725E89549403DD7F7E120F34B40
10810	26145	51.034747000000003	51.065379	55.947187	55.925525999999998	Советская	0103000020E610000001000000050000002B51F6967284494081CCCEA277F64B402B51F696728449402219726C3DF94B402F6CCD565E8849402219726C3DF94B402F6CCD565E88494081CCCEA277F64B402B51F6967284494081CCCEA277F64B40
79133	61402	51.046999999999997	51.067050000000002	55.642377000000003	55.626593999999997	Ленина	0103000020E61000000100000005000000BC7493180486494056EF703B34D04B40BC74931804864940EF59D76839D24B4031992A1895884940EF59D76839D24B4031992A189588494056EF703B34D04B40BC7493180486494056EF703B34D04B40
11845	25669	51.375611999999997	51.427076999999997	55.734997999999997	55.679093000000002	Текстильный переулок	0103000020E6100000010000000500000019FED30D14B04940A5F8F884ECD64B4019FED30D14B049400D501A6A14DE4B40D8EF8975AAB649400D501A6A14DE4B40D8EF8975AAB64940A5F8F884ECD64B4019FED30D14B04940A5F8F884ECD64B40
10804	25669	51.375611999999997	51.427076999999997	55.734997999999997	55.679093000000002	Советская	0103000020E6100000010000000500000019FED30D14B04940A5F8F884ECD64B4019FED30D14B049400D501A6A14DE4B40D8EF8975AAB649400D501A6A14DE4B40D8EF8975AAB64940A5F8F884ECD64B4019FED30D14B04940A5F8F884ECD64B40
10798	25669	51.375611999999997	51.427076999999997	55.734997999999997	55.679093000000002	Ленина	0103000020E6100000010000000500000019FED30D14B04940A5F8F884ECD64B4019FED30D14B049400D501A6A14DE4B40D8EF8975AAB649400D501A6A14DE4B40D8EF8975AAB64940A5F8F884ECD64B4019FED30D14B04940A5F8F884ECD64B40
10807	25669	51.375611999999997	51.427076999999997	55.734997999999997	55.679093000000002	Давыдова	0103000020E6100000010000000500000019FED30D14B04940A5F8F884ECD64B4019FED30D14B049400D501A6A14DE4B40D8EF8975AAB649400D501A6A14DE4B40D8EF8975AAB64940A5F8F884ECD64B4019FED30D14B04940A5F8F884ECD64B40
10805	25669	51.375611999999997	51.427076999999997	55.734997999999997	55.679093000000002	Горького	0103000020E6100000010000000500000019FED30D14B04940A5F8F884ECD64B4019FED30D14B049400D501A6A14DE4B40D8EF8975AAB649400D501A6A14DE4B40D8EF8975AAB64940A5F8F884ECD64B4019FED30D14B04940A5F8F884ECD64B40
10801	25669	51.375611999999997	51.427076999999997	55.734997999999997	55.679093000000002	Азина	0103000020E6100000010000000500000019FED30D14B04940A5F8F884ECD64B4019FED30D14B049400D501A6A14DE4B40D8EF8975AAB649400D501A6A14DE4B40D8EF8975AAB64940A5F8F884ECD64B4019FED30D14B04940A5F8F884ECD64B40
10800	25568	51.068379	51.098401000000003	55.746091	55.731231999999999	Нигматуллина	0103000020E61000000100000005000000D95DA0A4C0884940F3E49A0299DD4B40D95DA0A4C0884940836BEEE87FDF4B4065726A67988C4940836BEEE87FDF4B4065726A67988C4940F3E49A0299DD4B40D95DA0A4C0884940F3E49A0299DD4B40
10791	25531	51.344225000000002	51.364328999999998	55.818841999999997	55.807881000000002	Советская	0103000020E6100000010000000500000099BB96900FAC4940A70705A568E74B4099BB96900FAC4940AD4B8DD0CFE84B4000FE2955A2AE4940AD4B8DD0CFE84B4000FE2955A2AE4940A70705A568E74B4099BB96900FAC4940A70705A568E74B40
10797	25633	50.921424000000002	50.943226000000003	55.715094000000001	55.700380000000003	Советская	0103000020E61000000100000005000000F0DFBC38F1754940E162450DA6D94B40F0DFBC38F17549406DC83F3388DB4B40535E2BA1BB7849406DC83F3388DB4B40535E2BA1BB784940E162450DA6D94B40F0DFBC38F1754940E162450DA6D94B40
10823	26319	51.330939000000001	51.361975999999999	55.855137999999997	55.847588999999999	Гагарина	0103000020E6100000010000000500000048FC8A355CAA494084B9DDCB7DEC4B4048FC8A355CAA49408EC8772975ED4B40ECF7C43A55AE49408EC8772975ED4B40ECF7C43A55AE494084B9DDCB7DEC4B4048FC8A355CAA494084B9DDCB7DEC4B40
11844	25467	50.874136999999997	50.899856	55.626223000000003	55.609181999999997	А.Гайдара	0103000020E610000001000000050000009D9CA1B8E36F4940EBA7FFACF9CD4B409D9CA1B8E36F49406380441328D04B40008E3D7B2E7349406380441328D04B40008E3D7B2E734940EBA7FFACF9CD4B409D9CA1B8E36F4940EBA7FFACF9CD4B40
10785	25395	51.358364999999999	51.377794999999999	55.707284000000001	55.691831000000001	Ямашева	0103000020E61000000100000005000000F98381E7DEAD4940F3AD0FEB8DD84B40F98381E7DEAD4940F67D384888DA4B40D1CB28965BB04940F67D384888DA4B40D1CB28965BB04940F3AD0FEB8DD84B40F98381E7DEAD4940F3AD0FEB8DD84B40
10784	25352	51.118766000000001	51.148581	55.963797999999997	55.954338999999997	Центральная	0103000020E6100000010000000500000039F06AB9338F49400F26C5C727FA4B4039F06AB9338F4940A0F99CBB5DFB4B404BE7C3B304934940A0F99CBB5DFB4B404BE7C3B3049349400F26C5C727FA4B4039F06AB9338F49400F26C5C727FA4B40
10783	25292	50.822232	50.859081000000003	55.646197999999998	55.629623000000002	Ленина	0103000020E61000000100000005000000C2DCEEE53E6949409BE7887C97D04B40C2DCEEE53E694940CC5EB69DB6D24B40B8CEBF5DF66D4940CC5EB69DB6D24B40B8CEBF5DF66D49409BE7887C97D04B40C2DCEEE53E6949409BE7887C97D04B40
10769	24672	50.949604000000001	50.976688000000003	55.837175999999999	55.821396	Школьная	0103000020E610000001000000050000004D13B69F8C79494059880E8123E94B404D13B69F8C794940807F4A9528EB4B40A532C51C047D4940807F4A9528EB4B40A532C51C047D494059880E8123E94B404D13B69F8C79494059880E8123E94B40
10782	25195	51.335574000000001	51.364195000000002	55.955770999999999	55.938521000000001	Советская	0103000020E61000000100000005000000A7B1BD16F4AA4940FBCDC47421F84B40A7B1BD16F4AA49408CBB41B456FA4B40F12E17F19DAE49408CBB41B456FA4B40F12E17F19DAE4940FBCDC47421F84B40A7B1BD16F4AA4940FBCDC47421F84B40
78409	61296	50.619185999999999	51.578882999999998	56.072001999999998	55.440697	Ленина	0103000020E610000001000000050000000E12A27C414F4940003961C268B84B400E12A27C414F4940909F8D5C37094C40ED9A90D618CA4940909F8D5C37094C40ED9A90D618CA4940003961C268B84B400E12A27C414F4940003961C268B84B40
11026	25061	51.243640999999997	51.265407000000003	55.868167	55.859923000000002	Молодежная	0103000020E610000001000000050000007C7BD7A02F9F4940030AF5F411EE4B407C7BD7A02F9F4940B43BA41820EF4B40939048DBF8A14940B43BA41820EF4B40939048DBF8A14940030AF5F411EE4B407C7BD7A02F9F4940030AF5F411EE4B40
10966	32003	51.090128	51.115065000000001	55.919044	55.914166000000002	Центральная	0103000020E61000000100000005000000193A7650898B4940BD8E386403F54B40193A7650898B4940E2CAD93BA3F54B4006F52D73BA8E4940E2CAD93BA3F54B4006F52D73BA8E4940BD8E386403F54B40193A7650898B4940BD8E386403F54B40
10835	40831	50.619185999999999	51.578882999999998	56.072001999999998	55.440697	Центральная	0103000020E610000001000000050000000E12A27C414F4940003961C268B84B400E12A27C414F4940909F8D5C37094C40ED9A90D618CA4940909F8D5C37094C40ED9A90D618CA4940003961C268B84B400E12A27C414F4940003961C268B84B40
10774	24972	51.026679999999999	51.045040999999998	55.590057999999999	55.582115999999999	Центральная	0103000020E6100000010000000500000088BA0F406A8349403A3DEFC682CA4B4088BA0F406A834940205F420587CB4B4054FD4AE7C3854940205F420587CB4B4054FD4AE7C38549403A3DEFC682CA4B4088BA0F406A8349403A3DEFC682CA4B40
10814	24951	51.437092999999997	51.446677999999999	55.889543000000003	55.882182	Красное Знамя	0103000020E61000000100000005000000BF27D6A9F2B74940588FFB56EBF04B40BF27D6A9F2B7494060B1868BDCF14B40DDEBA4BE2CB9494060B1868BDCF14B40DDEBA4BE2CB94940588FFB56EBF04B40BF27D6A9F2B74940588FFB56EBF04B40
10765	24720	50.841717000000003	50.866895999999997	55.744374000000001	55.721797000000002	Школьная	0103000020E610000001000000050000005EBEF561BD6B4940EBAC16D863DC4B405EBEF561BD6B494011FFB0A547DF4B404084B872F66E494011FFB0A547DF4B404084B872F66E4940EBAC16D863DC4B405EBEF561BD6B4940EBAC16D863DC4B40
10813	24868	50.939283000000003	50.978799000000002	55.754643999999999	55.735191	Советская	0103000020E610000001000000050000002A58E36C3A78494022A81ABD1ADE4B402A58E36C3A784940B20FB22C98E04B40C32D1F49497D4940B20FB22C98E04B40C32D1F49497D494022A81ABD1ADE4B402A58E36C3A78494022A81ABD1ADE4B40
10811	24803	51.198481999999998	51.219538999999997	55.769454000000003	55.751674999999999	Советская	0103000020E610000001000000050000001E6CB1DB67994940431CEBE236E04B401E6CB1DB6799494061E3FA777DE24B4028999CDA199C494061E3FA777DE24B4028999CDA199C4940431CEBE236E04B401E6CB1DB67994940431CEBE236E04B40
10767	24778	50.790638000000001	50.820939000000003	55.731526000000002	55.714511000000002	Советская	0103000020E61000000100000005000000C87C40A033654940EED0B01875DB4B40C87C40A0336549403C16DBA4A2DD4B4067817687146949403C16DBA4A2DD4B406781768714694940EED0B01875DB4B40C87C40A033654940EED0B01875DB4B40
79254	61496	50.619185999999999	51.578882999999998	56.072001999999998	55.440697	Центральная	0103000020E610000001000000050000000E12A27C414F4940003961C268B84B400E12A27C414F4940909F8D5C37094C40ED9A90D618CA4940909F8D5C37094C40ED9A90D618CA4940003961C268B84B400E12A27C414F4940003961C268B84B40
10763	24629	51.315066000000002	51.336813999999997	55.897911999999998	55.888199999999998	Давыдова	0103000020E61000000100000005000000700A2B1554A849405227A089B0F14B40700A2B1554A84940CD57C9C7EEF24B40DF6A9DB81CAB4940CD57C9C7EEF24B40DF6A9DB81CAB49405227A089B0F14B40700A2B1554A849405227A089B0F14B40
10762	24529	50.720669000000001	50.750582000000001	55.774056000000002	55.762196000000003	Центральная	0103000020E61000000100000005000000DA1EBDE13E5C49402E9276A38FE14B40DA1EBDE13E5C4940E4A25A4414E34B40AF7B2B1213604940E4A25A4414E34B40AF7B2B12136049402E9276A38FE14B40DA1EBDE13E5C49402E9276A38FE14B40
10718	23397	51.828543000000003	51.844695000000002	54.570844000000001	54.544587	Советская	0103000020E61000000100000005000000352A70B20DEA4940D369DD06B5454B40352A70B20DEA4940158F8B6A11494B40200C3CF71EEC4940158F8B6A11494B40200C3CF71EEC4940D369DD06B5454B40352A70B20DEA4940D369DD06B5454B40
10742	24068	52.246223999999998	52.262895999999998	54.497587000000003	54.488264000000001	Советская	0103000020E61000000100000005000000C2BE9D44841F4A4036E84B6F7F3E4B40C2BE9D44841F4A4017F549EEB03F4B40E61F7D93A6214A4017F549EEB03F4B40E61F7D93A6214A4036E84B6F7F3E4B40C2BE9D44841F4A4036E84B6F7F3E4B40
10760	24466	52.113453	52.142378000000001	54.525827999999997	54.502302999999998	Ленина	0103000020E610000001000000050000000951BEA0850E4A4062D7F6764B404B400951BEA0850E4A4019A9F7544E434B40BFD53A7139124A4019A9F7544E434B40BFD53A7139124A4062D7F6764B404B400951BEA0850E4A4062D7F6764B404B40
10754	24364	51.976936000000002	51.996096999999999	54.686281000000001	54.664254999999997	Советская	0103000020E610000001000000050000007D24253D0CFD49402C9ACE4E06554B407D24253D0CFD4940DF6E490ED8574B406552431B80FF4940DF6E490ED8574B406552431B80FF49402C9ACE4E06554B407D24253D0CFD49402C9ACE4E06554B40
79281	61517	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Школьная	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10780	24272	51.891263000000002	51.929845999999998	54.763897999999998	54.747636	Центральная	0103000020E610000001000000050000004391EEE714F24940F8A75489B25F4B404391EEE714F249406ABDDF68C7614B408028983105F749406ABDDF68C7614B408028983105F74940F8A75489B25F4B404391EEE714F24940F8A75489B25F4B40
10750	24206	52.112141000000001	52.136656000000002	54.427007000000003	54.403807	Советская	0103000020E6100000010000000500000037C5E3A25A0E4A40AC72A1F2AF334B4037C5E3A25A0E4A40E014562AA8364B40AE669DF17D114A40E014562AA8364B40AE669DF17D114A40AC72A1F2AF334B4037C5E3A25A0E4A40AC72A1F2AF334B40
10746	24111	52.346601	52.389316000000001	54.576616000000001	54.560602000000003	Кирова	0103000020E6100000010000000500000065E1EB6B5D2C4A403E096CCEC1474B4065E1EB6B5D2C4A40D82C978DCE494B409FE74F1BD5314A40D82C978DCE494B409FE74F1BD5314A403E096CCEC1474B4065E1EB6B5D2C4A403E096CCEC1474B40
10740	24028	52.266750000000002	52.304406999999998	54.535749000000003	54.516317999999998	Центральная	0103000020E61000000100000005000000A01A2FDD24224A40062B4EB516424B40A01A2FDD24224A40AFEE586C93444B4034D6FECEF6264A40AFEE586C93444B4034D6FECEF6264A40062B4EB516424B40A01A2FDD24224A40062B4EB516424B40
10738	23907	51.932577000000002	51.968761000000001	54.634427000000002	54.607159000000003	Заварыкина	0103000020E610000001000000050000003B00E2AE5EF749406D3CD862B74D4B403B00E2AE5EF74940865968E734514B40F451465C00FC4940865968E734514B40F451465C00FC49406D3CD862B74D4B403B00E2AE5EF749406D3CD862B74D4B40
10737	23819	52.009166999999998	52.029998999999997	54.557501000000002	54.539045999999999	Школьная	0103000020E61000000100000005000000E9995E622C014A4012859675FF444B40E9995E622C014A40603E59315C474B40D3F4D901D7034A40603E59315C474B40D3F4D901D7034A4012859675FF444B40E9995E622C014A4012859675FF444B40
10989	23977	52.093231000000003	52.116138999999997	54.533617999999997	54.512104999999998	С.Садриева	0103000020E6100000010000000500000098FC4FFEEE0B4A401D8F19A88C414B4098FC4FFEEE0B4A40494739984D444B4023658BA4DD0E4A40494739984D444B4023658BA4DD0E4A401D8F19A88C414B4098FC4FFEEE0B4A401D8F19A88C414B40
10987	23741	52.595291000000003	52.660068000000003	54.566026000000001	54.541736	Центральная	0103000020E61000000100000005000000344DD87E324C4A406E88F19A57454B40344DD87E324C4A40C5573B8A73484B406D91B41B7D544A40C5573B8A73484B406D91B41B7D544A406E88F19A57454B40344DD87E324C4A406E88F19A57454B40
10707	22981	52.054926999999999	52.083044999999998	54.472189	54.450113999999999	Советская	0103000020E610000001000000050000006D5512D907074A4062BCE6559D394B406D5512D907074A40F6436CB0703C4B40548CF337A10A4A40F6436CB0703C4B40548CF337A10A4A4062BCE6559D394B406D5512D907074A4062BCE6559D394B40
10732	23781	51.886125	51.909086000000002	54.674048999999997	54.648103999999996	Кирова	0103000020E610000001000000050000008195438B6CF1494011346612F5524B408195438B6CF149406473D53C47564B4030A017EE5CF449406473D53C47564B4030A017EE5CF4494011346612F5524B408195438B6CF1494011346612F5524B40
10986	40868	52.500698	52.512466000000003	54.594099	54.586190999999999	Гагарина	0103000020E6100000010000000500000018963FDF16404A40D21A834E084B4B4018963FDF16404A400CCB9F6F0B4C4B40EE27637C98414A400CCB9F6F0B4C4B40EE27637C98414A40D21A834E084B4B4018963FDF16404A40D21A834E084B4B40
10729	23608	52.004244	52.036368000000003	54.506495999999999	54.490727	Центральная	0103000020E61000000100000005000000249A40118B004A40D1217024D03E4B40249A40118B004A4004C765DCD4404B407B4FE5B4A7044A4004C765DCD4404B407B4FE5B4A7044A40D1217024D03E4B40249A40118B004A40D1217024D03E4B40
10727	23637	52.378312000000001	52.396296	54.647244999999998	54.636277	Центральная	0103000020E6100000010000000500000099D711876C304A403719558671514B4099D711876C304A40F0BF95ECD8524B408FC4CBD3B9324A40F0BF95ECD8524B408FC4CBD3B9324A403719558671514B4099D711876C304A403719558671514B40
10720	23444	51.708545999999998	51.735000999999997	54.572201	54.559776999999997	Центральная	0103000020E6100000010000000500000016DBA4A2B1DA4940C806D2C5A6474B4016DBA4A2B1DA494087DEE2E13D494B407EC3448314DE494087DEE2E13D494B407EC3448314DE4940C806D2C5A6474B4016DBA4A2B1DA4940C806D2C5A6474B40
78181	8104	51.876136000000002	51.883690000000001	54.792146000000002	54.780112000000003	Советская	0103000020E61000000100000005000000946C753925F04940CC9BC3B5DA634B40946C753925F0494020D4450A65654B40B0E600C11CF1494020D4450A65654B40B0E600C11CF14940CC9BC3B5DA634B40946C753925F04940CC9BC3B5DA634B40
78339	23834	52.381222000000001	52.388319000000003	54.470770999999999	54.467182000000001	Центральная	0103000020E610000001000000050000000342EBE1CB304A40D3A3A99ECC3B4B400342EBE1CB304A40DE736039423C4B402DB5DE6FB4314A40DE736039423C4B402DB5DE6FB4314A40D3A3A99ECC3B4B400342EBE1CB304A40D3A3A99ECC3B4B40
10724	23545	52.089368999999998	52.131832000000003	54.669967	54.657094000000001	Центральная	0103000020E610000001000000050000005B238271700B4A40EC32FCA71B544B405B238271700B4A401A33897AC1554B407C48F8DEDF104A401A33897AC1554B407C48F8DEDF104A40EC32FCA71B544B405B238271700B4A40EC32FCA71B544B40
10725	23492	52.037275000000001	52.057648999999998	54.591794	54.576574000000001	Механизаторов	0103000020E61000000100000005000000ADFA5C6DC5044A40A9DC442DCD494B40ADFA5C6DC5044A4009FCE1E7BF4B4B40D4D2DC0A61074A4009FCE1E7BF4B4B40D4D2DC0A61074A40A9DC442DCD494B40ADFA5C6DC5044A40A9DC442DCD494B40
10710	23265	51.812660999999999	51.846499999999999	54.631905000000003	54.608389000000003	Нагорная	0103000020E6100000010000000500000009DE904605E84940821FD5B0DF4D4B4009DE904605E84940E6965643E2504B403108AC1C5AEC4940E6965643E2504B403108AC1C5AEC4940821FD5B0DF4D4B4009DE904605E84940821FD5B0DF4D4B40
10708	23088	52.553331	52.574925999999998	54.444611999999999	54.428091000000002	Центральная	0103000020E61000000100000005000000766EDA8CD3464A40215B96AFCB364B40766EDA8CD3464A405FB4C70BE9384B405FCFD72C97494A405FB4C70BE9384B405FCFD72C97494A40215B96AFCB364B40766EDA8CD3464A40215B96AFCB364B40
10674	40765	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Губкина	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10755	24426	52.007289999999998	52.035488000000001	54.666550999999998	54.660881000000003	Кооперативная	0103000020E610000001000000050000003ECBF3E0EE004A401EC6A4BF97544B403ECBF3E0EE004A40DC0E0D8B51554B4042B3EBDE8A044A40DC0E0D8B51554B4042B3EBDE8A044A401EC6A4BF97544B403ECBF3E0EE004A401EC6A4BF97544B40
12264	23349	52.178049999999999	52.211719000000002	54.664057	54.647854000000002	Карла Маркса	0103000020E61000000100000005000000C286A757CA164A40994A3FE1EC524B40C286A757CA164A4006D7DCD1FF544B408E78B29B191B4A4006D7DCD1FF544B408E78B29B191B4A40994A3FE1EC524B40C286A757CA164A40994A3FE1EC524B40
10712	23307	51.874222000000003	51.907162999999997	54.707124999999998	54.694378	Советская	0103000020E61000000100000005000000CCB8A981E6EF4940EC87D860E1584B40CCB8A981E6EF49408D976E12835A4B401492CCEA1DF449408D976E12835A4B401492CCEA1DF44940EC87D860E1584B40CCB8A981E6EF4940EC87D860E1584B40
10706	23125	52.174224000000002	52.224995999999997	54.515397999999998	54.492457999999999	Советская	0103000020E61000000100000005000000D316D7F84C164A40A8531EDD083F4B40D316D7F84C164A403F36C98FF8414B408BDD3EABCC1C4A403F36C98FF8414B408BDD3EABCC1C4A40A8531EDD083F4B40D316D7F84C164A40A8531EDD083F4B40
10703	23033	52.425311999999998	52.471009000000002	54.510181000000003	54.501545	Юности	0103000020E61000000100000005000000554CA59F70364A40753C66A032404B40554CA59F70364A4032056B9C4D414B40938FDD054A3C4A4032056B9C4D414B40938FDD054A3C4A40753C66A032404B40554CA59F70364A40753C66A032404B40
78039	61271	52.030996000000002	52.058062	54.491166	54.475704999999998	Строительная	0103000020E6100000010000000500000046274BADF7034A4097C5C4E6E33C4B4046274BADF7034A401D740987DE3E4B40F7915B936E074A401D740987DE3E4B40F7915B936E074A4097C5C4E6E33C4B4046274BADF7034A4097C5C4E6E33C4B40
10700	22903	52.355791000000004	52.400599	54.715592000000001	54.691718999999999	Советская	0103000020E61000000100000005000000079B3A8F8A2D4A40CB82893F8A584B40079B3A8F8A2D4A40BEA3C684985B4B40B8E7F9D346334A40BEA3C684985B4B40B8E7F9D346334A40CB82893F8A584B40079B3A8F8A2D4A40CB82893F8A584B40
78960	9395	51.858044	51.865561999999997	54.755555000000001	54.750701999999997	Ирня	0103000020E61000000100000005000000B743C362D4ED49405985CD0017604B40B743C362D4ED494026AAB706B6604B40865451BCCAEE494026AAB706B6604B40865451BCCAEE49405985CD0017604B40B743C362D4ED49405985CD0017604B40
10735	23873	52.032882999999998	52.050767999999998	54.546106999999999	54.534632000000002	Нагорная	0103000020E6100000010000000500000014CC988235044A4092B245D26E444B4014CC988235044A40EF8E8CD5E6454B4077D7D9907F064A40EF8E8CD5E6454B4077D7D9907F064A4092B245D26E444B4014CC988235044A4092B245D26E444B40
10682	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Школьная	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10681	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Широкая	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
11787	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Шашина	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
11050	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Степная	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
11009	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Садриева	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10684	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Морякова	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10688	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Ленинградская	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10953	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Кутузова	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
11786	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Крупской	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10697	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Кошевого	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
10686	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Гагарина	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
11781	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Асфальтная	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
11782	40766	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	Агадуллмна	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
11000	40766	52.402296999999997	52.504731999999997	54.620140999999997	54.563912000000002	50 лет Победы	0103000020E61000000100000005000000B323D5777E334A4036E9B6442E484B40B323D5777E334A4051F4C0C7604F4B40519FE40E9B404A4051F4C0C7604F4B40519FE40E9B404A4036E9B6442E484B40B323D5777E334A4036E9B6442E484B40
75151	48581	49.583320999999998	49.613055000000003	55.499738999999998	55.479076999999997	Центральная	0103000020E61000000100000005000000F6083543AACA484005A2276552BD4B40F6083543AACA484093C49272F7BF4B401CD3139678CE484093C49272F7BF4B401CD3139678CE484005A2276552BD4B40F6083543AACA484005A2276552BD4B40
10600	20355	49.808906	49.835963	55.379024999999999	55.362997	Кооперативная	0103000020E61000000100000005000000E3C4573B8AE74840E7C589AF76AE4B40E3C4573B8AE74840E6AE25E483B04B4041D5E8D500EB4840E6AE25E483B04B4041D5E8D500EB4840E7C589AF76AE4B40E3C4573B8AE74840E7C589AF76AE4B40
10593	20155	49.705356999999999	49.724814000000002	55.453232999999997	55.436545000000002	Заводская	0103000020E6100000010000000500000099805F2349DA4840BD1DE1B4E0B74B4099805F2349DA4840E63BF88903BA4B406BD784B4C6DC4840E63BF88903BA4B406BD784B4C6DC4840BD1DE1B4E0B74B4099805F2349DA4840BD1DE1B4E0B74B40
10666	21760	49.202703999999997	49.223697999999999	55.443572000000003	55.424531000000002	Центральная	0103000020E610000001000000050000005A626534F2994840B091240857B64B405A626534F2994840EEB5A0F7C6B84B401E17D522A29C4840EEB5A0F7C6B84B401E17D522A29C4840B091240857B64B405A626534F2994840B091240857B64B40
10568	19443	49.367877999999997	49.393371999999999	55.326512000000001	55.314638000000002	Верхняя	0103000020E610000001000000050000007D7555A016AF4840180AD80E46A84B407D7555A016AF484033E02C25CBA94B40C09481035AB2484033E02C25CBA94B40C09481035AB24840180AD80E46A84B407D7555A016AF4840180AD80E46A84B40
10606	20475	49.747244999999999	49.784632999999999	55.559821999999997	55.546408999999997	Магазинная	0103000020E61000000100000005000000BD8C62B9A5DF4840BA9EE8BAF0C54B40BD8C62B9A5DF484068CA4E3FA8C74B40622EA9DA6EE4484068CA4E3FA8C74B40622EA9DA6EE44840BA9EE8BAF0C54B40BD8C62B9A5DF4840BA9EE8BAF0C54B40
10663	21705	49.237549999999999	49.256199000000002	55.494833	55.485142000000003	Солнечная	0103000020E610000001000000050000001895D409689E484041F50F2219BE4B401895D409689E4840A4FD0FB056BF4B404B22FB20CBA04840A4FD0FB056BF4B404B22FB20CBA0484041F50F2219BE4B401895D409689E484041F50F2219BE4B40
10566	19408	49.252578999999997	49.287083000000003	55.347413000000003	55.337567999999997	Татарстан	0103000020E610000001000000050000000454388254A048408B16A06D35AB4B400454388254A04840469A780778AC4B40691EC022BFA44840469A780778AC4B40691EC022BFA448408B16A06D35AB4B400454388254A048408B16A06D35AB4B40
10563	19309	49.299318	49.316367999999997	55.415559000000002	55.403528000000001	Октябрьская	0103000020E61000000100000005000000548D5E0D50A64840998235CEA6B34B40548D5E0D50A648407C478D0931B54B401EC022BF7EA848407C478D0931B54B401EC022BF7EA84840998235CEA6B34B40548D5E0D50A64840998235CEA6B34B40
11720	40754	49.200971000000003	49.230435	55.658053000000002	55.622146000000001	Заозерная	0103000020E61000000100000005000000E338F06AB99948402AABE97AA2CF4B40E338F06AB99948407104A9143BD44B40486DE2E47E9D48407104A9143BD44B40486DE2E47E9D48402AABE97AA2CF4B40E338F06AB99948402AABE97AA2CF4B40
10641	8302	49.200971000000003	49.230435	55.658053000000002	55.622146000000001	Школьная	0103000020E61000000100000005000000E338F06AB99948402AABE97AA2CF4B40E338F06AB99948407104A9143BD44B40486DE2E47E9D48407104A9143BD44B40486DE2E47E9D48402AABE97AA2CF4B40E338F06AB99948402AABE97AA2CF4B40
10642	8302	49.200971000000003	49.230435	55.658053000000002	55.622146000000001	Совхозная	0103000020E61000000100000005000000E338F06AB99948402AABE97AA2CF4B40E338F06AB99948407104A9143BD44B40486DE2E47E9D48407104A9143BD44B40486DE2E47E9D48402AABE97AA2CF4B40E338F06AB99948402AABE97AA2CF4B40
10645	8302	49.200971000000003	49.230435	55.658053000000002	55.622146000000001	Северная	0103000020E61000000100000005000000E338F06AB99948402AABE97AA2CF4B40E338F06AB99948407104A9143BD44B40486DE2E47E9D48407104A9143BD44B40486DE2E47E9D48402AABE97AA2CF4B40E338F06AB99948402AABE97AA2CF4B40
10602	20389	49.648555999999999	49.679502999999997	55.513871000000002	55.486193	Сергеева	0103000020E61000000100000005000000F2CF0CE203D34840A6457D923BBE4B40F2CF0CE203D3484071AE6186C6C14B4056444DF4F9D6484071AE6186C6C14B4056444DF4F9D64840A6457D923BBE4B40F2CF0CE203D34840A6457D923BBE4B40
10636	20804	49.384892000000001	49.423608999999999	55.626537999999996	55.610737999999998	Школьная	0103000020E61000000100000005000000FB3E1C2444B148405436ACA92CCE4B40FB3E1C2444B14840C2D9AD6532D04B4048A5D8D138B64840C2D9AD6532D04B4048A5D8D138B648405436ACA92CCE4B40FB3E1C2444B148405436ACA92CCE4B40
10571	19337	49.292831999999997	49.312344000000003	55.395885	55.382497999999998	Школьная	0103000020E61000000100000005000000739CDB847BA548408864C8B1F5B04B40739CDB847BA548400DFD135CACB24B40098D60E3FAA748400DFD135CACB24B40098D60E3FAA748408864C8B1F5B04B40739CDB847BA548408864C8B1F5B04B40
10657	21526	49.155650999999999	49.186022999999999	55.572177000000003	55.552999	Закарьевская	0103000020E610000001000000050000007B4B395FEC93484040DCD5ABC8C64B407B4B395FEC934840FF428F183DC94B40E3A6069ACF974840FF428F183DC94B40E3A6069ACF97484040DCD5ABC8C64B407B4B395FEC93484040DCD5ABC8C64B40
10649	21369	49.123292999999997	49.159827999999997	55.634410000000003	55.618836999999999	Октябрьская	0103000020E61000000100000005000000B169A510C88F48400247020D36CF4B40B169A510C88F4840B020CD5834D14B40177E703E75944840B020CD5834D14B40177E703E759448400247020D36CF4B40B169A510C88F48400247020D36CF4B40
10607	20592	49.580311000000002	49.606290999999999	55.577159000000002	55.560091999999997	Советская	0103000020E6100000010000000500000029417FA147CA484028603B18B1C74B4029417FA147CA4840C9CB9A58E0C94B40F86D88F19ACD4840C9CB9A58E0C94B40F86D88F19ACD484028603B18B1C74B4029417FA147CA484028603B18B1C74B40
10655	40758	49.058245999999997	49.086840000000002	55.573703999999999	55.556140999999997	Олимпийская	0103000020E61000000100000005000000B88FDC9A748748407C7BD7A02FC74B40B88FDC9A74874840CDCAF6216FC94B4009FEB7921D8B4840CDCAF6216FC94B4009FEB7921D8B48407C7BD7A02FC74B40B88FDC9A748748407C7BD7A02FC74B40
10659	21568	49.170741999999997	49.206144999999999	55.543653999999997	55.524355	Центральная	0103000020E61000000100000005000000DD06B5DFDA9548403E3F8C101EC34B40DD06B5DFDA954840772B4B7496C54B40F19D98F5629A4840772B4B7496C54B40F19D98F5629A48403E3F8C101EC34B40DD06B5DFDA9548403E3F8C101EC34B40
10665	8423	49.287191	49.304932999999998	55.497081999999999	55.482540999999998	Центральная	0103000020E610000001000000050000004F5AB8ACC2A4484054FD4AE7C3BD4B404F5AB8ACC2A4484013B70A62A0BF4B404F3C670B08A7484013B70A62A0BF4B404F3C670B08A7484054FD4AE7C3BD4B404F5AB8ACC2A4484054FD4AE7C3BD4B40
11722	40761	49.287191	49.304932999999998	55.497081999999999	55.482540999999998	Молодежная	0103000020E610000001000000050000004F5AB8ACC2A4484054FD4AE7C3BD4B404F5AB8ACC2A4484013B70A62A0BF4B404F3C670B08A7484013B70A62A0BF4B404F3C670B08A7484054FD4AE7C3BD4B404F5AB8ACC2A4484054FD4AE7C3BD4B40
10637	21003	49.265658000000002	49.300522000000001	55.658890999999997	55.604666000000002	Южная	0103000020E61000000100000005000000DCF5D21401A2484067800BB265CD4B40DCF5D21401A248407A50508A56D44B4040DD408177A648407A50508A56D44B4040DD408177A6484067800BB265CD4B40DCF5D21401A2484067800BB265CD4B40
10624	20223	49.826557000000001	49.853085	55.424551000000001	55.405873999999997	Советская	0103000020E61000000100000005000000D3A3A99ECCE94840FA25E2ADF3B34B40D3A3A99ECCE94840F73DEAAF57B64B40A5DAA7E331ED4840F73DEAAF57B64B40A5DAA7E331ED4840FA25E2ADF3B34B40D3A3A99ECCE94840FA25E2ADF3B34B40
11721	8112	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Чернышевского	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
11852	8112	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Производственная	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
10616	8112	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Маяковского	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
10613	8112	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Ленина	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
10614	8112	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Лебедевой	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
10584	8112	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Александра Матросова	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
10587	40732	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Школьный переулок	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
10585	40732	49.509900999999999	49.576816999999998	55.410136000000001	55.394872999999997	Горького	0103000020E610000001000000050000004E999B6F44C148406589CE328BB24B404E999B6F44C14840C57421567FB44B406F63B323D5C94840C57421567FB44B406F63B323D5C948406589CE328BB24B404E999B6F44C148406589CE328BB24B40
79246	61491	49.198743	49.225656000000001	55.522224999999999	55.508794000000002	Центральная	0103000020E610000001000000050000008BA71E697099484055336B2920C14B408BA71E6970994840A913D044D8C24B40B612BA4BE29C4840A913D044D8C24B40B612BA4BE29C484055336B2920C14B408BA71E697099484055336B2920C14B40
10572	19613	49.368668	49.384784000000003	55.447978999999997	55.435948000000003	Центральная	0103000020E61000000100000005000000768A558330AF4840D960E124CDB74B40768A558330AF4840BB25396057B94B401503249A40B14840BB25396057B94B401503249A40B14840D960E124CDB74B40768A558330AF4840D960E124CDB74B40
10623	20826	49.303612000000001	49.331145999999997	55.570782000000001	55.556406000000003	Юности	0103000020E610000001000000050000002A560DC2DCA648402BA6D24F38C74B402A560DC2DCA648409F9273620FC94B40C119FCFD62AA48409F9273620FC94B40C119FCFD62AA48402BA6D24F38C74B402A560DC2DCA648402BA6D24F38C74B40
10638	20914	49.301645000000001	49.325414000000002	55.522438999999999	55.503227000000003	Овражная	0103000020E610000001000000050000003F00A94D9CA648406BBB09BE69C04B403F00A94D9CA64840D593F947DFC24B408DD47B2AA7A94840D593F947DFC24B408DD47B2AA7A948406BBB09BE69C04B403F00A94D9CA648406BBB09BE69C04B40
10609	20611	49.472208000000002	49.494720000000001	55.583478999999997	55.571444	Центральная	0103000020E610000001000000050000006D74CE4F71BC48406ABFB51325C94B406D74CE4F71BC48408E739B70AFCA4B40AC5626FC52BF48408E739B70AFCA4B40AC5626FC52BF48406ABFB51325C94B406D74CE4F71BC48406ABFB51325C94B40
10589	20096	49.711419999999997	49.737310000000001	55.434206000000003	55.41657	Школьная	0103000020E6100000010000000500000033DC80CF0FDB4840533F6F2A52B54B4033DC80CF0FDB48400EDDEC0F94B74B40C381902C60DE48400EDDEC0F94B74B40C381902C60DE4840533F6F2A52B54B4033DC80CF0FDB4840533F6F2A52B54B40
10561	19230	49.309863999999997	49.339275000000001	55.449342000000001	55.434981999999998	Юности	0103000020E61000000100000005000000971AA19FA9A74840A12C7C7DADB74B40971AA19FA9A74840105CE50984B94B40DAACFA5C6DAB4840105CE50984B94B40DAACFA5C6DAB4840A12C7C7DADB74B40971AA19FA9A74840A12C7C7DADB74B40
10603	20498	49.550173000000001	49.573619000000001	55.559756	55.546236	Заббарова	0103000020E610000001000000050000003412A1116CC64840EDF2AD0FEBC54B403412A1116CC64840B1DEA815A6C74B409FAEEE586CC94840B1DEA815A6C74B409FAEEE586CC94840EDF2AD0FEBC54B403412A1116CC64840EDF2AD0FEBC54B40
10575	19494	49.137746999999997	49.151671	55.617251000000003	55.606313999999998	Советская	0103000020E61000000100000005000000A10F96B1A1914840B08D78B29BCD4B40A10F96B1A19148402F36AD1402CF4B40356090F4699348402F36AD1402CF4B40356090F469934840B08D78B29BCD4B40A10F96B1A1914840B08D78B29BCD4B40
10652	21431	49.011946999999999	49.027695000000001	55.624901000000001	55.600847000000002	Березовая	0103000020E610000001000000050000008524B37A878148402A73F38DE8CC4B408524B37A878148406D1E87C1FCCF4B40A1A17F828B8348406D1E87C1FCCF4B40A1A17F828B8348402A73F38DE8CC4B408524B37A878148402A73F38DE8CC4B40
10630	20945	49.293874000000002	49.323186	55.653075999999999	55.639192000000001	Победы	0103000020E610000001000000050000008692C9A99DA54840B3EE1F0BD1D14B408692C9A99DA54840B8E68EFE97D34B403543AA285EA94840B8E68EFE97D34B403543AA285EA94840B3EE1F0BD1D14B408692C9A99DA54840B3EE1F0BD1D14B40
10611	20701	49.48677	49.526448000000002	55.621581999999997	55.613833999999997	Центральная	0103000020E610000001000000050000004356B77A4EBE48402096CD1C92CE4B404356B77A4EBE484021E4BCFF8FCF4B40B685E7A562C3484021E4BCFF8FCF4B40B685E7A562C348402096CD1C92CE4B404356B77A4EBE48402096CD1C92CE4B40
10619	20713	49.419629999999998	49.440057000000003	55.552785	55.545558999999997	Центральная	0103000020E61000000100000005000000D235936FB6B54840EC8497E0D4C54B40D235936FB6B54840145CACA8C1C64B401DB0ABC953B84840145CACA8C1C64B401DB0ABC953B84840EC8497E0D4C54B40D235936FB6B54840EC8497E0D4C54B40
10635	21056	49.335870999999997	49.368614000000001	55.294150000000002	55.273117999999997	Молодежная	0103000020E61000000100000005000000605628D2FDAA484076F9D687F5A24B40605628D2FDAA4840280F0BB5A6A54B40836C59BE2EAF4840280F0BB5A6A54B40836C59BE2EAF484076F9D687F5A24B40605628D2FDAA484076F9D687F5A24B40
79311	61527	49.011946999999999	49.853085	55.658890999999997	55.273117999999997	Молодежная	0103000020E610000001000000050000008524B37A8781484076F9D687F5A24B408524B37A878148407A50508A56D44B40A5DAA7E331ED48407A50508A56D44B40A5DAA7E331ED484076F9D687F5A24B408524B37A8781484076F9D687F5A24B40
11855	40968	49.011946999999999	49.853085	55.658890999999997	55.273117999999997	Медицинская	0103000020E610000001000000050000008524B37A8781484076F9D687F5A24B408524B37A878148407A50508A56D44B40A5DAA7E331ED48407A50508A56D44B40A5DAA7E331ED484076F9D687F5A24B408524B37A8781484076F9D687F5A24B40
10408	15055	50.790323999999998	50.816536999999997	55.999566000000002	55.983378000000002	Центральная	0103000020E61000000100000005000000389F3A56296549408ECD8E54DFFD4B40389F3A5629654940C61858C7F1FF4B40AA7CCF4884684940C61858C7F1FF4B40AA7CCF48846849408ECD8E54DFFD4B40389F3A56296549408ECD8E54DFFD4B40
10414	14957	50.559815999999998	50.592398000000003	56.261457999999998	56.249411000000002	Центральная	0103000020E6100000010000000500000086E3F90CA84749409F211CB3EC1F4C4086E3F90CA847494087A3AB7477214C40A01B9AB2D34B494087A3AB7477214C40A01B9AB2D34B49409F211CB3EC1F4C4086E3F90CA84749409F211CB3EC1F4C40
10433	15638	50.788186000000003	50.802531999999999	56.233769000000002	56.219633000000002	Пионерская	0103000020E6100000010000000500000021956247E3644940AA0F24EF1C1C4C4021956247E3644940C9E88024EC1D4C402AFF5A5EB9664940C9E88024EC1D4C402AFF5A5EB9664940AA0F24EF1C1C4C4021956247E3644940AA0F24EF1C1C4C40
10559	19147	50.497545000000002	50.524628999999997	56.236151	56.225548000000003	Ленина	0103000020E61000000100000005000000E8A4F78DAF3F4940D0D6C1C1DE1C4C40E8A4F78DAF3F494077F52A323A1E4C403FC4060B2743494077F52A323A1E4C403FC4060B27434940D0D6C1C1DE1C4C40E8A4F78DAF3F4940D0D6C1C1DE1C4C40
10449	15910	50.625141999999997	50.656357999999997	56.304985000000002	56.294201000000001	Победы	0103000020E6100000010000000500000092AD2EA704504940AAB9DC60A8254C4092AD2EA704504940A2629CBF09274C40E63BF88903544940A2629CBF09274C40E63BF88903544940AAB9DC60A8254C4092AD2EA704504940AAB9DC60A8254C40
10545	18864	50.888896000000003	50.909198000000004	56.287396999999999	56.277847999999999	Школьная	0103000020E61000000100000005000000CAC51858C771494027A1F48590234C40CAC51858C7714940F8FBC56CC9244C4058CB9D9960744940F8FBC56CC9244C4058CB9D996074494027A1F48590234C40CAC51858C771494027A1F48590234C40
12261	41033	50.311387000000003	51.647388999999997	56.409951999999997	55.842700999999998	Молодежная	0103000020E6100000010000000500000025B37A87DB2749403BA759A0DDEB4B4025B37A87DB2749400377A04E79344C4023658BA4DDD249400377A04E79344C4023658BA4DDD249403BA759A0DDEB4B4025B37A87DB2749403BA759A0DDEB4B40
10508	17815	50.941626999999997	50.960994999999997	56.049590999999999	56.038077000000001	Пионерская	0103000020E61000000100000005000000EA03C93B877849406ADD06B5DF044C40EA03C93B87784940859675FF58064C404C4F58E2017B4940859675FF58064C404C4F58E2017B49406ADD06B5DF044C40EA03C93B877849406ADD06B5DF044C40
10513	17913	50.878889000000001	50.907347000000001	55.958728999999998	55.946255000000001	Центральная	0103000020E6100000010000000500000036E84B6F7F704940975643E21EF94B4036E84B6F7F704940075DC2A1B7FA4B40D68F4DF223744940075DC2A1B7FA4B40D68F4DF223744940975643E21EF94B4036E84B6F7F704940975643E21EF94B40
10543	18828	50.846127000000003	50.878025999999998	56.272199999999998	56.263482000000003	Заречная	0103000020E610000001000000050000009DA1B8E34D6C4940D78A36C7B9214C409DA1B8E34D6C494050FC1873D7224C40D384ED276370494050FC1873D7224C40D384ED2763704940D78A36C7B9214C409DA1B8E34D6C4940D78A36C7B9214C40
10553	18512	50.507596999999997	50.534734999999998	56.362057	56.352536999999998	Набережная	0103000020E610000001000000050000001B4641F0F8404940A2D0B2EE1F2D4C401B4641F0F8404940D9243FE2572E4C4066834C3272444940D9243FE2572E4C4066834C3272444940A2D0B2EE1F2D4C401B4641F0F8404940A2D0B2EE1F2D4C40
10555	19070	51.265739000000004	51.298160000000003	56.075212000000001	56.067484	Зеленая	0103000020E61000000100000005000000C9224DBC03A249406B80D250A3084C40C9224DBC03A249402522FC8BA0094C40D97C5C1B2AA649402522FC8BA0094C40D97C5C1B2AA649406B80D250A3084C40C9224DBC03A249406B80D250A3084C40
11554	1351	50.702683999999998	50.726013999999999	55.873444999999997	55.861908	Кирова	0103000020E6100000010000000500000013B69F8CF15949409414580053EE4B4013B69F8CF159494067EDB60BCDEF4B401538D906EE5C494067EDB60BCDEF4B401538D906EE5C49409414580053EE4B4013B69F8CF15949409414580053EE4B40
10460	16506	50.985850999999997	50.997332	56.064895999999997	56.057212	Зеленая	0103000020E610000001000000050000004CDD955D307E494029780AB952074C404CDD955D307E494013D21A834E084C408CA03193A87F494013D21A834E084C408CA03193A87F494029780AB952074C404CDD955D307E494029780AB952074C40
10522	18141	50.706223999999999	50.734377000000002	56.158872000000002	56.142837	Школьная	0103000020E610000001000000050000003DD34B8C655A494052D4997B48124C403DD34B8C655A49400420EEEA55144C40A1F7C610005E49400420EEEA55144C40A1F7C610005E494052D4997B48124C403DD34B8C655A494052D4997B48124C40
10539	18646	50.777855000000002	50.793297000000003	56.158591000000001	56.146006	Майская	0103000020E61000000100000005000000DA03ADC09063494088821953B0124C40DA03ADC0906349405038BBB54C144C40E9818FC18A6549405038BBB54C144C40E9818FC18A65494088821953B0124C40DA03ADC09063494088821953B0124C40
10628	18618	50.471134999999997	50.486891	56.27225	56.258597999999999	Школьная	0103000020E610000001000000050000001F80D4264E3C4940CF6740BD19214C401F80D4264E3C4940022B8716D9224C40BEDBBC71523E4940022B8716D9224C40BEDBBC71523E4940CF6740BD19214C401F80D4264E3C4940CF6740BD19214C40
10617	18398	50.565736000000001	50.599350999999999	56.324675999999997	56.316578999999997	Центральная	0103000020E61000000100000005000000BE1589096A484940D9CC21A985284C40BE1589096A484940E6E5B0FB8E294C4096E99788B74C4940E6E5B0FB8E294C4096E99788B74C4940D9CC21A985284C40BE1589096A484940D9CC21A985284C40
10455	16314	50.752146000000003	50.776004999999998	56.210712000000001	56.20487	Ленина	0103000020E610000001000000050000009BE8F351466049403CF71E2E391A4C409BE8F35146604940F86F5E9CF81A4C402844C02154634940F86F5E9CF81A4C402844C021546349403CF71E2E391A4C409BE8F351466049403CF71E2E391A4C40
12259	19195	50.467568	50.484321999999999	56.223196000000002	56.213875999999999	Мусы Джалиля	0103000020E61000000100000005000000FC53AA44D93B49401CB3EC49601B4C40FC53AA44D93B49408C4CC0AF911C4C40DD5D6743FE3D49408C4CC0AF911C4C40DD5D6743FE3D49401CB3EC49601B4C40FC53AA44D93B49401CB3EC49601B4C40
10500	17612	50.865324000000001	50.888446999999999	56.086911000000001	56.069991999999999	Школьная	0103000020E61000000100000005000000D238D4EFC26E4940A67D737FF5084C40D238D4EFC26E4940D2544FE61F0B4C405A9D9CA1B8714940D2544FE61F0B4C405A9D9CA1B8714940A67D737FF5084C40D238D4EFC26E4940A67D737FF5084C40
10458	16402	51.0227	51.038806999999998	56.073484000000001	56.063915999999999	Ленина	0103000020E6100000010000000500000042CF66D5E782494077D844662E084C4042CF66D5E7824940BF6378EC67094C408DEDB5A0F7844940BF6378EC67094C408DEDB5A0F784494077D844662E084C4042CF66D5E782494077D844662E084C40
10532	18537	50.473308000000003	50.494346999999998	56.301349000000002	56.290973999999999	Новая	0103000020E61000000100000005000000B477465B953C49403FFED2A23E254C40B477465B953C494056D7A19A92264C4017F032C3463F494056D7A19A92264C4017F032C3463F49403FFED2A23E254C40B477465B953C49403FFED2A23E254C40
10476	16932	50.721710999999999	50.743549000000002	56.132638999999998	56.123313000000003	Школьная	0103000020E61000000100000005000000EC14AB06615C4940F9156BB8C80F4C40EC14AB06615C49404A969350FA104C409CFC169D2C5F49404A969350FA104C409CFC169D2C5F4940F9156BB8C80F4C40EC14AB06615C4940F9156BB8C80F4C40
10515	18014	50.655999000000001	50.671844999999998	56.271965000000002	56.256777999999997	Новая	0103000020E61000000100000005000000B79A75C6F7534940882AFC19DE204C40B79A75C6F75349400D54C6BFCF224C40957D5704FF5549400D54C6BFCF224C40957D5704FF554940882AFC19DE204C40B79A75C6F7534940882AFC19DE204C40
10512	17929	50.575203999999999	50.585507999999997	56.204694000000003	56.195704999999997	Комсомольская	0103000020E61000000100000005000000A243E048A0494940F35487DC0C194C40A243E048A0494940FED7B969331A4C40EFC517EDF14A4940FED7B969331A4C40EFC517EDF14A4940F35487DC0C194C40A243E048A0494940F35487DC0C194C40
79106	61384	50.810572000000001	50.844977	55.945034999999997	55.930472999999999	Садовая	0103000020E61000000100000005000000D386C3D2C0674940CF6740BD19F74B40D386C3D2C0674940A54929E8F6F84B40A46FD234286C4940A54929E8F6F84B40A46FD234286C4940CF6740BD19F74B40D386C3D2C0674940CF6740BD19F74B40
10551	18426	50.589137000000001	50.609861000000002	56.381329999999998	56.373694	Новая	0103000020E6100000010000000500000089EE59D7684B4940105B7A34D52F4C4089EE59D7684B4940E97DE36BCF304C408D0DDDEC0F4E4940E97DE36BCF304C408D0DDDEC0F4E4940105B7A34D52F4C4089EE59D7684B4940105B7A34D52F4C40
10504	17723	50.970751	50.998112999999996	56.015002000000003	56.008333999999998	Г.Ахметова	0103000020E6100000010000000500000097C79A91417C4940F1B8A81611014C4097C79A91417C4940F3AFE595EB014C40315BB22AC27F4940F3AFE595EB014C40315BB22AC27F4940F1B8A81611014C4097C79A91417C4940F1B8A81611014C40
10541	18755	50.813491999999997	50.838599000000002	56.145524999999999	56.138724000000003	Нагорная	0103000020E6100000010000000500000060C77F8120684940CD9541B5C1114C4060C77F81206849400DE02D90A0124C40AABA4736576B49400DE02D90A0124C40AABA4736576B4940CD9541B5C1114C4060C77F8120684940CD9541B5C1114C40
12258	18104	50.632939	50.647967999999999	56.273964999999997	56.267867000000003	Мусы Джалиля	0103000020E6100000010000000500000075AE282504514940BD56427749224C4075AE282504514940D39FFD4811234C40616D8C9DF0524940D39FFD4811234C40616D8C9DF0524940BD56427749224C4075AE282504514940BD56427749224C40
10494	17419	51.115155000000001	51.125387000000003	56.021835000000003	56.002591000000002	Советская	0103000020E61000000100000005000000467C2766BD8E4940C921E2E654004C40467C2766BD8E49403F74417DCB024C40FA2B64AE0C9049403F74417DCB024C40FA2B64AE0C904940C921E2E654004C40467C2766BD8E4940C921E2E654004C40
10480	16836	50.823211000000001	50.840674999999997	56.345973000000001	56.334318000000003	Центральная	0103000020E610000001000000050000008E5A61FA5E694940693BA6EECA2A4C408E5A61FA5E6949404626E0D7482C4C404BC8073D9B6B49404626E0D7482C4C404BC8073D9B6B4940693BA6EECA2A4C408E5A61FA5E694940693BA6EECA2A4C40
10426	15535	50.905515000000001	50.930272000000002	56.180638000000002	56.172916000000001	Молодежная	0103000020E61000000100000005000000CB845FEAE7734940427A8A1C22164C40CB845FEAE77349401A355F251F174C4038312427137749401A355F251F174C403831242713774940427A8A1C22164C40CB845FEAE7734940427A8A1C22164C40
10586	17198	50.833784000000001	50.867103	56.374467000000003	56.362166999999999	Школьная	0103000020E61000000100000005000000CBF6216FB96A49406058FE7C5B2E4C40CBF6216FB96A49403337DF88EE2F4C40BAA1293BFD6E49403337DF88EE2F4C40BAA1293BFD6E49406058FE7C5B2E4C40CBF6216FB96A49406058FE7C5B2E4C40
10486	17301	50.909953000000002	50.936965000000001	56.148257999999998	56.138939999999998	Центральная	0103000020E61000000100000005000000D4F2035779744940990D32C9C8114C40D4F203577974494068AF3E1EFA124C40923F1878EE77494068AF3E1EFA124C40923F1878EE774940990D32C9C8114C40D4F2035779744940990D32C9C8114C40
10482	17103	51.382089000000001	51.412551000000001	56.055245999999997	56.022905999999999	Школьная	0103000020E61000000100000005000000A794D74AE8B04940EB707495EE024C40A794D74AE8B049400E9E094D12074C404F779E78CEB449400E9E094D12074C404F779E78CEB44940EB707495EE024C40A794D74AE8B04940EB707495EE024C40
10479	17103	51.382089000000001	51.412551000000001	56.055245999999997	56.022905999999999	Техникумская	0103000020E61000000100000005000000A794D74AE8B04940EB707495EE024C40A794D74AE8B049400E9E094D12074C404F779E78CEB449400E9E094D12074C404F779E78CEB44940EB707495EE024C40A794D74AE8B04940EB707495EE024C40
10477	17004	50.509816000000001	50.529210999999997	56.323262999999997	56.309967999999998	Школьная	0103000020E61000000100000005000000207D93A6414149403C670B08AD274C40207D93A641414940E08096AE60294C407BD7A02FBD434940E08096AE60294C407BD7A02FBD4349403C670B08AD274C40207D93A6414149403C670B08AD274C40
10423	14579	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	Нур Баяна	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
12257	14579	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	Мусы Джалиля	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
10421	14579	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	Мичурина	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
10415	14579	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	Майская	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
10419	14579	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	Ленина	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
10816	14579	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	Железнодорожная	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
10411	14579	50.867426000000002	50.936956000000002	56.196061	56.173552000000001	Ворошилова	0103000020E610000001000000050000009DD9AED0076F4940E413B2F336164C409DD9AED0076F4940B282DF8618194C403FE5982CEE774940B282DF8618194C403FE5982CEE774940E413B2F336164C409DD9AED0076F4940E413B2F336164C40
10468	16817	50.794654000000001	50.821190000000001	56.337052	56.324351	Театральная	0103000020E610000001000000050000005BD1E638B765494063B6645584294C405BD1E638B765494094861A85242B4C40B0E600C11C69494094861A85242B4C40B0E600C11C69494063B6645584294C405BD1E638B765494063B6645584294C40
10444	16016	50.706152000000003	50.721854	56.272435000000002	56.260407999999998	Пролетарская 	0103000020E61000000100000005000000A4005130635A4940F2CEA10C55214C40A4005130635A494094A46B26DF224C404F3E3DB6655C494094A46B26DF224C404F3E3DB6655C4940F2CEA10C55214C40A4005130635A4940F2CEA10C55214C40
10524	18303	50.920318999999999	50.934745999999997	56.096201999999998	56.088020999999998	Майская	0103000020E6100000010000000500000097715303CD7549403C2EAA45440B4C4097715303CD754940A7E7DD58500C4C408D08C6C1A5774940A7E7DD58500C4C408D08C6C1A57749403C2EAA45440B4C4097715303CD7549403C2EAA45440B4C40
10550	18221	50.849666999999997	50.864218999999999	56.060147000000001	56.049888000000003	Средняя	0103000020E61000000100000005000000C6BE64E3C16C49403F3BE0BA62064C40C6BE64E3C16C4940ECF99AE5B2074C4079CA6ABA9E6E4940ECF99AE5B2074C4079CA6ABA9E6E49403F3BE0BA62064C40C6BE64E3C16C49403F3BE0BA62064C40
10879	17316	50.956800000000001	50.968738000000002	56.194623999999997	56.184970999999997	Зеленая	0103000020E610000001000000050000000A68226C787A4940ADDA3521AD174C400A68226C787A494023827170E9184C403C32569BFF7B494023827170E9184C403C32569BFF7B4940ADDA3521AD174C400A68226C787A4940ADDA3521AD174C40
10463	16610	51.131512999999998	51.153647999999997	56.109732000000001	56.102353000000001	Ленина 	0103000020E61000000100000005000000DAFF006BD5904940E1D231E7190D4C40DAFF006BD59049408FA9BBB20B0E4C40438CD7BCAA9349408FA9BBB20B0E4C40438CD7BCAA934940E1D231E7190D4C40DAFF006BD5904940E1D231E7190D4C40
78606	31794	50.859296999999998	50.883111	56.129047	56.120266999999998	Ленина	0103000020E610000001000000050000008446B071FD6D4940DEE4B7E8640F4C408446B071FD6D4940CE52B29C84104C4072DEFFC709714940CE52B29C84104C4072DEFFC709714940DEE4B7E8640F4C408446B071FD6D4940DEE4B7E8640F4C40
10462	16517	50.620237000000003	50.645048000000003	56.183283000000003	56.173217000000001	Х.Такташа	0103000020E6100000010000000500000074620FED634F49403D0E83F92B164C4074620FED634F4940D6743DD175174C40D42CD0EE90524940D6743DD175174C40D42CD0EE905249403D0E83F92B164C4074620FED634F49403D0E83F92B164C40
79249	61492	50.511387999999997	50.537070999999997	56.169607999999997	56.159267999999997	Центральная	0103000020E610000001000000050000008EC877297541494050A6D1E462144C408EC8772975414940EA9106B7B5154C40A45016BEBE444940EA9106B7B5154C40A45016BEBE44494050A6D1E462144C408EC877297541494050A6D1E462144C40
10438	15720	50.747132999999998	50.764228000000003	56.233569000000003	56.226894000000001	Центральная	0103000020E610000001000000050000009561DC0DA25F49404ED4D2DC0A1D4C409561DC0DA25F4940022EC896E51D4C4000581D39D2614940022EC896E51D4C4000581D39D26149404ED4D2DC0A1D4C409561DC0DA25F49404ED4D2DC0A1D4C40
10459	16419	51.032356999999998	51.059612000000001	56.098140000000001	56.089433	Октябрьская	0103000020E61000000100000005000000F9653046248449407217618A720B4C40F965304624844940F836FDD98F0C4C407E39B35DA1874940F836FDD98F0C4C407E39B35DA18749407217618A720B4C40F9653046248449407217618A720B4C40
10501	17502	51.113655000000001	51.130732000000002	56.063685	56.049455000000002	С.Ахтямова	0103000020E6100000010000000500000071033E3F8C8E4940D5CF9B8A54064C4071033E3F8C8E4940751F80D426084C40354580D3BB904940751F80D426084C40354580D3BB904940D5CF9B8A54064C4071033E3F8C8E4940D5CF9B8A54064C40
10547	18941	50.901823	50.924864999999997	55.986823000000001	55.974589000000002	Зеленая	0103000020E61000000100000005000000EBE3A1EF6E7349404B051555BFFC4B40EBE3A1EF6E73494066F84F3750FE4B40861BF0F96176494066F84F3750FE4B40861BF0F9617649404B051555BFFC4B40EBE3A1EF6E7349404B051555BFFC4B40
10406	15041	50.517226999999998	50.551453000000002	56.278891999999999	56.268380999999998	Клубная	0103000020E61000000100000005000000D9CD8C7E3442494013EF004F5A224C40D9CD8C7E34424940DA8EA9BBB2234C40FB230C0396464940DA8EA9BBB2234C40FB230C039646494013EF004F5A224C40D9CD8C7E3442494013EF004F5A224C40
10440	15816	50.680667	50.715924999999999	56.304765000000003	56.287562000000001	Центральная	0103000020E61000000100000005000000B43BA4182057494043C9E4D4CE244C40B43BA4182057494094FB1D8A02274C40C4B12E6EA35B494094FB1D8A02274C40C4B12E6EA35B494043C9E4D4CE244C40B43BA4182057494043C9E4D4CE244C40
10441	15547	50.835833000000001	50.863213000000002	56.204759000000003	56.193161000000003	Ленина	0103000020E6100000010000000500000073F56393FC6A49406CEEE87FB9184C4073F56393FC6A4940E547FC8A351A4C40B43D7AC37D6E4940E547FC8A351A4C40B43D7AC37D6E49406CEEE87FB9184C4073F56393FC6A49406CEEE87FB9184C40
10497	17520	51.117427999999997	51.133417999999999	56.040464999999998	56.028132999999997	Гагарина	0103000020E610000001000000050000003DD175E1078F49401C78B5DC99034C403DD175E1078F4940FAD005F52D054C404F594DD713914940FAD005F52D054C404F594DD7139149401C78B5DC99034C403DD175E1078F49401C78B5DC99034C40
79067	1467	50.790405	50.805531999999999	56.116342000000003	56.102684000000004	Ленина	0103000020E6100000010000000500000025CCB4FD2B65494047E9D2BF240D4C4025CCB4FD2B6549405C936E4BE40E4C40D4F02DAC1B6749405C936E4BE40E4C40D4F02DAC1B67494047E9D2BF240D4C4025CCB4FD2B65494047E9D2BF240D4C40
10518	18037	50.636245000000002	50.650762	56.253492000000001	56.239852999999997	Центральная	0103000020E610000001000000050000002C9FE579705149407A6CCB80B31E4C402C9FE5797051494019E6046D72204C4062BD512B4C53494019E6046D72204C4062BD512B4C5349407A6CCB80B31E4C402C9FE579705149407A6CCB80B31E4C40
10453	16303	50.705182000000001	50.735714999999999	56.212259000000003	56.202480999999999	Советская	0103000020E610000001000000050000002BDD5D67435A4940DB87BCE5EA194C402BDD5D67435A49400EA48B4D2B1B4C409C16BCE82B5E49400EA48B4D2B1B4C409C16BCE82B5E4940DB87BCE5EA194C402BDD5D67435A4940DB87BCE5EA194C40
10451	16105	50.731332000000002	50.744284999999998	56.292693	56.281196000000001	Молодежная 	0103000020E61000000100000005000000574277499C5D49400DE2033BFE234C40574277499C5D49405262D7F676254C40A1F31ABB445F49405262D7F676254C40A1F31ABB445F49400DE2033BFE234C40574277499C5D49400DE2033BFE234C40
10526	18326	50.934800000000003	50.950754000000003	56.127301000000003	56.109898000000001	Молодежная	0103000020E610000001000000050000008126C286A7774940AAF23D23110E4C408126C286A7774940C2DF2F664B104C4046459C4EB2794940C2DF2F664B104C4046459C4EB2794940AAF23D23110E4C408126C286A7774940AAF23D23110E4C40
10457	16196	50.742784999999998	50.759889000000001	56.317253000000001	56.303072	Татарстан	0103000020E61000000100000005000000CC7A3194135F4940AA2A3410CB264C40CC7A3194135F494069C70DBF9B284C408ACBF10A4461494069C70DBF9B284C408ACBF10A44614940AA2A3410CB264C40CC7A3194135F4940AA2A3410CB264C40
11553	1238	50.733074000000002	50.763787999999998	55.881995000000003	55.869070999999998	Ленина	0103000020E6100000010000000500000022C66B5ED55D49407573F1B73DEF4B4022C66B5ED55D4940261E5036E5F04B40E38920CEC3614940261E5036E5F04B40E38920CEC36149407573F1B73DEF4B4022C66B5ED55D49407573F1B73DEF4B40
12162	41027	51.171002999999999	51.193145999999999	56.117019999999997	56.105877	Татарстан	0103000020E610000001000000050000004A42226DE39549400533A6608D0D4C404A42226DE39549402C7DE882FA0E4C4036AD1402B99849402C7DE882FA0E4C4036AD1402B99849400533A6608D0D4C404A42226DE39549400533A6608D0D4C40
10393	14764	48.882904000000003	48.902540999999999	55.477373	55.466442999999998	Лесная	0103000020E61000000100000005000000F9C08EFF027148405C397B67B4BB4B40F9C08EFF02714840287FF78E1ABD4B404A26A77686734840287FF78E1ABD4B404A26A776867348405C397B67B4BB4B40F9C08EFF027148405C397B67B4BB4B40
11914	40976	48.712296000000002	49.420492000000003	55.509298999999999	55.043700999999999	Ленина	0103000020E610000001000000050000002B89EC832C5B4840B8E68EFE97854B402B89EC832C5B48405871AAB530C14B40651D8EAED2B548405871AAB530C14B40651D8EAED2B54840B8E68EFE97854B402B89EC832C5B4840B8E68EFE97854B40
10363	13923	48.897987000000001	48.908650000000002	55.233331	55.223807000000001	Ленина	0103000020E61000000100000005000000D89DEE3CF1724840D5CE30B5A59C4B40D89DEE3CF17248404D124BCADD9D4B4055C1A8A44E7448404D124BCADD9D4B4055C1A8A44E744840D5CE30B5A59C4B40D89DEE3CF1724840D5CE30B5A59C4B40
10384	14566	49.169987999999996	49.193182	55.186931000000001	55.176665999999997	Мира	0103000020E61000000100000005000000315BB22AC29548405628D2FD9C964B40315BB22AC2954840E6CDE15AED974B4083161230BA984840E6CDE15AED974B4083161230BA9848405628D2FD9C964B40315BB22AC29548405628D2FD9C964B40
10396	14665	48.950799000000004	49.006638000000002	55.444690999999999	55.42427	Октябрьская	0103000020E61000000100000005000000E60819C8B37948404356B77A4EB64B40E60819C8B3794840ABE97AA2EBB84B4097749483D9804840ABE97AA2EBB84B4097749483D98048404356B77A4EB64B40E60819C8B37948404356B77A4EB64B40
10391	14665	48.950799000000004	49.006638000000002	55.444690999999999	55.42427	Вторая Октябрьская	0103000020E61000000100000005000000E60819C8B37948404356B77A4EB64B40E60819C8B3794840ABE97AA2EBB84B4097749483D9804840ABE97AA2EBB84B4097749483D98048404356B77A4EB64B40E60819C8B37948404356B77A4EB64B40
10349	13806	48.994734999999999	49.036147999999997	55.116551999999999	55.099294	Колхозная	0103000020E61000000100000005000000E197FA79537F4840325871AAB58C4B40E197FA79537F484046240A2DEB8E4B406CE8667FA084484046240A2DEB8E4B406CE8667FA0844840325871AAB58C4B40E197FA79537F4840325871AAB58C4B40
10621	13157	48.830595000000002	48.850394000000001	55.314351000000002	55.303283	Хади Такташа	0103000020E610000001000000050000004E9CDCEF506A4840653733FAD1A64B404E9CDCEF506A4840823B50A73CA84B40795BE9B5D96C4840823B50A73CA84B40795BE9B5D96C4840653733FAD1A64B404E9CDCEF506A4840653733FAD1A64B40
10327	12982	48.728223	48.747169	55.315821	55.301628000000001	Центральная 	0103000020E61000000100000005000000F6984869365D484069C70DBF9BA64B40F6984869365D4840EC3191D26CA84B40E2CAD93BA35F4840EC3191D26CA84B40E2CAD93BA35F484069C70DBF9BA64B40F6984869365D484069C70DBF9BA64B40
10596	12721	49.130785000000003	49.142417999999999	55.178511	55.172604	Центральная	0103000020E6100000010000000500000058E71890BD90484053944BE317964B4058E71890BD904840F67CCD72D9964B404D2EC6C03A924840F67CCD72D9964B404D2EC6C03A92484053944BE317964B4058E71890BD90484053944BE317964B40
10634	13258	49.060887000000001	49.085393000000003	55.120294999999999	55.104717999999998	Центральная	0103000020E6100000010000000500000033E02C25CB874840B9A64066678D4B4033E02C25CB874840A86F99D3658F4B4057276728EE8A4840A86F99D3658F4B4057276728EE8A4840B9A64066678D4B4033E02C25CB874840B9A64066678D4B40
10378	14200	49.080613999999997	49.108642000000003	55.289023999999998	55.279046999999998	Баки Урманче	0103000020E61000000100000005000000C4CC3E8F518A48400186E5CFB7A34B40C4CC3E8F518A48402AE109BDFEA44B406C7C26FBE78D48402AE109BDFEA44B406C7C26FBE78D48400186E5CFB7A34B40C4CC3E8F518A48400186E5CFB7A34B40
10389	14489	49.153557999999997	49.175800000000002	55.201058000000003	55.191541000000001	Малая	0103000020E610000001000000050000000305DEC9A7934840EC6B5D6A84984B400305DEC9A7934840B24CBF44BC994B408351499D80964840B24CBF44BC994B408351499D80964840EC6B5D6A84984B400305DEC9A7934840EC6B5D6A84984B40
10398	14863	48.917389999999997	48.934665000000003	55.271180000000001	55.261208000000003	Центральная	0103000020E61000000100000005000000B6D617096D7548400FBA84436FA14B40B6D617096D75484026AAB706B6A24B40A1DB4B1AA377484026AAB706B6A24B40A1DB4B1AA37748400FBA84436FA14B40B6D617096D7548400FBA84436FA14B40
10373	14293	49.144250999999997	49.171909999999997	55.258161000000001	55.243495000000003	Вахитова	0103000020E6100000010000000500000028B517D176924840A9DE1AD82A9F4B4028B517D176924840240D6E6B0BA14B407CED992501964840240D6E6B0BA14B407CED992501964840A9DE1AD82A9F4B4028B517D176924840A9DE1AD82A9F4B40
11661	40648	49.147826000000002	49.186794999999996	55.168166999999997	55.144818999999998	Ульяновское шоссе	0103000020E61000000100000005000000CFBF5DF6EB924840726BD26D89924B40CFBF5DF6EB9248401AA20A7F86954B40350708E6E89748401AA20A7F86954B40350708E6E8974840726BD26D89924B40CFBF5DF6EB924840726BD26D89924B40
78514	40648	49.147826000000002	49.186794999999996	55.168166999999997	55.144818999999998	Ленина	0103000020E61000000100000005000000CFBF5DF6EB924840726BD26D89924B40CFBF5DF6EB9248401AA20A7F86954B40350708E6E89748401AA20A7F86954B40350708E6E8974840726BD26D89924B40CFBF5DF6EB924840726BD26D89924B40
78567	40648	49.147826000000002	49.186794999999996	55.168166999999997	55.144818999999998	Гагарина	0103000020E61000000100000005000000CFBF5DF6EB924840726BD26D89924B40CFBF5DF6EB9248401AA20A7F86954B40350708E6E89748401AA20A7F86954B40350708E6E8974840726BD26D89924B40CFBF5DF6EB924840726BD26D89924B40
10399	14779	49.064058000000003	49.090477999999997	55.372042999999998	55.349307000000003	Мира	0103000020E610000001000000050000000A86730D33884840C7A17E17B6AC4B400A86730D3388484055DAE21A9FAF4B40F58079C8948B484055DAE21A9FAF4B40F58079C8948B4840C7A17E17B6AC4B400A86730D33884840C7A17E17B6AC4B40
10364	14002	48.834853000000003	48.859341000000001	55.227032000000001	55.207639	Габдуллы Тукая	0103000020E61000000100000005000000D7FB8D76DC6A4840E42F2DEA939A4B40D7FB8D76DC6A48409F9273620F9D4B40548EC9E2FE6D48409F9273620F9D4B40548EC9E2FE6D4840E42F2DEA939A4B40D7FB8D76DC6A4840E42F2DEA939A4B40
10360	13706	49.124659000000001	49.156827	55.142662999999999	55.127305999999997	Площадь Совхозная	0103000020E6100000010000000500000077137CD3F48F4840D34A21904B904B4077137CD3F48F4840B4ACFBC742924B409D103AE812944840B4ACFBC742924B409D103AE812944840D34A21904B904B4077137CD3F48F4840D34A21904B904B40
10557	13071	48.748283000000001	48.761172999999999	55.294386000000003	55.282564000000001	Школьная	0103000020E610000001000000050000008E93C2BCC75F48407383A10E2BA44B408E93C2BCC75F48403C33C170AEA54B4092CCEA1D6E6148403C33C170AEA54B4092CCEA1D6E6148407383A10E2BA44B408E93C2BCC75F48407383A10E2BA44B40
10332	13146	48.823768000000001	48.850250000000003	55.290264999999998	55.279358999999999	Мостовая	0103000020E61000000100000005000000E4BED53A71694840F06B2409C2A34B40E4BED53A7169484033164D6727A54B4046B6F3FDD46C484033164D6727A54B4046B6F3FDD46C4840F06B2409C2A34B40E4BED53A71694840F06B2409C2A34B40
10340	13338	49.242759999999997	49.289499999999997	55.213531000000003	55.185105999999998	Комарова	0103000020E6100000010000000500000073637AC2129F48408D25AC8DB1974B4073637AC2129F484052D7DAFB549B4B40931804560EA5484052D7DAFB549B4B40931804560EA548408D25AC8DB1974B4073637AC2129F48408D25AC8DB1974B40
10337	13338	49.242759999999997	49.289499999999997	55.213531000000003	55.185105999999998	Карла Маркса	0103000020E6100000010000000500000073637AC2129F48408D25AC8DB1974B4073637AC2129F484052D7DAFB549B4B40931804560EA5484052D7DAFB549B4B40931804560EA548408D25AC8DB1974B4073637AC2129F48408D25AC8DB1974B40
10660	13338	49.242759999999997	49.289499999999997	55.213531000000003	55.185105999999998	Гагарина	0103000020E6100000010000000500000073637AC2129F48408D25AC8DB1974B4073637AC2129F484052D7DAFB549B4B40931804560EA5484052D7DAFB549B4B40931804560EA548408D25AC8DB1974B4073637AC2129F48408D25AC8DB1974B40
10366	13715	49.050699999999999	49.068280999999999	55.154933	55.147762	Центральная	0103000020E610000001000000050000001FF46C567D864840B8CB7EDDE9924B401FF46C567D8648401C0934D8D4934B4016F88A6EBD8848401C0934D8D4934B4016F88A6EBD884840B8CB7EDDE9924B401FF46C567D864840B8CB7EDDE9924B40
10379	14387	49.023077000000001	49.037244000000001	55.23366	55.225594000000001	Кооперативная	0103000020E610000001000000050000001825E82FF48248404016A243E09C4B401825E82FF482484012312592E89D4B4072FC5069C484484012312592E89D4B4072FC5069C48448404016A243E09C4B401825E82FF48248404016A243E09C4B40
10403	14874	48.857114000000003	48.882795999999999	55.37726	55.353171000000003	Школьная	0103000020E61000000100000005000000CD785BE9B56D4840A47213B534AD4B40CD785BE9B56D4840630B410E4AB04B4012859675FF704840630B410E4AB04B4012859675FF704840A47213B534AD4B40CD785BE9B56D4840A47213B534AD4B40
10386	14303	49.053826999999998	49.079940999999998	55.265579000000002	55.255015	Свердлова	0103000020E6100000010000000500000026529ACDE3864840A67EDE54A4A04B4026529ACDE386484090C01F7EFEA14B40054EB6813B8A484090C01F7EFEA14B40054EB6813B8A4840A67EDE54A4A04B4026529ACDE3864840A67EDE54A4A04B40
10358	13902	48.954490999999997	48.975394999999999	55.230046000000002	55.218609999999998	Пионерская	0103000020E61000000100000005000000C5A9D6C22C7A48400E4A9869FB9B4B40C5A9D6C22C7A4840AE49B725729D4B4049D74CBED97C4840AE49B725729D4B4049D74CBED97C48400E4A9869FB9B4B40C5A9D6C22C7A48400E4A9869FB9B4B40
10381	14397	49.116610000000001	49.134810000000002	55.216289000000003	55.208326999999997	Школьная	0103000020E610000001000000050000007B319413ED8E4840D8EF8975AA9A4B407B319413ED8E484006BEA25BAF9B4B403E963E744191484006BEA25BAF9B4B403E963E7441914840D8EF8975AA9A4B407B319413ED8E4840D8EF8975AA9A4B40
10372	14096	48.904203000000003	48.916868999999998	55.280369	55.269544000000003	Ленинградская	0103000020E61000000100000005000000F9F884ECBC734840A16AF46A80A24B40F9F884ECBC734840F7E7A221E3A34B40ADDBA0F65B754840F7E7A221E3A34B40ADDBA0F65B754840A16AF46A80A24B40F9F884ECBC734840A16AF46A80A24B40
10376	14191	48.977595999999998	48.997115999999998	55.288193999999997	55.271467000000001	Центральная	0103000020E61000000100000005000000A759A0DD217D4840BC783F6EBFA24B40A759A0DD217D4840A3737E8AE3A44B40BF28417FA17F4840A3737E8AE3A44B40BF28417FA17F4840BC783F6EBFA24B40A759A0DD217D4840BC783F6EBFA24B40
10383	14475	49.044941999999999	49.065325000000001	55.222113	55.213084000000002	Школьная	0103000020E61000000100000005000000C11BD2A8C085484083A62556469B4B40C11BD2A8C08548401B82E3326E9C4B403C4ED1915C8848401B82E3326E9C4B403C4ED1915C88484083A62556469B4B40C11BD2A8C085484083A62556469B4B40
10375	14111	48.899208999999999	48.925538000000003	55.310195999999998	55.303673000000003	Ленина	0103000020E610000001000000050000006AA2CF4719734840D0D6C1C1DEA64B406AA2CF4719734840CDACA580B4A74B40469A780778764840CDACA580B4A74B40469A780778764840D0D6C1C1DEA64B406AA2CF4719734840D0D6C1C1DEA64B40
10334	13242	48.845982999999997	48.864282000000003	55.274799999999999	55.265799000000001	Центральная	0103000020E6100000010000000500000069FCC22B496C48409E279EB305A24B4069FCC22B496C48406C787AA52CA34B40C042E6CAA06E48406C787AA52CA34B40C042E6CAA06E48409E279EB305A24B4069FCC22B496C48409E279EB305A24B40
10330	12971	48.863796999999998	48.883631999999999	55.331857999999997	55.321599999999997	Центральная	0103000020E6100000010000000500000003B16CE6906E4840613255302AA94B4003B16CE6906E48403E75AC527AAA4B407BD976DA1A7148403E75AC527AAA4B407BD976DA1A714840613255302AA94B4003B16CE6906E4840613255302AA94B40
10272	40592	48.421044000000002	48.421970000000002	55.460496999999997	55.460241000000003	Светлая	0103000020E61000000100000005000000A91611C5E4354840A1A3552DE9BA4B40A91611C5E4354840FB73D190F1BA4B4052F2EA1C03364840FB73D190F1BA4B4052F2EA1C03364840A1A3552DE9BA4B40A91611C5E4354840A1A3552DE9BA4B40
10865	40835	47.645583000000002	48.579489000000002	55.541397000000003	55.213911000000003	Гагарина	0103000020E6100000010000000500000042EDB776A2D2474099A0866F619B4B4042EDB776A2D247408693347F4CC54B4025B20FB22C4A48408693347F4CC54B4025B20FB22C4A484099A0866F619B4B4042EDB776A2D2474099A0866F619B4B40
10285	11841	47.742725999999998	47.761330999999998	55.331330999999999	55.320523999999999	Кирова	0103000020E61000000100000005000000C7F143A511DF4740A3CA30EE06A94B40C7F143A511DF47405393E00D69AA4B402A37514B73E147405393E00D69AA4B402A37514B73E14740A3CA30EE06A94B40C7F143A511DF4740A3CA30EE06A94B40
11547	12343	48.175947999999998	48.210686000000003	55.358150999999999	55.343480999999997	Светлая	0103000020E61000000100000005000000F7E5CC768516484010E6762FF7AB4B40F7E5CC7685164840CD0358E4D7AD4B40CFDC43C2F71A4840CD0358E4D7AD4B40CFDC43C2F71A484010E6762FF7AB4B40F7E5CC768516484010E6762FF7AB4B40
10269	11390	48.344687999999998	48.369652000000002	55.497674000000004	55.486096000000003	Ямашева	0103000020E610000001000000050000006DA983BC1E2C4840B45BCB6438BE4B406DA983BC1E2C4840E60819C8B3BF4B405473B9C1502F4840E60819C8B3BF4B405473B9C1502F4840B45BCB6438BE4B406DA983BC1E2C4840B45BCB6438BE4B40
10288	11954	47.751575000000003	47.790643000000003	55.291550999999998	55.276871999999997	Кооперативная	0103000020E61000000100000005000000E0BE0E9C33E04740CC96AC8A70A34B40E0BE0E9C33E04740DC0E0D8B51A54B40DAE731CA33E54740DC0E0D8B51A54B40DAE731CA33E54740CC96AC8A70A34B40E0BE0E9C33E04740CC96AC8A70A34B40
11519	11866	47.820898	47.843940000000003	55.374313999999998	55.358058999999997	Центральная	0103000020E6100000010000000500000008AD872F13E94740EC8497E0D4AD4B4008AD872F13E94740AC376A85E9AF4B40A4E4D53906EC4740AC376A85E9AF4B40A4E4D53906EC4740EC8497E0D4AD4B4008AD872F13E94740EC8497E0D4AD4B40
10261	11169	48.365672000000004	48.392532000000003	55.459980999999999	55.447575999999998	Тутаева	0103000020E610000001000000050000000E881057CE2E4840BC3C9D2B4AB94B400E881057CE2E484004E44BA8E0BA4B401651137D3E32484004E44BA8E0BA4B401651137D3E324840BC3C9D2B4AB94B400E881057CE2E4840BC3C9D2B4AB94B40
10328	12891	48.051485999999997	48.083637000000003	55.426758	55.404806000000001	Школьная	0103000020E61000000100000005000000D619DF1797064840BF9CD9AED0B34B40D619DF179706484037A79201A0B64B4027DE019EB40A484037A79201A0B64B4027DE019EB40A4840BF9CD9AED0B34B40D619DF1797064840BF9CD9AED0B34B40
11521	11939	47.873359000000001	47.891074000000003	55.359369000000001	55.337302000000001	Центральная	0103000020E6100000010000000500000069554B3ACAEF47400D7041B62CAB4B4069554B3ACAEF47401E19ABCDFFAD4B4070287CB60EF247401E19ABCDFFAD4B4070287CB60EF247400D7041B62CAB4B4069554B3ACAEF47400D7041B62CAB4B40
11534	12084	48.097937999999999	48.115599000000003	55.410387	55.395117999999997	Клубная	0103000020E6100000010000000500000090847D3B890C4840CC07043A93B24B4090847D3B890C48400EDAAB8F87B44B40A439B2F2CB0E48400EDAAB8F87B44B40A439B2F2CB0E4840CC07043A93B24B4090847D3B890C4840CC07043A93B24B40
11506	11763	47.707881	47.737786	55.346829	55.334556999999997	Советская	0103000020E61000000100000005000000DA3A38D89BDA4740EDD286C3D2AA4B40DA3A38D89BDA4740F62686E464AC4B402CB98AC56FDE4740F62686E464AC4B402CB98AC56FDE4740EDD286C3D2AA4B40DA3A38D89BDA4740EDD286C3D2AA4B40
79108	61383	47.838667000000001	47.849409999999999	55.311886999999999	55.306327000000003	Центральная	0103000020E61000000100000005000000029EB47059EB4740DF701FB935A74B40029EB47059EB47401686C8E9EBA74B409B728577B9EC47401686C8E9EBA74B409B728577B9EC4740DF701FB935A74B40029EB47059EB4740DF701FB935A74B40
10253	11096	48.009939000000003	48.042234000000001	55.501299000000003	55.492635	Центральная	0103000020E610000001000000050000003CFA5FAE45014840B7EEE6A90EBF4B403CFA5FAE450148403E42CD902AC04B40BF6378EC670548403E42CD902AC04B40BF6378EC67054840B7EEE6A90EBF4B403CFA5FAE45014840B7EEE6A90EBF4B40
10315	11103	48.319687000000002	48.343933	55.439118999999998	55.420223999999997	Центральная	0103000020E610000001000000050000006AFAEC80EB284840457F68E6C9B54B406AFAEC80EB284840AF06280D35B84B40F1811DFF052C4840AF06280D35B84B40F1811DFF052C4840457F68E6C9B54B406AFAEC80EB284840457F68E6C9B54B40
10276	11654	47.798512000000002	47.821103999999998	55.332273000000001	55.314121	Почтовая 	0103000020E6100000010000000500000056BB26A435E6474050FEEE1D35A84B4056BB26A435E64740022CF2EB87AA4B40B14E95EF19E94740022CF2EB87AA4B40B14E95EF19E9474050FEEE1D35A84B4056BB26A435E6474050FEEE1D35A84B40
9956	11464	48.507561000000003	48.519581000000002	55.457709999999999	55.438848999999998	Центральная	0103000020E61000000100000005000000CFDC43C2F7404840EF703B342CB84B40CFDC43C2F7404840AD86C43D96BA4B40BE4F55A181424840AD86C43D96BA4B40BE4F55A181424840EF703B342CB84B40CFDC43C2F7404840EF703B342CB84B40
10297	12252	48.252161000000001	48.274287000000001	55.418492000000001	55.409007000000003	Школьная	0103000020E61000000100000005000000D029C8CF46204840E46A64575AB44B40D029C8CF462048409ED1562591B54B40E65B1FD61B2348409ED1562591B54B40E65B1FD61B234840E46A64575AB44B40D029C8CF46204840E46A64575AB44B40
11545	12276	48.165132	48.178615999999998	55.380395999999998	55.363717999999999	Центральная	0103000020E61000000100000005000000F4C29D0B23154840B77BB94F8EAE4B40F4C29D0B23154840BDC3EDD0B0B04B406B459BE3DC164840BDC3EDD0B0B04B406B459BE3DC164840B77BB94F8EAE4B40F4C29D0B23154840B77BB94F8EAE4B40
10308	12560	48.329819999999998	48.357821000000001	55.356636000000002	55.346435	Усманова	0103000020E610000001000000050000008AC8B08A372A48404A9869FB57AC4B408AC8B08A372A4840C3499A3FA6AD4B4038691A14CD2D4840C3499A3FA6AD4B4038691A14CD2D48404A9869FB57AC4B408AC8B08A372A48404A9869FB57AC4B40
10321	12834	47.907674999999998	47.930061000000002	55.427545000000002	55.416550000000001	Большая Красная	0103000020E61000000100000005000000CA32C4B12EF447400C93A98251B54B40CA32C4B12EF44740BF4868CBB9B64B407D24253D0CF74740BF4868CBB9B64B407D24253D0CF747400C93A98251B54B40CA32C4B12EF447400C93A98251B54B40
10323	12910	48.019893000000003	48.031238000000002	55.389074000000001	55.378850999999997	Бутанина	0103000020E61000000100000005000000AD3594DA8B024840488787307EB04B40AD3594DA8B024840A9DC442DCDB14B403C32569BFF034840A9DC442DCDB14B403C32569BFF034840488787307EB04B40AD3594DA8B024840488787307EB04B40
10368	40653	48.019793999999997	48.048791000000001	55.287891000000002	55.281508000000002	Красный Герой	0103000020E6100000010000000500000019541B9C88024840FCC7427408A44B4019541B9C8802484008E8BE9CD9A44B4069AB92C83E06484008E8BE9CD9A44B4069AB92C83E064840FCC7427408A44B4019541B9C88024840FCC7427408A44B40
10271	11376	48.427512	48.452835999999998	55.511741000000001	55.491630000000001	Октябрьская	0103000020E61000000100000005000000E35295B6B8364840C2DD59BBEDBE4B40E35295B6B8364840DC82A5BA80C14B40C939B187F6394840DC82A5BA80C14B40C939B187F6394840C2DD59BBEDBE4B40E35295B6B8364840C2DD59BBEDBE4B40
11527	12045	47.713144999999997	47.735190000000003	55.280903000000002	55.268707999999997	Центральная	0103000020E610000001000000050000002827DA5548DB47403716140665A24B402827DA5548DB4740952C27A1F4A34B40522CB7B41ADE4740952C27A1F4A34B40522CB7B41ADE47403716140665A24B402827DA5548DB47403716140665A24B40
10317	12531	48.377647000000003	48.422131	55.367888000000001	55.357092000000002	Зиганшина	0103000020E610000001000000050000005D37A5BC56304840E5D4CE30B5AD4B405D37A5BC56304840A14B38F416AF4B405BD07B6308364840A14B38F416AF4B405BD07B6308364840E5D4CE30B5AD4B405D37A5BC56304840E5D4CE30B5AD4B40
10319	12749	47.962760000000003	47.992080999999999	55.369453999999998	55.345630999999997	Площадь Свободы	0103000020E61000000100000005000000D0F23CB83BFB4740ECBDF8A23DAC4B40D0F23CB83BFB47402DB0C7444AAF4B40D2FD9C82FCFE47402DB0C7444AAF4B40D2FD9C82FCFE4740ECBDF8A23DAC4B40D0F23CB83BFB4740ECBDF8A23DAC4B40
10299	12136	48.174852000000001	48.198262	55.412590000000002	55.394995000000002	Шамиля Галеева	0103000020E61000000100000005000000F2D1E28C61164840B18A37328FB24B40F2D1E28C611648400D54C6BFCFB44B40100533A6601948400D54C6BFCFB44B40100533A660194840B18A37328FB24B40F2D1E28C61164840B18A37328FB24B40
10305	12458	48.113892	48.152295000000002	55.361288000000002	55.349193999999997	Школьная	0103000020E6100000010000000500000055A35703940E4840CEFA9463B2AC4B4055A35703940E4840F83768AF3EAE4B40132C0E677E134840F83768AF3EAE4B40132C0E677E134840CEFA9463B2AC4B4055A35703940E4840CEFA9463B2AC4B40
10265	11269	48.402313999999997	48.421250999999998	55.475102	55.461441000000001	Школьная	0103000020E61000000100000005000000895C70067F3348404B04AA7F10BB4B40895C70067F334840D1217024D0BC4B402234828DEB354840D1217024D0BC4B402234828DEB3548404B04AA7F10BB4B40895C70067F3348404B04AA7F10BB4B40
10318	12633	48.133780999999999	48.161557000000002	55.493482	55.481606999999997	Центральная	0103000020E61000000100000005000000C0E95DBC1F1148402843554CA5BD4B40C0E95DBC1F11484014950D6B2ABF4B404EB857E6AD14484014950D6B2ABF4B404EB857E6AD1448402843554CA5BD4B40C0E95DBC1F1148402843554CA5BD4B40
10293	12189	48.203409000000001	48.219560999999999	55.434007000000001	55.426104000000002	Конторская	0103000020E61000000100000005000000255B5D4E091A4840EF586C938AB64B40255B5D4E091A4840179E978A8DB74B40103D29931A1C4840179E978A8DB74B40103D29931A1C4840EF586C938AB64B40255B5D4E091A4840EF586C938AB64B40
10662	12676	48.184994000000003	48.204918999999997	55.491987000000002	55.482444000000001	Чапаева	0103000020E6100000010000000500000066FA25E2AD174840621399B9C0BD4B4066FA25E2AD1748405187156EF9BE4B401DAA29C93A1A48405187156EF9BE4B401DAA29C93A1A4840621399B9C0BD4B4066FA25E2AD174840621399B9C0BD4B40
10222	10480	48.344993000000002	48.367783000000003	55.575434000000001	55.564281999999999	Центральная	0103000020E61000000100000005000000AA2C0ABB282C484059DC7F643AC84B40AA2C0ABB282C4840D48041D2A7C94B402C836A83132F4840D48041D2A7C94B402C836A83132F484059DC7F643AC84B40AA2C0ABB282C484059DC7F643AC84B40
10228	10548	48.443393999999998	48.454641000000002	55.571193999999998	55.557006000000001	Мира	0103000020E610000001000000050000000E9F7422C138484080D6FCF84BC74B400E9F7422C1384840F1D58EE21CC94B40DB3521AD313A4840F1D58EE21CC94B40DB3521AD313A484080D6FCF84BC74B400E9F7422C138484080D6FCF84BC74B40
10166	8783	48.713822999999998	48.733739	56.039821000000003	56.027565000000003	Дружбы	0103000020E61000000100000005000000F910548D5E5B4840D3C1FA3F87034C40F910548D5E5B4840D658C2DA18054C405E66D828EB5D4840D658C2DA18054C405E66D828EB5D4840D3C1FA3F87034C40F910548D5E5B4840D3C1FA3F87034C40
79149	61415	48.263973999999997	48.281472999999998	55.654482000000002	55.641204000000002	Центральная	0103000020E61000000100000005000000457F68E6C92148403E0801F912D24B40457F68E6C92148400CE9F010C6D34B407FDAA84E072448400CE9F010C6D34B407FDAA84E072448403E0801F912D24B40457F68E6C92148403E0801F912D24B40
10505	10770	48.178742	48.203122	55.520349000000003	55.509568999999999	Центральная	0103000020E61000000100000005000000F8359204E11648401807978E39C14B40F8359204E1164840CFC0C8CB9AC24B408F8CD5E6FF194840CFC0C8CB9AC24B408F8CD5E6FF1948401807978E39C14B40F8359204E11648401807978E39C14B40
10257	11005	48.082693999999996	48.098010000000002	55.676082999999998	55.661897000000003	Чишма	0103000020E61000000100000005000000A7C98CB7950A48400729780AB9D44B40A7C98CB7950A4840D73043E389D64B402A5778978B0C4840D73043E389D64B402A5778978B0C48400729780AB9D44B40A7C98CB7950A48400729780AB9D44B40
10442	9685	48.647095999999998	48.671315	55.777453999999999	55.765796999999999	Рождественская	0103000020E61000000100000005000000ABAFAE0AD4524840FD2FD7A205E24B40ABAFAE0AD45248407B12D89C83E34B40392861A6ED5548407B12D89C83E34B40392861A6ED554840FD2FD7A205E24B40ABAFAE0AD4524840FD2FD7A205E24B40
10234	10578	48.286549000000001	48.314791999999997	55.516807	55.505296999999999	Центральная	0103000020E61000000100000005000000CBD93BA3AD2448402AE27492ADC04B40CBD93BA3AD24484004AC55BB26C24B406E85B01A4B28484004AC55BB26C24B406E85B01A4B2848402AE27492ADC04B40CBD93BA3AD2448402AE27492ADC04B40
10506	32928	48.724575999999999	48.741850999999997	55.909135999999997	55.898254999999999	Клубный переулок	0103000020E61000000100000005000000B6BB07E8BE5C4840F73B1405FAF24B40B6BB07E8BE5C4840E1CE85915EF44B40A0C03BF9F45E4840E1CE85915EF44B40A0C03BF9F45E4840F73B1405FAF24B40B6BB07E8BE5C4840F73B1405FAF24B40
10220	9902	48.514245000000003	48.535274000000001	55.777008000000002	55.770183000000003	Кооперативная	0103000020E61000000100000005000000D690B8C7D2414840B477465B95E24B40D690B8C7D24148407D5D86FF74E34B401633C2DB834448407D5D86FF74E34B401633C2DB83444840B477465B95E24B40D690B8C7D2414840B477465B95E24B40
10347	40643	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Гагарина	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10484	10273	48.274062000000001	48.314000999999998	55.623950999999998	55.600454999999997	Школьная	0103000020E61000000100000005000000C689AF76142348401EDC9DB5DBCC4B40C689AF76142348403BA759A0DDCF4B40A5F44C2F312848403BA759A0DDCF4B40A5F44C2F312848401EDC9DB5DBCC4B40C689AF76142348401EDC9DB5DBCC4B40
10215	10273	48.274062000000001	48.314000999999998	55.623950999999998	55.600454999999997	Гагарина	0103000020E61000000100000005000000C689AF76142348401EDC9DB5DBCC4B40C689AF76142348403BA759A0DDCF4B40A5F44C2F312848403BA759A0DDCF4B40A5F44C2F312848401EDC9DB5DBCC4B40C689AF76142348401EDC9DB5DBCC4B40
10880	8404	48.750295000000001	48.773066999999998	55.877172000000002	55.870151999999997	Свободы	0103000020E6100000010000000500000019ADA3AA096048404546072461EF4B4019ADA3AA09604840C47B0E2C47F04B40F44E05DCF3624840C47B0E2C47F04B40F44E05DCF36248404546072461EF4B4019ADA3AA096048404546072461EF4B40
10216	10181	48.290078999999999	48.308827000000001	55.703378000000001	55.694747999999997	Центральная	0103000020E61000000100000005000000D120054F212548400F7BA180EDD84B40D120054F21254840EA5C514A08DA4B40978FA4A487274840EA5C514A08DA4B40978FA4A4872748400F7BA180EDD84B40D120054F212548400F7BA180EDD84B40
10199	9781	48.499898000000002	48.536881999999999	55.817526999999998	55.777726999999999	Школьная	0103000020E61000000100000005000000FCAA5CA8FC3F4840AC1BEF8E8CE34B40FCAA5CA8FC3F48406A4C88B9A4E84B40D1E7A38CB84448406A4C88B9A4E84B40D1E7A38CB8444840AC1BEF8E8CE34B40FCAA5CA8FC3F4840AC1BEF8E8CE34B40
10201	9781	48.499898000000002	48.536881999999999	55.817526999999998	55.777726999999999	Советская	0103000020E61000000100000005000000FCAA5CA8FC3F4840AC1BEF8E8CE34B40FCAA5CA8FC3F48406A4C88B9A4E84B40D1E7A38CB84448406A4C88B9A4E84B40D1E7A38CB8444840AC1BEF8E8CE34B40FCAA5CA8FC3F4840AC1BEF8E8CE34B40
10200	9781	48.499898000000002	48.536881999999999	55.817526999999998	55.777726999999999	Первомайская	0103000020E61000000100000005000000FCAA5CA8FC3F4840AC1BEF8E8CE34B40FCAA5CA8FC3F48406A4C88B9A4E84B40D1E7A38CB84448406A4C88B9A4E84B40D1E7A38CB8444840AC1BEF8E8CE34B40FCAA5CA8FC3F4840AC1BEF8E8CE34B40
10219	10409	48.371456999999999	48.404767	55.621800999999998	55.601258999999999	Центральная	0103000020E61000000100000005000000656F29E78B2F48407CB60E0EF6CC4B40656F29E78B2F48405FCFD72C97CF4B4001C0B167CF3348405FCFD72C97CF4B4001C0B167CF3348407CB60E0EF6CC4B40656F29E78B2F48407CB60E0EF6CC4B40
10237	10731	48.128839999999997	48.149430000000002	55.539211999999999	55.529730999999998	Ленина	0103000020E61000000100000005000000543541D47D104840B456B439CEC34B40543541D47D1048402DCE18E604C54B404985B185201348402DCE18E604C54B404985B18520134840B456B439CEC34B40543541D47D104840B456B439CEC34B40
10209	10000	48.348730000000003	48.378267000000001	55.762925000000003	55.743507000000001	Каюма Насыри	0103000020E610000001000000050000002A91442FA32C48406DACC43C2BDF4B402A91442FA32C48408126C286A7E14B40F913950D6B3048408126C286A7E14B40F913950D6B3048406DACC43C2BDF4B402A91442FA32C48406DACC43C2BDF4B40
10240	10912	48.157226999999999	48.175274000000002	55.663217000000003	55.650637000000003	Советская	0103000020E610000001000000050000002B86AB0320144840A648BE1248D34B402B86AB03201448405C936E4BE4D44B4068EBE0606F1648405C936E4BE4D44B4068EBE0606F164840A648BE1248D34B402B86AB0320144840A648BE1248D34B40
10260	10814	48.202035000000002	48.221986999999999	55.620941000000002	55.606614	Центральная	0103000020E61000000100000005000000DDD26A48DC194840DBA50D87A5CD4B40DDD26A48DC1948406EDFA3FE7ACF4B408E91EC116A1C48406EDFA3FE7ACF4B408E91EC116A1C4840DBA50D87A5CD4B40DDD26A48DC194840DBA50D87A5CD4B40
10402	8419	48.613517000000002	48.663338000000003	55.862074999999997	55.843055	Школьная	0103000020E6100000010000000500000020459DB9874E484059DDEA39E9EB4B4020459DB9874E48407FD93D7958EE4B40D7187442E85448407FD93D7958EE4B40D7187442E854484059DDEA39E9EB4B4020459DB9874E484059DDEA39E9EB4B40
10487	10386	48.305529999999997	48.330593	55.673071999999998	55.659936999999999	Светлая	0103000020E6100000010000000500000033F9669B1B274840CE35CCD078D44B4033F9669B1B27484039ED293927D64B40ADA415DF502A484039ED293927D64B40ADA415DF502A4840CE35CCD078D44B4033F9669B1B274840CE35CCD078D44B40
10235	10653	48.258566000000002	48.280332000000001	55.555346	55.541713000000001	Новая	0103000020E61000000100000005000000C4EDD0B018214840B66801DA56C54B40C4EDD0B01821484072FBE59315C74B40DA0242EBE123484072FBE59315C74B40DA0242EBE1234840B66801DA56C54B40C4EDD0B018214840B66801DA56C54B40
10431	8853	48.757697	48.770218999999997	56.022131999999999	56.015264000000002	Клубная	0103000020E610000001000000050000007FA31D37FC6048403067B62BF4014C407FA31D37FC604840F818AC38D5024C4000E1438996624840F818AC38D5024C4000E14389966248403067B62BF4014C407FA31D37FC6048403067B62BF4014C40
10481	40686	48.246160000000003	48.258836000000002	55.714795000000002	55.699406000000003	Ибрагимова	0103000020E61000000100000005000000ACCABE2B821F48402750C42286D94B40ACCABE2B821F4840132C0E677EDB4B408483BD8921214840132C0E677EDB4B408483BD89212148402750C42286D94B40ACCABE2B821F48402750C42286D94B40
10225	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Школьная	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10184	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Территория Санатория	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10173	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Спортивная	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10187	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Свободы	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10185	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Праздничная	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10189	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Первомайская	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10489	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Набережная	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10174	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Ленина	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10197	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Лагерная	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10194	9064	48.646692000000002	48.752963000000001	55.855932000000003	55.820101000000001	Залесная	0103000020E61000000100000005000000DC4AAFCDC65248405D35CF11F9E84B40DC4AAFCDC6524840C9CC052E8FED4B408D0C721761604840C9CC052E8FED4B408D0C7217616048405D35CF11F9E84B40DC4AAFCDC65248405D35CF11F9E84B40
10461	8966	48.864640999999999	48.895094	56.035637000000001	56.022801000000001	Подгорная	0103000020E61000000100000005000000EFE3688EAC6E484076A8A624EB024C40EFE3688EAC6E484087C3D2C08F044C40446CB0709272484087C3D2C08F044C40446CB0709272484076A8A624EB024C40EFE3688EAC6E484076A8A624EB024C40
10207	10087	48.457569999999997	48.485920999999998	55.741987000000002	55.725639999999999	Светлая	0103000020E61000000100000005000000BBD05CA7913A4840B05582C5E1DC4B40BBD05CA7913A48405187156EF9DE4B4045B8C9A8323E48405187156EF9DE4B4045B8C9A8323E4840B05582C5E1DC4B40BBD05CA7913A4840B05582C5E1DC4B40
10168	8862	48.770524999999999	48.805441999999999	56.030653000000001	56.010869999999997	Школьная	0103000020E610000001000000050000000DE02D90A0624840F6402B3064014C400DE02D90A06248401C430070EC034C40946934B9186748401C430070EC034C40946934B918674840F6402B3064014C400DE02D90A0624840F6402B3064014C40
10470	9978	48.437178000000003	48.456257999999998	55.764221999999997	55.753999999999998	Кирова	0103000020E61000000100000005000000EE43DE72F53748408D976E1283E04B40EE43DE72F53748401D71C806D2E14B40E94482A9663A48401D71C806D2E14B40E94482A9663A48408D976E1283E04B40EE43DE72F53748408D976E1283E04B40
10171	8935	48.822375999999998	48.848956999999999	56.020299999999999	56.002138000000002	Школьная	0103000020E61000000100000005000000F581E49D43694840180AD80E46004C40F581E49D43694840ED0DBE3099024C40EA5A7B9FAA6C4840ED0DBE3099024C40EA5A7B9FAA6C4840180AD80E46004C40F581E49D43694840180AD80E46004C40
10420	8700	48.772365999999998	48.823723000000001	55.992094999999999	55.972800999999997	Волостнова	0103000020E610000001000000050000006B459BE3DC6248400F4240BE84FC4B406B459BE3DC62484037C30DF8FCFE4B4044FB58C16F69484037C30DF8FCFE4B4044FB58C16F6948400F4240BE84FC4B406B459BE3DC6248400F4240BE84FC4B40
10213	10215	48.327305000000003	48.355826999999998	55.717253999999997	55.700049999999997	Кооперативная	0103000020E610000001000000050000009D685721E52948404BC8073D9BD94B409D685721E52948406C76A4FACEDB4B40530438BD8B2D48406C76A4FACEDB4B40530438BD8B2D48404BC8073D9BD94B409D685721E52948404BC8073D9BD94B40
10164	8762	48.930039000000001	48.952254000000003	56.002223999999998	55.991672000000001	Школьная	0103000020E61000000100000005000000958098840B774840F12DAC1BEFFE4B40958098840B77484016A243E048004C401BBE8575E379484016A243E048004C401BBE8575E3794840F12DAC1BEFFE4B40958098840B774840F12DAC1BEFFE4B40
10394	8583	48.757356000000001	48.771341999999997	55.932096999999999	55.923845999999998	Юбилейная	0103000020E61000000100000005000000F6B6990AF16048402C45F29540F64B40F6B6990AF160484090D959F44EF74B40FF03AC55BB62484090D959F44EF74B40FF03AC55BB6248402C45F29540F64B40F6B6990AF16048402C45F29540F64B40
10245	10938	48.055124999999997	48.076720000000002	55.646746	55.631813000000001	Центральная	0103000020E61000000100000005000000931804560E0748400518963FDFD04B40931804560E074840CF68AB92C8D24B407D7901F6D1094840CF68AB92C8D24B407D7901F6D10948400518963FDFD04B40931804560E0748400518963FDFD04B40
10353	8487	48.610714999999999	48.642228000000003	55.876959999999997	55.864787999999997	Светлая	0103000020E610000001000000050000009C16BCE82B4E484093FC885FB1EE4B409C16BCE82B4E484038F3AB3940F04B40AA49F0863452484038F3AB3940F04B40AA49F0863452484093FC885FB1EE4B409C16BCE82B4E484093FC885FB1EE4B40
10390	8487	48.610714999999999	48.642228000000003	55.876959999999997	55.864787999999997	Молодежная	0103000020E610000001000000050000009C16BCE82B4E484093FC885FB1EE4B409C16BCE82B4E484038F3AB3940F04B40AA49F0863452484038F3AB3940F04B40AA49F0863452484093FC885FB1EE4B409C16BCE82B4E484093FC885FB1EE4B40
10344	40640	48.858685999999999	48.914937999999999	55.888382	55.870662000000003	40 лет Победы	0103000020E610000001000000050000003BC43F6CE96D48405BEF37DA71EF4B403BC43F6CE96D4840732D5A80B6F14B400FEF39B01C754840732D5A80B6F14B400FEF39B01C7548405BEF37DA71EF4B403BC43F6CE96D48405BEF37DA71EF4B40
75359	60582	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	Школьная	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
10071	5853	52.239485999999999	52.256203999999997	55.476897999999998	55.462170999999998	Центральная	0103000020E61000000100000005000000C8EC2C7AA71E4A406E14596B28BB4B40C8EC2C7AA71E4A408FC360FE0ABD4B405C8DEC4ACB204A408FC360FE0ABD4B405C8DEC4ACB204A406E14596B28BB4B40C8EC2C7AA71E4A406E14596B28BB4B40
10087	40524	51.915247999999998	51.950831000000001	55.204622999999998	55.191915999999999	Молодежная	0103000020E610000001000000050000005DDDB1D826F5494021CA17B490984B405DDDB1D826F5494034812216319A4B40F18288D4B4F9494034812216319A4B40F18288D4B4F9494021CA17B490984B405DDDB1D826F5494021CA17B490984B40
10088	6404	52.227080000000001	52.25562	55.104692	55.084069999999997	Центральная	0103000020E61000000100000005000000B0C91AF5101D4A40904946CEC28A4B40B0C91AF5101D4A409013268C668D4B400D1AFA27B8204A409013268C668D4B400D1AFA27B8204A40904946CEC28A4B40B0C91AF5101D4A40904946CEC28A4B40
78906	21628	51.764771000000003	51.801755	55.140796000000002	55.126919999999998	Школьная	0103000020E61000000100000005000000F1F62004E4E14940AA9A20EA3E904B40F1F62004E4E149402DB4739A05924B40C63368E89FE649402DB4739A05924B40C63368E89FE64940AA9A20EA3E904B40F1F62004E4E14940AA9A20EA3E904B40
10758	5558	52.071151	52.086593000000001	55.418424999999999	55.409103999999999	Центральная	0103000020E61000000100000005000000F209D9791B094A40D65416855DB44B40F209D9791B094A40166A4DF38EB54B400188BB7A150B4A40166A4DF38EB54B400188BB7A150B4A40D65416855DB44B40F209D9791B094A40D65416855DB44B40
10105	6523	51.829360000000001	51.851368999999998	55.179036000000004	55.170774000000002	Центральная	0103000020E61000000100000005000000274EEE7728EA4940E98024ECDB954B40274EEE7728EA49404167D2A6EA964B4003EACDA8F9EC49404167D2A6EA964B4003EACDA8F9EC4940E98024ECDB954B40274EEE7728EA4940E98024ECDB954B40
10082	6273	51.989404	52.013587000000001	55.074154	55.063910999999997	Центральная	0103000020E610000001000000050000000B444FCAA4FE4940656D533C2E884B400B444FCAA4FE49400D6FD6E07D894B404C530438BD014A400D6FD6E07D894B404C530438BD014A40656D533C2E884B400B444FCAA4FE4940656D533C2E884B40
10847	40833	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Габдуллы Тукая	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
79107	61385	52.003346000000001	52.018859999999997	55.195616000000001	55.172203000000003	Ленина	0103000020E61000000100000005000000454948A46D004A40F5A276BF0A964B40454948A46D004A408449F1F109994B40ED9925016A024A408449F1F109994B40ED9925016A024A40F5A276BF0A964B40454948A46D004A40F5A276BF0A964B40
10098	6097	52.336081999999998	52.356212999999997	55.228279000000001	55.214706999999997	Центральная	0103000020E610000001000000050000001B6327BC042B4A40739CDB847B9B4B401B6327BC042B4A408AAE0B3F389D4B407CB43863982D4A408AAE0B3F389D4B407CB43863982D4A40739CDB847B9B4B401B6327BC042B4A40739CDB847B9B4B40
10077	6067	51.897947000000002	51.935110000000002	55.231242000000002	55.219658000000003	Центральная	0103000020E610000001000000050000004A4563EDEFF249400327DBC01D9C4B404A4563EDEFF2494017BB7D56999D4B40CF143AAFB1F7494017BB7D56999D4B40CF143AAFB1F749400327DBC01D9C4B404A4563EDEFF249400327DBC01D9C4B40
10080	6192	52.001064	52.040132	55.108632	55.092185000000001	Центральная	0103000020E61000000100000005000000FA997ADD22004A404417D4B7CC8B4B40FA997ADD22004A4048A643A7E78D4B40F4C29D0B23054A4048A643A7E78D4B40F4C29D0B23054A404417D4B7CC8B4B40FA997ADD22004A404417D4B7CC8B4B40
79262	61504	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Чапаева	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10078	5965	52.124574000000003	52.137833000000001	55.381951000000001	55.370441	Центральная	0103000020E6100000010000000500000049F7730AF20F4A407C0C569C6AAF4B4049F7730AF20F4A4056D636C5E3B04B40A0A70183A4114A4056D636C5E3B04B40A0A70183A4114A407C0C569C6AAF4B4049F7730AF20F4A407C0C569C6AAF4B40
10092	5878	52.195656999999997	52.223793000000001	55.152742000000003	55.132643999999999	Молодежная	0103000020E61000000100000005000000E21DE0490B194A405C01857AFA904B40E21DE0490B194A40E25CC30C8D934B407009C03FA51C4A40E25CC30C8D934B407009C03FA51C4A405C01857AFA904B40E21DE0490B194A405C01857AFA904B40
79222	61473	52.000965000000001	52.021726000000001	55.451996999999999	55.441887000000001	Центральная	0103000020E6100000010000000500000067B8019F1F004A4087C3D2C08FB84B4067B8019F1F004A40EF71A609DBB94B4088BCE5EAC7024A40EF71A609DBB94B4088BCE5EAC7024A4087C3D2C08FB84B4067B8019F1F004A4087C3D2C08FB84B40
10540	5643	52.240896999999997	52.259869000000002	55.447448000000001	55.436469000000002	Центральная	0103000020E610000001000000050000002D5A80B6D51E4A40E25B5837DEB74B402D5A80B6D51E4A408F54DFF945B94B40431F2C6343214A408F54DFF945B94B40431F2C6343214A40E25B5837DEB74B402D5A80B6D51E4A40E25B5837DEB74B40
10778	5709	52.191578999999997	52.211494999999999	55.449658999999997	55.435662000000001	Закира Салимова	0103000020E61000000100000005000000D9CC21A985184A40130EBDC5C3B74B40D9CC21A985184A4010AD156D8EB94B403E22A644121B4A4010AD156D8EB94B403E22A644121B4A40130EBDC5C3B74B40D9CC21A985184A40130EBDC5C3B74B40
10054	40500	51.810423999999998	51.822695000000003	55.088732999999998	55.077612000000002	Центральная	0103000020E610000001000000050000005EF23FF9BBE749407AE3A430EF894B405EF23FF9BBE74940B9895A9A5B8B4B4097CADB114EE94940B9895A9A5B8B4B4097CADB114EE949407AE3A430EF894B405EF23FF9BBE749407AE3A430EF894B40
79204	61458	51.957047000000003	51.975355	55.457807000000003	55.447167	Центральная	0103000020E6100000010000000500000012DE1E8480FA4940DB6CACC43CB94B4012DE1E8480FA4940A070766B99BA4B40BB7EC16ED8FC4940A070766B99BA4B40BB7EC16ED8FC4940DB6CACC43CB94B4012DE1E8480FA4940DB6CACC43CB94B40
10103	6389	51.669486999999997	51.68112	55.158205000000002	55.148508	Центральная	0103000020E610000001000000050000006F0C01C0B1D54940E198654F02934B406F0C01C0B1D549402788BA0F40944B406553AEF02ED749402788BA0F40944B406553AEF02ED74940E198654F02934B406F0C01C0B1D54940E198654F02934B40
79202	61457	52.103408999999999	52.135568999999997	55.245738000000003	55.224192000000002	Центральная	0103000020E61000000100000005000000588E90813C0D4A402E03CE52B29C4B40588E90813C0D4A4036B1C057749F4B40FBAC32535A114A4036B1C057749F4B40FBAC32535A114A402E03CE52B29C4B40588E90813C0D4A402E03CE52B29C4B40
12052	40999	51.970880999999999	52.002088000000001	55.400393999999999	55.386220999999999	Советская	0103000020E6100000010000000500000065A71FD445FC4940A30392B06FB14B4065A71FD445FC4940DFC14F1C40B34B4066DB696B44004A40DFC14F1C40B34B4066DB696B44004A40A30392B06FB14B4065A71FD445FC4940A30392B06FB14B40
12057	41004	52.220370000000003	52.247508000000003	55.355935000000002	55.347321000000001	Центральная	0103000020E6100000010000000500000080828B15351C4A40651BB80375AC4B4080828B15351C4A403A4030478FAD4B40CBBF9657AE1F4A403A4030478FAD4B40CBBF9657AE1F4A40651BB80375AC4B4080828B15351C4A40651BB80375AC4B40
10108	40527	52.069498000000003	52.086162000000002	55.087017000000003	55.075721000000001	Дорожная	0103000020E6100000010000000500000097917A4FE5084A406A4FC939B1894B4097917A4FE5084A401899805F238B4B4038143E5B070B4A401899805F238B4B4038143E5B070B4A406A4FC939B1894B4097917A4FE5084A406A4FC939B1894B40
12055	41002	52.210039000000002	52.235039999999998	55.332084000000002	55.315586000000003	Школьная	0103000020E6100000010000000500000039F1D58EE21A4A40A9893E1F65A84B4039F1D58EE21A4A402FC37FBA81AA4B403CA06CCA151E4A402FC37FBA81AA4B403CA06CCA151E4A40A9893E1F65A84B4039F1D58EE21A4A40A9893E1F65A84B40
12059	41006	51.981507999999998	52.004351999999997	55.5154	55.500621000000002	Центральная	0103000020E610000001000000050000009561DC0DA2FD49406D58535914C04B409561DC0DA2FD4940E02D90A0F8C14B400AD6389B8E004A40E02D90A0F8C14B400AD6389B8E004A406D58535914C04B409561DC0DA2FD49406D58535914C04B40
12058	41005	52.045935	52.063282000000001	55.474035999999998	55.460940999999998	Центральная	0103000020E61000000100000005000000F25EB532E1054A4059315C1D00BB4B40F25EB532E1054A4036902E36ADBC4B407636E49F19084A4036902E36ADBC4B407636E49F19084A4059315C1D00BB4B40F25EB532E1054A4059315C1D00BB4B40
11042	40691	52.098235000000003	52.121653999999999	55.456795999999997	55.445318999999998	Молодежная	0103000020E610000001000000050000004A29E8F6920C4A40CAA4863600B94B404A29E8F6920C4A40C878944A78BA4B40BBB6B75B920F4A40C878944A78BA4B40BBB6B75B920F4A40CAA4863600B94B404A29E8F6920C4A40CAA4863600B94B40
12100	41015	51.810369999999999	51.834767999999997	55.356164999999997	55.340220000000002	Центральная	0103000020E610000001000000050000006BD44334BAE74940FAB836548CAB4B406BD44334BAE749406B7D91D096AD4B40A8DF85ADD9EA49406B7D91D096AD4B40A8DF85ADD9EA4940FAB836548CAB4B406BD44334BAE74940FAB836548CAB4B40
12102	41017	52.324871000000002	52.347310999999998	55.461767999999999	55.451904999999996	Центральная	0103000020E610000001000000050000009C35785F95294A400EF3E505D8B94B409C35785F95294A406F2BBD361BBB4B404145D5AF742C4A406F2BBD361BBB4B404145D5AF742C4A400EF3E505D8B94B409C35785F95294A400EF3E505D8B94B40
10023	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	пр. Победы	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10021	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	пр. Нефтяников	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10015	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Энергетиков	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10034	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Ульянова	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10031	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Толстого	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
12049	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Пионерская	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10013	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Лобачевского	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10010	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Ленина	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10014	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Комсомольская	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10039	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Казанская	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
10029	40480	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	Заводская	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
12101	41016	52.297480999999998	52.326253999999999	55.440524000000003	55.428516000000002	Молодежная 	0103000020E6100000010000000500000037177FDB13264A4008E8BE9CD9B64B4037177FDB13264A40338D261763B84B403718EAB0C2294A40338D261763B84B403718EAB0C2294A4008E8BE9CD9B64B4037177FDB13264A4008E8BE9CD9B64B40
12053	41000	52.001738000000003	52.008287000000003	55.339118999999997	55.330342999999999	Пушкина	0103000020E610000001000000050000008A9466F338004A4034BBEEAD48AA4B408A9466F338004A40E2395B4068AB4B40B1FD648C0F014A40E2395B4068AB4B40B1FD648C0F014A4034BBEEAD48AA4B408A9466F338004A4034BBEEAD48AA4B40
12085	41009	52.240913999999997	52.259779000000002	55.269067	55.255071999999998	Молодежная	0103000020E6100000010000000500000003931B45D61E4A400A100533A6A04B4003931B45D61E4A4067B796C970A24B400398327040214A4067B796C970A24B400398327040214A400A100533A6A04B4003931B45D61E4A400A100533A6A04B40
12054	41001	52.283450000000002	52.305863000000002	55.347259000000001	55.336339000000002	Советская	0103000020E610000001000000050000008E06F01648244A4047AF06280DAB4B408E06F01648244A40EF1EA0FB72AC4B403A07CF8426274A40EF1EA0FB72AC4B403A07CF8426274A4047AF06280DAB4B408E06F01648244A4047AF06280DAB4B40
12099	41014	51.848306000000001	51.879854999999999	55.338991	55.320376000000003	Молодежная	0103000020E6100000010000000500000013807F4A95EC49402F36AD1402A94B4013807F4A95EC4940B5519D0E64AB4B406D1CB1169FF04940B5519D0E64AB4B406D1CB1169FF049402F36AD1402A94B4013807F4A95EC49402F36AD1402A94B40
12098	41013	52.105331999999997	52.117638999999997	55.508386000000002	55.500295000000001	Речная	0103000020E61000000100000005000000739CDB847B0D4A4019ADA3AA09C04B40739CDB847B0D4A4044DFDDCA12C14B40F8DD74CB0E0F4A4044DFDDCA12C14B40F8DD74CB0E0F4A4019ADA3AA09C04B40739CDB847B0D4A4019ADA3AA09C04B40
12079	41008	52.303482000000002	52.327305000000003	55.148291999999998	55.139411000000003	Школьная	0103000020E610000001000000050000005C76887FD8264A40F1D93A38D8914B405C76887FD8264A401421753BFB924B409D685721E5294A401421753BFB924B409D685721E5294A40F1D93A38D8914B405C76887FD8264A40F1D93A38D8914B40
12089	41010	52.205475999999997	52.236503999999996	55.491951999999998	55.486336000000001	Центральная	0103000020E61000000100000005000000730E9E094D1A4A40096F0F4240BE4B40730E9E094D1A4A40D4997B48F8BE4B40C4AF58C3451E4A40D4997B48F8BE4B40C4AF58C3451E4A40096F0F4240BE4B40730E9E094D1A4A40096F0F4240BE4B40
12056	41003	52.020603000000001	52.046968	55.494782000000001	55.480291000000001	Клубная	0103000020E6100000010000000500000089997D1EA3024A4015C8EC2C7ABD4B4089997D1EA3024A4022533E0455BF4B40B1FA230C03064A4022533E0455BF4B40B1FA230C03064A4015C8EC2C7ABD4B4089997D1EA3024A4015C8EC2C7ABD4B40
12103	41018	52.149070999999999	52.175615999999998	55.466672000000003	55.457112000000002	Центральная	0103000020E6100000010000000500000019E42EC214134A40F94D61A582BA4B4019E42EC214134A40BEFA78E8BBBB4B40C153C8957A164A40BEFA78E8BBBB4B40C153C8957A164A40F94D61A582BA4B4019E42EC214134A40F94D61A582BA4B40
12051	40998	51.899679999999996	51.927455999999999	55.348922999999999	55.333584000000002	Вахитова	0103000020E61000000100000005000000C16ED8B628F34940043C69E1B2AA4B40C16ED8B628F349403EE94482A9AC4B404F3DD2E0B6F649403EE94482A9AC4B404F3DD2E0B6F64940043C69E1B2AA4B40C16ED8B628F34940043C69E1B2AA4B40
8260	2234	51.857728999999999	51.874051999999999	55.829268999999996	55.820860000000003	Центральная	0103000020E6100000010000000500000057EA5910CAED49401B4CC3F011E94B4057EA5910CAED4940164B917C25EA4B406F8099EFE0EF4940164B917C25EA4B406F8099EFE0EF49401B4CC3F011E94B4057EA5910CAED49401B4CC3F011E94B40
8264	2467	51.797066000000001	51.829917000000002	55.791127000000003	55.775505000000003	Московская	0103000020E610000001000000050000007460394206E64940377172BF43E34B407460394206E64940C6FD47A643E54B407DB262B83AEA4940C6FD47A643E54B407DB262B83AEA4940377172BF43E34B407460394206E64940377172BF43E34B40
8261	2299	51.554071999999998	51.580283999999999	55.892254000000001	55.877172000000002	Ленина	0103000020E610000001000000050000008DD0CFD4EBC64940C47B0E2C47F04B408DD0CFD4EBC64940D3DC0A6135F24B402F3201BF46CA4940D3DC0A6135F24B402F3201BF46CA4940C47B0E2C47F04B408DD0CFD4EBC64940C47B0E2C47F04B40
8259	2191	51.949275999999998	51.973835999999999	55.825370999999997	55.812631000000003	Школьная	0103000020E6100000010000000500000058703FE081F949409F5BE84A04E84B4058703FE081F949408D08C6C1A5E94B406FD575A8A6FC49408D08C6C1A5E94B406FD575A8A6FC49409F5BE84A04E84B4058703FE081F949409F5BE84A04E84B40
12006	40995	51.544558000000002	51.565246999999999	55.748578999999999	55.732773000000002	Мира	0103000020E6100000010000000500000039639813B4C5494027327381CBDD4B4039639813B4C5494077BCC96FD1DF4B40C09481035AC8494077BCC96FD1DF4B40C09481035AC8494027327381CBDD4B4039639813B4C5494027327381CBDD4B40
11227	40903	51.953885	51.985083000000003	55.807611999999999	55.79768	Набережная	0103000020E610000001000000050000008E9257E718FA49402E56D4601AE64B408E9257E718FA4940B7ED7BD45FE74B403C6C223317FE4940B7ED7BD45FE74B403C6C223317FE49402E56D4601AE64B408E9257E718FA49402E56D4601AE64B40
12005	40994	51.542825000000001	51.572200000000002	55.856341	55.842509	Школьная	0103000020E61000000100000005000000C139234A7BC54940F7CABC55D7EB4B40C139234A7BC54940AA9CF6949CED4B40B7627FD93DC94940AA9CF6949CED4B40B7627FD93DC94940F7CABC55D7EB4B40C139234A7BC54940F7CABC55D7EB4B40
12003	40992	51.880186999999999	51.946114000000001	55.749257999999998	55.732838999999998	Ермазова	0103000020E61000000100000005000000A3AEB5F7A9F04940DE1D19ABCDDD4B40A3AEB5F7A9F049401822A7AFE7DF4B40D52478431AF949401822A7AFE7DF4B40D52478431AF94940DE1D19ABCDDD4B40A3AEB5F7A9F04940DE1D19ABCDDD4B40
12002	40991	51.722946	51.749949000000001	55.918666000000002	55.896397999999998	Школьная	0103000020E610000001000000050000001363997E89DC494093196F2BBDF24B401363997E89DC49403CF9F4D896F54B407E552E54FEDF49403CF9F4D896F54B407E552E54FEDF494093196F2BBDF24B401363997E89DC494093196F2BBDF24B40
12001	40990	51.588647999999999	51.606228000000002	55.915593999999999	55.902484999999999	Садовая	0103000020E610000001000000050000008B6D52D158CB4940B610E4A084F34B408B6D52D158CB4940F834272F32F54B40B2F50CE198CD4940F834272F32F54B40B2F50CE198CD4940B610E4A084F34B408B6D52D158CB4940B610E4A084F34B40
11992	40985	51.639420999999999	51.645789999999998	55.736502999999999	55.732362000000002	Центральная	0103000020E6100000010000000500000014B01D8CD8D14940A56ABB09BEDD4B4014B01D8CD8D14940F433F5BA45DE4B40BB0A293FA9D24940F433F5BA45DE4B40BB0A293FA9D24940A56ABB09BEDD4B4014B01D8CD8D14940A56ABB09BEDD4B40
11995	40987	52.218339999999998	52.236503999999996	55.780642999999998	55.770764999999997	Лесная	0103000020E610000001000000050000004EB4AB90F21B4A4062F3716DA8E24B404EB4AB90F21B4A40F86C1D1CECE34B40C4AF58C3451E4A40F86C1D1CECE34B40C4AF58C3451E4A4062F3716DA8E24B404EB4AB90F21B4A4062F3716DA8E24B40
11994	40986	51.704512000000001	51.729719000000003	55.717508000000002	55.698816999999998	Прикамская	0103000020E61000000100000005000000DDD1FF722DDA4940C571E0D572D94B40DDD1FF722DDA4940274F594DD7DB4B408A22A46E67DD4940274F594DD7DB4B408A22A46E67DD4940C571E0D572D94B40DDD1FF722DDA4940C571E0D572D94B40
9685	40268	51.713746999999998	51.739258999999997	55.820262999999997	55.801202000000004	Казанская	0103000020E610000001000000050000001E4FCB0F5CDB4940B2BE81C98DE64B401E4FCB0F5CDB4940368FC360FEE84B400723F609A0DE4940368FC360FEE84B400723F609A0DE4940B2BE81C98DE64B401E4FCB0F5CDB4940B2BE81C98DE64B40
11998	40989	52.168222999999998	52.18927	55.749085999999998	55.743183000000002	Есенина	0103000020E61000000100000005000000AEB7CD5488154A40BAF8DB9E20DF4B40AEB7CD5488154A401BF2CF0CE2DF4B40950ED6FF39184A401BF2CF0CE2DF4B40950ED6FF39184A40BAF8DB9E20DF4B40AEB7CD5488154A40BAF8DB9E20DF4B40
12007	40996	51.651099000000002	51.677185999999999	55.644297999999999	55.631020999999997	Нефтяников	0103000020E61000000100000005000000AABA473657D349406B0BCF4BC5D04B40AABA473657D3494069705B5B78D24B408FA7E507AED6494069705B5B78D24B408FA7E507AED649406B0BCF4BC5D04B40AABA473657D349406B0BCF4BC5D04B40
11988	40982	51.588396000000003	51.613512999999998	55.704746999999998	55.691633000000003	Молодежная	0103000020E61000000100000005000000728C648F50CB4940CDEA1D6E87D84B40728C648F50CB4940207A522635DA4B40DE550F9887CE4940207A522635DA4B40DE550F9887CE4940CDEA1D6E87D84B40728C648F50CB4940CDEA1D6E87D84B40
12004	40993	51.925443999999999	51.952914999999997	55.779504000000003	55.769241000000001	Центральная	0103000020E61000000100000005000000C423F1F274F6494005DF347D76E24B40C423F1F274F64940F48C7DC9C6E34B40156F641EF9F94940F48C7DC9C6E34B40156F641EF9F9494005DF347D76E24B40C423F1F274F6494005DF347D76E24B40
11970	40980	52.010029000000003	52.030484000000001	55.872905000000003	55.867213	Центральная	0103000020E610000001000000050000007C8159A148014A4041D5E8D500EF4B407C8159A148014A40E8C1DD59BBEF4B40908653E6E6034A40E8C1DD59BBEF4B40908653E6E6034A4041D5E8D500EF4B407C8159A148014A4041D5E8D500EF4B40
11186	40902	51.552931000000001	51.580993999999997	55.795994999999998	55.786833999999999	40 лет Победы	0103000020E61000000100000005000000E8F86871C6C64940C0B0FCF9B6E44B40E8F86871C6C64940C763062AE3E54B400B96EA025ECA4940C763062AE3E54B400B96EA025ECA4940C0B0FCF9B6E44B40E8F86871C6C64940C0B0FCF9B6E44B40
9628	40236	51.755600000000001	51.770933999999997	55.781550000000003	55.766278	Центральная	0103000020E61000000100000005000000C66D3480B7E0494078D2C26515E24B40C66D3480B7E049402B1895D409E44B40EEAF1EF7ADE249402B1895D409E44B40EEAF1EF7ADE2494078D2C26515E24B40C66D3480B7E0494078D2C26515E24B40
9632	40239	52.112625999999999	52.133656000000002	55.84075	55.822989	Гусева	0103000020E61000000100000005000000F3565D876A0E4A40DFFB1BB457E94B40F3565D876A0E4A40560E2DB29DEB4B400475CAA31B114A40560E2DB29DEB4B400475CAA31B114A40DFFB1BB457E94B40F3565D876A0E4A40DFFB1BB457E94B40
11964	40979	51.722793000000003	51.743606999999997	55.893183000000001	55.880046	Сайдашева	0103000020E610000001000000050000008D63247B84DC4940E17CEA58A5F04B408D63247B84DC4940ED2B0FD253F24B40D009A1832EDF4940ED2B0FD253F24B40D009A1832EDF4940E17CEA58A5F04B408D63247B84DC4940E17CEA58A5F04B40
78493	2857	47.377265000000001	47.411454999999997	54.823537999999999	54.806283000000001	Ленина	0103000020E61000000100000005000000757632384AB047400F29064834674B40757632384AB04740B28174B169694B404963B48EAAB44740B28174B169694B404963B48EAAB447400F29064834674B40757632384AB047400F29064834674B40
78477	3258	47.511769999999999	47.539411000000001	54.719408999999999	54.698390000000003	Октябрьская	0103000020E610000001000000050000007689EAAD81C147403EEDF0D764594B407689EAAD81C147405AB91798155C4B40240D6E6B0BC547405AB91798155C4B40240D6E6B0BC547403EEDF0D764594B407689EAAD81C147403EEDF0D764594B40
79070	2404	47.433095000000002	47.455714999999998	54.687603000000003	54.668384000000003	Горького	0103000020E61000000100000005000000D3872EA86FB74740B8955E9B8D554B40D3872EA86FB74740D5D0066003584B40F8A57EDE54BA4740D5D0066003584B40F8A57EDE54BA4740B8955E9B8D554B40D3872EA86FB74740B8955E9B8D554B40
79105	3976	47.722092000000004	47.752859000000001	54.902656	54.882862000000003	Школьная	0103000020E61000000100000005000000045ABA826DDC4740CA703C9F01714B40045ABA826DDC4740E3C4573B8A734B40E8BF07AF5DE04740E3C4573B8A734B40E8BF07AF5DE04740CA703C9F01714B40045ABA826DDC4740CA703C9F01714B40
79087	3875	47.684659000000003	47.717312999999997	54.822848	54.812561000000002	Горького	0103000020E61000000100000005000000BFF4F6E7A2D74740A680B4FF01684B40BFF4F6E7A2D747401DCA501553694B4071FF91E9D0DB47401DCA501553694B4071FF91E9D0DB4740A680B4FF01684B40BFF4F6E7A2D74740A680B4FF01684B40
79080	3324	47.516477000000002	47.530751000000002	54.728394000000002	54.719773000000004	Клубная	0103000020E610000001000000050000006F1118EB1BC247409CC58B85215C4B406F1118EB1BC24740234DBC033C5D4B40DFA815A6EFC34740234DBC033C5D4B40DFA815A6EFC347409CC58B85215C4B406F1118EB1BC247409CC58B85215C4B40
79103	3748	47.752608000000002	47.779935000000002	54.793230999999999	54.781171000000001	Красная площадь	0103000020E610000001000000050000009F5A7D7555E04740B4CA4C69FD634B409F5A7D7555E047403196E99788654B40BD00FBE8D4E347403196E99788654B40BD00FBE8D4E34740B4CA4C69FD634B409F5A7D7555E04740B4CA4C69FD634B40
79077	2101	47.375458999999999	47.400621000000001	54.554133	54.546039	Комарова	0103000020E6100000010000000500000093FE5E0A0FB0474097AB1F9BE4454B4093FE5E0A0FB04740335184D4ED464B40A08B868C47B34740335184D4ED464B40A08B868C47B3474097AB1F9BE4454B4093FE5E0A0FB0474097AB1F9BE4454B40
79081	3017	47.413539	47.430354999999999	54.874932000000001	54.859487000000001	Советская	0103000020E610000001000000050000006E4F90D8EEB44740282B86AB036E4B406E4F90D8EEB44740A81C93C5FD6F4B40C55565DF15B74740A81C93C5FD6F4B40C55565DF15B74740282B86AB036E4B406E4F90D8EEB44740282B86AB036E4B40
79073	2680	47.408867999999998	47.443767000000001	54.712014000000003	54.691881000000002	Гагарина	0103000020E61000000100000005000000C23060C955B44740A5DC7D8E8F584B40C23060C955B44740A7255646235B4B40A305685BCDB84740A7255646235B4B40A305685BCDB84740A5DC7D8E8F584B40C23060C955B44740A5DC7D8E8F584B40
78469	2451	47.521057999999996	47.556379999999997	54.664259999999999	54.637855999999999	Коминтерна	0103000020E61000000100000005000000DAA84E07B2C2474058C7F143A5514B40DAA84E07B2C247403E05C07806554B400113B87537C747403E05C07806554B400113B87537C7474058C7F143A5514B40DAA84E07B2C2474058C7F143A5514B40
78468	2981	47.500369999999997	47.537712999999997	54.844067000000003	54.820357999999999	Советская	0103000020E6100000010000000500000023F3C81F0CC047408881AE7D01694B4023F3C81F0CC04740015130630A6C4B4028D192C7D3C44740015130630A6C4B4028D192C7D3C447408881AE7D01694B4023F3C81F0CC047408881AE7D01694B40
79076	3140	47.470213999999999	47.496003999999999	54.816586999999998	54.799168000000002	Центральная	0103000020E61000000100000005000000880FECF82FBC47403F0114234B664B40880FECF82FBC47405CAB3DEC85684B40B4571F0F7DBF47405CAB3DEC85684B40B4571F0F7DBF47403F0114234B664B40880FECF82FBC47403F0114234B664B40
69280	1990	47.948583999999997	48.007154999999997	54.764063999999998	54.742341000000003	Ленина	0103000020E6100000010000000500000022C154336BF947406FBDA607055F4B4022C154336BF94740850662D9CC614B405E807D74EA004840850662D9CC614B405E807D74EA0048406FBDA607055F4B4022C154336BF947406FBDA607055F4B40
79102	3373	47.567599999999999	47.589635999999999	54.696033	54.683273	Центральная	0103000020E61000000100000005000000D49AE61DA7C84740B29E5A7D75574B40D49AE61DA7C84740E8F7FD9B17594B40AA45443179CB4740E8F7FD9B17594B40AA45443179CB4740B29E5A7D75574B40D49AE61DA7C84740B29E5A7D75574B40
79104	3587	47.673394000000002	47.691343000000003	54.787505000000003	54.779743000000003	Крепкова	0103000020E610000001000000050000004CA94BC631D6474079245E9ECE634B404CA94BC631D64740DF37BEF6CC644B40C6A86BED7DD84740DF37BEF6CC644B40C6A86BED7DD8474079245E9ECE634B404CA94BC631D6474079245E9ECE634B40
69321	3446	47.532611000000003	47.577607	54.735199000000001	54.717422999999997	Центральная	0103000020E61000000100000005000000B43EE5982CC44740F8325184D45B4B40B43EE5982CC44740A58636001B5E4B406878B306EFC94740A58636001B5E4B406878B306EFC94740F8325184D45B4B40B43EE5982CC44740F8325184D45B4B40
79093	3687	47.620789000000002	47.654682999999999	54.714078999999998	54.700242000000003	Ленина	0103000020E61000000100000005000000B85B920376CF474090A4A487A1594B40B85B920376CF474054E1CFF0665B4B40A31F0DA7CCD3474054E1CFF0665B4B40A31F0DA7CCD3474090A4A487A1594B40B85B920376CF474090A4A487A1594B40
79089	3791	47.769604000000001	47.803803000000002	54.782479000000002	54.759929	Центральная	0103000020E61000000100000005000000766F456282E2474018247D5A45614B40766F456282E247404567994528644B409EB64604E3E647404567994528644B409EB64604E3E6474018247D5A45614B40766F456282E2474018247D5A45614B40
79074	2558	47.610539000000003	47.639302999999998	54.648724000000001	54.631127999999997	Советская	0103000020E610000001000000050000005EF7562426CE474081CB63CDC8504B405EF7562426CE4740AE10566309534B400A9E42AED4D14740AE10566309534B400A9E42AED4D1474081CB63CDC8504B405EF7562426CE474081CB63CDC8504B40
79078	3223	47.569423	47.615211000000002	54.828206000000002	54.809370000000001	Ленина	0103000020E610000001000000050000008C4B55DAE2C84740882EA86F99674B408C4B55DAE2C84740ED2C7AA7026A4B40DA91EA3BBFCE4740ED2C7AA7026A4B40DA91EA3BBFCE4740882EA86F99674B408C4B55DAE2C84740882EA86F99674B40
78974	3091	47.540812000000003	47.567509999999999	54.803460000000001	54.787292000000001	Кооперативная	0103000020E6100000010000000500000066A4DE5339C547408333F8FBC5644B4066A4DE5339C5474074D2FBC6D7664B409413ED2AA4C8474074D2FBC6D7664B409413ED2AA4C847408333F8FBC5644B4066A4DE5339C547408333F8FBC5644B40
79075	2289	47.465318000000003	47.491522000000003	54.571125000000002	54.557422000000003	Центральная	0103000020E61000000100000005000000BD1E4C8A8FBB47401409A69A59474B40BD1E4C8A8FBB4740C976BE9F1A494B40DCA16131EABE4740C976BE9F1A494B40DCA16131EABE47401409A69A59474B40BD1E4C8A8FBB47401409A69A59474B40
78470	2523	47.613225	47.654584	54.678139999999999	54.663594000000003	Советская	0103000020E61000000100000005000000780B24287ECE474032E9EFA5F0544B40780B24287ECE4740020EA14ACD564B40103E9468C9D34740020EA14ACD564B40103E9468C9D3474032E9EFA5F0544B40780B24287ECE474032E9EFA5F0544B40
78484	3538	47.546283000000003	47.572361000000001	54.745797000000003	54.731310999999998	Молодежная	0103000020E610000001000000050000002EAEF199ECC547403F1A4E999B5D4B402EAEF199ECC547403B3AAE46765F4B40C040102043C947403B3AAE46765F4B40C040102043C947403F1A4E999B5D4B402EAEF199ECC547403F1A4E999B5D4B40
78464	2632	47.320993999999999	47.347071999999997	54.735235000000003	54.721041999999997	Ленина	0103000020E610000001000000050000002A1BD65416A947406E85B01A4B5C4B402A1BD65416A94740F2EF332E1C5E4B40BCADF4DA6CAC4740F2EF332E1C5E4B40BCADF4DA6CAC47406E85B01A4B5C4B402A1BD65416A947406E85B01A4B5C4B40
78458	2174	47.399687	47.425702000000001	54.599769000000002	54.58954	Дорожная	0103000020E6100000010000000500000074D190F128B3474088D7F50B764B4B4074D190F128B34740CB13083BC54C4B40C0EB33677DB64740CB13083BC54C4B40C0EB33677DB6474088D7F50B764B4B4074D190F128B3474088D7F50B764B4B40
79082	2783	47.377372999999999	47.418390000000002	54.781877000000001	54.758693000000001	Замалетдинова	0103000020E610000001000000050000005BB22AC24DB04740215A2BDA1C614B405BB22AC24DB047404F3FA88B14644B409A7CB3CD8DB547404F3FA88B14644B409A7CB3CD8DB54740215A2BDA1C614B405BB22AC24DB04740215A2BDA1C614B40
78466	2740	47.415883000000001	47.468983000000001	54.790708000000002	54.769678999999996	Уганина	0103000020E610000001000000050000002FFB75A73BB5474080B56AD784624B402FFB75A73BB54740C15774EB35654B40A3B08BA207BC4740C15774EB35654B40A3B08BA207BC474080B56AD784624B402FFB75A73BB5474080B56AD784624B40
79084	3844	47.781793999999998	47.811897000000002	54.789524	54.774788999999998	Центральная	0103000020E61000000100000005000000C11A67D311E44740782634492C634B40C11A67D311E447401CB4571F0F654B403A5CAB3DECE747401CB4571F0F654B403A5CAB3DECE74740782634492C634B40C11A67D311E44740782634492C634B40
75346	4050	47.850740000000002	47.895080999999998	54.778574999999996	54.758105999999998	Крупская	0103000020E6100000010000000500000014B35E0CE5EC474060730E9E09614B4014B35E0CE5EC4740D93D7958A8634B40AF22A30392F24740D93D7958A8634B40AF22A30392F2474060730E9E09614B4014B35E0CE5EC474060730E9E09614B40
79090	3941	47.632773	47.653362000000001	54.859979000000003	54.851354999999998	Комсомольская	0103000020E610000001000000050000005A65A6B4FED047409E245D33F96C4B405A65A6B4FED04740971FB8CA136E4B407E39B35DA1D34740971FB8CA136E4B407E39B35DA1D347409E245D33F96C4B405A65A6B4FED047409E245D33F96C4B40
78462	2215	47.503971999999997	47.549408999999997	54.593510000000002	54.568547000000002	Клубная	0103000020E61000000100000005000000C30C8D2782C04740959EE925C6484B40C30C8D2782C04740ABECBB22F84B4B406490BB0853C64740ABECBB22F84B4B406490BB0853C64740959EE925C6484B40C30C8D2782C04740959EE925C6484B40
79097	61381	47.257779999999997	48.114691999999998	54.909753000000002	54.496384999999997	Вокзальная	0103000020E610000001000000050000000CC85EEFFEA04740CB9C2E8B893F4B400CC85EEFFEA047400D384BC972744B40718E3A3AAE0E48400D384BC972744B40718E3A3AAE0E4840CB9C2E8B893F4B400CC85EEFFEA04740CB9C2E8B893F4B40
78455	1932	47.836087999999997	47.871698000000002	54.699762999999997	54.679676000000001	Родина	0103000020E61000000100000005000000FD497CEE04EB474024F0879FFF564B40FD497CEE04EB4740B5F97FD591594B408BFED0CC93EF4740B5F97FD591594B408BFED0CC93EF474024F0879FFF564B40FD497CEE04EB474024F0879FFF564B40
78463	2329	47.481406999999997	47.523502000000001	54.636980999999999	54.616506999999999	Октябрьская	0103000020E6100000010000000500000061889CBE9EBD4740A6608DB3E94E4B4061889CBE9EBD47403196E99788514B40FFB1101D02C347403196E99788514B40FFB1101D02C34740A6608DB3E94E4B4061889CBE9EBD4740A6608DB3E94E4B40
78482	3657	47.632745999999997	47.659219	54.758989	54.745078999999997	Школьная	0103000020E61000000100000005000000605628D2FDD04740DBF7A8BF5E5F4B40605628D2FDD047400A83328D26614B406FF3C64961D447400A83328D26614B406FF3C64961D44740DBF7A8BF5E5F4B40605628D2FDD04740DBF7A8BF5E5F4B40
77516	61191	49.360304999999997	49.408723999999999	55.98359	55.970649999999999	Кольцевая	0103000020E61000000100000005000000EACA67791EAE484063EE5A423EFC4B40EACA67791EAE48401956F146E6FD4B408F8B6A1151B448401956F146E6FD4B408F8B6A1151B4484063EE5A423EFC4B40EACA67791EAE484063EE5A423EFC4B40
79046	31311	48.902163999999999	48.917247000000003	56.119925000000002	56.10913	Кирова	0103000020E6100000010000000500000074D0251C7A7348409981CAF8F70D4C4074D0251C7A734840857CD0B3590F4C4054AD855968754840857CD0B3590F4C4054AD8559687548409981CAF8F70D4C4074D0251C7A7348409981CAF8F70D4C40
78451	649	49.585872000000002	49.620457000000002	55.982833999999997	55.967908999999999	Нариманова	0103000020E6100000010000000500000031D28BDAFDCA484085402E71E4FB4B4031D28BDAFDCA4840CCB22781CDFD4B4082C98D226BCF4840CCB22781CDFD4B4082C98D226BCF484085402E71E4FB4B4031D28BDAFDCA484085402E71E4FB4B40
79055	31980	48.905020999999998	48.934935000000003	56.052833999999997	56.039942000000003	Кооперативная	0103000020E61000000100000005000000BB9866BAD773484051DEC7D11C054C40BB9866BAD7734840F50EB743C3064C40617138F3AB774840F50EB743C3064C40617138F3AB77484051DEC7D11C054C40BB9866BAD773484051DEC7D11C054C40
79124	61395	49.332906000000001	49.351222999999997	56.117460999999999	56.105499999999999	Северная	0103000020E610000001000000050000003352EFA99CAA48402FDD2406810D4C403352EFA99CAA484019C748F6080F4C402F4D11E0F4AC484019C748F6080F4C402F4D11E0F4AC48402FDD2406810D4C403352EFA99CAA48402FDD2406810D4C40
78443	577	49.485304999999997	49.508994000000001	55.959591000000003	55.946838999999997	Ленина	0103000020E61000000100000005000000EACA67791EBE4840E6C9350532F94B40EACA67791EBE48409A44BDE0D3FA4B401CEE23B726C148409A44BDE0D3FA4B401CEE23B726C14840E6C9350532F94B40EACA67791EBE4840E6C9350532F94B40
79341	31746	49.000134000000003	49.018118999999999	56.071342999999999	56.058684999999997	Клубная	0103000020E6100000010000000500000010CF12640480484004E275FD82074C4010CF12640480484036E675C421094C40D63730B95182484036E675C421094C40D63730B95182484004E275FD82074C4010CF12640480484004E275FD82074C40
79079	61376	49.205471000000003	49.239849999999997	56.091898999999998	56.084063999999998	Центральня	0103000020E6100000010000000500000062A3ACDF4C9A4840AE62F19BC20A4C4062A3ACDF4C9A48407EC4AF58C30B4C4009F9A067B39E48407EC4AF58C30B4C4009F9A067B39E4840AE62F19BC20A4C4062A3ACDF4C9A4840AE62F19BC20A4C40
78454	1591	49.282905999999997	49.298285	55.969642	55.963531000000003	Клубная	0103000020E61000000100000005000000CCEB884336A4484052D7DAFB54FB4B40CCEB884336A44840FD69A33A1DFC4B4095F1EF332EA64840FD69A33A1DFC4B4095F1EF332EA6484052D7DAFB54FB4B40CCEB884336A4484052D7DAFB54FB4B40
75305	1639	49.502903000000003	49.530500000000004	56.008017000000002	55.994616999999998	Школьная	0103000020E61000000100000005000000B80721205FC04840D7851F9C4FFF4B40B80721205FC04840F16778B306014C4096438B6CE7C34840F16778B306014C4096438B6CE7C34840D7851F9C4FFF4B40B80721205FC04840D7851F9C4FFF4B40
69273	1524	49.294269999999997	49.317383	55.999696999999998	55.988695999999997	Советская	0103000020E61000000100000005000000D218ADA3AAA54840CFD72C978DFE4B40D218ADA3AAA5484064744012F6FF4B4037A79201A0A8484064744012F6FF4B4037A79201A0A84840CFD72C978DFE4B40D218ADA3AAA54840CFD72C978DFE4B40
78975	1399	49.456702999999997	49.490408000000002	56.073213000000003	56.060997	Школьная	0103000020E61000000100000005000000177E703E75BA4840BA13ECBFCE074C40177E703E75BA48402F52280B5F094C4030D978B0C5BE48402F52280B5F094C4030D978B0C5BE4840BA13ECBFCE074C40177E703E75BA4840BA13ECBFCE074C40
79069	1752	49.668588999999997	49.689349	56.043984999999999	56.036256000000002	Школьная	0103000020E6100000010000000500000090BB085394D5484053245F09A4044C4090BB085394D54840DD41EC4CA1054C40E14389963CD84840DD41EC4CA1054C40E14389963CD8484053245F09A4044C4090BB085394D5484053245F09A4044C40
79323	1175	49.106566999999998	49.129249000000002	56.102820000000001	56.092028999999997	Комсомольская	0103000020E610000001000000050000009AEAC9FCA38D48404CA4349BC70B4C409AEAC9FCA38D4840F7AFAC34290D4C403605323B8B904840F7AFAC34290D4C403605323B8B9048404CA4349BC70B4C409AEAC9FCA38D48404CA4349BC70B4C40
79066	1136	49.197988000000002	49.217678999999997	56.178268000000003	56.168767000000003	Центральная	0103000020E610000001000000050000000F80B8AB5799484070D234289A154C400F80B8AB5799484030F65E7CD1164C405303CDE7DC9B484030F65E7CD1164C405303CDE7DC9B484070D234289A154C400F80B8AB5799484070D234289A154C40
79068	1362	49.441054000000001	49.459209000000001	56.023274000000001	56.009360999999998	Центральная	0103000020E610000001000000050000008FE21C7574B84840CE6DC2BD32014C408FE21C7574B848406E6C76A4FA024C40B2834A5CC7BA48406E6C76A4FA024C40B2834A5CC7BA4840CE6DC2BD32014C408FE21C7574B84840CE6DC2BD32014C40
79071	999	49.093496000000002	49.106045999999999	55.954763	55.944550999999997	Верхняя	0103000020E6100000010000000500000046274BADF78B4840B933130CE7F84B4046274BADF78B484026378AAC35FA4B4091EF52EA928D484026378AAC35FA4B4091EF52EA928D4840B933130CE7F84B4046274BADF78B4840B933130CE7F84B40
79048	31368	49.168604000000002	49.192419000000001	56.060765000000004	56.044915000000003	Светлая	0103000020E61000000100000005000000C6FCDCD094954840C80C54C6BF054C40C6FCDCD094954840E8DEC325C7074C408410902FA1984840E8DEC325C7074C408410902FA1984840C80C54C6BF054C40C6FCDCD094954840C80C54C6BF054C40
78448	935	49.385016999999998	49.406748	55.886372000000001	55.876565999999997	Крупской	0103000020E61000000100000005000000B7B3AF3C48B148408C648F5033F04B40B7B3AF3C48B14840890B40A374F14B4051DB865110B44840890B40A374F14B4051DB865110B448408C648F5033F04B40B7B3AF3C48B148408C648F5033F04B40
79351	61534	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	Аринская 	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
79320	822	49.575783999999999	49.596651999999999	56.057664000000003	56.045886000000003	Центральная	0103000020E61000000100000005000000B0C7444AB3C9484011ACAA97DF054C40B0C7444AB3C948400A14B18861074C40E78BBD175FCC48400A14B18861074C40E78BBD175FCC484011ACAA97DF054C40B0C7444AB3C9484011ACAA97DF054C40
79060	697	48.924118999999997	48.949451000000003	56.065604999999998	56.050576	Кооперативная	0103000020E610000001000000050000005D4E09884976484033FB3C4679064C405D4E0988497648401FBAA0BE65084C40C713419C877948401FBAA0BE65084C40C713419C8779484033FB3C4679064C405D4E09884976484033FB3C4679064C40
79422	32362	49.243093000000002	49.260789000000003	56.131098999999999	56.123052000000001	Школьная	0103000020E610000001000000050000007A71E2AB1D9F48408CDAFD2AC00F4C407A71E2AB1D9F4840E7C41EDAC7104C400A14B18861A14840E7C41EDAC7104C400A14B18861A148408CDAFD2AC00F4C407A71E2AB1D9F48408CDAFD2AC00F4C40
79061	1302	49.043585999999998	49.059925999999997	56.118816000000002	56.106735	Г.Камала	0103000020E610000001000000050000001F48DE3994854840562B137EA90D4C401F48DE3994854840EB1ED95C350F4C400D17B9A7AB874840EB1ED95C350F4C400D17B9A7AB874840562B137EA90D4C401F48DE3994854840562B137EA90D4C40
78453	1702	49.591710999999997	49.614123999999997	56.005284000000003	55.995840999999999	Клубная	0103000020E610000001000000050000007BD7A02FBDCB48400A82C7B777FF4B407BD7A02FBDCB484096986725AD004C4027D87F9D9BCE484096986725AD004C4027D87F9D9BCE48400A82C7B777FF4B407BD7A02FBDCB48400A82C7B777FF4B40
75454	60614	49.548133999999997	49.575505	56.018383	56.002616000000003	Гагарина	0103000020E61000000100000005000000AFE9414129C64840223999B855004C40AFE9414129C64840B4E6C75F5A024C409DD7D825AAC94840B4E6C75F5A024C409DD7D825AAC94840223999B855004C40AFE9414129C64840223999B855004C40
78445	32240	49.355077000000001	49.373590999999998	55.950786000000001	55.943632999999998	Центральная	0103000020E61000000100000005000000E947C32973AD4840933655F7C8F84B40E947C32973AD484051BF0B5BB3F94B403B8A73D4D1AF484051BF0B5BB3F94B403B8A73D4D1AF4840933655F7C8F84B40E947C32973AD4840933655F7C8F84B40
79056	32452	49.193631000000003	49.221623000000001	56.251547000000002	56.240597999999999	Советская	0103000020E61000000100000005000000F33E8EE6C8984840D3BD4EEACB1E4C40F33E8EE6C898484016342DB132204C404D8578245E9C484016342DB132204C404D8578245E9C4840D3BD4EEACB1E4C40F33E8EE6C8984840D3BD4EEACB1E4C40
79053	31662	49.319341999999999	49.334423999999999	56.060161999999998	56.051537000000003	Колхозная	0103000020E610000001000000050000009F1EDB32E0A8484059C4B0C398064C409F1EDB32E0A84840213B6F63B3074C40AE7FD767CEAA4840213B6F63B3074C40AE7FD767CEAA484059C4B0C398064C409F1EDB32E0A8484059C4B0C398064C40
75343	32288	49.183686999999999	49.211005	56.128841999999999	56.112186999999999	Ленина	0103000020E61000000100000005000000A5D93C0E83974840A704C4245C0E4C40A5D93C0E83974840F52C08E57D104C4070253B36029B4840F52C08E57D104C4070253B36029B4840A704C4245C0E4C40A5D93C0E83974840A704C4245C0E4C40
79051	31522	49.044808000000003	49.063367	56.250906999999998	56.238531999999999	Школьная	0103000020E61000000100000005000000B24CBF44BC85484055867137881E4C40B24CBF44BC85484032AB77B81D204C40A452EC681C88484032AB77B81D204C40A452EC681C88484055867137881E4C40B24CBF44BC85484055867137881E4C40
79353	61535	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	Центральная	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
79360	61535	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	Татарстан	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
79063	524	48.970184000000003	48.990440999999997	56.155949	56.142651000000001	Школьная	0103000020E610000001000000050000001E8D43FD2E7C4840F0DE516342124C401E8D43FD2E7C4840056C0723F6134C400BCF4BC5C67E4840056C0723F6134C400BCF4BC5C67E4840F0DE516342124C401E8D43FD2E7C4840F0DE516342124C40
78437	31798	49.046684999999997	49.069017000000002	56.181579999999997	56.169041999999997	Московская	0103000020E610000001000000050000005C1B2AC6F985484041D3122BA3154C405C1B2AC6F9854840C8CD70033E174C401CEF8E8CD5884840C8CD70033E174C401CEF8E8CD588484041D3122BA3154C405C1B2AC6F985484041D3122BA3154C40
79064	31669	49.049621999999999	49.082419999999999	56.037061000000001	56.024099	Клубная	0103000020E61000000100000005000000C09481035A864840E36E10AD15034C40C09481035A864840817A336ABE044C40A64412BD8C8A4840817A336ABE044C40A64412BD8C8A4840E36E10AD15034C40C09481035A864840E36E10AD15034C40
78976	31879	49.001607999999997	49.026904000000002	56.187907000000003	56.179003999999999	Центральная	0103000020E61000000100000005000000BBB4E1B03480484035ED629AE9164C40BBB4E1B03480484041D829560D184C40D8101C977183484041D829560D184C40D8101C977183484035ED629AE9164C40BBB4E1B03480484035ED629AE9164C40
79356	61537	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	Центральная	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
78496	31611	49.261490000000002	49.273688999999997	56.071193000000001	56.060352999999999	Центральная	0103000020E61000000100000005000000931D1B8178A14840959BA8A5B9074C40931D1B8178A14840215A2BDA1C094C403123BC3D08A34840215A2BDA1C094C403123BC3D08A34840959BA8A5B9074C40931D1B8178A14840959BA8A5B9074C40
79050	31323	49.213690999999997	49.244143999999999	56.027659999999997	56.013824	Ленина	0103000020E610000001000000050000008A39083A5A9B484030F31DFCC4014C408A39083A5A9B484024B4E55C8A034C40DFC14F1C409F484024B4E55C8A034C40DFC14F1C409F484030F31DFCC4014C408A39083A5A9B484030F31DFCC4014C40
79052	31430	49.096245000000003	49.114975000000001	56.183188000000001	56.175732000000004	Центральная	0103000020E61000000100000005000000A7B393C1518C48402B6EDC627E164C40A7B393C1518C4840848252B472174C40C66D3480B78E4840848252B472174C40C66D3480B78E48402B6EDC627E164C40A7B393C1518C48402B6EDC627E164C40
79059	444	48.975600999999997	49.009028000000001	56.107759000000001	56.092717	Центральная	0103000020E61000000100000005000000F2785A7EE07C484041649126DE0B4C40F2785A7EE07C4840C26C020CCB0D4C40C85F5AD427814840C26C020CCB0D4C40C85F5AD42781484041649126DE0B4C40F2785A7EE07C484041649126DE0B4C40
79047	30931	48.902783999999997	48.912925999999999	55.564816	55.557623	Центральная	0103000020E6100000010000000500000010AD156D8E734840AB3FC23060C74B4010AD156D8E734840F72004E44BC84B4084D558C2DA744840F72004E44BC84B4084D558C2DA744840AB3FC23060C74B4010AD156D8E734840AB3FC23060C74B40
10120	30610	48.765386999999997	48.782454999999999	55.498525000000001	55.488289999999999	Школьная	0103000020E610000001000000050000004BE48233F86148405F7B664980BE4B404BE48233F8614840849ECDAACFBF4B40BCCB457C27644840849ECDAACFBF4B40BCCB457C276448405F7B664980BE4B404BE48233F86148405F7B664980BE4B40
79054	30728	48.981673999999998	49.028098999999997	55.537745000000001	55.518076000000001	Строителей	0103000020E61000000100000005000000B0AA5E7EA77D4840D76B7A5050C24B40B0AA5E7EA77D4840344B02D4D4C44B4070067FBF98834840344B02D4D4C44B4070067FBF98834840D76B7A5050C24B40B0AA5E7EA77D4840D76B7A5050C24B40
78433	30728	48.981673999999998	49.028098999999997	55.537745000000001	55.518076000000001	Советская	0103000020E61000000100000005000000B0AA5E7EA77D4840D76B7A5050C24B40B0AA5E7EA77D4840344B02D4D4C44B4070067FBF98834840344B02D4D4C44B4070067FBF98834840D76B7A5050C24B40B0AA5E7EA77D4840D76B7A5050C24B40
79345	30167	48.459105999999998	48.479695	55.553131	55.539771999999999	Центральная 	0103000020E61000000100000005000000DDB243FCC33A4840F4A5B73F17C54B40DDB243FCC33A4840AFB321FFCCC64B40018750A5663D4840AFB321FFCCC64B40018750A5663D4840F4A5B73F17C54B40DDB243FCC33A4840F4A5B73F17C54B40
79029	30028	48.689093	48.710059000000001	55.562621999999998	55.547173000000001	Заозерная	0103000020E6100000010000000500000086730D33345848408A20CEC309C64B4086730D33345848404B0169FF03C84B40809D9B36E35A48404B0169FF03C84B40809D9B36E35A48408A20CEC309C64B4086730D33345848408A20CEC309C64B40
79030	29565	48.641446000000002	48.663274999999999	55.707973000000003	55.696762999999997	Советская	0103000020E6100000010000000500000034130CE71A5248400B08AD872FD94B4034130CE71A524840BBB9F8DB9EDA4B4090A0F831E6544840BBB9F8DB9EDA4B4090A0F831E65448400B08AD872FD94B4034130CE71A5248400B08AD872FD94B40
79042	30717	48.782949000000002	48.801355000000001	55.569443	55.556700999999997	Дорожная	0103000020E61000000100000005000000CCB73EAC37644840435376FA41C74B40CCB73EAC37644840D3F71A82E3C84B4038BEF6CC92664840D3F71A82E3C84B4038BEF6CC92664840435376FA41C74B40CCB73EAC37644840435376FA41C74B40
79038	30129	48.445362000000003	48.475222000000002	55.629708999999998	55.594163000000002	Береговая	0103000020E61000000100000005000000CA703C9F0139484023BF7E880DCC4B40CA703C9F01394840997FF44D9AD04B407C2B1213D43C4840997FF44D9AD04B407C2B1213D43C484023BF7E880DCC4B40CA703C9F0139484023BF7E880DCC4B40
79027	29834	48.771262	48.804571000000003	55.619030000000002	55.609121000000002	Центральная	0103000020E61000000100000005000000E35295B6B862484046274BADF7CD4B40E35295B6B8624840179F02603CCF4B40AF27BA2EFC664840179F02603CCF4B40AF27BA2EFC66484046274BADF7CD4B40E35295B6B862484046274BADF7CD4B40
78762	29844	48.694051000000002	48.734394999999999	55.610686999999999	55.574247999999997	Центральная	0103000020E61000000100000005000000C860C5A9D65848408EE55DF580C94B40C860C5A9D6584840D28BDAFD2ACE4B4047ACC5A7005E4840D28BDAFD2ACE4B4047ACC5A7005E48408EE55DF580C94B40C860C5A9D65848408EE55DF580C94B40
78439	29844	48.694051000000002	48.734394999999999	55.610686999999999	55.574247999999997	Садовая	0103000020E61000000100000005000000C860C5A9D65848408EE55DF580C94B40C860C5A9D6584840D28BDAFD2ACE4B4047ACC5A7005E4840D28BDAFD2ACE4B4047ACC5A7005E48408EE55DF580C94B40C860C5A9D65848408EE55DF580C94B40
79026	29604	48.716788000000001	48.746566999999999	55.676966	55.662602999999997	Большая	0103000020E6100000010000000500000027158DB5BF5B4840A19DD32CD0D44B4027158DB5BF5B4840814067D2A6D64B40ECA2E8818F5F4840814067D2A6D64B40ECA2E8818F5F4840A19DD32CD0D44B4027158DB5BF5B4840A19DD32CD0D44B40
79037	30408	48.566985000000003	48.587232999999998	55.470973999999998	55.456606999999998	Береговая	0103000020E610000001000000050000004A29E8F692484840F50F221972BA4B404A29E8F69248484016A243E048BC4B40E41071732A4B484016A243E048BC4B40E41071732A4B4840F50F221972BA4B404A29E8F692484840F50F221972BA4B40
79354	61536	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	Центральная	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
79185	61440	48.706322	48.721665999999999	55.376359999999998	55.368082999999999	Центральная	0103000020E61000000100000005000000003961C2685A4840569BFF571DAF4B40003961C2685A4840E3C281902CB04B404C512E8D5F5C4840E3C281902CB04B404C512E8D5F5C4840569BFF571DAF4B40003961C2685A4840569BFF571DAF4B40
79301	30927	48.976202999999998	48.996136999999997	55.559873000000003	55.550707000000003	Центральная	0103000020E61000000100000005000000E8A04B38F47C4840D25625917DC64B40E8A04B38F47C4840EB7420EBA9C74B40F3AACE6A817F4840EB7420EBA9C74B40F3AACE6A817F4840D25625917DC64B40E8A04B38F47C4840D25625917DC64B40
78461	61301	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	Красавина	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
79045	31081	48.946451000000003	48.958893000000003	55.655183000000001	55.644027999999999	Волжская	0103000020E610000001000000050000001D226E4E25794840A9DA6E826FD24B401D226E4E2579484095F25A09DDD34B4082AE7D01BD7A484095F25A09DDD34B4082AE7D01BD7A4840A9DA6E826FD24B401D226E4E25794840A9DA6E826FD24B40
79049	30527	48.781196999999999	48.810805000000002	55.463104999999999	55.441009000000001	Советская	0103000020E61000000100000005000000DD5D6743FE634840EF1EA0FB72B84B40DD5D6743FE6348409ACE4E0647BB4B4076374F75C86748409ACE4E0647BB4B4076374F75C8674840EF1EA0FB72B84B40DD5D6743FE634840EF1EA0FB72B84B40
78432	29656	48.714613999999997	48.752414999999999	55.654888999999997	55.635838	Центральная	0103000020E61000000100000005000000C2A1B778785B4840EBC6BB2363D14B40C2A1B778785B48404CC11A67D3D34B408A027D224F6048404CC11A67D3D34B408A027D224F604840EBC6BB2363D14B40C2A1B778785B4840EBC6BB2363D14B40
79034	29656	48.714613999999997	48.752414999999999	55.654888999999997	55.635838	Пионерская	0103000020E61000000100000005000000C2A1B778785B4840EBC6BB2363D14B40C2A1B778785B48404CC11A67D3D34B408A027D224F6048404CC11A67D3D34B408A027D224F604840EBC6BB2363D14B40C2A1B778785B4840EBC6BB2363D14B40
79032	30310	48.641069000000002	48.669905	55.509141	55.488677000000003	Центральная Площадь	0103000020E610000001000000050000005EBD8A8C0E52484059A7CAF78CBE4B405EBD8A8C0E524840C00644882BC14B40A4367172BF554840C00644882BC14B40A4367172BF55484059A7CAF78CBE4B405EBD8A8C0E52484059A7CAF78CBE4B40
79337	30024	48.593215000000001	48.615735999999998	55.604748000000001	55.597805000000001	Центральная	0103000020E61000000100000005000000923F1878EE4B48405131CEDF84CC4B40923F1878EE4B48402429E96168CD4B40247CEF6FD04E48402429E96168CD4B40247CEF6FD04E48405131CEDF84CC4B40923F1878EE4B48405131CEDF84CC4B40
79043	30120	48.637403999999997	48.668799999999997	55.546138999999997	55.531982999999997	Центральная	0103000020E61000000100000005000000772B4B74965148409483D90418C44B40772B4B7496514840FA08FCE1E7C54B404BC8073D9B554840FA08FCE1E7C54B404BC8073D9B5548409483D90418C44B40772B4B74965148409483D90418C44B40
78879	30314	48.705613	48.733846999999997	55.513554999999997	55.496327000000001	Центральная	0103000020E61000000100000005000000F450DB86515A4840978FA4A487BF4B40F450DB86515A484040D9942BBCC14B4044A2D0B2EE5D484040D9942BBCC14B4044A2D0B2EE5D4840978FA4A487BF4B40F450DB86515A4840978FA4A487BF4B40
79062	61372	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	Чехова	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
79036	61372	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	Советская	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
79044	61372	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	Печищинский тракт	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
79091	61372	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	Колхозная	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
79343	61533	48.684950999999998	48.705351999999998	55.762135000000001	55.752637	Центральная	0103000020E61000000100000005000000662E7079AC5748403961C26856E04B40662E7079AC5748408811C2A38DE14B4087156EF9485A48408811C2A38DE14B4087156EF9485A48403961C26856E04B40662E7079AC5748403961C26856E04B40
79039	30418	48.657463	48.689129000000001	55.408040999999997	55.394499000000003	Молодежная	0103000020E610000001000000050000003FAA61BF2754484001A777F17EB24B403FAA61BF27544840AC36FFAF3AB44B40D3DC0A6135584840AC36FFAF3AB44B40D3DC0A613558484001A777F17EB24B403FAA61BF2754484001A777F17EB24B40
79184	61444	48.942013000000003	48.955668000000003	55.645974000000002	55.637627000000002	Центральная	0103000020E6100000010000000500000014B4C9E193784840F705F4C29DD14B4014B4C9E1937848407D08AA46AFD24B40B8EA3A54537A48407D08AA46AFD24B40B8EA3A54537A4840F705F4C29DD14B4014B4C9E193784840F705F4C29DD14B40
79096	61380	48.483342999999998	48.509762000000002	54.895941999999998	54.879598999999999	Нагорная	0103000020E6100000010000000500000011E0F42EDE3D4840124C35B396704B4011E0F42EDE3D4840718E3A3AAE724B402D5F97E13F414840718E3A3AAE724B402D5F97E13F414840124C35B396704B4011E0F42EDE3D4840124C35B396704B40
78970	25943	48.301658000000003	48.314863000000003	54.770468999999999	54.759098000000002	Ленина	0103000020E61000000100000005000000D449B6BA9C264840C13A8E1F2A614B40D449B6BA9C26484079CA6ABA9E624B4038DC476E4D28484079CA6ABA9E624B4038DC476E4D284840C13A8E1F2A614B40D449B6BA9C264840C13A8E1F2A614B40
78987	28798	47.844973000000003	47.870494000000001	54.914369000000001	54.902175	Центральная	0103000020E610000001000000050000006380441328EC474068226C787A734B406380441328EC4740F5BC1B0B0A754B409FAEEE586CEF4740F5BC1B0B0A754B409FAEEE586CEF474068226C787A734B406380441328EC474068226C787A734B40
79011	28198	48.083772000000003	48.106130999999998	54.810324999999999	54.795203000000001	Кооперативная	0103000020E610000001000000050000000729780AB90A48402E573F36C9654B400729780AB90A4840CB10C7BAB8674B40BF0B5BB3950D4840CB10C7BAB8674B40BF0B5BB3950D48402E573F36C9654B400729780AB90A48402E573F36C9654B40
79330	27950	48.209940000000003	48.238075000000002	54.990611999999999	54.978952999999997	Центральная	0103000020E61000000100000005000000A60F5D50DF1A484019A9F7544E7D4B40A60F5D50DF1A48403883BF5FCC7E4B40637FD93D791E48403883BF5FCC7E4B40637FD93D791E484019A9F7544E7D4B40A60F5D50DF1A484019A9F7544E7D4B40
79041	28653	48.154020000000003	48.183548000000002	54.785761000000001	54.769606000000003	Ленина	0103000020E61000000100000005000000087767EDB613484017670C7382624B40087767EDB613484073BC02D193644B40849F38807E17484073BC02D193644B40849F38807E17484017670C7382624B40087767EDB613484017670C7382624B40
78998	26567	48.074922999999998	48.092737	55.059704000000004	55.048735000000001	Школьная	0103000020E61000000100000005000000EE5BAD1397094840D595CFF23C864B40EE5BAD13970948405FB87361A4874B40881057CEDE0B48405FB87361A4874B40881057CEDE0B4840D595CFF23C864B40EE5BAD1397094840D595CFF23C864B40
78421	28511	48.261045000000003	48.280825999999998	55.113281999999998	55.095049000000003	пр-т.Иванова	0103000020E6100000010000000500000065E42CEC692148403E42CD902A8C4B4065E42CEC69214840DC9C4A06808E4B40E9EE3A1BF2234840DC9C4A06808E4B40E9EE3A1BF22348403E42CD902A8C4B4065E42CEC692148403E42CD902A8C4B40
78992	26366	48.345424000000001	48.367683999999997	55.085718999999997	55.074731	Советская	0103000020E6100000010000000500000073A087DA362C4840AA7F10C990894B4073A087DA362C4840AAD216D7F88A4B4098A1F144102F4840AAD216D7F88A4B4098A1F144102F4840AA7F10C990894B4073A087DA362C4840AA7F10C990894B40
78427	28469	48.273927	48.315348999999998	55.058579999999999	55.040322000000003	Озерная	0103000020E61000000100000005000000E63E390A1023484098A7734529854B40E63E390A102348408F19A88C7F874B40C4E9245B5D2848408F19A88C7F874B40C4E9245B5D28484098A7734529854B40E63E390A1023484098A7734529854B40
78990	26653	48.042458000000003	48.064943	55.055289999999999	55.045202000000003	Октябрьская	0103000020E610000001000000050000000FBA84436F0548405EDBDB2DC9854B400FBA84436F054840DEE522BE13874B40548D5E0D50084840DEE522BE13874B40548D5E0D500848405EDBDB2DC9854B400FBA84436F0548405EDBDB2DC9854B40
78978	26075	48.188488	48.219031000000001	54.943525000000001	54.932927999999997	Комсомольская	0103000020E610000001000000050000001FD8F15F20184840E7C2482F6A774B401FD8F15F20184840ADFA5C6DC5784B40B4E73235091C4840ADFA5C6DC5784B40B4E73235091C4840E7C2482F6A774B401FD8F15F20184840E7C2482F6A774B40
79013	28378	47.895457999999998	47.923862999999997	54.941859999999998	54.933993000000001	Мира	0103000020E610000001000000050000008578245E9EF24740B2D826158D774B408578245E9EF247408DB454DE8E784B40027E8D2441F647408DB454DE8E784B40027E8D2441F64740B2D826158D774B408578245E9EF24740B2D826158D774B40
79031	27151	48.231482	48.241705000000003	54.812036999999997	54.804341999999998	Вахитова	0103000020E610000001000000050000006CCEC133A11D48404D66BCADF4664B406CCEC133A11D48402B1213D4F0674B40CD237F30F01E48402B1213D4F0674B40CD237F30F01E48404D66BCADF4664B406CCEC133A11D48404D66BCADF4664B40
78986	26564	48.100462999999998	48.114835999999997	55.035384999999998	55.028187000000003	Мира	0103000020E61000000100000005000000A1BAB9F8DB0C48401096B1A19B834B40A1BAB9F8DB0C48406DE2E47E87844B40A43330F2B20E48406DE2E47E87844B40A43330F2B20E48401096B1A19B834B40A1BAB9F8DB0C48401096B1A19B834B40
79022	28745	48.10163	48.138497000000001	54.747667	54.736623000000002	Школьная	0103000020E6100000010000000500000070253B36020D48409F3D97A9495E4B4070253B36020D484033A6608DB35F4B400CCC0A45BA11484033A6608DB35F4B400CCC0A45BA1148409F3D97A9495E4B4070253B36020D48409F3D97A9495E4B40
78999	26840	48.209231000000003	48.222076000000001	55.040878999999997	55.032783999999999	Школьная	0103000020E610000001000000050000009A27D714C81A484081EA1F4432844B409A27D714C81A4840ED0BE8853B854B40FE9C82FC6C1C4840ED0BE8853B854B40FE9C82FC6C1C484081EA1F4432844B409A27D714C81A484081EA1F4432844B40
78981	26279	48.368538000000001	48.384160000000001	55.009377999999998	55.000754999999998	Колхозная	0103000020E61000000100000005000000A8AAD0402C2F48407C2766BD18804B40A8AAD0402C2F4840A4A65D4C33814B403737A6272C314840A4A65D4C33814B403737A6272C3148407C2766BD18804B40A8AAD0402C2F48407C2766BD18804B40
69263	28104	48.218232	48.279541999999999	54.892597000000002	54.872537999999999	Школьная	0103000020E610000001000000050000006878B306EF1B484035423F53AF6F4B406878B306EF1B4840FDC0559E40724B40E1ED4108C8234840FDC0559E40724B40E1ED4108C823484035423F53AF6F4B406878B306EF1B484035423F53AF6F4B40
79010	28191	48.140096	48.175589000000002	54.846913000000001	54.832245999999998	Советская	0103000020E6100000010000000500000074266DAAEE114840081D7409876A4B4074266DAAEE11484054C72AA5676C4B40C8444AB37916484054C72AA5676C4B40C8444AB379164840081D7409876A4B4074266DAAEE114840081D7409876A4B40
79006	27278	48.312483	48.33663	54.777603999999997	54.768656	Школьная	0103000020E610000001000000050000002AC76471FF274840E5EFDE5163624B402AC76471FF274840909E228788634B401E6D1CB1162B4840909E228788634B401E6D1CB1162B4840E5EFDE5163624B402AC76471FF274840E5EFDE5163624B40
78985	26413	48.383530999999998	48.408377999999999	54.812202999999997	54.797823999999999	Колхозная	0103000020E610000001000000050000004700378B1731484061FBC9181F664B404700378B17314840465B9544F6674B40F433F5BA45344840465B9544F6674B40F433F5BA4534484061FBC9181F664B404700378B1731484061FBC9181F664B40
79019	28245	48.095432000000002	48.114134999999997	54.854843000000002	54.844538999999997	Школьная	0103000020E61000000100000005000000F67EA31D370C484028999CDA196C4B40F67EA31D370C4840761BD47E6B6D4B401B2AC6F99B0E4840761BD47E6B6D4B401B2AC6F99B0E484028999CDA196C4B40F67EA31D370C484028999CDA196C4B40
78969	28031	47.806956	47.837211000000003	54.953668999999998	54.941766999999999	Центральная	0103000020E61000000100000005000000CEA78E554AE74740DCB930D28B784B40CEA78E554AE74740C11A67D3117A4B40FD6CE4BA29EB4740C11A67D3117A4B40FD6CE4BA29EB4740DCB930D28B784B40CEA78E554AE74740DCB930D28B784B40
79015	28289	48.032010999999997	48.056013999999998	54.849758999999999	54.836176000000002	Клубная	0103000020E610000001000000050000005E0EBBEF180448409DD9AED0076B4B405E0EBBEF18044840A73D25E7C46C4B401F0F7D772B074840A73D25E7C46C4B401F0F7D772B0748409DD9AED0076B4B405E0EBBEF180448409DD9AED0076B4B40
79001	27026	48.439109000000002	48.464315999999997	54.847290999999998	54.837378999999999	Садовая	0103000020E610000001000000050000008C3045B934384840B8AD2D3C2F6B4B408C3045B934384840FA980F08746C4B403881E9B46E3B4840FA980F08746C4B403881E9B46E3B4840B8AD2D3C2F6B4B408C3045B934384840B8AD2D3C2F6B4B40
78426	27936	48.138128999999999	48.16957	54.961522000000002	54.947346000000003	Советская	0103000020E6100000010000000500000089D00836AE1148408BFF3BA242794B4089D00836AE11484038312427137B4B40FD304278B415484038312427137B4B40FD304278B41548408BFF3BA242794B4089D00836AE1148408BFF3BA242794B40
78982	26027	48.214207000000002	48.246834	54.750900000000001	54.737600999999998	Клубная	0103000020E6100000010000000500000082C98D226B1B48409A3FA6B5695E4B4082C98D226B1B48408048BF7D1D604B403BC5AA41981F48408048BF7D1D604B403BC5AA41981F48409A3FA6B5695E4B4082C98D226B1B48409A3FA6B5695E4B40
78917	24120	48.360201000000004	48.365186999999999	54.979010000000002	54.976137000000001	Верхняя	0103000020E61000000100000005000000467EFD101B2E484031B5A50EF27C4B40467EFD101B2E48407E3A1E33507D4B4051F69672BE2E48407E3A1E33507D4B4051F69672BE2E484031B5A50EF27C4B40467EFD101B2E484031B5A50EF27C4B40
79008	27852	48.157666999999996	48.178984	55.039507	55.028703	Центральная	0103000020E610000001000000050000004754A86E2E1448400726378AAC834B404754A86E2E144840467BBC900E854B40EE409DF2E8164840467BBC900E854B40EE409DF2E81648400726378AAC834B404754A86E2E1448400726378AAC834B40
79014	27714	48.118231000000002	48.148487000000003	55.082358999999997	55.059142000000001	Свободы	0103000020E61000000100000005000000CB2F8331220F4840F7E80DF791874B40CB2F8331220F484000C45DBD8A8A4B40CA703C9F0113484000C45DBD8A8A4B40CA703C9F01134840F7E80DF791874B40CB2F8331220F4840F7E80DF791874B40
78416	27581	47.967368	48.009993000000001	54.830280000000002	54.804212999999997	Ленина	0103000020E610000001000000050000003599F1B6D2FB47404F029B73F0664B403599F1B6D2FB4740EE42739D466A4B402F185C7347014840EE42739D466A4B402F185C73470148404F029B73F0664B403599F1B6D2FB47404F029B73F0664B40
79003	27116	48.184742999999997	48.209041999999997	54.821883	54.812032000000002	Победы	0103000020E610000001000000050000001C959BA8A51748401AA721AAF0674B401C959BA8A5174840B6114F7633694B40C6BE64E3C11A4840B6114F7633694B40C6BE64E3C11A48401AA721AAF0674B401C959BA8A51748401AA721AAF0674B40
79020	28755	48.164907999999997	48.181337999999997	54.742471000000002	54.734378	Шоссейная	0103000020E61000000100000005000000A46C91B41B15484071732A19005E4B40A46C91B41B1548403D9D2B4A095F4B40D2C26515361748403D9D2B4A095F4B40D2C265153617484071732A19005E4B40A46C91B41B15484071732A19005E4B40
79007	27677	47.900812000000002	47.921931000000001	54.823366999999998	54.814366999999997	О.Кошевого	0103000020E6100000010000000500000014ECBFCE4DF3474087F8872D3D684B4014ECBFCE4DF3474085CD001764694B409415C3D501F6474085CD001764694B409415C3D501F6474087F8872D3D684B4014ECBFCE4DF3474087F8872D3D684B40
78410	27482	48.311639	48.333171	55.022576999999998	55.004029000000003	Советская	0103000020E610000001000000050000003E9468C9E3274840289EB30584804B403E9468C9E327484026529ACDE3824B40E17CEA58A52A484026529ACDE3824B40E17CEA58A52A4840289EB30584804B403E9468C9E3274840289EB30584804B40
78753	26142	48.115248999999999	48.135012000000003	54.939155	54.928024000000001	М.Вахитова	0103000020E61000000100000005000000C7F2AE7AC00E484099F38C7DC9764B40C7F2AE7AC00E4840FC6F253B36784B40A648BE1248114840FC6F253B36784B40A648BE124811484099F38C7DC9764B40C7F2AE7AC00E484099F38C7DC9764B40
78968	26142	48.115248999999999	48.135012000000003	54.939155	54.928024000000001	Колхозная	0103000020E61000000100000005000000C7F2AE7AC00E484099F38C7DC9764B40C7F2AE7AC00E4840FC6F253B36784B40A648BE1248114840FC6F253B36784B40A648BE124811484099F38C7DC9764B40C7F2AE7AC00E484099F38C7DC9764B40
78406	27389	47.99156	48.027214000000001	54.943944000000002	54.929219000000003	Молодежная	0103000020E61000000100000005000000C9022670EBFE474032E9EFA5F0764B40C9022670EBFE4740B2A03028D3784B4026FF93BF7B034840B2A03028D3784B4026FF93BF7B03484032E9EFA5F0764B40C9022670EBFE474032E9EFA5F0764B40
78230	27374	48.269795000000002	48.287033999999998	54.947274	54.930568999999998	М.Джалиля	0103000020E61000000100000005000000EACF7EA488224840F1D58EE21C774B40EACF7EA488224840F12C414640794B40876BB587BD244840F12C414640794B40876BB587BD244840F1D58EE21C774B40EACF7EA488224840F1D58EE21C774B40
78404	27284	48.229227000000002	48.248837000000002	54.962823999999998	54.947899	Молодежная	0103000020E610000001000000050000001B2E724F571D48409F7422C154794B401B2E724F571D4840E6E61BD13D7B4B4073840CE4D91F4840E6E61BD13D7B4B4073840CE4D91F48409F7422C154794B401B2E724F571D48409F7422C154794B40
79198	61453	48.232883000000001	48.243358000000001	55.057279999999999	55.049456999999997	Центральная	0103000020E61000000100000005000000AE65321CCF1D484075C7629B54864B40AE65321CCF1D4840815B77F354874B40289CDD5A261F4840815B77F354874B40289CDD5A261F484075C7629B54864B40AE65321CCF1D484075C7629B54864B40
79361	61454	48.139161999999999	48.150489999999998	55.110239	55.100653999999999	Школьная	0103000020E61000000100000005000000486C770FD0114840151BF33AE28C4B40486C770FD011484033DFC14F1C8E4B4001309E414313484033DFC14F1C8E4B4001309E4143134840151BF33AE28C4B40486C770FD0114840151BF33AE28C4B40
79199	61454	48.139161999999999	48.150489999999998	55.110239	55.100653999999999	Клубная	0103000020E61000000100000005000000486C770FD0114840151BF33AE28C4B40486C770FD011484033DFC14F1C8E4B4001309E414313484033DFC14F1C8E4B4001309E4143134840151BF33AE28C4B40486C770FD0114840151BF33AE28C4B40
79139	61407	48.278841	48.296025999999998	55.069412	55.061492999999999	Мирная	0103000020E6100000010000000500000058E4D70FB12348406AF7AB00DF874B4058E4D70FB123484098F90E7EE2884B400262122EE425484098F90E7EE2884B400262122EE42548406AF7AB00DF874B4058E4D70FB12348406AF7AB00DF874B40
79004	27208	48.260767000000001	48.279111	54.800356999999998	54.791367000000001	Революционная	0103000020E61000000100000005000000227024D0602148401B118C834B654B40227024D060214840F50F221972664B40187AC4E8B9234840F50F221972664B40187AC4E8B92348401B118C834B654B40227024D0602148401B118C834B654B40
79002	27106	48.212923000000004	48.239369000000003	54.841189999999997	54.827210000000001	Школьная	0103000020E610000001000000050000007AC8940F411B48404B766C04E2694B407AC8940F411B484072DC291DAC6B4B408F56B5A4A31E484072DC291DAC6B4B408F56B5A4A31E48404B766C04E2694B407AC8940F411B48404B766C04E2694B40
79000	27021	48.363121	48.578986	54.922865000000002	54.856169999999999	Широкая	0103000020E61000000100000005000000D3BEB9BF7A2E48407DE882FA966D4B40D3BEB9BF7A2E4840C0CFB87020764B40C26B97361C4A4840C0CFB87020764B40C26B97361C4A48407DE882FA966D4B40D3BEB9BF7A2E48407DE882FA966D4B40
78394	26946	48.392612999999997	48.419248000000003	54.892664000000003	54.872548999999999	Молодежная	0103000020E61000000100000005000000027E8D2441324840299485AFAF6F4B40027E8D244132484085285FD042724B40EB7420EBA935484085285FD042724B40EB7420EBA9354840299485AFAF6F4B40027E8D2441324840299485AFAF6F4B40
79018	26192	47.865661000000003	47.890050000000002	54.931541000000003	54.917918999999998	Центральная	0103000020E610000001000000050000001A36CAFACDEE474042B0AA5E7E754B401A36CAFACDEE47400BF148BC3C774B4004E78C28EDF147400BF148BC3C774B4004E78C28EDF1474042B0AA5E7E754B401A36CAFACDEE474042B0AA5E7E754B40
78984	26192	47.865661000000003	47.890050000000002	54.931541000000003	54.917918999999998	Ленина	0103000020E610000001000000050000001A36CAFACDEE474042B0AA5E7E754B401A36CAFACDEE47400BF148BC3C774B4004E78C28EDF147400BF148BC3C774B4004E78C28EDF1474042B0AA5E7E754B401A36CAFACDEE474042B0AA5E7E754B40
78995	26830	48.173810000000003	48.208835000000001	55.015495000000001	55.001854999999999	Мирная	0103000020E61000000100000005000000E0DBF4673F164840C32ADEC83C804B40E0DBF4673F16484032207BBDFB814B404DA1F31ABB1A484032207BBDFB814B404DA1F31ABB1A4840C32ADEC83C804B40E0DBF4673F164840C32ADEC83C804B40
79017	28568	48.248981000000001	48.265284999999999	55.083534	55.068814000000003	Московская	0103000020E61000000100000005000000A629029CDE1F4840E4C0ABE5CE884B40A629029CDE1F4840520DFB3DB18A4B40478FDFDBF4214840520DFB3DB18A4B40478FDFDBF4214840E4C0ABE5CE884B40A629029CDE1F4840E4C0ABE5CE884B40
78993	26664	47.919784	47.946086999999999	55.089480000000002	55.081184	Зеленая	0103000020E6100000010000000500000029B16B7BBBF54740AF7AC03C648A4B4029B16B7BBBF54740B3D2A414748B4B40DB15FA6019F94740B3D2A414748B4B40DB15FA6019F94740AF7AC03C648A4B4029B16B7BBBF54740AF7AC03C648A4B40
79012	27429	47.936978000000003	47.969389	54.943027999999998	54.932063999999997	Пролетарская	0103000020E61000000100000005000000278925E5EEF74740B4E386DF4D774B40278925E5EEF747402C9B3924B5784B40130D52F014FC47402C9B3924B5784B40130D52F014FC4740B4E386DF4D774B40278925E5EEF74740B4E386DF4D774B40
79023	28859	47.787103000000002	47.815759999999997	54.888992999999999	54.867482000000003	Калинина	0103000020E61000000100000005000000B0CA85CABFE4474031EF71A6096F4B40B0CA85CABFE44740BCAFCA85CA714B4046B1DCD26AE84740BCAFCA85CA714B4046B1DCD26AE8474031EF71A6096F4B40B0CA85CABFE4474031EF71A6096F4B40
79005	26893	48.232802	48.255313999999998	55.026231000000003	55.014178999999999	Центральная	0103000020E61000000100000005000000C138B874CC1D48401EA5129ED0814B40C138B874CC1D4840199293895B834B40001B1021AE204840199293895B834B40001B1021AE2048401EA5129ED0814B40C138B874CC1D48401EA5129ED0814B40
78996	26500	48.043275999999999	48.063012000000001	55.038876999999999	55.024951000000001	Центральная	0103000020E61000000100000005000000D15966118A0548405280289831834B40D15966118A05484086C8E9EBF9844B40B6A0F7C61008484086C8E9EBF9844B40B6A0F7C6100848405280289831834B40D15966118A0548405280289831834B40
78386	26368	48.281258000000001	48.332830000000001	54.821410999999998	54.798940000000002	Ленина	0103000020E6100000010000000500000083DE1B4300244840AEBB79AA43664B4083DE1B43002448408EC9E2FE23694B405890662C9A2A48408EC9E2FE23694B405890662C9A2A4840AEBB79AA43664B4083DE1B4300244840AEBB79AA43664B40
78983	26229	48.387141999999997	48.433585000000001	55.057367999999997	55.045851999999996	Гагарина	0103000020E610000001000000050000003A747ADE8D314840643A747ADE854B403A747ADE8D31484020EBA9D557874B40A18499B67F37484020EBA9D557874B40A18499B67F374840643A747ADE854B403A747ADE8D314840643A747ADE854B40
79016	27574	48.402521	48.423254	54.990198999999997	54.983732000000003	Овражная	0103000020E61000000100000005000000037AE1CE85334840AC0320EEEA7D4B40037AE1CE8533484015C440D7BE7E4B405AF3E32F2D36484015C440D7BE7E4B405AF3E32F2D364840AC0320EEEA7D4B40037AE1CE85334840AC0320EEEA7D4B40
78979	26147	48.079082999999997	48.101495999999997	55.136946000000002	55.125076999999997	Центральная	0103000020E61000000100000005000000B45549641F0A4840AB3DEC8502904B40B45549641F0A4840B5A84F7287914B40605628D2FD0C4840B5A84F7287914B40605628D2FD0C4840AB3DEC8502904B40B45549641F0A4840AB3DEC8502904B40
79009	27845	48.168886999999998	48.191678000000003	55.086599999999997	55.076855000000002	Центральная	0103000020E610000001000000050000001ADCD6169E1548405DC47762D6894B401ADCD6169E154840B3EA73B5158B4B406DAE9AE788184840B3EA73B5158B4B406DAE9AE7881848405DC47762D6894B401ADCD6169E1548405DC47762D6894B40
78994	26754	47.966515000000001	47.979325000000003	55.093086999999997	55.087156	Центральная	0103000020E61000000100000005000000F60B76C3B6FB474039D384ED278B4B40F60B76C3B6FB474064575A46EA8B4B40DE9387855AFD474064575A46EA8B4B40DE9387855AFD474039D384ED278B4B40F60B76C3B6FB474039D384ED278B4B40
78399	26030	48.147615000000002	48.187249000000001	54.943038999999999	54.924551999999998	Правды	0103000020E6100000010000000500000014B35E0CE5124840C7B94DB857764B4014B35E0CE512484020ED7F80B5784B40B79A75C6F717484020ED7F80B5784B40B79A75C6F7174840C7B94DB857764B4014B35E0CE5124840C7B94DB857764B40
78377	25936	48.267719999999997	48.298586	54.760126999999997	54.745063999999999	Центральная	0103000020E61000000100000005000000183E22A644224840A6B6D4415E5F4B40183E22A6442248403EE76ED74B614B409085E810382648403EE76ED74B614B409085E81038264840A6B6D4415E5F4B40183E22A644224840A6B6D4415E5F4B40
78997	26755	48.002088000000001	48.02619	55.105958999999999	55.088872000000002	Дружбы	0103000020E6100000010000000500000066DB696B44004840DBC35E28608B4B4066DB696B44004840C2DB8310908D4B40BABDA4315A034840C2DB8310908D4B40BABDA4315A034840DBC35E28608B4B4066DB696B44004840DBC35E28608B4B40
78977	25798	48.076334000000003	48.097057999999997	55.190086999999998	55.173226	Центральная	0103000020E6100000010000000500000054C90050C5094840906802452C964B4054C90050C5094840873254C554984B4057E883656C0C4840873254C554984B4057E883656C0C4840906802452C964B4054C90050C5094840906802452C964B40
78367	25758	48.333143999999997	48.352753999999997	54.956890000000001	54.934614000000003	Советская	0103000020E61000000100000005000000E76D6C76A42A48401F317A6EA1774B40E76D6C76A42A48404AEF1B5F7B7A4B403FC4060B272D48404AEF1B5F7B7A4B403FC4060B272D48401F317A6EA1774B40E76D6C76A42A48401F317A6EA1774B40
78351	24834	52.954760999999998	52.973427999999998	54.351171999999998	54.336067	Ворошилова	0103000020E61000000100000005000000853FC39B357A4A40E621533E042B4B40853FC39B357A4A40ADA23F34F32C4B405E81E849997C4A40ADA23F34F32C4B405E81E849997C4A40E621533E042B4B40853FC39B357A4A40E621533E042B4B40
79340	23610	52.722295000000003	52.736829	54.569727	54.563969	Новая 	0103000020E610000001000000050000003C889D29745C4A409A7ADD2230484B403C889D29745C4A40F85278D0EC484B4048DFA469505E4A40F85278D0EC484B4048DFA469505E4A409A7ADD2230484B403C889D29745C4A409A7ADD2230484B40
78928	24547	52.893298000000001	52.915927000000003	54.715555999999999	54.70082	Молодёжная	0103000020E6100000010000000500000086CABF9657724A40FD304278B4594B4086CABF9657724A40713AC956975B4B40FF428F183D754A40713AC956975B4B40FF428F183D754A40FD304278B4594B4086CABF9657724A40FD304278B4594B40
78946	24739	53.009369	53.027318000000001	54.461216	54.453699999999998	Советская	0103000020E61000000100000005000000514CDE0033814A40FC1873D7123A4B40514CDE0033814A402B323A20093B4B40CB4BFE277F834A402B323A20093B4B40CB4BFE277F834A40FC1873D7123A4B40514CDE0033814A40FC1873D7123A4B40
78940	24631	52.926130999999998	52.949973	54.434449000000001	54.415371999999998	Спасская	0103000020E61000000100000005000000E867EA758B764A4049D6E1E82A354B40E867EA758B764A40D4635B069C374B40A08A1BB798794A40D4635B069C374B40A08A1BB798794A4049D6E1E82A354B40E867EA758B764A4049D6E1E82A354B40
78972	24437	52.856368000000003	52.886237000000001	54.670566000000001	54.641596999999997	Полевая	0103000020E61000000100000005000000A4AB74779D6D4A40191BBAD91F524B40A4AB74779D6D4A409FE74F1BD5554B40A9C0C93670714A409FE74F1BD5554B40A9C0C93670714A40191BBAD91F524B40A4AB74779D6D4A40191BBAD91F524B40
78922	24324	53.046263000000003	53.063969	54.705257000000003	54.693286000000001	Центральная	0103000020E61000000100000005000000E7012CF2EB854A4028637C98BD584B40E7012CF2EB854A40362383DC455A4B409A7ADD2230884A40362383DC455A4B409A7ADD2230884A4028637C98BD584B40E7012CF2EB854A4028637C98BD584B40
78318	23740	52.764974000000002	52.786928000000003	54.569783999999999	54.558300000000003	Ягофарова	0103000020E61000000100000005000000292504ABEA614A40ACADD85F76474B40292504ABEA614A405CE49EAEEE484B404227840EBA644A405CE49EAEEE484B404227840EBA644A40ACADD85F76474B40292504ABEA614A40ACADD85F76474B40
11709	24422	52.880012000000001	52.910600000000002	54.643357999999999	54.629866999999997	Центральная	0103000020E61000000100000005000000350BB43BA4704A4031EA5A7B9F504B40350BB43BA4704A405BCF108E59524B406ADE718A8E744A405BCF108E59524B406ADE718A8E744A4031EA5A7B9F504B40350BB43BA4704A4031EA5A7B9F504B40
78358	24422	52.880012000000001	52.910600000000002	54.643357999999999	54.629866999999997	Луговая	0103000020E61000000100000005000000350BB43BA4704A4031EA5A7B9F504B40350BB43BA4704A405BCF108E59524B406ADE718A8E744A405BCF108E59524B406ADE718A8E744A4031EA5A7B9F504B40350BB43BA4704A4031EA5A7B9F504B40
78907	23935	52.658549999999998	52.673965000000003	54.679274999999997	54.667758999999997	Пушкина	0103000020E61000000100000005000000F163CC5D4B544A40094E7D2079554B40F163CC5D4B544A40C5FEB27BF2564B4007D3307C44564A40C5FEB27BF2564B4007D3307C44564A40094E7D2079554B40F163CC5D4B544A40094E7D2079554B40
78231	24325	52.767552000000002	53.059018999999999	54.432281000000003	54.387107	Центральная	0103000020E610000001000000050000005DFDD8243F624A40BE86E0B88C314B405DFDD8243F624A4052D7DAFB54374B40DB6B41EF8D874A4052D7DAFB54374B40DB6B41EF8D874A40BE86E0B88C314B405DFDD8243F624A40BE86E0B88C314B40
78916	24241	53.016475	53.038133000000002	54.657417000000002	54.641466999999999	Советская	0103000020E61000000100000005000000CE1951DA1B824A404B3B35971B524B40CE1951DA1B824A40CF6A813D26544B40FEF2C98AE1844A40CF6A813D26544B40FEF2C98AE1844A404B3B35971B524B40CE1951DA1B824A404B3B35971B524B40
78971	24132	52.905963999999997	52.921388	54.576448999999997	54.565686999999997	Центральная	0103000020E610000001000000050000003AADDBA0F6734A40DC627E6E68484B403AADDBA0F6734A40EC67B114C9494B40A376BF0AF0754A40EC67B114C9494B40A376BF0AF0754A40DC627E6E68484B403AADDBA0F6734A40DC627E6E68484B40
78333	24174	53.060096999999999	53.086894000000001	54.418844999999997	54.403398000000003	Советская	0103000020E610000001000000050000003ACB2C42B1874A40CBA2B08BA2334B403ACB2C42B1874A40EB8B84B69C354B40FC1BB4571F8B4A40EB8B84B69C354B40FC1BB4571F8B4A40CBA2B08BA2334B403ACB2C42B1874A40CBA2B08BA2334B40
69159	24033	52.869743999999997	52.901733	54.522066000000002	54.499872000000003	Совхозная	0103000020E6100000010000000500000034F279C5536F4A40D31742CEFB3F4B4034F279C5536F4A40412D060FD3424B40AB5CA8FC6B734A40412D060FD3424B40AB5CA8FC6B734A40D31742CEFB3F4B4034F279C5536F4A40D31742CEFB3F4B40
78328	24025	52.587296000000002	52.623578999999999	54.750193000000003	54.735937	Советская	0103000020E610000001000000050000002B89EC832C4B4A404B75012F335E4B402B89EC832C4B4A401558005306604B4077BCC96FD14F4A401558005306604B4077BCC96FD14F4A404B75012F335E4B402B89EC832C4B4A404B75012F335E4B40
78325	23872	53.011021999999997	53.032958999999998	54.562418999999998	54.551986999999997	Озерная	0103000020E61000000100000005000000ACC43C2B69814A4098689082A7464B40ACC43C2B69814A4013D38558FD474B40EF8D210038844A4013D38558FD474B40EF8D210038844A4098689082A7464B40ACC43C2B69814A4098689082A7464B40
75331	23446	52.537880000000001	52.597760999999998	54.713147999999997	54.687764000000001	Школьная	0103000020E6100000010000000500000014967840D9444A40DEAE97A608584B4014967840D9444A40999A046F485B4B4081E9B46E834C4A40999A046F485B4B4081E9B46E834C4A40DEAE97A608584B4014967840D9444A40DEAE97A608584B40
69150	23446	52.537880000000001	52.597760999999998	54.713147999999997	54.687764000000001	Вахитова	0103000020E6100000010000000500000014967840D9444A40DEAE97A608584B4014967840D9444A40999A046F485B4B4081E9B46E834C4A40999A046F485B4B4081E9B46E834C4A40DEAE97A608584B4014967840D9444A40DEAE97A608584B40
78315	23743	52.732112999999998	52.764183000000003	54.453778999999997	54.433171000000002	Шоссейная	0103000020E61000000100000005000000FCFCF7E0B55D4A40AE49B72572374B40FCFCF7E0B55D4A40484E266E153A4B406094A0BFD0614A40484E266E153A4B406094A0BFD0614A40AE49B72572374B40FCFCF7E0B55D4A40AE49B72572374B40
78909	23820	52.772888000000002	52.79663	54.505085000000001	54.498094999999999	Ленина	0103000020E6100000010000000500000045BC75FEED624A408BA6B393C13F4B4045BC75FEED624A409F5912A0A6404B409981CAF8F7654A409F5912A0A6404B409981CAF8F7654A408BA6B393C13F4B4045BC75FEED624A408BA6B393C13F4B40
78937	24638	52.835526999999999	52.849820000000001	54.479100000000003	54.464925999999998	Советская	0103000020E6100000010000000500000066F6798CF26A4A40B187F6B1823B4B4066F6798CF26A4A40BEC11726533D4B404DBED9E6C66C4A40BEC11726533D4B404DBED9E6C66C4A40B187F6B1823B4B4066F6798CF26A4A40B187F6B1823B4B40
78340	24781	52.945625	52.966636000000001	54.507866	54.494408	Гафиатуллина	0103000020E61000000100000005000000D7A3703D0A794A40BD70E7C2483F4B40D7A3703D0A794A400B60CAC001414B4071917BBABA7B4A400B60CAC001414B4071917BBABA7B4A40BD70E7C2483F4B40D7A3703D0A794A40BD70E7C2483F4B40
71676	23560	52.782024	52.787872	54.578218	54.571218999999999	Центральная	0103000020E61000000100000005000000F357C85C19644A404AED45B41D494B40F357C85C19644A40B1FA230C034A4B4091B75CFDD8644A40B1FA230C034A4B4091B75CFDD8644A404AED45B41D494B40F357C85C19644A404AED45B41D494B40
78923	24491	52.861147000000003	52.873814000000003	54.612336999999997	54.604421000000002	Школьная	0103000020E6100000010000000500000036069D103A6E4A400002D6AA5D4D4B4036069D103A6E4A40BC900E0F614E4B40BB641C23D96F4A40BC900E0F614E4B40BB641C23D96F4A400002D6AA5D4D4B4036069D103A6E4A400002D6AA5D4D4B40
78647	23451	52.586145999999999	52.607408999999997	54.381743	54.362341999999998	Ключевская	0103000020E61000000100000005000000325706D5064B4A40CEFBFF38612E4B40325706D5064B4A400C3D62F4DC304B40E525FF93BF4D4A400C3D62F4DC304B40E525FF93BF4D4A40CEFBFF38612E4B40325706D5064B4A40CEFBFF38612E4B40
11687	40934	52.581636000000003	52.607562000000001	54.425750000000001	54.412097000000003	Школьная	0103000020E610000001000000050000009016670C734A4A40CEE33098BF344B409016670C734A4A40D122DBF97E364B406C257497C44D4A40D122DBF97E364B406C257497C44D4A40CEE33098BF344B409016670C734A4A40CEE33098BF344B40
9866	40336	52.486764999999998	53.145159	54.804498000000002	54.266773000000001	Гафиатуллина	0103000020E6100000010000000500000031EBC5504E3E4A40583A1F9E25224B4031EBC5504E3E4A4045D95BCAF9664B402BDCF29194924A4045D95BCAF9664B402BDCF29194924A40583A1F9E25224B4031EBC5504E3E4A40583A1F9E25224B40
78899	21527	50.148198999999998	50.159311000000002	56.384000999999998	56.377592	М.Горького	0103000020E610000001000000050000006326512FF8124940999D45EF54304C406326512FF8124940CE50DCF126314C405072874D64144940CE50DCF126314C405072874D64144940999D45EF54304C406326512FF8124940999D45EF54304C40
78301	21672	50.378312000000001	50.416525999999998	56.420752	56.400638000000001	Дружбы	0103000020E6100000010000000500000099D711876C30494076C4211B48334C4099D711876C30494001DD9733DB354C4083F755B95035494001DD9733DB354C4083F755B95035494076C4211B48334C4099D711876C30494076C4211B48334C40
78299	21390	50.478375	50.498353999999999	56.476472999999999	56.455278999999997	Г.Тукая	0103000020E61000000100000005000000AC1C5A643B3D49401DC70F95463A4C40AC1C5A643B3D4940A8363811FD3C4C4057EA5910CA3F4940A8363811FD3C4C4057EA5910CA3F49401DC70F95463A4C40AC1C5A643B3D49401DC70F95463A4C40
78891	20976	50.500104999999998	50.524799999999999	56.517063	56.507547000000002	В.Булатова	0103000020E6100000010000000500000075C8CD70034049406A17D34CF7404C4075C8CD70034049405F7CD11E2F424C406C787AA52C4349405F7CD11E2F424C406C787AA52C4349406A17D34CF7404C4075C8CD70034049406A17D34CF7404C40
71499	21531	50.278391999999997	50.320757	56.533749999999998	56.518548000000003	Ленина	0103000020E61000000100000005000000E8BB5B59A2234940FFB3E6C75F424C40E8BB5B59A2234940B81E85EB51444C40467BBC900E294940B81E85EB51444C40467BBC900E294940FFB3E6C75F424C40E8BB5B59A2234940FFB3E6C75F424C40
78895	21349	50.231122999999997	50.257731	56.478546000000001	56.463312000000002	Колхозная	0103000020E610000001000000050000003C2D3F70951D494014ECBFCE4D3B4C403C2D3F70951D4940D9D0CDFE403D4C402B155454FD204940D9D0CDFE403D4C402B155454FD20494014ECBFCE4D3B4C403C2D3F70951D494014ECBFCE4D3B4C40
78910	21738	50.310524999999998	50.332839	56.43262	56.415793000000001	Дружбы	0103000020E6100000010000000500000092CB7F48BF274940EF737CB438354C4092CB7F48BF2749403ACC971760374C40ABEAE5779A2A49403ACC971760374C40ABEAE5779A2A4940EF737CB438354C4092CB7F48BF274940EF737CB438354C40
75317	21122	50.315995999999998	50.338956000000003	56.374332000000003	56.357095999999999	Советская	0103000020E610000001000000050000005AD5928E7228494026C45C52B52D4C405AD5928E7228494053EC681CEA2F4C40396403E9622B494053EC681CEA2F4C40396403E9622B494026C45C52B52D4C405AD5928E7228494026C45C52B52D4C40
78896	21342	50.267288999999998	50.287995000000002	56.451678000000001	56.441772	Центральная	0103000020E610000001000000050000004FCAA48636224940EE2422FC8B384C404FCAA486362249404E29AF95D0394C40AD342905DD2449404E29AF95D0394C40AD342905DD244940EE2422FC8B384C404FCAA48636224940EE2422FC8B384C40
78295	21254	50.441561999999998	50.463427000000003	56.487065999999999	56.466171000000003	Баумана	0103000020E610000001000000050000000394861A85384940FCABC77DAB3B4C400394861A853849402C7FBE2D583E4C40AD8A7093513B49402C7FBE2D583E4C40AD8A7093513B4940FCABC77DAB3B4C400394861A85384940FCABC77DAB3B4C40
78290	21061	50.351298999999997	50.370882999999999	56.600866000000003	56.58578	С.Муликова	0103000020E610000001000000050000000A0F9A5DF72C49405053CBD6FA4A4C400A0F9A5DF72C4940A1A3552DE94C4C4039D21918792F4940A1A3552DE94C4C4039D21918792F49405053CBD6FA4A4C400A0F9A5DF72C49405053CBD6FA4A4C40
78286	20968	50.448748999999999	50.48451	56.537894999999999	56.517598999999997	Ленина	0103000020E610000001000000050000006D8E739B703949409DB81CAF40424C406D8E739B7039494049D74CBED9444C40E04A766C043E494049D74CBED9444C40E04A766C043E49409DB81CAF40424C406D8E739B703949409DB81CAF40424C40
71513	20806	50.269148000000001	50.294786000000002	56.341383	56.329346999999999	Казанская	0103000020E6100000010000000500000054E41071732249409204E10A282A4C4054E410717322494087342A70B22B4C40CAA8328CBB25494087342A70B22B4C40CAA8328CBB2549409204E10A282A4C4054E41071732249409204E10A282A4C40
78289	21177	50.217441000000001	50.245055999999998	56.389054000000002	56.357460000000003	Героя Сарвара	0103000020E610000001000000050000009FE74F1BD51B494068D0D03FC12D4C409FE74F1BD51B494062307F85CC314C4023D8B8FE5D1F494062307F85CC314C4023D8B8FE5D1F494068D0D03FC12D4C409FE74F1BD51B494068D0D03FC12D4C40
78277	20648	50.016057000000004	50.041936999999997	56.338369	56.329211999999998	Школьная	0103000020E610000001000000050000009AEFE0270E024940B2B96A9E232A4C409AEFE0270E024940787DE6AC4F2B4C4005BF0D315E054940787DE6AC4F2B4C4005BF0D315E054940B2B96A9E232A4C409AEFE0270E024940B2B96A9E232A4C40
78302	21826	50.135613999999997	50.153733000000003	56.351500000000001	56.343767999999997	Центральная	0103000020E610000001000000050000009B70AFCC5B114940A6B4FE96002C4C409B70AFCC5B114940A245B6F3FD2C4C4072A8DF85AD134940A245B6F3FD2C4C4072A8DF85AD134940A6B4FE96002C4C409B70AFCC5B114940A6B4FE96002C4C40
78893	20550	50.158583999999998	50.190545999999998	56.451787000000003	56.439070000000001	Центральная	0103000020E610000001000000050000009DD5027B4C144940CE531D7233384C409DD5027B4C14494005E10A28D4394C401A31B3CF6318494005E10A28D4394C401A31B3CF63184940CE531D7233384C409DD5027B4C144940CE531D7233384C40
78276	20752	50.222552999999998	50.262706999999999	56.619853999999997	56.600569	Кирова	0103000020E610000001000000050000003750E09D7C1C4940E7FEEA71DF4C4C403750E09D7C1C4940BB253960574F4C4013B70A62A0214940BB253960574F4C4013B70A62A0214940E7FEEA71DF4C4C403750E09D7C1C4940E7FEEA71DF4C4C40
78221	20869	50.285640999999998	50.307865999999997	56.310687000000001	56.300998999999997	Г.Тукая	0103000020E61000000100000005000000C8B260E28F24494079909E2287264C40C8B260E28F2449406C257497C4274C4071C63027682749406C257497C4274C4071C630276827494079909E2287264C40C8B260E28F24494079909E2287264C40
78279	20642	50.092432000000002	50.108789999999999	56.346131999999997	56.340535000000003	Сибирский Тракт	0103000020E610000001000000050000004C8DD0CFD40B49405A12A0A6962B4C404C8DD0CFD40B4940AE0CAA0D4E2C4C40E010AAD4EC0D4940AE0CAA0D4E2C4C40E010AAD4EC0D49405A12A0A6962B4C404C8DD0CFD40B49405A12A0A6962B4C40
78281	20762	50.288803999999999	50.312258999999997	56.600222000000002	56.586959999999998	Парковая	0103000020E610000001000000050000001C7A8B87F7244940B3075A81214B4C401C7A8B87F72449407C2B1213D44C4C40DA70581AF82749407C2B1213D44C4C40DA70581AF8274940B3075A81214B4C401C7A8B87F7244940B3075A81214B4C40
78967	21444	50.063451999999998	50.079037999999997	56.377282999999998	56.366878999999997	Центральная	0103000020E61000000100000005000000D26EF4311F0849406A4B1DE4F52E4C40D26EF4311F0849401B2B31CF4A304C401492CCEA1D0A49401B2B31CF4A304C401492CCEA1D0A49406A4B1DE4F52E4C40D26EF4311F0849406A4B1DE4F52E4C40
78280	20484	50.107595000000003	50.131005000000002	56.492016	56.484878999999999	Карла Маркса	0103000020E61000000100000005000000481B47ACC50D494033C2DB83103E4C40481B47ACC50D4940EB8D5A61FA3E4C40664E97C5C4104940EB8D5A61FA3E4C40664E97C5C410494033C2DB83103E4C40481B47ACC50D494033C2DB83103E4C40
78312	21257	50.375967000000003	50.404156	56.437094000000002	56.425412000000001	Татарстана	0103000020E6100000010000000500000008B0C8AF1F304940B9A981E673364C4008B0C8AF1F30494090A339B2F2374C40B83D4162BB33494090A339B2F2374C40B83D4162BB334940B9A981E673364C4008B0C8AF1F304940B9A981E673364C40
78271	20422	50.393520000000002	50.428401999999998	56.305619	56.293767000000003	Шакирова	0103000020E61000000100000005000000352905DD5E32494070D234289A254C40352905DD5E324940A304FD851E274C403FC571E0D5364940A304FD851E274C403FC571E0D536494070D234289A254C40352905DD5E32494070D234289A254C40
68839	59178	50.182129000000003	50.239638999999997	56.353430000000003	56.337322	Наримана	0103000020E610000001000000050000009C53C90050174940541C075E2D2B4C409C53C9005017494070B6B9313D2D4C404EECA17DAC1E494070B6B9313D2D4C404EECA17DAC1E4940541C075E2D2B4C409C53C90050174940541C075E2D2B4C40
68872	20291	50.182129000000003	50.239638999999997	56.353430000000003	56.337322	Ленина	0103000020E610000001000000050000009C53C90050174940541C075E2D2B4C409C53C9005017494070B6B9313D2D4C404EECA17DAC1E494070B6B9313D2D4C404EECA17DAC1E4940541C075E2D2B4C409C53C90050174940541C075E2D2B4C40
68717	20291	50.182129000000003	50.239638999999997	56.353430000000003	56.337322	Карла Маркса	0103000020E610000001000000050000009C53C90050174940541C075E2D2B4C409C53C9005017494070B6B9313D2D4C404EECA17DAC1E494070B6B9313D2D4C404EECA17DAC1E4940541C075E2D2B4C409C53C90050174940541C075E2D2B4C40
78973	21067	50.350769	50.372993999999998	56.638945999999997	56.631025000000001	Комсомола	0103000020E61000000100000005000000AEB9A3FFE52C4940ADFA5C6DC5504C40AEB9A3FFE52C49407BF486FBC8514C4057CD7344BE2F49407BF486FBC8514C4057CD7344BE2F4940ADFA5C6DC5504C40AEB9A3FFE52C4940ADFA5C6DC5504C40
78912	21616	50.193114999999999	50.235793999999999	56.553699999999999	56.538316999999999	Татарстана	0103000020E61000000100000005000000FBAE08FEB7184940BFF04A92E7444C40FBAE08FEB7184940C9E53FA4DF464C40E84B6F7F2E1E4940C9E53FA4DF464C40E84B6F7F2E1E4940BFF04A92E7444C40FBAE08FEB7184940BFF04A92E7444C40
78884	61366	52.950000000000003	53.504125000000002	54.573400999999997	53.974775999999999	Вахитова	0103000020E610000001000000050000009A99999999794A407D76C075C5FC4A409A99999999794A40313F373465494B404A0C022B87C04A40313F373465494B404A0C022B87C04A407D76C075C5FC4A409A99999999794A407D76C075C5FC4A40
78877	19724	53.436580999999997	53.461950000000002	54.109009999999998	54.086185	Советская	0103000020E610000001000000050000000987DEE2E1B74A40F0332E1C080B4B400987DEE2E1B74A40EE77280AF40D4B409031772D21BB4A40EE77280AF40D4B409031772D21BB4A40F0332E1C080B4B400987DEE2E1B74A40F0332E1C080B4B40
78873	19730	53.354914999999998	53.373187000000001	54.048358	54.036689000000003	Советская	0103000020E610000001000000050000000FEECEDA6DAD4A40BD8FA339B2044B400FEECEDA6DAD4A40FF3F4E9830064B406C257497C4AF4A40FF3F4E9830064B406C257497C4AF4A40BD8FA339B2044B400FEECEDA6DAD4A40BD8FA339B2044B40
78885	20179	53.129465000000003	53.159657000000003	54.308782000000001	54.292641000000003	Ленина	0103000020E61000000100000005000000037D224F92904A40003CA24275254B40037D224F92904A40F7CB272B86274B40EBC9FCA36F944A40F7CB272B86274B40EBC9FCA36F944A40003CA24275254B40037D224F92904A40003CA24275254B40
78966	19056	53.400029000000004	53.414850999999999	54.500143999999999	54.487202000000003	Центральная	0103000020E61000000100000005000000CE39782634B34A40DD4598A25C3E4B40CE39782634B34A4033A5F5B704404B4040DB6AD619B54A4033A5F5B704404B4040DB6AD619B54A40DD4598A25C3E4B40CE39782634B34A40DD4598A25C3E4B40
79156	61421	53.220680000000002	53.241610999999999	54.493837999999997	54.481783	Подгорная	0103000020E61000000100000005000000CE70033E3F9C4A406762BA10AB3D4B40CE70033E3F9C4A40D2C26515363F4B404BADF71BED9E4A40D2C26515363F4B404BADF71BED9E4A406762BA10AB3D4B40CE70033E3F9C4A406762BA10AB3D4B40
79318	19932	53.10566	53.157870000000003	54.138764999999999	54.119708000000003	Советская	0103000020E61000000100000005000000683F5244868D4A40E8887C97520F4B40683F5244868D4A402B6A300DC3114B4080828B1535944A402B6A300DC3114B4080828B1535944A40E8887C97520F4B40683F5244868D4A40E8887C97520F4B40
78066	19512	53.249453000000003	53.287542000000002	54.322358000000001	54.312784000000001	Ленина	0103000020E61000000100000005000000CE716E13EE9F4A40255B5D4E09284B40CE716E13EE9F4A404FCDE50643294B40FC1C1F2DCEA44A404FCDE50643294B40FC1C1F2DCEA44A40255B5D4E09284B40CE716E13EE9F4A40255B5D4E09284B40
78902	19840	53.281613	53.315587000000001	54.106788000000002	54.097670000000001	Калинина	0103000020E61000000100000005000000719010E50BA44A4071E65773800C4B40719010E50BA44A4079CDAB3AAB0D4B407905A22765A84A4079CDAB3AAB0D4B407905A22765A84A4071E65773800C4B40719010E50BA44A4071E65773800C4B40
78268	20286	53.148240000000001	53.192329000000001	54.369891000000003	54.352179	Советская	0103000020E61000000100000005000000C2FA3F87F9924A4043AB9333142D4B40C2FA3F87F9924A40D90A9A96582F4B404489963C9E984A40D90A9A96582F4B404489963C9E984A4043AB9333142D4B40C2FA3F87F9924A4043AB9333142D4B40
78274	20056	53.214446000000002	53.268030000000003	54.202603000000003	54.176900000000003	Центральная	0103000020E6100000010000000500000007616EF7729B4A40CA54C1A8A4164B4007616EF7729B4A40278925E5EE194B40672C9ACE4EA24A40278925E5EE194B40672C9ACE4EA24A40CA54C1A8A4164B4007616EF7729B4A40CA54C1A8A4164B40
78269	19523	53.353541	53.406928000000001	54.260857000000001	54.252768000000003	Советская	0103000020E61000000100000005000000C765DCD440AD4A40D8BCAAB35A204B40C765DCD440AD4A4062F71DC363214B40D1E9793716B44A4062F71DC363214B40D1E9793716B44A40D8BCAAB35A204B40C765DCD440AD4A40D8BCAAB35A204B40
78878	19780	53.323653999999998	53.345635999999999	54.076703999999999	54.063747999999997	Школьная	0103000020E610000001000000050000001B9C887E6DA94A40BB97FBE428084B401B9C887E6DA94A4077BCC96FD1094B40FE28EACC3DAC4A4077BCC96FD1094B40FE28EACC3DAC4A40BB97FBE428084B401B9C887E6DA94A40BB97FBE428084B40
78883	19617	53.356504999999999	53.388036	54.206600000000002	54.191136	Советская	0103000020E6100000010000000500000024EEB1F4A1AD4A404C8BFA2477184B4024EEB1F4A1AD4A4043AD69DE711A4B40D8D5E429ABB14A4043AD69DE711A4B40D8D5E429ABB14A404C8BFA2477184B4024EEB1F4A1AD4A404C8BFA2477184B40
78988	19410	53.116501999999997	53.144233	54.483677	54.466805000000001	Школьная	0103000020E6100000010000000500000094F59B89E98E4A40FD4D2844C03B4B4094F59B89E98E4A40E869C020E93D4B408200193A76924A40E869C020E93D4B408200193A76924A40FD4D2844C03B4B4094F59B89E98E4A40FD4D2844C03B4B40
78874	19351	53.102102000000002	53.130021999999997	54.561093	54.515790000000003	Советская	0103000020E61000000100000005000000986DA7AD118D4A404BCD1E6805424B40986DA7AD118D4A40DC813AE5D1474B4058E1968FA4904A40DC813AE5D1474B4058E1968FA4904A404BCD1E6805424B40986DA7AD118D4A404BCD1E6805424B40
75315	19011	53.373942	53.393103000000004	54.427529999999997	54.403655000000001	Советская	0103000020E61000000100000005000000E84CDA54DDAF4A40F6EE8FF7AA334B40E84CDA54DDAF4A408907944DB9364B40D17AF83251B24A408907944DB9364B40D17AF83251B24A40F6EE8FF7AA334B40E84CDA54DDAF4A40F6EE8FF7AA334B40
78222	19415	53.365299999999998	53.401547000000001	54.340445000000003	54.319386000000002	Советская	0103000020E61000000100000005000000499D8026C2AE4A406F66F4A3E1284B40499D8026C2AE4A401A8BA6B3932B4B40496760E465B34A401A8BA6B3932B4B40496760E465B34A406F66F4A3E1284B40499D8026C2AE4A406F66F4A3E1284B40
78886	20044	53.05292	53.087828000000002	54.195503000000002	54.163986000000001	Советская	0103000020E61000000100000005000000F4A62215C6864A403D80457EFD144B40F4A62215C6864A408CA2073E06194B4028D6A9F23D8B4A408CA2073E06194B4028D6A9F23D8B4A403D80457EFD144B40F4A62215C6864A403D80457EFD144B40
79321	19266	53.161785999999999	53.182493000000001	54.409084	54.392229	Школьная	0103000020E61000000100000005000000AF795567B5944A407AC5538F34324B40AF795567B5944A408FA850DD5C344B40DD5F3DEE5B974A408FA850DD5C344B40DD5F3DEE5B974A407AC5538F34324B40AF795567B5944A407AC5538F34324B40
75074	60491	53.374993000000003	53.383023999999999	54.377237999999998	54.367179	Горюнова	0103000020E610000001000000050000004E9D47C5FFAF4A409563B2B8FF2E4B404E9D47C5FFAF4A407B67B45549304B40A3CA30EE06B14A407B67B45549304B40A3CA30EE06B14A409563B2B8FF2E4B404E9D47C5FFAF4A409563B2B8FF2E4B40
78888	20113	53.188583000000001	53.212128	54.256439	54.229322000000003	Советская	0103000020E6100000010000000500000071CADC7C23984A406D205D6C5A1D4B4071CADC7C23984A40A0353FFED2204B406F48A302279B4A40A0353FFED2204B406F48A302279B4A406D205D6C5A1D4B4071CADC7C23984A406D205D6C5A1D4B40
78266	19116	53.267096000000002	53.293227999999999	54.476326999999998	54.457076000000001	Школьная	0103000020E610000001000000050000003B72A43330A24A40ACE46377813A4B403B72A43330A24A40D4997B48F83C4B40C022BF7E88A54A40D4997B48F83C4B40C022BF7E88A54A40ACE46377813A4B403B72A43330A24A40ACE46377813A4B40
79342	61532	49.576259999999998	49.596131	56.340690000000002	56.328403999999999	М.Горького	0103000020E6100000010000000500000019FF3EE3C2C9484013F06B24092A4C4019FF3EE3C2C948408109DCBA9B2B4C40DE9046054ECC48408109DCBA9B2B4C40DE9046054ECC484013F06B24092A4C4019FF3EE3C2C9484013F06B24092A4C40
78867	18349	49.424939000000002	49.455679000000003	56.372418000000003	56.363618000000002	Зелень	0103000020E61000000100000005000000C1E5B16664B64840541EDD088B2E4C40C1E5B16664B648408B389D64AB2F4C40AC3C81B053BA48408B389D64AB2F4C40AC3C81B053BA4840541EDD088B2E4C40C1E5B16664B64840541EDD088B2E4C40
78849	32507	49.551098000000003	49.577958000000002	56.349249999999998	56.337217000000003	Татарстан	0103000020E610000001000000050000000D7217618AC64840DF5339ED292B4C400D7217618AC6484062105839B42C4C40153B1A87FAC9484062105839B42C4C40153B1A87FAC94840DF5339ED292B4C400D7217618AC64840DF5339ED292B4C40
78852	18257	49.454394000000001	49.468308999999998	56.370553000000001	56.357334999999999	Молодежная	0103000020E61000000100000005000000D3BF249529BA4840AB5B3D27BD2D4C40D3BF249529BA4840A437DC476E2F4C4013B69F8CF1BB4840A437DC476E2F4C4013B69F8CF1BB4840AB5B3D27BD2D4C40D3BF249529BA4840AB5B3D27BD2D4C40
78991	17872	49.277003999999998	49.304636000000002	56.294626000000001	56.282265000000002	Татарстан	0103000020E610000001000000050000003B6EF8DD74A3484019E76F4221244C403B6EF8DD74A348409146054EB6254C409697FC4FFEA648409146054EB6254C409697FC4FFEA6484019E76F4221244C403B6EF8DD74A3484019E76F4221244C40
78260	17164	49.315578000000002	49.353648	56.247301	56.224516999999999	Чишмяле	0103000020E6100000010000000500000026AB22DC64A84840B1321AF9BC1C4C4026AB22DC64A8484051A2258FA71F4C40DD25715644AD484051A2258FA71F4C40DD25715644AD4840B1321AF9BC1C4C4026AB22DC64A84840B1321AF9BC1C4C40
78788	17072	49.455544000000003	49.474561999999999	56.235491000000003	56.223176000000002	Советская	0103000020E61000000100000005000000CCF10A444FBA484045A0FA07911C4C40CCF10A444FBA48404DC0AF91241E4C4051F69672BEBC48404DC0AF91241E4C4051F69672BEBC484045A0FA07911C4C40CCF10A444FBA484045A0FA07911C4C40
79217	61468	49.553263000000001	49.561177000000001	56.380527999999998	56.368594000000002	Ленина	0103000020E610000001000000050000001E8B6D52D1C648403CC093162E2F4C401E8B6D52D1C648402C9B3924B5304C403A22DFA5D4C748402C9B3924B5304C403A22DFA5D4C748403CC093162E2F4C401E8B6D52D1C648403CC093162E2F4C40
78823	17781	49.479314000000002	49.507430999999997	56.353754000000002	56.337226999999999	Татарстан	0103000020E61000000100000005000000EA4141295ABD4840022A1C412A2B4C40EA4141295ABD4840236AA2CF472D4C4000FDBE7FF3C04840236AA2CF472D4C4000FDBE7FF3C04840022A1C412A2B4C40EA4141295ABD4840022A1C412A2B4C40
78275	17518	49.472873	49.495500999999997	56.323757000000001	56.311906	Советская	0103000020E61000000100000005000000A9143B1A87BC48408DB62A89EC274C40A9143B1A87BC4840F06C8FDE70294C405111A7936CBF4840F06C8FDE70294C405111A7936CBF48408DB62A89EC274C40A9143B1A87BC48408DB62A89EC274C40
78822	17673	49.274676999999997	49.301600000000001	56.338639000000001	56.325684000000003	Кирова	0103000020E6100000010000000500000050FBAD9D28A348404D6A6803B0294C4050FBAD9D28A348403813D385582B4C409F3C2CD49AA648403813D385582B4C409F3C2CD49AA648404D6A6803B0294C4050FBAD9D28A348404D6A6803B0294C40
78259	17583	49.369799999999998	49.405678999999999	56.310248000000001	56.280411999999998	Школьная	0103000020E61000000100000005000000C8073D9B55AF4840F6B3588AE4234C40C8073D9B55AF484020D3DA34B6274C4045D61A4AEDB3484020D3DA34B6274C4045D61A4AEDB34840F6B3588AE4234C40C8073D9B55AF4840F6B3588AE4234C40
79344	18119	49.504547000000002	49.525855	56.293407000000002	56.281376000000002	Татарстан 	0103000020E61000000100000005000000C02500FF94C048408DF0F62004244C40C02500FF94C0484070B54E5C8E254C4013B875374FC3484070B54E5C8E254C4013B875374FC348408DF0F62004244C40C02500FF94C048408DF0F62004244C40
78814	17465	49.444037000000002	49.473654000000003	56.164721999999998	56.143794999999997	Комсомольская	0103000020E61000000100000005000000639B5434D6B84840062AE3DF67124C40639B5434D6B848404277499C15154C404FCFBBB1A0BC48404277499C15154C404FCFBBB1A0BC4840062AE3DF67124C40639B5434D6B84840062AE3DF67124C40
78868	18362	49.416063000000001	49.436490999999997	56.429912000000002	56.416046999999999	Тукая	0103000020E61000000100000005000000AF09698D41B54840A94C310741354C40AF09698D41B5484038143E5B07374C40C9FFE4EFDEB7484038143E5B07374C40C9FFE4EFDEB74840A94C310741354C40AF09698D41B54840A94C310741354C40
79307	17362	49.325871999999997	49.333920999999997	56.311416000000001	56.305309000000001	Мира	0103000020E610000001000000050000004F57772CB6A948405516855D14274C404F57772CB6A94840BFB9BF7ADC274C404B395FECBDAA4840BFB9BF7ADC274C404B395FECBDAA48405516855D14274C404F57772CB6A948405516855D14274C40
78819	17676	49.145428000000003	49.170644000000003	56.333329999999997	56.318230999999997	Колхозная	0103000020E610000001000000050000001BF67B629D92484064C91CCBBB284C401BF67B629D9248404963B48EAA2A4C401BA19FA9D79548404963B48EAA2A4C401BA19FA9D795484064C91CCBBB284C401BF67B629D92484064C91CCBBB284C40
79316	17214	49.433895	49.451250000000002	56.303986000000002	56.294086	Ш.Камала	0103000020E61000000100000005000000EF7211DF89B74840111B2C9CA4254C40EF7211DF89B748408F386403E9264C40F6285C8FC2B948408F386403E9264C40F6285C8FC2B94840111B2C9CA4254C40EF7211DF89B74840111B2C9CA4254C40
78962	17451	49.557153	49.574283999999999	56.134801000000003	56.12256	Узяк	0103000020E6100000010000000500000024EF1CCA50C748401DE6CB0BB00F4C4024EF1CCA50C74840EB3BBF2841114C40DB4E5B2382C94840EB3BBF2841114C40DB4E5B2382C948401DE6CB0BB00F4C4024EF1CCA50C748401DE6CB0BB00F4C40
78649	17974	49.245733999999999	49.275449999999999	56.31561	56.307541000000001	Тукая	0103000020E61000000100000005000000F4C13236749F4840EE96E4805D274C40F4C13236749F4840312592E865284C4073D712F241A34840312592E865284C4073D712F241A34840EE96E4805D274C40F4C13236749F4840EE96E4805D274C40
78265	18062	49.558095999999999	49.583249000000002	56.248491000000001	56.231377999999999	Советская	0103000020E61000000100000005000000A30392B06FC74840C78157CB9D1D4C40A30392B06FC74840D82C978DCE1F4C405D363AE7A7CA4840D82C978DCE1F4C405D363AE7A7CA4840C78157CB9D1D4C40A30392B06FC74840C78157CB9D1D4C40
78800	17174	49.257897	49.276654000000001	56.231952999999997	56.210932999999997	Большая	0103000020E61000000100000005000000465ED6C402A14840D65240DAFF1A4C40465ED6C402A14840C39ACAA2B01D4C405F27F56569A34840C39ACAA2B01D4C405F27F56569A34840D65240DAFF1A4C40465ED6C402A14840D65240DAFF1A4C40
75309	16979	49.430444999999999	49.467357	56.267896999999998	56.241404000000003	Советская	0103000020E6100000010000000500000005DD5ED218B74840D28F8653E61E4C4005DD5ED218B7484027D9EA724A224C404147AB5AD2BB484027D9EA724A224C404147AB5AD2BB4840D28F8653E61E4C4005DD5ED218B74840D28F8653E61E4C40
78824	18073	49.590381000000001	49.616424000000002	56.215608000000003	56.203381999999998	Ирек	0103000020E610000001000000050000000397C79A91CB48402B4CDF6B081A4C400397C79A91CB4840C460FE0A991B4C40193C4CFBE6CE4840C460FE0A991B4C40193C4CFBE6CE48402B4CDF6B081A4C400397C79A91CB48402B4CDF6B081A4C40
78767	16926	49.970790999999998	49.994039000000001	55.993746000000002	55.979742000000002	Центральная	0103000020E61000000100000005000000252026E142FC48404242942F68FD4B40252026E142FC4840F243A51133FF4B406AF981AB3CFF4840F243A51133FF4B406AF981AB3CFF48404242942F68FD4B40252026E142FC48404242942F68FD4B40
78258	16779	49.862535000000001	49.890203	56.397120999999999	56.384509999999999	Школьная	0103000020E61000000100000005000000E353008C67EE4840137EA99F37314C40E353008C67EE484004C765DCD4324C408AE6012CF2F1484004C765DCD4324C408AE6012CF2F14840137EA99F37314C40E353008C67EE4840137EA99F37314C40
78711	14527	49.700029999999998	49.720762999999998	56.484695000000002	56.470134000000002	Гагарина	0103000020E61000000100000005000000041C42959AD948406C5ED5592D3C4C40041C42959AD9484072C45A7C0A3E4C405B9544F641DC484072C45A7C0A3E4C405B9544F641DC48406C5ED5592D3C4C40041C42959AD948406C5ED5592D3C4C40
78713	14575	49.668140000000001	49.684694999999998	56.497813999999998	56.481872000000003	Х.Такташа	0103000020E6100000010000000500000021938C9C85D54840D76D50FBAD3D4C4021938C9C85D54840D7BE805EB83F4C400B5EF415A4D74840D7BE805EB83F4C400B5EF415A4D74840D76D50FBAD3D4C4021938C9C85D54840D76D50FBAD3D4C40
78741	15782	49.792465999999997	49.810899999999997	55.968952000000002	55.952772000000003	Советская	0103000020E610000001000000050000009198A0866FE54840B345D26EF4F94B409198A0866FE5484068B27F9E06FC4B40C7293A92CBE7484068B27F9E06FC4B40C7293A92CBE74840B345D26EF4F94B409198A0866FE54840B345D26EF4F94B40
78764	16880	49.821446000000002	49.846544999999999	56.409199999999998	56.393818000000003	Свердлова	0103000020E610000001000000050000000BB77C2425E94840BF49D3A068324C400BB77C2425E94840F8C264AA60344C40D1CB28965BEC4840F8C264AA60344C40D1CB28965BEC4840BF49D3A068324C400BB77C2425E94840BF49D3A068324C40
79352	14076	50.010199999999998	50.029074000000001	56.364505999999999	56.353585000000002	Комсомольская	0103000020E61000000100000005000000A835CD3B4E01494097ADF545422D4C40A835CD3B4E0149400F99F221A82E4C40FB9463B2B80349400F99F221A82E4C40FB9463B2B803494097ADF545422D4C40A835CD3B4E01494097ADF545422D4C40
78717	14870	49.798242999999999	49.814044000000003	56.185903000000003	56.174109000000001	Тукая	0103000020E6100000010000000500000066A19DD32CE648403A78263449164C4066A19DD32CE64840399D64ABCB174C40A5C0029832E84840399D64ABCB174C40A5C0029832E848403A78263449164C4066A19DD32CE648403A78263449164C40
78758	16576	49.649661000000002	49.668489999999998	56.159328000000002	56.146391999999999	Кооперативная	0103000020E610000001000000050000004B3E761728D34840B1321AF9BC124C404B3E761728D3484026AB22DC64144C40FDD98F1491D5484026AB22DC64144C40FDD98F1491D54840B1321AF9BC124C404B3E761728D34840B1321AF9BC124C40
79346	16259	49.901269999999997	50.012130999999997	56.306583000000003	56.223225999999997	Садовая	0103000020E61000000100000005000000D66EBBD05CF34840F6CE68AB921C4C40D66EBBD05CF348403A419B1C3E274C40462234828D0149403A419B1C3E274C40462234828D014940F6CE68AB921C4C40D66EBBD05CF34840F6CE68AB921C4C40
11266	18510	49.909993	49.947434999999999	56.085605999999999	56.076467999999998	Ленина	0103000020E61000000100000005000000624B8FA67AF44840639813B4C9094C40624B8FA67AF44840B22B2D23F50A4C40FA0AD28C45F94840B22B2D23F50A4C40FA0AD28C45F94840639813B4C9094C40624B8FA67AF44840639813B4C9094C40
79310	61526	50.212778999999998	50.233009000000003	56.202446000000002	56.195219999999999	Ленина	0103000020E6100000010000000500000046239F573C1B494037C30DF8FC184C4046239F573C1B49405F9A22C0E9194C403B56293DD31D49405F9A22C0E9194C403B56293DD31D494037C30DF8FC184C4046239F573C1B494037C30DF8FC184C40
78707	14435	49.635027999999998	49.656101999999997	56.402346000000001	56.388520999999997	Советская	0103000020E61000000100000005000000AB05F69848D1484094675E0EBB314C40AB05F69848D1484095D6DF1280334C408B6B7C26FBD3484095D6DF1280334C408B6B7C26FBD3484094675E0EBB314C40AB05F69848D1484094675E0EBB314C40
78726	15450	49.815966000000003	49.830455999999998	56.232357999999998	56.222821000000003	М.Джалиля	0103000020E61000000100000005000000F052EA9271E8484057EE0566851C4C40F052EA9271E84840637B2DE8BD1D4C402C62D8614CEA4840637B2DE8BD1D4C402C62D8614CEA484057EE0566851C4C40F052EA9271E8484057EE0566851C4C40
79308	15396	49.887203	49.913164000000002	56.203381999999998	56.189194000000001	Молодежная	0103000020E61000000100000005000000E0F42EDE8FF14840BA4C4D8237184C40E0F42EDE8FF148402B4CDF6B081A4C4039F1D58EE2F448402B4CDF6B081A4C4039F1D58EE2F44840BA4C4D8237184C40E0F42EDE8FF14840BA4C4D8237184C40
78721	14723	49.625532	49.653272000000001	56.255968000000003	56.245595000000002	Г.Сафиуллина	0103000020E61000000100000005000000FD4CBD6E11D04840D3872EA86F1F4C40FD4CBD6E11D048404969368FC3204C403EB2B96A9ED348404969368FC3204C403EB2B96A9ED34840D3872EA86F1F4C40FD4CBD6E11D04840D3872EA86F1F4C40
79317	16160	49.654269999999997	49.675021000000001	56.354621999999999	56.341327999999997	Школьная 	0103000020E6100000010000000500000080608E1EBFD34840C39ACAA2B02B4C4080608E1EBFD348409738F240642D4C407E8E8F1667D648409738F240642D4C407E8E8F1667D64840C39ACAA2B02B4C4080608E1EBFD34840C39ACAA2B02B4C40
78754	16555	49.957836999999998	49.972372	56.202821999999998	56.194477999999997	Школьная	0103000020E610000001000000050000000AF31E679AFA48404FE5B4A7E4184C400AF31E679AFA484064744012F6194C40E7C589AF76FC484064744012F6194C40E7C589AF76FC48404FE5B4A7E4184C400AF31E679AFA48404FE5B4A7E4184C40
79309	15678	49.715580000000003	49.740589	56.033484999999999	56.022714999999998	Школьная	0103000020E61000000100000005000000FAD51C2098DB484077103B53E8024C40FAD51C2098DB48400AF4893C49044C408063CF9ECBDE48400AF4893C49044C408063CF9ECBDE484077103B53E8024C40FAD51C2098DB484077103B53E8024C40
78734	15286	49.572046999999998	49.591315999999999	56.114680999999997	56.098877999999999	Центральная	0103000020E6100000010000000500000030630AD638C948409E25C808A80C4C4030630AD638C948407D3CF4DDAD0E4C40FFCC203EB0CB48407D3CF4DDAD0E4C40FFCC203EB0CB48409E25C808A80C4C4030630AD638C948409E25C808A80C4C40
78254	15289	50.039943000000001	50.059176000000001	56.104391	56.095593999999998	Молодежная	0103000020E61000000100000005000000215A2BDA1C054940CFD8976C3C0C4C40215A2BDA1C054940957F2DAF5C0D4C40A35A441493074940957F2DAF5C0D4C40A35A441493074940CFD8976C3C0C4C40215A2BDA1C054940CFD8976C3C0C4C40
79292	16367	49.934562	49.966470000000001	56.253447000000001	56.241439	Вахитова	0103000020E61000000100000005000000CC0A45BA9FF748404E7D2079E71E4C40CC0A45BA9FF74840792288F370204C405648F949B5FB4840792288F370204C405648F949B5FB48404E7D2079E71E4C40CC0A45BA9FF748404E7D2079E71E4C40
78252	15096	50.089288000000003	50.114457999999999	56.113526999999998	56.100273999999999	Школьная	0103000020E610000001000000050000006FF607CA6D0B4940CE5147C7D50C4C406FF607CA6D0B4940431B800D880E4C40FE614B8FA60E4940431B800D880E4C40FE614B8FA60E4940CE5147C7D50C4C406FF607CA6D0B4940CE5147C7D50C4C40
78724	15094	50.124150999999998	50.143796999999999	56.170225000000002	56.158380999999999	Школьная	0103000020E610000001000000050000000262122EE40F494065A71FD445144C400262122EE40F494016FBCBEEC9154C40A721AAF06712494016FBCBEEC9154C40A721AAF06712494065A71FD445144C400262122EE40F494065A71FD445144C40
79306	15010	50.189638000000002	50.206122999999998	56.184936	56.173633000000002	Школьная	0103000020E61000000100000005000000180AD80E46184940D1402C9B39164C40180AD80E4618494031ED9BFBAB174C4009FA0B3D621A494031ED9BFBAB174C4009FA0B3D621A4940D1402C9B39164C40180AD80E46184940D1402C9B39164C40
79282	13967	49.973090999999997	50.003785999999998	56.419840999999998	56.408696999999997	Чапаева 	0103000020E610000001000000050000001684F23E8EFC4840957CEC2E50344C401684F23E8EFC48408D429259BD354C406117450F7C0049408D429259BD354C406117450F7C004940957CEC2E50344C401684F23E8EFC4840957CEC2E50344C40
79298	16788	49.905330999999997	49.931381999999999	56.433574999999998	56.421843000000003	Татарстана	0103000020E610000001000000050000000987DEE2E1F34840F58590F3FE354C400987DEE2E1F348407DAEB6627F374C40A20A7F8637F748407DAEB6627F374C40A20A7F8637F74840F58590F3FE354C400987DEE2E1F34840F58590F3FE354C40
78248	14827	49.784849000000001	49.802230999999999	56.282339999999998	56.260038000000002	Центральная	0103000020E610000001000000050000002FA699EE75E44840CFDBD8EC48214C402FA699EE75E44840232D95B723244C402F6B6281AFE64840232D95B723244C402F6B6281AFE64840CFDBD8EC48214C402FA699EE75E44840CFDBD8EC48214C40
79329	14643	49.650388999999997	49.678991000000003	56.268695999999998	56.252186999999999	Новая	0103000020E61000000100000005000000CD565EF23FD34840F9BCE2A947204C40CD565EF23FD3484073486AA164224C40A1A3552DE9D6484073486AA164224C40A1A3552DE9D64840F9BCE2A947204C40CD565EF23FD34840F9BCE2A947204C40
78246	13862	49.687821999999997	49.735998000000002	56.410893000000002	56.385899999999999	Советская	0103000020E6100000010000000500000012BC218D0AD8484061C3D32B65314C4012BC218D0AD84840E2934E2498344C40F1F5B52E35DE4840E2934E2498344C40F1F5B52E35DE484061C3D32B65314C4012BC218D0AD8484061C3D32B65314C40
78782	17065	49.612633000000002	49.625613000000001	56.489933000000001	56.482298999999998	Советская	0103000020E61000000100000005000000A6B915C26ACE48405EF23FF9BB3D4C40A6B915C26ACE4840971DE21FB63E4C40EA79371614D04840971DE21FB63E4C40EA79371614D048405EF23FF9BB3D4C40A6B915C26ACE48405EF23FF9BB3D4C40
78699	14437	49.594765000000002	49.619855000000001	56.406854000000003	56.396956000000003	Кирова	0103000020E6100000010000000500000019E76F4221CC4840BAF94674CF324C4019E76F4221CC4840971FB8CA13344C408CA19C6857CF4840971FB8CA13344C408CA19C6857CF4840BAF94674CF324C4019E76F4221CC4840BAF94674CF324C40
78747	15505	49.896625999999998	49.925407999999997	56.146918999999997	56.133808000000002	Центральная	0103000020E61000000100000005000000245F09A4C4F24840BAF8DB9E20114C40245F09A4C4F248409C14E63DCE124C4077BAF3C473F648409C14E63DCE124C4077BAF3C473F64840BAF8DB9E20114C40245F09A4C4F24840BAF8DB9E20114C40
78253	15210	49.679341999999998	49.703183000000003	56.124431000000001	56.115273000000002	Центральная	0103000020E610000001000000050000004D66BCADF4D64840508E0244C10E4C404D66BCADF4D64840E6CDE15AED0F4C40350D8AE601DA4840E6CDE15AED0F4C40350D8AE601DA4840508E0244C10E4C404D66BCADF4D64840508E0244C10E4C40
79319	14243	49.725254	49.750954999999998	56.121110000000002	56.106524	Молодежная	0103000020E6100000010000000500000087A5811FD5DC48409B1E1494A20D4C4087A5811FD5DC4840FA9B5088800F4C4043E21E4B1FE04840FA9B5088800F4C4043E21E4B1FE048409B1E1494A20D4C4087A5811FD5DC48409B1E1494A20D4C40
79285	15590	49.894101999999997	49.916254000000002	56.178708999999998	56.16395	Татарстан	0103000020E61000000100000005000000E3A430EF71F24840F0164850FC144C40E3A430EF71F248401C40BFEFDF164C40236AA2CF47F548401C40BFEFDF164C40236AA2CF47F54840F0164850FC144C40E3A430EF71F24840F0164850FC144C40
9893	14823	49.646903000000002	49.676259999999999	56.289434999999997	56.266992000000002	Мостовая	0103000020E610000001000000050000009757AEB7CDD2484096253ACB2C224C409757AEB7CDD24840ACA8C1340C254C40E6CB0BB08FD64840ACA8C1340C254C40E6CB0BB08FD6484096253ACB2C224C409757AEB7CDD2484096253ACB2C224C40
79295	15586	49.551206000000001	49.569558000000001	56.165157999999998	56.154559999999996	Тукая	0103000020E61000000100000005000000F3AD0FEB8DC6484087A2409FC8134C40F3AD0FEB8DC648401D56B8E523154C406C96CB46E7C848401D56B8E523154C406C96CB46E7C8484087A2409FC8134C40F3AD0FEB8DC6484087A2409FC8134C40
78245	14151	49.791164000000002	49.825443999999997	56.070247999999999	56.052497000000002	Центральная	0103000020E61000000100000005000000E3E2A8DC44E54840AE11C138B8064C40E3E2A8DC44E54840014EEFE2FD084C40F7562426A8E94840014EEFE2FD084C40F7562426A8E94840AE11C138B8064C40E3E2A8DC44E54840AE11C138B8064C40
78256	16469	49.964781000000002	49.989035999999999	56.163212999999999	56.14575	Кирова	0103000020E61000000100000005000000AE669DF17DFB48402DB29DEFA7124C40AE669DF17DFB48401AA4E029E4144C4088484DBB98FE48401AA4E029E4144C4088484DBB98FE48402DB29DEFA7124C40AE669DF17DFB48402DB29DEFA7124C40
78725	14929	49.797587	49.813854999999997	56.161924999999997	56.153131000000002	Мостовая	0103000020E610000001000000050000007D5BB05417E648407C80EECB99134C407D5BB05417E64840D0B359F5B9144C40D15790662CE84840D0B359F5B9144C40D15790662CE848407C80EECB99134C407D5BB05417E648407C80EECB99134C40
78761	16621	49.687911	49.705348000000001	56.155358	56.140960999999997	Кооперативная	0103000020E6100000010000000500000082C7B7770DD84840778192020B124C4082C7B7770DD8484003965CC5E2134C404626E0D748DA484003965CC5E2134C404626E0D748DA4840778192020B124C4082C7B7770DD84840778192020B124C40
78965	15865	49.899959000000003	49.911493	55.965234000000002	55.956798999999997	Школьная	0103000020E61000000100000005000000D55E44DB31F3484039ECBE6378FA4B40D55E44DB31F348405F7EA7C98CFB4B4037C478CDABF448405F7EA7C98CFB4B4037C478CDABF4484039ECBE6378FA4B40D55E44DB31F3484039ECBE6378FA4B40
79195	61450	49.731597000000001	49.756525000000003	56.516437000000003	56.497526000000001	Тукая	0103000020E61000000100000005000000056D72F8A4DD4840717495EEAE3F4C40056D72F8A4DD4840E1B88C9B1A424C409FCDAACFD5E04840E1B88C9B1A424C409FCDAACFD5E04840717495EEAE3F4C40056D72F8A4DD4840717495EEAE3F4C40
79336	15971	49.755572999999998	49.793086000000002	56.338259999999998	56.313442999999999	Пионерская	0103000020E61000000100000005000000CC5EB69DB6E048407F1475E61E284C40CC5EB69DB6E04840C1C58A1A4C2B4C402E7590D783E54840C1C58A1A4C2B4C402E7590D783E548407F1475E61E284C40CC5EB69DB6E048407F1475E61E284C40
75238	13111	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Школьная	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
78243	13111	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Цветочная	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
75308	13111	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Трудовая	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
75306	13111	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Мостовая	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
78239	13111	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Комсомольская	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
75239	13111	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Галактионова	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
68546	13111	49.850560000000002	49.908645	56.109481000000002	56.063997000000001	Банковская	0103000020E6100000010000000500000094A46B26DFEC48406405BF0D31084C4094A46B26DFEC484046443179030E4C404356B77A4EF4484046443179030E4C404356B77A4EF448406405BF0D31084C4094A46B26DFEC48406405BF0D31084C40
79300	13864	49.972318000000001	49.988928000000001	56.395048000000003	56.381774	Советская	0103000020E61000000100000005000000F4A78DEA74FC4840473B6EF8DD304C40F4A78DEA74FC4840D42CD0EE90324C40A20C553195FE4840D42CD0EE90324C40A20C553195FE4840473B6EF8DD304C40F4A78DEA74FC4840473B6EF8DD304C40
78789	61361	49.851477000000003	49.871617000000001	56.337420999999999	56.329371999999999	Школьная	0103000020E61000000100000005000000EA25C632FDEC4840EB1B98DC282A4C40EA25C632FDEC4840E7FD7F9C302B4C409ED1562591EF4840E7FD7F9C302B4C409ED1562591EF4840EB1B98DC282A4C40EA25C632FDEC4840EB1B98DC282A4C40
78634	11098	48.688580999999999	48.719437999999997	55.318587999999998	55.304395	Подгорная	0103000020E61000000100000005000000D0D2156C235848407008556AF6A64B40D0D2156C23584840F372D87DC7A84B40F4BF5C8B165C4840F372D87DC7A84B40F4BF5C8B165C48407008556AF6A64B40D0D2156C235848407008556AF6A64B40
78697	13021	48.358575000000002	48.382686	55.265466000000004	55.254660999999999	Х.Такташа	0103000020E61000000100000005000000E4141DC9E52D484088484DBB98A04B40E4141DC9E52D4840981936CAFAA14B408B51D7DAFB304840981936CAFAA14B408B51D7DAFB30484088484DBB98A04B40E4141DC9E52D484088484DBB98A04B40
79332	11143	48.571719000000002	48.601291000000003	55.284399999999998	55.266615000000002	Завражная	0103000020E610000001000000050000003CC093162E494840C0CFB87020A24B403CC093162E494840BF7D1D3867A44B4088307E1AF74C4840BF7D1D3867A44B4088307E1AF74C4840C0CFB87020A24B403CC093162E494840C0CFB87020A24B40
78644	12146	48.511020000000002	48.526784999999997	55.370789000000002	55.361989000000001	Клубная	0103000020E610000001000000050000000CCD751A694148408141D2A755AE4B400CCD751A69414840B85B920376AF4B40FD82DDB06D434840B85B920376AF4B40FD82DDB06D4348408141D2A755AE4B400CCD751A694148408141D2A755AE4B40
78687	12345	48.230241999999997	48.253490999999997	55.214959	55.203668	Центральная	0103000020E610000001000000050000003315E291781D4840F19E03CB119A4B403315E291781D48408D7DC9C6839B4B40486AA164722048408D7DC9C6839B4B40486AA16472204840F19E03CB119A4B403315E291781D4840F19E03CB119A4B40
78695	12896	48.400841	48.424117000000003	55.301966	55.288305999999999	Г.Тукая	0103000020E61000000100000005000000AEF204C24E334840CB9E0436E7A44B40AEF204C24E334840814067D2A6A64B40BD56427749364840814067D2A6A64B40BD56427749364840CB9E0436E7A44B40AEF204C24E334840CB9E0436E7A44B40
79164	61428	48.004854999999999	48.852694	55.435395999999997	55.101401000000003	Гагарина	0103000020E610000001000000050000006D1CB1169F0048400F643DB5FA8C4B406D1CB1169F00484094675E0EBBB74B406ABFB513256D484094675E0EBBB74B406ABFB513256D48400F643DB5FA8C4B406D1CB1169F0048400F643DB5FA8C4B40
79175	61436	48.095576000000001	48.129550000000002	55.267609999999998	55.252501000000002	Вахитова	0103000020E61000000100000005000000292499D53B0C4840899AE8F351A04B40292499D53B0C4840910A630B41A24B4031992A1895104840910A630B41A24B4031992A1895104840899AE8F351A04B40292499D53B0C4840899AE8F351A04B40
78804	61362	48.210120000000003	48.235514999999999	55.173267000000003	55.167138000000001	Татарстан	0103000020E61000000100000005000000261E5036E51A48409DF529C764954B40261E5036E51A4840EF3CF19C2D964B40D55B035B251E4840EF3CF19C2D964B40D55B035B251E48409DF529C764954B40261E5036E51A48409DF529C764954B40
78662	11515	48.522841	48.545003000000001	55.323822999999997	55.316201	Ленина	0103000020E6100000010000000500000004013274EC42484033FB3C4679A84B4004013274EC424840A758350873A94B40679C86A8C2454840A758350873A94B40679C86A8C245484033FB3C4679A84B4004013274EC42484033FB3C4679A84B40
78870	12588	48.433926	48.452728	55.127425000000002	55.114666999999997	Ленина	0103000020E610000001000000050000002A711DE38A37484018778368AD8E4B402A711DE38A374840AED85F764F904B40E3FDB8FDF2394840AED85F764F904B40E3FDB8FDF239484018778368AD8E4B402A711DE38A37484018778368AD8E4B40
78692	12648	48.122633	48.139845000000001	55.190041000000001	55.175164000000002	С.Ахтямова	0103000020E6100000010000000500000087342A70B20F4840E1B721C66B964B4087342A70B20F484017F3734353984B402BC1E270E611484017F3734353984B402BC1E270E6114840E1B721C66B964B4087342A70B20F4840E1B721C66B964B40
78694	12855	48.597670999999998	48.615251000000001	55.203384999999997	55.192245	Советская	0103000020E610000001000000050000004162BB7B804C4840E6E8F17B9B984B404162BB7B804C48409CBF0985089A4B4068EA758BC04E48409CBF0985089A4B4068EA758BC04E4840E6E8F17B9B984B404162BB7B804C4840E6E8F17B9B984B40
78689	12533	48.440753000000001	48.455486000000001	55.166218000000001	55.149290000000001	Молодежная	0103000020E61000000100000005000000944E24986A38484057CF49EF1B934B40944E24986A384840D600A5A146954B4097E4805D4D3A4840D600A5A146954B4097E4805D4D3A484057CF49EF1B934B40944E24986A38484057CF49EF1B934B40
79135	61404	48.580289	48.602558000000002	55.141222999999997	55.126888999999998	Вахитова	0103000020E61000000100000005000000419DF2E8464A48406F9C14E63D904B40419DF2E8464A4840B438639813924B40BAF8DB9E204D4840B438639813924B40BAF8DB9E204D48406F9C14E63D904B40419DF2E8464A48406F9C14E63D904B40
78627	10552	48.519482000000004	48.540196999999999	55.193714999999997	55.178094999999999	Советская	0103000020E610000001000000050000002B6EDC627E424840624A24D1CB964B402B6EDC627E42484050DF32A7CB984B40DB32E02C2545484050DF32A7CB984B40DB32E02C25454840624A24D1CB964B402B6EDC627E424840624A24D1CB964B40
78672	12102	48.291929000000003	48.305439999999997	55.184545999999997	55.176819999999999	Амира Сабирова	0103000020E6100000010000000500000083E0F1ED5D254840ADA3AA09A2964B4083E0F1ED5D254840C64D0D349F974B40F3716DA818274840C64D0D349F974B40F3716DA818274840ADA3AA09A2964B4083E0F1ED5D254840ADA3AA09A2964B40
78700	13028	48.280593000000003	48.309060000000002	55.298589	55.288136999999999	Островского	0103000020E61000000100000005000000473EAF78EA2348403FE257ACE1A44B40473EAF78EA23484001F9122A38A64B403A4030478F27484001F9122A38A64B403A4030478F2748403FE257ACE1A44B40473EAF78EA2348403FE257ACE1A44B40
78677	12264	48.265312000000002	48.292566999999998	55.234414999999998	55.218995	50 лет Победы	0103000020E61000000100000005000000419E5DBEF5214840677E3507089C4B40419E5DBEF52148408E588B4F019E4B40C571E0D5722548408E588B4F019E4B40C571E0D572254840677E3507089C4B40419E5DBEF5214840677E3507089C4B40
78663	11848	48.437474999999999	48.461027999999999	55.239049999999999	55.224947	Заводская	0103000020E61000000100000005000000A7E8482EFF374840AA2A3410CB9C4B40A7E8482EFF374840ED0DBE30999E4B4028452BF7023B4840ED0DBE30999E4B4028452BF7023B4840AA2A3410CB9C4B40A7E8482EFF374840AA2A3410CB9C4B40
78964	12143	48.447940000000003	48.474440000000001	55.385325999999999	55.373654000000002	Центральная	0103000020E61000000100000005000000FE481119563948408202EFE4D3AF4B40FE481119563948403526C45C52B14B4006F52D73BA3C48403526C45C52B14B4006F52D73BA3C48408202EFE4D3AF4B40FE481119563948408202EFE4D3AF4B40
78698	12939	48.315277000000002	48.335093999999998	55.291074999999999	55.281922999999999	Г.Тукая	0103000020E610000001000000050000002B172AFF5A284840BF7E880D16A44B402B172AFF5A28484073D712F241A54B40FC8A355CE42A484073D712F241A54B40FC8A355CE42A4840BF7E880D16A44B402B172AFF5A284840BF7E880D16A44B40
78696	11847	48.368609999999997	48.377090000000003	55.246256000000002	55.240862	Татарстана	0103000020E61000000100000005000000417DCB9C2E2F4840B16CE690D49E4B40417DCB9C2E2F4840CE380D51859F4B4007D3307C44304840CE380D51859F4B4007D3307C44304840B16CE690D49E4B40417DCB9C2E2F4840B16CE690D49E4B40
78632	11053	48.621845	48.645947	55.329262	55.315795999999999	Пушкина	0103000020E610000001000000050000002F17F19D984F4840931ADA006CA84B402F17F19D984F484064E8D84125AA4B4083F92B64AE52484064E8D84125AA4B4083F92B64AE524840931ADA006CA84B402F17F19D984F4840931ADA006CA84B40
78630	10967	48.756565000000002	48.782041	55.208702000000002	55.200302000000001	Школьная	0103000020E610000001000000050000002D26361FD760484065A9F57EA3994B402D26361FD76048400E4E44BFB69A4B40C99063EB196448400E4E44BFB69A4B40C99063EB1964484065A9F57EA3994B402D26361FD760484065A9F57EA3994B40
78669	11680	48.567802	48.580989000000002	55.17718	55.168377	Сунгатуллина	0103000020E610000001000000050000003C4D66BCAD4848400533A6608D954B403C4D66BCAD484840ADC090D5AD964B40FA2AF9D85D4A4840ADC090D5AD964B40FA2AF9D85D4A48400533A6608D954B403C4D66BCAD4848400533A6608D954B40
78670	11986	48.272103999999999	48.297103999999997	55.156688000000003	55.141134999999998	Хади Такташа	0103000020E610000001000000050000002E8ECA4DD422484015A930B610924B402E8ECA4DD42248407CD6355A0E944B4061C1FD80072648407CD6355A0E944B4061C1FD800726484015A930B610924B402E8ECA4DD422484015A930B610924B40
78640	11325	48.484250000000003	48.517280999999997	55.287824000000001	55.274175	Молодежная	0103000020E61000000100000005000000448B6CE7FB3D4840BE30992A18A34B40448B6CE7FB3D48408080B56AD7A44B40CCEB8843364248408080B56AD7A44B40CCEB884336424840BE30992A18A34B40448B6CE7FB3D4840BE30992A18A34B40
78660	11612	48.327907000000003	48.349494	55.154089999999997	55.144202	Просвещения	0103000020E61000000100000005000000939048DBF829484047020D3675924B40939048DBF829484000529B38B9934B40F9122A38BC2C484000529B38B9934B40F9122A38BC2C484047020D3675924B40939048DBF829484047020D3675924B40
78247	61291	48.349528999999997	48.410111999999998	55.247883000000002	55.218929000000003	Х.Такташа	0103000020E610000001000000050000007500C45DBD2C4840B0928FDD059C4B407500C45DBD2C4840001E51A1BA9F4B403CD9CD8C7E344840001E51A1BA9F4B403CD9CD8C7E344840B0928FDD059C4B407500C45DBD2C4840B0928FDD059C4B40
78675	61349	48.304271999999997	48.312742999999998	55.172978999999998	55.164437999999997	Пионерская	0103000020E61000000100000005000000548B8862F22648401D1CEC4D0C954B40548B8862F226484088F2052D24964B40C6866EF60728484088F2052D24964B40C6866EF6072848401D1CEC4D0C954B40548B8862F22648401D1CEC4D0C954B40
78668	11901	48.175409000000002	48.200149000000003	55.197533	55.180182000000002	Вахитова	0103000020E61000000100000005000000483657CD73164840F8A92A3410974B40483657CD73164840BD70E7C248994B40DFA9807B9E194840BD70E7C248994B40DFA9807B9E194840F8A92A3410974B40483657CD73164840F8A92A3410974B40
78656	11382	48.442227000000003	48.466211999999999	55.411189	55.399330999999997	Гали Хужи	0103000020E610000001000000050000004034F3E49A384840B5A338471DB34B404034F3E49A384840CBBC55D7A1B44B405A80B6D5AC3B4840CBBC55D7A1B44B405A80B6D5AC3B4840B5A338471DB34B404034F3E49A384840B5A338471DB34B40
78621	12478	48.606321999999999	48.624504000000002	55.140599999999999	55.132973	Тукая	0103000020E61000000100000005000000336C94F59B4D484021205F4205914B40336C94F59B4D4840A7E8482EFF914B40501C40BFEF4F4840A7E8482EFF914B40501C40BFEF4F484021205F4205914B40336C94F59B4D484021205F4205914B40
78679	12253	48.545667999999999	48.576245999999998	55.345134999999999	55.334080999999998	Школьная	0103000020E61000000100000005000000A33CF372D8454840849B8C2AC3AA4B40A33CF372D84548403CDA38622DAC4B40B439CE6DC24948403CDA38622DAC4B40B439CE6DC2494840849B8C2AC3AA4B40A33CF372D8454840849B8C2AC3AA4B40
79221	61472	48.004854999999999	48.852694	55.435395999999997	55.101401000000003	Вахитова	0103000020E610000001000000050000006D1CB1169F0048400F643DB5FA8C4B406D1CB1169F00484094675E0EBBB74B406ABFB513256D484094675E0EBBB74B406ABFB513256D48400F643DB5FA8C4B406D1CB1169F0048400F643DB5FA8C4B40
78661	11570	48.344408999999999	48.369508000000003	55.186062	55.164351000000003	Ленина	0103000020E610000001000000050000005AB91798152C48404F081D7409954B405AB91798152C4840A1832EE1D0974B4021CEC3094C2F4840A1832EE1D0974B4021CEC3094C2F48404F081D7409954B405AB91798152C48404F081D7409954B40
78951	10866	48.353940000000001	48.381923	55.221829999999997	55.20711	Молодежная	0103000020E61000000100000005000000855FEAE74D2D484058569A94829A4B40855FEAE74D2D4840C6A2E9EC649C4B408C4B55DAE2304840C6A2E9EC649C4B408C4B55DAE230484058569A94829A4B40855FEAE74D2D484058569A94829A4B40
78655	11468	48.471637000000001	48.489576999999997	55.308115999999998	55.297696999999999	Тукая	0103000020E61000000100000005000000B24AE9995E3C4840048F6FEF1AA64B40B24AE9995E3C4840EAAF575870A74B40D8EF8975AA3E4840EAAF575870A74B40D8EF8975AA3E4840048F6FEF1AA64B40B24AE9995E3C4840048F6FEF1AA64B40
78684	12339	48.236944000000001	48.271816000000001	55.242997000000003	55.235272000000002	Советская	0103000020E61000000100000005000000E17D552E541E48400FD594641D9E4B40E17D552E541E4840580394861A9F4B40C843DFDDCA224840580394861A9F4B40C843DFDDCA2248400FD594641D9E4B40E17D552E541E48400FD594641D9E4B40
78846	7757	48.758982000000003	48.781646000000002	55.245358000000003	55.233880999999997	Советская	0103000020E6100000010000000500000058207A5226614840F01307D0EF9D4B4058207A5226614840EFE714E4679F4B404D86E3F90C644840EFE714E4679F4B404D86E3F90C644840F01307D0EF9D4B4058207A5226614840F01307D0EF9D4B40
78638	11225	48.475779000000003	48.493071	55.263931999999997	55.251721000000003	Мечеть	0103000020E61000000100000005000000D28F8653E63C4840B45BCB6438A04B40D28F8653E63C4840162F1686C8A14B4092CD55F31C3F4840162F1686C8A14B4092CD55F31C3F4840B45BCB6438A04B40D28F8653E63C4840B45BCB6438A04B40
78643	11006	48.635041000000001	48.669975999999998	55.313803	55.304267000000003	Ленина	0103000020E61000000100000005000000404F03064951484043209738F2A64B40404F0306495148407F315BB22AA84B406D8D08C6C15548407F315BB22AA84B406D8D08C6C155484043209738F2A64B40404F03064951484043209738F2A64B40
78666	10921	48.798786	48.819609	55.231800999999997	55.216576000000003	Советская	0103000020E610000001000000050000005740A19E3E6648409C8C2AC3B89B4B405740A19E3E6648400D17B9A7AB9D4B40EE409DF2E86848400D17B9A7AB9D4B40EE409DF2E86848409C8C2AC3B89B4B405740A19E3E6648409C8C2AC3B89B4B40
78641	10793	48.427107999999997	48.437159999999999	55.234281000000003	55.224038	Ленина	0103000020E6100000010000000500000013EE9579AB364840D787F546AD9C4B4013EE9579AB3648407F8978EBFC9D4B40478FDFDBF43748407F8978EBFC9D4B40478FDFDBF4374840D787F546AD9C4B4013EE9579AB364840D787F546AD9C4B40
78955	9630	48.187185999999997	48.215465000000002	55.256323999999999	55.242159999999998	Центральная	0103000020E610000001000000050000007022FAB5F51748401E335019FF9E4B407022FAB5F517484007978E39CFA04B4061376C5B941B484007978E39CFA04B4061376C5B941B48401E335019FF9E4B407022FAB5F51748401E335019FF9E4B40
10248	9630	48.187185999999997	48.215465000000002	55.256323999999999	55.242159999999998	Советская	0103000020E610000001000000050000007022FAB5F51748401E335019FF9E4B407022FAB5F517484007978E39CFA04B4061376C5B941B484007978E39CFA04B4061376C5B941B48401E335019FF9E4B407022FAB5F51748401E335019FF9E4B40
79209	61462	48.080959999999997	48.101145000000002	55.281517999999998	55.268605000000001	Зеленая	0103000020E610000001000000050000005F24B4E55C0A484063450DA661A24B405F24B4E55C0A48401F9E25C808A44B40B493C151F20C48401F9E25C808A44B40B493C151F20C484063450DA661A24B405F24B4E55C0A484063450DA661A24B40
79196	61451	48.004854999999999	48.852694	55.435395999999997	55.101401000000003	Центральная	0103000020E610000001000000050000006D1CB1169F0048400F643DB5FA8C4B406D1CB1169F00484094675E0EBBB74B406ABFB513256D484094675E0EBBB74B406ABFB513256D48400F643DB5FA8C4B406D1CB1169F0048400F643DB5FA8C4B40
78233	10343	48.484313	48.533298000000002	55.211497000000001	55.192101000000001	Советская	0103000020E610000001000000050000008A03E8F7FD3D4840B343FCC396984B408A03E8F7FD3D4840DF196D55129B4B40D882DE1B43444840DF196D55129B4B40D882DE1B43444840B343FCC396984B408A03E8F7FD3D4840B343FCC396984B40
68526	10343	48.484313	48.533298000000002	55.211497000000001	55.192101000000001	Красноармейская	0103000020E610000001000000050000008A03E8F7FD3D4840B343FCC396984B408A03E8F7FD3D4840DF196D55129B4B40D882DE1B43444840DF196D55129B4B40D882DE1B43444840B343FCC396984B408A03E8F7FD3D4840B343FCC396984B40
79288	10343	48.484313	48.533298000000002	55.211497000000001	55.192101000000001	Заводская	0103000020E610000001000000050000008A03E8F7FD3D4840B343FCC396984B408A03E8F7FD3D4840DF196D55129B4B40D882DE1B43444840DF196D55129B4B40D882DE1B43444840B343FCC396984B408A03E8F7FD3D4840B343FCC396984B40
78224	10343	48.484313	48.533298000000002	55.211497000000001	55.192101000000001	Гагарина	0103000020E610000001000000050000008A03E8F7FD3D4840B343FCC396984B408A03E8F7FD3D4840DF196D55129B4B40D882DE1B43444840DF196D55129B4B40D882DE1B43444840B343FCC396984B408A03E8F7FD3D4840B343FCC396984B40
79312	10608	48.714424999999999	48.732688000000003	55.261198	55.251721000000003	Победа	0103000020E61000000100000005000000EF384547725B4840B45BCB6438A04B40EF384547725B4840EBE3A1EF6EA14B40F9156BB8C85D4840EBE3A1EF6EA14B40F9156BB8C85D4840B45BCB6438A04B40EF384547725B4840B45BCB6438A04B40
78784	25756	48.700240999999998	48.716724999999997	55.277087999999999	55.268917999999999	Ленина	0103000020E61000000100000005000000BF28417FA159484022A7AFE76BA24B40BF28417FA1594840990E9D9E77A34B40E09C11A5BD5B4840990E9D9E77A34B40E09C11A5BD5B484022A7AFE76BA24B40BF28417FA159484022A7AFE76BA24B40
78651	11370	48.523972999999998	48.542909999999999	55.426093999999999	55.406702000000003	Октябрьская	0103000020E61000000100000005000000567E198C11434840E19BA6CF0EB44B40567E198C11434840CB82893F8AB64B40EF552B137E454840CB82893F8AB64B40EF552B137E454840E19BA6CF0EB44B40567E198C11434840E19BA6CF0EB44B40
78216	9889	51.587561000000001	51.624850000000002	55.129128000000001	55.100551000000003	Советская	0103000020E61000000100000005000000D9B3E73235CB4940414AECDADE8C4B40D9B3E73235CB4940BB7F2C4487904B40EB73B515FBCF4940BB7F2C4487904B40EB73B515FBCF4940414AECDADE8C4B40D9B3E73235CB4940414AECDADE8C4B40
78959	10004	52.164648	52.193860999999998	55.040446000000003	55.027985000000001	Советская	0103000020E6100000010000000500000008AD872F13154A40A8E3310395834B4008AD872F13154A4084A0A3552D854B40247CEF6FD0184A4084A0A3552D854B40247CEF6FD0184A40A8E3310395834B4008AD872F13154A40A8E3310395834B40
78185	8647	52.122463000000003	52.146887999999997	54.803164000000002	54.787188	Кирова	0103000020E610000001000000050000002BFC19DEAC0F4A40DEE68D93C2644B402BFC19DEAC0F4A408BA9F413CE664B406116DA39CD124A408BA9F413CE664B406116DA39CD124A40DEE68D93C2644B402BFC19DEAC0F4A40DEE68D93C2644B40
78950	9310	51.680078000000002	51.701279	54.934877999999998	54.924635000000002	Центральная	0103000020E61000000100000005000000535DC0CB0CD7494055DE8E705A764B40535DC0CB0CD74940FCDF1115AA774B40902FA182C3D94940FCDF1115AA774B40902FA182C3D9494055DE8E705A764B40535DC0CB0CD7494055DE8E705A764B40
78691	61355	52.639460999999997	52.672823999999999	55.006745000000002	54.995626999999999	Ахмадуллина	0103000020E61000000100000005000000A208A9DBD9514A40DE019EB4707F4B40A208A9DBD9514A40AD342905DD804B4061FBC9181F564A40AD342905DD804B4061FBC9181F564A40DE019EB4707F4B40A208A9DBD9514A40DE019EB4707F4B40
78211	9793	52.489486999999997	52.520273000000003	54.807107999999999	54.790942000000001	Ленина	0103000020E6100000010000000500000098689082A73E4A40348463963D654B4098689082A73E4A40842BA0504F674B40F4FE3F4E98424A40842BA0504F674B40F4FE3F4E98424A40348463963D654B4098689082A73E4A40348463963D654B40
79314	9583	52.601973999999998	52.634943	54.998179	54.986319999999999	Заречная	0103000020E610000001000000050000006A85E97B0D4D4A4003B2D7BB3F7E4B406A85E97B0D4D4A40E9465854C47F4B407DE9EDCF45514A40E9465854C47F4B407DE9EDCF45514A4003B2D7BB3F7E4B406A85E97B0D4D4A4003B2D7BB3F7E4B40
78203	9483	52.197929999999999	52.221438999999997	54.755389000000001	54.732999999999997	Ленина	0103000020E61000000100000005000000DA722EC555194A40E7FBA9F1D25D4B40DA722EC555194A400B613596B0604B408B87F71C581C4A400B613596B0604B408B87F71C581C4A40E7FBA9F1D25D4B40DA722EC555194A40E7FBA9F1D25D4B40
79328	9311	52.532120999999997	52.549216000000001	55.058956000000002	55.049075000000002	Ленина	0103000020E61000000100000005000000E5417A8A1C444A408E06F01648864B40E5417A8A1C444A4095F3C5DE8B874B405038BBB54C464A4095F3C5DE8B874B405038BBB54C464A408E06F01648864B40E5417A8A1C444A408E06F01648864B40
10095	5315	51.863028999999997	51.882432999999999	55.052669999999999	55.040621000000002	Долгобуль	0103000020E61000000100000005000000F23FF9BB77EE4940F243A51133854B40F23FF9BB77EE49407BBDFBE3BD864B40A1F48590F3F049407BBDFBE3BD864B40A1F48590F3F04940F243A51133854B40F23FF9BB77EE4940F243A51133854B40
71037	9151	52.098936000000002	52.141390000000001	55.050865000000002	55.025395000000003	Школьная	0103000020E61000000100000005000000D33252EFA90C4A40B03DB32440834B40D33252EFA90C4A406AC18BBE82864B40A0FD481119124A406AC18BBE82864B40A0FD481119124A40B03DB32440834B40D33252EFA90C4A40B03DB32440834B40
75301	9151	52.098936000000002	52.141390000000001	55.050865000000002	55.025395000000003	Комсомольская	0103000020E61000000100000005000000D33252EFA90C4A40B03DB32440834B40D33252EFA90C4A406AC18BBE82864B40A0FD481119124A406AC18BBE82864B40A0FD481119124A40B03DB32440834B40D33252EFA90C4A40B03DB32440834B40
78202	9100	51.450989999999997	51.471319000000001	55.028444999999998	55.010122000000003	Советская	0103000020E610000001000000050000005969520ABAB949402D7C7DAD4B814B405969520ABAB949400B5EF415A4834B40E17D552E54BC49400B5EF415A4834B40E17D552E54BC49402D7C7DAD4B814B405969520ABAB949402D7C7DAD4B814B40
78199	9099	52.325508999999997	52.356869000000003	55.062626999999999	55.045051999999998	Центральная	0103000020E61000000100000005000000DEC66647AA294A40484F9143C4854B40DEC66647AA294A405D6C5A2904884B4066FA25E2AD2D4A405D6C5A2904884B4066FA25E2AD2D4A40484F9143C4854B40DEC66647AA294A40484F9143C4854B40
78954	9536	52.235928999999999	52.249187999999997	54.727249999999998	54.711556000000002	Лесная	0103000020E61000000100000005000000C896E5EB321E4A40E4A25A44145B4B40C896E5EB321E4A400C022B87165D4B401F477364E51F4A400C022B87165D4B401F477364E51F4A40E4A25A44145B4B40C896E5EB321E4A40E4A25A44145B4B40
75240	9059	52.452700999999998	52.484169000000001	54.905783	54.884317000000003	Советская	0103000020E61000000100000005000000E9EE3A1BF2394A40FF25A94C31714B40E9EE3A1BF2394A40EA2285B2F0734B40575EF23FF93D4A40EA2285B2F0734B40575EF23FF93D4A40FF25A94C31714B40E9EE3A1BF2394A40FF25A94C31714B40
78215	32598	52.509439	52.551597000000001	54.975605000000002	54.948478999999999	Школьная	0103000020E610000001000000050000004A27124C35414A40ADF886C267794B404A27124C35414A403468E89FE07C4B402EC901BB9A464A403468E89FE07C4B402EC901BB9A464A40ADF886C267794B404A27124C35414A40ADF886C267794B40
78117	32598	52.509439	52.551597000000001	54.975605000000002	54.948478999999999	Тавабилова	0103000020E610000001000000050000004A27124C35414A40ADF886C267794B404A27124C35414A403468E89FE07C4B402EC901BB9A464A403468E89FE07C4B402EC901BB9A464A40ADF886C267794B404A27124C35414A40ADF886C267794B40
78953	9789	52.577558000000003	52.599082000000003	55.020119999999999	55.005071999999998	Заречная	0103000020E6100000010000000500000087C5A86BED494A400A100533A6804B4087C5A86BED494A406DFFCA4A93824B40A7CF0EB8AE4C4A406DFFCA4A93824B40A7CF0EB8AE4C4A400A100533A6804B4087C5A86BED494A400A100533A6804B40
75294	7382	52.392856000000002	52.450589999999998	54.893839999999997	54.828470000000003	Терешковой	0103000020E61000000100000005000000C904FC1A49324A40CBDB114E0B6A4B40C904FC1A49324A40A6ED5F5969724B40CBF3E0EEAC394A40A6ED5F5969724B40CBF3E0EEAC394A40CBDB114E0B6A4B40C904FC1A49324A40CBDB114E0B6A4B40
79331	7382	52.392856000000002	52.450589999999998	54.893839999999997	54.828470000000003	Промышленная	0103000020E61000000100000005000000C904FC1A49324A40CBDB114E0B6A4B40C904FC1A49324A40A6ED5F5969724B40CBF3E0EEAC394A40A6ED5F5969724B40CBF3E0EEAC394A40CBDB114E0B6A4B40C904FC1A49324A40CBDB114E0B6A4B40
75131	7382	52.392856000000002	52.450589999999998	54.893839999999997	54.828470000000003	Некрасова	0103000020E61000000100000005000000C904FC1A49324A40CBDB114E0B6A4B40C904FC1A49324A40A6ED5F5969724B40CBF3E0EEAC394A40A6ED5F5969724B40CBF3E0EEAC394A40CBDB114E0B6A4B40C904FC1A49324A40CBDB114E0B6A4B40
78206	8821	51.587344999999999	51.632233999999997	54.897221000000002	54.871740000000003	ул.Ленина	0103000020E610000001000000050000000C3CF71E2ECB4940BA4E232D956F4B400C3CF71E2ECB494068244223D8724B40AAB5300BEDD0494068244223D8724B40AAB5300BEDD04940BA4E232D956F4B400C3CF71E2ECB4940BA4E232D956F4B40
78905	8384	52.030152000000001	52.056148999999998	54.886341999999999	54.871678000000003	Центральная	0103000020E610000001000000050000005AF44E05DC034A4044520B25936F4B405AF44E05DC034A401E8997A773714B40FF59F3E32F074A401E8997A773714B40FF59F3E32F074A4044520B25936F4B405AF44E05DC034A4044520B25936F4B40
78213	8768	52.221393999999997	52.282739999999997	54.839053999999997	54.804845999999998	Шоссейная	0103000020E61000000100000005000000EBC37AA3561C4A408028983105674B40EBC37AA3561C4A40FBC9181F666B4B40B1A206D330244A40FBC9181F666B4B40B1A206D330244A408028983105674B40EBC37AA3561C4A408028983105674B40
78197	8768	52.221393999999997	52.282739999999997	54.839053999999997	54.804845999999998	Бикчурина	0103000020E61000000100000005000000EBC37AA3561C4A408028983105674B40EBC37AA3561C4A40FBC9181F666B4B40B1A206D330244A40FBC9181F666B4B40B1A206D330244A408028983105674B40EBC37AA3561C4A408028983105674B40
78189	8706	52.073936000000003	52.098315999999997	54.821660000000001	54.808788999999997	Советская	0103000020E61000000100000005000000A0FF1EBC76094A40A92EE06586674B40A0FF1EBC76094A403737A6272C694B403656629E950C4A403737A6272C694B403656629E950C4A40A92EE06586674B40A0FF1EBC76094A40A92EE06586674B40
75300	8591	52.147821999999998	52.213022000000002	54.900886	54.860523000000001	Тукая	0103000020E610000001000000050000008DD0CFD4EB124A40583A1F9E256E4B408DD0CFD4EB124A404EB6813B50734B400DAA0D4E441B4A404EB6813B50734B400DAA0D4E441B4A40583A1F9E256E4B408DD0CFD4EB124A40583A1F9E256E4B40
78864	8510	51.764026000000001	51.793365000000001	55.030839	55.009960999999997	Советская	0103000020E6100000010000000500000098A59D9ACBE14940239EEC6646814B4098A59D9ACBE149407E384888F2834B404165FCFB8CE549407E384888F2834B404165FCFB8CE54940239EEC6646814B4098A59D9ACBE14940239EEC6646814B40
78863	8503	51.683293999999997	51.708213999999998	54.884819	54.86786	Центральная	0103000020E61000000100000005000000C9C6832D76D74940D7C05609166F4B40C9C6832D76D7494091F0BDBF41714B40E048A0C1A6DA494091F0BDBF41714B40E048A0C1A6DA4940D7C05609166F4B40C9C6832D76D74940D7C05609166F4B40
78103	8414	52.065877999999998	52.097588000000002	54.847487999999998	54.837871999999997	Юлдаш	0103000020E6100000010000000500000050C3B7B06E084A40F71DC3633F6B4B4050C3B7B06E084A4050E09D7C7A6C4B40B43D7AC37D0C4A4050E09D7C7A6C4B40B43D7AC37D0C4A40F71DC3633F6B4B4050C3B7B06E084A40F71DC3633F6B4B40
78853	8320	51.968347999999999	51.998162999999998	54.902262999999998	54.885554999999997	Центральная	0103000020E61000000100000005000000D192C7D3F2FB494096E7C1DD59714B40D192C7D3F2FB494007B29E5A7D734B40E38920CEC3FF494007B29E5A7D734B40E38920CEC3FF494096E7C1DD59714B40D192C7D3F2FB494096E7C1DD59714B40
79174	61435	51.705877999999998	51.722155000000001	54.980998999999997	54.965744999999998	Советская	0103000020E61000000100000005000000A27BD6355ADA494044A33B889D7B4B40A27BD6355ADA494050340F60917D4B404AD235936FDC494050340F60917D4B404AD235936FDC494044A33B889D7B4B40A27BD6355ADA494044A33B889D7B4B40
78188	8304	52.530620999999996	52.565187999999999	54.908956000000003	54.880034000000002	Школьная	0103000020E6100000010000000500000010C99063EB434A401DAF40F4A4704B4010C99063EB434A4062C092AB58744B40BB0B941458484A4062C092AB58744B40BB0B941458484A401DAF40F4A4704B4010C99063EB434A401DAF40F4A4704B40
11484	30044	52.633172999999999	52.642578	54.830767999999999	54.823917000000002	Ключевая	0103000020E61000000100000005000000E8DA17D00B514A4029CFBC1C76694B40E8DA17D00B514A401B48179B566A4B408690F3FE3F524A401B48179B566A4B408690F3FE3F524A4029CFBC1C76694B40E8DA17D00B514A4029CFBC1C76694B40
75299	8223	52.125283000000003	52.204371000000002	54.942118000000001	54.906652000000001	Токарликова	0103000020E6100000010000000500000055DFF94509104A402F6D382C0D744B4055DFF94509104A40897C975297784B401BA034D4281A4A40897C975297784B401BA034D4281A4A402F6D382C0D744B4055DFF94509104A402F6D382C0D744B40
68502	8223	52.125283000000003	52.204371000000002	54.942118000000001	54.906652000000001	Железнодорожная	0103000020E6100000010000000500000055DFF94509104A402F6D382C0D744B4055DFF94509104A40897C975297784B401BA034D4281A4A40897C975297784B401BA034D4281A4A402F6D382C0D744B4055DFF94509104A402F6D382C0D744B40
78786	7629	51.892547999999998	51.913083	54.964033999999998	54.947474999999997	Советская	0103000020E610000001000000050000001B0E4B033FF2494088635DDC46794B401B0E4B033FF24940B41D5377657B4B404CC45BE7DFF44940B41D5377657B4B404CC45BE7DFF4494088635DDC46794B401B0E4B033FF2494088635DDC46794B40
79338	9891	52.126325000000001	52.141022	55.073509999999999	55.060775999999997	Верхняя	0103000020E6100000010000000500000067D5E76A2B104A40DB300A82C7874B4067D5E76A2B104A40E8F692C668894B401D0247020D124A40E8F692C668894B401D0247020D124A40DB300A82C7874B4067D5E76A2B104A40DB300A82C7874B40
78855	8208	51.738109000000001	51.761150999999998	54.937835999999997	54.921453	Советская	0103000020E610000001000000050000000FF10F5B7ADE49408AE6012CF2754B400FF10F5B7ADE4940778192020B784B40AA285E656DE14940778192020B784B40AA285E656DE149408AE6012CF2754B400FF10F5B7ADE49408AE6012CF2754B40
78072	7547	52.002654	52.027510999999997	54.953850000000003	54.939791	Школьная	0103000020E610000001000000050000000F9A5DF756004A409E094D124B784B400F9A5DF756004A4012A5BDC1177A4B40DFA3FE7A85034A4012A5BDC1177A4B40DFA3FE7A85034A409E094D124B784B400F9A5DF756004A409E094D124B784B40
78876	7638	51.526287000000004	51.552804999999999	54.943824999999997	54.931970999999997	Молодёжная	0103000020E61000000100000005000000ADA7565F5DC3494003E962D34A774B40ADA7565F5DC34940D712F241CF784B405B087250C2C64940D712F241CF784B405B087250C2C6494003E962D34A774B40ADA7565F5DC3494003E962D34A774B40
78176	8102	52.344005000000003	52.377125999999997	54.837581	54.816716999999997	Октября	0103000020E610000001000000050000008B54185B082C4A402A8BC22E8A684B408B54185B082C4A402060ADDA356B4B40533C2EAA45304A402060ADDA356B4B40533C2EAA45304A402A8BC22E8A684B408B54185B082C4A402A8BC22E8A684B40
78175	8046	52.126766000000003	52.174151999999999	54.971919999999997	54.949739999999998	Советская	0103000020E61000000100000005000000541F48DE39104A40FDD98F1491794B40541F48DE39104A40062AE3DF677C4B403944DC9C4A164A40062AE3DF677C4B403944DC9C4A164A40FDD98F1491794B40541F48DE39104A40FDD98F1491794B40
78857	7964	52.278984999999999	52.299942999999999	54.775309	54.760958000000002	Центральная	0103000020E610000001000000050000008B89CDC7B5234A4096D05D1267614B408B89CDC7B5234A40B1A547533D634B4002D53F8864264A40B1A547533D634B4002D53F8864264A4096D05D1267614B408B89CDC7B5234A4096D05D1267614B40
78751	7911	51.928831000000002	51.952573000000001	55.025342999999999	55.008809999999997	Бльшая	0103000020E61000000100000005000000684128EFE3F649405AF0A2AF20814B40684128EFE3F649405D177E703E834B40BC067DE9EDF949405D177E703E834B40BC067DE9EDF949405AF0A2AF20814B40684128EFE3F649405AF0A2AF20814B40
78749	7809	51.632063000000002	51.652096	55.038960000000003	55.026747	Центральная	0103000020E610000001000000050000007E01BD70E7D04940102219726C834B407E01BD70E7D0494014ED2AA4FC844B401CEDB8E177D3494014ED2AA4FC844B401CEDB8E177D34940102219726C834B407E01BD70E7D04940102219726C834B40
79327	7716	52.580603000000004	52.609977999999998	54.868326000000003	54.848193000000002	Советская	0103000020E61000000100000005000000D17AF832514A4A401BD99596916C4B40D17AF832514A4A401D226E4E256F4B40C6A354C2134E4A401D226E4E256F4B40C6A354C2134E4A401BD99596916C4B40D17AF832514A4A401BD99596916C4B40
78949	9017	52.419705999999998	52.446629000000001	55.020538000000002	55.012357000000002	Школьная	0103000020E61000000100000005000000ADF71BEDB8354A40377007EA94814B40ADF71BEDB8354A40A2293BFDA0824B40FC389A232B394A40A2293BFDA0824B40FC389A232B394A40377007EA94814B40ADF71BEDB8354A40377007EA94814B40
78750	7900	51.704566	51.728372	55.031835000000001	55.014431999999999	Центральная	0103000020E61000000100000005000000D0EFFB372FDA4940080264E8D8814B40D0EFFB372FDA494020EF552B13844B403BA92F4B3BDD494020EF552B13844B403BA92F4B3BDD4940080264E8D8814B40D0EFFB372FDA4940080264E8D8814B40
78585	7557	51.900129999999997	51.918725000000002	54.940649000000001	54.922829	Школьная	0103000020E610000001000000050000000113B87537F349407366BB421F764B400113B87537F34940EF01BA2F67784B404182E2C798F54940EF01BA2F67784B404182E2C798F549407366BB421F764B400113B87537F349407366BB421F764B40
75380	60590	52.464630999999997	52.498812000000001	54.785553	54.764532000000003	Советская	0103000020E6100000010000000500000098DA5207793B4A406C5F402FDC614B4098DA5207793B4A4029232E008D644B401A6D5512D93F4A4029232E008D644B401A6D5512D93F4A406C5F402FDC614B4098DA5207793B4A406C5F402FDC614B40
75273	59389	52.248362	52.385624	54.921101	54.861719999999998	Советская	0103000020E61000000100000005000000DAC87553CA1F4A40912749D74C6E4B40DAC87553CA1F4A400DA837A3E6754B40BF4692205C314A400DA837A3E6754B40BF4692205C314A40912749D74C6E4B40DAC87553CA1F4A40912749D74C6E4B40
70189	59389	52.248362	52.385624	54.921101	54.861719999999998	Белоглазова	0103000020E61000000100000005000000DAC87553CA1F4A40912749D74C6E4B40DAC87553CA1F4A400DA837A3E6754B40BF4692205C314A400DA837A3E6754B40BF4692205C314A40912749D74C6E4B40DAC87553CA1F4A40912749D74C6E4B40
78113	3937	49.957649000000004	49.996402000000003	54.629513000000003	54.619045999999997	Луговая	0103000020E610000001000000050000000806103E94FA48401C5C3AE63C4F4B400806103E94FA484014B4C9E193504B40A2D5C9198AFF484014B4C9E193504B40A2D5C9198AFF48401C5C3AE63C4F4B400806103E94FA48401C5C3AE63C4F4B40
78956	3789	49.791136999999999	49.807898999999999	54.821966000000003	54.814433999999999	Центральная	0103000020E61000000100000005000000E9D32AFA43E548400F60915F3F684B40E9D32AFA43E548404436902E36694B404DBC033C69E748404436902E36694B404DBC033C69E748400F60915F3F684B40E9D32AFA43E548400F60915F3F684B40
78744	3747	49.801872000000003	49.832352	54.727587999999997	54.706620000000001	Центральная	0103000020E6100000010000000500000000CADFBDA3E648408A592F86725A4B4000CADFBDA3E64840247B849A215D4B404E61A5828AEA4840247B849A215D4B404E61A5828AEA48408A592F86725A4B4000CADFBDA3E648408A592F86725A4B40
78114	3684	50.055079999999997	50.114378000000002	54.747537999999999	54.733347999999999	Молодежная	0103000020E61000000100000005000000F35487DC0C074940234BE658DE5D4B40F35487DC0C07494035423F53AF5F4B40E2B034F0A30E494035423F53AF5F4B40E2B034F0A30E4940234BE658DE5D4B40F35487DC0C074940234BE658DE5D4B40
78746	3653	49.824150000000003	49.842582999999998	55.026128	55.015542000000003	Зеленая	0103000020E61000000100000005000000CC7F48BF7DE9484073DBBE47FD814B40CC7F48BF7DE9484044C18C2958834B4031957EC2D9EB484044C18C2958834B4031957EC2D9EB484073DBBE47FD814B40CC7F48BF7DE9484073DBBE47FD814B40
79024	3447	49.923036000000003	49.94332	54.865062000000002	54.851412000000003	Центральная	0103000020E61000000100000005000000ED832C0B26F6484003B68311FB6C4B40ED832C0B26F648409581035ABA6E4B40D4D4B2B5BEF848409581035ABA6E4B40D4D4B2B5BEF8484003B68311FB6C4B40ED832C0B26F6484003B68311FB6C4B40
78942	3372	49.656066000000003	49.683095999999999	54.808934999999998	54.796542000000002	Шавалеева	0103000020E610000001000000050000003F027FF8F9D34840FAF19716F5654B403F027FF8F9D348407DCB9C2E8B674B40A30392B06FD748407DCB9C2E8B674B40A30392B06FD74840FAF19716F5654B403F027FF8F9D34840FAF19716F5654B40
78938	3328	50.140321	50.162159000000003	54.906300000000002	54.891629000000002	Школьная	0103000020E6100000010000000500000094F8DC09F6114940259529E620724B4094F8DC09F6114940B22E6EA301744B4044E048A0C1144940B22E6EA301744B4044E048A0C1144940259529E620724B4094F8DC09F6114940259529E620724B40
78957	3257	49.836725999999999	49.872174000000001	54.741118999999998	54.726953999999999	Центральная	0103000020E6100000010000000500000040DB6AD619EB484023D923D40C5D4B4040DB6AD619EB4840DCB8C5FCDC5E4B40F435CB65A3EF4840DCB8C5FCDC5E4B40F435CB65A3EF484023D923D40C5D4B4040DB6AD619EB484023D923D40C5D4B40
78948	4167	50.036808000000001	50.062365	54.707966999999996	54.690396999999997	Центральная	0103000020E61000000100000005000000971DE21FB6044940D520CCED5E584B40971DE21FB6044940D8D2A3A99E5A4B4020B58993FB074940D8D2A3A99E5A4B4020B58993FB074940D520CCED5E584B40971DE21FB6044940D520CCED5E584B40
78952	3848	49.862589	49.904468000000001	54.66639	54.652130999999997	Мира	0103000020E61000000100000005000000D671FC5069EE484098DA520779534B40D671FC5069EE4840D3307C444C554B40A723809BC5F34840D3307C444C554B40A723809BC5F3484098DA520779534B40D671FC5069EE484098DA520779534B40
78944	3224	50.044910999999999	50.065249000000001	54.988287999999997	54.970132	Центральная	0103000020E61000000100000005000000861DC6A4BF054940CB660E492D7C4B40861DC6A4BF054940BE839F38807E4B40618C48145A084940BE839F38807E4B40618C48145A084940CB660E492D7C4B40861DC6A4BF054940CB660E492D7C4B40
78947	3473	50.008844000000003	50.036754000000002	54.899276	54.886434999999999	Г. Тукая	0103000020E610000001000000050000000762D9CC21014940CF83BBB376714B400762D9CC21014940F209D9791B734B40A4FFE55AB4044940F209D9791B734B40A4FFE55AB4044940CF83BBB376714B400762D9CC21014940CF83BBB376714B40
78936	2785	49.721122000000001	49.748593	54.938529000000003	54.924163999999998	Клубная	0103000020E610000001000000050000008B36C7B94DDC4840FD1186014B764B408B36C7B94DDC48407EACE0B721784B40DC813AE5D1DF48407EACE0B721784B40DC813AE5D1DF4840FD1186014B764B408B36C7B94DDC4840FD1186014B764B40
78943	2979	49.828183000000003	49.860962999999998	54.876252000000001	54.861414000000003	Центральная	0103000020E61000000100000005000000350D8AE601EA484085285FD0426E4B40350D8AE601EA4840FD86890629704B4074081C0934EE4840FD86890629704B4074081C0934EE484085285FD0426E4B40350D8AE601EA484085285FD0426E4B40
78745	3979	50.169732000000003	50.187527000000003	54.770187999999997	54.755460999999997	Мира	0103000020E61000000100000005000000D78A36C7B9154940A43330F2B2604B40D78A36C7B9154940C5E2378595624B40FA0E7EE200184940C5E2378595624B40FA0E7EE200184940A43330F2B2604B40D78A36C7B9154940A43330F2B2604B40
78935	2912	50.107289999999999	50.131805	54.846010999999997	54.828578999999998	Нижняя	0103000020E610000001000000050000000B98C0ADBB0D494081936DE00E6A4B400B98C0ADBB0D49403387A4164A6C4B4082397AFCDE1049403387A4164A6C4B4082397AFCDE10494081936DE00E6A4B400B98C0ADBB0D494081936DE00E6A4B40
78963	2861	50.151505	50.194066999999997	54.887103000000003	54.867750999999998	Северная	0103000020E610000001000000050000001A170E84641349402009FB76126F4B401A170E84641349407D9752978C714B40CD1DFD2FD71849407D9752978C714B40CD1DFD2FD71849402009FB76126F4B401A170E84641349402009FB76126F4B40
78945	3591	49.926504000000001	49.951163000000001	54.784001000000004	54.771948999999999	Школьная	0103000020E610000001000000050000007DCEDDAE97F6484007978E39CF624B407DCEDDAE97F6484002840F255A644B4027158DB5BFF9484002840F255A644B4027158DB5BFF9484007978E39CF624B407DCEDDAE97F6484007978E39CF624B40
78941	3088	49.654502999999998	49.679755	54.894275	54.886181000000001	Ежевичная	0103000020E6100000010000000500000023111AC1C6D3484015AB06616E714B4023111AC1C6D34840B1506B9A77724B4070253B3602D74840B1506B9A77724B4070253B3602D7484015AB06616E714B4023111AC1C6D3484015AB06616E714B40
78939	2739	50.006903000000001	50.041048000000004	54.82846	54.815280000000001	Центральная	0103000020E61000000100000005000000459F8F32E20049409C8A54185B684B40459F8F32E2004940A7052FFA0A6A4B407AC8940F41054940A7052FFA0A6A4B407AC8940F410549409C8A54185B684B40459F8F32E20049409C8A54185B684B40
79225	61476	49.578892000000003	50.257192000000003	55.056600000000003	54.501153000000002	Майская	0103000020E6100000010000000500000041F50F2219CA48406AA510C825404B4041F50F2219CA4840107A36AB3E874B407C65DEAAEB204940107A36AB3E874B407C65DEAAEB2049406AA510C825404B4041F50F2219CA48406AA510C825404B40
78739	2555	50.013308000000002	50.039045000000002	54.958322000000003	54.943085000000004	Советская	0103000020E6100000010000000500000039639813B4014940912C6002B7784B4039639813B4014940C784984BAA7A4B404209336DFF044940C784984BAA7A4B404209336DFF044940912C6002B7784B4039639813B4014940912C6002B7784B40
79025	61371	49.766209000000003	49.781201000000003	54.963211999999999	54.951037999999997	Школьная	0103000020E610000001000000050000005073F22213E248406AA0F99CBB794B405073F22213E24840B08EE3874A7B4B401F4DF564FEE34840B08EE3874A7B4B401F4DF564FEE348406AA0F99CBB794B405073F22213E248406AA0F99CBB794B40
79186	4053	49.807476999999999	49.830177999999997	54.765166000000001	54.757269000000001	Центральная	0103000020E61000000100000005000000D7A205685BE7484027A3CA30EE604B40D7A205685BE748406D01A1F5F0614B40E9EDCF4543EA48406D01A1F5F0614B40E9EDCF4543EA484027A3CA30EE604B40D7A205685BE7484027A3CA30EE604B40
78932	2065	49.961413	50.006337000000002	54.681576	54.670358	Центральная	0103000020E610000001000000050000008179C8940FFB4840554E7B4ACE554B408179C8940FFB484087DEE2E13D574B409CE09BA6CF00494087DEE2E13D574B409CE09BA6CF004940554E7B4ACE554B408179C8940FFB4840554E7B4ACE554B40
78931	2520	49.955421000000001	49.967861999999997	54.889904000000001	54.880929999999999	Мира	0103000020E61000000100000005000000B0743E3C4BFA48405B087250C2704B40B0743E3C4BFA4840304AD05FE8714B404485EAE6E2FB4840304AD05FE8714B404485EAE6E2FB48405B087250C2704B40B0743E3C4BFA48405B087250C2704B40
78926	2452	49.974133000000002	49.991767000000003	54.616152999999997	54.596691999999997	Советская	0103000020E61000000100000005000000297AE063B0FC484075E44867604C4B40297AE063B0FC4840882AFC19DE4E4B4043209738F2FE4840882AFC19DE4E4B4043209738F2FE484075E44867604C4B40297AE063B0FC484075E44867604C4B40
78168	2407	50.019722000000002	50.049689999999998	54.789664999999999	54.769077000000003	Советская	0103000020E6100000010000000500000080812040860249408B8D791D71624B408081204086024940DEE522BE13654B401878EE3D5C064940DEE522BE13654B401878EE3D5C0649408B8D791D71624B4080812040860249408B8D791D71624B40
78930	2328	49.618813000000003	49.645277	54.836098	54.820658999999999	М.Джалиля	0103000020E610000001000000050000007AABAE4335CF48408315A75A0B694B407AABAE4335CF484021205F42056B4B4035EECD6F98D2484021205F42056B4B4035EECD6F98D248408315A75A0B694B407AABAE4335CF48408315A75A0B694B40
78919	2219	49.903973999999998	49.935468999999998	55.005749000000002	54.992440999999999	Мастовая	0103000020E610000001000000050000009737876BB5F34840D21A834E087F4B409737876BB5F348400B7E1B62BC804B40FEB5BC72BDF748400B7E1B62BC804B40FEB5BC72BDF74840D21A834E087F4B409737876BB5F34840D21A834E087F4B40
78918	2173	50.202331999999998	50.22222	54.821863	54.807839999999999	Г. Тукая	0103000020E610000001000000050000009677D503E61949404833164D67674B409677D503E61949406F6589CE32694B40314278B4711C49406F6589CE32694B40314278B4711C49404833164D67674B409677D503E61949404833164D67674B40
78920	2290	49.980178000000002	49.995925999999997	54.570081000000002	54.556978999999998	Школьная	0103000020E610000001000000050000001D21037976FD484086C77E164B474B401D21037976FD48401689096AF8484B40389ECF807AFF48401689096AF8484B40389ECF807AFF484086C77E164B474B401D21037976FD484086C77E164B474B40
78915	1985	49.787705000000003	49.812615999999998	54.869605999999997	54.858004999999999	Клубная	0103000020E61000000100000005000000A6F27684D3E44840F9669B1BD36D4B40A6F27684D3E44840E333D93F4F6F4B40691A14CD03E84840E333D93F4F6F4B40691A14CD03E84840F9669B1BD36D4B40A6F27684D3E44840F9669B1BD36D4B40
78921	1931	49.76885	49.796266000000003	54.761643999999997	54.737594999999999	8 Марта	0103000020E61000000100000005000000CAC342AD69E24840B8585183695E4B40CAC342AD69E24840E998F38C7D614B405875560BECE54840E998F38C7D614B405875560BECE54840B8585183695E4B40CAC342AD69E24840B8585183695E4B40
79348	2106	49.925030999999997	49.942934000000001	54.695298999999999	54.681961000000001	Центральная	0103000020E61000000100000005000000A164726A67F64840E012807F4A574B40A164726A67F6484083F8C08EFF584B40AB24B20FB2F8484083F8C08EFF584B40AB24B20FB2F84840E012807F4A574B40A164726A67F64840E012807F4A574B40
78925	1853	49.894101999999997	49.931265000000003	54.618744	54.610469999999999	Пионерская	0103000020E61000000100000005000000E3A430EF71F24840359886E1234E4B40E3A430EF71F24840514CDE00334F4B40697407B133F74840514CDE00334F4B40697407B133F74840359886E1234E4B40E3A430EF71F24840359886E1234E4B40
78913	1817	49.972920000000002	49.992809000000001	54.78546	54.775064999999998	Мира	0103000020E61000000100000005000000EACF7EA488FC48401AA3755435634B40EACF7EA488FC484078280AF489644B405516855D14FF484078280AF489644B405516855D14FF48401AA3755435634B40EACF7EA488FC48401AA3755435634B40
78908	1753	50.101540999999997	50.126100999999998	54.798591999999999	54.779161999999999	Дружбы	0103000020E61000000100000005000000001AA54BFF0C49409A249694BB634B40001AA54BFF0C4940726C3D4338664B40177FDB1324104940726C3D4338664B40177FDB13241049409A249694BB634B40001AA54BFF0C49409A249694BB634B40
78911	1710	50.054755999999998	50.078327999999999	55.012748999999999	54.998080000000002	Мира	0103000020E6100000010000000500000040A19E3E020749405665DF15C17F4B4040A19E3E0207494042075DC2A1814B40382EE3A6060A494042075DC2A1814B40382EE3A6060A49405665DF15C17F4B4040A19E3E020749405665DF15C17F4B40
78159	1397	49.904873000000002	49.948251999999997	54.920222000000003	54.892561000000001	Школьная	0103000020E610000001000000050000004704E3E0D2F34840B05758703F724B404704E3E0D2F34840A587A1D5C9754B40EC2E505260F94840A587A1D5C9754B40EC2E505260F94840B05758703F724B404704E3E0D2F34840B05758703F724B40
78187	1397	49.904873000000002	49.948251999999997	54.920222000000003	54.892561000000001	Центральная Усадьба	0103000020E610000001000000050000004704E3E0D2F34840B05758703F724B404704E3E0D2F34840A587A1D5C9754B40EC2E505260F94840A587A1D5C9754B40EC2E505260F94840B05758703F724B404704E3E0D2F34840B05758703F724B40
78112	1397	49.904873000000002	49.948251999999997	54.920222000000003	54.892561000000001	Крайнова	0103000020E610000001000000050000004704E3E0D2F34840B05758703F724B404704E3E0D2F34840A587A1D5C9754B40EC2E505260F94840A587A1D5C9754B40EC2E505260F94840B05758703F724B404704E3E0D2F34840B05758703F724B40
78163	1397	49.904873000000002	49.948251999999997	54.920222000000003	54.892561000000001	40 лет Победы	0103000020E610000001000000050000004704E3E0D2F34840B05758703F724B404704E3E0D2F34840A587A1D5C9754B40EC2E505260F94840A587A1D5C9754B40EC2E505260F94840B05758703F724B404704E3E0D2F34840B05758703F724B40
78961	4092	49.946806000000002	49.979593999999999	54.540371999999998	54.525154000000001	Мира	0103000020E610000001000000050000000BD462F030F948408AAE0B3F38434B400BD462F030F9484049D6E1E82A454B40CDAD105663FD484049D6E1E82A454B40CDAD105663FD48408AAE0B3F38434B400BD462F030F948408AAE0B3F38434B40
9917	40355	49.578892000000003	50.257192000000003	55.056600000000003	54.501153000000002	Центральная	0103000020E6100000010000000500000041F50F2219CA48406AA510C825404B4041F50F2219CA4840107A36AB3E874B407C65DEAAEB204940107A36AB3E874B407C65DEAAEB2049406AA510C825404B4041F50F2219CA48406AA510C825404B40
78740	1299	49.868445999999999	49.890436999999999	55.089036999999998	55.077008999999997	Гагарина	0103000020E61000000100000005000000C72B103D29EF4840B33F506EDB894B40C72B103D29EF484025917D90658B4B40FD12F1D6F9F1484025917D90658B4B40FD12F1D6F9F14840B33F506EDB894B40C72B103D29EF4840B33F506EDB894B40
78860	31528	50.472535999999998	50.495649999999998	54.990167999999997	54.971848000000001	Заречная	0103000020E610000001000000050000006117450F7C3C49406D57E883657C4B406117450F7C3C4940DAC534D3BD7E4B4096218E75713F4940DAC534D3BD7E4B4096218E75713F49406D57E883657C4B406117450F7C3C49406D57E883657C4B40
78903	446	50.508477999999997	50.540080000000003	55.057363000000002	55.048197999999999	Школьная	0103000020E61000000100000005000000245E9ECE15414940C6DD205A2B864B40245E9ECE154149400F80B8AB57874B40A29C6857214549400F80B8AB57874B40A29C685721454940C6DD205A2B864B40245E9ECE15414940C6DD205A2B864B40
78727	700	50.246806999999997	50.259985999999998	55.159695999999997	55.149517000000003	Кирова	0103000020E6100000010000000500000041B62C5F971F49401899805F23934B4041B62C5F971F4940A8A624EB70944B407CB5A33847214940A8A624EB70944B407CB5A338472149401899805F23934B4041B62C5F971F49401899805F23934B40
78722	32290	50.011358999999999	50.037266000000002	55.155962000000002	55.140856999999997	Заки Кутлина	0103000020E61000000100000005000000F4C1323674014940D234289A07924B40F4C13236740149409AB51490F6934B405AA0DD21C50449409AB51490F6934B405AA0DD21C5044940D234289A07924B40F4C1323674014940D234289A07924B40
78653	1134	50.257379999999998	50.289396000000004	55.294817000000002	55.275221000000002	Вахитова	0103000020E610000001000000050000007E52EDD3F1204940121615713AA34B407E52EDD3F120494005A73E90BCA54B40EFCB99ED0A25494005A73E90BCA54B40EFCB99ED0A254940121615713AA34B407E52EDD3F1204940121615713AA34B40
78671	32111	50.148397000000003	50.181472999999997	54.938684000000002	54.927573000000002	Гагарина	0103000020E610000001000000050000008AE942ACFE12494089D349B6BA764B408AE942ACFE124940A5A31CCC26784B40B20DDC813A174940A5A31CCC26784B40B20DDC813A17494089D349B6BA764B408AE942ACFE12494089D349B6BA764B40
78106	1006	50.179631000000001	50.208745999999998	55.177720000000001	55.153816999999997	Зеленая	0103000020E61000000100000005000000842C0B26FE164940CF488446B0934B40842C0B26FE1649402DEC6987BF964B40DD955D30B81A49402DEC6987BF964B40DD955D30B81A4940CF488446B0934B40842C0B26FE164940CF488446B0934B40
78735	893	50.262949999999996	50.312249999999999	55.318064999999997	55.304385000000003	Мирная	0103000020E61000000100000005000000D93D7958A82149404D327216F6A64B40D93D7958A821494049809A5AB6A84B408716D9CEF727494049809A5AB6A84B408716D9CEF72749404D327216F6A64B40D93D7958A82149404D327216F6A64B40
78927	132	50.195782999999999	50.214458999999998	55.378979000000001	55.365233000000003	Центральная	0103000020E610000001000000050000006F0ED76A0F194940C23577F4BFAE4B406F0ED76A0F194940766F456282B04B409BAA7B64731B4940766F456282B04B409BAA7B64731B4940C23577F4BFAE4B406F0ED76A0F194940C23577F4BFAE4B40
78858	31369	50.015186	50.031778000000003	55.248837000000002	55.238044000000002	Центральная	0103000020E61000000100000005000000B4AD669DF10149402881CD39789E4B40B4AD669DF101494073840CE4D99F4B40BC5D2F4D1104494073840CE4D99F4B40BC5D2F4D110449402881CD39789E4B40B4AD669DF10149402881CD39789E4B40
78731	821	49.983106999999997	50.020746000000003	55.067715999999997	55.054355999999999	Советская	0103000020E61000000100000005000000FDBB3E73D6FD4840B22B2D23F5864B40FDBB3E73D6FD48403DB5FAEAAA884B40ECC20FCEA70249403DB5FAEAAA884B40ECC20FCEA7024940B22B2D23F5864B40FDBB3E73D6FD4840B22B2D23F5864B40
78659	651	50.244795000000003	50.262348000000003	55.146759000000003	55.129669	Советская	0103000020E61000000100000005000000B79C4B71551F49400B2769FE98904B40B79C4B71551F494064B2B8FFC8924B40E415889E9421494064B2B8FFC8924B40E415889E942149400B2769FE98904B40B79C4B71551F49400B2769FE98904B40
78737	933	50.255673999999999	50.290205	55.371296000000001	55.358421999999997	Комсомольская	0103000020E610000001000000050000000038F6ECB92049405D15A8C5E0AD4B400038F6ECB92049405C9198A086AF4B405E11FC6F252549405C9198A086AF4B405E11FC6F252549405D15A8C5E0AD4B400038F6ECB92049405D15A8C5E0AD4B40
78890	32514	50.261862999999998	50.287196000000002	54.957442999999998	54.941285999999998	Бутлерова	0103000020E6100000010000000500000027840EBA842149406117450F7C784B4027840EBA842149405E64027E8D7A4B4061C5A9D6C22449405E64027E8D7A4B4061C5A9D6C22449406117450F7C784B4027840EBA842149406117450F7C784B40
78904	523	50.336136000000003	50.360875	55.120325999999999	55.104140999999998	Тукая	0103000020E610000001000000050000000F812381062B49401C96067E548D4B400F812381062B4940E36DA5D7668F4B40D578E926312E4940E36DA5D7668F4B40D578E926312E49401C96067E548D4B400F812381062B49401C96067E548D4B40
78826	61363	49.641891000000001	50.560786	55.414597999999998	54.857698999999997	Некрасова	0103000020E61000000100000005000000624CFA7B29D24840EC67B114C96D4B40624CFA7B29D24840567E198C11B54B40FF06EDD5C7474940567E198C11B54B40FF06EDD5C7474940EC67B114C96D4B40624CFA7B29D24840EC67B114C96D4B40
78736	1056	50.222472000000003	50.251927999999999	55.194865999999998	55.182968000000002	Центральная	0103000020E610000001000000050000004B2366F6791C4940761BD47E6B974B404B2366F6791C4940198D7C5EF1984B402D793C2D3F204940198D7C5EF1984B402D793C2D3F204940761BD47E6B974B404B2366F6791C4940761BD47E6B974B40
78158	31883	49.968536	50.003157000000002	55.299577999999997	55.278430999999998	Школьная	0103000020E61000000100000005000000D47FD6FCF8FB4840A69883A0A3A34B40D47FD6FCF8FB4840F04C689258A64B4072E0D57267004940F04C689258A64B4072E0D57267004940A69883A0A3A34B40D47FD6FCF8FB4840A69883A0A3A34B40
78729	767	49.989502999999999	50.012140000000002	55.11562	55.096755000000002	Школьная	0103000020E610000001000000050000009E25C808A8FE4840BC5CC477628C4B409E25C808A8FE4840BB61DBA2CC8E4B409A7CB3CD8D014940BB61DBA2CC8E4B409A7CB3CD8D014940BC5CC477628C4B409E25C808A8FE4840BC5CC477628C4B40
78720	32200	50.218358000000002	50.240968000000002	54.884762000000002	54.872202000000001	Школьная	0103000020E61000000100000005000000F568AA27F31B4940BEC0AC50A46F4B40F568AA27F31B49402D5F97E13F714B40F7B0170AD81E49402D5F97E13F714B40F7B0170AD81E4940BEC0AC50A46F4B40F568AA27F31B4940BEC0AC50A46F4B40
78733	1178	50.241003999999997	50.255431000000002	55.243746000000002	55.228839000000001	Молодежная	0103000020E61000000100000005000000431A1538D91E49405186AA984A9D4B40431A1538D91E4940F243A511339F4B403AB187F6B1204940F243A511339F4B403AB187F6B12049405186AA984A9D4B40431A1538D91E49405186AA984A9D4B40
79287	182	49.899456000000001	49.926450000000003	55.149697000000003	55.129328999999998	Советская	0103000020E610000001000000050000007218CC5F21F3484052B648DA8D904B407218CC5F21F3484098A7734529934B408AB0E1E995F6484098A7734529934B408AB0E1E995F6484052B648DA8D904B407218CC5F21F3484052B648DA8D904B40
78152	25	50.142099999999999	50.165374999999997	55.333359000000002	55.312845000000003	Центральная	0103000020E610000001000000050000007C61325530124940CBDB114E0BA84B407C61325530124940E469F981ABAA4B40BA490C022B154940E469F981ABAA4B40BA490C022B154940CBDB114E0BA84B407C61325530124940CBDB114E0BA84B40
78723	32360	49.804423	49.855922999999997	55.234023999999998	55.217275000000001	Кооперативная	0103000020E610000001000000050000003A933655F7E64840849ECDAACF9B4B403A933655F7E64840533D997FF49D4B40757286E28EED4840533D997FF49D4B40757286E28EED4840849ECDAACF9B4B403A933655F7E64840849ECDAACF9B4B40
78719	32239	50.099933	50.124617999999998	55.201324999999997	55.188564999999997	Центральная	0103000020E610000001000000050000004565C39ACA0C4940CA15DEE522984B404565C39ACA0C4940006F8104C5994B40183F8D7BF30F4940006F8104C5994B40183F8D7BF30F4940CA15DEE522984B404565C39ACA0C4940CA15DEE522984B40
78865	31665	50.186737000000001	50.215823999999998	55.028945	55.015329999999999	Центральная	0103000020E6100000010000000500000001FA7DFFE6174940E7525C55F6814B4001FA7DFFE6174940FD304278B4834B4090D8EE1EA01B4940FD304278B4834B4090D8EE1EA01B4940E7525C55F6814B4001FA7DFFE6174940E7525C55F6814B40
78742	1247	49.829386999999997	49.867888999999998	55.101534999999998	55.087007	Школьная	0103000020E61000000100000005000000205D6C5A29EA4840F4C29D0B238B4B40205D6C5A29EA48401E335019FF8C4B4071C79BFC16EF48401E335019FF8C4B4071C79BFC16EF4840F4C29D0B238B4B40205D6C5A29EA4840F4C29D0B238B4B40
78900	32109	50.215949999999999	50.235956000000002	54.960937999999999	54.946038000000001	Правонабережная	0103000020E610000001000000050000001DC9E53FA41B4940FA62EFC517794B401DC9E53FA41B4940E8BD3104007B4B40C2A563CE331E4940E8BD3104007B4B40C2A563CE331E4940FA62EFC517794B401DC9E53FA41B4940FA62EFC517794B40
78897	317	50.403086999999999	50.423057	55.029125999999998	55.017446999999997	Ленина	0103000020E61000000100000005000000AC38D55A98334940E7340BB43B824B40AC38D55A983349404DBB9866BA834B4004AC55BB263649404DBB9866BA834B4004AC55BB26364940E7340BB43B824B40AC38D55A98334940E7340BB43B824B40
78889	31981	49.780329999999999	49.810397000000002	55.115212999999997	55.097903000000002	Викторова	0103000020E61000000100000005000000390B7BDAE1E348401497E315888C4B40390B7BDAE1E348407A89B14CBF8E4B4065E3C116BBE748407A89B14CBF8E4B4065E3C116BBE748401497E315888C4B40390B7BDAE1E348401497E315888C4B40
78898	398	50.438023000000001	50.458387000000002	55.080348999999998	55.065973	Горская	0103000020E61000000100000005000000AAF23D2311384940A2B5A2CD71884B40AAF23D231138494016A243E0488A4B40AEF4DA6CAC3A494016A243E0488A4B40AEF4DA6CAC3A4940A2B5A2CD71884B40AAF23D2311384940A2B5A2CD71884B40
78613	31931	49.944209999999998	49.966307999999998	55.258946000000002	55.248005999999997	Центральная	0103000020E6100000010000000500000030478FDFDBF848401B9B1DA9BE9F4B4030478FDFDBF848400BB77C2425A14B407CEE04FBAFFB48400BB77C2425A14B407CEE04FBAFFB48401B9B1DA9BE9F4B4030478FDFDBF848401B9B1DA9BE9F4B40
78881	31745	50.135973	50.166058	55.141993999999997	55.122430999999999	Баттала	0103000020E61000000100000005000000CB113290671149401F82AAD1AB8F4B40CB11329067114940361D01DC2C924B409D9E776341154940361D01DC2C924B409D9E7763411549401F82AAD1AB8F4B40CB113290671149401F82AAD1AB8F4B40
78861	31615	50.209598999999997	50.238399000000001	55.060285999999998	55.040709	Центральная	0103000020E610000001000000050000001C23D923D41A494091D3D7F335854B401C23D923D41A49400D349F73B7874B401633C2DB831E49400D349F73B7874B401633C2DB831E494091D3D7F335854B401C23D923D41A494091D3D7F335854B40
75243	31431	50.357246000000004	50.404434999999999	54.998353999999999	54.970002999999998	Ленина	0103000020E610000001000000050000003C50A73CBA2D4940CD02ED0E297C4B403C50A73CBA2D494057EA5910CA7F4B40CB2DAD86C433494057EA5910CA7F4B40CB2DAD86C4334940CD02ED0E297C4B403C50A73CBA2D4940CD02ED0E297C4B40
78063	31431	50.357246000000004	50.404434999999999	54.998353999999999	54.970002999999998	Калинина	0103000020E610000001000000050000003C50A73CBA2D4940CD02ED0E297C4B403C50A73CBA2D494057EA5910CA7F4B40CB2DAD86C433494057EA5910CA7F4B40CB2DAD86C4334940CD02ED0E297C4B403C50A73CBA2D4940CD02ED0E297C4B40
78880	31938	49.918374	49.936357999999998	55.312567999999999	55.299475999999999	Комсомольская	0103000020E6100000010000000500000094BF7B478DF54840ECF7C43A55A64B4094BF7B478DF5484058E36C3A02A84B408AAC3594DAF7484058E36C3A02A84B408AAC3594DAF74840ECF7C43A55A64B4094BF7B478DF54840ECF7C43A55A64B40
78628	32039	49.718094999999998	49.737301000000002	55.144947999999999	55.127898000000002	Федина	0103000020E61000000100000005000000E7357689EADB4840A69C2FF65E904B40E7357689EADB484070CFF3A78D924B40702711E15FDE484070CFF3A78D924B40702711E15FDE4840A69C2FF65E904B40E7357689EADB4840A69C2FF65E904B40
78901	578	50.297679000000002	50.314055000000003	55.028269000000002	55.0017	Чернышевского	0103000020E610000001000000050000005EDA70581A2649409C33A2B437804B405EDA70581A264940CD3E8F519E834B40991249F432284940CD3E8F519E834B40991249F4322849409C33A2B437804B405EDA70581A2649409C33A2B437804B40
75195	31084	50.072696000000001	50.141219	55.319633000000003	55.295344	Советская	0103000020E6100000010000000500000067463F1A4E094940F0880AD5CDA54B4067463F1A4E09494077DCF0BBE9A84B407349D5761312494077DCF0BBE9A84B407349D57613124940F0880AD5CDA54B4067463F1A4E094940F0880AD5CDA54B40
67732	31084	50.072696000000001	50.141219	55.319633000000003	55.295344	Некрасова	0103000020E6100000010000000500000067463F1A4E094940F0880AD5CDA54B4067463F1A4E09494077DCF0BBE9A84B407349D5761312494077DCF0BBE9A84B407349D57613124940F0880AD5CDA54B4067463F1A4E094940F0880AD5CDA54B40
67739	31084	50.072696000000001	50.141219	55.319633000000003	55.295344	Ленина	0103000020E6100000010000000500000067463F1A4E094940F0880AD5CDA54B4067463F1A4E09494077DCF0BBE9A84B407349D5761312494077DCF0BBE9A84B407349D57613124940F0880AD5CDA54B4067463F1A4E094940F0880AD5CDA54B40
68200	31084	50.072696000000001	50.141219	55.319633000000003	55.295344	Есенина	0103000020E6100000010000000500000067463F1A4E094940F0880AD5CDA54B4067463F1A4E09494077DCF0BBE9A84B407349D5761312494077DCF0BBE9A84B407349D57613124940F0880AD5CDA54B4067463F1A4E094940F0880AD5CDA54B40
78042	31084	50.072696000000001	50.141219	55.319633000000003	55.295344	Дорожников	0103000020E6100000010000000500000067463F1A4E094940F0880AD5CDA54B4067463F1A4E09494077DCF0BBE9A84B407349D5761312494077DCF0BBE9A84B407349D57613124940F0880AD5CDA54B4067463F1A4E094940F0880AD5CDA54B40
68182	31084	50.072696000000001	50.141219	55.319633000000003	55.295344	Гагарина	0103000020E6100000010000000500000067463F1A4E094940F0880AD5CDA54B4067463F1A4E09494077DCF0BBE9A84B407349D5761312494077DCF0BBE9A84B407349D57613124940F0880AD5CDA54B4067463F1A4E094940F0880AD5CDA54B40
78882	31667	50.126226000000003	50.148172000000002	55.039037	55.029533000000001	Мирная	0103000020E61000000100000005000000D4F36E2C281049408E93C2BCC7834B40D4F36E2C28104940BF2A172AFF844B406A17D34CF7124940BF2A172AFF844B406A17D34CF71249408E93C2BCC7834B40D4F36E2C281049408E93C2BCC7834B40
78716	31026	53.922471000000002	53.937714999999997	55.708004000000003	55.698324999999997	Центральная	0103000020E6100000010000000500000014419C8713F64A40567DAEB662D94B4014419C8713F64A40F6B704E09FDA4B40FCFB8C0B07F84A40F6B704E09FDA4B40FCFB8C0B07F84A40567DAEB662D94B4014419C8713F64A40567DAEB662D94B40
78718	30930	53.847551000000003	53.884005000000002	55.417648999999997	55.400660000000002	Кирова	0103000020E610000001000000050000009758198D7CEC4A405E68AED348B34B409758198D7CEC4A40821ABE8575B54B4010406A1327F14A40821ABE8575B54B4010406A1327F14A405E68AED348B34B409758198D7CEC4A405E68AED348B34B40
78715	30925	54.000292000000002	54.015760999999998	55.588084000000002	55.56953	Центральная	0103000020E61000000100000005000000A839799109004B40A20BEA5BE6C84B40A839799109004B4083A6255646CB4B40B0C6D97404024B4083A6255646CB4B40B0C6D97404024B40A20BEA5BE6C84B40A839799109004B40A20BEA5BE6C84B40
78714	30845	53.655482999999997	53.675505999999999	55.669035999999998	55.659880999999999	Центральная	0103000020E61000000100000005000000BF0AF0DDE6D34A403A2009FB76D44B40BF0AF0DDE6D34A405FECBDF8A2D54B403A2009FB76D64A405FECBDF8A2D54B403A2009FB76D64A403A2009FB76D44B40BF0AF0DDE6D34A403A2009FB76D44B40
78709	30778	53.763297999999999	53.786878999999999	55.779989999999998	55.765985000000001	Центральная	0103000020E61000000100000005000000158DB5BFB3E14A40001DE6CB0BE24B40158DB5BFB3E14A40809A5AB6D6E34B4060747973B8E44A40809A5AB6D6E34B4060747973B8E44A40001DE6CB0BE24B40158DB5BFB3E14A40001DE6CB0BE24B40
78705	30733	53.611375000000002	53.634174999999999	55.569077	55.562612000000001	Молодежная	0103000020E61000000100000005000000C74B378941CE4A40282B86AB03C84B40C74B378941CE4A40F1F3DF83D7C84B406C787AA52CD14A40F1F3DF83D7C84B406C787AA52CD14A40282B86AB03C84B40C74B378941CE4A40282B86AB03C84B40
78862	30719	53.924384000000003	53.946941000000002	55.761015999999998	55.74982	Центральная	0103000020E610000001000000050000000C79043752F64A4080F10C1AFADF4B400C79043752F64A40CADDE7F868E14B40EB1ED95C35F94A40CADDE7F868E14B40EB1ED95C35F94A4080F10C1AFADF4B400C79043752F64A4080F10C1AFADF4B40
78702	30612	53.659776999999998	53.67971	55.486539999999998	55.474336999999998	1 Мая	0103000020E6100000010000000500000095D39E9273D44A4031242713B7BC4B4095D39E9273D44A40111956F146BE4B40D061BEBC00D74A40111956F146BE4B40D061BEBC00D74A4031242713B7BC4B4095D39E9273D44A4031242713B7BC4B40
78109	30614	53.535108000000001	53.560755	55.610595000000004	55.594071999999997	Ленина	0103000020E61000000100000005000000FBE93F6B7EC44A4012BC218D0ACC4B40FBE93F6B7EC44A40F20C1AFA27CE4B40C408E1D1C6C74A40F20C1AFA27CE4B40C408E1D1C6C74A4012BC218D0ACC4B40FBE93F6B7EC44A4012BC218D0ACC4B40
78148	30422	53.746087000000003	53.769424999999998	55.832439000000001	55.823146000000001	Ленина	0103000020E61000000100000005000000427C60C77FDF4A40A7EA1ED95CE94B40427C60C77FDF4A401D75745C8DEA4B40C6DCB5847CE24A401D75745C8DEA4B40C6DCB5847CE24A40A7EA1ED95CE94B40427C60C77FDF4A40A7EA1ED95CE94B40
78095	30417	53.646642999999997	53.666702999999998	55.762799000000001	55.745548999999997	Гагарина	0103000020E61000000100000005000000FA97A432C5D24A4062484E266EDF4B40FA97A432C5D24A40F435CB65A3E14B4092921E8656D54A40F435CB65A3E14B4092921E8656D54A4062484E266EDF4B40FA97A432C5D24A4062484E266EDF4B40
78098	30313	53.853678000000002	53.884597999999997	55.777596000000003	55.758685999999997	Г.Авзал	0103000020E6100000010000000500000048A8195245ED4A406EF7729F1CE14B4048A8195245ED4A400EC0064488E34B40B20DDC813AF14A400EC0064488E34B40B20DDC813AF14A406EF7729F1CE14B4048A8195245ED4A406EF7729F1CE14B40
79165	61429	53.735602999999998	53.756515999999998	55.438603999999998	55.424627999999998	Гагарина	0103000020E6100000010000000500000074EB353D28DE4A40A27BD6355AB64B4074EB353D28DE4A4088F2052D24B84B404B732B84D5E04A4088F2052D24B84B404B732B84D5E04A40A27BD6355AB64B4074EB353D28DE4A40A27BD6355AB64B40
79213	61464	53.602904000000002	53.615614999999998	55.702145000000002	55.692439999999998	 Советская	0103000020E61000000100000005000000555051F52BCD4A409B38B9DFA1D84B40555051F52BCD4A4064062AE3DFD94B40A9F6E978CCCE4A4064062AE3DFD94B40A9F6E978CCCE4A409B38B9DFA1D84B40555051F52BCD4A409B38B9DFA1D84B40
78046	32547	53.880259000000002	53.943105000000003	55.620016	55.607472999999999	Центральная	0103000020E610000001000000050000003D81B053ACF04A40FC19DEACC1CD4B403D81B053ACF04A40957F2DAF5CCF4B40D8D825AAB7F84A40957F2DAF5CCF4B40D8D825AAB7F84A40FC19DEACC1CD4B403D81B053ACF04A40FC19DEACC1CD4B40
78701	30470	53.845475999999998	53.877034000000002	55.711696000000003	55.699334999999998	Центральная	0103000020E61000000100000005000000C5C6BC8E38EC4A405DF92CCF83D94B40C5C6BC8E38EC4A40D658C2DA18DB4B4073BD6DA642F04A40D658C2DA18DB4B4073BD6DA642F04A405DF92CCF83D94B40C5C6BC8E38EC4A405DF92CCF83D94B40
78105	32563	53.775002999999998	53.802950000000003	55.557785000000003	55.540199999999999	М.Вахитова	0103000020E61000000100000005000000A4A65D4C33E34A404CA60A4625C54B40A4A65D4C33E34A408599B67F65C74B405F29CB10C7E64A408599B67F65C74B405F29CB10C7E64A404CA60A4625C54B40A4A65D4C33E34A404CA60A4625C54B40
78052	32555	53.751683	53.771132000000001	55.675311000000001	55.660941999999999	Центральная	0103000020E61000000100000005000000C6FA062637E04A40C34659BF99D44B40C6FA062637E04A4085D0419770D64B4015731074B4E24A4085D0419770D64B4015731074B4E24A40C34659BF99D44B40C6FA062637E04A40C34659BF99D44B40
79151	61417	53.676305999999997	53.695646000000004	55.641157999999997	55.628759000000002	Г.Тукая	0103000020E61000000100000005000000560BEC3191D64A406808C72C7BD04B40560BEC3191D64A40CDC8207711D24B40EFCB99ED0AD94A40CDC8207711D24B40EFCB99ED0AD94A406808C72C7BD04B40560BEC3191D64A406808C72C7BD04B40
78089	32543	53.853974000000001	53.887768999999999	55.486677999999998	55.474229999999999	Советская	0103000020E6100000010000000500000031D120054FED4A401B649291B3BC4B4031D120054FED4A4062D7F6764BBE4B4089B3226AA2F14A4062D7F6764BBE4B4089B3226AA2F14A401B649291B3BC4B4031D120054FED4A401B649291B3BC4B40
79190	61448	54.032245000000003	54.054290000000002	55.630699999999997	55.618893	Центральная	0103000020E61000000100000005000000D23AAA9A20044B40965CC5E237CF4B40D23AAA9A20044B4029CB10C7BAD04B40FB3F87F9F2064B4029CB10C7BAD04B40FB3F87F9F2064B40965CC5E237CF4B40D23AAA9A20044B40965CC5E237CF4B40
78924	61368	53.515058000000003	53.544153999999999	55.516154999999998	55.505020999999999	Новая	0103000020E6100000010000000500000087C5A86BEDC14A4088653387A4C04B4087C5A86BEDC14A405C55F65D11C24B4069FE98D6A6C54A405C55F65D11C24B4069FE98D6A6C54A4088653387A4C04B4087C5A86BEDC14A4088653387A4C04B40
79259	61501	53.818347000000003	53.842449000000002	55.400522000000002	55.384031999999998	Ленина	0103000020E61000000100000005000000CEE33098BFE84A40094FE8F527B14B40CEE33098BFE84A400DAA0D4E44B34B4022C66B5ED5EB4A400DAA0D4E44B34B4022C66B5ED5EB4A40094FE8F527B14B40CEE33098BFE84A40094FE8F527B14B40
75266	29883	53.473303999999999	53.514769999999999	55.547035999999999	55.527462999999997	Советская	0103000020E610000001000000050000007288B83995BC4A40CE6C57E883C34B407288B83995BC4A4009DE904605C64B40207BBDFBE3C14A4009DE904605C64B40207BBDFBE3C14A40CE6C57E883C34B407288B83995BC4A40CE6C57E883C34B40
79187	61445	53.706552000000002	53.724060000000001	55.719048999999998	55.704670999999998	Центральная	0103000020E610000001000000050000003276C24B70DA4A4045B8C9A832DA4B403276C24B70DA4A405A9C31CC09DC4B40BF2B82FFADDC4A405A9C31CC09DC4B40BF2B82FFADDC4A4045B8C9A832DA4B403276C24B70DA4A4045B8C9A832DA4B40
78086	33137	54.021034	54.064045	55.685158000000001	55.669305000000001	Г.Тукая	0103000020E61000000100000005000000520DFB3DB1024B404F0647C9ABD54B40520DFB3DB1024B40E04BE141B3D74B40753C66A032084B40E04BE141B3D74B40753C66A032084B404F0647C9ABD54B40520DFB3DB1024B404F0647C9ABD54B40
78869	61364	53.805410999999999	53.820430999999999	55.789937000000002	55.781686000000001	Красноармейская	0103000020E61000000100000005000000596B28B517E74A40DBDE6E490EE44B40596B28B517E74A403F73D6A71CE54B40F2CF0CE203E94A403F73D6A71CE54B40F2CF0CE203E94A40DBDE6E490EE44B40596B28B517E74A40DBDE6E490EE44B40
78856	29737	53.633546000000003	53.658707999999997	55.751852	55.739341000000003	И.Миннибаева	0103000020E610000001000000050000007D410B0918D14A40C5CBD3B9A2DE4B407D410B0918D14A4052B7B3AF3CE04B4089CE328B50D44A4052B7B3AF3CE04B4089CE328B50D44A40C5CBD3B9A2DE4B407D410B0918D14A40C5CBD3B9A2DE4B40
78611	29660	53.990743000000002	54.025219999999997	55.744931000000001	55.726117000000002	Центральная	0103000020E61000000100000005000000D7DEA7AAD0FE4A40EA08E066F1DC4B40D7DEA7AAD0FE4A40676325E659DF4B40419AB1683A034B40676325E659DF4B40419AB1683A034B40EA08E066F1DC4B40D7DEA7AAD0FE4A40EA08E066F1DC4B40
79160	61424	53.566575999999998	53.600524	55.658346999999999	55.641823000000002	Советская	0103000020E610000001000000050000006859F78F85C84A400A698D4127D24B406859F78F85C84A40B935E9B644D44B40473B6EF8DDCC4A40B935E9B644D44B40473B6EF8DDCC4A400A698D4127D24B406859F78F85C84A400A698D4127D24B40
78850	29471	53.566037000000001	53.577114000000002	55.554561999999997	55.538941999999999	Центральная	0103000020E61000000100000005000000B9A981E673C84A406D382C0DFCC44B40B9A981E673C84A405BCD3AE3FBC64B4029081EDFDEC94A405BCD3AE3FBC64B4029081EDFDEC94A406D382C0DFCC44B40B9A981E673C84A406D382C0DFCC44B40
78847	29465	54.172598000000001	54.210667999999998	55.675224999999998	55.653095999999998	Первомайская	0103000020E6100000010000000500000071ADF6B017164B40FF9254A698D34B4071ADF6B017164B408638D6C56DD64B402828452BF71A4B408638D6C56DD64B402828452BF71A4B40FF9254A698D34B4071ADF6B017164B40FF9254A698D34B40
78710	29465	54.172598000000001	54.210667999999998	55.675224999999998	55.653095999999998	Октябрьская	0103000020E6100000010000000500000071ADF6B017164B40FF9254A698D34B4071ADF6B017164B408638D6C56DD64B402828452BF71A4B408638D6C56DD64B402828452BF71A4B40FF9254A698D34B4071ADF6B017164B40FF9254A698D34B40
78507	29335	53.687624	53.716424000000004	55.557785000000003	55.545228000000002	Кирова	0103000020E61000000100000005000000ECF82F1004D84A40876EF607CAC54B40ECF82F1004D84A408599B67F65C74B40E60819C8B3DB4A408599B67F65C74B40E60819C8B3DB4A40876EF607CAC54B40ECF82F1004D84A40876EF607CAC54B40
79152	61413	53.719172999999998	53.737175000000001	55.477817000000002	55.465774000000003	Победы	0103000020E61000000100000005000000469561DC0DDC4A40DFA9807B9EBB4B40469561DC0DDC4A40863C821B29BD4B40E3361AC05BDE4A40863C821B29BD4B40E3361AC05BDE4A40DFA9807B9EBB4B40469561DC0DDC4A40DFA9807B9EBB4B40
78851	29292	53.842036	53.858367000000001	55.819817999999998	55.808532999999997	Куйбышева	0103000020E61000000100000005000000FF06EDD5C7EB4A404E5E64027EE74B40FF06EDD5C7EB4A400856D5CBEFE84B409A7B48F8DEED4A400856D5CBEFE84B409A7B48F8DEED4A404E5E64027EE74B40FF06EDD5C7EB4A404E5E64027EE74B40
78848	29201	53.630231000000002	53.642304000000003	55.620586000000003	55.611795000000001	Центральная	0103000020E6100000010000000500000073F6CE68ABD04A409C6D6E4C4FCE4B4073F6CE68ABD04A40802DAF5C6FCF4B40850B790437D24A40802DAF5C6FCF4B40850B790437D24A409C6D6E4C4FCE4B4073F6CE68ABD04A409C6D6E4C4FCE4B40
69627	28752	54.043528000000002	54.097498999999999	55.732109000000001	55.702297000000002	проспект Ленина	0103000020E61000000100000005000000EB3A545392054B401A8A3BDEE4D94B40EB3A545392054B40BB0D6ABFB5DD4B404432E4D87A0C4B40BB0D6ABFB5DD4B404432E4D87A0C4B401A8A3BDEE4D94B40EB3A545392054B401A8A3BDEE4D94B40
67720	28752	54.043528000000002	54.097498999999999	55.732109000000001	55.702297000000002	Юбилейная	0103000020E61000000100000005000000EB3A545392054B401A8A3BDEE4D94B40EB3A545392054B40BB0D6ABFB5DD4B404432E4D87A0C4B40BB0D6ABFB5DD4B404432E4D87A0C4B401A8A3BDEE4D94B40EB3A545392054B401A8A3BDEE4D94B40
78184	28752	54.043528000000002	54.097498999999999	55.732109000000001	55.702297000000002	Центральная	0103000020E61000000100000005000000EB3A545392054B401A8A3BDEE4D94B40EB3A545392054B40BB0D6ABFB5DD4B404432E4D87A0C4B40BB0D6ABFB5DD4B404432E4D87A0C4B401A8A3BDEE4D94B40EB3A545392054B401A8A3BDEE4D94B40
75264	28752	54.043528000000002	54.097498999999999	55.732109000000001	55.702297000000002	Механизаторов	0103000020E61000000100000005000000EB3A545392054B401A8A3BDEE4D94B40EB3A545392054B40BB0D6ABFB5DD4B404432E4D87A0C4B40BB0D6ABFB5DD4B404432E4D87A0C4B401A8A3BDEE4D94B40EB3A545392054B401A8A3BDEE4D94B40
78841	29199	53.919201000000001	53.942377999999998	55.528477000000002	55.514845000000001	Центральная	0103000020E61000000100000005000000AAB9DC60A8F54A402BC1E270E6C14B40AAB9DC60A8F54A4017D86322A5C34B40253CA1D79FF84A4017D86322A5C34B40253CA1D79FF84A402BC1E270E6C14B40AAB9DC60A8F54A402BC1E270E6C14B40
78854	29073	54.117871999999998	54.142684000000003	55.635843000000001	55.622216999999999	Ленина	0103000020E610000001000000050000009B8E006E160F4B40F30181CEA4CF4B409B8E006E160F4B40FD31AD4D63D14B40CCD4247843124B40FD31AD4D63D14B40CCD4247843124B40F30181CEA4CF4B409B8E006E160F4B40F30181CEA4CF4B40
78843	29032	53.534928999999998	53.559722000000001	55.716357000000002	55.706659999999999	Горького	0103000020E610000001000000050000004B57B08D78C44A4018B2BAD573DA4B404B57B08D78C44A405EA10F96B1DB4B40056D72F8A4C74A405EA10F96B1DB4B40056D72F8A4C74A4018B2BAD573DA4B404B57B08D78C44A4018B2BAD573DA4B40
78732	28287	50.586855999999997	50.613922000000002	54.833469000000001	54.818927000000002	Лермонтова	0103000020E610000001000000050000000EBBEF181E4B4940DC679599D2684B400EBBEF181E4B49406B9DB81CAF6A4B40C02500FF944E49406B9DB81CAF6A4B40C02500FF944E4940DC679599D2684B400EBBEF181E4B4940DC679599D2684B40
78809	27025	50.941304000000002	50.976652999999999	54.918456999999997	54.900368	Школьная	0103000020E6100000010000000500000008CC43A67C784940B62E35423F734B4008CC43A67C78494021E4BCFF8F754B4028452BF7027D494021E4BCFF8F754B4028452BF7027D4940B62E35423F734B4008CC43A67C784940B62E35423F734B40
79248	61487	50.534978000000002	50.548560000000002	54.952258	54.932316999999998	Чапаева	0103000020E610000001000000050000002D0ABB287A4449409E40D82956774B402D0ABB287A4449405CAD1397E3794B4067F2CD36374649405CAD1397E3794B4067F2CD36374649409E40D82956774B402D0ABB287A4449409E40D82956774B40
78136	26842	50.804490000000001	50.825780000000002	55.012047000000003	55.000197999999997	Фрунзе	0103000020E61000000100000005000000C2FA3F87F966494026C3F17C06804B40C2FA3F87F9664940E9818FC18A814B406FD8B628B3694940E9818FC18A814B406FD8B628B369494026C3F17C06804B40C2FA3F87F966494026C3F17C06804B40
9833	27951	50.559978000000001	50.588248	54.761445999999999	54.746898000000002	Романова	0103000020E61000000100000005000000603DEE5BAD47494052B9895A9A5F4B40603DEE5BAD474940C3D5011077614B40FDF7E0B54B4B4940C3D5011077614B40FDF7E0B54B4B494052B9895A9A5F4B40603DEE5BAD47494052B9895A9A5F4B40
78834	28651	50.629975000000002	50.655900000000003	54.987937000000002	54.969253999999999	Школьная	0103000020E6100000010000000500000018265305A350494033C2DB83107C4B4018265305A350494012C138B8747E4B4024B9FC87F453494012C138B8747E4B4024B9FC87F453494033C2DB83107C4B4018265305A350494033C2DB83107C4B40
78821	27769	50.717264	50.740566000000001	54.722087000000002	54.712935000000002	Тукая	0103000020E61000000100000005000000904C874ECF5B49403E963E74415B4B40904C874ECF5B4940F2EEC8586D5C4B40C843DFDDCA5E4940F2EEC8586D5C4B40C843DFDDCA5E49403E963E74415B4B40904C874ECF5B49403E963E74415B4B40
78808	27024	50.850465999999997	50.864561000000002	54.956518000000003	54.946364000000003	Западная	0103000020E61000000100000005000000122EE411DC6C49404E0E9F7422794B40122EE411DC6C494086048C2E6F7A4B40D33252EFA96E494086048C2E6F7A4B40D33252EFA96E49404E0E9F7422794B40122EE411DC6C49404E0E9F7422794B40
78832	27843	50.670650000000002	50.691113999999999	54.705984999999998	54.688389000000001	Ленина	0103000020E61000000100000005000000FD87F4DBD75549408CF678211D584B40FD87F4DBD7554940B83B6BB75D5A4B4064E76D6C76584940B83B6BB75D5A4B4064E76D6C765849408CF678211D584B40FD87F4DBD75549408CF678211D584B40
78835	28513	50.586953999999999	50.613832000000002	55.022478999999997	55.005940000000002	Центральная	0103000020E61000000100000005000000D120054F214B49407FDE54A4C2804B40D120054F214B494063EC8497E0824B40809E060C924E494063EC8497E0824B40809E060C924E49407FDE54A4C2804B40D120054F214B49407FDE54A4C2804B40
78801	26835	50.708145999999999	50.744115000000001	55.005386999999999	54.991981000000003	Комсомольская	0103000020E6100000010000000500000088653387A45A49406FA0C03BF97E4B4088653387A45A49406A696E85B0804B4045BB0A293F5F49406A696E85B0804B4045BB0A293F5F49406FA0C03BF97E4B4088653387A45A49406FA0C03BF97E4B40
78144	28655	51.060968000000003	51.084629999999997	54.747408	54.727696999999999	Центральная	0103000020E61000000100000005000000200DA7CCCD874940DB32E02C255D4B40200DA7CCCD8749406762BA10AB5F4B405721E527D58A49406762BA10AB5F4B405721E527D58A4940DB32E02C255D4B40200DA7CCCD874940DB32E02C255D4B40
78817	27572	50.880721000000001	50.905909999999999	54.706192999999999	54.690964999999998	Ленина	0103000020E6100000010000000500000041F33977BB7049401FD7868A71584B4041F33977BB70494002D53F88645A4B40478FDFDBF473494002D53F88645A4B40478FDFDBF47349401FD7868A71584B4041F33977BB7049401FD7868A71584B40
78137	27281	50.975026999999997	51.013590999999998	54.749766999999999	54.720584000000002	Ленина	0103000020E61000000100000005000000C6DB4AAFCD7C4940AC02B5183C5C4B40C6DB4AAFCD7C49405D4F745DF85F4B408D429259BD8149405D4F745DF85F4B408D429259BD814940AC02B5183C5C4B40C6DB4AAFCD7C4940AC02B5183C5C4B40
78825	27672	50.789866000000004	50.826185000000002	54.716008000000002	54.703040999999999	Зеленая	0103000020E61000000100000005000000761C3F541A654940A25F5B3FFD594B40761C3F541A65494052D66F26A65B4B400FB9196EC069494052D66F26A65B4B400FB9196EC0694940A25F5B3FFD594B40761C3F541A654940A25F5B3FFD594B40
78807	26944	50.855362	50.888474000000002	54.901062000000003	54.883648999999998	Советская	0103000020E61000000100000005000000DE1E84807C6D4940511212691B714B40DE1E84807C6D49408DD5E6FF55734B4054AC1A84B97149408DD5E6FF55734B4054AC1A84B9714940511212691B714B40DE1E84807C6D4940511212691B714B40
75263	27105	51.009126999999999	51.056046000000002	54.872523000000001	54.848959999999998	Кооперативная	0103000020E610000001000000050000005B41D3122B8149405BCEA5B8AA6C4B405B41D3122B81494000016BD5AE6F4B402B89EC832C87494000016BD5AE6F4B402B89EC832C8749405BCEA5B8AA6C4B405B41D3122B8149405BCEA5B8AA6C4B40
78803	26750	50.763285000000003	50.796315999999997	54.922519000000001	54.904519999999998	Ленина	0103000020E610000001000000050000008143A852B3614940F949B54FC7734B408143A852B36149402578431A15764B4009A4C4AEED6549402578431A15764B4009A4C4AEED654940F949B54FC7734B408143A852B3614940F949B54FC7734B40
79181	61441	50.571440000000003	50.594535999999998	54.921152999999997	54.910017000000003	Садовая	0103000020E6100000010000000500000029D027F224494940EBE6E26F7B744B4029D027F2244949405FCE6C57E8754B40B72572C1194C49405FCE6C57E8754B40B72572C1194C4940EBE6E26F7B744B4029D027F224494940EBE6E26F7B744B40
78139	26891	50.754390999999998	50.787252000000002	55.004038999999999	54.993133	Советская	0103000020E61000000100000005000000C8B260E28F60494008CA6DFB1E7F4B40C8B260E28F6049404B74965984804B40F5DA6CACC46449404B74965984804B40F5DA6CACC464494008CA6DFB1E7F4B40C8B260E28F60494008CA6DFB1E7F4B40
78836	28243	50.677711000000002	50.733424999999997	54.900202999999998	54.876246999999999	Новостройки	0103000020E61000000100000005000000DA91EA3BBF564940EB1B98DC28704B40DA91EA3BBF5649406B6116DA39734B40CE88D2DEE05D49406B6116DA39734B40CE88D2DEE05D4940EB1B98DC28704B40DA91EA3BBF564940EB1B98DC28704B40
78833	27715	50.713616999999999	50.731591999999999	54.672513000000002	54.663108999999999	Центральная	0103000020E61000000100000005000000506F46CD575B4940755776C1E0544B40506F46CD575B49404391EEE714564B40F30181CEA45D49404391EEE714564B40F30181CEA45D4940755776C1E0544B40506F46CD575B4940755776C1E0544B40
78796	27988	50.605235	50.616706999999998	54.714348999999999	54.710572999999997	Садовая	0103000020E6100000010000000500000081B22957784D4940D6355A0EF45A4B4081B22957784D49401477BCC96F5B4B406D1B4641F04E49401477BCC96F5B4B406D1B4641F04E4940D6355A0EF45A4B4081B22957784D4940D6355A0EF45A4B40
78704	28373	50.567075000000003	50.583450999999997	54.991045999999997	54.976317999999999	Советская	0103000020E610000001000000050000008AB0E1E995484940813FFCFCF77C4B408AB0E1E995484940726A6798DA7E4B40C4E8B985AE4A4940726A6798DA7E4B40C4E8B985AE4A4940813FFCFCF77C4B408AB0E1E995484940813FFCFCF77C4B40
78812	27386	50.907508999999997	50.935715999999999	54.717604999999999	54.701245999999998	Школьная	0103000020E61000000100000005000000AFE9414129744940B439CE6DC2594B40AFE941412974494019390B7BDA5B4B40062CB98AC577494019390B7BDA5B4B40062CB98AC5774940B439CE6DC2594B40AFE9414129744940B439CE6DC2594B40
78813	27372	50.976759999999999	51.011166000000003	54.790480000000002	54.767108	Центральная	0103000020E610000001000000050000003E05C078067D4940FF3F4E9830624B403E05C078067D49403012DA722E654B40E06932E36D8149403012DA722E654B40E06932E36D814940FF3F4E9830624B403E05C078067D4940FF3F4E9830624B40
78818	27579	50.856744999999997	50.876795999999999	54.746160000000003	54.72607	Ленина	0103000020E610000001000000050000007901F6D1A96D4940A94D9CDCEF5C4B407901F6D1A96D4940ACCABE2B825F4B40BEA1F0D93A704940ACCABE2B825F4B40BEA1F0D93A704940A94D9CDCEF5C4B407901F6D1A96D4940A94D9CDCEF5C4B40
78797	26662	50.892319000000001	50.911920000000002	54.908152999999999	54.892125999999998	Центральная	0103000020E61000000100000005000000BA4C4D8237724940A5F44C2F31724B40BA4C4D8237724940D461855B3E744B40BF4868CBB9744940D461855B3E744B40BF4868CBB9744940A5F44C2F31724B40BA4C4D8237724940A5F44C2F31724B40
75152	27115	51.147520999999998	51.193587000000001	54.877370999999997	54.857652000000002	Советская	0103000020E61000000100000005000000923CD7F7E1924940ACAC6D8AC76D4B40923CD7F7E1924940BABA63B14D704B4023F77475C7984940BABA63B14D704B4023F77475C7984940ACAC6D8AC76D4B40923CD7F7E1924940ACAC6D8AC76D4B40
78859	28189	50.688859000000001	50.713383	54.817360000000001	54.803682999999999	Калинина	0103000020E6100000010000000500000013471E882C584940F3ACA415DF664B4013471E882C5849407F87A2409F684B40DD425722505B49407F87A2409F684B40DD425722505B4940F3ACA415DF664B4013471E882C584940F3ACA415DF664B40
78690	27153	50.879212000000003	50.911920000000002	54.843279000000003	54.831389999999999	Центральная	0103000020E610000001000000050000001920D1048A704940581CCEFC6A6A4B401920D1048A704940A933F790F06B4B40BF4868CBB9744940A933F790F06B4B40BF4868CBB9744940581CCEFC6A6A4B401920D1048A704940581CCEFC6A6A4B40
78831	28201	50.694932000000001	50.719869000000003	54.855801999999997	54.841413000000003	Мусы Джалиля	0103000020E61000000100000005000000D1782288F3584940F2B6D26BB36B4B40D1782288F3584940FAEC80EB8A6D4B40BE33DAAA245C4940FAEC80EB8A6D4B40BE33DAAA245C4940F2B6D26BB36B4B40D1782288F3584940F2B6D26BB36B4B40
78840	28569	50.510032000000002	50.529426000000001	55.043886000000001	55.029336999999998	Центральная	0103000020E61000000100000005000000EDF483BA4841494008C89750C1834B40EDF483BA484149404A60730E9E854B4078D32D3BC44349404A60730E9E854B4078D32D3BC443494008C89750C1834B40EDF483BA4841494008C89750C1834B40
78828	28108	50.741249000000003	50.764291	54.797497	54.779541000000002	Зеленая	0103000020E61000000100000005000000AB984A3FE15E49401172DEFFC7634B40AB984A3FE15E49403DD4B66114664B4046D09849D46149403DD4B66114664B4046D09849D46149401172DEFFC7634B40AB984A3FE15E49401172DEFFC7634B40
78802	26756	50.671143999999998	50.688653000000002	55.044288999999999	55.035493000000002	Центральная	0103000020E610000001000000050000000C74ED0BE8554940541EDD088B844B400C74ED0BE855494049490F43AB854B406AA510C82558494049490F43AB854B406AA510C825584940541EDD088B844B400C74ED0BE8554940541EDD088B844B40
78820	27656	50.763787999999998	50.796028	54.716611	54.703446999999997	Центральная	0103000020E61000000100000005000000E38920CEC361494012BC218D0A5A4B40E38920CEC3614940187AC4E8B95B4B40A359D93EE4654940187AC4E8B95B4B40A359D93EE465494012BC218D0A5A4B40E38920CEC361494012BC218D0A5A4B40
78827	27851	50.642138000000003	50.655172	54.661406999999997	54.650620000000004	Гагарина	0103000020E610000001000000050000006AC2F69331524940D00F238447534B406AC2F69331524940382C0DFCA8544B40A1A014ADDC534940382C0DFCA8544B40A1A014ADDC534940D00F238447534B406AC2F69331524940D00F238447534B40
78693	27206	50.903816999999997	50.913536999999998	54.816130999999999	54.807144000000001	Лесная	0103000020E61000000100000005000000CF488446B0734940D1949D7E50674B40CF488446B07349403A2009FB76684B40CD57C9C7EE7449403A2009FB76684B40CD57C9C7EE744940D1949D7E50674B40CF488446B0734940D1949D7E50674B40
78829	28102	50.714703999999998	50.747681	54.777603999999997	54.758209999999998	Школьная	0103000020E610000001000000050000000229B16B7B5B494005C078060D614B400229B16B7B5B4940909E228788634B40986BD102B45F4940909E228788634B40986BD102B45F494005C078060D614B400229B16B7B5B494005C078060D614B40
78810	27280	50.853853000000001	50.876221000000001	54.861544000000002	54.849671000000001	Ленина	0103000020E61000000100000005000000B64B1B0E4B6D494008AEF204C26C4B40B64B1B0E4B6D49405308E412476E4B40C2887D02287049405308E412476E4B40C2887D022870494008AEF204C26C4B40B64B1B0E4B6D494008AEF204C26C4B40
78839	28742	51.063493000000001	51.079725000000003	54.768807000000002	54.757497999999998	Гафиятуллина	0103000020E610000001000000050000003143E389208849408864C8B1F5604B403143E38920884940CBF78C4468624B4039D6C56D348A4940CBF78C4468624B4039D6C56D348A49408864C8B1F5604B403143E389208849408864C8B1F5604B40
78844	27938	50.668062999999997	50.692273	54.749116999999998	54.728087000000002	Кирова	0103000020E610000001000000050000007555A0168355494046D26EF4315D4B407555A0168355494056F0DB10E35F4B40B073D3669C58494056F0DB10E35F4B40B073D3669C58494046D26EF4315D4B407555A0168355494046D26EF4315D4B40
78706	28377	50.550618	50.566867999999999	54.976678999999997	54.966085999999997	Центральная	0103000020E61000000100000005000000624B8FA67A464940CD8FBFB4A87B4B40624B8FA67A46494051D845D1037D4B40109370218F48494051D845D1037D4B40109370218F484940CD8FBFB4A87B4B40624B8FA67A464940CD8FBFB4A87B4B40
78816	27430	50.943207999999998	50.974874	54.718015999999999	54.705975000000002	Полевая	0103000020E61000000100000005000000ACA92C0ABB784940956588635D5A4B40ACA92C0ABB7849409B00C3F2E75B4B4040DCD5ABC87C49409B00C3F2E75B4B4040DCD5ABC87C4940956588635D5A4B40ACA92C0ABB784940956588635D5A4B40
78815	27484	50.964785999999997	50.987198999999997	54.678925999999997	54.667489000000003	Зеленая	0103000020E61000000100000005000000BFD18E1B7E7B49404AB8904770554B40BFD18E1B7E7B4940B933130CE7564B406BD26D895C7E4940B933130CE7564B406BD26D895C7E49404AB8904770554B40BFD18E1B7E7B49404AB8904770554B40
75256	26496	50.778869999999998	50.851095000000001	54.874527	54.825643999999997	Школьная	0103000020E61000000100000005000000F2EA1C03B2634940BE11DDB3AE694B40F2EA1C03B2634940083C3080F06F4B40026553AEF06C4940083C3080F06F4B40026553AEF06C4940BE11DDB3AE694B40F2EA1C03B2634940BE11DDB3AE694B40
75255	26496	50.778869999999998	50.851095000000001	54.874527	54.825643999999997	Романова	0103000020E61000000100000005000000F2EA1C03B2634940BE11DDB3AE694B40F2EA1C03B2634940083C3080F06F4B40026553AEF06C4940083C3080F06F4B40026553AEF06C4940BE11DDB3AE694B40F2EA1C03B2634940BE11DDB3AE694B40
68159	26496	50.778869999999998	50.851095000000001	54.874527	54.825643999999997	Мазилина	0103000020E61000000100000005000000F2EA1C03B2634940BE11DDB3AE694B40F2EA1C03B2634940083C3080F06F4B40026553AEF06C4940083C3080F06F4B40026553AEF06C4940BE11DDB3AE694B40F2EA1C03B2634940BE11DDB3AE694B40
78838	26367	52.892533999999998	52.908757999999999	55.097588999999999	55.079889999999999	Советская	0103000020E61000000100000005000000B648DA8D3E724A4083A3E4D5398A4B40B648DA8D3E724A4084B9DDCB7D8C4B403BFDA02E52744A4084B9DDCB7D8C4B403BFDA02E52744A4083A3E4D5398A4B40B648DA8D3E724A4083A3E4D5398A4B40
78777	24724	52.845498999999997	52.871828000000001	54.770192999999999	54.760458999999997	Нагорная	0103000020E610000001000000050000007DE6AC4F396C4A40747973B856614B407DE6AC4F396C4A40D74D29AF95624B4059DE550F986F4A40D74D29AF95624B4059DE550F986F4A40747973B856614B407DE6AC4F396C4A40747973B856614B40
79134	61403	52.685572000000001	53.650452000000001	55.191299999999998	54.650396000000001	Базарная	0103000020E61000000100000005000000D386C3D2C0574A4080B9162D40534B40D386C3D2C0574A40C6DCB5847C984B4014CFD90242D34A40C6DCB5847C984B4014CFD90242D34A4080B9162D40534B40D386C3D2C0574A4080B9162D40534B40
78085	26149	53.049227999999999	53.098939999999999	55.102801999999997	55.071148999999998	Центральная	0103000020E610000001000000050000001406651A4D864A40511212691B894B401406651A4D864A4050FBAD9D288D4B401422E010AA8C4A4050FBAD9D288D4B401422E010AA8C4A40511212691B894B401406651A4D864A40511212691B894B40
78790	25934	53.291412999999999	53.317635000000003	54.918818999999999	54.904297	Советская	0103000020E610000001000000050000008B506C054DA54A407A6F0C01C0734B408B506C054DA54A40C2F869DC9B754B4051888043A8A84A40C2F869DC9B754B4051888043A8A84A407A6F0C01C0734B408B506C054DA54A407A6F0C01C0734B40
78131	26029	53.210996000000002	53.249318000000002	55.095605999999997	55.069566000000002	Советская	0103000020E610000001000000050000001DCBBBEA019B4A40EF74E789E7884B401DCBBBEA019B4A4093A641D13C8C4B40EE26F8A6E99F4A4093A641D13C8C4B40EE26F8A6E99F4A40EF74E789E7884B401DCBBBEA019B4A40EF74E789E7884B40
78794	25551	53.340389999999999	53.368659999999998	54.847073999999999	54.824969000000003	Татарстана	0103000020E6100000010000000500000056F146E691AB4A405F9B8D9598694B4056F146E691AB4A405DA5BBEB6C6C4B40F3AB394030AF4A405DA5BBEB6C6C4B40F3AB394030AF4A405F9B8D9598694B4056F146E691AB4A405F9B8D9598694B40
9776	25161	53.148716	53.187918000000003	54.878169	54.863424999999999	Энгельса	0103000020E610000001000000050000002B323A2009934A403FC6DCB5846E4B402B323A2009934A4036AE7FD767704B40352A70B20D984A4036AE7FD767704B40352A70B20D984A403FC6DCB5846E4B402B323A2009934A403FC6DCB5846E4B40
69945	26026	53.282519999999998	53.320383999999997	55.030720000000002	55.006301000000001	Тельмана	0103000020E61000000100000005000000A33B889D29A44A404F779E78CE804B40A33B889D29A44A40A4AA09A2EE834B40B114C95702A94A40A4AA09A2EE834B40B114C95702A94A404F779E78CE804B40A33B889D29A44A404F779E78CE804B40
78791	26227	53.016232000000002	53.062854999999999	55.154722999999997	55.138120000000001	Советская	0103000020E610000001000000050000000893E2E313824A40367689EAAD914B400893E2E313824A40317898F6CD934B40EEB1F4A10B884A40317898F6CD934B40EEB1F4A10B884A40367689EAAD914B400893E2E313824A40367689EAAD914B40
78642	25457	53.250746999999997	53.261229999999998	54.747044000000002	54.740220000000001	Центральная	0103000020E61000000100000005000000F9484A7A18A04A402DEC6987BF5E4B40F9484A7A18A04A40265646239F5F4B40F65D11FC6FA14A40265646239F5F4B40F65D11FC6FA14A402DEC6987BF5E4B40F9484A7A18A04A402DEC6987BF5E4B40
79258	61500	53.069934000000003	53.096632	54.816079000000002	54.804737000000003	Мусы Джалиля	0103000020E610000001000000050000007270E998F3884A40CA703C9F01674B407270E998F3884A40E8F9D34675684B40A0DFF76F5E8C4A40E8F9D34675684B40A0DFF76F5E8C4A40CA703C9F01674B407270E998F3884A40CA703C9F01674B40
78125	25799	53.436985	53.483240000000002	54.968736999999997	54.948979999999999	Центральная	0103000020E61000000100000005000000D9EBDD1FEFB74A406F47382D78794B40D9EBDD1FEFB74A406BB6F292FF7B4B403D0FEECEDABD4A406BB6F292FF7B4B403D0FEECEDABD4A406F47382D78794B40D9EBDD1FEFB74A406F47382D78794B40
78081	25252	53.121065999999999	53.142994000000002	54.908909000000001	54.899037999999997	Школьная	0103000020E610000001000000050000002A5437177F8F4A403DEE5BAD13734B402A5437177F8F4A4021054F2157744B401AC39CA04D924A4021054F2157744B401AC39CA04D924A403DEE5BAD13734B402A5437177F8F4A403DEE5BAD13734B40
78079	25606	53.391333000000003	53.410125999999998	54.872838999999999	54.859414000000001	Центральная	0103000020E610000001000000050000003C6C223317B24A40BEDC2747016E4B403C6C223317B24A4030D63730B96F4B40A19E3E027FB44A4030D63730B96F4B40A19E3E027FB44A40BEDC2747016E4B403C6C223317B24A40BEDC2747016E4B40
78645	52144	53.315891999999998	53.338180000000001	54.765675000000002	54.755772999999998	Средняя	0103000020E61000000100000005000000B58828266FA84A4093196F2BBD604B40B58828266FA84A40B22E6EA301624B40A514747B49AB4A40B22E6EA301624B40A514747B49AB4A4093196F2BBD604B40B58828266FA84A4093196F2BBD604B40
79145	61411	53.020561999999998	53.036166000000001	54.889884000000002	54.873207000000001	Советская	0103000020E610000001000000050000002AC58EC6A1824A40B3D1393FC56F4B402AC58EC6A1824A40E99D0AB8E7714B40139D6516A1844A40E99D0AB8E7714B40139D6516A1844A40B3D1393FC56F4B402AC58EC6A1824A40B3D1393FC56F4B40
78795	26277	52.877541999999998	52.894744000000003	55.133045000000003	55.117592000000002	Новая	0103000020E61000000100000005000000E76ED74B53704A40B82231410D8F4B40E76ED74B53704A40BBF2599E07914B406825ADF886724A40BBF2599E07914B406825ADF886724A40B82231410D8F4B40E76ED74B53704A40B82231410D8F4B40
78648	26074	53.150098999999997	53.174453	55.045484999999999	55.034739999999999	Гафури	0103000020E61000000100000005000000C614AC7136934A4078EE3D5C72844B40C614AC7136934A40B2BAD573D2854B4034D8D47954964A40B2BAD573D2854B4034D8D47954964A4078EE3D5C72844B40C614AC7136934A4078EE3D5C72844B40
78624	25365	53.279178000000002	53.317087000000001	54.827438000000001	54.813220000000001	Тукая	0103000020E61000000100000005000000A0E1CD1ABCA34A40003ACC9717684B40A0E1CD1ABCA34A40DCBB067DE9694B404E7E8B4E96A84A40DCBB067DE9694B404E7E8B4E96A84A40003ACC9717684B40A0E1CD1ABCA34A40003ACC9717684B40
78119	24421	52.738185999999999	52.748641999999997	54.740006999999999	54.711638999999998	Советская	0103000020E61000000100000005000000BA2EFCE07C5E4A4071C79BFC165B4B40BA2EFCE07C5E4A40D1E7A38CB85E4B40BD344580D35F4A40D1E7A38CB85E4B40BD344580D35F4A4071C79BFC165B4B40BA2EFCE07C5E4A4071C79BFC165B4B40
78783	24838	52.883417000000001	52.912216999999998	55.004344000000003	54.991830999999998	Багманова	0103000020E610000001000000050000007FDDE9CE13714A4059147651F47E4B407FDDE9CE13714A4088F71C588E804B4078EDD286C3744A4088F71C588E804B4078EDD286C3744A4059147651F47E4B407FDDE9CE13714A4059147651F47E4B40
78121	24734	52.804822999999999	52.830334999999998	54.893445999999997	54.878179000000003	Нефтяников	0103000020E61000000100000005000000C808A87004674A405A84622B68704B40C808A87004674A40FA5E43705C724B40B1DCD26A486A4A40FA5E43705C724B40B1DCD26A486A4A405A84622B68704B40C808A87004674A405A84622B68704B40
78787	25938	53.375028999999998	53.399740999999999	55.013765999999997	54.993665	Ленина	0103000020E610000001000000050000009A0645F300B04A4005172B6A307F4B409A0645F300B04A40FBE59315C3814B4067EF8CB62AB34A40FBE59315C3814B4067EF8CB62AB34A4005172B6A307F4B409A0645F300B04A4005172B6A307F4B40
78080	25454	53.172144000000003	53.201636000000001	54.793053999999998	54.778309999999998	Молодежная	0103000020E61000000100000005000000F01989D008964A402B137EA99F634B40F01989D008964A4022FB20CB82654B401FD95C35CF994A4022FB20CB82654B401FD95C35CF994A402B137EA99F634B40F01989D008964A402B137EA99F634B40
78132	24917	52.903843999999999	52.93524	54.955091000000003	54.936439999999997	Советская	0103000020E61000000100000005000000C9570229B1734A4047551344DD774B40C9570229B1734A401BDA006C407A4B409DF4BEF1B5774A401BDA006C407A4B409DF4BEF1B5774A4047551344DD774B40C9570229B1734A4047551344DD774B40
78665	26143	52.912010000000002	53.032735000000002	55.045284000000002	55.013849	Гагарина	0103000020E61000000100000005000000FFCF61BEBC744A40890AD5CDC5814B40FFCF61BEBC744A401B84B9DDCB854B40A03715A930844A401B84B9DDCB854B40A03715A930844A40890AD5CDC5814B40FFCF61BEBC744A40890AD5CDC5814B40
78781	24911	52.847529000000002	52.869734999999999	55.039161	55.028238000000002	Валеева	0103000020E61000000100000005000000AFB48CD47B6C4A409240834D9D834B40AFB48CD47B6C4A40AB23473A03854B40E197FA79536F4A40AB23473A03854B40E197FA79536F4A409240834D9D834B40AFB48CD47B6C4A409240834D9D834B40
78082	25750	53.451394000000001	53.477435999999997	54.912159000000003	54.894917	Советская	0103000020E6100000010000000500000029CE5147C7B94A4035D1E7A38C724B4029CE5147C7B94A4044E048A0C1744B406EF7729F1CBD4A4044E048A0C1744B406EF7729F1CBD4A4035D1E7A38C724B4029CE5147C7B94A4035D1E7A38C724B40
78798	26422	52.825367	52.859808999999998	55.083410000000001	55.070974	Октябрьская	0103000020E610000001000000050000004C1938A0A5694A40E36E10AD15894B404C1938A0A5694A406614CB2DAD8A4B403AE7A7380E6E4A406614CB2DAD8A4B403AE7A7380E6E4A40E36E10AD15894B404C1938A0A5694A40E36E10AD15894B40
78785	25882	53.412264	53.435377000000003	54.988835000000002	54.975005000000003	Центральная	0103000020E61000000100000005000000B9A81611C5B44A40DF37BEF6CC7C4B40B9A81611C5B44A40F1113125927E4B401E37FC6EBAB74A40F1113125927E4B401E37FC6EBAB74A40DF37BEF6CC7C4B40B9A81611C5B44A40DF37BEF6CC7C4B40
78077	25264	53.133004	53.157322000000001	54.998756999999998	54.984419000000003	Советская	0103000020E610000001000000050000005C1E6B4606914A40D0471971017E4B405C1E6B4606914A4056D3F544D77F4B407D78962023944A4056D3F544D77F4B407D78962023944A40D0471971017E4B405C1E6B4606914A40D0471971017E4B40
78771	24635	52.794654000000001	52.806027	54.697161999999999	54.689605999999998	Центральная	0103000020E610000001000000050000005BD1E638B7654A400C90680245584B405BD1E638B7654A40C901BB9A3C594B40B4588AE42B674A40C901BB9A3C594B40B4588AE42B674A400C90680245584B405BD1E638B7654A400C90680245584B40
10361	13816	53.015891000000003	53.057608999999999	54.798031999999999	54.775801999999999	Центральная	0103000020E610000001000000050000007FA65EB708824A40F015DD7A4D634B407FA65EB708824A40AB949EE925664B40467A51BB5F874A40AB949EE925664B40467A51BB5F874A40F015DD7A4D634B407FA65EB708824A40F015DD7A4D634B40
78780	13816	53.015891000000003	53.057608999999999	54.798031999999999	54.775801999999999	Молодежная	0103000020E610000001000000050000007FA65EB708824A40F015DD7A4D634B407FA65EB708824A40AB949EE925664B40467A51BB5F874A40AB949EE925664B40467A51BB5F874A40F015DD7A4D634B407FA65EB708824A40F015DD7A4D634B40
78792	26188	52.975960999999998	52.992956999999997	55.093699999999998	55.084363000000003	Октябрьская	0103000020E61000000100000005000000F295404AEC7C4A4009FF2268CC8A4B40F295404AEC7C4A404ED1915CFE8B4B40C9AA0837197F4A404ED1915CFE8B4B40C9AA0837197F4A4009FF2268CC8A4B40F295404AEC7C4A4009FF2268CC8A4B40
78616	25310	53.230786000000002	53.253900000000002	54.844543999999999	54.827494999999999	Центральная	0103000020E61000000100000005000000F52F49658A9D4A40404D2D5BEB694B40F52F49658A9D4A403A048E041A6C4B402A3A92CB7FA04A403A048E041A6C4B402A3A92CB7FA04A40404D2D5BEB694B40F52F49658A9D4A40404D2D5BEB694B40
78772	24786	52.770533999999998	52.806412999999999	54.939869000000002	54.927495999999998	Советская	0103000020E61000000100000005000000603AADDBA0624A40DD955D30B8764B40603AADDBA0624A401AC39CA04D784B40DD088B8A38674A401AC39CA04D784B40DD088B8A38674A40DD955D30B8764B40603AADDBA0624A40DD955D30B8764B40
68148	24436	52.766043000000003	52.831933999999997	54.822702999999997	54.805748999999999	Лесная	0103000020E61000000100000005000000352A70B20D624A4071E481C822674B40352A70B20D624A4019A9F7544E694B40193735D07C6A4A4019A9F7544E694B40193735D07C6A4A4071E481C822674B40352A70B20D624A4071E481C822674B40
75247	24436	52.766043000000003	52.831933999999997	54.822702999999997	54.805748999999999	Комарова	0103000020E61000000100000005000000352A70B20D624A4071E481C822674B40352A70B20D624A4019A9F7544E694B40193735D07C6A4A4019A9F7544E694B40193735D07C6A4A4071E481C822674B40352A70B20D624A4071E481C822674B40
69936	24436	52.766043000000003	52.831933999999997	54.822702999999997	54.805748999999999	Губкина	0103000020E61000000100000005000000352A70B20D624A4071E481C822674B40352A70B20D624A4019A9F7544E694B40193735D07C6A4A4019A9F7544E694B40193735D07C6A4A4071E481C822674B40352A70B20D624A4071E481C822674B40
78145	24436	52.766043000000003	52.831933999999997	54.822702999999997	54.805748999999999	Булатова	0103000020E61000000100000005000000352A70B20D624A4071E481C822674B40352A70B20D624A4019A9F7544E694B40193735D07C6A4A4019A9F7544E694B40193735D07C6A4A4071E481C822674B40352A70B20D624A4071E481C822674B40
79350	24993	52.993146000000003	53.012801000000003	54.837363000000003	54.823340999999999	Хакима	0103000020E610000001000000050000009D137B681F7F4A405C3AE63C63694B409D137B681F7F4A40B3F0F5B52E6B4B40952D9276A3814A40B3F0F5B52E6B4B40952D9276A3814A405C3AE63C63694B409D137B681F7F4A405C3AE63C63694B40
79291	22214	52.807975999999996	52.843378999999999	56.219723000000002	56.208253999999997	Молодежная	0103000020E61000000100000005000000F8F9EFC16B674A406EA12B11A81A4C40F8F9EFC16B674A40EA961DE21F1C4C400C91D3D7F36B4A40EA961DE21F1C4C400C91D3D7F36B4A406EA12B11A81A4C40F8F9EFC16B674A406EA12B11A81A4C40
78759	22780	53.003261000000002	53.024864999999998	56.011681000000003	55.998840999999999	Советская	0103000020E61000000100000005000000172D40DB6A804A40B4739A05DAFF4B40172D40DB6A804A40077E54C37E014C4053E8BCC62E834A40077E54C37E014C4053E8BCC62E834A40B4739A05DAFF4B40172D40DB6A804A40B4739A05DAFF4B40
78756	22659	53.008166000000003	53.033309000000003	56.105541000000002	56.093550999999998	Лесоводов	0103000020E6100000010000000500000036785F950B814A4009C1AA7AF90B4C4036785F950B814A408EB1135E820D4C40CCD4247843844A408EB1135E820D4C40CCD4247843844A4009C1AA7AF90B4C4036785F950B814A4009C1AA7AF90B4C40
78770	23379	53.516226000000003	53.535836000000003	56.165303000000002	56.152780999999997	Центральная	0103000020E6100000010000000500000026AC8DB113C24A409F39EB538E134C4026AC8DB113C24A40217711A628154C407E02284696C44A40217711A628154C407E02284696C44A409F39EB538E134C4026AC8DB113C24A409F39EB538E134C40
78757	22831	52.940261999999997	52.961381000000003	56.010649000000001	56.000784000000003	Ленина	0103000020E61000000100000005000000F5D555815A784A40172EABB019004C40F5D555815A784A40185E49F25C014C4076FF58880E7B4A40185E49F25C014C4076FF58880E7B4A40172EABB019004C40F5D555815A784A40172EABB019004C40
78088	21918	52.866672000000001	52.913437999999999	56.342669999999998	56.319105	Школьная	0103000020E61000000100000005000000F12DAC1BEF6E4A40BB7EC16ED8284C40F12DAC1BEF6E4A4000A94D9CDC2B4C403A765089EB744A4000A94D9CDC2B4C403A765089EB744A40BB7EC16ED8284C40F12DAC1BEF6E4A40BB7EC16ED8284C40
78057	21918	52.866672000000001	52.913437999999999	56.342669999999998	56.319105	Центральная	0103000020E61000000100000005000000F12DAC1BEF6E4A40BB7EC16ED8284C40F12DAC1BEF6E4A4000A94D9CDC2B4C403A765089EB744A4000A94D9CDC2B4C403A765089EB744A40BB7EC16ED8284C40F12DAC1BEF6E4A40BB7EC16ED8284C40
78604	22119	52.672249999999998	52.693899000000002	56.287196999999999	56.274628999999997	Ленина	0103000020E61000000100000005000000355EBA490C564A403FC4060B27234C40355EBA490C564A4031410DDFC2244C4012DDB3AED1584A4031410DDFC2244C4012DDB3AED1584A403FC4060B27234C40355EBA490C564A403FC4060B27234C40
78609	22201	52.588220999999997	52.608235999999998	56.254237000000003	56.242899000000001	Карла Маркса	0103000020E6100000010000000500000003E962D34A4B4A40959D7E50171F4C4003E962D34A4B4A40723788D68A204C40FB1F60ADDA4D4A40723788D68A204C40FB1F60ADDA4D4A40959D7E50171F4C4003E962D34A4B4A40959D7E50171F4C40
78775	23320	53.504009000000003	53.516190000000002	56.187570999999998	56.169257999999999	Клубная	0103000020E61000000100000005000000E1F1ED5D83C04A400E4B033FAA154C40E1F1ED5D83C04A40C956975302184C40D942908312C24A40C956975302184C40D942908312C24A400E4B033FAA154C40E1F1ED5D83C04A400E4B033FAA154C40
78765	22741	53.132860999999998	53.154581999999998	56.088006	56.064704999999996	Зеленая	0103000020E61000000100000005000000F9F4D89601914A409F71E14048084C40F9F4D89601914A4007EDD5C7430B4C406F46CD57C9934A4007EDD5C7430B4C406F46CD57C9934A409F71E14048084C40F9F4D89601914A409F71E14048084C40
78779	23450	53.444684000000002	53.464267	56.225352999999998	56.219608000000001	Центральная	0103000020E61000000100000005000000F986C267EBB84A4051F86C1D1C1C4C40F986C267EBB84A401A87FA5DD81C4C4057CEDE196DBB4A401A87FA5DD81C4C4057CEDE196DBB4A4051F86C1D1C1C4C40F986C267EBB84A4051F86C1D1C1C4C40
79325	21968	52.805461000000001	52.840747	56.317942000000002	56.304181	Площадь Кирова	0103000020E610000001000000050000000B9A965819674A4044882B67EF264C400B9A965819674A402E03CE52B2284C40E59A02999D6B4A402E03CE52B2284C40E59A02999D6B4A4044882B67EF264C400B9A965819674A4044882B67EF264C40
79112	61387	52.868630000000003	52.903143999999998	55.999259000000002	55.987915999999998	Ленина	0103000020E61000000100000005000000892991442F6F4A40FA980F0874FE4B40892991442F6F4A40E99D0AB8E7FF4B4010CAFB389A734A40E99D0AB8E7FF4B4010CAFB389A734A40FA980F0874FE4B40892991442F6F4A40FA980F0874FE4B40
78763	23106	53.280005000000003	53.304896999999997	56.031140999999998	56.021115000000002	Ленина	0103000020E61000000100000005000000B6DB2E34D7A34A403F3A75E5B3024C40B6DB2E34D7A34A404948A46DFC034C4002D369DD06A74A404948A46DFC034C4002D369DD06A74A403F3A75E5B3024C40B6DB2E34D7A34A403F3A75E5B3024C40
78603	22117	52.729624999999999	52.754534999999997	56.276499000000001	56.257998000000001	Ленина	0103000020E6100000010000000500000008AC1C5A645D4A407A37161406214C4008AC1C5A645D4A403830B95164234C40FB57569A94604A403830B95164234C40FB57569A94604A407A37161406214C4008AC1C5A645D4A407A37161406214C40
79275	22309	52.913411000000004	52.944412	56.215228000000003	56.195295000000002	Ленина	0103000020E610000001000000050000004167D2A6EA744A404209336DFF184C404167D2A6EA744A407D9752978C1B4C4098F90E7EE2784A407D9752978C1B4C4098F90E7EE2784A404209336DFF184C404167D2A6EA744A404209336DFF184C40
79205	61459	52.556600000000003	53.578505999999997	56.543840000000003	55.842897999999998	Советская	0103000020E61000000100000005000000107A36AB3E474A4091EEE714E4EB4B40107A36AB3E474A40DA20938C9C454C4017450F7C0CCA4A40DA20938C9C454C4017450F7C0CCA4A4091EEE714E4EB4B40107A36AB3E474A4091EEE714E4EB4B40
79349	21824	52.805326000000001	52.827666999999998	56.374332000000003	56.362875000000003	Тукая	0103000020E610000001000000050000002B4F20EC14674A409CC420B0722E4C402B4F20EC14674A4053EC681CEA2F4C403D7D04FEF0694A4053EC681CEA2F4C403D7D04FEF0694A409CC420B0722E4C402B4F20EC14674A409CC420B0722E4C40
78116	22473	52.895220000000002	52.936615000000003	56.150354	56.133026000000001	Советская	0103000020E61000000100000005000000D15CA79196724A4044C2F7FE06114C40D15CA79196724A405169C4CC3E134C40B6F81400E3774A405169C4CC3E134C40B6F81400E3774A4044C2F7FE06114C40D15CA79196724A4044C2F7FE06114C40
69541	23041	53.063133000000001	53.099389000000002	55.903937999999997	55.882767000000001	Маркина	0103000020E610000001000000050000003126FDBD14884A40787E5182FEF04B403126FDBD14884A404ACE893DB4F34B40844A5CC7B88C4A404ACE893DB4F34B40844A5CC7B88C4A40787E5182FEF04B403126FDBD14884A40787E5182FEF04B40
78989	61369	52.556600000000003	53.578505999999997	56.543840000000003	55.842897999999998	М. Джалиля	0103000020E61000000100000005000000107A36AB3E474A4091EEE714E4EB4B40107A36AB3E474A40DA20938C9C454C4017450F7C0CCA4A40DA20938C9C454C4017450F7C0CCA4A4091EEE714E4EB4B40107A36AB3E474A4091EEE714E4EB4B40
78619	22994	53.218209999999999	53.232933000000003	55.986687000000003	55.976826000000003	Шкетана	0103000020E6100000010000000500000080D4264EEE9B4A40F6F065A208FD4B4080D4264EEE9B4A40B63176C24BFE4B406094A0BFD09D4A40B63176C24BFE4B406094A0BFD09D4A40F6F065A208FD4B4080D4264EEE9B4A40F6F065A208FD4B40
78806	23274	53.409343999999997	53.433732999999997	56.167273000000002	56.150058000000001	Клубная	0103000020E610000001000000050000002B685A6265B44A406840BD1935134C402B685A6265B44A407D40A03369154C4015191D9084B74A407D40A03369154C4015191D9084B74A406840BD1935134C402B685A6265B44A406840BD1935134C40
78774	22737	53.129356999999999	53.150494999999999	56.15428	56.131113999999997	Ленина	0103000020E610000001000000050000001C412AC58E904A401C06F357C8104C401C412AC58E904A40A4367172BF134C40139B8F6B43934A40A4367172BF134C40139B8F6B43934A401C06F357C8104C401C412AC58E904A401C06F357C8104C40
78122	23266	53.407009000000002	53.429403999999998	56.058563999999997	56.038434000000002	Советская	0103000020E61000000100000005000000BE16F4DE18B44A40F986C267EB044C40BE16F4DE18B44A40895C70067F074C40C362D4B5F6B64A40895C70067F074C40C362D4B5F6B64A40F986C267EB044C40BE16F4DE18B44A40F986C267EB044C40
78598	21637	52.980029999999999	53.008363000000003	56.477587	56.463082999999997	Центральная	0103000020E61000000100000005000000A88C7F9F717D4A40B22AC24D463B4C40A88C7F9F717D4A4054FF2092213D4C408CBFED0912814A4054FF2092213D4C408CBFED0912814A40B22AC24D463B4C40A88C7F9F717D4A40B22AC24D463B4C40
78597	21674	52.955587000000001	52.970868000000003	56.409449000000002	56.399841000000002	Центральная	0103000020E61000000100000005000000CBBDC0AC507A4A40CB4C69FD2D334C40CBBDC0AC507A4A40A13028D368344C40D15D1267457C4A40A13028D368344C40D15D1267457C4A40CB4C69FD2D334C40CBBDC0AC507A4A40CB4C69FD2D334C40
78773	23459	53.384613999999999	53.407376999999997	56.209235	56.194684000000002	Советская	0103000020E61000000100000005000000B8CA13083BB14A40F986C267EB184C40B8CA13083BB14A40DB166536C81A4C404012F6ED24B44A40DB166536C81A4C404012F6ED24B44A40F986C267EB184C40B8CA13083BB14A40F986C267EB184C40
79284	61519	52.867525000000001	52.889741000000001	56.216518999999998	56.204639	Ленина	0103000020E6100000010000000500000030BB270F0B6F4A403A3E5A9C311A4C4030BB270F0B6F4A4037FB03E5B61B4C4086747808E3714A4037FB03E5B61B4C4086747808E3714A403A3E5A9C311A4C4030BB270F0B6F4A403A3E5A9C311A4C40
79233	61483	52.886327000000001	52.903708999999999	56.068665000000003	56.058940999999997	Клубная	0103000020E61000000100000005000000E947C32973714A405FB2F1608B074C40E947C32973714A409FB0C403CA084C40E90C8CBCAC734A409FB0C403CA084C40E90C8CBCAC734A405FB2F1608B074C40E947C32973714A405FB2F1608B074C40
78755	22654	52.764308999999997	52.795777000000001	56.061101999999998	56.052270999999998	Клубная	0103000020E61000000100000005000000EC8497E0D4614A40BDC3EDD0B0064C40EC8497E0D4614A402FDCB930D2074C405AF44E05DC654A402FDCB930D2074C405AF44E05DC654A40BDC3EDD0B0064C40EC8497E0D4614A40BDC3EDD0B0064C40
78768	23182	53.334398	53.357053000000001	56.012591999999998	56.001266999999999	Ленина	0103000020E6100000010000000500000085ECBC8DCDAA4A4032C85D8429004C4085ECBC8DCDAA4A407A185A9D9C014C4027F8A6E9B3AD4A407A185A9D9C014C4027F8A6E9B3AD4A4032C85D8429004C4085ECBC8DCDAA4A4032C85D8429004C40
78605	21737	52.893836999999998	52.917247000000003	56.389558000000001	56.379033	Сайдашева	0103000020E61000000100000005000000357A354069724A40698D412784304C40357A354069724A4095F25A09DD314C4054AD855968754A4095F25A09DD314C4054AD855968754A40698D412784304C40357A354069724A40698D412784304C40
78760	22905	53.128377999999998	53.157519000000001	56.008253000000003	55.993510000000001	Советская	0103000020E6100000010000000500000050C3B7B06E904A40DE1FEF552BFF4B4050C3B7B06E904A40058C2E6F0E014C40D3BF249529944A40058C2E6F0E014C40D3BF249529944A40DE1FEF552BFF4B4050C3B7B06E904A40DE1FEF552BFF4B40
67588	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Энергетиков	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
78045	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Чапаева	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
78060	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Саетова	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
75234	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Пушкина	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
78068	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Октябрьская	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
78036	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Карла Маркса,	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
67637	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Карла Маркса	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
79289	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Заводская	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
78047	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Гагарина	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
75236	20870	52.96537	53.040047000000001	56.536980999999997	56.500794999999997	Вокзальная	0103000020E610000001000000050000000F45813E917B4A400A80F10C1A404C400F45813E917B4A4064C91CCBBB444C40C6A6954220854A4064C91CCBBB444C40C6A6954220854A400A80F10C1A404C400F45813E917B4A400A80F10C1A404C40
11599	40921	50.290295	51.245285000000003	55.489998	55.034198000000004	Мира	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
79116	61389	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	Радищева	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
54445	56537	43.188150999999998	43.233452999999997	54.653922999999999	54.616011999999998	Советская	0103000020E61000000100000005000000D7DAFB5415984540C6F8307BD94E4B40D7DAFB5415984540158DB5BFB3534B409813B4C9E19D4540158DB5BFB3534B409813B4C9E19D4540C6F8307BD94E4B40D7DAFB5415984540C6F8307BD94E4B40
501	1332	45.155039000000002	45.155498000000001	54.182986	54.180678	улица Школьная	0103000020E61000000100000005000000624D6551D8934640A88DEA7420174B40624D6551D89346401CD0D2156C174B40F54BC45BE79346401CD0D2156C174B40F54BC45BE7934640A88DEA7420174B40624D6551D8934640A88DEA7420174B40
4905	1332	45.187316000000003	45.191034999999999	54.207680000000003	54.181263000000001	проспект Ленина	0103000020E610000001000000050000003F027FF8F9974640C87C40A033174B403F027FF8F997464043041C42951A4B4018B2BAD57398464043041C42951A4B4018B2BAD573984640C87C40A033174B403F027FF8F9974640C87C40A033174B40
54385	1332	45.187316000000003	45.191034999999999	54.207680000000003	54.181263000000001	проспект Ленина	0103000020E610000001000000050000003F027FF8F9974640C87C40A033174B403F027FF8F997464043041C42951A4B4018B2BAD57398464043041C42951A4B4018B2BAD573984640C87C40A033174B403F027FF8F9974640C87C40A033174B40
7244	1332	45.208641999999998	45.250979999999998	54.193601999999998	54.188054000000001	проспект 70 лет Октября	0103000020E610000001000000050000003849F3C7B49A4640E5F0492712184B403849F3C7B49A4640583849F3C7184B409CF9D51C20A04640583849F3C7184B409CF9D51C20A04640E5F0492712184B403849F3C7B49A4640E5F0492712184B40
7548	1332	45.123840999999999	45.148598999999997	54.221131999999997	54.218673000000003	проспект 60 лет Октября	0103000020E61000000100000005000000B4739A05DA8F464055C2137AFD1B4B40B4739A05DA8F4640AE0CAA0D4E1C4B40F19BC24A05934640AE0CAA0D4E1C4B40F19BC24A0593464055C2137AFD1B4B40B4739A05DA8F464055C2137AFD1B4B40
7311	1332	45.248617000000003	45.248877	54.200628000000002	54.193080000000002	бульвар Степана Эрьзи	0103000020E61000000100000005000000651D8EAED29F46407FC16ED8B6184B40651D8EAED29F4640B954A52DAE194B4001DD9733DB9F4640B954A52DAE194B4001DD9733DB9F46407FC16ED8B6184B40651D8EAED29F46407FC16ED8B6184B40
54504	1332	45.180695	45.198590000000003	54.219963	54.213261000000003	Энергетическая	0103000020E610000001000000050000007EC68503219746409241EE224C1B4B407EC68503219746403FAA61BF271C4B4005A8A9656B9946403FAA61BF271C4B4005A8A9656B9946409241EE224C1B4B407EC68503219746409241EE224C1B4B40
54472	1332	45.144905999999999	45.155020999999998	54.175212999999999	54.174728000000002	Щорса	0103000020E61000000100000005000000417FA1478C92464006D9B27C5D164B40417FA1478C924640C26A2C616D164B40BB9866BAD7934640C26A2C616D164B40BB9866BAD793464006D9B27C5D164B40417FA1478C92464006D9B27C5D164B40
54395	1332	45.144924000000003	45.152532999999998	54.148454000000001	54.145826999999997	Школьная площадь	0103000020E61000000100000005000000E833A0DE8C924640D8EF8975AA124B40E833A0DE8C924640EE7A698A00134B40C7478B3386934640EE7A698A00134B40C7478B3386934640D8EF8975AA124B40E833A0DE8C924640D8EF8975AA124B40
54662	1332	45.155039000000002	45.155498000000001	54.182986	54.180678	Школьная	0103000020E61000000100000005000000624D6551D8934640A88DEA7420174B40624D6551D89346401CD0D2156C174B40F54BC45BE79346401CD0D2156C174B40F54BC45BE7934640A88DEA7420174B40624D6551D8934640A88DEA7420174B40
54509	1332	45.129877999999998	45.155245999999998	54.177557999999998	54.176546000000002	Фурманова	0103000020E61000000100000005000000253CA1D79F904640AC1E300F99164B40253CA1D79F90464053927538BA164B40DB6AD619DF93464053927538BA164B40DB6AD619DF934640AC1E300F99164B40253CA1D79F904640AC1E300F99164B40
54453	1332	45.150153000000003	45.150601999999999	54.183297000000003	54.181105000000002	Ульянова	0103000020E61000000100000005000000BA32A836389346403012DA722E174B40BA32A836389346403B3AAE4676174B40295B24ED469346403B3AAE4676174B40295B24ED469346403012DA722E174B40BA32A836389346403012DA722E174B40
54480	1332	45.145257000000001	45.164093999999999	54.161513999999997	54.157322999999998	Транспортная	0103000020E61000000100000005000000EE4108C8979246404DF4F92823144B40EE4108C8979246404EECA17DAC144B4023BC3D08019546404EECA17DAC144B4023BC3D08019546404DF4F92823144B40EE4108C8979246404DF4F92823144B40
54491	1332	45.224677	45.250539000000003	54.203871999999997	54.199475	Сущинского	0103000020E61000000100000005000000EA944737C29C46404FAF946588194B40EA944737C29C4640F9484A7A181A4B40B0AF75A911A04640F9484A7A181A4B40B0AF75A911A046404FAF946588194B40EA944737C29C46404FAF946588194B40
54503	1332	45.152416000000002	45.164884999999998	54.160575999999999	54.159357999999997	Студенческая	0103000020E610000001000000050000008EB1135E82934640902DCBD765144B408EB1135E82934640E1421EC18D144B40EC4CA1F31A954640E1421EC18D144B40EC4CA1F31A954640902DCBD765144B408EB1135E82934640902DCBD765144B40
54477	1332	45.166789000000001	45.167651999999997	54.192801000000003	54.184992999999999	Степана Разина	0103000020E61000000100000005000000912A8A5759954640957EC2D9AD174B40912A8A57599546406CD102B4AD184B40F38DE89E759546406CD102B4AD184B40F38DE89E75954640957EC2D9AD174B40912A8A5759954640957EC2D9AD174B40
1853	1332	45.143504999999998	45.201580999999997	54.183838999999999	54.180261999999999	Советская улица	0103000020E61000000100000005000000FFE7305F5E924640145B41D312174B40FFE7305F5E9246405B5D4E0988174B405B3FFD67CD9946405B5D4E0988174B405B3FFD67CD994640145B41D312174B40FFE7305F5E924640145B41D312174B40
54471	1332	45.143504999999998	45.201580999999997	54.183838999999999	54.180261999999999	Советская	0103000020E61000000100000005000000FFE7305F5E924640145B41D312174B40FFE7305F5E9246405B5D4E0988174B405B3FFD67CD9946405B5D4E0988174B405B3FFD67CD994640145B41D312174B40FFE7305F5E924640145B41D312174B40
6816	1332	45.132536999999999	45.141987	54.179865999999997	54.168993999999998	Серадзская улица	0103000020E610000001000000050000004641F0F8F6904640309C6B98A1154B404641F0F8F6904640C7D45DD905174B4084BA48A12C924640C7D45DD905174B4084BA48A12C924640309C6B98A1154B404641F0F8F6904640309C6B98A1154B40
54494	1332	45.132536999999999	45.141987	54.179865999999997	54.168993999999998	Серадзская	0103000020E610000001000000050000004641F0F8F6904640309C6B98A1154B404641F0F8F6904640C7D45DD905174B4084BA48A12C924640C7D45DD905174B4084BA48A12C924640309C6B98A1154B404641F0F8F6904640309C6B98A1154B40
7235	1332	45.223868000000003	45.224677	54.201202000000002	54.192590000000003	Севастопольская улица	0103000020E610000001000000050000007B4FE5B4A79C4640B1C403CAA6184B407B4FE5B4A79C4640E5F1B4FCC0194B40EA944737C29C4640E5F1B4FCC0194B40EA944737C29C4640B1C403CAA6184B407B4FE5B4A79C4640B1C403CAA6184B40
54466	1332	45.223868000000003	45.224677	54.201202000000002	54.192590000000003	Севастопольская	0103000020E610000001000000050000007B4FE5B4A79C4640B1C403CAA6184B407B4FE5B4A79C4640E5F1B4FCC0194B40EA944737C29C4640E5F1B4FCC0194B40EA944737C29C4640B1C403CAA6184B407B4FE5B4A79C4640B1C403CAA6184B40
6761	1332	45.161830999999999	45.180579000000002	54.180861999999998	54.177964000000003	Саранская улица	0103000020E610000001000000050000004F3DD2E0B6944640C4EE3B86C7164B404F3DD2E0B6944640698B6B7C26174B4015AC71361D974640698B6B7C26174B4015AC71361D974640C4EE3B86C7164B404F3DD2E0B6944640C4EE3B86C7164B40
54347	1332	45.121676000000001	45.132995000000001	54.177537000000001	54.165678999999997	Розы Люксембург	0103000020E61000000100000005000000A35A4414938F464026512FF834154B40A35A4414938F46403C6A4C88B9164B4009C4EBFA059146403C6A4C88B9164B4009C4EBFA0591464026512FF834154B40A35A4414938F464026512FF834154B40
54400	1332	45.190424	45.197763000000002	54.203588000000003	54.179259999999999	Рабочая	0103000020E61000000100000005000000CF2F4AD05F98464090BDDEFDF1164B40CF2F4AD05F984640D5EDEC2B0F1A4B40EFAD484C50994640D5EDEC2B0F1A4B40EFAD484C5099464090BDDEFDF1164B40CF2F4AD05F98464090BDDEFDF1164B40
54906	1332	45.190424	45.197763000000002	54.203588000000003	54.179259999999999	Рабочая	0103000020E61000000100000005000000CF2F4AD05F98464090BDDEFDF1164B40CF2F4AD05F984640D5EDEC2B0F1A4B40EFAD484C50994640D5EDEC2B0F1A4B40EFAD484C5099464090BDDEFDF1164B40CF2F4AD05F98464090BDDEFDF1164B40
54353	1332	45.110860000000002	45.143056000000001	54.231026999999997	54.219794999999998	Пушкина	0103000020E61000000100000005000000A03715A9308E46408369183E221C4B40A03715A9308E46401ABFF04A921D4B4090BFB4A84F9246401ABFF04A921D4B4090BFB4A84F9246408369183E221C4B40A03715A9308E46408369183E221C4B40
54486	1332	45.175800000000002	45.180785	54.232432000000003	54.178089999999997	Пролетарская	0103000020E610000001000000050000008351499D8096464050DF32A7CB164B408351499D809646409E45EF54C01D4B40BE4D7FF6239746409E45EF54C01D4B40BE4D7FF62397464050DF32A7CB164B408351499D8096464050DF32A7CB164B40
54488	1332	45.137576000000003	45.198374000000001	54.197688999999997	54.188870999999999	Полежаева	0103000020E61000000100000005000000755B22179C914640D714C8EC2C184B40755B22179C914640B4E386DF4D194B403830B95164994640B4E386DF4D194B403830B95164994640D714C8EC2C184B40755B22179C914640D714C8EC2C184B40
54481	1332	45.104761000000003	45.138106000000001	54.208880000000001	54.202007999999999	Победы	0103000020E61000000100000005000000B972F6CE688D4640E3C3EC65DB194B40B972F6CE688D4640ED647094BC1A4B40D1B01875AD914640ED647094BC1A4B40D1B01875AD914640E3C3EC65DB194B40B972F6CE688D4640E3C3EC65DB194B40
54411	1332	45.151724999999999	45.166493000000003	54.165357	54.163922999999997	Павлика Морозова	0103000020E61000000100000005000000287E8CB96B934640F607CA6DFB144B40287E8CB96B93464014950D6B2A154B40A80183A44F95464014950D6B2A154B40A80183A44F954640F607CA6DFB144B40287E8CB96B934640F607CA6DFB144B40
54377	1332	45.151985000000003	45.154375000000002	54.196224999999998	54.192394999999998	Октябрьская	0103000020E61000000100000005000000C53D963E74934640FB743C66A0184B40C53D963E749346402CD49AE61D194B40F6285C8FC29346402CD49AE61D194B40F6285C8FC2934640FB743C66A0184B40C53D963E74934640FB743C66A0184B40
54476	1332	45.151985000000003	45.154375000000002	54.196224999999998	54.192394999999998	Октябрьская	0103000020E61000000100000005000000C53D963E74934640FB743C66A0184B40C53D963E749346402CD49AE61D194B40F6285C8FC29346402CD49AE61D194B40F6285C8FC2934640FB743C66A0184B40C53D963E74934640FB743C66A0184B40
54396	1332	45.107025	45.110860000000002	54.219794999999998	54.209333000000001	Никула Эркая	0103000020E610000001000000050000005D6DC5FEB28D46409E7C7A6CCB1A4B405D6DC5FEB28D46408369183E221C4B40A03715A9308E46408369183E221C4B40A03715A9308E46409E7C7A6CCB1A4B405D6DC5FEB28D46409E7C7A6CCB1A4B40
54456	1332	45.183157000000001	45.192534999999999	54.180793999999999	54.157654999999998	Московская	0103000020E61000000100000005000000498446B0719746408386FE092E144B40498446B07197464011A8FE4124174B40ED2AA4FCA498464011A8FE4124174B40ED2AA4FCA49846408386FE092E144B40498446B0719746408386FE092E144B40
54898	1332	45.183157000000001	45.192534999999999	54.180793999999999	54.157654999999998	Московская	0103000020E61000000100000005000000498446B0719746408386FE092E144B40498446B07197464011A8FE4124174B40ED2AA4FCA498464011A8FE4124174B40ED2AA4FCA49846408386FE092E144B40498446B0719746408386FE092E144B40
54510	1332	45.183326999999998	45.192166999999998	54.163243000000001	54.162737	Мокшанская	0103000020E61000000100000005000000A5BC564277974640B16CE690D4144B40A5BC56427797464085268925E5144B406A2FA2ED9898464085268925E5144B406A2FA2ED98984640B16CE690D4144B40A5BC564277974640B16CE690D4144B40
54374	1332	45.206899	45.219979000000002	54.168736000000003	54.164766999999998	Мичурина	0103000020E610000001000000050000009D499BAA7B9A4640E23AC61517154B409D499BAA7B9A464035D4282499154B4045679945289C464035D4282499154B4045679945289C4640E23AC61517154B409D499BAA7B9A4640E23AC61517154B40
54501	1332	45.105749000000003	45.118333999999997	54.213566999999998	54.213355999999997	Миронова	0103000020E61000000100000005000000D84AE82E898D4640E333D93F4F1B4B40D84AE82E898D46409E40D829561B4B409F008A91258F46409E40D829561B4B409F008A91258F4640E333D93F4F1B4B40D84AE82E898D4640E333D93F4F1B4B40
54515	1332	45.120311000000001	45.127138000000002	54.218752000000002	54.217305000000003	Металлургов	0103000020E61000000100000005000000AE2CD159668F4640EF2076A6D01B4B40AE2CD159668F4640A1F7C610001C4B40180AD80E46904640A1F7C610001C4B40180AD80E46904640EF2076A6D01B4B40AE2CD159668F4640EF2076A6D01B4B40
54470	1332	45.139049	45.148643	54.178601999999998	54.166964999999998	Марины Расковой	0103000020E6100000010000000500000050C58D5BCC914640CF49EF1B5F154B4050C58D5BCC91464006802A6EDC164B40C1E3DBBB0693464006802A6EDC164B40C1E3DBBB06934640CF49EF1B5F154B4050C58D5BCC914640CF49EF1B5F154B40
54492	1332	45.234135999999999	45.248617000000003	54.202603000000003	54.193080000000002	Лихачева	0103000020E610000001000000050000007B681F2BF89D46407FC16ED8B6184B407B681F2BF89D4640278925E5EE194B40651D8EAED29F4640278925E5EE194B40651D8EAED29F46407FC16ED8B6184B407B681F2BF89D46407FC16ED8B6184B40
54512	1332	45.238923999999997	45.239669999999997	54.18347	54.174433000000001	Ленинградская	0103000020E61000000100000005000000601DC70F959E4640ED2B0FD253164B40601DC70F959E464008E6E8F17B174B4089EAAD81AD9E464008E6E8F17B174B4089EAAD81AD9E4640ED2B0FD253164B40601DC70F959E4640ED2B0FD253164B40
54460	1332	45.235653999999997	45.260779999999997	54.207178999999996	54.185583000000001	Косарева	0103000020E61000000100000005000000F69507E9299E4640C7D8092FC1174B40F69507E9299E464080B56AD7841A4B40B6B9313D61A1464080B56AD7841A4B40B6B9313D61A14640C7D8092FC1174B40F69507E9299E4640C7D8092FC1174B40
54555	1332	45.189642999999997	45.199810999999997	54.218415	54.214362000000001	Кооперативная	0103000020E610000001000000050000002975C93846984640A9C0C936701B4B402975C9384698464059FAD005F51B4B40C63027689399464059FAD005F51B4B40C630276893994640A9C0C936701B4B402975C93846984640A9C0C936701B4B40
54499	1332	45.152596000000003	45.196424999999998	54.186315999999998	54.183866000000002	Коммунистическая	0103000020E610000001000000050000000EC0064488934640556CCCEB88174B400EC00644889346405B5CE333D9174B40F38E5374249946405B5CE333D9174B40F38E537424994640556CCCEB88174B400EC0064488934640556CCCEB88174B40
54508	1332	45.152596000000003	45.196424999999998	54.186315999999998	54.183866000000002	Коммунистическая	0103000020E610000001000000050000000EC0064488934640556CCCEB88174B400EC00644889346405B5CE333D9174B40F38E5374249946405B5CE333D9174B40F38E537424994640556CCCEB88174B400EC0064488934640556CCCEB88174B40
54495	1332	45.145347000000001	45.152174000000002	54.170586	54.160601999999997	Комарова	0103000020E610000001000000050000002EC901BB9A9246400AD6389B8E144B402EC901BB9A924640E69315C3D5154B4098A608707A934640E69315C3D5154B4098A608707A9346400AD6389B8E144B402EC901BB9A9246400AD6389B8E144B40
54402	1332	45.118279999999999	45.122771999999998	54.220362999999999	54.208475	Коваленко	0103000020E61000000100000005000000ACE28DCC238F46404D840D4FAF1A4B40ACE28DCC238F4640CD1FD3DA341C4B40A86E2EFEB68F4640CD1FD3DA341C4B40A86E2EFEB68F46404D840D4FAF1A4B40ACE28DCC238F46404D840D4FAF1A4B40
54507	1332	45.118279999999999	45.122771999999998	54.220362999999999	54.208475	Коваленко	0103000020E61000000100000005000000ACE28DCC238F46404D840D4FAF1A4B40ACE28DCC238F4640CD1FD3DA341C4B40A86E2EFEB68F4640CD1FD3DA341C4B40A86E2EFEB68F46404D840D4FAF1A4B40ACE28DCC238F46404D840D4FAF1A4B40
55018	1332	45.089354999999998	45.267094999999998	54.244281999999998	54.116135999999997	Зеленый Дол	0103000020E61000000100000005000000F65D11FC6F8B4640B2F1608BDD0E4B40F65D11FC6F8B46403080F0A1441F4B406AF6402B30A246403080F0A1441F4B406AF6402B30A24640B2F1608BDD0E4B40F65D11FC6F8B4640B2F1608BDD0E4B40
54482	1332	45.119709	45.126311000000001	54.228248000000001	54.223748000000001	Есенина	0103000020E61000000100000005000000B804E09F528F4640D04543C6A31C4B40B804E09F528F46404FB0FF3A371D4B40021077F52A9046404FB0FF3A371D4B40021077F52A904640D04543C6A31C4B40B804E09F528F4640D04543C6A31C4B40
54485	1332	45.149819999999998	45.162585	54.194870999999999	54.160300999999997	Гагарина	0103000020E61000000100000005000000B324404D2D9346400F4240BE84144B40B324404D2D9346402BF86D88F1184B40FBE8D495CF9446402BF86D88F1184B40FBE8D495CF9446400F4240BE84144B40B324404D2D9346400F4240BE84144B40
54489	1332	45.149819999999998	45.162585	54.194870999999999	54.160300999999997	Гагарина	0103000020E61000000100000005000000B324404D2D9346400F4240BE84144B40B324404D2D9346402BF86D88F1184B40FBE8D495CF9446402BF86D88F1184B40FBE8D495CF9446400F4240BE84144B40B324404D2D9346400F4240BE84144B40
54487	1332	45.149819999999998	45.162585	54.194870999999999	54.160300999999997	Гагарина	0103000020E61000000100000005000000B324404D2D9346400F4240BE84144B40B324404D2D9346402BF86D88F1184B40FBE8D495CF9446402BF86D88F1184B40FBE8D495CF9446400F4240BE84144B40B324404D2D9346400F4240BE84144B40
54497	1332	45.188231999999999	45.190899999999999	54.194940000000003	54.180604000000002	Володарского	0103000020E61000000100000005000000C40776FC179846406EC328081E174B40C40776FC1798464054573ECBF3184B40386744696F98464054573ECBF3184B40386744696F9846406EC328081E174B40C40776FC179846406EC328081E174B40
7216	1332	45.206657	45.240316999999997	54.186627000000001	54.184572000000003	Волгоградская улица	0103000020E61000000100000005000000A73E90BC739A4640F0E0270EA0174B40A73E90BC739A46407AC6BE64E3174B401FD61BB5C29E46407AC6BE64E3174B401FD61BB5C29E4640F0E0270EA0174B40A73E90BC739A4640F0E0270EA0174B40
54448	1332	45.123401000000001	45.148670000000003	54.226233000000001	54.220984000000001	Веселовского	0103000020E6100000010000000500000098A59D9ACB8F46403A782634491C4B4098A59D9ACB8F46405323F433F51C4B40BBF2599E079346405323F433F51C4B40BBF2599E079346403A782634491C4B4098A59D9ACB8F46403A782634491C4B40
54502	1332	45.19408	45.199325999999999	54.217841999999997	54.213135000000001	Вакеева	0103000020E6100000010000000500000062670A9DD79846400551F701481B4B4062670A9DD7984640FDD8243FE21B4B400A9FAD8383994640FDD8243FE21B4B400A9FAD83839946400551F701481B4B4062670A9DD79846400551F701481B4B40
6962	1332	45.171092000000002	45.172736	54.194918000000001	54.180450999999998	Ботевградская улица	0103000020E61000000100000005000000BA4DB857E6954640E7C3B30419174B40BA4DB857E69546406CB3B112F3184B40C26B97361C9646406CB3B112F3184B40C26B97361C964640E7C3B30419174B40BA4DB857E6954640E7C3B30419174B40
54473	1332	45.157474000000001	45.197952000000001	54.187590999999998	54.186357999999998	Богдана Хмельницкого	0103000020E6100000010000000500000033FCA71B289446408AAC3594DA174B4033FCA71B2894464010035DFB02184B40C216BB7D5699464010035DFB02184B40C216BB7D569946408AAC3594DA174B4033FCA71B289446408AAC3594DA174B40
54483	1332	45.137099999999997	45.138483999999998	54.229148000000002	54.225574999999999	Анны Лусс	0103000020E610000001000000050000000B24287E8C914640C9E53FA4DF1C4B400B24287E8C914640CFF8BEB8541D4B407782FDD7B9914640CFF8BEB8541D4B407782FDD7B9914640C9E53FA4DF1C4B400B24287E8C914640C9E53FA4DF1C4B40
54506	1332	45.152264000000002	45.195571000000001	54.171013000000002	54.169511	Александра Невского	0103000020E61000000100000005000000D82D02637D934640F8A75489B2154B40D82D02637D9346406E1805C1E3154B40E4857478089946406E1805C1E3154B40E485747808994640F8A75489B2154B40D82D02637D934640F8A75489B2154B40
54423	1332	45.190424	45.197763000000002	54.203588000000003	54.179259999999999	 Рабочая	0103000020E61000000100000005000000CF2F4AD05F98464090BDDEFDF1164B40CF2F4AD05F984640D5EDEC2B0F1A4B40EFAD484C50994640D5EDEC2B0F1A4B40EFAD484C5099464090BDDEFDF1164B40CF2F4AD05F98464090BDDEFDF1164B40
54484	1332	45.110860000000002	45.143056000000001	54.231026999999997	54.219794999999998	 Пушкина	0103000020E61000000100000005000000A03715A9308E46408369183E221C4B40A03715A9308E46401ABFF04A921D4B4090BFB4A84F9246401ABFF04A921D4B4090BFB4A84F9246408369183E221C4B40A03715A9308E46408369183E221C4B40
54475	1332	45.162602999999997	45.188457	54.195149999999998	54.194412999999997	 Васенко	0103000020E61000000100000005000000A19DD32CD094464068757286E2184B40A19DD32CD09446403EE8D9ACFA184B40E4D9E55B1F9846403EE8D9ACFA184B40E4D9E55B1F98464068757286E2184B40A19DD32CD094464068757286E2184B40
54548	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	бульвар Школьный	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54382	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	бульвар Горшкова	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54342	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Юрасова	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
55076	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Энергетическая	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54341	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Тухачевского	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54431	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Титова	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54434	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Терешковой	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54331	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Станиславского	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54527	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Революции 1905 года	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54458	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Полежаева	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54625	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Мира	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54437	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Маяковского	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54588	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Луговая	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54451	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Ленина	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54474	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Красноармейская	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54635	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	Карла Маркса	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54375	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	З.Космодемьянской	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54352	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	40 Лет Победы 	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54340	32650	44.892874999999997	44.989094000000001	54.080613	54.018019000000002	 Байкузова	0103000020E610000001000000050000003F355EBA4972464073DA53724E024B403F355EBA49724640F450DB86510A4B40BD55D7A19A7E4640F450DB86510A4B40BD55D7A19A7E464073DA53724E024B403F355EBA4972464073DA53724E024B40
54959	56533	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	пл. Советская	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
54349	56533	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	Коммунистическая	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
81074	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Щорса	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54540	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Школьная	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54387	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Фролова	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54365	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Урицкого	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54789	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Сосновый бор	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54658	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Пионерская	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54439	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Ленина	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54682	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Кутузова	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54386	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Королева	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54958	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Желябова	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54758	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Есенина	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54609	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	Гагарина	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
54542	12510	43.882297000000001	43.978552000000001	54.064393000000003	54.025154999999998	40 лет Октября	0103000020E61000000100000005000000F12DAC1BEFF045405A2A6F4738034B40F12DAC1BEFF04540B18BA2073E084B40BBB7223141FD4540B18BA2073E084B40BBB7223141FD45405A2A6F4738034B40F12DAC1BEFF045405A2A6F4738034B40
79757	56539	44.340411000000003	44.412672000000001	53.876137999999997	53.855001000000001	Московская	0103000020E610000001000000050000006E197096922B46400E863AAC70ED4A406E197096922B464034643C4A25F04A40CAFCA36FD234464034643C4A25F04A40CAFCA36FD23446400E863AAC70ED4A406E197096922B46400E863AAC70ED4A40
54544	56539	44.340411000000003	44.412672000000001	53.876137999999997	53.855001000000001	Восточный переулок	0103000020E610000001000000050000006E197096922B46400E863AAC70ED4A406E197096922B464034643C4A25F04A40CAFCA36FD234464034643C4A25F04A40CAFCA36FD23446400E863AAC70ED4A406E197096922B46400E863AAC70ED4A40
54652	56539	44.340411000000003	44.412672000000001	53.876137999999997	53.855001000000001	Больничный переулок	0103000020E610000001000000050000006E197096922B46400E863AAC70ED4A406E197096922B464034643C4A25F04A40CAFCA36FD234464034643C4A25F04A40CAFCA36FD23446400E863AAC70ED4A406E197096922B46400E863AAC70ED4A40
81125	62088	45.175800000000002	45.180785	54.232432000000003	54.178089999999997	Пролетарская	0103000020E610000001000000050000008351499D8096464050DF32A7CB164B408351499D809646409E45EF54C01D4B40BE4D7FF6239746409E45EF54C01D4B40BE4D7FF62397464050DF32A7CB164B408351499D8096464050DF32A7CB164B40
54441	56536	46.219982999999999	46.258817000000001	54.867097999999999	54.821078999999997	Садовая	0103000020E6100000010000000500000086562767281C47405837DE1D19694B4086562767281C4740A8363811FD6E4B400D535BEA20214740A8363811FD6E4B400D535BEA202147405837DE1D19694B4086562767281C47405837DE1D19694B40
54415	24809	45.749040999999998	45.810980000000001	54.422806000000001	54.391793999999997	микрорайон6	0103000020E610000001000000050000007B2E5393E0DF46406F62484E26324B407B2E5393E0DF4640BB46CB811E364B40E4DA5031CEE74640BB46CB811E364B40E4DA5031CEE746406F62484E26324B407B2E5393E0DF46406F62484E26324B40
54334	24809	45.749040999999998	45.810980000000001	54.422806000000001	54.391793999999997	Титова	0103000020E610000001000000050000007B2E5393E0DF46406F62484E26324B407B2E5393E0DF4640BB46CB811E364B40E4DA5031CEE74640BB46CB811E364B40E4DA5031CEE746406F62484E26324B407B2E5393E0DF46406F62484E26324B40
54363	24809	45.749040999999998	45.810980000000001	54.422806000000001	54.391793999999997	Терешковой	0103000020E610000001000000050000007B2E5393E0DF46406F62484E26324B407B2E5393E0DF4640BB46CB811E364B40E4DA5031CEE74640BB46CB811E364B40E4DA5031CEE746406F62484E26324B407B2E5393E0DF46406F62484E26324B40
9732	24809	45.749040999999998	45.810980000000001	54.422806000000001	54.391793999999997	Ленина	0103000020E610000001000000050000007B2E5393E0DF46406F62484E26324B407B2E5393E0DF4640BB46CB811E364B40E4DA5031CEE74640BB46CB811E364B40E4DA5031CEE746406F62484E26324B407B2E5393E0DF46406F62484E26324B40
54874	25950	45.856534000000003	45.897820000000003	54.484994999999998	54.467176000000002	Советская	0103000020E61000000100000005000000BFF4F6E7A2ED4640F1BC546CCC3B4B40BFF4F6E7A2ED46409CDCEF50143E4B40EDD808C4EBF246409CDCEF50143E4B40EDD808C4EBF24640F1BC546CCC3B4B40BFF4F6E7A2ED4640F1BC546CCC3B4B40
54523	56540	45.729818000000002	45.751781000000001	54.406438000000001	54.393135999999998	Советская	0103000020E610000001000000050000001D041DAD6ADD4640AC70CB4752324B401D041DAD6ADD464003ED0E2906344B4089601C5C3AE0464003ED0E2906344B4089601C5C3AE04640AC70CB4752324B401D041DAD6ADD4640AC70CB4752324B40
54696	25800	45.688693000000001	45.718184000000001	54.286665999999997	54.275123000000001	Подлесная	0103000020E61000000100000005000000F8FD9B1727D846404FB0FF3A37234B40F8FD9B1727D846400470B378B1244B4057410C74EDDB46400470B378B1244B4057410C74EDDB46404FB0FF3A37234B40F8FD9B1727D846404FB0FF3A37234B40
54683	56557	45.812750000000001	45.852131999999997	54.329804000000003	54.301921	Луначарского	0103000020E6100000010000000500000079E9263108E84640E17CEA58A5264B4079E9263108E84640850B7904372A4B4002F04FA912ED4640850B7904372A4B4002F04FA912ED4640E17CEA58A5264B4079E9263108E84640E17CEA58A5264B40
54875	45559	45.652095000000003	45.680472999999999	54.441580999999999	54.422628000000003	Молодежная	0103000020E610000001000000050000004C7155D977D34640DC2F9FAC18364B404C7155D977D346407AC4E8B985384B40CF6740BD19D746407AC4E8B985384B40CF6740BD19D74640DC2F9FAC18364B404C7155D977D34640DC2F9FAC18364B40
55033	45487	45.692016000000002	45.721760000000003	54.540512999999997	54.525410000000001	Центральная	0103000020E610000001000000050000008527F4FA93D84640E57E87A240434B408527F4FA93D846400B08AD872F454B40CEC7B5A162DC46400B08AD872F454B40CEC7B5A162DC4640E57E87A240434B408527F4FA93D84640E57E87A240434B40
54891	25240	45.66592	45.700172999999999	54.497247999999999	54.480721000000003	Большая	0103000020E610000001000000050000004CE0D6DD3CD546400EC00644883D4B404CE0D6DD3CD546402E008DD2A53F4B406745D4449FD946402E008DD2A53F4B406745D4449FD946400EC00644883D4B404CE0D6DD3CD546400EC00644883D4B40
54883	25784	45.609406999999997	45.642851999999998	54.266278999999997	54.243451	Ленинская	0103000020E610000001000000050000000B7A6F0C01CE4640D9960167291F4B400B7A6F0C01CE4640484E266E15224B4087156EF948D24640484E266E15224B4087156EF948D24640D9960167291F4B400B7A6F0C01CE4640D9960167291F4B40
55031	45483	45.736905	45.758904999999999	54.558576000000002	54.542414999999998	Советская	0103000020E6100000010000000500000023A12DE752DE46400FEECEDA6D454B4023A12DE752DE46404E2A1A6B7F474B40ACE28DCC23E146404E2A1A6B7F474B40ACE28DCC23E146400FEECEDA6D454B4023A12DE752DE46400FEECEDA6D454B40
54633	25505	45.973602	46.030124000000001	54.449674999999999	54.429552000000001	Гагарина	0103000020E61000000100000005000000FCA886FD9EFC464038F7578FFB364B40FCA886FD9EFC4640166A4DF38E394B4090696D1ADB034740166A4DF38E394B4090696D1ADB03474038F7578FFB364B40FCA886FD9EFC464038F7578FFB364B40
54703	25599	46.035065000000003	46.065275	54.394120999999998	54.378917000000001	Ленина	0103000020E61000000100000005000000FC1D8A027D04474000732D5A80304B40FC1D8A027D0447405AD5928E72324B408A1F63EE5A0847405AD5928E72324B408A1F63EE5A08474000732D5A80304B40FC1D8A027D04474000732D5A80304B40
54873	25497	45.582808	45.609864999999999	54.322530999999998	54.305472000000002	Ленина	0103000020E6100000010000000500000070ECD97399CA4640FFEBDCB419274B4070ECD97399CA46401C7920B248294B40CEFC6A0E10CE46401C7920B248294B40CEFC6A0E10CE4640FFEBDCB419274B4070ECD97399CA4640FFEBDCB419274B40
54897	25406	45.584927999999998	45.612650000000002	54.440769000000003	54.422255999999997	Площадь	0103000020E61000000100000005000000E141B3EBDECA464017450F7C0C364B40E141B3EBDECA46409A0B5C1E6B384B407CF2B0506BCE46409A0B5C1E6B384B407CF2B0506BCE464017450F7C0C364B40E141B3EBDECA464017450F7C0C364B40
54909	45403	45.651350000000001	45.678370999999999	54.594296999999997	54.587536999999998	Центральная	0103000020E61000000100000005000000F31FD26F5FD3464050189469344B4B40F31FD26F5FD34640328E91EC114C4B4004C765DCD4D64640328E91EC114C4B4004C765DCD4D6464050189469344B4B40F31FD26F5FD3464050189469344B4B40
54345	49497	45.806542999999998	45.836168999999998	54.446821999999997	54.426000999999999	микрорайон-2	0103000020E61000000100000005000000ABE80FCD3CE746401A88653387364B40ABE80FCD3CE7464010919A7631394B40EA76F69507EB464010919A7631394B40EA76F69507EB46401A88653387364B40ABE80FCD3CE746401A88653387364B40
54391	49497	45.806542999999998	45.836168999999998	54.446821999999997	54.426000999999999	микрорайон-1	0103000020E61000000100000005000000ABE80FCD3CE746401A88653387364B40ABE80FCD3CE7464010919A7631394B40EA76F69507EB464010919A7631394B40EA76F69507EB46401A88653387364B40ABE80FCD3CE746401A88653387364B40
54344	49497	45.806542999999998	45.836168999999998	54.446821999999997	54.426000999999999	Театральная	0103000020E61000000100000005000000ABE80FCD3CE746401A88653387364B40ABE80FCD3CE7464010919A7631394B40EA76F69507EB464010919A7631394B40EA76F69507EB46401A88653387364B40ABE80FCD3CE746401A88653387364B40
54390	49497	45.806542999999998	45.836168999999998	54.446821999999997	54.426000999999999	Комсомольская	0103000020E61000000100000005000000ABE80FCD3CE746401A88653387364B40ABE80FCD3CE7464010919A7631394B40EA76F69507EB464010919A7631394B40EA76F69507EB46401A88653387364B40ABE80FCD3CE746401A88653387364B40
54639	25132	45.829495000000001	45.859723000000002	54.436726999999998	54.415671000000003	Советская	0103000020E61000000100000005000000079964E42CEA4640A47213B534354B40079964E42CEA4640DD239BABE6374B403C4F3C670BEE4640DD239BABE6374B403C4F3C670BEE4640A47213B534354B40079964E42CEA4640A47213B534354B40
54651	25132	45.829495000000001	45.859723000000002	54.436726999999998	54.415671000000003	Карла Маркса	0103000020E61000000100000005000000079964E42CEA4640A47213B534354B40079964E42CEA4640DD239BABE6374B403C4F3C670BEE4640DD239BABE6374B403C4F3C670BEE4640A47213B534354B40079964E42CEA4640A47213B534354B40
54917	25132	45.829495000000001	45.859723000000002	54.436726999999998	54.415671000000003	 Советская	0103000020E61000000100000005000000079964E42CEA4640A47213B534354B40079964E42CEA4640DD239BABE6374B403C4F3C670BEE4640DD239BABE6374B403C4F3C670BEE4640A47213B534354B40079964E42CEA4640A47213B534354B40
54562	25304	45.656694999999999	45.695430000000002	54.360191	54.339689	Видяйкина	0103000020E610000001000000050000002E39EE940ED44640CDE7DCED7A2B4B402E39EE940ED4464022A81ABD1A2E4B402254A9D903D9464022A81ABD1A2E4B402254A9D903D94640CDE7DCED7A2B4B402E39EE940ED44640CDE7DCED7A2B4B40
54700	25318	45.541387	45.582017999999998	54.375554999999999	54.362101000000003	Молодежная	0103000020E6100000010000000500000062BD512B4CC54640A96C5853592E4B4062BD512B4CC54640B56CAD2F12304B4077D7D9907FCA4640B56CAD2F12304B4077D7D9907FCA4640A96C5853592E4B4062BD512B4CC54640A96C5853592E4B40
54560	25188	45.750227000000002	45.789726000000002	54.510039999999996	54.488635000000002	Центральная	0103000020E61000000100000005000000C1C9367007E046402A5778978B3E4B40C1C9367007E046406FD39FFD48414B408466D7BD15E546406FD39FFD48414B408466D7BD15E546402A5778978B3E4B40C1C9367007E046402A5778978B3E4B40
54900	56574	43.042138999999999	43.062916999999999	54.106639999999999	54.096023000000002	Школьная	0103000020E610000001000000050000006D718DCF64854540F8544E7B4A0C4B406D718DCF6485454004392861A60D4B4064AE0CAA0D88454004392861A60D4B4064AE0CAA0D884540F8544E7B4A0C4B406D718DCF64854540F8544E7B4A0C4B40
54872	24487	43.215181999999999	43.250225	54.184545	54.154017000000003	Советская 1-я	0103000020E610000001000000050000000C5872158B9B454097033DD4B6134B400C5872158B9B4540F6D1A92B9F174B4020D26F5F07A04540F6D1A92B9F174B4020D26F5F07A0454097033DD4B6134B400C5872158B9B454097033DD4B6134B40
54356	49253	43.21405	43.262926999999998	54.088819999999998	54.063991999999999	мкр 3-й	0103000020E61000000100000005000000BADA8AFD659B4540529ACDE330084B40BADA8AFD659B4540889D29745E0B4B40211E8997A7A14540889D29745E0B4B40211E8997A7A14540529ACDE330084B40BADA8AFD659B4540529ACDE330084B40
54440	49253	43.21405	43.262926999999998	54.088819999999998	54.063991999999999	Студенческая	0103000020E61000000100000005000000BADA8AFD659B4540529ACDE330084B40BADA8AFD659B4540889D29745E0B4B40211E8997A7A14540889D29745E0B4B40211E8997A7A14540529ACDE330084B40BADA8AFD659B4540529ACDE330084B40
54443	49253	43.21405	43.262926999999998	54.088819999999998	54.063991999999999	Садовая	0103000020E61000000100000005000000BADA8AFD659B4540529ACDE330084B40BADA8AFD659B4540889D29745E0B4B40211E8997A7A14540889D29745E0B4B40211E8997A7A14540529ACDE330084B40BADA8AFD659B4540529ACDE330084B40
54892	24159	43.331207999999997	43.352362999999997	54.195371000000002	54.174880999999999	Молодежная	0103000020E610000001000000050000003716140665AA45408CD8278062164B403716140665AA45401DCBBBEA01194B4004A9143B1AAD45401DCBBBEA01194B4004A9143B1AAD45408CD8278062164B403716140665AA45408CD8278062164B40
55034	19739	43.062935000000003	43.108047999999997	54.048563999999999	54.027842	Школьная	0103000020E610000001000000050000000B630B410E88454045BA9F5390034B400B630B410E884540A8E15B5837064B40F8325184D48D4540A8E15B5837064B40F8325184D48D454045BA9F5390034B400B630B410E88454045BA9F5390034B40
54822	18409	43.454807000000002	43.494441000000002	54.010469000000001	54.000112999999999	Ленина	0103000020E61000000100000005000000F67EA31D37BA4540F8A6E9B303004B40F67EA31D37BA4540984F560C57014B409966BAD749BF4540984F560C57014B409966BAD749BF4540F8A6E9B303004B40F67EA31D37BA4540F8A6E9B303004B40
54800	9608	43.136220000000002	43.158192	54.038254000000002	54.024970000000003	Советская	0103000020E61000000100000005000000D3872EA86F914540C9B08A3732034B40D3872EA86F9145407978CF81E5044B40923EADA23F9445407978CF81E5044B40923EADA23F944540C9B08A3732034B40D3872EA86F914540C9B08A3732034B40
55045	17812	43.388547000000003	43.412047000000001	54.047792000000001	54.029634999999999	Восточная	0103000020E61000000100000005000000BEFA78E8BBB1454092E86514CB034B40BEFA78E8BBB1454056815A0C1E064B401CB5C2F4BDB4454056815A0C1E064B401CB5C2F4BDB4454092E86514CB034B40BEFA78E8BBB1454092E86514CB034B40
54636	27981	43.135832999999998	43.170904	54.141359999999999	54.108350000000002	Эрькина	0103000020E61000000100000005000000D95BCAF962914540C442AD69DE0D4B40D95BCAF962914540357BA01518124B40B760A92EE0954540357BA01518124B40B760A92EE0954540C442AD69DE0D4B40D95BCAF962914540C442AD69DE0D4B40
54859	17942	43.054338000000001	43.105604999999997	54.083818999999998	54.070073000000001	Школьная	0103000020E610000001000000050000000C772E8CF486454093AAED26F8084B400C772E8CF486454047E4BB94BA0A4B40A4A5F276848D454047E4BB94BA0A4B40A4A5F276848D454093AAED26F8084B400C772E8CF486454093AAED26F8084B40
54518	24567	43.165126999999998	43.201661999999999	54.240073000000002	54.219847000000001	Центральная	0103000020E61000000100000005000000E257ACE122954540D68F4DF2231C4B40E257ACE12295454089D349B6BA1E4B40486C770FD099454089D349B6BA1E4B40486C770FD0994540D68F4DF2231C4B40E257ACE122954540D68F4DF2231C4B40
55089	56604	43.135742999999998	43.159809000000003	54.061439	54.044714999999997	Центральная	0103000020E6100000010000000500000099D4D0066091454000529B38B9054B4099D4D0066091454077D9AF3BDD074B40A14D0E9F7494454077D9AF3BDD074B40A14D0E9F7494454000529B38B9054B4099D4D0066091454000529B38B9054B40
54890	24193	43.437541000000003	43.477004000000001	54.154549000000003	54.135331000000001	Школьная	0103000020E610000001000000050000005FD4EE5701B845404791B58652114B405FD4EE5701B845409450FA42C8134B40D50792770EBD45409450FA42C8134B40D50792770EBD45404791B58652114B405FD4EE5701B845404791B58652114B40
54697	49353	43.102012000000002	43.125539000000003	54.174860000000002	54.159421000000002	Садовая	0103000020E6100000010000000500000058E6ADBA0E8D4540D7A546E867144B4058E6ADBA0E8D454075B0FECF61164B40B0AF75A91190454075B0FECF61164B40B0AF75A911904540D7A546E867144B4058E6ADBA0E8D4540D7A546E867144B40
54821	48369	43.100745000000003	43.128773000000002	54.013421999999998	53.996778999999997	Центральная	0103000020E61000000100000005000000261E5036E58C4540772B4B7496FF4A40261E5036E58C45400186E5CFB7014B40CDCD37A27B9045400186E5CFB7014B40CDCD37A27B904540772B4B7496FF4A40261E5036E58C4540772B4B7496FF4A40
55052	48734	43.331702	43.349102000000002	54.068351	54.056137999999997	Школьная	0103000020E6100000010000000500000047020D3675AA45400B08AD872F074B4047020D3675AA45400FD3BEB9BF084B40EE7BD45FAFAC45400FD3BEB9BF084B40EE7BD45FAFAC45400B08AD872F074B4047020D3675AA45400B08AD872F074B40
54629	56546	43.433050000000001	43.458409000000003	54.085551000000002	54.072076000000003	Школьная	0103000020E6100000010000000500000033C4B12E6EB74540CB694FC939094B4033C4B12E6EB74540EF91CD55F30A4B4096986725ADBA4540EF91CD55F30A4B4096986725ADBA4540CB694FC939094B4033C4B12E6EB74540CB694FC939094B40
54913	20579	43.475836999999999	43.499633000000003	54.043542000000002	54.021622000000001	Советская	0103000020E61000000100000005000000069D103AE8BC4540E36F7B82C4024B40069D103AE8BC45405000C5C892054B404E8061F9F3BF45405000C5C892054B404E8061F9F3BF4540E36F7B82C4024B40069D103AE8BC4540E36F7B82C4024B40
55036	6189	43.147897999999998	43.190074000000003	54.027540000000002	53.99192	Школьная	0103000020E6100000010000000500000068925852EE924540C91F0C3CF7FE4A4068925852EE9245407AAA436E86034B40F3E84658549845407AAA436E86034B40F3E8465854984540C91F0C3CF7FE4A4068925852EE924540C91F0C3CF7FE4A40
54595	32998	43.273473000000003	43.306801	54.112658000000003	54.089454000000003	Почтовая	0103000020E6100000010000000500000065ABCB2901A345408A3F8A3A730B4B4065ABCB2901A34540FFD0CC936B0E4B40A7B0524145A74540FFD0CC936B0E4B40A7B0524145A745408A3F8A3A730B4B4065ABCB2901A345408A3F8A3A730B4B40
54360	47003	43.237693	43.280192999999997	54.066026000000001	54.028841	Школьная	0103000020E610000001000000050000007BBE66B96C9E454058E4D70FB1034B407BBE66B96C9E4540C5573B8A73084B40B8C83D5DDDA34540C5573B8A73084B40B8C83D5DDDA3454058E4D70FB1034B407BBE66B96C9E454058E4D70FB1034B40
54815	24583	42.965288000000001	43.014910999999998	54.265121999999998	54.241531000000002	Советская	0103000020E61000000100000005000000529CA38E8E7B45402FFCE07CEA1E4B40529CA38E8E7B45409DB98784EF214B40E2AC889AE88145409DB98784EF214B40E2AC889AE88145402FFCE07CEA1E4B40529CA38E8E7B45402FFCE07CEA1E4B40
54887	24360	43.103062999999999	43.128449000000003	54.193379999999998	54.176640999999996	Советская 2-я	0103000020E61000000100000005000000BD361B2B318D4540FD101B2C9C164B40BD361B2B318D4540A9D903ADC0184B401A1A4F0471904540A9D903ADC0184B401A1A4F0471904540FD101B2C9C164B40BD361B2B318D4540FD101B2C9C164B40
54911	47476	43.101024000000002	43.122681999999998	54.005479999999999	53.985979999999998	Школьная	0103000020E61000000100000005000000390EBC5AEE8C45404A41B79734FE4A40390EBC5AEE8C45401B649291B3004B4068E7340BB48F45401B649291B3004B4068E7340BB48F45404A41B79734FE4A40390EBC5AEE8C45404A41B79734FE4A40
55030	49186	42.502924999999998	42.533154000000003	54.783835000000003	54.761741999999998	Верхняя	0103000020E610000001000000050000009FABADD85F404540ACFE08C380614B409FABADD85F404540E73A8DB454644B40A5DDE8633E444540E73A8DB454644B40A5DDE8633E444540ACFE08C380614B409FABADD85F404540ACFE08C380614B40
54871	23279	42.520693999999999	42.542397000000001	54.716298999999999	54.702827999999997	Советская	0103000020E61000000100000005000000999CDA19A6424540465B9544F6594B40999CDA19A6424540299485AFAF5B4B406939D0436D454540299485AFAF5B4B406939D0436D454540465B9544F6594B40999CDA19A6424540465B9544F6594B40
55032	23774	42.813796000000004	42.832993000000002	54.638002	54.627943999999999	Школьная	0103000020E61000000100000005000000CDCEA2772A68454016DC0F7860504B40CDCEA2772A6845402C64AE0CAA514B400266BE839F6A45402C64AE0CAA514B400266BE839F6A454016DC0F7860504B40CDCEA2772A68454016DC0F7860504B40
54455	56538	42.695847000000001	42.731932999999998	54.785024	54.753050999999999	проспект Ленина	0103000020E610000001000000050000008602B683115945402C9CA4F963604B408602B683115945409D499BAA7B644B407CEE04FBAF5D45409D499BAA7B644B407CEE04FBAF5D45402C9CA4F963604B408602B683115945402C9CA4F963604B40
55087	56538	42.695847000000001	42.731932999999998	54.785024	54.753050999999999	Школьная	0103000020E610000001000000050000008602B683115945402C9CA4F963604B408602B683115945409D499BAA7B644B407CEE04FBAF5D45409D499BAA7B644B407CEE04FBAF5D45402C9CA4F963604B408602B683115945402C9CA4F963604B40
55053	56538	42.695847000000001	42.731932999999998	54.785024	54.753050999999999	Центральная	0103000020E610000001000000050000008602B683115945402C9CA4F963604B408602B683115945409D499BAA7B644B407CEE04FBAF5D45409D499BAA7B644B407CEE04FBAF5D45402C9CA4F963604B408602B683115945402C9CA4F963604B40
54478	56538	42.695847000000001	42.731932999999998	54.785024	54.753050999999999	Московская	0103000020E610000001000000050000008602B683115945402C9CA4F963604B408602B683115945409D499BAA7B644B407CEE04FBAF5D45409D499BAA7B644B407CEE04FBAF5D45402C9CA4F963604B408602B683115945402C9CA4F963604B40
54452	56538	42.695847000000001	42.731932999999998	54.785024	54.753050999999999	Ленина	0103000020E610000001000000050000008602B683115945402C9CA4F963604B408602B683115945409D499BAA7B644B407CEE04FBAF5D45409D499BAA7B644B407CEE04FBAF5D45402C9CA4F963604B408602B683115945402C9CA4F963604B40
54868	23205	42.772168000000001	42.783963	54.746980999999998	54.737636999999999	Центральная	0103000020E610000001000000050000004582A966D6624540E7A8A3E36A5E4B404582A966D6624540DFDDCA129D5F4B4014234BE658644540DFDDCA129D5F4B4014234BE658644540E7A8A3E36A5E4B404582A966D6624540E7A8A3E36A5E4B40
55026	23671	42.944681000000003	42.970444000000001	54.729745999999999	54.713251999999997	Новая	0103000020E610000001000000050000008813984EEB7845403EE76ED74B5B4B408813984EEB78454083312251685D4B40BA4C4D82377C454083312251685D4B40BA4C4D82377C45403EE76ED74B5B4B408813984EEB7845403EE76ED74B5B4B40
54885	23483	42.644418999999999	42.671709999999997	54.650167000000003	54.634172	Школьная	0103000020E61000000100000005000000E4F560527C524540FB04508C2C514B40E4F560527C5245401FF818AC38534B40B532E197FA5545401FF818AC38534B40B532E197FA554540FB04508C2C514B40E4F560527C524540FB04508C2C514B40
55029	23817	42.586846000000001	42.607660000000003	54.764932000000002	54.752670999999999	Советская	0103000020E61000000100000005000000EBE40CC51D4B4540E5D2F88557604B40EBE40CC51D4B4540FAD4B14AE9614B402F8B89CDC74D4540FAD4B14AE9614B402F8B89CDC74D4540E5D2F88557604B40EBE40CC51D4B4540E5D2F88557604B40
54869	49116	42.882418999999999	42.902002000000003	54.71114	54.703961999999997	Центральная	0103000020E610000001000000050000003C2F151BF370454039D0436D1B5A4B403C2F151BF37045405070B1A2065B4B409B7631CD747345405070B1A2065B4B409B7631CD7473454039D0436D1B5A4B403C2F151BF370454039D0436D1B5A4B40
54870	23416	42.678654000000002	42.701003999999998	54.734392999999997	54.720438999999999	Садовая	0103000020E6100000010000000500000059A65F22DE564540A8E15B58375C4B4059A65F22DE564540A6B4FE96005E4B40BE2EC37FBA594540A6B4FE96005E4B40BE2EC37FBA594540A8E15B58375C4B4059A65F22DE564540A8E15B58375C4B40
54889	49104	42.925753	42.950026000000001	54.728726999999999	54.720537999999998	 Центральная	0103000020E61000000100000005000000429605137F7645403BC3D4963A5C4B40429605137F764540295B24ED465D4B40C32CB4739A794540295B24ED465D4B40C32CB4739A7945403BC3D4963A5C4B40429605137F7645403BC3D4963A5C4B40
79748	61830	42.416687000000003	42.441533999999997	54.763851000000003	54.748753000000001	Гагарина	0103000020E610000001000000050000008DD5E6FF5535454015E46723D75F4B408DD5E6FF553545402A029CDEC5614B403909A52F843845402A029CDEC5614B403909A52F8438454015E46723D75F4B408DD5E6FF5535454015E46723D75F4B40
54740	56566	42.545847000000002	42.575617000000001	54.739455999999997	54.730286999999997	Куликово	0103000020E6100000010000000500000053CF8250DE454540D3D85E0B7A5D4B4053CF8250DE4545405D6A847EA65E4B40C5025FD1AD4945405D6A847EA65E4B40C5025FD1AD494540D3D85E0B7A5D4B4053CF8250DE454540D3D85E0B7A5D4B40
55028	22931	42.684547000000002	42.711891000000001	54.803024000000001	54.794964	Центральная	0103000020E6100000010000000500000097C9703C9F574540A9BF5E61C1654B4097C9703C9F57454099F38C7DC9664B408BA8893E1F5B454099F38C7DC9664B408BA8893E1F5B4540A9BF5E61C1654B4097C9703C9F574540A9BF5E61C1654B40
54867	23037	42.745947000000001	42.768394999999998	54.787613999999998	54.775064999999998	Центральная	0103000020E6100000010000000500000050C6F8307B5F45401AA3755435634B4050C6F8307B5F454095EF1989D0644B4078B471C45A62454095EF1989D0644B4078B471C45A6245401AA3755435634B4050C6F8307B5F45401AA3755435634B40
55027	49151	42.964649999999999	43.013742999999998	54.735844	54.723964000000002	Поповка	0103000020E610000001000000050000000F0BB5A6797B45409DBD33DAAA5C4B400F0BB5A6797B45409A7ADD22305E4B4043C6A354C28145409A7ADD22305E4B4043C6A354C28145409DBD33DAAA5C4B400F0BB5A6797B45409DBD33DAAA5C4B40
54694	22984	42.730504000000003	42.747483000000003	54.775796999999997	54.765403999999997	Центральная	0103000020E6100000010000000500000071CCB227815D4540211D1EC2F8614B4071CCB227815D4540DEAAEB504D634B4072A8DF85AD5F4540DEAAEB504D634B4072A8DF85AD5F4540211D1EC2F8614B4071CCB227815D4540211D1EC2F8614B40
55060	56592	43.333875999999997	43.352865999999999	54.679312000000003	54.667645	Школьная	0103000020E61000000100000005000000AB75E272BCAA4540412B306475554B40AB75E272BCAA4540E3E313B2F3564B4067EF8CB62AAD4540E3E313B2F3564B4067EF8CB62AAD4540412B306475554B40AB75E272BCAA4540412B306475554B40
54731	56562	43.139175000000002	43.152551000000003	54.639913999999997	54.632185999999997	Фрунзе	0103000020E61000000100000005000000DDB5847CD0914540997E8978EB504B40DDB5847CD09145405320B3B3E8514B406EFC89CA869345405320B3B3E8514B406EFC89CA86934540997E8978EB504B40DDB5847CD0914540997E8978EB504B40
54884	22667	43.529349000000003	43.566504000000002	54.613390000000003	54.586806000000003	Советская	0103000020E61000000100000005000000CD9541B5C1C345405D8C81751C4B4B40CD9541B5C1C34540C3D84290834E4B40CF86FC3383C84540C3D84290834E4B40CF86FC3383C845405D8C81751C4B4B40CD9541B5C1C345405D8C81751C4B4B40
54669	56553	43.246245000000002	43.264525999999996	54.666749000000003	54.655433000000002	Молодежная	0103000020E61000000100000005000000DAE6C6F4849F45400EDC813AE5534B40DAE6C6F4849F454003D2FE0758554B408978EBFCDBA1454003D2FE0758554B408978EBFCDBA145400EDC813AE5534B40DAE6C6F4849F45400EDC813AE5534B40
54355	19573	43.188150999999998	43.233452999999997	54.653922999999999	54.616011999999998	Школьная	0103000020E61000000100000005000000D7DAFB5415984540C6F8307BD94E4B40D7DAFB5415984540158DB5BFB3534B409813B4C9E19D4540158DB5BFB3534B409813B4C9E19D4540C6F8307BD94E4B40D7DAFB5415984540C6F8307BD94E4B40
54412	19573	43.188150999999998	43.233452999999997	54.653922999999999	54.616011999999998	Коммунистическая	0103000020E61000000100000005000000D7DAFB5415984540C6F8307BD94E4B40D7DAFB5415984540158DB5BFB3534B409813B4C9E19D4540158DB5BFB3534B409813B4C9E19D4540C6F8307BD94E4B40D7DAFB5415984540C6F8307BD94E4B40
54517	19573	43.188150999999998	43.233452999999997	54.653922999999999	54.616011999999998	Восточная	0103000020E61000000100000005000000D7DAFB5415984540C6F8307BD94E4B40D7DAFB5415984540158DB5BFB3534B409813B4C9E19D4540158DB5BFB3534B409813B4C9E19D4540C6F8307BD94E4B40D7DAFB5415984540C6F8307BD94E4B40
54397	19573	43.188150999999998	43.233452999999997	54.653922999999999	54.616011999999998	Белинского	0103000020E61000000100000005000000D7DAFB5415984540C6F8307BD94E4B40D7DAFB5415984540158DB5BFB3534B409813B4C9E19D4540158DB5BFB3534B409813B4C9E19D4540C6F8307BD94E4B40D7DAFB5415984540C6F8307BD94E4B40
55024	48755	43.404815999999997	43.420895999999999	54.545783	54.530520000000003	Малая	0103000020E61000000100000005000000E272BC02D1B34540DDEF5014E8434B40E272BC02D1B345403CDBA337DC454B4034828DEBDFB545403CDBA337DC454B4034828DEBDFB54540DDEF5014E8434B40E272BC02D1B34540DDEF5014E8434B40
54902	22515	43.476717000000001	43.507995999999999	54.636021999999997	54.623451000000003	 Центральная	0103000020E610000001000000050000003F390A1005BD45404AD40B3ECD4F4B403F390A1005BD4540ACC43C2B69514B40D93F4F0306C14540ACC43C2B69514B40D93F4F0306C145404AD40B3ECD4F4B403F390A1005BD45404AD40B3ECD4F4B40
55062	56593	43.086579	43.121881999999999	54.685256000000003	54.671388	Центральная	0103000020E610000001000000050000009CC24A05158B4540A376BF0AF0554B409CC24A05158B4540A3B1F677B6574B404CFC51D4998F4540A3B1F677B6574B404CFC51D4998F4540A376BF0AF0554B409CC24A05158B4540A376BF0AF0554B40
54975	22448	43.227137999999997	43.251348	54.696902000000001	54.676057999999998	Центральная	0103000020E61000000100000005000000E4D6A4DB129D45407E198C1189564B40E4D6A4DB129D45402D42B11534594B401FF5D72B2CA045402D42B11534594B401FF5D72B2CA045407E198C1189564B40E4D6A4DB129D45407E198C1189564B40
55025	22511	43.222045000000001	43.229492	54.715395000000001	54.711067	Лесная	0103000020E61000000100000005000000C39E76F86B9C4540E621533E045B4B40C39E76F86B9C4540685C3810925B4B40C9586DFE5F9D4540685C3810925B4B40C9586DFE5F9D4540E621533E045B4B40C39E76F86B9C4540E621533E045B4B40
54688	22407	43.524732	43.578989999999997	54.676943000000001	54.650213999999998	Крупской	0103000020E6100000010000000500000014950D6B2AC345405FB35C363A534B4014950D6B2AC34540C9207711A6564B40035B25581CCA4540C9207711A6564B40035B25581CCA45405FB35C363A534B4014950D6B2AC345405FB35C363A534B40
54777	22189	43.282617999999999	43.310716999999997	54.597698000000001	54.577554999999997	Центральная	0103000020E6100000010000000500000066A19DD32CA4454015527E52ED494B4066A19DD32CA445403B71395E814C4B40D6A71C93C5A745403B71395E814C4B40D6A71C93C5A7454015527E52ED494B4066A19DD32CA4454015527E52ED494B40
54532	30141	43.094932999999997	43.104545000000002	54.565759999999997	54.560893999999998	Юбилейная	0103000020E61000000100000005000000D427B9C3268C4540E542E55FCB474B40D427B9C3268C454046B1DCD26A484B40ECFA05BB618D454046B1DCD26A484B40ECFA05BB618D4540E542E55FCB474B40D427B9C3268C4540E542E55FCB474B40
54896	48738	43.454394000000001	43.470500999999999	54.66677	54.651812999999997	Центральная	0103000020E61000000100000005000000D3BF249529BA4540C70DBF9B6E534B40D3BF249529BA45401AFA27B858554B401EDE736039BC45401AFA27B858554B401EDE736039BC4540C70DBF9B6E534B40D3BF249529BA4540C70DBF9B6E534B40
54526	22333	43.376061	43.398671	54.659813	54.644030000000001	Центральная	0103000020E61000000100000005000000892650C422B045404AD235936F524B40892650C422B04540E23C9CC074544B408B6EBDA607B34540E23C9CC074544B408B6EBDA607B345404AD235936F524B40892650C422B045404AD235936F524B40
55022	21906	43.154122999999998	43.170822999999999	54.561818000000002	54.554409999999997	Центральная	0103000020E61000000100000005000000DC476E4DBA934540A54929E8F6464B40DC476E4DBA934540EE26F8A6E9474B40CA332F87DD954540EE26F8A6E9474B40CA332F87DD954540A54929E8F6464B40DC476E4DBA934540A54929E8F6464B40
55064	21947	43.164560999999999	43.171416000000001	54.531821000000001	54.524621000000003	Лесная	0103000020E610000001000000050000003999B85510954540BDE5EAC726434B403999B85510954540BB29E5B512444B406D01A1F5F0954540BB29E5B512444B406D01A1F5F0954540BDE5EAC726434B403999B85510954540BDE5EAC726434B40
54916	48789	43.038832999999997	43.058632000000003	54.500765999999999	54.48762	Бугорская	0103000020E61000000100000005000000B680D07AF8844540117008556A3E4B40B680D07AF88445407079AC1919404B40E23FDD40818745407079AC1919404B40E23FDD4081874540117008556A3E4B40B680D07AF8844540117008556A3E4B40
54689	22062	43.257699000000002	43.286687000000001	54.511436000000003	54.496499999999997	Школьная	0103000020E61000000100000005000000209BE447FCA04540643BDF4F8D3F4B40209BE447FCA04540A0FF1EBC76414B401C98DC28B2A44540A0FF1EBC76414B401C98DC28B2A44540643BDF4F8D3F4B40209BE447FCA04540643BDF4F8D3F4B40
54810	22152	43.293289999999999	43.323014999999998	54.616028	54.602220000000003	Центральная	0103000020E61000000100000005000000361FD7868AA54540A27F828B154D4B40361FD7868AA54540CCB56801DA4E4B40088F368E58A94540CCB56801DA4E4B40088F368E58A94540A27F828B154D4B40361FD7868AA54540A27F828B154D4B40
54813	22269	43.327857000000002	43.345446000000003	54.562021999999999	54.547103999999997	Молодежная	0103000020E61000000100000005000000E161DA37F7A9454061C1FD8007464B40E161DA37F7A94540F6D03E56F0474B405B44149337AC4540F6D03E56F0474B405B44149337AC454061C1FD8007464B40E161DA37F7A9454061C1FD8007464B40
54708	48597	43.388672999999997	43.442222000000001	54.730291999999999	54.697256000000003	Молодежная	0103000020E610000001000000050000004AEB6F09C0B145404B7842AF3F594B404AEB6F09C0B14540E54350357A5D4B402EC901BB9AB84540E54350357A5D4B402EC901BB9AB845404B7842AF3F594B404AEB6F09C0B145404B7842AF3F594B40
54566	22705	43.548482999999997	43.569826999999997	54.561838999999999	54.549084000000001	Гагарина	0103000020E61000000100000005000000BBB4E1B034C64540E1606F6248464B40BBB4E1B034C64540054F2157EA474B405BB05417F0C84540054F2157EA474B405BB05417F0C84540E1606F6248464B40BBB4E1B034C64540E1606F6248464B40
54559	40323	43.319780999999999	43.472197999999999	54.734554000000003	54.632238000000001	Молодежная	0103000020E61000000100000005000000EB707495EEA84540ECA4BE2CED504B40EB707495EEA84540B0928FDD055E4B40499EEBFB70BC4540B0928FDD055E4B40499EEBFB70BC4540ECA4BE2CED504B40EB707495EEA84540ECA4BE2CED504B40
55035	48040	43.124037999999999	43.144807	54.637912999999998	54.626021000000001	 Поселковая	0103000020E610000001000000050000000ABB287AE08F4540FBCDC47421504B400ABB287AE08F4540BC581822A7514B40AE9D280989924540BC581822A7514B40AE9D280989924540FBCDC47421504B400ABB287AE08F4540FBCDC47421504B40
55042	22068	43.401600000000002	43.433140000000002	54.602924000000002	54.589790000000001	Центральная	0103000020E610000001000000050000006C09F9A067B3454001C11C3D7E4B4B406C09F9A067B345409CFC169D2C4D4B40734BAB2171B745409CFC169D2C4D4B40734BAB2171B7454001C11C3D7E4B4B406C09F9A067B3454001C11C3D7E4B4B40
54866	21654	44.438282999999998	44.489145000000001	54.198779000000002	54.176146000000003	 Центральная	0103000020E6100000010000000500000046B247A8193846401EA9BEF38B164B4046B247A819384640D8101C9771194B403F00A94D9C3E4640D8101C9771194B403F00A94D9C3E46401EA9BEF38B164B4046B247A8193846401EA9BEF38B164B40
54865	21613	44.768225000000001	44.799064000000001	54.433250000000001	54.419448000000003	Московская	0103000020E610000001000000050000001C7C613255624640B22FD978B0354B401C7C613255624640FA7E6ABC74374B409AB4A9BA47664640FA7E6ABC74374B409AB4A9BA47664640B22FD978B0354B401C7C613255624640B22FD978B0354B40
54357	21499	44.4482	44.487223	54.318792000000002	54.284117000000002	Комсомольский переулок	0103000020E610000001000000050000009A081B9E5E3946406B9E23F25D244B409A081B9E5E394640FC1C1F2DCE284B40F46DC1525D3E4640FC1C1F2DCE284B40F46DC1525D3E46406B9E23F25D244B409A081B9E5E3946406B9E23F25D244B40
54343	21499	44.4482	44.487223	54.318792000000002	54.284117000000002	Кирова	0103000020E610000001000000050000009A081B9E5E3946406B9E23F25D244B409A081B9E5E394640FC1C1F2DCE284B40F46DC1525D3E4640FC1C1F2DCE284B40F46DC1525D3E46406B9E23F25D244B409A081B9E5E3946406B9E23F25D244B40
54886	21482	44.734385000000003	44.771414	54.497487999999997	54.483117	Молодежная	0103000020E6100000010000000500000024D6E253005E4640219221C7D63D4B4024D6E253005E46408313D1AFAD3F4B4099D6A6B1BD6246408313D1AFAD3F4B4099D6A6B1BD624640219221C7D63D4B4024D6E253005E4640219221C7D63D4B40
54519	21382	44.510579	44.549861999999997	54.27854	54.241694000000003	Центральная	0103000020E610000001000000050000001F8315A75A414640D9D138D4EF1E4B401F8315A75A4146405D50DF32A7234B4015A8C5E0614646405D50DF32A7234B4015A8C5E061464640D9D138D4EF1E4B401F8315A75A414640D9D138D4EF1E4B40
55019	20563	44.537744000000004	44.560220000000001	54.169463	54.157432999999997	Центральная	0103000020E6100000010000000500000064CF9ECBD4444640D427B9C326144B4064CF9ECBD4444640E770ADF6B0154B405648F949B5474640E770ADF6B0154B405648F949B5474640D427B9C326144B4064CF9ECBD4444640D427B9C326144B40
55086	21294	44.560569999999998	44.585704999999997	54.218321000000003	54.200333000000001	Ленина	0103000020E61000000100000005000000328FFCC1C0474640A0A70183A4194B40328FFCC1C0474640D88349F1F11B4B40450DA661F84A4640D88349F1F11B4B40450DA661F84A4640A0A70183A4194B40328FFCC1C0474640A0A70183A4194B40
55091	56605	44.765098999999999	44.804454	54.378999999999998	54.364823999999999	Советская	0103000020E61000000100000005000000E59997C3EE614640E065868DB22E4B40E59997C3EE6146408D976E1283304B4075914259F86646408D976E1283304B4075914259F8664640E065868DB22E4B40E59997C3EE614640E065868DB22E4B40
54593	20929	44.769526999999997	44.794761000000001	54.311087999999998	54.292400000000001	Центральная	0103000020E61000000100000005000000CA3159DC7F624640DAACFA5C6D254B40CA3159DC7F624640CA1649BBD1274B4071917BBABA654640CA1649BBD1274B4071917BBABA654640DAACFA5C6D254B40CA3159DC7F624640DAACFA5C6D254B40
54880	40458	44.420971999999999	44.447823	54.519813999999997	54.494664	Новая	0103000020E610000001000000050000000F441669E235464018416326513F4B400F441669E23546406000E14389424B40C4B29943523946406000E14389424B40C4B299435239464018416326513F4B400F441669E235464018416326513F4B40
54594	20915	44.701785999999998	44.756421000000003	54.465176999999997	54.443255999999998	Ремесленная 1	0103000020E610000001000000050000003465A71FD4594640BDE0D39CBC384B403465A71FD4594640FAEC80EB8A3B4B40FA804067D2604640FAEC80EB8A3B4B40FA804067D2604640BDE0D39CBC384B403465A71FD4594640BDE0D39CBC384B40
55041	20836	44.543762999999998	44.579416999999999	54.322521000000002	54.301321999999999	Центральная	0103000020E610000001000000050000002EE3A6069A4546405CC823B891264B402EE3A6069A454640F9A23D5E48294B408BDF14562A4A4640F9A23D5E48294B408BDF14562A4A46405CC823B891264B402EE3A6069A4546405CC823B891264B40
54863	20748	44.696638	44.735418000000003	54.351255999999999	54.336376000000001	 Советская	0103000020E610000001000000050000004F93196F2B5946406494675E0E2B4B404F93196F2B5946400B43E4F4F52C4B40E371512D225E46400B43E4F4F52C4B40E371512D225E46406494675E0E2B4B404F93196F2B5946406494675E0E2B4B40
55069	56595	44.581707999999999	44.623353999999999	54.424309000000001	54.409089999999999	Чапаева	0103000020E6100000010000000500000029E96168754A4640718FA50F5D344B4029E96168754A46400133DFC14F364B4057EA5910CA4F46400133DFC14F364B4057EA5910CA4F4640718FA50F5D344B4029E96168754A4640718FA50F5D344B40
55094	56607	44.887979000000001	44.909143999999998	54.356276999999999	54.347240999999997	Молодежная	0103000020E610000001000000050000007444BE4BA9714640486AA164722C4B407444BE4BA971464093A8177C9A2D4B4064ADA1D45E74464093A8177C9A2D4B4064ADA1D45E744640486AA164722C4B407444BE4BA9714640486AA164722C4B40
54882	20641	44.829858000000002	44.857894999999999	54.399372999999997	54.387332000000001	Советская	0103000020E61000000100000005000000782975C9386A4640DE58501894314B40782975C9386A4640E4F38AA71E334B407233DC80CF6D4640E4F38AA71E334B407233DC80CF6D4640DE58501894314B40782975C9386A4640DE58501894314B40
54864	21131	44.503436999999998	44.547572000000002	54.497880000000002	54.464292999999998	Базарная	0103000020E61000000100000005000000554CA59F704046408061F9F36D3B4B40554CA59F704046408FAA2688BA3F4B40481ADCD6164646408FAA2688BA3F4B40481ADCD6164646408061F9F36D3B4B40554CA59F704046408061F9F36D3B4B40
54516	20521	44.374763000000002	44.381509000000001	54.311608	54.299393000000002	Переулок Чапаева	0103000020E610000001000000050000001C60E63BF82F46405FD3838252264B401C60E63BF82F464003965CC5E2274B4099107349D530464003965CC5E2274B4099107349D53046405FD3838252264B401C60E63BF82F46405FD3838252264B40
54565	56541	45.282708	45.292535999999998	54.237805000000002	54.230753999999997	Тепличная	0103000020E61000000100000005000000A62897C62FA44640E9B5D958891D4B40A62897C62FA44640A3E9EC64701E4B408A73D4D171A54640A3E9EC64701E4B408A73D4D171A54640E9B5D958891D4B40A62897C62FA44640E9B5D958891D4B40
54701	56559	45.119914999999999	45.141115999999997	54.092210999999999	54.077131000000001	Школьная	0103000020E6100000010000000500000061A6ED5F598F4640FF40B96DDF094B4061A6ED5F598F46406DAAEE91CD0B4B409E78CE16109246406DAAEE91CD0B4B409E78CE1610924640FF40B96DDF094B4061A6ED5F598F4640FF40B96DDF094B40
54351	19725	44.877899999999997	44.904750999999997	54.026662000000002	54.014310999999999	Садовая	0103000020E610000001000000050000004694F6065F7046408D7C5EF1D4014B404694F6065F704640E20511A969034B40FB027AE1CE734640E20511A969034B40FB027AE1CE7346408D7C5EF1D4014B404694F6065F7046408D7C5EF1D4014B40
54525	19456	44.742255	44.775232000000003	54.201892000000001	54.176341000000001	Базарная	0103000020E6100000010000000500000070253B36025F4640D3F8855792164B4070253B36025F46407AA9D898D7194B4006685BCD3A6346407AA9D898D7194B4006685BCD3A634640D3F8855792164B4070253B36025F4640D3F8855792164B40
54879	20339	44.585166000000001	44.610193000000002	54.080289999999998	54.061629000000003	Железнодорожная	0103000020E61000000100000005000000965D30B8E64A46401BBE8575E3074B40965D30B8E64A4640111956F1460A4B40C39FE1CD1A4E4640111956F1460A4B40C39FE1CD1A4E46401BBE8575E3074B40965D30B8E64A46401BBE8575E3074B40
54590	20215	44.832185000000003	44.860894999999999	54.032009000000002	54.025582999999997	Ленина	0103000020E61000000100000005000000639CBF09856A4640B22AC24D46034B40639CBF09856A4640BE16F4DE18044B401C25AFCE316E4640BE16F4DE18044B401C25AFCE316E4640B22AC24D46034B40639CBF09856A4640B22AC24D46034B40
54381	20046	44.890161999999997	44.93347	54.069429	54.054414999999999	Южная	0103000020E610000001000000050000002B1213D4F0714640B7B41A12F7064B402B1213D4F07146406E32AA0CE3084B4008E6E8F17B7746406E32AA0CE3084B4008E6E8F17B774640B7B41A12F7064B402B1213D4F0714640B7B41A12F7064B40
54407	20046	44.890161999999997	44.93347	54.069429	54.054414999999999	 пер.Школьный	0103000020E610000001000000050000002B1213D4F0714640B7B41A12F7064B402B1213D4F07146406E32AA0CE3084B4008E6E8F17B7746406E32AA0CE3084B4008E6E8F17B774640B7B41A12F7064B402B1213D4F0714640B7B41A12F7064B40
54624	18676	44.908442999999998	44.935975999999997	54.127924	54.112146000000003	Коммунистическая	0103000020E61000000100000005000000DBA337DC477446404930D5CC5A0E4B40DBA337DC47744640CF2F4AD05F104B40A2EBC20FCE774640CF2F4AD05F104B40A2EBC20FCE7746404930D5CC5A0E4B40DBA337DC477446404930D5CC5A0E4B40
55079	56600	44.685803999999997	44.716177000000002	54.205025999999997	54.187795999999999	Пролетарская	0103000020E61000000100000005000000A5BBEB6CC8574640E92807B309184B40A5BBEB6CC8574640336ABE4A3E1A4B40DE921CB0AB5B4640336ABE4A3E1A4B40DE921CB0AB5B4640E92807B309184B40A5BBEB6CC8574640E92807B309184B40
54876	19899	44.676606	44.706519999999998	54.045672000000003	54.033431999999998	Школьная	0103000020E61000000100000005000000812381069B564640E751F17F47044B40812381069B564640E52B8194D8054B4026FC523F6F5A4640E52B8194D8054B4026FC523F6F5A4640E751F17F47044B40812381069B564640E751F17F47044B40
54623	18772	45.014443999999997	45.029698000000003	54.024272000000003	54.013283999999999	Солнечная	0103000020E61000000100000005000000CCCF0D4DD9814640B0C7444AB3014B40CCCF0D4DD9814640B11A4B581B034B40D960E124CD834640B11A4B581B034B40D960E124CD834640B0C7444AB3014B40CCCF0D4DD9814640B0C7444AB3014B40
54619	18717	44.893737999999999	44.925601	54.199348000000001	54.175651000000002	Шишкеевская	0103000020E61000000100000005000000A298BC01667246403E4162BB7B164B40A298BC0166724640F2423A3C84194B408C12F4177A764640F2423A3C84194B408C12F4177A7646403E4162BB7B164B40A298BC01667246403E4162BB7B164B40
54684	19885	44.723103000000002	44.748705000000001	53.949105000000003	53.933295000000001	Садовая	0103000020E61000000100000005000000DB519CA38E5C46409A42E73576F74A40DB519CA38E5C46402CBCCB457CF94A4004ADC090D55F46402CBCCB457CF94A4004ADC090D55F46409A42E73576F74A40DB519CA38E5C46409A42E73576F74A40
54768	56567	44.821925999999998	44.851472000000001	54.085107000000001	54.069408000000003	Центральная	0103000020E61000000100000005000000B5DD04DF34694640570A815CE2084B40B5DD04DF3469464091D442C9E40A4B40D8BAD408FD6C464091D442C9E40A4B40D8BAD408FD6C4640570A815CE2084B40B5DD04DF34694640570A815CE2084B40
54862	19984	44.716966999999997	44.736541000000003	54.058537999999999	54.049895999999997	Центральная	0103000020E61000000100000005000000D6A71C93C55B4640C119FCFD62064B40D6A71C93C55B464060C9552C7E074B40E294B9F9465E464060C9552C7E074B40E294B9F9465E4640C119FCFD62064B40D6A71C93C55B4640C119FCFD62064B40
54861	19572	44.692855999999999	44.714883	54.004834000000002	53.992035999999999	Молодежная	0103000020E610000001000000050000002F6B6281AF584640323A2009FBFE4A402F6B6281AF58464056F487669E004B40B2BB4049815B464056F487669E004B40B2BB4049815B4640323A2009FBFE4A402F6B6281AF584640323A2009FBFE4A40
54905	19774	44.782390999999997	44.812942999999997	54.114114000000001	54.100807000000003	Байкузова	0103000020E61000000100000005000000A5D76663256446409C1A683EE70C4B40A5D766632564464004029D499B0E4B408D4127840E68464004029D499B0E4B408D4127840E6846409C1A683EE70C4B40A5D76663256446409C1A683EE70C4B40
54591	18835	45.068989999999999	45.094475000000003	54.111759999999997	54.103394000000002	Центральная	0103000020E6100000010000000500000022E010AAD4884640234DBC033C0D4B4022E010AAD48846401F80D4264E0E4B4012A5BDC1178C46401F80D4264E0E4B4012A5BDC1178C4640234DBC033C0D4B4022E010AAD4884640234DBC033C0D4B40
54585	18605	44.998435999999998	45.021225999999999	54.094501999999999	54.074320999999998	Ленина	0103000020E61000000100000005000000149337C0CC7F4640F833BC5983094B40149337C0CC7F46400BB43BA4180C4B4096E99788B78246400BB43BA4180C4B4096E99788B7824640F833BC5983094B40149337C0CC7F4640F833BC5983094B40
54584	18561	44.968504000000003	44.979464	54.051761999999997	54.045270000000002	Переулок Школьный	0103000020E61000000100000005000000C90567F0F77B4640B6BE4868CB054B40C90567F0F77B464078962023A0064B40FFCD8B135F7D464078962023A0064B40FFCD8B135F7D4640B6BE4868CB054B40C90567F0F77B4640B6BE4868CB054B40
54860	18460	44.992120999999997	45.008893	54.149434999999997	54.135415999999999	Центральная	0103000020E61000000100000005000000605628D2FD7E464075ADBD4F55114B40605628D2FD7E46405AF0A2AF20134B40E814E467238146405AF0A2AF20134B40E814E4672381464075ADBD4F55114B40605628D2FD7E464075ADBD4F55114B40
54878	20266	44.767380000000003	44.794249000000001	54.014194000000003	54.007230999999997	Московская	0103000020E6100000010000000500000060CD018239624640394206F2EC004B4060CD01823962464054E6E61BD1014B40BBF083F3A965464054E6E61BD1014B40BBF083F3A9654640394206F2EC004B4060CD018239624640394206F2EC004B40
54676	19670	44.673363000000002	44.691329000000003	53.935909000000002	53.927802999999997	Урледимская	0103000020E6100000010000000500000011AB3FC230564640BA10AB3FC2F64A4011AB3FC2305646401B84B9DDCBF74A4061E3FA777D5846401B84B9DDCBF74A4061E3FA777D584640BA10AB3FC2F64A4011AB3FC230564640BA10AB3FC2F64A40
54568	19466	44.605522000000001	44.657111999999998	53.997996000000001	53.976449000000002	Никольская	0103000020E610000001000000050000001781B1BE814D4640209BE447FCFC4A401781B1BE814D4640F8C43A55BEFF4A4092E7FA3E1C544640F8C43A55BEFF4A4092E7FA3E1C544640209BE447FCFC4A401781B1BE814D4640209BE447FCFC4A40
54617	32937	45.045616000000003	45.071396999999997	54.053004000000001	54.033040999999997	Советская	0103000020E610000001000000050000005116BEBED6854640AC36FFAF3A044B405116BEBED68546405247C7D5C8064B4029047289238946405247C7D5C8064B402904728923894640AC36FFAF3A044B405116BEBED6854640AC36FFAF3A044B40
54776	18330	45.082814999999997	45.102334999999997	53.988394	53.979011999999997	Школьная	0103000020E61000000100000005000000224F92AE998A46401E32E54350FD4A40224F92AE998A464004C8D0B183FE4A403A1E3350198D464004C8D0B183FE4A403A1E3350198D46401E32E54350FD4A40224F92AE998A46401E32E54350FD4A40
9946	40362	44.517954000000003	45.144385	54.262393000000003	53.927802999999997	Переходная	0103000020E610000001000000050000008C6A11514C424640BA10AB3FC2F64A408C6A11514C42464084D9041896214B4038842A357B92464084D9041896214B4038842A357B924640BA10AB3FC2F64A408C6A11514C424640BA10AB3FC2F64A40
55017	17664	45.238124999999997	45.273204	54.514426	54.491239	Клубная	0103000020E6100000010000000500000014AE47E17A9E464087C267EBE03E4B4014AE47E17A9E4640261B0FB6D8414B4075914259F8A24640261B0FB6D8414B4075914259F8A2464087C267EBE03E4B4014AE47E17A9E464087C267EBE03E4B40
54653	17620	45.211480999999999	45.250008999999999	54.525174999999997	54.505701999999999	Школьная	0103000020E61000000100000005000000D95C35CF119B4640CAC2D7D7BA404B40D95C35CF119B4640A1D634EF38434B40535A7F4B00A04640A1D634EF38434B40535A7F4B00A04640CAC2D7D7BA404B40D95C35CF119B4640CAC2D7D7BA404B40
55047	16751	45.161768000000002	45.170085999999998	54.358784999999997	54.351759999999999	Центральная	0103000020E6100000010000000500000009C556D0B49446403E05C078062D4B4009C556D0B4944640CEA5B8AAEC2D4B40F4C0C760C5954640CEA5B8AAEC2D4B40F4C0C760C59546403E05C078062D4B4009C556D0B49446403E05C078062D4B40
55023	17101	45.410187999999998	45.427759000000002	54.427300000000002	54.419217000000003	Садовая	0103000020E61000000100000005000000179B560A81B44640B07614E7A8354B40179B560A81B4464058CA32C4B1364B40EBC891CEC0B6464058CA32C4B1364B40EBC891CEC0B64640B07614E7A8354B40179B560A81B44640B07614E7A8354B40
54997	56583	45.018199000000003	45.632295999999997	54.591397000000001	54.267898000000002	Школьный переулок	0103000020E61000000100000005000000F3E8465854824640F8544E7B4A224B40F3E8465854824640ECF99AE5B24B4B4020B24813EFD04640ECF99AE5B24B4B4020B24813EFD04640F8544E7B4A224B40F3E8465854824640F8544E7B4A224B40
54498	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Центральная	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
54413	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Транспортный проезд	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
54556	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Пятинское шоссе	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
54614	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Промышленное шоссе	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
54399	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Крылова	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
54430	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Железнодорожная	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
54373	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Есенина	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
54372	16286	45.305804000000002	45.380319	54.439093999999997	54.401795	Дорожная	0103000020E61000000100000005000000357EE19524A746402159C0046E334B40357EE19524A7464056EF703B34384B401286014BAEB0464056EF703B34384B401286014BAEB046402159C0046E334B40357EE19524A746402159C0046E334B40
55015	17488	45.363115999999998	45.381540999999999	54.531658999999998	54.494100000000003	Школьная	0103000020E61000000100000005000000C153C8957AAE4640107A36AB3E3F4B40C153C8957AAE4640E1CFF0660D444B40A48AE255D6B04640E1CFF0660D444B40A48AE255D6B04640107A36AB3E3F4B40C153C8957AAE4640107A36AB3E3F4B40
54771	17404	45.448438000000003	45.474930000000001	54.394441	54.365516	Дорожная 	0103000020E610000001000000050000004F24986A66B946401615713AC92E4B404F24986A66B94640CC99ED0A7D324B40D4F19881CABC4640CC99ED0A7D324B40D4F19881CABC46401615713AC92E4B404F24986A66B946401615713AC92E4B40
54968	17325	45.112881999999999	45.131881	54.435554000000003	54.419710000000002	Школьная	0103000020E610000001000000050000004E27D9EA728E4640EFE6A90EB9354B404E27D9EA728E46402DD2C43BC0374B405DFB027AE19046402DD2C43BC0374B405DFB027AE1904640EFE6A90EB9354B404E27D9EA728E4640EFE6A90EB9354B40
54858	17244	45.520887000000002	45.557673000000001	54.562789000000002	54.545726000000002	Кирова	0103000020E61000000100000005000000AEF4DA6CACC24640D8497D59DA454B40AEF4DA6CACC2464037C64E7809484B405D6E30D461C7464037C64E7809484B405D6E30D461C74640D8497D59DA454B40AEF4DA6CACC24640D8497D59DA454B40
54856	17135	45.462515000000003	45.485368000000001	54.465595999999998	54.454098000000002	Центральная	0103000020E61000000100000005000000697407B133BB4640EA961DE21F3A4B40697407B133BB4640FF9254A6983B4B403143E38920BE4640FF9254A6983B4B403143E38920BE4640EA961DE21F3A4B40697407B133BB4640EA961DE21F3A4B40
54966	17296	45.228628999999998	45.251742999999998	54.437449000000001	54.432637	Школьная	0103000020E6100000010000000500000066F50EB7439D4640100533A660374B4066F50EB7439D46407E552E54FE374B409BFF571D39A046407E552E54FE374B409BFF571D39A04640100533A660374B4066F50EB7439D4640100533A660374B40
54855	17038	45.441924999999998	45.461652000000001	54.426960000000001	54.415104999999997	 Молодежная	0103000020E61000000100000005000000742497FF90B84640FAB31F2922354B40742497FF90B846409F5912A0A6364B400611A96917BB46409F5912A0A6364B400611A96917BB4640FAB31F2922354B40742497FF90B84640FAB31F2922354B40
54772	16950	45.363826000000003	45.376465000000003	54.476489000000001	54.460676999999997	Центральная	0103000020E610000001000000050000009EB7B1D991AE46407B82C476F73A4B409EB7B1D991AE4640AEF36F97FD3C4B40598B4F0130B04640AEF36F97FD3C4B40598B4F0130B046407B82C476F73A4B409EB7B1D991AE46407B82C476F73A4B40
55013	16992	45.394423000000003	45.412289999999999	54.454065999999997	54.443815999999998	Центральная	0103000020E6100000010000000500000026E5EE737CB2464084B872F6CE384B4026E5EE737CB24640DE1CAED51E3A4B40E23B31EBC5B44640DE1CAED51E3A4B40E23B31EBC5B4464084B872F6CE384B4026E5EE737CB2464084B872F6CE384B40
54967	16905	45.136983000000001	45.162512999999997	54.459153999999998	54.444586000000001	Школьная	0103000020E61000000100000005000000D28DB0A8889146403621AD31E8384B40D28DB0A888914640EEE9EA8EC53A4B406116DA39CD944640EEE9EA8EC53A4B406116DA39CD9446403621AD31E8384B40D28DB0A8889146403621AD31E8384B40
54857	17194	45.507269000000001	45.536949	54.497577	54.479607000000001	Химмашевская	0103000020E6100000010000000500000027A3CA30EEC0464062F71DC3633D4B4027A3CA30EEC04640F31E679AB03F4B40594FADBEBAC44640F31E679AB03F4B40594FADBEBAC4464062F71DC3633D4B4027A3CA30EEC0464062F71DC3633D4B40
54348	16845	45.357106999999999	45.388539000000002	54.353417999999998	54.328086999999996	Центральная	0103000020E610000001000000050000001A16A3AEB5AD4640129F3BC1FE294B401A16A3AEB5AD4640ABE80FCD3C2D4B403B1C5DA5BBB14640ABE80FCD3C2D4B403B1C5DA5BBB14640129F3BC1FE294B401A16A3AEB5AD4640129F3BC1FE294B40
54582	16704	45.291476000000003	45.306809999999999	54.391520999999997	54.373074000000003	Новая	0103000020E61000000100000005000000D2C8E7154FA54640747E8AE3C02F4B40D2C8E7154FA546403E59315C1D324B40FA0AD28C45A746403E59315C1D324B40FA0AD28C45A74640747E8AE3C02F4B40D2C8E7154FA54640747E8AE3C02F4B40
55011	16637	45.321945999999997	45.349381000000001	54.381034999999997	54.366675000000001	Молодежная	0103000020E61000000100000005000000FC89CA8635A9464062A1D634EF2E4B40FC89CA8635A94640D0D03FC1C5304B40016C4084B8AC4640D0D03FC1C5304B40016C4084B8AC464062A1D634EF2E4B40FC89CA8635A9464062A1D634EF2E4B40
54769	15941	45.068908999999998	45.088554999999999	54.272252000000002	54.249001	Молодёжная 	0103000020E6100000010000000500000035B39602D2884640EDD5C743DF1F4B4035B39602D2884640A3224E27D9224B40DA722EC5558B4640A3224E27D9224B40DA722EC5558B4640EDD5C743DF1F4B4035B39602D2884640EDD5C743DF1F4B40
54642	28176	45.342193999999999	45.366458000000002	54.234622000000002	54.212887000000002	Школьная	0103000020E6100000010000000500000097715303CDAB46402D5F97E13F1B4B4097715303CDAB46400876FC17081E4B40C5AD8218E8AE46400876FC17081E4B40C5AD8218E8AE46402D5F97E13F1B4B4097715303CDAB46402D5F97E13F1B4B40
54598	33141	44.937018000000002	45.046469000000002	54.252251999999999	54.206541999999999	Центральная	0103000020E61000000100000005000000B5E1B034F07746400EA0DFF76F1A4B40B5E1B034F0774640E02C25CB49204B4090A339B2F2854640E02C25CB49204B4090A339B2F28546400EA0DFF76F1A4B40B5E1B034F07746400EA0DFF76F1A4B40
55072	56598	45.258471	45.273508999999997	54.345540999999997	54.336722999999999	Молодежная	0103000020E6100000010000000500000072FBE59315A14640CF6740BD192B4B4072FBE59315A14640AC36FFAF3A2C4B40B114C95702A34640AC36FFAF3A2C4B40B114C95702A34640CF6740BD192B4B4072FBE59315A14640CF6740BD192B4B40
54818	29365	44.954822999999998	44.980685000000001	54.371653000000002	54.357971999999997	Школьная	0103000020E61000000100000005000000FB3BDBA3377A46401D71C806D22D4B40FB3BDBA3377A4640EB3A5453922F4B40C1560916877D4640EB3A5453922F4B40C1560916877D46401D71C806D22D4B40FB3BDBA3377A46401D71C806D22D4B40
54787	29365	44.954822999999998	44.980685000000001	54.371653000000002	54.357971999999997	Центральная	0103000020E61000000100000005000000FB3BDBA3377A46401D71C806D22D4B40FB3BDBA3377A4640EB3A5453922F4B40C1560916877D4640EB3A5453922F4B40C1560916877D46401D71C806D22D4B40FB3BDBA3377A46401D71C806D22D4B40
55043	49324	45.563575	45.589635000000001	54.200006999999999	54.184561000000002	Советская	0103000020E61000000100000005000000EEEBC03923C84640FC8EE1B19F174B40EEEBC03923C846404CFC51D499194B40DAC9E02879CB46404CFC51D499194B40DAC9E02879CB4640FC8EE1B19F174B40EEEBC03923C84640FC8EE1B19F174B40
55001	16127	45.516728000000001	45.550792000000001	54.267772000000001	54.255198	Комсомольская	0103000020E61000000100000005000000B876A22424C246409700FC53AA204B40B876A22424C246406B64575A46224B4000732D5A80C646406B64575A46224B4000732D5A80C646409700FC53AA204B40B876A22424C246409700FC53AA204B40
54549	32594	45.015971	45.043962999999998	54.440125000000002	54.421030000000002	Жигули	0103000020E610000001000000050000009B5775560B8246404451A04FE4354B409B5775560B8246407593180456384B40F59D5F94A08546407593180456384B40F59D5F94A08546404451A04FE4354B409B5775560B8246404451A04FE4354B40
54638	16088	44.971719999999998	45.009225000000001	54.246339999999996	54.225532000000001	Юбилейная	0103000020E610000001000000050000003F6F2A52617C4640CA198A3BDE1C4B403F6F2A52617C46402BD9B111881F4B401EA7E8482E8146402BD9B111881F4B401EA7E8482E814640CA198A3BDE1C4B403F6F2A52617C4640CA198A3BDE1C4B40
79746	61828	45.072287000000003	45.085850999999998	54.327230999999998	54.317731999999999	Нижняя	0103000020E6100000010000000500000086764EB34089464043723271AB284B4086764EB340894640629E95B4E2294B4019AA622AFD8A4640629E95B4E2294B4019AA622AFD8A464043723271AB284B4086764EB34089464043723271AB284B40
55010	45962	44.870265000000003	44.881970000000003	54.306355000000003	54.297201999999999	Заречная	0103000020E610000001000000050000003EEDF0D7646F4640242713B70A264B403EEDF0D7646F4640A9FB00A436274B40CD069964E4704640A9FB00A436274B40CD069964E4704640242713B70A264B403EEDF0D7646F4640242713B70A264B40
54650	15800	45.099091999999999	45.150421999999999	54.295341999999998	54.267398999999997	Октябрьская	0103000020E61000000100000005000000CAA5F10BAF8C4640D6FD63213A224B40CAA5F10BAF8C46404F9143C4CD254B40A94C3107419346404F9143C4CD254B40A94C310741934640D6FD63213A224B40CAA5F10BAF8C4640D6FD63213A224B40
54339	15800	45.099091999999999	45.150421999999999	54.295341999999998	54.267398999999997	Ленина	0103000020E61000000100000005000000CAA5F10BAF8C4640D6FD63213A224B40CAA5F10BAF8C46404F9143C4CD254B40A94C3107419346404F9143C4CD254B40A94C310741934640D6FD63213A224B40CAA5F10BAF8C4640D6FD63213A224B40
54612	15708	45.284962999999998	45.299677000000003	54.342350000000003	54.328516999999998	Ленина	0103000020E61000000100000005000000F7C8E6AA79A446400B9755D80C2A4B40F7C8E6AA79A446408FE4F21FD22B4B40842EE1D05BA646408FE4F21FD22B4B40842EE1D05BA646400B9755D80C2A4B40F7C8E6AA79A446400B9755D80C2A4B40
54393	15560	45.302489000000001	45.348761000000003	54.288873000000002	54.258642999999999	Фабричная	0103000020E610000001000000050000002B33A5F5B7A646406F2BBD361B214B402B33A5F5B7A6464045D95BCAF9244B40658F5033A4AC464045D95BCAF9244B40658F5033A4AC46406F2BBD361B214B402B33A5F5B7A646406F2BBD361B214B40
54964	45943	44.916150000000002	44.932940000000002	54.280000999999999	54.271357999999999	Садовая	0103000020E610000001000000050000007E1D38674475464005C1E3DBBB224B407E1D38674475464074ECA012D7234B40AC90F2936A77464074ECA012D7234B40AC90F2936A77464005C1E3DBBB224B407E1D38674475464005C1E3DBBB224B40
54432	15225	45.380076000000003	45.421444000000001	54.190783000000003	54.169822000000003	Центральная	0103000020E610000001000000050000004CFF9254A6B04640171230BABC154B404CFF9254A6B04640FFD0CC936B184B40378C82E0F1B54640FFD0CC936B184B40378C82E0F1B54640171230BABC154B404CFF9254A6B04640171230BABC154B40
79740	61824	45.248797000000003	45.276069	54.273929000000003	54.260525999999999	Долганова	0103000020E61000000100000005000000E52B8194D89F4640FCE07CEA58214B40E52B8194D89F46408736001B10234B403F389F3A56A346408736001B10234B403F389F3A56A34640FCE07CEA58214B40E52B8194D89F4640FCE07CEA58214B40
54394	45763	45.328539999999997	45.366996999999998	54.255982000000003	54.240125999999997	Молодежная	0103000020E61000000100000005000000C3B645990DAA4640AB75E272BC1E4B40C3B645990DAA4640AE2EA704C4204B40745DF8C1F9AE4640AE2EA704C4204B40745DF8C1F9AE4640AB75E272BC1E4B40C3B645990DAA4640AB75E272BC1E4B40
54770	14950	43.743147999999998	43.782485999999999	54.334082000000002	54.315578000000002	Ленина	0103000020E610000001000000050000003D0B42791FDF454026AB22DC64284B403D0B42791FDF45405517F032C32A4B40F7C9518028E445405517F032C32A4B40F7C9518028E4454026AB22DC64284B403D0B42791FDF454026AB22DC64284B40
42040	1219	43.625324999999997	43.647837000000003	54.530932999999997	54.515675000000002	Садовая	0103000020E61000000100000005000000832F4CA60AD04540B22E6EA301424B40832F4CA60AD04540FFAECF9CF5434B40C311A452ECD24540FFAECF9CF5434B40C311A452ECD24540B22E6EA301424B40832F4CA60AD04540B22E6EA301424B40
54427	14600	43.776116999999999	43.801538999999998	54.460881000000001	54.433799	Садовая	0103000020E61000000100000005000000506F46CD57E34540CD04C3B986374B40506F46CD57E34540842C0B26FE3A4B40F9BB77D498E64540842C0B26FE3A4B40F9BB77D498E64540CD04C3B986374B40506F46CD57E34540CD04C3B986374B40
54428	14896	44.080025999999997	44.138981999999999	54.428499000000002	54.401538000000002	Советская	0103000020E61000000100000005000000336ABE4A3E0A4640F60CE19865334B40336ABE4A3E0A464032AF230ED9364B40C85D8429CA11464032AF230ED9364B40C85D8429CA114640F60CE19865334B40336ABE4A3E0A4640F60CE19865334B40
54854	14753	43.803291000000002	43.820898	54.406899000000003	54.392893999999998	Нижняя	0103000020E61000000100000005000000E8154F3DD2E64540B665C0594A324B40E8154F3DD2E6454037E3344415344B4008AD872F13E9454037E3344415344B4008AD872F13E94540B665C0594A324B40E8154F3DD2E64540B665C0594A324B40
54586	14849	43.904727999999999	43.940956999999997	54.344963999999997	54.329641000000002	 Молодежная	0103000020E6100000010000000500000043E38920CEF34540DB3521AD312A4B4043E38920CEF345400F26C5C7272C4B409CF86A4771F845400F26C5C7272C4B409CF86A4771F84540DB3521AD312A4B4043E38920CEF34540DB3521AD312A4B40
54962	14552	43.522441000000001	43.557555999999998	54.408245999999998	54.385900999999997	Коммунистическая	0103000020E61000000100000005000000768BC058DFC24540313F373465314B40768BC058DFC24540855CA96741344B4023D8B8FE5DC74540855CA96741344B4023D8B8FE5DC74540313F373465314B40768BC058DFC24540313F373465314B40
54814	14500	44.235182999999999	44.275543999999996	54.363449000000003	54.340628000000002	Садовая	0103000020E610000001000000050000009FC9FE791A1E46400B0DC4B2992B4B409FC9FE791A1E4640C861307F852E4B40F44D9A0645234640C861307F852E4B40F44D9A06452346400B0DC4B2992B4B409FC9FE791A1E46400B0DC4B2992B4B40
54547	14472	43.487307999999999	43.530185000000003	54.480103999999997	54.45693	Ленина	0103000020E61000000100000005000000228AC91B60BE4540D847A7AE7C3A4B40228AC91B60BE4540E256410C743D4B4036EA211ADDC34540E256410C743D4B4036EA211ADDC34540D847A7AE7C3A4B40228AC91B60BE4540D847A7AE7C3A4B40
54773	14285	43.791091000000002	43.828425000000003	54.523383000000003	54.502110000000002	Подгора	0103000020E6100000010000000500000079944A7842E545404E7FF62345404B4079944A7842E545402524D236FE424B402B1895D409EA45402524D236FE424B402B1895D409EA45404E7FF62345404B4079944A7842E545404E7FF62345404B40
54580	14687	43.754475999999997	43.781219	54.419642000000003	54.405264000000003	Центральная	0103000020E61000000100000005000000F6CE68AB92E04540821FD5B0DF334B40F6CE68AB92E0454097033DD4B6354B40C501F4FBFEE3454097033DD4B6354B40C501F4FBFEE34540821FD5B0DF334B40F6CE68AB92E04540821FD5B0DF334B40
54661	56551	43.404591000000003	44.365501000000002	54.570791	54.235095000000001	Лесная	0103000020E61000000100000005000000C3A04CA3C9B34540003ACC97171E4B40C3A04CA3C9B34540F2ECF2AD0F494B40E1D39CBCC82E4640F2ECF2AD0F494B40E1D39CBCC82E4640003ACC97171E4B40C3A04CA3C9B34540003ACC97171E4B40
54853	14027	43.735709999999997	43.758465000000001	54.383378999999998	54.367798000000001	Большая	0103000020E610000001000000050000008AABCABE2BDE454061C43E01142F4B408AABCABE2BDE4540917C259012314B409014916115E14540917C259012314B409014916115E1454061C43E01142F4B408AABCABE2BDE454061C43E01142F4B40
54583	14408	43.947550999999997	44.013496000000004	54.427818000000002	54.399037999999997	пл. Центральная	0103000020E610000001000000050000006325E65949F945403DEE5BAD13334B406325E65949F94540F0517FBDC2364B403C50A73CBA014640F0517FBDC2364B403C50A73CBA0146403DEE5BAD13334B406325E65949F945403DEE5BAD13334B40
54961	14379	43.488250999999998	43.518749	54.422255999999997	54.410929000000003	Ленина	0103000020E61000000100000005000000A19E3E027FBE45402FFD4B5299344B40A19E3E027FBE454017450F7C0C364B4096EA025E66C2454017450F7C0C364B4096EA025E66C245402FFD4B5299344B40A19E3E027FBE45402FFD4B5299344B40
55007	14308	43.637003	43.664447000000003	54.418421000000002	54.402124999999998	Центральная	0103000020E61000000100000005000000193A765089D14540B6F3FDD478334B40193A765089D14540D57ABFD18E354B4071766B990CD54540D57ABFD18E354B4071766B990CD54540B6F3FDD478334B40193A765089D14540B6F3FDD478334B40
54429	13614	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	Микрорайон3	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
54367	13614	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	Микрорайон-3	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
54338	13614	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	Микрорайон-1	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
54369	13614	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	Кирова	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
54329	13614	43.753227000000003	43.821103999999998	54.436427999999999	54.414355	Интернациональная	0103000020E610000001000000050000006BBB09BE69E0454090F7AA9509354B406BBB09BE69E04540838769DFDC374B40B14E95EF19E94540838769DFDC374B40B14E95EF19E9454090F7AA9509354B406BBB09BE69E0454090F7AA9509354B40
54613	14221	43.783465	43.806317999999997	54.494486999999999	54.474747000000001	Зелёная	0103000020E61000000100000005000000C347C49448E44540E36F7B82C43C4B40C347C49448E4454009A69A594B3F4B408B16A06D35E7454009A69A594B3F4B408B16A06D35E74540E36F7B82C43C4B40C347C49448E44540E36F7B82C43C4B40
54577	14128	44.131337000000002	44.169111000000001	54.369681	54.348227999999999	Пролетарская	0103000020E610000001000000050000009CE09BA6CF10464097C62FBC922C4B409CE09BA6CF104640EE79FEB4512F4B406A32E36DA5154640EE79FEB4512F4B406A32E36DA515464097C62FBC922C4B409CE09BA6CF10464097C62FBC922C4B40
54578	14658	43.801817	43.823484999999998	54.423979000000003	54.405301000000001	 Кооперативная	0103000020E610000001000000050000003C3080F0A1E645409F0436E7E0334B403C3080F0A1E645406C98A1F144364B408FDFDBF467E945406C98A1F144364B408FDFDBF467E945409F0436E7E0334B403C3080F0A1E645409F0436E7E0334B40
54765	14184	43.75515	43.774490999999998	54.486668000000002	54.462952999999999	Центральная	0103000020E6100000010000000500000086C954C1A8E04540E44A3D0B423B4B4086C954C1A8E045403F0114234B3E4B40EE05668522E345403F0114234B3E4B40EE05668522E34540E44A3D0B423B4B4086C954C1A8E04540E44A3D0B423B4B40
54543	14093	43.751933999999999	43.787892999999997	54.313267000000003	54.295825999999998	Центральная	0103000020E610000001000000050000000F60915F3FE045403BA759A0DD254B400F60915F3FE0454041F50F2219284B40A8DF85ADD9E4454041F50F2219284B40A8DF85ADD9E445403BA759A0DD254B400F60915F3FE045403BA759A0DD254B40
54576	13993	43.703136999999998	43.746858000000003	54.395657	54.380521000000002	Победы	0103000020E61000000100000005000000C4CDA96400DA45407A3881E9B4304B40C4CDA96400DA45407CB779E3A4324B40C460FE0A99DF45407CB779E3A4324B40C460FE0A99DF45407A3881E9B4304B40C4CDA96400DA45407A3881E9B4304B40
54760	13148	45.599553	45.640965000000001	53.953995999999997	53.94556	Московская	0103000020E61000000100000005000000FE9B1727BECC4640F0332E1C08F94A40FE9B1727BECC4640E5417A8A1CFA4A40B97020240BD24640E5417A8A1CFA4A40B97020240BD24640F0332E1C08F94A40FE9B1727BECC4640F0332E1C08F94A40
54774	13552	45.449714	45.494790999999999	53.928210999999997	53.902873	Московская	0103000020E61000000100000005000000D446753A90B9464080B8AB5791F34A40D446753A90B94640CB64389ECFF64A4075ADBD4F55BF4640CB64389ECFF64A4075ADBD4F55BF464080B8AB5791F34A40D446753A90B9464080B8AB5791F34A40
54610	13466	45.326186	45.339967000000001	53.949947999999999	53.931451000000003	Центральная	0103000020E61000000100000005000000DF347D76C0A94640CB694FC939F74A40DF347D76C0A94640477364E597F94A40105CE50984AB4640477364E597F94A40105CE50984AB4640CB694FC939F74A40DF347D76C0A94640CB694FC939F74A40
54553	30639	45.683446000000004	45.768085999999997	54.003146000000001	53.979551999999998	Ленина	0103000020E61000000100000005000000804A95287BD746409E5DBEF561FD4A40804A95287BD746407E8E8F1667004B40FA415DA450E246407E8E8F1667004B40FA415DA450E246409E5DBEF561FD4A40804A95287BD746409E5DBEF561FD4A40
54955	13379	45.458579999999998	45.493119999999998	54.104629000000003	54.087018999999998	Школьная	0103000020E61000000100000005000000C24CDBBFB2BA4640B8904770230B4B40C24CDBBFB2BA46404A9BAA7B640D4B407380608E1EBF46404A9BAA7B640D4B407380608E1EBF4640B8904770230B4B40C24CDBBFB2BA4640B8904770230B4B40
54775	13526	45.336678999999997	45.366889	53.917808000000001	53.883718000000002	Карла Маркса	0103000020E61000000100000005000000FF1F274C18AB46407A71E2AB1DF14A40FF1F274C18AB4640EB0088BB7AF54A408E210038F6AE4640EB0088BB7AF54A408E210038F6AE46407A71E2AB1DF14A40FF1F274C18AB46407A71E2AB1DF14A40
54763	13337	45.444001	45.472701999999998	54.021785999999999	54.000118999999998	Школьная	0103000020E6100000010000000500000016325706D5B84640DA8D3EE603004B4016325706D5B846405DC136E2C9024B407C60C77F81BC46405DC136E2C9024B407C60C77F81BC4640DA8D3EE603004B4016325706D5B84640DA8D3EE603004B40
54960	13286	45.543802999999997	45.588071999999997	54.044234000000003	54.037058999999999	Центральная	0103000020E61000000100000005000000BC3B32569BC54640E0826C59BE044B40BC3B32569BC5464086AFAF75A9054B40BED87BF145CB464086AFAF75A9054B40BED87BF145CB4640E0826C59BE044B40BC3B32569BC54640E0826C59BE044B40
54764	13236	45.724212000000001	45.750109999999999	53.978000999999999	53.965645000000002	Центральная	0103000020E6100000010000000500000075AF93FAB2DC4640E1455F419AFB4A4075AF93FAB2DC4640473A03232FFD4A408733BF9A03E04640473A03232FFD4A408733BF9A03E04640E1455F419AFB4A4075AF93FAB2DC4640E1455F419AFB4A40
54762	13173	45.412765999999998	45.434998999999998	53.968601	53.949185	Центральная	0103000020E610000001000000050000004B732B84D5B44640486DE2E47EF94A404B732B84D5B44640BBEF181EFBFB4A407765170CAEB74640BBEF181EFBFB4A407765170CAEB74640486DE2E47EF94A404B732B84D5B44640486DE2E47EF94A40
54370	12952	45.386930999999997	45.456802000000003	54.049632000000003	54.025376999999999	Ленинская	0103000020E610000001000000050000007F677BF486B146400989B48D3F034B407F677BF486B14640E46A64575A064B40AB5FE97C78BA4640E46A64575A064B40AB5FE97C78BA46400989B48D3F034B407F677BF486B146400989B48D3F034B40
54546	12952	45.386930999999997	45.456802000000003	54.049632000000003	54.025376999999999	Ленина	0103000020E610000001000000050000007F677BF486B146400989B48D3F034B407F677BF486B14640E46A64575A064B40AB5FE97C78BA4640E46A64575A064B40AB5FE97C78BA46400989B48D3F034B407F677BF486B146400989B48D3F034B40
54761	13091	45.642771000000003	45.690246999999999	53.953572000000001	53.929440999999997	Нагорная	0103000020E610000001000000050000009BE8F35146D24640E04735ECF7F64A409BE8F35146D24640CF30B5A50EFA4A40C09481035AD84640CF30B5A50EFA4A40C09481035AD84640E04735ECF7F64A409BE8F35146D24640E04735ECF7F64A40
54646	56549	45.320993999999999	45.353997999999997	54.113143000000001	54.102544000000002	Орлова	0103000020E610000001000000050000002A1BD65416A9464055336B29200D4B402A1BD65416A94640BB6246787B0E4B40B96C74CE4FAD4640BB6246787B0E4B40B96C74CE4FAD464055336B29200D4B402A1BD65416A9464055336B29200D4B40
54808	13054	45.236732000000003	45.388080000000002	53.979664	53.944828999999999	Советская	0103000020E6100000010000000500000056F5F23B4D9E4640FCA71B28F0F84A4056F5F23B4D9E4640C68844A165FD4A40A81DFE9AACB14640C68844A165FD4A40A81DFE9AACB14640FCA71B28F0F84A4056F5F23B4D9E4640FCA71B28F0F84A40
54575	12999	45.23021	45.250017999999997	54.060867999999999	54.049193000000002	Корнишина	0103000020E61000000100000005000000289B7285779D46409818CBF44B064B40289B7285779D4640BCAFCA85CA074B40A6B4FE9600A04640BCAFCA85CA074B40A6B4FE9600A046409818CBF44B064B40289B7285779D46409818CBF44B064B40
54358	50006	43.994892	44.025893000000003	53.824908000000001	53.803941999999999	Советская	0103000020E61000000100000005000000A986FD9E58FF4540BFF04A92E7E64A40A986FD9E58FF4540B91AD99596E94A4001193A7650034640B91AD99596E94A4001193A7650034640BFF04A92E7E64A40A986FD9E58FF4540BFF04A92E7E64A40
55077	33151	44.034354999999998	44.053336999999999	53.910229999999999	53.892946000000002	Центральная	0103000020E610000001000000050000001FBAA0BE65044640098CF50D4CF24A401FBAA0BE6504464046EBA86A82F44A4058552FBFD306464046EBA86A82F44A4058552FBFD3064640098CF50D4CF24A401FBAA0BE65044640098CF50D4CF24A40
54908	22700	43.711410999999998	43.732126000000001	53.986843	53.968510999999999	Центральная	0103000020E61000000100000005000000E08101840FDB45407B681F2BF8FB4A40E08101840FDB4540ADA415DF50FE4A409146054EB6DD4540ADA415DF50FE4A409146054EB6DD45407B681F2BF8FB4A40E08101840FDB45407B681F2BF8FB4A40
54848	11262	44.246600000000001	44.274098000000002	54.109369000000001	54.091951999999999	Верхняя	0103000020E61000000100000005000000C898BB96901F4640A1664815C50B4B40C898BB96901F46401E19ABCDFF0D4B4013F3ACA4152346401E19ABCDFF0D4B4013F3ACA415234640A1664815C50B4B40C898BB96901F4640A1664815C50B4B40
55006	50007	43.795071	43.842106999999999	54.109918	54.071916999999999	Молодежная	0103000020E61000000100000005000000BF7FF3E2C4E545406283859334094B40BF7FF3E2C4E54540F19E03CB110E4B40C85D8429CAEB4540F19E03CB110E4B40C85D8429CAEB45406283859334094B40BF7FF3E2C4E545406283859334094B40
54895	11201	44.083098	44.110047000000002	54.066749999999999	54.034722000000002	Новая	0103000020E61000000100000005000000772E8CF4A20A4640D2393FC571044B40772E8CF4A20A4640068195438B084B40EF022505160E4640068195438B084B40EF022505160E4640D2393FC571044B40772E8CF4A20A4640D2393FC571044B40
55092	56606	44.182065000000001	44.230978	54.113930000000003	54.102786000000002	 Школьная	0103000020E61000000100000005000000855FEAE74D1746404B3E7617280D4B40855FEAE74D17464043041C42950E4B40390CE6AF901D464043041C42950E4B40390CE6AF901D46404B3E7617280D4B40855FEAE74D1746404B3E7617280D4B40
54805	31057	43.927007000000003	43.962733	53.906055000000002	53.881875999999998	Школьная	0103000020E61000000100000005000000E014562AA8F645404B901150E1F04A40E014562AA8F645404BB0389CF9F34A40D6E3BED53AFB45404BB0389CF9F34A40D6E3BED53AFB45404B901150E1F04A40E014562AA8F645404B901150E1F04A40
54956	11747	43.488	43.514060000000001	54.226790000000001	54.206853000000002	Центральная	0103000020E610000001000000050000005839B4C876BE45402D0ABB287A1A4B405839B4C876BE4540A9876874071D4B404417D4B7CCC14540A9876874071D4B404417D4B7CCC145402D0ABB287A1A4B405839B4C876BE45402D0ABB287A1A4B40
54538	11779	43.670510999999998	43.690120999999998	54.226838000000001	54.212260999999998	Сире веле	0103000020E61000000100000005000000DB4DF04DD3D54540AE9B525E2B1B4B40DB4DF04DD3D54540BABE0F07091D4B4033A48AE255D84540BABE0F07091D4B4033A48AE255D84540AE9B525E2B1B4B40DB4DF04DD3D54540AE9B525E2B1B4B40
54802	45818	43.904594000000003	43.915633999999997	54.111781000000001	54.106582000000003	Горького	0103000020E61000000100000005000000341477BCC9F34540D02B9E7AA40D4B40341477BCC9F3454037A8FDD64E0E4B40868DB27E33F5454037A8FDD64E0E4B40868DB27E33F54540D02B9E7AA40D4B40341477BCC9F34540D02B9E7AA40D4B40
54425	12021	43.873108000000002	43.904710000000001	54.320577999999998	54.305661000000001	Центральная	0103000020E6100000010000000500000020F0C000C2EF4540D2544FE61F274B4020F0C000C2EF454096E82CB308294B409D2E8B89CDF3454096E82CB308294B409D2E8B89CDF34540D2544FE61F274B4020F0C000C2EF4540D2544FE61F274B40
54904	11454	43.630921999999998	43.667852000000003	54.022013000000001	53.976322000000003	Советская	0103000020E61000000100000005000000D829560DC2D04540C32E8A1EF8FC4A40D829560DC2D045401E8B6D52D1024B40BB48A12C7CD545401E8B6D52D1024B40BB48A12C7CD54540C32E8A1EF8FC4A40D829560DC2D04540C32E8A1EF8FC4A40
55075	11923	43.764626999999997	43.774777999999998	54.269576000000001	54.254651000000003	Советская	0103000020E61000000100000005000000BD512B4CDFE1454065726A6798204B40BD512B4CDFE14540ACE4637781224B4084D4EDEC2BE34540ACE4637781224B4084D4EDEC2BE3454065726A6798204B40BD512B4CDFE1454065726A6798204B40
54422	11923	43.764626999999997	43.774777999999998	54.269576000000001	54.254651000000003	Мокшанская	0103000020E61000000100000005000000BD512B4CDFE1454065726A6798204B40BD512B4CDFE14540ACE4637781224B4084D4EDEC2BE34540ACE4637781224B4084D4EDEC2BE3454065726A6798204B40BD512B4CDFE1454065726A6798204B40
54707	50008	43.810386999999999	44.109121999999999	54.233322000000001	54.000124	Школьная	0103000020E61000000100000005000000410DDFC2BAE74540ECF82F1004004B40410DDFC2BAE74540FAB7CB7EDD1D4B4016A3AEB5F70D4640FAB7CB7EDD1D4B4016A3AEB5F70D4640ECF82F1004004B40410DDFC2BAE74540ECF82F1004004B40
54607	56543	43.476689999999998	44.344695999999999	54.336995999999999	53.736611000000003	Песчаная	0103000020E61000000100000005000000452A8C2D04BD4540DB6FED4449DE4A40452A8C2D04BD4540007157AF222B4B40F0879FFF1E2C4640007157AF222B4B40F0879FFF1E2C4640DB6FED4449DE4A40452A8C2D04BD4540DB6FED4449DE4A40
54521	16897	43.762103000000003	43.793337000000001	54.205936999999999	54.195846000000003	Молодежная	0103000020E610000001000000050000007D9752978CE14540B686527B11194B407D9752978CE14540A704C4245C1A4B4077DA1A118CE54540A704C4245C1A4B4077DA1A118CE54540B686527B11194B407D9752978CE14540B686527B11194B40
54709	49415	43.581513999999999	43.651322999999998	54.078014000000003	54.054960000000001	Советская	0103000020E610000001000000050000004415FE0C6FCA4540494BE5ED08074B404415FE0C6FCA4540A950DD5CFC094B40F910548D5ED34540A950DD5CFC094B40F910548D5ED34540494BE5ED08074B404415FE0C6FCA4540494BE5ED08074B40
54852	56572	44.041829	44.062086000000001	54.135942999999997	54.117412999999999	Приовражная	0103000020E610000001000000050000001F8315A75A0546400890A163070F4B401F8315A75A054640608F899466114B400DC51D6FF2074640608F899466114B400DC51D6FF20746400890A163070F4B401F8315A75A0546400890A163070F4B40
54947	10094	43.884633000000001	43.912740999999997	54.005082999999999	53.975400999999998	Совесткая	0103000020E610000001000000050000002FFB75A73BF145402BBEA1F0D9FC4A402FFB75A73BF14540FE614B8FA6004B40F25B74B2D4F44540FE614B8FA6004B40F25B74B2D4F445402BBEA1F0D9FC4A402FFB75A73BF145402BBEA1F0D9FC4A40
54846	10657	43.790498999999997	43.821347000000003	53.960957000000001	53.945723999999998	Центральная	0103000020E61000000100000005000000A6423C122FE545406A85E97B0DF94A40A6423C122FE545405FEE93A300FB4A4078D503E621E945405FEE93A300FB4A4078D503E621E945406A85E97B0DF94A40A6423C122FE545406A85E97B0DF94A40
54943	48000	44.047739999999997	44.060747999999997	53.756238000000003	53.746724	Школьная	0103000020E61000000100000005000000035B25581C064640B491EBA694DF4A40035B25581C06464009FF2268CCE04A4011A62897C607464009FF2268CCE04A4011A62897C6074640B491EBA694DF4A40035B25581C064640B491EBA694DF4A40
55066	11160	44.151432999999997	44.167251999999998	54.049292999999999	54.035435999999997	Советская	0103000020E610000001000000050000008044132862134640EF8CB62A89044B408044132862134640FB75A73B4F064B406518778368154640FB75A73B4F064B406518778368154640EF8CB62A89044B408044132862134640EF8CB62A89044B40
55057	56590	44.037903999999997	44.048647000000003	54.236694999999997	54.228758999999997	Центральная	0103000020E610000001000000050000009C31CC09DA04464034D593F9471D4B409C31CC09DA044640381092054C1E4B4036069D103A064640381092054C1E4B4036069D103A06464034D593F9471D4B409C31CC09DA04464034D593F9471D4B40
55067	56594	43.852797000000002	43.871059000000002	53.973382999999998	53.959907999999999	Советская	0103000020E610000001000000050000003F90BC7328ED45409A95ED43DEFA4A403F90BC7328ED4540BEBD6BD097FC4A4078F17EDC7EEF4540BEBD6BD097FC4A4078F17EDC7EEF45409A95ED43DEFA4A403F90BC7328ED45409A95ED43DEFA4A40
55090	11024	44.121267000000003	44.146608999999998	53.971958999999998	53.959282999999999	Молодежная	0103000020E61000000100000005000000C28A53AD850F4640EC4D0CC9C9FA4A40C28A53AD850F4640C4060B2769FC4A404E266E15C4124640C4060B2769FC4A404E266E15C4124640EC4D0CC9C9FA4A40C28A53AD850F4640EC4D0CC9C9FA4A40
54851	48900	43.562685999999999	43.600658000000003	54.146123000000003	54.131565000000002	Школьная	0103000020E6100000010000000500000062F5471806C845402D26361FD7104B4062F5471806C84540C2189128B4124B40570A815CE2CC4540C2189128B4124B40570A815CE2CC45402D26361FD7104B4062F5471806C845402D26361FD7104B40
54611	11955	43.949527000000003	43.990642999999999	54.306711999999997	54.287291000000003	Советская	0103000020E61000000100000005000000A2D5C9198AF94540B3B794F3C5244B40A2D5C9198AF9454037A5BC5642274B407381CB63CDFE454037A5BC5642274B407381CB63CDFE4540B3B794F3C5244B40A2D5C9198AF94540B3B794F3C5244B40
54608	30738	43.860118	43.902329999999999	54.064922000000003	54.041966000000002	Гагарина	0103000020E61000000100000005000000B859BC5818EE4540A0C552245F054B40B859BC5818EE45403D65355D4F084B408F19A88C7FF345403D65355D4F084B408F19A88C7FF34540A0C552245F054B40B859BC5818EE4540A0C552245F054B40
54953	10796	44.079225999999998	44.117494000000001	53.859706000000003	53.834744999999998	Советская	0103000020E61000000100000005000000177FDB13240A4640F0BF95ECD8EA4A40177FDB13240A46406616A1D80AEE4A40F5BC1B0B0A0F46406616A1D80AEE4A40F5BC1B0B0A0F4640F0BF95ECD8EA4A40177FDB13240A4640F0BF95ECD8EA4A40
54541	32609	44.01585	44.041254000000002	54.105615999999998	54.095368000000001	Победы	0103000020E6100000010000000500000020D26F5F07024640DF8AC404350C4B4020D26F5F0702464098F738D3840D4B40236AA2CF4705464098F738D3840D4B40236AA2CF47054640DF8AC404350C4B4020D26F5F07024640DF8AC404350C4B40
54847	11071	44.021194999999999	44.064413000000002	54.030147999999997	54.006644000000001	Ленина	0103000020E610000001000000050000005BEB8B84B6024640795BE9B5D9004B405BEB8B84B60246401805C1E3DB034B40F83768AF3E0846401805C1E3DB034B40F83768AF3E084640795BE9B5D9004B405BEB8B84B6024640795BE9B5D9004B40
54801	46371	43.662039	43.679412999999997	53.974882000000001	53.970205999999997	Центральная	0103000020E6100000010000000500000099D6A6B1BDD445400531D0B52FFC4A4099D6A6B1BDD44540C3BAF1EEC8FC4A4016BD5301F7D64540C3BAF1EEC8FC4A4016BD5301F7D645400531D0B52FFC4A4099D6A6B1BDD445400531D0B52FFC4A40
55085	56603	44.022111000000002	44.049213000000002	53.940773999999998	53.919155000000003	Центральная	0103000020E61000000100000005000000E1F08288D40246403A7AFCDEA6F54A40E1F08288D4024640AB764D486BF84A40DFC4909C4C064640AB764D486BF84A40DFC4909C4C0646403A7AFCDEA6F54A40E1F08288D40246403A7AFCDEA6F54A40
54695	4870	43.732261000000001	43.744486999999999	54.123381000000002	54.113481	Центральная	0103000020E6100000010000000500000071917BBABADD4540D3DB9F8B860E4B4071917BBABADD454051F9D7F2CA0F4B4009A69A594BDF454051F9D7F2CA0F4B4009A69A594BDF4540D3DB9F8B860E4B4071917BBABADD4540D3DB9F8B860E4B40
55008	56585	43.697262000000002	43.716810000000002	54.094344	54.080311000000002	Старая	0103000020E610000001000000050000002D5F97E13FD9454029417FA1470A4B402D5F97E13FD945407349D576130C4B400FB9196EC0DB45407349D576130C4B400FB9196EC0DB454029417FA1470A4B402D5F97E13FD9454029417FA1470A4B40
54912	20090	43.715265000000002	43.748843999999998	54.024715999999998	54.017749000000002	Школная	0103000020E610000001000000050000009A7CB3CD8DDB4540B344679945024B409A7CB3CD8DDB45400ED8D5E429034B4025E7C41EDADF45400ED8D5E429034B4025E7C41EDADF4540B344679945024B409A7CB3CD8DDB4540B344679945024B40
54384	12135	43.760908000000001	43.786060999999997	54.165863000000002	54.151147999999999	Советская	0103000020E61000000100000005000000E4A1EF6E65E145408B6D52D158134B40E4A1EF6E65E14540E84EB0FF3A154B409DD497A59DE44540E84EB0FF3A154B409DD497A59DE445408B6D52D158134B40E4A1EF6E65E145408B6D52D158134B40
55046	56589	43.856110999999999	43.873817000000003	53.933872999999998	53.924002000000002	Школьная	0103000020E61000000100000005000000785F950B95ED454024B891B245F64A40785F950B95ED454007CF842689F74A402CD8463CD9EF454007CF842689F74A402CD8463CD9EF454024B891B245F64A40785F950B95ED454024B891B245F64A40
54850	11632	43.663899000000001	43.692411999999997	54.179217999999999	54.166659000000003	Молодежная	0103000020E610000001000000050000006E6C76A4FAD44540C34A051555154B406E6C76A4FAD44540616D8C9DF0164B40D1ADD7F4A0D84540616D8C9DF0164B40D1ADD7F4A0D84540C34A051555154B406E6C76A4FAD44540C34A051555154B40
54806	32381	43.945422000000001	43.968491	53.825392000000001	53.801510999999998	Школьная	0103000020E610000001000000050000009F758D9603F945402F3196E997E64A409F758D9603F94540A530EF71A6E94A4034BC5983F7FB4540A530EF71A6E94A4034BC5983F7FB45402F3196E997E64A409F758D9603F945402F3196E997E64A40
54693	8019	44.24015	44.261161999999999	53.966110999999998	53.953895000000003	Молодежная	0103000020E610000001000000050000003411363CBD1E4640B2683A3B19FA4A403411363CBD1E464026A77686A9FB4A409E7AA4C16D21464026A77686A9FB4A409E7AA4C16D214640B2683A3B19FA4A403411363CBD1E4640B2683A3B19FA4A40
55003	10715	44.191515000000003	44.211638000000001	54.090905999999997	54.068604000000001	Нижняя	0103000020E61000000100000005000000C3D8429083184640F92F1004C8084B40C3D84290831846404D81CCCEA20B4B40A14B38F4161B46404D81CCCEA20B4B40A14B38F4161B4640F92F1004C8084B40C3D8429083184640F92F1004C8084B40
54759	10522	44.357379999999999	44.392271000000001	54.100807000000003	54.087294	Московская	0103000020E610000001000000050000004B1FBAA0BE2D46408A9125732C0B4B404B1FBAA0BE2D46409C1A683EE70C4B40A915A6EF353246409C1A683EE70C4B40A915A6EF353246408A9125732C0B4B404B1FBAA0BE2D46408A9125732C0B4B40
54845	10407	44.203203000000002	44.244039999999998	54.027842	54.010992999999999	Школьная	0103000020E610000001000000050000007CB94F8E021A464012BEF73768014B407CB94F8E021A464045BA9F5390034B403A75E5B33C1F464045BA9F5390034B403A75E5B33C1F464012BEF73768014B407CB94F8E021A464012BEF73768014B40
54949	10473	44.406275999999998	44.440815999999998	54.149729999999998	54.125644999999999	Школьная	0103000020E6100000010000000500000029931ADA00344640F5F3A62215104B4029931ADA00344640739D465A2A134B40DAC69FA86C384640739D465A2A134B40DAC69FA86C384640F5F3A62215104B4029931ADA00344640F5F3A62215104B40
55071	56597	44.392845999999999	44.417442000000001	53.966588000000002	53.942326999999999	Молодежная	0103000020E61000000100000005000000A52E19C748324640A391CF2B9EF84A40A52E19C748324640605AD427B9FB4A4009FD4CBD6E354640605AD427B9FB4A4009FD4CBD6E354640A391CF2B9EF84A40A52E19C748324640A391CF2B9EF84A40
54336	9956	44.373154999999997	44.434626999999999	54.043505000000003	54.017283999999997	Светотехническая	0103000020E6100000010000000500000060AB048BC32F46403D5FB35C36024B4060AB048BC32F4640331B649291054B40B37A87DBA1374640331B649291054B40B37A87DBA13746403D5FB35C36024B4060AB048BC32F46403D5FB35C36024B40
54383	9956	44.373154999999997	44.434626999999999	54.043505000000003	54.017283999999997	Крупской	0103000020E6100000010000000500000060AB048BC32F46403D5FB35C36024B4060AB048BC32F4640331B649291054B40B37A87DBA1374640331B649291054B40B37A87DBA13746403D5FB35C36024B4060AB048BC32F46403D5FB35C36024B40
54656	9956	44.373154999999997	44.434626999999999	54.043505000000003	54.017283999999997	Заводская	0103000020E6100000010000000500000060AB048BC32F46403D5FB35C36024B4060AB048BC32F4640331B649291054B40B37A87DBA1374640331B649291054B40B37A87DBA13746403D5FB35C36024B4060AB048BC32F46403D5FB35C36024B40
54950	52959	44.283171000000003	44.302124999999997	54.073307	54.059669	Советская	0103000020E610000001000000050000007B1684F23E244640E2CAD93BA3074B407B1684F23E244640B0C8AF1F62094B40E9263108AC264640B0C8AF1F62094B40E9263108AC264640E2CAD93BA3074B407B1684F23E244640E2CAD93BA3074B40
55002	10385	44.242764000000001	44.270854999999997	54.028857000000002	54.021853999999998	А. Корнеева	0103000020E61000000100000005000000B55208E4121F4640B5A4A31CCC024B40B55208E4121F46405EA10F96B1034B40A27A6B60AB2246405EA10F96B1034B40A27A6B60AB224640B5A4A31CCC024B40B55208E4121F4640B5A4A31CCC024B40
54599	10315	44.299321999999997	44.335631999999997	54.011327000000001	53.992783000000003	Школьная	0103000020E61000000100000005000000957CEC2E502646402C836A8313FF4A40957CEC2E50264640E947C32973014B40DBBE47FDF52A4640E947C32973014B40DBBE47FDF52A46402C836A8313FF4A40957CEC2E502646402C836A8313FF4A40
54679	10248	44.31268	44.336728000000001	53.964315999999997	53.935909000000002	Пролетарская	0103000020E61000000100000005000000800EF3E5052846401B84B9DDCBF74A40800EF3E5052846403881E9B46EFB4A40E1D231E7192B46403881E9B46EFB4A40E1D231E7192B46401B84B9DDCBF74A40800EF3E5052846401B84B9DDCBF74A40
55021	9194	45.352075999999997	45.366951999999998	54.659745000000001	54.649270999999999	Гагарина	0103000020E610000001000000050000006EDA8CD310AD4640E09EE74F1B534B406EDA8CD310AD46408A592F8672544B40D4997B48F8AE46408A592F8672544B40D4997B48F8AE4640E09EE74F1B534B406EDA8CD310AD4640E09EE74F1B534B40
55016	47890	45.440694999999998	45.456522999999997	54.700695000000003	54.694592	Колхозная	0103000020E610000001000000050000005F419AB168B8464018080264E8584B405F419AB168B8464041BCAE5FB0594B40976F7D586FBA464041BCAE5FB0594B40976F7D586FBA464018080264E8584B405F419AB168B8464018080264E8584B40
54573	32577	45.272288000000003	45.312531999999997	54.732089999999999	54.718775000000001	Школьная	0103000020E61000000100000005000000F08B4B55DAA246405917B7D1005C4B40F08B4B55DAA2464044DD0720B55D4B400B7A6F0C01A8464044DD0720B55D4B400B7A6F0C01A846405917B7D1005C4B40F08B4B55DAA246405917B7D1005C4B40
54648	32577	45.272288000000003	45.312531999999997	54.732089999999999	54.718775000000001	Мира	0103000020E61000000100000005000000F08B4B55DAA246405917B7D1005C4B40F08B4B55DAA2464044DD0720B55D4B400B7A6F0C01A8464044DD0720B55D4B400B7A6F0C01A846405917B7D1005C4B40F08B4B55DAA246405917B7D1005C4B40
54755	32577	45.272288000000003	45.312531999999997	54.732089999999999	54.718775000000001	Алатырская	0103000020E61000000100000005000000F08B4B55DAA246405917B7D1005C4B40F08B4B55DAA2464044DD0720B55D4B400B7A6F0C01A8464044DD0720B55D4B400B7A6F0C01A846405917B7D1005C4B40F08B4B55DAA246405917B7D1005C4B40
54893	9783	45.617609000000002	45.656677000000002	54.745286999999998	54.732734999999998	Центральная	0103000020E610000001000000050000008E5BCCCF0DCF464039D1AE42CA5D4B408E5BCCCF0DCF464025917D90655F4B408884EFFD0DD4464025917D90655F4B408884EFFD0DD4464039D1AE42CA5D4B408E5BCCCF0DCF464039D1AE42CA5D4B40
54570	47816	45.262514000000003	45.316862	54.700611000000002	54.677500000000002	Первомайская	0103000020E61000000100000005000000FF5E0A0F9AA146401F85EB51B8564B40FF5E0A0F9AA14640E31B0A9FAD594B402EAC1BEF8EA84640E31B0A9FAD594B402EAC1BEF8EA846401F85EB51B8564B40FF5E0A0F9AA146401F85EB51B8564B40
54778	47816	45.262514000000003	45.316862	54.700611000000002	54.677500000000002	Кулакова	0103000020E61000000100000005000000FF5E0A0F9AA146401F85EB51B8564B40FF5E0A0F9AA14640E31B0A9FAD594B402EAC1BEF8EA84640E31B0A9FAD594B402EAC1BEF8EA846401F85EB51B8564B40FF5E0A0F9AA146401F85EB51B8564B40
54952	9514	45.452804	45.493991999999999	54.63646	54.614364999999999	Советская	0103000020E61000000100000005000000BEBF417BF5B946404D672783A34E4B40BEBF417BF5B94640289B728577514B40293E3E213BBF4640289B728577514B40293E3E213BBF46404D672783A34E4B40BEBF417BF5B946404D672783A34E4B40
54901	47763	45.173194000000002	45.206980000000001	54.603054999999998	54.579521999999997	 Садовая	0103000020E6100000010000000500000085EE92382B96464000A8E2C62D4A4B4085EE92382B9646403A58FFE7304D4B408A7615527E9A46403A58FFE7304D4B408A7615527E9A464000A8E2C62D4A4B4085EE92382B96464000A8E2C62D4A4B40
54843	9424	45.652023	45.670330999999997	54.673596000000003	54.655042000000002	Колхозная	0103000020E61000000100000005000000B29E5A7D75D34640D3C08F6AD8534B40B29E5A7D75D34640B45BCB6438564B405B3FFD67CDD54640B45BCB6438564B405B3FFD67CDD54640D3C08F6AD8534B40B29E5A7D75D34640D3C08F6AD8534B40
54844	9707	45.573574000000001	45.599947999999998	54.747906	54.733181999999999	Красная	0103000020E61000000100000005000000FFEA71DF6AC94640080264E8D85D4B40FFEA71DF6AC94640B83D4162BB5F4B407AA69718CBCC4640B83D4162BB5F4B407AA69718CBCC4640080264E8D85D4B40FFEA71DF6AC94640080264E8D85D4B40
54637	33005	45.322288	45.358246999999999	54.666832999999997	54.656860000000002	Мира	0103000020E6100000010000000500000056F2B1BB40A9464079060DFD13544B4056F2B1BB40A946406072A3C85A554B40EF71A609DBAD46406072A3C85A554B40EF71A609DBAD464079060DFD13544B4056F2B1BB40A9464079060DFD13544B40
81095	33005	45.322288	45.358246999999999	54.666832999999997	54.656860000000002	Ленина	0103000020E6100000010000000500000056F2B1BB40A9464079060DFD13544B4056F2B1BB40A946406072A3C85A554B40EF71A609DBAD46406072A3C85A554B40EF71A609DBAD464079060DFD13544B4056F2B1BB40A9464079060DFD13544B40
55014	9019	45.386895000000003	45.430095000000001	54.732615000000003	54.719169999999998	Нагорная	0103000020E6100000010000000500000033FE7DC685B14640D52137C30D5C4B4033FE7DC685B146408FC70C54C65D4B4029965B5A0DB746408FC70C54C65D4B4029965B5A0DB74640D52137C30D5C4B4033FE7DC685B14640D52137C30D5C4B40
54925	8756	45.138348999999998	45.168182000000002	54.633853999999999	54.609740000000002	Молодежная	0103000020E610000001000000050000009737876BB59146401288D7F50B4E4B409737876BB59146402A38BC2022514B4050E3DEFC869546402A38BC2022514B4050E3DEFC869546401288D7F50B4E4B409737876BB59146401288D7F50B4E4B40
54903	47964	45.412298999999997	45.451618000000003	54.601939000000002	54.566558000000001	Базарная	0103000020E610000001000000050000003596B036C6B44640C2A4F8F884484B403596B036C6B44640EE974F560C4D4B4079245E9ECEB94640EE974F560C4D4B4079245E9ECEB94640C2A4F8F884484B403596B036C6B44640C2A4F8F884484B40
54753	8230	45.180847999999997	45.205039999999997	54.722341999999998	54.704191000000002	А. Егорова	0103000020E6100000010000000500000004C6FA06269746409B9141EE225A4B4004C6FA06269746407C43E1B3755C4B40982F2FC03E9A46407C43E1B3755C4B40982F2FC03E9A46409B9141EE225A4B4004C6FA06269746409B9141EE225A4B40
54754	8180	45.045544	45.072744999999998	54.729875999999997	54.714750000000002	Кооперативная	0103000020E61000000100000005000000B743C362D4854640736891ED7C5B4B40B743C362D48546405111A7936C5D4B4048F949B54F8946405111A7936C5D4B4048F949B54F894640736891ED7C5B4B40B743C362D4854640736891ED7C5B4B40
54534	6530	45.212316000000001	45.270617000000001	54.708404000000002	54.673226	Советская	0103000020E610000001000000050000007235B22B2D9B4640906802452C564B407235B22B2D9B4640842D76FBAC5A4B40EE5EEE93A3A24640842D76FBAC5A4B40EE5EEE93A3A24640906802452C564B407235B22B2D9B4640906802452C564B40
54704	6530	45.212316000000001	45.270617000000001	54.708404000000002	54.673226	Кооперативный пер	0103000020E610000001000000050000007235B22B2D9B4640906802452C564B407235B22B2D9B4640842D76FBAC5A4B40EE5EEE93A3A24640842D76FBAC5A4B40EE5EEE93A3A24640906802452C564B407235B22B2D9B4640906802452C564B40
54558	6530	45.212316000000001	45.270617000000001	54.708404000000002	54.673226	 Советская	0103000020E610000001000000050000007235B22B2D9B4640906802452C564B407235B22B2D9B4640842D76FBAC5A4B40EE5EEE93A3A24640842D76FBAC5A4B40EE5EEE93A3A24640906802452C564B407235B22B2D9B4640906802452C564B40
54572	6530	45.212316000000001	45.270617000000001	54.708404000000002	54.673226	 Больничный пер	0103000020E610000001000000050000007235B22B2D9B4640906802452C564B407235B22B2D9B4640842D76FBAC5A4B40EE5EEE93A3A24640842D76FBAC5A4B40EE5EEE93A3A24640906802452C564B407235B22B2D9B4640906802452C564B40
54757	48085	45.518129999999999	45.550989999999999	54.609864999999999	54.597631	Шлукина	0103000020E61000000100000005000000CA89761552C24640B309302C7F4C4B40CA89761552C24640CEFC6A0E104E4B4026361FD786C64640CEFC6A0E104E4B4026361FD786C64640B309302C7F4C4B40CA89761552C24640B309302C7F4C4B40
54705	8439	45.250520999999999	45.332771000000001	54.690361000000003	54.666826999999998	им. В.И.Чинченкова	0103000020E6100000010000000500000009FB761211A046407E8B4E965A554B4009FB761211A0464089B7CEBF5D584B405307793D98AA464089B7CEBF5D584B405307793D98AA46407E8B4E965A554B4009FB761211A046407E8B4E965A554B40
54615	8439	45.250520999999999	45.332771000000001	54.690361000000003	54.666826999999998	Школьная	0103000020E6100000010000000500000009FB761211A046407E8B4E965A554B4009FB761211A0464089B7CEBF5D584B405307793D98AA464089B7CEBF5D584B405307793D98AA46407E8B4E965A554B4009FB761211A046407E8B4E965A554B40
54574	8439	45.250520999999999	45.332771000000001	54.690361000000003	54.666826999999998	Махова	0103000020E6100000010000000500000009FB761211A046407E8B4E965A554B4009FB761211A0464089B7CEBF5D584B405307793D98AA464089B7CEBF5D584B405307793D98AA46407E8B4E965A554B4009FB761211A046407E8B4E965A554B40
54957	56579	45.384765999999999	45.408318999999999	54.600848999999997	54.564736000000003	Хилковская	0103000020E610000001000000050000006E4E250340B14640DB6FED4449484B406E4E250340B14640CA6ABA9EE84C4B40EFAA07CC43B44640CA6ABA9EE84C4B40EFAA07CC43B44640DB6FED4449484B406E4E250340B14640DB6FED4449484B40
54849	56571	45.716540000000002	45.738280000000003	54.738140999999999	54.722160000000002	Ленинская	0103000020E610000001000000050000004F232D95B7DB46405C3D27BD6F5C4B404F232D95B7DB46401A6B7F677B5E4B403CA583F57FDE46401A6B7F677B5E4B403CA583F57FDE46405C3D27BD6F5C4B404F232D95B7DB46405C3D27BD6F5C4B40
54826	47979	45.401654000000001	45.436356000000004	54.661411999999999	54.643624000000003	Советская	0103000020E610000001000000050000005F27F56569B34640DA756F4562524B405F27F56569B346404A97FE25A9544B40EAB46E83DAB746404A97FE25A9544B40EAB46E83DAB74640DA756F4562524B405F27F56569B34640DA756F4562524B40
54592	56542	45.639366000000003	45.658887	54.677750000000003	54.658475000000003	Московская	0103000020E610000001000000050000005116BEBED6D14640E71DA7E848544B405116BEBED6D14640986E1283C0564B403961C26856D44640986E1283C0564B403961C26856D44640E71DA7E848544B405116BEBED6D14640E71DA7E848544B40
54840	47528	45.109594000000001	45.139175000000002	54.743713	54.723996	Советская	0103000020E610000001000000050000003EEB1A2D078E4640A837A3E6AB5C4B403EEB1A2D078E4640164ED2FC315F4B40DDB5847CD0914640164ED2FC315F4B40DDB5847CD0914640A837A3E6AB5C4B403EEB1A2D078E4640A837A3E6AB5C4B40
54941	9440	45.590192000000002	45.620879000000002	54.69558	54.674053999999998	Ленинская	0103000020E61000000100000005000000302E55698BCB464076DEC66647564B40302E55698BCB464037E0F3C308594B40F8E28BF678CF464037E0F3C308594B40F8E28BF678CF464076DEC66647564B40302E55698BCB464076DEC66647564B40
55054	8831	45.234019000000004	45.279392999999999	54.570191000000001	54.554791000000002	Смоленская	0103000020E6100000010000000500000042D2A755F49D4640BD8E386403474B4042D2A755F49D46409DBCC804FC484B409CDD5A26C3A346409DBCC804FC484B409CDD5A26C3A34640BD8E386403474B4042D2A755F49D4640BD8E386403474B40
54999	9609	45.527894000000003	45.573044000000003	54.720261999999998	54.698113999999997	Советская	0103000020E6100000010000000500000098E0D40792C346409B70AFCC5B594B4098E0D40792C346409946938B315C4B40A3957B8159C946409946938B315C4B40A3957B8159C946409B70AFCC5B594B4098E0D40792C346409B70AFCC5B594B40
55000	9631	45.586914	45.624104000000003	54.744985999999997	54.725945000000003	Советская	0103000020E6100000010000000500000043C879FF1FCB4640EDD808C4EB5C4B4043C879FF1FCB46402AFD84B35B5F4B40C2A6CEA3E2CF46402AFD84B35B5F4B40C2A6CEA3E2CF4640EDD808C4EB5C4B4043C879FF1FCB4640EDD808C4EB5C4B40
64828	58366	45.308219999999999	45.347997999999997	54.689928999999999	54.666826999999998	1 Мая	0103000020E610000001000000050000008FFCC1C073A746407E8B4E965A554B408FFCC1C073A74640EFC7ED974F584B406589CE328BAC4640EFC7ED974F584B406589CE328BAC46407E8B4E965A554B408FFCC1C073A746407E8B4E965A554B40
54842	8084	44.552027000000002	44.567559000000003	53.902023999999997	53.893768000000001	Колхозная	0103000020E6100000010000000500000027C11BD2A84646400D1B65FD66F24A4027C11BD2A8464640821ABE8575F34A4076C6F7C5A5484640821ABE8575F34A4076C6F7C5A54846400D1B65FD66F24A4027C11BD2A84646400D1B65FD66F24A40
54752	7970	44.549162000000003	44.56888	53.792682999999997	53.769309999999997	Гагарина	0103000020E610000001000000050000005D1ABFF04A4646402D3E05C078E24A405D1ABFF04A4646402E8CF4A276E54A409BAC510FD14846402E8CF4A276E54A409BAC510FD14846402D3E05C078E24A405D1ABFF04A4646402D3E05C078E24A40
54948	56577	44.642110000000002	44.665188000000001	53.730384000000001	53.699401999999999	Бибишева	0103000020E61000000100000005000000A03715A930524640E560360186D94A40A03715A930524640C6C210397DDD4A4088D860E124554640C6C210397DDD4A4088D860E124554640E560360186D94A40A03715A930524640E560360186D94A40
54899	7887	44.210030000000003	44.239333000000002	53.901918000000002	53.885151	Центральная	0103000020E61000000100000005000000E6965643E21A4640C782C2A04CF14A40E6965643E21A46403DD68C0C72F34A4042EDB776A21E46403DD68C0C72F34A4042EDB776A21E4640C782C2A04CF14A40E6965643E21A4640C782C2A04CF14A40
54837	7793	44.517802000000003	44.558998000000003	53.8748	53.861702000000001	Центральная	0103000020E61000000100000005000000D6E6FF5547424640EB724A404CEE4A40D6E6FF554742464039454772F9EF4A40C443183F8D47464039454772F9EF4A40C443183F8D474640EB724A404CEE4A40D6E6FF5547424640EB724A404CEE4A40
54756	7739	44.499575	44.535867000000003	53.824339999999999	53.804378	Советская	0103000020E610000001000000050000001973D712F23F46409ACFB9DBF5E64A401973D712F23F46406F641EF983E94A40B900344A974446406F641EF983E94A40B900344A974446409ACFB9DBF5E64A401973D712F23F46409ACFB9DBF5E64A40
54841	7572	44.298864000000002	44.323846000000003	53.910170999999998	53.895651999999998	Садовая	0103000020E61000000100000005000000D3F9F02C412646406A4C88B9A4F24A40D3F9F02C412646404162BB7B80F44A40607825C9732946404162BB7B80F44A40607825C9732946406A4C88B9A4F24A40D3F9F02C412646406A4C88B9A4F24A40
55012	56587	44.555612000000004	44.580871999999999	53.855924999999999	53.842449000000002	Большая	0103000020E61000000100000005000000F1A1444B1E47464022C66B5ED5EB4A40F1A1444B1E474640166A4DF38EED4A40C09481035A4A4640166A4DF38EED4A40C09481035A4A464022C66B5ED5EB4A40F1A1444B1E47464022C66B5ED5EB4A40
54750	7538	44.541696999999999	44.563948000000003	53.933492000000001	53.920253000000002	Московская	0103000020E61000000100000005000000B0ABC95356454640E085ADD9CAF54A40B0ABC95356454640F08975AA7CF74A408352B4722F484640F08975AA7CF74A408352B4722F484640E085ADD9CAF54A40B0ABC95356454640E085ADD9CAF54A40
55070	56596	44.442872999999999	44.480521000000003	53.838867999999998	53.826842999999997	Центральная	0103000020E6100000010000000500000005A4FD0FB038464098F6CDFDD5E94A4005A4FD0FB038464099D4D00660EB4A4047054EB6813D464099D4D00660EB4A4047054EB6813D464098F6CDFDD5E94A4005A4FD0FB038464098F6CDFDD5E94A40
54998	7434	44.251747999999999	44.271447999999999	53.750146999999998	53.733623000000001	Центральная,	0103000020E61000000100000005000000AD6A494739204640F54BC45BE7DD4A40AD6A494739204640A41820D104E04A404548DDCEBE224640A41820D104E04A404548DDCEBE224640F54BC45BE7DD4A40AD6A494739204640F54BC45BE7DD4A40
54996	56582	44.142781999999997	44.177303999999999	53.750999	53.717401000000002	Фролова	0103000020E610000001000000050000008E3A3AAE46124640118FC4CBD3DB4A408E3A3AAE46124640132A38BC20E04A4099B9C0E5B1164640132A38BC20E04A4099B9C0E5B1164640118FC4CBD3DB4A408E3A3AAE46124640118FC4CBD3DB4A40
54944	7613	44.285048000000003	44.305996999999998	53.886637	53.871513999999998	Антроповых	0103000020E6100000010000000500000026E5EE737C244640C90050C58DEF4A4026E5EE737C24464037363B527DF14A4049D6E1E82A27464037363B527DF14A4049D6E1E82A274640C90050C58DEF4A4026E5EE737C244640C90050C58DEF4A40
54993	7258	44.237904	44.276010999999997	53.807127000000001	53.785373999999997	Ленина	0103000020E6100000010000000500000036CB65A3731E464079909E2287E44A4036CB65A3731E4640FB5B02F04FE74A400A2B155454234640FB5B02F04FE74A400A2B15545423464079909E2287E44A4036CB65A3731E464079909E2287E44A40
54838	7482	44.387357000000002	44.410992	53.827469999999998	53.795513	Новая Казеевка	0103000020E61000000100000005000000377007EA943146407C45B75ED3E54A40377007EA94314640E7357689EAE94A407575C7629B344640E7357689EAE94A407575C7629B3446407C45B75ED3E54A40377007EA943146407C45B75ED3E54A40
54467	32694	44.340411000000003	44.412672000000001	53.876137999999997	53.855001000000001	Советская	0103000020E610000001000000050000006E197096922B46400E863AAC70ED4A406E197096922B464034643C4A25F04A40CAFCA36FD234464034643C4A25F04A40CAFCA36FD23446400E863AAC70ED4A406E197096922B46400E863AAC70ED4A40
54461	32694	44.340411000000003	44.412672000000001	53.876137999999997	53.855001000000001	Гагарина	0103000020E610000001000000050000006E197096922B46400E863AAC70ED4A406E197096922B464034643C4A25F04A40CAFCA36FD234464034643C4A25F04A40CAFCA36FD23446400E863AAC70ED4A406E197096922B46400E863AAC70ED4A40
54921	46839	44.289836000000001	44.302906999999998	53.829287999999998	53.824095	Энгельса	0103000020E610000001000000050000000B9A96581925464008E6E8F17BE94A400B9A9658192546408D7BF31B26EA4A405F5D15A8C52646408D7BF31B26EA4A405F5D15A8C526464008E6E8F17BE94A400B9A96581925464008E6E8F17BE94A40
54749	7198	44.181489999999997	44.205781000000002	53.789315999999999	53.769959999999998	Московская	0103000020E61000000100000005000000884677103B174640349D9D0C8EE24A40884677103B174640D21A834E08E54A40B0912408571A4640D21A834E08E54A40B0912408571A4640349D9D0C8EE24A40884677103B174640349D9D0C8EE24A40
54945	7300	44.311422999999998	44.341723000000002	53.841248	53.821427	Ленина	0103000020E61000000100000005000000711C78B5DC27464094861A8524E94A40711C78B5DC274640A7E9B303AEEB4A4040A54A94BD2B4640A7E9B303AEEB4A4040A54A94BD2B464094861A8524E94A40711C78B5DC27464094861A8524E94A40
54834	4326	42.821953000000001	42.843601999999997	54.130493999999999	54.118273000000002	Школьная	0103000020E61000000100000005000000AFEC82C135694540FA7FD591230F4B40AFEC82C13569454080290307B4104B408B6B7C26FB6B454080290307B4104B408B6B7C26FB6B4540FA7FD591230F4B40AFEC82C135694540FA7FD591230F4B40
54539	6469	42.823290999999998	42.866670999999997	54.425843999999998	54.409483000000002	Чернореченская	0103000020E61000000100000005000000AA0B7899616945404DA25EF069344B40AA0B7899616945405299620E82364B4020B24813EF6E45405299620E82364B4020B24813EF6E45404DA25EF069344B40AA0B7899616945404DA25EF069344B40
54424	6469	42.823290999999998	42.866670999999997	54.425843999999998	54.409483000000002	Косарева	0103000020E61000000100000005000000AA0B7899616945404DA25EF069344B40AA0B7899616945405299620E82364B4020B24813EF6E45405299620E82364B4020B24813EF6E45404DA25EF069344B40AA0B7899616945404DA25EF069344B40
54380	6469	42.823290999999998	42.866670999999997	54.425843999999998	54.409483000000002	Дзержинского	0103000020E61000000100000005000000AA0B7899616945404DA25EF069344B40AA0B7899616945405299620E82364B4020B24813EF6E45405299620E82364B4020B24813EF6E45404DA25EF069344B40AA0B7899616945404DA25EF069344B40
55020	56588	42.164313999999997	43.181080999999999	54.508974000000002	53.733350999999999	Садовая	0103000020E610000001000000050000003123BC3D0815454094BE1072DEDD4A403123BC3D08154540D5415E0F26414B40A77686A92D974540D5415E0F26414B40A77686A92D97454094BE1072DEDD4A403123BC3D0815454094BE1072DEDD4A40
54337	6414	42.748201000000002	42.795650000000002	53.861123999999997	53.837274000000001	Новая	0103000020E61000000100000005000000D1EAE40CC55F454043E55FCB2BEB4A40D1EAE40CC55F45407DE6AC4F39EE4A40FD87F4DBD76545407DE6AC4F39EE4A40FD87F4DBD765454043E55FCB2BEB4A40D1EAE40CC55F454043E55FCB2BEB4A40
54839	6250	42.676785000000002	42.718207	54.129511999999998	54.104016000000001	Школьная	0103000020E6100000010000000500000031B610E4A056454060217365500D4B4031B610E4A0564540433866D993104B400F61FC34EE5B4540433866D993104B400F61FC34EE5B454060217365500D4B4031B610E4A056454060217365500D4B40
54368	6250	42.676785000000002	42.718207	54.129511999999998	54.104016000000001	Озерная	0103000020E6100000010000000500000031B610E4A056454060217365500D4B4031B610E4A0564540433866D993104B400F61FC34EE5B4540433866D993104B400F61FC34EE5B454060217365500D4B4031B610E4A056454060217365500D4B40
54524	5300	42.848489000000001	42.861784	54.347813000000002	54.337741000000001	Молодежная	0103000020E6100000010000000500000004029D499B6C454059C2DA183B2B4B4004029D499B6C4540D40FEA22852C4B40A81B28F04E6E4540D40FEA22852C4B40A81B28F04E6E454059C2DA183B2B4B4004029D499B6C454059C2DA183B2B4B40
54836	6190	42.852764999999998	42.863517999999999	54.021737999999999	54.012729	Школьная	0103000020E6100000010000000500000033164D67276D4540FB5A971AA1014B4033164D67276D45404C8A8F4FC8024B40F0C000C2876E45404C8A8F4FC8024B40F0C000C2876E4540FB5A971AA1014B4033164D67276D4540FB5A971AA1014B40
54530	6171	42.960132000000002	42.992210999999998	53.942428	53.919341000000003	Ленина	0103000020E61000000100000005000000EAEBF99AE57A45409C6F44F7ACF54A40EAEBF99AE57A4540D76A0F7BA1F84A40A0DD21C5007F4540D76A0F7BA1F84A40A0DD21C5007F45409C6F44F7ACF54A40EAEBF99AE57A45409C6F44F7ACF54A40
54954	6100	42.307039000000003	42.343753	54.169437000000002	54.155382000000003	Центральная	0103000020E610000001000000050000005CCCCF0D4D2745408C31B08EE3134B405CCCCF0D4D274540BEDD921CB0154B4071732A19002C4540BEDD921CB0154B4071732A19002C45408C31B08EE3134B405CCCCF0D4D2745408C31B08EE3134B40
54746	6044	42.670972999999996	42.715718000000003	53.853014000000002	53.824886999999997	Центральная	0103000020E61000000100000005000000DFBF7971E2554540A1F2AFE595E94A40DFBF7971E2554540DC8310902FED4A404B94BDA59C5B4540DC8310902FED4A404B94BDA59C5B4540A1F2AFE595E94A40DFBF7971E2554540A1F2AFE595E94A40
54678	56556	42.868737000000003	42.898454000000001	54.276589000000001	54.258947999999997	Почтовая	0103000020E610000001000000050000009FE925C6326F4540ABAE433525214B409FE925C6326F454078B7B24467234B40EE7A698A0073454078B7B24467234B40EE7A698A00734540ABAE433525214B409FE925C6326F4540ABAE433525214B40
54942	5351	42.420738	42.447786999999998	54.012528000000003	54.000563	Школьная	0103000020E610000001000000050000009C1727BEDA354540384BC97212004B409C1727BEDA35454064247B849A014B4077499C155139454064247B849A014B4077499C1551394540384BC97212004B409C1727BEDA354540384BC97212004B40
54739	4793	42.882365	42.905217999999998	53.846666999999997	53.830691000000002	Садовая	0103000020E6100000010000000500000049111956F1704540700A2B1554EA4A4049111956F17045401CCD91955FEC4A4011E0F42EDE7345401CCD91955FEC4A4011E0F42EDE734540700A2B1554EA4A4049111956F1704540700A2B1554EA4A40
54378	5831	42.889156	42.926400000000001	54.128093	54.109591000000002	Школьная	0103000020E61000000100000005000000668522DDCF714540CD77F013070E4B40668522DDCF7145405BECF65965104B40D8817346947645405BECF65965104B40D881734694764540CD77F013070E4B40668522DDCF714540CD77F013070E4B40
54655	5831	42.889156	42.926400000000001	54.128093	54.109591000000002	Пионерская	0103000020E61000000100000005000000668522DDCF714540CD77F013070E4B40668522DDCF7145405BECF65965104B40D8817346947645405BECF65965104B40D881734694764540CD77F013070E4B40668522DDCF714540CD77F013070E4B40
54992	5039	42.991213999999999	43.013635000000001	54.013739000000001	53.987727	Монастырская	0103000020E610000001000000050000002EABB019E07E454027309DD66DFE4A402EABB019E07E454002D71533C2014B405D8AABCABE81454002D71533C2014B405D8AABCABE81454027309DD66DFE4A402EABB019E07E454027309DD66DFE4A40
54835	5771	42.662016999999999	42.685704999999999	54.316004	54.292647000000002	Центральная	0103000020E61000000100000005000000B1321AF9BC544540E222F77475254B40B1321AF9BC544540DDB3AED172284B4012DA722EC5574540DDB3AED172284B4012DA722EC5574540E222F77475254B40B1321AF9BC544540E222F77475254B40
54833	5734	42.945624000000002	42.979022999999998	53.880549000000002	53.860778000000003	Советская	0103000020E6100000010000000500000007280D350A794540E38E37F92DEE4A4007280D350A79454044C362D4B5F04A4012842BA0507D454044C362D4B5F04A4012842BA0507D4540E38E37F92DEE4A4007280D350A794540E38E37F92DEE4A40
54641	6831	42.708891000000001	42.866869000000001	54.375314000000003	54.257196999999998	Школьная	0103000020E61000000100000005000000E1B6B6F0BC5A45408DD0CFD4EB204B40E1B6B6F0BC5A454090DD054A0A304B4047753A90F56E454090DD054A0A304B4047753A90F56E45408DD0CFD4EB204B40E1B6B6F0BC5A45408DD0CFD4EB204B40
54618	6771	42.688040999999998	42.701255000000003	54.414957999999999	54.404352000000003	Центральная	0103000020E6100000010000000500000050A73CBA115845403E096CCEC1334B4050A73CBA11584540569BFF571D354B4008944DB9C2594540569BFF571D354B4008944DB9C25945403E096CCEC1334B4050A73CBA115845403E096CCEC1334B40
54537	5572	42.961281999999997	42.982714999999999	54.005453000000003	53.983105000000002	Школьная	0103000020E61000000100000005000000E21DE0490B7B45405DC47762D6FD4A40E21DE0490B7B4540225514AFB2004B40F224E99AC97D4540225514AFB2004B40F224E99AC97D45405DC47762D6FD4A40E21DE0490B7B45405DC47762D6FD4A40
54745	5505	42.725402000000003	42.746125999999997	53.807679999999998	53.780937000000002	Советская	0103000020E61000000100000005000000FC3905F9D95C4540419E5DBEF5E34A40FC3905F9D95C45400FD1E80E62E74A40FF58880E815F45400FD1E80E62E74A40FF58880E815F4540419E5DBEF5E34A40FC3905F9D95C4540419E5DBEF5E34A40
54643	5699	42.960158999999997	43.003889000000001	54.057909000000002	54.032808000000003	Советская	0103000020E61000000100000005000000E3FA777DE67A45400A86730D33044B40E3FA777DE67A45407192E68F69074B4036E84B6F7F8045407192E68F69074B4036E84B6F7F8045400A86730D33044B40E3FA777DE67A45400A86730D33044B40
54743	5409	43.119466000000003	43.159908000000001	53.862673999999998	53.845413000000001	Центральная	0103000020E61000000100000005000000F27D71A94A8F45407F4E417E36EC4A40F27D71A94A8F4540048E041A6CEE4A40342F87DD77944540048E041A6CEE4A40342F87DD779445407F4E417E36EC4A40F27D71A94A8F45407F4E417E36EC4A40
54664	5457	42.824513000000003	42.837547999999998	53.976523999999998	53.941325999999997	Степная	0103000020E610000001000000050000003D1059A489694540EF6FD05E7DF84A403D1059A4896945402AE109BDFEFC4A40446ADAC5346B45402AE109BDFEFC4A40446ADAC5346B4540EF6FD05E7DF84A403D1059A489694540EF6FD05E7DF84A40
54747	5991	42.868772999999997	42.897033999999998	54.243755999999998	54.230812	Новая	0103000020E61000000100000005000000EB5223F4336F45401EC3633F8B1D4B40EB5223F4336F4540151A8865331F4B4035B39602D2724540151A8865331F4B4035B39602D27245401EC3633F8B1D4B40EB5223F4336F45401EC3633F8B1D4B40
54748	6726	42.701543000000001	42.724980000000002	54.469175	54.457165000000003	Лесная	0103000020E610000001000000050000006EDE3829CC5945401CF0F961843A4B406EDE3829CC594540E78C28ED0D3C4B4086200725CC5C4540E78C28ED0D3C4B4086200725CC5C45401CF0F961843A4B406EDE3829CC5945401CF0F961843A4B40
54597	5234	42.846423000000001	42.863571999999998	54.314574999999998	54.304715999999999	Садовая	0103000020E6100000010000000500000086CABF96576C4540B24813EF00274B4086CABF96576C4540D1915CFE43284B40E3DEFC86896E4540D1915CFE43284B40E3DEFC86896E4540B24813EF00274B4086CABF96576C4540B24813EF00274B40
54831	5190	42.598846999999999	42.619076999999997	54.218525999999997	54.185304000000002	Сураевой	0103000020E610000001000000050000006327BC04A74C4540B4E89D0AB8174B406327BC04A74C4540B0A9F3A8F81B4B40575A46EA3D4F4540B0A9F3A8F81B4B40575A46EA3D4F4540B4E89D0AB8174B406327BC04A74C4540B4E89D0AB8174B40
54940	5080	42.975977999999998	42.992283	53.987012999999997	53.969920000000002	Школьная	0103000020E61000000100000005000000C8CEDBD8EC7C454040DEAB5626FC4A40C8CEDBD8EC7C454009DD257156FE4A403AB01C21037F454009DD257156FE4A403AB01C21037F454040DEAB5626FC4A40C8CEDBD8EC7C454040DEAB5626FC4A40
54946	5142	42.433898999999997	42.454586999999997	53.943795000000001	53.929780999999998	Свердлова	0103000020E6100000010000000500000030629F008A37454099B8551003F74A4030629F008A3745406D904946CEF84A40E71725E82F3A45406D904946CEF84A40E71725E82F3A454099B8551003F74A4030629F008A37454099B8551003F74A40
54409	4046	42.797384000000001	42.864488000000001	54.098134999999999	54.059626999999999	Советская	0103000020E61000000100000005000000452DCDAD10664540B37A87DBA1074B40452DCDAD10664540E6CB0BB08F0C4B4069E4F38AA76E4540E6CB0BB08F0C4B4069E4F38AA76E4540B37A87DBA1074B40452DCDAD10664540B37A87DBA1074B40
54418	4046	42.797384000000001	42.864488000000001	54.098134999999999	54.059626999999999	Олега Кошевого	0103000020E61000000100000005000000452DCDAD10664540B37A87DBA1074B40452DCDAD10664540E6CB0BB08F0C4B4069E4F38AA76E4540E6CB0BB08F0C4B4069E4F38AA76E4540B37A87DBA1074B40452DCDAD10664540B37A87DBA1074B40
54361	4046	42.797384000000001	42.864488000000001	54.098134999999999	54.059626999999999	Новикова-Прибоя	0103000020E61000000100000005000000452DCDAD10664540B37A87DBA1074B40452DCDAD10664540E6CB0BB08F0C4B4069E4F38AA76E4540E6CB0BB08F0C4B4069E4F38AA76E4540B37A87DBA1074B40452DCDAD10664540B37A87DBA1074B40
54416	4046	42.797384000000001	42.864488000000001	54.098134999999999	54.059626999999999	Ленинская	0103000020E61000000100000005000000452DCDAD10664540B37A87DBA1074B40452DCDAD10664540E6CB0BB08F0C4B4069E4F38AA76E4540E6CB0BB08F0C4B4069E4F38AA76E4540B37A87DBA1074B40452DCDAD10664540B37A87DBA1074B40
54622	4046	42.797384000000001	42.864488000000001	54.098134999999999	54.059626999999999	 Новикова-Прибоя	0103000020E61000000100000005000000452DCDAD10664540B37A87DBA1074B40452DCDAD10664540E6CB0BB08F0C4B4069E4F38AA76E4540E6CB0BB08F0C4B4069E4F38AA76E4540B37A87DBA1074B40452DCDAD10664540B37A87DBA1074B40
54742	4977	42.998409000000002	43.00759	53.985047999999999	53.959887000000002	Балашова	0103000020E610000001000000050000001B84B9DDCB7F4540836DC493DDFA4A401B84B9DDCB7F4540BF7E880D16FE4A4069E388B5F8804540BF7E880D16FE4A4069E388B5F8804540836DC493DDFA4A401B84B9DDCB7F4540836DC493DDFA4A40
54640	4942	42.554955999999997	42.596260000000001	54.134507999999997	54.116025	Заречная	0103000020E61000000100000005000000075C57CC084745405B423EE8D90E4B40075C57CC084745407286E28E37114B40DCF4673F524C45407286E28E37114B40DCF4673F524C45405B423EE8D90E4B40075C57CC084745405B423EE8D90E4B40
54994	4876	42.714604000000001	42.744078000000002	53.879354999999997	53.866284999999998	Школьная	0103000020E610000001000000050000009FCBD424785B4540F701486DE2EE4A409FCBD424785B45407B4963B48EF04A4028D6A9F23D5F45407B4963B48EF04A4028D6A9F23D5F4540F701486DE2EE4A409FCBD424785B4540F701486DE2EE4A40
54632	4835	42.567514000000003	42.589773999999998	54.167523000000003	54.156241999999999	Пионерская	0103000020E61000000100000005000000D6027B4CA44845407D21E4BCFF134B40D6027B4CA4484540F629C76471154B40FB03E5B67D4B4540F629C76471154B40FB03E5B67D4B45407D21E4BCFF134B40D6027B4CA44845407D21E4BCFF134B40
54928	2835	42.889550999999997	42.906627999999998	53.868721999999998	53.854905000000002	Школьная	0103000020E61000000100000005000000E28FA2CEDC714540EC17EC866DED4A40E28FA2CEDC71454069A8514832EF4A40A6D1E4620C74454069A8514832EF4A40A6D1E4620C744540EC17EC866DED4A40E28FA2CEDC714540EC17EC866DED4A40
54832	4631	42.366678	42.384554000000001	53.858750000000001	53.837375000000002	Школьная	0103000020E61000000100000005000000D314014EEF2E454077BE9F1A2FEB4A40D314014EEF2E454052B81E85EBED4A40E3C5C2103931454052B81E85EBED4A40E3C5C2103931454077BE9F1A2FEB4A40D314014EEF2E454077BE9F1A2FEB4A40
54995	4662	42.626623000000002	42.651237000000002	54.290508000000003	54.271478999999999	Молодежная	0103000020E61000000100000005000000F1F5B52E355045408046E9D2BF224B40F1F5B52E35504540FA9CBB5D2F254B40FB78E8BB5B534540FA9CBB5D2F254B40FB78E8BB5B5345408046E9D2BF224B40F1F5B52E355045408046E9D2BF224B40
54741	4568	42.862575	42.893171000000002	53.907269999999997	53.889443999999997	Центральная	0103000020E6100000010000000500000071AC8BDB686E4540CCCF0D4DD9F14A4071AC8BDB686E45402A52616C21F44A40295E656D537245402A52616C21F44A40295E656D53724540CCCF0D4DD9F14A4071AC8BDB686E4540CCCF0D4DD9F14A40
54557	4504	42.990620999999997	43.015540000000001	53.919829	53.901493000000002	Молодежная	0103000020E610000001000000050000008BDD3EABCC7E45405649641F64F34A408BDD3EABCC7E4540C974E8F4BCF54A40D2E3F736FD814540C974E8F4BCF54A40D2E3F736FD8145405649641F64F34A408BDD3EABCC7E45405649641F64F34A40
54991	5614	42.879679000000003	42.899720000000002	54.054895999999999	54.040131000000002	Алтухова	0103000020E610000001000000050000002FFD4B529970454024473A0323054B402FFD4B5299704540325706D506074B4050C763062A734540325706D506074B4050C763062A73454024473A0323054B402FFD4B529970454024473A0323054B40
55040	2741	43.824598999999999	43.841918	54.582256000000001	54.572367999999997	Безбородова	0103000020E610000001000000050000003BA8C4758CE9454072A3C85A43494B403BA8C4758CE945402CF3565D874A4B40F5F411F8C3EB45402CF3565D874A4B40F5F411F8C3EB454072A3C85A43494B403BA8C4758CE9454072A3C85A43494B40
54744	52621	44.055653999999997	44.067385999999999	54.559933999999998	54.550973999999997	Школьная	0103000020E610000001000000050000001FF296AB1F0746402079E75086464B401FF296AB1F07464090F5D4EAAB474B40A81ABD1AA008464090F5D4EAAB474B40A81ABD1AA00846402079E75086464B401FF296AB1F0746402079E75086464B40
54606	3558	43.747369999999997	43.783537000000003	54.596978999999997	54.575937000000003	Ленинская	0103000020E610000001000000050000007901F6D1A9DF454037C7B94DB8494B407901F6D1A9DF45400BB3D0CE694C4B405D1ABFF04AE445400BB3D0CE694C4B405D1ABFF04AE4454037C7B94DB8494B407901F6D1A9DF454037C7B94DB8494B40
54935	3660	43.930025000000001	43.954998000000003	54.700558999999998	54.684756	Советская	0103000020E6100000010000000500000030BB270F0BF74540B1DEA815A6574B4030BB270F0BF7454090F5D4EAAB594B406ADFDC5F3DFA454090F5D4EAAB594B406ADFDC5F3DFA4540B1DEA815A6574B4030BB270F0BF74540B1DEA815A6574B40
54735	56564	43.963343000000002	43.981247000000003	54.583174999999997	54.575577000000003	Школьная	0103000020E610000001000000050000004FEACBD24EFB454037AAD381AC494B404FEACBD24EFB4540226C787AA54A4B4029266F8099FD4540226C787AA54A4B4029266F8099FD454037AAD381AC494B404FEACBD24EFB454037AAD381AC494B40
54736	3299	43.644091000000003	43.673295000000003	54.798591999999999	54.790308000000003	Колхозная	0103000020E61000000100000005000000F052EA9271D2454033E202D028654B40F052EA9271D24540726C3D4338664B40B9C7D2872ED64540726C3D4338664B40B9C7D2872ED6454033E202D028654B40F052EA9271D2454033E202D028654B40
54830	3521	43.688136	43.707026999999997	54.573573000000003	54.563535999999999	 Колхозная	0103000020E61000000100000005000000A29927D714D84540300F99F221484B40A29927D714D845402F6F0ED76A494B40CA3159DC7FDA45402F6F0ED76A494B40CA3159DC7FDA4540300F99F221484B40A29927D714D84540300F99F221484B40
55068	56591	43.723106999999999	43.738844999999998	54.749434000000001	54.730552000000003	Центральная	0103000020E610000001000000050000001C412AC58EDC454082035ABA825D4B401C412AC58EDC454057410C74ED5F4B4014E8137992DE454057410C74ED5F4B4014E8137992DE454082035ABA825D4B401C412AC58EDC454082035ABA825D4B40
54989	3920	44.060657999999997	44.074851000000002	54.496568000000003	54.488639999999997	Луговая	0103000020E61000000100000005000000D11E2FA4C30746403BC269C18B3E4B40D11E2FA4C3074640BD1E4C8A8F3F4B405589B2B794094640BD1E4C8A8F3F4B405589B2B7940946403BC269C18B3E4B40D11E2FA4C30746403BC269C18B3E4B40
55050	3628	44.016057000000004	44.046976999999998	54.696292999999997	54.669195999999999	Пролетарская	0103000020E610000001000000050000009AEFE0270E024640984EEB36A8554B409AEFE0270E02464084B7072120594B400455A3570306464084B7072120594B400455A35703064640984EEB36A8554B409AEFE0270E024640984EEB36A8554B40
54939	3951	43.950218999999997	43.993194000000003	54.576338999999997	54.564272000000003	Центральная	0103000020E61000000100000005000000D784B4C6A0F9454036069D103A484B40D784B4C6A0F945406534F279C5494B40AE4A22FB20FF45406534F279C5494B40AE4A22FB20FF454036069D103A484B40D784B4C6A0F9454036069D103A484B40
54987	3723	44.062489999999997	44.087356	54.645135000000003	54.626099000000004	М.Ларина	0103000020E61000000100000005000000DC291DACFF0746407787140324504B40DC291DACFF074640A3409FC893524B40008E3D7B2E0B4640A3409FC893524B40008E3D7B2E0B46407787140324504B40DC291DACFF0746407787140324504B40
54933	3340	43.642159999999997	43.655464000000002	54.686703000000001	54.678541000000003	Центральная	0103000020E610000001000000050000005166834C32D2454061FF756EDA564B405166834C32D24540558847E2E5574B4049DA8D3EE6D34540558847E2E5574B4049DA8D3EE6D3454061FF756EDA564B405166834C32D2454061FF756EDA564B40
54988	3852	43.943705999999999	43.960118000000001	54.514614000000002	54.507066000000002	Маскинская	0103000020E61000000100000005000000FD84B35BCBF84540EF74E789E7404B40FD84B35BCBF8454029081EDFDE414B4085268925E5FA454029081EDFDE414B4085268925E5FA4540EF74E789E7404B40FD84B35BCBF84540EF74E789E7404B40
54937	3824	43.776099000000002	43.799607000000002	54.541767	54.527400999999998	Ленина	0103000020E61000000100000005000000AABA473657E3454058703FE081434B40AABA473657E34540A986FD9E58454B408B53AD8559E64540A986FD9E58454B408B53AD8559E6454058703FE081434B40AABA473657E3454058703FE081434B40
54379	2864	43.832261000000003	43.889716999999997	54.639189999999999	54.605061999999997	площадь 1 Мая	0103000020E610000001000000050000003E5E488787EA4540B306EFAB724D4B403E5E488787EA454012F758FAD0514B40FDD8243FE2F1454012F758FAD0514B40FDD8243FE2F14540B306EFAB724D4B403E5E488787EA4540B306EFAB724D4B40
54332	2864	43.832261000000003	43.889716999999997	54.639189999999999	54.605061999999997	Садовая	0103000020E610000001000000050000003E5E488787EA4540B306EFAB724D4B403E5E488787EA454012F758FAD0514B40FDD8243FE2F1454012F758FAD0514B40FDD8243FE2F14540B306EFAB724D4B403E5E488787EA4540B306EFAB724D4B40
54531	2864	43.832261000000003	43.889716999999997	54.639189999999999	54.605061999999997	Ленина	0103000020E610000001000000050000003E5E488787EA4540B306EFAB724D4B403E5E488787EA454012F758FAD0514B40FDD8243FE2F1454012F758FAD0514B40FDD8243FE2F14540B306EFAB724D4B403E5E488787EA4540B306EFAB724D4B40
54934	3449	43.696767999999999	43.707287999999998	54.635750999999999	54.628742000000003	Мира	0103000020E610000001000000050000001D739EB12FD9454092CF2B9E7A504B401D739EB12FD945401CB3EC4960514B40376DC66988DA45401CB3EC4960514B40376DC66988DA454092CF2B9E7A504B401D739EB12FD9454092CF2B9E7A504B40
54828	3189	43.836545999999998	43.864770999999998	54.691678000000003	54.678213	Советская	0103000020E61000000100000005000000C0CC77F013EB45406C5CFFAECF564B40C0CC77F013EB45406DAE9AE788584B40BDC3EDD0B0EE45406DAE9AE788584B40BDC3EDD0B0EE45406C5CFFAECF564B40C0CC77F013EB45406C5CFFAECF564B40
54738	3414	43.690911	43.707431	54.668478	54.651021	Школьная	0103000020E610000001000000050000002CB98AC56FD845402E01F8A754534B402CB98AC56FD84540390CE6AF90554B409A9658198DDA4540390CE6AF90554B409A9658198DDA45402E01F8A754534B402CB98AC56FD845402E01F8A754534B40
54936	3750	44.136305	44.157065000000003	54.625098000000001	54.620136000000002	Центральная	0103000020E6100000010000000500000001A43671721146404089CF9D604F4B4001A4367172114640C365153603504B40522CB7B41A144640C365153603504B40522CB7B41A1446404089CF9D604F4B4001A43671721146404089CF9D604F4B40
54985	3103	43.734910999999997	43.752876999999998	54.641967000000001	54.632077000000002	Молодежная	0103000020E610000001000000050000003E3C4B9011DE4540E3C62DE6E7504B403E3C4B9011DE45403D0E83F92B524B408E7406465EE045403D0E83F92B524B408E7406465EE04540E3C62DE6E7504B403E3C4B9011DE4540E3C62DE6E7504B40
54986	2705	46.380538999999999	46.40889	54.475757000000002	54.451684999999998	 Советская	0103000020E6100000010000000500000020ED7F80B5304740008C67D0D0394B4020ED7F80B5304740EAEBF99AE53C4B40AAD4EC8156344740EAEBF99AE53C4B40AAD4EC8156344740008C67D0D0394B4020ED7F80B5304740008C67D0D0394B40
54983	2633	46.454937999999999	46.489702000000001	54.380107000000002	54.350043999999997	Большая	0103000020E6100000010000000500000094DA8B683B3A47409C14E63DCE2C4B4094DA8B683B3A474087FD9E58A7304B4095641D8EAE3E474087FD9E58A7304B4095641D8EAE3E47409C14E63DCE2C4B4094DA8B683B3A47409C14E63DCE2C4B40
54630	2597	46.609088999999997	46.661423999999997	54.381570000000004	54.366481	Жадейкина	0103000020E610000001000000050000003AADDBA0F64D47407DCD72D9E82E4B403AADDBA0F64D47403F912749D7304B400E65A88AA95447403F912749D7304B400E65A88AA95447407DCD72D9E82E4B403AADDBA0F64D47407DCD72D9E82E4B40
54930	2406	46.278410000000001	46.340437999999999	54.480679000000002	54.454464000000002	Школьная	0103000020E610000001000000050000008F705AF0A2234740CC9A58E02B3A4B408F705AF0A2234740DF6FB4E3863D4B406728EE78932B4740DF6FB4E3863D4B406728EE78932B4740CC9A58E02B3A4B408F705AF0A2234740CC9A58E02B3A4B40
54605	2406	46.278410000000001	46.340437999999999	54.480679000000002	54.454464000000002	 Школьная	0103000020E610000001000000050000008F705AF0A2234740CC9A58E02B3A4B408F705AF0A2234740DF6FB4E3863D4B406728EE78932B4740DF6FB4E3863D4B406728EE78932B4740CC9A58E02B3A4B408F705AF0A2234740CC9A58E02B3A4B40
54827	49483	46.124906000000003	46.138758000000003	54.358480999999998	54.347535000000001	Богдановка	0103000020E610000001000000050000007F8978EBFC0F4740919BE1067C2C4B407F8978EBFC0F4740629E95B4E22D4B40790778D2C2114740629E95B4E22D4B40790778D2C2114740919BE1067C2C4B407F8978EBFC0F4740919BE1067C2C4B40
54981	2251	46.430889999999998	46.472760000000001	54.414078000000003	54.391357999999997	Московская	0103000020E6100000010000000500000033164D67273747409483D90418324B4033164D67273747401EFF058200354B40B16D5166833C47401EFF058200354B40B16D5166833C47409483D90418324B4033164D67273747409483D90418324B40
54733	2148	46.112912999999999	46.148665999999999	54.383741000000001	54.349640000000001	Семипалаты	0103000020E610000001000000050000008925E5EE730E4740CDAFE600C12C4B408925E5EE730E47403291D26C1E314B407903CC7C071347403291D26C1E314B407903CC7C07134740CDAFE600C12C4B408925E5EE730E4740CDAFE600C12C4B40
54927	49459	46.420613000000003	46.452790999999998	54.375717999999999	54.353628	Молодежная	0103000020E61000000100000005000000E0A293A5D63547409679ABAE432D4B40E0A293A5D63547405F42058717304B402976340EF53947405F42058717304B402976340EF53947409679ABAE432D4B40E0A293A5D63547409679ABAE432D4B40
54820	1940	46.228929999999998	46.276980999999999	54.351202999999998	54.326101999999999	Ленина	0103000020E61000000100000005000000618907944D1D47408194D8B5BD294B40618907944D1D4740E8A04B38F42C4B40834E081D74234740E8A04B38F42C4B40834E081D742347408194D8B5BD294B40618907944D1D47408194D8B5BD294B40
54563	32695	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	Центральная	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
54645	32695	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	Луговая	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
55088	32695	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	Лесная	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
55083	32695	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	Куйбышева	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
54581	32695	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	Денисова	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
54528	32695	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	Бровцева	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
55082	32695	46.273972000000001	46.329461000000002	54.451397	54.426279000000001	 Школьная	0103000020E610000001000000050000008602B683112347405DFC6D4F90364B408602B683112347409A417C60C7394B405B272EC72B2A47409A417C60C7394B405B272EC72B2A47405DFC6D4F90364B408602B683112347405DFC6D4F90364B40
81157	62111	\N	\N	\N	\N	Центральная	\N
54829	49581	46.248252999999998	46.290841999999998	54.515340000000002	54.507542000000001	Лесная	0103000020E6100000010000000500000023111AC1C61F474058ACE122F7404B4023111AC1C61F47400B293FA9F6414B40D026874F3A2547400B293FA9F6414B40D026874F3A25474058ACE122F7404B4023111AC1C61F474058ACE122F7404B40
54926	50005	45.504655	45.532808000000003	55.043861	55.028588999999997	Кооперативная	0103000020E61000000100000005000000A661F88898C046403E03EACDA8834B40A661F88898C04640F148BC3C9D854B400A86730D33C44640F148BC3C9D854B400A86730D33C446403E03EACDA8834B40A661F88898C046403E03EACDA8834B40
54919	6949	45.831263999999997	45.853389999999997	54.969895000000001	54.955334000000001	Центральная	0103000020E61000000100000005000000CB2BD7DB66EA4640E1606F62487A4B40CB2BD7DB66EA4640E7C6F484257C4B40E15D2EE23BED4640E7C6F484257C4B40E15D2EE23BED4640E1606F62487A4B40CB2BD7DB66EA4640E1606F62487A4B40
54980	1261	45.441457999999997	45.468038999999997	55.049235000000003	55.024306000000003	Садовая	0103000020E610000001000000050000005E471CB281B846405D8C81751C834B405E471CB281B84640C7681D554D864B405320B3B3E8BB4640C7681D554D864B405320B3B3E8BB46405D8C81751C834B405E471CB281B846405D8C81751C834B40
54729	1008	45.612029999999997	45.628649000000003	55.074596999999997	55.051957999999999	Западная	0103000020E61000000100000005000000DF15C1FF56CE4640FE614B8FA6864B40DF15C1FF56CE46409AB0FD648C894B40E1D4079277D046409AB0FD648C894B40E1D4079277D04640FE614B8FA6864B40DF15C1FF56CE4640FE614B8FA6864B40
54982	50004	45.660521000000003	45.683689000000001	55.130971000000002	55.118014000000002	 Новая	0103000020E610000001000000050000001EA9BEF38BD446402E3C2F151B8F4B401EA9BEF38BD44640BADC60A8C3904B4046D1031F83D74640BADC60A8C3904B4046D1031F83D746402E3C2F151B8F4B401EA9BEF38BD446402E3C2F151B8F4B40
55055	22597	45.482475000000001	45.510772000000003	54.969135000000001	54.954579000000003	Ленина	0103000020E610000001000000050000009D11A5BDC1BD4640653909A52F7A4B409D11A5BDC1BD464059349D9D0C7C4B4034DB15FA60C1464059349D9D0C7C4B4034DB15FA60C14640653909A52F7A4B409D11A5BDC1BD4640653909A52F7A4B40
54823	15620	45.586851000000003	45.615955999999997	54.934153000000002	54.912578000000003	Гагарина	0103000020E61000000100000005000000FD4FFEEE1DCB464049861C5BCF744B40FD4FFEEE1DCB4640EB3A545392774B4032E36DA5D7CE4640EB3A545392774B4032E36DA5D7CE464049861C5BCF744B40FD4FFEEE1DCB464049861C5BCF744B40
54698	19361	45.719676	45.745807999999997	54.896743999999998	54.887269000000003	Советская	0103000020E61000000100000005000000A9DBD9571EDC464098E0D40792714B40A9DBD9571EDC46402E71E481C8724B402E8CF4A276DF46402E71E481C8724B402E8CF4A276DF464098E0D40792714B40A9DBD9571EDC464098E0D40792714B40
54977	56580	45.445383999999997	45.465353	54.897784999999999	54.883954000000003	 Гагарина	0103000020E61000000100000005000000B114C95702B946408E95986725714B40B114C95702B9464070EB6E9EEA724B40390CE6AF90BB464070EB6E9EEA724B40390CE6AF90BB46408E95986725714B40B114C95702B946408E95986725714B40
54710	12278	45.672271000000002	45.704216000000002	55.038423000000002	55.020274999999998	Ленина	0103000020E610000001000000050000004D86E3F90CD6464094F6065F98824B404D86E3F90CD6464005357C0BEB844B40F4A8F8BF23DA464005357C0BEB844B40F4A8F8BF23DA464094F6065F98824B404D86E3F90CD6464094F6065F98824B40
54690	49603	45.668975000000003	45.686751999999998	54.991365999999999	54.979139000000004	Школьная	0103000020E61000000100000005000000BA6B09F9A0D546407C9E3F6D547D4B40BA6B09F9A0D54640E42EC214E57E4B40363B527DE7D74640E42EC214E57E4B40363B527DE7D746407C9E3F6D547D4B40BA6B09F9A0D546407C9E3F6D547D4B40
64826	58364	45.785907999999999	45.808923	54.877800999999998	54.867896000000002	Советская	0103000020E6100000010000000500000017D522A298E44640242A5437176F4B4017D522A298E44640B3B27DC85B704B40B9FDF2C98AE74640B3B27DC85B704B40B9FDF2C98AE74640242A5437176F4B4017D522A298E44640242A5437176F4B40
54766	47731	45.492483	45.518669000000003	54.901936999999997	54.893047000000003	Школьная	0103000020E61000000100000005000000016BD5AE09BF46403D65355D4F724B40016BD5AE09BF4640B306EFAB72734B407A39ECBE63C24640B306EFAB72734B407A39ECBE63C246403D65355D4F724B40016BD5AE09BF46403D65355D4F724B40
55049	2414	45.541907999999999	45.580534999999998	54.976612000000003	54.966551000000003	Советская	0103000020E610000001000000050000006BB8C83D5DC54640437573F1B77B4B406BB8C83D5DC54640CA703C9F017D4B4078978BF84ECA4640CA703C9F017D4B4078978BF84ECA4640437573F1B77B4B406BB8C83D5DC54640437573F1B77B4B40
54401	1673	45.550918000000003	45.591799999999999	55.033526999999999	55.007157999999997	Советская	0103000020E610000001000000050000008D63247B84C64640CFF3A78DEA804B408D63247B84C646403944DC9C4A844B40EBE2361AC0CB46403944DC9C4A844B40EBE2361AC0CB4640CFF3A78DEA804B408D63247B84C64640CFF3A78DEA804B40
54730	1132	45.599606999999999	45.635368999999997	55.115028000000002	55.103008000000003	Центральная	0103000020E61000000100000005000000F1B913ECBFCC4640FA9CBB5D2F8D4B40F1B913ECBFCC4640E90FCD3CB98E4B4034F279C553D14640E90FCD3CB98E4B4034F279C553D14640FA9CBB5D2F8D4B40F1B913ECBFCC4640FA9CBB5D2F8D4B40
54604	780	46.064844000000001	46.129460000000002	54.281314999999999	54.255166000000003	Карла Маркса	0103000020E61000000100000005000000C1ABE5CE4C0847408C868C47A9204B40C1ABE5CE4C084740E76F422102244B40F111312592104740E76F422102244B40F1113125921047408C868C47A9204B40C1ABE5CE4C0847408C868C47A9204B40
54819	739	46.236080999999999	46.266542999999999	54.286177000000002	54.271495000000002	Центральная	0103000020E610000001000000050000007E1AF7E6371E474086032159C0224B407E1AF7E6371E474007EFAB72A1244B4026FDBD141E22474007EFAB72A1244B4026FDBD141E22474086032159C0224B407E1AF7E6371E474086032159C0224B40
54924	658	46.061619	46.09554	54.319448999999999	54.302309000000001	Ленина	0103000020E61000000100000005000000F7E7A221E3074740AB24B20FB2264B40F7E7A221E3074740B5DE6FB4E3284B40DCBA9BA73A0C4740B5DE6FB4E3284B40DCBA9BA73A0C4740AB24B20FB2264B40F7E7A221E3074740AB24B20FB2264B40
54811	280	45.777455000000003	45.835656999999998	54.162072999999999	54.146518	Школьная	0103000020E610000001000000050000004C8E3BA583E346403E23111AC1124B404C8E3BA583E346404548DDCEBE144B4034D6FECEF6EA46404548DDCEBE144B4034D6FECEF6EA46403E23111AC1124B404C8E3BA583E346403E23111AC1124B40
54732	623	45.923270000000002	45.940992999999999	54.283607000000003	54.245403000000003	О.Николаева	0103000020E6100000010000000500000060B01BB62DF646408FAB915D691F4B4060B01BB62DF6464056F5F23B4D244B40E961687572F8464056F5F23B4D244B40E961687572F846408FAB915D691F4B4060B01BB62DF646408FAB915D691F4B40
54817	526	46.15596	46.189655999999999	54.262087999999999	54.245977000000003	Ленина	0103000020E61000000100000005000000F9BD4D7FF6134740BB48A12C7C1F4B40F9BD4D7FF613474047567E198C214B40BEBED6A54618474047567E198C214B40BEBED6A546184740BB48A12C7C1F4B40F9BD4D7FF6134740BB48A12C7C1F4B40
54596	507	46.036690999999998	46.079774	54.239967999999998	54.223700999999998	Центральная	0103000020E610000001000000050000005D876A4AB20447408F8AFF3BA21C4B405D876A4AB2044740130B7C45B71E4B401A89D008360A4740130B7C45B71E4B401A89D008360A47408F8AFF3BA21C4B405D876A4AB20447408F8AFF3BA21C4B40
54951	56578	45.571489	46.331895000000003	54.378695999999998	54.021098000000002	Новосельская	0103000020E610000001000000050000000A83328D26C946406901DA56B3024B400A83328D26C9464021904B1C79304B405C5A0D897B2A474021904B1C79304B405C5A0D897B2A47406901DA56B3024B400A83328D26C946406901DA56B3024B40
54727	232	45.835441000000003	45.868841000000003	54.211196999999999	54.198937000000001	Октябрьская	0103000020E61000000100000005000000685E0EBBEFEA4640707B82C476194B40685E0EBBEFEA4640B401D880081B4B404436902E36EF4640B401D880081B4B404436902E36EF4640707B82C476194B40685E0EBBEFEA4640707B82C476194B40
54809	144	45.796356000000003	45.841631	54.104734000000001	54.083168999999998	Верхняя	0103000020E6100000010000000500000098FC4FFEEEE5464040852348A50A4B4098FC4FFEEEE54640BF6378EC670D4B405F268A90BAEB4640BF6378EC670D4B405F268A90BAEB464040852348A50A4B4098FC4FFEEEE5464040852348A50A4B40
54922	363	46.165581000000003	46.215698000000003	54.315871999999999	54.284495	Московская	0103000020E6100000010000000500000064EB19C231154740117008556A244B4064EB19C2311547406EDC627E6E284B4004E8F7FD9B1B47406EDC627E6E284B4004E8F7FD9B1B4740117008556A244B4064EB19C231154740117008556A244B40
54804	32255	46.002446999999997	46.042934000000002	54.153221000000002	54.139629999999997	Центральная	0103000020E61000000100000005000000957CEC2E500047402EC55565DF114B40957CEC2E50004740BC07E8BE9C134B4078F17EDC7E054740BC07E8BE9C134B4078F17EDC7E0547402EC55565DF114B40957CEC2E500047402EC55565DF114B40
81085	32255	46.002446999999997	46.042934000000002	54.153221000000002	54.139629999999997	 Школьная	0103000020E61000000100000005000000957CEC2E500047402EC55565DF114B40957CEC2E50004740BC07E8BE9C134B4078F17EDC7E054740BC07E8BE9C134B4078F17EDC7E0547402EC55565DF114B40957CEC2E500047402EC55565DF114B40
54554	82	45.896625999999998	45.937652	54.142341000000002	54.126758000000002	Гагарина	0103000020E61000000100000005000000245F09A4C4F24640D1402C9B39104B40245F09A4C4F24640A2F0D93A38124B40B68311FB04F84640A2F0D93A38124B40B68311FB04F84640D1402C9B39104B40245F09A4C4F24640D1402C9B39104B40
54725	32212	45.937857999999999	45.957082	54.213597999999998	54.196651000000003	Советская	0103000020E610000001000000050000005F251FBB0BF84640E4DC26DC2B194B405F251FBB0BF84640D93EE42D571B4B408ECBB8A981FA4640D93EE42D571B4B408ECBB8A981FA4640E4DC26DC2B194B405F251FBB0BF84640E4DC26DC2B194B40
54979	32469	45.758913999999997	45.800846999999997	54.224006000000003	54.205604999999998	Ленина	0103000020E61000000100000005000000FF3C0D1824E146407172BF43511A4B40FF3C0D1824E14640CC0D863AAC1C4B40C30C8D2782E64640CC0D863AAC1C4B40C30C8D2782E646407172BF43511A4B40FF3C0D1824E146407172BF43511A4B40
55081	56602	45.876520999999997	45.895744999999998	54.243414000000001	54.228811999999998	Садовая	0103000020E61000000100000005000000ECA012D731F0464057772CB6491D4B40ECA012D731F04640BCB1A030281F4B401B47ACC5A7F24640BCB1A030281F4B401B47ACC5A7F2464057772CB6491D4B40ECA012D731F0464057772CB6491D4B40
54807	32386	45.667582000000003	45.693058000000001	54.167006999999998	54.147266999999999	Советская	0103000020E61000000100000005000000FBB2B45373D54640D86322A5D9124B40FBB2B45373D54640FE99417C60154B40971DE21FB6D84640FE99417C60154B40971DE21FB6D84640D86322A5D9124B40FBB2B45373D54640D86322A5D9124B40
54726	32355	45.679934000000003	45.718642000000003	54.197262000000002	54.178465000000003	Советская	0103000020E6100000010000000500000020B8CA1308D74640863DEDF0D7164B4020B8CA1308D746402D5F97E13F194B401AC40776FCDB46402D5F97E13F194B401AC40776FCDB4640863DEDF0D7164B4020B8CA1308D74640863DEDF0D7164B40
55039	32316	45.608472999999996	45.655949	54.152161	54.137272000000003	Школьная	0103000020E61000000100000005000000DFBF7971E2CD46400954FF2092114B40DFBF7971E2CD4640035DFB027A134B40056C0723F6D34640035DFB027A134B40056C0723F6D346400954FF2092114B40DFBF7971E2CD46400954FF2092114B40
54816	408	46.150075999999999	46.176783	54.337899	54.318697999999998	Карла Маркса	0103000020E610000001000000050000000EF5BBB0351347407AA69718CB284B400EF5BBB035134740F12C4146402B4B4090BE49D3A0164740F12C4146402B4B4090BE49D3A01647407AA69718CB284B400EF5BBB0351347407AA69718CB284B40
54376	31954	45.939287	45.993265999999998	54.187116000000003	54.162841999999998	Ленина	0103000020E610000001000000050000006B47718E3AF846402635B401D8144B406B47718E3AF846407847C66AF3174B40471D1D5723FF46407847C66AF3174B40471D1D5723FF46402635B401D8144B406B47718E3AF846402635B401D8144B40
54403	31954	45.939287	45.993265999999998	54.187116000000003	54.162841999999998	Карла Маркса	0103000020E610000001000000050000006B47718E3AF846402635B401D8144B406B47718E3AF846407847C66AF3174B40471D1D5723FF46407847C66AF3174B40471D1D5723FF46402635B401D8144B406B47718E3AF846402635B401D8144B40
54601	31954	45.939287	45.993265999999998	54.187116000000003	54.162841999999998	Казанская	0103000020E610000001000000050000006B47718E3AF846402635B401D8144B406B47718E3AF846407847C66AF3174B40471D1D5723FF46407847C66AF3174B40471D1D5723FF46402635B401D8144B406B47718E3AF846402635B401D8144B40
54803	31954	45.939287	45.993265999999998	54.187116000000003	54.162841999999998	Дубенское шоссе	0103000020E610000001000000050000006B47718E3AF846402635B401D8144B406B47718E3AF846407847C66AF3174B40471D1D5723FF46407847C66AF3174B40471D1D5723FF46402635B401D8144B406B47718E3AF846402635B401D8144B40
55138	31863	46.090733999999998	46.137284000000001	54.503050999999999	54.47842	Лесная	0103000020E610000001000000050000005051F52B9D0B47404CE0D6DD3C3D4B405051F52B9D0B47402C9CA4F963404B40CD21A985921147402C9CA4F963404B40CD21A985921147404CE0D6DD3C3D4B405051F52B9D0B47404CE0D6DD3C3D4B40
54798	31863	46.090733999999998	46.137284000000001	54.503050999999999	54.47842	Комсомольская	0103000020E610000001000000050000005051F52B9D0B47404CE0D6DD3C3D4B405051F52B9D0B47402C9CA4F963404B40CD21A985921147402C9CA4F963404B40CD21A985921147404CE0D6DD3C3D4B405051F52B9D0B47404CE0D6DD3C3D4B40
54984	30894	45.777957999999998	45.820771999999998	54.725971000000001	54.713729999999998	Красная Слобода	0103000020E61000000100000005000000AED4B32094E34640481630815B5B4B40AED4B32094E34640166C239EEC5C4B407BBC900E0FE94640166C239EEC5C4B407BBC900E0FE94640481630815B5B4B40AED4B32094E34640481630815B5B4B40
54797	48528	45.787947000000003	45.822074000000001	54.609380000000002	54.593119000000002	Центральная	0103000020E610000001000000050000009CFD8172DBE4464070D1C952EB4B4B409CFD8172DBE44640126BF129004E4B402A7288B839E94640126BF129004E4B402A7288B839E9464070D1C952EB4B4B409CFD8172DBE4464070D1C952EB4B4B40
54792	48330	46.016919000000001	46.055196000000002	54.580064999999998	54.567425	 Ленина	0103000020E610000001000000050000002CD7DB662A02474066F7E461A1484B402CD7DB662A024740F146E6913F4A4B405D6F9BA910074740F146E6913F4A4B405D6F9BA91007474066F7E461A1484B402CD7DB662A02474066F7E461A1484B40
54724	48676	46.226748000000001	46.258358999999999	54.592691000000002	54.569346000000003	Красная	0103000020E610000001000000050000007A371614061D4740E10D6954E0484B407A371614061D474018D1764CDD4B4B404AD05FE81121474018D1764CDD4B4B404AD05FE811214740E10D6954E0484B407A371614061D4740E10D6954E0484B40
54711	6041	45.746167	45.769568	54.637262	54.613379000000002	Ленина	0103000020E610000001000000050000005E2D776682DF4640CF86FC33834E4B405E2D776682DF4640E57D1CCD91514B402906483481E24640E57D1CCD91514B402906483481E24640CF86FC33834E4B405E2D776682DF4640CF86FC33834E4B40
54923	31808	46.119013000000002	46.153830999999997	54.693123999999997	54.677962999999998	Ленина	0103000020E61000000100000005000000416667D13B0F4740F372D87DC7564B40416667D13B0F47404E098849B8584B40340EF5BBB01347404E098849B8584B40340EF5BBB0134740F372D87DC7564B40416667D13B0F4740F372D87DC7564B40
54751	31621	46.242818	46.271304000000001	54.659917	54.640476999999997	Ленинская	0103000020E61000000100000005000000A87004A9141F47408B6B7C26FB514B40A87004A9141F47408789062978544B4012A3E716BA2247408789062978544B4012A3E716BA2247408B6B7C26FB514B40A87004A9141F47408B6B7C26FB514B40
54920	31559	46.268825	46.297336999999999	54.592221000000002	54.572467000000003	Советская	0103000020E6100000010000000500000071AC8BDB682247400685419946494B4071AC8BDB682247409180D1E5CD4B4B40047289230F2647409180D1E5CD4B4B40047289230F2647400685419946494B4071AC8BDB682247400685419946494B40
55038	31478	45.892619000000003	45.930410999999999	54.530990000000003	54.507880999999998	Советская	0103000020E61000000100000005000000E564E25641F2464040A19E3E02414B40E564E25641F246406440F67AF7434B40596B28B517F746406440F67AF7434B40596B28B517F7464040A19E3E02414B40E564E25641F2464040A19E3E02414B40
54796	48578	45.820214999999997	45.843516999999999	54.775843999999999	54.763077000000003	Центральная	0103000020E6100000010000000500000025581CCEFCE8464037AAD381AC614B4025581CCEFCE846401F662FDB4E634B405D4F745DF8EB46401F662FDB4E634B405D4F745DF8EB464037AAD381AC614B4025581CCEFCE8464037AAD381AC614B40
54722	31157	45.926071999999998	45.961179000000001	54.720106000000001	54.702421999999999	М.Горького	0103000020E61000000100000005000000E3DEFC8689F64640D6FECEF6E8594B40E3DEFC8689F64640A2D3F36E2C5C4B400E4DD9E907FB4640A2D3F36E2C5C4B400E4DD9E907FB4640D6FECEF6E8594B40E3DEFC8689F64640D6FECEF6E8594B40
54812	56570	45.735944000000003	45.756425999999998	54.711868000000003	54.700907999999998	Первомайская	0103000020E61000000100000005000000FED7B96933DE46409CC0745AB7594B40FED7B96933DE4640D388997D1E5B4B400BEC3191D2E04640D388997D1E5B4B400BEC3191D2E046409CC0745AB7594B40FED7B96933DE46409CC0745AB7594B40
54799	31396	45.851108000000004	45.880070000000003	54.685735000000001	54.663936999999997	Центральная	0103000020E6100000010000000500000097AE601BF1EC46405BCD3AE3FB544B4097AE601BF1EC46407D5C1B2AC6574B406A183E22A6F046407D5C1B2AC6574B406A183E22A6F046405BCD3AE3FB544B4097AE601BF1EC46405BCD3AE3FB544B40
54712	18136	46.434348	46.470829000000002	54.576407000000003	54.562747999999999	Октябрьская	0103000020E61000000100000005000000A08A1BB798374740D8F15F2008484B40A08A1BB798374740BE175FB4C7494B401381EA1F443C4740BE175FB4C7494B401381EA1F443C4740D8F15F2008484B40A08A1BB798374740D8F15F2008484B40
54723	31601	46.285794000000003	46.314979999999998	54.598882000000003	54.572507999999999	Новая	0103000020E610000001000000050000004FB2D5E594244740645930F147494B404FB2D5E594244740E014562AA84C4B407172BF4351284740E014562AA84C4B407172BF4351284740645930F147494B404FB2D5E594244740645930F147494B40
54644	3548	45.71116	45.750506000000001	54.657088999999999	54.631191000000001	Пушкина	0103000020E61000000100000005000000971C774A07DB4640C843DFDDCA504B40971C774A07DB4640DAC70A7E1B544B40D4B9A29410E04640DAC70A7E1B544B40D4B9A29410E04640C843DFDDCA504B40971C774A07DB4640C843DFDDCA504B40
54824	1587	46.161180000000002	46.198279999999997	54.560549999999999	54.541511	Центральная	0103000020E610000001000000050000007862D68BA11447404EB6813B50454B407862D68BA1144740EBE2361AC0474B40B6B9313D61194740EBE2361AC0474B40B6B9313D611947404EB6813B50454B407862D68BA11447404EB6813B50454B40
54894	56573	45.834282999999999	45.851179999999999	54.788060999999999	54.774222999999999	Центральная	0103000020E61000000100000005000000EC4D0CC9C9EA4640CF6740BD19634B40EC4D0CC9C9EA46406420CF2EDF644B4030815B77F3EC46406420CF2EDF644B4030815B77F3EC4640CF6740BD19634B40EC4D0CC9C9EA4640CF6740BD19634B40
54793	30989	46.340994999999999	46.382812000000001	54.661301999999999	54.636887000000002	Комсомольская	0103000020E61000000100000005000000BD8C62B9A52B4740B01F628385514B40BD8C62B9A52B4740C3633F8BA5544B401842CEFBFF304740C3633F8BA5544B401842CEFBFF304740B01F628385514B40BD8C62B9A52B4740B01F628385514B40
54791	30792	45.940373999999998	45.982154000000001	54.621955	54.596932000000002	Куйбышева	0103000020E610000001000000050000001D01DC2C5EF84640CBF78C44684C4B401D01DC2C5EF84640B64AB0389C4F4B405BD1E638B7FD4640B64AB0389C4F4B405BD1E638B7FD4640CBF78C44684C4B401D01DC2C5EF84640CBF78C44684C4B40
54550	30709	45.971249	46.013263000000002	54.574601000000001	54.553418000000001	Молодежная	0103000020E61000000100000005000000E8A221E351FC46404582A966D6464B40E8A221E351FC4640DC9F8B868C494B40999F1B9AB2014740DC9F8B868C494B40999F1B9AB20147404582A966D6464B40E8A221E351FC46404582A966D6464B40
54600	30559	46.118634999999998	46.154145999999997	54.583826999999999	54.566009999999999	Ленина	0103000020E610000001000000050000009A94826E2F0F4740BF9A030473484B409A94826E2F0F4740CAC2D7D7BA4A4B4094675E0EBB134740CAC2D7D7BA4A4B4094675E0EBB134740BF9A030473484B409A94826E2F0F4740BF9A030473484B40
54974	30865	45.858142000000001	45.878911000000002	54.600833000000002	54.587719	Ленина	0103000020E610000001000000050000007AA9D898D7ED4640711E4E603A4B4B407AA9D898D7ED4640C5AD8218E84C4B401E8CD82780F04640C5AD8218E84C4B401E8CD82780F04640711E4E603A4B4B407AA9D898D7ED4640711E4E603A4B4B40
54420	1137	46.04889	46.146518999999998	54.605432999999998	54.551412999999997	Центральная	0103000020E61000000100000005000000FC8C0B07420647406CCB80B394464B40FC8C0B0742064740A7751BD47E4D4B400E9F7422C1124740A7751BD47E4D4B400E9F7422C11247406CCB80B394464B40FC8C0B07420647406CCB80B394464B40
54435	1137	46.04889	46.146518999999998	54.605432999999998	54.551412999999997	Советский переулок	0103000020E61000000100000005000000FC8C0B07420647406CCB80B394464B40FC8C0B0742064740A7751BD47E4D4B400E9F7422C1124740A7751BD47E4D4B400E9F7422C11247406CCB80B394464B40FC8C0B07420647406CCB80B394464B40
54417	1137	46.04889	46.146518999999998	54.605432999999998	54.551412999999997	Микрорайон-2	0103000020E61000000100000005000000FC8C0B07420647406CCB80B394464B40FC8C0B0742064740A7751BD47E4D4B400E9F7422C1124740A7751BD47E4D4B400E9F7422C11247406CCB80B394464B40FC8C0B07420647406CCB80B394464B40
54668	1137	46.04889	46.146518999999998	54.605432999999998	54.551412999999997	Большевистская	0103000020E61000000100000005000000FC8C0B07420647406CCB80B394464B40FC8C0B0742064740A7751BD47E4D4B400E9F7422C1124740A7751BD47E4D4B400E9F7422C11247406CCB80B394464B40FC8C0B07420647406CCB80B394464B40
54794	56569	45.978920000000002	46.007936000000001	54.661833999999999	54.648375000000001	Ленина	0103000020E610000001000000050000003EB324404DFD4640A245B6F3FD524B403EB324404DFD4640C0B0FCF9B6544B40043BFE0B04014740C0B0FCF9B6544B40043BFE0B04014740A245B6F3FD524B403EB324404DFD4640A245B6F3FD524B40
54628	30604	46.408495000000002	46.481025000000002	54.650770999999999	54.613571999999998	Школьная	0103000020E610000001000000050000002ECA6C9049344740E3DEFC86894E4B402ECA6C9049344740B517D1764C534B407AC7293A923D4740B517D1764C534B407AC7293A923D4740E3DEFC86894E4B402ECA6C9049344740E3DEFC86894E4B40
55080	56601	46.209750999999997	46.239755000000002	54.645468000000001	54.625332999999998	Новая	0103000020E61000000100000005000000D2A6EA1ED91A4740060E68E90A504B40D2A6EA1ED91A4740A94E07B29E524B40B806B64AB01E4740A94E07B29E524B40B806B64AB01E4740060E68E90A504B40D2A6EA1ED91A4740060E68E90A504B40
55074	56599	43.356153999999997	43.386203000000002	54.243383000000001	54.230817000000002	Центральная	0103000020E61000000100000005000000772B4B7496AD4540302E55698B1D4B40772B4B7496AD454081B3942C271F4B40FD4E93196FB1454081B3942C271F4B40FD4E93196FB14540302E55698B1D4B40772B4B7496AD4540302E55698B1D4B40
54717	47948	43.136606	43.160240999999999	54.318503999999997	54.299083000000003	Центральная	0103000020E61000000100000005000000FC372F4E7C91454011E50B5A48264B40FC372F4E7C91454095D233BDC4284B403A3DEFC68294454095D233BDC4284B403A3DEFC68294454011E50B5A48264B40FC372F4E7C91454011E50B5A48264B40
55004	56584	43.436194	43.464706999999997	54.233047999999997	54.221021	Центральная	0103000020E61000000100000005000000105B7A34D5B74540575D876A4A1C4B40105B7A34D5B74540F8325184D41D4B40739CDB847BBB4540F8325184D41D4B40739CDB847BBB4540575D876A4A1C4B40105B7A34D5B74540575D876A4A1C4B40
54781	46193	43.184584999999998	43.261454000000001	54.458578000000003	54.375329000000001	Школьная	0103000020E61000000100000005000000842A357BA0974540C51EDAC70A304B40842A357BA0974540225514AFB23A4B4046B41D5377A14540225514AFB23A4B4046B41D5377A14540C51EDAC70A304B40842A357BA0974540C51EDAC70A304B40
54976	29674	43.332726000000001	43.341970000000003	54.346632999999997	54.339982999999997	Мелиораторов	0103000020E61000000100000005000000B343FCC396AA454015191D90842B4B40B343FCC396AA4540705B5B785E2C4B40481B47ACC5AB4540705B5B785E2C4B40481B47ACC5AB454015191D90842B4B40B343FCC396AA454015191D90842B4B40
54675	26468	43.210177999999999	43.233291999999999	54.423073000000002	54.408351000000003	Школьная	0103000020E610000001000000050000005A2BDA1CE79A4540FB2477D844344B405A2BDA1CE79A45400A698D4127364B408F352383DC9D45400A698D4127364B408F352383DC9D4540FB2477D844344B405A2BDA1CE79A4540FB2477D844344B40
54825	48089	43.454520000000002	43.477533999999999	54.315342000000001	54.303669999999997	Заречная	0103000020E6100000010000000500000060B01BB62DBA45405E6397A8DE264B4060B01BB62DBA454012876C205D284B40315D88D51FBD454012876C205D284B40315D88D51FBD45405E6397A8DE264B4060B01BB62DBA45405E6397A8DE264B40
54907	30276	43.320490999999997	43.338079999999998	54.407868999999998	54.390996999999999	 Школьная	0103000020E61000000100000005000000C7D45DD905A94540C4EA8F300C324B40C7D45DD905A94540AF06280D35344B4041B7973446AB4540AF06280D35344B4041B7973446AB4540C4EA8F300C324B40C7D45DD905A94540C4EA8F300C324B40
80936	62027	43.361714999999997	43.391593	54.413150000000002	54.401862999999999	Новая	0103000020E610000001000000050000007FBC57AD4CAE4540793C2D3F70334B407FBC57AD4CAE4540D42B6519E2344B40D82B2CB81FB24540D42B6519E2344B40D82B2CB81FB24540793C2D3F70334B407FBC57AD4CAE4540793C2D3F70334B40
54687	30187	43.302965	43.320256999999998	54.464711999999999	54.454914000000002	Центральная	0103000020E61000000100000005000000946A9F8EC7A645400C3F389F3A3A4B40946A9F8EC7A645408507CDAE7B3B4B4054A86E2EFEA845408507CDAE7B3B4B4054A86E2EFEA845400C3F389F3A3A4B40946A9F8EC7A645400C3F389F3A3A4B40
54702	30117	43.429887999999998	43.454177999999999	54.33634	54.314973999999999	Центральная	0103000020E61000000100000005000000AF78EA9106B745408F8B6A1151284B40AF78EA9106B74540172B6A300D2B4B400648348122BA4540172B6A300D2B4B400648348122BA45408F8B6A1151284B40AF78EA9106B745408F8B6A1151284B40
55056	29422	43.270463999999997	43.303719000000001	54.438177000000003	54.427714000000002	Лесная	0103000020E61000000100000005000000675F79909EA245404B051555BF364B40675F79909EA24540016E162F16384B404016A243E0A64540016E162F16384B404016A243E0A645404B051555BF364B40675F79909EA245404B051555BF364B40
54918	30068	43.173509000000003	43.224946000000003	54.383735000000001	54.371285999999998	Нижняя	0103000020E61000000100000005000000E547FC8A3596454038BBB54C862F4B40E547FC8A3596454050AA7D3A1E314B40DAAED007CB9C454050AA7D3A1E314B40DAAED007CB9C454038BBB54C862F4B40E547FC8A3596454038BBB54C862F4B40
79737	61822	43.303485999999999	43.325620000000001	54.291773999999997	54.277073000000001	Молодежная	0103000020E610000001000000050000009D6516A1D8A6454064CDC82077234B409D6516A1D8A645405BE9B5D958254B40367689EAADA945405BE9B5D958254B40367689EAADA9454064CDC82077234B409D6516A1D8A6454064CDC82077234B40
55065	30369	43.381936000000003	43.403117999999999	54.351576000000001	54.338261000000003	Школьная	0103000020E6100000010000000500000021956247E3B045409241EE224C2B4B4021956247E3B045407D073F71002D4B40E736E15E99B345407D073F71002D4B40E736E15E99B345409241EE224C2B4B4021956247E3B045409241EE224C2B4B40
54790	29971	43.262352	43.310789	54.236716000000001	54.220753000000002	Центральная	0103000020E61000000100000005000000250516C094A1454038BF61A2411C4B40250516C094A145405038BBB54C1E4B40707A17EFC7A745405038BBB54C1E4B40707A17EFC7A7454038BF61A2411C4B40250516C094A1454038BF61A2411C4B40
54721	29909	43.481245000000001	43.496578999999997	54.263438999999998	54.247627999999999	Центральная	0103000020E61000000100000005000000882EA86F99BD454075C93846B21F4B40882EA86F99BD4540D7BE805EB8214B40B07092E68FBF4540D7BE805EB8214B40B07092E68FBF454075C93846B21F4B40882EA86F99BD454075C93846B21F4B40
79738	61823	43.258147999999998	43.277245999999998	54.495229000000002	54.480324000000003	Школьная	0103000020E610000001000000050000008FC360FE0AA14540F1BDBF417B3D4B408FC360FE0AA14540F183F3A9633F4B40317903CC7CA34540F183F3A9633F4B40317903CC7CA34540F1BDBF417B3D4B408FC360FE0AA14540F1BDBF417B3D4B40
79741	61823	43.258147999999998	43.277245999999998	54.495229000000002	54.480324000000003	Молодежная	0103000020E610000001000000050000008FC360FE0AA14540F1BDBF417B3D4B408FC360FE0AA14540F183F3A9633F4B40317903CC7CA34540F183F3A9633F4B40317903CC7CA34540F1BDBF417B3D4B408FC360FE0AA14540F1BDBF417B3D4B40
54333	29552	43.312595000000002	43.359568000000003	54.338366000000001	54.309432999999999	Школьная	0103000020E6100000010000000500000052F2EA1C03A84540CEA623809B274B4052F2EA1C03A84540070ABC934F2B4B401558005306AE4540070ABC934F2B4B401558005306AE4540CEA623809B274B4052F2EA1C03A84540CEA623809B274B40
54335	29552	43.312595000000002	43.359568000000003	54.338366000000001	54.309432999999999	Центральная	0103000020E6100000010000000500000052F2EA1C03A84540CEA623809B274B4052F2EA1C03A84540070ABC934F2B4B401558005306AE4540070ABC934F2B4B401558005306AE4540CEA623809B274B4052F2EA1C03A84540CEA623809B274B40
54405	29552	43.312595000000002	43.359568000000003	54.338366000000001	54.309432999999999	Ленина	0103000020E6100000010000000500000052F2EA1C03A84540CEA623809B274B4052F2EA1C03A84540070ABC934F2B4B401558005306AE4540070ABC934F2B4B401558005306AE4540CEA623809B274B4052F2EA1C03A84540CEA623809B274B40
54719	47931	43.130766999999999	43.142085999999999	54.343981999999997	54.331750999999997	Школьная	0103000020E61000000100000005000000B1321AF9BC90454028B517D1762A4B40B1321AF9BC904540D234289A072C4B40179CC1DF2F924540D234289A072C4B40179CC1DF2F92454028B517D1762A4B40B1321AF9BC90454028B517D1762A4B40
54564	29513	46.275202999999998	46.308719000000004	54.728810000000003	54.702452999999998	Полевая	0103000020E610000001000000050000006B6116DA3923474011FDDAFAE9594B406B6116DA39234740B77F65A5495D4B40B153AC1A84274740B77F65A5495D4B40B153AC1A8427474011FDDAFAE9594B406B6116DA3923474011FDDAFAE9594B40
54603	29418	46.248576999999997	46.279370999999998	55.039785000000002	55.01979	Ленина	0103000020E61000000100000005000000D6C4025FD11F4740D8648D7A88824B40D6C4025FD11F474089EFC4AC17854B40B439CE6DC223474089EFC4AC17854B40B439CE6DC2234740D8648D7A88824B40D6C4025FD11F4740D8648D7A88824B40
54971	29320	46.185102000000001	46.205897999999998	54.816909000000003	54.802007000000003	Центральная	0103000020E610000001000000050000004C361E6CB1174740E014562AA8664B404C361E6CB11747406F675F7990684B40E9279CDD5A1A47406F675F7990684B40E9279CDD5A1A4740E014562AA8664B404C361E6CB1174740E014562AA8664B40
54602	56535	46.286242999999999	46.356670999999999	54.854610000000001	54.827874000000001	Ленинская	0103000020E61000000100000005000000BEDA519CA3244740B79A75C6F7694B40BEDA519CA3244740D36A48DC636D4B403F373465A72D4740D36A48DC636D4B403F373465A72D4740B79A75C6F7694B40BEDA519CA3244740B79A75C6F7694B40
54454	56535	46.286242999999999	46.356670999999999	54.854610000000001	54.827874000000001	Заводская	0103000020E61000000100000005000000BEDA519CA3244740B79A75C6F7694B40BEDA519CA3244740D36A48DC636D4B403F373465A72D4740D36A48DC636D4B403F373465A72D4740B79A75C6F7694B40BEDA519CA3244740B79A75C6F7694B40
54433	56535	46.286242999999999	46.356670999999999	54.854610000000001	54.827874000000001	Заводская	0103000020E61000000100000005000000BEDA519CA3244740B79A75C6F7694B40BEDA519CA3244740D36A48DC636D4B403F373465A72D4740D36A48DC636D4B403F373465A72D4740B79A75C6F7694B40BEDA519CA3244740B79A75C6F7694B40
54972	29266	46.194884000000002	46.217377999999997	55.005536999999997	54.985762000000001	Советская	0103000020E61000000100000005000000C0417BF5F1184740DDD1FF722D7E4B40C0417BF5F11847407FF5B86FB5804B40586FD40AD31B47407FF5B86FB5804B40586FD40AD31B4740DDD1FF722D7E4B40C0417BF5F1184740DDD1FF722D7E4B40
54713	28827	45.892097999999997	45.918886000000001	54.806230999999997	54.792721999999998	 Набережная	0103000020E61000000100000005000000DB696B4430F24640EC681CEA77654B40DB696B4430F24640BC02D19332674B404A60730E9EF54640BC02D19332674B404A60730E9EF54640EC681CEA77654B40DB696B4430F24640EC681CEA77654B40
54718	29208	45.932253000000003	45.960648999999997	54.981329000000002	54.970658999999998	Центральная	0103000020E61000000100000005000000884CF91054F74640B648DA8D3E7C4B40884CF91054F74640E6CE4C309C7D4B40B1F7E28BF6FA4640E6CE4C309C7D4B40B1F7E28BF6FA4640B648DA8D3E7C4B40884CF91054F74640B648DA8D3E7C4B40
54970	29178	46.022641	46.035091999999999	54.989733999999999	54.979320000000001	Садовая	0103000020E610000001000000050000003D4679E6E5024740CC28965B5A7D4B403D4679E6E5024740A0DE8C9AAF7E4B40F52C08E57D044740A0DE8C9AAF7E4B40F52C08E57D044740CC28965B5A7D4B403D4679E6E5024740CC28965B5A7D4B40
54551	29111	46.158906999999999	46.183681999999997	54.829611	54.796314000000002	Гагарина	0103000020E61000000100000005000000800D88105714474069ACFD9DED654B40800D88105714474070B378B1306A4B40936E4BE48217474070B378B1306A4B40936E4BE48217474069ACFD9DED654B40800D88105714474069ACFD9DED654B40
54915	28467	46.135452000000001	46.177878999999997	54.778044999999999	54.751502000000002	Церковная	0103000020E61000000100000005000000C216BB7D561147407670B03731604B40C216BB7D561147407DE882FA96634B4095D233BDC41647407DE882FA96634B4095D233BDC41647407670B03731604B40C216BB7D561147407670B03731604B40
54715	29042	46.297265000000003	46.318339999999999	54.664848999999997	54.644181000000003	Молодежная	0103000020E610000001000000050000006B9F8EC70C26474030DAE38574524B406B9F8EC70C2647409FE3A3C519554B401B81785DBF2847409FE3A3C519554B401B81785DBF28474030DAE38574524B406B9F8EC70C26474030DAE38574524B40
54626	29019	46.199860999999999	46.230269	54.914974000000001	54.883944	Юбилейная	0103000020E61000000100000005000000785F950B951947406ABFB51325714B40785F950B951947405C5837DE1D754B402D246074791D47405C5837DE1D754B402D246074791D47406ABFB51325714B40785F950B951947406ABFB51325714B40
54627	28982	46.292019000000003	46.322966000000001	54.765804000000003	54.750453	Центральная	0103000020E61000000100000005000000C367EBE060254740B1170AD80E604B40C367EBE060254740B0928FDD05624B4027DC2BF356294740B0928FDD05624B4027DC2BF356294740B1170AD80E604B40C367EBE060254740B1170AD80E604B40
54714	28915	45.984453999999999	46.007638999999998	54.960354000000002	54.932338000000001	Центральная	0103000020E610000001000000050000004C35B39602FE4640B66801DA56774B404C35B39602FE4640994A3FE1EC7A4B404A969350FA004740994A3FE1EC7A4B404A969350FA004740B66801DA56774B404C35B39602FE4640B66801DA56774B40
54786	28882	45.984453999999999	46.007638999999998	54.960354000000002	54.932338000000001	Центральная	0103000020E610000001000000050000004C35B39602FE4640B66801DA56774B404C35B39602FE4640994A3FE1EC7A4B404A969350FA004740994A3FE1EC7A4B404A969350FA004740B66801DA56774B404C35B39602FE4640B66801DA56774B40
54783	28573	46.114125999999999	46.142324000000002	55.022948999999997	55.000518	Речная	0103000020E61000000100000005000000C8CF46AE9B0E474098874CF910804B40C8CF46AE9B0E4740EA3C2AFEEF824B40CCB73EAC37124740EA3C2AFEEF824B40CCB73EAC3712474098874CF910804B40C8CF46AE9B0E474098874CF910804B40
54720	56561	45.793176000000003	45.823647000000001	54.827106000000001	54.803553999999998	Карла Маркса	0103000020E610000001000000050000006EFC89CA86E54640F54883DBDA664B406EFC89CA86E54640A629029CDE694B406939D0436DE94640A629029CDE694B406939D0436DE94640F54883DBDA664B406EFC89CA86E54640F54883DBDA664B40
54784	28724	45.937058999999998	45.971015000000001	54.799017999999997	54.780864999999999	Центральная	0103000020E6100000010000000500000013B69F8CF1F74640A7CB6262F3634B4013B69F8CF1F746402975C93846664B40757632384AFC46402975C93846664B40757632384AFC4640A7CB6262F3634B4013B69F8CF1F74640A7CB6262F3634B40
54788	28665	46.016784000000001	46.028570000000002	54.828927	54.816540000000003	Заводская	0103000020E610000001000000050000004C8C65FA250247401CF0F96184684B404C8C65FA25024740BDE2A9471A6A4B40C8D2872EA8034740BDE2A9471A6A4B40C8D2872EA80347401CF0F96184684B404C8C65FA250247401CF0F96184684B40
54520	28633	46.366084999999998	46.423594999999999	54.739103	54.723860000000002	Полевая	0103000020E6100000010000000500000030478FDFDB2E4740F870C971A75C4B4030478FDFDB2E474010B056ED9A5E4B40E3DF675C3836474010B056ED9A5E4B40E3DF675C38364740F870C971A75C4B4030478FDFDB2E4740F870C971A75C4B40
54780	28487	46.129828000000003	46.149707999999997	54.967311000000002	54.948979999999999	Центральная	0103000020E61000000100000005000000740D33349E1047406F47382D78794B40740D33349E104740D107CBD8D07B4B408BF9B9A129134740D107CBD8D07B4B408BF9B9A1291347406F47382D78794B40740D33349E1047406F47382D78794B40
54969	28362	46.094659	46.130924	54.751610999999997	54.728445999999998	Ларина	0103000020E61000000100000005000000D3A23EC91D0C47407573F1B73D5D4B40D3A23EC91D0C47402C280CCA34604B4079211D1EC21047402C280CCA34604B4079211D1EC21047407573F1B73D5D4B40D3A23EC91D0C47407573F1B73D5D4B40
54877	28274	46.328158000000002	46.346035000000001	54.706978999999997	54.692405999999998	Одыре	0103000020E61000000100000005000000DCF5D214012A4740EFC682C2A0584B40DCF5D214012A4740B9FAB1497E5A4B40BC22F8DF4A2C4740B9FAB1497E5A4B40BC22F8DF4A2C4740EFC682C2A0584B40DCF5D214012A4740EFC682C2A0584B40
55037	28234	46.018222000000002	46.051045999999999	54.789586999999997	54.773449999999997	Овражная	0103000020E61000000100000005000000AB08371955024740AC8BDB6800634B40AB08371955024740622CD32F11654B40BA4BE2AC88064740622CD32F11654B40BA4BE2AC88064740AC8BDB6800634B40AB08371955024740AC8BDB6800634B40
54699	28170	46.235433999999998	46.257730000000002	54.726610999999998	54.712398999999998	Колхозная	0103000020E61000000100000005000000E82E89B3221E4740FF59F3E32F5B4B40E82E89B3221E4740F9F4D896015D4B405B99F04BFD204740F9F4D896015D4B405B99F04BFD204740FF59F3E32F5B4B40E82E89B3221E4740FF59F3E32F5B4B40
54681	28147	46.207712000000001	46.233834999999999	55.038789999999999	55.026566000000003	Верхняя	0103000020E610000001000000050000004E7E8B4E961A4740C097C28366834B404E7E8B4E961A4740B7B41A12F7844B4080D4264EEE1D4740B7B41A12F7844B4080D4264EEE1D4740C097C28366834B404E7E8B4E961A4740C097C28366834B40
54782	28547	46.075516	46.106929999999998	54.955975000000002	54.941591000000003	Газовиков	0103000020E6100000010000000500000091291F82AA0947409E9ACB0D86784B4091291F82AA094740956588635D7A4B400B7BDAE1AF0D4740956588635D7A4B400B7BDAE1AF0D47409E9ACB0D86784B4091291F82AA0947409E9ACB0D86784B40
54785	29137	46.096814999999999	46.127259000000002	54.853822000000001	54.838166999999999	Ленинская	0103000020E610000001000000050000009161156F640C474010CB660E496B4B409161156F640C47407B4D0F0A4A6D4B40938FDD054A1047407B4D0F0A4A6D4B40938FDD054A10474010CB660E496B4B409161156F640C474010CB660E496B4B40
54914	28400	46.062922	46.088541999999997	54.761482999999998	54.742507000000003	Центральная	0103000020E610000001000000050000007619FED30D0847408A0629780A5F4B407619FED30D084740E0BA624678614B4045292158550B4740E0BA624678614B4045292158550B47408A0629780A5F4B407619FED30D0847408A0629780A5F4B40
54404	28087	46.352027	46.385956	54.850282	54.82	Советская	0103000020E610000001000000050000008D2782380F2D4740295C8FC2F5684B408D2782380F2D47405130630AD66C4B40F5D89601673147405130630AD66C4B40F5D8960167314740295C8FC2F5684B408D2782380F2D4740295C8FC2F5684B40
54677	56555	46.252951000000003	46.278419	54.777287000000001	54.754151999999998	Центральная	0103000020E61000000100000005000000C93EC8B260204740431B800D88604B40C93EC8B260204740904DF2237E634B40E2CAD93BA3234740904DF2237E634B40E2CAD93BA3234740431B800D88604B40C93EC8B260204740431B800D88604B40
54450	32696	46.219982999999999	46.258817000000001	54.867097999999999	54.821078999999997	Полевая	0103000020E6100000010000000500000086562767281C47405837DE1D19694B4086562767281C4740A8363811FD6E4B400D535BEA20214740A8363811FD6E4B400D535BEA202147405837DE1D19694B4086562767281C47405837DE1D19694B40
54511	32696	46.219982999999999	46.258817000000001	54.867097999999999	54.821078999999997	Луначарского	0103000020E6100000010000000500000086562767281C47405837DE1D19694B4086562767281C4740A8363811FD6E4B400D535BEA20214740A8363811FD6E4B400D535BEA202147405837DE1D19694B4086562767281C47405837DE1D19694B40
81155	32696	46.219982999999999	46.258817000000001	54.867097999999999	54.821078999999997	Л.Толстого	0103000020E6100000010000000500000086562767281C47405837DE1D19694B4086562767281C4740A8363811FD6E4B400D535BEA20214740A8363811FD6E4B400D535BEA202147405837DE1D19694B4086562767281C47405837DE1D19694B40
38834	32696	46.219982999999999	46.258817000000001	54.867097999999999	54.821078999999997	Карла Маркса	0103000020E6100000010000000500000086562767281C47405837DE1D19694B4086562767281C4740A8363811FD6E4B400D535BEA20214740A8363811FD6E4B400D535BEA202147405837DE1D19694B4086562767281C47405837DE1D19694B40
54529	28303	46.382658999999997	46.403464	54.704918999999997	54.692765000000001	Первомайская	0103000020E61000000100000005000000914259F8FA3047401F680586AC584B40914259F8FA3047401DAA29C93A5A4B40828E56B5A43347401DAA29C93A5A4B40828E56B5A43347401F680586AC584B40914259F8FA3047401F680586AC584B40
54965	28303	46.382658999999997	46.403464	54.704918999999997	54.692765000000001	Колхозная	0103000020E61000000100000005000000914259F8FA3047401F680586AC584B40914259F8FA3047401DAA29C93A5A4B40828E56B5A43347401DAA29C93A5A4B40828E56B5A43347401F680586AC584B40914259F8FA3047401F680586AC584B40
62235	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	бульвар Космонавтов	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
63189	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Юбилейная	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62949	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Чернышевского	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62183	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Советская	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62266	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Свободы	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
63091	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Свердлова	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62268	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Промышленная	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62981	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Комсомольская	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62234	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Квартал маслозавода	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
63034	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	Гагарина	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62305	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	8 Марта	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62265	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	3-ий микрорайон	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62155	7823	46.524925000000003	46.593476000000003	56.346331999999997	56.317596999999999	2-ой микрорайон	0103000020E6100000010000000500000029ED0DBE304347406327BC04A7284C4029ED0DBE3043474075C7629B542C4C40FF7A8505F74B474075C7629B542C4C40FF7A8505F74B47406327BC04A7284C4029ED0DBE304347406327BC04A7284C40
62162	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	проспект Гагарина	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62159	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	площадь Ленина	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62250	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	переулок Голикова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62298	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	пер.Голикова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62249	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	бульвар Эшкинина	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62166	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	бульвар Чавайна	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62224	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Я.Эшпая	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62175	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Школьная	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62297	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Успенская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62227	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Строителей	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62299	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Сомбатхей	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62246	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Соловьева	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62228	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Советская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
63030	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Пушкина	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62176	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Прохорова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62225	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Пролетарская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62301	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Подольских курсантов	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62164	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Петрова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62169	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Первомайская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62163	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Панфилова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62170	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Осипенко	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62161	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Орая	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62222	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Мичурина	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62168	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Мира	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62167	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Медицинская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62174	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Машиностроителей	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62256	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Лобачевского	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62165	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Ленинский проспект	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
63018	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Крылова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62172	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Кремлевская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62260	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Краснофлотская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62226	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Красноармейская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62217	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Комсомольская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62252	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Кирпичная	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62259	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	К.Либкнехта	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62254	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Йывана Кырли	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62171	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Интернатская	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62291	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Зеленая	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62253	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Звездная	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62255	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Зарубина	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62257	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Дружбы	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62258	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Димитрова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62150	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Героев Сталинградской Битвы	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62247	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Волкова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62221	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Воинов-Интернационалистов	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62218	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Водопроводная	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62302	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Баумана	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62173	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	Анциферова	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62251	1218	47.827123	47.921903999999998	56.666265000000003	56.606475000000003	8 Марта	0103000020E610000001000000050000007C629D2ADFE94740BA6B09F9A04D4C407C629D2ADFE9474017BCE82B48554C409A0645F300F6474017BCE82B48554C409A0645F300F64740BA6B09F9A04D4C407C629D2ADFE94740BA6B09F9A04D4C40
62307	57932	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	Школьная	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
62277	57932	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	Чехова	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
62958	57932	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	Пушкина	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
62988	57932	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	Ленина	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
62306	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Юбилейная	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62303	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Щорса	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62181	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Щербакова	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62237	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Шестакова	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62272	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Учительская	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62179	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Советская	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62240	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Прохорова	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62945	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Помарское шоссе	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62304	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Маяковского	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62182	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Либкнехта	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62229	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Ленина	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62177	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Кошкина	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62178	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Коммунистическая	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62239	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Комарова	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62261	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Кирова	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62152	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Дружбы	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62180	6770	48.307560000000002	48.408585000000002	55.892843999999997	55.844344	Гагарина	0103000020E6100000010000000500000065C746205E2748407349D57613EC4B4065C746205E274840043752B648F24B406E5166834C344840043752B648F24B406E5166834C3448407349D57613EC4B4065C746205E2748407349D57613EC4B40
62264	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	Гаврилова	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62233	6770	48.390250000000002	48.410516000000001	55.865192	55.84395	107 бригады	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
63137	26701	46.195675000000001	46.225453999999999	56.525261	56.503548000000002	Юркинская	0103000020E6100000010000000500000089D2DEE00B194740ADFBC74274404C4089D2DEE00B194740A06EA0C03B434C404E603AADDB1C4740A06EA0C03B434C404E603AADDB1C4740ADFBC74274404C4089D2DEE00B194740ADFBC74274404C40
63138	26701	46.195675000000001	46.225453999999999	56.525261	56.503548000000002	Новая Стройка	0103000020E6100000010000000500000089D2DEE00B194740ADFBC74274404C4089D2DEE00B194740A06EA0C03B434C404E603AADDB1C4740A06EA0C03B434C404E603AADDB1C4740ADFBC74274404C4089D2DEE00B194740ADFBC74274404C40
62209	26130	46.252377000000003	46.321843000000001	56.305619	56.283259999999999	переулок Володарского	0103000020E610000001000000050000009DA1B8E34D204740EA211ADD41244C409DA1B8E34D204740A304FD851E274C4028B9C32632294740A304FD851E274C4028B9C32632294740EA211ADD41244C409DA1B8E34D204740EA211ADD41244C40
62216	26130	46.252377000000003	46.321843000000001	56.305619	56.283259999999999	Центральный проспект	0103000020E610000001000000050000009DA1B8E34D204740EA211ADD41244C409DA1B8E34D204740A304FD851E274C4028B9C32632294740A304FD851E274C4028B9C32632294740EA211ADD41244C409DA1B8E34D204740EA211ADD41244C40
63025	26130	46.252377000000003	46.321843000000001	56.305619	56.283259999999999	Советская	0103000020E610000001000000050000009DA1B8E34D204740EA211ADD41244C409DA1B8E34D204740A304FD851E274C4028B9C32632294740A304FD851E274C4028B9C32632294740EA211ADD41244C409DA1B8E34D204740EA211ADD41244C40
63212	26300	46.273091999999998	46.292800999999997	56.341332999999999	56.325155000000002	Лесная	0103000020E610000001000000050000004D66BCADF4224740C190D5AD9E294C404D66BCADF4224740D505BCCCB02B4C40389ECF807A254740D505BCCCB02B4C40389ECF807A254740C190D5AD9E294C404D66BCADF4224740C190D5AD9E294C40
63187	26463	46.093499999999999	46.139071999999999	56.282775000000001	56.273260000000001	Починок	0103000020E610000001000000050000008716D9CEF70B474009A7052FFA224C408716D9CEF70B47402E90A0F831244C4008E57D1CCD1147402E90A0F831244C4008E57D1CCD11474009A7052FFA224C408716D9CEF70B474009A7052FFA224C40
63059	26601	46.000084999999999	46.023736999999997	56.580689	56.547511999999998	Школьная	0103000020E610000001000000050000002E1C08C90200474072158BDF14464C402E1C08C902004740CF126404544A4C40425A63D009034740CF126404544A4C40425A63D00903474072158BDF14464C402E1C08C90200474072158BDF14464C40
63094	26610	46.019848000000003	46.050741000000002	56.529738999999999	56.517952000000001	Школьная	0103000020E610000001000000050000000D7217618A024740EB724A404C424C400D7217618A0247403735D07CCE434C407EC85BAE7E0647403735D07CCE434C407EC85BAE7E064740EB724A404C424C400D7217618A024740EB724A404C424C40
63215	26553	45.912076999999996	45.943823000000002	56.724904000000002	56.692526999999998	Железнодорожная	0103000020E6100000010000000500000086376BF0BEF446406A4C88B9A4584C4086376BF0BEF44640AB5E7EA7C95C4C40371B2B31CFF84640AB5E7EA7C95C4C40371B2B31CFF846406A4C88B9A4584C4086376BF0BEF446406A4C88B9A4584C40
63084	58060	46.146833000000001	46.176873000000001	56.283205000000002	56.275328999999999	Горный Шимец	0103000020E610000001000000050000009E7C7A6CCB124740F8510DFB3D234C409E7C7A6CCB1247402788BA0F40244C40D04543C6A31647402788BA0F40244C40D04543C6A3164740F8510DFB3D234C409E7C7A6CCB124740F8510DFB3D234C40
63134	26329	45.791442000000004	45.825578	56.530239999999999	56.507109	Школьная	0103000020E610000001000000050000002657B1F84DE54640EE409DF2E8404C402657B1F84DE54640F98381E7DE434C400726378AACE94640F98381E7DE434C400726378AACE94640EE409DF2E8404C402657B1F84DE54640EE409DF2E8404C40
63060	26246	46.261637999999998	46.305520999999999	56.310637	56.293351999999999	Центральная	0103000020E6100000010000000500000007B29E5A7D214740AC1BEF8E8C254C4007B29E5A7D214740BAF605F4C2274C40E09EE74F1B274740BAF605F4C2274C40E09EE74F1B274740AC1BEF8E8C254C4007B29E5A7D214740AC1BEF8E8C254C40
63434	58086	48.129998999999998	48.809494000000001	56.985996	56.447996000000003	Мира	0103000020E61000000100000005000000A0C1A6CEA3104840925ED4EE57394C40A0C1A6CEA310484050FEEE1D357E4C407427D87F9D67484050FEEE1D357E4C407427D87F9D674840925ED4EE57394C40A0C1A6CEA3104840925ED4EE57394C40
63004	25778	48.183861999999998	48.204828999999997	56.795658000000003	56.780053000000002	Речная	0103000020E61000000100000005000000137D3ECA88174840C712D6C6D8634C40137D3ECA881748408066101FD8654C40DD2230D6371A48408066101FD8654C40DD2230D6371A4840C712D6C6D8634C40137D3ECA88174840C712D6C6D8634C40
63099	25953	48.414378999999997	48.445495999999999	56.708182999999998	56.693505000000002	Центральная	0103000020E610000001000000050000001893FE5E0A354840664E97C5C4584C401893FE5E0A354840A54A94BDA55A4C40D93F4F0306394840A54A94BDA55A4C40D93F4F0306394840664E97C5C4584C401893FE5E0A354840664E97C5C4584C40
62999	25303	\N	\N	\N	\N	Новая	\N
63002	25699	48.383647000000003	48.403742999999999	56.937373000000001	56.924014	Молодежная	0103000020E61000000100000005000000B11A4B581B314840E8853B1746764C40B11A4B581B314840A393A5D6FB774C40957EC2D9AD334840A393A5D6FB774C40957EC2D9AD334840E8853B1746764C40B11A4B581B314840E8853B1746764C40
62205	26033	48.390663000000004	48.413355000000003	56.546653999999997	56.536068	Солнечная	0103000020E61000000100000005000000EE60C43E01324840503750E09D444C40EE60C43E01324840211D1EC2F8454C40AD510FD1E8344840211D1EC2F8454C40AD510FD1E8344840503750E09D444C40EE60C43E01324840503750E09D444C40
62290	25112	48.458396	48.494571000000001	56.772669999999998	56.743439000000002	Свободы	0103000020E61000000100000005000000014F5AB8AC3A484015C95702295F4C40014F5AB8AC3A4840D74CBED9E6624C4067463F1A4E3F4840D74CBED9E6624C4067463F1A4E3F484015C95702295F4C40014F5AB8AC3A484015C95702295F4C40
62944	25112	48.458396	48.494571000000001	56.772669999999998	56.743439000000002	Пушкина	0103000020E61000000100000005000000014F5AB8AC3A484015C95702295F4C40014F5AB8AC3A4840D74CBED9E6624C4067463F1A4E3F4840D74CBED9E6624C4067463F1A4E3F484015C95702295F4C40014F5AB8AC3A484015C95702295F4C40
62214	25112	48.458396	48.494571000000001	56.772669999999998	56.743439000000002	Победы	0103000020E61000000100000005000000014F5AB8AC3A484015C95702295F4C40014F5AB8AC3A4840D74CBED9E6624C4067463F1A4E3F4840D74CBED9E6624C4067463F1A4E3F484015C95702295F4C40014F5AB8AC3A484015C95702295F4C40
62213	25112	48.458396	48.494571000000001	56.772669999999998	56.743439000000002	Ломоносова	0103000020E61000000100000005000000014F5AB8AC3A484015C95702295F4C40014F5AB8AC3A4840D74CBED9E6624C4067463F1A4E3F4840D74CBED9E6624C4067463F1A4E3F484015C95702295F4C40014F5AB8AC3A484015C95702295F4C40
62223	57930	48.319580000000002	48.336899000000003	56.678674000000001	56.669713000000002	Советская	0103000020E61000000100000005000000543A58FFE7284840605AD427B9554C40543A58FFE7284840A05225CADE564C400E87A5811F2B4840A05225CADE564C400E87A5811F2B4840605AD427B9554C40543A58FFE7284840605AD427B9554C40
62204	25928	48.498165	48.532552000000003	56.713276	56.697122999999998	Центральная	0103000020E610000001000000050000008481E7DEC33F48400B2593533B594C408481E7DEC33F4840C782C2A04C5B4C40AFB5F7A92A444840C782C2A04C5B4C40AFB5F7A92A4448400B2593533B594C408481E7DEC33F48400B2593533B594C40
63024	25511	48.496934000000003	48.515636999999998	56.915813999999997	56.902884999999998	Советская	0103000020E610000001000000050000009F2287889B3F4840448655BC91734C409F2287889B3F4840069CA56439754C40C4CDA96400424840069CA56439754C40C4CDA96400424840448655BC91734C409F2287889B3F4840448655BC91734C40
62203	25879	48.247804000000002	48.265689999999999	56.663842000000002	56.651651000000001	Зеленая	0103000020E61000000100000005000000B4E89D0AB81F4840EEB3CA4C69534C40B4E89D0AB81F48400ADB4FC6F8544C40E76F4221022248400ADB4FC6F8544C40E76F422102224840EEB3CA4C69534C40B4E89D0AB81F4840EEB3CA4C69534C40
63001	25410	48.656098	48.698281999999999	56.881216999999999	56.869199999999999	Нижняя	0103000020E610000001000000050000004A7CEE04FB53484073D712F2416F4C404A7CEE04FB534840F1D6F9B7CB704C4057B1F84D61594840F1D6F9B7CB704C4057B1F84D6159484073D712F2416F4C404A7CEE04FB53484073D712F2416F4C40
63058	25639	48.313237999999998	48.328194000000003	56.852854000000001	56.844968000000001	Центральная	0103000020E61000000100000005000000A6EECA2E18284840511553E9276C4C40A6EECA2E18284840A321E3512A6D4C40295FD042022A4840A321E3512A6D4C40295FD042022A4840511553E9276C4C40A6EECA2E18284840511553E9276C4C40
63147	25597	48.535912000000003	48.553618	56.832270000000001	56.813004999999997	м-н Светлый	0103000020E6100000010000000500000059C4B0C398444840033E3F8C10684C4059C4B0C39844484091B8C7D2876A4C400C3D62F4DC46484091B8C7D2876A4C400C3D62F4DC464840033E3F8C10684C4059C4B0C398444840033E3F8C10684C40
63003	25705	48.250552999999996	48.281455000000001	56.822459000000002	56.811132999999998	Ермакова	0103000020E610000001000000050000001475E61E122048406ADAC534D3674C401475E61E1220484083A6255646694C40D925AAB70624484083A6255646694C40D925AAB7062448406ADAC534D3674C401475E61E122048406ADAC534D3674C40
62295	25496	48.512008000000002	48.529111999999998	56.787430000000001	56.777014999999999	Дружбы	0103000020E610000001000000050000002BA5677A894148402FC03E3A75634C402BA5677A89414840D4F19881CA644C40E8F527F1B9434840D4F19881CA644C40E8F527F1B94348402FC03E3A75634C402BA5677A894148402FC03E3A75634C40
63039	25401	48.634224000000003	48.658172999999998	56.782859000000002	56.768087999999999	Центральная	0103000020E610000001000000050000004E2B85402E5148409B3924B550624C404E2B85402E5148408C3045B934644C401B0E4B033F5448408C3045B934644C401B0E4B033F5448409B3924B550624C404E2B85402E5148409B3924B550624C40
62215	25311	48.332255000000004	48.360399000000001	56.753019000000002	56.742086999999998	Октябрьская	0103000020E610000001000000050000005C77F354872A4840B4E4F1B4FC5E4C405C77F354872A4840212235ED62604C406C41EF8D212E4840212235ED62604C406C41EF8D212E4840B4E4F1B4FC5E4C405C77F354872A4840B4E4F1B4FC5E4C40
63089	24418	49.141663999999999	49.150288000000003	57.303440999999999	57.299337000000001	Эшполдино	0103000020E61000000100000005000000A182C30B22924840CBBDC0AC50A64C40A182C30B22924840FDA19927D7A64C409A7D1EA33C934840FDA19927D7A64C409A7D1EA33C934840CBBDC0AC50A64C40A182C30B22924840CBBDC0AC50A64C40
63218	24279	49.065953999999998	49.085861000000001	57.262794999999997	57.243938	Читово	0103000020E610000001000000050000002B85402E718848403620425C399F4C402B85402E71884840B2463D44A3A14C403D80457EFD8A4840B2463D44A3A14C403D80457EFD8A48403620425C399F4C402B85402E718848403620425C399F4C40
62973	24889	49.080902000000002	49.103566000000001	56.910727999999999	56.899763	Колхозная	0103000020E610000001000000050000002B172AFF5A8A48404F93196F2B734C402B172AFF5A8A484097C62FBC92744C40207D93A6418D484097C62FBC92744C40207D93A6418D48404F93196F2B734C402B172AFF5A8A48404F93196F2B734C40
63131	23975	49.301302999999997	49.330499000000003	56.877640999999997	56.866539000000003	Мира	0103000020E61000000100000005000000E597C11891A64840B2DAFCBFEA6E4C40E597C11891A648407A50508A56704C402C2E8ECA4DAA48407A50508A56704C402C2E8ECA4DAA4840B2DAFCBFEA6E4C40E597C11891A64840B2DAFCBFEA6E4C40
62210	23578	49.110798000000003	49.168658000000001	56.952893000000003	56.922589000000002	Микрорайон	0103000020E610000001000000050000002A3BFDA02E8E48401E53776517764C402A3BFDA02E8E48402ECBD765F8794C40B91AD995969548402ECBD765F8794C40B91AD995969548401E53776517764C402A3BFDA02E8E48401E53776517764C40
62201	23578	49.110798000000003	49.168658000000001	56.952893000000003	56.922589000000002	Комсомольская	0103000020E610000001000000050000002A3BFDA02E8E48401E53776517764C402A3BFDA02E8E48402ECBD765F8794C40B91AD995969548402ECBD765F8794C40B91AD995969548401E53776517764C402A3BFDA02E8E48401E53776517764C40
62202	23578	49.110798000000003	49.168658000000001	56.952893000000003	56.922589000000002	Коммунистическая	0103000020E610000001000000050000002A3BFDA02E8E48401E53776517764C402A3BFDA02E8E48402ECBD765F8794C40B91AD995969548402ECBD765F8794C40B91AD995969548401E53776517764C402A3BFDA02E8E48401E53776517764C40
62212	23578	49.110798000000003	49.168658000000001	56.952893000000003	56.922589000000002	Казанская	0103000020E610000001000000050000002A3BFDA02E8E48401E53776517764C402A3BFDA02E8E48402ECBD765F8794C40B91AD995969548402ECBD765F8794C40B91AD995969548401E53776517764C402A3BFDA02E8E48401E53776517764C40
63136	24475	49.095256999999997	49.111004000000001	57.224643	57.215808000000003	Нижний Рушенер	0103000020E6100000010000000500000087DBA161318C48408B1BB7989F9B4C4087DBA161318C48403E23111AC19C4C40D3DC0A61358E48403E23111AC19C4C40D3DC0A61358E48408B1BB7989F9B4C4087DBA161318C48408B1BB7989F9B4C40
63035	23814	49.214796	49.225090000000002	56.892555999999999	56.886803999999998	Советская	0103000020E61000000100000005000000E3A7716F7E9B484022FB20CB82714C40E3A7716F7E9B48409EEC66463F724C400D54C6BFCF9C48409EEC66463F724C400D54C6BFCF9C484022FB20CB82714C40E3A7716F7E9B484022FB20CB82714C40
63184	24978	49.010573000000001	49.026958	56.944557000000003	56.931077000000002	Центральная	0103000020E610000001000000050000003D9CC0745A8148406687F8872D774C403D9CC0745A8148409C1A683EE7784C40CB2E185C738348409C1A683EE7784C40CB2E185C738348406687F8872D774C403D9CC0745A8148406687F8872D774C40
62970	24726	49.081682999999998	49.098751	57.044119000000002	57.035476000000003	Центральная	0103000020E61000000100000005000000D0D1AA96748A48407EE5417A8A844C40D0D1AA96748A4840ED10FFB0A5854C4041B96DDFA38C4840ED10FFB0A5854C4041B96DDFA38C48407EE5417A8A844C40D0D1AA96748A48407EE5417A8A844C40
63211	24810	49.002344000000001	49.020769000000001	57.038645000000002	57.028354	Набережная	0103000020E61000000100000005000000C1ABE5CE4C804840FB5A971AA1834C40C1ABE5CE4C804840B493C151F2844C40A4E2FF8EA8824840B493C151F2844C40A4E2FF8EA8824840FB5A971AA1834C40C1ABE5CE4C804840FB5A971AA1834C40
63224	24067	49.217015000000004	49.237945000000003	57.027267000000002	57.014498000000003	Лоскутово	0103000020E61000000100000005000000E8DEC325C79B4840C0ED0912DB814C40E8DEC325C79B484049A12C7C7D834C40959F54FB749E484049A12C7C7D834C40959F54FB749E4840C0ED0912DB814C40E8DEC325C79B4840C0ED0912DB814C40
63093	24588	49.283535000000001	49.293092999999999	56.992007999999998	56.988688000000003	Летник	0103000020E61000000100000005000000BC22F8DF4AA448404DF910548D7E4C40BC22F8DF4AA4484068AF3E1EFA7E4C40E0D7481284A5484068AF3E1EFA7E4C40E0D7481284A548404DF910548D7E4C40BC22F8DF4AA448404DF910548D7E4C40
63009	58053	49.263241999999998	49.280659999999997	56.881345000000003	56.872413000000002	Молодежная	0103000020E610000001000000050000008177F2E9B1A1484079CDAB3AAB6F4C408177F2E9B1A148401FBFB7E9CF704C40CEA5B8AAECA348401FBFB7E9CF704C40CEA5B8AAECA3484079CDAB3AAB6F4C408177F2E9B1A1484079CDAB3AAB6F4C40
63182	24367	49.135509999999996	49.151122999999998	57.259222000000001	57.251043000000003	Купсола	0103000020E61000000100000005000000F623456458914840E371512D22A04C40F623456458914840AD33BE2F2EA14C4032569BFF57934840AD33BE2F2EA14C4032569BFF57934840E371512D22A04C40F623456458914840E371512D22A04C40
63183	24925	49.048130999999998	49.075018	56.903562999999998	56.896219000000002	Центральная	0103000020E610000001000000050000003E76172829864840E486DF4DB7724C403E761728298648401570CFF3A7734C40404E98309A8948401570CFF3A7734C40404E98309A894840E486DF4DB7724C403E76172829864840E486DF4DB7724C40
63123	58066	49.038977000000003	49.073068999999997	57.241517999999999	57.221601999999997	Кооперативная	0103000020E61000000100000005000000EA25C632FD844840355D4F745D9C4C40EA25C632FD8448409AB2D30FEA9E4C40FBAC32535A8948409AB2D30FEA9E4C40FBAC32535A894840355D4F745D9C4C40EA25C632FD844840355D4F745D9C4C40
63200	24676	49.219521	49.233255999999997	56.942312999999999	56.930635000000002	Кочанур	0103000020E6100000010000000500000082E49D43199C4840A9C1340C1F774C4082E49D43199C48403ECC5EB69D784C4042CC2555DB9D48403ECC5EB69D784C4042CC2555DB9D4840A9C1340C1F774C4082E49D43199C4840A9C1340C1F774C40
63023	24157	49.487848	49.521237999999997	56.986652999999997	56.975132000000002	Новая	0103000020E61000000100000005000000A2B5A2CD71BE48403CA41820D17C4C40A2B5A2CD71BE484009C03FA54A7E4C405AB741EDB7C2484009C03FA54A7E4C405AB741EDB7C248403CA41820D17C4C40A2B5A2CD71BE48403CA41820D17C4C40
62293	24199	49.112442000000001	49.139580000000002	57.158285999999997	57.142462000000002	Коммунальная	0103000020E610000001000000050000003259DC7F648E48401D76DF313C924C403259DC7F648E484013B534B742944C407D96E7C1DD91484013B534B742944C407D96E7C1DD9148401D76DF313C924C403259DC7F648E48401D76DF313C924C40
63086	24752	49.109855000000003	49.127003000000002	57.060352999999999	57.049211	Йошкар-Памаш	0103000020E61000000100000005000000AB2688BA0F8E48403ECDC98B4C864C40AB2688BA0F8E4840959BA8A5B9874C4038BF61A241904840959BA8A5B9874C4038BF61A2419048403ECDC98B4C864C40AB2688BA0F8E48403ECDC98B4C864C40
63133	24079	49.371794000000001	49.389231000000002	56.970377999999997	56.961987000000001	Больничная	0103000020E61000000100000005000000AD6C1FF296AF4840AD16D863227B4C40AD6C1FF296AF48400261A758357C4C4071CB4752D2B148400261A758357C4C4071CB4752D2B14840AD16D863227B4C40AD6C1FF296AF4840AD16D863227B4C40
63033	23979	49.116098000000001	49.126060000000003	56.975862999999997	56.968896000000001	Дубники	0103000020E61000000100000005000000C5909C4CDC8E4840D49CBCC8047C4C40C5909C4CDC8E48402F302B14E97C4C40B9AAECBB229048402F302B14E97C4C40B9AAECBB22904840D49CBCC8047C4C40C5909C4CDC8E4840D49CBCC8047C4C40
63214	25046	49.050566000000003	49.064669000000002	56.865141000000001	56.858837999999999	Полевая	0103000020E6100000010000000500000010255AF278864840F1475167EE6D4C4010255AF278864840E1B6B6F0BC6E4C405308E41247884840E1B6B6F0BC6E4C405308E41247884840F1475167EE6D4C4010255AF278864840F1475167EE6D4C40
62969	24484	49.255310000000001	49.283517000000003	56.94276	56.932800999999998	Большой Сердеж	0103000020E61000000100000005000000BF2B82FFADA048408A56EE0566774C40BF2B82FFADA048400DFD135CAC784C40166EF9484AA448400DFD135CAC784C40166EF9484AA448408A56EE0566774C40BF2B82FFADA048408A56EE0566774C40
63213	24840	48.982931999999998	49.013869999999997	57.015791999999998	57.003597999999997	Шабалина	0103000020E610000001000000050000008F183DB7D07D48405E2A36E675804C408F183DB7D07D4840EBC4E57805824C40A032FE7DC6814840EBC4E57805824C40A032FE7DC68148405E2A36E675804C408F183DB7D07D48405E2A36E675804C40
63186	23849	49.132474000000002	49.150872	56.902059000000001	56.891657000000002	Центральная	0103000020E6100000010000000500000000C974E8F4904840EF1F0BD121724C4000C974E8F4904840FF0758AB76734C40E9F010C64F934840FF0758AB76734C40E9F010C64F934840EF1F0BD121724C4000C974E8F4904840EF1F0BD121724C40
63132	23544	49.456263	49.479125000000003	56.729956000000001	56.716166000000001	Коммунистическая	0103000020E61000000100000005000000FBAF73D366BA4840EA40D653AB5B4C40FBAF73D366BA48406EC2BD326F5D4C4017D9CEF753BD48406EC2BD326F5D4C4017D9CEF753BD4840EA40D653AB5B4C40FBAF73D366BA4840EA40D653AB5B4C40
63010	23413	49.482970000000002	49.508805000000002	56.890726999999998	56.876539999999999	Молодежная	0103000020E610000001000000050000007D7901F6D1BD484063D1747632704C407D7901F6D1BD48400455A35703724C404985B18520C148400455A35703724C404985B18520C1484063D1747632704C407D7901F6D1BD484063D1747632704C40
62983	23394	49.258211000000003	49.284343	56.692596000000002	56.674481	Колхозная	0103000020E61000000100000005000000D63BDC0E0DA14840FE62B66455564C40D63BDC0E0DA1484093AB58FCA6584C405BECF65965A4484093AB58FCA6584C405BECF65965A44840FE62B66455564C40D63BDC0E0DA14840FE62B66455564C40
63216	23128	49.388179999999998	49.409163999999997	56.882962999999997	56.873086999999998	Мира	0103000020E610000001000000050000000B7BDAE1AFB1484008C89750C16F4C400B7BDAE1AFB14840FD497CEE04714C40AB59677C5FB44840FD497CEE04714C40AB59677C5FB4484008C89750C16F4C400B7BDAE1AFB1484008C89750C16F4C40
62200	22842	49.386418999999997	49.424470999999997	56.716664999999999	56.691710999999998	Тукаевская	0103000020E61000000100000005000000C9C6832D76B1484048A46DFC89584C40C9C6832D76B148400B98C0ADBB5B4C40DA8CD31055B648400B98C0ADBB5B4C40DA8CD31055B6484048A46DFC89584C40C9C6832D76B1484048A46DFC89584C40
62288	22842	49.386418999999997	49.424470999999997	56.716664999999999	56.691710999999998	Колхозная	0103000020E61000000100000005000000C9C6832D76B1484048A46DFC89584C40C9C6832D76B148400B98C0ADBB5B4C40DA8CD31055B648400B98C0ADBB5B4C40DA8CD31055B6484048A46DFC89584C40C9C6832D76B1484048A46DFC89584C40
62294	22842	49.386418999999997	49.424470999999997	56.716664999999999	56.691710999999998	Гагарина	0103000020E61000000100000005000000C9C6832D76B1484048A46DFC89584C40C9C6832D76B148400B98C0ADBB5B4C40DA8CD31055B648400B98C0ADBB5B4C40DA8CD31055B6484048A46DFC89584C40C9C6832D76B1484048A46DFC89584C40
62984	23479	49.545330999999997	49.570951000000001	56.750818000000002	56.736454000000002	Гагарина	0103000020E610000001000000050000005B3FFD67CDC548401381EA1F445E4C405B3FFD67CDC54840C39FE1CD1A604C402B4F20EC14C94840C39FE1CD1A604C402B4F20EC14C948401381EA1F445E4C405B3FFD67CDC548401381EA1F445E4C40
63110	23285	49.238269000000003	49.259469000000003	56.749431000000001	56.736153000000002	Центральная	0103000020E6100000010000000500000048533D997F9E484018EDF1423A5E4C4048533D997F9E4840E6CDE15AED5F4C40B5A9BA4736A14840E6CDE15AED5F4C40B5A9BA4736A1484018EDF1423A5E4C4048533D997F9E484018EDF1423A5E4C40
63180	23036	49.452300999999999	49.472881999999998	56.77525	56.760159000000002	Советская	0103000020E610000001000000050000005B79C9FFE4B948404A61DEE34C614C405B79C9FFE4B94840AC1C5A643B634C40FC6EBA6587BC4840AC1C5A643B634C40FC6EBA6587BC48404A61DEE34C614C405B79C9FFE4B948404A61DEE34C614C40
62967	23237	49.277830999999999	49.291620000000002	56.734833999999999	56.725135999999999	Новая	0103000020E61000000100000005000000516859F78FA348407D93A641D15C4C40516859F78FA3484093FE5E0A0F5E4C40056EDDCD53A5484093FE5E0A0F5E4C40056EDDCD53A548407D93A641D15C4C40516859F78FA348407D93A641D15C4C40
63209	23337	49.282671999999998	49.307124999999999	56.698413000000002	56.688527999999998	Кооперативная	0103000020E6100000010000000500000059BF99982EA44840AD307DAF21584C4059BF99982EA44840F60CE19865594C405A643BDF4FA74840F60CE19865594C405A643BDF4FA74840AD307DAF21584C4059BF99982EA44840AD307DAF21584C40
62962	23197	49.384784000000003	49.412497000000002	56.799818000000002	56.784373000000002	Мира	0103000020E610000001000000050000001503249A40B14840C66E9F5566644C401503249A40B148404660AC6F60664C405C59A2B3CCB448404660AC6F60664C405C59A2B3CCB44840C66E9F5566644C401503249A40B14840C66E9F5566644C40
63081	23173	49.491118	49.510907000000003	56.584819000000003	56.564760999999997	Заречная	0103000020E610000001000000050000000C3D62F4DCBE48403387A4164A484C400C3D62F4DCBE48402B8A5759DB4A4C4014268C6665C148402B8A5759DB4A4C4014268C6665C148403387A4164A484C400C3D62F4DCBE48403387A4164A484C40
62968	23050	49.407277999999998	49.426924	56.861786000000002	56.849328999999997	Рабочая	0103000020E61000000100000005000000AD307DAF21B44840AE450BD0B66C4C40AD307DAF21B448404913EF004F6E4C4052F01472A5B648404913EF004F6E4C4052F01472A5B64840AE450BD0B66C4C40AD307DAF21B44840AE450BD0B66C4C40
63031	22976	49.467320999999998	49.505589000000001	56.786385000000003	56.763939000000001	Ленина	0103000020E61000000100000005000000F4DDAD2CD1BB4840C991CEC0C8614C40F4DDAD2CD1BB484051888043A8644C40D21BEE23B7C0484051888043A8644C40D21BEE23B7C04840C991CEC0C8614C40F4DDAD2CD1BB4840C991CEC0C8614C40
62971	22789	48.155835000000003	48.178930000000001	56.946972000000002	56.935969	Микрорайон	0103000020E610000001000000050000003D49BA66F2134840F0880AD5CD774C403D49BA66F2134840261DE56036794C40FB22A12DE7164840261DE56036794C40FB22A12DE7164840F0880AD5CD774C403D49BA66F2134840F0880AD5CD774C40
63205	22710	48.214764000000002	48.256644000000001	56.915740999999997	56.889882	Новая	0103000020E61000000100000005000000D82D02637D1B484048A643A7E7714C40D82D02637D1B48409C4D470037754C40795BE9B5D92048409C4D470037754C40795BE9B5D920484048A643A7E7714C40D82D02637D1B484048A643A7E7714C40
63129	22670	47.710773000000003	47.748421999999998	56.883237999999999	56.857007000000003	Первомайская	0103000020E610000001000000050000009EF0129CFADA4740B7B8C667B26D4C409EF0129CFADA4740CF4A5AF10D714C40AFCDC64ACCDF4740CF4A5AF10D714C40AFCDC64ACCDF4740B7B8C667B26D4C409EF0129CFADA4740B7B8C667B26D4C40
63178	22645	47.694837	47.816217999999999	56.984721	56.958703999999997	Школьная	0103000020E610000001000000050000007F86376BF0D84740AE450BD0B67A4C407F86376BF0D847409B5775560B7E4C400934D8D479E847409B5775560B7E4C400934D8D479E84740AE450BD0B67A4C407F86376BF0D84740AE450BD0B67A4C40
62979	22596	47.984903000000003	48.009112999999999	56.807958999999997	56.795766	Волкова	0103000020E61000000100000005000000BC5D2F4D11FE474066A208A9DB654C40BC5D2F4D11FE474022C154336B674C40F67B629D2A01484022C154336B674C40F67B629D2A01484066A208A9DB654C40BC5D2F4D11FE474066A208A9DB654C40
63207	22756	48.289783	48.319372999999999	56.981969999999997	56.967163999999997	Школьная	0103000020E61000000100000005000000E8F7FD9B172548402CEFAA07CC7B4C40E8F7FD9B1725484099D36531B17D4C40DA1CE736E128484099D36531B17D4C40DA1CE736E12848402CEFAA07CC7B4C40E8F7FD9B172548402CEFAA07CC7B4C40
63141	22149	47.862247000000004	47.917583999999998	56.931156000000001	56.910119000000002	Юбилейная	0103000020E610000001000000050000007D09151C5EEE4740EF3B86C77E744C407D09151C5EEE4740B2BCAB1E30774C409BAA7B6473F54740B2BCAB1E30774C409BAA7B6473F54740EF3B86C77E744C407D09151C5EEE4740EF3B86C77E744C40
62211	22149	47.862247000000004	47.917583999999998	56.931156000000001	56.910119000000002	Советская	0103000020E610000001000000050000007D09151C5EEE4740EF3B86C77E744C407D09151C5EEE4740B2BCAB1E30774C409BAA7B6473F54740B2BCAB1E30774C409BAA7B6473F54740EF3B86C77E744C407D09151C5EEE4740EF3B86C77E744C40
63075	22149	47.862247000000004	47.917583999999998	56.931156000000001	56.910119000000002	Пролетарская	0103000020E610000001000000050000007D09151C5EEE4740EF3B86C77E744C407D09151C5EEE4740B2BCAB1E30774C409BAA7B6473F54740B2BCAB1E30774C409BAA7B6473F54740EF3B86C77E744C407D09151C5EEE4740EF3B86C77E744C40
62199	22149	47.862247000000004	47.917583999999998	56.931156000000001	56.910119000000002	Гагарина	0103000020E610000001000000050000007D09151C5EEE4740EF3B86C77E744C407D09151C5EEE4740B2BCAB1E30774C409BAA7B6473F54740B2BCAB1E30774C409BAA7B6473F54740EF3B86C77E744C407D09151C5EEE4740EF3B86C77E744C40
62964	21902	47.902124000000001	47.924734000000001	56.873804999999997	56.851337999999998	Восточная	0103000020E61000000100000005000000E6779ACC78F34740C8EBC1A4F86C4C40E6779ACC78F34740670A9DD7D86F4C40E8BF07AF5DF64740670A9DD7D86F4C40E8BF07AF5DF64740C8EBC1A4F86C4C40E6779ACC78F34740C8EBC1A4F86C4C40
63197	22408	48.107802	48.122641999999999	56.857577999999997	56.849600000000002	Новая	0103000020E61000000100000005000000C138B874CC0D48403F575BB1BF6C4C40C138B874CC0D484071E2AB1DC56D4C40DA8EA9BBB20F484071E2AB1DC56D4C40DA8EA9BBB20F48403F575BB1BF6C4C40C138B874CC0D48403F575BB1BF6C4C40
63130	22510	48.312600000000003	48.327772000000003	57.077855999999997	57.072122	Центральная	0103000020E61000000100000005000000645DDC46032848403BA92F4B3B894C40645DDC460328484010E6762FF7894C40B345D26EF429484010E6762FF7894C40B345D26EF42948403BA92F4B3B894C40645DDC46032848403BA92F4B3B894C40
63202	22446	47.911977999999998	47.931094000000002	56.943482000000003	56.926755	Школьная	0103000020E61000000100000005000000F355F2B1BBF44740C63368E89F764C40F355F2B1BBF44740AE2EA704C4784C403CC093162EF74740AE2EA704C4784C403CC093162EF74740C63368E89F764C40F355F2B1BBF44740C63368E89F764C40
63077	22519	48.207946	48.240150999999997	57.019477000000002	57.003675999999999	Центральная	0103000020E61000000100000005000000C1AA7AF99D1A4840DAE3857478804C40C1AA7AF99D1A48401903EB387E824C40048D9944BD1E48401903EB387E824C40048D9944BD1E4840DAE3857478804C40C1AA7AF99D1A4840DAE3857478804C40
63179	22353	48.055331000000002	48.104990000000001	56.823385000000002	56.807186000000002	Шкетана	0103000020E610000001000000050000003DBA11161507484000E5EFDE51674C403DBA1116150748402C82FFAD64694C401A34F44F700D48402C82FFAD64694C401A34F44F700D484000E5EFDE51674C403DBA11161507484000E5EFDE51674C40
63156	22336	47.810836999999999	47.854118	56.929372999999998	56.913898000000003	155а	0103000020E6100000010000000500000081B1BE81C9E747409EF0129CFA744C4081B1BE81C9E747408864C8B1F5764C40647616BD53ED47408864C8B1F5764C40647616BD53ED47409EF0129CFA744C4081B1BE81C9E747409EF0129CFA744C40
63195	21694	48.304937000000002	48.332478999999999	57.127887000000001	57.115124000000002	Микрорайон	0103000020E61000000100000005000000912BF52C082748400B7E1B62BC8E4C40912BF52C08274840B24AE9995E904C40ABCDFFAB8E2A4840B24AE9995E904C40ABCDFFAB8E2A48400B7E1B62BC8E4C40912BF52C082748400B7E1B62BC8E4C40
63143	22063	48.759816999999998	48.770696000000001	57.008915999999999	57.004446000000002	им.В.Иванова	0103000020E61000000100000005000000F0F8F6AE416148408C4CC0AF91804C40F0F8F6AE41614840A034D42824814C403A94A12AA6624840A034D42824814C403A94A12AA66248408C4CC0AF91804C40F0F8F6AE416148408C4CC0AF91804C40
63022	21778	48.710014000000001	48.7271	56.928021999999999	56.915087	Центральная	0103000020E61000000100000005000000E0D91EBDE15A484054FF209221754C40E0D91EBDE15A4840F8FBC56CC9764C40F775E09C115D4840F8FBC56CC9764C40F775E09C115D484054FF209221754C40E0D91EBDE15A484054FF209221754C40
63037	21772	48.768369	48.803609999999999	56.970545000000001	56.954134000000003	Центральная	0103000020E610000001000000050000004F2157EA5962484037001B10217A4C404F2157EA59624840EE258DD13A7C4C40895E46B1DC664840EE258DD13A7C4C40895E46B1DC66484037001B10217A4C404F2157EA5962484037001B10217A4C40
79389	61561	48.221905999999997	48.944195999999998	57.174191	56.867198000000002	Молодежная	0103000020E61000000100000005000000A164726A671C48400C941458006F4C40A164726A671C4840F72004E44B964C40CB811E6ADB784840F72004E44B964C40CB811E6ADB7848400C941458006F4C40A164726A671C48400C941458006F4C40
63021	21638	48.380135000000003	48.394337	57.038375000000002	57.026384999999998	Советская	0103000020E6100000010000000500000051888043A83048406F0D6C9560834C4051888043A8304840F4FDD478E9844C40274D83A279324840F4FDD478E9844C40274D83A2793248406F0D6C9560834C4051888043A83048406F0D6C9560834C40
62287	21241	48.712152000000003	48.748443999999999	57.023715000000003	56.993366000000002	Советская	0103000020E61000000100000005000000F8E3F6CB275B4840AB7AF99D267F4C40F8E3F6CB275B48405BB6D61709834C4097715303CD5F48405BB6D61709834C4097715303CD5F4840AB7AF99D267F4C40F8E3F6CB275B4840AB7AF99D267F4C40
62286	21241	48.712152000000003	48.748443999999999	57.023715000000003	56.993366000000002	Первомайская	0103000020E61000000100000005000000F8E3F6CB275B4840AB7AF99D267F4C40F8E3F6CB275B48405BB6D61709834C4097715303CD5F48405BB6D61709834C4097715303CD5F4840AB7AF99D267F4C40F8E3F6CB275B4840AB7AF99D267F4C40
62198	21241	48.712152000000003	48.748443999999999	57.023715000000003	56.993366000000002	Культуры	0103000020E61000000100000005000000F8E3F6CB275B4840AB7AF99D267F4C40F8E3F6CB275B48405BB6D61709834C4097715303CD5F48405BB6D61709834C4097715303CD5F4840AB7AF99D267F4C40F8E3F6CB275B4840AB7AF99D267F4C40
62292	21241	48.712152000000003	48.748443999999999	57.023715000000003	56.993366000000002	Коммунистическая	0103000020E61000000100000005000000F8E3F6CB275B4840AB7AF99D267F4C40F8E3F6CB275B48405BB6D61709834C4097715303CD5F48405BB6D61709834C4097715303CD5F4840AB7AF99D267F4C40F8E3F6CB275B4840AB7AF99D267F4C40
62965	21936	48.797753	48.818944000000002	57.077846000000001	57.060191000000003	Центральная	0103000020E6100000010000000500000098A432C51C664840BC41B456B4874C4098A432C51C664840ED0F94DBF6894C40B2A03028D3684840ED0F94DBF6894C40B2A03028D3684840BC41B456B4874C4098A432C51C664840BC41B456B4874C40
63191	21484	48.641105000000003	48.655397000000001	57.127589	57.114674000000001	Советская	0103000020E61000000100000005000000AB2688BA0F524840CBD93BA3AD8E4C40AB2688BA0F524840282A1BD654904C40C172840CE4534840282A1BD654904C40C172840CE4534840CBD93BA3AD8E4C40AB2688BA0F524840CBD93BA3AD8E4C40
63074	21861	48.872996000000001	48.888195000000003	56.945720000000001	56.93479	Центральная	0103000020E61000000100000005000000F8C43A55BE6F48405D50DF32A7774C40F8C43A55BE6F484029965B5A0D794C4041BCAE5FB071484029965B5A0D794C4041BCAE5FB07148405D50DF32A7774C40F8C43A55BE6F48405D50DF32A7774C40
63188	58075	48.557903000000003	48.577513000000003	57.087629	57.079113	Полевая	0103000020E610000001000000050000008FAB915D694748401FD8F15F208A4C408FAB915D694748403197546D378B4C40E7012CF2EB4948403197546D378B4C40E7012CF2EB4948401FD8F15F208A4C408FAB915D694748401FD8F15F208A4C40
63065	21611	48.456986000000001	48.474781999999998	57.082600999999997	57.071255999999998	Микрорайон	0103000020E610000001000000050000006C5D6A847E3A484067D2A6EA1E894C406C5D6A847E3A4840F6CE68AB928A4C405F5D15A8C53C4840F6CE68AB928A4C405F5D15A8C53C484067D2A6EA1E894C406C5D6A847E3A484067D2A6EA1E894C40
62978	21566	48.584995999999997	48.602459000000003	56.983299000000002	56.959234000000002	Центральная	0103000020E6100000010000000500000039252026E14A48400B9B012EC87A4C4039252026E14A48404298DBBDDC7D4C40271763601D4D48404298DBBDDC7D4C40271763601D4D48400B9B012EC87A4C4039252026E14A48400B9B012EC87A4C40
63041	22078	48.710256999999999	48.733065000000003	56.979948999999998	56.963503000000003	Центральная	0103000020E61000000100000005000000A6608DB3E95A4840884CF910547B4C40A6608DB3E95A4840BB5F05F86E7D4C40CF6BEC12D55D4840BB5F05F86E7D4C40CF6BEC12D55D4840884CF910547B4C40A6608DB3E95A4840884CF910547B4C40
63175	58072	48.705064999999998	48.733946000000003	57.125791	57.104453999999997	переулок Садовый	0103000020E61000000100000005000000F146E6913F5A4840DBF7A8BF5E8D4C40F146E6913F5A4840C99063EB19904C40D88349F1F15D4840C99063EB19904C40D88349F1F15D4840DBF7A8BF5E8D4C40F146E6913F5A4840DBF7A8BF5E8D4C40
63140	20473	49.492221999999998	49.499678000000003	56.439418000000003	56.428821999999997	Ямбаторская	0103000020E61000000100000005000000942F682101BF484014E7A8A3E3364C40942F682101BF48400AA359D93E384C40EE43DE72F5BF48400AA359D93E384C40EE43DE72F5BF484014E7A8A3E3364C40942F682101BF484014E7A8A3E3364C40
62208	20561	49.498376	49.522692999999997	56.470671000000003	56.454144999999997	Спортивная	0103000020E610000001000000050000003F8EE6C8CABF48402A52616C213A4C403F8EE6C8CABF48407B1684F23E3C4C408F6CAE9AE7C248407B1684F23E3C4C408F6CAE9AE7C248402A52616C213A4C403F8EE6C8CABF48402A52616C213A4C40
62975	20072	49.087027999999997	49.110132999999998	56.579161999999997	56.563169000000002	Центральная	0103000020E610000001000000050000000BEBC6BB238B48407E8FFAEB15484C400BEBC6BB238B4840008BFCFA214A4C40ED9A90D6188E4840008BFCFA214A4C40ED9A90D6188E48407E8FFAEB15484C400BEBC6BB238B48407E8FFAEB15484C40
63011	20338	49.351519000000003	49.376384999999999	56.441667000000002	56.409703	Петрова	0103000020E6100000010000000500000019761893FEAC48405B09DD2571344C4019761893FEAC4840795C548B88384C403CDA38622DB04840795C548B88384C403CDA38622DB048405B09DD2571344C4019761893FEAC48405B09DD2571344C40
63109	21039	48.695435000000003	48.719213000000003	56.347423999999997	56.328907999999998	Школьная	0103000020E6100000010000000500000034BF9A030459484046B247A8192A4C4034BF9A030459484039ECBE63782C4C40D5EDEC2B0F5C484039ECBE63782C4C40D5EDEC2B0F5C484046B247A8192A4C4034BF9A030459484046B247A8192A4C40
63157	58070	49.497055000000003	49.519801000000001	56.522570000000002	56.513035000000002	Набережная	0103000020E610000001000000050000001AA88C7F9FBF4840085A8121AB414C401AA88C7F9FBF484074EFE192E3424C40CCB6D3D688C2484074EFE192E3424C40CCB6D3D688C24840085A8121AB414C401AA88C7F9FBF4840085A8121AB414C40
63177	19669	48.851185000000001	48.872186999999997	56.443314000000001	56.431804	Молодежная	0103000020E6100000010000000500000042EC4CA1F36C484018247D5A45374C4042EC4CA1F36C4840F2ED5D83BE384C40887FD8D2A36F4840F2ED5D83BE384C40887FD8D2A36F484018247D5A45374C4042EC4CA1F36C484018247D5A45374C40
63217	20252	49.348168999999999	49.363205999999998	56.392094	56.384180999999998	Центральная	0103000020E61000000100000005000000923D42CD90AC48404E5FCFD72C314C40923D42CD90AC48409A7ADD2230324C4001DBC1887DAE48409A7ADD2230324C4001DBC1887DAE48404E5FCFD72C314C40923D42CD90AC48404E5FCFD72C314C40
62966	20378	49.332816000000001	49.349193	56.416131999999998	56.400627999999998	Школьная	0103000020E61000000100000005000000F3CAF5B699AA484052EE3EC747334C40F3CAF5B699AA4840D76839D043354C40FE7E315BB2AC4840D76839D043354C40FE7E315BB2AC484052EE3EC747334C40F3CAF5B699AA484052EE3EC747334C40
63206	20378	49.332816000000001	49.349193	56.416131999999998	56.400627999999998	Солнечная	0103000020E61000000100000005000000F3CAF5B699AA484052EE3EC747334C40F3CAF5B699AA4840D76839D043354C40FE7E315BB2AC4840D76839D043354C40FE7E315BB2AC484052EE3EC747334C40F3CAF5B699AA484052EE3EC747334C40
63145	19367	49.101042	49.111103	56.404817000000001	56.391845000000004	Центральная	0103000020E61000000100000005000000DFC2BAF1EE8C4840F20C1AFA27324C40DFC2BAF1EE8C4840B3EE1F0BD1334C4066BE839F388E4840B3EE1F0BD1334C4066BE839F388E4840F20C1AFA27324C40DFC2BAF1EE8C4840F20C1AFA27324C40
63226	19889	49.073112999999999	49.092571	56.523646999999997	56.51088	Советская	0103000020E61000000100000005000000CBF44BC45B8948401A170E8464414C40CBF44BC45B89484002D369DD06434C406DC7D45DD98B484002D369DD06434C406DC7D45DD98B48401A170E8464414C40CBF44BC45B8948401A170E8464414C40
63104	19720	48.803528999999997	48.829832000000003	56.486941000000002	56.476458000000001	Школьная	0103000020E610000001000000050000009C31CC09DA66484073F56393FC3C4C409C31CC09DA664840700A2B15543E4C404F965AEF376A4840700A2B15543E4C404F965AEF376A484073F56393FC3C4C409C31CC09DA66484073F56393FC3C4C40
63127	20023	49.246595999999997	49.275692999999997	56.562196999999998	56.548231999999999	Пушкина	0103000020E6100000010000000500000086A92D75909F4840724F57772C464C4086A92D75909F484064744012F6474C40395E81E849A3484064744012F6474C40395E81E849A34840724F57772C464C4086A92D75909F4840724F57772C464C40
63020	20779	48.725698999999999	48.735041000000002	56.422424999999997	56.414169999999999	Клубная	0103000020E61000000100000005000000B5DE6FB4E35C4840FE7DC68503354C40B5DE6FB4E35C4840A301BC0512364C400D1CD0D2155E4840A301BC0512364C400D1CD0D2155E4840FE7DC68503354C40B5DE6FB4E35C4840FE7DC68503354C40
63027	21139	48.587547000000001	48.617443000000002	56.321311000000001	56.303721000000003	Центральная	0103000020E6100000010000000500000074EE76BD344B4840E10D6954E0264C4074EE76BD344B48402B6C06B820294C4073124A5F084F48402B6C06B820294C4073124A5F084F4840E10D6954E0264C4074EE76BD344B4840E10D6954E0264C40
63125	20139	49.284334000000001	49.298518999999999	56.418094000000004	56.390255000000003	Школьная	0103000020E610000001000000050000000892770E65A44840DD0C37E0F3314C400892770E65A44840B153AC1A84354C40081EDFDE35A64840B153AC1A84354C40081EDFDE35A64840DD0C37E0F3314C400892770E65A44840DD0C37E0F3314C40
62195	19100	48.963115000000002	49.025115999999997	56.447806999999997	56.420687999999998	бул. Калинина	0103000020E61000000100000005000000BEA4315A477B4840EAE8B81AD9354C40BEA4315A477B4840BEF561BD51394C409C4D470037834840BEF561BD51394C409C4D470037834840EAE8B81AD9354C40BEA4315A477B4840EAE8B81AD9354C40
62194	19100	48.963115000000002	49.025115999999997	56.447806999999997	56.420687999999998	Советская	0103000020E61000000100000005000000BEA4315A477B4840EAE8B81AD9354C40BEA4315A477B4840BEF561BD51394C409C4D470037834840BEF561BD51394C409C4D470037834840EAE8B81AD9354C40BEA4315A477B4840EAE8B81AD9354C40
62245	19100	48.963115000000002	49.025115999999997	56.447806999999997	56.420687999999998	Льва Толстого	0103000020E61000000100000005000000BEA4315A477B4840EAE8B81AD9354C40BEA4315A477B4840BEF561BD51394C409C4D470037834840BEF561BD51394C409C4D470037834840EAE8B81AD9354C40BEA4315A477B4840EAE8B81AD9354C40
62196	19100	48.963115000000002	49.025115999999997	56.447806999999997	56.420687999999998	Компрессорная	0103000020E61000000100000005000000BEA4315A477B4840EAE8B81AD9354C40BEA4315A477B4840BEF561BD51394C409C4D470037834840BEF561BD51394C409C4D470037834840EAE8B81AD9354C40BEA4315A477B4840EAE8B81AD9354C40
62219	19100	48.963115000000002	49.025115999999997	56.447806999999997	56.420687999999998	Заозерная	0103000020E61000000100000005000000BEA4315A477B4840EAE8B81AD9354C40BEA4315A477B4840BEF561BD51394C409C4D470037834840BEF561BD51394C409C4D470037834840EAE8B81AD9354C40BEA4315A477B4840EAE8B81AD9354C40
63128	19452	49.034477000000003	49.061039999999998	56.364604999999997	56.352342999999998	Центральная	0103000020E610000001000000050000006BBB09BE69844840BDFC4E93192D4C406BBB09BE69844840A27A6B60AB2E4C40B9DFA128D0874840A27A6B60AB2E4C40B9DFA128D0874840BDFC4E93192D4C406BBB09BE69844840BDFC4E93192D4C40
63100	19464	48.949998999999998	48.979841	56.384216000000002	56.370828000000003	Центральная	0103000020E61000000100000005000000C91D3691997948407638BA4A772F4C40C91D369199794840CB4C69FD2D314C40D5230D6E6B7D4840CB4C69FD2D314C40D5230D6E6B7D48407638BA4A772F4C40C91D3691997948407638BA4A772F4C40
63103	21108	48.665143999999998	48.694267000000004	56.363079999999997	56.354267999999998	М. Казакова	0103000020E61000000100000005000000B890477023554840790261A7582D4C40B89047702355484074EACA67792E4C4095D8B5BDDD58484074EACA67792E4C4095D8B5BDDD584840790261A7582D4C40B890477023554840790261A7582D4C40
63068	20925	48.784951999999997	48.809530000000002	56.297553000000001	56.278627	Центральная	0103000020E610000001000000050000000377A04E796448402C64AE0CAA234C400377A04E79644840D1E9793716264C40C190D5AD9E674840D1E9793716264C40C190D5AD9E6748402C64AE0CAA234C400377A04E796448402C64AE0CAA234C40
62976	21197	48.774199000000003	48.807006000000001	56.229996999999997	56.215592999999998	Советская	0103000020E6100000010000000500000047CCECF3186348408E1F2A8D981B4C4047CCECF318634840CC96AC8A701D4C4080D6FCF84B674840CC96AC8A701D4C4080D6FCF84B6748408E1F2A8D981B4C4047CCECF3186348408E1F2A8D981B4C40
63029	20911	48.746234000000001	48.767586999999999	56.356447000000003	56.338898	Юбилейная	0103000020E61000000100000005000000E6948098845F484004577902612B4C40E6948098845F4840F0E0270EA02D4C40D9EA724A40624840F0E0270EA02D4C40D9EA724A4062484004577902612B4C40E6948098845F484004577902612B4C40
63064	19797	48.744661999999998	48.761802000000003	56.615792999999996	56.603026999999997	Центральная	0103000020E6100000010000000500000077499C15515F484070CD1DFD2F4D4C4077499C15515F4840880D164ED24E4C4082035ABA82614840880D164ED24E4C4082035ABA8261484070CD1DFD2F4D4C4077499C15515F484070CD1DFD2F4D4C40
63124	20830	48.701759000000003	48.713141	56.475265	56.463849000000003	Центральная	0103000020E610000001000000050000003B56293DD359484023A46E675F3B4C403B56293DD35948407BF7C77BD53C4C40E7374C34485B48407BF7C77BD53C4C40E7374C34485B484023A46E675F3B4C403B56293DD359484023A46E675F3B4C40
62972	19881	48.774639000000001	48.799450999999998	56.532544000000001	56.509518999999997	Кооперативная	0103000020E61000000100000005000000639AE95E2763484066D828EB37414C40639AE95E276348402CD7DB662A444C4093E00D69546648402CD7DB662A444C4093E00D695466484066D828EB37414C40639AE95E2763484066D828EB37414C40
63126	20206	49.279034000000003	49.292301999999999	56.362805000000002	56.351948999999998	Мира	0103000020E610000001000000050000006D3CD862B7A34840116E32AA0C2D4C406D3CD862B7A34840A3E9EC64702E4C401747E5266AA54840A3E9EC64702E4C401747E5266AA54840116E32AA0C2D4C406D3CD862B7A34840116E32AA0C2D4C40
63111	19746	48.791392999999999	48.816113999999999	56.559289999999997	56.546207000000003	Заозерная	0103000020E6100000010000000500000044A4A65D4C65484053EC681CEA454C4044A4A65D4C6548406B7D91D096474C4064E76D6C766848406B7D91D096474C4064E76D6C7668484053EC681CEA454C4044A4A65D4C65484053EC681CEA454C40
63112	58063	48.89893	48.917444000000003	56.450752000000001	56.442812000000004	Центральная	0103000020E6100000010000000500000057B263231073484060234910AE384C4057B2632310734840A54DD53DB2394C40AAF413CE6E754840A54DD53DB2394C40AAF413CE6E75484060234910AE384C4057B263231073484060234910AE384C40
63026	20697	48.825726000000003	48.847079000000001	56.428109999999997	56.410744000000001	Молодежная	0103000020E610000001000000050000007CBABA63B16948409D83674293344C407CBABA63B1694840978BF84ECC364C406F10AD156D6C4840978BF84ECC364C406F10AD156D6C48409D83674293344C407CBABA63B16948409D83674293344C40
63067	19972	49.060150999999998	49.085321999999998	56.498325999999999	56.486086999999998	Титова	0103000020E610000001000000050000002DE92807B387484060014C19383E4C402DE92807B38748408D5F7825C93F4C408DD0CFD4EB8A48408D5F7825C93F4C408DD0CFD4EB8A484060014C19383E4C402DE92807B387484060014C19383E4C40
63105	20751	48.843584999999997	48.922071000000003	56.440871000000001	56.395746000000003	Школьная	0103000020E61000000100000005000000B532E197FA6B4840ECC20FCEA7324C40B532E197FA6B48409E60FF756E384C4086CB2A6C067648409E60FF756E384C4086CB2A6C06764840ECC20FCEA7324C40B532E197FA6B4840ECC20FCEA7324C40
63173	19560	48.958317999999998	48.981682999999997	56.351550000000003	56.338234999999997	Русская	0103000020E6100000010000000500000085950A2AAA7A484068AED3484B2B4C4085950A2AAA7A484054742497FF2C4C400305DEC9A77D484054742497FF2C4C400305DEC9A77D484068AED3484B2B4C4085950A2AAA7A484068AED3484B2B4C40
63028	58054	47.184693000000003	48.364593999999997	56.924112000000001	56.319294999999997	Культуры	0103000020E610000001000000050000006B662D05A49747405E6397A8DE284C406B662D05A4974740ABEB504D49764C40AE282504AB2E4840ABEB504D49764C40AE282504AB2E48405E6397A8DE284C406B662D05A49747405E6397A8DE284C40
62974	18012	47.642887999999999	47.673332000000002	56.795893999999997	56.781917	Центральная	0103000020E61000000100000005000000D47E6B274AD24740DD9733DB15644C40D47E6B274AD24740938AC6DADF654C40D6AC33BE2FD64740938AC6DADF654C40D6AC33BE2FD64740DD9733DB15644C40D47E6B274AD24740DD9733DB15644C40
62193	18805	47.900866000000001	47.926791000000001	56.729061999999999	56.717767000000002	Мира	0103000020E61000000100000005000000070ABC934FF34740F392FFC9DF5B4C40070ABC934FF34740D06053E7515D4C40139D6516A1F64740D06053E7515D4C40139D6516A1F64740F392FFC9DF5B4C40070ABC934FF34740F392FFC9DF5B4C40
63171	17293	47.610377999999997	47.643192999999997	56.662070999999997	56.644995000000002	Советская	0103000020E610000001000000050000005419C6DD20CE4740B18A37328F524C405419C6DD20CE4740A45016BEBE544C401002F22554D24740A45016BEBE544C401002F22554D24740B18A37328F524C405419C6DD20CE4740B18A37328F524C40
62998	18951	47.808348000000002	47.844802000000001	56.742649	56.724621999999997	Пионерская	0103000020E61000000100000005000000BDE47FF277E7474026FBE769C05C4C40BDE47FF277E747401CB4571F0F5F4C4036CCD07822EC47401CB4571F0F5F4C4036CCD07822EC474026FBE769C05C4C40BDE47FF277E7474026FBE769C05C4C40
63097	17452	48.101621000000002	48.133718000000002	56.774977999999997	56.765557000000001	Школьная	0103000020E610000001000000050000001DCBBBEA010D4840A81C93C5FD614C401DCBBBEA010D48404B8FA67A32634C407A71E2AB1D1148404B8FA67A32634C407A71E2AB1D114840A81C93C5FD614C401DCBBBEA010D4840A81C93C5FD614C40
62283	17807	48.104666999999999	48.136997000000001	56.455956	56.437009000000003	Коммунистическая	0103000020E6100000010000000500000037FC6EBA650D4840628731E9EF374C4037FC6EBA650D48401E3526C45C3A4C403753211E891148401E3526C45C3A4C403753211E89114840628731E9EF374C4037FC6EBA650D4840628731E9EF374C40
63102	18780	47.572118000000003	47.592042999999997	56.885067999999997	56.875191999999998	Школьная	0103000020E61000000100000005000000FAB9A1293BC9474044DC9C4A06704C40FAB9A1293BC94740395E81E849714C40B169A510C8CB4740395E81E849714C40B169A510C8CB474044DC9C4A06704C40FAB9A1293BC9474044DC9C4A06704C40
63203	58079	47.184693000000003	48.364593999999997	56.924112000000001	56.319294999999997	Центральная	0103000020E610000001000000050000006B662D05A49747405E6397A8DE284C406B662D05A4974740ABEB504D49764C40AE282504AB2E4840ABEB504D49764C40AE282504AB2E48405E6397A8DE284C406B662D05A49747405E6397A8DE284C40
63014	17235	47.638503999999998	47.655455000000003	56.626103999999998	56.615045000000002	Зеленая	0103000020E61000000100000005000000BE2EC37FBAD14740BF4868CBB94E4C40BE2EC37FBAD1474088F2052D24504C40F67F0EF3E5D3474088F2052D24504C40F67F0EF3E5D34740BF4868CBB94E4C40BE2EC37FBAD14740BF4868CBB94E4C40
62192	17756	48.177269000000003	48.207093	56.393295000000002	56.368754000000003	Мира	0103000020E610000001000000050000001DCC26C0B01648407522C154332F4C401DCC26C0B01648401557957D57324C40821DFF05821A48401557957D57324C40821DFF05821A48407522C154332F4C401DCC26C0B01648407522C154332F4C40
62942	18487	47.904297	47.920566000000001	56.681511999999998	56.673239000000002	Школьная	0103000020E610000001000000050000007A6F0C01C0F3474025B20FB22C564C407A6F0C01C0F3474070EA03C93B574C409FE74F1BD5F5474070EA03C93B574C409FE74F1BD5F5474025B20FB22C564C407A6F0C01C0F3474025B20FB22C564C40
62284	18406	47.749994000000001	47.768211999999998	56.637045000000001	56.621271	Шумелева	0103000020E610000001000000050000001E19ABCDFFDF4740037AE1CE854F4C401E19ABCDFFDF4740488AC8B08A514C40873254C554E24740488AC8B08A514C40873254C554E24740037AE1CE854F4C401E19ABCDFFDF4740037AE1CE854F4C40
62943	18406	47.749994000000001	47.768211999999998	56.637045000000001	56.621271	Победы	0103000020E610000001000000050000001E19ABCDFFDF4740037AE1CE854F4C401E19ABCDFFDF4740488AC8B08A514C40873254C554E24740488AC8B08A514C40873254C554E24740037AE1CE854F4C401E19ABCDFFDF4740037AE1CE854F4C40
62313	18319	48.134751000000001	48.159680000000002	56.679321999999999	56.667392999999997	Пионерская	0103000020E61000000100000005000000390D51853F114840274A42226D554C40390D51853F11484006BAF605F4564C40A3E9EC647014484006BAF605F4564C40A3E9EC6470144840274A42226D554C40390D51853F114840274A42226D554C40
62977	18288	47.37086	47.395778999999997	56.836070999999997	56.819310999999999	Центральная	0103000020E6100000010000000500000081B2295778AF47406420CF2EDF684C4081B2295778AF47402711E15F046B4C40C7B8E2E2A8B247402711E15F046B4C40C7B8E2E2A8B247406420CF2EDF684C4081B2295778AF47406420CF2EDF684C40
63016	17884	48.039548000000003	48.061636999999997	56.521183999999998	56.507924000000003	Зеленая	0103000020E61000000100000005000000A54FABE80F054840406D54A703414C40A54FABE80F05484067994528B6424C409D9CA1B8E307484067994528B6424C409D9CA1B8E3074840406D54A703414C40A54FABE80F054840406D54A703414C40
63017	18191	47.710962000000002	47.745538000000003	56.680365000000002	56.672468000000002	Транспортная	0103000020E61000000100000005000000715985CD00DB4740A3CD716E13564C40715985CD00DB4740E92B483316574C406FF607CA6DDF4740E92B483316574C406FF607CA6DDF4740A3CD716E13564C40715985CD00DB4740A3CD716E13564C40
63174	18935	47.846741999999999	47.856588000000002	56.732849000000002	56.724770999999997	Орешкино	0103000020E610000001000000050000002713B70A62EC47406B0BCF4BC55C4C402713B70A62EC474002F4FBFECD5D4C40B212F3ACA4ED474002F4FBFECD5D4C40B212F3ACA4ED47406B0BCF4BC55C4C402713B70A62EC47406B0BCF4BC55C4C40
63055	18025	47.698403999999996	47.725155000000001	56.718266	56.701723999999999	Кедровой	0103000020E61000000100000005000000A2B2614D65D94740BE688F17D2594C40A2B2614D65D9474014EAE923F05B4C40F4C308E1D1DC474014EAE923F05B4C40F4C308E1D1DC4740BE688F17D2594C40A2B2614D65D94740BE688F17D2594C40
62947	18233	\N	\N	\N	\N	Школьная	\N
62950	17670	48.017898000000002	48.032666999999996	56.724198000000001	56.716704999999997	Школьная	0103000020E61000000100000005000000F8544E7B4A02484099F04BFDBC5B4C40F8544E7B4A02484010EA2285B25C4C404754A86E2E04484010EA2285B25C4C404754A86E2E04484099F04BFDBC5B4C40F8544E7B4A02484099F04BFDBC5B4C40
62187	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Шумелева	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
63098	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Чехова	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
62279	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Терешковой	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
62312	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Советская	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
62281	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Полевая	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
62280	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Мира	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
62311	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Лермонтова	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
62282	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Ленина	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
63096	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Коммунистическая	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
63054	16500	47.768796000000002	47.831085000000002	56.644509999999997	56.629098999999997	Гагарина	0103000020E61000000100000005000000D7A546E867E247402079E75086504C40D7A546E867E24740F4F8BD4D7F524C401C9947FE60EA4740F4F8BD4D7F524C401C9947FE60EA47402079E75086504C40D7A546E867E247402079E75086504C40
62996	17945	47.547792000000001	47.579889000000001	56.835721999999997	56.815286	Лесная	0103000020E6100000010000000500000056815A0C1EC647407E71A94A5B684C4056815A0C1EC647401B4641F0F86A4C40B32781CD39CA47401B4641F0F86A4C40B32781CD39CA47407E71A94A5B684C4056815A0C1EC647407E71A94A5B684C40
62296	17619	48.025184000000003	48.057091999999997	56.697786000000001	56.686965000000001	Пионерская	0103000020E61000000100000005000000F530B43A39034840923F1878EE574C40F530B43A39034840A7CD380D51594C407E6E68CA4E074840A7CD380D51594C407E6E68CA4E074840923F1878EE574C40F530B43A39034840923F1878EE574C40
62285	17097	47.639949999999999	47.686940999999997	56.685155999999999	56.667344	Фабричная	0103000020E61000000100000005000000A089B0E1E9D14740469737876B554C40A089B0E1E9D147403F541A31B3574C4009A4C4AEEDD747403F541A31B3574C4009A4C4AEEDD74740469737876B554C40A089B0E1E9D14740469737876B554C40
62189	17097	47.639949999999999	47.686940999999997	56.685155999999999	56.667344	Горького	0103000020E61000000100000005000000A089B0E1E9D14740469737876B554C40A089B0E1E9D147403F541A31B3574C4009A4C4AEEDD747403F541A31B3574C4009A4C4AEEDD74740469737876B554C40A089B0E1E9D14740469737876B554C40
63230	17702	48.089081	48.111241999999997	56.735975000000003	56.722715999999998	Центральная	0103000020E61000000100000005000000F5D89601670B4840E12538F5815C4C40F5D89601670B484039D6C56D345E4C4087F8872D3D0E484039D6C56D345E4C4087F8872D3D0E4840E12538F5815C4C40F5D89601670B4840E12538F5815C4C40
62191	17480	47.989215000000002	47.997326999999999	56.641708000000001	56.633426999999998	Победы	0103000020E6100000010000000500000038DBDC989EFE4740A2B3CC2214514C4038DBDC989EFE474071CADC7C23524C407A354069A8FF474071CADC7C23524C407A354069A8FF4740A2B3CC2214514C4038DBDC989EFE4740A2B3CC2214514C40
9894	17400	48.107478	48.136305	56.723812000000002	56.706923000000003	Комсомольская	0103000020E610000001000000050000000E85CFD6C10D484026E5EE737C5A4C400E85CFD6C10D4840E73922DFA55C4C4001A4367172114840E73922DFA55C4C4001A436717211484026E5EE737C5A4C400E85CFD6C10D484026E5EE737C5A4C40
63232	18106	47.749644000000004	47.782046000000001	56.723190000000002	56.710805999999998	Полевая	0103000020E6100000010000000500000042D2A755F4DF474079E6E5B0FB5A4C4042D2A755F4DF4740AA656B7D915C4C40DBFB54151AE44740AA656B7D915C4C40DBFB54151AE4474079E6E5B0FB5A4C4042D2A755F4DF474079E6E5B0FB5A4C40
63380	58103	47.954334000000003	47.974932000000003	56.770913999999998	56.764130999999999	Аксаркино	0103000020E61000000100000005000000FEBAD39D27FA47400D6E6B0BCF614C40FEBAD39D27FA4740A703594FAD624C4075E95F92CAFC4740A703594FAD624C4075E95F92CAFC47400D6E6B0BCF614C40FEBAD39D27FA47400D6E6B0BCF614C40
62190	17197	48.202483999999998	48.236476000000003	56.723373000000002	56.709265000000002	Фабричная	0103000020E610000001000000050000004CFBE6FEEA19484046990D32C95A4C404CFBE6FEEA1948409BE7887C975C4C40FB2477D8441E48409BE7887C975C4C40FB2477D8441E484046990D32C95A4C404CFBE6FEEA19484046990D32C95A4C40
63015	16427	49.926566999999999	49.962373999999997	56.659874000000002	56.637143999999999	Свободы	0103000020E61000000100000005000000C34659BF99F64840DB6B41EF8D514C40C34659BF99F6484088BD50C076544C40A6423C122FFB484088BD50C076544C40A6423C122FFB4840DB6B41EF8D514C40C34659BF99F64840DB6B41EF8D514C40
63057	15619	49.694459999999999	49.724274999999999	56.812488000000002	56.795381999999996	Победы	0103000020E61000000100000005000000A930B610E4D84840DDE9CE13CF654C40A930B610E4D848403C32569BFF674C40BB270F0BB5DC48403C32569BFF674C40BB270F0BB5DC4840DDE9CE13CF654C40A930B610E4D84840DDE9CE13CF654C40
63135	58067	49.806686999999997	49.821508999999999	56.484614999999998	56.474260999999998	Клубная	0103000020E61000000100000005000000DE8D058541E7484056629E95B43C4C40DE8D058541E74840551344DD073E4C40512FF83427E94840551344DD073E4C40512FF83427E9484056629E95B43C4C40DE8D058541E7484056629E95B43C4C40
63108	15993	49.901198000000001	49.933357999999998	56.799137999999999	56.781069000000002	Русская Сенда	0103000020E610000001000000050000003D9CC0745AF34840B075A911FA634C403D9CC0745AF34840D47E6B274A664C40E0BA624678F74840D47E6B274A664C40E0BA624678F74840B075A911FA634C403D9CC0745AF34840B075A911FA634C40
63166	15738	49.961413	49.987139999999997	56.454487999999998	56.441608000000002	Советская	0103000020E610000001000000050000008179C8940FFB484074D3669C86384C408179C8940FFB48405436ACA92C3A4C406649809A5AFE48405436ACA92C3A4C406649809A5AFE484074D3669C86384C408179C8940FFB484074D3669C86384C40
62186	16121	49.812184000000002	49.853102999999997	56.523831000000001	56.508302	Клубная	0103000020E61000000100000005000000D02A33A5F5E74840E63E390A10414C40D02A33A5F5E74840C4D0EAE40C434C404B8FA67A32ED4840C4D0EAE40C434C404B8FA67A32ED4840E63E390A10414C40D02A33A5F5E74840E63E390A10414C40
63012	15262	49.598188	49.638854000000002	56.797994000000003	56.778543999999997	Советская	0103000020E61000000100000005000000096EA46C91CC48409E3F6D54A7634C40096EA46C91CC4840BE33DAAA24664C409B75C6F7C5D14840BE33DAAA24664C409B75C6F7C5D148409E3F6D54A7634C40096EA46C91CC48409E3F6D54A7634C40
62310	15262	49.598188	49.638854000000002	56.797994000000003	56.778543999999997	Парковая	0103000020E61000000100000005000000096EA46C91CC48409E3F6D54A7634C40096EA46C91CC4840BE33DAAA24664C409B75C6F7C5D14840BE33DAAA24664C409B75C6F7C5D148409E3F6D54A7634C40096EA46C91CC48409E3F6D54A7634C40
62997	15262	49.598188	49.638854000000002	56.797994000000003	56.778543999999997	Мичурина	0103000020E61000000100000005000000096EA46C91CC48409E3F6D54A7634C40096EA46C91CC4840BE33DAAA24664C409B75C6F7C5D14840BE33DAAA24664C409B75C6F7C5D148409E3F6D54A7634C40096EA46C91CC48409E3F6D54A7634C40
62276	15262	49.598188	49.638854000000002	56.797994000000003	56.778543999999997	Комсомольская	0103000020E61000000100000005000000096EA46C91CC48409E3F6D54A7634C40096EA46C91CC4840BE33DAAA24664C409B75C6F7C5D14840BE33DAAA24664C409B75C6F7C5D148409E3F6D54A7634C40096EA46C91CC48409E3F6D54A7634C40
62995	15431	49.697380000000003	49.719909000000001	56.859684999999999	56.842058999999999	Молодежная	0103000020E61000000100000005000000377172BF43D94840B726DD96C86B4C40377172BF43D948404EEE77280A6E4C404C8C65FA25DC48404EEE77280A6E4C404C8C65FA25DC4840B726DD96C86B4C40377172BF43D94840B726DD96C86B4C40
63225	15371	49.643166000000001	49.658194999999999	56.829044000000003	56.816473999999999	Школьная	0103000020E6100000010000000500000017F3734353D248406404543882684C4017F3734353D24840F778211D1E6A4C4003B2D7BB3FD44840F778211D1E6A4C4003B2D7BB3FD448406404543882684C4017F3734353D248406404543882684C40
63053	15904	49.889915999999999	49.913325999999998	56.851303000000001	56.832467000000001	Колхозная	0103000020E61000000100000005000000F4177AC4E8F14840E7FF55478E6A4C40F4177AC4E8F148404CFE277FF76C4C40124BCADDE7F448404CFE277FF76C4C40124BCADDE7F44840E7FF55478E6A4C40F4177AC4E8F14840E7FF55478E6A4C40
63049	15715	50.160846999999997	50.177484	56.562950999999998	56.553814000000003	Лопово	0103000020E6100000010000000500000071546EA29614494092088D60E3464C4071546EA296144940102043C70E484C4019C8B3CBB7164940102043C70E484C4019C8B3CBB716494092088D60E3464C4071546EA29614494092088D60E3464C40
63172	16294	49.969892999999999	49.990786999999997	56.614519999999999	56.606118000000002	Лом	0103000020E6100000010000000500000046CF2D7425FC48402BC24D46954D4C4046CF2D7425FC4840745E6397A84E4C40A626C11BD2FE4840745E6397A84E4C40A626C11BD2FE48402BC24D46954D4C4046CF2D7425FC48402BC24D46954D4C40
62158	15796	49.585414	49.616647999999998	56.941865999999997	56.912851000000003	Совхозная	0103000020E610000001000000050000006E4F90D8EECA48407A8F334DD8744C406E4F90D8EECA48406F9BA9108F784C4068925852EECE48406F9BA9108F784C4068925852EECE48407A8F334DD8744C406E4F90D8EECA48407A8F334DD8744C40
63056	15943	49.802850999999997	49.842925000000001	56.819153999999997	56.802159000000003	Школьная	0103000020E61000000100000005000000CB4752D2C3E6484096986725AD664C40CB4752D2C3E648409C31CC09DA684C408BFD65F7E4EB48409C31CC09DA684C408BFD65F7E4EB484096986725AD664C40CB4752D2C3E6484096986725AD664C40
62243	15653	50.04889	50.076514000000003	56.572305	56.558864	Мира	0103000020E61000000100000005000000FC8C0B0742064940B47405DB88474C40FC8C0B07420649402C2B4D4A41494C40D4D7F335CB0949402C2B4D4A41494C40D4D7F335CB094940B47405DB88474C40FC8C0B0742064940B47405DB88474C40
63013	16390	49.833177999999997	49.856310000000001	56.664707	56.648364999999998	Советская	0103000020E6100000010000000500000093DFA293A5EA48407E6FD39FFD524C4093DFA293A5EA48400D36751E15554C406F9EEA909BED48400D36751E15554C406F9EEA909BED48407E6FD39FFD524C4093DFA293A5EA48407E6FD39FFD524C40
63087	15224	49.723115999999997	49.743364	56.723284	56.716833000000001	Заречная	0103000020E610000001000000050000006F9BA9108FDC4840C7D8092FC15B4C406F9BA9108FDC48402BDCF291945C4C400A83328D26DF48402BDCF291945C4C400A83328D26DF4840C7D8092FC15B4C406F9BA9108FDC4840C7D8092FC15B4C40
62994	15168	49.156880999999998	49.190325999999999	56.814881999999997	56.802627000000001	Коммунистическая	0103000020E61000000100000005000000902E36AD149448407CF1457BBC664C40902E36AD14944840AE0CAA0D4E684C400CCA349A5C984840AE0CAA0D4E684C400CCA349A5C9848407CF1457BBC664C40902E36AD149448407CF1457BBC664C40
63019	14887	49.066716999999997	49.09064	56.826587000000004	56.820847999999998	Центральная	0103000020E610000001000000050000002A8BC22E8A884840567E198C11694C402A8BC22E8A8848403E26529ACD694C40CFDA6D179A8B48403E26529ACD694C40CFDA6D179A8B4840567E198C11694C402A8BC22E8A884840567E198C11694C40
62961	14949	49.077910000000003	49.095778000000003	56.768329000000001	56.758871999999997	Рыбакова	0103000020E61000000100000005000000040473F4F8894840D0ECBAB722614C40040473F4F8894840C1C8CB9A58624C4091D61874428C4840C1C8CB9A58624C4091D61874428C4840D0ECBAB722614C40040473F4F8894840D0ECBAB722614C40
63167	14792	48.763275999999998	48.786316999999997	56.836686999999998	56.827345000000001	Тумьюмучаш	0103000020E610000001000000050000002DE92807B36148402BC1E270E6694C402DE92807B361484082FE428F186B4C40F8A41309A664484082FE428F186B4C40F8A41309A66448402BC1E270E6694C402DE92807B36148402BC1E270E6694C40
63052	14694	48.913536999999998	48.939228999999997	56.878709000000001	56.86121	Молодежная	0103000020E61000000100000005000000CD57C9C7EE7448407C7E18213C6E4C40CD57C9C7EE744840B6D9588979704C40363AE7A738784840B6D9588979704C40363AE7A7387848407C7E18213C6E4C40CD57C9C7EE7448407C7E18213C6E4C40
63169	14652	48.915827	48.934368999999997	56.712035999999998	56.704644999999999	Рубочая	0103000020E610000001000000050000009BE5B2D1397548401C25AFCE315A4C409BE5B2D1397548408EC9E2FE235B4C40B7B24467997748408EC9E2FE235B4C40B7B24467997748401C25AFCE315A4C409BE5B2D1397548401C25AFCE315A4C40
63051	14550	49.125906999999998	49.152327	56.674129000000001	56.664796000000003	Школьная	0103000020E6100000010000000500000032AB77B81D9048407D410B0918554C4032AB77B81D9048408124ECDB49564C401EA67D737F9348408124ECDB49564C401EA67D737F9348407D410B0918554C4032AB77B81D9048407D410B0918554C40
63168	14599	49.084603000000001	49.109045999999999	56.691631999999998	56.681229999999999	Починок	0103000020E610000001000000050000005E126745D48A4840EC866D8B32574C405E126745D48A4840FC6EBA6587584C403BE12538F58D4840FC6EBA6587584C403BE12538F58D4840EC866D8B32574C405E126745D48A4840EC866D8B32574C40
62185	14314	48.894635999999998	48.928359	56.824252000000001	56.796968999999997	Степана Лебедева	0103000020E6100000010000000500000081E9B46E837248408176871403664C4081E9B46E83724840D0D4EB1681694C4040F9BB77D4764840D0D4EB1681694C4040F9BB77D47648408176871403664C4081E9B46E837248408176871403664C40
63229	58084	49.143371000000002	49.174424999999999	56.757795999999999	56.749288	Зеленая	0103000020E61000000100000005000000F0181EFB5992484083A44FABE85F4C40F0181EFB5992484012859675FF604C406A4DF38E5396484012859675FF604C406A4DF38E5396484083A44FABE85F4C40F0181EFB5992484083A44FABE85F4C40
63170	14853	48.784413000000001	48.804319999999997	56.865957999999999	56.854709	Конганур	0103000020E6100000010000000500000054C72AA567644840664CC11A676D4C4054C72AA567644840D3DA34B6D76E4C4065C22FF5F3664840D3DA34B6D76E4C4065C22FF5F3664840664CC11A676D4C4054C72AA567644840664CC11A676D4C40
62992	14503	48.812683	48.826965999999999	56.798231000000001	56.783397000000001	Набережная	0103000020E61000000100000005000000F1811DFF056848406B64575A46644C40F1811DFF05684840A2D3F36E2C664C40B4739A05DA694840A2D3F36E2C664C40B4739A05DA6948406B64575A46644C40F1811DFF056848406B64575A46644C40
63227	15121	49.136876000000001	49.158785999999999	56.854311000000003	56.847650999999999	Ивансола	0103000020E61000000100000005000000BCCD1B2785914840FAB5F5D37F6C4C40BCCD1B278591484079CE16105A6D4C40058882195394484079CE16105A6D4C400588821953944840FAB5F5D37F6C4C40BCCD1B2785914840FAB5F5D37F6C4C40
63223	14763	48.746980000000001	48.767353999999997	56.805131000000003	56.797052999999998	Школьная	0103000020E610000001000000050000000F62670A9D5F4840DF162CD505664C400F62670A9D5F484076FF58880E674C40363AE7A73862484076FF58880E674C40363AE7A738624840DF162CD505664C400F62670A9D5F4840DF162CD505664C40
62948	15066	49.243129000000003	49.264175999999999	56.835706999999999	56.825074999999998	Центральная	0103000020E61000000100000005000000C7DADFD91E9F4840A4DFBE0E9C694C40C7DADFD91E9F4840E6046D72F86A4C40AD31E884D0A14840E6046D72F86A4C40AD31E884D0A14840A4DFBE0E9C694C40C7DADFD91E9F4840A4DFBE0E9C694C40
63219	14277	47.022035000000002	47.051139999999997	56.325150000000001	56.310907	Школьная	0103000020E61000000100000005000000062FFA0AD28247407A8CF2CCCB274C40062FFA0AD2824740AF25E4839E294C403BC269C18B864740AF25E4839E294C403BC269C18B8647407A8CF2CCCB274C40062FFA0AD28247407A8CF2CCCB274C40
63222	14188	46.906844	46.929499999999997	56.749341999999999	56.730331	Механизаторов	0103000020E610000001000000050000007349D57613744740A320787C7B5D4C407349D5761374474076C24B70EA5F4C40E5D022DBF976474076C24B70EA5F4C40E5D022DBF9764740A320787C7B5D4C407349D57613744740A320787C7B5D4C40
63088	13928	47.109000999999999	47.132796999999997	56.585462999999997	56.570231999999997	Зеленая	0103000020E610000001000000050000009B1DA9BEF38D4740FB90B75CFD484C409B1DA9BEF38D47404F029B73F04A4C40E200FA7DFF9047404F029B73F04A4C40E200FA7DFF904740FB90B75CFD484C409B1DA9BEF38D4740FB90B75CFD484C40
63164	14091	46.632075999999998	46.658002000000003	56.938851	56.925620000000002	Коммунистическая	0103000020E61000000100000005000000124BCADDE7504740034356B77A764C40124BCADDE7504740906802452C784C40EF59D76839544740906802452C784C40EF59D76839544740034356B77A764C40124BCADDE7504740034356B77A764C40
63162	13700	46.746333	46.765439999999998	56.423675000000003	56.415787999999999	Ветеранов	0103000020E610000001000000050000007976F9D6875F4740DD088B8A38354C407976F9D6875F474000917EFB3A364C406E861BF0F961474000917EFB3A364C406E861BF0F9614740DD088B8A38354C407976F9D6875F4740DD088B8A38354C40
63163	14032	46.463669000000003	46.49935	56.720438999999999	56.705717	Железнодорожная	0103000020E61000000100000005000000A3957B81593B4740999D45EF545A4C40A3957B81593B4740A8E15B58375C4C40F9A067B3EA3F4740A8E15B58375C4C40F9A067B3EA3F4740999D45EF545A4C40A3957B81593B4740999D45EF545A4C40
63122	13989	46.634107	46.657291999999998	56.689635000000003	56.680301	Советская	0103000020E6100000010000000500000014950D6B2A514740D237691A14574C4014950D6B2A514740A796ADF545584C4012F6ED2422544740A796ADF545584C4012F6ED2422544740D237691A14574C4014950D6B2A514740D237691A14574C40
63085	13898	47.141717999999997	47.167696999999997	56.565486	56.556468000000002	Центральная	0103000020E6100000010000000500000094A0BFD023924740A1A2EA573A474C4094A0BFD023924740452C62D861484C409351651877954740452C62D861484C409351651877954740A1A2EA573A474C4094A0BFD023924740A1A2EA573A474C40
62273	13450	46.843046000000001	46.898902999999997	56.802616999999998	56.768931000000002	Садовая	0103000020E6100000010000000500000006836BEEE86B4740B7F0BC546C624C4006836BEEE86B4740581B6327BC664C405DA3E5400F734740581B6327BC664C405DA3E5400F734740B7F0BC546C624C4006836BEEE86B4740B7F0BC546C624C40
62309	13450	46.843046000000001	46.898902999999997	56.802616999999998	56.768931000000002	Мира	0103000020E6100000010000000500000006836BEEE86B4740B7F0BC546C624C4006836BEEE86B4740581B6327BC664C405DA3E5400F734740581B6327BC664C405DA3E5400F734740B7F0BC546C624C4006836BEEE86B4740B7F0BC546C624C40
63092	13647	46.842973999999998	46.863438000000002	56.401668999999998	56.390300000000003	Школьная	0103000020E610000001000000050000006CB07092E66B47407DD0B359F5314C406CB07092E66B47409468C9E369334C40D40FEA22856E47409468C9E369334C40D40FEA22856E47407DD0B359F5314C406CB07092E66B47407DD0B359F5314C40
62275	57931	46.907679999999999	46.965432	56.449478999999997	56.422415000000001	Советская	0103000020E61000000100000005000000DC9DB5DB2E744740802BD9B111364C40DC9DB5DB2E744740909E228788394C4085419946937B4740909E228788394C4085419946937B4740802BD9B111364C40DC9DB5DB2E744740802BD9B111364C40
63117	13733	47.065001000000002	47.080713000000003	56.915058000000002	56.908034999999998	Большекибеевская	0103000020E61000000100000005000000899AE8F351884740CA4FAA7D3A744C40899AE8F351884740BAF8DB9E20754C4058AEB7CD548A4740BAF8DB9E20754C4058AEB7CD548A4740CA4FAA7D3A744C40899AE8F351884740CA4FAA7D3A744C40
63050	13619	46.770498000000003	46.790899000000003	56.410485000000001	56.399532000000001	Школьная	0103000020E6100000010000000500000014D1AFAD9F6247404DDA54DD23334C4014D1AFAD9F624740D13FC1C58A344C4035B8AD2D3C654740D13FC1C58A344C4035B8AD2D3C6547404DDA54DD23334C4014D1AFAD9F6247404DDA54DD23334C40
63221	13558	46.707912	46.740817	56.433570000000003	56.418308000000003	Лесная	0103000020E61000000100000005000000153944DC9C5A4740DDD3D51D8B354C40153944DC9C5A47406C43C5387F374C4011A96917D35E47406C43C5387F374C4011A96917D35E4740DDD3D51D8B354C40153944DC9C5A4740DDD3D51D8B354C40
63090	14218	46.913176999999997	46.936748999999999	56.273584999999997	56.262182000000003	Алатайкинская	0103000020E61000000100000005000000CD3AE3FBE2744740C9CC052E8F214C40CD3AE3FBE27447408CD651D504234C40C5C72764E77747408CD651D504234C40C5C72764E7774740C9CC052E8F214C40CD3AE3FBE2744740C9CC052E8F214C40
63118	14127	47.000700000000002	47.015881999999998	56.676215999999997	56.663916	Лесная	0103000020E61000000100000005000000B98D06F01680474044A51133FB544C40B98D06F0168047401684F23E8E564C402B4CDF6B088247401684F23E8E564C402B4CDF6B0882474044A51133FB544C40B98D06F01680474044A51133FB544C40
62300	57933	47.954467999999999	47.997390000000003	56.650368999999998	56.641713000000003	Молодежная	0103000020E610000001000000050000000D8AE6012CFA47408335CEA623524C400D8AE6012CFA474086AA984A3F534C40C1ADBB79AAFF474086AA984A3F534C40C1ADBB79AAFF47408335CEA623524C400D8AE6012CFA47408335CEA623524C40
63000	18667	47.837480999999997	47.843032000000001	56.553719000000001	56.550291000000001	Садовая	0103000020E61000000100000005000000BC02D19332EB47403E247CEF6F464C40BC02D19332EB47404016A243E0464C40A1BDFA78E8EB47404016A243E0464C40A1BDFA78E8EB47403E247CEF6F464C40BC02D19332EB47403E247CEF6F464C40
62188	57927	47.998800000000003	48.020530000000001	56.666345	56.650269999999999	Школьная	0103000020E61000000100000005000000569FABADD8FF4740F3C81F0C3C534C40569FABADD8FF4740336DFFCA4A554C401F4B1FBAA0024840336DFFCA4A554C401F4B1FBAA0024840F3C81F0C3C534C40569FABADD8FF4740F3C81F0C3C534C40
63210	58081	47.894154999999998	47.910100999999997	56.592680000000001	56.586891000000001	Нолька	0103000020E610000001000000050000000647C9AB73F247408BA8893E1F4B4C400647C9AB73F24740247F30F0DC4B4C40488787307EF44740247F30F0DC4B4C40488787307EF447408BA8893E1F4B4C400647C9AB73F247408BA8893E1F4B4C40
62244	17855	47.973934999999997	47.993563000000002	56.557698000000002	56.542484999999999	Лесная	0103000020E6100000010000000500000002B7EEE6A9FC474008C9022670454C4002B7EEE6A9FC4740B685E7A562474C4001C287122DFF4740B685E7A562474C4001C287122DFF474008C9022670454C4002B7EEE6A9FC474008C9022670454C40
63101	18709	47.798682999999997	47.813324999999999	56.575875000000003	56.571586000000003	Зеленая	0103000020E61000000100000005000000826F9A3E3BE64740FD6CE4BA29494C40826F9A3E3BE64740C1CAA145B6494C4075029A081BE84740C1CAA145B6494C4075029A081BE84740FD6CE4BA29494C40826F9A3E3BE64740FD6CE4BA29494C40
63119	13143	47.891739000000001	47.908295000000003	56.198003999999997	56.180903000000001	Шимшургинская	0103000020E61000000100000005000000ACC8E88024F24740C85F5AD427174C40ACC8E88024F24740143DF03158194C40670FB40243F44740143DF03158194C40670FB40243F44740C85F5AD427174C40ACC8E88024F24740C85F5AD427174C40
62184	13371	48.233457999999999	48.268915	56.236145999999998	56.207572999999996	Школьная	0103000020E61000000100000005000000AA7EA5F3E11D48402C4487C0911A4C40AA7EA5F3E11D4840658A39083A1E4C40B13385CE6B224840658A39083A1E4C40B13385CE6B2248402C4487C0911A4C40AA7EA5F3E11D48402C4487C0911A4C40
63161	13425	48.495128000000001	48.516480999999999	56.288851000000001	56.280441000000003	Валерия Волкова	0103000020E61000000100000005000000BDAAB35A603F484091BA9D7DE5234C40BDAAB35A603F48405D35CF11F9244C40B000A60C1C4248405D35CF11F9244C40B000A60C1C42484091BA9D7DE5234C40BDAAB35A603F484091BA9D7DE5234C40
63160	13058	47.836213999999998	47.863684999999997	56.276369000000003	56.261243	Школьная	0103000020E610000001000000050000008A3A730F09EB47408BA71E6970214C408A3A730F09EB47406A50340F60234C40DB85E63A8DEE47406A50340F60234C40DB85E63A8DEE47408BA71E6970214C408A3A730F09EB47408BA71E6970214C40
62956	12428	48.233449	48.274681999999999	56.324435999999999	56.298611999999999	Железнодорожная	0103000020E61000000100000005000000572426A8E11D4840B91803EB38264C40572426A8E11D484091D26C1E87294C4062669FC72823484091D26C1E87294C4062669FC728234840B91803EB38264C40572426A8E11D4840B91803EB38264C40
62242	12428	48.233449	48.274681999999999	56.324435999999999	56.298611999999999	Гвардейская	0103000020E61000000100000005000000572426A8E11D4840B91803EB38264C40572426A8E11D484091D26C1E87294C4062669FC72823484091D26C1E87294C4062669FC728234840B91803EB38264C40572426A8E11D4840B91803EB38264C40
63155	52796	48.034553000000002	48.050310000000003	56.036406999999997	56.018025999999999	Мюшультурская	0103000020E61000000100000005000000467D923B6C044840253D0CAD4E024C40467D923B6C044840382C0DFCA8044C40B554DE8E70064840382C0DFCA8044C40B554DE8E70064840253D0CAD4E024C40467D923B6C044840253D0CAD4E024C40
62960	13238	47.624499	47.651187999999998	56.175001000000002	56.154977000000002	Школьная	0103000020E610000001000000050000003EB14E95EFCF4740EC504D49D6134C403EB14E95EFCF474037E2C96E66164C4019C6DD205AD3474037E2C96E66164C4019C6DD205AD34740EC504D49D6134C403EB14E95EFCF4740EC504D49D6134C40
63080	13076	47.840823	47.885207999999999	56.149586999999997	56.132955000000003	Селиванова	0103000020E61000000100000005000000C05C8B16A0EB47407B6B60AB04114C40C05C8B16A0EB47401074B4AA25134C402B14E97E4EF147401074B4AA25134C402B14E97E4EF147407B6B60AB04114C40C05C8B16A0EB47407B6B60AB04114C40
62990	12954	48.088461000000002	48.116309000000001	56.170791000000001	56.156725999999999	Школьная	0103000020E6100000010000000500000059FCA6B0520B48406937FA980F144C4059FCA6B0520B4840BFB9BF7ADC154C40809D9B36E30E4840BFB9BF7ADC154C40809D9B36E30E48406937FA980F144C4059FCA6B0520B48406937FA980F144C40
63158	13277	47.451141999999997	47.463529999999999	56.259563	56.249256000000003	Новая	0103000020E610000001000000050000000FED6305BFB94740782AE09EE71F4C400FED6305BFB947403620425C39214C40815B77F354BB47403620425C39214C40815B77F354BB4740782AE09EE71F4C400FED6305BFB94740782AE09EE71F4C40
63044	58057	48.005259000000002	48.049025	56.112958999999996	56.099797000000002	Центральная	0103000020E610000001000000050000003D81B053AC004840959EE925C60C4C403D81B053AC004840F964C570750E4C40DCD7817346064840F964C570750E4C40DCD7817346064840959EE925C60C4C403D81B053AC004840959EE925C60C4C40
62278	12360	48.345998999999999	48.363937999999997	56.341158	56.319468999999998	Школьная	0103000020E610000001000000050000006FB9FAB1492C4840FC8A355CE4284C406FB9FAB1492C48406762BA10AB2B4C40C5E23785952E48406762BA10AB2B4C40C5E23785952E4840FC8A355CE4284C406FB9FAB1492C4840FC8A355CE4284C40
63204	12872	48.175894	48.197454	56.165283000000002	56.155577999999998	Малокужмарская	0103000020E6100000010000000500000004C8D0B18316484011FDDAFAE9134C4004C8D0B183164840DACA4BFE27154C40713B342C46194840DACA4BFE27154C40713B342C4619484011FDDAFAE9134C4004C8D0B18316484011FDDAFAE9134C40
63007	12780	48.051765000000003	48.078831000000001	56.154245000000003	56.135032000000002	Центральная	0103000020E61000000100000005000000EA094B3CA0064840EDF483BA48114C40EA094B3CA00648402849D74CBE134C409B745B22170A48402849D74CBE134C409B745B22170A4840EDF483BA48114C40EA094B3CA0064840EDF483BA48114C40
62989	12612	48.006740999999998	48.039726999999999	56.046444000000001	56.023418999999997	Центральная	0103000020E610000001000000050000006B459BE3DC004840718DCF64FF024C406B459BE3DC004840378C82E0F1054C4054E23AC615054840378C82E0F1054C4054E23AC615054840718DCF64FF024C406B459BE3DC004840718DCF64FF024C40
62270	12022	48.300832	48.348576999999999	56.169733999999998	56.137524999999997	Центральная	0103000020E610000001000000050000008ECBB8A981264840F2B0506B9A114C408ECBB8A9812648407782FDD7B9154C40A391CF2B9E2C48407782FDD7B9154C40A391CF2B9E2C4840F2B0506B9A114C408ECBB8A981264840F2B0506B9A114C40
63106	12022	48.300832	48.348576999999999	56.169733999999998	56.137524999999997	Первомайская	0103000020E610000001000000050000008ECBB8A981264840F2B0506B9A114C408ECBB8A9812648407782FDD7B9154C40A391CF2B9E2C48407782FDD7B9154C40A391CF2B9E2C4840F2B0506B9A114C408ECBB8A981264840F2B0506B9A114C40
62308	12022	48.300832	48.348576999999999	56.169733999999998	56.137524999999997	Машиностроителей	0103000020E610000001000000050000008ECBB8A981264840F2B0506B9A114C408ECBB8A9812648407782FDD7B9154C40A391CF2B9E2C48407782FDD7B9154C40A391CF2B9E2C4840F2B0506B9A114C408ECBB8A981264840F2B0506B9A114C40
62271	12022	48.300832	48.348576999999999	56.169733999999998	56.137524999999997	Ленина	0103000020E610000001000000050000008ECBB8A981264840F2B0506B9A114C408ECBB8A9812648407782FDD7B9154C40A391CF2B9E2C48407782FDD7B9154C40A391CF2B9E2C4840F2B0506B9A114C408ECBB8A981264840F2B0506B9A114C40
62993	13178	47.705553999999999	47.772469999999998	56.170110000000001	56.152956000000003	Молодежная	0103000020E61000000100000005000000EFC7ED974FDA47400EDDEC0F94134C40EFC7ED974FDA47407D5C1B2AC6154C401092054CE0E247407D5C1B2AC6154C401092054CE0E247400EDDEC0F94134C40EFC7ED974FDA47400EDDEC0F94134C40
63046	12993	47.802303000000002	47.832118000000001	56.151606999999998	56.133603000000001	Заводская	0103000020E61000000100000005000000C93D5DDDB1E64740E1D231E719114C40C93D5DDDB1E647401E6CB1DB67134C40DB34B6D782EA47401E6CB1DB67134C40DB34B6D782EA4740E1D231E719114C40C93D5DDDB1E64740E1D231E719114C40
62957	12499	48.201981000000004	48.225363999999999	55.982064000000001	55.970720999999998	Молодежная	0103000020E61000000100000005000000EAB46E83DA1948402C45F29540FC4B40EAB46E83DA1948401B4AED45B4FD4B400ED940BAD81C48401B4AED45B4FD4B400ED940BAD81C48402C45F29540FC4B40EAB46E83DA1948402C45F29540FC4B40
63121	12758	47.992386000000003	48.013711999999998	56.075031000000003	56.052410999999999	Малое Иркино	0103000020E610000001000000050000000F81238106FF4740AF795567B5064C400F81238106FF4740D597A59D9A094C4008C89750C1014840D597A59D9A094C4008C89750C1014840AF795567B5064C400F81238106FF4740AF795567B5064C40
63159	11963	48.343879000000001	48.358989000000001	56.121943000000002	56.107532999999997	Куйбышева	0103000020E61000000100000005000000FE63213A042C4840D11E2FA4C30D4C40FE63213A042C4840F27C06D49B0F4C40D74FFF59F32D4840F27C06D49B0F4C40D74FFF59F32D4840D11E2FA4C30D4C40FE63213A042C4840D11E2FA4C30D4C40
63005	11587	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	Советская	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
63008	11587	48.001126999999997	48.122283000000003	55.989195000000002	55.939005000000002	Набережная	0103000020E610000001000000050000004012F6ED24004840E7E3DA5031F84B404012F6ED24004840F12E17F19DFE4B40ABED26F8A60F4840F12E17F19DFE4B40ABED26F8A60F4840E7E3DA5031F84B404012F6ED24004840E7E3DA5031F84B40
63248	58087	47.238197	48.609788999999999	56.480896999999999	55.913030999999997	Чуваш-Отарская	0103000020E61000000100000005000000AE80423D7D9E4740F99D2633DEF44B40AE80423D7D9E47404CDF6B088E3D4C40F33AE2900D4E48404CDF6B088E3D4C40F33AE2900D4E4840F99D2633DEF44B40AE80423D7D9E4740F99D2633DEF44B40
63078	11266	46.208440000000003	46.231454999999997	56.075221999999997	56.067659999999997	Яшгутинская	0103000020E61000000100000005000000D1967329AE1A4740A99F3715A9084C40D1967329AE1A474048F8DEDFA0094C4072BF4351A01D474048F8DEDFA0094C4072BF4351A01D4740A99F3715A9084C40D1967329AE1A4740A99F3715A9084C40
63201	10170	46.435938	46.469462999999998	56.138413	56.125484999999998	Юнго-Кушерга	0103000020E61000000100000005000000B58AFED0CC374740BC9179E40F104C40B58AFED0CC374740AE2B6684B7114C404DD7135D173C4740AE2B6684B7114C404DD7135D173C4740BC9179E40F104C40B58AFED0CC374740BC9179E40F104C40
63198	10713	46.722025000000002	46.739111000000001	56.209085000000002	56.202106000000001	Вознесенская	0103000020E610000001000000050000007CF2B0506B5C4740A629029CDE194C407CF2B0506B5C4740C68A1A4CC31A4C40938E72309B5E4740C68A1A4CC31A4C40938E72309B5E4740A629029CDE194C407CF2B0506B5C4740A629029CDE194C40
63070	10474	46.598452000000002	46.614567999999998	56.269610999999998	56.255958	Архипкинская	0103000020E61000000100000005000000E71C3C139A4C47402593533BC3204C40E71C3C139A4C474028D2FD9C82224C4085950A2AAA4E474028D2FD9C82224C4085950A2AAA4E47402593533BC3204C40E71C3C139A4C47402593533BC3204C40
62954	11449	46.466804000000003	46.477764000000001	56.251702000000002	56.242004000000001	Центральная	0103000020E610000001000000050000002DD2C43BC03B474027C0B0FCF91E4C402DD2C43BC03B47403D2B69C537204C40639AE95E273D47403D2B69C537204C40639AE95E273D474027C0B0FCF91E4C402DD2C43BC03B474027C0B0FCF91E4C40
62959	11543	46.597779000000003	46.609986999999997	56.239978000000001	56.233344000000002	Центральная	0103000020E61000000100000005000000289EB305844C4740E25B5837DE1D4C40289EB305844C474037E15E99B71E4C4019FED30D144E474037E15E99B71E4C4019FED30D144E4740E25B5837DE1D4C40289EB305844C4740E25B5837DE1D4C40
63082	9867	46.592469999999999	46.610131000000003	56.198089000000003	56.190241	Тушналы	0103000020E6100000010000000500000039EE940ED64B4740DEAD2CD159184C4039EE940ED64B47404359F8FA5A194C404DA3C9C5184E47404359F8FA5A194C404DA3C9C5184E4740DEAD2CD159184C4039EE940ED64B4740DEAD2CD159184C40
63120	11399	46.450617000000001	46.476469999999999	56.301454	56.284028999999997	Карла Маркса	0103000020E61000000100000005000000C5025FD1AD394740CB0EF10F5B244C40C5025FD1AD394740CB9F6F0B96264C4037C30DF8FC3C4740CB9F6F0B96264C4037C30DF8FC3C4740CB0EF10F5B244C40C5025FD1AD394740CB0EF10F5B244C40
63072	11028	46.619346999999998	46.634914999999999	56.532344999999999	56.520856999999999	Больничная	0103000020E6100000010000000500000017F032C3464F474043723271AB424C4017F032C3464F4740359886E123444C40B35E0CE544514740359886E123444C40B35E0CE54451474043723271AB424C4017F032C3464F474043723271AB424C40
63115	10612	46.773479999999999	46.800555000000003	56.197122999999998	56.185988000000002	Лесная	0103000020E61000000100000005000000170E84640163474067B96C74CE174C40170E8464016347400B2593533B194C401CD31396786647400B2593533B194C401CD313967866474067B96C74CE174C40170E84640163474067B96C74CE174C40
63821	58135	46.043616999999998	46.813769999999998	56.637298000000001	56.017885	Пичужкино	0103000020E610000001000000050000005A46EA3D95054740630B410E4A024C405A46EA3D9505474032E719FB92514C40A33B889D2968474032E719FB92514C40A33B889D29684740630B410E4A024C405A46EA3D95054740630B410E4A024C40
63149	10093	46.353904	46.377090000000003	56.160209999999999	56.152500000000003	Пертюково	0103000020E6100000010000000500000038F6ECB94C2D4740EC51B81E85134C4038F6ECB94C2D4740FF3EE3C281144C4007D3307C44304740FF3EE3C281144C4007D3307C44304740EC51B81E85134C4038F6ECB94C2D4740EC51B81E85134C40
63150	10319	46.424574999999997	46.438310000000001	56.230491999999998	56.225487999999999	Пертнуры	0103000020E610000001000000050000007FD93D7958364740FAD170CADC1C4C407FD93D7958364740ACFE08C3801D4C4040C1C58A1A384740ACFE08C3801D4C4040C1C58A1A384740FAD170CADC1C4C407FD93D7958364740FAD170CADC1C4C40
63153	9799	46.541831999999999	46.559204999999999	56.140158	56.132975999999999	Паратмары	0103000020E6100000010000000500000090F63FC05A4547409293895B05114C4090F63FC05A454740EA2285B2F0114C403D61890794474740EA2285B2F0114C403D618907944747409293895B05114C4090F63FC05A4547409293895B05114C40
62955	11163	46.294255999999997	46.310650000000003	56.185462000000001	56.172345	Новая	0103000020E610000001000000050000006D533C2EAA2547408750A5660F164C406D533C2EAA2547404C530438BD174C404F401361C32747404C530438BD174C404F401361C32747408750A5660F164C406D533C2EAA2547408750A5660F164C40
63069	10404	46.523927999999998	46.532964999999997	56.293906	56.285283	Красная	0103000020E61000000100000005000000B6BA9C1210434740698D412784244C40B6BA9C1210434740910C39B69E254C40D174763238444740910C39B69E254C40D174763238444740698D412784244C40B6BA9C1210434740698D412784244C40
62987	10939	46.506833	46.560310000000001	56.420707999999998	56.381694000000003	Советская	0103000020E610000001000000050000004CC45BE7DF4047402B8A5759DB304C404CC45BE7DF40474031957EC2D9354C4096CFF23CB847474031957EC2D9354C4096CFF23CB84747402B8A5759DB304C404CC45BE7DF4047402B8A5759DB304C40
62982	10939	46.506833	46.560310000000001	56.420707999999998	56.381694000000003	Заволжская	0103000020E610000001000000050000004CC45BE7DF4047402B8A5759DB304C404CC45BE7DF40474031957EC2D9354C4096CFF23CB847474031957EC2D9354C4096CFF23CB84747402B8A5759DB304C404CC45BE7DF4047402B8A5759DB304C40
63142	11200	46.080312999999997	46.097723000000002	56.103296	56.093822000000003	Школьная	0103000020E61000000100000005000000C93846B2470A47409AD2FA5B020C4C40C93846B2470A474060E7A6CD380D4C409488F02F820C474060E7A6CD380D4C409488F02F820C47409AD2FA5B020C4C40C93846B2470A47409AD2FA5B020C4C40
63165	10531	46.579920000000001	46.604112000000001	56.278368	56.268431	Нижнешелаболкинская	0103000020E61000000100000005000000EE258DD13A4A4740C51D6FF25B224C40EE258DD13A4A474060200890A1234C40828FC18A534D474060200890A1234C40828FC18A534D4740C51D6FF25B224C40EE258DD13A4A4740C51D6FF25B224C40
63199	11364	46.478383999999998	46.500033000000002	56.312049999999999	56.307017000000002	Набережная	0103000020E61000000100000005000000FF76D9AF3B3D4740742843554C274C40FF76D9AF3B3D4740C05B2041F1274C40DCF5D21401404740C05B2041F1274C40DCF5D21401404740742843554C274C40FF76D9AF3B3D4740742843554C274C40
63006	10844	46.223216999999998	46.243582000000004	56.212494999999997	56.198625	Центральная	0103000020E61000000100000005000000A374E95F921C47408195438B6C194C40A374E95F921C474021C84109331B4C4078F2E9B12D1F474021C84109331B4C4078F2E9B12D1F47408195438B6C194C40A374E95F921C47408195438B6C194C40
63083	11293	46.504866	46.511648000000001	56.264991999999999	56.259962999999999	Центральная	0103000020E61000000100000005000000616EF7729F404740C495B37746214C40616EF7729F404740CFD90242EB214C402B8881AE7D414740CFD90242EB214C402B8881AE7D414740C495B37746214C40616EF7729F404740C495B37746214C40
62952	11117	46.252394000000002	46.266677999999999	56.163825000000003	56.156635999999999	Центральная	0103000020E6100000010000000500000073DA53724E20474029B000A60C144C4073DA53724E20474034A2B437F8144C40064834812222474034A2B437F8144C40064834812222474029B000A60C144C4073DA53724E20474029B000A60C144C40
63045	10380	46.540672999999998	46.561038000000003	56.256717999999999	56.243254	Механизаторов	0103000020E61000000100000005000000446ADAC534454740834F73F2221F4C40446ADAC534454740B325AB22DC204C4019E8DA17D0474740B325AB22DC204C4019E8DA17D0474740834F73F2221F4C40446ADAC534454740834F73F2221F4C40
63071	10583	46.695390000000003	46.731143000000003	56.168340999999998	56.154535000000003	Центральная	0103000020E6100000010000000500000094FB1D8A025947402F8B89CDC7134C4094FB1D8A02594740B8C9A8328C154C4084D90418965D4740B8C9A8328C154C4084D90418965D47402F8B89CDC7134C4094FB1D8A025947402F8B89CDC7134C40
63151	10583	46.695390000000003	46.731143000000003	56.168340999999998	56.154535000000003	Верхняя	0103000020E6100000010000000500000094FB1D8A025947402F8B89CDC7134C4094FB1D8A02594740B8C9A8328C154C4084D90418965D4740B8C9A8328C154C4084D90418965D47402F8B89CDC7134C4094FB1D8A025947402F8B89CDC7134C40
63066	9782	46.651452999999997	46.670129000000003	56.129995999999998	56.117967999999998	Кожважи	0103000020E61000000100000005000000C7F0D8CF62534740BDFC4E93190F4C40C7F0D8CF625347402F4E7CB5A3104C40F48C7DC9C65547402F4E7CB5A3104C40F48C7DC9C6554740BDFC4E93190F4C40C7F0D8CF62534740BDFC4E93190F4C40
63193	10083	46.513553000000002	46.525796999999997	56.205185	56.198360000000001	Центральная	0103000020E61000000100000005000000A0E1CD1ABC414740D36A48DC63194C40A0E1CD1ABC4147409C508880431A4C40DEAAEB504D4347409C508880431A4C40DEAAEB504D434740D36A48DC63194C40A0E1CD1ABC414740D36A48DC63194C40
63062	10895	46.419203000000003	46.448227000000003	56.404702	56.392313000000001	Центральная	0103000020E610000001000000050000004BB1A371A8354740D865F84F37324C404BB1A371A83547401A506F46CD334C40941799805F3947401A506F46CD334C40941799805F394740D865F84F37324C404BB1A371A8354740D865F84F37324C40
63043	10242	46.336567000000002	46.352988000000003	56.232784000000002	56.221079000000003	Проезжая	0103000020E61000000100000005000000D8F4A0A0142B47408C6A11514C1C4C40D8F4A0A0142B47401B84B9DDCB1D4C40B3F0F5B52E2D47401B84B9DDCB1D4C40B3F0F5B52E2D47408C6A11514C1C4C40D8F4A0A0142B47408C6A11514C1C4C40
63048	10795	46.229765999999998	46.257514999999998	56.239578000000002	56.227184999999999	Приволжская	0103000020E61000000100000005000000CADDE7F8681D47402592E865141D4C40CADDE7F8681D4740A96BED7DAA1E4C405E9D6340F6204740A96BED7DAA1E4C405E9D6340F62047402592E865141D4C40CADDE7F8681D47402592E865141D4C40
62953	9961	46.448515	46.479092999999999	56.173192	56.164596000000003	Октябрьская	0103000020E61000000100000005000000FA6184F068394740B686527B11154C40FA6184F068394740E4F6CB272B164C400B5F5FEB523D4740E4F6CB272B164C400B5F5FEB523D4740B686527B11154C40FA6184F068394740B686527B11154C40
63042	9716	46.588875999999999	46.627485999999998	56.181434000000003	56.164797	Советская	0103000020E610000001000000050000001CB3EC49604B47404DBD6E1118154C401CB3EC49604B4740F530B43A39174C405359147651504740F530B43A39174C4053591476515047404DBD6E1118154C401CB3EC49604B47404DBD6E1118154C40
63194	11074	46.303086	46.317737999999999	56.216363999999999	56.208550000000002	Центральная	0103000020E610000001000000050000000FF0A485CB26474058CA32C4B11A4C400FF0A485CB2647401004C8D0B11B4C40255987A3AB2847401004C8D0B11B4C40255987A3AB28474058CA32C4B11A4C400FF0A485CB26474058CA32C4B11A4C40
63073	10773	46.188524000000001	46.300787	56.162812000000002	56.150339000000002	Центральная	0103000020E610000001000000050000006C41EF8D211847401C28F04E3E134C406C41EF8D21184740BCB20B06D7144C40EE073C3080264740BCB20B06D7144C40EE073C30802647401C28F04E3E134C406C41EF8D211847401C28F04E3E134C40
63146	9011	48.715341000000002	48.740377000000002	56.133983999999998	56.117682000000002	Красноармейская	0103000020E61000000100000005000000753E3C4B905B4840F8A92A34100F4C40753E3C4B905B4840F817416326114C40F5DA6CACC45E4840F817416326114C40F5DA6CACC45E4840F8A92A34100F4C40753E3C4B905B4840F8A92A34100F4C40
62269	9635	48.398560000000003	48.473874000000002	55.999994000000001	55.984214000000001	Советская	0103000020E6100000010000000500000034BF9A0304334840F7216FB9FAFD4B4034BF9A03043348401E19ABCDFFFF4B405D363AE7A73C48401E19ABCDFFFF4B405D363AE7A73C4840F7216FB9FAFD4B4034BF9A0304334840F7216FB9FAFD4B40
63114	9532	48.757669999999997	48.772114999999999	56.165678999999997	56.157654000000001	Клубная	0103000020E6100000010000000500000085949F54FB604840B30A9B012E144C4085949F54FB60484026512FF834154C4022E010AAD462484026512FF834154C4022E010AAD4624840B30A9B012E144C4085949F54FB604840B30A9B012E144C40
63040	8813	48.853214999999999	48.915702000000003	56.180041000000003	56.154901000000002	Школьная	0103000020E6100000010000000500000073BA2C26366D4840118FC4CBD3134C4073BA2C26366D484036785F950B174C40DF701FB93575484036785F950B174C40DF701FB935754840118FC4CBD3134C4073BA2C26366D4840118FC4CBD3134C40
62238	9300	48.319803999999998	48.370621999999997	55.936182000000002	55.909225999999997	Школьная	0103000020E61000000100000005000000A3906456EF28484021567F8461F44B40A3906456EF2848404C8DD0CFD4F74B40CC96AC8A702F48404C8DD0CFD4F74B40CC96AC8A702F484021567F8461F44B40A3906456EF28484021567F8461F44B40
62951	9171	48.770829999999997	48.793647999999997	56.072704999999999	56.061186999999997	Советская	0103000020E610000001000000050000004963B48EAA6248405DF8C1F9D4074C404963B48EAA624840BAA0BE654E094C409544F64196654840BAA0BE654E094C409544F641966548405DF8C1F9D4074C404963B48EAA6248405DF8C1F9D4074C40
63038	9517	48.762017999999998	48.793934999999998	56.150218000000002	56.131444999999999	Центральная	0103000020E610000001000000050000004E7B4ACE89614840821C9430D3104C404E7B4ACE89614840A1A2EA573A134C402B137EA99F654840A1A2EA573A134C402B137EA99F654840821C9430D3104C404E7B4ACE89614840821C9430D3104C40
62267	9308	48.399259999999998	48.442227000000003	55.978079999999999	55.950069999999997	Молодежная	0103000020E61000000100000005000000EC4CA1F31A3348409274CDE49BF94B40EC4CA1F31A334840936FB6B931FD4B404034F3E49A384840936FB6B931FD4B404034F3E49A3848409274CDE49BF94B40EC4CA1F31A3348409274CDE49BF94B40
62241	9308	48.399259999999998	48.442227000000003	55.978079999999999	55.950069999999997	Заводская	0103000020E61000000100000005000000EC4CA1F31A3348409274CDE49BF94B40EC4CA1F31A334840936FB6B931FD4B404034F3E49A384840936FB6B931FD4B404034F3E49A3848409274CDE49BF94B40EC4CA1F31A3348409274CDE49BF94B40
62941	9250	48.329470000000001	48.369813000000001	55.979697000000002	55.958427	Станционная	0103000020E61000000100000005000000AE81AD122C2A48403C4D66BCADFA4B40AE81AD122C2A4840A27E17B666FD4B405D514A08562F4840A27E17B666FD4B405D514A08562F48403C4D66BCADFA4B40AE81AD122C2A48403C4D66BCADFA4B40
62236	8913	48.331634999999999	48.359814999999998	56.036994999999997	56.012214	Новая	0103000020E61000000100000005000000BF9A0304732A4840D446753A90014C40BF9A0304732A4840C98E8D40BC044C401CCEFC6A0E2E4840C98E8D40BC044C401CCEFC6A0E2E4840D446753A90014C40BF9A0304732A4840D446753A90014C40
62157	8986	48.684314000000001	48.704894000000003	56.105590999999997	56.089739000000002	Школьная	0103000020E61000000100000005000000F418E599975748407F164B917C0B4C40F418E599975748403FE08101840D4C40C59272F7395A48403FE08101840D4C40C59272F7395A48407F164B917C0B4C40F418E599975748407F164B917C0B4C40
63152	58068	48.220792000000003	48.996037999999999	56.206296999999999	55.828313999999999	Центральная	0103000020E61000000100000005000000F69B89E9421C4840D368723106EA4B40F69B89E9421C4840A721AAF0671A4C4060C9552C7E7F4840A721AAF0671A4C4060C9552C7E7F4840D368723106EA4B40F69B89E9421C4840D368723106EA4B40
63063	8697	48.662880000000001	48.675877999999997	56.012199000000003	56.006301000000001	Учительская	0103000020E6100000010000000500000014967840D95448404F779E78CE004C4014967840D95448409F05A1BC8F014C40FE0A992B835648409F05A1BC8F014C40FE0A992B835648404F779E78CE004C4014967840D95448404F779E78CE004C40
63148	9438	48.796711000000002	48.824351999999998	56.174278999999999	56.158461000000003	Центральная	0103000020E6100000010000000500000086AE44A0FA6548408258367348144C4086AE44A0FA65484096B036C64E164C403332C85D8469484096B036C64E164C403332C85D846948408258367348144C4086AE44A0FA6548408258367348144C40
63144	8755	48.956997000000001	48.975681999999999	56.186143000000001	56.171447999999998	Центральная	0103000020E6100000010000000500000060AFB0E07E7A4840787B1002F2154C4060AFB0E07E7A48408EB0A888D3174C40DFA5D425E37C48408EB0A888D3174C40DFA5D425E37C4840787B1002F2154C4060AFB0E07E7A4840787B1002F2154C40
63220	9607	48.497922000000003	48.516480999999999	55.959102000000001	55.943860000000001	Зеленая	0103000020E61000000100000005000000BEFA78E8BB3F484054008C67D0F84B40BEFA78E8BB3F48409CC3B5DAC3FA4B40B000A60C1C4248409CC3B5DAC3FA4B40B000A60C1C42484054008C67D0F84B40BEFA78E8BB3F484054008C67D0F84B40
63139	8891	48.422733000000001	48.429470999999999	56.137630999999999	56.132779999999997	Пугачева	0103000020E6100000010000000500000051F86C1D1C3648400CC85EEFFE104C4051F86C1D1C36484038F581E49D114C404BCADDE7F836484038F581E49D114C404BCADDE7F83648400CC85EEFFE104C4051F86C1D1C3648400CC85EEFFE104C40
63061	8842	48.346026000000002	48.355117	56.077351999999998	56.072006999999999	Лесная	0103000020E6100000010000000500000069C878944A2C4840A20A7F8637094C4069C878944A2C4840DD239BABE6094C4077A04E79742D4840DD239BABE6094C4077A04E79742D4840A20A7F8637094C4069C878944A2C4840A20A7F8637094C40
63113	9138	48.633029000000001	48.661918999999997	56.052717999999999	56.035587	Пионерская	0103000020E61000000100000005000000B535221807514840D594641D8E044C40B5352218075148408CF4A276BF064C40EECC04C3B95448408CF4A276BF064C40EECC04C3B9544840D594641D8E044C40B535221807514840D594641D8E044C40
63190	9086	48.613266000000003	48.634321999999997	56.070117000000003	56.060062000000002	Школьная	0103000020E61000000100000005000000D7DF12807F4E4840BEDD921CB0074C40D7DF12807F4E484063F20698F9084C4010919A763151484063F20698F9084C4010919A7631514840BEDD921CB0074C40D7DF12807F4E4840BEDD921CB0074C40
62289	6592	48.390250000000002	48.410516000000001	55.865192	55.84395	Кабанова	0103000020E61000000100000005000000CBA145B6F3314840C7BAB88D06EC4B40CBA145B6F33148406361889CBEEE4B400C3ECDC98B3448406361889CBEEE4B400C3ECDC98B344840C7BAB88D06EC4B40CBA145B6F3314840C7BAB88D06EC4B40
62197	57928	48.648398999999998	48.671207000000003	55.989738000000003	55.965671999999998	Финская	0103000020E610000001000000050000002AE109BDFE524840DA54DD239BFB4B402AE109BDFE524840E2CD1ABCAFFE4B4053EC681CEA554840E2CD1ABCAFFE4B4053EC681CEA554840DA54DD239BFB4B402AE109BDFE524840DA54DD239BFB4B40
63231	58085	48.617964000000001	48.644716000000003	55.965088000000002	55.955815999999999	Заречная	0103000020E610000001000000050000007C0DC171194F48402C7FBE2D58FA4B407C0DC171194F48408BE1EA0088FB4B409E9ACB0D865248408BE1EA0088FB4B409E9ACB0D865248402C7FBE2D58FA4B407C0DC171194F48402C7FBE2D58FA4B40
63154	58069	48.282451999999999	48.310308999999997	55.967163999999997	55.955851000000003	Лесная	0103000020E610000001000000050000004B581B6327244840A96C585359FA4B404B581B63272448402CEFAA07CCFB4B40C5538F34B82748402CEFAA07CCFB4B40C5538F34B8274840A96C585359FA4B404B581B6327244840A96C585359FA4B40
64714	58326	57.819318000000003	57.833402999999997	52.618350999999997	52.598199000000001	Буранбая	0103000020E6100000010000000500000017838769DFE84C40FDBFEAC8914C4A4017838769DFE84C4075392520264F4A40B3B112F3ACEA4C4075392520264F4A40B3B112F3ACEA4C40FDBFEAC8914C4A4017838769DFE84C40FDBFEAC8914C4A40
66028	58690	57.929541	57.950938999999998	52.255631000000001	52.240169999999999	Школьная	0103000020E6100000010000000500000044A51133FBF64C407BBDFBE3BD1E4A4044A51133FBF64C40016C4084B8204A40D7BE805EB8F94C40016C4084B8204A40D7BE805EB8F94C407BBDFBE3BD1E4A4044A51133FBF64C407BBDFBE3BD1E4A40
63502	58088	54.878439999999998	54.960959000000003	56.294801	56.242694	Социалистическая	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
63444	58088	54.878439999999998	54.960959000000003	56.294801	56.242694	Советская	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
63687	58088	54.878439999999998	54.960959000000003	56.294801	56.242694	Ломоносова	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
63332	58088	54.878439999999998	54.960959000000003	56.294801	56.242694	Куйбышева	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
63250	58088	54.878439999999998	54.960959000000003	56.294801	56.242694	Кирова	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
63249	58088	54.878439999999998	54.960959000000003	56.294801	56.242694	Азина	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
65088	58467	56.274358999999997	56.300221999999998	55.957428999999998	55.947212	Центральная	0103000020E610000001000000050000007F2E1A321E234C407B30293E3EF94B407F2E1A321E234C40F99E91088DFA4B4015C5ABAC6D264C40F99E91088DFA4B4015C5ABAC6D264C407B30293E3EF94B407F2E1A321E234C407B30293E3EF94B40
65867	58648	54.223711999999999	54.245567999999999	55.672255	55.653553000000002	Т. Назмиева	0103000020E6100000010000000500000083DC4598A21C4B40F299EC9FA7D34B4083DC4598A21C4B4047C9AB730CD64B40D978B0C56E1F4B4047C9AB730CD64B40D978B0C56E1F4B40F299EC9FA7D34B4083DC4598A21C4B40F299EC9FA7D34B40
64934	58303	58.414371000000003	58.446423000000003	55.634394999999998	55.616202999999999	Школьная	0103000020E6100000010000000500000096B4E21B0A354D403A596ABDDFCE4B4096B4E21B0A354D407ADFF8DA33D14B4053978C6324394D407ADFF8DA33D14B4053978C6324394D403A596ABDDFCE4B4096B4E21B0A354D403A596ABDDFCE4B40
65689	58601	58.604742000000002	58.618639000000002	55.365279000000001	55.356681999999999	Салавата Юлаева	0103000020E610000001000000050000004242942F684D4D4033897AC1A7AD4B404242942F684D4D4032755776C1AE4B40DC8310902F4F4D4032755776C1AE4B40DC8310902F4F4D4033897AC1A7AD4B404242942F684D4D4033897AC1A7AD4B40
65056	58452	55.591343000000002	55.619182000000002	55.925131999999998	55.914721	Школьная	0103000020E61000000100000005000000F9DB9E20B1CB4B4072FBE59315F54B40F9DB9E20B1CB4B40D53DB2B96AF64B40CD22145B41CF4B40D53DB2B96AF64B40CD22145B41CF4B4072FBE59315F54B40F9DB9E20B1CB4B4072FBE59315F54B40
65954	58670	57.862976000000003	57.890554000000002	52.350141000000001	52.332512000000001	Центральная	0103000020E61000000100000005000000D09D60FF75EE4C4087C3D2C08F2A4A40D09D60FF75EE4C408FFE976BD12C4A4037A968ACFDF14C408FFE976BD12C4A4037A968ACFDF14C4087C3D2C08F2A4A40D09D60FF75EE4C4087C3D2C08F2A4A40
64433	58230	55.646552999999997	55.654179999999997	53.918444999999998	53.908082	Школьная	0103000020E61000000100000005000000BA10AB3FC2D24B400B0BEE073CF44A40BA10AB3FC2D24B405D16139B8FF54A4040D9942BBCD34B405D16139B8FF54A4040D9942BBCD34B400B0BEE073CF44A40BA10AB3FC2D24B400B0BEE073CF44A40
65127	58474	58.360138999999997	58.384376000000003	55.338858000000002	55.319971000000002	Ленина	0103000020E61000000100000005000000CF81E508192E4D408F554ACFF4A84B40CF81E508192E4D4076FEEDB25FAB4B4004AF963B33314D4076FEEDB25FAB4B4004AF963B33314D408F554ACFF4A84B40CF81E508192E4D408F554ACFF4A84B40
2231	8159	56.193789000000002	56.201048	54.656396999999998	54.643357999999999	улица Мира	0103000020E610000001000000050000008BA9F413CE184C405BCF108E59524B408BA9F413CE184C40A41820D104544B408E76DCF0BB194C40A41820D104544B408E76DCF0BB194C405BCF108E59524B408BA9F413CE184C405BCF108E59524B40
66375	8159	56.193789000000002	56.201048	54.656396999999998	54.643357999999999	Мира	0103000020E610000001000000050000008BA9F413CE184C405BCF108E59524B408BA9F413CE184C40A41820D104544B408E76DCF0BB194C40A41820D104544B408E76DCF0BB194C405BCF108E59524B408BA9F413CE184C405BCF108E59524B40
64645	58313	55.124192000000001	55.165523999999998	54.911755999999997	54.894227999999998	Школьная	0103000020E6100000010000000500000061360186E58F4B407095271076724B4061360186E58F4B4044F7AC6BB4744B40FF59F3E32F954B4044F7AC6BB4744B40FF59F3E32F954B407095271076724B4061360186E58F4B407095271076724B40
64318	58207	58.117432999999998	58.130701000000002	53.589160999999997	53.582864000000001	Султанова	0103000020E610000001000000050000004F3C670B080F4D4004029D499BCA4A404F3C670B080F4D40118AADA069CB4A40FA4674CFBA104D40118AADA069CB4A40FA4674CFBA104D4004029D499BCA4A404F3C670B080F4D4004029D499BCA4A40
65707	58604	54.754733000000002	54.779527000000002	54.015929999999997	53.993174000000003	Салавата Юлаева	0103000020E61000000100000005000000221B48179B604B40679E5C5320FF4A40221B48179B604B403C8386FE09024B40ACAC6D8AC7634B403C8386FE09024B40ACAC6D8AC7634B40679E5C5320FF4A40221B48179B604B40679E5C5320FF4A40
65581	58571	54.565134999999998	54.583289999999998	53.704982999999999	53.698160000000001	Демская	0103000020E610000001000000050000009869FB5756484B400CB08F4E5DD94A409869FB5756484B40349E08E23CDA4A40BB0A293FA94A4B40349E08E23CDA4A40BB0A293FA94A4B400CB08F4E5DD94A409869FB5756484B400CB08F4E5DD94A40
65061	58455	54.147939000000001	54.189701999999997	54.410283999999997	54.395341999999999	Советская	0103000020E61000000100000005000000C76647AAEF124B401C5E10919A324B40C76647AAEF124B403909A52F84344B402EFEB62748184B403909A52F84344B402EFEB62748184B401C5E10919A324B40C76647AAEF124B401C5E10919A324B40
65158	58482	56.564497000000003	56.575043000000001	54.655073999999999	54.646666000000003	Цветочная	0103000020E6100000010000000500000056D80C7041484C40B3B794F3C5524B4056D80C7041484C40DE3AFF76D9534B4099654F029B494C40DE3AFF76D9534B4099654F029B494C40B3B794F3C5524B4056D80C7041484C40B3B794F3C5524B40
65054	58450	55.540129999999998	55.551789999999997	54.269154999999998	54.262151000000003	Молодёжная	0103000020E6100000010000000500000053CBD6FA22C54B408ECEF9298E214B4053CBD6FA22C54B400647C9AB73224B404221020EA1C64B400647C9AB73224B404221020EA1C64B408ECEF9298E214B4053CBD6FA22C54B408ECEF9298E214B40
64827	58365	57.995001000000002	58.020738000000001	52.658501999999999	52.648062000000003	Х. Ахметова	0103000020E61000000100000005000000603E59315CFF4C40E3E313B2F3524A40603E59315CFF4C40E02C25CB49544A4069E4F38AA7024D40E02C25CB49544A4069E4F38AA7024D40E3E313B2F3524A40603E59315CFF4C40E3E313B2F3524A40
6538	8386	55.951576000000003	55.957802000000001	54.606476000000001	54.602116000000002	улица Нур	0103000020E610000001000000050000004AD40B3ECDF94B40FD321823124D4B404AD40B3ECDF94B408AE76C01A14D4B408E05854199FA4B408AE76C01A14D4B408E05854199FA4B40FD321823124D4B404AD40B3ECDF94B40FD321823124D4B40
66940	8386	55.948855000000002	55.954649000000003	54.604968999999997	54.602522999999998	Мажита Гафури	0103000020E61000000100000005000000B3D2A41474F94B403D0B42791F4D4B40B3D2A41474F94B40020CCB9F6F4D4B405E143DF031FA4B40020CCB9F6F4D4B405E143DF031FA4B403D0B42791F4D4B40B3D2A41474F94B403D0B42791F4D4B40
64276	58176	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	Октябрьская	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
64153	58176	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	Мира	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
64400	58176	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	70-лет Октября	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
65104	58472	56.705469999999998	56.726166999999997	55.316051999999999	55.285921999999999	Симская	0103000020E61000000100000005000000912749D74C5A4C407C9A931799A44B40912749D74C5A4C40EEEA556474A84B409B374E0AF35C4C40EEEA556474A84B409B374E0AF35C4C407C9A931799A44B40912749D74C5A4C407C9A931799A44B40
65880	58653	56.036332999999999	56.051423999999997	52.804146000000003	52.790304999999996	Псянчина	0103000020E61000000100000005000000FE614B8FA6044C40C16ED8B628654A40FE614B8FA6044C40C89A9141EE664A40601DC70F95064C40C89A9141EE664A40601DC70F95064C40C16ED8B628654A40FE614B8FA6044C40C16ED8B628654A40
65006	58435	55.007717	55.016682000000003	54.740813000000003	54.734127999999998	Центральная	0103000020E61000000100000005000000C64FE3DEFC804B40F88903E8F75D4B40C64FE3DEFC804B40D0B9DBF5D25E4B404837C2A222824B40D0B9DBF5D25E4B404837C2A222824B40F88903E8F75D4B40C64FE3DEFC804B40F88903E8F75D4B40
65603	58576	57.967585	58.002842999999999	53.510942	53.497349	Сагадатова	0103000020E61000000100000005000000D28C45D3D9FB4C4062D9CC21A9BF4A40D28C45D3D9FB4C409013268C66C14A40E202D0285D004D409013268C66C14A40E202D0285D004D4062D9CC21A9BF4A40D28C45D3D9FB4C4062D9CC21A9BF4A40
66408	16756	55.943221999999999	55.981814	54.580629000000002	54.560654	переулок Овражный	0103000020E61000000100000005000000116F9D7FBBF84B40902FA182C3474B40116F9D7FBBF84B40FA0D130D524A4B40A260C614ACFD4B40FA0D130D524A4B40A260C614ACFD4B40902FA182C3474B40116F9D7FBBF84B40902FA182C3474B40
66377	16756	55.963228000000001	55.965499999999999	54.571829999999999	54.569851999999997	Центральная	0103000020E61000000100000005000000B64B1B0E4BFB4B40B4C70BE9F0484B40B64B1B0E4BFB4B40936FB6B931494B40DD24068195FB4B40936FB6B931494B40DD24068195FB4B40B4C70BE9F0484B40B64B1B0E4BFB4B40B4C70BE9F0484B40
65644	16756	55.943221999999999	55.981814	54.580629000000002	54.560654	Мусы Гареева	0103000020E61000000100000005000000116F9D7FBBF84B40902FA182C3474B40116F9D7FBBF84B40FA0D130D524A4B40A260C614ACFD4B40FA0D130D524A4B40A260C614ACFD4B40902FA182C3474B40116F9D7FBBF84B40902FA182C3474B40
66135	58712	55.045777999999999	55.068137	53.559936	53.548268999999998	Центральная	0103000020E610000001000000050000002A70B20DDC854B408F34B8AD2DC64A402A70B20DDC854B4031ED9BFBABC74A40E35295B6B8884B4031ED9BFBABC74A40E35295B6B8884B408F34B8AD2DC64A402A70B20DDC854B408F34B8AD2DC64A40
63876	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	пер.Школьный	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63860	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Энергетиков	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
64530	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Чкалова	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63988	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Фабричный переулок	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63442	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Муртазина	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63978	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Максима Горького	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63806	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Максима Горького	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63556	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Ленинского Комсомола	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63304	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Ленина	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63825	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Кирова	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63619	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Башкортостана	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
64378	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Багаутдинова	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63690	58097	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Ахметгалина	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
179	59	56.049025999999998	56.079155	54.779961	54.763933999999999	улица Юрия Гагарина	0103000020E61000000100000005000000AC53E57B46064C40B726DD96C8614B40AC53E57B46064C40E69315C3D5634B404E2844C0210A4C40E69315C3D5634B404E2844C0210A4C40B726DD96C8614B40AC53E57B46064C40B726DD96C8614B40
6406	59	55.826172	55.834184999999998	54.713344999999997	54.698493999999997	улица Ухтомского	0103000020E610000001000000050000007A6F0C01C0E94B40E2395B4068594B407A6F0C01C0E94B40EFE192E34E5B4B4029E8F692C6EA4B40EFE192E34E5B4B4029E8F692C6EA4B40E2395B4068594B407A6F0C01C0E94B40E2395B4068594B40
4284	59	56.160308999999998	56.163130000000002	54.818781000000001	54.814512000000001	улица Совхозная	0103000020E6100000010000000500000092205C0185144C408B19E1ED41684B4092205C0185144C4008CBD8D0CD684B408D7F9F71E1144C4008CBD8D0CD684B408D7F9F71E1144C408B19E1ED41684B4092205C0185144C408B19E1ED41684B40
7673	59	55.935344000000001	55.935550999999997	54.603690999999998	54.594870999999998	улица Светлая	0103000020E610000001000000050000004241295AB9F74B405E2BA1BB244C4B404241295AB9F74B40DCF126BF454D4B40BB5E9A22C0F74B40DCF126BF454D4B40BB5E9A22C0F74B405E2BA1BB244C4B404241295AB9F74B405E2BA1BB244C4B40
7046	59	55.917862999999997	55.940643999999999	54.731440999999997	54.725315999999999	улица Свердлова	0103000020E61000000100000005000000AE9AE7887CF54B40FDA19927D75C4B40AE9AE7887CF54B400DFAD2DB9F5D4B40DD96C80567F84B400DFAD2DB9F5D4B40DD96C80567F84B40FDA19927D75C4B40AE9AE7887CF54B40FDA19927D75C4B40
952	59	56.088830000000002	56.090375000000002	54.823450000000001	54.819253000000003	улица Репина	0103000020E61000000100000005000000AC730CC85E0B4C4030134548DD684B40AC730CC85E0B4C4013F241CF66694B4021B07268910B4C4013F241CF66694B4021B07268910B4C4030134548DD684B40AC730CC85E0B4C4030134548DD684B40
1892	59	55.916884000000003	55.958925000000001	54.727364999999999	54.716096999999998	улица Пушкина	0103000020E61000000100000005000000E31C75745CF54B40C1E10511A95B4B40E31C75745CF54B40A5A0DB4B1A5D4B408D28ED0DBEFA4B40A5A0DB4B1A5D4B408D28ED0DBEFA4B40C1E10511A95B4B40E31C75745CF54B40C1E10511A95B4B40
1429	59	55.961970000000001	55.973998000000002	54.748499000000002	54.722597	улица Пархоменко	0103000020E61000000100000005000000D7DD3CD521FB4B400798F90E7E5C4B40D7DD3CD521FB4B405B0BB3D0CE5F4B40492F6AF7ABFC4B405B0BB3D0CE5F4B40492F6AF7ABFC4B400798F90E7E5C4B40D7DD3CD521FB4B400798F90E7E5C4B40
15358	59	56.05659	56.056769000000003	54.764567999999997	54.760283000000001	улица Натальи Ковшовой	0103000020E61000000100000005000000ECA353573E074C40365A0EF450614B40ECA353573E074C40B8C83D5DDD614B409C36E33444074C40B8C83D5DDD614B409C36E33444074C40365A0EF450614B40ECA353573E074C40365A0EF450614B40
15709	59	55.820746	55.830995999999999	54.712628000000002	54.696928	улица Мусы Джалиля	0103000020E61000000100000005000000522976340EE94B4056D5CBEF34594B40522976340EE94B40611BF164375B4B40AC8DB1135EEA4B40611BF164375B4B40AC8DB1135EEA4B4056D5CBEF34594B40522976340EE94B4056D5CBEF34594B40
61	59	55.964773000000001	56.032415999999998	54.753819999999997	54.709850000000003	улица Менделеева	0103000020E610000001000000050000002B8881AE7DFB4B406688635DDC5A4B402B8881AE7DFB4B400D897B2C7D604B40FEEE1D3526044C400D897B2C7D604B40FEEE1D3526044C406688635DDC5A4B402B8881AE7DFB4B406688635DDC5A4B40
2256	59	55.898926000000003	55.911870999999998	54.743344	54.740501000000002	улица Лесозаводская	0103000020E6100000010000000500000016C3D50110F34B40E1D39CBCC85E4B4016C3D50110F34B40C3D66CE5255F4B40DD955D30B8F44B40C3D66CE5255F4B40DD955D30B8F44B40E1D39CBCC85E4B4016C3D50110F34B40E1D39CBCC85E4B40
1894	59	55.995226000000002	56.002429999999997	54.719149000000002	54.714958000000003	улица Красноводская	0103000020E610000001000000050000008010C99063FF4B40BD0166BE835B4B408010C99063FF4B40BEF90D130D5C4B40BF4351A04F004C40BEF90D130D5C4B40BF4351A04F004C40BD0166BE835B4B408010C99063FF4B40BD0166BE835B4B40
130	59	55.989412999999999	56.028418000000002	54.767055999999997	54.737085999999998	улица Комсомольская	0103000020E610000001000000050000005E9ECE15A5FE4B40732B84D5585E4B405E9ECE15A5FE4B40AC1919E42E624B40124F7633A3034C40AC1919E42E624B40124F7633A3034C40732B84D5585E4B405E9ECE15A5FE4B40732B84D5585E4B40
15937	59	55.946717	55.987886000000003	54.731440999999997	54.724952000000002	улица Кирова	0103000020E610000001000000050000009BC8CC052EF94B40BC95253ACB5C4B409BC8CC052EF94B400DFAD2DB9F5D4B409016670C73FE4B400DFAD2DB9F5D4B409016670C73FE4B40BC95253ACB5C4B409BC8CC052EF94B40BC95253ACB5C4B40
6875	59	56.116326999999998	56.117873000000003	54.804301000000002	54.801166000000002	улица Карима Хакимова	0103000020E6100000010000000500000026529ACDE30E4C406555849B8C664B4026529ACDE30E4C40EF91CD55F3664B406C0A6476160F4C40EF91CD55F3664B406C0A6476160F4C406555849B8C664B4026529ACDE30E4C406555849B8C664B40
1825	59	56.052959999999999	56.137106000000003	54.811709999999998	54.800454999999999	улица Интернациональная	0103000020E6100000010000000500000082FFAD64C7064C40B875374F75664B4082FFAD64C7064C4007EBFF1CE6674B40EE0A7DB08C114C4007EBFF1CE6674B40EE0A7DB08C114C40B875374F75664B4082FFAD64C7064C40B875374F75664B40
6446	59	55.831623999999998	55.844569	54.713532999999998	54.704529000000001	улица Дагестанская	0103000020E61000000100000005000000CB48BDA772EA4B40B30A9B012E5A4B40CB48BDA772EA4B40F2CEA10C555B4B40931B45D61AEC4B40F2CEA10C555B4B40931B45D61AEC4B40B30A9B012E5A4B40CB48BDA772EA4B40B30A9B012E5A4B40
6635	59	56.112689000000003	56.116560999999997	54.783330999999997	54.774555999999997	улица Георгия Мушникова	0103000020E610000001000000050000003ACFD8976C0E4C40D575A8A624634B403ACFD8976C0E4C40B378B13044644B40997E8978EB0E4C40B378B13044644B40997E8978EB0E4C40D575A8A624634B403ACFD8976C0E4C40D575A8A624634B40
7358	59	56.007038000000001	56.014315000000003	54.718550999999998	54.715114	улица Генерала Горбатова	0103000020E6100000010000000500000025EA059FE6004C40B47405DB885B4B4025EA059FE6004C4009C1AA7AF95B4B40CF6BEC12D5014C4009C1AA7AF95B4B40CF6BEC12D5014C40B47405DB885B4B4025EA059FE6004C40B47405DB885B4B40
15743	59	55.921429000000003	55.922606000000002	54.730280999999998	54.727463	улица Гаражная	0103000020E61000000100000005000000024BAE62F1F54B406806F1811D5D4B40024BAE62F1F54B40F1F109D9795D4B40F48B12F417F64B40F1F109D9795D4B40F48B12F417F64B406806F1811D5D4B40024BAE62F1F54B406806F1811D5D4B40
1971	59	55.979469000000002	56.001019999999997	54.719231999999998	54.711286000000001	улица Бакалинская	0103000020E6100000010000000500000011397D3D5FFD4B40240D6E6B0B5B4B4011397D3D5FFD4B404B1E4FCB0F5C4B402A52616C21004C404B1E4FCB0F5C4B402A52616C21004C40240D6E6B0B5B4B4011397D3D5FFD4B40240D6E6B0B5B4B40
1922	59	55.994695999999998	55.999977999999999	54.718114	54.712758000000001	улица Акназарова	0103000020E6100000010000000500000023BBD23252FF4B402FFB75A73B5B4B4023BBD23252FF4B405E66D828EB5B4B40185C7347FFFF4B405E66D828EB5B4B40185C7347FFFF4B402FFB75A73B5B4B4023BBD23252FF4B402FFB75A73B5B4B40
1486	59	55.958053	55.983763000000003	54.739103	54.735182999999999	улица 50-летия Октября	0103000020E61000000100000005000000D76A0F7BA1FA4B409FC9FE791A5E4B40D76A0F7BA1FA4B4010B056ED9A5E4B40E7012CF2EBFD4B4010B056ED9A5E4B40E7012CF2EBFD4B409FC9FE791A5E4B40D76A0F7BA1FA4B409FC9FE791A5E4B40
8	59	55.996744	56.029173	54.759175999999997	54.743884000000001	улица 50 Лет СССР	0103000020E61000000100000005000000FB3DB14E95FF4B4043024697375F4B40FB3DB14E95FF4B403CF4DDAD2C614B408E76DCF0BB034C403CF4DDAD2C614B408E76DCF0BB034C4043024697375F4B40FB3DB14E95FF4B4043024697375F4B40
63889	59	55.983763000000003	56.050049999999999	54.807989999999997	54.739103	проспект Октября 	0103000020E61000000100000005000000E7012CF2EBFD4B4010B056ED9A5E4B40E7012CF2EBFD4B405DBF60376C674B401895D40968064C405DBF60376C674B401895D40968064C4010B056ED9A5E4B40E7012CF2EBFD4B4010B056ED9A5E4B40
63974	59	55.969031000000001	56.000202000000002	54.755228000000002	54.742736000000001	им. Города Галле	0103000020E61000000100000005000000B4E7323509FC4B40EBC726F9115F4B40B4E7323509FC4B400283A44FAB604B4068B27F9E06004C400283A44FAB604B4068B27F9E06004C40EBC726F9115F4B40B4E7323509FC4B40EBC726F9115F4B40
63813	59	56.049025999999998	56.079155	54.779961	54.763933999999999	Юрия Гагарина	0103000020E61000000100000005000000AC53E57B46064C40B726DD96C8614B40AC53E57B46064C40E69315C3D5634B404E2844C0210A4C40E69315C3D5634B404E2844C0210A4C40B726DD96C8614B40AC53E57B46064C40B726DD96C8614B40
63769	59	56.049025999999998	56.079155	54.779961	54.763933999999999	Юрия Гагарина	0103000020E61000000100000005000000AC53E57B46064C40B726DD96C8614B40AC53E57B46064C40E69315C3D5634B404E2844C0210A4C40E69315C3D5634B404E2844C0210A4C40B726DD96C8614B40AC53E57B46064C40B726DD96C8614B40
66934	59	55.940545	55.975014000000002	54.667296	54.663364999999999	Элеваторная	0103000020E610000001000000050000004AB54FC763F84B40D027F224E9544B404AB54FC763F84B40356090F469554B4032923D42CDFC4B40356090F469554B4032923D42CDFC4B40D027F224E9544B404AB54FC763F84B40D027F224E9544B40
66949	59	56.036358999999997	56.060371000000004	54.792883000000003	54.790531999999999	Шота Руставели	0103000020E6100000010000000500000027F56569A7044C4082380F2730654B4027F56569A7044C40F646AD307D654B403C50A73CBA074C40F646AD307D654B403C50A73CBA074C4082380F2730654B4027F56569A7044C4082380F2730654B40
2665	59	55.939053999999999	55.957380000000001	54.704498000000001	54.702010999999999	Школьный переулок	0103000020E61000000100000005000000C896E5EB32F84B405437177FDB594B40C896E5EB32F84B40780C8FFD2C5A4B4018EC866D8BFA4B40780C8FFD2C5A4B4018EC866D8BFA4B405437177FDB594B40C896E5EB32F84B405437177FDB594B40
63861	59	55.994371999999998	56.021312999999999	54.766381000000003	54.754246000000002	Шафиева	0103000020E610000001000000050000007007EA9447FF4B40C59107228B604B407007EA9447FF4B404DA3C9C518624B4065FD6662BA024C404DA3C9C518624B4065FD6662BA024C40C59107228B604B407007EA9447FF4B40C59107228B604B40
63905	59	55.872183	55.893051	54.796086000000003	54.784001000000004	Чкалова	0103000020E6100000010000000500000047904AB1A3EF4B4002840F255A644B4047904AB1A3EF4B40D8666325E6654B407E54C37E4FF24B40D8666325E6654B407E54C37E4FF24B4002840F255A644B4047904AB1A3EF4B4002840F255A644B40
65423	59	55.764502	56.311235000000003	54.968240999999999	54.492655999999997	Чишминская	0103000020E6100000010000000500000001DD9733DBE14B40CE16105A0F3F4B4001DD9733DBE14B40BBD23252EF7B4B406F2F698CD6274C40BBD23252EF7B4B406F2F698CD6274C40CE16105A0F3F4B4001DD9733DBE14B40CE16105A0F3F4B40
63908	59	56.185164999999998	56.232354000000001	54.845678999999997	54.827111000000002	Чехова	0103000020E6100000010000000500000092AE997CB3174C40B894F3C5DE694B4092AE997CB3174C40FDF49F353F6C4B40228C9FC6BD1D4C40FDF49F353F6C4B40228C9FC6BD1D4C40B894F3C5DE694B4092AE997CB3174C40B894F3C5DE694B40
63837	59	55.922362999999997	55.977744000000001	54.732911999999999	54.723959000000001	Чернышевского	0103000020E610000001000000050000002D05A4FD0FF64B408B5242B0AA5C4B402D05A4FD0FF64B40486C770FD05D4B401CEE23B726FD4B40486C770FD05D4B401CEE23B726FD4B408B5242B0AA5C4B402D05A4FD0FF64B408B5242B0AA5C4B40
63827	59	56.09731	56.130844000000003	54.814132999999998	54.806412999999999	Черниковская	0103000020E6100000010000000500000071C971A7740C4C40DD088B8A38674B4071C971A7740C4C4014CC988235684B405D70067FBF104C4014CC988235684B405D70067FBF104C40DD088B8A38674B4071C971A7740C4C40DD088B8A38674B40
63957	59	55.946950000000001	55.965276000000003	54.750926	54.714708000000002	Цюрупы	0103000020E610000001000000050000003E7958A835F94B4044183F8D7B5B4B403E7958A835F94B40A9DBD9571E604B408ECEF9298EFB4B40A9DBD9571E604B408ECEF9298EFB4B4044183F8D7B5B4B403E7958A835F94B4044183F8D7B5B4B40
64457	59	55.908430000000003	55.910479000000002	54.677577999999997	54.670549999999999	Цветы Башкирии	0103000020E61000000100000005000000475A2A6F47F44B40992A1895D4554B40475A2A6F47F44B409A3E3BE0BA564B40EF586C938AF44B409A3E3BE0BA564B40EF586C938AF44B40992A1895D4554B40475A2A6F47F44B40992A1895D4554B40
63909	59	55.957559000000003	55.968249	54.748207999999998	54.724660999999998	Худайбердина	0103000020E61000000100000005000000C87E164B91FA4B40E4D70FB1C15C4B40C87E164B91FA4B40834D9D47C55F4B403EB14E95EFFB4B40834D9D47C55F4B403EB14E95EFFB4B40E4D70FB1C15C4B40C87E164B91FA4B40E4D70FB1C15C4B40
63870	59	55.977384999999998	55.983376999999997	54.733499000000002	54.732531999999999	Харьковская	0103000020E61000000100000005000000EC4CA1F31AFD4B4001A3CB9BC35D4B40EC4CA1F31AFD4B400953944BE35D4B40BD512B4CDFFD4B400953944BE35D4B40BD512B4CDFFD4B4001A3CB9BC35D4B40EC4CA1F31AFD4B4001A3CB9BC35D4B40
1622	59	55.983781	55.997318999999997	54.739113000000003	54.732486000000002	Хадии Давлетшиной бульвар	0103000020E610000001000000050000008DB62A89ECFD4B409163EB19C25D4B408DB62A89ECFD4B40348639419B5E4B40F7562426A8FF4B40348639419B5E4B40F7562426A8FF4B409163EB19C25D4B408DB62A89ECFD4B409163EB19C25D4B40
63934	59	56.138902000000002	56.170980999999998	54.799438000000002	54.797818999999997	Фурманова	0103000020E61000000100000005000000ACAC6D8AC7114C404F90D8EE1E664B40ACAC6D8AC7114C40FF9600FC53664B40629E95B4E2154C40FF9600FC53664B40629E95B4E2154C404F90D8EE1E664B40ACAC6D8AC7114C404F90D8EE1E664B40
63916	59	56.13062	56.131213000000002	54.788055	54.774613000000002	Ферина	0103000020E610000001000000050000000D1AFA27B8104C403A07CF8426634B400D1AFA27B8104C4082397AFCDE644B40B0E76B96CB104C4082397AFCDE644B40B0E76B96CB104C403A07CF8426634B400D1AFA27B8104C403A07CF8426634B40
63958	59	55.826172	55.834184999999998	54.713344999999997	54.698493999999997	Ухтомского	0103000020E610000001000000050000007A6F0C01C0E94B40E2395B4068594B407A6F0C01C0E94B40EFE192E34E5B4B4029E8F692C6EA4B40EFE192E34E5B4B4029E8F692C6EA4B40E2395B4068594B407A6F0C01C0E94B40E2395B4068594B40
63879	59	56.037042	56.085704	54.808872000000001	54.780740000000002	Уфимское Шоссе	0103000020E610000001000000050000000A4AD1CABD044C40EB56CF49EF634B400A4AD1CABD044C403753211E89674B4075914259F80A4C403753211E89674B4075914259F80A4C40EB56CF49EF634B400A4AD1CABD044C40EB56CF49EF634B40
63927	59	56.069561	56.089314999999999	54.839188	54.811689999999999	Ульяновых	0103000020E61000000100000005000000DD09F65FE7084C40C03E3A75E5674B40DD09F65FE7084C400B992B836A6B4B40680586AC6E0B4C400B992B836A6B4B40680586AC6E0B4C40C03E3A75E5674B40DD09F65FE7084C40C03E3A75E5674B40
6587	59	56.121510999999998	56.124403000000001	54.788102000000002	54.774352999999998	Тухвата Янаби бульвар	0103000020E61000000100000005000000588D25AC8D0F4C409D47C5FF1D634B40588D25AC8D0F4C40C3F4BD86E0644B401C430070EC0F4C40C3F4BD86E0644B401C430070EC0F4C409D47C5FF1D634B40588D25AC8D0F4C409D47C5FF1D634B40
63891	59	55.933655000000002	55.952133000000003	54.718333000000001	54.715159999999997	Тукаева	0103000020E610000001000000050000009A5FCD0182F74B4024B4E55C8A5B4B409A5FCD0182F74B409C51F355F25B4B40A038807EDFF94B409C51F355F25B4B40A038807EDFF94B4024B4E55C8A5B4B409A5FCD0182F74B4024B4E55C8A5B4B40
63873	59	56.120998999999998	56.121339999999996	54.784213999999999	54.776290000000003	Транспортная	0103000020E61000000100000005000000A2EC2DE57C0F4C401E1B81785D634B40A2EC2DE57C0F4C405D88D51F61644B402BD9B111880F4C405D88D51F61644B402BD9B111880F4C401E1B81785D634B40A2EC2DE57C0F4C401E1B81785D634B40
66461	59	56.038730999999999	56.109617	54.799666999999999	54.795997	Трамвайная	0103000020E61000000100000005000000B22B2D23F5044C40685BCD3AE3654B40B22B2D23F5044C406058FE7C5B664B40F60A0BEE070E4C406058FE7C5B664B40F60A0BEE070E4C40685BCD3AE3654B40B22B2D23F5044C40685BCD3AE3654B40
63954	59	56.146484000000001	56.153266000000002	54.838281000000002	54.830300999999999	Таманская	0103000020E6100000010000000500000092B1DAFCBF124C40056B9C4D476A4B4092B1DAFCBF124C40D9EDB3CA4C6B4B405CCB64389E134C40D9EDB3CA4C6B4B405CCB64389E134C40056B9C4D476A4B4092B1DAFCBF124C40056B9C4D476A4B40
63900	59	55.835783999999997	55.840473000000003	54.707452000000004	54.700617000000001	Таллинская	0103000020E61000000100000005000000914259F8FAEA4B40C5025FD1AD594B40914259F8FAEA4B40B2BE81C98D5A4B40E415889E94EB4B40B2BE81C98D5A4B40E415889E94EB4B40C5025FD1AD594B40914259F8FAEA4B40C5025FD1AD594B40
63855	59	56.113883999999999	56.128033000000002	54.818289	54.800454999999999	Суворова	0103000020E61000000100000005000000D2C43BC0930E4C40B875374F75664B40D2C43BC0930E4C4099D6A6B1BD684B4086E7A56263104C4099D6A6B1BD684B4086E7A56263104C40B875374F75664B40D2C43BC0930E4C40B875374F75664B40
63892	59	55.994103000000003	56.003050000000002	54.71566	54.697572999999998	Степана Кувыкина	0103000020E6100000010000000500000081ED60C43EFF4B404BC972124A594B4081ED60C43EFF4B40168733BF9A5B4B405C2041F163004C40168733BF9A5B4B405C2041F163004C404BC972124A594B4081ED60C43EFF4B404BC972124A594B40
63816	59	55.992620000000002	56.006922000000003	54.726391999999997	54.717224999999999	Степана Злобина	0103000020E6100000010000000500000082AD122C0EFF4B40D26F5F07CE5B4B4082AD122C0EFF4B40BB09BE69FA5C4B40BCCFF1D1E2004C40BB09BE69FA5C4B40BCCFF1D1E2004C40D26F5F07CE5B4B4082AD122C0EFF4B40D26F5F07CE5B4B40
63828	59	56.051971999999999	56.064135	54.778148999999999	54.773257000000001	Станиславского	0103000020E610000001000000050000006327BC04A7064C409833DB15FA624B406327BC04A7064C402235ED629A634B40B5C35F9335084C402235ED629A634B40B5C35F9335084C409833DB15FA624B406327BC04A7064C409833DB15FA624B40
63887	59	56.224133999999999	56.227502999999999	54.766817000000003	54.766677000000001	Стадионная	0103000020E61000000100000005000000F9F5436CB01C4C4036CCD07822624B40F9F5436CB01C4C402882380F27624B40F65E7CD11E1D4C402882380F27624B40F65E7CD11E1D4C4036CCD07822624B40F9F5436CB01C4C4036CCD07822624B40
63950	59	56.073666000000003	56.077691000000002	54.815238000000001	54.814081000000002	Спартака	0103000020E61000000100000005000000E06932E36D094C40C2A563CE33684B40E06932E36D094C406D3A02B859684B40C61858C7F1094C406D3A02B859684B40C61858C7F1094C40C2A563CE33684B40E06932E36D094C40C2A563CE33684B40
63977	59	55.964773000000001	55.973495	54.709850000000003	54.705703999999997	Сочинская	0103000020E610000001000000050000002B8881AE7DFB4B4004543882545A4B402B8881AE7DFB4B406688635DDC5A4B40E6E8F17B9BFC4B406688635DDC5A4B40E6E8F17B9BFC4B4004543882545A4B402B8881AE7DFB4B4004543882545A4B40
63933	59	55.972515999999999	56.001944999999999	54.705703999999997	54.693046000000002	Софьи Перовской	0103000020E610000001000000050000001A6B7F677BFC4B40D34F38BBB5584B401A6B7F677BFC4B4004543882545A4B4003B2D7BB3F004C4004543882545A4B4003B2D7BB3F004C40D34F38BBB5584B401A6B7F677BFC4B40D34F38BBB5584B40
63910	59	56.160138000000003	56.185164999999998	54.827111000000002	54.810957999999999	Сосновская	0103000020E61000000100000005000000666CE8667F144C40FC36C478CD674B40666CE8667F144C40B894F3C5DE694B4092AE997CB3174C40B894F3C5DE694B4092AE997CB3174C40FC36C478CD674B40666CE8667F144C40FC36C478CD674B40
63780	59	55.944695000000003	55.948199000000002	54.724068000000003	54.716636999999999	Советская	0103000020E61000000100000005000000EDD808C4EBF84B40410DDFC2BA5B4B40EDD808C4EBF84B40420A9E42AE5C4B40CA8CB7955EF94B40420A9E42AE5C4B40CA8CB7955EF94B40410DDFC2BA5B4B40EDD808C4EBF84B40410DDFC2BA5B4B40
64217	59	55.944695000000003	55.948199000000002	54.724068000000003	54.716636999999999	Советская	0103000020E61000000100000005000000EDD808C4EBF84B40410DDFC2BA5B4B40EDD808C4EBF84B40420A9E42AE5C4B40CA8CB7955EF94B40420A9E42AE5C4B40CA8CB7955EF94B40410DDFC2BA5B4B40EDD808C4EBF84B40410DDFC2BA5B4B40
63888	59	56.223954999999997	56.235812000000003	54.790832999999999	54.782479000000002	Советов	0103000020E610000001000000050000004963B48EAA1C4C404567994528644B404963B48EAA1C4C407DCC07043A654B408F006E162F1E4C407DCC07043A654B408F006E162F1E4C404567994528644B404963B48EAA1C4C404567994528644B40
531	59	56.028678999999997	56.036054	54.791217000000003	54.789876999999997	Славы бульвар	0103000020E610000001000000050000007E8AE3C0AB034C40696E85B01A654B407E8AE3C0AB034C400685419946654B40EB71DF6A9D044C400685419946654B40EB71DF6A9D044C40696E85B01A654B407E8AE3C0AB034C40696E85B01A654B40
63878	59	56.032164000000002	56.052861999999998	54.780538	54.754485000000003	Сипайловская	0103000020E61000000100000005000000E50D30F31D044C404A29E8F692604B40E50D30F31D044C4083A44FABE8634B40BF99982EC4064C4083A44FABE8634B40BF99982EC4064C404A29E8F692604B40E50D30F31D044C404A29E8F692604B40
63858	59	55.913784	55.930340000000001	54.748581999999999	54.744669000000002	Силикатная	0103000020E61000000100000005000000D5CDC5DFF6F44B402AAC5450515F4B40D5CDC5DFF6F44B40E82FF488D15F4B409014916115F74B40E82FF488D15F4B409014916115F74B402AAC5450515F4B40D5CDC5DFF6F44B402AAC5450515F4B40
63871	59	56.077412000000002	56.139198999999998	54.802754	54.788044999999997	Сельская Богородская	0103000020E61000000100000005000000B328ECA2E8094C405E6397A8DE644B40B328ECA2E8094C40D95DA0A4C0664B406551D845D1114C40D95DA0A4C0664B406551D845D1114C405E6397A8DE644B40B328ECA2E8094C405E6397A8DE644B40
63982	59	56.058548000000002	56.065483	54.813671999999997	54.812587000000001	Северодвинская	0103000020E61000000100000005000000849F38807E074C40CF13CFD902684B40849F38807E074C40E0D5726726684B40D4B837BF61084C40E0D5726726684B40D4B837BF61084C40CF13CFD902684B40849F38807E074C40CF13CFD902684B40
63884	59	56.098028999999997	56.116821999999999	54.836803000000003	54.807668999999997	Свободы	0103000020E61000000100000005000000A087DA368C0C4C401B7FA2B261674B40A087DA368C0C4C40EC18575C1C6B4B4006BAF605F40E4C40EC18575C1C6B4B4006BAF605F40E4C401B7FA2B261674B40A087DA368C0C4C401B7FA2B261674B40
63936	59	55.917862999999997	55.940643999999999	54.731440999999997	54.725315999999999	Свердлова	0103000020E61000000100000005000000AE9AE7887CF54B40FDA19927D75C4B40AE9AE7887CF54B400DFAD2DB9F5D4B40DD96C80567F84B400DFAD2DB9F5D4B40DD96C80567F84B40FDA19927D75C4B40AE9AE7887CF54B40FDA19927D75C4B40
717	59	55.956059000000003	56.032164000000002	54.754485000000003	54.712206000000002	Салавата Юлаева проспект	0103000020E61000000100000005000000F3052D2460FA4B40EB01F390295B4B40F3052D2460FA4B404A29E8F692604B40E50D30F31D044C404A29E8F692604B40E50D30F31D044C40EB01F390295B4B40F3052D2460FA4B40EB01F390295B4B40
63932	59	55.988182999999999	56.014333000000001	54.730884000000003	54.723117000000002	Сагита Агиша	0103000020E6100000010000000500000049BBD1C77CFE4B4040170D198F5C4B4049BBD1C77CFE4B40B8955E9B8D5D4B407520EBA9D5014C40B8955E9B8D5D4B407520EBA9D5014C4040170D198F5C4B4049BBD1C77CFE4B4040170D198F5C4B40
63862	59	56.028418000000002	56.043976999999998	54.796287999999997	54.767055999999997	Российская	0103000020E61000000100000005000000124F7633A3034C40AC1919E42E624B40124F7633A3034C403F19E3C3EC654B405A63D009A1054C403F19E3C3EC654B405A63D009A1054C40AC1919E42E624B40124F7633A3034C40AC1919E42E624B40
63859	59	55.981796000000003	56.020674999999997	54.775818000000001	54.746909000000002	Рихарда Зорге	0103000020E61000000100000005000000FCABC77DABFD4B40460BD0B69A5F4B40FCABC77DABFD4B40F6D214014E634B40226C787AA5024C40F6D214014E634B40226C787AA5024C40460BD0B69A5F4B40FCABC77DABFD4B40460BD0B69A5F4B40
63824	59	55.940050999999997	55.997174999999999	54.737720000000003	54.730322999999999	Революционная	0103000020E610000001000000050000003AC9569753F84B4020425C397B5D4B403AC9569753F84B4075CDE49B6D5E4B40C4B12E6EA3FF4B4075CDE49B6D5E4B40C4B12E6EA3FF4B4020425C397B5D4B403AC9569753F84B4020425C397B5D4B40
63841	59	55.986457999999999	55.988335999999997	54.702849000000001	54.702609000000002	Рабкоров	0103000020E610000001000000050000005470784144FE4B4009707A17EF594B405470784144FE4B405E83BEF4F6594B40CFBA46CB81FE4B405E83BEF4F6594B40CFBA46CB81FE4B4009707A17EF594B405470784144FE4B4009707A17EF594B40
64574	59	55.916884000000003	55.958925000000001	54.727364999999999	54.716096999999998	Пушкина	0103000020E61000000100000005000000E31C75745CF54B40C1E10511A95B4B40E31C75745CF54B40A5A0DB4B1A5D4B408D28ED0DBEFA4B40A5A0DB4B1A5D4B408D28ED0DBEFA4B40C1E10511A95B4B40E31C75745CF54B40C1E10511A95B4B40
16106	59	55.947786000000001	55.949052000000002	54.748145999999998	54.747418000000003	Привокзальная площадь	0103000020E61000000100000005000000A7CD380D51F94B408B389D64AB5F4B40A7CD380D51F94B400D51853FC35F4B40091A33897AF94B400D51853FC35F4B40091A33897AF94B408B389D64AB5F4B40A7CD380D51F94B408B389D64AB5F4B40
63897	59	55.811672999999999	55.846986000000001	54.704867	54.695428999999997	Правды	0103000020E61000000100000005000000EA059FE6E4E74B4051D845D103594B40EA059FE6E4E74B40CB83F414395A4B40BE1589096AEC4B40CB83F414395A4B40BE1589096AEC4B4051D845D103594B40EA059FE6E4E74B4051D845D103594B40
63925	59	55.963918999999997	55.969847999999999	54.714703	54.710577999999998	Посадская	0103000020E610000001000000050000001B7FA2B261FB4B40E8A04B38F45A4B401B7FA2B261FB4B4032AD4D637B5B4B40A60BB1FA23FC4B4032AD4D637B5B4B40A60BB1FA23FC4B40E8A04B38F45A4B401B7FA2B261FB4B40E8A04B38F45A4B40
63864	59	55.940330000000003	55.946778999999999	54.739144000000003	54.738292000000001	Подвойского	0103000020E610000001000000050000004EB9C2BB5CF84B4000732D5A805E4B404EB9C2BB5CF84B406F8445459C5E4B4011C5E40D30F94B406F8445459C5E4B4011C5E40D30F94B4000732D5A805E4B404EB9C2BB5CF84B4000732D5A805E4B40
63928	59	56.080494000000002	56.085030000000003	54.823709000000001	54.810502	Победы	0103000020E610000001000000050000001AC39CA04D0A4C40DAAB8F87BE674B401AC39CA04D0A4C40DF35E84B6F694B40E6965643E20A4C40DF35E84B6F694B40E6965643E20A4C40DAAB8F87BE674B401AC39CA04D0A4C40DAAB8F87BE674B40
6794	59	56.130969999999998	56.137914000000002	54.809184000000002	54.808042	Плеханова бульвар	0103000020E61000000100000005000000E960FD9FC3104C40B0E595EB6D674B40E960FD9FC3104C402639605793674B408DD47B2AA7114C402639605793674B408DD47B2AA7114C40B0E595EB6D674B40E960FD9FC3104C40B0E595EB6D674B40
63838	59	56.139127000000002	56.146493	54.796298	54.796283000000003	Петрозаводская	0103000020E61000000100000005000000CC7EDDE9CE114C402EAEF199EC654B40CC7EDDE9CE114C4063EFC517ED654B40E50B5A48C0124C4063EFC517ED654B40E50B5A48C0124C402EAEF199EC654B40CC7EDDE9CE114C402EAEF199EC654B40
63863	59	56.058781000000003	56.113515999999997	54.822122	54.806604999999998	Первомайская	0103000020E610000001000000050000002750C42286074C4021E527D53E674B402750C42286074C403BA92F4B3B694B404FC939B1870E4C403BA92F4B3B694B404FC939B1870E4C4021E527D53E674B402750C42286074C4021E527D53E674B40
63924	59	55.990113999999998	55.995396	54.766038000000002	54.759244000000002	Парковая	0103000020E61000000100000005000000E7A7380EBCFE4B4095D74AE82E614B40E7A7380EBCFE4B4023BF7E880D624B40DC48D92269FF4B4023BF7E880D624B40DC48D92269FF4B4095D74AE82E614B40E7A7380EBCFE4B4095D74AE82E614B40
63902	59	55.823332999999998	55.829512999999999	54.704554999999999	54.703628999999999	Островского	0103000020E61000000100000005000000D95BCAF962E94B4033C2DB83105A4B40D95BCAF962E94B40DC9DB5DB2E5A4B40AD4D637B2DEA4B40DC9DB5DB2E5A4B40AD4D637B2DEA4B4033C2DB83105A4B40D95BCAF962E94B4033C2DB83105A4B40
63946	59	56.112814999999998	56.132128999999999	54.806246999999999	54.804104000000002	Орджоникидзе	0103000020E61000000100000005000000C6BFCFB8700E4C40994A3FE1EC664B40C6BFCFB8700E4C40C2BF081A33674B4035ED629AE9104C40C2BF081A33674B4035ED629AE9104C40994A3FE1EC664B40C6BFCFB8700E4C40994A3FE1EC664B40
63911	59	55.991165000000002	55.994245999999997	54.708897999999998	54.708767999999999	Онежская	0103000020E610000001000000050000004DF8A57EDEFE4B40C539EAE8B85A4B404DF8A57EDEFE4B4093196F2BBD5A4B40E316F37343FF4B4093196F2BBD5A4B40E316F37343FF4B40C539EAE8B85A4B404DF8A57EDEFE4B40C539EAE8B85A4B40
63935	59	56.221359	56.229703999999998	54.777884	54.770966999999999	Олимпийская	0103000020E610000001000000050000006FD6E07D551C4C40CAA5F10BAF624B406FD6E07D551C4C40740AF2B391634B4054E1CFF0661D4C40740AF2B391634B4054E1CFF0661D4C40CAA5F10BAF624B406FD6E07D551C4C40CAA5F10BAF624B40
482	59	55.983763000000003	56.050049999999999	54.807989999999997	54.739103	Октября проспект	0103000020E61000000100000005000000E7012CF2EBFD4B4010B056ED9A5E4B40E7012CF2EBFD4B405DBF60376C674B401895D40968064C405DBF60376C674B401895D40968064C4010B056ED9A5E4B40E7012CF2EBFD4B4010B056ED9A5E4B40
63984	59	55.946554999999996	55.963011999999999	54.724364999999999	54.711702000000002	Октябрьской Революции	0103000020E61000000100000005000000C16ED8B628F94B40B83F170D195B4B40C16ED8B628F94B40FBAE08FEB75C4B40E9D32AFA43FB4B40FBAE08FEB75C4B40E9D32AFA43FB4B40B83F170D195B4B40C16ED8B628F94B40B83F170D195B4B40
64580	59	56.064728000000002	56.075794999999999	54.830711000000001	54.826982000000001	Новочеркасская	0103000020E610000001000000050000005891D10149084C40BA30D28BDA694B405891D10149084C40B7B6F0BC546A4B40A4198BA6B3094C40B7B6F0BC546A4B40A4198BA6B3094C40BA30D28BDA694B405891D10149084C40BA30D28BDA694B40
66536	59	56.092818999999999	56.104407000000002	54.625962999999999	54.622252000000003	Новая	0103000020E6100000010000000500000045B9347EE10B4C4070EF1AF4A54F4B4045B9347EE10B4C40C6C03A8E1F504B409B3C65355D0D4C40C6C03A8E1F504B409B3C65355D0D4C4070EF1AF4A54F4B4045B9347EE10B4C4070EF1AF4A54F4B40
63895	59	55.994793999999999	56.000129999999999	54.738213999999999	54.731222000000002	Николая Дмитриева	0103000020E61000000100000005000000E620E86855FF4B40D00EB8AE985D4B40E620E86855FF4B4084B9DDCB7D5E4B40CEDF844204004C4084B9DDCB7D5E4B40CEDF844204004C40D00EB8AE985D4B40E620E86855FF4B40D00EB8AE985D4B40
63922	59	55.909553000000002	55.921573000000002	54.738644999999998	54.725113	Нехаева	0103000020E61000000100000005000000467D923B6CF44B40C573B680D05C4B40467D923B6CF44B404D2D5BEB8B5E4B4035F0A31AF6F54B404D2D5BEB8B5E4B4035F0A31AF6F54B40C573B680D05C4B40467D923B6CF44B40C573B680D05C4B40
63923	59	56.063586999999998	56.081750999999997	54.817199000000002	54.811979999999998	Нежинская	0103000020E61000000100000005000000B2B96A9E23084C40C780ECF5EE674B40B2B96A9E23084C4076A911FA99684B4028B517D1760A4C4076A911FA99684B4028B517D1760A4C40C780ECF5EE674B40B2B96A9E23084C40C780ECF5EE674B40
63896	59	56.045431999999998	56.085030000000003	54.783273999999999	54.759098000000002	Набережная р.Уфы	0103000020E610000001000000050000008F183DB7D0054C40C13A8E1F2A614B408F183DB7D0054C404FE78A5242644B40E6965643E20A4C404FE78A5242644B40E6965643E20A4C40C13A8E1F2A614B408F183DB7D0054C40C13A8E1F2A614B40
63963	59	55.944408000000003	55.949519000000002	54.737341000000001	54.726559000000002	Мустая Карима	0103000020E61000000100000005000000570A815CE2F84B40A7CEA3E2FF5C4B40570A815CE2F84B40FE7F9C30615E4B401FF7ADD689F94B40FE7F9C30615E4B401FF7ADD689F94B40A7CEA3E2FF5C4B40570A815CE2F84B40A7CEA3E2FF5C4B40
63931	59	55.817915999999997	55.8367	54.710031999999998	54.704087000000001	Мусоргского	0103000020E610000001000000050000000470B378B1E84B40F644D7851F5A4B400470B378B1E84B40868E1D54E25A4B40174850FC18EB4B40868E1D54E25A4B40174850FC18EB4B40F644D7851F5A4B400470B378B1E84B40F644D7851F5A4B40
63844	59	55.990490999999999	56.002043999999998	54.702759999999998	54.693165999999998	Мубарякова	0103000020E61000000100000005000000BDFDB968C8FE4B407D59DAA9B9584B40BDFDB968C8FE4B40EE77280AF4594B40969350FA42004C40EE77280AF4594B40969350FA42004C407D59DAA9B9584B40BDFDB968C8FE4B407D59DAA9B9584B40
66502	59	55.864699999999999	55.865670999999999	54.704503000000003	54.700695000000003	Молодежная	0103000020E61000000100000005000000F46C567DAEEE4B4041BCAE5FB0594B40F46C567DAEEE4B408A7780272D5A4B403D0CAD4ECEEE4B408A7780272D5A4B403D0CAD4ECEEE4B4041BCAE5FB0594B40F46C567DAEEE4B4041BCAE5FB0594B40
66562	59	55.864699999999999	55.865670999999999	54.704503000000003	54.700695000000003	Молодежная	0103000020E61000000100000005000000F46C567DAEEE4B4041BCAE5FB0594B40F46C567DAEEE4B408A7780272D5A4B403D0CAD4ECEEE4B408A7780272D5A4B403D0CAD4ECEEE4B4041BCAE5FB0594B40F46C567DAEEE4B4041BCAE5FB0594B40
66545	59	55.864699999999999	55.865670999999999	54.704503000000003	54.700695000000003	Молодежная	0103000020E61000000100000005000000F46C567DAEEE4B4041BCAE5FB0594B40F46C567DAEEE4B408A7780272D5A4B403D0CAD4ECEEE4B408A7780272D5A4B403D0CAD4ECEEE4B4041BCAE5FB0594B40F46C567DAEEE4B4041BCAE5FB0594B40
63872	59	55.987886000000003	56.005744999999997	54.724952000000002	54.717610000000001	Минигали Губайдуллина	0103000020E610000001000000050000009016670C73FE4B402BA4FCA4DA5B4B409016670C73FE4B40BC95253ACB5C4B40C98E8D40BC004C40BC95253ACB5C4B40C98E8D40BC004C402BA4FCA4DA5B4B409016670C73FE4B402BA4FCA4DA5B4B40
63940	59	55.965814999999999	55.97204	54.737262999999999	54.714379999999998	Мингажева	0103000020E610000001000000050000003D7E6FD39FFB4B404F75C8CD705B4B403D7E6FD39FFB4B4082C64CA25E5E4B40B13385CE6BFC4B4082C64CA25E5E4B40B13385CE6BFC4B404F75C8CD705B4B403D7E6FD39FFB4B404F75C8CD705B4B40
63886	59	55.953184	55.958179000000001	54.749746000000002	54.742632	Миасская	0103000020E610000001000000050000000589EDEE01FA4B40467BBC900E5F4B400589EDEE01FA4B4046274BADF75F4B40645B069CA5FA4B4046274BADF75F4B40645B069CA5FA4B40467BBC900E5F4B400589EDEE01FA4B40467BBC900E5F4B40
63840	59	55.964773000000001	56.032415999999998	54.753819999999997	54.709850000000003	Менделеева	0103000020E610000001000000050000002B8881AE7DFB4B406688635DDC5A4B402B8881AE7DFB4B400D897B2C7D604B40FEEE1D3526044C400D897B2C7D604B40FEEE1D3526044C406688635DDC5A4B402B8881AE7DFB4B406688635DDC5A4B40
63980	59	56.075291999999997	56.081473000000003	54.818517	54.811269000000003	Маяковского	0103000020E6100000010000000500000041D3122BA3094C401BA19FA9D7674B4041D3122BA3094C402A1C412AC5684B40E6400FB56D0A4C402A1C412AC5684B40E6400FB56D0A4C401BA19FA9D7674B4041D3122BA3094C401BA19FA9D7674B40
63975	59	56.111170999999999	56.117261999999997	54.810974000000002	54.803854999999999	Машиностроителей	0103000020E61000000100000005000000BEA1F0D93A0E4C40F0DC7BB8E4664B40BEA1F0D93A0E4C4002F4FBFECD674B402288F370020F4C4002F4FBFECD674B402288F370020F4C40F0DC7BB8E4664B40BEA1F0D93A0E4C40F0DC7BB8E4664B40
63986	59	56.057560000000002	56.063327000000001	54.820695000000001	54.817940999999998	Матвея Пинского	0103000020E6100000010000000500000065C746205E074C405D876A4AB2684B4065C746205E074C40D07EA4880C694B4016FA60191B084C40D07EA4880C694B4016FA60191B084C405D876A4AB2684B4065C746205E074C405D876A4AB2684B40
64548	59	55.917845	55.934004999999999	54.744107999999997	54.733893999999999	Малая Трактовая	0103000020E6100000010000000500000008E6E8F17BF54B40855D143DF05D4B4008E6E8F17BF54B40925852EE3E5F4B4076A6D0798DF74B40925852EE3E5F4B4076A6D0798DF74B40855D143DF05D4B4008E6E8F17BF54B40855D143DF05D4B40
63913	59	55.793823000000003	55.812365	54.694540000000003	54.685682	Майкопская	0103000020E6100000010000000500000004E8F7FD9BE54B405ABA826DC4574B4004E8F7FD9BE54B40C6E1CCAFE6584B4020B58993FBE74B40C6E1CCAFE6584B4020B58993FBE74B405ABA826DC4574B4004E8F7FD9BE54B405ABA826DC4574B40
63760	59	55.948855000000002	55.954649000000003	54.604968999999997	54.602522999999998	Мажита Гафури	0103000020E61000000100000005000000B3D2A41474F94B403D0B42791F4D4B40B3D2A41474F94B40020CCB9F6F4D4B405E143DF031FA4B40020CCB9F6F4D4B405E143DF031FA4B403D0B42791F4D4B40B3D2A41474F94B403D0B42791F4D4B40
63903	59	55.816380000000002	55.835864000000001	54.710603999999996	54.707827000000002	Магистральная	0103000020E61000000100000005000000E38DCC237FE84B40E71C3C139A5A4B40E38DCC237FE84B4011346612F55A4B40AEF36F97FDEA4B4011346612F55A4B40AEF36F97FDEA4B40E71C3C139A5A4B40E38DCC237FE84B40E71C3C139A5A4B40
63990	59	56.037213000000001	56.040159000000003	54.787982999999997	54.787547000000004	Львовская	0103000020E6100000010000000500000037FE4465C3044C400E881057CE644B4037FE4465C3044C40E8667FA0DC644B40EED11BEE23054C40E8667FA0DC644B40EED11BEE23054C400E881057CE644B4037FE4465C3044C400E881057CE644B40
63856	59	55.852536999999998	55.866999999999997	54.794404	54.791367000000001	Летчиков	0103000020E61000000100000005000000A2D0B2EE1FED4B401B118C834B654B40A2D0B2EE1FED4B40E2E7BF07AF654B40E5D022DBF9EE4B40E2E7BF07AF654B40E5D022DBF9EE4B401B118C834B654B40A2D0B2EE1FED4B401B118C834B654B40
63831	59	55.945306000000002	55.963388999999999	54.752557000000003	54.721837999999998	Ленина	0103000020E61000000100000005000000365B79C9FFF84B4049810530655C4B40365B79C9FFF84B401DB0ABC953604B40BF29AC5450FB4B401DB0ABC953604B40BF29AC5450FB4B4049810530655C4B40365B79C9FFF84B4049810530655C4B40
63942	59	55.817647000000001	55.842565999999998	54.703806	54.693213	Левитана	0103000020E6100000010000000500000015562AA8A8E84B40BE141E34BB584B4015562AA8A8E84B40425DA450165A4B405B5CE333D9EB4B40425DA450165A4B405B5CE333D9EB4B40BE141E34BB584B4015562AA8A8E84B40BE141E34BB584B40
63890	59	55.964737	55.966956000000003	54.733426000000001	54.728617999999997	Кустарная	0103000020E61000000100000005000000DE1E84807CFB4B4072A3C85A435D4B40DE1E84807CFB4B409F0436E7E05D4B40E355D636C5FB4B409F0436E7E05D4B40E355D636C5FB4B4072A3C85A435D4B40DE1E84807CFB4B4072A3C85A435D4B40
63869	59	56.096556	56.107334999999999	54.828111999999997	54.817852999999999	Кулибина	0103000020E61000000100000005000000C51D6FF25B0C4C40BEF73768AF684B40C51D6FF25B0C4C406BB6F292FF694B40AB5B3D27BD0D4C406BB6F292FF694B40AB5B3D27BD0D4C40BEF73768AF684B40C51D6FF25B0C4C40BEF73768AF684B40
63877	59	55.92266	55.940832999999998	54.735427999999999	54.732469999999999	Красина	0103000020E61000000100000005000000E7A90EB919F64B408BA6B393C15D4B40E7A90EB919F64B4006483481225E4B40B0FF3A376DF84B4006483481225E4B40B0FF3A376DF84B408BA6B393C15D4B40E7A90EB919F64B408BA6B393C15D4B40
63983	59	56.057442999999999	56.069813000000003	54.818962999999997	54.817692000000001	Космонавтов	0103000020E610000001000000050000002B31CF4A5A074C40B519A721AA684B402B31CF4A5A074C4028D192C7D3684B40F7EAE3A1EF084C4028D192C7D3684B40F7EAE3A1EF084C40B519A721AA684B402B31CF4A5A074C40B519A721AA684B40
63937	59	56.064162000000003	56.069902999999996	54.825327000000001	54.819066999999997	Конституции	0103000020E61000000100000005000000AFD2DD7536084C40CD1DFD2FD7684B40AFD2DD7536084C40BEC0AC50A4694B403672DD94F2084C40BEC0AC50A4694B403672DD94F2084C40CD1DFD2FD7684B40AFD2DD7536084C40CD1DFD2FD7684B40
63901	59	55.989412999999999	56.028418000000002	54.767055999999997	54.737085999999998	Комсомольская	0103000020E610000001000000050000005E9ECE15A5FE4B40732B84D5585E4B405E9ECE15A5FE4B40AC1919E42E624B40124F7633A3034C40AC1919E42E624B40124F7633A3034C40732B84D5585E4B405E9ECE15A5FE4B40732B84D5585E4B40
63852	59	55.925040000000003	55.968339	54.729911999999999	54.714084	Коммунистическая	0103000020E61000000100000005000000F5BEF1B567F64B40664CC11A675B4B40F5BEF1B567F64B409E7AA4C16D5D4B407E384888F2FB4B409E7AA4C16D5D4B407E384888F2FB4B40664CC11A675B4B40F5BEF1B567F64B40664CC11A675B4B40
63907	59	56.110317999999999	56.13194	54.817925000000002	54.807518000000002	Коммунаров	0103000020E610000001000000050000007F1475E61E0E4C403677F4BF5C674B407F1475E61E0E4C4058CA32C4B1684B406284F068E3104C4058CA32C4B1684B406284F068E3104C403677F4BF5C674B407F1475E61E0E4C403677F4BF5C674B40
63830	59	56.061197999999997	56.127628000000001	54.822921000000001	54.810917000000003	Кольцевая	0103000020E61000000100000005000000514A0856D5074C409E62D520CC674B40514A0856D5074C408718AF7955694B40E606431D56104C408718AF7955694B40E606431D56104C409E62D520CC674B40514A0856D5074C409E62D520CC674B40
63917	59	55.946717	55.987886000000003	54.731440999999997	54.724952000000002	Кирова	0103000020E610000001000000050000009BC8CC052EF94B40BC95253ACB5C4B409BC8CC052EF94B400DFAD2DB9F5D4B409016670C73FE4B400DFAD2DB9F5D4B409016670C73FE4B40BC95253ACB5C4B409BC8CC052EF94B40BC95253ACB5C4B40
63948	59	55.946717	55.987886000000003	54.731440999999997	54.724952000000002	Кирова	0103000020E610000001000000050000009BC8CC052EF94B40BC95253ACB5C4B409BC8CC052EF94B400DFAD2DB9F5D4B409016670C73FE4B400DFAD2DB9F5D4B409016670C73FE4B40BC95253ACB5C4B409BC8CC052EF94B40BC95253ACB5C4B40
63815	59	55.946717	55.987886000000003	54.731440999999997	54.724952000000002	Кирова	0103000020E610000001000000050000009BC8CC052EF94B40BC95253ACB5C4B409BC8CC052EF94B400DFAD2DB9F5D4B409016670C73FE4B400DFAD2DB9F5D4B409016670C73FE4B40BC95253ACB5C4B409BC8CC052EF94B40BC95253ACB5C4B40
63919	59	55.899348000000003	55.906255999999999	54.740645999999998	54.736691	Кирзаводская	0103000020E610000001000000050000008CDCD3D51DF34B40F72004E44B5E4B408CDCD3D51DF34B40E4F4F57CCD5E4B40E2E6543200F44B40E4F4F57CCD5E4B40E2E6543200F44B40F72004E44B5E4B408CDCD3D51DF34B40F72004E44B5E4B40
63972	59	56.235326999999998	56.249412999999997	54.755066999999997	54.754156999999999	Касимовская	0103000020E61000000100000005000000D26EF4311F1E4C405586713788604B40D26EF4311F1E4C40F8A41309A6604B403F19E3C3EC1F4C40F8A41309A6604B403F19E3C3EC1F4C405586713788604B40D26EF4311F1E4C405586713788604B40
63845	59	55.936979000000001	55.952933000000002	54.748260000000002	54.717838999999998	Карла Маркса	0103000020E61000000100000005000000F70489EDEEF74B408C65FA25E25B4B40F70489EDEEF74B40D673D2FBC65F4B40BC2363B5F9F94B40D673D2FBC65F4B40BC2363B5F9F94B408C65FA25E25B4B40F70489EDEEF74B408C65FA25E25B4B40
63868	59	56.000202000000002	56.001631000000003	54.742736000000001	54.73968	Казанская	0103000020E6100000010000000500000068B27F9E06004C40ADC090D5AD5E4B4068B27F9E06004C40EBC726F9115F4B4074D4D17135004C40EBC726F9115F4B4074D4D17135004C40ADC090D5AD5E4B4068B27F9E06004C40ADC090D5AD5E4B40
64403	59	55.898648000000001	55.912723999999997	54.523215999999998	54.515528000000003	Искинская	0103000020E61000000100000005000000D34ECDE506F34B400E164ED2FC414B40D34ECDE506F34B40395FECBDF8424B401C23D923D4F44B40395FECBDF8424B401C23D923D4F44B400E164ED2FC414B40D34ECDE506F34B400E164ED2FC414B40
63943	59	56.052959999999999	56.137106000000003	54.811709999999998	54.800454999999999	Интернациональная	0103000020E6100000010000000500000082FFAD64C7064C40B875374F75664B4082FFAD64C7064C4007EBFF1CE6674B40EE0A7DB08C114C4007EBFF1CE6674B40EE0A7DB08C114C40B875374F75664B4082FFAD64C7064C40B875374F75664B40
1402	59	55.946753000000001	55.973422999999997	54.744996	54.738962000000001	Ибрагимова бульвар	0103000020E61000000100000005000000E831CA332FF94B404E7E8B4E965E4B40E831CA332FF94B404ED367075C5F4B404C16F71F99FC4B404ED367075C5F4B404C16F71F99FC4B404E7E8B4E965E4B40E831CA332FF94B404E7E8B4E965E4B40
63874	59	55.948450000000001	55.954585999999999	54.705506999999997	54.690038000000001	Зои Космодемьянской	0103000020E6100000010000000500000013F241CF66F94B40A67F492A53584B4013F241CF66F94B40AE0CAA0D4E5A4B40179CC1DF2FFA4B40AE0CAA0D4E5A4B40179CC1DF2FFA4B40A67F492A53584B4013F241CF66F94B40A67F492A53584B40
63951	59	55.930762000000001	55.938307999999999	54.740147	54.725040999999997	Зенцова	0103000020E61000000100000005000000062E8F3523F74B402BA1BB24CE5C4B40062E8F3523F74B40C39D0B23BD5E4B409FC9FE791AF84B40C39D0B23BD5E4B409FC9FE791AF84B402BA1BB24CE5C4B40062E8F3523F74B402BA1BB24CE5C4B40
63894	59	55.944721999999999	55.949519000000002	54.792037000000001	54.787671000000003	Защитников Отечества	0103000020E61000000100000005000000E6E786A6ECF84B40FA804067D2644B40E6E786A6ECF84B40691CEA7761654B401FF7ADD689F94B40691CEA7761654B401FF7ADD689F94B40FA804067D2644B40E6E786A6ECF84B40FA804067D2644B40
63882	59	55.943069000000001	55.949213999999998	54.746580999999999	54.737262999999999	Запотоцкого	0103000020E610000001000000050000008B6F287CB6F84B4082C64CA25E5E4B408B6F287CB6F84B40516859F78F5F4B40E27327D87FF94B40516859F78F5F4B40E27327D87FF94B4082C64CA25E5E4B408B6F287CB6F84B4082C64CA25E5E4B40
63979	59	55.926755999999997	55.958466999999999	54.722129000000002	54.714374999999997	Заки Валиди	0103000020E6100000010000000500000096AFCBF09FF64B403D0AD7A3705B4B4096AFCBF09FF64B40213F1BB96E5C4B40CAA5F10BAFFA4B40213F1BB96E5C4B40CAA5F10BAFFA4B403D0AD7A3705B4B4096AFCBF09FF64B403D0AD7A3705B4B40
63945	59	55.981948000000003	55.988362000000002	54.697198	54.694445999999999	Загира Исмагилова	0103000020E61000000100000005000000B22FD978B0FD4B40446B459BE3584B40B22FD978B0FD4B40166BB8C83D594B40F94D61A582FE4B40166BB8C83D594B40F94D61A582FE4B40446B459BE3584B40B22FD978B0FD4B40446B459BE3584B40
63930	59	55.992916999999998	55.994498	54.743203000000001	54.741956000000002	Железняцкая	0103000020E610000001000000050000003B527DE717FF4B401689096AF85E4B403B527DE717FF4B4001A5A146215F4B40FDF7E0B54BFF4B4001A5A146215F4B40FDF7E0B54BFF4B401689096AF85E4B403B527DE717FF4B401689096AF85E4B40
7542	59	55.994193000000003	55.998674999999999	54.712387999999997	54.709001999999998	Дуванский бульвар	0103000020E61000000100000005000000C1745AB741FF4B403866D993C05A4B40C1745AB741FF4B400B08AD872F5B4B40992A1895D4FF4B400B08AD872F5B4B40992A1895D4FF4B403866D993C05A4B40C1745AB741FF4B403866D993C05A4B40
63832	59	55.926504000000001	55.977716999999998	54.737012999999997	54.729252000000002	Достоевского	0103000020E610000001000000050000007DCEDDAE97F64B4074452921585D4B407DCEDDAE97F64B4009DD2571565E4B4022DFA5D425FD4B4009DD2571565E4B4022DFA5D425FD4B4074452921585D4B407DCEDDAE97F64B4074452921585D4B40
63956	59	56.085397999999998	56.109293999999998	54.825519	54.820943999999997	Дмитрия Донского	0103000020E6100000010000000500000068925852EE0A4C4078EC67B114694B4068925852EE0A4C40029D499BAA694B4013D38558FD0D4C40029D499BAA694B4013D38558FD0D4C4078EC67B114694B4068925852EE0A4C4078EC67B114694B40
64415	59	55.943598999999999	55.948118000000001	54.708181000000003	54.696376000000001	Демская	0103000020E61000000100000005000000E7C41EDAC7F84B4012DC48D922594B40E7C41EDAC7F84B400553CDACA55A4B40DD5F3DEE5BF94B400553CDACA55A4B40DD5F3DEE5BF94B4012DC48D922594B40E7C41EDAC7F84B4012DC48D922594B40
63880	59	56.044013	56.045279999999998	54.790646000000002	54.786430000000003	Даута Юлтыя	0103000020E61000000100000005000000A7CCCD37A2054C40F14BFDBCA9644B40A7CCCD37A2054C404B5B5CE333654B40D9942BBCCB054C404B5B5CE333654B40D9942BBCCB054C40F14BFDBCA9644B40A7CCCD37A2054C40F14BFDBCA9644B40
63961	59	55.831623999999998	55.844569	54.713532999999998	54.704529000000001	Дагестанская	0103000020E61000000100000005000000CB48BDA772EA4B40B30A9B012E5A4B40CB48BDA772EA4B40F2CEA10C555B4B40931B45D61AEC4B40F2CEA10C555B4B40931B45D61AEC4B40B30A9B012E5A4B40CB48BDA772EA4B40B30A9B012E5A4B40
63921	59	56.095261999999998	56.098370000000003	54.815378000000003	54.811804000000002	Гончарова	0103000020E610000001000000050000009946938B310C4C4089618731E9674B409946938B310C4C405FF0694E5E684B402A745E63970C4C405FF0694E5E684B402A745E63970C4C4089618731E9674B409946938B310C4C4089618731E9674B40
64572	59	55.824052000000002	55.849240000000002	54.691932999999999	54.688701000000002	Глазовская	0103000020E61000000100000005000000091A33897AE94B407BDCB75A27584B40091A33897AE94B40F702B34291584B403F3A75E5B3EC4B40F702B34291584B403F3A75E5B3EC4B407BDCB75A27584B40091A33897AE94B407BDCB75A27584B40
63926	59	56.112689000000003	56.116560999999997	54.783330999999997	54.774555999999997	Георгия Мушникова	0103000020E610000001000000050000003ACFD8976C0E4C40D575A8A624634B403ACFD8976C0E4C40B378B13044644B40997E8978EB0E4C40B378B13044644B40997E8978EB0E4C40D575A8A624634B403ACFD8976C0E4C40D575A8A624634B40
63342	59	55.925542999999998	55.934202999999997	54.738598000000003	54.720765999999998	Гафури	0103000020E6100000010000000500000057056A3178F64B40CC086F0F425C4B4057056A3178F64B400D7217618A5E4B409C69C2F693F74B400D7217618A5E4B409C69C2F693F74B40CC086F0F425C4B4057056A3178F64B40CC086F0F425C4B40
64558	59	56.132379999999998	56.138218999999999	54.691074	54.687015000000002	Галечная	0103000020E610000001000000050000007E52EDD3F1104C40446E861BF0574B407E52EDD3F1104C40D68EE21C75584B40C9570229B1114C40D68EE21C75584B40C9570229B1114C40446E861BF0574B407E52EDD3F1104C40446E861BF0574B40
63949	59	55.911906999999999	55.922983000000002	54.742542999999998	54.737023999999998	Выгонная	0103000020E610000001000000050000002AFF5A5EB9F44B40FD2E6CCD565E4B402AFF5A5EB9F44B40D66F26A60B5F4B40CAE1934E24F64B40D66F26A60B5F4B40CAE1934E24F64B40FD2E6CCD565E4B402AFF5A5EB9F44B40FD2E6CCD565E4B40
63836	59	56.108117	56.137106000000003	54.823630999999999	54.802754	Вологодская	0103000020E61000000100000005000000219221C7D60D4C40D95DA0A4C0664B40219221C7D60D4C40637C98BD6C694B40EE0A7DB08C114C40637C98BD6C694B40EE0A7DB08C114C40D95DA0A4C0664B40219221C7D60D4C40D95DA0A4C0664B40
63875	59	55.934679000000003	55.963290000000001	54.752499999999998	54.743291999999997	Вокзальная	0103000020E6100000010000000500000006A1BC8FA3F74B4070B03731245F4B4006A1BC8FA3F74B40B81E85EB51604B402C4833164DFB4B40B81E85EB51604B402C4833164DFB4B4070B03731245F4B4006A1BC8FA3F74B4070B03731245F4B40
63981	59	55.984364999999997	55.988542000000002	54.735714000000002	54.726018000000003	Владивостокская	0103000020E61000000100000005000000DC291DACFFFD4B4057276728EE5C4B40DC291DACFFFD4B40CC9A58E02B5E4B40795C548B88FE4B40CC9A58E02B5E4B40795C548B88FE4B4057276728EE5C4B40DC291DACFFFD4B4057276728EE5C4B40
63866	59	56.107210000000002	56.123002	54.818537999999997	54.806708999999998	Борисоглебская	0103000020E61000000100000005000000EFE6A90EB90D4C40C631923D42674B40EFE6A90EB90D4C4041446ADAC5684B40DAAB8F87BE0F4C4041446ADAC5684B40DAAB8F87BE0F4C40C631923D42674B40EFE6A90EB90D4C40C631923D42674B40
63853	59	56.020674999999997	56.032955000000001	54.795105	54.775818000000001	Блюхера	0103000020E61000000100000005000000226C787AA5024C40F6D214014E634B40226C787AA5024C406BF12900C6654B40AE9E93DE37044C406BF12900C6654B40AE9E93DE37044C40F6D214014E634B40226C787AA5024C40F6D214014E634B40
66508	59	56.036827000000002	56.042943999999999	54.899394999999998	54.885156000000002	Биологическая	0103000020E610000001000000050000000E4E44BFB6044C40D9EDB3CA4C714B400E4E44BFB6044C40CC9717601F734B409BC761307F054C40CC9717601F734B409BC761307F054C40D9EDB3CA4C714B400E4E44BFB6044C40D9EDB3CA4C714B40
63834	59	55.95402	55.959778	54.750053000000001	54.741421000000003	Белякова	0103000020E610000001000000050000006EDDCD531DFA4B40A8C821E2E65E4B406EDDCD531DFA4B4023A298BC01604B40CCB56801DAFA4B4023A298BC01604B40CCB56801DAFA4B40A8C821E2E65E4B406EDDCD531DFA4B40A8C821E2E65E4B40
66542	59	56.039881000000001	56.043554999999998	54.761882999999997	54.753019000000002	Белоозерская	0103000020E61000000100000005000000AB5D13D21A054C40212235ED62604B40AB5D13D21A054C406E30D46185614B40E449D23593054C406E30D46185614B40E449D23593054C40212235ED62604B40AB5D13D21A054C40212235ED62604B40
63395	59	56.049241000000002	56.069229	54.772494000000002	54.761102999999999	Баязита Бикбая	0103000020E61000000100000005000000A94F72874D064C4099F1B6D26B614B40A94F72874D064C40992D5915E1624B40A777F17EDC084C40992D5915E1624B40A777F17EDC084C4099F1B6D26B614B40A94F72874D064C4099F1B6D26B614B40
63839	59	55.999789	56.008645999999999	54.708893000000003	54.707425999999998	Батырская	0103000020E6100000010000000500000045F30016F9FF4B40882B67EF8C5A4B4045F30016F9FF4B4082AE7D01BD5A4B40E09EE74F1B014C4082AE7D01BD5A4B40E09EE74F1B014C40882B67EF8C5A4B4045F30016F9FF4B40882B67EF8C5A4B40
63906	59	55.976604000000002	55.987797	54.744689999999999	54.742206000000003	Бабушкина	0103000020E610000001000000050000004792205C01FD4B408F72309B005F4B404792205C01FD4B4041D47D00525F4B40200BD12170FE4B4041D47D00525F4B40200BD12170FE4B408F72309B005F4B404792205C01FD4B408F72309B005F4B40
63829	59	55.872695	55.907496000000002	54.794719999999998	54.757061999999998	Ахметова	0103000020E61000000100000005000000FD304278B4EF4B40AD855968E7604B40FD304278B4EF4B4012BD8C62B9654B401BA034D428F44B4012BD8C62B9654B401BA034D428F44B40AD855968E7604B40FD304278B4EF4B40AD855968E7604B40
63955	59	55.994695999999998	55.999977999999999	54.718114	54.712758000000001	Акназарова	0103000020E6100000010000000500000023BBD23252FF4B402FFB75A73B5B4B4023BBD23252FF4B405E66D828EB5B4B40185C7347FFFF4B405E66D828EB5B4B40185C7347FFFF4B402FFB75A73B5B4B4023BBD23252FF4B402FFB75A73B5B4B40
63898	59	56.064791	56.085011999999999	54.774009999999997	54.773356	Академика Королева	0103000020E610000001000000050000009E094D124B084C402B155454FD624B409E094D124B084C4073637AC212634B403FE257ACE10A4C4073637AC212634B403FE257ACE10A4C402B155454FD624B409E094D124B084C402B155454FD624B40
63941	59	56.054774999999999	56.056885999999999	54.796993999999998	54.791367000000001	Адмирала Макарова	0103000020E61000000100000005000000B7D100DE02074C401B118C834B654B40B7D100DE02074C40DA8D3EE603664B40D5CC5A0A48074C40DA8D3EE603664B40D5CC5A0A48074C401B118C834B654B40B7D100DE02074C401B118C834B654B40
63959	59	56.001944999999999	56.008645999999999	54.707425999999998	54.693046000000002	Авроры	0103000020E6100000010000000500000003B2D7BB3F004C40D34F38BBB5584B4003B2D7BB3F004C40882B67EF8C5A4B40E09EE74F1B014C40882B67EF8C5A4B40E09EE74F1B014C40D34F38BBB5584B4003B2D7BB3F004C40D34F38BBB5584B40
65686	59	56.001944999999999	56.008645999999999	54.707425999999998	54.693046000000002	Авроры	0103000020E6100000010000000500000003B2D7BB3F004C40D34F38BBB5584B4003B2D7BB3F004C40882B67EF8C5A4B40E09EE74F1B014C40882B67EF8C5A4B40E09EE74F1B014C40D34F38BBB5584B4003B2D7BB3F004C40D34F38BBB5584B40
63883	59	55.764502	56.311235000000003	54.968240999999999	54.492655999999997	8 Марта	0103000020E6100000010000000500000001DD9733DBE14B40CE16105A0F3F4B4001DD9733DBE14B40BBD23252EF7B4B406F2F698CD6274C40BBD23252EF7B4B406F2F698CD6274C40CE16105A0F3F4B4001DD9733DBE14B40CE16105A0F3F4B40
63929	59	55.958053	55.983763000000003	54.739103	54.735182999999999	50-летия Октября	0103000020E61000000100000005000000D76A0F7BA1FA4B409FC9FE791A5E4B40D76A0F7BA1FA4B4010B056ED9A5E4B40E7012CF2EBFD4B4010B056ED9A5E4B40E7012CF2EBFD4B409FC9FE791A5E4B40D76A0F7BA1FA4B409FC9FE791A5E4B40
63867	59	55.764502	56.311235000000003	54.968240999999999	54.492655999999997	50 Лет СССР	0103000020E6100000010000000500000001DD9733DBE14B40CE16105A0F3F4B4001DD9733DBE14B40BBD23252EF7B4B406F2F698CD6274C40BBD23252EF7B4B406F2F698CD6274C40CE16105A0F3F4B4001DD9733DBE14B40CE16105A0F3F4B40
63843	59	56.049025999999998	56.079155	54.779961	54.763933999999999	 Юрия Гагарина	0103000020E61000000100000005000000AC53E57B46064C40B726DD96C8614B40AC53E57B46064C40E69315C3D5634B404E2844C0210A4C40E69315C3D5634B404E2844C0210A4C40B726DD96C8614B40AC53E57B46064C40B726DD96C8614B40
66948	59	56.036358999999997	56.060371000000004	54.792883000000003	54.790531999999999	 Шота Руставели	0103000020E6100000010000000500000027F56569A7044C4082380F2730654B4027F56569A7044C40F646AD307D654B403C50A73CBA074C40F646AD307D654B403C50A73CBA074C4082380F2730654B4027F56569A7044C4082380F2730654B40
63947	59	56.09731	56.130844000000003	54.814132999999998	54.806412999999999	 Черниковская	0103000020E6100000010000000500000071C971A7740C4C40DD088B8A38674B4071C971A7740C4C4014CC988235684B405D70067FBF104C4014CC988235684B405D70067FBF104C40DD088B8A38674B4071C971A7740C4C40DD088B8A38674B40
66943	59	55.968877999999997	55.992080999999999	54.701245999999998	54.685921999999998	 Пугачева	0103000020E610000001000000050000002DE8BD3104FC4B40AFCDC64ACC574B402DE8BD3104FC4B40B439CE6DC2594B40D2FD9C82FCFE4B40B439CE6DC2594B40D2FD9C82FCFE4B40AFCDC64ACC574B402DE8BD3104FC4B40AFCDC64ACC574B40
66539	59	55.864699999999999	55.865670999999999	54.704503000000003	54.700695000000003	 Молодежная	0103000020E61000000100000005000000F46C567DAEEE4B4041BCAE5FB0594B40F46C567DAEEE4B408A7780272D5A4B403D0CAD4ECEEE4B408A7780272D5A4B403D0CAD4ECEEE4B4041BCAE5FB0594B40F46C567DAEEE4B4041BCAE5FB0594B40
63962	59	55.898926000000003	55.911870999999998	54.743344	54.740501000000002	 Лесозаводская	0103000020E6100000010000000500000016C3D50110F34B40E1D39CBCC85E4B4016C3D50110F34B40C3D66CE5255F4B40DD955D30B8F44B40C3D66CE5255F4B40DD955D30B8F44B40E1D39CBCC85E4B4016C3D50110F34B40E1D39CBCC85E4B40
63939	59	55.946717	55.987886000000003	54.731440999999997	54.724952000000002	 Кирова	0103000020E610000001000000050000009BC8CC052EF94B40BC95253ACB5C4B409BC8CC052EF94B400DFAD2DB9F5D4B409016670C73FE4B400DFAD2DB9F5D4B409016670C73FE4B40BC95253ACB5C4B409BC8CC052EF94B40BC95253ACB5C4B40
63971	59	55.831623999999998	55.844569	54.713532999999998	54.704529000000001	 Дагестанская	0103000020E61000000100000005000000CB48BDA772EA4B40B30A9B012E5A4B40CB48BDA772EA4B40F2CEA10C555B4B40931B45D61AEC4B40F2CEA10C555B4B40931B45D61AEC4B40B30A9B012E5A4B40CB48BDA772EA4B40B30A9B012E5A4B40
66938	59	55.815328999999998	55.824869	54.710438000000003	54.696876000000003	 Грозненская	0103000020E610000001000000050000007D3D5FB35CE84B4004AF963B33594B407D3D5FB35CE84B40F7EAE3A1EF5A4B40FB3DB14E95E94B40F7EAE3A1EF5A4B40FB3DB14E95E94B4004AF963B33594B407D3D5FB35CE84B4004AF963B33594B40
63966	59	56.049025999999998	56.079155	54.779961	54.763933999999999	 Гагарина	0103000020E61000000100000005000000AC53E57B46064C40B726DD96C8614B40AC53E57B46064C40E69315C3D5634B404E2844C0210A4C40E69315C3D5634B404E2844C0210A4C40B726DD96C8614B40AC53E57B46064C40B726DD96C8614B40
65095	58354	55.534838999999998	55.551915999999999	55.836801999999999	55.827033999999998	Центральная	0103000020E610000001000000050000000BD0B69A75C44B400C570740DCE94B400BD0B69A75C44B401B9DF3531CEB4B40CF11F92EA5C64B401B9DF3531CEB4B40CF11F92EA5C64B400C570740DCE94B400BD0B69A75C44B400C570740DCE94B40
64736	58333	57.501170000000002	57.520816000000003	54.230038	54.224248000000003	Ленина	0103000020E6100000010000000500000040DEAB5626C04C40C2189128B41C4B4040DEAB5626C04C402B6B9BE2711D4B40E59D4319AAC24C402B6B9BE2711D4B40E59D4319AAC24C40C2189128B41C4B4040DEAB5626C04C40C2189128B41C4B40
63814	9468	55.897354	55.902240999999997	54.570900999999999	54.569184	Строителей	0103000020E61000000100000005000000A777F17EDCF24B4007B47405DB484B40A777F17EDCF24B407920B24813494B401F0E12A27CF34B407920B24813494B401F0E12A27CF34B4007B47405DB484B40A777F17EDCF24B4007B47405DB484B40
65609	58578	56.865873000000001	56.901626	56.094253999999999	56.080205999999997	Ленина	0103000020E61000000100000005000000A5BE2CEDD46E4C40B378B130440A4C40A5BE2CEDD46E4C4033C2DB83100C4C40959C137B68734C4033C2DB83100C4C40959C137B68734C40B378B130440A4C40A5BE2CEDD46E4C40B378B130440A4C40
64932	58401	54.227431000000003	54.266129999999997	55.331608000000003	55.313279999999999	Р.Хайри	0103000020E610000001000000050000005D8C81751C1D4B40D53E1D8F19A84B405D8C81751C1D4B40C68B852172AA4B40033E3F8C10224B40C68B852172AA4B40033E3F8C10224B40D53E1D8F19A84B405D8C81751C1D4B40D53E1D8F19A84B40
64056	58158	56.653502000000003	56.677694000000002	55.743335000000002	55.729244999999999	Корочкина	0103000020E6100000010000000500000070EF1AF4A5534C40C1E270E657DD4B4070EF1AF4A5534C40707CED9925DF4B4004594FADBE564C40707CED9925DF4B4004594FADBE564C40C1E270E657DD4B4070EF1AF4A5534C40C1E270E657DD4B40
64829	58367	53.792566000000001	53.823943999999997	55.320995000000003	55.300033999999997	Октябрьская	0103000020E61000000100000005000000F5F57CCD72E54A4012D89C8367A64B40F5F57CCD72E54A40FB96395D16A94B4022DE3AFF76E94A40FB96395D16A94B4022DE3AFF76E94A4012D89C8367A64B40F5F57CCD72E54A4012D89C8367A64B40
65727	58612	55.184936	55.205615000000002	54.496479000000001	54.486041	Школьная	0103000020E6100000010000000500000031ED9BFBAB974B40F0C16B97363E4B4031ED9BFBAB974B404D13B69F8C3F4B409548A297519A4B404D13B69F8C3F4B409548A297519A4B40F0C16B97363E4B4031ED9BFBAB974B40F0C16B97363E4B40
65532	58561	55.198950000000004	55.226087999999997	53.497017	53.485151000000002	Школьная	0103000020E6100000010000000500000005C58F3177994B40944F8F6D19BE4A4005C58F3177994B402C47C8409EBF4A404F029B73F09C4B402C47C8409EBF4A404F029B73F09C4B40944F8F6D19BE4A4005C58F3177994B40944F8F6D19BE4A40
64200	58188	53.778039999999997	53.811214999999997	54.694133999999998	54.673105999999997	Клубная	0103000020E610000001000000050000006B7D91D096E34A40E55E605628564B406B7D91D096E34A4055850662D9584B402783A3E4D5E74A4055850662D9584B402783A3E4D5E74A40E55E605628564B406B7D91D096E34A40E55E605628564B40
65075	58461	55.477203000000003	55.485495	52.737225000000002	52.73169	Интернациональная	0103000020E61000000100000005000000CC46E7FC14BD4B40B6679604A85D4A40CC46E7FC14BD4B40956588635D5E4A408EAF3DB324BE4B40956588635D5E4A408EAF3DB324BE4B40B6679604A85D4A40CC46E7FC14BD4B40B6679604A85D4A40
65076	58462	55.702185999999998	55.723108000000003	56.085836999999998	56.069876000000001	Октябрьская	0103000020E61000000100000005000000C2DA183BE1D94B403D635FB2F1084C40C2DA183BE1D94B40B4E4F1B4FC0A4C40EDBC8DCD8EDC4B40B4E4F1B4FC0A4C40EDBC8DCD8EDC4B403D635FB2F1084C40C2DA183BE1D94B403D635FB2F1084C40
63544	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	проспект Ленина	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63774	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	площадь Октября	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63425	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	микрорайон Молодежный	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63548	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Южная	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63428	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Чехова	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63707	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Чапаева	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63313	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Советская	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63765	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	С.Юлаева	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63679	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Островского	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63682	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Ленина	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63290	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Комарова	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63535	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Зеленая	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63670	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Губкина	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63770	58096	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Гафурова	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
65669	58593	54.999828999999998	55.013007999999999	55.774436000000001	55.763376000000001	Садовая	0103000020E61000000100000005000000D34B8C65FA7F4B409146054EB6E14B40D34B8C65FA7F4B402B6C06B820E34B400E4B033FAA814B402B6C06B820E34B400E4B033FAA814B409146054EB6E14B40D34B8C65FA7F4B409146054EB6E14B40
64402	27931	55.951189999999997	55.986961000000001	54.943871000000001	54.918649000000002	Луговая	0103000020E6100000010000000500000020240B98C0F94B4066C0594A96754B4020240B98C0F94B404852D2C3D0784B40B7B6F0BC54FE4B404852D2C3D0784B40B7B6F0BC54FE4B4066C0594A96754B4020240B98C0F94B4066C0594A96754B40
65577	58570	56.067118000000001	56.094974999999998	56.115158000000001	56.093214000000003	Центральная	0103000020E61000000100000005000000897C975297084C40C2C3B46FEE0B4C40897C975297084C40B7EF517FBD0E4C4003780B24280C4C40B7EF517FBD0E4C4003780B24280C4C40C2C3B46FEE0B4C40897C975297084C40C2C3B46FEE0B4C40
64164	58179	58.551291999999997	58.608012000000002	54.228022000000003	54.187010999999998	Полуэктова	0103000020E61000000100000005000000F1457BBC90464D40027FF8F9EF174B40F1457BBC90464D405F622CD32F1D4B40ACC95356D34D4D405F622CD32F1D4B40ACC95356D34D4D40027FF8F9EF174B40F1457BBC90464D40027FF8F9EF174B40
64982	58425	55.320753000000003	55.347459000000001	52.672941999999999	52.663466999999997	Центральная	0103000020E61000000100000005000000058C2E6F0EA94B40D47C957CEC544A40058C2E6F0EA94B406B0DA5F622564A40B6D9588979AC4B406B0DA5F622564A40B6D9588979AC4B40D47C957CEC544A40058C2E6F0EA94B40D47C957CEC544A40
65093	58468	55.495699000000002	55.517519	56.053527000000003	56.037180999999997	Мелиораторов	0103000020E6100000010000000500000078D4981073BF4B402B84D558C2044C4078D4981073BF4B40FC3905F9D9064C40810706103EC24B40FC3905F9D9064C40810706103EC24B402B84D558C2044C4078D4981073BF4B402B84D558C2044C40
65738	58615	54.013165000000001	54.038111000000001	54.929720000000003	54.921422	Рабочая	0103000020E61000000100000005000000D6390664AF014B404FE8F527F1754B40D6390664AF014B40F437A11001774B40164F3DD2E0044B40F437A11001774B40164F3DD2E0044B404FE8F527F1754B40D6390664AF014B404FE8F527F1754B40
65064	58456	58.675232000000001	58.689076	53.477274000000001	53.466473999999998	Коммунистическая	0103000020E61000000100000005000000399B8E006E564D409737876BB5BB4A40399B8E006E564D40959D7E5017BD4A40B03A72A433584D40959D7E5017BD4A40B03A72A433584D409737876BB5BB4A40399B8E006E564D409737876BB5BB4A40
63783	58131	54.254900999999997	54.296996	56.054884999999999	56.039163000000002	Чеверева	0103000020E61000000100000005000000DD5B9198A0204B404C1B0E4B03054C40DD5B9198A0204B403E05C07806074C407B8505F703264B403E05C07806074C407B8505F703264B404C1B0E4B03054C40DD5B9198A0204B404C1B0E4B03054C40
65052	58449	54.952568999999997	54.965207999999997	53.467503000000001	53.455843000000002	Школьная	0103000020E610000001000000050000007A17EFC7ED794B40268E3C1059BA4A407A17EFC7ED794B4015E46723D7BB4A4035EB8CEF8B7B4B4015E46723D7BB4A4035EB8CEF8B7B4B40268E3C1059BA4A407A17EFC7ED794B40268E3C1059BA4A40
64747	58335	55.152929	55.164383000000001	55.559002	55.550417000000003	Октябрьской Революции	0103000020E6100000010000000500000014CE6E2D93934B40CB14731074C64B4014CE6E2D93934B400533A6608DC74B405A828C800A954B400533A6608DC74B405A828C800A954B40CB14731074C64B4014CE6E2D93934B40CB14731074C64B40
65186	58489	58.137169	58.170155000000001	55.215913999999998	55.199587999999999	Школьная	0103000020E610000001000000050000003483F8C08E114D4047567E198C994B403483F8C08E114D40D05FE811A39B4B401D2098A3C7154D40D05FE811A39B4B401D2098A3C7154D4047567E198C994B403483F8C08E114D4047567E198C994B40
66139	58714	54.875861999999998	54.893613000000002	55.222154000000003	55.208855999999997	Ф. Алтайского	0103000020E6100000010000000500000092E7FA3E1C704B4064C91CCBBB9A4B4092E7FA3E1C704B407A56D28A6F9C4B40E62329E961724B407A56D28A6F9C4B40E62329E961724B4064C91CCBBB9A4B4092E7FA3E1C704B4064C91CCBBB9A4B40
64397	8259	55.767035999999997	55.811250999999999	54.619813000000001	54.592137999999998	Центральная	0103000020E61000000100000005000000656D533C2EE24B40035C902DCB4B4B40656D533C2EE24B405D514A08564F4B4074ECA012D7E74B405D514A08564F4B4074ECA012D7E74B40035C902DCB4B4B40656D533C2EE24B40035C902DCB4B4B40
64810	58357	54.548704000000001	54.567425	53.600261000000003	53.588402000000002	Советская	0103000020E610000001000000050000009A97C3EE3B464B405473B9C150CB4A409A97C3EE3B464B403A083A5AD5CC4A4066F7E461A1484B403A083A5AD5CC4A4066F7E461A1484B405473B9C150CB4A409A97C3EE3B464B405473B9C150CB4A40
65320	58521	53.477229999999999	53.503433999999999	54.989212999999999	54.976281999999998	Родниковая	0103000020E61000000100000005000000C55565DF15BD4A4034D6FECEF67C4B40C55565DF15BD4A4097E315889E7E4B40E4D87A8670C04A4097E315889E7E4B40E4D87A8670C04A4034D6FECEF67C4B40C55565DF15BD4A4034D6FECEF67C4B40
64840	58371	55.428711999999997	55.461041999999999	53.300584000000001	53.288915000000003	Комсомольская	0103000020E610000001000000050000008DB3E908E0B64B407429AE2AFBA44A408DB3E908E0B64B40B6D9588979A64A408D0A9C6C03BB4B40B6D9588979A64A408D0A9C6C03BB4B407429AE2AFBA44A408DB3E908E0B64B407429AE2AFBA44A40
66225	58731	56.438059000000003	56.458962999999997	55.735799	55.723638000000001	Нагорная	0103000020E61000000100000005000000F75B3B5112384C404912842BA0DC4B40F75B3B5112384C40FAB660A92EDE4B407A89B14CBF3A4C40FAB660A92EDE4B407A89B14CBF3A4C404912842BA0DC4B40F75B3B5112384C404912842BA0DC4B40
64805	1043	55.932513999999998	55.973855	54.473543999999997	54.450386999999999	Пушкина	0103000020E61000000100000005000000F487669E5CF74B4093C5FD47A6394B40F487669E5CF74B40C79BFC169D3C4B40E605D847A7FC4B40C79BFC169D3C4B40E605D847A7FC4B4093C5FD47A6394B40F487669E5CF74B4093C5FD47A6394B40
64626	58304	53.479681999999997	53.492528	54.114589000000002	54.103456999999999	Комсомольская	0103000020E610000001000000050000006C3D433866BD4A4069C537143E0D4B406C3D433866BD4A409DBD33DAAA0E4B40A12E52280BBF4A409DBD33DAAA0E4B40A12E52280BBF4A4069C537143E0D4B406C3D433866BD4A4069C537143E0D4B40
64824	58362	53.804468	53.821159000000002	54.567602000000001	54.560769000000001	Ленина	0103000020E61000000100000005000000DA56B3CEF8E64A4029CE5147C7474B40DA56B3CEF8E64A407592AD2EA7484B4075E8F4BC1BE94A407592AD2EA7484B4075E8F4BC1BE94A4029CE5147C7474B40DA56B3CEF8E64A4029CE5147C7474B40
64562	33034	55.879629999999999	55.880744	54.521355	54.517257999999998	Школьная	0103000020E610000001000000050000004D4A41B797F04B4014CC988235424B404D4A41B797F04B40944DB9C2BB424B40F9122A38BCF04B40944DB9C2BB424B40F9122A38BCF04B4014CC988235424B404D4A41B797F04B4014CC988235424B40
63259	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	проспект Октября	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63446	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	проспект Ленина	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63497	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Южная	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63457	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Элеваторная	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63587	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Шафиева	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63451	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Шаймуратова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63575	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Чехова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63381	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Худайбердина	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63499	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Фучика	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63353	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Тукаева	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63635	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Суханова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63453	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Стерлибашевский тракт	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63256	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Социалистическая	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63627	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Сакко и Ванцетти	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63785	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Сазонова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63784	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Революционная	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63597	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Проспект Ленина	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63625	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Полевая	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63260	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Паровозная	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63631	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Островского	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63995	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Оренбургский тракт	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63356	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Октября проспект	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63257	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Одесская	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63532	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Николаева	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63715	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Мира	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63534	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Макаренко	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63718	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Лесная	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63504	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Ленина проспект	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63455	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Л. Толстого	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63508	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Курчатова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63354	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Коммунистическая	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63362	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Комарова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63355	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	К. Маркса	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
64094	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Ивлева	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63258	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Ибрагимова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63589	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Дружбы	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63358	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Голикова	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63489	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Гоголя	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63588	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Волочаевская	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
62314	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Вокзальная	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63628	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Воинов-интернационалистов	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63439	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Бородина	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63393	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Блюхера	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63363	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	Артема	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63591	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	А. Невского	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63712	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	23 Мая	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
63262	15983	55.897255000000001	56.026873000000002	53.717177	53.585965000000002	 Гоголя	0103000020E6100000010000000500000014967840D9F24B40E2CCAFE600CB4A4014967840D9F24B40C138B874CCDB4A409D12109370034C40C138B874CCDB4A409D12109370034C40E2CCAFE600CB4A4014967840D9F24B40E2CCAFE600CB4A40
64830	58368	55.474041	55.499526000000003	56.259887999999997	56.243724999999998	Центральная	0103000020E6100000010000000500000048FB1F60ADBC4B40DA1B7C61321F4C4048FB1F60ADBC4B40B94F8E0244214C4038C0CC77F0BF4B40B94F8E0244214C4038C0CC77F0BF4B40DA1B7C61321F4C4048FB1F60ADBC4B40DA1B7C61321F4C40
65393	58538	55.375540999999998	55.409334999999999	53.488692999999998	53.479182000000002	Молодёжная	0103000020E6100000010000000500000050A73CBA11B04B407B6AF5D555BD4A4050A73CBA11B04B405E64027E8DBE4A40D80DDB1665B44B405E64027E8DBE4A40D80DDB1665B44B407B6AF5D555BD4A4050A73CBA11B04B407B6AF5D555BD4A40
65219	58498	56.732410000000002	56.757221999999999	55.900950000000002	55.885666000000001	Салавата	0103000020E61000000100000005000000B6A1629CBF5D4C40EE96E4805DF14B40B6A1629CBF5D4C4065AA605452F34B40E6E786A6EC604C4065AA605452F34B40E6E786A6EC604C40EE96E4805DF14B40B6A1629CBF5D4C40EE96E4805DF14B40
64269	32224	56.035398000000001	56.079954999999998	54.583029000000003	54.552509000000001	Октября	0103000020E61000000100000005000000022CF2EB87044C4072DF6A9DB8464B40022CF2EB87044C404FCFBBB1A04A4B406A1327F73B0A4C404FCFBBB1A04A4B406A1327F73B0A4C4072DF6A9DB8464B40022CF2EB87044C4072DF6A9DB8464B40
64641	58311	55.641730000000003	55.661572999999997	55.969828999999997	55.958320999999998	Школьная	0103000020E61000000100000005000000596E693524D24B40F6083543AAFA4B40596E693524D24B402FDB4E5B23FC4B4053758F6CAED44B402FDB4E5B23FC4B4053758F6CAED44B40F6083543AAFA4B40596E693524D24B40F6083543AAFA4B40
64797	58352	53.717880000000001	53.751153000000002	55.135840000000002	55.112009999999998	Миасара Басырова	0103000020E61000000100000005000000EB39E97DE3DB4A409869FB57568E4B40EB39E97DE3DB4A408CBE823463914B406AA510C825E04A408CBE823463914B406AA510C825E04A409869FB57568E4B40EB39E97DE3DB4A409869FB57568E4B40
64684	58319	54.834736999999997	54.857761000000004	55.454799999999999	55.436632000000003	Матросова	0103000020E610000001000000050000006DE179A9D86A4B408C31B08EE3B74B406DE179A9D86A4B40431CEBE236BA4B406364C91CCB6D4B40431CEBE236BA4B406364C91CCB6D4B408C31B08EE3B74B406DE179A9D86A4B408C31B08EE3B74B40
64998	58433	55.792026999999997	55.802931999999998	52.435746000000002	52.429870999999999	Школьная	0103000020E610000001000000050000004546072461E54B40D93F4F0306374A404546072461E54B4071AE6186C6374A40B874CC79C6E64B4071AE6186C6374A40B874CC79C6E64B40D93F4F0306374A404546072461E54B40D93F4F0306374A40
65382	58534	55.514645000000002	55.527858999999999	54.279753999999997	54.268166999999998	Центральная	0103000020E6100000010000000500000064062AE3DFC14B40E76ED74B53224B4064062AE3DFC14B406C76A4FACE234B401BF33AE290C34B406C76A4FACE234B401BF33AE290C34B40E76ED74B53224B4064062AE3DFC14B40E76ED74B53224B40
64708	58325	56.840198999999998	56.871352000000002	56.094906000000002	56.088749999999997	Комсомольская	0103000020E61000000100000005000000E2900DA48B6B4C408FC2F5285C0B4C40E2900DA48B6B4C40DB183BE1250C4C40F0A65B76886F4C40DB183BE1250C4C40F0A65B76886F4C408FC2F5285C0B4C40E2900DA48B6B4C408FC2F5285C0B4C40
65940	58668	54.939273999999997	54.960546000000001	55.59543	55.58379	Ленина	0103000020E61000000100000005000000D6FD63213A784B40ADDD76A1B9CA4B40D6FD63213A784B405587DC0C37CC4B40DD26DC2BF37A4B405587DC0C37CC4B40DD26DC2BF37A4B40ADDD76A1B9CA4B40D6FD63213A784B40ADDD76A1B9CA4B40
65719	58608	55.044646	55.063294999999997	55.080627	55.068570999999999	Днепр	0103000020E61000000100000005000000D8F2CAF5B6854B401D3A3DEFC6884B40D8F2CAF5B6854B4059164CFC518A4B400A80F10C1A884B4059164CFC518A4B400A80F10C1A884B401D3A3DEFC6884B40D8F2CAF5B6854B401D3A3DEFC6884B40
65764	58625	54.169687000000003	54.205027000000001	55.080457000000003	55.070895999999998	Центральная	0103000020E6100000010000000500000037C7B94DB8154B4067B5C01E13894B4037C7B94DB8154B40FDDD3B6A4C8A4B4004E621533E1A4B40FDDD3B6A4C8A4B4004E621533E1A4B4067B5C01E13894B4037C7B94DB8154B4067B5C01E13894B40
65325	58522	56.58276	56.614173999999998	55.204535999999997	55.195365000000002	Центральная	0103000020E610000001000000050000005FB532E1974A4C403BE466B801994B405FB532E1974A4C40656D533C2E9A4B40D906EE409D4E4C40656D533C2E9A4B40D906EE409D4E4C403BE466B801994B405FB532E1974A4C403BE466B801994B40
64975	58422	55.289895000000001	55.311813999999998	55.154758999999999	55.143234999999997	Школьная	0103000020E61000000100000005000000102384471BA54B403F52448655924B40102384471BA54B407EE19524CF934B40AC376A85E9A74B407EE19524CF934B40AC376A85E9A74B403F52448655924B40102384471BA54B403F52448655924B40
64494	58245	56.129362	56.147615999999999	54.195276999999997	54.182738000000001	Садовая	0103000020E610000001000000050000002EAC1BEF8E104C4044DE72F563174B402EAC1BEF8E104C409B5434D6FE184B40E42EC214E5124C409B5434D6FE184B40E42EC214E5124C4044DE72F563174B402EAC1BEF8E104C4044DE72F563174B40
65676	58594	54.977559999999997	54.998033	54.131601000000003	54.122405000000001	Энгельса	0103000020E610000001000000050000005AF0A2AF207D4B40F6EE8FF7AA0F4B405AF0A2AF207D4B407A8F334DD8104B4015AA9B8BBF7F4B407A8F334DD8104B4015AA9B8BBF7F4B40F6EE8FF7AA0F4B405AF0A2AF207D4B40F6EE8FF7AA0F4B40
65685	58599	55.644100999999999	55.666649	54.128193000000003	54.112552000000001	Ленина	0103000020E610000001000000050000001329CDE671D24B40B98C9B1A680E4B401329CDE671D24B40BF49D3A068104B409F7422C154D54B40BF49D3A068104B409F7422C154D54B40B98C9B1A680E4B401329CDE671D24B40B98C9B1A680E4B40
64996	58432	55.83661	55.858277000000001	52.596316999999999	52.572620000000001	Дружбы	0103000020E61000000100000005000000D7C0560916EB4B408C84B69C4B494A40D7C0560916EB4B4040868E1D544C4A405AF44E05DCED4B4040868E1D544C4A405AF44E05DCED4B408C84B69C4B494A40D7C0560916EB4B408C84B69C4B494A40
64936	58404	54.229424999999999	54.262509999999999	55.809848000000002	55.792569	Молодёжная	0103000020E6100000010000000500000041F163CC5D1D4B406669A7E672E54B4041F163CC5D1D4B40925D6919A9E74B40BD6F7CED99214B40925D6919A9E74B40BD6F7CED99214B406669A7E672E54B4041F163CC5D1D4B406669A7E672E54B40
66276	58736	54.319840999999997	54.333100000000002	54.240715000000002	54.224373999999997	Школьная	0103000020E61000000100000005000000C075C58CF0284B404E098849B81C4B40C075C58CF0284B400D54C6BFCF1E4B4018265305A32A4B400D54C6BFCF1E4B4018265305A32A4B404E098849B81C4B40C075C58CF0284B404E098849B81C4B40
63702	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	проспект Горняков	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63346	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Чайковского	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63492	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Цеткин	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63681	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Старательская	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63352	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Сибаева	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63255	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Маяковского	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63747	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Ленина	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63708	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Кусимова	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63261	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Заки Валиди	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
64227	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Достоевского	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63487	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Горького	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63608	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Горняков проспект	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63294	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Горная	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
64338	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Гаражная	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
63253	15877	58.634475999999999	58.702289999999998	52.740720000000003	52.679668999999997	Белова	0103000020E61000000100000005000000670C738236514D40718DCF64FF564A40670C738236514D401FBFB7E9CF5E4A40672783A3E4594D401FBFB7E9CF5E4A40672783A3E4594D40718DCF64FF564A40670C738236514D40718DCF64FF564A40
64843	58372	55.231712000000002	55.250576000000002	56.198214999999998	56.184365	Байман	0103000020E610000001000000050000009E0B23BDA89D4B4076C3B64599174C409E0B23BDA89D4B40CF49EF1B5F194C40CD94D6DF12A04B40CF49EF1B5F194C40CD94D6DF12A04B4076C3B64599174C409E0B23BDA89D4B4076C3B64599174C40
65971	58674	58.680011999999998	58.702505000000002	53.395685	53.384338	Центральная	0103000020E610000001000000050000009B711AA20A574D40164ED2FC31B14A409B711AA20A574D4046425BCEA5B24A40642310AFEB594D4046425BCEA5B24A40642310AFEB594D40164ED2FC31B14A409B711AA20A574D40164ED2FC31B14A40
65193	58491	55.386921999999998	55.409227999999999	56.258043000000001	56.250497000000003	Центральная	0103000020E610000001000000050000002C0DFCA886B14B40815F234910204C402C0DFCA886B14B401AFB928D07214C40C24D469561B44B401AFB928D07214C40C24D469561B44B40815F234910204C402C0DFCA886B14B40815F234910204C40
65355	58529	55.585287999999998	55.599328999999997	53.35718	53.345500000000001	Школьная	0103000020E61000000100000005000000E15E99B7EACA4B404E62105839AC4A40E15E99B7EACA4B4084640113B8AD4A40AE450BD0B6CC4B4084640113B8AD4A40AE450BD0B6CC4B404E62105839AC4A40E15E99B7EACA4B404E62105839AC4A40
65100	58471	56.132505999999999	56.151119000000001	55.289597999999998	55.272830999999996	Школьная	0103000020E610000001000000050000000B43E4F4F5104C40E02A4F20ECA24B400B43E4F4F5104C40567E198C11A54B40F1660DDE57134C40567E198C11A54B40F1660DDE57134C40E02A4F20ECA24B400B43E4F4F5104C40E02A4F20ECA24B40
64838	58370	55.48659	55.509542000000003	54.626207999999998	54.615147	Школьная	0103000020E61000000100000005000000C347C49448BE4B40C39D0B23BD4E4B40C347C49448BE4B402D3F709527504B401FF818AC38C14B402D3F709527504B401FF818AC38C14B40C39D0B23BD4E4B40C347C49448BE4B40C39D0B23BD4E4B40
65156	58481	55.627966999999998	55.633904999999999	52.669037000000003	52.656410000000001	Центральная	0103000020E61000000100000005000000CEFBFF3861D04B4039622D3E05544A40CEFBFF3861D04B4030682101A3554A40ACE28DCC23D14B4030682101A3554A40ACE28DCC23D14B4039622D3E05544A40CEFBFF3861D04B4039622D3E05544A40
65362	58531	54.951490999999997	54.972861999999999	54.636083999999997	54.618133999999998	Центральная	0103000020E610000001000000050000001BB80375CA794B40D845D1031F4F4B401BB80375CA794B4022C154336B514B40B5C2F4BD867C4B4022C154336B514B40B5C2F4BD867C4B40D845D1031F4F4B401BB80375CA794B40D845D1031F4F4B40
66072	58702	56.202413	56.231679999999997	53.523797000000002	53.506180999999998	Советская	0103000020E6100000010000000500000083A44FABE8194C40A46DFC89CAC04A4083A44FABE8194C40185FB4C70BC34A409291B3B0A71D4C40185FB4C70BC34A409291B3B0A71D4C40A46DFC89CAC04A4083A44FABE8194C40A46DFC89CAC04A40
66026	58689	55.469082	55.482216000000001	56.017060000000001	56.010060000000003	М.Гафури	0103000020E61000000100000005000000369204E10ABC4B40B77F65A549014C40369204E10ABC4B40EE08A7052F024C40D1CDFE40B9BD4B40EE08A7052F024C40D1CDFE40B9BD4B40B77F65A549014C40369204E10ABC4B40B77F65A549014C40
65047	58446	58.569851	58.584600999999999	53.472585000000002	53.464491000000002	Школьная	0103000020E61000000100000005000000E44BA8E0F0484D40A724EB7074BB4A40E44BA8E0F0484D4043CA4FAA7DBC4A40BD1AA034D44A4D4043CA4FAA7DBC4A40BD1AA034D44A4D40A724EB7074BB4A40E44BA8E0F0484D40A724EB7074BB4A40
63373	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	бульвар Космонавтов	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63485	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Школьный переулок	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63420	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Фурманова	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63252	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Уфимская	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
64246	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Строителей	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63994	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Пугачева	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63344	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Первомаяская	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63461	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Островского	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
66752	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Октябрьская	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63247	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Монтажников	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63408	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Матросова	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63421	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Ленина	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63623	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Комсомольская	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63573	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Калинина	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63779	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	К. Маркса	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63584	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Губкина	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63401	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Губайдуллина	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63405	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Горького	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63348	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Гагарина	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63705	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Бочкарева	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63683	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Б.Хмельницкого	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
9723	7789	55.857101	55.977106999999997	53.430034999999997	53.323895	Б.С.Юлаева	0103000020E61000000100000005000000382F4E7CB5ED4B40412B306475A94A40382F4E7CB5ED4B4053910A630BB74A40A9D898D711FD4B4053910A630BB74A40A9D898D711FD4B40412B306475A94A40382F4E7CB5ED4B40412B306475A94A40
9702	7789	55.857101	55.977106999999997	53.430034999999997	53.323895	Б.С. Юлаева	0103000020E61000000100000005000000382F4E7CB5ED4B40412B306475A94A40382F4E7CB5ED4B4053910A630BB74A40A9D898D711FD4B4053910A630BB74A40A9D898D711FD4B40412B306475A94A40382F4E7CB5ED4B40412B306475A94A40
63788	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Б. Хмельницкого	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63347	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	Б. Космонавтов	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63431	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	30 лет Победы	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
66664	7789	55.857289000000002	55.967233999999998	53.428286	53.322943000000002	21-го съезда	0103000020E610000001000000050000003B1C5DA5BBED4B406FBC3B3256A94A403B1C5DA5BBED4B40D6AA5D13D2B64A4025CADE52CEFB4B40D6AA5D13D2B64A4025CADE52CEFB4B406FBC3B3256A94A403B1C5DA5BBED4B406FBC3B3256A94A40
63787	7789	55.857101	55.977106999999997	53.430034999999997	53.323895	 Б.С. Юлаева	0103000020E61000000100000005000000382F4E7CB5ED4B40412B306475A94A40382F4E7CB5ED4B4053910A630BB74A40A9D898D711FD4B4053910A630BB74A40A9D898D711FD4B40412B306475A94A40382F4E7CB5ED4B40412B306475A94A40
64060	58159	55.025475999999998	55.046928000000001	55.954994999999997	55.947409	Центральная	0103000020E610000001000000050000009C6A2DCC42834B40D177B7B244F94B409C6A2DCC42834B40F86BB2463DFA4B4023A298BC01864B40F86BB2463DFA4B4023A298BC01864B40D177B7B244F94B409C6A2DCC42834B40D177B7B244F94B40
64170	58181	54.500680000000003	54.543925000000002	55.820869999999999	55.808326000000001	Ленина	0103000020E6100000010000000500000072E1404816404B40D540F33977E74B4072E1404816404B403E22A64412E94B40083D9B559F454B403E22A64412E94B40083D9B559F454B40D540F33977E74B4072E1404816404B40D540F33977E74B40
66741	3847	55.790140000000001	55.830824999999997	54.795696	54.774991999999997	Школьная	0103000020E6100000010000000500000077A1B94E23E54B40B05417F032634B4077A1B94E23E54B406DC7D45DD9654B407FD93D7958EA4B406DC7D45DD9654B407FD93D7958EA4B40B05417F032634B4077A1B94E23E54B40B05417F032634B40
65506	3847	55.790140000000001	55.830824999999997	54.795696	54.774991999999997	Центральная	0103000020E6100000010000000500000077A1B94E23E54B40B05417F032634B4077A1B94E23E54B406DC7D45DD9654B407FD93D7958EA4B406DC7D45DD9654B407FD93D7958EA4B40B05417F032634B4077A1B94E23E54B40B05417F032634B40
64655	58315	55.585099999999997	55.609417000000001	54.350195999999997	54.335997999999996	Сергея Алексеева	0103000020E61000000100000005000000DE718A8EE4CA4B40BDC282FB012B4B40DE718A8EE4CA4B405298F738D32C4B402F50526001CE4B405298F738D32C4B402F50526001CE4B40BDC282FB012B4B40DE718A8EE4CA4B40BDC282FB012B4B40
64652	58314	54.814920000000001	54.833812000000002	53.406298999999997	53.397660999999999	Космонавтов	0103000020E610000001000000050000009C6D6E4C4F684B4084F23E8EE6B24A409C6D6E4C4F684B40E1B20A9B01B44A409581035ABA6A4B40E1B20A9B01B44A409581035ABA6A4B4084F23E8EE6B24A409C6D6E4C4F684B4084F23E8EE6B24A40
64505	58248	54.284042999999997	54.301461000000003	54.052787000000002	54.040987999999999	Центральная	0103000020E6100000010000000500000030D461855B244B40A4C343183F054B4030D461855B244B40B55373B9C1064B407E02284696264B40B55373B9C1064B407E02284696264B40A4C343183F054B4030D461855B244B40A4C343183F054B40
66118	58711	56.406654000000003	56.431690000000003	54.048664000000002	54.040109999999999	Центральная	0103000020E61000000100000005000000D064FF3C0D344C400C1F115322054B40D064FF3C0D344C400C3F389F3A064B405001309E41374C400C3F389F3A064B405001309E41374C400C1F115322054B40D064FF3C0D344C400C1F115322054B40
64123	7989	55.955502000000003	55.956535000000002	54.704783999999997	54.696542999999998	Школьная	0103000020E610000001000000050000009DA1B8E34DFA4B40FDA02E5228594B409DA1B8E34DFA4B403D5FB35C365A4B405C3D27BD6FFA4B403D5FB35C365A4B405C3D27BD6FFA4B40FDA02E5228594B409DA1B8E34DFA4B40FDA02E5228594B40
63564	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Шашина	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63400	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Трипольского	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63613	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Свердлова	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63402	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Садовое кольцо	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63392	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Партизанская	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63482	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Островского	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
66658	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Матросова	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
64337	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Ломоносова	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63614	7989	56.131168000000002	56.132111000000002	54.806055000000001	54.804611999999999	Лермонтова	0103000020E610000001000000050000001024EF1CCA104C400DFCA886FD664B401024EF1CCA104C407EE36BCF2C674B408F386403E9104C407EE36BCF2C674B408F386403E9104C400DFCA886FD664B401024EF1CCA104C400DFCA886FD664B40
63624	7989	56.022174999999997	56.025857999999999	54.773912000000003	54.771532999999998	Ленина	0103000020E61000000100000005000000F7E461A1D6024C407364E597C1624B40F7E461A1D6024C40B1FD648C0F634B40842BA0504F034C40B1FD648C0F634B40842BA0504F034C407364E597C1624B40F7E461A1D6024C407364E597C1624B40
63483	7989	55.994103000000003	56.003050000000002	54.71566	54.697572999999998	Кувыкина	0103000020E6100000010000000500000081ED60C43EFF4B404BC972124A594B4081ED60C43EFF4B40168733BF9A5B4B405C2041F163004C40168733BF9A5B4B405C2041F163004C404BC972124A594B4081ED60C43EFF4B404BC972124A594B40
63610	7989	55.950364	55.968662000000002	54.752676999999998	54.725597	Крупской	0103000020E61000000100000005000000DBA50D87A5F94B40B189CC5CE05C4B40DBA50D87A5F94B40C7B94DB857604B406170CD1DFDFB4B40C7B94DB857604B406170CD1DFDFB4B40B189CC5CE05C4B40DBA50D87A5F94B40B189CC5CE05C4B40
63617	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Космонавтов	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63772	7989	56.064791	56.085011999999999	54.774009999999997	54.773356	Королева	0103000020E610000001000000050000009E094D124B084C402B155454FD624B409E094D124B084C4073637AC212634B403FE257ACE10A4C4073637AC212634B403FE257ACE10A4C402B155454FD624B409E094D124B084C402B155454FD624B40
63561	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Кооперативная	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63699	7989	55.989412999999999	56.028418000000002	54.767055999999997	54.737085999999998	Комсомольская	0103000020E610000001000000050000005E9ECE15A5FE4B40732B84D5585E4B405E9ECE15A5FE4B40AC1919E42E624B40124F7633A3034C40AC1919E42E624B40124F7633A3034C40732B84D5585E4B405E9ECE15A5FE4B40732B84D5585E4B40
63295	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Девонская	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63768	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	Герцена	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63696	7989	55.973388	55.975597	54.693015000000003	54.689815000000003	Геофизиков	0103000020E61000000100000005000000D0285DFA97FC4B4027A5A0DB4B584B40D0285DFA97FC4B4098512CB7B4584B40B189CC5CE0FC4B4098512CB7B4584B40B189CC5CE0FC4B4027A5A0DB4B584B40D0285DFA97FC4B4027A5A0DB4B584B40
63626	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	35 микрорайон	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63243	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	34 микрорайон	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63404	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	29 микрорайон	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
63341	7989	53.426861000000002	53.543238000000002	54.514901000000002	54.455998000000001	25 микрорайон	0103000020E610000001000000050000000C789961A3B64A404D8578245E3A4B400C789961A3B64A40BFD6A546E8414B40E4F8A1D288C54A40BFD6A546E8414B40E4F8A1D288C54A404D8578245E3A4B400C789961A3B64A404D8578245E3A4B40
64938	58405	54.184060000000002	54.208818000000001	55.872374999999998	55.858907000000002	Дорожная	0103000020E610000001000000050000003A4030478F174B401AA721AAF0ED4B403A4030478F174B408B6CE7FBA9EF4B407768588CBA1A4B408B6CE7FBA9EF4B407768588CBA1A4B401AA721AAF0ED4B403A4030478F174B401AA721AAF0ED4B40
65795	58631	53.917521000000001	53.946654000000002	53.776335000000003	53.759618000000003	Абдулинская	0103000020E610000001000000050000005532005471F54A40FAB9A1293BE14A405532005471F54A40BEDEFDF15EE34A40555051F52BF94A40BEDEFDF15EE34A40555051F52BF94A40FAB9A1293BE14A405532005471F54A40FAB9A1293BE14A40
64520	58253	54.296655000000001	54.326030000000003	55.925657000000001	55.908358	Школьная	0103000020E61000000100000005000000F29881CAF8254B40AD872F1345F44B40F29881CAF8254B402028B7ED7BF64B40E8C1DD59BB294B402028B7ED7BF64B40E8C1DD59BB294B40AD872F1345F44B40F29881CAF8254B40AD872F1345F44B40
66037	58692	55.927726	55.943420000000003	56.231318000000002	56.217826000000002	Школьная	0103000020E610000001000000050000000FD3BEB9BFF64B40F81BEDB8E11B4C400FD3BEB9BFF64B40F27C06D49B1D4C4038328FFCC1F84B40F27C06D49B1D4C4038328FFCC1F84B40F81BEDB8E11B4C400FD3BEB9BFF64B40F81BEDB8E11B4C40
65623	58583	53.658769999999997	53.679144000000001	54.467678999999997	54.458368999999998	Центральная	0103000020E61000000100000005000000FFCA4A9352D44A400740DCD5AB3A4B40FFCA4A9352D44A405303CDE7DC3B4B4027A3CA30EED64A405303CDE7DC3B4B4027A3CA30EED64A400740DCD5AB3A4B40FFCA4A9352D44A400740DCD5AB3A4B40
65067	58458	54.887306000000002	54.898184999999998	55.760975000000002	55.753447999999999	Озерная	0103000020E61000000100000005000000B5C5353E93714B40499EEBFB70E04B40B5C5353E93714B406C09F9A067E14B40FE60E0B9F7724B406C09F9A067E14B40FE60E0B9F7724B40499EEBFB70E04B40B5C5353E93714B40499EEBFB70E04B40
64820	58361	56.678232999999999	56.696244	54.534522000000003	54.521993000000002	Нижняя	0103000020E61000000100000005000000B308C556D0564C40D7DEA7AAD0424B40B308C556D0564C400B7F86376B444B40A304FD851E594C400B7F86376B444B40A304FD851E594C40D7DEA7AAD0424B40B308C556D0564C40D7DEA7AAD0424B40
64603	58295	55.254671999999999	55.274875999999999	55.409435999999999	55.400869999999998	Агидель	0103000020E610000001000000050000007C9A931799A04B4048F949B54FB34B407C9A931799A04B400CE71A6668B44B40473A03232FA34B400CE71A6668B44B40473A03232FA34B4048F949B54FB34B407C9A931799A04B4048F949B54FB34B40
66074	58703	53.389401999999997	53.425773999999997	55.142910000000001	55.130744999999997	Ленина	0103000020E610000001000000050000009D7FBBECD7B14A40C98E8D40BC904B409D7FBBECD7B14A40BC22F8DF4A924B4059BE2EC37FB64A40BC22F8DF4A924B4059BE2EC37FB64A40C98E8D40BC904B409D7FBBECD7B14A40C98E8D40BC904B40
66055	58698	56.522860000000001	56.546225	52.685155000000002	52.671249000000003	Молодежная	0103000020E610000001000000050000007B319413ED424C40823CBB7CEB554A407B319413ED424C406FD8B628B3574A40F9A067B3EA454C406FD8B628B3574A40F9A067B3EA454C40823CBB7CEB554A407B319413ED424C40823CBB7CEB554A40
64453	58234	58.443871000000001	58.487349999999999	55.957177000000001	55.92718	Луговая	0103000020E610000001000000050000004852D2C3D0384D40ADC090D5ADF64B404852D2C3D0384D40E0BDA3C684FA4B4051DA1B7C613E4D40E0BDA3C684FA4B4051DA1B7C613E4D40ADC090D5ADF64B404852D2C3D0384D40ADC090D5ADF64B40
64835	58369	54.029190999999997	54.053193999999998	55.083694000000001	55.067937000000001	Центральная	0103000020E61000000100000005000000342BDB87BC034B401C98DC28B2884B40342BDB87BC034B408B6F287CB68A4B40F52B9D0FCF064B408B6F287CB68A4B40F52B9D0FCF064B401C98DC28B2884B40342BDB87BC034B401C98DC28B2884B40
64431	58229	55.036346000000002	55.053800000000003	55.560015	55.546649000000002	Молодёжная	0103000020E6100000010000000500000093AB58FCA6844B4010B22C98F8C54B4093AB58FCA6844B407D224F92AEC74B402D431CEBE2864B407D224F92AEC74B402D431CEBE2864B4010B22C98F8C54B4093AB58FCA6844B4010B22C98F8C54B40
64845	58373	55.769846999999999	55.786825	56.357385000000001	56.344192	Новая	0103000020E610000001000000050000003CF6B3588AE24B40BDC5C37B0E2C4C403CF6B3588AE24B405D8AABCABE2D4C406D567DAEB6E44B405D8AABCABE2D4C406D567DAEB6E44B40BDC5C37B0E2C4C403CF6B3588AE24B40BDC5C37B0E2C4C40
64210	58191	53.901755999999999	53.931274000000002	55.926735999999998	55.910845999999999	Центральная	0103000020E61000000100000005000000637C98BD6CF34A40A1D80A9A96F44B40637C98BD6CF34A404F0306499FF64B40BCCE86FC33F74A404F0306499FF64B40BCCE86FC33F74A40A1D80A9A96F44B40637C98BD6CF34A40A1D80A9A96F44B40
64991	58430	55.818078	55.832630999999999	52.691001999999997	52.676600000000001	Уральская	0103000020E61000000100000005000000DEC9A7C7B6E84B409F3C2CD49A564A40DEC9A7C7B6E84B403CBCE7C072584A40615111A793EA4B403CBCE7C072584A40615111A793EA4B409F3C2CD49A564A40DEC9A7C7B6E84B409F3C2CD49A564A40
64935	58403	54.422006000000003	54.445030000000003	55.909398000000003	55.892885	Ленина	0103000020E610000001000000050000009F5BE84A04364B40630B410E4AF24B409F5BE84A04364B401F86562767F44B4094DE37BEF6384B401F86562767F44B4094DE37BEF6384B40630B410E4AF24B409F5BE84A04364B40630B410E4AF24B40
66424	58770	55.398349000000003	55.41442	56.090482000000002	56.079357000000002	Худайбердина	0103000020E6100000010000000500000079B29B19FDB24B40B6DAC35E280A4C4079B29B19FDB24B40377007EA940B4C407767EDB60BB54B40377007EA940B4C407767EDB60BB54B40B6DAC35E280A4C4079B29B19FDB24B40B6DAC35E280A4C40
64798	58353	56.378411	56.399557000000001	54.206041999999997	54.194902999999996	Шоссейная	0103000020E610000001000000050000002CB98AC56F304C403672DD94F2184B402CB98AC56F304C401CCD91955F1A4B40A6F10BAF24334C401CCD91955F1A4B40A6F10BAF24334C403672DD94F2184B402CB98AC56F304C403672DD94F2184B40
65373	58533	56.558478000000001	56.580936000000001	53.750391999999998	53.732968	Гафури	0103000020E610000001000000050000008BC404357C474C40DC813AE5D1DD4A408BC404357C474C400B9755D80CE04A40D788601C5C4A4C400B9755D80CE04A40D788601C5C4A4C40DC813AE5D1DD4A408BC404357C474C40DC813AE5D1DD4A40
65822	58638	56.699181000000003	56.709691999999997	51.989610999999996	51.983144000000003	Юнай	0103000020E61000000100000005000000077E54C37E594C401BA19FA9D7FD4940077E54C37E594C408461C092ABFE4940CD1DFD2FD75A4C408461C092ABFE4940CD1DFD2FD75A4C401BA19FA9D7FD4940077E54C37E594C401BA19FA9D7FD4940
64503	58247	58.721361000000002	58.764983000000001	55.828121000000003	55.810906000000003	Бунакова	0103000020E6100000010000000500000010CEA78E555C4D40AA108FC4CBE74B4010CEA78E555C4D40BF1072DEFFE94B407C7F83F6EA614D40BF1072DEFFE94B407C7F83F6EA614D40AA108FC4CBE74B4010CEA78E555C4D40AA108FC4CBE74B40
65871	58650	58.474719999999998	58.534601000000002	55.553508000000001	55.529511999999997	8 Марта	0103000020E61000000100000005000000E960FD9FC33C4D40766B990CC7C34B40E960FD9FC33C4D408509A359D9C64B4057B439CE6D444D408509A359D9C64B4057B439CE6D444D40766B990CC7C34B40E960FD9FC33C4D40766B990CC7C34B40
64418	58227	56.104218000000003	56.134428999999997	56.215178000000002	56.202545999999998	Центральная	0103000020E61000000100000005000000C8D3F203570D4C40C2F7FE06ED194C40C8D3F203570D4C40CB68E4F38A1B4C4026512FF834114C40CB68E4F38A1B4C4026512FF834114C40C2F7FE06ED194C40C8D3F203570D4C40C2F7FE06ED194C40
588	2298	55.840679000000002	55.862931000000003	54.622633	54.613593000000002	улица Школьная	0103000020E610000001000000050000008DB7955E9BEB4B40FB0626378A4E4B408DB7955E9BEB4B4087342A70B24F4B4030DAE38574EE4B4087342A70B24F4B4030DAE38574EE4B40FB0626378A4E4B408DB7955E9BEB4B40FB0626378A4E4B40
63807	2298	55.840679000000002	55.862931000000003	54.622633	54.613593000000002	Школьная	0103000020E610000001000000050000008DB7955E9BEB4B40FB0626378A4E4B408DB7955E9BEB4B4087342A70B24F4B4030DAE38574EE4B4087342A70B24F4B4030DAE38574EE4B40FB0626378A4E4B408DB7955E9BEB4B40FB0626378A4E4B40
66474	2298	55.846401999999998	55.862329000000003	54.608963000000003	54.605390999999997	Центральная	0103000020E610000001000000050000006EA296E656EC4B407825C9737D4D4B406EA296E656EC4B40AEBCE47FF24D4B403AB2F2CB60EE4B40AEBCE47FF24D4B403AB2F2CB60EE4B407825C9737D4D4B406EA296E656EC4B407825C9737D4D4B40
66481	2298	55.840679000000002	55.862931000000003	54.622633	54.613593000000002	 Школьная	0103000020E610000001000000050000008DB7955E9BEB4B40FB0626378A4E4B408DB7955E9BEB4B4087342A70B24F4B4030DAE38574EE4B4087342A70B24F4B4030DAE38574EE4B40FB0626378A4E4B408DB7955E9BEB4B40FB0626378A4E4B40
63606	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Юбилейный проспект	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63469	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Трактовая	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63246	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Строителей	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63335	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Социалистическая	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
64413	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Сиреневая	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63245	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Победы	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63315	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Парковая	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63379	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Нефтяников	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63241	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Ленина	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63387	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Кувыкина переулок	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63284	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Комсомольский проспект	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63251	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Карла Маркса	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63472	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Дорожная	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
63336	8531	54.226666999999999	54.321663999999998	56.124948000000003	56.067962000000001	Дзержинского	0103000020E610000001000000050000008D0A9C6C031D4B4075AF93FAB2084C408D0A9C6C031D4B40AED9CA4BFE0F4C40782634492C294B40AED9CA4BFE0F4C40782634492C294B4075AF93FAB2084C408D0A9C6C031D4B4075AF93FAB2084C40
66011	58684	56.347931000000003	56.362375999999998	54.504263999999999	54.498863	Школьная	0103000020E61000000100000005000000DE21C500892C4C409C1727BEDA3F4B40DE21C500892C4C406B4606B98B404B407A6D3656622E4C406B4606B98B404B407A6D3656622E4C409C1727BEDA3F4B40DE21C500892C4C409C1727BEDA3F4B40
65716	58607	58.619374999999998	58.630352999999999	52.796686999999999	52.786433000000002	1 Мая	0103000020E61000000100000005000000E17A14AE474F4D4062BF27D6A9644A40E17A14AE474F4D40FD12F1D6F9654A40BEF73768AF504D40FD12F1D6F9654A40BEF73768AF504D4062BF27D6A9644A40E17A14AE474F4D4062BF27D6A9644A40
64907	58394	54.137895999999998	54.152458000000003	54.938538999999999	54.929957999999999	Миргая Фархутдинова	0103000020E61000000100000005000000E61F7D93A6114B40A8531EDD08774B40E61F7D93A6114B40A182C30B22784B40BD0166BE83134B40A182C30B22784B40BD0166BE83134B40A8531EDD08774B40E61F7D93A6114B40A8531EDD08774B40
66420	7265	55.885649000000001	55.886519999999997	54.801966	54.797378000000002	Школьная	0103000020E61000000100000005000000185E49F25CF14B406346787B10664B40185E49F25CF14B40814067D2A6664B40FD9FC37C79F14B40814067D2A6664B40FD9FC37C79F14B406346787B10664B40185E49F25CF14B406346787B10664B40
65413	7265	55.843940000000003	55.917791000000001	54.831119999999999	54.786040999999997	Центральная	0103000020E61000000100000005000000A4E4D53906EC4B405628D2FD9C644B40A4E4D53906EC4B409886E123626A4B4015C8EC2C7AF54B409886E123626A4B4015C8EC2C7AF54B405628D2FD9C644B40A4E4D53906EC4B405628D2FD9C644B40
64132	7265	55.897606000000003	55.909678999999997	54.821872999999997	54.816654999999997	Парковая	0103000020E61000000100000005000000C158DFC0E4F24B40B48EAA2688684B40C158DFC0E4F24B40923B6C2233694B40D26D895C70F44B40923B6C2233694B40D26D895C70F44B40B48EAA2688684B40C158DFC0E4F24B40B48EAA2688684B40
63846	7265	55.89085	55.901009999999999	54.816577000000002	54.797818999999997	Ленина	0103000020E6100000010000000500000020D26F5F07F24B404F90D8EE1E664B4020D26F5F07F24B4039D55A9885684B403AAFB14B54F34B4039D55A9885684B403AAFB14B54F34B404F90D8EE1E664B4020D26F5F07F24B404F90D8EE1E664B40
66203	7265	55.843940000000003	55.917791000000001	54.831119999999999	54.786040999999997	Красногвардейская	0103000020E61000000100000005000000A4E4D53906EC4B405628D2FD9C644B40A4E4D53906EC4B409886E123626A4B4015C8EC2C7AF54B409886E123626A4B4015C8EC2C7AF54B405628D2FD9C644B40A4E4D53906EC4B405628D2FD9C644B40
64102	58165	54.114593999999997	54.119138999999997	53.774003999999998	53.770949999999999	Школьная	0103000020E61000000100000005000000AE282504AB0E4B40F46C567DAEE24A40AE282504AB0E4B40917C259012E34A40CD565EF23F0F4B40917C259012E34A40CD565EF23F0F4B40F46C567DAEE24A40AE282504AB0E4B40F46C567DAEE24A40
64252	58196	58.774065	58.831125999999998	54.063853999999999	54.002273000000002	Хисматуллина	0103000020E6100000010000000500000037FDD98F14634D40F8544E7B4A004B4037FDD98F14634D4001DC2C5E2C084B407A6D3656626A4D4001DC2C5E2C084B407A6D3656626A4D40F8544E7B4A004B4037FDD98F14634D40F8544E7B4A004B40
1671	6151	55.820619999999998	55.837553	54.775781000000002	54.774213000000003	улица Советская	0103000020E61000000100000005000000C5387F130AE94B40AC915D6919634B40C5387F130AE94B40D9EDB3CA4C634B4056D5CBEF34EB4B40D9EDB3CA4C634B4056D5CBEF34EB4B40AC915D6919634B40C5387F130AE94B40AC915D6919634B40
16088	6151	55.823628999999997	55.833843000000002	54.781275000000001	54.778880999999998	улица Приозерная	0103000020E61000000100000005000000C284D1AC6CE94B40E63C635FB2634B40C284D1AC6CE94B405917B7D100644B40D07F0F5EBBEA4B405917B7D100644B40D07F0F5EBBEA4B40E63C635FB2634B40C284D1AC6CE94B40E63C635FB2634B40
2131	6151	55.837553	55.841146999999999	54.781046000000003	54.775781000000002	улица Михайлова	0103000020E6100000010000000500000056D5CBEF34EB4B40D9EDB3CA4C634B4056D5CBEF34EB4B40F855B950F9634B40731074B4AAEB4B40F855B950F9634B40731074B4AAEB4B40D9EDB3CA4C634B4056D5CBEF34EB4B40D9EDB3CA4C634B40
63849	6151	55.820619999999998	55.837553	54.775781000000002	54.774213000000003	Советская	0103000020E61000000100000005000000C5387F130AE94B40AC915D6919634B40C5387F130AE94B40D9EDB3CA4C634B4056D5CBEF34EB4B40D9EDB3CA4C634B4056D5CBEF34EB4B40AC915D6919634B40C5387F130AE94B40AC915D6919634B40
64512	58250	54.636955	54.664164999999997	54.236806000000001	54.214908999999999	Центральная	0103000020E610000001000000050000000803CFBD87514B40DB4E5B23821B4B400803CFBD87514B4090BFB4A84F1E4B40EC12D55B03554B4090BFB4A84F1E4B40EC12D55B03554B40DB4E5B23821B4B400803CFBD87514B40DB4E5B23821B4B40
65967	58673	57.991731000000001	58.019804000000001	55.373562	55.352474999999998	Центральная	0103000020E61000000100000005000000F6B6990AF1FE4C402CD49AE61DAD4B40F6B6990AF1FE4C40A1832EE1D0AF4B403D2AFEEF88024D40A1832EE1D0AF4B403D2AFEEF88024D402CD49AE61DAD4B40F6B6990AF1FE4C402CD49AE61DAD4B40
63529	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Шлычкова	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63527	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Свердлова	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63528	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Правды	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63761	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Площадь Лесокомбината	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
65865	58647	55.369988999999997	55.3797	54.740988999999999	54.729652000000002	Дружбы	0103000020E610000001000000050000009B70AFCC5BAF4B4002BB9A3C655D4B409B70AFCC5BAF4B400ED940BAD85E4B40462575029AB04B400ED940BAD85E4B40462575029AB04B4002BB9A3C655D4B409B70AFCC5BAF4B4002BB9A3C655D4B40
63282	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Октябрьская	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63430	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Московская	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63738	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Ленина	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63744	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Колхозная	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63411	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Бурангулова	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63312	58094	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	31 микрорайон	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
64777	58345	58.595354	58.622689999999999	55.595933000000002	55.583342000000002	Безымянная	0103000020E610000001000000050000007AC5538F344C4D400E315EF3AACA4B407AC5538F344C4D40B8CD548847CC4B40EBC5504EB44F4D40B8CD548847CC4B40EBC5504EB44F4D400E315EF3AACA4B407AC5538F344C4D400E315EF3AACA4B40
64757	58338	57.596570999999997	57.609067000000003	54.271411000000001	54.262340000000002	Новая	0103000020E61000000100000005000000FA5E43705CCC4C4061376C5B94214B40FA5E43705CCC4C4028637C98BD224B4053094FE8F5CD4C4028637C98BD224B4053094FE8F5CD4C4061376C5B94214B40FA5E43705CCC4C4061376C5B94214B40
64764	58339	56.308342000000003	56.324897999999997	53.424610000000001	53.413286999999997	Каран-Елга	0103000020E61000000100000005000000DBFD2AC077274C40546EA296E6B44A40DBFD2AC077274C40FCC6D79E59B64A409544F64196294C40FCC6D79E59B64A409544F64196294C40546EA296E6B44A40DBFD2AC077274C40546EA296E6B44A40
65636	58587	58.199008999999997	58.213192999999997	53.536171000000003	53.529705999999997	Лесорубов	0103000020E61000000100000005000000094E7D2079194D405B3FFD67CDC34A40094E7D2079194D4025085740A1C44A40395E81E8491B4D4025085740A1C44A40395E81E8491B4D405B3FFD67CDC34A40094E7D2079194D405B3FFD67CDC34A40
64729	58331	58.613014999999997	58.637898	55.725042000000002	55.703586000000001	Мира	0103000020E610000001000000050000008D7A8846774E4D4034F6251B0FDA4B408D7A8846774E4D40FC1C1F2DCEDC4B40871744A4A6514D40FC1C1F2DCEDC4B40871744A4A6514D4034F6251B0FDA4B408D7A8846774E4D4034F6251B0FDA4B40
65946	58669	55.102938000000002	55.118774999999999	54.878847999999998	54.866844999999998	Ленина	0103000020E6100000010000000500000001C287122D8D4B40BED9E6C6F46E4B4001C287122D8D4B40D7135D177E704B408C4AEA04348F4B40D7135D177E704B408C4AEA04348F4B40BED9E6C6F46E4B4001C287122D8D4B40BED9E6C6F46E4B40
65842	58642	57.252768000000003	57.272989000000003	52.919282000000003	52.908822999999998	Заречная	0103000020E61000000100000005000000D8BCAAB35AA04C40226DE34F54744A40D8BCAAB35AA04C4097E65608AB754A407995B54DF1A24C4097E65608AB754A407995B54DF1A24C40226DE34F54744A40D8BCAAB35AA04C40226DE34F54744A40
65639	58589	59.027569999999997	59.041988000000003	54.181105000000002	54.171255000000002	Школьная	0103000020E61000000100000005000000E42CEC6987834D40642310AFEB154B40E42CEC6987834D403012DA722E174B408869DFDC5F854D403012DA722E174B408869DFDC5F854D40642310AFEB154B40E42CEC6987834D40642310AFEB154B40
64751	58337	57.959184999999998	57.977637000000001	55.356681999999999	55.349164000000002	Школьная	0103000020E6100000010000000500000029E8F692C6FA4C406478EC67B1AC4B4029E8F692C6FA4C4033897AC1A7AD4B40062E8F3523FD4C4033897AC1A7AD4B40062E8F3523FD4C406478EC67B1AC4B4029E8F692C6FA4C406478EC67B1AC4B40
66112	58709	54.725062000000001	54.754534999999997	54.998556000000001	54.975009999999997	Ахтямова	0103000020E6100000010000000500000043C9E4D4CE5C4B40F0A2AF20CD7C4B4043C9E4D4CE5C4B40BF9CD9AED07F4B40FB57569A94604B40BF9CD9AED07F4B40FB57569A94604B40F0A2AF20CD7C4B4043C9E4D4CE5C4B40F0A2AF20CD7C4B40
65712	58605	58.414442999999999	58.436191000000001	52.989238999999998	52.978276999999999	Б. Валида	0103000020E610000001000000050000002F87DD770C354D40E9B6442E387D4A402F87DD770C354D40C07630629F7E4A409FE74F1BD5374D40C07630629F7E4A409FE74F1BD5374D40E9B6442E387D4A402F87DD770C354D40E9B6442E387D4A40
64816	58360	56.565054000000003	56.581861000000004	54.510725000000001	54.495705000000001	Школьная	0103000020E61000000100000005000000AC3C81B053484C405ABBED42733F4B40AC3C81B053484C40F31FD26F5F414B40B0E8D66B7A4A4C40F31FD26F5F414B40B0E8D66B7A4A4C405ABBED42733F4B40AC3C81B053484C405ABBED42733F4B40
63238	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Чапаева	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63376	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Пушкина	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
64325	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Палатникова	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63339	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Некрасова	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63465	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Мира	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63388	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Машиностроителей	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63239	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Ломоносова	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63235	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Комсомольская	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63382	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Калинина	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63759	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Заслонова	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63466	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Горького	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
66917	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Вокзальная	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
64412	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	Антошкина	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63471	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	70 лет Октября	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63609	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	60 лет БАССР	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63693	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	40 лет Победы	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
63695	8146	55.759867	55.864575000000002	52.799638000000002	52.743217000000001	2-й переулок Салавата	0103000020E61000000100000005000000A227655243E14B40666A12BC215F4A40A227655243E14B40C651B9895A664A4038F8C264AAEE4B40C651B9895A664A4038F8C264AAEE4B40666A12BC215F4A40A227655243E14B40666A12BC215F4A40
65798	1267	56.164386999999998	56.205269999999999	54.511116999999999	54.492060000000002	Школьная	0103000020E610000001000000050000009B711AA20A154C40BBD573D2FB3E4B409B711AA20A154C40FEB627486C414B40CA6C9049461A4C40FEB627486C414B40CA6C9049461A4C40BBD573D2FB3E4B409B711AA20A154C40BBD573D2FB3E4B40
66185	1267	56.164386999999998	56.205269999999999	54.511116999999999	54.492060000000002	Шагар	0103000020E610000001000000050000009B711AA20A154C40BBD573D2FB3E4B409B711AA20A154C40FEB627486C414B40CA6C9049461A4C40FEB627486C414B40CA6C9049461A4C40BBD573D2FB3E4B409B711AA20A154C40BBD573D2FB3E4B40
65877	58652	54.050499000000002	54.078643	55.896549	55.882171999999997	Центральная	0103000020E6100000010000000500000088BD50C076064B4034B91803EBF04B4088BD50C076064B4079211D1EC2F24B4098874CF9100A4B4079211D1EC2F24B4098874CF9100A4B4034B91803EBF04B4088BD50C076064B4034B91803EBF04B40
66080	58704	55.649033000000003	55.664996000000002	55.066592	55.056569000000003	Горная	0103000020E610000001000000050000002C836A8313D34B40D57B2AA73D874B402C836A8313D34B406E162F1686884B4044FCC3961ED54B406E162F1686884B4044FCC3961ED54B40D57B2AA73D874B402C836A8313D34B40D57B2AA73D874B40
65214	58494	56.718235	56.766914	56.114586000000003	56.092998000000001	Совхозная	0103000020E61000000100000005000000D9EBDD1FEF5B4C40F54BC45BE70B4C40D9EBDD1FEF5B4C402C4A09C1AA0E4C401A6CEA3C2A624C402C4A09C1AA0E4C401A6CEA3C2A624C40F54BC45BE70B4C40D9EBDD1FEF5B4C40F54BC45BE70B4C40
65997	58681	55.224299999999999	55.246479999999998	53.896639	53.886248999999999	Краснобашкирская	0103000020E61000000100000005000000143FC6DCB59C4B406D8E739B70F14A40143FC6DCB59C4B40B9A81611C5F24A401D8F19A88C9F4B40B9A81611C5F24A401D8F19A88C9F4B406D8E739B70F14A40143FC6DCB59C4B406D8E739B70F14A40
66047	58695	59.722999999999999	59.745054000000003	54.623029000000002	54.612257999999997	Зайнаб Биишевой	0103000020E61000000100000005000000068195438BDC4D40705B5B785E4E4B40068195438BDC4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40705B5B785E4E4B40068195438BDC4D40705B5B785E4E4B40
66107	58707	58.130260999999997	58.143124	55.280374999999999	55.269455999999998	Школьная	0103000020E61000000100000005000000DD787764AC104D4001DBC1887DA24B40DD787764AC104D40D9CEF753E3A34B40E8A221E351124D40D9CEF753E3A34B40E8A221E351124D4001DBC1887DA24B40DD787764AC104D4001DBC1887DA24B40
65226	58501	54.558433000000001	54.576408000000001	56.044513000000002	56.035763000000003	Труда	0103000020E61000000100000005000000EB0088BB7A474B4014B4C9E193044C40EB0088BB7A474B40999F1B9AB2054C408E93C2BCC7494B40999F1B9AB2054C408E93C2BCC7494B4014B4C9E193044C40EB0088BB7A474B4014B4C9E193044C40
65350	58527	54.058259999999997	54.079819999999998	53.886429999999997	53.861862000000002	Центральная	0103000020E610000001000000050000001D554D1075074B4024D5777E51EE4A401D554D1075074B40BD18CA8976F14A408AC8B08A370A4B40BD18CA8976F14A408AC8B08A370A4B4024D5777E51EE4A401D554D1075074B4024D5777E51EE4A40
65354	58528	54.171331000000002	54.193600000000004	53.841562000000003	53.827039999999997	Центральная	0103000020E610000001000000050000003FE5982CEE154B40EE3D5C72DCE94A403FE5982CEE154B4037C7B94DB8EB4A40B84082E2C7184B4037C7B94DB8EB4A40B84082E2C7184B40EE3D5C72DCE94A403FE5982CEE154B40EE3D5C72DCE94A40
63327	7621	56.286054999999998	56.325491	54.818142999999999	54.787697000000001	Центральная	0103000020E61000000100000005000000BBED42739D244C4023145B41D3644B40BBED42739D244C40C539EAE8B8684B40381268B0A9294C40C539EAE8B8684B40381268B0A9294C4023145B41D3644B40BBED42739D244C4023145B41D3644B40
64554	58267	54.126441999999997	54.151775000000001	54.767595999999998	54.756433000000001	Дорожная	0103000020E61000000100000005000000A06B5F402F104B40BE4EEACBD2604B40A06B5F402F104B402C45F29540624B40DAACFA5C6D134B402C45F29540624B40DAACFA5C6D134B40BE4EEACBD2604B40A06B5F402F104B40BE4EEACBD2604B40
66115	58710	56.168897000000001	56.185533999999997	52.669392000000002	52.664667999999999	Центральная	0103000020E610000001000000050000003EB2B96A9E154C404F594DD713554A403EB2B96A9E154C401E1A16A3AE554A40E525FF93BF174C401E1A16A3AE554A40E525FF93BF174C404F594DD713554A403EB2B96A9E154C404F594DD713554A40
65725	58611	54.864849	54.895535000000002	55.077390999999999	55.063040000000001	Буденного	0103000020E61000000100000005000000397D3D5FB36E4B40802BD9B111884B40397D3D5FB36E4B409B00C3F2E7894B4031B610E4A0724B409B00C3F2E7894B4031B610E4A0724B40802BD9B111884B40397D3D5FB36E4B40802BD9B111884B40
64583	58282	55.449399999999997	55.473188	56.114581000000001	56.097703000000003	Центральная	0103000020E6100000010000000500000044696FF085B94B404DDC2A88810C4C4044696FF085B94B401ADF1797AA0E4C40096EA46C91BC4B401ADF1797AA0E4C40096EA46C91BC4B404DDC2A88810C4C4044696FF085B94B404DDC2A88810C4C40
66001	58682	54.968200000000003	54.990710999999997	54.030850999999998	54.016669999999998	Центральная	0103000020E610000001000000050000005DFE43FAED7B4B408369183E22024B405DFE43FAED7B4B404206F2ECF2034B40CB64389ECF7E4B404206F2ECF2034B40CB64389ECF7E4B408369183E22024B405DFE43FAED7B4B408369183E22024B40
64784	58348	55.484802999999999	55.507556999999998	54.913639000000003	54.901615999999997	Центральная	0103000020E61000000100000005000000580053060EBE4B4071C6302768734B40580053060EBE4B40D2AC6C1FF2744B408DEDB5A0F7C04B40D2AC6C1FF2744B408DEDB5A0F7C04B4071C6302768734B40580053060EBE4B4071C6302768734B40
64808	58356	56.539361999999997	56.560859000000001	52.507731	52.503061000000002	Родниковая	0103000020E61000000100000005000000425A63D009454C405072874D64404A40425A63D009454C402B155454FD404A4069554B3ACA474C402B155454FD404A4069554B3ACA474C405072874D64404A40425A63D009454C405072874D64404A40
64600	58292	54.633631000000001	54.664586999999997	55.416018999999999	55.399872999999999	Советская	0103000020E61000000100000005000000AB5D13D21A514B40D6C6D8092FB34B40AB5D13D21A514B40DFC14F1C40B54B40622CD32F11554B40DFC14F1C40B54B40622CD32F11554B40D6C6D8092FB34B40AB5D13D21A514B40D6C6D8092FB34B40
64565	6894	55.937463999999999	55.947184	54.518909999999998	54.510337999999997	Саитова	0103000020E61000000100000005000000B39602D2FEF74B40F9F36DC152414B40B39602D2FEF74B409FC893A46B424B40B1A547533DF94B409FC893A46B424B40B1A547533DF94B40F9F36DC152414B40B39602D2FEF74B40F9F36DC152414B40
64804	58355	58.180197999999997	58.192414999999997	55.173960999999998	55.158518999999998	Центральная	0103000020E61000000100000005000000FD6662BA10174D40B665C0594A944B40FD6662BA10174D40C5E3A25A44964B404221020EA1184D40C5E3A25A44964B404221020EA1184D40B665C0594A944B40FD6662BA10174D40B665C0594A944B40
65754	58621	53.460836	53.514726000000003	55.218913000000001	55.206344000000001	Колхозная	0103000020E61000000100000005000000E4688EACFCBA4A40E8DCED7A699A4B40E4688EACFCBA4A40AAD55757059C4B405133A48AE2C14A40AAD55757059C4B405133A48AE2C14A40E8DCED7A699A4B40E4688EACFCBA4A40E8DCED7A699A4B40
63803	32179	56.143475000000002	56.161799999999999	54.543224000000002	54.530754999999999	Победы	0103000020E61000000100000005000000956588635D124C402098A3C7EF434B40956588635D124C407F33315D88454B40143FC6DCB5144C407F33315D88454B40143FC6DCB5144C402098A3C7EF434B40956588635D124C402098A3C7EF434B40
65768	58626	55.943320999999997	55.958098	55.882171999999997	55.869045999999997	Советская	0103000020E61000000100000005000000A45016BEBEF84B401C5C3AE63CEF4B40A45016BEBEF84B4034B91803EBF04B40772E8CF4A2FA4B4034B91803EBF04B40772E8CF4A2FA4B401C5C3AE63CEF4B40A45016BEBEF84B401C5C3AE63CEF4B40
64159	58177	58.153849999999998	58.177053999999998	52.456023000000002	52.438980000000001	Игишева	0103000020E61000000100000005000000AB3E575BB1134D408ECC237F30384A40AB3E575BB1134D40A69C2FF65E3A4A4020D099B4A9164D40A69C2FF65E3A4A4020D099B4A9164D408ECC237F30384A40AB3E575BB1134D408ECC237F30384A40
63326	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	проспект Ленина	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63285	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Стахановская	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63678	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Революционная	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63612	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Радужная	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63475	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Промысловая	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63577	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Пролетарская	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63641	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Мичурина	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63733	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Машиностроителей	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63440	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Ленина проспект	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63458	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Космонавтов	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
62320	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Есенина	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63756	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Докучаева	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63653	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Губкина	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
62321	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Горького	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
62319	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Геологическая	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63308	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Гайфуллина	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63378	57936	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Бульварная	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
65139	58477	56.832284999999999	56.850323000000003	51.880192999999998	51.869422999999998	Камышева	0103000020E61000000100000005000000C6F99B50886A4C40F2B1BB4049EF4940C6F99B50886A4C4085950A2AAAF04940B0045262D76C4C4085950A2AAAF04940B0045262D76C4C40F2B1BB4049EF4940C6F99B50886A4C40F2B1BB4049EF4940
64463	58236	54.611325999999998	54.646639	55.572471999999998	55.547280000000001	Ханифв Валиева	0103000020E61000000100000005000000E5982CEE3F4E4B40A0E062450DC64B40E5982CEE3F4E4B4017F032C346C94B40B9A81611C5524B4017F032C346C94B40B9A81611C5524B40A0E062450DC64B40E5982CEE3F4E4B40A0E062450DC64B40
66142	58715	57.761789999999998	57.769398000000002	52.357312999999998	52.350487000000001	Центральная	0103000020E61000000100000005000000BD35B05582E14C402A560DC2DC2C4A40BD35B05582E14C40C3B7B06EBC2D4A40CDCD37A27BE24C40C3B7B06EBC2D4A40CDCD37A27BE24C402A560DC2DC2C4A40BD35B05582E14C402A560DC2DC2C4A40
65815	58637	55.389842000000002	55.405284000000002	54.182485	54.168461999999998	Верхняя	0103000020E61000000100000005000000BA4DB857E6B14B40334FAE2990154B40BA4DB857E6B14B405A8121AB5B174B40C9CB9A58E0B34B405A8121AB5B174B40C9CB9A58E0B34B40334FAE2990154B40BA4DB857E6B14B40334FAE2990154B40
65962	58672	56.551606	56.586056999999997	54.437130000000003	54.419710000000002	Советская	0103000020E61000000100000005000000812381069B464C40EFE6A90EB9354B40812381069B464C40DD0C37E0F3374B40C24B70EA034B4C40DD0C37E0F3374B40C24B70EA034B4C40EFE6A90EB9354B40812381069B464C40EFE6A90EB9354B40
65337	58206	57.536087999999999	57.584597000000002	54.229447999999998	54.203218999999997	Пушкина	0103000020E6100000010000000500000097E315889EC44C4081768714031A4B4097E315889EC44C40F910548D5E1D4B407C2B1213D4CA4C40F910548D5E1D4B407C2B1213D4CA4C4081768714031A4B4097E315889EC44C4081768714031A4B40
64312	58206	57.536087999999999	57.584597000000002	54.229447999999998	54.203218999999997	Дорожников	0103000020E6100000010000000500000097E315889EC44C4081768714031A4B4097E315889EC44C40F910548D5E1D4B407C2B1213D4CA4C40F910548D5E1D4B407C2B1213D4CA4C4081768714031A4B4097E315889EC44C4081768714031A4B40
65855	58644	54.573766999999997	54.606501999999999	55.301695000000002	55.290813	Санникова	0103000020E610000001000000050000001343723271494B403620425C39A54B401343723271494B40F12E17F19DA64B40B37A87DBA14D4B40F12E17F19DA64B40B37A87DBA14D4B403620425C39A54B401343723271494B403620425C39A54B40
65691	58602	55.991928999999999	56.010883	54.341064000000003	54.327530000000003	Мостовая	0103000020E610000001000000050000001C7A8B87F7FE4B40BD3AC780EC294B401C7A8B87F7FE4B40E6EB32FCA72B4B408B8A389D64014C40E6EB32FCA72B4B408B8A389D64014C40BD3AC780EC294B401C7A8B87F7FE4B40BD3AC780EC294B40
64689	58322	59.253244000000002	59.285189000000003	54.343798	54.334639000000003	Клубная	0103000020E6100000010000000500000041F4A44C6AA04D40AB7B6473D52A4B4041F4A44C6AA04D401137A792012C4B40E816BA1281A44D401137A792012C4B40E816BA1281A44D40AB7B6473D52A4B4041F4A44C6AA04D40AB7B6473D52A4B40
66065	58700	56.500869000000002	56.506205000000001	52.758969999999998	52.743608999999999	Школьная	0103000020E61000000100000005000000454AB3791C404C40710168942E5F4A40454AB3791C404C409352D0ED25614A402D095053CB404C409352D0ED25614A402D095053CB404C40710168942E5F4A40454AB3791C404C40710168942E5F4A40
65854	58643	54.523794000000002	54.554400000000001	55.405873999999997	55.389882	Ленина	0103000020E61000000100000005000000A7EB89AE0B434B4048A643A7E7B14B40A7EB89AE0B434B40FA25E2ADF3B34B4082734694F6464B40FA25E2ADF3B34B4082734694F6464B4048A643A7E7B14B40A7EB89AE0B434B4048A643A7E7B14B40
65209	58492	57.460673999999997	57.493445000000001	52.643313999999997	52.620843999999998	Школьная	0103000020E610000001000000050000000A0F9A5DF7BA4C407BF5F1D0774F4A400A0F9A5DF7BA4C408B87F71C58524A40F7AFAC3429BF4C408B87F71C58524A40F7AFAC3429BF4C407BF5F1D0774F4A400A0F9A5DF7BA4C407BF5F1D0774F4A40
65109	1370	56.216822000000001	56.257893000000003	54.516103000000001	54.491892999999997	Школьная	0103000020E61000000100000005000000D386C3D2C01B4C40CF108E59F63E4B40D386C3D2C01B4C400A2FC1A90F424B40056F48A302214C400A2FC1A90F424B40056F48A302214C40CF108E59F63E4B40D386C3D2C01B4C40CF108E59F63E4B40
63818	1776	55.894784999999999	55.929701999999999	54.636724999999998	54.605412000000001	Центральная	0103000020E61000000100000005000000C6F99B5088F24B40904DF2237E4D4B40C6F99B5088F24B40D6C56D3480514B404D83A27900F74B40D6C56D3480514B404D83A27900F74B40904DF2237E4D4B40C6F99B5088F24B40904DF2237E4D4B40
65919	58663	55.577725000000001	55.591647999999999	56.326233000000002	56.315185999999997	Центральная	0103000020E61000000100000005000000728A8EE4F2C94B401A14CD0358284C40728A8EE4F2C94B4020F0C000C2294C40355F251FBBCB4B4020F0C000C2294C40355F251FBBCB4B401A14CD0358284C40728A8EE4F2C94B401A14CD0358284C40
65082	58465	55.326062	55.346147999999999	54.618378999999997	54.602220000000003	Центральная	0103000020E61000000100000005000000F33B4D66BCA94B40A27F828B154D4B40F33B4D66BCA94B403FC4060B274F4B40B4C9E1934EAC4B403FC4060B274F4B40B4C9E1934EAC4B40A27F828B154D4B40F33B4D66BCA94B40A27F828B154D4B40
64650	20835	55.742395000000002	55.802824000000001	54.522129	54.494351000000002	Манаева	0103000020E6100000010000000500000062DBA2CC06DF4B4059DFC0E4463F4B4062DBA2CC06DF4B4087A5811FD5424B40D238D4EFC2E64B4087A5811FD5424B40D238D4EFC2E64B4059DFC0E4463F4B4062DBA2CC06DF4B4059DFC0E4463F4B40
63398	58104	57.080857999999999	57.088332000000001	55.641387000000002	55.637112999999999	Советская	0103000020E610000001000000050000005BCF108E598A4C40A06D35EB8CD14B405BCF108E598A4C402F8A1EF818D24B405B9885764E8B4C402F8A1EF818D24B405B9885764E8B4C40A06D35EB8CD14B405BCF108E598A4C40A06D35EB8CD14B40
63762	58104	55.062505000000002	55.073653	54.150815999999999	54.135553000000002	Первомайская	0103000020E61000000100000005000000126BF12900884B40F6EFFACC59114B40126BF12900884B4055DB4DF04D134B404B2025766D894B4055DB4DF04D134B404B2025766D894B40F6EFFACC59114B40126BF12900884B40F6EFFACC59114B40
66738	58104	57.080857999999999	57.088332000000001	55.641387000000002	55.637112999999999	Ленина	0103000020E610000001000000050000005BCF108E598A4C40A06D35EB8CD14B405BCF108E598A4C402F8A1EF818D24B405B9885764E8B4C402F8A1EF818D24B405B9885764E8B4C40A06D35EB8CD14B405BCF108E598A4C40A06D35EB8CD14B40
65003	58434	58.287483999999999	58.323695000000001	55.687249000000001	55.666207999999997	Вагапова	0103000020E61000000100000005000000C70F9546CC244D40B22AC24D46D54B40C70F9546CC244D40B79A75C6F7D74B407A7077D66E294D40B79A75C6F7D74B407A7077D66E294D40B22AC24D46D54B40C70F9546CC244D40B22AC24D46D54B40
64088	58163	57.853713999999997	57.924393999999999	55.715971000000003	55.663791000000003	С.А. Михляева	0103000020E610000001000000050000009411178046ED4C4088307E1AF7D44B409411178046ED4C4035F10EF0A4DB4B402F4FE78A52F64C4035F10EF0A4DB4B402F4FE78A52F64C4088307E1AF7D44B409411178046ED4C4088307E1AF7D44B40
63819	5667	55.796725000000002	55.807442000000002	54.814304	54.809728	Школьная	0103000020E61000000100000005000000EB73B515FBE54B40E753C72AA5674B40EB73B515FBE54B4041800C1D3B684B405BB56B425AE74B4041800C1D3B684B405BB56B425AE74B40E753C72AA5674B40EB73B515FBE54B40E753C72AA5674B40
65825	5667	55.770180000000003	55.826943999999997	54.828688	54.793796999999998	Чучкалова	0103000020E6100000010000000500000043041C4295E24B40DA54DD239B654B4043041C4295E24B40384BC972126A4B40CCCF0D4DD9E94B40384BC972126A4B40CCCF0D4DD9E94B40DA54DD239B654B4043041C4295E24B40DA54DD239B654B40
66967	5667	55.770180000000003	55.826943999999997	54.828688	54.793796999999998	Центральная	0103000020E6100000010000000500000043041C4295E24B40DA54DD239B654B4043041C4295E24B40384BC972126A4B40CCCF0D4DD9E94B40384BC972126A4B40CCCF0D4DD9E94B40DA54DD239B654B4043041C4295E24B40DA54DD239B654B40
65576	5667	55.770180000000003	55.826943999999997	54.828688	54.793796999999998	Комиссарова	0103000020E6100000010000000500000043041C4295E24B40DA54DD239B654B4043041C4295E24B40384BC972126A4B40CCCF0D4DD9E94B40384BC972126A4B40CCCF0D4DD9E94B40DA54DD239B654B4043041C4295E24B40DA54DD239B654B40
65625	58584	58.508082999999999	58.520992	53.366970999999999	53.361581000000001	Школьная	0103000020E61000000100000005000000A8531EDD08414D4070ED444948AE4A40A8531EDD08414D404BCADDE7F8AE4A4023BDA8DDAF424D404BCADDE7F8AE4A4023BDA8DDAF424D4070ED444948AE4A40A8531EDD08414D4070ED444948AE4A40
63811	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Российская	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63322	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Комсомольская	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
64186	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Коммунистическая	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63416	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Карла Маркса	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63586	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Гагарина	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63377	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Высоковольтная	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63407	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Ворошилова	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63798	58100	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Беляева	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
65974	58675	58.083089999999999	58.112006999999998	55.243105	55.236227	Центральная	0103000020E61000000100000005000000F44F70B1A20A4D4052B7B3AF3C9E4B40F44F70B1A20A4D403E3F8C101E9F4B4027F6D03E560E4D403E3F8C101E9F4B4027F6D03E560E4D4052B7B3AF3C9E4B40F44F70B1A20A4D4052B7B3AF3C9E4B40
64847	58374	54.791311999999998	54.809089999999998	56.21743	56.205590999999998	Центральная	0103000020E6100000010000000500000057772CB649654B400CAD4ECE501A4C4057772CB649654B40AB9509BFD41B4C40A4C2D84290674B40AB9509BFD41B4C40A4C2D84290674B400CAD4ECE501A4C4057772CB649654B400CAD4ECE501A4C40
64537	58258	55.914682999999997	55.916595999999998	54.578614000000002	54.575895000000003	Геологов	0103000020E61000000100000005000000849A215514F54B40087767EDB6494B40849A215514F54B40FE800706104A4B407CD2890453F54B40FE800706104A4B407CD2890453F54B40087767EDB6494B40849A215514F54B40087767EDB6494B40
64555	58269	56.216498999999999	56.225499999999997	54.877111999999997	54.874521999999999	Клубная	0103000020E61000000100000005000000F04E3E3DB61B4C40F6D03E56F06F4B40F04E3E3DB61B4C40EE76BD3445704B40BE9F1A2FDD1C4C40EE76BD3445704B40BE9F1A2FDD1C4C40F6D03E56F06F4B40F04E3E3DB61B4C40F6D03E56F06F4B40
66214	58729	55.181019999999997	55.200350999999998	55.616031	55.605947999999998	Школьная	0103000020E6100000010000000500000001F6D1A92B974B40CE893DB48FCD4B4001F6D1A92B974B403D29931ADACE4B40465C001AA5994B403D29931ADACE4B40465C001AA5994B40CE893DB48FCD4B4001F6D1A92B974B40CE893DB48FCD4B40
64773	58344	54.614192000000003	54.630648999999998	55.986066999999998	55.973889	Красноармейская	0103000020E6100000010000000500000080BBECD79D4E4B4092770E65A8FC4B4080BBECD79D4E4B401955867137FE4B40A7203F1BB9504B401955867137FE4B40A7203F1BB9504B4092770E65A8FC4B4080BBECD79D4E4B4092770E65A8FC4B40
65740	58616	56.427621000000002	56.451785000000001	53.047818999999997	53.036428000000001	Нугуш	0103000020E610000001000000050000009A0AF148BC364C40505436ACA9844A409A0AF148BC364C404F90D8EE1E864A4064E94317D4394C404F90D8EE1E864A4064E94317D4394C40505436ACA9844A409A0AF148BC364C40505436ACA9844A40
65241	58506	55.595565000000001	55.611358000000003	53.828234999999999	53.821257000000003	Центральная	0103000020E6100000010000000500000035D252793BCC4B40384E0AF31EE94A4035D252793BCC4B408733BF9A03EA4A40F1129CFA40CE4B408733BF9A03EA4A40F1129CFA40CE4B40384E0AF31EE94A4035D252793BCC4B40384E0AF31EE94A40
65616	58581	58.754015000000003	58.772682000000003	52.959225000000004	52.945568999999999	Школьная	0103000020E61000000100000005000000C3D8429083604D40438EAD6708794A40C3D8429083604D40B84082E2C77A4A409C1A683EE7624D40B84082E2C77A4A409C1A683EE7624D40438EAD6708794A40C3D8429083604D40438EAD6708794A40
66083	58705	54.984468	55.010455999999998	54.978064000000003	54.965662000000002	Мира	0103000020E61000000100000005000000B1FA230C037E4B40B77EFACF9A7B4B40B1FA230C037E4B408EB27E33317D4B400306499F56814B408EB27E33317D4B400306499F56814B40B77EFACF9A7B4B40B1FA230C037E4B40B77EFACF9A7B4B40
64732	58332	58.715055	58.739857000000001	55.645963999999999	55.634613000000002	Животноводов	0103000020E61000000100000005000000AFEB17EC865B4D40E84EB0FF3AD14B40AFEB17EC865B4D405932C7F2AED24B40BC5B59A2B35E4D405932C7F2AED24B40BC5B59A2B35E4D40E84EB0FF3AD14B40AFEB17EC865B4D40E84EB0FF3AD14B40
66403	13289	55.843913000000001	55.850856999999998	54.817515999999998	54.816347999999998	улица Заречная	0103000020E61000000100000005000000AAD5575705EC4B40D7135D177E684B40AAD5575705EC4B4076FA415DA4684B404D49D6E1E8EC4B4076FA415DA4684B404D49D6E1E8EC4B40D7135D177E684B40AAD5575705EC4B40D7135D177E684B40
66550	13289	55.852913999999998	55.855547000000001	54.810988999999999	54.804310999999998	 Первомайская	0103000020E61000000100000005000000782634492CED4B401268B0A9F3664B40782634492CED4B403735D07CCE674B407098689082ED4B403735D07CCE674B407098689082ED4B401268B0A9F3664B40782634492CED4B401268B0A9F3664B40
65643	58590	55.412362999999999	55.427858999999998	56.283749	56.272069999999999	Центральная	0103000020E610000001000000050000004C8A8F4FC8B44B40821C9430D3224C404C8A8F4FC8B44B40E8A221E351244C404E266E15C4B64B40E8A221E351244C404E266E15C4B64B40821C9430D3224C404C8A8F4FC8B44B40821C9430D3224C40
65019	58439	57.901387999999997	57.923324999999998	55.962381999999998	55.949702000000002	Советская	0103000020E61000000100000005000000E08096AE60F34C401079CBD58FF94B40E08096AE60F34C40292158552FFB4B40234A7B832FF64C40292158552FFB4B40234A7B832FF64C401079CBD58FF94B40E08096AE60F34C401079CBD58FF94B40
64120	58171	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	Ленина	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
63938	2245	55.849212999999999	55.924393000000002	54.504629999999999	54.483949000000003	Цюрупы	0103000020E61000000100000005000000452BF702B3EC4B4049F7730AF23D4B40452BF702B3EC4B404D4A41B797404B405FD3838252F64B404D4A41B797404B405FD3838252F64B4049F7730AF23D4B40452BF702B3EC4B4049F7730AF23D4B40
66477	2245	55.878391000000001	55.884948000000001	54.495721000000003	54.495348999999997	Лесная	0103000020E61000000100000005000000E50CC51D6FF04B409B8D9598673F4B40E50CC51D6FF04B40607825C9733F4B408F54DFF945F14B40607825C9733F4B408F54DFF945F14B409B8D9598673F4B40E50CC51D6FF04B409B8D9598673F4B40
65697	58603	53.553299000000003	53.584947	55.103589999999997	55.088506000000002	Школьная	0103000020E610000001000000050000006BF46A80D2C64A40F9BF232A548B4B406BF46A80D2C64A40A818E76F428D4B405872158BDFCA4A40A818E76F428D4B405872158BDFCA4A40F9BF232A548B4B406BF46A80D2C64A40F9BF232A548B4B40
64901	58392	56.784072000000002	56.795687000000001	51.786320000000003	51.776240999999999	Лесная	0103000020E61000000100000005000000CBDAA6785C644C403C6876DD5BE34940CBDAA6785C644C406A183E22A6E449401A6D5512D9654C406A183E22A6E449401A6D5512D9654C403C6876DD5BE34940CBDAA6785C644C403C6876DD5BE34940
65079	58463	55.650362000000001	55.676755	53.001190000000001	52.983167000000002	Центральная	0103000020E61000000100000005000000D447E00F3FD34B40D3C08F6AD87D4A40D447E00F3FD34B40878A71FE26804A40C63368E89FD64B40878A71FE26804A40C63368E89FD64B40D3C08F6AD87D4A40D447E00F3FD34B40D3C08F6AD87D4A40
64716	58327	58.271036000000002	58.285229000000001	52.401857999999997	52.382061999999998	Молодежная	0103000020E61000000100000005000000F304C24EB1224D40AD855968E7304A40F304C24EB1224D4067D13B1570334A40766F456282244D4067D13B1570334A40766F456282244D40AD855968E7304A40F304C24EB1224D40AD855968E7304A40
63323	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Чапаева	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
64053	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Социалистическая	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63562	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Советская	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63778	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Седова	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63734	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Расковой	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
62316	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Комарова	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63630	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Кирова	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63757	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Демьяна Бедного	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63603	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Братьев Першиных	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63998	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Братьев Кадомцевых	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63560	57935	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	 Социалистический	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63523	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Ленина	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63801	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Курбатова	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63370	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Красноармейская	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63374	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Коммунистическая	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63654	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Кирова	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63746	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Калинина	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63367	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Интернациональная	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63795	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Гагарина	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63390	58102	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Бурновская	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
66320	58743	56.738059999999997	56.749164	52.211832000000001	52.201946999999997	Школьная	0103000020E610000001000000050000002D3E05C0785E4C403D433866D9194A402D3E05C0785E4C40861F9C4F1D1B4A4097AB1F9BE45F4C40861F9C4F1D1B4A4097AB1F9BE45F4C403D433866D9194A402D3E05C0785E4C403D433866D9194A40
64081	58132	54.247320000000002	54.287852000000001	53.707574000000001	53.687261999999997	Строительная	0103000020E61000000100000005000000C8D2872EA81F4B404BE48233F8D74A40C8D2872EA81F4B40FDBFEAC891DA4A404A0B9755D8244B40FDBFEAC891DA4A404A0B9755D8244B404BE48233F8D74A40C8D2872EA81F4B404BE48233F8D74A40
63794	58132	54.247320000000002	54.287852000000001	53.707574000000001	53.687261999999997	Советская	0103000020E61000000100000005000000C8D2872EA81F4B404BE48233F8D74A40C8D2872EA81F4B40FDBFEAC891DA4A404A0B9755D8244B40FDBFEAC891DA4A404A0B9755D8244B404BE48233F8D74A40C8D2872EA81F4B404BE48233F8D74A40
66023	58688	56.022965999999997	56.032901000000003	56.219327	56.208710000000004	Центральная	0103000020E61000000100000005000000C075C58CF0024C40912C6002B71A4C40C075C58CF0024C409D103AE8121C4C40BB80971936044C409D103AE8121C4C40BB80971936044C40912C6002B71A4C40C075C58CF0024C40912C6002B71A4C40
64630	58306	56.169373	56.205449000000002	55.912264	55.895963999999999	Октябрьская	0103000020E61000000100000005000000A7E9B303AE154C405932C7F2AEF24B40A7E9B303AE154C40B9A81611C5F44B407AFF1F274C1A4C40B9A81611C5F44B407AFF1F274C1A4C405932C7F2AEF24B40A7E9B303AE154C405932C7F2AEF24B40
63274	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Спортивная	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
65789	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Совхозная	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63655	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Свободы	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63272	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Садовая	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63658	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Молодежная	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
65343	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Маршала Жукова	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63514	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Маркса	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63743	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Луначарского	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63790	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Ленина	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63669	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Крупской	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63383	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Блюхера	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63800	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Артамонова	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63725	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Алексеева	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63710	58093	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	50 лет Октября	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63318	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Советская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63607	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Революционеров	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63305	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Пионерская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63644	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Красноармейская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63361	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Красная	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63637	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Карла Маркса	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63417	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Горохова	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63622	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Восточная	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
62327	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Волгоградская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63572	57937	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Амирова	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
64686	58320	58.466436999999999	58.492102000000003	55.080224999999999	55.062260999999999	С.Юлаева	0103000020E610000001000000050000007A522635B43B4D407B681F2BF8874B407A522635B43B4D402AA913D0448A4B40EA25C632FD3E4D402AA913D0448A4B40EA25C632FD3E4D407B681F2BF8874B407A522635B43B4D407B681F2BF8874B40
65011	58437	56.263309999999997	56.274915999999997	52.997104	52.977696999999999	Береговая	0103000020E61000000100000005000000D95A5F24B4214C40DB32E02C257D4A40D95A5F24B4214C40FB5A971AA17F4A40D5928E7230234C40FB5A971AA17F4A40D5928E7230234C40DB32E02C257D4A40D95A5F24B4214C40DB32E02C257D4A40
66033	58691	54.072372999999999	54.103993000000003	54.456380000000003	54.433867999999997	Школьная	0103000020E61000000100000005000000840EBA8443094B40F56393FC88374B40840EBA8443094B403546EBA86A3A4B40A80183A44F0D4B403546EBA86A3A4B40A80183A44F0D4B40F56393FC88374B40840EBA8443094B40F56393FC88374B40
65895	58658	55.114624999999997	55.144610999999998	55.055914000000001	55.045490999999998	Шоссейная	0103000020E61000000100000005000000E9263108AC8E4B4094A12AA6D2854B40E9263108AC8E4B40BCB1A03028874B4028D2FD9C82924B40BCB1A03028874B4028D2FD9C82924B4094A12AA6D2854B40E9263108AC8E4B4094A12AA6D2854B40
63539	58090	58.282525	58.343341000000002	52.612741	52.564118999999998	пр.С.Юлаева	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
64147	58090	58.282525	58.343341000000002	52.612741	52.564118999999998	Юбилейная	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
63264	58090	58.282525	58.343341000000002	52.612741	52.564118999999998	Чекмарева	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
63651	58090	58.282525	58.343341000000002	52.612741	52.564118999999998	Стахановская	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
63266	58090	58.282525	58.343341000000002	52.612741	52.564118999999998	Нигмати	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
63675	58090	58.282525	58.343341000000002	52.612741	52.564118999999998	М.Горького	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
64190	58090	58.282525	58.343341000000002	52.612741	52.564118999999998	Ленина	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
64609	58299	59.585864000000001	59.630896	54.221637000000001	54.198836999999997	Центральная	0103000020E61000000100000005000000AEF36F97FDCA4D400C1EA67D73194B40AEF36F97FDCA4D40B24AE9995E1C4B40AF963B33C1D04D40B24AE9995E1C4B40AF963B33C1D04D400C1EA67D73194B40AEF36F97FDCA4D400C1EA67D73194B40
64978	58423	55.255167	55.272359999999999	55.039543000000002	55.030720000000002	Лесная	0103000020E610000001000000050000005C02F04FA9A04B40A4AA09A2EE834B405C02F04FA9A04B4093E4B9BE0F854B40895E46B1DCA24B4093E4B9BE0F854B40895E46B1DCA24B40A4AA09A2EE834B405C02F04FA9A04B40A4AA09A2EE834B40
65930	58665	55.880583000000001	55.896042999999999	56.194654	56.181870000000004	Центральная	0103000020E61000000100000005000000F03499F1B6F04B40D00F238447174C40F03499F1B6F04B408E041A6CEA184C40A5677A89B1F24B408E041A6CEA184C40A5677A89B1F24B40D00F238447174C40F03499F1B6F04B40D00F238447174C40
64893	58388	56.438381999999997	56.478160000000003	55.860570000000003	55.843145999999997	Центральная	0103000020E61000000100000005000000D993C0E61C384C4069E04735ECEB4B40D993C0E61C384C4099F5622827EE4B40B020CD58343D4C4099F5622827EE4B40B020CD58343D4C4069E04735ECEB4B40D993C0E61C384C4069E04735ECEB4B40
64965	58417	56.52984	56.561855999999999	52.371308999999997	52.360173000000003	Старый Хутор	0103000020E610000001000000050000006B0E10CCD1434C407CF31B261A2E4A406B0E10CCD1434C40F0DAA50D872F4A40DB87BCE5EA474C40F0DAA50D872F4A40DB87BCE5EA474C407CF31B261A2E4A406B0E10CCD1434C407CF31B261A2E4A40
65390	58537	58.268816999999999	58.312331	55.456601999999997	55.424643000000003	Центральная	0103000020E61000000100000005000000EECD6F9868224D40D8BCAAB35AB64B40EECD6F9868224D40E3A430EF71BA4B4074435376FA274D40E3A430EF71BA4B4074435376FA274D40D8BCAAB35AB64B40EECD6F9868224D40D8BCAAB35AB64B40
65046	58445	58.072068000000002	58.086638000000001	52.973337000000001	52.966867000000001	Школьная	0103000020E61000000100000005000000488B338639094D40734A404CC27B4A40488B338639094D404E7E8B4E967C4A40A14B38F4160B4D404E7E8B4E967C4A40A14B38F4160B4D40734A404CC27B4A40488B338639094D40734A404CC27B4A40
65988	58679	58.308467999999998	58.322553999999997	53.357039999999998	53.346235999999998	Центральная	0103000020E6100000010000000500000067EE21E17B274D405359147651AC4A4067EE21E17B274D4092AE997CB3AD4A40D498107349294D4092AE997CB3AD4A40D498107349294D405359147651AC4A4067EE21E17B274D405359147651AC4A40
1636	6002	55.986665000000002	56.004308000000002	54.837674	54.819097999999997	улица Центральная	0103000020E61000000100000005000000CE8DE9094BFE4B40081C0934D8684B40CE8DE9094BFE4B40D15AD1E6386B4B403B8E1F2A8D004C40D15AD1E6386B4B403B8E1F2A8D004C40081C0934D8684B40CE8DE9094BFE4B40081C0934D8684B40
66382	6002	55.995719999999999	55.998558000000003	54.834356	54.831338000000002	Школьная	0103000020E610000001000000050000008FFCC1C073FF4B4006F69848696A4B408FFCC1C073FF4B40569C6A2DCC6A4B406094A0BFD0FF4B40569C6A2DCC6A4B406094A0BFD0FF4B4006F69848696A4B408FFCC1C073FF4B4006F69848696A4B40
63316	6002	55.986665000000002	56.004308000000002	54.837674	54.819097999999997	Центральная	0103000020E61000000100000005000000CE8DE9094BFE4B40081C0934D8684B40CE8DE9094BFE4B40D15AD1E6386B4B403B8E1F2A8D004C40D15AD1E6386B4B403B8E1F2A8D004C40081C0934D8684B40CE8DE9094BFE4B40081C0934D8684B40
66429	6002	55.986665000000002	56.004308000000002	54.837674	54.819097999999997	 Центральная	0103000020E61000000100000005000000CE8DE9094BFE4B40081C0934D8684B40CE8DE9094BFE4B40D15AD1E6386B4B403B8E1F2A8D004C40D15AD1E6386B4B403B8E1F2A8D004C40081C0934D8684B40CE8DE9094BFE4B40081C0934D8684B40
64612	58301	56.178292999999996	56.203930999999997	54.228875000000002	54.215829999999997	Школьная	0103000020E61000000100000005000000880D164ED2164C4072BF4351A01B4B40880D164ED2164C409EEFA7C64B1D4B40FED137691A1A4C409EEFA7C64B1D4B40FED137691A1A4C4072BF4351A01B4B40880D164ED2164C4072BF4351A01B4B40
64521	19288	56.161287999999999	56.201946	54.606309000000003	54.579768000000001	Центральная	0103000020E610000001000000050000005E9ECE15A5144C4038A27BD6354A4B405E9ECE15A5144C409F2287889B4D4B406DC7D45DD9194C409F2287889B4D4B406DC7D45DD9194C4038A27BD6354A4B405E9ECE15A5144C4038A27BD6354A4B40
65862	58645	55.962077999999998	55.981050000000003	53.036672000000003	53.026539	Тятер	0103000020E61000000100000005000000BD19355F25FB4B40C68844A165834A40BD19355F25FB4B40E75608ABB1844A40D3DEE00B93FD4B40E75608ABB1844A40D3DEE00B93FD4B40C68844A165834A40BD19355F25FB4B40C68844A165834A40
65606	58577	57.111876000000002	57.130516	51.911887999999998	51.899318999999998	Центральная	0103000020E61000000100000005000000899AE8F3518E4C40F1D58EE21CF34940899AE8F3518E4C40B3CEF8BEB8F4494068CD8FBFB4904C40B3CEF8BEB8F4494068CD8FBFB4904C40F1D58EE21CF34940899AE8F3518E4C40F1D58EE21CF34940
63334	57934	53.926253000000003	53.950319	55.904614000000002	55.869757999999997	Цветочный бульвар	0103000020E61000000100000005000000346953758FF64A4099B7EA3A54EF4B40346953758FF64A407BC03C64CAF34B403BE2900DA4F94A407BC03C64CAF34B403BE2900DA4F94A4099B7EA3A54EF4B40346953758FF64A4099B7EA3A54EF4B40
62315	57934	53.926253000000003	53.950319	55.904614000000002	55.869757999999997	Мира	0103000020E61000000100000005000000346953758FF64A4099B7EA3A54EF4B40346953758FF64A407BC03C64CAF34B403BE2900DA4F94A407BC03C64CAF34B403BE2900DA4F94A4099B7EA3A54EF4B40346953758FF64A4099B7EA3A54EF4B40
64448	58233	58.486010999999998	58.506169999999997	52.808304999999997	52.796981000000002	Ленина	0103000020E61000000100000005000000853FC39B353E4D404644317903664A40853FC39B353E4D40BD18CA8976674A40B01BB62DCA404D40BD18CA8976674A40B01BB62DCA404D404644317903664A40853FC39B353E4D404644317903664A40
65906	58661	55.479647	55.496471999999997	52.628973000000002	52.618547999999997	Молодёжная	0103000020E61000000100000005000000F04FA91265BD4B40CB80B3942C4F4A40F04FA91265BD4B409488F02F82504A409AB0FD648CBF4B409488F02F82504A409AB0FD648CBF4B40CB80B3942C4F4A40F04FA91265BD4B40CB80B3942C4F4A40
66350	58748	55.187874000000001	55.217149999999997	54.024351000000003	54.008066999999997	Айская	0103000020E6100000010000000500000065E256410C984B40A296E65608014B4065E256410C984B40FD4FFEEE1D034B40C7293A92CB9B4B40FD4FFEEE1D034B40C7293A92CB9B4B40A296E65608014B4065E256410C984B40A296E65608014B40
63240	24735	54.878439999999998	54.960959000000003	56.294801	56.242694	Победы	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
63579	24735	54.878439999999998	54.960959000000003	56.294801	56.242694	Ленина	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
66665	24735	54.878439999999998	54.960959000000003	56.294801	56.242694	Азина	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
63233	24735	54.878439999999998	54.960959000000003	56.294801	56.242694	Азина	0103000020E61000000100000005000000C6BFCFB870704B40BC77D498101F4C40C6BFCFB870704B40FFE9060ABC254C4000E65AB4007B4B40FFE9060ABC254C4000E65AB4007B4B40BC77D498101F4C40C6BFCFB870704B40BC77D498101F4C40
64475	27135	55.313592999999997	55.344154000000003	56.146070999999999	56.135494000000001	Центральная	0103000020E6100000010000000500000094A0BFD023A84B40F1660DDE57114C4094A0BFD023A84B406FF25B74B2124C40D064FF3C0DAC4B406FF25B74B2124C40D064FF3C0DAC4B40F1660DDE57114C4094A0BFD023A84B40F1660DDE57114C40
65205	25262	55.141278	55.156154000000001	56.201709999999999	56.188617999999998	Центральная	0103000020E6100000010000000500000078D2C26515924B40EDB776A224184C4078D2C26515924B4059A31EA2D1194C40DE91B1DAFC934B4059A31EA2D1194C40DE91B1DAFC934B40EDB776A224184C4078D2C26515924B40EDB776A224184C40
66088	27215	55.371741	55.396839999999997	56.179730999999997	56.166986999999999	Ф. Халикова	0103000020E610000001000000050000008ACA863595AF4B40B7ED7BD45F154C408ACA863595AF4B40E789E76C01174C4050DF32A7CBB24B40E789E76C01174C4050DF32A7CBB24B40B7ED7BD45F154C408ACA863595AF4B40B7ED7BD45F154C40
64050	58157	54.327314999999999	55.508347999999998	56.533661000000002	55.988700999999999	Высоковольтная	0103000020E61000000100000005000000C03E3A75E5294B40E1421EC18DFE4B40C03E3A75E5294B404913EF004F444C40567E198C11C14B404913EF004F444C40567E198C11C14B40E1421EC18DFE4B40C03E3A75E5294B40E1421EC18DFE4B40
64480	27099	54.877352999999999	54.886094	56.253382000000002	56.243729999999999	Центральная	0103000020E610000001000000050000001406651A4D704B40EC866D8B321F4C401406651A4D704B4092B245D26E204C40469737876B714B4092B245D26E204C40469737876B714B40EC866D8B321F4C401406651A4D704B40EC866D8B321F4C40
65327	58523	55.423484000000002	55.437327000000003	56.217300000000002	56.209069999999997	 Центральная	0103000020E610000001000000050000008C3045B934B64B40904946CEC21A4C408C3045B934B64B40DDB5847CD01B4C403354C554FAB74B40DDB5847CD01B4C403354C554FAB74B40904946CEC21A4C408C3045B934B64B40904946CEC21A4C40
64844	26528	54.903619999999997	54.925170000000001	56.324351	56.312764000000001	Верхняя	0103000020E610000001000000050000007901F6D1A9734B40DEAE97A608284C407901F6D1A9734B4063B6645584294C40C39E76F86B764B4063B6645584294C40C39E76F86B764B40DEAE97A608284C407901F6D1A9734B40DEAE97A608284C40
64316	26674	54.900601000000002	54.919258999999997	56.189855000000001	56.183202999999999	Комсомольская	0103000020E6100000010000000500000059DFC0E446734B40B9C3263273174C4059DFC0E446734B40B5FD2B2B4D184C40DEC66647AA754B40B5FD2B2B4D184C40DEC66647AA754B40B9C3263273174C4059DFC0E446734B40B9C3263273174C40
66565	58840	54.327314999999999	55.508347999999998	56.533661000000002	55.988700999999999	Центральная	0103000020E61000000100000005000000C03E3A75E5294B40E1421EC18DFE4B40C03E3A75E5294B404913EF004F444C40567E198C11C14B404913EF004F444C40567E198C11C14B40E1421EC18DFE4B40C03E3A75E5294B40E1421EC18DFE4B40
65575	58569	54.327314999999999	55.508347999999998	56.533661000000002	55.988700999999999	Ф.Асхадуллина	0103000020E61000000100000005000000C03E3A75E5294B40E1421EC18DFE4B40C03E3A75E5294B404913EF004F444C40567E198C11C14B404913EF004F444C40567E198C11C14B40E1421EC18DFE4B40C03E3A75E5294B40E1421EC18DFE4B40
64011	26942	55.271794	55.297494999999998	56.089086000000002	56.082416000000002	Парковая	0103000020E61000000100000005000000E09F5225CAA24B406555849B8C0A4C40E09F5225CAA24B400744882B670B4C409CDCEF5014A64B400744882B670B4C409CDCEF5014A64B406555849B8C0A4C40E09F5225CAA24B406555849B8C0A4C40
66456	58781	54.806404000000001	54.823884999999997	56.254992000000001	56.243915000000001	Чапаева	0103000020E610000001000000050000008AAE0B3F38674B407E00529B381F4C408AAE0B3F38674B40EE5EEE93A3204C401D554D1075694B40EE5EEE93A3204C401D554D1075694B407E00529B381F4C408AAE0B3F38674B407E00529B381F4C40
64813	27012	54.684933999999998	54.713869000000003	56.135589000000003	56.122127999999996	Центральная	0103000020E6100000010000000500000090F5D4EAAB574B4083F6EAE3A10F4C4090F5D4EAAB574B404359F8FA5A114C406A50340F605B4B404359F8FA5A114C406A50340F605B4B4083F6EAE3A10F4C4090F5D4EAAB574B4083F6EAE3A10F4C40
66460	58786	54.73462	54.747843000000003	56.161368000000003	56.154375000000002	Центральная	0103000020E61000000100000005000000677E3507085E4B40F6285C8FC2134C40677E3507085E4B407B4FE5B4A7144C4072C5C551B95F4B407B4FE5B4A7144C4072C5C551B95F4B40F6285C8FC2134C40677E3507085E4B40F6285C8FC2134C40
64068	33033	55.182977999999999	55.204906000000001	56.264032	56.249276000000002	Комсомольская	0103000020E6100000010000000500000099F1B6D26B974B40BFD6A546E81F4C4099F1B6D26B974B407A8CF2CCCB214C4089601C5C3A9A4B407A8CF2CCCB214C4089601C5C3A9A4B40BFD6A546E81F4C4099F1B6D26B974B40BFD6A546E81F4C40
65239	20092	55.410646999999997	55.434793999999997	56.195751000000001	56.183352999999997	Победы	0103000020E61000000100000005000000AA99B51490B44B40CE4F711C78174C40AA99B51490B44B406494675E0E194C409E3F6D54A7B74B406494675E0E194C409E3F6D54A7B74B40CE4F711C78174C40AA99B51490B44B40CE4F711C78174C40
66310	26930	55.22448	55.244593000000002	56.328902999999997	56.307901000000001	Мира	0103000020E61000000100000005000000944DB9C2BB9C4B40EEB3CA4C69274C40944DB9C2BB9C4B403447567E192A4C404FEACBD24E9F4B403447567E192A4C404FEACBD24E9F4B40EEB3CA4C69274C40944DB9C2BB9C4B40EEB3CA4C69274C40
66807	26161	54.714506	54.728268999999997	56.251027000000001	56.238267	Центральная	0103000020E61000000100000005000000DC65BFEE745B4B40A75B76887F1E4C40DC65BFEE745B4B40DDB419A721204C4066D828EB375D4B40DDB419A721204C4066D828EB375D4B40A75B76887F1E4C40DC65BFEE745B4B40A75B76887F1E4C40
66867	26390	54.729903999999998	54.742201999999999	56.291409000000002	56.285293000000003	Чишминская	0103000020E610000001000000050000001B9C887E6D5D4B408D63247B84244C401B9C887E6D5D4B404A61DEE34C254C404D83A279005F4B404A61DEE34C254C404D83A279005F4B408D63247B84244C401B9C887E6D5D4B408D63247B84244C40
64410	26445	54.807653000000002	54.828709000000003	56.328943000000002	56.306493000000003	Центральная	0103000020E6100000010000000500000016C26A2C61674B40FAB9A1293B274C4016C26A2C61674B40C39FE1CD1A2A4C405073F222136A4B40C39FE1CD1A2A4C405073F222136A4B40FAB9A1293B274C4016C26A2C61674B40FAB9A1293B274C40
65596	26270	55.341827000000002	55.355293000000003	56.091939000000004	56.083240000000004	Центральная	0103000020E61000000100000005000000E5F1B4FCC0AB4B400ADCBA9BA70A4C40E5F1B4FCC0AB4B400D1D3BA8C40B4C40B6BFB33D7AAD4B400D1D3BA8C40B4C40B6BFB33D7AAD4B400ADCBA9BA70A4C40E5F1B4FCC0AB4B400ADCBA9BA70A4C40
65280	26189	55.303432999999998	55.328935999999999	56.245919999999998	56.232979	Молодежная	0103000020E610000001000000050000007AC37DE4D6A64B40D0D38041D21D4C407AC37DE4D6A64B4056B77A4E7A1F4C40103D29931AAA4B4056B77A4E7A1F4C40103D29931AAA4B40D0D38041D21D4C407AC37DE4D6A64B40D0D38041D21D4C40
65604	26095	54.384051999999997	54.407238	56.216358999999997	56.202857000000002	Школьная	0103000020E6100000010000000500000050FBAD9D28314B40E161DA37F7194C4050FBAD9D28314B40FE98D6A6B11B4C401FD8F15F20344B40FE98D6A6B11B4C401FD8F15F20344B40E161DA37F7194C4050FBAD9D28314B40E161DA37F7194C40
65275	27030	54.667147	54.679974999999999	56.179996000000003	56.163648999999999	Мира	0103000020E61000000100000005000000F04FA91265554B40F5824F73F2144C40F04FA91265554B4096B4E21B0A174C407E8CB96B09574B4096B4E21B0A174C407E8CB96B09574B40F5824F73F2144C40F04FA91265554B40F5824F73F2144C40
64218	26115	54.633477999999997	54.652540999999999	56.235686000000001	56.220247999999998	Победы	0103000020E61000000100000005000000245E9ECE15514B4034812216311C4C40245E9ECE15514B40021077F52A1E4C404A26A77686534B40021077F52A1E4C404A26A77686534B4034812216311C4C40245E9ECE15514B4034812216311C4C40
66806	26034	54.521953000000003	54.547122999999999	56.240613000000003	56.221694999999997	Магистральная	0103000020E6100000010000000500000049861C5BCF424B40E6577380601C4C4049861C5BCF424B4009FF2268CC1E4C40D8F15F2008464B4009FF2268CC1E4C40D8F15F2008464B40E6577380601C4C4049861C5BCF424B40E6577380601C4C40
66302	26005	55.063861000000003	55.076608	56.193171	56.174729999999997	Полевая	0103000020E61000000100000005000000B43EE5982C884B40A6D0798D5D164C40B43EE5982C884B408FC4CBD3B9184C40554E7B4ACE894B408FC4CBD3B9184C40554E7B4ACE894B40A6D0798D5D164C40B43EE5982C884B40A6D0798D5D164C40
64499	25944	54.957751999999999	54.978682999999997	56.229376000000002	56.212079000000003	Куйбышева	0103000020E61000000100000005000000DCD6169E977A4B408E959867251B4C40DCD6169E977A4B40603E59315C1D4C4059130B7C457D4B40603E59315C1D4C4059130B7C457D4B408E959867251B4C40DCD6169E977A4B408E959867251B4C40
64146	25816	55.014040999999999	55.029833000000004	56.285882999999998	56.273715000000003	Центральная	0103000020E61000000100000005000000CDE67118CC814B405BB6D61709234C40CDE67118CC814B40BEBD6BD097244C40B9AB5791D1834B40BEBD6BD097244C40B9AB5791D1834B405BB6D61709234C40CDE67118CC814B405BB6D61709234C40
64799	25657	55.064247999999999	55.089894000000001	56.045619000000002	56.032840999999998	Школьная	0103000020E61000000100000005000000AD6A494739884B40E57B462234044C40AD6A494739884B40C289E8D7D6054C40A60D87A5818B4B40C289E8D7D6054C40A60D87A5818B4B40E57B462234044C40AD6A494739884B40E57B462234044C40
64690	48714	54.935186999999999	54.958022	56.105139000000001	56.087916	Молодежная	0103000020E610000001000000050000007A522635B4774B40C765DCD4400B4C407A522635B4774B405F44DB31750D4C409C6C0377A07A4B405F44DB31750D4C409C6C0377A07A4B40C765DCD4400B4C407A522635B4774B40C765DCD4400B4C40
65544	25559	54.646594	54.661479	56.379874999999998	56.363532999999997	Новая	0103000020E6100000010000000500000019E59997C3524B402502D53F882E4C4019E59997C3524B40B4C876BE9F304C40D2FE0758AB544B40B4C876BE9F304C40D2FE0758AB544B402502D53F882E4C4019E59997C3524B402502D53F882E4C40
65289	26254	55.314481999999998	55.327041000000001	56.299421000000002	56.288311	Г.Файзуллина	0103000020E61000000100000005000000209738F240A84B40DD09F65FE7244C40209738F240A84B40295E656D53264C40BFB9BF7ADCA94B40295E656D53264C40BFB9BF7ADCA94B40DD09F65FE7244C40209738F240A84B40DD09F65FE7244C40
65611	26467	54.832410000000003	54.848095000000001	56.355100999999998	56.345348999999999	Механизаторов	0103000020E61000000100000005000000836E2F698C6A4B40685A6265342C4C40836E2F698C6A4B4071E316F3732D4C40587380608E6C4B4071E316F3732D4C40587380608E6C4B40685A6265342C4C40836E2F698C6A4B40685A6265342C4C40
65607	26854	55.221308999999998	55.235447999999998	56.278972000000003	56.265506999999999	Школьная	0103000020E61000000100000005000000BDA772DA539C4B40F6ED2422FC214C40BDA772DA539C4B40F73FC05AB5234C404DF4F928239E4B40F73FC05AB5234C404DF4F928239E4B40F6ED2422FC214C40BDA772DA539C4B40F6ED2422FC214C40
65170	25850	55.022081	55.047961000000001	56.257362999999998	56.243043999999998	Молодежная	0103000020E61000000100000005000000766EDA8CD3824B4098BED7101C1F4C40766EDA8CD3824B40A8195245F1204C40E23D079623864B40A8195245F1204C40E23D079623864B4098BED7101C1F4C40766EDA8CD3824B4098BED7101C1F4C40
66766	25771	55.03172	55.057806999999997	56.071503999999997	56.060253000000003	Центральная	0103000020E610000001000000050000008750A5660F844B40323ECC5EB6074C408750A5660F844B403FC4060B27094C406C3D433866874B403FC4060B27094C406C3D433866874B40323ECC5EB6074C408750A5660F844B40323ECC5EB6074C40
65742	25172	55.170132000000002	55.197153	56.184564999999999	56.172891	Центральная	0103000020E610000001000000050000006500A8E2C6954B40E962D34A21164C406500A8E2C6954B403D7E6FD39F174C4076A73B4F3C994B403D7E6FD39F174C4076A73B4F3C994B40E962D34A21164C406500A8E2C6954B40E962D34A21164C40
65188	25631	54.649343000000002	54.661991	56.340190999999997	56.322594000000002	Центральная	0103000020E610000001000000050000007A71E2AB1D534B4063F19BC24A294C407A71E2AB1D534B405FB2F1608B2B4C40889FFF1EBC544B405FB2F1608B2B4C40889FFF1EBC544B4063F19BC24A294C407A71E2AB1D534B4063F19BC24A294C40
65208	25433	54.715916999999997	54.735877000000002	56.21313	56.201990000000002	Центральная	0103000020E6100000010000000500000041D3122BA35B4B403D0FEECEDA194C4041D3122BA35B4B40F3E505D8471B4C407670B037315E4B40F3E505D8471B4C407670B037315E4B403D0FEECEDA194C4041D3122BA35B4B403D0FEECEDA194C40
66835	22806	54.211691999999999	54.243726000000002	54.903447999999997	54.891530000000003	Центральная	0103000020E61000000100000005000000946934B9181B4B4092B3B0A71D724B40946934B9181B4B407CD11E2FA4734B40AB97DF69321F4B407CD11E2FA4734B40AB97DF69321F4B4092B3B0A71D724B40946934B9181B4B4092B3B0A71D724B40
64905	24408	53.957272000000003	53.995745999999997	54.752786	54.718000000000004	Шаранская	0103000020E6100000010000000500000032B08EE387FA4A4096438B6CE75B4B4032B08EE387FA4A407E71A94A5B604B40B88FDC9A74FF4A407E71A94A5B604B40B88FDC9A74FF4A4096438B6CE75B4B4032B08EE387FA4A4096438B6CE75B4B40
65266	23424	54.111637999999999	54.157138000000003	54.973398000000003	54.957712000000001	Центральная	0103000020E61000000100000005000000D47E6B274A0E4B404E7E8B4E967A4B40D47E6B274A0E4B40F4FE3F4E987C4B40BC7A15191D144B40F4FE3F4E987C4B40BC7A15191D144B404E7E8B4E967A4B40D47E6B274A0E4B404E7E8B4E967A4B40
63432	24450	53.968761000000001	54.017251999999999	54.833038999999999	54.805084000000001	Школьная	0103000020E61000000100000005000000F451465C00FC4A40354415FE0C674B40F451465C00FC4A4072A59E05A16A4B4032E5435035024B4072A59E05A16A4B4032E5435035024B40354415FE0C674B40F451465C00FC4A40354415FE0C674B40
64504	24450	53.968761000000001	54.017251999999999	54.833038999999999	54.805084000000001	Пролетарская	0103000020E61000000100000005000000F451465C00FC4A40354415FE0C674B40F451465C00FC4A4072A59E05A16A4B4032E5435035024B4072A59E05A16A4B4032E5435035024B40354415FE0C674B40F451465C00FC4A40354415FE0C674B40
66815	24450	53.968761000000001	54.017251999999999	54.833038999999999	54.805084000000001	Первомайская	0103000020E61000000100000005000000F451465C00FC4A40354415FE0C674B40F451465C00FC4A4072A59E05A16A4B4032E5435035024B4072A59E05A16A4B4032E5435035024B40354415FE0C674B40F451465C00FC4A40354415FE0C674B40
65057	48682	54.072876000000001	54.088911000000003	54.810481000000003	54.797918000000003	Школьная	0103000020E61000000100000005000000E754320054094B40E371512D22664B40E754320054094B40C38366D7BD674B4099A0866F610B4B40C38366D7BD674B4099A0866F610B4B40E371512D22664B40E754320054094B40E371512D22664B40
66758	23746	53.629781999999999	53.650533000000003	54.851905000000002	54.843294999999998	Клубная	0103000020E6100000010000000500000003CE52B29CD04A40AEF02E17F16B4B4003CE52B29CD04A40422619390B6D4B4001FC53AA44D34A40422619390B6D4B4001FC53AA44D34A40AEF02E17F16B4B4003CE52B29CD04A40AEF02E17F16B4B40
64271	24334	53.891677000000001	53.919092999999997	54.776586000000002	54.754854000000002	Школьная	0103000020E6100000010000000500000036CCD07822F24A409DA04D0E9F604B4036CCD07822F24A400744882B67634B40C37DE4D6A4F54A400744882B67634B40C37DE4D6A4F54A409DA04D0E9F604B4036CCD07822F24A409DA04D0E9F604B40
66161	47151	54.112788000000002	54.131732999999997	54.849069	54.842055000000002	Шоссейная	0103000020E61000000100000005000000CDB051D66F0E4B4076374F75C86B4B40CDB051D66F0E4B401286014BAE6C4B40E8667FA0DC104B401286014BAE6C4B40E8667FA0DC104B4076374F75C86B4B40CDB051D66F0E4B4076374F75C86B4B40
64668	23590	54.297266	54.309438	54.981515000000002	54.976461999999998	Возрождения	0103000020E610000001000000050000003B1BF2CF0C264B40B4E4F1B4FC7C4B403B1BF2CF0C264B4048C49448A27D4B40E01115AA9B274B4048C49448A27D4B40E01115AA9B274B40B4E4F1B4FC7C4B403B1BF2CF0C264B40B4E4F1B4FC7C4B40
64906	47872	54.031320000000001	54.055799	54.767398999999997	54.757570999999999	Школьная	0103000020E61000000100000005000000F9DA334B02044B40F2B22616F8604B40F9DA334B02044B40D6FD63213A624B402313F06B24074B40D6FD63213A624B402313F06B24074B40F2B22616F8604B40F9DA334B02044B40F2B22616F8604B40
66219	23676	54.268906000000001	54.286855000000003	55.030853999999998	55.019516000000003	Центральная	0103000020E610000001000000050000005ED905836B224B40D7DF12807F824B405ED905836B224B40B3791C06F3834B40D8D825AAB7244B40B3791C06F3834B40D8D825AAB7244B40D7DF12807F824B405ED905836B224B40D7DF12807F824B40
65735	24234	54.020997999999999	54.046788999999997	54.882472999999997	54.870491999999999	Центральная	0103000020E6100000010000000500000005A4FD0FB0024B40FEB627486C6F4B4005A4FD0FB0024B402F4D11E0F4704B400168942EFD054B402F4D11E0F4704B400168942EFD054B40FEB627486C6F4B4005A4FD0FB0024B40FEB627486C6F4B40
66387	47489	54.203437000000001	54.213093999999998	55.001787999999998	54.994517000000002	Школьная	0103000020E61000000100000005000000EFE53E390A1A4B40742843554C7F4B40EFE53E390A1A4B403BC3D4963A804B40A67C08AA461B4B403BC3D4963A804B40A67C08AA461B4B40742843554C7F4B40EFE53E390A1A4B40742843554C7F4B40
65730	24213	54.024042999999999	54.041632	54.999778999999997	54.990637999999997	Центральная	0103000020E610000001000000050000004F594DD713034B406116DA39CD7E4B404F594DD713034B40211D1EC2F87F4B40C93B873254054B40211D1EC2F87F4B40C93B873254054B406116DA39CD7E4B404F594DD713034B406116DA39CD7E4B40
65426	46401	54.333432000000002	54.344642999999998	54.923547999999997	54.916367000000001	30 лет Победы	0103000020E610000001000000050000004EB857E6AD2A4B401B118C834B754B404EB857E6AD2A4B40A22424D236764B40CDE506431D2C4B40A22424D236764B40CDE506431D2C4B401B118C834B754B404EB857E6AD2A4B401B118C834B754B40
66533	58827	53.931821999999997	53.958950999999999	54.97701	54.965378000000001	 Школьная	0103000020E61000000100000005000000BED87BF145F74A4092239D81917B4B40BED87BF145F74A40B7EEE6A90E7D4B40B6BB07E8BEFA4A40B7EEE6A90E7D4B40B6BB07E8BEFA4A4092239D81917B4B40BED87BF145F74A4092239D81917B4B40
65538	23953	54.192647999999998	54.227978999999998	54.796526999999998	54.777464000000002	Центральная	0103000020E61000000100000005000000E5D18DB0A8184B409FE8BAF083634B40E5D18DB0A8184B40C4B0C398F4654B405F96766A2E1D4B40C4B0C398F4654B405F96766A2E1D4B409FE8BAF083634B40E5D18DB0A8184B409FE8BAF083634B40
65273	23464	54.178984999999997	54.209069	54.957768999999999	54.951073999999998	Центральная	0103000020E61000000100000005000000BEBC00FBE8164B40B709F7CABC794B40BEBC00FBE8164B40B20FB22C987A4B40C0CDE2C5C21A4B40B20FB22C987A4B40C0CDE2C5C21A4B40B709F7CABC794B40BEBC00FBE8164B40B709F7CABC794B40
66870	23900	53.737938999999997	53.751944000000002	54.975476	54.959842000000002	Центральная	0103000020E61000000100000005000000B2B8FFC874DE4A40E3A9471ADC7A4B40B2B8FFC874DE4A403604C765DC7C4B40333674B33FE04A403604C765DC7C4B40333674B33FE04A40E3A9471ADC7A4B40B2B8FFC874DE4A40E3A9471ADC7A4B40
66158	22755	54.171303999999999	54.193043000000003	54.891095	54.878867999999997	Центральная	0103000020E6100000010000000500000045D61A4AED154B401EC022BF7E704B4045D61A4AED154B408750A5660F724B4062DC0DA2B5184B408750A5660F724B4062DC0DA2B5184B401EC022BF7E704B4045D61A4AED154B401EC022BF7E704B40
65747	22755	54.171303999999999	54.193043000000003	54.891095	54.878867999999997	Октябрьская	0103000020E6100000010000000500000045D61A4AED154B401EC022BF7E704B4045D61A4AED154B408750A5660F724B4062DC0DA2B5184B408750A5660F724B4062DC0DA2B5184B401EC022BF7E704B4045D61A4AED154B401EC022BF7E704B40
65626	24460	54.063426	54.074044000000001	54.977469999999997	54.972261000000003	Школьная	0103000020E61000000100000005000000A9DBD9571E084B409016670C737C4B40A9DBD9571E084B401A69A9BC1D7D4B40863B17467A094B401A69A9BC1D7D4B40863B17467A094B409016670C737C4B40A9DBD9571E084B409016670C737C4B40
64058	23832	53.734524999999998	53.769666999999998	54.939081999999999	54.918514000000002	Победы	0103000020E61000000100000005000000158C4AEA04DE4A408675E3DD91754B40158C4AEA04DE4A409221C7D633784B40BCE7C07284E24A409221C7D633784B40BCE7C07284E24A408675E3DD91754B40158C4AEA04DE4A408675E3DD91754B40
64154	23729	53.644694000000001	53.687283000000001	54.847203	54.824202	Центральная	0103000020E61000000100000005000000B6F63E5585D24A401EA67D737F694B40B6F63E5585D24A405B09DD25716C4B40630CACE3F8D74A405B09DD25716C4B40630CACE3F8D74A401EA67D737F694B40B6F63E5585D24A401EA67D737F694B40
66718	24648	53.956184999999998	53.983359	54.806553000000001	54.783414	Школьная	0103000020E610000001000000050000007FF6234564FA4A40419DF2E846644B407FF6234564FA4A40CFBEF2203D674B40179D2CB5DEFD4A40CFBEF2203D674B40179D2CB5DEFD4A40419DF2E846644B407FF6234564FA4A40419DF2E846644B40
66653	22818	54.078598	54.099259000000004	54.832500000000003	54.818765999999997	Центральная	0103000020E61000000100000005000000F8C3CF7F0F0A4B40D2890453CD684B40F8C3CF7F0F0A4B40C3F5285C8F6A4B40B66AD784B40C4B40C3F5285C8F6A4B40B66AD784B40C4B40D2890453CD684B40F8C3CF7F0F0A4B40D2890453CD684B40
66590	22818	54.078598	54.099259000000004	54.832500000000003	54.818765999999997	Кооперативная	0103000020E61000000100000005000000F8C3CF7F0F0A4B40D2890453CD684B40F8C3CF7F0F0A4B40C3F5285C8F6A4B40B66AD784B40C4B40C3F5285C8F6A4B40B66AD784B40C4B40D2890453CD684B40F8C3CF7F0F0A4B40D2890453CD684B40
65729	23280	53.757010000000001	53.800902000000001	54.899130999999997	54.881520000000002	Школьная	0103000020E610000001000000050000005B5F24B4E5E04A408D62B9A5D5704B405B5F24B4E5E04A40EEE87FB916734B4087A6ECF483E64A40EEE87FB916734B4087A6ECF483E64A408D62B9A5D5704B405B5F24B4E5E04A408D62B9A5D5704B40
66224	23811	53.673744999999997	53.701287999999998	54.893321999999998	54.881659999999997	Центральная	0103000020E61000000100000005000000F86BB2463DD64A407E18213CDA704B40F86BB2463DD64A400E66136058724B40E38920CEC3D94A400E66136058724B40E38920CEC3D94A407E18213CDA704B40F86BB2463DD64A407E18213CDA704B40
66453	58783	53.827806000000002	53.860514000000002	54.902703000000002	54.890427000000003	Цветочная	0103000020E610000001000000050000005FB7088CF5E94A40DA3C0E83F9714B405FB7088CF5E94A4024809BC58B734B4005E09F5225EE4A4024809BC58B734B4005E09F5225EE4A40DA3C0E83F9714B405FB7088CF5E94A40DA3C0E83F9714B40
64323	21410	53.750236999999998	53.784875999999997	54.860430000000001	54.838219000000002	Дружбы	0103000020E61000000100000005000000E49F19C407E04A4063F19BC24A6B4B40E49F19C407E04A40A73FFB91226E4B4028B517D176E44A40A73FFB91226E4B4028B517D176E44A4063F19BC24A6B4B40E49F19C407E04A4063F19BC24A6B4B40
66166	23097	53.746940000000002	53.764403000000001	54.769652999999998	54.755279999999999	Салиха Сабитова	0103000020E610000001000000050000008109DCBA9BDF4A4054A9D903AD604B408109DCBA9BDF4A40572250FD83624B406EFB1EF5D7E14A40572250FD83624B406EFB1EF5D7E14A4054A9D903AD604B408109DCBA9BDF4A4054A9D903AD604B40
64669	24052	54.206626	54.247247999999999	54.829030000000003	54.814174999999999	Шадт Булата	0103000020E610000001000000050000006C4084B8721A4B40431CEBE236684B406C4084B8721A4B4092B3B0A71D6A4B402E008DD2A51F4B4092B3B0A71D6A4B402E008DD2A51F4B40431CEBE236684B406C4084B8721A4B40431CEBE236684B40
66223	23990	54.227592999999999	54.241003999999997	54.760277000000002	54.741061999999999	Мухаметьянова	0103000020E6100000010000000500000036E675C4211D4B4078279F1EDB5E4B4036E675C4211D4B405473B9C150614B40431A1538D91E4B405473B9C150614B40431A1538D91E4B4078279F1EDB5E4B4036E675C4211D4B4078279F1EDB5E4B40
65203	23012	53.914009	53.936726999999998	54.854823000000003	54.840255999999997	Полевая	0103000020E61000000100000005000000F59F353FFEF44A40462234828D6B4B40F59F353FFEF44A402F6F0ED76A6D4B40DD239BABE6F74A402F6F0ED76A6D4B40DD239BABE6F74A40462234828D6B4B40F59F353FFEF44A40462234828D6B4B40
65653	14451	54.128202999999999	54.141641999999997	54.855932000000003	54.850566999999998	Центральная	0103000020E61000000100000005000000E21FB6F468104B4046072461DF6C4B40E21FB6F468104B40C9CC052E8F6D4B40B9DE365321124B40C9CC052E8F6D4B40B9DE365321124B4046072461DF6C4B40E21FB6F468104B4046072461DF6C4B40
65262	22936	54.069623999999997	54.090285000000002	54.733832	54.715873000000002	Школьная	0103000020E6100000010000000500000023827170E9084B40728BF9B9A15B4B4023827170E9084B400F61FC34EE5D4B40E12879758E0B4B400F61FC34EE5D4B40E12879758E0B4B40728BF9B9A15B4B4023827170E9084B40728BF9B9A15B4B40
66288	24134	53.840446	53.874079000000002	54.988318999999997	54.970286999999999	Центральная	0103000020E61000000100000005000000EA060ABC93EB4A40F25D4A5D327C4B40EA060ABC93EB4A40F981AB3C817E4B40698F17D2E1EF4A40F981AB3C817E4B40698F17D2E1EF4A40F25D4A5D327C4B40EA060ABC93EB4A40F25D4A5D327C4B40
66157	23347	53.812390999999998	53.835800999999996	54.846322000000001	54.834522	Речная	0103000020E610000001000000050000004948A46DFCE74A4071E5EC9DD16A4B404948A46DFCE74A4052F17F47546C4B40677BF486FBEA4A4052F17F47546C4B40677BF486FBEA4A4071E5EC9DD16A4B404948A46DFCE74A4071E5EC9DD16A4B40
65258	22703	54.174134000000002	54.208511999999999	54.873243000000002	54.850499999999997	Центральная	0103000020E61000000100000005000000938FDD054A164B40BE9F1A2FDD6C4B40938FDD054A164B40003B376DC66F4B406A696E85B01A4B40003B376DC66F4B406A696E85B01A4B40BE9F1A2FDD6C4B40938FDD054A164B40BE9F1A2FDD6C4B40
66373	58758	55.577041999999999	55.594414999999998	54.641722000000001	54.633104000000003	Нагорная	0103000020E610000001000000050000008F352383DCC94B40C07B478D09514B408F352383DCC94B40D68F4DF223524B403CA06CCA15CC4B40D68F4DF223524B403CA06CCA15CC4B40C07B478D09514B408F352383DCC94B40C07B478D09514B40
65260	22095	55.260170000000002	55.275539999999999	54.405729999999998	54.389330000000001	Западная	0103000020E610000001000000050000003EB324404DA14B4004ADC090D5314B403EB324404DA14B40C780ECF5EE334B40B35E0CE544A34B40C780ECF5EE334B40B35E0CE544A34B4004ADC090D5314B403EB324404DA14B4004ADC090D5314B40
64437	22131	55.195860000000003	55.224148	54.398440000000001	54.373629999999999	Школьная	0103000020E610000001000000050000001B4CC3F011994B40F9669B1BD32F4B401B4CC3F011994B4089B5F81400334B405EBBB4E1B09C4B4089B5F81400334B405EBBB4E1B09C4B40F9669B1BD32F4B401B4CC3F011994B40F9669B1BD32F4B40
63578	22131	55.195860000000003	55.224148	54.398440000000001	54.373629999999999	Малокольцевая	0103000020E610000001000000050000001B4CC3F011994B40F9669B1BD32F4B401B4CC3F011994B4089B5F81400334B405EBBB4E1B09C4B4089B5F81400334B405EBBB4E1B09C4B40F9669B1BD32F4B401B4CC3F011994B40F9669B1BD32F4B40
66621	5640	55.407924999999999	55.443021999999999	54.379105000000003	54.360731999999999	Центральная	0103000020E61000000100000005000000431CEBE236B44B40724F57772C2E4B40431CEBE236B44B4003603C8386304B404AB4E4F1B4B84B4003603C8386304B404AB4E4F1B4B84B40724F57772C2E4B40431CEBE236B44B40724F57772C2E4B40
63477	21689	55.320303000000003	55.387300000000003	54.582236000000002	54.563484000000003	Революционная	0103000020E61000000100000005000000C5E74EB0FFA84B40DEE8633E20484B40C5E74EB0FFA84B40E54691B5864A4B40D3DEE00B93B14B40E54691B5864A4B40D3DEE00B93B14B40DEE8633E20484B40C5E74EB0FFA84B40DEE8633E20484B40
63501	21689	55.320303000000003	55.387300000000003	54.582236000000002	54.563484000000003	Парковая	0103000020E61000000100000005000000C5E74EB0FFA84B40DEE8633E20484B40C5E74EB0FFA84B40E54691B5864A4B40D3DEE00B93B14B40E54691B5864A4B40D3DEE00B93B14B40DEE8633E20484B40C5E74EB0FFA84B40DEE8633E20484B40
63688	21689	55.320303000000003	55.387300000000003	54.582236000000002	54.563484000000003	Ленина	0103000020E61000000100000005000000C5E74EB0FFA84B40DEE8633E20484B40C5E74EB0FFA84B40E54691B5864A4B40D3DEE00B93B14B40E54691B5864A4B40D3DEE00B93B14B40DEE8633E20484B40C5E74EB0FFA84B40DEE8633E20484B40
63234	21689	55.320303000000003	55.387300000000003	54.582236000000002	54.563484000000003	Кирова	0103000020E61000000100000005000000C5E74EB0FFA84B40DEE8633E20484B40C5E74EB0FFA84B40E54691B5864A4B40D3DEE00B93B14B40E54691B5864A4B40D3DEE00B93B14B40DEE8633E20484B40C5E74EB0FFA84B40DEE8633E20484B40
64545	46624	55.353963	55.432296000000001	54.602151999999997	54.580027999999999	Элеваторная	0103000020E610000001000000050000003D7FDAA84EAD4B40D461855B3E4A4B403D7FDAA84EAD4B40499C1551134D4B408718AF7955B74B40499C1551134D4B408718AF7955B74B40D461855B3E4A4B403D7FDAA84EAD4B40D461855B3E4A4B40
63462	46624	55.353963	55.432296000000001	54.602151999999997	54.580027999999999	Садовая	0103000020E610000001000000050000003D7FDAA84EAD4B40D461855B3E4A4B403D7FDAA84EAD4B40499C1551134D4B408718AF7955B74B40499C1551134D4B408718AF7955B74B40D461855B3E4A4B403D7FDAA84EAD4B40D461855B3E4A4B40
64291	46624	55.353963	55.432296000000001	54.602151999999997	54.580027999999999	Промышленная	0103000020E610000001000000050000003D7FDAA84EAD4B40D461855B3E4A4B403D7FDAA84EAD4B40499C1551134D4B408718AF7955B74B40499C1551134D4B408718AF7955B74B40D461855B3E4A4B403D7FDAA84EAD4B40D461855B3E4A4B40
64571	46624	55.353963	55.432296000000001	54.602151999999997	54.580027999999999	Нагорная	0103000020E610000001000000050000003D7FDAA84EAD4B40D461855B3E4A4B403D7FDAA84EAD4B40499C1551134D4B408718AF7955B74B40499C1551134D4B408718AF7955B74B40D461855B3E4A4B403D7FDAA84EAD4B40D461855B3E4A4B40
63350	46624	55.353963	55.432296000000001	54.602151999999997	54.580027999999999	Мира	0103000020E610000001000000050000003D7FDAA84EAD4B40D461855B3E4A4B403D7FDAA84EAD4B40499C1551134D4B408718AF7955B74B40499C1551134D4B408718AF7955B74B40D461855B3E4A4B403D7FDAA84EAD4B40D461855B3E4A4B40
63340	46624	55.353963	55.432296000000001	54.602151999999997	54.580027999999999	Колхозная	0103000020E610000001000000050000003D7FDAA84EAD4B40D461855B3E4A4B403D7FDAA84EAD4B40499C1551134D4B408718AF7955B74B40499C1551134D4B408718AF7955B74B40D461855B3E4A4B403D7FDAA84EAD4B40D461855B3E4A4B40
65202	20134	55.461635000000001	55.491405	54.690731	54.677438000000002	Школьная	0103000020E6100000010000000500000030D80DDB16BB4B40A988D349B6564B4030D80DDB16BB4B40ACAA97DF69584B40A20BEA5BE6BE4B40ACAA97DF69584B40A20BEA5BE6BE4B40A988D349B6564B4030D80DDB16BB4B40A988D349B6564B40
64726	58330	54.891421000000001	55.784993	54.828071000000001	54.317405999999998	Центральная	0103000020E61000000100000005000000DBFB54151A724B40EFC682C2A0284B40DBFB54151A724B400DE2033BFE694B40624B8FA67AE44B400DE2033BFE694B40624B8FA67AE44B40EFC682C2A0284B40DBFB54151A724B40EFC682C2A0284B40
65250	21934	55.381326000000001	55.413592999999999	54.331457	54.317405999999998	Школьная	0103000020E61000000100000005000000A88E554ACFB04B40EFC682C2A0284B40A88E554ACFB04B40E083D72E6D2A4B40616D8C9DF0B44B40E083D72E6D2A4B40616D8C9DF0B44B40EFC682C2A0284B40A88E554ACFB04B40EFC682C2A0284B40
66831	1831	55.495294999999999	55.528551	54.395746000000003	54.379880999999997	Центральная	0103000020E61000000100000005000000A86F99D365BF4B4096AFCBF09F304B40A86F99D365BF4B40ECC20FCEA7324B4051A2258FA7C34B40ECC20FCEA7324B4051A2258FA7C34B4096AFCBF09F304B40A86F99D365BF4B4096AFCBF09F304B40
63802	10303	55.196767000000001	55.240972999999997	54.563122999999997	54.550431000000003	Центральная	0103000020E610000001000000050000004DF73AA92F994B4030DAE38574464B404DF73AA92F994B400D501A6A14484B40081C0934D89E4B400D501A6A14484B40081C0934D89E4B4030DAE38574464B404DF73AA92F994B4030DAE38574464B40
66048	58696	55.524895000000001	55.557772999999997	54.701324	54.685713999999997	Мира	0103000020E61000000100000005000000BE6A65C22FC34B406534F279C5574B40BE6A65C22FC34B4030F31DFCC4594B40C0CB0C1B65C74B4030F31DFCC4594B40C0CB0C1B65C74B406534F279C5574B40BE6A65C22FC34B406534F279C5574B40
65531	58560	55.616568000000001	55.643723999999999	54.507185999999997	54.493367999999997	 пер.Школьный	0103000020E610000001000000050000004CE141B3EBCE4B404B72C0AE263F4B404CE141B3EBCE4B40997E8978EB404B403DD34B8C65D24B40997E8978EB404B403DD34B8C65D24B404B72C0AE263F4B404CE141B3EBCE4B404B72C0AE263F4B40
65574	21986	55.248249000000001	55.268462	54.454720999999999	54.446131000000001	Шоссейная	0103000020E61000000100000005000000E2218C9FC69F4B40AB5D13D21A394B40E2218C9FC69F4B40F7E6374C343A4B40001C7BF65CA24B40F7E6374C343A4B40001C7BF65CA24B40AB5D13D21A394B40E2218C9FC69F4B40AB5D13D21A394B40
66451	46652	55.511636000000003	55.538440999999999	54.482624999999999	54.467846000000002	Центральная	0103000020E6100000010000000500000067BAD7497DC14B403FC8B260E23B4B4067BAD7497DC14B40B29DEFA7C63D4B40ABE97AA2EBC44B40B29DEFA7C63D4B40ABE97AA2EBC44B403FC8B260E23B4B4067BAD7497DC14B403FC8B260E23B4B40
66475	58793	55.241970000000002	55.275388	54.598089000000002	54.589649000000001	 Центральная	0103000020E610000001000000050000007B4E7ADFF89E4B403F8F519E794B4B407B4E7ADFF89E4B40768C2B2E8E4C4B40FDDAFAE93FA34B40768C2B2E8E4C4B40FDDAFAE93FA34B403F8F519E794B4B407B4E7ADFF89E4B403F8F519E794B4B40
65053	20324	55.640830999999999	55.668266000000003	54.563243999999997	54.549641999999999	Мустая Карима	0103000020E61000000100000005000000A9A10DC006D24B40074147AB5A464B40A9A10DC006D24B4088D51F6118484B40AE8383BD89D54B4088D51F6118484B40AE8383BD89D54B40074147AB5A464B40A9A10DC006D24B40074147AB5A464B40
66777	19338	55.141736000000002	55.158031999999999	54.560853000000002	54.554519999999997	Школьная	0103000020E610000001000000050000003B55BE6724924B402C7DE882FA464B403B55BE6724924B40876EF607CA474B4059DC7F643A944B40876EF607CA474B4059DC7F643A944B402C7DE882FA464B403B55BE6724924B402C7DE882FA464B40
64439	21320	55.462516000000001	55.476582999999998	54.566271	54.552796000000001	Центральная	0103000020E6100000010000000500000039F06AB933BB4B4008AEF204C2464B4039F06AB933BB4B402CD670917B484B402F6AF7AB00BD4B402CD670917B484B402F6AF7AB00BD4B4008AEF204C2464B4039F06AB933BB4B4008AEF204C2464B40
64424	20990	55.200296999999999	55.24409	54.663760000000003	54.647948	Школьная	0103000020E61000000100000005000000533E0455A3994B401AC1C6F5EF524B40533E0455A3994B404D327216F6544B40ECA353573E9F4B404D327216F6544B40ECA353573E9F4B401AC1C6F5EF524B40533E0455A3994B401AC1C6F5EF524B40
64468	58237	55.315398999999999	55.327615999999999	54.531407999999999	54.517817000000001	Центральная	0103000020E61000000100000005000000761893FE5EA84B400B28D4D347424B40761893FE5EA84B40986A662D05444B40BBD23252EFA94B40986A662D05444B40BBD23252EFA94B400B28D4D347424B40761893FE5EA84B400B28D4D347424B40
65508	21143	55.588576000000003	55.620007999999999	54.404089999999997	54.392589999999998	Молодежная	0103000020E61000000100000005000000F29A577556CB4B404A5E9D6340324B40F29A577556CB4B4000529B38B9334B4012A1116C5CCF4B4000529B38B9334B4012A1116C5CCF4B404A5E9D6340324B40F29A577556CB4B404A5E9D6340324B40
64899	46167	55.284613	55.294513000000002	54.432003000000002	54.416733999999998	Центральная	0103000020E610000001000000050000001B82E3326EA44B40CD902A8A57354B401B82E3326EA44B400F63D2DF4B374B40999F1B9AB2A54B400F63D2DF4B374B40999F1B9AB2A54B40CD902A8A57354B401B82E3326EA44B40CD902A8A57354B40
64763	22029	55.332008000000002	55.347208000000002	54.775958000000003	54.754925999999998	Старая Деревня	0103000020E610000001000000050000005401F73C7FAA4B403673486AA1604B405401F73C7FAA4B40E8887C9752634B406D74CE4F71AC4B40E8887C9752634B406D74CE4F71AC4B403673486AA1604B405401F73C7FAA4B403673486AA1604B40
66735	22029	55.332008000000002	55.347208000000002	54.775958000000003	54.754925999999998	Мира	0103000020E610000001000000050000005401F73C7FAA4B403673486AA1604B405401F73C7FAA4B40E8887C9752634B406D74CE4F71AC4B40E8887C9752634B406D74CE4F71AC4B403673486AA1604B405401F73C7FAA4B403673486AA1604B40
65218	58497	55.427311000000003	55.444001	54.547955999999999	54.539484000000002	Молодежная	0103000020E610000001000000050000004C1C7920B2B64B408E5BCCCF0D454B404C1C7920B2B64B40D0D2156C23464B4016325706D5B84B40D0D2156C23464B4016325706D5B84B408E5BCCCF0D454B404C1C7920B2B64B408E5BCCCF0D454B40
66349	58747	55.688423999999998	55.703201	54.416949000000002	54.408423999999997	Центральная	0103000020E6100000010000000500000008E412471ED84B406473D53C47344B4008E412471ED84B40CA8CB7955E354B40DBC1887D02DA4B40CA8CB7955E354B40DBC1887D02DA4B406473D53C47344B4008E412471ED84B406473D53C47344B40
66537	58829	55.028655999999998	55.042040999999998	54.443696000000003	54.431967	 Школьная	0103000020E61000000100000005000000C66AF3FFAA834B40C2F9D4B14A374B40C66AF3FFAA834B40DAAED007CB384B40AA0B789961854B40DAAED007CB384B40AA0B789961854B40C2F9D4B14A374B40C66AF3FFAA834B40C2F9D4B14A374B40
64786	21045	55.167634999999997	55.200755999999998	54.610151999999999	54.600237999999997	Центральная	0103000020E610000001000000050000001D554D1075954B4081E84999D44C4B401D554D1075954B4064CBF275194E4B40E63C635FB2994B4064CBF275194E4B40E63C635FB2994B4081E84999D44C4B401D554D1075954B4081E84999D44C4B40
65051	20735	55.360852999999999	55.372872999999998	54.385272000000001	54.378444999999999	Шоссейная	0103000020E61000000100000005000000EDD45C6E30AE4B40D82AC1E270304B40EDD45C6E30AE4B404208C89750314B40DC476E4DBAAF4B404208C89750314B40DC476E4DBAAF4B40D82AC1E270304B40EDD45C6E30AE4B40D82AC1E270304B40
65074	20546	55.256137000000003	55.276133000000002	54.786425000000001	54.773111999999998	Новая	0103000020E61000000100000005000000D525E318C9A04B4094128255F5624B40D525E318C9A04B40DFE00B93A9644B40562C7E5358A34B40DFE00B93A9644B40562C7E5358A34B4094128255F5624B40D525E318C9A04B4094128255F5624B40
64895	21507	55.583841999999997	55.607908000000002	54.488163999999998	54.473246000000003	Центральная	0103000020E61000000100000005000000FF03AC55BBCA4B403E7B2E53933C4B40FF03AC55BBCA4B40D28A6F287C3E4B40077DE9EDCFCD4B40D28A6F287C3E4B40077DE9EDCFCD4B403E7B2E53933C4B40FF03AC55BBCA4B403E7B2E53933C4B40
65510	20854	55.736671999999999	55.751880999999997	54.448565000000002	54.438329000000003	Молодежная	0103000020E6100000010000000500000080F0A1444BDE4B40B7F1272A1B384B4080F0A1444BDE4B40AC90F2936A394B40ECBDF8A23DE04B40AC90F2936A394B40ECBDF8A23DE04B40B7F1272A1B384B4080F0A1444BDE4B40B7F1272A1B384B40
64679	20406	55.394979999999997	55.430643000000003	54.687192000000003	54.670586999999998	Центральная	0103000020E610000001000000050000007B4963B48EB24B40B60F79CBD5554B407B4963B48EB24B4053094FE8F5574B402CA0504F1FB74B4053094FE8F5574B402CA0504F1FB74B40B60F79CBD5554B407B4963B48EB24B40B60F79CBD5554B40
64139	20244	55.573205999999999	55.600999999999999	54.575983999999998	54.560727	Центральная	0103000020E610000001000000050000007CEF6FD05EC94B40FA7DFFE6C5474B407CEF6FD05EC94B407782FDD7B9494B40B0726891EDCC4B407782FDD7B9494B40B0726891EDCC4B40FA7DFFE6C5474B407CEF6FD05EC94B40FA7DFFE6C5474B40
65509	20764	55.279870000000003	55.292670999999999	54.343798	54.332486000000003	Демская	0103000020E61000000100000005000000D690B8C7D2A34B405E30B8E68E2A4B40D690B8C7D2A34B401137A792012C4B406ABE4A3E76A54B401137A792012C4B406ABE4A3E76A54B405E30B8E68E2A4B40D690B8C7D2A34B405E30B8E68E2A4B40
64045	58156	55.547308000000001	55.610163	54.666514999999997	54.637417999999997	Школьный переулок	0103000020E610000001000000050000006A6B44300EC64B40DCF0BBE996514B406A6B44300EC64B408FA50F5D50554B40581D39D219CE4B408FA50F5D50554B40581D39D219CE4B40DCF0BBE996514B406A6B44300EC64B40DCF0BBE996514B40
66104	21841	55.451411999999998	55.474679000000002	54.402963	54.387877000000003	Центральная	0103000020E61000000100000005000000CF8250DEC7B94B4070EF1AF4A5314B40CF8250DEC7B94B40C03FA54A94334B408B8C0E48C2BC4B40C03FA54A94334B408B8C0E48C2BC4B4070EF1AF4A5314B40CF8250DEC7B94B4070EF1AF4A5314B40
66680	18345	54.397446000000002	54.436639999999997	55.007876000000003	54.991334999999999	Советская	0103000020E6100000010000000500000088F6B182DF324B40A930B610E47E4B4088F6B182DF324B402F36AD1402814B400E10CCD1E3374B402F36AD1402814B400E10CCD1E3374B40A930B610E47E4B4088F6B182DF324B40A930B610E47E4B40
64004	17073	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	Тракторная	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
64145	17073	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	Мира	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
63786	17073	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	Ленина	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
64008	17073	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	Кооперативная	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
64272	17073	54.624226	54.684187999999999	55.162474000000003	55.124146000000003	Западная	0103000020E610000001000000050000000DA837A3E64F4B40F1F62004E48F4B400DA837A3E64F4B40A439B2F2CB944B406728EE7893574B40A439B2F2CB944B406728EE7893574B40F1F62004E48F4B400DA837A3E64F4B40F1F62004E48F4B40
66887	19245	54.747033999999999	54.791375000000002	55.045692000000003	55.023263	Советская	0103000020E61000000100000005000000028063CF9E5F4B407A1A3048FA824B40028063CF9E5F4B402CD8463CD9854B409EEFA7C64B654B402CD8463CD9854B409EEFA7C64B654B407A1A3048FA824B40028063CF9E5F4B407A1A3048FA824B40
64662	18361	54.410651000000001	54.447617000000001	54.975557999999999	54.957039999999999	Кутуева	0103000020E61000000100000005000000EC88433690344B405F7B6649807A4B40EC88433690344B40F3ACA415DF7C4B401B118C834B394B40F3ACA415DF7C4B401B118C834B394B405F7B6649807A4B40EC88433690344B405F7B6649807A4B40
66632	58864	54.398246	54.419508999999998	55.182968000000002	55.169317999999997	Центральная	0103000020E61000000100000005000000A4E194B9F9324B40E34F5436AC954B40A4E194B9F9324B40761BD47E6B974B4057B08D78B2354B40761BD47E6B974B4057B08D78B2354B40E34F5436AC954B40A4E194B9F9324B40E34F5436AC954B40
65731	58613	54.481501000000002	54.495362	55.148435999999997	55.142169000000003	Салавата	0103000020E61000000100000005000000E3FE23D3A13D4B40A5C0029832924B40E3FE23D3A13D4B4047C66AF3FF924B4030D7A205683F4B4047C66AF3FF924B4030D7A205683F4B40A5C0029832924B40E3FE23D3A13D4B40A5C0029832924B40
65540	19537	54.806341000000003	54.843755999999999	55.213849000000003	55.199711999999998	Центральная	0103000020E610000001000000050000004436902E36674B40334FAE2990994B404436902E36674B4023A46E675F9B4B40E2E65432006C4B4023A46E675F9B4B40E2E65432006C4B40334FAE2990994B404436902E36674B40334FAE2990994B40
65714	19082	54.944906000000003	54.979365999999999	55.130147999999998	55.119013000000002	Молодежная	0103000020E61000000100000005000000A8E507AEF2784B40416667D13B8F4B40A8E507AEF2784B40E5D18DB0A8904B403C6876DD5B7D4B40E5D18DB0A8904B403C6876DD5B7D4B40416667D13B8F4B40A8E507AEF2784B40416667D13B8F4B40
65728	19918	54.530971999999998	54.567397999999997	55.245860999999998	55.233172000000003	Центральная	0103000020E61000000100000005000000BD8BF7E3F6434B40E52B8194D89D4B40BD8BF7E3F6434B40512E8D5F789F4B406CE8667FA0484B40512E8D5F789F4B406CE8667FA0484B40E52B8194D89D4B40BD8BF7E3F6434B40E52B8194D89D4B40
64138	19604	54.739201000000001	54.768045999999998	55.219611999999998	55.205779	Хузиных	0103000020E61000000100000005000000D3156C239E5E4B400F9A5DF7569A4B40D3156C239E5E4B4092E7FA3E1C9C4B406CE9D1544F624B4092E7FA3E1C9C4B406CE9D1544F624B400F9A5DF7569A4B40D3156C239E5E4B400F9A5DF7569A4B40
66620	18178	54.248379999999997	54.283782000000002	55.072313999999999	55.050189000000003	Гагарина	0103000020E61000000100000005000000807D74EACA1F4B403ACFD8976C864B40807D74EACA1F4B407F85CC9541894B40C498F4F752244B407F85CC9541894B40C498F4F752244B403ACFD8976C864B40807D74EACA1F4B403ACFD8976C864B40
65092	18275	54.460957000000001	54.477890000000002	54.999231999999999	54.985084999999998	Ш.Салихова	0103000020E610000001000000050000005FEE93A3003B4B40DC63E943177E4B405FEE93A3003B4B40EF8E8CD5E67F4B40F08AE07F2B3D4B40EF8E8CD5E67F4B40F08AE07F2B3D4B40DC63E943177E4B405FEE93A3003B4B40DC63E943177E4B40
66756	1997	54.791178000000002	54.859107999999999	55.134157000000002	55.114280999999998	Нефтяников	0103000020E6100000010000000500000048A8195245654B40EFC682C2A08E4B4048A8195245654B40C6C37B0E2C914B40B1DD3D40F76D4B40C6C37B0E2C914B40B1DD3D40F76D4B40EFC682C2A08E4B4048A8195245654B40EFC682C2A08E4B40
64052	1997	54.791178000000002	54.859107999999999	55.134157000000002	55.114280999999998	Мира	0103000020E6100000010000000500000048A8195245654B40EFC682C2A08E4B4048A8195245654B40C6C37B0E2C914B40B1DD3D40F76D4B40C6C37B0E2C914B40B1DD3D40F76D4B40EFC682C2A08E4B4048A8195245654B40EFC682C2A08E4B40
65708	18708	54.564298999999998	54.599944000000001	55.031447999999997	55.019021000000002	 Мира	0103000020E610000001000000050000002F151BF33A484B40F777B6476F824B402F151BF33A484B4026C3F17C06844B4039B709F7CA4C4B4026C3F17C06844B4039B709F7CA4C4B40F777B6476F824B402F151BF33A484B40F777B6476F824B40
65703	18002	54.349350000000001	54.380611999999999	55.176645000000001	55.161399000000003	В.Галимова	0103000020E61000000100000005000000C66D3480B72C4B40B64DF1B8A8944B40C66D3480B72C4B403F00A94D9C964B408A3BDEE4B7304B403F00A94D9C964B408A3BDEE4B7304B40B64DF1B8A8944B40C66D3480B72C4B40B64DF1B8A8944B40
64320	18089	54.271034999999998	54.315089	55.104337000000001	55.090639000000003	Центральная	0103000020E6100000010000000500000022895E46B1224B40FF5E0A0F9A8B4B4022895E46B1224B40A26131EA5A8D4B40282A1BD654284B40A26131EA5A8D4B40282A1BD654284B40FF5E0A0F9A8B4B4022895E46B1224B40FF5E0A0F9A8B4B40
66916	1440	54.587197000000003	54.628484	55.074139000000002	55.056553000000001	Ленина	0103000020E6100000010000000500000098A77345294B4B40CFBEF2203D874B4098A77345294B4B40D82D02637D894B409607E92972504B40D82D02637D894B409607E92972504B40CFBEF2203D874B4098A77345294B4B40CFBEF2203D874B40
66659	17831	54.343736	54.37321	55.050721000000003	55.038687000000003	Школьная	0103000020E610000001000000050000009B3A8F8AFF2B4B40E3E313B2F3844B409B3A8F8AFF2B4B40371C96067E864B4024456458C52F4B40371C96067E864B4024456458C52F4B40E3E313B2F3844B409B3A8F8AFF2B4B40E3E313B2F3844B40
66794	17831	54.343736	54.37321	55.050721000000003	55.038687000000003	Центральная	0103000020E610000001000000050000009B3A8F8AFF2B4B40E3E313B2F3844B409B3A8F8AFF2B4B40371C96067E864B4024456458C52F4B40371C96067E864B4024456458C52F4B40E3E313B2F3844B409B3A8F8AFF2B4B40E3E313B2F3844B40
64791	58350	54.429031000000002	54.446198000000003	54.985787999999999	54.973211999999997	Свободы	0103000020E610000001000000050000002FFCE07CEA364B409109F835927C4B402FFCE07CEA364B4006651A4D2E7E4B4033C51C041D394B4006651A4D2E7E4B4033C51C041D394B409109F835927C4B402FFCE07CEA364B409109F835927C4B40
66797	2303	54.570174000000002	54.595649999999999	55.222836999999998	55.197363000000003	Центральная	0103000020E61000000100000005000000C7832D76FB484B406138D73043994B40C7832D76FB484B405CAB3DEC859C4B4063EE5A423E4C4B405CAB3DEC859C4B4063EE5A423E4C4B406138D73043994B40C7832D76FB484B406138D73043994B40
64860	19000	55.037405999999997	55.068092	55.129688999999999	55.117390999999998	С. Муратова	0103000020E610000001000000050000004B5645B8C9844B4020EC14AB068F4B404B5645B8C9844B4052D32EA699904B40438F183DB7884B4052D32EA699904B40438F183DB7884B4020EC14AB068F4B404B5645B8C9844B4020EC14AB068F4B40
66109	19173	54.914687000000001	55.045310999999998	55.079942000000003	55.061864	55 лет Победы	0103000020E61000000100000005000000C689AF7614754B405E66D828EB874B40C689AF7614754B40D6C9198A3B8A4B40149337C0CC854B40D6C9198A3B8A4B40149337C0CC854B405E66D828EB874B40C689AF7614754B405E66D828EB874B40
66097	18600	54.667327	54.685509000000003	55.070112999999999	55.061245	Дуслык	0103000020E61000000100000005000000705E9CF86A554B4092054CE0D6874B40705E9CF86A554B4021037976F9884B408D0E48C2BE574B4021037976F9884B408D0E48C2BE574B4092054CE0D6874B40705E9CF86A554B4092054CE0D6874B40
66666	17703	54.411189999999998	54.440125000000002	55.127023000000001	55.103023	Ленина	0103000020E610000001000000050000009B38B9DFA1344B402FDE8FDB2F8D4B409B38B9DFA1344B407F6B274A42904B407593180456384B407F6B274A42904B407593180456384B402FDE8FDB2F8D4B409B38B9DFA1344B402FDE8FDB2F8D4B40
65723	18138	54.250337999999999	54.279344999999999	55.139215999999998	55.129216	М. Дашкина	0103000020E61000000100000005000000187959130B204B405A0F5F268A904B40187959130B204B403B8A73D4D1914B408BA6B393C1234B403B8A73D4D1914B408BA6B393C1234B405A0F5F268A904B40187959130B204B405A0F5F268A904B40
65711	18878	54.917417999999998	54.947332000000003	55.188571000000003	55.177283000000003	Еникеева Рифката	0103000020E610000001000000050000008061F9F36D754B4082919735B1964B408061F9F36D754B40ADFC321823984B40263ACB2C42794B40ADFC321823984B40263ACB2C42794B4082919735B1964B408061F9F36D754B4082919735B1964B40
66092	49378	54.645021999999997	54.654463	55.176546999999999	55.167853000000001	Фабричная	0103000020E61000000100000005000000AA99B51490524B408BC404357C954B40AA99B51490524B407C9A931799964B4095B88E71C5534B407C9A931799964B4095B88E71C5534B408BC404357C954B40AA99B51490524B408BC404357C954B40
66843	18223	54.455494999999999	54.47833	55.036447000000003	55.013455999999998	Молодежная	0103000020E61000000100000005000000EA3E00A94D3A4B40ADF71BEDB8814B40EA3E00A94D3A4B40C784984BAA844B400C59DDEA393D4B40C784984BAA844B400C59DDEA393D4B40ADF71BEDB8814B40EA3E00A94D3A4B40ADF71BEDB8814B40
66094	49404	54.437627999999997	54.457605999999998	55.100735999999998	55.089243000000003	Кашаевых	0103000020E610000001000000050000002DE8BD3104384B40CF328B506C8B4B402DE8BD3104384B40D2C3D0EAE48C4B40083A5AD5923A4B40D2C3D0EAE48C4B40083A5AD5923A4B40CF328B506C8B4B402DE8BD3104384B40CF328B506C8B4B40
64665	18458	54.350842	54.367721000000003	54.953932999999999	54.946202999999997	Родниковая	0103000020E6100000010000000500000018080264E82C4B4044300E2E1D794B4018080264E82C4B409FC9FE791A7A4B40B686527B112F4B409FC9FE791A7A4B40B686527B112F4B4044300E2E1D794B4018080264E82C4B4044300E2E1D794B40
65699	47158	54.355387	54.379739999999998	55.133338999999999	55.120953999999998	Новая	0103000020E6100000010000000500000037363B527D2D4B400229B16B7B8F4B4037363B527D2D4B4003249A4011914B40D47D00529B304B4003249A4011914B40D47D00529B304B400229B16B7B8F4B4037363B527D2D4B400229B16B7B8F4B40
66842	19687	54.794421	54.814202000000002	55.298174000000003	55.282513000000002	Школьная	0103000020E61000000100000005000000B8205B96AF654B40F1D8CF6229A44B40B8205B96AF654B403E42CD902AA64B403D2B69C537684B403E42CD902AA64B403D2B69C537684B40F1D8CF6229A44B40B8205B96AF654B40F1D8CF6229A44B40
64304	18643	54.578626999999997	54.650734999999997	55.024765000000002	54.991356000000003	Центральная	0103000020E6100000010000000500000092CA1473104A4B40C158DFC0E47E4B4092CA1473104A4B40F08AE07F2B834B4068AED3484B534B40F08AE07F2B834B4068AED3484B534B40C158DFC0E47E4B4092CA1473104A4B40C158DFC0E47E4B40
66850	58878	54.535589000000002	54.55095	55.118529000000002	55.110984999999999	Центральная	0103000020E61000000100000005000000768C2B2E8E444B405CACA8C1348E4B40768C2B2E8E444B40555051F52B8F4B4098DD938785464B40555051F52B8F4B4098DD938785464B405CACA8C1348E4B40768C2B2E8E444B405CACA8C1348E4B40
66675	19755	54.639820999999998	54.673426999999997	55.291167000000002	55.276676999999999	Школьная	0103000020E61000000100000005000000A2258FA7E5514B401747E5266AA34B40A2258FA7E5514B405456D3F544A54B40279F1EDB32564B405456D3F544A54B40279F1EDB32564B401747E5266AA34B40A2258FA7E5514B401747E5266AA34B40
66633	19784	54.674576000000002	54.699576	55.338192999999997	55.316876999999998	Кр. Партизан	0103000020E610000001000000050000005055A18158564B4063EDEF6C8FA84B405055A18158564B40395E81E849AB4B408388D4B48B594B40395E81E849AB4B408388D4B48B594B4063EDEF6C8FA84B405055A18158564B4063EDEF6C8FA84B40
65216	19492	54.769159999999999	54.784171000000001	54.945283000000003	54.932890999999998	Первомайская	0103000020E6100000010000000500000018B2BAD573624B40CADDE7F868774B4018B2BAD573624B407E3B8908FF784B405EBC1FB75F644B407E3B8908FF784B405EBC1FB75F644B40CADDE7F868774B4018B2BAD573624B40CADDE7F868774B40
66100	18031	54.400033000000001	54.422373999999998	55.232104	55.218522999999998	Нур Гайсина	0103000020E610000001000000050000000F29064834334B403F36C98FF89B4B400F29064834334B40A9A27895B59D4B402157EA5910364B40A9A27895B59D4B402157EA5910364B403F36C98FF89B4B400F29064834334B403F36C98FF89B4B40
66929	4462	54.814300000000003	54.888807	54.997692999999998	54.962792999999998	Советская	0103000020E6100000010000000500000000917EFB3A684B40ABE80FCD3C7B4B4000917EFB3A684B405C397B67B47F4B405ABA826DC4714B405C397B67B47F4B405ABA826DC4714B40ABE80FCD3C7B4B4000917EFB3A684B40ABE80FCD3C7B4B40
65847	4462	54.814300000000003	54.888807	54.997692999999998	54.962792999999998	Профессора Кудоярова	0103000020E6100000010000000500000000917EFB3A684B40ABE80FCD3C7B4B4000917EFB3A684B405C397B67B47F4B405ABA826DC4714B405C397B67B47F4B405ABA826DC4714B40ABE80FCD3C7B4B4000917EFB3A684B40ABE80FCD3C7B4B40
66196	15126	57.708142000000002	57.747120000000002	51.895696000000001	51.881532999999997	Школьная	0103000020E610000001000000050000004776A565A4DA4C4021ACC612D6F049404776A565A4DA4C403A94A12AA6F249400118CFA0A1DF4C403A94A12AA6F249400118CFA0A1DF4C4021ACC612D6F049404776A565A4DA4C4021ACC612D6F04940
65233	58504	57.965131999999997	57.985847	52.004781999999999	51.993648	Ахметшина	0103000020E610000001000000050000005A29047289FB4C402FDE8FDB2FFF49405A29047289FB4C4003CE52B29C004A400BEE073C30FE4C4003CE52B29C004A400BEE073C30FE4C402FDE8FDB2FFF49405A29047289FB4C402FDE8FDB2FFF4940
65461	15879	57.990724999999998	58.003661000000001	52.06944	52.059823000000002	Вахитова	0103000020E61000000100000005000000302AA913D0FE4C403946B247A8074A40302AA913D0FE4C406284F068E3084A40A5A2B1F677004D406284F068E3084A40A5A2B1F677004D403946B247A8074A40302AA913D0FE4C403946B247A8074A40
64467	33038	58.643296999999997	58.658793000000003	52.241239999999998	52.229546999999997	Заки Валиди	0103000020E61000000100000005000000B54E5C8E57524D408CF2CCCB611D4A40B54E5C8E57524D40573ECBF3E01E4A40B8EA3A5453544D40573ECBF3E01E4A40B8EA3A5453544D408CF2CCCB611D4A40B54E5C8E57524D408CF2CCCB611D4A40
66194	15856	58.134779000000002	58.150221000000002	52.106167999999997	52.098970999999999	Матросова	0103000020E610000001000000050000000398327040114D404F20EC14AB0C4A400398327040114D40DCF0BBE9960D4A40121615713A134D40DCF0BBE9960D4A40121615713A134D404F20EC14AB0C4A400398327040114D404F20EC14AB0C4A40
64183	16366	58.276631999999999	58.304713	52.218888999999997	52.205562	Целинная	0103000020E61000000100000005000000778368AD68234D4072A609DB4F1A4A40778368AD68234D40213A048E041C4A4041D5E8D500274D40213A048E041C4A4041D5E8D500274D4072A609DB4F1A4A40778368AD68234D4072A609DB4F1A4A40
66705	16366	58.276631999999999	58.304713	52.218888999999997	52.205562	Арсланова	0103000020E61000000100000005000000778368AD68234D4072A609DB4F1A4A40778368AD68234D40213A048E041C4A4041D5E8D500274D40213A048E041C4A4041D5E8D500274D4072A609DB4F1A4A40778368AD68234D4072A609DB4F1A4A40
66832	14531	57.632747000000002	57.647533000000003	51.840324000000003	51.832405000000001	Салавата Юлаева	0103000020E6100000010000000500000031D28BDAFDD04C4071033E3F8CEA494031D28BDAFDD04C409F05A1BC8FEB4940570A815CE2D24C409F05A1BC8FEB4940570A815CE2D24C4071033E3F8CEA494031D28BDAFDD04C4071033E3F8CEA4940
66197	14749	57.436725000000003	57.452437000000003	51.971266	51.963354000000002	Заки Валиди	0103000020E610000001000000050000003D2CD49AE6B74C40433C122F4FFB49403D2CD49AE6B74C40BEDBBC7152FC49400C40A374E9B94C40BEDBBC7152FC49400C40A374E9B94C40433C122F4FFB49403D2CD49AE6B74C40433C122F4FFB4940
66476	58794	57.299686999999999	58.713113999999997	52.379731999999997	51.719147999999997	Бабича	0103000020E61000000100000005000000A704C4245CA64C40ED7DAA0A0DDC4940A704C4245CA64C40519FE40E9B304A40ED28CE51475B4D40519FE40E9B304A40ED28CE51475B4D40ED7DAA0A0DDC4940A704C4245CA64C40ED7DAA0A0DDC4940
64174	16253	58.134177000000001	58.152268999999997	51.980930000000001	51.953636000000003	Победы	0103000020E610000001000000050000000D7041B62C114D40E62494BE10FA49400D7041B62C114D4028D53E1D8FFD4940E998F38C7D134D4028D53E1D8FFD4940E998F38C7D134D40E62494BE10FA49400D7041B62C114D40E62494BE10FA4940
66401	33160	57.510019	57.528011999999997	51.839511000000002	51.832683000000003	Мира	0103000020E6100000010000000500000058AB764D48C14C40B477465B95EA494058AB764D48C14C40EED0B01875EB4940A1F2AFE595C34C40EED0B01875EB4940A1F2AFE595C34C40B477465B95EA494058AB764D48C14C40B477465B95EA4940
65515	47255	58.196080000000002	58.214602999999997	51.909042999999997	51.898257999999998	Новая	0103000020E6100000010000000500000029B3412619194D4068AF3E1EFAF2494029B3412619194D4030D461855BF44940CE4F711C781B4D4030D461855BF44940CE4F711C781B4D4068AF3E1EFAF2494029B3412619194D4068AF3E1EFAF24940
66306	47255	58.196080000000002	58.214602999999997	51.909042999999997	51.898257999999998	 Фестивальная	0103000020E6100000010000000500000029B3412619194D4068AF3E1EFAF2494029B3412619194D4030D461855BF44940CE4F711C781B4D4030D461855BF44940CE4F711C781B4D4068AF3E1EFAF2494029B3412619194D4068AF3E1EFAF24940
65614	58580	58.469419000000002	58.486244999999997	51.812503	51.802078999999999	Школьная	0103000020E610000001000000050000007E8FFAEB153C4D4079E75086AAE649407E8FFAEB153C4D4071732A1900E84940F86BB2463D3E4D4071732A1900E84940F86BB2463D3E4D4079E75086AAE649407E8FFAEB153C4D4079E75086AAE64940
65588	16158	58.539892000000002	58.557391000000003	52.080328999999999	52.075479999999999	 Муртазина	0103000020E610000001000000050000009FAF592E1B454D4044C02154A9094A409FAF592E1B454D40CFF57D38480A4A40D90A9A9658474D40CFF57D38480A4A40D90A9A9658474D4044C02154A9094A409FAF592E1B454D4044C02154A9094A40
65045	48661	57.818041999999998	57.831426999999998	51.947085999999999	51.938986	Яковлева	0103000020E610000001000000050000009160AA99B5E84C4070B378B130F849409160AA99B5E84C40EE3F321D3AF9494075012F336CEA4C40EE3F321D3AF9494075012F336CEA4C4070B378B130F849409160AA99B5E84C4070B378B130F84940
66880	8757	58.425635999999997	58.450401999999997	52.051572	52.033602000000002	Гагарина	0103000020E6100000010000000500000008008E3D7B364D40448A01124D044A4008008E3D7B364D40D5B14AE999064A40C806D2C5A6394D40D5B14AE999064A40C806D2C5A6394D40448A01124D044A4008008E3D7B364D40448A01124D044A40
64047	33026	58.057623	58.071376000000001	52.176229999999997	52.166530999999999	Кипчак	0103000020E61000000100000005000000AB3FC23060074D40956247E350154A40AB3FC23060074D407B4963B48E164A4012DC48D922094D407B4963B48E164A4012DC48D922094D40956247E350154A40AB3FC23060074D40956247E350154A40
66681	3500	58.267972	58.318961000000002	51.805670999999997	51.793495999999998	Баракатова	0103000020E61000000100000005000000321F10E84C224D40DFC0E44691E54940321F10E84C224D40F52A323A20E7494088D9CBB6D3284D40F52A323A20E7494088D9CBB6D3284D40DFC0E44691E54940321F10E84C224D40DFC0E44691E54940
65465	16136	58.584521000000002	58.600268	52.092691000000002	52.083705000000002	Полтавская	0103000020E61000000100000005000000A1698995D14A4D407FC16ED8B60A4A40A1698995D14A4D4018D1764CDD0B4A40EC6AF294D54C4D4018D1764CDD0B4A40EC6AF294D54C4D407FC16ED8B60A4A40A1698995D14A4D407FC16ED8B60A4A40
66160	58719	58.208404999999999	58.220424000000001	52.318465000000003	52.310195999999998	Победы	0103000020E6100000010000000500000054A9D903AD1A4D40CDACA580B4274A4054A9D903AD1A4D40D8F50B76C3284A4073A087DA361C4D40D8F50B76C3284A4073A087DA361C4D40CDACA580B4274A4054A9D903AD1A4D40CDACA580B4274A40
64613	58302	57.850633000000002	57.872236999999998	52.045755999999997	52.030310999999998	Худайбердина	0103000020E61000000100000005000000FEF2C98AE1EC4C40C2DA183BE1034A40FEF2C98AE1EC4C4042CC2555DB054A403AAE4676A5EF4C4042CC2555DB054A403AAE4676A5EF4C40C2DA183BE1034A40FEF2C98AE1EC4C40C2DA183BE1034A40
65649	2239	58.426732000000001	58.449657000000002	51.865518999999999	51.850411000000001	Салавата Юлаева	0103000020E610000001000000050000000E1478279F364D404F948444DAEC49400E1478279F364D4087889B53C9EE494070B54E5C8E394D4087889B53C9EE494070B54E5C8E394D404F948444DAEC49400E1478279F364D404F948444DAEC4940
65700	2239	58.426732000000001	58.449657000000002	51.865518999999999	51.850411000000001	Набережная	0103000020E610000001000000050000000E1478279F364D404F948444DAEC49400E1478279F364D4087889B53C9EE494070B54E5C8E394D4087889B53C9EE494070B54E5C8E394D404F948444DAEC49400E1478279F364D404F948444DAEC4940
66187	14417	57.482745999999999	57.505364999999998	51.801583000000001	51.787385	Молодежная	0103000020E610000001000000050000002D23F59ECABD4C40342E1C08C9E449402D23F59ECABD4C40C90391459AE6494082C5E1CCAFC04C40C90391459AE6494082C5E1CCAFC04C40342E1C08C9E449402D23F59ECABD4C40342E1C08C9E44940
64382	15573	58.331142	58.360894000000002	51.978662	51.951881999999998	Целинная	0103000020E61000000100000005000000802A6EDC622A4D4056D3F544D7F94940802A6EDC622A4D4042EBE1CB44FD49404CA94BC6312E4D4042EBE1CB44FD49404CA94BC6312E4D4056D3F544D7F94940802A6EDC622A4D4056D3F544D7F94940
65507	49208	58.470317999999999	58.489182	52.311264000000001	52.303896999999999	Акмуллы	0103000020E610000001000000050000002D5C5661333C4D401F2DCE18E6264A402D5C5661333C4D400936AE7FD7274A405CE509849D3E4D400936AE7FD7274A405CE509849D3E4D401F2DCE18E6264A402D5C5661333C4D401F2DCE18E6264A40
66878	15674	58.196888999999999	58.218618999999997	51.770282999999999	51.758946000000002	Мира	0103000020E6100000010000000500000098F8A3A833194D400BB77C2425E1494098F8A3A833194D4017D522A298E2494061A417B5FB1B4D4017D522A298E2494061A417B5FB1B4D400BB77C2425E1494098F8A3A833194D400BB77C2425E14940
64369	33150	57.871868999999997	57.906480999999999	51.993637	51.967016000000001	Заки Валиди	0103000020E61000000100000005000000B7B2446799EF4C40B85A272EC7FB4940B7B2446799EF4C403B8C497F2FFF494002B9C49107F44C403B8C497F2FFF494002B9C49107F44C40B85A272EC7FB4940B7B2446799EF4C40B85A272EC7FB4940
9867	40337	57.299686999999999	58.713113999999997	52.379731999999997	51.719147999999997	Акмулы	0103000020E61000000100000005000000A704C4245CA64C40ED7DAA0A0DDC4940A704C4245CA64C40519FE40E9B304A40ED28CE51475B4D40519FE40E9B304A40ED28CE51475B4D40ED7DAA0A0DDC4940A704C4245CA64C40ED7DAA0A0DDC4940
66764	149	57.528677000000002	57.554279000000001	51.957599000000002	51.942328000000003	Гагарина	0103000020E61000000100000005000000DE921CB0ABC34C40740D33349EF84940DE921CB0ABC34C4056D7A19A92FA494007EE409DF2C64C4056D7A19A92FA494007EE409DF2C64C40740D33349EF84940DE921CB0ABC34C40740D33349EF84940
65720	58609	58.352414000000003	58.365879999999997	52.124240999999998	52.114581000000001	Первоцелинников	0103000020E610000001000000050000008753E6E61B2D4D401ADF1797AA0E4A408753E6E61B2D4D4042E90B21E70F4A405721E527D52E4D4042E90B21E70F4A405721E527D52E4D401ADF1797AA0E4A408753E6E61B2D4D401ADF1797AA0E4A40
63448	12476	58.141651000000003	58.18159	51.977896000000001	51.941817	Тасимова	0103000020E610000001000000050000000D39B69E21124D408EE89E758DF849400D39B69E21124D40D27135B22BFD4940ECA353573E174D40D27135B22BFD4940ECA353573E174D408EE89E758DF849400D39B69E21124D408EE89E758DF84940
63536	12476	58.141651000000003	58.18159	51.977896000000001	51.941817	Заки Валиди	0103000020E610000001000000050000000D39B69E21124D408EE89E758DF849400D39B69E21124D40D27135B22BFD4940ECA353573E174D40D27135B22BFD4940ECA353573E174D408EE89E758DF849400D39B69E21124D408EE89E758DF84940
63297	12476	58.141651000000003	58.18159	51.977896000000001	51.941817	Гагарина	0103000020E610000001000000050000000D39B69E21124D408EE89E758DF849400D39B69E21124D40D27135B22BFD4940ECA353573E174D40D27135B22BFD4940ECA353573E174D408EE89E758DF849400D39B69E21124D408EE89E758DF84940
65642	15778	58.103042000000002	58.122318999999997	52.097991999999998	52.087572999999999	Юбилейная	0103000020E61000000100000005000000A60EF27A300D4D409D819197350B4A40A60EF27A300D4D4083A279008B0C4A40F7562426A80F4D4083A279008B0C4A40F7562426A80F4D409D819197350B4A40A60EF27A300D4D409D819197350B4A40
66190	14441	57.535522	57.552050999999999	51.813979000000003	51.805894000000002	Дружбы	0103000020E61000000100000005000000EE2422FC8BC44C407505DB8827E74940EE2422FC8BC44C40BE50C07630E84940AF5C6F9BA9C64C40BE50C07630E84940AF5C6F9BA9C64C407505DB8827E74940EE2422FC8BC44C407505DB8827E74940
66790	14344	57.487399000000003	57.512597	51.781990999999998	51.766894999999998	Ахметшина	0103000020E61000000100000005000000338D261763BE4C40A33B889D29E24940338D261763BE4C401762F54718E449408C834BC79CC14C401762F54718E449408C834BC79CC14C40A33B889D29E24940338D261763BE4C40A33B889D29E24940
66569	58843	58.512422000000001	58.531637000000003	52.003224000000003	51.985762000000001	Победы	0103000020E610000001000000050000001EE0490B97414D40DDD1FF722DFE49401EE0490B97414D40FA47DFA469004A40FA2B64AE0C444D40FA47DFA469004A40FA2B64AE0C444D40DDD1FF722DFE49401EE0490B97414D40DDD1FF722DFE4940
64119	16233	57.971967999999997	57.991155999999997	51.930562000000002	51.917760000000001	Гагарина	0103000020E6100000010000000500000017618A7269FC4C40DAC9E02879F5494017618A7269FC4C403F73D6A71CF74940F99D2633DEFE4C403F73D6A71CF74940F99D2633DEFE4C40DAC9E02879F5494017618A7269FC4C40DAC9E02879F54940
65043	15183	57.883547	57.912849999999999	51.897584999999999	51.875827999999998	К.Ахметшина	0103000020E610000001000000050000004DBD6E1118F14C40E675C4211BF049404DBD6E1118F14C40A930B610E4F24940A913D044D8F44C40A930B610E4F24940A913D044D8F44C40E675C4211BF049404DBD6E1118F14C40E675C4211BF04940
65463	16477	58.286738	58.302898999999996	52.246549999999999	52.226078000000001	Дружбы	0103000020E610000001000000050000009E42AED4B3244D402C2CB81FF01C4A409E42AED4B3244D40166A4DF38E1F4A40DC7EF964C5264D40166A4DF38E1F4A40DC7EF964C5264D402C2CB81FF01C4A409E42AED4B3244D402C2CB81FF01C4A40
64395	14789	58.188066999999997	58.234321000000001	51.876550999999999	51.845626000000003	Энергетиков	0103000020E61000000100000005000000793A579412184D40DB5207793DEC4940793A579412184D405723BBD232F049400DE2033BFE1D4D405723BBD232F049400DE2033BFE1D4D40DB5207793DEC4940793A579412184D40DB5207793DEC4940
64394	14789	58.188066999999997	58.234321000000001	51.876550999999999	51.845626000000003	Подгорная	0103000020E61000000100000005000000793A579412184D40DB5207793DEC4940793A579412184D405723BBD232F049400DE2033BFE1D4D405723BBD232F049400DE2033BFE1D4D40DB5207793DEC4940793A579412184D40DB5207793DEC4940
64253	14789	58.188066999999997	58.234321000000001	51.876550999999999	51.845626000000003	Акмуллы	0103000020E61000000100000005000000793A579412184D40DB5207793DEC4940793A579412184D405723BBD232F049400DE2033BFE1D4D405723BBD232F049400DE2033BFE1D4D40DB5207793DEC4940793A579412184D40DB5207793DEC4940
66195	14683	57.493758999999997	57.511510000000001	51.900809000000002	51.890210000000003	Горная	0103000020E61000000100000005000000868DB27E33BF4C403D49BA66F2F14940868DB27E33BF4C40A37895B54DF34940DAC9E02879C14C40A37895B54DF34940DAC9E02879C14C403D49BA66F2F14940868DB27E33BF4C403D49BA66F2F14940
65621	15419	57.791003000000003	57.797947000000001	51.950195000000001	51.937824999999997	М. Муртазина	0103000020E61000000100000005000000DA0418963FE54C40832F4CA60AF84940DA0418963FE54C404FE960FD9FF949407D78962023E64C404FE960FD9FF949407D78962023E64C40832F4CA60AF84940DA0418963FE54C40832F4CA60AF84940
66563	58806	57.639403000000001	57.651592999999998	51.920321000000001	51.912759999999999	 Акназарова	0103000020E610000001000000050000006EFB1EF5D7D14C40698CD651D5F449406EFB1EF5D7D14C4038691A14CDF54940B9A6406667D34C4038691A14CDF54940B9A6406667D34C40698CD651D5F449406EFB1EF5D7D14C40698CD651D5F44940
65647	16797	57.952528999999998	57.980116000000002	51.874566000000002	51.861624999999997	Заки Валиди	0103000020E61000000100000005000000ECBE6378ECF94C403F355EBA49EE4940ECBE6378ECF94C40C61858C7F1EF4940A724EB7074FD4C40C61858C7F1EF4940A724EB7074FD4C403F355EBA49EE4940ECBE6378ECF94C403F355EBA49EE4940
64597	17062	58.40325	58.414101000000002	52.269922999999999	52.265431	Абдулнасыровская	0103000020E61000000100000005000000560E2DB29D334D401B2C9CA4F9214A40560E2DB29D334D4017B83CD68C224A40D61EF64201354D4017B83CD68C224A40D61EF64201354D401B2C9CA4F9214A40560E2DB29D334D401B2C9CA4F9214A40
66418	33601	55.161696999999997	55.214616999999997	53.189991999999997	53.164318000000002	Центральная	0103000020E610000001000000050000003F6EBF7CB2944B4073124A5F08954A403F6EBF7CB2944B40354069A851984A403315E291789B4B40354069A851984A403315E291789B4B4073124A5F08954A403F6EBF7CB2944B4073124A5F08954A40
66193	33601	55.161696999999997	55.214616999999997	53.189991999999997	53.164318000000002	Первая	0103000020E610000001000000050000003F6EBF7CB2944B4073124A5F08954A403F6EBF7CB2944B40354069A851984A403315E291789B4B40354069A851984A403315E291789B4B4073124A5F08954A403F6EBF7CB2944B4073124A5F08954A40
64151	33601	55.161696999999997	55.214616999999997	53.189991999999997	53.164318000000002	Коммунистическая	0103000020E610000001000000050000003F6EBF7CB2944B4073124A5F08954A403F6EBF7CB2944B40354069A851984A403315E291789B4B40354069A851984A403315E291789B4B4073124A5F08954A403F6EBF7CB2944B4073124A5F08954A40
66415	33601	55.161696999999997	55.214616999999997	53.189991999999997	53.164318000000002	Дружбы	0103000020E610000001000000050000003F6EBF7CB2944B4073124A5F08954A403F6EBF7CB2944B40354069A851984A403315E291789B4B40354069A851984A403315E291789B4B4073124A5F08954A403F6EBF7CB2944B4073124A5F08954A40
65480	45679	55.362237	55.386042000000003	53.042670999999999	53.026685999999998	Ленина	0103000020E61000000100000005000000593332C85DAE4B406AA164726A834A40593332C85DAE4B406ABE4A3E76854A40F47002D369B14B406ABE4A3E76854A40F47002D369B14B406AA164726A834A40593332C85DAE4B406AA164726A834A40
66567	58842	55.202407999999998	55.232987000000001	53.112298000000003	53.097349999999999	 Центральная	0103000020E6100000010000000500000071395E81E8994B40FF21FDF6758C4A4071395E81E8994B40FFB3E6C75F8E4A4053B29C84D29D4B40FFB3E6C75F8E4A4053B29C84D29D4B40FF21FDF6758C4A4071395E81E8994B40FF21FDF6758C4A40
64255	32601	55.102488999999998	55.124336	53.178438999999997	53.166445000000003	Салавата Юлаева	0103000020E6100000010000000500000091990B5C1E8D4B4097CADB114E954A4091990B5C1E8D4B405CAAD216D7964A4094DBF63DEA8F4B405CAAD216D7964A4094DBF63DEA8F4B4097CADB114E954A4091990B5C1E8D4B4097CADB114E954A40
64095	33108	55.290677000000002	55.317267000000001	53.104377999999997	53.084283999999997	Ленина	0103000020E61000000100000005000000865968E734A54B40BCC96FD1C98A4A40865968E734A54B40003620425C8D4A40CE8C7E349CA84B40003620425C8D4A40CE8C7E349CA84B40BCC96FD1C98A4A40865968E734A54B40BCC96FD1C98A4A40
65039	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Школьная	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
66457	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Тагирова	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63805	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Строительная	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63808	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Пионерская	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
64533	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Партизанская	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63968	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Мира	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63989	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Ленина	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
63558	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	Ахметгалина	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
66528	11421	59.365192999999998	59.467528999999999	54.335903999999999	54.274464999999999	 Чехова	0103000020E6100000010000000500000033DDEBA4BEAE4D40C5724BAB21234B4033DDEBA4BEAE4D403C4CFBE6FE2A4B403E7782FDD7BB4D403C4CFBE6FE2A4B403E7782FDD7BB4D40C5724BAB21234B4033DDEBA4BEAE4D40C5724BAB21234B40
64192	58183	59.410907999999999	59.453937000000003	54.382429999999999	54.343640999999998	Элеваторный переулок	0103000020E6100000010000000500000017D522A298B44D404948A46DFC2B4B4017D522A298B44D4030815B77F3304B40E1B88C9B1ABA4D4030815B77F3304B40E1B88C9B1ABA4D404948A46DFC2B4B4017D522A298B44D404948A46DFC2B4B40
64178	58183	59.410907999999999	59.453937000000003	54.382429999999999	54.343640999999998	С.Юлаева	0103000020E6100000010000000500000017D522A298B44D404948A46DFC2B4B4017D522A298B44D4030815B77F3304B40E1B88C9B1ABA4D4030815B77F3304B40E1B88C9B1ABA4D404948A46DFC2B4B4017D522A298B44D404948A46DFC2B4B40
63551	46927	59.105840000000001	59.135483999999998	54.133600999999999	54.112436000000002	Гагарина	0103000020E61000000100000005000000E84D452A8C8D4D405072874D640E4B40E84D452A8C8D4D4040DB6AD619114B40CD902A8A57914D4040DB6AD619114B40CD902A8A57914D405072874D640E4B40E84D452A8C8D4D405072874D640E4B40
64263	10890	59.11777	59.138494000000001	54.277456999999998	54.255661000000003	Центральная	0103000020E6100000010000000500000097395D16138F4D406CEEE87FB9204B4097395D16138F4D40EC8502B683234B409B58E02BBA914D40EC8502B683234B409B58E02BBA914D406CEEE87FB9204B4097395D16138F4D406CEEE87FB9204B40
66708	10488	59.714852999999998	59.740239000000003	54.608347999999999	54.596457000000001	Ирандыкская	0103000020E610000001000000050000004739984D80DB4D40323CF6B3584C4B404739984D80DB4D40234BE658DE4D4B40A41CCC26C0DE4D40234BE658DE4D4B40A41CCC26C0DE4D40323CF6B3584C4B404739984D80DB4D40323CF6B3584C4B40
65630	8822	59.000045	59.010770999999998	54.026328999999997	54.018278000000002	Школьная	0103000020E61000000100000005000000A0C37C7901804D403F1EFAEE56024B40A0C37C7901804D40DBF7A8BF5E034B40635FB2F160814D40DBF7A8BF5E034B40635FB2F160814D403F1EFAEE56024B40A0C37C7901804D403F1EFAEE56024B40
65964	31502	59.867691999999998	59.882928	54.775863999999999	54.770479000000002	Турновская	0103000020E610000001000000050000001B800D8810EF4D409DA04D0E9F624B401B800D8810EF4D406612F5824F634B40815CE2C803F14D406612F5824F634B40815CE2C803F14D409DA04D0E9F624B401B800D8810EF4D409DA04D0E9F624B40
64688	10419	59.710971999999998	59.731048999999999	54.575660999999997	54.563963999999999	Школьная	0103000020E61000000100000005000000942F682101DB4D40880FECF82F484B40942F682101DB4D40944A7842AF494B4002637D0393DD4D40944A7842AF494B4002637D0393DD4D40880FECF82F484B40942F682101DB4D40880FECF82F484B40
65044	10622	59.670009	59.684255999999998	54.666265000000003	54.657271000000001	Клубная	0103000020E610000001000000050000004983DBDAC2D54D40FBCDC47421544B404983DBDAC2D54D4017BCE82B48554B40BF0B5BB395D74D4017BCE82B48554B40BF0B5BB395D74D40FBCDC47421544B404983DBDAC2D54D40FBCDC47421544B40
65457	10670	59.699688999999999	59.713838000000003	54.732396999999999	54.727235	Центральная	0103000020E610000001000000050000007B2FBE688FD94D40D7C05609165D4B407B2FBE688FD94D402158552FBF5D4B402F52280B5FDB4D402158552FBF5D4B402F52280B5FDB4D40D7C05609165D4B407B2FBE688FD94D40D7C05609165D4B40
66183	11523	59.547119000000002	59.573718	54.344712000000001	54.331242000000003	М.Шагеева	0103000020E610000001000000050000009702D2FE07C64D40E4874A23662A4B409702D2FE07C64D40F644D7851F2C4B40329067976FC94D40F644D7851F2C4B40329067976FC94D40E4874A23662A4B409702D2FE07C64D40E4874A23662A4B40
65210	9371	59.371535000000002	59.396157000000002	54.480584999999998	54.461163999999997	Центральная	0103000020E61000000100000005000000E12879758EAF4D40D80B056C073B4B40E12879758EAF4D405DF92CCF833D4B406E8AC745B5B24D405DF92CCF833D4B406E8AC745B5B24D40D80B056C073B4B40E12879758EAF4D40D80B056C073B4B40
65640	9500	59.226106000000001	59.245365999999997	54.218736999999997	54.207380000000001	Школьная	0103000020E61000000100000005000000F6B6990AF19C4D4018EC866D8B1A4B40F6B6990AF19C4D406BB6F292FF1B4B4071C63027689F4D406BB6F292FF1B4B4071C63027689F4D4018EC866D8B1A4B40F6B6990AF19C4D4018EC866D8B1A4B40
65650	58592	59.684364000000002	59.716011999999999	54.636198999999998	54.625114000000004	Советская	0103000020E61000000100000005000000A647533D99D74D40C9224DBC03504B40A647533D99D74D40BB5F05F86E514B4093C5FD47A6DB4D40BB5F05F86E514B4093C5FD47A6DB4D40C9224DBC03504B40A647533D99D74D40C9224DBC03504B40
66174	10376	59.688811000000001	59.705438000000001	54.436464999999998	54.421422999999997	Заречная	0103000020E61000000100000005000000021077F52AD84D401F645930F1354B40021077F52AD84D40A06CCA15DE374B4086ADD9CA4BDA4D40A06CCA15DE374B4086ADD9CA4BDA4D401F645930F1354B40021077F52AD84D401F645930F1354B40
65269	45770	59.217447	59.234074	54.102105000000002	54.092041999999999	Школьная	0103000020E6100000010000000500000081CEA44DD59B4D40E1ED4108C80B4B4081CEA44DD59B4D4009E1D1C6110D4B40056C0723F69D4D4009E1D1C6110D4B40056C0723F69D4D40E1ED4108C80B4B4081CEA44DD59B4D40E1ED4108C80B4B40
65391	45770	59.217447	59.234074	54.102105000000002	54.092041999999999	 Центральная	0103000020E6100000010000000500000081CEA44DD59B4D40E1ED4108C80B4B4081CEA44DD59B4D4009E1D1C6110D4B40056C0723F69D4D4009E1D1C6110D4B40056C0723F69D4D40E1ED4108C80B4B4081CEA44DD59B4D40E1ED4108C80B4B40
66871	9975	58.842903	58.859350999999997	53.955590999999998	53.948399999999999	Школьная	0103000020E61000000100000005000000A359D93EE46B4D4061C3D32B65F94A40A359D93EE46B4D400CAD4ECE50FA4A407764AC36FF6D4D400CAD4ECE50FA4A407764AC36FF6D4D4061C3D32B65F94A40A359D93EE46B4D4061C3D32B65F94A40
64531	10143	59.022314999999999	59.047099000000003	54.105457999999999	54.094909000000001	Шоссейная	0103000020E61000000100000005000000E99AC937DB824D404C8C65FA250C4B40E99AC937DB824D40008DD2A57F0D4B4050560C5707864D40008DD2A57F0D4B4050560C5707864D404C8C65FA250C4B40E99AC937DB824D404C8C65FA250C4B40
65037	46529	59.074857000000002	59.096604999999997	54.056449999999998	54.035642000000003	Школьный	0103000020E61000000100000005000000377007EA94894D40992EC4EA8F044B40377007EA94894D40FAEDEBC039074B40A6D0798D5D8C4D40FAEDEBC039074B40A6D0798D5D8C4D40992EC4EA8F044B40377007EA94894D40992EC4EA8F044B40
66722	9158	59.382494000000001	59.398197000000003	54.405012999999997	54.390509000000002	Школьная	0103000020E6100000010000000500000047753A90F5B04D4097E5EB32FC314B4047753A90F5B04D4038BA4A77D7334B40C32E8A1EF8B24D4038BA4A77D7334B40C32E8A1EF8B24D4097E5EB32FC314B4047753A90F5B04D4097E5EB32FC314B40
65456	9158	59.382494000000001	59.398197000000003	54.405012999999997	54.390509000000002	Иремельская	0103000020E6100000010000000500000047753A90F5B04D4097E5EB32FC314B4047753A90F5B04D4038BA4A77D7334B40C32E8A1EF8B24D4038BA4A77D7334B40C32E8A1EF8B24D4097E5EB32FC314B4047753A90F5B04D4097E5EB32FC314B40
65217	58496	59.093559999999997	59.111634000000002	53.986986000000002	53.973377999999997	Школьная	0103000020E610000001000000050000005C1B2AC6F98B4D40AC527AA697FC4A405C1B2AC6F98B4D4010CEA78E55FE4A40938FDD054A8E4D4010CEA78E55FE4A40938FDD054A8E4D40AC527AA697FC4A405C1B2AC6F98B4D40AC527AA697FC4A40
63292	9838	58.774065	58.831125999999998	54.063853999999999	54.002273000000002	Уфимская	0103000020E6100000010000000500000037FDD98F14634D40F8544E7B4A004B4037FDD98F14634D4001DC2C5E2C084B407A6D3656626A4D4001DC2C5E2C084B407A6D3656626A4D40F8544E7B4A004B4037FDD98F14634D40F8544E7B4A004B40
64518	32736	59.520798999999997	59.531326999999997	54.489638999999997	54.481442999999999	Мира	0103000020E610000001000000050000000E65A88AA9C24D40AEF199EC9F3D4B400E65A88AA9C24D404EECA17DAC3E4B40AB3DEC8502C44D404EECA17DAC3E4B40AB3DEC8502C44D40AEF199EC9F3D4B400E65A88AA9C24D40AEF199EC9F3D4B40
65032	8900	58.938330999999998	58.950243	54.058326000000001	54.051777999999999	Советская	0103000020E6100000010000000500000057E9EE3A1B784D407E5358A9A0064B4057E9EE3A1B784D40D540F33977074B4060200890A1794D40D540F33977074B4060200890A1794D407E5358A9A0064B4057E9EE3A1B784D407E5358A9A0064B40
65624	46100	59.904998999999997	59.918716000000003	54.841101999999999	54.832670999999998	Хандугас	0103000020E61000000100000005000000D3F4D901D7F34D40EFA99CF6946A4B40D3F4D901D7F34D40D34CF73AA96B4B40EE27637C98F54D40D34CF73AA96B4B40EE27637C98F54D40EFA99CF6946A4B40D3F4D901D7F34D40EFA99CF6946A4B40
66686	10576	59.807423999999997	59.818204000000001	54.643441000000003	54.630842000000001	Соловьиная	0103000020E61000000100000005000000B4006DAB59E74D40BC783F6EBF504B40B4006DAB59E74D40E9F351465C524B406BBA9EE8BAE84D40E9F351465C524B406BBA9EE8BAE84D40BC783F6EBF504B40B4006DAB59E74D40BC783F6EBF504B40
64354	9615	59.299641999999999	59.320861000000001	54.345483000000002	54.335106000000003	Шоссейная	0103000020E61000000100000005000000074147AB5AA64D40C158DFC0E42A4B40074147AB5AA64D40782975C9382C4B40EBC726F911A94D40782975C9382C4B40EBC726F911A94D40C158DFC0E42A4B40074147AB5AA64D40C158DFC0E42A4B40
66189	46243	59.263764000000002	59.275047000000001	54.218246999999998	54.211596999999998	Салавата	0103000020E610000001000000050000005BEECC04C3A14D404277499C151B4B405BEECC04C3A14D409DB98784EF1B4B4074EE76BD34A34D409DB98784EF1B4B4074EE76BD34A34D404277499C151B4B405BEECC04C3A14D404277499C151B4B40
66172	9917	58.709350000000001	58.726095000000001	53.937223000000003	53.925905	Куяшевская	0103000020E6100000010000000500000074B515FBCB5A4D40F819170E84F64A4074B515FBCB5A4D408E075BECF6F74A40026553AEF05C4D408E075BECF6F74A40026553AEF05C4D40F819170E84F64A4074B515FBCB5A4D40F819170E84F64A40
66602	46686	59.722999999999999	59.745054000000003	54.623029000000002	54.612257999999997	З.Биишевой	0103000020E61000000100000005000000068195438BDC4D40705B5B785E4E4B40068195438BDC4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40705B5B785E4E4B40068195438BDC4D40705B5B785E4E4B40
65038	46686	59.722999999999999	59.745054000000003	54.623029000000002	54.612257999999997	Беркут Тау	0103000020E61000000100000005000000068195438BDC4D40705B5B785E4E4B40068195438BDC4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40D4BA0D6ABF4F4B4083E0F1ED5DDF4D40705B5B785E4E4B40068195438BDC4D40705B5B785E4E4B40
65627	7183	59.254196999999998	59.274884999999998	54.560423999999998	54.543014999999997	Никольская	0103000020E61000000100000005000000E3DEFC8689A04D40641EF98381454B40E3DEFC8689A04D405EF23FF9BB474B409A94826E2FA34D405EF23FF9BB474B409A94826E2FA34D40641EF98381454B40E3DEFC8689A04D40641EF98381454B40
65523	9124	59.806265000000003	59.828130000000002	54.706178000000001	54.683684	Центральная	0103000020E61000000100000005000000697407B133E74D40346612F582574B40697407B133E74D40CD936B0A645A4B40126BF12900EA4D40CD936B0A645A4B40126BF12900EA4D40346612F582574B40697407B133E74D40346612F582574B40
66177	11134	59.299948000000001	59.319944	54.414141000000001	54.406379999999999	Школьная	0103000020E61000000100000005000000144031B264A64D40CEDF844204344B40144031B264A64D406477819202354B409546CCECF3A84D406477819202354B409546CCECF3A84D40CEDF844204344B40144031B264A64D40CEDF844204344B40
65041	10704	59.601827	59.610827999999998	54.692698	54.686197999999997	Центральная	0103000020E61000000100000005000000C66CC9AA08CD4D40514A0856D5574B40C66CC9AA08CD4D409700FC53AA584B4094BDA59C2FCE4D409700FC53AA584B4094BDA59C2FCE4D40514A0856D5574B40C66CC9AA08CD4D40514A0856D5574B40
65641	10769	59.107277000000003	59.128360999999998	54.206226000000001	54.198726999999998	Сорагул	0103000020E61000000100000005000000774EB340BB8D4D4085EAE6E26F194B40774EB340BB8D4D40DECA129D651A4B407A8A1C226E904D40DECA129D651A4B407A8A1C226E904D4085EAE6E26F194B40774EB340BB8D4D4085EAE6E26F194B40
65469	10980	59.163089999999997	59.178584999999998	54.172809999999998	54.162331000000002	Школьная	0103000020E61000000100000005000000FE261422E0944D4041102043C7144B40FE261422E0944D40FC3559A31E164B4030478FDFDB964D40FC3559A31E164B4030478FDFDB964D4041102043C7144B40FE261422E0944D4041102043C7144B40
66186	10956	59.155327999999997	59.176653999999999	54.144303000000001	54.135579	Центральная	0103000020E610000001000000050000009813B4C9E1934D401F8315A75A114B409813B4C9E1934D407BDB4C8578124B40925A28999C964D407BDB4C8578124B40925A28999C964D401F8315A75A114B409813B4C9E1934D401F8315A75A114B40
64594	58289	59.301519999999996	59.330823000000002	54.281540999999997	54.266441999999998	Центральная	0103000020E61000000100000005000000828B153598A64D40F2237EC51A224B40828B153598A64D40D7BD158909244B40DFE1766858AA4D40D7BD158909244B40DFE1766858AA4D40F2237EC51A224B40828B153598A64D40F2237EC51A224B40
63997	9347	59.521652000000003	59.545377000000002	54.430934999999998	54.409745000000001	Кучербай	0103000020E610000001000000050000004EF2237EC5C24D408A592F8672344B404EF2237EC5C24D40D3D9C9E028374B40CC7EDDE9CEC54D40D3D9C9E028374B40CC7EDDE9CEC54D408A592F8672344B404EF2237EC5C24D408A592F8672344B40
64567	32626	59.799824000000001	59.809769000000003	54.759180999999998	54.756126000000002	Агышбай	0103000020E61000000100000005000000284701A260E64D40E1D39CBCC8604B40284701A260E64D404E5FCFD72C614B404628B682A6E74D404E5FCFD72C614B404628B682A6E74D40E1D39CBCC8604B40284701A260E64D40E1D39CBCC8604B40
65462	46605	59.572038999999997	59.601782	54.651817999999999	54.638893000000003	Зеленая	0103000020E61000000100000005000000AD84EE9238C94D405952EE3EC7514B40AD84EE9238C94D40D978B0C56E534B4026A94C3107CD4D40D978B0C56E534B4026A94C3107CD4D405952EE3EC7514B40AD84EE9238C94D405952EE3EC7514B40
64034	9150	59.487175000000001	59.5154	54.258505999999997	54.247013000000003	Центральная	0103000020E61000000100000005000000E3361AC05BBE4D40EB573A1F9E1F4B40E3361AC05BBE4D40EEE87FB916214B40E02D90A0F8C14D40EEE87FB916214B40E02D90A0F8C14D40EB573A1F9E1F4B40E3361AC05BBE4D40EB573A1F9E1F4B40
66604	4468	58.865388000000003	58.881827000000001	53.887591999999998	53.880974000000002	Школьная	0103000020E61000000100000005000000E92CB308C56E4D402B508BC1C3F04A40E92CB308C56E4D407A185A9D9CF14A406ADD06B5DF704D407A185A9D9CF14A406ADD06B5DF704D402B508BC1C3F04A40E92CB308C56E4D402B508BC1C3F04A40
63721	8920	59.585864000000001	59.630896	54.221637000000001	54.198836999999997	Партизанская	0103000020E61000000100000005000000AEF36F97FDCA4D400C1EA67D73194B40AEF36F97FDCA4D40B24AE9995E1C4B40AF963B33C1D04D40B24AE9995E1C4B40AF963B33C1D04D400C1EA67D73194B40AEF36F97FDCA4D400C1EA67D73194B40
64130	9745	59.545628000000001	59.562939	54.586916000000002	54.579996999999999	Шоссейная	0103000020E6100000010000000500000015E46723D7C54D40996379573D4A4B4015E46723D7C54D40E4BF4010204B4B404C5299620EC84D40E4BF4010204B4B404C5299620EC84D40996379573D4A4B4015E46723D7C54D40996379573D4A4B40
64540	58260	55.622326000000001	55.643130999999997	54.622022999999999	54.605620000000002	Кольцевая	0103000020E61000000100000005000000AAB9DC60A8CF4B40DAE6C6F4844D4B40AAB9DC60A8CF4B400E2E1D739E4F4B409A05DA1D52D24B400E2E1D739E4F4B409A05DA1D52D24B40DAE6C6F4844D4B40AAB9DC60A8CF4B40DAE6C6F4844D4B40
63547	45892	55.671886000000001	55.703740000000003	54.632192000000003	54.615094999999997	Центральная	0103000020E61000000100000005000000F451465C00D64B407077D66EBB4E4B40F451465C00D64B407C65DEAAEB504B408B71FE2614DA4B407C65DEAAEB504B408B71FE2614DA4B407077D66EBB4E4B40F451465C00D64B407077D66EBB4E4B40
64535	45892	55.671886000000001	55.703740000000003	54.632192000000003	54.615094999999997	Северная	0103000020E61000000100000005000000F451465C00D64B407077D66EBB4E4B40F451465C00D64B407C65DEAAEB504B408B71FE2614DA4B407C65DEAAEB504B408B71FE2614DA4B407077D66EBB4E4B40F451465C00D64B407077D66EBB4E4B40
65453	8641	55.482683000000002	55.507854000000002	54.797860999999997	54.781632999999999	Молодежная	0103000020E61000000100000005000000E7AA798EC8BD4B40B83CD68C0C644B40E7AA798EC8BD4B407EE02A4F20664B404792205C01C14B407EE02A4F20664B404792205C01C14B40B83CD68C0C644B40E7AA798EC8BD4B40B83CD68C0C644B40
65455	58546	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	Заречная	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
63833	58137	55.927231999999997	55.943446999999999	54.618577000000002	54.606600999999998	Школьная	0103000020E61000000100000005000000FFE6C589AFF64B40465C001AA54D4B40FFE6C589AFF64B406687F8872D4F4B4031410DDFC2F84B406687F8872D4F4B4031410DDFC2F84B40465C001AA54D4B40FFE6C589AFF64B40465C001AA54D4B40
64532	7731	55.808079999999997	55.826495000000001	54.867674000000001	54.84966	Школьная	0103000020E610000001000000050000009D465A2A6FE74B40145CACA8C16C4B409D465A2A6FE74B4075CB0EF10F6F4B405DA79196CAE94B4075CB0EF10F6F4B405DA79196CAE94B40145CACA8C16C4B409D465A2A6FE74B40145CACA8C16C4B40
65811	58636	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	Трактовая	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
65449	7377	55.732872999999998	55.758060999999998	54.710796999999999	54.696756000000001	Центральная	0103000020E610000001000000050000008A8F4FC8CEDD4B4059A5F44C2F594B408A8F4FC8CEDD4B40268C6665FB5A4B40C0AF912408E14B40268C6665FB5A4B40C0AF912408E14B4059A5F44C2F594B408A8F4FC8CEDD4B4059A5F44C2F594B40
64110	58168	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	Центральная	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
63422	7167	55.714035000000003	55.763164000000003	54.874811999999999	54.859938	Южная	0103000020E610000001000000050000008599B67F65DB4B40384BC972126E4B408599B67F65DB4B40FD12F1D6F96F4B4006BEA25BAFE14B40FD12F1D6F96F4B4006BEA25BAFE14B40384BC972126E4B408599B67F65DB4B40384BC972126E4B40
65628	8627	55.421768	55.441253000000003	54.782874	54.772686	Школьная	0103000020E61000000100000005000000EA3F6B7EFCB54B40DD09F65FE7624B40EA3F6B7EFCB54B40C171193735644B40862172FA7AB84B40C171193735644B40862172FA7AB84B40DD09F65FE7624B40EA3F6B7EFCB54B40DD09F65FE7624B40
64237	58195	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	Буденова	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
63447	8479	55.465615	55.500397999999997	54.769778000000002	54.753788	Центральная	0103000020E6100000010000000500000076C3B64599BB4B40020F0C207C604B4076C3B64599BB4B401497E31588624B40ED7DAA0A0DC04B401497E31588624B40ED7DAA0A0DC04B40020F0C207C604B4076C3B64599BB4B40020F0C207C604B40
63549	8001	55.554215999999997	55.584498000000004	54.822034000000002	54.806230999999997	Школьная	0103000020E61000000100000005000000C075C58CF0C64B40BC02D19332674B40C075C58CF0C64B409C19FD6838694B40E94999D4D0CA4B409C19FD6838694B40E94999D4D0CA4B40BC02D19332674B40C075C58CF0C64B40BC02D19332674B40
66165	8559	55.413504000000003	55.430562999999999	54.730817000000002	54.718910000000001	Школьная	0103000020E61000000100000005000000F261F6B2EDB44B4039622D3E055C4B40F261F6B2EDB44B40302E55698B5D4B400FEF39B01CB74B40302E55698B5D4B400FEF39B01CB74B4039622D3E055C4B40F261F6B2EDB44B4039622D3E055C4B40
63533	7993	55.682181	55.704808999999997	54.824601000000001	54.814298999999998	Советская	0103000020E61000000100000005000000EE79FEB451D74B402F151BF33A684B40EE79FEB451D74B40DC9F8B868C694B4096766A2E37DA4B40DC9F8B868C694B4096766A2E37DA4B402F151BF33A684B40EE79FEB451D74B402F151BF33A684B40
63817	58134	55.842996999999997	55.844496999999997	54.613253999999998	54.609062000000002	Мира	0103000020E6100000010000000500000024D06053E7EB4B40419E5DBEF54D4B4024D06053E7EB4B401212691B7F4E4B40F9484A7A18EC4B401212691B7F4E4B40F9484A7A18EC4B40419E5DBEF54D4B4024D06053E7EB4B40419E5DBEF54D4B40
63987	58152	55.89085	55.901009999999999	54.816577000000002	54.797818999999997	Ленина	0103000020E6100000010000000500000020D26F5F07F24B404F90D8EE1E664B4020D26F5F07F24B4039D55A9885684B403AAFB14B54F34B4039D55A9885684B403AAFB14B54F34B404F90D8EE1E664B4020D26F5F07F24B404F90D8EE1E664B40
64687	58321	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	Школьная	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
66781	1203	55.857405999999997	55.883555999999999	54.953721000000002	54.941471999999997	Центральная	0103000020E6100000010000000500000074B2D47ABFED4B40C30C8D2782784B4074B2D47ABFED4B4014419C87137A4B40A017EE5C18F14B4014419C87137A4B40A017EE5C18F14B40C30C8D2782784B4074B2D47ABFED4B40C30C8D2782784B40
63673	7650	55.891182999999998	55.931660999999998	54.897841999999997	54.886549000000002	Советская	0103000020E6100000010000000500000026E0D74812F24B4098A608707A714B4026E0D74812F24B40D47C957CEC724B40B5FAEAAA40F74B40D47C957CEC724B40B5FAEAAA40F74B4098A608707A714B4026E0D74812F24B4098A608707A714B40
63716	58123	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	Ильина	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
63851	58139	55.803274000000002	55.808492999999999	54.811217999999997	54.806728999999997	Советская	0103000020E6100000010000000500000012DDB3AED1E64B400DDE57E542674B4012DDB3AED1E64B4098F6CDFDD5674B40C005D9B27CE74B4098F6CDFDD5674B40C005D9B27CE74B400DDE57E542674B4012DDB3AED1E64B400DDE57E542674B40
64390	7267	55.610791999999996	55.624760000000002	54.905771999999999	54.885289999999998	Мкр.Солнечный	0103000020E610000001000000050000004754A86E2ECE4B40E8BCC62E51714B404754A86E2ECE4B40F6D03E56F0734B40ABECBB22F8CF4B40F6D03E56F0734B40ABECBB22F8CF4B40E8BCC62E51714B404754A86E2ECE4B40E8BCC62E51714B40
64882	8543	55.484003000000001	55.509712999999998	54.728606999999997	54.715701000000003	Бейгуловская	0103000020E610000001000000050000003C1570CFF3BD4B40755B22179C5B4B403C1570CFF3BD4B407E5182FE425D4B404BAC8C463EC14B407E5182FE425D4B404BAC8C463EC14B40755B22179C5B4B403C1570CFF3BD4B40755B22179C5B4B40
66171	7567	55.473897000000001	55.495924000000002	54.901994000000002	54.887397999999997	Восточная	0103000020E6100000010000000500000015562AA8A8BC4B409544F64196714B4015562AA8A8BC4B401898158A74734B4098A608707ABF4B401898158A74734B4098A608707ABF4B409544F64196714B4015562AA8A8BC4B409544F64196714B40
63810	58098	55.995719999999999	55.998558000000003	54.834356	54.831338000000002	Школьная	0103000020E610000001000000050000008FFCC1C073FF4B4006F69848696A4B408FFCC1C073FF4B40569C6A2DCC6A4B406094A0BFD0FF4B40569C6A2DCC6A4B406094A0BFD0FF4B4006F69848696A4B408FFCC1C073FF4B4006F69848696A4B40
63409	58098	55.986665000000002	56.004308000000002	54.837674	54.819097999999997	Центральная	0103000020E61000000100000005000000CE8DE9094BFE4B40081C0934D8684B40CE8DE9094BFE4B40D15AD1E6386B4B403B8E1F2A8D004C40D15AD1E6386B4B403B8E1F2A8D004C40081C0934D8684B40CE8DE9094BFE4B40081C0934D8684B40
63574	6717	55.706543000000003	55.724896000000001	54.673178999999998	54.665703000000001	60-летия СССР	0103000020E61000000100000005000000DF1B430070DA4B40AFEC82C135554B40DF1B430070DA4B404FADBEBA2A564B4028806264C9DC4B404FADBEBA2A564B4028806264C9DC4B40AFEC82C135554B40DF1B430070DA4B40AFEC82C135554B40
64388	4343	53.514645000000002	53.541567000000001	54.608660999999998	54.598429000000003	Уфимская	0103000020E6100000010000000500000064062AE3DFC14A402FFD4B52994C4B4064062AE3DFC14A40E2AC889AE84D4B40E2CB441152C54A40E2AC889AE84D4B40E2CB441152C54A402FFD4B52994C4B4064062AE3DFC14A402FFD4B52994C4B40
66052	6156	53.844056999999999	53.862634	54.636432999999997	54.633234000000002	Пушкина	0103000020E61000000100000005000000DD7A4D0F0AEC4A408E5BCCCF0D514B40DD7A4D0F0AEC4A402E8CF4A276514B40763579CA6AEE4A402E8CF4A276514B40763579CA6AEE4A408E5BCCCF0D514B40DD7A4D0F0AEC4A408E5BCCCF0D514B40
65493	58556	53.718786999999999	53.737561999999997	54.341825	54.33466	 Центральная	0103000020E610000001000000050000001DE5603601DC4A40C2A38D23D62A4B401DE5603601DC4A4044FAEDEBC02B4B40DC627E6E68DE4A4044FAEDEBC02B4B40DC627E6E68DE4A40C2A38D23D62A4B401DE5603601DC4A40C2A38D23D62A4B40
66031	5309	53.404260000000001	53.434722000000001	54.377495000000003	54.364545999999997	Школьная	0103000020E610000001000000050000005D8AABCABEB34A409DF17D71A92E4B405D8AABCABEB34A40A7B393C151304B40056D72F8A4B74A40A7B393C151304B40056D72F8A4B74A409DF17D71A92E4B405D8AABCABEB34A409DF17D71A92E4B40
65198	5663	54.209347999999999	54.229371	54.551600999999998	54.537796999999998	Социалистическая	0103000020E61000000100000005000000D3BD4EEACB1A4B4086713788D6444B40D3BD4EEACB1A4B406FB88FDC9A464B404ED367075C1D4B406FB88FDC9A464B404ED367075C1D4B4086713788D6444B40D3BD4EEACB1A4B4086713788D6444B40
64063	3858	54.045917000000003	54.079425000000001	54.655042000000002	54.637459999999997	Центральная	0103000020E610000001000000050000004CAAB69BE0054B400B410E4A98514B404CAAB69BE0054B40D3C08F6AD8534B400EBE30992A0A4B40D3C08F6AD8534B400EBE30992A0A4B400B410E4A98514B404CAAB69BE0054B400B410E4A98514B40
63314	2300	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Советская	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
66618	2300	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Пугачева	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63543	2300	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Островского	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63717	2300	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Луначарского	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
66717	2300	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Лесовода Морозова	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63302	2300	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Комарова	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
63325	2300	53.661518999999998	53.753712999999998	54.628355999999997	54.587713999999998	Гагарина	0103000020E61000000100000005000000605793A7ACD44A405FB35C363A4B4B40605793A7ACD44A40681F2BF86D504B40F7C8E6AA79E04A40681F2BF86D504B40F7C8E6AA79E04A405FB35C363A4B4B40605793A7ACD44A405FB35C363A4B4B40
65503	6364	53.913308000000001	53.942836	54.697338999999999	54.683320000000002	Лесная	0103000020E610000001000000050000006C96CB46E7F44A40F3599E0777574B406C96CB46E7F44A40D89C836742594B40E8BE9CD9AEF84A40D89C836742594B40E8BE9CD9AEF84A40F3599E0777574B406C96CB46E7F44A40F3599E0777574B40
65199	6091	53.882047	53.906427000000001	54.632040000000003	54.616210000000002	Ленина	0103000020E61000000100000005000000784485EAE6F04A40EDBB22F8DF4E4B40784485EAE6F04A40C6E1CCAFE6504B400F9BC8CC05F44A40C6E1CCAFE6504B400F9BC8CC05F44A40EDBB22F8DF4E4B40784485EAE6F04A40EDBB22F8DF4E4B40
63480	49199	53.790498999999997	53.822038999999997	54.560617999999998	54.552165000000002	Школьная	0103000020E61000000100000005000000A6423C122FE54A40787FBC57AD464B40A6423C122FE54A4043C6A354C2474B40AD84EE9238E94A4043C6A354C2474B40AD84EE9238E94A40787FBC57AD464B40A6423C122FE54A40787FBC57AD464B40
63506	49199	53.790498999999997	53.822038999999997	54.560617999999998	54.552165000000002	Черняева	0103000020E61000000100000005000000A6423C122FE54A40787FBC57AD464B40A6423C122FE54A4043C6A354C2474B40AD84EE9238E94A4043C6A354C2474B40AD84EE9238E94A40787FBC57AD464B40A6423C122FE54A40787FBC57AD464B40
63454	5887	53.594900000000003	53.621462999999999	54.554707000000001	54.538736999999998	Гаражная	0103000020E61000000100000005000000F931E6AE25CC4A4094128255F5444B40F931E6AE25CC4A405FEE93A300474B4047567E198CCF4A405FEE93A300474B4047567E198CCF4A4094128255F5444B40F931E6AE25CC4A4094128255F5444B40
65612	4711	54.035694999999997	54.066676999999999	54.549610999999999	54.538048000000003	Центральная	0103000020E61000000100000005000000BBD05CA791044B40D0D6C1C1DE444B40BBD05CA791044B40CC423BA759464B409C3237DF88084B40CC423BA759464B409C3237DF88084B40D0D6C1C1DE444B40BBD05CA791044B40D0D6C1C1DE444B40
63491	5758	53.784885000000003	53.81541	54.430039000000001	54.418405	площадь Советская	0103000020E610000001000000050000007C0F971C77E44A40CFBD874B8E354B407C0F971C77E44A40958098840B374B406A6AD95A5FE84A40958098840B374B406A6AD95A5FE84A40CFBD874B8E354B407C0F971C77E44A40CFBD874B8E354B40
63494	5758	53.784885000000003	53.81541	54.430039000000001	54.418405	Ленина	0103000020E610000001000000050000007C0F971C77E44A40CFBD874B8E354B407C0F971C77E44A40958098840B374B406A6AD95A5FE84A40958098840B374B406A6AD95A5FE84A40CFBD874B8E354B407C0F971C77E44A40CFBD874B8E354B40
63476	5758	53.784885000000003	53.81541	54.430039000000001	54.418405	21-ый квартал	0103000020E610000001000000050000007C0F971C77E44A40CFBD874B8E354B407C0F971C77E44A40958098840B374B406A6AD95A5FE84A40958098840B374B406A6AD95A5FE84A40CFBD874B8E354B407C0F971C77E44A40CFBD874B8E354B40
64386	5636	54.180250999999998	54.207614	54.487113000000001	54.469081000000003	Советская	0103000020E610000001000000050000002009FB7612174B406616A1D80A3C4B402009FB7612174B406D3A02B8593E4B408B187618931A4B406D3A02B8593E4B408B187618931A4B406616A1D80A3C4B402009FB7612174B406616A1D80A3C4B40
64264	6587	53.698861999999998	53.717089000000001	54.640216000000002	54.627084000000004	Гагарина	0103000020E6100000010000000500000065355D4F74D94A4025ECDB4944504B4065355D4F74D94A401F300F99F2514B4022A98592C9DB4A401F300F99F2514B4022A98592C9DB4A4025ECDB4944504B4065355D4F74D94A4025ECDB4944504B40
63495	6061	53.789726999999999	53.801431999999998	54.577523999999997	54.568165999999998	Первомайская	0103000020E6100000010000000500000054E23AC615E54A407D59DAA9B9484B4054E23AC615E54A40DA53724EEC494B40E3FBE25295E64A40DA53724EEC494B40E3FBE25295E64A407D59DAA9B9484B4054E23AC615E54A407D59DAA9B9484B40
66168	58720	53.864026000000003	53.879756	54.526313999999999	54.512836999999998	Центральная	0103000020E6100000010000000500000065726A6798EE4A40E1968FA4A4414B4065726A6798EE4A40A6B6D4415E434B40DA3A38D89BF04A40A6B6D4415E434B40DA3A38D89BF04A40E1968FA4A4414B4065726A6798EE4A40E1968FA4A4414B40
66433	58775	53.384163999999998	54.355513000000002	54.797055999999998	54.265000999999998	Центральная	0103000020E61000000100000005000000782634492CB14A402234828DEB214B40782634492CB14A40508A56EE05664B40C4263273812D4B40508A56EE05664B40C4263273812D4B402234828DEB214B40782634492CB14A402234828DEB214B40
64573	58278	53.729486000000001	53.752096000000002	54.498413999999997	54.480826	Зеленая	0103000020E61000000100000005000000E77118CC5FDD4A408388D4B48B3D4B40E77118CC5FDD4A402CEFAA07CC3F4B40E9B985AE44E04A402CEFAA07CC3F4B40E9B985AE44E04A408388D4B48B3D4B40E77118CC5FDD4A408388D4B48B3D4B40
63671	5342	53.659461999999998	53.714528999999999	54.350757000000002	54.330832999999998	Ленина	0103000020E61000000100000005000000357A354069D44A4002B859BC582A4B40357A354069D44A40EAEBF99AE52C4B409485AFAF75DB4A40EAEBF99AE52C4B409485AFAF75DB4A4002B859BC582A4B40357A354069D44A4002B859BC582A4B40
63330	5342	53.659461999999998	53.714528999999999	54.350757000000002	54.330832999999998	Гагарина	0103000020E61000000100000005000000357A354069D44A4002B859BC582A4B40357A354069D44A40EAEBF99AE52C4B409485AFAF75DB4A40EAEBF99AE52C4B409485AFAF75DB4A4002B859BC582A4B40357A354069D44A4002B859BC582A4B40
65102	5022	54.110658999999998	54.134860000000003	54.315851000000002	54.30171	Чапаева	0103000020E610000001000000050000000801F9122A0E4B402670EB6E9E264B400801F9122A0E4B4057B439CE6D284B40F0C4AC1743114B4057B439CE6D284B40F0C4AC1743114B402670EB6E9E264B400801F9122A0E4B402670EB6E9E264B40
66208	30197	53.832926999999998	53.847487999999998	54.639350999999998	54.634714000000002	Коммунистическая	0103000020E610000001000000050000004A7A185A9DEA4A401C28F04E3E514B404A7A185A9DEA4A401BD5E940D6514B4050E09D7C7AEC4A401BD5E940D6514B4050E09D7C7AEC4A401C28F04E3E514B404A7A185A9DEA4A401C28F04E3E514B40
66039	5571	53.913739	53.929900000000004	54.484869000000003	54.469771999999999	Клубная	0103000020E61000000100000005000000350A4966F5F44A40CB49287D213C4B40350A4966F5F44A4010ECF82F103E4B40744694F606F74A4010ECF82F103E4B40744694F606F74A40CB49287D213C4B40350A4966F5F44A40CB49287D213C4B40
65645	5229	53.417222000000002	53.435367999999997	54.345697999999999	54.335290000000001	Школьная	0103000020E61000000100000005000000FB95CE8767B54A40825660C8EA2A4B40FB95CE8767B54A40742502D53F2C4B40CADC7C23BAB74A40742502D53F2C4B40CADC7C23BAB74A40825660C8EA2A4B40FB95CE8767B54A40825660C8EA2A4B40
64106	4921	54.043734000000001	54.072130000000001	54.361224999999997	54.340806999999998	Ленина	0103000020E6100000010000000500000094DC611399054B40BA9F53909F2B4B4094DC611399054B40B1BFEC9E3C2E4B40BE874B8E3B094B40B1BFEC9E3C2E4B40BE874B8E3B094B40BA9F53909F2B4B4094DC611399054B40BA9F53909F2B4B40
66044	5507	53.999268000000001	54.039161999999997	54.502361000000001	54.485444000000001	Озерная	0103000020E610000001000000050000003CF88903E8FF4A400C056C07233E4B403CF88903E8FF4A4097E4805D4D404B407B9FAA4203054B4097E4805D4D404B407B9FAA4203054B400C056C07233E4B403CF88903E8FF4A400C056C07233E4B40
64173	4790	54.084904000000002	54.119435000000003	54.519092999999998	54.507112999999997	Молодежная	0103000020E6100000010000000500000059A65F22DE0A4B402F302B14E9404B4059A65F22DE0A4B40904AB1A371424B40B77F65A5490F4B40904AB1A371424B40B77F65A5490F4B402F302B14E9404B4059A65F22DE0A4B402F302B14E9404B40
63686	4490	54.083556999999999	54.135767000000001	54.565102000000003	54.536130999999997	Мира	0103000020E610000001000000050000000A2DEBFEB10A4B4096AFCBF09F444B400A2DEBFEB10A4B40BD73284355484B40227024D060114B40BD73284355484B40227024D060114B4096AFCBF09F444B400A2DEBFEB10A4B4096AFCBF09F444B40
63692	4490	54.083556999999999	54.135767000000001	54.565102000000003	54.536130999999997	Матросова	0103000020E610000001000000050000000A2DEBFEB10A4B4096AFCBF09F444B400A2DEBFEB10A4B40BD73284355484B40227024D060114B40BD73284355484B40227024D060114B4096AFCBF09F444B400A2DEBFEB10A4B4096AFCBF09F444B40
63568	4490	54.083556999999999	54.135767000000001	54.565102000000003	54.536130999999997	Крупской	0103000020E610000001000000050000000A2DEBFEB10A4B4096AFCBF09F444B400A2DEBFEB10A4B40BD73284355484B40227024D060114B40BD73284355484B40227024D060114B4096AFCBF09F444B400A2DEBFEB10A4B4096AFCBF09F444B40
63550	4490	54.083556999999999	54.135767000000001	54.565102000000003	54.536130999999997	Вострецова	0103000020E610000001000000050000000A2DEBFEB10A4B4096AFCBF09F444B400A2DEBFEB10A4B40BD73284355484B40227024D060114B40BD73284355484B40227024D060114B4096AFCBF09F444B400A2DEBFEB10A4B4096AFCBF09F444B40
65696	5097	54.057172999999999	54.094138999999998	54.321413	54.304758	Центральная	0103000020E610000001000000050000006B9BE27151074B40E198654F02274B406B9BE27151074B402FC1A90F24294B409A232BBF0C0C4B402FC1A90F24294B409A232BBF0C0C4B40E198654F02274B406B9BE27151074B40E198654F02274B40
64103	4372	53.642654999999998	53.659157	54.705537999999997	54.691510999999998	Школьная	0103000020E6100000010000000500000031CEDF8442D24A4081E9B46E83584B4031CEDF8442D24A40E90AB6114F5A4B40F9F6AE415FD44A40E90AB6114F5A4B40F9F6AE415FD44A4081E9B46E83584B4031CEDF8442D24A4081E9B46E83584B40
64524	4264	53.561428999999997	53.587462000000002	54.645432	54.632337999999997	Советская	0103000020E610000001000000050000005303CDE7DCC74A404F029B73F0504B405303CDE7DCC74A405CE509849D524B4046D26EF431CB4A405CE509849D524B4046D26EF431CB4A404F029B73F0504B405303CDE7DCC74A404F029B73F0504B40
64222	4825	54.156491000000003	54.192324999999997	54.595512999999997	54.572032999999998	Даутова	0103000020E61000000100000005000000268FA7E507144B40CB9D996038494B40268FA7E507144B40E2AB1DC5394C4B40029A081B9E184B40E2AB1DC5394C4B40029A081B9E184B40CB9D996038494B40268FA7E507144B40CB9D996038494B40
64636	3902	54.222158	54.260596999999997	54.655417	54.639116999999999	Центральная	0103000020E61000000100000005000000BB4560AC6F1C4B40A8A8FA95CE514B40BB4560AC6F1C4B40081F4AB4E4534B40C537143E5B214B40081F4AB4E4534B40C537143E5B214B40A8A8FA95CE514B40BB4560AC6F1C4B40A8A8FA95CE514B40
62326	1381	53.769145999999999	53.785541000000002	54.554211000000002	54.544325999999998	Клубная	0103000020E61000000100000005000000B3EC496073E24A40662E7079AC454B40B3EC496073E24A40AF0AD462F0464B406555849B8CE44A40AF0AD462F0464B406555849B8CE44A40662E7079AC454B40B3EC496073E24A40662E7079AC454B40
63324	4222	53.682817999999997	53.709677999999997	54.532124000000003	54.517760000000003	Школьная	0103000020E61000000100000005000000608F899466D74A40A796ADF545424B40608F899466D74A4057B5A4A31C444B4068588CBAD6DA4A4057B5A4A31C444B4068588CBAD6DA4A40A796ADF545424B40608F899466D74A40A796ADF545424B40
65201	6298	53.955331000000001	53.974079000000003	54.649250000000002	54.635187999999999	Центральная	0103000020E6100000010000000500000070ED444948FA4A40E46723D74D514B4070ED444948FA4A40C976BE9F1A534B40365CE49EAEFC4A40C976BE9F1A534B40365CE49EAEFC4A40E46723D74D514B4070ED444948FA4A40E46723D74D514B40
64129	3947	53.693697	53.722712999999999	54.486469999999997	54.469425999999999	Победы	0103000020E61000000100000005000000AA2A3410CBD84A4030F2B226163C4B40AA2A3410CBD84A40183E22A6443E4B4070B20DDC81DC4A40183E22A6443E4B4070B20DDC81DC4A4030F2B226163C4B40AA2A3410CBD84A4030F2B226163C4B40
64267	4119	53.757837000000002	53.808008000000001	54.353554000000003	54.337941000000001	Базарная	0103000020E61000000100000005000000715985CD00E14A40207D93A6412B4B40715985CD00E14A405CAFE941412D4B4004745FCE6CE74A405CAFE941412D4B4004745FCE6CE74A40207D93A6412B4B40715985CD00E14A40207D93A6412B4B40
65488	58555	54.164144999999998	54.203086999999996	54.680222999999998	54.65699	Гагарина	0103000020E61000000100000005000000A5660FB402154B4047E6913F18544B40A5660FB402154B40567E198C11574B40129F3BC1FE194B40567E198C11574B40129F3BC1FE194B4047E6913F18544B40A5660FB402154B4047E6913F18544B40
65200	6206	53.877609	53.909823000000003	54.593389999999999	54.583232000000002	Центральная	0103000020E610000001000000050000006FD6E07D55F04A4087FD9E58A74A4B406FD6E07D55F04A4000E31934F44B4B4006137F1475F44A4000E31934F44B4B4006137F1475F44A4087FD9E58A74A4B406FD6E07D55F04A4087FD9E58A74A4B40
64199	6471	53.764088999999998	53.771867999999998	54.628757	54.621752000000001	Комарова	0103000020E61000000100000005000000DE1D19ABCDE14A407E1CCD91954F4B40DE1D19ABCDE14A40C710001C7B504B401A6A1492CCE24A40C710001C7B504B401A6A1492CCE24A407E1CCD91954F4B40DE1D19ABCDE14A407E1CCD91954F4B40
66181	2194	53.631982999999998	53.660603000000002	54.775396999999998	54.758875000000003	Центральная	0103000020E610000001000000050000006150A6D1E4D04A404260E5D022614B406150A6D1E4D04A4050357A3540634B40DB519CA38ED44A4050357A3540634B40DB519CA38ED44A404260E5D022614B406150A6D1E4D04A404260E5D022614B40
65087	2130	55.728264000000003	55.759318999999998	56.146157000000002	56.131782000000001	Центральная	0103000020E61000000100000005000000556D37C137DD4B40CA198A3BDE104C40556D37C137DD4B406E8AC745B5124C409F1D705D31E14B406E8AC745B5124C409F1D705D31E14B40CA198A3BDE104C40556D37C137DD4B40CA198A3BDE104C40
65195	142	55.883502	55.902951000000002	56.362386999999998	56.351613999999998	Центральная	0103000020E61000000100000005000000ADF9F19716F14B406A6803B0012D4C40ADF9F19716F14B406EBF7CB2622E4C40FC71FBE593F34B406EBF7CB2622E4C40FC71FBE593F34B406A6803B0012D4C40ADF9F19716F14B406A6803B0012D4C40
64332	1944	55.481515000000002	55.518849000000003	56.162365999999999	56.144405999999996	Центральная	0103000020E6100000010000000500000048C49448A2BD4B404FAC53E57B124C4048C49448A2BD4B40BDFDB968C8144C40FA47DFA469C24B40BDFDB968C8144C40FA47DFA469C24B404FAC53E57B124C4048C49448A2BD4B404FAC53E57B124C40
65452	32227	55.635953000000001	55.661034000000001	56.147019	56.131756000000003	Ленина	0103000020E6100000010000000500000084656CE866D14B40A1866F61DD104C4084656CE866D14B400072C284D1124C40A4C519C39CD44B400072C284D1124C40A4C519C39CD44B40A1866F61DD104C4084656CE866D14B40A1866F61DD104C40
65192	1887	55.863163999999998	55.885362000000001	56.261857999999997	56.247456	Центральная	0103000020E61000000100000005000000D28A6F287CEE4B40789961A3AC1F4C40D28A6F287CEE4B4015191D9084214C40828FC18A53F14B4015191D9084214C40828FC18A53F14B40789961A3AC1F4C40D28A6F287CEE4B40789961A3AC1F4C40
66473	58792	55.324354999999997	56.204982000000001	56.455936000000001	56.069203000000002	Центральная	0103000020E61000000100000005000000A4A5F27684A94B407EE4D6A4DB084C40A4A5F27684A94B40D788601C5C3A4C406422A5D93C1A4C40D788601C5C3A4C406422A5D93C1A4C407EE4D6A4DB084C40A4A5F27684A94B407EE4D6A4DB084C40
66383	58762	55.324354999999997	56.204982000000001	56.455936000000001	56.069203000000002	Дружбы	0103000020E61000000100000005000000A4A5F27684A94B407EE4D6A4DB084C40A4A5F27684A94B40D788601C5C3A4C406422A5D93C1A4C40D788601C5C3A4C406422A5D93C1A4C407EE4D6A4DB084C40A4A5F27684A94B407EE4D6A4DB084C40
66019	1205	55.474041	55.499526000000003	56.259887999999997	56.243724999999998	Центральная	0103000020E6100000010000000500000048FB1F60ADBC4B40DA1B7C61321F4C4048FB1F60ADBC4B40B94F8E0244214C4038C0CC77F0BF4B40B94F8E0244214C4038C0CC77F0BF4B40DA1B7C61321F4C4048FB1F60ADBC4B40DA1B7C61321F4C40
66493	58803	56.146375999999997	56.164163000000002	56.249791999999999	56.238621999999999	Центральная	0103000020E61000000100000005000000AB75E272BC124C40950D6B2A8B1E4C40AB75E272BC124C40B6662B2FF91F4C404C1B0E4B03154C40B6662B2FF91F4C404C1B0E4B03154C40950D6B2A8B1E4C40AB75E272BC124C40950D6B2A8B1E4C40
66889	215	55.656956000000001	55.675713000000002	56.335929	56.327845000000003	М.Джалиля	0103000020E610000001000000050000009B745B2217D44B401D9430D3F6294C409B745B2217D44B409563B2B8FF2A4C40B43D7AC37DD64B409563B2B8FF2A4C40B43D7AC37DD64B401D9430D3F6294C409B745B2217D44B401D9430D3F6294C40
66359	58752	55.752302999999998	55.776612	56.42933	56.423555	Лесная	0103000020E6100000010000000500000062D7F6764BE04B405587DC0C37364C4062D7F6764BE04B4089981249F4364C4030D7A20568E34B4089981249F4364C4030D7A20568E34B405587DC0C37364C4062D7F6764BE04B405587DC0C37364C40
64257	605	56.024430000000002	56.048864000000002	56.174073999999997	56.163845000000002	Советская	0103000020E610000001000000050000004985B18520034C407B4E7ADFF8144C404985B18520034C40BD8A8C0E48164C40D3F9F02C41064C40BD8A8C0E48164C40D3F9F02C41064C407B4E7ADFF8144C404985B18520034C407B4E7ADFF8144C40
65446	31766	55.728290999999999	55.759768000000001	56.381779000000002	56.363852999999999	Центральная	0103000020E610000001000000050000004E7CB5A338DD4B4097C62FBC922E4C404E7CB5A338DD4B4059A65F22DE304C400F46EC1340E14B4059A65F22DE304C400F46EC1340E14B4097C62FBC922E4C404E7CB5A338DD4B4097C62FBC922E4C40
66199	19032	55.583140999999998	55.60727	56.131616000000001	56.116162000000003	Центральная	0103000020E6100000010000000500000076FA415DA4CA4B40DC847B65DE0E4C4076FA415DA4CA4B40AFD007CBD8104C40C4EBFA05BBCD4B40AFD007CBD8104C40C4EBFA05BBCD4B40DC847B65DE0E4C4076FA415DA4CA4B40DC847B65DE0E4C40
65928	662	55.918599	55.938226999999998	56.166651000000002	56.153557999999997	Центральная	0103000020E61000000100000005000000B491EBA694F54B400305DEC9A7134C40B491EBA694F54B40406CE9D154154C40B29C84D217F84B40406CE9D154154C40B29C84D217F84B400305DEC9A7134C40B491EBA694F54B400305DEC9A7134C40
65304	1319	55.596606999999999	55.612031000000002	56.108984	56.098030000000001	Центральная	0103000020E6100000010000000500000047C8409E5DCC4B4071033E3F8C0C4C4047C8409E5DCC4B40C5E40D30F30D4C40B091240857CE4B40C5E40D30F30D4C40B091240857CE4B4071033E3F8C0C4C4047C8409E5DCC4B4071033E3F8C0C4C40
65898	46175	55.577958000000002	55.593705999999997	56.105395000000001	56.101272999999999	Ленина	0103000020E61000000100000005000000153B1A87FAC94B40E17B7F83F60C4C40153B1A87FAC94B40BA1457957D0D4C4030B8E68EFECB4B40BA1457957D0D4C4030B8E68EFECB4B40E17B7F83F60C4C40153B1A87FAC94B40E17B7F83F60C4C40
64848	31031	55.6965	55.723934	56.350617	56.335850000000001	Центарльная	0103000020E61000000100000005000000FED478E926D94B40492EFF21FD2A4C40FED478E926D94B40F8359204E12C4C40323B8BDEA9DC4B40F8359204E12C4C40323B8BDEA9DC4B40492EFF21FD2A4C40FED478E926D94B40492EFF21FD2A4C40
64989	58429	55.991686000000001	56.015411	56.221238999999997	56.211162999999999	М.Гарипова	0103000020E6100000010000000500000056F31C91EFFE4B400890A163071B4C4056F31C91EFFE4B40C4CC3E8F511C4C40D47FD6FCF8014C40C4CC3E8F511C4C40D47FD6FCF8014C400890A163071B4C4056F31C91EFFE4B400890A163071B4C40
66029	1720	56.149411999999998	56.173369999999998	56.296489000000001	56.283324999999998	Парковая	0103000020E61000000100000005000000A2D0B2EE1F134C40D1915CFE43244C40A2D0B2EE1F134C40D74FFF59F3254C40C30DF8FC30164C40D74FFF59F3254C40C30DF8FC30164C40D1915CFE43244C40A2D0B2EE1F134C40D1915CFE43244C40
65900	1142	55.603119999999997	55.620251000000003	56.273375000000001	56.262901999999997	Фрунзе	0103000020E6100000010000000500000021C8410933CD4B40C806D2C5A6214C4021C8410933CD4B40A245B6F3FD224C40D927806264CF4B40A245B6F3FD224C40D927806264CF4B40C806D2C5A6214C4021C8410933CD4B40C806D2C5A6214C40
65945	791	55.933484	55.963397999999998	56.285358000000002	56.269621000000001	Арманшина	0103000020E610000001000000050000006DAB59677CF74B404CA8E0F082224C406DAB59677CF74B4074D3669C86244C4012842BA050FB4B4074D3669C86244C4012842BA050FB4B404CA8E0F082224C406DAB59677CF74B404CA8E0F082224C40
66489	58801	55.629584000000001	55.644793	56.367403000000003	56.353214999999999	Центральная	0103000020E61000000100000005000000DD0A613596D04B4073BA2C26362D4C40DD0A613596D04B40E5B9BE0F072F4C4049D8B79388D24B40E5B9BE0F072F4C4049D8B79388D24B4073BA2C26362D4C40DD0A613596D04B4073BA2C26362D4C40
65187	2000	55.558123000000002	55.589834000000003	56.178502999999999	56.161273000000001	Октябрьская	0103000020E610000001000000050000009D12109370C74B40295DFA97A4144C409D12109370C74B40739EB12FD9164C40D10836AE7FCB4B40739EB12FD9164C40D10836AE7FCB4B40295DFA97A4144C409D12109370C74B40295DFA97A4144C40
64042	282	55.827294999999999	55.875723000000001	56.303750999999998	56.280226999999996	Строителей	0103000020E61000000100000005000000799274CDE4E94B40643A747ADE234C40799274CDE4E94B404B901150E1264C4071ADF6B017F04B404B901150E1264C4071ADF6B017F04B40643A747ADE234C40799274CDE4E94B40643A747ADE234C40
62325	282	55.827294999999999	55.875723000000001	56.303750999999998	56.280226999999996	Советская	0103000020E61000000100000005000000799274CDE4E94B40643A747ADE234C40799274CDE4E94B404B901150E1264C4071ADF6B017F04B404B901150E1264C4071ADF6B017F04B40643A747ADE234C40799274CDE4E94B40643A747ADE234C40
63329	282	55.827294999999999	55.875723000000001	56.303750999999998	56.280226999999996	Ленина	0103000020E61000000100000005000000799274CDE4E94B40643A747ADE234C40799274CDE4E94B404B901150E1264C4071ADF6B017F04B404B901150E1264C4071ADF6B017F04B40643A747ADE234C40799274CDE4E94B40643A747ADE234C40
64201	282	55.827294999999999	55.875723000000001	56.303750999999998	56.280226999999996	Комсомольская	0103000020E61000000100000005000000799274CDE4E94B40643A747ADE234C40799274CDE4E94B404B901150E1264C4071ADF6B017F04B404B901150E1264C4071ADF6B017F04B40643A747ADE234C40799274CDE4E94B40643A747ADE234C40
65955	940	55.682935000000001	55.709454000000001	56.293142000000003	56.278063000000003	Хайдарова	0103000020E610000001000000050000009A25016A6AD74B40249D819197234C409A25016A6AD74B40C28A53AD85254C4019028063CFDA4B40C28A53AD85254C4019028063CFDA4B40249D819197234C409A25016A6AD74B40249D819197234C40
64336	28945	55.763002	55.802151000000002	56.335225999999999	56.321167000000003	Ленина	0103000020E610000001000000050000002C64AE0CAAE14B40F8C610001C294C402C64AE0CAAE14B406B6281AFE82A4C4013BA4BE2ACE64B406B6281AFE82A4C4013BA4BE2ACE64B40F8C610001C294C402C64AE0CAAE14B40F8C610001C294C40
65196	47331	55.879002	55.900354999999998	56.427961000000003	56.410857999999998	Школьная	0103000020E610000001000000050000002E8F352383F04B4065A6B4FE96344C402E8F352383F04B40537B116DC7364C4021E527D53EF34B40537B116DC7364C4021E527D53EF34B4065A6B4FE96344C402E8F352383F04B4065A6B4FE96344C40
64817	2198	55.687607	55.701441000000003	56.121983	56.111921000000002	Центральная	0103000020E6100000010000000500000016C0948103D84B40295E656D530E4C4016C0948103D84B4080D591239D0F4C406A8995D1C8D94B4080D591239D0F4C406A8995D1C8D94B40295E656D530E4C4016C0948103D84B40295E656D530E4C40
65985	32455	55.877626999999997	55.903094000000003	56.385586000000004	56.370434000000003	Матросова	0103000020E61000000100000005000000158BDF1456F04B40CAA99D616A2F4C40158BDF1456F04B40D2E5CDE15A314C405F9B8D9598F34B40D2E5CDE15A314C405F9B8D9598F34B40CAA99D616A2F4C40158BDF1456F04B40CAA99D616A2F4C40
65944	32315	55.504691999999999	55.525720999999997	56.353999000000002	56.343229000000001	Центральная	0103000020E61000000100000005000000C34659BF99C04B40F70489EDEE2B4C40C34659BF99C04B408AE8D7D64F2D4C4003E962D34AC34B408AE8D7D64F2D4C4003E962D34AC34B40F70489EDEE2B4C40C34659BF99C04B40F70489EDEE2B4C40
66853	27367	55.753669000000002	55.76735	56.257463000000001	56.238216999999999	Школьная	0103000020E610000001000000050000002881CD3978E04B40F52C08E57D1E4C402881CD3978E04B400C772E8CF4204C40F54A598638E24B400C772E8CF4204C40F54A598638E24B40F52C08E57D1E4C402881CD3978E04B40F52C08E57D1E4C40
64248	32242	55.580410999999998	55.616315999999998	56.370494000000001	56.355944000000001	Центральная	0103000020E610000001000000050000008C9E5BE84ACA4B408D9AAF928F2D4C408C9E5BE84ACA4B409FAEEE586C2F4C4032005471E3CE4B409FAEEE586C2F4C4032005471E3CE4B408D9AAF928F2D4C408C9E5BE84ACA4B408D9AAF928F2D4C40
65693	1483	55.449193999999999	55.464024999999999	56.268141	56.258443	Центральная	0103000020E610000001000000050000009BC761307FB94B40A87004A914214C409BC761307FB94B40BEDBBC7152224C4061C3D32B65BB4B40BEDBBC7152224C4061C3D32B65BB4B40A87004A914214C409BC761307FB94B40A87004A914214C40
64364	58215	55.417555	55.438692000000003	53.855069999999998	53.841774000000001	Молодежная	0103000020E6100000010000000500000001A4367172B54B40C24F1C40BFEB4A4001A4367172B54B4036E50AEF72ED4A402882380F27B84B4036E50AEF72ED4A402882380F27B84B40C24F1C40BFEB4A4001A4367172B54B40C24F1C40BFEB4A40
66697	58215	55.417555	55.438692000000003	53.855069999999998	53.841774000000001	Дружбы	0103000020E6100000010000000500000001A4367172B54B40C24F1C40BFEB4A4001A4367172B54B4036E50AEF72ED4A402882380F27B84B4036E50AEF72ED4A402882380F27B84B40C24F1C40BFEB4A4001A4367172B54B40C24F1C40BFEB4A40
66763	58874	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	Имая Насыри	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
67008	58911	55.419072999999997	55.436321	53.716372	53.704689999999999	 Южная	0103000020E610000001000000050000007CD11E2FA4B54B40BCE82B4833DA4A407CD11E2FA4B54B4093E2E313B2DB4A406DC7D45DD9B74B4093E2E313B2DB4A406DC7D45DD9B74B40BCE82B4833DA4A407CD11E2FA4B54B40BCE82B4833DA4A40
66770	30724	55.419072999999997	55.436321	53.716372	53.704689999999999	Степная	0103000020E610000001000000050000007CD11E2FA4B54B40BCE82B4833DA4A407CD11E2FA4B54B4093E2E313B2DB4A406DC7D45DD9B74B4093E2E313B2DB4A406DC7D45DD9B74B40BCE82B4833DA4A407CD11E2FA4B54B40BCE82B4833DA4A40
66942	58889	55.371479999999998	55.392699	53.905662999999997	53.896155999999998	Мира	0103000020E610000001000000050000001D8F19A88CAF4B409D0E643DB5F24A401D8F19A88CAF4B403F19E3C3ECF34A400116F9F543B24B403F19E3C3ECF34A400116F9F543B24B409D0E643DB5F24A401D8F19A88CAF4B409D0E643DB5F24A40
66730	31324	55.488683999999999	55.506281999999999	53.795985999999999	53.784410999999999	Ленина	0103000020E610000001000000050000000B0A83328DBE4B40B3CF639467E44A400B0A83328DBE4B40740987DEE2E54A40D8463CD9CDC04B40740987DEE2E54A40D8463CD9CDC04B40B3CF639467E44A400B0A83328DBE4B40B3CF639467E44A40
66525	58821	55.852510000000002	55.863352999999996	53.640439999999998	53.632517	Набережная	0103000020E61000000100000005000000A9C1340C1FED4B40FF942A51F6D04A40A9C1340C1FED4B406E861BF0F9D14A40A5F3E15982EE4B406E861BF0F9D14A40A5F3E15982EE4B40FF942A51F6D04A40A9C1340C1FED4B40FF942A51F6D04A40
66759	29282	56.120541000000003	56.135210000000001	53.747512	53.737580000000001	Шоссейная	0103000020E61000000100000005000000E06932E36D0F4C4083177D0569DE4A40E06932E36D0F4C400CAF2479AEDF4A40CC0BB08F4E114C400CAF2479AEDF4A40CC0BB08F4E114C4083177D0569DE4A40E06932E36D0F4C4083177D0569DE4A40
66922	32041	55.502544999999998	55.525371	53.741366999999997	53.725732999999998	Молодежная	0103000020E6100000010000000500000058E2016553C04B406150A6D1E4DC4A4058E2016553C04B40B4AA251DE5DE4A4027A25F5B3FC34B40B4AA251DE5DE4A4027A25F5B3FC34B406150A6D1E4DC4A4058E2016553C04B406150A6D1E4DC4A40
66941	58888	56.014736999999997	56.037472999999999	53.776276000000003	53.766734999999997	Центральная	0103000020E610000001000000050000004485EAE6E2014C406AD95A5F24E24A404485EAE6E2014C40B95510035DE34A40D3BD4EEACB044C40B95510035DE34A40D3BD4EEACB044C406AD95A5F24E24A404485EAE6E2014C406AD95A5F24E24A40
66619	32099	55.549579999999999	55.579053999999999	53.769570999999999	53.754646000000001	Мира	0103000020E6100000010000000500000091442FA358C64B405307793D98E04A4091442FA358C64B409A79724D81E24A401A4F04711ECA4B409A79724D81E24A401A4F04711ECA4B405307793D98E04A4091442FA358C64B405307793D98E04A40
66798	31918	55.598449000000002	55.662255999999999	53.473554999999998	53.447724999999998	Центральная	0103000020E6100000010000000500000076A911FA99CC4B40014D840D4FB94A4076A911FA99CC4B40BBED42739DBC4A4036CAFACDC4D44B40BBED42739DBC4A4036CAFACDC4D44B40014D840D4FB94A4076A911FA99CC4B40014D840D4FB94A40
66864	29563	55.777374999999999	55.810523000000003	53.768917000000002	53.747681999999998	Октябрьская	0103000020E610000001000000050000002FDD240681E34B4068E7340BB4DF4A402FDD240681E34B40522B4CDF6BE24A40F2D3B837BFE74B40522B4CDF6BE24A40F2D3B837BFE74B4068E7340BB4DF4A402FDD240681E34B4068E7340BB4DF4A40
66684	31626	56.000256	56.041632999999997	53.820549999999997	53.807673999999999	Мира	0103000020E610000001000000050000005BD07B6308004C402DEA93DC61E74A405BD07B6308004C40CC5D4BC807E94A4099B7EA3A54054C40CC5D4BC807E94A4099B7EA3A54054C402DEA93DC61E74A405BD07B6308004C402DEA93DC61E74A40
63665	58117	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	Водолаженко	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
66761	30687	55.629863	55.646211999999998	53.624502	53.610138999999997	Московская	0103000020E61000000100000005000000F0FACC599FD04B40CF81E50819CE4A40F0FACC599FD04B40AF2479AEEFCF4A4031242713B7D24B40AF2479AEEFCF4A4031242713B7D24B40CF81E50819CE4A40F0FACC599FD04B40CF81E50819CE4A40
66657	29622	55.730609000000001	55.763505000000002	53.791981	53.761242000000003	Первомайская	0103000020E61000000100000005000000E694809884DD4B40BB2BBB6070E14A40E694809884DD4B40D50627A25FE54A408FAA2688BAE14B40D50627A25FE54A408FAA2688BAE14B40BB2BBB6070E14A40E694809884DD4B40BB2BBB6070E14A40
66818	31737	55.736133000000002	55.793256999999997	53.677892	53.658468999999997	Центральная	0103000020E61000000100000005000000D1402C9B39DE4B40043752B648D44A40D1402C9B39DE4B402A1C412AC5D64A405A29047289E54B402A1C412AC5D64A405A29047289E54B40043752B648D44A40D1402C9B39DE4B40043752B648D44A40
66845	31677	55.917997	55.928686999999996	53.752330000000001	53.742980000000003	Лесная	0103000020E61000000100000005000000BE69FAEC80F54B4082CAF8F719DF4A40BE69FAEC80F54B405CE674594CE04A40349C3237DFF64B405CE674594CE04A40349C3237DFF64B4082CAF8F719DF4A40BE69FAEC80F54B4082CAF8F719DF4A40
66672	30581	55.710037	55.750767000000003	53.575166000000003	53.558936000000003	Молодежная	0103000020E6100000010000000500000098F90E7EE2DA4B404E4700378BC74A4098F90E7EE2DA4B40B5E21B0A9FC94A4041F50F2219E04B40B5E21B0A9FC94A4041F50F2219E04B404E4700378BC74A4098F90E7EE2DA4B404E4700378BC74A40
66900	29138	55.824832999999998	55.866047999999999	53.525418999999999	53.496572999999998	Центральная	0103000020E61000000100000005000000AED4B32094E94B40CE893DB48FBF4A40AED4B32094E94B4038D906EE40C34A4013622EA9DAEE4B4038D906EE40C34A4013622EA9DAEE4B40CE893DB48FBF4A40AED4B32094E94B40CE893DB48FBF4A40
66710	29995	55.931956999999997	56.165447	53.861060000000002	53.534550000000003	Центральная	0103000020E610000001000000050000009E23F25D4AF74B40D50968226CC44A409E23F25D4AF74B4067F2CD3637EE4A40541C075E2D154C4067F2CD3637EE4A40541C075E2D154C40D50968226CC44A409E23F25D4AF74B40D50968226CC44A40
66772	29995	55.931956999999997	56.165447	53.861060000000002	53.534550000000003	Мира	0103000020E610000001000000050000009E23F25D4AF74B40D50968226CC44A409E23F25D4AF74B4067F2CD3637EE4A40541C075E2D154C4067F2CD3637EE4A40541C075E2D154C40D50968226CC44A409E23F25D4AF74B40D50968226CC44A40
66673	31526	55.918644	55.940725	53.821283999999999	53.806659000000003	Центральная	0103000020E610000001000000050000005455682096F54B401503249A40E74A405455682096F54B40315D88D51FE94A40CAC342AD69F84B40315D88D51FE94A40CAC342AD69F84B401503249A40E74A405455682096F54B401503249A40E74A40
66709	58869	55.44914	55.459775999999998	53.870538000000003	53.859419000000003	Мира	0103000020E61000000100000005000000A8A9656B7DB94B40D047197101EE4A40A8A9656B7DB94B406FF607CA6DEF4A402BBEA1F0D9BA4B406FF607CA6DEF4A402BBEA1F0D9BA4B40D047197101EE4A40A8A9656B7DB94B40D047197101EE4A40
66930	29357	55.730671999999998	55.747165000000003	53.429519999999997	53.407297	Центральная	0103000020E610000001000000050000002C0DFCA886DD4B402461DF4E22B44A402C0DFCA886DD4B402C7DE882FAB64A40A1DB4B1AA3DF4B402C7DE882FAB64A40A1DB4B1AA3DF4B402461DF4E22B44A402C0DFCA886DD4B402461DF4E22B44A40
66837	29652	55.898764	55.922452999999997	53.711058999999999	53.695452000000003	Дружбы	0103000020E610000001000000050000003C69E1B20AF34B400AF8359204D94A403C69E1B20AF34B40634337FB03DB4A406D8C9DF012F64B40634337FB03DB4A406D8C9DF012F64B400AF8359204D94A403C69E1B20AF34B400AF8359204D94A40
66791	30909	55.887194000000001	55.907254000000002	53.599907999999999	53.587141000000003	Школьная	0103000020E610000001000000050000008D9AAF928FF14B400492B06F27CB4A408D9AAF928FF14B40EC4D0CC9C9CC4A40259529E620F44B40EC4D0CC9C9CC4A40259529E620F44B400492B06F27CB4A408D9AAF928FF14B400492B06F27CB4A40
66778	29451	55.824545999999998	55.846330000000002	53.474262000000003	53.461708999999999	Центральная	0103000020E6100000010000000500000018062CB98AE94B406AA2CF4719BB4A4018062CB98AE94B4027DE019EB4BC4A40D5CF9B8A54EC4B4027DE019EB4BC4A40D5CF9B8A54EC4B406AA2CF4719BB4A4018062CB98AE94B406AA2CF4719BB4A40
65655	30524	55.546993000000001	55.592547000000003	53.539563999999999	53.515937999999998	Нижняя	0103000020E610000001000000050000000A12DBDD03C64B40BF61A2410AC24A400A12DBDD03C64B40AA0CE36E10C54A40E52B8194D8CB4B40AA0CE36E10C54A40E52B8194D8CB4B40BF61A2410AC24A400A12DBDD03C64B40BF61A2410AC24A40
66612	30201	55.884625	55.928840000000001	53.532387999999997	53.506743999999998	Студенческая	0103000020E61000000100000005000000AC1C5A643BF14B40DCB8C5FCDCC04A40AC1C5A643BF14B4034643C4A25C44A40BB9BA73AE4F64B4034643C4A25C44A40BB9BA73AE4F64B40DCB8C5FCDCC04A40AC1C5A643BF14B40DCB8C5FCDCC04A40
66890	30201	55.884625	55.928840000000001	53.532387999999997	53.506743999999998	Ленина	0103000020E61000000100000005000000AC1C5A643BF14B40DCB8C5FCDCC04A40AC1C5A643BF14B4034643C4A25C44A40BB9BA73AE4F64B4034643C4A25C44A40BB9BA73AE4F64B40DCB8C5FCDCC04A40AC1C5A643BF14B40DCB8C5FCDCC04A40
66614	29475	55.799069000000003	55.812257000000002	53.401198999999998	53.387205999999999	Сухайлинская	0103000020E61000000100000005000000AC1F9BE447E64B40516859F78FB14A40AC1F9BE447E64B400D18247D5AB34A403A799109F8E74B400D18247D5AB34A403A799109F8E74B40516859F78FB14A40AC1F9BE447E64B40516859F78FB14A40
66747	31401	55.525730000000003	55.537281999999998	53.867676000000003	53.863512999999998	Полевая	0103000020E610000001000000050000005743E21E4BC34B40DE550F9887EE4A405743E21E4BC34B4016C3D50110EF4A405F5D15A8C5C44B4016C3D50110EF4A405F5D15A8C5C44B40DE550F9887EE4A405743E21E4BC34B40DE550F9887EE4A40
66836	31000	55.828741000000001	55.861763000000003	53.661996000000002	53.644038000000002	Молодежная	0103000020E610000001000000050000005BED612F14EA4B40CDB051D66FD24A405BED612F14EA4B409A0AF148BCD44A4091F3FE3F4EEE4B409A0AF148BCD44A4091F3FE3F4EEE4B40CDB051D66FD24A405BED612F14EA4B40CDB051D66FD24A40
66746	31000	55.828741000000001	55.861763000000003	53.661996000000002	53.644038000000002	Лазурная	0103000020E610000001000000050000005BED612F14EA4B40CDB051D66FD24A405BED612F14EA4B409A0AF148BCD44A4091F3FE3F4EEE4B409A0AF148BCD44A4091F3FE3F4EEE4B40CDB051D66FD24A405BED612F14EA4B40CDB051D66FD24A40
66903	30096	55.458258000000001	55.489977000000003	53.608280000000001	53.600138000000001	Молодежная	0103000020E61000000100000005000000B090B932A8BA4B401E8B6D52D1CC4A40B090B932A8BA4B40CB67791EDCCD4A406765FB90B7BE4B40CB67791EDCCD4A406765FB90B7BE4B401E8B6D52D1CC4A40B090B932A8BA4B401E8B6D52D1CC4A40
66816	31816	55.652706999999999	55.691477999999996	53.687742	53.673310999999998	Мира	0103000020E61000000100000005000000656F29E78BD34B40BE840A0E2FD64A40656F29E78BD34B40F60A0BEE07D84A40A5F3E15982D84B40F60A0BEE07D84A40A5F3E15982D84B40BE840A0E2FD64A40656F29E78BD34B40BE840A0E2FD64A40
66921	58885	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	Степная	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
66866	29815	55.999529000000003	56.007344000000003	53.705174999999997	53.698880000000003	Ленина	0103000020E61000000100000005000000A933F790F0FF4B400CEA5BE674D94A40A933F790F0FF4B40787AA52C43DA4A4032E9EFA5F0004C40787AA52C43DA4A4032E9EFA5F0004C400CEA5BE674D94A40A933F790F0FF4B400CEA5BE674D94A40
66849	29761	55.373483999999998	55.386212999999998	53.776871999999997	53.752643999999997	Мира	0103000020E6100000010000000500000025CADE52CEAF4B40EBC37AA356E04A4025CADE52CEAF4B40CC96AC8A70E34A402025766D6FB14B40CC96AC8A70E34A402025766D6FB14B40EBC37AA356E04A4025CADE52CEAF4B40EBC37AA356E04A40
66737	30807	55.646535999999998	55.658070000000002	53.559871999999999	53.555410999999999	Трудовая	0103000020E61000000100000005000000E4D70FB1C1D24B40596B28B517C74A40E4D70FB1C1D24B401AF9BCE2A9C74A40473D44A33BD44B401AF9BCE2A9C74A40473D44A33BD44B40596B28B517C74A40E4D70FB1C1D24B40596B28B517C74A40
66724	283	55.854486999999999	55.888190999999999	53.747053999999999	53.729520999999998	Трудовая	0103000020E61000000100000005000000B7ED7BD45FED4B40635FB2F160DD4A40B7ED7BD45FED4B40492C29779FDF4A40FFCC203EB0F14B40492C29779FDF4A40FFCC203EB0F14B40635FB2F160DD4A40B7ED7BD45FED4B40635FB2F160DD4A40
66819	30483	55.931068000000003	55.943095999999997	53.452464999999997	53.440485000000002	Школьная	0103000020E61000000100000005000000132D793C2DF74B4075B0FECF61B84A40132D793C2DF74B40D5CA845FEAB94A40847EA65EB7F84B40D5CA845FEAB94A40847EA65EB7F84B4075B0FECF61B84A40132D793C2DF74B4075B0FECF61B84A40
66674	31598	55.946510000000004	55.991120000000002	53.811731000000002	53.801937000000002	Школьная	0103000020E6100000010000000500000022AB5B3D27F94B40E73922DFA5E64A4022AB5B3D27F94B401F1329CDE6E74A40AD342905DDFE4B401F1329CDE6E74A40AD342905DDFE4B40E73922DFA5E64A4022AB5B3D27F94B40E73922DFA5E64A40
9972	31850	55.500146000000001	55.572361999999998	53.431413999999997	53.410040000000002	Центральная	0103000020E61000000100000005000000D49CBCC804C04B40A306D3307CB44A40D49CBCC804C04B40AD84EE9238B74A4090BC732843C94B40AD84EE9238B74A4090BC732843C94B40A306D3307CB44A40D49CBCC804C04B40A306D3307CB44A40
66968	58900	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	Клубная	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
66919	58884	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	Фестивальная	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
66897	29165	56.130744999999997	56.144992999999999	53.723047999999999	53.711362999999999	Советская	0103000020E61000000100000005000000C98E8D40BC104C40CF4A5AF10DDB4A40C98E8D40BC104C4017B83CD68CDC4A40109370218F124C4017B83CD68CDC4A40109370218F124C40CF4A5AF10DDB4A40C98E8D40BC104C40CF4A5AF10DDB4A40
66661	31129	55.513800000000003	55.525424999999998	53.848089999999999	53.835515000000001	Дружбы	0103000020E61000000100000005000000A857CA32C4C14B40A228D027F2EA4A40A857CA32C4C14B4046088F368EEC4A401AC05B2041C34B4046088F368EEC4A401AC05B2041C34B40A228D027F2EA4A40A857CA32C4C14B40A228D027F2EA4A40
66529	58824	55.919874999999998	55.945602999999998	53.727682999999999	53.719479	Парковая	0103000020E6100000010000000500000039B4C876BEF54B4053944BE317DC4A4039B4C876BEF54B40766D6FB724DD4A40EFFFE38409F94B40766D6FB724DD4A40EFFFE38409F94B4053944BE317DC4A4039B4C876BEF54B4053944BE317DC4A40
66760	30840	55.775767000000002	55.792700000000004	53.563707000000001	53.551667000000002	Луговая	0103000020E61000000100000005000000742843554CE34B4027A435069DC64A40742843554CE34B405DC30C8D27C84A4005C58F3177E54B405DC30C8D27C84A4005C58F3177E54B4027A435069DC64A40742843554CE34B4027A435069DC64A40
66787	31957	55.582459	55.609578999999997	53.732354999999998	53.714917	40 лет Победы	0103000020E6100000010000000500000064213A048ECA4B405E2D776682DB4A4064213A048ECA4B40F20703CFBDDD4A4008AA46AF06CE4B40F20703CFBDDD4A4008AA46AF06CE4B405E2D776682DB4A4064213A048ECA4B405E2D776682DB4A40
66745	29535	55.767142999999997	55.809517	53.724736999999998	53.710500000000003	Советская	0103000020E610000001000000050000007B2DE8BD31E24B406DE7FBA9F1DA4A407B2DE8BD31E24B40BF99982EC4DC4A402C47C8409EE74B40BF99982EC4DC4A402C47C8409EE74B406DE7FBA9F1DA4A407B2DE8BD31E24B406DE7FBA9F1DA4A40
66650	30048	55.519297999999999	55.567394	53.666429000000001	53.650047999999998	Садовая	0103000020E6100000010000000500000069705B5B78C24B40446ADAC534D34A4069705B5B78C24B40910DA48B4DD54A402BF9D85DA0C84B40910DA48B4DD54A402BF9D85DA0C84B40446ADAC534D34A4069705B5B78C24B40446ADAC534D34A40
66859	29933	56.058205999999998	56.117738000000003	53.819837999999997	53.790210000000002	Ленина	0103000020E610000001000000050000002A37514B73074C40707CED9925E54A402A37514B73074C404F029B73F0E84A408CBFED09120F4C404F029B73F0E84A408CBFED09120F4C40707CED9925E54A402A37514B73074C40707CED9925E54A40
66789	29376	55.776791000000003	55.790939999999999	53.440973	53.429470999999999	Янаульская	0103000020E61000000100000005000000E06932E36DE34B404BCADDE7F8B64A40E06932E36DE34B40A2B5A2CD71B84A40938C9C853DE54B40A2B5A2CD71B84A40938C9C853DE54B404BCADDE7F8B64A40E06932E36DE34B404BCADDE7F8B64A40
66792	30133	55.381622	55.399571000000002	53.643743999999998	53.630814000000001	Дружбы	0103000020E6100000010000000500000091B75CFDD8B04B40F2ED5D83BED04A4091B75CFDD8B04B40847F113466D24A400BB77C2425B34B40847F113466D24A400BB77C2425B34B40F2ED5D83BED04A4091B75CFDD8B04B40F2ED5D83BED04A40
66624	29097	55.795845	55.818725000000001	53.495930000000001	53.474342999999998	Центральная	0103000020E61000000100000005000000B2D7BB3FDEE54B40130B7C45B7BC4A40B2D7BB3FDEE54B407A8D5DA27ABF4A4074B515FBCBE84B407A8D5DA27ABF4A4074B515FBCBE84B40130B7C45B7BC4A40B2D7BB3FDEE54B40130B7C45B7BC4A40
64062	58092	55.887490999999997	56.015715999999998	53.717587000000002	53.586081999999998	Садовая	0103000020E61000000100000005000000463F1A4E99F14B401B6327BC04CB4A40463F1A4E99F14B4073840CE4D9DB4A4010035DFB02024C4073840CE4D9DB4A4010035DFB02024C401B6327BC04CB4A40463F1A4E99F14B401B6327BC04CB4A40
64385	27667	54.831772999999998	54.859026999999998	53.341231000000001	53.319268999999998	Р.Кашапова	0103000020E610000001000000050000001059A489776A4B4035D07CCEDDA84A401059A489776A4B40D1B01875ADAB4A40C4B0C398F46D4B40D1B01875ADAB4A40C4B0C398F46D4B4035D07CCEDDA84A401059A489776A4B4035D07CCEDDA84A40
65602	29015	55.163826	55.185682	53.577278	53.552233999999999	Советская	0103000020E61000000100000005000000041E1840F8944B40A0DE8C9AAFC64A40041E1840F8944B40A359D93EE4C94A405ABA826DC4974B40A359D93EE4C94A405ABA826DC4974B40A0DE8C9AAFC64A40041E1840F8944B40A0DE8C9AAFC64A40
66615	1884	55.289355999999998	55.312578000000002	53.555058000000002	53.543722000000002	Лесная	0103000020E6100000010000000500000060730E9E09A54B40D00EB8AE98C54A4060730E9E09A54B400CB1FA230CC74A407CB94F8E02A84B400CB1FA230CC74A407CB94F8E02A84B40D00EB8AE98C54A4060730E9E09A54B40D00EB8AE98C54A40
65587	27855	55.241188999999999	55.257826000000001	53.387672999999999	53.363402999999998	Центральная	0103000020E61000000100000005000000D593F947DF9E4B40572250FD83AE4A40D593F947DF9E4B406745D4449FB14A407D073F7100A14B406745D4449FB14A407D073F7100A14B40572250FD83AE4A40D593F947DF9E4B40572250FD83AE4A40
66150	27838	54.599997999999999	54.615367999999997	53.324696000000003	53.306728999999997	Школьная	0103000020E610000001000000050000002CD505BCCC4C4B400DDE57E542A74A402CD505BCCC4C4B402E9276A38FA94A40A180ED60C44E4B402E9276A38FA94A40A180ED60C44E4B400DDE57E542A74A402CD505BCCC4C4B400DDE57E542A74A40
64408	27540	54.924515	54.968218	53.348559000000002	53.329832000000003	К.Маркса	0103000020E61000000100000005000000AAD4EC8156764B404F965AEF37AA4A40AAD4EC8156764B40FDDCD0949DAC4A4003B34291EE7B4B40FDDCD0949DAC4A4003B34291EE7B4B404F965AEF37AA4A40AAD4EC8156764B404F965AEF37AA4A40
65593	28932	55.196649999999998	55.218038999999997	53.525917	53.517110000000002	Школьная	0103000020E610000001000000050000001361C3D32B994B40A03715A930C24A401361C3D32B994B4089B48D3F51C34A405320B3B3E89B4B4089B48D3F51C34A405320B3B3E89B4B40A03715A930C24A401361C3D32B994B40A03715A930C24A40
63703	27759	55.234046999999997	55.286850000000001	53.448217999999997	53.42915	Школьная	0103000020E610000001000000050000000B5D8940F59D4B40098A1F63EEB64A400B5D8940F59D4B4040BD19355FB94A40C66D3480B7A44B4040BD19355FB94A40C66D3480B7A44B40098A1F63EEB64A400B5D8940F59D4B40098A1F63EEB64A40
63309	27759	55.234046999999997	55.286850000000001	53.448217999999997	53.42915	Комсомольская	0103000020E610000001000000050000000B5D8940F59D4B40098A1F63EEB64A400B5D8940F59D4B4040BD19355FB94A40C66D3480B7A44B4040BD19355FB94A40C66D3480B7A44B40098A1F63EEB64A400B5D8940F59D4B40098A1F63EEB64A40
63310	27759	55.234046999999997	55.286850000000001	53.448217999999997	53.42915	Карла Маркса	0103000020E610000001000000050000000B5D8940F59D4B40098A1F63EEB64A400B5D8940F59D4B4040BD19355FB94A40C66D3480B7A44B4040BD19355FB94A40C66D3480B7A44B40098A1F63EEB64A400B5D8940F59D4B40098A1F63EEB64A40
63713	27759	55.234046999999997	55.286850000000001	53.448217999999997	53.42915	К.Маркса	0103000020E610000001000000050000000B5D8940F59D4B40098A1F63EEB64A400B5D8940F59D4B4040BD19355FB94A40C66D3480B7A44B4040BD19355FB94A40C66D3480B7A44B40098A1F63EEB64A400B5D8940F59D4B40098A1F63EEB64A40
66297	58741	55.406793	55.438791000000002	53.258442000000002	53.253146999999998	Ворошилова	0103000020E61000000100000005000000F19E03CB11B44B404E0AF31E67A04A40F19E03CB11B44B40D8F4A0A014A14A40BB63B14D2AB84B40D8F4A0A014A14A40BB63B14D2AB84B404E0AF31E67A04A40F19E03CB11B44B404E0AF31E67A04A40
65375	48648	55.287111000000003	55.305121999999997	53.462876999999999	53.455660999999999	Центральная	0103000020E6100000010000000500000033A9A10DC0A44B400588821953BA4A4033A9A10DC0A44B400989B48D3FBB4A4022A5D93C0EA74B400989B48D3FBB4A4022A5D93C0EA74B400588821953BA4A4033A9A10DC0A44B400588821953BA4A40
66159	28878	55.435791000000002	55.452365	53.485135	53.478484999999999	Центральная	0103000020E610000001000000050000001172DEFFC7B74B40335019FF3EBD4A401172DEFFC7B74B408E9257E718BE4A40726DA818E7B94B408E9257E718BE4A40726DA818E7B94B40335019FF3EBD4A401172DEFFC7B74B40335019FF3EBD4A40
64575	58280	55.516692999999997	55.539752999999997	53.224438999999997	53.212560000000003	 Молодежная	0103000020E610000001000000050000003B8908FF22C24B400938842A359B4A403B8908FF22C24B403579CA6ABA9C4A407D7555A016C54B403579CA6ABA9C4A407D7555A016C54B400938842A359B4A403B8908FF22C24B400938842A359B4A40
9740	27655	54.809378000000002	54.838115000000002	53.302472000000002	53.292392	Центральная	0103000020E610000001000000050000000B0DC4B299674B4057CEDE196DA54A400B0DC4B299674B4055FA0967B7A64A40BEA4315A476B4B4055FA0967B7A64A40BEA4315A476B4B4057CEDE196DA54A400B0DC4B299674B4057CEDE196DA54A40
66162	28659	55.264876999999998	55.279663999999997	53.505758	53.499662999999998	Школьная	0103000020E61000000100000005000000363B527DE7A14B40B8020AF5F4BF4A40363B527DE7A14B405ED89AADBCC04A402CEFAA07CCA34B405ED89AADBCC04A402CEFAA07CCA34B40B8020AF5F4BF4A40363B527DE7A14B40B8020AF5F4BF4A40
65595	28202	55.419891	55.453164000000001	53.278584000000002	53.259977999999997	Советская	0103000020E610000001000000050000003F7100FDBEB54B40F9D687F546A14A403F7100FDBEB54B402D98F8A3A8A34A40BEDC274701BA4B402D98F8A3A8A34A40BEDC274701BA4B40F9D687F546A14A403F7100FDBEB54B40F9D687F546A14A40
64057	28731	55.350791999999998	55.385485000000003	53.594499999999996	53.572738999999999	Школьная	0103000020E6100000010000000500000066D993C0E6AC4B406612F5824FC94A4066D993C0E6AC4B406ABC749318CC4A409E0C8E9257B14B406ABC749318CC4A409E0C8E9257B14B406612F5824FC94A4066D993C0E6AC4B406612F5824FC94A40
64207	27975	55.253559000000003	55.286365000000004	53.301578999999997	53.289409999999997	Саубанова	0103000020E61000000100000005000000A14D0E9F74A04B4053910A630BA54A40A14D0E9F74A04B40871403249AA64A400ADCBA9BA7A44B40871403249AA64A400ADCBA9BA7A44B4053910A630BA54A40A14D0E9F74A04B4053910A630BA54A40
64118	27995	55.321893000000003	55.368875000000003	53.27496	53.261851999999998	Центральная	0103000020E61000000100000005000000DAE731CA33A94B403332C85D84A14A40DAE731CA33A94B40A5DAA7E331A34A40F0A7C64B37AF4B40A5DAA7E331A34A40F0A7C64B37AF4B403332C85D84A14A40DAE731CA33A94B403332C85D84A14A40
66270	28565	55.342761000000003	55.361716000000001	53.475313	53.464753999999999	Ленина	0103000020E6100000010000000500000011ACAA97DFAB4B40B4571F0F7DBB4A4011ACAA97DFAB4B408C2E6F0ED7BC4A405038BBB54CAE4B408C2E6F0ED7BC4A405038BBB54CAE4B40B4571F0F7DBB4A4011ACAA97DFAB4B40B4571F0F7DBB4A40
65346	24885	55.624284000000003	55.646607000000003	53.360543999999997	53.348134000000002	Парковая	0103000020E6100000010000000500000042B5C189E8CF4B401650A8A78FAC4A4042B5C189E8CF4B406F62484E26AE4A40AE2EA704C4D24B406F62484E26AE4A40AE2EA704C4D24B401650A8A78FAC4A4042B5C189E8CF4B401650A8A78FAC4A40
65672	24885	55.624284000000003	55.646607000000003	53.360543999999997	53.348134000000002	Коммунистическая	0103000020E6100000010000000500000042B5C189E8CF4B401650A8A78FAC4A4042B5C189E8CF4B406F62484E26AE4A40AE2EA704C4D24B406F62484E26AE4A40AE2EA704C4D24B401650A8A78FAC4A4042B5C189E8CF4B401650A8A78FAC4A40
66169	29026	55.115046999999997	55.125188999999999	53.555025999999998	53.542732000000001	Центральная	0103000020E610000001000000050000005F402FDCB98E4B40103FFF3D78C54A405F402FDCB98E4B4000378B170BC74A40D368723106904B4000378B170BC74A40D368723106904B40103FFF3D78C54A405F402FDCB98E4B40103FFF3D78C54A40
66151	28180	55.504700999999997	55.525630999999997	53.299329999999998	53.282547000000001	Заки Валиди	0103000020E6100000010000000500000016A1D80A9AC04B409D4A06802AA44A4016A1D80A9AC04B40185B087250A64A40C36169E047C34B40185B087250A64A40C36169E047C34B409D4A06802AA44A4016A1D80A9AC04B409D4A06802AA44A40
66652	46426	55.109558999999997	55.123311999999999	53.462088999999999	53.447864000000003	Оренбургский тракт	0103000020E61000000100000005000000C1FD8007068E4B402387889B53B94A40C1FD8007068E4B40B16B7BBB25BB4A40289A07B0C88F4B40B16B7BBB25BB4A40289A07B0C88F4B402387889B53B94A40C1FD8007068E4B402387889B53B94A40
64098	27753	54.677128000000003	54.710391999999999	53.317982999999998	53.293345000000002	Ленина	0103000020E610000001000000050000005B9A5B21AC564B40FAB836548CA54A405B9A5B21AC564B408CD7BCAAB3A84A4086AB0320EE5A4B408CD7BCAAB3A84A4086AB0320EE5A4B40FAB836548CA54A405B9A5B21AC564B40FAB836548CA54A40
64035	28313	55.346443999999998	55.367536999999999	53.368614999999998	53.345995000000002	Советская	0103000020E610000001000000050000009DF2E84658AC4B402ECA6C9049AC4A409DF2E84658AC4B4053E8BCC62EAF4A40F488D1730BAF4B4053E8BCC62EAF4A40F488D1730BAF4B402ECA6C9049AC4A409DF2E84658AC4B402ECA6C9049AC4A40
65419	27921	55.181047	55.216358999999997	53.348193000000002	53.335366	Российская	0103000020E61000000100000005000000FB04508C2C974B405D18E945EDAA4A40FB04508C2C974B401BD9959691AC4A40FE98D6A6B19B4B401BD9959691AC4A40FE98D6A6B19B4B405D18E945EDAA4A40FB04508C2C974B405D18E945EDAA4A40
66584	27921	55.181047	55.216358999999997	53.348193000000002	53.335366	Акчишма	0103000020E61000000100000005000000FB04508C2C974B405D18E945EDAA4A40FB04508C2C974B401BD9959691AC4A40FE98D6A6B19B4B401BD9959691AC4A40FE98D6A6B19B4B405D18E945EDAA4A40FB04508C2C974B405D18E945EDAA4A40
64302	27505	55.001005999999997	55.053584999999998	53.394401999999999	53.369135999999997	Молодежная	0103000020E61000000100000005000000C58CF0F620804B405CE333D93FAF4A40C58CF0F620804B400EBDC5C37BB24A4030478FDFDB864B400EBDC5C37BB24A4030478FDFDB864B405CE333D93FAF4A40C58CF0F620804B405CE333D93FAF4A40
63782	58130	58.633747999999997	58.701571000000001	52.741194	52.679406999999998	проспект Горняков	0103000020E61000000100000005000000E4F38AA71E514D4034D6FECEF6564A40E4F38AA71E514D40E7FEEA71DF5E4A4038691A14CD594D40E7FEEA71DF5E4A4038691A14CD594D4034D6FECEF6564A40E4F38AA71E514D4034D6FECEF6564A40
64852	58375	57.473655000000001	58.826419000000001	55.519626000000002	54.907536999999998	Школьная	0103000020E610000001000000050000001F4B1FBAA0BC4C407974232C2A744B401F4B1FBAA0BC4C405E13D21A83C24B4082E50819C8694D405E13D21A83C24B4082E50819C8694D407974232C2A744B401F4B1FBAA0BC4C407974232C2A744B40
65183	26170	58.347391999999999	58.385112999999997	55.281713000000003	55.264271000000001	Школьная	0103000020E610000001000000050000002E724F57772C4D40FF23D3A1D3A14B402E724F57772C4D40D5EDEC2B0FA44B40D921FE614B314D40D5EDEC2B0FA44B40D921FE614B314D40FF23D3A1D3A14B402E724F57772C4D40FF23D3A1D3A14B40
66366	58755	57.992998	58.008403999999999	55.133513999999998	55.124357000000003	Школьная	0103000020E61000000100000005000000287FF78E1AFF4C40AC0320EEEA8F4B40287FF78E1AFF4C4071C79BFC16914B40EA93DC6113014D4071C79BFC16914B40EA93DC6113014D40AC0320EEEA8F4B40287FF78E1AFF4C40AC0320EEEA8F4B40
65758	58622	58.155529999999999	58.199305000000003	55.456183000000003	55.442749999999997	Парт Мурзы	0103000020E6100000010000000500000000C63368E8134D40E9263108ACB84B4000C63368E8134D40DFFE5C3464BA4B40F37684D382194D40DFFE5C3464BA4B40F37684D382194D40E9263108ACB84B4000C63368E8134D40E9263108ACB84B40
66008	58683	58.090699000000001	58.116247000000001	55.296866999999999	55.290858999999998	Коммунаров	0103000020E61000000100000005000000D4635B069C0B4D40A65F22DE3AA54B40D4635B069C0B4D407D21E4BCFFA54B400AA1832EE10E4D407D21E4BCFFA54B400AA1832EE10E4D40A65F22DE3AA54B40D4635B069C0B4D40A65F22DE3AA54B40
65177	49014	58.408845999999997	58.441212	55.216180999999999	55.207926999999998	Центральная	0103000020E61000000100000005000000DA8CD31055344D404A7A185A9D9A4B40DA8CD31055344D401F82AAD1AB9B4B40274D83A279384D401F82AAD1AB9B4B40274D83A279384D404A7A185A9D9A4B40DA8CD31055344D404A7A185A9D9A4B40
65757	26252	58.511856000000002	58.529741000000001	55.151465999999999	55.138243000000003	Школьная	0103000020E610000001000000050000007521567F84414D4052F355F2B1914B407521567F84414D405C3AE63C63934B40D82C978DCE434D405C3AE63C63934B40D82C978DCE434D4052F355F2B1914B407521567F84414D4052F355F2B1914B40
64127	27168	57.696418999999999	57.722740000000002	55.487845999999998	55.456066	Центральная	0103000020E6100000010000000500000011A8FE4124D94C40A568E55E60BA4B4011A8FE4124D94C4001BEDBBC71BE4B406AC18BBE82DC4C4001BEDBBC71BE4B406AC18BBE82DC4C40A568E55E60BA4B4011A8FE4124D94C40A568E55E60BA4B40
64258	27288	58.252952000000001	58.263373000000001	55.339241999999999	55.327710000000003	Центральная	0103000020E6100000010000000500000099BA2BBB60204D403D49BA66F2A94B4099BA2BBB60204D40FEB627486CAB4B4020D3DA34B6214D40FEB627486CAB4B4020D3DA34B6214D403D49BA66F2A94B4099BA2BBB60204D403D49BA66F2A94B40
64514	27214	58.603555999999998	58.654921999999999	55.085884	55.070092000000002	Школьная	0103000020E61000000100000005000000FCA6B052414D4D400ADB4FC6F8884B40FCA6B052414D4D40F59F353FFE8A4B4028B7ED7BD4534D40F59F353FFE8A4B4028B7ED7BD4534D400ADB4FC6F8884B40FCA6B052414D4D400ADB4FC6F8884B40
66682	27132	57.832469000000003	57.868023999999998	55.478510999999997	55.461818999999998	Молодежная	0103000020E6100000010000000500000088F71C588EEA4C40F1D58EE21CBB4B4088F71C588EEA4C405CE333D93FBD4B40511212691BEF4C405CE333D93FBD4B40511212691BEF4C40F1D58EE21CBB4B4088F71C588EEA4C40F1D58EE21CBB4B40
65981	26618	58.087913999999998	58.124079999999999	55.414976000000003	55.398145	Центральная	0103000020E61000000100000005000000266E15C4400B4D407008556AF6B24B40266E15C4400B4D40FD4FFEEE1DB54B40390B7BDAE10F4D40FD4FFEEE1DB54B40390B7BDAE10F4D407008556AF6B24B40266E15C4400B4D407008556AF6B24B40
66038	16791	58.686577999999997	58.752271999999998	55.112164999999997	55.083657000000002	Советская	0103000020E610000001000000050000009813B4C9E1574D406E8AC745B58A4B409813B4C9E1574D40BF60376C5B8E4B4027D9EA724A604D40BF60376C5B8E4B4027D9EA724A604D406E8AC745B58A4B409813B4C9E1574D406E8AC745B58A4B40
65171	25658	58.130566000000002	58.149898	55.141506	55.131799999999998	Переулок Пришкольный	0103000020E610000001000000050000001AFCFD62B6104D4070CE88D2DE904B401AFCFD62B6104D4009185DDE1C924B402FDE8FDB2F134D4009185DDE1C924B402FDE8FDB2F134D4070CE88D2DE904B401AFCFD62B6104D4070CE88D2DE904B40
64274	26859	58.313229	58.342433999999997	55.174244000000002	55.161676999999997	Центральная	0103000020E6100000010000000500000053944BE317284D40F8C1F9D4B1944B4053944BE317284D401AC39CA04D964B40EC8497E0D42B4D401AC39CA04D964B40EC8497E0D42B4D40F8C1F9D4B1944B4053944BE317284D40F8C1F9D4B1944B40
62324	26799	58.542766999999998	58.586281	55.050674000000001	55.025951999999997	Пепеляева	0103000020E610000001000000050000008C2C996379454D4005A2276552834B408C2C996379454D40F660527C7C864B4012A27C410B4B4D40F660527C7C864B4012A27C410B4B4D4005A2276552834B408C2C996379454D4005A2276552834B40
65178	26003	57.966444000000003	57.997003999999997	54.945309000000002	54.936532999999997	Школьная	0103000020E610000001000000050000002DB5DE6FB4FB4C40F84F3750E0774B402DB5DE6FB4FB4C40A7CEA3E2FF784B4097FDBAD39DFF4C40A7CEA3E2FF784B4097FDBAD39DFF4C40F84F3750E0774B402DB5DE6FB4FB4C40F84F3750E0774B40
65578	26576	58.191544	58.220820000000003	55.430906	55.414414000000001	Ленина	0103000020E610000001000000050000005DDF878384184D40958098840BB54B405DDF878384184D4039D384ED27B74B40C0266BD4431C4D4039D384ED27B74B40C0266BD4431C4D40958098840BB54B405DDF878384184D40958098840BB54B40
63443	27009	58.146205999999999	58.186576000000002	55.194963999999999	55.166207	Коммунистическая	0103000020E610000001000000050000004F3DD2E0B6124D40E2AE5E4546954B404F3DD2E0B6124D40DCF29194F4984B40F81BEDB8E1174D40DCF29194F4984B40F81BEDB8E1174D40E2AE5E4546954B404F3DD2E0B6124D40E2AE5E4546954B40
64509	26191	58.529471999999998	58.571548999999997	55.204639	55.185111999999997	Советская	0103000020E61000000100000005000000E8120EBDC5434D406F0C01C0B1974B40E8120EBDC5434D403A3E5A9C319A4B40DF87838428494D403A3E5A9C319A4B40DF87838428494D406F0C01C0B1974B40E8120EBDC5434D406F0C01C0B1974B40
64387	26094	58.434241	58.455316000000003	55.274754000000001	55.250509999999998	Айская	0103000020E610000001000000050000008ACA863595374D4015A930B610A04B408ACA863595374D40FC389A232BA34B403BAC70CB473A4D40FC389A232BA34B403BAC70CB473A4D4015A930B610A04B408ACA863595374D4015A930B610A04B40
65561	25906	57.868456000000002	57.890877000000003	55.401370999999997	55.392940000000003	Центральная	0103000020E61000000100000005000000EB01F39029EF4C4027A5A0DB4BB24B40EB01F39029EF4C400A48FB1F60B34B401AE1ED4108F24C400A48FB1F60B34B401AE1ED4108F24C4027A5A0DB4BB24B40EB01F39029EF4C4027A5A0DB4BB24B40
65530	5566	58.130260999999997	58.143124	55.280374999999999	55.269455999999998	Школьная	0103000020E61000000100000005000000DD787764AC104D4001DBC1887DA24B40DD787764AC104D40D9CEF753E3A34B40E8A221E351124D40D9CEF753E3A34B40E8A221E351124D4001DBC1887DA24B40DD787764AC104D4001DBC1887DA24B40
64792	26783	58.475223	58.509932999999997	55.041961999999998	55.024538	Центральная	0103000020E610000001000000050000004CA7751BD43C4D402FC1A90F24834B404CA7751BD43C4D405ED6C4025F854B4059130B7C45414D405ED6C4025F854B4059130B7C45414D402FC1A90F24834B404CA7751BD43C4D402FC1A90F24834B40
64674	25945	58.015366	58.034114000000002	54.940793999999997	54.928064999999997	Молодежная	0103000020E6100000010000000500000034BC5983F7014D40F7C77BD5CA764B4034BC5983F7014D40F22213F06B784B40FA2AF9D85D044D40F22213F06B784B40FA2AF9D85D044D40F7C77BD5CA764B4034BC5983F7014D40F7C77BD5CA764B40
64614	27360	58.137546	58.149538	55.271410000000003	55.262542000000003	Школьная	0103000020E610000001000000050000000AD9791B9B114D40C9E9EBF99AA14B400AD9791B9B114D4058E71890BDA24B402FC1A90F24134D4058E71890BDA24B402FC1A90F24134D40C9E9EBF99AA14B400AD9791B9B114D40C9E9EBF99AA14B40
66557	58836	58.119273999999997	58.134751999999999	55.058306000000002	55.048063999999997	Молодежная	0103000020E61000000100000005000000ADA1D45E440F4D40B60E0EF626864B40ADA1D45E440F4D408E942D9276874B400989B48D3F114D408E942D9276874B400989B48D3F114D40B60E0EF626864B40ADA1D45E440F4D40B60E0EF626864B40
66507	58810	57.805177999999998	57.819389999999999	55.425863999999997	55.419584999999998	Центральная	0103000020E61000000100000005000000B6BA9C1210E74C40327216F6B4B54B40B6BA9C1210E74C40994528B682B64B40B05582C5E1E84C40994528B682B64B40B05582C5E1E84C40327216F6B4B54B40B6BA9C1210E74C40327216F6B4B54B40
65991	6362	58.222383000000001	58.239702000000001	55.400613999999997	55.374222000000003	Центральная	0103000020E61000000100000005000000DB17D00B771C4D40CCB8A981E6AF4B40DB17D00B771C4D40ED28CE5147B34B4095641D8EAE1E4D40ED28CE5147B34B4095641D8EAE1E4D40CCB8A981E6AF4B40DB17D00B771C4D40CCB8A981E6AF4B40
65792	30905	57.59093	57.599446	55.377864000000002	55.372298000000001	Школьная	0103000020E61000000100000005000000D61C2098A3CB4C40E02EFB75A7AF4B40D61C2098A3CB4C40FA2AF9D85DB04B40E8DB82A5BACC4C40FA2AF9D85DB04B40E8DB82A5BACC4C40E02EFB75A7AF4B40D61C2098A3CB4C40E02EFB75A7AF4B40
64673	25848	57.945979999999999	57.963937000000001	55.384982999999998	55.375070999999998	Школьная	0103000020E61000000100000005000000C55565DF15F94C40C956975302B04B40C55565DF15F94C400B42791F47B14B40C233A14962FB4C400B42791F47B14B40C233A14962FB4C40C956975302B04B40C55565DF15F94C40C956975302B04B40
65476	58550	58.042853999999998	58.081643999999997	55.328960000000002	55.317357999999999	Центральная	0103000020E610000001000000050000005B40683D7C054D40DE8FDB2F9FA84B405B40683D7C054D4099D87C5C1BAA4B4012F5824F730A4D4099D87C5C1BAA4B4012F5824F730A4D40DE8FDB2F9FA84B405B40683D7C054D40DE8FDB2F9FA84B40
63668	25815	57.911152000000001	57.937356000000001	55.409319000000004	55.389918000000002	Салавата Юлаева	0103000020E61000000100000005000000AED7F4A0A0F44C40950F41D5E8B14B40AED7F4A0A0F44C40D350A39064B44B40CD5A0A48FBF74C40D350A39064B44B40CD5A0A48FBF74C40950F41D5E8B14B40AED7F4A0A0F44C40950F41D5E8B14B40
64741	48807	58.064576000000002	58.092486000000001	55.095497999999999	55.080410999999998	Кольцевая	0103000020E61000000100000005000000A20DC00644084D408C9E5BE84A8A4B40A20DC00644084D40AD6A4947398C4B403FABCC94D60B4D40AD6A4947398C4B403FABCC94D60B4D408C9E5BE84A8A4B40A20DC00644084D408C9E5BE84A8A4B40
66362	58753	58.362797999999998	58.396574999999999	55.394561000000003	55.378565000000002	Школьная	0103000020E61000000100000005000000F086342A702E4D40833463D174B04B40F086342A702E4D4077A38FF980B24B40A2B437F8C2324D4077A38FF980B24B40A2B437F8C2324D40833463D174B04B40F086342A702E4D40833463D174B04B40
65584	25335	56.609943000000001	56.630766000000001	55.421306999999999	55.406221000000002	Садовая	0103000020E610000001000000050000004AB6BA9C124E4C4066F9BA0CFFB34B404AB6BA9C124E4C40B6494563EDB54B40E1B6B6F0BC504C40B6494563EDB54B40E1B6B6F0BC504C4066F9BA0CFFB34B404AB6BA9C124E4C4066F9BA0CFFB34B40
66598	24118	56.473281999999998	56.494177000000001	55.035921000000002	55.026705999999997	Центральная	0103000020E610000001000000050000008AE42B81943C4C40B14D2A1A6B834B408AE42B81943C4C40AC1E300F99844B40BBB72231413F4C40AC1E300F99844B40BBB72231413F4C40B14D2A1A6B834B408AE42B81943C4C40B14D2A1A6B834B40
65499	24413	56.628107	56.657831999999999	55.139097	55.113945999999999	Колхозная	0103000020E61000000100000005000000C0B167CF65504C4048C153C8958E4B40C0B167CF65504C4061FC34EECD914B409221C7D633544C4061FC34EECD914B409221C7D633544C4048C153C8958E4B40C0B167CF65504C4048C153C8958E4B40
66622	24465	56.652954000000001	56.685653000000002	55.111217000000003	55.097903000000002	Центральная	0103000020E610000001000000050000006DE525FF93534C401497E315888C4B406DE525FF93534C402FE1D05B3C8E4B40C0B33D7AC3574C402FE1D05B3C8E4B40C0B33D7AC3574C401497E315888C4B406DE525FF93534C401497E315888C4B40
65555	24936	56.582220999999997	56.602981	55.261685	55.244228999999997	Береговая	0103000020E61000000100000005000000AF05BD37864A4C400DDE57E5429F4B40AF05BD37864A4C40486DE2E47EA14B40008E3D7B2E4D4C40486DE2E47EA14B40008E3D7B2E4D4C400DDE57E5429F4B40AF05BD37864A4C400DDE57E5429F4B40
65548	24335	56.715980000000002	56.729858999999998	55.032975	55.024177000000002	Центральная	0103000020E61000000100000005000000884B8E3BA55B4C405F28603B18834B40884B8E3BA55B4C40F54A598638844B407BD80B056C5D4C40F54A598638844B407BD80B056C5D4C405F28603B18834B40884B8E3BA55B4C405F28603B18834B40
64582	25095	57.031235000000002	57.067067999999999	55.247163999999998	55.226903	Школьная	0103000020E61000000100000005000000CBBE2B82FF834C40A12E52280B9D4B40CBBE2B82FF834C40D05FE811A39F4B40D74D29AF95884C40D05FE811A39F4B40D74D29AF95884C40A12E52280B9D4B40CBBE2B82FF834C40A12E52280B9D4B40
64735	32552	56.530665999999997	56.575842999999999	55.429603999999998	55.409503000000001	Строителей	0103000020E61000000100000005000000B08C0DDDEC434C40944E24986AB44B40B08C0DDDEC434C408A1D8D43FDB64B40B5503239B5494C408A1D8D43FDB64B40B5503239B5494C40944E24986AB44B40B08C0DDDEC434C40944E24986AB44B40
64074	32552	56.530665999999997	56.575842999999999	55.429603999999998	55.409503000000001	Карла Маркса	0103000020E61000000100000005000000B08C0DDDEC434C40944E24986AB44B40B08C0DDDEC434C408A1D8D43FDB64B40B5503239B5494C408A1D8D43FDB64B40B5503239B5494C40944E24986AB44B40B08C0DDDEC434C40944E24986AB44B40
65551	25017	56.992679000000003	57.013987	55.150956999999998	55.137734000000002	Лесная	0103000020E610000001000000050000008736001B107F4C400DC68844A1914B408736001B107F4C40170D198F52934B40DAC87553CA814C40170D198F52934B40DAC87553CA814C400DC68844A1914B408736001B107F4C400DC68844A1914B40
63767	24311	56.598785999999997	56.637323000000002	55.097974999999998	55.066550999999997	Советская	0103000020E61000000100000005000000BDA60705A54C4C400F4240BE84884B40BDA60705A54C4C40AD69DE718A8C4B408BFED0CC93514C40AD69DE718A8C4B408BFED0CC93514C400F4240BE84884B40BDA60705A54C4C400F4240BE84884B40
66706	24825	56.621530999999997	56.639749000000002	55.247610999999999	55.234727999999997	Центральная	0103000020E610000001000000050000009F39EB538E4F4C404DBA2D910B9E4B409F39EB538E4F4C409F909DB7B19F4B400953944BE3514C409F909DB7B19F4B400953944BE3514C404DBA2D910B9E4B409F39EB538E4F4C404DBA2D910B9E4B40
66882	24205	56.548067000000003	56.584690999999999	55.069814000000001	55.055517000000002	Насретдинова	0103000020E610000001000000050000002882380F27464C409FAF592E1B874B402882380F27464C40C76647AAEF884B40FDA19927D74A4C40C76647AAEF884B40FDA19927D74A4C409FAF592E1B874B402882380F27464C409FAF592E1B874B40
66736	24961	56.779598999999997	56.827308000000002	55.196094000000002	55.178491000000001	Центральная	0103000020E61000000100000005000000457F68E6C9634C40AFD007CBD8964B40457F68E6C9634C408E78B29B19994B400EDC813AE5694C408E78B29B19994B400EDC813AE5694C40AFD007CBD8964B40457F68E6C9634C40AFD007CBD8964B40
65319	24232	56.569572000000001	56.591455000000003	55.010508999999999	55.003512999999998	Роодниковая	0103000020E61000000100000005000000D15B3CBCE7484C40300E2E1D73804B40D15B3CBCE7484C4026A8E15B58814B40210725CCB44B4C4026A8E15B58814B40210725CCB44B4C40300E2E1D73804B40D15B3CBCE7484C40300E2E1D73804B40
66847	23987	56.598292000000001	56.605432999999998	54.984718000000001	54.972230000000003	Парковая	0103000020E61000000100000005000000AEBA0ED5944C4C4055185B08727C4B40AEBA0ED5944C4C402AE44A3D0B7E4B40A7751BD47E4D4C402AE44A3D0B7E4B40A7751BD47E4D4C4055185B08727C4B40AEBA0ED5944C4C4055185B08727C4B40
64490	32533	56.611443000000001	56.684961000000001	55.397402999999997	55.370963000000003	Матросова	0103000020E610000001000000050000001F2FA4C3434E4C40568330B77BAF4B401F2FA4C3434E4C40882AFC19DEB24B408A0453CDAC574C40882AFC19DEB24B408A0453CDAC574C40568330B77BAF4B401F2FA4C3434E4C40568330B77BAF4B40
64406	24654	56.646262	56.692633000000001	55.215615999999997	55.178629999999998	Тукаева	0103000020E61000000100000005000000E35295B6B8524C40D00A0C59DD964B40E35295B6B8524C40463F1A4E999B4B40B090B932A8584C40463F1A4E999B4B40B090B932A8584C40D00A0C59DD964B40E35295B6B8524C40D00A0C59DD964B40
64615	24654	56.646262	56.692633000000001	55.215615999999997	55.178629999999998	Советская	0103000020E61000000100000005000000E35295B6B8524C40D00A0C59DD964B40E35295B6B8524C40463F1A4E999B4B40B090B932A8584C40463F1A4E999B4B40B090B932A8584C40D00A0C59DD964B40E35295B6B8524C40D00A0C59DD964B40
64242	24654	56.646262	56.692633000000001	55.215615999999997	55.178629999999998	Альмухаметова	0103000020E61000000100000005000000E35295B6B8524C40D00A0C59DD964B40E35295B6B8524C40463F1A4E999B4B40B090B932A8584C40463F1A4E999B4B40B090B932A8584C40D00A0C59DD964B40E35295B6B8524C40D00A0C59DD964B40
66227	46898	56.430154000000002	56.444840999999997	55.010523999999997	54.998122000000002	Интернациональная	0103000020E610000001000000050000002E1F49490F374C4085B53176C27F4B402E1F49490F374C405BE9B5D958814B40C075C58CF0384C405BE9B5D958814B40C075C58CF0384C4085B53176C27F4B402E1F49490F374C4085B53176C27F4B40
66800	24486	56.803080999999999	56.831781999999997	55.080942	55.070824000000002	Центральная	0103000020E61000000100000005000000FD84B35BCB664C40CEE2C5C210894B40FD84B35BCB664C40B96FB54E5C8A4B4063B323D5776A4C40B96FB54E5C8A4B4063B323D5776A4C40CEE2C5C210894B40FD84B35BCB664C40CEE2C5C210894B40
66779	24126	56.482337000000001	56.495479000000003	55.055093999999997	55.046470999999997	Мубарякова	0103000020E610000001000000050000004C530438BD3D4C40309B00C3F2854B404C530438BD3D4C40581AF8510D874B406A6D1ADB6B3F4C40581AF8510D874B406A6D1ADB6B3F4C40309B00C3F2854B404C530438BD3D4C40309B00C3F2854B40
65547	24592	56.743324999999999	56.757418999999999	55.165816	55.151487000000003	Школьная	0103000020E610000001000000050000004CA60A46255F4C4074620FED63934B404CA60A46255F4C40A7936C7539954B403C2F151BF3604C40A7936C7539954B403C2F151BF3604C4074620FED63934B404CA60A46255F4C4074620FED63934B40
66704	24062	56.492668000000002	56.518611	55.012335999999998	54.998499000000002	Свободы	0103000020E6100000010000000500000093E4B9BE0F3F4C405B0BB3D0CE7F4B4093E4B9BE0F3F4C401F48DE3994814B40452C62D861424C401F48DE3994814B40452C62D861424C405B0BB3D0CE7F4B4093E4B9BE0F3F4C405B0BB3D0CE7F4B40
66944	23949	56.434869999999997	56.452109	54.993994999999998	54.983612999999998	Школьная	0103000020E610000001000000050000007901F6D1A9374C40D175E107E77D4B407901F6D1A9374C409AB1683A3B7F4B40179D2CB5DE394C409AB1683A3B7F4B40179D2CB5DE394C40D175E107E77D4B407901F6D1A9374C40D175E107E77D4B40
65514	24560	56.713464999999999	56.733182999999997	55.150647999999997	55.139854	Советская	0103000020E610000001000000050000009AEB34D2525B4C407E1B62BCE6914B409AEB34D2525B4C40999A046F48934B40D87DC7F0D85D4C40999A046F48934B40D87DC7F0D85D4C407E1B62BCE6914B409AEB34D2525B4C407E1B62BCE6914B40
66148	23901	56.503295000000001	56.522661999999997	54.986542	54.974606999999999	Садовая	0103000020E61000000100000005000000C39E76F86B404C40F1B913ECBF7C4B40C39E76F86B404C40B2101D02477E4B40546EA296E6424C40B2101D02477E4B40546EA296E6424C40F1B913ECBF7C4B40C39E76F86B404C40F1B913ECBF7C4B40
66273	30681	57.212398	57.229680999999999	55.587234000000002	55.562300999999998	Коммунистическая	0103000020E610000001000000050000002FDE8FDB2F9B4C4009C1AA7AF9C74B402FDE8FDB2F9B4C40B58CD47B2ACB4B409CC1DF2F669D4C40B58CD47B2ACB4B409CC1DF2F669D4C4009C1AA7AF9C74B402FDE8FDB2F9B4C4009C1AA7AF9C74B40
66138	22391	54.553995999999998	54.576858000000001	53.447735999999999	53.433532999999997	Шоссейная	0103000020E61000000100000005000000B20E4757E9464B404E5E64027EB74A40B20E4757E9464B40F59ECA694FB94A40CE37A27BD6494B40F59ECA694FB94A40CE37A27BD6494B404E5E64027EB74A40B20E4757E9464B404E5E64027EB74A40
64809	21741	54.827801999999998	54.841124000000001	53.814995000000003	53.806716999999999	Центральная	0103000020E610000001000000050000001DC87A6AF5694B404910AE8042E74A401DC87A6AF5694B40A7B393C151E84A40BBF083F3A96B4B40A7B393C151E84A40BBF083F3A96B4B404910AE8042E74A401DC87A6AF5694B404910AE8042E74A40
64215	23805	55.129680999999998	55.158884999999998	53.635902000000002	53.620618999999998	Ленина	0103000020E61000000100000005000000CFF4126399904B405B23827170CF4A40CFF4126399904B4002BB9A3C65D14A409869FB5756944B4002BB9A3C65D14A409869FB5756944B405B23827170CF4A40CFF4126399904B405B23827170CF4A40
65444	23828	55.211787000000001	55.237200000000001	53.647427	53.633254000000001	Ленина	0103000020E61000000100000005000000E65B1FD61B9B4B40D50792770ED14A40E65B1FD61B9B4B4011C64FE3DED24A403C4ED1915C9E4B4011C64FE3DED24A403C4ED1915C9E4B40D50792770ED14A40E65B1FD61B9B4B40D50792770ED14A40
65035	22684	55.116762999999999	55.132078999999997	53.733623000000001	53.717554999999997	Полевая	0103000020E6100000010000000500000001310917F28E4B40670A9DD7D8DB4A4001310917F28E4B40F54BC45BE7DD4A4083BEF4F6E7904B40F54BC45BE7DD4A4083BEF4F6E7904B40670A9DD7D8DB4A4001310917F28E4B40670A9DD7D8DB4A40
65494	47503	54.450321000000002	54.464495999999997	53.566144999999999	53.556624999999997	 Первомайская	0103000020E61000000100000005000000DCD9571EA4394B406891ED7C3FC74A40DCD9571EA4394B409FE5797077C84A40B88FDC9A743B4B409FE5797077C84A40B88FDC9A743B4B406891ED7C3FC74A40DCD9571EA4394B406891ED7C3FC74A40
65099	23673	54.727676000000002	54.741528000000002	53.518774999999998	53.490236000000003	Центральная	0103000020E61000000100000005000000C40AB77C245D4B4033A9A10DC0BE4A40C40AB77C245D4B40BF7D1D3867C24A40BE88B663EA5E4B40BF7D1D3867C24A40BE88B663EA5E4B4033A9A10DC0BE4A40C40AB77C245D4B4033A9A10DC0BE4A40
66491	58802	54.740558	54.758201	53.691015999999998	53.671097000000003	 Садовая	0103000020E610000001000000050000004565C39ACA5E4B40CCB8A981E6D54A404565C39ACA5E4B40A181583673D84A40B265F9BA0C614B40A181583673D84A40B265F9BA0C614B40CCB8A981E6D54A404565C39ACA5E4B40CCB8A981E6D54A40
64765	58340	54.361117999999998	55.346362999999997	53.868901999999999	53.346725999999997	Молодежная	0103000020E610000001000000050000009BFF571D392E4B4021567F8461AC4A409BFF571D392E4B40E9B6442E38EF4A40B0C56E9F55AC4B40E9B6442E38EF4A40B0C56E9F55AC4B4021567F8461AC4A409BFF571D392E4B4021567F8461AC4A40
65549	48008	55.037002000000001	55.074686	53.698283000000004	53.684702999999999	Молодежная	0103000020E610000001000000050000007CF1457BBC844B408E3C1059A4D74A407CF1457BBC844B40282D5C5661D94A400ABC934F8F894B40282D5C5661D94A400ABC934F8F894B408E3C1059A4D74A407CF1457BBC844B408E3C1059A4D74A40
66255	23728	54.701273999999998	54.724235	53.553314	53.540768	Шевченко	0103000020E610000001000000050000007EC4AF58C3594B40965CC5E237C54A407EC4AF58C3594B40A0353FFED2C64A402DCF83BBB35C4B40A0353FFED2C64A402DCF83BBB35C4B40965CC5E237C54A407EC4AF58C3594B40965CC5E237C54A40
65560	58565	54.697816000000003	54.72296	53.664166999999999	53.647657000000002	Центральная	0103000020E610000001000000050000001250E10852594B404303B16CE6D24A401250E10852594B408D0A9C6C03D54A4078280AF4895C4B408D0A9C6C03D54A4078280AF4895C4B404303B16CE6D24A401250E10852594B404303B16CE6D24A40
66136	22751	54.837504000000003	54.855649999999997	53.500906000000001	53.478093999999999	Центральная	0103000020E610000001000000050000007522C154336B4B40F834272F32BD4A407522C154336B4B40622F14B01DC04A4044696FF0856D4B40622F14B01DC04A4044696FF0856D4B40F834272F32BD4A407522C154336B4B40F834272F32BD4A40
65025	22478	55.032932000000002	55.044215000000001	53.856912000000001	53.840159	Мира	0103000020E61000000100000005000000F67EA31D37844B40543882548AEB4A40F67EA31D37844B4065C6DB4AAFED4A400F7F4DD6A8854B4065C6DB4AAFED4A400F7F4DD6A8854B40543882548AEB4A40F67EA31D37844B40543882548AEB4A40
64256	22925	54.734467000000002	54.753250999999999	53.790390000000002	53.775658999999997	Коммунистическая	0103000020E61000000100000005000000E17EC003035E4B408DEC4ACB48E34A40E17EC003035E4B40F08AE07F2BE54A40F3565D876A604B40F08AE07F2BE54A40F3565D876A604B408DEC4ACB48E34A40E17EC003035E4B408DEC4ACB48E34A40
64036	22958	54.509124999999997	54.539406999999997	53.717955000000003	53.691197000000003	Шоссейная	0103000020E61000000100000005000000BA490C022B414B40F20BAF2479D84A40BA490C022B414B40F67F0EF3E5DB4A40E21DE0490B454B40F67F0EF3E5DB4A40E21DE0490B454B40F20BAF2479D84A40BA490C022B414B40F20BAF2479D84A40
65030	22134	54.941619000000003	54.970050000000001	53.520847000000003	53.505265999999999	Первомайская	0103000020E610000001000000050000006825ADF886784B40EFE3688EACC04A406825ADF886784B40209C4F1DABC24A400EBE30992A7C4B40209C4F1DABC24A400EBE30992A7C4B40EFE3688EACC04A406825ADF886784B40EFE3688EACC04A40
66147	23170	54.833120000000001	54.848841	53.557540000000003	53.548189000000001	Королева	0103000020E610000001000000050000005FD218ADA36A4B407383A10E2BC64A405FD218ADA36A4B401E1B81785DC74A40814067D2A66C4B401E1B81785DC74A40814067D2A66C4B407383A10E2BC64A405FD218ADA36A4B407383A10E2BC64A40
66141	22560	54.926617	54.94267	53.801760999999999	53.794182999999997	Демская	0103000020E610000001000000050000007575C7629B764B400305DEC9A7E54A407575C7629B764B40A81ABD1AA0E64A40CD751A69A9784B40A81ABD1AA0E64A40CD751A69A9784B400305DEC9A7E54A407575C7629B764B400305DEC9A7E54A40
66294	21990	54.487430000000003	54.503419999999998	53.560065000000002	53.553057000000003	Матросова	0103000020E610000001000000050000006E8B321B643E4B4075E95F92CAC64A406E8B321B643E4B402F51BD35B0C74A407F130A1170404B402F51BD35B0C74A407F130A1170404B4075E95F92CAC64A406E8B321B643E4B4075E95F92CAC64A40
64578	58281	54.864426000000002	54.890279999999997	53.472814999999997	53.461280000000002	Шоссейная	0103000020E61000000100000005000000F3E7DB82A56E4B40422619390BBB4A40F3E7DB82A56E4B407407B13385BC4A403524EEB1F4714B407407B13385BC4A403524EEB1F4714B40422619390BBB4A40F3E7DB82A56E4B40422619390BBB4A40
65534	58562	55.011021999999997	55.027937999999999	53.751019999999997	53.736221999999998	Центральная	0103000020E61000000100000005000000ACC43C2B69814B40404CC2853CDE4A40ACC43C2B69814B402A52616C21E04A406728EE7893834B402A52616C21E04A406728EE7893834B40404CC2853CDE4A40ACC43C2B69814B40404CC2853CDE4A40
64465	22822	54.694248999999999	54.725788999999999	53.747874000000003	53.731209999999997	Советская	0103000020E61000000100000005000000EE23B726DD584B400B410E4A98DD4A40EE23B726DD584B40ADC3D155BADF4A40F56569A7E65C4B40ADC3D155BADF4A40F56569A7E65C4B400B410E4A98DD4A40EE23B726DD584B400B410E4A98DD4A40
64113	23213	54.782428000000003	54.819536999999997	53.648018999999998	53.620533999999999	Шоссейная	0103000020E61000000100000005000000C3BCC79926644B402D077AA86DCF4A40C3BCC79926644B40E3175E49F2D24A40546EA296E6684B40E3175E49F2D24A40546EA296E6684B402D077AA86DCF4A40C3BCC79926644B402D077AA86DCF4A40
64037	23213	54.782428000000003	54.819536999999997	53.648018999999998	53.620533999999999	Советская	0103000020E61000000100000005000000C3BCC79926644B402D077AA86DCF4A40C3BCC79926644B40E3175E49F2D24A40546EA296E6684B40E3175E49F2D24A40546EA296E6684B402D077AA86DCF4A40C3BCC79926644B402D077AA86DCF4A40
63418	23213	54.782428000000003	54.819536999999997	53.648018999999998	53.620533999999999	Ленина	0103000020E61000000100000005000000C3BCC79926644B402D077AA86DCF4A40C3BCC79926644B40E3175E49F2D24A40546EA296E6684B40E3175E49F2D24A40546EA296E6684B402D077AA86DCF4A40C3BCC79926644B402D077AA86DCF4A40
64033	23213	54.782428000000003	54.819536999999997	53.648018999999998	53.620533999999999	Калинина	0103000020E61000000100000005000000C3BCC79926644B402D077AA86DCF4A40C3BCC79926644B40E3175E49F2D24A40546EA296E6684B40E3175E49F2D24A40546EA296E6684B402D077AA86DCF4A40C3BCC79926644B402D077AA86DCF4A40
63822	23213	54.782428000000003	54.819536999999997	53.648018999999998	53.620533999999999	Губайдуллина	0103000020E61000000100000005000000C3BCC79926644B402D077AA86DCF4A40C3BCC79926644B40E3175E49F2D24A40546EA296E6684B40E3175E49F2D24A40546EA296E6684B402D077AA86DCF4A40C3BCC79926644B402D077AA86DCF4A40
64243	23213	54.782428000000003	54.819536999999997	53.648018999999998	53.620533999999999	Абдуллина	0103000020E61000000100000005000000C3BCC79926644B402D077AA86DCF4A40C3BCC79926644B40E3175E49F2D24A40546EA296E6684B40E3175E49F2D24A40546EA296E6684B402D077AA86DCF4A40C3BCC79926644B402D077AA86DCF4A40
65472	22888	54.702306999999998	54.735069000000003	53.722861999999999	53.708553999999999	Советская	0103000020E610000001000000050000003D601E32E5594B4099B9C0E5B1DA4A403D601E32E5594B40B5C2F4BD86DC4A40D7A6B1BD165E4B40B5C2F4BD86DC4A40D7A6B1BD165E4B4099B9C0E5B1DA4A403D601E32E5594B4099B9C0E5B1DA4A40
65442	22545	54.918424000000002	54.938384999999997	53.773935000000002	53.762391000000001	Школьная	0103000020E6100000010000000500000046EEE9EA8E754B40E3E13D0796E14A4046EEE9EA8E754B40691D554D10E34A404A07EBFF1C784B40691D554D10E34A404A07EBFF1C784B40E3E13D0796E14A4046EEE9EA8E754B40E3E13D0796E14A40
65166	21939	54.562359000000001	54.5976	53.671374	53.655591999999999	Советская	0103000020E610000001000000050000003ECE3461FB474B4076C24B70EAD34A403ECE3461FB474B403EB14E95EFD54A40780B24287E4C4B403EB14E95EFD54A40780B24287E4C4B4076C24B70EAD34A403ECE3461FB474B4076C24B70EAD34A40
65948	22345	54.465242000000003	54.484797999999998	53.442737000000001	53.436267999999998	Ш. Бабича	0103000020E61000000100000005000000E25CC30C8D3B4B404A253CA1D7B74A40E25CC30C8D3B4B4055DD239BABB84A40469561DC0D3E4B4055DD239BABB84A40469561DC0D3E4B404A253CA1D7B74A40E25CC30C8D3B4B404A253CA1D7B74A40
65929	22423	54.989939	55.013770999999998	53.829543000000001	53.816622000000002	Советская	0103000020E6100000010000000500000079043752B67E4B40D998D71187E84A4079043752B67E4B4018D00B772EEA4A400D51853FC3814B4018D00B772EEA4A400D51853FC3814B40D998D71187E84A4079043752B67E4B40D998D71187E84A40
64523	22311	54.610534999999999	54.643664999999999	53.442255000000003	53.415692	Дружбы	0103000020E610000001000000050000001C08C902264E4B40BB9A3C6535B54A401C08C902264E4B400ABFD4CF9BB84A40384A5E9D63524B400ABFD4CF9BB84A40384A5E9D63524B40BB9A3C6535B54A401C08C902264E4B40BB9A3C6535B54A40
66863	1139	54.827595000000002	54.842975000000003	53.619525000000003	53.607837000000004	Центральная	0103000020E61000000100000005000000A4AA09A2EE694B403E26529ACDCD4A40A4AA09A2EE694B40F7065F984CCF4A403D2CD49AE66B4B40F7065F984CCF4A403D2CD49AE66B4B403E26529ACDCD4A40A4AA09A2EE694B403E26529ACDCD4A40
65101	22221	54.506726	54.521836	53.628143999999999	53.619160999999998	Центральная	0103000020E610000001000000050000003604C765DC404B40B5FAEAAA40CF4A403604C765DC404B40DD96C80567D04A400FF0A485CB424B40DD96C80567D04A400FF0A485CB424B40B5FAEAAA40CF4A403604C765DC404B40B5FAEAAA40CF4A40
65293	46164	54.926957999999999	54.932698000000002	53.554747999999996	53.550077999999999	Молодежная	0103000020E61000000100000005000000FE614B8FA6764B40E21FB6F468C64A40FE614B8FA6764B40BDC282FB01C74A40B685E7A562774B40BDC282FB01C74A40B685E7A562774B40E21FB6F468C64A40FE614B8FA6764B40E21FB6F468C64A40
65925	22092	54.99991	55.026868999999998	53.507894999999998	53.492769000000003	Советская	0103000020E61000000100000005000000C078060DFD7F4B40C7BDF90D13BF4A40C078060DFD7F4B40A5660FB402C14A405B23827170834B40A5660FB402C14A405B23827170834B40C7BDF90D13BF4A40C078060DFD7F4B40C7BDF90D13BF4A40
65062	47711	54.546008999999998	54.561425	53.628650999999998	53.615358000000001	Ленина	0103000020E610000001000000050000002C29779FE3454B407EAA0A0DC4CE4A402C29779FE3454B4081CCCEA277D04A4012143FC6DC474B4081CCCEA277D04A4012143FC6DC474B407EAA0A0DC4CE4A402C29779FE3454B407EAA0A0DC4CE4A40
65307	45714	54.880038999999996	54.898446	53.749636000000002	53.734858000000003	Школьная	0103000020E610000001000000050000002E1A321EA5704B401C9AB2D30FDE4A402E1A321EA5704B40BFF38B12F4DF4A406B9C4D4700734B40BFF38B12F4DF4A406B9C4D4700734B401C9AB2D30FDE4A402E1A321EA5704B401C9AB2D30FDE4A40
65749	58620	54.744213999999999	54.774037999999997	53.461756999999999	53.446331000000001	Мира	0103000020E61000000100000005000000D89C8367425F4B407218CC5F21B94A40D89C8367425F4B407BD976DA1ABB4A403DEE5BAD13634B407BD976DA1ABB4A403DEE5BAD13634B407218CC5F21B94A40D89C8367425F4B407218CC5F21B94A40
64586	58284	54.361117999999998	55.346362999999997	53.868901999999999	53.346725999999997	Центральная	0103000020E610000001000000050000009BFF571D392E4B4021567F8461AC4A409BFF571D392E4B40E9B6442E38EF4A40B0C56E9F55AC4B40E9B6442E38EF4A40B0C56E9F55AC4B4021567F8461AC4A409BFF571D392E4B4021567F8461AC4A40
65437	18898	55.963614	55.983907000000002	55.417005000000003	55.407009000000002	Ленина	0103000020E61000000100000005000000DFFB1BB457FB4B40BE16F4DE18B44B40DFFB1BB457FB4B405EA27A6B60B54B401AA721AAF0FD4B405EA27A6B60B54B401AA721AAF0FD4B40BE16F4DE18B44B40DFFB1BB457FB4B40BE16F4DE18B44B40
65028	18877	56.028607000000001	56.060451999999998	55.381746	55.363022999999998	Клубная	0103000020E61000000100000005000000E5B7E864A9034C401059A48977AE4B40E5B7E864A9034C407DB08C0DDDB04B40287D21E4BC074C407DB08C0DDDB04B40287D21E4BC074C401059A48977AE4B40E5B7E864A9034C401059A48977AE4B40
64814	58359	55.570053000000001	55.591056000000002	55.634872999999999	55.618588000000003	Яныша Ялкайна	0103000020E610000001000000050000004CFE277FF7C84B405AD93EE42DCF4B404CFE277FF7C84B40840EBA8443D14B40630D17B9A7CB4B40840EBA8443D14B40630D17B9A7CB4B405AD93EE42DCF4B404CFE277FF7C84B405AD93EE42DCF4B40
64821	58359	55.570053000000001	55.591056000000002	55.634872999999999	55.618588000000003	Ленина	0103000020E610000001000000050000004CFE277FF7C84B405AD93EE42DCF4B404CFE277FF7C84B40840EBA8443D14B40630D17B9A7CB4B40840EBA8443D14B40630D17B9A7CB4B405AD93EE42DCF4B404CFE277FF7C84B405AD93EE42DCF4B40
65024	18746	56.049340000000001	56.077115999999997	55.431345999999998	55.417133	Фатхинурова	0103000020E610000001000000050000003C31EBC550064C408B8A389D64B54B403C31EBC550064C4055A1815836B74B40C9FFE4EFDE094C4055A1815836B74B40C9FFE4EFDE094C408B8A389D64B54B403C31EBC550064C408B8A389D64B54B40
65923	20210	56.126443000000002	56.145181000000001	55.686878	55.676051999999999	Лесная	0103000020E6100000010000000500000071E7C2482F104C409C3237DF88D64B4071E7C2482F104C40C32B499EEBD74B4013807F4A95124C40C32B499EEBD74B4013807F4A95124C409C3237DF88D64B4071E7C2482F104C409C3237DF88D64B40
66284	21040	55.447800999999998	55.467258999999999	55.608145	55.593955000000001	Школьная	0103000020E61000000100000005000000DC0E0D8B51B94B40D925AAB706CC4B40DC0E0D8B51B94B40EB1C03B2D7CD4B407EE19524CFBB4B40EB1C03B2D7CD4B407EE19524CFBB4B40D925AAB706CC4B40DC0E0D8B51B94B40D925AAB706CC4B40
64692	21416	55.654234000000002	55.667771999999999	55.683858000000001	55.675767999999998	Шоссейная	0103000020E6100000010000000500000034F790F0BDD34B4077D7D9907FD64B4034F790F0BDD34B40D28DB0A888D74B409E978A8D79D54B40D28DB0A888D74B409E978A8D79D54B4077D7D9907FD64B4034F790F0BDD34B4077D7D9907FD64B40
65418	20447	55.908375999999997	55.934624999999997	55.715915000000003	55.706218	Чапаева	0103000020E61000000100000005000000533C2EAA45F44B405BECF65965DA4B40533C2EAA45F44B40A1DB4B1AA3DB4B401283C0CAA1F74B40A1DB4B1AA3DB4B401283C0CAA1F74B405BECF65965DA4B40533C2EAA45F44B405BECF65965DA4B40
66132	20240	55.971124000000003	55.993600000000001	55.642432999999997	55.625104999999998	Саита Хамата	0103000020E610000001000000050000002C2E8ECA4DFC4B4075C8CD7003D04B402C2E8ECA4DFC4B40826F9A3E3BD24B401EA7E8482EFF4B40826F9A3E3BD24B401EA7E8482EFF4B4075C8CD7003D04B402C2E8ECA4DFC4B4075C8CD7003D04B40
65837	20984	55.499293000000002	55.539608999999999	55.626506999999997	55.614260999999999	Чапаева	0103000020E61000000100000005000000950F41D5E8BF4B40A81ABD1AA0CE4B40950F41D5E8BF4B4087DBA16131D04B404AD05FE811C54B4087DBA16131D04B404AD05FE811C54B40A81ABD1AA0CE4B40950F41D5E8BF4B40A81ABD1AA0CE4B40
65009	19060	55.964880999999998	55.983583000000003	55.517769999999999	55.508830000000003	Трактовая	0103000020E6100000010000000500000011C4793881FB4B40A29C685721C14B4011C4793881FB4B40CA6C904946C24B4067F3380CE6FD4B40CA6C904946C24B4067F3380CE6FD4B40A29C685721C14B4011C4793881FB4B40A29C685721C14B40
65922	20373	55.956212000000001	55.977466	55.701942000000003	55.687558000000003	Советская	0103000020E610000001000000050000007905A22765FA4B40350D8AE601D84B407905A22765FA4B402CD8463CD9D94B40D9791B9B1DFD4B402CD8463CD9D94B40D9791B9B1DFD4B40350D8AE601D84B407905A22765FA4B40350D8AE601D84B40
65031	19961	56.080871000000002	56.111700999999996	55.632443000000002	55.611398999999999	Яныша Ялкайна	0103000020E61000000100000005000000F0181EFB590A4C404FE78A5242CE4B40F0181EFB590A4C40C5CA68E4F3D04B401AF7E6374C0E4C40C5CA68E4F3D04B401AF7E6374C0E4C404FE78A5242CE4B40F0181EFB590A4C404FE78A5242CE4B40
65479	46186	55.973612000000003	55.984095000000003	55.486325999999998	55.477786000000002	Трактовая	0103000020E61000000100000005000000207F69519FFC4B404B3E761728BD4B40207F69519FFC4B40E5982CEE3FBE4B401D9430D3F6FD4B40E5982CEE3FBE4B401D9430D3F6FD4B404B3E761728BD4B40207F69519FFC4B404B3E761728BD4B40
64664	46909	55.575991000000002	55.594990000000003	55.561971	55.547412000000001	Школьная	0103000020E610000001000000050000002AE5B512BAC94B400FB8AE9811C64B402AE5B512BAC94B4074266DAAEEC74B4039B9DFA128CC4B4074266DAAEEC74B4039B9DFA128CC4B400FB8AE9811C64B402AE5B512BAC94B400FB8AE9811C64B40
65085	18804	56.028553000000002	56.059859000000003	55.41724	55.404172000000003	Мичуринская	0103000020E61000000100000005000000F299EC9FA7034C40BEFA78E8BBB34B40F299EC9FA7034C40A14ACD1E68B54B4086AFAF75A9074C40A14ACD1E68B54B4086AFAF75A9074C40BEFA78E8BBB34B40F299EC9FA7034C40BEFA78E8BBB34B40
65943	5641	55.621526000000003	55.636780000000002	55.612045000000002	55.604610000000001	Яныша Ялкайна	0103000020E610000001000000050000008ECEF9298ECF4B40D36A48DC63CD4B408ECEF9298ECF4B401557957D57CE4B409A5FCD0182D14B401557957D57CE4B409A5FCD0182D14B40D36A48DC63CD4B408ECEF9298ECF4B40D36A48DC63CD4B40
65937	19628	55.770090000000003	55.787121999999997	55.591315000000002	55.578330000000001	Советская	0103000020E61000000100000005000000037D224F92E24B40D925AAB706CA4B40037D224F92E24B402F51BD35B0CB4B4026FBE769C0E44B402F51BD35B0CB4B4026FBE769C0E44B40D925AAB706CA4B40037D224F92E24B40D925AAB706CA4B40
66639	58865	55.568292	55.583464999999997	55.65466	55.646222999999999	Тракторная	0103000020E610000001000000050000000A4AD1CABDC84B4025766D6FB7D24B400A4AD1CABDC84B40EBFF1CE6CBD34B4029AE2AFBAECA4B40EBFF1CE6CBD34B4029AE2AFBAECA4B4025766D6FB7D24B400A4AD1CABDC84B4025766D6FB7D24B40
66530	58825	56.005969	56.019893000000003	55.673493999999998	55.658617	Школьная	0103000020E6100000010000000500000019E59997C3004C4079CBD58F4DD44B4019E59997C3004C40AF06280D35D64B40AD3594DA8B024C40AF06280D35D64B40AD3594DA8B024C4079CBD58F4DD44B4019E59997C3004C4079CBD58F4DD44B40
65023	19131	56.000031999999997	56.013326999999997	55.530149000000002	55.518092000000003	Интернациональная	0103000020E610000001000000050000000B7A6F0C01004C40DD28B2D650C24B400B7A6F0C01004C40E98024ECDBC34B40AF93FAB2B4014C40E98024ECDBC34B40AF93FAB2B4014C40DD28B2D650C24B400B7A6F0C01004C40DD28B2D650C24B40
65601	19761	55.941209999999998	55.953921000000001	55.607259999999997	55.595511000000002	Интернациональная	0103000020E610000001000000050000008655BC9179F84B4042B456B439CC4B408655BC9179F84B40A01518B2BACD4B40DBFB54151AFA4B40A01518B2BACD4B40DBFB54151AFA4B4042B456B439CC4B408655BC9179F84B4042B456B439CC4B40
65366	33060	55.945261000000002	55.981383000000001	55.551476000000001	55.516593	Центральная	0103000020E610000001000000050000009697FC4FFEF84B40D82B2CB81FC24B409697FC4FFEF84B40B343FCC396C64B40D9EC48F59DFD4B40B343FCC396C64B40D9EC48F59DFD4B40D82B2CB81FC24B409697FC4FFEF84B40D82B2CB81FC24B40
64454	33060	55.945261000000002	55.981383000000001	55.551476000000001	55.516593	Тракторная	0103000020E610000001000000050000009697FC4FFEF84B40D82B2CB81FC24B409697FC4FFEF84B40B343FCC396C64B40D9EC48F59DFD4B40B343FCC396C64B40D9EC48F59DFD4B40D82B2CB81FC24B409697FC4FFEF84B40D82B2CB81FC24B40
64522	33060	55.945261000000002	55.981383000000001	55.551476000000001	55.516593	Мира	0103000020E610000001000000050000009697FC4FFEF84B40D82B2CB81FC24B409697FC4FFEF84B40B343FCC396C64B40D9EC48F59DFD4B40B343FCC396C64B40D9EC48F59DFD4B40D82B2CB81FC24B409697FC4FFEF84B40D82B2CB81FC24B40
64009	33060	55.945261000000002	55.981383000000001	55.551476000000001	55.516593	Ленина	0103000020E610000001000000050000009697FC4FFEF84B40D82B2CB81FC24B409697FC4FFEF84B40B343FCC396C64B40D9EC48F59DFD4B40B343FCC396C64B40D9EC48F59DFD4B40D82B2CB81FC24B409697FC4FFEF84B40D82B2CB81FC24B40
64136	33060	55.945261000000002	55.981383000000001	55.551476000000001	55.516593	Дружбы	0103000020E610000001000000050000009697FC4FFEF84B40D82B2CB81FC24B409697FC4FFEF84B40B343FCC396C64B40D9EC48F59DFD4B40B343FCC396C64B40D9EC48F59DFD4B40D82B2CB81FC24B409697FC4FFEF84B40D82B2CB81FC24B40
64661	20619	55.793401000000003	55.810253000000003	55.611007000000001	55.600745000000003	Малошадинская	0103000020E610000001000000050000008ECEF9298EE54B40261E5036E5CC4B408ECEF9298EE54B404450357A35CE4B40323ECC5EB6E74B404450357A35CE4B40323ECC5EB6E74B40261E5036E5CC4B408ECEF9298EE54B40261E5036E5CC4B40
66583	58851	56.113956000000002	56.141058000000001	55.651994000000002	55.640065999999997	Школьная	0103000020E610000001000000050000006C97361C960E4C4009A4C4AEEDD14B406C97361C960E4C401898158A74D34B406A6B44300E124C401898158A74D34B406A6B44300E124C4009A4C4AEEDD14B406C97361C960E4C4009A4C4AEEDD14B40
66834	21448	55.666676000000002	55.682262000000001	55.711326	55.699086000000001	Молодежная	0103000020E610000001000000050000009983A0A355D54B40B58B69A67BD94B409983A0A355D54B40B265F9BA0CDB4B40DBA6785C54D74B40B265F9BA0CDB4B40DBA6785C54D74B40B58B69A67BD94B409983A0A355D54B40B58B69A67BD94B40
64117	58170	56.205575000000003	56.222275000000003	55.439712	55.431673000000004	Советская	0103000020E6100000010000000500000007F01648501A4C407AC8940F41B74B4007F01648501A4C4052D4997B48B84B40F5DBD781731C4C4052D4997B48B84B40F5DBD781731C4C407AC8940F41B74B4007F01648501A4C407AC8940F41B74B40
65438	19548	55.829118000000001	55.853166000000002	55.491436999999998	55.468035	Социалистическая	0103000020E610000001000000050000003143E38920EA4B4012312592E8BB4B403143E38920EA4B40AD855968E7BE4B409207228B34ED4B40AD855968E7BE4B409207228B34ED4B4012312592E8BB4B403143E38920EA4B4012312592E8BB4B40
64985	11033	56.077897999999998	56.101703000000001	55.481923999999999	55.456463999999997	Орсаева	0103000020E610000001000000050000003F36C98FF8094C4092E68F696DBA4B403F36C98FF8094C40299485AFAFBD4B40DA73999A040D4C40299485AFAFBD4B40DA73999A040D4C4092E68F696DBA4B403F36C98FF8094C4092E68F696DBA4B40
66124	11033	56.077897999999998	56.101703000000001	55.481923999999999	55.456463999999997	Больничная	0103000020E610000001000000050000003F36C98FF8094C4092E68F696DBA4B403F36C98FF8094C40299485AFAFBD4B40DA73999A040D4C40299485AFAFBD4B40DA73999A040D4C4092E68F696DBA4B403F36C98FF8094C4092E68F696DBA4B40
65167	20774	55.704934999999999	55.724285000000002	55.557327000000001	55.547809999999998	Центральная	0103000020E610000001000000050000002367614F3BDA4B40FC3559A31EC64B402367614F3BDA4B40C216BB7D56C74B40DFFDF15EB5DC4B40C216BB7D56C74B40DFFDF15EB5DC4B40FC3559A31EC64B402367614F3BDA4B40FC3559A31EC64B40
65428	20510	55.881759000000002	55.903129999999997	55.657271000000001	55.643571000000001	Кирова	0103000020E6100000010000000500000012FA997ADDF04B40B7D3D68860D24B4012FA997ADDF04B40FBCDC47421D44B40AB048BC399F34B40FBCDC47421D44B40AB048BC399F34B40B7D3D68860D24B4012FA997ADDF04B40B7D3D68860D24B40
64663	47180	55.630465000000001	55.640355	55.753042999999998	55.741003999999997	Ишкинина	0103000020E61000000100000005000000E622BE13B3D04B40431A1538D9DE4B40E622BE13B3D04B40A9BD88B663E04B40406A1327F7D14B40A9BD88B663E04B40406A1327F7D14B40431A1538D9DE4B40E622BE13B3D04B40431A1538D9DE4B40
66129	19792	55.949412000000002	55.963586999999997	55.576090999999998	55.558086000000003	Социалистическая	0103000020E610000001000000050000000937195586F94B40802DAF5C6FC74B400937195586F94B408D429259BDC94B40E5EC9DD156FB4B408D429259BDC94B40E5EC9DD156FB4B40802DAF5C6FC74B400937195586F94B40802DAF5C6FC74B40
65840	21075	55.386355999999999	55.413009000000002	55.606482	55.596426999999998	Мичурина	0103000020E61000000100000005000000834E081D74B14B40C7B94DB857CC4B40834E081D74B14B406CCEC133A1CD4B4012FA997ADDB44B406CCEC133A1CD4B4012FA997ADDB44B40C7B94DB857CC4B40834E081D74B14B40C7B94DB857CC4B40
66126	46546	56.005592	56.023108999999998	55.609706000000003	55.595877000000002	Трактовая	0103000020E61000000100000005000000438F183DB7004C4024B891B245CC4B40438F183DB7004C406616A1D80ACE4B40239F573CF5024C406616A1D80ACE4B40239F573CF5024C4024B891B245CC4B40438F183DB7004C4024B891B245CC4B40
65917	19707	55.896006999999997	55.909742000000001	55.602418	55.587494	Матросова	0103000020E6100000010000000500000058FE7C5BB0F24B40514CDE0033CB4B4058FE7C5BB0F24B40C84274081CCD4B4019E6046D72F44B40C84274081CCD4B4019E6046D72F44B40514CDE0033CB4B4058FE7C5BB0F24B40514CDE0033CB4B40
66289	21354	55.62547	55.644128000000002	55.650663000000002	55.642026999999999	Советская	0103000020E610000001000000050000008750A5660FD04B401213D4F02DD24B408750A5660FD04B40CFDBD8EC48D34B400D384BC972D24B40CFDBD8EC48D34B400D384BC972D24B401213D4F02DD24B408750A5660FD04B401213D4F02DD24B40
65160	20556	55.800094000000001	55.823692000000001	55.664147	55.648198999999998	Больничная	0103000020E61000000100000005000000E8DCED7A69E64B406326512FF8D24B40E8DCED7A69E64B40465ED6C402D54B4009FD4CBD6EE94B40465ED6C402D54B4009FD4CBD6EE94B406326512FF8D24B40E8DCED7A69E64B406326512FF8D24B40
64347	20944	55.531478999999997	55.567466000000003	55.578152000000003	55.557856999999998	Центральная	0103000020E6100000010000000500000061C1FD8007C44B401E6CB1DB67C74B4061C1FD8007C44B40FA0E7EE200CA4B40C5CBD3B9A2C84B40FA0E7EE200CA4B40C5CBD3B9A2C84B401E6CB1DB67C74B4061C1FD8007C44B401E6CB1DB67C74B40
66740	6889	56.201639999999998	56.221251000000002	55.702703	55.680067000000001	Мира	0103000020E6100000010000000500000060C8EA56CF194C405F0B7A6F0CD74B4060C8EA56CF194C408AE6012CF2D94B40899AE8F3511C4C408AE6012CF2D94B40899AE8F3511C4C405F0B7A6F0CD74B4060C8EA56CF194C405F0B7A6F0CD74B40
64780	20731	55.679251999999998	55.698773000000003	55.522872	55.514783999999999	Трактовая	0103000020E610000001000000050000000DDFC2BAF1D64B4085402E71E4C14B400DDFC2BAF1D64B403FFF3D78EDC24B40F629C76471D94B403FFF3D78EDC24B40F629C76471D94B4085402E71E4C14B400DDFC2BAF1D64B4085402E71E4C14B40
65018	18710	56.195675999999999	56.227521000000003	55.409875999999997	55.401221999999997	Школьная	0103000020E61000000100000005000000594E42E90B194C40C537143E5BB34B40594E42E90B194C4028B517D176B44B409D137B681F1D4C4028B517D176B44B409D137B681F1D4C40C537143E5BB34B40594E42E90B194C40C537143E5BB34B40
65492	46005	56.113354000000001	56.144418000000002	55.508682	55.491840000000003	Школьная	0103000020E61000000100000005000000766F4562820E4C40AD6EF59CF4BE4B40766F4562820E4C402D08E57D1CC14B40147AFD497C124C402D08E57D1CC14B40147AFD497C124C40AD6EF59CF4BE4B40766F4562820E4C40AD6EF59CF4BE4B40
65597	58542	58.377926000000002	58.397041999999999	55.829315000000001	55.819004	Юлаева	0103000020E61000000100000005000000702711E15F304D4087A5811FD5E84B40702711E15F304D40878A71FE26EA4B40B891B245D2324D40878A71FE26EA4B40B891B245D2324D4087A5811FD5E84B40702711E15F304D4087A5811FD5E84B40
65431	58542	58.377926000000002	58.397041999999999	55.829315000000001	55.819004	Хаерзаманова	0103000020E61000000100000005000000702711E15F304D4087A5811FD5E84B40702711E15F304D40878A71FE26EA4B40B891B245D2324D40878A71FE26EA4B40B891B245D2324D4087A5811FD5E84B40702711E15F304D4087A5811FD5E84B40
66131	17193	58.589578000000003	58.608209000000002	56.075251999999999	56.058720000000001	Мира	0103000020E610000001000000050000007638BA4A774B4D4081CF0F2384074C407638BA4A774B4D40B37A87DBA1094C400211E2CAD94D4D40B37A87DBA1094C400211E2CAD94D4D4081CF0F2384074C407638BA4A774B4D4081CF0F2384074C40
66155	17531	58.435445000000001	58.470793999999998	55.765239999999999	55.755282000000001	Горная	0103000020E61000000100000005000000761A69A9BC374D40F5A0A014ADE04B40761A69A9BC374D40A7CB6262F3E14B40969350FA423C4D40A7CB6262F3E14B40969350FA423C4D40F5A0A014ADE04B40761A69A9BC374D40F5A0A014ADE04B40
65516	45704	58.324413	58.351425999999996	55.804409999999997	55.794705	Миасс	0103000020E61000000100000005000000D9B27C5D86294D40DD7BB8E4B8E54B40D9B27C5D86294D40A54929E8F6E64B40677BF486FB2C4D40A54929E8F6E64B40677BF486FB2C4D40DD7BB8E4B8E54B40D9B27C5D86294D40DD7BB8E4B8E54B40
65490	45704	58.324413	58.351425999999996	55.804409999999997	55.794705	Механизаторов	0103000020E61000000100000005000000D9B27C5D86294D40DD7BB8E4B8E54B40D9B27C5D86294D40A54929E8F6E64B40677BF486FB2C4D40A54929E8F6E64B40677BF486FB2C4D40DD7BB8E4B8E54B40D9B27C5D86294D40DD7BB8E4B8E54B40
66468	58788	58.114063999999999	58.132021000000002	56.037906	56.028188	Советская	0103000020E6100000010000000500000052D32EA6990E4D40E01115AA9B034C4052D32EA6990E4D403D29931ADA044C404FB16A10E6104D403D29931ADA044C404FB16A10E6104D40E01115AA9B034C4052D32EA6990E4D40E01115AA9B034C40
65420	17798	58.402808999999998	58.417954999999999	55.741616999999998	55.730781	Коммунистическая	0103000020E6100000010000000500000069C4CC3E8F334D40E3C4573B8ADD4B4069C4CC3E8F334D402D944C4EEDDE4B408F19A88C7F354D402D944C4EEDDE4B408F19A88C7F354D40E3C4573B8ADD4B4069C4CC3E8F334D40E3C4573B8ADD4B40
66607	58860	57.896096999999997	58.831674	56.173006000000001	55.613128000000003	Советская	0103000020E610000001000000050000009885764EB3F24C40862172FA7ACE4B409885764EB3F24C408201840F25164C407D772B4B746A4D408201840F25164C407D772B4B746A4D40862172FA7ACE4B409885764EB3F24C40862172FA7ACE4B40
66513	58724	58.089486000000001	58.104587000000002	55.979948999999998	55.971626999999998	Школьная	0103000020E6100000010000000500000095B9F946740B4D408E7406465EFC4B4095B9F946740B4D40BB5F05F86EFD4B401B4B581B630D4D40BB5F05F86EFD4B401B4B581B630D4D408E7406465EFC4B4095B9F946740B4D408E7406465EFC4B40
65448	58544	58.216903000000002	58.233719000000001	55.920689000000003	55.911814999999997	Айская	0103000020E61000000100000005000000C0B33D7AC31B4D4049809A5AB6F44B40C0B33D7AC31B4D40BB641C23D9F54B4017BA1281EA1D4D40BB641C23D9F54B4017BA1281EA1D4D4049809A5AB6F44B40C0B33D7AC31B4D4049809A5AB6F44B40
65432	17920	58.245441999999997	58.268358999999997	55.881359000000003	55.873106999999997	Молодежная	0103000020E610000001000000050000004C88B9A46A1F4D404F745DF8C1EF4B404C88B9A46A1F4D408484285FD0F04B402B4B749659224D408484285FD0F04B402B4B749659224D404F745DF8C1EF4B404C88B9A46A1F4D404F745DF8C1EF4B40
64236	17632	58.385921000000003	58.413876999999999	55.709870000000002	55.692577	Школьная	0103000020E6100000010000000500000079EBFCDB65314D401C7BF65CA6D84B4079EBFCDB65314D40AD342905DDDA4B4086C8E9EBF9344D40AD342905DDDA4B4086C8E9EBF9344D401C7BF65CA6D84B4079EBFCDB65314D401C7BF65CA6D84B40
65021	16678	58.182380999999999	58.211136000000003	55.68974	55.677371999999998	Октябрьская	0103000020E61000000100000005000000B534B74258174D40F19C2D20B4D64B40B534B74258174D401C5F7B6649D84B400F812381061B4D401C5F7B6649D84B400F812381061B4D40F19C2D20B4D64B40B534B74258174D40F19C2D20B4D64B40
65433	17071	58.356527999999997	58.403078999999998	55.999625999999999	55.984597000000001	Солнечная	0103000020E61000000100000005000000DC0DA2B5A22D4D40AF5E454607FE4B40DC0DA2B5A22D4D409B1DA9BEF3FF4B40295AB91798334D409B1DA9BEF3FF4B40295AB91798334D40AF5E454607FE4B40DC0DA2B5A22D4D40AF5E454607FE4B40
65016	18135	57.966012999999997	57.992037000000003	55.936101000000001	55.919347000000002	Революционная	0103000020E6100000010000000500000063416150A6FB4C407E569929ADF54B4063416150A6FB4C405F605628D2F74B4003B68311FBFE4C405F605628D2F74B4003B68311FBFE4C407E569929ADF54B4063416150A6FB4C407E569929ADF54B40
65197	17051	58.299520999999999	58.362718000000001	55.998725	55.977606999999999	Трактовая	0103000020E610000001000000050000008CBB41B456264D409BABE63922FD4B408CBB41B456264D404B598638D6FF4B40D4D51D8B6D2E4D404B598638D6FF4B40D4D51D8B6D2E4D409BABE63922FD4B408CBB41B456264D409BABE63922FD4B40
66669	29945	58.252206999999999	58.283746999999998	55.838531000000003	55.822079000000002	улица Карла Маркса	0103000020E610000001000000050000004069A85148204D403CDD79E239E94B404069A85148204D4052D7DAFB54EB4B4047AB5AD251244D4052D7DAFB54EB4B4047AB5AD251244D403CDD79E239E94B404069A85148204D403CDD79E239E94B40
65012	17149	58.501919999999998	58.543098999999998	56.149099999999997	56.1342	Ленина	0103000020E61000000100000005000000AA9A20EA3E404D40C58F31772D114C40AA9A20EA3E404D40B3EA73B515134C40C2BE9D4484454D40B3EA73B515134C40C2BE9D4484454D40C58F31772D114C40AA9A20EA3E404D40C58F31772D114C40
66488	58800	58.056176000000001	58.080888999999999	56.079583	56.070746	Первомайская	0103000020E61000000100000005000000F96871C630074D40522976340E094C40F96871C630074D40A62897C62F0A4C4096CD1C925A0A4D40A62897C62F0A4C4096CD1C925A0A4D40522976340E094C40F96871C630074D40522976340E094C40
65042	58444	58.288570999999997	58.302629000000003	55.642640999999998	55.636854	Набережная	0103000020E6100000010000000500000079C9FFE4EF244D40D4298F6E84D14B4079C9FFE4EF244D40CC086F0F42D24B401DE90C8CBC264D40CC086F0F42D24B401DE90C8CBC264D40D4298F6E84D14B4079C9FFE4EF244D40D4298F6E84D14B40
66884	5576	58.534807999999998	58.557049999999997	56.010618999999998	55.998479000000003	Пролетарская	0103000020E61000000100000005000000D0D1AA9674444D40145FED28CEFF4B40D0D1AA9674444D40ADDBA0F65B014C404F1E166A4D474D40ADDBA0F65B014C404F1E166A4D474D40145FED28CEFF4B40D0D1AA9674444D40145FED28CEFF4B40
66707	26539	58.291113000000003	58.322930999999997	55.701962999999999	55.689791	Школьная	0103000020E610000001000000050000006138D73043254D409E094D124BD84B406138D73043254D40430070ECD9D94B40AAEE91CD55294D40430070ECD9D94B40AAEE91CD55294D409E094D124BD84B406138D73043254D409E094D124BD84B40
66667	47236	58.313282999999998	58.332228999999998	55.662674000000003	55.653979999999997	Центральная	0103000020E6100000010000000500000046B247A819284D40791EDC9DB5D34B4046B247A819284D406BF46A80D2D44B4032E4D87A862A4D406BF46A80D2D44B4032E4D87A862A4D40791EDC9DB5D34B4046B247A819284D40791EDC9DB5D34B40
66490	18035	58.099170000000001	58.114792000000001	55.904840999999998	55.894672	Мостовая	0103000020E61000000100000005000000465F419AB10C4D40CE52B29C84F24B40465F419AB10C4D403B8A73D4D1F34B40D5EB1681B10E4D403B8A73D4D1F34B40D5EB1681B10E4D40CE52B29C84F24B40465F419AB10C4D40CE52B29C84F24B40
64971	8327	58.235947000000003	58.253087000000001	55.680509000000001	55.669365999999997	Школьная	0103000020E610000001000000050000006F4BE482331E4D40F486FBC8ADD54B406F4BE482331E4D401CD13DEB1AD74B407905A22765204D401CD13DEB1AD74B407905A22765204D40F486FBC8ADD54B406F4BE482331E4D40F486FBC8ADD54B40
63960	58146	57.896096999999997	58.831674	56.173006000000001	55.613128000000003	Ленина	0103000020E610000001000000050000009885764EB3F24C40862172FA7ACE4B409885764EB3F24C408201840F25164C407D772B4B746A4D408201840F25164C407D772B4B746A4D40862172FA7ACE4B409885764EB3F24C40862172FA7ACE4B40
65435	18247	58.060785000000003	58.089809000000002	55.974936999999997	55.957242000000001	Революционная	0103000020E610000001000000050000002F8B89CDC7074D40C72DE6E786FA4B402F8B89CDC7074D40865451BCCAFC4B4078F17EDC7E0B4D40865451BCCAFC4B4078F17EDC7E0B4D40C72DE6E786FA4B402F8B89CDC7074D40C72DE6E786FA4B40
64319	18390	58.181562999999997	58.234205000000003	56.098782999999997	56.052546999999997	Мира	0103000020E61000000100000005000000F294D5743D174D405F402FDCB9064C40F294D5743D174D404C33DDEBA40C4C40A4C7EF6DFA1D4D404C33DDEBA40C4C40A4C7EF6DFA1D4D405F402FDCB9064C40F294D5743D174D405F402FDCB9064C40
63976	58145	58.241939000000002	58.29909	55.962553999999997	55.927230000000002	Молодежная	0103000020E6100000010000000500000040506EDBF71E4D405FEFFE78AFF64B4040506EDBF71E4D4026512FF834FB4B40C347C49448264D4026512FF834FB4B40C347C49448264D405FEFFE78AFF64B4040506EDBF71E4D405FEFFE78AFF64B40
63953	58145	58.241939000000002	58.29909	55.962553999999997	55.927230000000002	Ленина	0103000020E6100000010000000500000040506EDBF71E4D405FEFFE78AFF64B4040506EDBF71E4D4026512FF834FB4B40C347C49448264D4026512FF834FB4B40C347C49448264D405FEFFE78AFF64B4040506EDBF71E4D405FEFFE78AFF64B40
65020	17384	58.295406999999997	58.312663000000001	55.865257999999997	55.854835000000001	Школьная	0103000020E61000000100000005000000360186E5CF254D40F33CB83B6BED4B40360186E5CF254D401A4D2EC6C0EE4B40AAD5575705284D401A4D2EC6C0EE4B40AAD5575705284D40F33CB83B6BED4B40360186E5CF254D40F33CB83B6BED4B40
64298	18099	58.092136000000004	58.149133999999997	55.945104999999998	55.928865000000002	Октябрьская	0103000020E610000001000000050000006364C91CCB0B4D4014B35E0CE5F64B406364C91CCB0B4D409E245D33F9F84B405F5CAAD216134D409E245D33F9F84B405F5CAAD216134D4014B35E0CE5F64B406364C91CCB0B4D4014B35E0CE5F64B40
66715	931	58.241830999999998	58.278986000000003	56.039852000000003	56.017543000000003	Школьная	0103000020E6100000010000000500000059147651F41E4D400AA359D93E024C4059147651F41E4D401157CEDE19054C405C0531D0B5234D401157CEDE19054C405C0531D0B5234D400AA359D93E024C4059147651F41E4D400AA359D93E024C40
65430	17599	58.433225999999998	58.456474999999998	55.749890999999998	55.742164000000002	Гагарина	0103000020E6100000010000000500000071E316F373374D406022DE3AFFDE4B4071E316F373374D404948A46DFCDF4B408638D6C56D3A4D404948A46DFCDF4B408638D6C56D3A4D406022DE3AFFDE4B4071E316F373374D406022DE3AFFDE4B40
66485	5479	57.933394999999997	57.996932999999999	56.078190999999997	56.058855000000001	Ленина	0103000020E61000000100000005000000FD9FC37C79F74C40611A868F88074C40FD9FC37C79F74C40B7EBA529020A4C40CEA623809BFF4C40B7EBA529020A4C40CEA623809BFF4C40611A868F88074C40FD9FC37C79F74C40611A868F88074C40
65014	17428	58.305135999999997	58.330368999999997	55.834381	55.818396999999997	Октябрьская	0103000020E61000000100000005000000876A4AB20E274D407F129F3BC1E84B40876A4AB20E274D40AFB321FFCCEA4B405D4E0988492A4D40AFB321FFCCEA4B405D4E0988492A4D407F129F3BC1E84B40876A4AB20E274D407F129F3BC1E84B40
64855	58376	55.553156000000001	56.902928000000003	53.390208000000001	52.814706000000001	Ленина	0103000020E6100000010000000500000008CBD8D0CDC64B4070ED444948684A4008CBD8D0CDC64B409C51F355F2B14A4044520B2593734C409C51F355F2B14A4044520B2593734C4070ED444948684A4008CBD8D0CDC64B4070ED444948684A40
65007	15671	55.962536	55.980502000000001	53.183813999999998	53.162725999999999	Салавата Юлаева	0103000020E61000000100000005000000809C306134FB4B40BD1AA034D4944A40809C306134FB4B400246973787974A40D0D4EB1681FD4B400246973787974A40D0D4EB1681FD4B40BD1AA034D4944A40809C306134FB4B40BD1AA034D4944A40
65421	16747	56.056562999999997	56.065069999999999	52.985920999999998	52.966867000000001	Потешкина	0103000020E61000000100000005000000F294D5743D074C40734A404CC27B4A40F294D5743D074C4045B8C9A8327E4A40B1F9B83654084C4045B8C9A8327E4A40B1F9B83654084C40734A404CC27B4A40F294D5743D074C40734A404CC27B4A40
65912	15124	55.785046999999999	55.855286	53.033324999999998	52.997391	Победы	0103000020E6100000010000000500000055698B6B7CE44B4091291F82AA7F4A4055698B6B7CE44B40D1915CFE43844A40035DFB027AED4B40D1915CFE43844A40035DFB027AED4B4091291F82AA7F4A4055698B6B7CE44B4091291F82AA7F4A40
66122	15509	55.767853000000002	55.786169999999998	53.285792999999998	53.262045999999998	Сухаревская	0103000020E610000001000000050000005891D10149E24B4018062CB98AA14A405891D10149E24B407E3672DD94A44A40548CF337A1E44B407E3672DD94A44A40548CF337A1E44B4018062CB98AA14A405891D10149E24B4018062CB98AA14A40
64099	15853	56.060299999999998	56.077385999999997	53.042546000000002	53.028174999999997	Правонабережная	0103000020E6100000010000000500000072F90FE9B7074C404BC8073D9B834A4072F90FE9B7074C40AE49B72572854A408995D1C8E7094C40AE49B72572854A408995D1C8E7094C404BC8073D9B834A4072F90FE9B7074C404BC8073D9B834A40
65422	16161	56.477997999999999	56.494410000000002	53.072816000000003	53.063650000000003	Мира	0103000020E61000000100000005000000D6C6D8092F3D4C40F931E6AE25884A40D6C6D8092F3D4C401250E10852894A405E68AED3483F4C401250E10852894A405E68AED3483F4C40F931E6AE25884A40D6C6D8092F3D4C40F931E6AE25884A40
64116	16263	56.311639	56.340474999999998	52.913156999999998	52.901045000000003	Мира	0103000020E610000001000000050000003E9468C9E3274C40B79C4B7155734A403E9468C9E3274C40868E1D54E2744A40840D4FAF942B4C40868E1D54E2744A40840D4FAF942B4C40B79C4B7155734A403E9468C9E3274C40B79C4B7155734A40
65918	16558	56.049906	56.067863000000003	52.955627999999997	52.934949000000003	Советская	0103000020E61000000100000005000000E5EFDE5163064C40C636A968AC774A40E5EFDE5163064C402992AF04527A4A40E2CD1ABCAF084C402992AF04527A4A40E2CD1ABCAF084C40C636A968AC774A40E5EFDE5163064C40C636A968AC774A40
65913	15030	55.608823999999998	55.628318	53.042541	53.031024000000002	Юрматинская	0103000020E610000001000000050000008C82E0F1EDCD4B4010B22C98F8834A408C82E0F1EDCD4B409CDEC5FB71854A407BBE66B96CD04B409CDEC5FB71854A407BBE66B96CD04B4010B22C98F8834A408C82E0F1EDCD4B4010B22C98F8834A40
65000	15580	55.949627	55.964655999999998	53.259093999999997	53.247646000000003	Колхозная	0103000020E610000001000000050000000533A6608DF94B401C7E37DDB29F4A400533A6608DF94B407F4B00FE29A14A40F1F109D979FB4B407F4B00FE29A14A40F1F109D979FB4B401C7E37DDB29F4A400533A6608DF94B401C7E37DDB29F4A40
65363	46848	55.871366000000002	55.891964000000002	52.933357999999998	52.918157999999998	Центральная	0103000020E61000000100000005000000556CCCEB88EF4B40C7478B3386754A40556CCCEB88EF4B40E0BA624678774A40CC9A58E02BF24B40E0BA624678774A40CC9A58E02BF24B40C7478B3386754A40556CCCEB88EF4B40C7478B3386754A40
65911	14974	55.689276999999997	55.705151000000001	53.123111999999999	53.099929000000003	Центральная	0103000020E6100000010000000500000047718E3A3AD84B4004763579CA8C4A4047718E3A3AD84B4061DF4E22C28F4A40F0DE516342DA4B4061DF4E22C28F4A40F0DE516342DA4B4004763579CA8C4A4047718E3A3AD84B4004763579CA8C4A40
66319	58742	55.776170999999998	55.802070000000001	52.924737999999998	52.913749000000003	Озерная	0103000020E61000000100000005000000438D429259E34B4059E02BBAF5744A40438D429259E34B4029AF95D05D764A40268DD13AAAE64B4029AF95D05D764A40268DD13AAAE64B4059E02BBAF5744A40438D429259E34B4059E02BBAF5744A40
64393	16144	56.427621000000002	56.451785000000001	53.047818999999997	53.036428000000001	Молодежная	0103000020E610000001000000050000009A0AF148BC364C40505436ACA9844A409A0AF148BC364C404F90D8EE1E864A4064E94317D4394C404F90D8EE1E864A4064E94317D4394C40505436ACA9844A409A0AF148BC364C40505436ACA9844A40
64446	15209	55.583519000000003	55.611339999999998	53.254941000000002	53.227995999999997	Гагарина	0103000020E610000001000000050000001DCC26C0B0CA4B4035CF11F92E9D4A401DCC26C0B0CA4B406CB41CE8A1A04A404A5E9D6340CE4B406CB41CE8A1A04A404A5E9D6340CE4B4035CF11F92E9D4A401DCC26C0B0CA4B4035CF11F92E9D4A40
66631	46136	55.662318999999997	55.683016000000002	53.345295999999998	53.334097	Молодежная	0103000020E610000001000000050000007C4276DEC6D44B408A58C4B0C3AA4A407C4276DEC6D44B4045B8C9A832AC4A4087527B116DD74B4045B8C9A832AC4A4087527B116DD74B408A58C4B0C3AA4A407C4276DEC6D44B408A58C4B0C3AA4A40
63602	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Южная	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63289	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Смоленская	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63286	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Площадь Элеватора	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63552	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Первомайская	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63598	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Костромская	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
64238	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	Береговая	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63283	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	50 лет ВЛКСМ	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
63698	13759	55.900497999999999	55.967044999999999	52.985492999999998	52.928494999999998	32 микрорайон	0103000020E61000000100000005000000840EBA8443F34B40F0BF95ECD8764A40840EBA8443F34B40EDB776A2247E4A4052616C21C8FB4B40EDB776A2247E4A4052616C21C8FB4B40F0BF95ECD8764A40840EBA8443F34B40F0BF95ECD8764A40
64097	14852	55.953175000000002	55.968643999999998	53.015137000000003	53.003428	Школьная	0103000020E61000000100000005000000B22E6EA301FA4B4002F2255470804A40B22E6EA301FA4B40D3FA5B02F0814A40BABBCE86FCFB4B40D3FA5B02F0814A40BABBCE86FCFB4B4002F2255470804A40B22E6EA301FA4B4002F2255470804A40
64527	15363	55.787965999999997	55.805115000000001	53.340398	53.314109999999999	Ямилева	0103000020E61000000100000005000000122EE411DCE44B405CACA8C134A84A40122EE411DCE44B40D9CF622992AB4A40704221020EE74B40D9CF622992AB4A40704221020EE74B405CACA8C134A84A40122EE411DCE44B405CACA8C134A84A40
63685	58118	55.861061999999997	55.874833000000002	53.337774000000003	53.330461	Ленина	0103000020E6100000010000000500000007EA944737EE4B403ECDC98B4CAA4A4007EA944737EE4B4035B8AD2D3CAB4A40153B1A87FAEF4B4035B8AD2D3CAB4A40153B1A87FAEF4B403ECDC98B4CAA4A4007EA944737EE4B403ECDC98B4CAA4A40
66857	559	56.131535999999997	56.149152000000001	52.972057	52.961378000000003	Школьная	0103000020E61000000100000005000000921FF12BD6104C40058C2E6F0E7B4A40921FF12BD6104C40876C205D6C7C4A400611A96917134C40876C205D6C7C4A400611A96917134C40058C2E6F0E7B4A40921FF12BD6104C40058C2E6F0E7B4A40
63415	14785	55.912391999999997	55.924025	52.928918000000003	52.919586000000002	Берёзовая	0103000020E61000000100000005000000E690D442C9F44B4003EE79FEB4754A40E690D442C9F44B403755F7C8E6764A40DCD7817346F64B403755F7C8E6764A40DCD7817346F64B4003EE79FEB4754A40E690D442C9F44B4003EE79FEB4754A40
66902	5950	56.425986000000002	56.454543000000001	52.973233999999998	52.954006	Центральная	0103000020E61000000100000005000000E54691B586364C4009185DDE1C7A4A40E54691B586364C4079AD84EE927C4A4018D00B772E3A4C4079AD84EE927C4A4018D00B772E3A4C4009185DDE1C7A4A40E54691B586364C4009185DDE1C7A4A40
63288	15677	55.906472000000001	55.936036000000001	53.250114000000004	53.202632000000001	Советская	0103000020E61000000100000005000000AF5E454607F44B40C18F6AD8EF994A40AF5E454607F44B40C9224DBC03A04A4078F01307D0F74B40C9224DBC03A04A4078F01307D0F74B40C18F6AD8EF994A40AF5E454607F44B40C18F6AD8EF994A40
66120	15277	55.725363000000002	55.741757	53.229894000000002	53.215251000000002	Механизаторов	0103000020E610000001000000050000003E5DDDB1D8DC4B4035B742588D9B4A403E5DDDB1D8DC4B40F8C5A52A6D9D4A401F4AB4E4F1DE4B40F8C5A52A6D9D4A401F4AB4E4F1DE4B4035B742588D9B4A403E5DDDB1D8DC4B4035B742588D9B4A40
64317	15058	55.853327999999998	55.912759999999999	53.060760000000002	53.035420999999999	Советская	0103000020E610000001000000050000006B6116DA39ED4B40BA4BE2AC88844A406B6116DA39ED4B40D673D2FBC6874A40698CD651D5F44B40D673D2FBC6874A40698CD651D5F44B40BA4BE2AC88844A406B6116DA39ED4B40BA4BE2AC88844A40
65915	15488	55.642763000000002	55.668894999999999	53.332596000000002	53.321916000000002	Школьная	0103000020E61000000100000005000000180AD80E46D24B409207228B34A94A40180AD80E46D24B40E563778192AA4A409DBAF2599ED54B40E563778192AA4A409DBAF2599ED54B409207228B34A94A40180AD80E46D24B409207228B34A94A40
65690	46777	56.280144	56.296520999999998	52.964545999999999	52.954737999999999	Школьная	0103000020E61000000100000005000000D71533C2DB234C40CD1FD3DA347A4A40D71533C2DB234C406ABE4A3E767B4A40E2C96E66F4254C406ABE4A3E767B4A40E2C96E66F4254C40CD1FD3DA347A4A40D71533C2DB234C40CD1FD3DA347A4A40
64352	58213	56.122526000000001	56.161467999999999	53.138207999999999	53.108822000000004	Ленина	0103000020E61000000100000005000000717495EEAE0F4C40EC8A19E1ED8D4A40717495EEAE0F4C40D505BCCCB0914A40DEACC1FBAA144C40D505BCCCB0914A40DEACC1FBAA144C40EC8A19E1ED8D4A40717495EEAE0F4C40EC8A19E1ED8D4A40
64107	15872	56.122526000000001	56.161467999999999	53.138207999999999	53.108822000000004	Рихарда Зорге	0103000020E61000000100000005000000717495EEAE0F4C40EC8A19E1ED8D4A40717495EEAE0F4C40D505BCCCB0914A40DEACC1FBAA144C40D505BCCCB0914A40DEACC1FBAA144C40EC8A19E1ED8D4A40717495EEAE0F4C40EC8A19E1ED8D4A40
66121	15594	55.966551000000003	55.986009000000003	53.317138999999997	53.303721000000003	Школьная	0103000020E61000000100000005000000437573F1B7FB4B40E10D6954E0A64A40437573F1B7FB4B40A0A4C00298A84A40E547FC8A35FE4B40A0A4C00298A84A40E547FC8A35FE4B40E10D6954E0A64A40437573F1B7FB4B40E10D6954E0A64A40
65103	15181	55.949339999999999	55.974313000000002	53.106406	53.081828999999999	Школьная	0103000020E610000001000000050000006F641EF983F94B40A46E675F798A4A406F641EF983F94B40910C39B69E8D4A40A988D349B6FC4B40910C39B69E8D4A40A988D349B6FC4B40A46E675F798A4A406F641EF983F94B40A46E675F798A4A40
66739	15181	55.949339999999999	55.974313000000002	53.106406	53.081828999999999	Центральная	0103000020E610000001000000050000006F641EF983F94B40A46E675F798A4A406F641EF983F94B40910C39B69E8D4A40A988D349B6FC4B40910C39B69E8D4A40A988D349B6FC4B40A46E675F798A4A406F641EF983F94B40A46E675F798A4A40
66721	15309	55.721338000000003	55.735081999999998	53.198014000000001	53.179150999999997	Социалстическая	0103000020E6100000010000000500000058AEB7CD54DC4B40D905836BEE964A4058AEB7CD54DC4B403813D38558994A406BF0BE2A17DE4B403813D38558994A406BF0BE2A17DE4B40D905836BEE964A4058AEB7CD54DC4B40D905836BEE964A40
66805	5876	55.956068000000002	55.973261999999998	53.126905999999998	53.105508	Заречная	0103000020E610000001000000050000004660AC6F60FA4B40B2BB4049818D4A404660AC6F60FA4B4045D5AF743E904A40433866D993FC4B4045D5AF743E904A40433866D993FC4B40B2BB4049818D4A404660AC6F60FA4B40B2BB4049818D4A40
64450	16356	56.164952999999997	56.183351000000002	52.894418000000002	52.883485999999998	Салима Масагутова	0103000020E6100000010000000500000044300E2E1D154C40A73CBA1116714A4044300E2E1D154C40147AFD497C724A402E58AA0B78174C40147AFD497C724A402E58AA0B78174C40A73CBA1116714A4044300E2E1D154C40A73CBA1116714A40
65005	14894	55.725875000000002	55.754693000000003	52.911202000000003	52.901279000000002	Заречная	0103000020E61000000100000005000000F4FDD478E9DC4B402AC93A1C5D734A40F4FDD478E9DC4B4060066344A2744A4094C2BCC799E04B4060066344A2744A4094C2BCC799E04B402AC93A1C5D734A40F4FDD478E9DC4B402AC93A1C5D734A40
65004	15962	56.236162999999998	56.261063999999998	53.051873999999998	53.018279	Центральная	0103000020E610000001000000050000003BC3D4963A1E4C400F9A5DF756824A403BC3D4963A1E4C40A0C1A6CEA3864A40DB148F8B6A214C40A0C1A6CEA3864A40DB148F8B6A214C400F9A5DF756824A403BC3D4963A1E4C400F9A5DF756824A40
64029	16365	56.331159999999997	56.353833000000002	53.008896	53.001238999999998	Центральная	0103000020E6100000010000000500000026DF6C73632A4C40683D7C9928804A4026DF6C73632A4C4059880E8123814A406F9F55664A2D4C4059880E8123814A406F9F55664A2D4C40683D7C9928804A4026DF6C73632A4C40683D7C9928804A40
65907	12820	55.996295000000003	56.007720999999997	52.585031000000001	52.579996999999999	Школьная	0103000020E610000001000000050000008C15359886FF4B40996379573D4A4A408C15359886FF4B40B612BA4BE24A4A40073F7100FD004C40B612BA4BE24A4A40073F7100FD004C40996379573D4A4A408C15359886FF4B40996379573D4A4A40
64997	13075	55.929451	55.939602000000001	52.549258999999999	52.534669000000001	Школьная	0103000020E61000000100000005000000041E1840F8F64B40AF97A60870444A40041E1840F8F64B404F04711E4E464A40CBA0DAE044F84B404F04711E4E464A40CBA0DAE044F84B40AF97A60870444A40041E1840F8F64B40AF97A60870444A40
65416	12041	55.547136999999999	55.570556000000003	52.804102999999998	52.792603	Искужина	0103000020E610000001000000050000003DB7D09508C64B4012DBDD0374654A403DB7D09508C64B40C8CEDBD8EC664A40AF44A0FA07C94B40C8CEDBD8EC664A40AF44A0FA07C94B4012DBDD0374654A403DB7D09508C64B4012DBDD0374654A40
64399	13697	55.561366	55.584829999999997	52.566598999999997	52.555813999999998	Талгата Азнабаева	0103000020E610000001000000050000000D8B51D7DAC74B405854C4E924474A400D8B51D7DAC74B402079E75086484A401EDC9DB5DBCA4B402079E75086484A401EDC9DB5DBCA4B405854C4E924474A400D8B51D7DAC74B405854C4E924474A40
66804	58875	55.105902	56.202907000000003	52.962105000000001	52.346147000000002	Баяна	0103000020E610000001000000050000005E4A5D328E8D4B40E44D7E8B4E2C4A405E4A5D328E8D4B40B728B341267B4A40939048DBF8194C40B728B341267B4A40939048DBF8194C40E44D7E8B4E2C4A405E4A5D328E8D4B40E44D7E8B4E2C4A40
65080	13636	55.543723	55.564689999999999	52.635050999999997	52.621062999999999	Центральная	0103000020E61000000100000005000000A08A1BB798C54B40B9E00CFE7E4F4A40A08A1BB798C54B406325E65949514A406A300DC347C84B406325E65949514A406A300DC347C84B40B9E00CFE7E4F4A40A08A1BB798C54B40B9E00CFE7E4F4A40
64999	13605	55.683186999999997	55.693868000000002	52.522818000000001	52.512383999999997	Биктеевская	0103000020E61000000100000005000000B306EFAB72D74B40307F85CC95414A40B306EFAB72D74B404CE141B3EB424A40D7DEA7AAD0D84B404CE141B3EB424A40D7DEA7AAD0D84B40307F85CC95414A40B306EFAB72D74B40307F85CC95414A40
66123	13192	55.79898	55.806552000000003	52.497968	52.489513000000002	Кооперативная	0103000020E610000001000000050000003C1405FA44E64B40C2FBAA5CA83E4A403C1405FA44E64B402E3A596ABD3F4A40FF428F183DE74B402E3A596ABD3F4A40FF428F183DE74B40C2FBAA5CA83E4A403C1405FA44E64B40C2FBAA5CA83E4A40
65159	12325	55.832234999999997	55.851854000000003	52.906531000000001	52.896901	Дружбы	0103000020E6100000010000000500000014CB2DAD86EA4B40F65FE7A6CD724A4014CB2DAD86EA4B40B4E7323509744A40C07B478D09ED4B40B4E7323509744A40C07B478D09ED4B40F65FE7A6CD724A4014CB2DAD86EA4B40F65FE7A6CD724A40
66812	3948	55.692404000000003	55.721141000000003	52.734972999999997	52.720750000000002	Мира	0103000020E610000001000000050000004FCFBBB1A0D84B40C74B3789415C4A404FCFBBB1A0D84B40B4386398135E4A40026729594EDC4B40B4386398135E4A40026729594EDC4B40C74B3789415C4A404FCFBBB1A0D84B40C74B3789415C4A40
64987	12408	55.620798999999998	55.645386000000002	52.744208999999998	52.731259999999999	Дружбы	0103000020E61000000100000005000000DB31755776CF4B40BD6F7CED995D4A40DB31755776CF4B40C631923D425F4A40ECA529029CD24B40C631923D425F4A40ECA529029CD24B40BD6F7CED995D4A40DB31755776CF4B40BD6F7CED995D4A40
66101	11921	55.425325000000001	55.451546999999998	52.763907000000003	52.744073	Гагарина	0103000020E61000000100000005000000EA95B20C71B64B40166BB8C83D5F4A40EA95B20C71B64B40BE175FB4C7614A40AFCDC64ACCB94B40BE175FB4C7614A40AFCDC64ACCB94B40166BB8C83D5F4A40EA95B20C71B64B40166BB8C83D5F4A40
63570	12760	56.083556999999999	56.095872999999997	52.671335999999997	52.664603	Карла Маркса	0103000020E610000001000000050000000A2DEBFEB10A4C4068E90AB611554A400A2DEBFEB10A4C4050508A56EE554A40E2C80391450C4C4050508A56EE554A40E2C80391450C4C4068E90AB611554A400A2DEBFEB10A4C4068E90AB611554A40
9805	11947	55.449733000000002	55.472136999999996	52.793545000000002	52.780206999999997	Ленина	0103000020E610000001000000050000004B77D7D990B94B401D8EAED2DD634A404B77D7D990B94B40C173EFE192654A40A31D37FC6EBC4B40C173EFE192654A40A31D37FC6EBC4B401D8EAED2DD634A404B77D7D990B94B401D8EAED2DD634A40
64988	12236	55.660927000000001	55.681372000000003	52.845148000000002	52.829752999999997	Школьная	0103000020E610000001000000050000008E05854199D44B400261A758356A4A408E05854199D44B40D12346CF2D6C4A407F349C3237D74B40D12346CF2D6C4A407F349C3237D74B400261A758356A4A408E05854199D44B400261A758356A4A40
64381	13290	55.773755000000001	55.790832000000002	52.431151	52.418222999999998	Парковая	0103000020E61000000100000005000000E90E62670AE34B40AEB7CD5488354A40E90E62670AE34B40A051BAF42F374A40AD50A4FB39E54B40A051BAF42F374A40AD50A4FB39E54B40AEB7CD5488354A40E90E62670AE34B40AEB7CD5488354A40
64992	13435	55.634058000000003	55.649042000000001	52.408396000000003	52.400666000000001	Бязита Бикбая	0103000020E6100000010000000500000033E202D028D14B40404F030649334A4033E202D028D14B409BE8F35146344A407FDDE9CE13D34B409BE8F35146344A407FDDE9CE13D34B40404F030649334A4033E202D028D14B40404F030649334A40
64995	13001	55.83343	55.845278999999998	52.649745000000003	52.630482000000001	Новоотрадинская	0103000020E61000000100000005000000ADC090D5ADEA4B40BC5B59A2B3504A40ADC090D5ADEA4B40A9DE1AD82A534A406F7F2E1A32EC4B40A9DE1AD82A534A406F7F2E1A32EC4B40BC5B59A2B3504A40ADC090D5ADEA4B40BC5B59A2B3504A40
65910	13502	55.525334999999998	55.538558000000002	52.403973999999998	52.398045000000003	Молодежная	0103000020E61000000100000005000000DA38622D3EC34B400DAB7823F3324A40DA38622D3EC34B409737876BB5334A40E57FF277EFC44B409737876BB5334A40E57FF277EFC44B400DAB7823F3324A40DA38622D3EC34B400DAB7823F3324A40
65899	11709	55.709085000000002	55.729145000000003	52.630422000000003	52.616284	Школьная	0103000020E61000000100000005000000C68A1A4CC3DA4B402786E464E24E4A40C68A1A4CC3DA4B40E75608ABB1504A405E85949F54DD4B40E75608ABB1504A405E85949F54DD4B402786E464E24E4A40C68A1A4CC3DA4B402786E464E24E4A40
66106	12161	55.204618000000004	55.224758999999999	52.955601000000001	52.947673999999999	Центральная	0103000020E61000000100000005000000231631EC309A4B407FA2B2614D794A40231631EC309A4B4030833122517A4A40A73D25E7C49C4B4030833122517A4A40A73D25E7C49C4B407FA2B2614D794A40231631EC309A4B407FA2B2614D794A40
65897	12137	55.315677000000001	55.329492999999999	52.896292000000003	52.885111000000002	Школьная	0103000020E61000000100000005000000B98C9B1A68A84B40392A37514B714A40B98C9B1A68A84B404ED53DB2B9724A4066A19DD32CAA4B404ED53DB2B9724A4066A19DD32CAA4B40392A37514B714A40B98C9B1A68A84B40392A37514B714A40
65081	12574	55.95711	55.979793000000001	52.884611	52.870148999999998	Заки Валиди	0103000020E6100000010000000500000058569A9482FA4B40D4D2DC0A616F4A4058569A9482FA4B404757E9EE3A714A40C4EC65DB69FD4B404757E9EE3A714A40C4EC65DB69FD4B40D4D2DC0A616F4A4058569A9482FA4B40D4D2DC0A616F4A40
66644	4235	55.556111000000001	55.569837	52.500473	52.493997999999998	Школьная	0103000020E6100000010000000500000012F92EA52EC74B400B2593533B3F4A4012F92EA52EC74B40F8C3CF7F0F404A407F86376BF0C84B40F8C3CF7F0F404A407F86376BF0C84B400B2593533B3F4A4012F92EA52EC74B400B2593533B3F4A40
65415	13564	55.530689000000002	55.539231999999998	52.528517000000001	52.519705999999999	Школьная	0103000020E6100000010000000500000069ACFD9DEDC34B407AC4E8B985424A4069ACFD9DEDC34B40A530EF71A6434A40747ADE8D05C54B40A530EF71A6434A40747ADE8D05C54B407AC4E8B985424A4069ACFD9DEDC34B407AC4E8B985424A40
66103	12693	56.034787000000001	56.054729999999999	52.694882	52.678369000000004	Школьная	0103000020E61000000100000005000000B9A981E673044C4064CF9ECBD4564A40B9A981E673044C401F4AB4E4F1584A40170E846401074C401F4AB4E4F1584A40170E846401074C4064CF9ECBD4564A40B9A981E673044C4064CF9ECBD4564A40
66939	29476	55.696626000000002	55.705519000000002	52.422584000000001	52.413339999999998	Горная	0103000020E610000001000000050000008BC56F0A2BD94B4077103B53E8344A408BC56F0A2BD94B400CE8853B17364A4073DA53724EDA4B400CE8853B17364A4073DA53724EDA4B4077103B53E8344A408BC56F0A2BD94B4077103B53E8344A40
65001	12395	55.731892999999999	55.743032999999997	52.794722	52.783203	Центральная	0103000020E61000000100000005000000EE9579ABAEDD4B408690F3FE3F644A40EE9579ABAEDD4B40B3B45373B9654A40A46C91B41BDF4B40B3B45373B9654A40A46C91B41BDF4B408690F3FE3F644A40EE9579ABAEDD4B408690F3FE3F644A40
66886	3239	55.771383	55.794280999999998	52.869213999999999	52.859684000000001	Набережная	0103000020E610000001000000050000005ED89AADBCE24B407E7214200A6E4A405ED89AADBCE24B40D89C8367426F4A40C66AF3FFAAE54B40D89C8367426F4A40C66AF3FFAAE54B407E7214200A6E4A405ED89AADBCE24B407E7214200A6E4A40
64104	12057	55.404961	55.435827000000003	52.87885	52.861586000000003	Школьная	0103000020E61000000100000005000000E69315C3D5B34B4082583673486E4A40E69315C3D5B34B40780B24287E704A405EDBDB2DC9B74B40780B24287E704A405EDBDB2DC9B74B4082583673486E4A40E69315C3D5B34B4082583673486E4A40
63419	3292	55.778579000000001	55.829352	52.726815000000002	52.677588999999998	проспект Мира	0103000020E610000001000000050000001B2D077AA8E34B408E90813CBB564A401B2D077AA8E34B40029F1F46085D4A40A46FD23428EA4B40029F1F46085D4A40A46FD23428EA4B408E90813CBB564A401B2D077AA8E34B408E90813CBB564A40
66821	3292	55.778579000000001	55.829352	52.726815000000002	52.677588999999998	Чапаева	0103000020E610000001000000050000001B2D077AA8E34B408E90813CBB564A401B2D077AA8E34B40029F1F46085D4A40A46FD23428EA4B40029F1F46085D4A40A46FD23428EA4B408E90813CBB564A401B2D077AA8E34B408E90813CBB564A40
63600	3292	55.778579000000001	55.829352	52.726815000000002	52.677588999999998	Советская	0103000020E610000001000000050000001B2D077AA8E34B408E90813CBB564A401B2D077AA8E34B40029F1F46085D4A40A46FD23428EA4B40029F1F46085D4A40A46FD23428EA4B408E90813CBB564A401B2D077AA8E34B408E90813CBB564A40
64295	3292	55.778579000000001	55.829352	52.726815000000002	52.677588999999998	Калинина	0103000020E610000001000000050000001B2D077AA8E34B408E90813CBB564A401B2D077AA8E34B40029F1F46085D4A40A46FD23428EA4B40029F1F46085D4A40A46FD23428EA4B408E90813CBB564A401B2D077AA8E34B408E90813CBB564A40
63739	3292	55.778579000000001	55.829352	52.726815000000002	52.677588999999998	Ватутина	0103000020E610000001000000050000001B2D077AA8E34B408E90813CBB564A401B2D077AA8E34B40029F1F46085D4A40A46FD23428EA4B40029F1F46085D4A40A46FD23428EA4B408E90813CBB564A401B2D077AA8E34B408E90813CBB564A40
64993	12882	55.892691999999997	55.905349000000001	52.614528999999997	52.606250000000003	Баянская	0103000020E610000001000000050000004EB340BB43F24B409A999999994D4A404EB340BB43F24B40C7B8E2E2A84E4A40B03BDD79E2F34B40C7B8E2E2A84E4A40B03BDD79E2F34B409A999999994D4A404EB340BB43F24B409A999999994D4A40
66809	12505	55.943697999999998	55.984310999999998	52.842292	52.829360999999999	Школьная	0103000020E610000001000000050000007AA69718CBF84B40F7C95180286A4A407AA69718CBF84B405AD76839D06B4A40E90B21E7FDFD4B405AD76839D06B4A40E90B21E7FDFD4B40F7C95180286A4A407AA69718CBF84B40F7C95180286A4A40
66872	12923	55.898890000000002	55.915948999999998	52.66516	52.643968999999998	Советская	0103000020E61000000100000005000000C959D8D30EF34B40A45181936D524A40C959D8D30EF34B40BE4D7FF623554A40E6E61BD13DF54B40BE4D7FF623554A40E6E61BD13DF54B40A45181936D524A40C959D8D30EF34B40A45181936D524A40
66811	4115	55.914746000000001	55.932136999999997	52.763460000000002	52.747261999999999	Рабочая	0103000020E61000000100000005000000CB129D6516F54B4093C5FD47A65F4A40CB129D6516F54B40EFE6A90EB9614A401E32E54350F74B40EFE6A90EB9614A401E32E54350F74B4093C5FD47A65F4A40CB129D6516F54B4093C5FD47A65F4A40
66119	13134	55.817726999999998	55.836511000000002	52.488042999999998	52.478313999999997	Молодежная	0103000020E6100000010000000500000031074147ABE84B40069CA564393D4A4031074147ABE84B4057056A31783E4A4044DFDDCA12EB4B4057056A31783E4A4044DFDDCA12EB4B40069CA564393D4A4031074147ABE84B40069CA564393D4A40
66287	58740	55.999861000000003	56.008071999999999	54.843746000000003	54.839007000000002	40 лет Победы	0103000020E61000000100000005000000DFC5FB71FBFF4B40BB0ED594646B4B40DFC5FB71FBFF4B40BF1072DEFF6B4B40B401D88008014C40BF1072DEFF6B4B40B401D88008014C40BB0ED594646B4B40DFC5FB71FBFF4B40BB0ED594646B4B40
65412	10218	55.198824000000002	55.216718999999998	55.120835	55.111505999999999	Молодежная	0103000020E6100000010000000500000078D4981073994B4065A71FD4458E4B4078D4981073994B40289B7285778F4B40FEB5BC72BD9B4B40289B7285778F4B40FEB5BC72BD9B4B4065A71FD4458E4B4078D4981073994B4065A71FD4458E4B40
66082	10014	55.130741	55.162118999999997	55.166058	55.158369	Речная	0103000020E61000000100000005000000889FFF1EBC904B40A1D9756F45944B40889FFF1EBC904B409D9E776341954B40B587BD50C0944B409D9E776341954B40B587BD50C0944B40A1D9756F45944B40889FFF1EBC904B40A1D9756F45944B40
64981	11155	55.301977999999998	55.344701999999998	54.943731999999997	54.929855000000003	Мира	0103000020E61000000100000005000000450E1137A7A64B40D482177D05774B40450E1137A7A64B402618CE35CC784B40D26EF4311FAC4B402618CE35CC784B40D26EF4311FAC4B40D482177D05774B40450E1137A7A64B40D482177D05774B40
64683	10071	55.019601000000002	55.046622999999997	55.197256000000003	55.177694000000002	Победы	0103000020E6100000010000000500000005FC1A4982824B4004594FADBE964B4005FC1A4982824B404B7842AF3F994B40E61E12BEF7854B404B7842AF3F994B40E61E12BEF7854B4004594FADBE964B4005FC1A4982824B4004594FADBE964B40
63317	9418	55.384810999999999	55.405966999999997	55.092891000000002	55.072231000000002	Кирова	0103000020E610000001000000050000000E12A27C41B14B40F2608BDD3E894B400E12A27C41B14B40DF8B2FDAE38B4B40AB2006BAF6B34B40DF8B2FDAE38B4B40AB2006BAF6B34B40F2608BDD3E894B400E12A27C41B14B40F2608BDD3E894B40
65406	10523	55.440300000000001	55.459614000000002	54.855682999999999	54.842163999999997	Школьная	0103000020E61000000100000005000000E3361AC05BB84B402CEFAA07CC6B4B40E3361AC05BB84B40205F4205876D4B405264ADA1D4BA4B40205F4205876D4B405264ADA1D4BA4B402CEFAA07CC6B4B40E3361AC05BB84B402CEFAA07CC6B4B40
64314	10960	55.250413999999999	55.285286999999997	54.948086000000004	54.927801000000002	Центральная	0103000020E61000000100000005000000F33AE2900DA04B401A19E42EC2764B40F33AE2900DA04B40D2E5CDE15A794B40AA7CCF4884A44B40D2E5CDE15A794B40AA7CCF4884A44B401A19E42EC2764B40F33AE2900DA04B401A19E42EC2764B40
64370	10629	55.756354999999999	55.777869000000003	54.961336000000003	54.939025999999998	Школьная	0103000020E6100000010000000500000042959A3DD0E04B40FE0B040132784B4042959A3DD0E04B40D63BDC0E0D7B4B403FC91D3691E34B40D63BDC0E0D7B4B403FC91D3691E34B40FE0B040132784B4042959A3DD0E04B40FE0B040132784B40
64172	10703	55.265847000000001	55.298150999999997	55.096167000000001	55.077803000000003	Парковая	0103000020E61000000100000005000000AF5E454607A24B40EE43DE72F5894B40AF5E454607A24B402BFA43334F8C4B408522DDCF29A64B402BFA43334F8C4B408522DDCF29A64B40EE43DE72F5894B40AF5E454607A24B40EE43DE72F5894B40
64367	10415	55.290039	55.323959000000002	54.840614000000002	54.817655999999999	Валиева	0103000020E6100000010000000500000043C879FF1FA54B4068B0A9F3A8684B4043C879FF1FA54B40A647533D996B4B40581F0F7D77A94B40A647533D996B4B40581F0F7D77A94B4068B0A9F3A8684B4043C879FF1FA54B4068B0A9F3A8684B40
66784	9924	55.028072000000002	55.040604000000002	55.278477000000002	55.262675000000002	Коммунаров	0103000020E6100000010000000500000077F700DD97834B40083D9B559FA14B4077F700DD97834B4017D86322A5A34B401C0B0A8332854B4017D86322A5A34B401C0B0A8332854B40083D9B559FA14B4077F700DD97834B40083D9B559FA14B40
65586	10288	55.08587	55.102103	55.084842999999999	55.071407000000001	Пролетарская	0103000020E6100000010000000500000090DAC4C9FD8A4B404DDA54DD23894B4090DAC4C9FD8A4B40B325AB22DC8A4B4068E90AB6118D4B40B325AB22DC8A4B4068E90AB6118D4B404DDA54DD23894B4090DAC4C9FD8A4B404DDA54DD23894B40
66087	10569	55.718266	55.748530000000002	55.019815999999999	55.002000000000002	Парковая	0103000020E6100000010000000500000014EAE923F0DB4B40C74B378941804B4014EAE923F0DB4B4001F8A75489824B409609BFD4CFDF4B4001F8A75489824B409609BFD4CFDF4B40C74B378941804B4014EAE923F0DB4B40C74B378941804B40
65411	11061	55.284730000000003	55.302804000000002	55.012278999999999	54.997914999999999	Центральная	0103000020E6100000010000000500000055185B0872A44B400B98C0ADBB7F4B4055185B0872A44B40BBB6B75B92814B408B8C0E48C2A64B40BBB6B75B92814B408B8C0E48C2A64B400B98C0ADBB7F4B4055185B0872A44B400B98C0ADBB7F4B40
65893	10800	55.163350000000001	55.181145000000001	55.025834000000003	55.013142000000002	Центральная	0103000020E610000001000000050000009BE61DA7E8944B401E1A16A3AE814B409BE61DA7E8944B40FC8F4C874E834B40BE6A65C22F974B40FC8F4C874E834B40BE6A65C22F974B401E1A16A3AE814B409BE61DA7E8944B401E1A16A3AE814B40
66085	10478	55.283841000000002	55.313125999999997	54.888910000000003	54.882064	Новая	0103000020E61000000100000005000000C921E2E654A44B404E7D2079E7704B40C921E2E654A44B402F8B89CDC7714B407EC3448314A84B402F8B89CDC7714B407EC3448314A84B404E7D2079E7704B40C921E2E654A44B404E7D2079E7704B40
65405	9663	55.581730999999998	55.604565999999998	55.058610999999999	55.047286	Трактовая	0103000020E61000000100000005000000E108522976CA4B4082C7B7770D864B40E108522976CA4B40CA17B49080874B4003232F6B62CD4B40CA17B49080874B4003232F6B62CD4B4082C7B7770D864B40E108522976CA4B4082C7B7770D864B40
66098	11249	55.564438000000003	55.606631999999998	55.008479999999999	54.992688999999999	Центральная	0103000020E61000000100000005000000514F1F813FC84B40AA0CE36E107F4B40514F1F813FC84B40C55565DF15814B40815A0C1EA6CD4B40C55565DF15814B40815A0C1EA6CD4B40AA0CE36E107F4B40514F1F813FC84B40AA0CE36E107F4B40
63735	9117	55.324202	55.389474	55.123821	55.090350999999998	Терешковой	0103000020E610000001000000050000001EA67D737FA94B4098141F9F908B4B401EA67D737FA94B406DC7D45DD98F4B403752B648DAB14B406DC7D45DD98F4B403752B648DAB14B4098141F9F908B4B401EA67D737FA94B4098141F9F908B4B40
63596	9117	55.324202	55.389474	55.123821	55.090350999999998	Советская	0103000020E610000001000000050000001EA67D737FA94B4098141F9F908B4B401EA67D737FA94B406DC7D45DD98F4B403752B648DAB14B406DC7D45DD98F4B403752B648DAB14B4098141F9F908B4B401EA67D737FA94B4098141F9F908B4B40
63599	9117	55.324202	55.389474	55.123821	55.090350999999998	Октябрьская	0103000020E610000001000000050000001EA67D737FA94B4098141F9F908B4B401EA67D737FA94B406DC7D45DD98F4B403752B648DAB14B406DC7D45DD98F4B403752B648DAB14B4098141F9F908B4B401EA67D737FA94B4098141F9F908B4B40
66782	9117	55.324202	55.389474	55.123821	55.090350999999998	Мичурина	0103000020E610000001000000050000001EA67D737FA94B4098141F9F908B4B401EA67D737FA94B406DC7D45DD98F4B403752B648DAB14B406DC7D45DD98F4B403752B648DAB14B4098141F9F908B4B401EA67D737FA94B4098141F9F908B4B40
63661	9117	55.324202	55.389474	55.123821	55.090350999999998	Большевистская	0103000020E610000001000000050000001EA67D737FA94B4098141F9F908B4B401EA67D737FA94B406DC7D45DD98F4B403752B648DAB14B406DC7D45DD98F4B403752B648DAB14B4098141F9F908B4B401EA67D737FA94B4098141F9F908B4B40
64162	9970	55.112056000000003	55.137379000000003	55.212862999999999	55.193119000000003	Ленина	0103000020E6100000010000000500000009A9DBD9578E4B403D9E961FB8984B4009A9DBD9578E4B40A4C343183F9B4B401F1494A295914B40A4C343183F9B4B401F1494A295914B403D9E961FB8984B4009A9DBD9578E4B403D9E961FB8984B40
66093	10976	55.202857999999999	55.236868000000001	54.974581999999998	54.958953000000001	школьная	0103000020E61000000100000005000000B1DD3D40F7994B4057B3CEF8BE7A4B40B1DD3D40F7994B4098A25C1ABF7C4B4006BCCCB0519E4B4098A25C1ABF7C4B4006BCCCB0519E4B4057B3CEF8BE7A4B40B1DD3D40F7994B4057B3CEF8BE7A4B40
64976	9497	55.532926000000003	55.557592999999997	55.117910999999999	55.111803999999999	Центральная	0103000020E6100000010000000500000014984EEB36C44B40EFC7ED974F8E4B4014984EEB36C44B40596B28B5178F4B4040BD19355FC74B40596B28B5178F4B4040BD19355FC74B40EFC7ED974F8E4B4014984EEB36C44B40EFC7ED974F8E4B40
64528	11308	55.394979999999997	55.428505000000001	55.009559000000003	54.996454	Дорожная	0103000020E610000001000000050000007B4963B48EB24B40F4FBFECD8B7F4B407B4963B48EB24B40F530B43A39814B4014967840D9B64B40F530B43A39814B4014967840D9B64B40F4FBFECD8B7F4B407B4963B48EB24B40F4FBFECD8B7F4B40
65414	11133	55.354726999999997	55.386788000000003	54.948453000000001	54.939036000000002	Школьная	0103000020E610000001000000050000000C01C0B167AD4B4022E2E65432784B400C01C0B167AD4B4084656CE866794B401D3EE94482B14B4084656CE866794B401D3EE94482B14B4022E2E65432784B400C01C0B167AD4B4022E2E65432784B40
65410	10668	55.777357000000002	55.806947999999998	54.972431999999998	54.954078000000003	Школьная	0103000020E610000001000000050000008928266F80E34B40A3EA573A1F7A4B408928266F80E34B40BCCADAA6787C4B404BC972124AE74B40BCCADAA6787C4B404BC972124AE74B40A3EA573A1F7A4B408928266F80E34B40A3EA573A1F7A4B40
9932	9835	54.940235000000001	54.975727999999997	55.227822000000003	55.204618000000004	Школьная	0103000020E61000000100000005000000FCC6D79E59784B40231631EC309A4B40FCC6D79E59784B4098A77345299D4B404FE5B4A7E47C4B4098A77345299D4B404FE5B4A7E47C4B40231631EC309A4B40FCC6D79E59784B40231631EC309A4B40
64233	9835	54.940235000000001	54.975727999999997	55.227822000000003	55.204618000000004	Коминтерна	0103000020E61000000100000005000000FCC6D79E59784B40231631EC309A4B40FCC6D79E59784B4098A77345299D4B404FE5B4A7E47C4B4098A77345299D4B404FE5B4A7E47C4B40231631EC309A4B40FCC6D79E59784B40231631EC309A4B40
65648	58591	55.181432999999998	55.196874999999999	55.032356	55.021937000000001	Центральная	0103000020E6100000010000000500000024B5503239974B4043C9E4D4CE824B4024B5503239974B4029EACC3D24844B403333333333994B4029EACC3D24844B403333333333994B4043C9E4D4CE824B4024B5503239974B4043C9E4D4CE824B40
65905	11346	55.340372000000002	55.362560000000002	55.005186000000002	54.996572	Парковая	0103000020E61000000100000005000000B03C484F91AB4B40FE0DDAAB8F7F4B40B03C484F91AB4B40D33252EFA9804B403C6BB75D68AE4B40D33252EFA9804B403C6BB75D68AE4B40FE0DDAAB8F7F4B40B03C484F91AB4B40FE0DDAAB8F7F4B40
65890	9849	55.039014000000002	55.056702000000001	55.221522	55.207552	13 лет Октября	0103000020E61000000100000005000000070B2769FE844B40151C5E10919A4B40070B2769FE844B4019AC38D55A9C4B4014CFD90242874B4019AC38D55A9C4B4014CFD90242874B40151C5E10919A4B40070B2769FE844B40151C5E10919A4B40
65755	47332	55.461770000000001	55.474319999999999	55.154018000000001	55.147551	Садовая	0103000020E61000000100000005000000102384471BBB4B40FDBE7FF3E2924B40102384471BBB4B40677FA0DCB6934B405BEB8B84B6BC4B40677FA0DCB6934B405BEB8B84B6BC4B40FDBE7FF3E2924B40102384471BBB4B40FDBE7FF3E2924B40
66095	10883	55.061041000000003	55.079509999999999	54.971826999999998	54.959060999999998	Центральная	0103000020E610000001000000050000008A5B0531D0874B403DEFC682C27A4B408A5B0531D0874B40552FBFD3647C4B403CDA38622D8A4B40552FBFD3647C4B403CDA38622D8A4B403DEFC682C27A4B408A5B0531D0874B403DEFC682C27A4B40
65891	10139	55.245185999999997	55.263108000000003	55.183210000000003	55.165441000000001	Свободы	0103000020E61000000100000005000000F1B73D41629F4B407235B22B2D954B40F1B73D41629F4B406C26DF6C73974B4072A8DF85ADA14B406C26DF6C73974B4072A8DF85ADA14B407235B22B2D954B40F1B73D41629F4B407235B22B2D954B40
66081	9706	55.022376999999999	55.046442999999996	55.044738000000002	55.015830999999999	Центральная	0103000020E610000001000000050000005F97E13FDD824B40A9A10DC006824B405F97E13FDD824B40B9718BF9B9854B4066101FD8F1854B40B9718BF9B9854B4066101FD8F1854B40A9A10DC006824B405F97E13FDD824B40A9A10DC006824B40
64447	9465	55.479376999999999	55.518732	55.108193999999997	55.088785000000001	Центральная	0103000020E6100000010000000500000030BABC395CBD4B400CB08F4E5D8B4B4030BABC395CBD4B40CCCF0D4DD98D4B40C0B167CF65C24B40CCCF0D4DD98D4B40C0B167CF65C24B400CB08F4E5D8B4B4030BABC395CBD4B400CB08F4E5D8B4B40
65886	9570	55.657468000000001	55.674805999999997	55.16686	55.157108999999998	Центральная	0103000020E61000000100000005000000511553E927D44B402174D0251C944B40511553E927D44B405A8121AB5B954B408192020B60D64B405A8121AB5B954B408192020B60D64B402174D0251C944B40511553E927D44B402174D0251C944B40
65397	7832	56.444374000000003	56.460436000000001	52.589861999999997	52.574590000000001	М. Гафури	0103000020E61000000100000005000000AB984A3FE1384C40E84D452A8C494A40AB984A3FE1384C409A931799804B4A4056F31C91EF3A4C409A931799804B4A4056F31C91EF3A4C40E84D452A8C494A40AB984A3FE1384C40E84D452A8C494A40
65896	6426	56.441769000000001	56.458683999999998	52.874220000000001	52.863793999999999	Центральная	0103000020E610000001000000050000007DB1F7E28B384C40923D42CD906E4A407DB1F7E28B384C402BC1E270E66F4A4067994528B63A4C402BC1E270E66F4A4067994528B63A4C40923D42CD906E4A407DB1F7E28B384C40923D42CD906E4A40
66058	6426	56.441769000000001	56.458683999999998	52.874220000000001	52.863793999999999	Мира	0103000020E610000001000000050000007DB1F7E28B384C40923D42CD906E4A407DB1F7E28B384C402BC1E270E66F4A4067994528B63A4C402BC1E270E66F4A4067994528B63A4C40923D42CD906E4A407DB1F7E28B384C40923D42CD906E4A40
64380	7170	56.372284000000001	56.400841999999997	52.914797	52.880155000000002	Школьная	0103000020E610000001000000050000007B698A00A72F4C40983446EBA8704A407B698A00A72F4C404DBD6E1118754A407E6E68CA4E334C404DBD6E1118754A407E6E68CA4E334C40983446EBA8704A407B698A00A72F4C40983446EBA8704A40
63410	7170	56.372284000000001	56.400841999999997	52.914797	52.880155000000002	Строителей	0103000020E610000001000000050000007B698A00A72F4C40983446EBA8704A407B698A00A72F4C404DBD6E1118754A407E6E68CA4E334C404DBD6E1118754A407E6E68CA4E334C40983446EBA8704A407B698A00A72F4C40983446EBA8704A40
64954	7170	56.372284000000001	56.400841999999997	52.914797	52.880155000000002	Равенства	0103000020E610000001000000050000007B698A00A72F4C40983446EBA8704A407B698A00A72F4C404DBD6E1118754A407E6E68CA4E334C404DBD6E1118754A407E6E68CA4E334C40983446EBA8704A407B698A00A72F4C40983446EBA8704A40
66802	7170	56.372284000000001	56.400841999999997	52.914797	52.880155000000002	Комсомольская	0103000020E610000001000000050000007B698A00A72F4C40983446EBA8704A407B698A00A72F4C404DBD6E1118754A407E6E68CA4E334C404DBD6E1118754A407E6E68CA4E334C40983446EBA8704A407B698A00A72F4C40983446EBA8704A40
66152	58717	55.980421	57.182384999999996	53.005113999999999	52.233711999999997	З. Биишевой	0103000020E61000000100000005000000E3A7716F7EFD4B4064575A46EA1D4A40E3A7716F7EFD4B4039605793A7804A40F623456458974C4039605793A7804A40F623456458974C4064575A46EA1D4A40E3A7716F7EFD4B4064575A46EA1D4A40
66378	58760	56.241328000000003	56.273119000000001	52.883871999999997	52.877409999999998	Речная	0103000020E61000000100000005000000F7CDFDD5E31E4C4078978BF84E704A40F7CDFDD5E31E4C40D0ECBAB722714A4047753A90F5224C40D0ECBAB722714A4047753A90F5224C4078978BF84E704A40F7CDFDD5E31E4C4078978BF84E704A40
64952	7046	56.542856999999998	56.563042000000003	52.869506999999999	52.855528999999997	Школьная	0103000020E61000000100000005000000CCB392567C454C40C9E369F9816D4A40CCB392567C454C40505260014C6F4A402123A0C211484C40505260014C6F4A402123A0C211484C40C9E369F9816D4A40CCB392567C454C40C9E369F9816D4A40
64983	58426	56.727091999999999	56.744321999999997	52.669283	52.659194999999997	З. Валиди	0103000020E610000001000000050000007497C459115D4C40E657738060544A407497C459115D4C406762BA10AB554A40BED87BF1455F4C406762BA10AB554A40BED87BF1455F4C40E657738060544A407497C459115D4C40E657738060544A40
65409	58541	56.756816999999998	56.767049	52.522725000000001	52.517316999999998	Мира	0103000020E6100000010000000500000046072461DF604C401955867137424A4046072461DF604C409BE61DA7E8424A40FAB660A92E624C409BE61DA7E8424A40FAB660A92E624C401955867137424A4046072461DF604C401955867137424A40
66070	8175	56.468341000000002	56.482785999999997	52.346873000000002	52.339686999999998	Школьная	0103000020E610000001000000050000001F300F99F23B4C402CF015DD7A2B4A401F300F99F23B4C40C66E9F55662C4A40BB7B80EECB3D4C40C66E9F55662C4A40BB7B80EECB3D4C402CF015DD7A2B4A401F300F99F23B4C402CF015DD7A2B4A40
65381	6630	56.302898999999996	56.326650000000001	52.669725	52.662320000000001	Молодежная	0103000020E61000000100000005000000DC7EF964C5264C404DBED9E6C6544A40DC7EF964C5264C4024287E8CB9554A40849ECDAACF294C4024287E8CB9554A40849ECDAACF294C404DBED9E6C6544A40DC7EF964C5264C404DBED9E6C6544A40
66057	6716	56.330755000000003	56.355172000000003	52.606490999999998	52.595863000000001	Сэнкем	0103000020E6100000010000000500000087FE092E562A4C40BFF2203D454C4A4087FE092E562A4C40BF28417FA14D4A403B3AAE46762D4C40BF28417FA14D4A403B3AAE46762D4C40BFF2203D454C4A4087FE092E562A4C40BFF2203D454C4A40
64940	6149	56.623938000000003	56.641716000000002	52.769018000000003	52.761476000000002	Х. Давлетшиной	0103000020E61000000100000005000000A75D4C33DD4F4C402E58AA0B78614A40A75D4C33DD4F4C4086048C2E6F624A40F4A8F8BF23524C4086048C2E6F624A40F4A8F8BF23524C402E58AA0B78614A40A75D4C33DD4F4C402E58AA0B78614A40
64947	6978	56.397491000000002	56.416463999999998	52.873469999999998	52.85622	Колхозная	0103000020E6100000010000000500000028BA2EFCE0324C402F17F19D986D4A4028BA2EFCE0324C40C0046EDDCD6F4A400DFB3DB14E354C40C0046EDDCD6F4A400DFB3DB14E354C402F17F19D986D4A4028BA2EFCE0324C402F17F19D986D4A40
64579	8823	56.77393	56.799748000000001	52.604117000000002	52.593401999999998	Пушкина	0103000020E6100000010000000500000057B2632310634C40C4B0C398F44B4A4057B2632310634C4094FAB2B4534D4A404D8578245E664C4094FAB2B4534D4A404D8578245E664C40C4B0C398F44B4A4057B2632310634C40C4B0C398F44B4A40
64979	8542	56.537018000000003	56.54645	52.526603999999999	52.518872999999999	Молодежная	0103000020E6100000010000000500000082AE7D01BD444C4082E3326E6A424A4082AE7D01BD444C40ADF886C267434A401973D712F2454C40ADF886C267434A401973D712F2454C4082E3326E6A424A4082AE7D01BD444C4082E3326E6A424A40
65392	7724	56.527324999999998	56.540906999999997	52.606048000000001	52.592745000000001	Верхняя	0103000020E610000001000000050000007DAEB6627F434C400BEF7211DF4B4A407DAEB6627F434C4032E719FB924D4A40B796C9703C454C4032E719FB924D4A40B796C9703C454C400BEF7211DF4B4A407DAEB6627F434C400BEF7211DF4B4A40
63582	1085	56.515861999999998	56.526282999999999	52.974952999999999	52.969427000000003	Пугачева	0103000020E61000000100000005000000E49F19C407424C40016E162F167C4A40E49F19C407424C408C118942CB7C4A406BB8C83D5D434C408C118942CB7C4A406BB8C83D5D434C40016E162F167C4A40E49F19C407424C40016E162F167C4A40
63237	1085	56.515861999999998	56.526282999999999	52.974952999999999	52.969427000000003	Ленина	0103000020E61000000100000005000000E49F19C407424C40016E162F167C4A40E49F19C407424C408C118942CB7C4A406BB8C83D5D434C408C118942CB7C4A406BB8C83D5D434C40016E162F167C4A40E49F19C407424C40016E162F167C4A40
64943	6809	56.328733999999997	56.377558000000001	52.733468000000002	52.702838999999997	Советская	0103000020E61000000100000005000000A88AA9F4132A4C403AADDBA0F6594A40A88AA9F4132A4C40CE548847E25D4A40ED2B0FD253304C40CE548847E25D4A40ED2B0FD253304C403AADDBA0F6594A40A88AA9F4132A4C403AADDBA0F6594A40
66848	27601	57.123617000000003	57.145176999999997	52.72195	52.712595	Советская	0103000020E61000000100000005000000651D8EAED28F4C4085251E50365B4A40651D8EAED28F4C4071AC8BDB685C4A40D190F12895924C4071AC8BDB685C4A40D190F12895924C4085251E50365B4A40651D8EAED28F4C4085251E50365B4A40
65887	9024	56.677694000000002	56.695408	52.561864	52.551105	Салавата Юлаева	0103000020E6100000010000000500000004594FADBE564C40BFD4CF9B8A464A4004594FADBE564C405E66D828EB474A403AB01C2103594C405E66D828EB474A403AB01C2103594C40BFD4CF9B8A464A4004594FADBE564C40BFD4CF9B8A464A40
65402	58539	56.733801999999997	56.752442000000002	52.631864999999998	52.622517000000002	Оло Ик	0103000020E61000000100000005000000A4DE5339ED5D4C401E1A16A3AE4F4A40A4DE5339ED5D4C40573ECBF3E0504A408411FB0450604C40573ECBF3E0504A408411FB0450604C401E1A16A3AE4F4A40A4DE5339ED5D4C401E1A16A3AE4F4A40
65878	6262	56.535338000000003	56.551606	52.657677	52.643428	Заозерная	0103000020E610000001000000050000002D27A1F485444C4054AA44D95B524A402D27A1F485444C406B2A8BC22E544A40812381069B464C406B2A8BC22E544A40812381069B464C4054AA44D95B524A402D27A1F485444C4054AA44D95B524A40
64961	7709	56.4938	56.509619000000001	52.624977000000001	52.606228000000002	Центральная	0103000020E61000000100000005000000E561A1D6343F4C40B2F50CE1984D4A40E561A1D6343F4C4048E00F3FFF4F4A40CA3505323B414C4048E00F3FFF4F4A40CA3505323B414C40B2F50CE1984D4A40E561A1D6343F4C40B2F50CE1984D4A40
66198	7709	56.4938	56.509619000000001	52.624977000000001	52.606228000000002	Гафури	0103000020E61000000100000005000000E561A1D6343F4C40B2F50CE1984D4A40E561A1D6343F4C4048E00F3FFF4F4A40CA3505323B414C4048E00F3FFF4F4A40CA3505323B414C40B2F50CE1984D4A40E561A1D6343F4C40B2F50CE1984D4A40
65879	7374	56.494734000000001	56.512537999999999	52.962831999999999	52.953127000000002	Победы	0103000020E61000000100000005000000111C9771533F4C40A1F7C610007A4A40111C9771533F4C4069C537143E7B4A4087FA5DD89A414C4069C537143E7B4A4087FA5DD89A414C40A1F7C610007A4A40111C9771533F4C40A1F7C610007A4A40
65885	8157	56.484071	56.496971000000002	52.315426000000002	52.286662999999997	Центральная	0103000020E6100000010000000500000094F8DC09F63D4C4093FC885FB1244A4094F8DC09F63D4C40702711E15F284A40BC07E8BE9C3F4C40702711E15F284A40BC07E8BE9C3F4C4093FC885FB1244A4094F8DC09F63D4C4093FC885FB1244A40
66595	58291	55.980421	57.182384999999996	53.005113999999999	52.233711999999997	Молодежная	0103000020E61000000100000005000000E3A7716F7EFD4B4064575A46EA1D4A40E3A7716F7EFD4B4039605793A7804A40F623456458974C4039605793A7804A40F623456458974C4064575A46EA1D4A40E3A7716F7EFD4B4064575A46EA1D4A40
64963	7912	56.486649	56.501362999999998	52.484194000000002	52.465131999999997	с. Юлаева	0103000020E61000000100000005000000C8D0B1834A3E4C405A290472893B4A40C8D0B1834A3E4C40B075A911FA3D4A405436ACA92C404C40B075A911FA3D4A405436ACA92C404C405A290472893B4A40C8D0B1834A3E4C405A290472893B4A40
64002	5881	56.598345000000002	56.655459999999998	52.723570000000002	52.704149000000001	Учительская	0103000020E61000000100000005000000D15CA791964C4C406C41EF8D215A4A40D15CA791964C4C40F12E17F19D5C4A4007EBFF1CE6534C40F12E17F19D5C4A4007EBFF1CE6534C406C41EF8D215A4A40D15CA791964C4C406C41EF8D215A4A40
64031	5881	56.598345000000002	56.655459999999998	52.723570000000002	52.704149000000001	Октябрьская	0103000020E61000000100000005000000D15CA791964C4C406C41EF8D215A4A40D15CA791964C4C40F12E17F19D5C4A4007EBFF1CE6534C40F12E17F19D5C4A4007EBFF1CE6534C406C41EF8D215A4A40D15CA791964C4C406C41EF8D215A4A40
63657	5881	56.598345000000002	56.655459999999998	52.723570000000002	52.704149000000001	Ленина	0103000020E61000000100000005000000D15CA791964C4C406C41EF8D215A4A40D15CA791964C4C40F12E17F19D5C4A4007EBFF1CE6534C40F12E17F19D5C4A4007EBFF1CE6534C406C41EF8D215A4A40D15CA791964C4C406C41EF8D215A4A40
64310	5881	56.598345000000002	56.655459999999998	52.723570000000002	52.704149000000001	Иванова	0103000020E61000000100000005000000D15CA791964C4C406C41EF8D215A4A40D15CA791964C4C40F12E17F19D5C4A4007EBFF1CE6534C40F12E17F19D5C4A4007EBFF1CE6534C406C41EF8D215A4A40D15CA791964C4C406C41EF8D215A4A40
63646	5881	56.598345000000002	56.655459999999998	52.723570000000002	52.704149000000001	З.Биишевой	0103000020E61000000100000005000000D15CA791964C4C406C41EF8D215A4A40D15CA791964C4C40F12E17F19D5C4A4007EBFF1CE6534C40F12E17F19D5C4A4007EBFF1CE6534C406C41EF8D215A4A40D15CA791964C4C406C41EF8D215A4A40
64235	8008	56.519258000000001	56.538319999999999	52.329804000000003	52.313983999999998	Центральная	0103000020E61000000100000005000000DB17D00B77424C40CFBBB1A030284A40DB17D00B77424C40850B7904372A4A40306475ABE7444C40850B7904372A4A40306475ABE7444C40CFBBB1A030284A40DB17D00B77424C40CFBBB1A030284A40
65884	6304	56.667830000000002	56.697375999999998	52.699396	52.683855999999999	Центральная	0103000020E61000000100000005000000D3A414747B554C403196E99788574A40D3A414747B554C40037AE1CE85594A40F581E49D43594C40037AE1CE85594A40F581E49D43594C403196E99788574A40D3A414747B554C403196E99788574A40
64330	8390	56.563167	56.599882000000001	52.448042999999998	52.429524999999998	Советская	0103000020E61000000100000005000000DD9733DB15484C403EE8D9ACFA364A40DD9733DB15484C40D219187959394A40C3BAF1EEC84C4C40D219187959394A40C3BAF1EEC84C4C403EE8D9ACFA364A40DD9733DB15484C403EE8D9ACFA364A40
64313	6575	56.250500000000002	56.263480999999999	52.785366000000003	52.768129999999999	Молодежная	0103000020E61000000100000005000000F2D24D6210204C40CA89761552624A40F2D24D6210204C40F7B182DF86644A40060FD3BEB9214C40F7B182DF86644A40060FD3BEB9214C40CA89761552624A40F2D24D6210204C40CA89761552624A40
64526	7884	56.499028000000003	56.520811999999999	52.549435000000003	52.526248000000002	40 лет Победы	0103000020E61000000100000005000000E7E44526E03F4C40EFCA2E185C434A40E7E44526E03F4C408E23D6E253464A40A3AEB5F7A9424C408E23D6E253464A40A3AEB5F7A9424C40EFCA2E185C434A40E7E44526E03F4C40EFCA2E185C434A40
66064	7614	56.472572	56.502755999999998	52.713237999999997	52.701939000000003	Шевченко	0103000020E61000000100000005000000AE80423D7D3C4C40BB641C23D9594A40AE80423D7D3C4C40D921FE614B5B4A4013EF004F5A404C40D921FE614B5B4A4013EF004F5A404C40BB641C23D9594A40AE80423D7D3C4C40BB641C23D9594A40
64682	8558	56.591203999999998	56.626238000000001	52.520287000000003	52.510745999999997	Школьная	0103000020E61000000100000005000000D7A19A92AC4B4C400A48FB1F60414A40D7A19A92AC4B4C4059C4B0C398424A4098C1189128504C4059C4B0C398424A4098C1189128504C400A48FB1F60414A40D7A19A92AC4B4C400A48FB1F60414A40
65403	8801	56.679876999999998	56.697330999999998	52.679291999999997	52.669370000000001	Школьная	0103000020E61000000100000005000000BB26A43506574C40367689EAAD554A40BB26A43506574C409B374E0AF3564A4055BE672442594C409B374E0AF3564A4055BE672442594C40367689EAAD554A40BB26A43506574C40367689EAAD554A40
66066	8086	56.576138999999998	56.589021000000002	52.296163999999997	52.289692000000002	Сулеймана	0103000020E610000001000000050000009E7939ECBE494C40D8F4A0A014254A409E7939ECBE494C405320B3B3E8254A4020D4450A654B4C405320B3B3E8254A4020D4450A654B4C40D8F4A0A014254A409E7939ECBE494C40D8F4A0A014254A40
9968	6688	56.223218000000003	56.234428999999999	52.615425999999999	52.610050999999999	Луговая	0103000020E6100000010000000500000074F04C68921C4C4030F2B226164E4A4074F04C68921C4C40D68D7747C64E4A40F31DFCC4011E4C40D68D7747C64E4A40F31DFCC4011E4C4030F2B226164E4A4074F04C68921C4C4030F2B226164E4A40
64785	6862	56.356617999999997	56.372877000000003	52.804152000000002	52.783399000000003	70 лет Октября	0103000020E610000001000000050000001C959BA8A52D4C400C5C1E6B46644A401C959BA8A52D4C40AA81E673EE664A401E37FC6EBA2F4C40AA81E673EE664A401E37FC6EBA2F4C400C5C1E6B46644A401C959BA8A52D4C400C5C1E6B46644A40
65378	6518	56.222220999999998	56.243321999999999	52.827559999999998	52.799894000000002	Центральная	0103000020E6100000010000000500000001BEDBBC711C4C40212235ED62664A4001BEDBBC711C4C4027BD6F7CED694A40DB32E02C251F4C4027BD6F7CED694A40DB32E02C251F4C40212235ED62664A4001BEDBBC711C4C40212235ED62664A40
65398	8478	56.506070999999999	56.516661999999997	52.447093000000002	52.438184	Центральная	0103000020E610000001000000050000001D3A3DEFC6404C40B3D0CE6916384A401D3A3DEFC6404C40A1A2EA573A394A40008BFCFA21424C40A1A2EA573A394A40008BFCFA21424C40B3D0CE6916384A401D3A3DEFC6404C40B3D0CE6916384A40
64967	7992	56.379111999999999	56.399611	52.488624999999999	52.475517000000004	Центральная	0103000020E61000000100000005000000B5C2F4BD86304C4095D8B5BDDD3C4A40B5C2F4BD86304C40068195438B3E4A40990F087426334C40068195438B3E4A40990F087426334C4095D8B5BDDD3C4A40B5C2F4BD86304C4095D8B5BDDD3C4A40
64959	7649	56.487546999999999	56.498462000000004	52.426143000000003	52.413702999999998	Центральная	0103000020E61000000100000005000000A721AAF0673E4C40E8A04B38F4344A40A721AAF0673E4C40AD3594DA8B364A403E26529ACD3F4C40AD3594DA8B364A403E26529ACD3F4C40E8A04B38F4344A40A721AAF0673E4C40E8A04B38F4344A40
65882	8257	56.588526999999999	56.621808999999999	52.394444999999997	52.387262	Русская	0103000020E6100000010000000500000010E84CDA544B4C40E57D1CCD91314A4010E84CDA544B4C400D897B2C7D324A40E2ADF36F974F4C400D897B2C7D324A40E2ADF36F974F4C40E57D1CCD91314A4010E84CDA544B4C40E57D1CCD91314A40
64771	7457	56.518251999999997	56.537025999999997	53.001466999999998	52.990864999999999	Набережная	0103000020E61000000100000005000000158BDF1456424C4022E010AAD47E4A40158BDF1456424C40F982161230804A40048D9944BD444C40F982161230804A40048D9944BD444C4022E010AAD47E4A40158BDF1456424C4022E010AAD47E4A40
65399	8622	56.747556000000003	56.767398999999997	52.737907	52.717384000000003	Набережная	0103000020E61000000100000005000000DCF63DEAAF5F4C403B56293DD35B4A40DCF63DEAAF5F4C40A73E90BC735E4A40D6FD63213A624C40A73E90BC735E4A40D6FD63213A624C403B56293DD35B4A40DCF63DEAAF5F4C403B56293DD35B4A40
65881	6787	56.346952000000002	56.375456	52.662559999999999	52.653782	Буранбая	0103000020E6100000010000000500000012A452EC682C4C40535BEA20AF534A4012A452EC682C4C40A2D11DC4CE544A40228B34F10E304C40A2D11DC4CE544A40228B34F10E304C40535BEA20AF534A4012A452EC682C4C40535BEA20AF534A40
64977	8988	56.865954000000002	56.877290000000002	52.621282000000001	52.606403	Худайбердина	0103000020E6100000010000000500000092EBA694D76E4C4020990E9D9E4D4A4092EBA694D76E4C40F7CB272B864F4A40CE8DE9094B704C40F7CB272B864F4A40CE8DE9094B704C4020990E9D9E4D4A4092EBA694D76E4C4020990E9D9E4D4A40
66577	58847	55.980421	57.182384999999996	53.005113999999999	52.233711999999997	Революционная	0103000020E61000000100000005000000E3A7716F7EFD4B4064575A46EA1D4A40E3A7716F7EFD4B4039605793A7804A40F623456458974C4039605793A7804A40F623456458974C4064575A46EA1D4A40E3A7716F7EFD4B4064575A46EA1D4A40
65396	7468	56.573669000000002	56.603008000000003	52.823844000000001	52.808315999999998	Центральная	0103000020E6100000010000000500000051DD5CFC6D494C40B16A10E676674A4051DD5CFC6D494C40BF805EB873694A40FA9CBB5D2F4D4C40BF805EB873694A40FA9CBB5D2F4D4C40B16A10E676674A4051DD5CFC6D494C40B16A10E676674A40
64964	7081	56.323039000000001	56.352080999999998	52.895336	52.875546	Молодежная	0103000020E61000000100000005000000912A8A5759294C4062122EE411704A40912A8A5759294C403A77BB5E9A724A4080457EFD102D4C403A77BB5E9A724A4080457EFD102D4C4062122EE411704A40912A8A5759294C4062122EE411704A40
65872	4721	54.365996000000003	54.389909000000003	55.761031000000003	55.752930999999997	Береговая	0103000020E61000000100000005000000C13BF9F4D82E4B408192020B60E04B40C13BF9F4D82E4B40001FBC7669E14B4042B5C189E8314B40001FBC7669E14B4042B5C189E8314B408192020B60E04B40C13BF9F4D82E4B408192020B60E04B40
65874	5096	54.351694999999999	54.372948999999998	55.901237999999999	55.887422000000001	Советская	0103000020E6100000010000000500000057957D57042D4B401EE0490B97F14B4057957D57042D4B40CBF44BC45BF34B40B709F7CABC2F4B40CBF44BC45BF34B40B709F7CABC2F4B401EE0490B97F14B4057957D57042D4B401EE0490B97F14B40
65374	5298	54.099035000000001	54.123342999999998	55.821527000000003	55.793824000000001	Победы	0103000020E610000001000000050000006614CB2DAD0C4B40D4635B069CE54B406614CB2DAD0C4B40F8E3F6CB27E94B40639813B4C90F4B40F8E3F6CB27E94B40639813B4C90F4B40D4635B069CE54B406614CB2DAD0C4B40D4635B069CE54B40
66566	58841	54.555478000000001	54.571342000000001	55.727516000000001	55.712572999999999	Центральная	0103000020E61000000100000005000000E1D231E719474B409D81919735DB4B40E1D231E719474B408BA8893E1FDD4B40666A12BC21494B408BA8893E1FDD4B40666A12BC21494B409D81919735DB4B40E1D231E719474B409D81919735DB4B40
65875	5625	53.862481000000002	53.934868000000002	55.990876	55.975436000000002	Дорожная	0103000020E61000000100000005000000F03504C765EE4A40A8AB3B16DBFC4B40F03504C765EE4A4016325706D5FE4B40D9092FC1A9F74A4016325706D5FE4B40D9092FC1A9F74A40A8AB3B16DBFC4B40F03504C765EE4A40A8AB3B16DBFC4B40
66073	5660	54.001064	54.034256999999997	56.006210000000003	55.988545000000002	Дорожная	0103000020E61000000100000005000000FA997ADD22004B40EACF7EA488FE4B40FA997ADD22004B403F74417DCB004C405C548B8862044B403F74417DCB004C405C548B8862044B40EACF7EA488FE4B40FA997ADD22004B40EACF7EA488FE4B40
65836	33072	54.400041999999999	54.419967	56.145946000000002	56.132835	Центральная	0103000020E610000001000000050000006283859334334B40D061BEBC00114C406283859334334B40B37DC85BAE124C401A33897AC1354B40B37DC85BAE124C401A33897AC1354B40D061BEBC00114C406283859334334B40D061BEBC00114C40
64455	33072	54.400041999999999	54.419967	56.145946000000002	56.132835	Молодежная	0103000020E610000001000000050000006283859334334B40D061BEBC00114C406283859334334B40B37DC85BAE124C401A33897AC1354B40B37DC85BAE124C401A33897AC1354B40D061BEBC00114C406283859334334B40D061BEBC00114C40
65174	4598	54.465296000000002	54.501632999999998	55.807577000000002	55.787669999999999	Школьная	0103000020E61000000100000005000000D57ABFD18E3B4B402905DD5ED2E44B40D57ABFD18E3B4B403B00E2AE5EE74B4014CC988235404B403B00E2AE5EE74B4014CC988235404B402905DD5ED2E44B40D57ABFD18E3B4B402905DD5ED2E44B40
65299	4814	54.636631999999999	54.653565	55.850423999999997	55.839325000000002	Озерная	0103000020E6100000010000000500000025CB49287D514B408CDB68006FEB4B4025CB49287D514B40E3DD91B1DAEC4B40B6679604A8534B40E3DD91B1DAEC4B40B6679604A8534B408CDB68006FEB4B4025CB49287D514B408CDB68006FEB4B40
65401	49085	54.199385999999997	54.218268000000002	56.019767000000002	56.009003	Ленина	0103000020E61000000100000005000000DFA3FE7A85194B406F48A30227014C40DFA3FE7A85194B4020459DB987024C40B5E1B034F01B4B4020459DB987024C40B5E1B034F01B4B406F48A30227014C40DFA3FE7A85194B406F48A30227014C40
64100	5246	54.228113999999998	54.259760999999997	55.932454999999997	55.911911000000003	Колхозная	0103000020E610000001000000050000003FE1ECD6321D4B406CEEE87FB9F44B403FE1ECD6321D4B40EFFE78AF5AF74B405CE333D93F214B40EFFE78AF5AF74B405CE333D93F214B406CEEE87FB9F44B403FE1ECD6321D4B406CEEE87FB9F44B40
66051	5128	54.372608	54.397644	55.869304	55.861994000000003	Большая	0103000020E610000001000000050000002E1D739EB12F4B4093ACC3D155EE4B402E1D739EB12F4B4018247D5A45EF4B40AEB9A3FFE5324B4018247D5A45EF4B40AEB9A3FFE5324B4093ACC3D155EE4B402E1D739EB12F4B4093ACC3D155EE4B40
64093	4369	54.575249999999997	54.597527999999997	55.778855999999998	55.764693000000001	Колхозная	0103000020E610000001000000050000001283C0CAA1494B40753DD175E1E14B401283C0CAA1494B408D25AC8DB1E34B40DE3829CC7B4C4B408D25AC8DB1E34B40DE3829CC7B4C4B40753DD175E1E14B401283C0CAA1494B40753DD175E1E14B40
66596	58856	54.581240999999999	54.620659000000003	55.740400999999999	55.727491000000001	 Школьная	0103000020E61000000100000005000000130CE71A664A4B403291D26C1EDD4B40130CE71A664A4B407D76C075C5DE4B40EA7B0DC1714F4B407D76C075C5DE4B40EA7B0DC1714F4B403291D26C1EDD4B40130CE71A664A4B403291D26C1EDD4B40
65821	7722	54.542856	54.558784000000003	56.184761000000002	56.172370000000001	Дорожная	0103000020E61000000100000005000000FC372F4E7C454B40E0675C3810164C40FC372F4E7C454B40C3499A3FA6174C4098C3EE3B86474B40C3499A3FA6174C4098C3EE3B86474B40E0675C3810164C40FC372F4E7C454B40E0675C3810164C40
63521	5757	54.131689000000001	54.190680999999998	56.147123999999998	56.114745999999997	Макаренко	0103000020E61000000100000005000000191F662FDB104B4064AC36FFAF0E4C40191F662FDB104B40753A90F5D4124C40FA7B293C68184B40753A90F5D4124C40FA7B293C68184B4064AC36FFAF0E4C40191F662FDB104B4064AC36FFAF0E4C40
63320	5757	54.131689000000001	54.190680999999998	56.147123999999998	56.114745999999997	Карла Маркса	0103000020E61000000100000005000000191F662FDB104B4064AC36FFAF0E4C40191F662FDB104B40753A90F5D4124C40FA7B293C68184B40753A90F5D4124C40FA7B293C68184B4064AC36FFAF0E4C40191F662FDB104B4064AC36FFAF0E4C40
65498	58558	54.381644999999999	54.385831000000003	56.159213000000001	56.155437999999997	  Речная	0103000020E6100000010000000500000049D74CBED9304B401F477364E5134C4049D74CBED9304B408D0C721761144C40396403E962314B408D0C721761144C40396403E962314B401F477364E5134C4049D74CBED9304B401F477364E5134C40
64445	4068	54.378725000000003	54.388669999999998	56.181660000000001	56.163874999999997	Школьная	0103000020E61000000100000005000000BC96900F7A304B40E5D022DBF9144C40BC96900F7A304B40E57E87A240174C40D97745F0BF314B40E57E87A240174C40D97745F0BF314B40E5D022DBF9144C40BC96900F7A304B40E5D022DBF9144C40
66768	4556	54.666877999999997	54.685364999999997	55.755955999999998	55.739823000000001	Чапаева	0103000020E61000000100000005000000003620425C554B4010EA2285B2DE4B40003620425C554B40849B8C2AC3E04B405969520ABA574B40849B8C2AC3E04B405969520ABA574B4010EA2285B2DE4B40003620425C554B4010EA2285B2DE4B40
66713	33049	54.339891000000001	54.356904999999998	56.067228	56.061137000000002	Солнечная	0103000020E61000000100000005000000359A5C8C812B4B40ACC95356D3074C40359A5C8C812B4B4010B056ED9A084C40B2632310AF2D4B4010B056ED9A084C40B2632310AF2D4B40ACC95356D3074C40359A5C8C812B4B40ACC95356D3074C40
64760	4676	54.469698000000001	54.485975000000003	55.858497999999997	55.847825999999998	Речная	0103000020E61000000100000005000000917F66101F3C4B406859F78F85EC4B40917F66101F3C4B4038D73043E3ED4B4039D6C56D343E4B4038D73043E3ED4B4039D6C56D343E4B406859F78F85EC4B40917F66101F3C4B406859F78F85EC4B40
66050	49195	54.498758000000002	54.513562	56.177230999999999	56.167172999999998	Центральная	0103000020E61000000100000005000000274F594DD73F4B4019E3C3EC65154C40274F594DD73F4B402F6B6281AF164C40F33B4D66BC414B402F6B6281AF164C40F33B4D66BC414B4019E3C3EC65154C40274F594DD73F4B4019E3C3EC65154C40
64092	3906	54.417344	54.433369999999996	56.026009999999999	56.010745	Школьная	0103000020E61000000100000005000000469737876B354B403ACC971760014C40469737876B354B403AAFB14B54034C40A4880CAB78374B403AAFB14B54034C40A4880CAB78374B403ACC971760014C40469737876B354B403ACC971760014C40
65873	4008	54.367415000000001	54.384492000000002	55.995533000000002	55.987195	Можарская	0103000020E61000000100000005000000A9876874072F4B402AE3DF675CFE4B40A9876874072F4B405D8B16A06DFF4B406DC9AA0837314B405D8B16A06DFF4B406DC9AA0837314B402AE3DF675CFE4B40A9876874072F4B402AE3DF675CFE4B40
65813	49156	54.261747	54.277782000000002	56.138744000000003	56.130150999999998	Школьная	0103000020E61000000100000005000000BE69FAEC80214B405645B8C9A8104C40BE69FAEC80214B401442075DC2114C4070B54E5C8E234B401442075DC2114C4070B54E5C8E234B405645B8C9A8104C40BE69FAEC80214B405645B8C9A8104C40
66079	4340	54.593324000000003	54.609690999999998	56.165694000000002	56.155527999999997	Зеленая	0103000020E6100000010000000500000049F7730AF24B4B405FCE6C57E8134C4049F7730AF24B4B405C92037635154C4030D5CC5A0A4E4B405C92037635154C4030D5CC5A0A4E4B405FCE6C57E8134C4049F7730AF24B4B405FCE6C57E8134C40
64929	2874	54.356752	54.376677000000001	55.800873000000003	55.785229999999999	Школьная	0103000020E610000001000000050000002C64AE0CAA2D4B4046EBA86A82E44B402C64AE0CAA2D4B40ED9FA70183E64B40E413B2F336304B40ED9FA70183E64B40E413B2F336304B4046EBA86A82E44B402C64AE0CAA2D4B4046EBA86A82E44B40
65168	4890	54.541518000000003	54.557175999999998	55.842438000000001	55.835259999999998	Центральная	0103000020E6100000010000000500000001193A7650454B4017D4B7CCE9EA4B4001193A7650454B402E742502D5EB4B40DC0E0D8B51474B402E742502D5EB4B40DC0E0D8B51474B4017D4B7CCE9EA4B4001193A7650454B4017D4B7CCE9EA4B40
66610	58861	54.052968999999997	54.076622	55.841068999999997	55.832844000000001	Новая	0103000020E61000000100000005000000D5592DB0C7064B40BD55D7A19AEA4B40D5592DB0C7064B40F7562426A8EB4B40BA13ECBFCE094B40F7562426A8EB4B40BA13ECBFCE094B40BD55D7A19AEA4B40D5592DB0C7064B40BD55D7A19AEA4B40
64308	3811	54.240546000000002	54.255960999999999	55.979509999999998	55.965510999999999	Ленина	0103000020E6100000010000000500000081971936CA1E4B40D1764CDD95FB4B4081971936CA1E4B406F0D6C9560FD4B4096067E54C3204B406F0D6C9560FD4B4096067E54C3204B40D1764CDD95FB4B4081971936CA1E4B40D1764CDD95FB4B40
63674	6159	53.926253000000003	53.950319	55.904614000000002	55.869757999999997	Цветочный бульвар	0103000020E61000000100000005000000346953758FF64A4099B7EA3A54EF4B40346953758FF64A407BC03C64CAF34B403BE2900DA4F94A407BC03C64CAF34B403BE2900DA4F94A4099B7EA3A54EF4B40346953758FF64A4099B7EA3A54EF4B40
63464	6159	53.926253000000003	53.950319	55.904614000000002	55.869757999999997	Первых строителей	0103000020E61000000100000005000000346953758FF64A4099B7EA3A54EF4B40346953758FF64A407BC03C64CAF34B403BE2900DA4F94A407BC03C64CAF34B403BE2900DA4F94A4099B7EA3A54EF4B40346953758FF64A4099B7EA3A54EF4B40
65870	3342	58.509726999999998	58.543072000000002	55.270082000000002	55.261105000000001	М.Халила	0103000020E61000000100000005000000B071FDBB3E414D403AE97DE36BA14B40B071FDBB3E414D40809E060C92A24B40C9AF1F6283454D40809E060C92A24B40C9AF1F6283454D403AE97DE36BA14B40B071FDBB3E414D403AE97DE36BA14B40
65903	58660	58.360138999999997	58.384376000000003	55.338858000000002	55.319971000000002	Ленина	0103000020E61000000100000005000000CF81E508192E4D408F554ACFF4A84B40CF81E508192E4D4076FEEDB25FAB4B4004AF963B33314D4076FEEDB25FAB4B4004AF963B33314D408F554ACFF4A84B40CF81E508192E4D408F554ACFF4A84B40
65395	2934	58.521576000000003	58.533935999999997	55.484254999999997	55.477117999999997	Центральная	0103000020E6100000010000000500000073309B00C3424D409D2ADF3312BD4B4073309B00C3424D4055F65D11FCBD4B401A14CD0358444D4055F65D11FCBD4B401A14CD0358444D409D2ADF3312BD4B4073309B00C3424D409D2ADF3312BD4B40
64806	2481	58.742542999999998	58.776518000000003	55.324421999999998	55.311841000000001	Советская	0103000020E61000000100000005000000D66F26A60B5F4D40A646E867EAA74B40D66F26A60B5F4D402C0DFCA886A94B40AF601BF164634D402C0DFCA886A94B40AF601BF164634D40A646E867EAA74B40D66F26A60B5F4D40A646E867EAA74B40
65958	2424	59.067391999999998	59.089481999999997	55.429434999999998	55.420265000000001	Нагорная	0103000020E610000001000000050000008A01124DA0884D40A453573ECBB54B408A01124DA0884D40FE60E0B9F7B64B4053CA6B25748B4D40FE60E0B9F7B64B4053CA6B25748B4D40A453573ECBB54B408A01124DA0884D40A453573ECBB54B40
66808	1051	58.473515999999996	58.482481	55.587142999999998	55.571061999999998	Солдатская	0103000020E61000000100000005000000FD101B2C9C3C4D4082FE428F18C94B40FD101B2C9C3C4D40A489778027CB4B407FF8F9EFC13D4D40A489778027CB4B407FF8F9EFC13D4D4082FE428F18C94B40FD101B2C9C3C4D4082FE428F18C94B40
66732	3234	58.468826999999997	58.492398000000001	55.285722	55.267220000000002	Советская	0103000020E61000000100000005000000AB3DEC85023C4D40276BD44334A24B40AB3DEC85023C4D40B5DFDA8992A44B40D34ECDE5063F4D40B5DFDA8992A44B40D34ECDE5063F4D40276BD44334A24B40AB3DEC85023C4D40276BD44334A24B40
9857	2824	58.574738000000004	58.594895999999999	55.458627999999997	55.445835000000002	Новая	0103000020E610000001000000050000005DE2C80391494D40C2340C1F11B94B405DE2C80391494D40D3838252B4BA4B40B742588D254C4D40D3838252B4BA4B40B742588D254C4D40C2340C1F11B94B405DE2C80391494D40C2340C1F11B94B40
66810	1077	58.474719999999998	58.534601000000002	55.553508000000001	55.529511999999997	8-Марта	0103000020E61000000100000005000000E960FD9FC33C4D40766B990CC7C34B40E960FD9FC33C4D408509A359D9C64B4057B439CE6D444D408509A359D9C64B4057B439CE6D444D40766B990CC7C34B40E960FD9FC33C4D40766B990CC7C34B40
66691	3612	58.741636	58.866258999999999	55.453217000000002	55.426707	Ракшина	0103000020E61000000100000005000000A4C4AEEDED5E4D40B5FCC0559EB64B40A4C4AEEDED5E4D40E17EC00303BA4B40CE6E2D93E16E4D40E17EC00303BA4B40CE6E2D93E16E4D40B5FCC0559EB64B40A4C4AEEDED5E4D40B5FCC0559EB64B40
64026	3612	58.741636	58.866258999999999	55.453217000000002	55.426707	Гагарина	0103000020E61000000100000005000000A4C4AEEDED5E4D40B5FCC0559EB64B40A4C4AEEDED5E4D40E17EC00303BA4B40CE6E2D93E16E4D40E17EC00303BA4B40CE6E2D93E16E4D40B5FCC0559EB64B40A4C4AEEDED5E4D40B5FCC0559EB64B40
65288	3557	58.748821999999997	58.768127	55.375833	55.361435999999998	Салавата Юлаева	0103000020E610000001000000050000003D433866D95F4D406CCCEB8843AE4B403D433866D95F4D40F8E0B54B1BB04B4059164CFC51624D40F8E0B54B1BB04B4059164CFC51624D406CCCEB8843AE4B403D433866D95F4D406CCCEB8843AE4B40
66689	3102	58.702047	58.724038	55.180793999999999	55.168233000000001	Школьная	0103000020E61000000100000005000000A1A014ADDC594D40D28DB0A888954B40A1A014ADDC594D4011A8FE4124974B40D787F546AD5C4D4011A8FE4124974B40D787F546AD5C4D40D28DB0A888954B40A1A014ADDC594D40D28DB0A888954B40
66702	2344	59.134774999999998	59.153962999999997	55.346108000000001	55.339339000000002	Заречная	0103000020E61000000100000005000000C1A8A44E40914D40F1A0D9756FAB4B40C1A8A44E40914D40267156444DAC4B40A3E5400FB5934D40267156444DAC4B40A3E5400FB5934D40F1A0D9756FAB4B40C1A8A44E40914D40F1A0D9756FAB4B40
65869	3397	58.460588999999999	58.501030999999998	55.611750000000001	55.591121000000001	Мира	0103000020E61000000100000005000000DCF29194F43A4D404A7D59DAA9CB4B40DCF29194F43A4D40FCA9F1D24DCE4B401EA4A7C821404D40FCA9F1D24DCE4B401EA4A7C821404D404A7D59DAA9CB4B40DCF29194F43A4D404A7D59DAA9CB4B40
65308	855	58.850278000000003	58.886372000000001	55.376553999999999	55.369408	Школьная	0103000020E610000001000000050000001041D5E8D56C4D40BD70E7C248AF4B401041D5E8D56C4D40C896E5EB32B04B40890B40A374714D40C896E5EB32B04B40890B40A374714D40BD70E7C248AF4B401041D5E8D56C4D40BD70E7C248AF4B40
66820	855	58.850278000000003	58.886372000000001	55.376553999999999	55.369408	Молодежная	0103000020E610000001000000050000001041D5E8D56C4D40BD70E7C248AF4B401041D5E8D56C4D40C896E5EB32B04B40890B40A374714D40C896E5EB32B04B40890B40A374714D40BD70E7C248AF4B401041D5E8D56C4D40BD70E7C248AF4B40
66372	855	58.850278000000003	58.886372000000001	55.376553999999999	55.369408	 Салавата Юлаева	0103000020E610000001000000050000001041D5E8D56C4D40BD70E7C248AF4B401041D5E8D56C4D40C896E5EB32B04B40890B40A374714D40C896E5EB32B04B40890B40A374714D40BD70E7C248AF4B401041D5E8D56C4D40BD70E7C248AF4B40
66049	3169	58.442343999999999	58.464083000000002	55.327033999999998	55.312480999999998	Советская	0103000020E6100000010000000500000079CA6ABA9E384D4089CF9D60FFA74B4079CA6ABA9E384D400C570740DCA94B4096D05D12673B4D400C570740DCA94B4096D05D12673B4D4089CF9D60FFA74B4079CA6ABA9E384D4089CF9D60FFA74B40
66765	939	58.587656000000003	58.620651000000002	55.236992000000001	55.217587999999999	Бурхана Шарафутдинова	0103000020E610000001000000050000002BA6D24F384B4D40430070ECD99B4B402BA6D24F384B4D40F2B4FCC0559E4B40679DF17D714F4D40F2B4FCC0559E4B40679DF17D714F4D40430070ECD99B4B402BA6D24F384B4D40430070ECD99B4B40
65294	2753	58.483953999999997	58.518071999999997	55.450296999999999	55.432158000000001	Советская	0103000020E610000001000000050000005A626534F23D4D40365A0EF450B74B405A626534F23D4D40533E0455A3B94B40957CEC2E50424D40533E0455A3B94B40957CEC2E50424D40365A0EF450B74B405A626534F23D4D40365A0EF450B74B40
62323	2537	58.566698000000002	58.641851000000003	55.422747999999999	55.387908000000003	Советская	0103000020E61000000100000005000000B45A608F89484D40ABED26F8A6B14B40B45A608F89484D408639419B1CB64B40D4F36E2C28524D408639419B1CB64B40D4F36E2C28524D40ABED26F8A6B14B40B45A608F89484D40ABED26F8A6B14B40
62328	2537	58.566698000000002	58.641851000000003	55.422747999999999	55.387908000000003	Салавата	0103000020E61000000100000005000000B45A608F89484D40ABED26F8A6B14B40B45A608F89484D408639419B1CB64B40D4F36E2C28524D408639419B1CB64B40D4F36E2C28524D40ABED26F8A6B14B40B45A608F89484D40ABED26F8A6B14B40
63236	2537	58.566698000000002	58.641851000000003	55.422747999999999	55.387908000000003	Ибрагимова	0103000020E61000000100000005000000B45A608F89484D40ABED26F8A6B14B40B45A608F89484D408639419B1CB64B40D4F36E2C28524D408639419B1CB64B40D4F36E2C28524D40ABED26F8A6B14B40B45A608F89484D40ABED26F8A6B14B40
66860	3054	58.634349999999998	58.662188999999998	55.282389999999999	55.271963999999997	Школьная	0103000020E61000000100000005000000DA1B7C6132514D403CD862B7CFA24B40DA1B7C6132514D40D55B035B25A44B40AE62F19BC2544D40D55B035B25A44B40AE62F19BC2544D403CD862B7CFA24B40DA1B7C6132514D403CD862B7CFA24B40
64766	2242	59.070779000000002	59.084252999999997	55.317466000000003	55.308827999999998	Центральная	0103000020E610000001000000050000002E1F49490F894D40670B08AD87A74B402E1F49490F894D40C5CBD3B9A2A84B4081CB63CDC88A4D40C5CBD3B9A2A84B4081CB63CDC88A4D40670B08AD87A74B402E1F49490F894D40670B08AD87A74B40
65119	2187	58.979680000000002	59.001204000000001	55.364331999999997	55.351686999999998	Кирова	0103000020E61000000100000005000000CC457C27667D4D40D4B6611404AD4B40CC457C27667D4D407171546EA2AE4B40EC4FE27327804D407171546EA2AE4B40EC4FE27327804D40D4B6611404AD4B40CC457C27667D4D40D4B6611404AD4B40
65116	2070	58.759647000000001	58.790882000000003	55.599193999999997	55.581448999999999	Гагарина	0103000020E6100000010000000500000094C0E61C3C614D405DA5BBEB6CCA4B4094C0E61C3C614D40CEFA9463B2CC4B405F7F129F3B654D40CEFA9463B2CC4B405F7F129F3B654D405DA5BBEB6CCA4B4094C0E61C3C614D405DA5BBEB6CCA4B40
65778	782	58.662602	58.706611000000002	55.607030999999999	55.588622999999998	Школьная	0103000020E61000000100000005000000D1217024D0544D4032569BFF57CB4B40D1217024D0544D403F541A31B3CD4B4037FFAF3A725A4D403F541A31B3CD4B4037FFAF3A725A4D4032569BFF57CB4B40D1217024D0544D4032569BFF57CB4B40
66091	154	56.275813999999997	56.301622999999999	54.370126999999997	54.356287999999999	Школьная	0103000020E61000000100000005000000B4E386DF4D234C4087FA5DD89A2D4B40B4E386DF4D234C40EC2E5052602F4B40575C1C959B264C40EC2E5052602F4B40575C1C959B264C4087FA5DD89A2D4B40B4E386DF4D234C4087FA5DD89A2D4B40
64065	1955	56.027411999999998	56.060110999999999	54.374930999999997	54.349445000000003	Партизанская	0103000020E610000001000000050000004CC2853C82034C4018601F9DBA2C4B404CC2853C82034C40D7A02FBDFD2F4B409F909DB7B1074C40D7A02FBDFD2F4B409F909DB7B1074C4018601F9DBA2C4B404CC2853C82034C4018601F9DBA2C4B40
64837	851	56.446297000000001	56.469338	54.326112999999999	54.313975999999997	Идель	0103000020E61000000100000005000000C6A6954220394C404CDD955D30284B40C6A6954220394C4075E61E12BE294B4091628044133C4C4075E61E12BE294B4091628044133C4C404CDD955D30284B40C6A6954220394C404CDD955D30284B40
66649	79	56.236198999999999	56.255547999999997	54.404142999999998	54.391441999999998	Центральная	0103000020E61000000100000005000000882CD2C43B1E4C40F2237EC51A324B40882CD2C43B1E4C4023F433F5BA334B407347FFCBB5204C4023F433F5BA334B407347FFCBB5204C40F2237EC51A324B40882CD2C43B1E4C40F2237EC51A324B40
63777	32439	56.297823000000001	56.345999999999997	54.441481000000003	54.419981999999997	К. Маркса	0103000020E61000000100000005000000917F66101F264C404F745DF8C1354B40917F66101F264C4017670C7382384B403F355EBA492C4C4017670C7382384B403F355EBA492C4C404F745DF8C1354B40917F66101F264C404F745DF8C1354B40
63429	32439	56.297823000000001	56.345999999999997	54.441481000000003	54.419981999999997	60 лет Октября	0103000020E61000000100000005000000917F66101F264C404F745DF8C1354B40917F66101F264C4017670C7382384B403F355EBA492C4C4017670C7382384B403F355EBA492C4C404F745DF8C1354B40917F66101F264C404F745DF8C1354B40
65585	1601	56.451048999999998	56.468933999999997	54.450622000000003	54.433197	Новая	0103000020E610000001000000050000005EF23FF9BB394C40D7DCD1FF72374B405EF23FF9BB394C40D76D50FBAD394B40C1FD8007063C4C40D76D50FBAD394B40C1FD8007063C4C40D7DCD1FF72374B405EF23FF9BB394C40D7DCD1FF72374B40
64539	32827	55.922812	55.945782000000001	54.357453	54.3414	Молодежная	0103000020E610000001000000050000009D2D20B41EF64B405D6DC5FEB22B4B409D2D20B41EF64B40B56D1805C12D4B409F9273620FF94B40B56D1805C12D4B409F9273620FF94B405D6DC5FEB22B4B409D2D20B41EF64B405D6DC5FEB22B4B40
65960	1545	56.427387000000003	56.447949999999999	54.462111	54.449894999999998	Школьная	0103000020E6100000010000000500000027DE019EB4364C4024D1CB2896394B4027DE019EB4364C40990F0874263B4B40211FF46C56394C40990F0874263B4B40211FF46C56394C4024D1CB2896394B4027DE019EB4364C4024D1CB2896394B40
66827	58877	55.540129999999998	56.529705	54.517122000000001	54.122267999999998	Школьная	0103000020E6100000010000000500000053CBD6FA22C54B4075AC527AA60F4B4053CBD6FA22C54B406405BF0D31424B408BC3995FCD434C406405BF0D31424B408BC3995FCD434C4075AC527AA60F4B4053CBD6FA22C54B4075AC527AA60F4B40
64328	1481	56.349888999999997	56.397984999999998	54.440696000000003	54.420893999999997	Шоссейная	0103000020E61000000100000005000000751DAA29C92C4C40938AC6DADF354B40751DAA29C92C4C4030BDFDB968384B4037A6272CF1324C4030BDFDB968384B4037A6272CF1324C40938AC6DADF354B40751DAA29C92C4C40938AC6DADF354B40
64001	793	56.442542000000003	56.462843999999997	54.367708999999998	54.357546999999997	Школьная	0103000020E61000000100000005000000A08D5C37A5384C4036E49F19C42D4B40A08D5C37A5384C40F1B8A816112F4B402D93E1783E3B4C40F1B8A816112F4B402D93E1783E3B4C4036E49F19C42D4B40A08D5C37A5384C4036E49F19C42D4B40
65583	58572	55.947130000000001	55.964979	54.435318000000002	54.426676999999998	Центральная	0103000020E61000000100000005000000BE874B8E3BF94B404A7A185A9D364B40BE874B8E3BF94B4019AE0E80B8374B40D4298F6E84FB4B4019AE0E80B8374B40D4298F6E84FB4B404A7A185A9D364B40BE874B8E3BF94B404A7A185A9D364B40
64211	32746	56.227063000000001	56.254613999999997	54.479433999999998	54.460692999999999	Мира	0103000020E61000000100000005000000DA907F66101D4C40813FFCFCF73A4B40DA907F66101D4C40944BE3175E3D4B40478D093197204C40944BE3175E3D4B40478D093197204C40813FFCFCF73A4B40DA907F66101D4C40813FFCFCF73A4B40
64254	717	56.415511000000002	56.445874000000003	54.345241999999999	54.330233999999997	Б.Батыровой	0103000020E610000001000000050000006B10E6762F354C407D03931B452A4B406B10E6762F354C40529ACDE3302C4B408011346612394C40529ACDE3302C4B408011346612394C407D03931B452A4B406B10E6762F354C407D03931B452A4B40
64516	45944	56.129344000000003	56.161360000000002	54.472963	54.454934999999999	50 лет Октября	0103000020E6100000010000000500000088F71C588E104C402367614F3B3A4B4088F71C588E104C40E99B340D8A3C4B40F870C971A7144C40E99B340D8A3C4B40F870C971A7144C402367614F3B3A4B4088F71C588E104C402367614F3B3A4B40
65687	47689	55.596580000000003	55.603327	54.251373999999998	54.244546	Центральная	0103000020E610000001000000050000004EB9C2BB5CCC4B400E2F88484D1F4B404EB9C2BB5CCC4B404888F2052D204B409BE5B2D139CD4B404888F2052D204B409BE5B2D139CD4B400E2F88484D1F4B404EB9C2BB5CCC4B400E2F88484D1F4B40
66279	603	56.287483000000002	56.30527	54.312826000000001	54.301336999999997	Центральная	0103000020E61000000100000005000000F793313ECC244C409109F83592264B40F793313ECC244C4054ABAFAE0A284B4097395D1613274C4054ABAFAE0A284B4097395D1613274C409109F83592264B40F793313ECC244C409109F83592264B40
65077	32354	56.411990000000003	56.426112000000003	54.266672999999997	54.254525000000001	Центральная	0103000020E61000000100000005000000B8239C16BC344C40D881734694204B40B8239C16BC344C40F4DC425722224B40723788D68A364C40F4DC425722224B40723788D68A364C40D881734694204B40B8239C16BC344C40D881734694204B40
66077	31912	56.338175	56.349719	54.384763	54.375959000000002	Центральная	0103000020E6100000010000000500000093A98251492B4C4085D1AC6C1F304B4093A98251492B4C40FDDAFAE93F314B4019E59997C32C4C40FDDAFAE93F314B4019E59997C32C4C4085D1AC6C1F304B4093A98251492B4C4085D1AC6C1F304B40
63676	206	56.159526999999997	56.202817000000003	54.384647999999999	54.352389000000002	Советская	0103000020E610000001000000050000001CEA77616B144C402E3C2F151B2D4B401CEA77616B144C40643C4A253C314B4053094FE8F5194C40643C4A253C314B4053094FE8F5194C402E3C2F151B2D4B401CEA77616B144C402E3C2F151B2D4B40
63677	206	56.159526999999997	56.202817000000003	54.384647999999999	54.352389000000002	Садовая	0103000020E610000001000000050000001CEA77616B144C402E3C2F151B2D4B401CEA77616B144C40643C4A253C314B4053094FE8F5194C40643C4A253C314B4053094FE8F5194C402E3C2F151B2D4B401CEA77616B144C402E3C2F151B2D4B40
63667	206	56.159526999999997	56.202817000000003	54.384647999999999	54.352389000000002	Парковая	0103000020E610000001000000050000001CEA77616B144C402E3C2F151B2D4B401CEA77616B144C40643C4A253C314B4053094FE8F5194C40643C4A253C314B4053094FE8F5194C402E3C2F151B2D4B401CEA77616B144C402E3C2F151B2D4B40
64658	1651	56.099088999999999	56.116489000000001	54.254888000000001	54.238779000000001	Центральная	0103000020E610000001000000050000005932C7F2AE0C4C405DFC6D4F901E4B405932C7F2AE0C4C404912842BA0204B4000AC8E1CE90E4C404912842BA0204B4000AC8E1CE90E4C405DFC6D4F901E4B405932C7F2AE0C4C405DFC6D4F901E4B40
65678	439	56.117548999999997	56.145127000000002	54.324956999999998	54.303821999999997	Ш. Биккула	0103000020E61000000100000005000000B8567BD80B0F4C4014E7A8A3E3264B40B8567BD80B0F4C409ACDE33098294B402062838593124C409ACDE33098294B402062838593124C4014E7A8A3E3264B40B8567BD80B0F4C4014E7A8A3E3264B40
65073	32293	56.318438999999998	56.349457999999998	54.250973999999999	54.235280000000003	Школьная	0103000020E61000000100000005000000AE62F19BC2284C4092B3B0A71D1E4B40AE62F19BC2284C40BA1281EA1F204B40ACA92C0ABB2C4C40BA1281EA1F204B40ACA92C0ABB2C4C4092B3B0A71D1E4B40AE62F19BC2284C4092B3B0A71D1E4B40
66726	1890	56.013102000000003	56.043464999999998	54.428463000000001	54.406784000000002	Школьная	0103000020E6100000010000000500000090C18A53AD014C409E44847F11344B4090C18A53AD014C40E54526E0D7364B40A4C2D84290054C40E54526E0D7364B40A4C2D84290054C409E44847F11344B4090C18A53AD014C409E44847F11344B40
66636	32119	56.244363999999997	56.275050999999998	54.274113	54.259405999999998	Ленина	0103000020E61000000100000005000000ED28CE51471F4C406E313F3734214B40ED28CE51471F4C404834812216234B40B5DD04DF34234C404834812216234B40B5DD04DF34234C406E313F3734214B40ED28CE51471F4C406E313F3734214B40
66268	49514	55.980960000000003	55.988748999999999	54.301642000000001	54.296519000000004	Восточная	0103000020E610000001000000050000009357E71890FD4B4042D2A755F4254B409357E71890FD4B40CE8C7E349C264B40F279C5538FFE4B40CE8C7E349C264B40F279C5538FFE4B4042D2A755F4254B409357E71890FD4B4042D2A755F4254B40
63427	32032	55.797479000000003	55.836098	54.304794000000001	54.280909999999999	Советская	0103000020E61000000100000005000000971FB8CA13E64B40478FDFDBF4234B40971FB8CA13E64B402E02637D03274B4021205F4205EB4B402E02637D03274B4021205F4205EB4B40478FDFDBF4234B40971FB8CA13E64B40478FDFDBF4234B40
64137	1204	56.258063999999997	56.283943999999998	54.459938999999999	54.445554999999999	Школьная	0103000020E610000001000000050000003123BC3D08214C40DEC83CF207394B403123BC3D08214C40D593F947DF3A4B409DF2E84658244C40D593F947DF3A4B409DF2E84658244C40DEC83CF207394B403123BC3D08214C40DEC83CF207394B40
64069	31966	55.654836000000003	55.679468	54.331226000000001	54.313425000000002	Коммунистическая	0103000020E610000001000000050000002A1F82AAD1D34B40D95F764F1E284B402A1F82AAD1D34B40DECA129D652A4B40DA56B3CEF8D64B40DECA129D652A4B40DA56B3CEF8D64B40D95F764F1E284B402A1F82AAD1D34B40D95F764F1E284B40
65148	30299	56.837665999999999	56.866484	55.569280999999997	55.558441999999999	Школьная	0103000020E610000001000000050000004E7CB5A3386B4C403E5B07077BC74B404E7CB5A3386B4C40F99D2633DEC84B40EE409DF2E86E4C40F99D2633DEC84B40EE409DF2E86E4C403E5B07077BC74B404E7CB5A3386B4C403E5B07077BC74B40
65688	58600	56.729410000000001	56.749127999999999	55.878677000000003	55.86795	 Дружбы	0103000020E610000001000000050000000CB08F4E5D5D4C40174850FC18EF4B400CB08F4E5D5D4C40AB5FE97C78F04B404A42226DE35F4C40AB5FE97C78F04B404A42226DE35F4C40174850FC18EF4B400CB08F4E5D5D4C40174850FC18EF4B40
65481	31841	56.448703999999999	56.471333000000001	55.788666999999997	55.771818000000003	Центральная	0103000020E61000000100000005000000CDCAF6216F394C40693BA6EECAE24B40CDCAF6216F394C409B374E0AF3E44B404643C6A3543C4C409B374E0AF3E44B404643C6A3543C4C40693BA6EECAE24B40CDCAF6216F394C40693BA6EECAE24B40
66597	5517	57.13411	57.150378000000003	55.605521000000003	55.595663999999999	Садовая	0103000020E61000000100000005000000850838842A914C40C8B3CBB73ECC4B40850838842A914C4047054EB681CD4B40DA0418963F934C4047054EB681CD4B40DA0418963F934C40C8B3CBB73ECC4B40850838842A914C40C8B3CBB73ECC4B40
65732	47526	56.799909	56.819259000000002	55.691870999999999	55.680751999999998	Школьная	0103000020E610000001000000050000005663096B63664C40E257ACE122D74B405663096B63664C4081069B3A8FD84B4012FA997ADD684C4081069B3A8FD84B4012FA997ADD684C40E257ACE122D74B405663096B63664C40E257ACE122D74B40
65860	47526	56.799909	56.819259000000002	55.691870999999999	55.680751999999998	Ленина	0103000020E610000001000000050000005663096B63664C40E257ACE122D74B405663096B63664C4081069B3A8FD84B4012FA997ADD684C4081069B3A8FD84B4012FA997ADD684C40E257ACE122D74B405663096B63664C40E257ACE122D74B40
66235	29944	56.972700000000003	56.987926999999999	55.946345000000001	55.931679000000003	Центральная	0103000020E61000000100000005000000DC68006F817C4C405CAFE94141F74B40DC68006F817C4C40D7DD3CD521F94B40EEEA5564747E4C40D7DD3CD521F94B40EEEA5564747E4C405CAFE94141F74B40DC68006F817C4C405CAFE94141F74B40
66275	58735	56.695390000000003	56.715504000000003	55.905512000000002	55.895626	Школьная	0103000020E6100000010000000500000094FB1D8A02594C4041B96DDFA3F24B4094FB1D8A02594C405A1135D1E7F34B401F1494A2955B4C405A1135D1E7F34B401F1494A2955B4C4041B96DDFA3F24B4094FB1D8A02594C4041B96DDFA3F24B40
66409	58766	56.521619999999999	56.542290999999999	55.633226000000001	55.623640999999999	Трактовая	0103000020E610000001000000050000004278B471C4424C40EDB8E177D3CF4B404278B471C4424C400B7DB08C0DD14B4023F59ECA69454C400B7DB08C0DD14B4023F59ECA69454C40EDB8E177D3CF4B404278B471C4424C40EDB8E177D3CF4B40
65478	58518	56.271538	56.288822000000003	55.615726000000002	55.606329000000002	Центральная	0103000020E6100000010000000500000085CFD6C1C1224C40E6CE4C309CCD4B4085CFD6C1C1224C4001A60C1CD0CE4B40C32E8A1EF8244C4001A60C1CD0CE4B40C32E8A1EF8244C40E6CE4C309CCD4B4085CFD6C1C1224C40E6CE4C309CCD4B40
65312	58518	56.271538	56.288822000000003	55.615726000000002	55.606329000000002	 Центральная	0103000020E6100000010000000500000085CFD6C1C1224C40E6CE4C309CCD4B4085CFD6C1C1224C4001A60C1CD0CE4B40C32E8A1EF8244C4001A60C1CD0CE4B40C32E8A1EF8244C40E6CE4C309CCD4B4085CFD6C1C1224C40E6CE4C309CCD4B40
65223	31290	56.642291	56.670893	55.909846999999999	55.895493999999999	Центральная	0103000020E61000000100000005000000F0C16B9736524C40D2E1218C9FF24B40F0C16B9736524C408EAED2DD75F44B40C30E63D2DF554C408EAED2DD75F44B40C30E63D2DF554C40D2E1218C9FF24B40F0C16B9736524C40D2E1218C9FF24B40
65115	31817	56.352710000000002	56.384563999999997	55.807161999999998	55.791941000000001	Хамзи Исламова	0103000020E61000000100000005000000707CED99252D4C4047AE9B525EE54B40707CED99252D4C4077499C1551E74B40069CA56439314C4077499C1551E74B40069CA56439314C4047AE9B525EE54B40707CED99252D4C4047AE9B525EE54B40
66042	8483	56.438059000000003	56.458962999999997	55.735799	55.723638000000001	Таулы	0103000020E61000000100000005000000F75B3B5112384C404912842BA0DC4B40F75B3B5112384C40FAB660A92EDE4B407A89B14CBF3A4C40FAB660A92EDE4B407A89B14CBF3A4C404912842BA0DC4B40F75B3B5112384C404912842BA0DC4B40
66267	8483	56.438059000000003	56.458962999999997	55.735799	55.723638000000001	Суюндюковская	0103000020E61000000100000005000000F75B3B5112384C404912842BA0DC4B40F75B3B5112384C40FAB660A92EDE4B407A89B14CBF3A4C40FAB660A92EDE4B407A89B14CBF3A4C404912842BA0DC4B40F75B3B5112384C404912842BA0DC4B40
65107	30006	56.873679000000003	56.896217999999998	55.896129999999999	55.874172999999999	Центральная	0103000020E61000000100000005000000DB19A6B6D46F4C40EA059FE6E4EF4B40DB19A6B6D46F4C40747B4963B4F24B40130B7C45B7724C40747B4963B4F24B40130B7C45B7724C40EA059FE6E4EF4B40DB19A6B6D46F4C40EA059FE6E4EF4B40
66244	29442	56.507364000000003	56.531655000000001	55.890033000000003	55.875971	Центральная	0103000020E610000001000000050000007995B54DF1404C40499F56D11FF04B407995B54DF1404C402EAEF199ECF14B40A0E062450D444C402EAEF199ECF14B40A0E062450D444C40499F56D11FF04B407995B54DF1404C40499F56D11FF04B40
66063	46743	56.482993	56.512394999999998	55.593277999999998	55.577831000000003	Хайруллина	0103000020E610000001000000050000003599F1B6D23D4C40B8CEBF5DF6C94B403599F1B6D23D4C40D8B79388F0CB4B4024D1CB2896414C40D8B79388F0CB4B4024D1CB2896414C40B8CEBF5DF6C94B403599F1B6D23D4C40B8CEBF5DF6C94B40
65175	46743	56.482993	56.512394999999998	55.593277999999998	55.577831000000003	Речная	0103000020E610000001000000050000003599F1B6D23D4C40B8CEBF5DF6C94B403599F1B6D23D4C40D8B79388F0CB4B4024D1CB2896414C40D8B79388F0CB4B4024D1CB2896414C40B8CEBF5DF6C94B403599F1B6D23D4C40B8CEBF5DF6C94B40
63758	30993	56.279578000000001	56.310443999999997	55.689933000000003	55.674849000000002	Советская	0103000020E610000001000000050000002E573F36C9234C40815EB87361D64B402E573F36C9234C4031B77BB94FD84B40A59E05A1BC274C4031B77BB94FD84B40A59E05A1BC274C40815EB87361D64B402E573F36C9234C40815EB87361D64B40
66892	30993	56.279578000000001	56.310443999999997	55.689933000000003	55.674849000000002	Дружбы	0103000020E610000001000000050000002E573F36C9234C40815EB87361D64B402E573F36C9234C4031B77BB94FD84B40A59E05A1BC274C4031B77BB94FD84B40A59E05A1BC274C40815EB87361D64B402E573F36C9234C40815EB87361D64B40
66360	46570	57.430680000000002	57.445151000000003	56.048867000000001	56.022100999999999	Набережная	0103000020E610000001000000050000004985B18520B74C40BD1AA034D4024C404985B18520B74C40446D1B4641064C400F643DB5FAB84C40446D1B4641064C400F643DB5FAB84C40BD1AA034D4024C404985B18520B74C40BD1AA034D4024C40
66274	30584	57.109909000000002	57.127678000000003	55.628286000000003	55.621648	Центральная	0103000020E610000001000000050000009E44847F118E4C40D9CF622992CF4B409E44847F118E4C407044F7AC6BD04B409835B1C057904C407044F7AC6BD04B409835B1C057904C40D9CF622992CF4B409E44847F118E4C40D9CF622992CF4B40
65084	29646	56.841465999999997	56.869700000000002	55.715859999999999	55.703763000000002	Центральная	0103000020E6100000010000000500000014596B28B56B4C404391EEE714DA4B4014596B28B56B4C40DD41EC4CA1DB4B4065AA6054526F4C40DD41EC4CA1DB4B4065AA6054526F4C404391EEE714DA4B4014596B28B56B4C404391EEE714DA4B40
65094	30730	57.090415999999998	57.110798000000003	55.955523999999997	55.944721999999999	Центральная	0103000020E610000001000000050000007F8461C0928B4C40E6E786A6ECF84B407F8461C0928B4C408445459C4EFA4B402A3BFDA02E8E4C408445459C4EFA4B402A3BFDA02E8E4C40E6E786A6ECF84B407F8461C0928B4C40E6E786A6ECF84B40
65090	29899	56.989561999999999	57.015793000000002	55.894661999999997	55.876899999999999	Школьная	0103000020E61000000100000005000000A3AEB5F7A97E4C4063EE5A423EF04B40A3AEB5F7A97E4C40AA7CCF4884F24B40BC40498105824C40AA7CCF4884F24B40BC40498105824C4063EE5A423EF04B40A3AEB5F7A97E4C4063EE5A423EF04B40
64666	31030	56.302898999999996	56.326442999999998	55.611465000000003	55.596421999999997	Центральная	0103000020E61000000100000005000000DC7EF964C5264C40B54E5C8E57CC4B40DC7EF964C5264C4007D3307C44CE4B400A815CE2C8294C4007D3307C44CE4B400A815CE2C8294C40B54E5C8E57CC4B40DC7EF964C5264C40B54E5C8E57CC4B40
65512	31760	56.461531999999998	56.495255	55.676296000000001	55.663069999999998	Центральная	0103000020E610000001000000050000005B07077B133B4C40B77A4E7ADFD44B405B07077B133B4C40333509DE90D64B401A170E84643F4C40333509DE90D64B401A170E84643F4C40B77A4E7ADFD44B405B07077B133B4C40B77A4E7ADFD44B40
62322	30492	56.951141	56.974901000000003	55.772421000000001	55.750145000000003	Октябрьская	0103000020E610000001000000050000003F7100FDBE794C40042159C004E04B403F7100FDBE794C402FDFFAB0DEE24B403AEB538EC97C4C402FDFFAB0DEE24B403AEB538EC97C4C40042159C004E04B403F7100FDBE794C40042159C004E04B40
65089	30319	56.344410000000003	56.377521999999999	55.724226000000002	55.707684	Мира	0103000020E610000001000000050000002B357BA0152C4C4084F3A96395DA4B402B357BA0152C4C40DA740470B3DC4B40A0C211A452304C40DA740470B3DC4B40A0C211A452304C4084F3A96395DA4B402B357BA0152C4C4084F3A96395DA4B40
65097	30835	57.421453999999997	57.435575	56.005209000000001	55.985326999999998	Центральная	0103000020E610000001000000050000005A626534F2B54C40D26EF4311FFE4B405A626534F2B54C408B5242B0AA004C4044FAEDEBC0B74C408B5242B0AA004C4044FAEDEBC0B74C40D26EF4311FFE4B405A626534F2B54C40D26EF4311FFE4B40
66282	31736	56.443179000000001	56.464146	55.641702000000002	55.628124	Школьная	0103000020E6100000010000000500000012A3E716BA384C4096EA025E66D04B4012A3E716BA384C408FE3874A23D24B40DC48D922693B4C408FE3874A23D24B40DC48D922693B4C4096EA025E66D04B4012A3E716BA384C4096EA025E66D04B40
65436	47644	57.126645000000003	57.151770999999997	55.708241999999998	55.697422000000003	Почтовая	0103000020E61000000100000005000000D99942E735904C4066C1C41F45D94B40D99942E735904C40AAD381ACA7DA4B4098BD6C3B6D934C40AAD381ACA7DA4B4098BD6C3B6D934C4066C1C41F45D94B40D99942E735904C4066C1C41F45D94B40
9836	29166	56.750188000000001	56.815738000000003	55.626613999999996	55.600430000000003	Центральная	0103000020E6100000010000000500000003ED0E2906604C40C6C4E6E3DACC4B4003ED0E2906604C409D9B36E334D04B405F0D501A6A684C409D9B36E334D04B405F0D501A6A684C40C6C4E6E3DACC4B4003ED0E2906604C40C6C4E6E3DACC4B40
64018	32979	57.015334000000003	57.032446999999998	55.705219	55.696027000000001	Советская	0103000020E610000001000000050000002942EA76F6814C400611A96917D94B402942EA76F6814C4048C2BE9D44DA4B4039ED293927844C4048C2BE9D44DA4B4039ED293927844C400611A96917D94B402942EA76F6814C400611A96917D94B40
63449	29756	56.861246000000001	56.931665000000002	55.85772	55.822012999999998	Мира	0103000020E61000000100000005000000C9E7154F3D6E4C4084F1D3B837E94B40C9E7154F3D6E4C400490DAC4C9ED4B40F7E978CC40774C400490DAC4C9ED4B40F7E978CC40774C4084F1D3B837E94B40C9E7154F3D6E4C4084F1D3B837E94B40
63493	29756	56.861246000000001	56.931665000000002	55.85772	55.822012999999998	Ленина	0103000020E61000000100000005000000C9E7154F3D6E4C4084F1D3B837E94B40C9E7154F3D6E4C400490DAC4C9ED4B40F7E978CC40774C400490DAC4C9ED4B40F7E978CC40774C4084F1D3B837E94B40C9E7154F3D6E4C4084F1D3B837E94B40
63505	3167	56.455855	56.471189000000003	55.562378000000002	55.555280000000003	Карла Маркса	0103000020E61000000100000005000000EA5BE674593A4C40BB0F406A13C74B40EA5BE674593A4C40B5FE9600FCC74B40139ED0EB4F3C4C40B5FE9600FCC74B40139ED0EB4F3C4C40BB0F406A13C74B40EA5BE674593A4C40BB0F406A13C74B40
64913	47471	56.737988999999999	56.757041999999998	55.75094	55.736741000000002	Центральная	0103000020E6100000010000000500000064E76D6C765E4C40A94F72874DDE4B4064E76D6C765E4C400EA14ACD1EE04B4066D993C0E6604C400EA14ACD1EE04B4066D993C0E6604C40A94F72874DDE4B4064E76D6C765E4C40A94F72874DDE4B40
65589	58573	56.605486999999997	56.627719999999997	55.650886	55.639578	переулок Школьный	0103000020E610000001000000050000009A931799804D4C40DC9E20B1DDD14B409A931799804D4C404EB6813B50D34B40C685032159504C404EB6813B50D34B40C685032159504C40DC9E20B1DDD14B409A931799804D4C40DC9E20B1DDD14B40
65162	47028	56.318897999999997	56.339576999999998	55.735889999999998	55.722517000000003	Лесная	0103000020E61000000100000005000000416150A6D1284C40EBE6E26F7BDC4B40416150A6D1284C400ABABDA431DE4B40A5BC5642772B4C400ABABDA431DE4B40A5BC5642772B4C40EBE6E26F7BDC4B40416150A6D1284C40EBE6E26F7BDC4B40
66586	17180	56.935205000000003	56.953449999999997	55.799430999999998	55.785406999999999	Центральная	0103000020E61000000100000005000000210725CCB4774C405586713788E44B40210725CCB4774C404C3448C153E64B40832F4CA60A7A4C404C3448C153E64B40832F4CA60A7A4C405586713788E44B40210725CCB4774C405586713788E44B40
66281	47252	57.489564000000001	57.505212999999998	55.813344000000001	55.803463999999998	Лесная	0103000020E6100000010000000500000044A67C08AABE4C40B5C189E8D7E64B4044A67C08AABE4C40EC32FCA71BE84B40CC41D0D1AAC04C40EC32FCA71BE84B40CC41D0D1AAC04C40B5C189E8D7E64B4044A67C08AABE4C40B5C189E8D7E64B40
63445	29473	56.551346000000002	56.603655000000003	55.816439000000003	55.798054999999998	Корочкина	0103000020E61000000100000005000000E563778192464C4063B48EAA26E64B40E563778192464C40E816BA1281E84B4090882991444D4C40E816BA1281E84B4090882991444D4C4063B48EAA26E64B40E563778192464C4063B48EAA26E64B40
66879	5011	56.594276000000001	56.616976999999999	55.885427999999997	55.874718000000001	Центральная	0103000020E610000001000000050000001B66683C114C4C407C9C69C2F6EF4B401B66683C114C4C40397B67B455F14B402DB1321AF94E4C40397B67B455F14B402DB1321AF94E4C407C9C69C2F6EF4B401B66683C114C4C407C9C69C2F6EF4B40
66731	29568	56.789560999999999	56.849595000000001	55.850459000000001	55.82976	Ленина	0103000020E610000001000000050000003999B85510654C40B5C35F9335EA4B403999B85510654C4060CB2BD7DBEC4B402DEC6987BF6C4C4060CB2BD7DBEC4B402DEC6987BF6C4C40B5C35F9335EA4B403999B85510654C40B5C35F9335EA4B40
66140	46968	56.696216999999997	56.707113999999997	55.581093000000003	55.56841	Школьная	0103000020E61000000100000005000000A9F57EA31D594C40145CACA8C1C84B40A9F57EA31D594C409F77634161CA4B40994528B6825A4C409F77634161CA4B40994528B6825A4C40145CACA8C1C84B40A9F57EA31D594C40145CACA8C1C84B40
64373	29851	56.912216999999998	56.945867999999997	55.830193999999999	55.812443999999999	Лежнина	0103000020E6100000010000000500000078EDD286C3744C406CEA3C2AFEE74B4078EDD286C3744C40EFAA07CC43EA4B409D2ADF3312794C40EFAA07CC43EA4B409D2ADF3312794C406CEA3C2AFEE74B4078EDD286C3744C406CEA3C2AFEE74B40
65227	29375	56.411181999999997	56.426946999999998	55.837985000000003	55.819595	Ленина	0103000020E61000000100000005000000185A9D9CA1344C40897B2C7DE8E84B40185A9D9CA1344C40F0C4AC1743EB4B400A100533A6364C40F0C4AC1743EB4B400A100533A6364C40897B2C7DE8E84B40185A9D9CA1344C40897B2C7DE8E84B40
66771	30092	57.003323999999999	57.081693000000001	55.726239	55.709353	С.Юлаева	0103000020E610000001000000050000005DA5BBEB6C804C40E5284014CCDA4B405DA5BBEB6C804C40350A4966F5DC4B40F4A78DEA748A4C40350A4966F5DC4B40F4A78DEA748A4C40E5284014CCDA4B405DA5BBEB6C804C40E5284014CCDA4B40
64745	28041	54.770282999999999	54.790145000000003	55.803736999999998	55.789188000000003	Центральная	0103000020E6100000010000000500000017D522A298624B40A532C51C04E54B4017D522A298624B40E6CAA0DAE0E64B40890CAB7823654B40E6CAA0DAE0E64B40890CAB7823654B40A532C51C04E54B4017D522A298624B40A532C51C04E54B40
64800	28301	54.450589999999998	54.472419000000002	56.09798	56.087077000000001	Пеледыш	0103000020E61000000100000005000000CBF3E0EEAC394B40ED9DD156250B4C40CBF3E0EEAC394B40BFD4CF9B8A0C4C402881CD39783C4B40BFD4CF9B8A0C4C402881CD39783C4B40ED9DD156250B4C40CBF3E0EEAC394B40ED9DD156250B4C40
65670	28561	54.855936999999997	54.874406999999998	56.057110999999999	56.039800999999997	 Центральная	0103000020E61000000100000005000000DA37F7578F6D4B408EACFC3218054C40DA37F7578F6D4B40F59ECA694F074C405D328E91EC6F4B40F59ECA694F074C405D328E91EC6F4B408EACFC3218054C40DA37F7578F6D4B408EACFC3218054C40
66775	28546	54.715108000000001	54.735509	56.095685000000003	56.083295	Комсомольская	0103000020E61000000100000005000000D28DB0A8885B4B40CD751A69A90A4C40D28DB0A8885B4B40E0DBF4673F0C4C40F374AE28255E4B40E0DBF4673F0C4C40F374AE28255E4B40CD751A69A90A4C40D28DB0A8885B4B40CD751A69A90A4C40
66532	58826	54.410418	55.422153999999999	56.151300999999997	55.718806000000001	Центральная	0103000020E6100000010000000500000049D8B79388344B409415C3D501DC4B4049D8B79388344B40116DC7D45D134C4013F06B2409B64B40116DC7D45D134C4013F06B2409B64B409415C3D501DC4B4049D8B79388344B409415C3D501DC4B40
65673	28872	55.332700000000003	55.346831000000002	56.041384999999998	56.029893999999999	Садовая	0103000020E610000001000000050000008AB0E1E995AA4B405E2C0C91D3034C408AB0E1E995AA4B40C1C58A1A4C054C40971E4DF564AC4B40C1C58A1A4C054C40971E4DF564AC4B405E2C0C91D3034C408AB0E1E995AA4B405E2C0C91D3034C40
65347	58525	54.431626999999999	54.443196999999998	56.098917999999998	56.091918999999997	Ленина	0103000020E610000001000000050000000989B48D3F374B40C5707500C40B4C400989B48D3F374B402C7E5358A90C4C40B857E6ADBA384B402C7E5358A90C4C40B857E6ADBA384B40C5707500C40B4C400989B48D3F374B40C5707500C40B4C40
66262	28727	55.144269000000001	55.166691	55.986747000000001	55.976030000000002	Ленина	0103000020E61000000100000005000000CF69166877924B401BF5108DEEFC4B40CF69166877924B408B36C7B94DFE4B40CEC4742156954B408B36C7B94DFE4B40CEC4742156954B401BF5108DEEFC4B40CF69166877924B401BF5108DEEFC4B40
65470	28455	54.709251000000002	54.729886	55.989708	55.971803999999999	Гагарина	0103000020E61000000100000005000000E1D39CBCC85A4B409D0FCF1264FC4B40E1D39CBCC85A4B40774B72C0AEFE4B4075E789E76C5D4B40774B72C0AEFE4B4075E789E76C5D4B409D0FCF1264FC4B40E1D39CBCC85A4B409D0FCF1264FC4B40
64902	58393	54.868343000000003	54.893881999999998	55.859518999999999	55.846567999999998	Центральная	0103000020E61000000100000005000000F35A09DD256F4B4089EB18575CEC4B40F35A09DD256F4B4033A5F5B704EE4B40D53DB2B96A724B4033A5F5B704EE4B40D53DB2B96A724B4089EB18575CEC4B40F35A09DD256F4B4089EB18575CEC4B40
63306	58099	55.083956999999998	55.096451999999999	55.967748	55.951658000000002	Танып	0103000020E6100000010000000500000098A25C1ABF8A4B40077DE9EDCFF94B4098A25C1ABF8A4B407C629D2ADFFB4B4020D1048A588C4B407C629D2ADFFB4B4020D1048A588C4B40077DE9EDCFF94B4098A25C1ABF8A4B40077DE9EDCFF94B40
65671	28809	55.257241999999998	55.282107000000003	56.001770999999998	55.994446000000003	Школьная	0103000020E610000001000000050000002D944C4EEDA04B40ABD1AB014AFF4B402D944C4EEDA04B40658A39083A004C40817C09151CA44B40658A39083A004C40817C09151CA44B40ABD1AB014AFF4B402D944C4EEDA04B40ABD1AB014AFF4B40
64479	28179	54.508755999999998	54.538831999999999	56.004479000000003	55.985211	Нефтяников	0103000020E6100000010000000500000067D2A6EA1E414B406954E0641BFE4B4067D2A6EA1E414B40684293C492004C40E6046D72F8444B40684293C492004C40E6046D72F8444B406954E0641BFE4B4067D2A6EA1E414B406954E0641BFE4B40
66239	29030	55.071497000000001	55.100261000000003	55.882044999999998	55.864823000000001	Нагорная	0103000020E610000001000000050000008D614ED026894B4010EA2285B2EE4B408D614ED026894B40D74CBED9E6F04B403A083A5AD58C4B40D74CBED9E6F04B403A083A5AD58C4B4010EA2285B2EE4B408D614ED026894B4010EA2285B2EE4B40
63486	4918	55.032932000000002	55.060816000000003	55.999842999999998	55.973365000000001	Юбилейная	0103000020E61000000100000005000000F67EA31D37844B4018096D3997FC4B40F67EA31D37844B403811FDDAFAFF4B406A8995D1C8874B403811FDDAFAFF4B406A8995D1C8874B4018096D3997FC4B40F67EA31D37844B4018096D3997FC4B40
63490	4918	55.032932000000002	55.060816000000003	55.999842999999998	55.973365000000001	Тимиряя	0103000020E61000000100000005000000F67EA31D37844B4018096D3997FC4B40F67EA31D37844B403811FDDAFAFF4B406A8995D1C8874B403811FDDAFAFF4B406A8995D1C8874B4018096D3997FC4B40F67EA31D37844B4018096D3997FC4B40
63441	4918	55.032932000000002	55.060816000000003	55.999842999999998	55.973365000000001	Стадионная	0103000020E61000000100000005000000F67EA31D37844B4018096D3997FC4B40F67EA31D37844B403811FDDAFAFF4B406A8995D1C8874B403811FDDAFAFF4B406A8995D1C8874B4018096D3997FC4B40F67EA31D37844B4018096D3997FC4B40
66861	4918	55.032932000000002	55.060816000000003	55.999842999999998	55.973365000000001	Парковая	0103000020E61000000100000005000000F67EA31D37844B4018096D3997FC4B40F67EA31D37844B403811FDDAFAFF4B406A8995D1C8874B403811FDDAFAFF4B406A8995D1C8874B4018096D3997FC4B40F67EA31D37844B4018096D3997FC4B40
64646	28475	54.672967999999997	54.691510000000001	55.993369000000001	55.978628999999998	Пушкина	0103000020E6100000010000000500000094A0BFD023564B4066F50EB743FD4B4094A0BFD023564B401CEE23B726FF4B40B16D516683584B401CEE23B726FF4B40B16D516683584B4066F50EB743FD4B4094A0BFD023564B4066F50EB743FD4B40
65224	29013	55.164158	55.18835	55.963793000000003	55.956511999999996	В.Абдуллина	0103000020E610000001000000050000003AB01C2103954B40A31D37FC6EFA4B403AB01C2103954B408F8EAB915DFB4B40CE1951DA1B984B408F8EAB915DFB4B40CE1951DA1B984B40A31D37FC6EFA4B403AB01C2103954B40A31D37FC6EFA4B40
66322	48421	54.619303000000002	54.621558	56.014654999999998	56.010708999999999	Школьная	0103000020E6100000010000000500000048A81952454F4B40ED629AE95E014C4048A81952454F4B4087DC0C37E0014C40994869368F4F4B4087DC0C37E0014C40994869368F4F4B40ED629AE95E014C4048A81952454F4B40ED629AE95E014C40
65117	27922	54.925708999999998	54.952748999999997	55.899743999999998	55.889668999999998	Молодежная	0103000020E61000000100000005000000724EECA17D764B40ECA17DACE0F14B40724EECA17D764B40D862B7CF2AF34B40FA25E2ADF3794B40D862B7CF2AF34B40FA25E2ADF3794B40ECA17DACE0F14B40724EECA17D764B40ECA17DACE0F14B40
65225	28265	54.544697999999997	54.562385999999996	56.103411999999999	56.084204	Советская	0103000020E610000001000000050000002A1900AAB8454B40A0185932C70A4C402A1900AAB8454B40C901BB9A3C0D4C4037DDB243FC474B40C901BB9A3C0D4C4037DDB243FC474B40A0185932C70A4C402A1900AAB8454B40A0185932C70A4C40
65125	28112	54.450420000000001	54.464900999999998	55.935091999999997	55.918393000000002	Мира	0103000020E610000001000000050000006FBBD05CA7394B400BF0DDE68DF54B406FBBD05CA7394B4028603B18B1F74B4058703FE0813B4B4028603B18B1F74B4058703FE0813B4B400BF0DDE68DF54B406FBBD05CA7394B400BF0DDE68DF54B40
65668	28544	54.701031999999998	54.713248999999998	56.019570999999999	56.008972999999997	Кирова	0103000020E6100000010000000500000088B9A46ABB594B4004C6FA0626014C4088B9A46ABB594B409A79724D81024C40CD7344BE4B5B4B409A79724D81024C40CD7344BE4B5B4B4004C6FA0626014C4088B9A46ABB594B4004C6FA0626014C40
64442	28095	54.531995999999999	54.562232999999999	55.976371999999998	55.955573999999999	Советская	0103000020E6100000010000000500000029CDE67118444B403674B33F50FA4B4029CDE67118444B40745DF8C1F9FC4B40B1DD3D40F7474B40745DF8C1F9FC4B40B1DD3D40F7474B403674B33F50FA4B4029CDE67118444B403674B33F50FA4B40
64788	28642	54.815970999999998	54.834423000000001	56.037804999999999	56.028841999999997	Кооперативная	0103000020E6100000010000000500000001BEDBBC71684B4028603B18B1034C4001BEDBBC71684B40095053CBD6044C40DE03745FCE6A4B40095053CBD6044C40DE03745FCE6A4B4028603B18B1034C4001BEDBBC71684B4028603B18B1034C40
65746	29140	54.951320000000003	54.970939999999999	56.022665000000003	56.012797999999997	Центральная	0103000020E61000000100000005000000EF0390DAC4794B4023BA675DA3014C40EF0390DAC4794B40C6E1CCAFE6024C406A300DC3477C4B40C6E1CCAFE6024C406A300DC3477C4B4023BA675DA3014C40EF0390DAC4794B4023BA675DA3014C40
64411	28951	55.149462	55.180714000000002	55.924325000000003	55.916431000000003	Советская	0103000020E6100000010000000500000054FF209221934B4032056B9C4DF54B4054FF209221934B4007F0164850F64B40F5F6E7A221974B4007F0164850F64B40F5F6E7A221974B4032056B9C4DF54B4054FF209221934B4032056B9C4DF54B40
65904	47282	54.761640999999997	54.775421000000001	55.931970999999997	55.925153000000002	Школьная	0103000020E610000001000000050000007825C9737D614B40ED65DB696BF64B407825C9737D614B4003E962D34AF74B40D9D0CDFE40634B4003E962D34AF74B40D9D0CDFE40634B40ED65DB696BF64B407825C9737D614B40ED65DB696BF64B40
64604	58296	55.032465000000002	55.053089999999997	55.899521999999997	55.891990999999997	Центральная	0103000020E61000000100000005000000E0A128D027844B40C5A9D6C22CF24B40E0A128D027844B402904728923F34B4050DF32A7CB864B402904728923F34B4050DF32A7CB864B40C5A9D6C22CF24B40E0A128D027844B40C5A9D6C22CF24B40
66258	28338	54.604041000000002	54.628124	56.069906000000003	56.055432000000003	Дружбы	0103000020E61000000100000005000000B9382A37514D4B407193516518074C40B9382A37514D4B40A8E507AEF2084C4096EA025E66504B40A8E507AEF2084C4096EA025E66504B407193516518074C40B9382A37514D4B407193516518074C40
66234	28925	55.301780000000001	55.327435999999999	55.999535999999999	55.990841000000003	Дорожная	0103000020E610000001000000050000001F4B1FBAA0A64B409A44BDE0D3FE4B401F4B1FBAA0A64B405B96AFCBF0FF4B403BC43F6CE9A94B405B96AFCBF0FF4B403BC43F6CE9A94B409A44BDE0D3FE4B401F4B1FBAA0A64B409A44BDE0D3FE4B40
65105	26166	56.021816000000001	56.036737000000002	53.512104000000001	53.493561999999997	Береговая	0103000020E61000000100000005000000C843DFDDCA024C403046240A2DBF4A40C843DFDDCA024C404D13B69F8CC14A40CEC64ACCB3044C404D13B69F8CC14A40CEC64ACCB3044C403046240A2DBF4A40C843DFDDCA024C403046240A2DBF4A40
66851	32638	56.340744999999998	56.366768999999998	53.694598999999997	53.676628000000001	Пролетарская	0103000020E6100000010000000500000044A33B889D2B4C4069C70DBF9BD64A4044A33B889D2B4C40CA6ABA9EE8D84A40E3175E49F22E4C40CA6ABA9EE8D84A40E3175E49F22E4C4069C70DBF9BD64A4044A33B889D2B4C4069C70DBF9BD64A40
67019	58917	56.078355999999999	56.089998000000001	53.568161000000003	53.562615999999998	Центральная	0103000020E6100000010000000500000002B9C491070A4C40691A14CD03C84A4002B9C491070A4C406CEEE87FB9C84A404B5AF10D850B4C406CEEE87FB9C84A404B5AF10D850B4C40691A14CD03C84A4002B9C491070A4C40691A14CD03C84A40
63781	58129	56.059939999999997	56.078679000000001	53.663531999999996	53.640002000000003	Российская	0103000020E6100000010000000500000072DC291DAC074C40F3AFE595EBD14A4072DC291DAC074C40BBECD79DEED44A40E5F04927120A4C40BBECD79DEED44A40E5F04927120A4C40F3AFE595EBD14A4072DC291DAC074C40F3AFE595EBD14A40
64187	26187	56.068834000000003	56.093178000000002	53.533495000000002	53.520895000000003	Центральная	0103000020E610000001000000050000002B6D718DCF084C4031D3F6AFACC24A402B6D718DCF084C402ECA6C9049C44A40755AB741ED0B4C402ECA6C9049C44A40755AB741ED0B4C4031D3F6AFACC24A402B6D718DCF084C4031D3F6AFACC24A40
66685	27383	56.327755000000003	56.356267000000003	53.341273999999999	53.323594	Октября	0103000020E61000000100000005000000DD0C37E0F3294C40469737876BA94A40DD0C37E0F3294C40D07CCEDDAEAB4A4070D234289A2D4C40D07CCEDDAEAB4A4070D234289A2D4C40469737876BA94A40DD0C37E0F3294C40469737876BA94A40
65843	26534	56.317478000000001	56.349431000000003	53.544711999999997	53.531216000000001	Партизанская	0103000020E6100000010000000500000089997D1EA3284C40548EC9E2FEC34A4089997D1EA3284C408FDE701FB9C54A40B39AAE27BA2C4C408FDE701FB9C54A40B39AAE27BA2C4C40548EC9E2FEC34A4089997D1EA3284C40548EC9E2FEC34A40
66247	27597	56.105035999999998	56.139774000000003	53.316633000000003	53.290174999999998	Школьная	0103000020E610000001000000050000008A73D4D1710D4C40F38E537424A54A408A73D4D1710D4C40CDEA1D6E87A84A40626A4B1DE4114C40CDEA1D6E87A84A40626A4B1DE4114C40F38E537424A54A408A73D4D1710D4C40F38E537424A54A40
66828	21549	56.384977999999997	56.414155000000001	53.453516	53.440372000000004	Надыршина	0103000020E61000000100000005000000F9D687F546314C407D09151C5EB84A40F9D687F546314C403B1BF2CF0CBA4A40C93CF20703354C403B1BF2CF0CBA4A40C93CF20703354C407D09151C5EB84A40F9D687F546314C407D09151C5EB84A40
65504	58559	56.411199000000003	56.432310000000001	53.581479999999999	53.564765999999999	Электрофикации	0103000020E61000000100000005000000EF92382BA2344C4045F295404AC84A40EF92382BA2344C4098A3C7EF6DCA4A40ECDD1FEF55374C4098A3C7EF6DCA4A40ECDD1FEF55374C4045F295404AC84A40EF92382BA2344C4045F295404AC84A40
66692	27271	56.286109000000003	56.306545999999997	53.492507000000003	53.474347999999999	Школьная	0103000020E61000000100000005000000AF0B3F389F244C4025766D6FB7BC4A40AF0B3F389F244C408A0629780ABF4A401C5C3AE63C274C408A0629780ABF4A401C5C3AE63C274C4025766D6FB7BC4A40AF0B3F389F244C4025766D6FB7BC4A40
66854	26670	56.490547999999997	56.509008000000001	53.680719000000003	53.654845000000002	Гизатуллина	0103000020E61000000100000005000000218FE046CA3E4C407D7901F6D1D34A40218FE046CA3E4C400762D9CC21D74A4081B3942C27414C400762D9CC21D74A4081B3942C27414C407D7901F6D1D34A40218FE046CA3E4C407D7901F6D1D34A40
63826	58136	56.914983999999997	56.950907000000001	53.586227000000001	53.573669000000002	Школьная	0103000020E610000001000000050000007F2E1A321E754C4051DD5CFC6DC94A407F2E1A321E754C401F84807C09CB4A40CC441152B7794C401F84807C09CB4A40CC441152B7794C4051DD5CFC6DC94A407F2E1A321E754C4051DD5CFC6DC94A40
66881	27096	56.460391000000001	56.500222999999998	53.568578000000002	53.558166	Советская	0103000020E61000000100000005000000B62FA017EE3A4C409CDEC5FB71C74A40B62FA017EE3A4C40D09CF529C7C84A407FDAA84E07404C40D09CF529C7C84A407FDAA84E07404C409CDEC5FB71C74A40B62FA017EE3A4C409CDEC5FB71C74A40
66914	27649	56.044507000000003	56.059356000000001	53.300094000000001	53.288156000000001	Первомайская	0103000020E61000000100000005000000B7B8C667B2054C40B612BA4BE2A44A40B7B8C667B2054C40E8DCED7A69A64A40236937FA98074C40E8DCED7A69A64A40236937FA98074C40B612BA4BE2A44A40B7B8C667B2054C40B612BA4BE2A44A40
66678	27509	56.184842000000003	56.208917	53.413576999999997	53.394364000000003	1 мая	0103000020E61000000100000005000000B07614E7A8174C40215C01857AB24A40B07614E7A8174C405BB05417F0B44A400A4AD1CABD1A4C405BB05417F0B44A400A4AD1CABD1A4C40215C01857AB24A40B07614E7A8174C40215C01857AB24A40
66589	26249	56.034211999999997	56.055745000000002	53.603076999999999	53.586739999999999	Кутушева	0103000020E61000000100000005000000BC900E0F61044C40A5A0DB4B1ACB4A40BC900E0F61044C4022FC8BA031CD4A4030F5F3A622074C4022FC8BA031CD4A4030F5F3A622074C40A5A0DB4B1ACB4A40BC900E0F61044C40A5A0DB4B1ACB4A40
66855	26385	56.193339999999999	56.212967999999996	53.566353999999997	53.552672000000001	Хасанова	0103000020E610000001000000050000001B81785DBF184C401CB5C2F4BDC64A401B81785DBF184C40B9FAB1497EC84A40198C1189421B4C40B9FAB1497EC84A40198C1189421B4C401CB5C2F4BDC64A401B81785DBF184C401CB5C2F4BDC64A40
9703	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Чкалова	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63281	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Стахановская	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63662	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Советская	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63755	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Революционная	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63620	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Мичурина	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
64179	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Ленина проспект	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63524	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Крылова	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63731	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Ишимбайская	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63615	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Заки Валиди бульвар	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
66783	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Жуковского	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
63467	1315	56.008602000000003	56.093420000000002	53.495384000000001	53.400602999999997	Губкина	0103000020E610000001000000050000001157CEDE19014C40F9D687F546B34A401157CEDE19014C40187B2FBE68BF4A406B65C22FF50B4C40187B2FBE68BF4A406B65C22FF50B4C40F9D687F546B34A401157CEDE19014C40F9D687F546B34A40
66936	32671	56.114063999999999	56.15155	53.625629000000004	53.611299000000002	Уразбаевых	0103000020E6100000010000000500000052D32EA6990E4C40EC89AE0B3FCE4A4052D32EA6990E4C40F0366F9C14D04A40BADA8AFD65134C40F0366F9C14D04A40BADA8AFD65134C40EC89AE0B3FCE4A4052D32EA6990E4C40EC89AE0B3FCE4A40
64135	27671	56.257748999999997	56.301721999999998	53.197685	53.181137	Ленина	0103000020E61000000100000005000000D1C952EBFD204C403B8C497F2F974A40D1C952EBFD204C4073F4F8BD4D994A40EA3D95D39E264C4073F4F8BD4D994A40EA3D95D39E264C403B8C497F2F974A40D1C952EBFD204C403B8C497F2F974A40
66874	27289	56.309106	56.342486999999998	53.390847000000001	53.364977000000003	Молодежная	0103000020E61000000100000005000000AA7F10C990274C406765FB90B7AE4A40AA7F10C990274C40AF5E454607B24A400F27309DD62B4C40AF5E454607B24A400F27309DD62B4C406765FB90B7AE4A40AA7F10C990274C406765FB90B7AE4A40
66925	33109	56.481762000000003	56.501741000000003	53.707312000000002	53.682158999999999	Советская	0103000020E61000000100000005000000503A9160AA3D4C4006D671FC50D74A40503A9160AA3D4C40C0081A3389DA4A40FB07910C39404C40C0081A3389DA4A40FB07910C39404C4006D671FC50D74A40503A9160AA3D4C4006D671FC50D74A40
66858	27129	56.317469000000003	56.329498000000001	53.471705999999998	53.459854	Селеукская	0103000020E61000000100000005000000363FFED2A2284C40A777F17EDCBA4A40363FFED2A2284C40DAA9B9DC60BC4A40780C8FFD2C2A4C40DAA9B9DC60BC4A40780C8FFD2C2A4C40A777F17EDCBA4A40363FFED2A2284C40A777F17EDCBA4A40
66013	26465	56.355665999999999	56.374960999999999	53.583013999999999	53.565755000000003	Центральная	0103000020E610000001000000050000004A26A776862D4C403546EBA86AC84A404A26A776862D4C40198EE733A0CA4A404223D8B8FE2F4C40198EE733A0CA4A404223D8B8FE2F4C403546EBA86AC84A404A26A776862D4C403546EBA86AC84A40
66059	48168	56.138094000000002	56.169677999999998	53.435581999999997	53.421042	Школьная	0103000020E610000001000000050000000DE36E10AD114C40081F4AB4E4B54A400DE36E10AD114C40F65CA626C1B74A40E36C3A02B8154C40F65CA626C1B74A40E36C3A02B8154C40081F4AB4E4B54A400DE36E10AD114C40081F4AB4E4B54A40
66357	48168	56.138094000000002	56.169677999999998	53.435581999999997	53.421042	Пионерских лагерей	0103000020E610000001000000050000000DE36E10AD114C40081F4AB4E4B54A400DE36E10AD114C40F65CA626C1B74A40E36C3A02B8154C40F65CA626C1B74A40E36C3A02B8154C40081F4AB4E4B54A400DE36E10AD114C40081F4AB4E4B54A40
66901	32623	56.188588000000003	56.227241999999997	53.604075999999999	53.579132999999999	Горная	0103000020E610000001000000050000008335CEA623184C406684B70721CA4A408335CEA623184C403526C45C52CD4A4089230F44161D4C403526C45C52CD4A4089230F44161D4C406684B70721CA4A408335CEA623184C406684B70721CA4A40
66593	26923	56.440978999999999	56.469104999999999	53.648536999999997	53.637380999999998	Центральная	0103000020E61000000100000005000000849CF7FF71384C40BF0B5BB395D14A40849CF7FF71384C407B9FAA4203D34A40EEB1F4A10B3C4C407B9FAA4203D34A40EEB1F4A10B3C4C40BF0B5BB395D14A40849CF7FF71384C40BF0B5BB395D14A40
66895	27209	56.266435999999999	56.289954000000002	53.501795000000001	53.489784999999998	Салавата Юлаева	0103000020E61000000100000005000000103D29931A224C4022895E46B1BE4A40103D29931A224C40EE258DD13AC04A4015AC71361D254C40EE258DD13AC04A4015AC71361D254C4022895E46B1BE4A40103D29931A224C4022895E46B1BE4A40
66626	21079	56.349601999999997	56.377853999999999	53.410871999999998	53.402579000000003	Гиниятуллина	0103000020E61000000100000005000000DF4E22C2BF2C4C4038876BB587B34A40DF4E22C2BF2C4C40CA6B257497B44A40D65416855D304C40CA6B257497B44A40D65416855D304C4038876BB587B34A40DF4E22C2BF2C4C4038876BB587B34A40
66630	23465	54.384250000000002	54.399548000000003	55.312609000000002	55.301842999999998	Центральная	0103000020E6100000010000000500000077BE9F1A2F314B4065C39ACAA2A64B4077BE9F1A2F314B40B7B75B9203A84B4053978C6324334B40B7B75B9203A84B4053978C6324334B4065C39ACAA2A64B4077BE9F1A2F314B4065C39ACAA2A64B40
66716	6810	54.118006999999999	54.134571999999999	55.594051	55.583953000000001	Центральная	0103000020E610000001000000050000007BD976DA1A0F4B4057B3CEF8BECA4B407BD976DA1A0F4B40FB93F8DC09CC4B40897AC1A739114B40FB93F8DC09CC4B40897AC1A739114B4057B3CEF8BECA4B407BD976DA1A0F4B4057B3CEF8BECA4B40
66899	6991	54.528042999999997	54.545515000000002	55.666274000000001	55.656936000000002	Чапаева	0103000020E61000000100000005000000DCF0BBE996434B4054C8957A16D44B40DCF0BBE996434B406A16687748D54B401D3D7E6FD3454B406A16687748D54B401D3D7E6FD3454B4054C8957A16D44B40DCF0BBE996434B4054C8957A16D44B40
64937	23290	54.353149999999999	54.362060999999997	55.705325999999999	55.693824999999997	Лесная	0103000020E610000001000000050000008C4AEA04342D4B40D712F241CFD84B408C4AEA04342D4B405E82531F48DA4B401A14CD03582E4B405E82531F48DA4B401A14CD03582E4B40D712F241CFD84B408C4AEA04342D4B40D712F241CFD84B40
66725	21938	54.249305	54.275060000000003	55.248894	55.241267000000001	Урняк	0103000020E6100000010000000500000059DDEA39E91F4B40514D49D6E19E4B4059DDEA39E91F4B40D71533C2DB9F4B400938842A35234B40D71533C2DB9F4B400938842A35234B40514D49D6E19E4B4059DDEA39E91F4B40514D49D6E19E4B40
66841	32541	54.141973999999998	54.161180000000002	55.516955000000003	55.509345000000003	Лесная	0103000020E61000000100000005000000EF703B342C124B40C9B08A3732C14B40EF703B342C124B407940D9942BC24B407862D68BA1144B407940D9942BC24B407862D68BA1144B40C9B08A3732C14B40EF703B342C124B40C9B08A3732C14B40
66796	22226	54.005116000000001	54.032846999999997	55.518932999999997	55.494543	Центральная	0103000020E61000000100000005000000DA571EA4A7004B409DBB5D2F4DBF4B40DA571EA4A7004B4057E883656CC24B40C7629B5434044B4057E883656CC24B40C7629B5434044B409DBB5D2F4DBF4B40DA571EA4A7004B409DBB5D2F4DBF4B40
65191	23734	54.161396000000003	54.194678000000003	55.277692999999999	55.261572000000001	Центральная	0103000020E6100000010000000500000045DAC69FA8144B4050C6F8307BA14B4045DAC69FA8144B4000AAB8718BA34B4017A06D35EB184B4000AAB8718BA34B4017A06D35EB184B4050C6F8307BA14B4045DAC69FA8144B4050C6F8307BA14B40
66634	7271	53.907046999999999	53.926693	55.419677	55.410913000000001	Сюнь	0103000020E61000000100000005000000AB77B81D1AF44A40294014CC98B44B40AB77B81D1AF44A4013F1D6F9B7B54B40503750E09DF64A4013F1D6F9B7B54B40503750E09DF64A40294014CC98B44B40AB77B81D1AF44A40294014CC98B44B40
66580	58849	54.481186999999998	54.500428999999997	55.543582000000001	55.529429999999998	Центральная	0103000020E6100000010000000500000053211E89973D4B40B9C2BB5CC4C34B4053211E89973D4B40DE58501894C54B40287CB60E0E404B40DE58501894C54B40287CB60E0E404B40B9C2BB5CC4C34B4053211E89973D4B40B9C2BB5CC4C34B40
65850	22398	54.301147	54.327809000000002	55.620508999999998	55.609217000000001	Центральная	0103000020E61000000100000005000000EE2422FC8B264B40689599D2FACD4B40EE2422FC8B264B40D4EFC2D66CCF4B40D02A33A5F5294B40D4EFC2D66CCF4B40D02A33A5F5294B40689599D2FACD4B40EE2422FC8B264B40689599D2FACD4B40
66587	21508	54.461720999999997	54.483604	55.608089	55.598872999999998	Ленина	0103000020E610000001000000050000002E7079AC193B4B408CBAD6DEA7CC4B402E7079AC193B4B40570740DCD5CD4B407E1B62BCE63D4B40570740DCD5CD4B407E1B62BCE63D4B408CBAD6DEA7CC4B402E7079AC193B4B408CBAD6DEA7CC4B40
66822	7042	54.470578000000003	54.482005000000001	55.626584000000001	55.620657000000001	Ворошилова	0103000020E61000000100000005000000CA1B60E63B3C4B40498446B071CF4B40CA1B60E63B3C4B4033198EE733D04B4016C1FF56B23D4B4033198EE733D04B4016C1FF56B23D4B40498446B071CF4B40CA1B60E63B3C4B40498446B071CF4B40
65580	23006	54.542928000000003	54.564810999999999	55.620829999999998	55.600785999999999	Мостовая	0103000020E61000000100000005000000960A2AAA7E454B4084F23E8EE6CC4B40960A2AAA7E454B401630815B77CF4B40E5B512BA4B484B401630815B77CF4B40E5B512BA4B484B4084F23E8EE6CC4B40960A2AAA7E454B4084F23E8EE6CC4B40
65858	23436	54.407255999999997	54.429290999999999	55.301479	55.291407999999997	Центральная	0103000020E61000000100000005000000C58CF0F620344B4079E57ADB4CA54B40C58CF0F620344B4024B726DD96A64B40CBBBEA01F3364B4024B726DD96A64B40CBBBEA01F3364B4079E57ADB4CA54B40C58CF0F620344B4079E57ADB4CA54B40
66906	22801	53.891066000000002	53.916981999999997	55.369838000000001	55.358699000000001	Мухамадиева	0103000020E61000000100000005000000ED4960730EF24A40D00D4DD9E9AD4B40ED4960730EF24A40B66801DA56AF4B40A5828AAA5FF54A40B66801DA56AF4B40A5828AAA5FF54A40D00D4DD9E9AD4B40ED4960730EF24A40D00D4DD9E9AD4B40
65194	24113	54.188130000000001	54.217469000000001	55.749592	55.735368000000001	Советская	0103000020E61000000100000005000000C0B2D2A414184B403143E38920DE4B40C0B2D2A414184B40EFAB72A1F2DF4B4069723106D61B4B40EFAB72A1F2DF4B4069723106D61B4B403143E38920DE4B40C0B2D2A414184B403143E38920DE4B40
65185	23532	54.211522000000002	54.246941999999997	55.468927999999998	55.459119000000001	Советская	0103000020E6100000010000000500000038312427131B4B4072FC5069C4BA4B4038312427131B4B40DF162CD505BC4B402101A3CB9B1F4B40DF162CD505BC4B402101A3CB9B1F4B4072FC5069C4BA4B4038312427131B4B4072FC5069C4BA4B40
65856	23175	54.297274999999999	54.325077999999998	55.693596999999997	55.678423000000002	Новая	0103000020E610000001000000050000008E75711B0D264B4057ED9A90D6D64B408E75711B0D264B4046CD57C9C7D84B401553E9279C294B4046CD57C9C7D84B401553E9279C294B4057ED9A90D6D64B408E75711B0D264B4057ED9A90D6D64B40
66043	22702	54.544392999999999	54.563374000000003	55.490631	55.483989999999999	Центральная	0103000020E61000000100000005000000EE9579ABAE454B40A7CB6262F3BD4B40EE9579ABAE454B40AFB321FFCCBE4B4057B5A4A31C484B40AFB321FFCCBE4B4057B5A4A31C484B40A7CB6262F3BD4B40EE9579ABAE454B40A7CB6262F3BD4B40
64329	23374	54.340637000000001	54.390089000000003	55.365918999999998	55.350996000000002	Советская	0103000020E610000001000000050000005E6743FE992B4B406F83DA6FEDAC4B405E6743FE992B4B4015FE0C6FD6AE4B40C2C3B46FEE314B4015FE0C6FD6AE4B40C2C3B46FEE314B406F83DA6FEDAC4B405E6743FE992B4B406F83DA6FEDAC4B40
65851	21412	54.512790000000003	54.528976999999998	55.627305	55.619405999999998	Титова	0103000020E61000000100000005000000A1DB4B1AA3414B401C7920B248CF4B40A1DB4B1AA3414B4003CFBD874BD04B4008ABB184B5434B4003CFBD874BD04B4008ABB184B5434B401C7920B248CF4B40A1DB4B1AA3414B401C7920B248CF4B40
65179	23093	54.290222999999997	54.313094	55.709012999999999	55.690694000000001	Школьная	0103000020E6100000010000000500000004C6FA0626254B408FC536A968D84B4004C6FA0626254B402CB81FF0C0DA4B407349D57613284B402CB81FF0C0DA4B407349D57613284B408FC536A968D84B4004C6FA0626254B408FC536A968D84B40
66905	22891	54.204065999999997	54.235245999999997	55.416907999999999	55.404263999999998	Куйбышева	0103000020E61000000100000005000000DE1CAED51E1A4B409E7939ECBEB34B40DE1CAED51E1A4B406BB8C83D5DB54B40E5417A8A1C1E4B406BB8C83D5DB54B40E5417A8A1C1E4B409E7939ECBEB34B40DE1CAED51E1A4B409E7939ECBEB34B40
66873	21989	54.317836999999997	54.348407000000002	55.468020000000003	55.456566000000002	К.Маркса	0103000020E61000000100000005000000B83A00E2AE284B40973B33C170BA4B40B83A00E2AE284B40DDEF5014E8BB4B404759BF99982C4B40DDEF5014E8BB4B404759BF99982C4B40973B33C170BA4B40B83A00E2AE284B40973B33C170BA4B40
66046	23745	54.390034999999997	54.418503000000001	55.503171000000002	55.487009	Советская	0103000020E61000000100000005000000CEA5B8AAEC314B40C8ED974F56BE4B40CEA5B8AAEC314B40D7A546E867C04B4092239D8191354B40D7A546E867C04B4092239D8191354B40C8ED974F56BE4B40CEA5B8AAEC314B40C8ED974F56BE4B40
64761	21325	54.496988000000002	54.507966000000003	55.690694000000001	55.680565000000001	Чапаева	0103000020E610000001000000050000009240834D9D3F4B40B0E600C11CD74B409240834D9D3F4B408FC536A968D84B406FBDA60705414B408FC536A968D84B406FBDA60705414B40B0E600C11CD74B409240834D9D3F4B40B0E600C11CD74B40
66826	21645	54.482939000000002	54.512160999999999	55.651369000000003	55.643875999999999	Ленина	0103000020E61000000100000005000000427BF5F1D03D4B40F3565D876AD24B40427BF5F1D03D4B406A50340F60D34B40B1A4DC7D8E414B406A50340F60D34B40B1A4DC7D8E414B40F3565D876AD24B40427BF5F1D03D4B40F3565D876AD24B40
65848	21811	54.556789000000002	54.573740000000001	55.322384	55.310693000000001	Х.Гильданова	0103000020E61000000100000005000000E3E2A8DC44474B404E0CC9C9C4A74B40E3E2A8DC44474B40786000E143A94B401A34F44F70494B40786000E143A94B401A34F44F70494B404E0CC9C9C4A74B40E3E2A8DC44474B404E0CC9C9C4A74B40
66041	22680	54.594347999999997	54.616123000000002	55.478934000000002	55.463115000000002	Кооперативная	0103000020E61000000100000005000000B4386398134C4B40BEA4315A47BB4B40B4386398134C4B40A37895B54DBD4B401EA8531EDD4E4B40A37895B54DBD4B401EA8531EDD4E4B40BEA4315A47BB4B40B4386398134C4B40BEA4315A47BB4B40
64926	22957	54.546081000000001	54.567326999999999	55.604309999999998	55.580782999999997	Шоссейная	0103000020E61000000100000005000000C6FB71FBE5454B405089EB1857CA4B40C6FB71FBE5454B40A852B3075ACD4B40A391CF2B9E484B40A852B3075ACD4B40A391CF2B9E484B405089EB1857CA4B40C6FB71FBE5454B405089EB1857CA4B40
65859	23346	54.315564999999999	54.321556000000001	55.661104999999999	55.650973	Молодежная	0103000020E610000001000000050000009161156F64284B401DCA501553D34B409161156F64284B406D1CB1169FD44B4092EA3BBF28294B406D1CB1169FD44B4092EA3BBF28294B401DCA501553D34B409161156F64284B401DCA501553D34B40
67012	58913	53.845934	54.697096999999999	55.829901	55.203400999999999	Центральная	0103000020E610000001000000050000008849B89047EC4A40A27C410B099A4B408849B89047EC4A4077F52A323AEA4B40E29178793A594B4077F52A323AEA4B40E29178793A594B40A27C410B099A4B408849B89047EC4A40A27C410B099A4B40
65189	22815	54.160955999999999	54.197499000000001	55.401902	55.387106000000003	Мира	0103000020E61000000100000005000000280CCA349A144B40EE0A7DB08CB14B40280CCA349A144B403719558671B34B4011FFB0A547194B403719558671B34B4011FFB0A547194B40EE0A7DB08CB14B40280CCA349A144B40EE0A7DB08CB14B40
66695	22748	54.007280999999999	54.048082000000001	55.369500000000002	55.354450999999997	Центральная	0103000020E61000000100000005000000EB707495EE004B406A847EA65EAD4B40EB707495EE004B409EEFA7C64BAF4B405DC30C8D27064B409EEFA7C64BAF4B405DC30C8D27064B406A847EA65EAD4B40EB707495EE004B406A847EA65EAD4B40
65852	22934	54.181688999999999	54.209923000000003	55.387172	55.370288000000002	Пионерская	0103000020E610000001000000050000007F85CC9541174B40F60CE19865AF4B407F85CC9541174B40A5F622DA8EB14B40D0D6C1C1DE1A4B40A5F622DA8EB14B40D0D6C1C1DE1A4B40F60CE19865AF4B407F85CC9541174B40F60CE19865AF4B40
64155	22642	54.510866999999998	54.541849999999997	55.484245000000001	55.469627000000003	Ленина	0103000020E6100000010000000500000085CD001764414B40C828CFBC1CBC4B4085CD001764414B4032207BBDFBBD4B4036AB3E575B454B4032207BBDFBBD4B4036AB3E575B454B40C828CFBC1CBC4B4085CD001764414B40C828CFBC1CBC4B40
64930	22479	54.436487	54.478582000000003	55.529995999999997	55.510567999999999	Советская	0103000020E61000000100000005000000881057CEDE374B402B31CF4A5AC14B40881057CEDE374B406281AFE8D6C34B40263ACB2C423D4B406281AFE8D6C34B40263ACB2C423D4B402B31CF4A5AC14B40881057CEDE374B402B31CF4A5AC14B40
65070	22347	54.206966999999999	54.236449999999998	55.571855999999997	55.543464999999998	Школьная	0103000020E61000000100000005000000F52C08E57D1A4B40A4C2D84290C54B40F52C08E57D1A4B40BC02D19332C94B40D1915CFE431E4B40BC02D19332C94B40D1915CFE431E4B40A4C2D84290C54B40F52C08E57D1A4B40A4C2D84290C54B40
65245	22347	54.206966999999999	54.236449999999998	55.571855999999997	55.543464999999998	Центральная	0103000020E61000000100000005000000F52C08E57D1A4B40A4C2D84290C54B40F52C08E57D1A4B40BC02D19332C94B40D1915CFE431E4B40BC02D19332C94B40D1915CFE431E4B40A4C2D84290C54B40F52C08E57D1A4B40A4C2D84290C54B40
66769	7192	54.045710999999997	54.072543000000003	55.473025999999997	55.452635000000001	Шоссейная	0103000020E61000000100000005000000A208A9DBD9054B40320395F1EFB94B40A208A9DBD9054B402F14B01D8CBC4B40E146CA1649094B402F14B01D8CBC4B40E146CA1649094B40320395F1EFB94B40A208A9DBD9054B40320395F1EFB94B40
65579	23993	54.184024000000001	54.203006000000002	55.638770000000001	55.620952000000003	Советская	0103000020E61000000100000005000000EDD632198E174B406231EA5A7BCF4B40EDD632198E174B403DD52137C3D14B402672C119FC194B403DD52137C3D14B402672C119FC194B406231EA5A7BCF4B40EDD632198E174B406231EA5A7BCF4B40
66617	58862	53.845934	54.697096999999999	55.829901	55.203400999999999	 Победы	0103000020E610000001000000050000008849B89047EC4A40A27C410B099A4B408849B89047EC4A4077F52A323AEA4B40E29178793A594B4077F52A323AEA4B40E29178793A594B40A27C410B099A4B408849B89047EC4A40A27C410B099A4B40
66923	7297	54.031652000000001	54.044426000000001	55.484918	55.476453999999997	Береговая	0103000020E610000001000000050000002F6D382C0D044B403106D671FCBC4B402F6D382C0D044B40F19E03CB11BE4B40CA8B4CC0AF054B40F19E03CB11BE4B40CA8B4CC0AF054B403106D671FCBC4B402F6D382C0D044B403106D671FCBC4B40
66933	7085	54.324108000000003	54.368977999999998	55.268928000000002	55.242483999999997	Советская	0103000020E610000001000000050000009D2FF65E7C294B40D1E638B7099F4B409D2FF65E7C294B40467D923B6CA24B40C478CDAB3A2F4B40467D923B6CA24B40C478CDAB3A2F4B40D1E638B7099F4B409D2FF65E7C294B40D1E638B7099F4B40
66660	23219	54.310237999999998	54.320729999999998	55.701495999999999	55.697223999999999	Новая	0103000020E61000000100000005000000FCFCF7E0B5274B403FFED2A23ED94B40FCFCF7E0B5274B402D23F59ECAD94B404C6C3EAE0D294B402D23F59ECAD94B404C6C3EAE0D294B403FFED2A23ED94B40FCFCF7E0B5274B403FFED2A23ED94B40
66045	23077	54.445999999999998	54.642263999999997	55.715133999999999	55.611077999999999	Родниковая	0103000020E610000001000000050000000C022B8716394B400DA7CCCD37CE4B400C022B8716394B40FB20CB8289DB4B40F6B2EDB435524B40FB20CB8289DB4B40F6B2EDB435524B400DA7CCCD37CE4B400C022B8716394B400DA7CCCD37CE4B40
65868	58649	54.258701000000002	54.259106000000003	55.693317	55.693083999999999	Чеверева	0103000020E61000000100000005000000A438471D1D214B40C0B0FCF9B6D84B40A438471D1D214B406361889CBED84B404419AA622A214B406361889CBED84B404419AA622A214B40C0B0FCF9B6D84B40A438471D1D214B40C0B0FCF9B6D84B40
63752	1272	54.302143999999998	54.334232	55.461210999999999	55.431626999999999	Советская	0103000020E61000000100000005000000605793A7AC264B400989B48D3FB74B40605793A7AC264B4019C748F608BB4B406AA33A1DC82A4B4019C748F608BB4B406AA33A1DC82A4B400989B48D3FB74B40605793A7AC264B400989B48D3FB74B40
66638	1272	54.302143999999998	54.334232	55.461210999999999	55.431626999999999	Молодежная	0103000020E61000000100000005000000605793A7AC264B400989B48D3FB74B40605793A7AC264B4019C748F608BB4B406AA33A1DC82A4B4019C748F608BB4B406AA33A1DC82A4B400989B48D3FB74B40605793A7AC264B400989B48D3FB74B40
66744	1272	54.302143999999998	54.334232	55.461210999999999	55.431626999999999	Матросова	0103000020E61000000100000005000000605793A7AC264B400989B48D3FB74B40605793A7AC264B4019C748F608BB4B406AA33A1DC82A4B4019C748F608BB4B406AA33A1DC82A4B400989B48D3FB74B40605793A7AC264B400989B48D3FB74B40
63463	1272	54.302143999999998	54.334232	55.461210999999999	55.431626999999999	Коммунистическая	0103000020E61000000100000005000000605793A7AC264B400989B48D3FB74B40605793A7AC264B4019C748F608BB4B406AA33A1DC82A4B4019C748F608BB4B406AA33A1DC82A4B400989B48D3FB74B40605793A7AC264B400989B48D3FB74B40
63406	1272	54.302143999999998	54.334232	55.461210999999999	55.431626999999999	50-лет Октября	0103000020E61000000100000005000000605793A7AC264B400989B48D3FB74B40605793A7AC264B4019C748F608BB4B406AA33A1DC82A4B4019C748F608BB4B406AA33A1DC82A4B400989B48D3FB74B40605793A7AC264B400989B48D3FB74B40
64605	58297	54.318672999999997	54.336638999999998	55.410243999999999	55.395153999999998	Дорожная	0103000020E61000000100000005000000218FE046CA284B401971016894B24B40218FE046CA284B40ABB019E082B44B4071C79BFC162B4B40ABB019E082B44B4071C79BFC162B4B401971016894B24B40218FE046CA284B401971016894B24B40
65866	23807	54.345756999999999	54.372967000000003	55.496122999999997	55.484796000000003	Гафури	0103000020E6100000010000000500000079AEEFC3412C4B40A69D9ACB0DBE4B4079AEEFC3412C4B408EE55DF580BF4B405EBEF561BD2F4B408EE55DF580BF4B405EBEF561BD2F4B40A69D9ACB0DBE4B4079AEEFC3412C4B40A69D9ACB0DBE4B40
65849	22138	54.540475999999998	54.569177000000003	55.374079000000002	55.355939999999997	Ленина	0103000020E61000000100000005000000EE224C512E454B404BAB21718FAD4B40EE224C512E454B40698F17D2E1AF4B405551BCCADA484B40698F17D2E1AF4B405551BCCADA484B404BAB21718FAD4B40EE224C512E454B404BAB21718FAD4B40
66036	32505	54.381518999999997	54.400993999999997	55.540698999999996	55.532787999999996	Центральная	0103000020E61000000100000005000000BCE6559DD5304B40C2D9AD6532C44B40BCE6559DD5304B406DFDF49F35C54B4034F279C553334B406DFDF49F35C54B4034F279C553334B40C2D9AD6532C44B40BCE6559DD5304B40C2D9AD6532C44B40
66030	3813	54.532220000000002	54.559305000000002	55.316983999999998	55.303154999999997	Ленина	0103000020E610000001000000050000007923F3C81F444B40374F75C8CDA64B407923F3C81F444B4079AD84EE92A84B40A1BE654E97474B4079AD84EE92A84B40A1BE654E97474B40374F75C8CDA64B407923F3C81F444B40374F75C8CDA64B40
66690	21362	54.521628999999997	54.548363000000002	55.652805999999998	55.640827999999999	Пушкина	0103000020E6100000010000000500000095D233BDC4424B40382EE3A606D24B4095D233BDC4424B40F850A2258FD34B4011AB3FC230464B40F850A2258FD34B4011AB3FC230464B40382EE3A606D24B4095D233BDC4424B40382EE3A606D24B40
66651	7173	54.304138000000002	54.328977000000002	55.280045999999999	55.273724000000001	Чишминская	0103000020E6100000010000000500000045BC75FEED264B40AE10566309A34B4045BC75FEED264B4014B01D8CD8A34B406F1118EB1B2A4B4014B01D8CD8A34B406F1118EB1B2A4B40AE10566309A34B4045BC75FEED264B40AE10566309A34B40
64444	21228	54.372590000000002	54.402782000000002	55.709028000000004	55.684888999999998	Советская	0103000020E6100000010000000500000088687407B12F4B40F0315871AAD74B4088687407B12F4B4062F9F36DC1DA4B4070B54E5C8E334B4062F9F36DC1DA4B4070B54E5C8E334B40F0315871AAD74B4088687407B12F4B40F0315871AAD74B40
64922	21269	54.402746	54.424619999999997	55.713968000000001	55.702098999999997	Свердлова	0103000020E61000000100000005000000234C512E8D334B40F3C64961DED94B40234C512E8D334B40FD31AD4D63DB4B401F9DBAF259364B40FD31AD4D63DB4B401F9DBAF259364B40F3C64961DED94B40234C512E8D334B40F3C64961DED94B40
66582	21076	54.116219999999998	54.144632999999999	55.565677000000001	55.548242999999999	Школьная	0103000020E610000001000000050000001092054CE00E4B4066A19DD32CC64B401092054CE00E4B40B98C9B1A68C84B4010768A5583124B40B98C9B1A68C84B4010768A5583124B4066A19DD32CC64B401092054CE00E4B4066A19DD32CC64B40
66928	27752	54.568629000000001	54.588805000000001	55.412681999999997	55.400649999999999	Дружбы	0103000020E610000001000000050000005247C7D5C8484B403A92CB7F48B34B405247C7D5C8484B40EDD286C3D2B44B40535C55F65D4B4B40EDD286C3D2B44B40535C55F65D4B4B403A92CB7F48B34B405247C7D5C8484B403A92CB7F48B34B40
66505	58808	56.417856	56.437727000000002	54.764386000000002	54.756833	Центральная	0103000020E61000000100000005000000FC372F4E7C354C404CC45BE7DF604B40FC372F4E7C354C4098C28366D7614B40C1C9367007384C4098C28366D7614B40C1C9367007384C404CC45BE7DF604B40FC372F4E7C354C404CC45BE7DF604B40
63605	20949	56.550033999999997	56.602406000000002	54.893720999999999	54.875424000000002	Площадь Октября	0103000020E6100000010000000500000012D89C8367464C401711C5E40D704B4012D89C8367464C40CC5F217365724B400475CAA31B4D4C40CC5F217365724B400475CAA31B4D4C401711C5E40D704B4012D89C8367464C401711C5E40D704B40
65145	19369	56.324458	56.339433	54.567622999999998	54.55724	Центральная	0103000020E610000001000000050000007976F9D687294C40F302ECA353474B407976F9D687294C408CBAD6DEA7484B407217618A722B4C408CBAD6DEA7484B407217618A722B4C40F302ECA353474B407976F9D687294C40F302ECA353474B40
65149	19223	56.841887999999997	56.893073999999999	54.889417999999999	54.856988999999999	Ленина	0103000020E610000001000000050000008A7269FCC26B4C401004C8D0B16D4B408A7269FCC26B4C40A33CF372D8714B403674B33F50724C40A33CF372D8714B403674B33F50724C401004C8D0B16D4B408A7269FCC26B4C401004C8D0B16D4B40
64059	19223	56.841887999999997	56.893073999999999	54.889417999999999	54.856988999999999	Калинина	0103000020E610000001000000050000008A7269FCC26B4C401004C8D0B16D4B408A7269FCC26B4C40A33CF372D8714B403674B33F50724C40A33CF372D8714B403674B33F50724C401004C8D0B16D4B408A7269FCC26B4C401004C8D0B16D4B40
64374	19059	56.961461999999997	56.997394999999997	54.924396999999999	54.901321000000003	Ленина	0103000020E61000000100000005000000622CD32F117B4C4059198D7C5E734B40622CD32F117B4C40A0C211A452764B40D218ADA3AA7F4C40A0C211A452764B40D218ADA3AA7F4C4059198D7C5E734B40622CD32F117B4C4059198D7C5E734B40
64025	19059	56.961461999999997	56.997394999999997	54.924396999999999	54.901321000000003	Коммунистическая	0103000020E61000000100000005000000622CD32F117B4C4059198D7C5E734B40622CD32F117B4C40A0C211A452764B40D218ADA3AA7F4C40A0C211A452764B40D218ADA3AA7F4C4059198D7C5E734B40622CD32F117B4C4059198D7C5E734B40
65157	6589	56.991466000000003	57.007123999999997	54.80921	54.797248000000003	Пчеловодов	0103000020E61000000100000005000000488C9E5BE87E4C409566F3380C664B40488C9E5BE87E4C404FCC7A3194674B4023827170E9804C404FCC7A3194674B4023827170E9804C409566F3380C664B40488C9E5BE87E4C409566F3380C664B40
65846	20734	56.477702000000001	56.496737000000003	54.961227000000001	54.945681	Центральная	0103000020E61000000100000005000000ED9DD156253D4C406BB933130C794B40ED9DD156253D4C401F84807C097B4B4049DBF813953F4C401F84807C097B4B4049DBF813953F4C406BB933130C794B40ED9DD156253D4C406BB933130C794B40
64361	20664	56.294373999999998	56.317585999999999	54.661223999999997	54.644613999999997	Центральная	0103000020E610000001000000050000007765170CAE254C40994528B682524B407765170CAE254C4047AAEFFCA2544B406FD575A8A6284C4047AAEFFCA2544B406FD575A8A6284C40994528B682524B407765170CAE254C40994528B682524B40
65164	20439	56.85962	56.890424000000003	54.828201	54.820414999999997	Главная	0103000020E61000000100000005000000677E3507086E4C40EC12D55B03694B40677E3507086E4C40DBC1887D026A4B4069C9E369F9714C40DBC1887D026A4B4069C9E369F9714C40EC12D55B03694B40677E3507086E4C40EC12D55B03694B40
65784	48075	57.002974000000002	57.012279999999997	54.795779000000003	54.789306000000003	Центральная	0103000020E61000000100000005000000815EB87361804C40AF44A0FA07654B40815EB87361804C40FBEB1516DC654B408B321B6492814C40FBEB1516DC654B408B321B6492814C40AF44A0FA07654B40815EB87361804C40AF44A0FA07654B40
66628	7459	57.067428	57.089525999999999	54.722242999999999	54.712529000000004	Родниковая	0103000020E61000000100000005000000D76A0F7BA1884C40CE397826345B4B40D76A0F7BA1884C40E9616875725C4B4023128596758B4C40E9616875725C4B4023128596758B4C40CE397826345B4B40D76A0F7BA1884C40CE397826345B4B40
63750	20562	56.627667000000002	56.660041999999997	54.899254999999997	54.869249000000003	Крупской	0103000020E61000000100000005000000A4E36A6457504C40558A1D8D436F4B40A4E36A6457504C40DAE1AFC91A734B4043FE99417C544C40DAE1AFC91A734B4043FE99417C544C40558A1D8D436F4B40A4E36A6457504C40558A1D8D436F4B40
66780	7474	56.494571999999998	56.515431	54.857295000000001	54.844534000000003	Школьная	0103000020E6100000010000000500000037C2A2224E3F4C40172EABB0196C4B4037C2A2224E3F4C401D03B2D7BB6D4B401B2C9CA4F9414C401D03B2D7BB6D4B401B2C9CA4F9414C40172EABB0196C4B4037C2A2224E3F4C40172EABB0196C4B40
66520	58817	56.485832000000002	56.510148999999998	54.903024000000002	54.885497999999998	Центральная	0103000020E61000000100000005000000D6AC33BE2F3E4C4032569BFF57714B40D6AC33BE2F3E4C4066C0594A96734B40268BFB8F4C414C4066C0594A96734B40268BFB8F4C414C4032569BFF57714B40D6AC33BE2F3E4C4032569BFF57714B40
64915	20306	57.048788000000002	57.070222000000001	54.897199999999998	54.888133000000003	Центральная	0103000020E61000000100000005000000F83768AF3E864C40CBBF9657AE714B40F83768AF3E864C4050FC1873D7724B40D8BAD408FD884C4050FC1873D7724B40D8BAD408FD884C40CBBF9657AE714B40F83768AF3E864C40CBBF9657AE714B40
64917	19472	56.781520999999998	56.812863	54.857838999999998	54.728644000000003	Центральная	0103000020E61000000100000005000000901150E108644C409C36E334445D4B40901150E108644C40DE1D19ABCD6D4B40719010E50B684C40DE1D19ABCD6D4B40719010E50B684C409C36E334445D4B40901150E108644C409C36E334445D4B40
65558	19472	56.781520999999998	56.812863	54.857838999999998	54.728644000000003	Романовская	0103000020E61000000100000005000000901150E108644C409C36E334445D4B40901150E108644C40DE1D19ABCD6D4B40719010E50B684C40DE1D19ABCD6D4B40719010E50B684C409C36E334445D4B40901150E108644C409C36E334445D4B40
66915	7371	56.514757000000003	56.530577000000001	54.704217	54.694336999999997	Горького	0103000020E610000001000000050000008C31B08EE3414C408DB3E908E0584B408C31B08EE3414C40C4245CC8235A4B40418177F2E9434C40C4245CC8235A4B40418177F2E9434C408DB3E908E0584B408C31B08EE3414C408DB3E908E0584B40
66024	20627	56.639955	56.663077999999999	54.945582999999999	54.930677000000003	Школьная	0103000020E61000000100000005000000B2F4A10BEA514C40D811876C20774B40B2F4A10BEA514C40A8531EDD08794B403A596ABDDF544C40A8531EDD08794B403A596ABDDF544C40D811876C20774B40B2F4A10BEA514C40D811876C20774B40
63399	58105	56.687908	56.705945999999997	54.721676000000002	54.710895999999998	Ленина	0103000020E6100000010000000500000011548D5E0D584C40B96DDFA3FE5A4B4011548D5E0D584C40702711E15F5C4B40FA5E43705C5A4C40702711E15F5C4B40FA5E43705C5A4C40B96DDFA3FE5A4B4011548D5E0D584C40B96DDFA3FE5A4B40
64240	46731	56.606332000000002	56.613599000000001	54.730406000000002	54.721895000000004	Садовая	0103000020E61000000100000005000000574277499C4D4C40AE122C0E675C4B40574277499C4D4C40AE669DF17D5D4B40DDED7A698A4E4C40AE669DF17D5D4B40DDED7A698A4E4C40AE122C0E675C4B40574277499C4D4C40AE122C0E675C4B40
65646	46731	56.606332000000002	56.613599000000001	54.730406000000002	54.721895000000004	Бабича	0103000020E61000000100000005000000574277499C4D4C40AE122C0E675C4B40574277499C4D4C40AE669DF17D5D4B40DDED7A698A4E4C40AE669DF17D5D4B40DDED7A698A4E4C40AE122C0E675C4B40574277499C4D4C40AE122C0E675C4B40
65471	28550	57.124965000000003	57.136642999999999	55.083790999999998	55.075695000000003	Конторная	0103000020E61000000100000005000000841266DAFE8F4C4041BCAE5FB0894B40841266DAFE8F4C407D59DAA9B98A4B40191D90847D914C407D59DAA9B98A4B40191D90847D914C4041BCAE5FB0894B40841266DAFE8F4C4041BCAE5FB0894B40
64089	20511	56.350383999999998	56.384897000000002	54.511837999999997	54.484147	Анискина	0103000020E6100000010000000500000055850662D92C4C406FBA6587F83D4B4055850662D92C4C40CE6C57E883414B400DAA0D4E44314C40CE6C57E883414B400DAA0D4E44314C406FBA6587F83D4B4055850662D92C4C406FBA6587F83D4B40
64920	21036	56.541401	56.563068999999999	54.847695999999999	54.836264	Хисматуллина	0103000020E61000000100000005000000C782C2A04C454C403C69E1B20A6B4B40C782C2A04C454C409A79724D816C4B401A321EA512484C409A79724D816C4B401A321EA512484C403C69E1B20A6B4B40C782C2A04C454C403C69E1B20A6B4B40
65841	20055	56.977812	57.007689999999997	54.766993999999997	54.741925000000002	Центральная	0103000020E6100000010000000500000074D190F1287D4C40DB8AFD65F75E4B4074D190F1287D4C40361D01DC2C624B40CC4065FCFB804C40361D01DC2C624B40CC4065FCFB804C40DB8AFD65F75E4B4074D190F1287D4C40DB8AFD65F75E4B40
64918	20769	56.459322	56.478968000000002	54.924480000000003	54.907051000000003	Центральная	0103000020E61000000100000005000000AA2A3410CB3A4C40ED66463F1A744B40AA2A3410CB3A4C402EE7525C55764B404FEACBD24E3D4C402EE7525C55764B404FEACBD24E3D4C40ED66463F1A744B40AA2A3410CB3A4C40ED66463F1A744B40
65857	20243	57.046712999999997	57.071353000000002	54.869092999999999	54.854641000000001	Центральная	0103000020E6100000010000000500000026A60BB1FA854C400E6954E0646D4B4026A60BB1FA854C405D177E703E6F4B405ABC581822894C405D177E703E6F4B405ABC581822894C400E6954E0646D4B4026A60BB1FA854C400E6954E0646D4B40
65916	46439	56.489299000000003	56.556134	54.770156999999998	54.642868	Новостройка	0103000020E61000000100000005000000967B8159A13E4C408DD2A57F49524B40967B8159A13E4C408AE42B8194624B40CA181F662F474C408AE42B8194624B40CA181F662F474C408DD2A57F49524B40967B8159A13E4C408DD2A57F49524B40
64436	18973	56.732239	56.796855000000001	54.889308999999997	54.866404000000003	Чапаева	0103000020E6100000010000000500000089EDEE01BA5D4C40D28F8653E66E4B4089EDEE01BA5D4C40EC8497E0D4714B40B9533A58FF654C40EC8497E0D4714B40B9533A58FF654C40D28F8653E66E4B4089EDEE01BA5D4C40D28F8653E66E4B40
64496	18973	56.732239	56.796855000000001	54.889308999999997	54.866404000000003	Пушкина	0103000020E6100000010000000500000089EDEE01BA5D4C40D28F8653E66E4B4089EDEE01BA5D4C40EC8497E0D4714B40B9533A58FF654C40EC8497E0D4714B40B9533A58FF654C40D28F8653E66E4B4089EDEE01BA5D4C40D28F8653E66E4B40
65838	19637	57.001536000000002	57.062415000000001	54.983643999999998	54.96407	Молодежная	0103000020E6100000010000000500000022E2E65432804C40018750A5667B4B4022E2E65432804C400C74ED0BE87D4B40D2E3F736FD874C400C74ED0BE87D4B40D2E3F736FD874C40018750A5667B4B4022E2E65432804C40018750A5667B4B40
65184	20880	56.385120999999998	56.400680000000001	54.920304000000002	54.903773999999999	Школьная	0103000020E610000001000000050000005C001AA54B314C40D07CCEDDAE734B405C001AA54B314C4062307F85CC754B40A514747B49334C4062307F85CC754B40A514747B49334C40D07CCEDDAE734B405C001AA54B314C40D07CCEDDAE734B40
64027	19954	56.609008000000003	56.636290000000002	54.685119999999998	54.670014000000002	Парковая	0103000020E610000001000000050000004E8061F9F34D4C405BEECC04C3554B404E8061F9F34D4C40F2EA1C03B2574B40CC6262F371514C40F2EA1C03B2574B40CC6262F371514C405BEECC04C3554B404E8061F9F34D4C405BEECC04C3554B40
64294	19786	56.406455999999999	56.421044999999999	54.723699000000003	54.710895999999998	Школьная	0103000020E61000000100000005000000A9A10DC006344C40B96DDFA3FE5A4B40A9A10DC006344C40EF92382BA25C4B40799274CDE4354C40EF92382BA25C4B40799274CDE4354C40B96DDFA3FE5A4B40A9A10DC006344C40B96DDFA3FE5A4B40
65151	19712	57.104348999999999	57.137371000000002	54.992317	54.975656000000001	Советская	0103000020E61000000100000005000000662FDB4E5B8D4C40B612BA4BE27C4B40662FDB4E5B8D4C40E621533E047F4B409C35785F95914C40E621533E047F4B409C35785F95914C40B612BA4BE27C4B40662FDB4E5B8D4C40B612BA4BE27C4B40
63522	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Якутова	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
63601	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Целинная	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
64000	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Свердлова	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
64309	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Революционная	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
63311	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Октябрьская	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
63277	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Ленина	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
63594	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Гражданская	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
63519	18563	56.375689000000001	56.450626999999997	54.850628999999998	54.804597000000001	Горького	0103000020E61000000100000005000000C53BC09316304C40D8BAD408FD664B40C53BC09316304C40BC033C69E16C4B40E8D84125AE394C40BC033C69E16C4B40E8D84125AE394C40D8BAD408FD664B40C53BC09316304C40D8BAD408FD664B40
65147	19614	56.403796999999997	56.440503	54.611579999999996	54.600248999999998	Центральная	0103000020E61000000100000005000000889CBE9EAF334C40753A90F5D44C4B40889CBE9EAF334C409F71E140484E4B401B65FD6662384C409F71E140484E4B401B65FD6662384C40753A90F5D44C4B40889CBE9EAF334C40753A90F5D44C4B40
64028	19553	56.517892000000003	56.553007999999998	54.779494	54.764578999999998	Центральная	0103000020E61000000100000005000000166EF9484A424C40AC1A84B9DD614B40166EF9484A424C40D0B69A75C6634B40933655F7C8464C40D0B69A75C6634B40933655F7C8464C40AC1A84B9DD614B40166EF9484A424C40AC1A84B9DD614B40
65835	19437	56.745328000000001	56.762431999999997	54.816068000000001	54.804943999999999	Школьная	0103000020E6100000010000000500000084656CE8665F4C40438EAD6708674B4084656CE8665F4C40F4A78DEA74684B4041B62C5F97614C40F4A78DEA74684B4041B62C5F97614C40438EAD6708674B4084656CE8665F4C40438EAD6708674B40
64371	19842	56.357804000000002	56.379579	54.783906999999999	54.769913000000003	Интернациональная	0103000020E6100000010000000500000062307F85CC2D4C40F4E159828C624B4062307F85CC2D4C40800D881057644B40CB9F6F0B96304C40800D881057644B40CB9F6F0B96304C40F4E159828C624B4062307F85CC2D4C40F4E159828C624B40
64357	18424	57.992162999999998	58.022993	52.310124000000002	52.295591999999999	Центральная	0103000020E610000001000000050000008FA67A32FFFE4C40C87A6AF5D5254A408FA67A32FFFE4C4034DAAA24B2274A40BA84436FF1024D4034DAAA24B2274A40BA84436FF1024D40C87A6AF5D5254A408FA67A32FFFE4C40C87A6AF5D5254A40
64890	18387	57.749887000000001	57.776817999999999	52.216918999999997	52.208824	Ш. Бабича	0103000020E610000001000000050000000859164CFCDF4C40594FADBEBA1A4A400859164CFCDF4C40C5707500C41B4A40D978B0C56EE34C40C5707500C41B4A40D978B0C56EE34C40594FADBEBA1A4A400859164CFCDF4C40594FADBEBA1A4A40
65827	18245	57.050458999999996	57.074893000000003	52.456252999999997	52.437716999999999	Акман	0103000020E61000000100000005000000F964C57075864C409DF3531C07384A40F964C57075864C40D7D9907F663A4A4084D9041896894C40D7D9907F663A4A4084D9041896894C409DF3531C07384A40F964C57075864C409DF3531C07384A40
65154	18131	58.134033000000002	58.147238999999999	52.308577	52.300300999999997	С. Юлаева	0103000020E61000000100000005000000DACA4BFE27114D4061FA5E4370264A40DACA4BFE27114D401EA67D737F274A400ED940BAD8124D401EA67D737F274A400ED940BAD8124D4061FA5E4370264A40DACA4BFE27114D4061FA5E4370264A40
64957	58413	57.841039000000002	57.849500999999997	52.235047000000002	52.229101	Дильмухаметова	0103000020E610000001000000050000008DD47B2AA7EB4C408E3D7B2E531D4A408DD47B2AA7EB4C40EF022505161E4A40AB75E272BCEC4C40EF022505161E4A40AB75E272BCEC4C408E3D7B2E531D4A408DD47B2AA7EB4C408E3D7B2E531D4A40
64950	58410	57.966200999999998	57.992215999999999	52.173932000000001	52.166894999999997	Молодёжная	0103000020E61000000100000005000000662E7079ACFB4C40D66EBBD05C154A40662E7079ACFB4C402BDD5D6743164A40B24813EF00FF4C402BDD5D6743164A40B24813EF00FF4C40D66EBBD05C154A40662E7079ACFB4C40D66EBBD05C154A40
66015	17978	57.691586000000001	57.706229	52.201627000000002	52.194257999999998	Муртаева	0103000020E610000001000000050000008C2FDAE385D84C40417E3672DD184A408C2FDAE385D84C40CC7EDDE9CE194A404F3E3DB665DA4C40CC7EDDE9CE194A404F3E3DB665DA4C40417E3672DD184A408C2FDAE385D84C40417E3672DD184A40
65830	17890	57.749420000000001	57.770305999999998	52.070447999999999	52.057502999999997	Школьная	0103000020E61000000100000005000000F27B9BFEECDF4C40003620425C074A40F27B9BFEECDF4C40C808A87004094A40CFF4126399E24C40C808A87004094A40CFF4126399E24C40003620425C074A40F27B9BFEECDF4C40003620425C074A40
66245	58734	57.434218999999999	57.460026999999997	52.361812	52.344017000000001	Павлова	0103000020E61000000100000005000000A226FA7C94B74C404F22C2BF082C4A40A226FA7C94B74C4072A609DB4F2E4A4074232C2AE2BA4C4072A609DB4F2E4A4074232C2AE2BA4C404F22C2BF082C4A40A226FA7C94B74C404F22C2BF082C4A40
66953	58893	57.601385999999998	57.618642999999999	52.173772	52.165503000000001	Центральная	0103000020E61000000100000005000000D9226937FACC4C40E831CA332F154A40D9226937FACC4C40F27A30293E164A401D739EB12FCF4C40F27A30293E164A401D739EB12FCF4C40E831CA332F154A40D9226937FACC4C40E831CA332F154A40
66950	58892	57.160052999999998	57.180354999999999	52.477781999999998	52.467002999999998	Школьная	0103000020E610000001000000050000003750E09D7C944C4023111AC1C63B4A403750E09D7C944C40094FE8F5273D4A40C55565DF15974C40094FE8F5273D4A40C55565DF15974C4023111AC1C63B4A403750E09D7C944C4023111AC1C63B4A40
64168	16742	58.018303000000003	58.032290000000003	52.258789	52.240380000000002	Салавата Юлаева	0103000020E610000001000000050000009835B1C057024D40664E97C5C41E4A409835B1C057024D4043C879FF1F214A4072FE261422044D4043C879FF1F214A4072FE261422044D40664E97C5C41E4A409835B1C057024D40664E97C5C41E4A40
66519	58816	57.835613000000002	57.850875000000002	52.337321000000003	52.325983999999998	Шахизады Бабича	0103000020E61000000100000005000000658EE55DF5EA4C407782FDD7B9294A40658EE55DF5EA4C4084A0A3552D2B4A40F4FDD478E9EC4C4084A0A3552D2B4A40F4FDD478E9EC4C407782FDD7B9294A40658EE55DF5EA4C407782FDD7B9294A40
64939	58406	57.772748999999997	57.782127000000003	52.273885	52.268143000000002	Салавата Юлаева	0103000020E6100000010000000500000023827170E9E24C405FD3838252224A4023827170E9E24C40B7EEE6A90E234A40C828CFBC1CE44C40B7EEE6A90E234A40C828CFBC1CE44C405FD3838252224A4023827170E9E24C405FD3838252224A40
64883	46775	57.757584999999999	57.774923000000001	52.344898000000001	52.335582000000002	Школьная	0103000020E610000001000000050000005778978BF8E04C402A90D959F42A4A405778978BF8E04C40583A1F9E252C4A4088F546AD30E34C40583A1F9E252C4A4088F546AD30E34C402A90D959F42A4A405778978BF8E04C402A90D959F42A4A40
65819	7168	57.094144	57.116179000000002	52.404825000000002	52.393642999999997	Центральня	0103000020E61000000100000005000000AC8E1CE90C8C4C4050A6D1E462324A40AC8E1CE90C8C4C4036CD3B4ED1334A40B2BD16F4DE8E4C4036CD3B4ED1334A40B2BD16F4DE8E4C4050A6D1E462324A40AC8E1CE90C8C4C4050A6D1E462324A40
64046	32595	57.458545000000001	57.505859999999998	52.792482999999997	52.771453000000001	Ленина	0103000020E61000000100000005000000465F419AB1BA4C4057B3CEF8BE624A40465F419AB1BA4C4067D13B1570654A40622D3E05C0C04C4067D13B1570654A40622D3E05C0C04C4057B3CEF8BE624A40465F419AB1BA4C4057B3CEF8BE624A40
65557	17541	57.621859000000001	57.637875999999999	51.99438	51.987924999999997	Акмуллы	0103000020E6100000010000000500000094DC611399CF4C404DF38E5374FE494094DC611399CF4C40F3E505D847FF49409F73B7EBA5D14C40F3E505D847FF49409F73B7EBA5D14C404DF38E5374FE494094DC611399CF4C404DF38E5374FE4940
64497	6000	57.426206000000001	57.463639000000001	52.248392000000003	52.214773000000001	Шестакова	0103000020E61000000100000005000000F3AD0FEB8DB64C402B8881AE7D1B4A40F3AD0FEB8DB64C40454B1E4FCB1F4A403813D38558BB4C40454B1E4FCB1F4A403813D38558BB4C402B8881AE7D1B4A40F3AD0FEB8DB64C402B8881AE7D1B4A40
63526	6000	57.426206000000001	57.463639000000001	52.248392000000003	52.214773000000001	Ленина	0103000020E61000000100000005000000F3AD0FEB8DB64C402B8881AE7D1B4A40F3AD0FEB8DB64C40454B1E4FCB1F4A403813D38558BB4C40454B1E4FCB1F4A403813D38558BB4C402B8881AE7D1B4A40F3AD0FEB8DB64C402B8881AE7D1B4A40
64634	17332	57.856670000000001	57.869551000000001	52.144207999999999	52.133988000000002	Сакмара	0103000020E610000001000000050000006FBBD05CA7ED4C403A07CF8426114A406FBBD05CA7ED4C4029E9616875124A40209A79724DEF4C4029E9616875124A40209A79724DEF4C403A07CF8426114A406FBBD05CA7ED4C403A07CF8426114A40
66286	58739	57.583123999999998	57.598018000000003	52.105741999999999	52.094506000000003	Клубная	0103000020E61000000100000005000000A0C1A6CEA3CA4C404DA3C9C5180C4A40A0C1A6CEA3CA4C4025E82FF4880D4A40AD3594DA8BCC4C4025E82FF4880D4A40AD3594DA8BCC4C404DA3C9C5180C4A40A0C1A6CEA3CA4C404DA3C9C5180C4A40
64914	46067	57.195995000000003	57.217877999999999	52.187041999999998	52.170856000000001	Школьная	0103000020E61000000100000005000000FB96395D16994C40A629029CDE154A40FB96395D16994C403D7D04FEF0174A404A42226DE39B4C403D7D04FEF0174A404A42226DE39B4C40A629029CDE154A40FB96395D16994C40A629029CDE154A40
64908	17136	58.02814	58.036324	52.235619999999997	52.228963	Ш.Бабича	0103000020E61000000100000005000000CFDA6D179A034D403D7FDAA84E1D4A40CFDA6D179A034D404A24D1CB281E4A40AB07CC43A6044D404A24D1CB281E4A40AB07CC43A6044D403D7FDAA84E1D4A40CFDA6D179A034D403D7FDAA84E1D4A40
66012	17079	57.869002999999999	57.884436999999998	52.078955999999998	52.073	Молодежная	0103000020E610000001000000050000001D90847D3BEF4C40D34D621058094A401D90847D3BEF4C4057E9EE3A1B0A4A40A92F4B3B35F14C4057E9EE3A1B0A4A40A92F4B3B35F14C40D34D621058094A401D90847D3BEF4C40D34D621058094A40
65529	17046	57.674284999999998	57.684489999999997	52.018312999999999	52.008429999999997	Школьная	0103000020E6100000010000000500000078978BF84ED64C401327F73B14014A4078978BF84ED64C40BB0B941458024A4032384A5E9DD74C40BB0B941458024A4032384A5E9DD74C401327F73B14014A4078978BF84ED64C401327F73B14014A40
65316	58520	57.483294000000001	57.501682000000002	52.132302000000003	52.114144000000003	Школьная	0103000020E61000000100000005000000302DEA93DCBD4C406F8445459C0E4A40302DEA93DCBD4C4003999D45EF104A40F67EA31D37C04C4003999D45EF104A40F67EA31D37C04C406F8445459C0E4A40302DEA93DCBD4C406F8445459C0E4A40
66965	58899	56.865594000000002	56.883192000000001	51.686684999999997	51.677320000000002	Речная	0103000020E6100000010000000500000092CEC0C8CB6E4C409F76F86BB2D6494092CEC0C8CB6E4C40AED3484BE5D749405F0B7A6F0C714C40AED3484BE5D749405F0B7A6F0C714C409F76F86BB2D6494092CEC0C8CB6E4C409F76F86BB2D64940
65824	16712	57.256065	57.279483999999997	51.698186	51.680202000000001	Школьная	0103000020E610000001000000050000003B53E8BCC6A04C403F56F0DB10D749403B53E8BCC6A04C403543AA285ED94940ACE0B721C6A34C403543AA285ED94940ACE0B721C6A34C403F56F0DB10D749403B53E8BCC6A04C403F56F0DB10D74940
64903	16549	57.062199999999997	57.077731	51.737724	51.723694999999999	Центральная	0103000020E61000000100000005000000D5E76A2BF6874C40ADA3AA09A2DC4940D5E76A2BF6874C40B6BC72BD6DDE49405471E316F3894C40B6BC72BD6DDE49405471E316F3894C40ADA3AA09A2DC4940D5E76A2BF6874C40ADA3AA09A2DC4940
63593	13996	56.627513999999998	56.654221	51.861179999999997	51.854894999999999	Советская	0103000020E610000001000000050000001DE4F56052504C40C84109336DED49401DE4F56052504C4011FC6F253BEE49409FAD8383BD534C4011FC6F253BEE49409FAD8383BD534C40C84109336DED49401DE4F56052504C40C84109336DED4940
65546	16247	56.955191999999997	56.966259999999998	52.157983999999999	52.154023000000002	Центральная	0103000020E610000001000000050000004EB340BB437A4C4079EA9106B7134A404EB340BB437A4C4048A5D8D138144A406BB75D68AE7B4C4048A5D8D138144A406BB75D68AE7B4C4079EA9106B7134A404EB340BB437A4C4079EA9106B7134A40
65141	16492	57.024003	57.056891	51.708354999999997	51.696449999999999	С.Абдуллина	0103000020E61000000100000005000000C100C28712834C404CA60A4625D94940C100C28712834C40A27A6B60ABDA4940E7374C3448874C40A27A6B60ABDA4940E7374C3448874C404CA60A4625D94940C100C28712834C404CA60A4625D94940
66009	15457	56.799415000000003	56.815693000000003	52.068415999999999	52.058903999999998	Гафарова	0103000020E610000001000000050000004777103B53664C4042CD902A8A074A404777103B53664C40F64201DBC1084A40BF49D3A068684C40F64201DBC1084A40BF49D3A068684C4042CD902A8A074A404777103B53664C4042CD902A8A074A40
64696	14695	56.746972	56.764282000000001	52.242348	52.231158000000001	Дружбы	0103000020E610000001000000050000008C834BC79C5F4C40B91AD995961D4A408C834BC79C5F4C4021205F42051F4A40F37519FED3614C4021205F42051F4A40F37519FED3614C40B91AD995961D4A408C834BC79C5F4C40B91AD995961D4A40
64368	16339	56.663221999999998	56.699756000000001	52.155332000000001	52.142733	Советская	0103000020E610000001000000050000006DFE5F75E4544C40AD872F1345124A406DFE5F75E4544C40DA0242EBE1134A400397C79A91594C40DA0242EBE1134A400397C79A91594C40AD872F1345124A406DFE5F75E4544C40AD872F1345124A40
65522	14511	56.890557999999999	56.909934999999997	52.257962999999997	52.243402000000003	Школьная	0103000020E610000001000000050000007898F6CDFD714C40F8E3F6CB271F4A407898F6CDFD714C40FD497CEE04214A402D3E05C078744C40FD497CEE04214A402D3E05C078744C40F8E3F6CB271F4A407898F6CDFD714C40F8E3F6CB271F4A40
65228	14177	57.102201999999998	57.114660999999998	51.820008000000001	51.808855999999999	Салавата Юлаева	0103000020E61000000100000005000000FBCA83F4148D4C403196E99788E74940FBCA83F4148D4C40AC3AAB05F6E8494036902E36AD8E4C40AC3AAB05F6E8494036902E36AD8E4C403196E99788E74940FBCA83F4148D4C403196E99788E74940
66250	15643	56.552891000000002	56.574801000000001	52.237402000000003	52.209001000000001	Стеклянка	0103000020E610000001000000050000005AA0DD21C5464C4068EA758BC01A4A405AA0DD21C5464C40A4005130631E4A40A35A441493494C40A4005130631E4A40A35A441493494C4068EA758BC01A4A405AA0DD21C5464C4068EA758BC01A4A40
64815	15071	56.563338000000002	56.580891000000001	52.177726	52.169457999999999	Мира	0103000020E610000001000000050000000A4CA7751B484C40D505BCCCB0154A400A4CA7751B484C400FD3BEB9BF164A4037C5E3A25A4A4C400FD3BEB9BF164A4037C5E3A25A4A4C40D505BCCCB0154A400A4CA7751B484C40D505BCCCB0154A40
64774	15882	56.414648999999997	56.425069000000001	52.271895999999998	52.261116000000001	Центральная	0103000020E61000000100000005000000D828EB3713354C402E3BC43F6C214A40D828EB3713354C40E4F4F57CCD224A408FC536A968364C40E4F4F57CCD224A408FC536A968364C402E3BC43F6C214A40D828EB3713354C402E3BC43F6C214A40
66300	15882	56.414648999999997	56.425069000000001	52.271895999999998	52.261116000000001	Лесная	0103000020E61000000100000005000000D828EB3713354C402E3BC43F6C214A40D828EB3713354C40E4F4F57CCD224A408FC536A968364C40E4F4F57CCD224A408FC536A968364C402E3BC43F6C214A40D828EB3713354C402E3BC43F6C214A40
65998	14748	56.777684999999998	56.788429000000001	52.266032000000003	52.250287999999998	Центральная	0103000020E610000001000000050000007DCB9C2E8B634C40664AEB6F09204A407DCB9C2E8B634C4041D829560D224A40E71BD13DEB644C4041D829560D224A40E71BD13DEB644C40664AEB6F09204A407DCB9C2E8B634C40664AEB6F09204A40
65543	15358	56.749029	56.779885999999998	52.004344000000003	51.992933000000001	Хутор	0103000020E61000000100000005000000B760A92EE05F4C40410FB56D18FF4940B760A92EE05F4C4088F71C588E004A40DB4DF04DD3634C4088F71C588E004A40DB4DF04DD3634C40410FB56D18FF4940B760A92EE05F4C40410FB56D18FF4940
65142	13847	56.940441999999997	56.947682	51.976199000000001	51.968459000000003	Советская	0103000020E6100000010000000500000075E4486760784C402942EA76F6FB494075E4486760784C40A7B1BD16F4FC49400281CEA44D794C40A7B1BD16F4FC49400281CEA44D794C402942EA76F6FB494075E4486760784C402942EA76F6FB4940
66888	660	56.757185999999997	56.765369	52.127127000000002	52.123722000000001	Центральная	0103000020E61000000100000005000000997E8978EB604C40DAE55B1FD60F4A40997E8978EB604C4024B891B245104A40A52F849CF7614C4024B891B245104A40A52F849CF7614C40DAE55B1FD60F4A40997E8978EB604C40DAE55B1FD60F4A40
65957	14044	56.867544000000002	56.883730999999997	51.784275999999998	51.772635000000001	Школьная	0103000020E61000000100000005000000A7EB89AE0B6F4C405B5F24B4E5E24940A7EB89AE0B6F4C40D384ED2763E449400EBBEF181E714C40D384ED2763E449400EBBEF181E714C405B5F24B4E5E24940A7EB89AE0B6F4C405B5F24B4E5E24940
65278	15563	56.893585999999999	56.905946999999998	52.064928000000002	52.057170999999997	Большой Ускалык	0103000020E61000000100000005000000EC14AB0661724C40CAA31B6151074A40EC14AB0661724C401F4C8A8F4F084A4064744012F6734C401F4C8A8F4F084A4064744012F6734C40CAA31B6151074A40EC14AB0661724C40CAA31B6151074A40
66368	58756	56.958534	56.973697999999999	51.874003999999999	51.863433000000001	Центральная	0103000020E61000000100000005000000520DFB3DB17A4C40C2A4F8F884EE4940520DFB3DB17A4C405E49F25CDFEF49401E17D522A27C4C405E49F25CDFEF49401E17D522A27C4C40C2A4F8F884EE4940520DFB3DB17A4C40C2A4F8F884EE4940
66246	15787	56.401874999999997	56.415331999999999	52.219583999999998	52.215093000000003	Советская	0103000020E610000001000000050000003D0AD7A370334C409D4CDC2A881B4A403D0AD7A370334C40C85C19541B1C4A40BB7D569929354C40C85C19541B1C4A40BB7D569929354C409D4CDC2A881B4A403D0AD7A370334C409D4CDC2A881B4A40
65829	16846	57.169592999999999	57.185799000000003	51.605398000000001	51.591366000000001	Школьная	0103000020E61000000100000005000000B5503239B5954C40B1FB8EE1B1CB4940B5503239B5954C402B8881AE7DCD49409450FA42C8974C402B8881AE7DCD49409450FA42C8974C40B1FB8EE1B1CB4940B5503239B5954C40B1FB8EE1B1CB4940
64202	16091	56.817785999999998	56.845283000000002	52.154625000000003	52.142263	Комсомольская	0103000020E6100000010000000500000036902E36AD684C4026378AAC35124A4036902E36AD684C406F1283C0CA134A40B16EBC3B326C4C406F1283C0CA134A40B16EBC3B326C4C4026378AAC35124A4036902E36AD684C4026378AAC35124A40
66251	16171	56.795650999999999	56.80256	52.161724999999997	52.155095000000003	Центральная	0103000020E61000000100000005000000CD0358E4D7654C40F6622827DA134A40CD0358E4D7654C4009F9A067B3144A40F4893C49BA664C4009F9A067B3144A40F4893C49BA664C40F6622827DA134A40CD0358E4D7654C40F6622827DA134A40
66511	58811	57.089993	57.102884000000003	52.126745999999997	52.117024999999998	Центральная	0103000020E6100000010000000500000039EFFFE3848B4C403EE8D9ACFA0E4A4039EFFFE3848B4C400C73823639104A400EA48B4D2B8D4C400C73823639104A400EA48B4D2B8D4C403EE8D9ACFA0E4A4039EFFFE3848B4C403EE8D9ACFA0E4A40
64629	15260	57.144970000000001	57.174211	51.821266999999999	51.801271	Утарбарская	0103000020E61000000100000005000000587380608E924C40DA1D520C90E64940587380608E924C405B24ED461FE949403ECDC98B4C964C405B24ED461FE949403ECDC98B4C964C40DA1D520C90E64940587380608E924C40DA1D520C90E64940
64725	58329	56.199835	57.401107000000003	52.462915000000002	51.572012999999998	Сергея Чекмарева	0103000020E610000001000000050000004FCC7A3194194C4084F1D3B837C949404FCC7A3194194C40F7E978CC403B4A402D99637957B34C40F7E978CC403B4A402D99637957B34C4084F1D3B837C949404FCC7A3194194C4084F1D3B837C94940
63273	5239	56.554884999999999	56.605477999999998	52.205407999999998	52.179676000000001	Советская	0103000020E610000001000000050000003E05C07806474C4024F0879FFF164A403E05C07806474C401B2B31CF4A1A4A404739984D804D4C401B2B31CF4A1A4A404739984D804D4C4024F0879FFF164A403E05C07806474C4024F0879FFF164A40
66754	5239	56.554884999999999	56.605477999999998	52.205407999999998	52.179676000000001	Магистральная	0103000020E610000001000000050000003E05C07806474C4024F0879FFF164A403E05C07806474C401B2B31CF4A1A4A404739984D804D4C401B2B31CF4A1A4A404739984D804D4C4024F0879FFF164A403E05C07806474C4024F0879FFF164A40
64819	5239	56.554884999999999	56.605477999999998	52.205407999999998	52.179676000000001	Лесная	0103000020E610000001000000050000003E05C07806474C4024F0879FFF164A403E05C07806474C401B2B31CF4A1A4A404739984D804D4C401B2B31CF4A1A4A404739984D804D4C4024F0879FFF164A403E05C07806474C4024F0879FFF164A40
63301	5239	56.554884999999999	56.605477999999998	52.205407999999998	52.179676000000001	Комсомольская	0103000020E610000001000000050000003E05C07806474C4024F0879FFF164A403E05C07806474C401B2B31CF4A1A4A404739984D804D4C401B2B31CF4A1A4A404739984D804D4C4024F0879FFF164A403E05C07806474C4024F0879FFF164A40
64030	5239	56.554884999999999	56.605477999999998	52.205407999999998	52.179676000000001	40 лет Победы	0103000020E610000001000000050000003E05C07806474C4024F0879FFF164A403E05C07806474C401B2B31CF4A1A4A404739984D804D4C401B2B31CF4A1A4A404739984D804D4C4024F0879FFF164A403E05C07806474C4024F0879FFF164A40
64693	14416	57.096812	57.110106999999999	51.879686999999997	51.870863	Кунсбаева	0103000020E6100000010000000500000020EEEA55648C4C40F225547078EF494020EEEA55648C4C40B1DB679599F04940C40776FC178E4C40B1DB679599F04940C40776FC178E4C40F225547078EF494020EEEA55648C4C40F225547078EF4940
64904	16569	56.999218999999997	57.012549999999997	51.746462999999999	51.733696999999999	Школьная	0103000020E610000001000000050000005A457F68E67F4C402F1686C8E9DD49405A457F68E67F4C4047567E198CDF49404BC8073D9B814C4047567E198CDF49404BC8073D9B814C402F1686C8E9DD49405A457F68E67F4C402F1686C8E9DD4940
63542	15213	57.109361	57.149534000000003	51.786130999999997	51.750315999999998	Советская	0103000020E610000001000000050000009B3A8F8AFF8D4C4030D5CC5A0AE049409B3A8F8AFF8D4C4096AFCBF09FE44940EED11BEE23934C4096AFCBF09FE44940EED11BEE23934C4030D5CC5A0AE049409B3A8F8AFF8D4C4030D5CC5A0AE04940
65533	14539	56.946784000000001	56.973517999999999	52.260255999999998	52.253982000000001	Школьная	0103000020E610000001000000050000002330D63730794C40E7E26F7B82204A402330D63730794C403C4B901150214A409E08E23C9C7C4C403C4B901150214A409E08E23C9C7C4C40E7E26F7B82204A402330D63730794C40E7E26F7B82204A40
66243	15611	56.884369	56.896335000000001	52.111156999999999	52.108629999999998	Малый Ускалык	0103000020E61000000100000005000000514CDE0033714C40A7AE7C96E70D4A40514CDE0033714C4059DC7F643A0E4A404DA1F31ABB724C4059DC7F643A0E4A404DA1F31ABB724C40A7AE7C96E70D4A40514CDE0033714C40A7AE7C96E70D4A40
66003	14784	56.770569999999999	56.782688999999998	52.283825	52.274227000000003	Центральная	0103000020E61000000100000005000000ADA3AA09A2624C401157CEDE19234A40ADA3AA09A2624C40C364AA6054244A402FF834272F644C40C364AA6054244A402FF834272F644C401157CEDE19234A40ADA3AA09A2624C401157CEDE19234A40
65542	15298	56.740898999999999	56.768639	52.040505000000003	52.026215999999998	Центральная	0103000020E61000000100000005000000CE5147C7D55E4C40E350BF0B5B034A40CE5147C7D55E4C40892991442F054A400FB743C362624C40892991442F054A400FB743C362624C40E350BF0B5B034A40CE5147C7D55E4C40E350BF0B5B034A40
66579	58848	57.286284000000002	57.306244999999997	51.724314	51.714047999999998	Центральная	0103000020E610000001000000050000001DAF40F4A4A44C4019E3C3EC65DB49401DAF40F4A4A44C4079043752B6DC494021C8410933A74C4079043752B6DC494021C8410933A74C4019E3C3EC65DB49401DAF40F4A4A44C4019E3C3EC65DB4940
65519	14442	57.173842	57.204636000000001	51.948990000000002	51.938675000000003	Ялна Ер	0103000020E61000000100000005000000EB55647440964C4052499D8026F84940EB55647440964C40931D1B8178F94940C9CA2F83319A4C40931D1B8178F94940C9CA2F83319A4C4052499D8026F84940EB55647440964C4052499D8026F84940
65844	16400	56.624540000000003	56.635328999999999	52.104885000000003	52.098224000000002	Центральная	0103000020E610000001000000050000009D853DEDF04F4C4056D7A19A920C4A409D853DEDF04F4C40A56B26DF6C0D4A40A699EE7552514C40A56B26DF6C0D4A40A699EE7552514C4056D7A19A920C4A409D853DEDF04F4C4056D7A19A920C4A40
65140	16893	57.194324000000002	57.207321999999998	51.672142999999998	51.66263	Центральная	0103000020E61000000100000005000000F969DC9BDF984C409BAC510FD1D44940F969DC9BDF984C401F9E25C808D64940E3DEFC86899A4C401F9E25C808D64940E3DEFC86899A4C409BAC510FD1D44940F969DC9BDF984C409BAC510FD1D44940
65972	13901	56.773705999999997	56.795265000000001	51.949384000000002	51.936604000000003	Кооперативная	0103000020E61000000100000005000000075C57CC08634C40C2A6CEA3E2F74940075C57CC08634C403FAC376A85F94940A453573ECB654C403FAC376A85F94940A453573ECB654C40C2A6CEA3E2F74940075C57CC08634C40C2A6CEA3E2F74940
64327	15697	56.648992999999997	56.670399000000003	52.275627	52.253667999999998	Молодежная	0103000020E610000001000000050000009D2ADF3312534C4057056A3178204A409D2ADF3312534C408272DBBE47234A40B4226AA2CF554C408272DBBE47234A40B4226AA2CF554C4057056A3178204A409D2ADF3312534C4057056A3178204A40
64900	14611	56.879922000000001	56.892040999999999	52.214683999999998	52.203178000000001	Бишай	0103000020E61000000100000005000000F583BA48A1704C4023A298BC011A4A40F583BA48A1704C40BB7CEBC37A1B4A4077D844662E724C40BB7CEBC37A1B4A4077D844662E724C4023A298BC011A4A40F583BA48A1704C4023A298BC011A4A40
65231	14219	57.078809	57.099713000000001	51.845098	51.833078	Школьная	0103000020E61000000100000005000000B3D0CE69168A4C403082C64CA2EA4940B3D0CE69168A4C401FF5D72B2CEC494037FE4465C38C4C401FF5D72B2CEC494037FE4465C38C4C403082C64CA2EA4940B3D0CE69168A4C403082C64CA2EA4940
65608	15158	56.500492000000001	56.516680000000001	52.168242999999997	52.162962	Набережная	0103000020E610000001000000050000006FF4311F10404C40D13E56F0DB144A406FF4311F10404C40F56393FC88154A40A73FFB9122424C40F56393FC88154A40A73FFB9122424C40D13E56F0DB144A406FF4311F10404C40D13E56F0DB144A40
65949	13778	56.920239000000002	56.933650999999998	51.940123999999997	51.928980000000003	Ассель	0103000020E610000001000000050000007BC03C64CA754C40AD510FD1E8F649407BC03C64CA754C40A417B5FB55F8494058703FE081774C40A417B5FB55F8494058703FE081774C40AD510FD1E8F649407BC03C64CA754C40AD510FD1E8F64940
64691	14350	57.010438999999998	57.021461000000002	51.888693000000004	51.880431999999999	Центральная	0103000020E610000001000000050000002DCDAD1056814C400A2DEBFEB1F049402DCDAD1056814C40929735B1C0F14940DA91EA3BBF824C40929735B1C0F14940DA91EA3BBF824C400A2DEBFEB1F049402DCDAD1056814C400A2DEBFEB1F04940
65144	14133	56.882967999999998	56.898311	51.758355000000002	51.748280000000001	Ишапай	0103000020E610000001000000050000000FB56D1805714C401D2098A3C7DF49400FB56D1805714C4009E1D1C611E149408B51D7DAFB724C4009E1D1C611E149408B51D7DAFB724C401D2098A3C7DF49400FB56D1805714C401D2098A3C7DF4940
64434	13760	56.744168999999999	56.783344999999997	51.859206	51.843913000000001	Магадеева	0103000020E6100000010000000500000038D906EE405F4C40AAD5575705EC494038D906EE405F4C4074435376FAED4940183E22A644644C4074435376FAED4940183E22A644644C40AAD5575705EC494038D906EE405F4C40AAD5575705EC4940
66573	58845	53.926774000000002	53.930708000000003	53.840823	53.837577000000003	Школьная	0103000020E610000001000000050000003D64CA87A0F64A40DF701FB935EB4A403D64CA87A0F64A40C05C8B16A0EB4A401310937021F74A40C05C8B16A0EB4A401310937021F74A40DF701FB935EB4A403D64CA87A0F64A40DF701FB935EB4A40
64039	12503	53.741838000000001	53.772739999999999	53.902490999999998	53.891497000000001	Школьная	0103000020E610000001000000050000000C772E8CF4DE4A40B6BDDD921CF24A400C772E8CF4DE4A4098F738D384F34A40D027F224E9E24A4098F738D384F34A40D027F224E9E24A40B6BDDD921CF24A400C772E8CF4DE4A40B6BDDD921CF24A40
66875	4902	53.550874	53.576619000000001	54.277825	54.258600999999999	Центральная	0103000020E61000000100000005000000BD1B0B0A83C64A4040DB6AD619214B40BD1B0B0A83C64A406F8104C58F234B4049A0C1A6CEC94A406F8104C58F234B4049A0C1A6CEC94A4040DB6AD619214B40BD1B0B0A83C64A4040DB6AD619214B40
64466	13637	53.614834000000002	53.650623000000003	53.844462	53.828496000000001	Молодежная	0103000020E61000000100000005000000043C69E1B2CE4A40F46E2C280CEA4A40043C69E1B2CE4A407D5BB05417EC4A4041834D9D47D34A407D5BB05417EC4A4041834D9D47D34A40F46E2C280CEA4A40043C69E1B2CE4A40F46E2C280CEA4A40
64443	13608	53.720027000000002	53.749679999999998	54.251874000000001	54.216456999999998	Школьная	0103000020E61000000100000005000000569E40D829DC4A40C1FEEBDCB41B4B40569E40D829DC4A403A5B40683D204B408E3BA583F5DF4A403A5B40683D204B408E3BA583F5DF4A40C1FEEBDCB41B4B40569E40D829DC4A40C1FEEBDCB41B4B40
65521	13480	53.560513	53.592708000000002	54.202182000000001	54.177773999999999	Школьная	0103000020E61000000100000005000000CEFDD5E3BEC74A40200A664CC1164B40CEFDD5E3BEC74A4081EB8A19E1194B40EE0912DBDDCB4A4081EB8A19E1194B40EE0912DBDDCB4A40200A664CC1164B40CEFDD5E3BEC74A40200A664CC1164B40
65748	13576	53.575757000000003	53.642673000000002	54.306176000000001	54.286351000000003	Центральная	0103000020E61000000100000005000000B7B8C667B2C94A40A5164A26A7244B40B7B8C667B2C94A40F96871C630274B40D882DE1B43D24A40F96871C630274B40D882DE1B43D24A40A5164A26A7244B40B7B8C667B2C94A40A5164A26A7244B40
66727	448	53.471983999999999	53.521714000000003	54.285221	54.266899000000002	Ленина	0103000020E610000001000000050000001D1EC2F869BC4A40E52A16BF29224B401D1EC2F869BC4A40F390291F82244B40C4EE3B86C7C24A40F390291F82244B40C4EE3B86C7C24A40E52A16BF29224B401D1EC2F869BC4A40E52A16BF29224B40
66824	448	53.471983999999999	53.521714000000003	54.285221	54.266899000000002	Кирова	0103000020E610000001000000050000001D1EC2F869BC4A40E52A16BF29224B401D1EC2F869BC4A40F390291F82244B40C4EE3B86C7C24A40F390291F82244B40C4EE3B86C7C24A40E52A16BF29224B401D1EC2F869BC4A40E52A16BF29224B40
66927	445	53.583007000000002	53.613612000000003	53.991315999999998	53.970830999999997	Чапаева	0103000020E61000000100000005000000672B2FF99FCA4A40B378B13044FC4A40672B2FF99FCA4A4032005471E3FE4A40723788D68ACE4A4032005471E3FE4A40723788D68ACE4A40B378B13044FC4A40672B2FF99FCA4A40B378B13044FC4A40
64144	13328	53.784427000000001	53.813685	53.988844	53.972546999999999	Клубная	0103000020E61000000100000005000000B98C9B1A68E44A4055698B6B7CFC4A40B98C9B1A68E44A40446CB07092FE4A40751F80D426E84A40446CB07092FE4A40751F80D426E84A4055698B6B7CFC4A40B98C9B1A68E44A4055698B6B7CFC4A40
64623	13292	53.785639000000003	53.807944999999997	54.108772999999999	54.095807000000001	Лесная	0103000020E6100000010000000500000028BB99D18FE44A402BDD5D67430C4B4028BB99D18FE44A400AD80E46EC0D4B40BDFBE3BD6AE74A400AD80E46EC0D4B40BDFBE3BD6AE74A402BDD5D67430C4B4028BB99D18FE44A402BDD5D67430C4B40
64043	13218	53.507503	53.555436999999998	54.1004	54.071463000000001	Коммунистическая	0103000020E610000001000000050000009ACFB9DBF5C04A40E1EF17B325094B409ACFB9DBF5C04A405B423EE8D90C4B4082FE428F18C74A405B423EE8D90C4B4082FE428F18C74A40E1EF17B325094B409ACFB9DBF5C04A40E1EF17B325094B40
63581	12213	53.908555999999997	53.961897999999998	53.912866000000001	53.874015	Школьная	0103000020E61000000100000005000000D34A21904BF44A40529B38B9DFEF4A40D34A21904BF44A40AFD007CBD8F44A403D0B42791FFB4A40AFD007CBD8F44A403D0B42791FFB4A40529B38B9DFEF4A40D34A21904BF44A40529B38B9DFEF4A40
63640	12213	53.908555999999997	53.961897999999998	53.912866000000001	53.874015	Свердлова	0103000020E61000000100000005000000D34A21904BF44A40529B38B9DFEF4A40D34A21904BF44A40AFD007CBD8F44A403D0B42791FFB4A40AFD007CBD8F44A403D0B42791FFB4A40529B38B9DFEF4A40D34A21904BF44A40529B38B9DFEF4A40
64547	12213	53.908555999999997	53.961897999999998	53.912866000000001	53.874015	Первомайская	0103000020E61000000100000005000000D34A21904BF44A40529B38B9DFEF4A40D34A21904BF44A40AFD007CBD8F44A403D0B42791FFB4A40AFD007CBD8F44A403D0B42791FFB4A40529B38B9DFEF4A40D34A21904BF44A40529B38B9DFEF4A40
63645	12213	53.908555999999997	53.961897999999998	53.912866000000001	53.874015	Комсомольская	0103000020E61000000100000005000000D34A21904BF44A40529B38B9DFEF4A40D34A21904BF44A40AFD007CBD8F44A403D0B42791FFB4A40AFD007CBD8F44A403D0B42791FFB4A40529B38B9DFEF4A40D34A21904BF44A40529B38B9DFEF4A40
63384	12213	53.908555999999997	53.961897999999998	53.912866000000001	53.874015	Бульвар Мира	0103000020E61000000100000005000000D34A21904BF44A40529B38B9DFEF4A40D34A21904BF44A40AFD007CBD8F44A403D0B42791FFB4A40AFD007CBD8F44A403D0B42791FFB4A40529B38B9DFEF4A40D34A21904BF44A40529B38B9DFEF4A40
63647	12213	53.908555999999997	53.961897999999998	53.912866000000001	53.874015	50 лет ВЛКСМ	0103000020E61000000100000005000000D34A21904BF44A40529B38B9DFEF4A40D34A21904BF44A40AFD007CBD8F44A403D0B42791FFB4A40AFD007CBD8F44A403D0B42791FFB4A40529B38B9DFEF4A40D34A21904BF44A40529B38B9DFEF4A40
64621	13138	53.741774999999997	53.762562000000003	53.983111000000001	53.978620999999997	Пионерская	0103000020E61000000100000005000000C5FEB27BF2DE4A40E316F37343FD4A40C5FEB27BF2DE4A403FABCC94D6FD4A401096B1A19BE14A403FABCC94D6FD4A401096B1A19BE14A40E316F37343FD4A40C5FEB27BF2DE4A40E316F37343FD4A40
66719	13202	\N	\N	\N	\N	Молодежная	\N
66788	343	53.593210999999997	53.625371000000001	54.175381999999999	54.152766999999997	Центральная	0103000020E6100000010000000500000050508A56EECB4A403A747ADE8D134B4050508A56EECB4A404E27D9EA72164B40F46E2C280CD04A404E27D9EA72164B40F46E2C280CD04A403A747ADE8D134B4050508A56EECB4A403A747ADE8D134B40
64620	13045	53.825650000000003	53.838217999999998	53.816918999999999	53.804532000000002	Нагорная	0103000020E61000000100000005000000A1F831E6AEE94A40F14A92E7FAE64A40A1F831E6AEE94A40923D42CD90E84A40927538BA4AEB4A40923D42CD90E84A40927538BA4AEB4A40F14A92E7FAE64A40A1F831E6AEE94A40F14A92E7FAE64A40
65137	13085	53.825363000000003	53.84854	53.835738999999997	53.823261000000002	Салавата Юлаева	0103000020E610000001000000050000000B2AAA7EA5E94A404089CF9D60E94A400B2AAA7EA5E94A40F17EDC7EF9EA4A4086AC6EF59CEC4A40F17EDC7EF9EA4A4086AC6EF59CEC4A404089CF9D60E94A400B2AAA7EA5E94A404089CF9D60E94A40
66575	58846	53.563459000000002	53.582953000000003	53.955404999999999	53.943361000000003	Молодежная	0103000020E6100000010000000500000085D1AC6C1FC84A4033A9A10DC0F84A4085D1AC6C1FC84A40AAB706B64AFA4A40740D33349ECA4A40AAB706B64AFA4A40740D33349ECA4A4033A9A10DC0F84A4085D1AC6C1FC84A4033A9A10DC0F84A40
64911	12943	53.730491999999998	53.752949999999998	54.068277000000002	54.056581999999999	Молодёжная	0103000020E61000000100000005000000ACFE08C380DD4A4069C537143E074B40ACFE08C380DD4A40D508FD4CBD084B40F8C264AA60E04A40D508FD4CBD084B40F8C264AA60E04A4069C537143E074B40ACFE08C380DD4A4069C537143E074B40
65517	12886	53.696033	53.714762	54.172888999999998	54.153674000000002	Школьная	0103000020E61000000100000005000000E8F7FD9B17D94A406D1FF296AB134B40E8F7FD9B17D94A40486B0C3A21164B4037363B527DDB4A40486B0C3A21164B4037363B527DDB4A406D1FF296AB134B40E8F7FD9B17D94A406D1FF296AB134B40
66640	4673	53.457934000000002	53.476610000000001	54.168098000000001	54.156247	Клубная	0103000020E61000000100000005000000FDDCD0949DBA4A408F8CD5E6FF134B40FDDCD0949DBA4A40F2423A3C84154B402979758E01BD4A40F2423A3C84154B402979758E01BD4A408F8CD5E6FF134B40FDDCD0949DBA4A408F8CD5E6FF134B40
66688	10285	53.710954000000001	53.751899000000002	53.762720999999999	53.750185000000002	Садовая	0103000020E61000000100000005000000EE7A698A00DB4A409279E40F06E04A40EE7A698A00DB4A40787C7BD7A0E14A409372F7393EE04A40787C7BD7A0E14A409372F7393EE04A409279E40F06E04A40EE7A698A00DB4A409279E40F06E04A40
63537	12607	53.648952000000001	53.695340999999999	54.089458999999998	54.066253000000003	Школьная	0103000020E610000001000000050000003F56F0DB10D34A40862172FA7A084B403F56F0DB10D34A409BAA7B64730B4B40B24813EF00D94A409BAA7B64730B4B40B24813EF00D94A40862172FA7A084B403F56F0DB10D34A40862172FA7A084B40
63426	12607	53.648952000000001	53.695340999999999	54.089458999999998	54.066253000000003	Ленина	0103000020E610000001000000050000003F56F0DB10D34A40862172FA7A084B403F56F0DB10D34A409BAA7B64730B4B40B24813EF00D94A409BAA7B64730B4B40B24813EF00D94A40862172FA7A084B403F56F0DB10D34A40862172FA7A084B40
64430	12607	53.648952000000001	53.695340999999999	54.089458999999998	54.066253000000003	Коммунистическая	0103000020E610000001000000050000003F56F0DB10D34A40862172FA7A084B403F56F0DB10D34A409BAA7B64730B4B40B24813EF00D94A409BAA7B64730B4B40B24813EF00D94A40862172FA7A084B403F56F0DB10D34A40862172FA7A084B40
65518	12470	53.731687000000001	53.743904000000001	54.035229999999999	54.019970999999998	Центральная	0103000020E6100000010000000500000045F46BEBA7DD4A4028EFE3688E024B4045F46BEBA7DD4A4046EBA86A82044B408AAE0B3F38DF4A4046EBA86A82044B408AAE0B3F38DF4A4028EFE3688E024B4045F46BEBA7DD4A4028EFE3688E024B40
66581	58850	53.823369	53.832514000000003	54.046908999999999	54.037556000000002	Набережная	0103000020E6100000010000000500000026C5C72764E94A4061E28FA2CE044B4026C5C72764E94A40AC71361D01064B4028BB99D18FEA4A40AC71361D01064B4028BB99D18FEA4A4061E28FA2CE044B4026C5C72764E94A4061E28FA2CE044B40
65947	12406	53.863154999999999	53.890599000000002	53.922072	53.911555999999997	Школьная	0103000020E610000001000000050000007F30F0DC7BEE4A407D3CF4DDADF44A407F30F0DC7BEE4A4056478E7406F64A40D76CE525FFF14A4056478E7406F64A40D76CE525FFF14A407D3CF4DDADF44A407F30F0DC7BEE4A407D3CF4DDADF44A40
65501	12406	53.863154999999999	53.890599000000002	53.922072	53.911555999999997	Октябрьская	0103000020E610000001000000050000007F30F0DC7BEE4A407D3CF4DDADF44A407F30F0DC7BEE4A4056478E7406F64A40D76CE525FFF14A4056478E7406F64A40D76CE525FFF14A407D3CF4DDADF44A407F30F0DC7BEE4A407D3CF4DDADF44A40
65952	12382	53.598700000000001	53.617564999999999	53.876308000000002	53.868960999999999	Мира	0103000020E61000000100000005000000BF0E9C33A2CC4A40EE3F321D3AEF4A40BF0E9C33A2CC4A40919C4CDC2AF04A40BE13B35E0CCF4A40919C4CDC2AF04A40BE13B35E0CCF4A40EE3F321D3AEF4A40BF0E9C33A2CC4A40EE3F321D3AEF4A40
65134	12318	53.434254000000003	53.450828000000001	54.249985000000002	54.224122000000001	Горная	0103000020E610000001000000050000001F1494A295B74A4035289A07B01C4B401F1494A295B74A40CBBE2B82FF1F4B40800F5EBBB4B94A40CBBE2B82FF1F4B40800F5EBBB4B94A4035289A07B01C4B401F1494A295B74A4035289A07B01C4B40
65122	12268	53.589348999999999	53.621724	54.086306	54.075341000000002	Тукая	0103000020E610000001000000050000001477BCC96FCB4A4023861DC6A4094B401477BCC96FCB4A406BB933130C0B4B40B491EBA694CF4A406BB933130C0B4B40B491EBA694CF4A4023861DC6A4094B401477BCC96FCB4A4023861DC6A4094B40
64622	12212	54.644159000000002	54.679983999999997	55.717365999999998	55.699756000000001	Центральная	0103000020E61000000100000005000000483657CD73524B400397C79A91D94B40483657CD73524B4094A12AA6D2DB4B40D1E638B709574B4094A12AA6D2DB4B40D1E638B709574B400397C79A91D94B40483657CD73524B400397C79A91D94B40
64617	12154	54.740718999999999	54.767130000000002	55.744155999999997	55.732768	Центральная	0103000020E610000001000000050000004E4354E1CF5E4B4015C78157CBDD4B404E4354E1CF5E4B40A38FF98040DF4B40E7E3DA5031624B40A38FF98040DF4B40E7E3DA5031624B4015C78157CBDD4B404E4354E1CF5E4B4015C78157CBDD4B40
64611	11959	55.007950000000001	55.027155999999998	55.453279000000002	55.442458999999999	Советская	0103000020E6100000010000000500000069006F8104814B4012691B7FA2B84B4069006F8104814B40577BD80B05BA4B40F1F109D979834B40577BD80B05BA4B40F1F109D979834B4012691B7FA2B84B4069006F8104814B4012691B7FA2B84B40
64671	10487	54.914265	54.942104	55.272661999999997	55.261721000000001	Механизаторская	0103000020E610000001000000050000005070B1A206754B4095D6DF1280A14B405070B1A206754B40546EA296E6A24B4024B726DD96784B40546EA296E6A24B4024B726DD96784B4095D6DF1280A14B405070B1A206754B4095D6DF1280A14B40
66683	58866	55.017122000000001	55.037405999999997	55.654477	55.646720999999999	Давлетгареевых	0103000020E610000001000000050000006405BF0D31824B407651F4C0C7D24B406405BF0D31824B40FA7DFFE6C5D34B404B5645B8C9844B40FA7DFFE6C5D34B404B5645B8C9844B407651F4C0C7D24B406405BF0D31824B407651F4C0C7D24B40
65511	11807	54.776364000000001	54.794744000000001	55.468214000000003	55.455474000000002	Механизаторская	0103000020E6100000010000000500000058E542E55F634B40D316D7F84CBA4B4058E542E55F634B40C2C3B46FEEBB4B409B58E02BBA654B40C2C3B46FEEBB4B409B58E02BBA654B40D316D7F84CBA4B4058E542E55F634B40D316D7F84CBA4B40
64307	11597	54.825609999999998	54.851275000000001	55.380831000000001	55.365718999999999	Озерная	0103000020E6100000010000000500000012A0A696AD694B404E4354E1CFAE4B4012A0A696AD694B40C826F911BFB04B4082734694F66C4B40C826F911BFB04B4082734694F66C4B404E4354E1CFAE4B4012A0A696AD694B404E4354E1CFAE4B40
65941	11627	54.827775000000003	54.849576999999996	55.415818999999999	55.402577000000001	Ахуновых	0103000020E6100000010000000500000024B9FC87F4694B40978FA4A487B34B4024B9FC87F4694B401807978E39B54B4086376BF0BE6C4B401807978E39B54B4086376BF0BE6C4B40978FA4A487B34B4024B9FC87F4694B40978FA4A487B34B40
64128	11511	54.901760000000003	54.928269999999998	55.420994999999998	55.405194000000002	Центральная	0103000020E61000000100000005000000A56B26DF6C734B408944A165DDB34B40A56B26DF6C734B40C763062AE3B54B40D0ED258DD1764B40C763062AE3B54B40D0ED258DD1764B408944A165DDB34B40A56B26DF6C734B408944A165DDB34B40
64021	11309	55.068362	55.085340000000002	55.477106999999997	55.461190999999999	Молодежная	0103000020E6100000010000000500000003250516C0884B40D21A834E08BB4B4003250516C0884B40A9D898D711BD4B403485CE6BEC8A4B40A9D898D711BD4B403485CE6BEC8A4B40D21A834E08BB4B4003250516C0884B40D21A834E08BB4B40
64896	11215	55.120840999999999	55.153333000000003	55.405571999999999	55.393864999999998	Кооперативная	0103000020E610000001000000050000000A82C7B7778F4B40FF04172B6AB24B400A82C7B7778F4B402F1686C8E9B34B40E4326E6AA0934B402F1686C8E9B34B40E4326E6AA0934B40FF04172B6AB24B400A82C7B7778F4B40FF04172B6AB24B40
65484	9612	54.699603000000003	54.732194	55.536436000000002	55.525633999999997	Дормидонтова	0103000020E610000001000000050000007D9752978C594B4034D593F947C34B407D9752978C594B40D33252EFA9C44B40E9297288B85D4B40D33252EFA9C44B40E9297288B85D4B4034D593F947C34B407D9752978C594B4034D593F947C34B40
65497	11165	55.105786000000002	55.124605000000003	55.425716000000001	55.410305000000001	Молодежная	0103000020E61000000100000005000000F52F49658A8D4B405131CEDF84B44B40F52F49658A8D4B4025B1A4DC7DB64B4084F57F0EF38F4B4025B1A4DC7DB64B4084F57F0EF38F4B405131CEDF84B44B40F52F49658A8D4B405131CEDF84B44B40
65272	10300	54.509923999999998	54.525438000000001	55.534458999999998	55.524583999999997	Советская	0103000020E6100000010000000500000006B98B3045414B409F008A9125C34B4006B98B3045414B40C4060B2769C44B40AF09698D41434B40C4060B2769C44B40AF09698D41434B409F008A9125C34B4006B98B3045414B409F008A9125C34B40
63293	10887	54.603223	54.627189999999999	55.366849999999999	55.353560000000002	Мира	0103000020E61000000100000005000000F6984869364D4B403E963E7441AD4B40F6984869364D4B40D044D8F0F4AE4B406A300DC347504B40D044D8F0F4AE4B406A300DC347504B403E963E7441AD4B40F6984869364D4B403E963E7441AD4B40
64311	10887	54.603223	54.627189999999999	55.366849999999999	55.353560000000002	Ленина	0103000020E61000000100000005000000F6984869364D4B403E963E7441AD4B40F6984869364D4B40D044D8F0F4AE4B406A300DC347504B40D044D8F0F4AE4B406A300DC347504B403E963E7441AD4B40F6984869364D4B403E963E7441AD4B40
64607	11429	55.163215000000001	55.181351999999997	55.475530999999997	55.467249000000002	Фазыловых	0103000020E61000000100000005000000BB9BA73AE4944B405B0BB3D0CEBB4B40BB9BA73AE4944B40F99D2633DEBC4B403788D68A36974B40F99D2633DEBC4B403788D68A36974B405B0BB3D0CEBB4B40BB9BA73AE4944B405B0BB3D0CEBB4B40
65942	11931	54.821792000000002	54.863599999999998	55.568888999999999	55.554634	Механизаторская	0103000020E61000000100000005000000A60EF27A30694B40F59F353FFEC64B40A60EF27A30694B40EE06D15AD1C84B40AD69DE718A6E4B40EE06D15AD1C84B40AD69DE718A6E4B40F59F353FFEC64B40A60EF27A30694B40F59F353FFEC64B40
65114	11131	54.608334999999997	54.636136999999998	55.398988000000003	55.383372000000001	Коммунистическая	0103000020E610000001000000050000008E01D9EBDD4D4B40DF196D5512B14B408E01D9EBDD4D4B408CBFED0912B34B404563EDEF6C514B408CBFED0912B34B404563EDEF6C514B40DF196D5512B14B408E01D9EBDD4D4B40DF196D5512B14B40
65486	11035	54.717722000000002	54.744537000000001	55.378754000000001	55.362029999999997	Гумерова	0103000020E6100000010000000500000053CF8250DE5B4B40DF15C1FF56AE4B4053CF8250DE5B4B40569DD5027BB04B40BBD408FD4C5F4B40569DD5027BB04B40BBD408FD4C5F4B40DF15C1FF56AE4B4053CF8250DE5B4B40DF15C1FF56AE4B40
64889	10153	54.643818000000003	54.661245000000001	55.528049000000003	55.515518	Школьная	0103000020E61000000100000005000000BF49D3A068524B40EA3F6B7EFCC14B40BF49D3A068524B40BFD7101C97C34B405FD218ADA3544B40BFD7101C97C34B405FD218ADA3544B40EA3F6B7EFCC14B40BF49D3A068524B40EA3F6B7EFCC14B40
64249	10696	55.060349000000002	55.109710999999997	55.330261	55.307997999999998	Калинина	0103000020E6100000010000000500000054AC1A84B9874B40E09D7C7A6CA74B4054AC1A84B9874B40771211FE45AA4B40778192020B8E4B40771211FE45AA4B40778192020B8E4B40E09D7C7A6CA74B4054AC1A84B9874B40E09D7C7A6CA74B40
65931	10617	55.008274	55.038474999999998	55.625501	55.61327	Советская	0103000020E610000001000000050000001CB4571F0F814B4018CFA0A17FCE4B401CB4571F0F814B40C24EB16A10D04B40575BB1BFEC844B40C24EB16A10D04B40575BB1BFEC844B4018CFA0A17FCE4B401CB4571F0F814B4018CFA0A17FCE4B40
64247	10527	54.948518	54.967830999999997	55.624439000000002	55.610148000000002	Горшкова	0103000020E610000001000000050000006BD5AE0969794B4023DC645419CE4B406BD5AE0969794B4069ACFD9DEDCF4B400987DEE2E17B4B4069ACFD9DEDCF4B400987DEE2E17B4B4023DC645419CE4B406BD5AE0969794B4023DC645419CE4B40
64755	11883	54.760958000000002	54.799505000000003	55.516359000000001	55.502737000000003	Советская	0103000020E6100000010000000500000096D05D1267614B409DBE9EAF59C04B4096D05D1267614B4065FF3C0D18C24B4087FE092E56664B4065FF3C0D18C24B4087FE092E56664B409DBE9EAF59C04B4096D05D1267614B409DBE9EAF59C04B40
64894	10392	54.930399000000001	54.962440999999998	55.323796999999999	55.310509000000003	Школьная	0103000020E61000000100000005000000959D7E5017774B408D0E48C2BEA74B40959D7E5017774B407EC51A2E72A94B402EAA4544317B4B407EC51A2E72A94B402EAA4544317B4B408D0E48C2BEA74B40959D7E5017774B408D0E48C2BEA74B40
64462	10070	54.611325999999998	54.646639	55.572471999999998	55.547280000000001	Школьная	0103000020E61000000100000005000000E5982CEE3F4E4B40A0E062450DC64B40E5982CEE3F4E4B4017F032C346C94B40B9A81611C5524B4017F032C346C94B40B9A81611C5524B40A0E062450DC64B40E5982CEE3F4E4B40A0E062450DC64B40
65936	10858	54.982374999999998	55.003548000000002	55.342559999999999	55.331893999999998	Школьная	0103000020E6100000010000000500000039B4C876BE7D4B408BDEA9807BAA4B4039B4C876BE7D4B4079758E01D9AB4B40ADFBC74274804B4079758E01D9AB4B40ADFBC74274804B408BDEA9807BAA4B4039B4C876BE7D4B408BDEA9807BAA4B40
65108	10417	54.989390999999998	55.01493	55.296703000000001	55.283378999999996	Школьная	0103000020E6100000010000000500000076FA415DA47E4B40C4AF58C345A44B4076FA415DA47E4B4003D0285DFAA54B4059DDEA39E9814B4003D0285DFAA54B4059DDEA39E9814B40C4AF58C345A44B4076FA415DA47E4B40C4AF58C345A44B40
63276	11716	54.810743000000002	54.840153999999998	55.499713	55.484678000000002	Комсомольская	0103000020E61000000100000005000000003B376DC6674B409C8BBFED09BE4B40003B376DC6674B406A317898F6BF4B4042CD902A8A6B4B406A317898F6BF4B4042CD902A8A6B4B409C8BBFED09BE4B40003B376DC6674B409C8BBFED09BE4B40
65123	12048	55.029617999999999	55.046964000000003	55.460543000000001	55.453676999999999	Социалистическая	0103000020E61000000100000005000000BCAFCA85CA834B4044F9821612BA4B40BCAFCA85CA834B406CB3B112F3BA4B40700B96EA02864B406CB3B112F3BA4B40700B96EA02864B4044F9821612BA4B40BCAFCA85CA834B4044F9821612BA4B40
63751	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	переулок Марии Якутовой	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
64384	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Седова	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
63569	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Разиля Мусина	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
63636	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Первомайская	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
63279	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Назара Наджми	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
63700	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Матросова	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
64022	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Марии Якутовой	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
63516	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Ленина	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
63730	295	54.837404999999997	54.884531000000003	55.506138	55.471597000000003	Василия Горшкова	0103000020E61000000100000005000000E1404816306B4B4024F25D4A5DBC4B40E1404816306B4B40A5A14621C9C04B402BA6D24F38714B40A5A14621C9C04B402BA6D24F38714B4024F25D4A5DBC4B40E1404816306B4B4024F25D4A5DBC4B40
65124	11725	54.791725999999997	54.810105	55.491906	55.474831999999999	Школьная	0103000020E610000001000000050000004AB20E4757654B40118C834BC7BC4B404AB20E4757654B40645A9BC6F6BE4B40BDA94885B1674B40645A9BC6F6BE4B40BDA94885B1674B40118C834BC7BC4B404AB20E4757654B40118C834BC7BC4B40
65489	11439	55.151527999999999	55.162281	55.532848999999999	55.518926999999998	Интернациональная	0103000020E61000000100000005000000D236FE4465934B4075012F336CC24B40D236FE4465934B40685A626534C44B408FE1B19FC5944B40685A626534C44B408FE1B19FC5944B4075012F336CC24B40D236FE4465934B4075012F336CC24B40
64232	10018	54.696064	54.742165999999997	55.453488	55.435319999999997	Ш.Бабича	0103000020E6100000010000000500000023F609A018594B40B9A5D590B8B74B4023F609A018594B40719010E50BBA4B40001AA54BFF5E4B40719010E50BBA4B40001AA54BFF5E4B40B9A5D590B8B74B4023F609A018594B40B9A5D590B8B74B40
64038	9931	54.775798999999999	54.830353000000002	55.653731000000001	55.617663	Чиглинцева	0103000020E610000001000000050000007FA2B2614D634B408179C8940FCF4B407FA2B2614D634B40D1B01875ADD34B405891D101496A4B40D1B01875ADD34B405891D101496A4B408179C8940FCF4B407FA2B2614D634B408179C8940FCF4B40
65939	11347	55.104663000000002	55.128639	55.445503000000002	55.430793999999999	Интернациональная	0103000020E61000000100000005000000F60CE198658D4B4011A8FE4124B74B40F60CE198658D4B408CA2073E06B94B40BDFE243E77904B408CA2073E06B94B40BDFE243E77904B4011A8FE4124B74B40F60CE198658D4B4011A8FE4124B74B40
64245	8919	57.925876000000002	58.005088999999998	55.872869999999999	55.828794000000002	Советская	0103000020E610000001000000050000005E13D21A83F64C407E8FFAEB15EA4B405E13D21A83F64C406BD44334BAEF4B40E048A0C1A6004D406BD44334BAEF4B40E048A0C1A6004D407E8FFAEB15EA4B405E13D21A83F64C407E8FFAEB15EA4B40
66351	8658	57.894182999999998	57.926684000000002	55.738697999999999	55.719611999999998	Сушзаводская	0103000020E61000000100000005000000D0D1AA9674F24C4092E7FA3E1CDC4B40D0D1AA9674F24C4070CFF3A78DDE4B40FDDCD0949DF64C4070CFF3A78DDE4B40FDDCD0949DF64C4092E7FA3E1CDC4B40D0D1AA9674F24C4092E7FA3E1CDC4B40
63396	8476	57.957954999999998	57.994309000000001	55.670304999999999	55.651313000000002	60 лет Октября	0103000020E610000001000000050000001405FA449EFA4C40D63A71395ED34B401405FA449EFA4C4032ACE28DCCD54B402A8F6E8445FF4C4032ACE28DCCD54B402A8F6E8445FF4C40D63A71395ED34B401405FA449EFA4C40D63A71395ED34B40
64090	8816	57.851090999999997	57.919075999999997	55.773135000000003	55.751199	Площадь Ившина	0103000020E61000000100000005000000C075C58CF0EC4C40DAE4F04927E04B40C075C58CF0EC4C404D327216F6E24B40ED444948A4F54C404D327216F6E24B40ED444948A4F54C40DAE4F04927E04B40C075C58CF0EC4C40DAE4F04927E04B40
64888	7923	58.333621000000001	58.355792000000001	55.584567999999997	55.572732000000002	Центральная	0103000020E610000001000000050000002121CA17B42A4D40B4AF3C484FC94B402121CA17B42A4D40E124CD1FD3CA4B40D7169E978A2D4D40E124CD1FD3CA4B40D7169E978A2D4D40B4AF3C484FC94B402121CA17B42A4D40B4AF3C484FC94B40
64322	9078	57.938650000000003	57.980196999999997	55.918706	55.883454	Октябрьская	0103000020E61000000100000005000000F931E6AE25F84C409CC24A0515F14B40F931E6AE25F84C40CA51802898F54B409351651877FD4C40CA51802898F54B409351651877FD4C409CC24A0515F14B40F931E6AE25F84C409CC24A0515F14B40
66743	8158	58.355297	58.396836	55.468673000000003	55.447733999999997	Мира	0103000020E61000000100000005000000F7AE415F7A2D4D4054A703594FB94B40F7AE415F7A2D4D4055C2137AFDBB4B400FF0A485CB324D4055C2137AFDBB4B400FF0A485CB324D4054A703594FB94B40F7AE415F7A2D4D4054A703594FB94B40
65384	8730	57.479134999999999	57.516171999999997	55.627453000000003	55.606766	Лесная	0103000020E610000001000000050000003AAFB14B54BD4C4091291F82AACD4B403AAFB14B54BD4C407863416150D04B40328E91EC11C24C407863416150D04B40328E91EC11C24C4091291F82AACD4B403AAFB14B54BD4C4091291F82AACD4B40
64365	8388	57.906543999999997	57.958331999999999	55.592820000000003	55.565117000000001	Михайловская	0103000020E61000000100000005000000483140A209F44C40F2B4FCC055C84B40483140A209F44C4016359886E1CB4B40EA5A7B9FAAFA4C4016359886E1CB4B40EA5A7B9FAAFA4C40F2B4FCC055C84B40483140A209F44C40F2B4FCC055C84B40
65820	8437	57.920549000000001	57.942709999999998	55.637656999999997	55.623066000000001	Береговая	0103000020E61000000100000005000000C9AEB48CD4F54C40F19F6EA0C0CF4B40C9AEB48CD4F54C4061889CBE9ED14B405BCEA5B8AAF84C4061889CBE9ED14B405BCEA5B8AAF84C40F19F6EA0C0CF4B40C9AEB48CD4F54C40F19F6EA0C0CF4B40
64458	9120	57.933070999999998	57.976460000000003	56.025643000000002	56.001353000000002	Советская	0103000020E610000001000000050000004AECDADE6EF74C403160C9552C004C404AECDADE6EF74C40882F134548034C4014ED2AA4FCFC4C40882F134548034C4014ED2AA4FCFC4C403160C9552C004C404AECDADE6EF74C403160C9552C004C40
63616	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Электрическая	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
63660	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Революционная	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
65818	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Промышленная	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
64019	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Партизанская	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
64303	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Новая	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
64515	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Набережная	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
66356	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Магистральная	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
65380	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Крупская	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
64087	7454	58.225850000000001	58.293925000000002	55.546827	55.508640999999997	Коммунистическая	0103000020E610000001000000050000009BE61DA7E81C4D40CE33F6251BC14B409BE61DA7E81C4D40EFC8586DFEC54B40083D9B559F254D40EFC8586DFEC54B40083D9B559F254D40CE33F6251BC14B409BE61DA7E81C4D40CE33F6251BC14B40
65385	8804	58.052430000000001	58.096384999999998	55.752986999999997	55.735753000000003	Молодежная	0103000020E6100000010000000500000026AAB706B6064D408A7780272DDE4B4026AAB706B6064D4015A8C5E061E04B409869FB57560C4D4015A8C5E061E04B409869FB57560C4D408A7780272DDE4B4026AAB706B6064D408A7780272DDE4B40
66347	8081	58.168501999999997	58.182110999999999	55.571668000000003	55.564301999999998	Речная	0103000020E61000000100000005000000C1A7397991154D40A088450C3BC84B40C1A7397991154D40BA15C26A2CC94B40F59ECA694F174D40BA15C26A2CC94B40F59ECA694F174D40A088450C3BC84B40C1A7397991154D40A088450C3BC84B40
65969	8738	57.461661999999997	57.481667999999999	55.630831999999998	55.619695999999998	Центральная	0103000020E6100000010000000500000029E78BBD17BB4C4023BBD23252CF4B4029E78BBD17BB4C4098A25C1ABFD04B40CEC3094CA7BD4C4098A25C1ABFD04B40CEC3094CA7BD4C4023BBD23252CF4B4029E78BBD17BB4C4023BBD23252CF4B40
66883	216	58.272086999999999	58.296106999999999	55.389018	55.378830999999998	Первомайская	0103000020E6100000010000000500000058552FBFD3224D4001DBC1887DB04B4058552FBFD3224D4015C78157CBB14B40EF8E8CD5E6254D4015C78157CBB14B40EF8E8CD5E6254D4001DBC1887DB04B4058552FBFD3224D4001DBC1887DB04B40
65932	9162	57.559435000000001	57.589950999999999	56.096724000000002	56.082988999999998	 Советская	0103000020E610000001000000050000006F9EEA909BC74C40C07630629F0A4C406F9EEA909BC74C40815EB873610C4C400A9FAD8383CB4C40815EB873610C4C400A9FAD8383CB4C40C07630629F0A4C406F9EEA909BC74C40C07630629F0A4C40
66668	8530	57.853713999999997	57.924393999999999	55.715971000000003	55.663791000000003	Ленина	0103000020E610000001000000050000009411178046ED4C4088307E1AF7D44B409411178046ED4C4035F10EF0A4DB4B402F4FE78A52F64C4035F10EF0A4DB4B402F4FE78A52F64C4088307E1AF7D44B409411178046ED4C4088307E1AF7D44B40
64485	8530	57.853713999999997	57.924393999999999	55.715971000000003	55.663791000000003	Гагарина	0103000020E610000001000000050000009411178046ED4C4088307E1AF7D44B409411178046ED4C4035F10EF0A4DB4B402F4FE78A52F64C4035F10EF0A4DB4B402F4FE78A52F64C4088307E1AF7D44B409411178046ED4C4088307E1AF7D44B40
64096	8903	57.894703999999997	57.981876999999997	55.819569999999999	55.779463999999997	Центральная	0103000020E61000000100000005000000D9CC21A985F24C406534F279C5E34B40D9CC21A985F24C40306475ABE7E84B40E8D84125AEFD4C40306475ABE7E84B40E8D84125AEFD4C406534F279C5E34B40D9CC21A985F24C406534F279C5E34B40
64358	8005	58.199852999999997	58.218241999999996	55.618090000000002	55.608561999999999	Салавата Юлаева	0103000020E61000000100000005000000F58079C894194D404FCB0F5CE5CD4B40F58079C894194D4009FEB7921DCF4B408B4E965AEF1B4D4009FEB7921DCF4B408B4E965AEF1B4D404FCB0F5CE5CD4B40F58079C894194D404FCB0F5CE5CD4B40
66439	58778	55.417006999999998	55.436644000000001	54.103245999999999	54.086754999999997	Центральная	0103000020E61000000100000005000000FE99417C60B54B40DAE1AFC91A0B4B40FE99417C60B54B40AEB8382A370D4B4050FF59F3E3B74B40AEB8382A370D4B4050FF59F3E3B74B40DAE1AFC91A0B4B40FE99417C60B54B40DAE1AFC91A0B4B40
66344	7260	55.354709	55.388053999999997	54.109305999999997	54.093688999999998	Центральная	0103000020E61000000100000005000000664CC11A67AD4B405A7F4B00FE0B4B40664CC11A67AD4B40D7A02FBDFD0D4B407E8AE3C0ABB14B40D7A02FBDFD0D4B407E8AE3C0ABB14B405A7F4B00FE0B4B40664CC11A67AD4B405A7F4B00FE0B4B40
65383	6374	55.552491000000003	55.571480999999999	54.124879999999997	54.104576000000002	Озерная	0103000020E61000000100000005000000CC2A6C06B8C64B4027F911BF620D4B40CC2A6C06B8C64B4055F65D11FC0F4B4087A4164A26C94B4055F65D11FC0F4B4087A4164A26C94B4027F911BF620D4B40CC2A6C06B8C64B4027F911BF620D4B40
65812	6269	55.302183999999997	55.324596999999997	54.232669000000001	54.220078999999998	Озерная	0103000020E61000000100000005000000EEAF1EF7ADA64B40A8C4758C2B1C4B40EEAF1EF7ADA64B4082E50819C81D4B409AB0FD648CA94B4082E50819C81D4B409AB0FD648CA94B40A8C4758C2B1C4B40EEAF1EF7ADA64B40A8C4758C2B1C4B40
65814	7187	55.102874999999997	55.132249999999999	54.205047	54.195650999999998	Школьная	0103000020E61000000100000005000000BA490C022B8D4B4000378B170B194B40BA490C022B8D4B404B92E7FA3E1A4B40B0726891ED904B404B92E7FA3E1A4B40B0726891ED904B4000378B170B194B40BA490C022B8D4B4000378B170B194B40
64284	7087	54.914569999999998	54.961677999999999	54.219321000000001	54.206831999999999	Центральная	0103000020E610000001000000050000008CF337A110754B4015E29178791A4B408CF337A110754B40BB29E5B5121C4B402FA4C343187B4B40BB29E5B5121C4B402FA4C343187B4B4015E29178791A4B408CF337A110754B4015E29178791A4B40
66833	5954	54.798149000000002	54.827308000000002	54.320205000000001	54.311796999999999	Молодежная	0103000020E61000000100000005000000E52A16BF29664B40D6FECEF6E8274B40E52A16BF29664B400282397AFC284B400EDC813AE5694B400282397AFC284B400EDC813AE5694B40D6FECEF6E8274B40E52A16BF29664B40D6FECEF6E8274B40
65659	6981	54.947142999999997	54.972368000000003	54.293745000000001	54.285305000000001	Школьная	0103000020E6100000010000000500000052D158FB3B794B405131CEDF84244B4052D158FB3B794B40882EA86F99254B40A6D6FB8D767C4B40882EA86F99254B40A6D6FB8D767C4B405131CEDF84244B4052D158FB3B794B405131CEDF84244B40
66679	6981	54.947142999999997	54.972368000000003	54.293745000000001	54.285305000000001	Клубная	0103000020E6100000010000000500000052D158FB3B794B405131CEDF84244B4052D158FB3B794B40882EA86F99254B40A6D6FB8D767C4B40882EA86F99254B40A6D6FB8D767C4B405131CEDF84244B4052D158FB3B794B405131CEDF84244B40
64877	6886	55.164121999999999	55.182510999999998	54.129854999999999	54.118963999999998	Каримова	0103000020E61000000100000005000000ED461FF301954B405FB35C363A0F4B40ED461FF301954B406D1CB1169F104B4083143C855C974B406D1CB1169F104B4083143C855C974B405FB35C363A0F4B40ED461FF301954B405FB35C363A0F4B40
64885	6865	55.027515000000001	55.057313000000001	54.335794	54.310436000000003	Поляковская	0103000020E6100000010000000500000021938C9C85834B4023C0E95DBC274B4021938C9C85834B40B5183C4CFB2A4B405D514A0856874B40B5183C4CFB2A4B405D514A0856874B4023C0E95DBC274B4021938C9C85834B4023C0E95DBC274B40
65810	6467	55.182510999999998	55.212325999999997	54.327047	54.318593	Школьная	0103000020E6100000010000000500000083143C855C974B4005DEC9A7C7284B4083143C855C974B40A1A014ADDC294B40950B957F2D9B4B40A1A014ADDC294B40950B957F2D9B4B4005DEC9A7C7284B4083143C855C974B4005DEC9A7C7284B40
64024	6302	55.556291000000002	55.565489999999997	54.198188999999999	54.18974	Мира	0103000020E610000001000000050000009207228B34C74B401C5F7B6649184B409207228B34C74B40A6B6D4415E194B40861BF0F961C84B40A6B6D4415E194B40861BF0F961C84B401C5F7B6649184B409207228B34C74B401C5F7B6649184B40
64875	6727	55.000413000000002	55.017814000000001	54.139482000000001	54.130809999999997	Салавата	0103000020E6100000010000000500000023BF7E880D804B40B0FECF61BE104B4023BF7E880D804B40BA30D28BDA114B409AB4A9BA47824B40BA30D28BDA114B409AB4A9BA47824B40B0FECF61BE104B4023BF7E880D804B40B0FECF61BE104B40
64880	7049	54.709386000000002	54.726776999999998	54.361393	54.348978000000002	Полевая	0103000020E61000000100000005000000C11E1329CD5A4B400283A44FAB2C4B40C11E1329CD5A4B406D003620422E4B40143E5B07075D4B406D003620422E4B40143E5B07075D4B400283A44FAB2C4B40C11E1329CD5A4B400283A44FAB2C4B40
65739	5765	54.552145000000003	54.577737999999997	54.256287	54.240299999999998	Салавата Юлаева	0103000020E6100000010000000500000031D3F6AFAC464B40499D8026C21E4B4031D3F6AFAC464B40EAB12D03CE204B4006D49B51F3494B40EAB12D03CE204B4006D49B51F3494B40499D8026C21E4B4031D3F6AFAC464B40499D8026C21E4B40
64299	33123	54.928646999999998	54.946586000000003	54.243834999999997	54.233606000000002	Школьная	0103000020E61000000100000005000000A643A7E7DD764B401F1329CDE61D4B40A643A7E7DD764B40614F3BFC351F4B40FD6CE4BA29794B40614F3BFC351F4B40FD6CE4BA29794B401F1329CDE61D4B40A643A7E7DD764B401F1329CDE61D4B40
64300	6577	54.445740000000001	54.464469000000001	54.327919000000001	54.312511000000001	Школьная	0103000020E61000000100000005000000704221020E394B40F451465C00284B40704221020E394B40575EF23FF9294B40BF805EB8733B4B40575EF23FF9294B40BF805EB8733B4B40F451465C00284B40704221020E394B40F451465C00284B40
65823	6423	55.211067999999997	55.225208000000002	54.2883	54.272824999999997	Демская	0103000020E61000000100000005000000B69DB646049B4B40FE43FAEDEB224B40B69DB646049B4B40E9B7AF03E7244B401766A19DD39C4B40E9B7AF03E7244B401766A19DD39C4B40FE43FAEDEB224B40B69DB646049B4B40FE43FAEDEB224B40
66599	58857	55.383732999999999	55.417771000000002	54.230274999999999	54.219836999999998	Советская	0103000020E61000000100000005000000AFB2B6291EB14B40B2B96A9E231C4B40AFB2B6291EB14B400F0BB5A6791D4B40CE1B278579B54B400F0BB5A6791D4B40CE1B278579B54B40B2B96A9E231C4B40AFB2B6291EB14B40B2B96A9E231C4B40
64085	6088	54.606645999999998	54.651246999999998	54.404246999999998	54.376064	Механизаторская	0103000020E61000000100000005000000E61F7D93A64D4B40FA997ADD22304B40E61F7D93A64D4B40C8409E5DBE334B401E4FCB0F5C534B40C8409E5DBE334B401E4FCB0F5C534B40FA997ADD22304B40E61F7D93A64D4B40FA997ADD22304B40
64084	7342	54.825907000000001	54.874020000000002	54.422701000000004	54.407397000000003	Крестьянская	0103000020E61000000100000005000000CC441152B7694B4088BEBB9525344B40CC441152B7694B40467EFD101B364B4064062AE3DF6F4B40467EFD101B364B4064062AE3DF6F4B4088BEBB9525344B40CC441152B7694B4088BEBB9525344B40
66346	6693	55.062505000000002	55.073653	54.150815999999999	54.135553000000002	Ярыштау	0103000020E61000000100000005000000126BF12900884B40F6EFFACC59114B40126BF12900884B4055DB4DF04D134B404B2025766D894B4055DB4DF04D134B404B2025766D894B40F6EFFACC59114B40126BF12900884B40F6EFFACC59114B40
65526	6693	55.062505000000002	55.073653	54.150815999999999	54.135553000000002	Школьная	0103000020E61000000100000005000000126BF12900884B40F6EFFACC59114B40126BF12900884B4055DB4DF04D134B404B2025766D894B4055DB4DF04D134B404B2025766D894B40F6EFFACC59114B40126BF12900884B40F6EFFACC59114B40
66654	5107	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Первомайская	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63397	5107	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Мира	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63729	5107	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Красная Площадь	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
63745	5107	54.999541999999998	55.074336000000002	54.231585000000003	54.177030999999999	Заводская	0103000020E610000001000000050000003D7D04FEF07F4B4068B0A9F3A8164B403D7D04FEF07F4B40419FC893A41D4B402E7590D783894B40419FC893A41D4B402E7590D783894B4068B0A9F3A8164B403D7D04FEF07F4B4068B0A9F3A8164B40
66014	58685	55.270384	55.282062000000003	54.149180999999999	54.139414000000002	 Центарльная	0103000020E610000001000000050000004BAE62F19BA24B40624D6551D8114B404BAE62F19BA24B40A017EE5C18134B40E1B88C9B1AA44B40A017EE5C18134B40E1B88C9B1AA44B40624D6551D8114B404BAE62F19BA24B40624D6551D8114B40
63590	6799	55.113016999999999	55.131199000000002	54.304983	54.289608999999999	Школьная	0103000020E610000001000000050000002E724F57778E4B404AD05FE811254B402E724F57778E4B40016BD5AE09274B404B22FB20CB904B40016BD5AE09274B404B22FB20CB904B404AD05FE811254B402E724F57778E4B404AD05FE811254B40
9682	6636	54.499504000000002	54.517927999999998	54.301206000000001	54.287754	Школьная	0103000020E61000000100000005000000501C40BFEF3F4B4087A5811FD5244B40501C40BFEF3F4B40F3AD0FEB8D264B4062D7F6764B424B40F3AD0FEB8D264B4062D7F6764B424B4087A5811FD5244B40501C40BFEF3F4B4087A5811FD5244B40
64873	5843	54.625061000000002	54.644716000000003	54.285325999999998	54.276164000000001	Центральная	0103000020E61000000100000005000000A680B4FF01504B40912A8A5759234B40A680B4FF01504B406859F78F85244B409E9ACB0D86524B406859F78F85244B409E9ACB0D86524B40912A8A5759234B40A680B4FF01504B40912A8A5759234B40
64872	69	56.277548000000003	56.323442999999997	53.792209999999997	53.762588000000001	Асфандиярова	0103000020E61000000100000005000000FD885FB186234C403929CC7B9CE14A40FD885FB186234C4036C8242367E54A40608F899466294C4036C8242367E54A40608F899466294C403929CC7B9CE14A40FD885FB186234C403929CC7B9CE14A40
66180	58723	56.528644999999997	56.544626000000001	54.307426	54.294859000000002	 Молодежная	0103000020E61000000100000005000000D218ADA3AA434C4034F790F0BD254B40D218ADA3AA434C4055F833BC59274B409146054EB6454C4055F833BC59274B409146054EB6454C4034F790F0BD254B40D218ADA3AA434C4034F790F0BD254B40
66335	3911	56.508954000000003	56.527009999999997	54.151676000000002	54.140543000000001	Школьная	0103000020E610000001000000050000008E95986725414C4043572250FD114B408E95986725414C4047CB811E6A134B401D554D1075434C4047CB811E6A134B401D554D1075434C4043572250FD114B408E95986725414C4043572250FD114B40
64017	4371	56.633963999999999	56.666266999999998	54.236499999999999	54.220174	Центральная	0103000020E61000000100000005000000B16B7BBB25514C40FAB660A92E1C4B40B16B7BBB25514C4083C0CAA1451E4B40B7B3AF3C48554C4083C0CAA1451E4B40B7B3AF3C48554C40FAB660A92E1C4B40B16B7BBB25514C40FAB660A92E1C4B40
65817	4253	56.586388999999997	56.605397000000004	54.159874000000002	54.142356999999997	30 лет Победы	0103000020E61000000100000005000000F8DD74CB0E4B4C40A7AD11C138124B40F8DD74CB0E4B4C4088BD50C076144B405B0C1EA67D4D4C4088BD50C076144B405B0C1EA67D4D4C40A7AD11C138124B40F8DD74CB0E4B4C40A7AD11C138124B40
65377	4822	56.418422	56.442982000000001	53.738720000000001	53.715898000000003	Чапаева	0103000020E61000000100000005000000A5F622DA8E354C40CBA2B08BA2DB4A40A5F622DA8E354C40587380608EDE4A40BC5B59A2B3384C40587380608EDE4A40BC5B59A2B3384C40CBA2B08BA2DB4A40A5F622DA8E354C40CBA2B08BA2DB4A40
64229	4011	56.45749	56.477404999999997	54.194406999999998	54.181472999999997	Школьная	0103000020E610000001000000050000009F1F46088F3A4C40B20DDC813A174B409F1F46088F3A4C40868E1D54E2184B4033F9669B1B3D4C40868E1D54E2184B4033F9669B1B3D4C40B20DDC813A174B409F1F46088F3A4C40B20DDC813A174B40
64871	4892	56.332363000000001	56.354480000000002	53.751179999999998	53.737696999999997	Центральная	0103000020E6100000010000000500000042B3EBDE8A2A4C40BCADF4DA6CDE4A4042B3EBDE8A2A4C4063B48EAA26E04A40058BC3995F2D4C4063B48EAA26E04A40058BC3995F2D4C40BCADF4DA6CDE4A4042B3EBDE8A2A4C40BCADF4DA6CDE4A40
66291	4892	56.332363000000001	56.354480000000002	53.751179999999998	53.737696999999997	Победы	0103000020E6100000010000000500000042B3EBDE8A2A4C40BCADF4DA6CDE4A4042B3EBDE8A2A4C4063B48EAA26E04A40058BC3995F2D4C4063B48EAA26E04A40058BC3995F2D4C40BCADF4DA6CDE4A4042B3EBDE8A2A4C40BCADF4DA6CDE4A40
64868	4669	57.091808	57.117069000000001	54.032437999999999	54.018706999999999	Центральная	0103000020E610000001000000050000006EC1525DC08B4C40679AB0FD64024B406EC1525DC08B4C40E692AAED26044B400E30F31DFC8E4C40E692AAED26044B400E30F31DFC8E4C40679AB0FD64024B406EC1525DC08B4C40679AB0FD64024B40
64870	4727	56.628734999999999	56.653070999999997	53.906458999999998	53.890638000000003	Школьный переулок	0103000020E61000000100000005000000DF6C73637A504C4095490D6D00F24A40DF6C73637A504C401A1538D906F44A40A67B9DD497534C401A1538D906F44A40A67B9DD497534C4095490D6D00F24A40DF6C73637A504C4095490D6D00F24A40
66240	3614	56.263066999999999	56.286810000000003	53.946026000000003	53.936677000000003	Школьная	0103000020E6100000010000000500000013D4F02DAC214C402CF52C08E5F74A4013D4F02DAC214C403695456117F94A403815A930B6244C403695456117F94A403815A930B6244C402CF52C08E5F74A4013D4F02DAC214C402CF52C08E5F74A40
64015	2240	56.369472999999999	56.396278000000002	53.999758999999997	53.963155999999998	Школьная	0103000020E61000000100000005000000A4E029E44A2F4C401C7920B248FB4A40A4E029E44A2F4C40DA70581AF8FF4A40E90FCD3CB9324C40DA70581AF8FF4A40E90FCD3CB9324C401C7920B248FB4A40A4E029E44A2F4C401C7920B248FB4A40
64362	2240	56.369472999999999	56.396278000000002	53.999758999999997	53.963155999999998	Центральная	0103000020E61000000100000005000000A4E029E44A2F4C401C7920B248FB4A40A4E029E44A2F4C40DA70581AF8FF4A40E90FCD3CB9324C40DA70581AF8FF4A40E90FCD3CB9324C401C7920B248FB4A40A4E029E44A2F4C401C7920B248FB4A40
64191	4124	56.683739000000003	56.718288999999999	54.098125000000003	54.074764999999999	Партизанская	0103000020E61000000100000005000000F8FF71C284574C4056F146E691094B40F8FF71C284574C40C3F5285C8F0C4B40CC09DAE4F05B4C40C3F5285C8F0C4B40CC09DAE4F05B4C4056F146E691094B40F8FF71C284574C4056F146E691094B40
64016	4124	56.683739000000003	56.718288999999999	54.098125000000003	54.074764999999999	Вахитова	0103000020E61000000100000005000000F8FF71C284574C4056F146E691094B40F8FF71C284574C40C3F5285C8F0C4B40CC09DAE4F05B4C40C3F5285C8F0C4B40CC09DAE4F05B4C4056F146E691094B40F8FF71C284574C4056F146E691094B40
65172	3663	56.216714000000003	56.241129999999998	53.911428000000001	53.897758000000003	Чапаева	0103000020E61000000100000005000000ED4ACB48BD1B4C4077DCF0BBE9F24A40ED4ACB48BD1B4C40505436ACA9F44A40D00A0C59DD1E4C40505436ACA9F44A40D00A0C59DD1E4C4077DCF0BBE9F24A40ED4ACB48BD1B4C4077DCF0BBE9F24A40
64340	33014	56.388292	56.403410999999998	53.950541000000001	53.937711	Центральная	0103000020E6100000010000000500000033A6608DB3314C40BB0CFFE906F84A4033A6608DB3314C40EA40D653ABF94A405FECBDF8A2334C40EA40D653ABF94A405FECBDF8A2334C40BB0CFFE906F84A4033A6608DB3314C40BB0CFFE906F84A40
64427	5006	56.175634000000002	56.205404000000001	53.793066000000003	53.778334999999998	Партизанская	0103000020E610000001000000050000006808C72C7B164C40842A357BA0E34A406808C72C7B164C40E7C8CA2F83E54A40DA3BA3AD4A1A4C40E7C8CA2F83E54A40DA3BA3AD4A1A4C40842A357BA0E34A406808C72C7B164C40842A357BA0E34A40
65376	4785	56.774945000000002	56.793298	53.932951000000003	53.910133999999999	Центральная	0103000020E610000001000000050000007099D36531634C40247D5A457FF44A407099D36531634C40A0E238F06AF74A40B9FDF2C98A654C40A0E238F06AF74A40B9FDF2C98A654C40247D5A457FF44A407099D36531634C40247D5A457FF44A40
64864	3393	56.277000000000001	56.298873999999998	53.848121999999996	53.829048	Кооперативная	0103000020E61000000100000005000000FA7E6ABC74234C403868AF3E1EEA4A40FA7E6ABC74234C405182FE428FEC4A40F6CFD38041264C405182FE428FEC4A40F6CFD38041264C403868AF3E1EEA4A40FA7E6ABC74234C403868AF3E1EEA4A40
63850	58138	56.517595999999998	56.532831000000002	53.932102999999998	53.917729000000001	Ключевая	0103000020E610000001000000050000002C45F29540424C409FCBD42478F54A402C45F29540424C4072C0AE264FF74A40C2A563CE33444C4072C0AE264FF74A40C2A563CE33444C409FCBD42478F54A402C45F29540424C409FCBD42478F54A40
65368	3816	56.381061000000003	56.405486000000003	54.139212999999998	54.129137999999998	Школьная	0103000020E61000000100000005000000FA635A9BC6304C40DE550F9887104B40FA635A9BC6304C40CA1649BBD1114B40317E1AF7E6334C40CA1649BBD1114B40317E1AF7E6334C40DE550F9887104B40FA635A9BC6304C40DE550F9887104B40
65369	4565	56.605378999999999	56.635769000000003	53.818626000000002	53.810003000000002	Лесная	0103000020E61000000100000005000000B4571F0F7D4D4C40B954A52DAEE74A40B4571F0F7D4D4C40E1D39CBCC8E84A40C367EBE060514C40E1D39CBCC8E84A40C367EBE060514C40B954A52DAEE74A40B4571F0F7D4D4C40B954A52DAEE74A40
64432	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	Чкалова	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
63385	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	Фрунзе	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
66823	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	Садовая	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
63666	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	Ленина	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
63389	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	Коммунистическая	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
64511	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	Комарова	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
64301	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	Калмыкова	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
64169	2641	56.434502000000002	56.502037000000001	53.915909999999997	53.874428999999999	К.Маркса	0103000020E61000000100000005000000F705F4C29D374C4045D61A4AEDEF4A40F705F4C29D374C40280AF4893CF54A40E43098BF42404C40280AF4893CF54A40E43098BF42404C4045D61A4AEDEF4A40F705F4C29D374C4045D61A4AEDEF4A40
64351	4350	56.746406	56.781340999999998	54.217509999999997	54.204335999999998	Заки Валиди	0103000020E61000000100000005000000E3C4573B8A5F4C409EB29AAE271A4B40E3C4573B8A5F4C40C746205ED71B4B4010035DFB02644C40C746205ED71B4B4010035DFB02644C409EB29AAE271A4B40E3C4573B8A5F4C409EB29AAE271A4B40
64082	4484	56.690125999999999	56.710303000000003	54.146075000000003	54.135441999999998	Центральная	0103000020E61000000100000005000000450F7C0C56584C409E40D82956114B40450F7C0C56584C40B1E1E995B2124B4017A06D35EB5A4C40B1E1E995B2124B4017A06D35EB5A4C409E40D82956114B40450F7C0C56584C409E40D82956114B40
65367	3334	56.293528999999999	56.314190000000004	53.884614999999997	53.869895	Школьная	0103000020E61000000100000005000000BBB6B75B92254C401AFA27B858EF4A40BBB6B75B92254C40884677103BF14A40795DBF6037284C40884677103BF14A40795DBF6037284C401AFA27B858EF4A40BBB6B75B92254C401AFA27B858EF4A40
64867	4469	56.748210999999998	56.772457000000003	54.146887	54.128171999999999	Колхозная	0103000020E61000000100000005000000F4C0C760C55F4C40A721AAF067104B40F4C0C760C55F4C40919A7631CD124B407C48F8DEDF624C40919A7631CD124B407C48F8DEDF624C40A721AAF067104B40F4C0C760C55F4C40A721AAF067104B40
66339	4071	56.588428	56.607903999999998	54.250616000000001	54.233179999999997	Бикташева	0103000020E610000001000000050000007D06D49B514B4C40670A9DD7D81D4B407D06D49B514B4C405BED612F14204B40C58D5BCCCF4D4C405BED612F14204B40C58D5BCCCF4D4C40670A9DD7D81D4B407D06D49B514B4C40670A9DD7D81D4B40
66340	3959	56.536262999999998	56.561343999999998	54.240763000000001	54.226748000000001	М.Гафури	0103000020E6100000010000000500000005871744A4444C407A371614061D4B4005871744A4444C401E8B6D52D11E4B4025E7C41EDA474C401E8B6D52D11E4B4025E7C41EDA474C407A371614061D4B4005871744A4444C407A371614061D4B40
66342	5018	56.219408999999999	56.232227999999999	53.729222999999998	53.711944000000003	Молодежная	0103000020E610000001000000050000005AB91798151C4C40AE4A22FB20DB4A405AB91798151C4C40D93EE42D57DD4A40959BA8A5B91D4C40D93EE42D57DD4A40959BA8A5B91D4C40AE4A22FB20DB4A405AB91798151C4C40AE4A22FB20DB4A40
64866	3712	56.458531999999998	56.484780000000001	54.140216000000002	54.121102	Казанская	0103000020E61000000100000005000000B115342DB13A4C4077BD3445800F4B40B115342DB13A4C401F300F99F2114B40A0E062450D3E4C401F300F99F2114B40A0E062450D3E4C4077BD3445800F4B40B115342DB13A4C4077BD3445800F4B40
65808	3285	56.477108999999999	56.493215999999997	54.083728999999998	54.072768000000003	Школьная	0103000020E610000001000000050000004AD05FE8113D4C4001193A7650094B404AD05FE8113D4C40075DC2A1B70A4B4095EEAEB3213F4C40075DC2A1B70A4B4095EEAEB3213F4C4001193A7650094B404AD05FE8113D4C4001193A7650094B40
66358	3285	56.477108999999999	56.493215999999997	54.083728999999998	54.072768000000003	Советская	0103000020E610000001000000050000004AD05FE8113D4C4001193A7650094B404AD05FE8113D4C40075DC2A1B70A4B4095EEAEB3213F4C40075DC2A1B70A4B4095EEAEB3213F4C4001193A7650094B404AD05FE8113D4C4001193A7650094B40
65496	3285	56.477108999999999	56.493215999999997	54.083728999999998	54.072768000000003	  Школьная	0103000020E610000001000000050000004AD05FE8113D4C4001193A7650094B404AD05FE8113D4C40075DC2A1B70A4B4095EEAEB3213F4C40075DC2A1B70A4B4095EEAEB3213F4C4001193A7650094B404AD05FE8113D4C4001193A7650094B40
66954	58194	56.219203	56.243600999999998	54.008692000000003	53.98292	Элеваторная	0103000020E61000000100000005000000B1170AD80E1C4C40CB4A9352D0FD4A40B1170AD80E1C4C4051DEC7D11C014B40EE224C512E1F4C4051DEC7D11C014B40EE224C512E1F4C40CB4A9352D0FD4A40B1170AD80E1C4C40CB4A9352D0FD4A40
64234	58194	56.219203	56.243600999999998	54.008692000000003	53.98292	Школьная	0103000020E61000000100000005000000B1170AD80E1C4C40CB4A9352D0FD4A40B1170AD80E1C4C4051DEC7D11C014B40EE224C512E1F4C4051DEC7D11C014B40EE224C512E1F4C40CB4A9352D0FD4A40B1170AD80E1C4C40CB4A9352D0FD4A40
66333	3754	56.441670000000002	56.455370000000002	54.177715999999997	54.161161	Центральная	0103000020E61000000100000005000000EACF7EA488384C40013274ECA0144B40EACF7EA488384C40EBFCDB65BF164B402ECA6C90493A4C40EBFCDB65BF164B402ECA6C90493A4C40013274ECA0144B40EACF7EA488384C40013274ECA0144B40
66238	3232	56.394392000000003	56.417892000000002	54.078257000000001	54.061947000000004	Центральная	0103000020E61000000100000005000000EBE6E26F7B324C40EC8A19E1ED074B40EBE6E26F7B324C406FD74B53040A4B4049A12C7C7D354C406FD74B53040A4B4049A12C7C7D354C40EC8A19E1ED074B40EBE6E26F7B324C40EC8A19E1ED074B40
63280	3232	56.394392000000003	56.417892000000002	54.078257000000001	54.061947000000004	Н.Крупской	0103000020E61000000100000005000000EBE6E26F7B324C40EC8A19E1ED074B40EBE6E26F7B324C406FD74B53040A4B4049A12C7C7D354C406FD74B53040A4B4049A12C7C7D354C40EC8A19E1ED074B40EBE6E26F7B324C40EC8A19E1ED074B40
64315	3562	56.266345999999999	56.292622000000001	54.006427000000002	53.981045999999999	Школьная	0103000020E61000000100000005000000D0B52FA017224C4091EF52EA92FD4A40D0B52FA017224C40DC679599D2004B40890B40A374254C40DC679599D2004B40890B40A374254C4091EF52EA92FD4A40D0B52FA017224C4091EF52EA92FD4A40
66753	1090	57.621760000000002	57.64367	53.331730999999998	53.322738000000001	Школьная	0103000020E6100000010000000500000001FBE8D495CF4C409696917A4FA94A4001FBE8D495CF4C40E108522976AA4A404AB54FC763D24C40E108522976AA4A404AB54FC763D24C409696917A4FA94A4001FBE8D495CF4C409696917A4FA94A40
66662	9346	57.526843999999997	57.549275000000002	53.184936	53.175955999999999	Агидели	0103000020E61000000100000005000000020CCB9F6FC34C407AC4E8B985964A40020CCB9F6FC34C4031ED9BFBAB974A4055C1A8A44EC64C4031ED9BFBAB974A4055C1A8A44EC64C407AC4E8B985964A40020CCB9F6FC34C407AC4E8B985964A40
66337	2007	57.409703999999998	57.448259999999998	53.125284999999998	53.083776	Школьная	0103000020E610000001000000050000002B85402E71B44C404818062CB98A4A402B85402E71B44C40F5D6C05609904A406F0D6C9560B94C40F5D6C05609904A406F0D6C9560B94C404818062CB98A4A402B85402E71B44C404818062CB98A4A40
64225	2007	57.409703999999998	57.448259999999998	53.125284999999998	53.083776	М.Гареева	0103000020E610000001000000050000002B85402E71B44C404818062CB98A4A402B85402E71B44C40F5D6C05609904A406F0D6C9560B94C40F5D6C05609904A406F0D6C9560B94C404818062CB98A4A402B85402E71B44C404818062CB98A4A40
63518	2007	57.409703999999998	57.448259999999998	53.125284999999998	53.083776	Ленина	0103000020E610000001000000050000002B85402E71B44C404818062CB98A4A402B85402E71B44C40F5D6C05609904A406F0D6C9560B94C40F5D6C05609904A406F0D6C9560B94C404818062CB98A4A402B85402E71B44C404818062CB98A4A40
64296	2007	57.409703999999998	57.448259999999998	53.125284999999998	53.083776	Кызыл-Таш	0103000020E610000001000000050000002B85402E71B44C404818062CB98A4A402B85402E71B44C40F5D6C05609904A406F0D6C9560B94C40F5D6C05609904A406F0D6C9560B94C404818062CB98A4A402B85402E71B44C404818062CB98A4A40
66330	2479	57.414096999999998	57.422773999999997	53.163378999999999	53.155804000000003	Сакмагош	0103000020E61000000100000005000000942F682101B54C40024BAE62F1934A40942F682101B54C4035ED629AE9944A40AFCC5B751DB64C4035ED629AE9944A40AFCC5B751DB64C40024BAE62F1934A40942F682101B54C40024BAE62F1934A40
65800	2077	57.567591999999998	57.585557999999999	53.233080000000001	53.222836999999998	С.Юлаева	0103000020E6100000010000000500000051BCCADAA6C84C405CAB3DEC859C4A4051BCCADAA6C84C4004ADC090D59D4A40A1F48590F3CA4C4004ADC090D59D4A40A1F48590F3CA4C405CAB3DEC859C4A4051BCCADAA6C84C405CAB3DEC859C4A40
66694	1827	57.778506999999998	57.792960999999998	53.349456000000004	53.340671999999998	Центральная	0103000020E61000000100000005000000815A0C1EA6E34C40DA54DD239BAB4A40815A0C1EA6E34C400CB265F9BAAC4A407100FDBE7FE54C400CB265F9BAAC4A407100FDBE7FE54C40DA54DD239BAB4A40815A0C1EA6E34C40DA54DD239BAB4A40
66733	784	57.646374000000002	57.661285999999997	53.070380999999998	53.063195999999998	Шаймуратова	0103000020E610000001000000050000000B7E1B62BCD24C40779E78CE16884A400B7E1B62BCD24C4040A19E3E02894A40BDA60705A5D44C4040A19E3E02894A40BDA60705A5D44C40779E78CE16884A400B7E1B62BCD24C40779E78CE16884A40
66839	2432	57.433562999999999	57.452103999999999	53.149366999999998	53.140022999999999	Школьная	0103000020E61000000100000005000000B9E00CFE7EB74C400AD80E46EC914A40B9E00CFE7EB74C40020D36751E934A4005323B8BDEB94C40020D36751E934A4005323B8BDEB94C400AD80E46EC914A40B9E00CFE7EB74C400AD80E46EC914A40
64863	2363	57.368256000000002	57.377544	53.206499000000001	53.197518000000002	З. Валиди	0103000020E6100000010000000500000024473A0323AF4C40882F134548994A4024473A0323AF4C400FD4298F6E9A4A4088669E5C53B04C400FD4298F6E9A4A4088669E5C53B04C40882F134548994A4024473A0323AF4C40882F134548994A40
66776	1957	57.539752999999997	57.547235999999998	53.240819000000002	53.231479	М.Сагитова	0103000020E610000001000000050000007D7555A016C54C40FB5A971AA19D4A407D7555A016C54C40B2A03028D39E4A40D09849D40BC64C40B2A03028D39E4A40D09849D40BC64C40FB5A971AA19D4A407D7555A016C54C40FB5A971AA19D4A40
66829	716	57.535584999999998	57.546067999999998	53.270651999999998	53.253577999999997	А.Сатвалова	0103000020E61000000100000005000000349D9D0C8EC44C40177E703E75A04A40349D9D0C8EC44C406A4C88B9A4A24A4031B2648EE5C54C406A4C88B9A4A24A4031B2648EE5C54C40177E703E75A04A40349D9D0C8EC44C40177E703E75A04A40
66909	1049	57.517654	57.529952000000002	53.345215000000003	53.338386999999997	Школьная	0103000020E6100000010000000500000061527C7C42C24C401E32E54350AB4A4061527C7C42C24C40598B4F0130AC4A4093399677D5C34C40598B4F0130AC4A4093399677D5C34C401E32E54350AB4A4061527C7C42C24C401E32E54350AB4A40
65806	1049	57.517654	57.529952000000002	53.345215000000003	53.338386999999997	Мусы Гареева	0103000020E6100000010000000500000061527C7C42C24C401E32E54350AB4A4061527C7C42C24C40598B4F0130AC4A4093399677D5C34C40598B4F0130AC4A4093399677D5C34C401E32E54350AB4A4061527C7C42C24C401E32E54350AB4A40
66728	1561	57.334676999999999	57.342429000000003	53.056041	53.051364999999997	Агидели	0103000020E6100000010000000500000098DC28B2D6AA4C405B94D92093864A4098DC28B2D6AA4C40191EFB592C874A40DB19A6B6D4AB4C40191EFB592C874A40DB19A6B6D4AB4C405B94D92093864A4098DC28B2D6AA4C405B94D92093864A40
66844	1712	57.783538	57.790131000000002	53.286718999999998	53.283661000000002	Молодежная	0103000020E610000001000000050000002D9622F94AE44C404913EF004FA44A402D9622F94AE44C4027124C35B3A44A4024473A0323E54C4027124C35B3A44A4024473A0323E54C404913EF004FA44A402D9622F94AE44C404913EF004FA44A40
66332	1377	56.946973	56.959459000000003	53.007069999999999	53.002122	Школьная	0103000020E61000000100000005000000F698486936794C40124DA08845804A40F698486936794C40306475ABE7804A402B6D718DCF7A4C40306475ABE7804A402B6D718DCF7A4C40124DA08845804A40F698486936794C40124DA08845804A40
66793	942	57.610208	57.628866000000002	53.393273999999998	53.379268000000003	З.Валиди	0103000020E61000000100000005000000F8E0B54B1BCE4C40AD3594DA8BB04A40F8E0B54B1BCE4C40FD2E6CCD56B24A407EC85BAE7ED04C40FD2E6CCD56B24A407EC85BAE7ED04C40AD3594DA8BB04A40F8E0B54B1BCE4C40AD3594DA8BB04A40
66663	1324	57.023051000000002	57.042715000000001	52.986674999999998	52.981465	Туйбага	0103000020E61000000100000005000000EF91CD55F3824C40969526A5A07D4A40EF91CD55F3824C40F163CC5D4B7E4A403A0664AF77854C40F163CC5D4B7E4A403A0664AF77854C40969526A5A07D4A40EF91CD55F3824C40969526A5A07D4A40
66907	925	57.539797999999998	57.552985	53.279995	53.275137999999998	Школьная	0103000020E610000001000000050000001D39D21918C54C4084F1D3B837A34A401D39D21918C54C4092054CE0D6A34A40DB166536C8C64C4092054CE0D6A34A40DB166536C8C64C4084F1D3B837A34A401D39D21918C54C4084F1D3B837A34A40
66813	1775	57.941740000000003	57.960918999999997	53.366455000000002	53.359045000000002	Ш.Шакмана	0103000020E61000000100000005000000E3AAB2EF8AF84C406B65C22FF5AD4A40E3AAB2EF8AF84C40543A58FFE7AE4A40718DCF64FFFA4C40543A58FFE7AE4A40718DCF64FFFA4C406B65C22FF5AD4A40E3AAB2EF8AF84C406B65C22FF5AD4A40
66711	1657	57.850318999999999	57.869821000000002	53.282153999999998	53.276935999999999	Молодежная	0103000020E610000001000000050000006E15C440D7EC4C40E38A8BA372A34A406E15C440D7EC4C40C1374D9F1DA44A40E02F664B56EF4C40C1374D9F1DA44A40E02F664B56EF4C40E38A8BA372A34A406E15C440D7EC4C40E38A8BA372A34A40
66676	1496	57.254474999999999	57.261589999999998	53.051910999999997	53.041485000000002	Школьная	0103000020E61000000100000005000000265305A392A04C40252367614F854A40265305A392A04C40BDA60705A5864A40F67AF7C77BA14C40BDA60705A5864A40F67AF7C77BA14C40252367614F854A40265305A392A04C40252367614F854A40
66701	614	57.275972000000003	57.294916999999998	53.418438999999999	53.409986000000004	Сыбайялан	0103000020E610000001000000050000004D4EED0C53A34C40B0E8D66B7AB44A404D4EED0C53A34C407B2FBE688FB54A4068041BD7BFA54C407B2FBE688FB54A4068041BD7BFA54C40B0E8D66B7AB44A404D4EED0C53A34C40B0E8D66B7AB44A40
66952	33107	57.015245	57.034638999999999	52.964165999999999	52.953941	Заповедная	0103000020E61000000100000005000000B936548CF3814C4022A81ABD1A7A4A40B936548CF3814C4023F59ECA697B4A404415FE0C6F844C4023F59ECA697B4A404415FE0C6F844C4022A81ABD1A7A4A40B936548CF3814C4022A81ABD1A7A4A40
66625	1201	57.052013000000002	57.068057000000003	53.276662000000002	53.259908000000003	Центральная	0103000020E61000000100000005000000C2FBAA5CA8864C4001FC53AA44A14A40C2FBAA5CA8864C40E20511A969A34A40C7A17E17B6884C40E20511A969A34A40C7A17E17B6884C4001FC53AA44A14A40C2FBAA5CA8864C4001FC53AA44A14A40
66773	1441	57.041727000000002	57.062631000000003	53.082889000000002	53.073735999999997	Шульган	0103000020E610000001000000050000001B2E724F57854C40D844662E70894A401B2E724F57854C405D19541B9C8A4A409F5BE84A04884C405D19541B9C8A4A409F5BE84A04884C40D844662E70894A401B2E724F57854C40D844662E70894A40
66647	563	57.194135000000003	57.214311000000002	53.543945999999998	53.533999000000001	Школьная	0103000020E6100000010000000500000026016A6AD9984C40618C48145AC44A4026016A6AD9984C401F65C405A0C54A402716F88A6E9B4C401F65C405A0C54A402716F88A6E9B4C40618C48145AC44A4026016A6AD9984C40618C48145AC44A40
66869	845	57.533222000000002	57.554791000000002	53.301918000000001	53.286459999999998	Октября	0103000020E61000000100000005000000FDC0559E40C44C405BCEA5B8AAA44A40FDC0559E40C44C407009C03FA5A64A40BD8E386403C74C407009C03FA5A64A40BD8E386403C74C405BCEA5B8AAA44A40FDC0559E40C44C405BCEA5B8AAA44A40
66840	715	57.715176	57.734552999999998	53.170580000000001	53.155096999999998	Горная	0103000020E610000001000000050000002A711DE38ADB4C40965AEF37DA934A402A711DE38ADB4C4004ADC090D5954A40DF162CD505DE4C4004ADC090D5954A40DF162CD505DE4C40965AEF37DA934A402A711DE38ADB4C40965AEF37DA934A40
66893	667	57.355373999999998	57.374768000000003	53.016182999999998	53.004696000000003	Дружбы	0103000020E61000000100000005000000A2EC2DE57CAD4C400536E7E099804A40A2EC2DE57CAD4C4026E0D74812824A402ECBD765F8AF4C4026E0D74812824A402ECBD765F8AF4C400536E7E099804A40A2EC2DE57CAD4C400536E7E099804A40
66601	459	57.333283999999999	57.351044000000002	53.467986000000003	53.453972	Школьная	0103000020E61000000100000005000000D923D40CA9AA4C405DA626C11BBA4A40D923D40CA9AA4C40317E1AF7E6BB4A4080BA8102EFAC4C40317E1AF7E6BB4A4080BA8102EFAC4C405DA626C11BBA4A40D923D40CA9AA4C405DA626C11BBA4A40
63632	459	57.333283999999999	57.351044000000002	53.467986000000003	53.453972	Р.Давлетова	0103000020E61000000100000005000000D923D40CA9AA4C405DA626C11BBA4A40D923D40CA9AA4C40317E1AF7E6BB4A4080BA8102EFAC4C40317E1AF7E6BB4A4080BA8102EFAC4C405DA626C11BBA4A40D923D40CA9AA4C405DA626C11BBA4A40
63804	459	57.333283999999999	57.351044000000002	53.467986000000003	53.453972	Ленина	0103000020E61000000100000005000000D923D40CA9AA4C405DA626C11BBA4A40D923D40CA9AA4C40317E1AF7E6BB4A4080BA8102EFAC4C40317E1AF7E6BB4A4080BA8102EFAC4C405DA626C11BBA4A40D923D40CA9AA4C405DA626C11BBA4A40
66698	1610	57.715733	57.736134	53.285254999999999	53.273904999999999	С.Мухаметкулова	0103000020E6100000010000000500000080D591239DDB4C40FE9AAC510FA34A4080D591239DDB4C409F02603C83A44A40A1BC8FA339DE4C409F02603C83A44A40A1BC8FA339DE4C40FE9AAC510FA34A4080D591239DDB4C40FE9AAC510FA34A40
66425	58771	55.343651000000001	55.376815999999998	55.806559999999998	55.795236000000003	Султанова	0103000020E610000001000000050000006D1E87C1FCAB4B400A4D124BCAE54B406D1E87C1FCAB4B408121AB5B3DE74B40054EB6813BB04B408121AB5B3DE74B40054EB6813BB04B400A4D124BCAE54B406D1E87C1FCAB4B400A4D124BCAE54B40
65662	32511	55.513835999999998	55.532584	55.865186999999999	55.855305000000001	Ключевая	0103000020E61000000100000005000000F4C0C760C5C14B407A8D5DA27AED4B40F4C0C760C5C14B4051F69672BEEE4B40BA2F67B62BC44B4051F69672BEEE4B40BA2F67B62BC44B407A8D5DA27AED4B40F4C0C760C5C14B407A8D5DA27AED4B40
64343	347	55.034126999999998	55.065280999999999	55.713836000000001	55.684742	Пинегина	0103000020E610000001000000050000008E7406465E844B404C1938A0A5D74B408E7406465E844B408E5A61FA5EDB4B406C06B8205B884B408E5A61FA5EDB4B406C06B8205B884B404C1938A0A5D74B408E7406465E844B404C1938A0A5D74B40
64793	32433	54.932563999999999	54.967140000000001	55.796247999999999	55.778309999999998	Школьная	0103000020E61000000100000005000000A6B6D4415E774B402B137EA99FE34B40A6B6D4415E774B40B1C05774EBE54B40A453573ECB7B4B40B1C05774EBE54B40A453573ECB7B4B402B137EA99FE34B40A6B6D4415E774B402B137EA99FE34B40
64678	32252	55.625397999999997	55.639474999999997	55.875723000000001	55.859554000000003	Лебединая	0103000020E61000000100000005000000ED7DAA0A0DD04B40B0928FDD05EE4B40ED7DAA0A0DD04B4071ADF6B017F04B4007CE1951DAD14B4071ADF6B017F04B4007CE1951DAD14B40B0928FDD05EE4B40ED7DAA0A0DD04B40B0928FDD05EE4B40
66228	32192	55.676161999999998	55.698143999999999	55.914045000000002	55.907147000000002	Пушкина	0103000020E610000001000000050000002366F6798CD64B400FD594641DF44B402366F6798CD64B404209336DFFF44B4006F357C85CD94B404209336DFFF44B4006F357C85CD94B400FD594641DF44B402366F6798CD64B400FD594641DF44B40
65657	31719	55.785809999999998	55.811933000000003	55.747889999999998	55.737121999999999	Мира	0103000020E61000000100000005000000546F0D6C95E44B40C09481035ADE4B40546F0D6C95E44B40B28009DCBADF4B4087C5A86BEDE74B40B28009DCBADF4B4087C5A86BEDE74B40C09481035ADE4B40546F0D6C95E44B40C09481035ADE4B40
66209	31029	55.348860999999999	55.368417000000001	55.747225999999998	55.734363999999999	Школьная	0103000020E61000000100000005000000C8EC2C7AA7AC4B400CAEB9A3FFDD4B40C8EC2C7AA7AC4B40465C001AA5DF4B402D25CB4928AF4B40465C001AA5DF4B402D25CB4928AF4B400CAEB9A3FFDD4B40C8EC2C7AA7AC4B400CAEB9A3FFDD4B40
66623	58863	55.305579999999999	55.320869000000002	55.704641000000002	55.691166000000003	Школьная	0103000020E61000000100000005000000E527D53E1DA74B40B70DA32078D84B40E527D53E1DA74B40DB3521AD31DA4B406EA6423C12A94B40DB3521AD31DA4B406EA6423C12A94B40B70DA32078D84B40E527D53E1DA74B40B70DA32078D84B40
65091	71	55.019295999999997	55.038268000000002	55.831569999999999	55.818325999999999	Школьная	0103000020E61000000100000005000000C878944A78824B40B6BB07E8BEE84B40C878944A78824B40D82AC1E270EA4B40DE3D40F7E5844B40D82AC1E270EA4B40DE3D40F7E5844B40B6BB07E8BEE84B40C878944A78824B40B6BB07E8BEE84B40
66229	32221	55.559085000000003	55.578541999999999	55.851019999999998	55.838410000000003	Школьная	0103000020E610000001000000050000009357E71890C74B40D751D50451EB4B409357E71890C74B40F71E2E39EEEC4B4064AE0CAA0DCA4B40F71E2E39EEEC4B4064AE0CAA0DCA4B40D751D50451EB4B409357E71890C74B40D751D50451EB4B40
66263	30800	55.542897000000004	55.559704000000004	55.702809999999999	55.690049999999999	Мира	0103000020E610000001000000050000005B0C1EA67DC54B406A4DF38E53D84B405B0C1EA67DC54B40A0A696ADF5D94B405FB87361A4C74B40A0A696ADF5D94B405FB87361A4C74B406A4DF38E53D84B405B0C1EA67DC54B406A4DF38E53D84B40
66231	32116	55.682037000000001	55.706021999999997	55.895772000000001	55.879944999999999	г.Тукая	0103000020E61000000100000005000000BBD408FD4CD74B40ADA3AA09A2F04B40BBD408FD4CD74B4015562AA8A8F24B40D520CCED5EDA4B4015562AA8A8F24B40D520CCED5EDA4B40ADA3AA09A2F04B40BBD408FD4CD74B40ADA3AA09A2F04B40
65058	31319	55.227058	55.264150000000001	55.568441	55.557240999999998	Школьная	0103000020E61000000100000005000000C8258E3C109D4B40C37E4FAC53C74B40C8258E3C109D4B404F5AB8ACC2C84B40849ECDAACFA14B404F5AB8ACC2C84B40849ECDAACFA14B40C37E4FAC53C74B40C8258E3C109D4B40C37E4FAC53C74B40
64660	31400	55.110734999999998	55.156863999999999	55.670304999999999	55.659658	Школьная	0103000020E61000000100000005000000E3C281902C8E4B40BB4560AC6FD44B40E3C281902C8E4B4032ACE28DCCD54B40BAF59A1E14944B4032ACE28DCCD54B40BAF59A1E14944B40BB4560AC6FD44B40E3C281902C8E4B40BB4560AC6FD44B40
65264	46467	55.556291000000002	55.573287000000001	56.011122	56.005555999999999	Школьная	0103000020E610000001000000050000009207228B34C74B40F6251B0FB6004C409207228B34C74B40102219726C014C40691CEA7761C94B40102219726C014C40691CEA7761C94B40F6251B0FB6004C409207228B34C74B40F6251B0FB6004C40
66868	46467	55.556291000000002	55.573287000000001	56.011122	56.005555999999999	Ушакова	0103000020E610000001000000050000009207228B34C74B40F6251B0FB6004C409207228B34C74B40102219726C014C40691CEA7761C94B40102219726C014C40691CEA7761C94B40F6251B0FB6004C409207228B34C74B40F6251B0FB6004C40
66852	29569	55.427922000000002	55.464564000000003	55.760807999999997	55.745189000000003	Горная	0103000020E61000000100000005000000959EE925C6B64B40632B685A62DF4B40959EE925C6B64B408044132862E14B40117349D576BB4B408044132862E14B40117349D576BB4B40632B685A62DF4B40959EE925C6B64B40632B685A62DF4B40
66534	31128	55.434057000000003	55.451511000000004	55.999898000000002	55.982456999999997	 Полевая	0103000020E61000000100000005000000C9CC052E8FB74B40F65CA626C1FD4B40C9CC052E8FB74B40FCAA5CA8FCFF4B406364C91CCBB94B40FCAA5CA8FCFF4B406364C91CCBB94B40F65CA626C1FD4B40C9CC052E8FB74B40F65CA626C1FD4B40
64656	30727	55.593283	55.609112000000003	55.781422999999997	55.776097	Школьная	0103000020E61000000100000005000000EA2285B2F0CB4B4009C3802557E34B40EA2285B2F0CB4B40CDAB3AAB05E44B40F3CCCB61F7CD4B40CDAB3AAB05E44B40F3CCCB61F7CD4B4009C3802557E34B40EA2285B2F0CB4B4009C3802557E34B40
65594	31909	55.247647999999998	55.261895000000003	55.820565999999999	55.799501999999997	Роберта Ахметгалиева	0103000020E61000000100000005000000BC75FEEDB29F4B40158BDF1456E64B40BC75FEEDB29F4B40D21A834E08E94B4033FE7DC685A14B40D21A834E08E94B4033FE7DC685A14B40158BDF1456E64B40BC75FEEDB29F4B40158BDF1456E64B40
65654	31529	55.207089000000003	55.234082999999998	55.785477999999998	55.770612999999997	Школьная	0103000020E61000000100000005000000412E71E4819A4B40AC6F6072A3E24B40412E71E4819A4B401EDD088B8AE44B4058C6866EF69D4B401EDD088B8AE44B4058C6866EF69D4B40AC6F6072A3E24B40412E71E4819A4B40AC6F6072A3E24B40
65658	31782	55.307690999999998	55.325575999999998	55.914388000000002	55.901490000000003	Школьная	0103000020E6100000010000000500000003232F6B62A74B40E5D5390664F34B4003232F6B62A74B406CED7DAA0AF54B40662E7079ACA94B406CED7DAA0AF54B40662E7079ACA94B40E5D5390664F34B4003232F6B62A74B40E5D5390664F34B40
66156	58718	55.269368999999998	55.298051999999998	55.862838000000004	55.844324	Малика Вахитова	0103000020E6100000010000000500000032C7F2AE7AA24B402C9D0FCF12EC4B4032C7F2AE7AA24B407FDFBF7971EE4B40F240649126A64B407FDFBF7971EE4B40F240649126A64B402C9D0FCF12EC4B4032C7F2AE7AA24B402C9D0FCF12EC4B40
66216	31595	55.737121999999999	55.761313000000001	55.793621999999999	55.776319999999998	Ахмета Закирова	0103000020E61000000100000005000000C09481035ADE4B40889D29745EE34B40C09481035ADE4B406CB1DB6795E54B40848252B472E14B406CB1DB6795E54B40848252B472E14B40889D29745EE34B40C09481035ADE4B40889D29745EE34B40
66527	58823	55.602150000000002	55.617044	55.897114999999999	55.887599000000002	Школьная	0103000020E61000000100000005000000A9A44E4013CD4B402D7B12D89CF14B40A9A44E4013CD4B4022E010AAD4F24B40B5183C4CFBCE4B4022E010AAD4F24B40B5183C4CFBCE4B402D7B12D89CF14B40A9A44E4013CD4B402D7B12D89CF14B40
65660	32097	55.194566000000002	55.213377000000001	55.827919000000001	55.819913999999997	Солнечная	0103000020E61000000100000005000000EF74E789E7984B402AC423F1F2E84B40EF74E789E7984B40575EF23FF9E94B40FB5B02F04F9B4B40575EF23FF9E94B40FB5B02F04F9B4B402AC423F1F2E84B40EF74E789E7984B402AC423F1F2E84B40
65069	48051	55.129420000000003	55.143110999999998	55.744768999999998	55.729036999999998	Набережная	0103000020E6100000010000000500000063B9A5D590904B4077499C1551DD4B4063B9A5D590904B408D09319754DF4B405359147651924B408D09319754DF4B405359147651924B4077499C1551DD4B4063B9A5D590904B4077499C1551DD4B40
66212	31427	55.134135999999998	55.142086999999997	55.771768000000002	55.767128999999997	Молодежная	0103000020E61000000100000005000000AE9B525E2B914B401668774831E24B40AE9B525E2B914B40B70C384BC9E24B40E71725E82F924B40B70C384BC9E24B40E71725E82F924B401668774831E24B40AE9B525E2B914B401668774831E24B40
66213	31624	55.698062999999998	55.722954999999999	55.774856	55.762104999999998	Свободы	0103000020E6100000010000000500000019C6DD205AD94B401D8F19A88CE14B4019C6DD205AD94B40008E3D7B2EE34B4066BD18CA89DC4B40008E3D7B2EE34B4066BD18CA89DC4B401D8F19A88CE14B4019C6DD205AD94B401D8F19A88CE14B40
65049	31101	55.412309	55.439663000000003	55.948487999999998	55.930714999999999	Молодежная	0103000020E61000000100000005000000596C938AC6B44B40C5724BAB21F74B40596C938AC6B44B400053060E68F94B4071218FE046B84B400053060E68F94B4071218FE046B84B40C5724BAB21F74B40596C938AC6B44B40C5724BAB21F74B40
65661	31849	55.238458000000001	55.262093	55.944046999999998	55.935142999999997	Школьная	0103000020E610000001000000050000001BBCAFCA859E4B40AA0A0DC4B2F74B401BBCAFCA859E4B4086713788D6F84B4059C16F438CA14B4086713788D6F84B4059C16F438CA14B40AA0A0DC4B2F74B401BBCAFCA859E4B40AA0A0DC4B2F74B40
64209	10311	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	Энергетиков	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
63436	10311	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	Чкалова	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
63694	10311	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	Победы	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
64048	10311	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	Пионерская	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
63565	10311	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	Магдана	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
64283	10311	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	М.Гафури	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
62317	10311	55.384677000000003	55.44021	55.855925999999997	55.825811000000002	Ленина	0103000020E61000000100000005000000FF428F183DB14B40AAD6C22CB4E94B40FF428F183DB14B40E6E5B0FB8EED4B40A3AF20CD58B84B40E6E5B0FB8EED4B40A3AF20CD58B84B40AAD6C22CB4E94B40FF428F183DB14B40AAD6C22CB4E94B40
65279	31188	55.536347999999997	55.556192000000003	55.950493999999999	55.940437000000003	Школьная	0103000020E6100000010000000500000033A31F0DA7C44B406479573D60F84B4033A31F0DA7C44B40A98592C9A9F94B40FF25A94C31C74B40A98592C9A9F94B40FF25A94C31C74B406479573D60F84B4033A31F0DA7C44B406479573D60F84B40
64259	30903	55.247297000000003	55.273150999999999	55.699350000000003	55.685665	Ленина	0103000020E6100000010000000500000010B3976DA79F4B408481E7DEC3D74B4010B3976DA79F4B40933A014D84D94B4052EFA99CF6A24B40933A014D84D94B4052EFA99CF6A24B408481E7DEC3D74B4010B3976DA79F4B408481E7DEC3D74B40
64787	30932	55.207655000000003	55.228307000000001	55.738571	55.724383000000003	Мира	0103000020E61000000100000005000000EAEC6470949A4B40A2630795B8DC4B40EAEC6470949A4B401363997E89DE4B405439ED29399D4B401363997E89DE4B405439ED29399D4B40A2630795B8DC4B40EAEC6470949A4B40A2630795B8DC4B40
63278	5884	55.714933000000002	55.729944000000003	55.826210000000003	55.815958999999999	Шакирьянова	0103000020E6100000010000000500000064EAAEEC82DB4B403DF0315871E84B4064EAAEEC82DB4B4068D0D03FC1E94B40AAF413CE6EDD4B4068D0D03FC1E94B40AAF413CE6EDD4B403DF0315871E84B4064EAAEEC82DB4B403DF0315871E84B40
63652	5884	55.714933000000002	55.729944000000003	55.826210000000003	55.815958999999999	Октябрьская	0103000020E6100000010000000500000064EAAEEC82DB4B403DF0315871E84B4064EAAEEC82DB4B4068D0D03FC1E94B40AAF413CE6EDD4B4068D0D03FC1E94B40AAF413CE6EDD4B403DF0315871E84B4064EAAEEC82DB4B403DF0315871E84B40
66345	5884	55.714933000000002	55.729944000000003	55.826210000000003	55.815958999999999	Луговая	0103000020E6100000010000000500000064EAAEEC82DB4B403DF0315871E84B4064EAAEEC82DB4B4068D0D03FC1E94B40AAF413CE6EDD4B4068D0D03FC1E94B40AAF413CE6EDD4B403DF0315871E84B4064EAAEEC82DB4B403DF0315871E84B40
65663	278	55.601027000000002	55.618679	56.080959	56.070177999999999	Гагарина	0103000020E61000000100000005000000AA81E673EECC4B400873BB97FB084C40AA81E673EECC4B408FA850DD5C0A4C406ADC9BDF30CF4B408FA850DD5C0A4C406ADC9BDF30CF4B400873BB97FB084C40AA81E673EECC4B400873BB97FB084C40
66233	210	55.581291	55.601826000000003	56.016486	56.004095999999997	Мира	0103000020E61000000100000005000000C53A55BE67CA4B40AF05BD3786004C40C53A55BE67CA4B40C26B97361C024C40F6F065A208CD4B40C26B97361C024C40F6F065A208CD4B40AF05BD3786004C40C53A55BE67CA4B40AF05BD3786004C40
66217	31830	55.352328	55.372872999999998	55.944122	55.923841000000003	Мира	0103000020E6100000010000000500000088BB7A1519AD4B401BDA006C40F64B4088BB7A1519AD4B4091B75CFDD8F84B40DC476E4DBAAF4B4091B75CFDD8F84B40DC476E4DBAAF4B401BDA006C40F64B4088BB7A1519AD4B401BDA006C40F64B40
65665	30683	55.504044999999998	55.523125	55.771245999999998	55.761107000000003	Школьная	0103000020E610000001000000050000002D5BEB8B84C04B40DBE044F46BE14B402D5BEB8B84C04B40DD955D30B8E24B40295C8FC2F5C24B40DD955D30B8E24B40295C8FC2F5C24B40DBE044F46BE14B402D5BEB8B84C04B40DBE044F46BE14B40
65775	48301	55.151311999999997	55.168559999999999	55.812776999999997	55.801475000000003	Школьная	0103000020E6100000010000000500000005BF0D315E934B40E3C798BB96E64B4005BF0D315E934B4072F8A41309E84B40F6B4C35F93954B4072F8A41309E84B40F6B4C35F93954B40E3C798BB96E64B4005BF0D315E934B40E3C798BB96E64B40
66442	58779	54.445819999999998	54.464317000000001	54.467883	54.456201999999998	 Мира	0103000020E610000001000000050000008CF337A110394B40552FBFD3643A4B408CF337A110394B405CAD1397E33B4B4009FD4CBD6E3B4B405CAD1397E33B4B4009FD4CBD6E3B4B40552FBFD3643A4B408CF337A110394B40552FBFD3643A4B40
65135	47227	54.518313999999997	54.554803999999997	54.820394999999998	54.807279000000001	Центральная	0103000020E610000001000000050000008B87F71C58424B40B1DF13EB54674B408B87F71C58424B40A5660FB402694B4051D845D103474B40A5660FB402694B4051D845D103474B40B1DF13EB54674B408B87F71C58424B40B1DF13EB54674B40
64772	28088	54.318727000000003	54.337572999999999	54.613858999999998	54.602085000000002	Центральная	0103000020E6100000010000000500000015ADDC0BCC284B40C2340C1F114D4B4015ADDC0BCC284B4079AD84EE924E4B409D819197352B4B4079AD84EE924E4B409D819197352B4B40C2340C1F114D4B4015ADDC0BCC284B40C2340C1F114D4B40
66427	58772	54.405701999999998	54.462888	54.606183999999999	54.583874000000002	Центральная	0103000020E61000000100000005000000FDF50A0BEE334B400B7E1B62BC4A4B40FDF50A0BEE334B40E2ADF36F974D4B40FDDAFAE93F3B4B40E2ADF36F974D4B40FDDAFAE93F3B4B400B7E1B62BC4A4B40FDF50A0BEE334B400B7E1B62BC4A4B40
64651	29374	54.516095999999997	54.532077000000001	54.755913	54.74747	Центральная	0103000020E6100000010000000500000057CC086F0F424B40DD5ED218AD5F4B4057CC086F0F424B4085CFD6C1C1604B4016FA60191B444B4085CFD6C1C1604B4016FA60191B444B40DD5ED218AD5F4B4057CC086F0F424B40DD5ED218AD5F4B40
65794	58630	54.657032000000001	54.675744000000002	54.910462000000003	54.903799999999997	Салавата	0103000020E610000001000000050000007636E49F19544B40F90FE9B7AF734B407636E49F19544B401920D1048A744B40EF3B86C77E564B401920D1048A744B40EF3B86C77E564B40F90FE9B7AF734B407636E49F19544B40F90FE9B7AF734B40
66546	58834	54.445819999999998	54.464317000000001	54.467883	54.456201999999998	Школьная	0103000020E610000001000000050000008CF337A110394B40552FBFD3643A4B408CF337A110394B405CAD1397E33B4B4009FD4CBD6E3B4B405CAD1397E33B4B4009FD4CBD6E3B4B40552FBFD3643A4B408CF337A110394B40552FBFD3643A4B40
64195	28106	54.351928000000001	54.394804999999998	54.710245999999998	54.686884999999997	Мостовая	0103000020E61000000100000005000000FA4509FA0B2D4B40758E01D9EB574B40FA4509FA0B2D4B40B20E4757E95A4B400DA661F888324B40B20E4757E95A4B400DA661F888324B40758E01D9EB574B40FA4509FA0B2D4B40758E01D9EB574B40
64250	29161	54.471412999999998	54.496737000000003	54.713886000000002	54.698442	60 лет СССР	0103000020E6100000010000000500000062F4DC42573C4B409013268C66594B4062F4DC42573C4B404089CF9D605B4B4049DBF813953F4B404089CF9D605B4B4049DBF813953F4B409013268C66594B4062F4DC42573C4B409013268C66594B40
64049	29752	54.541697999999997	54.589686	54.919170999999999	54.896340000000002	Революционная	0103000020E6100000010000000500000080272D5C56454B405F0CE544BB724B4080272D5C56454B403F373465A7754B405C74B2D47A4B4B403F373465A7754B405C74B2D47A4B4B405F0CE544BB724B4080272D5C56454B405F0CE544BB724B40
65477	58551	54.524746	54.549754999999998	54.512977999999997	54.502522999999997	Молодежная	0103000020E61000000100000005000000795A7EE02A434B40703E75AC52404B40795A7EE02A434B40A3C85A43A9414B40FFE7305F5E464B40A3C85A43A9414B40FFE7305F5E464B40703E75AC52404B40795A7EE02A434B40703E75AC52404B40
65474	28772	54.367083000000001	54.391086000000001	54.416268000000002	54.403503000000001	Центральная	0103000020E6100000010000000500000073F56393FC2E4B40406B7EFCA5334B4073F56393FC2E4B40882F134548354B4034F6251B0F324B40882F134548354B4034F6251B0F324B40406B7EFCA5334B4073F56393FC2E4B40406B7EFCA5334B40
66497	58807	54.182721999999998	54.843693000000002	54.990101000000003	54.306196999999997	Центральная	0103000020E610000001000000050000003E213B6F63174B4010919A7631274B403E213B6F63174B40535E2BA1BB7E4B409C6ED921FE6B4B40535E2BA1BB7E4B409C6ED921FE6B4B4010919A7631274B403E213B6F63174B4010919A7631274B40
64790	30137	54.524459	54.565314000000001	54.625588	54.600983999999997	Школьная	0103000020E61000000100000005000000E38BF67821434B40AAB5300BED4C4B40E38BF67821434B409162804413504B4048FC8A355C484B409162804413504B4048FC8A355C484B40AAB5300BED4C4B40E38BF67821434B40AAB5300BED4C4B40
66428	58773	54.439936000000003	54.474468000000002	54.63673	54.625812000000003	Казанская	0103000020E61000000100000005000000A22AA6D24F384B40E1B88C9B1A504B40A22AA6D24F384B40E8305F5E80514B40D07F0F5EBB3C4B40E8305F5E80514B40D07F0F5EBB3C4B40E1B88C9B1A504B40A22AA6D24F384B40E1B88C9B1A504B40
64331	29997	54.384259	54.425913999999999	54.825933999999997	54.806941999999999	Центральная	0103000020E61000000100000005000000CA181F662F314B4069E21DE049674B40CA181F662F314B40C5538F34B8694B404B74965984364B40C5538F34B8694B404B74965984364B4069E21DE049674B40CA181F662F314B4069E21DE049674B40
64778	29133	54.445343999999999	54.471404	54.728831	54.709750999999997	Коммунистическая	0103000020E6100000010000000500000023BC3D0801394B40D2A6EA1ED95A4B4023BC3D0801394B40CEA78E554A5D4B400F9A5DF7563C4B40CEA78E554A5D4B400F9A5DF7563C4B40D2A6EA1ED95A4B4023BC3D0801394B40D2A6EA1ED95A4B40
65679	58596	54.627764999999997	54.647500999999998	54.594824000000003	54.570749999999997	Центральная	0103000020E610000001000000050000006649809A5A504B40931804560E494B406649809A5A504B401E705D31234C4B404B901150E1524B401E705D31234C4B404B901150E1524B40931804560E494B406649809A5A504B40931804560E494B40
66207	29896	54.640988	54.666294000000001	54.968654000000001	54.950526000000004	Советская	0103000020E61000000100000005000000719010E50B524B40B5FF01D6AA794B40719010E50B524B40DE91B1DAFC7B4B40B1C22D1F49554B40DE91B1DAFC7B4B40B1C22D1F49554B40B5FF01D6AA794B40719010E50B524B40B5FF01D6AA794B40
65274	47109	54.456330999999999	54.477477	54.748213	54.738670999999997	Школьная	0103000020E610000001000000050000005393E00D693A4B4076C075C58C5E4B405393E00D693A4B4095B88E71C55F4B40CDCB61F71D3D4B4095B88E71C55F4B40CDCB61F71D3D4B4076C075C58C5E4B405393E00D693A4B4076C075C58C5E4B40
64216	29566	54.447617000000001	54.482489999999999	54.884321999999997	54.863311000000003	Мира	0103000020E610000001000000050000001B118C834B394B4077A38FF9806E4B401B118C834B394B4010919A7631714B40D252793BC23D4B4010919A7631714B40D252793BC23D4B4077A38FF9806E4B401B118C834B394B4077A38FF9806E4B40
64776	29027	54.337187	54.358953	54.764864000000003	54.749164	Идяш	0103000020E6100000010000000500000074D190F1282B4B4097AB1F9BE45F4B4074D190F1282B4B40A2F14410E7614B408AE6012CF22D4B40A2F14410E7614B408AE6012CF22D4B4097AB1F9BE45F4B4074D190F1282B4B4097AB1F9BE45F4B40
65473	58548	54.547851000000001	54.585166999999998	54.465183000000003	54.447145999999996	Школьная	0103000020E610000001000000050000005B0A48FB1F464B40C34483143C394B405B0A48FB1F464B40DDD3D51D8B3B4B4066D993C0E64A4B40DDD3D51D8B3B4B4066D993C0E64A4B40C34483143C394B405B0A48FB1F464B40C34483143C394B40
66437	58777	54.182721999999998	54.843693000000002	54.990101000000003	54.306196999999997	Школьная	0103000020E610000001000000050000003E213B6F63174B4010919A7631274B403E213B6F63174B40535E2BA1BB7E4B409C6ED921FE6B4B40535E2BA1BB7E4B409C6ED921FE6B4B4010919A7631274B403E213B6F63174B4010919A7631274B40
65060	58454	54.456394000000003	54.479435000000002	54.907133999999999	54.902470000000001	Мажита Гафури	0103000020E610000001000000050000009A0B5C1E6B3A4B4081CF0F2384734B409A0B5C1E6B3A4B407A8B87F71C744B4065C746205E3D4B407A8B87F71C744B4065C746205E3D4B4081CF0F2384734B409A0B5C1E6B3A4B4081CF0F2384734B40
65482	58552	54.486235999999998	54.499476999999999	54.410772000000001	54.404536	Центральная	0103000020E61000000100000005000000A51133FB3C3E4B40FF06EDD5C7334B40A51133FB3C3E4B40670E492D94344B40560DC2DCEE3F4B40670E492D94344B40560DC2DCEE3F4B40FF06EDD5C7334B40A51133FB3C3E4B40FF06EDD5C7334B40
66210	10805	54.595677000000002	54.629489999999997	54.891120999999998	54.870621	Ленина	0103000020E610000001000000050000005DFDD8243F4C4B40FC1A4982706F4B405DFDD8243F4C4B40B0E3BF4010724B405B94D92093504B40B0E3BF4010724B405B94D92093504B40FC1A4982706F4B405DFDD8243F4C4B40FC1A4982706F4B40
64176	28940	54.348379999999999	54.383952999999998	54.534255000000002	54.510741000000003	Ленина	0103000020E610000001000000050000004D4A41B7972C4B40F9DC09F65F414B404D4A41B7972C4B40BC5CC47762444B40BD19355F25314B40BC5CC47762444B40BD19355F25314B40F9DC09F65F414B404D4A41B7972C4B40F9DC09F65F414B40
64500	29294	54.593449999999997	54.642569000000002	54.780417999999997	54.756230000000002	Буденного	0103000020E61000000100000005000000D5E76A2BF64B4B4086200725CC604B40D5E76A2BF64B4B40D89AADBCE4634B40333674B33F524B40D89AADBCE4634B40333674B33F524B4086200725CC604B40D5E76A2BF64B4B4086200725CC604B40
64783	30052	54.460759000000003	54.486882000000001	54.818776	54.809977000000003	Центральная	0103000020E61000000100000005000000392BA226FA3A4B4090C18A53AD674B40392BA226FA3A4B40F65FE7A6CD684B406B813D26523E4B40F65FE7A6CD684B406B813D26523E4B4090C18A53AD674B40392BA226FA3A4B4090C18A53AD674B40
65651	29847	54.455925999999998	54.474035999999998	54.946829000000001	54.928691000000001	Матросова	0103000020E61000000100000005000000B3B27DC85B3A4B40768BC058DF764B40B3B27DC85B3A4B40C3F352B131794B4036902E36AD3C4B40C3F352B131794B4036902E36AD3C4B40768BC058DF764B40B3B27DC85B3A4B40768BC058DF764B40
64335	28732	54.426577999999999	54.465403999999999	54.382612999999999	54.371049999999997	Школьная	0103000020E61000000100000005000000B7989F1B9A364B402497FF907E2F4B40B7989F1B9A364B4021037976F9304B40BBB6B75B923B4B4021037976F9304B40BBB6B75B923B4B402497FF907E2F4B40B7989F1B9A364B402497FF907E2F4B40
66757	8898	54.312016	54.339154000000001	54.461095999999998	54.454076999999998	Горная	0103000020E6100000010000000500000014EAE923F0274B40D26EF4311F3A4B4014EAE923F0274B4080289831053B4B405F27F565692B4B4080289831053B4B405F27F565692B4B40D26EF4311F3A4B4014EAE923F0274B40D26EF4311F3A4B40
66204	29707	54.309635999999998	54.338318999999998	54.872838999999999	54.863864999999997	Лесная	0103000020E6100000010000000500000006D50627A2274B405B94D920936E4B4006D50627A2274B4030D63730B96F4B40C64E78094E2B4B4030D63730B96F4B40C64E78094E2B4B405B94D920936E4B4006D50627A2274B405B94D920936E4B40
66178	28454	54.664416000000003	54.681071000000003	54.556524000000003	54.539270000000002	Школьная	0103000020E6100000010000000500000036785F950B554B4062DBA2CC06454B4036785F950B554B4035B8AD2D3C474B4084A0A3552D574B4035B8AD2D3C474B4084A0A3552D574B4062DBA2CC06454B4036785F950B554B4062DBA2CC06454B40
63433	28173	54.501579	54.560302	54.586075999999998	54.556263000000001	Рабочая	0103000020E6100000010000000500000021AE9CBD33404B40C87C40A033474B4021AE9CBD33404B40397CD289044B4B4013F1D6F9B7474B40397CD289044B4B4013F1D6F9B7474B40C87C40A033474B4021AE9CBD33404B40C87C40A033474B40
62318	28173	54.501579	54.560302	54.586075999999998	54.556263000000001	Красная площадь	0103000020E6100000010000000500000021AE9CBD33404B40C87C40A033474B4021AE9CBD33404B40397CD289044B4B4013F1D6F9B7474B40397CD289044B4B4013F1D6F9B7474B40C87C40A033474B4021AE9CBD33404B40C87C40A033474B40
63337	28173	54.501579	54.560302	54.586075999999998	54.556263000000001	Кирова	0103000020E6100000010000000500000021AE9CBD33404B40C87C40A033474B4021AE9CBD33404B40397CD289044B4B4013F1D6F9B7474B40397CD289044B4B4013F1D6F9B7474B40C87C40A033474B4021AE9CBD33404B40C87C40A033474B40
66202	29010	54.366194	54.391202999999997	54.578086999999996	54.561568000000001	Колхозная	0103000020E61000000100000005000000E7FEEA71DF2E4B40753DD175E1474B40E7FEEA71DF2E4B40129F3BC1FE494B406D8C9DF012324B40129F3BC1FE494B406D8C9DF012324B40753DD175E1474B40E7FEEA71DF2E4B40753DD175E1474B40
65439	58543	54.382883999999997	54.417603999999997	54.661985000000001	54.646385000000002	  Центральная	0103000020E61000000100000005000000B114C95702314B40FFCF61BEBC524B40B114C95702314B40A6B8AAECBB544B40E256410C74354B40A6B8AAECBB544B40E256410C74354B40FFCF61BEBC524B40B114C95702314B40FFCF61BEBC524B40
65220	27130	56.667937999999999	56.692856999999997	55.301068999999998	55.287987999999999	Речная	0103000020E61000000100000005000000B9E00CFE7E554C40FAD170CADCA44B40B9E00CFE7E554C40726BD26D89A64B40FFE6C589AF584C40726BD26D89A64B40FFE6C589AF584C40FAD170CADCA44B40B9E00CFE7E554C40FAD170CADCA44B40
9626	32887	55.825111999999997	55.849932000000003	55.182855000000004	55.163620999999999	Зырянова	0103000020E61000000100000005000000C1C41F459DE94B402BF86D88F1944B40C1C41F459DE94B407E74EACA67974B4075E95F92CAEC4B407E74EACA67974B4075E95F92CAEC4B402BF86D88F1944B40C1C41F459DE94B402BF86D88F1944B40
65487	27749	56.214334000000001	56.241202000000001	55.036808999999998	55.023319999999998	Школьная	0103000020E61000000100000005000000DF35E84B6F1B4C40DEAB5626FC824B40DF35E84B6F1B4C4067994528B6844B406ADD06B5DF1E4C4067994528B6844B406ADD06B5DF1E4C40DEAB5626FC824B40DF35E84B6F1B4C40DEAB5626FC824B40
64775	46460	56.104801999999999	56.126074000000003	55.131171999999999	55.122585999999998	Горная	0103000020E610000001000000050000001747E5266A0D4C404679E6E5B08F4B401747E5266A0D4C4051137D3ECA904B401E705D3123104C4051137D3ECA904B401E705D3123104C404679E6E5B08F4B401747E5266A0D4C404679E6E5B08F4B40
66182	27292	56.447384	56.480370000000001	55.224854999999998	55.205271000000003	Молодежная	0103000020E61000000100000005000000786000E143394C409BE8F351469A4B40786000E143394C40C9AB730CC89C4B4061FD9FC37C3D4C40C9AB730CC89C4B4061FD9FC37C3D4C409BE8F351469A4B40786000E143394C409BE8F351469A4B40
65230	58502	56.223919000000002	56.252592999999997	55.352060999999999	55.336841	Советская	0103000020E61000000100000005000000FDF9B660A91C4C40D9791B9B1DAB4B40FDF9B660A91C4C403999B85510AD4B406919A9F754204C403999B85510AD4B406919A9F754204C40D9791B9B1DAB4B40FDF9B660A91C4C40D9791B9B1DAB4B40
65267	46376	56.033062999999999	56.039971000000001	55.205019	55.200626	Первомайская	0103000020E6100000010000000500000094DA8B683B044C40185DDE1CAE994B4094DA8B683B044C40810706103E9A4B40EBE40CC51D054C40810706103E9A4B40EBE40CC51D054C40185DDE1CAE994B4094DA8B683B044C40185DDE1CAE994B40
64898	58391	56.334043000000001	56.369059	55.469524999999997	55.458081999999997	Лесная	0103000020E61000000100000005000000973AC8EBC12A4C407171546EA2BA4B40973AC8EBC12A4C40C3D32B6519BC4B40B1A547533D2F4C40C3D32B6519BC4B40B1A547533D2F4C407171546EA2BA4B40973AC8EBC12A4C407171546EA2BA4B40
66191	58725	55.989511999999998	56.239513000000002	55.291930999999998	55.185934000000003	Школьная	0103000020E61000000100000005000000F17F4754A8FE4B40749B70AFCC974B40F17F4754A8FE4B4023D8B8FE5DA54B40C2FBAA5CA81E4C4023D8B8FE5DA54B40C2FBAA5CA81E4C40749B70AFCC974B40F17F4754A8FE4B40749B70AFCC974B40
64241	33023	56.082659	56.107838000000001	55.185929000000002	55.168515999999997	Советская	0103000020E610000001000000050000002BDCF291940A4C40266DAAEE91954B402BDCF291940A4C4062307F85CC974B400EA2B5A2CD0D4C4062307F85CC974B400EA2B5A2CD0D4C40266DAAEE91954B402BDCF291940A4C40266DAAEE91954B40
66571	58844	55.741073999999998	57.050961999999998	55.837772999999999	54.939838000000002	Школьная	0103000020E610000001000000050000003CF54883DBDE4B40DFC4909C4C784B403CF54883DBDE4B40643C4A253CEB4B405CAB3DEC85864C40643C4A253CEB4B405CAB3DEC85864C40DFC4909C4C784B403CF54883DBDE4B40DFC4909C4C784B40
66751	27093	56.444329000000003	56.466059999999999	55.512616999999999	55.499499	Нижняя	0103000020E610000001000000050000000BD5CDC5DF384C403EB14E95EFBF4B400BD5CDC5DF384C40D32F116F9DC14B40A4FCA4DAA73B4C40D32F116F9DC14B40A4FCA4DAA73B4C403EB14E95EFBF4B400BD5CDC5DF384C403EB14E95EFBF4B40
63899	58142	56.159824	56.196061999999998	55.054104000000002	55.036478000000002	Советская	0103000020E61000000100000005000000D68EE21C75144C400283A44FAB844B40D68EE21C75144C40994A3FE1EC864B4082FE428F18194C40994A3FE1EC864B4082FE428F18194C400283A44FAB844B40D68EE21C75144C400283A44FAB844B40
66817	32952	56.295074	56.316795999999997	55.421925000000002	55.399115999999999	Петропавловка	0103000020E6100000010000000500000030F31DFCC4254C40B9A7AB3B16B34B4030F31DFCC4254C40B22E6EA301B64B4076C075C58C284C40B22E6EA301B64B4076C075C58C284C40B9A7AB3B16B34B4030F31DFCC4254C40B9A7AB3B16B34B40
66086	58706	56.279282000000002	56.296332	55.357035000000003	55.346286999999997	 Садовая	0103000020E61000000100000005000000452E3883BF234C40D503E62153AC4B40452E3883BF234C408143A852B3AD4B400F61FC34EE254C408143A852B3AD4B400F61FC34EE254C40D503E62153AC4B40452E3883BF234C40D503E62153AC4B40
65677	58595	56.343826	56.367910000000002	55.181646999999998	55.171221000000003	Молодежная	0103000020E61000000100000005000000DBC1887D022C4C40B8B1D991EA954B40DBC1887D022C4C4050357A3540974B4089EFC4AC172F4C4050357A3540974B4089EFC4AC172F4C40B8B1D991EA954B40DBC1887D022C4C40B8B1D991EA954B40
64112	27841	56.235245999999997	56.252403999999999	54.990876	54.98368	Школьная	0103000020E61000000100000005000000E5417A8A1C1E4C4059DDEA39E97D4B40E5417A8A1C1E4C4016325706D57E4B4096B036C64E204C4016325706D57E4B4096B036C64E204C4059DDEA39E97D4B40E5417A8A1C1E4C4059DDEA39E97D4B40
66173	46035	55.922220000000003	55.949178000000003	55.254050999999997	55.233941999999999	Осиновка	0103000020E61000000100000005000000CBDB114E0BF64B409694BBCFF19D4B40CBDB114E0BF64B400F4240BE84A04B40960A2AAA7EF94B400F4240BE84A04B40960A2AAA7EF94B409694BBCFF19D4B40CBDB114E0BF64B409694BBCFF19D4B40
66838	39011	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Комарова	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63629	39011	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Кирова	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
66629	39011	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Братьев Першиных	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
63479	39011	55.943016	56.017862999999998	55.051890999999998	55.017529000000003	Баранова	0103000020E6100000010000000500000068CD8FBFB4F84B40A5DDE8633E824B4068CD8FBFB4F84B4076FA415DA4864B407B67B45549024C4076FA415DA4864B407B67B45549024C40A5DDE8633E824B4068CD8FBFB4F84B40A5DDE8633E824B40
65524	26927	56.179219000000003	56.204982000000001	55.385981000000001	55.369771	Партизанская	0103000020E6100000010000000500000032E9EFA5F0164C402E01F8A754AF4B4032E9EFA5F0164C404EF04DD367B14B406422A5D93C1A4C404EF04DD367B14B406422A5D93C1A4C402E01F8A754AF4B4032E9EFA5F0164C402E01F8A754AF4B40
63437	27162	56.359340000000003	56.399386999999997	55.339216999999998	55.310851999999997	Чернышевского	0103000020E61000000100000005000000841266DAFE2D4C40B6F292FFC9A74B40841266DAFE2D4C40A59F70766BAB4B4049B9FB1C1F334C40A59F70766BAB4B4049B9FB1C1F334C40B6F292FFC9A74B40841266DAFE2D4C40B6F292FFC9A74B40
65120	58473	56.510427	56.529687000000003	55.138989000000002	55.127059000000003	Шоссейная	0103000020E6100000010000000500000069FF03AC55414C40CCD4247843904B4069FF03AC55414C407BC03C64CA914B40E50E9BC8CC434C407BC03C64CA914B40E50E9BC8CC434C40CCD4247843904B4069FF03AC55414C40CCD4247843904B40
65772	58628	56.068770999999998	56.420963999999998	55.291828000000002	55.266471000000003	Интернациональная	0103000020E61000000100000005000000E4F4F57CCD084C408D2AC3B81BA24B40E4F4F57CCD084C404F07B29E5AA54B408C65FA25E2354C404F07B29E5AA54B408C65FA25E2354C408D2AC3B81BA24B40E4F4F57CCD084C408D2AC3B81BA24B40
66164	25775	55.074326999999997	55.105220000000003	54.933052000000004	54.914389999999997	Базарная	0103000020E61000000100000005000000DA1A118C83894B400CE544BB0A754B40DA1A118C83894B40D4BB783F6E774B404C7155D9778D4B40D4BB783F6E774B404C7155D9778D4B400CE544BB0A754B40DA1A118C83894B400CE544BB0A754B40
64653	25731	55.077058000000001	55.092858999999997	54.624228000000002	54.615620999999997	Цветочная	0103000020E6100000010000000500000095F25A09DD894B408BDD3EABCC4E4B4095F25A09DD894B40AE9FFEB3E64F4B40D311C0CDE28B4B40AE9FFEB3E64F4B40D311C0CDE28B4B408BDD3EABCC4E4B4095F25A09DD894B408BDD3EABCC4E4B40
63468	45494	55.000638000000002	55.031728999999999	54.703946000000002	54.679124000000002	Пушкина	0103000020E610000001000000050000004391EEE714804B40E0F60489ED564B404391EEE714804B4034130CE71A5A4B40DAAA24B20F844B4034130CE71A5A4B40DAAA24B20F844B40E0F60489ED564B404391EEE714804B40E0F60489ED564B40
63541	45494	55.000638000000002	55.031728999999999	54.703946000000002	54.679124000000002	Ленина	0103000020E610000001000000050000004391EEE714804B40E0F60489ED564B404391EEE714804B4034130CE71A5A4B40DAAA24B20F844B4034130CE71A5A4B40DAAA24B20F844B40E0F60489ED564B404391EEE714804B40E0F60489ED564B40
66312	4228	54.904643999999998	54.917758999999997	54.854557999999997	54.847031999999999	Центральная	0103000020E61000000100000005000000E542E55FCB734B402E55698B6B6C4B40E542E55FCB734B4080441328626D4B40094E7D2079754B4080441328626D4B40094E7D2079754B402E55698B6B6C4B40E542E55FCB734B402E55698B6B6C4B40
64239	25426	54.933812000000003	54.969987000000003	54.539572999999997	54.514938000000001	Центральная	0103000020E61000000100000005000000624ED02687774B40DCBB067DE9414B40624ED02687774B40FD6662BA10454B40C845B588287C4B40FD6662BA10454B40C845B588287C4B40DCBB067DE9414B40624ED02687774B40DCBB067DE9414B40
64676	45411	54.777513999999996	54.800251000000003	54.804445999999999	54.791170000000001	Центральная	0103000020E610000001000000050000005017299485634B40C5C9FD0E45654B405017299485634B40F2B22616F8664B40B0CBF09F6E664B40F2B22616F8664B40B0CBF09F6E664B40C5C9FD0E45654B405017299485634B40C5C9FD0E45654B40
64534	25162	55.000135	55.025044999999999	54.827562999999998	54.811673999999996	Коммуны	0103000020E61000000100000005000000E04A766C04804B40BA8102EFE4674B40E04A766C04804B4098309A95ED694B40D3F6AFAC34834B4098309A95ED694B40D3F6AFAC34834B40BA8102EFE4674B40E04A766C04804B40BA8102EFE4674B40
66317	25243	54.873283999999998	54.894888000000002	54.841349999999998	54.827500000000001	Такчуринская	0103000020E610000001000000050000005E0F26C5C76F4B4052B81E85EB694B405E0F26C5C76F4B40AB3E575BB16B4B409BCAA2B08B724B40AB3E575BB16B4B409BCAA2B08B724B4052B81E85EB694B405E0F26C5C76F4B4052B81E85EB694B40
65360	25149	54.998662000000003	55.014921000000001	54.913344000000002	54.905414999999998	Школьная	0103000020E6100000010000000500000005E10A28D47F4B40672783A3E4734B4005E10A28D47F4B40B9FFC874E8744B4006836BEEE8814B40B9FFC874E8744B4006836BEEE8814B40672783A3E4734B4005E10A28D47F4B40672783A3E4734B40
65803	25091	54.726202999999998	54.746630000000003	54.676344999999998	54.664161	Совхозная	0103000020E61000000100000005000000E8A04B38F45C4B40AB23473A03554B40E8A04B38F45C4B4014E8137992564B40331B6492915F4B4014E8137992564B40331B6492915F4B40AB23473A03554B40E8A04B38F45C4B40AB23473A03554B40
64513	24732	54.823830999999998	54.879868000000002	54.920315000000002	54.894803000000003	Центральная	0103000020E610000001000000050000002A37514B73694B406DAE9AE788724B402A37514B73694B405682C5E1CC754B400266BE839F704B405682C5E1CC754B400266BE839F704B406DAE9AE788724B402A37514B73694B406DAE9AE788724B40
65799	24828	54.777793000000003	54.813546000000002	54.912402	54.896014000000001	Киндеркульская	0103000020E61000000100000005000000640795B88E634B400B613596B0724B40640795B88E634B400A67B796C9744B4054E57B4622684B400A67B796C9744B4054E57B4622684B400B613596B0724B40640795B88E634B400B613596B0724B40
64349	24303	55.023716	55.043649000000002	54.551642000000001	54.535321000000003	А.Галиева	0103000020E610000001000000050000002B323A2009834B4057EE056685444B402B323A2009834B40CE8C7E349C464B4066C0594A96854B40CE8C7E349C464B4066C0594A96854B4057EE056685444B402B323A2009834B4057EE056685444B40
63672	24229	55.148617000000002	55.172953	54.848954999999997	54.833246000000003	Ленина	0103000020E610000001000000050000009850C1E105934B40ECC20FCEA76A4B409850C1E105934B404963B48EAA6C4B405F5FEB5223964B404963B48EAA6C4B405F5FEB5223964B40ECC20FCEA76A4B409850C1E105934B40ECC20FCEA76A4B40
64064	58161	54.780954999999999	54.806789999999999	54.678359	54.669077000000001	Ленина	0103000020E61000000100000005000000E7525C55F6634B40BEC0AC50A4554B40E7525C55F6634B4040F9BB77D4564B40B35E0CE544674B4040F9BB77D4564B40B35E0CE544674B40BEC0AC50A4554B40E7525C55F6634B40BEC0AC50A4554B40
66510	49372	54.857410000000002	54.882877999999998	54.660635999999997	54.643071999999997	 Клубная	0103000020E61000000100000005000000B6A1629CBF6D4B40957CEC2E50524B40B6A1629CBF6D4B40B6476FB88F544B40CF2D742502714B40B6476FB88F544B40CF2D742502714B40957CEC2E50524B40B6A1629CBF6D4B40957CEC2E50524B40
66398	58764	54.743603	54.776615999999997	54.568646000000001	54.552754999999998	Центральная	0103000020E610000001000000050000008F1A13622E5F4B40A9D903ADC0464B408F1A13622E5F4B4028806264C9484B4071C6302768634B4028806264C9484B4071C6302768634B40A9D903ADC0464B408F1A13622E5F4B40A9D903ADC0464B40
64861	49505	54.765863000000003	54.803134	54.870046000000002	54.853816999999999	Центральная	0103000020E61000000100000005000000B51B7DCC07624B4069E21DE0496D4B40B51B7DCC07624B400002D6AA5D6F4B4020274C18CD664B400002D6AA5D6F4B4020274C18CD664B4069E21DE0496D4B40B51B7DCC07624B4069E21DE0496D4B40
65520	25459	54.887791	54.905425000000001	54.488503999999999	54.475400999999998	Центральная	0103000020E610000001000000050000007157AF22A3714B402BBEA1F0D93C4B407157AF22A3714B408BFB8F4C873E4B408BFD65F7E4734B408BFB8F4C873E4B408BFD65F7E4734B402BBEA1F0D93C4B407157AF22A3714B402BBEA1F0D93C4B40
64423	24933	55.006028000000001	55.022584000000002	54.729906999999997	54.709516999999998	Центральная	0103000020E610000001000000050000001E6E8786C5804B405F7AFB73D15A4B401E6E8786C5804B408C0FB3976D5D4B40D9B45208E4824B408C0FB3976D5D4B40D9B45208E4824B405F7AFB73D15A4B401E6E8786C5804B405F7AFB73D15A4B40
64859	24714	55.162953999999999	55.192158999999997	54.738292000000001	54.724696999999999	Советская	0103000020E610000001000000050000004E603AADDB944B4031410DDFC25C4B404E603AADDB944B4000732D5A805E4B40E75086AA98984B4000732D5A805E4B40E75086AA98984B4031410DDFC25C4B404E603AADDB944B4031410DDFC25C4B40
66514	58812	55.129644999999996	55.150486000000001	54.791040000000002	54.778367000000003	Школьная	0103000020E61000000100000005000000828B153598904B4090A4A487A1634B40828B153598904B40F7E978CC40654B40C040102043934B40F7E978CC40654B40C040102043934B4090A4A487A1634B40828B153598904B4090A4A487A1634B40
63275	24332	54.912711000000002	54.950215	54.590234000000002	54.569198999999998	Совхозная	0103000020E6100000010000000500000088D9CBB6D3744B403CF54883DB484B4088D9CBB6D3744B405F7EA7C98C4B4B40969526A5A0794B405F7EA7C98C4B4B40969526A5A0794B403CF54883DB484B4088D9CBB6D3744B403CF54883DB484B40
66364	58708	54.893262	54.917400000000001	54.914591999999999	54.904758000000001	Центральная	0103000020E610000001000000050000003961C26856724B40AE65321CCF734B403961C26856724B407497C45911754B40DAACFA5C6D754B407497C45911754B40DAACFA5C6D754B40AE65321CCF734B403961C26856724B40AE65321CCF734B40
65359	58530	54.704571000000001	54.723498999999997	54.744056	54.732028	Речная	0103000020E61000000100000005000000E25AED612F5A4B40CEE0EF17B35D4B40E25AED612F5A4B4040321D3A3D5F4B4027D87F9D9B5C4B4040321D3A3D5F4B4027D87F9D9B5C4B40CEE0EF17B35D4B40E25AED612F5A4B40CEE0EF17B35D4B40
64823	25256	55.038699000000001	55.065486999999997	54.855666999999997	54.846907999999999	Школьная	0103000020E61000000100000005000000A7B1BD16F4844B40425C397B676C4B40A7B1BD16F4844B401AA20A7F866D4B4015A8C5E061884B401AA20A7F866D4B4015A8C5E061884B40425C397B676C4B40A7B1BD16F4844B40425C397B676C4B40
65635	23693	55.141018000000003	55.170473000000001	55.283523000000002	55.268825	Радужная	0103000020E61000000100000005000000DC12B9E00C924B4071AC8BDB68A24B40DC12B9E00C924B40F8544E7B4AA44B40EEEC2B0FD2954B40F8544E7B4AA44B40EEEC2B0FD2954B4071AC8BDB68A24B40DC12B9E00C924B4071AC8BDB68A24B40
66391	58763	55.675282000000003	55.701988999999998	55.2836	55.265861000000001	Коммунистическая	0103000020E61000000100000005000000EBC9FCA36FD64B401424B6BB07A24B40EBC9FCA36FD64B40A3923A014DA44B406C938AC6DAD94B40A3923A014DA44B406C938AC6DAD94B401424B6BB07A24B40EBC9FCA36FD64B401424B6BB07A24B40
64429	33124	55.691343000000003	55.707172	55.434649999999998	55.420836999999999	Антипина	0103000020E61000000100000005000000C6A86BED7DD84B402FF99FFCDDB54B40C6A86BED7DD84B406B9A779CA2B74B40CE52B29C84DA4B406B9A779CA2B74B40CE52B29C84DA4B402FF99FFCDDB54B40C6A86BED7DD84B402FF99FFCDDB54B40
64167	23343	55.608007000000001	55.629818	55.445436000000001	55.434773	Школьная	0103000020E610000001000000050000009A5E622CD3CD4B40871744A4A6B74B409A5E622CD3CD4B40043BFE0B04B94B40503750E09DD04B40043BFE0B04B94B40503750E09DD04B40871744A4A6B74B409A5E622CD3CD4B40871744A4A6B74B40
64067	23868	55.303738000000003	55.323708000000003	55.308874000000003	55.295893	Комарова	0103000020E61000000100000005000000B74604E3E0A64B40C30E63D2DFA54B40B74604E3E0A64B40D84AE82E89A74B400FBA84436FA94B40D84AE82E89A74B400FBA84436FA94B40C30E63D2DFA54B40B74604E3E0A64B40C30E63D2DFA54B40
64356	23815	55.512112000000002	55.534264	55.331152000000003	55.318024000000001	Восточная	0103000020E61000000100000005000000D0F1D1E28CC14B40EBABAB02B5A84B40D0F1D1E28CC14B40A400513063AA4B400FB743C362C44B40A400513063AA4B400FB743C362C44B40EBABAB02B5A84B40D0F1D1E28CC14B40EBABAB02B5A84B40
63726	48932	55.543849000000002	55.569037999999999	55.404611000000003	55.388644999999997	Гагарина	0103000020E610000001000000050000002D7B12D89CC54B4080608E1EBFB14B402D7B12D89CC54B400A4D124BCAB34B403317B83CD6C84B400A4D124BCAB34B403317B83CD6C84B4080608E1EBFB14B402D7B12D89CC54B4080608E1EBFB14B40
64080	23891	55.498663999999998	55.526088999999999	55.246609999999997	55.231406	Мира	0103000020E61000000100000005000000A5D8D138D4BF4B40910C39B69E9D4B40A5D8D138D4BF4B40EB6E9EEA909F4B4086E464E256C34B40EB6E9EEA909F4B4086E464E256C34B40910C39B69E9D4B40A5D8D138D4BF4B40910C39B69E9D4B40
64856	49053	55.325657	55.356729999999999	55.225594000000001	55.211373000000002	Советская	0103000020E61000000100000005000000535BEA20AFA94B40F3203D450E9B4B40535BEA20AFA94B404016A243E09C4B4044C02154A9AD4B404016A243E09C4B4044C02154A9AD4B40F3203D450E9B4B40535BEA20AFA94B40F3203D450E9B4B40
64517	33100	55.714672999999998	55.738658000000001	55.369587000000003	55.354497000000002	Овчинникова	0103000020E61000000100000005000000C72AA5677ADB4B40DBC35E2860AD4B40C72AA5677ADB4B406D0377A04EAF4B40E27668588CDE4B406D0377A04EAF4B40E27668588CDE4B40DBC35E2860AD4B40C72AA5677ADB4B40DBC35E2860AD4B40
64854	23212	55.248303	55.279439000000004	55.518977999999997	55.505526000000003	Ленина	0103000020E61000000100000005000000D53F8864C89F4B408CA37213B5C04B40D53F8864C89F4B40F7AB00DF6DC24B400D1D3BA8C4A34B40F7AB00DF6DC24B400D1D3BA8C4A34B408CA37213B5C04B40D53F8864C89F4B408CA37213B5C04B40
66280	23092	55.423349000000002	55.443292	55.510067999999997	55.501983000000003	Красноармейская	0103000020E61000000100000005000000ACE5CE4C30B64B40F1129CFA40C04B40ACE5CE4C30B64B40395E81E849C14B400A4AD1CABDB84B40395E81E849C14B400A4AD1CABDB84B40F1129CFA40C04B40ACE5CE4C30B64B40F1129CFA40C04B40
65652	49082	55.596525999999997	55.621777999999999	55.400103000000001	55.384670999999997	Октябрьская	0103000020E610000001000000050000005A9BC6F65ACC4B401C5C3AE63CB14B405A9BC6F65ACC4B4008043A9336B34B40A7AFE76B96CF4B4008043A9336B34B40A7AFE76B96CF4B401C5C3AE63CB14B405A9BC6F65ACC4B401C5C3AE63CB14B40
64857	23622	55.209864000000003	55.234020000000001	55.251742	55.241863000000002	Свердлова	0103000020E61000000100000005000000CB4DD4D2DC9A4B40658EE55DF59E4B40CB4DD4D2DC9A4B40CB83F41439A04B40124E0B5EF49D4B40CB83F41439A04B40124E0B5EF49D4B40658EE55DF59E4B40CB4DD4D2DC9A4B40658EE55DF59E4B40
65365	24045	55.833601000000002	55.852780000000003	55.409370000000003	55.389769999999999	Школьная	0103000020E61000000100000005000000DA740470B3EA4B40207BBDFBE3B14B40DA740470B3EA4B4055FB743C66B44B40695721E527ED4B4055FB743C66B44B40695721E527ED4B40207BBDFBE3B14B40DA740470B3EA4B40207BBDFBE3B14B40
64956	19342	55.365344999999998	55.388198000000003	55.409610000000001	55.395778	Новосктройки	0103000020E61000000100000005000000E960FD9FC3AE4B40F73C7FDAA8B24B40E960FD9FC3AE4B40AA0EB9196EB44B40B22FD978B0B14B40AA0EB9196EB44B40B22FD978B0B14B40F73C7FDAA8B24B40E960FD9FC3AE4B40F73C7FDAA8B24B40
66482	58797	55.173212999999997	55.194457999999997	55.365422000000002	55.352300999999997	 Ленина	0103000020E61000000100000005000000FB1EF5D72B964B408EACFC3218AD4B40FB1EF5D72B964B40959EE925C6AE4B400839EFFFE3984B40959EE925C6AE4B400839EFFFE3984B408EACFC3218AD4B40FB1EF5D72B964B408EACFC3218AD4B40
66517	58814	55.451287000000001	55.460180000000001	55.398660999999997	55.393906000000001	Школьная	0103000020E61000000100000005000000130EBDC5C3B94B405ED905836BB24B40130EBDC5C3B94B406798DA5207B34B40FB22A12DE7BA4B406798DA5207B34B40FB22A12DE7BA4B405ED905836BB24B40130EBDC5C3B94B405ED905836BB24B40
63659	23418	55.738630999999998	55.755420000000001	55.250976999999999	55.235339000000003	Калинина	0103000020E61000000100000005000000E867EA758BDE4B40973C9E961F9E4B40E867EA758BDE4B402B86AB0320A04B40465F419AB1E04B402B86AB0320A04B40465F419AB1E04B40973C9E961F9E4B40E867EA758BDE4B40973C9E961F9E4B40
66329	23772	55.890903999999999	55.916739999999997	55.368267000000003	55.359051999999998	Антипина	0103000020E6100000010000000500000013F06B2409F24B401DC87A6AF5AD4B4013F06B2409F24B401899805F23AF4B40AF777FBC57F54B401899805F23AF4B40AF777FBC57F54B401DC87A6AF5AD4B4013F06B2409F24B401DC87A6AF5AD4B40
64853	23167	55.36018	55.377884999999999	55.476419	55.466182000000003	Тукая	0103000020E610000001000000050000002E56D4601AAE4B40F0FD0DDAABBB4B402E56D4601AAE4B40B5183C4CFBBC4B40115322895EB04B40B5183C4CFBBC4B40115322895EB04B40F0FD0DDAABBB4B402E56D4601AAE4B40F0FD0DDAABBB4B40
63403	22315	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Чеверева	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63773	22315	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Пролетарская	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63796	22315	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Овчинникова	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
63580	22315	55.517941999999998	55.575102000000001	55.450803000000001	55.402838000000003	Мира	0103000020E61000000100000005000000C79C67EC4BC24B4004CB113290B34B40C79C67EC4BC24B4027F8A6E9B3B94B409EEE3CF19CC94B4027F8A6E9B3B94B409EEE3CF19CC94B4004CB113290B34B40C79C67EC4BC24B4004CB113290B34B40
66326	23962	55.569774000000002	55.582144	55.231960999999998	55.218671999999998	Молодежная	0103000020E61000000100000005000000390EBC5AEEC84B408446B071FD9B4B40390EBC5AEEC84B404679E6E5B09D4B4004C8D0B183CA4B404679E6E5B09D4B4004C8D0B183CA4B408446B071FD9B4B40390EBC5AEEC84B408446B071FD9B4B40
64508	23074	55.457808	55.477760000000004	55.545284000000002	55.529654000000001	Памфилова	0103000020E6100000010000000500000070ECD97399BA4B400919C8B3CBC34B4070ECD97399BA4B401B84B9DDCBC54B4022AB5B3D27BD4B401B84B9DDCBC54B4022AB5B3D27BD4B400919C8B3CBC34B4070ECD97399BA4B400919C8B3CBC34B40
64020	33043	55.578406999999999	55.595151999999999	55.497118	55.485984000000002	Мира	0103000020E610000001000000050000008463963D09CA4B408C3045B934BE4B408463963D09CA4B4060200890A1BF4B401213D4F02DCC4B4060200890A1BF4B401213D4F02DCC4B408C3045B934BE4B408463963D09CA4B408C3045B934BE4B40
66363	58754	55.254834000000002	55.260807999999997	55.380865999999997	55.376744000000002	Школьная	0103000020E6100000010000000500000056F487669EA04B406C7BBB2539B04B4056F487669EA04B4044149337C0B04B408044132862A14B4044149337C0B04B408044132862A14B406C7BBB2539B04B4056F487669EA04B406C7BBB2539B04B40
65796	23582	55.268920000000001	55.286256999999999	55.350192	55.341755999999997	Школьная	0103000020E61000000100000005000000C39E76F86BA24B401B9B1DA9BEAB4B40C39E76F86BA24B4011A96917D3AC4B4023A0C211A4A44B4011A96917D3AC4B4023A0C211A4A44B401B9B1DA9BEAB4B40C39E76F86BA24B401B9B1DA9BEAB4B40
65138	48261	54.283377999999999	54.303823999999999	53.416566000000003	53.402594999999998	Центральная	0103000020E61000000100000005000000F433F5BA45244B403D44A33B88B34A40F433F5BA45244B401250E10852B54A40B5DE6FB4E3264B401250E10852B54A40B5DE6FB4E3264B403D44A33B88B34A40F433F5BA45244B403D44A33B88B34A40
64231	58193	53.984095000000003	54.002294999999997	53.741067999999999	53.730656000000003	Центральная	0103000020E610000001000000050000001D9430D3F6FD4A402750C42286DD4A401D9430D3F6FD4A405A0EF450DBDE4A40DFF8DA334B004B405A0EF450DBDE4A40DFF8DA334B004B402750C42286DD4A401D9430D3F6FD4A402750C42286DD4A40
66729	20871	54.118205000000003	54.135848000000003	53.712769999999999	53.701129000000002	Центральная	0103000020E61000000100000005000000A29C6857210F4B407BA35698BED94A40A29C6857210F4B40F3C81F0C3CDB4A400F9D9E7763114B40F3C81F0C3CDB4A400F9D9E7763114B407BA35698BED94A40A29C6857210F4B407BA35698BED94A40
65801	58633	54.009509000000001	54.019516000000003	53.5852	53.577314999999999	Молодежная	0103000020E610000001000000050000004302469737014B40C03E3A75E5C94A404302469737014B4042CF66D5E7CA4A40D7DF12807F024B4042CF66D5E7CA4A40D7DF12807F024B40C03E3A75E5C94A404302469737014B40C03E3A75E5C94A40
66926	32902	54.129711999999998	54.145845999999999	53.907328	53.903944000000003	Девонская	0103000020E610000001000000050000000AF31E679A104B402DB5DE6FB4F34A400AF31E679A104B405F5FEB5223F44A404F20EC14AB124B405F5FEB5223F44A404F20EC14AB124B402DB5DE6FB4F34A400AF31E679A104B402DB5DE6FB4F34A40
64851	21889	54.310220000000001	54.327610999999997	53.886270000000003	53.865625999999999	Центральная	0103000020E610000001000000050000005648F949B5274B409D4830D5CCEE4A405648F949B5274B4085B69C4B71F14A40A9674128EF294B4085B69C4B71F14A40A9674128EF294B409D4830D5CCEE4A405648F949B5274B409D4830D5CCEE4A40
65351	21445	54.064036000000002	54.095647999999997	53.666493000000003	53.650064	переулок Школьный	0103000020E6100000010000000500000022E2E65432084B404A27124C35D34A4022E2E65432084B40A80183A44FD54A40C2F693313E0C4B40A80183A44FD54A40C2F693313E0C4B404A27124C35D34A4022E2E65432084B404A27124C35D34A40
66324	21991	54.187842000000003	54.197336999999997	53.984772999999997	53.970767000000002	Шоссейная	0103000020E610000001000000050000005A68E7340B184B409D84D21742FC4A405A68E7340B184B40ED7DAA0A0DFE4A4037A5BC5642194B40ED7DAA0A0DFE4A4037A5BC5642194B409D84D21742FC4A405A68E7340B184B409D84D21742FC4A40
65345	21503	53.996060999999997	54.012203999999997	53.663842000000002	53.645319000000001	Центральная	0103000020E6100000010000000500000018E945ED7EFF4A40643E20D099D24A4018E945ED7EFF4A400ADB4FC6F8D44A40B07092E68F014B400ADB4FC6F8D44A40B07092E68F014B40643E20D099D24A4018E945ED7EFF4A40643E20D099D24A40
64221	21734	54.424629000000003	54.457031000000001	53.722254999999997	53.712535000000003	Центральная	0103000020E6100000010000000500000073F7393E5A364B40B020CD5834DB4A4073F7393E5A364B40AD2F12DA72DC4A400C21E7FD7F3A4B40AD2F12DA72DC4A400C21E7FD7F3A4B40B020CD5834DB4A4073F7393E5A364B40B020CD5834DB4A40
64083	21792	54.216327999999997	54.246555999999998	53.926690000000001	53.900655	МТМ	0103000020E61000000100000005000000C39ACAA2B01B4B404CFDBCA948F34A40C39ACAA2B01B4B40DFC325C79DF64A40F850A2258F1F4B40DFC325C79DF64A40F850A2258F1F4B404CFDBCA948F34A40C39ACAA2B01B4B404CFDBCA948F34A40
65341	20369	54.250822999999997	54.289054999999998	53.814681	53.803356999999998	Школьная	0103000020E61000000100000005000000D40AD3F71A204B409F01F566D4E64A40D40AD3F71A204B4017D68D7747E84A4065DF15C1FF244B4017D68D7747E84A4065DF15C1FF244B409F01F566D4E64A40D40AD3F71A204B409F01F566D4E64A40
63571	21686	54.388409000000003	54.421692	53.682676000000001	53.668846000000002	Центральная	0103000020E610000001000000050000006D3CD862B7314B40BC07E8BE9CD54A406D3CD862B7314B40CEE15AED61D74A400F7EE200FA354B40CEE15AED61D74A400F7EE200FA354B40BC07E8BE9CD54A406D3CD862B7314B40BC07E8BE9CD54A40
66325	21358	54.292721	54.30509	53.526029000000001	53.514727999999998	Салавата Юлаева	0103000020E610000001000000050000001CEDB8E177254B40F12A6B9BE2C14A401CEDB8E177254B40B1DF13EB54C34A40172B6A300D274B40B1DF13EB54C34A40172B6A300D274B40F12A6B9BE2C14A401CEDB8E177254B40F12A6B9BE2C14A40
65790	46048	54.154048000000003	54.175480999999998	53.559139000000002	53.552864999999997	Подлесная	0103000020E61000000100000005000000D20149D8B7134B40300DC347C4C64A40D20149D8B7134B408675E3DD91C74A40E108522976164B408675E3DD91C74A40E108522976164B40300DC347C4C64A40D20149D8B7134B40300DC347C4C64A40
66308	17178	54.145909000000003	54.163021999999998	53.426537000000003	53.40945	Коммунистическая	0103000020E6100000010000000500000096986725AD124B4071AC8BDB68B44A4096986725AD124B4059C4B0C398B64A40A643A7E7DD144B4059C4B0C398B64A40A643A7E7DD144B4071AC8BDB68B44A4096986725AD124B4071AC8BDB68B44A40
66774	27037	53.820349999999998	53.837049999999998	53.729259999999996	53.711858999999997	Речная	0103000020E6100000010000000500000005A3923A01E94A407F2E1A321EDB4A4005A3923A01E94A40F623456458DD4A40F38E537424EB4A40F623456458DD4A40F38E537424EB4A407F2E1A321EDB4A4005A3923A01E94A407F2E1A321EDB4A40
64849	27037	53.820349999999998	53.837049999999998	53.729259999999996	53.711858999999997	Мусы Джалиля	0103000020E6100000010000000500000005A3923A01E94A407F2E1A321EDB4A4005A3923A01E94A40F623456458DD4A40F38E537424EB4A40F623456458DD4A40F38E537424EB4A407F2E1A321EDB4A4005A3923A01E94A407F2E1A321EDB4A40
65863	58646	54.122849000000002	54.139746000000002	53.654066	53.629634000000003	Центральная	0103000020E6100000010000000500000054AC1A84B90F4B408F39CFD897D04A4054AC1A84B90F4B4078B6476FB8D34A4098DF6932E3114B4078B6476FB8D34A4098DF6932E3114B408F39CFD897D04A4054AC1A84B90F4B408F39CFD897D04A40
64180	21318	54.244993000000001	54.271538	53.542282	53.528281999999997	Центральная	0103000020E61000000100000005000000DD5F3DEE5B1F4B4061889CBE9EC34A40DD5F3DEE5B1F4B40D09A1F7F69C54A4085CFD6C1C1224B40D09A1F7F69C54A4085CFD6C1C1224B4061889CBE9EC34A40DD5F3DEE5B1F4B4061889CBE9EC34A40
66696	20825	54.197660999999997	54.215259000000003	53.656238000000002	53.642442000000003	Чкалова	0103000020E61000000100000005000000EA58A5F44C194B40D6C9198A3BD24A40EA58A5F44C194B403C32569BFFD34A40B8955E9B8D1B4B403C32569BFFD34A40B8955E9B8D1B4B40D6C9198A3BD24A40EA58A5F44C194B40D6C9198A3BD24A40
64746	47927	54.349134999999997	54.364846	53.740110000000001	53.734017000000001	Центральная	0103000020E61000000100000005000000C971A774B02C4B40A1DAE044F4DD4A40C971A774B02C4B40A6B8AAECBBDE4A40C8091346B32E4B40A6B8AAECBBDE4A40C8091346B32E4B40A1DAE044F4DD4A40C971A774B02C4B40A1DAE044F4DD4A40
64659	15694	54.173388000000003	54.193492999999997	53.488959999999999	53.476722000000002	Центральная	0103000020E610000001000000050000006AC2F69331164B4051A4FB3905BD4A406AC2F69331164B40AD86C43D96BE4A40A180ED60C4184B40AD86C43D96BE4A40A180ED60C4184B4051A4FB3905BD4A406AC2F69331164B4051A4FB3905BD4A40
64404	21034	54.438597999999999	54.471153000000001	53.546926999999997	53.529133000000002	Центральная	0103000020E61000000100000005000000A60BB1FA23384B40001E51A1BAC34A40A60BB1FA23384B40522635B401C64A40C634D3BD4E3C4B40522635B401C64A40C634D3BD4E3C4B40001E51A1BAC34A40A60BB1FA23384B40001E51A1BAC34A40
66305	20942	54.301541999999998	54.313623999999997	53.633676000000001	53.623071000000003	Центральная	0103000020E610000001000000050000006A2FA2ED98264B40030B60CAC0CF4A406A2FA2ED98264B404B21904B1CD14A40CF9ECBD424284B404B21904B1CD14A40CF9ECBD424284B40030B60CAC0CF4A406A2FA2ED98264B40030B60CAC0CF4A40
65769	48269	54.290725999999999	54.322355999999999	53.503037999999997	53.494784000000003	Садовая	0103000020E61000000100000005000000670C738236254B40C34A051555BF4A40670C738236254B409752978C63C04A40AED51EF642294B409752978C63C04A40AED51EF642294B40C34A051555BF4A40670C738236254B40C34A051555BF4A40
66687	20446	54.247320000000002	54.287852000000001	53.707574000000001	53.687261999999997	Трудовая	0103000020E61000000100000005000000C8D2872EA81F4B404BE48233F8D74A40C8D2872EA81F4B40FDBFEAC891DA4A404A0B9755D8244B40FDBFEAC891DA4A404A0B9755D8244B404BE48233F8D74A40C8D2872EA81F4B404BE48233F8D74A40
64224	20446	54.247320000000002	54.287852000000001	53.707574000000001	53.687261999999997	Спортивная	0103000020E61000000100000005000000C8D2872EA81F4B404BE48233F8D74A40C8D2872EA81F4B40FDBFEAC891DA4A404A0B9755D8244B40FDBFEAC891DA4A404A0B9755D8244B404BE48233F8D74A40C8D2872EA81F4B404BE48233F8D74A40
64078	20446	54.247320000000002	54.287852000000001	53.707574000000001	53.687261999999997	Пушкина	0103000020E61000000100000005000000C8D2872EA81F4B404BE48233F8D74A40C8D2872EA81F4B40FDBFEAC891DA4A404A0B9755D8244B40FDBFEAC891DA4A404A0B9755D8244B404BE48233F8D74A40C8D2872EA81F4B404BE48233F8D74A40
64076	20239	54.262681000000001	54.305207000000003	53.760071000000003	53.732643000000003	Центральная	0103000020E61000000100000005000000EA23F0879F214B405952EE3EC7DD4A40EA23F0879F214B40ABD1AB014AE14A4051C1E10511274B40ABD1AB014AE14A4051C1E10511274B405952EE3EC7DD4A40EA23F0879F214B405952EE3EC7DD4A40
64372	20053	54.186593999999999	54.225454999999997	53.534646000000002	53.519883	Фатиха Карима	0103000020E610000001000000050000009ED0EB4FE2174B40895FB1868BC24A409ED0EB4FE2174B40F777B6476FC44A401EDC9DB5DB1C4B40F777B6476FC44A401EDC9DB5DB1C4B40895FB1868BC24A409ED0EB4FE2174B40895FB1868BC24A40
66056	27363	54.385939	54.408253000000002	53.500884999999997	53.485788999999997	Центральная	0103000020E610000001000000050000001FA0FB7266314B40D6E07D552EBE4A401FA0FB7266314B404A07EBFF1CC04A4038BF61A241344B404A07EBFF1CC04A4038BF61A241344B40D6E07D552EBE4A401FA0FB7266314B40D6E07D552EBE4A40
66318	19787	58.192846000000003	58.212600000000002	53.810572000000001	53.796379000000002	Школьная	0103000020E610000001000000050000000C957F2DAF184D40501C40BFEFE54A400C957F2DAF184D40D386C3D2C0E74A4097900F7A361B4D40D386C3D2C0E74A4097900F7A361B4D40501C40BFEFE54A400C957F2DAF184D40501C40BFEFE54A40
64970	19955	58.234563999999999	58.249448999999998	53.73122	53.721705999999998	Молодежная	0103000020E61000000100000005000000D3687231061E4D40DAA9B9DC60DC4A40D3687231061E4D402F17F19D98DD4A408C82E0F1ED1F4D402F17F19D98DD4A408C82E0F1ED1F4D40DAA9B9DC60DC4A40D3687231061E4D40DAA9B9DC60DC4A40
66321	19893	58.228231000000001	58.249754000000003	53.780090999999999	53.766793	Школьная	0103000020E61000000100000005000000797764AC361D4D409FE6E44526E24A40797764AC361D4D40B4739A05DAE34A40C90567F0F71F4D40B4739A05DAE34A40C90567F0F71F4D409FE6E44526E24A40797764AC361D4D409FE6E44526E24A40
64850	19841	58.221305000000001	58.252881000000002	53.686664999999998	53.672964	Янгиреева	0103000020E610000001000000050000007CB8E4B8531C4D4053B131AF23D64A407CB8E4B8531C4D40672783A3E4D74A40D06394675E204D40672783A3E4D74A40D06394675E204D4053B131AF23D64A407CB8E4B8531C4D4053B131AF23D64A40
64951	19714	57.845018000000003	57.884310999999997	53.706555999999999	53.686404000000003	Портнова	0103000020E610000001000000050000000344C18C29EC4C40FBEB1516DCD74A400344C18C29EC4C407365506D70DA4A401C3F541A31F14C407365506D70DA4A401C3F541A31F14C40FBEB1516DCD74A400344C18C29EC4C40FBEB1516DCD74A40
64226	19714	57.845018000000003	57.884310999999997	53.706555999999999	53.686404000000003	Победы	0103000020E610000001000000050000000344C18C29EC4C40FBEB1516DCD74A400344C18C29EC4C407365506D70DA4A401C3F541A31F14C407365506D70DA4A401C3F541A31F14C40FBEB1516DCD74A400344C18C29EC4C40FBEB1516DCD74A40
64426	19550	57.430284	57.492024999999998	53.855569000000003	53.828420999999999	Матросова	0103000020E61000000100000005000000FCFECD8B13B74C40E92807B309EA4A40FCFECD8B13B74C40583CF54883ED4A403EE8D9ACFABE4C40583CF54883ED4A403EE8D9ACFABE4C40E92807B309EA4A40FCFECD8B13B74C40E92807B309EA4A40
64292	19550	57.430284	57.492024999999998	53.855569000000003	53.828420999999999	Горького	0103000020E61000000100000005000000FCFECD8B13B74C40E92807B309EA4A40FCFECD8B13B74C40583CF54883ED4A403EE8D9ACFABE4C40583CF54883ED4A403EE8D9ACFABE4C40E92807B309EA4A40FCFECD8B13B74C40E92807B309EA4A40
64003	19277	58.551291999999997	58.608012000000002	54.228022000000003	54.187010999999998	проезд Дзержинского	0103000020E61000000100000005000000F1457BBC90464D40027FF8F9EF174B40F1457BBC90464D405F622CD32F1D4B40ACC95356D34D4D405F622CD32F1D4B40ACC95356D34D4D40027FF8F9EF174B40F1457BBC90464D40027FF8F9EF174B40
64012	19277	58.551291999999997	58.608012000000002	54.228022000000003	54.187010999999998	Советская	0103000020E61000000100000005000000F1457BBC90464D40027FF8F9EF174B40F1457BBC90464D405F622CD32F1D4B40ACC95356D34D4D405F622CD32F1D4B40ACC95356D34D4D40027FF8F9EF174B40F1457BBC90464D40027FF8F9EF174B40
64230	19277	58.551291999999997	58.608012000000002	54.228022000000003	54.187010999999998	Первомайская	0103000020E61000000100000005000000F1457BBC90464D40027FF8F9EF174B40F1457BBC90464D405F622CD32F1D4B40ACC95356D34D4D405F622CD32F1D4B40ACC95356D34D4D40027FF8F9EF174B40F1457BBC90464D40027FF8F9EF174B40
64223	19277	58.551291999999997	58.608012000000002	54.228022000000003	54.187010999999998	Коммунистическая	0103000020E61000000100000005000000F1457BBC90464D40027FF8F9EF174B40F1457BBC90464D405F622CD32F1D4B40ACC95356D34D4D405F622CD32F1D4B40ACC95356D34D4D40027FF8F9EF174B40F1457BBC90464D40027FF8F9EF174B40
64213	19201	58.284267999999997	58.303995	53.862302	53.849541000000002	Центральная	0103000020E6100000010000000500000050A6D1E462244D403ACE6DC2BDEC4A4050A6D1E462244D4040A374E95FEE4A40E292E34EE9264D4040A374E95FEE4A40E292E34EE9264D403ACE6DC2BDEC4A4050A6D1E462244D403ACE6DC2BDEC4A40
63267	19137	58.082622999999998	58.143411999999998	53.912945000000001	53.868499	Ленина	0103000020E61000000100000005000000DE72F563930A4D40EACDA8F92AEF4A40DE72F563930A4D40FB05BB61DBF44A404EED0C535B124D40FB05BB61DBF44A404EED0C535B124D40EACDA8F92AEF4A40DE72F563930A4D40EACDA8F92AEF4A40
66313	19233	58.261163000000003	58.276659000000002	53.804431000000001	53.793453999999997	Школьная	0103000020E610000001000000050000006FF607CA6D214D40B07092E68FE54A406FF607CA6D214D40BD715298F7E64A407192E68F69234D40BD715298F7E64A407192E68F69234D40B07092E68FE54A406FF607CA6D214D40B07092E68FE54A40
65788	19030	58.248578000000002	58.259177999999999	54.062998	54.058691000000003	Школьная	0103000020E61000000100000005000000A7406667D11F4D40E7C8CA2F83074B40A7406667D11F4D4051DB865110084B40DDEBA4BE2C214D4051DB865110084B40DDEBA4BE2C214D40E7C8CA2F83074B40A7406667D11F4D40E7C8CA2F83074B40
65786	18560	57.369351999999999	57.393579000000003	54.180092999999999	54.170470000000002	Горная	0103000020E61000000100000005000000295B24ED46AF4C407D7901F6D1154B40295B24ED46AF4C40889E94490D174B403AB2F2CB60B24C40889E94490D174B403AB2F2CB60B24C407D7901F6D1154B40295B24ED46AF4C407D7901F6D1154B40
66242	20039	58.163893000000002	58.178482000000002	53.857926999999997	53.852356	Бельская	0103000020E610000001000000050000008C852172FA144D4052465C001AED4A408C852172FA144D407DAD4B8DD0ED4A405C76887FD8164D407DAD4B8DD0ED4A405C76887FD8164D4052465C001AED4A408C852172FA144D4052465C001AED4A40
66301	17143	58.640377999999998	58.650089000000001	53.813161000000001	53.805978000000003	Вокзальная	0103000020E61000000100000005000000F88903E8F7514D40D3A57F492AE74A40F88903E8F7514D40FBB0DEA815E84A40A33EC91D36534D40FBB0DEA815E84A40A33EC91D36534D40D3A57F492AE74A40F88903E8F7514D40D3A57F492AE74A40
65787	18879	58.730614000000003	58.749766000000001	54.377825999999999	54.365721000000001	Центральная	0103000020E61000000100000005000000F8FF71C2845D4D40EF3A1BF2CF2E4B40F8FF71C2845D4D400CCA349A5C304B408DD31055F85F4D400CCA349A5C304B408DD31055F85F4D40EF3A1BF2CF2E4B40F8FF71C2845D4D40EF3A1BF2CF2E4B40
65776	17076	58.465277999999998	58.476480000000002	53.702013999999998	53.692131000000003	Школьная	0103000020E610000001000000050000002EC6C03A8E3B4D401EC6A4BF97D84A402EC6C03A8E3B4D40C5AA4198DBD94A405B99F04BFD3C4D40C5AA4198DBD94A405B99F04BFD3C4D401EC6A4BF97D84A402EC6C03A8E3B4D401EC6A4BF97D84A40
64841	17592	57.644621999999998	57.666119000000002	54.594150999999997	54.580764000000002	Центральная	0103000020E610000001000000050000001C2444F982D24C40DA588979564A4B401C2444F982D24C405EF1D4230D4C4B40431F2C6343D54C405EF1D4230D4C4B40431F2C6343D54C40DA588979564A4B401C2444F982D24C40DA588979564A4B40
64157	58121	56.931207000000001	59.049219000000001	54.716678999999999	53.362419000000003	Советская	0103000020E6100000010000000500000034677DCA31774C407A39ECBE63AE4A4034677DCA31774C40705D3123BC5B4B40C1ABE5CE4C864D40705D3123BC5B4B40C1ABE5CE4C864D407A39ECBE63AE4A4034677DCA31774C407A39ECBE63AE4A40
63709	58121	55.999861000000003	56.008071999999999	54.843746000000003	54.839007000000002	40 лет Победы	0103000020E61000000100000005000000DFC5FB71FBFF4B40BB0ED594646B4B40DFC5FB71FBFF4B40BF1072DEFF6B4B40B401D88008014C40BF1072DEFF6B4B40B401D88008014C40BB0ED594646B4B40DFC5FB71FBFF4B40BB0ED594646B4B40
66643	18803	58.786192	58.811534000000002	54.335425999999998	54.323807000000002	Иремель	0103000020E610000001000000050000003C3080F0A1644D40A29BFD8172294B403C3080F0A1644D40321D3A3DEF2A4B40C9CB9A58E0674D40321D3A3DEF2A4B40C9CB9A58E0674D40A29BFD8172294B403C3080F0A1644D40A29BFD8172294B40
63366	18750	58.353366000000001	58.383262000000002	53.931731999999997	53.910165999999997	Ленина	0103000020E6100000010000000500000059C2DA183B2D4D402FF7C95180F44A4059C2DA183B2D4D407E5182FE42F74A4058E6ADBA0E314D407E5182FE42F74A4058E6ADBA0E314D402FF7C95180F44A4059C2DA183B2D4D402FF7C95180F44A40
65780	17341	58.238427000000001	58.258853999999999	53.996996000000003	53.986573	Центральная	0103000020E61000000100000005000000E0BDA3C6841E4D40ED0E290648FE4A40E0BDA3C6841E4D40151F9F909DFF4A402A38BC2022214D40151F9F909DFF4A402A38BC2022214D40ED0E290648FE4A40E0BDA3C6841E4D40ED0E290648FE4A40
65364	19763	57.779819000000003	57.801045999999999	53.646129999999999	53.630535999999999	Юлаева	0103000020E6100000010000000500000054E6E61BD1E34C40AF795567B5D04A4054E6E61BD1E34C40747B4963B4D24A40BA4BE2AC88E64C40747B4963B4D24A40BA4BE2AC88E64C40AF795567B5D04A4054E6E61BD1E34C40AF795567B5D04A40
66641	18721	57.678964999999998	57.703721999999999	53.534956999999999	53.514096000000002	Ленина	0103000020E6100000010000000500000077103B53E8D64C409180D1E5CDC14A4077103B53E8D64C4015E2917879C44A40E4BCFF8F13DA4C4015E2917879C44A40E4BCFF8F13DA4C409180D1E5CDC14A4077103B53E8D64C409180D1E5CDC14A40
64846	18588	57.792816999999999	57.823853999999997	53.903812000000002	53.893583	Советская	0103000020E610000001000000050000003E5B07077BE54C407BA180ED60F24A403E5B07077BE54C40BEDD921CB0F34A40E256410C74E94C40BEDD921CB0F34A40E256410C74E94C407BA180ED60F24A403E5B07077BE54C407BA180ED60F24A40
66311	17795	57.544119000000002	57.555940999999997	53.703341999999999	53.689331000000003	Советская	0103000020E61000000100000005000000ED10FFB0A5C54C403B8F8AFF3BD84A40ED10FFB0A5C54C409DF3531C07DA4A40B5C01E1329C74C409DF3531C07DA4A40B5C01E1329C74C403B8F8AFF3BD84A40ED10FFB0A5C54C403B8F8AFF3BD84A40
66309	17651	57.578676999999999	57.600307999999998	54.545265999999998	54.531612000000003	Клубная	0103000020E6100000010000000500000044F9821612CA4C40A114ADDC0B444B4044F9821612CA4C4074CFBA46CB454B407AC37DE4D6CC4C4074CFBA46CB454B407AC37DE4D6CC4C40A114ADDC0B444B4044F9821612CA4C40A114ADDC0B444B40
9670	18102	57.536087999999999	57.584597000000002	54.229447999999998	54.203218999999997	Энергетиков	0103000020E6100000010000000500000097E315889EC44C4081768714031A4B4097E315889EC44C40F910548D5E1D4B407C2B1213D4CA4C40F910548D5E1D4B407C2B1213D4CA4C4081768714031A4B4097E315889EC44C4081768714031A4B40
65785	18102	57.536087999999999	57.584597000000002	54.229447999999998	54.203218999999997	Школьная	0103000020E6100000010000000500000097E315889EC44C4081768714031A4B4097E315889EC44C40F910548D5E1D4B407C2B1213D4CA4C40F910548D5E1D4B407C2B1213D4CA4C4081768714031A4B4097E315889EC44C4081768714031A4B40
64420	18102	57.536087999999999	57.584597000000002	54.229447999999998	54.203218999999997	Октябрьская	0103000020E6100000010000000500000097E315889EC44C4081768714031A4B4097E315889EC44C40F910548D5E1D4B407C2B1213D4CA4C40F910548D5E1D4B407C2B1213D4CA4C4081768714031A4B4097E315889EC44C4081768714031A4B40
64214	17982	57.347234999999998	57.385601999999999	54.412123000000001	54.397874000000002	Мубарякова	0103000020E6100000010000000500000066834C3272AC4C40E0F60489ED324B4066834C3272AC4C40F7764B72C0344B40D7A205685BB14C40F7764B72C0344B40D7A205685BB14C40E0F60489ED324B4066834C3272AC4C40E0F60489ED324B40
65781	17888	57.319648000000001	57.338448999999997	53.847825	53.827353000000002	Школьная	0103000020E61000000100000005000000AC1DC539EAA84C40AE9FFEB3E6E94A40AC1DC539EAA84C4098DD938785EC4A40942EFD4B52AB4C4098DD938785EC4A40942EFD4B52AB4C40AE9FFEB3E6E94A40AC1DC539EAA84C40AE9FFEB3E6E94A40
65335	17888	57.319648000000001	57.338448999999997	53.847825	53.827353000000002	Октябрьская	0103000020E61000000100000005000000AC1DC539EAA84C40AE9FFEB3E6E94A40AC1DC539EAA84C4098DD938785EC4A40942EFD4B52AB4C4098DD938785EC4A40942EFD4B52AB4C40AE9FFEB3E6E94A40AC1DC539EAA84C40AE9FFEB3E6E94A40
65783	18045	57.265084000000002	57.280831999999997	54.460493999999997	54.444146000000003	Школьная	0103000020E61000000100000005000000B058C345EEA14C401A53B0C6D9384B40B058C345EEA14C408A00A777F13A4B40CBD58F4DF2A34C408A00A777F13A4B40CBD58F4DF2A34C401A53B0C6D9384B40B058C345EEA14C401A53B0C6D9384B40
66814	17694	57.504755000000003	57.591558999999997	53.547626999999999	53.504221000000001	Загорская	0103000020E610000001000000050000000ABFD4CF9BC04C406C7A50508AC04A400ABFD4CF9BC04C400BB43BA418C64A40C5538F34B8CB4C400BB43BA418C64A40C5538F34B8CB4C406C7A50508AC04A400ABFD4CF9BC04C406C7A50508AC04A40
66918	17694	57.504755000000003	57.591558999999997	53.547626999999999	53.504221000000001	Блюхера	0103000020E610000001000000050000000ABFD4CF9BC04C406C7A50508AC04A400ABFD4CF9BC04C400BB43BA418C64A40C5538F34B8CB4C400BB43BA418C64A40C5538F34B8CB4C406C7A50508AC04A400ABFD4CF9BC04C406C7A50508AC04A40
66503	58809	56.931207000000001	59.049219000000001	54.716678999999999	53.362419000000003	Школьная	0103000020E6100000010000000500000034677DCA31774C407A39ECBE63AE4A4034677DCA31774C40705D3123BC5B4B40C1ABE5CE4C864D40705D3123BC5B4B40C1ABE5CE4C864D407A39ECBE63AE4A4034677DCA31774C407A39ECBE63AE4A40
66314	18899	58.517282000000002	58.545667999999999	54.374071000000001	54.355952000000002	переулок Школьный	0103000020E610000001000000050000009D67EC4B36424D401079CBD58F2D4B409D67EC4B36424D40E6B0FB8EE12F4B40A33CF372D8454D40E6B0FB8EE12F4B40A33CF372D8454D401079CBD58F2D4B409D67EC4B36424D401079CBD58F2D4B40
66303	17475	57.471902999999998	57.500855999999999	54.387017999999998	54.372109000000002	Горная	0103000020E6100000010000000500000030F1475167BC4C400DC68844A12F4B4030F1475167BC4C404E7B4ACE89314B40B000A60C1CC04C404E7B4ACE89314B40B000A60C1CC04C400DC68844A12F4B4030F1475167BC4C400DC68844A12F4B40
64734	17542	57.499004999999997	57.507008999999996	54.412709999999997	54.401035	Центральная	0103000020E610000001000000050000002EC55565DFBF4C4093C6681D55334B402EC55565DFBF4C40B75D68AED3344B408AE3C0ABE5C04C40B75D68AED3344B408AE3C0ABE5C04C4093C6681D55334B402EC55565DFBF4C4093C6681D55334B40
65026	18382	57.774158999999997	57.792090000000002	54.164149999999999	54.154859999999999	Школьная	0103000020E61000000100000005000000B87361A417E34C40B2BAD573D2134B40B87361A417E34C40B7D100DE02154B408CBE823463E54C40B7D100DE02154B408CBE823463E54C40B2BAD573D2134B40B87361A417E34C40B2BAD573D2134B40
66154	48339	57.641585999999997	57.651251999999999	53.521548000000003	53.511574000000003	Школьная	0103000020E6100000010000000500000025C9737D1FD24C40F1BDBF417BC14A4025C9737D1FD24C40A9A5B915C2C24A4030BABC395CD34C40A9A5B915C2C24A4030BABC395CD34C40F1BDBF417BC14A4025C9737D1FD24C40F1BDBF417BC14A40
65831	48339	57.641585999999997	57.651251999999999	53.521548000000003	53.511574000000003	Центральная	0103000020E6100000010000000500000025C9737D1FD24C40F1BDBF417BC14A4025C9737D1FD24C40A9A5B915C2C24A4030BABC395CD34C40A9A5B915C2C24A4030BABC395CD34C40F1BDBF417BC14A4025C9737D1FD24C40F1BDBF417BC14A40
66947	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Тюленина	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63557	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Точисского	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
66894	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Пушкина	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63728	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Металлургическая	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63793	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Маркса	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63727	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Ленина	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63503	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	Косоротова	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63375	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	50 лет Октября	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
64869	15455	58.323667999999998	58.455737999999997	54.00421	53.945942000000002	50 Лет Октября	0103000020E610000001000000050000008061F9F36D294D40D8F4A0A014F94A408061F9F36D294D4078280AF489004B40B0C56E9F553A4D4078280AF489004B40B0C56E9F553A4D40D8F4A0A014F94A408061F9F36D294D40D8F4A0A014F94A40
63996	17437	57.553758000000002	57.589447999999997	54.380887999999999	54.361854000000001	Мубарякова	0103000020E61000000100000005000000FEF2C98AE1C64C40A1F65B3B512E4B40FEF2C98AE1C64C402CB81FF0C0304B40A758350873CB4C402CB81FF0C0304B40A758350873CB4C40A1F65B3B512E4B40FEF2C98AE1C64C40A1F65B3B512E4B40
65336	17288	58.140537000000002	58.159365999999999	53.930846000000003	53.922198999999999	Победы	0103000020E610000001000000050000006170CD1DFD114D40B3B3E89D0AF64A406170CD1DFD114D4064CE33F625F74A40130CE71A66144D4064CE33F625F74A40130CE71A66144D40B3B3E89D0AF64A406170CD1DFD114D40B3B3E89D0AF64A40
66799	19065	57.971214000000003	57.987302999999997	53.840387999999997	53.828496000000001	Агидель	0103000020E610000001000000050000006CB587BD50FC4C40F46E2C280CEA4A406CB587BD50FC4C40B5F97FD591EB4A40101FD8F15FFE4C40B5F97FD591EB4A40101FD8F15FFE4C40F46E2C280CEA4A406CB587BD50FC4C40F46E2C280CEA4A40
65777	17242	58.229973999999999	58.248505999999999	53.937812000000001	53.926535999999999	Советская	0103000020E610000001000000050000001477BCC96F1D4D4088484DBB98F64A401477BCC96F1D4D40EFE53E390AF84A400D6E6B0BCF1F4D40EFE53E390AF84A400D6E6B0BCF1F4D4088484DBB98F64A401477BCC96F1D4D4088484DBB98F64A40
64070	14374	58.695382000000002	58.737917000000003	55.770856000000002	55.751102000000003	Центральная	0103000020E61000000100000005000000111D024702594D40E8FA3E1C24E04B40111D024702594D4073F6CE68ABE24B40CB147310745E4D4073F6CE68ABE24B40CB147310745E4D40E8FA3E1C24E04B40111D024702594D40E8FA3E1C24E04B40
66298	14745	59.119539000000003	59.172899000000001	55.771701999999998	55.755333	Советская	0103000020E610000001000000050000005CCCCF0D4D8F4D40774B72C0AEE04B405CCCCF0D4D8F4D40FF209221C7E24B406C41EF8D21964D40FF209221C7E24B406C41EF8D21964D40774B72C0AEE04B405CCCCF0D4D8F4D40774B72C0AEE04B40
63576	14922	59.489888000000001	59.506030000000003	55.555163	55.540979999999998	Х.Давлетшиной	0103000020E61000000100000005000000F75965A6B4BE4D4021E527D53EC54B40F75965A6B4BE4D408179C8940FC74B40BF654E97C5C04D408179C8940FC74B40BF654E97C5C04D4021E527D53EC54B40F75965A6B4BE4D4021E527D53EC54B40
63386	14922	59.489888000000001	59.506030000000003	55.555163	55.540979999999998	Ленина	0103000020E61000000100000005000000F75965A6B4BE4D4021E527D53EC54B40F75965A6B4BE4D408179C8940FC74B40BF654E97C5C04D408179C8940FC74B40BF654E97C5C04D4021E527D53EC54B40F75965A6B4BE4D4021E527D53EC54B40
66484	58799	59.081972	59.108911999999997	55.671976000000001	55.658611000000001	Мира	0103000020E610000001000000050000000798F90E7E8A4D4097E4805D4DD44B400798F90E7E8A4D4034D93F4F03D64B402B1213D4F08D4D4034D93F4F03D64B402B1213D4F08D4D4097E4805D4DD44B400798F90E7E8A4D4097E4805D4DD44B40
64405	14684	58.961767999999999	59.01361	55.797942999999997	55.767432999999997	Советская	0103000020E610000001000000050000006F2BBD361B7B4D40826F9A3E3BE24B406F2BBD361B7B4D403B8908FF22E64B400473F4F8BD814D403B8908FF22E64B400473F4F8BD814D40826F9A3E3BE24B406F2BBD361B7B4D40826F9A3E3BE24B40
65326	14492	58.876527000000003	58.900008999999997	55.74597	55.730187999999998	Клубная	0103000020E61000000100000005000000CF87670932704D4040F7E5CC76DD4B40CF87670932704D4008E6E8F17BDF4B40868DB27E33734D4008E6E8F17BDF4B40868DB27E33734D4040F7E5CC76DD4B40CF87670932704D4040F7E5CC76DD4B40
64353	14119	58.631413000000002	58.675637000000002	56.004237000000003	55.954006999999997	Крупской	0103000020E6100000010000000500000077A22424D2504D40D993C0E61CFA4B4077A22424D2504D40723788D68A004C40D97BF1457B564D40723788D68A004C40D97BF1457B564D40D993C0E61CFA4B4077A22424D2504D40D993C0E61CFA4B40
63611	14553	58.917014000000002	58.992068000000003	55.722729999999999	55.692053999999999	Школьный переулок	0103000020E61000000100000005000000B1FCF9B660754D407288B83995D84B40B1FCF9B660754D4046EBA86A82DC4B403EB48F15FC7E4D4046EBA86A82DC4B403EB48F15FC7E4D407288B83995D84B40B1FCF9B660754D407288B83995D84B40
63649	14553	58.917014000000002	58.992068000000003	55.722729999999999	55.692053999999999	Советская	0103000020E61000000100000005000000B1FCF9B660754D407288B83995D84B40B1FCF9B660754D4046EBA86A82DC4B403EB48F15FC7E4D4046EBA86A82DC4B403EB48F15FC7E4D407288B83995D84B40B1FCF9B660754D407288B83995D84B40
63531	14553	58.917014000000002	58.992068000000003	55.722729999999999	55.692053999999999	Молодежная	0103000020E61000000100000005000000B1FCF9B660754D407288B83995D84B40B1FCF9B660754D4046EBA86A82DC4B403EB48F15FC7E4D4046EBA86A82DC4B403EB48F15FC7E4D407288B83995D84B40B1FCF9B660754D407288B83995D84B40
66304	14787	58.957061000000003	58.980058	55.665619	55.646070999999999	Победы	0103000020E6100000010000000500000077A38FF9807A4D406FF25B74B2D24B4077A38FF9807A4D40514CDE0033D54B407217618A727D4D40514CDE0033D54B407217618A727D4D406FF25B74B2D24B4077A38FF9807A4D406FF25B74B2D24B40
66518	58815	58.652002000000003	58.679409999999997	55.762180999999998	55.746364999999997	Совхозная	0103000020E610000001000000050000009B7631CD74534D4084F068E388DF4B409B7631CD74534D40F850A2258FE14B40A54929E8F6564D40F850A2258FE14B40A54929E8F6564D4084F068E388DF4B409B7631CD74534D4084F068E388DF4B40
64072	15169	58.855435	58.890945000000002	55.615360000000003	55.599463	Мира	0103000020E61000000100000005000000486DE2E47E6D4D40BE141E34BBCC4B40486DE2E47E6D4D401FA2D11DC4CE4B4072C45A7C0A724D401FA2D11DC4CE4B4072C45A7C0A724D40BE141E34BBCC4B40486DE2E47E6D4D40BE141E34BBCC4B40
64733	15414	59.223232000000003	59.246299999999998	56.073514000000003	56.061171999999999	Мусы Гареева	0103000020E61000000100000005000000D9B5BDDD929C4D4028B7ED7BD4074C40D9B5BDDD929C4D402AE620E868094C409D8026C2869F4D402AE620E868094C409D8026C2869F4D4028B7ED7BD4074C40D9B5BDDD929C4D4028B7ED7BD4074C40
63791	14167	58.664704	58.737414000000001	55.968131	55.926443999999996	Советская	0103000020E610000001000000050000009CC24A0515554D40A7C98CB795F64B409CC24A0515554D40349F73B7EBFB4B4068CEFA94635E4D40349F73B7EBFB4B4068CEFA94635E4D40A7C98CB795F64B409CC24A0515554D40A7C98CB795F64B40
65330	14909	59.152067000000002	59.206603999999999	55.610813999999998	55.598160999999998	Школьный переулок	0103000020E6100000010000000500000082E673EE76934D400F5F268A90CC4B4082E673EE76934D402FF834272FCE4B40849CF7FF719A4D402FF834272FCE4B40849CF7FF719A4D400F5F268A90CC4B4082E673EE76934D400F5F268A90CC4B40
65333	15113	59.156855	59.174228999999997	55.527600999999997	55.517913	Мира	0103000020E61000000100000005000000679B1BD313944D402D9622F94AC24B40679B1BD313944D401F2BF86D88C34B40E481C8224D964D401F2BF86D88C34B40E481C8224D964D402D9622F94AC24B40679B1BD313944D402D9622F94AC24B40
64493	14084	58.578223000000001	58.638375000000003	55.953251000000002	55.926428999999999	Кирова	0103000020E61000000100000005000000C3651536034A4D407288B83995F64B40C3651536034A4D408DF0F62004FA4B40C1CAA145B6514D408DF0F62004FA4B40C1CAA145B6514D407288B83995F64B40C3651536034A4D407288B83995F64B40
64165	15361	59.209280999999997	59.261527000000001	56.051274999999997	56.035145	Гагарина	0103000020E610000001000000050000004B5645B8C99A4D4018CFA0A17F044C404B5645B8C99A4D401B0DE02D90064C40B0027CB779A14D401B0DE02D90064C40B0027CB779A14D4018CFA0A17F044C404B5645B8C99A4D4018CFA0A17F044C40
65342	15319	59.182242000000002	59.204906000000001	55.929071	55.916657999999998	Школьный переулок	0103000020E6100000010000000500000094FAB2B453974D40F2CEA10C55F54B4094FAB2B453974D40BD546CCCEBF64B4089601C5C3A9A4D40BD546CCCEBF64B4089601C5C3A9A4D40F2CEA10C55F54B4094FAB2B453974D40F2CEA10C55F54B40
65328	14847	59.021523999999999	59.041367999999999	55.703859999999999	55.690942999999997	Салавата Юлаева	0103000020E61000000100000005000000200A664CC1824D403733FAD170D84B40200A664CC1824D40357BA01518DA4B40EB8CEF8B4B854D40357BA01518DA4B40EB8CEF8B4B854D403733FAD170D84B40200A664CC1824D403733FAD170D84B40
65324	14240	58.709907000000001	58.730991000000003	55.917262999999998	55.899053000000002	Салавата Юлаева	0103000020E61000000100000005000000CA198A3BDE5A4D40732F302B14F34B40CA198A3BDE5A4D40596ABDDF68F54B40CE55F31C915D4D40596ABDDF68F54B40CE55F31C915D4D40732F302B14F34B40CA198A3BDE5A4D40732F302B14F34B40
66295	14402	58.795113000000001	58.822017000000002	55.725994999999998	55.709935999999999	Мечетлинская	0103000020E61000000100000005000000EECF4543C6654D406420CF2EDFDA4B40EECF4543C6654D409E077767EDDC4B40C6E061DA37694D409E077767EDDC4B40C6E061DA37694D406420CF2EDFDA4B40EECF4543C6654D406420CF2EDFDA4B40
64836	14997	59.502859000000001	59.520592000000001	55.532176999999997	55.516731	Шаймуратова	0103000020E61000000100000005000000E8BF07AF5DC04D4029EACC3D24C24B40E8BF07AF5DC04D4079573D601EC44B40954737C2A2C24D4079573D601EC44B40954737C2A2C24D4029EACC3D24C24B40E8BF07AF5DC04D4029EACC3D24C24B40
63952	58144	54.291893999999999	54.313848999999998	54.010226000000003	53.993492000000003	Садовая	0103000020E6100000010000000500000006F357C85C254B40386BF0BE2AFF4A4006F357C85C254B40D2C8E7154F014B40EF703B342C284B40D2C8E7154F014B40EF703B342C284B40386BF0BE2AFF4A4006F357C85C254B40386BF0BE2AFF4A40
65323	13968	54.376012000000003	54.395595999999998	54.031364000000004	54.012855999999999	Школьная	0103000020E61000000100000005000000A873452921304B4058C7F143A5014B40A873452921304B40C9224DBC03044B40D636C5E3A2324B40C9224DBC03044B40D636C5E3A2324B4058C7F143A5014B40A873452921304B4058C7F143A5014B40
64344	13884	54.321314000000001	54.358961999999998	54.201587000000004	54.174275000000002	Комсомольская	0103000020E610000001000000050000009CDF30D120294B4055C1A8A44E164B409CDF30D120294B403E26529ACD194B40DD408177F22D4B403E26529ACD194B40DD408177F22D4B4055C1A8A44E164B409CDF30D120294B4055C1A8A44E164B40
66767	13820	54.126531999999997	54.144911999999998	54.267198999999998	54.249417000000001	Чапаева	0103000020E61000000100000005000000E0F2583332104B40810871E5EC1F4B40E0F2583332104B400F43AB9333224B402366F6798C124B400F43AB9333224B402366F6798C124B40810871E5EC1F4B40E0F2583332104B40810871E5EC1F4B40
64839	13678	54.283073000000002	54.308881	54.349713000000001	54.338538999999997	Дружбы	0103000020E61000000100000005000000B8B06EBC3B244B40D4B5F63E552B4B40B8B06EBC3B244B4037FE4465C32C4B408AADA06989274B4037FE4465C32C4B408AADA06989274B40D4B5F63E552B4B40B8B06EBC3B244B40D4B5F63E552B4B40
64290	13796	54.399360000000001	54.430405	53.986462000000003	53.961153000000003	К.Иванова	0103000020E6100000010000000500000050AA7D3A1E334B40E5B9BE0F07FB4A4050AA7D3A1E334B40965F066344FE4A407784D38217374B40965F066344FE4A407784D38217374B40E5B9BE0F07FB4A4050AA7D3A1E334B40E5B9BE0F07FB4A40
66264	13663	53.972318000000001	53.993105	54.047373999999998	54.040289999999999	Лесная	0103000020E61000000100000005000000F4A78DEA74FC4A408C2D043928054B40F4A78DEA74FC4A402157EA5910064B403E3F8C101EFF4A402157EA5910064B403E3F8C101EFF4A408C2D043928054B40F4A78DEA74FC4A408C2D043928054B40
66266	13742	54.311135999999998	54.339181000000004	54.394450999999997	54.374175999999999	Пушкина	0103000020E61000000100000005000000DB4DF04DD3274B405B79C9FFE42F4B40DB4DF04DD3274B40EF6FD05E7D324B40593673486A2B4B40EF6FD05E7D324B40593673486A2B4B405B79C9FFE42F4B40DB4DF04DD3274B405B79C9FFE42F4B40
65773	13262	54.432130000000001	54.450671	54.078642000000002	54.067858999999999	Овражная	0103000020E610000001000000050000006CCF2C0950374B40A0DE8C9AAF084B406CCF2C0950374B40C80BE9F0100A4B40B8205B96AF394B40C80BE9F0100A4B40B8205B96AF394B40A0DE8C9AAF084B406CCF2C0950374B40A0DE8C9AAF084B40
65313	12751	54.145072999999996	54.164180999999999	54.041331999999997	54.029476000000003	Интернациональная	0103000020E610000001000000050000002C4487C091124B402A029CDEC5034B402C4487C091124B409E23F25D4A054B40F2CF0CE203154B409E23F25D4A054B40F2CF0CE203154B402A029CDEC5034B402C4487C091124B402A029CDEC5034B40
64542	13545	54.215770999999997	54.264629999999997	54.301164	54.286766	Школьная	0103000020E610000001000000050000006D3656629E1B4B4068CD8FBFB4244B406D3656629E1B4B40C45DBD8A8C264B402EC55565DF214B40C45DBD8A8C264B402EC55565DF214B4068CD8FBFB4244B406D3656629E1B4B4068CD8FBFB4244B40
63254	58089	54.247642999999997	54.254334999999998	54.115940000000002	54.111263999999998	40 лет Победы	0103000020E61000000100000005000000AA0A0DC4B21F4B406F9C14E63D0E4B40AA0A0DC4B21F4B402D26361FD70E4B40349D9D0C8E204B402D26361FD70E4B40349D9D0C8E204B406F9C14E63D0E4B40AA0A0DC4B21F4B406F9C14E63D0E4B40
66236	13185	53.895404999999997	53.927591	54.262151000000003	54.232410999999999	Центральная	0103000020E6100000010000000500000062D68BA19CF24A40861DC6A4BF1D4B4062D68BA19CF24A408ECEF9298E214B402F88484DBBF64A408ECEF9298E214B402F88484DBBF64A40861DC6A4BF1D4B4062D68BA19CF24A40861DC6A4BF1D4B40
64075	13461	54.076289000000003	54.084608000000003	54.006072000000003	53.995857999999998	Школьная	0103000020E61000000100000005000000B40584D6C3094B40E0BA624678FF4A40B40584D6C3094B40EEB5A0F7C6004B40707D586FD40A4B40EEB5A0F7C6004B40707D586FD40A4B40E0BA624678FF4A40B40584D6C3094B40E0BA624678FF4A40
66259	12912	54.059769000000003	54.096572999999999	54.194338999999999	54.172877999999997	Центральная	0103000020E610000001000000050000004628B682A6074B405419C6DD20164B404628B682A6074B402EABB019E0184B409B560A815C0C4B402EABB019E0184B409B560A815C0C4B405419C6DD20164B404628B682A6074B405419C6DD20164B40
65920	13237	54.369858999999998	54.407867000000003	54.121882999999997	54.082926	Зеленая	0103000020E61000000100000005000000CD902A8A572F4B407AFEB4519D0A4B40CD902A8A572F4B401C78B5DC990F4B400F0F61FC34344B401C78B5DC990F4B400F0F61FC34344B407AFEB4519D0A4B40CD902A8A572F4B407AFEB4519D0A4B40
63723	13237	54.369858999999998	54.407867000000003	54.121882999999997	54.082926	Заводская	0103000020E61000000100000005000000CD902A8A572F4B407AFEB4519D0A4B40CD902A8A572F4B401C78B5DC990F4B400F0F61FC34344B401C78B5DC990F4B400F0F61FC34344B407AFEB4519D0A4B40CD902A8A572F4B407AFEB4519D0A4B40
65832	13112	53.898494999999997	53.926890999999998	54.204762000000002	54.181362999999997	Центральная	0103000020E610000001000000050000004C4F58E201F34A402BDA1CE736174B404C4F58E201F34A4056BB26A4351A4B4076FA415DA4F64A4056BB26A4351A4B4076FA415DA4F64A402BDA1CE736174B404C4F58E201F34A402BDA1CE736174B40
65767	13112	53.898494999999997	53.926890999999998	54.204762000000002	54.181362999999997	Ленина	0103000020E610000001000000050000004C4F58E201F34A402BDA1CE736174B404C4F58E201F34A4056BB26A4351A4B4076FA415DA4F64A4056BB26A4351A4B4076FA415DA4F64A402BDA1CE736174B404C4F58E201F34A402BDA1CE736174B40
66296	13949	54.486981	54.518197999999998	54.174754999999998	54.156968999999997	Веровка	0103000020E61000000100000005000000FE62B664553E4B402FBE688F17144B40FE62B664553E4B40FFE7305F5E164B40226DE34F54424B40FFE7305F5E164B40226DE34F54424B402FBE688F17144B40FE62B664553E4B402FBE688F17144B40
63321	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Чапаева	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63792	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Тукаева	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
64044	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Советская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63621	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Пролетарская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
9951	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Ленина	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63639	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Красноармейская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63328	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Красная	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63592	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Коммунистическая	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63595	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Волгоградская	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
63473	10973	54.073487	54.156275000000001	54.134556000000003	54.072451000000001	Амирова	0103000020E6100000010000000500000030D7A20568094B4000C8091346094B4030D7A20568094B4084BD892139114B405917B7D100144B4084BD892139114B405917B7D100144B4000C8091346094B4030D7A20568094B4000C8091346094B40
65314	13103	53.887642999999997	53.904361000000002	54.172088000000002	54.148164000000001	Мира	0103000020E61000000100000005000000FCC22B499EF14A40E738B709F7124B40FCC22B499EF14A405C04C6FA06164B409163EB19C2F34A405C04C6FA06164B409163EB19C2F34A40E738B709F7124B40FCC22B499EF14A40E738B709F7124B40
63545	12962	53.889924999999998	53.913012000000002	53.983539	53.966206999999997	Административная	0103000020E610000001000000050000004772F90FE9F14A404815C5ABACFB4A404772F90FE9F14A4097AB1F9BE4FD4A40836DC493DDF44A4097AB1F9BE4FD4A40836DC493DDF44A404815C5ABACFB4A404772F90FE9F14A404815C5ABACFB4A40
66257	12874	54.046940999999997	54.071753000000001	54.255381999999997	54.235148000000002	Советская	0103000020E61000000100000005000000B7EBA52902064B4023DC6454191E4B40B7EBA52902064B4058FE7C5BB0204B40E831CA332F094B4058FE7C5BB0204B40E831CA332F094B4023DC6454191E4B40B7EBA52902064B4023DC6454191E4B40
65318	13592	54.017854	54.032181999999999	54.107357999999998	54.095663999999999	Школьная	0103000020E61000000100000005000000280D350A49024B40C8B3CBB73E0C4B40280D350A49024B40637B2DE8BD0D4B408BC22E8A1E044B40637B2DE8BD0D4B408BC22E8A1E044B40C8B3CBB73E0C4B40280D350A49024B40C8B3CBB73E0C4B40
63364	12767	54.138829999999999	54.164738	54.028593000000001	54.005003000000002	Первомайская	0103000020E6100000010000000500000012DA722EC5114B40E2B034F0A3004B4012DA722EC5114B4080F277EFA8034B404834812216154B4080F277EFA8034B404834812216154B40E2B034F0A3004B4012DA722EC5114B40E2B034F0A3004B40
64727	13042	53.959553	53.985729999999997	54.189782000000001	54.171259999999997	Центральная	0103000020E61000000100000005000000ACE3F8A1D2FA4A40758E01D9EB154B40ACE3F8A1D2FA4A404BAFCDC64A184B40D15790662CFE4A404BAFCDC64A184B40D15790662CFE4A40758E01D9EB154B40ACE3F8A1D2FA4A40758E01D9EB154B40
66249	8991	56.130735999999999	56.145029000000001	55.979484999999997	55.967269999999999	Центральная	0103000020E6100000010000000500000076340EF5BB104C407233DC80CFFB4B4076340EF5BB104C4016F6B4C35FFD4B405DFC6D4F90124C4016F6B4C35FFD4B405DFC6D4F90124C407233DC80CFFB4B4076340EF5BB104C407233DC80CFFB4B40
64244	10862	56.129747999999999	56.165599999999998	56.086233	56.071193000000001	Центральная	0103000020E61000000100000005000000575C1C959B104C40215A2BDA1C094C40575C1C959B104C40016BD5AE090B4C40DA1B7C6132154C40016BD5AE090B4C40DA1B7C6132154C40215A2BDA1C094C40575C1C959B104C40215A2BDA1C094C40
66452	58782	55.818770000000001	55.849708	56.088242000000001	56.069443999999997	Центральная	0103000020E6100000010000000500000014799274CDE84B40A3737E8AE3084C4014799274CDE84B401B118C834B0B4C402593533BC3EC4B401B118C834B0B4C402593533BC3EC4B40A3737E8AE3084C4014799274CDE84B40A3737E8AE3084C40
66252	9128	55.963433999999999	55.979998999999999	55.797316000000002	55.786904999999997	Центральная	0103000020E610000001000000050000005FED28CE51FB4B408907944DB9E44B405FED28CE51FB4B40ED4960730EE64B406D8E739B70FD4B40ED4960730EE64B406D8E739B70FD4B408907944DB9E44B405FED28CE51FB4B408907944DB9E44B40
65572	48372	56.188363000000003	56.209932000000002	55.892552000000002	55.882485000000003	Центральная	0103000020E6100000010000000500000063635E471C184C40F41ABB44F5F04B4063635E471C184C405DFDD8243FF24B402331410DDF1A4C405DFDD8243FF24B402331410DDF1A4C40F41ABB44F5F04B4063635E471C184C40F41ABB44F5F04B40
65797	58632	55.955978000000002	55.970027999999999	55.870227999999997	55.861656000000004	Советская	0103000020E6100000010000000500000006D9B27C5DFA4B407B336ABE4AEE4B4006D9B27C5DFA4B40200890A163EF4B40261AA4E029FC4B40200890A163EF4B40261AA4E029FC4B407B336ABE4AEE4B4006D9B27C5DFA4B407B336ABE4AEE4B40
66478	58795	55.780825	55.795763999999998	55.926473999999999	55.910860999999997	Центральная	0103000020E610000001000000050000001973D712F2E34B40D619DF1797F44B401973D712F2E34B40124C35B396F64B40C5AA4198DBE54B40124C35B396F64B40C5AA4198DBE54B40D619DF1797F44B401973D712F2E34B40D619DF1797F44B40
64633	10572	55.684426000000002	55.718670000000003	55.994017999999997	55.980150000000002	Школьная	0103000020E610000001000000050000001C446B459BD74B405396218E75FD4B401C446B459BD74B4052D158FB3BFF4B40E44EE960FDDB4B4052D158FB3BFF4B40E44EE960FDDB4B405396218E75FD4B401C446B459BD74B405396218E75FD4B40
66463	58785	55.950848999999998	55.972785999999999	56.091636999999999	56.077472999999998	Центральная	0103000020E610000001000000050000009737876BB5F94B4058A9A0A2EA094C409737876BB5F94B40410DDFC2BA0B4C40DA006C4084FC4B40410DDFC2BA0B4C40DA006C4084FC4B4058A9A0A2EA094C409737876BB5F94B4058A9A0A2EA094C40
66261	9922	56.026721000000002	56.038021000000001	56.036124999999998	56.028182999999999	Центральная	0103000020E61000000100000005000000E78EFE976B034C40CEA623809B034C40E78EFE976B034C40B4C876BE9F044C40D6C743DFDD044C40B4C876BE9F044C40D6C743DFDD044C40CEA623809B034C40E78EFE976B034C40CEA623809B034C40
66795	4263	55.952663000000001	55.963120000000004	55.991726999999997	55.983820999999999	Мира	0103000020E61000000100000005000000FC8D76DCF0F94B401B0FB6D8EDFD4B40FC8D76DCF0F94B40B4C70BE9F0FE4B40D00F238447FB4B40B4C70BE9F0FE4B40D00F238447FB4B401B0FB6D8EDFD4B40FC8D76DCF0F94B401B0FB6D8EDFD4B40
66469	58789	55.866677000000003	55.887571000000001	56.083134000000001	56.075598999999997	Центральная	0103000020E6100000010000000500000003999D45EFEE4B401E4E603AAD094C4003999D45EFEE4B40C4978922A40A4C4063F030ED9BF14B40C4978922A40A4C4063F030ED9BF14B401E4E603AAD094C4003999D45EFEE4B401E4E603AAD094C40
64833	10011	56.139935000000001	56.168016999999999	55.921708000000002	55.906244000000001	Ленина	0103000020E610000001000000050000006B48DC63E9114C401E19ABCDFFF34B406B48DC63E9114C40153B1A87FAF54B400516C09481154C40153B1A87FAF54B400516C09481154C401E19ABCDFFF34B406B48DC63E9114C401E19ABCDFFF34B40
64627	10289	55.827142000000002	55.840148999999997	55.947817000000001	55.934134	Центральная	0103000020E61000000100000005000000F392FFC9DFE94B40740AF2B391F74B40F392FFC9DFE94B40E2CB441152F94B4030629F008AEB4B40E2CB441152F94B4030629F008AEB4B40740AF2B391F74B40F392FFC9DFE94B40740AF2B391F74B40
64730	9839	55.867565999999997	55.891021000000002	56.015056999999999	56.002284000000003	Центральная	0103000020E610000001000000050000008E8F16670CEF4B40ECA694D74A004C408E8F16670CEF4B40B6494563ED014C404D86E3F90CF24B40B6494563ED014C404D86E3F90CF24B40ECA694D74A004C408E8F16670CEF4B40ECA694D74A004C40
66608	8535	56.084276000000003	56.109006000000001	55.871040999999998	55.851216999999998	улица Центральная	0103000020E610000001000000050000003AEB538EC90A4C404D66BCADF4EC4B403AEB538EC90A4C40D13C80457EEF4B40AD889AE8F30D4C40D13C80457EEF4B40AD889AE8F30D4C404D66BCADF4EC4B403AEB538EC90A4C404D66BCADF4EC4B40
63724	9747	55.910711999999997	55.939782000000001	56.013845000000003	55.992426999999999	Юбилейная	0103000020E610000001000000050000009109F83592F44B406D5512D907FF4B409109F83592F44B40481B47ACC5014C404BAFCDC64AF84B40481B47ACC5014C404BAFCDC64AF84B406D5512D907FF4B409109F83592F44B406D5512D907FF4B40
63291	9747	55.910711999999997	55.939782000000001	56.013845000000003	55.992426999999999	Советская	0103000020E610000001000000050000009109F83592F44B406D5512D907FF4B409109F83592F44B40481B47ACC5014C404BAFCDC64AF84B40481B47ACC5014C404BAFCDC64AF84B406D5512D907FF4B409109F83592F44B406D5512D907FF4B40
63511	9747	55.910711999999997	55.939782000000001	56.013845000000003	55.992426999999999	Комсомольская	0103000020E610000001000000050000009109F83592F44B406D5512D907FF4B409109F83592F44B40481B47ACC5014C404BAFCDC64AF84B40481B47ACC5014C404BAFCDC64AF84B406D5512D907FF4B409109F83592F44B406D5512D907FF4B40
64196	10222	55.772398000000003	55.806355000000003	55.980899999999998	55.962598999999997	Советская	0103000020E6100000010000000500000077BF0AF0DDE24B40C614AC7136FB4B4077BF0AF0DDE24B40BD5296218EFD4B40A9FB00A436E74B40BD5296218EFD4B40A9FB00A436E74B40C614AC7136FB4B4077BF0AF0DDE24B40C614AC7136FB4B40
64723	8645	55.922578999999999	55.944785000000003	55.923766000000001	55.909523999999998	К.Маркса	0103000020E61000000100000005000000FA7C941117F64B40AB764D486BF44B40FA7C941117F64B401094DBF63DF64B402D6002B7EEF84B401094DBF63DF64B402D6002B7EEF84B40AB764D486BF44B40FA7C941117F64B40AB764D486BF44B40
64973	6508	56.010092999999998	56.034948999999997	56.061388999999998	56.041319999999999	Первомайская	0103000020E61000000100000005000000927538BA4A014C40DA5548F949054C40927538BA4A014C40C5AA4198DB074C409203763579044C40C5AA4198DB074C409203763579044C40DA5548F949054C40927538BA4A014C40DA5548F949054C40
66896	4342	55.880932999999999	55.919462000000003	56.129393999999998	56.113621999999999	Центральная	0103000020E61000000100000005000000CC7B9C69C2F04B40950D6B2A8B0E4C40CC7B9C69C2F04B4039268BFB8F104C4017F549EEB0F54B4039268BFB8F104C4017F549EEB0F54B40950D6B2A8B0E4C40CC7B9C69C2F04B40950D6B2A8B0E4C40
64739	9031	55.965499999999999	55.987122999999997	55.843105999999999	55.826321	Центральная	0103000020E61000000100000005000000DD24068195FB4B40BF7FF3E2C4E94B40DD24068195FB4B40DB87BCE5EAEB4B409010E50B5AFE4B40DB87BCE5EAEB4B409010E50B5AFE4B40BF7FF3E2C4E94B40DD24068195FB4B40BF7FF3E2C4E94B40
66248	8818	55.985244999999999	56.004387999999999	55.961419999999997	55.951033000000002	Центральная	0103000020E6100000010000000500000015C616821CFE4B4059350873BBF94B4015C616821CFE4B4033DC80CF0FFB4B40573F36C98F004C4033DC80CF0FFB4B40573F36C98F004C4059350873BBF94B4015C616821CFE4B4059350873BBF94B40
66564	58839	55.897956000000001	55.915168000000001	55.818007000000001	55.805427000000002	Озерная	0103000020E610000001000000050000009D9FE238F0F24B405F28603B18E74B409D9FE238F0F24B4015731074B4E84B40412C9B3924F54B4015731074B4E84B40412C9B3924F54B405F28603B18E74B409D9FE238F0F24B405F28603B18E74B40
65441	10265	56.199646000000001	56.231177000000002	56.076211999999998	56.062499000000003	Ленина	0103000020E610000001000000050000007C6308008E194C4030849CF7FF074C407C6308008E194C4008C89750C1094C40304B3B35971D4C4008C89750C1094C40304B3B35971D4C4030849CF7FF074C407C6308008E194C4030849CF7FF074C40
66483	58798	55.986691999999998	55.998036999999997	56.132649000000001	56.118636000000002	Центральная	0103000020E61000000100000005000000C79C67EC4BFE4B406B10E6762F0F4C40C79C67EC4BFE4B406E6C76A4FA104C40569929ADBFFF4B406E6C76A4FA104C40569929ADBFFF4B406B10E6762F0F4C40C79C67EC4BFE4B406B10E6762F0F4C40
65771	8805	56.283926000000001	56.313229	55.917006000000001	55.900041999999999	Первомайская	0103000020E61000000100000005000000F73DEAAF57244C406283859334F34B40F73DEAAF57244C402E1EDE7360F54B4053944BE317284C402E1EDE7360F54B4053944BE317284C406283859334F34B40F73DEAAF57244C406283859334F34B40
65765	8905	56.054747999999996	56.079506000000002	55.970841	55.958793999999997	К.Маркса	0103000020E61000000100000005000000BDC282FB01074C40EECC04C3B9FA4B40BDC282FB01074C40D74E948444FC4B40FBEAAA402D0A4C40D74E948444FC4B40FBEAAA402D0A4C40EECC04C3B9FA4B40BDC282FB01074C40EECC04C3B9FA4B40
64832	8744	56.175967	56.226973000000001	55.859988999999999	55.839416	Такаева	0103000020E610000001000000050000006E162F1686164C409CDEC5FB71EB4B406E162F1686164C40BAF59A1E14EE4B409A0986730D1D4C40BAF59A1E14EE4B409A0986730D1D4C409CDEC5FB71EB4B406E162F1686164C409CDEC5FB71EB4B40
66256	9848	55.993212999999997	56.021599999999999	56.012501	56.000250000000001	Советская	0103000020E61000000100000005000000247B849A21FF4B4079E9263108004C40247B849A21FF4B406A15FDA199014C40FBCBEEC9C3024C406A15FDA199014C40FBCBEEC9C3024C4079E9263108004C40247B849A21FF4B4079E9263108004C40
65443	29446	55.807873000000001	55.828417000000002	56.040717000000001	56.031723999999997	Центральная	0103000020E610000001000000050000002429E96168E74B40C83F33880F044C402429E96168E74B4014B2F33636054C40A839799109EA4B4014B2F33636054C40A839799109EA4B40C83F33880F044C402429E96168E74B40C83F33880F044C40
66253	9159	55.830824999999997	55.854073	55.760742	55.751294999999999	Центральная	0103000020E610000001000000050000007FD93D7958EA4B40FC523F6F2AE04B407FD93D7958EA4B40C9586DFE5FE14B40C4B2994352ED4B40C9586DFE5FE14B40C4B2994352ED4B40FC523F6F2AE04B407FD93D7958EA4B40FC523F6F2AE04B40
66495	58805	55.950291999999997	55.963704	56.04569	56.027332999999999	Кооперативная	0103000020E6100000010000000500000041D3122BA3F94B40008DD2A57F034C4041D3122BA3F94B408BE07F2BD9054C401F8315A75AFB4B408BE07F2BD9054C401F8315A75AFB4B40008DD2A57F034C4041D3122BA3F94B40008DD2A57F034C40
66226	8620	55.931409000000002	55.943635	55.959806999999998	55.949224000000001	Социалистическая	0103000020E610000001000000050000009C19FD6838F74B40064A0A2C80F94B409C19FD6838F74B4066BCADF4DAFA4B40342E1C08C9F84B4066BCADF4DAFA4B40342E1C08C9F84B40064A0A2C80F94B409C19FD6838F74B40064A0A2C80F94B40
66480	58796	55.971617999999999	55.998001000000002	55.817050999999999	55.801763999999999	Центральная	0103000020E610000001000000050000003B1A87FA5DFC4B40198EE733A0E64B403B1A87FA5DFC4B4001158E2095E84B400A302C7FBEFF4B4001158E2095E84B400A302C7FBEFF4B40198EE733A0E64B403B1A87FA5DFC4B40198EE733A0E64B40
65150	10619	55.720790000000001	55.743239000000003	56.017904999999999	56.004997000000003	Школьная	0103000020E6100000010000000500000055A4C2D842DC4B4000CADFBDA3004C4055A4C2D842DC4B40AAB706B64A024C404E0E9F7422DF4B40AAB706B64A024C404E0E9F7422DF4B4000CADFBDA3004C4055A4C2D842DC4B4000CADFBDA3004C40
66292	47349	56.056967	56.086556999999999	55.853682999999997	55.837566000000002	Варламова	0103000020E61000000100000005000000C2F9D4B14A074C40EB1ED95C35EB4B40C2F9D4B14A074C4059130B7C45ED4B40B41EBE4C140B4C4059130B7C45ED4B40B41EBE4C140B4C40EB1ED95C35EB4B40C2F9D4B14A074C40EB1ED95C35EB4B40
66163	10408	56.097875999999999	56.116973999999999	56.147385	56.128906999999998	Минниахметова	0103000020E610000001000000050000001A886533870C4C40DC9C4A0680104C401A886533870C4C40E275FD82DD124C40BC3D0801F90E4C40E275FD82DD124C40BC3D0801F90E4C40DC9C4A0680104C401A886533870C4C40DC9C4A0680104C40
66108	6683	53.627042000000003	53.672865000000002	55.142854	55.131495999999999	Центральная	0103000020E61000000100000005000000F69B89E942D04A4004C765DCD4904B40F69B89E942D04A40280D350A49924B40C0CFB87020D64A40280D350A49924B40C0CFB87020D64A4004C765DCD4904B40F69B89E942D04A4004C765DCD4904B40
66524	58820	53.758034000000002	53.787283000000002	55.228613000000003	55.219467999999999	Центральная	0103000020E61000000100000005000000C7A0134207E14A405F420587179C4B40C7A0134207E14A406138D730439D4B4030D978B0C5E44A406138D730439D4B4030D978B0C5E44A405F420587179C4B40C7A0134207E14A405F420587179C4B40
64591	7347	53.746212	53.798718999999998	55.008097999999997	54.994495999999998	Мира	0103000020E61000000100000005000000FEF0F3DF83DF4A405C001AA54B7F4B40FEF0F3DF83DF4A40DD94F25A09814B40CFD8976C3CE64A40DD94F25A09814B40CFD8976C3CE64A405C001AA54B7F4B40FEF0F3DF83DF4A405C001AA54B7F4B40
65163	6808	53.718328999999997	53.728721999999998	54.999763999999999	54.992930999999999	Т. Нуркаева	0103000020E610000001000000050000005A626534F2DB4A40A017EE5C187F4B405A626534F2DB4A40ECDB4944F87F4B4017F032C346DD4A40ECDB4944F87F4B4017F032C346DD4A40A017EE5C187F4B405A626534F2DB4A40A017EE5C187F4B40
65311	47608	53.520600999999999	53.537739999999999	54.931556999999998	54.921877000000002	Центральная	0103000020E61000000100000005000000E8A1B60DA3C24A40A1F7C61000764B40E8A1B60DA3C24A4010AE80423D774B4022E010AAD4C44A4010AE80423D774B4022E010AAD4C44A40A1F7C61000764B40E8A1B60DA3C24A40A1F7C61000764B40
64715	6417	53.874788000000002	53.894452000000001	55.145888999999997	55.129201000000002	Школьная	0103000020E6100000010000000500000075779D0DF9EF4A4025CE8AA889904B4075779D0DF9EF4A404EECA17DAC924B40C0EB33677DF24A404EECA17DAC924B40C0EB33677DF24A4025CE8AA889904B4075779D0DF9EF4A4025CE8AA889904B40
65774	8170	54.182830000000003	54.207659	55.232880000000002	55.214584000000002	Молодежная	0103000020E61000000100000005000000255D33F966174B40581F0F7D779B4B40255D33F966174B403DF20703CF9D4B402BDCF291941A4B403DF20703CF9D4B402BDCF291941A4B40581F0F7D779B4B40255D33F966174B40581F0F7D779B4B40
64286	7984	53.924950000000003	53.961061999999998	55.243704999999999	55.224516000000001	Победы	0103000020E61000000100000005000000B537F8C264F64A40E1B6B6F0BC9C4B40B537F8C264F64A40936FB6B9319F4B40D4B6611404FB4A40936FB6B9319F4B40D4B6611404FB4A40E1B6B6F0BC9C4B40B537F8C264F64A40E1B6B6F0BC9C4B40
65753	6359	53.824401999999999	53.867674000000001	55.124417999999999	55.100999000000002	Центральная	0103000020E61000000100000005000000E560360186E94A40E0F60489ED8C4B40E560360186E94A405184D4EDEC8F4B4075CB0EF10FEF4A405184D4EDEC8F4B4075CB0EF10FEF4A40E0F60489ED8C4B40E560360186E94A40E0F60489ED8C4B40
64014	7640	54.039935	54.085614	55.148287000000003	55.126303	Центральная	0103000020E610000001000000050000009E7B0F971C054B407F315BB22A904B409E7B0F971C054B4003B68311FB924B40350A4966F50A4B4003B68311FB924B40350A4966F50A4B407F315BB22A904B409E7B0F971C054B407F315BB22A904B40
66434	58776	53.622281000000001	53.671877000000002	55.212195000000001	55.195298000000001	Центральная	0103000020E610000001000000050000000AF65FE7A6CF4A40B37C5D86FF984B400AF65FE7A6CF4A40F7AFAC34299B4B40A1F7C61000D64A40F7AFAC34299B4B40A1F7C61000D64A40B37C5D86FF984B400AF65FE7A6CF4A40B37C5D86FF984B40
64502	7455	53.894981999999999	53.960766	55.183312999999998	55.171498999999997	Школьная	0103000020E610000001000000050000001C412AC58EF24A40FA25E2ADF3954B401C412AC58EF24A4040F7E5CC76974B40EB8D5A61FAFA4A4040F7E5CC76974B40EB8D5A61FAFA4A40FA25E2ADF3954B401C412AC58EF24A40FA25E2ADF3954B40
65545	6987	53.854495	53.873117000000001	55.331684000000003	55.319443	Центральная	0103000020E610000001000000050000003ACC971760ED4A40D3F71A82E3A84B403ACC971760ED4A40A14D0E9F74AA4B40734A404CC2EF4A40A14D0E9F74AA4B40734A404CC2EF4A40D3F71A82E3A84B403ACC971760ED4A40D3F71A82E3A84B40
66105	6712	53.547441999999997	53.585090999999998	55.162483999999999	55.153339000000003	Центральная	0103000020E61000000100000005000000793A579412C64A40C619C39CA0934B40793A579412C64A40C70F9546CC944B408B170B43E4CA4A40C70F9546CC944B408B170B43E4CA4A40C619C39CA0934B40793A579412C64A40C619C39CA0934B40
66494	58804	53.157313000000002	54.240223	55.359389	54.879680999999998	Сосновая	0103000020E610000001000000050000002A1E17D522944A40CFF4126399704B402A1E17D522944A4065C5707500AE4B409E5F94A0BF1E4B4065C5707500AE4B409E5F94A0BF1E4B40CFF4126399704B402A1E17D522944A40CFF4126399704B40
65667	7178	53.353397000000001	53.378999	55.047167000000002	55.029420000000002	Центральная	0103000020E6100000010000000500000094C0E61C3CAD4A4096ECD808C4834B4094C0E61C3CAD4A40A839799109864B40BD1B0B0A83B04A40A839799109864B40BD1B0B0A83B04A4096ECD808C4834B4094C0E61C3CAD4A4096ECD808C4834B40
66116	8006	54.032927999999998	54.054935999999998	55.259315000000001	55.247338999999997	Ленина	0103000020E61000000100000005000000B48F15FC36044B403E03EACDA89F4B40B48F15FC36044B405E2EE23B31A14B40C0AF912408074B405E2EE23B31A14B40C0AF912408074B403E03EACDA89F4B40B48F15FC36044B403E03EACDA89F4B40
65302	6293	53.762408999999998	53.790984000000002	55.140965000000001	55.125571999999998	Центральная	0103000020E6100000010000000500000089963C9E96E14A408BA548BE12904B4089963C9E96E14A40B97020240B924B4063D4B5F63EE54A40B97020240B924B4063D4B5F63EE54A408BA548BE12904B4089963C9E96E14A408BA548BE12904B40
64706	7169	53.431199999999997	53.455356000000002	55.008778999999997	54.992255	Нагорная	0103000020E610000001000000050000008104C58F31B74A4070253B36027F4B408104C58F31B74A401FF296AB1F814B40C904FC1A49BA4A401FF296AB1F814B40C904FC1A49BA4A4070253B36027F4B408104C58F31B74A4070253B36027F4B40
64865	58377	53.874456000000002	53.895251999999999	55.353161	55.33446	Магистральная	0103000020E610000001000000050000003FE5982CEEEF4A40FBE8D495CFAA4B403FE5982CEEEF4A40809C306134AD4B40DCD6169E97F24A40809C306134AD4B40DCD6169E97F24A40FBE8D495CFAA4B403FE5982CEEEF4A40FBE8D495CFAA4B40
66117	6888	53.722406999999997	53.750911000000002	55.293556000000002	55.281303000000001	Мира	0103000020E6100000010000000500000063B323D577DC4A4023A298BC01A44B4063B323D577DC4A40B5C5353E93A54B40749A05DA1DE04A40B5C5353E93A54B40749A05DA1DE04A4023A298BC01A44B4063B323D577DC4A4023A298BC01A44B40
65762	8154	53.691693999999998	53.718428000000003	55.276021	55.267020000000002	Школьная	0103000020E61000000100000005000000726BD26D89D84A4060B01BB62DA24B40726BD26D89D84A402E01F8A754A34B40EE43DE72F5DB4A402E01F8A754A34B40EE43DE72F5DB4A4060B01BB62DA24B40726BD26D89D84A4060B01BB62DA24B40
64767	7532	53.258902999999997	53.274211000000001	55.166463999999998	55.147658999999997	Речная	0103000020E610000001000000050000000BEBC6BB23A14A40E3FA777DE6924B400BEBC6BB23A14A400DFB3DB14E954B400B9A965819A34A400DFB3DB14E954B400B9A965819A34A40E3FA777DE6924B400BEBC6BB23A14A40E3FA777DE6924B40
64193	7379	53.582863000000003	53.633949999999999	55.028480999999999	55.009647000000001	Ленина	0103000020E61000000100000005000000348639419BCA4A4094C0E61C3C814B40348639419BCA4A4058C7F143A5834B404CA60A4625D14A4058C7F143A5834B404CA60A4625D14A4094C0E61C3C814B40348639419BCA4A4094C0E61C3C814B40
66179	8330	53.609884000000001	53.634425999999998	54.965791000000003	54.952677000000001	Центральная	0103000020E61000000100000005000000452DCDAD10CE4A406153E751F1794B40452DCDAD10CE4A40B5E21B0A9F7B4B40B5DD04DF34D14A40B5E21B0A9F7B4B40B5DD04DF34D14A406153E751F1794B40452DCDAD10CE4A406153E751F1794B40
65305	7077	53.391790999999998	53.431569000000003	55.031221000000002	55.006435000000003	Школьная	0103000020E61000000100000005000000FEEE1D3526B24A405F46B1DCD2804B40FEEE1D3526B24A4066F9BA0CFF834B40D57B2AA73DB74A4066F9BA0CFF834B40D57B2AA73DB74A405F46B1DCD2804B40FEEE1D3526B24A405F46B1DCD2804B40
64756	32117	53.481262999999998	53.509757999999998	55.076673999999997	55.062193999999998	Ленина	0103000020E610000001000000050000002EE3A6069ABD4A40F30016F9F5874B402EE3A6069ABD4A400C3A2174D0894B40EB6F09C03FC14A400C3A2174D0894B40EB6F09C03FC14A40F30016F9F5874B402EE3A6069ABD4A40F30016F9F5874B40
64719	7836	53.981706000000003	53.996932000000001	55.158796000000002	55.142431999999999	Советская	0103000020E61000000100000005000000BC24CE8AA8FD4A40B2F336363B924B40BC24CE8AA8FD4A40295E656D53944B40FE2AC0779BFF4A40295E656D53944B40FE2AC0779BFF4A40B2F336363B924B40BC24CE8AA8FD4A40B2F336363B924B40
65760	47020	53.812283999999998	53.857289000000002	55.289332000000002	55.277251999999997	Центральная	0103000020E6100000010000000500000033880FECF8E74A40136058FE7CA34B4033880FECF8E74A40D8D7BAD408A54B403B1C5DA5BBED4A40D8D7BAD408A54B403B1C5DA5BBED4A40136058FE7CA34B4033880FECF8E74A40136058FE7CA34B40
64345	6784	53.704467999999999	53.740149000000002	55.045361999999997	55.020048000000003	Клубная	0103000020E610000001000000050000000D8AE6012CDA4A40D42CD0EE90824B400D8AE6012CDA4A40963D096CCE854B406495D233BDDE4A40963D096CCE854B406495D233BDDE4A40D42CD0EE90824B400D8AE6012CDA4A40D42CD0EE90824B40
64720	7718	54.201757000000001	54.216957000000001	55.196387000000001	55.177230999999999	Центральная	0103000020E610000001000000050000009A5E622CD3194B402F6B6281AF964B409A5E622CD3194B40062E8F3523994B40B3D1393FC51B4B40062E8F3523994B40B3D1393FC51B4B402F6B6281AF964B409A5E622CD3194B402F6B6281AF964B40
65306	6624	53.643130999999997	53.673943000000001	55.088428999999998	55.074235999999999	Школьная	0103000020E610000001000000050000009A05DA1D52D24A40CA17B49080894B409A05DA1D52D24A404D8237A4518B4B401F2FA4C343D64A404D8237A4518B4B401F2FA4C343D64A40CA17B49080894B409A05DA1D52D24A40CA17B49080894B40
66381	58761	54.084069	54.093356999999997	55.218364000000001	55.204355999999997	Лесная	0103000020E61000000100000005000000C0CDE2C5C20A4B40E55E6056289A4B40C0CDE2C5C20A4B40D74FFF59F39B4B4024ED461FF30B4B40D74FFF59F39B4B4024ED461FF30B4B40E55E6056289A4B40C0CDE2C5C20A4B40E55E6056289A4B40
66071	7284	53.907361000000002	53.936143000000001	55.063684000000002	55.049111000000003	Утина	0103000020E610000001000000050000003B55BE6724F44A40DB6FED4449864B403B55BE6724F44A40A5A31CCC26884B408EB0A888D3F74A40A5A31CCC26884B408EB0A888D3F74A40DB6FED4449864B403B55BE6724F44A40DB6FED4449864B40
64728	47484	54.076864	54.095846000000002	55.080787000000001	55.066251999999999	Центральная	0103000020E61000000100000005000000B01EF7ADD6094B40B5A50EF27A884B40B01EF7ADD6094B409278793A578A4B40E9B985AE440C4B409278793A578A4B40E9B985AE440C4B40B5A50EF27A884B40B01EF7ADD6094B40B5A50EF27A884B40
63722	32794	53.782792000000001	53.818373999999999	55.194614000000001	55.161234	Школьная	0103000020E6100000010000000500000004C93B8732E44A406B80D250A3944B4004C93B8732E44A4000AC8E1CE9984B40C7F2AE7AC0E84A4000AC8E1CE9984B40C7F2AE7AC0E84A406B80D250A3944B4004C93B8732E44A406B80D250A3944B40
63296	32794	53.782792000000001	53.818373999999999	55.194614000000001	55.161234	Ленина	0103000020E6100000010000000500000004C93B8732E44A406B80D250A3944B4004C93B8732E44A4000AC8E1CE9984B40C7F2AE7AC0E84A4000AC8E1CE9984B40C7F2AE7AC0E84A406B80D250A3944B4004C93B8732E44A406B80D250A3944B40
63488	32794	53.782792000000001	53.818373999999999	55.194614000000001	55.161234	Красных партизан	0103000020E6100000010000000500000004C93B8732E44A406B80D250A3944B4004C93B8732E44A4000AC8E1CE9984B40C7F2AE7AC0E84A4000AC8E1CE9984B40C7F2AE7AC0E84A406B80D250A3944B4004C93B8732E44A406B80D250A3944B40
65701	46850	53.697569000000001	53.743732999999999	55.150782	55.133529000000003	Центральная	0103000020E610000001000000050000000ADAE4F049D94A40A708707A17914B400ADAE4F049D94A40A96917D34C934B405DFA97A432DF4A40A96917D34C934B405DFA97A432DF4A40A708707A17914B400ADAE4F049D94A40A708707A17914B40
65704	2687	57.955466000000001	57.97231	52.572822000000002	52.559499000000002	Сакмара	0103000020E610000001000000050000005038BBB54CFA4C408692C9A99D474A405038BBB54CFA4C40F436363B52494A4071C971A774FC4C40F436363B52494A4071C971A774FC4C408692C9A99D474A405038BBB54CFA4C408692C9A99D474A40
65295	5127	58.583182000000001	58.597940999999999	52.624622000000002	52.616174999999998	Мельничная	0103000020E61000000100000005000000D5CE30B5A54A4D4070CE88D2DE4E4A40D5CE30B5A54A4D405A2E1B9DF34F4A4001F8A754894C4D405A2E1B9DF34F4A4001F8A754894C4D4070CE88D2DE4E4A40D5CE30B5A54A4D4070CE88D2DE4E4A40
65310	5766	58.479678	58.492012000000003	52.357627000000001	52.352775000000001	Янгазинская	0103000020E610000001000000050000002B4EB516663D4D4057EC2FBB272D4A402B4EB516663D4D405395B6B8C62D4A40AA9ECC3FFA3E4D405395B6B8C62D4A40AA9ECC3FFA3E4D4057EC2FBB272D4A402B4EB516663D4D4057EC2FBB272D4A40
64007	2347	57.930636999999997	57.951577	52.513382	52.500610000000002	Школьная	0103000020E6100000010000000500000049B9FB1C1FF74C4079060DFD13404A4049B9FB1C1FF74C40732D5A80B6414A401A506F46CDF94C40732D5A80B6414A401A506F46CDF94C4079060DFD13404A4049B9FB1C1FF74C4079060DFD13404A40
65705	2413	57.789197000000001	57.801296999999998	52.524571999999999	52.513623000000003	Чанышева	0103000020E61000000100000005000000F88C446804E54C4099BC0166BE414A40F88C446804E54C40DB32E02C25434A4003B16CE690E64C40DB32E02C25434A4003B16CE690E64C4099BC0166BE414A40F88C446804E54C4099BC0166BE414A40
65247	2996	57.704234	57.724069	52.694626	52.685991000000001	Акназарова	0103000020E610000001000000050000009A5DF75624DA4C40D82C978DCE574A409A5DF75624DA4C40C4793881E9584A401286014BAEDC4C40C4793881E9584A401286014BAEDC4C40D82C978DCE574A409A5DF75624DA4C40D82C978DCE574A40
65876	58651	58.890217	58.904859999999999	52.280206	52.270313999999999	Школьная	0103000020E61000000100000005000000EFAB72A1F2714D4052D32EA699224A40EFAB72A1F2714D404D124BCADD234A40B2BAD573D2734D404D124BCADD234A40B2BAD573D2734D4052D32EA699224A40EFAB72A1F2714D4052D32EA699224A40
66125	4255	58.169741000000002	58.195793000000002	53.136251999999999	53.123176999999998	Башкир	0103000020E610000001000000050000002AE5B512BA154D40484F9143C48F4A402AE5B512BA154D40DE019EB470914A4093E4B9BE0F194D40DE019EB470914A4093E4B9BE0F194D40484F9143C48F4A402AE5B512BA154D40484F9143C48F4A40
65255	58510	58.507660999999999	58.528151000000001	52.880175999999999	52.866159000000003	Мурадым	0103000020E61000000100000005000000323A2009FB404D406B11514CDE6E4A40323A2009FB404D40AF5C6F9BA9704A40C32CB4739A434D40AF5C6F9BA9704A40C32CB4739A434D406B11514CDE6E4A40323A2009FB404D406B11514CDE6E4A40
64182	4589	58.507660999999999	58.528151000000001	52.880175999999999	52.866159000000003	Школьная	0103000020E61000000100000005000000323A2009FB404D406B11514CDE6E4A40323A2009FB404D40AF5C6F9BA9704A40C32CB4739A434D40AF5C6F9BA9704A40C32CB4739A434D406B11514CDE6E4A40323A2009FB404D406B11514CDE6E4A40
64205	4348	58.208359999999999	58.242818999999997	52.907812999999997	52.878329000000001	С.Юлаева	0103000020E61000000100000005000000B4E55C8AAB1A4D406F10AD156D704A40B4E55C8AAB1A4D401BF1643733744A4078EC67B1141F4D401BF1643733744A4078EC67B1141F4D406F10AD156D704A40B4E55C8AAB1A4D406F10AD156D704A40
66913	3809	58.081086999999997	58.139539999999997	53.001786000000003	52.977967999999997	Советская	0103000020E61000000100000005000000BC900E0F610A4D406B44300E2E7D4A40BC900E0F610A4D409BCB0D863A804A40EE3D5C72DC114D409BCB0D863A804A40EE3D5C72DC114D406B44300E2E7D4A40BC900E0F610A4D406B44300E2E7D4A40
63265	3809	58.081086999999997	58.139539999999997	53.001786000000003	52.977967999999997	С.Юлаева	0103000020E61000000100000005000000BC900E0F610A4D406B44300E2E7D4A40BC900E0F610A4D409BCB0D863A804A40EE3D5C72DC114D409BCB0D863A804A40EE3D5C72DC114D406B44300E2E7D4A40BC900E0F610A4D406B44300E2E7D4A40
65717	5001	58.586936999999999	58.606986999999997	52.581135000000003	52.570348000000003	Татлыбаева	0103000020E61000000100000005000000FBE769C0204B4D4065ABCB2901494A40FBE769C0204B4D40CEC7B5A1624A4A406F0C01C0B14D4D40CEC7B5A1624A4A406F0C01C0B14D4D4065ABCB2901494A40FBE769C0204B4D4065ABCB2901494A40
63749	4883	58.545507000000001	58.576867	52.715175000000002	52.699717999999997	Ленина	0103000020E610000001000000050000009A5E622CD3454D401536035C90594A409A5E622CD3454D405AF5B9DA8A5B4A40219221C7D6494D405AF5B9DA8A5B4A40219221C7D6494D401536035C90594A409A5E622CD3454D401536035C90594A40
65710	3954	58.131374000000001	58.150588999999997	52.830655999999998	52.816980999999998	Школьная	0103000020E61000000100000005000000B9C5FCDCD0104D40083A5AD592684A40B9C5FCDCD0104D40F31C91EF526A4A409411178046134D40F31C91EF526A4A409411178046134D40083A5AD592684A40B9C5FCDCD0104D40083A5AD592684A40
65407	58540	55.829756000000003	55.842295999999997	54.788694	54.782054000000002	Молодежная	0103000020E6100000010000000500000074D4D17135EA4B405EDA70581A644B4074D4D17135EA4B409546CCECF3644B409BC6F65AD0EB4B409546CCECF3644B409BC6F65AD0EB4B405EDA70581A644B4074D4D17135EA4B405EDA70581A644B40
64487	2872	57.934634000000003	57.982030000000002	52.641204000000002	52.620942999999997	Ленина	0103000020E6100000010000000500000066DD3F16A2F74C400ED76A0F7B4F4A4066DD3F16A2F74C403E0801F912524A406FD8B628B3FD4C403E0801F912524A406FD8B628B3FD4C400ED76A0F7B4F4A4066DD3F16A2F74C400ED76A0F7B4F4A40
66343	58746	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	Школьная	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
66034	4012	58.157604999999997	58.171556000000002	53.046190000000003	53.027996000000002	Школьная	0103000020E61000000100000005000000D15790662C144D409C35785F95834A40D15790662C144D407DB3CD8DE9854A405FB7088CF5154D407DB3CD8DE9854A405FB7088CF5154D409C35785F95834A40D15790662C144D409C35785F95834A40
79368	61546	58.064988999999997	58.079605000000001	52.699297000000001	52.686366999999997	З.Валиди	0103000020E61000000100000005000000C4CC3E8F51084D40DD06B5DFDA574A40C4CC3E8F51084D407098689082594A408ECC237F300A4D407098689082594A408ECC237F300A4D40DD06B5DFDA574A40C4CC3E8F51084D40DD06B5DFDA574A40
64492	3450	58.027861999999999	58.069704999999999	52.794820000000001	52.784047999999999	К.Диярова	0103000020E610000001000000050000008C6665FB90034D40423F53AF5B644A408C6665FB90034D40761A69A9BC654A4010AFEB17EC084D40761A69A9BC654A4010AFEB17EC084D40423F53AF5B644A408C6665FB90034D40423F53AF5B644A40
65683	58598	58.091777	58.113202000000001	52.904021999999998	52.893445	Тансыккужина	0103000020E6100000010000000500000033C34659BF0B4D402AE3DF675C724A4033C34659BF0B4D40A86E2EFEB6734A40C0EB33677D0E4D40A86E2EFEB6734A40C0EB33677D0E4D402AE3DF675C724A4033C34659BF0B4D402AE3DF675C724A40
66856	58598	58.091777	58.113202000000001	52.904021999999998	52.893445	Сулейманова	0103000020E6100000010000000500000033C34659BF0B4D402AE3DF675C724A4033C34659BF0B4D40A86E2EFEB6734A40C0EB33677D0E4D40A86E2EFEB6734A40C0EB33677D0E4D402AE3DF675C724A4033C34659BF0B4D402AE3DF675C724A40
64152	4376	58.307839000000001	58.327970999999998	52.687354999999997	52.676375999999998	Р.Уметбаева	0103000020E6100000010000000500000078B7B24467274D404FE61F7D93564A4078B7B24467274D40FCDEA63FFB574A40A98427F4FA294D40FCDEA63FFB574A40A98427F4FA294D404FE61F7D93564A4078B7B24467274D404FE61F7D93564A40
64495	3288	58.162635999999999	58.188543000000003	52.672280999999998	52.659194999999997	Аселинская	0103000020E610000001000000050000007D93A641D1144D40E657738060544A407D93A641D1144D40705CC64D0D564A40E371512D22184D40705CC64D0D564A40E371512D22184D40E657738060544A407D93A641D1144D40E657738060544A40
66027	3617	58.065266999999999	58.081454999999998	52.934683	52.920324000000001	Самарбаева	0103000020E61000000100000005000000074147AB5A084D40A9DC442DCD754A40074147AB5A084D4047904AB1A3774A403F8C101E6D0A4D4047904AB1A3774A403F8C101E6D0A4D40A9DC442DCD754A40074147AB5A084D40A9DC442DCD754A40
66585	58852	58.694806999999997	58.704552999999997	52.634974	52.621675000000003	Школьная	0103000020E6100000010000000500000014048F6FEF584D40D3DEE00B934F4A4014048F6FEF584D40B8E7F9D346514A403BA6EECA2E5A4D40B8E7F9D346514A403BA6EECA2E5A4D40D3DEE00B934F4A4014048F6FEF584D40D3DEE00B934F4A40
66143	58716	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	Ирандык	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
66801	2596	57.670699999999997	57.691280999999996	52.423672000000003	52.414296	Почтовая	0103000020E61000000100000005000000AEB6627FD9D54C408B6EBDA607354A40AEB6627FD9D54C408F1D54E23A364A404FAC53E57BD84C408F1D54E23A364A404FAC53E57BD84C408B6EBDA607354A40AEB6627FD9D54C408B6EBDA607354A40
66102	5016	58.601571	58.619833	52.531523999999997	52.523437999999999	Ямаш	0103000020E610000001000000050000006B9C4D47004D4D40E8BD310400434A406B9C4D47004D4D4001857AFA08444A40A4FD0FB0564F4D4001857AFA08444A40A4FD0FB0564F4D40E8BD310400434A406B9C4D47004D4D40E8BD310400434A40
65246	2189	58.106428000000001	58.121142999999996	52.630541999999998	52.619816	С.Юлаева	0103000020E6100000010000000500000079B0C56E9F0D4D40CEC47421564F4A4079B0C56E9F0D4D409160AA99B5504A40D591239D810F4D409160AA99B5504A40D591239D810F4D40CEC47421564F4A4079B0C56E9F0D4D40CEC47421564F4A40
65290	4914	58.738985999999997	58.762045999999998	52.715741999999999	52.708371999999997	Школьная	0103000020E61000000100000005000000D619DF17975E4D4078B306EFAB5A4A40D619DF17975E4D40D32F116F9D5B4A4018062CB98A614D40D32F116F9D5B4A4018062CB98A614D4078B306EFAB5A4A40D619DF17975E4D4078B306EFAB5A4A40
66099	4777	58.721882000000001	58.734926000000002	52.792903000000003	52.780137000000003	Школьная	0103000020E6100000010000000500000019C91EA1665C4D4025B37A87DB634A4019C91EA1665C4D403DF372D87D654A40747D1F0E125E4D403DF372D87D654A40747D1F0E125E4D4025B37A87DB634A4019C91EA1665C4D4025B37A87DB634A40
64722	5754	58.457920999999999	58.476148000000002	52.392670000000003	52.383502999999997	Даута	0103000020E610000001000000050000006893C3279D3A4D407D7555A016314A406893C3279D3A4D40670FB40243324A402507EC6AF23C4D40670FB40243324A402507EC6AF23C4D407D7555A016314A406893C3279D3A4D407D7555A016314A40
65251	4118	57.835487000000001	57.859670000000001	52.966774999999998	52.952449000000001	Куктакинская	0103000020E61000000100000005000000D89DEE3CF1EA4C40D00D4DD9E9794A40D89DEE3CF1EA4C4092CB7F48BF7B4A4019ADA3AA09EE4C4092CB7F48BF7B4A4019ADA3AA09EE4C40D00D4DD9E9794A40D89DEE3CF1EA4C40D00D4DD9E9794A40
64710	2474	57.652689000000002	57.666784	52.490758	52.474930000000001	С.Юлаева	0103000020E61000000100000005000000BFBA2A508BD34C40D4F19881CA3C4A40BFBA2A508BD34C400C207C28D13E4A407FBF982D59D54C400C207C28D13E4A407FBF982D59D54C40D4F19881CA3C4A40BFBA2A508BD34C40D4F19881CA3C4A40
65249	3560	58.240240999999997	58.249116999999998	52.822662999999999	52.816203000000002	Аминева	0103000020E6100000010000000500000044149337C01E4D40D4F2035779684A4044149337C01E4D408B506C054D694A4056F0DB10E31F4D408B506C054D694A4056F0DB10E31F4D40D4F2035779684A4044149337C01E4D40D4F2035779684A40
66096	4561	58.369922000000003	58.386307000000002	52.929910999999997	52.920036000000003	Исрафилова	0103000020E610000001000000050000001409A69A592F4D40439259BDC3754A401409A69A592F4D406798DA5207774A40A29BFD8172314D406798DA5207774A40A29BFD8172314D40439259BDC3754A401409A69A592F4D40439259BDC3754A40
66471	58791	57.681345	57.692259999999997	52.600873999999997	52.583799999999997	Школьная	0103000020E6100000010000000500000085251E5036D74C40D0B359F5B94A4A4085251E5036D74C4023827170E94C4A401B2AC6F99BD84C4023827170E94C4A401B2AC6F99BD84C40D0B359F5B94A4A4085251E5036D74C40D0B359F5B94A4A40
65718	2747	57.951225999999998	57.976576999999999	52.590468999999999	52.581288000000001	Исмагилова	0103000020E610000001000000050000006D8D08C6C1F94C4054C72AA5674A4A406D8D08C6C1F94C40A226FA7C944B4A404D83A27900FD4C40A226FA7C944B4A404D83A27900FD4C4054C72AA5674A4A406D8D08C6C1F94C4054C72AA5674A4A40
66020	2938	57.920234000000001	57.941173999999997	52.618608000000002	52.609056000000002	Школьная	0103000020E6100000010000000500000069554B3ACAF54C405FB7088CF54D4A4069554B3ACAF54C40A185048C2E4F4A4039ECBE6378F84C40A185048C2E4F4A4039ECBE6378F84C405FB7088CF54D4A4069554B3ACAF54C405FB7088CF54D4A40
64219	58192	57.960551000000002	57.991615000000003	52.837477999999997	52.813057000000001	Ленина	0103000020E61000000100000005000000EF91CD55F3FA4C405664744012684A40EF91CD55F3FA4C404B8FA67A326B4A408D9C853DEDFE4C404B8FA67A326B4A408D9C853DEDFE4C405664744012684A40EF91CD55F3FA4C405664744012684A40
66588	58853	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	 Школьная	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
66035	2527	57.553713000000002	57.562831000000003	52.409638000000001	52.400830999999997	Баракал	0103000020E610000001000000050000005E2F4D11E0C64C408A1C226E4E334A405E2F4D11E0C64C4074999A046F344A406616A1D80AC84C4074999A046F344A406616A1D80AC84C408A1C226E4E334A405E2F4D11E0C64C408A1C226E4E334A40
64834	3163	57.988101999999998	58.007578000000002	52.643695999999998	52.633569999999999	Сакмар	0103000020E610000001000000050000005C8E57207AFE4C4005DD5ED218514A405C8E57207AFE4C4073486AA164524A40A515DF50F8004D4073486AA164524A40A515DF50F8004D4005DD5ED218514A405C8E57207AFE4C4005DD5ED218514A40
65934	58666	58.419077999999999	58.437322999999999	52.905639999999998	52.898313000000002	К.Диярова	0103000020E610000001000000050000008E3C1059A4354D402C499EEBFB724A408E3C1059A4354D4087F9F202EC734A40F1643733FA374D4087F9F202EC734A40F1643733FA374D402C499EEBFB724A408E3C1059A4354D402C499EEBFB724A40
66670	4172	58.208917	58.231347999999997	53.084977000000002	53.071500999999998	З.Биишевой	0103000020E610000001000000050000000A4AD1CABD1A4D40CE50DCF126894A400A4AD1CABD1A4D40C3F4BD86E08A4A405CFFAECF9C1D4D40C3F4BD86E08A4A405CFFAECF9C1D4D40CE50DCF126894A400A4AD1CABD1A4D40CE50DCF126894A40
66862	58879	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	Школьная	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
64288	3226	58.071384999999999	58.102215000000001	52.749290000000002	52.729771	Колхозная	0103000020E610000001000000050000006536C82423094D40DC48D922695D4A406536C82423094D40249C16BCE85F4A4090149161150D4D40249C16BCE85F4A4090149161150D4D40DC48D922695D4A406536C82423094D40DC48D922695D4A40
66299	47212	58.425240000000002	58.441706000000003	52.437233999999997	52.434176000000001	Мичурина	0103000020E61000000100000005000000BC79AA436E364D40A35A441493374A40BC79AA436E364D408159A148F7374A4037397CD289384D408159A148F7374A4037397CD289384D40A35A441493374A40BC79AA436E364D40A35A441493374A40
63538	1475	58.282525	58.343341000000002	52.612741	52.564118999999998	проспект С.Юлаева	0103000020E61000000100000005000000B5A679C729244D40AF06280D35484A40B5A679C729244D408CF50D4C6E4E4A401F300F99F22B4D408CF50D4C6E4E4A401F300F99F22B4D40AF06280D35484A40B5A679C729244D40AF06280D35484A40
65300	5837	58.510534999999997	58.534061999999999	52.479098	52.46472	Ургаза	0103000020E610000001000000050000004F3BFC3559414D4008E6E8F17B3B4A404F3BFC3559414D401DCA5015533D4A40A704C4245C444D401DCA5015533D4A40A704C4245C444D4008E6E8F17B3B4A404F3BFC3559414D4008E6E8F17B3B4A40
64712	3392	57.982694000000002	58.005431000000002	52.871974999999999	52.859363000000002	Садовая	0103000020E61000000100000005000000DBFCBFEAC8FD4C403C32569BFF6D4A40DBFCBFEAC8FD4C40FDF675E09C6F4A403AB187F6B1004D40FDF675E09C6F4A403AB187F6B1004D403C32569BFF6D4A40DBFCBFEAC8FD4C403C32569BFF6D4A40
64717	4712	58.520417000000002	58.532283999999997	52.838484999999999	52.828598999999997	Школьная	0103000020E6100000010000000500000027A435069D424D40C83F33880F6A4A4027A435069D424D40E197FA79536B4A408F17D2E121444D40E197FA79536B4A408F17D2E121444D40C83F33880F6A4A4027A435069D424D40C83F33880F6A4A40
66221	3900	58.072068000000002	58.086638000000001	52.973337000000001	52.966867000000001	Школьная	0103000020E61000000100000005000000488B338639094D40734A404CC27B4A40488B338639094D404E7E8B4E967C4A40A14B38F4160B4D404E7E8B4E967C4A40A14B38F4160B4D40734A404CC27B4A40488B338639094D40734A404CC27B4A40
66830	2003	57.801495000000003	57.819704000000002	52.460034	52.448504	Янтура	0103000020E610000001000000050000002A745E6397E64C4006103E9468394A402A745E6397E64C402786E464E23A4A404033880FECE84C402786E464E23A4A404033880FECE84C4006103E9468394A402A745E6397E64C4006103E9468394A40
66016	2141	58.156213000000001	58.181482000000003	52.577638	52.567464000000001	Х.Давлетшиной	0103000020E61000000100000005000000E31A9FC9FE134D4024D40CA9A2484A40E31A9FC9FE134D40A376BF0AF0494A4006685BCD3A174D40A376BF0AF0494A4006685BCD3A174D4024D40CA9A2484A40E31A9FC9FE134D4024D40CA9A2484A40
66693	2067	58.114539999999998	58.140115000000002	52.545420999999997	52.528379999999999	Ленина	0103000020E61000000100000005000000BB0A293FA90E4D4024EEB1F4A1434A40BB0A293FA90E4D409BC6F65AD0454A40EB56CF49EF114D409BC6F65AD0454A40EB56CF49EF114D4024EEB1F4A1434A40BB0A293FA90E4D4024EEB1F4A1434A40
65692	1946	57.856228999999999	57.879216999999997	52.427109000000002	52.417597000000001	Молодёжная	0103000020E61000000100000005000000827170E998ED4C4030F488D173354A40827170E998ED4C40E469F981AB364A402A8BC22E8AF04C40E469F981AB364A402A8BC22E8AF04C4030F488D173354A40827170E998ED4C4030F488D173354A40
66865	5094	58.616959000000001	58.631996999999998	52.560457	52.552370000000003	Центральная	0103000020E6100000010000000500000087FC3383F84E4D4051A5660FB4464A4087FC3383F84E4D403AE8120EBD474A40C6151747E5504D403AE8120EBD474A40C6151747E5504D4051A5660FB4464A4087FC3383F84E4D4051A5660FB4464A40
65292	5094	58.616959000000001	58.631996999999998	52.560457	52.552370000000003	С.Юлаева	0103000020E6100000010000000500000087FC3383F84E4D4051A5660FB4464A4087FC3383F84E4D403AE8120EBD474A40C6151747E5504D403AE8120EBD474A40C6151747E5504D4051A5660FB4464A4087FC3383F84E4D4051A5660FB4464A40
64803	45365	55.646552999999997	55.654179999999997	53.918444999999998	53.908082	Школьная	0103000020E61000000100000005000000BA10AB3FC2D24B400B0BEE073CF44A40BA10AB3FC2D24B405D16139B8FF54A4040D9942BBCD34B405D16139B8FF54A4040D9942BBCD34B400B0BEE073CF44A40BA10AB3FC2D24B400B0BEE073CF44A40
64709	786	55.819676999999999	55.837383000000003	54.038561000000001	54.027132999999999	Ленина	0103000020E6100000010000000500000046240A2DEBE84B4039D2191879034B4046240A2DEBE84B4056F31C91EF044B40FA9CBB5D2FEB4B4056F31C91EF044B40FA9CBB5D2FEB4B4039D2191879034B4046240A2DEBE84B4039D2191879034B40
64197	32463	55.654018000000001	55.68289	53.878394	53.862195999999997	Центральная	0103000020E61000000100000005000000677FA0DCB6D34B40FA5E43705CEE4A40677FA0DCB6D34B405680EF366FF04A40FA6184F068D74B405680EF366FF04A40FA6184F068D74B40FA5E43705CEE4A40677FA0DCB6D34B40FA5E43705CEE4A40
66146	67	55.675839000000003	55.698529999999998	53.897720999999997	53.886392000000001	Центральная	0103000020E61000000100000005000000412E71E481D64B40D0B7054B75F14A40412E71E481D64B4059F78F85E8F24A402FA3586E69D94B4059F78F85E8F24A402FA3586E69D94B40D0B7054B75F14A40412E71E481D64B40D0B7054B75F14A40
64149	1427	56.151865000000001	56.187778999999999	53.964315999999997	53.945740000000001	Центральная	0103000020E610000001000000050000001A34F44F70134C40704221020EF94A401A34F44F70134C403881E9B46EFB4A4013F06B2409184C403881E9B46EFB4A4013F06B2409184C40704221020EF94A401A34F44F70134C40704221020EF94A40
64140	32096	56.230179999999997	56.253509000000001	54.132503999999997	54.120657999999999	Молодежная	0103000020E61000000100000005000000BD18CA89761D4C401900AAB8710F4B40BD18CA89761D4C406A4B1DE4F5104B40EF1EA0FB72204C406A4B1DE4F5104B40EF1EA0FB72204C401900AAB8710F4B40BD18CA89761D4C401900AAB8710F4B40
64711	1213	55.536006999999998	55.554583999999998	54.076101000000001	54.061281000000001	Центральная	0103000020E61000000100000005000000AAB69BE09BC44B40DF6E490ED8074B40AAB69BE09BC44B40B11875ADBD094B404371C79BFCC64B40B11875ADBD094B404371C79BFCC64B40DF6E490ED8074B40AAB69BE09BC44B40DF6E490ED8074B40
65992	1153	55.511645000000001	55.534722000000002	54.019961000000002	54.001458	Центральная	0103000020E61000000100000005000000BA1457957DC14B40A62897C62F004B40BA1457957DC14B40051901158E024B40D2393FC571C44B40051901158E024B40D2393FC571C44B40A62897C62F004B40BA1457957DC14B40A62897C62F004B40
64491	936	55.810890999999998	55.832737999999999	54.224696000000002	54.210628	Чанышева	0103000020E6100000010000000500000074CFBA46CBE74B409ACFB9DBF51A4B4074CFBA46CBE74B4061C5A9D6C21C4B407711A62897EA4B4061C5A9D6C21C4B407711A62897EA4B409ACFB9DBF51A4B4074CFBA46CBE74B409ACFB9DBF51A4B40
64484	844	56.161664999999999	56.190465000000003	54.092289999999998	54.081674	Первомайская	0103000020E6100000010000000500000034F44F70B1144C407D772B4B740A4B4034F44F70B1144C40B9DFA128D00B4B402E04392861184C40B9DFA128D00B4B402E04392861184C407D772B4B740A4B4034F44F70B1144C407D772B4B740A4B40
63566	461	55.869318	55.919128999999998	54.033115000000002	53.978769	Школьная	0103000020E610000001000000050000007DE9EDCF45EF4B4058AB764D48FD4A407DE9EDCF45EF4B40E700C11C3D044B4010E7E104A6F54B40E700C11C3D044B4010E7E104A6F54B4058AB764D48FD4A407DE9EDCF45EF4B4058AB764D48FD4A40
63633	461	55.869318	55.919128999999998	54.033115000000002	53.978769	Химиков	0103000020E610000001000000050000007DE9EDCF45EF4B4058AB764D48FD4A407DE9EDCF45EF4B40E700C11C3D044B4010E7E104A6F54B40E700C11C3D044B4010E7E104A6F54B4058AB764D48FD4A407DE9EDCF45EF4B4058AB764D48FD4A40
63512	461	55.869318	55.919128999999998	54.033115000000002	53.978769	Ленина	0103000020E610000001000000050000007DE9EDCF45EF4B4058AB764D48FD4A407DE9EDCF45EF4B40E700C11C3D044B4010E7E104A6F54B40E700C11C3D044B4010E7E104A6F54B4058AB764D48FD4A407DE9EDCF45EF4B4058AB764D48FD4A40
63510	461	55.869318	55.919128999999998	54.033115000000002	53.978769	Ибрагимова	0103000020E610000001000000050000007DE9EDCF45EF4B4058AB764D48FD4A407DE9EDCF45EF4B40E700C11C3D044B4010E7E104A6F54B40E700C11C3D044B4010E7E104A6F54B4058AB764D48FD4A407DE9EDCF45EF4B4058AB764D48FD4A40
64142	342	55.736690000000003	55.755932000000001	53.969664999999999	53.952798000000001	Фрунзе	0103000020E6100000010000000500000027A5A0DB4BDE4B40DCD8EC48F5F94A4027A5A0DB4BDE4B40B58993FB1DFC4A40FCFF3861C2E04B40B58993FB1DFC4A40FCFF3861C2E04B40DCD8EC48F5F94A4027A5A0DB4BDE4B40DCD8EC48F5F94A40
64486	32031	56.280943999999998	56.296503000000001	54.103065999999998	54.087319999999998	Центральная	0103000020E61000000100000005000000F30016F9F5234C40B324404D2D0B4B40F30016F9F5234C402EAA4544310D4B403C1570CFF3254C402EAA4544310D4B403C1570CFF3254C40B324404D2D0B4B40F30016F9F5234C40B324404D2D0B4B40
64392	274	55.712282999999999	55.748359999999998	54.112546999999999	54.088656999999998	Центральная	0103000020E61000000100000005000000963FDF162CDB4B40DEC7D11C590B4B40963FDF162CDB4B40A721AAF0670E4B4039D1AE42CADF4B40A721AAF0670E4B4039D1AE42CADF4B40DEC7D11C590B4B40963FDF162CDB4B40DEC7D11C590B4B40
64324	153	55.678255	55.692889000000001	54.007877000000001	53.997096999999997	Молодежная	0103000020E610000001000000050000009BAC510FD1D64B4048F8DEDFA0FF4A409BAC510FD1D64B40FFB1101D02014B400B613596B0D84B40FFB1101D02014B400B613596B0D84B4048F8DEDFA0FF4A409BAC510FD1D64B4048F8DEDFA0FF4A40
65987	31920	55.874662999999998	55.908098000000003	53.903700000000001	53.886408000000003	Выездная	0103000020E61000000100000005000000B8020AF5F4EF4B40D6743DD175F14A40B8020AF5F4EF4B4096B20C71ACF34A4011C8258E3CF44B4096B20C71ACF34A4011C8258E3CF44B40D6743DD175F14A40B8020AF5F4EF4B40D6743DD175F14A40
65234	31735	55.916677	55.932721000000001	54.261315000000003	54.248049000000002	Советская	0103000020E6100000010000000500000069FF03AC55F54B401B67D311C01F4B4069FF03AC55F54B40257A19C572214B406EA5D76663F74B40257A19C572214B406EA5D76663F74B401B67D311C01F4B4069FF03AC55F54B401B67D311C01F4B40
64341	32297	55.670834999999997	55.721195000000002	53.825493000000002	53.800660999999998	Советская	0103000020E610000001000000050000008E01D9EBDDD54B406117450F7CE64A408E01D9EBDDD54B40D9092FC1A9E94A40F584251E50DC4B40D9092FC1A9E94A40F584251E50DC4B406117450F7CE64A408E01D9EBDDD54B406117450F7CE64A40
66748	45948	55.521562000000003	55.529502999999998	54.038952000000002	54.031326999999997	Советская	0103000020E610000001000000050000000E6B2A8BC2C24B40AB3DEC8502044B400E6B2A8BC2C24B40910E0F61FC044B4023111AC1C6C34B40910E0F61FC044B4023111AC1C6C34B40AB3DEC8502044B400E6B2A8BC2C24B40AB3DEC8502044B40
65445	3910	55.923341999999998	55.944049	54.059382999999997	54.042521000000001	Центральная	0103000020E61000000100000005000000F982161230F64B405532005471054B40F982161230F64B401C78B5DC99074B402769FE98D6F84B401C78B5DC99074B402769FE98D6F84B405532005471054B40F982161230F64B405532005471054B40
64441	31535	56.069471	56.090797000000002	54.122146000000001	54.107273999999997	Первомайская	0103000020E610000001000000050000009D82FC6CE4084C4005DB8827BB0D4B409D82FC6CE4084C402AABE97AA20F4B4097C9703C9F0B4C402AABE97AA20F4B4097C9703C9F0B4C4005DB8827BB0D4B409D82FC6CE4084C4005DB8827BB0D4B40
65229	31635	55.977483999999997	55.994058000000003	54.208654000000003	54.197673000000002	К.Маркса	0103000020E610000001000000050000007F2E1A321EFD4B40AF264F594D194B407F2E1A321EFD4B40FD169D2CB51A4B40E129E44A3DFF4B40FD169D2CB51A4B40E129E44A3DFF4B40AF264F594D194B407F2E1A321EFD4B40AF264F594D194B40
64707	31316	55.955322000000002	55.969399000000003	54.030904	54.024794999999997	Школьная	0103000020E610000001000000050000001D93C5FD47FA4B405A0D897B2C034B401D93C5FD47FA4B4065A88AA9F4034B4037E3344415FC4B4065A88AA9F4034B4037E3344415FC4B405A0D897B2C034B401D93C5FD47FA4B405A0D897B2C034B40
66436	58774	55.549365000000002	55.567888000000004	53.794539	53.781787999999999	Центральная	0103000020E610000001000000050000009548A29751C64B40DF3312A111E44A409548A29751C64B40C2323674B3E54A403BE5D18DB0C84B40C2323674B3E54A403BE5D18DB0C84B40DF3312A111E44A409548A29751C64B40DF3312A111E44A40
64321	31215	55.765275000000003	55.791038999999998	53.906717999999998	53.881774999999998	Центральная	0103000020E6100000010000000500000024B9FC87F4E14B4017B7D100DEF04A4024B9FC87F4E14B40E658DE550FF44A40266E15C440E54B40E658DE550FF44A40266E15C440E54B4017B7D100DEF04A4024B9FC87F4E14B4017B7D100DEF04A40
65620	31412	56.093178000000002	56.119515999999997	54.075901000000002	54.058284	7 Ноября	0103000020E61000000100000005000000755AB741ED0B4C40A6F0A0D975074B40755AB741ED0B4C40EA5DBC1FB7094B40A3ACDF4C4C0F4C40EA5DBC1FB7094B40A3ACDF4C4C0F4C40A6F0A0D975074B40755AB741ED0B4C40A6F0A0D975074B40
64878	58380	55.462561000000001	56.391877000000001	54.291207	53.763508999999999	Школьная	0103000020E61000000100000005000000D9B3E73235BB4B40D099B4A9BAE14A40D9B3E73235BB4B40E2AE5E4546254B40FD86890629324C40E2AE5E4546254B40FD86890629324C40D099B4A9BAE14A40D9B3E73235BB4B40D099B4A9BAE14A40
66010	31962	55.615957000000002	55.739061999999997	53.968426000000001	53.905917000000002	Ленина	0103000020E61000000100000005000000035FD1ADD7CE4B40FAF19716F5F34A40035FD1ADD7CE4B404D4C1762F5FB4A40B1DB679599DE4B404D4C1762F5FB4A40B1DB679599DE4B40FAF19716F5F34A40035FD1ADD7CE4B40FAF19716F5F34A40
64077	31821	55.801279000000001	55.837148999999997	53.847883000000003	53.834229999999998	Центральная	0103000020E610000001000000050000005DFC6D4F90E64B40C9AB730CC8EA4A405DFC6D4F90E64B40CDEA1D6E87EC4A408670CCB227EB4B40CDEA1D6E87EC4A408670CCB227EB4B40C9AB730CC8EA4A405DFC6D4F90E64B40C9AB730CC8EA4A40
65619	31851	55.763945	55.787975000000003	53.861080999999999	53.843904000000002	Циолковского	0103000020E61000000100000005000000AB7823F3C8E14B40577BD80B05EC4A40AB7823F3C8E14B407E1AF7E637EE4A406688635DDCE44B407E1AF7E637EE4A406688635DDCE44B40577BD80B05EC4A40AB7823F3C8E14B40577BD80B05EC4A40
65240	932	56.217514000000001	56.235534000000001	54.067807000000002	54.053595999999999	Восточная	0103000020E610000001000000050000000936AE7FD71B4C402499D53BDC064B400936AE7FD71B4C404EB857E6AD084B404C8C65FA251E4C404EB857E6AD084B404C8C65FA251E4C402499D53BDC064B400936AE7FD71B4C402499D53BDC064B40
65617	31518	56.008654999999997	56.027133999999997	54.141260000000003	54.131053000000001	Ленина	0103000020E6100000010000000500000033F9669B1B014C4077853E58C6104B4033F9669B1B014C40D21DC4CE14124B40094E7D2079034C40D21DC4CE14124B40094E7D2079034C4077853E58C6104B4033F9669B1B014C4077853E58C6104B40
66825	58876	55.746374000000003	55.756084999999999	54.229033000000001	54.224316999999999	Центральная	0103000020E61000000100000005000000D84AE82E89DF4B40EA77616BB61C4B40D84AE82E89DF4B40365A0EF4501D4B4082FFAD64C7E04B40365A0EF4501D4B4082FFAD64C7E04B40EA77616BB61C4B40D84AE82E89DF4B40EA77616BB61C4B40
64280	32248	55.797893000000002	55.826324	54.108445000000003	54.090595	Ленина	0103000020E610000001000000050000008A5A9A5B21E64B402F17F19D980B4B408A5A9A5B21E64B4016359886E10D4B4030F31DFCC4E94B4016359886E10D4B4030F31DFCC4E94B402F17F19D980B4B408A5A9A5B21E64B402F17F19D980B4B40
65242	1326	55.620538000000003	55.648116999999999	54.145499999999998	54.128942000000002	Школьная	0103000020E610000001000000050000006FF607CA6DCF4B40598AE42B81104B406FF607CA6DCF4B40B4C876BE9F124B40A67D737FF5D24B40B4C876BE9F124B40A67D737FF5D24B40598AE42B81104B406FF607CA6DCF4B40598AE42B81104B40
64469	31284	56.030799000000002	56.04766	54.027301999999999	54.009348000000003	Садовая	0103000020E61000000100000005000000F0DFBC38F1034C403A24B55032014B40F0DFBC38F1034C40C58EC6A17E034B40E7A90EB919064C40C58EC6A17E034B40E7A90EB919064C403A24B55032014B40F0DFBC38F1034C403A24B55032014B40
64279	31761	55.919569000000003	55.952789000000003	53.948453000000001	53.934674000000001	Мира	0103000020E610000001000000050000002DB5DE6FB4F54B40F435CB65A3F74A402DB5DE6FB4F54B4084656CE866F94A40897E6DFDF4F94B4084656CE866F94A40897E6DFDF4F94B40F435CB65A3F74A402DB5DE6FB4F54B40F435CB65A3F74A40
66464	58787	55.462561000000001	56.391877000000001	54.291207	53.763508999999999	Центральная	0103000020E61000000100000005000000D9B3E73235BB4B40D099B4A9BAE14A40D9B3E73235BB4B40E2AE5E4546254B40FD86890629324C40E2AE5E4546254B40FD86890629324C40D099B4A9BAE14A40D9B3E73235BB4B40D099B4A9BAE14A40
64273	31682	55.888640000000002	55.920701000000001	54.207889999999999	54.187654000000002	Ленина	0103000020E610000001000000050000006FF59CF4BEF14B40577BD80B05184B406FF59CF4BEF14B402D95B7239C1A4B407F32C687D9F54B402D95B7239C1A4B407F32C687D9F54B40577BD80B05184B406FF59CF4BEF14B40577BD80B05184B40
64391	31599	55.932963000000001	55.970998000000002	54.175566000000003	54.162430999999998	Центральная	0103000020E6100000010000000500000064B0E2546BF74B40A46DFC89CA144B4064B0E2546BF74B4010255AF278164B409F3D97A949FC4B4010255AF278164B409F3D97A949FC4B40A46DFC89CA144B4064B0E2546BF74B40A46DFC89CA144B40
65664	1047	55.816470000000002	55.843743000000003	54.178918000000003	54.162878999999997	Центральная	0103000020E610000001000000050000002315C61682E84B40431A1538D9144B402315C61682E84B403755F7C8E6164B404E9D47C5FFEB4B403755F7C8E6164B404E9D47C5FFEB4B40431A1538D9144B402315C61682E84B40431A1538D9144B40
64326	31429	56.095261999999998	56.145541000000001	53.990336999999997	53.972662999999997	Центральная	0103000020E610000001000000050000009946938B310C4C40BE839F3880FC4A409946938B310C4C406682E15CC3FE4A40139D6516A1124C406682E15CC3FE4A40139D6516A1124C40BE839F3880FC4A409946938B310C4C40BE839F3880FC4A40
66594	28776	55.804765000000003	55.831291999999998	53.962524999999999	53.943801000000001	Центральная	0103000020E6100000010000000500000094FB1D8A02E74B404F779E78CEF84A4094FB1D8A02E74B408C4AEA0434FB4A4095B6B8C667EA4B408C4AEA0434FB4A4095B6B8C667EA4B404F779E78CEF84A4094FB1D8A02E74B404F779E78CEF84A40
65633	32425	55.686124	55.710711000000003	53.843113000000002	53.826991999999997	Центральная	0103000020E61000000100000005000000178046E9D2D74B40DD06B5DFDAE94A40178046E9D2D74B408EEA7420EBEB4A4028F4FA93F8DA4B408EEA7420EBEB4A4028F4FA93F8DA4B40DD06B5DFDAE94A40178046E9D2D74B40DD06B5DFDAE94A40
65243	1089	55.700083999999997	55.713146000000002	54.242010000000001	54.229774999999997	Школьная	0103000020E61000000100000005000000F7393E5A9CD94B401D386744691D4B40F7393E5A9CD94B4009A7052FFA1E4B40F9A23D5E48DB4B4009A7052FFA1E4B40F9A23D5E48DB4B401D386744691D4B40F7393E5A9CD94B401D386744691D4B40
63546	11407	55.733941999999999	55.753103000000003	53.870691999999998	53.860635000000002	Школьная	0103000020E610000001000000050000009694BBCFF1DD4B408065A54929EE4A409694BBCFF1DD4B40C571E0D572EF4A407FC2D9AD65E04B40C571E0D572EF4A407FC2D9AD65E04B408065A54929EE4A409694BBCFF1DD4B408065A54929EE4A40
63563	11407	55.733941999999999	55.753103000000003	53.870691999999998	53.860635000000002	Лесохимическая	0103000020E610000001000000050000009694BBCFF1DD4B408065A54929EE4A409694BBCFF1DD4B40C571E0D572EF4A407FC2D9AD65E04B40C571E0D572EF4A407FC2D9AD65E04B408065A54929EE4A409694BBCFF1DD4B408065A54929EE4A40
66648	224	55.721114	55.730024999999998	54.052554999999998	54.039073999999999	Ленина	0103000020E610000001000000050000000858AB764DDC4B40DC0F786000054B400858AB764DDC4B40E21E4B1FBA064B4096218E7571DD4B40E21E4B1FBA064B4096218E7571DD4B40DC0F786000054B400858AB764DDC4B40DC0F786000054B40
64699	30899	57.165047999999999	57.189777999999997	56.085656	56.070222999999999	Центральная	0103000020E610000001000000050000009622F94A20954C40A8363811FD084C409622F94A20954C40645A9BC6F60A4C4009C03FA54A984C40645A9BC6F60A4C4009C03FA54A984C40A8363811FD084C409622F94A20954C40A8363811FD084C40
65535	29560	56.373668000000002	56.395757000000003	55.918908000000002	55.905245000000001	Центральная	0103000020E61000000100000005000000E7C75F5AD42F4C400BEF7211DFF34B40E7C75F5AD42F4C40320400C79EF54B40E014562AA8324C40320400C79EF54B40E014562AA8324C400BEF7211DFF34B40E7C75F5AD42F4C400BEF7211DFF34B40
64754	30325	56.785932000000003	56.813214000000002	56.097552999999998	56.084169000000003	Крупской	0103000020E61000000100000005000000A070766B99644C40242BBF0CC60A4C40A070766B99644C403750E09D7C0C4C401E53776517684C403750E09D7C0C4C401E53776517684C40242BBF0CC60A4C40A070766B99644C40242BBF0CC60A4C40
65221	31127	57.450127999999999	57.477804999999996	56.139958	56.122886000000001	Гагарина	0103000020E61000000100000005000000C78157CB9DB94C4071917BBABA0F4C40C78157CB9DB94C402368CC24EA114C40C16ED8B628BD4C402368CC24EA114C40C16ED8B628BD4C4071917BBABA0F4C40C78157CB9DB94C4071917BBABA0F4C40
64703	31110	57.071990999999997	57.090263	56.158119999999997	56.141382	Набережная	0103000020E610000001000000050000009C4D470037894C401D1F2DCE18124C409C4D470037894C40F86BB2463D144C40F984ECBC8D8B4C40F86BB2463D144C40F984ECBC8D8B4C401D1F2DCE18124C409C4D470037894C401D1F2DCE18124C40
64742	29709	56.483333999999999	56.519526999999997	55.934305999999999	55.922367999999999	Центральная	0103000020E61000000100000005000000BE8575E3DD3D4C403F70952710F64B40BE8575E3DD3D4C40713AC95697F74B40CA3159DC7F424C40713AC95697F74B40CA3159DC7F424C403F70952710F64B40BE8575E3DD3D4C403F70952710F64B40
64672	47344	56.341948000000002	56.376137999999997	56.354661999999998	56.340116000000002	Лесная	0103000020E610000001000000050000006077BAF3C42B4C40556CCCEB882B4C406077BAF3C42B4C4025917D90652D4C4034643C4A25304C4025917D90652D4C4034643C4A25304C40556CCCEB882B4C406077BAF3C42B4C40556CCCEB882B4C40
64657	29372	56.603546999999999	56.629041000000001	56.267412	56.256633000000001	Цветочная	0103000020E61000000100000005000000A94C3107414D4C408509A359D9204C40A94C3107414D4C406B47718E3A224C40EC6B5D6A84504C406B47718E3A224C40EC6B5D6A84504C408509A359D9204C40A94C3107414D4C408509A359D9204C40
65235	29275	56.468341000000002	56.499305999999997	56.240098000000003	56.227054000000003	Юбилейная	0103000020E610000001000000050000001F300F99F23B4C408736001B101D4C401F300F99F23B4C40E2EA0088BB1E4C4029594E42E93F4C40E2EA0088BB1E4C4029594E42E93F4C408736001B101D4C401F300F99F23B4C408736001B101D4C40
65568	30841	57.128864	57.149892999999999	56.042254999999997	56.018177000000001	Центральная	0103000020E61000000100000005000000DDD0949D7E904C400B45BA9F53024C40DDD0949D7E904C40D68BA19C68054C401D739EB12F934C40D68BA19C68054C401D739EB12F934C400B45BA9F53024C40DDD0949D7E904C400B45BA9F53024C40
65539	29642	56.473336000000003	56.489685000000001	56.033419000000002	56.023902	Механизаторов	0103000020E610000001000000050000007E022846963C4C408D2782380F034C407E022846963C4C405308E41247044C40BF2B82FFAD3E4C405308E41247044C40BF2B82FFAD3E4C408D2782380F034C407E022846963C4C408D2782380F034C40
64753	30625	56.273003000000003	56.296512	56.226148999999999	56.216743999999998	Центральная	0103000020E61000000100000005000000DE5A26C3F1224C4057CD7344BE1B4C40DE5A26C3F1224C40F5824F73F21C4C408F6FEF1AF4254C40F5824F73F21C4C408F6FEF1AF4254C4057CD7344BE1B4C40DE5A26C3F1224C4057CD7344BE1B4C40
64261	29751	56.208989000000003	56.242415000000001	56.214171999999998	56.194918999999999	Школьная	0103000020E61000000100000005000000A41CCC26C01A4C403C2F151BF3184C40A41CCC26C01A4C4005DCF3FC691B4C40A9876874071F4C4005DCF3FC691B4C40A9876874071F4C403C2F151BF3184C40A41CCC26C01A4C403C2F151BF3184C40
64700	29751	56.208989000000003	56.242415000000001	56.214171999999998	56.194918999999999	Центральная	0103000020E61000000100000005000000A41CCC26C01A4C403C2F151BF3184C40A41CCC26C01A4C4005DCF3FC691B4C40A9876874071F4C4005DCF3FC691B4C40A9876874071F4C403C2F151BF3184C40A41CCC26C01A4C403C2F151BF3184C40
65562	8554	56.268816000000001	56.291328	56.293607000000002	56.271590000000003	Гумерова	0103000020E610000001000000050000001E520C9068224C40D8F50B76C3224C401E520C9068224C40377007EA94254C405D34643C4A254C40377007EA94254C405D34643C4A254C40D8F50B76C3224C401E520C9068224C40D8F50B76C3224C40
66526	58822	56.136890000000001	57.596876999999999	56.405748000000003	55.878708000000003	Советская	0103000020E6100000010000000500000021938C9C85114C40E65DF58079F04B4021938C9C85114C406E35EB8CEF334C40075E2D7766CC4C406E35EB8CEF334C40075E2D7766CC4C40E65DF58079F04B4021938C9C85114C40E65DF58079F04B40
64704	31001	56.844321999999998	56.869025999999998	56.089633999999997	56.083163999999996	Трактовая	0103000020E610000001000000050000008BA548BE126C4C402E1A321EA50A4C408BA548BE126C4C40094E7D20790B4C40D5AF743E3C6F4C40094E7D20790B4C40D5AF743E3C6F4C402E1A321EA50A4C408BA548BE126C4C402E1A321EA50A4C40
65968	29856	56.244911999999999	56.267065000000002	56.135418000000001	56.126634000000003	Школьная	0103000020E61000000100000005000000F032C346591F4C40E547FC8A35104C40F032C346591F4C4016A5846055114C400074982F2F224C4016A5846055114C400074982F2F224C40E547FC8A35104C40F032C346591F4C40E547FC8A35104C40
65956	29349	56.667955999999997	56.688276000000002	56.171422999999997	56.147004000000003	Школьная	0103000020E610000001000000050000005F950B957F554C40CB30EE06D1124C405F950B957F554C401F645930F1154C40944F8F6D19584C401F645930F1154C40944F8F6D19584C40CB30EE06D1124C405F950B957F554C40CB30EE06D1124C40
64909	30706	56.331726000000003	56.358477000000001	56.217965999999997	56.201815000000003	Центральная	0103000020E61000000100000005000000D09D60FF752A4C40CF6BEC12D5194C40D09D60FF752A4C40E9D1544FE61B4C4021AF0793E22D4C40E9D1544FE61B4C4021AF0793E22D4C40CF6BEC12D5194C40D09D60FF752A4C40CF6BEC12D5194C40
64701	30387	56.758291	56.779795999999997	56.058453	56.041922999999997	Ленина	0103000020E61000000100000005000000F2ECF2AD0F614C40A0F99CBB5D054C40F2ECF2AD0F614C4032AD4D637B074C409BC6F65AD0634C4032AD4D637B074C409BC6F65AD0634C40A0F99CBB5D054C40F2ECF2AD0F614C40A0F99CBB5D054C40
65975	30498	56.336226000000003	56.361756	56.293951	56.278373000000002	Школьная	0103000020E610000001000000050000004F081D74092B4C40728BF9B9A1234C404F081D74092B4C4031D0B52FA0254C40DE9046054E2E4C4031D0B52FA0254C40DE9046054E2E4C40728BF9B9A1234C404F081D74092B4C40728BF9B9A1234C40
64695	29445	56.556097999999999	56.592336000000003	56.025858999999997	56.002329000000003	Крестьянская	0103000020E610000001000000050000007DAF21382E474C408C6A11514C004C407DAF21382E474C4054A703594F034C402A1F82AAD14B4C4054A703594F034C402A1F82AAD14B4C408C6A11514C004C407DAF21382E474C408C6A11514C004C40
65973	30416	57.289842	57.322387999999997	56.227640000000001	56.201214	Молодежная	0103000020E61000000100000005000000ED80EB8A19A54C40A9BF5E61C1194C40ED80EB8A19A54C4077A1B94E231D4C40B94F8E0244A94C4077A1B94E231D4C40B94F8E0244A94C40A9BF5E61C1194C40ED80EB8A19A54C40A9BF5E61C1194C40
65559	30217	56.718235	56.766914	56.114586000000003	56.092998000000001	Ленина	0103000020E61000000100000005000000D9EBDD1FEF5B4C40F54BC45BE70B4C40D9EBDD1FEF5B4C402C4A09C1AA0E4C401A6CEA3C2A624C402C4A09C1AA0E4C401A6CEA3C2A624C40F54BC45BE70B4C40D9EBDD1FEF5B4C40F54BC45BE70B4C40
65556	30205	56.369050999999999	56.385956999999998	55.992159999999998	55.976900999999998	Центральная	0103000020E610000001000000050000002EC72B103D2F4C4000378B170BFD4B402EC72B103D2F4C401E335019FFFE4B40C554FA0967314C401E335019FFFE4B40C554FA0967314C4000378B170BFD4B402EC72B103D2F4C4000378B170BFD4B40
65980	30798	56.310597000000001	56.361226000000002	56.064051999999997	56.042084000000003	Центральная	0103000020E610000001000000050000002C9E7AA4C1274C40AAD72D0263054C402C9E7AA4C1274C40279F1EDB32084C40823B50A73C2E4C40279F1EDB32084C40823B50A73C2E4C40AAD72D0263054C402C9E7AA4C1274C40AAD72D0263054C40
65550	29902	56.979607999999999	57.011175000000001	56.031005	56.013250999999997	Мира	0103000020E61000000100000005000000327381CB637D4C40D4D17135B2014C40327381CB637D4C409981CAF8F7034C4033C4B12E6E814C409981CAF8F7034C4033C4B12E6E814C40D4D17135B2014C40327381CB637D4C40D4D17135B2014C40
65215	30138	56.572034000000002	56.607284	55.954138	55.933025000000001	Центральная	0103000020E610000001000000050000009C19FD6838494C40DAACFA5C6DF74B409C19FD6838494C4078EFA83121FA4B4029B16B7BBB4D4C4078EFA83121FA4B4029B16B7BBB4D4C40DAACFA5C6DF74B409C19FD6838494C40DAACFA5C6DF74B40
64740	29623	56.505406000000001	56.519230999999998	56.001810999999996	55.988202999999999	Центральная	0103000020E61000000100000005000000E199D024B1404C409067976F7DFE4B40E199D024B1404C40F3E2C4573B004C40E108522976424C40F3E2C4573B004C40E108522976424C409067976F7DFE4B40E199D024B1404C409067976F7DFE4B40
64702	30110	57.043056	57.061363999999998	56.002288999999998	55.990749999999998	Первомайская	0103000020E61000000100000005000000C3F2E7DB82854C40894160E5D0FE4B40C3F2E7DB82854C40FD1186014B004C406C938AC6DA874C40FD1186014B004C406C938AC6DA874C40894160E5D0FE4B40C3F2E7DB82854C40894160E5D0FE4B40
65978	30043	56.886201999999997	56.923068999999998	56.010483000000001	55.996172999999999	Первомайская	0103000020E610000001000000050000002CD32F116F714C404014CC9882FF4B402CD32F116F714C40FD14C78157014C40C879FF1F27764C40FD14C78157014C40C879FF1F27764C404014CC9882FF4B402CD32F116F714C404014CC9882FF4B40
65938	29291	56.539209	56.561092000000002	56.149335999999998	56.137414999999997	Лесная	0103000020E61000000100000005000000BC5AEECC04454C406B7D91D096114C40BC5AEECC04454C40C70E2A711D134C400C06D7DCD1474C40C70E2A711D134C400C06D7DCD1474C406B7D91D096114C40BC5AEECC04454C406B7D91D096114C40
66786	28737	56.391437000000003	56.421979	56.355269999999997	56.340355000000002	Центральная	0103000020E61000000100000005000000E1B88C9B1A324C40DA03ADC0902B4C40E1B88C9B1A324C40FD9FC37C792D4C40A54C6A6803364C40FD9FC37C792D4C40A54C6A6803364C40DA03ADC0902B4C40E1B88C9B1A324C40DA03ADC0902B4C40
63372	29025	56.537539000000002	56.613104999999997	56.110971999999997	56.075031000000003	Пионерская	0103000020E610000001000000050000008BA9F413CE444C40D597A59D9A094C408BA9F413CE444C40C7629B54340E4C40CD0182397A4E4C40C7629B54340E4C40CD0182397A4E4C40D597A59D9A094C408BA9F413CE444C40D597A59D9A094C40
63634	29025	56.537539000000002	56.613104999999997	56.110971999999997	56.075031000000003	Октябрьская	0103000020E610000001000000050000008BA9F413CE444C40D597A59D9A094C408BA9F413CE444C40C7629B54340E4C40CD0182397A4E4C40C7629B54340E4C40CD0182397A4E4C40D597A59D9A094C408BA9F413CE444C40D597A59D9A094C40
63459	29025	56.537539000000002	56.613104999999997	56.110971999999997	56.075031000000003	Мичурина	0103000020E610000001000000050000008BA9F413CE444C40D597A59D9A094C408BA9F413CE444C40C7629B54340E4C40CD0182397A4E4C40C7629B54340E4C40CD0182397A4E4C40D597A59D9A094C408BA9F413CE444C40D597A59D9A094C40
66637	29025	56.537539000000002	56.613104999999997	56.110971999999997	56.075031000000003	Мира	0103000020E610000001000000050000008BA9F413CE444C40D597A59D9A094C408BA9F413CE444C40C7629B54340E4C40CD0182397A4E4C40C7629B54340E4C40CD0182397A4E4C40D597A59D9A094C408BA9F413CE444C40D597A59D9A094C40
64483	29025	56.537539000000002	56.613104999999997	56.110971999999997	56.075031000000003	Ленина	0103000020E610000001000000050000008BA9F413CE444C40D597A59D9A094C408BA9F413CE444C40C7629B54340E4C40CD0182397A4E4C40C7629B54340E4C40CD0182397A4E4C40D597A59D9A094C408BA9F413CE444C40D597A59D9A094C40
65536	29534	56.354146999999998	56.376739999999998	55.958033	55.945846000000003	Центральная	0103000020E61000000100000005000000FE7C5BB0542D4C40B686527B11F94B40FE7C5BB0542D4C4090BE49D3A0FA4B402A8C2D0439304C4090BE49D3A0FA4B402A8C2D0439304C40B686527B11F94B40FE7C5BB0542D4C40B686527B11F94B40
64748	29280	56.961300999999999	56.987836999999999	56.044165999999997	56.029772999999999	Центральная	0103000020E61000000100000005000000594E42E90B7B4C40E3A6069ACF034C40594E42E90B7B4C402DCC423BA7054C40AE635C71717E4C402DCC423BA7054C40AE635C71717E4C40E3A6069ACF034C40594E42E90B7B4C40E3A6069ACF034C40
65211	29007	56.929968000000002	56.959612	54.526743000000003	54.510897	Центральная	0103000020E61000000100000005000000CC29013109774C40F04FA91265414B40CC29013109774C40CF328B506C434B40B16CE690D47A4C40CF328B506C434B40B16CE690D47A4C40F04FA91265414B40CC29013109774C40F04FA91265414B40
65598	13952	56.824981000000001	56.840828000000002	54.235390000000002	54.222515999999999	Центральная	0103000020E61000000100000005000000236937FA98694C401A6B7F677B1C4B40236937FA98694C4019E76F42211E4B40D2C77C40A06B4C4019E76F42211E4B40D2C77C40A06B4C401A6B7F677B1C4B40236937FA98694C401A6B7F677B1C4B40
65483	58553	56.668908000000002	56.699199	54.633733999999997	54.620662000000003	Заречная	0103000020E61000000100000005000000320400C79E554C405BEF37DA714F4B40320400C79E554C407F2E1A321E514B40AD32535A7F594C407F2E1A321E514B40AD32535A7F594C405BEF37DA714F4B40320400C79E554C405BEF37DA714F4B40
64409	7491	56.930892999999998	56.983713999999999	54.438476000000001	54.423873999999998	Школьная	0103000020E61000000100000005000000A489778027774C40F6CFD38041364B40A489778027774C405B0A48FB1F384B40054F2157EA7D4C405B0A48FB1F384B40054F2157EA7D4C40F6CFD38041364B40A489778027774C40F6CFD38041364B40
66005	28870	56.739291000000001	56.775224000000001	54.473731999999998	54.463104999999999	Школьная	0103000020E61000000100000005000000139D6516A15E4C409ACE4E06473B4B40139D6516A15E4C40CA880B40A33C4B4083893F8A3A634C40CA880B40A33C4B4083893F8A3A634C409ACE4E06473B4B40139D6516A15E4C409ACE4E06473B4B40
65126	47461	56.785249	56.801867999999999	54.596190999999997	54.589346999999997	Школьная	0103000020E61000000100000005000000BD1B0B0A83644C40737FF5B86F4B4B40BD1B0B0A83644C40B39597FC4F4C4B40BEDA519CA3664C40B39597FC4F4C4B40BEDA519CA3664C40737FF5B86F4B4B40BD1B0B0A83644C40737FF5B86F4B4B40
66004	28803	56.736550999999999	56.752254000000001	54.449863000000001	54.444637999999998	Вокзальная	0103000020E61000000100000005000000056B9C4D475E4C408847E2E5E9384B40056B9C4D475E4C4019575C1C95394B408124ECDB49604C4019575C1C95394B408124ECDB49604C408847E2E5E9384B40056B9C4D475E4C408847E2E5E9384B40
66352	58623	56.563400999999999	56.589551	54.337226999999999	54.322678000000003	Центральная	0103000020E6100000010000000500000050C422861D484C40C19140834D294B4050C422861D484C40022A1C412A2B4B407C293C68764B4C40022A1C412A2B4B407C293C68764B4C40C19140834D294B4050C422861D484C40C19140834D294B40
65759	58623	56.563400999999999	56.589551	54.337226999999999	54.322678000000003	 Казаковская	0103000020E6100000010000000500000050C422861D484C40C19140834D294B4050C422861D484C40022A1C412A2B4B407C293C68764B4C40022A1C412A2B4B407C293C68764B4C40C19140834D294B4050C422861D484C40C19140834D294B40
64150	32842	56.779032999999998	56.803027	54.308325000000004	54.291454000000002	Ленина	0103000020E610000001000000050000009CC0745AB7634C40EA245B5D4E254B409CC0745AB7634C4005C58F3177274B400A67B796C9664C4005C58F3177274B400A67B796C9664C40EA245B5D4E254B409CC0745AB7634C40EA245B5D4E254B40
65782	28453	56.666212999999999	56.681161000000003	54.339829999999999	54.326349	Центральная	0103000020E61000000100000005000000C495B37746554C40890AD5CDC5294B40C495B37746554C408F19A88C7F2B4B40C4279D4830574C408F19A88C7F2B4B40C4279D4830574C40890AD5CDC5294B40C495B37746554C40890AD5CDC5294B40
65737	28406	56.603017000000001	56.624549000000002	54.328989999999997	54.312232999999999	Центральная	0103000020E610000001000000050000004DF73AA92F4D4C40B1DD3D40F7274B404DF73AA92F4D4C40035B25581C2A4B40F0DFBC38F14F4C40035B25581C2A4B40F0DFBC38F14F4C40B1DD3D40F7274B404DF73AA92F4D4C40B1DD3D40F7274B40
66646	27830	57.109298000000003	57.125818000000002	54.416173000000001	54.401721000000002	Центральная	0103000020E6100000010000000500000055C2137AFD8D4C40E78EFE976B334B4055C2137AFD8D4C40363D282845354B40C39FE1CD1A904C40363D282845354B40C39FE1CD1A904C40E78EFE976B334B4055C2137AFD8D4C40E78EFE976B334B40
66516	28723	56.493602000000003	56.514792999999997	54.381638000000002	54.365468999999997	 Нефтяников	0103000020E61000000100000005000000BF9EAF592E3F4C40D5592DB0C72E4B40BF9EAF592E3F4C4097749483D9304B40D89AADBCE4414C4097749483D9304B40D89AADBCE4414C40D5592DB0C72E4B40BF9EAF592E3F4C40D5592DB0C72E4B40
65050	58448	56.829635000000003	56.849567999999998	54.524773000000003	54.502847000000003	Озерная	0103000020E61000000100000005000000F94ECC7A316A4C4024F25D4A5D404B40F94ECC7A316A4C407369FCC22B434B4033DDEBA4BE6C4C407369FCC22B434B4033DDEBA4BE6C4C4024F25D4A5D404B40F94ECC7A316A4C4024F25D4A5D404B40
66188	47372	56.807409999999997	56.826777999999997	54.283113	54.274318000000001	Школьная	0103000020E610000001000000050000004F3BFC3559674C40215A2BDA1C234B404F3BFC3559674C404609FA0B3D244B40B1868BDCD3694C404609FA0B3D244B40B1868BDCD3694C40215A2BDA1C234B404F3BFC3559674C40215A2BDA1C234B40
64858	28334	56.692129999999999	56.712539	54.319113000000002	54.306007999999999	Нижняя	0103000020E610000001000000050000004D4A41B797584C403D2828452B274B404D4A41B797584C403E5DDDB1D8284B40F10F5B7A345B4C403E5DDDB1D8284B40F10F5B7A345B4C403D2828452B274B404D4A41B797584C403D2828452B274B40
64268	33045	56.873688000000001	56.891322000000002	54.550503999999997	54.532755999999999	Советская	0103000020E610000001000000050000002E742502D56F4C40B75F3E5931444B402E742502D56F4C40992842EA76464B40481ADCD616724C40992842EA76464B40481ADCD616724C40B75F3E5931444B402E742502D56F4C40B75F3E5931444B40
64185	58184	56.638716000000002	56.659108000000003	54.519176000000002	54.496426999999997	Центральная	0103000020E610000001000000050000004AB72572C1514C40FAEC80EB8A3F4B404AB72572C1514C401E6FF25B74424B401844A4A65D544C401E6FF25B74424B401844A4A65D544C40FAEC80EB8A3F4B404AB72572C1514C40FAEC80EB8A3F4B40
64266	27732	56.886678000000003	56.921038000000003	54.443471000000002	54.420819999999999	Матросова	0103000020E61000000100000005000000960A2AAA7E714C4059C0046EDD354B40960A2AAA7E714C40BADC60A8C3384B40C72FBC92E4754C40BADC60A8C3384B40C72FBC92E4754C4059C0046EDD354B40960A2AAA7E714C4059C0046EDD354B40
63604	47303	56.753906999999998	56.805667999999997	54.417169000000001	54.390546000000001	Чернышевского	0103000020E61000000100000005000000DC9C4A0680604C40B4CA4C69FD314B40DC9C4A0680604C40D8F335CB65354B4084B7072120674C40D8F335CB65354B4084B7072120674C40B4CA4C69FD314B40DC9C4A0680604C40B4CA4C69FD314B40
66002	28944	57.036948000000002	57.072637999999998	54.489162999999998	54.480407	Школьная	0103000020E6100000010000000500000089D349B6BA844C407EE200FA7D3D4B4089D349B6BA844C40E5B4A7E49C3E4B403239B5334C894C40E5B4A7E49C3E4B403239B5334C894C407EE200FA7D3D4B4089D349B6BA844C407EE200FA7D3D4B40
65143	47632	57.081639000000003	57.106153999999997	54.462345999999997	54.445737999999999	Советская	0103000020E61000000100000005000000018A9125738A4C40CF4A5AF10D394B40018A9125738A4C40DCB75A272E3B4B40772B4B74968D4C40DCB75A272E3B4B40772B4B74968D4C40CF4A5AF10D394B40018A9125738A4C40CF4A5AF10D394B40
64481	28043	56.651156999999998	56.690333000000003	54.462387999999997	54.452674000000002	А.Абдрахманова	0103000020E61000000100000005000000DEC7D11C59534C40F0DFBC38F1394B40DEC7D11C59534C400B08AD872F3B4B40BF2CEDD45C584C400B08AD872F3B4B40BF2CEDD45C584C40F0DFBC38F1394B40DEC7D11C59534C40F0DFBC38F1394B40
66561	58838	54.345621999999999	55.497954	54.245803000000002	53.702905000000001	Салавата Юлаева	0103000020E61000000100000005000000996379573D2C4B40F29881CAF8D94A40996379573D2C4B401D210379761F4B40C974E8F4BCBF4B401D210379761F4B40C974E8F4BCBF4B40F29881CAF8D94A40996379573D2C4B40F29881CAF8D94A40
63456	27863	54.759825999999997	54.790387000000003	53.991888000000003	53.972138999999999	Кирова	0103000020E61000000100000005000000435376FA41614B404415FE0C6FFC4A40435376FA41614B40BEA59C2FF6FE4A407F17B6662B654B40BEA59C2FF6FE4A407F17B6662B654B404415FE0C6FFC4A40435376FA41614B404415FE0C6FFC4A40
65698	26861	54.992894	55.014391000000003	54.004320999999997	53.995455999999997	Школьная	0103000020E6100000010000000500000083328D26177F4B40B14D2A1A6BFF4A4083328D26177F4B40CFD72C978D004B40AA2D7590D7814B40CFD72C978D004B40AA2D7590D7814B40B14D2A1A6BFF4A4083328D26177F4B40B14D2A1A6BFF4A40
64287	27840	54.99682	55.013223000000004	53.869692999999998	53.860698999999997	Центральная	0103000020E61000000100000005000000D6FF39CC977F4B40965984622BEE4A40D6FF39CC977F4B40B247A81952EF4A400B47904AB1814B40B247A81952EF4A400B47904AB1814B40965984622BEE4A40D6FF39CC977F4B40965984622BEE4A40
65129	26336	54.586388999999997	54.616526999999998	53.951633000000001	53.944955999999998	Школьная	0103000020E61000000100000005000000F8DD74CB0E4B4B4059147651F4F84A40F8DD74CB0E4B4B40AE65321CCFF94A40ED0C535BEA4E4B40AE65321CCFF94A40ED0C535BEA4E4B4059147651F4F84A40F8DD74CB0E4B4B4059147651F4F84A40
65702	27094	55.403038000000002	55.419747000000001	53.825589000000001	53.814627999999999	Молодежная	0103000020E61000000100000005000000CB85CABF96B34B40F433F5BA45E84A40CB85CABF96B34B40FB777DE6ACE94A400CCC0A45BAB54B40FB777DE6ACE94A400CCC0A45BAB54B40F433F5BA45E84A40CB85CABF96B34B40F433F5BA45E84A40
65118	26804	54.863779999999998	54.876624999999997	53.992539000000001	53.984116999999998	Рабочая	0103000020E610000001000000050000002D78D157906E4B400438BD8BF7FD4A402D78D157906E4B40958098840BFF4A4091ED7C3F35704B40958098840BFF4A4091ED7C3F35704B400438BD8BF7FD4A402D78D157906E4B400438BD8BF7FD4A40
64472	27750	54.724198999999999	54.763832999999998	54.107959999999999	54.086115999999997	Центральная	0103000020E61000000100000005000000E065868DB25C4B40C7D45DD9050B4B40E065868DB25C4B4059A31EA2D10D4B40834D9D47C5614B4059A31EA2D10D4B40834D9D47C5614B40C7D45DD9050B4B40E065868DB25C4B40C7D45DD9050B4B40
64293	27663	54.666482999999999	54.706493999999999	54.186126000000002	54.164355	Центральная	0103000020E61000000100000005000000842BA0504F554B4090F7AA9509154B40842BA0504F554B40B8770DFAD2174B40FD6838656E5A4B40B8770DFAD2174B40FD6838656E5A4B4090F7AA9509154B40842BA0504F554B4090F7AA9509154B40
64278	27034	55.236248000000003	55.258381999999997	53.798406	53.780436999999999	Гагарина	0103000020E610000001000000050000006ADFDC5F3D9E4B404FCB0F5CE5E34A406ADFDC5F3D9E4B401077F52A32E64A4002F04FA912A14B401077F52A32E64A4002F04FA912A14B404FCB0F5CE5E34A406ADFDC5F3D9E4B404FCB0F5CE5E34A40
64010	27595	54.692390000000003	54.736012000000002	53.972577999999999	53.954636999999998	Центральная	0103000020E61000000100000005000000EA094B3CA0584B409946938B31FA4A40EA094B3CA0584B409067976F7DFC4A4056BB26A4355E4B409067976F7DFC4A4056BB26A4355E4B409946938B31FA4A40EA094B3CA0584B409946938B31FA4A40
65999	27761	54.602809999999998	54.628312999999999	54.085968000000001	54.060234000000001	Школьная	0103000020E61000000100000005000000D3D9C9E0284D4B40BB0D6ABFB5074B40D3D9C9E0284D4B405340DAFF000B4B406953758F6C504B405340DAFF000B4B406953758F6C504B40BB0D6ABFB5074B40D3D9C9E0284D4B40BB0D6ABFB5074B40
63736	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Школьная	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
63991	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Советская площадь	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
63638	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Свободы	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
63643	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Полевая	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
63357	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Победы	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
64281	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Кускова	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
64421	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Коммунистическая	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
63359	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Кирова	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
63515	4593	54.912899000000003	54.962648000000002	54.086312	54.046999	Гагарина	0103000020E610000001000000050000008BC6DADFD9744B40ECF82F1004064B408BC6DADFD9744B404DA088450C0B4B40A8C7B60C387B4B404DA088450C0B4B40A8C7B60C387B4B40ECF82F1004064B408BC6DADFD9744B40ECF82F1004064B40
65726	27011	55.116224000000003	55.134127999999997	53.976100000000002	53.965131	Центральная	0103000020E610000001000000050000005281936DE08E4B408AADA06989FB4A405281936DE08E4B4014D044D8F0FC4A402BBD361B2B914B4014D044D8F0FC4A402BBD361B2B914B408AADA06989FB4A405281936DE08E4B408AADA06989FB4A40
65485	58554	54.643341999999997	54.654660999999997	54.149867	54.141618999999999	Школьная	0103000020E610000001000000050000005512D90759524B4001BF469220124B405512D90759524B40F4DF83D72E134B40BB7B80EECB534B40F4DF83D72E134B40BB7B80EECB534B4001BF469220124B405512D90759524B4001BF469220124B40
64134	26614	55.026491	55.041772000000002	54.087299000000002	54.072377000000003	Центральная	0103000020E61000000100000005000000B5519D0E64834B40C6FD47A643094B40B5519D0E64834B409CFC169D2C0B4B40BBF1EEC858854B409CFC169D2C0B4B40BBF1EEC858854B40C6FD47A643094B40B5519D0E64834B40C6FD47A643094B40
65802	25015	55.173743000000002	55.205489999999998	53.808674000000003	53.787624000000001	Дружбы	0103000020E610000001000000050000005874EB353D964B40B9C5FCDCD0E44A405874EB353D964B4011902FA182E74A40D8D30E7F4D9A4B4011902FA182E74A40D8D30E7F4D9A4B40B9C5FCDCD0E44A405874EB353D964B40B9C5FCDCD0E44A40
64188	27388	54.680667	54.716760999999998	53.836860000000001	53.816876999999998	Дружбы	0103000020E61000000100000005000000B43BA41820574B4063EDEF6C8FE84A40B43BA41820574B4050AA7D3A1EEB4A402D060FD3BE5B4B4050AA7D3A1EEB4A402D060FD3BE5B4B4063EDEF6C8FE84A40B43BA41820574B4063EDEF6C8FE84A40
64006	27513	54.880533	54.912854000000003	53.925465000000003	53.910229999999999	Ленина	0103000020E610000001000000050000003E062B4EB5704B4046EBA86A82F44A403E062B4EB5704B40DC4B1AA375F64A40EB025E66D8744B40DC4B1AA375F64A40EB025E66D8744B4046EBA86A82F44A403E062B4EB5704B4046EBA86A82F44A40
66605	58858	55.840679000000002	55.862931000000003	54.622633	54.613593000000002	Школьная	0103000020E610000001000000050000008DB7955E9BEB4B40FB0626378A4E4B408DB7955E9BEB4B4087342A70B24F4B4030DAE38574EE4B4087342A70B24F4B4030DAE38574EE4B40FB0626378A4E4B408DB7955E9BEB4B40FB0626378A4E4B40
66877	27211	55.332763	55.364474000000001	54.019970999999998	54.003818000000003	Центральная	0103000020E61000000100000005000000D0285DFA97AA4B406D91B41B7D004B40D0285DFA97AA4B4028EFE3688E024B40041F8315A7AE4B4028EFE3688E024B40041F8315A7AE4B406D91B41B7D004B40D0285DFA97AA4B406D91B41B7D004B40
65553	27357	55.435872000000003	55.461402	53.974744000000001	53.965936999999997	Дружбы	0103000020E61000000100000005000000FE9E58A7CAB74B40887FD8D2A3FB4A40FE9E58A7CAB74B4072FC5069C4FC4A408D2782380FBB4B4072FC5069C4FC4A408D2782380FBB4B40887FD8D2A3FB4A40FE9E58A7CAB74B40887FD8D2A3FB4A40
64435	27164	54.761560000000003	54.780748000000003	53.922910000000002	53.907105999999999	Центральная	0103000020E610000001000000050000008CF84ECC7A614B40B000A60C1CF44A408CF84ECC7A614B40609335EA21F64A406E35EB8CEF634B40609335EA21F64A406E35EB8CEF634B40B000A60C1CF44A408CF84ECC7A614B40B000A60C1CF44A40
63999	26185	55.269027999999999	55.283284000000002	54.075198	54.067267999999999	Больничная	0103000020E61000000100000005000000A9DA6E826FA24B409E08E23C9C084B40A9DA6E826FA24B40C05C8B16A0094B4073BD6DA642A44B40C05C8B16A0094B4073BD6DA642A44B409E08E23C9C084B40A9DA6E826FA24B409E08E23C9C084B40
64131	26939	55.041896999999999	55.080426000000003	53.944552999999999	53.925831000000002	Салавата Юлаева	0103000020E61000000100000005000000776682E15C854B40BE4F55A181F64A40776682E15C854B405A2BDA1CE7F84A40C2DF2F664B8A4B405A2BDA1CE7F84A40C2DF2F664B8A4B40BE4F55A181F64A40776682E15C854B40BE4F55A181F64A40
65111	26379	54.493223999999998	54.531869999999998	53.941977999999999	53.921149	Центральная	0103000020E6100000010000000500000018CDCAF6213F4B401EDFDE35E8F54A4018CDCAF6213F4B4097C62FBC92F84A409CDCEF5014444B4097C62FBC92F84A409CDCEF5014444B401EDFDE35E8F54A4018CDCAF6213F4B401EDFDE35E8F54A40
64648	26660	54.786776000000003	54.840018999999998	54.143279999999997	54.129866	Центральная	0103000020E610000001000000050000008CA37213B5644B40616EF7729F104B408CA37213B5644B40DF15C1FF56124B4062821ABE856B4B40DF15C1FF56124B4062821ABE856B4B40616EF7729F104B408CA37213B5644B40616EF7729F104B40
65133	27964	54.837234000000002	54.884207000000004	54.025181000000003	54.013416999999997	Школьная	0103000020E61000000100000005000000B58CD47B2A6B4B40EF1AF4A5B7014B40B58CD47B2A6B4B4084BD892139034B4078F2E9B12D714B4084BD892139034B4078F2E9B12D714B40EF1AF4A5B7014B40B58CD47B2A6B4B40EF1AF4A5B7014B40
64642	26544	55.133327999999999	55.160663999999997	53.833390000000001	53.824356000000002	Школьная	0103000020E610000001000000050000000FD253E410914B407521567F84E94A400FD253E410914B401F680586ACEA4A4080D250A390944B401F680586ACEA4A4080D250A390944B407521567F84E94A400FD253E410914B407521567F84E94A40
64476	26472	54.578581999999997	54.627738000000001	53.805585000000001	53.790832000000002	Центральная	0103000020E61000000100000005000000F20698F90E4A4B40AD50A4FB39E54A40F20698F90E4A4B40F792C6681DE74A406D3A02B859504B40F792C6681DE74A406D3A02B859504B40AD50A4FB39E54A40F20698F90E4A4B40AD50A4FB39E54A40
64125	26431	54.503599999999999	54.534905999999999	53.879826999999999	53.871927999999997	Центральная	0103000020E61000000100000005000000FF21FDF675404B40BC3B32569BEF4A40FF21FDF675404B40A391CF2B9EF04A409337C0CC77444B40A391CF2B9EF04A409337C0CC77444B40BC3B32569BEF4A40FF21FDF675404B40BC3B32569BEF4A40
65130	27467	54.834935000000002	54.846783000000002	53.839224000000002	53.830765	Школьная	0103000020E6100000010000000500000094A46B26DF6A4B40AAD4EC8156EA4A4094A46B26DF6A4B40580229B16BEB4A4086E7A562636C4B40580229B16BEB4A4086E7A562636C4B40AAD4EC8156EA4A4094A46B26DF6A4B40AAD4EC8156EA4A40
64737	27285	55.341540000000002	55.366458999999999	53.957417999999997	53.936736000000003	Центральная	0103000020E610000001000000050000004F232D95B7AB4B40317E1AF7E6F74A404F232D95B7AB4B40054D4BAC8CFA4A409529E620E8AE4B40054D4BAC8CFA4A409529E620E8AE4B40317E1AF7E6F74A404F232D95B7AB4B40317E1AF7E6F74A40
64459	26247	54.589362000000001	54.618288	53.923959000000004	53.909385999999998	Советская	0103000020E61000000100000005000000A9C0C936704B4B405AB8ACC266F44A40A9C0C936704B4B4025ECDB4944F64A402FC1A90F244F4B4025ECDB4944F64A402FC1A90F244F4B405AB8ACC266F44A40A9C0C936704B4B405AB8ACC266F44A40
64184	26168	55.187874000000001	55.217149999999997	54.024351000000003	54.008066999999997	Озерная	0103000020E6100000010000000500000065E256410C984B40A296E65608014B4065E256410C984B40FD4FFEEE1D034B40C7293A92CB9B4B40FD4FFEEE1D034B40C7293A92CB9B4B40A296E65608014B4065E256410C984B40A296E65608014B40
66932	32926	58.799505000000003	58.813079000000002	53.458314999999999	53.451515999999998	Школьная	0103000020E6100000010000000500000087FE092E56664D4074CFBA46CBB94A4087FE092E56664D401422E010AABA4A403E0801F912684D401422E010AABA4A403E0801F912684D4074CFBA46CBB94A4087FE092E56664D4074CFBA46CBB94A40
79396	61565	58.779769000000002	58.807608000000002	53.264125	53.251734999999996	Стадионная	0103000020E61000000100000005000000A2B77878CF634D4018213CDA38A04A40A2B77878CF634D402B8716D9CEA14A4076FEEDB25F674D402B8716D9CEA14A4076FEEDB25F674D4018213CDA38A04A40A2B77878CF634D4018213CDA38A04A40
66885	4489	58.117432999999998	58.130701000000002	53.589160999999997	53.582864000000001	Горная	0103000020E610000001000000050000004F3C670B080F4D4004029D499BCA4A404F3C670B080F4D40118AADA069CB4A40FA4674CFBA104D40118AADA069CB4A40FA4674CFBA104D4004029D499BCA4A404F3C670B080F4D4004029D499BCA4A40
66931	8076	58.717750000000002	58.747205000000001	53.028461999999998	53.013181000000003	Ленина	0103000020E610000001000000050000001D5A643BDF5B4D40DCF63DEAAF814A401D5A643BDF5B4D40E1968FA4A4834A402F34D769A45F4D40E1968FA4A4834A402F34D769A45F4D40DCF63DEAAF814A401D5A643BDF5B4D40DCF63DEAAF814A40
64262	25334	58.541077999999999	58.570013000000003	53.058411999999997	53.041868999999998	Советская	0103000020E61000000100000005000000E44A3D0B42454D40ADDBA0F65B854A40E44A3D0B42454D40D3D85E0B7A874A40BEA59C2FF6484D40D3D85E0B7A874A40BEA59C2FF6484D40ADDBA0F65B854A40E44A3D0B42454D40ADDBA0F65B854A40
64752	25151	58.646836999999998	58.661883000000003	53.446415999999999	53.432572	Хисматуллина	0103000020E61000000100000005000000DF6B088ECB524D402995F0845EB74A40DF6B088ECB524D40A034D42824B94A40A2630795B8544D40A034D42824B94A40A2630795B8544D402995F0845EB74A40DF6B088ECB524D402995F0845EB74A40
65567	24457	58.548651	58.557904000000001	53.145564999999998	53.134960999999997	Центральная	0103000020E6100000010000000500000077F52A323A464D40239EEC6646914A4077F52A323A464D409B38B9DFA1924A405F27F56569474D409B38B9DFA1924A405F27F56569474D40239EEC6646914A4077F52A323A464D40239EEC6646914A40
66254	17231	58.640728000000003	58.650089000000001	53.665111000000003	53.658814999999997	Советская	0103000020E61000000100000005000000D5D0066003524D409F8EC70C54D44A40D5D0066003524D40DD9A745B22D54A40A33EC91D36534D40DD9A745B22D54A40A33EC91D36534D409F8EC70C54D44A40D5D0066003524D409F8EC70C54D44A40
66979	58902	57.854460000000003	58.989113000000003	53.877538999999999	52.857525000000003	улица Мира	0103000020E61000000100000005000000BEDEFDF15EED4C404F401361C36D4A40BEDEFDF15EED4C4076FBAC3253F04A40348639419B7E4D4076FBAC3253F04A40348639419B7E4D404F401361C36D4A40BEDEFDF15EED4C404F401361C36D4A40
64005	24808	58.684835	58.712198000000001	53.631770000000003	53.615614999999998	Центральная	0103000020E61000000100000005000000FD135CACA8574D40A9F6E978CCCE4A40FD135CACA8574D40064CE0D6DDD04A406823D74D295B4D40064CE0D6DDD04A406823D74D295B4D40A9F6E978CCCE4A40FD135CACA8574D40A9F6E978CCCE4A40
65656	23667	58.448408000000001	58.464587000000002	53.251423000000003	53.240102	Клубная	0103000020E61000000100000005000000E4A1EF6E65394D4023DA8EA9BB9E4A40E4A1EF6E65394D402A3BFDA02EA04A40C9923996773B4D402A3BFDA02EA04A40C9923996773B4D4023DA8EA9BB9E4A40E4A1EF6E65394D4023DA8EA9BB9E4A40
66645	3772	58.647267999999997	58.667048999999999	53.243718000000001	53.231338999999998	Целинная	0103000020E61000000100000005000000A8DF85ADD9524D4009A52F849C9D4A40A8DF85ADD9524D4028B9C326329F4A402DEA93DC61554D4028B9C326329F4A402DEA93DC61554D4009A52F849C9D4A40A8DF85ADD9524D4009A52F849C9D4A40
65541	23363	58.797978000000001	58.817974999999997	53.696629999999999	53.689587000000003	Центральная	0103000020E61000000100000005000000B876A22424664D40965F066344D84A40B876A22424664D40CCB4FD2B2BD94A4009F9A067B3684D40CCB4FD2B2BD94A4009F9A067B3684D40965F066344D84A40B876A22424664D40965F066344D84A40
65065	46521	58.778359000000002	58.791789000000001	53.135835999999998	53.125230999999999	Клубная	0103000020E610000001000000050000000DC68844A1634D4002B9C49107904A400DC68844A1634D404ACFF41263914A40912A8A5759654D404ACFF41263914A40912A8A5759654D4002B9C49107904A400DC68844A1634D4002B9C49107904A40
66455	58784	58.724010999999997	58.737279000000001	53.525702000000003	53.520305999999998	Центральная	0103000020E61000000100000005000000DD787764AC5C4D40CFF4126399C24A40DD787764AC5C4D408DB800344AC34A40888384285F5E4D408DB800344AC34A40888384285F5E4D40CFF4126399C24A40DD787764AC5C4D40CFF4126399C24A40
64595	22926	58.335903000000002	58.353887	53.319011000000003	53.311480000000003	40 лет Победы 	0103000020E610000001000000050000006CD097DEFE2A4D40D6AD9E93DEA74A406CD097DEFE2A4D403A083A5AD5A84A4062BD512B4C2D4D403A083A5AD5A84A4062BD512B4C2D4D40D6AD9E93DEA74A406CD097DEFE2A4D40D6AD9E93DEA74A40
66912	3665	58.880012000000001	58.892767999999997	53.827741000000003	53.820751999999999	Школьная	0103000020E61000000100000005000000350BB43BA4704D403410CB660EE94A40350BB43BA4704D407847C66AF3E94A402975C93846724D407847C66AF3E94A402975C93846724D403410CB660EE94A40350BB43BA4704D403410CB660EE94A40
65525	24412	58.512512000000001	58.525087999999997	53.211351999999998	53.203446	Центральная	0103000020E610000001000000050000005E6743FE99414D404240BE840A9A4A405E6743FE99414D40DBF813950D9B4A40D2C2651536434D40DBF813950D9B4A40D2C2651536434D404240BE840A9A4A405E6743FE99414D404240BE840A9A4A40
65618	58582	58.846145999999997	58.860474000000004	53.242046999999999	53.234475000000003	Ф.Гумеровой	0103000020E6100000010000000500000013D21A834E6C4D40645DDC46039E4A4013D21A834E6C4D40268C6665FB9E4A4077871403246E4D40268C6665FB9E4A4077871403246E4D40645DDC46039E4A4013D21A834E6C4D40645DDC46039E4A40
65977	23281	58.744672000000001	58.759827000000001	53.750104999999998	53.741115999999998	Салавата Юлаева	0103000020E610000001000000050000009B1F7F69515F4D406B459BE3DCDE4A409B1F7F69515F4D4075C8CD7003E04A4014CFD90242614D4075C8CD7003E04A4014CFD90242614D406B459BE3DCDE4A409B1F7F69515F4D406B459BE3DCDE4A40
64637	24731	58.719006999999998	58.733524000000003	53.707931000000002	53.700372999999999	Школьная	0103000020E610000001000000050000002B4CDF6B085C4D402E008DD2A5D94A402B4CDF6B085C4D408C69A67B9DDA4A40626A4B1DE45D4D408C69A67B9DDA4A40626A4B1DE45D4D402E008DD2A5D94A402B4CDF6B085C4D402E008DD2A5D94A40
64590	23233	58.688986	58.706898000000002	53.770327000000002	53.757387999999999	Центральная	0103000020E6100000010000000500000070B378B130584D4001310917F2E04A4070B378B130584D40E71C3C139AE24A40CDCD37A27B5A4D40E71C3C139AE24A40CDCD37A27B5A4D4001310917F2E04A4070B378B130584D4001310917F2E04A40
65889	58656	58.534573999999999	58.544438	53.129401999999999	53.109994999999998	Дружбы	0103000020E610000001000000050000005DA5BBEB6C444D409CDCEF50148E4A405DA5BBEB6C444D40BC04A73E90904A408E59F624B0454D40BC04A73E90904A408E59F624B0454D409CDCEF50148E4A405DA5BBEB6C444D409CDCEF50148E4A40
65113	23803	58.610446000000003	58.628456999999997	53.349628000000003	53.344951999999999	Сулейманова	0103000020E61000000100000005000000ADFC3218234E4D404B581B6327AC4A40ADFC3218234E4D4009E23C9CC0AC4A409CF86A4771504D4009E23C9CC0AC4A409CF86A4771504D404B581B6327AC4A40ADFC3218234E4D404B581B6327AC4A40
64563	58275	58.633865	58.680109999999999	53.615651999999997	53.597909999999999	Школьная	0103000020E610000001000000050000001E8A027D22514D40C6F99B5088CC4A401E8A027D22514D40C6DB4AAFCDCE4A405ED72FD80D574D40C6DB4AAFCDCE4A405ED72FD80D574D40C6F99B5088CC4A401E8A027D22514D40C6F99B5088CC4A40
66742	24716	58.607633999999997	58.623364000000002	53.627952000000001	53.620587	Школьная	0103000020E6100000010000000500000005F86EF3C64D4D4050A912656FCF4A4005F86EF3C64D4D4099BA2BBB60D04A407BC03C64CA4F4D4099BA2BBB60D04A407BC03C64CA4F4D4050A912656FCF4A4005F86EF3C64D4D4050A912656FCF4A40
65527	24939	58.567399000000002	58.592694999999999	53.455506	53.443123	Худайбердина	0103000020E610000001000000050000003D64CA87A0484D407E8D2441B8B84A403D64CA87A0484D40DE9046054EBA4A4059C0046EDD4B4D40DE9046054EBA4A4059C0046EDD4B4D407E8D2441B8B84A403D64CA87A0484D407E8D2441B8B84A40
63711	58122	58.799505000000003	58.813079000000002	53.458314999999999	53.451515999999998	Центральная	0103000020E6100000010000000500000087FE092E56664D4074CFBA46CBB94A4087FE092E56664D401422E010AABA4A403E0801F912684D401422E010AABA4A403E0801F912684D4074CFBA46CBB94A4087FE092E56664D4074CFBA46CBB94A40
66128	23992	58.252324000000002	58.272382999999998	53.229737999999998	53.219085	Советская	0103000020E610000001000000050000007AFF1F274C204D40A7052FFA0A9C4A407AFF1F274C204D400053060E689D4A40417E3672DD224D400053060E689D4A40417E3672DD224D40A7052FFA0A9C4A407AFF1F274C204D40A7052FFA0A9C4A40
65068	22884	58.305908000000002	58.329318000000001	53.319318000000003	53.306207000000001	Ишбулатова	0103000020E61000000100000005000000DACA4BFE27274D4034677DCA31A74A40DACA4BFE27274D4017838769DFA84A40F8FD9B17272A4D4017838769DFA84A40F8FD9B17272A4D4034677DCA31A74A40DACA4BFE27274D4034677DCA31A74A40
63993	24331	58.536712000000001	58.561523999999999	53.169651999999999	53.160117999999997	Матросова	0103000020E6100000010000000500000075AF93FAB2444D401EC022BF7E944A4075AF93FAB2444D40BAD91F28B7954A40A5F5B704E0474D40BAD91F28B7954A40A5F5B704E0474D401EC022BF7E944A4075AF93FAB2444D401EC022BF7E944A40
65110	23457	58.278599	58.293349999999997	53.434074000000003	53.423848	Салавата Юлаева	0103000020E6100000010000000500000062D9CC21A9234D40CD3CB9A640B64A4062D9CC21A9234D409F05A1BC8FB74A400B24287E8C254D409F05A1BC8FB74A400B24287E8C254D40CD3CB9A640B64A4062D9CC21A9234D40CD3CB9A640B64A40
66069	25239	58.584071000000002	58.601956999999999	53.080838999999997	53.069516	Новая	0103000020E6100000010000000500000061C5A9D6C24A4D403D4679E6E5884A4061C5A9D6C24A4D40E49EAEEE588A4A40944C4EED0C4D4D40E49EAEEE588A4A40944C4EED0C4D4D403D4679E6E5884A4061C5A9D6C24A4D403D4679E6E5884A40
64584	12631	58.776328999999997	58.791510000000002	53.771768999999999	53.760832000000001	Шаймуратова	0103000020E61000000100000005000000DBF7A8BF5E634D4009E066F162E14A40DBF7A8BF5E634D4087889B53C9E24A407E3A1E3350654D4087889B53C9E24A407E3A1E3350654D4009E066F162E14A40DBF7A8BF5E634D4009E066F162E14A40
64762	24230	58.622304	58.634269000000003	53.197944	53.191119999999998	Центральная	0103000020E61000000100000005000000C21550A8A74F4D4046CEC29E76984A40C21550A8A74F4D403F389F3A56994A40EEEE01BA2F514D403F389F3A56994A40EEEE01BA2F514D4046CEC29E76984A40C21550A8A74F4D4046CEC29E76984A40
64456	32901	58.663302999999999	58.682229999999997	53.352912000000003	53.345387000000002	Школьная	0103000020E610000001000000050000005A2BDA1CE7544D4056BB26A435AC4A405A2BDA1CE7544D40D82E6D382CAD4A40CF2C095053574D40D82E6D382CAD4A40CF2C095053574D4056BB26A435AC4A405A2BDA1CE7544D4056BB26A435AC4A40
64251	23580	58.718108999999998	58.756825999999997	53.271191000000002	53.264232999999997	Соколова	0103000020E610000001000000050000004CFBE6FEEA5B4D4011C30E63D2A14A404CFBE6FEEA5B4D401AFCFD62B6A24A409961A3ACDF604D401AFCFD62B6A24A409961A3ACDF604D4011C30E63D2A14A404CFBE6FEEA5B4D4011C30E63D2A14A40
65059	58453	58.659466999999999	58.672573	53.057015	53.049633	Молодежная	0103000020E6100000010000000500000047E5266A69544D40B4E6C75F5A864A4047E5266A69544D40D3307C444C874A4018963FDF16564D40D3307C444C874A4018963FDF16564D40B4E6C75F5A864A4047E5266A69544D40B4E6C75F5A864A40
63509	58110	58.831369000000002	58.848256999999997	53.741653999999997	53.717027999999999	Школьная	0103000020E6100000010000000500000041F4A44C6A6A4D407C28D192C7DB4A4041F4A44C6A6A4D404A79AD84EEDE4A4031CD74AF936C4D404A79AD84EEDE4A4031CD74AF936C4D407C28D192C7DB4A4041F4A44C6A6A4D407C28D192C7DB4A40
65213	24584	58.705964000000002	58.719231999999998	53.590972999999998	53.581977000000002	Школьная	0103000020E61000000100000005000000A11342075D5A4D401903EB387ECA4A40A11342075D5A4D40D5E8D500A5CB4A404B1E4FCB0F5C4D40D5E8D500A5CB4A404B1E4FCB0F5C4D401903EB387ECA4A40A11342075D5A4D401903EB387ECA4A40
64887	58385	58.173811000000001	58.188192999999998	53.233144000000003	53.225408999999999	Сакмарская	0103000020E61000000100000005000000B05758703F164D40AE9CBD33DA9C4A40B05758703F164D401BA19FA9D79D4A40062B4EB516184D401BA19FA9D79D4A40062B4EB516184D40AE9CBD33DA9C4A40B05758703F164D40AE9CBD33DA9C4A40
66540	58831	58.650025999999997	58.702936999999999	53.182076000000002	53.147897999999998	 Школьная	0103000020E610000001000000050000005CC64D0D34534D4068925852EE924A405CC64D0D34534D4079B130444E974A40FD12F1D6F9594D4079B130444E974A40FD12F1D6F9594D4068925852EE924A405CC64D0D34534D4068925852EE924A40
63513	49432	58.496962000000003	58.525770999999999	53.348106999999999	53.326718	Пионерская	0103000020E6100000010000000500000069AD68739C3F4D40DC813AE5D1A94A4069AD68739C3F4D401C412AC58EAC4A40B517D1764C434D401C412AC58EAC4A40B517D1764C434D40DC813AE5D1A94A4069AD68739C3F4D40DC813AE5D1A94A40
65990	22558	58.677218000000003	58.775457000000003	53.027681999999999	53.007199999999997	Молодежная	0103000020E610000001000000050000009B215514AF564D40FE43FAEDEB804A409B215514AF564D400C5872158B834A40263ACB2C42634D400C5872158B834A40263ACB2C42634D40FE43FAEDEB804A409B215514AF564D40FE43FAEDEB804A40
66592	58855	57.854460000000003	58.989113000000003	53.877538999999999	52.857525000000003	Центральная	0103000020E61000000100000005000000BEDEFDF15EED4C404F401361C36D4A40BEDEFDF15EED4C4076FBAC3253F04A40348639419B7E4D4076FBAC3253F04A40348639419B7E4D404F401361C36D4A40BEDEFDF15EED4C404F401361C36D4A40
66021	24832	58.650843000000002	58.673121000000002	53.470847999999997	53.464716000000003	Клочкова	0103000020E610000001000000050000004FEACBD24E534D40C7F65AD07BBB4A404FEACBD24E534D4089B14CBF44BC4A401BA034D428564D4089B14CBF44BC4A401BA034D428564D40C7F65AD07BBB4A404FEACBD24E534D40C7F65AD07BBB4A40
64924	25163	58.537852999999998	58.550986000000002	53.113227000000002	53.099922999999997	Салавата Кадырова	0103000020E610000001000000050000001A87FA5DD8444D40218FE046CA8C4A401A87FA5DD8444D401903EB387E8E4A40E54691B586464D401903EB387E8E4A40E54691B586464D40218FE046CA8C4A401A87FA5DD8444D40218FE046CA8C4A40
65986	22799	58.241463000000003	58.256805999999997	53.348466999999999	53.334634000000001	Ленина	0103000020E61000000100000005000000D7187442E81E4D4099107349D5AA4A40D7187442E81E4D401C5E10919AAC4A4052B5DD04DF204D401C5E10919AAC4A4052B5DD04DF204D4099107349D5AA4A40D7187442E81E4D4099107349D5AA4A40
1788	6621	48.251756999999998	48.260210000000001	54.427357999999998	54.427007000000003	Школьная улица	0103000020E6100000010000000500000000C5C89239204840E014562AA8364B4000C5C892392048408CD7BCAAB3364B40CC0BB08F4E2148408CD7BCAAB3364B40CC0BB08F4E214840E014562AA8364B4000C5C89239204840E014562AA8364B40
47142	6621	48.275678999999997	48.284258000000001	54.426535000000001	54.418903	Новокомбинатовская	0103000020E61000000100000005000000D49810734923484020990E9D9E354B40D498107349234840B8CCE9B298364B402DD0EE9062244840B8CCE9B298364B402DD0EE906224484020990E9D9E354B40D49810734923484020990E9D9E354B40
47149	6621	48.268464999999999	48.281275000000001	54.421123999999999	54.419223000000002	Дачная	0103000020E61000000100000005000000718FA50F5D224840925D6919A9354B40718FA50F5D224840C5C72764E7354B405917B7D100244840C5C72764E7354B405917B7D100244840925D6919A9354B40718FA50F5D224840925D6919A9354B40
7440	72	48.337699000000001	48.340527999999999	54.307699	54.299177999999998	улица Терешковой	0103000020E610000001000000050000002A7288B8392B484062D7F6764B264B402A7288B8392B484086014BAE62274B40A7AFE76B962B484086014BAE62274B40A7AFE76B962B484062D7F6764B264B402A7288B8392B484062D7F6764B264B40
7077	72	48.531222999999997	48.556573	54.348627	54.347540000000002	улица Тельмана	0103000020E6100000010000000500000006F1811DFF434840A306D3307C2C4B4006F1811DFF43484055C03DCF9F2C4B40166BB8C83D47484055C03DCF9F2C4B40166BB8C83D474840A306D3307C2C4B4006F1811DFF434840A306D3307C2C4B40
7908	72	48.391669	48.398226999999999	54.349891	54.343347000000001	улица Северный Венец	0103000020E61000000100000005000000B3EDB43522324840011764CBF22B4B40B3EDB435223248401615713AC92C4B402DB1321AF93248401615713AC92C4B402DB1321AF9324840011764CBF22B4B40B3EDB43522324840011764CBF22B4B40
7597	72	48.281391999999997	48.315331	54.293486999999999	54.264780000000002	улица Рябикова	0103000020E6100000010000000500000092AD2EA7042448404451A04FE4214B4092AD2EA7042448408C6665FB90254B401E3526C45C2848408C6665FB90254B401E3526C45C2848404451A04FE4214B4092AD2EA7042448404451A04FE4214B40
7878	72	48.374682	48.391885000000002	54.357683000000002	54.340544000000001	улица Розы Люксембург	0103000020E610000001000000050000002F336C94F52F4840AD6C1FF2962B4B402F336C94F52F4840E7AA798EC82D4B408065A54929324840E7AA798EC82D4B408065A54929324840AD6C1FF2962B4B402F336C94F52F4840AD6C1FF2962B4B40
8012	72	48.388435000000001	48.404981999999997	54.348627	54.321339000000002	улица Радищева	0103000020E6100000010000000500000096CFF23CB8314840F5F6E7A221294B4096CFF23CB831484055C03DCF9F2C4B40FDBB3E73D633484055C03DCF9F2C4B40FDBB3E73D6334840F5F6E7A221294B4096CFF23CB8314840F5F6E7A221294B40
7431	72	48.315555000000003	48.348945999999998	54.305124999999997	54.302850999999997	улица Полбина	0103000020E610000001000000050000006E8B321B64284840CB4752D2C3264B406E8B321B64284840931804560E274B40F6083543AA2C4840931804560E274B40F6083543AA2C4840CB4752D2C3264B406E8B321B64284840CB4752D2C3264B40
7630	72	48.270873000000002	48.307451999999998	54.295667999999999	54.267735000000002	улица Ефремова	0103000020E61000000100000005000000492F6AF7AB2248404E7FF62345224B40492F6AF7AB224840A33CF372D8254B407E8B4E965A274840A33CF372D8254B407E8B4E965A2748404E7FF62345224B40492F6AF7AB2248404E7FF62345224B40
6854	72	48.320765000000002	48.342396999999998	54.257680999999998	54.252715000000002	улица Варейкиса	0103000020E61000000100000005000000C959D8D30E294840B51A12F758204B40C959D8D30E29484079E6E5B0FB204B40CF9F36AAD32B484079E6E5B0FB204B40CF9F36AAD32B4840B51A12F758204B40C959D8D30E294840B51A12F758204B40
7364	72	48.356679999999997	48.363605999999997	54.321832999999998	54.314953000000003	улица Артема	0103000020E610000001000000050000009291B3B0A72D48407863416150284B409291B3B0A72D484004E3E0D231294B408F5033A48A2E484004E3E0D231294B408F5033A48A2E48407863416150284B409291B3B0A72D48407863416150284B40
7032	72	48.467263000000003	48.480127000000003	54.336224000000001	54.333547000000003	улица Академика Сахарова	0103000020E61000000100000005000000C0D02346CF3B4840E75608ABB12A4B40C0D02346CF3B4840AE105663092B4B409B7631CD743D4840AE105663092B4B409B7631CD743D4840E75608ABB12A4B40C0D02346CF3B4840E75608ABB12A4B40
7743	72	48.296061999999999	48.300589000000002	54.271453000000001	54.267561999999998	проспект Хо Ши Мина	0103000020E610000001000000050000004FCB0F5CE525484080D3BB783F224B404FCB0F5CE525484057B3CEF8BE224B40C8444AB37926484057B3CEF8BE224B40C8444AB37926484080D3BB783F224B404FCB0F5CE525484080D3BB783F224B40
7192	72	48.565035000000002	48.581654	54.377851999999997	54.365028000000002	проспект Туполева	0103000020E61000000100000005000000350C1F1153484840E90FCD3CB92E4B40350C1F1153484840355D4F745D304B4036CB65A3734A4840355D4F745D304B4036CB65A3734A4840E90FCD3CB92E4B40350C1F1153484840E90FCD3CB92E4B40
7233	72	48.564155	48.620345	54.382058000000001	54.357478999999998	проспект Созидателей	0103000020E61000000100000005000000FC6F253B36484840DE0033DFC12D4B40FC6F253B364848406C96CB46E7304B405A9E0777674F48406C96CB46E7304B405A9E0777674F4840DE0033DFC12D4B40FC6F253B36484840DE0033DFC12D4B40
7927	72	48.336117999999999	48.387151000000003	54.362651999999997	54.332166000000001	проспект Нариманова	0103000020E6100000010000000500000068CC24EA052B4840EC6B5D6A842A4B4068CC24EA052B48401CEA77616B2E4B408ECEF9298E3148401CEA77616B2E4B408ECEF9298E314840EC6B5D6A842A4B4068CC24EA052B4840EC6B5D6A842A4B40
6799	72	48.303517999999997	48.343483999999997	54.278950000000002	54.234879999999997	проспект Гая	0103000020E61000000100000005000000A8DF85ADD9264840033E3F8C101E4B40A8DF85ADD92648400F9C33A2B4234B408159A148F72B48400F9C33A2B4234B408159A148F72B4840033E3F8C101E4B40A8DF85ADD9264840033E3F8C101E4B40
7304	72	48.582714000000003	48.598030000000001	54.394624	54.382717999999997	проспект Врача Сурова	0103000020E61000000100000005000000EF75525F964A484096CB46E7FC304B40EF75525F964A4840BD1B0B0A83324B4071033E3F8C4C4840BD1B0B0A83324B4071033E3F8C4C484096CB46E7FC304B40EF75525F964A484096CB46E7FC304B40
7517	72	48.329433999999999	48.331814999999999	54.308245999999997	54.298074999999997	проспект 50-летия ВЛКСМ	0103000020E610000001000000050000006118B0E42A2A4840AA60545227264B406118B0E42A2A4840B88FDC9A74274B403FA9F6E9782A4840B88FDC9A74274B403FA9F6E9782A4840AA60545227264B406118B0E42A2A4840AA60545227264B40
16287	72	48.355933999999998	48.364944999999999	54.300392000000002	54.289672000000003	Южная улица	0103000020E6100000010000000500000069C4CC3E8F2D48409148DBF813254B4069C4CC3E8F2D484072FDBB3E73264B405BEB8B84B62E484072FDBB3E73264B405BEB8B84B62E48409148DBF813254B4069C4CC3E8F2D48409148DBF813254B40
47235	72	48.478599000000003	48.494976000000001	54.335174000000002	54.330108000000003	Шоферов	0103000020E61000000100000005000000FC7266BB423D4840F1129CFA402A4B40FC7266BB423D4840193C4CFBE62A4B400727A25F5B3F4840193C4CFBE62A4B400727A25F5B3F4840F1129CFA402A4B40FC7266BB423D4840F1129CFA402A4B40
47130	72	48.327494000000002	48.331096000000002	54.271920999999999	54.270406999999999	Школьная улица	0103000020E6100000010000000500000070D1C952EB29484003CE52B29C224B4070D1C952EB2948403D0CAD4ECE224B4010EB8D5A612A48403D0CAD4ECE224B4010EB8D5A612A484003CE52B29C224B4070D1C952EB29484003CE52B29C224B40
47448	72	48.327494000000002	48.331096000000002	54.271920999999999	54.270406999999999	Школьная улица	0103000020E6100000010000000500000070D1C952EB29484003CE52B29C224B4070D1C952EB2948403D0CAD4ECE224B4010EB8D5A612A48403D0CAD4ECE224B4010EB8D5A612A484003CE52B29C224B4070D1C952EB29484003CE52B29C224B40
47631	72	48.327494000000002	48.331096000000002	54.271920999999999	54.270406999999999	Школьная	0103000020E6100000010000000500000070D1C952EB29484003CE52B29C224B4070D1C952EB2948403D0CAD4ECE224B4010EB8D5A612A48403D0CAD4ECE224B4010EB8D5A612A484003CE52B29C224B4070D1C952EB29484003CE52B29C224B40
47248	72	48.327494000000002	48.331096000000002	54.271920999999999	54.270406999999999	Школьная	0103000020E6100000010000000500000070D1C952EB29484003CE52B29C224B4070D1C952EB2948403D0CAD4ECE224B4010EB8D5A612A48403D0CAD4ECE224B4010EB8D5A612A484003CE52B29C224B4070D1C952EB29484003CE52B29C224B40
47383	72	48.549674000000003	48.562313000000003	54.383620000000001	54.377695000000003	Центральная	0103000020E6100000010000000500000013BBB6B75B4648406E6E4C4F58304B4013BBB6B75B464840B70BCD751A314B40CE8E54DFF9474840B70BCD751A314B40CE8E54DFF94748406E6E4C4F58304B4013BBB6B75B4648406E6E4C4F58304B40
47145	72	48.333520999999998	48.334778999999997	54.271946999999997	54.248874999999998	Хрустальная	0103000020E61000000100000005000000BDC3EDD0B02A484060E5D022DB1F4B40BDC3EDD0B02A4840669FC728CF224B409C31CC09DA2A4840669FC728CF224B409C31CC09DA2A484060E5D022DB1F4B40BDC3EDD0B02A484060E5D022DB1F4B40
47207	72	48.250929999999997	48.281391999999997	54.264780000000002	54.252031000000002	Хваткова	0103000020E61000000100000005000000EACA67791E204840024A438D42204B40EACA67791E2048404451A04FE4214B4092AD2EA7042448404451A04FE4214B4092AD2EA704244840024A438D42204B40EACA67791E204840024A438D42204B40
47230	72	48.300561999999999	48.312967999999998	54.278671000000003	54.277473000000001	Фруктовая	0103000020E61000000100000005000000CE35CCD078264840F2423A3C84234B40CE35CCD078264840FCABC77DAB234B40E658DE550F284840FCABC77DAB234B40E658DE550F284840F2423A3C84234B40CE35CCD078264840F2423A3C84234B40
7210	72	48.569823	48.581232	54.379534999999997	54.368516	Фестивальный бульвар	0103000020E610000001000000050000001AC1C6F5EF484840C00644882B2F4B401AC1C6F5EF484840FB57569A94304B40C0B167CF654A4840FB57569A94304B40C0B167CF654A4840C00644882B2F4B401AC1C6F5EF484840C00644882B2F4B40
47161	72	48.380153	48.385004000000002	54.359493999999998	54.354782	Ульяны Громовой	0103000020E61000000100000005000000F73C7FDAA8304840D09A1F7F692D4B40F73C7FDAA8304840DA8D3EE6032E4B40236AA2CF47314840DA8D3EE6032E4B40236AA2CF47314840D09A1F7F692D4B40F73C7FDAA8304840D09A1F7F692D4B40
6780	72	48.362968000000002	48.366138999999997	54.288967999999997	54.286025000000002	Трудовая улица	0103000020E610000001000000050000004DBF44BC752E4840516B9A779C244B404DBF44BC752E484096CB46E7FC244B4023658BA4DD2E484096CB46E7FC244B4023658BA4DD2E4840516B9A779C244B404DBF44BC752E4840516B9A779C244B40
47194	72	48.356625999999999	48.373550000000002	54.34742	54.334350000000001	Толбухина	0103000020E610000001000000050000009F73B7EBA52D484074B515FBCB2A4B409F73B7EBA52D4840F8FC3042782C4B40DDB5847CD02F4840F8FC3042782C4B40DDB5847CD02F484074B515FBCB2A4B409F73B7EBA52D484074B515FBCB2A4B40
47201	72	48.377879999999998	48.391041000000001	54.346080999999998	54.341379000000003	Тимирязева	0103000020E61000000100000005000000FFE7305F5E30484046459C4EB22B4B40FFE7305F5E3048402C62D8614C2C4B409432A9A10D3248402C62D8614C2C4B409432A9A10D32484046459C4EB22B4B40FFE7305F5E30484046459C4EB22B4B40
47228	72	48.531222999999997	48.556573	54.348627	54.347540000000002	Тельмана	0103000020E6100000010000000500000006F1811DFF434840A306D3307C2C4B4006F1811DFF43484055C03DCF9F2C4B40166BB8C83D47484055C03DCF9F2C4B40166BB8C83D474840A306D3307C2C4B4006F1811DFF434840A306D3307C2C4B40
47252	72	48.301001999999997	48.320172999999997	54.339436999999997	54.333741000000003	Старосельдинская	0103000020E61000000100000005000000EA03C93B87264840CC2A6C06B82A4B40EA03C93B87264840B306EFAB722B4B40F607CA6DFB284840B306EFAB722B4B40F607CA6DFB284840CC2A6C06B82A4B40EA03C93B87264840CC2A6C06B82A4B40
47237	72	48.285857	48.302304999999997	54.298416000000003	54.285761999999998	Станкостроителей	0103000020E61000000100000005000000952A51F696244840433866D993244B40952A51F696244840344DD87E32264B40693524EEB1264840344DD87E32264B40693524EEB1264840433866D993244B40952A51F696244840433866D993244B40
47046	72	48.142719	48.692982000000001	54.421596000000001	54.184033999999997	Спасская	0103000020E6100000010000000500000048C2BE9D4412484010AD156D8E174B4048C2BE9D44124840ED0F94DBF6354B40BC5B59A2B3584840ED0F94DBF6354B40BC5B59A2B358484010AD156D8E174B4048C2BE9D4412484010AD156D8E174B40
47218	72	48.537385	48.553455999999997	54.360700000000001	54.357951	Солнечная	0103000020E61000000100000005000000342E1C08C944484006499F56D12D4B40342E1C08C944484067D5E76A2B2E4B4032E36DA5D746484067D5E76A2B2E4B4032E36DA5D746484006499F56D12D4B40342E1C08C944484006499F56D12D4B40
28898	72	48.285533000000001	48.291786000000002	54.267304000000003	54.265563999999998	Совхозный переулок	0103000020E61000000100000005000000E27668588C2448405A7F4B00FE214B40E27668588C244840850B790437224B4020B75F3E59254840850B790437224B4020B75F3E592548405A7F4B00FE214B40E27668588C2448405A7F4B00FE214B40
47233	72	48.280602000000002	48.296044000000002	54.314732999999997	54.313766000000001	Сельдинская	0103000020E610000001000000050000009A982EC4EA234840624CFA7B29284B409A982EC4EA23484069FCC22B49284B40A91611C5E425484069FCC22B49284B40A91611C5E4254840624CFA7B29284B409A982EC4EA234840624CFA7B29284B40
47119	72	48.307668	48.315097000000002	54.289771999999999	54.286555999999997	Севастопольская	0103000020E610000001000000050000004B033FAA612748407D3CF4DDAD244B404B033FAA61274840F4A5B73F17254B40AB08371955284840F4A5B73F17254B40AB083719552848407D3CF4DDAD244B404B033FAA612748407D3CF4DDAD244B40
47243	72	48.307668	48.315097000000002	54.289771999999999	54.286555999999997	Севастопольская	0103000020E610000001000000050000004B033FAA612748407D3CF4DDAD244B404B033FAA61274840F4A5B73F17254B40AB08371955284840F4A5B73F17254B40AB083719552848407D3CF4DDAD244B404B033FAA612748407D3CF4DDAD244B40
47191	72	48.285829999999997	48.300561999999999	54.278671000000003	54.259832000000003	Самарская	0103000020E610000001000000050000009B1BD31396244840263ACB2C42214B409B1BD31396244840FCABC77DAB234B40CE35CCD078264840FCABC77DAB234B40CE35CCD078264840263ACB2C42214B409B1BD31396244840263ACB2C42214B40
47251	72	48.333520999999998	48.358414000000003	54.337138000000003	54.336061000000001	Российская	0103000020E61000000100000005000000BDC3EDD0B02A4840043BFE0B042B4B40BDC3EDD0B02A4840931E8656272B4B40DB368C82E02D4840931E8656272B4B40DB368C82E02D4840043BFE0B042B4B40BDC3EDD0B02A4840043BFE0B042B4B40
47236	72	48.388435000000001	48.404981999999997	54.348627	54.321339000000002	Радищева	0103000020E6100000010000000500000096CFF23CB8314840F5F6E7A221294B4096CFF23CB831484055C03DCF9F2C4B40FDBB3E73D633484055C03DCF9F2C4B40FDBB3E73D6334840F5F6E7A221294B4096CFF23CB8314840F5F6E7A221294B40
47210	72	48.372768999999998	48.381796999999999	54.299850999999997	54.299357000000001	Пушкинская	0103000020E6100000010000000500000037FB03E5B62F4840126A865451264B4037FB03E5B62F484021567F8461264B40FF5A5EB9DE30484021567F8461264B40FF5A5EB9DE304840126A865451264B4037FB03E5B62F4840126A865451264B40
47278	72	48.349215000000001	48.357390000000002	54.326757999999998	54.306643999999999	Пушкарева	0103000020E61000000100000005000000E622BE13B32C4840DFC14F1C40274B40E622BE13B32C48406ADAC534D3294B406FF59CF4BE2D48406ADAC534D3294B406FF59CF4BE2D4840DFC14F1C40274B40E622BE13B32C4840DFC14F1C40274B40
9250	72	48.366920999999998	48.371879999999997	54.389361000000001	54.354709	Поливенское шоссе	0103000020E61000000100000005000000999B6F44F72E4840664CC11A672D4B40999B6F44F72E48403FABCC94D6314B40AB048BC3992F48403FABCC94D6314B40AB048BC3992F4840664CC11A672D4B40999B6F44F72E4840664CC11A672D4B40
47371	72	48.370873000000003	48.374538999999999	54.399515000000001	54.389361000000001	Поливенская	0103000020E6100000010000000500000016FC36C4782F48403FABCC94D6314B4016FC36C4782F484077A1B94E23334B40CC09DAE4F02F484077A1B94E23334B40CC09DAE4F02F48403FABCC94D6314B4016FC36C4782F48403FABCC94D6314B40
7344	72	48.608207999999998	48.613894999999999	54.386997000000001	54.382477000000002	Пензенский бульвар	0103000020E6100000010000000500000031957EC2D94D4840713C9F01F5304B4031957EC2D94D48403753211E89314B40C616821C944E48403753211E89314B40C616821C944E4840713C9F01F5304B4031957EC2D94D4840713C9F01F5304B40
47158	72	48.358908	48.378095999999999	54.350777999999998	54.335830999999999	Пархоменко	0103000020E61000000100000005000000EA2285B2F02D4840D2FD9C82FC2A4B40EA2285B2F02D48400114234BE62C4B40CC5F2173653048400114234BE62C4B40CC5F217365304840D2FD9C82FC2A4B40EA2285B2F02D4840D2FD9C82FC2A4B40
47231	72	48.269039999999997	48.301693999999998	54.274974999999998	54.264637999999998	Отрадная	0103000020E610000001000000050000006DA818E76F224840B1A371A8DF214B406DA818E76F224840DA1B7C6132234B4020B3B3E89D264840DA1B7C6132234B4020B3B3E89D264840B1A371A8DF214B406DA818E76F224840B1A371A8DF214B40
47202	72	48.393089000000003	48.394247999999997	54.332985000000001	54.324012000000003	Островского	0103000020E610000001000000050000006CB587BD503248407BC1A73979294B406CB587BD503248407F87A2409F2A4B40B741EDB7763248407F87A2409F2A4B40B741EDB7763248407BC1A73979294B406CB587BD503248407BC1A73979294B40
7136	72	48.525500000000001	48.541922	54.363453999999997	54.347540000000002	Оренбургская улица	0103000020E610000001000000050000002506819543434840A306D3307C2C4B402506819543434840D9CC21A9852E4B40D07D39B35D454840D9CC21A9852E4B40D07D39B35D454840A306D3307C2C4B402506819543434840A306D3307C2C4B40
47240	72	48.525500000000001	48.541922	54.363453999999997	54.347540000000002	Оренбургская	0103000020E610000001000000050000002506819543434840A306D3307C2C4B402506819543434840D9CC21A9852E4B40D07D39B35D454840D9CC21A9852E4B40D07D39B35D454840A306D3307C2C4B402506819543434840A306D3307C2C4B40
7447	72	48.313687000000002	48.350059000000002	54.305987000000002	54.297511999999998	Октябрьская улица	0103000020E61000000100000005000000161747E52628484072158BDF14264B40161747E5262848402600FF942A274B40D255BABBCE2C48402600FF942A274B40D255BABBCE2C484072158BDF14264B40161747E52628484072158BDF14264B40
6823	72	48.344884999999998	48.349798999999997	54.269238999999999	54.267183000000003	Озерный переулок	0103000020E61000000100000005000000C3F01131252C48400A86730D33224B40C3F01131252C484064E76D6C76224B403596B036C62C484064E76D6C76224B403596B036C62C48400A86730D33224B40C3F01131252C48400A86730D33224B40
7252	72	48.576552	48.591248	54.382508000000001	54.373415000000001	Новосондецкий бульвар	0103000020E61000000100000005000000C138B874CC494840FD6A0E10CC2F4B40C138B874CC494840AC3AAB05F6304B40A7E9B303AE4B4840AC3AAB05F6304B40A7E9B303AE4B4840FD6A0E10CC2F4B40C138B874CC494840FD6A0E10CC2F4B40
47148	72	48.370351999999997	48.372534999999999	54.318497999999998	54.308146000000001	Набережная реки Свияги	0103000020E610000001000000050000000C01C0B1672F48405532005471274B400C01C0B1672F4840B3EBDE8AC4284B40C4CE143AAF2F4840B3EBDE8AC4284B40C4CE143AAF2F48405532005471274B400C01C0B1672F48405532005471274B40
7787	72	48.255358999999999	48.372104	54.308439999999997	54.290508000000003	Московское шоссе	0103000020E61000000100000005000000A0DE8C9AAF204840FA9CBB5D2F254B40A0DE8C9AAF2048409D6340F67A274B40FB5A971AA12F48409D6340F67A274B40FB5A971AA12F4840FA9CBB5D2F254B40A0DE8C9AAF204840FA9CBB5D2F254B40
47217	72	48.543458000000001	48.554130000000001	54.351686000000001	54.350436999999999	Московская	0103000020E61000000100000005000000F25F20089045484078279F1EDB2C4B40F25F200890454840043BFE0B042D4B40C2DD59BBED464840043BFE0B042D4B40C2DD59BBED46484078279F1EDB2C4B40F25F20089045484078279F1EDB2C4B40
47222	72	48.372076999999997	48.396456999999998	54.308346	54.306213	Минаева	0103000020E61000000100000005000000014C1938A02F4840164ED2FC31274B40014C1938A02F48401CEDB8E177274B4098A25C1ABF3248401CEDB8E177274B4098A25C1ABF324840164ED2FC31274B40014C1938A02F4840164ED2FC31274B40
7094	72	48.559618	48.561127999999997	54.348694999999999	54.338087999999999	Мелекесская улица	0103000020E6100000010000000500000060200890A1474840C495B377462B4B4060200890A1474840ADA3AA09A22C4B40586FD40AD3474840ADA3AA09A22C4B40586FD40AD3474840C495B377462B4B4060200890A1474840C495B377462B4B40
47245	72	48.368861000000003	48.391418000000002	54.356917000000003	54.348328000000002	Любови Шевцовой	0103000020E610000001000000050000008BE255D6362F4840FB230C03962C4B408BE255D6362F48407731CD74AF2D4B406A882AFC193248407731CD74AF2D4B406A882AFC19324840FB230C03962C4B408BE255D6362F4840FB230C03962C4B40
7317	72	48.604705000000003	48.612853000000001	54.382986000000002	54.378838000000002	Львовский бульвар	0103000020E61000000100000005000000255D33F9664D4840B43D7AC37D304B40255D33F9664D4840B6696CAF05314B40B42094F7714E4840B6696CAF05314B40B42094F7714E4840B43D7AC37D304B40255D33F9664D4840B43D7AC37D304B40
47204	72	48.371699999999997	48.395657999999997	54.312536999999999	54.310121000000002	Льва Толстого	0103000020E610000001000000050000002BF697DD932F4840C366800BB2274B402BF697DD932F48401DE5603601284B404C33DDEBA43248401DE5603601284B404C33DDEBA4324840C366800BB2274B402BF697DD932F4840C366800BB2274B40
6786	72	48.316867000000002	48.369095000000002	54.290081999999998	54.257711999999998	Локомотивная улица	0103000020E6100000010000000500000040170D198F284840B4E4F1B4FC204B4040170D198F28484042942F6821254B40FE0E45813E2F484042942F6821254B40FE0E45813E2F4840B4E4F1B4FC204B4040170D198F284840B4E4F1B4FC204B40
47250	72	48.387591	48.397913000000003	54.330896000000003	54.329830000000001	Лесная	0103000020E61000000100000005000000AA9CF6949C314840AE9E93DE372A4B40AA9CF6949C3148404930D5CC5A2A4B409ED32CD0EE3248404930D5CC5A2A4B409ED32CD0EE324840AE9E93DE372A4B40AA9CF6949C314840AE9E93DE372A4B40
47166	72	48.372104	48.378957999999997	54.306213	54.304085000000001	Куйбышева	0103000020E61000000100000005000000FB5A971AA12F4840221ADD41EC264B40FB5A971AA12F4840164ED2FC31274B405E471CB281304840164ED2FC31274B405E471CB281304840221ADD41EC264B40FB5A971AA12F4840221ADD41EC264B40
47249	72	48.378419000000001	48.387976999999999	54.322085000000001	54.312410999999997	Крымова	0103000020E61000000100000005000000AF97A6087030484090F46915FD274B40AF97A608703048401EC4CE143A294B40D34CF73AA93148401EC4CE143A294B40D34CF73AA931484090F46915FD274B40AF97A6087030484090F46915FD274B40
5228	72	48.395980999999999	48.397579999999998	54.332611999999997	54.332375999999996	Красноармейский переулок	0103000020E610000001000000050000002F6B6281AF324840D6FCF84B8B2A4B402F6B6281AF324840EA20AF07932A4B4097C5C4E6E3324840EA20AF07932A4B4097C5C4E6E3324840D6FCF84B8B2A4B402F6B6281AF324840D6FCF84B8B2A4B40
47206	72	48.301982000000002	48.309977000000003	54.276505	54.272993	Корунковой	0103000020E6100000010000000500000087FD9E58A7264840BA84436FF1224B4087FD9E58A72648401A170E8464234B4090C18A53AD2748401A170E8464234B4090C18A53AD274840BA84436FF1224B4087FD9E58A7264840BA84436FF1224B40
6881	72	48.334384	48.34263	54.262318999999998	54.255456000000002	Кольцевая улица	0103000020E6100000010000000500000020274C18CD2A484093C83EC8B2204B4020274C18CD2A4840490F43AB93214B407250C24CDB2B4840490F43AB93214B407250C24CDB2B484093C83EC8B2204B4020274C18CD2A484093C83EC8B2204B40
47147	72	48.586118999999997	48.598703999999998	54.386740000000003	54.376987	Карбышева	0103000020E61000000100000005000000384888F2054B484032022A1C41304B40384888F2054B48400C0742B280314B4000FE2955A24C48400C0742B280314B4000FE2955A24C484032022A1C41304B40384888F2054B484032022A1C41304B40
7710	72	48.274143000000002	48.311621000000002	54.280169000000001	54.267457	Камышинская улица	0103000020E61000000100000005000000B3B6291E172348400B0BEE073C224B40B3B6291E17234840302DEA93DC234B4098DF6932E3274840302DEA93DC234B4098DF6932E32748400B0BEE073C224B40B3B6291E172348400B0BEE073C224B40
47220	72	48.274143000000002	48.311621000000002	54.280169000000001	54.267457	Камышинская	0103000020E61000000100000005000000B3B6291E172348400B0BEE073C224B40B3B6291E17234840302DEA93DC234B4098DF6932E3274840302DEA93DC234B4098DF6932E32748400B0BEE073C224B40B3B6291E172348400B0BEE073C224B40
47213	72	48.470199999999998	48.472329000000002	54.332842999999997	54.329599000000002	Калнина	0103000020E61000000100000005000000234A7B832F3C4840ACE5CE4C302A4B40234A7B832F3C4840ECD973999A2A4B40E8F9D346753C4840ECD973999A2A4B40E8F9D346753C4840ACE5CE4C302A4B40234A7B832F3C4840ACE5CE4C302A4B40
47164	72	48.350985000000001	48.360615000000003	54.366743	54.353664000000002	Ипподромная	0103000020E610000001000000050000007B319413ED2C4840E3E2A8DC442D4B407B319413ED2C4840BA84436FF12E4B4039B9DFA1282E4840BA84436FF12E4B4039B9DFA1282E4840E3E2A8DC442D4B407B319413ED2C4840E3E2A8DC442D4B40
47212	72	48.470047000000001	48.482515999999997	54.324637000000003	54.320498999999998	Заречная	0103000020E610000001000000050000009D4A06802A3C48404AB3791C06294B409D4A06802A3C4840290989B48D294B40FBE59315C33D4840290989B48D294B40FBE59315C33D48404AB3791C06294B409D4A06802A3C48404AB3791C06294B40
7494	72	48.315123999999997	48.324187999999999	54.307468	54.293365999999999	Западный бульвар	0103000020E61000000100000005000000A417B5FB5528484011E15F048D254B40A417B5FB552848408448861C5B274B40B9E00CFE7E2948408448861C5B274B40B9E00CFE7E29484011E15F048D254B40A417B5FB5528484011E15F048D254B40
6987	72	48.469625000000001	48.483530999999999	54.329729999999998	54.322719999999997	Заводской проезд	0103000020E61000000100000005000000273108AC1C3C4840EFE192E34E294B40273108AC1C3C48404A41B797342A4B4014CD0358E43D48404A41B797342A4B4014CD0358E43D4840EFE192E34E294B40273108AC1C3C4840EFE192E34E294B40
47065	72	48.238273	48.252592	54.347624000000003	54.344197000000001	Дорожная	0103000020E610000001000000050000008942CBBA7F1E4840CF30B5A50E2C4B408942CBBA7F1E484001A777F17E2C4B40999D45EF5420484001A777F17E2C4B40999D45EF54204840CF30B5A50E2C4B408942CBBA7F1E4840CF30B5A50E2C4B40
47244	72	48.302979000000001	48.317675000000001	54.298999000000002	54.287754	Доватора	0103000020E61000000100000005000000F92F1004C826484087A5811FD5244B40F92F1004C8264840B344679945264B40DFE00B93A9284840B344679945264B40DFE00B93A928484087A5811FD5244B40F92F1004C826484087A5811FD5244B40
47215	72	48.540871000000003	48.564523000000001	54.348090999999997	54.337153000000001	Димитрова	0103000020E610000001000000050000006B2DCC423B454840C85F5AD4272B4B406B2DCC423B4548401684F23E8E2C4B407F6B274A424848401684F23E8E2C4B407F6B274A42484840C85F5AD4272B4B406B2DCC423B454840C85F5AD4272B4B40
47176	72	48.398145999999997	48.401820000000001	54.329293999999997	54.328743000000003	Гоголя	0103000020E610000001000000050000004084B872F6324840FCE42840142A4B404084B872F63248406F62484E262A4B407A7077D66E3348406F62484E262A4B407A7077D66E334840FCE42840142A4B404084B872F6324840FCE42840142A4B40
47211	72	48.325606999999998	48.334347999999999	54.263323999999997	54.261671999999997	Героев Свири	0103000020E61000000100000005000000A12C7C7DAD294840B323D5777E214B40A12C7C7DAD2948403E20D099B4214B40D3BD4EEACB2A48403E20D099B4214B40D3BD4EEACB2A4840B323D5777E214B40A12C7C7DAD294840B323D5777E214B40
47128	72	48.290232000000003	48.305314000000003	54.299005000000001	54.290528999999999	Герасимова	0103000020E6100000010000000500000058207A522625484011C5E40D30254B4058207A5226254840952BBCCB45264B406781768714274840952BBCCB45264B40678176871427484011C5E40D30254B4058207A522625484011C5E40D30254B40
47238	72	48.303750999999998	48.310074999999998	54.255460999999997	54.248716999999999	Вольная	0103000020E610000001000000050000004B901150E1264840C87A6AF5D51F4B404B901150E1264840A43330F2B2204B405227A089B0274840A43330F2B2204B405227A089B0274840C87A6AF5D51F4B404B901150E1264840C87A6AF5D51F4B40
47234	72	48.384815000000003	48.386144999999999	54.331232	54.324648000000003	Верхнеполевая	0103000020E610000001000000050000005001309E413148401D5BCF108E294B405001309E41314840C0B167CF652A4B40C84109336D314840C0B167CF652A4B40C84109336D3148401D5BCF108E294B405001309E413148401D5BCF108E294B40
47645	72	48.345827999999997	48.348083000000003	54.347073000000002	54.347031000000001	Архитектора Шодэ	0103000020E6100000010000000500000042058717442C48405ED905836B2C4B4042058717442C48408D2958E36C2C4B4094A5D6FB8D2C48408D2958E36C2C4B4094A5D6FB8D2C48405ED905836B2C4B4042058717442C48405ED905836B2C4B40
47172	72	48.356679999999997	48.363605999999997	54.321832999999998	54.314953000000003	Артема	0103000020E610000001000000050000009291B3B0A72D48407863416150284B409291B3B0A72D484004E3E0D231294B408F5033A48A2E484004E3E0D231294B408F5033A48A2E48407863416150284B409291B3B0A72D48407863416150284B40
47167	72	48.313166000000002	48.323981000000003	54.263776	54.261319999999998	Амурская	0103000020E610000001000000050000000D1CD0D21528484036E50AEF72214B400D1CD0D2152848401FBC7669C3214B4040C39B35782948401FBC7669C3214B4040C39B357829484036E50AEF72214B400D1CD0D21528484036E50AEF72214B40
47227	72	48.308574999999998	48.330736999999999	54.293860000000002	54.282376999999997	Александра Невского	0103000020E610000001000000050000007DAEB6627F2748404012F6ED24244B407DAEB6627F27484021CD58349D254B40E0490B97552A484021CD58349D254B40E0490B97552A48404012F6ED24244B407DAEB6627F2748404012F6ED24244B40
47208	72	48.390070000000001	48.394193999999999	54.315615000000001	54.307941	Александра Матросова	0103000020E610000001000000050000004B9352D0ED3148407C0C569C6A274B404B9352D0ED3148404390831266284B40C423F1F2743248404390831266284B40C423F1F2743248407C0C569C6A274B404B9352D0ED3148407C0C569C6A274B40
47241	72	48.519024000000002	48.563948000000003	54.334738999999999	54.332895999999998	Академика Павлова	0103000020E6100000010000000500000068EBE0606F4248400F7C0C569C2A4B4068EBE0606F4248400ED940BAD82A4B408352B4722F4848400ED940BAD82A4B408352B4722F4848400F7C0C569C2A4B4068EBE0606F4248400F7C0C569C2A4B40
47183	72	48.356887	48.370029000000002	54.323633999999998	54.305162000000003	Аблукова	0103000020E610000001000000050000000CAF2479AE2D4840B1FD648C0F274B400CAF2479AE2D4840D4EFC2D66C294B402AC93A1C5D2F4840D4EFC2D66C294B402AC93A1C5D2F4840B1FD648C0F274B400CAF2479AE2D4840B1FD648C0F274B40
47209	72	48.142719	48.692982000000001	54.421596000000001	54.184033999999997	12 Сентября	0103000020E6100000010000000500000048C2BE9D4412484010AD156D8E174B4048C2BE9D44124840ED0F94DBF6354B40BC5B59A2B3584840ED0F94DBF6354B40BC5B59A2B358484010AD156D8E174B4048C2BE9D4412484010AD156D8E174B40
7012	72	48.471449	48.472786999999997	54.330575000000003	54.328564999999998	1-я Линия	0103000020E61000000100000005000000AF5DDA70583C48401CCEFC6A0E2A4B40AF5DDA70583C484007F01648502A4B40AA7CCF48843C484007F01648502A4B40AA7CCF48843C48401CCEFC6A0E2A4B40AF5DDA70583C48401CCEFC6A0E2A4B40
47189	72	48.337699000000001	48.340527999999999	54.307699	54.299177999999998	 Терешковой	0103000020E610000001000000050000002A7288B8392B484062D7F6764B264B402A7288B8392B484086014BAE62274B40A7AFE76B962B484086014BAE62274B40A7AFE76B962B484062D7F6764B264B402A7288B8392B484062D7F6764B264B40
47186	72	48.299619	48.314306999999999	54.297497	54.286256000000002	 Стасова	0103000020E610000001000000050000004F2157EA5926484053245F09A4244B404F2157EA592648403DD4B66114264B40B2F336363B2848403DD4B66114264B40B2F336363B28484053245F09A4244B404F2157EA5926484053245F09A4244B40
47181	72	48.574970999999998	48.595649999999999	54.375318999999998	54.366014	 40-летия Победы	0103000020E61000000100000005000000FF9254A69849484067F0F78BD92E4B40FF9254A698494840A148F7730A304B4063EE5A423E4C4840A148F7730A304B4063EE5A423E4C484067F0F78BD92E4B40FF9254A69849484067F0F78BD92E4B40
47643	55840	48.200445000000002	48.213569	54.412416999999998	54.401972999999998	Центральная улица	0103000020E61000000100000005000000C8D2872EA81948400070ECD973334B40C8D2872EA81948403FA88B14CA344B403F389F3A561B48403FA88B14CA344B403F389F3A561B48400070ECD973334B40C8D2872EA81948400070ECD973334B40
46905	22727	48.560634	48.575608000000003	54.321381000000002	54.320929999999997	Центральная	0103000020E610000001000000050000004983DBDAC24748401327F73B14294B404983DBDAC247484024473A0323294B4072A8DF85AD49484024473A0323294B4072A8DF85AD4948401327F73B14294B404983DBDAC24748401327F73B14294B40
47043	55765	48.255780999999999	48.264279000000002	54.438685	54.416759999999996	Ленина	0103000020E6100000010000000500000016F88A6EBD204840F623456458354B4016F88A6EBD204840751F80D426384B408202EFE4D3214840751F80D426384B408202EFE4D3214840F623456458354B4016F88A6EBD204840F623456458354B40
47108	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	пр. Ленина	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
9849	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	пр. Дмитрова	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46903	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	пр. Димитрова	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
47109	12983	48.337699000000001	48.340527999999999	54.307699	54.299177999999998	Терешковой	0103000020E610000001000000050000002A7288B8392B484062D7F6764B264B402A7288B8392B484086014BAE62274B40A7AFE76B962B484086014BAE62274B40A7AFE76B962B484062D7F6764B264B402A7288B8392B484062D7F6764B264B40
47113	12983	48.364980000000003	48.370119000000003	54.289172999999998	54.286681999999999	Строителей	0103000020E61000000100000005000000D8D825AAB72E48400A2DEBFEB1244B40D8D825AAB72E48406FF1F09E03254B406A50340F602F48406FF1F09E03254B406A50340F602F48400A2DEBFEB1244B40D8D825AAB72E48400A2DEBFEB1244B40
46996	12983	48.486908999999997	48.490654999999997	54.335405000000002	54.332538999999997	Рабочая	0103000020E610000001000000050000006490BB08533E484080D250A3902A4B406490BB08533E48401BF5108DEE2A4B40374F75C8CD3E48401BF5108DEE2A4B40374F75C8CD3E484080D250A3902A4B406490BB08533E484080D250A3902A4B40
46982	12983	48.548848	48.553699000000002	54.352164000000002	54.33793	Победы	0103000020E61000000100000005000000CD3CB9A6404648402C2B4D4A412B4B40CD3CB9A6404648400E6ABFB5132D4B40F969DC9BDF4648400E6ABFB5132D4B40F969DC9BDF4648402C2B4D4A412B4B40CD3CB9A6404648402C2B4D4A412B4B40
46990	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Московская	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46929	12983	48.559618	48.561127999999997	54.348694999999999	54.338087999999999	Мелекесская	0103000020E6100000010000000500000060200890A1474840C495B377462B4B4060200890A1474840ADA3AA09A22C4B40586FD40AD3474840ADA3AA09A22C4B40586FD40AD3474840C495B377462B4B4060200890A1474840C495B377462B4B40
46964	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	М.Тореза	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46925	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Луговая	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
47365	12983	48.470846999999999	48.478599000000003	54.335174000000002	54.324637000000003	Ленинградская	0103000020E61000000100000005000000B935E9B6443C4840290989B48D294B40B935E9B6443C4840193C4CFBE62A4B40FC7266BB423D4840193C4CFBE62A4B40FC7266BB423D4840290989B48D294B40B935E9B6443C4840290989B48D294B40
47112	12983	48.370325000000001	48.401057000000002	54.31541	54.312410999999997	Ленина	0103000020E6100000010000000500000013F241CF662F484090F46915FD274B4013F241CF662F48406A6AD95A5F284B407B6AF5D5553348406A6AD95A5F284B407B6AF5D55533484090F46915FD274B4013F241CF662F484090F46915FD274B40
46985	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Курчатова	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46906	12983	48.372104	48.378957999999997	54.306213	54.304085000000001	Куйбышева	0103000020E61000000100000005000000FB5A971AA12F4840221ADD41EC264B40FB5A971AA12F4840164ED2FC31274B405E471CB281304840164ED2FC31274B405E471CB281304840221ADD41EC264B40FB5A971AA12F4840221ADD41EC264B40
46991	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Крымская	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46901	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Королева	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46978	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Западная	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
47106	12983	48.395145999999997	48.401749000000002	54.321711999999998	54.308346	Гончарова	0103000020E610000001000000050000009692E524943248401CEDB8E177274B409692E52494324840895DDBDB2D294B40B119E0826C334840895DDBDB2D294B40B119E0826C3348401CEDB8E177274B409692E524943248401CEDB8E177274B40
46902	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Гвардейская	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46999	12983	48.386702	48.388812999999999	54.332324	54.322054000000001	Гагарина	0103000020E610000001000000050000001EA67D737F314840E3C5C21039294B401EA67D737F31484084D6C397892A4B403CA1D79FC431484084D6C397892A4B403CA1D79FC4314840E3C5C21039294B401EA67D737F314840E3C5C21039294B40
46911	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Восточная	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
47044	12983	48.363318999999997	48.368501999999999	54.298946999999998	54.290734	Вокзальная	0103000020E61000000100000005000000F981AB3C812E4840EAEA8EC536254B40F981AB3C812E4840601E32E543264B405B41D3122B2F4840601E32E543264B405B41D3122B2F4840EAEA8EC536254B40F981AB3C812E4840EAEA8EC536254B40
46987	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Братская	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
9744	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Баданова	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46910	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	Автостроителей	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
47005	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	III Интернационала	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46907	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	9-ая Линия	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46927	12983	48.378957999999997	48.388840000000002	54.305950000000003	54.304578999999997	3-го Интернационала	0103000020E610000001000000050000005E471CB2813048403106D671FC264B405E471CB281304840091B9E5E29274B4036B05582C5314840091B9E5E29274B4036B05582C53148403106D671FC264B405E471CB2813048403106D671FC264B40
46984	12983	49.511598999999997	49.703785000000003	54.247638999999999	54.187658999999996	 пр. Димитрова	0103000020E6100000010000000500000049D576137CC1484068E6C93505184B4049D576137CC14840691B7FA2B21F4B402B357BA015DA4840691B7FA2B21F4B402B357BA015DA484068E6C93505184B4049D576137CC1484068E6C93505184B40
46909	12983	48.313687000000002	48.350059000000002	54.305987000000002	54.297511999999998	 Октябрьская	0103000020E61000000100000005000000161747E52628484072158BDF14264B40161747E5262848402600FF942A274B40D255BABBCE2C48402600FF942A274B40D255BABBCE2C484072158BDF14264B40161747E52628484072158BDF14264B40
46932	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Фабричная	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
47343	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Строителей	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
47264	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Степана Разина	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
47345	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Льва Толстого	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
46931	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Луначарского	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
41952	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Ленина	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
46924	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Красноармейская	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
46853	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Калинина	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
47312	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	Бебеля	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
47070	23336	47.088132999999999	47.185752999999998	53.674346	53.619230999999999	45 Стрелковой Дивизии	0103000020E61000000100000005000000645930F1478B4740AED51EF642CF4A40645930F1478B47401E1840F850D64A4023111AC1C69747401E1840F850D64A4023111AC1C6974740AED51EF642CF4A40645930F1478B4740AED51EF642CF4A40
47254	22638	48.968764999999998	48.985528000000002	54.202534999999997	54.190994000000003	Советская	0103000020E610000001000000050000003541D47D007C4840BADDCB7D72184B403541D47D007C4840CEA5B8AAEC194B406AA510C8257E4840CEA5B8AAEC194B406AA510C8257E4840BADDCB7D72184B403541D47D007C4840BADDCB7D72184B40
46894	21430	48.811326000000001	48.879814000000003	54.385680999999998	54.333022	Советская	0103000020E610000001000000050000007F32C687D96748409C6C0377A02A4B407F32C687D967484023D8B8FE5D314B400F48C2BE9D70484023D8B8FE5D314B400F48C2BE9D7048409C6C0377A02A4B407F32C687D96748409C6C0377A02A4B40
46896	21430	48.811326000000001	48.879814000000003	54.385680999999998	54.333022	Неверова	0103000020E610000001000000050000007F32C687D96748409C6C0377A02A4B407F32C687D967484023D8B8FE5D314B400F48C2BE9D70484023D8B8FE5D314B400F48C2BE9D7048409C6C0377A02A4B407F32C687D96748409C6C0377A02A4B40
47041	21430	48.811326000000001	48.879814000000003	54.385680999999998	54.333022	50 лет ВЛКСМ	0103000020E610000001000000050000007F32C687D96748409C6C0377A02A4B407F32C687D967484023D8B8FE5D314B400F48C2BE9D70484023D8B8FE5D314B400F48C2BE9D7048409C6C0377A02A4B407F32C687D96748409C6C0377A02A4B40
47362	22682	48.865997999999998	48.892031000000003	54.157381000000001	54.144455999999998	Школьная	0103000020E610000001000000050000006133C005D96E484001DBC1887D124B406133C005D96E48408201840F25144B40540262122E7248408201840F25144B40540262122E72484001DBC1887D124B406133C005D96E484001DBC1887D124B40
47300	22185	49.014471	49.069187999999997	54.046756000000002	54.004140999999997	Школьная	0103000020E61000000100000005000000C6DE8B2FDA8148404FC939B187004B40C6DE8B2FDA8148402672C119FC054B4048A30227DB8848402672C119FC054B4048A30227DB8848404FC939B187004B40C6DE8B2FDA8148404FC939B187004B40
47333	22140	48.882086999999999	48.922097999999998	53.999139999999997	53.962387999999997	Школьная	0103000020E61000000100000005000000069D103AE87048400B08AD872FFB4A40069D103AE87048400E10CCD1E3FF4A407FDAA84E077648400E10CCD1E3FF4A407FDAA84E077648400B08AD872FFB4A40069D103AE87048400B08AD872FFB4A40
47617	47687	48.955838	48.972062000000001	54.344124000000001	54.331162999999997	Центральная	0103000020E6100000010000000500000014234BE6587A48409752978C632A4B4014234BE6587A484065E256410C2C4B4099D711876C7C484065E256410C2C4B4099D711876C7C48409752978C632A4B4014234BE6587A48409752978C632A4B40
47616	22330	49.123635	49.150421999999999	54.360830999999997	54.346811000000002	Центральная	0103000020E610000001000000050000000BD28C45D38F48405072874D642C4B400BD28C45D38F48400531D0B52F2E4B40A94C3107419348400531D0B52F2E4B40A94C3107419348405072874D642C4B400BD28C45D38F48405072874D642C4B40
47615	22497	49.257348999999998	49.292409999999997	54.325955	54.309438	Центральная	0103000020E610000001000000050000004354E1CFF0A04840E01115AA9B274B404354E1CFF0A04840DD7BB8E4B8294B40FD82DDB06DA54840DD7BB8E4B8294B40FD82DDB06DA54840E01115AA9B274B404354E1CFF0A04840E01115AA9B274B40
47545	22406	49.343003000000003	49.366683000000002	54.347824000000003	54.334245000000003	Школьная	0103000020E6100000010000000500000007B7B585E7AB4840FFEC478AC82A4B4007B7B585E7AB4840C861307F852C4B40E57FF277EFAE4840C861307F852C4B40E57FF277EFAE4840FFEC478AC82A4B4007B7B585E7AB4840FFEC478AC82A4B40
47256	23256	48.812117000000001	48.830775000000003	54.236879000000002	54.22099	переулок Садовый	0103000020E6100000010000000500000048C32973F36748401C5F7B66491C4B4048C32973F3674840FA0D130D521E4B40CEAACFD5566A4840FA0D130D521E4B40CEAACFD5566A48401C5F7B66491C4B4048C32973F36748401C5F7B66491C4B40
47303	22589	48.913600000000002	48.951400999999997	54.247281000000001	54.231633000000002	 Центральная	0103000020E6100000010000000500000014D044D8F074484052D66F26A61D4B4014D044D8F07448400AF65FE7A61F4B40DB300A82C77948400AF65FE7A61F4B40DB300A82C779484052D66F26A61D4B4014D044D8F074484052D66F26A61D4B40
47382	22272	49.001894999999998	49.034773000000001	54.390791999999998	54.374538000000001	Центральная	0103000020E61000000100000005000000518369183E804840FC8D76DCF02F4B40518369183E804840EBC4E57805324B4054E4107173844840EBC4E57805324B4054E4107173844840FC8D76DCF02F4B40518369183E804840FC8D76DCF02F4B40
47253	23198	48.709071000000002	48.737323000000004	54.291778999999998	54.273282999999999	Первомайская	0103000020E6100000010000000500000061C5A9D6C25A4840C1C6F5EFFA224B4061C5A9D6C25A48406D54A70359254B4058CB9D99605E48406D54A70359254B4058CB9D99605E4840C1C6F5EFFA224B4061C5A9D6C25A4840C1C6F5EFFA224B40
46921	23119	48.673633000000002	48.726849000000001	54.347335999999999	54.329410000000003	Студенческая	0103000020E61000000100000005000000D1402C9B39564840D97C5C1B2A2A4B40D1402C9B395648409A5C8C81752C4B40AE105663095D48409A5C8C81752C4B40AE105663095D4840D97C5C1B2A2A4B40D1402C9B39564840D97C5C1B2A2A4B40
46919	23119	48.673633000000002	48.726849000000001	54.347335999999999	54.329410000000003	Ленина	0103000020E61000000100000005000000D1402C9B39564840D97C5C1B2A2A4B40D1402C9B395648409A5C8C81752C4B40AE105663095D48409A5C8C81752C4B40AE105663095D4840D97C5C1B2A2A4B40D1402C9B39564840D97C5C1B2A2A4B40
47104	22971	49.063752999999998	49.099677	54.301726000000002	54.269570999999999	Центральная	0103000020E61000000100000005000000CD02ED0E298848409A79724D81224B40CD02ED0E298848402C2D23F59E264B40EA944737C28C48402C2D23F59E264B40EA944737C28C48409A79724D81224B40CD02ED0E298848409A79724D81224B40
47329	22104	48.935267000000003	48.995947999999999	53.981506000000003	53.962901000000002	Пролетарская	0103000020E6100000010000000500000097033DD4B67748409224085740FB4A4097033DD4B6774840F56915FDA1FD4A4020425C397B7F4840F56915FDA1FD4A4020425C397B7F48409224085740FB4A4097033DD4B67748409224085740FB4A40
46917	22883	48.712090000000003	48.750897000000002	54.374049999999997	54.357505000000003	Молодежная	0103000020E6100000010000000500000082E7DEC3255B484008944DB9C22D4B4082E7DEC3255B4840CE88D2DEE02F4B400FD594641D604840CE88D2DEE02F4B400FD594641D60484008944DB9C22D4B4082E7DEC3255B484008944DB9C22D4B40
47620	22924	49.000726999999998	49.024362000000004	54.327677000000001	54.315116000000003	Центральная	0103000020E61000000100000005000000B29C84D217804840223999B855284B40B29C84D2178048406153E751F1294B40F1A1444B1E8348406153E751F1294B40F1A1444B1E834840223999B855284B40B29C84D217804840223999B855284B40
46918	22788	48.611173000000001	48.652208000000002	54.198163000000001	54.171571	Ленина	0103000020E610000001000000050000005F99B7EA3A4E484094F8DC09F6154B405F99B7EA3A4E48407D23BA675D194B4044183F8D7B5348407D23BA675D194B4044183F8D7B53484094F8DC09F6154B405F99B7EA3A4E484094F8DC09F6154B40
47305	22754	48.536487000000001	48.568691000000001	54.249758999999997	54.234138000000002	Пионерская	0103000020E6100000010000000500000055DD239BAB4448401C60E63BF81D4B4055DD239BAB444840DA70581AF81F4B40C843DFDDCA484840DA70581AF81F4B40C843DFDDCA4848401C60E63BF81D4B4055DD239BAB4448401C60E63BF81D4B40
47322	21842	48.879266000000001	48.910536	54.434815	54.417248000000001	Первая	0103000020E610000001000000050000000C3ECDC98B7048402429E96168354B400C3ECDC98B704840B6679604A8374B4053EA92718C744840B6679604A8374B4053EA92718C7448402429E96168354B400C3ECDC98B7048402429E96168354B40
47449	22230	49.069744999999998	49.097251	54.393712000000001	54.381722000000003	Лидии Бернт 	0103000020E610000001000000050000009E077767ED884840F5143944DC304B409E077767ED8848407905A22765324B406C4084B8728C48407905A22765324B406C4084B8728C4840F5143944DC304B409E077767ED884840F5143944DC304B40
46897	22837	48.640413000000002	48.678331	54.440967999999998	54.419065000000003	50 лет Победы	0103000020E6100000010000000500000075779D0DF9514840FAF202ECA3354B4075779D0DF9514840904AB1A371384B40766EDA8CD3564840904AB1A371384B40766EDA8CD3564840FAF202ECA3354B4075779D0DF9514840FAF202ECA3354B40
47334	22539	48.817892999999998	48.855711999999997	54.15437	54.139724999999999	Дружбы	0103000020E610000001000000050000004C50C3B7B068484080B74082E2114B404C50C3B7B0684840E4BD6A65C2134B40BA6587F8876D4840E4BD6A65C2134B40BA6587F8876D484080B74082E2114B404C50C3B7B068484080B74082E2114B40
47638	55836	49.449596999999997	49.473923999999997	54.430202000000001	54.413674	Школьная	0103000020E610000001000000050000009AB0FD648CB948404E9A0645F3344B409AB0FD648CB948403F56F0DB10374B400E65A88AA9BC48403F56F0DB10374B400E65A88AA9BC48404E9A0645F3344B409AB0FD648CB948404E9A0645F3344B40
47612	21660	47.693921000000003	47.735235000000003	54.493974000000001	54.481181999999997	Плетневская	0103000020E61000000100000005000000FA804067D2D8474041B62C5F973D4B40FA804067D2D8474083893F8A3A3F4B40F2EF332E1CDE474083893F8A3A3F4B40F2EF332E1CDE474041B62C5F973D4B40FA804067D2D8474041B62C5F973D4B40
47286	20019	48.122759000000002	48.166471000000001	54.605364999999999	54.580561000000003	Станционная	0103000020E6100000010000000500000014252191B60F4840A22AA6D24F4A4B4014252191B60F48404F92AE997C4D4B40C05DF6EB4E1548404F92AE997C4D4B40C05DF6EB4E154840A22AA6D24F4A4B4014252191B60F4840A22AA6D24F4A4B40
46970	20019	48.122759000000002	48.166471000000001	54.605364999999999	54.580561000000003	О.Кошевого	0103000020E6100000010000000500000014252191B60F4840A22AA6D24F4A4B4014252191B60F48404F92AE997C4D4B40C05DF6EB4E1548404F92AE997C4D4B40C05DF6EB4E154840A22AA6D24F4A4B4014252191B60F4840A22AA6D24F4A4B40
47446	21612	47.775398000000003	47.793813999999998	54.452302000000003	54.431108000000002	Зеленая	0103000020E6100000010000000500000021B1DD3D40E34740A185048C2E374B4021B1DD3D40E347402CF52C08E5394B40B08D78B29BE547402CF52C08E5394B40B08D78B29BE54740A185048C2E374B4021B1DD3D40E34740A185048C2E374B40
47619	21555	47.558356000000003	47.579610000000002	54.419443000000001	54.409933000000002	Тимофеевская	0103000020E6100000010000000500000040C39B3578C747408D463EAF78344B4040C39B3578C74740A0C4E74EB0354B40A03715A930CA4740A0C4E74EB0354B40A03715A930CA47408D463EAF78344B4040C39B3578C747408D463EAF78344B40
47501	19949	48.180340999999999	48.199852	54.602803999999999	54.587927999999998	переулок Школьный	0103000020E610000001000000050000006090F469151748408B338639414B4B406090F46915174840F1F274AE284D4B40250516C094194840F1F274AE284D4B40250516C0941948408B338639414B4B406090F469151748408B338639414B4B40
47500	21377	48.059534999999997	48.084651999999998	54.643754000000001	54.634447999999999	Пролетарская	0103000020E61000000100000005000000D2FBC6D79E0748409D81919735514B40D2FBC6D79E074840A855F48766524B403FC571E0D50A4840A855F48766524B403FC571E0D50A48409D81919735514B40D2FBC6D79E0748409D81919735514B40
47332	20458	47.836599999999997	47.871220999999998	54.402920999999999	54.373629999999999	Пионерская	0103000020E61000000100000005000000B3EA73B515EB4740F9669B1BD32F4B40B3EA73B515EB474091EF52EA92334B40514B732B84EF474091EF52EA92334B40514B732B84EF4740F9669B1BD32F4B40B3EA73B515EB4740F9669B1BD32F4B40
46891	20353	47.717357999999997	47.763379	54.679170999999997	54.642977999999999	Советская	0103000020E6100000010000000500000011C30E63D2DB47401406651A4D524B4011C30E63D2DB474020B24813EF564B4002BA2F67B6E1474020B24813EF564B4002BA2F67B6E147401406651A4D524B4011C30E63D2DB47401406651A4D524B40
47621	55827	47.762013000000003	47.788307000000003	54.705022999999997	54.689539000000003	Школьная	0103000020E610000001000000050000003D1059A489E1474085285FD042584B403D1059A489E14740C2F693313E5A4B409C1A683EE7E44740C2F693313E5A4B409C1A683EE7E4474085285FD042584B403D1059A489E1474085285FD042584B40
47301	21812	47.694541000000001	47.741514000000002	54.559818999999997	54.54242	Школьная	0103000020E61000000100000005000000965D30B8E6D847402159C0046E454B40965D30B8E6D84740F7562426A8474B4059C345EEE9DE4740F7562426A8474B4059C345EEE9DE47402159C0046E454B40965D30B8E6D847402159C0046E454B40
47445	21341	47.932496	47.976045999999997	54.713240999999996	54.698805999999998	Советская	0103000020E610000001000000050000004ED367075CF74740D11F9A7972594B404ED367075CF747404A95287B4B5B4B4020B24813EFFC47404A95287B4B5B4B4020B24813EFFC4740D11F9A7972594B404ED367075CF74740D11F9A7972594B40
47542	21285	48.060639999999999	48.092520999999998	54.602257000000002	54.584108999999998	Советская	0103000020E610000001000000050000002B6A300DC30748404E266E15C44A4B402B6A300DC3074840BF64E3C1164D4B40BB9866BAD70B4840BF64E3C1164D4B40BB9866BAD70B48404E266E15C44A4B402B6A300DC30748404E266E15C44A4B40
47497	20384	47.883096999999999	47.911456999999999	54.449841999999997	54.430295999999998	Красная горка 	0103000020E610000001000000050000000D198F5209F14740C0CC77F013374B400D198F5209F14740012F336C94394B40EA5A7B9FAAF44740012F336C94394B40EA5A7B9FAAF44740C0CC77F013374B400D198F5209F14740C0CC77F013374B40
47541	20916	47.818930999999999	47.838146000000002	54.614713999999999	54.604306000000001	Молодёжная	0103000020E610000001000000050000001D5723BBD2E84740676325E6594D4B401D5723BBD2E847405932C7F2AE4E4B40F9A23D5E48EB47405932C7F2AE4E4B40F9A23D5E48EB4740676325E6594D4B401D5723BBD2E84740676325E6594D4B40
47287	20798	47.913200000000003	47.933250000000001	54.519840000000002	54.512993000000002	Молодёжная	0103000020E61000000100000005000000865AD3BCE3F44740D9092FC1A9414B40865AD3BCE3F447408A93FB1D8A424B40FA7E6ABC74F747408A93FB1D8A424B40FA7E6ABC74F74740D9092FC1A9414B40865AD3BCE3F44740D9092FC1A9414B40
47499	20805	47.827959	47.865004999999996	54.549517000000002	54.532071999999999	Кооперативная	0103000020E61000000100000005000000E5B67D8FFAE94740048F6FEF1A444B40E5B67D8FFAE947404BCCB39256464B4030F0DC7BB8EE47404BCCB39256464B4030F0DC7BB8EE4740048F6FEF1A444B40E5B67D8FFAE94740048F6FEF1A444B40
47285	20222	47.723323000000001	47.769505000000002	54.727167000000001	54.705433999999997	Школьная	0103000020E61000000100000005000000E9B81AD995DC474044BE4BA94B5A4B40E9B81AD995DC47407FDDE9CE135D4B40E38DCC237FE247407FDDE9CE135D4B40E38DCC237FE2474044BE4BA94B5A4B40E9B81AD995DC474044BE4BA94B5A4B40
47288	21513	47.677976000000001	47.696418000000001	54.449261	54.432746999999999	Школьная	0103000020E6100000010000000500000088BCE5EAC7D647409738F24064374B4088BCE5EAC7D64740232F6B6281394B40412C9B3924D94740232F6B6281394B40412C9B3924D947409738F24064374B4088BCE5EAC7D647409738F24064374B40
47341	21757	47.739313000000003	47.794657999999998	54.558832000000002	54.539583999999998	Центральная	0103000020E61000000100000005000000FB40F2CEA1DE4740F1B8A81611454B40FB40F2CEA1DE4740A9FA95CE87474B409CC0745AB7E54740A9FA95CE87474B409CC0745AB7E54740F1B8A81611454B40FB40F2CEA1DE4740F1B8A81611454B40
47401	21221	48.030645999999997	48.064746	54.684100000000001	54.669018999999999	Суркова	0103000020E6100000010000000500000069E04735EC03484089B3226AA2554B4069E04735EC034840C898BB9690574B40FE45D09849084840C898BB9690574B40FE45D0984908484089B3226AA2554B4069E04735EC03484089B3226AA2554B40
47444	20699	47.880986	47.911951000000002	54.636819000000003	54.620662000000003	Ликино	0103000020E61000000100000005000000EF1D3526C4F047405BEF37DA714F4B40EF1D3526C4F04740583CF54883514B40FA4674CFBAF44740583CF54883514B40FA4674CFBAF447405BEF37DA714F4B40EF1D3526C4F047405BEF37DA714F4B40
47628	55828	48.107047000000001	48.141191999999997	54.730145999999998	54.714744000000003	Школьная	0103000020E61000000100000005000000451152B7B30D484091813CBB7C5B4B40451152B7B30D484011A7936C755D4B40793A57941212484011A7936C755D4B40793A57941212484091813CBB7C5B4B40451152B7B30D484091813CBB7C5B4B40
47465	20601	48.042476000000001	48.083241999999998	54.518507	54.498685000000002	Церковная	0103000020E61000000100000005000000B56E83DA6F054840BD00FBE8D43F4B40B56E83DA6F054840A0DFF76F5E424B40AAD381ACA70A4840A0DFF76F5E424B40AAD381ACA70A4840BD00FBE8D43F4B40B56E83DA6F054840BD00FBE8D43F4B40
47611	21456	47.706865999999998	47.732719000000003	54.435203000000001	54.421889	Школьная	0103000020E61000000100000005000000C153C8957ADA474065C5707500364B40C153C8957ADA4740800F5EBBB4374B40341477BCC9DD4740800F5EBBB4374B40341477BCC9DD474065C5707500364B40C153C8957ADA474065C5707500364B40
47498	21090	48.197076000000003	48.214378000000004	54.718671000000001	54.698562000000003	Центральная	0103000020E61000000100000005000000CB694FC9391948403B1DC87A6A594B40CB694FC939194840B4CA4C69FD5B4B40AF7D01BD701B4840B4CA4C69FD5B4B40AF7D01BD701B48403B1DC87A6A594B40CB694FC9391948403B1DC87A6A594B40
47373	55792	48.180458000000002	48.209249	54.699071000000004	54.676433000000003	Колхозная	0103000020E610000001000000050000009A266C3F19174840B477465B95564B409A266C3F19174840804A95287B594B4040DCD5ABC81A4840804A95287B594B4040DCD5ABC81A4840B477465B95564B409A266C3F19174840B477465B95564B40
47361	21691	47.634892999999998	47.675676000000003	54.551673999999998	54.534846000000002	Пролетарская	0103000020E61000000100000005000000CBBA7F2C44D14740BE326FD575444B40CBBA7F2C44D14740D906EE409D464B409758198D7CD64740D906EE409D464B409758198D7CD64740BE326FD575444B40CBBA7F2C44D14740BE326FD575444B40
47102	20481	47.945880000000002	47.986727000000002	54.526423999999999	54.507657000000002	площадь Революции	0103000020E6100000010000000500000062F8889812F94740F14A92E7FA404B4062F8889812F947402DEA93DC61434B40448A01124DFE47402DEA93DC61434B40448A01124DFE4740F14A92E7FA404B4062F8889812F94740F14A92E7FA404B40
47036	20481	47.945880000000002	47.986727000000002	54.526423999999999	54.507657000000002	Садовая	0103000020E6100000010000000500000062F8889812F94740F14A92E7FA404B4062F8889812F947402DEA93DC61434B40448A01124DFE47402DEA93DC61434B40448A01124DFE4740F14A92E7FA404B4062F8889812F94740F14A92E7FA404B40
47610	21185	48.071311999999999	48.107326	54.571449000000001	54.554833000000002	Труда	0103000020E61000000100000005000000FBE769C020094840ECDE8AC404474B40FBE769C0200948407C2AA73D25494B405801BEDBBC0D48407C2AA73D25494B405801BEDBBC0D4840ECDE8AC404474B40FBE769C020094840ECDE8AC404474B40
47339	20144	47.654988000000003	47.693966000000003	54.627637	54.600696999999997	Ленина	0103000020E61000000100000005000000E0A293A5D6D3474014E7A8A3E34C4B40E0A293A5D6D347403961C26856504B409A44BDE0D3D847403961C26856504B409A44BDE0D3D8474014E7A8A3E34C4B40E0A293A5D6D3474014E7A8A3E34C4B40
47462	19921	48.220180999999997	48.243698999999999	54.572367999999997	54.538685000000001	Свияжская	0103000020E61000000100000005000000AC1919E42E1C484042EC4CA1F3444B40AC1919E42E1C484072A3C85A43494B40B1886187311F484072A3C85A43494B40B1886187311F484042EC4CA1F3444B40AC1919E42E1C484042EC4CA1F3444B40
46893	18733	48.274053000000002	48.282640999999998	54.12041	54.114130000000003	Каштанкина	0103000020E61000000100000005000000732F302B142348400ABFD4CF9B0E4B40732F302B14234840410E4A98690F4B401EC18D942D244840410E4A98690F4B401EC18D942D2448400ABFD4CF9B0E4B40732F302B142348400ABFD4CF9B0E4B40
47094	18733	48.274053000000002	48.282640999999998	54.12041	54.114130000000003	Димитрова	0103000020E61000000100000005000000732F302B142348400ABFD4CF9B0E4B40732F302B14234840410E4A98690F4B401EC18D942D244840410E4A98690F4B401EC18D942D2448400ABFD4CF9B0E4B40732F302B142348400ABFD4CF9B0E4B40
47229	55778	47.820799000000001	48.549529999999997	54.694524000000001	54.053797000000003	капитана Каравашкина	0103000020E6100000010000000500000075CB0EF10FE94740BCCFF1D1E2064B4075CB0EF10FE94740C0249529E6584B40DF15C1FF56464840C0249529E6584B40DF15C1FF56464840BCCFF1D1E2064B4075CB0EF10FE94740BCCFF1D1E2064B40
47299	19544	48.199537999999997	48.233826000000001	54.521528000000004	54.506082999999997	Победы	0103000020E61000000100000005000000952710768A194840E107E753C7404B40952710768A19484062F9F36DC1424B402D7AA702EE1D484062F9F36DC1424B402D7AA702EE1D4840E107E753C7404B40952710768A194840E107E753C7404B40
47096	19599	48.373182	48.416426999999999	54.616897999999999	54.597641000000003	Мира	0103000020E610000001000000050000005ABA826DC42F4840D7DF12807F4C4B405ABA826DC42F4840E17B7F83F64E4B40F015DD7A4D354840E17B7F83F64E4B40F015DD7A4D354840D7DF12807F4C4B405ABA826DC42F4840D7DF12807F4C4B40
47077	3044	48.251486999999997	48.283718999999998	54.481228999999999	54.449413	Победы	0103000020E61000000100000005000000402FDCB930204840D9B27C5D86394B40402FDCB930204840827170E9983D4B407D2079E750244840827170E9983D4B407D2079E750244840D9B27C5D86394B40402FDCB930204840D9B27C5D86394B40
47443	18834	48.207720999999999	48.224834000000001	54.080596999999997	54.06982	Лесная	0103000020E61000000100000005000000A1D80A9A961A4840A94D9CDCEF084B40A1D80A9A961A4840EE93A300510A4B40B2834A5CC71C4840EE93A300510A4B40B2834A5CC71C4840A94D9CDCEF084B40A1D80A9A961A4840A94D9CDCEF084B40
47502	55815	48.470658	48.503680000000003	54.118822000000002	54.108941999999999	Ленина	0103000020E61000000100000005000000E6CC76853E3C48409694BBCFF10D4B40E6CC76853E3C4840CD052E8F350F4B401CD3139678404840CD052E8F350F4B401CD31396784048409694BBCFF10D4B40E6CC76853E3C48409694BBCFF10D4B40
47310	55788	48.066398	48.089044999999999	54.216852000000003	54.205505000000002	переулок Школьный	0103000020E610000001000000050000008942CBBA7F0848400E15E3FC4D1A4B408942CBBA7F0848403E096CCEC11B4B40A86F99D3650B48403E096CCEC11B4B40A86F99D3650B48400E15E3FC4D1A4B408942CBBA7F0848400E15E3FC4D1A4B40
47330	19405	48.114674000000001	48.150956999999998	54.429640999999997	54.412244000000001	Школьная	0103000020E61000000100000005000000CBD93BA3AD0E484072FC5069C4344B40CBD93BA3AD0E4840A702EE79FE364B40170D198F52134840A702EE79FE364B40170D198F5213484072FC5069C4344B40CBD93BA3AD0E484072FC5069C4344B40
47364	18656	48.344408999999999	48.374322999999997	54.501660000000001	54.491427000000002	Центральная	0103000020E610000001000000050000005AB91798152C48408AAF7614E73E4B405AB91798152C48400EDB166536404B40FF91E9D0E92F48400EDB166536404B40FF91E9D0E92F48408AAF7614E73E4B405AB91798152C48408AAF7614E73E4B40
47369	55791	48.313839000000002	48.339477000000002	54.123533999999999	54.113486000000002	Школьная	0103000020E61000000100000005000000CC9A58E02B284840E54691B5860E4B40CC9A58E02B284840D7F84CF6CF0F4B40425F7AFB732B4840D7F84CF6CF0F4B40425F7AFB732B4840E54691B5860E4B40CC9A58E02B284840E54691B5860E4B40
47261	55779	48.390878999999998	48.413490000000003	54.116985	54.107638000000001	Ленина	0103000020E61000000100000005000000BAD8B4520832484047E7FC14C70D4B40BAD8B45208324840B08F4E5DF90E4B408D9C853DED344840B08F4E5DF90E4B408D9C853DED34484047E7FC14C70D4B40BAD8B4520832484047E7FC14C70D4B40
47020	55762	48.511172000000002	48.549529999999997	54.112895000000002	54.090077000000001	Полевая	0103000020E61000000100000005000000C25087156E414840978FA4A4870B4B40C25087156E414840E370E657730E4B40DF15C1FF56464840E370E657730E4B40DF15C1FF56464840978FA4A4870B4B40C25087156E414840978FA4A4870B4B40
47496	19048	48.089593000000001	48.111080999999999	54.199168999999998	54.180135	Школьная	0103000020E61000000100000005000000AB798EC8770B4840B7EEE6A90E174B40AB798EC8770B484042B0AA5E7E194B407E1AF7E6370E484042B0AA5E7E194B407E1AF7E6370E4840B7EEE6A90E174B40AB798EC8770B4840B7EEE6A90E174B40
47263	55780	48.010586000000004	48.031264999999998	54.167824000000003	54.154153999999998	Лесная	0103000020E61000000100000005000000D2E5CDE15A01484017467A51BB134B40D2E5CDE15A014840F1BDBF417B154B403541D47D00044840F1BDBF417B154B403541D47D0004484017467A51BB134B40D2E5CDE15A01484017467A51BB134B40
47598	19310	47.950426	47.979415000000003	54.405631	54.390388999999999	Школьная	0103000020E6100000010000000500000051A2258FA7F94740ECDB4944F8314B4051A2258FA7F94740349F73B7EB334B401E1B81785DFD4740349F73B7EB334B401E1B81785DFD4740ECDB4944F8314B4051A2258FA7F94740ECDB4944F8314B40
47298	18937	48.091991	48.116542000000003	54.094793000000003	54.070892000000001	Набережная	0103000020E610000001000000050000005F43705CC60B484026C632FD12094B405F43705CC60B4840E371512D220C4B40234E27D9EA0E4840E371512D220C4B40234E27D9EA0E484026C632FD12094B405F43705CC60B484026C632FD12094B40
47360	19869	48.337681000000003	48.364485999999999	54.558962999999999	54.547291999999999	Колхозная	0103000020E6100000010000000500000084BD8921392B484064AE0CAA0D464B4084BD8921392B484047567E198C474B40C8EC2C7AA72E484047567E198C474B40C8EC2C7AA72E484064AE0CAA0D464B4084BD8921392B484064AE0CAA0D464B40
47415	55804	48.105538000000003	48.112867999999999	54.414349999999999	54.407507000000003	Школьная	0103000020E610000001000000050000001D3EE944820D48400FF27A3029344B401D3EE944820D48407E8CB96B09354B40E9616875720E48407E8CB96B09354B40E9616875720E48400FF27A3029344B401D3EE944820D48400FF27A3029344B40
47648	55841	47.820799000000001	48.549529999999997	54.694524000000001	54.053797000000003	Школьная	0103000020E6100000010000000500000075CB0EF10FE94740BCCFF1D1E2064B4075CB0EF10FE94740C0249529E6584B40DF15C1FF56464840C0249529E6584B40DF15C1FF56464840BCCFF1D1E2064B4075CB0EF10FE94740BCCFF1D1E2064B40
47379	55795	48.112724999999998	48.131715	54.277729999999998	54.265163999999999	Мира	0103000020E610000001000000050000008638D6C56D0E4840CC09DAE4F0214B408638D6C56D0E48401D8F19A88C234B4042B28009DC1048401D8F19A88C234B4042B28009DC104840CC09DAE4F0214B408638D6C56D0E4840CC09DAE4F0214B40
46972	25285	48.371529000000002	48.413426999999999	54.154876000000002	54.130974000000002	Ульяновская	0103000020E61000000100000005000000FF4124438E2F48402B508BC1C3104B40FF4124438E2F4840B8770DFAD2134B4046240A2DEB344840B8770DFAD2134B4046240A2DEB3448402B508BC1C3104B40FF4124438E2F48402B508BC1C3104B40
46912	25285	48.371529000000002	48.413426999999999	54.154876000000002	54.130974000000002	Мира	0103000020E61000000100000005000000FF4124438E2F48402B508BC1C3104B40FF4124438E2F4840B8770DFAD2134B4046240A2DEB344840B8770DFAD2134B4046240A2DEB3448402B508BC1C3104B40FF4124438E2F48402B508BC1C3104B40
47260	25285	48.371529000000002	48.413426999999999	54.154876000000002	54.130974000000002	Кременская	0103000020E61000000100000005000000FF4124438E2F48402B508BC1C3104B40FF4124438E2F4840B8770DFAD2134B4046240A2DEB344840B8770DFAD2134B4046240A2DEB3448402B508BC1C3104B40FF4124438E2F48402B508BC1C3104B40
46914	25285	48.371529000000002	48.413426999999999	54.154876000000002	54.130974000000002	Комсомольская	0103000020E61000000100000005000000FF4124438E2F48402B508BC1C3104B40FF4124438E2F4840B8770DFAD2134B4046240A2DEB344840B8770DFAD2134B4046240A2DEB3448402B508BC1C3104B40FF4124438E2F48402B508BC1C3104B40
46915	25285	48.371529000000002	48.413426999999999	54.154876000000002	54.130974000000002	Заводская	0103000020E61000000100000005000000FF4124438E2F48402B508BC1C3104B40FF4124438E2F4840B8770DFAD2134B4046240A2DEB344840B8770DFAD2134B4046240A2DEB3448402B508BC1C3104B40FF4124438E2F48402B508BC1C3104B40
47219	55775	48.128678999999998	48.158771999999999	54.306916999999999	54.297559999999997	Центральная	0103000020E610000001000000050000004B57B08D78104840834C327216264B404B57B08D7810484010CB660E49274B40A0C211A45214484010CB660E49274B40A0C211A452144840834C327216264B404B57B08D78104840834C327216264B40
47331	18298	48.23901	48.307577999999999	53.924675000000001	53.903917999999997	Центральная	0103000020E610000001000000050000005FB532E1971E48400322C495B3F34A405FB532E1971E4840E3361AC05BF64A400B7C45B75E274840E3361AC05BF64A400B7C45B75E2748400322C495B3F34A405FB532E1971E48400322C495B3F34A40
47297	18298	48.23901	48.307577999999999	53.924675000000001	53.903917999999997	Ленина	0103000020E610000001000000050000005FB532E1971E48400322C495B3F34A405FB532E1971E4840E3361AC05BF64A400B7C45B75E274840E3361AC05BF64A400B7C45B75E2748400322C495B3F34A405FB532E1971E48400322C495B3F34A40
46974	17105	48.341858000000002	48.392128	53.729680999999999	53.704115000000002	площадь Ленина	0103000020E6100000010000000500000020F0C000C22B4840C0CFB87020DA4A4020F0C000C22B48409CC1DF2F66DD4A4046EC1340313248409CC1DF2F66DD4A4046EC134031324840C0CFB87020DA4A4020F0C000C22B4840C0CFB87020DA4A40
47089	17105	48.341858000000002	48.392128	53.729680999999999	53.704115000000002	Евстифеева	0103000020E6100000010000000500000020F0C000C22B4840C0CFB87020DA4A4020F0C000C22B48409CC1DF2F66DD4A4046EC1340313248409CC1DF2F66DD4A4046EC134031324840C0CFB87020DA4A4020F0C000C22B4840C0CFB87020DA4A40
47056	17105	48.341858000000002	48.392128	53.729680999999999	53.704115000000002	Булыгина	0103000020E6100000010000000500000020F0C000C22B4840C0CFB87020DA4A4020F0C000C22B48409CC1DF2F66DD4A4046EC1340313248409CC1DF2F66DD4A4046EC134031324840C0CFB87020DA4A4020F0C000C22B4840C0CFB87020DA4A40
47433	18204	48.108412999999999	48.136358999999999	53.915129999999998	53.892510999999999	Ряская	0103000020E610000001000000050000000ABB287AE00D4840FE28EACC3DF24A400ABB287AE00D484053CBD6FA22F54A40F4C132367411484053CBD6FA22F54A40F4C1323674114840FE28EACC3DF24A400ABB287AE00D4840FE28EACC3DF24A40
47402	16909	47.340649999999997	47.375055000000003	54.562376999999998	54.546379000000002	пер. Школьный	0103000020E61000000100000005000000F2B0506B9AAB4740501C40BFEF454B40F2B0506B9AAB4740E48233F8FB474B40C4995FCD01B04740E48233F8FB474B40C4995FCD01B04740501C40BFEF454B40F2B0506B9AAB4740501C40BFEF454B40
47495	16909	47.340649999999997	47.375055000000003	54.562376999999998	54.546379000000002	Первомайская	0103000020E61000000100000005000000F2B0506B9AAB4740501C40BFEF454B40F2B0506B9AAB4740E48233F8FB474B40C4995FCD01B04740E48233F8FB474B40C4995FCD01B04740501C40BFEF454B40F2B0506B9AAB4740501C40BFEF454B40
47603	16735	46.526874999999997	46.545136999999997	54.655265999999997	54.639637999999998	Гора	0103000020E610000001000000050000003D0AD7A370434740B1A371A8DF514B403D0AD7A37043474022179CC1DF534B40766B990CC745474022179CC1DF534B40766B990CC7454740B1A371A8DF514B403D0AD7A370434740B1A371A8DF514B40
47539	17025	47.190899999999999	47.215558999999999	54.538621999999997	54.526398	Центральная	0103000020E61000000100000005000000386744696F9847400457790261434B40386744696F984740FB73D190F1444B40E2ADF36F979B4740FB73D190F1444B40E2ADF36F979B47400457790261434B40386744696F9847400457790261434B40
47494	16634	46.545406999999997	46.587797999999999	54.611939999999997	54.594537000000003	Школьная	0103000020E61000000100000005000000360186E5CF45474088A1D5C9194C4B40360186E5CF4547409F8EC70C544E4B40BD5301F73C4B47409F8EC70C544E4B40BD5301F73C4B474088A1D5C9194C4B40360186E5CF45474088A1D5C9194C4B40
47490	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Юбилейная	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
46867	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Энгельса	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
47535	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Центральная	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
46889	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Хазова	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
47030	5226	47.243541999999998	47.267122000000001	53.104140999999998	53.083668000000003	Юдина	0103000020E61000000100000005000000E9995E622C9F474062DC0DA2B58A4A40E9995E622C9F47401C96067E548D4A406405BF0D31A247401C96067E548D4A406405BF0D31A2474062DC0DA2B58A4A40E9995E622C9F474062DC0DA2B58A4A40
47034	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Советская	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
47328	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Промышленная	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
47602	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Ленина	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
47409	16005	46.687475999999997	46.738985	54.494616999999998	54.464810999999997	Зеленая	0103000020E610000001000000050000007764AC36FF57474018E945ED7E3B4B407764AC36FF574740D7851F9C4F3F4B40069E7B0F975E4740D7851F9C4F3F4B40069E7B0F975E474018E945ED7E3B4B407764AC36FF57474018E945ED7E3B4B40
47492	15823	46.737178999999998	46.768763999999997	54.661974000000001	54.627861000000003	Советская	0103000020E610000001000000050000002426A8E15B5E474089B7CEBF5D504B402426A8E15B5E4740B2666490BB544B40CB2BD7DB66624740B2666490BB544B40CB2BD7DB6662474089B7CEBF5D504B402426A8E15B5E474089B7CEBF5D504B40
47353	15823	46.737178999999998	46.768763999999997	54.661974000000001	54.627861000000003	Комсомольская	0103000020E610000001000000050000002426A8E15B5E474089B7CEBF5D504B402426A8E15B5E4740B2666490BB544B40CB2BD7DB66624740B2666490BB544B40CB2BD7DB6662474089B7CEBF5D504B402426A8E15B5E474089B7CEBF5D504B40
47606	15566	47.278190000000002	47.300423000000002	54.439444000000002	54.417865999999997	Мира	0103000020E610000001000000050000008109DCBA9BA347401F0E12A27C354B408109DCBA9BA34740333674B33F384B40ADFBC74274A64740333674B33F384B40ADFBC74274A647401F0E12A27C354B408109DCBA9BA347401F0E12A27C354B40
47534	15336	47.229509999999998	47.254913999999999	54.626198000000002	54.618098000000003	пер. Центральный	0103000020E610000001000000050000006F0D6C95609D47408CDCD3D51D4F4B406F0D6C95609D47400A698D4127504B4072A59E05A1A047400A698D4127504B4072A59E05A1A047408CDCD3D51D4F4B406F0D6C95609D47408CDCD3D51D4F4B40
47397	15650	47.056080999999999	47.086587999999999	54.472842999999997	54.452381000000003	Линёвка	0103000020E61000000100000005000000A77686A92D874740782AE09EE7394B40A77686A92D8747403E92921E863C4B40EF1CCA50158B47403E92921E863C4B40EF1CCA50158B4740782AE09EE7394B40A77686A92D874740782AE09EE7394B40
47282	15438	46.875978000000003	46.918512999999997	54.487374000000003	54.469347999999997	Садовая	0103000020E61000000100000005000000FC010F0C20704740B4386398133C4B40FC010F0C20704740DA756F45623E4B40B5F97FD591754740DA756F45623E4B40B5F97FD591754740B4386398133C4B40FC010F0C20704740B4386398133C4B40
47597	15541	47.221147000000002	47.240281000000003	54.489272999999997	54.475636999999999	Мира	0103000020E61000000100000005000000E44D7E8B4E9C47403FE257ACE13C4B40E44D7E8B4E9C47406CE8667FA03E4B40D36C1E87C19E47406CE8667FA03E4B40D36C1E87C19E47403FE257ACE13C4B40E44D7E8B4E9C47403FE257ACE13C4B40
47493	16528	46.544409999999999	46.583379000000001	54.573870999999997	54.548169999999999	Большая дорога	0103000020E61000000100000005000000C4CE143AAF454740FC523F6F2A464B40C4CE143AAF454740B88FDC9A74494B402B16BF29AC4A4740B88FDC9A74494B402B16BF29AC4A4740FC523F6F2A464B40C4CE143AAF454740FC523F6F2A464B40
47447	52682	46.692317000000003	46.731152000000002	54.409514000000001	54.396202000000002	Центральная	0103000020E6100000010000000500000080BBECD79D5847400E4E44BFB6324B4080BBECD79D58474088A06AF46A344B40D7338463965D474088A06AF46A344B40D7338463965D47400E4E44BFB6324B4080BBECD79D5847400E4E44BFB6324B40
47540	16305	46.518332000000001	46.553330000000003	54.703232999999997	54.687961999999999	Ленина	0103000020E61000000100000005000000323CF6B358424740047289230F584B40323CF6B358424740E63BF889035A4B40A6F27684D3464740E63BF889035A4B40A6F27684D3464740047289230F584B40323CF6B358424740047289230F584B40
47600	16305	46.518332000000001	46.553330000000003	54.703232999999997	54.687961999999999	Красная площадь 	0103000020E61000000100000005000000323CF6B358424740047289230F584B40323CF6B358424740E63BF889035A4B40A6F27684D3464740E63BF889035A4B40A6F27684D3464740047289230F584B40323CF6B358424740047289230F584B40
47430	15810	46.628259	46.668188999999998	54.683886999999999	54.667321999999999	Центральная	0103000020E61000000100000005000000763579CA6A5047405EF3AACE6A554B40763579CA6A5047406C94F59B89574B4002469737875547406C94F59B89574B4002469737875547405EF3AACE6A554B40763579CA6A5047405EF3AACE6A554B40
47537	16412	46.563966000000001	46.596305000000001	54.440019999999997	54.423853000000001	Ягодная	0103000020E610000001000000050000002907B30930484740DFA7AAD040364B402907B30930484740FFCA4A9352384B407CB8E4B8534C4740FFCA4A9352384B407CB8E4B8534C4740DFA7AAD040364B402907B30930484740DFA7AAD040364B40
47392	15712	47.021532000000001	47.043056	54.499845999999998	54.481332999999999	Проулок	0103000020E61000000100000005000000A3E8818FC182474027BEDA519C3D4B40A3E8818FC1824740A98427F4FA3F4B40C3F2E7DB82854740A98427F4FA3F4B40C3F2E7DB8285474027BEDA519C3D4B40A3E8818FC182474027BEDA519C3D4B40
47599	15712	47.021532000000001	47.043056	54.499845999999998	54.481332999999999	Московская	0103000020E61000000100000005000000A3E8818FC182474027BEDA519C3D4B40A3E8818FC1824740A98427F4FA3F4B40C3F2E7DB82854740A98427F4FA3F4B40C3F2E7DB8285474027BEDA519C3D4B40A3E8818FC182474027BEDA519C3D4B40
47538	14682	47.073220999999997	47.113528000000002	54.630889000000003	54.607664999999997	Московская	0103000020E61000000100000005000000B130444E5F89474040F67AF7C74D4B40B130444E5F894740FD3383F8C0504B401497E315888E4740FD3383F8C0504B401497E315888E474040F67AF7C74D4B40B130444E5F89474040F67AF7C74D4B40
47487	14682	47.073220999999997	47.113528000000002	54.630889000000003	54.607664999999997	Волкова	0103000020E61000000100000005000000B130444E5F89474040F67AF7C74D4B40B130444E5F894740FD3383F8C0504B401497E315888E4740FD3383F8C0504B401497E315888E474040F67AF7C74D4B40B130444E5F89474040F67AF7C74D4B40
47489	15462	46.805047000000002	46.850878999999999	54.449162000000001	54.431274999999999	Садовая	0103000020E61000000100000005000000185FB4C70B6747408C4AEA0434374B40185FB4C70B674740904DF2237E394B4035ED629AE96C4740904DF2237E394B4035ED629AE96C47408C4AEA0434374B40185FB4C70B6747408C4AEA0434374B40
47637	55835	46.771486000000003	46.798696	54.598318999999996	54.574590999999998	Кирова	0103000020E6100000010000000500000033A9A10DC0624740B8C9A8328C494B4033A9A10DC0624740A7C98CB7954C4B4017B9A7AB3B664740A7C98CB7954C4B4017B9A7AB3B664740B8C9A8328C494B4033A9A10DC0624740B8C9A8328C494B40
47429	15139	47.118631000000001	47.156764000000003	54.552822999999997	54.540644	Центральная	0103000020E6100000010000000500000059A5F44C2F8F4740AA6395D233454B4059A5F44C2F8F474001BD70E7C2464B405798BED71094474001BD70E7C2464B405798BED710944740AA6395D233454B4059A5F44C2F8F4740AA6395D233454B40
47491	15139	47.118631000000001	47.156764000000003	54.552822999999997	54.540644	Линия	0103000020E6100000010000000500000059A5F44C2F8F4740AA6395D233454B4059A5F44C2F8F474001BD70E7C2464B405798BED71094474001BD70E7C2464B405798BED710944740AA6395D233454B4059A5F44C2F8F4740AA6395D233454B40
47296	15139	47.118631000000001	47.156764000000003	54.552822999999997	54.540644	Красная площадь	0103000020E6100000010000000500000059A5F44C2F8F4740AA6395D233454B4059A5F44C2F8F474001BD70E7C2464B405798BED71094474001BD70E7C2464B405798BED710944740AA6395D233454B4059A5F44C2F8F4740AA6395D233454B40
47389	17015	47.307366999999999	47.321550999999999	54.536658000000003	54.523716999999998	Центральная	0103000020E61000000100000005000000506F46CD57A74740FBAD9D2809434B40506F46CD57A7474082919735B1444B40807F4A9528A9474082919735B1444B40807F4A9528A94740FBAD9D2809434B40506F46CD57A74740FBAD9D2809434B40
47431	16612	46.601030999999999	46.620829000000001	54.589101999999997	54.572575999999998	переулок Школьный	0103000020E61000000100000005000000EB707495EE4C4740BC3C9D2B4A494B40EB707495EE4C47400C01C0B1674B4B4046B41D53774F47400C01C0B1674B4B4046B41D53774F4740BC3C9D2B4A494B40EB707495EE4C4740BC3C9D2B4A494B40
47426	55807	47.183525000000003	47.206350999999998	54.578499000000001	54.566777000000002	Садовая	0103000020E61000000100000005000000CC7F48BF7D974740009013268C484B40CC7F48BF7D97474065E256410C4A4B409A3FA6B5699A474065E256410C4A4B409A3FA6B5699A4740009013268C484B40CC7F48BF7D974740009013268C484B40
47601	55824	48.599314999999997	49.584327000000002	54.890044000000003	54.351092999999999	Пушкина	0103000020E6100000010000000500000049809A5AB64C4840616D8C9DF02C4B4049809A5AB64C4840220038F6EC714B40BC95253ACBCA4840220038F6EC714B40BC95253ACBCA4840616D8C9DF02C4B4049809A5AB64C4840616D8C9DF02C4B40
47393	14496	49.154958999999998	49.181953	54.798551000000003	54.777095000000003	переулок Школьный	0103000020E61000000100000005000000459C4EB2D59348404C7155D977634B40459C4EB2D593484014984EEB36664B405D34643C4A97484014984EEB36664B405D34643C4A9748404C7155D977634B40459C4EB2D59348404C7155D977634B40
47420	15047	49.228324000000001	49.277982999999999	54.435715999999999	54.410561999999999	Кооперативная	0103000020E610000001000000050000002A7288B8399D48407C7DAD4B8D344B402A7288B8399D4840062CB98AC5374B4007EC6AF294A34840062CB98AC5374B4007EC6AF294A348407C7DAD4B8D344B402A7288B8399D48407C7DAD4B8D344B40
47594	14973	49.501179	49.544297999999998	54.590994999999999	54.573286000000003	Советская	0103000020E6100000010000000500000093382BA226C0484099A0866F61494B4093382BA226C04840BD8C62B9A54B4B409CA38E8EABC54840BD8C62B9A54B4B409CA38E8EABC5484099A0866F61494B4093382BA226C0484099A0866F61494B40
46854	13908	48.890306000000002	48.958165000000001	54.617164000000002	54.593958000000001	Площадь Ленина	0103000020E610000001000000050000005FB7088CF57148404A99D4D0064C4B405FB7088CF57148406022DE3AFF4E4B40FF959526A57A48406022DE3AFF4E4B40FF959526A57A48404A99D4D0064C4B405FB7088CF57148404A99D4D0064C4B40
47002	13908	48.890306000000002	48.958165000000001	54.617164000000002	54.593958000000001	Льва Толстого	0103000020E610000001000000050000005FB7088CF57148404A99D4D0064C4B405FB7088CF57148406022DE3AFF4E4B40FF959526A57A48406022DE3AFF4E4B40FF959526A57A48404A99D4D0064C4B405FB7088CF57148404A99D4D0064C4B40
46979	13908	48.890306000000002	48.958165000000001	54.617164000000002	54.593958000000001	Комсомольская	0103000020E610000001000000050000005FB7088CF57148404A99D4D0064C4B405FB7088CF57148406022DE3AFF4E4B40FF959526A57A48406022DE3AFF4E4B40FF959526A57A48404A99D4D0064C4B405FB7088CF57148404A99D4D0064C4B40
47396	14668	49.355220000000003	49.3857	54.756745000000002	54.734954999999999	Школьная	0103000020E610000001000000050000004C7155D977AD48400E846401135E4B404C7155D977AD4840AD342905DD604B409A081B9E5EB14840AD342905DD604B409A081B9E5EB148400E846401135E4B404C7155D977AD48400E846401135E4B40
47338	14295	48.940666	48.958497000000001	54.544128000000001	54.528832999999999	Советская	0103000020E61000000100000005000000C53A55BE67784840D505BCCCB0434B40C53A55BE67784840406B7EFCA5454B4035289A07B07A4840406B7EFCA5454B4035289A07B07A4840D505BCCCB0434B40C53A55BE67784840D505BCCCB0434B40
47544	14210	49.150243000000003	49.184792000000002	54.503746	54.480773999999997	Придорожная	0103000020E61000000100000005000000FAB9A1293B93484030629F008A3D4B40FAB9A1293B934840D3BEB9BF7A404B40FE47A643A7974840D3BEB9BF7A404B40FE47A643A797484030629F008A3D4B40FAB9A1293B93484030629F008A3D4B40
47484	14476	49.181719999999999	49.215226999999999	54.786606999999997	54.772941000000003	Матвеевская	0103000020E61000000100000005000000BA83D89942974840685E0EBBEF624B40BA83D89942974840FFE6C589AF644B40AC1BEF8E8C9B4840FFE6C589AF644B40AC1BEF8E8C9B4840685E0EBBEF624B40BA83D89942974840685E0EBBEF624B40
47531	14862	49.363430999999999	49.407547000000001	54.504148999999998	54.477766000000003	Кооперативная	0103000020E6100000010000000500000021AD31E884AE48400492B06F273D4B4021AD31E884AE4840D2A755F487404B409D4A06802AB44840D2A755F487404B409D4A06802AB448400492B06F273D4B4021AD31E884AE48400492B06F273D4B40
47548	14964	49.438189000000001	49.466971000000001	54.608400000000003	54.585231	Магистральная	0103000020E61000000100000005000000C53BC09316B848407DCD72D9E84A4B40C53BC09316B8484076711B0DE04D4B401897AAB4C5BB484076711B0DE04D4B401897AAB4C5BB48407DCD72D9E84A4B40C53BC09316B848407DCD72D9E84A4B40
47547	14790	49.268101999999999	49.28022	54.576396000000003	54.568359000000001	Парковая	0103000020E6100000010000000500000000FF942A51A2484092B1DAFCBF484B4000FF942A51A24840CAC51858C7494B40B2D7BB3FDEA34840CAC51858C7494B40B2D7BB3FDEA3484092B1DAFCBF484B4000FF942A51A2484092B1DAFCBF484B40
47403	14383	48.849020000000003	48.884979000000001	54.516489999999997	54.500923	Дачная	0103000020E6100000010000000500000031D3F6AFAC6C48403868AF3E1E404B4031D3F6AFAC6C4840035B25581C424B40CA52EBFD46714840035B25581C424B40CA52EBFD467148403868AF3E1E404B4031D3F6AFAC6C48403868AF3E1E404B40
47377	55793	49.101958000000003	49.140765999999999	54.596482999999999	54.562168	Советская	0103000020E6100000010000000500000065C8B1F50C8D4840CA6DFB1EF5474B4065C8B1F50C8D48405BCF108E594C4B40C231CB9E049248405BCF108E594C4B40C231CB9E04924840CA6DFB1EF5474B4065C8B1F50C8D4840CA6DFB1EF5474B40
47543	14121	49.150754999999997	49.172189000000003	54.737090999999999	54.716793000000003	Казанская	0103000020E61000000100000005000000AF5A99F04B93484039807EDFBF5B4B40AF5A99F04B934840859675FF585E4B4090DD054A0A964840859675FF585E4B4090DD054A0A96484039807EDFBF5B4B40AF5A99F04B93484039807EDFBF5B4B40
47425	14884	49.411599000000002	49.435979000000003	54.464664999999997	54.452249999999999	 Школьная	0103000020E610000001000000050000007D08AA46AFB44840D9CEF753E3394B407D08AA46AFB44840444C89247A3B4B40145FED28CEB74840444C89247A3B4B40145FED28CEB74840D9CEF753E3394B407D08AA46AFB44840D9CEF753E3394B40
47258	14393	48.913356999999998	48.940171999999997	54.444879	54.425047999999997	Школьная	0103000020E610000001000000050000004D49D6E1E8744840779D0DF967364B404D49D6E1E8744840AED689CBF1384B40B54E5C8E57784840AED689CBF1384B40B54E5C8E57784840779D0DF967364B404D49D6E1E8744840779D0DF967364B40
47394	14568	49.255803999999998	49.283192999999997	54.814926999999997	54.797865999999999	Центральная	0103000020E61000000100000005000000CE177B2FBEA04840904B1C7920664B40CE177B2FBEA048404ED026874F684B4062BA10AB3FA448404ED026874F684B4062BA10AB3FA44840904B1C7920664B40CE177B2FBEA04840904B1C7920664B40
47486	14318	48.978566000000001	48.995291999999999	54.529041999999997	54.518935999999997	Снежная	0103000020E61000000100000005000000207D93A6417D4840C85BAE7E6C424B40207D93A6417D4840EF1AF4A5B7434B4037FC6EBA657F4840EF1AF4A5B7434B4037FC6EBA657F4840C85BAE7E6C424B40207D93A6417D4840C85BAE7E6C424B40
47483	14100	49.004041999999998	49.036633000000002	54.731233000000003	54.715738000000002	Центральная	0103000020E61000000100000005000000BCE7C072848048409240834D9D5B4B40BCE7C07284804840C460FE0A995D4B40297AE063B0844840C460FE0A995D4B40297AE063B08448409240834D9D5B4B40BCE7C072848048409240834D9D5B4B40
47336	14769	49.326726000000001	49.363188000000001	54.571281999999997	54.531063000000003	Московская	0103000020E610000001000000050000005F605628D2A94840CE8E54DFF9434B405F605628D2A948409065C1C41F494B405B26C3F17CAE48409065C1C41F494B405B26C3F17CAE4840CE8E54DFF9434B405F605628D2A94840CE8E54DFF9434B40
47395	14585	49.436230000000002	49.456738999999999	54.790142000000003	54.777064000000003	Школьная	0103000020E610000001000000050000005DC47762D6B74840117349D576634B405DC47762D6B748401899805F23654B4064E76D6C76BA48401899805F23654B4064E76D6C76BA4840117349D576634B405DC47762D6B74840117349D576634B40
47618	14031	49.042695999999999	49.055137999999999	54.678311999999998	54.670712000000002	Озаренная	0103000020E61000000100000005000000C3D501107785484073840CE4D9554B40C3D5011077854840FF3D78EDD2564B40286211C30E874840FF3D78EDD2564B40286211C30E87484073840CE4D9554B40C3D501107785484073840CE4D9554B40
47536	13251	47.745341000000003	47.765616000000001	52.61927	52.605238	Октябрьская	0103000020E6100000010000000500000019AF795567DF4740F2255470784D4A4019AF795567DF47406CB2463D444F4A40ADA580B4FFE147406CB2463D444F4A40ADA580B4FFE14740F2255470784D4A4019AF795567DF4740F2255470784D4A40
47357	55790	47.391179999999999	47.418111000000003	52.713053000000002	52.687192000000003	Юбилейная	0103000020E61000000100000005000000B56CAD2F12B2474053094FE8F5574A40B56CAD2F12B2474048A81952455B4A40878C47A984B5474048A81952455B4A40878C47A984B5474053094FE8F5574A40B56CAD2F12B2474053094FE8F5574A40
47325	13548	47.284604000000002	47.326402000000002	52.795189999999998	52.776328999999997	Ленина	0103000020E61000000100000005000000C82764E76DA44740DBF7A8BF5E634A40C82764E76DA44740990D32C9C8654A40ACAC6D8AC7A94740990D32C9C8654A40ACAC6D8AC7A94740DBF7A8BF5E634A40C82764E76DA44740DBF7A8BF5E634A40
47340	13260	47.898781999999997	47.938892000000003	52.796213000000002	52.766043000000003	Советская	0103000020E61000000100000005000000E21DE0490BF34740352A70B20D624A40E21DE0490BF3474035D3BD4EEA654A40EF3CF19C2DF8474035D3BD4EEA654A40EF3CF19C2DF84740352A70B20D624A40E21DE0490BF34740352A70B20D624A40
47391	13163	47.486707000000003	47.502417999999999	52.816769000000001	52.802219000000001	Молодёжная	0103000020E61000000100000005000000FDDD3B6A4CBE47406B9DB81CAF664A40FDDD3B6A4CBE47407DB1F7E28B684A40FB75A73B4FC047407DB1F7E28B684A40FB75A73B4FC047406B9DB81CAF664A40FDDD3B6A4CBE47406B9DB81CAF664A40
46963	12888	47.592663000000002	47.643301000000001	52.746575	52.709763000000002	Куйбышева	0103000020E610000001000000050000004E469561DCCB474097749483D95A4A404E469561DCCB47406F8104C58F5F4A40F73DEAAF57D247406F8104C58F5F4A40F73DEAAF57D2474097749483D95A4A404E469561DCCB474097749483D95A4A40
47354	13711	47.486707000000003	47.537793999999998	52.897421999999999	52.883952999999998	М. Асадуллина	0103000020E61000000100000005000000FDDD3B6A4CBE4740BD19355F25714A40FDDD3B6A4CBE4740FF5A5EB9DE724A4015FE0C6FD6C44740FF5A5EB9DE724A4015FE0C6FD6C44740BD19355F25714A40FDDD3B6A4CBE4740BD19355F25714A40
47423	13536	47.428719999999998	47.447648000000001	52.731411999999999	52.715595	Просвещения	0103000020E610000001000000050000001092054CE0B647402F17F19D985B4A401092054CE0B6474073F38DE89E5D4A40560F98874CB9474073F38DE89E5D4A40560F98874CB947402F17F19D985B4A401092054CE0B647402F17F19D985B4A40
47259	13062	47.544046000000002	47.572432999999997	52.681814000000003	52.663308000000001	Кузахметова	0103000020E6100000010000000500000083C2A04CA3C547406C96CB46E7544A4083C2A04CA3C547403CFA5FAE45574A4059130B7C45C947403CFA5FAE45574A4059130B7C45C947406C96CB46E7544A4083C2A04CA3C547406C96CB46E7544A40
47593	13433	48.003399999999999	48.023530999999998	52.790751999999998	52.781089999999999	Советская	0103000020E61000000100000005000000386744696F004840C79DD2C1FA634A40386744696F004840909F8D5C37654A4099B8551003034840909F8D5C37654A4099B8551003034840C79DD2C1FA634A40386744696F004840C79DD2C1FA634A40
47485	13154	47.566952999999998	47.580571999999997	52.764620999999998	52.750968999999998	Т. Рашитой 	0103000020E610000001000000050000003EAF78EA91C84740A8A78FC01F604A403EAF78EA91C84740DB6AD619DF614A40957CEC2E50CA4740DB6AD619DF614A40957CEC2E50CA4740A8A78FC01F604A403EAF78EA91C84740A8A78FC01F604A40
47546	13825	47.534829000000002	47.565748999999997	52.907634000000002	52.887892999999998	4-х братьев Аксяновых	0103000020E61000000100000005000000E8F9D34675C4474075AC527AA6714A40E8F9D34675C447406C5ED5592D744A40525F96766AC847406C5ED5592D744A40525F96766AC8474075AC527AA6714A40E8F9D34675C4474075AC527AA6714A40
47388	13086	47.639671999999997	47.671956999999999	52.660763000000003	52.646439000000001	Советская	0103000020E610000001000000050000005D15A8C5E0D14740F2ED5D83BE524A405D15A8C5E0D1474014B4C9E193544A40BDA8DDAF02D6474014B4C9E193544A40BDA8DDAF02D64740F2ED5D83BE524A405D15A8C5E0D14740F2ED5D83BE524A40
47482	13635	47.264778	47.288995999999997	52.739248000000003	52.723412000000003	Советская	0103000020E61000000100000005000000A359D93EE4A1474059C4B0C3985C4A40A359D93EE4A1474014D1AFAD9F5E4A40605628D2FDA4474014D1AFAD9F5E4A40605628D2FDA4474059C4B0C3985C4A40A359D93EE4A1474059C4B0C3985C4A40
47422	13810	47.623384999999999	47.662309	52.915996999999997	52.897649999999999	Советская	0103000020E6100000010000000500000092E86514CBCF474090A0F831E6724A4092E86514CBCF4740F71DC3633F754A40596C938AC6D44740F71DC3633F754A40596C938AC6D4474090A0F831E6724A4092E86514CBCF474090A0F831E6724A40
47595	13620	47.358248000000003	47.391188999999997	52.840029000000001	52.829436999999999	Советская	0103000020E61000000100000005000000C0ED0912DBAD4740D28BDAFD2A6A4A40C0ED0912DBAD47408658FD11866B4A4008C72C7B12B247408658FD11866B4A4008C72C7B12B24740D28BDAFD2A6A4A40C0ED0912DBAD4740D28BDAFD2A6A4A40
47591	13360	47.930816	47.941245000000002	52.699052000000002	52.689090999999998	Г. Тукая	0103000020E61000000100000005000000F94B8BFA24F74740E57B462234584A40F94B8BFA24F74740091A33897A594A40034356B77AF84740091A33897A594A40034356B77AF84740E57B462234584A40F94B8BFA24F74740E57B462234584A40
47589	13344	48.005789	48.032998999999997	52.685690000000001	52.672254000000002	Советская	0103000020E6100000010000000500000099D6A6B1BD004840774D486B0C564A4099D6A6B1BD004840DD989EB0C4574A407DE6AC4F39044840DD989EB0C4574A407DE6AC4F39044840774D486B0C564A4099D6A6B1BD004840774D486B0C564A40
47592	13730	47.348275999999998	47.391044999999998	52.904195999999999	52.890163999999999	Советская	0103000020E61000000100000005000000A8FDD64E94AC4740CC09DAE4F0714A40A8FDD64E94AC47404696CCB1BC734A40D52137C30DB247404696CCB1BC734A40D52137C30DB24740CC09DAE4F0714A40A8FDD64E94AC4740CC09DAE4F0714A40
47302	12972	47.739277000000001	47.766226000000003	52.706614999999999	52.692988	Школьная	0103000020E61000000100000005000000AED7F4A0A0DE47409E42AED4B3584A40AED7F4A0A0DE474078EE3D5C725A4A4026AC8DB113E2474078EE3D5C725A4A4026AC8DB113E247409E42AED4B3584A40AED7F4A0A0DE47409E42AED4B3584A40
47326	12824	48.630837	48.660876999999999	54.064140000000002	54.040602	Володарского	0103000020E61000000100000005000000AA0D4E44BF5048407B13437232054B40AA0D4E44BF504840C72E51BD35084B40DCD6169E97544840C72E51BD35084B40DCD6169E975448407B13437232054B40AA0D4E44BF5048407B13437232054B40
47351	12803	48.496045000000002	48.534475	54.052903999999998	54.004219999999997	Центральная	0103000020E61000000100000005000000132C0E677E3F48409BFEEC478A004B40132C0E677E3F4840EEE9EA8EC5064B40CAC342AD69444840EEE9EA8EC5064B40CAC342AD694448409BFEEC478A004B40132C0E677E3F48409BFEEC478A004B40
46960	11949	48.313246999999997	48.340394000000003	53.995381999999999	53.983111000000001	Садовая	0103000020E61000000100000005000000F9484A7A182848403FABCC94D6FD4A40F9484A7A18284840778368AD68FF4A4098E0D407922B4840778368AD68FF4A4098E0D407922B48403FABCC94D6FD4A40F9484A7A182848403FABCC94D6FD4A40
46888	11949	48.313246999999997	48.340394000000003	53.995381999999999	53.983111000000001	Заводская	0103000020E61000000100000005000000F9484A7A182848403FABCC94D6FD4A40F9484A7A18284840778368AD68FF4A4098E0D407922B4840778368AD68FF4A4098E0D407922B48403FABCC94D6FD4A40F9484A7A182848403FABCC94D6FD4A40
46868	11291	48.752656999999999	48.827595000000002	53.973500000000001	53.947885999999997	Чапаева	0103000020E61000000100000005000000800D8810576048400A2B155454F94A40800D881057604840F853E3A59BFC4A40A4AA09A2EE694840F853E3A59BFC4A40A4AA09A2EE6948400A2B155454F94A40800D8810576048400A2B155454F94A40
47289	11291	48.752656999999999	48.827595000000002	53.973500000000001	53.947885999999997	Октябрьская	0103000020E61000000100000005000000800D8810576048400A2B155454F94A40800D881057604840F853E3A59BFC4A40A4AA09A2EE694840F853E3A59BFC4A40A4AA09A2EE6948400A2B155454F94A40800D8810576048400A2B155454F94A40
47084	11291	48.752656999999999	48.827595000000002	53.973500000000001	53.947885999999997	Новая Линия	0103000020E61000000100000005000000800D8810576048400A2B155454F94A40800D881057604840F853E3A59BFC4A40A4AA09A2EE694840F853E3A59BFC4A40A4AA09A2EE6948400A2B155454F94A40800D8810576048400A2B155454F94A40
46887	11291	48.752656999999999	48.827595000000002	53.973500000000001	53.947885999999997	Красноармейская	0103000020E61000000100000005000000800D8810576048400A2B155454F94A40800D881057604840F853E3A59BFC4A40A4AA09A2EE694840F853E3A59BFC4A40A4AA09A2EE6948400A2B155454F94A40800D8810576048400A2B155454F94A40
46955	11291	48.752656999999999	48.827595000000002	53.973500000000001	53.947885999999997	Колхозная	0103000020E61000000100000005000000800D8810576048400A2B155454F94A40800D881057604840F853E3A59BFC4A40A4AA09A2EE694840F853E3A59BFC4A40A4AA09A2EE6948400A2B155454F94A40800D8810576048400A2B155454F94A40
47356	55789	48.716239999999999	48.749854999999997	54.011020000000002	53.993237999999998	Цементников	0103000020E61000000100000005000000240B98C0AD5B48407D923B6C22FF4A40240B98C0AD5B48400CCD751A69014B40FCDEA63FFB5F48400CCD751A69014B40FCDEA63FFB5F48407D923B6C22FF4A40240B98C0AD5B48407D923B6C22FF4A40
47590	12632	48.827379000000001	48.867435	53.772711000000001	53.763919000000001	Полевая	0103000020E61000000100000005000000D732198EE769484082E50819C8E14A40D732198EE76948403621AD31E8E24A40F0332E1C086F48403621AD31E8E24A40F0332E1C086F484082E50819C8E14A40D732198EE769484082E50819C8E14A40
47417	12674	48.870471000000002	48.898364000000001	53.810029999999998	53.796348000000002	Ленина	0103000020E61000000100000005000000E78EFE976B6F4840151E34BBEEE54A40E78EFE976B6F4840B2632310AFE74A40AEF36F97FD724840B2632310AFE74A40AEF36F97FD724840151E34BBEEE54A40E78EFE976B6F4840151E34BBEEE54A40
47587	12542	48.533873	48.569329000000003	53.787188	53.759874000000003	Школьная	0103000020E61000000100000005000000D49B51F355444840558A1D8D43E14A40D49B51F355444840DEE68D93C2E44A400BD5CDC5DF484840DEE68D93C2E44A400BD5CDC5DF484840558A1D8D43E14A40D49B51F355444840558A1D8D43E14A40
46966	12088	48.321843000000001	48.340699000000001	54.043246000000003	54.012549	переулок Пионерский	0103000020E6100000010000000500000028B9C326322948407B4CA4349B014B4028B9C3263229484067D7BD1589054B40D4635B069C2B484067D7BD1589054B40D4635B069C2B48407B4CA4349B014B4028B9C326322948407B4CA4349B014B40
47088	12088	48.321843000000001	48.340699000000001	54.043246000000003	54.012549	Мира	0103000020E6100000010000000500000028B9C326322948407B4CA4349B014B4028B9C3263229484067D7BD1589054B40D4635B069C2B484067D7BD1589054B40D4635B069C2B48407B4CA4349B014B4028B9C326322948407B4CA4349B014B40
47481	12334	48.681348999999997	48.701157000000002	53.956448999999999	53.94679	пер. Речной	0103000020E61000000100000005000000C614AC713657484005172B6A30F94A40C614AC71365748405DA5BBEB6CFA4A40452E3883BF5948405DA5BBEB6CFA4A40452E3883BF59484005172B6A30F94A40C614AC713657484005172B6A30F94A40
47283	12438	48.774082	48.830955000000003	53.851027999999999	53.825705999999997	Крупской	0103000020E610000001000000050000000D36751E15634840340EF5BBB0E94A400D36751E156348407AFD497CEEEC4A404EB9C2BB5C6A48407AFD497CEEEC4A404EB9C2BB5C6A4840340EF5BBB0E94A400D36751E15634840340EF5BBB0E94A40
47588	12251	48.847923999999999	48.875034999999997	53.846533999999998	53.830882000000003	Кооперативная	0103000020E610000001000000050000002BBF0CC6886C4840E46A64575AEA4A402BBF0CC6886C4840DD79E2395BEC4A407CED992501704840DD79E2395BEC4A407CED992501704840E46A64575AEA4A402BBF0CC6886C4840E46A64575AEA4A40
47418	12519	48.725672000000003	48.763050999999997	53.767207999999997	53.744556000000003	Ленина	0103000020E61000000100000005000000BCCFF1D1E25C484032056B9C4DDF4A40BCCFF1D1E25C4840629D2ADF33E24A400D17B9A7AB614840629D2ADF33E24A400D17B9A7AB61484032056B9C4DDF4A40BCCFF1D1E25C484032056B9C4DDF4A40
47327	12711	48.420954999999999	48.452314999999999	53.970210999999999	53.953327999999999	Советская	0103000020E61000000100000005000000390B7BDAE1354840382EE3A606FA4A40390B7BDAE1354840179CC1DF2FFC4A40C03E3A75E5394840179CC1DF2FFC4A40C03E3A75E5394840382EE3A606FA4A40390B7BDAE1354840382EE3A606FA4A40
47421	12174	48.792003999999999	48.823157000000002	53.882055999999999	53.863990999999999	Молодежная	0103000020E610000001000000050000008D26176360654840E884D04197EE4A408D26176360654840CB9E0436E7F04A409B3C65355D694840CB9E0436E7F04A409B3C65355D694840E884D04197EE4A408D26176360654840E884D04197EE4A40
46863	10428	47.834848999999998	47.897891999999999	52.868164999999998	52.845365000000001	пл. 50 лет ВЛКСМ	0103000020E61000000100000005000000950C0055DCEA47406E179AEB346C4A40950C0055DCEA47401344DD07206F4A4086AB0320EEF247401344DD07206F4A4086AB0320EEF247406E179AEB346C4A40950C0055DCEA47406E179AEB346C4A40
47324	10428	47.834848999999998	47.897891999999999	52.868164999999998	52.845365000000001	Свердлова	0103000020E61000000100000005000000950C0055DCEA47406E179AEB346C4A40950C0055DCEA47401344DD07206F4A4086AB0320EEF247401344DD07206F4A4086AB0320EEF247406E179AEB346C4A40950C0055DCEA47406E179AEB346C4A40
47281	10428	47.834848999999998	47.897891999999999	52.868164999999998	52.845365000000001	Кооперативная	0103000020E61000000100000005000000950C0055DCEA47406E179AEB346C4A40950C0055DCEA47401344DD07206F4A4086AB0320EEF247401344DD07206F4A4086AB0320EEF247406E179AEB346C4A40950C0055DCEA47406E179AEB346C4A40
47295	10428	47.834848999999998	47.897891999999999	52.868164999999998	52.845365000000001	Заводская	0103000020E61000000100000005000000950C0055DCEA47406E179AEB346C4A40950C0055DCEA47401344DD07206F4A4086AB0320EEF247401344DD07206F4A4086AB0320EEF247406E179AEB346C4A40950C0055DCEA47406E179AEB346C4A40
47609	10224	47.382268000000003	47.416207	52.618110999999999	52.590989	Молодежная	0103000020E6100000010000000500000057276728EEB04740DBA50D87A54B4A4057276728EEB047402026E1421E4F4A40E2AE5E4546B547402026E1421E4F4A40E2AE5E4546B54740DBA50D87A54B4A4057276728EEB04740DBA50D87A54B4A40
47280	10085	47.242274999999999	47.294800000000002	52.632334999999998	52.619171000000001	Советская	0103000020E61000000100000005000000B7D100DE029F4740D9D0CDFE404F4A40B7D100DE029F4740DE8E705AF0504A402F6EA301BCA54740DE8E705AF0504A402F6EA301BCA54740D9D0CDFE404F4A40B7D100DE029F4740D9D0CDFE404F4A40
47323	9400	47.044673000000003	47.074955000000003	52.637849000000003	52.610258999999999	Центральная	0103000020E61000000100000005000000D20149D8B78547407A8B87F71C4E4A40D20149D8B7854740A6643909A5514A40FAD51C2098894740A6643909A5514A40FAD51C20988947407A8B87F71C4E4A40D20149D8B78547407A8B87F71C4E4A40
47349	9881	47.209800999999999	47.240136999999997	52.858814000000002	52.837065000000003	Центральная	0103000020E6100000010000000500000084D558C2DA9A474029D027F2246B4A4084D558C2DA9A474069ACFD9DED6D4A409FC728CFBC9E474069ACFD9DED6D4A409FC728CFBC9E474029D027F2246B4A4084D558C2DA9A474029D027F2246B4A40
47368	10275	46.986516000000002	47.010491999999999	52.736494	52.724344000000002	Центральная	0103000020E61000000100000005000000897D0228467E4740E486DF4DB75C4A40897D0228467E4740A1D9756F455E4A40506F46CD57814740A1D9756F455E4A40506F46CD57814740E486DF4DB75C4A40897D0228467E4740E486DF4DB75C4A40
47529	9668	47.050296000000003	47.07676	52.880850000000002	52.859270000000002	Школьная	0103000020E61000000100000005000000508F6D19708647408B37328FFC6D4A40508F6D19708647403F575BB1BF704A400BD28C45D38947403F575BB1BF704A400BD28C45D38947408B37328FFC6D4A40508F6D19708647408B37328FFC6D4A40
47530	9801	46.953547999999998	46.986317999999997	52.905124000000001	52.887588000000001	Заречная	0103000020E61000000100000005000000469561DC0D7A47403929CC7B9C714A40469561DC0D7A474090696D1ADB734A4062BA10AB3F7E474090696D1ADB734A4062BA10AB3F7E47403929CC7B9C714A40469561DC0D7A47403929CC7B9C714A40
47472	9560	46.850887999999998	46.884475999999999	52.664433000000002	52.652132000000002	Молодежная	0103000020E610000001000000050000008847E2E5E96C47406956B60F79534A408847E2E5E96C47400CB1FA230C554A40670C7382367147400CB1FA230C554A40670C7382367147406956B60F79534A408847E2E5E96C47406956B60F79534A40
46958	9157	47.115586	47.170347	52.698625999999997	52.675623000000002	пл. Советская	0103000020E610000001000000050000000FF0A485CB8E474074B680D07A564A400FF0A485CB8E47405111A7936C594A4061FC34EECD9547405111A7936C594A4061FC34EECD95474074B680D07A564A400FF0A485CB8E474074B680D07A564A40
46890	9157	47.115586	47.170347	52.698625999999997	52.675623000000002	Школьная	0103000020E610000001000000050000000FF0A485CB8E474074B680D07A564A400FF0A485CB8E47405111A7936C594A4061FC34EECD9547405111A7936C594A4061FC34EECD95474074B680D07A564A400FF0A485CB8E474074B680D07A564A40
46952	9157	47.115586	47.170347	52.698625999999997	52.675623000000002	Калинина	0103000020E610000001000000050000000FF0A485CB8E474074B680D07A564A400FF0A485CB8E47405111A7936C594A4061FC34EECD9547405111A7936C594A4061FC34EECD95474074B680D07A564A400FF0A485CB8E474074B680D07A564A40
47350	10003	47.117471999999999	47.147205999999997	52.754522000000001	52.733179	Центральная	0103000020E610000001000000050000000D198F52098F4740978E39CFD85D4A400D198F52098F4740670E492D94604A4032E36DA5D7924740670E492D94604A4032E36DA5D7924740978E39CFD85D4A400D198F52098F4740978E39CFD85D4A40
47532	9985	47.168658000000001	47.183723000000001	52.808202000000001	52.795261000000004	Новая	0103000020E61000000100000005000000B91AD995969547406364C91CCB654A40B91AD99596954740E947C32973674A40F2423A3C84974740E947C32973674A40F2423A3C849747406364C91CCB654A40B91AD995969547406364C91CCB654A40
47480	10184	47.375368999999999	47.387182000000003	52.650044999999999	52.640318999999998	Садовая	0103000020E61000000100000005000000537765170CB04740F30016F9F5514A40537765170CB04740D3F6AFAC34534A40C9CC052E8FB14740D3F6AFAC34534A40C9CC052E8FB14740F30016F9F5514A40537765170CB04740F30016F9F5514A40
47412	9788	47.104590000000002	47.127740000000003	52.840378000000001	52.826369	Новая	0103000020E610000001000000050000008CBE8234638D4740D0B69A75C6694A408CBE8234638D474092239D81916B4A400E32C9C85990474092239D81916B4A400E32C9C859904740D0B69A75C6694A408CBE8234638D4740D0B69A75C6694A40
47348	9505	46.884340999999999	46.900860999999999	52.693173999999999	52.678986000000002	Колхозная	0103000020E6100000010000000500000087C1FC15327147408F386403E9564A4087C1FC15327147400038F6ECB9584A40F59ECA694F7347400038F6ECB9584A40F59ECA694F7347408F386403E9564A4087C1FC15327147408F386403E9564A40
47478	10382	46.973221000000002	46.997591999999997	52.800711	52.783453999999999	Школьная	0103000020E61000000100000005000000E5637781927C4740CFF57D3848644A40E5637781927C47401346B3B27D664A4028603B18B17F47401346B3B27D664A4028603B18B17F4740CFF57D3848644A40E5637781927C4740CFF57D3848644A40
47416	9690	47.008308999999997	47.032257999999999	52.858580000000003	52.848117000000002	Верхняя	0103000020E6100000010000000500000098A1F1441081474040170D198F6C4A4098A1F14410814740F67F0EF3E56D4A406684B70721844740F67F0EF3E56D4A406684B7072184474040170D198F6C4A4098A1F1441081474040170D198F6C4A40
47527	9380	47.205435000000001	47.227308999999998	52.674061000000002	52.658442000000001	А.Новикова	0103000020E61000000100000005000000153AAFB14B9A47400B28D4D347544A40153AAFB14B9A474029417FA147564A40118B1876189D474029417FA147564A40118B1876189D47400B28D4D347544A40153AAFB14B9A47400B28D4D347544A40
47607	9315	47.087792	47.114310000000003	52.603762000000003	52.589485000000003	Саратовская	0103000020E61000000100000005000000DB6CACC43C8B4740C53D963E744B4A40DB6CACC43C8B4740A648BE12484D4A408ACDC7B5A18E4740A648BE12484D4A408ACDC7B5A18E4740C53D963E744B4A40DB6CACC43C8B4740C53D963E744B4A40
47533	9898	47.200170999999997	47.219799000000002	52.828425000000003	52.818891999999998	Вторая	0103000020E61000000100000005000000C64D0D349F9947405F7AFB73D1684A40C64D0D349F9947402B1895D4096A4A40C558A65F229C47402B1895D4096A4A40C558A65F229C47405F7AFB73D1684A40C64D0D349F9947405F7AFB73D1684A40
47586	9298	47.213493	47.239257000000002	52.742704000000003	52.731400999999998	Центральная	0103000020E61000000100000005000000647616BD539B47407FA1478C9E5D4A40647616BD539B4740E04DB7EC105F4A40672B2FF99F9E4740E04DB7EC105F4A40672B2FF99F9E47407FA1478C9E5D4A40647616BD539B47407FA1478C9E5D4A40
47475	10106	47.343237000000002	47.369225	52.632263999999999	52.621850000000002	Луговая	0103000020E610000001000000050000007AE3A430EFAB47404182E2C7984F4A407AE3A430EFAB47401538D906EE504A40CCEEC9C342AF47401538D906EE504A40CCEEC9C342AF47404182E2C7984F4A407AE3A430EFAB47404182E2C7984F4A40
47528	9470	46.898722999999997	46.922393999999997	52.68432	52.668982999999997	Рабочая	0103000020E61000000100000005000000DD94F25A097347403C4A253CA1554A40DD94F25A09734740D6FF39CC97574A406803B00111764740D6FF39CC97574A406803B001117647403C4A253CA1554A40DD94F25A097347403C4A253CA1554A40
47476	9070	47.858725999999997	47.878525000000003	53.24944	53.235073999999997	Запрудная	0103000020E61000000100000005000000C91CCBBBEAED4740E811A3E7169E4A40C91CCBBBEAED4740392861A6ED9F4A40F5DBD78173F04740392861A6ED9F4A40F5DBD78173F04740E811A3E7169E4A40C91CCBBBEAED4740E811A3E7169E4A40
47605	8520	47.873646999999998	47.925398999999999	53.204692000000001	53.171869999999998	Школьная	0103000020E61000000100000005000000CF9F36AAD3EF4740EE940ED6FF954A40CF9F36AAD3EF47405DE0F258339A4A402460747973F647405DE0F258339A4A402460747973F64740EE940ED6FF954A40CF9F36AAD3EF4740EE940ED6FF954A40
47526	8800	47.575505	47.603568000000003	53.154631999999999	53.136111999999997	Почтовая	0103000020E610000001000000050000009DD7D825AAC94740EC4B361E6C914A409DD7D825AAC9474021753BFBCA934A40C1745AB741CD474021753BFBCA934A40C1745AB741CD4740EC4B361E6C914A409DD7D825AAC94740EC4B361E6C914A40
47524	8972	47.808762000000002	47.829692000000001	53.290168999999999	53.267696000000001	Молодежная	0103000020E61000000100000005000000B01F628385E7474090A2CEDC43A24A40B01F628385E7474011A8FE4124A54A405DE0F25833EA474011A8FE4124A54A405DE0F25833EA474090A2CEDC43A24A40B01F628385E7474090A2CEDC43A24A40
47378	55794	47.636977000000002	47.686303000000002	53.137981000000003	53.122360999999998	Школьная	0103000020E61000000100000005000000F0A65B7688D1474026A77686A98F4A40F0A65B7688D14740153C855CA9914A40C712D6C6D8D74740153C855CA9914A40C712D6C6D8D7474026A77686A98F4A40F0A65B7688D1474026A77686A98F4A40
47294	8691	48.070853999999997	48.113255000000002	53.179335000000002	53.149031999999998	Школьная	0103000020E6100000010000000500000038656EBE110948405B07077B13934A4038656EBE110948409B030473F4964A40E38DCC237F0E48409B030473F4964A40E38DCC237F0E48405B07077B13934A4038656EBE110948405B07077B13934A40
47473	9042	47.851925999999999	47.858770999999997	53.251627999999997	53.246617000000001	Центральная	0103000020E61000000100000005000000594E42E90BED47409ED15625919F4A40594E42E90BED47400261A75835A04A4069E04735ECED47400261A75835A04A4069E04735ECED47409ED15625919F4A40594E42E90BED47409ED15625919F4A40
47086	7937	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	площадь Макаренко	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
47284	7937	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	Сельхозтехника	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
46886	7937	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	Мира	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
46953	7937	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	Кузнецкая	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
47032	7937	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	Горького	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
47471	7937	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	Горшенина	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
47522	7937	47.710270000000001	47.792411999999999	53.162126000000001	53.133885999999997	Гагарина	0103000020E610000001000000050000003BAA9A20EADA474035B22B2D23914A403BAA9A20EADA474068EA758BC0944A409E7AA4C16DE5474068EA758BC0944A409E7AA4C16DE5474035B22B2D23914A403BAA9A20EADA474035B22B2D23914A40
47477	8858	47.536805999999999	47.560979000000003	53.061242	53.044002999999996	Молодежная	0103000020E61000000100000005000000F6251B0FB6C4474083F6EAE3A1854A40F6251B0FB6C44740219221C7D6874A40145FED28CEC74740219221C7D6874A40145FED28CEC7474083F6EAE3A1854A40F6251B0FB6C4474083F6EAE3A1854A40
47523	8611	48.112931000000003	48.147894000000001	53.155529000000001	53.148384	Центральная	0103000020E6100000010000000500000030DAE385740E4840F59F353FFE924A4030DAE385740E4840304AD05FE8934A4027A3CA30EE124840304AD05FE8934A4027A3CA30EE124840F59F353FFE924A4030DAE385740E4840F59F353FFE924A40
47584	8696	48.047085000000003	48.083170000000003	53.147962999999997	53.140341999999997	Урожайная	0103000020E61000000100000005000000EB909BE106064840AB2006BAF6914A40EB909BE1060648404F029B73F0924A4011018750A50A48404F029B73F0924A4011018750A50A4840AB2006BAF6914A40EB909BE106064840AB2006BAF6914A40
47082	8588	48.110021000000003	48.140824000000002	53.178843999999998	53.168810000000001	Школьная	0103000020E61000000100000005000000C66F0A2B150E48406F9EEA909B954A40C66F0A2B150E4840FC8A355CE4964A40F73E558506124840FC8A355CE4964A40F73E5585061248406F9EEA909B954A40C66F0A2B150E48406F9EEA909B954A40
47304	8484	47.912067999999998	47.966721	53.190908999999998	53.172474999999999	Ленина	0103000020E6100000010000000500000033DDEBA4BEF4474055302AA913964A4033DDEBA4BEF447408BC1C3B46F984A409FAD8383BDFB47408BC1C3B46F984A409FAD8383BDFB474055302AA913964A4033DDEBA4BEF4474055302AA913964A40
47470	8430	47.948135000000001	47.973619999999997	53.296756999999999	53.281641999999998	Советская	0103000020E61000000100000005000000B398D87C5CF947400B9755D80CA44A40B398D87C5CF94740F6ED2422FCA54A40A25D85949FFC4740F6ED2422FCA54A40A25D85949FFC47400B9755D80CA44A40B398D87C5CF947400B9755D80CA44A40
47585	7349	50.140670999999998	50.168816	54.180535999999996	54.168993999999998	Молодежная	0103000020E61000000100000005000000703FE08101124940309C6B98A1154B40703FE0810112494015E0BBCD1B174B4051853FC39B15494015E0BBCD1B174B4051853FC39B154940309C6B98A1154B40703FE08101124940309C6B98A1154B40
47525	7646	50.057011000000003	50.074491999999999	54.335819999999998	54.321491999999999	Центральная	0103000020E610000001000000050000009241EE224C0749407BF65CA626294B409241EE224C074940DEAB5626FC2A4B4025E82FF488094940DEAB5626FC2A4B4025E82FF4880949407BF65CA626294B409241EE224C0749407BF65CA626294B40
47320	7543	50.142504000000002	50.174258999999999	54.321207999999999	54.293582000000001	Кооперативная	0103000020E610000001000000050000004CC631923D124940DE58501894254B404CC631923D124940569BFF571D294B404F04711E4E164940569BFF571D294B404F04711E4E164940DE58501894254B404CC631923D124940DE58501894254B40
47613	7894	49.822074999999998	49.846283999999997	54.236441999999997	54.217778000000003	Центральная	0103000020E61000000100000005000000FAEDEBC039E94840E7E44526E01B4B40FAEDEBC039E948404EB340BB431E4B406490BB0853EC48404EB340BB431E4B406490BB0853EC4840E7E44526E01B4B40FAEDEBC039E94840E7E44526E01B4B40
47411	7264	49.969551000000003	49.991487999999997	54.231811	54.217289000000001	Совхозная	0103000020E61000000100000005000000ED66463F1AFC4840E9633E20D01B4B40ED66463F1AFC484031ED9BFBAB1D4B402F302B14E9FE484031ED9BFBAB1D4B402F302B14E9FE4840E9633E20D01B4B40ED66463F1AFC4840E9633E20D01B4B40
47520	7626	49.949168	49.992342000000001	54.308340000000001	54.284678999999997	Колхозная	0103000020E61000000100000005000000723447567EF94840D26D895C70244B40723447567EF948403A0664AF77274B403F390A1005FF48403A0664AF77274B403F390A1005FF4840D26D895C70244B40723447567EF94840D26D895C70244B40
47642	55839	50.070926	50.101900000000001	54.200617999999999	54.191152000000002	Кооперативная улица	0103000020E61000000100000005000000D237691A14094940524832AB77184B40D237691A14094940957EC2D9AD194B4030BB270F0B0D4940957EC2D9AD194B4030BB270F0B0D4940524832AB77184B40D237691A14094940524832AB77184B40
47319	7818	49.790706	49.831713999999998	54.173838000000003	54.160207	Октябрьская	0103000020E610000001000000050000002060ADDA35E548408ECBB8A981144B402060ADDA35E54840AA66D65240164B400BD0B69A75EA4840AA66D65240164B400BD0B69A75EA48408ECBB8A981144B402060ADDA35E548408ECBB8A981144B40
47293	7564	50.077734999999997	50.104523	54.294223000000002	54.253445999999997	Школьная	0103000020E6100000010000000500000095607138F3094940A8A624EB70204B4095607138F3094940925D6919A9254B4004577902610D4940925D6919A9254B4004577902610D4940A8A624EB70204B4095607138F3094940A8A624EB70204B40
46948	7439	50.119103000000003	50.190097000000002	54.391212000000003	54.336123999999998	Заводская	0103000020E6100000010000000500000081ED60C43E0F49404AB3791C062B4B4081ED60C43E0F4940C1E61C3C13324B40AB08371955184940C1E61C3C13324B40AB083719551849404AB3791C062B4B4081ED60C43E0F49404AB3791C062B4B40
46950	7439	50.119103000000003	50.190097000000002	54.391212000000003	54.336123999999998	Дорожная	0103000020E6100000010000000500000081ED60C43E0F49404AB3791C062B4B4081ED60C43E0F4940C1E61C3C13324B40AB08371955184940C1E61C3C13324B40AB083719551849404AB3791C062B4B4081ED60C43E0F49404AB3791C062B4B40
46947	7156	49.900371999999997	49.968707000000002	54.212614000000002	54.187196	Советская	0103000020E61000000100000005000000F71DC3633FF3484094F8DC09F6174B40F71DC3633FF34840FC5580EF361B4B4001344A97FEFB4840FC5580EF361B4B4001344A97FEFB484094F8DC09F6174B40F71DC3633FF3484094F8DC09F6174B40
46973	7156	49.900371999999997	49.968707000000002	54.212614000000002	54.187196	Кооперативная	0103000020E61000000100000005000000F71DC3633FF3484094F8DC09F6174B40F71DC3633FF34840FC5580EF361B4B4001344A97FEFB4840FC5580EF361B4B4001344A97FEFB484094F8DC09F6174B40F71DC3633FF3484094F8DC09F6174B40
47387	7063	50.035245000000003	50.068635	54.135637000000003	54.117348999999997	Советская	0103000020E610000001000000050000007C2C7DE882044940F19BC24A050F4B407C2C7DE88204494054909F8D5C114B40342E1C08C908494054909F8D5C114B40342E1C08C9084940F19BC24A050F4B407C2C7DE882044940F19BC24A050F4B40
47517	6994	50.129469	50.162446000000003	54.135590000000001	54.115470999999999	Колхозная	0103000020E61000000100000005000000446CB070921049407651F4C0C70E4B40446CB0709210494013D55B035B114B40DAAED007CB14494013D55B035B114B40DAAED007CB1449407651F4C0C70E4B40446CB070921049407651F4C0C70E4B40
47582	7807	49.771059999999999	49.810046	54.218330999999999	54.201171000000002	Молодежная	0103000020E610000001000000050000007BA01518B2E24840AAF3A8F8BF194B407BA01518B2E24840FB592C45F21B4B40B8205B96AFE74840FB592C45F21B4B40B8205B96AFE74840AAF3A8F8BF194B407BA01518B2E24840AAF3A8F8BF194B40
47479	6969	49.960667000000001	49.998136000000002	54.079175999999997	54.060070000000003	Центральная	0103000020E6100000010000000500000058ACE122F7FA484041BCAE5FB0074B4058ACE122F7FA484065506D70220A4B40EA7AA2EBC2FF484065506D70220A4B40EA7AA2EBC2FF484041BCAE5FB0074B4058ACE122F7FA484041BCAE5FB0074B40
47516	6893	50.086143999999997	50.109706000000003	54.085312999999999	54.067368000000002	Братьев Кипкаевых 	0103000020E61000000100000005000000915F3FC4060B49400266BE839F084B40915F3FC4060B49403A765089EB0A4B406616A1D80A0E49403A765089EB0A4B406616A1D80A0E49400266BE839F084B40915F3FC4060B49400266BE839F084B40
47413	7389	50.181024000000001	50.214162000000002	54.311644000000001	54.296886999999998	Центральная	0103000020E6100000010000000500000043E55FCB2B174940C4CDA96400264B4043E55FCB2B17494050FF59F3E3274B40E20511A9691B494050FF59F3E3274B40E20511A9691B4940C4CDA96400264B4043E55FCB2B174940C4CDA96400264B40
47488	7715	49.856355000000001	49.890185000000002	54.143844000000001	54.115043	Советская	0103000020E610000001000000050000000F62670A9DED48401E51A1BAB90E4B400F62670A9DED4840E8DCED7A69124B40E4310395F1F14840E8DCED7A69124B40E4310395F1F148401E51A1BAB90E4B400F62670A9DED48401E51A1BAB90E4B40
47649	55843	50.018878000000001	50.040391999999997	54.024540999999999	54.007432000000001	площадь 50-летия Победы	0103000020E61000000100000005000000944E24986A024940D1782288F3004B40944E24986A024940A034D42824034B409082A7902B054940A034D42824034B409082A7902B054940D1782288F3004B40944E24986A024940D1782288F3004B40
47583	7100	50.024762000000003	50.099564000000001	54.247906999999998	54.147266999999999	Центральная	0103000020E610000001000000050000007F17B6662B034940D86322A5D9124B407F17B6662B03494088B9A46ABB1F4B40F2ED5D83BE0C494088B9A46ABB1F4B40F2ED5D83BE0C4940D86322A5D9124B407F17B6662B034940D86322A5D9124B40
47467	6602	46.988205000000001	47.026409999999998	53.311059999999998	53.297710000000002	Центральная	0103000020E61000000100000005000000315F5E807D7E474099D87C5C1BA64A40315F5E807D7E4740008C67D0D0A74A40C824236761834740008C67D0D0A74A40C82423676183474099D87C5C1BA64A40315F5E807D7E474099D87C5C1BA64A40
47626	55829	47.084684000000003	47.124828999999998	53.303623999999999	53.291159999999998	Школьная	0103000020E610000001000000050000004B3FE1ECD68A4740A1F31ABB44A54A404B3FE1ECD68A4740EE23B726DDA64A40D34B8C65FA8F4740EE23B726DDA64A40D34B8C65FA8F4740A1F31ABB44A54A404B3FE1ECD68A4740A1F31ABB44A54A40
47577	5856	47.209809999999997	47.244574999999998	53.286703000000003	53.276985000000003	Советская	0103000020E61000000100000005000000D72FD80DDB9A4740C53D963E74A34A40D72FD80DDB9A4740225514AFB2A44A40A835CD3B4E9F4740225514AFB2A44A40A835CD3B4E9F4740C53D963E74A34A40D72FD80DDB9A4740C53D963E74A34A40
47579	5647	47.414014999999999	47.439473	53.238754999999998	53.223846000000002	переулок Школьный	0103000020E61000000100000005000000D7868A71FEB4474093AB58FCA69C4A40D7868A71FEB44740D4601A868F9E4A40CD3CB9A640B84740D4601A868F9E4A40CD3CB9A640B8474093AB58FCA69C4A40D7868A71FEB4474093AB58FCA69C4A40
47408	5570	47.246020999999999	47.291286999999997	53.025640000000003	53.007123999999997	Центральная	0103000020E610000001000000050000008A90BA9D7D9F474023827170E9804A408A90BA9D7D9F474017BCE82B48834A40FE5F75E448A5474017BCE82B48834A40FE5F75E448A5474023827170E9804A408A90BA9D7D9F474023827170E9804A40
46883	6482	47.094619000000002	47.154321000000003	53.300094000000001	53.284866999999998	Советская	0103000020E61000000100000005000000454AB3791C8C4740D55A988576A44A40454AB3791C8C4740E8DCED7A69A64A40030B60CAC0934740E8DCED7A69A64A40030B60CAC0934740D55A988576A44A40454AB3791C8C4740D55A988576A44A40
47407	6785	47.459631000000002	47.512011999999999	52.988160000000001	52.971992	Николаевская	0103000020E61000000100000005000000289D4830D5BA4740A0FCDD3B6A7C4A40289D4830D5BA4740919BE1067C7E4A406C94F59B89C14740919BE1067C7E4A406C94F59B89C14740A0FCDD3B6A7C4A40289D4830D5BA4740A0FCDD3B6A7C4A40
46884	6692	47.155012999999997	47.197189000000002	52.969768999999999	52.947082999999999	Узкоколейная	0103000020E6100000010000000500000038BA4A77D79347407DCC07043A794A4038BA4A77D79347405AD6FD63217C4A40C310397D3D9947405AD6FD63217C4A40C310397D3D9947407DCC07043A794A4038BA4A77D79347407DCC07043A794A40
47518	6292	46.956135000000003	46.990144999999998	53.195711000000003	53.181288000000002	Афанасьева	0103000020E61000000100000005000000CEC7B5A1627A47402194F77134974A40CEC7B5A1627A4740D63BDC0E0D994A4022A64412BD7E4740D63BDC0E0D994A4022A64412BD7E47402194F77134974A40CEC7B5A1627A47402194F77134974A40
47410	6515	47.038384000000001	47.067777	53.310457	53.303311999999998	Школьная	0103000020E61000000100000005000000475854C4E9844740FF3D78EDD2A64A40475854C4E98447403AE8120EBDA74A40E335AFEAAC8847403AE8120EBDA74A40E335AFEAAC884740FF3D78EDD2A64A40475854C4E9844740FF3D78EDD2A64A40
47466	5320	47.136184	47.163114999999998	53.197712000000003	53.181569000000003	Молодёжная	0103000020E61000000100000005000000861E317A6E914740D57B2AA73D974A40861E317A6E9147406D0377A04E994A40573ECBF3E09447406D0377A04E994A40573ECBF3E0944740D57B2AA73D974A40861E317A6E914740D57B2AA73D974A40
47640	55837	47.047412000000001	47.060257999999997	53.154324000000003	53.147849000000001	Железнодорожная	0103000020E610000001000000050000000FB8AE981186474087DF4DB7EC924A400FB8AE9811864740747E8AE3C0934A4043A9BD88B6874740747E8AE3C0934A4043A9BD88B687474087DF4DB7EC924A400FB8AE981186474087DF4DB7EC924A40
47519	6259	47.046666999999999	47.068261999999997	53.175341000000003	53.160252999999997	Путиловка	0103000020E61000000100000005000000B6662B2FF9854740FE0A992B83944A40B6662B2FF9854740F052EA9271964A409FC728CFBC884740F052EA9271964A409FC728CFBC884740FE0A992B83944A40B6662B2FF9854740FE0A992B83944A40
47163	55764	47.181781999999998	47.237279999999998	53.141140999999998	53.119492000000001	площадь Ленина	0103000020E610000001000000050000003080F0A1449747401B118C834B8F4A403080F0A144974740F78F85E810924A4058FFE7305F9E4740F78F85E810924A4058FFE7305F9E47401B118C834B8F4A403080F0A1449747401B118C834B8F4A40
47644	55764	47.181781999999998	47.237279999999998	53.141140999999998	53.119492000000001	Узкоколейная	0103000020E610000001000000050000003080F0A1449747401B118C834B8F4A403080F0A144974740F78F85E810924A4058FFE7305F9E4740F78F85E810924A4058FFE7305F9E47401B118C834B8F4A403080F0A1449747401B118C834B8F4A40
47133	55764	47.181781999999998	47.237279999999998	53.141140999999998	53.119492000000001	Советская	0103000020E610000001000000050000003080F0A1449747401B118C834B8F4A403080F0A144974740F78F85E810924A4058FFE7305F9E4740F78F85E810924A4058FFE7305F9E47401B118C834B8F4A403080F0A1449747401B118C834B8F4A40
47029	55764	47.181781999999998	47.237279999999998	53.141140999999998	53.119492000000001	Комсомольская	0103000020E610000001000000050000003080F0A1449747401B118C834B8F4A403080F0A144974740F78F85E810924A4058FFE7305F9E4740F78F85E810924A4058FFE7305F9E47401B118C834B8F4A403080F0A1449747401B118C834B8F4A40
47321	55764	47.181781999999998	47.237279999999998	53.141140999999998	53.119492000000001	Коммунальная	0103000020E610000001000000050000003080F0A1449747401B118C834B8F4A403080F0A144974740F78F85E810924A4058FFE7305F9E4740F78F85E810924A4058FFE7305F9E47401B118C834B8F4A403080F0A1449747401B118C834B8F4A40
47647	55764	47.181781999999998	47.237279999999998	53.141140999999998	53.119492000000001	Гагарина	0103000020E610000001000000050000003080F0A1449747401B118C834B8F4A403080F0A144974740F78F85E810924A4058FFE7305F9E4740F78F85E810924A4058FFE7305F9E47401B118C834B8F4A403080F0A1449747401B118C834B8F4A40
47521	6819	47.434227	47.447341999999999	53.090725999999997	53.074553000000002	Старая	0103000020E61000000100000005000000250516C094B74740CB68E4F38A894A40250516C094B74740CD72D9E89C8B4A404910AE8042B94740CD72D9E89C8B4A404910AE8042B94740CB68E4F38A894A40250516C094B74740CB68E4F38A894A40
47468	6181	46.957276	46.979114000000003	53.133881000000002	53.126527000000003	Школьная	0103000020E61000000100000005000000739F1C05887A4740CF87670932904A40739F1C05887A474024473A0323914A402387889B537D474024473A0323914A402387889B537D4740CF87670932904A40739F1C05887A4740CF87670932904A40
47317	6101	47.388745	47.426996000000003	53.148724000000001	53.137965000000001	Центральная	0103000020E61000000100000005000000E4BD6A65C2B147400F7F4DD6A8914A40E4BD6A65C2B14740AE10566309934A40ECC20FCEA7B64740AE10566309934A40ECC20FCEA7B647400F7F4DD6A8914A40E4BD6A65C2B147400F7F4DD6A8914A40
47509	5713	47.285601	47.320967000000003	53.296143999999998	53.286428000000001	Центральная	0103000020E610000001000000050000003A5AD5928EA44740505436ACA9A44A403A5AD5928EA447400C74ED0BE8A54A40310C587215A947400C74ED0BE8A54A40310C587215A94740505436ACA9A44A403A5AD5928EA44740505436ACA9A44A40
47424	15626	47.184325000000001	47.205579	53.290390000000002	53.281377999999997	Советская	0103000020E61000000100000005000000E86A2BF6979747402DE8BD3104A44A40E86A2BF697974740F08AE07F2BA54A4048DFA469509A4740F08AE07F2BA54A4048DFA469509A47402DE8BD3104A44A40E86A2BF6979747402DE8BD3104A44A40
47510	5789	47.450792	47.478397000000001	53.350487999999999	53.311878	Центральная	0103000020E6100000010000000500000033A6608DB3B94740C32B499EEBA74A4033A6608DB3B94740FAD170CADCAC4A4094C0E61C3CBD4740FAD170CADCAC4A4094C0E61C3CBD4740C32B499EEBA74A4033A6608DB3B94740C32B499EEBA74A40
47639	6052	47.477786000000002	47.556100999999998	53.183976000000001	53.146552999999997	Центральная	0103000020E610000001000000050000004B3E761728BD4740BA10AB3FC2924A404B3E761728BD4740DC9F8B868C974A40EE224C512EC74740DC9F8B868C974A40EE224C512EC74740BA10AB3FC2924A404B3E761728BD4740BA10AB3FC2924A40
46881	6052	47.477786000000002	47.556100999999998	53.183976000000001	53.146552999999997	Лесная	0103000020E610000001000000050000004B3E761728BD4740BA10AB3FC2924A404B3E761728BD4740DC9F8B868C974A40EE224C512EC74740DC9F8B868C974A40EE224C512EC74740BA10AB3FC2924A404B3E761728BD4740BA10AB3FC2924A40
47512	5864	47.012881	47.040036999999998	53.095624999999998	53.081384999999997	Нижняя	0103000020E61000000100000005000000B1DEA815A681474046B1DCD26A8A4A40B1DEA815A68147400AD7A3703D8C4A40A2D0B2EE1F8547400AD7A3703D8C4A40A2D0B2EE1F85474046B1DCD26A8A4A40B1DEA815A681474046B1DCD26A8A4A40
47337	5390	47.149433999999999	47.174703999999998	53.078637000000001	53.057761999999997	Новая	0103000020E610000001000000050000008A743FA720934740CC79C6BE64874A408A743FA720934740B6A0F7C6108A4A407D3D5FB35C964740B6A0F7C6108A4A407D3D5FB35C964740CC79C6BE64874A408A743FA720934740CC79C6BE64874A40
47581	5532	47.097583	47.124012	53.074012000000003	53.054726000000002	Школьная	0103000020E61000000100000005000000A2D288997D8C4740D61EF64201874A40A2D288997D8C47407BC1A73979894A40E1270EA0DF8F47407BC1A73979894A40E1270EA0DF8F4740D61EF64201874A40A2D288997D8C4740D61EF64201874A40
47511	5707	47.346497999999997	47.372297000000003	53.288311999999998	53.272860000000001	Почтовая	0103000020E610000001000000050000009010E50B5AAC47407B319413EDA24A409010E50B5AAC4740AD855968E7A44A4010B3976DA7AF4740AD855968E7A44A4010B3976DA7AF47407B319413EDA24A409010E50B5AAC47407B319413EDA24A40
46885	6180	46.995049999999999	47.03904	53.156937999999997	53.139012999999998	Советская	0103000020E6100000010000000500000041F163CC5D7F4740035C902DCB914A4041F163CC5D7F4740F4BF5C8B16944A40309E4143FF844740F4BF5C8B16944A40309E4143FF844740035C902DCB914A4041F163CC5D7F4740035C902DCB914A40
47614	5466	47.098823000000003	47.124389000000001	53.029794000000003	53.015928000000002	Центральная	0103000020E61000000100000005000000DB8B683BA68C47409C8BBFED09824A40DB8B683BA68C4740FBCE2F4AD0834A40B77D8FFAEB8F4740FBCE2F4AD0834A40B77D8FFAEB8F47409C8BBFED09824A40DB8B683BA68C47409C8BBFED09824A40
47419	55805	46.980280999999998	46.998041000000001	53.029415	53.012146000000001	Приозерная	0103000020E61000000100000005000000F1F109D9797D47407C6308008E814A40F1F109D9797D47408481E7DEC3834A409888B7CEBF7F47408481E7DEC3834A409888B7CEBF7F47407C6308008E814A40F1F109D9797D47407C6308008E814A40
47335	5362	47.144646000000002	47.180489000000001	53.030807000000003	53.008533	Советская	0103000020E61000000100000005000000A5BF97C283924740E8F7FD9B17814A40A5BF97C28392474073BED87BF1834A40D52478431A97474073BED87BF1834A40D52478431A974740E8F7FD9B17814A40A5BF97C283924740E8F7FD9B17814A40
47347	6387	46.977488000000001	47.011766999999999	53.247219999999999	53.224249999999998	Средняя	0103000020E61000000100000005000000C11DA8531E7D474062105839B49C4A40C11DA8531E7D47406475ABE7A49F4A400516C094818147406475ABE7A49F4A400516C0948181474062105839B49C4A40C11DA8531E7D474062105839B49C4A40
47580	6708	47.064436000000001	47.09337	52.973576000000001	52.957977	Центральная	0103000020E61000000100000005000000B05758703F884740FCA886FD9E7A4A40B05758703F884740D3156C239E7C4A40B936548CF38B4740D3156C239E7C4A40B936548CF38B4740FCA886FD9E7A4A40B05758703F884740FCA886FD9E7A4A40
47573	2697	49.873449000000001	49.891488000000003	54.106973000000004	54.099054000000002	Школьная	0103000020E61000000100000005000000A9DC442DCDEF4840DD442DCDAD0C4B40A9DC442DCDEF48400B47904AB10D4B4063635E471CF248400B47904AB10D4B4063635E471CF24840DD442DCDAD0C4B40A9DC442DCDEF4840DD442DCDAD0C4B40
47405	4192	49.196523999999997	49.233400000000003	53.888319000000003	53.871552000000001	Дзержинского	0103000020E610000001000000050000008670CCB227994840B76114048FEF4A408670CCB2279948402DB5DE6FB4F14A4076711B0DE09D48402DB5DE6FB4F14A4076711B0DE09D4840B76114048FEF4A408670CCB227994840B76114048FEF4A40
47636	55834	49.733778999999998	49.763855	54.186179000000003	54.167918999999998	Лесная	0103000020E61000000100000005000000ECBE6378ECDD484042B0AA5E7E154B40ECBE6378ECDD4840DB19A6B6D4174B406BF12900C6E14840DB19A6B6D4174B406BF12900C6E1484042B0AA5E7E154B40ECBE6378ECDD484042B0AA5E7E154B40
47275	3770	49.746687999999999	49.780402000000002	54.01511	53.987732999999999	Куйбышева	0103000020E610000001000000050000006728EE7893DF48400917F2086EFE4A406728EE7893DF4840D9EBDD1FEF014B40D3DD7536E4E34840D9EBDD1FEF014B40D3DD7536E4E348400917F2086EFE4A406728EE7893DF48400917F2086EFE4A40
47469	3609	49.631811999999996	49.651566000000003	53.913179	53.901662999999999	Труда	0103000020E61000000100000005000000349C3237DFD04840B28174B169F34A40349C3237DFD048406E32AA0CE3F44A40C097C28366D348406E32AA0CE3F44A40C097C28366D34840B28174B169F34A40349C3237DFD04840B28174B169F34A40
47508	4955	49.586239999999997	49.613055000000003	54.510302000000003	54.487839999999998	Набережная	0103000020E61000000100000005000000B3CD8DE909CB48401FD7868A713E4B40B3CD8DE909CB4840AD8A709351414B401CD3139678CE4840AD8A709351414B401CD3139678CE48401FD7868A713E4B40B3CD8DE909CB48401FD7868A713E4B40
41930	4622	49.619549999999997	49.666361000000002	54.408408000000001	54.369140999999999	площадь Советов	0103000020E610000001000000050000004F1E166A4DCF48406E4E2503402F4B404F1E166A4DCF48405FB69DB646344B40392A37514BD548405FB69DB646344B40392A37514BD548406E4E2503402F4B404F1E166A4DCF48406E4E2503402F4B40
47515	4862	49.751871000000001	49.764285999999998	54.395699	54.376047999999997	Центральная	0103000020E61000000100000005000000C9E7154F3DE04840F4DC425722304B40C9E7154F3DE04840AB07CC43A6324B403465A71FD4E14840AB07CC43A6324B403465A71FD4E14840F4DC425722304B40C9E7154F3DE04840F4DC425722304B40
47398	3116	49.500765000000001	49.525730000000003	54.064599000000001	54.045386999999998	Набережная	0103000020E61000000100000005000000A0FD481119C04840EF54C03DCF054B40A0FD481119C048405A2DB0C744084B405743E21E4BC348405A2DB0C744084B405743E21E4BC34840EF54C03DCF054B40A0FD481119C04840EF54C03DCF054B40
47506	49157	49.893732999999997	49.915579999999999	54.377679000000001	54.372571000000001	Новая	0103000020E61000000100000005000000902DCBD765F2484011381268B02F4B40902DCBD765F2484068B114C957304B40936FB6B931F5484068B114C957304B40936FB6B931F5484011381268B02F4B40902DCBD765F2484011381268B02F4B40
47291	4233	49.928750000000001	49.961682000000003	54.430180999999997	54.412531999999999	Комсомольская	0103000020E610000001000000050000007B14AE47E1F64840D8463CD9CD344B407B14AE47E1F64840272EC72B10374B407193516518FB4840272EC72B10374B407193516518FB4840D8463CD9CD344B407B14AE47E1F64840D8463CD9CD344B40
47635	55833	49.637937999999998	49.668686999999998	54.361666	54.346952999999999	Центральная	0103000020E610000001000000050000001570CFF3A7D14840E21FB6F4682C4B401570CFF3A7D148409E094D124B2E4B4053211E8997D548409E094D124B2E4B4053211E8997D54840E21FB6F4682C4B401570CFF3A7D14840E21FB6F4682C4B40
47316	2944	49.637569999999997	49.684992000000001	54.153151999999999	54.134650999999998	Мелиоративная	0103000020E610000001000000050000009274CDE49BD14840D5AF743E3C114B409274CDE49BD1484093A8177C9A134B40C5025FD1ADD7484093A8177C9A134B40C5025FD1ADD74840D5AF743E3C114B409274CDE49BD14840D5AF743E3C114B40
46946	2944	49.637569999999997	49.684992000000001	54.153151999999999	54.134650999999998	 Победы	0103000020E610000001000000050000009274CDE49BD14840D5AF743E3C114B409274CDE49BD1484093A8177C9A134B40C5025FD1ADD7484093A8177C9A134B40C5025FD1ADD74840D5AF743E3C114B409274CDE49BD14840D5AF743E3C114B40
46879	3871	49.391790999999998	49.424103000000002	53.994222999999998	53.969431999999998	Октябрьская	0103000020E61000000100000005000000FEEE1D3526B2484012D9075916FC4A40FEEE1D3526B248402BF702B342FF4A405891D10149B648402BF702B342FF4A405891D10149B6484012D9075916FC4A40FEEE1D3526B2484012D9075916FC4A40
47344	4782	49.519404999999999	49.553280999999998	54.318098999999997	54.294916999999998	Школьная	0103000020E610000001000000050000007F30F0DC7BC2484068041BD7BF254B407F30F0DC7BC24840F5F1D077B7284B40C43F6CE9D1C64840F5F1D077B7284B40C43F6CE9D1C6484068041BD7BF254B407F30F0DC7BC2484068041BD7BF254B40
47463	3559	49.902814999999997	49.922775999999999	53.875039000000001	53.861856000000003	Майская	0103000020E610000001000000050000004BAB21718FF3484042EE224C51EE4A404BAB21718FF34840BEDC274701F04A4050C422861DF64840BEDC274701F04A4050C422861DF6484042EE224C51EE4A404BAB21718FF3484042EE224C51EE4A40
47404	2886	49.446111999999999	49.467016000000001	54.062258	54.049678999999998	Мира	0103000020E61000000100000005000000342DB1321AB948402426A8E15B064B40342DB1321AB948400AF5F411F8074B40B85A272EC7BB48400AF5F411F8074B40B85A272EC7BB48402426A8E15B064B40342DB1321AB948402426A8E15B064B40
46878	3403	49.726529999999997	49.797874	53.915686999999998	53.888567999999999	Крупской	0103000020E610000001000000050000000CC85EEFFEDC4840D522A298BCF14A400CC85EEFFEDC4840A92F4B3B35F54A40132A38BC20E64840A92F4B3B35F54A40132A38BC20E64840D522A298BCF14A400CC85EEFFEDC4840D522A298BCF14A40
47578	3807	50.007182	50.023800999999999	54.466402000000002	54.454396000000003	Черемшанская	0103000020E61000000100000005000000588FFB56EB00494074B7EBA5293A4B40588FFB56EB004940FE648C0FB33B4B40594E42E90B034940FE648C0FB33B4B40594E42E90B03494074B7EBA5293A4B40588FFB56EB00494074B7EBA5293A4B40
46944	2422	49.712542999999997	49.790140000000001	54.164208000000002	54.133997000000001	Шутова	0103000020E6100000010000000500000032FFE89B34DB48408D614ED026114B4032FFE89B34DB4840ECDE8AC404154B4077A1B94E23E54840ECDE8AC404154B4077A1B94E23E548408D614ED026114B4032FFE89B34DB48408D614ED026114B40
46993	2422	49.712542999999997	49.790140000000001	54.164208000000002	54.133997000000001	Новая	0103000020E6100000010000000500000032FFE89B34DB48408D614ED026114B4032FFE89B34DB4840ECDE8AC404154B4077A1B94E23E54840ECDE8AC404154B4077A1B94E23E548408D614ED026114B4032FFE89B34DB48408D614ED026114B40
46877	3241	49.153019	49.209702	54.068984999999998	54.039005000000003	Ленина	0103000020E610000001000000050000005455682096934840B4B0A71DFE044B40545568209693484010751F80D4084B40F1F3DF83D79A484010751F80D4084B40F1F3DF83D79A4840B4B0A71DFE044B405455682096934840B4B0A71DFE044B40
46942	2193	49.362496999999998	49.421723	54.243850999999999	54.166601	Советская	0103000020E61000000100000005000000F5F23B4D66AE48408E3D7B2E53154B40F5F23B4D66AE4840670C7382361F4B404A7CEE04FBB54840670C7382361F4B404A7CEE04FBB548408E3D7B2E53154B40F5F23B4D66AE48408E3D7B2E53154B40
46941	2193	49.362496999999998	49.421723	54.243850999999999	54.166601	Победы	0103000020E61000000100000005000000F5F23B4D66AE48408E3D7B2E53154B40F5F23B4D66AE4840670C7382361F4B404A7CEE04FBB54840670C7382361F4B404A7CEE04FBB548408E3D7B2E53154B40F5F23B4D66AE48408E3D7B2E53154B40
47049	2193	49.362496999999998	49.421723	54.243850999999999	54.166601	Красноармейская	0103000020E61000000100000005000000F5F23B4D66AE48408E3D7B2E53154B40F5F23B4D66AE4840670C7382361F4B404A7CEE04FBB54840670C7382361F4B404A7CEE04FBB548408E3D7B2E53154B40F5F23B4D66AE48408E3D7B2E53154B40
47608	3714	49.685009999999998	49.716137000000003	53.988197999999997	53.968167000000001	Клубная	0103000020E610000001000000050000006BB75D68AED74840810871E5ECFB4A406BB75D68AED748407EFCA5457DFE4A40503A9160AADB48407EFCA5457DFE4A40503A9160AADB4840810871E5ECFB4A406BB75D68AED74840810871E5ECFB4A40
47604	3672	49.736465000000003	49.770997000000001	54.059283000000001	54.034166999999997	Школьная	0103000020E6100000010000000500000007D3307C44DE48401CCD91955F044B4007D3307C44DE4840B91AD99596074B4035289A07B0E24840B91AD99596074B4035289A07B0E248401CCD91955F044B4007D3307C44DE48401CCD91955F044B40
9681	2373	49.158265	49.17615	54.268245999999998	54.253335999999997	Дорожная	0103000020E61000000100000005000000FC8C0B0742944840217365506D204B40FC8C0B074294484033A48AE255224B405F984C158C96484033A48AE255224B405F984C158C964840217365506D204B40FC8C0B0742944840217365506D204B40
47292	4752	49.640669000000003	49.694333999999998	54.542048999999999	54.512931000000002	Мираксовой	0103000020E61000000100000005000000D047197101D24840630D17B9A7414B40D047197101D248402DEA93DC61454B401C40BFEFDFD848402DEA93DC61454B401C40BFEFDFD84840630D17B9A7414B40D047197101D24840630D17B9A7414B40
47575	4691	49.648763000000002	49.675595999999999	54.468929000000003	54.461900999999997	Набережная	0103000020E610000001000000050000006CED7DAA0AD34840AE7E6C921F3B4B406CED7DAA0AD34840B0928FDD053C4B407AA702EE79D64840B0928FDD053C4B407AA702EE79D64840AE7E6C921F3B4B406CED7DAA0AD34840AE7E6C921F3B4B40
47290	2759	49.589770000000001	49.628138	54.138041999999999	54.107854000000003	Березовая	0103000020E61000000100000005000000BA1457957DCB4840145FED28CE0D4B40BA1457957DCB4840BABC395CAB114B40FBAF73D366D04840BABC395CAB114B40FBAF73D366D04840145FED28CE0D4B40BA1457957DCB4840145FED28CE0D4B40
47574	3181	49.458652000000001	49.476618999999999	54.036388000000002	54.023277	Центральная	0103000020E610000001000000050000005C1FD61BB5BA4840DFDFA0BDFA024B405C1FD61BB5BA4840C2FBAA5CA8044B407CD3F4D901BD4840C2FBAA5CA8044B407CD3F4D901BD4840DFDFA0BDFA024B405C1FD61BB5BA4840DFDFA0BDFA024B40
47451	3501	49.913784	49.940634000000003	53.997674000000004	53.979235000000003	Центральная	0103000020E61000000100000005000000D5CDC5DFF6F448409E0C8E9257FD4A40D5CDC5DFF6F44840E60819C8B3FF4A40BAC0E5B166F84840E60819C8B3FF4A40BAC0E5B166F848409E0C8E9257FD4A40D5CDC5DFF6F448409E0C8E9257FD4A40
47504	3353	49.143037999999997	49.174551000000001	54.161302999999997	54.143358999999997	Гагарина	0103000020E61000000100000005000000E90AB6114F9248402B4B749659124B40E90AB6114F92484093DFA293A5144B40F73DEAAF5796484093DFA293A5144B40F73DEAAF579648402B4B749659124B40E90AB6114F9248402B4B749659124B40
47400	3295	49.284863999999999	49.328028000000003	54.131062999999997	54.10201	Молодежная	0103000020E6100000010000000500000064E76D6C76A44840B7EEE6A90E0D4B4064E76D6C76A448409A5B21ACC6104B400E164ED2FCA948409A5B21ACC6104B400E164ED2FCA94840B7EEE6A90E0D4B4064E76D6C76A44840B7EEE6A90E0D4B40
47464	4140	49.436221000000003	49.453245000000003	53.870113000000003	53.861485000000002	Школьная	0103000020E610000001000000050000000A6AF816D6B748404E7FF62345EE4A400A6AF816D6B748408869DFDC5FEF4A40AB09A2EE03BA48408869DFDC5FEF4A40AB09A2EE03BA48404E7FF62345EE4A400A6AF816D6B748404E7FF62345EE4A40
47276	3912	49.471345999999997	49.506433999999999	53.951155999999997	53.931573	Советская	0103000020E61000000100000005000000DA8CD31055BC4840166BB8C83DF74A40DA8CD31055BC484074B2D47ABFF94A408ECA4DD4D2C0484074B2D47ABFF94A408ECA4DD4D2C04840166BB8C83DF74A40DA8CD31055BC4840166BB8C83DF74A40
47505	4041	49.540210000000002	49.560305999999997	53.916651999999999	53.906776999999998	Центральная	0103000020E61000000100000005000000707CED9925C54840EBE1CB4411F44A40707CED9925C5484010E84CDA54F54A4054E0641BB8C7484010E84CDA54F54A4054E0641BB8C74840EBE1CB4411F44A40707CED9925C54840EBE1CB4411F44A40
47399	3461	49.843966999999999	49.869909999999997	53.960486000000003	53.944648999999998	Центральная	0103000020E610000001000000050000009DF3531C07EC48407C992842EAF84A409DF3531C07EC484008228B34F1FA4A404F3BFC3559EF484008228B34F1FA4A404F3BFC3559EF48407C992842EAF84A409DF3531C07EC48407C992842EAF84A40
47503	2590	49.772379999999998	49.801270000000002	54.117776999999997	54.093721000000002	 Луговая	0103000020E61000000100000005000000D00A0C59DDE2484066F9BA0CFF0B4B40D00A0C59DDE24840499C1551130F4B400AA2EE0390E64840499C1551130F4B400AA2EE0390E6484066F9BA0CFF0B4B40D00A0C59DDE2484066F9BA0CFF0B4B40
47576	4385	49.744047000000002	49.804558	54.314380999999997	54.296014999999997	Советская	0103000020E61000000100000005000000EDD79DEE3CDF48400E10CCD1E3254B40EDD79DEE3CDF4840ECBDF8A23D284B401ADEACC1FBE64840ECBDF8A23D284B401ADEACC1FBE648400E10CCD1E3254B40EDD79DEE3CDF48400E10CCD1E3254B40
47406	4356	49.928229000000002	49.962473000000003	54.498173000000001	54.486046000000002	Советская	0103000020E6100000010000000500000072193735D0F64840022D5DC1363E4B4072193735D0F6484007600322C43F4B403A24B55032FB484007600322C43F4B403A24B55032FB4840022D5DC1363E4B4072193735D0F64840022D5DC1363E4B40
47513	4029	49.2288	49.257537999999997	53.928953999999997	53.910674999999998	Гагарина	0103000020E6100000010000000500000093A98251499D4840742497FF90F44A4093A98251499D484083BEF4F6E7F64A4016BD5301F7A0484083BEF4F6E7F64A4016BD5301F7A04840742497FF90F44A4093A98251499D4840742497FF90F44A40
47507	4303	49.903193000000002	49.927286000000002	54.533357000000002	54.518816000000001	Комсомольская	0103000020E61000000100000005000000F27C06D49BF348401E520C9068424B40F27C06D49BF34840DD0BCC0A45444B40F304C24EB1F64840DD0BCC0A45444B40F304C24EB1F648401E520C9068424B40F27C06D49BF348401E520C9068424B40
47453	2828	49.553882999999999	49.587983000000001	54.059103	54.040142000000003	Школьная	0103000020E61000000100000005000000BA675DA3E5C648401899805F23054B40BA675DA3E5C64840390CE6AF90074B404FCDE50643CB4840390CE6AF90074B404FCDE50643CB48401899805F23054B40BA675DA3E5C648401899805F23054B40
47342	3952	49.381962999999999	49.415722000000002	53.936725000000003	53.910404999999997	Советская	0103000020E610000001000000050000001AA4E029E4B04840B48EAA2688F44A401AA4E029E4B048403D2CD49AE6F74A40261DE56036B548403D2CD49AE6F74A40261DE56036B54840B48EAA2688F44A401AA4E029E4B04840B48EAA2688F44A40
47075	479	47.578308	47.644334000000001	54.128445999999997	54.098621000000001	Советская	0103000020E61000000100000005000000F1811DFF05CA474073D9E89C9F0C4B40F1811DFF05CA4740A8A624EB70104B40B6D9588979D24740A8A624EB70104B40B6D9588979D2474073D9E89C9F0C4B40F1811DFF05CA474073D9E89C9F0C4B40
46859	479	47.578308	47.644334000000001	54.128445999999997	54.098621000000001	Первомайская	0103000020E61000000100000005000000F1811DFF05CA474073D9E89C9F0C4B40F1811DFF05CA4740A8A624EB70104B40B6D9588979D24740A8A624EB70104B40B6D9588979D2474073D9E89C9F0C4B40F1811DFF05CA474073D9E89C9F0C4B40
47315	479	47.578308	47.644334000000001	54.128445999999997	54.098621000000001	Павлика Морозова	0103000020E61000000100000005000000F1811DFF05CA474073D9E89C9F0C4B40F1811DFF05CA4740A8A624EB70104B40B6D9588979D24740A8A624EB70104B40B6D9588979D2474073D9E89C9F0C4B40F1811DFF05CA474073D9E89C9F0C4B40
46976	479	47.578308	47.644334000000001	54.128445999999997	54.098621000000001	1-я Комсомольская	0103000020E61000000100000005000000F1811DFF05CA474073D9E89C9F0C4B40F1811DFF05CA4740A8A624EB70104B40B6D9588979D24740A8A624EB70104B40B6D9588979D2474073D9E89C9F0C4B40F1811DFF05CA474073D9E89C9F0C4B40
46876	58	47.627876999999998	47.68121	53.961291000000003	53.938547999999997	2 Советская	0103000020E610000001000000050000008E7406465ED04740F4DC425722F84A408E7406465ED0474036785F950BFB4A40A5DAA7E331D7474036785F950BFB4A40A5DAA7E331D74740F4DC425722F84A408E7406465ED04740F4DC425722F84A40
47386	55798	46.430692000000001	47.509695000000001	54.445	54.005898000000002	Фабричная	0103000020E610000001000000050000000D535BEA20374740508E0244C1004B400D535BEA20374740295C8FC2F5384B40A5F78DAF3DC14740295C8FC2F5384B40A5F78DAF3DC14740508E0244C1004B400D535BEA20374740508E0244C1004B40
47366	29881	47.363726999999997	47.412253999999997	54.306784999999998	54.281461999999998	Октябрьская	0103000020E610000001000000050000000AD6389B8EAE47408B8862F206244B400AD6389B8EAE4740A1F31ABB44274B4095D233BDC4B44740A1F31ABB44274B4095D233BDC4B447408B8862F206244B400AD6389B8EAE47408B8862F206244B40
46875	29881	47.363726999999997	47.412253999999997	54.306784999999998	54.281461999999998	Клубная	0103000020E610000001000000050000000AD6389B8EAE47408B8862F206244B400AD6389B8EAE4740A1F31ABB44274B4095D233BDC4B44740A1F31ABB44274B4095D233BDC4B447408B8862F206244B400AD6389B8EAE47408B8862F206244B40
47450	55809	46.430692000000001	47.509695000000001	54.445	54.005898000000002	Комарова	0103000020E610000001000000050000000D535BEA20374740508E0244C1004B400D535BEA20374740295C8FC2F5384B40A5F78DAF3DC14740295C8FC2F5384B40A5F78DAF3DC14740508E0244C1004B400D535BEA20374740508E0244C1004B40
47022	29479	46.960042000000001	47.019734999999997	54.221995	54.161867000000001	Ульянова	0103000020E61000000100000005000000AA6400A8E27A47409CA6CF0EB8144B40AA6400A8E27A4740117008556A1C4B4014CB2DAD86824740117008556A1C4B4014CB2DAD868247409CA6CF0EB8144B40AA6400A8E27A47409CA6CF0EB8144B40
47000	29479	46.960042000000001	47.019734999999997	54.221995	54.161867000000001	Советская	0103000020E61000000100000005000000AA6400A8E27A47409CA6CF0EB8144B40AA6400A8E27A4740117008556A1C4B4014CB2DAD86824740117008556A1C4B4014CB2DAD868247409CA6CF0EB8144B40AA6400A8E27A47409CA6CF0EB8144B40
47027	29479	46.960042000000001	47.019734999999997	54.221995	54.161867000000001	Мира	0103000020E61000000100000005000000AA6400A8E27A47409CA6CF0EB8144B40AA6400A8E27A4740117008556A1C4B4014CB2DAD86824740117008556A1C4B4014CB2DAD868247409CA6CF0EB8144B40AA6400A8E27A47409CA6CF0EB8144B40
47566	55821	46.459007	46.459814999999999	53.905619999999999	53.905375999999997	Лесная	0103000020E610000001000000050000004AD1CABDC03A4740A94A5B5CE3F34A404AD1CABDC03A4740404D2D5BEBF34A40E99AC937DB3A4740404D2D5BEBF34A40E99AC937DB3A4740A94A5B5CE3F34A404AD1CABDC03A4740A94A5B5CE3F34A40
47650	55844	45.796517000000001	46.802791999999997	54.272447	53.580795999999999	Центральная	0103000020E61000000100000005000000A1DAE044F4E54640E5D2F88557CA4A40A1DAE044F4E546405872158BDF224B40C6BE64E3C16647405872158BDF224B40C6BE64E3C1664740E5D2F88557CA4A40A1DAE044F4E54640E5D2F88557CA4A40
47571	29456	46.430117000000003	46.453158999999999	53.753245999999997	53.739412000000002	Шоссейная	0103000020E61000000100000005000000113AE8120E3747408E226B0DA5DE4A40113AE8120E374740E1EB6B5D6AE04A40AC71361D013A4740E1EB6B5D6AE04A40AC71361D013A47408E226B0DA5DE4A40113AE8120E3747408E226B0DA5DE4A40
47367	29146	46.376289999999997	46.410452999999997	53.916159	53.899270000000001	пер. Советский	0103000020E61000000100000005000000EAE74D452A304740102384471BF34A40EAE74D452A304740D177B7B244F54A40C5C551B989344740D177B7B244F54A40C5C551B989344740102384471BF34A40EAE74D452A304740102384471BF34A40
47438	28420	46.097408000000001	46.137635000000003	54.149861999999999	54.133848999999998	Центральная	0103000020E61000000100000005000000342F87DD770C474018CDCAF621114B40342F87DD770C4740E27492AD2E134B407AE40F069E114740E27492AD2E134B407AE40F069E11474018CDCAF621114B40342F87DD770C474018CDCAF621114B40
47570	29387	46.368716999999997	46.391517	53.790889999999997	53.780665999999997	Советская	0103000020E61000000100000005000000573D601E322F4740B08C0DDDECE34A40573D601E322F4740E15D2EE23BE54A40FD69A33A1D324740E15D2EE23BE54A40FD69A33A1D324740B08C0DDDECE34A40573D601E322F4740B08C0DDDECE34A40
47567	28329	46.121150999999998	46.155025999999999	54.125244000000002	54.094163999999999	Школьный переулок	0103000020E6100000010000000500000058703FE0810F4740F33AE2900D0C4B4058703FE0810F47409702D2FE07104B40CD0358E4D71347409702D2FE07104B40CD0358E4D7134740F33AE2900D0C4B4058703FE0810F4740F33AE2900D0C4B40
47572	29362	46.443170000000002	46.457721999999997	53.738335999999997	53.717326	пер. Школьный	0103000020E61000000100000005000000BF4868CBB938474006499F56D1DB4A40BF4868CBB9384740CFBA46CB81DE4A4071546EA2963A4740CFBA46CB81DE4A4071546EA2963A474006499F56D1DB4A40BF4868CBB938474006499F56D1DB4A40
47555	28320	45.897371	45.932208000000003	54.025055000000002	54.009771000000001	Советская	0103000020E610000001000000050000007DB08C0DDDF2464080B9162D40014B407DB08C0DDDF24640F7CC920035034B40E8887C9752F74640F7CC920035034B40E8887C9752F7464080B9162D40014B407DB08C0DDDF2464080B9162D40014B40
47363	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	переулок Рузаевской	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
46869	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Энгельса	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
46870	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Школьная	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
47358	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Фрунзе	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
46934	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Терешковой	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
46873	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Революции	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
47271	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Пугачева	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
47074	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Парковая	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
46871	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Мира	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
46935	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Ломоносова	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
47309	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Дорожная	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
46938	27225	46.318322000000002	46.411755999999997	53.876604999999998	53.830595000000002	Алашеева	0103000020E6100000010000000500000075CC79C6BE2847404E9CDCEF50EA4A4075CC79C6BE2847404A41B79734F04A4044F7AC6BB43447404A41B79734F04A4044F7AC6BB43447404E9CDCEF50EA4A4075CC79C6BE2847404E9CDCEF50EA4A40
47273	27934	46.675671999999999	46.719580999999998	53.966206999999997	53.944490000000002	Советская	0103000020E6100000010000000500000055698B6B7C56474014B35E0CE5F84A4055698B6B7C5647404815C5ABACFB4A4057E9EE3A1B5C47404815C5ABACFB4A4057E9EE3A1B5C474014B35E0CE5F84A4055698B6B7C56474014B35E0CE5F84A40
47272	27934	46.675671999999999	46.719580999999998	53.966206999999997	53.944490000000002	Садовая	0103000020E6100000010000000500000055698B6B7C56474014B35E0CE5F84A4055698B6B7C5647404815C5ABACFB4A4057E9EE3A1B5C47404815C5ABACFB4A4057E9EE3A1B5C474014B35E0CE5F84A4055698B6B7C56474014B35E0CE5F84A40
47556	28231	46.187015000000002	46.226064999999998	54.071542000000001	54.051397000000001	Большая	0103000020E61000000100000005000000446E861BF0174740670E492D94064B40446E861BF01747402D25CB4928094B4097E2AAB2EF1C47402D25CB4928094B4097E2AAB2EF1C4740670E492D94064B40446E861BF0174740670E492D94064B40
47569	29323	46.403095999999998	46.421304999999997	53.772965999999997	53.756270000000001	Центральная	0103000020E61000000100000005000000FF9254A69833474014799274CDE04A40FF9254A698334740C075C58CF0E24A4015527E52ED354740C075C58CF0E24A4015527E52ED35474014799274CDE04A40FF9254A69833474014799274CDE04A40
47558	28166	46.219813000000002	46.242702000000001	54.160259000000003	54.144598999999999	Центральная	0103000020E610000001000000050000002A1E17D5221C47406404543882124B402A1E17D5221C4740E1F1ED5D83144B403F56F0DB101F4740E1F1ED5D83144B403F56F0DB101F47406404543882124B402A1E17D5221C47406404543882124B40
47442	29260	46.455629000000002	46.478023999999998	53.678527000000003	53.664866000000004	Ленина	0103000020E61000000100000005000000FA0D130D523A4740761C3F541AD54A40FA0D130D523A4740FC3905F9D9D64A40FF59F3E32F3D4740FC3905F9D9D64A40FF59F3E32F3D4740761C3F541AD54A40FA0D130D523A4740761C3F541AD54A40
47557	29226	46.540304999999996	46.569284000000003	53.638651000000003	53.617618	Молодежная	0103000020E61000000100000005000000C16ED8B628454740E1B54B1B0ECF4A40C16ED8B6284547406347E350BFD14A406B11514CDE4847406347E350BFD14A406B11514CDE484740E1B54B1B0ECF4A40C16ED8B628454740E1B54B1B0ECF4A40
47565	28150	46.074744000000003	46.124403000000001	54.070802	54.052523000000001	Центральная	0103000020E610000001000000050000003FC91D3691094740D7A4DB12B9064B403FC91D3691094740E63E390A10094B401C430070EC0F4740E63E390A10094B401C430070EC0F4740D7A4DB12B9064B403FC91D3691094740D7A4DB12B9064B40
47311	26878	46.826625	46.864092999999997	53.975009	53.955452999999999	Заводская	0103000020E610000001000000050000002B8716D9CE694740BBEEAD484CFA4A402B8716D9CE69474020274C18CDFC4A40ECD973999A6E474020274C18CDFC4A40ECD973999A6E4740BBEEAD484CFA4A402B8716D9CE694740BBEEAD484CFA4A40
47564	26878	46.826625	46.864092999999997	53.975009	53.955452999999999	 Школьная	0103000020E610000001000000050000002B8716D9CE694740BBEEAD484CFA4A402B8716D9CE69474020274C18CDFC4A40ECD973999A6E474020274C18CDFC4A40ECD973999A6E4740BBEEAD484CFA4A402B8716D9CE694740BBEEAD484CFA4A40
46933	26432	47.298977000000001	47.359748000000003	54.104492	54.085555999999997	Заводская	0103000020E61000000100000005000000CBA0DAE044A6474000FDBE7FF30A4B40CBA0DAE044A64740C9586DFE5F0D4B409566F3380CAE4740C9586DFE5F0D4B409566F3380CAE474000FDBE7FF30A4B40CBA0DAE044A6474000FDBE7FF30A4B40
47434	26373	47.15795	47.186993000000001	54.119239	54.103731000000003	Ленина	0103000020E610000001000000050000009C33A2B4379447406B4AB20E470D4B409C33A2B43794474031B43A39430F4B405CCAF962EF97474031B43A39430F4B405CCAF962EF9747406B4AB20E470D4B409C33A2B4379447406B4AB20E470D4B40
47385	55797	47.388188	47.407088999999999	53.968595999999998	53.949916000000002	Центральный Массив	0103000020E610000001000000050000008E59F624B0B147403CF9F4D896F94A408E59F624B0B14740A98427F4FAFB4A40DAC70A7E1BB44740A98427F4FAFB4A40DAC70A7E1BB447403CF9F4D896F94A408E59F624B0B147403CF9F4D896F94A40
47440	26666	46.846657	46.879643000000002	54.140912	54.108910000000002	Центральная	0103000020E61000000100000005000000F9F6AE415F6C47408B1A4CC3F00D4B40F9F6AE415F6C474096CE876709124B40E2934E249870474096CE876709124B40E2934E24987047408B1A4CC3F00D4B40F9F6AE415F6C47408B1A4CC3F00D4B40
47441	27063	47.149487999999998	47.168056	53.902729000000001	53.888165000000001	Клубная	0103000020E610000001000000050000007D923B6C22934740D6390664AFF14A407D923B6C229347404D13B69F8CF34A40C3F2E7DB829547404D13B69F8CF34A40C3F2E7DB82954740D6390664AFF14A407D923B6C22934740D6390664AFF14A40
47568	55822	46.933065999999997	46.968747	53.944071000000001	53.928852999999997	Верхняя	0103000020E610000001000000050000003881E9B46E7747404FE5B4A7E4F64A403881E9B46E7747400F0D8B51D7F84A408F8CD5E6FF7B47400F0D8B51D7F84A408F8CD5E6FF7B47404FE5B4A7E4F64A403881E9B46E7747404FE5B4A7E4F64A40
47277	55783	47.221029999999999	47.267940000000003	54.016283999999999	53.980707000000002	Репинского	0103000020E61000000100000005000000AAB706B64A9C4740A9FA95CE87FD4A40AAB706B64A9C47405AB9179815024B4027A5A0DB4BA247405AB9179815024B4027A5A0DB4BA24740A9FA95CE87FD4A40AAB706B64A9C4740A9FA95CE87FD4A40
47554	26985	46.978054	47.005721999999999	53.881068999999997	53.867432000000001	Центральная	0103000020E610000001000000050000006ADC9BDF307D47407FC0030308EF4A406ADC9BDF307D47407C4276DEC6F04A40116F9D7FBB8047407C4276DEC6F04A40116F9D7FBB8047407FC0030308EF4A406ADC9BDF307D47407FC0030308EF4A40
47314	26951	47.053485000000002	47.1265	53.934201999999999	53.911152999999999	Егоровка	0103000020E61000000100000005000000CDE9B298D88647407E5358A9A0F44A40CDE9B298D8864740CCED5EEE93F74A40D578E92631904740CCED5EEE93F74A40D578E926319047407E5358A9A0F44A40CDE9B298D88647407E5358A9A0F44A40
47553	26788	46.839551	46.862189000000001	54.056095999999997	54.035330000000002	Советская	0103000020E610000001000000050000007C293C68766B4740AA4885B185044B407C293C68766B4740DCB75A272E074B4048FC8A355C6E4740DCB75A272E074B4048FC8A355C6E4740AA4885B185044B407C293C68766B4740AA4885B185044B40
47634	55831	46.682993000000003	47.488197999999997	54.219299999999997	53.805594999999997	Советская	0103000020E61000000100000005000000CF328B506C5747401A69A9BC1DE74A40CF328B506C574740A301BC05121C4B407EFCA5457DBE4740A301BC05121C4B407EFCA5457DBE47401A69A9BC1DE74A40CF328B506C5747401A69A9BC1DE74A40
47355	26718	46.861846999999997	46.878646000000003	54.022579	53.991311000000003	Центральная	0103000020E61000000100000005000000EE93A300516E474021956247E3FE4A40EE93A300516E4740C74961DEE3024B407061DD7877704740C74961DEE3024B407061DD787770474021956247E3FE4A40EE93A300516E474021956247E3FE4A40
47307	26223	47.001759999999997	47.043917999999998	54.089374999999997	54.035907000000002	Школьная	0103000020E610000001000000050000007138F3AB398047404759BF9998044B407138F3AB398047403D0AD7A3700B4B4055DAE21A9F8547403D0AD7A3700B4B4055DAE21A9F8547404759BF9998044B407138F3AB398047404759BF9998044B40
47069	26046	47.101903999999998	47.142885	54.065407999999998	54.034500000000001	Труда	0103000020E6100000010000000500000071AAB5300B8D474023DBF97E6A044B4071AAB5300B8D4740C972124A5F084B40630B410E4A924740C972124A5F084B40630B410E4A92474023DBF97E6A044B4071AAB5300B8D474023DBF97E6A044B40
47071	26046	47.101903999999998	47.142885	54.065407999999998	54.034500000000001	Лесхозная	0103000020E6100000010000000500000071AAB5300B8D474023DBF97E6A044B4071AAB5300B8D4740C972124A5F084B40630B410E4A924740C972124A5F084B40630B410E4A92474023DBF97E6A044B4071AAB5300B8D474023DBF97E6A044B40
47018	26046	47.101903999999998	47.142885	54.065407999999998	54.034500000000001	Комсомольская	0103000020E6100000010000000500000071AAB5300B8D474023DBF97E6A044B4071AAB5300B8D4740C972124A5F084B40630B410E4A924740C972124A5F084B40630B410E4A92474023DBF97E6A044B4071AAB5300B8D474023DBF97E6A044B40
46872	26046	47.101903999999998	47.142885	54.065407999999998	54.034500000000001	 Комсомольская	0103000020E6100000010000000500000071AAB5300B8D474023DBF97E6A044B4071AAB5300B8D4740C972124A5F084B40630B410E4A924740C972124A5F084B40630B410E4A92474023DBF97E6A044B4071AAB5300B8D474023DBF97E6A044B40
47458	26537	47.310187999999997	47.333444999999998	54.060429999999997	54.035483999999997	Калинина	0103000020E610000001000000050000004ACE893DB4A7474000C45DBD8A044B404ACE893DB4A7474040D9942BBC074B40E2016553AEAA474040D9942BBC074B40E2016553AEAA474000C45DBD8A044B404ACE893DB4A7474000C45DBD8A044B40
47437	26215	47.121515000000002	47.148051000000002	54.159236999999997	54.143416999999999	Волынцева	0103000020E610000001000000050000009A7CB3CD8D8F47406058FE7C5B124B409A7CB3CD8D8F474015A8C5E061144B40EF91CD55F392474015A8C5E061144B40EF91CD55F39247406058FE7C5B124B409A7CB3CD8D8F47406058FE7C5B124B40
47460	27190	47.387208999999999	47.432152000000002	53.871090000000002	53.847687000000001	Школьная	0103000020E61000000100000005000000C2DB831090B14740471FF30181EC4A40C2DB831090B14740B3EF8AE07FEF4A405473B9C150B74740B3EF8AE07FEF4A405473B9C150B74740471FF30181EC4A40C2DB831090B14740471FF30181EC4A40
47313	26630	46.856259999999999	46.887351000000002	54.112161	54.062882000000002	Центральная	0103000020E61000000100000005000000BD6F7CED996D4740E8C072840C084B40BD6F7CED996D47407E71A94A5B0E4B405589B2B7947147407E71A94A5B0E4B405589B2B794714740E8C072840C084B40BD6F7CED996D4740E8C072840C084B40
47439	27069	47.009521999999997	47.03454	53.944156	53.932839999999999	Клубная	0103000020E61000000100000005000000D74B5304388147404833164D67F74A40D74B5304388147403D29931ADAF84A40B13385CE6B8447403D29931ADAF84A40B13385CE6B8447404833164D67F74A40D74B5304388147404833164D67F74A40
47267	24410	46.972538	46.988779000000001	53.576059000000001	53.553928999999997	Молодежная	0103000020E61000000100000005000000020F0C207C7C47402AA73D25E7C64A40020F0C207C7C474082C8224DBCC94A405DFC6D4F907E474082C8224DBCC94A405DFC6D4F907E47402AA73D25E7C64A40020F0C207C7C47402AA73D25E7C64A40
47014	24410	46.972538	46.988779000000001	53.576059000000001	53.553928999999997	Ленина	0103000020E61000000100000005000000020F0C207C7C47402AA73D25E7C64A40020F0C207C7C474082C8224DBCC94A405DFC6D4F907E474082C8224DBCC94A405DFC6D4F907E47402AA73D25E7C64A40020F0C207C7C47402AA73D25E7C64A40
47270	25811	47.014777000000002	47.045031999999999	53.702365999999998	53.683822999999997	Шоссейная	0103000020E61000000100000005000000D3DD7536E481474055A0168387D74A40D3DD7536E481474042E90B21E7D94A4001A3CB9BC385474042E90B21E7D94A4001A3CB9BC385474055A0168387D74A40D3DD7536E481474055A0168387D74A40
47559	24791	46.930829000000003	46.946505000000002	53.394767000000002	53.380938	Старая	0103000020E610000001000000050000008E95986725774740DEE68D93C2B04A408E9598672577474020459DB987B24A4010406A132779474020459DB987B24A4010406A1327794740DEE68D93C2B04A408E95986725774740DEE68D93C2B04A40
47021	24859	47.510449000000001	47.558599000000001	53.731881000000001	53.709983000000001	Советская	0103000020E6100000010000000500000051A3906456C14740A5DB12B9E0DA4A4051A3906456C147402AC8CF46AEDD4A40064A0A2C80C747402AC8CF46AEDD4A40064A0A2C80C74740A5DB12B9E0DA4A4051A3906456C14740A5DB12B9E0DA4A40
46937	24859	47.510449000000001	47.558599000000001	53.731881000000001	53.709983000000001	Пролетарская	0103000020E6100000010000000500000051A3906456C14740A5DB12B9E0DA4A4051A3906456C147402AC8CF46AEDD4A40064A0A2C80C747402AC8CF46AEDD4A40064A0A2C80C74740A5DB12B9E0DA4A4051A3906456C14740A5DB12B9E0DA4A40
47474	25774	46.976157999999998	47.004356000000001	53.761555999999999	53.749215999999997	Центральная	0103000020E6100000010000000500000048DDCEBEF27C4740E9D1544FE6DF4A4048DDCEBEF27C47404A09C1AA7AE14A404CC5C6BC8E8047404A09C1AA7AE14A404CC5C6BC8E804740E9D1544FE6DF4A4048DDCEBEF27C4740E9D1544FE6DF4A40
47454	25028	47.662452999999999	47.675452	53.723996999999997	53.712141000000003	Нижняя	0103000020E610000001000000050000008C118942CBD447400492B06F27DB4A408C118942CBD4474078B306EFABDC4A4047020D3675D6474078B306EFABDC4A4047020D3675D647400492B06F27DB4A408C118942CBD447400492B06F27DB4A40
81080	62068	46.689900999999999	47.720799	53.886699999999998	53.320597999999997	Школьная	0103000020E61000000100000005000000253D0CAD4E584740DD94F25A09A94A40253D0CAD4E5847407DAEB6627FF14A40A8FE412443DC47407DAEB6627FF14A40A8FE412443DC4740DD94F25A09A94A40253D0CAD4E584740DD94F25A09A94A40
47435	24776	47.087657	47.102398000000001	53.402734000000002	53.386228000000003	Центральная	0103000020E61000000100000005000000FB213658388B474056664AEB6FB14A40FB213658388B47405F7EA7C98CB34A408196AE601B8D47405F7EA7C98CB34A408196AE601B8D474056664AEB6FB14A40FB213658388B474056664AEB6FB14A40
47262	24710	46.973131000000002	47.004123	53.541935000000002	53.515605999999998	Чкалова	0103000020E61000000100000005000000A5DC7D8E8F7C474089CF9D60FFC14A40A5DC7D8E8F7C474065C746205EC54A40A9143B1A8780474065C746205EC54A40A9143B1A8780474089CF9D60FFC14A40A5DC7D8E8F7C474089CF9D60FFC14A40
47318	25856	47.348455999999999	47.381065	53.620587	53.605513000000002	Школьная	0103000020E61000000100000005000000280CCA349AAC4740C426327381CD4A40280CCA349AAC474050A912656FCF4A403B53E8BCC6B0474050A912656FCF4A403B53E8BCC6B04740C426327381CD4A40280CCA349AAC4740C426327381CD4A40
47550	24101	46.754669	46.781196999999999	53.599555000000002	53.587654000000001	Молодежная	0103000020E610000001000000050000000B2769FE986047408AAE0B3F38CB4A400B2769FE986047409F93DE37BECC4A40DD5D6743FE6347409F93DE37BECC4A40DD5D6743FE6347408AAE0B3F38CB4A400B2769FE986047408AAE0B3F38CB4A40
47552	25282	47.282007999999998	47.301572999999998	53.496316	53.474379999999996	Молодёжная	0103000020E61000000100000005000000ED9A90D618A4474030F0DC7BB8BC4A40ED9A90D618A44740A33D5E4887BF4A40A52DAEF199A64740A33D5E4887BF4A40A52DAEF199A6474030F0DC7BB8BC4A40ED9A90D618A4474030F0DC7BB8BC4A40
47514	25740	47.139535000000002	47.171748000000001	53.815165	53.802453	 Молодежная	0103000020E61000000100000005000000DDD26A48DC914740DEC9A7C7B6E64A40DDD26A48DC91474003ECA35357E84A40A393A5D6FB95474003ECA35357E84A40A393A5D6FB954740DEC9A7C7B6E64A40DDD26A48DC914740DEC9A7C7B6E64A40
47452	24347	47.204591000000001	47.2273	53.669145	53.661248999999998	Центральная	0103000020E610000001000000050000002907B309309A4740A0C1A6CEA3D44A402907B309309A474016A4198BA6D54A40BE30992A189D474016A4198BA6D54A40BE30992A189D4740A0C1A6CEA3D44A402907B309309A4740A0C1A6CEA3D44A40
47641	55838	\N	\N	\N	\N	Центральная	\N
47436	24662	47.039687000000001	47.077506	53.395851	53.380557000000003	Центральная	0103000020E61000000100000005000000C689AF7614854740C7A17E17B6B04A40C689AF7614854740618BDD3EABB24A40349F73B7EB894740618BDD3EABB24A40349F73B7EB894740C7A17E17B6B04A40C689AF7614854740C7A17E17B6B04A40
47269	25578	47.059252000000001	47.096308000000001	53.766489999999997	53.746915000000001	Новоселов	0103000020E610000001000000050000007E1CCD919587474028F224E99ADF4A407E1CCD9195874740035B25581CE24A40ED2B0FD2538C4740035B25581CE24A40ED2B0FD2538C474028F224E99ADF4A407E1CCD919587474028F224E99ADF4A40
47384	24306	47.309559	47.327497999999999	53.818998000000001	53.810938999999998	переулок Центральный	0103000020E610000001000000050000005B971AA19FA74740850662D9CCE74A405B971AA19FA74740A5BE2CEDD4E84A40B1C05774EBA94740A5BE2CEDD4E84A40B1C05774EBA94740850662D9CCE74A405B971AA19FA74740850662D9CCE74A40
47461	25216	47.227128999999998	47.246129000000003	53.497810000000001	53.485391999999997	Молодежная	0103000020E61000000100000005000000917C2590129D4740B9DE365321BE4A40917C2590129D474096CFF23CB8BF4A4071CCB227819F474096CFF23CB8BF4A4071CCB227819F4740B9DE365321BE4A40917C2590129D4740B9DE365321BE4A40
47562	24622	46.774379000000003	46.796315	53.439915999999997	53.422845000000002	Центральная	0103000020E61000000100000005000000C7DADFD91E6347407923F3C81FB64A40C7DADFD91E6347405A7EE02A4FB84A40392861A6ED6547405A7EE02A4FB84A40392861A6ED6547407923F3C81FB64A40C7DADFD91E6347407923F3C81FB64A40
47563	25485	47.000062	47.026975999999998	53.609059999999999	53.601041000000002	Школьная	0103000020E6100000010000000500000076FC1708028047400F4757E9EECC4A4076FC170802804740A0A696ADF5CD4A4071E316F373834740A0A696ADF5CD4A4071E316F3738347400F4757E9EECC4A4076FC1708028047400F4757E9EECC4A40
47560	25441	47.169547000000001	47.191664000000003	53.573086000000004	53.557299	Седова	0103000020E61000000100000005000000451152B7B3954740F88BD99255C74A40451152B7B3954740D2E5CDE15AC94A4008E9297288984740D2E5CDE15AC94A4008E9297288984740F88BD99255C74A40451152B7B3954740F88BD99255C74A40
47561	25177	47.190998999999998	47.216610000000003	53.456755000000001	53.437196	Новая	0103000020E61000000100000005000000CB48BDA77298474094F8DC09F6B74A40CB48BDA7729847406AA4A5F276BA4A4048FE60E0B99B47406AA4A5F276BA4A4048FE60E0B99B474094F8DC09F6B74A40CB48BDA77298474094F8DC09F6B74A40
47455	25148	47.077111000000002	47.104267	53.523235	53.509785000000001	Центральная	0103000020E61000000100000005000000B894F3C5DE894740E57E87A240C14A40B894F3C5DE894740B08F4E5DF9C24A40A986FD9E588D4740B08F4E5DF9C24A40A986FD9E588D4740E57E87A240C14A40B894F3C5DE894740E57E87A240C14A40
46865	24959	47.485619999999997	47.514131999999996	53.791550000000001	53.776100999999997	Советская	0103000020E610000001000000050000004A24D1CB28BE47404AB20E4757E34A404A24D1CB28BE47400C93A98251E54A40DDE9CE13CFC147400C93A98251E54A40DDE9CE13CFC147404AB20E4757E34A404A24D1CB28BE47404AB20E4757E34A40
46855	24182	47.224254999999999	47.259379000000003	53.734219000000003	53.708368	Школьная	0103000020E61000000100000005000000747B4963B49C474037C478CDABDA4A40747B4963B49C4740098D60E3FADD4A407522C15433A14740098D60E3FADD4A407522C15433A1474037C478CDABDA4A40747B4963B49C474037C478CDABDA4A40
46856	24182	47.224254999999999	47.259379000000003	53.734219000000003	53.708368	Советская	0103000020E61000000100000005000000747B4963B49C474037C478CDABDA4A40747B4963B49C4740098D60E3FADD4A407522C15433A14740098D60E3FADD4A407522C15433A1474037C478CDABDA4A40747B4963B49C474037C478CDABDA4A40
47457	25373	47.064749999999997	47.092140000000001	53.651333999999999	53.635662000000004	Плодопитомническая	0103000020E610000001000000050000003F355EBA49884740ADA7565F5DD14A403F355EBA49884740ED629AE95ED34A40A453573ECB8B4740ED629AE95ED34A40A453573ECB8B4740ADA7565F5DD14A403F355EBA49884740ADA7565F5DD14A40
47266	24946	47.573447999999999	47.605553999999998	53.733266	53.717996999999997	 Зеленая	0103000020E6100000010000000500000072FA7ABE66C9474024D06053E7DB4A4072FA7ABE66C9474066A208A9DBDD4A4022FB20CB82CD474066A208A9DBDD4A4022FB20CB82CD474024D06053E7DB4A4072FA7ABE66C9474024D06053E7DB4A40
47456	25114	47.226599	47.273311999999997	53.428972999999999	53.408563999999998	Парковая	0103000020E6100000010000000500000035272F32019D474056293DD34BB44A4035272F32019D4740FAEE5696E8B64A405BCD3AE3FBA24740FAEE5696E8B64A405BCD3AE3FBA2474056293DD34BB44A4035272F32019D474056293DD34BB44A40
47255	25050	47.110599999999998	47.149731000000003	53.488168000000002	53.474493000000002	Школьная	0103000020E6100000010000000500000003780B24288E47402997C62FBCBC4A4003780B24288E4740147AFD497CBE4A404419AA622A934740147AFD497CBE4A404419AA622A9347402997C62FBCBC4A4003780B24288E47402997C62FBCBC4A40
47279	23957	46.926724	46.972673	53.580950999999999	53.567568000000001	Гая	0103000020E610000001000000050000008B355CE49E764740C9207711A6C84A408B355CE49E7647400CCA349A5CCA4A40E259828C807C47400CCA349A5CCA4A40E259828C807C4740C9207711A6C84A408B355CE49E764740C9207711A6C84A40
47265	23957	46.926724	46.972673	53.580950999999999	53.567568000000001	Гагарина	0103000020E610000001000000050000008B355CE49E764740C9207711A6C84A408B355CE49E7647400CCA349A5CCA4A40E259828C807C47400CCA349A5CCA4A40E259828C807C4740C9207711A6C84A408B355CE49E764740C9207711A6C84A40
47432	24546	46.848804000000001	46.875456999999997	53.487535000000001	53.468522	Молодёжная	0103000020E61000000100000005000000645B069CA56C47406FBA6587F8BB4A40645B069CA56C4740E353008C67BE4A40F20698F90E704740E353008C67BE4A40F20698F90E7047406FBA6587F8BB4A40645B069CA56C47406FBA6587F8BB4A40
47551	24512	46.919195999999999	46.952109999999998	53.525199000000001	53.506214	Советская	0103000020E61000000100000005000000984EEB36A87547408063CF9ECBC04A40984EEB36A87547402A7288B839C34A40E71890BDDE7947402A7288B839C34A40E71890BDDE7947408063CF9ECBC04A40984EEB36A87547408063CF9ECBC04A40
47596	25980	47.295454999999997	47.316054000000001	53.640951999999999	53.628379000000002	Школьная	0103000020E6100000010000000500000047382D78D1A54740213F1BB96ED04A4047382D78D1A54740242713B70AD24A408FE21C7574A84740242713B70AD24A408FE21C7574A84740213F1BB96ED04A4047382D78D1A54740213F1BB96ED04A40
47549	25674	47.154761000000001	47.176023999999998	53.859243999999997	53.834446999999997	Горная	0103000020E610000001000000050000001FD95C35CF934740669FC728CFEA4A401FD95C35CF93474061A417B5FBED4A40D2A755F48796474061A417B5FBED4A40D2A755F487964740669FC728CFEA4A401FD95C35CF934740669FC728CFEA4A40
47459	25637	46.983550999999999	47.015729	53.720267	53.712743000000003	Больничный переулок	0103000020E610000001000000050000005B79C9FFE47D4740FAB9A1293BDB4A405B79C9FFE47D4740ABB184B531DC4A40A54C6A6803824740ABB184B531DC4A40A54C6A6803824740FAB9A1293BDB4A405B79C9FFE47D4740FAB9A1293BDB4A40
47346	25915	47.412101999999997	47.451106000000003	53.685710999999998	53.661430000000003	Колхозная	0103000020E61000000100000005000000DF4E22C2BFB44740F14BFDBCA9D44A40DF4E22C2BFB44740F4C0C760C5D74A40C38366D7BDB94740F4C0C760C5D74A40C38366D7BDB94740F14BFDBCA9D44A40DF4E22C2BFB44740F14BFDBCA9D44A40
47067	22393	46.735346999999997	46.794438	53.774355	53.733575000000002	Советская	0103000020E61000000100000005000000191BBAD91F5E4740E4141DC9E5DD4A40191BBAD91F5E47403E3F8C101EE34A408E59F624B06547403E3F8C101EE34A408E59F624B0654740E4141DC9E5DD4A40191BBAD91F5E4740E4141DC9E5DD4A40
46857	22393	46.735346999999997	46.794438	53.774355	53.733575000000002	Рабочая	0103000020E61000000100000005000000191BBAD91F5E4740E4141DC9E5DD4A40191BBAD91F5E47403E3F8C101EE34A408E59F624B06547403E3F8C101EE34A408E59F624B0654740E4141DC9E5DD4A40191BBAD91F5E4740E4141DC9E5DD4A40
47427	22393	46.735346999999997	46.794438	53.774355	53.733575000000002	Дорожная	0103000020E61000000100000005000000191BBAD91F5E4740E4141DC9E5DD4A40191BBAD91F5E47403E3F8C101EE34A408E59F624B06547403E3F8C101EE34A408E59F624B0654740E4141DC9E5DD4A40191BBAD91F5E4740E4141DC9E5DD4A40
47008	22393	46.735346999999997	46.794438	53.774355	53.733575000000002	Авдеева	0103000020E61000000100000005000000191BBAD91F5E4740E4141DC9E5DD4A40191BBAD91F5E47403E3F8C101EE34A408E59F624B06547403E3F8C101EE34A408E59F624B0654740E4141DC9E5DD4A40191BBAD91F5E4740E4141DC9E5DD4A40
31079	1193	45.966963999999997	45.972155999999998	51.614688000000001	51.586340999999997	проспект Строителей	0103000020E610000001000000050000006534F279C5FB4640E7A6CD380DCB49406534F279C5FB4640309FAC18AECE49401A4E999B6FFC4640309FAC18AECE49401A4E999B6FFC4640E7A6CD380DCB49406534F279C5FB4640E7A6CD380DCB4940
30763	1193	45.959023000000002	45.967996999999997	51.600867000000001	51.595675	проспект Ломоносова	0103000020E61000000100000005000000508E0244C1FA4640BC0512143FCC4940508E0244C1FA4640711FB935E9CC494024D06053E7FB4640711FB935E9CC494024D06053E7FB4640BC0512143FCC4940508E0244C1FA4640BC0512143FCC4940
31291	1193	46.122821000000002	46.125714000000002	51.501806999999999	51.494909999999997	площадь Свободы	0103000020E610000001000000050000008A213999B80F47404F3BFC3559BF49408A213999B80F4740B2F336363BC049401E53776517104740B2F336363BC049401E537765171047404F3BFC3559BF49408A213999B80F47404F3BFC3559BF4940
30730	1193	46.152833999999999	46.165447	51.480172000000003	51.478735999999998	Энгельс-1	0103000020E61000000100000005000000C2DB8310901347407CB5A33847BD4940C2DB8310901347403B3AAE4676BD4940541C075E2D1547403B3AAE4676BD4940541C075E2D1547407CB5A33847BD4940C2DB8310901347407CB5A33847BD4940
30463	1193	45.939089000000003	45.94032	51.590203000000002	51.588188000000002	Щорса	0103000020E6100000010000000500000045847F1134F8464028F38FBE49CB494045847F1134F8464024809BC58BCB49402AE3DF675CF8464024809BC58BCB49402AE3DF675CF8464028F38FBE49CB494045847F1134F8464028F38FBE49CB4940
31526	1193	46.114710000000002	46.121465000000001	51.501638999999997	51.497275999999999	Халтурина	0103000020E61000000100000005000000184339D1AE0E4740F88A6EBDA6BF4940184339D1AE0E4740F6B2EDB435C04940E84D452A8C0F4740F6B2EDB435C04940E84D452A8C0F4740F88A6EBDA6BF4940184339D1AE0E4740F88A6EBDA6BF4940
31499	1193	45.903857000000002	45.906264999999998	51.588724999999997	51.586447999999997	Тургенева	0103000020E610000001000000050000005EA10F96B1F34640FD6662BA10CB49405EA10F96B1F3464036AB3E575BCB49403541D47D00F4464036AB3E575BCB49403541D47D00F44640FD6662BA10CB49405EA10F96B1F34640FD6662BA10CB4940
30961	1193	46.093231000000003	46.098064000000001	51.490732000000001	51.482084	Транспортная	0103000020E6100000010000000500000098FC4FFEEE0B474062F6B2EDB4BD494098FC4FFEEE0B4740E38C614ED0BE49401D75745C8D0C4740E38C614ED0BE49401D75745C8D0C474062F6B2EDB4BD494098FC4FFEEE0B474062F6B2EDB4BD4940
30605	1193	46.114449	46.139933999999997	51.497225999999998	51.474595999999998	Тельмана	0103000020E61000000100000005000000AB07CC43A60E4740FD67CD8FBFBC4940AB07CC43A60E4740465C001AA5BF49409ACC785BE9114740465C001AA5BF49409ACC785BE9114740FD67CD8FBFBC4940AB07CC43A60E4740FD67CD8FBFBC4940
30966	1193	46.031382000000001	46.036394999999999	51.533579000000003	51.532414000000003	Театральная	0103000020E610000001000000050000006FD74B53040447405EF7562426C449406FD74B53040447408C6A11514CC44940745E6397A80447408C6A11514CC44940745E6397A80447405EF7562426C449406FD74B53040447405EF7562426C44940
31125	1193	46.154387999999997	46.210819999999998	51.509526000000001	51.496727	Студенческая	0103000020E610000001000000050000008A7269FCC2134740250516C094BF49408A7269FCC2134740193BE12538C14940DEAB5626FC1A4740193BE12538C14940DEAB5626FC1A4740250516C094BF49408A7269FCC2134740250516C094BF4940
31248	1193	46.129891000000001	46.136915999999999	51.481192	51.477440000000001	Строительная	0103000020E61000000100000005000000BA85AE44A0104740B0E600C11CBD4940BA85AE44A0104740658C0FB397BD49404A26A77686114740658C0FB397BD49404A26A77686114740B0E600C11CBD4940BA85AE44A0104740B0E600C11CBD4940
2427	1193	46.128131000000003	46.146222999999999	51.480794000000003	51.440283999999998	Строителей проспект	0103000020E61000000100000005000000494DBB9866104740DD79E2395BB84940494DBB9866104740780E65A88ABD494025766D6FB7124740780E65A88ABD494025766D6FB7124740DD79E2395BB84940494DBB9866104740DD79E2395BB84940
30404	1193	45.878461999999999	45.882261999999997	51.569220000000001	51.567137000000002	Санаторная	0103000020E61000000100000005000000AE635C7171F0464000ADF9F197C84940AE635C7171F04640541D7233DCC84940744012F6EDF04640541D7233DCC84940744012F6EDF0464000ADF9F197C84940AE635C7171F0464000ADF9F197C84940
31491	1193	46.022883999999998	46.028309999999998	51.529696000000001	51.528492	Пушкина	0103000020E6100000010000000500000003CDE7DCED0247404C1938A0A5C3494003CDE7DCED02474038691A14CDC349402B137EA99F03474038691A14CDC349402B137EA99F0347404C1938A0A5C3494003CDE7DCED0247404C1938A0A5C34940
30190	1193	46.114054000000003	46.155071	51.477659000000003	51.468598	Полтавская	0103000020E610000001000000050000002FFD4B52990E47404A7CEE04FBBB49402FFD4B52990E4740EED11BEE23BD49406DC7D45DD9134740EED11BEE23BD49406DC7D45DD91347404A7CEE04FBBB49402FFD4B52990E47404A7CEE04FBBB4940
31372	1193	46.126899999999999	46.154387999999997	51.496833000000002	51.484861000000002	Полиграфическая	0103000020E6100000010000000500000063EE5A423E1047408D0DDDEC0FBE494063EE5A423E1047406B49473998BF49408A7269FCC21347406B49473998BF49408A7269FCC21347408D0DDDEC0FBE494063EE5A423E1047408D0DDDEC0FBE4940
30794	1193	\N	\N	\N	\N	Новая	\N
30608	1193	46.136457999999998	46.155214999999998	51.470478	51.466326000000002	Менделеева	0103000020E6100000010000000500000087A3AB747711474023A30392B0BB494087A3AB747711474066BE839F38BC4940A06CCA15DE13474066BE839F38BC4940A06CCA15DE13474023A30392B0BB494087A3AB747711474023A30392B0BB4940
30347	1193	46.160550999999998	46.173954000000002	51.504857000000001	51.493077	Маршала Василевского	0103000020E61000000100000005000000882B67EF8C14474074B4AA251DBF4940882B67EF8C1447400E1478279FC049401381EA1F441647400E1478279FC049401381EA1F4416474074B4AA251DBF4940882B67EF8C14474074B4AA251DBF4940
31653	1193	45.919865000000001	45.925462000000003	51.493406999999998	51.491630000000001	Марины Расковой	0103000020E6100000010000000500000016DEE522BEF54640C2DD59BBEDBE494016DEE522BEF54640094FE8F527BF49406BD8EF8975F64640094FE8F527BF49406BD8EF8975F64640C2DD59BBEDBE494016DEE522BEF54640C2DD59BBEDBE4940
30464	1193	46.079954000000001	46.095522000000003	51.502282999999998	51.492021999999999	Лесозаводская	0103000020E610000001000000050000009A97C3EE3B0A4740CD74AF93FABE49409A97C3EE3B0A47401B2B31CF4AC0494036069D103A0C47401B2B31CF4AC0494036069D103A0C4740CD74AF93FABE49409A97C3EE3B0A4740CD74AF93FABE4940
30870	1193	42.501936999999998	50.833129	52.818674000000001	49.801195999999997	Курчатова	0103000020E6100000010000000500000080D3BB783F404540CFD72C978DE6484080D3BB783F404540F20A444FCA684A40B22C98F8A36A4940F20A444FCA684A40B22C98F8A36A4940CFD72C978DE6484080D3BB783F404540CFD72C978DE64840
30349	1193	46.110298999999998	46.113263000000003	51.458649999999999	51.4559	Крупской	0103000020E6100000010000000500000008E412471E0E47408A1F63EE5ABA494008E412471E0E4740BB270F0BB5BA4940666CE8667F0E4740BB270F0BB5BA4940666CE8667F0E47408A1F63EE5ABA494008E412471E0E47408A1F63EE5ABA4940
31335	1193	46.015841000000002	46.016936999999999	51.548205000000003	51.547364999999999	Колхозная	0103000020E61000000100000005000000CD77F01307024740CEFC6A0E10C64940CD77F013070247407940D9942BC64940D28BDAFD2A0247407940D9942BC64940D28BDAFD2A024740CEFC6A0E10C64940CD77F01307024740CEFC6A0E10C64940
31110	1193	46.148935000000002	46.171097000000003	51.496524999999998	51.479790000000001	Колотилова	0103000020E61000000100000005000000691D554D1013474053793BC269BD4940691D554D10134740BD5296218EBF4940CCB8A981E6154740BD5296218EBF4940CCB8A981E615474053793BC269BD4940691D554D1013474053793BC269BD4940
31303	1193	46.002411000000002	46.015230000000003	51.551099999999998	51.532839000000003	Железнодорожная	0103000020E610000001000000050000004913EF004F00474045847F1134C449404913EF004F004740AD69DE718AC6494084F57F0EF3014740AD69DE718AC6494084F57F0EF301474045847F1134C449404913EF004F00474045847F1134C44940
30673	1193	46.148378999999998	46.152493	51.432743000000002	51.431980000000003	Гагарина	0103000020E61000000100000005000000E3344415FE1247405743E21E4BB74940E3344415FE1247405649641F64B7494039EFFFE3841347405649641F64B7494039EFFFE3841347405743E21E4BB74940E3344415FE1247405743E21E4BB74940
31161	1193	45.970306000000001	45.973396000000001	51.589754999999997	51.58849	Воронежская	0103000020E61000000100000005000000698EACFC32FC4640F302ECA353CB4940698EACFC32FC464084D382177DCB49405307793D98FC464084D382177DCB49405307793D98FC4640F302ECA353CB4940698EACFC32FC4640F302ECA353CB4940
30621	1193	46.107396999999999	46.122785999999998	51.494860000000003	51.485461000000001	Волоха	0103000020E610000001000000050000002158552FBF0D4740E23D079623BE49402158552FBF0D47409E0C8E9257BF49400D349F73B70F47409E0C8E9257BF49400D349F73B70F4740E23D079623BE49402158552FBF0D4740E23D079623BE4940
31439	1193	42.501936999999998	50.833129	52.818674000000001	49.801195999999997	Большевистский переулок	0103000020E6100000010000000500000080D3BB783F404540CFD72C978DE6484080D3BB783F404540F20A444FCA684A40B22C98F8A36A4940F20A444FCA684A40B22C98F8A36A4940CFD72C978DE6484080D3BB783F404540CFD72C978DE64840
30758	1193	42.501936999999998	50.833129	52.818674000000001	49.801195999999997	Авиабаза Энгельс-2	0103000020E6100000010000000500000080D3BB783F404540CFD72C978DE6484080D3BB783F404540F20A444FCA684A40B22C98F8A36A4940F20A444FCA684A40B22C98F8A36A4940CFD72C978DE6484080D3BB783F404540CFD72C978DE64840
30919	1193	46.142547999999998	46.157209000000002	51.488680000000002	51.481019000000003	2-я Ленинградская	0103000020E610000001000000050000001B0E4B033F12474098E0D40792BD49401B0E4B033F124740CA1AF5108DBE494085D1AC6C1F144740CA1AF5108DBE494085D1AC6C1F14474098E0D40792BD49401B0E4B033F12474098E0D40792BD4940
30791	1193	46.113461000000001	46.123216999999997	51.470348999999999	51.465001999999998	1-й Микрорайон	0103000020E610000001000000050000008C2FDAE3850E47408C497F2F85BB49408C2FDAE3850E4740685A626534BC4940D6A71C93C50F4740685A626534BC4940D6A71C93C50F47408C497F2F85BB49408C2FDAE3850E47408C497F2F85BB4940
30860	11330	46.008502	46.032774000000003	51.533169999999998	51.526513999999999	Советская	0103000020E61000000100000005000000ADF9F197160147406D718DCF64C34940ADF9F19716014740AA9A20EA3EC449405E143DF031044740AA9A20EA3EC449405E143DF0310447406D718DCF64C34940ADF9F197160147406D718DCF64C34940
30308	1659	48.069713	48.116847999999997	52.519984999999998	52.465800999999999	Советская	0103000020E61000000100000005000000938D075BEC084840D8B8FE5D9F3B4A40938D075BEC0848408DB454DE8E424A402F4D11E0F40E48408DB454DE8E424A402F4D11E0F40E4840D8B8FE5D9F3B4A40938D075BEC084840D8B8FE5D9F3B4A40
31117	1659	48.069713	48.116847999999997	52.519984999999998	52.465800999999999	Росреспублики	0103000020E61000000100000005000000938D075BEC084840D8B8FE5D9F3B4A40938D075BEC0848408DB454DE8E424A402F4D11E0F40E48408DB454DE8E424A402F4D11E0F40E4840D8B8FE5D9F3B4A40938D075BEC084840D8B8FE5D9F3B4A40
30388	1659	48.069713	48.116847999999997	52.519984999999998	52.465800999999999	Верхняя Слободка	0103000020E61000000100000005000000938D075BEC084840D8B8FE5D9F3B4A40938D075BEC0848408DB454DE8E424A402F4D11E0F40E48408DB454DE8E424A402F4D11E0F40E4840D8B8FE5D9F3B4A40938D075BEC084840D8B8FE5D9F3B4A40
1233	29	45.972264000000003	45.996015	51.582563999999998	51.569432999999997	улица Шехурдина	0103000020E61000000100000005000000018A912573FC4640AF21382EE3C84940018A912573FC4640D9E9077591CA4940A8A9656B7DFF4640D9E9077591CA4940A8A9656B7DFF4640AF21382EE3C84940018A912573FC4640AF21382EE3C84940
1001	29	46.018301999999998	46.056696000000002	51.538615	51.528194999999997	улица Челюскинцев	0103000020E61000000100000005000000C7B94DB8570247409274CDE49BC34940C7B94DB85702474049111956F1C4494032E884D04107474049111956F1C4494032E884D0410747409274CDE49BC34940C7B94DB8570247409274CDE49BC34940
710	29	45.990527	45.995027	51.566046	51.564287999999998	улица Техническая	0103000020E610000001000000050000000A67B796C9FE46403BC3D4963AC849400A67B796C9FE46400C04013274C8494089D1730B5DFF46400C04013274C8494089D1730B5DFF46403BC3D4963AC849400A67B796C9FE46403BC3D4963AC84940
31366	29	45.975031000000001	45.976278999999998	51.564287999999998	51.561841000000001	улица Телеграфная	0103000020E6100000010000000500000008CBD8D0CDFC4640A646E867EAC7494008CBD8D0CDFC46403BC3D4963AC84940C362D4B5F6FC46403BC3D4963AC84940C362D4B5F6FC4640A646E867EAC7494008CBD8D0CDFC4640A646E867EAC74940
724	29	46.009031999999998	46.029899999999998	51.598863999999999	51.548043	улица Танкистов	0103000020E61000000100000005000000094FE8F5270147409FE6E44526C64940094FE8F52701474039605793A7CC4940401361C3D303474039605793A7CC4940401361C3D30347409FE6E44526C64940094FE8F5270147409FE6E44526C64940
30947	29	45.852401999999998	45.861969000000002	51.593553999999997	51.583458999999998	улица Строителей	0103000020E61000000100000005000000C2853C821BED464047C7D5C8AECA4940C2853C821BED46407A34D593F9CB49403A950C0055EE46407A34D593F9CB49403A950C0055EE464047C7D5C8AECA4940C2853C821BED464047C7D5C8AECA4940
30707	29	45.986241999999997	46.007666	51.547998	51.527527999999997	улица Степана Разина	0103000020E6100000010000000500000087F8872D3DFE4640B5DC990986C3494087F8872D3DFE4640FF2268CC24C6494044A51133FB004740FF2268CC24C6494044A51133FB004740B5DC990986C3494087F8872D3DFE4640B5DC990986C34940
30375	29	45.986241999999997	46.007666	51.547998	51.527527999999997	улица Степана Разина	0103000020E6100000010000000500000087F8872D3DFE4640B5DC990986C3494087F8872D3DFE4640FF2268CC24C6494044A51133FB004740FF2268CC24C6494044A51133FB004740B5DC990986C3494087F8872D3DFE4640B5DC990986C34940
1281	29	46.008502	46.032774000000003	51.533169999999998	51.526513999999999	улица Советская	0103000020E61000000100000005000000ADF9F197160147406D718DCF64C34940ADF9F19716014740AA9A20EA3EC449405E143DF031044740AA9A20EA3EC449405E143DF0310447406D718DCF64C34940ADF9F197160147406D718DCF64C34940
30980	29	45.991146000000001	46.006202000000002	51.541988000000003	51.532615	улица Слонова	0103000020E61000000100000005000000D6C743DFDDFE4640F52D73BA2CC44940D6C743DFDDFE46408869DFDC5FC54940BC95253ACB0047408869DFDC5FC54940BC95253ACB004740F52D73BA2CC44940D6C743DFDDFE4640F52D73BA2CC44940
377	29	45.939601000000003	45.947246	51.512335	51.510317000000001	улица Ростовская	0103000020E61000000100000005000000FB2477D844F84640E2CB441152C14940FB2477D844F846404FCC7A3194C1494027A25F5B3FF946404FCC7A3194C1494027A25F5B3FF94640E2CB441152C14940FB2477D844F84640E2CB441152C14940
7914	29	46.053094000000002	46.063200000000002	51.537742000000001	51.534284999999997	улица Рогожина	0103000020E6100000010000000500000092CEC0C8CB06474026DF6C7363C4494092CEC0C8CB064740C3D7D7BAD4C44940B98D06F016084740C3D7D7BAD4C44940B98D06F01608474026DF6C7363C4494092CEC0C8CB06474026DF6C7363C44940
2861	29	46.005439000000003	46.024447000000002	51.549005999999999	51.522384000000002	улица Рахова	0103000020E61000000100000005000000BD8FA339B200474012FA997ADDC24940BD8FA339B200474065A71FD445C649401FBE4C142103474065A71FD445C649401FBE4C142103474012FA997ADDC24940BD8FA339B200474012FA997ADDC24940
1923	29	45.985218000000003	45.987886000000003	51.615057	51.602404999999997	улица Перспективная	0103000020E610000001000000050000001CB7989F1BFE464033F9669B1BCD49401CB7989F1BFE464083161230BACE49409016670C73FE464083161230BACE49409016670C73FE464033F9669B1BCD49401CB7989F1BFE464033F9669B1BCD4940
31280	29	45.986601	45.987085999999998	51.592244999999998	51.587394000000003	улица Овражная	0103000020E61000000100000005000000B7990AF148FE4640EEEE01BA2FCB4940B7990AF148FE4640191C25AFCECB4940732B84D558FE4640191C25AFCECB4940732B84D558FE4640EEEE01BA2FCB4940B7990AF148FE4640EEEE01BA2FCB4940
517	29	45.991720999999998	46.055968999999997	51.544676000000003	51.526626	улица Московская	0103000020E61000000100000005000000D2E0B6B6F0FE4640959C137B68C34940D2E0B6B6F0FE4640437573F1B7C549407F4B00FE29074740437573F1B7C549407F4B00FE29074740959C137B68C34940D2E0B6B6F0FE4640959C137B68C34940
31100	29	46.106696999999997	46.115257999999997	51.591875999999999	51.581282000000002	улица Молодежная	0103000020E6100000010000000500000068CA4E3FA80D474072E0D57267CA494068CA4E3FA80D4740C6A4BF97C2CB49401A4D2EC6C00E4740C6A4BF97C2CB49401A4D2EC6C00E474072E0D57267CA494068CA4E3FA80D474072E0D57267CA4940
2215	29	46.008806999999997	46.065302000000003	51.535421999999997	51.524889000000002	улица Мичурина	0103000020E61000000100000005000000E97C789620014740DC8310902FC34940E97C7896200147408AC745B588C44940842EE1D05B0847408AC745B588C44940842EE1D05B084740DC8310902FC34940E97C789620014740DC8310902FC34940
1398	29	45.959885	45.968705999999997	51.581366000000003	51.580548999999998	улица Мира	0103000020E61000000100000005000000E275FD82DDFA4640DD5CFC6D4FCA4940E275FD82DDFA4640D0807A336ACA494030B8E68EFEFB4640D0807A336ACA494030B8E68EFEFB4640DD5CFC6D4FCA4940E275FD82DDFA4640DD5CFC6D4FCA4940
173	29	45.799590000000002	45.898575000000001	51.492767999999998	51.479419999999998	улица Маркина	0103000020E61000000100000005000000B51A12F758E646402F8672A25DBD4940B51A12F758E64640F641960513BF494069006F8104F34640F641960513BF494069006F8104F346402F8672A25DBD4940B51A12F758E646402F8672A25DBD4940
1567	29	45.915939000000002	45.917960999999998	51.592843999999999	51.588831999999996	улица Крылова	0103000020E61000000100000005000000C310397D3DF546404C6BD3D85ECB4940C310397D3DF546409ED0EB4FE2CB49407100FDBE7FF546409ED0EB4FE2CB49407100FDBE7FF546404C6BD3D85ECB4940C310397D3DF546404C6BD3D85ECB4940
2612	29	45.948017999999998	45.97945	51.533040999999997	51.524608000000001	улица Клочкова	0103000020E61000000100000005000000790261A758F94640289CDD5A26C34940790261A758F94640AC36FFAF3AC449409A081B9E5EFD4640AC36FFAF3AC449409A081B9E5EFD4640289CDD5A26C34940790261A758F94640289CDD5A26C34940
7959	29	46.054675000000003	46.060757000000002	51.568917999999996	51.567658000000002	улица Казанская	0103000020E6100000010000000500000054742497FF06474009A87004A9C8494054742497FF064740880D164ED2C849406500A8E2C6074740880D164ED2C849406500A8E2C607474009A87004A9C8494054742497FF06474009A87004A9C84940
606	29	46.028049000000003	46.038398000000001	51.549812000000003	51.547656000000003	улица Зеленая	0103000020E61000000100000005000000BFD7101C97034740A6BA809719C64940BFD7101C970347406479573D60C64940AC1DC539EA0447406479573D60C64940AC1DC539EA044740A6BA809719C64940BFD7101C97034740A6BA809719C64940
1168	29	46.000290999999997	46.035837999999998	51.539628999999998	51.531534000000001	улица Большая Казачья	0103000020E61000000100000005000000D7BD158909004740255B5D4E09C44940D7BD158909004740917C259012C549401EFAEE5696044740917C259012C549401EFAEE5696044740255B5D4E09C44940D7BD158909004740255B5D4E09C44940
2196	29	45.990625000000001	45.992736000000001	51.609732999999999	51.602198000000001	улица Бардина	0103000020E61000000100000005000000CDCCCCCCCCFE4640BADBF5D214CD4940CDCCCCCCCCFE46405F251FBB0BCE4940EBC726F911FF46405F251FBB0BCE4940EBC726F911FF4640BADBF5D214CD4940CDCCCCCCCCFE4640BADBF5D214CD4940
1126	29	45.990651999999997	46.016703	51.548127000000001	51.522871000000002	улица Астраханская	0103000020E61000000100000005000000C6DB4AAFCDFE46406F83DA6FEDC24940C6DB4AAFCDFE4640FD86890629C649405F5FEB5223024740FD86890629C649405F5FEB52230247406F83DA6FEDC24940C6DB4AAFCDFE46406F83DA6FEDC24940
31631	29	45.929971000000002	45.968482000000002	51.505640999999997	51.424854000000003	проспект Энтузиастов	0103000020E610000001000000050000003D9D2B4A09F7464093C9A99D61B649403D9D2B4A09F74640244223D8B8C04940E161DA37F7FB4640244223D8B8C04940E161DA37F7FB464093C9A99D61B649403D9D2B4A09F7464093C9A99D61B64940
30918	29	45.966963999999997	45.972155999999998	51.614688000000001	51.586340999999997	проспект Строителей	0103000020E610000001000000050000006534F279C5FB4640E7A6CD380DCB49406534F279C5FB4640309FAC18AECE49401A4E999B6FFC4640309FAC18AECE49401A4E999B6FFC4640E7A6CD380DCB49406534F279C5FB4640E7A6CD380DCB4940
30588	29	45.959023000000002	45.967996999999997	51.600867000000001	51.595675	проспект Ломоносова	0103000020E61000000100000005000000508E0244C1FA4640BC0512143FCC4940508E0244C1FA4640711FB935E9CC494024D06053E7FB4640711FB935E9CC494024D06053E7FB4640BC0512143FCC4940508E0244C1FA4640BC0512143FCC4940
30582	29	45.959023000000002	45.967996999999997	51.600867000000001	51.595675	проспект Ломоносова	0103000020E61000000100000005000000508E0244C1FA4640BC0512143FCC4940508E0244C1FA4640711FB935E9CC494024D06053E7FB4640711FB935E9CC494024D06053E7FB4640BC0512143FCC4940508E0244C1FA4640BC0512143FCC4940
30810	29	45.959023000000002	45.967996999999997	51.600867000000001	51.595675	проспект Ломоносова	0103000020E61000000100000005000000508E0244C1FA4640BC0512143FCC4940508E0244C1FA4640711FB935E9CC494024D06053E7FB4640711FB935E9CC494024D06053E7FB4640BC0512143FCC4940508E0244C1FA4640BC0512143FCC4940
31310	29	45.937885000000001	45.999859999999998	51.591757999999999	51.556348	проспект 50 лет Октября	0103000020E6100000010000000500000059349D9D0CF84640F698486936C7494059349D9D0CF84640BC92E4B9BECB49400E4A9869FBFF4640BC92E4B9BECB49400E4A9869FBFF4640F698486936C7494059349D9D0CF84640F698486936C74940
71745	29	46.000112000000001	46.006633000000001	51.523795999999997	51.519911999999998	проезд Весенний	0103000020E61000000100000005000000282B86AB030047402366F6798CC24940282B86AB0300474047E350BF0BC349408509A359D900474047E350BF0BC349408509A359D90047402366F6798CC24940282B86AB030047402366F6798CC24940
30926	29	45.808959000000002	46.012571000000001	51.545763000000001	51.388981000000001	поселок Юриш	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640F52EDE8FDBC5494063F030ED9B014740F52EDE8FDBC5494063F030ED9B014740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
30762	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	площадь им. Ленина В.И	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
30593	29	46.031382000000001	46.036394999999999	51.533579000000003	51.532414000000003	площадь Театральная	0103000020E610000001000000050000006FD74B53040447405EF7562426C449406FD74B53040447408C6A11514CC44940745E6397A80447408C6A11514CC44940745E6397A80447405EF7562426C449406FD74B53040447405EF7562426C44940
31511	29	46.031382000000001	46.036394999999999	51.533579000000003	51.532414000000003	площадь Театральная	0103000020E610000001000000050000006FD74B53040447405EF7562426C449406FD74B53040447408C6A11514CC44940745E6397A80447408C6A11514CC44940745E6397A80447405EF7562426C449406FD74B53040447405EF7562426C44940
31084	29	46.039467000000002	46.062922	51.528782999999997	51.523173999999997	набережная Космонавтов	0103000020E61000000100000005000000B82231410D0547400A0F9A5DF7C24940B82231410D05474023D74D29AFC349407619FED30D08474023D74D29AFC349407619FED30D0847400A0F9A5DF7C24940B82231410D0547400A0F9A5DF7C24940
30244	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	им.Пономарева П.Т.	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
30679	29	45.808959000000002	46.012571000000001	51.545763000000001	51.388981000000001	им.Пономарева П.Т	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640F52EDE8FDBC5494063F030ED9B014740F52EDE8FDBC5494063F030ED9B014740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
31640	29	45.968705999999997	46.008349000000003	51.602885999999998	51.598528000000002	академика Антонова	0103000020E6100000010000000500000030B8E68EFEFB4640C2DEC4909CCC494030B8E68EFEFB4640AE9B525E2BCD494027FA7C9411014740AE9B525E2BCD494027FA7C9411014740C2DEC4909CCC494030B8E68EFEFB4640C2DEC4909CCC4940
31596	29	45.919029999999999	45.923628999999998	51.472217000000001	51.469743000000001	Южно-Зеленая	0103000020E610000001000000050000007D0569C6A2F546403143E38920BC49407D0569C6A2F54640C0CE4D9B71BC49408F519E7939F64640C0CE4D9B71BC49408F519E7939F646403143E38920BC49407D0569C6A2F546403143E38920BC4940
31528	29	45.908923999999999	45.923979000000003	51.508882	51.499357000000003	Южная	0103000020E610000001000000050000005646239F57F44640AC0320EEEABF49405646239F57F44640F4C29D0B23C149406C98A1F144F64640F4C29D0B23C149406C98A1F144F64640AC0320EEEABF49405646239F57F44640AC0320EEEABF4940
51	29	45.924104999999997	45.968482000000002	51.508130000000001	51.424854000000003	Энтузиастов проспект	0103000020E61000000100000005000000F888981249F6464093C9A99D61B64940F888981249F64640E90E62670AC14940E161DA37F7FB4640E90E62670AC14940E161DA37F7FB464093C9A99D61B64940F888981249F6464093C9A99D61B64940
31537	29	45.970871000000002	45.973844999999997	51.568441999999997	51.567720000000001	Школьная	0103000020E6100000010000000500000042D13C8045FC46407FA4880CABC8494042D13C8045FC46401FD61BB5C2C84940C22FF5F3A6FC46401FD61BB5C2C84940C22FF5F3A6FC46407FA4880CABC8494042D13C8045FC46407FA4880CABC84940
31508	29	45.878551999999999	45.890256999999998	51.575915000000002	51.567652000000002	Широкая	0103000020E61000000100000005000000EEEA556474F0464027C11BD2A8C84940EEEA556474F046404F232D95B7C949407D04FEF0F3F146404F232D95B7C949407D04FEF0F3F1464027C11BD2A8C84940EEEA556474F0464027C11BD2A8C84940
31605	29	45.972264000000003	45.996015	51.582563999999998	51.569432999999997	Шехурдина	0103000020E61000000100000005000000018A912573FC4640AF21382EE3C84940018A912573FC4640D9E9077591CA4940A8A9656B7DFF4640D9E9077591CA4940A8A9656B7DFF4640AF21382EE3C84940018A912573FC4640AF21382EE3C84940
31500	29	45.958807	46.014988000000002	51.549734000000001	51.518343000000002	Шелковичная	0103000020E6100000010000000500000083161230BAFA4640268E3C1059C2494083161230BAFA4640E8BF07AF5DC649408EEA7420EB014740E8BF07AF5DC649408EEA7420EB014740268E3C1059C2494083161230BAFA4640268E3C1059C24940
31611	29	46.002006999999999	46.002428999999999	51.609498000000002	51.601885000000003	Чехова	0103000020E6100000010000000500000079AEEFC341004740FB7953910ACD494079AEEFC3410047401C7DCC0704CE4940EFC7ED974F0047401C7DCC0704CE4940EFC7ED974F004740FB7953910ACD494079AEEFC341004740FB7953910ACD4940
31623	29	45.977778999999998	46.066505999999997	51.535316000000002	51.507810999999997	Чернышевского	0103000020E6100000010000000500000098DBBDDC27FD464047C66AF3FFC0494098DBBDDC27FD46404583143C85C449406F7EC344830847404583143C85C449406F7EC3448308474047C66AF3FFC0494098DBBDDC27FD464047C66AF3FFC04940
31648	29	45.969838000000003	45.976917	51.608206000000003	51.608038000000001	Чемодурова	0103000020E610000001000000050000008335CEA623FC4640D55C6E30D4CD49408335CEA623FC4640919DB7B1D9CD494006F4C29D0BFD4640919DB7B1D9CD494006F4C29D0BFD4640D55C6E30D4CD49408335CEA623FC4640D55C6E30D4CD4940
31576	29	46.018301999999998	46.056696000000002	51.538615	51.528194999999997	Челюскинцев	0103000020E61000000100000005000000C7B94DB8570247409274CDE49BC34940C7B94DB85702474049111956F1C4494032E884D04107474049111956F1C4494032E884D0410747409274CDE49BC34940C7B94DB8570247409274CDE49BC34940
31610	29	46.013874000000001	46.032828000000002	51.555788	51.518416000000002	Чапаева	0103000020E61000000100000005000000E2218C9FC601474090DC9A745BC24940E2218C9FC60147402FC1A90F24C74940513239B5330447402FC1A90F24C74940513239B53304474090DC9A745BC24940E2218C9FC601474090DC9A745BC24940
30613	29	45.967584000000002	45.97954	51.587651000000001	51.587029999999999	Центральная	0103000020E610000001000000050000000211E2CAD9FB4640ACE28DCC23CB49400211E2CAD9FB4640193BE12538CB4940DA8F149161FD4640193BE12538CB4940DA8F149161FD4640ACE28DCC23CB49400211E2CAD9FB4640ACE28DCC23CB4940
31649	29	45.999679999999998	46.011107000000003	51.529567	51.522227000000001	Хользунова	0103000020E610000001000000050000008E3BA583F5FF46404A0B9755D8C249408E3BA583F5FF46403A05F9D9C8C34940DBE044F46B0147403A05F9D9C8C34940DBE044F46B0147404A0B9755D8C249408E3BA583F5FF46404A0B9755D8C24940
31115	29	46.067898	46.070000999999998	51.576580999999997	51.571907000000003	Федоровская улица	0103000020E610000001000000050000005EBBB4E1B00847403FADA23F34C949405EBBB4E1B00847405B3FFD67CDC94940F9D7F2CAF50847405B3FFD67CDC94940F9D7F2CAF50847403FADA23F34C949405EBBB4E1B00847403FADA23F34C94940
31637	29	45.994388999999998	46.000174000000001	51.613295000000001	51.611857999999998	Уфимцева	0103000020E610000001000000050000004640852348FF4640E2E5E95C51CE49404640852348FF464071E6577380CE49409E279EB30500474071E6577380CE49409E279EB305004740E2E5E95C51CE49404640852348FF4640E2E5E95C51CE4940
31592	29	45.996490999999999	46.011529000000003	51.549520999999999	51.533085999999997	Университетская	0103000020E6100000010000000500000011E15F048DFF46404CFA7B293CC4494011E15F048DFF46408CBB41B456C6494051FA42C8790147408CBB41B456C6494051FA42C8790147404CFA7B293CC4494011E15F048DFF46404CFA7B293CC44940
31645	29	45.990113000000001	45.999724999999998	51.556348	51.554735000000001	Украинская	0103000020E61000000100000005000000172CD505BCFE46402979758E01C74940172CD505BCFE4640F698486936C749402EFF21FDF6FF4640F698486936C749402EFF21FDF6FF46402979758E01C74940172CD505BCFE46402979758E01C74940
31644	29	45.895871	45.905636000000001	51.479246000000003	51.473109000000001	Тульская	0103000020E61000000100000005000000A837A3E6ABF24640BD38F1D58EBC4940A837A3E6ABF24640925ED4EE57BD4940460A65E1EBF34640925ED4EE57BD4940460A65E1EBF34640BD38F1D58EBC4940A837A3E6ABF24640BD38F1D58EBC4940
31622	29	45.993006000000001	46.004289	51.571967999999998	51.571508999999999	Тулайкова	0103000020E61000000100000005000000AB5D13D21AFF4640512FF83427C94940AB5D13D21AFF4640E42D573F36C94940C45DBD8A8C004740E42D573F36C94940C45DBD8A8C004740512FF83427C94940AB5D13D21AFF4640512FF83427C94940
31615	29	45.999724999999998	46.001126999999997	51.556348	51.549734000000001	Тракторная	0103000020E610000001000000050000002EFF21FDF6FF4640E8BF07AF5DC649402EFF21FDF6FF4640F698486936C749404012F6ED24004740F698486936C749404012F6ED24004740E8BF07AF5DC649402EFF21FDF6FF4640E8BF07AF5DC64940
30717	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	Телефонная	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
31618	29	45.972327	45.982782999999998	51.573385000000002	51.564757999999998	Тверская	0103000020E6100000010000000500000047020D3675FC4640C2137AFD49C8494047020D3675FC46402C82FFAD64C949404A0856D5CBFD46402C82FFAD64C949404A0856D5CBFD4640C2137AFD49C8494047020D3675FC4640C2137AFD49C84940
30186	29	46.013182	46.027259000000001	51.529932000000002	51.526839000000002	Тараса Шевченко	0103000020E61000000100000005000000AC72A1F2AF014740F1A0D9756FC34940AC72A1F2AF0147404C8DD0CFD4C34940C6C210397D0347404C8DD0CFD4C34940C6C210397D034740F1A0D9756FC34940AC72A1F2AF014740F1A0D9756FC34940
31527	29	46.015239000000001	46.029899999999998	51.586711000000001	51.546109999999999	Танкистов	0103000020E61000000100000005000000D74FFF59F30147406002B7EEE6C54940D74FFF59F30147400B9A965819CB4940401361C3D30347400B9A965819CB4940401361C3D30347406002B7EEE6C54940D74FFF59F30147406002B7EEE6C54940
1933	29	45.966963999999997	45.972155999999998	51.614688000000001	51.586340999999997	Строителей проспект	0103000020E610000001000000050000006534F279C5FB4640E7A6CD380DCB49406534F279C5FB4640309FAC18AECE49401A4E999B6FFC4640309FAC18AECE49401A4E999B6FFC4640E7A6CD380DCB49406534F279C5FB4640E7A6CD380DCB4940
30238	29	45.966963999999997	45.972155999999998	51.614688000000001	51.586340999999997	Строителей	0103000020E610000001000000050000006534F279C5FB4640E7A6CD380DCB49406534F279C5FB4640309FAC18AECE49401A4E999B6FFC4640309FAC18AECE49401A4E999B6FFC4640E7A6CD380DCB49406534F279C5FB4640E7A6CD380DCB4940
31647	29	46.046652999999999	46.053632999999998	51.531371	51.527248	Соляная	0103000020E6100000010000000500000051A1BAB9F8054740D270CADC7CC3494051A1BAB9F80547407B8505F703C44940417E3672DD0647407B8505F703C44940417E3672DD064740D270CADC7CC3494051A1BAB9F8054740D270CADC7CC34940
31584	29	46.051307000000001	46.053471999999999	51.557741999999998	51.551637999999997	Соколовогорская	0103000020E6100000010000000500000027874F3A910647408C9DF0129CC6494027874F3A9106474085CD001764C7494038A0A52BD806474085CD001764C7494038A0A52BD80647408C9DF0129CC6494027874F3A910647408C9DF0129CC64940
71757	29	45.996015	46.062615999999998	51.569432999999997	51.529007	Соколовая	0103000020E61000000100000005000000A8A9656B7DFF4640732D5A80B6C34940A8A9656B7DFF4640AF21382EE3C84940691A14CD03084740AF21382EE3C84940691A14CD03084740732D5A80B6C34940A8A9656B7DFF4640732D5A80B6C34940
31651	29	46.008502	46.032774000000003	51.533169999999998	51.526513999999999	Советская	0103000020E61000000100000005000000ADF9F197160147406D718DCF64C34940ADF9F19716014740AA9A20EA3EC449405E143DF031044740AA9A20EA3EC449405E143DF0310447406D718DCF64C34940ADF9F197160147406D718DCF64C34940
31577	29	46.035837999999998	46.048287999999999	51.546754	51.524182000000003	Соборная	0103000020E610000001000000050000001EFAEE56960447407193516518C349401EFAEE5696044740857AFA08FCC5494006651A4D2E064740857AFA08FCC5494006651A4D2E0647407193516518C349401EFAEE56960447407193516518C34940
31561	29	46.003256	46.013334999999998	51.524306000000003	51.517749000000002	Симбирцева	0103000020E6100000010000000500000005C24EB16A004740B344679945C2494005C24EB16A0047405D8C81751CC34940327216F6B40147405D8C81751CC34940327216F6B4014740B344679945C2494005C24EB16A004740B344679945C24940
31567	29	46.050040000000003	46.05198	51.532637999999999	51.531993	Северная	0103000020E61000000100000005000000F5BEF1B567064740B859BC5818C44940F5BEF1B567064740AD4D637B2DC44940E605D847A7064740AD4D637B2DC44940E605D847A7064740B859BC5818C44940F5BEF1B567064740B859BC5818C44940
31601	29	45.983573999999997	45.986708999999998	51.540917999999998	51.537287999999997	Свинцовая	0103000020E610000001000000050000001399B9C0E5FD464041446ADAC5C449401399B9C0E5FD4640ABE80FCD3CC549409DD5027B4CFE4640ABE80FCD3CC549409DD5027B4CFE464041446ADAC5C449401399B9C0E5FD464041446ADAC5C44940
31627	29	45.990284000000003	45.994964000000003	51.560363000000002	51.558284999999998	Рябиновская	0103000020E6100000010000000500000044E048A0C1FE4640766C04E275C7494044E048A0C1FE4640B9718BF9B9C749404359F8FA5AFF4640B9718BF9B9C749404359F8FA5AFF4640766C04E275C7494044E048A0C1FE4640766C04E275C74940
31513	29	45.939601000000003	45.947246	51.512335	51.510317000000001	Ростовская	0103000020E61000000100000005000000FB2477D844F84640E2CB441152C14940FB2477D844F846404FCC7A3194C1494027A25F5B3FF946404FCC7A3194C1494027A25F5B3FF94640E2CB441152C14940FB2477D844F84640E2CB441152C14940
31545	29	46.005439000000003	46.024447000000002	51.549005999999999	51.522384000000002	Рахова	0103000020E61000000100000005000000BD8FA339B200474012FA997ADDC24940BD8FA339B200474065A71FD445C649401FBE4C142103474065A71FD445C649401FBE4C142103474012FA997ADDC24940BD8FA339B200474012FA997ADDC24940
31612	29	46.030349000000001	46.044012000000002	51.543897999999999	51.522440000000003	Радищева	0103000020E61000000100000005000000B03BDD79E2034740A60F5D50DFC24940B03BDD79E20347400E2E1D739EC54940D7506A2FA20547400E2E1D739EC54940D7506A2FA2054740A60F5D50DFC24940B03BDD79E2034740A60F5D50DFC24940
31549	29	45.979557999999997	46.03078	51.541007	51.523235	Рабочая	0103000020E610000001000000050000008044132862FD4640B08F4E5DF9C249408044132862FD46401BF4A5B73FC5494079AF5A99F00347401BF4A5B73FC5494079AF5A99F0034740B08F4E5DF9C249408044132862FD4640B08F4E5DF9C24940
30254	29	45.997605	46.022713000000003	51.554057	51.523471000000001	Пугачевская улица	0103000020E61000000100000005000000BDA94885B1FF4640C4B3041901C34940BDA94885B1FF4640588FFB56EBC64940D7187442E8024740588FFB56EBC64940D7187442E8024740C4B3041901C34940BDA94885B1FF4640C4B3041901C34940
31228	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	Пугачева	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
31656	29	45.971643999999998	45.972183000000001	51.602756999999997	51.595703	Производственная	0103000020E6100000010000000500000064ADA1D45EFC46408690F3FE3FCC494064ADA1D45EFC4640B037312427CD4940145D177E70FC4640B037312427CD4940145D177E70FC46408690F3FE3FCC494064ADA1D45EFC46408690F3FE3FCC4940
31617	29	46.027492000000002	46.030430000000003	51.527045999999999	51.521700000000003	Провиантская	0103000020E6100000010000000500000069739CDB840347405F29CB10C7C2494069739CDB840347406ABE4A3E76C349409D685721E50347406ABE4A3E76C349409D685721E50347405F29CB10C7C2494069739CDB840347405F29CB10C7C24940
15777	29	45.998980000000003	46.001269999999998	51.541752000000002	51.540128000000003	Привокзальная площадь	0103000020E61000000100000005000000D6AD9E93DEFF4640B3D30FEA22C54940D6AD9E93DEFF46407445292158C54940A33B889D290047407445292158C54940A33B889D29004740B3D30FEA22C54940D6AD9E93DEFF4640B3D30FEA22C54940
31570	29	46.004424	46.053804	51.546686999999999	51.534542999999999	Посадского	0103000020E61000000100000005000000A4A833F79000474022A7AFE76BC44940A4A833F790004740FD12F1D6F9C549406E32AA0CE3064740FD12F1D6F9C549406E32AA0CE306474022A7AFE76BC44940A4A833F79000474022A7AFE76BC44940
30819	29	45.930509999999998	45.939008000000001	51.496200000000002	51.492100999999998	Пономарева	0103000020E61000000100000005000000EC4CA1F31AF7464019AA622AFDBE4940EC4CA1F31AF746403A234A7B83BF49405857056A31F846403A234A7B83BF49405857056A31F8464019AA622AFDBE4940EC4CA1F31AF7464019AA622AFDBE4940
31589	29	45.979019000000001	45.984732000000001	51.531478	51.513215000000002	Политехническая	0103000020E61000000100000005000000D1949D7E50FD464088687407B1C14940D1949D7E50FD464091459A7807C449408FA9BBB20BFE464091459A7807C449408FA9BBB20BFE464088687407B1C14940D1949D7E50FD464088687407B1C14940
31580	29	45.985218000000003	45.987886000000003	51.615057	51.602404999999997	Перспективная	0103000020E610000001000000050000001CB7989F1BFE464033F9669B1BCD49401CB7989F1BFE464083161230BACE49409016670C73FE464083161230BACE49409016670C73FE464033F9669B1BCD49401CB7989F1BFE464033F9669B1BCD4940
31609	29	45.962992999999997	45.970331999999999	51.590246999999998	51.589945	Осенняя	0103000020E6100000010000000500000072A3C85A43FB464028B8585183CB494072A3C85A43FB4640F3C7B4368DCB49409221C7D633FC4640F3C7B4368DCB49409221C7D633FC464028B8585183CB494072A3C85A43FB464028B8585183CB4940
31597	29	45.962409000000001	45.969496999999997	51.580891000000001	51.578299000000001	Одесская	0103000020E610000001000000050000002330D63730FB46409E279EB305CA49402330D63730FB464037C5E3A25ACA4940F9484A7A18FC464037C5E3A25ACA4940F9484A7A18FC46409E279EB305CA49402330D63730FB46409E279EB305CA4940
31591	29	45.914439000000002	45.980358000000003	51.514851	51.490205000000003	Огородная	0103000020E61000000100000005000000EE974F560CF54640F8AA9509BFBE4940EE974F560CF546400DA837A3E6C149409D2FF65E7CFD46400DA837A3E6C149409D2FF65E7CFD4640F8AA9509BFBE4940EE974F560CF54640F8AA9509BFBE4940
31548	29	45.960307	46.011555999999999	51.537506	51.517423999999998	Новоузенская	0103000020E61000000100000005000000588FFB56EBFA46402F151BF33AC24940588FFB56EBFA4640AFB321FFCCC449404A09C1AA7A014740AFB321FFCCC449404A09C1AA7A0147402F151BF33AC24940588FFB56EBFA46402F151BF33AC24940
30445	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	Ново-Крекингская	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
30355	29	45.898575000000001	45.984642999999998	51.513281999999997	51.487211000000002	Ново-Астраханское шоссе	0103000020E6100000010000000500000069006F8104F3464030A017EE5CBE494069006F8104F346400FD07D39B3C149401F9E25C808FE46400FD07D39B3C149401F9E25C808FE464030A017EE5CBE494069006F8104F3464030A017EE5CBE4940
30360	29	45.898575000000001	45.984642999999998	51.513281999999997	51.487211000000002	Ново-Астраханское шоссе	0103000020E6100000010000000500000069006F8104F3464030A017EE5CBE494069006F8104F346400FD07D39B3C149401F9E25C808FE46400FD07D39B3C149401F9E25C808FE464030A017EE5CBE494069006F8104F3464030A017EE5CBE4940
31573	29	45.986781000000001	45.990175999999998	51.561757	51.561214	Наумовская	0103000020E6100000010000000500000037A8FDD64EFE4640570740DCD5C7494037A8FDD64EFE464048A643A7E7C749405DA45016BEFE464048A643A7E7C749405DA45016BEFE4640570740DCD5C7494037A8FDD64EFE4640570740DCD5C74940
30365	29	45.896715999999998	45.939672999999999	51.611471999999999	51.593963000000002	Московское шоссе	0103000020E6100000010000000500000064E60297C7F246405C04C6FA06CC494064E60297C7F24640B935E9B644CE494094F7713447F84640B935E9B644CE494094F7713447F846405C04C6FA06CC494064E60297C7F246405C04C6FA06CC4940
31585	29	45.991720999999998	46.055968999999997	51.544676000000003	51.526626	Московская	0103000020E61000000100000005000000D2E0B6B6F0FE4640959C137B68C34940D2E0B6B6F0FE4640437573F1B7C549407F4B00FE29074740437573F1B7C549407F4B00FE29074740959C137B68C34940D2E0B6B6F0FE4640959C137B68C34940
30400	29	46.008806999999997	46.065302000000003	51.535421999999997	51.524889000000002	Мичурина	0103000020E61000000100000005000000E97C789620014740DC8310902FC34940E97C7896200147408AC745B588C44940842EE1D05B0847408AC745B588C44940842EE1D05B084740DC8310902FC34940E97C789620014740DC8310902FC34940
31638	29	46.008806999999997	46.065302000000003	51.535421999999997	51.524889000000002	Мичурина	0103000020E61000000100000005000000E97C789620014740DC8310902FC34940E97C7896200147408AC745B588C44940842EE1D05B0847408AC745B588C44940842EE1D05B084740DC8310902FC34940E97C789620014740DC8310902FC34940
2050	29	46.015715	46.018680000000003	51.535473000000003	51.530402000000002	Мирный переулок	0103000020E610000001000000050000004087F9F202024740D3DD7536E4C349404087F9F2020247400D7217618AC449406E8B321B640247400D7217618AC449406E8B321B64024740D3DD7536E4C349404087F9F202024740D3DD7536E4C34940
31574	29	45.959885	45.968705999999997	51.581366000000003	51.580548999999998	Мира	0103000020E61000000100000005000000E275FD82DDFA4640DD5CFC6D4FCA4940E275FD82DDFA4640D0807A336ACA494030B8E68EFEFB4640D0807A336ACA494030B8E68EFEFB4640DD5CFC6D4FCA4940E275FD82DDFA4640DD5CFC6D4FCA4940
30786	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	Мелиораторов	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
31619	29	45.950057000000001	45.969129000000002	51.584926000000003	51.580739000000001	Международная	0103000020E61000000100000005000000FE2AC0779BF946408141D2A755CA4940FE2AC0779BF94640414AECDADECA4940774D486B0CFC4640414AECDADECA4940774D486B0CFC46408141D2A755CA4940FE2AC0779BF946408141D2A755CA4940
31492	29	45.799590000000002	45.898575000000001	51.492767999999998	51.479419999999998	Маркина	0103000020E61000000100000005000000B51A12F758E646402F8672A25DBD4940B51A12F758E64640F641960513BF494069006F8104F34640F641960513BF494069006F8104F346402F8672A25DBD4940B51A12F758E646402F8672A25DBD4940
30749	29	45.919865000000001	45.925462000000003	51.493406999999998	51.491630000000001	Марины Расковой	0103000020E6100000010000000500000016DEE522BEF54640C2DD59BBEDBE494016DEE522BEF54640094FE8F527BF49406BD8EF8975F64640094FE8F527BF49406BD8EF8975F64640C2DD59BBEDBE494016DEE522BEF54640C2DD59BBEDBE4940
31565	29	46.002411000000002	46.009687999999997	51.607371999999998	51.607199000000001	Мамонтовой	0103000020E610000001000000050000004913EF004F004740FB9463B2B8CD49404913EF004F004740C8409E5DBECD4940F294D5743D014740C8409E5DBECD4940F294D5743D014740FB9463B2B8CD49404913EF004F004740FB9463B2B8CD4940
30370	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	Мало-Елшанская	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
31566	29	46.024751999999999	46.041955000000002	51.549867999999996	51.52281	Максима Горького	0103000020E610000001000000050000005B41D3122B034740C9022670EBC249405B41D3122B034740F78E1A1362C64940AC730CC85E054740F78E1A1362C64940AC730CC85E054740C9022670EBC249405B41D3122B034740C9022670EBC24940
30209	29	45.808959000000002	46.012571000000001	51.545763000000001	51.388981000000001	Лесопильная	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640F52EDE8FDBC5494063F030ED9B014740F52EDE8FDBC5494063F030ED9B014740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
31594	29	45.997875000000001	46.000525000000003	51.564041000000003	51.562849	Лесная	0103000020E610000001000000050000007D3F355EBAFF46400CCB9F6F0BC849407D3F355EBAFF4640344DD87E32C849404BEA043411004740344DD87E32C849404BEA0434110047400CCB9F6F0BC849407D3F355EBAFF46400CCB9F6F0BC84940
30587	29	45.974474000000001	45.987769	51.614559	51.595613	Лебедева-Кумача	0103000020E61000000100000005000000B2666490BBFC46404609FA0B3DCC4940B2666490BBFC4640323B8BDEA9CE49405680EF366FFE4640323B8BDEA9CE49405680EF366FFE46404609FA0B3DCC4940B2666490BBFC46404609FA0B3DCC4940
31628	29	45.970350000000003	45.975614999999998	51.587203000000002	51.583722000000002	Куприянова	0103000020E6100000010000000500000039D6C56D34FC464055FA0967B7CA494039D6C56D34FC46407A8EC87729CB4940573ECBF3E0FC46407A8EC87729CB4940573ECBF3E0FC464055FA0967B7CA494039D6C56D34FC464055FA0967B7CA4940
31626	29	45.918365000000001	45.930267999999998	51.491461000000001	51.489610999999996	Крымская	0103000020E610000001000000050000004165FCFB8CF546408461C092ABBE49404165FCFB8CF546403621AD31E8BE4940F641960513F746403621AD31E8BE4940F641960513F746408461C092ABBE49404165FCFB8CF546408461C092ABBE4940
31655	29	45.915939000000002	45.917960999999998	51.592843999999999	51.588831999999996	Крылова	0103000020E61000000100000005000000C310397D3DF546404C6BD3D85ECB4940C310397D3DF546409ED0EB4FE2CB49407100FDBE7FF546409ED0EB4FE2CB49407100FDBE7FF546404C6BD3D85ECB4940C310397D3DF546404C6BD3D85ECB4940
31636	29	45.989897999999997	46.001126999999997	51.549734000000001	51.541988000000003	Краевая	0103000020E610000001000000050000001A3048FAB4FE46408869DFDC5FC549401A3048FAB4FE4640E8BF07AF5DC649404012F6ED24004740E8BF07AF5DC649404012F6ED240047408869DFDC5FC549401A3048FAB4FE46408869DFDC5FC54940
30402	29	46.041722	46.051073000000002	51.543663000000002	51.524473999999998	Комсомольская улица	0103000020E6100000010000000500000009C380255705474018CDCAF621C3494009C3802557054740CB85CABF96C54940B45A608F89064740CB85CABF96C54940B45A608F8906474018CDCAF621C3494009C380255705474018CDCAF621C34940
31564	29	46.041722	46.051073000000002	51.543663000000002	51.524473999999998	Комсомольская	0103000020E6100000010000000500000009C380255705474018CDCAF621C3494009C3802557054740CB85CABF96C54940B45A608F89064740CB85CABF96C54940B45A608F8906474018CDCAF621C3494009C380255705474018CDCAF621C34940
29034	29	46.015841000000002	46.016936999999999	51.548205000000003	51.547364999999999	Колхозная площадь	0103000020E61000000100000005000000CD77F01307024740CEFC6A0E10C64940CD77F013070247407940D9942BC64940D28BDAFD2A0247407940D9942BC64940D28BDAFD2A024740CEFC6A0E10C64940CD77F01307024740CEFC6A0E10C64940
31671	29	45.948017999999998	45.97945	51.533040999999997	51.524608000000001	Клочкова	0103000020E61000000100000005000000790261A758F94640289CDD5A26C34940790261A758F94640AC36FFAF3AC449409A081B9E5EFD4640AC36FFAF3AC449409A081B9E5EFD4640289CDD5A26C34940790261A758F94640289CDD5A26C34940
31531	29	45.952689999999997	45.968589999999999	51.538984999999997	51.534739000000002	Клиническая	0103000020E61000000100000005000000F59CF4BEF1F94640A872DA5372C44940F59CF4BEF1F946406C04E275FDC44940C79DD2C1FAFB46406C04E275FDC44940C79DD2C1FAFB4640A872DA5372C44940F59CF4BEF1F94640A872DA5372C44940
2803	29	46.021168000000003	46.034849000000001	51.532890000000002	51.529864000000003	Кирова проспект	0103000020E6100000010000000500000062DC0DA2B5024740F4A96395D2C3494062DC0DA2B5024740C72E51BD35C449402FA699EE75044740C72E51BD35C449402FA699EE75044740F4A96395D2C3494062DC0DA2B5024740F4A96395D2C34940
31536	29	45.933250000000001	45.941496999999998	51.500349	51.494287999999997	Кавказская	0103000020E61000000100000005000000FA7E6ABC74F74640126745D444BF4940FA7E6ABC74F746400CCB9F6F0BC049401C2444F982F846400CCB9F6F0BC049401C2444F982F84640126745D444BF4940FA7E6ABC74F74640126745D444BF4940
15733	29	46.013891999999998	46.016677000000001	51.520797999999999	51.520187	Ильинская площадь	0103000020E6100000010000000500000088D68A36C7014740F566D47C95C2494088D68A36C70147403EE94482A9C2494036CCD078220247403EE94482A9C2494036CCD07822024740F566D47C95C2494088D68A36C7014740F566D47C95C24940
31661	29	46.015121999999998	46.017341000000002	51.564158999999997	51.563116999999998	Зенитная	0103000020E610000001000000050000009DB98784EF0147402B69C53714C849409DB98784EF0147403D5FB35C36C84940A2F0D93A380247403D5FB35C36C84940A2F0D93A380247402B69C53714C849409DB98784EF0147402B69C53714C84940
31509	29	46.028049000000003	46.038398000000001	51.549812000000003	51.547656000000003	Зеленая	0103000020E61000000100000005000000BFD7101C97034740A6BA809719C64940BFD7101C970347406479573D60C64940AC1DC539EA0447406479573D60C64940AC1DC539EA044740A6BA809719C64940BFD7101C97034740A6BA809719C64940
31568	29	45.997002999999999	46.039521000000001	51.547846999999997	51.536738999999997	Зарубина	0103000020E61000000100000005000000C78157CB9DFF46406EBE11DDB3C44940C78157CB9DFF4640191BBAD91FC64940AB402D060F054740191BBAD91FC64940AB402D060F0547406EBE11DDB3C44940C78157CB9DFF46406EBE11DDB3C44940
31547	29	45.908465	45.914287000000002	51.474141000000003	51.466920999999999	Заречная	0103000020E61000000100000005000000C347C49448F4464066683C11C4BB4940C347C49448F44640AC58FCA6B0BC494038143E5B07F54640AC58FCA6B0BC494038143E5B07F5464066683C11C4BB4940C347C49448F4464066683C11C4BB4940
31660	29	45.958483999999999	45.965930999999998	51.599691999999997	51.595568	Загороднева	0103000020E61000000100000005000000A0DE8C9AAFFA4640A6457D923BCC4940A0DE8C9AAFFA46401FD61BB5C2CC4940A69883A0A3FB46401FD61BB5C2CC4940A69883A0A3FB4640A6457D923BCC4940A0DE8C9AAFFA4640A6457D923BCC4940
31616	29	46.023485999999998	46.030735	51.563963000000001	51.562350000000002	Жуковского	0103000020E61000000100000005000000F9F4D89601034740EB73B515FBC74940F9F4D89601034740B89388F02FC84940D9EBDD1FEF034740B89388F02FC84940D9EBDD1FEF034740EB73B515FBC74940F9F4D89601034740EB73B515FBC74940
31581	29	46.002411000000002	46.015230000000003	51.551099999999998	51.532839000000003	Железнодорожная	0103000020E610000001000000050000004913EF004F00474045847F1134C449404913EF004F004740AD69DE718AC6494084F57F0EF3014740AD69DE718AC6494084F57F0EF301474045847F1134C449404913EF004F00474045847F1134C44940
75040	29	45.970503000000001	45.976917	51.575550999999997	51.572499999999998	Дубовикова	0103000020E61000000100000005000000BFD53A7139FC4640E17A14AE47C94940BFD53A7139FC46400D17B9A7ABC9494006F4C29D0BFD46400D17B9A7ABC9494006F4C29D0BFD4640E17A14AE47C94940BFD53A7139FC4640E17A14AE47C94940
31517	29	46.063389000000001	46.071680000000001	51.573172	51.572718999999999	Державинская улица	0103000020E610000001000000050000008CF678211D0847401F662FDB4EC949408CF678211D084740D07D39B35DC949407EE36BCF2C094740D07D39B35DC949407EE36BCF2C0947401F662FDB4EC949408CF678211D0847401F662FDB4EC94940
31493	29	46.063389000000001	46.071680000000001	51.573172	51.572718999999999	Державинская	0103000020E610000001000000050000008CF678211D0847401F662FDB4EC949408CF678211D084740D07D39B35DC949407EE36BCF2C094740D07D39B35DC949407EE36BCF2C0947401F662FDB4EC949408CF678211D0847401F662FDB4EC94940
1235	29	45.981938999999997	45.985514000000002	51.568733000000002	51.565714999999997	Деловой проезд	0103000020E610000001000000050000005ED5592DB0FD4640A6ED5F5969C849405ED5592DB0FD4640F793313ECCC8494005E09F5225FE4640F793313ECCC8494005E09F5225FE4640A6ED5F5969C849405ED5592DB0FD4640A6ED5F5969C84940
31562	29	45.989241999999997	45.996527	51.518405000000001	51.510126	Дегтярная	0103000020E6100000010000000500000031EA5A7B9FFE46406E6B0BCF4BC1494031EA5A7B9FFE46409C8A54185BC249405E4A5D328EFF46409C8A54185BC249405E4A5D328EFF46406E6B0BCF4BC1494031EA5A7B9FFE46406E6B0BCF4BC14940
31643	29	46.020926000000003	46.028632999999999	51.564433000000001	51.561236000000001	Высокая	0103000020E610000001000000050000006CD102B4AD0247403FABCC94D6C749406CD102B4AD0247403FE42D573FC849400E4B033FAA0347403FE42D573FC849400E4B033FAA0347403FABCC94D6C749406CD102B4AD0247403FABCC94D6C74940
31497	29	46.048431999999998	46.054378999999997	51.540767000000002	51.531002000000001	Вознесенская улица	0103000020E61000000100000005000000390A100533064740280EA0DFF7C34940390A100533064740C6E061DA37C549406A4B1DE4F5064740C6E061DA37C549406A4B1DE4F5064740280EA0DFF7C34940390A100533064740280EA0DFF7C34940
31532	29	45.977581999999998	45.987912000000001	51.565480000000001	51.563425000000002	Вишневая	0103000020E6100000010000000500000042942F6821FD4640D95F764F1EC8494042942F6821FD464063450DA661C84940B9A981E673FE464063450DA661C84940B9A981E673FE4640D95F764F1EC8494042942F6821FD4640D95F764F1EC84940
31659	29	45.914942000000003	45.929817999999997	51.478971000000001	51.477961999999998	Васильковская	0103000020E6100000010000000500000051DEC7D11CF54640895DDBDB2DBD494051DEC7D11CF54640C05DF6EB4EBD4940B69DB64604F74640C05DF6EB4EBD4940B69DB64604F74640895DDBDB2DBD494051DEC7D11CF54640895DDBDB2DBD4940
30208	29	46.003785999999998	46.017313999999999	51.536453000000002	51.533135999999999	Вавилова	0103000020E610000001000000050000006117450F7C004740FE28EACC3DC449406117450F7C004740A96BED7DAAC44940A8E15B5837024740A96BED7DAAC44940A8E15B5837024740FE28EACC3DC449406117450F7C004740FE28EACC3DC44940
31613	29	45.915984000000002	45.948467000000001	51.472014999999999	51.458329999999997	Брянская	0103000020E6100000010000000500000063D4B5F63EF546404963B48EAABA494063D4B5F63EF54640581CCEFC6ABC4940E92ADD5D67F94640581CCEFC6ABC4940E92ADD5D67F946404963B48EAABA494063D4B5F63EF546404963B48EAABA4940
31603	29	45.982028999999997	46.040446000000003	51.552103000000002	51.508707999999999	Большая Садовая	0103000020E610000001000000050000009E5C5320B3FD4640569BFF571DC149409E5C5320B3FD46400283A44FABC6494084A0A3552D0547400283A44FABC6494084A0A3552D054740569BFF571DC149409E5C5320B3FD4640569BFF571DC14940
31546	29	46.000290999999997	46.035837999999998	51.539628999999998	51.531534000000001	Большая Казачья	0103000020E61000000100000005000000D7BD158909004740255B5D4E09C44940D7BD158909004740917C259012C549401EFAEE5696044740917C259012C549401EFAEE5696044740255B5D4E09C44940D7BD158909004740255B5D4E09C44940
30969	29	45.999724999999998	46.062508999999999	51.556365	51.528973000000001	Большая Горная улица	0103000020E610000001000000050000002EFF21FDF6FF4640C7BB2363B5C349402EFF21FDF6FF4640CCD1E3F736C74940535A7F4B00084740CCD1E3F736C74940535A7F4B00084740C7BB2363B5C349402EFF21FDF6FF4640C7BB2363B5C34940
31494	29	45.999724999999998	46.062508999999999	51.556365	51.528973000000001	Большая Горная улица	0103000020E610000001000000050000002EFF21FDF6FF4640C7BB2363B5C349402EFF21FDF6FF4640CCD1E3F736C74940535A7F4B00084740CCD1E3F736C74940535A7F4B00084740C7BB2363B5C349402EFF21FDF6FF4640C7BB2363B5C34940
31595	29	45.999724999999998	46.062508999999999	51.556365	51.528973000000001	Большая Горная	0103000020E610000001000000050000002EFF21FDF6FF4640C7BB2363B5C349402EFF21FDF6FF4640CCD1E3F736C74940535A7F4B00084740CCD1E3F736C74940535A7F4B00084740C7BB2363B5C349402EFF21FDF6FF4640C7BB2363B5C34940
31505	29	45.978057999999997	46.008465999999999	51.602398999999998	51.599009000000002	Блинова	0103000020E61000000100000005000000ABCB290131FD46403D81B053ACCC4940ABCB290131FD4640511212691BCD49406090F46915014740511212691BCD49406090F469150147403D81B053ACCC4940ABCB290131FD46403D81B053ACCC4940
31558	29	46.026800999999999	46.031103000000002	51.569785000000003	51.569091	Бирюзова	0103000020E61000000100000005000000034015376E03474056B950F9D7C84940034015376E0347402D6002B7EEC849405CE7DF2EFB0347402D6002B7EEC849405CE7DF2EFB03474056B950F9D7C84940034015376E03474056B950F9D7C84940
31620	29	45.935478000000003	45.937885000000001	51.591645999999997	51.58717	Бережная	0103000020E6100000010000000500000052103CBEBDF746409E98F56228CB494052103CBEBDF7464094675E0EBBCB494059349D9D0CF8464094675E0EBBCB494059349D9D0CF846409E98F56228CB494052103CBEBDF746409E98F56228CB4940
67052	29	45.935478000000003	45.937885000000001	51.591645999999997	51.58717	Бережная	0103000020E6100000010000000500000052103CBEBDF746409E98F56228CB494052103CBEBDF7464094675E0EBBCB494059349D9D0CF8464094675E0EBBCB494059349D9D0CF846409E98F56228CB494052103CBEBDF746409E98F56228CB4940
31633	29	46.007801000000001	46.021402000000002	51.564624000000002	51.559376999999998	Безымянная	0103000020E6100000010000000500000024F0879FFF0047403A9160AA99C7494024F0879FFF004740B344679945C84940D508FD4CBD024740B344679945C84940D508FD4CBD0247403A9160AA99C7494024F0879FFF0047403A9160AA99C74940
31604	29	46.002411000000002	46.016632000000001	51.612501000000002	51.609498000000002	Батавина	0103000020E610000001000000050000004913EF004F0047401C7DCC0704CE49404913EF004F00474037E2C96E66CE4940960854FF2002474037E2C96E66CE4940960854FF200247401C7DCC0704CE49404913EF004F0047401C7DCC0704CE4940
31556	29	45.986339999999998	46.002366000000002	51.543170000000003	51.530447000000002	Аткарская 	0103000020E610000001000000050000004A5E9D6340FE464073A1F2AFE5C349404A5E9D6340FE46408C15359886C54940A94F72874D0047408C15359886C54940A94F72874D00474073A1F2AFE5C349404A5E9D6340FE464073A1F2AFE5C34940
31583	29	45.986339999999998	46.002366000000002	51.543170000000003	51.530447000000002	Аткарская	0103000020E610000001000000050000004A5E9D6340FE464073A1F2AFE5C349404A5E9D6340FE46408C15359886C54940A94F72874D0047408C15359886C54940A94F72874D00474073A1F2AFE5C349404A5E9D6340FE464073A1F2AFE5C34940
31630	29	46.004289	46.021518	51.571508999999999	51.565697999999998	Артиллерийская	0103000020E61000000100000005000000C45DBD8A8C004740D0B4C4CA68C84940C45DBD8A8C004740512FF83427C949403E23111AC1024740512FF83427C949403E23111AC1024740D0B4C4CA68C84940C45DBD8A8C004740D0B4C4CA68C84940
31516	29	45.980915000000003	45.990454999999997	51.561509999999998	51.557636000000002	Аптечная	0103000020E61000000100000005000000F3936A9F8EFD46404089CF9D60C74940F3936A9F8EFD46404030478FDFC749407094BC3AC7FE46404030478FDFC749407094BC3AC7FE46404089CF9D60C74940F3936A9F8EFD46404089CF9D60C74940
30843	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	Азовская	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
30616	29	45.904755000000002	45.933771	51.476951999999997	51.445303000000003	Азина	0103000020E610000001000000050000003DF20703CFF34640C5E74EB0FFB849403DF20703CFF3464082E15CC30CBD4940037AE1CE85F7464082E15CC30CBD4940037AE1CE85F74640C5E74EB0FFB849403DF20703CFF34640C5E74EB0FFB84940
597	29	45.992099000000003	46.000309000000001	51.562815000000001	51.557696999999997	50 Лет Октября проспект	0103000020E6100000010000000500000079B29B19FDFE4640E509849D62C7494079B29B19FDFE4640605969520AC849407E7214200A004740605969520AC849407E7214200A004740E509849D62C7494079B29B19FDFE4640E509849D62C74940
396	29	45.945207000000003	45.949967999999998	51.522378000000003	51.515552	5-й Нагорный проезд	0103000020E61000000100000005000000A379008BFCF8464096B1A19BFDC14940A379008BFCF8464030134548DDC249408E1F2A8D98F9464030134548DDC249408E1F2A8D98F9464096B1A19BFDC14940A379008BFCF8464096B1A19BFDC14940
31642	29	46.001666	46.002735000000001	51.515894000000003	51.515625	4-й проезд Чернышевского	0103000020E61000000100000005000000F0C16B97360047400000000000C24940F0C16B9736004740F01989D008C24940FCC6D79E59004740F01989D008C24940FCC6D79E590047400000000000C24940F0C16B97360047400000000000C24940
31621	29	45.905653999999998	45.921725000000002	51.603876	51.595886999999998	3-я Степная	0103000020E61000000100000005000000ECBE6378ECF34640478E740646CC4940ECBE6378ECF346406E6B0BCF4BCD4940EB73B515FBF546406E6B0BCF4BCD4940EB73B515FBF54640478E740646CC4940ECBE6378ECF34640478E740646CC4940
1879	29	45.969262999999998	45.974778999999998	51.604799	51.604720999999998	3-й Строителей проезд	0103000020E61000000100000005000000861C5BCF10FC46402A1A6B7F67CD4940861C5BCF10FC4640A6D3BA0D6ACD4940EEE9EA8EC5FC4640A6D3BA0D6ACD4940EEE9EA8EC5FC46402A1A6B7F67CD4940861C5BCF10FC46402A1A6B7F67CD4940
31543	29	45.905743999999999	45.911816000000002	51.604346	51.603271999999997	2-я Степная улица	0103000020E610000001000000050000002C465D6BEFF34640D74B530438CD49402C465D6BEFF34640F5BBB0355BCD49401AFCFD62B6F44640F5BBB0355BCD49401AFCFD62B6F44640D74B530438CD49402C465D6BEFF34640D74B530438CD4940
31588	29	45.959301000000004	46.007872999999996	51.535012999999999	51.516432000000002	2-я Садовая	0103000020E6100000010000000500000093020B60CAFA4640CF4D9B711AC2494093020B60CAFA4640A9F7544E7BC44940BDC282FB01014740A9F7544E7BC44940BDC282FB01014740CF4D9B711AC2494093020B60CAFA4640CF4D9B711AC24940
1726	29	45.919623000000001	45.924114000000003	51.599994000000002	51.596983999999999	2-й Московский проезд	0103000020E6100000010000000500000020D3DA34B6F546401D1EC2F869CC494020D3DA34B6F54640EBE5779ACCCC49404CE3175E49F64640EBE5779ACCCC49404CE3175E49F646401D1EC2F869CC494020D3DA34B6F546401D1EC2F869CC4940
797	29	46.021715999999998	46.022561000000003	51.563476000000001	51.558996	2-й Магнитный проезд	0103000020E6100000010000000500000064E60297C7024740234C512E8DC7494064E60297C70247405B0A48FB1FC8494021956247E30247405B0A48FB1FC8494021956247E3024740234C512E8DC7494064E60297C7024740234C512E8DC74940
30441	29	45.972309000000003	45.976880999999999	51.524608000000001	51.520125	1-я линия	0103000020E61000000100000005000000A14D0E9F74FC46407F6ABC7493C24940A14D0E9F74FC4640289CDD5A26C34940B98AC56F0AFD4640289CDD5A26C34940B98AC56F0AFD46407F6ABC7493C24940A14D0E9F74FC46407F6ABC7493C24940
31502	29	46.010820000000002	46.051549000000001	51.55133	51.542076999999999	1-я Садовая улица	0103000020E610000001000000050000004512BD8C62014740F77475C762C549404512BD8C62014740DFA63FFB91C649401D925A2899064740DFA63FFB91C649401D925A2899064740F77475C762C549404512BD8C62014740F77475C762C54940
31658	29	46.010820000000002	46.051549000000001	51.55133	51.542076999999999	1-я Садовая	0103000020E610000001000000050000004512BD8C62014740F77475C762C549404512BD8C62014740DFA63FFB91C649401D925A2899064740DFA63FFB91C649401D925A2899064740F77475C762C549404512BD8C62014740F77475C762C54940
31308	29	45.954118000000001	45.962499000000001	51.578164999999998	51.575265000000002	1-я Одесская улица	0103000020E610000001000000050000003143E38920FA464048C49448A2C949403143E38920FA46408E588B4F01CA494063B7CF2A33FB46408E588B4F01CA494063B7CF2A33FB464048C49448A2C949403143E38920FA464048C49448A2C94940
31544	29	45.896563	45.899500000000003	51.585546999999998	51.578018999999998	1-я Елшанская	0103000020E61000000100000005000000DEE68D93C2F24640BABBCE86FCC94940DEE68D93C2F24640ADA23F34F3CA49404260E5D022F34640ADA23F34F3CA49404260E5D022F34640BABBCE86FCC94940DEE68D93C2F24640BABBCE86FCC94940
31506	29	45.972417	45.974608000000003	51.531584000000002	51.526626	1-я Детская	0103000020E610000001000000050000008789062978FC4640959C137B68C349408789062978FC4640D789CBF10AC44940C23577F4BFFC4640D789CBF10AC44940C23577F4BFFC4640959C137B68C349408789062978FC4640959C137B68C34940
77483	29	45.930250000000001	45.931148	51.591858999999999	51.589776999999998	1-й проезд Панфилова	0103000020E61000000100000005000000508D976E12F746406C770FD07DCB4940508D976E12F74640F06B2409C2CB49402FDE8FDB2FF74640F06B2409C2CB49402FDE8FDB2FF746406C770FD07DCB4940508D976E12F746406C770FD07DCB4940
134	29	45.893490999999997	45.904629999999997	51.476844999999997	51.473109000000001	1-й Тульский проезд	0103000020E610000001000000050000009A22C0E95DF24640BD38F1D58EBC49409A22C0E95DF246406C21C84109BD4940807D74EACAF346406C21C84109BD4940807D74EACAF34640BD38F1D58EBC49409A22C0E95DF24640BD38F1D58EBC4940
30986	29	46.010576999999998	46.015813999999999	51.610515999999997	51.610470999999997	1-й Топольчанский проезд	0103000020E610000001000000050000007E8B4E965A0147400514EAE923CE49407E8B4E965A014740A5D7666325CE4940D368723106024740A5D7666325CE4940D3687231060247400514EAE923CE49407E8B4E965A0147400514EAE923CE4940
7941	29	46.051352000000001	46.054549999999999	51.551637999999997	51.551178999999998	1-й Соколовогорский проезд	0103000020E61000000100000005000000C74ACCB392064740F99E91088DC64940C74ACCB3920647408C9DF0129CC6494097FF907EFB0647408C9DF0129CC6494097FF907EFB064740F99E91088DC64940C74ACCB392064740F99E91088DC64940
1545	29	45.930250000000001	45.931148	51.591858999999999	51.589776999999998	1-й Панфилова проезд	0103000020E61000000100000005000000508D976E12F746406C770FD07DCB4940508D976E12F74640F06B2409C2CB49402FDE8FDB2FF74640F06B2409C2CB49402FDE8FDB2FF746406C770FD07DCB4940508D976E12F746406C770FD07DCB4940
30788	29	45.808959000000002	46.199924000000003	51.686098999999999	51.388981000000001	1-й Нефтяной проезд	0103000020E610000001000000050000000667F0F78BE74640F8E12021CAB149400667F0F78BE74640BE688F17D2D74940BFD7101C97194740BE688F17D2D74940BFD7101C97194740F8E12021CAB149400667F0F78BE74640F8E12021CAB14940
31652	29	45.985218000000003	45.987886000000003	51.615057	51.602404999999997	 Перспективная	0103000020E610000001000000050000001CB7989F1BFE464033F9669B1BCD49401CB7989F1BFE464083161230BACE49409016670C73FE464083161230BACE49409016670C73FE464033F9669B1BCD49401CB7989F1BFE464033F9669B1BCD4940
67166	29	45.990651999999997	46.015777999999997	51.546390000000002	51.522871000000002	 Астраханская	0103000020E61000000100000005000000C6DB4AAFCDFE46406F83DA6FEDC24940C6DB4AAFCDFE4640446E861BF0C5494086FF740305024740446E861BF0C5494086FF7403050247406F83DA6FEDC24940C6DB4AAFCDFE46406F83DA6FEDC24940
30523	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Яблочкова	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
31481	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Чкалова	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30829	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Советская	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30902	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Сердобский тупик	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
31355	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Пугачевская	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30731	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Переулок Ветеринарный	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30305	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	М. Горького	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
31522	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Котовского	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30897	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	К. Маркса	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
31471	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Ильича	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
31053	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Зои Космодемьянской	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30732	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Железнодорожная	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
31345	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Горная	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30312	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	Алексея Громова	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30536	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	60 лет Октября	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30527	23458	43.743301000000002	43.829458000000002	52.288997999999999	52.232785	22 Партсъезда	0103000020E61000000100000005000000C40AB77C24DF4540EBFF1CE6CB1D4A40C40AB77C24DF4540014EEFE2FD244A40EAB303AE2BEA4540014EEFE2FD244A40EAB303AE2BEA4540EBFF1CE6CB1D4A40C40AB77C24DF4540EBFF1CE6CB1D4A40
30668	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Урицкого	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
16806	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Топорковская	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30642	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Рев.Проспект	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30452	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Пушкинская	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30701	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	М.Горького	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30787	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Кутякова	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30904	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Коммунистическая	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30651	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Карьер МВД-4	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
31033	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Интернациональная	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30410	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Железнодорожная	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
30669	2278	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Горького	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
31490	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Шамаева	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
30938	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Чернышевского	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
31096	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Спартака	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
31321	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Советская	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
31441	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Радищева	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
30597	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Московская	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
30759	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Железнодорожная	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
31444	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	Гоголя	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
31432	19941	45.349919999999997	45.415523999999998	52.333750000000002	52.278937999999997	25 лет Октября	0103000020E61000000100000005000000B01BB62DCAAC46404ACE893DB4234A40B01BB62DCAAC46401F85EB51B82A4A40FF59F3E32FB546401F85EB51B82A4A40FF59F3E32FB546404ACE893DB4234A40B01BB62DCAAC46404ACE893DB4234A40
30690	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	проспект Строителей	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
31320	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	пр. Ленина	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
31298	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	Строителей	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
31389	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	Рабочая	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
31043	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	Победы	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
30368	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	Ленина	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
30922	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	Интернациональная площадь	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
67110	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	Загородная роща	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
31162	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	6-я линия	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
31434	2574	46.721234000000003	46.77993	51.723967999999999	51.693457000000002	10-я линия	0103000020E61000000100000005000000B3614D65515C47405517F032C3D84940B3614D65515C4740DEACC1FBAADC4940AB9509BFD4634740DEACC1FBAADC4940AB9509BFD46347405517F032C3D84940B3614D65515C47405517F032C3D84940
67059	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	Танцорова	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
31106	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	Почтовая	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
30778	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	Луначарского	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
30236	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	Коммунистическая	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
30399	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	Кирова	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
30555	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	Захарова	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
30851	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	Богдана Хмельницкого	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
30525	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	5 микрорайон	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
31120	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	3-й Фабричный переулок	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
30415	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	1 микрорайон	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
31388	23	45.667985999999999	45.734623999999997	51.046968999999997	51.004689999999997	1 Мая	0103000020E61000000100000005000000CA17B49080D54640224F92AE99804940CA17B49080D546408176871403864940A86DC32808DE46408176871403864940A86DC32808DE4640224F92AE99804940CA17B49080D54640224F92AE99804940
31143	32022	45.834417000000002	45.843516999999999	51.474983000000002	51.469310999999998	Центральная	0103000020E61000000100000005000000FC1C1F2DCEEA46409753026212BC4940FC1C1F2DCEEA4640F793313ECCBC49405D4F745DF8EB4640F793313ECCBC49405D4F745DF8EB46409753026212BC4940FC1C1F2DCEEA46409753026212BC4940
30662	53162	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	Советская	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
30960	53183	42.501936999999998	50.833129	52.818674000000001	49.801195999999997	60 лет Победы	0103000020E6100000010000000500000080D3BB783F404540CFD72C978DE6484080D3BB783F404540F20A444FCA684A40B22C98F8A36A4940F20A444FCA684A40B22C98F8A36A4940CFD72C978DE6484080D3BB783F404540CFD72C978DE64840
30955	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	улица Чернышевского	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31272	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	поселок завода Красный Октябрь	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30385	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	площадь Юности	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30622	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	площадь Свободы	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30873	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	площадь Равенства	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31119	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Школьная	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31399	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Чехова	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31278	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Цементников	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31416	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Струина	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30774	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Свердлова	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31275	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Саратовская	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30617	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Революционная	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30181	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Пятницкого	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31396	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Пугачева	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31282	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Одесская	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30957	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Некрасова	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31109	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Льва Толстого	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30606	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Краснооктябрьская	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30790	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Красногвардейская	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31139	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Комсомольская	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30747	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Коммунарная	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
31271	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Володарского	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30601	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Волжская	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30626	3738	47.221874	47.500746999999997	52.089969000000004	51.977552000000003	Волгоградская	0103000020E6100000010000000500000096EA025E669C4740D811876C20FD494096EA025E669C4740B153AC1A840B4A40F9484A7A18C04740B153AC1A840B4A40F9484A7A18C04740D811876C20FD494096EA025E669C4740D811876C20FD4940
30498	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	переулок Вокзальный	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30711	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	пер. Школьный	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
31219	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Юбилейная	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
31223	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Шоссейная	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
31135	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Фестивальная	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30411	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Титова	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30891	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Строителей	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30703	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Софинского	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30217	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Пушкина	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30798	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Пугачевская	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30179	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Нефтяная	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
31405	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Нарадноя	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30424	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Менделеева	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30213	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Ленина	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30886	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Красина	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30797	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Коммунистическая	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30296	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	К. Маркса	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30287	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Депутатская	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
31167	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Володарского	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
67041	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Вокзальный переулок	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
31377	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	Балашов-3	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
31218	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	50 лет ВЛКСМ	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
30299	4360	43.118001999999997	43.225951999999999	51.565766000000004	51.518954000000001	50  лет ВЛКСМ	0103000020E61000000100000005000000696E85B01A8F45406F10AD156DC24940696E85B01A8F4540299831056BC849409F3BC1FEEB9C4540299831056BC849409F3BC1FEEB9C45406F10AD156DC24940696E85B01A8F45406F10AD156DC24940
9895	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Шевченко	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30903	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Чапаева	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30284	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Факел Социализма	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30656	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Трнавская	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30840	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Титова	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30242	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Степная	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30396	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Свердлова	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30407	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Саратовское Шоссе	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
31004	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Редкова	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30378	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Привокзальная	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30618	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Пионерская	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30434	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Набережная Леонова	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30221	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Минская	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30814	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Менделеева	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30454	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Красноармейская	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30351	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Комсомольская	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30602	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Коммунистическая	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30653	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Комарова	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30827	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Заречная	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30836	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Волжская	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30983	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Вокзальная	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30992	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Бульвар Роз	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30611	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	Братьев Захаровых	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30195	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	30 лет Победы	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30781	6127	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	30 Лет Победы	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30314	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Школьная	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
30896	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Чапаева	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
30310	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Советская	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
31049	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Локомотивная	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
30521	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Ленина	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
30900	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	К. Маркса	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
31215	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Грибоедова	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
31216	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Гоголя	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
30526	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Гагарина	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
71742	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	Верхне-Красавская	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
30515	6079	44.947062000000003	45.044457000000001	51.906165000000001	51.843634999999999	30 лет Победы	0103000020E6100000010000000500000066A4DE533979464067614F3BFCEB494066A4DE5339794640D2E3F736FDF34940058A58C4B0854640D2E3F736FDF34940058A58C4B085464067614F3BFCEB494066A4DE533979464067614F3BFCEB4940
30694	53168	43.463304999999998	43.553711999999997	51.951937999999998	51.907364999999999	Ленина	0103000020E61000000100000005000000618907944DBB45407C444C8924F44940618907944DBB4540EAE8B81AD9F949408DB3E908E0C64540EAE8B81AD9F949408DB3E908E0C645407C444C8924F44940618907944DBB45407C444C8924F44940
31417	53211	45.811033999999999	45.865580000000001	51.452711999999998	51.437139999999999	Привокзальная	0103000020E61000000100000005000000D7F84CF6CFE7464000E31934F4B74940D7F84CF6CFE74640DD408177F2B949402D095053CBEE4640DD408177F2B949402D095053CBEE464000E31934F4B74940D7F84CF6CFE7464000E31934F4B74940
31027	53188	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	3-й квартал 	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31277	53202	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Молодежная	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30448	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Энгельс-19	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30228	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Энгельс-1	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30229	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Тельмана	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30231	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Степная	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30514	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Свердлова	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30376	53136	45.982028999999997	46.040446000000003	51.552103000000002	51.508707999999999	Садовая	0103000020E610000001000000050000009E5C5320B3FD4640569BFF571DC149409E5C5320B3FD46400283A44FABC6494084A0A3552D0547400283A44FABC6494084A0A3552D054740569BFF571DC149409E5C5320B3FD4640569BFF571DC14940
30352	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Рабочая	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30183	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Полтавская	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30446	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Минская	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31255	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Колотилова	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31103	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Гагарина	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31443	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	2-Микрорайон	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30738	53136	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	 1-й Микрорайон	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31145	53192	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	1-й квартал 	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31068	12723	46.625383999999997	46.658720000000002	51.287058000000002	51.274326000000002	Рабочая	0103000020E6100000010000000500000088B839950C504740A438471D1DA3494088B839950C50474010070951BEA449404E9CDCEF5054474010070951BEA449404E9CDCEF50544740A438471D1DA3494088B839950C504740A438471D1DA34940
31440	12486	46.477880999999996	46.491022999999998	51.133513999999998	51.122017	Школьная	0103000020E610000001000000050000009C3061342B3D47402C47C8409E8F49409C3061342B3D474071C79BFC16914940BA4A77D7D93E474071C79BFC16914940BA4A77D7D93E47402C47C8409E8F49409C3061342B3D47402C47C8409E8F4940
30995	11056	45.905070000000002	45.931426000000002	51.263173000000002	51.240566999999999	Революционная	0103000020E610000001000000050000009D4B7155D9F3464098BF42E6CA9E49409D4B7155D9F34640591822A7AFA14940725298F738F74640591822A7AFA14940725298F738F7464098BF42E6CA9E49409D4B7155D9F3464098BF42E6CA9E4940
30700	12727	46.585382000000003	46.619311000000003	51.305683000000002	51.293050999999998	Школьная	0103000020E6100000010000000500000063D520CCED4A4740B187F6B182A5494063D520CCED4A4740BAF8DB9E20A74940CB863595454F4740BAF8DB9E20A74940CB863595454F4740B187F6B182A5494063D520CCED4A4740B187F6B182A54940
30280	10965	45.953130000000002	45.978749999999998	51.311565999999999	51.295248000000001	Центральная	0103000020E61000000100000005000000126BF12900FA4640CE1ABCAFCAA54940126BF12900FA4640D4450A65E1A74940E17A14AE47FD4640D4450A65E1A74940E17A14AE47FD4640CE1ABCAFCAA54940126BF12900FA4640CE1ABCAFCAA54940
30459	11230	45.941937000000003	45.958511000000001	51.127890000000001	51.112772999999997	Первомайская	0103000020E6100000010000000500000039F2406491F84640976F7D586F8E494039F2406491F8464023BE13B35E9049409AED0A7DB0FA464023BE13B35E9049409AED0A7DB0FA4640976F7D586F8E494039F2406491F84640976F7D586F8E4940
30470	11607	46.485928999999999	46.512466000000003	51.569398999999997	51.554124999999999	Центральная 	0103000020E61000000100000005000000C896E5EB323E4740B0726891EDC64940C896E5EB323E474003B00111E2C84940EE27637C9841474003B00111E2C84940EE27637C98414740B0726891EDC64940C896E5EB323E4740B0726891EDC64940
31012	12009	46.214153000000003	46.236530000000002	51.379368999999997	51.366948999999998	Советская	0103000020E610000001000000050000008FAB915D691B47406326512FF8AE49408FAB915D691B4740E00ED4298FB04940EE42739D461E4740E00ED4298FB04940EE42739D461E47406326512FF8AE49408FAB915D691B47406326512FF8AE4940
30331	11050	45.940347000000003	45.953318000000003	51.288612999999998	51.276946000000002	Центральная	0103000020E6100000010000000500000024F25D4A5DF8464007616EF772A3494024F25D4A5DF84640A8195245F1A449401558005306FA4640A8195245F1A449401558005306FA464007616EF772A3494024F25D4A5DF8464007616EF772A34940
31507	53220	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	улица Ленина	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31438	12407	46.475096000000001	46.488193000000003	51.245676000000003	51.233027999999997	Овражная	0103000020E61000000100000005000000EF3A1BF2CF3C4740B1868BDCD39D4940EF3A1BF2CF3C4740C0B4A84F729F49406D91B41B7D3E4740C0B4A84F729F49406D91B41B7D3E4740B1868BDCD39D4940EF3A1BF2CF3C4740B1868BDCD39D4940
31319	11850	46.285138000000003	46.311441000000002	51.398209000000001	51.383102000000001	Школьная	0103000020E61000000100000005000000666CE8667F2447401F84807C09B14940666CE8667F24474087FC3383F8B2494018D1764CDD27474087FC3383F8B2494018D1764CDD2747401F84807C09B14940666CE8667F2447401F84807C09B14940
30264	11463	46.461666000000001	46.488840000000003	51.670589999999997	51.656551	Кирова	0103000020E610000001000000050000006BD619DF173B4740FB93F8DC09D449406BD619DF173B47402783A3E4D5D54940037D224F923E47402783A3E4D5D54940037D224F923E4740FB93F8DC09D449406BD619DF173B4740FB93F8DC09D44940
30863	12257	46.506303000000003	46.527261000000003	51.351892999999997	51.337333000000001	Трактовая	0103000020E61000000100000005000000F06E6589CE404740486E4DBA2DAB4940F06E6589CE4047407D586FD40AAD494067BAD7497D4347407D586FD40AAD494067BAD7497D434740486E4DBA2DAB4940F06E6589CE404740486E4DBA2DAB4940
30850	12001	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	1-й квартал	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
31183	12578	46.420864999999999	46.443987	51.274420999999997	51.263995999999999	Колхозная	0103000020E61000000100000005000000F98381E7DE3547402D23F59ECAA14940F98381E7DE354740F52A323A20A34940B16CE690D4384740F52A323A20A34940B16CE690D43847402D23F59ECAA14940F98381E7DE3547402D23F59ECAA14940
31326	12095	46.273271000000001	46.298622000000002	51.366567000000003	51.356274999999997	Ленина	0103000020E61000000100000005000000FDF84B8BFA224740F2B0506B9AAD4940FDF84B8BFA2247407C65DEAAEBAE4940DDEEE53E392647407C65DEAAEBAE4940DDEEE53E39264740F2B0506B9AAD4940FDF84B8BFA224740F2B0506B9AAD4940
30847	11663	46.606105999999997	46.622248999999996	51.536301999999999	51.517749000000002	Советская	0103000020E6100000010000000500000066F4A3E1944D4740B344679945C2494066F4A3E1944D4740C3633F8BA5C44940FE7BF0DAA54F4740C3633F8BA5C44940FE7BF0DAA54F4740B344679945C2494066F4A3E1944D4740B344679945C24940
31001	11477	46.481805999999999	46.505279000000002	51.619548000000002	51.604810000000001	Ленина	0103000020E610000001000000050000001F82AAD1AB3D47409A25016A6ACD49401F82AAD1AB3D4740AF264F594DCF4940842D76FBAC404740AF264F594DCF4940842D76FBAC4047409A25016A6ACD49401F82AAD1AB3D47409A25016A6ACD4940
30999	11387	46.397579999999998	46.448217999999997	51.639628999999999	51.618200000000002	Мира	0103000020E6100000010000000500000097C5C4E6E33247409031772D21CF494097C5C4E6E33247405E49F25CDFD1494040BD19355F3947405E49F25CDFD1494040BD19355F3947409031772D21CF494097C5C4E6E33247409031772D21CF4940
31089	12333	46.457524999999997	46.478752	51.326557000000001	51.315057000000003	Южная	0103000020E610000001000000050000001B0DE02D903A47401DB0ABC953A849401B0DE02D903A4740D3A3A99ECCA949408272DBBE473D4740D3A3A99ECCA949408272DBBE473D47401DB0ABC953A849401B0DE02D903A47401DB0ABC953A84940
30461	11144	45.908105999999997	45.924249000000003	51.211778000000002	51.194158999999999	Ленина	0103000020E6100000010000000500000093A641D13CF44640AE9CBD33DA98494093A641D13CF446409301A08A1B9B49402C2E8ECA4DF646409301A08A1B9B49402C2E8ECA4DF64640AE9CBD33DA98494093A641D13CF44640AE9CBD33DA984940
31431	11774	46.172130000000003	46.196196	51.439115999999999	51.420051999999998	Школьная	0103000020E610000001000000050000008B54185B08164740484F9143C4B549408B54185B081647403E93FDF334B8494092CD55F31C1947403E93FDF334B8494092CD55F31C194740484F9143C4B549408B54185B08164740484F9143C4B54940
30695	12598	46.368124000000002	46.395288999999998	51.038888	51.016590999999998	Советская	0103000020E61000000100000005000000B56FEEAF1E2F4740373465A71F824940B56FEEAF1E2F47407A1A3048FA844940F9BB77D4983247407A1A3048FA844940F9BB77D498324740373465A71F824940B56FEEAF1E2F4740373465A71F824940
31020	12488	46.483305999999999	46.575474	51.099691999999997	51.075980999999999	Дорожная	0103000020E61000000100000005000000F4FA93F8DC3D4740060FD3BEB9894940F4FA93F8DC3D47401FD61BB5C28C494062D9CC21A94947401FD61BB5C28C494062D9CC21A9494740060FD3BEB9894940F4FA93F8DC3D4740060FD3BEB9894940
31019	12349	46.439801000000003	46.458979999999997	51.258353999999997	51.244588	Советская	0103000020E61000000100000005000000C2DF2F664B3847403D7FDAA84E9F4940C2DF2F664B38474038656EBE11A1494050C24CDBBF3A474038656EBE11A1494050C24CDBBF3A47403D7FDAA84E9F4940C2DF2F664B3847403D7FDAA84E9F4940
31095	2511	46.506734000000002	46.540511000000002	51.634827999999999	51.615588000000002	Ленина	0103000020E61000000100000005000000B9E2E2A8DC404740B0E76B96CBCE4940B9E2E2A8DC404740E44A3D0B42D149406B10E6762F454740E44A3D0B42D149406B10E6762F454740B0E76B96CBCE4940B9E2E2A8DC404740B0E76B96CBCE4940
31133	11855	46.309176999999998	46.323827999999999	51.458077000000003	51.441727	Центральная	0103000020E6100000010000000500000073D6A71C932747404E61A5828AB8494073D6A71C9327474060066344A2BA4940B9C326327329474060066344A2BA4940B9C32632732947404E61A5828AB8494073D6A71C932747404E61A5828AB84940
30839	11331	46.323549999999997	46.357577999999997	51.602258999999997	51.583342000000002	Московская	0103000020E61000000100000005000000764F1E166A2947400E315EF3AACA4940764F1E166A2947405F5CAAD216CD494071E2AB1DC52D47405F5CAAD216CD494071E2AB1DC52D47400E315EF3AACA4940764F1E166A2947400E315EF3AACA4940
30281	12642	46.435453000000003	46.477314999999997	51.005710000000001	50.980176	Центральная	0103000020E61000000100000005000000F9F884ECBC3747407C293C68767D4940F9F884ECBC3747404DA1F31ABB804940F3716DA8183D47404DA1F31ABB804940F3716DA8183D47407C293C68767D4940F9F884ECBC3747407C293C68767D4940
31571	53232	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	Производственная	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
30862	12806	46.398783999999999	46.418591999999997	51.286095000000003	51.274223999999997	Школьная	0103000020E610000001000000050000008315A75A0B3347409FE3A3C519A349408315A75A0B3347404A46CEC29EA44940012F336C943547404A46CEC29EA44940012F336C943547409FE3A3C519A349408315A75A0B3347409FE3A3C519A34940
30672	11183	45.909345999999999	45.948926	51.190496000000003	51.172021999999998	Центральная	0103000020E61000000100000005000000CC5F217365F44640A41820D104964940CC5F217365F446406902452C629849407C293C6876F946406902452C629849407C293C6876F94640A41820D104964940CC5F217365F44640A41820D104964940
30854	12109	46.423065000000001	46.456086999999997	51.342796999999997	51.321519000000002	Чкалова	0103000020E61000000100000005000000878A71FE263647407505DB8827A94940878A71FE263647405D15A8C5E0AB4940BC900E0F613A47405D15A8C5E0AB4940BC900E0F613A47407505DB8827A94940878A71FE263647407505DB8827A94940
31614	53243	47.492176999999998	48.427987999999999	52.818674000000001	52.230798999999998	улица Железнодорожная	0103000020E61000000100000005000000F46BEBA7FFBE4740897956D28A1D4A40F46BEBA7FFBE4740F20A444FCA684A404C8A8F4FC8364840F20A444FCA684A404C8A8F4FC8364840897956D28A1D4A40F46BEBA7FFBE4740897956D28A1D4A40
30311	53150	47.492176999999998	48.427987999999999	52.818674000000001	52.230798999999998	Советская	0103000020E61000000100000005000000F46BEBA7FFBE4740897956D28A1D4A40F46BEBA7FFBE4740F20A444FCA684A404C8A8F4FC8364840F20A444FCA684A404C8A8F4FC8364840897956D28A1D4A40F46BEBA7FFBE4740897956D28A1D4A40
30381	53150	47.492176999999998	48.427987999999999	52.818674000000001	52.230798999999998	Революционная	0103000020E61000000100000005000000F46BEBA7FFBE4740897956D28A1D4A40F46BEBA7FFBE4740F20A444FCA684A404C8A8F4FC8364840F20A444FCA684A404C8A8F4FC8364840897956D28A1D4A40F46BEBA7FFBE4740897956D28A1D4A40
30592	7084	47.877411000000002	47.926450000000003	52.446719999999999	52.427076	имени Ульянина	0103000020E610000001000000050000004913EF004FF047400874266DAA364A404913EF004FF047400C3CF71E2E394A408AB0E1E995F647400C3CF71E2E394A408AB0E1E995F647400874266DAA364A404913EF004FF047400874266DAA364A40
30171	7017	47.854278999999998	47.882361000000003	52.697589000000001	52.672609000000001	Первомайская	0103000020E610000001000000050000006D54A70359ED474065FF3C0D18564A406D54A70359ED47405186AA984A594A4008228B34F1F047405186AA984A594A4008228B34F1F0474065FF3C0D18564A406D54A70359ED474065FF3C0D18564A40
30931	7030	47.839053	47.902932	52.503039000000001	52.483387	Ленина	0103000020E610000001000000050000002B4EB51666EB4740E1270EA0DF3D4A402B4EB51666EB474068CEFA9463404A408541994693F3474068CEFA9463404A408541994693F34740E1270EA0DF3D4A402B4EB51666EB4740E1270EA0DF3D4A40
30578	6548	47.875920000000001	47.914628	52.370479000000003	52.332759000000003	Центральная	0103000020E61000000100000005000000C7F484251EF047408F39CFD8972A4A40C7F484251EF047406A6D1ADB6B2F4A40C100C28712F547406A6D1ADB6B2F4A40C100C28712F547408F39CFD8972A4A40C7F484251EF047408F39CFD8972A4A40
31385	6796	48.206823	48.234931000000003	52.732492000000001	52.711978000000002	Мира	0103000020E61000000100000005000000C287122D791A48405ABC5818225B4A40C287122D791A4840734A404CC25D4A4086E81038121E4840734A404CC25D4A4086E81038121E48405ABC5818225B4A40C287122D791A48405ABC5818225B4A40
31263	6935	47.829827000000002	47.847074999999997	52.609537000000003	52.593165999999997	Космонавтов	0103000020E610000001000000050000003D2B69C537EA4740B08C0DDDEC4B4A403D2B69C537EA4740DA59F44E054E4A402D211FF46CEC4740DA59F44E054E4A402D211FF46CEC4740B08C0DDDEC4B4A403D2B69C537EA4740B08C0DDDEC4B4A40
30167	6931	47.963918999999997	47.99783	52.597673999999998	52.567267000000001	Николаева	0103000020E610000001000000050000001B7FA2B261FB4740CE8C7E349C484A401B7FA2B261FB4740B2D5E594804C4A40DD7BB8E4B8FF4740B2D5E594804C4A40DD7BB8E4B8FF4740CE8C7E349C484A401B7FA2B261FB4740CE8C7E349C484A40
31172	7132	47.792456999999999	47.813819000000002	52.536662999999997	52.521782999999999	Молодежная	0103000020E610000001000000050000003E3E213B6FE54740EC4D0CC9C9424A403E3E213B6FE5474093FC885FB1444A4085EE92382BE8474093FC885FB1444A4085EE92382BE84740EC4D0CC9C9424A403E3E213B6FE54740EC4D0CC9C9424A40
31260	6878	47.596345999999997	47.620564999999999	52.576937999999998	52.555540000000001	Советская	0103000020E61000000100000005000000DA8CD31055CC474057CF49EF1B474A40DA8CD31055CC4740EAE8B81AD9494A40680586AC6ECF4740EAE8B81AD9494A40680586AC6ECF474057CF49EF1B474A40DA8CD31055CC474057CF49EF1B474A40
30158	6705	48.147461999999997	48.226649000000002	52.720776999999998	52.682360000000003	Степная	0103000020E610000001000000050000008DB3E908E01248409E0C8E9257574A408DB3E908E0124840C05AB56B425C4A40E7559DD5021D4840C05AB56B425C4A40E7559DD5021D48409E0C8E9257574A408DB3E908E01248409E0C8E9257574A40
31380	6552	48.085729999999998	48.117674000000001	52.700989	52.687753999999998	Центральная	0103000020E610000001000000050000009E245D33F90A4840BAD8B45208584A409E245D33F90A484089EDEE01BA594A4075CB0EF10F0F484089EDEE01BA594A4075CB0EF10F0F4840BAD8B45208584A409E245D33F90A4840BAD8B45208584A40
30945	6795	47.698368000000002	47.735737999999998	52.324888999999999	52.297562999999997	60 лет Октября	0103000020E610000001000000050000005649641F64D94740F4BF5C8B16264A405649641F64D9474042EA76F695294A405436ACA92CDE474042EA76F695294A405436ACA92CDE4740F4BF5C8B16264A405649641F64D94740F4BF5C8B16264A40
30940	6497	48.004953999999998	48.049663000000002	52.331564999999998	52.285786999999999	Чапаева	0103000020E6100000010000000500000000FE2955A20048409C4F1DAB94244A4000FE2955A2004840C6BFCFB8702A4A401F69705B5B064840C6BFCFB8702A4A401F69705B5B0648409C4F1DAB94244A4000FE2955A20048409C4F1DAB94244A40
30599	7221	47.644342999999999	47.679834999999997	52.460095000000003	52.447482999999998	Молодежная	0103000020E610000001000000050000000934D8D479D247400B42791F47394A400934D8D479D24740CD069964E43A4A408CD651D504D74740CD069964E43A4A408CD651D504D747400B42791F47394A400934D8D479D247400B42791F47394A40
31373	1454	47.493696	47.520958999999998	51.371318000000002	51.347056000000002	Молодежная	0103000020E610000001000000050000004015376E31BF4740B7F0BC546CAC49404015376E31BF47404435255987AF494047C7D5C8AEC247404435255987AF494047C7D5C8AEC24740B7F0BC546CAC49404015376E31BF4740B7F0BC546CAC4940
30835	1580	47.112234999999998	47.149918999999997	51.370733000000001	51.353220999999998	Победы 	0103000020E61000000100000005000000B83B6BB75D8E474055A1815836AD4940B83B6BB75D8E47402446CF2D74AF49404606B98B309347402446CF2D74AF49404606B98B3093474055A1815836AD4940B83B6BB75D8E474055A1815836AD4940
30293	5870	47.774931000000002	47.796221000000003	51.385800000000003	51.367652	Советская	0103000020E610000001000000050000000BD462F030E347408D2782380FAF49400BD462F030E34740FE65F7E461B14940B8B1D991EAE54740FE65F7E461B14940B8B1D991EAE547408D2782380FAF49400BD462F030E347408D2782380FAF4940
30554	53159	47.927672000000001	47.948531000000003	51.180903999999998	51.170102	Набережная	0103000020E610000001000000050000001CB5C2F4BDF64740FA7DFFE6C59549401CB5C2F4BDF6474098DBBDDC27974940001FBC7669F9474098DBBDDC27974940001FBC7669F94740FA7DFFE6C59549401CB5C2F4BDF64740FA7DFFE6C5954940
30557	5430	47.591082	47.619675000000001	51.192273999999998	51.172879999999999	Центральная	0103000020E610000001000000050000008CA03193A8CB4740F5108DEE209649408CA03193A8CB474080EF366F9C9849400C93A98251CF474080EF366F9C9849400C93A98251CF4740F5108DEE209649408CA03193A8CB4740F5108DEE20964940
30765	6195	47.358544000000002	47.390343999999999	51.395252999999997	51.372280000000003	Советская	0103000020E61000000100000005000000A91611C5E4AD47403A7AFCDEA6AF4940A91611C5E4AD4740AC527AA697B249404C18CDCAF6B14740AC527AA697B249404C18CDCAF6B147403A7AFCDEA6AF4940A91611C5E4AD47403A7AFCDEA6AF4940
30544	5865	47.766675999999997	47.789053000000003	51.297747999999999	51.287711000000002	Рабочая	0103000020E6100000010000000500000065506D7022E2474088D9CBB6D3A4494065506D7022E247408639419B1CA64940C5E74EB0FFE447408639419B1CA64940C5E74EB0FFE4474088D9CBB6D3A4494065506D7022E2474088D9CBB6D3A44940
31367	5977	47.593831000000002	47.637614999999997	51.470809000000003	51.453924000000001	Октябрьская	0103000020E61000000100000005000000ED2C7AA702CC47404C6F7F2E1ABA4940ED2C7AA702CC4740CCD4247843BC494032384A5E9DD14740CCD4247843BC494032384A5E9DD147404C6F7F2E1ABA4940ED2C7AA702CC47404C6F7F2E1ABA4940
30979	5489	47.666549000000003	47.689124	51.196095	51.184415999999999	Центральная	0103000020E610000001000000050000003C17467A51D54740F86D88F19A9749403C17467A51D547405EF415A419994940C171193735D847405EF415A419994940C171193735D84740F86D88F19A9749403C17467A51D54740F86D88F19A974940
30328	5666	47.831085000000002	47.853667999999999	51.301031000000002	51.277301000000001	Степная	0103000020E610000001000000050000001C9947FE60EA4740F51263997EA349401C9947FE60EA4740850A0E2F88A6494024D236FE44ED4740850A0E2F88A6494024D236FE44ED4740F51263997EA349401C9947FE60EA4740F51263997EA34940
30532	829	47.483625000000004	47.531711999999999	51.250912999999997	51.225763000000001	Энгельса	0103000020E6100000010000000500000096438B6CE7BD4740CCD24ECDE59C494096438B6CE7BD47401492CCEA1DA04940047289230FC447401492CCEA1DA04940047289230FC44740CCD24ECDE59C494096438B6CE7BD4740CCD24ECDE59C4940
31212	829	47.483625000000004	47.531711999999999	51.250912999999997	51.225763000000001	Советская	0103000020E6100000010000000500000096438B6CE7BD4740CCD24ECDE59C494096438B6CE7BD47401492CCEA1DA04940047289230FC447401492CCEA1DA04940047289230FC44740CCD24ECDE59C494096438B6CE7BD4740CCD24ECDE59C4940
31234	829	47.483625000000004	47.531711999999999	51.250912999999997	51.225763000000001	Сельхозтеник	0103000020E6100000010000000500000096438B6CE7BD4740CCD24ECDE59C494096438B6CE7BD47401492CCEA1DA04940047289230FC447401492CCEA1DA04940047289230FC44740CCD24ECDE59C494096438B6CE7BD4740CCD24ECDE59C4940
30243	829	47.483625000000004	47.531711999999999	51.250912999999997	51.225763000000001	Победы	0103000020E6100000010000000500000096438B6CE7BD4740CCD24ECDE59C494096438B6CE7BD47401492CCEA1DA04940047289230FC447401492CCEA1DA04940047289230FC44740CCD24ECDE59C494096438B6CE7BD4740CCD24ECDE59C4940
31226	829	47.483625000000004	47.531711999999999	51.250912999999997	51.225763000000001	Восточная	0103000020E6100000010000000500000096438B6CE7BD4740CCD24ECDE59C494096438B6CE7BD47401492CCEA1DA04940047289230FC447401492CCEA1DA04940047289230FC44740CCD24ECDE59C494096438B6CE7BD4740CCD24ECDE59C4940
31238	1352	47.536760999999998	47.567042999999998	51.164816000000002	51.153151000000001	Новая	0103000020E6100000010000000500000056629E95B4C44740C32CB4739A93494056629E95B4C44740C4EDD0B0189549407E3672DD94C84740C4EDD0B0189549407E3672DD94C84740C32CB4739A93494056629E95B4C44740C32CB4739A934940
30834	6282	47.158498000000002	47.180624000000002	51.379223000000003	51.362703000000003	Школьная	0103000020E610000001000000050000009F3D97A9499447409F94490D6DAE49409F3D97A9499447400D7217618AB04940B56FEEAF1E9747400D7217618AB04940B56FEEAF1E9747409F94490D6DAE49409F3D97A9499447409F94490D6DAE4940
31067	5598	47.719298000000002	47.747397999999997	51.230817000000002	51.217030999999999	Победы	0103000020E61000000100000005000000030AF5F411DC4740ED9BFBABC79B4940030AF5F411DC4740302E55698B9D4940438CD7BCAADF4740302E55698B9D4940438CD7BCAADF4740ED9BFBABC79B4940030AF5F411DC4740ED9BFBABC79B4940
30324	887	47.491898999999997	47.522478	51.168086000000002	51.158014999999999	Центральная	0103000020E61000000100000005000000B1F7E28BF6BE474083A3E4D539944940B1F7E28BF6BE47402E7590D7839549409370218FE0C247402E7590D7839549409370218FE0C2474083A3E4D539944940B1F7E28BF6BE474083A3E4D539944940
30576	6338	47.308041000000003	47.337856000000002	51.239626000000001	51.223709999999997	 Мирная	0103000020E61000000100000005000000E06932E36DA74740E2E47E87A29C4940E06932E36DA74740BAA29410AC9E4940F2608BDD3EAB4740BAA29410AC9E4940F2608BDD3EAB4740E2E47E87A29C4940E06932E36DA74740E2E47E87A29C4940
31314	6399	47.403602999999997	47.432744999999997	51.152416000000002	51.12923	Иванова А. А. 	0103000020E61000000100000005000000A3C85A43A9B34740BFD4CF9B8A904940A3C85A43A9B347408EB1135E82934940F6402B3064B747408EB1135E82934940F6402B3064B74740BFD4CF9B8A904940A3C85A43A9B34740BFD4CF9B8A904940
30335	1417	47.741351999999999	47.776755000000001	51.029502999999998	51.005994000000001	Победы	0103000020E610000001000000050000007F69519FE4DE474072FC5069C48049407F69519FE4DE474023111AC1C6834940930035B56CE3474023111AC1C6834940930035B56CE3474072FC5069C48049407F69519FE4DE474072FC5069C4804940
67133	758	43.201760999999998	43.244439999999997	51.93506	51.908042999999999	Школьная	0103000020E61000000100000005000000DB4DF04DD39945404D2EC6C03AF44940DB4DF04DD39945401DE6CB0BB0F74940C8EA56CF499F45401DE6CB0BB0F74940C8EA56CF499F45404D2EC6C03AF44940DB4DF04DD39945404D2EC6C03AF44940
67132	4962	43.021926999999998	43.061031	51.966872000000002	51.939680000000003	40 лет Победы	0103000020E610000001000000050000001FF30181CE824540475A2A6F47F849401FF30181CE82454085B53176C2FB4940668522DDCF87454085B53176C2FB4940668522DDCF874540475A2A6F47F849401FF30181CE824540475A2A6F47F84940
31048	4153	43.247683000000002	43.295904	52.007719999999999	51.959946000000002	Ульяны Громовой	0103000020E6100000010000000500000039639813B49F454088F6B182DFFA494039639813B49F454037C30DF8FC004A40B760A92EE0A5454037C30DF8FC004A40B760A92EE0A5454088F6B182DFFA494039639813B49F454088F6B182DFFA4940
30666	4153	43.247683000000002	43.295904	52.007719999999999	51.959946000000002	Свердлова	0103000020E6100000010000000500000039639813B49F454088F6B182DFFA494039639813B49F454037C30DF8FC004A40B760A92EE0A5454037C30DF8FC004A40B760A92EE0A5454088F6B182DFFA494039639813B49F454088F6B182DFFA4940
30301	4153	43.247683000000002	43.295904	52.007719999999999	51.959946000000002	Ленина	0103000020E6100000010000000500000039639813B49F454088F6B182DFFA494039639813B49F454037C30DF8FC004A40B760A92EE0A5454037C30DF8FC004A40B760A92EE0A5454088F6B182DFFA494039639813B49F454088F6B182DFFA4940
9759	4362	43.263457000000002	43.297682999999999	52.053891999999998	52.021045999999998	Центральная	0103000020E610000001000000050000007E737FF5B8A1454016DBA4A2B1024A407E737FF5B8A145400DC2DCEEE5064A409FC9FE791AA645400DC2DCEEE5064A409FC9FE791AA6454016DBA4A2B1024A407E737FF5B8A1454016DBA4A2B1024A40
31137	4958	43.079805	43.112253000000003	52.1188	52.099938999999999	Мира	0103000020E610000001000000050000005587DC0C378A4540274C18CDCA0C4A405587DC0C378A4540E561A1D6340F4A405FF0694E5E8E4540E561A1D6340F4A405FF0694E5E8E4540274C18CDCA0C4A405587DC0C378A4540274C18CDCA0C4A40
30978	4911	42.936433999999998	42.975330999999997	52.126868000000002	52.107689000000001	Центральная	0103000020E61000000100000005000000656EBE11DD774540C991CEC0C80D4A40656EBE11DD7745405874EB353D104A4032E36DA5D77C45405874EB353D104A4032E36DA5D77C4540C991CEC0C80D4A40656EBE11DD774540C991CEC0C80D4A40
31350	4852	42.939515	43.016573000000001	52.238742000000002	52.222889000000002	Советская	0103000020E61000000100000005000000FC8C0B0742784540AFD172A0871C4A40FC8C0B074278454040170D198F1E4A40917F66101F82454040170D198F1E4A40917F66101F824540AFD172A0871C4A40FC8C0B0742784540AFD172A0871C4A40
31467	4710	43.242113000000003	43.272520999999998	52.229078000000001	52.194749000000002	Центральная	0103000020E61000000100000005000000DE770C8FFD9E4540E0F60489ED184A40DE770C8FFD9E4540D61D8B6D521D4A40923CD7F7E1A24540D61D8B6D521D4A40923CD7F7E1A24540E0F60489ED184A40DE770C8FFD9E4540E0F60489ED184A40
30728	4702	42.768673999999997	42.788778000000001	52.127370999999997	52.111007999999998	Молодежная	0103000020E610000001000000050000008BA4DDE86362454014CC9882350E4A408BA4DDE863624540BABA63B14D104A40F3E670ADF6644540BABA63B14D104A40F3E670ADF664454014CC9882350E4A408BA4DDE86362454014CC9882350E4A40
31456	4594	42.857643000000003	42.878906000000001	52.046475999999998	52.030825999999998	Горная	0103000020E610000001000000050000005952EE3EC76D4540E9EE3A1BF2034A405952EE3EC76D45404206F2ECF2054A400C21E7FD7F7045404206F2ECF2054A400C21E7FD7F704540E9EE3A1BF2034A405952EE3EC76D4540E9EE3A1BF2034A40
9856	4587	43.161669000000003	43.188223000000001	52.020591000000003	52.007277000000002	Ленина	0103000020E6100000010000000500000076E3DD91B1944540AA81E673EE004A4076E3DD91B1944540C5CBD3B9A2024A4071ADF6B017984540C5CBD3B9A2024A4071ADF6B017984540AA81E673EE004A4076E3DD91B1944540AA81E673EE004A40
9920	4522	43.043891000000002	43.066716999999997	52.235630999999998	52.223474000000003	Советская	0103000020E610000001000000050000005CCB64389E854540CFC0C8CB9A1C4A405CCB64389E8545403E761728291E4A402A8BC22E8A8845403E761728291E4A402A8BC22E8A884540CFC0C8CB9A1C4A405CCB64389E854540CFC0C8CB9A1C4A40
31466	4435	43.167337000000003	43.194232999999997	52.157167000000001	52.137580999999997	Школьная	0103000020E6100000010000000500000094347F4C6B95454086C613419C114A4094347F4C6B95454056815A0C1E144A40E8667FA0DC98454056815A0C1E144A40E8667FA0DC98454086C613419C114A4094347F4C6B95454086C613419C114A40
31451	3983	45.583410000000001	45.623583000000004	51.979182999999999	51.964081	Советская	0103000020E610000001000000050000006614CB2DADCA4640F5D8960167FB49406614CB2DADCA46404BE658DE55FD4940B9AB5791D1CF46404BE658DE55FD4940B9AB5791D1CF4640F5D8960167FB49406614CB2DADCA4640F5D8960167FB4940
31195	3892	45.765391000000001	45.789707999999997	51.713869000000003	51.696846000000001	Московская	0103000020E610000001000000050000008DD31055F8E14640992CEE3F32D949408DD31055F8E146406A50340F60DB4940DDB1D82615E546406A50340F60DB4940DDB1D82615E54640992CEE3F32D949408DD31055F8E14640992CEE3F32D94940
30332	3794	45.568416999999997	45.643552	51.697342999999996	51.658696999999997	Школьная	0103000020E61000000100000005000000C6BE64E3C1C84640957CEC2E50D44940C6BE64E3C1C84640198C118942D9494040A374E95FD24640198C118942D9494040A374E95FD24640957CEC2E50D44940C6BE64E3C1C84640957CEC2E50D44940
31338	3794	45.568416999999997	45.643552	51.697342999999996	51.658696999999997	Советская	0103000020E61000000100000005000000C6BE64E3C1C84640957CEC2E50D44940C6BE64E3C1C84640198C118942D9494040A374E95FD24640198C118942D9494040A374E95FD24640957CEC2E50D44940C6BE64E3C1C84640957CEC2E50D44940
31600	53184	44.908901	46.040562999999999	52.061445999999997	51.544210999999997	Школьная	0103000020E610000001000000050000009E2633DE56744640CD8FBFB4A8C549409E2633DE56744640293C6876DD074A40BD361B2B31054740293C6876DD074A40BD361B2B31054740CD8FBFB4A8C549409E2633DE56744640CD8FBFB4A8C54940
30963	53184	44.908901	46.040562999999999	52.061445999999997	51.544210999999997	Свободный переулок	0103000020E610000001000000050000009E2633DE56744640CD8FBFB4A8C549409E2633DE56744640293C6876DD074A40BD361B2B31054740293C6876DD074A40BD361B2B31054740CD8FBFB4A8C549409E2633DE56744640CD8FBFB4A8C54940
30893	3275	45.776511999999997	45.801225000000002	52.023888999999997	51.982495	Юбилейная	0103000020E61000000100000005000000CC79C6BE64E34640E4BD6A65C2FD4940CC79C6BE64E34640F8DD74CB0E034A406ADE718A8EE64640F8DD74CB0E034A406ADE718A8EE64640E4BD6A65C2FD4940CC79C6BE64E34640E4BD6A65C2FD4940
31136	2922	45.455939000000001	45.499093999999999	51.754525000000001	51.737985999999999	Школьная	0103000020E6100000010000000500000048FC8A355CBA4640F373435376DE494048FC8A355CBA4640D881734694E049409ED0EB4FE2BF4640D881734694E049409ED0EB4FE2BF4640F373435376DE494048FC8A355CBA4640F373435376DE4940
30865	3439	45.305506999999999	45.322035999999997	51.765897000000002	51.755845999999998	Центральная	0103000020E610000001000000050000007BD976DA1AA74640FD67CD8FBFE049407BD976DA1AA74640618DB3E908E249403C11C47938A94640618DB3E908E249403C11C47938A94640FD67CD8FBFE049407BD976DA1AA74640FD67CD8FBFE04940
30421	3497	45.307716999999997	45.319045000000003	51.789456999999999	51.776513999999999	Центральная	0103000020E610000001000000050000002CB6494563A746406D718DCF64E349402CB6494563A74640944C4EED0CE54940E6797077D6A84640944C4EED0CE54940E6797077D6A846406D718DCF64E349402CB6494563A746406D718DCF64E34940
30366	2616	45.586410000000001	45.612264000000003	51.868510999999998	51.852685999999999	Центральная	0103000020E6100000010000000500000010069E7B0FCB4640E7E099D024ED494010069E7B0FCB4640AE9B525E2BEF49405342B0AA5ECE4640AE9B525E2BEF49405342B0AA5ECE4640E7E099D024ED494010069E7B0FCB4640E7E099D024ED4940
30384	3315	45.435169999999999	45.473959000000001	51.643613999999999	51.631759000000002	Уханова	0103000020E61000000100000005000000A4198BA6B3B7464012FA997ADDD04940A4198BA6B3B74640B69F8CF161D249408B5242B0AABC4640B69F8CF161D249408B5242B0AABC464012FA997ADDD04940A4198BA6B3B7464012FA997ADDD04940
30691	2731	45.842196999999999	45.867941999999999	51.798425000000002	51.780754000000002	Дорожная	0103000020E6100000010000000500000008E57D1CCDEB4640501C40BFEFE3494008E57D1CCDEB464087A757CA32E64940946934B918EF464087A757CA32E64940946934B918EF4640501C40BFEFE3494008E57D1CCDEB4640501C40BFEFE34940
30696	3150	45.787759000000001	45.835576000000003	51.858972000000001	51.836289000000001	Октябрьская	0103000020E6100000010000000500000099107349D5E44640958098840BEB494099107349D5E44640011764CBF2ED494048A98427F4EA4640011764CBF2ED494048A98427F4EA4640958098840BEB494099107349D5E44640958098840BEB4940
30430	832	45.865606999999997	45.885854999999999	51.717429000000003	51.705894000000001	Дорожная	0103000020E610000001000000050000002618CE35CCEE4640A8380EBC5ADA49402618CE35CCEE4640DB19A6B6D4DB4940C1FF56B263F14640DB19A6B6D4DB4940C1FF56B263F14640A8380EBC5ADA49402618CE35CCEE4640A8380EBC5ADA4940
31435	2851	45.499093999999999	45.511994000000001	51.799109999999999	51.784187000000003	Центральная	0103000020E610000001000000050000009ED0EB4FE2BF46406479573D60E449409ED0EB4FE2BF46400AF4893C49E64940C6DFF60489C146400AF4893C49E64940C6DFF60489C146406479573D60E449409ED0EB4FE2BF46406479573D60E44940
31378	3706	45.681677000000001	45.777769999999997	51.653036	51.600468999999997	Школьная	0103000020E61000000100000005000000BBB7223141D7464083A10E2BDCCC4940BBB7223141D746402A8E03AF96D34940ABE7A4F78DE346402A8E03AF96D34940ABE7A4F78DE3464083A10E2BDCCC4940BBB7223141D7464083A10E2BDCCC4940
30500	3706	45.681677000000001	45.777769999999997	51.653036	51.600468999999997	Пономарева	0103000020E61000000100000005000000BBB7223141D7464083A10E2BDCCC4940BBB7223141D746402A8E03AF96D34940ABE7A4F78DE346402A8E03AF96D34940ABE7A4F78DE3464083A10E2BDCCC4940BBB7223141D7464083A10E2BDCCC4940
30692	3074	45.280318999999999	45.297072	51.592374	51.576016000000003	Мира	0103000020E6100000010000000500000045B9347EE1A3464083FC6CE4BAC9494045B9347EE1A34640178046E9D2CB494056478E7406A64640178046E9D2CB494056478E7406A6464083FC6CE4BAC9494045B9347EE1A3464083FC6CE4BAC94940
31235	3381	45.484065000000001	45.524202000000002	51.635717	51.627090000000003	Шигаева	0103000020E61000000100000005000000B21188D7F5BD464007D3307C44D04940B21188D7F5BD46407041B62C5FD14940B83F170D19C346407041B62C5FD14940B83F170D19C3464007D3307C44D04940B21188D7F5BD464007D3307C44D04940
31101	3214	45.742573999999998	45.773322999999998	51.885891000000001	51.864629000000001	Центральная	0103000020E61000000100000005000000116E32AA0CDF46402B16BF29ACEE4940116E32AA0CDF46400E6954E064F149404F1F813FFCE246400E6954E064F149404F1F813FFCE246402B16BF29ACEE4940116E32AA0CDF46402B16BF29ACEE4940
31279	3041	45.276859999999999	45.297978999999998	51.699145999999999	51.685903000000003	Школьная	0103000020E6100000010000000500000008C9022670A34640399D64ABCBD7494008C9022670A346408A90BA9D7DD9494088F2052D24A646408A90BA9D7DD9494088F2052D24A64640399D64ABCBD7494008C9022670A34640399D64ABCBD74940
30735	2970	45.345033000000001	45.370482000000003	51.653064000000001	51.642620000000001	Юбилейная	0103000020E610000001000000050000003885950A2AAC4640B5E0455F41D249403885950A2AAC4640F418E59997D34940DBE044F46BAF4640F418E59997D34940DBE044F46BAF4640B5E0455F41D249403885950A2AAC4640B5E0455F41D24940
31107	3648	45.683033000000002	45.703271999999998	51.664673999999998	51.652098000000002	Центральная	0103000020E610000001000000050000005D8B16A06DD74640BDE47FF277D349405D8B16A06DD746403140A20914D54940A41820D104DA46403140A20914D54940A41820D104DA4640BDE47FF277D349405D8B16A06DD74640BDE47FF277D34940
9940	2802	45.620626999999999	45.647163999999997	51.723008	51.701233000000002	Центральная	0103000020E61000000100000005000000DE019EB470CF464020F0C000C2D94940DE019EB470CF4640895FB1868BDC494003931B45D6D24640895FB1868BDC494003931B45D6D2464020F0C000C2D94940DE019EB470CF464020F0C000C2D94940
30771	53171	44.908901	46.040562999999999	52.061445999999997	51.544210999999997	Кузнецова	0103000020E610000001000000050000009E2633DE56744640CD8FBFB4A8C549409E2633DE56744640293C6876DD074A40BD361B2B31054740293C6876DD074A40BD361B2B31054740CD8FBFB4A8C549409E2633DE56744640CD8FBFB4A8C54940
30417	2696	45.758752000000001	45.805149999999998	51.814490999999997	51.791629999999998	Ленина	0103000020E6100000010000000500000026E318C91EE146402844C02154E5494026E318C91EE1464073F1B73D41E84940EC2FBB270FE7464073F1B73D41E84940EC2FBB270FE746402844C02154E5494026E318C91EE146402844C02154E54940
30203	4102	45.482250999999998	45.515622999999998	51.854111000000003	51.836672999999998	Верхняя	0103000020E610000001000000050000004DBB9866BABD46401D39D21918EB49404DBB9866BABD4640B2135E8253ED49405F0839EFFFC14640B2135E8253ED49405F0839EFFFC146401D39D21918EB49404DBB9866BABD46401D39D21918EB4940
30497	3928	45.730922	45.753542000000003	51.76923	51.750889999999998	Рабочая	0103000020E61000000100000005000000A5F622DA8EDD46405C72DC291DE04940A5F622DA8EDD4640118DEE2076E24940CB14731074E04640118DEE2076E24940CB14731074E046405C72DC291DE04940A5F622DA8EDD46405C72DC291DE04940
67117	2575	45.605437000000002	45.631245	51.819178999999998	51.802824999999999	Административный проезд	0103000020E61000000100000005000000E964A9F57ECD4640A2B437F8C2E64940E964A9F57ECD4640F54883DBDAE84940BB61DBA2CCD04640F54883DBDAE84940BB61DBA2CCD04640A2B437F8C2E64940E964A9F57ECD4640A2B437F8C2E64940
30250	1523	46.825358000000001	46.862305999999997	51.398629999999997	51.362450000000003	Школьная	0103000020E61000000100000005000000F9BEB854A5694740B537F8C264AE4940F9BEB854A56947402C9ACE4E06B349408192020B606E47402C9ACE4E06B349408192020B606E4740B537F8C264AE4940F9BEB854A5694740B537F8C264AE4940
31159	1523	46.825358000000001	46.862305999999997	51.398629999999997	51.362450000000003	Советская 	0103000020E61000000100000005000000F9BEB854A5694740B537F8C264AE4940F9BEB854A56947402C9ACE4E06B349408192020B606E47402C9ACE4E06B349408192020B606E4740B537F8C264AE4940F9BEB854A5694740B537F8C264AE4940
31081	1523	46.825358000000001	46.862305999999997	51.398629999999997	51.362450000000003	К.Маркса	0103000020E61000000100000005000000F9BEB854A5694740B537F8C264AE4940F9BEB854A56947402C9ACE4E06B349408192020B606E47402C9ACE4E06B349408192020B606E4740B537F8C264AE4940F9BEB854A5694740B537F8C264AE4940
30563	1523	46.825358000000001	46.862305999999997	51.398629999999997	51.362450000000003	Димитрова	0103000020E61000000100000005000000F9BEB854A5694740B537F8C264AE4940F9BEB854A56947402C9ACE4E06B349408192020B606E47402C9ACE4E06B349408192020B606E4740B537F8C264AE4940F9BEB854A5694740B537F8C264AE4940
30998	1523	46.825358000000001	46.862305999999997	51.398629999999997	51.362450000000003	50 лет Победы	0103000020E61000000100000005000000F9BEB854A5694740B537F8C264AE4940F9BEB854A56947402C9ACE4E06B349408192020B606E47402C9ACE4E06B349408192020B606E4740B537F8C264AE4940F9BEB854A5694740B537F8C264AE4940
30468	1869	46.718674	46.752585000000003	51.455624999999998	51.430289999999999	50 лет Пионерии	0103000020E61000000100000005000000253E7782FD5B4740DEE522BE13B74940253E7782FD5B4740B81E85EB51BA4940E73A8DB454604740B81E85EB51BA4940E73A8DB454604740DEE522BE13B74940253E7782FD5B4740DEE522BE13B74940
30205	2158	46.750196000000003	46.806080000000001	51.241802	51.210965999999999	Кооперативная	0103000020E6100000010000000500000086CB2A6C06604740B24813EF009B494086CB2A6C06604740BF0D315EF39E4940D7FA22A12D674740BF0D315EF39E4940D7FA22A12D674740B24813EF009B494086CB2A6C06604740B24813EF009B4940
30471	1913	46.959378000000001	46.98657	51.24492	51.218114	Кооперативная	0103000020E610000001000000050000003E40F7E5CC7A47405E66D828EB9B49403E40F7E5CC7A47407311DF89599F49407C9BFEEC477E47407311DF89599F49407C9BFEEC477E47405E66D828EB9B49403E40F7E5CC7A47405E66D828EB9B4940
30265	2280	46.855316999999999	46.88223	51.301819999999999	51.287796	Клубная	0103000020E610000001000000050000003E5B07077B6D4740B6F5D37FD6A449403E5B07077B6D4740ADA3AA09A2A6494069C6A2E9EC704740ADA3AA09A2A6494069C6A2E9EC704740B6F5D37FD6A449403E5B07077B6D4740B6F5D37FD6A44940
30933	2517	46.952272000000001	46.975735999999998	51.358604	51.345548000000001	Клубная	0103000020E61000000100000005000000C172840CE47947405F99B7EA3AAC4940C172840CE47947407E1B62BCE6AD4940D2C3D0EAE47C47407E1B62BCE6AD4940D2C3D0EAE47C47405F99B7EA3AAC4940C172840CE47947405F99B7EA3AAC4940
30206	2459	47.010528000000001	47.042938999999997	51.291040000000002	51.277565000000003	Школьная	0103000020E610000001000000050000009DD843FB58814740D3C1FA3F87A349409DD843FB58814740F7E978CC40A54940895C70067F854740F7E978CC40A54940895C70067F854740D3C1FA3F87A349409DD843FB58814740D3C1FA3F87A34940
30965	1998	46.938167999999997	46.955641	51.266390999999999	51.258274999999998	Школьная	0103000020E61000000100000005000000AD1397E315784740EC2FBB270FA14940AD1397E3157847407079AC1919A24940BEDBBC71527A47407079AC1919A24940BEDBBC71527A4740EC2FBB270FA14940AD1397E315784740EC2FBB270FA14940
30883	2356	47.005012000000001	47.019061999999998	51.448462999999997	51.423819999999999	Школьная	0103000020E61000000100000005000000350BB43BA480474003B2D7BB3FB64940350BB43BA4804740A73B4F3C67B94940554CA59F70824740A73B4F3C67B94940554CA59F7082474003B2D7BB3FB64940350BB43BA480474003B2D7BB3FB64940
31194	2394	47.083058000000001	47.106422999999999	51.445892000000001	51.432276999999999	Школьная	0103000020E61000000100000005000000E9D500A5A18A474010E84CDA54B74940E9D500A5A18A474026C632FD12B949406745D4449F8D474026C632FD12B949406745D4449F8D474010E84CDA54B74940E9D500A5A18A474010E84CDA54B74940
30412	2052	46.775151000000001	46.800403000000003	51.286015999999996	51.274354000000002	Вокзальная	0103000020E61000000100000005000000193BE125386347406EC328081EA34940193BE12538634740FD101B2C9CA44940664F029B73664740FD101B2C9CA44940664F029B736647406EC328081EA34940193BE125386347406EC328081EA34940
30289	2121	46.832455000000003	46.860247999999999	51.272275	51.255000000000003	Юбилейная	0103000020E610000001000000050000002332ACE28D6A4740713D0AD7A3A049402332ACE28D6A47405B423EE8D9A249408639419B1C6E47405B423EE8D9A249408639419B1C6E4740713D0AD7A3A049402332ACE28D6A4740713D0AD7A3A04940
31158	53194	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	Школьная	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
31221	583	45.429178	45.441836000000002	51.450730999999998	51.436169	Молодежная	0103000020E61000000100000005000000D314014EEFB64640B743C362D4B74940D314014EEFB646408D25AC8DB1B94940051901158EB846408D25AC8DB1B94940051901158EB84640B743C362D4B74940D314014EEFB64640B743C362D4B74940
67112	32195	46.165554	46.187617000000003	51.813918000000001	51.799878999999997	Центральная	0103000020E610000001000000050000006ADC9BDF30154740EBE0606F62E649406ADC9BDF3015474018D00B772EE849403A9677D50318474018D00B772EE849403A9677D503184740EBE0606F62E649406ADC9BDF30154740EBE0606F62E64940
31311	1420	46.178480999999998	46.218187	51.661138000000001	51.640512000000001	Большая Советская	0103000020E610000001000000050000008BFA2477D81647400859164CFCD149408BFA2477D81647404912842BA0D44940C8B4368DED1B47404912842BA0D44940C8B4368DED1B47400859164CFCD149408BFA2477D81647400859164CFCD14940
30453	516	45.522675	45.548268	51.458835000000001	51.439605	Школьная	0103000020E61000000100000005000000E9B7AF03E7C246403C1405FA44B84940E9B7AF03E7C246404DA1F31ABBBA4940BFB854A52DC646404DA1F31ABBBA4940BFB854A52DC646403C1405FA44B84940E9B7AF03E7C246403C1405FA44B84940
30225	32191	45.804288	45.837893999999999	51.388936000000001	51.373629000000001	Центральная	0103000020E610000001000000050000005A48C0E8F2E6464029EB3713D3AF49405A48C0E8F2E64640581EA4A7C8B14940DFC14F1C40EB4640581EA4A7C8B14940DFC14F1C40EB464029EB3713D3AF49405A48C0E8F2E6464029EB3713D3AF4940
31586	53237	45.804288	45.837893999999999	51.388936000000001	51.373629000000001	Центральная	0103000020E610000001000000050000005A48C0E8F2E6464029EB3713D3AF49405A48C0E8F2E64640581EA4A7C8B14940DFC14F1C40EB4640581EA4A7C8B14940DFC14F1C40EB464029EB3713D3AF49405A48C0E8F2E6464029EB3713D3AF4940
31178	1195	45.753191999999999	45.779836000000003	51.245229999999999	51.229067999999998	Советская	0103000020E61000000100000005000000EECD6F9868E04640B247A819529D4940EECD6F9868E04640C1FF56B2639F49402A1F82AAD1E34640C1FF56B2639F49402A1F82AAD1E34640B247A819529D4940EECD6F9868E04640B247A819529D4940
31077	1236	45.637146999999999	45.665470999999997	51.299821000000001	51.280923000000001	Октябрьская	0103000020E610000001000000050000004CDF6B088ED14640DCD8EC48F5A349404CDF6B088ED14640B7D3D68860A64940DCB75A272ED54640B7D3D68860A64940DCB75A272ED54640DCD8EC48F5A349404CDF6B088ED14640DCD8EC48F5A34940
30826	32287	46.185200000000002	46.208305000000003	51.700837	51.681659000000003	Школьная	0103000020E610000001000000050000000F9C33A2B41747401503249A40D749400F9C33A2B4174740D369DD06B5D94940F14BFDBCA91A4740D369DD06B5D94940F14BFDBCA91A47401503249A40D749400F9C33A2B41747401503249A40D74940
31315	955	45.438322999999997	45.456657999999997	51.295591000000002	51.267547	Школьная	0103000020E61000000100000005000000D40AD3F71AB846404B92E7FA3EA24940D40AD3F71AB84640F8FE06EDD5A5494077BAF3C473BA4640F8FE06EDD5A5494077BAF3C473BA46404B92E7FA3EA24940D40AD3F71AB846404B92E7FA3EA24940
30681	53167	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	Советская	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
31323	1125	45.567770000000003	45.595627	51.428234000000003	51.412064000000001	Школьная	0103000020E6100000010000000500000031D3F6AFACC84640F2ED5D83BEB4494031D3F6AFACC846408484285FD0B64940ABCE6A813DCC46408484285FD0B64940ABCE6A813DCC4640F2ED5D83BEB4494031D3F6AFACC84640F2ED5D83BEB44940
30230	32454	46.071869	46.088065999999998	51.728102	51.716715000000001	Широкая	0103000020E61000000100000005000000514CDE0033094740BDC62E51BDDB4940514CDE00330947407B13437232DD4940DCF126BF450B47407B13437232DD4940DCF126BF450B4740BDC62E51BDDB4940514CDE0033094740BDC62E51BDDB4940
31292	324	45.701664000000001	45.727544999999999	51.501010999999998	51.486094999999999	Центральная	0103000020E61000000100000005000000E9633E20D0D94640E3DF675C38BE4940E9633E20D0D94640D7F7E12021C0494025AFCE3120DD4640D7F7E12021C0494025AFCE3120DD4640E3DF675C38BE4940E9633E20D0D94640E3DF675C38BE4940
30988	199	45.817501999999998	45.847532999999999	51.368231000000002	51.340406000000002	Калинина	0103000020E610000001000000050000001135D1E7A3E846405CAE7E6C92AB49401135D1E7A3E84640CB2F833122AF4940F0A31AF67BEC4640CB2F833122AF4940F0A31AF67BEC46405CAE7E6C92AB49401135D1E7A3E846405CAE7E6C92AB4940
30449	199	45.817501999999998	45.847532999999999	51.368231000000002	51.340406000000002	Базарная	0103000020E610000001000000050000001135D1E7A3E846405CAE7E6C92AB49401135D1E7A3E84640CB2F833122AF4940F0A31AF67BEC4640CB2F833122AF4940F0A31AF67BEC46405CAE7E6C92AB49401135D1E7A3E846405CAE7E6C92AB4940
30235	117	45.669584999999998	45.717205	51.549404000000003	51.533321000000001	Нефтяников	0103000020E61000000100000005000000327216F6B4D5464090A2CEDC43C44940327216F6B4D546405325CADE52C649408BC3995FCDDB46405325CADE52C649408BC3995FCDDB464090A2CEDC43C44940327216F6B4D5464090A2CEDC43C44940
30670	385	45.615479999999998	45.634740000000001	51.443444999999997	51.434292999999997	Коммунарная	0103000020E61000000100000005000000C9AB730CC8CE4640DCF0BBE996B74940C9AB730CC8CE4640904946CEC2B8494045BB0A293FD14640904946CEC2B8494045BB0A293FD14640DCF0BBE996B74940C9AB730CC8CE4640DCF0BBE996B74940
31131	466	45.731586999999998	45.75656	51.386080999999997	51.379942	Садовая	0103000020E61000000100000005000000E1968FA4A4DD46403C3080F0A1B04940E1968FA4A4DD4640B14D2A1A6BB149401BBB44F5D6E04640B14D2A1A6BB149401BBB44F5D6E046403C3080F0A1B04940E1968FA4A4DD46403C3080F0A1B04940
31422	32458	46.033610000000003	46.051253000000003	51.733150000000002	51.725251	Советская	0103000020E61000000100000005000000C7681D554D04474016325706D5DC4940C7681D554D044740FD87F4DBD7DD4940346953758F064740FD87F4DBD7DD4940346953758F06474016325706D5DC4940C7681D554D04474016325706D5DC4940
30832	646	45.681066000000001	45.695743999999998	51.394264	51.381684999999997	Центральная	0103000020E610000001000000050000007235B22B2DD74640D72FD80DDBB049407235B22B2DD74640BDFE243E77B24940B131AF230ED94640BDFE243E77B24940B131AF230ED94640D72FD80DDBB049407235B22B2DD74640D72FD80DDBB04940
31309	53205	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	Октябрьская 	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
30224	32118	45.807360000000003	45.839312999999997	51.421500999999999	51.410513999999999	Советская	0103000020E610000001000000050000009E0C8E9257E746406B4606B98BB449409E0C8E9257E746409B1DA9BEF3B54940C70DBF9B6EEB46409B1DA9BEF3B54940C70DBF9B6EEB46406B4606B98BB449409E0C8E9257E746406B4606B98BB44940
31147	53193	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	Овражная	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
30800	53172	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	Школьная	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
30612	22459	43.471561000000001	43.480148999999997	51.240442999999999	51.226061999999999	Совхозная	0103000020E61000000100000005000000D788601C5CBC4540266F8099EF9C4940D788601C5CBC4540ACC612D6C69E4940821ABE8575BD4540ACC612D6C69E4940821ABE8575BD4540266F8099EF9C4940D788601C5CBC4540266F8099EF9C4940
31078	6928	43.98254	44.006472000000002	51.208188999999997	51.180672999999999	Школьная	0103000020E610000001000000050000008481E7DEC3FD45409622F94A209749408481E7DEC3FD45408731E9EFA59A49407C2B1213D40046408731E9EFA59A49407C2B1213D40046409622F94A209749408481E7DEC3FD45409622F94A20974940
30954	30735	43.117085000000003	43.147098	51.137549999999997	51.129145000000001	Рабочая	0103000020E6100000010000000500000014ED2AA4FC8E454091B8C7D28790494014ED2AA4FC8E45404BC8073D9B9149404CA7751BD49245404BC8073D9B9149404CA7751BD492454091B8C7D28790494014ED2AA4FC8E454091B8C7D287904940
31123	31523	43.380291999999997	43.394350000000003	51.315157999999997	51.304375999999998	Мира	0103000020E6100000010000000500000018778368ADB04540F9D7F2CAF5A6494018778368ADB045405089EB1857A84940BC96900F7AB245405089EB1857A84940BC96900F7AB24540F9D7F2CAF5A6494018778368ADB04540F9D7F2CAF5A64940
31397	31418	43.411220999999998	43.456020000000002	51.344856	51.314652000000002	Ленина	0103000020E61000000100000005000000D636C5E3A2B445407DCF488446A84940D636C5E3A2B4454029EACC3D24AC4940352905DD5EBA454029EACC3D24AC4940352905DD5EBA45407DCF488446A84940D636C5E3A2B445407DCF488446A84940
30197	24576	43.569018999999997	43.592886999999997	51.418844	51.407384	Центральная	0103000020E61000000100000005000000BCE6559DD5C84540F374AE2825B44940BCE6559DD5C845401B1021AE9CB549409D9CA1B8E3CB45401B1021AE9CB549409D9CA1B8E3CB4540F374AE2825B44940BCE6559DD5C84540F374AE2825B44940
30769	23131	43.675469	43.750712	51.209515000000003	51.151302999999999	Ревякина	0103000020E610000001000000050000001D3BA8C475D64540B2648EE55D9349401D3BA8C475D64540BF823463D19A49407D5BB05417E04540BF823463D19A49407D5BB05417E04540B2648EE55D9349401D3BA8C475D64540B2648EE55D934940
30941	23131	43.675469	43.750712	51.209515000000003	51.151302999999999	Красная площадь	0103000020E610000001000000050000001D3BA8C475D64540B2648EE55D9349401D3BA8C475D64540BF823463D19A49407D5BB05417E04540BF823463D19A49407D5BB05417E04540B2648EE55D9349401D3BA8C475D64540B2648EE55D934940
30580	23131	43.675469	43.750712	51.209515000000003	51.151302999999999	Коневка	0103000020E610000001000000050000001D3BA8C475D64540B2648EE55D9349401D3BA8C475D64540BF823463D19A49407D5BB05417E04540BF823463D19A49407D5BB05417E04540B2648EE55D9349401D3BA8C475D64540B2648EE55D934940
31130	31757	44.118769999999998	44.148018999999998	51.188006000000001	51.173642999999998	Центральная	0103000020E610000001000000050000007ADFF8DA330F4640F4160FEF399649407ADFF8DA330F4640D4B9A29410984940E3175E49F2124640D4B9A29410984940E3175E49F2124640F4160FEF399649407ADFF8DA330F4640F4160FEF39964940
30953	30670	43.265056000000001	43.286228999999999	51.152664999999999	51.123911	 Ленина	0103000020E61000000100000005000000E6CDE15AEDA14540AD4ECE50DC8F4940E6CDE15AEDA14540361FD7868A9349405915E126A3A44540361FD7868A9349405915E126A3A44540AD4ECE50DC8F4940E6CDE15AEDA14540AD4ECE50DC8F4940
30290	22387	43.320203999999997	43.350144	51.079456	51.056980000000003	Победы	0103000020E610000001000000050000003106D671FCA845405743E21E4B8749403106D671FCA8454049BC3C9D2B8A49400072C284D1AC454049BC3C9D2B8A49400072C284D1AC45405743E21E4B8749403106D671FCA845405743E21E4B874940
30398	31325	43.654988000000003	43.700667000000003	51.327142000000002	51.281492	Ленина	0103000020E61000000100000005000000E0A293A5D6D34540F60A0BEE07A44940E0A293A5D6D34540F392FFC9DFA949407731CD74AFD94540F392FFC9DFA949407731CD74AFD94540F60A0BEE07A44940E0A293A5D6D34540F60A0BEE07A44940
30964	11846	43.374965000000003	43.397683000000001	51.418979	51.405512999999999	Школьная	0103000020E61000000100000005000000841266DAFEAF45402A8D98D9E7B34940841266DAFEAF4540FB5A971AA1B549406C96CB46E7B24540FB5A971AA1B549406C96CB46E7B245402A8D98D9E7B34940841266DAFEAF45402A8D98D9E7B34940
30950	30519	43.654907000000001	43.682583999999999	51.184629999999999	51.138967999999998	Ленина	0103000020E61000000100000005000000F37519FED3D34540639813B4C9914940F37519FED3D3454024EEB1F4A1974940ED629AE95ED7454024EEB1F4A1974940ED629AE95ED74540639813B4C9914940F37519FED3D34540639813B4C9914940
31166	6400	43.461660999999999	43.483947999999998	51.369120000000002	51.351269000000002	Грейдерная	0103000020E61000000100000005000000596B28B517BB4540A08CF161F6AC4940596B28B517BB45405726FC523FAF4940787B1002F2BD45405726FC523FAF4940787B1002F2BD4540A08CF161F6AC4940596B28B517BB4540A08CF161F6AC4940
31392	30974	43.458858999999997	43.484963999999998	51.329956000000003	51.313772999999998	Заречная	0103000020E61000000100000005000000D53C47E4BBBA454014AFB2B629A84940D53C47E4BBBA45403B8F8AFF3BAA494061DEE34C13BE45403B8F8AFF3BAA494061DEE34C13BE454014AFB2B629A84940D53C47E4BBBA454014AFB2B629A84940
30187	31210	43.237765000000003	43.273608000000003	51.271079999999998	51.252761999999997	Гагарина	0103000020E61000000100000005000000159161156F9E4540F5D555815AA04940159161156F9E4540C24CDBBFB2A2494045F6419605A34540C24CDBBFB2A2494045F6419605A34540F5D555815AA04940159161156F9E4540F5D555815AA04940
30600	30830	43.474497999999997	43.495356999999998	51.146974999999998	51.125408999999998	Новая	0103000020E610000001000000050000003A02B859BCBC4540E1CFF0660D9049403A02B859BCBC4540302AA913D09249401E6CB1DB67BF4540302AA913D09249401E6CB1DB67BF4540E1CFF0660D9049403A02B859BCBC4540E1CFF0660D904940
31233	31262	43.702931	43.735396000000001	51.323658000000002	51.299449000000003	Почтовая	0103000020E610000001000000050000001B2C9CA4F9D94540F3E8465854A649401B2C9CA4F9D945405D8B16A06DA94940FBCDC47421DE45405D8B16A06DA94940FBCDC47421DE4540F3E8465854A649401B2C9CA4F9D94540F3E8465854A64940
31398	31420	43.649777	43.678621999999997	51.419102000000002	51.400962	Новая	0103000020E61000000100000005000000B4588AE42BD3454029780AB952B34940B4588AE42BD3454017D86322A5B549404D2CF015DDD6454017D86322A5B549404D2CF015DDD6454029780AB952B34940B4588AE42BD3454029780AB952B34940
31284	22555	43.557564999999997	43.580005	51.455697999999998	51.445633999999998	Ковалевская	0103000020E610000001000000050000007632384A5EC745402AFEEF880AB949407632384A5EC74540226DE34F54BA49401C42959A3DCA4540226DE34F54BA49401C42959A3DCA45402AFEEF880AB949407632384A5EC745402AFEEF880AB94940
30604	9477	43.356189999999998	43.3902	51.358969000000002	51.344152999999999	Центральная	0103000020E61000000100000005000000C49448A297AD4540FFE89B340DAC4940C49448A297AD454090A339B2F2AD49401973D712F2B1454090A339B2F2AD49401973D712F2B14540FFE89B340DAC4940C49448A297AD4540FFE89B340DAC4940
30956	30616	43.376654000000002	43.445338999999997	51.186121	51.146416000000002	Ленина	0103000020E610000001000000050000002CF4C13236B045403ACE6DC2BD9249402CF4C13236B04540A60C1CD0D297494011514CDE00B94540A60C1CD0D297494011514CDE00B945403ACE6DC2BD9249402CF4C13236B045403ACE6DC2BD924940
30792	31211	43.746049999999997	43.779080999999998	51.349024	51.327750000000002	Центральная	0103000020E610000001000000050000002497FF907EDF4540CBA145B6F3A949402497FF907EDF454072C284D1ACAC4940ADF71BEDB8E3454072C284D1ACAC4940ADF71BEDB8E34540CBA145B6F3A949402497FF907EDF4540CBA145B6F3A94940
30777	5927	43.644908999999998	43.690193000000001	51.229005999999998	51.176014000000002	Школьная	0103000020E61000000100000005000000B2F2CB608CD24540AFD172A087964940B2F2CB608CD245403C4B9011509D4940CD76853E58D845403C4B9011509D4940CD76853E58D84540AFD172A087964940B2F2CB608CD24540AFD172A087964940
31387	30611	43.629305000000002	43.668973999999999	51.131428999999997	51.094386	Ленина	0103000020E61000000100000005000000CA1AF5108DD04540A29927D7148C4940CA1AF5108DD045407C5F5CAAD2904940E9EFA5F0A0D545407C5F5CAAD2904940E9EFA5F0A0D54540A29927D7148C4940CA1AF5108DD04540A29927D7148C4940
30779	30421	43.948709999999998	43.973466999999999	51.362428000000001	51.345407000000002	Елизаветинская	0103000020E61000000100000005000000AFB14B546FF945409D67EC4B36AC4940AFB14B546FF94540CD936B0A64AE49401C5E10919AFC4540CD936B0A64AE49401C5E10919AFC45409D67EC4B36AC4940AFB14B546FF945409D67EC4B36AC4940
31273	30832	43.475118000000002	43.512774999999998	51.077587999999999	51.057999000000002	Заречная	0103000020E61000000100000005000000D7DEA7AAD0BC4540B119E0826C874940D7DEA7AAD0BC4540F1475167EE8949406B9A779CA2C14540F1475167EE8949406B9A779CA2C14540B119E0826C874940D7DEA7AAD0BC4540B119E0826C874940
30185	22457	43.398231000000003	43.422854000000001	51.257294999999999	51.242562999999997	Заречная	0103000020E610000001000000050000006FA0C03BF9B245401D1CEC4D0C9F49406FA0C03BF9B245405036E50AEFA04940CC7D721420B645405036E50AEFA04940CC7D721420B645401D1CEC4D0C9F49406FA0C03BF9B245401D1CEC4D0C9F4940
30583	30364	44.028596999999998	44.062832	51.336956000000001	51.310108	Центральная	0103000020E61000000100000005000000C1E10511A90346402E1D739EB1A74940C1E10511A90346407218CC5F21AB4940369204E10A0846407218CC5F21AB4940369204E10A0846402E1D739EB1A74940C1E10511A90346402E1D739EB1A74940
31105	30518	44.033942000000003	44.054828000000001	51.299680000000002	51.278618999999999	Александровская	0103000020E61000000100000005000000FDFA213658044640A98592C9A9A34940FDFA213658044640F5A10BEA5BA64940DA73999A04074640F5A10BEA5BA64940DA73999A04074640A98592C9A9A34940FDFA213658044640A98592C9A9A34940
30341	29736	43.726880000000001	43.752374000000003	52.231776000000004	52.212218	Советская	0103000020E61000000100000005000000E90E62670ADD4540AFCF9CF5291B4A40E90E62670ADD4540B5FF01D6AA1D4A402C2E8ECA4DE04540B5FF01D6AA1D4A402C2E8ECA4DE04540AFCF9CF5291B4A40E90E62670ADD4540AFCF9CF5291B4A40
30577	30026	43.764169000000003	43.800254000000002	52.395259000000003	52.376719000000001	Школьная	0103000020E61000000100000005000000FBCE2F4AD0E145401364045438304A40FBCE2F4AD0E145408F39CFD897324A40213F1BB96EE645408F39CFD897324A40213F1BB96EE645401364045438304A40FBCE2F4AD0E145401364045438304A40
31071	29200	43.877724999999998	43.897120000000001	52.270243000000001	52.259478999999999	Мира	0103000020E61000000100000005000000D8F0F44A59F04540D87F9D9B36214A40D8F0F44A59F04540897C975297224A40344B02D4D4F24540897C975297224A40344B02D4D4F24540D87F9D9B36214A40D8F0F44A59F04540D87F9D9B36214A40
31569	53231	43.763908000000001	43.780878000000001	52.298223999999998	52.285037000000003	Школьная	0103000020E610000001000000050000008E93C2BCC7E145403293A8177C244A408E93C2BCC7E14540EF703B342C264A403C1570CFF3E34540EF703B342C264A403C1570CFF3E345403293A8177C244A408E93C2BCC7E145403293A8177C244A40
30818	53175	43.734712999999999	43.746158000000001	52.263078	52.255156999999997	Юбилейная	0103000020E61000000100000005000000187959130BDE4540382C0DFCA8204A40187959130BDE45400726378AAC214A400BD3F71A82DF45400726378AAC214A400BD3F71A82DF4540382C0DFCA8204A40187959130BDE4540382C0DFCA8204A40
31359	28933	43.572352000000002	43.598078999999998	52.187263000000002	52.176285	Куйбышева	0103000020E610000001000000050000006DE690D442C945403FE3C28190164A406DE690D442C945401C60E63BF8174A4052B648DA8DCC45401C60E63BF8174A4052B648DA8DCC45403FE3C28190164A406DE690D442C945403FE3C28190164A40
30745	29120	43.026606999999998	43.044142000000001	52.353110999999998	52.336413	Школьная	0103000020E610000001000000050000001E6CB1DB678345408179C8940F2B4A401E6CB1DB67834540CE6DC2BD322D4A40A530EF71A6854540CE6DC2BD322D4A40A530EF71A68545408179C8940F2B4A401E6CB1DB678345408179C8940F2B4A40
31076	29299	43.970674000000002	43.993957999999999	52.336523	52.321482000000003	Зеленая	0103000020E61000000100000005000000EC89AE0B3FFC454058207A5226294A40EC89AE0B3FFC454008AD872F132B4A407DCC07043AFF454008AD872F132B4A407DCC07043AFF454058207A5226294A40EC89AE0B3FFC454058207A5226294A40
31252	29469	44.058447999999999	44.090966999999999	52.125402000000001	52.105521000000003	Кирова	0103000020E6100000010000000500000020425C397B07464047054EB6810D4A4020425C397B0746402F6D382C0D104A40F30181CEA40B46402F6D382C0D104A40F30181CEA40B464047054EB6810D4A4020425C397B07464047054EB6810D4A40
31094	29932	43.866819	43.908617999999997	52.346058999999997	52.325747999999997	Школьная	0103000020E610000001000000050000009546CCECF3EE4540635E471CB2294A409546CCECF3EE454044BE4BA94B2C4A40494739984DF4454044BE4BA94B2C4A40494739984DF44540635E471CB2294A409546CCECF3EE4540635E471CB2294A40
31480	29116	43.235097000000003	43.262135999999998	52.414335000000001	52.393324	Свердлова	0103000020E61000000100000005000000A13193A8179E4540AF5DDA7058324A40A13193A8179E4540494BE5ED08354A40588D25AC8DA14540494BE5ED08354A40588D25AC8DA14540AF5DDA7058324A40A13193A8179E4540AF5DDA7058324A40
30559	29370	44.027743999999998	44.056570999999998	52.324244999999998	52.305405999999998	Школьная	0103000020E6100000010000000500000082548A1D8D0346404700378B17274A4082548A1D8D0346401D7233DC80294A407573F1B73D0746401D7233DC80294A407573F1B73D0746404700378B17274A4082548A1D8D0346404700378B17274A40
30911	28987	43.377076000000002	43.396712999999998	52.286068	52.258398	Молодежная	0103000020E61000000100000005000000A20DC00644B0454008AD872F13214A40A20DC00644B04540503750E09D244A40F372D87DC7B24540503750E09D244A40F372D87DC7B2454008AD872F13214A40A20DC00644B0454008AD872F13214A40
30329	28657	43.544459000000003	43.565300000000001	52.387839	52.371122	Горная	0103000020E61000000100000005000000A6811FD5B0C54540BE69FAEC802F4A40A6811FD5B0C54540828E56B5A4314A40E3361AC05BC84540828E56B5A4314A40E3361AC05BC84540BE69FAEC802F4A40A6811FD5B0C54540BE69FAEC802F4A40
31243	29373	44.193752000000003	44.21895	52.239083999999998	52.225945000000003	Садовая	0103000020E610000001000000050000006EC493DDCC184640EDD808C4EB1C4A406EC493DDCC184640997FF44D9A1E4A40C7BAB88D061C4640997FF44D9A1E4A40C7BAB88D061C4640EDD808C4EB1C4A406EC493DDCC184640EDD808C4EB1C4A40
31239	28848	43.278143999999998	43.291314	52.203443	52.197856999999999	Песчаная	0103000020E6100000010000000500000010CAFB389AA345407024D06053194A4010CAFB389AA34540D1CC936B0A1A4A40F86EF3C649A54540D1CC936B0A1A4A40F86EF3C649A545407024D06053194A4010CAFB389AA345407024D06053194A40
30929	29641	43.947119999999998	43.998485000000002	52.112882999999997	52.087839000000002	Крупской	0103000020E610000001000000050000009AB1683A3BF945401C28F04E3E0B4A409AB1683A3BF945401EA33CF3720E4A40F645425BCEFF45401EA33CF3720E4A40F645425BCEFF45401C28F04E3E0B4A409AB1683A3BF945401C28F04E3E0B4A40
31066	29035	43.303234000000003	43.353935	52.28669	52.261550999999997	Советская	0103000020E610000001000000050000008484285FD0A64540389ECF807A214A408484285FD0A645408D0B0742B2244A4073F4F8BD4DAD45408D0B0742B2244A4073F4F8BD4DAD4540389ECF807A214A408484285FD0A64540389ECF807A214A40
31362	29244	43.969101999999999	43.984040999999998	52.234346000000002	52.228029999999997	Ленина	0103000020E610000001000000050000007D3ECA880BFC4540E1404816301D4A407D3ECA880BFC454066F9BA0CFF1D4A402976340EF5FD454066F9BA0CFF1D4A402976340EF5FD4540E1404816301D4A407D3ECA880BFC4540E1404816301D4A40
31358	28950	43.488162000000003	43.514743000000003	52.153675	52.137144999999997	Молодежная	0103000020E610000001000000050000003293A8177CBE4540ABE7A4F78D114A403293A8177CBE45403D9B559FAB134A40276C3F19E3C145403D9B559FAB134A40276C3F19E3C14540ABE7A4F78D114A403293A8177CBE4540ABE7A4F78D114A40
30764	30030	43.984121000000002	43.991208999999998	52.217911999999998	52.210551000000002	Молодежная	0103000020E6100000010000000500000046274BADF7FD4540EF91CD55F31A4A4046274BADF7FD4540F6B3588AE41B4A401C40BFEFDFFE4540F6B3588AE41B4A401C40BFEFDFFE4540EF91CD55F31A4A4046274BADF7FD4540EF91CD55F31A4A40
30569	29515	44.033546999999999	44.086458	52.082940999999998	52.059857000000001	Пушкина	0103000020E6100000010000000500000080F0A1444B044640E5B7E864A9074A4080F0A1444B044640AF3F89CF9D0A4A40213D450E110B4640AF3F89CF9D0A4A40213D450E110B4640E5B7E864A9074A4080F0A1444B044640E5B7E864A9074A40
31253	29728	43.778210000000001	43.806758000000002	52.188035999999997	52.167496999999997	Школьная	0103000020E61000000100000005000000C8B5A1629CE34540CC96AC8A70154A40C8B5A1629CE345403E3C4B9011184A40A8E49CD843E745403E3C4B9011184A40A8E49CD843E74540CC96AC8A70154A40C8B5A1629CE34540CC96AC8A70154A40
31237	28845	43.422055	43.459477999999997	52.203443	52.189422	Барменкова	0103000020E61000000100000005000000800EF3E505B645404B92E7FA3E184A40800EF3E505B64540D1CC936B0A1A4A40A19DD32CD0BA4540D1CC936B0A1A4A40A19DD32CD0BA45404B92E7FA3E184A40800EF3E505B645404B92E7FA3E184A40
30704	28761	43.424624000000001	43.460628	52.234175	52.221063000000001	Первомайская	0103000020E61000000100000005000000618C48145AB6454086ADD9CA4B1C4A40618C48145AB6454039454772F91D4A409ACFB9DBF5BA454039454772F91D4A409ACFB9DBF5BA454086ADD9CA4B1C4A40618C48145AB6454086ADD9CA4B1C4A40
30570	29571	43.943302000000003	43.964205999999997	52.049101999999998	52.029851000000001	Школьная	0103000020E610000001000000050000002E20B41EBEF845405F605628D2034A402E20B41EBEF8454087156EF948064A40B14D2A1A6BFB454087156EF948064A40B14D2A1A6BFB45405F605628D2034A402E20B41EBEF845405F605628D2034A40
31374	29649	43.875264000000001	43.896185000000003	52.148220999999999	52.126258999999997	Советская	0103000020E61000000100000005000000DEAE97A608F04540AFE9414129104A40DEAE97A608F045404BCADDE7F8124A403815A930B6F245404BCADDE7F8124A403815A930B6F24540AFE9414129104A40DEAE97A608F04540AFE9414129104A40
30750	29466	44.147793999999998	44.225445000000001	52.226683999999999	52.187908999999998	Школьная	0103000020E61000000100000005000000C345EEE9EA124640E1CFF0660D184A40C345EEE9EA124640634337FB031D4A40FB05BB61DB1C4640634337FB031D4A40FB05BB61DB1C4640E1CFF0660D184A40C345EEE9EA124640E1CFF0660D184A40
30742	24646	43.449534	43.461221000000002	52.218722999999997	52.202371999999997	Советская	0103000020E61000000100000005000000543882548AB9454024D06053E7194A40543882548AB9454006F1811DFF1B4A403D9D2B4A09BB454006F1811DFF1B4A403D9D2B4A09BB454024D06053E7194A40543882548AB9454024D06053E7194A40
31061	28696	43.480176	43.503334000000002	52.346333999999999	52.317397	Садовая	0103000020E610000001000000050000007C293C6876BD45409C6C0377A0284A407C293C6876BD454016BF29AC542C4A40817B9E3F6DC0454016BF29AC542C4A40817B9E3F6DC045409C6C0377A0284A407C293C6876BD45409C6C0377A0284A40
31363	29198	43.046585999999998	43.071164000000003	52.315970999999998	52.295195	Ленина	0103000020E61000000100000005000000C939B187F6854540AB7823F3C8254A40C939B187F685454001BEDBBC71284A408753E6E61B89454001BEDBBC71284A408753E6E61B894540AB7823F3C8254A40C939B187F6854540AB7823F3C8254A40
30330	28649	43.601483999999999	43.871284000000003	52.340425000000003	52.261274999999998	60 лет Октября	0103000020E610000001000000050000009C887E6DFDCC454096218E7571214A409C887E6DFDCC4540D3DEE00B932B4A4098C3EE3B86EF4540D3DEE00B932B4A4098C3EE3B86EF454096218E7571214A409C887E6DFDCC454096218E7571214A40
31205	22999	42.85228	42.882103999999998	51.899341999999997	51.846417000000002	Ленина	0103000020E610000001000000050000007784D382176D4540A4E36A6457EC49407784D382176D4540A9F57EA31DF34940DCD5ABC8E8704540A9F57EA31DF34940DCD5ABC8E8704540A4E36A6457EC49407784D382176D4540A4E36A6457EC4940
31214	23367	42.910975999999998	42.930109999999999	51.688096999999999	51.682296000000001	Садовая	0103000020E610000001000000050000006FB88FDC9A7445408718AF7955D749406FB88FDC9A744540E4BCFF8F13D849405ED72FD80D774540E4BCFF8F13D849405ED72FD80D7745408718AF7955D749406FB88FDC9A7445408718AF7955D74940
30403	4298	42.722994999999997	42.774431999999997	51.777796000000002	51.723734	Федоровка	0103000020E61000000100000005000000F415A4198B5C45406B80D250A3DC4940F415A4198B5C4540D57ABFD18EE34940E97C789620634540D57ABFD18EE34940E97C7896206345406B80D250A3DC4940F415A4198B5C45406B80D250A3DC4940
30291	4298	42.722994999999997	42.774431999999997	51.777796000000002	51.723734	Советская	0103000020E61000000100000005000000F415A4198B5C45406B80D250A3DC4940F415A4198B5C4540D57ABFD18EE34940E97C789620634540D57ABFD18EE34940E97C7896206345406B80D250A3DC4940F415A4198B5C45406B80D250A3DC4940
30233	4298	42.722994999999997	42.774431999999997	51.777796000000002	51.723734	Народная	0103000020E61000000100000005000000F415A4198B5C45406B80D250A3DC4940F415A4198B5C4540D57ABFD18EE34940E97C789620634540D57ABFD18EE34940E97C7896206345406B80D250A3DC4940F415A4198B5C45406B80D250A3DC4940
31294	4298	42.722994999999997	42.774431999999997	51.777796000000002	51.723734	2-ая Заводская	0103000020E61000000100000005000000F415A4198B5C45406B80D250A3DC4940F415A4198B5C4540D57ABFD18EE34940E97C789620634540D57ABFD18EE34940E97C7896206345406B80D250A3DC4940F415A4198B5C45406B80D250A3DC4940
31224	4586	42.779246999999998	42.838149999999999	51.687806999999999	51.647106999999998	Чиркина	0103000020E61000000100000005000000C8409E5DBE6345409F01F566D4D24940C8409E5DBE634540DD7A4D0F0AD849403A92CB7F486B4540DD7A4D0F0AD849403A92CB7F486B45409F01F566D4D24940C8409E5DBE6345409F01F566D4D24940
31460	9734	43.160868999999998	43.192894000000003	51.872537000000001	51.857275999999999	Центральная	0103000020E6100000010000000500000059F8FA5A97944540A6D24F38BBED494059F8FA5A9794454065C6DB4AAFEF49401DCC26C0B098454065C6DB4AAFEF49401DCC26C0B0984540A6D24F38BBED494059F8FA5A97944540A6D24F38BBED4940
31458	22995	42.767237000000002	42.794086999999998	51.897485000000003	51.866525000000003	Центральная	0103000020E61000000100000005000000FDA36FD2346245404D158C4AEAEE4940FDA36FD23462454046D3D9C9E0F24940E1968FA4A465454046D3D9C9E0F24940E1968FA4A46545404D158C4AEAEE4940FDA36FD2346245404D158C4AEAEE4940
31047	20753	42.842246000000003	42.897744000000003	51.832132000000001	51.795974000000001	Ленина	0103000020E61000000100000005000000EA9788B7CE6B4540B03BDD79E2E54940EA9788B7CE6B454040FA264D83EA494012178046E972454040FA264D83EA494012178046E9724540B03BDD79E2E54940EA9788B7CE6B4540B03BDD79E2E54940
31463	20753	42.842246000000003	42.897744000000003	51.832132000000001	51.795974000000001	Комсомольская	0103000020E61000000100000005000000EA9788B7CE6B4540B03BDD79E2E54940EA9788B7CE6B454040FA264D83EA494012178046E972454040FA264D83EA494012178046E9724540B03BDD79E2E54940EA9788B7CE6B4540B03BDD79E2E54940
31203	3982	42.813499999999998	42.847797999999997	52.008845999999998	51.982323000000001	Народная	0103000020E61000000100000005000000E3A59BC420684540E78D93C2BCFD4940E3A59BC420684540A759A0DD21014A409ECE15A5846C4540A759A0DD21014A409ECE15A5846C4540E78D93C2BCFD4940E3A59BC420684540E78D93C2BCFD4940
30513	23356	42.798228000000002	42.814155999999997	51.767670000000003	51.724888999999997	Радость	0103000020E610000001000000050000003160C9552C664540751DAA29C9DC49403160C9552C664540670FB40243E24940CCEB884336684540670FB40243E24940CCEB884336684540751DAA29C9DC49403160C9552C664540751DAA29C9DC4940
30723	22807	42.931241999999997	42.961551	51.878275000000002	51.862487000000002	Горная	0103000020E61000000100000005000000B05417F032774540D21C59F965EE4940B05417F0327745407CF2B0506BF04940D237691A147B45407CF2B0506BF04940D237691A147B4540D21C59F965EE4940B05417F032774540D21C59F965EE4940
31213	17685	42.640681999999998	42.708171999999998	51.614789000000002	51.586072999999999	площадьСтоякина	0103000020E61000000100000005000000649126DE01524540C808A87004CB4940649126DE015245406478EC67B1CE4940B1F84D61A55A45406478EC67B1CE4940B1F84D61A55A4540C808A87004CB4940649126DE01524540C808A87004CB4940
30715	17685	42.640681999999998	42.708171999999998	51.614789000000002	51.586072999999999	Ленина	0103000020E61000000100000005000000649126DE01524540C808A87004CB4940649126DE015245406478EC67B1CE4940B1F84D61A55A45406478EC67B1CE4940B1F84D61A55A4540C808A87004CB4940649126DE01524540C808A87004CB4940
30882	22906	42.772851000000003	42.831637000000001	51.851005999999998	51.806373000000001	Ярославская	0103000020E6100000010000000500000028D714C8EC6245404FB0FF3A37E7494028D714C8EC6245409259BDC3EDEC49406092CA14736A45409259BDC3EDEC49406092CA14736A45404FB0FF3A37E7494028D714C8EC6245404FB0FF3A37E74940
30720	23190	43.021225999999999	43.055829000000003	51.891233	51.877313000000001	Набережная	0103000020E6100000010000000500000096E99788B782454086ADD9CA4BF0494096E99788B7824540D80E46EC13F249408E95986725874540D80E46EC13F249408E9598672587454086ADD9CA4BF0494096E99788B782454086ADD9CA4BF04940
31184	26365	46.006588000000001	46.031723	51.061967000000003	51.050128999999998	Почтовая	0103000020E61000000100000005000000E54526E0D700474064CA87A06A864940E54526E0D70047403337DF88EE874940F8C3CF7F0F0447403337DF88EE874940F8C3CF7F0F04474064CA87A06A864940E54526E0D700474064CA87A06A864940
31025	26359	46.054234999999998	46.075606000000001	51.038027	51.022596999999998	Школьная	0103000020E6100000010000000500000037A6272CF10647406DFE5F75E482494037A6272CF1064740B8AE9811DE844940D1B01875AD094740B8AE9811DE844940D1B01875AD0947406DFE5F75E482494037A6272CF10647406DFE5F75E4824940
30880	26657	46.166327000000003	46.185271999999998	50.658651999999996	50.645156999999998	Садовая	0103000020E610000001000000050000008DB800344A1547408AE42B81945249408DB800344A154740F5B86FB54E544940A86E2EFEB6174740F5B86FB54E544940A86E2EFEB61747408AE42B81945249408DB800344A1547408AE42B8194524940
30278	26273	46.074869	46.102511	51.030562000000003	51.014364	Рабочая	0103000020E61000000100000005000000FB3DB14E95094740B01EF7ADD6814940FB3DB14E950947400C40A374E9834940793D98141F0D47400C40A374E9834940793D98141F0D4740B01EF7ADD6814940FB3DB14E95094740B01EF7ADD6814940
30276	26267	46.091200999999998	46.116523999999998	50.990127000000001	50.966825	Кооперативная	0103000020E61000000100000005000000662E7079AC0B474044FAEDEBC07B4940662E7079AC0B47407CF1457BBC7E49407C992842EA0E47407CF1457BBC7E49407C992842EA0E474044FAEDEBC07B4940662E7079AC0B474044FAEDEBC07B4940
30858	22603	46.030177999999999	46.088684999999998	50.789790000000004	50.754792000000002	Свердлова	0103000020E61000000100000005000000838769DFDC03474027A435069D604940838769DFDC0347409B5AB6D617654940A852B3075A0B47409B5AB6D617654940A852B3075A0B474027A435069D604940838769DFDC03474027A435069D604940
67129	22603	46.030177999999999	46.088684999999998	50.789790000000004	50.754792000000002	Калинина	0103000020E61000000100000005000000838769DFDC03474027A435069D604940838769DFDC0347409B5AB6D617654940A852B3075A0B47409B5AB6D617654940A852B3075A0B474027A435069D604940838769DFDC03474027A435069D604940
30699	26194	46.065204000000001	46.098728999999999	50.941206999999999	50.918345000000002	Советская	0103000020E61000000100000005000000C1C8CB9A58084740FAB836548C754940C1C8CB9A5808474015E29178797849405915E126A30C474015E29178797849405915E126A30C4740FAB836548C754940C1C8CB9A58084740FAB836548C754940
30285	26457	45.936366999999997	45.965651999999999	51.101660000000003	51.078600999999999	Советская	0103000020E61000000100000005000000DD06B5DFDAF746406937FA980F8A4940DD06B5DFDAF74640DBA7E331038D494093A8177C9AFB4640DBA7E331038D494093A8177C9AFB46406937FA980F8A4940DD06B5DFDAF746406937FA980F8A4940
30286	26749	46.194820999999997	46.228113	50.581746000000003	50.567743	Центральная	0103000020E6100000010000000500000079C9FFE4EF18474037C478CDAB48494079C9FFE4EF184740174A26A7764A49406F6589CE321D4740174A26A7764A49406F6589CE321D474037C478CDAB48494079C9FFE4EF18474037C478CDAB484940
31093	26070	46.08061	46.091586999999997	50.801330999999998	50.787837000000003	Волжская	0103000020E6100000010000000500000083DDB06D510A474015CAC2D7D764494083DDB06D510A4740AF22A303926649408FDE701FB90B4740AF22A303926649408FDE701FB90B474015CAC2D7D764494083DDB06D510A474015CAC2D7D7644940
31026	26508	46.401280999999997	46.423397999999999	50.830962999999997	50.815480999999998	Советская	0103000020E61000000100000005000000CAC0012D5D33474033C170AE61684940CAC0012D5D334740D097DEFE5C6A49408D98D9E731364740D097DEFE5C6A49408D98D9E73136474033C170AE61684940CAC0012D5D33474033C170AE61684940
30489	26570	46.454766999999997	46.499125999999997	50.648007	50.627144000000001	Ленина	0103000020E61000000100000005000000672618CE353A4740FAF02C4146504940672618CE353A47401F4AB4E4F1524940A94A5B5CE33F47401F4AB4E4F1524940A94A5B5CE33F4740FAF02C4146504940672618CE353A4740FAF02C4146504940
31329	26028	46.060226999999998	46.08202	50.703831999999998	50.691240000000001	Центральная	0103000020E6100000010000000500000008ABB184B5074740F1D7648D7A58494008ABB184B50747406BF0BE2A175A494018CFA0A17F0A47406BF0BE2A175A494018CFA0A17F0A4740F1D7648D7A58494008ABB184B5074740F1D7648D7A584940
31333	26561	46.477890000000002	46.503168000000002	50.875760999999997	50.855266999999998	Советская	0103000020E61000000100000005000000F08AE07F2B3D47408C2C9963796D4940F08AE07F2B3D47405E0EBBEF1870494066321CCF674047405E0EBBEF1870494066321CCF674047408C2C9963796D4940F08AE07F2B3D47408C2C9963796D4940
31179	26141	46.111933999999998	46.148449999999997	50.862054999999998	50.836106000000001	Центральная	0103000020E61000000100000005000000BDA772DA530E4740A4FE7A85056B4940BDA772DA530E4740382D78D1576E4940AC8BDB6800134740382D78D1576E4940AC8BDB6800134740A4FE7A85056B4940BDA772DA530E4740A4FE7A85056B4940
30705	26658	46.257703999999997	46.273235	50.658115000000002	50.644443000000003	Волгоградская	0103000020E610000001000000050000003106D671FC2047406D91B41B7D5249403106D671FC204740E700C11C3D544940B08F4E5DF9224740E700C11C3D544940B08F4E5DF92247406D91B41B7D5249403106D671FC2047406D91B41B7D524940
31632	53244	45.837696000000001	46.619590000000002	51.147399	50.526026999999999	Волжская	0103000020E61000000100000005000000B9FE5D9F39EB464010E84CDA54434940B9FE5D9F39EB4640473B6EF8DD924940DE76A1B94E4F4740473B6EF8DD924940DE76A1B94E4F474010E84CDA54434940B9FE5D9F39EB464010E84CDA54434940
30260	25451	49.134765000000002	49.151842000000002	51.851551999999998	51.83108	Школьная	0103000020E610000001000000050000009ED2C1FA3F9148400A2E56D460EA49409ED2C1FA3F914840F46BEBA7FFEC49406214048F6F934840F46BEBA7FFEC49406214048F6F9348400A2E56D460EA49409ED2C1FA3F9148400A2E56D460EA4940
31426	24953	48.869779999999999	48.893459	52.06474	52.048847000000002	Набережная	0103000020E61000000100000005000000815B77F3546F4840FDC0559E40064A40815B77F3546F48401C5F7B6649084A408FA850DD5C7248401C5F7B6649084A408FA850DD5C724840FDC0559E40064A40815B77F3546F4840FDC0559E40064A40
31313	24920	48.705595000000002	48.722850999999999	52.053725999999997	52.034860000000002	Молодежная	0103000020E610000001000000050000004E9CDCEF505A484023F8DF4A76044A404E9CDCEF505A4840F2785A7EE0064A40C170AE61865C4840F2785A7EE0064A40C170AE61865C484023F8DF4A76044A404E9CDCEF505A484023F8DF4A76044A40
31010	25353	49.136597000000002	49.211337	52.070563999999997	52.041890000000002	Лободина	0103000020E61000000100000005000000A9DDAF027C914840C503CAA65C054A40A9DDAF027C9148403123BC3D08094A40A6B73F170D9B48403123BC3D08094A40A6B73F170D9B4840C503CAA65C054A40A9DDAF027C914840C503CAA65C054A40
30975	24826	48.413156999999998	48.438578999999997	52.088624000000003	52.068055999999999	Школьная	0103000020E61000000100000005000000868E1D54E2344840F6251B0FB6084A40868E1D54E234484003D2FE07580B4A402FDB4E5B2338484003D2FE07580B4A402FDB4E5B23384840F6251B0FB6084A40868E1D54E2344840F6251B0FB6084A40
31445	24686	48.648237000000002	48.685715000000002	52.247162000000003	52.217708000000002	Чапаева	0103000020E610000001000000050000005187156EF9524840EE0912DBDD1B4A405187156EF952484030682101A31F4A4036B05582C557484030682101A31F4A4036B05582C5574840EE0912DBDD1B4A405187156EF9524840EE0912DBDD1B4A40
31176	25460	49.470087999999997	49.491342000000003	51.968026000000002	51.949007000000002	Молодежная	0103000020E61000000100000005000000FB1EF5D72BBC48406956B60F79F94940FB1EF5D72BBC4840BFD6A546E8FB49405C936E4BE4BE4840BFD6A546E8FB49405C936E4BE4BE48406956B60F79F94940FB1EF5D72BBC48406956B60F79F94940
30451	24039	48.827415000000002	48.851616	52.040838000000001	52.027208000000002	Комарова	0103000020E61000000100000005000000249C16BCE869484044183F8D7B034A40249C16BCE86948408F37F92D3A054A400B60CAC0016D48408F37F92D3A054A400B60CAC0016D484044183F8D7B034A40249C16BCE869484044183F8D7B034A40
30564	53132	48.245190000000001	49.789690999999998	52.393098999999999	51.537097000000003	Садовая	0103000020E6100000010000000500000033A7CB62621F4840CEE33098BFC4494033A7CB62621F48408F8B6A1151324A4007793D9814E548408F8B6A1151324A4007793D9814E54840CEE33098BFC4494033A7CB62621F4840CEE33098BFC44940
30474	53132	48.245190000000001	49.789690999999998	52.393098999999999	51.537097000000003	Набережная	0103000020E6100000010000000500000033A7CB62621F4840CEE33098BFC4494033A7CB62621F48408F8B6A1151324A4007793D9814E548408F8B6A1151324A4007793D9814E54840CEE33098BFC4494033A7CB62621F4840CEE33098BFC44940
30168	53132	48.245190000000001	49.789690999999998	52.393098999999999	51.537097000000003	М.Горького	0103000020E6100000010000000500000033A7CB62621F4840CEE33098BFC4494033A7CB62621F48408F8B6A1151324A4007793D9814E548408F8B6A1151324A4007793D9814E54840CEE33098BFC4494033A7CB62621F4840CEE33098BFC44940
30273	53132	48.245190000000001	49.789690999999998	52.393098999999999	51.537097000000003	Камышинский переулок	0103000020E6100000010000000500000033A7CB62621F4840CEE33098BFC4494033A7CB62621F48408F8B6A1151324A4007793D9814E548408F8B6A1151324A4007793D9814E54840CEE33098BFC4494033A7CB62621F4840CEE33098BFC44940
31305	53132	48.245190000000001	49.789690999999998	52.393098999999999	51.537097000000003	Ермощенко	0103000020E6100000010000000500000033A7CB62621F4840CEE33098BFC4494033A7CB62621F48408F8B6A1151324A4007793D9814E548408F8B6A1151324A4007793D9814E54840CEE33098BFC4494033A7CB62621F4840CEE33098BFC44940
30923	25006	48.911875000000002	48.951220999999997	52.071554999999996	52.047018999999999	Советская	0103000020E610000001000000050000001F85EB51B874484033A5F5B704064A401F85EB51B8744840C16ED8B628094A405B22179CC1794840C16ED8B628094A405B22179CC179484033A5F5B704064A401F85EB51B874484033A5F5B704064A40
30477	25565	48.583477999999999	48.600149999999999	52.224466999999997	52.212967999999996	Комплексная	0103000020E61000000100000005000000BEF73768AF4A4840198C1189421B4A40BEF73768AF4A4840FF03AC55BB1C4A40E25817B7D14C4840FF03AC55BB1C4A40E25817B7D14C4840198C1189421B4A40BEF73768AF4A4840198C1189421B4A40
30480	25650	49.661428999999998	49.683985999999997	51.765400999999997	51.748314000000001	Советская	0103000020E6100000010000000500000020D099B4A9D44840C991CEC0C8DF494020D099B4A9D44840B0A9F3A8F8E14940FF756EDA8CD74840B0A9F3A8F8E14940FF756EDA8CD74840C991CEC0C8DF494020D099B4A9D44840C991CEC0C8DF4940
30994	24741	48.658568000000002	48.688464000000003	52.223224999999999	52.206389999999999	Ленина	0103000020E610000001000000050000009818CBF44B544840581CCEFC6A1A4A409818CBF44B544840265305A3921C4A40973C9E961F584840265305A3921C4A40973C9E961F584840581CCEFC6A1A4A409818CBF44B544840581CCEFC6A1A4A40
30997	25078	48.989615000000001	49.001967	52.063898999999999	52.051859999999998	Кооперативная	0103000020E61000000100000005000000C6504EB4AB7E48403BFC3559A3064A40C6504EB4AB7E4840A19FA9D72D084A40EB55647440804840A19FA9D72D084A40EB556474408048403BFC3559A3064A40C6504EB4AB7E48403BFC3559A3064A40
31330	24641	48.709178999999999	48.730756999999997	52.350442999999999	52.340660999999997	Фрунзе	0103000020E610000001000000050000004701A260C65A4840E60297C79A2B4A404701A260C65A48405A0EF450DB2C4A405A290472895D48405A0EF450DB2C4A405A290472895D4840E60297C79A2B4A404701A260C65A4840E60297C79A2B4A40
31433	25655	49.308697000000002	49.337757000000003	51.760323	51.741622	Советская	0103000020E61000000100000005000000C9AF1F6283A748403FFF3D78EDDE4940C9AF1F6283A74840C4B2994352E149405F7F129F3BAB4840C4B2994352E149405F7F129F3BAB48403FFF3D78EDDE4940C9AF1F6283A748403FFF3D78EDDE4940
31293	24909	48.587367	48.613076999999997	52.126547000000002	52.105868999999998	Кутякова	0103000020E61000000100000005000000F4DF83D72E4B484082548A1D8D0D4A40F4DF83D72E4B484016342DB132104A400377A04E794E484016342DB132104A400377A04E794E484082548A1D8D0D4A40F4DF83D72E4B484082548A1D8D0D4A40
30710	22567	49.170985000000002	49.210177999999999	51.682792999999997	51.663657999999998	Красноармейская	0103000020E61000000100000005000000A48D23D6E295484048DDCEBEF2D44940A48D23D6E29548400778D2C265D749405A2BDA1CE79A48400778D2C265D749405A2BDA1CE79A484048DDCEBEF2D44940A48D23D6E295484048DDCEBEF2D44940
31132	25508	49.507314000000001	49.527920999999999	51.809902999999998	51.793368000000001	Советская	0103000020E61000000100000005000000C76647AAEFC04840B2D826158DE54940C76647AAEFC0484055F7C8E6AAE7494091EF52EA92C3484055F7C8E6AAE7494091EF52EA92C34840B2D826158DE54940C76647AAEFC04840B2D826158DE54940
31428	25170	48.658307000000001	48.708927000000003	51.958171	51.924824999999998	Советская	0103000020E610000001000000050000002BDD5D6743544840F8C264AA60F649402BDD5D6743544840E17CEA58A5FA49402E20B41EBE5A4840E17CEA58A5FA49402E20B41EBE5A4840F8C264AA60F649402BDD5D6743544840F8C264AA60F64940
31429	25358	49.392302999999998	49.426205000000003	52.105206000000003	52.087772000000001	Школьная	0103000020E61000000100000005000000B48F15FC36B2484094C0E61C3C0B4A40B48F15FC36B24840E7ABE463770D4A402332ACE28DB64840E7ABE463770D4A402332ACE28DB6484094C0E61C3C0B4A40B48F15FC36B2484094C0E61C3C0B4A40
30846	25268	48.911389999999997	48.922896999999999	52.049101999999998	52.043894999999999	Заречная	0103000020E6100000010000000500000062F3716DA87448409DBAF2599E054A4062F3716DA874484087156EF948064A40CB49287D2176484087156EF948064A40CB49287D217648409DBAF2599E054A4062F3716DA87448409DBAF2599E054A40
30481	25158	48.490546999999999	48.536208000000002	51.932955999999997	51.913570999999997	Мира	0103000020E6100000010000000500000051137D3ECA3E484079C9FFE4EFF4494051137D3ECA3E4840B14D2A1A6BF7494042EDB776A2444840B14D2A1A6BF7494042EDB776A244484079C9FFE4EFF4494051137D3ECA3E484079C9FFE4EFF44940
30686	25836	49.380616000000003	49.414391999999999	51.611404999999998	51.593632999999997	Советская	0103000020E61000000100000005000000CC2A6C06B8B04840C669882AFCCB4940CC2A6C06B8B0484031CEDF8442CE4940ADDC0BCC0AB5484031CEDF8442CE4940ADDC0BCC0AB54840C669882AFCCB4940CC2A6C06B8B04840C669882AFCCB4940
30842	25208	48.847411999999998	48.888311999999999	51.993597999999999	51.961595000000003	Чапаевская	0103000020E61000000100000005000000751E15FF776C4840A27F828B15FB4940751E15FF776C48407DAF21382EFF49407A522635B47148407DAF21382EFF49407A522635B4714840A27F828B15FB4940751E15FF776C4840A27F828B15FB4940
30565	25082	49.031323999999998	49.082627000000002	52.111528	52.089216	Пугачевская	0103000020E610000001000000050000003ACAC16C02844840D5230D6E6B0B4A403ACAC16C028448404D4BAC8C460E4A4020628385938A48404D4BAC8C460E4A4020628385938A4840D5230D6E6B0B4A403ACAC16C02844840D5230D6E6B0B4A40
30639	12646	48.442272000000003	48.488553000000003	51.934221999999998	51.917698999999999	Советская	0103000020E61000000100000005000000E0F76F5E9C38484034492C2977F54940E0F76F5E9C384840139A249694F749406DAE9AE7883E4840139A249694F749406DAE9AE7883E484034492C2977F54940E0F76F5E9C38484034492C2977F54940
30336	20765	48.330053999999997	48.346088999999999	52.088115000000002	52.081386000000002	Гагарина	0103000020E61000000100000005000000FDF49F353F2A4840172D40DB6A0A4A40FDF49F353F2A4840BEA4315A470B4A40AF40F4A44C2C4840BEA4315A470B4A40AF40F4A44C2C4840172D40DB6A0A4A40FDF49F353F2A4840172D40DB6A0A4A40
31328	53207	48.728475000000003	48.852477999999998	52.048171000000004	51.982500000000002	Горького	0103000020E61000000100000005000000107A36AB3E5D4840F6285C8FC2FD4940107A36AB3E5D4840CDCEA2772A064A409D47C5FF1D6D4840CDCEA2772A064A409D47C5FF1D6D4840F6285C8FC2FD4940107A36AB3E5D4840F6285C8FC2FD4940
30675	53164	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Ермощенко	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
31521	53224	46.907266	47.884794999999997	50.991895999999997	50.371308999999997	Степная	0103000020E61000000100000005000000E962D34A21744740F0DAA50D872F4940E962D34A217447404084B872F67E494008556AF640F147404084B872F67E494008556AF640F14740F0DAA50D872F4940E962D34A21744740F0DAA50D872F4940
30652	52032	47.695932999999997	47.726520999999998	50.787574999999997	50.766393000000001	Ленина	0103000020E61000000100000005000000849A215514D947401171732A19624940849A215514D94740D712F241CF644940B96DDFA3FEDC4740D712F241CF644940B96DDFA3FEDC47401171732A19624940849A215514D947401171732A19624940
30383	2218	47.292445999999998	47.309908999999998	50.450429999999997	50.438073000000003	Московская	0103000020E610000001000000050000004AECDADE6EA547405C21ACC6123849404AECDADE6EA547409291B3B0A739494037DE1D19ABA747409291B3B0A739494037DE1D19ABA747405C21ACC6123849404AECDADE6EA547405C21ACC612384940
30641	53160	47.443237000000003	47.458750999999999	50.573937999999998	50.563513999999998	Колхозная	0103000020E6100000010000000500000047B071FDBBB84740486B0C3A2148494047B071FDBBB8474040F7E5CC76494940EF004F5AB8BA474040F7E5CC76494940EF004F5AB8BA4740486B0C3A2148494047B071FDBBB84740486B0C3A21484940
30442	21917	47.505229999999997	47.522117999999999	50.476008999999998	50.466487000000001	Колхозная	0103000020E61000000100000005000000A27A6B60ABC047402C8194D8B53B4940A27A6B60ABC0474003CDE7DCED3C494093533BC3D4C2474003CDE7DCED3C494093533BC3D4C247402C8194D8B53B4940A27A6B60ABC047402C8194D8B53B4940
30629	22821	47.529251000000002	47.553083000000001	50.827362000000001	50.817126000000002	Советская	0103000020E610000001000000050000000A302C7FBEC347400C5BB395976849400A302C7FBEC3474001FA7DFFE66949409E7C7A6CCBC6474001FA7DFFE66949409E7C7A6CCBC647400C5BB395976849400A302C7FBEC347400C5BB39597684940
30971	1992	47.416665000000002	47.439535999999997	50.623348999999997	50.608077999999999	Школьная	0103000020E61000000100000005000000A5315A4755B5474063B5F97FD54D4940A5315A4755B54740457F68E6C94F494013B534B742B84740457F68E6C94F494013B534B742B8474063B5F97FD54D4940A5315A4755B5474063B5F97FD54D4940
31251	1992	47.416665000000002	47.439535999999997	50.623348999999997	50.608077999999999	Молодежная	0103000020E61000000100000005000000A5315A4755B5474063B5F97FD54D4940A5315A4755B54740457F68E6C94F494013B534B742B84740457F68E6C94F494013B534B742B8474063B5F97FD54D4940A5315A4755B5474063B5F97FD54D4940
31129	49416	47.416044999999997	47.468597000000003	50.691862	50.656979	Ленина,	0103000020E6100000010000000500000008556AF640B5474053944BE31754494008556AF640B547402EAC1BEF8E5849407A008BFCFABB47402EAC1BEF8E5849407A008BFCFABB474053944BE31754494008556AF640B5474053944BE317544940
31256	23370	47.299579000000001	47.316485	50.573743999999998	50.563668999999997	Центральная	0103000020E61000000100000005000000C1C8CB9A58A647406F62484E26484940C1C8CB9A58A647405B2382717049494058569A9482A847405B2382717049494058569A9482A847406F62484E26484940C1C8CB9A58A647406F62484E26484940
30990	22914	47.663091000000001	47.680419000000001	50.957850000000001	50.945611	Крекера	0103000020E61000000100000005000000CFA2772AE0D4474072DEFFC709794940CFA2772AE0D447409F3C2CD49A7A4940DC4944F817D747409F3C2CD49A7A4940DC4944F817D7474072DEFFC709794940CFA2772AE0D4474072DEFFC709794940
30627	21834	47.552534999999999	47.578353	50.846207999999997	50.828966999999999	Советская	0103000020E610000001000000050000009B728577B9C647404B3B35971B6A49409B728577B9C6474089CE328B506C494091459A7807CA474089CE328B506C494091459A7807CA47404B3B35971B6A49409B728577B9C647404B3B35971B6A4940
30802	2049	47.367240000000002	47.404502000000001	50.783230000000003	50.765110999999997	Набережная	0103000020E610000001000000050000003BE466B801AF4740A9674128EF6149403BE466B801AF4740809F71E1406449405395B6B8C6B34740809F71E1406449405395B6B8C6B34740A9674128EF6149403BE466B801AF4740A9674128EF614940
30437	23086	47.371282000000001	47.394359999999999	50.436357999999998	50.416553999999998	Комсомольская	0103000020E61000000100000005000000F7CB272B86AF47404D8237A451354940F7CB272B86AF47408AAC3594DA374940DF6C73637AB247408AAC3594DA374940DF6C73637AB247404D8237A451354940F7CB272B86AF47404D8237A451354940
31421	23405	47.457332000000001	47.473142000000003	50.618715000000002	50.61009	Центральная	0103000020E6100000010000000500000007B5DFDA89BA4740EECEDA6D174E494007B5DFDA89BA4740B745990D324F4940992EC4EA8FBC4740B745990D324F4940992EC4EA8FBC4740EECEDA6D174E494007B5DFDA89BA4740EECEDA6D174E4940
30962	22608	47.432242000000002	47.454402999999999	50.748106999999997	50.733001999999999	Революционная	0103000020E6100000010000000500000094FAB2B453B7474088F37002D35D494094FAB2B453B747404F745DF8C15F4940261AA4E029BA47404F745DF8C15F4940261AA4E029BA474088F37002D35D494094FAB2B453B7474088F37002D35D4940
30693	21716	47.441080999999997	47.469701999999998	50.764997000000001	50.738948000000001	Садовая	0103000020E6100000010000000500000088F19A5775B84740E9B81AD9955E494088F19A5775B84740E144F46BEB614940D26EF4311FBC4740E144F46BEB614940D26EF4311FBC4740E9B81AD9955E494088F19A5775B84740E9B81AD9955E4940
30219	2161	47.604323000000001	47.652706000000002	50.496051999999999	50.472121999999999	Гагарина	0103000020E610000001000000050000003D9CC0745ACD47406EDC627E6E3C49403D9CC0745ACD4740C58EC6A17E3F494095F3C5DE8BD34740C58EC6A17E3F494095F3C5DE8BD347406EDC627E6E3C49403D9CC0745ACD47406EDC627E6E3C4940
31331	21775	47.563637999999997	47.582673999999997	50.872264999999999	50.853577999999999	Молодежная	0103000020E6100000010000000500000034643C4A25C84740E44A3D0B426D494034643C4A25C8474004392861A66F4940601DC70F95CA474004392861A66F4940601DC70F95CA4740E44A3D0B426D494034643C4A25C84740E44A3D0B426D4940
30632	21729	47.386895000000003	47.40531	50.793160999999998	50.775553000000002	Комсомольская	0103000020E6100000010000000500000033FE7DC685B1474048A819524563494033FE7DC685B1474038BBB54C86654940F25EB532E1B3474038BBB54C86654940F25EB532E1B3474048A819524563494033FE7DC685B1474048A8195245634940
30981	23188	47.150440000000003	47.180605999999997	50.554575999999997	50.538412000000001	Советская	0103000020E610000001000000050000005001309E4193474011E335AFEA4449405001309E41934740C092AB58FC4649400EBBEF181E974740C092AB58FC4649400EBBEF181E97474011E335AFEA4449405001309E4193474011E335AFEA444940
31297	22859	47.692708000000003	47.73704	50.964050999999998	50.949311000000002	переулок Школьный	0103000020E61000000100000005000000BBD6DEA7AAD84740D55DD90583794940BBD6DEA7AAD847408A56EE05667B494003ECA35357DE47408A56EE05667B494003ECA35357DE4740D55DD90583794940BBD6DEA7AAD84740D55DD90583794940
31211	18167	47.662291000000003	47.676054000000001	50.415985999999997	50.406469000000001	Центральная	0103000020E61000000100000005000000B3B794F3C5D447403EEB1A2D07344940B3B794F3C5D4474003CC7C073F3549403D2AFEEF88D6474003CC7C073F3549403D2AFEEF88D647403EEB1A2D07344940B3B794F3C5D447403EEB1A2D07344940
30163	21619	44.973956999999999	44.997376000000003	52.204641000000002	52.184116000000003	Центральная	0103000020E61000000100000005000000EA5A7B9FAA7C4640CE55F31C91174A40EA5A7B9FAA7C4640DB3521AD311A4A405CE84A04AA7F4640DB3521AD311A4A405CE84A04AA7F4640CE55F31C91174A40EA5A7B9FAA7C4640CE55F31C91174A40
31390	22304	45.720475	45.743713999999997	52.438865	52.426285999999998	Школьная	0103000020E61000000100000005000000F54A598638DC46400F5F268A90364A40F54A598638DC4640F52D73BA2C384A40E6C9350532DF4640F52D73BA2C384A40E6C9350532DF46400F5F268A90364A40F54A598638DC46400F5F268A90364A40
30782	22064	45.679592999999997	45.696553000000002	52.200274999999998	52.184280999999999	Молодежная	0103000020E6100000010000000500000096CB46E7FCD646401823128596174A4096CB46E7FCD646406B9A779CA2194A40217711A628D946406B9A779CA2194A40217711A628D946401823128596174A4096CB46E7FCD646401823128596174A40
30944	21483	45.074595000000002	45.095166999999996	52.111268000000003	52.086444	пер. Школьный	0103000020E61000000100000005000000FAB836548C894640BC77D498100B4A40FAB836548C894640B18BA2073E0E4A404754A86E2E8C4640B18BA2073E0E4A404754A86E2E8C4640BC77D498100B4A40FAB836548C894640BC77D498100B4A40
31266	21781	45.177210000000002	45.208516000000003	52.277324	52.256098999999999	Садовая	0103000020E61000000100000005000000184339D1AE964640E7C41EDAC7204A40184339D1AE964640AD32535A7F234A40AC58FCA6B09A4640AD32535A7F234A40AC58FCA6B09A4640E7C41EDAC7204A40184339D1AE964640E7C41EDAC7204A40
30783	22200	45.566845000000001	45.592374999999997	52.331482999999999	52.317832000000003	Центральная	0103000020E61000000100000005000000587380608EC84640A7CF0EB8AE284A40587380608EC846400917F2086E2A4A40E7FBA9F1D2CB46400917F2086E2A4A40E7FBA9F1D2CB4640A7CF0EB8AE284A40587380608EC84640A7CF0EB8AE284A40
30977	22390	45.673763000000001	45.693463000000001	52.448872000000001	52.433062	Мира	0103000020E610000001000000050000009F20B1DD3DD64640F7915B936E374A409F20B1DD3DD64640890B40A374394A4037FE4465C3D84640890B40A374394A4037FE4465C3D84640F7915B936E374A409F20B1DD3DD64640F7915B936E374A40
30594	21923	45.413260000000001	45.438583999999999	52.286529999999999	52.272860000000001	Светличная	0103000020E610000001000000050000005B5F24B4E5B446407B319413ED224A405B5F24B4E5B4464054A9D903AD244A404146408523B8464054A9D903AD244A404146408523B846407B319413ED224A405B5F24B4E5B446407B319413ED224A40
31268	21921	45.550693000000003	45.601745000000001	52.058433000000001	52.039386	Кооперативная	0103000020E610000001000000050000006D91B41B7DC64640CBF5B6990A054A406D91B41B7DC64640EB0088BB7A074A4009C4EBFA05CD4640EB0088BB7A074A4009C4EBFA05CD4640CBF5B6990A054A406D91B41B7DC64640CBF5B6990A054A40
31156	20750	45.464436999999997	45.514240000000001	52.025101999999997	51.99718	Политотдельская	0103000020E61000000100000005000000B306EFAB72BB4640D61C2098A3FF4940B306EFAB72BB46403788D68A36034A40C425C79DD2C146403788D68A36034A40C425C79DD2C14640D61C2098A3FF4940B306EFAB72BB4640D61C2098A3FF4940
31116	22294	45.602041	45.629009000000003	52.385223000000003	52.373085000000003	Советская	0103000020E61000000100000005000000F2ECF2AD0FCD464068D0D03FC12F4A40F2ECF2AD0FCD46406155BDFC4E314A40E1F1ED5D83D046406155BDFC4E314A40E1F1ED5D83D0464068D0D03FC12F4A40F2ECF2AD0FCD464068D0D03FC12F4A40
30586	21837	45.312891	45.335143000000002	52.194346000000003	52.160542	70 лет Октября	0103000020E610000001000000050000003B1BF2CF0CA8464035D1E7A38C144A403B1BF2CF0CA84640E10D6954E0184A40DE3D40F7E5AA4640E10D6954E0184A40DE3D40F7E5AA464035D1E7A38C144A403B1BF2CF0CA8464035D1E7A38C144A40
30392	22341	45.481459999999998	45.506720999999999	52.408990000000003	52.388306999999998	Молодежная	0103000020E61000000100000005000000842A357BA0BD464068E7340BB4314A40842A357BA0BD46400E32C9C859344A402499D53BDCC046400E32C9C859344A402499D53BDCC0464068E7340BB4314A40842A357BA0BD464068E7340BB4314A40
30637	3835	45.167642999999998	45.193676000000004	52.137399000000002	52.128056000000001	Центральная	0103000020E61000000100000005000000A0336953759546403E07962364104A40A03369537595464066C0594A96114A4093020B60CA98464066C0594A96114A4093020B60CA9846403E07962364104A40A0336953759546403E07962364104A40
31113	22023	45.406064999999998	45.423627000000003	52.225757999999999	52.211742999999998	Школьная	0103000020E610000001000000050000006E861BF0F9B34640161406651A1B4A406E861BF0F9B34640BA675DA3E51C4A40EF59D76839B64640BA675DA3E51C4A40EF59D76839B64640161406651A1B4A406E861BF0F9B34640161406651A1B4A40
30560	1873	45.495294000000001	45.514868999999997	52.152662999999997	52.141882000000003	Центральная	0103000020E61000000100000005000000D8F335CB65BF46400FF27A3029124A40D8F335CB65BF4640952710768A134A40B35C363AE7C14640952710768A134A40B35C363AE7C146400FF27A3029124A40D8F335CB65BF46400FF27A3029124A40
31262	21538	45.149380000000001	45.173966999999998	52.192016000000002	52.179416000000003	Рабочая	0103000020E61000000100000005000000975643E21E93464088307E1AF7164A40975643E21E9346408527F4FA93184A40A7CAF78C449646408527F4FA93184A40A7CAF78C4496464088307E1AF7164A40975643E21E93464088307E1AF7164A40
30164	21622	45.249406999999998	45.275530000000003	52.359233000000003	52.345205999999997	Новоселов	0103000020E610000001000000050000005D328E91EC9F46400531D0B52F2C4A405D328E91EC9F46406E52D158FB2D4A409088299144A346406E52D158FB2D4A409088299144A346400531D0B52F2C4A405D328E91EC9F46400531D0B52F2C4A40
30184	22204	45.648879000000001	45.679628999999998	52.288266	52.273769999999999	Центральная	0103000020E61000000100000005000000D50792770ED346401E5036E50A234A40D50792770ED346403D4679E6E5244A40E3344415FED646403D4679E6E5244A40E3344415FED646401E5036E50A234A40D50792770ED346401E5036E50A234A40
31112	22012	45.316313999999998	45.340055999999997	52.282195000000002	52.271455000000003	Центральная	0103000020E610000001000000050000002BA226FA7CA84640F8AA9509BF224A402BA226FA7CA84640200C3CF71E244A407F677BF486AB4640200C3CF71E244A407F677BF486AB4640F8AA9509BF224A402BA226FA7CA84640F8AA9509BF224A40
30770	21437	45.106665	45.140011000000001	52.105604	52.079912999999998	Советская	0103000020E610000001000000050000005D50DF32A78D46403BC3D4963A0A4A405D50DF32A78D4640D4298F6E840D4A40460A65E1EB914640D4298F6E840D4A40460A65E1EB9146403BC3D4963A0A4A405D50DF32A78D46403BC3D4963A0A4A40
31209	21732	44.905802000000001	44.955621999999998	52.345145000000002	52.327966000000004	Ленинская	0103000020E610000001000000050000006153E751F1734640981936CAFA294A406153E751F173464060B01BB62D2C4A4047AB5AD2517A464060B01BB62D2C4A4047AB5AD2517A4640981936CAFA294A406153E751F1734640981936CAFA294A40
30949	21714	45.196883	45.217975000000003	52.310394000000002	52.291691999999998	Молодежная 	0103000020E61000000100000005000000B6114F76339946409E40D82956254A40B6114F7633994640F46F97FDBA274A403D2CD49AE69B4640F46F97FDBA274A403D2CD49AE69B46409E40D82956254A40B6114F76339946409E40D82956254A40
31496	20050	50.164171000000003	50.187015000000002	51.681899000000001	51.665244000000001	 переулок Школьный	0103000020E61000000100000005000000CFF9298E031549401CEE23B726D54940CFF9298E031549406A16687748D74940446E861BF01749406A16687748D74940446E861BF01749401CEE23B726D54940CFF9298E031549401CEE23B726D54940
31357	20045	50.418331999999999	50.439720000000001	51.667389	51.656064999999998	Школьная	0103000020E61000000100000005000000656F29E78B3549406E861BF0F9D34940656F29E78B354940E65AB4006DD54940D5B2B5BE48384940E65AB4006DD54940D5B2B5BE483849406E861BF0F9D34940656F29E78B3549406E861BF0F9D34940
31479	20175	50.213462	50.229298999999997	51.678052000000001	51.667271999999997	Степная	0103000020E6100000010000000500000029780AB9521B4940ACC43C2B69D5494029780AB9521B4940637E6E68CAD64940B4006DAB591D4940637E6E68CAD64940B4006DAB591D4940ACC43C2B69D5494029780AB9521B4940ACC43C2B69D54940
30757	20850	49.828533999999998	49.860180999999997	52.118015	52.095021000000003	Школьная	0103000020E61000000100000005000000E1CFF0660DEA484074B7EBA5290C4A40E1CFF0660DEA4840FEB7921D1B0F4A40FED137691AEE4840FEB7921D1B0F4A40FED137691AEE484074B7EBA5290C4A40E1CFF0660DEA484074B7EBA5290C4A40
31510	53221	50.737602000000003	50.751390999999998	51.737260999999997	51.728631999999998	Степная	0103000020E610000001000000050000006BBB09BE695E4940D76839D043DD49406BBB09BE695E4940E1CE85915EDE49401EC18D942D604940E1CE85915EDE49401EC18D942D604940D76839D043DD49406BBB09BE695E4940D76839D043DD4940
30751	19886	49.921481999999997	49.943707000000003	51.983747999999999	51.975206	Советская	0103000020E6100000010000000500000024ED461FF3F54840766EDA8CD3FC494024ED461FF3F54840B1C05774EBFD4940CE001764CBF84840B1C05774EBFD4940CE001764CBF84840766EDA8CD3FC494024ED461FF3F54840766EDA8CD3FC4940
31075	20547	50.080682000000003	50.101657000000003	52.072108999999998	52.057220999999998	Школьная	0103000020E610000001000000050000001DB0ABC9530A49407CD2890453074A401DB0ABC9530A4940A65F22DE3A094A406A34B918030D4940A65F22DE3A094A406A34B918030D49407CD2890453074A401DB0ABC9530A49407CD2890453074A40
30541	19726	50.328392000000001	50.368879	51.878163000000001	51.846254999999999	Чкаловская	0103000020E610000001000000050000004F22C2BF082A4940CA89761552EC49404F22C2BF082A494054C72AA567F049403197546D372F494054C72AA567F049403197546D372F4940CA89761552EC49404F22C2BF082A4940CA89761552EC4940
31352	19726	50.328392000000001	50.368879	51.878163000000001	51.846254999999999	Ленина	0103000020E610000001000000050000004F22C2BF082A4940CA89761552EC49404F22C2BF082A494054C72AA567F049403197546D372F494054C72AA567F049403197546D372F4940CA89761552EC49404F22C2BF082A4940CA89761552EC4940
30746	20426	50.062733000000001	50.081435999999997	51.901375000000002	51.886085999999999	Советская	0103000020E61000000100000005000000A3B08BA207084940C3B81B446BF14940A3B08BA2070849404C37894160F34940C85BAE7E6C0A49404C37894160F34940C85BAE7E6C0A4940C3B81B446BF14940A3B08BA207084940C3B81B446BF14940
30426	4706	49.951127	49.963092000000003	51.975855000000003	51.973674000000003	Вокзальная	0103000020E61000000100000005000000DAAB8F87BEF94840967B8159A1FC4940DAAB8F87BEF94840AD510FD1E8FC49400685419946FB4840AD510FD1E8FC49400685419946FB4840967B8159A1FC4940DAAB8F87BEF94840967B8159A1FC4940
31064	20163	50.102519999999998	50.134149999999998	51.672355000000003	51.659472999999998	Школьная	0103000020E61000000100000005000000CC9717601F0D494029CC7B9C69D44940CC9717601F0D4940AB2688BA0FD649401361C3D32B114940AB2688BA0FD649401361C3D32B11494029CC7B9C69D44940CC9717601F0D494029CC7B9C69D44940
31065	19835	50.566741999999998	50.582687	51.784582	51.767859000000001	Западная	0103000020E6100000010000000500000083A279008B4849403A78263449E2494083A279008B484940E083D72E6DE44940F566D47C954A4940E083D72E6DE44940F566D47C954A49403A78263449E2494083A279008B4849403A78263449E24940
31150	20659	49.529547000000001	49.553001999999999	51.954374000000001	51.941279000000002	Ленина	0103000020E61000000100000005000000F3583332C8C34840AFB48CD47BF84940F3583332C8C348408C135FED28FA4940B14F00C5C8C648408C135FED28FA4940B14F00C5C8C64840AFB48CD47BF84940F3583332C8C34840AFB48CD47BF84940
30913	19945	50.306905	50.334311999999997	51.700000000000003	51.689498999999998	Интернациональная	0103000020E610000001000000050000004CFDBCA948274940F6CFD38041D849404CFDBCA9482749409A99999999D94940865451BCCA2A49409A99999999D94940865451BCCA2A4940F6CFD38041D849404CFDBCA948274940F6CFD38041D84940
30917	20304	49.932388000000003	49.948863000000003	51.684199999999997	51.678609999999999	Озерная	0103000020E6100000010000000500000068976F7D58F74840895E46B1DCD6494068976F7D58F748402BF697DD93D7494036B1C05774F948402BF697DD93D7494036B1C05774F94840895E46B1DCD6494068976F7D58F74840895E46B1DCD64940
30550	20235	49.799005999999999	49.819190999999996	51.715860999999997	51.702193999999999	Рабочая	0103000020E6100000010000000500000065A71FD445E6484045B9347EE1D9494065A71FD445E64840ADBD4F55A1DB4940B9162D40DBE84840ADBD4F55A1DB4940B9162D40DBE8484045B9347EE1D9494065A71FD445E6484045B9347EE1D94940
31060	19828	50.506762000000002	50.535544000000002	51.924785999999997	51.908431999999998	Советская	0103000020E61000000100000005000000836DC493DD404940E751F17F47F44940836DC493DD4049403AE63C635FF64940D6C8AEB48C4449403AE63C635FF64940D6C8AEB48C444940E751F17F47F44940836DC493DD404940E751F17F47F44940
30531	20594	49.798144000000001	49.847057	52.008496999999998	51.986533000000001	Перетрухина	0103000020E61000000100000005000000D3BF249529E648405FB69DB646FE4940D3BF249529E648409B8E006E16014A40876C205D6CEC48409B8E006E16014A40876C205D6CEC48405FB69DB646FE4940D3BF249529E648405FB69DB646FE4940
30845	20756	49.495401999999999	49.522765	51.988368999999999	51.978839000000001	Школьная	0103000020E61000000100000005000000BE2F2E5569BF48405186AA984AFD4940BE2F2E5569BF4840ABB019E082FE4940293FA9F6E9C24840ABB019E082FE4940293FA9F6E9C248405186AA984AFD4940BE2F2E5569BF48405186AA984AFD4940
31055	18997	49.664070000000002	49.696058999999998	51.182389000000001	51.169553999999998	Набережная	0103000020E610000001000000050000009B20EA3E00D54840F7730AF2B39549409B20EA3E00D548403813D38558974940118B187618D948403813D38558974940118B187618D94840F7730AF2B39549409B20EA3E00D54840F7730AF2B3954940
30478	19574	50.080035000000002	50.103974999999998	51.500607000000002	51.481765000000003	Терешковой	0103000020E6100000010000000500000087C43D963E0A4940C1ADBB79AABD494087C43D963E0A49400893E2E313C04940014D840D4F0D49400893E2E313C04940014D840D4F0D4940C1ADBB79AABD494087C43D963E0A4940C1ADBB79AABD4940
30934	2456	49.899580999999998	49.930168999999999	51.331553999999997	51.309218999999999	Рабочая	0103000020E610000001000000050000002E8D5F7825F34840A226FA7C94A749402E8D5F7825F34840D26D895C70AA494063601DC70FF74840D26D895C70AA494063601DC70FF74840A226FA7C94A749402E8D5F7825F34840A226FA7C94A74940
31059	19217	49.674948999999998	49.709434999999999	51.433743	51.412883999999998	Октябрьская	0103000020E61000000100000005000000E4BB94BA64D6484055850662D9B44940E4BB94BA64D6484039EFFFE384B74940A2D11DC4CEDA484039EFFFE384B74940A2D11DC4CEDA484055850662D9B44940E4BB94BA64D6484055850662D9B44940
30323	19407	49.804791000000002	49.827060000000003	51.638741000000003	51.620570999999998	Чапаевская	0103000020E61000000100000005000000BD8E386403E748404AECDADE6ECF4940BD8E386403E74840A3CEDC43C2D1494036EA211ADDE94840A3CEDC43C2D1494036EA211ADDE948404AECDADE6ECF4940BD8E386403E748404AECDADE6ECF4940
31052	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Советская	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
30300	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Молодежная	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
30519	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Ленина	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
31046	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Комарова	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
30522	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Кирова	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
30307	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Вольская	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
30516	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Ветеранов	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
31087	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	Александрова	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
30192	4104	49.692411999999997	49.759704999999997	51.215890999999999	51.183795000000003	8 Марта	0103000020E61000000100000005000000D1ADD7F4A0D848408C15359886974940D1ADD7F4A0D848401840F850A29B4940C8CD70033EE148401840F850A29B4940C8CD70033EE148408C15359886974940D1ADD7F4A0D848408C15359886974940
30325	19411	49.952986000000003	49.978183999999999	51.615957000000002	51.598886	площадь Революции	0103000020E61000000100000005000000DFC5FB71FBF948402104E44BA8CC4940DFC5FB71FBF94840035FD1ADD7CE494038BC202235FD4840035FD1ADD7CE494038BC202235FD48402104E44BA8CC4940DFC5FB71FBF948402104E44BA8CC4940
30935	4703	50.282550999999998	50.307174000000003	51.537277000000003	51.51484	Школьная	0103000020E61000000100000005000000DE3994A12A2449401956F146E6C14940DE3994A12A2449404EF2237EC5C449403C17467A512749404EF2237EC5C449403C17467A512749401956F146E6C14940DE3994A12A2449401956F146E6C14940
30529	9306	49.729773000000002	49.774876999999996	51.279660999999997	51.261308	Советская	0103000020E610000001000000050000007D40A03369DD48407217618A72A149407D40A03369DD4840BB7B80EECBA3494017B6662B2FE34840BB7B80EECBA3494017B6662B2FE348407217618A72A149407D40A03369DD48407217618A72A14940
30899	2353	49.383220999999999	49.429842999999998	51.179904999999998	51.155987000000003	Пионерская	0103000020E61000000100000005000000F911BF620DB14840F3CCCB61F7934940F911BF620DB1484085B18520079749400FB56D1805B7484085B18520079749400FB56D1805B74840F3CCCB61F7934940F911BF620DB14840F3CCCB61F7934940
30848	19111	49.511913999999997	49.534030000000001	51.390931000000002	51.374118000000003	Школьная	0103000020E61000000100000005000000A92EE06586C14840276C3F19E3AF4940A92EE06586C148400DFFE9060AB249409C8A54185BC448400DFFE9060AB249409C8A54185BC44840276C3F19E3AF4940A92EE06586C14840276C3F19E3AF4940
30729	18999	49.771481999999999	49.785674999999998	51.162607000000001	51.151415999999998	Школьная	0103000020E61000000100000005000000F1B913ECBFE24840AA0B789961934940F1B913ECBFE24840E38C614ED0944940742497FF90E44840E38C614ED0944940742497FF90E44840AA0B789961934940F1B913ECBFE24840AA0B789961934940
30540	19517	50.067998000000003	50.080188	51.431722000000001	51.411423999999997	Набережная	0103000020E61000000100000005000000C2189128B40849400E65A88AA9B44940C2189128B40849405B7B9FAA42B749400DC4B299430A49405B7B9FAA42B749400DC4B299430A49400E65A88AA9B44940C2189128B40849400E65A88AA9B44940
31227	19319	49.911394000000001	49.926772999999997	51.420012	51.399529000000001	Советская	0103000020E61000000100000005000000A4E2FF8EA8F44840DC662AC423B34940A4E2FF8EA8F44840BAF605F4C2B549406CE8667FA0F64840BAF605F4C2B549406CE8667FA0F64840DC662AC423B34940A4E2FF8EA8F44840DC662AC423B34940
30283	17168	48.958210000000001	48.979239	50.681601000000001	50.670265000000001	Зеленая	0103000020E610000001000000050000009F5912A0A67A4840A453573ECB5549409F5912A0A67A4840E0F599B33E574940DFFB1BB4577D4840E0F599B33E574940DFFB1BB4577D4840A453573ECB5549409F5912A0A67A4840A453573ECB554940
31452	17455	48.701740999999998	48.709367999999998	50.615456999999999	50.611685000000001	Центральная	0103000020E6100000010000000500000094A12AA6D2594840153AAFB14B4E494094A12AA6D2594840118C834BC74E49401A6A1492CC5A4840118C834BC74E49401A6A1492CC5A4840153AAFB14B4E494094A12AA6D2594840153AAFB14B4E4940
30831	18211	48.217413999999998	48.245666	50.594236000000002	50.584892000000004	Центральная	0103000020E61000000100000005000000A5D8D138D41B484095D8B5BDDD4A4940A5D8D138D41B48408D0DDDEC0F4C49409CDEC5FB711F48408D0DDDEC0F4C49409CDEC5FB711F484095D8B5BDDD4A4940A5D8D138D41B484095D8B5BDDD4A4940
30428	16969	48.111502999999999	48.128328000000003	50.174129999999998	50.162450999999997	Клубная	0103000020E61000000100000005000000F433F5BA450E4840EB19C231CB144940F433F5BA450E484051A04FE4491649409F94490D6D10484051A04FE4491649409F94490D6D104840EB19C231CB144940F433F5BA450E4840EB19C231CB144940
31410	17024	48.169238	48.245612000000001	50.795302	50.769942	Радищева	0103000020E61000000100000005000000C79E3D97A91548408EE89E758D624940C79E3D97A9154840C138B874CC654940A9C0C936701F4840C138B874CC654940A9C0C936701F48408EE89E758D624940C79E3D97A91548408EE89E758D624940
30722	18162	48.661335000000001	48.689065999999997	50.716129000000002	50.694491999999997	Центральная	0103000020E610000001000000050000009F5912A0A6544840B4AA251DE55849409F5912A0A6544840CD5B751DAA5B49408C648F5033584840CD5B751DAA5B49408C648F5033584840B4AA251DE55849409F5912A0A6544840B4AA251DE5584940
30288	18162	48.661335000000001	48.689065999999997	50.716129000000002	50.694491999999997	Новостепная	0103000020E610000001000000050000009F5912A0A6544840B4AA251DE55849409F5912A0A6544840CD5B751DAA5B49408C648F5033584840CD5B751DAA5B49408C648F5033584840B4AA251DE55849409F5912A0A6544840B4AA251DE5584940
30864	53177	48.234859999999998	48.275480999999999	50.466475000000003	50.448044000000003	Дружбы	0103000020E61000000100000005000000BC9179E40F1E4840A3957B8159394940BC9179E40F1E484068B3EA73B53B4940AED51EF64223484068B3EA73B53B4940AED51EF642234840A3957B8159394940BC9179E40F1E4840A3957B8159394940
31341	17988	48.040779000000001	48.096572999999999	50.472512000000002	50.459147000000002	Радищева	0103000020E610000001000000050000008AAE0B3F380548403C873254C53A49408AAE0B3F38054840D97BF1457B3C49409B560A815C0C4840D97BF1457B3C49409B560A815C0C48403C873254C53A49408AAE0B3F380548403C873254C53A4940
31340	17921	48.618628999999999	48.651246999999998	50.538795	50.513306999999998	Копылова	0103000020E61000000100000005000000B8AD2D3C2F4F484068E7340BB4414940B8AD2D3C2F4F4840C91F0C3CF74449401E4FCB0F5C534840C91F0C3CF74449401E4FCB0F5C53484068E7340BB4414940B8AD2D3C2F4F484068E7340BB4414940
31201	17860	47.905383999999998	47.930573000000003	50.262962000000002	50.249952	Площадь Революции	0103000020E610000001000000050000002C29779FE3F34740EFC8586DFE1F49402C29779FE3F347409E0B23BDA821494033C51C041DF747409E0B23BDA821494033C51C041DF74740EFC8586DFE1F49402C29779FE3F34740EFC8586DFE1F4940
30282	17162	48.686442999999997	48.706555999999999	50.763441999999998	50.746898999999999	Школьная	0103000020E61000000100000005000000B8C83D5DDD5748402235ED629A5F4940B8C83D5DDD5748404832AB77B86149407365506D705A48404832AB77B86149407365506D705A48402235ED629A5F4940B8C83D5DDD5748402235ED629A5F4940
31016	16800	48.313184	48.333458999999998	50.388829000000001	50.379139000000002	Советская	0103000020E61000000100000005000000B3D0CE6916284840AFD172A087304940B3D0CE6916284840425E0F26C531494047C7D5C8AE2A4840425E0F26C531494047C7D5C8AE2A4840AFD172A087304940B3D0CE6916284840AFD172A087304940
31534	16800	48.313184	48.333458999999998	50.388829000000001	50.379139000000002	Молодежная	0103000020E61000000100000005000000B3D0CE6916284840AFD172A087304940B3D0CE6916284840425E0F26C531494047C7D5C8AE2A4840425E0F26C531494047C7D5C8AE2A4840AFD172A087304940B3D0CE6916284840AFD172A087304940
30486	17081	48.739649999999997	48.775897000000001	50.692649000000003	50.671629000000003	Советская	0103000020E61000000100000005000000423EE8D9AC5E4840C90567F0F7554940423EE8D9AC5E4840B64DF1B8A85849404208C89750634840B64DF1B8A85849404208C89750634840C90567F0F7554940423EE8D9AC5E4840C90567F0F7554940
31198	17770	48.389539999999997	48.419435999999997	50.729598000000003	50.711435000000002	Первомайская	0103000020E61000000100000005000000EE3D5C72DC314840691D554D105B4940EE3D5C72DC3148400F9D9E77635D4940ED612F14B03548400F9D9E77635D4940ED612F14B0354840691D554D105B4940EE3D5C72DC314840691D554D105B4940
31041	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	пл.Льва Толстого	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
31182	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	Хайкина	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
30509	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	Трутнева	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
31023	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	Степная	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
30482	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	Советская	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
30483	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	Микрорайон-2	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
30646	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	Зеленый Клин	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
31086	9228	48.108916000000001	48.176971999999999	50.488103000000002	50.417140000000003	Елецкая	0103000020E610000001000000050000006D01A1F5F00D48403EEDF0D7643549406D01A1F5F00D48402D0ABB287A3E49406327BC04A71648402D0ABB287A3E49406327BC04A71648403EEDF0D7643549406D01A1F5F00D48403EEDF0D764354940
30813	16876	48.113047999999999	48.125418000000003	50.354908999999999	50.343936999999997	Трудовая	0103000020E6100000010000000500000069705B5B780E48403271AB20062C494069705B5B780E48402D077AA86D2D4940352A70B20D1048402D077AA86D2D4940352A70B20D1048403271AB20062C494069705B5B780E48403271AB20062C4940
31608	53242	47.985917999999998	47.997641000000002	50.183214999999997	50.173465999999998	Московская	0103000020E61000000100000005000000D4449F8F32FE4740E57B462234164940D4449F8F32FE47407D91D096731749400A1346B3B2FF47407D91D096731749400A1346B3B2FF4740E57B462234164940D4449F8F32FE4740E57B462234164940
30271	16870	48.162374	48.190688999999999	50.258054999999999	50.249053000000004	Центральная	0103000020E6100000010000000500000040DCD5ABC814484040FCFCF7E01F494040DCD5ABC8144840DEC83CF2072149407D5A457F68184840DEC83CF2072149407D5A457F6818484040FCFCF7E01F494040DCD5ABC814484040FCFCF7E01F4940
31196	3891	48.003704999999997	48.067791	50.746831	50.698697000000003	Площадь Революции	0103000020E6100000010000000500000074EACA67790048401B683EE76E59494074EACA6779004840CA518028985F494048FB1F60AD084840CA518028985F494048FB1F60AD0848401B683EE76E59494074EACA67790048401B683EE76E594940
30292	3891	48.003704999999997	48.067791	50.746831	50.698697000000003	Молодежная	0103000020E6100000010000000500000074EACA67790048401B683EE76E59494074EACA6779004840CA518028985F494048FB1F60AD084840CA518028985F494048FB1F60AD0848401B683EE76E59494074EACA67790048401B683EE76E594940
31186	17314	48.008242000000003	48.020108	50.590800000000002	50.584332000000003	Молодежная	0103000020E61000000100000005000000113AE8120E014840CE001764CB4A4940113AE8120E014840083D9B559F4B4940A93121E692024840083D9B559F4B4940A93121E692024840CE001764CB4A4940113AE8120E014840CE001764CB4A4940
31038	17577	47.991819999999997	48.023764	50.706449999999997	50.686874000000003	Площадь Космонавтов	0103000020E6100000010000000500000065C22FF5F3FE4740823CBB7CEB57494065C22FF5F3FE47402D211FF46C5A49403C69E1B20A0348402D211FF46C5A49403C69E1B20A034840823CBB7CEB57494065C22FF5F3FE4740823CBB7CEB574940
30716	3927	48.441625000000002	48.463714000000003	50.788035999999998	50.773485000000001	Центральная	0103000020E610000001000000050000004A0C022B873848402979758E016349404A0C022B873848400B09185DDE6449404359F8FA5A3B48400B09185DDE6449404359F8FA5A3B48402979758E016349404A0C022B873848402979758E01634940
30958	13773	47.709507000000002	47.733455999999997	50.536842999999998	50.523902999999997	Рабочая	0103000020E610000001000000050000003CA41820D1DA47405DA3E5400F4349403CA41820D1DA4740130B7C45B74449400987DEE2E1DD4740130B7C45B74449400987DEE2E1DD47405DA3E5400F4349403CA41820D1DA47405DA3E5400F434940
30709	17379	48.561073999999998	48.574593	50.669043000000002	50.641655	Почтовая	0103000020E610000001000000050000006551D845D14748404E2844C0215249406551D845D1474840124F7633A355494059C16F438C494840124F7633A355494059C16F438C4948404E2844C0215249406551D845D14748404E2844C021524940
31334	17258	47.962724000000001	47.981516999999997	50.649622999999998	50.629246000000002	Советская	0103000020E6100000010000000500000083893F8A3AFB4740C59107228B50494083893F8A3AFB47405DDDB1D826534940E8BB5B59A2FD47405DDDB1D826534940E8BB5B59A2FD4740C59107228B50494083893F8A3AFB4740C59107228B504940
31207	18068	47.953156999999997	47.972892999999999	50.452683999999998	50.443328000000001	Рабочая	0103000020E610000001000000050000000B7A6F0C01FA474057B3CEF8BE3849400B7A6F0C01FA474013B69F8CF1394940F0C000C287FC474013B69F8CF1394940F0C000C287FC474057B3CEF8BE3849400B7A6F0C01FA474057B3CEF8BE384940
30295	4040	48.171042999999997	48.193868999999999	50.531387000000002	50.52026	Новоузенская	0103000020E61000000100000005000000D89AADBCE41548405FB532E197424940D89AADBCE415484081423D7D04444940A75A0BB3D018484081423D7D04444940A75A0BB3D01848405FB532E197424940D89AADBCE41548405FB532E197424940
31442	16974	48.250642999999997	48.284294000000003	50.786180000000002	50.769708000000001	Октябрьская	0103000020E6100000010000000500000054FCDF11152048401BBCAFCA8562494054FCDF11152048407862D68BA16449407A39ECBE632448407862D68BA16449407A39ECBE632448401BBCAFCA8562494054FCDF11152048401BBCAFCA85624940
30868	17265	47.988028999999997	48.001908	50.604751	50.595773999999999	Целинная	0103000020E61000000100000005000000F23FF9BB77FE47404FE78A52424C4940F23FF9BB77FE4740959C137B684D4940E6CC76853E004840959C137B684D4940E6CC76853E0048404FE78A52424C4940F23FF9BB77FE47404FE78A52424C4940
31015	16730	48.118743000000002	48.149115000000002	50.416589000000002	50.396833999999998	Центральная	0103000020E6100000010000000500000081D07AF8320F48406EF8DD74CB32494081D07AF8320F4840CA6FD1C952354940E92B483316134840CA6FD1C952354940E92B4833161348406EF8DD74CB32494081D07AF8320F48406EF8DD74CB324940
31257	2684	46.059454000000002	46.108016999999997	51.972619999999999	51.956944	Чернышевского	0103000020E61000000100000005000000E6CE4C309C0747403D0D18247DFA4940E6CE4C309C074740BFB7E9CF7EFC4940BD344580D30D4740BFB7E9CF7EFC4940BD344580D30D47403D0D18247DFA4940E6CE4C309C0747403D0D18247DFA4940
30457	15504	46.113568999999998	46.147407999999999	52.083416999999997	52.054091999999997	Советская	0103000020E61000000100000005000000726BD26D890E4740D47C957CEC064A40726BD26D890E474018778368AD0A4A409A95ED43DE12474018778368AD0A4A409A95ED43DE124740D47C957CEC064A40726BD26D890E4740D47C957CEC064A40
31013	15200	46.167369000000001	46.177250000000001	51.877518999999999	51.862777000000001	Первомайская	0103000020E610000001000000050000009FAEEE586C154740D95E0B7A6FEE49409FAEEE586C1547402F4FE78A52F04940A69BC420B01647402F4FE78A52F04940A69BC420B0164740D95E0B7A6FEE49409FAEEE586C154740D95E0B7A6FEE4940
31354	15299	46.039081000000003	46.106346000000002	52.145606999999998	52.114144000000003	Советская	0103000020E610000001000000050000008F72309B000547406F8445459C0E4A408F72309B00054740CA880B40A3124A40BC07E8BE9C0D4740CA880B40A3124A40BC07E8BE9C0D47406F8445459C0E4A408F72309B000547406F8445459C0E4A40
30841	15299	46.039081000000003	46.106346000000002	52.145606999999998	52.114144000000003	Гагарина	0103000020E610000001000000050000008F72309B000547406F8445459C0E4A408F72309B00054740CA880B40A3124A40BC07E8BE9C0D4740CA880B40A3124A40BC07E8BE9C0D47406F8445459C0E4A408F72309B000547406F8445459C0E4A40
30255	15299	46.039081000000003	46.106346000000002	52.145606999999998	52.114144000000003	Баумана	0103000020E610000001000000050000008F72309B000547406F8445459C0E4A408F72309B00054740CA880B40A3124A40BC07E8BE9C0D4740CA880B40A3124A40BC07E8BE9C0D47406F8445459C0E4A408F72309B000547406F8445459C0E4A40
30796	15395	46.340654000000001	46.358162	51.970422999999997	51.952447999999997	Центральная	0103000020E6100000010000000500000034A0DE8C9A2B4740FF91E9D0E9F9494034A0DE8C9A2B4740A22424D236FC4940C1559E40D82D4740A22424D236FC4940C1559E40D82D4740FF91E9D0E9F9494034A0DE8C9A2B4740FF91E9D0E9F94940
30215	15603	45.913406000000002	45.938963000000001	52.038438999999997	52.013424999999998	Колхозная	0103000020E610000001000000050000002FFCE07CEAF4464072F90FE9B7014A402FFCE07CEAF446400AF2B391EB044A40B89388F02FF846400AF2B391EB044A40B89388F02FF8464072F90FE9B7014A402FFCE07CEAF4464072F90FE9B7014A40
30476	16071	45.829988999999998	45.854953000000002	52.301391000000002	52.276051000000002	Шарковых	0103000020E6100000010000000500000016855D143DEA46409983A0A355234A4016855D143DEA46408527F4FA93264A40FD4E93196FED46408527F4FA93264A40FD4E93196FED46409983A0A355234A4016855D143DEA46409983A0A355234A40
30465	2807	45.842457000000003	45.869208999999998	52.154553	52.110509999999998	Молодежная	0103000020E61000000100000005000000A5A487A1D5EB4640C3F01131250E4A40A5A487A1D5EB4640D53F8864C8134A40C631923D42EF4640D53F8864C8134A40C631923D42EF4640C3F01131250E4A40A5A487A1D5EB4640C3F01131250E4A40
30648	16114	45.879880999999997	45.906039999999997	52.405527999999997	52.383392999999998	Юбилейная	0103000020E6100000010000000500000096AFCBF09FF04640F641960513314A4096AFCBF09FF046405FCE6C57E8334A40156F641EF9F346405FCE6C57E8334A40156F641EF9F34640F641960513314A4096AFCBF09FF04640F641960513314A40
30685	16058	45.702795999999999	45.734408000000002	52.289037	52.269229000000003	Новая	0103000020E610000001000000050000003BE12538F5D9464041118B1876224A403BE12538F5D94640BF2A172AFF244A40DCF5D21401DE4640BF2A172AFF244A40DCF5D21401DE464041118B1876224A403BE12538F5D9464041118B1876224A40
30460	2732	46.228175999999998	46.248944999999999	52.011263	51.991413000000001	Первомайская	0103000020E61000000100000005000000B5DD04DF341D474025EA059FE6FE4940B5DD04DF341D4740D253E41071014A4059C0046EDD1F4740D253E41071014A4059C0046EDD1F474025EA059FE6FE4940B5DD04DF341D474025EA059FE6FE4940
30458	15550	46.002375000000001	46.043104999999997	52.079011000000001	52.048043999999997	Кооперативная	0103000020E61000000100000005000000FCA9F1D24D0047406F62484E26064A40FCA9F1D24D0047401B834E081D0A4A40A4A5F276840547401B834E081D0A4A40A4A5F276840547406F62484E26064A40FCA9F1D24D0047406F62484E26064A40
31625	53241	46.076971	46.109499	52.370137999999997	52.353842999999998	Мирная	0103000020E61000000100000005000000C6DE8B2FDA094740927538BA4A2D4A40C6DE8B2FDA094740E08096AE602F4A40ECF82F10040E4740E08096AE602F4A40ECF82F10040E4740927538BA4A2D4A40C6DE8B2FDA094740927538BA4A2D4A40
31124	15676	45.712542999999997	45.756011999999998	52.101101	52.080947999999999	Колхозная	0103000020E6100000010000000500000032FFE89B34DB46409B560A815C0A4A4032FFE89B34DB4640E44BA8E0F00C4A4018B14F00C5E04640E44BA8E0F00C4A4018B14F00C5E046409B560A815C0A4A4032FFE89B34DB46409B560A815C0A4A40
31002	15964	45.803794000000003	45.833672	52.266672	52.258861000000003	Элеваторная	0103000020E610000001000000050000004B5CC7B8E2E64640DD9A745B22214A404B5CC7B8E2E646402461DF4E22224A40A3CB9BC3B5EA46402461DF4E22224A40A3CB9BC3B5EA4640DD9A745B22214A404B5CC7B8E2E64640DD9A745B22214A40
30259	15889	46.104137000000001	46.143932	52.216417	52.203079000000002	Советская	0103000020E61000000100000005000000DBA6785C540D474090C01F7EFE194A40DBA6785C540D474033A6608DB31B4A40876C205D6C12474033A6608DB31B4A40876C205D6C12474090C01F7EFE194A40DBA6785C540D474090C01F7EFE194A40
31318	15957	45.841468999999996	45.873252000000001	52.250371000000001	52.232664	Октябрьская	0103000020E6100000010000000500000085CC9541B5EB4640707A17EFC71D4A4085CC9541B5EB4640F46E2C280C204A405395B6B8C6EF4640F46E2C280C204A405395B6B8C6EF4640707A17EFC71D4A4085CC9541B5EB4640707A17EFC71D4A40
30490	15251	46.153965999999997	46.166713000000001	51.934100000000001	51.911444000000003	Советская 	0103000020E6100000010000000500000014596B28B513474056116E32AAF4494014596B28B5134740C898BB9690F74940B66801DA56154740C898BB9690F74940B66801DA5615474056116E32AAF4494014596B28B513474056116E32AAF44940
30304	12934	47.049182000000002	47.072915999999999	51.862336999999997	51.848303000000001	Первомайская	0103000020E61000000100000005000000A4C684984B864740A20C553195EC4940A4C684984B864740BC900E0F61EE494075ADBD4F55894740BC900E0F61EE494075ADBD4F55894740A20C553195EC4940A4C684984B864740A20C553195EC4940
30438	13818	47.741495999999998	47.754773	51.575836000000002	51.567383999999997	Центральная	0103000020E61000000100000005000000B20E4757E9DE47400723F609A0C84940B20E4757E9DE474003EE79FEB4C94940B073D3669CE0474003EE79FEB4C94940B073D3669CE047400723F609A0C84940B20E4757E9DE47400723F609A0C84940
31276	13544	47.306711	47.318784999999998	51.560167	51.548121000000002	Центральная	0103000020E610000001000000050000006729594E42A747401BA034D428C649406729594E42A7474033A6608DB3C7494049BA66F2CDA8474033A6608DB3C7494049BA66F2CDA847401BA034D428C649406729594E42A747401BA034D428C64940
31144	13879	47.333956999999998	47.355364000000002	51.67107	51.649861999999999	Целинная	0103000020E6100000010000000500000098A25C1ABFAA4740E27492AD2ED3494098A25C1ABFAA4740D2A92B9FE5D549407F164B917CAD4740D2A92B9FE5D549407F164B917CAD4740E27492AD2ED3494098A25C1ABFAA4740E27492AD2ED34940
31423	14634	46.588822999999998	46.608441999999997	51.542940000000002	51.531612000000003	Заречная	0103000020E61000000100000005000000F910548D5E4B4740A114ADDC0BC44940F910548D5E4B47405AD8D30E7FC54940A4C16D6DE14D47405AD8D30E7FC54940A4C16D6DE14D4740A114ADDC0BC44940F910548D5E4B4740A114ADDC0BC44940
30805	13110	47.215801999999996	47.222152999999999	51.611767999999998	51.603507	Душанбинская	0103000020E61000000100000005000000A83462669F9B47401BF4A5B73FCD4940A83462669F9B4740A25EF0694ECE4940A9DA6E826F9C4740A25EF0694ECE4940A9DA6E826F9C47401BF4A5B73FCD4940A83462669F9B47401BF4A5B73FCD4940
31141	13596	47.479312999999998	47.491979999999998	51.488484	51.481831999999997	Рабочая	0103000020E6100000010000000500000019C6DD205ABD47404815C5ABACBD494019C6DD205ABD4740444FCAA486BE49409E245D33F9BE4740444FCAA486BE49409E245D33F9BE47404815C5ABACBD494019C6DD205ABD47404815C5ABACBD4940
31393	12976	47.335287000000001	47.354708000000002	51.774424000000003	51.759687	Школьная	0103000020E6100000010000000500000011E335AFEAAA47402219726C3DE1494011E335AFEAAA4740679E5C5320E3494096D05D1267AD4740679E5C5320E3494096D05D1267AD47402219726C3DE1494011E335AFEAAA47402219726C3DE14940
30830	14620	46.623614000000003	46.642640999999998	51.512703999999999	51.503701999999997	Мелиораторов	0103000020E61000000100000005000000F4A96395D24F47400377A04E79C04940F4A96395D24F4740A243E048A0C14940CC086F0F42524740A243E048A0C14940CC086F0F425247400377A04E79C04940F4A96395D24F47400377A04E79C04940
30422	13039	47.273384	47.286113	51.638668000000003	51.630578999999997	Центральная	0103000020E61000000100000005000000F59F353FFEA24740AE450BD0B6D04940F59F353FFEA2474039807EDFBFD14940F0FACC599FA4474039807EDFBFD14940F0FACC599FA44740AE450BD0B6D04940F59F353FFEA24740AE450BD0B6D04940
30665	14346	46.699916999999999	46.739299000000003	51.697806	51.684339999999999	К. Маркса	0103000020E610000001000000050000000C7558E1965947401DACFF7398D749400C7558E196594740EE79FEB451D94940967B8159A15E4740EE79FEB451D94940967B8159A15E47401DACFF7398D749400C7558E1965947401DACFF7398D74940
31579	53235	47.219951999999999	47.236210999999997	51.683858999999998	51.667695999999999	Мира	0103000020E610000001000000050000004B581B63279C4740C3D5011077D549404B581B63279C4740A20914B188D749404CFA7B293C9E4740A20914B188D749404CFA7B293C9E4740C3D5011077D549404B581B63279C4740C3D5011077D54940
30343	13210	47.009422999999998	47.029204	51.827461999999997	51.812821	Ленина	0103000020E61000000100000005000000446ADAC5348147404240BE840AE84940446ADAC53481474064575A46EAE94940C974E8F4BC83474064575A46EAE94940C974E8F4BC8347404240BE840AE84940446ADAC5348147404240BE840AE84940
30644	13210	47.009422999999998	47.029204	51.827461999999997	51.812821	Комсомольская	0103000020E61000000100000005000000446ADAC5348147404240BE840AE84940446ADAC53481474064575A46EAE94940C974E8F4BC83474064575A46EAE94940C974E8F4BC8347404240BE840AE84940446ADAC5348147404240BE840AE84940
31304	14247	46.677325000000003	46.712592000000001	51.685507000000001	51.671841000000001	Революции	0103000020E61000000100000005000000B1E1E995B2564740548EC9E2FED54940B1E1E995B2564740EC1681B1BED7494014B2F336365B4740EC1681B1BED7494014B2F336365B4740548EC9E2FED54940B1E1E995B2564740548EC9E2FED54940
30635	14528	46.799270999999997	46.828071000000001	51.582917000000002	51.569752000000001	Школьная	0103000020E6100000010000000500000013D21A834E664740516A2FA2EDC8494013D21A834E66474027A435069DCA49400DE2033BFE69474027A435069DCA49400DE2033BFE694740516A2FA2EDC8494013D21A834E664740516A2FA2EDC84940
30456	14826	46.872421000000003	46.917057999999997	51.767161999999999	51.754072999999998	Ленина 	0103000020E61000000100000005000000FCABC77DAB6F4740F7E5CC7685E04940FCABC77DAB6F4740F25D4A5D32E249408044132862754740F25D4A5D32E249408044132862754740F7E5CC7685E04940FCABC77DAB6F4740F7E5CC7685E04940
30996	12932	47.015172	47.045642999999998	51.839399999999998	51.822330000000001	Советская	0103000020E610000001000000050000004FE8F527F18147408542041C42E949404FE8F527F181474096218E7571EB49404A253CA1D785474096218E7571EB49404A253CA1D78547408542041C42E949404FE8F527F18147408542041C42E94940
30418	13487	47.384802000000001	47.421354000000001	51.555956000000002	51.535623999999999	Молодежная	0103000020E61000000100000005000000BBB7223141B14740F279C5538FC44940BBB7223141B14740EB01F39029C74940F70489EDEEB54740EB01F39029C74940F70489EDEEB54740F279C5538FC44940BBB7223141B14740F279C5538FC44940
31249	14454	46.595523999999997	46.618637999999997	51.687266000000001	51.675952000000002	Школьная	0103000020E61000000100000005000000D6FD63213A4C474039D55A9885D64940D6FD63213A4C47408DD31055F8D749400B08AD872F4F47408DD31055F8D749400B08AD872F4F474039D55A9885D64940D6FD63213A4C474039D55A9885D64940
30821	13766	47.595187000000003	47.603594999999999	51.673175999999998	51.662394999999997	Овражная	0103000020E610000001000000050000008F006E162FCC47405704FF5BC9D449408F006E162FCC4740DE3994A12AD64940BA83D89942CD4740DE3994A12AD64940BA83D89942CD47405704FF5BC9D449408F006E162FCC47405704FF5BC9D44940
31290	12854	47.246650000000002	47.272162000000002	51.771096999999997	51.759960999999997	Ленина	0103000020E610000001000000050000007AC7293A929F4740239EEC6646E149407AC7293A929F47409885764EB3E24940639B5434D6A247409885764EB3E24940639B5434D6A24740239EEC6646E149407AC7293A929F4740239EEC6646E14940
30444	13962	47.209496000000001	47.236866999999997	51.572578999999998	51.553178000000003	Кировская	0103000020E610000001000000050000004852D2C3D09A4740F06E6589CEC649404852D2C3D09A47402DB0C7444AC94940354069A8519E47402DB0C7444AC94940354069A8519E4740F06E6589CEC649404852D2C3D09A4740F06E6589CEC64940
30645	13400	47.021137000000003	47.047781000000001	51.711827	51.695723999999998	Заречная	0103000020E6100000010000000500000027DE019EB48247406A85E97B0DD9494027DE019EB482474074B4AA251DDB4940622F14B01D86474074B4AA251DDB4940622F14B01D8647406A85E97B0DD9494027DE019EB48247406A85E97B0DD94940
31009	14244	46.881269000000003	46.904876999999999	51.583928999999998	51.568817000000003	Ленина	0103000020E6100000010000000500000044FD2E6CCD7047405534D6FECEC8494044FD2E6CCD704740CE177B2FBECA494088F37002D3734740CE177B2FBECA494088F37002D37347405534D6FECEC8494044FD2E6CCD7047405534D6FECEC84940
30982	14059	47.078691999999997	47.105857	51.519424999999998	51.500757999999998	Центральная	0103000020E61000000100000005000000793A5794128A4740ED9A90D618C04940793A5794128A4740C6DCB5847CC24940BE86E0B88C8D4740C6DCB5847CC24940BE86E0B88C8D4740ED9A90D618C04940793A5794128A4740ED9A90D618C04940
30815	13673	47.591405000000002	47.611275999999997	51.533904	51.514487000000003	Школьная	0103000020E610000001000000050000006FD8B628B3CB4740CC9BC3B5DAC149406FD8B628B3CB47400F9A5DF756C44940336ABE4A3ECE47400F9A5DF756C44940336ABE4A3ECE4740CC9BC3B5DAC149406FD8B628B3CB4740CC9BC3B5DAC14940
30803	12729	47.163376	47.192742000000003	51.903225999999997	51.892755999999999	Ленина	0103000020E61000000100000005000000C4793881E994474065A71FD445F24940C4793881E9944740CD72D9E89CF34940674815C5AB984740CD72D9E89CF34940674815C5AB98474065A71FD445F24940C4793881E994474065A71FD445F24940
30817	13676	47.570177999999999	47.596175000000002	51.598427000000001	51.582430000000002	Почтовая	0103000020E610000001000000050000000873BB97FBC84740CA1AF5108DCA49400873BB97FBC847408E05854199CC4940AED85F764FCC47408E05854199CC4940AED85F764FCC4740CA1AF5108DCA49400873BB97FBC84740CA1AF5108DCA4940
30419	12805	47.261715000000002	47.287550000000003	51.939030000000002	51.927501999999997	Комсомольская	0103000020E61000000100000005000000B3EF8AE07FA14740BF7CB262B8F64940B3EF8AE07FA1474040FB912232F849407FFB3A70CEA4474040FB912232F849407FFB3A70CEA44740BF7CB262B8F64940B3EF8AE07FA14740BF7CB262B8F64940
30643	12852	47.246659000000001	47.267581	51.927129999999998	51.915970999999999	Интернациональная	0103000020E61000000100000005000000CD21A985929F4740CE8AA8893EF54940CD21A985929F4740FB912232ACF64940F7031E1840A24740FB912232ACF64940F7031E1840A24740CE8AA8893EF54940CD21A985929F4740CE8AA8893EF54940
31146	13966	47.293084	47.310124999999999	51.508383000000002	51.491669000000002	Калинина	0103000020E610000001000000050000008D7DC9C683A5474080BA8102EFBE49408D7DC9C683A54740D36BB3B112C1494004560E2DB2A74740D36BB3B112C1494004560E2DB2A7474080BA8102EFBE49408D7DC9C683A5474080BA8102EFBE4940
30659	14071	47.094465999999997	47.114310000000003	51.594600999999997	51.583437000000004	Комсомольская	0103000020E61000000100000005000000BE4A3E76178C474060234910AECA4940BE4A3E76178C47409E95B4E21BCC49408ACDC7B5A18E47409E95B4E21BCC49408ACDC7B5A18E474060234910AECA4940BE4A3E76178C474060234910AECA4940
31408	12730	47.188349000000002	47.217491000000003	51.911926999999999	51.900219999999997	Центральная	0103000020E61000000100000005000000FE9DEDD11B984740419AB1683AF34940FE9DEDD11B98474071AB2006BAF449405116BEBED69B474071AB2006BAF449405116BEBED69B4740419AB1683AF34940FE9DEDD11B984740419AB1683AF34940
30807	14163	46.854598000000003	46.883172999999999	51.684479000000003	51.668075999999999	Почтовая	0103000020E610000001000000050000000F9D9E77636D47400A9FAD8383D549400F9D9E77636D47403FE603029DD74940E8DA17D00B7147403FE603029DD74940E8DA17D00B7147400A9FAD8383D549400F9D9E77636D47400A9FAD8383D54940
30623	14395	46.615079999999999	46.650348000000001	51.652343999999999	51.643385000000002	Центральная	0103000020E610000001000000050000003B3602F1BA4E474055DE8E705AD249403B3602F1BA4E4740F4DE180280D349406F826F9A3E534740F4DE180280D349406F826F9A3E53474055DE8E705AD249403B3602F1BA4E474055DE8E705AD24940
31379	13503	47.487093000000002	47.503245	51.579777	51.572583999999999	Фрунзе	0103000020E61000000100000005000000268E3C1059BE47403F1BB96E4AC94940268E3C1059BE47408BFCFA2136CA4940117008556AC047408BFCFA2136CA4940117008556AC047403F1BB96E4AC94940268E3C1059BE47403F1BB96E4AC94940
30985	14114	46.823759000000003	46.845193000000002	51.668925000000002	51.650449000000002	З. Космодемьянской	0103000020E61000000100000005000000916456EF70694740A35BAFE941D34940916456EF70694740083D9B559FD5494071E7C2482F6C4740083D9B559FD5494071E7C2482F6C4740A35BAFE941D34940916456EF70694740A35BAFE941D34940
30191	13321	46.973588999999997	47.000314000000003	51.806077000000002	51.787022	Чапаева	0103000020E61000000100000005000000675F79909E7C4740C39D0B23BDE44940675F79909E7C47406687F8872DE7494090DD054A0A8047406687F8872DE7494090DD054A0A804740C39D0B23BDE44940675F79909E7C4740C39D0B23BDE44940
30196	13394	46.932364999999997	46.949334	51.766877999999998	51.759197	Колхозная	0103000020E61000000100000005000000AF777FBC57774740541C075E2DE14940AF777FBC57774740CD02ED0E29E249408D7DC9C683794740CD02ED0E29E249408D7DC9C683794740541C075E2DE14940AF777FBC57774740541C075E2DE14940
31299	14743	46.765180000000001	46.786560000000001	51.674515999999997	51.667814	Центральная	0103000020E61000000100000005000000D2C6116BF1614740CDE7DCED7AD54940D2C6116BF16147407A50508A56D64940BF2B82FFAD6447407A50508A56D64940BF2B82FFAD644740CDE7DCED7AD54940D2C6116BF1614740CDE7DCED7AD54940
30630	3075	44.631824999999999	44.670560000000002	51.640445	51.625922000000003	Садовая	0103000020E61000000100000005000000C9E53FA4DF50464068EC4B361ED04940C9E53FA4DF50464080F10C1AFAD14940BD00FBE8D455464080F10C1AFAD14940BD00FBE8D455464068EC4B361ED04940C9E53FA4DF50464068EC4B361ED04940
30204	11997	45.094709000000002	45.130201	51.560648	51.552573000000002	Центральная	0103000020E6100000010000000500000085D1AC6C1F8C464089D349B6BAC6494085D1AC6C1F8C4640AE484C50C3C749400874266DAA904640AE484C50C3C749400874266DAA90464089D349B6BAC6494085D1AC6C1F8C464089D349B6BAC64940
30447	53155	44.536890999999997	45.458993	51.701495999999999	51.079065	Транспортная	0103000020E61000000100000005000000244223D8B84446400EA14ACD1E8A4940244223D8B84446402D23F59ECAD94940E50B5A48C0BA46402D23F59ECAD94940E50B5A48C0BA46400EA14ACD1E8A4940244223D8B84446400EA14ACD1E8A4940
31028	12263	45.059575000000002	45.080379999999998	51.354531000000001	51.324637000000003	Садовая	0103000020E6100000010000000500000061545227A0874640290989B48DA9494061545227A08746408735954561AD494051A04FE4498A46408735954561AD494051A04FE4498A4640290989B48DA9494061545227A0874640290989B48DA94940
30631	11849	44.806870000000004	44.841743000000001	51.635123999999998	51.617635	Песчаная	0103000020E61000000100000005000000D00F238447674640B7EEE6A90ECF4940D00F238447674640CD7344BE4BD149408751103CBE6B4640CD7344BE4BD149408751103CBE6B4640B7EEE6A90ECF4940D00F238447674640B7EEE6A90ECF4940
30362	11673	44.745767000000001	44.775069999999999	51.391505000000002	51.372430999999999	Набережная	0103000020E61000000100000005000000D0B7054B755F46401F82AAD1ABAF4940D0B7054B755F4640399CF9D51CB249402C0E677E35634640399CF9D51CB249402C0E677E356346401F82AAD1ABAF4940D0B7054B755F46401F82AAD1ABAF4940
30773	9221	44.914569	44.952388999999997	51.446576999999998	51.421832000000002	Заречная	0103000020E61000000100000005000000BC77D4981075464001344A97FEB54940BC77D49810754640A912656F29B94940FA08FCE1E7794640A912656F29B94940FA08FCE1E779464001344A97FEB54940BC77D4981075464001344A97FEB54940
30590	12577	45.230218999999998	45.256163000000001	51.246724999999998	51.23556	Школьная	0103000020E610000001000000050000007BF5F1D0779D4640751F80D4269E49407BF5F1D0779D4640840D4FAF949F4940FEB8FDF2C9A04640840D4FAF949F4940FEB8FDF2C9A04640751F80D4269E49407BF5F1D0779D4640751F80D4269E4940
30369	11905	45.040270999999997	45.064804000000002	51.555261000000002	51.544983999999999	Почтовая	0103000020E6100000010000000500000015FDA19927854640F06B2409C2C5494015FDA1992785464044DFDDCA12C7494033535A7F4B88464044DFDDCA12C7494033535A7F4B884640F06B2409C2C5494015FDA19927854640F06B2409C2C54940
30178	11856	44.931547999999999	44.952756999999998	51.564270999999998	51.543180999999997	Садовая	0103000020E61000000100000005000000BD5301F73C7746407F677BF486C54940BD5301F73C774640658A39083AC849407D04FEF0F3794640658A39083AC849407D04FEF0F37946407F677BF486C54940BD5301F73C7746407F677BF486C54940
30533	12410	44.930973000000002	44.961478999999997	51.233235999999998	51.208240000000004	Центральная	0103000020E61000000100000005000000C13A8E1F2A7746400ADCBA9BA79A4940C13A8E1F2A774640FB1F60ADDA9D494038656EBE117B4640FB1F60ADDA9D494038656EBE117B46400ADCBA9BA79A4940C13A8E1F2A7746400ADCBA9BA79A4940
31134	3039	44.822816000000003	44.858586000000003	51.566929999999999	51.534939999999999	пл. 50 лет Октября	0103000020E610000001000000050000001250E108526946403FA9F6E978C449401250E10852694640868F882991C84940D8666325E66D4640868F882991C84940D8666325E66D46403FA9F6E978C449401250E108526946403FA9F6E978C44940
30951	3039	44.822816000000003	44.858586000000003	51.566929999999999	51.534939999999999	Пионерская	0103000020E610000001000000050000001250E108526946403FA9F6E978C449401250E10852694640868F882991C84940D8666325E66D4640868F882991C84940D8666325E66D46403FA9F6E978C449401250E108526946403FA9F6E978C44940
67043	3151	45.172314	45.204546000000001	51.440739000000001	51.426729000000002	Набережная	0103000020E610000001000000050000004C5299620E9646409DA04D0E9FB649404C5299620E9646402F89B3226AB84940894336902E9A46402F89B3226AB84940894336902E9A46409DA04D0E9FB649404C5299620E9646409DA04D0E9FB64940
30849	12492	45.278683999999998	45.308014	51.394061999999998	51.380735000000001	Советская,	0103000020E6100000010000000500000090F5D4EAABA34640A6B8AAECBBB0494090F5D4EAABA34640554CA59F70B24940E65AB4006DA74640554CA59F70B24940E65AB4006DA74640A6B8AAECBBB0494090F5D4EAABA34640A6B8AAECBBB04940
30984	12002	45.203414000000002	45.225566000000001	51.485864999999997	51.465983999999999	Мира	0103000020E6100000010000000500000037C64E78099A4640C93A1C5DA5BB494037C64E78099A4640B1A206D330BE4940768BC058DF9C4640B1A206D330BE4940768BC058DF9C4640C93A1C5DA5BB494037C64E78099A4640C93A1C5DA5BB4940
31090	11659	44.791491000000001	44.829372999999997	51.538761000000001	51.506723000000001	Молодежная	0103000020E61000000100000005000000070ABC934F654640C5909C4CDCC04940070ABC934F6546401DAED51EF6C44940BB97FBE4286A46401DAED51EF6C44940BB97FBE4286A4640C5909C4CDCC04940070ABC934F654640C5909C4CDCC04940
31220	12350	44.981233000000003	45.016438000000001	51.201608999999998	51.180937999999998	Советская	0103000020E61000000100000005000000C460FE0A997D4640444DF4F928974940C460FE0A997D464025CADE52CE994940B134F0A31A82464025CADE52CE994940B134F0A31A824640444DF4F928974940C460FE0A997D4640444DF4F928974940
30811	11726	44.718305999999998	44.765332000000001	51.610996999999998	51.590197000000003	Ленинская	0103000020E61000000100000005000000A2427573F15B4640429946938BCB4940A2427573F15B4640207A522635CE4940884A2366F6614640207A522635CE4940884A2366F6614640429946938BCB4940A2427573F15B4640429946938BCB4940
30598	12601	45.172277999999999	45.195787000000003	51.330540999999997	51.316138000000002	Дорожная	0103000020E61000000100000005000000FFE89B340D964640ED82C13577A84940FFE89B340D9646405A7EE02A4FAA4940B1FD648C0F9946405A7EE02A4FAA4940B1FD648C0F994640ED82C13577A84940FFE89B340D964640ED82C13577A84940
30240	12484	45.242427999999997	45.270473000000003	51.354633	51.341704999999997	Школьная	0103000020E610000001000000050000003DD175E1079F464099F04BFDBCAB49403DD175E1079F46408B8A389D64AD4940BBB9F8DB9EA246408B8A389D64AD4940BBB9F8DB9EA2464099F04BFDBCAB49403DD175E1079F464099F04BFDBCAB4940
31264	12331	45.0045	45.011983000000001	51.317061000000002	51.308430000000001	Центральная	0103000020E610000001000000050000007F6ABC74938046407A8D5DA27AA749407F6ABC749380464025EB707495A84940D28DB0A88881464025EB707495A84940D28DB0A8888146407A8D5DA27AA749407F6ABC74938046407A8D5DA27AA74940
30972	3212	44.825484000000003	44.845193000000002	51.300806000000001	51.283554000000002	Школьная	0103000020E6100000010000000500000086AFAF75A969464033535A7F4BA4494086AFAF75A969464065389ECF80A6494071E7C2482F6C464065389ECF80A6494071E7C2482F6C464033535A7F4BA4494086AFAF75A969464033535A7F4BA44940
31364	11182	48.852801999999997	48.885472999999998	51.746613000000004	51.728135000000002	Радищева	0103000020E6100000010000000500000050FBAD9D286D48405709168733DD494050FBAD9D286D48405DE2C80391DF4940D93EE42D577148405DE2C80391DF4940D93EE42D577148405709168733DD494050FBAD9D286D48405709168733DD4940
30927	10969	48.733514	48.766643999999999	51.922493000000003	51.903565	Центральная	0103000020E610000001000000050000003E9468C9E35D4840B6679604A8F349403E9468C9E35D4840FCE4284014F649405AD6FD6321624840FCE4284014F649405AD6FD6321624840B6679604A8F349403E9468C9E35D4840B6679604A8F34940
30333	10873	48.332776000000003	48.379748999999997	51.870663	51.825702999999997	М.Горького	0103000020E6100000010000000500000065726A67982A4840C39ACAA2B0E9494065726A67982A48402B6B9BE271EF494027D87F9D9B3048402B6B9BE271EF494027D87F9D9B304840C39ACAA2B0E9494065726A67982A4840C39ACAA2B0E94940
31654	53178	48.956943000000003	48.976823000000003	51.737501000000002	51.723025	улица Лопатина	0103000020E610000001000000050000006D91B41B7D7A48405F984C158CDC49406D91B41B7D7A484037E2C96E66DE4940857D3B89087D484037E2C96E66DE4940857D3B89087D48405F984C158CDC49406D91B41B7D7A48405F984C158CDC4940
30867	53178	48.956943000000003	48.976823000000003	51.737501000000002	51.723025	Кузнецова	0103000020E610000001000000050000006D91B41B7D7A48405F984C158CDC49406D91B41B7D7A484037E2C96E66DE4940857D3B89087D484037E2C96E66DE4940857D3B89087D48405F984C158CDC49406D91B41B7D7A48405F984C158CDC4940
30910	10799	48.484681000000002	48.51773	51.707299999999996	51.694673999999999	Ленинская	0103000020E610000001000000050000000DFFE9060A3E4840D5B0DF13EBD849400DFFE9060A3E4840FB3A70CE88DA49403C1405FA44424840FB3A70CE88DA49403C1405FA44424840D5B0DF13EBD849400DFFE9060A3E4840D5B0DF13EBD84940
31006	11391	48.523434000000002	48.552880999999999	51.583896000000003	51.570222000000001	Советская	0103000020E61000000100000005000000A7CEA3E2FF424840D8BAD408FDC84940A7CEA3E2FF424840F321A81ABDCA494036CAFACDC4464840F321A81ABDCA494036CAFACDC4464840D8BAD408FDC84940A7CEA3E2FF424840D8BAD408FDC84940
30744	11054	48.885553999999999	48.917237999999998	51.826521	51.805320000000002	Советская	0103000020E61000000100000005000000C66B5ED5597148404968CBB914E74940C66B5ED559714840863AAC70CBE949400053060E68754840863AAC70CBE949400053060E687548404968CBB914E74940C66B5ED5597148404968CBB914E74940
30752	11334	48.542335000000001	48.565663999999998	51.543258999999999	51.528167000000003	Центральная	0103000020E61000000100000005000000F33CB83B6B454840C9E9EBF99AC34940F33CB83B6B454840FB20CB8289C5494024438EAD67484840FB20CB8289C5494024438EAD67484840C9E9EBF99AC34940F33CB83B6B454840C9E9EBF99AC34940
30549	10966	48.728996000000002	48.769609000000003	51.829248999999997	51.809207000000001	Центральная	0103000020E610000001000000050000001975ADBD4F5D4840DE58501894E749401975ADBD4F5D4840CF9ECBD424EA494088DA368C82624840CF9ECBD424EA494088DA368C82624840DE58501894E749401975ADBD4F5D4840DE58501894E74940
30898	11228	49.109639000000001	49.12491	51.639958999999998	51.628442999999997	Школьная	0103000020E61000000100000005000000DEAE97A6088E48403733FAD170D04940DEAE97A6088E4840F3E32F2DEAD14940C078060DFD8F4840F3E32F2DEAD14940C078060DFD8F48403733FAD170D04940DEAE97A6088E48403733FAD170D04940
30353	11279	48.759520999999999	48.788643999999998	51.628152999999998	51.610968999999997	Степная	0103000020E6100000010000000500000007D0EFFB3761484056EF703B34CE494007D0EFFB3761484030F1475167D04940E3175E49F264484030F1475167D04940E3175E49F264484056EF703B34CE494007D0EFFB3761484056EF703B34CE4940
30339	11052	48.728062000000001	48.775348999999999	51.770662000000002	51.742620000000002	Школьная	0103000020E61000000100000005000000EDBAB722315D484082AD122C0EDF4940EDBAB722315D48408E226B0DA5E249403FFED2A23E6348408E226B0DA5E249403FFED2A23E63484082AD122C0EDF4940EDBAB722315D484082AD122C0EDF4940
30775	2974	48.521081000000002	48.542389	51.618808999999999	51.604005000000001	Молодежная	0103000020E6100000010000000500000093C83EC8B24248406CCF2C0950CD494093C83EC8B242484038BC202235CF4940E65AB4006D45484038BC202235CF4940E65AB4006D4548406CCF2C0950CD494093C83EC8B24248406CCF2C0950CD4940
31072	11141	48.785671000000001	48.800232000000001	51.681542	51.667428000000001	Чапаевская	0103000020E61000000100000005000000333509DE90644840A437DC476ED54940333509DE90644840DB6CACC43CD74940399B8E006E664840DB6CACC43CD74940399B8E006E664840A437DC476ED54940333509DE90644840A437DC476ED54940
31267	707	48.516724000000004	48.595255000000002	51.801822999999999	51.739457999999999	Стадионная площадь	0103000020E610000001000000050000007787140324424840FE614B8FA6DE494077871403244248401E17D522A2E64940E7E3DA50314C48401E17D522A2E64940E7E3DA50314C4840FE614B8FA6DE49407787140324424840FE614B8FA6DE4940
30510	707	48.516724000000004	48.595255000000002	51.801822999999999	51.739457999999999	Новая	0103000020E610000001000000050000007787140324424840FE614B8FA6DE494077871403244248401E17D522A2E64940E7E3DA50314C48401E17D522A2E64940E7E3DA50314C4840FE614B8FA6DE49407787140324424840FE614B8FA6DE4940
31474	707	48.516724000000004	48.595255000000002	51.801822999999999	51.739457999999999	Горная	0103000020E610000001000000050000007787140324424840FE614B8FA6DE494077871403244248401E17D522A2E64940E7E3DA50314C48401E17D522A2E64940E7E3DA50314C4840FE614B8FA6DE49407787140324424840FE614B8FA6DE4940
30566	11326	48.714326	48.739972999999999	51.536766999999998	51.520422000000003	Кутузова	0103000020E610000001000000050000005C57CC086F5B4840390F27309DC249405C57CC086F5B48403849F3C7B4C4494025766D6FB75E48403849F3C7B4C4494025766D6FB75E4840390F27309DC249405C57CC086F5B4840390F27309DC24940
31477	10878	48.500509000000001	48.534996	51.892906000000004	51.867576	Советская	0103000020E61000000100000005000000452DCDAD10404840B265F9BA0CEF4940452DCDAD104048407B336ABE4AF24940D3BEB9BF7A4448407B336ABE4AF24940D3BEB9BF7A444840B265F9BA0CEF4940452DCDAD10404840B265F9BA0CEF4940
30317	9993	47.214813999999997	47.244987999999999	50.982149	50.964725999999999	Школьная	0103000020E61000000100000005000000895C70067F9B4740EACC3D247C7B4940895C70067F9B47404966F50EB77D4940CBF44BC45B9F47404966F50EB77D4940CBF44BC45B9F4740EACC3D247C7B4940895C70067F9B4740EACC3D247C7B4940
31351	10190	47.034728000000001	47.065055000000001	50.736457000000001	50.717104999999997	Центральная	0103000020E61000000100000005000000B42094F7718447402766BD18CA5B4940B42094F77184474084F41439445E49407CB8E4B85388474084F41439445E49407CB8E4B8538847402766BD18CA5B4940B42094F7718447402766BD18CA5B4940
30318	10097	46.881610000000002	46.932662000000001	50.803209000000003	50.760359000000001	Клубный	0103000020E61000000100000005000000CDE9B298D8704740111C977153614940CDE9B298D87047402B6D718DCF664940691CEA77617747402B6D718DCF664940691CEA7761774740111C977153614940CDE9B298D8704740111C977153614940
30895	9592	47.047907000000002	47.065334	50.92165	50.909055000000002	Зеленая	0103000020E61000000100000005000000EF1F0BD121864740F5A10BEA5B744940EF1F0BD121864740E02D90A0F87549408FA850DD5C884740E02D90A0F87549408FA850DD5C884740F5A10BEA5B744940EF1F0BD121864740F5A10BEA5B744940
31063	10556	46.653447	46.674486000000002	50.973399000000001	50.957731000000003	Школьная	0103000020E61000000100000005000000AC55BB26A4534740C5AEEDED967A4940AC55BB26A4534740C47AA356987C494010CEA78E55564740C47AA356987C494010CEA78E55564740C5AEEDED967A4940AC55BB26A4534740C5AEEDED967A4940
30740	10496	46.734071	46.780684999999998	50.938845999999998	50.922092999999997	Зеленая	0103000020E6100000010000000500000094F8DC09F65D47406D6FB7240776494094F8DC09F65D47407EFD101B2C78494027BD6F7CED6347407EFD101B2C78494027BD6F7CED6347406D6FB7240776494094F8DC09F65D47406D6FB72407764940
30495	10606	46.954580999999997	46.980443000000001	50.937358000000003	50.928344000000003	Центральная	0103000020E610000001000000050000000531D0B52F7A47400BB8E7F9D37649400531D0B52F7A47406E52D158FB774940CB4BFE277F7D47406E52D158FB774940CB4BFE277F7D47400BB8E7F9D37649400531D0B52F7A47400BB8E7F9D3764940
31347	9634	47.048904	47.072690999999999	51.010652	50.983448000000003	Новая	0103000020E6100000010000000500000061527C7C4286474087A8C29FE17D494061527C7C4286474089D1730B5D81494055DB4DF04D89474089D1730B5D81494055DB4DF04D89474087A8C29FE17D494061527C7C4286474087A8C29FE17D4940
30543	10253	46.907238999999997	46.927774999999997	50.661267000000002	50.630046	Центральная	0103000020E61000000100000005000000EF53556820744740E17CEA58A5504940EF535568207447404776A565A4544940F085C954C17647404776A565A4544940F085C954C1764740E17CEA58A5504940EF53556820744740E17CEA58A5504940
31054	9729	47.128017999999997	47.153953000000001	51.085622999999998	51.067995000000003	Центральная	0103000020E6100000010000000500000050A6D1E46290474051A5660FB488494050A6D1E4629047408864C8B1F58A4940800F5EBBB49347408864C8B1F58A4940800F5EBBB493474051A5660FB488494050A6D1E46290474051A5660FB4884940
31230	10400	46.908183000000001	46.934189000000003	50.966296999999997	50.940916999999999	Советская	0103000020E610000001000000050000003FE42D573F7447400EA0DFF76F7849403FE42D573F744740889CBE9EAF7B494038A4518193774740889CBE9EAF7B494038A45181937747400EA0DFF76F7849403FE42D573F7447400EA0DFF76F784940
31217	512	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	пер.Спортивный	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
30889	512	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	пер. Инкубаторный	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
30303	512	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	Московская	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
30401	512	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	Куховаренко	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
31346	512	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	Комсомольская	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
30930	512	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	Астраханская	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
30322	512	46.945678000000001	46.991681	50.973182999999999	50.936235000000003	Авиационная	0103000020E61000000100000005000000FA4509FA0B7947406F2F698CD6774940FA4509FA0B794740F702B342917C494044882B67EF7E4740F702B342917C494044882B67EF7E47406F2F698CD6774940FA4509FA0B7947406F2F698CD6774940
31229	10062	47.027973000000003	47.062027999999998	50.794186000000003	50.775798000000002	Советская,	0103000020E61000000100000005000000E415889E94834740AF264F594D634940E415889E94834740757808E3A7654940D8B79388F0874740757808E3A7654940D8B79388F0874740AF264F594D634940E415889E94834740AF264F594D634940
30537	10334	46.686092000000002	46.716689000000002	50.812264999999996	50.799093999999997	Центральная	0103000020E610000001000000050000000C06D7DCD1574740043752B6486649400C06D7DCD1574740BC57AD4CF867494094331477BC5B4740BC57AD4CF867494094331477BC5B4740043752B6486649400C06D7DCD1574740043752B648664940
31057	9885	47.247773000000002	47.277695999999999	51.110199999999999	51.092910000000003	Центральная	0103000020E6100000010000000500000079EA9106B79F474056BC9179E48B494079EA9106B79F474075029A081B8E4940711DE38A8BA3474075029A081B8E4940711DE38A8BA3474056BC9179E48B494079EA9106B79F474056BC9179E48B4940
30908	10506	46.695821000000002	46.732076999999997	51.096428000000003	51.080235999999999	Школьная	0103000020E610000001000000050000005D6F9BA9105947401EFB592C458A49405D6F9BA9105947409835B1C0578C4940AF93FAB2B45D47409835B1C0578C4940AF93FAB2B45D47401EFB592C458A49405D6F9BA9105947401EFB592C458A4940
31050	9527	46.968873000000002	47.005488	50.981836999999999	50.960147999999997	Центральная	0103000020E610000001000000050000001C7DCC07047C4740EFA83121E67A49401C7DCC07047C47405A80B6D5AC7D49409E42AED4B38047405A80B6D5AC7D49409E42AED4B3804740EFA83121E67A49401C7DCC07047C4740EFA83121E67A4940
31470	9992	47.121074	47.145085999999999	50.893666000000003	50.882483999999998	Центральная	0103000020E61000000100000005000000AD32535A7F8F4740239F573CF5704940AD32535A7F8F474009C6C1A563724940C18D942D9292474009C6C1A563724940C18D942D92924740239F573CF5704940AD32535A7F8F4740239F573CF5704940
31468	9736	47.140936000000004	47.162011	51.071832999999998	51.054036000000004	Центральная	0103000020E610000001000000050000001F6ADB300A9247404167D2A6EA8649401F6ADB300A92474004E3E0D231894940CF4BC5C6BC94474004E3E0D231894940CF4BC5C6BC9447404167D2A6EA8649401F6ADB300A9247404167D2A6EA864940
30319	10192	46.756565000000002	46.803879000000002	50.737112000000003	50.699747000000002	Энгельса	0103000020E610000001000000050000002D26361FD7604740B03C484F915949402D26361FD76047409DBE9EAF595E49407978CF81E56647409DBE9EAF595E49407978CF81E5664740B03C484F915949402D26361FD7604740B03C484F91594940
31469	9941	46.998832	47.023103999999996	50.961526999999997	50.943340999999997	Советская	0103000020E6100000010000000500000061191BBAD97F4740EBFCDB65BF78494061191BBAD97F4740499C1551137B494011346612F5824740499C1551137B494011346612F5824740EBFCDB65BF78494061191BBAD97F4740EBFCDB65BF784940
30907	10397	46.917256000000002	46.952064999999997	50.945531000000003	50.922649	Солнечный	0103000020E61000000100000005000000A70705A568754740F357C85C19764940A70705A568754740562DE9280779494047551344DD794740562DE9280779494047551344DD794740F357C85C19764940A70705A568754740F357C85C19764940
31342	8830	45.531128000000002	45.560457999999997	50.980804999999997	50.969479999999997	Центральная	0103000020E61000000100000005000000B5FE9600FCC346402310AFEB177C4940B5FE9600FCC346406B60AB048B7D49400A647616BDC746406B60AB048B7D49400A647616BDC746402310AFEB177C4940B5FE9600FCC346402310AFEB177C4940
31462	470	45.363169999999997	45.392006000000002	51.074362000000001	51.058360999999998	Ленина	0103000020E61000000100000005000000B471C45A7CAE4640512E8D5F78874940B471C45A7CAE46405708ABB184894940FBEAAA402DB246405708ABB184894940FBEAAA402DB24640512E8D5F78874940B471C45A7CAE4640512E8D5F78874940
30869	7819	45.764662999999999	45.790444999999998	51.196474000000002	51.183179000000003	Красноармейская	0103000020E610000001000000050000000ABB287AE0E146403128D368729749400ABB287AE0E14640D5415E0F26994940B324404D2DE54640D5415E0F26994940B324404D2DE546403128D368729749400ABB287AE0E146403128D36872974940
31029	8274	45.703946000000002	45.735809000000003	50.902937000000001	50.890273999999998	Центральная	0103000020E6100000010000000500000034130CE71ADA4640533D997FF471494034130CE71ADA464097AC8A70937349401E8D43FD2EDE464097AC8A70937349401E8D43FD2EDE4640533D997FF471494034130CE71ADA4640533D997FF4714940
30390	8054	45.849141000000003	45.869613000000001	50.935048000000002	50.921207000000003	Советская	0103000020E61000000100000005000000AC58FCA6B0EC464053EC681CEA754940AC58FCA6B0EC4640591822A7AF7749409696917A4FEF4640591822A7AF7749409696917A4FEF464053EC681CEA754940AC58FCA6B0EC464053EC681CEA754940
30881	8597	45.470519000000003	45.498313000000003	50.790393999999999	50.777985000000001	Школьная	0103000020E61000000100000005000000C59272F739BC4640A8E3310395634940C59272F739BC4640317A6EA12B654940F9156BB8C8BF4640317A6EA12B654940F9156BB8C8BF4640A8E3310395634940C59272F739BC4640A8E3310395634940
31088	53191	45.485880000000002	45.522792000000003	51.196016	51.167966999999997	Пионерская	0103000020E61000000100000005000000E7E3DA5031BE464053E751F17F954940E7E3DA5031BE464012BF620D17994940234E27D9EAC2464012BF620D17994940234E27D9EAC2464053E751F17F954940E7E3DA5031BE464053E751F17F954940
31031	8382	45.640335999999998	45.657386000000002	50.734718000000001	50.726461999999998	Кооперативная	0103000020E61000000100000005000000C939B187F6D14640B4E4F1B4FC5C4940C939B187F6D146402AE44A3D0B5E4940946C753925D446402AE44A3D0B5E4940946C753925D44640B4E4F1B4FC5C4940C939B187F6D14640B4E4F1B4FC5C4940
31461	9102	45.282870000000003	45.325170999999997	51.171508000000003	51.154032000000001	Кирова	0103000020E6100000010000000500000080828B1535A44640CC441152B793494080828B1535A446404E8061F9F3954940C64D0D349FA946404E8061F9F3954940C64D0D349FA94640CC441152B793494080828B1535A44640CC441152B7934940
30708	8319	45.616073	45.639932000000002	50.792152999999999	50.782769000000002	Вишневая	0103000020E610000001000000050000006C79E57ADBCE46404CA94BC6316449406C79E57ADBCE4640D236FE4465654940FAD4B14AE9D14640D236FE4465654940FAD4B14AE9D146404CA94BC6316449406C79E57ADBCE46404CA94BC631644940
31175	7287	45.651924999999999	45.677607000000002	51.177872000000001	51.161346999999999	Волжская	0103000020E61000000100000005000000EF38454772D346406327BC04A7944940EF38454772D34640E36F7B82C4964940354580D3BBD64640E36F7B82C4964940354580D3BBD646406327BC04A7944940EF38454772D346406327BC04A7944940
30556	53158	45.082715999999998	46.067494000000003	51.246195	50.550558000000002	Захарова	0103000020E610000001000000050000008F6D1970968A46408D463EAF784649408F6D1970968A464028B85851839F49408F56B5A4A308474028B85851839F49408F56B5A4A30847408D463EAF784649408F6D1970968A46408D463EAF78464940
30697	251	45.679206000000001	45.706246	50.977390999999997	50.964770999999999	Ульяновская	0103000020E610000001000000050000009D9FE238F0D646408A90BA9D7D7B49409D9FE238F0D64640CE33F6251B7D49402577D84466DA4640CE33F6251B7D49402577D84466DA46408A90BA9D7D7B49409D9FE238F0D646408A90BA9D7D7B4940
31473	326	45.514608000000003	45.541682999999999	51.039777000000001	50.959949000000002	Школьная	0103000020E610000001000000050000004721C9ACDEC14640F969DC9BDF7A49404721C9ACDEC146400611A969178549404BE658DE55C546400611A969178549404BE658DE55C54640F969DC9BDF7A49404721C9ACDEC14640F969DC9BDF7A4940
31454	326	45.514608000000003	45.541682999999999	51.039777000000001	50.959949000000002	Почтовая	0103000020E610000001000000050000004721C9ACDEC14640F969DC9BDF7A49404721C9ACDEC146400611A969178549404BE658DE55C546400611A969178549404BE658DE55C54640F969DC9BDF7A49404721C9ACDEC14640F969DC9BDF7A4940
31339	8644	45.467931999999998	45.509433999999999	50.902585000000002	50.875442	Первомайская	0103000020E610000001000000050000003D601E32E5BB4640BDC5C37B0E7049403D601E32E5BB46401A6EC0E78773494038BC202235C146401A6EC0E78773494038BC202235C14640BDC5C37B0E7049403D601E32E5BB4640BDC5C37B0E704940
30501	8502	45.418452000000002	45.432034999999999	50.703147000000001	50.688220999999999	Советская	0103000020E610000001000000050000001079CBD58FB54640D0B52FA0175849401079CBD58FB54640E8A38CB8005A49401ADD41EC4CB74640E8A38CB8005A49401ADD41EC4CB74640D0B52FA0175849401079CBD58FB54640D0B52FA017584940
31332	8203	45.871383000000002	45.916576999999997	50.841976000000003	50.818081999999997	пер.Больничный	0103000020E610000001000000050000002BA5677A89EF46401FB935E9B66849402BA5677A89EF46402A029CDEC56B494005A2276552F546402A029CDEC56B494005A2276552F546401FB935E9B66849402BA5677A89EF46401FB935E9B6684940
30615	8557	45.454385000000002	45.461176000000002	50.739313000000003	50.732118	55 лет Победы	0103000020E610000001000000050000008065A54929BA46400E68E90AB65D49408065A54929BA4640FB40F2CEA15E49409DD9AED007BB4640FB40F2CEA15E49409DD9AED007BB46400E68E90AB65D49408065A54929BA46400E68E90AB65D4940
31185	8115	46.000245999999997	46.035164000000002	50.857968	50.848471000000004	Советская	0103000020E6100000010000000500000037FA980F080047405E4D9EB29A6C494037FA980F08004740DC813AE5D16D49408FFF024180044740DC813AE5D16D49408FFF0241800447405E4D9EB29A6C494037FA980F080047405E4D9EB29A6C4940
31085	8312	45.702347000000003	45.718803999999999	50.853440999999997	50.846224999999997	Школьная	0103000020E61000000100000005000000CCB8A981E6D946405F07CE19516C4940CCB8A981E6D946406308008E3D6D4940F31DFCC401DC46406308008E3D6D4940F31DFCC401DC46405F07CE19516C4940CCB8A981E6D946405F07CE19516C4940
30718	8415	45.381971999999998	45.402650999999999	50.651125	50.635387999999999	Заречная	0103000020E610000001000000050000006DFE5F75E4B04640AB22DC64545149406DFE5F75E4B04640D34D621058534940D15966118AB34640D34D621058534940D15966118AB34640AB22DC64545149406DFE5F75E4B04640AB22DC6454514940
31032	7958	45.781345000000002	45.801825999999998	50.962037000000002	50.952494000000002	Школьная	0103000020E6100000010000000500000052F2EA1C03E4464070D1C952EB79494052F2EA1C03E446405F454607247B49408F8AFF3BA2E646405F454607247B49408F8AFF3BA2E6464070D1C952EB79494052F2EA1C03E4464070D1C952EB794940
31206	9015	45.511274999999998	45.535808000000003	51.096598	51.069982000000003	Школьная	0103000020E6100000010000000500000096218E7571C1464083A7902BF588494096218E7571C14640F46DC1525D8C4940B477465B95C44640F46DC1525D8C4940B477465B95C4464083A7902BF588494096218E7571C1464083A7902BF5884940
30872	6402	44.505288	44.528824	51.372003999999997	51.352404999999997	Центральная	0103000020E61000000100000005000000D787F546AD40464033F9669B1BAD4940D787F546AD40464097FDBAD39DAF494082AB3C81B043464097FDBAD39DAF494082AB3C81B043464033F9669B1BAD4940D787F546AD40464033F9669B1BAD4940
30647	5594	44.398065000000003	44.427557	51.677917999999998	51.656534000000001	 Рабочая	0103000020E6100000010000000500000054573ECBF3324640255B5D4E09D4494054573ECBF332464053AF5B04C6D6494083161230BA36464053AF5B04C6D6494083161230BA364640255B5D4E09D4494054573ECBF3324640255B5D4E09D44940
31424	5975	44.355494	44.370424	51.434477999999999	51.420456000000001	Центральная	0103000020E610000001000000050000004DF6CFD3802D464018B49080D1B549404DF6CFD3802D46406E6AA0F99CB74940A6D3BA0D6A2F46406E6AA0F99CB74940A6D3BA0D6A2F464018B49080D1B549404DF6CFD3802D464018B49080D1B54940
31488	6197	44.215212999999999	44.248271000000003	51.322380000000003	51.296666999999999	Школьный переулок	0103000020E6100000010000000500000047567E198C1B4640B6662B2FF9A5494047567E198C1B4640377172BF43A94940CAC51858C71F4640377172BF43A94940CAC51858C71F4640B6662B2FF9A5494047567E198C1B4640B6662B2FF9A54940
30875	7020	44.273837	44.301909000000002	51.714606000000003	51.704225000000001	Кирова	0103000020E61000000100000005000000A6B73F170D2346404703780B24DA4940A6B73F170D23464040C39B3578DB49401DAF40F4A426464040C39B3578DB49401DAF40F4A42646404703780B24DA4940A6B73F170D2346404703780B24DA4940
30263	6128	44.736209000000002	44.766258000000001	51.379649999999998	51.353552999999998	Советская	0103000020E61000000100000005000000AC02B5183C5E46408B33863941AD4940AC02B5183C5E464094F6065F98B049403126FDBD1462464094F6065F98B049403126FDBD146246408B33863941AD4940AC02B5183C5E46408B33863941AD4940
30874	6797	44.041452	44.079450999999999	51.617640999999999	51.59798	Школьная 	0103000020E61000000100000005000000492D944C4E054640BFD4CF9B8ACC4940492D944C4E05464099D53BDC0ECF494037514B732B0A464099D53BDC0ECF494037514B732B0A4640BFD4CF9B8ACC4940492D944C4E054640BFD4CF9B8ACC4940
31030	6336	44.555621000000002	44.585408999999999	51.271790000000003	51.243386999999998	Верхняя 	0103000020E6100000010000000500000044FCC3961E474640C2A2224E279F494044FCC3961E4746409FB0C403CAA249405CE49EAEEE4A46409FB0C403CAA249405CE49EAEEE4A4640C2A2224E279F494044FCC3961E474640C2A2224E279F4940
30491	6699	44.065193999999998	44.079909000000001	51.509464999999999	51.497937999999998	Школьная	0103000020E610000001000000050000009DF2E84658084640C3B7B06EBCBF49409DF2E8465808464073BA2C2636C14940FAD346753A0A464073BA2C2636C14940FAD346753A0A4640C3B7B06EBCBF49409DF2E84658084640C3B7B06EBCBF4940
30359	5863	44.557713999999997	44.596834999999999	51.507165999999998	51.470123999999998	Октябрьская	0103000020E61000000100000005000000BB421F2C634746404888F2052DBC4940BB421F2C6347464052D2C3D0EAC04940D80DDB16654C464052D2C3D0EAC04940D80DDB16654C46404888F2052DBC4940BB421F2C634746404888F2052DBC4940
30321	6285	44.274465999999997	44.293168999999999	51.282736999999997	51.262801000000003	Мира	0103000020E6100000010000000500000095EEAEB321234640952D9276A3A1494095EEAEB321234640402FDCB930A44940BB99D18F86254640402FDCB930A44940BB99D18F86254640952D9276A3A1494095EEAEB321234640952D9276A3A14940
31035	6549	44.111350000000002	44.131220999999996	51.444538999999999	51.421905000000002	Придорожная	0103000020E610000001000000050000006E3480B7400E46406B82A8FB00B649406E3480B7400E4640F56569A7E6B8494032C687D9CB104640F56569A7E6B8494032C687D9CB1046406B82A8FB00B649406E3480B7400E46406B82A8FB00B64940
31190	6874	44.168267	44.199663000000001	51.563195999999998	51.540754999999997	Кооперативная	0103000020E610000001000000050000007EFFE6C5891546400113B87537C549407EFFE6C589154640779E78CE16C84940529CA38E8E194640779E78CE16C84940529CA38E8E1946400113B87537C549407EFFE6C5891546400113B87537C54940
30833	5718	44.554516	44.591346999999999	51.470680000000002	51.453778	Советская	0103000020E61000000100000005000000EB8D5A61FA46464078D2C26515BA4940EB8D5A61FA464640CE70033E3FBC49403ACB2C42B14B4640CE70033E3FBC49403ACB2C42B14B464078D2C26515BA4940EB8D5A61FA46464078D2C26515BA4940
31189	6620	44.096986000000001	44.145369000000002	51.381320000000002	51.358024	Петрозавадовка	0103000020E61000000100000005000000BE1589096A0C46407097FDBAD3AD4940BE1589096A0C4640C6A70018CFB04940166D8E739B124640C6A70018CFB04940166D8E739B1246407097FDBAD3AD4940BE1589096A0C46407097FDBAD3AD4940
31007	6134	44.660525999999997	44.684097999999999	51.420602000000002	51.407654000000001	Школьная	0103000020E610000001000000050000002F14B01D8C544640B30A9B012EB449402F14B01D8C544640EC504D49D6B5494027A1F48590574640EC504D49D6B5494027A1F48590574640B30A9B012EB449402F14B01D8C544640B30A9B012EB44940
31021	6278	44.401612999999998	44.421709	51.337277	51.325696000000001	Центральная	0103000020E610000001000000050000000053060E6833464011381268B0A949400053060E68334640B4588AE42BAB4940E5B67D8FFA354640B4588AE42BAB4940E5B67D8FFA35464011381268B0A949400053060E6833464011381268B0A94940
30538	5924	44.265554999999999	44.293464999999998	51.420327	51.400018000000003	Школьный тупик	0103000020E610000001000000050000000725CCB4FD214640DAE731CA33B349400725CCB4FD2146401A506F46CDB54940A4C2D842902546401A506F46CDB54940A4C2D84290254640DAE731CA33B349400725CCB4FD214640DAE731CA33B34940
31034	6494	44.392423999999998	44.415618000000002	51.220883999999998	51.206688	Центральная	0103000020E610000001000000050000002F151BF33A324640E23C9CC0749A49402F151BF33A324640D61A4AED459C494081D07AF832354640D61A4AED459C494081D07AF832354640E23C9CC0749A49402F151BF33A324640E23C9CC0749A4940
30706	6547	44.578429	44.613076999999997	51.212263	51.185313999999998	Ленина	0103000020E610000001000000050000006C0723F6094A4640D7BE805EB89749406C0723F6094A46404F93196F2B9B49400377A04E794E46404F93196F2B9B49400377A04E794E4640D7BE805EB89749406C0723F6094A4640D7BE805EB8974940
30237	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	Чехова	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
30232	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	Советская	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
30660	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	Первомайская	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
31485	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	Ленина	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
31486	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	Коллективная	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
31163	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	Богдана Хмельницкого	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
67124	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	50 лет Октября	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
30968	5060	44.417738	44.521134000000004	51.521543000000001	51.480766000000003	30 лет ВЛКСМ	0103000020E61000000100000005000000F225547078354640AE8383BD89BD4940F225547078354640973AC8EBC1C24940B66AD784B4424640973AC8EBC1C24940B66AD784B4424640AE8383BD89BD4940F225547078354640AE8383BD89BD4940
31427	6703	43.904350999999998	43.961779999999997	51.485421000000002	51.457504999999998	Молодежная	0103000020E610000001000000050000006D8D08C6C1F34540D4601A868FBA49406D8D08C6C1F3454054E57B4622BE494033F9669B1BFB454054E57B4622BE494033F9669B1BFB4540D4601A868FBA49406D8D08C6C1F34540D4601A868FBA4940
30989	5806	44.581716999999998	44.604785	51.555866000000002	51.544894999999997	Школьная	0103000020E610000001000000050000007C43E1B3754A464080608E1EBFC549407C43E1B3754A4640AB7AF99D26C74940410E4A98694D4640AB7AF99D26C74940410E4A98694D464080608E1EBFC549407C43E1B3754A464080608E1EBFC54940
30256	6076	44.266489	44.303364999999999	51.523890999999999	51.501392000000003	Центральная	0103000020E6100000010000000500000033DFC14F1C224640EF3CF19C2DC0494033DFC14F1C22464099D53BDC0EC3494022E010AAD426464099D53BDC0EC3494022E010AAD4264640EF3CF19C2DC0494033DFC14F1C224640EF3CF19C2DC04940
30492	6933	44.358899000000001	44.397364000000003	51.631501999999998	51.594489000000003	Центральная	0103000020E6100000010000000500000097C80567F02D4640776A2E3718CC494097C80567F02D4640E6ADBA0ED5D04940CB4DD4D2DC324640E6ADBA0ED5D04940CB4DD4D2DC324640776A2E3718CC494097C80567F02D4640776A2E3718CC4940
31151	5661	44.489981	44.513129999999997	51.717680000000001	51.702756999999998	Центральная	0103000020E61000000100000005000000A85489B2B73E46407D04FEF0F3D94940A85489B2B73E4640247F30F0DCDB4940594C6C3EAE414640247F30F0DCDB4940594C6C3EAE4146407D04FEF0F3D94940A85489B2B73E46407D04FEF0F3D94940
30338	6927	44.134383	44.165571999999997	51.688220000000001	51.670456000000001	Пушкина	0103000020E61000000100000005000000B6114F763311464018B49080D1D54940B6114F7633114640003ACC9717D8494010919A7631154640003ACC9717D8494010919A763115464018B49080D1D54940B6114F763311464018B49080D1D54940
30823	4909	49.581837999999998	49.615516	52.211334999999998	52.199109999999997	Чапаева	0103000020E61000000100000005000000F7C8E6AA79CA48403D27BD6F7C194A40F7C8E6AA79CA484005C078060D1B4A401615713AC9CE484005C078060D1B4A401615713AC9CE48403D27BD6F7C194A40F7C8E6AA79CA48403D27BD6F7C194A40
30822	4768	49.371749000000001	49.413117	52.325356999999997	52.306131999999998	Центральная	0103000020E610000001000000050000000DA9A27895AF4840292158552F274A400DA9A27895AF48402843554CA5294A40F8359204E1B448402843554CA5294A40F8359204E1B44840292158552F274A400DA9A27895AF4840292158552F274A40
30654	4359	48.923535000000001	48.943496000000003	52.300769000000003	52.281059999999997	Центральная 	0103000020E610000001000000050000000EDB1665367648405C1B2AC6F9234A400EDB16653676484048533D997F264A4013F4177AC478484048533D997F264A4013F4177AC47848405C1B2AC6F9234A400EDB1665367648405C1B2AC6F9234A40
31283	4156	49.195239000000001	49.238636999999997	52.459513000000001	52.445830999999998	Кооперативная	0103000020E61000000100000005000000AEF36F97FD98484080457EFD10394A40AEF36F97FD9848401E8B6D52D13A4A40CA4E3FA88B9E48401E8B6D52D13A4A40CA4E3FA88B9E484080457EFD10394A40AEF36F97FD98484080457EFD10394A40
31270	4365	48.881934000000001	48.893037	52.224190999999998	52.210562000000003	Рабочая	0103000020E61000000100000005000000809D9B36E3704840E3E313B2F31A4A40809D9B36E37048405D876A4AB21C4A40198F52094F7248405D876A4AB21C4A40198F52094F724840E3E313B2F31A4A40809D9B36E3704840E3E313B2F31A4A40
30658	4964	49.497100000000003	49.554915999999999	52.115637	52.101981000000002	Советская	0103000020E61000000100000005000000BA6B09F9A0BF48401DE8A1B60D0D4A40BA6B09F9A0BF4840919A7631CD0E4A407903CC7C07C74840919A7631CD0E4A407903CC7C07C748401DE8A1B60D0D4A40BA6B09F9A0BF48401DE8A1B60D0D4A40
30226	4956	49.630527000000001	49.663423000000002	52.199756000000001	52.179273000000002	Школьная	0103000020E610000001000000050000005C1FD61BB5D048402507EC6AF2164A405C1FD61BB5D048400397C79A91194A4005357C0BEBD448400397C79A91194A4005357C0BEBD448402507EC6AF2164A405C1FD61BB5D048402507EC6AF2164A40
30189	4430	49.075358999999999	49.133524999999999	52.286011999999999	52.255746000000002	Советская	0103000020E61000000100000005000000C93A1C5DA58948409A0AF148BC204A40C93A1C5DA5894840BC218D0A9C244A406519E25817914840BC218D0A9C244A406519E258179148409A0AF148BC204A40C93A1C5DA58948409A0AF148BC204A40
30784	4430	49.075358999999999	49.133524999999999	52.286011999999999	52.255746000000002	Московская	0103000020E61000000100000005000000C93A1C5DA58948409A0AF148BC204A40C93A1C5DA5894840BC218D0A9C244A406519E25817914840BC218D0A9C244A406519E258179148409A0AF148BC204A40C93A1C5DA58948409A0AF148BC204A40
30435	4430	49.075358999999999	49.133524999999999	52.286011999999999	52.255746000000002	Кооперативная	0103000020E61000000100000005000000C93A1C5DA58948409A0AF148BC204A40C93A1C5DA5894840BC218D0A9C244A406519E25817914840BC218D0A9C244A406519E258179148409A0AF148BC204A40C93A1C5DA58948409A0AF148BC204A40
31418	4430	49.075358999999999	49.133524999999999	52.286011999999999	52.255746000000002	 Строителей	0103000020E61000000100000005000000C93A1C5DA58948409A0AF148BC204A40C93A1C5DA5894840BC218D0A9C244A406519E25817914840BC218D0A9C244A406519E258179148409A0AF148BC204A40C93A1C5DA58948409A0AF148BC204A40
31142	4707	49.277057999999997	49.319969999999998	52.216991	52.186577999999997	Кооперативная	0103000020E610000001000000050000002E8CF4A276A348409813B4C9E1174A402E8CF4A276A348405F43705CC61B4A40BED9E6C6F4A848405F43705CC61B4A40BED9E6C6F4A848409813B4C9E1174A402E8CF4A276A348409813B4C9E1174A40
31402	4211	49.150288000000003	49.17765	52.330447999999997	52.312123	Центральная	0103000020E610000001000000050000009A7D1EA33C9348402AAA7EA5F3274A409A7D1EA33C934840A983BC1E4C2A4A403411363CBD964840A983BC1E4C2A4A403411363CBD9648402AAA7EA5F3274A409A7D1EA33C9348402AAA7EA5F3274A40
30440	4855	49.557144000000001	49.575055999999996	52.344540000000002	52.332324999999997	Зеленая	0103000020E61000000100000005000000D1949D7E50C74840545227A0892A4A40D1949D7E50C74840F91400E3192C4A402DAF5C6F9BC94840F91400E3192C4A402DAF5C6F9BC94840545227A0892A4A40D1949D7E50C74840545227A0892A4A40
30624	4108	49.053421999999998	49.092202999999998	52.440072999999998	52.416981999999997	Победы	0103000020E6100000010000000500000086713788D6864840A5828AAA5F354A4086713788D6864840226DE34F54384A40EACBD24ECD8B4840226DE34F54384A40EACBD24ECD8B4840A5828AAA5F354A4086713788D6864840A5828AAA5F354A40
30760	4306	49.040540999999997	49.065756	52.308318	52.294671999999998	Арбузовская	0103000020E61000000100000005000000D5928E72308548400186E5CFB7254A40D5928E72308548405262D7F676274A4005C24EB16A8848405262D7F676274A4005C24EB16A8848400186E5CFB7254A40D5928E72308548400186E5CFB7254A40
30937	2222	48.387419999999999	48.410732000000003	51.498308000000002	51.482044999999999	Центральная	0103000020E610000001000000050000007DE882FA96314840A4198BA6B3BD49407DE882FA96314840E7AA798EC8BF4940D9B5BDDD92344840E7AA798EC8BF4940D9B5BDDD92344840A4198BA6B3BD49407DE882FA96314840A4198BA6B3BD4940
30901	3033	47.853245999999999	47.868509000000003	51.417034999999998	51.406457000000003	Юбилейная	0103000020E61000000100000005000000AEB8382A37ED47407A1D71C806B44940AEB8382A37ED4740C824236761B549400EA48B4D2BEF4740C824236761B549400EA48B4D2BEF47407A1D71C806B44940AEB8382A37ED47407A1D71C806B44940
30173	3144	47.855716999999999	47.879558000000003	51.509408999999998	51.490316999999997	60 лет СССР	0103000020E61000000100000005000000CCD0782288ED47401FD61BB5C2BE4940CCD0782288ED4740DFA4695034C14940B477465B95F04740DFA4695034C14940B477465B95F047401FD61BB5C2BE4940CCD0782288ED47401FD61BB5C2BE4940
31098	2513	47.865031999999999	47.891820000000003	51.030177000000002	51.019396	Советская	0103000020E610000001000000050000002AFF5A5EB9EE47402CD670917B8249402AFF5A5EB9EE4740B30B06D7DC83494099F5622827F24740B30B06D7DC83494099F5622827F247402CD670917B8249402AFF5A5EB9EE47402CD670917B824940
31281	3314	48.040446000000003	48.061601000000003	51.646157000000002	51.630070000000003	Школьная	0103000020E6100000010000000500000084A0A3552D0548406A183E22A6D0494084A0A3552D0548406E8AC745B5D249405133A48AE20748406E8AC745B5D249405133A48AE20748406A183E22A6D0494084A0A3552D0548406A183E22A6D04940
30761	2349	48.509430000000002	48.534132999999997	51.353304999999999	51.336123999999998	Ленина	0103000020E61000000100000005000000F7CC9200354148404AB3791C06AB4940F7CC920035414840B341261939AD4940705B5B785E444840B341261939AD4940705B5B785E4448404AB3791C06AB4940F7CC9200354148404AB3791C06AB4940
31254	1915	48.208933999999999	48.241821000000002	51.354970000000002	51.335915	Центральная	0103000020E61000000100000005000000E0826C59BE1A4840309E4143FFAA4940E0826C59BE1A4840D3872EA86FAD4940363E93FDF31E4840D3872EA86FAD4940363E93FDF31E4840309E4143FFAA4940E0826C59BE1A4840309E4143FFAA4940
30193	53138	48.232047999999999	48.257649999999998	50.943573000000001	50.924681999999997	Центральная	0103000020E61000000100000005000000158DB5BFB31D48409599D2FA5B764940158DB5BFB31D4840BE310400C77849403EE8D9ACFA204840BE310400C77849403EE8D9ACFA2048409599D2FA5B764940158DB5BFB31D48409599D2FA5B764940
31111	3317	48.081589000000001	48.095557999999997	51.324058000000001	51.311909999999997	Центральная	0103000020E610000001000000050000004F5B2382710A4840CEA5B8AAECA749404F5B2382710A4840EB0088BB7AA94940826F9A3E3B0C4840EB0088BB7AA94940826F9A3E3B0C4840CEA5B8AAECA749404F5B2382710A4840CEA5B8AAECA74940
30363	2285	48.525581000000003	48.543610000000001	51.492600000000003	51.473199000000001	Семеново-Полтавская	0103000020E610000001000000050000001233FB3C46434840FDBFEAC891BC49401233FB3C464348403B014D840DBF4940A8E33103954548403B014D840DBF4940A8E3310395454840FDBFEAC891BC49401233FB3C46434840FDBFEAC891BC4940
30776	2682	48.318779999999997	48.339449999999999	51.667831	51.653500000000001	Рабочая	0103000020E61000000100000005000000374F75C8CD284840CFF753E3A5D34940374F75C8CD284840A320787C7BD549404850FC18732B4840A320787C7BD549404850FC18732B4840CFF753E3A5D34940374F75C8CD284840CFF753E3A5D34940
31121	3889	48.483359999999998	48.512619000000001	51.326529000000001	51.312787999999998	Ленина	0103000020E61000000100000005000000E71890BDDE3D4840664AEB6F09A84940E71890BDDE3D48400919C8B3CBA949407427D87F9D4148400919C8B3CBA949407427D87F9D414840664AEB6F09A84940E71890BDDE3D4840664AEB6F09A84940
30397	3796	48.034517000000001	48.080331000000001	51.217289999999998	51.187685000000002	Пылайкина	0103000020E61000000100000005000000F913950D6B0448409279E40F06984940F913950D6B044840B9DFA128D09B494070ED4449480A4840B9DFA128D09B494070ED4449480A48409279E40F06984940F913950D6B0448409279E40F06984940
30182	3493	48.528680000000001	48.551533999999997	51.112529000000002	51.099086999999997	Школьная	0103000020E610000001000000050000004F0647C9AB434840B83A00E2AE8C49404F0647C9AB434840016DAB59678E4940E75086AA98464840016DAB59678E4940E75086AA98464840B83A00E2AE8C49404F0647C9AB434840B83A00E2AE8C4940
30609	3651	48.173442000000001	48.228104000000002	50.938879999999997	50.900694000000001	Саловая	0103000020E610000001000000050000005DE0F258331648400ADAE4F0497349405DE0F258331648402A6F47382D7849401C0B0A83321D48402A6F47382D7849401C0B0A83321D48400ADAE4F0497349405DE0F258331648400ADAE4F049734940
30785	3651	48.173442000000001	48.228104000000002	50.938879999999997	50.900694000000001	Кривошеева	0103000020E610000001000000050000005DE0F258331648400ADAE4F0497349405DE0F258331648402A6F47382D7849401C0B0A83321D48402A6F47382D7849401C0B0A83321D48400ADAE4F0497349405DE0F258331648400ADAE4F049734940
31664	29790	\N	\N	\N	\N	Рабочая	\N
30386	3531	48.104675999999998	48.124626999999997	51.668322000000003	51.658479	Заводская	0103000020E610000001000000050000008A56EE05660D4840280D350A49D449408A56EE05660D4840429946938BD549406B990CC7F30F4840429946938BD549406B990CC7F30F4840280D350A49D449408A56EE05660D4840280D350A49D44940
30603	3434	48.398235999999997	48.455835999999998	51.085746999999998	51.061729	Советская	0103000020E61000000100000005000000800BB265F93248407E1B62BCE6874940800BB265F9324840745DF8C1F98A4940732B84D5583A4840745DF8C1F98A4940732B84D5583A48407E1B62BCE6874940800BB265F93248407E1B62BCE6874940
31288	3278	48.215527999999999	48.243662999999998	51.332943999999998	51.305383999999997	Братиславская	0103000020E61000000100000005000000A7AFE76B961B48405F5CAAD216A74940A7AFE76B961B484020B3B3E89DAA4940641F6459301F484020B3B3E89DAA4940641F6459301F48405F5CAAD216A74940A7AFE76B961B48405F5CAAD216A74940
9829	3081	47.922272999999997	47.972417	51.457275000000003	51.434164000000003	Новая	0103000020E61000000100000005000000ED7DAA0A0DF64740DF8C9AAF92B74940ED7DAA0A0DF64740A323B9FC87BA49408789062978FC4740A323B9FC87BA49408789062978FC4740DF8C9AAF92B74940ED7DAA0A0DF64740DF8C9AAF92B74940
30596	3211	48.247247000000002	48.269849000000001	51.248935000000003	51.237917000000003	 25 партсъезда	0103000020E610000001000000050000005E8429CAA51F4840CB147310749E49405E8429CAA51F484036EA211ADD9F4940DDED7A698A22484036EA211ADD9F4940DDED7A698A224840CB147310749E49405E8429CAA51F4840CB147310749E4940
30581	2733	48.236125999999999	48.260956	51.672333000000002	51.664177000000002	Почтовая	0103000020E610000001000000050000001EDE7360391E4840B1E07EC003D549401EDE7360391E4840C382FB010FD64940F5D8960167214840C382FB010FD64940F5D8960167214840B1E07EC003D549401EDE7360391E4840B1E07EC003D54940
30584	2971	47.913325999999998	47.939709000000001	51.451365000000003	51.436982999999998	Комсомольская	0103000020E61000000100000005000000124BCADDE7F4474038F4160FEFB74940124BCADDE7F447408FC70C54C6B94940E1606F6248F847408FC70C54C6B94940E1606F6248F8474038F4160FEFB74940124BCADDE7F4474038F4160FEFB74940
30165	2848	48.197535000000002	48.217145000000002	51.477680999999997	51.463661000000002	Молодежная	0103000020E610000001000000050000005E68AED34819484020B75F3E59BB49405E68AED348194840D575A8A624BD4940B6BE4868CB1B4840D575A8A624BD4940B6BE4868CB1B484020B75F3E59BB49405E68AED34819484020B75F3E59BB4940
30894	26181	48.177546999999997	48.202905999999999	51.583638000000001	51.566744999999997	Прудовая	0103000020E610000001000000050000005F402FDCB9164840F415A4198BC849405F402FDCB9164840F75965A6B4CA4940C214E5D2F8194840F75965A6B4CA4940C214E5D2F8194840F415A4198BC849405F402FDCB9164840F415A4198BC84940
31114	3377	48.075040000000001	48.088164999999996	51.355083	51.340905999999997	Молодежная	0103000020E6100000010000000500000028F224E99A0948404D81CCCEA2AB494028F224E99A094840CB2E185C73AD49406FD39FFD480B4840CB2E185C73AD49406FD39FFD480B48404D81CCCEA2AB494028F224E99A0948404D81CCCEA2AB4940
31104	2617	48.328581	48.351838000000001	51.639490000000002	51.623114999999999	Советская	0103000020E61000000100000005000000228B34F10E2A4840D252793BC2CF4940228B34F10E2A48403D0FEECEDAD14940BABE0F07092D48403D0FEECEDAD14940BABE0F07092D4840D252793BC2CF4940228B34F10E2A4840D252793BC2CF4940
30579	2453	47.910567999999998	47.939996999999998	51.060336999999997	51.045088999999997	Переулок Больничный	0103000020E610000001000000050000005E64027E8DF447406534F279C58549405E64027E8DF447408FDE701FB987494047AB5AD251F847408FDE701FB987494047AB5AD251F847406534F279C58549405E64027E8DF447406534F279C5854940
31261	2913	48.133178999999998	48.172345999999997	51.400170000000003	51.384062999999998	Центральная	0103000020E61000000100000005000000CAC16C020C114840444DF4F928B14940CAC16C020C114840906B43C538B3494057CC086F0F164840906B43C538B3494057CC086F0F164840444DF4F928B14940CAC16C020C114840444DF4F928B14940
31069	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Юбилейная	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31475	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Урожайная	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31152	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Ремонтная	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
30340	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Некрасова	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
30921	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Мелиоративная	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31407	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Локомотивная	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31483	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Крупской	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31070	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Краснопартизанская	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
30754	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Дорожный проезд	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
30530	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Горького	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31082	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Гагарина	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31080	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	Вокзальная	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
30914	1120	48.237797	48.320881999999997	51.368226	51.334063999999998	22 Партсъезда	0103000020E61000000100000005000000200BD121701E4840AE62F19BC2AA4940200BD121701E4840B9C4910722AF494002F04FA912294840B9C4910722AF494002F04FA912294840AE62F19BC2AA4940200BD121701E4840AE62F19BC2AA4940
31349	2578	48.023764	48.074762	51.068007000000001	51.049970000000002	Ленина	0103000020E610000001000000050000003C69E1B20A034840FCE3BD6A658649403C69E1B20A03484015731074B4884940E57D1CCD9109484015731074B4884940E57D1CCD91094840FCE3BD6A658649403C69E1B20A034840FCE3BD6A65864940
30628	3981	47.969873999999997	47.996941	51.612836999999999	51.599170999999998	Молодежная 	0103000020E61000000100000005000000CF9ECBD424FC474016DBA4A2B1CC4940CF9ECBD424FC4740AE635C7171CE494051853FC39BFF4740AE635C7171CE494051853FC39BFF474016DBA4A2B1CC4940CF9ECBD424FC474016DBA4A2B1CC4940
30946	2806	48.284312	48.306994000000003	51.543253999999997	51.528210999999999	Молодежная	0103000020E6100000010000000500000020EEEA55642448409831056B9CC3494020EEEA5564244840E9B5D95889C54940BC0853944B274840E9B5D95889C54940BC0853944B2748409831056B9CC3494020EEEA55642448409831056B9CC34940
31395	3838	48.047919999999998	48.070225000000001	51.119993000000001	51.100574000000002	Школьная	0103000020E610000001000000050000008369183E22064840F969DC9BDF8C49408369183E22064840DD5F3DEE5B8F4940492EFF21FD084840DD5F3DEE5B8F4940492EFF21FD084840F969DC9BDF8C49408369183E22064840F969DC9BDF8C4940
30316	2164	48.369553000000003	48.396250999999999	51.388745	51.3675	Парковая	0103000020E61000000100000005000000C19140834D2F4840D7A3703D0AAF4940C19140834D2F4840E4BD6A65C2B14940EF004F5AB8324840E4BD6A65C2B14940EF004F5AB8324840D7A3703D0AAF4940C19140834D2F4840D7A3703D0AAF4940
30799	253	44.290851000000004	44.316121000000003	51.852147000000002	51.839905999999999	Юбилейная	0103000020E610000001000000050000002481069B3A2546406ADB300A82EB49402481069B3A2546403831242713ED4940174A26A7762846403831242713ED4940174A26A7762846406ADB300A82EB49402481069B3A2546406ADB300A82EB4940
30414	209	44.273153999999998	44.286853999999998	51.789183999999999	51.772818999999998	Ленинская	0103000020E61000000100000005000000C362D4B5F62246401C5DA5BBEBE24940C362D4B5F6224640634337FB03E54940075DC2A1B7244640634337FB03E54940075DC2A1B72446401C5DA5BBEBE24940C362D4B5F62246401C5DA5BBEBE24940
30420	1064	44.524816999999999	44.562331	51.963214999999998	51.938763999999999	Молодежная	0103000020E6100000010000000500000042B115342D434640C154336B29F8494042B115342D43464021020EA14AFB494074435376FA47464021020EA14AFB494074435376FA474640C154336B29F8494042B115342D434640C154336B29F84940
30801	959	44.372256999999998	44.395558999999999	52.000107999999997	51.988495999999998	Молодёжная	0103000020E61000000100000005000000815A0C1EA62F4640081D740987FE4940815A0C1EA62F4640E63BF88903004A40B95164ADA1324640E63BF88903004A40B95164ADA1324640081D740987FE4940815A0C1EA62F4640081D740987FE4940
30416	992	44.403517999999998	44.437024999999998	52.017204999999997	52.007553999999999	Центральная	0103000020E6100000010000000500000075AC527AA63346401C7A8B87F7004A4075AC527AA6334640F12900C633024A406744696FF0374640F12900C633024A406744696FF03746401C7A8B87F7004A4075AC527AA63346401C7A8B87F7004A40
30433	830	44.256338	44.281024000000002	51.958680999999999	51.944820999999997	Центральная	0103000020E610000001000000050000006C5CFFAECF20464079C9FFE4EFF849406C5CFFAECF204640F6251B0FB6FA494010B22C98F8234640F6251B0FB6FA494010B22C98F823464079C9FFE4EFF849406C5CFFAECF20464079C9FFE4EFF84940
30734	393	44.617514999999997	44.644373999999999	52.370759	52.360861	Кипецкая	0103000020E610000001000000050000000CE544BB0A4F464070B378B1302E4A400CE544BB0A4F46404DD9E907752F4A404432E4D87A5246404DD9E907752F4A404432E4D87A52464070B378B1302E4A400CE544BB0A4F464070B378B1302E4A40
31289	885	44.306724000000003	44.334707000000002	52.042304999999999	52.033658000000003	Майская	0103000020E61000000100000005000000FC7266BB42274640D89FC4E74E044A40FC7266BB4227464088BA0F406A054A40035FD1ADD72A464088BA0F406A054A40035FD1ADD72A4640D89FC4E74E044A40FC7266BB42274640D89FC4E74E044A40
30636	714	44.734161	44.778699000000003	52.300179	52.284436999999997	Школьная	0103000020E61000000100000005000000D47FD6FCF85D4640DC627E6E68244A40D47FD6FCF85D464016F9F5436C264A40C636A968AC63464016F9F5436C264A40C636A968AC634640DC627E6E68244A40D47FD6FCF85D4640DC627E6E68244A40
30772	755	44.644795999999999	44.675752000000003	52.135072000000001	52.119624000000002	Школьная	0103000020E61000000100000005000000BA4BE2AC885246408AE8D7D64F0F4A40BA4BE2AC885246407B4D0F0A4A114A40721AA20A7F5646407B4D0F0A4A114A40721AA20A7F5646408AE8D7D64F0F4A40BA4BE2AC885246408AE8D7D64F0F4A40
30327	644	44.769464999999997	44.804929999999999	52.376603000000003	52.352302000000002	Угловая	0103000020E61000000100000005000000543541D47D6246405F28603B182D4A40543541D47D624640AA49F08634304A40DEC83CF207674640AA49F08634304A40DEC83CF2076746405F28603B182D4A40543541D47D6246405F28603B182D4A40
31286	467	44.094029999999997	44.134562000000003	51.887075000000003	51.85089	Новая	0103000020E61000000100000005000000E36BCF2C090C4640293FA9F6E9EC4940E36BCF2C090C4640B30C71AC8BF1494066A4DE5339114640B30C71AC8BF1494066A4DE5339114640293FA9F6E9EC4940E36BCF2C090C4640293FA9F6E9EC4940
30877	330	44.318268000000003	44.371169999999999	52.142085999999999	52.120736000000001	Советская	0103000020E6100000010000000500000082AE7D01BD28464095B9F946740F4A4082AE7D01BD284640179CC1DF2F124A40CFA0A17F822F4640179CC1DF2F124A40CFA0A17F822F464095B9F946740F4A4082AE7D01BD28464095B9F946740F4A40
30413	32461	44.549359000000003	44.568781000000001	52.465532000000003	52.454211999999998	Советская	0103000020E61000000100000005000000B3614D6551464640B2B96A9E233A4A40B3614D6551464640E99E758D963B4A4008CBD8D0CD484640E99E758D963B4A4008CBD8D0CD484640B2B96A9E233A4A40B3614D6551464640B2B96A9E233A4A40
30650	30924	44.328823	44.374879999999997	52.065542999999998	52.039845999999997	Первомайская	0103000020E6100000010000000500000018963FDF162A46402E7079AC19054A4018963FDF162A4640A9BD88B663084A4055F65D11FC2F4640A9BD88B663084A4055F65D11FC2F46402E7079AC19054A4018963FDF162A46402E7079AC19054A40
9654	30924	44.328823	44.374879999999997	52.065542999999998	52.039845999999997	Молодёжная	0103000020E6100000010000000500000018963FDF162A46402E7079AC19054A4018963FDF162A4640A9BD88B663084A4055F65D11FC2F4640A9BD88B663084A4055F65D11FC2F46402E7079AC19054A4018963FDF162A46402E7079AC19054A40
31348	30924	44.328823	44.374879999999997	52.065542999999998	52.039845999999997	Мичуринская	0103000020E6100000010000000500000018963FDF162A46402E7079AC19054A4018963FDF162A4640A9BD88B663084A4055F65D11FC2F4640A9BD88B663084A4055F65D11FC2F46402E7079AC19054A4018963FDF162A46402E7079AC19054A40
30973	510	44.095252000000002	44.122802999999998	51.955196000000001	51.915315999999997	Октябрьская	0103000020E610000001000000050000007670B037310C4640B5C01E1329F549407670B037310C464090A2CEDC43FA4940E36C3A02B80F464090A2CEDC43FA4940E36C3A02B80F4640B5C01E1329F549407670B037310C4640B5C01E1329F54940
30634	122	44.415052000000003	44.451048	51.857326	51.849603999999999	Петра Орешина	0103000020E61000000100000005000000D811876C203546408046E9D2BFEC4940D811876C203546405801BEDBBCED49408E76DCF0BB3946405801BEDBBCED49408E76DCF0BB3946408046E9D2BFEC4940D811876C203546408046E9D2BFEC4940
30633	34	44.584707999999999	44.605414000000003	52.028205	52.007475999999997	Центральная	0103000020E61000000100000005000000D3DA34B6D74A4640A0C03BF9F4004A40D3DA34B6D74A4640B64AB0389C034A403145B9347E4D4640B64AB0389C034A403145B9347E4D4640A0C03BF9F4004A40D3DA34B6D74A4640A0C03BF9F4004A40
31126	32367	44.346663999999997	44.385013000000001	52.305163	52.282679000000002	Верхняя	0103000020E61000000100000005000000AB59677C5F2C46400C2252D32E244A40AB59677C5F2C46408179C8940F274A4076C4211B483146408179C8940F274A4076C4211B483146400C2252D32E244A40AB59677C5F2C46400C2252D32E244A40
30409	32323	44.476156000000003	44.545281000000003	52.360041000000002	52.340634000000001	Центральная	0103000020E61000000100000005000000A8E507AEF23C4640EDF318E5992B4A40A8E507AEF23C46400D1CD0D2152E4A40AA108FC4CB4546400D1CD0D2152E4A40AA108FC4CB454640EDF318E5992B4A40A8E507AEF23C4640EDF318E5992B4A40
31400	32453	44.662582999999998	44.727198999999999	52.378202999999999	52.347830000000002	Тургенева	0103000020E610000001000000050000005AF10D85CF544640AA4885B1852C4A405AF10D85CF544640E21FB6F468304A408A5759DB145D4640E21FB6F468304A408A5759DB145D4640AA4885B1852C4A405AF10D85CF544640AA4885B1852C4A40
31412	32286	44.565277999999999	44.587285999999999	52.294533999999999	52.273570999999997	Рабочая	0103000020E61000000100000005000000FB928D075B4846402711E15F04234A40FB928D075B484640B0C7444AB3254A4007B309302C4B4640B0C7444AB3254A4007B309302C4B46402711E15F04234A40FB928D075B4846402711E15F04234A40
30726	16562	44.513399999999997	44.548209999999997	52.223441000000001	52.180304999999997	Революционная	0103000020E6100000010000000500000019E25817B74146401327F73B14174A4019E25817B7414640F3CAF5B6991C4A408AABCABE2B464640F3CAF5B6991C4A408AABCABE2B4646401327F73B14174A4019E25817B74146401327F73B14174A40
31202	31419	48.363992000000003	48.390797999999997	52.525109	52.50647	Ленина	0103000020E61000000100000005000000B900344A972E4840DB334B02D4404A40B900344A972E4840EAEA8EC536434A40CDAB3AAB05324840EAEA8EC536434A40CDAB3AAB05324840DB334B02D4404A40B900344A972E4840DB334B02D4404A40
30725	32021	48.161682999999996	48.181176000000001	52.270187999999997	52.248778000000001	Комсомольская	0103000020E61000000100000005000000DAA84E07B21448406EFB1EF5D71F4A40DAA84E07B2144840C5E2378595224A40F96871C630174840C5E2378595224A40F96871C6301748406EFB1EF5D71F4A40DAA84E07B21448406EFB1EF5D71F4A40
30724	31932	48.242359999999998	48.265250000000002	52.324294999999999	52.314920000000001	Гагарина	0103000020E61000000100000005000000E5ED08A7051F48409C6D6E4C4F284A40E5ED08A7051F4840CFA0A17F82294A40CBA145B6F3214840CFA0A17F82294A40CBA145B6F32148409C6D6E4C4F284A40E5ED08A7051F48409C6D6E4C4F284A40
30890	32027	48.460849000000003	48.488354999999999	52.267592	52.240931000000003	Заовражная	0103000020E6100000010000000500000079B29B19FD3A4840DACBB6D3D61E4A4079B29B19FD3A4840EB55647440224A4046EBA86A823E4840EB55647440224A4046EBA86A823E4840DACBB6D3D61E4A4079B29B19FD3A4840DACBB6D3D61E4A40
30512	31799	48.301146000000003	48.328150000000001	52.357286000000002	52.339671000000003	Гагарина	0103000020E610000001000000050000001EA9BEF38B2648402733DE567A2B4A401EA9BEF38B264840CAA8328CBB2D4A405917B7D1002A4840CAA8328CBB2D4A405917B7D1002A48402733DE567A2B4A401EA9BEF38B2648402733DE567A2B4A40
30393	17626	48.600805999999999	48.660184999999998	52.515514000000003	52.483322000000001	Советская	0103000020E61000000100000005000000CB9E0436E74C4840FAB7CB7EDD3D4A40CB9E0436E74C4840A950DD5CFC414A40A6272CF180544840A950DD5CFC414A40A6272CF180544840FAB7CB7EDD3D4A40CB9E0436E74C4840FAB7CB7EDD3D4A40
30539	952	48.380521000000002	48.421061999999999	52.419701000000003	52.396901999999997	Советская	0103000020E610000001000000050000007A3881E9B4304840C6DB4AAFCD324A407A3881E9B43048409C8C2AC3B8354A404FCB0F5CE53548409C8C2AC3B8354A404FCB0F5CE5354840C6DB4AAFCD324A407A3881E9B4304840C6DB4AAFCD324A40
31045	31743	48.503006999999997	48.540278000000001	52.352576999999997	52.338202000000003	Ленина	0103000020E610000001000000050000005C548B88624048408DB800344A2B4A405C548B886240484030293E3E212D4A40C85F5AD42745484030293E3E212D4A40C85F5AD4274548408DB800344A2B4A405C548B88624048408DB800344A2B4A40
31040	29514	48.194659999999999	48.241992000000003	52.510351	52.465049	пл. 60 лет Советской Армии	0103000020E6100000010000000500000070EB6E9EEA184840CD04C3B9863B4A4070EB6E9EEA1848408E3D7B2E53414A4063F20698F91E48408E3D7B2E53414A4063F20698F91E4840CD04C3B9863B4A4070EB6E9EEA184840CD04C3B9863B4A40
30504	29514	48.194659999999999	48.241992000000003	52.510351	52.465049	Чернышевского	0103000020E6100000010000000500000070EB6E9EEA184840CD04C3B9863B4A4070EB6E9EEA1848408E3D7B2E53414A4063F20698F91E48408E3D7B2E53414A4063F20698F91E4840CD04C3B9863B4A4070EB6E9EEA184840CD04C3B9863B4A40
30257	29514	48.194659999999999	48.241992000000003	52.510351	52.465049	Ленина	0103000020E6100000010000000500000070EB6E9EEA184840CD04C3B9863B4A4070EB6E9EEA1848408E3D7B2E53414A4063F20698F91E48408E3D7B2E53414A4063F20698F91E4840CD04C3B9863B4A4070EB6E9EEA184840CD04C3B9863B4A40
31208	29514	48.194659999999999	48.241992000000003	52.510351	52.465049	Красноармейская	0103000020E6100000010000000500000070EB6E9EEA184840CD04C3B9863B4A4070EB6E9EEA1848408E3D7B2E53414A4063F20698F91E48408E3D7B2E53414A4063F20698F91E4840CD04C3B9863B4A4070EB6E9EEA184840CD04C3B9863B4A40
31017	29514	48.194659999999999	48.241992000000003	52.510351	52.465049	Заводская	0103000020E6100000010000000500000070EB6E9EEA184840CD04C3B9863B4A4070EB6E9EEA1848408E3D7B2E53414A4063F20698F91E48408E3D7B2E53414A4063F20698F91E4840CD04C3B9863B4A4070EB6E9EEA184840CD04C3B9863B4A40
31360	987	48.194758999999998	48.213048000000001	52.430173000000003	52.408605000000001	Ленина	0103000020E6100000010000000500000003CDE7DCED184840B5FD2B2B4D344A4003CDE7DCED184840A54FABE80F374A40363D2828451B4840A54FABE80F374A40363D2828451B4840B5FD2B2B4D344A4003CDE7DCED184840B5FD2B2B4D344A40
30987	31531	48.573264000000002	48.595111000000003	52.608738000000002	52.590415	Пушкина	0103000020E61000000100000005000000B1FCF9B660494840AF08FEB7924B4A40B1FCF9B6604948408EEA7420EB4D4A40B43EE5982C4C48408EEA7420EB4D4A40B43EE5982C4C4840AF08FEB7924B4A40B1FCF9B660494840AF08FEB7924B4A40
31572	53233	48.219237999999997	48.249789999999997	52.293123999999999	52.279769999999999	Советская	0103000020E610000001000000050000002D05A4FD0F1C48407233DC80CF234A402D05A4FD0F1C48401BD6541685254A40156F641EF91F48401BD6541685254A40156F641EF91F48407233DC80CF234A402D05A4FD0F1C48407233DC80CF234A40
31459	31572	48.569212	48.598793999999998	52.562395000000002	52.525032000000003	Грибанова	0103000020E61000000100000005000000D13E56F0DB4848403FADA23F34434A40D13E56F0DB4848408B37328FFC474A4040852348A54C48408B37328FFC474A4040852348A54C48403FADA23F34434A40D13E56F0DB4848403FADA23F34434A40
31118	31668	48.775421000000001	48.817956000000002	52.466360999999999	52.437558000000003	Мира	0103000020E61000000100000005000000D9D0CDFE40634840350D8AE601384A40D9D0CDFE406348409F909DB7B13B4A4093C83EC8B26848409F909DB7B13B4A4093C83EC8B2684840350D8AE601384A40D9D0CDFE40634840350D8AE601384A40
30885	31520	48.423882999999996	48.453401999999997	52.628492000000001	52.600999999999999	Кирова	0103000020E61000000100000005000000492A53CC41364840B0726891ED4C4A40492A53CC4136484019E6046D72504A4072F8A413093A484019E6046D72504A4072F8A413093A4840B0726891ED4C4A40492A53CC41364840B0726891ED4C4A40
31464	30609	49.218451999999999	49.242203000000003	51.182563999999999	51.164453999999999	Центральная	0103000020E6100000010000000500000076DF313CF69B484023D923D40C95494076DF313CF69B4840A6B6D4415E9749401EFF0582009F4840A6B6D4415E9749401EFF0582009F484023D923D40C95494076DF313CF69B484023D923D40C954940
30678	6284	48.775016000000001	48.792200999999999	51.21096	51.191229999999997	Целинная	0103000020E6100000010000000500000039F06AB933634840CD0182397A98494039F06AB933634840D061BEBC009B4940E36DA5D766654840D061BEBC009B4940E36DA5D766654840CD0182397A98494039F06AB933634840CD0182397A984940
30712	31125	48.861640999999999	48.898822000000003	50.924261999999999	50.906430999999998	Комсомольская	0103000020E6100000010000000500000045F295404A6E4840508A56EE0574494045F295404A6E4840C0779B374E76494071766B990C734840C0779B374E76494071766B990C734840508A56EE0574494045F295404A6E4840508A56EE05744940
31153	6280	48.776085000000002	48.811084000000001	51.256787000000003	51.243471	Советская	0103000020E6100000010000000500000045F5D6C0566348402043C70E2A9F494045F5D6C056634840DC847B65DEA049408927BB99D1674840DC847B65DEA049408927BB99D16748402043C70E2A9F494045F5D6C0566348402043C70E2A9F4940
30702	30836	48.877972	48.917417	51.369328000000003	51.346279000000003	переулок Школьный	0103000020E61000000100000005000000E066F162617048405325CADE52AC4940E066F16261704840A1BFD02346AF4940B0E595EB6D754840A1BFD02346AF4940B0E595EB6D7548405325CADE52AC4940E066F162617048405325CADE52AC4940
31199	31037	48.752153999999997	48.783603999999997	51.044018999999999	51.031264	пер. Школьный	0103000020E610000001000000050000001DC70F954660484065C57075008449401DC70F954660484089B3226AA2854940E481C8224D64484089B3226AA2854940E481C8224D64484065C57075008449401DC70F954660484065C5707500844940
31036	30973	49.123204000000001	49.144151999999998	50.960205000000002	50.940804	Школьна	0103000020E61000000100000005000000425E0F26C58F484016F9F5436C784940425E0F26C58F4840543A58FFE77A494095D39E9273924840543A58FFE77A494095D39E927392484016F9F5436C784940425E0F26C58F484016F9F5436C784940
30487	30615	48.998615999999998	49.023347000000001	51.250005999999999	51.232142000000003	Данукалова	0103000020E6100000010000000500000094A12AA6D27F484097033DD4B69D494094A12AA6D27F4840E2E6543200A04940D8BAD408FD824840E2E6543200A04940D8BAD408FD82484097033DD4B69D494094A12AA6D27F484097033DD4B69D4940
30871	29462	48.507731999999997	48.535201999999998	50.910980000000002	50.897818999999998	Советская	0103000020E61000000100000005000000FB90B75CFD4048401C5DA5BBEB724940FB90B75CFD404840B1A71DFE9A7449407C60C77F81444840B1A71DFE9A7449407C60C77F814448401C5DA5BBEB724940FB90B75CFD4048401C5DA5BBEB724940
31192	30929	49.125782000000001	49.149757999999999	50.908974999999998	50.888229000000003	Школьная	0103000020E610000001000000050000007636E49F19904840ED2DE57CB17149407636E49F19904840D8F0F44A597449403D2828452B934840D8F0F44A597449403D2828452B934840ED2DE57CB17149407636E49F19904840ED2DE57CB1714940
31448	30831	48.890251999999997	48.917399000000003	51.479981000000002	51.448272000000003	Школьная	0103000020E610000001000000050000006B990CC7F371484034DB15FA60B949406B990CC7F3714840C7D9740470BD49400A3197546D754840C7D9740470BD49400A3197546D75484034DB15FA60B949406B990CC7F371484034DB15FA60B94940
31191	30731	48.291220000000003	48.318744000000002	50.954849000000003	50.936518	Школьная	0103000020E6100000010000000500000077F86BB246254840C30E63D2DF77494077F86BB24625484025CFF57D387A4940EBE5779ACC28484025CFF57D387A4940EBE5779ACC284840C30E63D2DF77494077F86BB246254840C30E63D2DF774940
31188	30667	49.219512000000002	49.239364999999999	51.433748999999999	51.417760000000001	Ленинская	0103000020E610000001000000050000002F8A1EF8189C4840DAC9E02879B549402F8A1EF8189C48401BD6541685B749404D672783A39E48401BD6541685B749404D672783A39E4840DAC9E02879B549402F8A1EF8189C4840DAC9E02879B54940
30269	29202	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	Советская	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
31155	29202	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	Сиреневая	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
31014	29202	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	Садовая	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
30852	29202	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	Олимпийская	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
30427	29202	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	Набережная	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
67143	29202	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	Комсомольская	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
31384	29202	48.727567000000001	48.798346000000002	51.253771999999998	51.21584	Веселый	0103000020E610000001000000050000000D535BEA205D4840969526A5A09B49400D535BEA205D4840FC51D4997BA049403B72A43330664840FC51D4997BA049403B72A43330664840969526A5A09B49400D535BEA205D4840969526A5A09B4940
31022	30522	49.112018999999997	49.137602999999999	51.213742000000003	51.189892	Комсомольская	0103000020E61000000100000005000000EBC37AA3568E4840D2E28C614E984940EBC37AA3568E48400DE4D9E55B9B49406E6AA0F99C9148400DE4D9E55B9B49406E6AA0F99C914840D2E28C614E984940EBC37AA3568E4840D2E28C614E984940
30861	30517	49.266717999999997	49.296156000000003	51.028064000000001	51.015067000000002	Школьная	0103000020E6100000010000000500000094A0BFD023A24840DA1F28B7ED81494094A0BFD023A24840F418E59997834940D1419770E8A54840F418E59997834940D1419770E8A54840DA1F28B7ED81494094A0BFD023A24840DA1F28B7ED814940
30649	30420	48.741607999999999	48.791932000000003	50.921514000000002	50.904761000000001	Комсомольская	0103000020E61000000100000005000000DA39CD02ED5E48401FD95C35CF734940DA39CD02ED5E48403067B62BF4754940F4531C075E6548403067B62BF4754940F4531C075E6548401FD95C35CF734940DA39CD02ED5E48401FD95C35CF734940
31018	30311	48.660471999999999	48.682310000000001	51.295467000000002	51.282698000000003	Центральная	0103000020E610000001000000050000003CF6B3588A5448408352B4722FA449403CF6B3588A5448400C06D7DCD1A54940ECDD1FEF555748400C06D7DCD1A54940ECDD1FEF555748408352B4722FA449403CF6B3588A5448408352B4722FA44940
31316	29468	48.791465000000002	48.819510000000001	51.329191000000002	51.313209999999998	Набережная	0103000020E61000000100000005000000DE76A1B94E654840DC63E94317A84940DE76A1B94E6548409B9141EE22AA49405B5F24B4E56848409B9141EE22AA49405B5F24B4E5684840DC63E94317A84940DE76A1B94E654840DC63E94317A84940
31180	30315	48.705334000000001	48.743045000000002	51.109188000000003	51.091213000000003	Школьная	0103000020E61000000100000005000000E1606F62485A48402BFC19DEAC8B4940E1606F62485A4840CE8E54DFF98D4940693A3B191C5F4840CE8E54DFF98D4940693A3B191C5F48402BFC19DEAC8B4940E1606F62485A48402BFC19DEAC8B4940
30838	25840	46.315815999999998	46.350275000000003	51.794052999999998	51.785305999999999	Советская	0103000020E61000000100000005000000DAC69FA86C28474021AD31E884E44940DAC69FA86C28474035255987A3E549409FCDAACFD52C474035255987A3E549409FCDAACFD52C474021AD31E884E44940DAC69FA86C28474021AD31E884E44940
30466	25933	46.475822999999998	46.523650000000004	51.813488999999997	51.797863	Набережная	0103000020E61000000100000005000000A1D79FC4E73C47401FD8F15F20E64940A1D79FC4E73C4740EF53556820E84940744694F606434740EF53556820E84940744694F6064347401FD8F15F20E64940A1D79FC4E73C47401FD8F15F20E64940
30467	5225	46.560111999999997	46.587429999999998	51.922187000000001	51.911777000000001	Тростянка	0103000020E610000001000000050000006F0C01C0B14747405C1FD61BB5F449406F0C01C0B1474740EFE53E390AF649403A58FFE7304B4740EFE53E390AF649403A58FFE7304B47405C1FD61BB5F449406F0C01C0B14747405C1FD61BB5F44940
31154	25760	46.238129000000001	46.259751999999999	51.848925999999999	51.834336	Центральная	0103000020E61000000100000005000000569DD5027B1E47400FF0A485CBEA4940569DD5027B1E4740AF5C6F9BA9EC49400989B48D3F214740AF5C6F9BA9EC49400989B48D3F2147400FF0A485CBEA4940569DD5027B1E47400FF0A485CBEA4940
30469	26024	46.650097000000002	46.680081999999999	52.000124999999997	51.977241999999997	Клочкова	0103000020E61000000100000005000000261DE5603653474089230F4416FD4940261DE56036534740BC74931804004A40944C4EED0C574740BC74931804004A40944C4EED0C57474089230F4416FD4940261DE5603653474089230F4416FD4940
30309	53149	46.798678000000002	46.820138999999998	51.965229000000001	51.949567000000002	70 лет Октября	0103000020E610000001000000050000007104A9143B664740302E55698BF949407104A9143B6647404D13B69F8CFB49404A969350FA6847404D13B69F8CFB49404A969350FA684740302E55698BF949407104A9143B664740302E55698BF94940
30258	26071	46.671225	46.695686000000002	51.979371999999998	51.960318000000001	Центральная	0103000020E61000000100000005000000F9A067B3EA5547404CE141B3EBFA4940F9A067B3EA5547401E4FCB0F5CFD49407D24253D0C5947401E4FCB0F5CFD49407D24253D0C5947404CE141B3EBFA4940F9A067B3EA5547404CE141B3EBFA4940
9747	5323	46.575887000000002	46.607193000000002	51.833941000000003	51.822429999999997	Вишневая	0103000020E6100000010000000500000085984BAAB6494740E89FE06245E9494085984BAAB649474093E52494BEEA494019AE0E80B84D474093E52494BEEA494019AE0E80B84D4740E89FE06245E9494085984BAAB6494740E89FE06245E94940
31005	25845	46.363399000000001	46.373865000000002	51.872998000000003	51.862209	Запрудная	0103000020E610000001000000050000001633C2DB832E47408FA850DD5CEE49401633C2DB832E474099BC0166BEEF49403D0FEECEDA2F474099BC0166BEEF49403D0FEECEDA2F47408FA850DD5CEE49401633C2DB832E47408FA850DD5CEE4940
31524	53225	46.853726999999999	46.875546999999997	51.931261999999997	51.922615	Луговая	0103000020E61000000100000005000000295B24ED466D474047E6913F18F64940295B24ED466D4740F700DD9733F74940328E91EC11704740F700DD9733F74940328E91EC1170474047E6913F18F64940295B24ED466D474047E6913F18F64940
30676	5210	46.376621999999998	46.41057	51.826326999999999	51.804378999999997	Школьная	0103000020E61000000100000005000000207A5226353047406A4B1DE4F5E64940207A522635304740A1664815C5E94940FF5BC98E8D344740A1664815C5E94940FF5BC98E8D3447406A4B1DE4F5E64940207A5226353047406A4B1DE4F5E64940
30479	29733	46.906925000000001	46.955443000000002	51.840541000000002	51.809719000000001	Шеина	0103000020E6100000010000000500000060764F1E1674474094F947DFA4E7494060764F1E167447403CF9F4D896EB49409818CBF44B7A47403CF9F4D896EB49409818CBF44B7A474094F947DFA4E7494060764F1E1674474094F947DFA4E74940
67121	29733	46.906925000000001	46.955443000000002	51.840541000000002	51.809719000000001	Партизанская	0103000020E6100000010000000500000060764F1E1674474094F947DFA4E7494060764F1E167447403CF9F4D896EB49409818CBF44B7A47403CF9F4D896EB49409818CBF44B7A474094F947DFA4E7494060764F1E1674474094F947DFA4E74940
31236	29570	46.848436	46.884520999999999	52.000140999999999	51.986593999999997	Новая	0103000020E61000000100000005000000E15F048D996C4740043752B648FE4940E15F048D996C4740C231CB9E04004A4007D0EFFB37714740C231CB9E04004A4007D0EFFB37714740043752B648FE4940E15F048D996C4740043752B648FE4940
30924	26072	46.596646999999997	46.618889000000003	51.869872999999998	51.853332000000002	Школьная	0103000020E61000000100000005000000D520CCED5E4C4740AD50A4FB39ED4940D520CCED5E4C474032569BFF57EF4940556D37C1374F474032569BFF57EF4940556D37C1374F4740AD50A4FB39ED4940D520CCED5E4C4740AD50A4FB39ED4940
31008	29643	46.832194000000001	46.852586000000002	51.943182999999998	51.930218000000004	Мусы Джалиля	0103000020E61000000100000005000000B6F63E55856A47404513286211F74940B6F63E55856A474053927538BAF849408483BD89216D474053927538BAF849408483BD89216D47404513286211F74940B6F63E55856A47404513286211F74940
30684	26137	46.683414999999997	46.711478	51.754871000000001	51.735956000000002	Набережная	0103000020E61000000100000005000000444C89247A574740C2A563CE33DE4940444C89247A57474073D9E89C9FE0494068E90AB6115B474073D9E89C9FE0494068E90AB6115B4740C2A563CE33DE4940444C89247A574740C2A563CE33DE4940
31160	25942	46.487735000000001	46.506329999999998	51.911816000000002	51.897613	Луговая,	0103000020E61000000100000005000000AA0EB9196E3E474073BB97FBE4F24940AA0EB9196E3E47401AFCFD62B6F44940E97DE36BCF4047401AFCFD62B6F44940E97DE36BCF40474073BB97FBE4F24940AA0EB9196E3E474073BB97FBE4F24940
30824	27625	47.463836000000001	47.488773000000002	52.354745000000001	52.336418999999999	Центральная	0103000020E610000001000000050000008E5A61FA5EBB474063601DC70F2B4A408E5A61FA5EBB4740B3B5BE48682D4A407B15191D90BE4740B3B5BE48682D4A407B15191D90BE474063601DC70F2B4A408E5A61FA5EBB474063601DC70F2B4A40
31519	53217	47.130201	47.228405000000002	52.133927	52.083699000000003	улица Ленина	0103000020E610000001000000050000000874266DAA9047409DDA19A6B60A4A400874266DAA90474094861A8524114A40179F02603C9D474094861A8524114A40179F02603C9D47409DDA19A6B60A4A400874266DAA9047409DDA19A6B60A4A40
31525	53217	47.130201	47.228405000000002	52.133927	52.083699000000003	Ленина	0103000020E610000001000000050000000874266DAA9047409DDA19A6B60A4A400874266DAA90474094861A8524114A40179F02603C9D474094861A8524114A40179F02603C9D47409DDA19A6B60A4A400874266DAA9047409DDA19A6B60A4A40
30268	28694	47.752409999999998	47.785046000000001	52.129106999999998	52.105066999999998	Коммунистическая	0103000020E6100000010000000500000078978BF84EE04740C571E0D5720D4A4078978BF84EE04740A357039486104A4085ED27637CE44740A357039486104A4085ED27637CE44740C571E0D5720D4A4078978BF84EE04740C571E0D5720D4A40
31420	27848	46.765072000000004	46.790638000000001	52.196322000000002	52.185727999999997	Ленина	0103000020E61000000100000005000000EC8A19E1ED614740CAF962EFC5174A40EC8A19E1ED6147401FBE4C1421194A40C87C40A0336547401FBE4C1421194A40C87C40A033654740CAF962EFC5174A40EC8A19E1ED614740CAF962EFC5174A40
30246	28556	47.181845000000003	47.238726999999997	52.443354999999997	52.406923999999997	Московская	0103000020E6100000010000000500000077F86BB2469747408FFAEB1516344A4077F86BB24697474050C24CDBBF384A400AD6389B8E9E474050C24CDBBF384A400AD6389B8E9E47408FFAEB1516344A4077F86BB2469747408FFAEB1516344A40
30741	28954	47.388485000000003	47.406972000000003	52.325961999999997	52.308897000000002	Народная	0103000020E6100000010000000500000048FE60E0B9B14740906AD8EF89274A4048FE60E0B9B147408FDE701FB9294A40A13193A817B447408FDE701FB9294A40A13193A817B44740906AD8EF89274A4048FE60E0B9B14740906AD8EF89274A40
31092	25706	47.601035000000003	47.61354	52.065958000000002	52.05104	Санаторная	0103000020E610000001000000050000002D6002B7EECC4740D8648D7A88064A402D6002B7EECC47406D74CE4F71084A40D8648D7A88CE47406D74CE4F71084A40D8648D7A88CE4740D8648D7A88064A402D6002B7EECC4740D8648D7A88064A40
30222	26656	47.495500999999997	47.570897000000002	52.102378999999999	52.067442	Талалихина 	0103000020E610000001000000050000005111A7936CBF47403C3080F0A1084A405111A7936CBF47400A664CC11A0D4A403831242713C947400A664CC11A0D4A403831242713C947403C3080F0A1084A405111A7936CBF47403C3080F0A1084A40
31391	26656	47.495500999999997	47.570897000000002	52.102378999999999	52.067442	Советская	0103000020E610000001000000050000005111A7936CBF47403C3080F0A1084A405111A7936CBF47400A664CC11A0D4A403831242713C947400A664CC11A0D4A403831242713C947403C3080F0A1084A405111A7936CBF47403C3080F0A1084A40
31419	26656	47.495500999999997	47.570897000000002	52.102378999999999	52.067442	Красный Октябрь	0103000020E610000001000000050000005111A7936CBF47403C3080F0A1084A405111A7936CBF47400A664CC11A0D4A403831242713C947400A664CC11A0D4A403831242713C947403C3080F0A1084A405111A7936CBF47403C3080F0A1084A40
30991	28429	47.492573	47.515650000000001	52.167524999999998	52.138598000000002	Талалихина	0103000020E6100000010000000500000041F2CEA10CBF474040A54A94BD114A4041F2CEA10CBF474096218E7571154A405917B7D100C2474096218E7571154A405917B7D100C2474040A54A94BD114A4041F2CEA10CBF474040A54A94BD114A40
30812	28279	47.63306	47.664473999999998	52.116377999999997	52.101322000000003	Школьная	0103000020E61000000100000005000000F0332E1C08D14740C32E8A1EF80C4A40F0332E1C08D14740A8FC6B79E50E4A406A85E97B0DD54740A8FC6B79E50E4A406A85E97B0DD54740C32E8A1EF80C4A40F0332E1C08D14740C32E8A1EF80C4A40
31003	4521	47.076877000000003	47.088923999999999	52.508411000000002	52.493147999999998	Народная	0103000020E610000001000000050000004568041BD78947403D0B42791F3F4A404568041BD78947409DF6949C13414A402DEA93DC618B47409DF6949C13414A402DEA93DC618B47403D0B42791F3F4A404568041BD78947403D0B42791F3F4A40
30239	28027	46.941859999999998	46.982716000000003	52.170563000000001	52.144756000000001	переулок Школьный	0103000020E610000001000000050000008DB454DE8E7847402CF3565D87124A408DB454DE8E7847402E742502D5154A40C3A04CA3C97D47402E742502D5154A40C3A04CA3C97D47402CF3565D87124A408DB454DE8E7847402CF3565D87124A40
30619	28027	46.941859999999998	46.982716000000003	52.170563000000001	52.144756000000001	пер. Школьный	0103000020E610000001000000050000008DB454DE8E7847402CF3565D87124A408DB454DE8E7847402E742502D5154A40C3A04CA3C97D47402E742502D5154A40C3A04CA3C97D47402CF3565D87124A408DB454DE8E7847402CF3565D87124A40
30202	28027	46.941859999999998	46.982716000000003	52.170563000000001	52.144756000000001	Солопова	0103000020E610000001000000050000008DB454DE8E7847402CF3565D87124A408DB454DE8E7847402E742502D5154A40C3A04CA3C97D47402E742502D5154A40C3A04CA3C97D47402CF3565D87124A408DB454DE8E7847402CF3565D87124A40
31287	28027	46.941859999999998	46.982716000000003	52.170563000000001	52.144756000000001	Привокзальная	0103000020E610000001000000050000008DB454DE8E7847402CF3565D87124A408DB454DE8E7847402E742502D5154A40C3A04CA3C97D47402E742502D5154A40C3A04CA3C97D47402CF3565D87124A408DB454DE8E7847402CF3565D87124A40
31097	5117	47.336221000000002	47.394351	52.530045000000001	52.513508000000002	Октябрьская	0103000020E610000001000000050000003D9D2B4A09AB4740001E51A1BA414A403D9D2B4A09AB47404434BA83D8434A408C12F4177AB247404434BA83D8434A408C12F4177AB24740001E51A1BA414A403D9D2B4A09AB4740001E51A1BA414A40
30277	28852	47.267617000000001	47.281962999999998	52.349040000000002	52.331553999999997	Центральная	0103000020E61000000100000005000000446D1B4641A24740D26D895C702A4A40446D1B4641A24740787FBC57AD2C4A404DD7135D17A44740787FBC57AD2C4A404DD7135D17A44740D26D895C702A4A40446D1B4641A24740D26D895C702A4A40
31446	28938	47.350163000000002	47.379519999999999	52.398533999999998	52.389543000000003	Центральная	0103000020E6100000010000000500000077A22424D2AC474060B1868BDC314A4077A22424D2AC47400A2C802903334A40C616821C94B047400A2C802903334A40C616821C94B0474060B1868BDC314A4077A22424D2AC474060B1868BDC314A40
30394	28020	47.009188999999999	47.030909999999999	52.341794999999998	52.331553999999997	Молодежная	0103000020E61000000100000005000000D13DEB1A2D814740D26D895C702A4A40D13DEB1A2D814740D97745F0BF2B4A40478FDFDBF4834740D97745F0BF2B4A40478FDFDBF4834740D26D895C702A4A40D13DEB1A2D814740D26D895C702A4A40
31302	27893	47.218406999999999	47.247638000000002	52.292133	52.270733	Пролетарская	0103000020E61000000100000005000000D61BB5C2F49B474057790261A7224A40D61BB5C2F49B47408B8A389D64254A40999F1B9AB29F47408B8A389D64254A40999F1B9AB29F474057790261A7224A40D61BB5C2F49B474057790261A7224A40
30671	28985	47.489958999999999	47.528523	52.520401999999997	52.499195999999998	Луговая	0103000020E61000000100000005000000C0B0FCF9B6BE4740A2258FA7E53F4A40C0B0FCF9B6BE4740F16261889C424A40871744A4A6C34740F16261889C424A40871744A4A6C34740A2258FA7E53F4A40C0B0FCF9B6BE4740A2258FA7E53F4A40
30674	27757	46.835732999999998	46.896594	52.174982	52.145727999999998	Садовая	0103000020E610000001000000050000000F98874CF96A4740450E1137A7124A400F98874CF96A4740C0B167CF65164A4019E59997C3724740C0B167CF65164A4019E59997C3724740450E1137A7124A400F98874CF96A4740450E1137A7124A40
31285	22013	47.574544000000003	47.613216000000001	52.259825999999997	52.224074999999999	Рабочая	0103000020E61000000100000005000000780E65A88AC94740F46C567DAE1C4A40780E65A88AC94740435376FA41214A4025B1A4DC7DCE4740435376FA41214A4025B1A4DC7DCE4740F46C567DAE1C4A40780E65A88AC94740F46C567DAE1C4A40
31149	27954	47.104536000000003	47.136111999999997	52.277478000000002	52.261358000000001	пер. Школьный	0103000020E6100000010000000500000099A0866F618D47402446CF2D74214A4099A0866F618D474004AE2B6684234A40EC4B361E6C91474004AE2B6684234A40EC4B361E6C9147402446CF2D74214A4099A0866F618D47402446CF2D74214A40
30484	10740	46.918612000000003	46.966087999999999	52.579247000000002	52.550863999999997	Ленина	0103000020E6100000010000000500000049DBF81395754740994528B682464A4049DBF813957547402FA704C4244A4A406E8786C5A87B47402FA704C4244A4A406E8786C5A87B4740994528B682464A4049DBF81395754740994528B682464A40
31265	53200	47.463996999999999	47.474499000000002	52.092415000000003	52.087201999999998	Радужная площадь	0103000020E610000001000000050000009738F24064BB4740A912656F290B4A409738F24064BB474076543541D40B4A400B7E1B62BCBC474076543541D40B4A400B7E1B62BCBC4740A912656F290B4A409738F24064BB4740A912656F290B4A40
31164	28656	47.109127000000001	47.137019000000002	52.572324000000002	52.546269000000002	Ленина	0103000020E61000000100000005000000280EA0DFF78D4740C9E88024EC454A40280EA0DFF78D4740A35BAFE941494A401FF7ADD689914740A35BAFE941494A401FF7ADD689914740C9E88024EC454A40280EA0DFF78D4740C9E88024EC454A40
30855	12166	47.736716999999999	47.750739000000003	52.207864000000001	52.193666999999998	Центральная	0103000020E6100000010000000500000020B41EBE4CDE47403FA88B14CA184A4020B41EBE4CDE474004029D499B1A4A40776A2E3718E0474004029D499B1A4A40776A2E3718E047403FA88B14CA184A4020B41EBE4CDE47403FA88B14CA184A40
30153	16252	47.015163000000001	47.03922	52.532263999999998	52.523513999999999	Народная	0103000020E61000000100000005000000FC8D76DCF0814740C37FBA8102434A40FC8D76DCF0814740486B0C3A21444A40B0AC342905854740486B0C3A21444A40B0AC342905854740C37FBA8102434A40FC8D76DCF0814740C37FBA8102434A40
30920	27762	46.939857000000003	46.964587999999999	52.215021	52.199049000000002	Советская	0103000020E6100000010000000500000056F5F23B4D78474098A608707A194A4056F5F23B4D784740037AE1CE851B4A40990E9D9E777B4740037AE1CE851B4A40990E9D9E777B474098A608707A194A4056F5F23B4D78474098A608707A194A40
30573	28478	47.631362000000003	47.664904999999997	52.075595999999997	52.057110000000002	Колхозная	0103000020E61000000100000005000000F5F75278D0D04740252367614F074A40F5F75278D0D04740ADDA3521AD094A4033F9669B1BD54740ADDA3521AD094A4033F9669B1BD54740252367614F074A40F5F75278D0D04740252367614F074A40
30395	53133	47.310124999999999	47.310834	52.085735999999997	52.085419999999999	поселок Большевик	0103000020E6100000010000000500000004560E2DB2A747405036E50AEF0A4A4004560E2DB2A74740800BB265F90A4A40103E9468C9A74740800BB265F90A4A40103E9468C9A747405036E50AEF0A4A4004560E2DB2A747405036E50AEF0A4A40
30170	53133	47.310124999999999	47.310834	52.085735999999997	52.085419999999999	Здравоохранения	0103000020E6100000010000000500000004560E2DB2A747405036E50AEF0A4A4004560E2DB2A74740800BB265F90A4A40103E9468C9A74740800BB265F90A4A40103E9468C9A747405036E50AEF0A4A4004560E2DB2A747405036E50AEF0A4A40
30575	53133	47.310124999999999	47.310834	52.085735999999997	52.085419999999999	Дзержинского	0103000020E6100000010000000500000004560E2DB2A747405036E50AEF0A4A4004560E2DB2A74740800BB265F90A4A40103E9468C9A74740800BB265F90A4A40103E9468C9A747405036E50AEF0A4A4004560E2DB2A747405036E50AEF0A4A40
30346	53133	47.310124999999999	47.310834	52.085735999999997	52.085419999999999	Водопьянова	0103000020E6100000010000000500000004560E2DB2A747405036E50AEF0A4A4004560E2DB2A74740800BB265F90A4A40103E9468C9A74740800BB265F90A4A40103E9468C9A747405036E50AEF0A4A4004560E2DB2A747405036E50AEF0A4A40
31414	27676	47.259891000000003	47.299425999999997	52.191426	52.154933999999997	Революционная	0103000020E610000001000000050000002BC3B81B44A14740EC8497E0D4134A402BC3B81B44A1474053CDACA580184A403AC9569753A6474053CDACA580184A403AC9569753A64740EC8497E0D4134A402BC3B81B44A14740EC8497E0D4134A40
31327	28847	47.809705000000001	47.842250999999997	52.197403999999999	52.183419999999998	Октябрьская	0103000020E610000001000000050000002F34D769A4E7474056B77A4E7A174A402F34D769A4E74740BF0CC68844194A40FB027AE1CEEB4740BF0CC68844194A40FB027AE1CEEB474056B77A4E7A174A402F34D769A4E7474056B77A4E7A174A40
31171	28757	47.720438999999999	47.739725999999997	52.229283000000002	52.212184999999998	Коммунистическая	0103000020E61000000100000005000000A8E15B5837DC4740D3D9C9E0281B4A40A8E15B5837DC4740AF433525591D4A401D007157AFDE4740AF433525591D4A401D007157AFDE4740D3D9C9E0281B4A40A8E15B5837DC4740D3D9C9E0281B4A40
30439	27580	47.537424999999999	47.620026000000003	52.419595999999999	52.372117000000003	65 лет Октября	0103000020E61000000100000005000000C286A757CAC4474090A4A487A12F4A40C286A757CAC4474026C45C52B5354A40B95510035DCF474026C45C52B5354A40B95510035DCF474090A4A487A12F4A40C286A757CAC4474090A4A487A12F4A40
31413	27577	46.911515000000001	46.952433999999997	52.137172	52.100205000000003	Ленина	0103000020E610000001000000050000001F680586AC744740A6F27684D30C4A401F680586AC744740A5F622DA8E114A409ACC785BE9794740A5F622DA8E114A409ACC785BE9794740A6F27684D30C4A401F680586AC744740A6F27684D30C4A40
30766	25651	46.690295999999996	46.742345	52.460631999999997	52.428806000000002	Ленина	0103000020E61000000100000005000000A1478C9E5B5847400F2A711DE3364A40A1478C9E5B584740DBBE47FDF53A4A40B0AC3429055F4740DBBE47FDF53A4A40B0AC3429055F47400F2A711DE3364A40A1478C9E5B5847400F2A711DE3364A40
30364	25458	46.616247999999999	46.647050999999998	52.37182	52.359578999999997	Центральная	0103000020E61000000100000005000000DA1CE736E14E474008AA46AF062E4A40DA1CE736E14E4740D6FF39CC972F4A400BEC3191D2524740D6FF39CC972F4A400BEC3191D252474008AA46AF062E4A40DA1CE736E14E474008AA46AF062E4A40
30939	25504	46.904401	46.948185000000002	52.381523999999999	52.361004000000001	Советская	0103000020E610000001000000050000001FBC7669C3734740D3DC0A61352E4A401FBC7669C3734740CE5147C7D5304A4065C746205E794740CE5147C7D5304A4065C746205E794740D3DC0A61352E4A401FBC7669C3734740D3DC0A61352E4A40
30768	25452	46.580657000000002	46.6036	52.499809999999997	52.470858999999997	Победы	0103000020E61000000100000005000000C498F4F7524A47407D03931B453C4A40C498F4F7524A47405C1B2AC6F93F4A40CCEEC9C3424D47405C1B2AC6F93F4A40CCEEC9C3424D47407D03931B453C4A40C498F4F7524A47407D03931B453C4A40
30936	25360	46.366560999999997	46.406734	52.628464999999998	52.613025999999998	Центральная	0103000020E61000000100000005000000997E8978EB2E474081CCCEA2774E4A40997E8978EB2E47401FD7868A71504A40EC1516DC0F3447401FD7868A71504A40EC1516DC0F34474081CCCEA2774E4A40997E8978EB2E474081CCCEA2774E4A40
31383	25354	46.605539999999998	46.623480000000001	52.436894000000002	52.426274999999997	Вишневая	0103000020E61000000100000005000000BD35B055824D47401B0DE02D90364A40BD35B055824D4740C9E88024EC374A40E4DA5031CE4F4740C9E88024EC374A40E4DA5031CE4F47401B0DE02D90364A40BD35B055824D47401B0DE02D90364A40
31250	25267	46.912134999999999	46.946074000000003	52.431524000000003	52.406094000000003	Почтовая	0103000020E61000000100000005000000BB44F5D6C0744740098D60E3FA334A40BB44F5D6C074474035B8AD2D3C374A4047CCECF31879474035B8AD2D3C374A4047CCECF318794740098D60E3FA334A40BB44F5D6C0744740098D60E3FA334A40
30571	25221	46.646189	46.65793	52.537461999999998	52.522374999999997	Зеленая	0103000020E6100000010000000500000079043752B6524740BE9F1A2FDD424A4079043752B6524740DF6B088ECB444A405587DC0C37544740DF6B088ECB444A405587DC0C37544740BE9F1A2FDD424A4079043752B6524740BE9F1A2FDD424A40
31148	25168	46.556896000000002	46.589613	52.666553	52.659387000000002	Колхозная	0103000020E61000000100000005000000F9A23D5E484747402B3410CB66544A40F9A23D5E484747407D06D49B51554A40F2255470784B47407D06D49B51554A40F2255470784B47402B3410CB66544A40F9A23D5E484747402B3410CB66544A40
30756	25159	46.747186999999997	46.829742000000003	52.527639999999998	52.482362000000002	Победы	0103000020E61000000100000005000000887FD8D2A35F4740A56ABB09BE3D4A40887FD8D2A35F4740DD0720B589434A400F0F61FC346A4740DD0720B589434A400F0F61FC346A4740A56ABB09BE3D4A40887FD8D2A35F4740A56ABB09BE3D4A40
30568	25083	46.472033000000003	46.488948000000001	52.505056000000003	52.489063000000002	Новая	0103000020E61000000100000005000000FFD0CC936B3C47408257CB9D993E4A40FFD0CC936B3C47400553CDACA5404A40E9B81AD9953E47400553CDACA5404A40E9B81AD9953E47408257CB9D993E4A40FFD0CC936B3C47408257CB9D993E4A40
31487	25079	46.529542999999997	46.553742999999997	52.614846	52.589686999999998	Пионерская	0103000020E61000000100000005000000B169A510C84347402CF015DD7A4B4A40B169A510C8434740C8091346B34E4A40C8B1F50CE1464740C8091346B34E4A40C8B1F50CE14647402CF015DD7A4B4A40B169A510C84347402CF015DD7A4B4A40
31083	25004	46.709341000000002	46.790188999999998	52.346367000000001	52.311109999999999	Новая	0103000020E61000000100000005000000215B96AFCB5A4740B2BAD573D2274A40215B96AFCB5A4740F2B4FCC0552C4A405854C4E924654740F2B4FCC0552C4A405854C4E924654740B2BAD573D2274A40215B96AFCB5A4740B2BAD573D2274A40
30380	17376	46.601506999999998	46.663688	52.476152999999996	52.455160999999997	Ленина	0103000020E6100000010000000500000054A86E2EFE4C474013B534B7423A4A4054A86E2EFE4C47403672DD94F23C4A40B35F77BAF35447403672DD94F23C4A40B35F77BAF354474013B534B7423A4A4054A86E2EFE4C474013B534B7423A4A40
31482	53215	43.081601999999997	43.107796999999998	51.596229000000001	51.570681	Почтовая	0103000020E61000000100000005000000E3A430EF718A45406BB933130CC94940E3A430EF718A4540A1F65B3B51CC4940AFCDC64ACC8D4540A1F65B3B51CC4940AFCDC64ACC8D45406BB933130CC94940E3A430EF718A45406BB933130CC94940
67126	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	Юбилейная	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
30218	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	Пушкина	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
30150	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	Макаренко	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
31343	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	Луначарского	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
30214	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	Ленина	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
30505	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	К. Маркса	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
30436	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	Горохова	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
30503	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	Астраханская	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
30520	53127	43.162145000000002	43.163635999999997	51.536436000000002	51.535915000000003	 Юбилейная	0103000020E61000000100000005000000DF1AD82AC1944540CA37DBDC98C44940DF1AD82AC1944540D33252EFA9C4494060394206F2944540D33252EFA9C4494060394206F2944540CA37DBDC98C44940DF1AD82AC1944540CA37DBDC98C44940
31193	53195	43.147286999999999	43.170140000000004	51.535915000000003	51.516286000000001	 Ленина	0103000020E610000001000000050000001F10E84CDA924540FBB0DEA815C249401F10E84CDA924540CA37DBDC98C44940E8DEC325C7954540CA37DBDC98C44940E8DEC325C7954540FBB0DEA815C249401F10E84CDA924540FBB0DEA815C24940
9941	21355	48.352853000000003	48.375112999999999	52.149807000000003	52.131191000000001	Советская	0103000020E61000000100000005000000D3A57F492A2D4840C843DFDDCA104A40D3A57F492A2D48401FDB32E02C134A40F8A6E9B3033048401FDB32E02C134A40F8A6E9B303304840C843DFDDCA104A40D3A57F492A2D4840C843DFDDCA104A40
31168	20861	48.171250000000001	48.210388999999999	51.895873999999999	51.871451999999998	Краснознаменцев	0103000020E6100000010000000500000052B81E85EB154840530438BD8BEF494052B81E85EB15484019ABCDFFABF249401538D906EE1A484019ABCDFFABF249401538D906EE1A4840530438BD8BEF494052B81E85EB154840530438BD8BEF4940
30462	20299	47.836232000000003	47.857126999999998	51.833433999999997	51.821733999999999	Молодежная	0103000020E6100000010000000500000031EF71A609EB4740710168942EE9494031EF71A609EB4740EEAF1EF7ADEA494061C26856B6ED4740EEAF1EF7ADEA494061C26856B6ED4740710168942EE9494031EF71A609EB4740710168942EE94940
30472	20767	47.888827999999997	47.911285999999997	52.012371000000002	51.997070000000001	Школьная	0103000020E6100000010000000500000071E2AB1DC5F147404FE960FD9FFF494071E2AB1DC5F147409C35785F95014A40BDA60705A5F447409C35785F95014A40BDA60705A5F447404FE960FD9FFF494071E2AB1DC5F147404FE960FD9FFF4940
30688	19833	47.327849000000001	47.390802000000001	51.977024999999998	51.960661999999999	Ленина	0103000020E610000001000000050000005E83BEF4F6A947404641F0F8F6FA49405E83BEF4F6A94740EC2FBB270FFD49400F9BC8CC05B24740EC2FBB270FFD49400F9BC8CC05B247404641F0F8F6FA49405E83BEF4F6A947404641F0F8F6FA4940
30261	20967	48.294812999999998	48.314979999999998	51.862521000000001	51.854160999999998	Садовая	0103000020E61000000100000005000000C3B7B06EBC2548406342CC2555ED4940C3B7B06EBC2548407E8E8F1667EE49407172BF43512848407E8E8F1667EE49407172BF43512848406342CC2555ED4940C3B7B06EBC2548406342CC2555ED4940
31312	20289	47.779080999999998	47.804647000000003	51.743344999999998	51.720202	Советская	0103000020E61000000100000005000000ADF71BEDB8E34740C44142942FDC4940ADF71BEDB8E347409352D0ED25DF49408AE942ACFEE647409352D0ED25DF49408AE942ACFEE64740C44142942FDC4940ADF71BEDB8E34740C44142942FDC4940
31425	19992	47.461644	47.498995999999998	51.759821000000002	51.750476999999997	Центральная	0103000020E6100000010000000500000083328D2617BB474039B35DA10FE0494083328D2617BB474032E884D041E14940DB6AD619DFBF474032E884D041E14940DB6AD619DFBF474039B35DA10FE0494083328D2617BB474039B35DA10FE04940
30267	21164	48.168447	48.201065	52.055990999999999	52.043407999999999	Советская	0103000020E61000000100000005000000FE0DDAAB8F1548404031B2648E054A40FE0DDAAB8F15484067EF8CB62A074A4064AF777FBC19484067EF8CB62A074A4064AF777FBC1948404031B2648E054A40FE0DDAAB8F1548404031B2648E054A40
30993	20167	47.669432999999998	47.693472	51.740763000000001	51.717970000000001	Ворошилова	0103000020E610000001000000050000007CEE04FBAFD547402BC1E270E6DB49407CEE04FBAFD547401E8B6D52D1DE49408A58C4B0C3D847401E8B6D52D1DE49408A58C4B0C3D847402BC1E270E6DB49407CEE04FBAFD547402BC1E270E6DB4940
30857	21302	48.196196	48.208466999999999	52.134624000000002	52.114956999999997	Школьная	0103000020E6100000010000000500000092CD55F31C1948401FB935E9B60E4A4092CD55F31C194840DCA0F65B3B114A40CAA5F10BAF1A4840DCA0F65B3B114A40CAA5F10BAF1A48401FB935E9B60E4A4092CD55F31C1948401FB935E9B60E4A40
30687	21264	48.052205000000001	48.085118999999999	52.181288000000002	52.159846000000002	Центральная	0103000020E6100000010000000500000006D847A7AE064840BE326FD575144A4006D847A7AE0648402194F77134174A4055A2EC2DE50A48402194F77134174A4055A2EC2DE50A4840BE326FD575144A4006D847A7AE064840BE326FD575144A40
30262	20532	47.963946	47.989179	51.842449000000002	51.823403999999996	Победы	0103000020E61000000100000005000000158E209562FB4740A2B2614D65E94940158E209562FB474022C66B5ED5EB4940EB71DF6A9DFE474022C66B5ED5EB4940EB71DF6A9DFE4740A2B2614D65E94940158E209562FB4740A2B2614D65E94940
31324	21169	47.905357000000002	47.936610000000002	52.072031000000003	52.055593000000002	Карла Маркса	0103000020E61000000100000005000000331AF9BCE2F347407A71E2AB1D074A40331AF9BCE2F347402BA6D24F38094A40A48D23D6E2F747402BA6D24F38094A40A48D23D6E2F747407A71E2AB1D074A40331AF9BCE2F347407A71E2AB1D074A40
30655	19935	47.600712000000001	47.650955000000003	51.910049000000001	51.888609000000002	Мельникова	0103000020E610000001000000050000004A287D21E4CC474034F790F0BDF149404A287D21E4CC4740F660527C7CF449407715527E52D34740F660527C7CF449407715527E52D3474034F790F0BDF149404A287D21E4CC474034F790F0BDF14940
30664	3705	47.999321000000002	48.019002999999998	52.161304999999999	52.140051999999997	Кирова	0103000020E610000001000000050000005F9A22C0E9FF4740A4DE5339ED114A405F9A22C0E9FF474034D769A4A5144A4050C3B7B06E02484034D769A4A5144A4050C3B7B06E024840A4DE5339ED114A405F9A22C0E9FF4740A4DE5339ED114A40
30252	20367	47.871805000000002	47.890895	51.856825000000001	51.839010000000002	Заиргизная	0103000020E61000000100000005000000A1BE654E97EF47402C82FFAD64EB4940A1BE654E97EF474096B20C71ACED4940C095ECD808F2474096B20C71ACED4940C095ECD808F247402C82FFAD64EB4940A1BE654E97EF47402C82FFAD64EB4940
30266	20979	48.302314000000003	48.344830999999999	51.918604000000002	51.898240999999999	Чапаева	0103000020E61000000100000005000000BD8FA339B22648409276A38FF9F24940BD8FA339B2264840C6FCDCD094F54940D0D2156C232C4840C6FCDCD094F54940D0D2156C232C48409276A38FF9F24940BD8FA339B22648409276A38FF9F24940
30247	20063	47.723196999999999	47.772308000000002	51.904693000000002	51.881810999999999	Советская 	0103000020E610000001000000050000005CC823B891DC47406420CF2EDFF049405CC823B891DC4740C7F5EFFACCF34940373811FDDAE24740C7F5EFFACCF34940373811FDDAE247406420CF2EDFF049405CC823B891DC47406420CF2EDFF04940
30680	20656	48.078848999999998	48.119058000000003	51.862515000000002	51.845008999999997	Коммунистическая	0103000020E6100000010000000500000041295AB9170A4840AFE9414129EC494041295AB9170A48409CA73AE466EE4940E129E44A3D0F48409CA73AE466EE4940E129E44A3D0F4840AFE9414129EC494041295AB9170A4840AFE9414129EC4940
30892	19827	47.608733999999998	47.650585999999997	51.971766000000002	51.952914	Героев	0103000020E610000001000000050000004CFBE6FEEACD474045F30016F9F949404CFBE6FEEACD4740B0AE0AD462FC4940239EEC6646D34740B0AE0AD462FC4940239EEC6646D3474045F30016F9F949404CFBE6FEEACD474045F30016F9F94940
30682	20643	47.992691999999998	48.031103999999999	51.905904	51.888897999999998	Гагарина	0103000020E610000001000000050000001B800D8810FF47406ABDDF68C7F149401B800D8810FF474065A88AA9F4F349402C634337FB03484065A88AA9F4F349402C634337FB0348406ABDDF68C7F149401B800D8810FF47406ABDDF68C7F14940
30518	53157	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Степная	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
30475	19742	47.477857999999998	47.761024999999997	52.000086000000003	51.708975000000002	Сельхозтехникум	0103000020E61000000100000005000000E41071732ABD47403F575BB1BFDA4940E41071732ABD4740FF976BD102004A401D38674469E14740FF976BD102004A401D38674469E147403F575BB1BFDA4940E41071732ABD47403F575BB1BFDA4940
31024	19929	47.465083999999997	47.485143999999998	51.947735000000002	51.922092999999997	Пролетарская	0103000020E6100000010000000500000049F25CDF87BB47406D6FB72407F6494049F25CDF87BB4740252367614FF94940E1ECD63219BE4740252367614FF94940E1ECD63219BE47406D6FB72407F6494049F25CDF87BB47406D6FB72407F64940
31173	21077	48.098765	48.110424999999999	51.999077	51.990431999999998	1-й Микрорайон	0103000020E61000000100000005000000A67EDE54A40C4840B874CC79C6FE4940A67EDE54A40C4840C89750C1E1FF494095D40968220E4840C89750C1E1FF494095D40968220E4840B874CC79C6FE4940A67EDE54A40C4840B874CC79C6FE4940
31169	21020	48.097247000000003	48.135452000000001	51.973047000000001	51.961561000000003	Новая	0103000020E610000001000000050000002B51F696720C4840F60D4C6E14FB49402B51F696720C4840473CD9CD8CFC4940C216BB7D56114840473CD9CD8CFC4940C216BB7D56114840F60D4C6E14FB49402B51F696720C4840F60D4C6E14FB4940
30249	20172	47.796446000000003	47.823072000000003	51.9437	51.919215000000001	Набережная	0103000020E61000000100000005000000D88349F1F1E547400F7F4DD6A8F54940D88349F1F1E547401B9E5E29CBF849406D205D6C5AE947401B9E5E29CBF849406D205D6C5AE947400F7F4DD6A8F54940D88349F1F1E547400F7F4DD6A8F54940
30677	20543	48.087491	48.117880999999997	51.780118999999999	51.757831000000003	Молодежная	0103000020E61000000100000005000000E0D8B3E7320B48408F72309B00E14940E0D8B3E7320B48407EFE7BF0DAE34940EEE87FB9160F48407EFE7BF0DAE34940EEE87FB9160F48408F72309B00E14940E0D8B3E7320B48408F72309B00E14940
31165	20708	48.111916000000001	48.124096999999999	51.822363000000003	51.816628999999999	Мира	0103000020E6100000010000000500000017F37343530E48408BFB8F4C87E8494017F37343530E48406138D73043E949400F441669E20F48406138D73043E949400F441669E20F48408BFB8F4C87E8494017F37343530E48408BFB8F4C87E84940
9902	40350	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Шевченко	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
30234	40350	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Трнавская	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
31296	40350	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Титова	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
30595	40350	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Набережная Леонова	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
30561	40350	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Московская	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
30223	40350	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Минская	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
30610	40350	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Коммунистическая	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
30455	53156	47.737623999999997	47.930376000000003	52.050674999999998	51.920293000000001	30 лет Победы	0103000020E61000000100000005000000525F96766ADE47406EDE3829CCF54940525F96766ADE4740C6DCB5847C064A40DD7D8E8F16F74740C6DCB5847C064A40DD7D8E8F16F747406EDE3829CCF54940525F96766ADE47406EDE3829CCF54940
30180	53135	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	Коммунистическая	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
31540	53228	45.931497999999998	46.829391000000001	52.612057999999998	51.923898000000001	Комсомольская	0103000020E610000001000000050000000B2593533BF746407F6B274A42F649400B2593533BF74640A9A0A2EA574E4A40624CFA7B296A4740A9A0A2EA574E4A40624CFA7B296A47407F6B274A42F649400B2593533BF746407F6B274A42F64940
30625	16665	46.162464	46.187913000000002	52.516379999999998	52.506765999999999	пер.Почтовый	0103000020E610000001000000050000008063CF9ECB144740C45C52B5DD404A408063CF9ECB1447407C2766BD18424A4023BF7E880D1847407C2766BD18424A4023BF7E880D184740C45C52B5DD404A408063CF9ECB144740C45C52B5DD404A40
31386	16672	46.155825999999998	46.193787999999998	52.582841999999999	52.564129999999999	Победы	0103000020E61000000100000005000000E9EE3A1BF2134740A3586E6935484A40E9EE3A1BF21347401C5E10919A4A4A40BA2D910BCE1847401C5E10919A4A4A40BA2D910BCE184740A3586E6935484A40E9EE3A1BF2134740A3586E6935484A40
31074	16357	46.545774999999999	46.583342999999999	52.365931000000003	52.336826000000002	Школьная	0103000020E61000000100000005000000B9FC87F4DB454740A438471D1D2B4A40B9FC87F4DB454740DACBB6D3D62E4A40DEACC1FBAA4A4740DACBB6D3D62E4A40DEACC1FBAA4A4740A438471D1D2B4A40B9FC87F4DB454740A438471D1D2B4A40
30174	16873	46.056516999999999	46.089153000000003	52.417651999999997	52.404407999999997	Школьная	0103000020E610000001000000050000008255F5F23B074740D11E2FA4C3334A408255F5F23B074740F38DE89E75354A408FAB915D690B4740F38DE89E75354A408FAB915D690B4740D11E2FA4C3334A408255F5F23B074740D11E2FA4C3334A40
30733	16489	46.295172000000001	46.327717999999997	52.354860000000002	52.338124999999998	Ленина	0103000020E61000000100000005000000F3583332C8254740E17A14AE472B4A40F3583332C82547404C546F0D6C2D4A40BF27D6A9F22947404C546F0D6C2D4A40BF27D6A9F2294740E17A14AE472B4A40F3583332C8254740E17A14AE472B4A40
31489	15961	46.395406000000001	46.440537999999997	52.025357	52.001821	Молодежная 	0103000020E610000001000000050000003352EFA99C32474017B9A7AB3B004A403352EFA99C324740C2DCEEE53E034A409752978C63384740C2DCEEE53E034A409752978C6338474017B9A7AB3B004A403352EFA99C32474017B9A7AB3B004A40
31091	16111	46.598587000000002	46.647168000000001	52.231119	52.209888999999997	Ленина	0103000020E61000000100000005000000C767B27F9E4C474023658BA4DD1A4A40C767B27F9E4C4740FB3DB14E951D4A404582A966D6524740FB3DB14E951D4A404582A966D652474023658BA4DD1A4A40C767B27F9E4C474023658BA4DD1A4A40
31246	16872	46.119776000000002	46.184598999999999	52.270209999999999	52.245821999999997	Ленина	0103000020E61000000100000005000000406CE9D1540F474093516518771F4A40406CE9D1540F4740AD86C43D96224A40E9EFA5F0A0174740AD86C43D96224A40E9EFA5F0A017474093516518771F4A40406CE9D1540F474093516518771F4A40
30342	5804	46.498497	46.528725000000001	52.211345999999999	52.191088999999998	Революции	0103000020E61000000100000005000000BA13ECBFCE3F47400BD0B69A75184A40BA13ECBFCE3F4740F911BF620D1B4A40EFC9C342AD434740F911BF620D1B4A40EFC9C342AD4347400BD0B69A75184A40BA13ECBFCE3F47400BD0B69A75184A40
31403	16421	46.346843	46.392342999999997	52.341645999999997	52.317210000000003	Советская	0103000020E610000001000000050000005BECF659652C47406AFB57569A284A405BECF659652C474094675E0EBB2B4A4042E8A04B3832474094675E0EBB2B4A4042E8A04B383247406AFB57569A284A405BECF659652C47406AFB57569A284A40
30372	16802	46.097166000000001	46.116658999999999	52.543602	52.529158000000002	Новая	0103000020E610000001000000050000003E247CEF6F0C474059350873BB434A403E247CEF6F0C4740250516C094454A405CE49EAEEE0E4740250516C094454A405CE49EAEEE0E474059350873BB434A403E247CEF6F0C474059350873BB434A40
30431	15545	45.965643	45.997757999999997	52.316693000000001	52.305472000000002	Московская	0103000020E61000000100000005000000404E98309AFB4640FFEBDCB419274A40404E98309AFB4640A2EF6E6589284A4043A9BD88B6FF4640A2EF6E6589284A4043A9BD88B6FF4640FFEBDCB419274A40404E98309AFB4640FFEBDCB419274A40
30574	16057	46.541058999999997	46.578681000000003	52.070304	52.04569	Советская	0103000020E610000001000000050000006D1ADB6B414547408BE07F2BD9054A406D1ADB6B414547409563B2B8FF084A4086E81038124A47409563B2B8FF084A4086E81038124A47408BE07F2BD9054A406D1ADB6B414547408BE07F2BD9054A40
31122	27196	46.171950000000002	46.220728999999999	52.456391000000004	52.418745000000001	Октябрьская	0103000020E610000001000000050000000B46257502164740882EA86F99354A400B46257502164740299831056B3A4A40AF230ED9401C4740299831056B3A4A40AF230ED9401C4740882EA86F99354A400B46257502164740882EA86F99354A40
31102	16363	46.395567999999997	46.415528999999999	52.322076000000003	52.306083000000001	Советская	0103000020E610000001000000050000000CACE3F8A1324740486E4DBA2D274A400CACE3F8A1324740CB694FC939294A4011C5E40D30354740CB694FC939294A4011C5E40D30354740486E4DBA2D274A400CACE3F8A1324740486E4DBA2D274A40
30361	5664	46.486593999999997	46.536656999999998	51.992505999999999	51.974007	Кооперативная	0103000020E61000000100000005000000043752B6483E47409C89E942ACFC4940043752B6483E4740B98AC56F0AFF4940B115342DB1444740B98AC56F0AFF4940B115342DB14447409C89E942ACFC4940043752B6483E47409C89E942ACFC4940
30207	16257	46.623703999999996	46.665188000000001	52.296863999999999	52.266302000000003	Коммунистическая	0103000020E6100000010000000500000033315D88D54F4740016E162F16224A4033315D88D54F47400CAEB9A3FF254A4088D860E1245547400CAEB9A3FF254A4088D860E124554740016E162F16224A4033315D88D54F4740016E162F16224A40
31371	15890	46.235577999999997	46.276173	52.157243999999999	52.142350999999998	Победы	0103000020E610000001000000050000001BD47E6B271E4740C5C6BC8E38124A401BD47E6B271E474001BF469220144A40E48409A35923474001BF469220144A40E48409A359234740C5C6BC8E38124A401BD47E6B271E4740C5C6BC8E38124A40
30152	16062	46.690466999999998	46.753520000000002	52.178654000000002	52.149408999999999	Советская	0103000020E61000000100000005000000CEFBFF3861584740315D88D51F134A40CEFBFF386158474059A65F22DE164A40E370E6577360474059A65F22DE164A40E370E65773604740315D88D51F134A40CEFBFF3861584740315D88D51F134A40
31247	17022	45.998800000000003	46.039870999999998	52.370885000000001	52.362681000000002	Молодежная	0103000020E61000000100000005000000569FABADD8FF4640B7F0BC546C2E4A40569FABADD8FF4640DAC9E028792F4A408787307E1A054740DAC9E028792F4A408787307E1A054740B7F0BC546C2E4A40569FABADD8FF4640B7F0BC546C2E4A40
30177	16972	46.282066	46.302079999999997	52.517662000000001	52.502918000000001	Школьная	0103000020E6100000010000000500000022A81ABD1A244740ED48F59D5F404A4022A81ABD1A244740E43098BF42424A404963B48EAA264740E43098BF42424A404963B48EAA264740ED48F59D5F404A4022A81ABD1A244740ED48F59D5F404A40
30212	5855	46.280332000000001	46.316974000000002	52.396731000000003	52.375751000000001	Жукова	0103000020E61000000100000005000000DA0242EBE12347403B38D89B18304A40DA0242EBE12347409A27D714C8324A4056D7A19A922847409A27D714C8324A4056D7A19A922847403B38D89B18304A40DA0242EBE12347403B38D89B18304A40
31245	16728	46.193742999999998	46.222983999999997	52.591498000000001	52.581632999999997	Коммунистическая	0103000020E610000001000000050000001A6A1492CC1847401EA33CF3724A4A401A6A1492CC18474020D3DA34B64B4A4000C45DBD8A1C474020D3DA34B64B4A4000C45DBD8A1C47401EA33CF3724A4A401A6A1492CC1847401EA33CF3724A4A40
30354	5595	46.388911	46.442279999999997	52.300691999999998	52.250751999999999	Топольчанская	0103000020E61000000100000005000000FF06EDD5C73147400BB43BA418204A40FF06EDD5C73147409C1551137D264A4062D68BA19C3847409C1551137D264A4062D68BA19C3847400BB43BA418204A40FF06EDD5C73147400BB43BA418204A40
31368	5595	46.388911	46.442279999999997	52.300691999999998	52.250751999999999	Социальная	0103000020E61000000100000005000000FF06EDD5C73147400BB43BA418204A40FF06EDD5C73147409C1551137D264A4062D68BA19C3847409C1551137D264A4062D68BA19C3847400BB43BA418204A40FF06EDD5C73147400BB43BA418204A40
31375	5595	46.388911	46.442279999999997	52.300691999999998	52.250751999999999	Некрасова	0103000020E61000000100000005000000FF06EDD5C73147400BB43BA418204A40FF06EDD5C73147409C1551137D264A4062D68BA19C3847409C1551137D264A4062D68BA19C3847400BB43BA418204A40FF06EDD5C73147400BB43BA418204A40
30689	5595	46.388911	46.442279999999997	52.300691999999998	52.250751999999999	Ленина	0103000020E61000000100000005000000FF06EDD5C73147400BB43BA418204A40FF06EDD5C73147409C1551137D264A4062D68BA19C3847409C1551137D264A4062D68BA19C3847400BB43BA418204A40FF06EDD5C73147400BB43BA418204A40
30928	15817	46.304461000000003	46.375877000000003	52.243257999999997	52.212549000000003	Советская	0103000020E6100000010000000500000028F4FA93F826474015E63DCE341B4A4028F4FA93F8264740C43E0114231F4A40C828CFBC1C304740C43E0114231F4A40C828CFBC1C30474015E63DCE341B4A4028F4FA93F826474015E63DCE341B4A40
31225	14394	44.879193999999998	44.904895000000003	52.181840999999999	52.167050000000003	Рабочая	0103000020E61000000100000005000000726BD26D89704640FE65F7E461154A40726BD26D897046403509DE9046174A402FA86F99D37346403509DE9046174A402FA86F99D3734640FE65F7E461154A40726BD26D89704640FE65F7E461154A40
30326	14623	44.954265999999997	44.973866999999998	51.916137999999997	51.901947999999997	Школьная	0103000020E61000000100000005000000A5D76663257A4640A758350873F34940A5D76663257A4640B94F8E0244F54940AAD381ACA77C4640B94F8E0244F54940AAD381ACA77C4640A758350873F34940A5D76663257A4640A758350873F34940
30542	14970	45.083964999999999	45.099891999999997	51.990403999999998	51.982455999999999	Школьная	0103000020E610000001000000050000001B81785DBF8A464026E1421EC1FD49401B81785DBF8A4640EEE9EA8EC5FE4940E690D442C98C4640EEE9EA8EC5FE4940E690D442C98C464026E1421EC1FD49401B81785DBF8A464026E1421EC1FD4940
31472	14530	45.017687000000002	45.042524999999998	52.065055999999998	52.052508000000003	Центральная	0103000020E610000001000000050000003D484F9143824640A2630795B8064A403D484F91438246404C3448C153084A4096218E75718546404C3448C153084A4096218E7571854640A2630795B8064A403D484F9143824640A2630795B8064A40
30916	15301	44.929777999999999	44.946010000000001	51.748894	51.738627000000001	Рабочая	0103000020E6100000010000000500000028452BF702774640A7785C548BDE494028452BF702774640D71533C2DBDF494030D80DDB16794640D71533C2DBDF494030D80DDB16794640A7785C548BDE494028452BF702774640A7785C548BDE4940
30545	14928	45.170482	45.194403999999999	51.998427999999997	51.982112000000001	Советская	0103000020E610000001000000050000004147AB5AD29546402C8194D8B5FD49404147AB5AD295464091B41B7DCCFF4940151BF33AE298464091B41B7DCCFF4940151BF33AE29846402C8194D8B5FD49404147AB5AD29546402C8194D8B5FD4940
30737	14915	45.435673000000001	45.465183000000003	51.944504999999999	51.938220000000001	Школьная	0103000020E6100000010000000500000007600322C4B74640003ACC9717F8494007600322C4B7464049F4328AE5F84940DDD3D51D8BBB464049F4328AE5F84940DDD3D51D8BBB4640003ACC9717F8494007600322C4B74640003ACC9717F84940
30553	15398	44.899262	44.949576999999998	51.680917000000001	51.653489	Школьная	0103000020E610000001000000050000008D4468041B734640DBA50D87A5D349408D4468041B7346402D25CB4928D74940530438BD8B7946402D25CB4928D74940530438BD8B794640DBA50D87A5D349408D4468041B734640DBA50D87A5D34940
30909	14825	45.248491000000001	45.263843000000001	51.855696000000002	51.846978	Школьная	0103000020E61000000100000005000000D82C978DCE9F46403B376DC669EC4940D82C978DCE9F4640B5A84F7287ED4940A723809BC5A14640B5A84F7287ED4940A723809BC5A146403B376DC669EC4940D82C978DCE9F46403B376DC669EC4940
30905	14674	44.749611999999999	44.798552000000001	51.960768000000002	51.93797	Революционная	0103000020E6100000010000000500000036583849F35F46408750A5660FF8494036583849F35F46408C852172FAFA4940E413B2F3366646408C852172FAFA4940E413B2F3366646408750A5660FF8494036583849F35F46408750A5660FF84940
30551	15397	45.062199	45.091276999999998	51.764336	51.748085000000003	Солнечная	0103000020E61000000100000005000000056C0723F687464068D0D03FC1DF4940056C0723F6874640E69315C3D5E1494041F0F8F6AE8B4640E69315C3D5E1494041F0F8F6AE8B464068D0D03FC1DF4940056C0723F687464068D0D03FC1DF4940
30736	14738	44.689326000000001	44.866393000000002	52.000092000000002	51.669131999999998	Советская	0103000020E61000000100000005000000292499D53B584640815A0C1EA6D54940292499D53B584640E17EC00303004A40DE3D40F7E56E4640E17EC00303004A40DE3D40F7E56E4640815A0C1EA6D54940292499D53B584640815A0C1EA6D54940
30548	15203	44.685957000000002	44.727108999999999	51.745525999999998	51.728313999999997	Молодежная	0103000020E610000001000000050000002CBB6070CD574640069CA56439DD49402CBB6070CD574640AA285E656DDF49404AD05FE8115D4640AA285E656DDF49404AD05FE8115D4640069CA56439DD49402CBB6070CD574640069CA56439DD4940
31244	15489	45.203628999999999	45.221846999999997	51.659796999999998	51.650114000000002	Чапаева	0103000020E6100000010000000500000033C2DB83109A4640FC5580EF36D3494033C2DB83109A4640DC7F643A74D449409CDB847B659C4640DC7F643A74D449409CDB847B659C4640FC5580EF36D3494033C2DB83109A4640FC5580EF36D34940
30753	14632	44.662483999999999	44.711128000000002	51.916893000000002	51.901263999999998	Советская	0103000020E61000000100000005000000C70F9546CC544640F487669E5CF34940C70F9546CC5446403677F4BF5CF549408CA2073E065B46403677F4BF5CF549408CA2073E065B4640F487669E5CF34940C70F9546CC544640F487669E5CF34940
30739	14819	45.209449999999997	45.228306000000003	51.839616999999997	51.825425000000003	Центральная	0103000020E61000000100000005000000D712F241CF9A46408126C286A7E94940D712F241CF9A46403315E29178EB494084BD8921399D46403315E29178EB494084BD8921399D46408126C286A7E94940D712F241CF9A46408126C286A7E94940
67035	15095	44.825060999999998	44.848875999999997	51.843750999999997	51.817881999999997	Кооперативная	0103000020E610000001000000050000003F1A4E999B69464058FE7C5BB0E849403F1A4E999B694640D07B630800EC4940FD2D01F8A76C4640D07B630800EC4940FD2D01F8A76C464058FE7C5BB0E849403F1A4E999B69464058FE7C5BB0E84940
30320	14526	44.881368000000002	44.899037999999997	51.988273999999997	51.955179000000001	Центральная	0103000020E61000000100000005000000D7DEA7AAD0704640BA69334E43FA4940D7DEA7AAD070464059BE2EC37FFE49403DEE5BAD1373464059BE2EC37FFE49403DEE5BAD13734640BA69334E43FA4940D7DEA7AAD0704640BA69334E43FA4940
31241	15192	44.491408999999997	44.572563000000002	51.786147999999997	51.769987999999998	Молодежная	0103000020E61000000100000005000000E3FA777DE63E4640FE277FF78EE24940E3FA777DE63E46406CE8667FA0E4494028F38FBE494946406CE8667FA0E4494028F38FBE49494640FE277FF78EE24940E3FA777DE63E4640FE277FF78EE24940
31465	9537	45.177354000000001	45.208714000000001	51.776786999999999	51.760663000000001	Перспективная	0103000020E610000001000000050000004BE82E89B39646407D23BA675DE149404BE82E89B39646409E7AA4C16DE34940D21BEE23B79A46409E7AA4C16DE34940D21BEE23B79A46407D23BA675DE149404BE82E89B39646407D23BA675DE14940
30241	5862	44.834853000000003	44.860868000000004	52.136111	52.114519999999999	Школьная	0103000020E61000000100000005000000D7FB8D76DC6A4640745E6397A80E4A40D7FB8D76DC6A46401CD0D2156C114A40231631EC306E46401CD0D2156C114A40231631EC306E4640745E6397A80E4A40D7FB8D76DC6A4640745E6397A80E4A40
31242	15247	44.761766000000001	44.777710999999996	51.685913999999997	51.667026	Центральная	0103000020E61000000100000005000000359A5C8C8161464075CAA31B61D54940359A5C8C816146402CEFAA07CCD74940A65EB7088C6346402CEFAA07CCD74940A65EB7088C63464075CAA31B61D54940359A5C8C8161464075CAA31B61D54940
31062	15025	45.049281000000001	45.070777	51.908465999999997	51.895479000000002	Советская	0103000020E6100000010000000500000037A8FDD64E8646409DA04D0E9FF2494037A8FDD64E86464093C3279D48F449408D2782380F89464093C3279D48F449408D2782380F8946409DA04D0E9FF2494037A8FDD64E8646409DA04D0E9FF24940
30315	53151	44.490493000000001	45.539392999999997	52.233297999999998	51.564796999999999	Советская	0103000020E610000001000000050000005EF58079C83E464080F0A1444BC849405EF58079C83E4640711C78B5DC1D4A407D586FD40AC54640711C78B5DC1D4A407D586FD40AC5464080F0A1444BC849405EF58079C83E464080F0A1444BC84940
30524	53151	44.490493000000001	45.539392999999997	52.233297999999998	51.564796999999999	Ленина	0103000020E610000001000000050000005EF58079C83E464080F0A1444BC849405EF58079C83E4640711C78B5DC1D4A407D586FD40AC54640711C78B5DC1D4A407D586FD40AC5464080F0A1444BC849405EF58079C83E464080F0A1444BC84940
30879	12978	43.753667999999998	43.773412999999998	51.768734000000002	51.749685999999997	Школьная	0103000020E6100000010000000500000057056A3178E045407022FAB5F5DF494057056A3178E0454061A92EE065E249408FA67A32FFE2454061A92EE065E249408FA67A32FFE245407022FAB5F5DF494057056A3178E045407022FAB5F5DF4940
30507	12733	43.29974	43.641800000000003	52.150016999999998	51.770600999999999	Буднюка	0103000020E61000000100000005000000CAA65CE15DA64540E8A1B60DA3E24940CAA65CE15DA64540096CCEC133134A4052499D8026D24540096CCEC133134A4052499D8026D24540E8A1B60DA3E24940CAA65CE15DA64540E8A1B60DA3E24940
31039	13107	43.893284000000001	43.912948	51.689287	51.670924999999997	Школьная	0103000020E6100000010000000500000021054F2157F24540CE88D2DEE0D5494021054F2157F245406B47718E3AD849406C79E57ADBF445406B47718E3AD849406C79E57ADBF44540CE88D2DEE0D5494021054F2157F24540CE88D2DEE0D54940
30517	12644	43.340757000000004	43.36891	51.893577999999998	51.870773999999997	Дружбы Народов	0103000020E610000001000000050000000971E5EC9DAB4540821ABE8575EF49400971E5EC9DAB454069368FC360F249406C95607138AF454069368FC360F249406C95607138AF4540821ABE8575EF49400971E5EC9DAB4540821ABE8575EF4940
30496	12933	43.579358999999997	43.623016999999997	51.871402000000003	51.848570000000002	пер.Школьный	0103000020E6100000010000000500000056D28A6F28CA4540F12E17F19DEC494056D28A6F28CA4540A2D5C9198AEF49400FED6305BFCF4540A2D5C9198AEF49400FED6305BFCF4540F12E17F19DEC494056D28A6F28CA4540F12E17F19DEC4940
30511	13601	43.490605000000002	43.510106999999998	51.991878999999997	51.969906999999999	Школьная	0103000020E6100000010000000500000086200725CCBE4540AB949EE925FC494086200725CCBE45406A4B1DE4F5FE4940F73AA92F4BC145406A4B1DE4F5FE4940F73AA92F4BC14540AB949EE925FC494086200725CCBE4540AB949EE925FC4940
30348	12728	43.237054999999998	43.277596000000003	51.849392999999999	51.819591000000003	Трудовая	0103000020E61000000100000005000000382D78D1579E4540488C9E5BE8E84940382D78D1579E4540C539EAE8B8EC49400EC0064488A34540C539EAE8B8EC49400EC0064488A34540488C9E5BE8E84940382D78D1579E4540488C9E5BE8E84940
31450	12857	43.460754000000001	43.505715000000002	51.874648999999998	51.845726999999997	Молодежная	0103000020E6100000010000000500000027C0B0FCF9BA45400E2C47C840EC494027C0B0FCF9BA4540533D997FF4EF49405F0CE544BBC04540533D997FF4EF49405F0CE544BBC045400E2C47C840EC494027C0B0FCF9BA45400E2C47C840EC4940
31344	13674	43.542977	43.563924999999998	51.973680000000002	51.958764000000002	Садовая	0103000020E6100000010000000500000077BD344580C54540844A5CC7B8FA494077BD344580C545407862D68BA1FC4940CA32C4B12EC845407862D68BA1FC4940CA32C4B12EC84540844A5CC7B8FA494077BD344580C54540844A5CC7B8FA4940
31037	13034	43.690722999999998	43.723959999999998	51.735576000000002	51.719293	Мира	0103000020E6100000010000000500000029CC7B9C69D84540F19E03CB11DC494029CC7B9C69D845407BDCB75A27DE49405BCEA5B8AADC45407BDCB75A27DE49405BCEA5B8AADC4540F19E03CB11DC494029CC7B9C69D84540F19E03CB11DC4940
30721	13483	43.715040000000002	43.763064	51.989494000000001	51.980276000000003	Новая	0103000020E610000001000000050000007AAA436E86DB4540E08618AF79FD49407AAA436E86DB45404BCB48BDA7FE4940A260C614ACE145404BCB48BDA7FE4940A260C614ACE14540E08618AF79FD49407AAA436E86DB4540E08618AF79FD4940
30878	12853	43.385269000000001	43.442346999999998	51.792304000000001	51.760289	Крупской	0103000020E61000000100000005000000D1949D7E50B145401841632651E14940D1949D7E50B14540B83EAC376AE54940EA3D95D39EB84540B83EAC376AE54940EA3D95D39EB845401841632651E14940D1949D7E50B145401841632651E14940
31042	13211	43.695824999999999	43.726080000000003	51.921393000000002	51.902931000000002	Школьная	0103000020E610000001000000050000009E5E29CB10D94540B5C5353E93F349409E5E29CB10D94540B5E1B034F0F54940CD237F30F0DC4540B5E1B034F0F54940CD237F30F0DC4540B5C5353E93F349409E5E29CB10D94540B5C5353E93F34940
30866	3650	43.367607999999997	43.391359000000001	51.878886000000001	51.867170000000002	Кумысная	0103000020E61000000100000005000000BDDF68C70DAF45404209336DFFEE4940BDDF68C70DAF4540C57421567FF0494065FF3C0D18B24540C57421567FF0494065FF3C0D18B245404209336DFFEE4940BDDF68C70DAF45404209336DFFEE4940
30713	13263	43.622872999999998	43.651933	51.916831999999999	51.905115000000002	Радищева	0103000020E61000000100000005000000DC476E4DBACF45403D0FEECEDAF34940DC476E4DBACF454090F63FC05AF549407217618A72D3454090F63FC05AF549407217618A72D345403D0FEECEDAF34940DC476E4DBACF45403D0FEECEDAF34940
30661	53161	43.392418999999997	43.437443000000002	51.922431000000003	51.901614000000002	Прихоперская	0103000020E610000001000000050000001DAA29C93AB24540D1CE691668F349401DAA29C93AB2454086E8103812F649409C6ED921FEB7454086E8103812F649409C6ED921FEB74540D1CE691668F349401DAA29C93AB24540D1CE691668F34940
30425	13319	43.517339	43.564276	52.063167999999997	52.046199999999999	Ленина	0103000020E6100000010000000500000001F9122A38C24540A089B0E1E9054A4001F9122A38C24540AD1397E315084A4077F52A323AC84540AD1397E315084A4077F52A323AC84540A089B0E1E9054A4001F9122A38C24540A089B0E1E9054A40
31210	13397	43.649849000000003	43.704467000000001	52.113607000000002	52.091921999999997	Советская	0103000020E610000001000000050000004E2B85402ED3454036E49F19C40B4A404E2B85402ED3454060CC96AC8A0E4A403D0E83F92BDA454060CC96AC8A0E4A403D0E83F92BDA454036E49F19C40B4A404E2B85402ED3454036E49F19C40B4A40
30884	13205	43.777023999999997	43.816217000000002	51.893738999999997	51.874538000000001	Инициативная	0103000020E61000000100000005000000821ABE8575E34540FC8D76DCF0EF4940821ABE8575E345407214200A66F2494039B874CC79E845407214200A66F2494039B874CC79E84540FC8D76DCF0EF4940821ABE8575E34540FC8D76DCF0EF4940
30502	12936	43.623097000000001	43.659219	51.833067	51.814920000000001	Школьная	0103000020E610000001000000050000002C9E7AA4C1CF45409C6D6E4C4FE849402C9E7AA4C1CF45403C3080F0A1EA49406FF3C64961D445403C3080F0A1EA49406FF3C64961D445409C6D6E4C4FE849402C9E7AA4C1CF45409C6D6E4C4FE84940
30297	13539	43.312657999999999	43.358246999999999	52.071787999999998	52.051682999999997	Советская	0103000020E61000000100000005000000986A662D05A845402C616D8C9D064A40986A662D05A84540641F645930094A40EF71A609DBAD4540641F645930094A40EF71A609DBAD45402C616D8C9D064A40986A662D05A845402C616D8C9D064A40
30714	13396	43.606873999999998	43.641880999999998	52.070397999999997	52.060349000000002	Первомайская	0103000020E610000001000000050000007765170CAECD454054AC1A84B9074A407765170CAECD454016DA39CD02094A403E76172829D2454016DA39CD02094A403E76172829D2454054AC1A84B9074A407765170CAECD454054AC1A84B9074A40
30294	13500	43.346946000000003	43.387172999999997	52.124833000000002	52.094811	Кооперативная	0103000020E6100000010000000500000030BDFDB968AC4540892650C4220C4A4030BDFDB968AC4540153B1A87FA0F4A40757286E28EB14540153B1A87FA0F4A40757286E28EB14540892650C4220C4A4030BDFDB968AC4540892650C4220C4A40
30201	3529	43.463304999999998	43.553711999999997	51.951937999999998	51.907364999999999	Ленина	0103000020E61000000100000005000000618907944DBB45407C444C8924F44940618907944DBB4540EAE8B81AD9F949408DB3E908E0C64540EAE8B81AD9F949408DB3E908E0C645407C444C8924F44940618907944DBB45407C444C8924F44940
30698	3529	43.463304999999998	43.553711999999997	51.951937999999998	51.907364999999999	Л.Толстого	0103000020E61000000100000005000000618907944DBB45407C444C8924F44940618907944DBB4540EAE8B81AD9F949408DB3E908E0C64540EAE8B81AD9F949408DB3E908E0C645407C444C8924F44940618907944DBB45407C444C8924F44940
30816	3529	43.463304999999998	43.553711999999997	51.951937999999998	51.907364999999999	Калинина	0103000020E61000000100000005000000618907944DBB45407C444C8924F44940618907944DBB4540EAE8B81AD9F949408DB3E908E0C64540EAE8B81AD9F949408DB3E908E0C645407C444C8924F44940618907944DBB45407C444C8924F44940
31382	3529	43.463304999999998	43.553711999999997	51.951937999999998	51.907364999999999	Заводская	0103000020E61000000100000005000000618907944DBB45407C444C8924F44940618907944DBB4540EAE8B81AD9F949408DB3E908E0C64540EAE8B81AD9F949408DB3E908E0C645407C444C8924F44940618907944DBB45407C444C8924F44940
30912	13115	43.899895000000001	43.964781000000002	51.849398999999998	51.829031999999998	Алексеевская	0103000020E61000000100000005000000BE6A65C22FF3454032AB77B81DEA4940BE6A65C22FF34540A7203F1BB9EC4940AE669DF17DFB4540A7203F1BB9EC4940AE669DF17DFB454032AB77B81DEA4940BE6A65C22FF3454032AB77B81DEA4940
31436	12115	48.344040999999997	48.363894000000002	50.09487	50.085166000000001	Алгайская	0103000020E61000000100000005000000D7BD1589092C4840965D30B8E60A4940D7BD1589092C48408EAF3DB3240C4940F69A1E14942E48408EAF3DB3240C4940F69A1E14942E4840965D30B8E60A4940D7BD1589092C4840965D30B8E60A4940
31322	11776	48.729363999999997	48.747546	50.099936999999997	50.090026999999999	Первомайская	0103000020E610000001000000050000009B70AFCC5B5D4840E5603601860B49409B70AFCC5B5D4840865451BCCA0C4940B8205B96AF5F4840865451BCCA0C4940B8205B96AF5F4840E5603601860B49409B70AFCC5B5D4840E5603601860B4940
31602	53240	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	Центральная	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
30374	3437	48.567909999999998	48.593071999999999	50.137706000000001	50.121172999999999	Прудовая	0103000020E6100000010000000500000022895E46B14848404014CC98820F494022895E46B1484840433BA759A01149402F1686C8E94B4840433BA759A01149402F1686C8E94B48404014CC98820F494022895E46B14848404014CC98820F4940
31174	11727	48.530199000000003	48.551515999999999	50.280079000000001	50.271265	Школьная	0103000020E610000001000000050000009BAF928FDD43484054C6BFCFB82249409BAF928FDD434840F0A5F0A0D9234940419C871398464840F0A5F0A0D9234940419C87139846484054C6BFCFB82249409BAF928FDD43484054C6BFCFB8224940
31409	11478	48.340268000000002	48.364027999999998	50.369494000000003	50.354725999999999	Школьная	0103000020E610000001000000050000000BF0DDE68D2B48403C855CA9672D49400BF0DDE68D2B4840BC0853944B2F4940056A3178982E4840BC0853944B2F4940056A3178982E48403C855CA9672D49400BF0DDE68D2B48403C855CA9672D4940
30974	11664	48.540340999999998	48.563687999999999	50.396707999999997	50.379455	Коммунарная	0103000020E610000001000000050000000ED8D5E429454840DFA63FFB913049400ED8D5E429454840E107E753C7324940E692AAED26484840E107E753C7324940E692AAED26484840DFA63FFB913049400ED8D5E429454840DFA63FFB91304940
30210	11474	48.349583000000003	48.387771000000001	50.277287000000001	50.250349	Новостройка	0103000020E61000000100000005000000691EC022BF2C48400CCB9F6F0B204940691EC022BF2C4840904DF2237E2349402AABE97AA2314840904DF2237E2349402AABE97AA23148400CCB9F6F0B204940691EC022BF2C48400CCB9F6F0B204940
30408	3498	48.274214999999998	48.293007000000003	49.945073000000001	49.936295000000001	Полевая	0103000020E610000001000000050000004C89247A192348404434BA83D8F748404C89247A1923484093AAED26F8F84840E23FDD408125484093AAED26F8F84840E23FDD40812548404434BA83D8F748404C89247A192348404434BA83D8F74840
31535	53227	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	Новая	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
30220	12006	48.176406	48.201002000000003	50.021422000000001	50.000540999999998	Пионерская	0103000020E61000000100000005000000BA68C8789416484050A73CBA11004940BA68C878941648401CB5C2F4BD0249401E37FC6EBA1948401CB5C2F4BD0249401E37FC6EBA19484050A73CBA11004940BA68C8789416484050A73CBA11004940
30176	12000	48.440492999999996	48.461405999999997	49.993366000000002	49.986908999999997	Лиманная	0103000020E61000000100000005000000F78E1A13623848406490BB0853FE4840F78E1A1362384840AB7AF99D26FF4840CE16105A0F3B4840AB7AF99D26FF4840CE16105A0F3B48406490BB0853FE4840F78E1A13623848406490BB0853FE4840
31404	11185	48.653421000000002	48.668036000000001	50.405785000000002	50.400216	Центральная	0103000020E6100000010000000500000083C2A04CA353484000AB23473A33494083C2A04CA35348408B1A4CC3F03349407C462234825548408B1A4CC3F03349407C4622348255484000AB23473A33494083C2A04CA353484000AB23473A334940
30853	11859	48.690475999999997	48.705064999999998	50.185015	50.175404999999998	Комсомольская	0103000020E6100000010000000500000021567F84615848400647C9AB7316494021567F84615848407D224F92AE174940F146E6913F5A48407D224F92AE174940F146E6913F5A48400647C9AB7316494021567F84615848400647C9AB73164940
30253	10970	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	площадь 35-летия победы	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
31127	10970	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	площадь 35-летия Победы	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
31336	10970	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	Советская	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
31128	10970	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	Привокзальная	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
30976	10970	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	Почтовая,	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
31455	10970	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	Красного бойца	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
31140	10970	48.522328999999999	48.599890000000002	50.163975000000001	50.123004000000002	Коммунистическая	0103000020E610000001000000050000004E603AADDB4248407BA35698BE0F49404E603AADDB424840492EFF21FD14494046990D32C94C4840492EFF21FD14494046990D32C94C48407BA35698BE0F49404E603AADDB4248407BA35698BE0F4940
30211	53141	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	Пограничная	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
30804	53173	48.730325000000001	48.841034000000001	52.045817	51.981423999999997	Вокзальная	0103000020E61000000100000005000000C139234A7B5D484037C1374D9FFD4940C139234A7B5D4840E84CDA54DD054A407B698A00A76B4840E84CDA54DD054A407B698A00A76B484037C1374D9FFD4940C139234A7B5D484037C1374D9FFD4940
48441	50003	50.012248	50.027079000000001	53.420709000000002	53.404150999999999	Рабочая	0103000020E6100000010000000500000080B8AB5791014940A6D24F38BBB34A4080B8AB57910149400211E2CAD9B54A4046B41D53770349400211E2CAD9B54A4046B41D5377034940A6D24F38BBB34A4080B8AB5791014940A6D24F38BBB34A40
47947	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Ярославская	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
48100	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Чкалова	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
48035	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Херсонская	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
48129	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Силикатная	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47969	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Сергея Лазо	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47944	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Радищева	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
48328	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Озерная	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47961	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Мирная	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
48004	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Макаренко	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47920	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Ленина	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47951	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Куйбышева	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47835	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Крымская	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
48205	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Крестьянская	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47859	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Котовского	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47821	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Короленко	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47995	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Карла Маркса	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47997	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Запорожская	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
47836	4596	49.661582000000003	49.795278000000003	53.029187999999998	52.916409000000002	Жуковского	0103000020E61000000100000005000000A7CF0EB8AED448404A61DEE34C754A40A7CF0EB8AED44840C3B7B06EBC834A40399D64ABCBE54840C3B7B06EBC834A40399D64ABCBE548404A61DEE34C754A40A7CF0EB8AED448404A61DEE34C754A40
48052	463	49.302292000000001	49.311346999999998	53.533228000000001	53.527206999999997	бульвар Луначарского	0103000020E61000000100000005000000D5EB1681B1A64840739CDB847BC34A40D5EB1681B1A64840DFA7AAD040C44A40965AEF37DAA74840DFA7AAD040C44A40965AEF37DAA74840739CDB847BC34A40D5EB1681B1A64840739CDB847BC34A40
47935	463	49.419513000000002	49.421120999999999	53.506165000000003	53.501055999999998	бульвар Ленина	0103000020E61000000100000005000000999F1B9AB2B5484077BB5E9A22C04A40999F1B9AB2B548409FB0C403CAC04A405454FD4AE7B548409FB0C403CAC04A405454FD4AE7B5484077BB5E9A22C04A40999F1B9AB2B5484077BB5E9A22C04A40
48108	463	49.260933000000001	49.268219000000002	53.515642999999997	53.508222000000004	бульвар Королева	0103000020E610000001000000050000003DB9A64066A14840CA8D226B0DC14A403DB9A64066A14840A6B4FE9600C24A403A950C0055A24840A6B4FE9600C24A403A950C0055A24840CA8D226B0DC14A403DB9A64066A14840CA8D226B0DC14A40
47708	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	бульвар Будённого	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
7043	463	49.274290999999998	49.288449	53.553122000000002	53.499315000000003	Юбилейная	0103000020E61000000100000005000000274BADF71BA348407DB3CD8DE9BF4A40274BADF71BA348405C59A2B3CCC64A402EC896E5EBA448405C59A2B3CCC64A402EC896E5EBA448407DB3CD8DE9BF4A40274BADF71BA348407DB3CD8DE9BF4A40
7638	463	49.513072000000001	49.521822	53.471395000000001	53.471212999999999	Энергетиков	0103000020E61000000100000005000000253FE257ACC148409B3924B550BC4A40253FE257ACC14840BC3FDEAB56BC4A40AA2A3410CBC24840BC3FDEAB56BC4A40AA2A3410CBC248409B3924B550BC4A40253FE257ACC148409B3924B550BC4A40
16251	463	49.395249	49.399597	53.515284000000001	53.512929	Школьный	0103000020E610000001000000050000006B63EC8497B24840C21550A8A7C14A406B63EC8497B2484077137CD3F4C14A40344A97FE25B3484077137CD3F4C14A40344A97FE25B34840C21550A8A7C14A406B63EC8497B24840C21550A8A7C14A40
7961	463	49.421956000000002	49.424543	53.542014999999999	53.533479	Чкалова	0103000020E61000000100000005000000ED2C7AA702B64840280D350A49C44A40ED2C7AA702B6484081785DBF60C54A40745FCE6C57B6484081785DBF60C54A40745FCE6C57B64840280D350A49C44A40ED2C7AA702B64840280D350A49C44A40
15646	463	49.397593999999998	49.40372	53.526313000000002	53.523336	Чернышевского	0103000020E61000000100000005000000FC8A355CE4B24840E4688EACFCC24A40FC8A355CE4B24840D63A71395EC34A40DD5ED218ADB34840D63A71395EC34A40DD5ED218ADB34840E4688EACFCC24A40FC8A355CE4B24840E4688EACFCC24A40
47891	463	49.455570999999999	49.486545	53.483592000000002	53.481422000000002	Чайкиной	0103000020E61000000100000005000000C500892650BA484097C9703C9FBD4A40C500892650BA4840BA4DB857E6BD4A402384471B47BE4840BA4DB857E6BD4A402384471B47BE484097C9703C9FBD4A40C500892650BA484097C9703C9FBD4A40
7280	463	49.334415	49.338943	53.541195999999999	53.532649999999997	Цветной	0103000020E610000001000000050000005B25581CCEAA4840711B0DE02DC44A405B25581CCEAA4840EE5C18E945C54A40A41AF67B62AB4840EE5C18E945C54A40A41AF67B62AB4840711B0DE02DC44A405B25581CCEAA4840711B0DE02DC44A40
7132	463	49.257680999999998	49.305399999999999	53.516398000000002	53.513030000000001	Фрунзе	0103000020E6100000010000000500000079E6E5B0FBA04840F6EE8FF7AAC14A4079E6E5B0FBA0484023DC645419C24A406519E25817A7484023DC645419C24A406519E25817A74840F6EE8FF7AAC14A4079E6E5B0FBA04840F6EE8FF7AAC14A40
6657	463	49.524543999999999	49.530445999999998	53.487653000000002	53.482214999999997	Фадеева	0103000020E6100000010000000500000011A8FE4124C3484000529B38B9BD4A4011A8FE4124C34840ED65DB696BBE4A40A2258FA7E5C34840ED65DB696BBE4A40A2258FA7E5C3484000529B38B9BD4A4011A8FE4124C3484000529B38B9BD4A40
7490	463	49.463476	49.496749999999999	53.488205000000001	53.486507000000003	Ульяны Громовой	0103000020E610000001000000050000008E3D7B2E53BB4840362383DC45BE4A408E3D7B2E53BB4840315F5E807DBE4A40DD24068195BF4840315F5E807DBE4A40DD24068195BF4840362383DC45BE4A408E3D7B2E53BB4840362383DC45BE4A40
7110	463	49.300738000000003	49.302498	53.525343999999997	53.518442999999998	Туполева	0103000020E610000001000000050000000D5531957EA6484089EB18575CC24A400D5531957EA648402D93E1783EC34A407E8D2441B8A648402D93E1783EC34A407E8D2441B8A6484089EB18575CC24A400D5531957EA6484089EB18575CC24A40
7349	463	49.344512000000002	49.346803000000001	53.548349999999999	53.532350000000001	Тополиная	0103000020E610000001000000050000002F8A1EF818AC48404703780B24C44A402F8A1EF818AC48407C61325530C64A40CD936B0A64AC48407C61325530C64A40CD936B0A64AC48404703780B24C44A402F8A1EF818AC48404703780B24C44A40
7592	463	49.519953000000001	49.529853000000003	53.489736999999998	53.485821000000001	Телеграфная	0103000020E61000000100000005000000823AE5D18DC24840E25AED612FBE4A40823AE5D18DC248401152B7B3AFBE4A4000581D39D2C348401152B7B3AFBE4A4000581D39D2C34840E25AED612FBE4A40823AE5D18DC24840E25AED612FBE4A40
7329	463	49.330686999999998	49.343955999999999	53.548596000000003	53.546487999999997	Татищева	0103000020E610000001000000050000002E1B9DF353AA484006D49B51F3C54A402E1B9DF353AA4840B45BCB6438C64A40A9A10DC006AC4840B45BCB6438C64A40A9A10DC006AC484006D49B51F3C54A402E1B9DF353AA484006D49B51F3C54A40
7062	463	49.289706000000002	49.303783000000003	53.560037999999999	53.498389000000003	Степана Разина	0103000020E610000001000000050000003DBA111615A54840D4D7F335CBBF4A403DBA111615A5484035423F53AFC74A40570A815CE2A6484035423F53AFC74A40570A815CE2A64840D4D7F335CBBF4A403DBA111615A54840D4D7F335CBBF4A40
7906	463	49.395167999999998	49.405957000000001	53.511958999999997	53.506861999999998	Ставропольская	0103000020E610000001000000050000007E3672DD94B24840E6CAA0DAE0C04A407E3672DD94B2484049F25CDF87C14A40884A2366F6B3484049F25CDF87C14A40884A2366F6B34840E6CAA0DAE0C04A407E3672DD94B24840E6CAA0DAE0C04A40
15531	463	49.371659999999999	49.373303	53.477353999999998	53.474936999999997	Специалистов	0103000020E610000001000000050000009D9D0C8E92AF4840865451BCCABC4A409D9D0C8E92AF4840B14E95EF19BD4A40D53F8864C8AF4840B14E95EF19BD4A40D53F8864C8AF4840865451BCCABC4A409D9D0C8E92AF4840865451BCCABC4A40
1308	463	49.395276000000003	49.409056	53.515872999999999	53.499625999999999	Советская	0103000020E6100000010000000500000065726A6798B248409B1DA9BEF3BF4A4065726A6798B24840D8F15F2008C24A40C51D6FF25BB44840D8F15F2008C24A40C51D6FF25BB448409B1DA9BEF3BF4A4065726A6798B248409B1DA9BEF3BF4A40
47701	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	Сиреневая	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
7658	463	49.531578000000003	49.535746000000003	53.467267999999997	53.466388999999999	Севастопольская	0103000020E61000000100000005000000F5A276BF0AC44840691B7FA2B2BB4A40F5A276BF0AC44840D13B1570CFBB4A403E7B2E5393C44840D13B1570CFBB4A403E7B2E5393C44840691B7FA2B2BB4A40F5A276BF0AC44840691B7FA2B2BB4A40
6981	463	49.262514000000003	49.309766000000003	53.530042999999999	53.52619	Свердлова	0103000020E61000000100000005000000FF5E0A0F9AA14840BABDA4315AC34A40FF5E0A0F9AA14840A33CF372D8C34A40D5B48B69A6A74840A33CF372D8C34A40D5B48B69A6A74840BABDA4315AC34A40FF5E0A0F9AA14840BABDA4315AC34A40
19395	463	49.395150000000001	49.398510000000002	53.513790999999998	53.512270000000001	Репина	0103000020E61000000100000005000000D881734694B24840685C381092C14A40D881734694B2484054FD4AE7C3C14A4082902C6002B3484054FD4AE7C3C14A4082902C6002B34840685C381092C14A40D881734694B24840685C381092C14A40
6912	463	49.268523999999999	49.278711000000001	53.537075999999999	53.499684999999999	Революционная	0103000020E61000000100000005000000761893FE5EA24840A0A696ADF5BF4A40761893FE5EA24840B6BB07E8BEC44A408A0453CDACA34840B6BB07E8BEC44A408A0453CDACA34840A0A696ADF5BF4A40761893FE5EA24840A0A696ADF5BF4A40
48344	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	Полякова	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
1860	463	49.421956000000002	49.430678999999998	53.532677	53.508977000000002	Победы	0103000020E61000000100000005000000ED2C7AA702B6484046B5882826C14A40ED2C7AA702B648406B2A8BC22EC44A4078094E7D20B748406B2A8BC22EC44A4078094E7D20B7484046B5882826C14A40ED2C7AA702B6484046B5882826C14A40
4756	463	49.401933	49.412703999999998	53.526649999999997	53.518315000000001	Первомайская	0103000020E610000001000000050000007217618A72B348405C035B2558C24A407217618A72B348401D38674469C34A40D576137CD3B448401D38674469C34A40D576137CD3B448405C035B2558C24A407217618A72B348405C035B2558C24A40
7310	463	49.284630999999997	49.331783000000001	53.549697999999999	53.537215000000003	Офицерская	0103000020E61000000100000005000000C136E2C96EA44840D8F50B76C3C44A40C136E2C96EA448409B560A815CC64A40342F87DD77AA48409B560A815CC64A40342F87DD77AA4840D8F50B76C3C44A40C136E2C96EA44840D8F50B76C3C44A40
16045	463	49.465434999999999	49.466189	53.479813999999998	53.477494	Островского	0103000020E61000000100000005000000F6B4C35F93BB4840A304FD851EBD4A40F6B4C35F93BB4840DB148F8B6ABD4A40A260C614ACBB4840DB148F8B6ABD4A40A260C614ACBB4840A304FD851EBD4A40F6B4C35F93BB4840A304FD851EBD4A40
6983	463	49.284666999999999	49.291027	53.527211999999999	53.519728000000001	Орджоникидзе	0103000020E610000001000000050000000EA0DFF76FA448406268757286C24A400EA0DFF76FA448408507CDAE7BC34A4062A06B5F40A548408507CDAE7BC34A4062A06B5F40A548406268757286C24A400EA0DFF76FA448406268757286C24A40
277	463	49.526088999999999	49.540470999999997	53.465794000000002	53.461638999999998	Носова	0103000020E6100000010000000500000086E464E256C3484071C79BFC16BB4A4086E464E256C34840265646239FBB4A40DCB75A272EC54840265646239FBB4A40DCB75A272EC5484071C79BFC16BB4A4086E464E256C3484071C79BFC16BB4A40
7419	463	49.459460999999997	49.485655999999999	53.478282	53.475574999999999	Мурысева	0103000020E61000000100000005000000CB64389ECFBA4840C9E53FA4DFBC4A40CB64389ECFBA4840FB21365838BD4A40978DCEF929BE4840FB21365838BD4A40978DCEF929BE4840C9E53FA4DFBC4A40CB64389ECFBA4840C9E53FA4DFBC4A40
6877	463	49.255578999999997	49.268317000000003	53.551720000000003	53.508676999999999	Московский	0103000020E61000000100000005000000AE450BD0B6A048401B9DF3531CC14A40AE450BD0B6A048404A46CEC29EC64A40FDFA213658A248404A46CEC29EC64A40FDFA213658A248401B9DF3531CC14A40AE450BD0B6A048401B9DF3531CC14A40
7960	463	49.402301000000001	49.412677000000002	53.524113	53.520429999999998	Молодежный	0103000020E61000000100000005000000F51263997EB34840BBED42739DC24A40F51263997EB348404834812216C34A40DC679599D2B448404834812216C34A40DC679599D2B44840BBED42739DC24A40F51263997EB34840BBED42739DC24A40
1239	463	49.390478999999999	49.453110000000002	53.512478999999999	53.505254999999998	Мира	0103000020E610000001000000050000002C634337FBB14840FB912232ACC04A402C634337FBB14840827170E998C14A40CBBE2B82FFB94840827170E998C14A40CBBE2B82FFB94840FB912232ACC04A402C634337FBB14840FB912232ACC04A40
7472	463	49.473843000000002	49.474758999999999	53.486457999999999	53.473934999999997	Матросова	0103000020E6100000010000000500000022382EE3A6BC484002B7EEE6A9BC4A4022382EE3A6BC48405470784144BE4A40A73D25E7C4BC48405470784144BE4A40A73D25E7C4BC484002B7EEE6A9BC4A4022382EE3A6BC484002B7EEE6A9BC4A40
326	463	49.395204	49.432467000000003	53.522485000000003	53.514181000000001	Максима Горького	0103000020E61000000100000005000000CB9F6F0B96B24840BF9CD9AED0C14A40CB9F6F0B96B2484046D3D9C9E0C24A40B4CC22145BB7484046D3D9C9E0C24A40B4CC22145BB74840BF9CD9AED0C14A40CB9F6F0B96B24840BF9CD9AED0C14A40
47941	463	49.513691999999999	49.524526000000002	53.482365000000001	53.479979999999998	Майский проезд	0103000020E61000000100000005000000C11BD2A8C0C14840F65D11FC6FBD4A40C11BD2A8C0C1484016DEE522BEBD4A406BF3FFAA23C3484016DEE522BEBD4A406BF3FFAA23C34840F65D11FC6FBD4A40C11BD2A8C0C14840F65D11FC6FBD4A40
47979	463	49.385160999999997	49.425854999999999	53.542459000000001	53.537610999999998	Льва Толстого	0103000020E61000000100000005000000EA58A5F44CB14840247CEF6FD0C44A40EA58A5F44CB14840DF35E84B6FC54A4046EBA86A82B64840DF35E84B6FC54A4046EBA86A82B64840247CEF6FD0C44A40EA58A5F44CB14840247CEF6FD0C44A40
7074	463	49.302292000000001	49.311346999999998	53.533228000000001	53.527206999999997	Луначарского	0103000020E61000000100000005000000D5EB1681B1A64840739CDB847BC34A40D5EB1681B1A64840DFA7AAD040C44A40965AEF37DAA74840DFA7AAD040C44A40965AEF37DAA74840739CDB847BC34A40D5EB1681B1A64840739CDB847BC34A40
47795	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	Лизы Чайкиной	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
48460	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	Лесопарковое шоссе	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
16334	463	49.390478999999999	49.395671999999998	53.528196999999999	53.505254999999998	Лесная	0103000020E610000001000000050000002C634337FBB14840FB912232ACC04A402C634337FBB14840336C94F59BC34A40B1F84D61A5B24840336C94F59BC34A40B1F84D61A5B24840FB912232ACC04A402C634337FBB14840FB912232ACC04A40
6862	463	49.259801000000003	49.307825000000001	53.521023999999997	53.517505999999997	Ленинский	0103000020E61000000100000005000000EB3BBF2841A14840ECBDF8A23DC24A40EB3BBF2841A148402E3718EAB0C24A4013F241CF66A748402E3718EAB0C24A4013F241CF66A74840ECBDF8A23DC24A40EB3BBF2841A14840ECBDF8A23DC24A40
1053	463	49.390300000000003	49.431254000000003	53.50752	53.503563	Ленинградская	0103000020E610000001000000050000007DD0B359F5B14840E23C9CC074C04A407DD0B359F5B148407008556AF6C04A407522C15433B748407008556AF6C04A407522C15433B74840E23C9CC074C04A407DD0B359F5B14840E23C9CC074C04A40
1037	463	49.40849	49.418075000000002	53.543298999999998	53.511310999999999	Ленина	0103000020E610000001000000050000001C5F7B6649B44840E38A8BA372C14A401C5F7B6649B44840897956D28AC54A403A234A7B83B54840897956D28AC54A403A234A7B83B54840E38A8BA372C14A401C5F7B6649B44840E38A8BA372C14A40
8050	463	49.38738	49.468372000000002	53.535651999999999	53.511156	Ларина	0103000020E61000000100000005000000EF8FF7AA95B14840BC934F8F6DC14A40EF8FF7AA95B14840BC04A73E90C44A405A2E1B9DF3BB4840BC04A73E90C44A405A2E1B9DF3BB4840BC934F8F6DC14A40EF8FF7AA95B14840BC934F8F6DC14A40
6945	463	49.289006000000001	49.292454999999997	53.536219000000003	53.528041999999999	Курчатова	0103000020E61000000100000005000000842C0B26FEA448400C7558E196C34A40842C0B26FEA44840363FFED2A2C44A409D465A2A6FA54840363FFED2A2C44A409D465A2A6FA548400C7558E196C34A40842C0B26FEA448400C7558E196C34A40
6828	463	49.266691000000002	49.273778999999998	53.537509	53.529926000000003	Кулибина	0103000020E610000001000000050000009B9141EE22A248406AA67B9DD4C34A409B9141EE22A2484020274C18CDC44A4071AAB5300BA3484020274C18CDC44A4071AAB5300BA348406AA67B9DD4C34A409B9141EE22A248406AA67B9DD4C34A40
7606	463	49.512210000000003	49.518749999999997	53.479568	53.475034000000001	Куйбышева	0103000020E610000001000000050000009357E71890C14840793E03EACDBC4A409357E71890C14840A41AF67B62BD4A406666666666C24840A41AF67B62BD4A406666666666C24840793E03EACDBC4A409357E71890C14840793E03EACDBC4A40
7268	463	49.319871999999997	49.324345000000001	53.542411000000001	53.533822000000001	Космонавтов	0103000020E61000000100000005000000FB73D190F1A8484052F17F4754C44A40FB73D190F1A84840CEFE40B96DC54A4081CF0F2384A94840CEFE40B96DC54A4081CF0F2384A9484052F17F4754C44A40FB73D190F1A8484052F17F4754C44A40
6896	463	49.260933000000001	49.268219000000002	53.515642999999997	53.508222000000004	Королева	0103000020E610000001000000050000003DB9A64066A14840CA8D226B0DC14A403DB9A64066A14840A6B4FE9600C24A403A950C0055A24840A6B4FE9600C24A403A950C0055A24840CA8D226B0DC14A403DB9A64066A14840CA8D226B0DC14A40
8090	463	49.366494000000003	49.380400000000002	53.478448	53.473875999999997	Комсомольское	0103000020E6100000010000000500000012178046E9AE4840FD2D01F8A7BC4A4012178046E9AE4840166BB8C83DBD4A40FFB27BF2B0B04840166BB8C83DBD4A40FFB27BF2B0B04840FD2D01F8A7BC4A4012178046E9AE4840FD2D01F8A7BC4A40
1829	463	49.395124000000003	49.462335000000003	53.519219999999997	53.509967000000003	Комсомольская	0103000020E61000000100000005000000AFEE586C93B248400685419946C14A40AFEE586C93B24840EDB60BCD75C24A40E96514CB2DBB4840EDB60BCD75C24A40E96514CB2DBB48400685419946C14A40AFEE586C93B248400685419946C14A40
1435	463	49.454089000000003	49.513314999999999	53.483640000000001	53.473013000000002	Коммунистическая	0103000020E61000000100000005000000973C9E961FBA48409BCAA2B08BBC4A40973C9E961FBA4840CB845FEAE7BD4A40EBC5504EB4C14840CB845FEAE7BD4A40EBC5504EB4C148409BCAA2B08BBC4A40973C9E961FBA48409BCAA2B08BBC4A40
16279	463	49.386705999999997	49.441206999999999	53.538049999999998	53.53257	Кирова	0103000020E610000001000000050000005F950B957FB14840556AF6402BC44A405F950B957FB1484070CE88D2DEC44A4015E2917879B8484070CE88D2DEC44A4015E2917879B84840556AF6402BC44A405F950B957FB14840556AF6402BC44A40
960	463	49.395572999999999	49.416125999999998	53.524835000000003	53.505774000000002	Карла Маркса	0103000020E610000001000000050000001E17D522A2B248406495D233BDC04A401E17D522A2B24840E96514CB2DC34A40F581E49D43B54840E96514CB2DC34A40F581E49D43B548406495D233BDC04A401E17D522A2B248406495D233BDC04A40
47798	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	Ингельберга	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
7839	463	49.408374000000002	49.414141000000001	53.512286000000003	53.500171999999999	Жилина	0103000020E61000000100000005000000B344679945B44840FD2FD7A205C04A40B344679945B448406E19709692C14A406477819202B548406E19709692C14A406477819202B54840FD2FD7A205C04A40B344679945B44840FD2FD7A205C04A40
7444	463	49.454089000000003	49.455570999999999	53.483592000000002	53.476678999999997	Есенина	0103000020E61000000100000005000000973C9E961FBA484051D845D103BD4A40973C9E961FBA4840BA4DB857E6BD4A40C500892650BA4840BA4DB857E6BD4A40C500892650BA484051D845D103BD4A40973C9E961FBA484051D845D103BD4A40
6953	463	49.264203000000002	49.343649999999997	53.538333000000002	53.531868000000003	Дзержинского	0103000020E61000000100000005000000A7406667D1A14840FCE4284014C44A40A7406667D1A14840C5AD8218E8C44A409CA223B9FCAB4840C5AD8218E8C44A409CA223B9FCAB4840FCE4284014C44A40A7406667D1A14840FCE4284014C44A40
7897	463	49.429474999999996	49.432448999999998	53.514133000000001	53.504955000000002	Голосова	0103000020E610000001000000050000008CB96B09F9B64840D1798D5DA2C04A408CB96B09F9B64840AE65321CCFC14A400D18247D5AB74840AE65321CCFC14A400D18247D5AB74840D1798D5DA2C04A408CB96B09F9B64840D1798D5DA2C04A40
7640	463	49.518749999999997	49.537902000000003	53.475034000000001	53.469873	Гидротехническая	0103000020E610000001000000050000006666666666C24840FF2268CC24BC4A406666666666C24840793E03EACDBC4A40FC3905F9D9C44840793E03EACDBC4A40FC3905F9D9C44840FF2268CC24BC4A406666666666C24840FF2268CC24BC4A40
7111	463	49.309164000000003	49.317132000000001	53.558774999999997	53.517924000000001	Ворошилова	0103000020E61000000100000005000000DF8C9AAF92A7484021E868554BC24A40DF8C9AAF92A7484044696FF085C74A40EE4108C897A8484044696FF085C74A40EE4108C897A8484021E868554BC24A40DF8C9AAF92A7484021E868554BC24A40
7418	463	49.218676000000002	49.344557000000002	53.573033000000002	53.56138	Вокзальная	0103000020E61000000100000005000000C6353E93FD9B48407250C24CDBC74A40C6353E93FD9B4840AF43352559C94A40CF4D9B711AAC4840AF43352559C94A40CF4D9B711AAC48407250C24CDBC74A40C6353E93FD9B48407250C24CDBC74A40
7770	463	49.395896	49.396659999999997	53.503563	53.498683	Белорусская	0103000020E61000000100000005000000014F5AB8ACB248401C0934D8D4BF4A40014F5AB8ACB24840E23C9CC074C04A40D0D03FC1C5B24840E23C9CC074C04A40D0D03FC1C5B248401C0934D8D4BF4A40014F5AB8ACB248401C0934D8D4BF4A40
6864	463	49.265532999999998	49.270096000000002	53.529128	53.520820000000001	Баумана	0103000020E610000001000000050000001F813FFCFCA14840268DD13AAAC24A401F813FFCFCA14840EEB25F77BAC34A40E563778192A24840EEB25F77BAC34A40E563778192A24840268DD13AAAC24A401F813FFCFCA14840268DD13AAAC24A40
7794	463	49.389598999999997	49.462282000000002	53.510744000000003	53.498570999999998	Баныкина	0103000020E61000000100000005000000F3C64961DEB14840F4DDAD2CD1BF4A40F3C64961DEB148406A50340F60C14A40C6C37B0E2CBB48406A50340F60C14A40C6C37B0E2CBB4840F4DDAD2CD1BF4A40F3C64961DEB14840F4DDAD2CD1BF4A40
7198	463	49.327129999999997	49.331783000000001	53.549697999999999	53.525317000000001	Автостроителей	0103000020E610000001000000050000002EC55565DFA94840348463963DC34A402EC55565DFA948409B560A815CC64A40342F87DD77AA48409B560A815CC64A40342F87DD77AA4840348463963DC34A402EC55565DFA94840348463963DC34A40
3490	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	70 Лет Октября	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
47800	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	60 лет СССР	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
979	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	50 Лет Октября	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
7211	463	49.208229000000003	49.566271	53.591442999999998	53.459023000000002	40 Лет Победы	0103000020E61000000100000005000000168A743FA79A4840508E0244C1BA4A40168A743FA79A48405C397B67B4CB4A402CD670917BC848405C397B67B4CB4A402CD670917BC84840508E0244C1BA4A40168A743FA79A4840508E0244C1BA4A40
47999	55877	50.315510000000003	50.320272000000003	53.331418999999997	53.330660000000002	Школьная	0103000020E61000000100000005000000CEC7B5A162284940350C1F1153AA4A40CEC7B5A162284940F22213F06BAA4A408AE942ACFE284940F22213F06BAA4A408AE942ACFE284940350C1F1153AA4A40CEC7B5A162284940350C1F1153AA4A40
47691	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	проспект 50 лет октября	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47806	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	пр.Гагарина	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47804	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	пр.50 лет Октября	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47802	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	пр. Гагарина	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47938	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	переулок Молодогвардейский	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48252	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	пер. Кемеровский	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47766	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Щусева	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48313	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Школьная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48023	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Челюскинцев	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48022	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Циолковского	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48324	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Фрунзе	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47928	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Ульяновская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47870	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Степана Разина	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47746	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Советская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48115	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Победы	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48311	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Парижской Коммуны	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47878	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Образцовская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47868	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Новостроящаяся	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48475	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Новосибирская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47911	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Новомайская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
8236	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Нефтебазная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47876	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Маршала Жукова	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47871	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Людиновская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48314	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Ленина	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47685	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Краснознаменная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47801	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Красина	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47955	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Кемеровский переулок	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47912	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Карла Маркса	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47934	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Карбышева	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47908	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Интернациональная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47729	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Звездная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47769	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Заборовская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48350	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Ерамасова	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47917	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Декабристов	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47914	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Дальневосточная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47932	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Гончарная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48116	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Гоголя	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47867	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Гидротурбинная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48162	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Бородинский проезд	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48128	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Байкальская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47684	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	Астраханская	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
47732	5112	48.347265999999998	48.586846000000001	53.213681999999999	53.055478000000001	2-я Железнодорожная	0103000020E61000000100000005000000A1815836732C4840E1D231E719874A40A1815836732C484037DF88EE599B4A40EBE40CC51D4B484037DF88EE599B4A40EBE40CC51D4B4840E1D231E719874A40A1815836732C4840E1D231E719874A40
48452	55917	50.196475	50.201613000000002	53.304076000000002	53.303522000000001	третья линия	0103000020E61000000100000005000000A5BDC11726194940EACE13CFD9A64A40A5BDC11726194940CFBF5DF6EBA64A4067B96C74CE194940CFBF5DF6EBA64A4067B96C74CE194940EACE13CFD9A64A40A5BDC11726194940EACE13CFD9A64A40
49	32	50.159813999999997	50.238857000000003	53.203619000000003	53.199675999999997	улица Юрия Гагарина	0103000020E61000000100000005000000B2B8FFC874144940E6E5B0FB8E994A40B2B8FFC87414494010ECF82F109A4A40D9B5BDDD921E494010ECF82F109A4A40D9B5BDDD921E4940E6E5B0FB8E994A40B2B8FFC874144940E6E5B0FB8E994A40
1467	32	50.128373000000003	50.131445999999997	53.210580999999998	53.209108999999998	улица Циолковского	0103000020E610000001000000050000003F58C6866E1049404E266E15C49A4A403F58C6866E10494059147651F49A4A405298F738D310494059147651F49A4A405298F738D31049404E266E15C49A4A403F58C6866E1049404E266E15C49A4A40
15792	32	50.135137999999998	50.158259999999999	53.147449999999999	53.135835999999998	улица Центральная	0103000020E610000001000000050000003239B5334C1149404ACFF41263914A403239B5334C114940C9E53FA4DF924A40EA211ADD41144940C9E53FA4DF924A40EA211ADD411449404ACFF41263914A403239B5334C1149404ACFF41263914A40
723	32	50.237034000000001	50.288327000000002	53.226880999999999	53.205382	улица Физкультурная	0103000020E6100000010000000500000021054F21571E4940F29716F5499A4A4021054F21571E4940B98AC56F0A9D4A40E3C62DE6E7244940B98AC56F0A9D4A40E3C62DE6E7244940F29716F5499A4A4021054F21571E4940F29716F5499A4A40
1759	32	50.124538000000001	50.145828000000002	53.191746000000002	53.188254999999998	улица Урицкого	0103000020E61000000100000005000000FC8D76DCF00F49407C2766BD18984A40FC8D76DCF00F4940C59107228B984A40A96BED7DAA124940C59107228B984A40A96BED7DAA1249407C2766BD18984A40FC8D76DCF00F49407C2766BD18984A40
6472	32	50.264719999999997	50.273299000000002	53.219279	53.214992000000002	улица Теннисная	0103000020E610000001000000050000006E4C4F58E221494069739CDB849B4A406E4C4F58E22149408CD99255119C4A40C7832D76FB2249408CD99255119C4A40C7832D76FB22494069739CDB849B4A406E4C4F58E221494069739CDB849B4A40
28764	32	50.216425999999998	50.244858000000001	53.225959000000003	53.204244000000003	улица Среднесадовая	0103000020E610000001000000050000008600E0D8B31B4940BE33DAAA249A4A408600E0D8B31B4940529E7939EC9C4A40FD14C781571F4940529E7939EC9C4A40FD14C781571F4940BE33DAAA249A4A408600E0D8B31B4940BE33DAAA249A4A40
184	32	50.173046999999997	50.222113	53.253346000000001	53.190908999999998	улица Советской Армии	0103000020E61000000100000005000000E0D57267261649408BC1C3B46F984A40E0D5726726164940454948A46DA04A401B82E3326E1C4940454948A46DA04A401B82E3326E1C49408BC1C3B46F984A40E0D57267261649408BC1C3B46F984A40
47926	32	50.118267000000003	50.130583000000001	53.209487000000003	53.199491999999999	улица Полевая	0103000020E610000001000000050000001899805F230F494025E82FF488994A401899805F230F4940F5F75278D09A4A40F03499F1B6104940F5F75278D09A4A40F03499F1B610494025E82FF488994A401899805F230F494025E82FF488994A40
16299	32	50.072040000000001	50.079630999999999	53.163221999999998	53.162908999999999	улица Пирогова	0103000020E610000001000000050000007E00529B38094940AE9CBD33DA944A407E00529B380949406DFE5F75E4944A40B75F3E59310A49406DFE5F75E4944A40B75F3E59310A4940AE9CBD33DA944A407E00529B38094940AE9CBD33DA944A40
6716	32	50.123486999999997	50.215257999999999	53.260925999999998	53.205176999999999	улица Ново-Садовая	0103000020E61000000100000005000000963D096CCE0F494019726C3D439A4A40963D096CCE0F49408A56EE0566A14A40E719FB928D1B49408A56EE0566A14A40E719FB928D1B494019726C3D439A4A40963D096CCE0F494019726C3D439A4A40
7309	32	50.134104999999998	50.144264999999997	53.180598000000003	53.178423000000002	улица Мостовая	0103000020E61000000100000005000000739D465A2A11494057ED9A90D6964A40739D465A2A1149408CDCD3D51D974A408D7A8846771249408CDCD3D51D974A408D7A88467712494057ED9A90D6964A40739D465A2A11494057ED9A90D6964A40
799	32	50.158898000000001	50.214224999999999	53.197539999999996	53.195985999999998	улица Мориса Тореза	0103000020E610000001000000050000002DB308C556144940A73CBA1116994A402DB308C5561449406FD39FFD48994A40287E8CB96B1B49406FD39FFD48994A40287E8CB96B1B4940A73CBA1116994A402DB308C556144940A73CBA1116994A40
47964	32	50.073836999999997	50.096798	53.199519000000002	53.177748000000001	улица Максима Горького	0103000020E610000001000000050000000C1EA67D73094940F7764B72C0964A400C1EA67D730949401FF7ADD689994A40BB287AE0630C49401FF7ADD689994A40BB287AE0630C4940F7764B72C0964A400C1EA67D73094940F7764B72C0964A40
434	32	50.087921999999999	50.118060999999997	53.193703999999997	53.186748999999999	улица Льва Толстого	0103000020E61000000100000005000000A94C3107410B4940C5C72764E7974A40A94C3107410B49405C8DEC4ACB984A406EF7729F1C0F49405C8DEC4ACB984A406EF7729F1C0F4940C5C72764E7974A40A94C3107410B4940C5C72764E7974A40
5653	32	50.289907999999997	50.347571000000002	53.245313000000003	53.224007	улица Литвинова	0103000020E61000000100000005000000A46C91B41B2549409C89E942AC9C4A40A46C91B41B2549404F24986A669F4A40DE04DF347D2C49404F24986A669F4A40DE04DF347D2C49409C89E942AC9C4A40A46C91B41B2549409C89E942AC9C4A40
413	32	50.083106999999998	50.096798	53.199196000000001	53.178741000000002	улица Куйбышева	0103000020E61000000100000005000000CA880B40A30A494028BA2EFCE0964A40CA880B40A30A49403CBF28417F994A40BB287AE0630C49403CBF28417F994A40BB287AE0630C494028BA2EFCE0964A40CA880B40A30A494028BA2EFCE0964A40
5818	32	50.228931000000003	50.266274000000003	53.234324999999998	53.216825999999998	проспект Юных Пионеров	0103000020E6100000010000000500000032056B9C4D1D4940147651F4C09B4A4032056B9C4D1D49404ED1915CFE9D4A4037E33444152249404ED1915CFE9D4A4037E3344415224940147651F4C09B4A4032056B9C4D1D4940147651F4C09B4A40
5760	32	50.258808999999999	50.280970000000003	53.240824000000003	53.225306000000003	проспект Металлургов	0103000020E610000001000000050000008A743FA720214940DACBB6D3D69C4A408A743FA720214940C40B2252D39E4A401D9430D3F6234940C40B2252D39E4A401D9430D3F6234940DACBB6D3D69C4A408A743FA720214940DACBB6D3D69C4A40
8147	32	50.148629999999997	50.163910999999999	53.216636999999999	53.204573000000003	проспект Масленникова	0103000020E610000001000000050000002C9ACE4E061349408352B4722F9A4A402C9ACE4E06134940410DDFC2BA9B4A40323A2009FB144940410DDFC2BA9B4A40323A2009FB1449408352B4722F9A4A402C9ACE4E061349408352B4722F9A4A40
8092	32	50.125354999999999	50.144345000000001	53.214378000000004	53.202944000000002	проспект Ленина	0103000020E61000000100000005000000EEB1F4A10B104940B075A911FA994A40EEB1F4A10B104940AF7D01BD709B4A40AA2B9FE579124940AF7D01BD709B4A40AA2B9FE579124940B075A911FA994A40EEB1F4A10B104940B075A911FA994A40
5819	32	50.215257999999999	50.294238	53.260855999999997	53.192377	проспект Кирова	0103000020E61000000100000005000000E719FB928D1B494055C03DCF9F984A40E719FB928D1B4940917BBABA63A14A40C79E3D97A9254940917BBABA63A14A40C79E3D97A925494055C03DCF9F984A40E719FB928D1B494055C03DCF9F984A40
247	32	50.134813999999999	50.290843000000002	53.260348999999998	53.189647000000001	проспект Карла Маркса	0103000020E610000001000000050000007F85CC95411149406B64575A46984A407F85CC9541114940ED45B41D53A14A40A1A2EA573A254940ED45B41D53A14A40A1A2EA573A2549406B64575A46984A407F85CC95411149406B64575A46984A40
48257	32	50.007325000000002	50.390833999999998	53.396335000000001	53.091963999999997	поселок Южный	0103000020E61000000100000005000000BBB88D06F00049406534F279C58B4A40BBB88D06F00049404DA1F31ABBB24A401A1538D9063249404DA1F31ABBB24A401A1538D9063249406534F279C58B4A40BBB88D06F00049406534F279C58B4A40
6507	32	50.248694	50.253751000000001	53.217089999999999	53.213039999999999	переулок Штамповщиков	0103000020E61000000100000005000000105B7A34D51F4940B35E0CE5449B4A40105B7A34D51F4940F224E99AC99B4A40E529ABE97A204940F224E99AC99B4A40E529ABE97A204940B35E0CE5449B4A40105B7A34D51F4940B35E0CE5449B4A40
47782	32	50.083449000000002	50.096330000000002	53.123015000000002	53.120367000000002	переулок Новомолодежный	0103000020E6100000010000000500000024F1F274AE0A49404242942F688F4A4024F1F274AE0A49406FF59CF4BE8F4A40D5CF9B8A540C49406FF59CF4BE8F4A40D5CF9B8A540C49404242942F688F4A4024F1F274AE0A49404242942F688F4A40
552	32	50.189396000000002	50.193564000000002	53.209313999999999	53.209221999999997	переулок Лучистый	0103000020E6100000010000000500000022FFCC203E18494046CD57C9C79A4A4022FFCC203E184940274C18CDCA9A4A406BD784B4C6184940274C18CDCA9A4A406BD784B4C618494046CD57C9C79A4A4022FFCC203E18494046CD57C9C79A4A40
7656	32	50.080798999999999	50.111421999999997	53.120907000000003	53.118237999999998	переулок Долотный	0103000020E610000001000000050000005646239F570A49407D923B6C228F4A405646239F570A4940C26D6DE1798F4A4007077B13430E4940C26D6DE1798F4A4007077B13430E49407D923B6C228F4A405646239F570A49407D923B6C228F4A40
48110	32	50.167242999999999	50.169443999999999	53.392442000000003	53.388016999999998	квартал 4 	0103000020E6100000010000000500000012BEF7376815494061A5828AAAB14A4012BEF73768154940D6C9198A3BB24A4070404B57B0154940D6C9198A3BB24A4070404B57B015494061A5828AAAB14A4012BEF7376815494061A5828AAAB14A40
47980	32	50.277386	50.281787999999999	53.303747999999999	53.302245999999997	квартал 3 	0103000020E61000000100000005000000232F6B628123494064AC36FFAFA64A40232F6B6281234940DA1CE736E1A64A40DF3312A111244940DA1CE736E1A64A40DF3312A11124494064AC36FFAFA64A40232F6B628123494064AC36FFAFA64A40
48000	32	50.268141999999997	50.275787000000001	53.303849999999997	53.301406999999998	квартал 13	0103000020E610000001000000050000008E57207A522249408AE42B8194A64A408E57207A52224940DE718A8EE4A64A40BBD408FD4C234940DE718A8EE4A64A40BBD408FD4C2349408AE42B8194A64A408E57207A522249408AE42B8194A64A40
48071	32	50.287483000000002	50.288902	53.300604999999997	53.296004000000003	квартал 10	0103000020E61000000100000005000000F793313ECC2449401BBE8575E3A54A40F793313ECC244940CD0182397AA64A40DFDFA0BDFA244940CD0182397AA64A40DFDFA0BDFA2449401BBE8575E3A54A40F793313ECC2449401BBE8575E3A54A40
47915	32	50.159813999999997	50.238857000000003	53.203619000000003	53.199675999999997	Юрия Гагарина	0103000020E61000000100000005000000B2B8FFC874144940E6E5B0FB8E994A40B2B8FFC87414494010ECF82F109A4A40D9B5BDDD921E494010ECF82F109A4A40D9B5BDDD921E4940E6E5B0FB8E994A40B2B8FFC874144940E6E5B0FB8E994A40
48045	32	50.159813999999997	50.238857000000003	53.203619000000003	53.199675999999997	Юрия Гагарина	0103000020E61000000100000005000000B2B8FFC874144940E6E5B0FB8E994A40B2B8FFC87414494010ECF82F109A4A40D9B5BDDD921E494010ECF82F109A4A40D9B5BDDD921E4940E6E5B0FB8E994A40B2B8FFC874144940E6E5B0FB8E994A40
7700	32	50.055664	50.057712000000002	53.124701000000002	53.118994000000001	Эльтонская улица	0103000020E6100000010000000500000043C879FF1F074940CA3505323B8F4A4043C879FF1F074940A663CE33F68F4A401B4B581B63074940A663CE33F68F4A401B4B581B63074940CA3505323B8F4A4043C879FF1F074940CA3505323B8F4A40
48092	32	50.240707999999998	50.241579000000002	53.184758000000002	53.181989999999999	Экспериментальная	0103000020E610000001000000050000005AF10D85CF1E49407A19C5724B974A405AF10D85CF1E494052D66F26A6974A404033880FEC1E494052D66F26A6974A404033880FEC1E49407A19C5724B974A405AF10D85CF1E49407A19C5724B974A40
48030	32	50.316606	50.320334000000003	53.264944	53.235957999999997	Щорса	0103000020E61000000100000005000000D3DB9F8B86284940629D2ADF339E4A40D3DB9F8B86284940BEA25BAFE9A14A4000E65AB400294940BEA25BAFE9A14A4000E65AB400294940629D2ADF339E4A40D3DB9F8B86284940629D2ADF339E4A40
7373	32	50.125121	50.150607000000001	53.201886999999999	53.19256	Чернореченская улица	0103000020E610000001000000050000007B8505F70310494046425BCEA5984A407B8505F703104940683EE76ED7994A403BC6151747134940683EE76ED7994A403BC615174713494046425BCEA5984A407B8505F70310494046425BCEA5984A40
47986	32	50.125121	50.150607000000001	53.201886999999999	53.19256	Чернореченская	0103000020E610000001000000050000007B8505F70310494046425BCEA5984A407B8505F703104940683EE76ED7994A403BC6151747134940683EE76ED7994A403BC615174713494046425BCEA5984A407B8505F70310494046425BCEA5984A40
6011	32	50.216363000000001	50.269750000000002	53.246008000000003	53.221122999999999	Черемшанская улица	0103000020E61000000100000005000000408864C8B11B49405BB22AC24D9C4A40408864C8B11B4940F646AD307D9F4A404A0C022B87224940F646AD307D9F4A404A0C022B872249405BB22AC24D9C4A40408864C8B11B49405BB22AC24D9C4A40
47993	32	50.216363000000001	50.269750000000002	53.246008000000003	53.221122999999999	Черемшанская	0103000020E61000000100000005000000408864C8B11B49405BB22AC24D9C4A40408864C8B11B4940F646AD307D9F4A404A0C022B87224940F646AD307D9F4A404A0C022B872249405BB22AC24D9C4A40408864C8B11B49405BB22AC24D9C4A40
47952	32	50.087454999999999	50.106121999999999	53.201827999999999	53.178832999999997	Чапаевская	0103000020E61000000100000005000000936FB6B9310B49400839EFFFE3964A40936FB6B9310B494063B5F97FD5994A406CB1DB67950D494063B5F97FD5994A406CB1DB67950D49400839EFFFE3964A40936FB6B9310B49400839EFFFE3964A40
48020	32	50.128373000000003	50.131445999999997	53.210580999999998	53.209108999999998	Циолковского	0103000020E610000001000000050000003F58C6866E1049404E266E15C49A4A403F58C6866E10494059147651F49A4A405298F738D310494059147651F49A4A405298F738D31049404E266E15C49A4A403F58C6866E1049404E266E15C49A4A40
48691	32	50.135137999999998	50.158259999999999	53.147449999999999	53.135835999999998	Центральная	0103000020E610000001000000050000003239B5334C1149404ACFF41263914A403239B5334C114940C9E53FA4DF924A40EA211ADD41144940C9E53FA4DF924A40EA211ADD411449404ACFF41263914A403239B5334C1149404ACFF41263914A40
47677	32	50.188543000000003	50.267207999999997	53.239207	53.179026999999998	ХХII Партсъезда	0103000020E61000000100000005000000E371512D22184940ED0C535BEA964A40E371512D22184940B5FCC0559E9E4A40629D2ADF33224940B5FCC0559E9E4A40629D2ADF33224940ED0C535BEA964A40E371512D22184940ED0C535BEA964A40
48104	32	50.085577999999998	50.098765	53.198715999999997	53.178713999999999	Фрунзе	0103000020E61000000100000005000000E8A04B38F40A49402EABB019E0964A40E8A04B38F40A49409198A0866F994A40A67EDE54A40C49409198A0866F994A40A67EDE54A40C49402EABB019E0964A40E8A04B38F40A49402EABB019E0964A40
48067	32	50.037796	50.046726	53.145623999999998	53.145159999999997	Флотская	0103000020E61000000100000005000000B6F5D37FD6044940FB57569A94924A40B6F5D37FD6044940A0C1A6CEA3924A40BBEF181EFB054940A0C1A6CEA3924A40BBEF181EFB054940FB57569A94924A40B6F5D37FD6044940FB57569A94924A40
47998	32	50.237034000000001	50.288327000000002	53.226880999999999	53.205382	Физкультурная	0103000020E6100000010000000500000021054F21571E4940F29716F5499A4A4021054F21571E4940B98AC56F0A9D4A40E3C62DE6E7244940B98AC56F0A9D4A40E3C62DE6E7244940F29716F5499A4A4021054F21571E4940F29716F5499A4A40
48036	32	50.067323999999999	50.084193999999997	53.118070000000003	53.111151999999997	Фасадная	0103000020E61000000100000005000000321EA5129E08494047718E3A3A8E4A40321EA5129E084940C251F2EA1C8F4A407C4276DEC60A4940C251F2EA1C8F4A407C4276DEC60A494047718E3A3A8E4A40321EA5129E08494047718E3A3A8E4A40
47763	32	50.124538000000001	50.145828000000002	53.191746000000002	53.188254999999998	Урицкого	0103000020E61000000100000005000000FC8D76DCF00F49407C2766BD18984A40FC8D76DCF00F4940C59107228B984A40A96BED7DAA124940C59107228B984A40A96BED7DAA1249407C2766BD18984A40FC8D76DCF00F49407C2766BD18984A40
48060	32	50.139449999999997	50.163128999999998	53.199730000000002	53.186442	Тухачевского	0103000020E61000000100000005000000AEB6627FD9114940E84CDA54DD974A40AEB6627FD9114940DA03ADC090994A40BC033C69E1144940DA03ADC090994A40BC033C69E1144940E84CDA54DD974A40AEB6627FD9114940E84CDA54DD974A40
48056	32	50.336773999999998	50.339388	53.259605999999998	53.238103000000002	Транзитная	0103000020E61000000100000005000000511212691B2B49402D0ABB287A9E4A40511212691B2B494035ECF7C43AA14A40D253E410712B494035ECF7C43AA14A40D253E410712B49402D0ABB287A9E4A40511212691B2B49402D0ABB287A9E4A40
48081	32	50.224224	50.230674	53.265698	53.262186	Тополей	0103000020E61000000100000005000000397D3D5FB31C49400ABC934F8FA14A40397D3D5FB31C49406A4E5E6402A24A40CD04C3B9861D49406A4E5E6402A24A40CD04C3B9861D49400ABC934F8FA14A40397D3D5FB31C49400ABC934F8FA14A40
48048	32	50.223056	50.257550999999999	53.268439000000001	53.240279999999998	Ташкентская	0103000020E610000001000000050000009A9658198D1C494002F1BA7EC19E4A409A9658198D1C494048FC8A355CA24A40AB06616EF720494048FC8A355CA24A40AB06616EF720494002F1BA7EC19E4A409A9658198D1C494002F1BA7EC19E4A40
48065	32	50.223056	50.257550999999999	53.268439000000001	53.240279999999998	Ташкентская	0103000020E610000001000000050000009A9658198D1C494002F1BA7EC19E4A409A9658198D1C494048FC8A355CA24A40AB06616EF720494048FC8A355CA24A40AB06616EF720494002F1BA7EC19E4A409A9658198D1C494002F1BA7EC19E4A40
47923	32	50.102860999999997	50.108530000000002	53.202399999999997	53.199972000000002	Студенческий переулок	0103000020E6100000010000000500000055849B8C2A0D4940D00EB8AE98994A4055849B8C2A0D4940EE5A423EE8994A404451A04FE40D4940EE5A423EE8994A404451A04FE40D4940D00EB8AE98994A4055849B8C2A0D4940D00EB8AE98994A40
48095	32	50.166615	50.174079999999996	53.179901000000001	53.171520000000001	Структурная	0103000020E61000000100000005000000F302ECA353154940124E0B5EF4954A40F302ECA35315494044C2F7FE06974A409F71E1404816494044C2F7FE06974A409F71E14048164940124E0B5EF4954A40F302ECA353154940124E0B5EF4954A40
48085	32	50.078660999999997	50.089917	53.193174999999997	53.176895000000002	Степана Разина	0103000020E610000001000000050000003E3C4B90110A4940B8E9CF7EA4964A403E3C4B90110A4940D0B359F5B9984A405E2D7766820B4940D0B359F5B9984A405E2D7766820B4940B8E9CF7EA4964A403E3C4B90110A4940B8E9CF7EA4964A40
47991	32	50.194957000000002	50.265393000000003	53.256265999999997	53.223398000000003	Стара Загора	0103000020E610000001000000050000002A90D959F4184940F4FE3F4E989C4A402A90D959F4184940D2890453CDA04A402ECBD765F8214940D2890453CDA04A402ECBD765F8214940F4FE3F4E989C4A402A90D959F4184940F4FE3F4E989C4A40
48107	32	50.213399000000003	50.274017000000001	53.240904999999998	53.212938000000001	Ставропольская	0103000020E61000000100000005000000E3FF8EA8501B4940AF09698D419B4A40E3FF8EA8501B4940B0389CF9D59E4A4026C632FD12234940B0389CF9D59E4A4026C632FD12234940AF09698D419B4A40E3FF8EA8501B4940AF09698D419B4A40
48063	32	50.121437999999998	50.126694000000001	53.195587000000003	53.187176000000001	Спортивная	0103000020E61000000100000005000000EE3EC7478B0F49404D4C1762F5974A40EE3EC7478B0F4940EA42ACFE08994A40BA4C4D8237104940EA42ACFE08994A40BA4C4D82371049404D4C1762F5974A40EE3EC7478B0F49404D4C1762F5974A40
47981	32	50.188192000000001	50.215986000000001	53.269871999999999	53.239207	Солнечная	0103000020E6100000010000000500000036AFEAAC16184940B5FCC0559E9E4A4036AFEAAC16184940950D6B2A8BA24A406A32E36DA51B4940950D6B2A8BA24A406A32E36DA51B4940B5FCC0559E9E4A4036AFEAAC16184940B5FCC0559E9E4A40
47977	32	50.188192000000001	50.215986000000001	53.269871999999999	53.239207	Солнечная	0103000020E6100000010000000500000036AFEAAC16184940B5FCC0559E9E4A4036AFEAAC16184940950D6B2A8BA24A406A32E36DA51B4940950D6B2A8BA24A406A32E36DA51B4940B5FCC0559E9E4A4036AFEAAC16184940B5FCC0559E9E4A40
48089	32	50.208764000000002	50.219560999999999	53.348145000000002	53.347639000000001	Солдатская	0103000020E61000000100000005000000844A5CC7B81A494036E84B6F7FAC4A40844A5CC7B81A49400AA2EE0390AC4A40103D29931A1C49400AA2EE0390AC4A40103D29931A1C494036E84B6F7FAC4A40844A5CC7B81A494036E84B6F7FAC4A40
48042	32	50.173046999999997	50.222113	53.253346000000001	53.190908999999998	Советской Армии	0103000020E61000000100000005000000E0D57267261649408BC1C3B46F984A40E0D5726726164940454948A46DA04A401B82E3326E1C4940454948A46DA04A401B82E3326E1C49408BC1C3B46F984A40E0D57267261649408BC1C3B46F984A40
48111	32	50.227969999999999	50.233764000000001	53.263860999999999	53.260962999999997	Силина	0103000020E610000001000000050000000C3CF71E2E1D4940A73B4F3C67A14A400C3CF71E2E1D49404DD87E32C6A14A40B77D8FFAEB1D49404DD87E32C6A14A40B77D8FFAEB1D4940A73B4F3C67A14A400C3CF71E2E1D4940A73B4F3C67A14A40
47950	32	50.12876	50.136125999999997	53.142681000000003	53.137652000000003	Силаева	0103000020E6100000010000000500000038842A357B104940501DAB949E914A4038842A357B1049405B61FA5E43924A405111A7936C1149405B61FA5E43924A405111A7936C114940501DAB949E914A4038842A357B104940501DAB949E914A40
48021	32	50.204118999999999	50.238883999999999	53.347414000000001	53.346257999999999	Сергея Лазо	0103000020E6100000010000000500000001BF4692201A49403BFDA02E52AC4A4001BF4692201A49401616DC0F78AC4A40D2C43BC0931E49401616DC0F78AC4A40D2C43BC0931E49403BFDA02E52AC4A4001BF4692201A49403BFDA02E52AC4A40
48027	32	50.226056	50.284357	53.238791999999997	53.206918999999999	Свободы	0103000020E6100000010000000500000044882B67EF1C4940E4F560527C9A4A4044882B67EF1C4940F1457BBC909E4A40C0B167CF65244940F1457BBC909E4A40C0B167CF65244940E4F560527C9A4A4044882B67EF1C4940E4F560527C9A4A40
47975	32	50.096815999999997	50.123486999999997	53.205176999999999	53.180532999999997	Самарская	0103000020E6100000010000000500000061DD7877640C4940A46C91B41B974A4061DD7877640C494019726C3D439A4A40963D096CCE0F494019726C3D439A4A40963D096CCE0F4940A46C91B41B974A4061DD7877640C4940A46C91B41B974A40
47985	32	50.099348999999997	50.124662999999998	53.204211999999998	53.180289999999999	Садовая	0103000020E61000000100000005000000F5F1D077B70C4940DEE522BE13974A40F5F1D077B70C4940B2B96A9E239A4A40B8020AF5F40F4940B2B96A9E239A4A40B8020AF5F40F4940DEE522BE13974A40F5F1D077B70C4940DEE522BE13974A40
48055	32	50.099348999999997	50.124662999999998	53.204211999999998	53.180289999999999	Садовая	0103000020E61000000100000005000000F5F1D077B70C4940DEE522BE13974A40F5F1D077B70C4940B2B96A9E239A4A40B8020AF5F40F4940B2B96A9E239A4A40B8020AF5F40F4940DEE522BE13974A40F5F1D077B70C4940DEE522BE13974A40
48053	32	50.243887999999998	50.251460999999999	53.20261	53.19755	Рыльская	0103000020E6100000010000000500000084F1D3B8371F494093A9825149994A4084F1D3B8371F4940D9EBDD1FEF994A40179CC1DF2F204940D9EBDD1FEF994A40179CC1DF2F20494093A9825149994A4084F1D3B8371F494093A9825149994A40
47956	32	50.274169999999998	50.282722	53.248767000000001	53.233953	Республиканская	0103000020E61000000100000005000000ACC5A700182349408AE6012CF29D4A40ACC5A700182349407AA9D898D79F4A400BEE073C302449407AA9D898D79F4A400BEE073C302449408AE6012CF29D4A40ACC5A700182349408AE6012CF29D4A40
8110	32	50.139494999999997	50.144795000000002	53.207237999999997	53.204687	Радонежская улица	0103000020E610000001000000050000004E7ADFF8DA1149404B75012F339A4A404E7ADFF8DA114940853E58C6869A4A40EACF7EA488124940853E58C6869A4A40EACF7EA4881249404B75012F339A4A404E7ADFF8DA1149404B75012F339A4A40
7842	32	50.074421000000001	50.090814999999999	53.128062	53.098695999999997	Пугачевский тракт	0103000020E610000001000000050000005C9198A0860949407D1F0E12A28C4A405C9198A08609494020EEEA5564904A403D7E6FD39F0B494020EEEA5564904A403D7E6FD39F0B49407D1F0E12A28C4A405C9198A0860949407D1F0E12A28C4A40
48018	32	50.170440999999997	50.228301999999999	53.201849000000003	53.173096000000001	Промышленности	0103000020E61000000100000005000000E272BC02D1154940C2887D0228964A40E272BC02D11549407BDD2230D6994A4042CEFBFF381D49407BDD2230D6994A4042CEFBFF381D4940C2887D0228964A40E272BC02D1154940C2887D0228964A40
7460	32	50.151837	50.155690999999997	53.202475	53.200895000000003	Пролетарская улица	0103000020E6100000010000000500000050A912656F134940087767EDB6994A4050A912656F134940F9A067B3EA994A4009A4C4AEED134940F9A067B3EA994A4009A4C4AEED134940087767EDB6994A4050A912656F134940087767EDB6994A40
47931	32	50.151837	50.155690999999997	53.202475	53.200895000000003	Пролетарская	0103000020E6100000010000000500000050A912656F134940087767EDB6994A4050A912656F134940F9A067B3EA994A4009A4C4AEED134940F9A067B3EA994A4009A4C4AEED134940087767EDB6994A4050A912656F134940087767EDB6994A40
48102	32	50.118267000000003	50.130583000000001	53.209487000000003	53.199491999999999	Полевая	0103000020E610000001000000050000001899805F230F494025E82FF488994A401899805F230F4940F5F75278D09A4A40F03499F1B6104940F5F75278D09A4A40F03499F1B610494025E82FF488994A401899805F230F494025E82FF488994A40
47907	32	50.224303999999997	50.281706999999997	53.228076999999999	53.201655000000002	Победы	0103000020E61000000100000005000000552E54FEB51C49409609BFD4CF994A40552E54FEB51C494022FC8BA0319D4A40F20698F90E24494022FC8BA0319D4A40F20698F90E2449409609BFD4CF994A40552E54FEB51C49409609BFD4CF994A40
47974	32	50.077232000000002	50.096815999999997	53.185184	53.180532999999997	Пионерская	0103000020E61000000100000005000000331AF9BCE2094940A46C91B41B974A40331AF9BCE209494009DFFB1BB4974A4061DD7877640C494009DFFB1BB4974A4061DD7877640C4940A46C91B41B974A40331AF9BCE2094940A46C91B41B974A40
48101	32	50.122992000000004	50.132604000000001	53.209341000000002	53.202497000000001	Первомайская	0103000020E61000000100000005000000B7D5AC33BE0F4940E144F46BEB994A40B7D5AC33BE0F4940215B96AFCB9A4A40CEA8F92AF9104940215B96AFCB9A4A40CEA8F92AF9104940E144F46BEB994A40B7D5AC33BE0F4940E144F46BEB994A40
48006	32	50.137284999999999	50.153823000000003	53.196682000000003	53.187154	Пензенская	0103000020E610000001000000050000009D9D0C8E9211494065A88AA9F4974A409D9D0C8E921149401FDB32E02C994A40B22FD978B01349401FDB32E02C994A40B22FD978B013494065A88AA9F4974A409D9D0C8E9211494065A88AA9F4974A40
961	32	50.156579999999998	50.207183000000001	53.197161999999999	53.186937999999998	Партизанская улица	0103000020E61000000100000005000000959A3DD00A14494098309A95ED974A40959A3DD00A144940C901BB9A3C994A40C2A4F8F8841A4940C901BB9A3C994A40C2A4F8F8841A494098309A95ED974A40959A3DD00A14494098309A95ED974A40
48094	32	50.156579999999998	50.207183000000001	53.197161999999999	53.186937999999998	Партизанская	0103000020E61000000100000005000000959A3DD00A14494098309A95ED974A40959A3DD00A144940C901BB9A3C994A40C2A4F8F8841A4940C901BB9A3C994A40C2A4F8F8841A494098309A95ED974A40959A3DD00A14494098309A95ED974A40
48001	32	50.212114	50.212437999999999	53.353095000000003	53.343215000000001	Парижской Коммуны	0103000020E610000001000000050000000A83328D261B4940923F1878EEAB4A400A83328D261B4940C9B08A3732AD4A40BD361B2B311B4940C9B08A3732AD4A40BD361B2B311B4940923F1878EEAB4A400A83328D261B4940923F1878EEAB4A40
48097	32	50.228949	50.244858000000001	53.141264999999997	53.134216000000002	Охтинская	0103000020E61000000100000005000000D8B969334E1D4940CB4C69FD2D914A40D8B969334E1D4940E388B5F814924A40FD14C781571F4940E388B5F814924A40FD14C781571F4940CB4C69FD2D914A40D8B969334E1D4940CB4C69FD2D914A40
48046	32	50.320594999999997	50.324134000000001	53.264906000000003	53.237547999999997	Офицерская	0103000020E610000001000000050000006C21C84109294940779D0DF9679E4A406C21C84109294940D1419770E8A14A40C6C210397D294940D1419770E8A14A40C6C210397D294940779D0DF9679E4A406C21C84109294940779D0DF9679E4A40
48038	32	50.126809999999999	50.147759000000001	53.212690000000002	53.198273	Осипенко	0103000020E610000001000000050000002367614F3B1049400457790261994A402367614F3B104940D717096D399B4A40475854C4E9124940D717096D399B4A40475854C4E91249400457790261994A402367614F3B1049400457790261994A40
16127	32	50.332507	50.337240999999999	53.264173999999997	53.237676999999998	Октябрьская улица	0103000020E610000001000000050000007558E1968F2A494075012F336C9E4A407558E1968F2A49400C3A2174D0A14A4067EF8CB62A2B49400C3A2174D0A14A4067EF8CB62A2B494075012F336C9E4A407558E1968F2A494075012F336C9E4A40
47788	32	50.143528000000003	50.165455999999999	53.185611000000002	53.177435000000003	Новоурицкая	0103000020E61000000100000005000000B80721205F1249403815A930B6964A40B80721205F1249409163EB19C2974A40A77686A92D1549409163EB19C2974A40A77686A92D1549403815A930B6964A40B80721205F1249403815A930B6964A40
47767	32	50.083449000000002	50.096330000000002	53.123015000000002	53.120367000000002	Новомолодежный переулок	0103000020E6100000010000000500000024F1F274AE0A49404242942F688F4A4024F1F274AE0A49406FF59CF4BE8F4A40D5CF9B8A540C49406FF59CF4BE8F4A40D5CF9B8A540C49404242942F688F4A4024F1F274AE0A49404242942F688F4A40
7855	32	50.090814999999999	50.103993000000003	53.136566000000002	53.128062	Новокуйбышевское шоссе	0103000020E610000001000000050000003D7E6FD39F0B494020EEEA5564904A403D7E6FD39F0B49406EDFA3FE7A914A40A80183A44F0D49406EDFA3FE7A914A40A80183A44F0D494020EEEA5564904A403D7E6FD39F0B494020EEEA5564904A40
48005	32	50.202556000000001	50.252431000000001	53.246229	53.209783000000002	Ново-вокзальная	0103000020E61000000100000005000000E6CDE15AED194940DE205A2BDA9A4A40E6CDE15AED194940D4298F6E849F4A4090BFB4A84F204940D4298F6E849F4A4090BFB4A84F204940DE205A2BDA9A4A40E6CDE15AED194940DE205A2BDA9A4A40
47922	32	50.123486999999997	50.215257999999999	53.260925999999998	53.205176999999999	Ново-Садовая	0103000020E61000000100000005000000963D096CCE0F494019726C3D439A4A40963D096CCE0F49408A56EE0566A14A40E719FB928D1B49408A56EE0566A14A40E719FB928D1B494019726C3D439A4A40963D096CCE0F494019726C3D439A4A40
48014	32	50.154173	50.166040000000002	53.219057999999997	53.206660999999997	Николая Панова	0103000020E610000001000000050000008E76DCF0BB134940E82D1EDE739A4A408E76DCF0BB134940ADF6B0170A9C4A40F7E978CC40154940ADF6B0170A9C4A40F7E978CC40154940E82D1EDE739A4A408E76DCF0BB134940E82D1EDE739A4A40
48057	32	50.110461000000001	50.134993999999999	53.183554999999998	53.181564000000002	Неверова	0103000020E61000000100000005000000E23D0796230E4940C310397D3D974A40E23D0796230E49403602F1BA7E974A40FF93BF7B471149403602F1BA7E974A40FF93BF7B47114940C310397D3D974A40E23D0796230E4940C310397D3D974A40
73	32	50.138336000000002	50.303626000000001	53.343527000000002	53.202970999999998	Московское шоссе	0103000020E6100000010000000500000003EE79FEB4114940A98427F4FA994A4003EE79FEB4114940812557B1F8AB4A408F1B7E37DD264940812557B1F8AB4A408F1B7E37DD264940A98427F4FA994A4003EE79FEB4114940A98427F4FA994A40
47869	32	50.268644999999999	50.273935999999999	53.281022999999998	53.277636000000001	Московское 18 км шоссе	0103000020E61000000100000005000000F19D98F5622249409C18929389A34A40F19D98F5622249403F36C98FF8A34A403999B855102349403F36C98FF8A34A403999B855102349409C18929389A34A40F19D98F5622249409C18929389A34A40
48271	32	50.007325000000002	50.390833999999998	53.396335000000001	53.091963999999997	Московского шоссе	0103000020E61000000100000005000000BBB88D06F00049406534F279C58B4A40BBB88D06F00049404DA1F31ABBB24A401A1538D9063249404DA1F31ABBB24A401A1538D9063249406534F279C58B4A40BBB88D06F00049406534F279C58B4A40
48025	32	50.158898000000001	50.214224999999999	53.197539999999996	53.195985999999998	Мориса Тореза	0103000020E610000001000000050000002DB308C556144940A73CBA1116994A402DB308C5561449406FD39FFD48994A40287E8CB96B1B49406FD39FFD48994A40287E8CB96B1B4940A73CBA1116994A402DB308C556144940A73CBA1116994A40
93	32	50.090851000000001	50.127285999999998	53.209864000000003	53.179518000000002	Молодогвардейская улица	0103000020E610000001000000050000008AE76C01A10B49408C852172FA964A408AE76C01A10B4940CB4DD4D2DC9A4A408C9E5BE84A104940CB4DD4D2DC9A4A408C9E5BE84A1049408C852172FA964A408AE76C01A10B49408C852172FA964A40
48087	32	50.090851000000001	50.127285999999998	53.209864000000003	53.179518000000002	Молодогвардейская	0103000020E610000001000000050000008AE76C01A10B49408C852172FA964A408AE76C01A10B4940CB4DD4D2DC9A4A408C9E5BE84A104940CB4DD4D2DC9A4A408C9E5BE84A1049408C852172FA964A408AE76C01A10B49408C852172FA964A40
48103	32	50.127088999999998	50.171618000000002	53.218330000000002	53.197879	Мичурина	0103000020E610000001000000050000003657CD734410494058C85C1954994A403657CD73441049402BDEC83CF29B4A40D5B32094F71549402BDEC83CF29B4A40D5B32094F715494058C85C1954994A403657CD734410494058C85C1954994A40
48099	32	50.249637	50.257632000000001	53.239708999999998	53.233531999999997	Майская	0103000020E610000001000000050000008F6FEF1AF41F4940E4486760E49D4A408F6FEF1AF41F494047C7D5C8AE9E4A409833DB15FA20494047C7D5C8AE9E4A409833DB15FA204940E4486760E49D4A408F6FEF1AF41F4940E4486760E49D4A40
48028	32	50.306922999999998	50.317334000000002	53.266075000000001	53.230201000000001	Магистральная	0103000020E61000000100000005000000F2B1BB4049274940D540F339779D4A40F2B1BB404927494040A4DFBE0EA24A4056F487669E28494040A4DFBE0EA24A4056F487669E284940D540F339779D4A40F2B1BB4049274940D540F339779D4A40
48012	32	50.145926000000003	50.157353000000001	53.215197000000003	53.204988999999998	Луначарского	0103000020E610000001000000050000006CD102B4AD12494016855D143D9A4A406CD102B4AD124940429946938B9B4A40B876A22424144940429946938B9B4A40B876A2242414494016855D143D9A4A406CD102B4AD12494016855D143D9A4A40
48015	32	50.162697999999999	50.176316	53.219763999999998	53.210991	Лукачева	0103000020E61000000100000005000000F38FBE49D31449400B60CAC0019B4A40F38FBE49D3144940486B0C3A219C4A407AE1CE8591164940486B0C3A219C4A407AE1CE85911649400B60CAC0019B4A40F38FBE49D31449400B60CAC0019B4A40
48010	32	50.031463000000002	50.035308000000001	53.104038000000003	53.101908000000002	Липяговская	0103000020E610000001000000050000005C04C6FA06044940B39943520B8D4A405C04C6FA0604494048C5FF1D518D4A40C2A4F8F88404494048C5FF1D518D4A40C2A4F8F884044940B39943520B8D4A405C04C6FA06044940B39943520B8D4A40
47936	32	50.083106999999998	50.096798	53.199196000000001	53.178741000000002	Куйбышева	0103000020E61000000100000005000000CA880B40A30A494028BA2EFCE0964A40CA880B40A30A49403CBF28417F994A40BB287AE0630C49403CBF28417F994A40BB287AE0630C494028BA2EFCE0964A40CA880B40A30A494028BA2EFCE0964A40
48047	32	50.239683999999997	50.257803000000003	53.212302000000001	53.204050000000002	Красных Коммунаров	0103000020E61000000100000005000000EEAF1EF7AD1E4940D95F764F1E9A4A40EEAF1EF7AD1E49400D7041B62C9B4A40C5E74EB0FF2049400D7041B62C9B4A40C5E74EB0FF204940D95F764F1E9A4A40EEAF1EF7AD1E4940D95F764F1E9A4A40
47937	32	50.089323999999998	50.131517000000002	53.196702999999999	53.187645000000003	Красноармейская	0103000020E61000000100000005000000BB5F05F86E0B4940042159C004984A40BB5F05F86E0B494036035C902D994A401CEF8E8CD510494036035C902D994A401CEF8E8CD5104940042159C004984A40BB5F05F86E0B4940042159C004984A40
7639	32	50.118060999999997	50.121437999999998	53.187176000000001	53.186732999999997	Комсомольская площадь	0103000020E610000001000000050000006EF7729F1C0F4940BF0AF0DDE6974A406EF7729F1C0F49404D4C1762F5974A40EE3EC7478B0F49404D4C1762F5974A40EE3EC7478B0F4940BF0AF0DDE6974A406EF7729F1C0F4940BF0AF0DDE6974A40
47954	32	50.124662999999998	50.144857000000002	53.203187	53.195587000000003	Коммунистическая	0103000020E61000000100000005000000B8020AF5F40F4940EA42ACFE08994A40B8020AF5F40F494076FC1708029A4A4060CC96AC8A12494076FC1708029A4A4060CC96AC8A124940EA42ACFE08994A40B8020AF5F40F4940EA42ACFE08994A40
47929	32	50.158934000000002	50.166615	53.185696999999998	53.179901000000001	Клиническая улица	0103000020E610000001000000050000007A1C06F35714494044C2F7FE06974A407A1C06F3571449408FFB56EBC4974A40F302ECA3531549408FFB56EBC4974A40F302ECA35315494044C2F7FE06974A407A1C06F35714494044C2F7FE06974A40
48068	32	50.071995000000001	50.080502000000003	53.117924000000002	53.114345999999998	Кишиневская	0103000020E61000000100000005000000DE3CD52137094940D636C5E3A28E4A40DE3CD52137094940EEB43522188F4A409DA1B8E34D0A4940EEB43522188F4A409DA1B8E34D0A4940D636C5E3A28E4A40DE3CD52137094940D636C5E3A28E4A40
47987	32	50.181086999999998	50.182721000000001	53.369661999999998	53.369104	Квартал 5	0103000020E61000000100000005000000895DDBDB2D1749405169C4CC3EAF4A40895DDBDB2D17494077499C1551AF4A406EA5D7666317494077499C1551AF4A406EA5D766631749405169C4CC3EAF4A40895DDBDB2D1749405169C4CC3EAF4A40
6464	32	50.251721000000003	50.271484000000001	53.230798999999998	53.215197000000003	Каховская улица	0103000020E61000000100000005000000B45BCB6438204940429946938B9B4A40B45BCB6438204940897956D28A9D4A4092B1DAFCBF224940897956D28A9D4A4092B1DAFCBF224940429946938B9B4A40B45BCB6438204940429946938B9B4A40
48054	32	50.202323	50.204127999999997	53.214717	53.193449999999999	Карбышева	0103000020E61000000100000005000000431D56B8E5194940A2B437F8C2984A40431D56B8E51949409772BED87B9B4A405419C6DD201A49409772BED87B9B4A405419C6DD201A4940A2B437F8C2984A40431D56B8E5194940A2B437F8C2984A40
48031	32	50.084283999999997	50.091299999999997	53.157634000000002	53.156753999999999	Казачья	0103000020E61000000100000005000000BCC96FD1C90A494033C2DB8310944A40BCC96FD1C90A49406C5ED5592D944A40F90FE9B7AF0B49406C5ED5592D944A40F90FE9B7AF0B494033C2DB8310944A40BCC96FD1C90A494033C2DB8310944A40
48327	32	50.264243999999998	50.278024000000002	53.202264999999997	53.189782000000001	Кабельная	0103000020E61000000100000005000000051555BFD22149404BAFCDC64A984A40051555BFD22149400E10CCD1E3994A4066C0594A962349400E10CCD1E3994A4066C0594A962349404BAFCDC64A984A40051555BFD22149404BAFCDC64A984A40
47990	32	50.309491999999999	50.342495999999997	53.246352999999999	53.244746999999997	Изыскательская	0103000020E61000000100000005000000D32F116F9D274940A565A4DE539F4A40D32F116F9D274940C022BF7E889F4A406281AFE8D62B4940C022BF7E889F4A406281AFE8D62B4940A565A4DE539F4A40D32F116F9D274940A565A4DE539F4A40
5679	32	50.288327000000002	50.327098999999997	53.240285	53.226880999999999	Зубчаниновское шоссе	0103000020E61000000100000005000000E3C62DE6E7244940B98AC56F0A9D4A40E3C62DE6E7244940145CACA8C19E4A40F3C64961DE294940145CACA8C19E4A40F3C64961DE294940B98AC56F0A9D4A40E3C62DE6E7244940B98AC56F0A9D4A40
48002	32	50.224826	50.234051000000001	53.260962999999997	53.257995000000001	Зои Космодемьянской	0103000020E610000001000000050000002FA52E19C71C494009C4EBFA05A14A402FA52E19C71C4940A73B4F3C67A14A404D4C1762F51D4940A73B4F3C67A14A404D4C1762F51D494009C4EBFA05A14A402FA52E19C71C494009C4EBFA05A14A40
48322	32	50.279505999999998	50.314630000000001	53.227376999999997	53.205938000000003	Земеца	0103000020E61000000100000005000000948444DAC62349407880272D5C9A4A40948444DAC6234940696E85B01A9D4A40952BBCCB45284940696E85B01A9D4A40952BBCCB452849407880272D5C9A4A40948444DAC62349407880272D5C9A4A40
48043	32	50.220298	50.221438999999997	53.212775999999998	53.198855999999999	Запорожская	0103000020E61000000100000005000000E6AF90B9321C4940834E081D74994A40E6AF90B9321C4940D5AF743E3C9B4A408B87F71C581C4940D5AF743E3C9B4A408B87F71C581C4940834E081D74994A40E6AF90B9321C4940834E081D74994A40
6455	32	50.192872000000001	50.293771	53.214351000000001	53.171072000000002	Заводское шоссе	0103000020E6100000010000000500000035289A07B018494073A1F2AFE5954A4035289A07B0184940B56E83DA6F9B4A40B1C1C2499A254940B56E83DA6F9B4A40B1C1C2499A25494073A1F2AFE5954A4035289A07B018494073A1F2AFE5954A40
48037	32	50.155655000000003	50.169831000000002	53.219732	53.208289000000001	Ерошевского	0103000020E61000000100000005000000BD3AC780EC134940EB8EC536A99A4A40BD3AC780EC1349403DF19C2D209C4A406A6CAF05BD1549403DF19C2D209C4A406A6CAF05BD154940EB8EC536A99A4A40BD3AC780EC134940EB8EC536A99A4A40
47992	32	50.261494999999996	50.281706999999997	53.242289999999997	53.227995999999997	Елизарова	0103000020E61000000100000005000000A4880CAB7821494035CF11F92E9D4A40A4880CAB78214940EC12D55B039F4A40F20698F90E244940EC12D55B039F4A40F20698F90E24494035CF11F92E9D4A40A4880CAB7821494035CF11F92E9D4A40
47939	32	50.101298	50.103318999999999	53.134712999999998	53.133341000000001	Дружбы Народов	0103000020E610000001000000050000003A933655F70C4940A41B615111914A403A933655F70C49404BAC8C463E914A401807978E390D49404BAC8C463E914A401807978E390D4940A41B615111914A403A933655F70C4940A41B615111914A40
48090	32	50.223244000000001	50.223649000000002	53.201563999999998	53.198867	Днепровская	0103000020E610000001000000050000009D836742931C494077A04E7974994A409D836742931C4940850662D9CC994A403D64CA87A01C4940850662D9CC994A403D64CA87A01C494077A04E7974994A409D836742931C494077A04E7974994A40
48325	32	50.237079000000001	50.244641999999999	53.281937999999997	53.264097999999997	Дальняя	0103000020E61000000100000005000000C1C8CB9A581E4940317898F6CDA14A40C1C8CB9A581E4940F4BF5C8B16A44A40309DD66D501F4940F4BF5C8B16A44A40309DD66D501F4940317898F6CDA14A40C1C8CB9A581E4940317898F6CDA14A40
48069	32	50.073450000000001	50.075614999999999	53.172626000000001	53.165483999999999	Главная	0103000020E6100000010000000500000013F241CF66094940710168942E954A4013F241CF660949403B38D89B18964A40240B98C0AD0949403B38D89B18964A40240B98C0AD094940710168942E954A4013F241CF66094940710168942E954A40
48062	32	50.212698000000003	50.242018999999999	53.265951000000001	53.247354999999999	Георгия Димитрова	0103000020E610000001000000050000005AF624B0391B494044C02154A99F4A405AF624B0391B494054ABAFAE0AA24A405C01857AFA1E494054ABAFAE0AA24A405C01857AFA1E494044C02154A99F4A405AF624B0391B494044C02154A99F4A40
48029	32	50.212698000000003	50.242018999999999	53.265951000000001	53.247354999999999	Георгия Димитрова	0103000020E610000001000000050000005AF624B0391B494044C02154A99F4A405AF624B0391B494054ABAFAE0AA24A405C01857AFA1E494054ABAFAE0AA24A405C01857AFA1E494044C02154A99F4A405AF624B0391B494044C02154A99F4A40
48093	32	50.276991000000002	50.282524000000002	53.239294000000001	53.231732000000001	Гвардейская	0103000020E61000000100000005000000A724EB7074234940E5B7E864A99D4A40A724EB70742349408410902FA19E4A40E52A16BF292449408410902FA19E4A40E52A16BF29244940E5B7E864A99D4A40A724EB7074234940E5B7E864A99D4A40
48084	32	50.208224999999999	50.208449000000002	53.209054999999999	53.202486	Гастелло	0103000020E61000000100000005000000D49AE61DA71A4940EDF2AD0FEB994A40D49AE61DA71A49405B087250C29A4A4024F1F274AE1A49405B087250C29A4A4024F1F274AE1A4940EDF2AD0FEB994A40D49AE61DA71A4940EDF2AD0FEB994A40
48098	32	50.094714000000003	50.122328000000003	53.206127000000002	53.180992000000003	Галактионовская	0103000020E61000000100000005000000973C9E961F0C4940386BF0BE2A974A40973C9E961F0C49404BE9995E629A4A404BB1A371A80F49404BE9995E629A4A404BB1A371A80F4940386BF0BE2A974A40973C9E961F0C4940386BF0BE2A974A40
47924	32	50.223424000000001	50.224348999999997	53.349902	53.346483999999997	Гайдара	0103000020E610000001000000050000001D925A28991C49402B4B749659AC4A401D925A28991C49400A67B796C9AC4A40F5F1D077B71C49400A67B796C9AC4A40F5F1D077B71C49402B4B749659AC4A401D925A28991C49402B4B749659AC4A40
48070	32	50.078346000000003	50.093069999999997	53.134405000000001	53.123165999999998	Восстания	0103000020E61000000100000005000000DFE2E13D070A494054FD4AE7C38F4A40DFE2E13D070A49409EB5DB2E34914A408E1EBFB7E90B49409EB5DB2E34914A408E1EBFB7E90B494054FD4AE7C38F4A40DFE2E13D070A494054FD4AE7C38F4A40
48080	32	50.216624000000003	50.257739999999998	53.245798000000001	53.214885000000002	Воронежская	0103000020E61000000100000005000000ADC3D155BA1B494053B3075A819B4A40ADC3D155BA1B49400BB6114F769F4A407E6FD39FFD2049400BB6114F769F4A407E6FD39FFD20494053B3075A819B4A40ADC3D155BA1B494053B3075A819B4A40
694	32	50.227699999999999	50.257945999999997	53.226028999999997	53.212403999999999	Вольская улица	0103000020E610000001000000050000004CA60A46251D494011C5E40D309B4A404CA60A46251D49404A79AD84EE9C4A402711E15F042149404A79AD84EE9C4A402711E15F0421494011C5E40D309B4A404CA60A46251D494011C5E40D309B4A40
48013	32	50.227699999999999	50.257945999999997	53.226028999999997	53.212403999999999	Вольская	0103000020E610000001000000050000004CA60A46251D494011C5E40D309B4A404CA60A46251D49404A79AD84EE9C4A402711E15F042149404A79AD84EE9C4A402711E15F0421494011C5E40D309B4A404CA60A46251D494011C5E40D309B4A40
7940	32	50.096798	50.121771000000003	53.211055999999999	53.199196000000001	Волжский проспект	0103000020E61000000100000005000000BB287AE0630C49403CBF28417F994A40BB287AE0630C4940F2CF0CE2039B4A40F54C2F31960F4940F2CF0CE2039B4A40F54C2F31960F49403CBF28417F994A40BB287AE0630C49403CBF28417F994A40
48061	32	50.183349999999997	50.192467999999998	53.196832999999998	53.176453000000002	Волгина	0103000020E610000001000000050000005DDC460378174940FB230C0396964A405DDC46037817494004E3E0D231994A4065C39ACAA218494004E3E0D231994A4065C39ACAA2184940FB230C0396964A405DDC460378174940FB230C0396964A40
47994	32	50.220711000000001	50.226640000000003	53.257052999999999	53.253573000000003	Бубнова	0103000020E61000000100000005000000096F0F42401C494006137F1475A04A40096F0F42401C49405A2BDA1CE7A04A4094FB1D8A021D49405A2BDA1CE7A04A4094FB1D8A021D494006137F1475A04A40096F0F42401C494006137F1475A04A40
48109	32	50.104793000000001	50.115932000000001	53.197172999999999	53.181244999999997	Братьев Коростелевых	0103000020E61000000100000005000000C4EC65DB690D494021C8410933974A40C4EC65DB690D4940BD5301F73C994A40AA471ADCD60E4940BD5301F73C994A40AA471ADCD60E494021C8410933974A40C4EC65DB690D494021C8410933974A40
48059	32	50.104793000000001	50.115932000000001	53.197172999999999	53.181244999999997	Братьев Коростелевых	0103000020E61000000100000005000000C4EC65DB690D494021C8410933974A40C4EC65DB690D4940BD5301F73C994A40AA471ADCD60E4940BD5301F73C994A40AA471ADCD60E494021C8410933974A40C4EC65DB690D494021C8410933974A40
48076	32	50.130744999999997	50.138686	53.203667000000003	53.200122999999998	Больничная	0103000020E61000000100000005000000C98E8D40BC104940B51666A19D994A40C98E8D40BC1049402123A0C2119A4A40DF347D76C01149402123A0C2119A4A40DF347D76C0114940B51666A19D994A40C98E8D40BC104940B51666A19D994A40
48041	32	50.193033999999997	50.211629000000002	53.214717	53.214441999999998	Блюхера	0103000020E610000001000000050000000E828E56B5184940C571E0D5729B4A400E828E56B51849409772BED87B9B4A404EF1B8A8161B49409772BED87B9B4A404EF1B8A8161B4940C571E0D5729B4A400E828E56B5184940C571E0D5729B4A40
868	32	50.198523000000002	50.206850000000003	53.182431999999999	53.174877000000002	Бельский переулок	0103000020E610000001000000050000007D40A033691949404BE9995E62964A407D40A0336919494037DF88EE59974A40BC96900F7A1A494037DF88EE59974A40BC96900F7A1A49404BE9995E62964A407D40A033691949404BE9995E62964A40
48096	32	50.02805	50.067863000000003	53.151808000000003	53.142874999999997	Белорусская	0103000020E610000001000000050000008F537424970349403F355EBA49924A408F53742497034940B6A2CD716E934A40E2CD1ABCAF084940B6A2CD716E934A40E2CD1ABCAF0849403F355EBA49924A408F537424970349403F355EBA49924A40
28821	32	50.185927999999997	50.193789000000002	53.173116999999998	53.171595000000003	Белгородская улица	0103000020E6100000010000000500000091B41B7DCC1749401D9430D3F6954A4091B41B7DCC174940D9B0A6B228964A408BA9F413CE184940D9B0A6B228964A408BA9F413CE1849401D9430D3F6954A4091B41B7DCC1749401D9430D3F6954A40
879	32	50.187860000000001	50.202250999999997	53.185211000000002	53.184753000000001	Балаковская улица	0103000020E61000000100000005000000001DE6CB0B184940406B7EFCA5974A40001DE6CB0B18494003EE79FEB4974A40A94A5B5CE319494003EE79FEB4974A40A94A5B5CE3194940406B7EFCA5974A40001DE6CB0B184940406B7EFCA5974A40
48049	32	50.187860000000001	50.202250999999997	53.185211000000002	53.184753000000001	Балаковская 	0103000020E61000000100000005000000001DE6CB0B184940406B7EFCA5974A40001DE6CB0B18494003EE79FEB4974A40A94A5B5CE319494003EE79FEB4974A40A94A5B5CE3194940406B7EFCA5974A40001DE6CB0B184940406B7EFCA5974A40
48011	32	50.171861	50.212608000000003	53.192323000000002	53.191054999999999	Аэродромная	0103000020E610000001000000050000009B3A8F8AFF1549405F5E807D74984A409B3A8F8AFF15494062A2410A9E984A401A6F2BBD361B494062A2410A9E984A401A6F2BBD361B49405F5E807D74984A409B3A8F8AFF1549405F5E807D74984A40
296	32	50.178248000000004	50.194040000000001	53.201844000000001	53.201358999999997	Артемовская улица	0103000020E61000000100000005000000E94999D4D0164940ACE0B721C6994A40E94999D4D016494069723106D6994A40D40E7F4DD618494069723106D6994A40D40E7F4DD6184940ACE0B721C6994A40E94999D4D0164940ACE0B721C6994A40
48113	32	50.178248000000004	50.194040000000001	53.201844000000001	53.201358999999997	Артемовская	0103000020E61000000100000005000000E94999D4D0164940ACE0B721C6994A40E94999D4D016494069723106D6994A40D40E7F4DD618494069723106D6994A40D40E7F4DD6184940ACE0B721C6994A40E94999D4D0164940ACE0B721C6994A40
48044	32	50.189889999999998	50.227699999999999	53.212884000000003	53.211401000000002	Антонова-Овсеенко	0103000020E6100000010000000500000031EBC5504E184940BDAB1E300F9B4A4031EBC5504E184940BCEB6CC83F9B4A404CA60A46251D4940BCEB6CC83F9B4A404CA60A46251D4940BDAB1E300F9B4A4031EBC5504E184940BDAB1E300F9B4A40
48082	32	50.207030000000003	50.212536999999998	53.251418000000001	53.245173000000001	Аминева	0103000020E610000001000000050000003CA583F57F1A49405D6E30D4619F4A403CA583F57F1A494018D00B772EA04A4050189469341B494018D00B772EA04A4050189469341B49405D6E30D4619F4A403CA583F57F1A49405D6E30D4619F4A40
48064	32	50.257793999999997	50.288587999999997	53.271326000000002	53.237833000000002	Алма-Атинская	0103000020E61000000100000005000000718DCF64FF2049406D74CE4F719E4A40718DCF64FF204940FA4674CFBAA24A404F029B73F0244940FA4674CFBAA24A404F029B73F02449406D74CE4F719E4A40718DCF64FF2049406D74CE4F719E4A40
48074	32	50.129344000000003	50.132209000000003	53.196741000000003	53.190390999999998	Аксакова	0103000020E6100000010000000500000088F71C588E104940F33977BB5E984A4088F71C588E104940246420CF2E994A40529E7939EC104940246420CF2E994A40529E7939EC104940F33977BB5E984A4088F71C588E104940F33977BB5E984A40
48039	32	50.175480999999998	50.185605000000002	53.230535000000003	53.224680999999997	Академика Павлова	0103000020E61000000100000005000000E1085229761649402B84D558C29C4A40E108522976164940ACCABE2B829D4A40AF7C96E7C1174940ACCABE2B829D4A40AF7C96E7C11749402B84D558C29C4A40E1085229761649402B84D558C29C4A40
47909	32	50.212437999999999	50.231867999999999	53.343479000000002	53.343183000000003	Академика Кузнецова	0103000020E61000000100000005000000BD361B2B311B494087C5A86BEDAB4A40BD361B2B311B494070EEAF1EF7AB4A40957EC2D9AD1D494070EEAF1EF7AB4A40957EC2D9AD1D494087C5A86BEDAB4A40BD361B2B311B494087C5A86BEDAB4A40
48114	32	50.186799999999998	50.196789000000003	53.215817000000001	53.162796	Авроры	0103000020E610000001000000050000004772F90FE9174940B6F5D37FD6944A404772F90FE9174940DE7536E49F9B4A40359BC76130194940DE7536E49F9B4A40359BC76130194940B6F5D37FD6944A404772F90FE9174940B6F5D37FD6944A40
48086	32	50.007325000000002	50.390833999999998	53.396335000000001	53.091963999999997	40 лет Пионерии	0103000020E61000000100000005000000BBB88D06F00049406534F279C58B4A40BBB88D06F00049404DA1F31ABBB24A401A1538D9063249404DA1F31ABBB24A401A1538D9063249406534F279C58B4A40BBB88D06F00049406534F279C58B4A40
48003	32	50.167242999999999	50.169443999999999	53.392442000000003	53.388016999999998	4-й квартал	0103000020E6100000010000000500000012BEF7376815494061A5828AAAB14A4012BEF73768154940D6C9198A3BB24A4070404B57B0154940D6C9198A3BB24A4070404B57B015494061A5828AAAB14A4012BEF7376815494061A5828AAAB14A40
47983	32	50.277386	50.281787999999999	53.303747999999999	53.302245999999997	3-й квартал	0103000020E61000000100000005000000232F6B628123494064AC36FFAFA64A40232F6B6281234940DA1CE736E1A64A40DF3312A111244940DA1CE736E1A64A40DF3312A11124494064AC36FFAFA64A40232F6B628123494064AC36FFAFA64A40
48078	32	50.283943999999998	50.287374999999997	53.302424000000002	53.301352999999999	2-й квартал Мехзавода	0103000020E610000001000000050000009DF2E8465824494097C62FBC92A64A409DF2E8465824494044C362D4B5A64A40105839B4C824494044C362D4B5A64A40105839B4C824494097C62FBC92A64A409DF2E8465824494097C62FBC92A64A40
48033	32	50.283943999999998	50.287374999999997	53.302424000000002	53.301352999999999	15-й квартал Мехзавода	0103000020E610000001000000050000009DF2E8465824494097C62FBC92A64A409DF2E8465824494044C362D4B5A64A40105839B4C824494044C362D4B5A64A40105839B4C824494097C62FBC92A64A409DF2E8465824494097C62FBC92A64A40
48106	32	50.283943999999998	50.287374999999997	53.302424000000002	53.301352999999999	11-й квартал Мехзавода	0103000020E610000001000000050000009DF2E8465824494097C62FBC92A64A409DF2E8465824494044C362D4B5A64A40105839B4C824494044C362D4B5A64A40105839B4C824494097C62FBC92A64A409DF2E8465824494097C62FBC92A64A40
48091	32	50.281787999999999	50.288606000000001	53.303747999999999	53.302849000000002	1-й квартал Мехзавода	0103000020E61000000100000005000000DF3312A1112449402B508BC1C3A64A40DF3312A111244940DA1CE736E1A64A40F6B6990AF1244940DA1CE736E1A64A40F6B6990AF12449402B508BC1C3A64A40DF3312A1112449402B508BC1C3A64A40
47988	32	50.276856000000002	50.285066999999998	53.300718000000003	53.295799000000002	 квартал 6,/1	0103000020E61000000100000005000000C7D97404702349404298DBBDDCA54A40C7D9740470234940C6A86BED7DA64A409C1551137D244940C6A86BED7DA64A409C1551137D2449404298DBBDDCA54A40C7D97404702349404298DBBDDCA54A40
47730	32	50.188543000000003	50.267207999999997	53.239207	53.179026999999998	 ХХII Партсъезда	0103000020E61000000100000005000000E371512D22184940ED0C535BEA964A40E371512D22184940B5FCC0559E9E4A40629D2ADF33224940B5FCC0559E9E4A40629D2ADF33224940ED0C535BEA964A40E371512D22184940ED0C535BEA964A40
48009	32	50.067323999999999	50.084193999999997	53.118070000000003	53.111151999999997	 Фасадная	0103000020E61000000100000005000000321EA5129E08494047718E3A3A8E4A40321EA5129E084940C251F2EA1C8F4A407C4276DEC60A4940C251F2EA1C8F4A407C4276DEC60A494047718E3A3A8E4A40321EA5129E08494047718E3A3A8E4A40
48083	32	50.173046999999997	50.222113	53.253346000000001	53.190908999999998	 Советской Армии	0103000020E61000000100000005000000E0D57267261649408BC1C3B46F984A40E0D5726726164940454948A46DA04A401B82E3326E1C4940454948A46DA04A401B82E3326E1C49408BC1C3B46F984A40E0D57267261649408BC1C3B46F984A40
48088	32	50.189889999999998	50.227699999999999	53.212884000000003	53.211401000000002	 Антонова-Овсеенко	0103000020E6100000010000000500000031EBC5504E184940BDAB1E300F9B4A4031EBC5504E184940BCEB6CC83F9B4A404CA60A46251D4940BCEB6CC83F9B4A404CA60A46251D4940BDAB1E300F9B4A4031EBC5504E184940BDAB1E300F9B4A40
81084	62070	50.073909	50.093186000000003	53.165483999999999	53.150857000000002	Шоссейная	0103000020E61000000100000005000000A6F0A0D975094940B4AF3C484F934A40A6F0A0D975094940710168942E954A40F838D384ED0B4940710168942E954A40F838D384ED0B4940B4AF3C484F934A40A6F0A0D975094940B4AF3C484F934A40
77221	55926	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	Пацаева	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
48487	55920	50.747914000000002	50.768988999999998	53.309344000000003	53.295045999999999	Тополиная	0103000020E610000001000000050000003B1C5DA5BB5F494066683C11C4A54A403B1C5DA5BB5F49405F9B8D9598A74A40EBFD463B6E6249405F9B8D9598A74A40EBFD463B6E62494066683C11C4A54A403B1C5DA5BB5F494066683C11C4A54A40
47743	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Центральная	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47888	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Революционная	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47832	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Мира	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47661	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Малиновского	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47852	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Лермонтова	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47660	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Ленинградская	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
48268	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Краснопутиловская	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47854	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Кооперативная	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47833	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Газовиков	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47853	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Бережкова	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
47741	2221	52.080950999999999	52.160839000000003	53.671821999999999	53.635677999999999	Андрея Васильева	0103000020E610000001000000050000000CCA349A5C0A4A40B2648EE55DD14A400CCA349A5C0A4A40DD5D6743FED54A40EF75525F96144A40DD5D6743FED54A40EF75525F96144A40B2648EE55DD14A400CCA349A5C0A4A40B2648EE55DD14A40
48537	55924	49.163204999999998	49.187944999999999	53.253329999999998	53.242252000000001	Школьная	0103000020E6100000010000000500000097C5C4E6E3944840FFB1101D029F4A4097C5C4E6E39448403F8C101E6DA04A402E39EE940E9848403F8C101E6DA04A402E39EE940E984840FFB1101D029F4A4097C5C4E6E3944840FFB1101D029F4A40
48681	55940	51.359110000000001	51.370680999999998	53.898696999999999	53.892766000000002	Садовая	0103000020E6100000010000000500000052D50451F7AD4940897D022846F24A4052D50451F7AD4940B401D88008F34A40D11F9A7972AF4940B401D88008F34A40D11F9A7972AF4940897D022846F24A4052D50451F7AD4940897D022846F24A40
47846	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Центральная	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47738	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Советская	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47655	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Пионерская	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47656	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Первомайская	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47851	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Отрадная	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47742	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Ленинградская	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47740	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Жигулёвская	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47657	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Гайдара	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47658	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	Гагарина	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
47654	2111	51.288888999999998	51.38456	53.397274000000003	53.349155000000003	 Ленина	0103000020E610000001000000050000004A969350FAA44940111E6D1CB1AC4A404A969350FAA449408BC6DADFD9B24A40C5AC174339B149408BC6DADFD9B24A40C5AC174339B14940111E6D1CB1AC4A404A969350FAA44940111E6D1CB1AC4A40
48279	55898	52.029442000000003	52.069479999999999	53.428452	53.411366000000001	Школьная	0103000020E610000001000000050000007E9065C1C4034A40DA571EA4A7B44A407E9065C1C4034A40F1F3DF83D7B64A40F0DC7BB8E4084A40F1F3DF83D7B64A40F0DC7BB8E4084A40DA571EA4A7B44A407E9065C1C4034A40DA571EA4A7B44A40
48050	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Центральная	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
48051	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Мира	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
47949	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Ленинградская	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
47796	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Ленина	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
47681	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Котовского	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
48024	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Гоголя	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
47680	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Гая	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
47679	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	Аипова	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
48126	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	3-го Октября	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
47728	4034	48.579211000000001	48.897492999999997	53.206946000000002	53.154302999999999	3 Октября	0103000020E61000000100000005000000E23D0796234A48405C566133C0934A40E23D0796234A4840DE04DF347D9A4A40C8B1F50CE1724840DE04DF347D9A4A40C8B1F50CE17248405C566133C0934A40E23D0796234A48405C566133C0934A40
77365	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	проезд Жележнодорожный	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
48034	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Чернышевского	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
77214	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Успенского	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
81127	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Свердлова	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
77339	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Победы проспект	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
77334	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Миронова	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
47989	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Киевская улица	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
48040	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Дзержинского	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
77384	55034	49.747847	49.985289999999999	53.115876	52.991498999999997	Гранная	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
47812	55859	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	Нефтяников	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
47770	55859	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	Буровиков	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
77305	55872	50.138336000000002	50.303626000000001	53.343527000000002	53.202970999999998	Московское шоссе	0103000020E6100000010000000500000003EE79FEB4114940A98427F4FA994A4003EE79FEB4114940812557B1F8AB4A408F1B7E37DD264940812557B1F8AB4A408F1B7E37DD264940A98427F4FA994A4003EE79FEB4114940A98427F4FA994A40
48181	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Элеваторная	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47722	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Шоссейная	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
48565	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Школьная	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47659	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Ульяновская	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47727	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Украинская	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47719	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Спортивная	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
48177	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Советская	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47848	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Первомайская	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
48202	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Октябрьская	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47735	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Невская	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47822	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Набережная	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
48269	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Мостовая	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47827	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Мира	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47717	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Маяковского	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
48446	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Дачная	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47653	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	Гагарина	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47725	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	27 Партсъезда	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
48646	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	 Центральная 	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
47828	7140	50.568340999999997	50.669643999999998	53.249015	53.183911000000002	 50 лет Октября	0103000020E61000000100000005000000EBFCDB65BF484940F52F49658A974A40EBFCDB65BF484940529B38B9DF9F4A4037FB03E5B6554940529B38B9DF9F4A4037FB03E5B6554940F52F49658A974A40EBFCDB65BF484940F52F49658A974A40
77386	61156	49.015531000000003	50.070189999999997	53.749178000000001	53.119382999999999	Пионерская	0103000020E610000001000000050000007F8978EBFC814840645930F1478F4A407F8978EBFC814840FC709010E5DF4A40CC4065FCFB084940FC709010E5DF4A40CC4065FCFB084940645930F1478F4A407F8978EBFC814840645930F1478F4A40
77317	55973	49.015531000000003	50.070189999999997	53.749178000000001	53.119382999999999	Морквашинская	0103000020E610000001000000050000007F8978EBFC814840645930F1478F4A407F8978EBFC814840FC709010E5DF4A40CC4065FCFB084940FC709010E5DF4A40CC4065FCFB084940645930F1478F4A407F8978EBFC814840645930F1478F4A40
77311	55973	49.015531000000003	50.070189999999997	53.749178000000001	53.119382999999999	В-1	0103000020E610000001000000050000007F8978EBFC814840645930F1478F4A407F8978EBFC814840FC709010E5DF4A40CC4065FCFB084940FC709010E5DF4A40CC4065FCFB084940645930F1478F4A407F8978EBFC814840645930F1478F4A40
47973	55874	50.146141999999998	50.150975000000003	53.187629000000001	53.185611000000002	Безымянная	0103000020E610000001000000050000003849F3C7B41249409163EB19C2974A403849F3C7B4124940FE63213A04984A40BEC1172653134940FE63213A04984A40BEC11726531349409163EB19C2974A403849F3C7B41249409163EB19C2974A40
48228	50002	49.917206	49.990355999999998	53.437626000000002	53.424588999999997	Управленческая	0103000020E61000000100000005000000F5D8960167F54840E49EAEEE58B64A40F5D8960167F548408DF0F62004B84A40DDB243FCC3FE48408DF0F62004B84A40DDB243FCC3FE4840E49EAEEE58B64A40F5D8960167F54840E49EAEEE58B64A40
47710	4584	48.642245000000003	48.646979999999999	53.336210000000001	53.333516000000003	Советская	0103000020E6100000010000000500000080828B1535524840AC58FCA6B0AA4A4080828B1535524840494BE5ED08AB4A4042959A3DD0524840494BE5ED08AB4A4042959A3DD0524840AC58FCA6B0AA4A4080828B1535524840AC58FCA6B0AA4A40
47711	25927	48.643619999999999	48.710050000000003	53.402814999999997	53.377124000000002	Советская	0103000020E610000001000000050000009886E12362524840B344679945B04A409886E123625248404BAB21718FB34A402D431CEBE25A48404BAB21718FB34A402D431CEBE25A4840B344679945B04A409886E12362524840B344679945B04A40
47709	46516	49.043253	49.080812000000002	53.403067	53.382243000000003	Ленина	0103000020E61000000100000005000000193A765089854840FE0FB056EDB04A40193A765089854840658C0FB397B34A40EB8F300C588A4840658C0FB397B34A40EB8F300C588A4840FE0FB056EDB04A40193A765089854840FE0FB056EDB04A40
48124	46516	49.043253	49.080812000000002	53.403067	53.382243000000003	Королёва	0103000020E61000000100000005000000193A765089854840FE0FB056EDB04A40193A765089854840658C0FB397B34A40EB8F300C588A4840658C0FB397B34A40EB8F300C588A4840FE0FB056EDB04A40193A765089854840FE0FB056EDB04A40
48393	48747	48.886730999999997	48.921639999999996	53.426698000000002	53.413502000000001	Ленина	0103000020E61000000100000005000000B8ACC26680714840516A2FA2EDB44A40B8ACC2668071484062A2410A9EB64A40BC57AD4CF875484062A2410A9EB64A40BC57AD4CF8754840516A2FA2EDB44A40B8ACC26680714840516A2FA2EDB44A40
48288	25656	48.454830000000001	48.497554000000001	53.534978000000002	53.513956999999998	Школьная	0103000020E61000000100000005000000AE9E93DE373A48406F46CD57C9C14A40AE9E93DE373A48402D0ABB287AC44A403BFF76D9AF3F48402D0ABB287AC44A403BFF76D9AF3F48406F46CD57C9C14A40AE9E93DE373A48406F46CD57C9C14A40
48427	4698	48.537322000000003	48.558360999999998	53.714022	53.695211999999998	Советская	0103000020E61000000100000005000000EEB5A0F7C6444840B4E4F1B4FCD84A40EEB5A0F7C6444840F04FA91265DB4A40512E8D5F78474840F04FA91265DB4A40512E8D5F78474840B4E4F1B4FCD84A40EEB5A0F7C6444840B4E4F1B4FCD84A40
48421	55913	48.781762999999998	48.795157000000003	53.717714999999998	53.707647999999999	Центральная	0103000020E61000000100000005000000861C5BCF10644840378AAC3594DA4A40861C5BCF10644840A06CCA15DEDB4A40BE175FB4C7654840A06CCA15DEDB4A40BE175FB4C7654840378AAC3594DA4A40861C5BCF10644840378AAC3594DA4A40
48435	49009	48.813806	48.849110000000003	53.693857999999999	53.675887000000003	Колхозная	0103000020E61000000100000005000000F0A485CB2A6848405265187783D64A40F0A485CB2A684840B308C556D0D84A40715AF0A2AF6C4840B308C556D0D84A40715AF0A2AF6C48405265187783D64A40F0A485CB2A6848405265187783D64A40
47825	48909	48.636882999999997	48.662906999999997	53.350574000000002	53.337128999999997	 Советская	0103000020E610000001000000050000006E30D461855148403FC4060B27AB4A406E30D46185514840F969DC9BDFAC4A400DA5F622DA544840F969DC9BDFAC4A400DA5F622DA5448403FC4060B27AB4A406E30D461855148403FC4060B27AB4A40
47793	48537	48.817399000000002	48.862763999999999	53.620716000000002	53.595616999999997	Ленинградская	0103000020E610000001000000050000003D64CA87A068484087F8872D3DCC4A403D64CA87A06848404E0D349F73CF4A404415FE0C6F6E48404E0D349F73CF4A404415FE0C6F6E484087F8872D3DCC4A403D64CA87A068484087F8872D3DCC4A40
48664	55937	48.490789999999997	48.493619000000002	53.652822999999998	53.651761	Набережная	0103000020E61000000100000005000000179AEB34D23E484075E789E76CD34A40179AEB34D23E4840CE893DB48FD34A4095D74AE82E3F4840CE893DB48FD34A4095D74AE82E3F484075E789E76CD34A40179AEB34D23E484075E789E76CD34A40
48187	26025	48.788159	48.818728999999998	53.342205	53.323067000000002	Советская	0103000020E610000001000000050000002786E464E26448405BB56B425AA94A402786E464E26448408BC3995FCDAB4A40B5A4A31CCC6848408BC3995FCDAB4A40B5A4A31CCC6848405BB56B425AA94A402786E464E26448405BB56B425AA94A40
47698	25753	48.571539000000001	48.617452	53.413336000000001	53.379182	Советская	0103000020E61000000100000005000000BCB1A03028494840AE9D280989B04A40BCB1A030284948403621AD31E8B44A40C66CC9AA084F48403621AD31E8B44A40C66CC9AA084F4840AE9D280989B04A40BCB1A03028494840AE9D280989B04A40
48571	46159	48.844169000000001	48.876094999999999	53.523266999999997	53.504247999999997	Калинина	0103000020E6100000010000000500000005A6D3BA0D6C48406589CE328BC04A4005A6D3BA0D6C4840BB09BE69FAC24A40359886E123704840BB09BE69FAC24A40359886E1237048406589CE328BC04A4005A6D3BA0D6C48406589CE328BC04A40
48562	26031	48.950789999999998	48.975107000000001	53.353901	53.347273999999999	Советская	0103000020E6100000010000000500000092AE997CB37948402460747973AC4A4092AE997CB3794840C782C2A04CAD4A40E38C614ED07C4840C782C2A04CAD4A40E38C614ED07C48402460747973AC4A4092AE997CB37948402460747973AC4A40
48430	49031	48.733379999999997	48.764848000000001	53.658670999999998	53.643317000000003	Новостойка	0103000020E610000001000000050000002EC55565DF5D4840FDFA213658D24A402EC55565DF5D48406CE9D1544FD44A409C340D8AE66148406CE9D1544FD44A409C340D8AE6614840FDFA213658D24A402EC55565DF5D4840FDFA213658D24A40
48546	48926	48.736389000000003	48.762611	53.490369000000001	53.469883000000003	Центральная	0103000020E610000001000000050000002C11A8FE415E484023F94A2025BC4A402C11A8FE415E484072FC5069C4BE4A40F148BC3C9D61484072FC5069C4BE4A40F148BC3C9D61484023F94A2025BC4A402C11A8FE415E484023F94A2025BC4A40
48687	26272	48.700707999999999	48.725825	53.540216999999998	53.523480999999997	Советская 	0103000020E61000000100000005000000D505BCCCB0594840E789E76C01C34A40D505BCCCB059484022DFA5D425C54A4042CF66D5E75C484022DFA5D425C54A4042CF66D5E75C4840E789E76C01C34A40D505BCCCB0594840E789E76C01C34A40
48690	49067	49.126285000000003	49.147368	53.316510000000001	53.296838000000001	Спортивная	0103000020E61000000100000005000000D97C5C1B2A904840E31A9FC9FEA54A40D97C5C1B2A904840B16D516683A84A400C3D62F4DC924840B16D516683A84A400C3D62F4DC924840E31A9FC9FEA54A40D97C5C1B2A904840E31A9FC9FEA54A40
48398	49557	49.000467	49.027174000000002	53.495919000000001	53.482258000000002	Новая	0103000020E6100000010000000500000016DD7A4D0F804840001E51A1BABD4A4016DD7A4D0F804840863B17467ABF4A4098A608707A834840863B17467ABF4A4098A608707A834840001E51A1BABD4A4016DD7A4D0F804840001E51A1BABD4A40
48304	26264	48.548775999999997	48.568961000000002	53.509635000000003	53.493112000000004	Заводская	0103000020E61000000100000005000000336ABE4A3E464840F1A1444B1EBF4A40336ABE4A3E464840D0F23CB83BC14A4088D9CBB6D3484840D0F23CB83BC14A4088D9CBB6D3484840F1A1444B1EBF4A40336ABE4A3E464840F1A1444B1EBF4A40
48153	48833	48.480629999999998	48.505189999999999	53.594344999999997	53.578454000000001	Школьная	0103000020E61000000100000005000000FDBCA948853D4840C51EDAC70ACA4A40FDBCA948853D484043C5387F13CC4A401422E010AA40484043C5387F13CC4A401422E010AA404840C51EDAC70ACA4A40FDBCA948853D4840C51EDAC70ACA4A40
48154	48875	48.533082	48.557138999999999	53.468147000000002	53.438929000000002	Центральная	0103000020E610000001000000050000000B0BEE073C4448400C2252D32EB84A400B0BEE073C4448403A5CAB3DECBB4A40BF29AC54504748403A5CAB3DECBB4A40BF29AC54504748400C2252D32EB84A400B0BEE073C4448400C2252D32EB84A40
48291	55899	51.466279	51.467806000000003	54.436689999999999	54.435957000000002	Попова	0103000020E61000000100000005000000E2E7BF07AFBB49402CBB6070CD374B40E2E7BF07AFBB4940C03E3A75E5374B40B16F2711E1BB4940C03E3A75E5374B40B16F2711E1BB49402CBB6070CD374B40E2E7BF07AFBB49402CBB6070CD374B40
48307	55847	51.443579	51.499679	54.444822000000002	54.406557999999997	Советская	0103000020E61000000100000005000000A0185932C7B84940ADF6B0170A344B40A0185932C7B849404A4563EDEF384B40BEBF417BF5BF49404A4563EDEF384B40BEBF417BF5BF4940ADF6B0170A344B40A0185932C7B84940ADF6B0170A344B40
47673	55847	51.443579	51.499679	54.444822000000002	54.406557999999997	Победы	0103000020E61000000100000005000000A0185932C7B84940ADF6B0170A344B40A0185932C7B849404A4563EDEF384B40BEBF417BF5BF49404A4563EDEF384B40BEBF417BF5BF4940ADF6B0170A344B40A0185932C7B84940ADF6B0170A344B40
48319	55847	51.443579	51.499679	54.444822000000002	54.406557999999997	Льва Толстого	0103000020E61000000100000005000000A0185932C7B84940ADF6B0170A344B40A0185932C7B849404A4563EDEF384B40BEBF417BF5BF49404A4563EDEF384B40BEBF417BF5BF4940ADF6B0170A344B40A0185932C7B84940ADF6B0170A344B40
48229	55847	51.443579	51.499679	54.444822000000002	54.406557999999997	Вокзальная	0103000020E61000000100000005000000A0185932C7B84940ADF6B0170A344B40A0185932C7B849404A4563EDEF384B40BEBF417BF5BF49404A4563EDEF384B40BEBF417BF5BF4940ADF6B0170A344B40A0185932C7B84940ADF6B0170A344B40
48287	20437	51.697263	51.727581000000001	54.519202	54.500028999999998	Ленина	0103000020E61000000100000005000000FDDAFAE93FD949409A0645F300404B40FDDAFAE93FD9494047020D3675424B407218CC5F21DD494047020D3675424B407218CC5F21DD49409A0645F300404B40FDDAFAE93FD949409A0645F300404B40
48587	20359	51.552509000000001	51.592052000000002	54.535901000000003	54.523147999999999	Советская	0103000020E6100000010000000500000072DF6A9DB8C64940E17B7F83F6424B4072DF6A9DB8C6494065726A6798444B4005C4245CC8CB494065726A6798444B4005C4245CC8CB4940E17B7F83F6424B4072DF6A9DB8C64940E17B7F83F6424B40
48702	55948	51.531469999999999	51.550612999999998	54.496384999999997	54.488121999999997	Садовая	0103000020E610000001000000050000000E677E3507C44940A33A1DC87A3E4B400E677E3507C44940CB9C2E8B893F4B4050E09D7C7AC64940CB9C2E8B893F4B4050E09D7C7AC64940A33A1DC87A3E4B400E677E3507C44940A33A1DC87A3E4B40
48630	19934	51.439087000000001	51.464751999999997	54.576698999999998	54.545256000000002	Тимяшево	0103000020E61000000100000005000000A48CB80034B8494051F9D7F2CA454B40A48CB80034B849406551D845D1494B40136058FE7CBB49406551D845D1494B40136058FE7CBB494051F9D7F2CA454B40A48CB80034B8494051F9D7F2CA454B40
48585	19621	51.743175999999998	51.770313999999999	54.401375000000002	54.383651999999998	Школьная	0103000020E610000001000000050000000796236420DF4940C2853C821B314B400796236420DF49404C37894160334B4052D32EA699E249404C37894160334B4052D32EA699E24940C2853C821B314B400796236420DF4940C2853C821B314B40
48629	47051	51.622855999999999	51.641010999999999	54.308193000000003	54.296340999999998	Школьная	0103000020E61000000100000005000000060FD3BEB9CF494062BB7B80EE254B40060FD3BEB9CF494096ED43DE72274B4029B000A60CD2494096ED43DE72274B4029B000A60CD2494062BB7B80EE254B40060FD3BEB9CF494062BB7B80EE254B40
48466	19926	51.583230999999998	51.611977000000003	54.602721000000003	54.579537999999999	Центральная	0103000020E61000000100000005000000B6813B50A7CA494006651A4D2E4A4B40B6813B50A7CA494064CE33F6254D4B40BD73284355CE494064CE33F6254D4B40BD73284355CE494006651A4D2E4A4B40B6813B50A7CA494006651A4D2E4A4B40
48632	19991	51.472890999999997	51.510153000000003	54.408712000000001	54.383741000000001	Советская	0103000020E610000001000000050000004FC939B187BC49403291D26C1E314B404FC939B187BC4940CBBDC0AC50344B40687A89B14CC14940CBBDC0AC50344B40687A89B14CC149403291D26C1E314B404FC939B187BC49403291D26C1E314B40
48471	20538	51.825811999999999	51.840437000000001	54.532929000000003	54.518642999999997	Школьная	0103000020E610000001000000050000007A522635B4E9494050A6D1E462424B407A522635B4E94940850B790437444B4097AC8A7093EB4940850B790437444B4097AC8A7093EB494050A6D1E462424B407A522635B4E9494050A6D1E462424B40
48465	19826	51.513306	51.532808000000003	54.615689000000003	54.592153000000003	Советская	0103000020E61000000100000005000000986BD102B4C14940399D64ABCB4B4B40986BD102B4C14940E4C0ABE5CE4E4B400A86730D33C44940E4C0ABE5CE4E4B400A86730D33C44940399D64ABCB4B4B40986BD102B4C14940399D64ABCB4B4B40
48679	47152	51.350315999999999	51.383347000000001	54.493628999999999	54.477111999999998	 Советская	0103000020E61000000100000005000000FDA19927D7AC4940BB438A01123D4B40FDA19927D7AC4940B8AD2D3C2F3F4B408602B68311B14940B8AD2D3C2F3F4B408602B68311B14940BB438A01123D4B40FDA19927D7AC4940BB438A01123D4B40
48468	19820	51.864718000000003	51.888595000000002	54.468479000000002	54.447209000000001	Журавлева	0103000020E610000001000000050000009B215514AFEE49400ABDFE243E394B409B215514AFEE494070EEAF1EF73B4B40CF31207BBDF1494070EEAF1EF73B4B40CF31207BBDF149400ABDFE243E394B409B215514AFEE49400ABDFE243E394B40
48635	20162	51.307977999999999	51.336212000000003	54.307746999999999	54.296115	Бочкарева	0103000020E6100000010000000500000099F1B6D26BA74940726DA818E7254B4099F1B6D26BA749409738F24064274B40EA42ACFE08AB49409738F24064274B40EA42ACFE08AB4940726DA818E7254B4099F1B6D26BA74940726DA818E7254B40
47682	45541	51.740858000000003	51.756678000000001	54.543882000000004	54.535316000000002	Комсомольская	0103000020E61000000100000005000000707D586FD4DE49404583143C85444B40707D586FD4DE49400971E5EC9D454B4025CD1FD3DAE049400971E5EC9D454B4025CD1FD3DAE049404583143C85444B40707D586FD4DE49404583143C85444B40
48636	19360	51.322046	51.352184000000001	54.424759999999999	54.417226999999997	Центральная	0103000020E6100000010000000500000060E7A6CD38A949400C01C0B167354B4060E7A6CD38A94940115322895E364B405516855D14AD4940115322895E364B405516855D14AD49400C01C0B167354B4060E7A6CD38A949400C01C0B167354B40
48567	19678	51.764367	51.783428999999998	54.431379999999997	54.419694	 Центральная	0103000020E61000000100000005000000219221C7D6E14940E9297288B8354B40219221C7D6E149400113B87537374B4076DEC66647E449400113B87537374B4076DEC66647E44940E9297288B8354B40219221C7D6E14940E9297288B8354B40
48198	19538	51.600684999999999	51.637956000000003	54.495057000000003	54.391939999999998	Хакимова	0103000020E610000001000000050000005019FF3EE3CC494043FF04172B324B405019FF3EE3CC4940F4531C075E3F4B40BC24CE8AA8D14940F4531C075E3F4B40BC24CE8AA8D1494043FF04172B324B405019FF3EE3CC494043FF04172B324B40
48647	49223	51.651511999999997	51.663207999999997	54.336024999999999	54.320388999999999	Центральная	0103000020E61000000100000005000000CC79C6BE64D34940C37FBA8102294B40CC79C6BE64D34940B7D100DE022B4B400839EFFFE3D44940B7D100DE022B4B400839EFFFE3D44940C37FBA8102294B40CC79C6BE64D34940C37FBA8102294B40
48634	20171	51.562668000000002	51.594154000000003	54.512324	54.499245000000002	Молодежная	0103000020E61000000100000005000000BC40498105C8494084D89942E73F4B40BC40498105C849405B7A34D593414B40D064FF3C0DCC49405B7A34D593414B40D064FF3C0DCC494084D89942E73F4B40BC40498105C8494084D89942E73F4B40
48633	20062	51.390470000000001	51.424309999999998	54.362808999999999	54.334066999999997	Школьная	0103000020E61000000100000005000000D908C4EBFAB149401FD61BB5C22A4B40D908C4EBFAB14940E4D87A86702E4B40D1AE42CA4FB64940E4D87A86702E4B40D1AE42CA4FB649401FD61BB5C22A4B40D908C4EBFAB149401FD61BB5C22A4B40
48356	19305	51.348734999999998	51.384765999999999	54.425708	54.412762999999998	Советская	0103000020E610000001000000050000003BFC3559A3AC4940DAFF006BD5344B403BFC3559A3AC4940A2D288997D364B406E4E250340B14940A2D288997D364B406E4E250340B14940DAFF006BD5344B403BFC3559A3AC4940DAFF006BD5344B40
48638	47359	51.634058000000003	51.651161999999999	54.529004999999998	54.509596000000002	Школьная	0103000020E6100000010000000500000033E202D028D14940121615713A414B4033E202D028D14940D235936FB6434B40F032C34659D34940D235936FB6434B40F032C34659D34940121615713A414B4033E202D028D14940121615713A414B40
48583	18306	50.842883999999998	50.860796999999998	54.360405999999998	54.345146999999997	Центральная	0103000020E610000001000000050000002C29779FE36B494000A8E2C62D2C4B402C29779FE36B49401EA4A7C8212E4B4059BF99982E6E49401EA4A7C8212E4B4059BF99982E6E494000A8E2C62D2C4B402C29779FE36B494000A8E2C62D2C4B40
48416	19200	51.141959999999997	51.171937	54.614662000000003	54.596550999999998	Советская	0103000020E610000001000000050000008AABCABE2B924940B3B27DC85B4C4B408AABCABE2B924940070C923EAD4E4B4076FC170802964940070C923EAD4E4B4076FC170802964940B3B27DC85B4C4B408AABCABE2B924940B3B27DC85B4C4B40
48419	19101	51.269854000000002	51.303756	54.489393	54.468532000000003	Центральная	0103000020E61000000100000005000000EF586C938AA24940939048DBF83B4B40EF586C938AA2494017F2086EA43E4B405DFB027AE1A6494017F2086EA43E4B405DFB027AE1A64940939048DBF83B4B40EF586C938AA24940939048DBF83B4B40
48462	46642	50.908003000000001	50.935068999999999	54.232258999999999	54.208016999999998	Школьная	0103000020E61000000100000005000000BFD53A71397449408A01124DA01A4B40BFD53A7139744940D099B4A9BA1D4B4070404B57B0774940D099B4A9BA1D4B4070404B57B07749408A01124DA01A4B40BFD53A71397449408A01124DA01A4B40
48346	18629	51.063133000000001	51.103808999999998	54.428620000000002	54.398266999999997	микрорайон Сельхозтехника	0103000020E610000001000000050000003126FDBD14884940BB09BE69FA324B403126FDBD14884940AD342905DD364B40E603029D498D4940AD342905DD364B40E603029D498D4940BB09BE69FA324B403126FDBD14884940BB09BE69FA324B40
48284	18629	51.063133000000001	51.103808999999998	54.428620000000002	54.398266999999997	Центральная	0103000020E610000001000000050000003126FDBD14884940BB09BE69FA324B403126FDBD14884940AD342905DD364B40E603029D498D4940AD342905DD364B40E603029D498D4940BB09BE69FA324B403126FDBD14884940BB09BE69FA324B40
48241	18629	51.063133000000001	51.103808999999998	54.428620000000002	54.398266999999997	Советская	0103000020E610000001000000050000003126FDBD14884940BB09BE69FA324B403126FDBD14884940AD342905DD364B40E603029D498D4940AD342905DD364B40E603029D498D4940BB09BE69FA324B403126FDBD14884940BB09BE69FA324B40
47765	18629	51.063133000000001	51.103808999999998	54.428620000000002	54.398266999999997	Почтовая	0103000020E610000001000000050000003126FDBD14884940BB09BE69FA324B403126FDBD14884940AD342905DD364B40E603029D498D4940AD342905DD364B40E603029D498D4940BB09BE69FA324B403126FDBD14884940BB09BE69FA324B40
48286	18629	51.063133000000001	51.103808999999998	54.428620000000002	54.398266999999997	Заводская	0103000020E610000001000000050000003126FDBD14884940BB09BE69FA324B403126FDBD14884940AD342905DD364B40E603029D498D4940AD342905DD364B40E603029D498D4940BB09BE69FA324B403126FDBD14884940BB09BE69FA324B40
48232	18629	51.063133000000001	51.103808999999998	54.428620000000002	54.398266999999997	 М. Джалиля	0103000020E610000001000000050000003126FDBD14884940BB09BE69FA324B403126FDBD14884940AD342905DD364B40E603029D498D4940AD342905DD364B40E603029D498D4940BB09BE69FA324B403126FDBD14884940BB09BE69FA324B40
48420	18580	51.131279999999997	51.165829000000002	54.345305000000003	54.326501	Центральная	0103000020E61000000100000005000000374F75C8CD9049403F8EE6C8CA294B40374F75C8CD904940991249F4322C4B403CDD79E239954940991249F4322C4B403CDD79E2399549403F8EE6C8CA294B40374F75C8CD9049403F8EE6C8CA294B40
48196	19104	51.154384	51.188564999999997	54.597098000000003	54.586033999999998	Школьная	0103000020E610000001000000050000004983DBDAC29349400A2C8029034B4B404983DBDAC2934940E6400FB56D4C4B40CA15DEE522984940E6400FB56D4C4B40CA15DEE5229849400A2C8029034B4B404983DBDAC29349400A2C8029034B4B40
48584	18573	51.014076000000003	51.044682000000002	54.535541000000002	54.519562999999998	Школьная	0103000020E610000001000000050000004AD40B3ECD814940179B560A81424B404AD40B3ECD8149406555849B8C444B40255CC823B88549406555849B8C444B40255CC823B8854940179B560A81424B404AD40B3ECD814940179B560A81424B40
47744	7960	50.914614999999998	50.924450999999998	54.339168999999998	54.328591000000003	Советская	0103000020E610000001000000050000002CB7B41A12754940466117450F2A4B402CB7B41A127549409468C9E3692B4B4093E00D69547649409468C9E3692B4B4093E00D6954764940466117450F2A4B402CB7B41A12754940466117450F2A4B40
48282	18466	51.093676000000002	51.137324999999997	54.547772999999999	54.527056000000002	Советская	0103000020E61000000100000005000000C6353E93FD8B49408E942D9276434B40C6353E93FD8B4940DF50F86C1D464B402BF697DD93914940DF50F86C1D464B402BF697DD939149408E942D9276434B40C6353E93FD8B49408E942D9276434B40
48184	45817	51.190576999999998	51.206001000000001	54.473581000000003	54.468359	Первомайская	0103000020E61000000100000005000000552FBFD364984940C5E40D30F33B4B40552FBFD364984940E5805D4D9E3C4B40BEF8A23D5E9A4940E5805D4D9E3C4B40BEF8A23D5E9A4940C5E40D30F33B4B40552FBFD364984940C5E40D30F33B4B40
48478	19206	51.236139999999999	51.261454000000001	54.544471999999999	54.530645999999997	Главная	0103000020E6100000010000000500000083A3E4D5399E494069E04735EC434B4083A3E4D5399E49403ACB2C42B1454B4046B41D5377A149403ACB2C42B1454B4046B41D5377A1494069E04735EC434B4083A3E4D5399E494069E04735EC434B40
48305	19014	51.123491000000001	51.155830000000002	54.490788999999999	54.475935	Озерная	0103000020E61000000100000005000000D82C978DCE8F4940C9022670EB3C4B40D82C978DCE8F4940471E882CD23E4B402BDEC83CF2934940471E882CD23E4B402BDEC83CF2934940C9022670EB3C4B40D82C978DCE8F4940C9022670EB3C4B40
48623	18165	51.296219000000001	51.327454000000003	54.576579000000002	54.562184000000002	 Центральная	0103000020E6100000010000000500000017BA1281EAA54940D02A33A5F5474B4017BA1281EAA54940BB473657CD494B40E2783E03EAA94940BB473657CD494B40E2783E03EAA94940D02A33A5F5474B4017BA1281EAA54940D02A33A5F5474B40
48581	18266	50.908344999999997	50.930120000000002	54.327697999999998	54.311307999999997	Молодежная	0103000020E61000000100000005000000183E22A644744940D87DC7F0D8274B40183E22A644744940787B1002F2294B4082AD122C0E774940787B1002F2294B4082AD122C0E774940D87DC7F0D8274B40183E22A644744940D87DC7F0D8274B40
48626	17965	51.218936999999997	51.243316999999998	54.482782	54.467725999999999	Школьная	0103000020E610000001000000050000003271AB20069C494094BE1072DE3B4B403271AB20069C49407A8CF2CCCB3D4B40C9C7EE02259F49407A8CF2CCCB3D4B40C9C7EE02259F494094BE1072DE3B4B403271AB20069C494094BE1072DE3B4B40
47751	11235	50.938564	50.971406000000002	54.246361	54.237152999999999	Куйбышевская	0103000020E61000000100000005000000FA997ADD22784940FB928D075B1E4B40FA997ADD227849404301DBC1881F4B40B0912408577C49404301DBC1881F4B40B0912408577C4940FB928D075B1E4B40FA997ADD22784940FB928D075B1E4B40
48137	18021	51.102542	51.149686000000003	54.293083000000003	54.271647000000002	Школьная	0103000020E61000000100000005000000B43BA418208D49403C873254C5224B40B43BA418208D4940BD0166BE83254B40A4552DE928934940BD0166BE83254B40A4552DE9289349403C873254C5224B40B43BA418208D49403C873254C5224B40
48463	18252	50.848875999999997	50.867238	54.295189999999998	54.285457000000001	Центральная	0103000020E61000000100000005000000FD2D01F8A76C494007B5DFDA89244B40FD2D01F8A76C4940990D32C9C8254B409AEC9FA7016F4940990D32C9C8254B409AEC9FA7016F494007B5DFDA89244B40FD2D01F8A76C494007B5DFDA89244B40
48119	48185	51.139284000000004	51.151491999999998	54.316566000000002	54.30397	Чапаевская	0103000020E61000000100000005000000946DE00ED4914940897B2C7DE8264B40946DE00ED49149404583143C85284B4085CD0017649349404583143C85284B4085CD001764934940897B2C7DE8264B40946DE00ED4914940897B2C7DE8264B40
48412	18161	51.212361000000001	51.244287999999997	54.630116999999998	54.616664	Центральная	0103000020E6100000010000000500000012F92EA52E9B49406E4F90D8EE4E4B4012F92EA52E9B4940AAD381ACA7504B40126745D4449F4940AAD381ACA7504B40126745D4449F49406E4F90D8EE4E4B4012F92EA52E9B49406E4F90D8EE4E4B40
48201	55892	51.264913	51.308292999999999	54.638658	54.623404000000001	Школьная	0103000020E6100000010000000500000083A44FABE8A149400919C8B3CB4F4B4083A44FABE8A1494015AA9B8BBF514B40F94A202576A7494015AA9B8BBF514B40F94A202576A749400919C8B3CB4F4B4083A44FABE8A149400919C8B3CB4F4B40
48627	46459	51.087522999999997	51.115459999999999	54.270243999999998	54.252409999999998	Фрунзе	0103000020E61000000100000005000000EB5223F4338B494078978BF84E204B40EB5223F4338B494059F8FA5A97224B4082FFAD64C78E494059F8FA5A97224B4082FFAD64C78E494078978BF84E204B40EB5223F4338B494078978BF84E204B40
48227	17863	51.184764999999999	51.214311000000002	54.441785000000003	54.407994000000002	Советская	0103000020E6100000010000000500000004392861A69749406C7BBB2539344B4004392861A6974940836E2F698C384B402716F88A6E9B4940836E2F698C384B402716F88A6E9B49406C7BBB2539344B4004392861A69749406C7BBB2539344B40
47745	45827	50.829777999999997	50.862881000000002	54.291091000000002	54.278624000000001	Ленинская	0103000020E610000001000000050000005B785E2A366A4940BBF083F3A9234B405B785E2A366A494079944A7842254B407EAB75E2726E494079944A7842254B407EAB75E2726E4940BBF083F3A9234B405B785E2A366A4940BBF083F3A9234B40
48192	47679	50.999200000000002	51.009377999999998	54.227300999999997	54.217956999999998	А.Толстого	0103000020E61000000100000005000000E4141DC9E57F49409677D503E61B4B40E4141DC9E57F49408EACFC32181D4B40A4A65D4C338149408EACFC32181D4B40A4A65D4C338149409677D503E61B4B40E4141DC9E57F49409677D503E61B4B40
48447	55916	48.882742	48.913742999999997	52.508629999999997	52.488899000000004	Молодёжная	0103000020E610000001000000050000001F679AB0FD7048400806103E943E4A401F679AB0FD704840DAE1AFC91A414A4076F9D687F5744840DAE1AFC91A414A4076F9D687F57448400806103E943E4A401F679AB0FD7048400806103E943E4A40
48432	55914	49.303603000000003	49.319845000000001	52.666542	52.654125999999998	Хлебная	0103000020E61000000100000005000000D7FB8D76DCA648404DBB9866BA534A40D7FB8D76DCA6484089B48D3F51554A40026553AEF0A8484089B48D3F51554A40026553AEF0A848404DBB9866BA534A40D7FB8D76DCA648404DBB9866BA534A40
47918	55856	48.932319999999997	48.992255999999998	52.632941000000002	52.594315000000002	Школьная	0103000020E610000001000000050000000FB4024356774840D9429083124C4A400FB402435677484016A6EF3504514A4040A19E3E027F484016A6EF3504514A4040A19E3E027F4840D9429083124C4A400FB4024356774840D9429083124C4A40
47733	55856	48.932319999999997	48.992255999999998	52.632941000000002	52.594315000000002	Плясункова	0103000020E610000001000000050000000FB4024356774840D9429083124C4A400FB402435677484016A6EF3504514A4040A19E3E027F484016A6EF3504514A4040A19E3E027F4840D9429083124C4A400FB4024356774840D9429083124C4A40
48642	55935	49.072609999999997	49.091088999999997	52.862076000000002	52.849907000000002	Центральная	0103000020E6100000010000000500000068AED3484B8948401CD2A8C0C96C4A4068AED3484B8948405055A181586E4A403E03EACDA88B48405055A181586E4A403E03EACDA88B48401CD2A8C0C96C4A4068AED3484B8948401CD2A8C0C96C4A40
48703	55949	49.186695999999998	49.223275999999998	52.801326000000003	52.779226999999999	Новый поселок	0103000020E61000000100000005000000A2258FA7E59748408194D8B5BD634A40A2258FA7E59748409EB7B1D991664A40A8FDD64E949C48409EB7B1D991664A40A8FDD64E949C48408194D8B5BD634A40A2258FA7E59748408194D8B5BD634A40
48708	55954	48.901561999999998	48.918818999999999	52.799169999999997	52.787680000000002	Полевая	0103000020E610000001000000050000007EA83462667348404DDBBFB2D2644A407EA8346266734840DFF8DA334B664A40C2F869DC9B754840DFF8DA334B664A40C2F869DC9B7548404DDBBFB2D2644A407EA83462667348404DDBBFB2D2644A40
48263	55896	49.404125000000001	49.433230000000002	52.753628999999997	52.726672999999998	Школьная	0103000020E610000001000000050000007D3F355EBAB348406FF1F09E035D4A407D3F355EBAB34840992842EA76604A40B3D2A41474B74840992842EA76604A40B3D2A41474B748406FF1F09E035D4A407D3F355EBAB348406FF1F09E035D4A40
48329	55906	49.009180000000001	49.040028	52.521858999999999	52.507671000000002	Молодежная	0103000020E610000001000000050000007EE36BCF2C8148405610035DFB404A407EE36BCF2C814840C70F9546CC424A404F7633A31F854840C70F9546CC424A404F7633A31F8548405610035DFB404A407EE36BCF2C8148405610035DFB404A40
48686	55942	49.122340999999999	49.139381999999998	52.751001000000002	52.739133000000002	Рабочая	0103000020E61000000100000005000000DFFAB0DEA88F48407B32FFE89B5E4A40DFFAB0DEA88F4840B421FFCC20604A4056D3F544D7914840B421FFCC20604A4056D3F544D79148407B32FFE89B5E4A40DFFAB0DEA88F48407B32FFE89B5E4A40
48303	55902	48.723705000000002	48.793467999999997	52.671925999999999	52.646259000000001	Советская	0103000020E61000000100000005000000D1798D5DA25C484072DF6A9DB8524A40D1798D5DA25C484082AAD1AB01564A401536035C9065484082AAD1AB01564A401536035C9065484072DF6A9DB8524A40D1798D5DA25C484072DF6A9DB8524A40
48309	55903	49.267598999999997	49.301124000000002	52.677844999999998	52.652634999999997	Советская	0103000020E610000001000000050000009DB81CAF40A24840CB9C2E8B89534A409DB81CAF40A24840E960FD9FC3564A403605323B8BA64840E960FD9FC3564A403605323B8BA64840CB9C2E8B89534A409DB81CAF40A24840CB9C2E8B89534A40
48392	55911	49.223140999999998	49.249479999999998	52.645172000000002	52.623939	Центральная	0103000020E61000000100000005000000C8B260E28F9C484077D9AF3BDD4F4A40C8B260E28F9C4840C02500FF94524A40C780ECF5EE9F4840C02500FF94524A40C780ECF5EE9F484077D9AF3BDD4F4A40C8B260E28F9C484077D9AF3BDD4F4A40
48148	55888	49.067472000000002	49.101213000000001	52.829203	52.806716000000002	Советская	0103000020E61000000100000005000000A7B228ECA288484079944A7842674A40A7B228ECA28848405F5FEB52236A4A400C772E8CF48C48405F5FEB52236A4A400C772E8CF48C484079944A7842674A40A7B228ECA288484079944A7842674A40
48569	55930	49.151392999999999	49.174686000000001	52.635362000000001	52.621609999999997	Советская	0103000020E61000000100000005000000F2EB87D860934840EB6E9EEA904F4A40F2EB87D860934840828FC18A53514A40D788601C5C964840828FC18A53514A40D788601C5C964840EB6E9EEA904F4A40F2EB87D860934840EB6E9EEA904F4A40
48440	55915	49.317500000000003	49.329106000000003	52.796953999999999	52.792608999999999	Широкая	0103000020E61000000100000005000000713D0AD7A3A84840F4C1323674654A40713D0AD7A3A848404C35B39602664A406D75392520AA48404C35B39602664A406D75392520AA4840F4C1323674654A40713D0AD7A3A84840F4C1323674654A40
48685	55941	49.320706999999999	49.354698999999997	52.711362000000001	52.690531999999997	Неверова	0103000020E61000000100000005000000944C4EED0CA94840B56B425A63584A40944C4EED0CA94840FFCEF6E80D5B4A404276DEC666AD4840FFCEF6E80D5B4A404276DEC666AD4840B56B425A63584A40944C4EED0CA94840B56B425A63584A40
48697	55945	48.805352999999997	48.826031999999998	52.762326999999999	52.750532999999997	Лесная	0103000020E61000000100000005000000245E9ECE15674840CDC8207711604A40245E9ECE15674840CCED5EEE93614A4088B9A46ABB694840CCED5EEE93614A4088B9A46ABB694840CDC8207711604A40245E9ECE15674840CDC8207711604A40
48118	55886	48.910330000000002	48.951642999999997	52.732742999999999	52.678544000000002	Специалистов	0103000020E61000000100000005000000AA4885B185744840D272A087DA564A40AA4885B185744840BCAFCA85CA5D4A40D13B1570CF794840BCAFCA85CA5D4A40D13B1570CF794840D272A087DA564A40AA4885B185744840D272A087DA564A40
48448	25080	49.146774999999998	49.165118999999997	52.545929999999998	52.529749000000002	Школьная	0103000020E61000000100000005000000696FF085C99248405B0BB3D0CE434A40696FF085C9924840E0F3C308E1454A405F79909E22954840E0F3C308E1454A405F79909E229548405B0BB3D0CE434A40696FF085C99248405B0BB3D0CE434A40
48316	55905	48.639882999999998	48.687485000000002	52.700164999999998	52.682366000000002	Школьная	0103000020E610000001000000050000001822A7AFE751484080F3E2C457574A401822A7AFE7514840E466B8019F594A40CBBE2B82FF574840E466B8019F594A40CBBE2B82FF57484080F3E2C457574A401822A7AFE751484080F3E2C457574A40
47686	55850	48.473578000000003	48.474727999999999	53.150350000000003	53.149740000000001	пр.50 лет октября	0103000020E61000000100000005000000740D33349E3C4840977329AE2A934A40740D33349E3C4840107A36AB3E934A406C3F19E3C33C4840107A36AB3E934A406C3F19E3C33C4840977329AE2A934A40740D33349E3C4840977329AE2A934A40
47958	55870	47.926988999999999	49.220391999999997	53.493316	52.939784000000003	Гаражная	0103000020E6100000010000000500000039605793A7F64740ECA694D74A784A4039605793A7F64740F94B8BFA24BF4A40672618CE359C4840F94B8BFA24BF4A40672618CE359C4840ECA694D74A784A4039605793A7F64740ECA694D74A784A40
48684	24377	48.435533999999997	48.454155999999998	53.329278000000002	53.308805999999997	Железникова	0103000020E61000000100000005000000E525FF93BF3748407F677BF486A74A40E525FF93BF3748406AA510C825AA4A401EA4A7C8213A48406AA510C825AA4A401EA4A7C8213A48407F677BF486A74A40E525FF93BF3748407F677BF486A74A40
47791	24228	48.674055000000003	48.714281	53.334536999999997	53.313954000000003	К.Маркса	0103000020E61000000100000005000000475A2A6F47564840653909A52FA84A40475A2A6F47564840A626C11BD2AA4A40BC934F8F6D5B4840A626C11BD2AA4A40BC934F8F6D5B4840653909A52FA84A40475A2A6F47564840653909A52FA84A40
48677	23784	48.347248	48.383980000000001	53.128909999999998	53.118631999999998	Колхозная	0103000020E61000000100000005000000FBCC599F722C4840292158552F8F4A40FBCC599F722C48404D10751F80904A40B728B341263148404D10751F80904A40B728B34126314840292158552F8F4A40FBCC599F722C4840292158552F8F4A40
48504	21830	48.222571000000002	48.257066000000002	53.315460999999999	53.305039000000001	Королева	0103000020E61000000100000005000000DE04DF347D1C4840958098840BA74A40DE04DF347D1C4840EC14AB0661A84A40EF74E789E7204840EC14AB0661A84A40EF74E789E7204840958098840BA74A40DE04DF347D1C4840958098840BA74A40
48662	47609	48.370154999999997	48.399636999999998	53.394069000000002	53.363016000000002	Вокзальная	0103000020E61000000100000005000000B6B9313D612F48405EF6EB4E77AE4A40B6B9313D612F484008AF5DDA70B24A40C2A2224E2733484008AF5DDA70B24A40C2A2224E273348405EF6EB4E77AE4A40B6B9313D612F48405EF6EB4E77AE4A40
47960	55871	48.002761999999997	48.0428	53.394970999999998	53.366573000000002	Ленинская	0103000020E61000000100000005000000F5D555815A0048405E4C33DDEBAE4A40F5D555815A00484028EFE3688EB24A4068226C787A05484028EFE3688EB24A4068226C787A0548405E4C33DDEBAE4A40F5D555815A0048405E4C33DDEBAE4A40
48424	24139	48.115141000000001	48.134014999999998	53.455575000000003	53.440441999999997	Советская	0103000020E61000000100000005000000E1B6B6F0BC0E484075E4486760B84A40E1B6B6F0BC0E484007F0164850BA4A4033164D672711484007F0164850BA4A4033164D672711484075E4486760B84A40E1B6B6F0BC0E484075E4486760B84A40
48156	23179	48.574323999999997	48.612341000000001	53.218286999999997	53.205156000000002	Школьная 	0103000020E6100000010000000500000069A7E67283494840024A438D429A4A4069A7E672834948402B1213D4F09B4A40FE7F9C30614E48402B1213D4F09B4A40FE7F9C30614E4840024A438D429A4A4069A7E67283494840024A438D429A4A40
48248	24038	48.327314000000001	48.375554000000001	53.241152999999997	53.224632999999997	Клубная	0103000020E61000000100000005000000F0C2D66CE52948401A4D2EC6C09C4A40F0C2D66CE5294840882AFC19DE9E4A40E5F0492712304840882AFC19DE9E4A40E5F04927123048401A4D2EC6C09C4A40F0C2D66CE52948401A4D2EC6C09C4A40
48299	4304	48.990566999999999	49.031342000000002	53.249591000000002	53.231591999999999	Советская	0103000020E6100000010000000500000098BF42E6CA7E4840F30181CEA49D4A4098BF42E6CA7E48401F300F99F29F4A40E17EC003038448401F300F99F29F4A40E17EC00303844840F30181CEA49D4A4098BF42E6CA7E4840F30181CEA49D4A40
48683	24333	48.840691999999997	48.864049000000001	53.258113999999999	53.246578999999997	Советская	0103000020E610000001000000050000002101A3CB9B6B4840B07092E68F9F4A402101A3CB9B6B4840E3512AE109A14A401D925A28996E4840E3512AE109A14A401D925A28996E4840B07092E68F9F4A402101A3CB9B6B4840B07092E68F9F4A40
48612	55895	48.503061000000002	48.515349000000001	53.286923000000002	53.282251000000002	Солнечная	0103000020E610000001000000050000005072874D64404840B421FFCC20A44A405072874D6440484030BC92E4B9A44A405E83BEF4F641484030BC92E4B9A44A405E83BEF4F6414840B421FFCC20A44A405072874D64404840B421FFCC20A44A40
48250	55895	48.503061000000002	48.515349000000001	53.286923000000002	53.282251000000002	Советская	0103000020E610000001000000050000005072874D64404840B421FFCC20A44A405072874D6440484030BC92E4B9A44A405E83BEF4F641484030BC92E4B9A44A405E83BEF4F6414840B421FFCC20A44A405072874D64404840B421FFCC20A44A40
48511	23747	48.237589999999997	48.285677	53.134447999999999	53.128678000000001	Центральная	0103000020E61000000100000005000000A6ED5F59691E48407BDB4C8578904A40A6ED5F59691E48409D81919735914A40151C5E10912448409D81919735914A40151C5E10912448407BDB4C8578904A40A6ED5F59691E48407BDB4C8578904A40
48710	55960	48.657822000000003	48.667973000000003	53.211405999999997	53.202593999999998	Рабочая	0103000020E610000001000000050000006F4BE48233544840D32EA699EE994A406F4BE48233544840CE16105A0F9B4A4036CEA62380554840CE16105A0F9B4A4036CEA62380554840D32EA699EE994A406F4BE48233544840D32EA699EE994A40
48395	23919	48.136701000000002	48.156032000000003	53.176226	53.171216999999999	Кооперативная	0103000020E610000001000000050000004E2A1A6B7F11484076C24B70EA954A404E2A1A6B7F1148403A5AD5928E964A40939048DBF81348403A5AD5928E964A40939048DBF813484076C24B70EA954A404E2A1A6B7F11484076C24B70EA954A40
48510	23839	48.337726000000004	48.350588999999999	53.188502999999997	53.182032999999997	Солнечная	0103000020E610000001000000050000002481069B3A2B484079E57ADB4C974A402481069B3A2B48405419C6DD20984A402EABB019E02C48405419C6DD20984A402EABB019E02C484079E57ADB4C974A402481069B3A2B484079E57ADB4C974A40
48245	23732	48.232577999999997	48.273989999999998	53.094965000000002	53.077295999999997	Юбилейная	0103000020E6100000010000000500000071E2AB1DC51D4840490ED8D5E4894A4071E2AB1DC51D4840E0A128D0278C4A402CB7B41A12234840E0A128D0278C4A402CB7B41A12234840490ED8D5E4894A4071E2AB1DC51D4840490ED8D5E4894A40
48561	23355	48.482165999999999	48.496521000000001	53.212187999999998	53.204098999999999	Центральная	0103000020E610000001000000050000001F9F909DB73D4840BA1281EA1F9A4A401F9F909DB73D4840444DF4F9289B4A407C6308008E3F4840444DF4F9289B4A407C6308008E3F4840BA1281EA1F9A4A401F9F909DB73D4840BA1281EA1F9A4A40
48312	55904	49.096218	49.167535000000001	53.275644	53.255969999999998	ЖБК	0103000020E61000000100000005000000ADA415DF508C4840E960FD9FC3A04A40ADA415DF508C484058AB764D48A34A40BAF770C97195484058AB764D48A34A40BAF770C971954840E960FD9FC3A04A40ADA415DF508C4840E960FD9FC3A04A40
48298	23570	48.508172000000002	48.538724000000002	53.251837999999999	53.240485	переулок Северный	0103000020E61000000100000005000000185FB4C70B414840DB166536C89E4A40185FB4C70B414840EDF1423A3CA04A4000C974E8F4444840EDF1423A3CA04A4000C974E8F4444840DB166536C89E4A40185FB4C70B414840DB166536C89E4A40
48503	20536	48.393771000000001	48.432254999999998	53.058726	53.031050999999998	Калиновская	0103000020E610000001000000050000007E8E8F166732484009C1AA7AF9834A407E8E8F166732484063B6645584874A402844C0215437484063B6645584874A402844C0215437484009C1AA7AF9834A407E8E8F166732484009C1AA7AF9834A40
48506	23504	48.436836999999997	48.477997999999999	53.27881	53.268348000000003	Школьная	0103000020E6100000010000000500000064575A46EA37484038F92D3A59A24A4064575A46EA3748401DE6CB0BB0A34A40D6C6D8092F3D48401DE6CB0BB0A34A40D6C6D8092F3D484038F92D3A59A24A4064575A46EA37484038F92D3A59A24A40
48155	23448	48.213498000000001	48.279801999999997	53.245911	53.21022	Почтовая	0103000020E6100000010000000500000076E107E7531B4840897B2C7DE89A4A4076E107E7531B4840035DFB027A9F4A407DAD4B8DD0234840035DFB027A9F4A407DAD4B8DD0234840897B2C7DE89A4A4076E107E7531B4840897B2C7DE89A4A40
48247	23447	48.159644	48.181221000000001	53.294119999999999	53.271540999999999	Советская	0103000020E610000001000000050000005680EF366F144840F64201DBC1A24A405680EF366F144840BD8C62B9A5A54A40992CEE3F32174840BD8C62B9A5A54A40992CEE3F32174840F64201DBC1A24A405680EF366F144840F64201DBC1A24A40
48676	23360	48.311673999999996	48.338389999999997	53.311878	53.303597000000003	Лесная	0103000020E61000000100000005000000BA8102EFE4274840F5143944DCA64A40BA8102EFE4274840C32B499EEBA74A408FA50F5D502B4840C32B499EEBA74A408FA50F5D502B4840F5143944DCA64A40BA8102EFE4274840F5143944DCA64A40
48437	24317	48.716921999999997	48.743026999999998	53.318043000000003	53.307805000000002	Школьная	0103000020E6100000010000000500000036E49F19C45B4840CC457C2766A74A4036E49F19C45B484062DC0DA2B5A84A40C2853C821B5F484062DC0DA2B5A84A40C2853C821B5F4840CC457C2766A74A4036E49F19C45B4840CC457C2766A74A40
48678	23925	48.348416	48.361288000000002	53.204146999999999	53.199832000000001	Пригородная	0103000020E610000001000000050000009AB33EE5982C4840DE58501894994A409AB33EE5982C4840CB49287D219A4A40F83768AF3E2E4840CB49287D219A4A40F83768AF3E2E4840DE58501894994A409AB33EE5982C4840DE58501894994A40
48306	55894	48.492865000000002	48.498263999999999	53.291052000000001	53.288361000000002	Центральная	0103000020E61000000100000005000000E92B4833163F48408F386403E9A44A40E92B4833163F4840BBB7223141A54A401763601DC73F4840BBB7223141A54A401763601DC73F48408F386403E9A44A40E92B4833163F48408F386403E9A44A40
47792	23276	48.401111	48.434311999999998	53.200625000000002	53.186247000000002	Советская	0103000020E610000001000000050000006E88F19A5733484033FD12F1D6974A406E88F19A5733484048E17A14AE994A4053211E899737484048E17A14AE994A4053211E899737484033FD12F1D6974A406E88F19A5733484033FD12F1D6974A40
47830	23091	49.026769000000002	49.064427000000002	53.621896	53.599310000000003	Советская	0103000020E61000000100000005000000F8C5A52A6D8348403815A930B6CC4A40F8C5A52A6D834840B1C1C2499ACF4A405DFDD8243F884840B1C1C2499ACF4A405DFDD8243F8848403815A930B6CC4A40F8C5A52A6D8348403815A930B6CC4A40
47818	23087	49.074568999999997	49.105874999999997	53.829160000000002	53.801138999999999	Полевая	0103000020E61000000100000005000000D0251C7A8B8948406B4606B98BE64A40D0251C7A8B894840609335EA21EA4A40643BDF4F8D8D4840609335EA21EA4A40643BDF4F8D8D48406B4606B98BE64A40D0251C7A8B8948406B4606B98BE64A40
47699	23007	49.658518999999998	49.719648999999997	53.657801999999997	53.626921000000003	Ленина	0103000020E61000000100000005000000B665C0594AD448407B1684F23ED04A40B665C0594AD44840279F1EDB32D44A40AFCC5B751DDC4840279F1EDB32D44A40AFCC5B751DDC48407B1684F23ED04A40B665C0594AD448407B1684F23ED04A40
47899	55864	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	Куйбышева	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
48514	22820	49.439957999999997	49.469720000000002	53.822788000000003	53.792203999999998	Центральная	0103000020E6100000010000000500000089CE328B50B8484054E1CFF066E54A4089CE328B50B8484048C5FF1D51E94A407923F3C81FBC484048C5FF1D51E94A407923F3C81FBC484054E1CFF066E54A4089CE328B50B8484054E1CFF066E54A40
47696	22820	49.439957999999997	49.469720000000002	53.822788000000003	53.792203999999998	Менжинского	0103000020E6100000010000000500000089CE328B50B8484054E1CFF066E54A4089CE328B50B8484048C5FF1D51E94A407923F3C81FBC484048C5FF1D51E94A407923F3C81FBC484054E1CFF066E54A4089CE328B50B8484054E1CFF066E54A40
47697	4152	49.510987999999998	49.548205000000003	53.295051000000001	53.268089000000003	Куйбышева,	0103000020E610000001000000050000000053060E68C148406CB587BD50A24A400053060E68C1484078D32D3BC4A54A407940D9942BC6484078D32D3BC4A54A407940D9942BC648406CB587BD50A24A400053060E68C148406CB587BD50A24A40
47826	50001	49.869289999999999	49.919749000000003	53.447870000000002	53.430925000000002	Нефтянников	0103000020E61000000100000005000000B35E0CE544EF4840B003E78C28B74A40B35E0CE544EF4840056EDDCD53B94A40ADC3D155BAF54840056EDDCD53B94A40ADC3D155BAF54840B003E78C28B74A40B35E0CE544EF4840B003E78C28B74A40
48296	2572	49.489339000000001	49.514321000000002	53.184666	53.170698999999999	Овражная	0103000020E6100000010000000500000024D40CA9A2BE4840DE3AFF76D9954A4024D40CA9A2BE48407157AF22A3974A40B1524145D5C148407157AF22A3974A40B1524145D5C14840DE3AFF76D9954A4024D40CA9A2BE4840DE3AFF76D9954A40
48017	55878	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	Советская	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
47845	24320	49.840868	49.881849000000003	53.495384000000001	53.477863999999997	Юности	0103000020E6100000010000000500000060200890A1EB4840C6F7C5A52ABD4A4060200890A1EB4840187B2FBE68BF4A405281936DE0F04840187B2FBE68BF4A405281936DE0F04840C6F7C5A52ABD4A4060200890A1EB4840C6F7C5A52ABD4A40
47844	24320	49.840868	49.881849000000003	53.495384000000001	53.477863999999997	Труда	0103000020E6100000010000000500000060200890A1EB4840C6F7C5A52ABD4A4060200890A1EB4840187B2FBE68BF4A405281936DE0F04840187B2FBE68BF4A405281936DE0F04840C6F7C5A52ABD4A4060200890A1EB4840C6F7C5A52ABD4A40
47847	24320	49.840868	49.881849000000003	53.495384000000001	53.477863999999997	Звездная	0103000020E6100000010000000500000060200890A1EB4840C6F7C5A52ABD4A4060200890A1EB4840187B2FBE68BF4A405281936DE0F04840187B2FBE68BF4A405281936DE0F04840C6F7C5A52ABD4A4060200890A1EB4840C6F7C5A52ABD4A40
47885	22414	49.098768999999997	49.166941999999999	53.524782000000002	53.507579	Советская	0103000020E61000000100000005000000E76D6C76A48C484075914259F8C04A40E76D6C76A48C4840C6C37B0E2CC34A40172AFF5A5E954840C6C37B0E2CC34A40172AFF5A5E95484075914259F8C04A40E76D6C76A48C484075914259F8C04A40
47819	22414	49.098768999999997	49.166941999999999	53.524782000000002	53.507579	Набережная	0103000020E61000000100000005000000E76D6C76A48C484075914259F8C04A40E76D6C76A48C4840C6C37B0E2CC34A40172AFF5A5E954840C6C37B0E2CC34A40172AFF5A5E95484075914259F8C04A40E76D6C76A48C484075914259F8C04A40
48509	22298	49.796374	49.834992999999997	53.641554999999997	53.623972999999999	Школьная	0103000020E610000001000000050000003EB14E95EFE54840234BE658DECF4A403EB14E95EFE54840EACA67791ED24A40C8B1F50CE1EA4840EACA67791ED24A40C8B1F50CE1EA4840234BE658DECF4A403EB14E95EFE54840234BE658DECF4A40
47817	22298	49.796374	49.834992999999997	53.641554999999997	53.623972999999999	Дружбы	0103000020E610000001000000050000003EB14E95EFE54840234BE658DECF4A403EB14E95EFE54840EACA67791ED24A40C8B1F50CE1EA4840EACA67791ED24A40C8B1F50CE1EA4840234BE658DECF4A403EB14E95EFE54840234BE658DECF4A40
48560	22384	49.631748999999999	49.653407000000001	53.199055000000001	53.180526999999998	Лазарева	0103000020E61000000100000005000000EE23B726DDD04840C2853C821B974A40EE23B726DDD048407A8D5DA27A994A401EFD2FD7A2D348407A8D5DA27A994A401EFD2FD7A2D34840C2853C821B974A40EE23B726DDD04840C2853C821B974A40
48161	52181	49.446938000000003	49.462335000000003	53.615876	53.601489999999998	Советская	0103000020E610000001000000050000007AABAE4335B948407E6FD39FFDCC4A407AABAE4335B9484016325706D5CE4A40E96514CB2DBB484016325706D5CE4A40E96514CB2DBB48407E6FD39FFDCC4A407AABAE4335B948407E6FD39FFDCC4A40
48674	52181	49.446938000000003	49.462335000000003	53.615876	53.601489999999998	Садовая	0103000020E610000001000000050000007AABAE4335B948407E6FD39FFDCC4A407AABAE4335B9484016325706D5CE4A40E96514CB2DBB484016325706D5CE4A40E96514CB2DBB48407E6FD39FFDCC4A407AABAE4335B948407E6FD39FFDCC4A40
48297	22218	49.899797	49.930897000000002	53.815351	53.793118999999997	Центральная	0103000020E61000000100000005000000FB04508C2CF34840096B63EC84E54A40FB04508C2CF3484065E1EB6B5DE84A40E67805A227F7484065E1EB6B5DE84A40E67805A227F74840096B63EC84E54A40FB04508C2CF34840096B63EC84E54A40
47790	22161	49.413862000000002	49.459235999999997	53.692940999999998	53.660063999999998	Красноармейская	0103000020E610000001000000050000005187156EF9B448402BA226FA7CD44A405187156EF9B448405D876A4AB2D84A40AB92C83EC8BA48405D876A4AB2D84A40AB92C83EC8BA48402BA226FA7CD44A405187156EF9B448402BA226FA7CD44A40
48302	22112	49.709533999999998	49.747182000000002	53.771656999999998	53.737703000000003	Школьная	0103000020E6100000010000000500000035B39602D2DA48409F94490D6DDE4A4035B39602D2DA48405F5D15A8C5E24A407714E7A8A3DF48405F5D15A8C5E24A407714E7A8A3DF48409F94490D6DDE4A4035B39602D2DA48409F94490D6DDE4A40
47789	22112	49.709533999999998	49.747182000000002	53.771656999999998	53.737703000000003	Молодежная	0103000020E6100000010000000500000035B39602D2DA48409F94490D6DDE4A4035B39602D2DA48405F5D15A8C5E24A407714E7A8A3DF48405F5D15A8C5E24A407714E7A8A3DF48409F94490D6DDE4A4035B39602D2DA48409F94490D6DDE4A40
47816	21872	49.055065999999997	49.093128	53.686067999999999	53.664183000000001	Злобина	0103000020E610000001000000050000008E8F16670C87484093C7D3F203D54A408E8F16670C874840836A8313D1D74A40C32B499EEB8B4840836A8313D1D74A40C32B499EEB8B484093C7D3F203D54A408E8F16670C87484093C7D3F203D54A40
48387	21720	49.368462000000001	49.391889999999997	53.753442999999997	53.739736999999998	Советская	0103000020E61000000100000005000000CDE847C329AF48401152B7B3AFDE4A40CDE847C329AF48403733FAD170E04A4091D0967329B248403733FAD170E04A4091D0967329B248401152B7B3AFDE4A40CDE847C329AF48401152B7B3AFDE4A40
48180	22296	49.785153999999999	49.824948999999997	53.862355999999998	53.845626000000003	Советская	0103000020E610000001000000050000006B2920ED7FE44840DB5207793DEC4A406B2920ED7FE4484033C170AE61EE4A4017EFC7ED97E9484033C170AE61EE4A4017EFC7ED97E94840DB5207793DEC4A406B2920ED7FE44840DB5207793DEC4A40
47892	50000	49.747793000000001	49.849626000000001	53.449151000000001	53.422271000000002	Первомайская	0103000020E61000000100000005000000C09657AEB7DF48404D86E3F90CB64A40C09657AEB7DF48409CFBABC77DB94A4068EA758BC0EC48409CFBABC77DB94A4068EA758BC0EC48404D86E3F90CB64A40C09657AEB7DF48404D86E3F90CB64A40
47694	991	49.288386000000003	49.321128999999999	53.375931999999999	53.346457000000001	Центральная	0103000020E61000000100000005000000E84F1BD5E9A44840323CF6B358AC4A40E84F1BD5E9A448408BC22E8A1EB04A400A664CC11AA948408BC22E8A1EB04A400A664CC11AA94840323CF6B358AC4A40E84F1BD5E9A44840323CF6B358AC4A40
47693	21821	49.266717999999997	49.321956	53.656520999999998	53.629019999999997	Победы	0103000020E6100000010000000500000094A0BFD023A24840D44334BA83D04A4094A0BFD023A24840901150E108D44A402060ADDA35A94840901150E108D44A402060ADDA35A94840D44334BA83D04A4094A0BFD023A24840D44334BA83D04A40
48391	22947	49.254348999999998	49.286498999999999	53.783538999999998	53.768911000000003	Школьная	0103000020E6100000010000000500000099620E828EA048407044F7AC6BE24A4099620E828EA04840FD1186014BE44A4019ABCDFFABA44840FD1186014BE44A4019ABCDFFABA448407044F7AC6BE24A4099620E828EA048407044F7AC6BE24A40
47814	21935	49.153917	49.195903999999999	53.738097000000003	53.718561999999999	Мира	0103000020E6100000010000000500000033A6608DB3934840FD12F1D6F9DB4A4033A6608DB39348404B2366F679DE4A40EA93DC61139948404B2366F679DE4A40EA93DC6113994840FD12F1D6F9DB4A4033A6608DB3934840FD12F1D6F9DB4A40
47787	21719	49.491567000000003	49.540489000000001	53.71902	53.698405000000001	Кооперативная	0103000020E610000001000000050000007C65DEAAEBBE4840732EC55565D94A407C65DEAAEBBE4840C095ECD808DC4A40836C59BE2EC54840C095ECD808DC4A40836C59BE2EC54840732EC55565D94A407C65DEAAEBBE4840732EC55565D94A40
48396	22015	49.391710000000003	49.418129	53.335026999999997	53.320791	Молодежная	0103000020E6100000010000000500000012C2A38D23B24840F2ECF2AD0FA94A4012C2A38D23B2484074232C2AE2AA4A402D41464085B5484074232C2AE2AA4A402D41464085B54840F2ECF2AD0FA94A4012C2A38D23B24840F2ECF2AD0FA94A40
48330	55907	49.287298999999997	49.313673000000001	53.273721999999999	53.251493000000004	Коммунальная	0103000020E610000001000000050000003596B036C6A44840231631EC30A04A403596B036C6A448400D198F5209A34A40B151D66F26A848400D198F5209A34A40B151D66F26A84840231631EC30A04A403596B036C6A44840231631EC30A04A40
48388	22812	49.548906000000002	49.566853999999999	53.250038000000004	53.237434	Советская	0103000020E61000000100000005000000024A438D42C64840AF7AC03C649E4A40024A438D42C64840EE60C43E01A04A40ABCDFFAB8EC84840EE60C43E01A04A40ABCDFFAB8EC84840AF7AC03C649E4A40024A438D42C64840AF7AC03C649E4A40
48244	21441	49.623384999999999	49.644441999999998	53.409357999999997	53.390503000000002	Бахиловская	0103000020E6100000010000000500000092E86514CBCF4840B5FE9600FCB14A4092E86514CBCF4840902DCBD765B44A409C1551137DD24840902DCBD765B44A409C1551137DD24840B5FE9600FCB14A4092E86514CBCF4840B5FE9600FCB14A40
48533	47940	49.458373999999999	49.486006000000003	53.366486999999999	53.342773999999999	Центральная	0103000020E6100000010000000500000019ABCDFFABBA4840A5F5B704E0AB4A4019ABCDFFABBA48405FB4C70BE9AE4A4074D4D17135BE48405FB4C70BE9AE4A4074D4D17135BE4840A5F5B704E0AB4A4019ABCDFFABBA4840A5F5B704E0AB4A40
77210	47940	49.458373999999999	49.486006000000003	53.366486999999999	53.342773999999999	Фабричная	0103000020E6100000010000000500000019ABCDFFABBA4840A5F5B704E0AB4A4019ABCDFFABBA48405FB4C70BE9AE4A4074D4D17135BE48405FB4C70BE9AE4A4074D4D17135BE4840A5F5B704E0AB4A4019ABCDFFABBA4840A5F5B704E0AB4A40
47919	55866	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	 Школьная	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
47761	17858	50.761335000000003	50.781700000000001	53.721961	53.693004999999999	Новостроевская	0103000020E610000001000000050000006C26DF6C73614940747B4963B4D84A406C26DF6C7361494065FED13769DC4A4040A4DFBE0E64494065FED13769DC4A4040A4DFBE0E644940747B4963B4D84A406C26DF6C73614940747B4963B4D84A40
48418	17371	50.896737999999999	50.937342000000001	53.890059000000001	53.865186000000001	Советская	0103000020E610000001000000050000004C8A8F4FC8724940817A336ABEEE4A404C8A8F4FC872494057410C74EDF14A40689599D2FA77494057410C74EDF14A40689599D2FA774940817A336ABEEE4A404C8A8F4FC8724940817A336ABEEE4A40
48410	16666	51.041116000000002	51.079850999999998	54.018051	54.006622999999998	Полевая	0103000020E61000000100000005000000D2AB014A438549406133C005D9004B40D2AB014A438549407E54C37E4F024B40C5C6BC8E388A49407E54C37E4F024B40C5C6BC8E388A49406133C005D9004B40D2AB014A438549406133C005D9004B40
47670	16794	51.191097999999997	51.253467999999998	53.909937999999997	53.883288	Школьная	0103000020E610000001000000050000005E2A36E6759849408179C8940FF14A405E2A36E6759849409EB12FD978F44A40904AB1A371A049409EB12FD978F44A40904AB1A371A049408179C8940FF14A405E2A36E6759849408179C8940FF14A40
47760	16794	51.191097999999997	51.253467999999998	53.909937999999997	53.883288	Суворова	0103000020E610000001000000050000005E2A36E6759849408179C8940FF14A405E2A36E6759849409EB12FD978F44A40904AB1A371A049409EB12FD978F44A40904AB1A371A049408179C8940FF14A405E2A36E6759849408179C8940FF14A40
47902	16794	51.191097999999997	51.253467999999998	53.909937999999997	53.883288	Пушкина	0103000020E610000001000000050000005E2A36E6759849408179C8940FF14A405E2A36E6759849409EB12FD978F44A40904AB1A371A049409EB12FD978F44A40904AB1A371A049408179C8940FF14A405E2A36E6759849408179C8940FF14A40
47671	16794	51.191097999999997	51.253467999999998	53.909937999999997	53.883288	Мира	0103000020E610000001000000050000005E2A36E6759849408179C8940FF14A405E2A36E6759849409EB12FD978F44A40904AB1A371A049409EB12FD978F44A40904AB1A371A049408179C8940FF14A405E2A36E6759849408179C8940FF14A40
47904	16971	51.172987999999997	51.230238	53.933052000000004	53.907206000000002	Сквозная	0103000020E61000000100000005000000DB4C857824964940145E82531FF44A40DB4C857824964940D4BB783F6EF74A40F2255470789D4940D4BB783F6EF74A40F2255470789D4940145E82531FF44A40DB4C857824964940145E82531FF44A40
47905	16971	51.172987999999997	51.230238	53.933052000000004	53.907206000000002	Первомайская	0103000020E61000000100000005000000DB4C857824964940145E82531FF44A40DB4C857824964940D4BB783F6EF74A40F2255470789D4940D4BB783F6EF74A40F2255470789D4940145E82531FF44A40DB4C857824964940145E82531FF44A40
48582	17567	51.432799000000003	51.473295	53.910117999999997	53.893047000000003	Центральная	0103000020E61000000100000005000000EA5E27F565B749403D65355D4FF24A40EA5E27F565B749401EC022BF7EF44A401F2E39EE94BC49401EC022BF7EF44A401F2E39EE94BC49403D65355D4FF24A40EA5E27F565B749403D65355D4FF24A40
48621	16359	50.910212999999999	50.945462999999997	54.141803000000003	54.129623000000002	Центральная	0103000020E6100000010000000500000070B20DDC817449409BE7887C97104B4070B20DDC81744940C3BCC79926124B40FD497CEE04794940C3BCC79926124B40FD497CEE047949409BE7887C97104B4070B20DDC817449409BE7887C97104B40
48461	17413	50.829149000000001	50.875754000000001	54.052993999999998	54.004564000000002	Центральная	0103000020E610000001000000050000006C41EF8D216A4940965E9B8D95004B406C41EF8D216A49402E71E481C8064B40ACAB02B5187049402E71E481C8064B40ACAB02B518704940965E9B8D95004B406C41EF8D216A4940965E9B8D95004B40
48294	17413	50.829149000000001	50.875754000000001	54.052993999999998	54.004564000000002	Галактионовская	0103000020E610000001000000050000006C41EF8D216A4940965E9B8D95004B406C41EF8D216A49402E71E481C8064B40ACAB02B5187049402E71E481C8064B40ACAB02B518704940965E9B8D95004B406C41EF8D216A4940965E9B8D95004B40
48193	17667	51.410305000000001	51.464905000000002	53.735050000000001	53.725909000000001	Рабочая	0103000020E610000001000000050000005131CEDF84B44940A06F0B96EADC4A405131CEDF84B4494060764F1E16DE4A409A5FCD0182BB494060764F1E16DE4A409A5FCD0182BB4940A06F0B96EADC4A405131CEDF84B44940A06F0B96EADC4A40
47764	17117	51.242617000000003	51.270986000000001	53.930988999999997	53.909624999999998	Советская	0103000020E61000000100000005000000113AE8120E9F4940DF4F8D976EF44A40113AE8120E9F4940C6F7C5A52AF74A4041D653ABAFA24940C6F7C5A52AF74A4041D653ABAFA24940DF4F8D976EF44A40113AE8120E9F4940DF4F8D976EF44A40
47842	17117	51.242617000000003	51.270986000000001	53.930988999999997	53.909624999999998	Вокзальная	0103000020E61000000100000005000000113AE8120E9F4940DF4F8D976EF44A40113AE8120E9F4940C6F7C5A52AF74A4041D653ABAFA24940C6F7C5A52AF74A4041D653ABAFA24940DF4F8D976EF44A40113AE8120E9F4940DF4F8D976EF44A40
47903	16462	51.132573000000001	51.186785999999998	53.959617000000001	53.930284	Советская	0103000020E6100000010000000500000093AAED26F8904940FCFECD8B13F74A4093AAED26F8904940C3D7D7BAD4FA4A40E2AC889AE8974940C3D7D7BAD4FA4A40E2AC889AE8974940FCFECD8B13F74A4093AAED26F8904940FCFECD8B13F74A40
47724	16462	51.132573000000001	51.186785999999998	53.959617000000001	53.930284	Ленина	0103000020E6100000010000000500000093AAED26F8904940FCFECD8B13F74A4093AAED26F8904940C3D7D7BAD4FA4A40E2AC889AE8974940C3D7D7BAD4FA4A40E2AC889AE8974940FCFECD8B13F74A4093AAED26F8904940FCFECD8B13F74A40
47703	50011	51.146138000000001	51.176932000000001	53.903843000000002	53.884417999999997	Полевая	0103000020E61000000100000005000000F75965A6B492494032FFE89B34F14A40F75965A6B4924940F9DB9E20B1F34A40D5CE30B5A5964940F9DB9E20B1F34A40D5CE30B5A596494032FFE89B34F14A40F75965A6B492494032FFE89B34F14A40
48542	17074	50.991475000000001	51.030084000000002	53.882390999999998	53.862535999999999	Центральная	0103000020E610000001000000050000009BE61DA7E87E4940B3CF639467EE4A409BE61DA7E87E494072A43330F2F04A400211E2CAD983494072A43330F2F04A400211E2CAD9834940B3CF639467EE4A409BE61DA7E87E4940B3CF639467EE4A40
48332	17261	50.691006000000002	50.730496000000002	53.833182999999998	53.818041000000001	Кооперативная	0103000020E610000001000000050000007EAB75E272584940C1E44691B5E84A407EAB75E272584940A54A94BDA5EA4A40EEED96E4805D4940A54A94BDA5EA4A40EEED96E4805D4940C1E44691B5E84A407EAB75E272584940C1E44691B5E84A40
48620	16270	51.027380000000001	51.057715999999999	54.124504999999999	54.109389999999998	Центральная	0103000020E6100000010000000500000041481630818349403541D47D000E4B4041481630818349402098A3C7EF0F4B405C3AE63C638749402098A3C7EF0F4B405C3AE63C638749403541D47D000E4B4041481630818349403541D47D000E4B40
48138	17720	51.216763	51.252301000000003	54.216524999999997	54.202356000000002	Центральная	0103000020E61000000100000005000000CEFDD5E3BE9B49401F1329CDE6194B40CEFDD5E3BE9B494019E25817B71B4B40C2DF2F664BA0494019E25817B71B4B40C2DF2F664BA049401F1329CDE6194B40CEFDD5E3BE9B49401F1329CDE6194B40
48195	17683	50.920831	50.940334	54.040649999999999	54.020696000000001	Школьная	0103000020E610000001000000050000004D124BCADD7549403A94A12AA6024B404D124BCADD7549408C4AEA0434054B408FA850DD5C7849408C4AEA0434054B408FA850DD5C7849403A94A12AA6024B404D124BCADD7549403A94A12AA6024B40
48224	50012	50.704768000000001	50.762746	53.980034000000003	53.957954000000001	Специалистов	0103000020E6100000010000000500000038A27BD6355A49404489963C9EFA4A4038A27BD6355A4940EA7B0DC171FD4A40D19332A9A1614940EA7B0DC171FD4A40D19332A9A16149404489963C9EFA4A4038A27BD6355A49404489963C9EFA4A40
47702	50010	51.276015999999998	51.309747999999999	53.843389000000002	53.820545000000003	Каськова	0103000020E610000001000000050000001C96067E54A34940BBF2599E07E94A401C96067E54A349403067B62BF4EB4A402E008DD2A5A749403067B62BF4EB4A402E008DD2A5A74940BBF2599E07E94A401C96067E54A34940BBF2599E07E94A40
48216	17358	50.831969999999998	50.859647000000002	53.835690999999997	53.815229000000002	Мамаева	0103000020E6100000010000000500000066A032FE7D6A49401AE0826C59E84A4066A032FE7D6A4940E04735ECF7EA4A40618DB3E9086E4940E04735ECF7EA4A40618DB3E9086E49401AE0826C59E84A4066A032FE7D6A49401AE0826C59E84A40
48417	17358	50.831969999999998	50.859647000000002	53.835690999999997	53.815229000000002	Кольцова	0103000020E6100000010000000500000066A032FE7D6A49401AE0826C59E84A4066A032FE7D6A4940E04735ECF7EA4A40618DB3E9086E4940E04735ECF7EA4A40618DB3E9086E49401AE0826C59E84A4066A032FE7D6A49401AE0826C59E84A40
48136	16782	51.163573999999997	51.182051999999999	53.690919999999998	53.676910999999997	пер. Почтовый	0103000020E61000000100000005000000EA3C2AFEEF944940BDA60705A5D64A40EA3C2AFEEF9449407F130A1170D84A40F015DD7A4D9749407F130A1170D84A40F015DD7A4D974940BDA60705A5D64A40EA3C2AFEEF944940BDA60705A5D64A40
48122	49998	51.040199000000001	51.088797999999997	53.737127000000001	53.711837000000003	Советская	0103000020E610000001000000050000007C2AA73D25854940988A8D791DDB4A407C2AA73D25854940D2FF722D5ADE4A40A0F99CBB5D8B4940D2FF722D5ADE4A40A0F99CBB5D8B4940988A8D791DDB4A407C2AA73D25854940988A8D791DDB4A40
48365	16577	51.282062000000003	51.310825999999999	54.028328000000002	54.008586000000001	Юбилейная	0103000020E61000000100000005000000E1B88C9B1AA449400B9A965819014B40E1B88C9B1AA44940D2C77C40A0034B408D5F7825C9A74940D2C77C40A0034B408D5F7825C9A749400B9A965819014B40E1B88C9B1AA449400B9A965819014B40
48625	17267	50.738455000000002	50.760382999999997	53.792592999999997	53.776994999999999	Центральная	0103000020E61000000100000005000000AA4885B1855E4940E813799274E34A40AA4885B1855E4940EE04FBAF73E54A4099B7EA3A54614940EE04FBAF73E54A4099B7EA3A54614940E813799274E34A40AA4885B1855E4940E813799274E34A40
48135	16675	51.311993999999999	51.326932999999997	53.959167000000001	53.946582999999997	Мичурина	0103000020E610000001000000050000002C465D6BEFA749408BF9B9A129F94A402C465D6BEFA749408333F8FBC5FA4A40D87DC7F0D8A949408333F8FBC5FA4A40D87DC7F0D8A949408BF9B9A129F94A402C465D6BEFA749408BF9B9A129F94A40
48453	47080	48.525787999999999	48.555145000000003	52.821432999999999	52.797013999999997	Юбилейная	0103000020E610000001000000050000008B506C054D434840213A048E04664A408B506C054D434840766D6FB724694A40DBC4C9FD0E474840766D6FB724694A40DBC4C9FD0E474840213A048E04664A408B506C054D434840213A048E04664A40
48361	47080	48.525787999999999	48.555145000000003	52.821432999999999	52.797013999999997	Первомайская	0103000020E610000001000000050000008B506C054D434840213A048E04664A408B506C054D434840766D6FB724694A40DBC4C9FD0E474840766D6FB724694A40DBC4C9FD0E474840213A048E04664A408B506C054D434840213A048E04664A40
48386	47080	48.525787999999999	48.555145000000003	52.821432999999999	52.797013999999997	Интернациональная	0103000020E610000001000000050000008B506C054D434840213A048E04664A408B506C054D434840766D6FB724694A40DBC4C9FD0E474840766D6FB724694A40DBC4C9FD0E474840213A048E04664A408B506C054D434840213A048E04664A40
48501	20776	48.670372	48.696800000000003	52.873742	52.859526000000002	Томана	0103000020E61000000100000005000000BA13ECBFCE554840E607AEF2046E4A40BA13ECBFCE554840219221C7D66F4A4029ED0DBE30594840219221C7D66F4A4029ED0DBE30594840E607AEF2046E4A40BA13ECBFCE554840E607AEF2046E4A40
48559	46817	48.823166000000001	48.845300999999999	52.963098000000002	52.951228	Школьная	0103000020E61000000100000005000000EE96E4805D6948400E85CFD6C1794A40EE96E4805D694840E86B96CB467B4A405723BBD2326C4840E86B96CB467B4A405723BBD2326C48400E85CFD6C1794A40EE96E4805D6948400E85CFD6C1794A40
48167	20975	48.569716	48.618135000000002	52.873311999999999	52.841346000000001	Школьная	0103000020E6100000010000000500000004013274EC4848406A4FC939B16B4A4004013274EC484840289A07B0C86F4A40A9C1340C1F4F4840289A07B0C86F4A40A9C1340C1F4F48406A4FC939B16B4A4004013274EC4848406A4FC939B16B4A40
47707	20975	48.569716	48.618135000000002	52.873311999999999	52.841346000000001	Строителей	0103000020E6100000010000000500000004013274EC4848406A4FC939B16B4A4004013274EC484840289A07B0C86F4A40A9C1340C1F4F4840289A07B0C86F4A40A9C1340C1F4F48406A4FC939B16B4A4004013274EC4848406A4FC939B16B4A40
48292	20975	48.569716	48.618135000000002	52.873311999999999	52.841346000000001	Специалистов	0103000020E6100000010000000500000004013274EC4848406A4FC939B16B4A4004013274EC484840289A07B0C86F4A40A9C1340C1F4F4840289A07B0C86F4A40A9C1340C1F4F48406A4FC939B16B4A4004013274EC4848406A4FC939B16B4A40
47813	20975	48.569716	48.618135000000002	52.873311999999999	52.841346000000001	Парковая	0103000020E6100000010000000500000004013274EC4848406A4FC939B16B4A4004013274EC484840289A07B0C86F4A40A9C1340C1F4F4840289A07B0C86F4A40A9C1340C1F4F48406A4FC939B16B4A4004013274EC4848406A4FC939B16B4A40
48672	20975	48.569716	48.618135000000002	52.873311999999999	52.841346000000001	Мира	0103000020E6100000010000000500000004013274EC4848406A4FC939B16B4A4004013274EC484840289A07B0C86F4A40A9C1340C1F4F4840289A07B0C86F4A40A9C1340C1F4F48406A4FC939B16B4A4004013274EC4848406A4FC939B16B4A40
48557	20969	48.735014999999997	48.769159000000002	52.803682999999999	52.786650999999999	Центральная	0103000020E61000000100000005000000E388B5F8145E4840CF2EDFFAB0644A40E388B5F8145E4840F3ACA415DF664A40483657CD73624840F3ACA415DF664A40483657CD73624840CF2EDFFAB0644A40E388B5F8145E4840CF2EDFFAB0644A40
47700	826	48.788688999999998	48.888922999999998	53.136020000000002	53.108179	Терешковой	0103000020E6100000010000000500000083DBDAC2F3644840978E39CFD88D4A4083DBDAC2F36448400CCD751A69914A40C3D4963AC87148400CCD751A69914A40C3D4963AC8714840978E39CFD88D4A4083DBDAC2F3644840978E39CFD88D4A40
48151	826	48.788688999999998	48.888922999999998	53.136020000000002	53.108179	Советская	0103000020E6100000010000000500000083DBDAC2F3644840978E39CFD88D4A4083DBDAC2F36448400CCD751A69914A40C3D4963AC87148400CCD751A69914A40C3D4963AC8714840978E39CFD88D4A4083DBDAC2F3644840978E39CFD88D4A40
47887	826	48.788688999999998	48.888922999999998	53.136020000000002	53.108179	Победы	0103000020E6100000010000000500000083DBDAC2F3644840978E39CFD88D4A4083DBDAC2F36448400CCD751A69914A40C3D4963AC87148400CCD751A69914A40C3D4963AC8714840978E39CFD88D4A4083DBDAC2F3644840978E39CFD88D4A40
47785	116	48.761361999999998	48.802782999999998	53.009946999999997	52.983432999999998	Школьная	0103000020E6100000010000000500000065355D4F746148405167EE21E17D4A4065355D4F74614840BED87BF145814A407364E597C1664840BED87BF145814A407364E597C16648405167EE21E17D4A4065355D4F746148405167EE21E17D4A40
48505	20064	48.925960000000003	48.950474999999997	53.186867999999997	53.175874999999998	Сельская	0103000020E61000000100000005000000BCB376DB857648408D976E1283964A40BCB376DB857648409F55664AEB974A403255302AA97948409F55664AEB974A403255302AA97948408D976E1283964A40BCB376DB857648408D976E1283964A40
48705	55951	48.806727000000002	48.825681000000003	52.876165999999998	52.856915999999998	Луговая	0103000020E610000001000000050000006DE690D442674840A6B5696CAF6D4A406DE690D442674840FEEE1D3526704A40DCF63DEAAF694840FEEE1D3526704A40DCF63DEAAF694840A6B5696CAF6D4A406DE690D442674840A6B5696CAF6D4A40
47786	46918	48.743315000000003	48.770353999999998	52.910598999999998	52.892625000000002	Школьная	0103000020E6100000010000000500000029D027F2245F4840C74B378941724A4029D027F2245F484099620E828E744A40E02BBAF59A62484099620E828E744A40E02BBAF59A624840C74B378941724A4029D027F2245F4840C74B378941724A40
48152	20654	48.599871999999998	48.622796999999998	52.962246	52.941943999999999	Школьная	0103000020E610000001000000050000009FE40E9BC84C4840EB54F99E91784A409FE40E9BC84C4840795A7EE02A7B4A400186E5CFB74F4840795A7EE02A7B4A400186E5CFB74F4840EB54F99E91784A409FE40E9BC84C4840EB54F99E91784A40
48680	47114	48.404372000000002	48.427764000000003	52.757083999999999	52.741145000000003	Пролетарская	0103000020E6100000010000000500000085B53176C2334840064CE0D6DD5E4A4085B53176C23348409529E620E8604A40FD3383F8C03648409529E620E8604A40FD3383F8C0364840064CE0D6DD5E4A4085B53176C2334840064CE0D6DD5E4A40
48675	20360	48.554175000000001	48.619895	53.114773	53.069716	Победы	0103000020E6100000010000000500000062A1D634EF46484004013274EC884A4062A1D634EF4648405EBBB4E1B08E4A401AFA27B8584F48405EBBB4E1B08E4A401AFA27B8584F484004013274EC884A4062A1D634EF46484004013274EC884A40
48558	20360	48.554175000000001	48.619895	53.114773	53.069716	Елизарова	0103000020E6100000010000000500000062A1D634EF46484004013274EC884A4062A1D634EF4648405EBBB4E1B08E4A401AFA27B8584F48405EBBB4E1B08E4A401AFA27B8584F484004013274EC884A4062A1D634EF46484004013274EC884A40
48779	49392	52.050085000000003	52.056750999999998	53.660043000000002	53.657690000000002	Школьная	0103000020E6100000010000000500000095826E2F69064A400074982F2FD44A4095826E2F69064A40147AFD497CD44A40F581E49D43074A40147AFD497CD44A40F581E49D43074A400074982F2FD44A4095826E2F69064A400074982F2FD44A40
48618	45536	52.282595999999998	52.310533999999997	53.797362999999997	53.781388999999997	Победы	0103000020E610000001000000050000007EFD101B2C244A40213A048E04E44A407EFD101B2C244A402D05A4FD0FE64A40E525FF93BF274A402D05A4FD0FE64A40E525FF93BF274A40213A048E04E44A407EFD101B2C244A40213A048E04E44A40
48415	16159	52.252009000000001	52.284796999999998	53.853402000000003	53.817818000000003	Советская	0103000020E610000001000000050000001AA6B6D441204A40420A9E42AEE84A401AA6B6D441204A40A62BD8463CED4A40DC7F643A74244A40A62BD8463CED4A40DC7F643A74244A40420A9E42AEE84A401AA6B6D441204A40420A9E42AEE84A40
47672	16059	51.934679000000003	51.994965000000001	53.722051999999998	53.691682999999998	Шулайкина	0103000020E6100000010000000500000006A1BC8FA3F749407E198C1189D84A4006A1BC8FA3F7494075012F336CDC4A4013D55B035BFF494075012F336CDC4A4013D55B035BFF49407E198C1189D84A4006A1BC8FA3F749407E198C1189D84A40
47843	16205	52.119543	52.137625999999997	53.703395	53.677722000000003	Советская	0103000020E610000001000000050000009DBB5D2F4D0F4A40CEE33098BFD64A409DBB5D2F4D0F4A40C095ECD808DA4A40268A90BA9D114A40C095ECD808DA4A40268A90BA9D114A40CEE33098BFD64A409DBB5D2F4D0F4A40CEE33098BFD64A40
48226	16149	52.220216999999998	52.257748999999997	53.911178999999997	53.885877999999998	Центральная	0103000020E61000000100000005000000F9821612301C4A40791F477364F14A40F9821612301C4A40A7E67283A1F44A40D1C952EBFD204A40A7E67283A1F44A40D1C952EBFD204A40791F477364F14A40F9821612301C4A40791F477364F14A40
47841	15917	52.043824000000001	52.079604000000003	53.621079000000002	53.589562000000001	Школьная	0103000020E61000000100000005000000D4635B069C054A40707B82C476CB4A40D4635B069C054A40BF9D44847FCF4A40BE50C076300A4A40BF9D44847FCF4A40BE50C076300A4A40707B82C476CB4A40D4635B069C054A40707B82C476CB4A40
48682	55936	51.793086000000002	51.814492999999999	53.830260000000003	53.805610999999999	Максима Горького	0103000020E610000001000000050000002E7590D783E549402026E1421EE74A402E7590D783E54940A796ADF545EA4A4014E97E4E41E84940A796ADF545EA4A4014E97E4E41E849402026E1421EE74A402E7590D783E549402026E1421EE74A40
48411	15878	51.675702999999999	51.702320999999998	53.711016999999998	53.694097999999997	Мира	0103000020E610000001000000050000009067976F7DD64940081C0934D8D84A409067976F7DD6494034F3E49A02DB4A40A2258FA7E5D9494034F3E49A02DB4A40A2258FA7E5D94940081C0934D8D84A409067976F7DD64940081C0934D8D84A40
47900	15863	51.675021000000001	51.711455999999998	53.624561	53.588935999999997	Центральная Усадьба	0103000020E610000001000000050000007E8E8F1667D64940F1B73D4162CB4A407E8E8F1667D64940B4AD669DF1CF4A4080457EFD10DB4940B4AD669DF1CF4A4080457EFD10DB4940F1B73D4162CB4A407E8E8F1667D64940F1B73D4162CB4A40
48220	15771	52.218169000000003	52.241605999999997	53.761502999999998	53.740493000000001	Ижедерова	0103000020E61000000100000005000000220038F6EC1B4A405EF58079C8DE4A40220038F6EC1B4A40276728EE78E14A40394206F2EC1E4A40276728EE78E14A40394206F2EC1E4A405EF58079C8DE4A40220038F6EC1B4A405EF58079C8DE4A40
47669	15632	51.787588999999997	51.823701	53.614659000000003	53.593249999999998	Куйбышевская	0103000020E610000001000000050000003CD862B7CFE449400E2DB29DEFCB4A403CD862B7CFE4494096986725ADCE4A405C57CC086FE9494096986725ADCE4A405C57CC086FE949400E2DB29DEFCB4A403CD862B7CFE449400E2DB29DEFCB4A40
48616	45409	51.694847000000003	51.715983999999999	53.536653000000001	53.524985000000001	Юбилейная	0103000020E61000000100000005000000A35C1ABFF0D84940FEF15EB532C34A40A35C1ABFF0D849407026A60BB1C44A40C93A1C5DA5DB49407026A60BB1C44A40C93A1C5DA5DB4940FEF15EB532C34A40A35C1ABFF0D84940FEF15EB532C34A40
48253	2054	52.029442000000003	52.069479999999999	53.428452	53.411366000000001	Кооперативная	0103000020E610000001000000050000007E9065C1C4034A40DA571EA4A7B44A407E9065C1C4034A40F1F3DF83D7B64A40F0DC7BB8E4084A40F1F3DF83D7B64A40F0DC7BB8E4084A40DA571EA4A7B44A407E9065C1C4034A40DA571EA4A7B44A40
48363	15017	52.226568	52.240214000000002	53.676703000000003	53.668061999999999	Центральная	0103000020E61000000100000005000000FA28232E001D4A40A5D93C0E83D54A40FA28232E001D4A40740D33349ED64A404B051555BF1E4A40740D33349ED64A404B051555BF1E4A40A5D93C0E83D54A40FA28232E001D4A40A5D93C0E83D54A40
47668	15582	51.83811	51.875767000000003	53.887045000000001	53.865296999999998	Ленина	0103000020E61000000100000005000000AC39403047EB4940D829560DC2EE4A40AC39403047EB4940488AC8B08AF14A4041F50F2219F04940488AC8B08AF14A4041F50F2219F04940D829560DC2EE4A40AC39403047EB4940D829560DC2EE4A40
48459	15688	51.782018999999998	51.801341999999998	53.583024999999999	53.575642000000002	Центральная	0103000020E61000000100000005000000E1ECD63219E449401E1A16A3AEC94A40E1ECD63219E449400DE02D90A0CA4A40A374E95F92E649400DE02D90A0CA4A40A374E95F92E649401E1A16A3AEC94A40E1ECD63219E449401E1A16A3AEC94A40
48194	15973	52.013973	52.039997	53.649146000000002	53.640915	Терешковой	0103000020E61000000100000005000000750305DEC9014A400742B28009D24A40750305DEC9014A40242A543717D34A401478279F1E054A40242A543717D34A401478279F1E054A400742B28009D24A40750305DEC9014A400742B28009D24A40
47901	15496	51.772038999999999	51.831282999999999	53.675038999999998	53.640349000000001	Г.Тукая	0103000020E61000000100000005000000471E882CD2E249405E83BEF4F6D14A40471E882CD2E2494024438EAD67D64A40425C397B67EA494024438EAD67D64A40425C397B67EA49405E83BEF4F6D14A40471E882CD2E249405E83BEF4F6D14A40
48199	15347	51.768256999999998	51.816927999999997	53.525098	53.494788999999997	Советская	0103000020E6100000010000000500000027F6D03E56E24940D4B5F63E55BF4A4027F6D03E56E24940F698486936C34A40E597C11891E84940F698486936C34A40E597C11891E84940D4B5F63E55BF4A4027F6D03E56E24940D4B5F63E55BF4A40
47839	15492	52.148001999999998	52.172795000000001	53.636836000000002	53.621180000000003	Школьная	0103000020E610000001000000050000000DDFC2BAF1124A40F37684D382CF4A400DDFC2BAF1124A402E7590D783D14A40C7F484251E164A402E7590D783D14A40C7F484251E164A40F37684D382CF4A400DDFC2BAF1124A40F37684D382CF4A40
48222	49583	52.108718000000003	52.152844000000002	53.867601999999998	53.848568	Центральная	0103000020E61000000100000005000000473EAF78EA0D4A40503750E09DEC4A40473EAF78EA0D4A40DBF813950DEF4A40E6B1666490134A40DBF813950DEF4A40E6B1666490134A40503750E09DEC4A40473EAF78EA0D4A40503750E09DEC4A40
48215	15100	51.896303000000003	51.928632999999998	53.586483000000001	53.559519000000002	Лукьянова	0103000020E610000001000000050000004227840EBAF24940CD3E8F519EC74A404227840EBAF249407A54FCDF11CB4A40417E3672DDF649407A54FCDF11CB4A40417E3672DDF64940CD3E8F519EC74A404227840EBAF24940CD3E8F519EC74A40
47758	15056	51.908143000000003	51.997821000000002	53.500804000000002	53.463172	Ленина	0103000020E61000000100000005000000B18BA2073EF449402236583849BB4A40B18BA2073EF449405EDA70581AC04A408A213999B8FF49405EDA70581AC04A408A213999B8FF49402236583849BB4A40B18BA2073EF449402236583849BB4A40
48413	15191	51.977635999999997	51.994281999999998	53.565716999999999	53.549157999999998	Центральная	0103000020E6100000010000000500000035B22B2D23FD49401B2B31CF4AC64A4035B22B2D23FD494047E5266A69C84A403080F0A144FF494047E5266A69C84A403080F0A144FF49401B2B31CF4AC64A4035B22B2D23FD49401B2B31CF4AC64A40
48619	16056	52.018886999999999	52.042107999999999	53.508119999999998	53.499647000000003	Ленина	0103000020E61000000100000005000000E7A8A3E36A024A40B345D26EF4BF4A40E7A8A3E36A024A40C5387F130AC14A40327381CB63054A40C5387F130AC14A40327381CB63054A40B345D26EF4BF4A40E7A8A3E36A024A40B345D26EF4BF4A40
47898	15007	52.232551000000001	52.265976999999999	53.740861000000002	53.720235000000002	Советская	0103000020E6100000010000000500000078D32D3BC41D4A40A03715A930DC4A4078D32D3BC41D4A40E1F08288D4DE4A407D3ECA880B224A40E1F08288D4DE4A407D3ECA880B224A40A03715A930DC4A4078D32D3BC41D4A40A03715A930DC4A40
48472	15294	51.967207000000002	51.994577999999997	53.898873000000002	53.888084999999997	Ленина	0103000020E610000001000000050000002CBB6070CDFB4940B988EFC4ACF14A402CBB6070CDFB4940F3203D450EF34A4019A9F7544EFF4940F3203D450EF34A4019A9F7544EFF4940B988EFC4ACF14A402CBB6070CDFB4940B988EFC4ACF14A40
48673	751	49.911304000000001	49.936278000000001	52.344419000000002	52.328994999999999	Молодежная	0103000020E61000000100000005000000645B069CA5F4484015C616821C2A4A40645B069CA5F448407E8FFAEB152C4A406EFB1EF5D7F748407E8FFAEB152C4A406EFB1EF5D7F7484015C616821C2A4A40645B069CA5F4484015C616821C2A4A40
48502	19508	49.465775999999998	49.484057	52.434083000000001	52.415031999999997	Молодёжная	0103000020E610000001000000050000007FA1478C9EBB48409065C1C41F354A407FA1478C9EBB4840F25F200890374A402F336C94F5BD4840F25F200890374A402F336C94F5BD48409065C1C41F354A407FA1478C9EBB48409065C1C41F354A40
48666	46349	49.776646999999997	49.799455000000002	52.287638000000001	52.269278	Чкалова	0103000020E61000000100000005000000ACC43C2B69E3484022C495B377224A40ACC43C2B69E348401E8B6D52D1244A40D5CF9B8A54E648401E8B6D52D1244A40D5CF9B8A54E6484022C495B377224A40ACC43C2B69E3484022C495B377224A40
48179	19733	49.935029	49.981704999999998	52.426242000000002	52.386262000000002	Октябрьская	0103000020E61000000100000005000000E2E7BF07AFF7484002D8800871314A40E2E7BF07AFF7484040170D198F364A40EBA86A82A8FD484040170D198F364A40EBA86A82A8FD484002D8800871314A40E2E7BF07AFF7484002D8800871314A40
48669	19733	49.935029	49.981704999999998	52.426242000000002	52.386262000000002	Мира	0103000020E61000000100000005000000E2E7BF07AFF7484002D8800871314A40E2E7BF07AFF7484040170D198F364A40EBA86A82A8FD484040170D198F364A40EBA86A82A8FD484002D8800871314A40E2E7BF07AFF7484002D8800871314A40
77323	19733	49.935029	49.981704999999998	52.426242000000002	52.386262000000002	Крайнюковская	0103000020E61000000100000005000000E2E7BF07AFF7484002D8800871314A40E2E7BF07AFF7484040170D198F364A40EBA86A82A8FD484040170D198F364A40EBA86A82A8FD484002D8800871314A40E2E7BF07AFF7484002D8800871314A40
47784	19733	49.935029	49.981704999999998	52.426242000000002	52.386262000000002	50 лет Октября	0103000020E61000000100000005000000E2E7BF07AFF7484002D8800871314A40E2E7BF07AFF7484040170D198F364A40EBA86A82A8FD484040170D198F364A40EBA86A82A8FD484002D8800871314A40E2E7BF07AFF7484002D8800871314A40
48176	19516	49.485143999999998	49.545475000000003	52.476131000000002	52.454189999999997	Клубная	0103000020E61000000100000005000000E1ECD63219BE4840CA15DEE5223A4A40E1ECD63219BE48404FCE50DCF13C4A408FE4F21FD2C548404FCE50DCF13C4A408FE4F21FD2C54840CA15DEE5223A4A40E1ECD63219BE4840CA15DEE5223A4A40
48665	55938	50.040222	50.060541999999998	52.285550000000001	52.277901999999997	Садовая	0103000020E61000000100000005000000344A97FE250549401ABFF04A92234A40344A97FE25054940B8AF03E78C244A4068041BD7BF074940B8AF03E78C244A4068041BD7BF0749401ABFF04A92234A40344A97FE250549401ABFF04A92234A40
48149	19359	49.793121999999997	49.841065	52.321702000000002	52.291753	Юбилейная	0103000020E610000001000000050000007ADE8D0585E5484044C18C2958254A407ADE8D0585E548406687F8872D294A40B6679604A8EB48406687F8872D294A40B6679604A8EB484044C18C2958254A407ADE8D0585E5484044C18C2958254A40
48389	46270	50.043284999999997	50.065176999999998	52.216681999999999	52.201439000000001	Центральная	0103000020E6100000010000000500000024B4E55C8A054940C991CEC0C8194A4024B4E55C8A054940E1D05B3CBC1B4A40C7B94DB857084940E1D05B3CBC1B4A40C7B94DB857084940C991CEC0C8194A4024B4E55C8A054940C991CEC0C8194A40
48175	710	49.716639999999998	49.756633000000001	52.379204000000001	52.351542999999999	Школьная	0103000020E61000000100000005000000B28009DCBADB4840A1116C5CFF2C4A40B28009DCBADB48409641B5C189304A408509A359D9E048409641B5C189304A408509A359D9E04840A1116C5CFF2C4A40B28009DCBADB4840A1116C5CFF2C4A40
48668	19417	49.469684000000001	49.504907000000003	52.373525000000001	52.355013999999997	Ленина	0103000020E610000001000000050000002CBAF59A1EBC4840A2CF4719712D4A402CBAF59A1EBC4840849ECDAACF2F4A40C042E6CAA0C04840849ECDAACF2F4A40C042E6CAA0C04840A2CF4719712D4A402CBAF59A1EBC4840A2CF4719712D4A40
48173	46200	50.025174999999997	50.057684999999999	52.286079000000001	52.261761	Центральная	0103000020E61000000100000005000000A1D634EF38034940232F6B6281214A40A1D634EF380349404489963C9E244A40213CDA38620749404489963C9E244A40213CDA3862074940232F6B6281214A40A1D634EF38034940232F6B6281214A40
48670	46324	49.801502999999997	49.831668999999998	52.284542000000002	52.269857000000002	Коммунистическая	0103000020E61000000100000005000000AC527AA697E6484060CC96AC8A224A40AC527AA697E64840522B4CDF6B244A406B0C3A2174EA4840522B4CDF6B244A406B0C3A2174EA484060CC96AC8A224A40AC527AA697E6484060CC96AC8A224A40
48379	46278	49.966605000000001	49.982649000000002	52.205992999999999	52.195936000000003	Центральная	0103000020E6100000010000000500000036936FB6B9FB4840F60D4C6E14194A4036936FB6B9FB48403B1A87FA5D1A4A403B394371C7FD48403B1A87FA5D1A4A403B394371C7FD4840F60D4C6E14194A4036936FB6B9FB4840F60D4C6E14194A40
48671	46224	50.197014000000003	50.214001000000003	52.290320000000001	52.279352000000003	Хлеборобов	0103000020E61000000100000005000000556D37C1371949403E096CCEC1234A40556D37C137194940F7AFAC3429254A40D9278062641B4940F7AFAC3429254A40D9278062641B49403E096CCEC1234A40556D37C1371949403E096CCEC1234A40
48384	46476	49.546695999999997	49.579224000000004	52.558759000000002	52.529108000000001	Советская	0103000020E61000000100000005000000506D7022FAC54840A7069ACFB9434A40506D7022FAC548403FAC376A85474A407787140324CA48403FAC376A85474A407787140324CA4840A7069ACFB9434A40506D7022FAC54840A7069ACFB9434A40
48383	19674	49.697828999999999	49.724015000000001	52.499136	52.484406999999997	Центральная	0103000020E61000000100000005000000A699EE7552D948400B7A6F0C013E4A40A699EE7552D94840CD203EB0E33F4A401F680586ACDC4840CD203EB0E33F4A401F680586ACDC48400B7A6F0C013E4A40A699EE7552D948400B7A6F0C013E4A40
48243	46168	50.019264	50.056311000000001	52.406869	52.388120000000001	Телеграфная	0103000020E61000000100000005000000BDFE243E77024940367689EAAD314A40BDFE243E77024940CC608C4814344A40D9B3E73235074940CC608C4814344A40D9B3E73235074940367689EAAD314A40BDFE243E77024940367689EAAD314A40
47678	55849	48.666716000000001	48.66818	53.161186999999998	53.160912000000003	переулок Железнодорожный	0103000020E6100000010000000500000027DC2BF35655484059C4B0C398944A4027DC2BF3565548402AC58EC6A1944A40AFEB17EC865548402AC58EC6A1944A40AFEB17EC8655484059C4B0C398944A4027DC2BF35655484059C4B0C398944A40
47797	55849	48.666716000000001	48.66818	53.161186999999998	53.160912000000003	Вологина	0103000020E6100000010000000500000027DC2BF35655484059C4B0C398944A4027DC2BF3565548402AC58EC6A1944A40AFEB17EC865548402AC58EC6A1944A40AFEB17EC8655484059C4B0C398944A4027DC2BF35655484059C4B0C398944A40
48121	55849	48.666716000000001	48.66818	53.161186999999998	53.160912000000003	3-го Октября	0103000020E6100000010000000500000027DC2BF35655484059C4B0C398944A4027DC2BF3565548402AC58EC6A1944A40AFEB17EC865548402AC58EC6A1944A40AFEB17EC8655484059C4B0C398944A4027DC2BF35655484059C4B0C398944A40
47737	55857	49.795493999999998	49.820844000000001	53.064526999999998	53.048955999999997	Куйбышева	0103000020E61000000100000005000000051555BFD2E54840B378B13044864A40051555BFD2E54840C05AB56B42884A40158F8B6A11E94840C05AB56B42884A40158F8B6A11E94840B378B13044864A40051555BFD2E54840B378B13044864A40
48214	45836	49.868715000000002	49.884183999999998	53.004691000000001	52.991498999999997	пер. Школьный	0103000020E61000000100000005000000B745990D32EF484023827170E97E4A40B745990D32EF4840F3CAF5B699804A40BFD2F9F02CF14840F3CAF5B699804A40BFD2F9F02CF1484023827170E97E4A40B745990D32EF484023827170E97E4A40
48689	50009	49.778668000000003	49.799670999999996	53.055652000000002	53.044333000000002	Школьная	0103000020E610000001000000050000008B389D64ABE34840199128B4AC854A408B389D64ABE348407FFACF9A1F874A40A1478C9E5BE648407FFACF9A1F874A40A1478C9E5BE64840199128B4AC854A408B389D64ABE34840199128B4AC854A40
47704	17356	50.901994000000002	50.977424999999997	52.921410000000002	52.888893000000003	Торговая	0103000020E610000001000000050000001898158A747349405952EE3EC7714A401898158A747349408B1A4CC3F0754A407AA52C431C7D49408B1A4CC3F0754A407AA52C431C7D49405952EE3EC7714A401898158A747349405952EE3EC7714A40
47689	17356	50.901994000000002	50.977424999999997	52.921410000000002	52.888893000000003	 Льва Толстого	0103000020E610000001000000050000001898158A747349405952EE3EC7714A401898158A747349408B1A4CC3F0754A407AA52C431C7D49408B1A4CC3F0754A407AA52C431C7D49405952EE3EC7714A401898158A747349405952EE3EC7714A40
48381	18307	50.838456000000001	50.859791000000001	52.832875999999999	52.815604	Центральная	0103000020E610000001000000050000004791B586526B49404F3E3DB665684A404791B586526B4940C8CF46AE9B6A4A409432A9A10D6E4940C8CF46AE9B6A4A409432A9A10D6E49404F3E3DB665684A404791B586526B49404F3E3DB665684A40
48500	18265	50.914085	50.927739000000003	52.734831	52.728206	Озёрная	0103000020E61000000100000005000000D061BEBC007549402060ADDA355D4A40D061BEBC00754940228B34F10E5E4A40A41CCC26C0764940228B34F10E5E4A40A41CCC26C07649402060ADDA355D4A40D061BEBC007549402060ADDA355D4A40
47690	18364	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	проспект Победы	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
47805	18364	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	Школьная	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
47811	18364	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	Нефтяников	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
47884	18364	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	Мира	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
47815	18364	51.151195000000001	51.206028000000003	52.820258000000003	52.789298000000002	Зеленая	0103000020E61000000100000005000000CC28965B5A9349402C6684B707654A40CC28965B5A9349402524D236FE684A40B80721205F9A49402524D236FE684A40B80721205F9A49402C6684B707654A40CC28965B5A9349402C6684B707654A40
48147	45787	51.086255999999999	51.115217999999999	52.794029999999999	52.765618000000003	Ленина	0103000020E61000000100000005000000B98AC56F0A8B49404E9D47C5FF614A40B98AC56F0A8B49407D0569C6A2654A408CF4A276BF8E49407D0569C6A2654A408CF4A276BF8E49404E9D47C5FF614A40B98AC56F0A8B49404E9D47C5FF614A40
48172	45744	51.026204	51.094323000000003	52.746352000000002	52.724448000000002	Школьная	0103000020E610000001000000050000001F8315A75A83494089D349B6BA5C4A401F8315A75A834940F0A65B76885F4A405C21ACC6128C4940F0A65B76885F4A405C21ACC6128C494089D349B6BA5C4A401F8315A75A83494089D349B6BA5C4A40
48549	17861	50.652990000000003	50.681851999999999	52.903522000000002	52.885843999999999	переулок Школьный	0103000020E61000000100000005000000BA4E232D95534940CDAD105663714A40BA4E232D95534940B79BE09BA6734A40295B24ED46574940B79BE09BA6734A40295B24ED46574940CDAD105663714A40BA4E232D95534940CDAD105663714A40
48551	17971	51.218882999999998	51.242617000000003	52.751268000000003	52.733975000000001	Школьная	0103000020E610000001000000050000003F53AF5B049C4940728A8EE4F25D4A403F53AF5B049C49400344C18C29604A40113AE8120E9F49400344C18C29604A40113AE8120E9F4940728A8EE4F25D4A403F53AF5B049C4940728A8EE4F25D4A40
47692	45694	50.722771000000002	50.790728000000001	52.729984000000002	52.682977000000001	 переулок Школьный	0103000020E61000000100000005000000A5BF97C2835C4940C97553CA6B574A40A5BF97C2835C4940384D9F1D705D4A4008043A9336654940384D9F1D705D4A4008043A9336654940C97553CA6B574A40A5BF97C2835C4940C97553CA6B574A40
48667	17687	50.808487999999997	50.847825	52.928733000000001	52.911423999999997	Чапаевская	0103000020E61000000100000005000000AE9AE7887C6749400E65A88AA9744A40AE9AE7887C674940A5DB12B9E0764A4098DD9387856C4940A5DB12B9E0764A4098DD9387856C49400E65A88AA9744A40AE9AE7887C6749400E65A88AA9744A40
48251	28559	50.607148000000002	50.627397000000002	53.505164000000001	53.476953000000002	Мира	0103000020E6100000010000000500000079EA9106B74D4940535DC0CB0CBD4A4079EA9106B74D4940EB8EC536A9C04A40E44D7E8B4E504940EB8EC536A9C04A40E44D7E8B4E504940535DC0CB0CBD4A4079EA9106B74D4940535DC0CB0CBD4A40
48639	28648	50.693269999999998	50.708074000000003	53.471415999999998	53.458469999999998	Центральная	0103000020E6100000010000000500000022A64412BD5849403B191C25AFBA4A4022A64412BD584940D367075C57BC4A40EF92382BA25A4940D367075C57BC4A40EF92382BA25A49403B191C25AFBA4A4022A64412BD5849403B191C25AFBA4A40
48123	28369	50.582247000000002	50.612124999999999	53.555276999999997	53.534126999999998	Центральная	0103000020E61000000100000005000000D998D711874A49408E7406465EC44A40D998D711874A4940499C155113C74A403108AC1C5A4E4940499C155113C74A403108AC1C5A4E49408E7406465EC44A40D998D711874A49408E7406465EC44A40
48223	28204	50.932707000000001	50.982159000000003	53.488055000000003	53.464506999999998	Школьная	0103000020E6100000010000000500000009E066F162774940ACE122F774BB4A4009E066F1627749401CD3139678BE4A406D3CD862B77D49401CD3139678BE4A406D3CD862B77D4940ACE122F774BB4A4009E066F162774940ACE122F774BB4A40
48160	28204	50.932707000000001	50.982159000000003	53.488055000000003	53.464506999999998	Рабочая	0103000020E6100000010000000500000009E066F162774940ACE122F774BB4A4009E066F1627749401CD3139678BE4A406D3CD862B77D49401CD3139678BE4A406D3CD862B77D4940ACE122F774BB4A4009E066F162774940ACE122F774BB4A40
48359	27118	50.377315000000003	50.393143000000002	53.550440999999999	53.543528999999999	Садовая	0103000020E6100000010000000500000027A5A0DB4B304940BBB6B75B92C54A4027A5A0DB4B30494053B0C6D974C64A405FD383825232494053B0C6D974C64A405FD3838252324940BBB6B75B92C54A4027A5A0DB4B304940BBB6B75B92C54A40
48334	28284	50.792174000000003	50.814390000000003	53.523330999999999	53.504789000000002	переулок Школьный	0103000020E61000000100000005000000EA5E27F565654940B6300BED9CC04A40EA5E27F565654940D2FD9C82FCC24A40401878EE3D684940D2FD9C82FCC24A40401878EE3D684940B6300BED9CC04A40EA5E27F565654940B6300BED9CC04A40
48563	28284	50.792174000000003	50.814390000000003	53.523330999999999	53.504789000000002	Полевая	0103000020E61000000100000005000000EA5E27F565654940B6300BED9CC04A40EA5E27F565654940D2FD9C82FCC24A40401878EE3D684940D2FD9C82FCC24A40401878EE3D684940B6300BED9CC04A40EA5E27F565654940B6300BED9CC04A40
48219	28110	50.214387000000002	50.258521000000002	53.653159000000002	53.634824000000002	Центральная	0103000020E6100000010000000500000002D88008711B4940A35BAFE941D14A4002D88008711B4940460BD0B69AD34A40242A543717214940460BD0B69AD34A40242A543717214940A35BAFE941D14A4002D88008711B4940A35BAFE941D14A40
48709	4429	50.251092	50.287796999999998	53.417425000000001	53.404322999999998	Рабочая	0103000020E61000000100000005000000C4245CC823204940A30227DBC0B34A40C4245CC82320494033C4B12E6EB54A4086713788D624494033C4B12E6EB54A4086713788D6244940A30227DBC0B34A40C4245CC823204940A30227DBC0B34A40
48516	28155	49.940705999999999	49.985343999999998	53.600543999999999	53.569242000000003	Фрунзе	0103000020E610000001000000050000005393E00D69F848403CC1FEEBDCC84A405393E00D69F848408EE733A0DECC4A40A8A78FC01FFE48408EE733A0DECC4A40A8A78FC01FFE48403CC1FEEBDCC84A405393E00D69F848403CC1FEEBDCC84A40
48431	28558	50.752468999999998	50.781331999999999	53.585948999999999	53.563823999999997	Центральная	0103000020E610000001000000050000007D2079E750604940965984622BC84A407D2079E750604940DC0F786000CB4A40BDA8DDAF02644940DC0F786000CB4A40BDA8DDAF02644940965984622BC84A407D2079E750604940965984622BC84A40
47759	27896	50.252124999999999	50.265663000000004	53.505828000000001	53.495950999999998	Советская	0103000020E6100000010000000500000083C0CAA14520494091B586527BBF4A4083C0CAA14520494057B3CEF8BEC04A40EE60C43E0122494057B3CEF8BEC04A40EE60C43E0122494091B586527BBF4A4083C0CAA14520494091B586527BBF4A40
48213	26753	50.638418999999999	50.660651999999999	53.779553999999997	53.759027000000003	Школьная	0103000020E610000001000000050000009012BBB6B7514940F8E3F6CB27E14A409012BBB6B7514940A5BBEB6CC8E34A40BC04A73E90544940A5BBEB6CC8E34A40BC04A73E90544940F8E3F6CB27E14A409012BBB6B7514940F8E3F6CB27E14A40
48474	4851	50.019227999999998	50.074151000000001	53.697114999999997	53.669673000000003	Энергетиков	0103000020E610000001000000050000007095271076024940D20149D8B7D54A407095271076024940884677103BD94A409CFBABC77D094940884677103BD94A409CFBABC77D094940D20149D8B7D54A407095271076024940D20149D8B7D54A40
48218	4851	50.019227999999998	50.074151000000001	53.697114999999997	53.669673000000003	Школьная	0103000020E610000001000000050000007095271076024940D20149D8B7D54A407095271076024940884677103BD94A409CFBABC77D094940884677103BD94A409CFBABC77D094940D20149D8B7D54A407095271076024940D20149D8B7D54A40
48159	4851	50.019227999999998	50.074151000000001	53.697114999999997	53.669673000000003	Степная	0103000020E610000001000000050000007095271076024940D20149D8B7D54A407095271076024940884677103BD94A409CFBABC77D094940884677103BD94A409CFBABC77D094940D20149D8B7D54A407095271076024940D20149D8B7D54A40
48512	4851	50.019227999999998	50.074151000000001	53.697114999999997	53.669673000000003	Лесной поселок	0103000020E610000001000000050000007095271076024940D20149D8B7D54A407095271076024940884677103BD94A409CFBABC77D094940884677103BD94A409CFBABC77D094940D20149D8B7D54A407095271076024940D20149D8B7D54A40
48513	27847	50.032046999999999	50.047902000000001	53.794943000000004	53.769390000000001	Центральная	0103000020E61000000100000005000000AB77B81D1A0449404AEF1B5F7BE24A40AB77B81D1A044940929735B1C0E54A40DDB419A721064940929735B1C0E54A40DDB419A7210649404AEF1B5F7BE24A40AB77B81D1A0449404AEF1B5F7BE24A40
47676	27331	50.317981000000003	50.369706000000001	53.387720999999999	53.363509999999998	Школьная	0103000020E61000000100000005000000ECDFF599B32849406DE2E47E87AE4A40ECDFF599B3284940787C7BD7A0B14A404791B586522F4940787C7BD7A0B14A404791B586522F49406DE2E47E87AE4A40ECDFF599B32849406DE2E47E87AE4A40
47865	27331	50.317981000000003	50.369706000000001	53.387720999999999	53.363509999999998	Советская	0103000020E61000000100000005000000ECDFF599B32849406DE2E47E87AE4A40ECDFF599B3284940787C7BD7A0B14A404791B586522F4940787C7BD7A0B14A404791B586522F49406DE2E47E87AE4A40ECDFF599B32849406DE2E47E87AE4A40
47866	27331	50.317981000000003	50.369706000000001	53.387720999999999	53.363509999999998	Московская	0103000020E61000000100000005000000ECDFF599B32849406DE2E47E87AE4A40ECDFF599B3284940787C7BD7A0B14A404791B586522F4940787C7BD7A0B14A404791B586522F49406DE2E47E87AE4A40ECDFF599B32849406DE2E47E87AE4A40
47863	27331	50.317981000000003	50.369706000000001	53.387720999999999	53.363509999999998	Мира	0103000020E61000000100000005000000ECDFF599B32849406DE2E47E87AE4A40ECDFF599B3284940787C7BD7A0B14A404791B586522F4940787C7BD7A0B14A404791B586522F49406DE2E47E87AE4A40ECDFF599B32849406DE2E47E87AE4A40
48464	46388	50.136611000000002	50.151667000000003	53.660342	53.650132999999997	Советская	0103000020E610000001000000050000000EA320787C1149407286E28E37D34A400EA320787C1149406E162F1686D44A40F47002D3691349406E162F1686D44A40F47002D3691349407286E28E37D34A400EA320787C1149407286E28E37D34A40
48333	27956	50.098235000000003	50.123891	53.561616000000001	53.522806000000003	Гагарина	0103000020E610000001000000050000004A29E8F6920C49408813984EEBC24A404A29E8F6920C494086747808E3C74A4066A208A9DB0F494086747808E3C74A4066A208A9DB0F49408813984EEBC24A404A29E8F6920C49408813984EEBC24A40
47757	4761	50.252943000000002	50.286127	53.515192999999996	53.501758000000002	Космодемьянской	0103000020E610000001000000050000004660AC6F60204940D1402C9B39C04A404660AC6F6020494066101FD8F1C14A4055C03DCF9F24494066101FD8F1C14A4055C03DCF9F244940D1402C9B39C04A404660AC6F60204940D1402C9B39C04A40
47864	4761	50.252943000000002	50.286127	53.515192999999996	53.501758000000002	Коммунистическая	0103000020E610000001000000050000004660AC6F60204940D1402C9B39C04A404660AC6F6020494066101FD8F1C14A4055C03DCF9F24494066101FD8F1C14A4055C03DCF9F244940D1402C9B39C04A404660AC6F60204940D1402C9B39C04A40
47862	4761	50.252943000000002	50.286127	53.515192999999996	53.501758000000002	Зои Космодемьянской	0103000020E610000001000000050000004660AC6F60204940D1402C9B39C04A404660AC6F6020494066101FD8F1C14A4055C03DCF9F24494066101FD8F1C14A4055C03DCF9F244940D1402C9B39C04A404660AC6F60204940D1402C9B39C04A40
48158	28021	50.16816	50.186584000000003	53.451393000000003	53.437154	Набережная	0103000020E61000000100000005000000683F52448615494065A88AA9F4B74A40683F5244861549405952EE3EC7B94A407BFA08FCE11749405952EE3EC7B94A407BFA08FCE117494065A88AA9F4B74A40683F52448615494065A88AA9F4B74A40
48450	27195	50.379533000000002	50.400976	53.630792	53.616405	Центральная	0103000020E610000001000000050000005B608F8994304940A20BEA5BE6CE4A405B608F89943049400A4AD1CABDD04A408E3D7B2E533349400A4AD1CABDD04A408E3D7B2E53334940A20BEA5BE6CE4A405B608F8994304940A20BEA5BE6CE4A40
48442	28426	50.615349999999999	50.634430000000002	53.626820000000002	53.616036999999999	Школьная	0103000020E61000000100000005000000FBCBEEC9C34E49401F10E84CDACE4A40FBCBEEC9C34E4940473D44A33BD04A40F7CC920035514940473D44A33BD04A40F7CC9200355149401F10E84CDACE4A40FBCBEEC9C34E49401F10E84CDACE4A40
48338	28385	50.498282000000003	50.524863000000003	53.571396	53.560946999999999	Победы	0103000020E61000000100000005000000BE175FB4C73F494008E57D1CCDC74A40BE175FB4C73F494059880E8123C94A40B3F0F5B52E43494059880E8123C94A40B3F0F5B52E43494008E57D1CCDC74A40BE175FB4C73F494008E57D1CCDC74A40
47756	4705	50.378132000000001	50.406689	53.512377000000001	53.476979	Полевая	0103000020E6100000010000000500000019C91EA1663049407CF0DAA50DBD4A4019C91EA1663049407E1CCD9195C14A404C5299620E3449407E1CCD9195C14A404C5299620E3449407CF0DAA50DBD4A4019C91EA1663049407CF0DAA50DBD4A40
47747	4705	50.378132000000001	50.406689	53.512377000000001	53.476979	Пионерская	0103000020E6100000010000000500000019C91EA1663049407CF0DAA50DBD4A4019C91EA1663049407E1CCD9195C14A404C5299620E3449407E1CCD9195C14A404C5299620E3449407CF0DAA50DBD4A4019C91EA1663049407CF0DAA50DBD4A40
48522	28479	50.641931	50.663328999999997	53.589765	53.581159	Каштановая	0103000020E61000000100000005000000F0A485CB2A5249405663096B63CA4A40F0A485CB2A524940A8A9656B7DCB4A4083BEF4F6E7544940A8A9656B7DCB4A4083BEF4F6E75449405663096B63CA4A40F0A485CB2A5249405663096B63CA4A40
47674	26844	50.310121000000002	50.332515999999998	53.744950000000003	53.731316	Центральная	0103000020E61000000100000005000000C366800BB227494051853FC39BDD4A40C366800BB2274940DE9387855ADF4A40C8B260E28F2A4940DE9387855ADF4A40C8B260E28F2A494051853FC39BDD4A40C366800BB227494051853FC39BDD4A40
48515	28026	50.195504	50.237113999999998	53.542752999999998	53.524470999999998	Колодинская	0103000020E610000001000000050000005C1E6B4606194940A759A0DD21C34A405C1E6B4606194940276728EE78C54A403DB665C0591E4940276728EE78C54A403DB665C0591E4940A759A0DD21C34A405C1E6B4606194940A759A0DD21C34A40
48568	26933	50.227386000000003	50.268932999999997	53.749583000000001	53.737239000000002	Школьная	0103000020E61000000100000005000000BDC804FC1A1D4940FA2AF9D85DDE4A40BDC804FC1A1D49409C51F355F2DF4A4057E883656C2249409C51F355F2DF4A4057E883656C224940FA2AF9D85DDE4A40BDC804FC1A1D4940FA2AF9D85DDE4A40
48120	28101	50.291795	50.311763999999997	53.593719999999998	53.581201999999998	Шоссейная	0103000020E610000001000000050000007311DF8959254940552FBFD364CA4A407311DF8959254940957D5704FFCB4A40FA08FCE1E7274940957D5704FFCB4A40FA08FCE1E7274940552FBFD364CA4A407311DF8959254940552FBFD364CA4A40
48308	28101	50.291795	50.311763999999997	53.593719999999998	53.581201999999998	Центральная	0103000020E610000001000000050000007311DF8959254940552FBFD364CA4A407311DF8959254940957D5704FFCB4A40FA08FCE1E7274940957D5704FFCB4A40FA08FCE1E7274940552FBFD364CA4A407311DF8959254940552FBFD364CA4A40
47860	5213	50.088766999999997	50.134383	53.442726	53.422345999999997	Князева	0103000020E6100000010000000500000065FB90B75C0B494057CC086F0FB64A4065FB90B75C0B4940618BDD3EABB84A40B6114F7633114940618BDD3EABB84A40B6114F763311494057CC086F0FB64A4065FB90B75C0B494057CC086F0FB64A40
47861	5213	50.088766999999997	50.134383	53.442726	53.422345999999997	Жилгородок	0103000020E6100000010000000500000065FB90B75C0B494057CC086F0FB64A4065FB90B75C0B4940618BDD3EABB84A40B6114F7633114940618BDD3EABB84A40B6114F763311494057CC086F0FB64A4065FB90B75C0B494057CC086F0FB64A40
48331	2681	50.403931999999998	50.431877999999998	53.383547999999998	53.371344000000001	Рабочая	0103000020E6100000010000000500000068E7340BB43349406DC83F3388AF4A4068E7340BB43349401D39D21918B14A4052EE3EC7473749401D39D21918B14A4052EE3EC7473749406DC83F3388AF4A4068E7340BB43349406DC83F3388AF4A40
48157	26659	50.598883999999998	50.643396000000003	53.701956000000003	53.683934999999998	Комсомольская	0103000020E61000000100000005000000800C1D3BA84C49407DCB9C2E8BD74A40800C1D3BA84C4940919DB7B1D9D94A404930D5CC5A524940919DB7B1D9D94A404930D5CC5A5249407DCB9C2E8BD74A40800C1D3BA84C49407DCB9C2E8BD74A40
48209	26654	50.481627000000003	50.528357	53.681690000000003	53.650795000000002	Центральная	0103000020E6100000010000000500000070EF1AF4A53D49403EB324404DD34A4070EF1AF4A53D49405001309E41D74A406CCEC133A14349405001309E41D74A406CCEC133A14349403EB324404DD34A4070EF1AF4A53D49403EB324404DD34A40
47850	24233	50.132064999999997	50.154370999999998	53.525221000000002	53.514052999999997	Лесная	0103000020E610000001000000050000001EF98381E710494091B41B7DCCC14A401EF98381E7104940121615713AC34A40B439CE6DC2134940121615713AC34A40B439CE6DC213494091B41B7DCCC14A401EF98381E710494091B41B7DCCC14A40
47683	47750	50.351165000000002	50.371988000000002	53.449483999999998	53.429659000000001	Дзержинского	0103000020E61000000100000005000000FB3F87F9F22C49404EB7EC10FFB64A40FB3F87F9F22C4940A20914B188B94A409240834D9D2F4940A20914B188B94A409240834D9D2F49404EB7EC10FFB64A40FB3F87F9F22C49404EB7EC10FFB64A40
47873	46604	50.406671000000003	50.417236000000003	53.782283	53.777175	Комсомольская	0103000020E61000000100000005000000A69D9ACB0D34494068226C787AE34A40A69D9ACB0D344940BF9B6ED921E44A40605B3FFD67354940BF9B6ED921E44A40605B3FFD6735494068226C787AE34A40A69D9ACB0D34494068226C787AE34A40
48077	55881	50.204118999999999	50.238883999999999	53.347414000000001	53.346257999999999	Сергея Лазо	0103000020E6100000010000000500000001BF4692201A49403BFDA02E52AC4A4001BF4692201A49401616DC0F78AC4A40D2C43BC0931E49401616DC0F78AC4A40D2C43BC0931E49403BFDA02E52AC4A4001BF4692201A49403BFDA02E52AC4A40
47721	55854	50.167242999999999	50.169443999999999	53.392442000000003	53.388016999999998	квартал 4	0103000020E6100000010000000500000012BEF7376815494061A5828AAAB14A4012BEF73768154940D6C9198A3BB24A4070404B57B0154940D6C9198A3BB24A4070404B57B015494061A5828AAAB14A4012BEF7376815494061A5828AAAB14A40
48239	17668	49.834147999999999	49.866531999999999	52.897922000000001	52.884045999999998	Набережная	0103000020E610000001000000050000000C03965CC5EA48406E14596B28714A400C03965CC5EA4840F12DAC1BEF724A40FF774485EAEE4840F12DAC1BEF724A40FF774485EAEE48406E14596B28714A400C03965CC5EA48406E14596B28714A40
48554	17372	50.197372999999999	50.201459999999997	52.640991	52.633432999999997	Молодежная	0103000020E61000000100000005000000840EBA8443194940849A215514514A40840EBA8443194940E2033BFE0B524A40E0B9F770C9194940E2033BFE0B524A40E0B9F770C9194940849A215514514A40840EBA8443194940849A215514514A40
48663	16970	49.710135999999999	49.731712999999999	52.674815000000002	52.658382000000003	Молодежная	0103000020E610000001000000050000002BDB87BCE5DA4840362383DC45544A402BDB87BCE5DA4840D5EC815660564A406E8786C5A8DD4840D5EC815660564A406E8786C5A8DD4840362383DC45544A402BDB87BCE5DA4840362383DC45544A40
48265	48263	49.868895000000002	49.884292000000002	52.756031999999998	52.745403000000003	Советская	0103000020E6100000010000000500000037548CF337EF48408FAB915D695F4A4037548CF337EF48405F5D15A8C5604A40A60EF27A30F148405F5D15A8C5604A40A60EF27A30F148408FAB915D695F4A4037548CF337EF48408FAB915D695F4A40
48699	48263	49.868895000000002	49.884292000000002	52.756031999999998	52.745403000000003	Первомайская	0103000020E6100000010000000500000037548CF337EF48408FAB915D695F4A4037548CF337EF48405F5D15A8C5604A40A60EF27A30F148405F5D15A8C5604A40A60EF27A30F148408FAB915D695F4A4037548CF337EF48408FAB915D695F4A40
48385	17416	50.303455	50.316102999999998	52.714934999999997	52.708360999999996	Самарская	0103000020E6100000010000000500000062670A9DD72649408461C092AB5A4A4062670A9DD726494004E275FD825B4A40709527107628494004E275FD825B4A4070952710762849408461C092AB5A4A4062670A9DD72649408461C092AB5A4A40
48656	16673	49.894506	49.915877000000002	52.600966999999997	52.590009999999999	Победы	0103000020E61000000100000005000000B309302C7FF248400F289B72854B4A40B309302C7FF24840D47C957CEC4C4A404D1421753BF54840D47C957CEC4C4A404D1421753BF548400F289B72854B4A40B309302C7FF248400F289B72854B4A40
48550	16362	50.024348000000003	50.034939999999999	52.780861000000002	52.769889999999997	Главная	0103000020E610000001000000050000008CDCD3D51D0349403BC269C18B624A408CDCD3D51D03494066DCD440F3634A403FA9F6E97804494066DCD440F3634A403FA9F6E9780449403BC269C18B624A408CDCD3D51D0349403BC269C18B624A40
48547	16670	49.785854999999998	49.798304999999999	52.508000000000003	52.498286	Мира	0103000020E61000000100000005000000F4328AE596E44840FF06EDD5C73F4A40F4328AE596E448401B2FDD2406414A40DC9DB5DB2EE648401B2FDD2406414A40DC9DB5DB2EE64840FF06EDD5C73F4A40F4328AE596E44840FF06EDD5C73F4A40
47794	17259	50.118582000000004	50.153759999999998	52.753546999999998	52.733392000000002	площадь Центральная	0103000020E6100000010000000500000078F2E9B12D0F4940F392FFC9DF5D4A4078F2E9B12D0F4940DC7F643A74604A406BB75D68AE134940DC7F643A74604A406BB75D68AE134940F392FFC9DF5D4A4078F2E9B12D0F4940F392FFC9DF5D4A40
48240	16792	49.588118000000001	49.617168999999997	52.660113000000003	52.641953000000001	Советская	0103000020E610000001000000050000002F185C7347CB4840D84812842B524A402F185C7347CB48400D5531957E544A40718DCF64FFCE48400D5531957E544A40718DCF64FFCE4840D84812842B524A402F185C7347CB4840D84812842B524A40
48657	16884	49.531253999999997	49.577148999999999	52.751699000000002	52.733238999999998	Центральная	0103000020E6100000010000000500000041EF8D2100C448406C938AC6DA5D4A4041EF8D2100C44840CCB73EAC37604A40A5F5B704E0C94840CCB73EAC37604A40A5F5B704E0C948406C938AC6DA5D4A4041EF8D2100C448406C938AC6DA5D4A40
47736	16208	50.013461	50.045054999999998	52.731940999999999	52.697868	Центральная	0103000020E61000000100000005000000BF620D17B9014940647616BD53594A40BF620D17B9014940FFCC203EB05D4A40B9C2BB5CC4054940FFCC203EB05D4A40B9C2BB5CC4054940647616BD53594A40BF620D17B9014940647616BD53594A40
47652	16208	50.013461	50.045054999999998	52.731940999999999	52.697868	Кирова	0103000020E61000000100000005000000BF620D17B9014940647616BD53594A40BF620D17B9014940FFCC203EB05D4A40B9C2BB5CC4054940FFCC203EB05D4A40B9C2BB5CC4054940647616BD53594A40BF620D17B9014940647616BD53594A40
48661	17263	50.203400999999999	50.214064	52.720657000000003	52.715093000000003	переулок Школьный	0103000020E61000000100000005000000A27C410B091A49409D4CDC2A885B4A40A27C410B091A49401651137D3E5C4A401FA0FB72661B49401651137D3E5C4A401FA0FB72661B49409D4CDC2A885B4A40A27C410B091A49409D4CDC2A885B4A40
48242	17574	50.000461999999999	50.047848000000002	52.928733000000001	52.904147000000002	Советская	0103000020E61000000100000005000000047289230F00494065E3C116BB734A40047289230F004940A5DB12B9E0764A40EA961DE21F064940A5DB12B9E0764A40EA961DE21F06494065E3C116BB734A40047289230F00494065E3C116BB734A40
48659	17075	49.902096999999998	49.917979000000003	52.679018999999997	52.667485999999997	Космическая	0103000020E61000000100000005000000EC681CEA77F34840D844662E70554A40EC681CEA77F348406A2E3718EA564A4018B5FB5580F548406A2E3718EA564A4018B5FB5580F54840D844662E70554A40EC681CEA77F34840D844662E70554A40
48378	16777	49.801414000000001	49.817529	52.603400999999998	52.587395000000001	Школьная	0103000020E610000001000000050000003D47E4BB94E64840BE6A65C22F4B4A403D47E4BB94E64840D5AF743E3C4D4A400B444FCAA4E84840D5AF743E3C4D4A400B444FCAA4E84840BE6A65C22F4B4A403D47E4BB94E64840BE6A65C22F4B4A40
48150	17064	49.835692999999999	49.861403000000003	52.680089000000002	52.667869000000003	Кирова	0103000020E61000000100000005000000813FFCFCF7EA484091813CBB7C554A40813FFCFCF7EA484047AF06280D574A4091D6187442EE484047AF06280D574A4091D6187442EE484091813CBB7C554A40813FFCFCF7EA484091813CBB7C554A40
48692	17565	49.953274	49.982486999999999	52.902365000000003	52.881034999999997	Центральная	0103000020E610000001000000050000004510E7E104FA4840D0D03FC1C5704A404510E7E104FA48400C0742B280734A4061DF4E22C2FD48400C0742B280734A4061DF4E22C2FD4840D0D03FC1C5704A404510E7E104FA4840D0D03FC1C5704A40
48443	16515	50.061017999999997	50.075490000000002	52.554867000000002	52.541406000000002	Центральная	0103000020E61000000100000005000000D13B1570CF074940D9EDB3CA4C454A40D13B1570CF0749409850C1E105474A40689604A8A90949409850C1E105474A40689604A8A9094940D9EDB3CA4C454A40D13B1570CF074940D9EDB3CA4C454A40
48185	17469	50.023063999999998	50.049087999999998	52.905624000000003	52.887403999999997	Молодёжная	0103000020E6100000010000000500000083DBDAC2F3024940772B4B7496714A4083DBDAC2F3024940823CBB7CEB734A402250FD8348064940823CBB7CEB734A402250FD8348064940772B4B7496714A4083DBDAC2F3024940772B4B7496714A40
48380	16967	49.674382999999999	49.712040000000002	52.783579000000003	52.765802999999998	Советская	0103000020E610000001000000050000003BFDA02E52D64840DF162CD505624A403BFDA02E52D648408C6A11514C644A40D0B8702024DB48408C6A11514C644A40D0B8702024DB4840DF162CD505624A403BFDA02E52D64840DF162CD505624A40
48660	16464	49.966856	49.995989000000002	52.569609	52.540311000000003	Советская	0103000020E610000001000000050000007FF8F9EFC1FB4840A4552DE928454A407FF8F9EFC1FB4840EE409DF2E8484A407F164B917CFF4840EE409DF2E8484A407F164B917CFF4840A4552DE928454A407FF8F9EFC1FB4840A4552DE928454A40
48552	16474	49.990734000000003	50.008709000000003	52.634115999999999	52.619701999999997	 Ленина	0103000020E610000001000000050000008484285FD0FE484005A22765524F4A408484285FD0FE484067EF8CB62A514A40271763601D01494067EF8CB62A514A40271763601D01494005A22765524F4A408484285FD0FE484005A22765524F4A40
48658	2624	49.563746000000002	49.608077999999999	52.699657999999999	52.675185999999997	Молодежная	0103000020E610000001000000050000001BA034D428C84840C85BAE7E6C564A401BA034D428C848404031B2648E594A4063B5F97FD5CD48404031B2648E594A4063B5F97FD5CD4840C85BAE7E6C564A401BA034D428C84840C85BAE7E6C564A40
48555	16584	49.827429000000002	49.839762999999998	52.538487000000003	52.528215000000003	Читателей	0103000020E6100000010000000500000089618731E9E94840DA20938C9C434A4089618731E9E948401C295B24ED444A4007B29E5A7DEB48401C295B24ED444A4007B29E5A7DEB4840DA20938C9C434A4089618731E9E94840DA20938C9C434A40
48613	13628	50.369140000000002	50.375571999999998	54.184271000000003	54.178876000000002	Центральная	0103000020E610000001000000050000009ED2C1FA3F2F49400805A568E5164B409ED2C1FA3F2F4940F54C2F3196174B408BA548BE12304940F54C2F3196174B408BA548BE123049400805A568E5164B409ED2C1FA3F2F49400805A568E5164B40
48406	14717	50.331662000000001	50.353554000000003	54.433987999999999	54.420160000000003	Большая	0103000020E61000000100000005000000B9A981E6732A49402F8B89CDC7354B40B9A981E6732A4940A06D35EB8C374B405CAFE941412D4940A06D35EB8C374B405CAFE941412D49402F8B89CDC7354B40B9A981E6732A49402F8B89CDC7354B40
48578	13873	50.667200999999999	50.679175000000001	54.197226000000001	54.175491999999998	Специалистов	0103000020E61000000100000005000000E36DA5D766554940D55A988576164B40E36DA5D766554940E0F599B33E194B4062A1D634EF564940E0F599B33E194B4062A1D634EF564940D55A988576164B40E36DA5D766554940D55A988576164B40
48576	13681	50.407407999999997	50.426659000000001	54.107030999999999	54.092834000000003	Центральная	0103000020E610000001000000050000007B1002F2253449407BFA08FCE10B4B407B1002F2253449403F541A31B30D4B40A4C519C39C3649403F541A31B30D4B40A4C519C39C3649407BFA08FCE10B4B407B1002F2253449407BFA08FCE10B4B40
48615	14063	50.621045000000002	50.647204000000002	54.332191999999999	54.312432000000001	Центральная	0103000020E61000000100000005000000132C0E677E4F4940A81C93C5FD274B40132C0E677E4F494015FF7744852A4B4092EBA694D752494015FF7744852A4B4092EBA694D7524940A81C93C5FD274B40132C0E677E4F4940A81C93C5FD274B40
48617	14731	50.312779999999997	50.335183999999998	54.320734999999999	54.306874999999998	Центральная	0103000020E61000000100000005000000E36BCF2C09284940E17A14AE47274B40E36BCF2C092849405ED72FD80D294B403C122F4FE72A49405ED72FD80D294B403C122F4FE72A4940E17A14AE47274B40E36BCF2C09284940E17A14AE47274B40
48575	14537	50.299179000000002	50.315834000000002	54.390949999999997	54.369204000000003	Центральная	0103000020E6100000010000000500000033535A7F4B264940B5C6A013422F4B4033535A7F4B264940832F4CA60A324B40817B9E3F6D284940832F4CA60A324B40817B9E3F6D284940B5C6A013422F4B4033535A7F4B264940B5C6A013422F4B40
48574	14832	50.296968999999997	50.321537999999997	54.344422999999999	54.329158	Озёрная	0103000020E610000001000000050000008176871403264940BF9B6ED9212A4B408176871403264940BF7E880D162C4B40EB353D2828294940BF7E880D162C4B40EB353D2828294940BF9B6ED9212A4B408176871403264940BF9B6ED9212A4B40
48221	7078	50.340707999999999	50.381715999999997	54.484121000000002	54.461461999999997	Школьная	0103000020E6100000010000000500000027BEDA519C2B4940622CD32F113B4B4027BEDA519C2B494046274BADF73D4B40122EE411DC30494046274BADF73D4B40122EE411DC304940622CD32F113B4B4027BEDA519C2B4940622CD32F113B4B40
48438	13970	50.785283999999997	50.831817000000001	54.160907999999999	54.152392999999996	Центральная	0103000020E610000001000000050000003909A52F84644940D591239D81134B403909A52F8464494017D522A298144B40E0A0BDFA786A494017D522A298144B40E0A0BDFA786A4940D591239D81134B403909A52F84644940D591239D81134B40
48454	14054	50.686748000000001	50.733479000000003	54.312553000000001	54.287202000000001	Луговая	0103000020E61000000100000005000000F54BC45BE757494043ACFE08C3244B40F54BC45BE757494023A298BC01284B40C2A6CEA3E25D494023A298BC01284B40C2A6CEA3E25D494043ACFE08C3244B40F54BC45BE757494043ACFE08C3244B40
48467	13856	50.548955999999997	50.568548	54.110610000000001	54.091931000000002	Школьная	0103000020E61000000100000005000000B378B130444649408A3E1F65C40B4B40B378B13044464940274EEE77280E4B40651A4D2EC6484940274EEE77280E4B40651A4D2EC64849408A3E1F65C40B4B40B378B130444649408A3E1F65C40B4B40
47723	13481	50.427619999999997	50.469912999999998	54.242694	54.216462	Пионерская	0103000020E61000000100000005000000C98E8D40BC364940D369DD06B51B4B40C98E8D40BC364940BC77D498101F4B408D7BF31B263C4940BC77D498101F4B408D7BF31B263C4940D369DD06B51B4B40C98E8D40BC364940D369DD06B51B4B40
47897	13489	50.294336999999999	50.337546000000003	54.194397000000002	54.177289000000002	Октябрьская	0103000020E610000001000000050000005A80B6D5AC2549406478EC67B1164B405A80B6D5AC25494063B83A00E2184B40A47213B5342B494063B83A00E2184B40A47213B5342B49406478EC67B1164B405A80B6D5AC2549406478EC67B1164B40
48610	14149	50.627675000000004	50.653744000000003	54.274697000000003	54.261394000000003	Центральная	0103000020E6100000010000000500000027C286A75750494071AFCC5B75214B4027C286A75750494098A7734529234B4066FA25E2AD53494098A7734529234B4066FA25E2AD53494071AFCC5B75214B4027C286A75750494071AFCC5B75214B40
48408	14484	50.312699000000002	50.334617999999999	54.401040000000002	54.370671999999999	Рабочая	0103000020E61000000100000005000000F73E5585062849407EC51A2E722F4B40F73E558506284940A5315A4755334B4093533BC3D42A4940A5315A4755334B4093533BC3D42A49407EC51A2E722F4B40F73E5585062849407EC51A2E722F4B40
48191	13771	50.683064999999999	50.707014000000001	54.119929999999997	54.094613000000003	Центральная	0103000020E61000000100000005000000680586AC6E57494063635E471C0C4B40680586AC6E57494096E7C1DD590F4B4036E84B6F7F5A494096E7C1DD590F4B4036E84B6F7F5A494063635E471C0C4B40680586AC6E57494063635E471C0C4B40
48189	13590	50.339675	50.392882	54.139541000000001	54.092934	Центральная	0103000020E6100000010000000500000068226C787A2B4940DE57E542E50B4B4068226C787A2B4940BFB9BF7ADC114B40F29716F549324940BFB9BF7ADC114B40F29716F549324940DE57E542E50B4B4068226C787A2B4940DE57E542E50B4B40
48455	14622	50.245010999999998	50.266497999999999	54.396779000000002	54.382016	Лесная	0103000020E6100000010000000500000083143C855C1F49403D4679E6E5304B4083143C855C1F4940AB5E7EA7C9324B408639419B1C224940AB5E7EA7C9324B408639419B1C2249403D4679E6E5304B4083143C855C1F49403D4679E6E5304B40
48456	14156	50.721269999999997	50.749890999999998	54.382755000000003	54.366785	Центральная	0103000020E61000000100000005000000FFCA4A93525C4940E9D495CFF22E4B40FFCA4A93525C4940B4B0A71DFE304B404948A46DFC5F4940B4B0A71DFE304B404948A46DFC5F4940E9D495CFF22E4B40FFCA4A93525C4940E9D495CFF22E4B40
48579	14447	50.310910999999997	50.343313000000002	54.452956999999998	54.439695999999998	Полевая	0103000020E61000000100000005000000BB7B80EECB2749404C1762F547384B40BB7B80EECB27494044BFB67EFA394B4055A52DAEF12B494044BFB67EFA394B4055A52DAEF12B49404C1762F547384B40BB7B80EECB2749404C1762F547384B40
48580	13916	50.532786000000002	50.550266999999998	54.206373999999997	54.197040999999999	Липовка	0103000020E6100000010000000500000022E2E654324449404E7CB5A338194B4022E2E65432444940525F96766A1A4B40B58828266F464940525F96766A1A4B40B58828266F4649404E7CB5A338194B4022E2E654324449404E7CB5A338194B40
48566	13581	50.291677999999997	50.315313000000003	54.154823999999998	54.143490999999997	Школьная	0103000020E61000000100000005000000397B67B4552549409A22C0E95D124B40397B67B4552549406551D845D1134B407880272D5C2849406551D845D1134B407880272D5C2849409A22C0E95D124B40397B67B4552549409A22C0E95D124B40
47762	7069	50.440232999999999	50.499063	54.220410999999999	54.185735999999999	Советская	0103000020E610000001000000050000005BCF108E593849404DD87E32C6174B405BCF108E59384940DE567A6D361C4B4063D2DF4BE13F4940DE567A6D361C4B4063D2DF4BE13F49404DD87E32C6174B405BCF108E593849404DD87E32C6174B40
48188	7069	50.440232999999999	50.499063	54.220410999999999	54.185735999999999	Победы	0103000020E610000001000000050000005BCF108E593849404DD87E32C6174B405BCF108E59384940DE567A6D361C4B4063D2DF4BE13F4940DE567A6D361C4B4063D2DF4BE13F49404DD87E32C6174B405BCF108E593849404DD87E32C6174B40
48186	7069	50.440232999999999	50.499063	54.220410999999999	54.185735999999999	Первомайская	0103000020E610000001000000050000005BCF108E593849404DD87E32C6174B405BCF108E59384940DE567A6D361C4B4063D2DF4BE13F4940DE567A6D361C4B4063D2DF4BE13F49404DD87E32C6174B405BCF108E593849404DD87E32C6174B40
47755	7069	50.440232999999999	50.499063	54.220410999999999	54.185735999999999	Мира	0103000020E610000001000000050000005BCF108E593849404DD87E32C6174B405BCF108E59384940DE567A6D361C4B4063D2DF4BE13F4940DE567A6D361C4B4063D2DF4BE13F49404DD87E32C6174B405BCF108E593849404DD87E32C6174B40
48458	14254	50.542012	50.562269000000001	54.259011000000001	54.244272000000002	Центральная	0103000020E61000000100000005000000100533A6604549400DAA0D4E441F4B40100533A660454940F226BF4527214B40FE463B6EF8474940F226BF4527214B40FE463B6EF84749400DAA0D4E441F4B40100533A6604549400DAA0D4E441F4B40
48611	14338	50.419849999999997	50.438651	54.392166000000003	54.379944000000002	Центральная	0103000020E61000000100000005000000E09C11A5BD354940DD274701A2304B40E09C11A5BD354940344DD87E32324B40C9AD49B725384940344DD87E32324B40C9AD49B725384940DD274701A2304B40E09C11A5BD354940DD274701A2304B40
48706	55952	50.349494	50.375912999999997	54.275374999999997	54.262051	Полевая	0103000020E61000000100000005000000F9122A38BC2C49402A711DE38A214B40F9122A38BC2C49406891ED7C3F234B401492CCEA1D3049406891ED7C3F234B401492CCEA1D3049402A711DE38A214B40F9122A38BC2C49402A711DE38A214B40
48134	14337	50.428868999999999	50.472544999999997	54.358029999999999	54.343834999999999	Школьная	0103000020E6100000010000000500000055A2EC2DE53649402E1C08C9022C4B4055A2EC2DE5364940527E52EDD32D4B40B471C45A7C3C4940527E52EDD32D4B40B471C45A7C3C49402E1C08C9022C4B4055A2EC2DE53649402E1C08C9022C4B40
48614	14203	50.463076999999998	50.495047999999997	54.301620999999997	54.269460000000002	Романовская	0103000020E61000000100000005000000D0436D1B463B494043CA4FAA7D224B40D0436D1B463B4940B66455849B264B40A0F99CBB5D3F4940B66455849B264B40A0F99CBB5D3F494043CA4FAA7D224B40D0436D1B463B494043CA4FAA7D224B40
48347	14908	50.285075999999997	50.313021999999997	54.258496000000001	54.253498999999998	Центральная	0103000020E61000000100000005000000EF6FD05E7D244940CB48BDA772204B40EF6FD05E7D244940CB129D6516214B40D976DA1A11284940CB129D6516214B40D976DA1A11284940CB48BDA772204B40EF6FD05E7D244940CB48BDA772204B40
48577	13767	50.454425999999998	50.468817000000001	54.144778000000002	54.133274	Придорожная	0103000020E61000000100000005000000DE3994A12A3A49401CB4571F0F114B40DE3994A12A3A49401497E31588124B4088670932023C49401497E31588124B4088670932023C49401CB4571F0F114B40DE3994A12A3A49401CB4571F0F114B40
48165	55889	50.454937999999999	50.467263000000003	54.404378000000001	54.390183999999998	Чапаева	0103000020E6100000010000000500000094DA8B683B3A494013B69F8CF1314B4094DA8B683B3A4940679C86A8C2334B40C0D02346CF3B4940679C86A8C2334B40C0D02346CF3B494013B69F8CF1314B4094DA8B683B3A494013B69F8CF1314B40
48163	46650	50.221339999999998	50.245297999999998	54.342471000000003	54.332191999999999	Советская	0103000020E61000000100000005000000F8A57EDE541C494015FF7744852A4B40F8A57EDE541C49400A6AF816D62B4B4019E3C3EC651F49400A6AF816D62B4B4019E3C3EC651F494015FF7744852A4B40F8A57EDE541C494015FF7744852A4B40
48449	13122	51.759534000000002	51.773665000000001	54.346617000000002	54.334912000000003	Центральная	0103000020E610000001000000050000009C19FD6838E14940DC847B65DE2A4B409C19FD6838E149406B9E23F25D2C4B40A987687407E349406B9E23F25D2C4B40A987687407E34940DC847B65DE2A4B409C19FD6838E14940DC847B65DE2A4B40
48409	48931	51.830438000000001	51.858339999999998	54.341341999999997	54.322510000000001	Центральная	0103000020E6100000010000000500000086ADD9CA4BEA49400551F70148294B4086ADD9CA4BEA494028603B18B12B4B40A06CCA15DEED494028603B18B12B4B40A06CCA15DEED49400551F70148294B4086ADD9CA4BEA49400551F70148294B40
48573	3840	51.909714999999998	51.932189999999999	54.366622999999997	54.353292000000003	Молодёжная	0103000020E610000001000000050000001FD7868A71F449401FF818AC382D4B401FD7868A71F449400F7BA180ED2E4B4041D47D0052F749400F7BA180ED2E4B4041D47D0052F749401FF818AC382D4B401FD7868A71F449401FF818AC382D4B40
9889	7370	52.189000999999998	52.294336999999999	54.316676000000001	54.293087999999997	Школьная	0103000020E61000000100000005000000A5F44C2F31184A40CE6C57E883254B40A5F44C2F31184A40CCB6D3D688284B405A80B6D5AC254A40CCB6D3D688284B405A80B6D5AC254A40CE6C57E883254B40A5F44C2F31184A40CE6C57E883254B40
48606	12725	51.887706000000001	51.910998999999997	54.212893000000001	54.190283000000001	 Центральная	0103000020E61000000100000005000000433BA759A0F149400DFE7E315B184B40433BA759A0F149400F46EC13401B4B4027D87F9D9BF449400F46EC13401B4B4027D87F9D9BF449400DFE7E315B184B40433BA759A0F149400DFE7E315B184B40
48605	12654	52.013299000000004	52.054406	54.151881000000003	54.139451000000001	переулок Школьный	0103000020E61000000100000005000000E60819C8B3014A407F32C687D9114B40E60819C8B3014A4020F12BD670134B40645A9BC6F6064A4020F12BD670134B40645A9BC6F6064A407F32C687D9114B40E60819C8B3014A407F32C687D9114B40
48570	7228	52.225966999999997	52.252934000000003	54.250990000000002	54.238379000000002	Школьная	0103000020E61000000100000005000000D47C957CEC1C4A40CF86FC33831E4B40D47C957CEC1C4A40C0CFB87020204B40F3052D2460204A40C0CFB87020204B40F3052D2460204A40CF86FC33831E4B40D47C957CEC1C4A40CF86FC33831E4B40
48320	7324	51.868698000000002	51.895198000000001	54.383893	54.367845000000003	Молодежная	0103000020E61000000100000005000000E10CFE7E31EF4940A27F828B152F4B40E10CFE7E31EF4940E814E46723314B40E9B81AD995F24940E814E46723314B40E9B81AD995F24940A27F828B152F4B40E10CFE7E31EF4940A27F828B152F4B40
48600	13019	52.449511999999999	52.492263000000001	54.380668	54.341143000000002	Молодежная	0103000020E610000001000000050000006C94F59B89394A403221E692AA2B4B406C94F59B89394A401E51A1BAB9304B40F3035779023F4A401E51A1BAB9304B40F3035779023F4A403221E692AA2B4B406C94F59B89394A403221E692AA2B4B40
48457	55918	51.860926999999997	51.887185000000002	54.266016	54.24776	Центральная	0103000020E61000000100000005000000279F1EDB32EE4940E4A08499B61F4B40279F1EDB32EE49403B1BF2CF0C224B403A4030478FF149403B1BF2CF0C224B403A4030478FF14940E4A08499B61F4B40279F1EDB32EE4940E4A08499B61F4B40
48407	12496	52.192711000000003	52.21622	54.237304999999999	54.216773000000003	Центральная	0103000020E610000001000000050000002C4A09C1AA184A40F2D3B837BF1B4B402C4A09C1AA184A40B1169F02601E4B40DD5ED218AD1B4A40B1169F02601E4B40DD5ED218AD1B4A40F2D3B837BF1B4B402C4A09C1AA184A40F2D3B837BF1B4B40
48602	12930	52.208646999999999	52.242145000000001	54.404798	54.391117000000001	Молодёжная	0103000020E610000001000000050000004AB4E4F1B41A4A406FF4311F10324B404AB4E4F1B41A4A403CBEBD6BD0334B40E9F17B9BFE1E4A403CBEBD6BD0334B40E9F17B9BFE1E4A406FF4311F10324B404AB4E4F1B41A4A406FF4311F10324B40
47945	3316	51.986834999999999	52.040832999999999	54.303297000000001	54.244602999999998	Советская	0103000020E610000001000000050000002AC6F99B50FE494072C0AE264F1F4B402AC6F99B50FE4940CAFCA36FD2264B407DCC07043A054A40CAFCA36FD2264B407DCC07043A054A4072C0AE264F1F4B402AC6F99B50FE494072C0AE264F1F4B40
47933	3316	51.986834999999999	52.040832999999999	54.303297000000001	54.244602999999998	Северная	0103000020E610000001000000050000002AC6F99B50FE494072C0AE264F1F4B402AC6F99B50FE4940CAFCA36FD2264B407DCC07043A054A40CAFCA36FD2264B407DCC07043A054A4072C0AE264F1F4B402AC6F99B50FE494072C0AE264F1F4B40
48608	3316	51.986834999999999	52.040832999999999	54.303297000000001	54.244602999999998	Молодежная	0103000020E610000001000000050000002AC6F99B50FE494072C0AE264F1F4B402AC6F99B50FE4940CAFCA36FD2264B407DCC07043A054A40CAFCA36FD2264B407DCC07043A054A4072C0AE264F1F4B402AC6F99B50FE494072C0AE264F1F4B40
48434	48801	52.010235999999999	52.035173	54.414188000000003	54.403565999999998	Октябрьская	0103000020E61000000100000005000000F59ECA694F014A4086E3F90CA8334B40F59ECA694F014A40A532C51C04354B40E259828C80044A40A532C51C04354B40E259828C80044A4086E3F90CA8334B40F59ECA694F014A4086E3F90CA8334B40
48428	3793	52.313102999999998	52.345450999999997	54.247923	54.235348000000002	Центральная	0103000020E61000000100000005000000C6A354C213284A40EA961DE21F1E4B40C6A354C213284A408E76DCF0BB1F4B406CAF05BD372C4A408E76DCF0BB1F4B406CAF05BD372C4A40EA961DE21F1E4B40C6A354C213284A40EA961DE21F1E4B40
48132	7226	51.778435000000002	51.823960999999997	54.253056999999998	54.217283999999999	Школьная	0103000020E61000000100000005000000E88711C2A3E34940D7F84CF6CF1B4B40E88711C2A3E349400E83F92B64204B40F816D68D77E949400E83F92B64204B40F816D68D77E94940D7F84CF6CF1B4B40E88711C2A3E34940D7F84CF6CF1B4B40
9965	6944	52.421126000000001	52.442982000000001	54.425382999999997	54.403450999999997	Молодежная	0103000020E6100000010000000500000066BFEE74E7354A40ED444948A4334B4066BFEE74E7354A401EA33CF372364B40BC5B59A2B3384A401EA33CF372364B40BC5B59A2B3384A40ED444948A4334B4066BFEE74E7354A40ED444948A4334B40
47665	9746	50.536181999999997	50.580126999999997	53.412309999999998	53.389519999999997	Нефтяников	0103000020E61000000100000005000000185A9D9CA1444940A79196CADBB14A40185A9D9CA144494029E8F692C6B44A406743FE99414A494029E8F692C6B44A406743FE99414A4940A79196CADBB14A40185A9D9CA1444940A79196CADBB14A40
48596	9481	50.971290000000003	50.986902000000001	53.209282000000002	53.194043999999998	Озерная	0103000020E610000001000000050000004777103B537C494015FE0C6FD6984A404777103B537C49401CD2A8C0C99A4A40B22D03CE527E49401CD2A8C0C99A4A40B22D03CE527E494015FE0C6FD6984A404777103B537C494015FE0C6FD6984A40
47716	55853	50.551183000000002	50.672052000000001	53.286611000000001	53.261975999999997	Тимирязева	0103000020E610000001000000050000003B8E1F2A8D4649401F2BF86D88A14A403B8E1F2A8D46494041D653ABAFA44A400F9BC8CC0556494041D653ABAFA44A400F9BC8CC055649401F2BF86D88A14A403B8E1F2A8D4649401F2BF86D88A14A40
48399	9268	50.738903999999998	50.750591	53.231203999999998	53.219763999999998	Школьная	0103000020E6100000010000000500000019710168945E4940486B0C3A219C4A4019710168945E4940295AB917989D4A4002D6AA5D13604940295AB917989D4A4002D6AA5D13604940486B0C3A219C4A4019710168945E4940486B0C3A219C4A40
48207	9790	50.511496000000001	50.539155000000001	53.352321000000003	53.331892000000003	Советская	0103000020E61000000100000005000000750470B378414940EBE6E26F7BAA4A40750470B378414940D658C2DA18AD4A40C93CF20703454940D658C2DA18AD4A40C93CF20703454940EBE6E26F7BAA4A40750470B378414940EBE6E26F7BAA4A40
48208	9638	50.72719	50.75414	53.332326999999999	53.314030000000002	Советская	0103000020E6100000010000000500000037FDD98F145D494040FB912232A84A4037FDD98F145D4940F549EEB089AA4A407F4DD6A887604940F549EEB089AA4A407F4DD6A88760494040FB912232A84A4037FDD98F145D494040FB912232A84A40
48532	9403	50.844358	50.859853999999999	53.295057	53.270082000000002	Центральная	0103000020E61000000100000005000000D80E46EC136C4940809E060C92A24A40D80E46EC136C49405ABA826DC4A54A40DAAA24B20F6E49405ABA826DC4A54A40DAAA24B20F6E4940809E060C92A24A40D80E46EC136C4940809E060C92A24A40
48422	9356	50.848759000000001	50.880488	53.276732000000003	53.258161999999999	Центральная	0103000020E61000000100000005000000C4978922A46C4940F488D1730BA14A40C4978922A46C4940DBE044F46BA34A409E42AED4B3704940DBE044F46BA34A409E42AED4B3704940F488D1730BA14A40C4978922A46C4940F488D1730BA14A40
47894	9581	51.021362000000003	51.05583	53.348897000000001	53.333984000000001	Школьная	0103000020E6100000010000000500000047B071FDBB82494092B1DAFCBFAA4A4047B071FDBB82494015562AA8A8AC4A405E11FC6F2587494015562AA8A8AC4A405E11FC6F2587494092B1DAFCBFAA4A4047B071FDBB82494092B1DAFCBFAA4A40
47749	1918	50.937432000000001	50.994646000000003	53.081921000000001	53.041339000000001	Молодежная	0103000020E61000000100000005000000A81C93C5FD7749405186AA984A854A40A81C93C5FD77494085ED27637C8A4A40728C648F507F494085ED27637C8A4A40728C648F507F49405186AA984A854A40A81C93C5FD7749405186AA984A854A40
48593	9058	51.191034999999999	51.208975000000002	53.192068999999996	53.185578	Центральная	0103000020E6100000010000000500000018B2BAD573984940B56D1805C1974A4018B2BAD573984940A7C98CB795984A403F575BB1BF9A4940A7C98CB795984A403F575BB1BF9A4940B56D1805C1974A4018B2BAD573984940B56D1805C1974A40
47667	9486	50.768441000000003	50.827308000000002	53.068975000000002	53.048127999999998	Кооперативная	0103000020E61000000100000005000000E9F351465C624940CD02ED0E29864A40E9F351465C624940ED9E3C2CD4884A400EDC813AE5694940ED9E3C2CD4884A400EDC813AE5694940CD02ED0E29864A40E9F351465C624940CD02ED0E29864A40
47893	9272	50.828232999999997	50.864443999999999	53.251859000000003	53.224012999999999	50 лет Октября	0103000020E61000000100000005000000E63BF889036A49407E703E75AC9C4A40E63BF889036A4940051A6CEA3CA04A40999CDA19A66E4940051A6CEA3CA04A40999CDA19A66E49407E703E75AC9C4A40E63BF889036A49407E703E75AC9C4A40
47838	9218	50.637152	50.670299999999997	53.261437000000001	53.252484000000003	Рабочая	0103000020E610000001000000050000005E4A5D328E514940B3614D6551A04A405E4A5D328E514940707B82C476A14A402041F163CC554940707B82C476A14A402041F163CC554940B3614D6551A04A405E4A5D328E514940B3614D6551A04A40
48364	55910	50.856178999999997	50.870148	53.353755999999997	53.346919	Казахская	0103000020E61000000100000005000000D0420246976D494036AE7FD767AC4A40D0420246976D4940C36169E047AD4A4004577902616F4940C36169E047AD4A4004577902616F494036AE7FD767AC4A40D0420246976D494036AE7FD767AC4A40
47720	9110	50.753878999999998	50.790233999999998	53.009925000000003	52.967730000000003	Большая	0103000020E610000001000000050000001212691B7F604940D6AD9E93DE7B4A401212691B7F604940D734EF3845814A40F817416326654940D734EF3845814A40F817416326654940D6AD9E93DE7B4A401212691B7F604940D6AD9E93DE7B4A40
48538	8961	51.128368999999999	51.145229999999998	53.303296000000003	53.288215000000001	Центральная	0103000020E61000000100000005000000FD6838656E904940BB9BA73AE4A44A40FD6838656E904940FA804067D2A64A40F4328AE596924940FA804067D2A64A40F4328AE596924940BB9BA73AE4A44A40FD6838656E904940BB9BA73AE4A44A40
48404	9313	51.092751	51.119062	53.172696000000002	53.154308	Пролетарская	0103000020E61000000100000005000000EDD5C743DF8B49406EC1525DC0934A40EDD5C743DF8B494034130CE71A964A402219726C3D8F494034130CE71A964A402219726C3D8F49406EC1525DC0934A40EDD5C743DF8B49406EC1525DC0934A40
47664	8863	50.949612999999999	51.026446	53.285603999999999	53.260958000000002	Специалистов	0103000020E61000000100000005000000A06D35EB8C79494096D05D1267A14A40A06D35EB8C794940ABCDFFAB8EA44A40158E209562834940ABCDFFAB8EA44A40158E20956283494096D05D1267A14A40A06D35EB8C79494096D05D1267A14A40
48714	8863	50.949612999999999	51.026446	53.285603999999999	53.260958000000002	Комсомольская	0103000020E61000000100000005000000A06D35EB8C79494096D05D1267A14A40A06D35EB8C794940ABCDFFAB8EA44A40158E209562834940ABCDFFAB8EA44A40158E20956283494096D05D1267A14A40A06D35EB8C79494096D05D1267A14A40
48283	9722	50.636263	50.677388000000001	53.353831999999997	53.336199000000001	Юбилейная	0103000020E61000000100000005000000D253E4107151494055F99E9108AB4A40D253E410715149409E23F25D4AAD4A40F75965A6B45649409E23F25D4AAD4A40F75965A6B456494055F99E9108AB4A40D253E4107151494055F99E9108AB4A40
48362	8951	51.12377	51.163421	53.259551999999999	53.235570000000003	Школьная	0103000020E61000000100000005000000EB1C03B2D78F494099F56228279E4A40EB1C03B2D78F494042CEFBFF38A14A40643DB5FAEA94494042CEFBFF38A14A40643DB5FAEA94494099F56228279E4A40EB1C03B2D78F494099F56228279E4A40
47705	8780	50.866985999999997	50.916159999999998	53.339581000000003	53.312905000000001	Конычева	0103000020E61000000100000005000000800BB265F96E4940A0E062450DA84A40800BB265F96E4940E7ABE46377AB4A40A1F31ABB44754940E7ABE46377AB4A40A1F31ABB44754940A0E062450DA84A40800BB265F96E4940A0E062450DA84A40
47663	1994	50.636380000000003	50.707697000000003	53.167012	53.144343999999997	Кирова	0103000020E610000001000000050000000CEA5BE674514940D9AF3BDD79924A400CEA5BE674514940100533A660954A40193DB7D0955A4940100533A660954A40193DB7D0955A4940D9AF3BDD79924A400CEA5BE674514940D9AF3BDD79924A40
48274	1866	50.733415999999998	50.760958000000002	53.427303999999999	53.412540999999997	Юбилейная	0103000020E610000001000000050000007B2E5393E05D49402BA1BB24CEB44A407B2E5393E05D494099B9C0E5B1B64A4096D05D126761494099B9C0E5B1B64A4096D05D12676149402BA1BB24CEB44A407B2E5393E05D49402BA1BB24CEB44A40
47750	48522	51.354035000000003	51.435772	53.352063000000001	53.322502	Школьная	0103000020E61000000100000005000000D751D50451AD49408272DBBE47A94A40D751D50451AD4940DA907F6610AD4A409A417C60C7B74940DA907F6610AD4A409A417C60C7B749408272DBBE47A94A40D751D50451AD49408272DBBE47A94A40
48599	48448	51.189463000000003	51.203612	53.423043999999997	53.411189	Солнечная	0103000020E61000000100000005000000AA66D65240984940CBBC55D7A1B44A40AA66D652409849406F62484E26B64A405D8940F50F9A49406F62484E26B64A405D8940F50F9A4940CBBC55D7A1B44A40AA66D65240984940CBBC55D7A1B44A40
48423	47965	51.446804	51.471795	53.422604	53.413781	Центральная	0103000020E610000001000000050000006ADC9BDF30B94940645A9BC6F6B44A406ADC9BDF30B9494053944BE317B64A404AB54FC763BC494053944BE317B64A404AB54FC763BC4940645A9BC6F6B44A406ADC9BDF30B94940645A9BC6F6B44A40
47714	46576	51.143541999999997	51.198033000000002	53.359189999999998	53.333984000000001	Фрунзе	0103000020E610000001000000050000001CCD91955F92494092B1DAFCBFAA4A401CCD91955F9249406E861BF0F9AD4A40AF433525599949406E861BF0F9AD4A40AF4335255999494092B1DAFCBFAA4A401CCD91955F92494092B1DAFCBFAA4A40
47753	46576	51.143541999999997	51.198033000000002	53.359189999999998	53.333984000000001	Революционная	0103000020E610000001000000050000001CCD91955F92494092B1DAFCBFAA4A401CCD91955F9249406E861BF0F9AD4A40AF433525599949406E861BF0F9AD4A40AF4335255999494092B1DAFCBFAA4A401CCD91955F92494092B1DAFCBFAA4A40
47754	46576	51.143541999999997	51.198033000000002	53.359189999999998	53.333984000000001	Комсомольская	0103000020E610000001000000050000001CCD91955F92494092B1DAFCBFAA4A401CCD91955F9249406E861BF0F9AD4A40AF433525599949406E861BF0F9AD4A40AF4335255999494092B1DAFCBFAA4A401CCD91955F92494092B1DAFCBFAA4A40
48300	55901	51.308939000000002	51.364212999999999	53.550586000000003	53.532414000000003	Центральная	0103000020E61000000100000005000000BFBA2A508BA749405EF7562426C44A40BFBA2A508BA7494057D11F9A79C64A4097E315889EAE494057D11F9A79C64A4097E315889EAE49405EF7562426C44A40BFBA2A508BA749405EF7562426C44A40
48401	47865	51.134990000000002	51.541494999999998	53.640588999999999	53.522635000000001	Революционная	0103000020E61000000100000005000000BEA4315A479149405B5F24B4E5C24A40BEA4315A47914940B39602D2FED14A4048F949B54FC54940B39602D2FED14A4048F949B54FC549405B5F24B4E5C24A40BEA4315A479149405B5F24B4E5C24A40
47895	11731	51.153323999999998	51.179195999999997	53.393247000000002	53.375894000000002	Школьная	0103000020E6100000010000000500000090D8EE1EA09349409E616A4B1DB04A4090D8EE1EA09349400420EEEA55B24A4079C9FFE4EF9649400420EEEA55B24A4079C9FFE4EF9649409E616A4B1DB04A4090D8EE1EA09349409E616A4B1DB04A40
48572	48439	51.062379	51.083094000000003	53.408853999999998	53.389805000000003	Победы	0103000020E61000000100000005000000857AFA08FC8749409D685721E5B14A40857AFA08FC8749405D6BEF5355B44A40363FFED2A28A49405D6BEF5355B44A40363FFED2A28A49409D685721E5B14A40857AFA08FC8749409D685721E5B14A40
48426	11674	51.198644000000002	51.21414	53.226610999999998	53.209874999999997	Центральная	0103000020E61000000100000005000000F8C5A52A6D994940BE9F1A2FDD9A4A40F8C5A52A6D994940F9F4D896019D4A40FA6184F0689B4940F9F4D896019D4A40FA6184F0689B4940BE9F1A2FDD9A4A40F8C5A52A6D994940BE9F1A2FDD9A4A40
48624	11106	51.573878999999998	51.587417000000002	53.487257	53.475388000000002	Гоголя	0103000020E610000001000000050000003B6EF8DD74C9494097749483D9BC4A403B6EF8DD74C94940A0DFF76F5EBE4A40A60EF27A30CB4940A0DFF76F5EBE4A40A60EF27A30CB494097749483D9BC4A403B6EF8DD74C9494097749483D9BC4A40
48540	1660	51.721113000000003	51.741289000000002	53.428575000000002	53.409008999999998	Солнечная	0103000020E6100000010000000500000038DC476E4DDC494084622B685AB44A4038DC476E4DDC49400D71AC8BDBB64A4039F1D58EE2DE49400D71AC8BDBB64A4039F1D58EE2DE494084622B685AB44A4038DC476E4DDC494084622B685AB44A40
47849	48385	51.169879999999999	51.185842999999998	53.258512000000003	53.244509999999998	Физкультурная	0103000020E610000001000000050000004B1FBAA0BE954940C1C58A1A4C9F4A404B1FBAA0BE954940D1CFD4EB16A14A40639813B4C9974940D1CFD4EB16A14A40639813B4C9974940C1C58A1A4C9F4A404B1FBAA0BE954940C1C58A1A4C9F4A40
48597	48355	51.859535000000001	51.893725000000003	53.322001999999998	53.292129000000003	Советская	0103000020E6100000010000000500000039622D3E05EE49404A9BAA7B64A54A4039622D3E05EE4940909F8D5C37A94A400E4FAF9465F24940909F8D5C37A94A400E4FAF9465F249404A9BAA7B64A54A4039622D3E05EE49404A9BAA7B64A54A40
48144	48319	51.271110999999998	51.302363999999997	53.343091999999999	53.331795	Школьная	0103000020E61000000100000005000000FD4AE7C3B3A24940F8FC304278AA4A40FD4AE7C3B3A2494076C24B70EAAB4A406EBE11DDB3A6494076C24B70EAAB4A406EBE11DDB3A64940F8FC304278AA4A40FD4AE7C3B3A24940F8FC304278AA4A40
48405	11573	51.792529000000002	51.828094	53.412422999999997	53.387453000000001	Заречная	0103000020E61000000100000005000000D8101C9771E5494059DE550F98B14A40D8101C9771E54940218FE046CAB44A40C501F4FBFEE94940218FE046CAB44A40C501F4FBFEE9494059DE550F98B14A40D8101C9771E5494059DE550F98B14A40
47752	48260	51.153880999999998	51.196632000000001	53.297913999999999	53.267975999999997	Школьная	0103000020E61000000100000005000000E63C635FB2934940730E9E094DA24A40E63C635FB2934940A182C30B22A64A406DACC43C2B994940A182C30B22A64A406DACC43C2B994940730E9E094DA24A40E63C635FB2934940730E9E094DA24A40
48594	48260	51.153880999999998	51.196632000000001	53.297913999999999	53.267975999999997	Центральная	0103000020E61000000100000005000000E63C635FB2934940730E9E094DA24A40E63C635FB2934940A182C30B22A64A406DACC43C2B994940A182C30B22A64A406DACC43C2B994940730E9E094DA24A40E63C635FB2934940730E9E094DA24A40
47896	48260	51.153880999999998	51.196632000000001	53.297913999999999	53.267975999999997	Советская	0103000020E61000000100000005000000E63C635FB2934940730E9E094DA24A40E63C635FB2934940A182C30B22A64A406DACC43C2B994940A182C30B22A64A406DACC43C2B994940730E9E094DA24A40E63C635FB2934940730E9E094DA24A40
47840	48260	51.153880999999998	51.196632000000001	53.297913999999999	53.267975999999997	Полевая	0103000020E61000000100000005000000E63C635FB2934940730E9E094DA24A40E63C635FB2934940A182C30B22A64A406DACC43C2B994940A182C30B22A64A406DACC43C2B994940730E9E094DA24A40E63C635FB2934940730E9E094DA24A40
48400	10194	51.676036000000003	51.696868000000002	53.319968000000003	53.307256000000002	Советская	0103000020E610000001000000050000009775FF5888D64940F9BF232A54A74A409775FF5888D649401EE21FB6F4A84A4081D07AF832D949401EE21FB6F4A84A4081D07AF832D94940F9BF232A54A74A409775FF5888D64940F9BF232A54A74A40
47927	55861	51.443435000000001	51.562703999999997	53.486592000000002	53.439498	Советская	0103000020E610000001000000050000006D73637AC2B849402654707841B84A406D73637AC2B84940643F8BA548BE4A4008AA46AF06C84940643F8BA548BE4A4008AA46AF06C849402654707841B84A406D73637AC2B849402654707841B84A40
48317	55861	51.443435000000001	51.562703999999997	53.486592000000002	53.439498	Механизаторов	0103000020E610000001000000050000006D73637AC2B849402654707841B84A406D73637AC2B84940643F8BA548BE4A4008AA46AF06C84940643F8BA548BE4A4008AA46AF06C849402654707841B84A406D73637AC2B849402654707841B84A40
47948	55861	51.443435000000001	51.562703999999997	53.486592000000002	53.439498	Красноармейская	0103000020E610000001000000050000006D73637AC2B849402654707841B84A406D73637AC2B84940643F8BA548BE4A4008AA46AF06C84940643F8BA548BE4A4008AA46AF06C849402654707841B84A406D73637AC2B849402654707841B84A40
47781	55861	51.443435000000001	51.562703999999997	53.486592000000002	53.439498	Казакова	0103000020E610000001000000050000006D73637AC2B849402654707841B84A406D73637AC2B84940643F8BA548BE4A4008AA46AF06C84940643F8BA548BE4A4008AA46AF06C849402654707841B84A406D73637AC2B849402654707841B84A40
47940	55861	51.443435000000001	51.562703999999997	53.486592000000002	53.439498	Дружбы	0103000020E610000001000000050000006D73637AC2B849402654707841B84A406D73637AC2B84940643F8BA548BE4A4008AA46AF06C84940643F8BA548BE4A4008AA46AF06C849402654707841B84A406D73637AC2B849402654707841B84A40
47913	55865	50.812188999999996	52.210802999999999	53.724401999999998	53.185200999999999	Озерная	0103000020E61000000100000005000000E19524CFF5674940DF1797AAB4974A40E19524CFF567494018946934B9DC4A400873BB97FB1A4A4018946934B9DC4A400873BB97FB1A4A40DF1797AAB4974A40E19524CFF5674940DF1797AAB4974A40
48007	55865	50.812188999999996	52.210802999999999	53.724401999999998	53.185200999999999	Московская	0103000020E61000000100000005000000E19524CFF5674940DF1797AAB4974A40E19524CFF567494018946934B9DC4A400873BB97FB1A4A4018946934B9DC4A400873BB97FB1A4A40DF1797AAB4974A40E19524CFF5674940DF1797AAB4974A40
48326	55865	50.812188999999996	52.210802999999999	53.724401999999998	53.185200999999999	Красноармейская	0103000020E61000000100000005000000E19524CFF5674940DF1797AAB4974A40E19524CFF567494018946934B9DC4A400873BB97FB1A4A4018946934B9DC4A400873BB97FB1A4A40DF1797AAB4974A40E19524CFF5674940DF1797AAB4974A40
47972	55865	50.812188999999996	52.210802999999999	53.724401999999998	53.185200999999999	Красноармейская	0103000020E61000000100000005000000E19524CFF5674940DF1797AAB4974A40E19524CFF567494018946934B9DC4A400873BB97FB1A4A4018946934B9DC4A400873BB97FB1A4A40DF1797AAB4974A40E19524CFF5674940DF1797AAB4974A40
48318	55865	50.812188999999996	52.210802999999999	53.724401999999998	53.185200999999999	Калинина	0103000020E61000000100000005000000E19524CFF5674940DF1797AAB4974A40E19524CFF567494018946934B9DC4A400873BB97FB1A4A4018946934B9DC4A400873BB97FB1A4A40DF1797AAB4974A40E19524CFF5674940DF1797AAB4974A40
48280	10256	51.264518000000002	51.301358	53.680607000000002	53.629553999999999	Крыгина	0103000020E61000000100000005000000079ACFB9DBA149407288B83995D04A40079ACFB9DBA14940DF3653211ED74A40A93121E692A64940DF3653211ED74A40A93121E692A649407288B83995D04A40079ACFB9DBA149407288B83995D04A40
48403	10051	51.645834999999998	51.676036000000003	53.506529	53.485542000000002	Центральная	0103000020E610000001000000050000005BCEA5B8AAD24940CF6A813D26BE4A405BCEA5B8AAD24940E0BC38F1D5C04A409775FF5888D64940E0BC38F1D5C04A409775FF5888D64940CF6A813D26BE4A405BCEA5B8AAD24940CF6A813D26BE4A40
48598	10006	52.128275000000002	52.149878999999999	53.373137999999997	53.361291000000001	Центральная	0103000020E610000001000000050000007CF2B0506B104A4069AB92C83EAE4A407CF2B0506B104A408A7269FCC2AF4A40B8AD2D3C2F134A408A7269FCC2AF4A40B8AD2D3C2F134A4069AB92C83EAE4A407CF2B0506B104A4069AB92C83EAE4A40
48402	47789	51.651476000000002	51.673116	53.370505999999999	53.360436	Школьная	0103000020E610000001000000050000008010C99063D34940892650C422AE4A408010C99063D34940637C98BD6CAF4A40093543AA28D64940637C98BD6CAF4A40093543AA28D64940892650C422AE4A408010C99063D34940892650C422AE4A40
48211	10747	51.298698999999999	51.334882999999998	53.481721999999998	53.468060999999999	Ленинская	0103000020E61000000100000005000000882CD2C43BA649403BC43F6CE9BB4A40882CD2C43BA64940C1E10511A9BD4A40417E3672DDAA4940C1E10511A9BD4A40417E3672DDAA49403BC43F6CE9BB4A40882CD2C43BA649403BC43F6CE9BB4A40
48206	47838	51.141331999999998	51.198490999999997	53.644689	53.621020000000001	Молодежная	0103000020E610000001000000050000006BF0BE2A17924940BA1457957DCF4A406BF0BE2A17924940A48B4D2B85D24A4071C6302768994940A48B4D2B85D24A4071C6302768994940BA1457957DCF4A406BF0BE2A17924940BA1457957DCF4A40
48212	55893	50.974145999999998	50.987127000000001	53.621634	53.616464000000001	Школьная	0103000020E61000000100000005000000BDC3EDD0B07C4940A794D74AE8CE4A40BDC3EDD0B07C4940740AF2B391CF4A40D2FF722D5A7E4940740AF2B391CF4A40D2FF722D5A7E4940A794D74AE8CE4A40BDC3EDD0B07C4940A794D74AE8CE4A40
48527	55893	50.974145999999998	50.987127000000001	53.621634	53.616464000000001	Набережная	0103000020E61000000100000005000000BDC3EDD0B07C4940A794D74AE8CE4A40BDC3EDD0B07C4940740AF2B391CF4A40D2FF722D5A7E4940740AF2B391CF4A40D2FF722D5A7E4940A794D74AE8CE4A40BDC3EDD0B07C4940A794D74AE8CE4A40
48281	47718	52.118088	52.150264999999997	53.440505999999999	53.4238	Первомайская	0103000020E610000001000000050000006806F1811D0F4A40BC0512143FB64A406806F1811D0F4A408CD8278062B84A40E15D2EE23B134A408CD8278062B84A40E15D2EE23B134A40BC0512143FB64A406806F1811D0F4A40BC0512143FB64A40
48529	9943	50.926661000000003	50.938491999999997	53.540008	53.527082999999998	Школьная	0103000020E6100000010000000500000045BDE0D39C76494087A3AB7477C34A4045BDE0D39C76494008CA6DFB1EC54A4060C77F812078494008CA6DFB1EC54A4060C77F812078494087A3AB7477C34A4045BDE0D39C76494087A3AB7477C34A40
48425	10678	51.389634999999998	51.412219	53.407431000000003	53.398637999999998	 Центральная	0103000020E610000001000000050000004030478FDFB14940AF78EA9106B34A404030478FDFB149403430F2B226B44A4019E59997C3B449403430F2B226B44A4019E59997C3B44940AF78EA9106B34A404030478FDFB14940AF78EA9106B34A40
47799	55846	50.475059999999999	50.550868999999999	53.261626	53.234648	Комсомольская	0103000020E61000000100000005000000A2D11DC4CE3C4940310917F2089E4A40A2D11DC4CE3C494043E4F4F57CA14A40ABB019E08246494043E4F4F57CA14A40ABB019E082464940310917F2089E4A40A2D11DC4CE3C4940310917F2089E4A40
47829	55846	50.475059999999999	50.550868999999999	53.261626	53.234648	Зазина	0103000020E61000000100000005000000A2D11DC4CE3C4940310917F2089E4A40A2D11DC4CE3C494043E4F4F57CA14A40ABB019E08246494043E4F4F57CA14A40ABB019E082464940310917F2089E4A40A2D11DC4CE3C4940310917F2089E4A40
48390	47396	52.059113000000004	52.068266999999999	54.108941999999999	54.099592000000001	Школьная	0103000020E610000001000000050000005DE2C80391074A40BC783F6EBF0C4B405DE2C80391074A409694BBCFF10D4B40B1321AF9BC084A409694BBCFF10D4B40B1321AF9BC084A40BC783F6EBF0C4B405DE2C80391074A40BC783F6EBF0C4B40
48335	7812	51.545448	51.571013999999998	53.930221000000003	53.917107999999999	Центральная	0103000020E6100000010000000500000095D5743DD1C54940327381CB63F54A4095D5743DD1C54940B686527B11F74A4071C79BFC16C94940B686527B11F74A4071C79BFC16C94940327381CB63F54A4095D5743DD1C54940327381CB63F54A40
48696	55944	51.56221	51.585405000000002	54.021478999999999	54.010733999999999	Центральная	0103000020E61000000100000005000000F9BD4D7FF6C74940467A51BB5F014B40F9BD4D7FF6C749408046E9D2BF024B401BF5108DEECA49408046E9D2BF024B401BF5108DEECA4940467A51BB5F014B40F9BD4D7FF6C74940467A51BB5F014B40
48693	2156	51.715983999999999	51.768877000000003	54.090409999999999	54.069364999999998	Советская	0103000020E61000000100000005000000C93A1C5DA5DB4940573ECBF3E0084B40C93A1C5DA5DB49409D9D0C8E920B4B40C4D2C08F6AE249409D9D0C8E920B4B40C4D2C08F6AE24940573ECBF3E0084B40C93A1C5DA5DB4940573ECBF3E0084B40
48528	7375	51.300593999999997	51.312533000000002	54.185440999999997	54.172114000000001	Центральная	0103000020E61000000100000005000000D9AF3BDD79A649408597E0D407164B40D9AF3BDD79A64940342BDB87BC174B40DCF5D21401A84940342BDB87BC174B40DCF5D21401A849408597E0D407164B40D9AF3BDD79A649408597E0D407164B40
48273	7904	51.851413999999998	51.867781000000001	54.078282999999999	54.061031999999997	Школьная	0103000020E61000000100000005000000A3AD4A22FBEC4940360186E5CF074B40A3AD4A22FBEC4940986A662D050A4B408B8BA37213EF4940986A662D050A4B408B8BA37213EF4940360186E5CF074B40A3AD4A22FBEC4940360186E5CF074B40
48367	46651	51.311211999999998	51.340927999999998	54.136808000000002	54.108905	Юбилейная	0103000020E61000000100000005000000B60F79CBD5A7494079AF5A99F00D4B40B60F79CBD5A7494064EAAEEC82114B4035255987A3AB494064EAAEEC82114B4035255987A3AB494079AF5A99F00D4B40B60F79CBD5A7494079AF5A99F00D4B40
48609	7136	51.623699999999999	51.648161000000002	54.086655	54.068330000000003	Школьная	0103000020E61000000100000005000000F241CF66D5CF4940F8AA9509BF084B40F241CF66D5CF49407784D382170B4B4076C58CF0F6D249407784D382170B4B4076C58CF0F6D24940F8AA9509BF084B40F241CF66D5CF4940F8AA9509BF084B40
48394	7763	51.494306999999999	51.516522000000002	53.899307999999998	53.884084000000001	Молодежная	0103000020E610000001000000050000008997A77345BF49405C751DAA29F14A408997A77345BF4940FD8348861CF34A400FD594641DC24940FD8348861CF34A400FD594641DC249405C751DAA29F14A408997A77345BF49405C751DAA29F14A40
48433	46502	51.560746000000002	51.576314000000004	54.062412000000002	54.049156000000004	Центральная	0103000020E6100000010000000500000071AE6186C6C749407B336ABE4A064B4071AE6186C6C749406170CD1DFD074B400D1D3BA8C4C949406170CD1DFD074B400D1D3BA8C4C949407B336ABE4A064B4071AE6186C6C749407B336ABE4A064B40
48564	6660	51.509532999999998	51.534210000000002	53.958097000000002	53.937441	Школьная	0103000020E61000000100000005000000CB9D996038C14940FB761211FEF74A40CB9D996038C14940A7B228ECA2FA4A401C9947FE60C44940A7B228ECA2FA4A401C9947FE60C44940FB761211FEF74A40CB9D996038C14940FB761211FEF74A40
48203	7633	51.822820999999998	51.869200999999997	53.956470000000003	53.932065999999999	Советская	0103000020E6100000010000000500000023BBD23252E9494055DB4DF04DF74A4023BBD23252E9494075CDE49B6DFA4A40435376FA41EF494075CDE49B6DFA4A40435376FA41EF494055DB4DF04DF74A4023BBD23252E9494055DB4DF04DF74A40
48590	7499	51.389958	51.399740999999999	54.087409999999998	54.077882000000002	Колхозная	0103000020E610000001000000050000002368CC24EAB149403A799109F8094B402368CC24EAB14940F3AB3940300B4B4067EF8CB62AB34940F3AB3940300B4B4067EF8CB62AB349403A799109F8094B402368CC24EAB149403A799109F8094B40
48340	7224	51.671382999999999	51.706848000000001	53.837347999999999	53.809258999999997	Советская	0103000020E61000000100000005000000910BCEE0EFD54940307F85CC95E74A40910BCEE0EFD549407DAF21382EEB4A401B9FC9FE79DA49407DAF21382EEB4A401B9FC9FE79DA4940307F85CC95E74A40910BCEE0EFD54940307F85CC95E74A40
48701	55947	51.565624	51.615138999999999	53.819119999999998	53.781288000000004	Куйбышева	0103000020E6100000010000000500000096EA025E66C84940EE60C43E01E44A4096EA025E66C84940F0BF95ECD8E84A4040BFEFDFBCCE4940F0BF95ECD8E84A4040BFEFDFBCCE4940EE60C43E01E44A4096EA025E66C84940EE60C43E01E44A40
48595	7227	51.729790999999999	51.758051999999999	53.856785000000002	53.848323999999998	Центральная	0103000020E6100000010000000500000023F59ECA69DD4940B9347EE195EC4A4023F59ECA69DD4940085A8121ABED4A406D5512D907E14940085A8121ABED4A406D5512D907E14940B9347EE195EC4A4023F59ECA69DD4940B9347EE195EC4A40
48445	46468	51.603963999999998	51.623547000000002	54.121707999999998	54.113813	Молодежная	0103000020E610000001000000050000000DFB3DB14ECD4940096EA46C910E4B400DFB3DB14ECD4940AED4B320940F4B406C425A63D0CF4940AED4B320940F4B406C425A63D0CF4940096EA46C910E4B400DFB3DB14ECD4940096EA46C910E4B40
48534	46598	51.405687999999998	51.433841000000001	54.161814	54.138463999999999	Школьная	0103000020E6100000010000000500000098309A95EDB3494030D63730B9114B4098309A95EDB3494079043752B6144B40FC54151A88B7494079043752B6144B40FC54151A88B7494030D63730B9114B4098309A95EDB3494030D63730B9114B40
48628	55934	51.751539000000001	51.759759000000003	53.936374999999998	53.930072000000003	Управленческая	0103000020E610000001000000050000009355116E32E0494071766B990CF74A409355116E32E0494060E5D022DBF74A40BCEB6CC83FE1494060E5D022DBF74A40BCEB6CC83FE1494071766B990CF74A409355116E32E0494071766B990CF74A40
47715	6871	51.505786999999998	51.557538999999998	54.146566	54.122304999999997	Первомайская	0103000020E61000000100000005000000F8DEDFA0BDC049409291B3B0A70F4B40F8DEDFA0BDC049404F5AB8ACC2124B404D9F1D705DC749404F5AB8ACC2124B404D9F1D705DC749409291B3B0A70F4B40F8DEDFA0BDC049409291B3B0A70F4B40
47718	6871	51.505786999999998	51.557538999999998	54.146566	54.122304999999997	Куйбышевская	0103000020E61000000100000005000000F8DEDFA0BDC049409291B3B0A70F4B40F8DEDFA0BDC049404F5AB8ACC2124B404D9F1D705DC749404F5AB8ACC2124B404D9F1D705DC749409291B3B0A70F4B40F8DEDFA0BDC049409291B3B0A70F4B40
48652	55925	51.549858999999998	51.561078000000002	53.801751000000003	53.795098000000003	Новая	0103000020E61000000100000005000000A4349BC761C64940B98E71C5C5E54A40A4349BC761C649408544DAC69FE64A40A7406667D1C749408544DAC69FE64A40A7406667D1C74940B98E71C5C5E54A40A4349BC761C64940B98E71C5C5E54A40
48589	46619	51.463503000000003	51.481892000000002	54.210017999999998	54.194355000000002	Школьная	0103000020E61000000100000005000000884CF91054BB49403468E89FE0184B40884CF91054BB494021C9ACDEE11A4B401E1A16A3AEBD494021C9ACDEE11A4B401E1A16A3AEBD49403468E89FE0184B40884CF91054BB49403468E89FE0184B40
48607	7070	51.562641999999997	51.588315000000001	54.098562999999999	54.084009000000002	Новая	0103000020E6100000010000000500000092AD2EA704C84940EBC891CEC00A4B4092AD2EA704C849403ECC5EB69D0C4B40855FEAE74DCB49403ECC5EB69D0C4B40855FEAE74DCB4940EBC891CEC00A4B4092AD2EA704C84940EBC891CEC00A4B40
48336	7685	51.772146999999997	51.795313999999998	53.928742	53.916716000000001	Советская	0103000020E610000001000000050000002D5A80B6D5E2494027DC2BF356F54A402D5A80B6D5E24940F8359204E1F64A40850662D9CCE54940F8359204E1F64A40850662D9CCE5494027DC2BF356F54A402D5A80B6D5E2494027DC2BF356F54A40
48133	7511	51.673934000000003	51.703434000000001	53.959510999999999	53.930405999999998	Октябрьская	0103000020E61000000100000005000000CCD4247843D649404700378B17F74A40CCD4247843D649407D93A641D1FA4A407E7214200ADA49407D93A641D1FA4A407E7214200ADA49404700378B17F74A40CCD4247843D649404700378B17F74A40
48131	7511	51.673934000000003	51.703434000000001	53.959510999999999	53.930405999999998	 Советская	0103000020E61000000100000005000000CCD4247843D649404700378B17F74A40CCD4247843D649407D93A641D1FA4A407E7214200ADA49407D93A641D1FA4A407E7214200ADA49404700378B17F74A40CCD4247843D649404700378B17F74A40
48604	6940	51.676234000000001	51.706282000000002	54.213182000000003	54.197789	Лесная	0103000020E61000000100000005000000BD38F1D58ED649401841632651194B40BD38F1D58ED64940460C3B8C491B4B4072E0D57267DA4940460C3B8C491B4B4072E0D57267DA49401841632651194B40BD38F1D58ED649401841632651194B40
48470	26559	50.145774000000003	50.187860000000001	53.986339999999998	53.966583	Школьная	0103000020E61000000100000005000000B64DF1B8A81249404EEFE2FDB8FB4A40B64DF1B8A81249404A5E9D6340FE4A40001DE6CB0B1849404A5E9D6340FE4A40001DE6CB0B1849404EEFE2FDB8FB4A40B64DF1B8A81249404EEFE2FDB8FB4A40
48586	26460	50.051369999999999	50.079810000000002	53.83381	53.810971000000002	Советская	0103000020E610000001000000050000006DFFCA4A930649409180D1E5CDE74A406DFFCA4A93064940F4893C49BAEA4A4067F2CD36370A4940F4893C49BAEA4A4067F2CD36370A49409180D1E5CDE74A406DFFCA4A930649409180D1E5CDE74A40
48231	26363	50.543359000000002	50.567138	53.944654	53.929504999999999	Школьная	0103000020E610000001000000050000005F7EA7C98C454940F73B1405FAF64A405F7EA7C98C4549408E041A6CEAF84A40D0285DFA974849408E041A6CEAF84A40D0285DFA97484940F73B1405FAF64A405F7EA7C98C454940F73B1405FAF64A40
48200	25652	50.365088	50.379722000000001	53.980262000000003	53.972360999999999	Школьная	0103000020E61000000100000005000000BE141E34BB2E4940F373435376FC4A40BE141E34BB2E49407BC1A73979FD4A402EC901BB9A3049407BC1A73979FD4A402EC901BB9A304940F373435376FC4A40BE141E34BB2E4940F373435376FC4A40
48469	26506	50.153823000000003	50.173845999999998	53.779336000000001	53.768197999999998	Школьная	0103000020E61000000100000005000000B22FD978B0134940226DE34F54E24A40B22FD978B0134940384C3448C1E34A402C45F29540164940384C3448C1E34A402C45F29540164940226DE34F54E24A40B22FD978B0134940226DE34F54E24A40
48451	23358	49.964053999999997	49.987921999999998	53.933369999999996	53.918911000000001	Комсомольская	0103000020E61000000100000005000000FBC9181F66FB4840A3772AE09EF54A40FBC9181F66FB4840A4880CAB78F74A40DC7F643A74FE4840A4880CAB78F74A40DC7F643A74FE4840A3772AE09EF54A40FBC9181F66FB4840A3772AE09EF54A40
48290	25000	50.358665000000002	50.384402000000001	53.830599999999997	53.821607999999998	Победы	0103000020E61000000100000005000000249C16BCE82D4940E41071732AE94A40249C16BCE82D49405F07CE1951EA4A402D42B115343149405F07CE1951EA4A402D42B11534314940E41071732AE94A40249C16BCE82D4940E41071732AE94A40
47675	55848	50.272300999999999	50.309851000000002	53.894027999999999	53.856126000000003	Школьная	0103000020E6100000010000000500000084D558C2DA224940AEA0698995ED4A4084D558C2DA224940A9DA6E826FF24A4003D19332A9274940A9DA6E826FF24A4003D19332A9274940AEA0698995ED4A4084D558C2DA224940AEA0698995ED4A40
48588	26568	50.250912999999997	50.271286000000003	54.029660999999997	54.009512000000001	Школьная	0103000020E610000001000000050000001492CCEA1D204940B47570B037014B401492CCEA1D204940BB7B80EECB034B406CEEE87FB9224940BB7B80EECB034B406CEEE87FB9224940B47570B037014B401492CCEA1D204940B47570B037014B40
48130	6080	50.362304000000002	50.413615	52.846778999999998	52.818418000000001	Николая Наумова	0103000020E61000000100000005000000E19A3BFA5F2E4940973AC8EBC1684A40E19A3BFA5F2E494044F81741636C4A4049111956F134494044F81741636C4A4049111956F1344940973AC8EBC1684A40E19A3BFA5F2E4940973AC8EBC1684A40
47748	6750	50.361530999999999	50.409329999999997	53.171351999999999	53.153297999999999	Победы	0103000020E61000000100000005000000BEBED6A5462E49406745D4449F934A40BEBED6A5462E4940560DC2DCEE954A40C6A2E9EC64344940560DC2DCEE954A40C6A2E9EC643449406745D4449F934A40BEBED6A5462E49406745D4449F934A40
48711	6698	50.448784000000003	50.489756999999997	53.194594000000002	53.172485999999999	Школьная	0103000020E61000000100000005000000EA7B0DC1713949404982700514964A40EA7B0DC171394940B9FFC874E8984A4058FE7C5BB03E4940B9FFC874E8984A4058FE7C5BB03E49404982700514964A40EA7B0DC1713949404982700514964A40
47879	1303	50.188578	50.244211	52.890191000000002	52.870958999999999	Советская	0103000020E610000001000000050000005F5FEB52231849401494A2957B6F4A405F5FEB5223184940C61858C7F1714A406729594E421F4940C61858C7F1714A406729594E421F49401494A2957B6F4A405F5FEB52231849401494A2957B6F4A40
47925	55869	49.574724000000003	50.663814000000002	53.516638999999998	52.719059000000001	Народная	0103000020E61000000100000005000000F81C588E90C948407E7214200A5C4A40F81C588E90C94840486B0C3A21C24A4040506EDBF7544940486B0C3A21C24A4040506EDBF75449407E7214200A5C4A40F81C588E90C948407E7214200A5C4A40
48289	6188	50.629921000000003	50.663814000000002	53.114752000000003	53.074823000000002	Школьная	0103000020E6100000010000000500000025085740A15049408BFED0CC93894A4025085740A150494047938B31B08E4A4040506EDBF754494047938B31B08E4A4040506EDBF75449408BFED0CC93894A4025085740A15049408BFED0CC93894A40
48523	5959	50.239693000000003	50.253374000000001	53.039226999999997	53.030796000000002	Молодёжная	0103000020E61000000100000005000000420A9E42AE1E49407F6C921FF1834A40420A9E42AE1E4940620FED6305854A400FD4298F6E204940620FED6305854A400FD4298F6E2049407F6C921FF1834A40420A9E42AE1E49407F6C921FF1834A40
48125	1124	50.353994	50.393214999999998	52.917701999999998	52.905706000000002	Центральная	0103000020E61000000100000005000000787DE6AC4F2D49403FE5982CEE734A40787DE6AC4F2D4940A5BC564277754A40F8A57EDE54324940A5BC564277754A40F8A57EDE543249403FE5982CEE734A40787DE6AC4F2D49403FE5982CEE734A40
47666	5967	50.476514999999999	50.500571999999998	53.023333000000001	53.005611999999999	Самарская	0103000020E61000000100000005000000D7868A71FE3C49408A3BDEE4B7804A40D7868A71FE3C494073F56393FC824A408BA548BE1240494073F56393FC824A408BA548BE124049408A3BDEE4B7804A40D7868A71FE3C49408A3BDEE4B7804A40
79094	61378	49.574724000000003	50.663814000000002	53.516638999999998	52.719059000000001	Ново-Садовая	0103000020E61000000100000005000000F81C588E90C948407E7214200A5C4A40F81C588E90C94840486B0C3A21C24A4040506EDBF7544940486B0C3A21C24A4040506EDBF75449407E7214200A5C4A40F81C588E90C948407E7214200A5C4A40
47856	6069	50.503141999999997	50.548839000000001	52.830134000000001	52.804254999999998	 Советская	0103000020E610000001000000050000003C9F01F5664049407E52EDD3F1664A403C9F01F5664049401AA6B6D4416A4A407AE2395B404649401AA6B6D4416A4A407AE2395B404649407E52EDD3F1664A403C9F01F5664049407E52EDD3F1664A40
47855	5273	50.353859999999997	50.389567999999997	53.317977999999997	53.284592000000004	Физкультурная	0103000020E6100000010000000500000068AED3484B2D4940045ABA826DA44A4068AED3484B2D49407A6CCB80B3A84A40B8C83D5DDD3149407A6CCB80B3A84A40B8C83D5DDD314940045ABA826DA44A4068AED3484B2D4940045ABA826DA44A40
47837	5273	50.353859999999997	50.389567999999997	53.317977999999997	53.284592000000004	Коммунаров	0103000020E6100000010000000500000068AED3484B2D4940045ABA826DA44A4068AED3484B2D49407A6CCB80B3A84A40B8C83D5DDD3149407A6CCB80B3A84A40B8C83D5DDD314940045ABA826DA44A4068AED3484B2D4940045ABA826DA44A40
48414	55912	50.534582999999998	50.544373999999998	52.745659000000003	52.739553000000001	 Школьная	0103000020E61000000100000005000000B0FF3A376D444940505436ACA95E4A40B0FF3A376D444940EA7B0DC1715F4A407765170CAE454940EA7B0DC1715F4A407765170CAE454940505436ACA95E4A40B0FF3A376D444940505436ACA95E4A40
47706	5811	50.201298999999999	50.237015999999997	53.083035000000002	53.069001999999998	Школьная	0103000020E61000000100000005000000D7DB662AC4194940E6ADBA0ED5884A40D7DB662AC419494031B610E4A08A4A407A50508A561E494031B610E4A08A4A407A50508A561E4940E6ADBA0ED5884A40D7DB662AC4194940E6ADBA0ED5884A40
48182	5811	50.201298999999999	50.237015999999997	53.083035000000002	53.069001999999998	Советская	0103000020E61000000100000005000000D7DB662AC4194940E6ADBA0ED5884A40D7DB662AC419494031B610E4A08A4A407A50508A561E494031B610E4A08A4A407A50508A561E4940E6ADBA0ED5884A40D7DB662AC4194940E6ADBA0ED5884A40
47834	4528	50.017620000000001	50.056516999999999	53.496834999999997	53.481566000000001	проспект Ленина	0103000020E61000000100000005000000B5E0455F41024940CA6E66F4A3BD4A40B5E0455F410249400B410E4A98BF4A408255F5F23B0749400B410E4A98BF4A408255F5F23B074940CA6E66F4A3BD4A40B5E0455F41024940CA6E66F4A3BD4A40
47820	4528	50.017620000000001	50.056516999999999	53.496834999999997	53.481566000000001	Победы	0103000020E61000000100000005000000B5E0455F41024940CA6E66F4A3BD4A40B5E0455F410249400B410E4A98BF4A408255F5F23B0749400B410E4A98BF4A408255F5F23B074940CA6E66F4A3BD4A40B5E0455F41024940CA6E66F4A3BD4A40
48591	5808	50.163775999999999	50.178598000000001	52.991455999999999	52.977924000000002	Советская	0103000020E6100000010000000500000052EFA99CF61449409CFC169D2C7D4A4052EFA99CF614494024B6BB07E87E4A40C5909C4CDC16494024B6BB07E87E4A40C5909C4CDC1649409CFC169D2C7D4A4052EFA99CF61449409CFC169D2C7D4A40
48204	45852	49.966676999999997	49.98856	52.994323000000001	52.979528999999999	 Школьная	0103000020E61000000100000005000000CF656A12BCFB4840E63DCE34617D4A40CF656A12BCFB48408F54DFF9457F4A401F11532289FE48408F54DFF9457F4A401F11532289FE4840E63DCE34617D4A40CF656A12BCFB4840E63DCE34617D4A40
47857	5659	50.270747	50.307577999999999	52.989705000000001	52.959566000000002	Советская	0103000020E61000000100000005000000BC3E73D6A7224940412D060FD37A4A40BC3E73D6A722494006D847A7AE7E4A400B7C45B75E27494006D847A7AE7E4A400B7C45B75E274940412D060FD37A4A40BC3E73D6A7224940412D060FD37A4A40
48171	6281	52.031543999999997	52.074043000000003	53.285890000000002	53.266156000000002	Кооперативная	0103000020E61000000100000005000000483140A209044A402DD1596611A24A40483140A209044A407120240B98A44A40B6BFB33D7A094A407120240B98A44A40B6BFB33D7A094A402DD1596611A24A40483140A209044A402DD1596611A24A40
48495	5929	51.510216	51.528083000000002	53.020457	53.007334999999998	Центральная	0103000020E61000000100000005000000AEF204C24EC14940DE8E705AF0804A40AEF204C24EC14940B5FCC0559E824A406B49473998C34940B5FCC0559E824A406B49473998C34940DE8E705AF0804A40AEF204C24EC14940DE8E705AF0804A40
48499	16162	51.689582000000001	51.708680999999999	52.844124999999998	52.805065999999997	Центральная	0103000020E6100000010000000500000084F4143944D849408E8F16670C674A4084F4143944D84940355EBA490C6C4A40F6251B0FB6DA4940355EBA490C6C4A40F6251B0FB6DA49408E8F16670C674A4084F4143944D849408E8F16670C674A40
48482	47889	51.979343	51.992790999999997	53.196601000000001	53.189253000000001	Молодежная	0103000020E610000001000000050000008448861C5BFD4940BFD53A7139984A408448861C5BFD494032AEB8382A994A40AE6186C613FF494032AEB8382A994A40AE6186C613FF4940BFD53A7139984A408448861C5BFD4940BFD53A7139984A40
48535	16151	51.705275999999998	51.722271999999997	52.778714999999998	52.756037999999997	Восточная	0103000020E61000000100000005000000AC53E57B46DA494041446ADAC5604A40AC53E57B46DA4940CBF3E0EEAC634A408368AD6873DC4940CBF3E0EEAC634A408368AD6873DC494041446ADAC5604A40AC53E57B46DA494041446ADAC5604A40
48360	15876	51.938738999999998	51.967827	53.134042999999998	53.113951999999998	Октябрьская	0103000020E61000000100000005000000683D7C9928F849402AA8A8FA958E4A40683D7C9928F84940FDA02E5228914A40C89750C1E1FB4940FDA02E5228914A40C89750C1E1FB49402AA8A8FA958E4A40683D7C9928F849402AA8A8FA958E4A40
48654	15190	51.483051000000003	51.505437000000001	52.94265	52.909582999999998	Центральная	0103000020E610000001000000050000006AA67B9DD4BD4940B0FF3A376D744A406AA67B9DD4BD494086C954C1A8784A401C98DC28B2C0494086C954C1A8784A401C98DC28B2C04940B0FF3A376D744A406AA67B9DD4BD4940B0FF3A376D744A40
48653	15918	52.005285999999998	52.031337999999998	53.161290000000001	53.145105999999998	Молодежная	0103000020E6100000010000000500000036902E36AD004A40083A5AD592924A4036902E36AD004A40FF959526A5944A409F8F32E202044A40FF959526A5944A409F8F32E202044A40083A5AD592924A4036902E36AD004A40083A5AD592924A40
48277	6291	51.787498999999997	51.814754000000001	53.229619	53.216366999999998	Центральная	0103000020E61000000100000005000000FC5069C4CCE449408177F2E9B19B4A40FC5069C4CCE4494026C5C727649D4A408124ECDB49E8494026C5C727649D4A408124ECDB49E849408177F2E9B19B4A40FC5069C4CCE449408177F2E9B19B4A40
42041	6142	51.594926999999998	51.626629000000001	53.207118999999999	53.192208999999998	улица Школьная	0103000020E61000000100000005000000F240649126CC4940997FF44D9A984A40F240649126CC4940ABB019E0829A4A40D3DC0A6135D04940ABB019E0829A4A40D3DC0A6135D04940997FF44D9A984A40F240649126CC4940997FF44D9A984A40
48694	55943	51.838540999999999	51.859247000000003	53.191232999999997	53.173262999999999	Молодежная	0103000020E6100000010000000500000075ADBD4F55EB4940AD4D637B2D964A4075ADBD4F55EB49403E75AC527A984A40D31742CEFBED49403E75AC527A984A40D31742CEFBED4940AD4D637B2D964A4075ADBD4F55EB4940AD4D637B2D964A40
47778	15593	51.731991999999998	51.753785000000001	53.049508000000003	53.040857000000003	переулок Строителей	0103000020E610000001000000050000008177F2E9B1DD494006685BCD3A854A408177F2E9B1DD4940F871344756864A40919BE1067CE04940F871344756864A40919BE1067CE0494006685BCD3A854A408177F2E9B1DD494006685BCD3A854A40
48544	6187	51.964619999999996	51.989834999999999	53.254106	53.238377	Звездная	0103000020E61000000100000005000000A4880CAB78FB49402E8F3523839E4A40A4880CAB78FB4940D3DB9F8B86A04A40D4B7CCE9B2FE4940D3DB9F8B86A04A40D4B7CCE9B2FE49402E8F3523839E4A40A4880CAB78FB49402E8F3523839E4A40
48377	6071	51.840490000000003	51.859948000000003	53.132784000000001	53.114303	Садовая	0103000020E61000000100000005000000BA4E232D95EB4940D76A0F7BA18E4A40BA4E232D95EB49404EB7EC10FF904A405C21ACC612EE49404EB7EC10FF904A405C21ACC612EE4940D76A0F7BA18E4A40BA4E232D95EB4940D76A0F7BA18E4A40
47695	19619	51.578631999999999	51.584237000000002	53.287999999999997	53.273764999999997	Пенькова	0103000020E61000000100000005000000A435069D10CA49400CE544BB0AA34A40A435069D10CA4940BE9F1A2FDDA44A407C0E2C47C8CA4940BE9F1A2FDDA44A407C0E2C47C8CA49400CE544BB0AA34A40A435069D10CA49400CE544BB0AA34A40
48493	5861	51.855609000000001	51.900964999999999	53.038285000000002	53.025433999999997	Центральная	0103000020E61000000100000005000000E694809884ED49406D1ADB6B41834A40E694809884ED4940B476DB85E6844A409AEB34D252F34940B476DB85E6844A409AEB34D252F349406D1ADB6B41834A40E694809884ED49406D1ADB6B41834A40
48278	15499	51.518301000000001	51.569918000000001	53.120004999999999	53.090162999999997	Нижне-Ленинская	0103000020E61000000100000005000000F73DEAAF57C24940952710768A8B4A40F73DEAAF57C24940A12DE7525C8F4A406CB3B112F3C84940A12DE7525C8F4A406CB3B112F3C84940952710768A8B4A40F73DEAAF57C24940952710768A8B4A40
48496	15495	51.794702999999998	51.830914	52.971905	52.955584999999999	Центральная	0103000020E610000001000000050000003C84F1D3B8E549402AC6F99B507A4A403C84F1D3B8E54940D1E80E62677C4A40EFE4D3635BEA4940D1E80E62677C4A40EFE4D3635BEA49402AC6F99B507A4A403C84F1D3B8E549402AC6F99B507A4A40
48237	15407	51.673609999999996	51.737535000000001	52.983806999999999	52.962007	Любимовка	0103000020E6100000010000000500000018213CDA38D64940F4C29D0B237B4A4018213CDA38D64940B6494563ED7D4A40E353008C67DE4940B6494563ED7D4A40E353008C67DE4940F4C29D0B237B4A4018213CDA38D64940F4C29D0B237B4A40
47823	55863	51.661079000000001	51.671247999999999	53.209060999999998	53.204039000000002	Советская	0103000020E610000001000000050000004489963C9ED44940E50D30F31D9A4A404489963C9ED449403DEFC682C29A4A40B1C05774EBD549403DEFC682C29A4A40B1C05774EBD54940E50D30F31D9A4A404489963C9ED44940E50D30F31D9A4A40
48376	3432	51.721094999999998	51.752554000000003	53.142254000000001	53.120837000000002	Молодежная	0103000020E61000000100000005000000912749D74CDC4940C9923996778F4A40912749D74CDC4940D3DC0A6135924A40AC3C81B053E04940D3DC0A6135924A40AC3C81B053E04940C9923996778F4A40912749D74CDC4940C9923996778F4A40
48498	16055	51.670169999999999	51.691189999999999	52.722261000000003	52.705053999999997	Луговая	0103000020E6100000010000000500000052616C21C8D54940FDF49F353F5A4A4052616C21C8D549409016670C735C4A403FA9F6E978D849409016670C735C4A403FA9F6E978D84940FDF49F353F5A4A4052616C21C8D54940FDF49F353F5A4A40
48276	15050	51.568264999999997	51.609974000000001	53.001559	52.983753	Школьная 	0103000020E61000000100000005000000103B53E8BCC84940C32B499EEB7D4A40103B53E8BCC84940DA01D71533804A4085B4C6A013CE4940DA01D71533804A4085B4C6A013CE4940C32B499EEB7D4A40103B53E8BCC84940C32B499EEB7D4A40
47930	15975	52.055287	52.112321000000001	53.191966999999998	53.170197000000002	Школьная	0103000020E610000001000000050000006D72F8A413074A404C70EA03C9954A406D72F8A413074A40A374E95F92984A40B7D3D688600E4A40A374E95F92984A40B7D3D688600E4A404C70EA03C9954A406D72F8A413074A404C70EA03C9954A40
48497	15975	52.055287	52.112321000000001	53.191966999999998	53.170197000000002	Центральная	0103000020E610000001000000050000006D72F8A413074A404C70EA03C9954A406D72F8A413074A40A374E95F92984A40B7D3D688600E4A40A374E95F92984A40B7D3D688600E4A404C70EA03C9954A406D72F8A413074A404C70EA03C9954A40
47810	5866	51.668418000000003	51.730204000000001	53.044890000000002	53.016328999999999	Степана Разина	0103000020E61000000100000005000000640795B88ED54940FA7C941117824A40640795B88ED549406FF59CF4BE854A4046B41D5377DD49406FF59CF4BE854A4046B41D5377DD4940FA7C941117824A40640795B88ED54940FA7C941117824A40
47883	5866	51.668418000000003	51.730204000000001	53.044890000000002	53.016328999999999	Советская	0103000020E61000000100000005000000640795B88ED54940FA7C941117824A40640795B88ED549406FF59CF4BE854A4046B41D5377DD49406FF59CF4BE854A4046B41D5377DD4940FA7C941117824A40640795B88ED54940FA7C941117824A40
47889	5866	51.668418000000003	51.730204000000001	53.044890000000002	53.016328999999999	Первомайская	0103000020E61000000100000005000000640795B88ED54940FA7C941117824A40640795B88ED549406FF59CF4BE854A4046B41D5377DD49406FF59CF4BE854A4046B41D5377DD4940FA7C941117824A40640795B88ED54940FA7C941117824A40
47777	5866	51.668418000000003	51.730204000000001	53.044890000000002	53.016328999999999	Ленинградская	0103000020E61000000100000005000000640795B88ED54940FA7C941117824A40640795B88ED549406FF59CF4BE854A4046B41D5377DD49406FF59CF4BE854A4046B41D5377DD4940FA7C941117824A40640795B88ED54940FA7C941117824A40
48492	14728	51.885218000000002	51.910200000000003	53.112876	53.094338	Молодежная	0103000020E610000001000000050000004FEACBD24EF1494091628044138C4A404FEACBD24EF149406C4084B8728E4A40DC68006F81F449406C4084B8728E4A40DC68006F81F4494091628044138C4A404FEACBD24EF1494091628044138C4A40
48543	15197	51.448439	51.470097000000003	52.860407000000002	52.842374	Центральная	0103000020E610000001000000050000001FA0FB7266B94940178046E9D26B4A401FA0FB7266B94940EF1F0BD1216E4A404F7974232CBC4940EF1F0BD1216E4A404F7974232CBC4940178046E9D26B4A401FA0FB7266B94940178046E9D26B4A40
48145	6081	51.647460000000002	51.676251000000001	52.913052999999998	52.895059000000003	Школьная	0103000020E61000000100000005000000EDBB22F8DFD24940C87E164B91724A40EDBB22F8DFD24940E141B3EBDE744A4093718C648FD64940E141B3EBDE744A4093718C648FD64940C87E164B91724A40EDBB22F8DFD24940C87E164B91724A40
48489	13765	50.649351000000003	50.669697999999997	52.065719999999999	52.049373000000003	Школьная	0103000020E61000000100000005000000FD4FFEEE1D5349401827BEDA51064A40FD4FFEEE1D534940B858518369084A402A1900AAB8554940B858518369084A402A1900AAB85549401827BEDA51064A40FD4FFEEE1D5349401827BEDA51064A40
48374	14719	50.844034000000001	50.867156999999999	52.205309	52.200628000000002	Степная	0103000020E61000000100000005000000255B5D4E096C4940B954A52DAE194A40255B5D4E096C49408849B890471A4A40ADBF2500FF6E49408849B890471A4A40ADBF2500FF6E4940B954A52DAE194A40255B5D4E096C4940B954A52DAE194A40
48436	13861	50.957841999999999	50.975726999999999	51.944021999999997	51.933633	Центральная	0103000020E610000001000000050000001C5E10919A7A4940B2BB404981F749401C5E10919A7A49402D5A80B6D5F849407F69519FE47C49402D5A80B6D5F849407F69519FE47C4940B2BB404981F749401C5E10919A7A4940B2BB404981F74940
48272	55897	51.013464999999997	51.065216999999997	52.170248000000001	52.153266000000002	Школьная	0103000020E6100000010000000500000000529B38B98149405CCB64389E134A4000529B38B9814940CE1ABCAFCA154A405512D90759884940CE1ABCAFCA154A405512D907598849405CCB64389E134A4000529B38B98149405CCB64389E134A40
48530	14065	50.598101999999997	50.622042999999998	52.111085000000003	52.092773999999999	Школьная	0103000020E610000001000000050000000AD6389B8E4C4940A5F5B704E00B4A400AD6389B8E4C4940C0098508380E4A4055DAE21A9F4F4940C0098508380E4A4055DAE21A9F4F4940A5F5B704E00B4A400AD6389B8E4C4940A5F5B704E00B4A40
48373	48811	50.198279999999997	50.223908999999999	52.044083999999998	52.032549000000003	Центральная	0103000020E61000000100000005000000B6B9313D611949403E42CD902A044A40B6B9313D611949407023658BA4054A40D923D40CA91C49407023658BA4054A40D923D40CA91C49403E42CD902A044A40B6B9313D611949403E42CD902A044A40
9655	40260	50.899757000000001	50.911399000000003	51.894405999999996	51.882761000000002	Центральная	0103000020E610000001000000050000006DACC43C2B7349409697FC4FFEF049406DACC43C2B7349404FAC53E57BF24940B64DF1B8A87449404FAC53E57BF24940B64DF1B8A87449409697FC4FFEF049406DACC43C2B7349409697FC4FFEF04940
48170	48922	50.806224	50.825026000000001	51.938741999999998	51.925291999999999	Физкультурная	0103000020E610000001000000050000000AA01859326749400EA0DFF76FF649400AA0185932674940D9B0A6B228F84940C32CB4739A694940D9B0A6B228F84940C32CB4739A6949400EA0DFF76FF649400AA01859326749400EA0DFF76FF64940
48517	14433	50.440511000000001	50.461289000000001	52.126247999999997	52.100216000000003	Советская	0103000020E610000001000000050000009E4319AA623849409A44BDE0D30C4A409E4319AA62384940BB97FBE428104A40958098840B3B4940BB97FBE428104A40958098840B3B49409A44BDE0D30C4A409E4319AA623849409A44BDE0D30C4A40
48366	248	50.669410999999997	50.690278999999997	52.240577999999999	52.225509000000002	Набережная	0103000020E61000000100000005000000944A7842AF55494012FA997ADD1C4A40944A7842AF5549408C118942CB1E4A40CB0EF10F5B5849408C118942CB1E4A40CB0EF10F5B58494012FA997ADD1C4A40944A7842AF55494012FA997ADD1C4A40
48507	14449	50.445585999999999	50.469481999999999	52.032688	52.013213999999998	Молодежная	0103000020E6100000010000000500000019C748F608394940B7EC10FFB0014A4019C748F6083949405F7CD11E2F044A40C40776FC173C49405F7CD11E2F044A40C40776FC173C4940B7EC10FFB0014A4019C748F608394940B7EC10FFB0014A40
48480	13482	50.717227999999999	50.730730000000001	52.146684	52.134816999999998	Степная	0103000020E6100000010000000500000043E38920CE5B4940F0F8F6AE41114A4043E38920CE5B4940596C938AC6124A40611A868F885D4940596C938AC6124A40611A868F885D4940F0F8F6AE41114A4043E38920CE5B4940F0F8F6AE41114A40
48536	48863	51.295859999999998	51.314535999999997	52.177677000000003	52.169387	Школьная	0103000020E61000000100000005000000E71890BDDEA549400CAF2479AE154A40E71890BDDEA549402E20B41EBE164A4013B534B742A849402E20B41EBE164A4013B534B742A849400CAF2479AE154A40E71890BDDEA549400CAF2479AE154A40
48368	48837	51.252929000000002	51.270733999999997	52.173982000000002	52.166944999999998	Школьная	0103000020E61000000100000005000000E19A3BFA5FA04940889D29745E154A40E19A3BFA5FA04940DD0BCC0A45164A4027F56569A7A24940DD0BCC0A45164A4027F56569A7A24940889D29745E154A40E19A3BFA5FA04940889D29745E154A40
48531	5719	50.904428000000003	50.924002000000002	52.185363000000002	52.176732000000001	Центральная	0103000020E6100000010000000500000019CBF44BC47349400E1478279F164A4019CBF44BC4734940B9718BF9B9174A4024B891B245764940B9718BF9B9174A4024B891B2457649400E1478279F164A4019CBF44BC47349400E1478279F164A40
48146	13973	50.415556000000002	50.445729999999998	52.173721999999998	52.137244000000003	Центральная	0103000020E610000001000000050000000BD462F0303549403FC91D3691114A400BD462F030354940404CC2853C164A404C6C3EAE0D394940404CC2853C164A404C6C3EAE0D3949403FC91D3691114A400BD462F0303549403FC91D3691114A40
48371	48655	51.081907999999999	51.110492999999998	51.965130000000002	51.943615999999999	Набережная	0103000020E61000000100000005000000F0A31AF67B8A4940BDFDB968C8F84940F0A31AF67B8A4940BA313D6189FB4940EDB776A2248E4940BA313D6189FB4940EDB776A2248E4940BDFDB968C8F84940F0A31AF67B8A4940BDFDB968C8F84940
48650	13919	51.164023	51.182690000000001	52.058000999999997	52.047046999999999	Школьная	0103000020E610000001000000050000005A65A6B4FE944940FD2FD7A205064A405A65A6B4FE9449405111A7936C074A4033A7CB62629749405111A7936C074A4033A7CB6262974940FD2FD7A205064A405A65A6B4FE944940FD2FD7A205064A40
48142	5596	50.830955000000003	50.886308999999997	52.109492000000003	52.077112999999997	Шоссейная	0103000020E610000001000000050000004EB9C2BB5C6A4940588CBAD6DE094A404EB9C2BB5C6A49403A9677D5030E4A404293C492727149403A9677D5030E4A404293C49272714940588CBAD6DE094A404EB9C2BB5C6A4940588CBAD6DE094A40
47808	5596	50.830955000000003	50.886308999999997	52.109492000000003	52.077112999999997	Советская	0103000020E610000001000000050000004EB9C2BB5C6A4940588CBAD6DE094A404EB9C2BB5C6A49403A9677D5030E4A404293C492727149403A9677D5030E4A404293C49272714940588CBAD6DE094A404EB9C2BB5C6A4940588CBAD6DE094A40
48236	5596	50.830955000000003	50.886308999999997	52.109492000000003	52.077112999999997	Полевая	0103000020E610000001000000050000004EB9C2BB5C6A4940588CBAD6DE094A404EB9C2BB5C6A49403A9677D5030E4A404293C492727149403A9677D5030E4A404293C49272714940588CBAD6DE094A404EB9C2BB5C6A4940588CBAD6DE094A40
47890	5596	50.830955000000003	50.886308999999997	52.109492000000003	52.077112999999997	Микрорайон №7	0103000020E610000001000000050000004EB9C2BB5C6A4940588CBAD6DE094A404EB9C2BB5C6A49403A9677D5030E4A404293C492727149403A9677D5030E4A404293C49272714940588CBAD6DE094A404EB9C2BB5C6A4940588CBAD6DE094A40
48370	48748	50.436261999999999	50.459384999999997	52.234495000000003	52.221730000000001	Набережная	0103000020E61000000100000005000000683EE76ED737494063450DA6611C4A40683EE76ED7374940AB09A2EE031E4A40F0A2AF20CD3A4940AB09A2EE031E4A40F0A2AF20CD3A494063450DA6611C4A40683EE76ED737494063450DA6611C4A40
48525	48923	50.854598000000003	50.868091	51.992972000000002	51.982944000000003	Школьная	0103000020E610000001000000050000000F9D9E77636D494054E6E61BD1FD49400F9D9E77636D4940FFEBDCB419FF4940D9791B9B1D6F4940FFEBDCB419FF4940D9791B9B1D6F494054E6E61BD1FD49400F9D9E77636D494054E6E61BD1FD4940
48372	14161	50.304254999999998	50.336019	52.085225999999999	52.071460999999999	Центральная	0103000020E610000001000000050000007E52EDD3F126494040F850A225094A407E52EDD3F12649406B6281AFE80A4A40D5EAABAB022B49406B6281AFE80A4A40D5EAABAB022B494040F850A225094A407E52EDD3F126494040F850A225094A40
48235	13314	50.712997000000001	50.757688000000002	52.264212999999998	52.232542000000002	Космическая	0103000020E61000000100000005000000B492567C435B49402579AEEFC31D4A40B492567C435B4940CA1649BBD1214A402C499EEBFB604940CA1649BBD1214A402C499EEBFB6049402579AEEFC31D4A40B492567C435B49402579AEEFC31D4A40
47824	13314	50.712997000000001	50.757688000000002	52.264212999999998	52.232542000000002	Кооперативная	0103000020E61000000100000005000000B492567C435B49402579AEEFC31D4A40B492567C435B4940CA1649BBD1214A402C499EEBFB604940CA1649BBD1214A402C499EEBFB6049402579AEEFC31D4A40B492567C435B49402579AEEFC31D4A40
48264	24026	51.043801999999999	51.081404999999997	52.345469999999999	52.324585999999996	Центральная	0103000020E61000000100000005000000ECBFCE4D9B854940A65EB7088C294A40ECBFCE4D9B854940E3DF675C382C4A408D5DA27A6B8A4940E3DF675C382C4A408D5DA27A6B8A4940A65EB7088C294A40ECBFCE4D9B854940A65EB7088C294A40
48267	48316	50.785885999999998	50.815091000000002	52.402743000000001	52.391598999999999	площадь Ленина	0103000020E610000001000000050000002F3196E997644940BA1281EA1F324A402F3196E997644940B2D826158D334A40C921E2E654684940B2D826158D334A40C921E2E654684940BA1281EA1F324A402F3196E997644940BA1281EA1F324A40
48490	12591	51.228341999999998	51.247486000000002	52.306072	52.294187000000001	Центральная	0103000020E61000000100000005000000D026874F3A9D494045F46BEBA7254A40D026874F3A9D4940541C075E2D274A40E31B0A9FAD9F4940541C075E2D274A40E31B0A9FAD9F494045F46BEBA7254A40D026874F3A9D494045F46BEBA7254A40
48266	48270	50.572285000000001	50.611567999999998	52.376483	52.348737999999997	Советская	0103000020E61000000100000005000000E57E87A240494940AC6F6072A32C4A40E57E87A240494940FF3F4E9830304A40DBA337DC474E4940FF3F4E9830304A40DBA337DC474E4940AC6F6072A32C4A40E57E87A240494940AC6F6072A32C4A40
48483	12107	50.717309	50.732104	52.577064	52.565471000000002	Полевая	0103000020E61000000100000005000000301004C8D05B494010EB8D5A61484A40301004C8D05B494077D9AF3BDD494A40A9A27895B55D494077D9AF3BDD494A40A9A27895B55D494010EB8D5A61484A40301004C8D05B494010EB8D5A61484A40
48553	48091	50.888599999999997	50.902999999999999	52.447718999999999	52.437103	Заречная	0103000020E61000000100000005000000E09C11A5BD714940E3FDB8FDF2374A40E09C11A5BD7149401F662FDB4E394A40DD240681957349401F662FDB4E394A40DD24068195734940E3FDB8FDF2374A40E09C11A5BD714940E3FDB8FDF2374A40
48713	12650	51.108533999999999	51.130299999999998	52.324674000000002	52.314368999999999	Центральная	0103000020E6100000010000000500000085402E71E48D494028F04E3E3D284A4085402E71E48D494046EEE9EA8E294A409B559FABAD90494046EEE9EA8E294A409B559FABAD90494028F04E3E3D284A4085402E71E48D494028F04E3E3D284A40
48355	12337	50.724854999999998	50.784638000000001	52.414487999999999	52.389961	Центральная	0103000020E61000000100000005000000C9AB730CC85C494094DBF63DEA314A40C9AB730CC85C4940CF4A5AF10D354A4074999A046F644940CF4A5AF10D354A4074999A046F64494094DBF63DEA314A40C9AB730CC85C494094DBF63DEA314A40
48261	12158	50.398181999999998	50.430602999999998	52.681296000000003	52.660795999999998	Юбилейная	0103000020E610000001000000050000008DEDB5A0F7324940EFA99CF694544A408DEDB5A0F7324940A47213B534574A409D47C5FF1D374940A47213B534574A409D47C5FF1D374940EFA99CF694544A408DEDB5A0F7324940EFA99CF694544A40
48651	12929	50.817883999999999	50.842686999999998	52.394660000000002	52.386251000000001	Солнечная	0103000020E61000000100000005000000F9F5436CB06849400E863AAC70314A40F9F5436CB06849400A85083884324A40D6E1E82ADD6B49400A85083884324A40D6E1E82ADD6B49400E863AAC70314A40F9F5436CB06849400E863AAC70314A40
48491	48125	50.973723999999997	51.012855000000002	52.358764999999998	52.344721999999997	Центральная	0103000020E6100000010000000500000047AAEFFCA27C4940191BBAD91F2C4A4047AAEFFCA27C494087F9F202EC2D4A40884B8E3BA581494087F9F202EC2D4A40884B8E3BA5814940191BBAD91F2C4A4047AAEFFCA27C4940191BBAD91F2C4A40
48190	12724	50.182461000000004	50.225175999999998	52.450096000000002	52.424413000000001	Советская	0103000020E61000000100000005000000D2E5CDE15A174940A67F492A53364A40D2E5CDE15A174940BC07E8BE9C394A400BEC3191D21C4940BC07E8BE9C394A400BEC3191D21C4940A67F492A53364A40D2E5CDE15A174940A67F492A53364A40
48369	12097	50.556770999999998	50.569769999999998	52.648417000000002	52.631701	Степная	0103000020E610000001000000050000003C2EAA4544474940DDEC0F94DB504A403C2EAA4544474940D1950854FF524A40F71E2E39EE484940D1950854FF524A40F71E2E39EE484940DDEC0F94DB504A403C2EAA4544474940DDEC0F94DB504A40
48648	12245	50.493000000000002	50.499782000000003	52.572969999999998	52.563800999999998	Центральная	0103000020E61000000100000005000000C976BE9F1A3F4940DE3994A12A484A40C976BE9F1A3F494068CBB91457494A40939048DBF83F494068CBB91457494A40939048DBF83F4940DE3994A12A484A40C976BE9F1A3F4940DE3994A12A484A40
48354	12495	51.021326000000002	51.036624000000003	52.299683999999999	52.290540999999997	Набережная	0103000020E61000000100000005000000FA4674CFBA824940D5928E7230254A40FA4674CFBA8249403691990B5C264A40D61F6118B08449403691990B5C264A40D61F6118B0844940D5928E7230254A40FA4674CFBA824940D5928E7230254A40
48178	55890	50.132083000000002	50.179371000000003	52.457022000000002	52.432825000000001	Центральная	0103000020E61000000100000005000000C5AD8218E810494013F241CF66374A40C5AD8218E8104940B9C667B27F3A4A40E86C01A1F5164940B9C667B27F3A4A40E86C01A1F516494013F241CF66374A40C5AD8218E810494013F241CF66374A40
48488	48452	50.573901999999997	50.591500000000003	52.299866000000002	52.279544000000001	Советская	0103000020E61000000100000005000000F38DE89E7549494082E50819C8234A40F38DE89E754949405797530262264A40C1CAA145B64B49405797530262264A40C1CAA145B64B494082E50819C8234A40F38DE89E7549494082E50819C8234A40
48649	12389	50.738481999999998	50.752423999999998	52.520670000000003	52.506832000000003	Молодежная	0103000020E61000000100000005000000A3570394865E49407C48F8DEDF404A40A3570394865E494011018750A5424A40DD5CFC6D4F60494011018750A5424A40DD5CFC6D4F6049407C48F8DEDF404A40A3570394865E49407C48F8DEDF404A40
48485	12298	50.315834000000002	50.344642999999998	52.510395000000003	52.467370000000003	Советская	0103000020E61000000100000005000000817B9E3F6D284940D690B8C7D23B4A40817B9E3F6D2849405E85949F54414A40CDE506431D2C49405E85949F54414A40CDE506431D2C4940D690B8C7D23B4A40817B9E3F6D284940D690B8C7D23B4A40
48140	5371	50.443655	50.517991000000002	52.424813999999998	52.371617000000001	Чапаевская	0103000020E610000001000000050000007BDAE1AFC93849409ED15625912F4A407BDAE1AFC938494004711E4E60364A40A94F72874D42494004711E4E60364A40A94F72874D4249409ED15625912F4A407BDAE1AFC93849409ED15625912F4A40
48166	5371	50.443655	50.517991000000002	52.424813999999998	52.371617000000001	Советская	0103000020E610000001000000050000007BDAE1AFC93849409ED15625912F4A407BDAE1AFC938494004711E4E60364A40A94F72874D42494004711E4E60364A40A94F72874D4249409ED15625912F4A407BDAE1AFC93849409ED15625912F4A40
48234	5371	50.443655	50.517991000000002	52.424813999999998	52.371617000000001	Первомайская	0103000020E610000001000000050000007BDAE1AFC93849409ED15625912F4A407BDAE1AFC938494004711E4E60364A40A94F72874D42494004711E4E60364A40A94F72874D4249409ED15625912F4A407BDAE1AFC93849409ED15625912F4A40
47881	5371	50.443655	50.517991000000002	52.424813999999998	52.371617000000001	Луговая	0103000020E610000001000000050000007BDAE1AFC93849409ED15625912F4A407BDAE1AFC938494004711E4E60364A40A94F72874D42494004711E4E60364A40A94F72874D4249409ED15625912F4A407BDAE1AFC93849409ED15625912F4A40
48141	5371	50.443655	50.517991000000002	52.424813999999998	52.371617000000001	Кировская	0103000020E610000001000000050000007BDAE1AFC93849409ED15625912F4A407BDAE1AFC938494004711E4E60364A40A94F72874D42494004711E4E60364A40A94F72874D4249409ED15625912F4A407BDAE1AFC93849409ED15625912F4A40
48168	5371	50.443655	50.517991000000002	52.424813999999998	52.371617000000001	Гагарина	0103000020E610000001000000050000007BDAE1AFC93849409ED15625912F4A407BDAE1AFC938494004711E4E60364A40A94F72874D42494004711E4E60364A40A94F72874D4249409ED15625912F4A407BDAE1AFC93849409ED15625912F4A40
48183	55891	50.590305000000001	50.625366	52.618001	52.576400999999997	Центральная	0103000020E6100000010000000500000028D53E1D8F4B4940DB300A82C7494A4028D53E1D8F4B494099F221A81A4F4A40E2033BFE0B50494099F221A81A4F4A40E2033BFE0B504940DB300A82C7494A4028D53E1D8F4B4940DB300A82C7494A40
48358	47919	51.109172000000001	51.131180999999998	53.037765	53.029442000000003	Центральная	0103000020E61000000100000005000000C8D11C59F98D49407E9065C1C4834A40C8D11C59F98D49407BF7C77BD5844A40A46DFC89CA9049407BF7C77BD5844A40A46DFC89CA9049407E9065C1C4834A40C8D11C59F98D49407E9065C1C4834A40
48521	5059	51.180551999999999	51.231225999999999	53.026035999999998	52.997965999999998	Молодежная	0103000020E610000001000000050000001B9DF3531C9749408D429259BD7F4A401B9DF3531C9749406342CC2555834A4011FE45D0989D49406342CC2555834A4011FE45D0989D49408D429259BD7F4A401B9DF3531C9749408D429259BD7F4A40
48259	11842	51.205885000000002	51.237793000000003	53.070998000000003	53.057702999999997	Советская	0103000020E6100000010000000500000055DE8E705A9A4940C7F0D8CF62874A4055DE8E705A9A49406C0A647616894A40DF1B4300709E49406C0A647616894A40DF1B4300709E4940C7F0D8CF62874A4055DE8E705A9A4940C7F0D8CF62874A40
48494	55922	51.128368999999999	51.13984	53.036898999999998	53.031841	Полевая	0103000020E61000000100000005000000FD6838656E90494002D6AA5D13844A40FD6838656E904940A7203F1BB9844A401956F146E6914940A7203F1BB9844A401956F146E691494002D6AA5D13844A40FD6838656E90494002D6AA5D13844A40
48169	47824	51.115873000000001	51.162658	52.990312000000003	52.965744999999998	Октябрьская	0103000020E61000000100000005000000A5BE2CEDD48E494044A33B889D7B4A40A5BE2CEDD48E49400E6B2A8BC27E4A40653733FAD19449400E6B2A8BC27E4A40653733FAD194494044A33B889D7B4A40A5BE2CEDD48E494044A33B889D7B4A40
48238	5325	51.429986999999997	51.446390999999998	53.056404000000001	53.046698999999997	Зеленая	0103000020E61000000100000005000000425A63D009B74940C1E09A3BFA854A40425A63D009B749408AAE0B3F38874A40471D1D5723B949408AAE0B3F38874A40471D1D5723B94940C1E09A3BFA854A40425A63D009B74940C1E09A3BFA854A40
48143	11675	51.414535999999998	51.482205999999998	53.031782	53.017406999999999	Советская	0103000020E61000000100000005000000E08101840FB5494059DC7F643A824A40E08101840FB54940FD4CBD6E11844A40ADF71BEDB8BD4940FD4CBD6E11844A40ADF71BEDB8BD494059DC7F643A824A40E08101840FB5494059DC7F643A824A40
47776	11336	51.311211999999998	51.353918	53.072302000000001	53.048929000000001	Чапаева	0103000020E61000000100000005000000B60F79CBD5A74940BA69334E43864A40B60F79CBD5A74940BBB7223141894A409DBB5D2F4DAD4940BBB7223141894A409DBB5D2F4DAD4940BA69334E43864A40B60F79CBD5A74940BA69334E43864A40
47775	11336	51.311211999999998	51.353918	53.072302000000001	53.048929000000001	Комсомольская	0103000020E61000000100000005000000B60F79CBD5A74940BA69334E43864A40B60F79CBD5A74940BBB7223141894A409DBB5D2F4DAD4940BBB7223141894A409DBB5D2F4DAD4940BA69334E43864A40B60F79CBD5A74940BA69334E43864A40
47877	11336	51.311211999999998	51.353918	53.072302000000001	53.048929000000001	Заводская	0103000020E61000000100000005000000B60F79CBD5A74940BA69334E43864A40B60F79CBD5A74940BBB7223141894A409DBB5D2F4DAD4940BBB7223141894A409DBB5D2F4DAD4940BA69334E43864A40B60F79CBD5A74940BA69334E43864A40
48139	47659	51.348455999999999	51.391790999999998	53.194215999999997	53.175519000000001	Школьная	0103000020E61000000100000005000000280CCA349AAC4940CF69166877964A40280CCA349AAC4940122EE411DC984A40FEEE1D3526B24940122EE411DC984A40FEEE1D3526B24940CF69166877964A40280CCA349AAC4940CF69166877964A40
48255	11222	51.348770999999999	51.386750999999997	53.176338999999999	53.162229000000004	Школьная	0103000020E6100000010000000500000088653387A4AC49403DBB7CEBC3944A4088653387A4AC49403201BF4692964A40FF58880E81B149403201BF4692964A40FF58880E81B149403DBB7CEBC3944A4088653387A4AC49403DBB7CEBC3944A40
48357	11237	51.295293999999998	51.324893000000003	53.166466999999997	53.151516000000001	Молодёжная	0103000020E610000001000000050000003E5A9C31CCA549400E6954E064934A403E5A9C31CCA549407E6E68CA4E954A4084D9041896A949407E6E68CA4E954A4084D9041896A949400E6954E064934A403E5A9C31CCA549400E6954E064934A40
47807	55862	49.613233999999999	49.614268000000003	52.957326000000002	52.957059999999998	Кооперативная	0103000020E61000000100000005000000CB65A3737ECE4840A6272CF1807A4A40CB65A3737ECE484025CE8AA8897A4A405B7D7555A0CE484025CE8AA8897A4A405B7D7555A0CE4840A6272CF1807A4A40CB65A3737ECE4840A6272CF1807A4A40
48349	55909	49.079312000000002	49.080146999999997	53.049323999999999	53.049112999999998	Вокзальная	0103000020E61000000100000005000000161747E5268A48407B67B45549864A40161747E5268A48403674B33F50864A40AEEFC341428A48403674B33F50864A40AEEFC341428A48407B67B45549864A40161747E5268A48407B67B45549864A40
48301	24225	49.730266999999998	49.749265999999999	52.871926000000002	52.854311000000003	Бр. Краснеевых 	0103000020E610000001000000050000008C2C996379DD484079CE16105A6D4A408C2C996379DD48401C446B459B6F4A409B00C3F2E7DF48401C446B459B6F4A409B00C3F2E7DF484079CE16105A6D4A408C2C996379DD484079CE16105A6D4A40
48233	47596	49.642924000000001	49.663037000000003	52.874763000000002	52.861086	Центральная	0103000020E6100000010000000500000021E868554BD248409085E810386E4A4021E868554BD248401C60E63BF86F4A40DC847B65DED448401C60E63BF86F4A40DC847B65DED448409085E810386E4A4021E868554BD248409085E810386E4A40
48258	11045	48.98462	49.035527999999999	53.081791000000003	53.066875000000003	Школьная	0103000020E61000000100000005000000677E3507087E4840C3F5285C8F884A40677E3507087E4840B70DA320788A4A40D00B772E8C844840B70DA320788A4A40D00B772E8C844840C3F5285C8F884A40677E3507087E4840C3F5285C8F884A40
48254	47516	49.418084	49.449894	52.932158999999999	52.921725000000002	Центральная	0103000020E610000001000000050000008D7DC9C683B54840EB73B515FB754A408D7DC9C683B5484006D671FC50774A405455682096B9484006D671FC50774A405455682096B94840EB73B515FB754A408D7DC9C683B54840EB73B515FB754A40
47875	47300	49.502867000000002	49.528002000000001	52.859242999999999	52.837603000000001	Маяковского	0103000020E610000001000000050000006B9E23F25DC0484008043A93366B4A406B9E23F25DC048409128B4ACFB6D4A407E1CCD9195C348409128B4ACFB6D4A407E1CCD9195C3484008043A93366B4A406B9E23F25DC0484008043A93366B4A40
47780	55860	49.101419	49.128405000000001	52.883338999999999	52.871322999999997	Школьная	0103000020E61000000100000005000000B5183C4CFB8C484055A01683876F4A40B5183C4CFB8C484003249A4011714A404AD235936F90484003249A4011714A404AD235936F90484055A01683876F4A40B5183C4CFB8C484055A01683876F4A40
48352	10974	49.387703000000002	49.400728999999998	52.844712999999999	52.831167999999998	Центральная	0103000020E61000000100000005000000D2C77C40A0B14840A9BD88B6636A4A40D2C77C40A0B14840C6C03A8E1F6C4A4086C77E164BB34840C6C03A8E1F6C4A4086C77E164BB34840A9BD88B6636A4A40D2C77C40A0B14840A9BD88B6636A4A40
48473	47653	49.448025000000001	49.484605000000002	53.048068000000001	53.032035999999998	Пролетарская	0103000020E610000001000000050000002C6519E258B94840B72572C119844A402C6519E258B94840F8FD9B1727864A40323D618907BE4840F8FD9B1727864A40323D618907BE4840B72572C119844A402C6519E258B94840B72572C119844A40
48164	47431	49.034970999999999	49.061380999999997	52.952368	52.927408999999997	Школьная	0103000020E610000001000000050000007AA702EE798448400E828E56B5764A407AA702EE79844840E3E0D231E7794A4042CC2555DB874840E3E0D231E7794A4042CC2555DB8748400E828E56B5764A407AA702EE798448400E828E56B5764A40
48688	11221	48.963977	48.981566000000001	52.857384000000003	52.842253999999997	Мира	0103000020E61000000100000005000000508C2C99637B48406C76A4FACE6B4A40508C2C99637B48408D0E48C2BE6D4A40CA6E66F4A37D48408D0E48C2BE6D4A40CA6E66F4A37D48406C76A4FACE6B4A40508C2C99637B48406C76A4FACE6B4A40
48256	10259	49.544783000000002	49.578955000000001	53.002598999999996	52.983725999999997	 Купинская	0103000020E6100000010000000500000059350873BBC54840C91CCBBBEA7D4A4059350873BBC548404B00FE2955804A40876D8B321BCA48404B00FE2955804A40876D8B321BCA4840C91CCBBBEA7D4A4059350873BBC54840C91CCBBBEA7D4A40
48348	10869	49.286760000000001	49.295625999999999	52.969188000000003	52.956457999999998	Центральная	0103000020E6100000010000000500000086E63A8DB4A44840B0FF3A376D7A4A4086E63A8DB4A448407CD6355A0E7C4A4074ECA012D7A548407CD6355A0E7C4A4074ECA012D7A54840B0FF3A376D7A4A4086E63A8DB4A44840B0FF3A376D7A4A40
48484	10681	49.251931999999996	49.31335	53.166753	53.131622999999998	Центральная	0103000020E610000001000000050000006E68CA4E3FA048406133C005D9904A406E68CA4E3FA0484044C18C2958954A40CE1951DA1BA8484044C18C2958954A40CE1951DA1BA848406133C005D9904A406E68CA4E3FA048406133C005D9904A40
48645	47517	49.315280999999999	49.325279999999999	52.982343	52.972468999999997	Центральная	0103000020E610000001000000050000006C06B8205BA84840D9AF3BDD797C4A406C06B8205BA848402E3A596ABD7D4A407D0569C6A2A948402E3A596ABD7D4A407D0569C6A2A94840D9AF3BDD797C4A406C06B8205BA84840D9AF3BDD797C4A40
47880	47383	49.417276000000001	49.461328999999999	53.106990000000003	53.064770000000003	Фрунзе	0103000020E61000000100000005000000EEB3CA4C69B5484087E123624A884A40EEB3CA4C69B54840E17F2BD9B18D4A4023D923D40CBB4840E17F2BD9B18D4A4023D923D40CBB484087E123624A884A40EEB3CA4C69B5484087E123624A884A40
47783	45709	49.442706999999999	49.456398	52.966845999999997	52.955703999999997	Советская	0103000020E61000000100000005000000EA5A7B9FAAB8484004543882547A4A40EA5A7B9FAAB848405B22179CC17B4A40DBFAE93F6BBA48405B22179CC17B4A40DBFAE93F6BBA484004543882547A4A40EA5A7B9FAAB8484004543882547A4A40
47687	4908	49.393228000000001	49.478513999999997	52.998610999999997	52.965023000000002	Чапаева	0103000020E610000001000000050000008DEF8B4B55B24840A471A8DF857B4A408DEF8B4B55B248408236397CD27F4A40CD565EF23FBD48408236397CD27F4A40CD565EF23FBD4840A471A8DF857B4A408DEF8B4B55B24840A471A8DF857B4A40
47774	4908	49.393228000000001	49.478513999999997	52.998610999999997	52.965023000000002	Центральная	0103000020E610000001000000050000008DEF8B4B55B24840A471A8DF857B4A408DEF8B4B55B248408236397CD27F4A40CD565EF23FBD48408236397CD27F4A40CD565EF23FBD4840A471A8DF857B4A408DEF8B4B55B24840A471A8DF857B4A40
47688	4908	49.393228000000001	49.478513999999997	52.998610999999997	52.965023000000002	Тимирязева	0103000020E610000001000000050000008DEF8B4B55B24840A471A8DF857B4A408DEF8B4B55B248408236397CD27F4A40CD565EF23FBD48408236397CD27F4A40CD565EF23FBD4840A471A8DF857B4A408DEF8B4B55B24840A471A8DF857B4A40
47872	4908	49.393228000000001	49.478513999999997	52.998610999999997	52.965023000000002	Садовая	0103000020E610000001000000050000008DEF8B4B55B24840A471A8DF857B4A408DEF8B4B55B248408236397CD27F4A40CD565EF23FBD48408236397CD27F4A40CD565EF23FBD4840A471A8DF857B4A408DEF8B4B55B24840A471A8DF857B4A40
47772	4908	49.393228000000001	49.478513999999997	52.998610999999997	52.965023000000002	Пушкина	0103000020E610000001000000050000008DEF8B4B55B24840A471A8DF857B4A408DEF8B4B55B248408236397CD27F4A40CD565EF23FBD48408236397CD27F4A40CD565EF23FBD4840A471A8DF857B4A408DEF8B4B55B24840A471A8DF857B4A40
47771	4908	49.393228000000001	49.478513999999997	52.998610999999997	52.965023000000002	Комсомольская	0103000020E610000001000000050000008DEF8B4B55B24840A471A8DF857B4A408DEF8B4B55B248408236397CD27F4A40CD565EF23FBD48408236397CD27F4A40CD565EF23FBD4840A471A8DF857B4A408DEF8B4B55B24840A471A8DF857B4A40
48641	9484	51.282071000000002	51.307592	52.367097000000001	52.353782000000002	Прикотельная	0103000020E6100000010000000500000034130CE71AA44940EDF483BA482D4A4034130CE71AA44940D8BAD408FD2E4A407041B62C5FA74940D8BAD408FD2E4A407041B62C5FA74940EDF483BA482D4A4034130CE71AA44940EDF483BA482D4A40
48643	46699	51.413933999999998	51.436059999999998	52.612479	52.598455999999999	Пионерская	0103000020E61000000100000005000000EA5910CAFBB44940280CCA349A4C4A40EA5910CAFBB449404F3E3DB6654E4A40008C67D0D0B749404F3E3DB6654E4A40008C67D0D0B74940280CCA349A4C4A40EA5910CAFBB44940280CCA349A4C4A40
48477	47045	50.959980000000002	50.995158000000004	52.543590999999999	52.530006999999998	Советская	0103000020E610000001000000050000003468E89FE07A494056D3F544D7434A403468E89FE07A494031B3CF6394454A40282D5C56617F494031B3CF6394454A40282D5C56617F494056D3F544D7434A403468E89FE07A494056D3F544D7434A40
48640	9264	51.371687000000001	51.390101999999999	52.783203	52.770254999999999	Рабочая	0103000020E6100000010000000500000097AC8A7093AF49404D4A41B797624A4097AC8A7093AF49408690F3FE3F644A40560DC2DCEEB149408690F3FE3F644A40560DC2DCEEB149404D4A41B797624A4097AC8A7093AF49404D4A41B797624A40
48345	9883	50.851543999999997	50.899613000000002	52.558891000000003	52.536366999999998	Чапаевская	0103000020E61000000100000005000000718DCF64FF6C4940AAD381ACA7444A40718DCF64FF6C4940AE8383BD89474A403A07CF8426734940AE8383BD89474A403A07CF8426734940AAD381ACA7444A40718DCF64FF6C4940AAD381ACA7444A40
48637	9216	51.306100999999998	51.329537999999999	52.869714000000002	52.851216999999998	Школьная	0103000020E61000000100000005000000EE224C512EA749404D66BCADF46C4A40EE224C512EA74940CA6FD1C9526F4A4006651A4D2EAA4940CA6FD1C9526F4A4006651A4D2EAA49404D66BCADF46C4A40EE224C512EA749404D66BCADF46C4A40
48230	4523	51.310124999999999	51.334567999999997	52.520490000000002	52.492972999999999	Советская	0103000020E6100000010000000500000004560E2DB2A74940CF6740BD193F4A4004560E2DB2A7494091F2936A9F424A40E124CD1FD3AA494091F2936A9F424A40E124CD1FD3AA4940CF6740BD193F4A4004560E2DB2A74940CF6740BD193F4A40
48556	9275	51.287685000000003	51.313763000000002	52.725642000000001	52.715273000000003	Горького	0103000020E610000001000000050000005F46B1DCD2A449401D5BCF108E5B4A405F46B1DCD2A44940514D49D6E15C4A40F1D8CF6229A84940514D49D6E15C4A40F1D8CF6229A849401D5BCF108E5B4A405F46B1DCD2A449401D5BCF108E5B4A40
48524	9791	50.850726999999999	50.922592000000002	52.573255000000003	52.542343000000002	Кирова	0103000020E610000001000000050000007F69519FE46C4940761BD47E6B454A407F69519FE46C49405EA27A6B60494A408FC6A17E177649405EA27A6B60494A408FC6A17E17764940761BD47E6B454A407F69519FE46C4940761BD47E6B454A40
48353	46720	51.307358000000001	51.319180000000003	52.547589000000002	52.533639000000001	Пролетарская	0103000020E61000000100000005000000FD14C78157A74940616F62484E444A40FD14C78157A749401E53776517464A40C6C4E6E3DAA849401E53776517464A40C6C4E6E3DAA84940616F62484E444A40FD14C78157A74940616F62484E444A40
48375	8955	51.087828000000002	51.110672000000001	52.622031	52.601070999999997	Победы	0103000020E6100000010000000500000028D6A9F23D8B494079C9FFE4EF4C4A4028D6A9F23D8B4940910C39B69E4F4A409D4A06802A8E4940910C39B69E4F4A409D4A06802A8E494079C9FFE4EF4C4A4028D6A9F23D8B494079C9FFE4EF4C4A40
48444	9723	50.974497	51.021380000000001	52.548552999999998	52.527202000000003	Захара Вобликова	0103000020E610000001000000050000006A865451BC7C49406231EA5A7B434A406A865451BC7C4940B48F15FC36464A40ED647094BC824940B48F15FC36464A40ED647094BC8249406231EA5A7B434A406A865451BC7C49406231EA5A7B434A40
48343	46752	51.135734999999997	51.147243000000003	52.440973	52.433791999999997	Черемушки	0103000020E6100000010000000500000016F6B4C35F9149401AA20A7F86374A4016F6B4C35F914940A2B5A2CD71384A4050C8CEDBD8924940A2B5A2CD71384A4050C8CEDBD89249401AA20A7F86374A4016F6B4C35F9149401AA20A7F86374A40
48342	9582	51.346677999999997	51.384613000000002	52.719014999999999	52.703744999999998	Центральная	0103000020E61000000100000005000000101FD8F15FAC49409CDCEF50145A4A40101FD8F15FAC4940AE2AFBAE085C4A40E84EB0FF3AB14940AE2AFBAE085C4A40E84EB0FF3AB149409CDCEF50145A4A40101FD8F15FAC49409CDCEF50145A4A40
48486	9942	51.080345000000001	51.098087	52.476213000000001	52.462657	Ленинская	0103000020E61000000100000005000000D5B2B5BE488A4940FB213658383B4A40D5B2B5BE488A49400C772E8CF43C4A40D594641D8E8C49400C772E8CF43C4A40D594641D8E8C4940FB213658383B4A40D5B2B5BE488A4940FB213658383B4A40
48337	46687	51.171506000000001	51.187109999999997	52.506853999999997	52.493017000000002	Молодёжная	0103000020E61000000100000005000000AD889AE8F39549409FAF592E1B3F4A40AD889AE8F395494063EC8497E0404A4095607138F397494063EC8497E0404A4095607138F39749409FAF592E1B3F4A40AD889AE8F39549409FAF592E1B3F4A40
48476	46995	51.494458999999999	51.516970999999998	52.757193000000001	52.747228999999997	 Школьная	0103000020E610000001000000050000003F1BB96E4ABF4940B7CF2A33A55F4A403F1BB96E4ABF49404CE141B3EB604A407EFD101B2CC249404CE141B3EB604A407EFD101B2CC24940B7CF2A33A55F4A403F1BB96E4ABF4940B7CF2A33A55F4A40
48644	46952	51.491216000000001	51.525531999999998	52.712529000000004	52.696993999999997	Школьная	0103000020E61000000100000005000000CFA2772AE0BE49400DC1711937594A40CFA2772AE0BE4940CE397826345B4A403080F0A144C34940CE397826345B4A403080F0A144C349400DC1711937594A40CFA2772AE0BE49400DC1711937594A40
48341	46933	51.384909999999998	51.406083000000002	52.417399000000003	52.405369	Прибрежная	0103000020E61000000100000005000000A1F31ABB44B14940F7E7A221E3334A40A1F31ABB44B149400A3197546D354A40153B1A87FAB349400A3197546D354A40153B1A87FAB34940F7E7A221E3334A40A1F31ABB44B14940F7E7A221E3334A40
48519	46865	51.326537000000002	51.349516000000001	52.466213000000003	52.452916999999999	 Л.Толстого	0103000020E610000001000000050000008CF7E3F6CBA94940B6662B2FF9394A408CF7E3F6CBA949402BFC19DEAC3B4A40E1B6B6F0BCAC49402BFC19DEAC3B4A40E1B6B6F0BCAC4940B6662B2FF9394A408CF7E3F6CBA94940B6662B2FF9394A40
48518	46843	51.230525	51.244808999999997	52.678997000000003	52.659424999999999	К. Маркса	0103000020E6100000010000000500000088F4DBD7819D49401895D40968544A4088F4DBD7819D4940838AAA5FE9564A401B62BCE6559F4940838AAA5FE9564A401B62BCE6559F49401895D40968544A4088F4DBD7819D49401895D40968544A40
48293	55900	51.256090999999998	51.293039	52.600009999999997	52.565170000000002	Школьная	0103000020E6100000010000000500000064E60297C7A049401557957D57484A4064E60297C7A04940F0A2AF20CD4C4A40EDB94C4D82A54940F0A2AF20CD4C4A40EDB94C4D82A549401557957D57484A4064E60297C7A049401557957D57484A40
48225	46770	51.257106999999998	51.296712999999997	52.634372999999997	52.612572	Рабочая	0103000020E610000001000000050000004D49D6E1E8A04940003961C2684E4A404D49D6E1E8A04940923B6C2233514A4026A60BB1FAA54940923B6C2233514A4026A60BB1FAA54940003961C2684E4A404D49D6E1E8A04940003961C2684E4A40
51500	56219	55.549562000000002	55.623672999999997	57.719743000000001	57.676831999999997	Советская	0103000020E61000000100000005000000EB8F300C58C64B407171546EA2D64C40EB8F300C58C64B403143E38920DC4C40F8325184D4CF4B403143E38920DC4C40F8325184D4CF4B407171546EA2D64C40EB8F300C58C64B407171546EA2D64C40
51769	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	переулок Чунжинский	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51771	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Юности	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51524	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Чайковского	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51728	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Попова	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51523	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Лысьвенская	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51520	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Ленина	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51767	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Крупской	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51772	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Коммунистическая	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
52117	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	Камгэс	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51525	22804	57.745800000000003	57.900561000000003	58.322695000000003	58.235863999999999	50 лет ВЛКСМ	0103000020E61000000100000005000000ACADD85F76DF4C40E126A3CA301E4D40ACADD85F76DF4C4097CADB114E294D40CB86359545F34C4097CADB114E294D40CB86359545F34C40E126A3CA301E4D40ACADD85F76DF4C40E126A3CA301E4D40
51522	56221	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Юбилейная	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51770	56221	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Коммунистическая	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51719	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	бульвар Текстильщиков	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51511	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Советская	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51513	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Проспект Победы	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51764	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Мира	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51648	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Ленина	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51650	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Карла Маркса	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51762	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Камская	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51718	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Кабалевского	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51714	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	К.Мракса	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51512	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	К.Маркса	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51521	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Зеленая	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51651	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Декабристов	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51647	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Вокзальная	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
52150	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Бажова	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51645	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	Азина	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51649	16298	54.057882999999997	54.196618999999998	56.791294999999998	56.727131	40 лет Октября	0103000020E6100000010000000500000047FFCBB568074B403274ECA0125D4C4047FFCBB568074B40813E912749654C40D862B7CF2A194B40813E912749654C40D862B7CF2A194B403274ECA0125D4C4047FFCBB568074B403274ECA0125D4C40
51564	56226	54.332974	54.388759	56.710416000000002	56.674163999999998	Ленина	0103000020E610000001000000050000008B355CE49E2A4B40FD1186014B564C408B355CE49E2A4B400F4757E9EE5A4C404983DBDAC2314B400F4757E9EE5A4C404983DBDAC2314B40FD1186014B564C408B355CE49E2A4B40FD1186014B564C40
51619	56231	56.28734	56.323855999999999	57.914155000000001	57.886645999999999	Строителей	0103000020E61000000100000005000000946A9F8EC7244C408A90BA9D7DF14C40946A9F8EC7244C40C93CF20703F54C40834E081D74294C40C93CF20703F54C40834E081D74294C408A90BA9D7DF14C40946A9F8EC7244C408A90BA9D7DF14C40
51680	56236	55.502867999999999	55.574131000000001	57.959105000000001	57.927334000000002	Московская	0103000020E610000001000000050000003B1A87FA5DC04B40043C69E1B2F64C403B1A87FA5DC04B400D37E0F3C3FA4C40554FE61F7DC94B400D37E0F3C3FA4C40554FE61F7DC94B40043C69E1B2F64C403B1A87FA5DC04B40043C69E1B2F64C40
51624	56233	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	Чернышевского	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
51623	56232	56.745058	56.784036	58.041218999999998	58.028111000000003	Большевистская	0103000020E61000000100000005000000C4CF7F0F5E5F4C4035D4282499034D40C4CF7F0F5E5F4C40A67C08AA46054D407E71A94A5B644C40A67C08AA46054D407E71A94A5B644C4035D4282499034D40C4CF7F0F5E5F4C4035D4282499034D40
51507	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Черняховского	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51641	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Цифриновича	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51759	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Фрунзе	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51639	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Транспортная	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51751	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Советская	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51706	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Сильвинитовая	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51704	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Северная	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51707	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Проспект Юбилейный	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51710	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Правды	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51640	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Пр.Юбилейный	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51503	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Парижской Коммуны	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
52019	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Осокина	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51642	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Набережная	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51506	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Молодежная	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
52020	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Мира	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51700	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Металлургов	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51508	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Культуры	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51760	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Карналлитовая	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51509	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Калийная	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51535	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Добролюбова	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51638	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Володарского	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51758	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	Белинского	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
51709	6221	56.727145999999998	56.811793999999999	59.665312	59.598647	20 лет Победы	0103000020E6100000010000000500000067B5C01E135D4C409C6C0377A0CC4D4067B5C01E135D4C4074D190F128D54D40658BA4DDE8674C4074D190F128D54D40658BA4DDE8674C409C6C0377A0CC4D4067B5C01E135D4C409C6C0377A0CC4D40
52143	29156	56.282983000000002	56.299852999999999	58.23901	58.225135999999999	Хохловская	0103000020E61000000100000005000000782975C938244C407D93A641D11C4D40782975C938244C405FB532E1971E4D40C24D469561264C405FB532E1971E4D40C24D469561264C407D93A641D11C4D40782975C938244C407D93A641D11C4D40
51851	56251	56.112132000000003	56.114603000000002	57.975298000000002	57.974710999999999	Солнечная	0103000020E61000000100000005000000E46A64575A0E4C4096067E54C3FC4C40E46A64575A0E4C4057ED9A90D6FC4C400283A44FAB0E4C4057ED9A90D6FC4C400283A44FAB0E4C4096067E54C3FC4C40E46A64575A0E4C4096067E54C3FC4C40
51546	56224	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	50 лет Октября	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
51481	56214	56.538167000000001	56.557229999999997	57.645054999999999	57.627854999999997	Школьная	0103000020E61000000100000005000000AA6400A8E2444C40A6D0798D5DD04C40AA6400A8E2444C40868F882991D24C40CF2C095053474C40868F882991D24C40CF2C095053474C40A6D0798D5DD04C40AA6400A8E2444C40A6D0798D5DD04C40
51632	83	56.045343000000003	56.231734000000003	58.002853999999999	57.938329000000003	шоссе Космонавтов	0103000020E61000000100000005000000200DA7CCCD054C40B7F1272A1BF84C40200DA7CCCD054C40D65416855D004D4086AFAF75A91D4C40D65416855D004D4086AFAF75A91D4C40B7F1272A1BF84C40200DA7CCCD054C40B7F1272A1BF84C40
51702	83	56.372526999999998	56.422401000000001	58.128276	58.126085000000003	улица Щербакова	0103000020E6100000010000000500000041F0F8F6AE2F4C4012C2A38D23104D4041F0F8F6AE2F4C404C6E14596B104D401B66683C11364C404C6E14596B104D401B66683C11364C4012C2A38D23104D4041F0F8F6AE2F4C4012C2A38D23104D40
2355	83	56.248945999999997	56.263103000000001	57.999538999999999	57.996099999999998	улица Полины Осипенко	0103000020E61000000100000005000000293C6876DD1F4C40D6C56D3480FF4C40293C6876DD1F4C40CC09DAE4F0FF4C40603DEE5BAD214C40CC09DAE4F0FF4C40603DEE5BAD214C40D6C56D3480FF4C40293C6876DD1F4C40D6C56D3480FF4C40
16009	83	56.213453000000001	56.222507999999998	57.998317999999998	57.995708999999998	улица Полевая	0103000020E61000000100000005000000D61D8B6D521B4C409BAA7B6473FF4C40D61D8B6D521B4C400A815CE2C8FF4C40978C63247B1C4C400A815CE2C8FF4C40978C63247B1C4C409BAA7B6473FF4C40D61D8B6D521B4C409BAA7B6473FF4C40
255	83	55.919282000000003	55.951836999999998	58.013125000000002	57.998175000000003	улица Ласьвинская	0103000020E6100000010000000500000097E65608ABF54B40A857CA32C4FF4C4097E65608ABF54B4048E17A14AE014D40B60F79CBD5F94B4048E17A14AE014D40B60F79CBD5F94B40A857CA32C4FF4C4097E65608ABF54B40A857CA32C4FF4C40
1136	83	56.279902	56.312358000000003	58.029541000000002	58.016261999999998	улица Ким	0103000020E61000000100000005000000E10A28D4D3234C4072158BDF14024D40E10A28D4D3234C401172DEFFC7034D406E52D158FB274C401172DEFFC7034D406E52D158FB274C4072158BDF14024D40E10A28D4D3234C4072158BDF14024D40
15887	83	56.379992000000001	56.382551999999997	58.140462999999997	58.136862000000001	улица Железнодорожная	0103000020E61000000100000005000000EE5EEE93A3304C405708ABB184114D40EE5EEE93A3304C4026A60BB1FA114D407B82C476F7304C4026A60BB1FA114D407B82C476F7304C405708ABB184114D40EE5EEE93A3304C405708ABB184114D40
51859	83	56.135613999999997	56.175832	57.998627999999997	57.995947999999999	проспект Парковый	0103000020E610000001000000050000009B70AFCC5B114C4020425C397BFF4C409B70AFCC5B114C40586FD40AD3FF4C408ECBB8A981164C40586FD40AD3FF4C408ECBB8A981164C4020425C397BFF4C409B70AFCC5B114C4020425C397BFF4C40
51631	83	56.190151	56.215851999999998	57.980251000000003	57.975082999999998	проспект Декабристов	0103000020E610000001000000050000009E2633DE56184C405AF10D85CFFC4C409E2633DE56184C40876F61DD78FD4C405A63D009A11B4C40876F61DD78FD4C405A63D009A11B4C405AF10D85CFFC4C409E2633DE56184C405AF10D85CFFC4C40
51959	83	56.296582999999998	56.307578999999997	58.104863999999999	58.098210999999999	маршала Толбухина	0103000020E6100000010000000500000058C6866EF6254C40C18D942D920C4D4058C6866EF6254C408D43FD2E6C0D4D40DBF7A8BF5E274C408D43FD2E6C0D4D40DBF7A8BF5E274C40C18D942D920C4D4058C6866EF6254C40C18D942D920C4D40
51879	83	55.933934000000001	55.996932000000001	58.024932	57.991788	маршала Рыбалко	0103000020E61000000100000005000000AD4F39268BF74B405A48C0E8F2FE4C40AD4F39268BF74B40DB4FC6F830034D40FE2AC0779BFF4B40DB4FC6F830034D40FE2AC0779BFF4B405A48C0E8F2FE4C40AD4F39268BF74B405A48C0E8F2FE4C40
51922	83	56.154578000000001	56.186045999999997	57.976590999999999	57.934142999999999	космонавта Леонова	0103000020E610000001000000050000002E573F36C9134C40C76471FF91F74C402E573F36C9134C40B24813EF00FD4C409BC6F65AD0174C40B24813EF00FD4C409BC6F65AD0174C40C76471FF91F74C402E573F36C9134C40C76471FF91F74C40
51965	83	56.383521999999999	56.413688	58.092692999999997	58.084586000000002	генерала Черняховского	0103000020E61000000100000005000000F4A5B73F17314C4088D9CBB6D30A4D40F4A5B73F17314C40B8C83D5DDD0B4D40B35F77BAF3344C40B8C83D5DDD0B4D40B35F77BAF3344C4088D9CBB6D30A4D40F4A5B73F17314C4088D9CBB6D30A4D40
54670	83	56.265591999999998	56.296646000000003	58.021968000000001	57.990304999999999	бульвар Гагарина	0103000020E61000000100000005000000240A2DEBFE214C405B087250C2FE4C40240A2DEBFE214C407EC7F0D8CF024D409F3E027FF8254C407EC7F0D8CF024D409F3E027FF8254C405B087250C2FE4C40240A2DEBFE214C405B087250C2FE4C40
51904	83	56.366489999999999	56.428519000000001	58.113979	58.088724999999997	академика Веденеева	0103000020E61000000100000005000000D027F224E92E4C4036AB3E575B0B4D40D027F224E92E4C4024B726DD960E4D40795BE9B5D9364C4024B726DD960E4D40795BE9B5D9364C4036AB3E575B0B4D40D027F224E92E4C4036AB3E575B0B4D40
51920	83	55.996771000000003	56.037626000000003	58.034486999999999	58.024889000000002	адмирала Ушакова	0103000020E61000000100000005000000F54C2F3196FF4B40DC8310902F034D40F54C2F3196FF4B408E91EC116A044D405ABDC3EDD0044C408E91EC116A044D405ABDC3EDD0044C40DC8310902F034D40F54C2F3196FF4B40DC8310902F034D40
51875	83	55.965698000000003	55.968653000000003	58.014626999999997	58.010835999999998	Ямпольская	0103000020E6100000010000000500000004E8F7FD9BFB4B404ACFF41263014D4004E8F7FD9BFB4B40BD512B4CDF014D400E164ED2FCFB4B40BD512B4CDF014D400E164ED2FCFB4B404ACFF41263014D4004E8F7FD9BFB4B404ACFF41263014D40
51895	83	56.299503000000001	56.309069999999998	58.013162999999999	58.001069999999999	Юрша	0103000020E61000000100000005000000E606431D56264C40DC80CF0F23004D40E606431D56264C4035423F53AF014D405D16139B8F274C4035423F53AF014D405D16139B8F274C40DC80CF0F23004D40E606431D56264C40DC80CF0F23004D40
51635	83	56.372526999999998	56.422401000000001	58.128276	58.126085000000003	Щербакова	0103000020E6100000010000000500000041F0F8F6AE2F4C4012C2A38D23104D4041F0F8F6AE2F4C404C6E14596B104D401B66683C11364C404C6E14596B104D401B66683C11364C4012C2A38D23104D4041F0F8F6AE2F4C4012C2A38D23104D40
51670	83	56.045343000000003	56.231734000000003	58.002853999999999	57.938329000000003	Шоссе Космонавтов	0103000020E61000000100000005000000200DA7CCCD054C40B7F1272A1BF84C40200DA7CCCD054C40D65416855D004D4086AFAF75A91D4C40D65416855D004D4086AFAF75A91D4C40B7F1272A1BF84C40200DA7CCCD054C40B7F1272A1BF84C40
51954	83	55.950274	55.964520999999998	58.010568999999997	58.004179999999998	Шишкина	0103000020E610000001000000050000009B1E1494A2F94B400DA661F888004D409B1E1494A2F94B40FBAC32535A014D4011A7936C75FB4B40FBAC32535A014D4011A7936C75FB4B400DA661F888004D409B1E1494A2F94B400DA661F888004D40
51866	83	56.304811999999998	56.311621000000002	58.166021999999998	58.165841	Читалина	0103000020E61000000100000005000000D4B6611404274C4000AB23473A154D40D4B6611404274C4050357A3540154D4098DF6932E3274C4050357A3540154D4098DF6932E3274C4000AB23473A154D40D4B6611404274C4000AB23473A154D40
51973	83	55.932944999999997	55.944093000000002	58.000183	57.994053999999998	Чистопольская	0103000020E61000000100000005000000BDFBE3BD6AF74B409F3A56293DFF4C40BDFBE3BD6AF74B40F1811DFF05004D40F7B0170AD8F84B40F1811DFF05004D40F7B0170AD8F84B409F3A56293DFF4C40BDFBE3BD6AF74B409F3A56293DFF4C40
51946	83	56.257092999999998	56.276541999999999	57.999625000000002	57.992097999999999	Чернышевского	0103000020E61000000100000005000000E883656CE8204C40A8363811FDFE4C40E883656CE8204C40CBA145B6F3FF4C4037FC6EBA65234C40CBA145B6F3FF4C4037FC6EBA65234C40A8363811FDFE4C40E883656CE8204C40A8363811FDFE4C40
51974	83	56.178750999999998	56.199745	57.968629999999997	57.963225999999999	Чердынская	0103000020E610000001000000050000004B901150E1164C40155454FD4AFB4C404B901150E1164C4055F65D11FCFB4C400F45813E91194C4055F65D11FCFB4C400F45813E91194C40155454FD4AFB4C404B901150E1164C40155454FD4AFB4C40
51998	83	56.352674	56.368485	58.074283999999999	58.049987999999999	Целинная	0103000020E610000001000000050000002313F06B242D4C40A298BC0166064D402313F06B242D4C40DB4E5B2382094D40850838842A2F4C40DB4E5B2382094D40850838842A2F4C40A298BC0166064D402313F06B242D4C40A298BC0166064D40
51835	83	56.327593	56.334986000000001	58.048164	58.045853999999999	Харьковская	0103000020E6100000010000000500000003B34291EE294C4005323B8BDE054D4003B34291EE294C401A6CEA3C2A064D40164F3DD2E02A4C401A6CEA3C2A064D40164F3DD2E02A4C4005323B8BDE054D4003B34291EE294C4005323B8BDE054D40
51924	83	55.842314000000002	55.849311999999998	58.030540999999999	58.029764999999998	Фадеева	0103000020E61000000100000005000000427BF5F1D0EB4B4060C8EA56CF034D40427BF5F1D0EB4B40F4177AC4E8034D40D80C7041B6EC4B40F4177AC4E8034D40D80C7041B6EC4B4060C8EA56CF034D40427BF5F1D0EB4B4060C8EA56CF034D40
51900	83	56.276775999999998	56.312626999999999	58.034162999999999	58.019660999999999	Уральская	0103000020E61000000100000005000000AA285E656D234C40DA006C4084024D40AA285E656D234C40DBDD03745F044D405D6C5A2904284C40DBDD03745F044D405D6C5A2904284C40DA006C4084024D40AA285E656D234C40DA006C4084024D40
51941	83	56.276775999999998	56.312626999999999	58.034162999999999	58.019660999999999	Уральская	0103000020E61000000100000005000000AA285E656D234C40DA006C4084024D40AA285E656D234C40DBDD03745F044D405D6C5A2904284C40DBDD03745F044D405D6C5A2904284C40DA006C4084024D40AA285E656D234C40DA006C4084024D40
51855	83	56.293681999999997	56.310121000000002	58.009591999999998	58.004547000000002	Уинская	0103000020E6100000010000000500000041B62C5F97254C40C02500FF94004D4041B62C5F97254C40D026874F3A014D40C366800BB2274C40D026874F3A014D40C366800BB2274C40C02500FF94004D4041B62C5F97254C40C02500FF94004D40
54767	83	56.288705	56.294023000000003	58.021157000000002	58.009396000000002	Тургенева	0103000020E6100000010000000500000089981249F4244C404B5B5CE333014D4089981249F4244C406E8AC745B5024D40CBA2B08BA2254C406E8AC745B5024D40CBA2B08BA2254C404B5B5CE333014D4089981249F4244C404B5B5CE333014D40
64697	83	56.601678	56.603160000000003	58.047635	58.046511000000002	Трудовая	0103000020E61000000100000005000000815CE2C8034D4C40BFF38B12F4054D40815CE2C8034D4C408E9257E718064D40B020CD58344D4C408E9257E718064D40B020CD58344D4C40BFF38B12F4054D40815CE2C8034D4C40BFF38B12F4054D40
51847	83	56.124574000000003	56.136350999999998	58.036901999999998	58.034120000000001	Транспортная	0103000020E6100000010000000500000049F7730AF20F4C40DC114E0B5E044D4049F7730AF20F4C4018946934B9044D4071E316F373114C4018946934B9044D4071E316F373114C40DC114E0B5E044D4049F7730AF20F4C40DC114E0B5E044D40
51964	83	56.378194999999998	56.382596999999997	58.137822	58.131374000000001	Томская	0103000020E610000001000000050000005F419AB168304C40B9C5FCDCD0104D405F419AB168304C40AC55BB26A4114D401B4641F0F8304C40AC55BB26A4114D401B4641F0F8304C40B9C5FCDCD0104D405F419AB168304C40B9C5FCDCD0104D40
51977	83	56.199134000000001	56.202475999999997	58.010517	58.004933000000001	Толмачева	0103000020E61000000100000005000000C6C210397D194C40E9D500A5A1004D40C6C210397D194C40A986FD9E58014D40C91CCBBBEA194C40A986FD9E58014D40C91CCBBBEA194C40E9D500A5A1004D40C6C210397D194C40E9D500A5A1004D40
51897	83	56.287923999999997	56.293852999999999	58.016119000000003	58.010021000000002	Техническая	0103000020E61000000100000005000000E3DD91B1DA244C40F9A23D5E48014D40E3DD91B1DA244C4010ECF82F10024D406E6AA0F99C254C4010ECF82F10024D406E6AA0F99C254C40F9A23D5E48014D40E3DD91B1DA244C40F9A23D5E48014D40
51925	83	56.012239999999998	56.026927000000001	58.029077999999998	58.020480999999997	Танцорова	0103000020E61000000100000005000000FDD98F1491014C403D98141F9F024D40FDD98F1491014C403C84F1D3B8034D4090300C5872034C403C84F1D3B8034D4090300C5872034C403D98141F9F024D40FDD98F1491014C403D98141F9F024D40
51932	83	56.196376000000001	56.214424000000001	57.989393	57.977536000000001	Танкистов	0103000020E6100000010000000500000012DC48D922194C40D2544FE61FFD4C4012DC48D922194C4017F2086EA4FE4C401FBDE13E721B4C4017F2086EA4FE4C401FBDE13E721B4C40D2544FE61FFD4C4012DC48D922194C40D2544FE61FFD4C40
51963	83	56.384331000000003	56.385193000000001	58.121988000000002	58.120220000000003	Таймырская	0103000020E6100000010000000500000064EB19C231314C409E29745E630F4D4064EB19C231314C409240834D9D0F4D40F6D214014E314C409240834D9D0F4D40F6D214014E314C409E29745E630F4D4064EB19C231314C409E29745E630F4D40
51887	83	55.974663	55.984796000000003	58.020184999999998	58.012829000000004	Сысольская	0103000020E6100000010000000500000085CFD6C1C1FC4B405FB87361A4014D4085CFD6C1C1FC4B40546F0D6C95024D40A69D9ACB0DFE4B40546F0D6C95024D40A69D9ACB0DFE4B405FB87361A4014D4085CFD6C1C1FC4B405FB87361A4014D40
51917	83	56.292568000000003	56.312223000000003	57.982103000000002	57.981310999999998	Суздальская	0103000020E6100000010000000500000096ED43DE72254C403F1A4E999BFD4C4096ED43DE72254C40D926158DB5FD4C408E075BECF6274C40D926158DB5FD4C408E075BECF6274C403F1A4E999BFD4C4096ED43DE72254C403F1A4E999BFD4C40
51936	83	56.291912000000004	56.313659999999999	58.012658000000002	57.981368000000003	Старцева	0103000020E61000000100000005000000ADA7565F5D254C40A4AB74779DFD4C40ADA7565F5D254C40320400C79E014D401C08C90226284C40320400C79E014D401C08C90226284C40A4AB74779DFD4C40ADA7565F5D254C40A4AB74779DFD4C40
54389	83	56.317864999999998	56.364046999999999	58.112453000000002	58.039161	Соликамская	0103000020E6100000010000000500000082C5E1CCAF284C40AB23473A03054D4082C5E1CCAF284C4026AB22DC640E4D407C9A9317992E4C4026AB22DC640E4D407C9A9317992E4C40AB23473A03054D4082C5E1CCAF284C40AB23473A03054D40
51949	83	56.224494	56.246395	57.975130999999998	57.961964999999999	Солдатова	0103000020E61000000100000005000000F9122A38BC1C4C40C5724BAB21FB4C40F9122A38BC1C4C406B28B517D1FC4C40EF7211DF891F4C406B28B517D1FC4C40EF7211DF891F4C40C5724BAB21FB4C40F9122A38BC1C4C40C5724BAB21FB4C40
51934	83	56.191102999999998	56.210489000000003	57.989541000000003	57.97251	Советской Армии	0103000020E610000001000000050000007095271076184C4038842A357BFC4C407095271076184C408C868C47A9FE4C407995B54DF11A4C408C868C47A9FE4C407995B54DF11A4C4038842A357BFC4C407095271076184C4038842A357BFC4C40
51993	83	56.211711000000001	56.253024000000003	58.018855000000002	58.009787000000003	Советская	0103000020E610000001000000050000000B9A9658191B4C4086764EB340014D400B9A9658191B4C40DC2E34D769024D40338D261763204C40DC2E34D769024D40338D261763204C4086764EB340014D400B9A9658191B4C4086764EB340014D40
51955	83	56.211711000000001	56.253024000000003	58.018855000000002	58.009787000000003	Советская	0103000020E610000001000000050000000B9A9658191B4C4086764EB340014D400B9A9658191B4C40DC2E34D769024D40338D261763204C40DC2E34D769024D40338D261763204C4086764EB340014D400B9A9658191B4C4086764EB340014D40
66991	83	56.211711000000001	56.253024000000003	58.018855000000002	58.009787000000003	Советская	0103000020E610000001000000050000000B9A9658191B4C4086764EB340014D400B9A9658191B4C40DC2E34D769024D40338D261763204C40DC2E34D769024D40338D261763204C4086764EB340014D400B9A9658191B4C4086764EB340014D40
51960	83	56.211711000000001	56.253024000000003	58.018855000000002	58.009787000000003	Советская	0103000020E610000001000000050000000B9A9658191B4C4086764EB340014D400B9A9658191B4C40DC2E34D769024D40338D261763204C40DC2E34D769024D40338D261763204C4086764EB340014D400B9A9658191B4C4086764EB340014D40
51909	83	56.213470999999998	56.224196999999997	57.983978	57.982636999999997	Сивкова	0103000020E610000001000000050000007CD28904531B4C40766B990CC7FD4C407CD28904531B4C40E3FDB8FDF2FD4C403F6EBF7CB21C4C40E3FDB8FDF2FD4C403F6EBF7CB21C4C40766B990CC7FD4C407CD28904531B4C40766B990CC7FD4C40
51844	83	56.242316000000002	56.261674999999997	58.017792	57.997239999999998	Сибирская	0103000020E6100000010000000500000016A6EF35041F4C40AB21718FA5FF4C4016A6EF35041F4C40B2101D0247024D402497FF907E214C40B2101D0247024D402497FF907E214C40AB21718FA5FF4C4016A6EF35041F4C40AB21718FA5FF4C40
2570	83	56.232146999999998	56.239989999999999	57.979019999999998	57.974013999999997	Серебрянский проезд	0103000020E61000000100000005000000A86E2EFEB61D4C404EECA17DACFC4C40A86E2EFEB61D4C40A110018750FD4C40FBAE08FEB71E4C40A110018750FD4C40FBAE08FEB71E4C404EECA17DACFC4C40A86E2EFEB61D4C404EECA17DACFC4C40
51923	83	56.221429999999998	56.229748999999998	57.997340999999999	57.994846000000003	Связистов	0103000020E61000000100000005000000382D78D1571C4C4039471D1D57FF4C40382D78D1571C4C40DFFAB0DEA8FF4C40F4A44C6A681D4C40DFFAB0DEA8FF4C40F4A44C6A681D4C4039471D1D57FF4C40382D78D1571C4C4039471D1D57FF4C40
54408	83	56.149780999999997	56.204892000000001	57.968013999999997	57.959817000000001	Свиязева	0103000020E61000000100000005000000F54718062C134C408A929048DBFA4C40F54718062C134C40FA08FCE1E7FB4C40249BABE6391A4C40FA08FCE1E7FB4C40249BABE6391A4C408A929048DBFA4C40F54718062C134C408A929048DBFA4C40
51891	83	56.024546999999998	56.057783999999998	58.044576999999997	58.038736999999998	Светлогорская	0103000020E61000000100000005000000821B295B24034C4094128255F5044D40821B295B24034C40AF93FAB2B4054D40B41D537765074C40AF93FAB2B4054D40B41D537765074C4094128255F5044D40821B295B24034C4094128255F5044D40
51950	83	56.296565000000001	56.336190000000002	57.998303999999997	57.975436000000002	Самаркандская	0103000020E61000000100000005000000B21188D7F5254C40A8AB3B16DBFC4C40B21188D7F5254C40A5BBEB6CC8FF4C40029F1F46082B4C40A5BBEB6CC8FF4C40029F1F46082B4C40A8AB3B16DBFC4C40B21188D7F5254C40A8AB3B16DBFC4C40
51903	83	56.278041999999999	56.319958	58.114254000000003	58.111877	Репина	0103000020E610000001000000050000000C7558E196234C4059164CFC510E4D400C7558E196234C40F6B704E09F0E4D40FA0B3D62F4284C40F6B704E09F0E4D40FA0B3D62F4284C4059164CFC510E4D400C7558E196234C4059164CFC510E4D40
51969	83	56.232056999999998	56.284564000000003	58.006988	58.002468	Революции	0103000020E6100000010000000500000068E7340BB41D4C40ADA415DF50004D4068E7340BB41D4C4073BB97FBE4004D403ACFD8976C244C4073BB97FBE4004D403ACFD8976C244C40ADA415DF50004D4068E7340BB41D4C40ADA415DF50004D40
51971	83	56.196457000000002	56.202727000000003	57.999873000000001	57.991841000000001	Рабочая	0103000020E61000000100000005000000FF08C38025194C407DEA58A5F4FE4C40FF08C38025194C40A393A5D6FBFF4C40138255F5F2194C40A393A5D6FBFF4C40138255F5F2194C407DEA58A5F4FE4C40FF08C38025194C407DEA58A5F4FE4C40
51892	83	56.196457000000002	56.202727000000003	57.999873000000001	57.991841000000001	Рабочая	0103000020E61000000100000005000000FF08C38025194C407DEA58A5F4FE4C40FF08C38025194C40A393A5D6FBFF4C40138255F5F2194C40A393A5D6FBFF4C40138255F5F2194C407DEA58A5F4FE4C40FF08C38025194C407DEA58A5F4FE4C40
51894	83	56.212060999999999	56.263525000000001	58.012028000000001	58.001376	Пушкина	0103000020E61000000100000005000000E7E099D0241B4C40E97FB9162D004D40E7E099D0241B4C4072512D228A014D40D656EC2FBB214C4072512D228A014D40D656EC2FBB214C40E97FB9162D004D40E7E099D0241B4C40E97FB9162D004D40
51994	83	56.212060999999999	56.263525000000001	58.012028000000001	58.001376	Пушкина	0103000020E61000000100000005000000E7E099D0241B4C40E97FB9162D004D40E7E099D0241B4C4072512D228A014D40D656EC2FBB214C4072512D228A014D40D656EC2FBB214C40E97FB9162D004D40E7E099D0241B4C40E97FB9162D004D40
51873	83	56.212060999999999	56.263525000000001	58.012028000000001	58.001376	Пушкина	0103000020E61000000100000005000000E7E099D0241B4C40E97FB9162D004D40E7E099D0241B4C4072512D228A014D40D656EC2FBB214C4072512D228A014D40D656EC2FBB214C40E97FB9162D004D40E7E099D0241B4C40E97FB9162D004D40
51869	83	56.212060999999999	56.263525000000001	58.012028000000001	58.001376	Пушкина	0103000020E61000000100000005000000E7E099D0241B4C40E97FB9162D004D40E7E099D0241B4C4072512D228A014D40D656EC2FBB214C4072512D228A014D40D656EC2FBB214C40E97FB9162D004D40E7E099D0241B4C40E97FB9162D004D40
52227	83	56.121806999999997	56.184438	57.958990999999997	57.872495000000001	Промышленная	0103000020E6100000010000000500000041B62C5F970F4C40367689EAADEF4C4041B62C5F970F4C4044149337C0FA4C40E01115AA9B174C4044149337C0FA4C40E01115AA9B174C40367689EAADEF4C4041B62C5F970F4C40367689EAADEF4C40
51997	83	56.319454999999998	56.329731000000002	58.034930000000003	58.03087	Постаногова	0103000020E6100000010000000500000097C5C4E6E3284C40B936548CF3034D4097C5C4E6E3284C401CD3139678044D401BBD1AA0342A4C401CD3139678044D401BBD1AA0342A4C40B936548CF3034D4097C5C4E6E3284C40B936548CF3034D40
51982	83	56.136647000000004	56.189154000000002	57.995719000000001	57.989584000000001	Подлесная	0103000020E610000001000000050000005B0C1EA67D114C408B5242B0AAFE4C405B0C1EA67D114C40BF805EB873FF4C402CF4C13236184C40BF805EB873FF4C402CF4C13236184C408B5242B0AAFE4C405B0C1EA67D114C408B5242B0AAFE4C40
51913	83	55.921230999999999	55.926253000000003	58.011083999999997	58.003211999999998	Победы	0103000020E61000000100000005000000DB87BCE5EAF54B40357A354069004D40DB87BCE5EAF54B4022C154336B014D40346953758FF64B4022C154336B014D40346953758FF64B40357A354069004D40DB87BCE5EAF54B40357A354069004D40
51979	83	56.202241999999998	56.211584999999999	58.011318000000003	57.994183	Плеханова	0103000020E6100000010000000500000056F0DB10E3194C409D9E776341FF4C4056F0DB10E3194C4096ED43DE72014D407EA99F37151B4C4096ED43DE72014D407EA99F37151B4C409D9E776341FF4C4056F0DB10E3194C409D9E776341FF4C40
51999	83	56.301667999999999	56.319265999999999	58.118271	58.104165000000002	Писарева	0103000020E61000000100000005000000F71F990E9D264C40A5315A47550D4D40F71F990E9D264C4059880E81230F4D40C45C52B5DD284C4059880E81230F4D40C45C52B5DD284C40A5315A47550D4D40F71F990E9D264C40A5315A47550D4D40
51553	83	56.193770999999998	56.257848000000003	58.018535999999997	58.005094999999997	Петропавловская улица	0103000020E61000000100000005000000E4F4F57CCD184C40C22FF5F3A6004D40E4F4F57CCD184C403AE63C635F024D4065ABCB2901214C403AE63C635F024D4065ABCB2901214C40C22FF5F3A6004D40E4F4F57CCD184C40C22FF5F3A6004D40
51753	83	56.193770999999998	56.257848000000003	58.018535999999997	58.005094999999997	Петропавловская	0103000020E61000000100000005000000E4F4F57CCD184C40C22FF5F3A6004D40E4F4F57CCD184C403AE63C635F024D4065ABCB2901214C403AE63C635F024D4065ABCB2901214C40C22FF5F3A6004D40E4F4F57CCD184C40C22FF5F3A6004D40
51633	83	56.193770999999998	56.257848000000003	58.018535999999997	58.005094999999997	Петропавловская	0103000020E61000000100000005000000E4F4F57CCD184C40C22FF5F3A6004D40E4F4F57CCD184C403AE63C635F024D4065ABCB2901214C403AE63C635F024D4065ABCB2901214C40C22FF5F3A6004D40E4F4F57CCD184C40C22FF5F3A6004D40
51761	83	56.357624000000001	56.359321999999999	58.081774000000003	58.074649999999998	Пархоменко	0103000020E61000000100000005000000E2218C9FC62D4C40BD5296218E094D40E2218C9FC62D4C40E1D40792770A4D40DD5D6743FE2D4C40E1D40792770A4D40DD5D6743FE2D4C40BD5296218E094D40E2218C9FC62D4C40BD5296218E094D40
7688	83	56.135613999999997	56.175832	57.998627999999997	57.995947999999999	Парковый проспект	0103000020E610000001000000050000009B70AFCC5B114C4020425C397BFF4C409B70AFCC5B114C40586FD40AD3FF4C408ECBB8A981164C40586FD40AD3FF4C408ECBB8A981164C4020425C397BFF4C409B70AFCC5B114C4020425C397BFF4C40
51658	83	56.135613999999997	56.175832	57.998627999999997	57.995947999999999	Парковый проспект	0103000020E610000001000000050000009B70AFCC5B114C4020425C397BFF4C409B70AFCC5B114C40586FD40AD3FF4C408ECBB8A981164C40586FD40AD3FF4C408ECBB8A981164C4020425C397BFF4C409B70AFCC5B114C4020425C397BFF4C40
51952	83	56.241211	56.246296000000001	57.974372000000002	57.972982999999999	Обвинская	0103000020E61000000100000005000000BD378600E01E4C403048FAB48AFC4C40BD378600E01E4C40AE11C138B8FC4C405C9198A0861F4C40AE11C138B8FC4C405C9198A0861F4C403048FAB48AFC4C40BD378600E01E4C403048FAB48AFC4C40
54686	83	56.194149000000003	56.202241999999998	57.970056999999997	57.967646000000002	Норильская	0103000020E610000001000000050000008BC6DADFD9184C40780DFAD2DBFB4C408BC6DADFD9184C40C020E9D32AFC4C4056F0DB10E3194C40C020E9D32AFC4C4056F0DB10E3194C40780DFAD2DBFB4C408BC6DADFD9184C40780DFAD2DBFB4C40
51868	83	56.234366000000001	56.243879	57.963154000000003	57.962733999999998	Новосибирская	0103000020E61000000100000005000000ADA580B4FF1D4C40A65F22DE3AFB4C40ADA580B4FF1D4C407C8159A148FB4C403197546D371F4C407C8159A148FB4C403197546D371F4C40A65F22DE3AFB4C40ADA580B4FF1D4C40A65F22DE3AFB4C40
51905	83	56.253024000000003	56.273029999999999	58.018855000000002	57.994269000000003	Николая Островского	0103000020E61000000100000005000000338D261763204C409C36E33444FF4C40338D261763204C40DC2E34D769024D40D769A4A5F2224C40DC2E34D769024D40D769A4A5F2224C409C36E33444FF4C40338D261763204C409C36E33444FF4C40
51966	83	56.253024000000003	56.273029999999999	58.018855000000002	57.994269000000003	Николая Островского	0103000020E61000000100000005000000338D261763204C409C36E33444FF4C40338D261763204C40DC2E34D769024D40D769A4A5F2224C40DC2E34D769024D40D769A4A5F2224C409C36E33444FF4C40338D261763204C409C36E33444FF4C40
51919	83	56.149825999999997	56.183979999999998	57.975378999999997	57.965431000000002	Нефтяников	0103000020E61000000100000005000000950B957F2D134C40B5C5353E93FB4C40950B957F2D134C40431A1538D9FC4C401D8F19A88C174C40431A1538D9FC4C401D8F19A88C174C40B5C5353E93FB4C40950B957F2D134C40B5C5353E93FB4C40
51948	83	56.243609999999997	56.247076999999997	57.994331000000003	57.993333999999997	Нестерова	0103000020E61000000100000005000000417DCB9C2E1F4C409F008A9125FF4C40417DCB9C2E1F4C401233FB3C46FF4C40014C1938A01F4C401233FB3C46FF4C40014C1938A01F4C409F008A9125FF4C40417DCB9C2E1F4C409F008A9125FF4C40
51951	83	56.226730000000003	56.230134999999997	57.972897000000003	57.970700999999998	Муромская	0103000020E61000000100000005000000D482177D051D4C40E5982CEE3FFC4C40D482177D051D4C4032B08EE387FC4C401D554D10751D4C4032B08EE387FC4C401D554D10751D4C40E5982CEE3FFC4C40D482177D051D4C40E5982CEE3FFC4C40
51838	83	56.317523000000001	56.326991	58.042724	58.039136999999997	Мостовая	0103000020E61000000100000005000000295DFA97A4284C402288F37002054D40295DFA97A4284C408D60E3FA77054D400D8B51D7DA294C408D60E3FA77054D400D8B51D7DA294C402288F37002054D40295DFA97A4284C402288F37002054D40
51888	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
52001	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
51987	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
52007	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
51976	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
51978	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
51935	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
54647	83	56.150067999999997	56.217136000000004	57.986068000000003	57.968124000000003	Мира	0103000020E610000001000000050000008B16A06D35134C40823CBB7CEBFB4C408B16A06D35134C40EAD0E97937FE4C406364C91CCB1B4C40EAD0E97937FE4C406364C91CCB1B4C40823CBB7CEBFB4C408B16A06D35134C40823CBB7CEBFB4C40
51890	83	56.224646	56.233835999999997	57.997917999999999	57.989699000000002	Мильчакова	0103000020E61000000100000005000000AF963B33C11C4C4024F1F274AEFE4C40AF963B33C11C4C407C0BEBC6BBFF4C4050508A56EE1D4C407C0BEBC6BBFF4C4050508A56EE1D4C4024F1F274AEFE4C40AF963B33C11C4C4024F1F274AEFE4C40
51898	83	56.108018000000001	56.135874999999999	58.007618000000001	58.002367999999997	Маяковского	0103000020E610000001000000050000008EB0A888D30D4C40494739984D004D408EB0A888D30D4C40336E6AA0F9004D4008AC1C5A64114C40336E6AA0F9004D4008AC1C5A64114C40494739984D004D408EB0A888D30D4C40494739984D004D40
51882	83	55.933934000000001	55.996932000000001	58.024932	57.991788	Маршала Рыбалко	0103000020E61000000100000005000000AD4F39268BF74B405A48C0E8F2FE4C40AD4F39268BF74B40DB4FC6F830034D40FE2AC0779BFF4B40DB4FC6F830034D40FE2AC0779BFF4B405A48C0E8F2FE4C40AD4F39268BF74B405A48C0E8F2FE4C40
51896	83	56.283943999999998	56.305171000000001	58.013210999999998	58.006988	Макаренко	0103000020E610000001000000050000009DF2E84658244C4073BB97FBE4004D409DF2E84658244C404679E6E5B0014D400458E4D70F274C404679E6E5B0014D400458E4D70F274C4073BB97FBE4004D409DF2E84658244C4073BB97FBE4004D40
51907	83	56.258315000000003	56.273605000000003	57.988368000000001	57.987442000000001	Льва Шатрова	0103000020E610000001000000050000007B88467710214C403259DC7F64FE4C407B88467710214C40DB34B6D782FE4C40D482177D05234C40DB34B6D782FE4C40D482177D05234C403259DC7F64FE4C407B88467710214C403259DC7F64FE4C40
51817	83	56.210974	56.227359	57.988163	57.986187000000001	Льва Толстого	0103000020E6100000010000000500000035272F32011B4C40C45E28603BFE4C4035272F32011B4C40020F0C207CFE4C40C3B986191A1D4C40020F0C207CFE4C40C3B986191A1D4C40C45E28603BFE4C4035272F32011B4C40C45E28603BFE4C40
51870	83	56.207541999999997	56.262428999999997	58.013486999999998	58.002181999999998	Луначарского	0103000020E61000000100000005000000F1457BBC901A4C40E751F17F47004D40F1457BBC901A4C40E8F527F1B9014D40D042024697214C40E8F527F1B9014D40D042024697214C40E751F17F47004D40F1457BBC901A4C40E751F17F47004D40
51967	83	56.226883000000001	56.242801	57.959071999999999	57.958083000000002	Лукоянова	0103000020E610000001000000050000005A828C800A1D4C4042EDB776A2FA4C405A828C800A1D4C4031410DDFC2FA4C40D237691A141F4C4031410DDFC2FA4C40D237691A141F4C4042EDB776A2FA4C405A828C800A1D4C4042EDB776A2FA4C40
51914	83	56.213813000000002	56.244607000000002	57.969833000000001	57.965798999999997	Лодыгина	0103000020E61000000100000005000000D63A71395E1B4C4037C1374D9FFB4C40D63A71395E1B4C4071CADC7C23FC4C40B4AF3C484F1F4C4071CADC7C23FC4C40B4AF3C484F1F4C4037C1374D9FFB4C40D63A71395E1B4C4037C1374D9FFB4C40
51918	83	55.956454000000001	55.967719000000002	58.013950000000001	58.005668	Липатова	0103000020E610000001000000050000006F10AD156DFA4B401E51A1BAB9004D406F10AD156DFA4B40BDE3141DC9014D40E25B5837DEFB4B40BDE3141DC9014D40E25B5837DEFB4B401E51A1BAB9004D406F10AD156DFA4B401E51A1BAB9004D40
51825	83	56.101855999999998	56.105269	58.046644000000001	58.039822999999998	Лепешинской	0103000020E6100000010000000500000060730E9E090D4C40765089EB18054D4060730E9E090D4C40FE463B6EF8054D402D246074790D4C40FE463B6EF8054D402D246074790D4C40765089EB18054D4060730E9E090D4C40765089EB18054D40
51871	83	56.184896000000002	56.264324999999999	58.016838999999997	58.003664999999998	Ленина	0103000020E61000000100000005000000A39410ACAA174C40E6913F1878004D40A39410ACAA174C400F26C5C727024D40F241CF66D5214C400F26C5C727024D40F241CF66D5214C40E6913F1878004D40A39410ACAA174C40E6913F1878004D40
54304	83	56.184896000000002	56.264324999999999	58.016838999999997	58.003664999999998	Ленина	0103000020E61000000100000005000000A39410ACAA174C40E6913F1878004D40A39410ACAA174C400F26C5C727024D40F241CF66D5214C400F26C5C727024D40F241CF66D5214C40E6913F1878004D40A39410ACAA174C40E6913F1878004D40
51933	83	56.278661999999997	56.300508999999998	58.027377000000001	58.017673000000002	Лебедева	0103000020E61000000100000005000000A8514832AB234C40D882DE1B43024D40A8514832AB234C40D0D4EB1681034D40AB93331477264C40D0D4EB1681034D40AB93331477264C40D882DE1B43024D40A8514832AB234C40D882DE1B43024D40
51989	83	55.855348999999997	55.951926999999998	58.028120999999999	57.998094000000002	Ласьвинская	0103000020E6100000010000000500000049D576137CED4B40BB2A508BC1FF4C4049D576137CED4B4058AA0B7899034D40F69672BED8F94B4058AA0B7899034D40F69672BED8F94B40BB2A508BC1FF4C4049D576137CED4B40BB2A508BC1FF4C40
52013	83	56.132542000000001	56.136899	57.999929999999999	57.992007999999998	Куфонина	0103000020E6100000010000000500000058ACE122F7104C4068AF3E1EFAFE4C4058ACE122F7104C400725CCB4FDFF4C4074ED0BE885114C400725CCB4FDFF4C4074ED0BE885114C4068AF3E1EFAFE4C4058ACE122F7104C4068AF3E1EFAFE4C40
51927	83	56.231257999999997	56.248829000000001	58.014997999999999	57.953633000000004	Куйбышева	0103000020E610000001000000050000001C78B5DC991D4C4075B169A510FA4C401C78B5DC991D4C40B1C05774EB014D40F0A5F0A0D91F4C40B1C05774EB014D40F0A5F0A0D91F4C4075B169A510FA4C401C78B5DC991D4C4075B169A510FA4C40
51883	83	56.271493	56.301937000000002	58.023840999999997	57.993423999999997	Крупской	0103000020E61000000100000005000000E50B5A48C0224C40DF87838428FF4C40E50B5A48C0224C40E7A6CD380D034D40E73922DFA5264C40E7A6CD380D034D40E73922DFA5264C40DF87838428FF4C40E50B5A48C0224C40DF87838428FF4C40
51940	83	56.237375	56.243609999999997	58.001514	57.993391000000003	Краснофлотская	0103000020E61000000100000005000000AAF1D24D621E4C400492B06F27FF4C40AAF1D24D621E4C403A3E5A9C31004D40417DCB9C2E1F4C403A3E5A9C31004D40417DCB9C2E1F4C400492B06F27FF4C40AAF1D24D621E4C400492B06F27FF4C40
51939	83	56.339092000000001	56.359896999999997	58.059821999999997	58.057960000000001	Красноуральская	0103000020E61000000100000005000000E92ADD5D672B4C40F33CB83B6B074D40E92ADD5D672B4C4068CA4E3FA8074D40D976DA1A112E4C4068CA4E3FA8074D40D976DA1A112E4C40F33CB83B6B074D40E92ADD5D672B4C40F33CB83B6B074D40
52000	83	56.261639000000002	56.276389000000002	57.976638999999999	57.966056999999999	Краснополянская	0103000020E61000000100000005000000D82D02637D214C4033897AC1A7FB4C40D82D02637D214C40C37FBA8102FD4C40B1FCF9B660234C40C37FBA8102FD4C40B1FCF9B660234C4033897AC1A7FB4C40D82D02637D214C4033897AC1A7FB4C40
51947	83	56.238596999999999	56.252386000000001	58.007126999999997	58.004528000000001	Краснова	0103000020E610000001000000050000003CF6B3588A1E4C4049F59D5F94004D403CF6B3588A1E4C4094F59B89E9004D40F0FB372F4E204C4094F59B89E9004D40F0FB372F4E204C4049F59D5F94004D403CF6B3588A1E4C4049F59D5F94004D40
51899	83	56.117280000000001	56.137618000000003	58.038761000000001	58.035725999999997	Костычева	0103000020E61000000100000005000000C93CF207030F4C40F6CE68AB92044D40C93CF207030F4C401DAED51EF6044D40A4AB74779D114C401DAED51EF6044D40A4AB74779D114C40F6CE68AB92044D40C93CF207030F4C40F6CE68AB92044D40
4368	83	56.045343000000003	56.231734000000003	58.002853999999999	57.938329000000003	Космонавтов шоссе	0103000020E61000000100000005000000200DA7CCCD054C40B7F1272A1BF84C40200DA7CCCD054C40D65416855D004D4086AFAF75A91D4C40D65416855D004D4086AFAF75A91D4C40B7F1272A1BF84C40200DA7CCCD054C40B7F1272A1BF84C40
64759	83	55.798423	56.658783999999997	58.179842999999998	57.864764000000001	Космонавта Беляева	0103000020E61000000100000005000000E6AF90B932E64B400B613596B0EE4C40E6AF90B932E64B400FB56D1805174D406490BB0853544C400FB56D1805174D406490BB0853544C400B613596B0EE4C40E6AF90B932E64B400B613596B0EE4C40
2358	83	56.233612000000001	56.253931000000001	58.016834000000003	57.982843000000003	Комсомольский проспект	0103000020E6100000010000000500000001FA7DFFE61D4C40200DA7CCCDFD4C4001FA7DFFE61D4C40FEBAD39D27024D4065389ECF80204C40FEBAD39D27024D4065389ECF80204C40200DA7CCCDFD4C4001FA7DFFE61D4C40200DA7CCCDFD4C40
51996	83	56.345874000000002	56.357256	58.043576999999999	58.034095999999998	Колыбалова	0103000020E61000000100000005000000B3446799452C4C405376FA415D044D40B3446799452C4C40CCED5EEE93054D405F268A90BA2D4C40CCED5EEE93054D405F268A90BA2D4C405376FA415D044D40B3446799452C4C405376FA415D044D40
51912	83	56.236818999999997	56.256563	57.992660999999998	57.986663999999998	Клары Цеткин	0103000020E610000001000000050000002409C215501E4C40FD1186014BFE4C402409C215501E4C40E08101840FFF4C408C2E6F0ED7204C40E08101840FFF4C408C2E6F0ED7204C40FD1186014BFE4C402409C215501E4C40FD1186014BFE4C40
51929	83	56.598705000000002	56.609969999999997	58.057707000000001	58.053573999999998	Кирова	0103000020E61000000100000005000000D1798D5DA24C4C403CF54883DB064D40D1798D5DA24C4C4009E066F162074D4043C5387F134E4C4009E066F162074D4043C5387F134E4C403CF54883DB064D40D1798D5DA24C4C403CF54883DB064D40
51961	83	56.279902	56.312358000000003	58.029541000000002	58.016261999999998	Ким	0103000020E61000000100000005000000E10A28D4D3234C4072158BDF14024D40E10A28D4D3234C401172DEFFC7034D406E52D158FB274C401172DEFFC7034D406E52D158FB274C4072158BDF14024D40E10A28D4D3234C4072158BDF14024D40
51839	83	56.310974000000002	56.320892000000001	58.024036000000002	58.021715	Каспийская	0103000020E6100000010000000500000002F4FBFECD274C40946A9F8EC7024D4002F4FBFECD274C409DF6949C13034D4026C632FD12294C409DF6949C13034D4026C632FD12294C40946A9F8EC7024D4002F4FBFECD274C40946A9F8EC7024D40
51910	83	56.193680999999998	56.218187	57.992522999999998	57.953867000000002	Карпинского	0103000020E61000000100000005000000A46DFC89CA184C40E8DD585018FA4C40A46DFC89CA184C408FC360FE0AFF4C40C8B4368DED1B4C408FC360FE0AFF4C40C8B4368DED1B4C40E8DD585018FA4C40A46DFC89CA184C40E8DD585018FA4C40
51990	83	56.004280999999999	56.021735	58.032085000000002	58.024374999999999	Капитанская	0103000020E61000000100000005000000417FA1478C004C4085EB51B81E034D40417FA1478C004C4099D87C5C1B044D40DB166536C8024C4099D87C5C1B044D40DB166536C8024C4085EB51B81E034D40417FA1478C004C4085EB51B81E034D40
51886	83	56.011879999999998	56.028292999999998	58.046387000000003	58.021157000000002	Калинина	0103000020E61000000100000005000000FDBCA94885014C406E8AC745B5024D40FDBCA94885014C40D3FA5B02F0054D4055DAE21A9F034C40D3FA5B02F0054D4055DAE21A9F034C406E8AC745B5024D40FDBCA94885014C406E8AC745B5024D40
51962	83	56.286000999999999	56.301749000000001	58.117182999999997	58.097943999999998	Кабельщиков	0103000020E61000000100000005000000C8CF46AE9B244C40726BD26D890C4D40C8CF46AE9B244C40D65240DAFF0E4D40E44C13B69F264C40D65240DAFF0E4D40E44C13B69F264C40726BD26D890C4D40C8CF46AE9B244C40726BD26D890C4D40
51937	83	56.293492999999998	56.30395	58.024265	58.015861000000001	Инженерная	0103000020E610000001000000050000006E4DBA2D91254C401424B6BB07024D406E4DBA2D91254C40FEB7921D1B034D4042CF66D5E7264C40FEB7921D1B034D4042CF66D5E7264C401424B6BB07024D406E4DBA2D91254C401424B6BB07024D40
51958	83	56.353734000000003	56.367775000000002	58.063949000000001	58.060378999999998	Ивана Франко	0103000020E61000000100000005000000DCBDDC27472D4C40BE2EC37FBA074D40DCBDDC27472D4C4053CE177B2F084D40A9A44E40132F4C4053CE177B2F084D40A9A44E40132F4C40BE2EC37FBA074D40DCBDDC27472D4C40BE2EC37FBA074D40
51942	83	56.30368	56.312987	58.112071999999998	58.111212000000002	Звенигородская	0103000020E6100000010000000500000082397AFCDE264C401D76DF313C0E4D4082397AFCDE264C400E661360580E4D405D8940F50F284C400E661360580E4D405D8940F50F284C401D76DF313C0E4D4082397AFCDE264C401D76DF313C0E4D40
51916	83	55.941451999999998	55.965159	58.007699000000002	57.995303999999997	Закамская	0103000020E610000001000000050000007C60C77F81F84B40FBC9181F66FF4C407C60C77F81F84B40209BE447FC004D40543882548AFB4B40209BE447FC004D40543882548AFB4B40FBC9181F66FF4C407C60C77F81F84B40FBC9181F66FF4C40
51915	83	56.273721000000002	56.277853999999998	57.975130999999998	57.974677	Загарьинская	0103000020E610000001000000050000003D9D2B4A09234C40EA944737C2FC4C403D9D2B4A09234C406B28B517D1FC4C40098849B890234C406B28B517D1FC4C40098849B890234C40EA944737C2FC4C403D9D2B4A09234C40EA944737C2FC4C40
51501	83	56.195532	56.264684000000003	58.016581000000002	58.002643999999997	Екатерининская	0103000020E6100000010000000500000026A94C3107194C40EBC37AA356004D4026A94C3107194C40145E82531F024D4022E3512AE1214C40145E82531F024D4022E3512AE1214C40EBC37AA356004D4026A94C3107194C40EBC37AA356004D40
51832	83	56.281644	56.292586	58.017249	58.014293000000002	Дружбы	0103000020E61000000100000005000000AC8E1CE90C244C40E7C75F5AD4014D40AC8E1CE90C244C40C171193735024D403CA2427573254C40C171193735024D403CA2427573254C40E7C75F5AD4014D40AC8E1CE90C244C40E7C75F5AD4014D40
51822	83	56.279722	56.285075999999997	58.046743999999997	58.043447999999998	Днепровская	0103000020E6100000010000000500000061FC34EECD234C40CE893DB48F054D4061FC34EECD234C4061A417B5FB054D40EF6FD05E7D244C4061A417B5FB054D40EF6FD05E7D244C40CE893DB48F054D4061FC34EECD234C40CE893DB48F054D40
52210	83	56.159419999999997	56.194372999999999	58.009573000000003	58.003712	Дзержинского	0103000020E61000000100000005000000062AE3DF67144C40274D83A279004D40062AE3DF67144C405AF624B039014D40DA1CE736E1184C405AF624B039014D40DA1CE736E1184C40274D83A279004D40062AE3DF67144C40274D83A279004D40
51953	83	56.161206999999997	56.167343000000002	57.974924999999999	57.969093000000001	Дениса Давыдова	0103000020E610000001000000050000007171546EA2144C402AE44A3D0BFC4C407171546EA2144C40C286A757CAFC4C40761BD47E6B154C40C286A757CAFC4C40761BD47E6B154C402AE44A3D0BFC4C407171546EA2144C402AE44A3D0BFC4C40
54444	83	56.212789000000001	56.215600000000002	58.057035999999997	58.048172999999998	Дедюкина	0103000020E610000001000000050000006AF981AB3C1B4C406DC669882A064D406AF981AB3C1B4C40EA58A5F44C074D404182E2C7981B4C40EA58A5F44C074D404182E2C7981B4C406DC669882A064D406AF981AB3C1B4C406DC669882A064D40
51848	83	56.211908000000001	56.224494	57.964314000000002	57.963436000000002	Гусарова	0103000020E6100000010000000500000061E124CD1F1B4C4000E5EFDE51FB4C4061E124CD1F1B4C40988922A46EFB4C40F9122A38BC1C4C40988922A46EFB4C40F9122A38BC1C4C4000E5EFDE51FB4C4061E124CD1F1B4C4000E5EFDE51FB4C40
51970	83	56.211269999999999	56.215465999999999	58.000292999999999	57.994926999999997	Голева	0103000020E610000001000000050000001E5036E50A1B4C40257497C459FF4C401E5036E50A1B4C4078B5DC9909004D4031B3CF63941B4C4078B5DC9909004D4031B3CF63941B4C40257497C459FF4C401E5036E50A1B4C40257497C459FF4C40
51938	83	56.254047999999997	56.268887999999997	57.995361000000003	57.929312000000003	Героев Хасана	0103000020E610000001000000050000009ECE15A584204C40E3E313B2F3F64C409ECE15A584204C40605B3FFD67FF4C40B72407EC6A224C40605B3FFD67FF4C40B72407EC6A224C40E3E313B2F3F64C409ECE15A584204C40E3E313B2F3F64C40
51945	83	56.384627000000002	56.386144999999999	58.094209999999997	58.083592000000003	Генерала Доватора	0103000020E610000001000000050000004D1421753B314C40871A8524B30A4D404D1421753B314C40637AC2120F0C4D40C84109336D314C40637AC2120F0C4D40C84109336D314C40871A8524B30A4D404D1421753B314C40871A8524B30A4D40
51995	83	56.347976000000003	56.356392999999997	58.071147000000003	58.059283000000001	Гашкова	0103000020E610000001000000050000007EE5417A8A2C4C40B91AD99596074D407EE5417A8A2C4C40B11A4B581B094D40FCC22B499E2D4C40B11A4B581B094D40FCC22B499E2D4C40B91AD99596074D407EE5417A8A2C4C40B91AD99596074D40
51928	83	55.882720999999997	55.939216000000002	57.995204000000001	57.991225	Гальперина	0103000020E61000000100000005000000073F7100FDF04B4022FDF675E0FE4C40073F7100FDF04B40986C3CD862FF4C40A2F0D93A38F84B40986C3CD862FF4C40A2F0D93A38F84B4022FDF675E0FE4C40073F7100FDF04B4022FDF675E0FE4C40
1088	83	56.265591999999998	56.296646000000003	58.021968000000001	57.990304999999999	Гагарина бульвар	0103000020E61000000100000005000000240A2DEBFE214C405B087250C2FE4C40240A2DEBFE214C407EC7F0D8CF024D409F3E027FF8254C407EC7F0D8CF024D409F3E027FF8254C405B087250C2FE4C40240A2DEBFE214C405B087250C2FE4C40
51893	83	56.039583999999998	56.055636999999997	58.045172999999998	58.043914999999998	Высокая	0103000020E61000000100000005000000F1B8A81611054C40E466B8019F054D40F1B8A81611054C40C3D4963AC8054D4049B9FB1C1F074C40C3D4963AC8054D4049B9FB1C1F074C40E466B8019F054D40F1B8A81611054C40E466B8019F054D40
51834	83	56.314917999999999	56.336936000000001	58.041552000000003	58.022238999999999	Восстания	0103000020E61000000100000005000000FB75A73B4F284C400ED940BAD8024D40FB75A73B4F284C40AD8A709351054D402B6C06B8202B4C40AD8A709351054D402B6C06B8202B4C400ED940BAD8024D40FB75A73B4F284C400ED940BAD8024D40
51926	83	55.831902999999997	55.843392000000001	58.037536000000003	58.025409000000003	Воронежская	0103000020E61000000100000005000000DE3829CC7BEA4B401503249A40034D40DE3829CC7BEA4B401A36CAFACD044D40A1DAE044F4EB4B401A36CAFACD044D40A1DAE044F4EB4B401503249A40034D40DE3829CC7BEA4B401503249A40034D40
51991	83	56.001989999999999	56.016390000000001	58.028035000000003	58.023730999999998	Волгодонская	0103000020E61000000100000005000000A375543541004C4060730E9E09034D40A375543541004C405A12A0A696034D40A0FD481119024C405A12A0A696034D40A0FD481119024C4060730E9E09034D40A375543541004C4060730E9E09034D40
51515	83	56.154147000000002	56.170549999999999	57.971083	57.963842	Власова	0103000020E6100000010000000500000065E3C116BB134C407041B62C5FFB4C4065E3C116BB134C40CD599F724CFC4C40992A1895D4154C40CD599F724CFC4C40992A1895D4154C407041B62C5FFB4C4065E3C116BB134C407041B62C5FFB4C40
51902	83	56.288409000000001	56.311459999999997	58.107427000000001	58.096336999999998	Вильямса	0103000020E61000000100000005000000A06F0B96EA244C40873254C5540C4D40A06F0B96EA244C408CDAFD2AC00D4D408E01D9EBDD274C408CDAFD2AC00D4D408E01D9EBDD274C40873254C5540C4D40A06F0B96EA244C40873254C5540C4D40
54674	83	56.232371999999998	56.23283	57.969465	57.963526000000002	Вижайская	0103000020E61000000100000005000000C8409E5DBE1D4C40406CE9D154FB4C40C8409E5DBE1D4C40EECEDA6D17FC4C408BC3995FCD1D4C40EECEDA6D17FC4C408BC3995FCD1D4C40406CE9D154FB4C40C8409E5DBE1D4C40406CE9D154FB4C40
51931	83	56.062716000000002	56.117846	58.045554000000003	58.040595000000003	Ветлужская	0103000020E61000000100000005000000CD77F01307084C40C9B08A3732054D40CD77F01307084C40DB19A6B6D4054D4072FBE593150F4C40DB19A6B6D4054D4072FBE593150F4C40C9B08A3732054D40CD77F01307084C40C9B08A3732054D40
51986	83	56.087859999999999	56.096896999999998	58.051988000000001	58.047567999999998	Вагонная	0103000020E61000000100000005000000335019FF3E0B4C40062B4EB516064D40335019FF3E0B4C4069E4F38AA7064D404E0AF31E670C4C4069E4F38AA7064D404E0AF31E670C4C40062B4EB516064D40335019FF3E0B4C40062B4EB516064D40
51944	83	56.385686999999997	56.400770000000001	58.088068999999997	58.082478000000002	Бушмакина	0103000020E6100000010000000500000005BF0D315E314C40DB519CA38E0A4D4005BF0D315E314C404D6551D8450B4D40E59B6D6E4C334C404D6551D8450B4D40E59B6D6E4C334C40DB519CA38E0A4D4005BF0D315E314C40DB519CA38E0A4D40
52218	83	56.285057999999999	56.322400999999999	57.980108000000001	57.975535999999998	Братская	0103000020E6100000010000000500000049BBD1C77C244C400B09185DDEFC4C4049BBD1C77C244C402446CF2D74FD4C404E999B6F44294C402446CF2D74FD4C404E999B6F44294C400B09185DDEFC4C4049BBD1C77C244C400B09185DDEFC4C40
51837	83	56.323048	56.338965999999999	58.027614999999997	58.024054999999997	Борчаниновская	0103000020E61000000100000005000000E48409A359294C401327F73B14034D40E48409A359294C4084F068E388034D405C3AE63C632B4C4084F068E388034D405C3AE63C632B4C401327F73B14034D40E48409A359294C401327F73B14034D40
51824	83	56.162770000000002	56.283296999999997	58.047316000000002	58.026434000000002	Борцов Революции	0103000020E610000001000000050000008D62B9A5D5144C4051C0763062034D408D62B9A5D5144C40ED4960730E064D4007077B1343244C40ED4960730E064D4007077B1343244C4051C0763062034D408D62B9A5D5144C4051C0763062034D40
51853	83	56.228535999999998	56.229075000000002	57.969475000000003	57.964829999999999	Бородинская	0103000020E61000000100000005000000B5FAEAAA401D4C408F19A88C7FFB4C40B5FAEAAA401D4C4012A5BDC117FC4C4065AA6054521D4C4012A5BDC117FC4C4065AA6054521D4C408F19A88C7FFB4C40B5FAEAAA401D4C408F19A88C7FFB4C40
51981	83	56.173262999999999	56.188381	58.000540999999998	57.997236000000001	Боровая	0103000020E61000000100000005000000AD4D637B2D164C406A32E36DA5FF4C40AD4D637B2D164C4050A73CBA11004D4009185DDE1C184C4050A73CBA11004D4009185DDE1C184C406A32E36DA5FF4C40AD4D637B2D164C406A32E36DA5FF4C40
51972	83	55.924196000000002	55.944147000000001	58.012686000000002	58.001533000000002	Богдана Хмельницкого	0103000020E61000000100000005000000098CF50D4CF64B40B16EBC3B32004D40098CF50D4CF64B40FC8EE1B19F014D40EACE13CFD9F84B40FC8EE1B19F014D40EACE13CFD9F84B40B16EBC3B32004D40098CF50D4CF64B40B16EBC3B32004D40
51908	83	56.247697000000002	56.271538	57.999549000000002	57.993749000000001	Белинского	0103000020E610000001000000050000009E280989B41F4C4063B7CF2A33FF4C409E280989B41F4C40F0DFBC38F1FF4C4085CFD6C1C1224C40F0DFBC38F1FF4C4085CFD6C1C1224C4063B7CF2A33FF4C409E280989B41F4C4063B7CF2A33FF4C40
51911	83	56.180737000000001	56.201658000000002	57.988430000000001	57.981492000000003	Баумана	0103000020E61000000100000005000000AD16D86322174C4090A4A487A1FD4C40AD16D86322174C405131CEDF84FE4C40077DE9EDCF194C405131CEDF84FE4C40077DE9EDCF194C4090A4A487A1FD4C40AD16D86322174C4090A4A487A1FD4C40
51943	83	56.306555000000003	56.306787999999997	58.109405000000002	58.105348999999997	Барнаульская	0103000020E6100000010000000500000070B6B9313D274C4049D576137C0D4D4070B6B9313D274C406B82A8FB000E4D40126745D444274C406B82A8FB000E4D40126745D444274C4049D576137C0D4D4070B6B9313D274C4049D576137C0D4D40
51956	83	56.292487000000001	56.295172999999998	58.006154000000002	58.000006999999997	Аркадия Гайдара	0103000020E61000000100000005000000A9C0C93670254C40B262B83A00004D40A9C0C93670254C40AB5E7EA7C9004D40C3D4963AC8254C40AB5E7EA7C9004D40C3D4963AC8254C40B262B83A00004D40A9C0C93670254C40B262B83A00004D40
51749	83	55.798423	56.658783999999997	58.179842999999998	57.864764000000001	Александра Невского	0103000020E61000000100000005000000E6AF90B932E64B400B613596B0EE4C40E6AF90B932E64B400FB56D1805174D406490BB0853544C400FB56D1805174D406490BB0853544C400B613596B0EE4C40E6AF90B932E64B400B613596B0EE4C40
51930	83	55.929343000000003	55.958475999999997	58.012543000000001	57.992331999999998	Автозаводская	0103000020E610000001000000050000001EE21FB6F4F64B401B6327BC04FF4C401EE21FB6F4F64B4099654F029B014D401D007157AFFA4B4099654F029B014D401D007157AFFA4B401B6327BC04FF4C401EE21FB6F4F64B401B6327BC04FF4C40
51842	83	56.305998000000002	56.319139999999997	58.037779	58.034244000000001	1905 Года	0103000020E610000001000000050000001A5245F12A274C40C80A7E1B62044D401A5245F12A274C40E0BC38F1D5044D40376C5B94D9284C40E0BC38F1D5044D40376C5B94D9284C40C80A7E1B62044D401A5245F12A274C40C80A7E1B62044D40
2010	83	56.506151000000003	56.512107	58.141764999999999	58.139322999999997	1-й Павловский проезд	0103000020E610000001000000050000003AEB538EC9404C40514A0856D5114D403AEB538EC9404C40D55B035B25124D40BE86E0B88C414C40D55B035B25124D40BE86E0B88C414C40514A0856D5114D403AEB538EC9404C40514A0856D5114D40
51519	83	56.237304000000002	56.249422000000003	57.999825999999999	57.997183	 Успенского	0103000020E61000000100000005000000E19A3BFA5F1E4C4047904AB1A3FF4C40E19A3BFA5F1E4C4062D8614CFAFF4C409373620FED1F4C4062D8614CFAFF4C409373620FED1F4C4047904AB1A3FF4C40E19A3BFA5F1E4C4047904AB1A3FF4C40
51985	83	56.124574000000003	56.136350999999998	58.036901999999998	58.034120000000001	 Транспортная	0103000020E6100000010000000500000049F7730AF20F4C40DC114E0B5E044D4049F7730AF20F4C4018946934B9044D4071E316F373114C4018946934B9044D4071E316F373114C40DC114E0B5E044D4049F7730AF20F4C40DC114E0B5E044D40
51984	83	56.189585000000001	56.195028999999998	58.003611999999997	57.997283000000003	 Локомотивная	0103000020E61000000100000005000000F5673F5244184C40ABED26F8A6FF4C40F5673F5244184C40C3EFA65B76004D40C362D4B5F6184C40C3EFA65B76004D40C362D4B5F6184C40ABED26F8A6FF4C40F5673F5244184C40ABED26F8A6FF4C40
51975	83	56.184896000000002	56.264324999999999	58.016838999999997	58.003664999999998	 Ленина	0103000020E61000000100000005000000A39410ACAA174C40E6913F1878004D40A39410ACAA174C400F26C5C727024D40F241CF66D5214C400F26C5C727024D40F241CF66D5214C40E6913F1878004D40A39410ACAA174C40E6913F1878004D40
51850	83	56.396216000000003	56.444338000000002	58.151572999999999	58.149503000000003	 Корсуньская	0103000020E610000001000000050000007313B534B7324C40B3D30FEA22134D407313B534B7324C4072FA7ABE66134D405E2F4D11E0384C4072FA7ABE66134D405E2F4D11E0384C40B3D30FEA22134D407313B534B7324C40B3D30FEA22134D40
51874	83	55.939216000000002	56.011879999999998	58.021157000000002	57.991225	 Кировоградская	0103000020E61000000100000005000000A2F0D93A38F84B4022FDF675E0FE4C40A2F0D93A38F84B406E8AC745B5024D40FDBCA94885014C406E8AC745B5024D40FDBCA94885014C4022FDF675E0FE4C40A2F0D93A38F84B4022FDF675E0FE4C40
51988	83	56.193680999999998	56.218187	57.992522999999998	57.953867000000002	 Карпинского	0103000020E61000000100000005000000A46DFC89CA184C40E8DD585018FA4C40A46DFC89CA184C408FC360FE0AFF4C40C8B4368DED1B4C408FC360FE0AFF4C40C8B4368DED1B4C40E8DD585018FA4C40A46DFC89CA184C40E8DD585018FA4C40
51514	83	56.195532	56.264684000000003	58.016581000000002	58.002643999999997	 Екатерининская	0103000020E6100000010000000500000026A94C3107194C40EBC37AA356004D4026A94C3107194C40145E82531F024D4022E3512AE1214C40145E82531F024D4022E3512AE1214C40EBC37AA356004D4026A94C3107194C40EBC37AA356004D40
62659	58014	57.179025000000003	57.201501	58.843718000000003	58.827902999999999	К. Маркса	0103000020E610000001000000050000004D158C4AEA964C4051A1BAB9F8694D404D158C4AEA964C40F58590F3FE6B4D403F8EE6C8CA994C40F58590F3FE6B4D403F8EE6C8CA994C4051A1BAB9F8694D404D158C4AEA964C4051A1BAB9F8694D40
51615	56229	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Красногвардейская	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
51495	56216	55.409264	55.483517999999997	57.294829	57.263398000000002	Пугачева	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51611	56216	55.409264	55.483517999999997	57.294829	57.263398000000002	М.Горького	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
52041	56216	55.409264	55.483517999999997	57.294829	57.263398000000002	Ленина	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51808	56213	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	проспект Ленина	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
51482	56213	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	Чапаева	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
51608	56213	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	Луговая	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
62602	58007	56.211711000000001	56.253024000000003	58.018855000000002	58.009787000000003	Советская	0103000020E610000001000000050000000B9A9658191B4C4086764EB340014D400B9A9658191B4C40DC2E34D769024D40338D261763204C40DC2E34D769024D40338D261763204C4086764EB340014D400B9A9658191B4C4086764EB340014D40
63196	58078	57.532179999999997	57.564681	58.783864000000001	58.759878	Советская	0103000020E61000000100000005000000EACA67791EC44C409679ABAE43614D40EACA67791EC44C408141D2A755644D4017D68D7747C84C408141D2A755644D4017D68D7747C84C409679ABAE43614D40EACA67791EC44C409679ABAE43614D40
62896	58035	58.197454	58.219571000000002	57.761139	57.747664	Молодежная	0103000020E61000000100000005000000713B342C46194D40C2323674B3DF4C40713B342C46194D40E65AB4006DE14C4034130CE71A1C4D40E65AB4006DE14C4034130CE71A1C4D40C2323674B3DF4C40713B342C46194D40C2323674B3DF4C40
63973	58150	57.825031000000003	57.868248999999999	57.791148999999997	57.767677999999997	Центральная	0103000020E61000000100000005000000D597A59D9AE94C40E9EDCF4543E24C40D597A59D9AE94C40ADA1D45E44E54C4071E481C822EF4C40ADA1D45E44E54C4071E481C822EF4C40E9EDCF4543E24C40D597A59D9AE94C40E9EDCF4543E24C40
51499	56217	56.577719999999999	56.590736999999997	58.050835999999997	58.049812000000003	Мира	0103000020E61000000100000005000000601F9DBAF2494C406479573D60064D40601F9DBAF2494C40CFBA46CB81064D40C1C41F459D4B4C40CFBA46CB81064D40C1C41F459D4B4C406479573D60064D40601F9DBAF2494C406479573D60064D40
51464	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	проспект Победы	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51799	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Чапаева	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51472	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Чайковского	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51466	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Федосеева	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51797	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Уральская	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51593	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Строительная	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51715	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Смышляева	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51801	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Революции	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51708	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Разина	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51534	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Полярников	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51595	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Полевая	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51711	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Орджоникидзе	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51471	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Никулина	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51727	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Мичурина	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51467	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Мира	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51732	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Ленина	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51717	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Кузьмина	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51594	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Коммунаров	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51795	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Калинина	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51803	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Гайдара	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51703	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	Быстрых	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
53174	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	А.Жарова	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
51465	15896	57.752088000000001	57.872928999999999	58.135052000000002	58.074702000000002	 Пожарского	0103000020E6100000010000000500000066DB696B44E04C401079CBD58F094D4066DB696B44E04C4034A1496249114D40705D3123BCEF4C4034A1496249114D40705D3123BCEF4C401079CBD58F094D4066DB696B44E04C401079CBD58F094D40
62889	58033	57.874851999999997	57.900084999999997	57.785521000000003	57.772602999999997	Школьная	0103000020E610000001000000050000008B6B7C26FBEF4C404FE5B4A7E4E24C408B6B7C26FBEF4C401EA9BEF38BE44C40614F3BFC35F34C401EA9BEF38BE44C40614F3BFC35F34C404FE5B4A7E4E24C408B6B7C26FBEF4C404FE5B4A7E4E24C40
51826	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Свободы	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51606	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Пугачева	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51743	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Просвещения	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51469	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Полетаевская	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51798	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Плехановский тракт	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51806	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Матросская	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51840	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	МОПРа	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51723	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Ленина	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51804	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Красная	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51876	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Космонавтов	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51613	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Кирова	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51463	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Каширина	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51701	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Карла Маркса	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51843	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Заводская	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
52191	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Гоголя	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51830	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Гоголя	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51845	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Гайдара	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51811	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Газеты Искра	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51796	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Воровского	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
52127	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Батальонная	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51612	32907	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	 Голованова	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
51497	56218	56.448695000000001	56.529463	57.663421	57.631638000000002	Мира	0103000020E610000001000000050000007A7077D66E394C4097749483D9D04C407A7077D66E394C40643DB5FAEAD44C4095B88E71C5434C40643DB5FAEAD44C4095B88E71C5434C4097749483D9D04C407A7077D66E394C4097749483D9D04C40
51729	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Строителей	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51663	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Пионерская	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51527	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Лихачева	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51539	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Леваневского	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51730	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Кузнецова	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
52285	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Конституции	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51750	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Загородная	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51661	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Горького	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51528	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Гагарина	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51664	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	Братчикова	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
51660	2524	54.613526999999998	54.693351	59.041514999999997	58.965049999999998	50 лет Октября	0103000020E61000000100000005000000431B800D884E4B409D8026C2867B4D40431B800D884E4B408FA50F5D50854D400FD3BEB9BF584B408FA50F5D50854D400FD3BEB9BF584B409D8026C2867B4D40431B800D884E4B409D8026C2867B4D40
62595	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	проспект Маяковского	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62592	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	переулок Банковский	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62600	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Энтузиастов	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
51829	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Чапаева	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62580	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Советская	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62593	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Рождественский проезд	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62578	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Матросова	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
51878	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Ленина	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62577	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Коммунистическая	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
81117	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Комарова	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62582	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	Карла Маркса	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62598	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	К.Либкнехта	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
62586	56211	55.438701000000002	56.208044999999998	58.351872	58.003321	50 лет Октября	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
51459	56210	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Толстого	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
52125	56210	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Морчанская	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
51457	56210	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Дзержинского	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
51543	56210	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Гагарина	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
52123	56210	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	1го Мая	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
51628	10335	56.102457000000001	56.104056	57.982590000000002	57.973556000000002	Карла Маркса	0103000020E61000000100000005000000861F9C4F1D0D4C408C69A67B9DFC4C40861F9C4F1D0D4C4036B05582C5FD4C40EE79FEB4510D4C4036B05582C5FD4C40EE79FEB4510D4C408C69A67B9DFC4C40861F9C4F1D0D4C408C69A67B9DFC4C40
51605	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Широковская	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51597	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Фурманова	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51675	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Советская	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51677	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Пролетарская	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51532	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Народной Памяти	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51584	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Макаренко	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51453	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Ленина	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51585	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Крупской	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51556	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Капитальный	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
51586	7570	57.579872000000002	57.722011999999999	59.077599999999997	59.022463999999999	Ашихмина	0103000020E61000000100000005000000DDEEE53E39CA4C402EABB019E0824D40DDEEE53E39CA4C40B515FBCBEE894D40E7A8A3E36ADC4C40B515FBCBEE894D40E7A8A3E36ADC4C402EABB019E0824D40DDEEE53E39CA4C402EABB019E0824D40
62825	58030	57.473438999999999	57.496893999999998	59.257745	59.245975999999999	Мира	0103000020E6100000010000000500000052D32EA699BC4C40EACC3D247C9F4D4052D32EA699BC4C4090DAC4C9FDA04D4010CAFB389ABF4C4090DAC4C9FDA04D4010CAFB389ABF4C40EACC3D247C9F4D4052D32EA699BC4C40EACC3D247C9F4D40
52037	56265	56.184896000000002	56.264324999999999	58.016838999999997	58.003664999999998	улица Ленина	0103000020E61000000100000005000000A39410ACAA174C40E6913F1878004D40A39410ACAA174C400F26C5C727024D40F241CF66D5214C400F26C5C727024D40F241CF66D5214C40E6913F1878004D40A39410ACAA174C40E6913F1878004D40
51577	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	пер. Строителей	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51788	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Энгельса	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
52004	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Трудовые резервы	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51438	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Советская	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51792	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Победы	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51697	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Переулок Строителей	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51439	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Маяковского	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51698	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Красногвардейская	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51574	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Жуковского	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51437	1505	56.387115999999999	56.459825000000002	58.493799000000003	58.432561999999997	Ветеранов Войны	0103000020E6100000010000000500000011E15F048D314C4005BF0D315E374D4011E15F048D314C4015E63DCE343F4D400D71AC8BDB3A4C4015E63DCE343F4D400D71AC8BDB3A4C4005BF0D315E374D4011E15F048D314C4005BF0D315E374D40
51695	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	проспект Октябрьский	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51435	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	пр.Октябрьский	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51434	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	пр.Ленина	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51787	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	Проспект Ленина	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51572	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	Парковая	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51569	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	Космонавтов	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51568	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	Коммунистическая	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51575	120	57.519092000000001	57.630411000000002	58.911783	58.824325000000002	Дегтярёва	0103000020E61000000100000005000000C0CE4D9B71C24C403A234A7B83694D40C0CE4D9B71C24C403E062B4EB5744D40F304C24EB1D04C403E062B4EB5744D40F304C24EB1D04C403A234A7B83694D40C0CE4D9B71C24C403A234A7B83694D40
51674	77	57.741973000000002	57.889035999999997	58.59901	58.498963000000003	Шахтеров	0103000020E61000000100000005000000ECC1A4F8F8DE4C4000750305DE3F4D40ECC1A4F8F8DE4C400DFD135CAC4C4D40BB7B80EECBF14C400DFD135CAC4C4D40BB7B80EECBF14C4000750305DE3F4D40ECC1A4F8F8DE4C4000750305DE3F4D40
52182	77	57.741973000000002	57.889035999999997	58.59901	58.498963000000003	Ушакова	0103000020E61000000100000005000000ECC1A4F8F8DE4C4000750305DE3F4D40ECC1A4F8F8DE4C400DFD135CAC4C4D40BB7B80EECBF14C400DFD135CAC4C4D40BB7B80EECBF14C4000750305DE3F4D40ECC1A4F8F8DE4C4000750305DE3F4D40
52003	77	57.741973000000002	57.889035999999997	58.59901	58.498963000000003	Труда	0103000020E61000000100000005000000ECC1A4F8F8DE4C4000750305DE3F4D40ECC1A4F8F8DE4C400DFD135CAC4C4D40BB7B80EECBF14C400DFD135CAC4C4D40BB7B80EECBF14C4000750305DE3F4D40ECC1A4F8F8DE4C4000750305DE3F4D40
51823	77	57.741973000000002	57.889035999999997	58.59901	58.498963000000003	Ленина	0103000020E61000000100000005000000ECC1A4F8F8DE4C4000750305DE3F4D40ECC1A4F8F8DE4C400DFD135CAC4C4D40BB7B80EECBF14C400DFD135CAC4C4D40BB7B80EECBF14C4000750305DE3F4D40ECC1A4F8F8DE4C4000750305DE3F4D40
51854	77	57.741973000000002	57.889035999999997	58.59901	58.498963000000003	Грибоедова	0103000020E61000000100000005000000ECC1A4F8F8DE4C4000750305DE3F4D40ECC1A4F8F8DE4C400DFD135CAC4C4D40BB7B80EECBF14C400DFD135CAC4C4D40BB7B80EECBF14C4000750305DE3F4D40ECC1A4F8F8DE4C4000750305DE3F4D40
51691	56238	58.295470000000002	58.344706000000002	58.397803000000003	58.366931999999998	Кирова	0103000020E610000001000000050000007D7901F6D1254D408DEDB5A0F72E4D407D7901F6D1254D4017A06D35EB324D40145E82531F2C4D4017A06D35EB324D40145E82531F2C4D408DEDB5A0F72E4D407D7901F6D1254D408DEDB5A0F72E4D40
51617	56230	56.089872	56.112670999999999	57.872371000000001	57.860923999999997	50 лет Октября	0103000020E61000000100000005000000BE69FAEC800B4C40B62BF4C132EE4C40BE69FAEC800B4C404A7D59DAA9EF4C40931ADA006C0E4C404A7D59DAA9EF4C40931ADA006C0E4C40B62BF4C132EE4C40BE69FAEC800B4C40B62BF4C132EE4C40
51431	56207	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Ленина	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51443	56207	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	К.Маркса	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51427	56207	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Железнодорожная	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
63689	58119	55.983987999999997	56.024698999999998	56.529699000000001	56.509726999999998	Зеленая	0103000020E6100000010000000500000006D49B51F3FD4B40B071FDBB3E414C4006D49B51F3FD4B40A9DC442DCD434C40389F3A5629034C40A9DC442DCD434C40389F3A5629034C40B071FDBB3E414C4006D49B51F3FD4B40B071FDBB3E414C40
63474	58107	55.464717	55.488953000000002	57.343245000000003	57.334238999999997	Центральная	0103000020E610000001000000050000009772BED87BBB4B401C06F357C8AA4C409772BED87BBB4B40FDC1C073EFAB4C40FB230C0396BE4B40FDC1C073EFAB4C40FB230C0396BE4B401C06F357C8AA4C409772BED87BBB4B401C06F357C8AA4C40
51551	56225	56.352584	56.38973	57.763928999999997	57.720469000000001	Школьная	0103000020E61000000100000005000000E38BF678212D4C401364045438DC4C40E38BF678212D4C40A5BBEB6CC8E14C40922232ACE2314C40A5BBEB6CC8E14C40922232ACE2314C401364045438DC4C40E38BF678212D4C401364045438DC4C40
51479	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Юбилейная	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51545	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Черняховского	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51428	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Химиков	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51426	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Тельмана	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51493	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Советский проспект	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51468	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Свердлова	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51570	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Пятилетки	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51549	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Потемина	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51757	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	О. Кошевого	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51476	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Набережная	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51505	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Мира	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51458	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Ломоносова	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51433	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Ленина проспект	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51552	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Л. Толстого	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51614	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Комсомольская	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51444	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Дощеникова	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
64464	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Восточная	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51450	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	В. Бирюковой	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
52178	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Аксакова	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51578	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	Азотчиков	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
51470	22854	56.715063999999998	56.882976999999997	59.471890000000002	59.367911999999997	30 лет Победы	0103000020E6100000010000000500000002469737875B4C4029E78BBD17AF4D4002469737875B4C409CA73AE466BC4D40620FED6305714C409CA73AE466BC4D40620FED6305714C4029E78BBD17AF4D4002469737875B4C4029E78BBD17AF4D40
52011	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	Советская	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
52114	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	Пионерская	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
51560	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	Мехоношина	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
51558	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	Ленина	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
51671	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	Кирова	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
52066	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	Калинина	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
51415	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	Войкова	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
52062	21403	57.537795000000003	57.615426999999997	59.179090000000002	59.146217999999998	III Интернационала	0103000020E61000000100000005000000E6797077D6C44C40130B7C45B7924D40E6797077D6C44C403485CE6BEC964D40A609DB4FC6CE4C403485CE6BEC964D40A609DB4FC6CE4C40130B7C45B7924D40E6797077D6C44C40130B7C45B7924D40
54496	4808	54.940693000000003	54.978395999999996	58.971071999999999	58.953263999999997	Центральная	0103000020E61000000100000005000000BF49D3A068784B40213A048E047A4D40BF49D3A068784B40D90759164C7C4D40C34483143C7D4B40D90759164C7C4D40C34483143C7D4B40213A048E047A4D40BF49D3A068784B40213A048E047A4D40
51667	4808	54.940693000000003	54.978395999999996	58.971071999999999	58.953263999999997	Красноармейская	0103000020E61000000100000005000000BF49D3A068784B40213A048E047A4D40BF49D3A068784B40D90759164C7C4D40C34483143C7D4B40D90759164C7C4D40C34483143C7D4B40213A048E047A4D40BF49D3A068784B40213A048E047A4D40
54500	5179	54.988312999999998	55.013294999999999	59.055340000000001	59.047648000000002	Центральная	0103000020E61000000100000005000000179B560A817E4B4023DC645419864D40179B560A817E4B409014916115874D40A4198BA6B3814B409014916115874D40A4198BA6B3814B4023DC645419864D40179B560A817E4B4023DC645419864D40
54571	5648	55.555455000000002	55.580635000000001	59.186936000000003	59.173653000000002	Комсомольская	0103000020E6100000010000000500000029B3412619C74B4018EDF1423A964D4029B3412619C74B40F838D384ED974D40DCF4673F52CA4B40F838D384ED974D40DCF4673F52CA4B4018EDF1423A964D4029B3412619C74B4018EDF1423A964D40
64750	58336	55.407063000000001	55.431829	59.096980000000002	59.090342	Парковая	0103000020E61000000100000005000000B134F0A31AB44B4045BA9F53908B4D40B134F0A31AB44B40DC2E34D7698C4D40713B342C46B74B40DC2E34D7698C4D40713B342C46B74B4045BA9F53908B4D40B134F0A31AB44B4045BA9F53908B4D40
51731	5907	56.057892000000002	56.114046000000002	59.098846999999999	59.067363999999998	Судомеханическая	0103000020E610000001000000050000009B594B0169074C40C07630629F884D409B594B0169074C406327BC04A78C4D40AC1E300F990E4C406327BC04A78C4D40AC1E300F990E4C40C07630629F884D409B594B0169074C40C07630629F884D40
51777	5907	56.057892000000002	56.114046000000002	59.098846999999999	59.067363999999998	Ленина	0103000020E610000001000000050000009B594B0169074C40C07630629F884D409B594B0169074C406327BC04A78C4D40AC1E300F990E4C406327BC04A78C4D40AC1E300F990E4C40C07630629F884D409B594B0169074C40C07630629F884D40
54513	5399	55.207897000000003	55.236454999999999	59.094715000000001	59.083953000000001	Центральная	0103000020E61000000100000005000000E0F76F5E9C9A4B4057B3CEF8BE8A4D40E0F76F5E9C9A4B4067B8019F1F8C4D40E3FC4D28449E4B4067B8019F1F8C4D40E3FC4D28449E4B4057B3CEF8BE8A4D40E0F76F5E9C9A4B4057B3CEF8BE8A4D40
52998	5672	55.69341	55.747371000000001	59.016795000000002	59.005614000000001	Центральная	0103000020E61000000100000005000000145CACA8C1D84B402B33A5F5B7804D40145CACA8C1D84B4040DEAB5626824D404A7D59DAA9DF4B4040DEAB5626824D404A7D59DAA9DF4B402B33A5F5B7804D40145CACA8C1D84B402B33A5F5B7804D40
64599	58290	54.999192000000001	55.014507999999999	59.097132999999999	59.089201000000003	Центральная	0103000020E6100000010000000500000061360186E57F4B40A0E238F06A8B4D4061360186E57F4B40622EA9DA6E8C4D40E3C3EC65DB814B40622EA9DA6E8C4D40E3C3EC65DB814B40A0E238F06A8B4D4061360186E57F4B40A0E238F06A8B4D40
52045	5092	54.830443000000002	54.839731999999998	58.880043999999998	58.870536000000001	Центральная	0103000020E610000001000000050000009818CBF44B6A4B40CEFE40B96D6F4D409818CBF44B6A4B4040852348A5704D40CCB392567C6B4B4040852348A5704D40CCB392567C6B4B40CEFE40B96D6F4D409818CBF44B6A4B40CEFE40B96D6F4D40
52103	5748	55.826630000000002	55.934356000000001	59.017581999999997	58.990915999999999	Октябрьская	0103000020E610000001000000050000003DF20703CFE94B40A48AE255D67E4D403DF20703CFE94B40C77F812040824D40236937FA98F74B40C77F812040824D40236937FA98F74B40A48AE255D67E4D403DF20703CFE94B40A48AE255D67E4D40
53738	5748	55.826630000000002	55.934356000000001	59.017581999999997	58.990915999999999	Ленина	0103000020E610000001000000050000003DF20703CFE94B40A48AE255D67E4D403DF20703CFE94B40C77F812040824D40236937FA98F74B40C77F812040824D40236937FA98F74B40A48AE255D67E4D403DF20703CFE94B40A48AE255D67E4D40
54533	7097	55.504063000000002	55.525281	58.994498999999998	58.980367000000001	Школьная	0103000020E61000000100000005000000D40FEA2285C04B40F08975AA7C7D4D40D40FEA2285C04B40CD7344BE4B7F4D40E71A66683CC34B40CD7344BE4B7F4D40E71A66683CC34B40F08975AA7C7D4D40D40FEA2285C04B40F08975AA7C7D4D40
54479	5458	55.39949	55.433059999999998	58.965026999999999	58.924098999999998	Центральная	0103000020E610000001000000050000001E8A027D22B34B4016A243E048764D401E8A027D22B34B40E5603601867B4D40569A94826EB74B40E5603601867B4D40569A94826EB74B4016A243E048764D401E8A027D22B34B4016A243E048764D40
52073	56272	55.417572999999997	55.425640000000001	59.077595000000002	59.072387999999997	Трудовая	0103000020E61000000100000005000000A758350873B54B40B94F8E0244894D40A758350873B54B40A4AA09A2EE894D404AEF1B5F7BB64B40A4AA09A2EE894D404AEF1B5F7BB64B40B94F8E0244894D40A758350873B54B40B94F8E0244894D40
54535	5353	55.239894999999997	55.252102999999998	59.060231000000002	59.044148999999997	Школьная	0103000020E61000000100000005000000A9BC1DE1B49E4B405793A7ACA6854D40A9BC1DE1B49E4B404A9A3FA6B5874D409B1C3EE944A04B404A9A3FA6B5874D409B1C3EE944A04B405793A7ACA6854D40A9BC1DE1B49E4B405793A7ACA6854D40
54271	56515	55.587201999999998	55.613999	58.996979000000003	58.989984	Садовая	0103000020E61000000100000005000000A912656F29CB4B4019C8B3CBB77E4D40A912656F29CB4B403FE603029D7F4D406B63EC8497CE4B403FE603029D7F4D406B63EC8497CE4B4019C8B3CBB77E4D40A912656F29CB4B4019C8B3CBB77E4D40
64536	47314	55.118461000000003	55.406973000000001	59.129100999999999	58.951453000000001	Центральная	0103000020E61000000100000005000000FD6CE4BA298F4B402E573F36C9794D40FD6CE4BA298F4B40C170AE6186904D4071ADF6B017B44B40C170AE6186904D4071ADF6B017B44B402E573F36C9794D40FD6CE4BA298F4B402E573F36C9794D40
52106	47368	54.958748999999997	54.985940999999997	59.035445000000003	59.027313999999997	Центральная	0103000020E610000001000000050000004E098849B87A4B40895C70067F834D404E098849B87A4B4043E7357689844D408C648F50337E4B4043E7357689844D408C648F50337E4B40895C70067F834D404E098849B87A4B40895C70067F834D40
52137	47436	55.150719000000002	55.179572999999998	59.025298999999997	59.012971999999998	Мира	0103000020E6100000010000000500000063F19BC24A934B40C1E10511A9814D4063F19BC24A934B408DCF64FF3C834D404F1F813FFC964B408DCF64FF3C834D404F1F813FFC964B40C1E10511A9814D4063F19BC24A934B40C1E10511A9814D40
64749	5498	55.356226999999997	55.372819	58.991013000000002	58.98563	Школьная	0103000020E61000000100000005000000E179A9D898AD4B406EFAB31F297E4D40E179A9D898AD4B4097749483D97E4D40E9297288B8AF4B4097749483D97E4D40E9297288B8AF4B406EFAB31F297E4D40E179A9D898AD4B406EFAB31F297E4D40
52246	56328	55.541082000000003	55.550164000000002	59.094127999999998	59.088017000000001	 Совхозная	0103000020E61000000100000005000000263ACB2C42C54B40FB3E1C24448B4D40263ACB2C42C54B40A6D1E4620C8C4D40E1B721C66BC64B40A6D1E4620C8C4D40E1B721C66BC64B40FB3E1C24448B4D40263ACB2C42C54B40FB3E1C24448B4D40
51557	3504	54.284967999999999	54.337735000000002	59.340215999999998	59.313428999999999	Пионеров	0103000020E610000001000000050000000934D8D479244B401A4F04711EA84D400934D8D479244B40B8C9A8328CAB4D4077DB85E63A2B4B40B8C9A8328CAB4D4077DB85E63A2B4B401A4F04711EA84D400934D8D479244B401A4F04711EA84D40
54426	3504	54.284967999999999	54.337735000000002	59.340215999999998	59.313428999999999	Кузнецова	0103000020E610000001000000050000000934D8D479244B401A4F04711EA84D400934D8D479244B40B8C9A8328CAB4D4077DB85E63A2B4B40B8C9A8328CAB4D4077DB85E63A2B4B401A4F04711EA84D400934D8D479244B401A4F04711EA84D40
51445	3504	54.284967999999999	54.337735000000002	59.340215999999998	59.313428999999999	Гагарина	0103000020E610000001000000050000000934D8D479244B401A4F04711EA84D400934D8D479244B40B8C9A8328CAB4D4077DB85E63A2B4B40B8C9A8328CAB4D4077DB85E63A2B4B401A4F04711EA84D400934D8D479244B401A4F04711EA84D40
63748	24578	57.228056000000002	57.263350000000003	58.167321999999999	58.155819000000001	Новая	0103000020E610000001000000050000000BD462F0309D4C40378C82E0F1134D400BD462F0309D4C405EF3AACE6A154D4068B3EA73B5A14C405EF3AACE6A154D4068B3EA73B5A14C40378C82E0F1134D400BD462F0309D4C40378C82E0F1134D40
51773	23986	57.687722999999998	57.752744	58.298682999999997	58.257849999999998	Первомайская	0103000020E610000001000000050000007FDAA84E07D84C4005A3923A01214D407FDAA84E07D84C40826F9A3E3B264D404F2157EA59E04C40826F9A3E3B264D404F2157EA59E04C4005A3923A01214D407FDAA84E07D84C4005A3923A01214D40
52053	23986	57.687722999999998	57.752744	58.298682999999997	58.257849999999998	Мира	0103000020E610000001000000050000007FDAA84E07D84C4005A3923A01214D407FDAA84E07D84C40826F9A3E3B264D404F2157EA59E04C40826F9A3E3B264D404F2157EA59E04C4005A3923A01214D407FDAA84E07D84C4005A3923A01214D40
51774	24131	57.586024999999999	57.637777	58.260179000000001	58.239345999999998	Заводская	0103000020E61000000100000005000000B7D100DE02CB4C40D636C5E3A21E4D40B7D100DE02CB4C40910DA48B4D214D400C923EADA2D14C40910DA48B4D214D400C923EADA2D14C40D636C5E3A21E4D40B7D100DE02CB4C40D636C5E3A21E4D40
52197	48506	57.077004000000002	57.089894999999999	58.091461000000002	58.081417000000002	Парковая	0103000020E61000000100000005000000A2D45E44DB894C40522B4CDF6B0A4D40A2D45E44DB894C4003EE79FEB40B4D407689EAAD818B4C4003EE79FEB40B4D407689EAAD818B4C40522B4CDF6B0A4D40A2D45E44DB894C40522B4CDF6B0A4D40
51725	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	бульвар 48 Стрелковой Бригады	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51517	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Юбилейная	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51748	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Пушкина	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51768	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Нефтяников	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
52085	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Мира	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51654	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Луначарского	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51657	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Ленина	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51518	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Красноармейская	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51554	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Комсомольская	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51659	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Коммунистическая	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
51765	20947	56.052959999999999	56.141165999999998	56.528869999999998	56.461207999999999	Горького	0103000020E6100000010000000500000082FFAD64C7064C40A8531EDD083B4C4082FFAD64C7064C40F2EA1C03B2434C4050A73CBA11124C40F2EA1C03B2434C4050A73CBA11124C40A8531EDD083B4C4082FFAD64C7064C40A8531EDD083B4C40
52323	56351	55.829144999999997	55.847254999999997	56.624592999999997	56.606064000000003	 Школьная	0103000020E610000001000000050000002A52616C21EA4B4038A45181934D4C402A52616C21EA4B40BF27D6A9F24F4C40AD2F12DA72EC4B40BF27D6A9F24F4C40AD2F12DA72EC4B4038A45181934D4C402A52616C21EA4B4038A45181934D4C40
64529	58255	56.335965999999999	56.381286000000003	56.647078	56.634892000000001	Золина	0103000020E61000000100000005000000B24813EF002B4C40FB3E1C2444514C40B24813EF002B4C4005FBAF73D3524C401A36CAFACD304C4005FBAF73D3524C401A36CAFACD304C40FB3E1C2444514C40B24813EF002B4C40FB3E1C2444514C40
62861	56355	56.296430999999998	56.332920000000001	56.700667000000003	56.684632000000001	Центральная	0103000020E61000000100000005000000A2427573F1254C40C5E57805A2574C40A2427573F1254C407731CD74AF594C409817601F9D2A4C407731CD74AF594C409817601F9D2A4C40C5E57805A2574C40A2427573F1254C40C5E57805A2574C40
51872	56254	55.748629000000001	56.631529	56.771906000000001	56.289935	Буденного	0103000020E6100000010000000500000029EB3713D3DF4B409E7B0F971C254C4029EB3713D3DF4B4008CBD8D0CD624C40E0BC38F1D5504C4008CBD8D0CD624C40E0BC38F1D5504C409E7B0F971C254C4029EB3713D3DF4B409E7B0F971C254C40
52140	23048	56.662376999999999	56.691338999999999	61.145086999999997	61.118329000000003	Бажова	0103000020E61000000100000005000000B14F00C5C8544C408E959867258F4E40B14F00C5C8544C409109F83592924E4084B9DDCB7D584C409109F83592924E4084B9DDCB7D584C408E959867258F4E40B14F00C5C8544C408E959867258F4E40
51655	19585	56.446593	56.507032000000002	60.421021000000003	60.376935000000003	Яборова	0103000020E61000000100000005000000AFCF9CF529394C40E0DBF4673F304E40AFCF9CF529394C40F1F62004E4354E404303B16CE6404C40F1F62004E4354E404303B16CE6404C40E0DBF4673F304E40AFCF9CF529394C40E0DBF4673F304E40
51721	19585	56.446593	56.507032000000002	60.421021000000003	60.376935000000003	Успенская	0103000020E61000000100000005000000AFCF9CF529394C40E0DBF4673F304E40AFCF9CF529394C40F1F62004E4354E404303B16CE6404C40F1F62004E4354E404303B16CE6404C40E0DBF4673F304E40AFCF9CF529394C40E0DBF4673F304E40
51722	19585	56.446593	56.507032000000002	60.421021000000003	60.376935000000003	Прокопьевская	0103000020E61000000100000005000000AFCF9CF529394C40E0DBF4673F304E40AFCF9CF529394C40F1F62004E4354E404303B16CE6404C40F1F62004E4354E404303B16CE6404C40E0DBF4673F304E40AFCF9CF529394C40E0DBF4673F304E40
52333	20337	55.631703999999999	55.646121999999998	60.430714999999999	60.419865999999999	Центральная	0103000020E610000001000000050000004E603AADDBD04B40E659492BBE354E404E603AADDBD04B40C5724BAB21374E40F19C2D20B4D24B40C5724BAB21374E40F19C2D20B4D24B40E659492BBE354E404E603AADDBD04B40E659492BBE354E40
53181	56409	56.316642999999999	56.344921999999997	60.336360999999997	60.328046000000001	Вторая	0103000020E61000000100000005000000F0C000C287284C40B4CA4C69FD294E40F0C000C287284C402E5393E00D2B4E40E0D57267262C4C402E5393E00D2B4E40E0D57267262C4C40B4CA4C69FD294E40F0C000C287284C40B4CA4C69FD294E40
52320	32976	56.504066999999999	56.517074999999998	60.374462000000001	60.363126999999999	Героев	0103000020E6100000010000000500000015FF774485404C40B5A50EF27A2E4E4015FF774485404C4021CCED5EEE2F4E40234A7B832F424C4021CCED5EEE2F4E40234A7B832F424C40B5A50EF27A2E4E4015FF774485404C40B5A50EF27A2E4E40
64743	48463	55.763621999999998	55.776575999999999	60.982809000000003	60.978296	Набережная	0103000020E61000000100000005000000C8409E5DBEE14B4060E7A6CD387D4E40C8409E5DBEE14B40749B70AFCC7D4E40E36DA5D766E34B40749B70AFCC7D4E40E36DA5D766E34B4060E7A6CD387D4E40C8409E5DBEE14B4060E7A6CD387D4E40
51724	20102	56.478771000000002	56.516517999999998	60.337936999999997	60.304192999999998	Ленина	0103000020E61000000100000005000000F9A23D5E483D4C400856D5CBEF264E40F9A23D5E483D4C40DE8D0585412B4E40CDE506431D424C40DE8D0585412B4E40CDE506431D424C400856D5CBEF264E40F9A23D5E483D4C400856D5CBEF264E40
52291	19982	56.446610999999997	56.471054000000002	60.194575999999998	60.179285	Набережная	0103000020E6100000010000000500000055849B8C2A394C40E9D495CFF2164E4055849B8C2A394C40124BCADDE7184E4033535A7F4B3C4C40124BCADDE7184E4033535A7F4B3C4C40E9D495CFF2164E4055849B8C2A394C40E9D495CFF2164E40
52337	8832	56.243879	56.275832000000001	60.160423000000002	60.147472	Набережная	0103000020E610000001000000050000003197546D371F4C40B189CC5CE0124E403197546D371F4C405B43A9BD88144E405B9885764E234C405B43A9BD88144E405B9885764E234C40B189CC5CE0124E403197546D371F4C40B189CC5CE0124E40
52082	20683	56.442568999999999	56.464585999999997	60.464142000000002	60.440663999999998	Мира	0103000020E61000000100000005000000999CDA19A6384C4024438EAD67384E40999CDA19A6384C409B594B01693B4E40F816D68D773B4C409B594B01693B4E40F816D68D773B4C4024438EAD67384E40999CDA19A6384C4024438EAD67384E40
52286	13987	55.999555000000001	56.033943000000001	60.838464999999999	60.813254000000001	Школьная	0103000020E61000000100000005000000D2C6116BF1FF4B40ACAB02B518684E40D2C6116BF1FF4B409AEB34D2526B4E40CD76853E58044C409AEB34D2526B4E40CD76853E58044C40ACAB02B518684E40D2C6116BF1FF4B40ACAB02B518684E40
64551	13987	55.999555000000001	56.033943000000001	60.838464999999999	60.813254000000001	Складская	0103000020E61000000100000005000000D2C6116BF1FF4B40ACAB02B518684E40D2C6116BF1FF4B409AEB34D2526B4E40CD76853E58044C409AEB34D2526B4E40CD76853E58044C40ACAB02B518684E40D2C6116BF1FF4B40ACAB02B518684E40
52153	19766	56.681007999999999	56.744070000000001	60.760342999999999	60.705542999999999	Уральская	0103000020E610000001000000050000003D2828452B574C40FB75A73B4F5A4E403D2828452B574C400B5F5FEB52614E40A5F78DAF3D5F4C400B5F5FEB52614E40A5F78DAF3D5F4C40FB75A73B4F5A4E403D2828452B574C40FB75A73B4F5A4E40
51656	19766	56.681007999999999	56.744070000000001	60.760342999999999	60.705542999999999	Уждавиниса	0103000020E610000001000000050000003D2828452B574C40FB75A73B4F5A4E403D2828452B574C400B5F5FEB52614E40A5F78DAF3D5F4C400B5F5FEB52614E40A5F78DAF3D5F4C40FB75A73B4F5A4E403D2828452B574C40FB75A73B4F5A4E40
52268	56331	56.121519999999997	56.151308	60.173096000000001	60.157198999999999	Центральная	0103000020E61000000100000005000000ABE7A4F78D0F4C4061FBC9181F144E40ABE7A4F78D0F4C40C2887D0228164E40C4CF7F0F5E134C40C2887D0228164E40C4CF7F0F5E134C4061FBC9181F144E40ABE7A4F78D0F4C4061FBC9181F144E40
66983	58905	56.246161000000001	56.266534999999998	60.112597999999998	60.098627999999998	Камская	0103000020E610000001000000050000007C462234821F4C40253CA1D79F0C4E407C462234821F4C4029CC7B9C690E4E40A31EA2D11D224C4029CC7B9C690E4E40A31EA2D11D224C40253CA1D79F0C4E407C462234821F4C40253CA1D79F0C4E40
53634	20788	56.143205000000002	56.199511000000001	60.408160000000002	60.397146999999997	Центральная	0103000020E61000000100000005000000D5CF9B8A54124C402D5A80B6D5324E40D5CF9B8A54124C4087C43D963E344E409C18929389194C4087C43D963E344E409C18929389194C402D5A80B6D5324E40D5CF9B8A54124C402D5A80B6D5324E40
51536	2657	56.268700000000003	56.313831	59.958638000000001	59.936751000000001	Пушкина	0103000020E61000000100000005000000B537F8C264224C4066BFEE74E7F74D40B537F8C264224C40F75965A6B4FA4D4049BC3C9D2B284C40F75965A6B4FA4D4049BC3C9D2B284C4066BFEE74E7F74D40B537F8C264224C4066BFEE74E7F74D40
64389	13299	56.680407000000002	56.722448	60.655946	60.641418000000002	Молодёжная	0103000020E61000000100000005000000187C9A9317574C406A882AFC19524E40187C9A9317574C4094F8DC09F6534E40C287122D795C4C4094F8DC09F6534E40C287122D795C4C406A882AFC19524E40187C9A9317574C406A882AFC19524E40
52169	20416	56.444626	56.48319	60.569830000000003	60.552180999999997	Трактовая	0103000020E61000000100000005000000C4793881E9384C407D3CF4DDAD464E40C4793881E9384C40CD237F30F0484E408BE07F2BD93D4C40CD237F30F0484E408BE07F2BD93D4C407D3CF4DDAD464E40C4793881E9384C407D3CF4DDAD464E40
52049	20884	57.240532999999999	57.263601999999999	61.136961999999997	61.124056000000003	Набережная	0103000020E61000000100000005000000EC4D0CC9C99E4C40B16F2711E18F4E40EC4D0CC9C99E4C40BA6587F887914E408194D8B5BDA14C40BA6587F887914E408194D8B5BDA14C40B16F2711E18F4E40EC4D0CC9C99E4C40B16F2711E18F4E40
53633	20838	57.468040000000002	57.518327999999997	60.835431	60.824010999999999	Советская	0103000020E61000000100000005000000249C16BCE8BB4C40AA45443179694E40249C16BCE8BB4C4044882B67EF6A4E40F04C689258C24C4044882B67EF6A4E40F04C689258C24C40AA45443179694E40249C16BCE8BB4C40AA45443179694E40
52167	20241	55.908017000000001	55.944164999999998	60.496076000000002	60.478279999999998	Красноармейская	0103000020E61000000100000005000000249BABE639F44B405A2A6F47383D4E40249BABE639F44B404E2A1A6B7F3F4E4090831266DAF84B404E2A1A6B7F3F4E4090831266DAF84B405A2A6F47383D4E40249BABE639F44B405A2A6F47383D4E40
52272	20608	56.111369000000003	56.129370999999999	60.282280999999998	60.269404999999999	Советская	0103000020E61000000100000005000000E564E256410E4C407F30F0DC7B224E40E564E256410E4C401EA4A7C821244E4081069B3A8F104C401EA4A7C821244E4081069B3A8F104C407F30F0DC7B224E40E564E256410E4C407F30F0DC7B224E40
51778	56244	55.833646000000002	55.845539000000002	59.998804999999997	59.992623000000002	Пролетарская	0103000020E610000001000000050000007A3881E9B4EA4B40F3203D450EFF4D407A3881E9B4EA4B40670A9DD7D8FF4D400C3F389F3AEC4B40670A9DD7D8FF4D400C3F389F3AEC4B40F3203D450EFF4D407A3881E9B4EA4B40F3203D450EFF4D40
53629	32877	54.811228	54.850394999999999	57.421992000000003	57.399298999999999	Спортивная	0103000020E61000000100000005000000BCCCB051D6674B40AA29C93A1CB34C40BCCCB051D6674B403A9677D503B64C4049D74CBED96C4B403A9677D503B64C4049D74CBED96C4B40AA29C93A1CB34C40BCCCB051D6674B40AA29C93A1CB34C40
52044	19324	54.788581999999998	54.826895	57.383412999999997	57.366928999999999	Школьная	0103000020E610000001000000050000006D1B4641F0644B401C7A8B87F7AE4C406D1B4641F0644B403DEE5BAD13B14C40EB1C03B2D7694B403DEE5BAD13B14C40EB1C03B2D7694B401C7A8B87F7AE4C406D1B4641F0644B401C7A8B87F7AE4C40
52171	18552	54.952713000000003	54.988052000000003	57.307918000000001	57.277068999999997	Нагорная	0103000020E61000000100000005000000AEBCE47FF2794B4022DE3AFF76A34C40AEBCE47FF2794B40C4EC65DB69A74C40AB5FE97C787E4B40C4EC65DB69A74C40AB5FE97C787E4B4022DE3AFF76A34C40AEBCE47FF2794B4022DE3AFF76A34C40
51653	18552	54.952713000000003	54.988052000000003	57.307918000000001	57.277068999999997	Ленина	0103000020E61000000100000005000000AEBCE47FF2794B4022DE3AFF76A34C40AEBCE47FF2794B40C4EC65DB69A74C40AB5FE97C787E4B40C4EC65DB69A74C40AB5FE97C787E4B4022DE3AFF76A34C40AEBCE47FF2794B4022DE3AFF76A34C40
52264	18984	54.883173999999997	54.901660999999997	57.218761000000001	57.210115000000002	Центральная	0103000020E61000000100000005000000B8567BD80B714B4014B35E0CE59A4C40B8567BD80B714B40F451465C009C4C40118AADA069734B40F451465C009C4C40118AADA069734B4014B35E0CE59A4C40B8567BD80B714B4014B35E0CE59A4C40
52266	32890	54.906188999999998	54.963231999999998	57.568069000000001	57.543467999999997	Школьная	0103000020E610000001000000050000005A7F4B00FE734B401536035C90C54C405A7F4B00FE734B408B6F287CB6C84C40F73AA92F4B7B4B408B6F287CB6C84C40F73AA92F4B7B4B401536035C90C54C405A7F4B00FE734B401536035C90C54C40
52330	19243	54.443843999999999	54.461342999999999	57.130060999999998	57.119033999999999	Центральная	0103000020E610000001000000050000004E4354E1CF384B40588E90813C8F4C404E4354E1CF384B4016BEBED6A5904C40889E94490D3B4B4016BEBED6A5904C40889E94490D3B4B40588E90813C8F4C404E4354E1CF384B40588E90813C8F4C40
52067	19022	54.713509000000002	54.780639999999998	57.119487999999997	57.073497000000003	Энтузиастов	0103000020E610000001000000050000006A334E43545B4B4054AD855968894C406A334E43545B4B40D921FE614B8F4C4087F9F202EC634B40D921FE614B8F4C4087F9F202EC634B4054AD855968894C406A334E43545B4B4054AD855968894C40
52076	19022	54.713509000000002	54.780639999999998	57.119487999999997	57.073497000000003	 Чапаева	0103000020E610000001000000050000006A334E43545B4B4054AD855968894C406A334E43545B4B40D921FE614B8F4C4087F9F202EC634B40D921FE614B8F4C4087F9F202EC634B4054AD855968894C406A334E43545B4B4054AD855968894C40
52325	32796	54.879328999999998	54.914876	57.28425	57.260686999999997	Октябрьская	0103000020E6100000010000000500000052B648DA8D704B4005BF0D315EA14C4052B648DA8D704B40AAF1D24D62A44C4099F221A81A754B40AAF1D24D62A44C4099F221A81A754B4005BF0D315EA14C4052B648DA8D704B4005BF0D315EA14C40
52265	32808	54.718091000000001	54.736649999999997	57.232247999999998	57.223185999999998	Советская	0103000020E61000000100000005000000A646E867EA5B4B406876DD5B919C4C40A646E867EA5B4B40DC476E4DBA9D4C40984C158C4A5E4B40DC476E4DBA9D4C40984C158C4A5E4B406876DD5B919C4C40A646E867EA5B4B406876DD5B919C4C40
52335	18918	54.914363999999999	54.957985999999998	57.171970999999999	57.160145999999997	Школьная	0103000020E61000000100000005000000E3512AE109754B40E84A04AA7F944C40E3512AE109754B40226E4E2503964C404F0306499F7A4B40226E4E2503964C404F0306499F7A4B40E84A04AA7F944C40E3512AE109754B40E84A04AA7F944C40
54003	19424	54.715682999999999	54.737656000000001	57.468691	57.460524999999997	Механизаторов	0103000020E61000000100000005000000CEA623809B5B4B40C5FEB27BF2BA4C40CEA623809B5B4B40FB761211FEBB4C405ED905836B5E4B40FB761211FEBB4C405ED905836B5E4B40C5FEB27BF2BA4C40CEA623809B5B4B40C5FEB27BF2BA4C40
64588	58286	54.718629999999997	54.748669	57.148400000000002	57.136177000000004	Школьная	0103000020E6100000010000000500000055F65D11FC5B4B40D4BB783F6E914C4055F65D11FC5B4B40FB5C6DC5FE924C40B743C362D45F4B40FB5C6DC5FE924C40B743C362D45F4B40D4BB783F6E914C4055F65D11FC5B4B40D4BB783F6E914C40
52458	32866	54.542569	54.559412000000002	57.142285999999999	57.123069999999998	Уральская	0103000020E610000001000000050000006669A7E672454B40328FFCC1C08F4C406669A7E672454B40DE567A6D36924C40B77EFACF9A474B40DE567A6D36924C40B77EFACF9A474B40328FFCC1C08F4C406669A7E672454B40328FFCC1C08F4C40
51669	56235	54.714390000000002	54.752226999999998	56.748133000000003	56.706488	Ленина	0103000020E61000000100000005000000734BAB21715B4B401B82E3326E5A4C40734BAB21715B4B40790778D2C25F4C4087156EF948604B40790778D2C25F4C4087156EF948604B401B82E3326E5A4C40734BAB21715B4B401B82E3326E5A4C40
52063	18096	54.398820999999998	54.435409	56.728568000000003	56.710811	Звездная	0103000020E61000000100000005000000A0FA07910C334B408B51D7DAFB5A4C40A0FA07910C334B40C1745AB7415D4C4029B16B7BBB374B40C1745AB7415D4C4029B16B7BBB374B408B51D7DAFB5A4C40A0FA07910C334B408B51D7DAFB5A4C40
51652	4995	54.332974	54.388759	56.710416000000002	56.674163999999998	Кирова	0103000020E610000001000000050000008B355CE49E2A4B40FD1186014B564C408B355CE49E2A4B400F4757E9EE5A4C404983DBDAC2314B400F4757E9EE5A4C404983DBDAC2314B40FD1186014B564C408B355CE49E2A4B40FD1186014B564C40
52065	48681	54.373578000000002	54.408244000000003	56.458378000000003	56.431649	Школьная	0103000020E61000000100000005000000A7406667D12F4B40F12C414640374C40A7406667D12F4B405B9A5B21AC3A4C40E564E25641344B405B9A5B21AC3A4C40E564E25641344B40F12C414640374C40A7406667D12F4B40F12C414640374C40
52147	18327	54.553573	54.590421999999997	56.694464000000004	56.668070999999998	 Школьная	0103000020E610000001000000050000006C79E57ADB464B40F833BC5983554C406C79E57ADB464B40EB1F4432E4584C40616BB6F2924B4B40EB1F4432E4584C40616BB6F2924B4B40F833BC5983554C406C79E57ADB464B40F833BC5983554C40
52329	18281	54.519984999999998	54.565852999999997	56.744041000000003	56.728776000000003	Новая	0103000020E610000001000000050000008DB454DE8E424B400B0E2F88485D4C408DB454DE8E424B400BF148BC3C5F4C40F7AB00DF6D484B400BF148BC3C5F4C40F7AB00DF6D484B400B0E2F88485D4C408DB454DE8E424B400B0E2F88485D4C40
52030	17908	53.928587999999998	53.969560999999999	56.674298	56.659537999999998	Комсомольская	0103000020E61000000100000005000000A1BAB9F8DBF64A40103CBEBD6B544C40A1BAB9F8DBF64A400DE198654F564C40103D29931AFC4A400DE198654F564C40103D29931AFC4A40103CBEBD6B544C40A1BAB9F8DBF64A40103CBEBD6B544C40
52149	18442	54.500573000000003	54.533442000000001	56.606028999999999	56.586454000000003	 Зеленая	0103000020E610000001000000050000005C21ACC612404B40E04DB7EC104B4C405C21ACC612404B40BBB6B75B924D4C400B28D4D347444B40BBB6B75B924D4C400B28D4D347444B40E04DB7EC104B4C405C21ACC612404B40E04DB7EC104B4C40
52283	17406	54.433171999999999	54.462017000000003	56.865299	56.846026999999999	Мира	0103000020E610000001000000050000007EC51A2E72374B403944DC9C4A6C4C407EC51A2E72374B4079211D1EC26E4C401899805F233B4B4079211D1EC26E4C401899805F233B4B403944DC9C4A6C4C407EC51A2E72374B403944DC9C4A6C4C40
53626	56434	54.273747999999998	54.292703000000003	56.531188999999998	56.518349000000001	Пролетарская	0103000020E6100000010000000500000036ACA92C0A234B400875914259424C4036ACA92C0A234B405A7F4B00FE434C407638BA4A77254B405A7F4B00FE434C407638BA4A77254B400875914259424C4036ACA92C0A234B400875914259424C40
52262	56330	54.285229000000001	54.300283999999998	56.720044000000001	56.704926999999998	Октябрьская	0103000020E61000000100000005000000766F456282244B40A088450C3B5A4C40766F456282244B402CD7DB662A5C4C408BC1C3B46F264B402CD7DB662A5C4C408BC1C3B46F264B40A088450C3B5A4C40766F456282244B40A088450C3B5A4C40
52023	17422	54.543008999999998	54.592551	56.897919999999999	56.881394	Советская	0103000020E610000001000000050000008237A45181454B400072C284D1704C408237A45181454B405036E50AEF724C40261B0FB6D84B4B405036E50AEF724C40261B0FB6D84B4B400072C284D1704C408237A45181454B400072C284D1704C40
52025	56262	54.354210000000002	54.383091	56.854931000000001	56.830911	Молодежная	0103000020E6100000010000000500000045F5D6C0562D4B407E71A94A5B6A4C4045F5D6C0562D4B4015AB06616E6D4C402B323A2009314B4015AB06616E6D4C402B323A2009314B407E71A94A5B6A4C4045F5D6C0562D4B407E71A94A5B6A4C40
52215	56262	54.354210000000002	54.383091	56.854931000000001	56.830911	Зеленая	0103000020E6100000010000000500000045F5D6C0562D4B407E71A94A5B6A4C4045F5D6C0562D4B4015AB06616E6D4C402B323A2009314B4015AB06616E6D4C402B323A2009314B407E71A94A5B6A4C4045F5D6C0562D4B407E71A94A5B6A4C40
52148	18370	54.539603999999997	54.555855000000001	56.552697000000002	56.541204999999998	Гаражная	0103000020E6100000010000000500000038656EBE11454B4041B7973446454C4038656EBE11454B4075CC79C6BE464C40B728B34126474B4075CC79C6BE464C40B728B34126474B4041B7973446454C4038656EBE11454B4041B7973446454C40
51720	17916	54.245289	54.271377000000001	56.675559	56.650101999999997	Победы	0103000020E61000000100000005000000C68844A1651F4B403788D68A36534C40C68844A1651F4B405DC2A1B778564C407CF1457BBC224B405DC2A1B778564C407CF1457BBC224B403788D68A36534C40C68844A1651F4B403788D68A36534C40
52326	32528	55.815778000000002	55.844155999999998	59.614227	59.600591999999999	Пионерская	0103000020E61000000100000005000000ED65DB696BE84B409F1EDB32E0CC4D40ED65DB696BE84B40FCA886FD9ECE4D40705CC64D0DEC4B40FCA886FD9ECE4D40705CC64D0DEC4B409F1EDB32E0CC4D40ED65DB696BE84B409F1EDB32E0CC4D40
52260	16003	56.052070999999998	56.081653000000003	59.375824999999999	59.363532999999997	Школьная	0103000020E61000000100000005000000F6083543AA064C402502D53F88AE4D40F6083543AA064C4075029A081BB04D40664F029B730A4C4075029A081BB04D40664F029B730A4C402502D53F88AE4D40F6083543AA064C402502D53F88AE4D40
52322	12489	56.464694000000001	56.478788999999999	59.406781000000002	59.392420000000001	Центральная	0103000020E61000000100000005000000DF52CE177B3B4C40EE258DD13AB24D40DF52CE177B3B4C402DD1596611B44D409F573CF5483D4C402DD1596611B44D409F573CF5483D4C40EE258DD13AB24D40DF52CE177B3B4C40EE258DD13AB24D40
52058	15846	56.567658999999999	56.606844000000002	59.490775999999997	59.466628	Игумнова	0103000020E61000000100000005000000D923D40CA9484C40EEB25F77BABB4D40D923D40CA9484C40B2D47ABFD1BE4D400DE36E10AD4D4C40B2D47ABFD1BE4D400DE36E10AD4D4C40EEB25F77BABB4D40D923D40CA9484C40EEB25F77BABB4D40
52327	56352	56.340960000000003	56.356150999999997	59.513876000000003	59.507055000000001	Школьная	0103000020E61000000100000005000000419FC893A42B4C40FB22A12DE7C04D40419FC893A42B4C40831953B0C6C14D4006B8205B962D4C40831953B0C6C14D4006B8205B962D4C40FB22A12DE7C04D40419FC893A42B4C40FB22A12DE7C04D40
52173	32648	56.554372999999998	56.613446000000003	59.350026	59.334411000000003	Советская	0103000020E610000001000000050000008864C8B1F5464C401A36CAFACDAA4D408864C8B1F5464C40F65FE7A6CDAC4D4057EE0566854E4C40F65FE7A6CDAC4D4057EE0566854E4C401A36CAFACDAA4D408864C8B1F5464C401A36CAFACDAA4D40
52006	32648	56.554372999999998	56.613446000000003	59.350026	59.334411000000003	1 мая	0103000020E610000001000000050000008864C8B1F5464C401A36CAFACDAA4D408864C8B1F5464C40F65FE7A6CDAC4D4057EE0566854E4C40F65FE7A6CDAC4D4057EE0566854E4C401A36CAFACDAA4D408864C8B1F5464C401A36CAFACDAA4D40
53974	33047	56.754840999999999	56.788429000000001	59.137	59.114271000000002	Южный	0103000020E61000000100000005000000085740A19E604C40CCF09F6EA08E4D40085740A19E604C40A8C64B3789914D40E71BD13DEB644C40A8C64B3789914D40E71BD13DEB644C40CCF09F6EA08E4D40085740A19E604C40CCF09F6EA08E4D40
64606	58298	56.043339000000003	56.068663000000001	59.454172	59.444781999999996	 Центральная	0103000020E6100000010000000500000018D2E1218C054C40BBECD79DEEB84D4018D2E1218C054C402461DF4E22BA4D40FEB8FDF2C9084C402461DF4E22BA4D40FEB8FDF2C9084C40BBECD79DEEB84D4018D2E1218C054C40BBECD79DEEB84D40
53572	14781	56.548237	56.558101000000001	56.953865	56.945608	Заречная	0103000020E6100000010000000500000084BA48A12C464C40016BD5AE09794C4084BA48A12C464C4047E6913F187A4C40B56E83DA6F474C4047E6913F187A4C40B56E83DA6F474C40016BD5AE09794C4084BA48A12C464C40016BD5AE09794C40
52057	14647	56.713689000000002	56.742651000000002	56.916969000000002	56.899954999999999	Советская	0103000020E61000000100000005000000EA4141295A5B4C40936FB6B931734C40EA4141295A5B4C4011397D3D5F754C40BDAB1E300F5F4C4011397D3D5F754C40BDAB1E300F5F4C40936FB6B931734C40EA4141295A5B4C40936FB6B931734C40
64628	58305	56.748246999999999	56.773400000000002	56.867739	56.852780000000003	Центральная	0103000020E61000000100000005000000412AC58EC65F4C40695721E5276D4C40412AC58EC65F4C405C3B5112126F4C40FB5C6DC5FE624C405C3B5112126F4C40FB5C6DC5FE624C40695721E5276D4C40412AC58EC65F4C40695721E5276D4C40
52257	14616	56.689748999999999	56.713104999999999	56.986902999999998	56.973464	Центральная	0103000020E610000001000000050000006FB9FAB149584C40ABEAE5779A7C4C406FB9FAB149584C4082A966D6527E4C409ACE4E06475B4C4082A966D6527E4C409ACE4E06475B4C40ABEAE5779A7C4C406FB9FAB149584C40ABEAE5779A7C4C40
51716	14171	56.538805000000004	56.612799000000003	56.890118000000001	56.865687999999999	Свободы	0103000020E61000000100000005000000EDF5EE8FF7444C40134548DDCE6E4C40EDF5EE8FF7444C405CCAF962EF714C40C1029832704E4C405CCAF962EF714C40C1029832704E4C40134548DDCE6E4C40EDF5EE8FF7444C40134548DDCE6E4C40
54030	14171	56.538805000000004	56.612799000000003	56.890118000000001	56.865687999999999	Ольховая	0103000020E61000000100000005000000EDF5EE8FF7444C40134548DDCE6E4C40EDF5EE8FF7444C405CCAF962EF714C40C1029832704E4C405CCAF962EF714C40C1029832704E4C40134548DDCE6E4C40EDF5EE8FF7444C40134548DDCE6E4C40
52321	14171	56.538805000000004	56.612799000000003	56.890118000000001	56.865687999999999	8 Марта	0103000020E61000000100000005000000EDF5EE8FF7444C40134548DDCE6E4C40EDF5EE8FF7444C405CCAF962EF714C40C1029832704E4C405CCAF962EF714C40C1029832704E4C40134548DDCE6E4C40EDF5EE8FF7444C40134548DDCE6E4C40
51712	14171	56.538805000000004	56.612799000000003	56.890118000000001	56.865687999999999	30 лет Победы	0103000020E61000000100000005000000EDF5EE8FF7444C40134548DDCE6E4C40EDF5EE8FF7444C405CCAF962EF714C40C1029832704E4C405CCAF962EF714C40C1029832704E4C40134548DDCE6E4C40EDF5EE8FF7444C40134548DDCE6E4C40
51646	14571	56.790638999999999	56.830030000000001	56.969289000000003	56.948244000000003	Центральная	0103000020E6100000010000000500000098F8A3A833654C406A50340F60794C4098F8A3A833654C40B0AF75A9117C4C4075594C6C3E6A4C40B0AF75A9117C4C4075594C6C3E6A4C406A50340F60794C4098F8A3A833654C406A50340F60794C40
53560	14767	56.468789999999998	56.488086000000003	56.983671000000001	56.973792000000003	Новая	0103000020E610000001000000050000008E588B4F013C4C40A08D5C37A57C4C408E588B4F013C4C4006836BEEE87D4C4057D11F9A793E4C4006836BEEE87D4C4057D11F9A793E4C40A08D5C37A57C4C408E588B4F013C4C40A08D5C37A57C4C40
54234	56508	56.111215999999999	56.136440999999998	56.795972999999996	56.782677	Центральная	0103000020E610000001000000050000005E656D533C0E4C406B2A8BC22E644C405E656D533C0E4C40DFBF7971E2654C40B16A10E676114C40DFBF7971E2654C40B16A10E676114C406B2A8BC22E644C405E656D533C0E4C406B2A8BC22E644C40
66176	58722	56.698596999999999	56.719240999999997	56.845917999999998	56.838036000000002	улица Заречная	0103000020E61000000100000005000000B70A62A06B594C40726F7EC3446B4C40B70A62A06B594C40828C800A476C4C409E78CE16105C4C40828C800A476C4C409E78CE16105C4C40726F7EC3446B4C40B70A62A06B594C40726F7EC3446B4C40
53542	14702	56.557130999999998	56.592354	56.981507999999998	56.960867999999998	Ленина	0103000020E610000001000000050000003C4B901150474C40EFE2FDB8FD7A4C403C4B901150474C409561DC0DA27D4C40D0D38041D24B4C409561DC0DA27D4C40D0D38041D24B4C40EFE2FDB8FD7A4C403C4B901150474C40EFE2FDB8FD7A4C40
53622	15269	56.094965999999999	56.147615999999999	56.877740000000003	56.868285	Центральная	0103000020E61000000100000005000000B01D8CD8270C4C40BE4D7FF6236F4C40B01D8CD8270C4C400E32C9C859704C40E42EC214E5124C400E32C9C859704C40E42EC214E5124C40BE4D7FF6236F4C40B01D8CD8270C4C40BE4D7FF6236F4C40
52258	15117	56.200985000000003	56.227646999999997	56.986364000000002	56.977040000000002	Школьная	0103000020E6100000010000000500000048FE60E0B9194C4022718FA50F7D4C4048FE60E0B9194C40D3F9F02C417E4C4029047289231D4C40D3F9F02C417E4C4029047289231D4C4022718FA50F7D4C4048FE60E0B9194C4022718FA50F7D4C40
52259	15220	56.146152000000001	56.182695000000002	56.940280000000001	56.932757000000002	Центральная	0103000020E610000001000000050000005C1FD61BB5124C40BB0ED59464774C405C1FD61BB5124C409C8A54185B784C404512BD8C62174C409C8A54185B784C404512BD8C62174C40BB0ED59464774C405C1FD61BB5124C40BB0ED59464774C40
53613	15002	56.162474000000003	56.191211000000003	56.821098999999997	56.805087	Центральная	0103000020E61000000100000005000000A439B2F2CB144C40A6B73F170D674C40A439B2F2CB144C409FE3A3C519694C4057D11F9A79184C409FE3A3C519694C4057D11F9A79184C40A6B73F170D674C40A439B2F2CB144C40A6B73F170D674C40
52427	14857	56.536236000000002	56.560805000000002	56.798718999999998	56.777000000000001	Юбилейная	0103000020E610000001000000050000000C789961A3444C40FA7E6ABC74634C400C789961A3444C40CFD8976C3C664C4076374F75C8474C40CFD8976C3C664C4076374F75C8474C40FA7E6ABC74634C400C789961A3444C40FA7E6ABC74634C40
63413	14378	56.937226000000003	56.976787999999999	56.833081999999997	56.818975999999999	переулок Восточный	0103000020E61000000100000005000000FF7A8505F7774C40BD1AA034D4684C40FF7A8505F7774C407171546EA26A4C400890A163077D4C407171546EA26A4C400890A163077D4C40BD1AA034D4684C40FF7A8505F7774C40BD1AA034D4684C40
52238	14421	56.869205999999998	56.908102999999997	56.856637999999997	56.836967999999999	Верхняя	0103000020E6100000010000000500000055BE6724426F4C4036E675C4216B4C4055BE6724426F4C4063416150A66D4C40223317B83C744C4063416150A66D4C40223317B83C744C4036E675C4216B4C4055BE6724426F4C4036E675C4216B4C40
54048	15356	56.334285999999999	56.360202000000001	56.982112000000001	56.968445000000003	Центральная	0103000020E610000001000000050000005DC136E2C92A4C40C47C7901F67B4C405DC136E2C92A4C402C8194D8B57D4C4016FA60191B2E4C402C8194D8B57D4C4016FA60191B2E4C40C47C7901F67B4C405DC136E2C92A4C40C47C7901F67B4C40
53579	14941	56.317433000000001	56.332614999999997	56.924967000000002	56.900373000000002	Центральная	0103000020E61000000100000005000000E9D500A5A1284C40C899266C3F734C40E9D500A5A1284C408B70935165764C405B94D920932A4C408B70935165764C405B94D920932A4C40C899266C3F734C40E9D500A5A1284C40C899266C3F734C40
54042	14460	56.846387999999997	56.870291999999999	56.884517000000002	56.873539000000001	Юбилейная	0103000020E6100000010000000500000009DD2571566C4C40E9633E20D06F4C4009DD2571566C4C40C6E061DA37714C4037FC6EBA656F4C40C6E061DA37714C4037FC6EBA656F4C40E9633E20D06F4C4009DD2571566C4C40E9633E20D06F4C40
52158	14906	56.290222999999997	56.350842	56.866985999999997	56.850766999999998	Школьная	0103000020E6100000010000000500000004C6FA0626254C400DC2DCEEE56C4C4004C6FA0626254C40800BB265F96E4C4018080264E82C4C40800BB265F96E4C4018080264E82C4C400DC2DCEEE56C4C4004C6FA0626254C400DC2DCEEE56C4C40
53517	13622	57.391854000000002	57.437021999999999	57.068441999999997	57.048673000000001	Центральная	0103000020E610000001000000050000004567994528B24C405F99B7EA3A864C404567994528B24C401FD61BB5C2884C40F6D03E56F0B74C401FD61BB5C2884C40F6D03E56F0B74C405F99B7EA3A864C404567994528B24C405F99B7EA3A864C40
53146	14144	57.503281000000001	57.551054000000001	57.040970999999999	57.030743999999999	Трактовая	0103000020E610000001000000050000005ED905836BC04C402C465D6BEF834C405ED905836BC04C40CE8AA8893E854C403D2AFEEF88C64C40CE8AA8893E854C403D2AFEEF88C64C402C465D6BEF834C405ED905836BC04C402C465D6BEF834C40
54022	14095	57.583599999999997	57.632629999999999	57.015085999999997	57.003582999999999	Северная	0103000020E6100000010000000500000009F9A067B3CA4C4029E9616875804C4009F9A067B3CA4C4050508A56EE814C40F73B1405FAD04C4050508A56EE814C40F73B1405FAD04C4029E9616875804C4009F9A067B3CA4C4029E9616875804C40
64383	14012	57.551924999999997	57.570681999999998	56.974331999999997	56.955120999999998	Колхозная	0103000020E61000000100000005000000226C787AA5C64C40855CA967417A4C40226C787AA5C64C401FB935E9B67C4C403B35971B0CC94C401FB935E9B67C4C403B35971B0CC94C40855CA967417A4C40226C787AA5C64C40855CA967417A4C40
52056	13918	57.768653	57.794694999999997	57.115017000000002	57.097776000000003	Молодёжная	0103000020E61000000100000005000000747CB43863E24C40B72A89EC838C4C40747CB43863E24C40F5BD86E0B88E4C40B9A5D590B8E54C40F5BD86E0B88E4C40B9A5D590B8E54C40B72A89EC838C4C40747CB43863E24C40B72A89EC838C4C40
51763	13141	57.369180999999998	57.436213000000002	57.163581999999998	57.129660000000001	Школьная	0103000020E61000000100000005000000FCA6B05241AF4C40B8CCE9B298904C40FCA6B05241AF4C406D1B4641F0944C40878BDCD3D5B74C406D1B4641F0944C40878BDCD3D5B74C40B8CCE9B298904C40FCA6B05241AF4C40B8CCE9B298904C40
51643	13141	57.369180999999998	57.436213000000002	57.163581999999998	57.129660000000001	Кирова	0103000020E61000000100000005000000FCA6B05241AF4C40B8CCE9B298904C40FCA6B05241AF4C406D1B4641F0944C40878BDCD3D5B74C406D1B4641F0944C40878BDCD3D5B74C40B8CCE9B298904C40FCA6B05241AF4C40B8CCE9B298904C40
51644	13141	57.369180999999998	57.436213000000002	57.163581999999998	57.129660000000001	Карла Маркса	0103000020E61000000100000005000000FCA6B05241AF4C40B8CCE9B298904C40FCA6B05241AF4C406D1B4641F0944C40878BDCD3D5B74C406D1B4641F0944C40878BDCD3D5B74C40B8CCE9B298904C40FCA6B05241AF4C40B8CCE9B298904C40
51510	13141	57.369180999999998	57.436213000000002	57.163581999999998	57.129660000000001	Большевистская	0103000020E61000000100000005000000FCA6B05241AF4C40B8CCE9B298904C40FCA6B05241AF4C406D1B4641F0944C40878BDCD3D5B74C406D1B4641F0944C40878BDCD3D5B74C40B8CCE9B298904C40FCA6B05241AF4C40B8CCE9B298904C40
54017	13426	57.298924	57.348933000000002	57.185051000000001	57.163006000000003	Советинская	0103000020E61000000100000005000000A8FE412443A64C40A1866F61DD944C40A8FE412443A64C40CA8B4CC0AF974C4062BF27D6A9AC4C40CA8B4CC0AF974C4062BF27D6A9AC4C40A1866F61DD944C40A8FE412443A64C40A1866F61DD944C40
52054	13358	57.201061000000003	57.229888000000003	57.184874999999998	57.168526	Победы	0103000020E6100000010000000500000023C0E95DBC994C404A438D4292954C4023C0E95DBC994C408B6CE7FBA9974C4016DF50F86C9D4C408B6CE7FBA9974C4016DF50F86C9D4C404A438D4292954C4023C0E95DBC994C404A438D4292954C40
52146	13909	57.521453999999999	57.541262000000003	57.128258000000002	57.116404000000003	Сосновая	0103000020E61000000100000005000000272F3201BFC24C40D28F8653E68E4C40272F3201BFC24C40A6B915C26A904C40A648BE1248C54C40A6B915C26A904C40A648BE1248C54C40D28F8653E68E4C40272F3201BFC24C40D28F8653E68E4C40
52236	13836	57.502319999999997	57.524805000000001	57.192377	57.181596999999996	Колхозная	0103000020E61000000100000005000000381092054CC04C409E060C923E974C40381092054CC04C4055C03DCF9F984C407EE36BCF2CC34C4055C03DCF9F984C407EE36BCF2CC34C409E060C923E974C40381092054CC04C409E060C923E974C40
52034	56264	57.423366999999999	57.447685	56.983671000000001	56.969661000000002	Пионерская	0103000020E61000000100000005000000529ACDE330B64C40749A05DA1D7C4C40529ACDE330B64C4006836BEEE87D4C4073F4F8BD4DB94C4006836BEEE87D4C4073F4F8BD4DB94C40749A05DA1D7C4C40529ACDE330B64C40749A05DA1D7C4C40
52234	13758	57.475523000000003	57.498682000000002	57.199739999999998	57.189323999999999	Трактовая	0103000020E6100000010000000500000077BF0AF0DDBC4C40882CD2C43B984C4077BF0AF0DDBC4C40FDD98F1491994C404C8DD0CFD4BF4C40FDD98F1491994C404C8DD0CFD4BF4C40882CD2C43B984C4077BF0AF0DDBC4C40882CD2C43B984C40
52151	32747	57.421346	57.446364000000003	57.001092999999997	56.984392	Школьная	0103000020E6100000010000000500000074266DAAEEB54C40D6389B8E007E4C4074266DAAEEB54C4094A0BFD023804C404E0E9F7422B94C4094A0BFD023804C404E0E9F7422B94C40D6389B8E007E4C4074266DAAEEB54C40D6389B8E007E4C40
52005	32839	57.747722000000003	57.764888999999997	57.055790999999999	57.036754000000002	Центральная	0103000020E61000000100000005000000F73FC05AB5DF4C40A4FFE55AB4844C40F73FC05AB5DF4C40A034D42824874C40FA08FCE1E7E14C40A034D42824874C40FA08FCE1E7E14C40A4FFE55AB4844C40F73FC05AB5DF4C40A4FFE55AB4844C40
52100	48401	56.925763000000003	56.959567	59.686669999999999	59.672069999999998	Мира	0103000020E61000000100000005000000666CE8667F764C40B54FC76306D64D40666CE8667F764C40799274CDE4D74D4011A96917D37A4C40799274CDE4D74D4011A96917D37A4C40B54FC76306D64D40666CE8667F764C40B54FC76306D64D40
52288	28692	56.826841000000002	56.853017999999999	59.537393000000002	59.525551999999998	Центральная	0103000020E61000000100000005000000F8FE06EDD5694C40772CB64945C34D40F8FE06EDD5694C40B70C384BC9C44D401D739EB12F6D4C40B70C384BC9C44D401D739EB12F6D4C40772CB64945C34D40F8FE06EDD5694C40772CB64945C34D40
51775	28047	56.513086000000001	56.539757000000002	59.845713000000003	59.833686999999998	Лесная	0103000020E610000001000000050000008A0453CDAC414C40D80C7041B6EA4D408A0453CDAC414C40AA66D65240EC4D40BF64E3C116454C40AA66D65240EC4D40BF64E3C116454C40D80C7041B6EA4D408A0453CDAC414C40D80C7041B6EA4D40
51776	28250	56.718181000000001	56.738796999999998	59.729019000000001	59.719501000000001	Дружбы	0103000020E61000000100000005000000E6CDE15AED5B4C403B38D89B18DC4D40E6CDE15AED5B4C40D1949D7E50DD4D4003B16CE6905E4C40D1949D7E50DD4D4003B16CE6905E4C403B38D89B18DC4D40E6CDE15AED5B4C403B38D89B18DC4D40
52024	56261	56.546117000000002	56.551443999999996	59.732433999999998	59.730184999999999	Ленина	0103000020E6100000010000000500000013656F29E7454C40CF83BBB376DD4D4013656F29E7454C403E3DB665C0DD4D40A7C98CB795464C403E3DB665C0DD4D40A7C98CB795464C40CF83BBB376DD4D4013656F29E7454C40CF83BBB376DD4D40
53688	48511	57.327480999999999	57.521751000000002	59.879587999999998	59.858759999999997	Молодежная	0103000020E61000000100000005000000DB87BCE5EAA94C40758E01D9EBED4D40DB87BCE5EAA94C401EFAEE5696F04D40E1D39CBCC8C24C401EFAEE5696F04D40E1D39CBCC8C24C40758E01D9EBED4D40DB87BCE5EAA94C40758E01D9EBED4D40
51526	28391	57.058382000000002	57.091287000000001	59.662143999999998	59.645032	Школьная	0103000020E610000001000000050000006956B60F79874C40CE6F986890D24D406956B60F79874C400E9F7422C1D44D4065C6DB4AAF8B4C400E9F7422C1D44D4065C6DB4AAF8B4C40CE6F986890D24D406956B60F79874C40CE6F986890D24D40
53962	48422	57.044494	57.067428	59.811042999999998	59.794569000000003	Центральная	0103000020E61000000100000005000000226FB9FAB1854C402DB5DE6FB4E54D40226FB9FAB1854C402A53CC41D0E74D40D76A0F7BA1884C402A53CC41D0E74D40D76A0F7BA1884C402DB5DE6FB4E54D40226FB9FAB1854C402DB5DE6FB4E54D40
54115	28132	56.593243000000001	56.614955000000002	59.810319	59.790027000000002	Спортивная	0103000020E610000001000000050000005CCAF962EF4B4C407FFACF9A1FE54D405CCAF962EF4B4C40E9297288B8E74D407FC16ED8B64E4C40E9297288B8E74D407FC16ED8B64E4C407FFACF9A1FE54D405CCAF962EF4B4C407FFACF9A1FE54D40
52116	47912	57.674545000000002	57.706479999999999	60.009453000000001	59.997824000000001	Гагарина	0103000020E610000001000000050000001557957D57D64C40FB9463B2B8FF4D401557957D57D64C40AFEC82C135014E4098A3C7EF6DDA4C40AFEC82C135014E4098A3C7EF6DDA4C40FB9463B2B8FF4D401557957D57D64C40FB9463B2B8FF4D40
52871	28184	56.331913999999998	56.368529000000002	59.697519	59.681350999999999	Набережная	0103000020E61000000100000005000000D28A6F287C2A4C40670C738236D74D40D28A6F287C2A4C4058AB764D48D94D40555051F52B2F4C4058AB764D48D94D40555051F52B2F4C40670C738236D74D40D28A6F287C2A4C40670C738236D74D40
52229	56316	56.571916999999999	56.584753999999997	59.831150000000001	59.824154	Советская	0103000020E610000001000000050000006283859334494C400D6FD6E07DE94D406283859334494C4003098A1F63EA4D40431A1538D94A4C4003098A1F63EA4D40431A1538D94A4C400D6FD6E07DE94D406283859334494C400D6FD6E07DE94D40
64452	28368	56.669339000000001	56.699945	59.953637000000001	59.939487	Культуры	0103000020E61000000100000005000000FB777DE6AC554C4032022A1C41F84D40FB777DE6AC554C40B6A0F7C610FA4D40D6FF39CC97594C40B6A0F7C610FA4D40D6FF39CC97594C4032022A1C41F84D40FB777DE6AC554C4032022A1C41F84D40
52110	28008	55.685198999999997	55.706139	59.766370999999999	59.754719000000001	Пионерская	0103000020E610000001000000050000003E20D099B4D74B40BD55D7A19AE04D403E20D099B4D74B4029CDE67118E24D400FB743C362DA4B4029CDE67118E24D400FB743C362DA4B40BD55D7A19AE04D403E20D099B4D74B40BD55D7A19AE04D40
52239	56322	54.019219	54.029128	58.520417999999999	58.514491	Школьная	0103000020E610000001000000050000001D3BA8C475024B400D8B51D7DA414D401D3BA8C475024B40F71F990E9D424D40EEB25F77BA034B40F71F990E9D424D40EEB25F77BA034B400D8B51D7DA414D401D3BA8C475024B400D8B51D7DA414D40
52052	11704	54.155144	54.173271999999997	58.406159000000002	58.396464000000002	Ленина	0103000020E61000000100000005000000D71533C2DB134B404B051555BF324D40D71533C2DB134B40F0FCA204FD334D4000A8E2C62D164B40F0FCA204FD334D4000A8E2C62D164B404B051555BF324D40D71533C2DB134B404B051555BF324D40
54288	56523	54.557211000000002	54.569949999999999	58.323295000000002	58.313699999999997	Красногвардейская	0103000020E6100000010000000500000059FCA6B052474B40AA60545227284D4059FCA6B052474B40ECFA05BB61294D40772D211FF4484B40ECFA05BB61294D40772D211FF4484B40AA60545227284D4059FCA6B052474B40AA60545227284D40
51637	11601	54.341939000000004	54.402549	58.397817000000003	58.358911999999997	Советская	0103000020E610000001000000050000000D1D3BA8C42B4B402B1213D4F02D4D400D1D3BA8C42B4B407C65DEAAEB324D40CD04C3B986334B407C65DEAAEB324D40CD04C3B986334B402B1213D4F02D4D400D1D3BA8C42B4B402B1213D4F02D4D40
51504	11601	54.341939000000004	54.402549	58.397817000000003	58.358911999999997	Ленина	0103000020E610000001000000050000000D1D3BA8C42B4B402B1213D4F02D4D400D1D3BA8C42B4B407C65DEAAEB324D40CD04C3B986334B407C65DEAAEB324D40CD04C3B986334B402B1213D4F02D4D400D1D3BA8C42B4B402B1213D4F02D4D40
54008	33065	54.258611000000002	54.283639000000001	58.516865000000003	58.507778999999999	Школьная	0103000020E6100000010000000500000064B14D2A1A214B403C4CFBE6FE404D4064B14D2A1A214B4039B9DFA128424D40616F62484E244B4039B9DFA128424D40616F62484E244B403C4CFBE6FE404D4064B14D2A1A214B403C4CFBE6FE404D40
53511	11248	53.956094999999998	53.974079000000003	58.357269000000002	58.346657999999998	Ленина	0103000020E610000001000000050000003F6F2A5261FA4A40C972124A5F2C4D403F6F2A5261FA4A40F46F97FDBA2D4D40365CE49EAEFC4A40F46F97FDBA2D4D40365CE49EAEFC4A40C972124A5F2C4D403F6F2A5261FA4A40C972124A5F2C4D40
51636	11168	53.988622999999997	54.041947	58.388793999999997	58.369509999999998	Советская	0103000020E610000001000000050000006589CE328BFE4A40C1C58A1A4C2F4D406589CE328BFE4A40C5707500C4314D402995F0845E054B40C5707500C4314D402995F0845E054B40C1C58A1A4C2F4D406589CE328BFE4A40C1C58A1A4C2F4D40
53134	11168	53.988622999999997	54.041947	58.388793999999997	58.369509999999998	Ленина	0103000020E610000001000000050000006589CE328BFE4A40C1C58A1A4C2F4D406589CE328BFE4A40C5707500C4314D402995F0845E054B40C5707500C4314D402995F0845E054B40C1C58A1A4C2F4D406589CE328BFE4A40C1C58A1A4C2F4D40
52231	10950	53.894264	53.906840000000003	58.549337000000001	58.543739000000002	Школьная	0103000020E61000000100000005000000BDFE243E77F24A40A647533D99454D40BDFE243E77F24A40CBBDC0AC50464D40325A475513F44A40CBBDC0AC50464D40325A475513F44A40A647533D99454D40BDFE243E77F24A40A647533D99454D40
52157	11428	54.384141999999997	54.417245000000001	58.358468000000002	58.341821000000003	Техническая	0103000020E610000001000000050000009082A7902B314B40030B60CAC02B4D409082A7902B314B40CE548847E22D4D40B3B5BE4868354B40CE548847E22D4D40B3B5BE4868354B40030B60CAC02B4D409082A7902B314B40030B60CAC02B4D40
64375	58217	54.512520000000002	54.531286000000001	58.317264000000002	58.310552000000001	Мира	0103000020E61000000100000005000000E1455F419A414B408CDAFD2AC0274D40E1455F419A414B405D19541B9C284D404D69FD2D01444B405D19541B9C284D404D69FD2D01444B408CDAFD2AC0274D40E1455F419A414B408CDAFD2AC0274D40
64546	58264	54.519123	54.528753000000002	58.575837999999997	58.572510999999999	Спорта	0103000020E61000000100000005000000FBCC599F72424B40D5CC5A0A48494D40FBCC599F72424B40A3E5400FB5494D40B954A52DAE434B40A3E5400FB5494D40B954A52DAE434B40D5CC5A0A48494D40FBCC599F72424B40D5CC5A0A48494D40
64568	58277	54.392091999999998	54.406618000000002	58.323669000000002	58.317197999999998	Безымяная	0103000020E61000000100000005000000F982161230324B40A52DAEF199284D40F982161230324B4051DD5CFC6D294D4083FB010F0C344B4051DD5CFC6D294D4083FB010F0C344B40A52DAEF199284D40F982161230324B40A52DAEF199284D40
52144	11361	54.532463	54.561253999999998	58.496381	58.474915000000003	Ленина	0103000020E610000001000000050000003FAA61BF27444B409FB0C403CA3C4D403FAA61BF27444B408AADA069893F4D40E55FCB2BD7474B408AADA069893F4D40E55FCB2BD7474B409FB0C403CA3C4D403FAA61BF27444B409FB0C403CA3C4D40
64379	46331	54.525914	54.536864999999999	58.431925999999997	58.428482000000002	Попова	0103000020E610000001000000050000001841632651434B405C76887FD8364D401841632651434B406325E65949374D40FBAE08FEB7444B406325E65949374D40FBAE08FEB7444B405C76887FD8364D401841632651434B405C76887FD8364D40
52154	56292	54.052745000000002	54.094813000000002	58.479249000000003	58.469192999999997	Ленина	0103000020E6100000010000000500000086032159C0064B408D4127840E3C4D4086032159C0064B4003D2FE07583D4D402A1E17D5220C4B4003D2FE07583D4D402A1E17D5220C4B408D4127840E3C4D4086032159C0064B408D4127840E3C4D40
64525	58254	54.462609999999998	54.485328000000003	58.423293000000001	58.412519000000003	Центральная 	0103000020E61000000100000005000000BA66F2CD363B4B4044FD2E6CCD344D40BA66F2CD363B4B4018D00B772E364D40A3EA573A1F3E4B4018D00B772E364D40A3EA573A1F3E4B4044FD2E6CCD344D40BA66F2CD363B4B4044FD2E6CCD344D40
51634	10734	54.360470999999997	54.397948999999997	58.301009999999998	58.288116000000002	Бубинская	0103000020E610000001000000050000000514EAE9232E4B4028BA2EFCE0244D400514EAE9232E4B406DE2E47E87264D40EA3C2AFEEF324B406DE2E47E87264D40EA3C2AFEEF324B4028BA2EFCE0244D400514EAE9232E4B4028BA2EFCE0244D40
54015	10754	54.426929000000001	54.456932999999999	58.299747000000004	58.296531000000002	Трудовая	0103000020E61000000100000005000000645B069CA5364B4006A051BAF4254D40645B069CA5364B407D09151C5E264D4049BBD1C77C3A4B407D09151C5E264D4049BBD1C77C3A4B4006A051BAF4254D40645B069CA5364B4006A051BAF4254D40
52017	10663	54.241103000000003	54.258926000000002	58.290018000000003	58.277876999999997	Самыловская	0103000020E61000000100000005000000D7FB8D76DC1E4B40C1A7397991234D40D7FB8D76DC1E4B402CA0504F1F254D40C40AB77C24214B402CA0504F1F254D40C40AB77C24214B40C1A7397991234D40D7FB8D76DC1E4B40C1A7397991234D40
63914	45904	54.292873	54.319436000000003	58.211976999999997	58.199620000000003	Центральная	0103000020E61000000100000005000000D270CADC7C254B4053D0ED258D194D40D270CADC7C254B408940F50F221B4D4021956247E3284B408940F50F221B4D4021956247E3284B4053D0ED258D194D40D270CADC7C254B4053D0ED258D194D40
52094	56279	54.267271000000001	54.287509999999997	58.508150000000001	58.498088000000003	Парковая	0103000020E61000000100000005000000A915A6EF35224B40D943FB58C13F4D40A915A6EF35224B4030BB270F0B414D40F0A2AF20CD244B4030BB270F0B414D40F0A2AF20CD244B40D943FB58C13F4D40A915A6EF35224B40D943FB58C13F4D40
52437	26928	56.408783	56.446333000000003	57.694113999999999	57.674363	Сибирский тракт	0103000020E610000001000000050000009414580053344C40F450DB8651D64C409414580053344C400ED940BAD8D84C401310937021394C400ED940BAD8D84C401310937021394C40F450DB8651D64C409414580053344C40F450DB8651D64C40
51498	6309	55.549562000000002	55.623672999999997	57.719743000000001	57.676831999999997	Советская	0103000020E61000000100000005000000EB8F300C58C64B407171546EA2D64C40EB8F300C58C64B403143E38920DC4C40F8325184D4CF4B403143E38920DC4C40F8325184D4CF4B407171546EA2D64C40EB8F300C58C64B407171546EA2D64C40
51747	6309	55.549562000000002	55.623672999999997	57.719743000000001	57.676831999999997	Мира	0103000020E61000000100000005000000EB8F300C58C64B407171546EA2D64C40EB8F300C58C64B403143E38920DC4C40F8325184D4CF4B403143E38920DC4C40F8325184D4CF4B407171546EA2D64C40EB8F300C58C64B407171546EA2D64C40
51746	6309	55.549562000000002	55.623672999999997	57.719743000000001	57.676831999999997	Декабристов	0103000020E61000000100000005000000EB8F300C58C64B407171546EA2D64C40EB8F300C58C64B403143E38920DC4C40F8325184D4CF4B403143E38920DC4C40F8325184D4CF4B407171546EA2D64C40EB8F300C58C64B407171546EA2D64C40
51818	56247	55.425863999999997	56.831521000000002	58.166168999999996	57.392600999999999	Комсомольский проспект	0103000020E61000000100000005000000994528B682B64B403EB0E3BF40B24C40994528B682B64B40F44D9A0645154D40F777B6476F6A4C40F44D9A0645154D40F777B6476F6A4C403EB0E3BF40B24C40994528B682B64B403EB0E3BF40B24C40
53996	28049	55.959985000000003	55.986539	57.869306999999999	57.853976000000003	Верховая	0103000020E6100000010000000500000046D3D9C9E0FA4B40D2C8E7154FED4C4046D3D9C9E0FA4B408997A77345EF4C40419DF2E846FE4B408997A77345EF4C40419DF2E846FE4B40D2C8E7154FED4C4046D3D9C9E0FA4B40D2C8E7154FED4C40
51815	28545	55.670413000000003	55.679566999999999	58.011532000000003	58.004533000000002	Победы	0103000020E6100000010000000500000019E8DA17D0D54B405B608F8994004D4019E8DA17D0D54B40C26D6DE179014D406D382C0DFCD64B40C26D6DE179014D406D382C0DFCD64B405B608F8994004D4019E8DA17D0D54B405B608F8994004D40
51627	28545	55.670413000000003	55.679566999999999	58.011532000000003	58.004533000000002	Краснознаменная	0103000020E6100000010000000500000019E8DA17D0D54B405B608F8994004D4019E8DA17D0D54B40C26D6DE179014D406D382C0DFCD64B40C26D6DE179014D406D382C0DFCD64B405B608F8994004D4019E8DA17D0D54B405B608F8994004D40
64013	58154	56.766384000000002	56.804329000000003	57.992584999999998	57.985128000000003	Советская	0103000020E61000000100000005000000BE16F4DE18624C40DC2F9FAC18FE4C40BE16F4DE18624C4005C078060DFF4C40B91CAF40F4664C4005C078060DFF4C40B91CAF40F4664C40DC2F9FAC18FE4C40BE16F4DE18624C40DC2F9FAC18FE4C40
51745	29322	56.745058	56.784036	58.041218999999998	58.028111000000003	Молодежная	0103000020E61000000100000005000000C4CF7F0F5E5F4C4035D4282499034D40C4CF7F0F5E5F4C40A67C08AA46054D407E71A94A5B644C40A67C08AA46054D407E71A94A5B644C4035D4282499034D40C4CF7F0F5E5F4C4035D4282499034D40
51629	29322	56.745058	56.784036	58.041218999999998	58.028111000000003	Заводской переулок	0103000020E61000000100000005000000C4CF7F0F5E5F4C4035D4282499034D40C4CF7F0F5E5F4C40A67C08AA46054D407E71A94A5B644C40A67C08AA46054D407E71A94A5B644C4035D4282499034D40C4CF7F0F5E5F4C4035D4282499034D40
52793	27319	55.704000999999998	55.720880000000001	57.923184999999997	57.918401000000003	Полевая	0103000020E61000000100000005000000F7AC6BB41CDA4B408ECEF9298EF54C40F7AC6BB41CDA4B40319413ED2AF64C40952BBCCB45DC4B40319413ED2AF64C40952BBCCB45DC4B408ECEF9298EF54C40F7AC6BB41CDA4B408ECEF9298EF54C40
63992	58153	55.693660999999999	55.713388000000002	57.560513999999998	57.552261999999999	Революционная	0103000020E610000001000000050000005DC136E2C9D84B406A696E85B0C64C405DC136E2C9D84B409E7939ECBEC74C40EFAD484C50DB4B409E7939ECBEC74C40EFAD484C50DB4B406A696E85B0C64C405DC136E2C9D84B406A696E85B0C64C40
52050	56267	56.015284999999999	56.045648	57.482444000000001	57.468037000000002	Граневая	0103000020E61000000100000005000000478FDFDBF4014C40B328ECA2E8BB4C40478FDFDBF4014C40621399B9C0BD4C405C902DCBD7054C40621399B9C0BD4C405C902DCBD7054C40B328ECA2E8BB4C40478FDFDBF4014C40B328ECA2E8BB4C40
52131	56267	56.015284999999999	56.045648	57.482444000000001	57.468037000000002	18 Годовщины Октября	0103000020E61000000100000005000000478FDFDBF4014C40B328ECA2E8BB4C40478FDFDBF4014C40621399B9C0BD4C405C902DCBD7054C40621399B9C0BD4C405C902DCBD7054C40B328ECA2E8BB4C40478FDFDBF4014C40B328ECA2E8BB4C40
52217	56310	\N	\N	\N	\N	Первомайская	\N
52048	28402	56.305540000000001	56.328330000000001	57.629536999999999	57.605826	Садовая	0103000020E6100000010000000500000057CF49EF1B274C408388D4B48BCD4C4057CF49EF1B274C409C4F1DAB94D04C40D925AAB7062A4C409C4F1DAB94D04C40D925AAB7062A4C408388D4B48BCD4C4057CF49EF1B274C408388D4B48BCD4C40
52047	27131	56.246412999999997	56.284500999999999	57.893639999999998	57.867013999999998	Трактовая	0103000020E61000000100000005000000952710768A1F4C404A969350FAEE4C40952710768A1F4C40DF32A7CB62F24C40F3565D876A244C40DF32A7CB62F24C40F3565D876A244C404A969350FAEE4C40952710768A1F4C404A969350FAEE4C40
51491	6640	56.358711	56.399422999999999	57.819412999999997	57.789791000000001	Октябрьская	0103000020E6100000010000000500000094DBF63DEA2D4C406BD619DF17E54C4094DBF63DEA2D4C4068757286E2E84C409622F94A20334C4068757286E2E84C409622F94A20334C406BD619DF17E54C4094DBF63DEA2D4C406BD619DF17E54C40
65387	58535	56.661506000000003	56.737341999999998	57.993614999999998	57.824029000000003	Мира	0103000020E61000000100000005000000CC0D863AAC544C4051FA42C879E94C40CC0D863AAC544C4053E8BCC62EFF4C40CEFBFF38615E4C4053E8BCC62EFF4C40CEFBFF38615E4C4051FA42C879E94C40CC0D863AAC544C4051FA42C879E94C40
51622	28128	56.279947	56.311990000000002	57.870474999999999	57.853771000000002	Культуры	0103000020E6100000010000000500000081CEA44DD5234C40F9A23D5E48ED4C4081CEA44DD5234C40287E8CB96BEF4C40EB56CF49EF274C40287E8CB96BEF4C40EB56CF49EF274C40F9A23D5E48ED4C4081CEA44DD5234C40F9A23D5E48ED4C40
51813	28086	56.591087000000002	56.63223	57.667873999999998	57.641654000000003	Чурекова	0103000020E610000001000000050000009E0B23BDA84B4C407EACE0B721D24C409E0B23BDA84B4C40A2EC2DE57CD54C4069C6A2E9EC504C40A2EC2DE57CD54C4069C6A2E9EC504C407EACE0B721D24C409E0B23BDA84B4C407EACE0B721D24C40
51494	27824	55.921841999999998	55.964207000000002	57.905458000000003	57.888033	Р.Кашина	0103000020E61000000100000005000000240A2DEBFEF54B406762BA10ABF14C40240A2DEBFEF54B4067F3380CE6F34C4082C98D226BFB4B4067F3380CE6F34C4082C98D226BFB4B406762BA10ABF14C40240A2DEBFEF54B406762BA10ABF14C40
51744	10345	56.448695000000001	56.529463	57.663421	57.631638000000002	Чапаева	0103000020E610000001000000050000007A7077D66E394C4097749483D9D04C407A7077D66E394C40643DB5FAEAD44C4095B88E71C5434C40643DB5FAEAD44C4095B88E71C5434C4097749483D9D04C407A7077D66E394C4097749483D9D04C40
51621	10345	56.448695000000001	56.529463	57.663421	57.631638000000002	Ульяновская	0103000020E610000001000000050000007A7077D66E394C4097749483D9D04C407A7077D66E394C40643DB5FAEAD44C4095B88E71C5434C40643DB5FAEAD44C4095B88E71C5434C4097749483D9D04C407A7077D66E394C4097749483D9D04C40
51816	49152	55.690866999999997	55.722074999999997	57.999004999999997	57.982765999999998	Садовая	0103000020E610000001000000050000005C7171546ED84B4074CFBA46CBFD4C405C7171546ED84B402EC55565DFFF4C402D211FF46CDC4B402EC55565DFFF4C402D211FF46CDC4B4074CFBA46CBFD4C405C7171546ED84B4074CFBA46CBFD4C40
52204	33032	56.293790000000001	56.341265999999997	57.809978000000001	57.785066	Советская	0103000020E6100000010000000500000028F224E99A254C40CC99ED0A7DE44C4028F224E99A254C40603DEE5BADE74C404D9EB29AAE2B4C40603DEE5BADE74C404D9EB29AAE2B4C40CC99ED0A7DE44C4028F224E99A254C40CC99ED0A7DE44C40
52046	27960	55.870503999999997	55.892781999999997	57.875222999999998	57.867182	Центральная	0103000020E61000000100000005000000C284D1AC6CEF4B4006D7DCD1FFEE4C40C284D1AC6CEF4B407FDAA84E07F04C408E3A3AAE46F24B407FDAA84E07F04C408E3A3AAE46F24B4006D7DCD1FFEE4C40C284D1AC6CEF4B4006D7DCD1FFEE4C40
53501	33090	56.211621000000001	56.251263000000002	57.823473	57.808266000000003	Клубная	0103000020E61000000100000005000000CB129D65161B4C40003CA24275E74C40CB129D65161B4C40CB11329067E94C40F1D8CF6229204C40CB11329067E94C40F1D8CF6229204C40003CA24275E74C40CB129D65161B4C40003CA24275E74C40
51791	56246	55.425863999999997	56.831521000000002	58.166168999999996	57.392600999999999	Бабичева	0103000020E61000000100000005000000994528B682B64B403EB0E3BF40B24C40994528B682B64B40F44D9A0645154D40F777B6476F6A4C40F44D9A0645154D40F777B6476F6A4C403EB0E3BF40B24C40994528B682B64B403EB0E3BF40B24C40
52107	32996	55.734768000000003	55.753048999999997	57.944009000000001	57.924532999999997	Школьная	0103000020E61000000100000005000000DC12B9E00CDE4B405089EB1857F64C40DC12B9E00CDE4B4099107349D5F84C408BA4DDE863E04B4099107349D5F84C408BA4DDE863E04B405089EB1857F64C40DC12B9E00CDE4B405089EB1857F64C40
52203	32986	56.316023000000001	56.641195000000003	57.900861999999996	57.827661999999997	Лямина	0103000020E6100000010000000500000054E4107173284C402B1213D4F0E94C4054E4107173284C40C51A2E724FF34C40EBAD81AD12524C40C51A2E724FF34C40EBAD81AD12524C402B1213D4F0E94C4054E4107173284C402B1213D4F0E94C40
65440	56311	55.535935000000002	55.544612999999998	57.908839	57.905425000000001	Клубная	0103000020E6100000010000000500000011E4A08499C44B408BFD65F7E4F34C4011E4A08499C44B40282A1BD654F44C40FCFCF7E0B5C54B40282A1BD654F44C40FCFCF7E0B5C54B408BFD65F7E4F34C4011E4A08499C44B408BFD65F7E4F34C40
52324	8468	56.196807999999997	56.226407000000002	57.630448000000001	57.619999	Школьная	0103000020E61000000100000005000000ABCB290131194C40BF4692205CCF4C40ABCB290131194C4010EA2285B2D04C40F14A92E7FA1C4C4010EA2285B2D04C40F14A92E7FA1C4C40BF4692205CCF4C40ABCB290131194C40BF4692205CCF4C40
52292	27251	55.771158999999997	55.787489999999998	57.903593000000001	57.897202999999998	Центральная	0103000020E610000001000000050000000E828E56B5E24B40C16F438CD7F24C400E828E56B5E24B4080F277EFA8F34C40A9F6E978CCE44B4080F277EFA8F34C40A9F6E978CCE44B40C16F438CD7F24C400E828E56B5E24B40C16F438CD7F24C40
64101	58164	56.292200000000001	56.329281999999999	57.742913999999999	57.728465999999997	Школьная	0103000020E6100000010000000500000013F241CF66254C40BC1FB75F3EDD4C4013F241CF66254C40CADE52CE17DF4C40AB949EE9252A4C40CADE52CE17DF4C40AB949EE9252A4C40BC1FB75F3EDD4C4013F241CF66254C40BC1FB75F3EDD4C40
52205	27873	55.891748999999997	55.919471000000001	57.851649000000002	57.835653999999998	Мавлютова	0103000020E61000000100000005000000CF9ECBD424F24B40C362D4B5F6EA4C40CF9ECBD424F24B40E7559DD502ED4C406A4FC939B1F54B40E7559DD502ED4C406A4FC939B1F54B40C362D4B5F6EA4C40CF9ECBD424F24B40C362D4B5F6EA4C40
52206	27755	56.477925999999997	56.510364000000003	57.593508	57.577587000000001	Школьная	0103000020E610000001000000050000003CF4DDAD2C3D4C4021CCED5EEEC94C403CF4DDAD2C3D4C400AF5F411F8CB4C402387889B53414C400AF5F411F8CB4C402387889B53414C4021CCED5EEEC94C403CF4DDAD2C3D4C4021CCED5EEEC94C40
53957	32950	54.263364000000003	54.28575	57.939360999999998	57.929499	Центральная	0103000020E61000000100000005000000CD785BE9B5214B401555BFD2F9F64C40CD785BE9B5214B40A51133FB3CF84C407F6ABC7493244B40A51133FB3CF84C407F6ABC7493244B401555BFD2F9F64C40CD785BE9B5214B401555BFD2F9F64C40
52142	26458	54.546565999999999	54.563769000000001	57.941037999999999	57.926459000000001	Центральная	0103000020E61000000100000005000000828DEBDFF5454B40DD0A613596F64C40828DEBDFF5454B408925E5EE73F84C40D3BF249529484B408925E5EE73F84C40D3BF249529484B40DD0A613596F64C40828DEBDFF5454B40DD0A613596F64C40
52172	32565	54.702289	54.716079000000001	57.835476999999997	57.825994000000001	Мира	0103000020E6100000010000000500000097AB1F9BE4594B409B58E02BBAE94C4097AB1F9BE4594B40B4C70BE9F0EA4C401B2D077AA85B4B40B4C70BE9F0EA4C401B2D077AA85B4B409B58E02BBAE94C4097AB1F9BE4594B409B58E02BBAE94C40
51616	48044	54.814300000000003	54.867731999999997	57.857481999999997	57.830666000000001	Таборская	0103000020E6100000010000000500000000917EFB3A684B4017F3734353EA4C4000917EFB3A684B404F745DF8C1ED4C40A9D898D7116F4B404F745DF8C1ED4C40A9D898D7116F4B4017F3734353EA4C4000917EFB3A684B4017F3734353EA4C40
51814	48044	54.814300000000003	54.867731999999997	57.857481999999997	57.830666000000001	Октябрьская	0103000020E6100000010000000500000000917EFB3A684B4017F3734353EA4C4000917EFB3A684B404F745DF8C1ED4C40A9D898D7116F4B404F745DF8C1ED4C40A9D898D7116F4B4017F3734353EA4C4000917EFB3A684B4017F3734353EA4C40
52096	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Школьная	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
51738	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Урицкого	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
52141	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Советская	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
51740	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Революционная	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
52200	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Пушкина	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
52202	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Олега Кошевого	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
51739	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Коммунистическая	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
51741	25794	54.669868999999998	54.783264000000003	57.916130000000003	57.861753	Дорожный	0103000020E6100000010000000500000057CD7344BE554B406D1D1CEC4DEE4C4057CD7344BE554B40377172BF43F54C402C11A8FE41644B40377172BF43F54C402C11A8FE41644B406D1D1CEC4DEE4C4057CD7344BE554B406D1D1CEC4DEE4C40
53946	26626	54.488275000000002	54.512816999999998	57.804065999999999	57.793835000000001	Мира	0103000020E610000001000000050000002A3A92CB7F3E4B40C8B5A1629CE54C402A3A92CB7F3E4B40ABE97AA2EBE64C409AEAC9FCA3414B40ABE97AA2EBE64C409AEAC9FCA3414B40C8B5A1629CE54C402A3A92CB7F3E4B40C8B5A1629CE54C40
52104	26206	54.954788000000001	54.977389000000002	57.873902000000001	57.853718000000001	Школьная	0103000020E610000001000000050000007F4E417E367A4B40D600A5A146ED4C407F4E417E367A4B405AF44E05DCEF4C402E3C2F151B7D4B405AF44E05DCEF4C402E3C2F151B7D4B40D600A5A146ED4C407F4E417E367A4B40D600A5A146ED4C40
53945	32922	54.801886000000003	54.823777999999997	57.958494000000002	57.934596999999997	Раздольная	0103000020E61000000100000005000000658F5033A4664B4048F8DEDFA0F74C40658F5033A4664B40C4B46FEEAFFA4C400795B88E71694B40C4B46FEEAFFA4C400795B88E71694B4048F8DEDFA0F74C40658F5033A4664B4048F8DEDFA0F74C40
53943	32911	54.708047999999998	54.732804999999999	57.924911000000002	57.912157000000001	Заречная	0103000020E61000000100000005000000C5FF1D51A15A4B40A3E8818FC1F44C40C5FF1D51A15A4B40F75AD07B63F64C4032ACE28DCC5D4B40F75AD07B63F64C4032ACE28DCC5D4B40A3E8818FC1F44C40C5FF1D51A15A4B40A3E8818FC1F44C40
53964	26833	54.337600000000002	54.364899999999999	57.882373000000001	57.870494000000001	Центральная	0103000020E6100000010000000500000097900F7A362B4B409FAEEE586CEF4C4097900F7A362B4B40CCEF3499F1F04C40BB270F0BB52E4B40CCEF3499F1F04C40BB270F0BB52E4B409FAEEE586CEF4C4097900F7A362B4B409FAEEE586CEF4C40
64333	32939	54.470999999999997	54.505234999999999	57.902087000000002	57.895524000000002	Советская	0103000020E610000001000000050000003F355EBA493C4B403D64CA87A0F24C403F355EBA493C4B40C992399677F34C40B4E55C8AAB404B40C992399677F34C40B4E55C8AAB404B403D64CA87A0F24C403F355EBA493C4B403D64CA87A0F24C40
54210	56503	54.923526000000003	54.963205000000002	58.021414999999998	58.009157999999999	Уральская	0103000020E61000000100000005000000BB80971936764B40963FDF162C014D40BB80971936764B4069520ABABD024D40FE2B2B4D4A7B4B4069520ABABD024D40FE2B2B4D4A7B4B40963FDF162C014D40BB80971936764B40963FDF162C014D40
51812	25446	55.312677000000001	55.338180000000001	57.716757999999999	57.705992999999999	Культуры	0103000020E610000001000000050000000F9BC8CC05A84B403B1A87FA5DDA4C400F9BC8CC05A84B40BC92E4B9BEDB4C40A514747B49AB4B40BC92E4B9BEDB4C40A514747B49AB4B403B1A87FA5DDA4C400F9BC8CC05A84B403B1A87FA5DDA4C40
52051	32744	55.136085999999999	55.161552999999998	57.836545999999998	57.821944000000002	Октября	0103000020E61000000100000005000000C3B81B446B914B405C92037635E94C40C3B81B446B914B40C0CC77F013EB4C400CC9C9C4AD944B40C0CC77F013EB4C400CC9C9C4AD944B405C92037635E94C40C3B81B446B914B405C92037635E94C40
63642	32780	54.943441999999997	54.978988000000001	57.759338999999997	57.741151000000002	Центральная	0103000020E610000001000000050000001FD61BB5C2784B40E8323509DEDE4C401FD61BB5C2784B40E6C9350532E14C409696917A4F7D4B40E6C9350532E14C409696917A4F7D4B40E8323509DEDE4C401FD61BB5C2784B40E8323509DEDE4C40
51625	25119	55.351205	55.421731999999999	57.730277999999998	57.699438000000001	Ленина	0103000020E6100000010000000500000089981249F4AC4B4032CA332F87D94C4089981249F4AC4B40807EDFBF79DD4C409DD66D50FBB54B40807EDFBF79DD4C409DD66D50FBB54B4032CA332F87D94C4089981249F4AC4B4032CA332F87D94C40
51604	25119	55.351205	55.421731999999999	57.730277999999998	57.699438000000001	Красная	0103000020E6100000010000000500000089981249F4AC4B4032CA332F87D94C4089981249F4AC4B40807EDFBF79DD4C409DD66D50FBB54B40807EDFBF79DD4C409DD66D50FBB54B4032CA332F87D94C4089981249F4AC4B4032CA332F87D94C40
51736	25119	55.351205	55.421731999999999	57.730277999999998	57.699438000000001	Винокурова	0103000020E6100000010000000500000089981249F4AC4B4032CA332F87D94C4089981249F4AC4B40807EDFBF79DD4C409DD66D50FBB54B40807EDFBF79DD4C409DD66D50FBB54B4032CA332F87D94C4089981249F4AC4B4032CA332F87D94C40
54552	9658	55.164760000000001	55.211643000000002	57.676836000000002	57.659469000000001	Советская	0103000020E6100000010000000500000030D80DDB16954B40E8DCED7A69D44C4030D80DDB16954B40B360E28FA2D64C40B3B6291E179B4B40B360E28FA2D64C40B3B6291E179B4B40E8DCED7A69D44C4030D80DDB16954B40E8DCED7A69D44C40
53937	32770	55.087243999999998	55.110205000000001	57.772602999999997	57.762228999999998	Центральная	0103000020E61000000100000005000000D862B7CF2A8B4B40098849B890E14C40D862B7CF2A8B4B404FE5B4A7E4E24C40876D8B321B8E4B404FE5B4A7E4E24C40876D8B321B8E4B40098849B890E14C40D862B7CF2A8B4B40098849B890E14C40
52022	56260	55.473547000000003	55.493237999999998	57.514707000000001	57.510393999999998	40 лет Победы	0103000020E61000000100000005000000390F27309DBC4B408D09319754C14C40390F27309DBC4B40DA0242EBE1C14C407D923B6C22BF4B40DA0242EBE1C14C407D923B6C22BF4B408D09319754C14C40390F27309DBC4B408D09319754C14C40
52095	56280	55.346398999999998	55.371184	57.598115	57.583218000000002	Садовая	0103000020E61000000100000005000000FD2E6CCD56AC4B4022382EE3A6CA4C40FD2E6CCD56AC4B409F1F46088FCC4C40346612F582AF4B409F1F46088FCC4C40346612F582AF4B4022382EE3A6CA4C40FD2E6CCD56AC4B4022382EE3A6CA4C40
51580	56227	55.223151000000001	55.244036000000001	57.700256000000003	57.690005999999997	Ленина,	0103000020E61000000100000005000000EC884336909C4B409A05DA1D52D84C40EC884336909C4B40F56915FDA1D94C40F98557923C9F4B40F56915FDA1D94C40F98557923C9F4B409A05DA1D52D84C40EC884336909C4B409A05DA1D52D84C40
52156	32711	55.458590000000001	55.499248000000001	57.480949000000003	57.459933999999997	 Камская	0103000020E61000000100000005000000E622BE13B3BA4B40C328081EDFBA4C40E622BE13B3BA4B409F05A1BC8FBD4C40F54BC45BE7BF4B409F05A1BC8FBD4C40F54BC45BE7BF4B40C328081EDFBA4C40E622BE13B3BA4B40C328081EDFBA4C40
52093	56277	55.233947999999998	55.263286999999998	57.524155999999998	57.517113999999999	 Победы	0103000020E61000000100000005000000787B1002F29D4B40E126A3CA30C24C40787B1002F29D4B404700378B17C34C40213B6F63B3A14B404700378B17C34C40213B6F63B3A14B40E126A3CA30C24C40787B1002F29D4B40E126A3CA30C24C40
64428	58228	55.353333999999997	55.381793000000002	57.264609999999998	57.251300999999998	Советская	0103000020E610000001000000050000004D486B0C3AAD4B40DE3994A12AA04C404D486B0C3AAD4B40E71890BDDEA14C40BE6BD097DEB04B40E71890BDDEA14C40BE6BD097DEB04B40DE3994A12AA04C404D486B0C3AAD4B40DE3994A12AA04C40
52130	32557	55.292904999999998	55.314132000000001	57.281573999999999	57.268095000000002	Уральская	0103000020E61000000100000005000000DDEA39E97DA54B404E9CDCEF50A24C40DDEA39E97DA54B40B3B3E89D0AA44C404450357A35A84B40B3B3E89D0AA44C404450357A35A84B404E9CDCEF50A24C40DDEA39E97DA54B404E9CDCEF50A24C40
52319	24903	55.636825000000002	55.674536000000003	57.469527999999997	57.449053999999997	Садовая	0103000020E610000001000000050000003A234A7B83D14B40A911FA997AB94C403A234A7B83D14B403447567E19BC4C40C2FC153257D64B403447567E19BC4C40C2FC153257D64B40A911FA997AB94C403A234A7B83D14B40A911FA997AB94C40
51735	23645	55.409264	55.483517999999997	57.294829	57.263398000000002	Строителей	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
52129	23645	55.409264	55.483517999999997	57.294829	57.263398000000002	Советская	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51490	23645	55.409264	55.483517999999997	57.294829	57.263398000000002	Пугачева	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51488	23645	55.409264	55.483517999999997	57.294829	57.263398000000002	Мира	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51603	23645	55.409264	55.483517999999997	57.294829	57.263398000000002	М.Горького	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51821	23645	55.409264	55.483517999999997	57.294829	57.263398000000002	Интернациональная	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51485	23645	55.409264	55.483517999999997	57.294829	57.263398000000002	Горького	0103000020E610000001000000050000000FB743C362B44B4079EA9106B7A14C400FB743C362B44B40C974E8F4BCA54C407F83F6EAE3BD4B40C974E8F4BCA54C407F83F6EAE3BD4B4079EA9106B7A14C400FB743C362B44B4079EA9106B7A14C40
51726	56241	55.226438000000002	55.241647	57.126275	57.115696	Школьная	0103000020E610000001000000050000002C499EEBFB9C4B4096236420CF8E4C402C499EEBFB9C4B40B5A679C729904C409816F549EE9E4B40B5A679C729904C409816F549EE9E4B4096236420CF8E4C402C499EEBFB9C4B4096236420CF8E4C40
52237	56323	54.977379999999997	55.926099999999998	57.515706999999999	57.053705000000001	Советская	0103000020E61000000100000005000000DAE1AFC91A7D4B40DB5031CEDF864C40DAE1AFC91A7D4B40BDA8DDAF02C24C40AD69DE718AF64B40BDA8DDAF02C24C40AD69DE718AF64B40DB5031CEDF864C40DAE1AFC91A7D4B40DB5031CEDF864C40
9943	32603	55.630958999999997	55.645583000000002	57.084498000000004	57.068148999999998	Молодежная	0103000020E61000000100000005000000F50EB743C3D04B40A7203F1BB9884C40F50EB743C3D04B40E94999D4D08A4C4042EDB776A2D24B40E94999D4D08A4C4042EDB776A2D24B40A7203F1BB9884C40F50EB743C3D04B40A7203F1BB9884C40
52287	32611	55.818804999999998	55.843373999999997	57.257255000000001	57.247225	Кирова	0103000020E6100000010000000500000090662C9ACEE84B4076E09C11A59F4C4090662C9ACEE84B40C2DD59BBEDA04C40FA25E2ADF3EB4B40C2DD59BBEDA04C40FA25E2ADF3EB4B4076E09C11A59F4C4090662C9ACEE84B4076E09C11A59F4C40
52317	32633	55.601610999999998	55.617905999999998	57.372616999999998	57.363832000000002	 Чапаева	0103000020E61000000100000005000000F9F4D89601CD4B40809E060C92AE4C40F9F4D89601CD4B408177F2E9B1AF4C404700378B17CF4B408177F2E9B1AF4C404700378B17CF4B40809E060C92AE4C40F9F4D89601CD4B40809E060C92AE4C40
52213	56309	55.531523999999997	55.562956	57.179552999999999	57.152794	Ленина	0103000020E6100000010000000500000001857AFA08C44B403483F8C08E934C4001857AFA08C44B400873BB97FB964C40228B34F10EC84B400873BB97FB964C40228B34F10EC84B403483F8C08E934C4001857AFA08C44B403483F8C08E934C40
52132	24773	55.558140999999999	55.586680999999999	57.301476000000001	57.289810000000003	Советская	0103000020E6100000010000000500000043C70E2A71C74B40E2067C7E18A54C4043C70E2A71C74B40B343FCC396A64C40A017EE5C18CB4B40B343FCC396A64C40A017EE5C18CB4B40E2067C7E18A54C4043C70E2A71C74B40E2067C7E18A54C40
52233	56320	55.510710000000003	55.532224999999997	57.215924999999999	57.205058999999999	Мира	0103000020E61000000100000005000000BEDEFDF15EC14B400F60915F3F9A4C40BEDEFDF15EC14B40C4B12E6EA39B4C408A8EE4F21FC44B40C4B12E6EA39B4C408A8EE4F21FC44B400F60915F3F9A4C40BEDEFDF15EC14B400F60915F3F9A4C40
52289	24988	55.312595999999999	55.335484999999998	57.356569999999998	57.339461	Молодежная	0103000020E61000000100000005000000226E4E2503A84B403CA2427573AB4C40226E4E2503A84B400B5EF415A4AD4C4037A6272CF1AA4B400B5EF415A4AD4C4037A6272CF1AA4B403CA2427573AB4C40226E4E2503A84B403CA2427573AB4C40
53492	33084	56.548157000000003	56.567982000000001	57.140602000000001	57.134495999999999	Центральная	0103000020E61000000100000005000000680932022A464C40AEB8382A37914C40680932022A464C4048E00F3FFF914C40BC5B59A2B3484C4048E00F3FFF914C40BC5B59A2B3484C40AEB8382A37914C40680932022A464C40AEB8382A37914C40
54457	22832	56.973193999999999	56.996371000000003	57.095520999999998	57.078315000000003	Ленина	0103000020E61000000100000005000000EB54F99E917C4C40A4E4D539068A4C40EB54F99E917C4C40658A39083A8C4C4067D7BD15897F4C40658A39083A8C4C4067D7BD15897F4C40A4E4D539068A4C40EB54F99E917C4C40A4E4D539068A4C40
52126	56287	56.915244000000001	56.928134999999997	57.066454999999998	57.057665	Терехинская	0103000020E610000001000000050000001CEE23B726754C40DA8F149161874C401CEE23B726754C40EDD3F19881884C40F0A2AF20CD764C40EDD3F19881884C40F0A2AF20CD764C40DA8F149161874C401CEE23B726754C40DA8F149161874C40
51602	9878	56.882213	56.946531999999998	57.221173	57.181587999999998	Трактовая	0103000020E61000000100000005000000938D075BEC704C404BAC8C463E974C40938D075BEC704C400DE198654F9C4C40094FE8F527794C400DE198654F9C4C40094FE8F527794C404BAC8C463E974C40938D075BEC704C404BAC8C463E974C40
51779	9878	56.882213	56.946531999999998	57.221173	57.181587999999998	Советская	0103000020E61000000100000005000000938D075BEC704C404BAC8C463E974C40938D075BEC704C400DE198654F9C4C40094FE8F527794C400DE198654F9C4C40094FE8F527794C404BAC8C463E974C40938D075BEC704C404BAC8C463E974C40
52315	9878	56.882213	56.946531999999998	57.221173	57.181587999999998	Пугачева	0103000020E61000000100000005000000938D075BEC704C404BAC8C463E974C40938D075BEC704C400DE198654F9C4C40094FE8F527794C400DE198654F9C4C40094FE8F527794C404BAC8C463E974C40938D075BEC704C404BAC8C463E974C40
54362	9878	56.882213	56.946531999999998	57.221173	57.181587999999998	1 Мая	0103000020E61000000100000005000000938D075BEC704C404BAC8C463E974C40938D075BEC704C400DE198654F9C4C40094FE8F527794C400DE198654F9C4C40094FE8F527794C404BAC8C463E974C40938D075BEC704C404BAC8C463E974C40
54421	9280	56.781754999999997	56.805551000000001	57.108848000000002	57.093927000000001	Советская	0103000020E61000000100000005000000033E3F8C10644C400F9BC8CC058C4C40033E3F8C10644C40151E34BBEE8D4C404B21904B1C674C40151E34BBEE8D4C404B21904B1C674C400F9BC8CC058C4C40033E3F8C10644C400F9BC8CC058C4C40
54490	9965	56.978476999999998	57.029474	56.929226	56.911451	Советская	0103000020E61000000100000005000000B071FDBB3E7D4C400874266DAA744C40B071FDBB3E7D4C40E44BA8E0F0764C40890AD5CDC5834C40E44BA8E0F0764C40890AD5CDC5834C400874266DAA744C40B071FDBB3E7D4C400874266DAA744C40
52759	33079	56.310822000000002	56.332920000000001	57.121808999999999	57.114797000000003	Гаражная	0103000020E610000001000000050000004C70EA03C9274C40E75608ABB18E4C404C70EA03C9274C40E2ADF36F978F4C409817601F9D2A4C40E2ADF36F978F4C409817601F9D2A4C40E75608ABB18E4C404C70EA03C9274C40E75608ABB18E4C40
52745	22970	56.879356000000001	56.908892999999999	56.937575000000002	56.924627999999998	Центральная	0103000020E610000001000000050000004CC5C6BC8E704C40A27BD6355A764C404CC5C6BC8E704C400B46257502784C401B48179B56744C400B46257502784C401B48179B56744C40A27BD6355A764C404CC5C6BC8E704C40A27BD6355A764C40
52040	33052	56.943064999999997	56.985833999999997	56.991208999999998	56.958832000000001	Ленина	0103000020E6100000010000000500000049809A5AB6784C40DC2DC901BB7A4C4049809A5AB6784C401C40BFEFDF7E4C4076A4FACE2F7E4C401C40BFEFDF7E4C4076A4FACE2F7E4C40DC2DC901BB7A4C4049809A5AB6784C40DC2DC901BB7A4C40
52039	23120	56.555990000000001	56.590153000000001	57.089604000000001	57.068775000000002	Советская	0103000020E61000000100000005000000977329AE2A474C4026E4839ECD884C40977329AE2A474C409FCBD424788B4C4072512D228A4B4C409FCBD424788B4C4072512D228A4B4C4026E4839ECD884C40977329AE2A474C4026E4839ECD884C40
52092	23384	56.63355	56.669815	57.098092999999999	57.079695000000001	Советская	0103000020E61000000100000005000000BE30992A18514C40CE531D72338A4C40BE30992A18514C40B77BB94F8E8C4C4064AF777FBC554C40B77BB94F8E8C4C4064AF777FBC554C40CE531D72338A4C40BE30992A18514C40CE531D72338A4C40
52198	23354	56.558459999999997	56.580261999999998	57.186197	57.165548999999999	Центральная	0103000020E61000000100000005000000E40F069E7B474C405871AAB530954C40E40F069E7B474C4081CEA44DD5974C40478E7406464A4C4081CEA44DD5974C40478E7406464A4C405871AAB530954C40E40F069E7B474C405871AAB530954C40
53494	22873	56.842229000000003	56.865656999999999	57.050102000000003	57.032890000000002	Центральная	0103000020E61000000100000005000000145FED28CE6B4C40C72E51BD35844C40145FED28CE6B4C406BBB09BE69864C40D8463CD9CD6E4C406BBB09BE69864C40D8463CD9CD6E4C40C72E51BD35844C40145FED28CE6B4C40C72E51BD35844C40
53935	23052	56.675573999999997	56.706566000000002	57.051071999999998	57.037415000000003	Заводская	0103000020E610000001000000050000009203763579564C409FB0C403CA844C409203763579564C40E3DEFC8689864C40973B33C1705A4C40E3DEFC8689864C40973B33C1705A4C409FB0C403CA844C409203763579564C409FB0C403CA844C40
52314	23533	56.838735	56.863573000000002	57.171014999999997	57.162185999999998	Большая	0103000020E610000001000000050000005A8121AB5B6B4C403DEFC682C2944C405A8121AB5B6B4C400E10CCD1E3954C40B45A608F896E4C400E10CCD1E3954C40B45A608F896E4C403DEFC682C2944C405A8121AB5B6B4C403DEFC682C2944C40
51809	23229	56.493979000000003	56.547483	57.127671999999997	57.103437	пер.Советский	0103000020E6100000010000000500000095F430B43A3F4C402219726C3D8D4C4095F430B43A3F4C40B54E5C8E57904C40D80E46EC13464C40B54E5C8E57904C40D80E46EC13464C402219726C3D8D4C4095F430B43A3F4C402219726C3D8D4C40
51487	46049	56.971784	57.021909999999998	56.651245000000003	56.629154	Первомайская	0103000020E610000001000000050000005663096B637C4C40E412471E88504C405663096B637C4C407E5704FF5B534C4049BA66F2CD824C407E5704FF5B534C4049BA66F2CD824C40E412471E88504C405663096B637C4C40E412471E88504C40
64350	58212	57.030290999999998	57.046613999999998	56.538936999999997	56.526888999999997	Центральная	0103000020E610000001000000050000007B2E5393E0834C40A2CF471971434C407B2E5393E0834C405BCD3AE3FB444C4093C49272F7854C405BCD3AE3FB444C4093C49272F7854C40A2CF471971434C407B2E5393E0834C40A2CF471971434C40
52736	21208	57.166763000000003	57.178153999999999	56.505941999999997	56.499464000000003	Речная	0103000020E6100000010000000500000068976F7D58954C40C2C3B46FEE3F4C4068976F7D58954C401FD61BB5C2404C4067D311C0CD964C401FD61BB5C2404C4067D311C0CD964C40C2C3B46FEE3F4C4068976F7D58954C40C2C3B46FEE3F4C40
51484	21407	57.081099999999999	57.100206999999997	56.473744000000003	56.464381000000003	Советская	0103000020E6100000010000000500000051DA1B7C618A4C4020F12BD6703B4C4051DA1B7C618A4C408F56B5A4A33C4C4046EA3D95D38C4C408F56B5A4A33C4C4046EA3D95D38C4C4020F12BD6703B4C4051DA1B7C618A4C4020F12BD6703B4C40
52128	22594	57.080516000000003	57.108454000000002	56.213850999999998	56.189960999999997	Зимина	0103000020E61000000100000005000000026729594E8A4C40FA415DA450184C40026729594E8A4C40C39B35785F1B4C40698F17D2E18D4C40C39B35785F1B4C40698F17D2E18D4C40FA415DA450184C40026729594E8A4C40FA415DA450184C40
51889	45764	57.177138999999997	57.235916000000003	56.530254999999997	56.490386000000001	Ленина	0103000020E610000001000000050000004EECA17DAC964C404835ECF7C43E4C404EECA17DAC964C402EC55565DF434C40344DD87E329E4C402EC55565DF434C40344DD87E329E4C404835ECF7C43E4C404EECA17DAC964C404835ECF7C43E4C40
52002	32660	56.775995999999999	56.821469	56.67727	56.656495	Мира	0103000020E61000000100000005000000D5E940D653634C40677E350708544C40D5E940D653634C40ED478AC8B0564C40C3D66CE525694C40ED478AC8B0564C40C3D66CE525694C40677E350708544C40D5E940D653634C40677E350708544C40
52036	19667	55.186185000000002	55.209352000000003	58.026556999999997	58.010053999999997	Школьная	0103000020E61000000100000005000000BD00FBE8D4974B40D498107349014D40BD00FBE8D4974B406C3D433866034D4015ADDC0BCC9A4B406C3D433866034D4015ADDC0BCC9A4B40D498107349014D40BD00FBE8D4974B40D498107349014D40
53909	19848	55.131199000000002	55.148411000000003	57.940444999999997	57.932786	Центральная	0103000020E610000001000000050000004B22FB20CB904B4055151A8865F74C404B22FB20CB904B40E657738060F84C40EFAEB321FF924B40E657738060F84C40EFAEB321FF924B4055151A8865F74C404B22FB20CB904B4055151A8865F74C40
51610	56215	55.473852000000001	55.566532000000002	58.140881999999998	58.114663	Строительная	0103000020E610000001000000050000007592AD2EA7BC4B40D787F546AD0E4D407592AD2EA7BC4B402B4CDF6B08124D409911DE1E84C84B402B4CDF6B08124D409911DE1E84C84B40D787F546AD0E4D407592AD2EA7BC4B40D787F546AD0E4D40
51483	56215	55.473852000000001	55.566532000000002	58.140881999999998	58.114663	Коробейникова	0103000020E610000001000000050000007592AD2EA7BC4B40D787F546AD0E4D407592AD2EA7BC4B402B4CDF6B08124D409911DE1E84C84B402B4CDF6B08124D409911DE1E84C84B40D787F546AD0E4D407592AD2EA7BC4B40D787F546AD0E4D40
51555	47999	55.170347999999997	55.176743999999999	58.049334999999999	58.042219000000003	Садовая	0103000020E61000000100000005000000317898F6CD954B408A22A46E67054D40317898F6CD954B402AC6F99B50064D40D2E1218C9F964B402AC6F99B50064D40D2E1218C9F964B408A22A46E67054D40317898F6CD954B408A22A46E67054D40
52731	19422	55.502867999999999	55.574131000000001	57.959105000000001	57.927334000000002	Центральная	0103000020E610000001000000050000003B1A87FA5DC04B40043C69E1B2F64C403B1A87FA5DC04B400D37E0F3C3FA4C40554FE61F7DC94B400D37E0F3C3FA4C40554FE61F7DC94B40043C69E1B2F64C403B1A87FA5DC04B40043C69E1B2F64C40
51489	19422	55.502867999999999	55.574131000000001	57.959105000000001	57.927334000000002	Набережная	0103000020E610000001000000050000003B1A87FA5DC04B40043C69E1B2F64C403B1A87FA5DC04B400D37E0F3C3FA4C40554FE61F7DC94B400D37E0F3C3FA4C40554FE61F7DC94B40043C69E1B2F64C403B1A87FA5DC04B40043C69E1B2F64C40
51600	19422	55.502867999999999	55.574131000000001	57.959105000000001	57.927334000000002	Московская	0103000020E610000001000000050000003B1A87FA5DC04B40043C69E1B2F64C403B1A87FA5DC04B400D37E0F3C3FA4C40554FE61F7DC94B400D37E0F3C3FA4C40554FE61F7DC94B40043C69E1B2F64C403B1A87FA5DC04B40043C69E1B2F64C40
53452	20419	55.264527000000001	55.278827999999997	58.306831000000003	58.298569999999998	Советская	0103000020E610000001000000050000005AF44E05DCA14B408AC8B08A37264D405AF44E05DCA14B401233FB3C46274D40C39ACAA2B0A34B401233FB3C46274D40C39ACAA2B0A34B408AC8B08A37264D405AF44E05DCA14B408AC8B08A37264D40
52273	32683	55.426591999999999	55.444935999999998	58.204984000000003	58.195807000000002	Речная	0103000020E610000001000000050000001C5E10919AB64B40F8A92A3410194D401C5E10919AB64B40051A6CEA3C1A4D401268B0A9F3B84B40051A6CEA3C1A4D401268B0A9F3B84B40F8A92A3410194D401C5E10919AB64B40F8A92A3410194D40
52138	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	пр.Ленина	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
51805	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	Оборина	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
51598	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	Ленина проспект	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
51742	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	Королева	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
54464	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	Комсомольская	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
51474	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	К.Маркса	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
51596	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	К.Либкнехта	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
53904	8751	55.298896999999997	55.374571000000003	57.959688	57.874448000000001	Белинского	0103000020E61000000100000005000000AEEFC34142A64B40BC067DE9EDEF4C40AEEFC34142A64B408C2E6F0ED7FA4C40D88349F1F1AF4B408C2E6F0ED7FA4C40D88349F1F1AF4B40BC067DE9EDEF4C40AEEFC34142A64B40BC067DE9EDEF4C40
52088	19308	55.459550999999998	55.496301000000003	57.929566000000001	57.885314999999999	Первомайская	0103000020E610000001000000050000000BEC3191D2BA4B4041D47D0052F14C400BEC3191D2BA4B409DBCC804FCF64C406EFC89CA86BF4B409DBCC804FCF64C406EFC89CA86BF4B4041D47D0052F14C400BEC3191D2BA4B4041D47D0052F14C40
51807	19308	55.459550999999998	55.496301000000003	57.929566000000001	57.885314999999999	Ленина	0103000020E610000001000000050000000BEC3191D2BA4B4041D47D0052F14C400BEC3191D2BA4B409DBCC804FCF64C406EFC89CA86BF4B409DBCC804FCF64C406EFC89CA86BF4B4041D47D0052F14C400BEC3191D2BA4B4041D47D0052F14C40
52091	19905	55.261913	55.301295000000003	57.943297000000001	57.92351	Молодежная	0103000020E61000000100000005000000D9B27C5D86A14B40B5C35F9335F64C40D9B27C5D86A14B401CB5C2F4BDF84C4063B9A5D590A64B401CB5C2F4BDF84C4063B9A5D590A64B40B5C35F9335F64C40D9B27C5D86A14B40B5C35F9335F64C40
64422	32689	55.193407000000001	55.359972999999997	58.245206000000003	58.107416999999998	Шоссейная	0103000020E61000000100000005000000A3E8818FC1984B4068041BD7BF0D4D40A3E8818FC1984B40396403E9621F4D40B438639813AE4B40396403E9621F4D40B438639813AE4B4068041BD7BF0D4D40A3E8818FC1984B4068041BD7BF0D4D40
52108	32689	55.193407000000001	55.359972999999997	58.245206000000003	58.107416999999998	Пономарева	0103000020E61000000100000005000000A3E8818FC1984B4068041BD7BF0D4D40A3E8818FC1984B40396403E9621F4D40B438639813AE4B40396403E9621F4D40B438639813AE4B4068041BD7BF0D4D40A3E8818FC1984B4068041BD7BF0D4D40
64498	58246	55.394657000000002	55.420617999999997	57.959071999999999	57.949553999999999	Школьная	0103000020E610000001000000050000009911DE1E84B24B409BE447FC8AF94C409911DE1E84B24B4031410DDFC2FA4C40F10D85CFD6B54B4031410DDFC2FA4C40F10D85CFD6B54B409BE447FC8AF94C409911DE1E84B24B409BE447FC8AF94C40
52276	20694	55.054645000000001	55.075189000000002	57.881334000000003	57.874949999999998	Центральная	0103000020E61000000100000005000000E9F17B9BFE864B404ED1915CFEEF4C40E9F17B9BFE864B402B6D718DCFF04C406D020CCB9F894B402B6D718DCFF04C406D020CCB9F894B404ED1915CFEEF4C40E9F17B9BFE864B404ED1915CFEEF4C40
51733	45480	55.362290999999999	55.400424000000001	58.231149000000002	58.208730000000003	Школьная	0103000020E610000001000000050000004C512E8D5FAE4B40D8D825AAB71A4D404C512E8D5FAE4B4066C0594A961D4D404A44F81741B34B4066C0594A961D4D404A44F81741B34B40D8D825AAB71A4D404C512E8D5FAE4B40D8D825AAB71A4D40
52196	56303	55.288879999999999	55.347019000000003	58.226055000000002	58.208531000000001	Октябрьская	0103000020E61000000100000005000000F73B1405FAA44B40E199D024B11A4D40F73B1405FAA44B40740CC85EEF1C4D409A0B5C1E6BAC4B40740CC85EEF1C4D409A0B5C1E6BAC4B40E199D024B11A4D40F73B1405FAA44B40E199D024B11A4D40
52224	32632	55.311608	55.333598000000002	57.972977999999998	57.962198999999998	Дружбы	0103000020E6100000010000000500000003965CC5E2A74B40389F3A5629FB4C4003965CC5E2A74B401EDD088B8AFC4C406901DA56B3AA4B401EDD088B8AFC4C406901DA56B3AA4B40389F3A5629FB4C4003965CC5E2A74B40389F3A5629FB4C40
52279	28365	57.524678999999999	57.546939000000002	57.901899999999998	57.891846000000001	Центральная	0103000020E61000000100000005000000F1F274AE28C34C40C2887D0228F24C40F1F274AE28C34C4096218E7571F34C4017F4DE1802C64C4096218E7571F34C4017F4DE1802C64C40C2887D0228F24C40F1F274AE28C34C40C2887D0228F24C40
52098	18058	57.370258999999997	57.384416000000002	57.891435000000001	57.885148000000001	Совхозная	0103000020E610000001000000050000005B069CA564AF4C40560F98874CF14C405B069CA564AF4C4040C1C58A1AF24C409207228B34B14C4040C1C58A1AF24C409207228B34B14C40560F98874CF14C405B069CA564AF4C40560F98874CF14C40
52035	18635	58.617407999999998	58.642228000000003	57.693517	57.681480000000001	Мира	0103000020E61000000100000005000000F624B039074F4D40657094BC3AD74C40F624B039074F4D402A1C412AC5D84C40AA49F08634524D402A1C412AC5D84C40AA49F08634524D40657094BC3AD74C40F624B039074F4D40657094BC3AD74C40
52270	56333	57.576709999999999	57.590265000000002	58.058179000000003	58.048307000000001	Центральная	0103000020E6100000010000000500000059A31EA2D1C94C407D957CEC2E064D4059A31EA2D1C94C403128D36872074D409A7CB3CD8DCB4C403128D36872074D409A7CB3CD8DCB4C407D957CEC2E064D4059A31EA2D1C94C407D957CEC2E064D40
54249	56509	57.946123999999998	57.973000999999996	58.185161999999998	58.172818999999997	Шмидта	0103000020E61000000100000005000000F8FA5A971AF94C404F90D8EE1E164D40F8FA5A971AF94C40213B6F63B3174D40D6FCF84B8BFC4C40213B6F63B3174D40D6FCF84B8BFC4C404F90D8EE1E164D40F8FA5A971AF94C404F90D8EE1E164D40
52269	56332	57.46707	57.504098999999997	57.844987000000003	57.822538000000002	Школьная	0103000020E61000000100000005000000AB7823F3C8BB4C40CFDBD8EC48E94C40AB7823F3C8BB4C40C845B58828EC4C402079E75086C04C40C845B58828EC4C402079E75086C04C40CFDBD8EC48E94C40AB7823F3C8BB4C40CFDBD8EC48E94C40
52190	18241	57.884903999999999	57.917513	58.009306000000002	57.996834999999997	Школьная	0103000020E61000000100000005000000BF0CC68844F14C400B410E4A98FF4C40BF0CC68844F14C400BD462F030014D40D253E41071F54C400BD462F030014D40D253E41071F54C400B410E4A98FF4C40BF0CC68844F14C400B410E4A98FF4C40
52226	56315	57.735180999999997	57.751755000000003	58.098030000000001	58.087421999999997	Полевая	0103000020E61000000100000005000000FED137691ADE4C40B779E3A4300B4D40FED137691ADE4C4071033E3F8C0C4D4060CD018239E04C4071033E3F8C0C4D4060CD018239E04C40B779E3A4300B4D40FED137691ADE4C40B779E3A4300B4D40
51473	18494	58.492344000000003	58.532705999999997	57.805264999999999	57.789287999999999	Заречная	0103000020E61000000100000005000000E030D120053F4D400890A16307E54C40E030D120053F4D4085CE6BEC12E74C400531D0B52F444D4085CE6BEC12E74C400531D0B52F444D400890A16307E54C40E030D120053F4D400890A16307E54C40
52195	18494	58.492344000000003	58.532705999999997	57.805264999999999	57.789287999999999	Железнодорожная	0103000020E61000000100000005000000E030D120053F4D400890A16307E54C40E030D120053F4D4085CE6BEC12E74C400531D0B52F444D4085CE6BEC12E74C400531D0B52F444D400890A16307E54C40E030D120053F4D400890A16307E54C40
52718	56376	58.341768999999999	58.375114000000004	57.869843000000003	57.853865999999996	Куйбышева	0103000020E61000000100000005000000B0E42A16BF2B4D404A95287B4BED4C40B0E42A16BF2B4D40C8D3F20357EF4C40C9224DBC03304D40C8D3F20357EF4C40C9224DBC03304D404A95287B4BED4C40B0E42A16BF2B4D404A95287B4BED4C40
51802	18202	58.007488000000002	58.043869999999998	57.873586000000003	57.847889000000002	Советская	0103000020E61000000100000005000000658EE55DF5004D40AFD172A087EC4C40658EE55DF5004D402A1F82AAD1EF4C4044A33B889D054D402A1F82AAD1EF4C4044A33B889D054D40AFD172A087EC4C40658EE55DF5004D40AFD172A087EC4C40
52105	56283	57.786403	57.805385000000001	58.144334999999998	58.135266000000001	Ленина	0103000020E61000000100000005000000F73C7FDAA8E44C406021736550114D40F73C7FDAA8E44C408655BC9179124D4030D80DDB16E74C408655BC9179124D4030D80DDB16E74C406021736550114D40F73C7FDAA8E44C406021736550114D40
52310	46177	57.895603000000001	57.916452	57.986201999999999	57.975245000000001	Гагарина	0103000020E6100000010000000500000089997D1EA3F24C40344B02D4D4FC4C4089997D1EA3F24C40F99FFCDD3BFE4C40492D944C4EF54C40F99FFCDD3BFE4C40492D944C4EF54C40344B02D4D4FC4C4089997D1EA3F24C40344B02D4D4FC4C40
54359	56534	57.418382000000001	57.440229000000002	57.786428000000001	57.769368	Ленина	0103000020E61000000100000005000000179E978A8DB54C40624B8FA67AE24C40179E978A8DB54C40505436ACA9E44C401AE0826C59B84C40505436ACA9E44C401AE0826C59B84C40624B8FA67AE24C40179E978A8DB54C40624B8FA67AE24C40
52097	56282	29.836445999999999	29.847954000000001	58.750883000000002	58.749575999999998	Казанский тракт	0103000020E61000000100000005000000B9DE365321D63D40E9EE3A1BF25F4D40B9DE365321D63D40AA0F24EF1C604D402C836A8313D93D40AA0F24EF1C604D402C836A8313D93D40E9EE3A1BF25F4D40B9DE365321D63D40E9EE3A1BF25F4D40
64541	58261	56.900503	56.913609000000001	57.367874999999998	57.356423999999997	Рязанова	0103000020E610000001000000050000009679ABAE43734C4037C1374D9FAD4C409679ABAE43734C400C022B8716AF4C40672AC423F1744C400C022B8716AF4C40672AC423F1744C4037C1374D9FAD4C409679ABAE43734C4037C1374D9FAD4C40
52089	56276	57.128289000000002	57.134971999999998	57.514744999999998	57.511158000000002	Чапаева	0103000020E61000000100000005000000E1B721C66B904C405D8B16A06DC14C40E1B721C66B904C40C763062AE3C14C4017F032C346914C40C763062AE3C14C4017F032C346914C405D8B16A06DC14C40E1B721C66B904C405D8B16A06DC14C40
51529	48933	56.048980999999998	56.062688999999999	57.196984999999998	57.186373000000003	Центральная	0103000020E610000001000000050000000C90680245064C40C0ED0912DB974C400C90680245064C40BA66F2CD36994C40D368723106084C40BA66F2CD36994C40D368723106084C40C0ED0912DB974C400C90680245064C40C0ED0912DB974C40
52084	56274	55.977043999999999	55.980708999999997	57.292718000000001	57.290914000000001	Октябрьская	0103000020E6100000010000000500000063601DC70FFD4B406AF981AB3CA54C4063601DC70FFD4B40AB798EC877A54C4049F25CDF87FD4B40AB798EC877A54C4049F25CDF87FD4B406AF981AB3CA54C4063601DC70FFD4B406AF981AB3CA54C40
51699	56240	56.892983999999998	57.020617000000001	57.460403999999997	57.375382999999999	Просвещения	0103000020E61000000100000005000000F6ECB94C4D724C40B83CD68C0CB04C40F6ECB94C4D724C404A79AD84EEBA4C40EE5EEE93A3824C404A79AD84EEBA4C40EE5EEE93A3824C40B83CD68C0CB04C40F6ECB94C4D724C40B83CD68C0CB04C40
51705	56240	56.892426999999998	57.020949000000002	57.461860999999999	57.369413999999999	Голованова	0103000020E61000000100000005000000A088450C3B724C409F573CF548AF4C40A088450C3B724C402026E1421EBB4C4024F1F274AE824C402026E1421EBB4C4024F1F274AE824C409F573CF548AF4C40A088450C3B724C409F573CF548AF4C40
9845	13907	55.571652	55.592475	56.559255999999998	56.546331000000002	Клубная	0103000020E61000000100000005000000B4588AE42BC94B403FE5982CEE454C40B4588AE42BC94B40BF0B5BB395474C404B598638D6CB4B40BF0B5BB395474C404B598638D6CB4B403FE5982CEE454C40B4588AE42BC94B403FE5982CEE454C40
53862	13571	55.483302999999999	55.512138999999998	56.423316	56.412547000000004	Победы	0103000020E61000000100000005000000838769DFDCBD4B400E881057CE344C40838769DFDCBD4B40D0EFFB372F364C40C90050C58DC14B40D0EFFB372F364C40C90050C58DC14B400E881057CE344C40838769DFDCBD4B400E881057CE344C40
53888	14649	54.860751999999998	54.878340999999999	56.425412000000001	56.403855999999998	А. Игнатьева	0103000020E61000000100000005000000B9FB1C1F2D6E4B408D25AC8DB1334C40B9FB1C1F2D6E4B40B9A981E673364C4033DE567A6D704B40B9A981E673364C4033DE567A6D704B408D25AC8DB1334C40B9FB1C1F2D6E4B408D25AC8DB1334C40
52267	14617	54.756475999999999	54.801023000000001	56.506126000000002	56.480902	Центральная	0103000020E61000000100000005000000BD1AA034D4604B405E4A5D328E3D4C40BD1AA034D4604B40E1D39CBCC8404C40022CF2EB87664B40E1D39CBCC8404C40022CF2EB87664B405E4A5D328E3D4C40BD1AA034D4604B405E4A5D328E3D4C40
52252	13522	55.593221	55.608806000000001	56.459212999999998	56.451124999999998	 Заречная	0103000020E6100000010000000500000074266DAAEECB4B4039B4C876BE394C4074266DAAEECB4B40F372D87DC73A4C40E6CDE15AEDCD4B40F372D87DC73A4C40E6CDE15AEDCD4B4039B4C876BE394C4074266DAAEECB4B4039B4C876BE394C40
52102	14225	55.179834	55.218946000000003	56.466410000000003	56.438173999999997	Школьная	0103000020E61000000100000005000000BC5AEECC04974B408FFAEB1516384C40BC5AEECC04974B408143A852B33B4C4086CB2A6C069C4B408143A852B33B4C4086CB2A6C069C4B408FFAEB1516384C40BC5AEECC04974B408FFAEB1516384C40
53870	13833	55.794640999999999	55.825426	56.458362999999999	56.443593	Дружбы	0103000020E61000000100000005000000C687D9CBB6E54B4005DEC9A7C7384C40C687D9CBB6E54B40255987A3AB3A4C4051A2258FA7E94B40255987A3AB3A4C4051A2258FA7E94B4005DEC9A7C7384C40C687D9CBB6E54B4005DEC9A7C7384C40
53443	14147	55.245303	55.264068999999999	56.350172999999998	56.346736	Центральная	0103000020E610000001000000050000002B4EB516669F4B40452C62D8612C4C402B4EB516669F4B409A780778D22C4C4097715303CDA14B409A780778D22C4C4097715303CDA14B40452C62D8612C4C402B4EB516669F4B40452C62D8612C4C40
52301	56337	55.623548	55.631013000000003	56.512171000000002	56.500855000000001	 Центральная	0103000020E610000001000000050000003CBEBD6BD0CF4B40E08442041C404C403CBEBD6BD0CF4B40D57ABFD18E414C40E92CB308C5D04B40D57ABFD18E414C40E92CB308C5D04B40E08442041C404C403CBEBD6BD0CF4B40E08442041C404C40
53446	14768	54.861308999999999	54.883541999999998	56.614817000000002	56.598151000000001	Центральная	0103000020E610000001000000050000000F60915F3F6E4B40EC884336904C4C400F60915F3F6E4B402E03CE52B24E4C403B527DE717714B402E03CE52B24E4C403B527DE717714B40EC884336904C4C400F60915F3F6E4B40EC884336904C4C40
52031	14567	54.860787999999999	54.891123999999998	56.519748999999997	56.488754999999998	Школьная	0103000020E6100000010000000500000006651A4D2E6E4B40D4601A868F3E4C4006651A4D2E6E4B4079909E2287424C402157EA5910724B4079909E2287424C402157EA5910724B40D4601A868F3E4C4006651A4D2E6E4B40D4601A868F3E4C40
51692	13226	55.540004000000003	55.614249999999998	56.447533	56.4129	Школьная	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
64557	13226	55.540004000000003	55.614249999999998	56.447533	56.4129	Центральная	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
52026	13226	55.540004000000003	55.614249999999998	56.447533	56.4129	Трактовая	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
51693	13226	55.540004000000003	55.614249999999998	56.447533	56.4129	Ленина	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
52189	13226	55.540004000000003	55.614249999999998	56.447533	56.4129	Комсомольская	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
52124	13226	55.540004000000003	55.614249999999998	56.447533	56.4129	Карла Маркса	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
51794	13226	55.540004000000003	55.614249999999998	56.447533	56.4129	Гагарина	0103000020E61000000100000005000000C7DADFD91EC54B405B423EE8D9344C40C7DADFD91EC54B40BD70E7C248394C40B4C876BE9FCE4B40BD70E7C248394C40B4C876BE9FCE4B405B423EE8D9344C40C7DADFD91EC54B405B423EE8D9344C40
53128	32579	55.155929999999998	55.179662999999998	56.362845	56.344391000000002	Садовая	0103000020E610000001000000050000008E3BA583F5934B40B4041901152C4C408E3BA583F5934B40314278B4712E4C408FA67A32FF964B40314278B4712E4C408FA67A32FF964B40B4041901152C4C408E3BA583F5934B40B4041901152C4C40
52693	32564	55.407888999999997	55.434102000000003	56.393847999999998	56.383597999999999	Школьная	0103000020E61000000100000005000000F6B2EDB435B44B40CF6740BD19314C40F6B2EDB435B44B4029CC7B9C69324C40699082A790B74B4029CC7B9C69324C40699082A790B74B40CF6740BD19314C40F6B2EDB435B44B40CF6740BD19314C40
52120	47663	55.000197999999997	55.017059000000003	56.470835000000001	56.464858	Пионерская	0103000020E6100000010000000500000026C3F17C06804B4059A48977803B4C4026C3F17C06804B40F5673F52443C4C401E8D43FD2E824B40F5673F52443C4C401E8D43FD2E824B4059A48977803B4C4026C3F17C06804B4059A48977803B4C40
52255	13757	55.647030000000001	55.663936	56.538356	56.533135000000001	Пилорамная	0103000020E61000000100000005000000F4C308E1D1D24B402EAD86C43D444C40F4C308E1D1D24B407DCD72D9E8444C408B51D7DAFBD44B407DCD72D9E8444C408B51D7DAFBD44B402EAD86C43D444C40F4C308E1D1D24B402EAD86C43D444C40
53878	13924	55.334766000000002	55.374265000000001	56.675404999999998	56.659370000000003	Новая	0103000020E6100000010000000500000008E8BE9CD9AA4B4055FB743C66544C4008E8BE9CD9AA4B400647C9AB73564C40CB845FEAE7AF4B400647C9AB73564C40CB845FEAE7AF4B4055FB743C66544C4008E8BE9CD9AA4B4055FB743C66544C40
52261	14515	54.999515000000002	55.044286999999997	56.689185000000002	56.659365000000001	Школьная	0103000020E61000000100000005000000446E861BF07F4B404390831266544C40446E861BF07F4B4067F2CD3637584C40A8514832AB854B4067F2CD3637584C40A8514832AB854B404390831266544C40446E861BF07F4B404390831266544C40
52232	56318	55.072781999999997	55.106648	56.372337999999999	56.353819000000001	Советская	0103000020E6100000010000000500000065DEAAEB50894B400ADAE4F0492D4C4065DEAAEB50894B406E8786C5A82F4C40871744A4A68D4B406E8786C5A82F4C40871744A4A68D4B400ADAE4F0492D4C4065DEAAEB50894B400ADAE4F0492D4C40
52256	14292	55.183633999999998	55.211615999999999	56.532483999999997	56.518652000000003	Центральная	0103000020E610000001000000050000008237A45181974B40A400513063424C408237A45181974B4056D28A6F28444C40B9A7AB3B169B4B4056D28A6F28444C40B9A7AB3B169B4B40A400513063424C408237A45181974B40A400513063424C40
64608	58293	55.178477000000001	55.196542000000001	56.691054000000001	56.672586000000003	Центральная	0103000020E610000001000000050000004A0B9755D8964B40ADDF4C4C17564C404A0B9755D8964B408FE21C7574584C402D25CB4928994B408FE21C7574584C402D25CB4928994B40ADDF4C4C17564C404A0B9755D8964B40ADDF4C4C17564C40
52087	14376	55.076546	55.111866999999997	56.463405999999999	56.444935999999998	Центральная	0103000020E61000000100000005000000DF516342CC894B401268B0A9F3384C40DF516342CC894B40956247E3503B4C40354069A8518E4B40956247E3503B4C40354069A8518E4B401268B0A9F3384C40DF516342CC894B401268B0A9F3384C40
53441	13624	55.341090000000001	55.377471999999997	56.572136	56.550375000000003	Центральная	0103000020E610000001000000050000000F7F4DD6A8AB4B409CC420B072464C400F7F4DD6A8AB4B40A06EA0C03B494C40EE93A30051B04B40A06EA0C03B494C40EE93A30051B04B409CC420B072464C400F7F4DD6A8AB4B409CC420B072464C40
63484	33136	55.439706999999999	55.474454000000001	56.532152000000004	56.515081000000002	Центральная	0103000020E610000001000000050000004069A85148B84B403FE5982CEE414C404069A85148B84B402140868E1D444C406BBA9EE8BABC4B402140868E1D444C406BBA9EE8BABC4B403FE5982CEE414C404069A85148B84B403FE5982CEE414C40
51591	14017	55.310467000000003	55.339303000000001	56.382221999999999	56.368209999999998	40 лет Победы	0103000020E610000001000000050000005EBEF561BDA74B40B3075A81212F4C405EBEF561BDA74B40E6E786A6EC304C40A437DC476EAB4B40E6E786A6EC304C40A437DC476EAB4B40B3075A81212F4C405EBEF561BDA74B40B3075A81212F4C40
52188	14700	54.999631999999998	55.039382000000003	56.614485000000002	56.575617000000001	Зеленая	0103000020E610000001000000050000007D04FEF0F37F4B40C5025FD1AD494C407D04FEF0F37F4B40F870C971A74E4C408A0629780A854B40F870C971A74E4C408A0629780A854B40C5025FD1AD494C407D04FEF0F37F4B40C5025FD1AD494C40
51685	14430	55.068227	55.138286999999998	56.759168000000003	56.720731000000001	Школьная	0103000020E6100000010000000500000023DA8EA9BB884B40501BD5E9405C4C4023DA8EA9BB884B40BA15C26A2C614C40213B6F63B3914B40BA15C26A2C614C40213B6F63B3914B40501BD5E9405C4C4023DA8EA9BB884B40501BD5E9405C4C40
53442	13785	55.706856999999999	55.739663999999998	56.485956999999999	56.471088999999999	Школьная	0103000020E610000001000000050000006EF9484A7ADA4B40AF40F4A44C3C4C406EF9484A7ADA4B409221C7D6333E4C40A703594FADDE4B409221C7D6333E4C40A703594FADDE4B40AF40F4A44C3C4C406EF9484A7ADA4B40AF40F4A44C3C4C40
52688	13699	55.572865	55.618023000000001	56.504814000000003	56.493650000000002	Центральная	0103000020E61000000100000005000000F302ECA353C94B40D0D556EC2F3F4C40F302ECA353C94B400F48C2BE9D404C408196AE601BCF4B400F48C2BE9D404C408196AE601BCF4B40D0D556EC2F3F4C40F302ECA353C94B40D0D556EC2F3F4C40
52313	2264	55.361086999999998	55.3782	59.357512	59.345309	Центральная	0103000020E6100000010000000500000060014C1938AE4B40DA01D71533AC4D4060014C1938AE4B40BAF605F4C2AD4D4071AC8BDB68B04B40BAF605F4C2AD4D4071AC8BDB68B04B40DA01D71533AC4D4060014C1938AE4B40DA01D71533AC4D40
52244	45549	54.362430000000003	54.399476	59.138496000000004	59.129899000000002	Школьная	0103000020E610000001000000050000006E8B321B642E4B403D64CA87A0904D406E8B321B642E4B403C50A73CBA914D40B9C4910722334B403C50A73CBA914D40B9C4910722334B403D64CA87A0904D406E8B321B642E4B403D64CA87A0904D40
53703	473	54.224440000000001	54.241840000000003	59.108472999999996	59.097876999999997	Школьная	0103000020E6100000010000000500000006F52D73BA1C4B40EA03C93B878C4D4006F52D73BA1C4B40DFBF7971E28D4D40AD6EF59CF41E4B40DFBF7971E28D4D40AD6EF59CF41E4B40EA03C93B878C4D4006F52D73BA1C4B40EA03C93B878C4D40
54346	56532	54.846792000000001	54.874667000000002	59.196812999999999	59.181727000000002	Медицинская	0103000020E61000000100000005000000D94125AE636C4B406DE690D442974D40D94125AE636C4B40BD361B2B31994D40FAF19716F56F4B40BD361B2B31994D40FAF19716F56F4B406DE690D442974D40D94125AE636C4B406DE690D442974D40
53154	1668	54.743386999999998	54.762405000000001	58.768819000000001	58.763621000000001	Молодежная	0103000020E61000000100000005000000C2A2224E275F4B40F8C43A55BE614D40C2A2224E275F4B408FC536A968624D4048A7AE7C96614B408FC536A968624D4048A7AE7C96614B40F8C43A55BE614D40C2A2224E275F4B40F8C43A55BE614D40
52109	46297	54.678474999999999	54.728520000000003	58.990735000000001	58.974165999999997	Сазонова	0103000020E61000000100000005000000A913D044D8564B400470B378B17C4D40A913D044D8564B4054008C67D07E4D40B03DB324405D4B4054008C67D07E4D40B03DB324405D4B400470B378B17C4D40A913D044D8564B400470B378B17C4D40
64631	58307	54.285497999999997	54.297669999999997	59.049712	59.045231999999999	Центральная	0103000020E610000001000000050000006589CE328B244B40C85D8429CA854D406589CE328B244B40001C7BF65C864D400A80F10C1A264B40001C7BF65C864D400A80F10C1A264B40C85D8429CA854D406589CE328B244B40C85D8429CA854D40
53708	903	54.062930999999999	54.094794999999998	58.943859000000003	58.930579000000002	Транспортная	0103000020E61000000100000005000000C9737D1F0E084B4015AC71361D774D40C9737D1F0E084B408484285FD0784D408369183E220C4B408484285FD0784D408369183E220C4B4015AC71361D774D40C9737D1F0E084B4015AC71361D774D40
52290	1778	54.686703999999999	54.707121999999998	58.672634000000002	58.659875999999997	Полевая	0103000020E610000001000000050000002504ABEAE5574B4028B517D176544D402504ABEAE5574B40BE16F4DE18564D401C2444F9825A4B40BE16F4DE18564D401C2444F9825A4B4028B517D176544D402504ABEAE5574B4028B517D176544D40
64769	58342	54.455368999999997	54.476004000000003	58.898578999999998	58.890321999999998	Центральная	0103000020E610000001000000050000005D4E0988493A4B4064744012F6714D405D4E0988493A4B40AAEFFCA204734D40F261F6B2ED3C4B40AAEFFCA204734D40F261F6B2ED3C4B4064744012F6714D405D4E0988493A4B4064744012F6714D40
52953	1316	54.905254999999997	54.920921	59.078164000000001	59.074745999999998	Садовая	0103000020E610000001000000050000002EC55565DF734B40DFC0E44691894D402EC55565DF734B40BEDC2747018A4D408D9944BDE0754B40BEDC2747018A4D408D9944BDE0754B40DFC0E44691894D402EC55565DF734B40DFC0E44691894D40
52432	1811	54.440161000000003	54.469455000000004	58.677433999999998	58.656880000000001	Школьная	0103000020E61000000100000005000000C2FC153257384B40C0B2D2A414544D40C2FC153257384B4067994528B6564D40CBF8F719173C4B4067994528B6564D40CBF8F719173C4B40C0B2D2A414544D40C2FC153257384B40C0B2D2A414544D40
51537	2381	54.557794999999999	54.586649000000001	58.9754	58.957087999999999	Голева	0103000020E61000000100000005000000A86F99D365474B4070B20DDC817A4D40A86F99D365474B405B423EE8D97C4D40959D7E50174B4B405B423EE8D97C4D40959D7E50174B4B4070B20DDC817A4D40A86F99D365474B4070B20DDC817A4D40
54230	56506	54.38955	54.412267999999997	59.181598000000001	59.171905000000002	Центральная	0103000020E6100000010000000500000012143FC6DC314B406B82A8FB00964D4012143FC6DC314B406F826F9A3E974D40FA97A432C5344B406F826F9A3E974D40FA97A432C5344B406B82A8FB00964D4012143FC6DC314B406B82A8FB00964D40
52121	56286	54.866196000000002	54.891466000000001	59.222836000000001	59.216304999999998	Центральная	0103000020E6100000010000000500000088F6B182DF6E4B400B7BDAE1AF9B4D4088F6B182DF6E4B408C2FDAE3859C4D407BBFD18E1B724B408C2FDAE3859C4D407BBFD18E1B724B400B7BDAE1AF9B4D4088F6B182DF6E4B400B7BDAE1AF9B4D40
54143	121	54.561433999999998	54.574648000000003	59.073580999999997	59.064219000000001	Степана Караваева	0103000020E61000000100000005000000656EBE11DD474B401364045438884D40656EBE11DD474B40B14D2A1A6B894D401D5BCF108E494B40B14D2A1A6B894D401D5BCF108E494B401364045438884D40656EBE11DD474B401364045438884D40
52311	45748	54.169822000000003	54.190725999999998	59.015743000000001	59.007666999999998	Центральная	0103000020E61000000100000005000000171230BABC154B401421753BFB804D40171230BABC154B400A12DBDD03824D409A3FA6B569184B400A12DBDD03824D409A3FA6B569184B401421753BFB804D40171230BABC154B401421753BFB804D40
53716	1369	54.700600999999999	54.712206999999999	59.167763999999998	59.159959000000001	Колхозная	0103000020E61000000100000005000000BF45274BAD594B40B6D9588979944D40BF45274BAD594B401BB96E4A79954D40BB7D5699295B4B401BB96E4A79954D40BB7D5699295B4B40B6D9588979944D40BF45274BAD594B40B6D9588979944D40
54493	2039	55.081774000000003	55.107743999999997	59.274982000000001	59.264727000000001	Центральная	0103000020E61000000100000005000000E1D40792778A4B4021AF0793E2A14D40E1D40792778A4B408D7E349C32A34D408C2B2E8ECA8D4B408D7E349C32A34D408C2B2E8ECA8D4B4021AF0793E2A14D40E1D40792778A4B4021AF0793E2A14D40
52281	45665	54.314343000000001	54.330962	59.117891999999998	59.110256	Мира	0103000020E61000000100000005000000FF5C34643C284B4009185DDE1C8E4D40FF5C34643C284B40E23AC615178F4D40001C7BF65C2A4B40E23AC615178F4D40001C7BF65C2A4B4009185DDE1C8E4D40FF5C34643C284B4009185DDE1C8E4D40
51538	2470	54.711739999999999	54.738869000000001	59.025706999999997	59.015774999999998	Зеленая	0103000020E61000000100000005000000A5A0DB4B1A5B4B40158C4AEA04824D40A5A0DB4B1A5B4B409E23F25D4A834D409D836742935E4B409E23F25D4A834D409D836742935E4B40158C4AEA04824D40A5A0DB4B1A5B4B40158C4AEA04824D40
52211	45983	54.682732999999999	54.709601999999997	58.729588	58.713915999999998	Попова	0103000020E61000000100000005000000327381CB63574B40AA0B7899615B4D40327381CB63574B40EBC6BB23635D4D408D96033DD45A4B40EBC6BB23635D4D408D96033DD45A4B40AA0B7899615B4D40327381CB63574B40AA0B7899615B4D40
52135	418	54.149143000000002	54.190348	59.134003999999997	59.120322000000002	Ленина	0103000020E61000000100000005000000B3B6291E17134B40A27E17B6668F4D40B3B6291E17134B403FC4060B27914D40F46DC1525D184B403FC4060B27914D40F46DC1525D184B40A27E17B6668F4D40B3B6291E17134B40A27E17B6668F4D40
52193	1270	54.873157999999997	54.906323999999998	59.116413999999999	59.106107000000002	Центральная	0103000020E61000000100000005000000D11E2FA4C36F4B40377007EA948D4D40D11E2FA4C36F4B40F56569A7E68E4D403ACAC16C02744B40F56569A7E68E4D403ACAC16C02744B40377007EA948D4D40D11E2FA4C36F4B40377007EA948D4D40
54282	56520	54.755110000000002	54.776823	59.202762	59.195394	Дружбы	0103000020E61000000100000005000000F870C971A7604B40D5EAABAB02994D40F870C971A7604B408F6FEF1AF4994D40EBE3A1EF6E634B408F6FEF1AF4994D40EBE3A1EF6E634B40D5EAABAB02994D40F870C971A7604B40D5EAABAB02994D40
52971	365	54.501632999999998	54.526615	59.200315000000003	59.180574	Центральная	0103000020E6100000010000000500000014CC988235404B400341800C1D974D4014CC988235404B40FAF202ECA3994D40A14ACD1E68434B40FAF202ECA3994D40A14ACD1E68434B400341800C1D974D4014CC988235404B400341800C1D974D40
52162	40406	54.355620999999999	54.379713000000002	59.101134999999999	59.088414999999998	Медицинская	0103000020E61000000100000005000000AA622AFD842D4B40E8BCC62E518B4D40AA622AFD842D4B4090BDDEFDF18C4D40DB6E826F9A304B4090BDDEFDF18C4D40DB6E826F9A304B40E8BCC62E518B4D40AA622AFD842D4B40E8BCC62E518B4D40
52099	1216	54.766043000000003	54.791097000000001	59.113346999999997	59.100940999999999	Советская	0103000020E61000000100000005000000352A70B20D624B40ABE97AA2EB8C4D40352A70B20D624B40C30C8D27828E4D405B7B9FAA42654B40C30C8D27828E4D405B7B9FAA42654B40ABE97AA2EB8C4D40352A70B20D624B40ABE97AA2EB8C4D40
54522	45723	54.609413000000004	54.622985999999997	59.031365999999998	59.026341000000002	Центральная	0103000020E61000000100000005000000EE60C43E014E4B40A0C552245F834D40EE60C43E014E4B40691A14CD03844D40D4EE5701BE4F4B40691A14CD03844D40D4EE5701BE4F4B40A0C552245F834D40EE60C43E014E4B40A0C552245F834D40
64376	45949	54.674567000000003	54.695515999999998	59.190328999999998	59.164115000000002	Центральная	0103000020E61000000100000005000000FDFA213658564B403BE466B801954D40FDFA213658564B407D3D5FB35C984D4020EC14AB06594B407D3D5FB35C984D4020EC14AB06594B403BE466B801954D40FDFA213658564B403BE466B801954D40
54631	56547	53.934579999999997	53.954684	58.935130000000001	58.926862999999997	Транспортная	0103000020E6100000010000000500000072BF4351A0F74A40AC6F6072A3764D4072BF4351A0F74A4016C1FF56B2774D40DA01D71533FA4A4016C1FF56B2774D40DA01D71533FA4A40AC6F6072A3764D4072BF4351A0F74A40AC6F6072A3764D40
52209	56307	54.634790000000002	54.680855999999999	58.841780999999997	58.827055000000001	Центральная	0103000020E61000000100000005000000F7E978CC40514B40247F30F0DC694D40F7E978CC40514B4074B2D47ABF6B4D4087A4164A26574B4074B2D47ABF6B4D4087A4164A26574B40247F30F0DC694D40F7E978CC40514B40247F30F0DC694D40
51827	56248	54.315492999999996	54.346997000000002	58.936318999999997	58.913665000000002	Октябрьская	0103000020E61000000100000005000000F78E1A1362284B40FB3F87F9F2744D40F78E1A1362284B40CCCF0D4DD9774D40B267CF656A2C4B40CCCF0D4DD9774D40B267CF656A2C4B40FB3F87F9F2744D40F78E1A1362284B40FB3F87F9F2744D40
54276	56517	55.056145000000001	55.073886000000002	59.242004999999999	59.227660999999998	Школьная	0103000020E61000000100000005000000BE6A65C22F874B408EC9E2FE239D4D40BE6A65C22F874B40F73B1405FA9E4D40EED0B01875894B40F73B1405FA9E4D40EED0B01875894B408EC9E2FE239D4D40BE6A65C22F874B408EC9E2FE239D4D40
64577	1107	54.084994000000002	54.095154000000001	59.008648999999998	59.004362999999998	Центральная	0103000020E61000000100000005000000992D5915E10A4B40FE277FF78E804D40992D5915E10A4B40511212691B814D40B30A9B012E0C4B40511212691B814D40B30A9B012E0C4B40FE277FF78E804D40992D5915E10A4B40FE277FF78E804D40
52282	527	54.103248000000001	54.118582000000004	59.114913000000001	59.107807000000001	Центральная	0103000020E610000001000000050000004FB0FF3A370D4B40D3A3A99ECC8D4D404FB0FF3A370D4B4050711C78B58E4D4078F2E9B12D0F4B4050711C78B58E4D4078F2E9B12D0F4B40D3A3A99ECC8D4D404FB0FF3A370D4B40D3A3A99ECC8D4D40
51713	32491	54.467910000000003	54.511927	59.148262000000003	59.135337999999997	Ленина	0103000020E6100000010000000500000056BC9179E43B4B40F9F36DC152914D4056BC9179E43B4B40AA9ECC3FFA924D403E78EDD286414B40AA9ECC3FFA924D403E78EDD286414B40F9F36DC152914D4056BC9179E43B4B40F9F36DC152914D40
54164	1499	54.678860999999998	54.694591000000003	59.136297999999996	59.128939000000003	Колхозная	0103000020E61000000100000005000000D2C3D0EAE4564B40E816BA1281904D40D2C3D0EAE4564B404E417E3672914D40488C9E5BE8584B404E417E3672914D40488C9E5BE8584B40E816BA1281904D40D2C3D0EAE4564B40E816BA1281904D40
63741	58125	55.654018000000001	55.699545000000001	58.144392000000003	58.131478999999999	Железнодорожная	0103000020E61000000100000005000000677FA0DCB6D34B402E8ECA4DD4104D40677FA0DCB6D34B40EBE6E26F7B124D40488AC8B08AD94B40EBE6E26F7B124D40488AC8B08AD94B402E8ECA4DD4104D40677FA0DCB6D34B402E8ECA4DD4104D40
52199	56304	55.706919999999997	55.74756	58.147554999999997	58.135646000000001	Северная	0103000020E61000000100000005000000B471C45A7CDA4B40A7EA1ED95C114D40B471C45A7CDA4B403EAE0D15E3124D401DE6CB0BB0DF4B403EAE0D15E3124D401DE6CB0BB0DF4B40A7EA1ED95C114D40B471C45A7CDA4B40A7EA1ED95C114D40
52685	47074	55.560215999999997	55.589367000000003	58.051836000000002	58.037802999999997	Совхозная	0103000020E6100000010000000500000014596B28B5C74B4068588CBAD6044D4014596B28B5C74B40B360E28FA2064D40BB2BBB6070CB4B40B360E28FA2064D40BB2BBB6070CB4B4068588CBAD6044D4014596B28B5C74B4068588CBAD6044D40
51460	13002	55.930779999999999	55.987167999999997	58.190441999999997	58.165940999999997	Советская	0103000020E61000000100000005000000ACE28DCC23F74B406308008E3D154D40ACE28DCC23F74B4075E4486760184D4030D461855BFE4B4075E4486760184D4030D461855BFE4B406308008E3D154D40ACE28DCC23F74B406308008E3D154D40
81120	12477	55.841883000000003	55.874257999999998	58.105477	58.077961999999999	переулок Клубный	0103000020E61000000100000005000000790778D2C2EB4B40562AA8A8FA094D40790778D2C2EB4B4077BD3445800D4D401822A7AFE7EF4B4077BD3445800D4D401822A7AFE7EF4B40562AA8A8FA094D40790778D2C2EB4B40562AA8A8FA094D40
81119	12477	55.841883000000003	55.874257999999998	58.105477	58.077961999999999	Строителей	0103000020E61000000100000005000000790778D2C2EB4B40562AA8A8FA094D40790778D2C2EB4B4077BD3445800D4D401822A7AFE7EF4B4077BD3445800D4D401822A7AFE7EF4B40562AA8A8FA094D40790778D2C2EB4B40562AA8A8FA094D40
81122	62086	55.897129999999997	55.933025999999998	58.067067999999999	58.054855000000003	Центральная	0103000020E610000001000000050000005721E527D5F24B40D482177D05074D405721E527D5F24B40D74D29AF95084D40AA285E656DF74B40D74D29AF95084D40AA285E656DF74B40D482177D05074D405721E527D5F24B40D482177D05074D40
81109	56313	55.635486	55.670088999999997	58.080052000000002	58.060578999999997	Циолковского	0103000020E610000001000000050000006E88F19A57D14B4085E97B0DC1074D406E88F19A57D14B405DFDD8243F0A4D406534F279C5D54B405DFDD8243F0A4D406534F279C5D54B4085E97B0DC1074D406E88F19A57D14B4085E97B0DC1074D40
53170	9759	57.340704000000002	57.362273000000002	60.132424	60.123370999999999	Первомайская	0103000020E61000000100000005000000E6CE4C309CAB4C402D23F59ECA0F4E40E6CE4C309CAB4C404E9A0645F3104E40A69C2FF65EAE4C404E9A0645F3104E40A69C2FF65EAE4C402D23F59ECA0F4E40E6CE4C309CAB4C402D23F59ECA0F4E40
53858	10260	56.771144999999997	56.802208999999998	60.340012000000002	60.325747	Центральная	0103000020E61000000100000005000000A9BC1DE1B4624C4093E2E313B2294E40A9BC1DE1B4624C40B01F6283852B4E4047C7D5C8AE664C40B01F6283852B4E4047C7D5C8AE664C4093E2E313B2294E40A9BC1DE1B4624C4093E2E313B2294E40
52083	10180	57.764395	57.792036000000003	60.125661000000001	60.116858000000001	Победы	0103000020E61000000100000005000000EB1C03B2D7E14C405323F433F50E4E40EB1C03B2D7E14C40FBB0DEA815104E4099A0866F61E54C40FBB0DEA815104E4099A0866F61E54C405323F433F50E4E40EB1C03B2D7E14C405323F433F50E4E40
52159	56294	57.601394999999997	57.611519000000001	60.259993000000001	60.255792	Промышленная	0103000020E610000001000000050000002C7DE882FACC4C400A4AD1CABD204E402C7DE882FACC4C402F185C7347214E40FAF02C4146CE4C402F185C7347214E40FAF02C4146CE4C400A4AD1CABD204E402C7DE882FACC4C400A4AD1CABD204E40
53437	46315	57.076348000000003	57.086409000000003	60.447246999999997	60.441201	Геологов	0103000020E61000000100000005000000B98E71C5C5894C4033FB3C4679384E40B98E71C5C5894C40F71DC3633F394E40408A3A730F8B4C40F71DC3633F394E40408A3A730F8B4C4033FB3C4679384E40B98E71C5C5894C4033FB3C4679384E40
52681	10518	57.961665000000004	57.997776999999999	60.454267000000002	60.437282000000003	Силовая	0103000020E610000001000000050000009B5AB6D617FB4C40939048DBF8374E409B5AB6D617FB4C407653CA6B253A4E40BAD91F28B7FF4C407653CA6B253A4E40BAD91F28B7FF4C40939048DBF8374E409B5AB6D617FB4C40939048DBF8374E40
51589	9164	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Школьная	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
51681	9164	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Спортивная	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
51789	9164	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Советская	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
51679	9164	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Куйбышева	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
53412	9164	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Комсомольская	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
51455	9164	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	Дзержинского	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
52250	9164	57.010393999999998	57.108130000000003	60.430613000000001	60.374443999999997	7-го Ноября	0103000020E610000001000000050000008D09319754814C407A17EFC7ED2F4E408D09319754814C40C11DA8531E374E40B6DB2E34D78D4C40C11DA8531E374E40B6DB2E34D78D4C407A17EFC7ED2F4E408D09319754814C407A17EFC7ED2F4E40
52253	11405	58.570461999999999	58.601795000000003	60.483462000000003	60.469428999999998	Центральная	0103000020E610000001000000050000002DCE18E604494D40A165DD3F163C4E402DCE18E604494D40EC6D3315E23D4E40BBF2599E074D4D40EC6D3315E23D4E40BBF2599E074D4D40A165DD3F163C4E402DCE18E604494D40A165DD3F163C4E40
52508	10987	57.280957000000001	57.293695	60.503267000000001	60.492348999999997	Мира	0103000020E61000000100000005000000884A2366F6A34C40F19BC24A053F4E40884A2366F6A34C40F913950D6B404E40D6FF39CC97A54C40F913950D6B404E40D6FF39CC97A54C40F19BC24A053F4E40884A2366F6A34C40F19BC24A053F4E40
52248	10424	56.751669999999997	56.779221	60.366446000000003	60.360430000000001	Набережная	0103000020E6100000010000000500000031B1F9B836604C40A73FFB91222E4E4031B1F9B836604C4001E0D8B3E72E4E409FAD8383BD634C4001E0D8B3E72E4E409FAD8383BD634C40A73FFB91222E4E4031B1F9B836604C40A73FFB91222E4E40
52249	10521	56.626409000000002	56.649118000000001	60.200026999999999	60.192630000000001	Советская	0103000020E61000000100000005000000C5758C2B2E504C403F1D8F19A8184E40C5758C2B2E504C4093A8177C9A194E405A9F724C16534C4093A8177C9A194E405A9F724C16534C403F1D8F19A8184E40C5758C2B2E504C403F1D8F19A8184E40
53432	11084	57.345967999999999	57.372478000000001	60.462851000000001	60.456187999999997	Пионерская	0103000020E6100000010000000500000034BBEEAD48AC4C40F0694E5E643A4E4034BBEEAD48AC4C40E0F599B33E3B4E40603DEE5BADAF4C40E0F599B33E3B4E40603DEE5BADAF4C40F0694E5E643A4E4034BBEEAD48AC4C40F0694E5E643A4E40
52294	10907	57.272387000000002	57.283994	60.147247999999998	60.143574999999998	Новая	0103000020E61000000100000005000000836DC493DDA24C40F8C264AA60124E40836DC493DDA24C406133C005D9124E404F2157EA59A44C406133C005D9124E404F2157EA59A44C40F8C264AA60124E40836DC493DDA24C40F8C264AA60124E40
52228	8968	57.440327000000003	57.448511000000003	60.106059999999999	60.093119000000002	 Советская	0103000020E61000000100000005000000DD4598A25CB84C4070D1C952EB0B4E40DD4598A25CB84C40F6B4C35F930D4E40B972F6CE68B94C40F6B4C35F930D4E40B972F6CE68B94C4070D1C952EB0B4E40DD4598A25CB84C4070D1C952EB0B4E40
53436	11510	58.772412000000003	58.802874000000003	60.741864999999997	60.729844999999997	Северная	0103000020E61000000100000005000000DC847B65DE624D4016139B8F6B5D4E40DC847B65DE624D400586AC6EF55E4E4084674293C4664D400586AC6EF55E4E4084674293C4664D4016139B8F6B5D4E40DC847B65DE624D4016139B8F6B5D4E40
53427	10591	58.361882000000001	58.400149999999996	60.605753999999997	60.587558999999999	Гагарина	0103000020E610000001000000050000006B813D26522E4D4038BC2022354B4E406B813D26522E4D40E9B5D958894D4E4048BF7D1D38334D40E9B5D958894D4E4048BF7D1D38334D4038BC2022354B4E406B813D26522E4D4038BC2022354B4E40
53421	10067	57.631326999999999	57.649526999999999	60.031300999999999	60.023947	Новая	0103000020E61000000100000005000000780AB952CFD04C402DEBFEB110034E40780AB952CFD04C4082AAD1AB01044E403B6F63B323D34C4082AAD1AB01044E403B6F63B323D34C402DEBFEB110034E40780AB952CFD04C402DEBFEB110034E40
54191	56500	56.585607000000003	56.604652000000002	60.238653999999997	60.226976999999998	Трактовая	0103000020E6100000010000000500000083A7902BF54A4C40DBF813950D1D4E4083A7902BF54A4C40A087DA368C1E4E4002BB9A3C654D4C40A087DA368C1E4E4002BB9A3C654D4C40DBF813950D1D4E4083A7902BF54A4C40DBF813950D1D4E40
52133	31095	54.294670000000004	54.327961000000002	59.612124000000001	59.590012000000002	Ленина	0103000020E61000000100000005000000618E1EBFB7254B40B01F628385CB4D40618E1EBFB7254B40618C48145ACE4D4086AE44A0FA294B40618C48145ACE4D4086AE44A0FA294B40B01F628385CB4D40618E1EBFB7254B40B01F628385CB4D40
52043	31095	54.294670000000004	54.327961000000002	59.612124000000001	59.590012000000002	А.Хомяковой	0103000020E61000000100000005000000618E1EBFB7254B40B01F628385CB4D40618E1EBFB7254B40618C48145ACE4D4086AE44A0FA294B40618C48145ACE4D4086AE44A0FA294B40B01F628385CB4D40618E1EBFB7254B40B01F628385CB4D40
52136	31095	54.294670000000004	54.327961000000002	59.612124000000001	59.590012000000002	50 лет Октября	0103000020E61000000100000005000000618E1EBFB7254B40B01F628385CB4D40618E1EBFB7254B40618C48145ACE4D4086AE44A0FA294B40618C48145ACE4D4086AE44A0FA294B40B01F628385CB4D40618E1EBFB7254B40B01F628385CB4D40
52061	56271	54.212699000000001	54.230404	59.581966999999999	59.577666000000001	Пушкина	0103000020E610000001000000050000002A7288B8391B4B406D01A1F5F0C94D402A7288B8391B4B40F52C08E57DCA4D400D6FD6E07D1D4B40F52C08E57DCA4D400D6FD6E07D1D4B406D01A1F5F0C94D402A7288B8391B4B406D01A1F5F0C94D40
64616	58300	54.822941999999998	54.840549000000003	60.219014000000001	60.211196000000001	Молодежная	0103000020E610000001000000050000009E40D82956694B40E4857478081B4E409E40D82956694B40DEAE97A6081C4E40BFD7101C976B4B40DEAE97A6081C4E40BFD7101C976B4B40E4857478081B4E409E40D82956694B40E4857478081B4E40
51737	56242	54.974245000000003	55.009289000000003	59.951912	59.937319000000002	Ленина	0103000020E6100000010000000500000051A5660FB47C4B40B075A911FAF74D4051A5660FB47C4B40C1559E40D8F94D40359BC76130814B40C1559E40D8F94D40359BC76130814B40B075A911FAF74D4051A5660FB47C4B40B075A911FAF74D40
52219	56257	57.221516000000001	57.273015999999998	57.381948000000001	57.339227999999999	Строителей	0103000020E6100000010000000500000037C5E3A25A9C4C4099F1B6D26BAB4C4037C5E3A25A9C4C40E5620CACE3B04C4072A43330F2A24C40E5620CACE3B04C4072A43330F2A24C4099F1B6D26BAB4C4037C5E3A25A9C4C4099F1B6D26BAB4C40
51983	56257	57.221516000000001	57.273015999999998	57.381948000000001	57.339227999999999	Советская	0103000020E6100000010000000500000037C5E3A25A9C4C4099F1B6D26BAB4C4037C5E3A25A9C4C40E5620CACE3B04C4072A43330F2A24C40E5620CACE3B04C4072A43330F2A24C4099F1B6D26BAB4C4037C5E3A25A9C4C4099F1B6D26BAB4C40
63912	32569	57.311213000000002	57.334515000000003	57.442419000000001	57.432017999999999	Речная	0103000020E61000000100000005000000878BDCD3D5A74C4044A4A65D4CB74C40878BDCD3D5A74C408410902FA1B84C40BF823463D1AA4C408410902FA1B84C40BF823463D1AA4C4044A4A65D4CB74C40878BDCD3D5A74C4044A4A65D4CB74C40
54299	56526	57.344163000000002	57.374040999999998	57.378528000000003	57.358069999999998	Советская	0103000020E6100000010000000500000023BF7E880DAC4C40E0D6DD3CD5AD4C4023BF7E880DAC4C40664F029B73B04C407B2E5393E0AF4C40664F029B73B04C407B2E5393E0AF4C40E0D6DD3CD5AD4C4023BF7E880DAC4C40E0D6DD3CD5AD4C40
64478	32523	57.246434999999998	57.275342999999999	57.426363000000002	57.410910999999999	Советская	0103000020E610000001000000050000007DCB9C2E8B9F4C4088484DBB98B44C407DCB9C2E8B9F4C40BB9C121093B64C405D177E703EA34C40BB9C121093B64C405D177E703EA34C4088484DBB98B44C407DCB9C2E8B9F4C4088484DBB98B44C40
64355	33105	57.915275999999999	57.962032999999998	57.244706999999998	57.231546999999999	Средняя	0103000020E61000000100000005000000276893C327F54C40533E0455A39D4C40276893C327F54C40170D198F529F4C401D56B8E523FB4C40170D198F529F4C401D56B8E523FB4C40533E0455A39D4C40276893C327F54C40533E0455A39D4C40
52670	8628	57.487741	57.518237999999997	57.270319000000001	57.261519999999997	Юбилейная	0103000020E610000001000000050000008CF50D4C6EBE4C40FD9FC37C79A14C408CF50D4C6EBE4C40643E20D099A24C40B0C56E9F55C24C40643E20D099A24C40B0C56E9F55C24C40FD9FC37C79A14C408CF50D4C6EBE4C40FD9FC37C79A14C40
52251	33111	57.479107999999997	57.498708999999998	57.359758999999997	57.352758000000001	Центральная	0103000020E6100000010000000500000040A0336953BD4C4081B3942C27AD4C4040A0336953BD4C4088B839950CAE4C40459C4EB2D5BF4C4088B839950CAE4C40459C4EB2D5BF4C4081B3942C27AD4C4040A0336953BD4C4081B3942C27AD4C40
53369	8345	57.369943999999997	57.780825	57.406902000000002	57.304558999999998	Комсомольская	0103000020E61000000100000005000000FBAC32535AAF4C40EA5910CAFBA64C40FBAC32535AAF4C40A8565F5D15B44C401973D712F2E34C40A8565F5D15B44C401973D712F2E34C40EA5910CAFBA64C40FBAC32535AAF4C40EA5910CAFBA64C40
52032	30166	57.898145	57.935631999999998	57.424953000000002	57.395676000000002	Советская	0103000020E610000001000000050000007008556AF6F24C40F3E7DB82A5B24C407008556AF6F24C4026AB22DC64B64C40A88B14CAC2F74C4026AB22DC64B64C40A88B14CAC2F74C40F3E7DB82A5B24C407008556AF6F24C40F3E7DB82A5B24C40
63704	30166	57.898145	57.935631999999998	57.424953000000002	57.395676000000002	Первомайская	0103000020E610000001000000050000007008556AF6F24C40F3E7DB82A5B24C407008556AF6F24C4026AB22DC64B64C40A88B14CAC2F74C4026AB22DC64B64C40A88B14CAC2F74C40F3E7DB82A5B24C407008556AF6F24C40F3E7DB82A5B24C40
52101	30166	57.898145	57.935631999999998	57.424953000000002	57.395676000000002	 Карла Маркса	0103000020E610000001000000050000007008556AF6F24C40F3E7DB82A5B24C407008556AF6F24C4026AB22DC64B64C40A88B14CAC2F74C4026AB22DC64B64C40A88B14CAC2F74C40F3E7DB82A5B24C407008556AF6F24C40F3E7DB82A5B24C40
52027	56263	57.405059999999999	57.436258000000002	57.344113999999998	57.334944	Школьная	0103000020E6100000010000000500000079758E01D9B34C40E7FEEA71DFAA4C4079758E01D9B34C40410C74ED0BAC4C40274F594DD7B74C40410C74ED0BAC4C40274F594DD7B74C40E7FEEA71DFAA4C4079758E01D9B34C40E7FEEA71DFAA4C40
64275	58200	57.327409000000003	57.349364000000001	57.400424000000001	57.391252999999999	Школьная	0103000020E6100000010000000500000042B5C189E8A94C401FBB0B9414B24C4042B5C189E8A94C404A44F81741B34C402B33A5F5B7AC4C404A44F81741B34C402B33A5F5B7AC4C401FBB0B9414B24C4042B5C189E8A94C401FBB0B9414B24C40
53852	8277	57.539617999999997	57.565553000000001	57.397644999999997	57.382199999999997	Школьная	0103000020E610000001000000050000009D2ADF3312C54C40FE43FAEDEBB04C409D2ADF3312C54C407E350708E6B24C40CD936B0A64C84C407E350708E6B24C40CD936B0A64C84C40FE43FAEDEBB04C409D2ADF3312C54C40FE43FAEDEBB04C40
52111	56284	57.689205999999999	57.700803000000001	57.255429999999997	57.251491000000001	 Советская	0103000020E610000001000000050000007E1AF7E637D84C40821E6ADB30A04C407E1AF7E637D84C40693524EEB1A04C4027F8A6E9B3D94C40693524EEB1A04C4027F8A6E9B3D94C40821E6ADB30A04C407E1AF7E637D84C40821E6ADB30A04C40
51454	7956	57.625632000000003	57.683509999999998	59.107613000000001	59.076286000000003	Баумана	0103000020E6100000010000000500000061AA99B514D04C40439259BDC3894D4061AA99B514D04C40EECF4543C68D4D40963E74417DD74C40EECF4543C68D4D40963E74417DD74C40439259BDC3894D4061AA99B514D04C40439259BDC3894D40
51678	8060	57.729953000000002	57.798431999999998	59.073632000000003	59.012726999999998	Няровская	0103000020E61000000100000005000000FD4E93196FDD4C405A63D009A1814D40FD4E93196FDD4C4034F8FBC56C894D40390A100533E64C4034F8FBC56C894D40390A100533E64C405A63D009A1814D40FD4E93196FDD4C405A63D009A1814D40
52661	7523	55.177705000000003	55.193910000000002	58.709752000000002	58.700958999999997	Центральная	0103000020E61000000100000005000000F8AA9509BF964B401E6B4606B9594D40F8AA9509BF964B40A3224E27D95A4D40062FFA0AD2984B40A3224E27D95A4D40062FFA0AD2984B401E6B4606B9594D40F8AA9509BF964B401E6B4606B9594D40
52332	56354	54.938735000000001	54.958669	58.612501999999999	58.606642999999998	Советская	0103000020E61000000100000005000000274EEE7728784B4075AC527AA64D4D40274EEE7728784B40075E2D77664E4D40325871AAB57A4B40075E2D77664E4D40325871AAB57A4B4075AC527AA64D4D40274EEE7728784B4075AC527AA64D4D40
64738	58334	54.872700000000002	54.877155000000002	58.509470999999998	58.507313000000003	Маяковского	0103000020E610000001000000050000000F9C33A2B46F4B40F7EAE3A1EF404D400F9C33A2B46F4B4055A1815836414D40EE42739D46704B4055A1815836414D40EE42739D46704B40F7EAE3A1EF404D400F9C33A2B46F4B40F7EAE3A1EF404D40
64363	33008	55.144996999999996	55.182141999999999	58.484701999999999	58.464919000000002	Центральная	0103000020E610000001000000050000005182FE428F924B40FF243E77823B4D405182FE428F924B40242713B70A3E4D40309DD66D50974B40242713B70A3E4D40309DD66D50974B40FF243E77823B4D405182FE428F924B40FF243E77823B4D40
52245	6544	55.173904999999998	55.206361000000001	58.414634999999997	58.398091000000001	Молодежная	0103000020E6100000010000000500000031CEDF8442964B407DEA58A5F4324D4031CEDF8442964B4073637AC212354D40BE1589096A9A4B4073637AC212354D40BE1589096A9A4B407DEA58A5F4324D4031CEDF8442964B407DEA58A5F4324D40
64346	33001	54.951725000000003	54.975825999999998	58.731876999999997	58.719692000000002	Центральная	0103000020E610000001000000050000008FE4F21FD2794B40AF9811DE1E5C4D408FE4F21FD2794B40E8D84125AE5D4D40124BCADDE77C4B40E8D84125AE5D4D40124BCADDE77C4B40AF9811DE1E5C4D408FE4F21FD2794B40AF9811DE1E5C4D40
64417	58226	54.803691000000001	54.816070000000003	58.506740000000001	58.498840000000001	Молодежная	0103000020E61000000100000005000000768BC058DF664B40E4F736FDD93F4D40768BC058DF664B409BC937DBDC404D40959F54FB74684B409BC937DBDC404D40959F54FB74684B40E4F736FDD93F4D40768BC058DF664B40E4F736FDD93F4D40
64560	58271	54.882572000000003	54.890307	58.486804999999997	58.483497	Школьная	0103000020E61000000100000005000000C32E8A1EF8704B40685BCD3AE33D4D40C32E8A1EF8704B40BF4351A04F3E4D402F336C94F5714B40BF4351A04F3E4D402F336C94F5714B40685BCD3AE33D4D40C32E8A1EF8704B40685BCD3AE33D4D40
51790	56245	54.958947000000002	54.994672999999999	58.195118999999998	58.176150999999997	  Центральная	0103000020E6100000010000000500000075CC79C6BE7A4B402F14B01D8C164D4075CC79C6BE7A4B4003EACDA8F9184D406B9BE271517F4B4003EACDA8F9184D406B9BE271517F4B402F14B01D8C164D4075CC79C6BE7A4B402F14B01D8C164D40
52008	33000	55.207475000000002	55.256092000000002	58.534748999999998	58.505912000000002	Мира	0103000020E610000001000000050000006ADE718A8E9A4B40B55373B9C1404D406ADE718A8E9A4B40CB48BDA772444D403562669FC7A04B40CB48BDA772444D403562669FC7A04B40B55373B9C1404D406ADE718A8E9A4B40B55373B9C1404D40
52080	7313	54.821064999999997	54.861263999999998	58.501657000000002	58.488323999999999	Советская	0103000020E61000000100000005000000F3716DA818694B400BED9C66813E4D40F3716DA818694B409D67EC4B36404D406F9C14E63D6E4B409D67EC4B36404D406F9C14E63D6E4B400BED9C66813E4D40F3716DA818694B400BED9C66813E4D40
52119	7137	55.035330999999999	55.065775000000002	58.704825	58.682065000000001	Советская	0103000020E610000001000000050000007AC4E8B985844B40855FEAE74D574D407AC4E8B985844B409C33A2B4375A4D407CF2B0506B884B409C33A2B4375A4D407CF2B0506B884B40855FEAE74D574D407AC4E8B985844B40855FEAE74D574D40
51452	49150	54.971074000000002	55.019278	58.179112000000003	58.154964	Октябрьская	0103000020E610000001000000050000007AFF1F274C7C4B40570740DCD5134D407AFF1F274C7C4B401C295B24ED164D4022C495B377824B401C295B24ED164D4022C495B377824B40570740DCD5134D407AFF1F274C7C4B40570740DCD5134D40
51451	49150	54.971074000000002	55.019278	58.179112000000003	58.154964	Ленина	0103000020E610000001000000050000007AFF1F274C7C4B40570740DCD5134D407AFF1F274C7C4B401C295B24ED164D4022C495B377824B401C295B24ED164D4022C495B377824B40570740DCD5134D407AFF1F274C7C4B40570740DCD5134D40
52186	6970	55.040621999999999	55.077623000000003	58.399963	58.382199	Школьный	0103000020E61000000100000005000000C2BF081A33854B402EC896E5EB304D40C2BF081A33854B40164ED2FC31334D406E35EB8CEF894B40164ED2FC31334D406E35EB8CEF894B402EC896E5EB304D40C2BF081A33854B402EC896E5EB304D40
51448	32955	54.908856999999998	54.954357000000002	58.279874	58.258091	Энергетиков	0103000020E61000000100000005000000CEDE196D55744B402B323A2009214D40CEDE196D55744B40178046E9D2234D40B6DAC35E287A4B40178046E9D2234D40B6DAC35E287A4B402B323A2009214D40CEDE196D55744B402B323A2009214D40
51449	32955	54.908856999999998	54.954357000000002	58.279874	58.258091	Российская	0103000020E61000000100000005000000CEDE196D55744B402B323A2009214D40CEDE196D55744B40178046E9D2234D40B6DAC35E287A4B40178046E9D2234D40B6DAC35E287A4B402B323A2009214D40CEDE196D55744B402B323A2009214D40
51583	32955	54.908856999999998	54.954357000000002	58.279874	58.258091	Кирова	0103000020E61000000100000005000000CEDE196D55744B402B323A2009214D40CEDE196D55744B40178046E9D2234D40B6DAC35E287A4B40178046E9D2234D40B6DAC35E287A4B402B323A2009214D40CEDE196D55744B402B323A2009214D40
51672	32955	54.908856999999998	54.954357000000002	58.279874	58.258091	Дзержинского	0103000020E61000000100000005000000CEDE196D55744B402B323A2009214D40CEDE196D55744B40178046E9D2234D40B6DAC35E287A4B40178046E9D2234D40B6DAC35E287A4B402B323A2009214D40CEDE196D55744B402B323A2009214D40
52184	32955	54.908856999999998	54.954357000000002	58.279874	58.258091	Гагарина	0103000020E61000000100000005000000CEDE196D55744B402B323A2009214D40CEDE196D55744B40178046E9D2234D40B6DAC35E287A4B40178046E9D2234D40B6DAC35E287A4B402B323A2009214D40CEDE196D55744B402B323A2009214D40
53846	6625	54.841250000000002	54.865495000000003	58.439680000000003	58.431224	Юбилейная	0103000020E6100000010000000500000048E17A14AE6B4B400AA0185932374D4048E17A14AE6B4B40475A2A6F47384D40FFEC478AC86E4B40475A2A6F47384D40FFEC478AC86E4B400AA0185932374D4048E17A14AE6B4B400AA0185932374D40
52247	32966	55.087837	55.107205	58.190213999999997	58.175846999999997	Центральная	0103000020E610000001000000050000007B30293E3E8B4B40C30C8D2782164D407B30293E3E8B4B40E49EAEEE58184D40DD7BB8E4B88D4B40E49EAEEE58184D40DD7BB8E4B88D4B40C30C8D2782164D407B30293E3E8B4B40C30C8D2782164D40
52304	56338	54.868665999999997	54.872152	58.781573999999999	58.779069	Центральная	0103000020E61000000100000005000000D5928E72306F4B40E9297288B8634D40D5928E72306F4B40B3B3E89D0A644D400C923EADA26F4B40B3B3E89D0A644D400C923EADA26F4B40E9297288B8634D40D5928E72306F4B40E9297288B8634D40
53359	6380	54.757562999999998	54.766078999999998	58.570366999999997	58.564627000000002	Молодежная	0103000020E610000001000000050000006FD40AD3F7604B4024B891B245484D406FD40AD3F7604B40DBDB2DC901494D4081936DE00E624B40DBDB2DC901494D4081936DE00E624B4024B891B245484D406FD40AD3F7604B4024B891B245484D40
51582	6093	56.118124000000002	56.179506000000003	58.80301	58.771614	Энгельса	0103000020E61000000100000005000000B56FEEAF1E0F4C4060915F3FC4624D40B56FEEAF1E0F4C40342E1C08C9664D40C8B7770DFA164C40342E1C08C9664D40C8B7770DFA164C4060915F3FC4624D40B56FEEAF1E0F4C4060915F3FC4624D40
52113	6093	56.118124000000002	56.179506000000003	58.80301	58.771614	Ломоносова	0103000020E61000000100000005000000B56FEEAF1E0F4C4060915F3FC4624D40B56FEEAF1E0F4C40342E1C08C9664D40C8B7770DFA164C40342E1C08C9664D40C8B7770DFA164C4060915F3FC4624D40B56FEEAF1E0F4C4060915F3FC4624D40
51581	48689	55.527805000000001	55.581820999999998	58.612751000000003	58.594076999999999	Центральная	0103000020E6100000010000000500000028D53E1D8FC34B40242713B70A4C4D4028D53E1D8FC34B40B0CBF09F6E4E4D4021904B1C79CA4B40B0CBF09F6E4E4D4021904B1C79CA4B40242713B70A4C4D4028D53E1D8FC34B40242713B70A4C4D40
63691	5104	55.999186999999999	56.024160000000002	58.639349000000003	58.626088000000003	Кирова	0103000020E610000001000000050000004FCB0F5CE5FF4B408335CEA623504D404FCB0F5CE5FF4B407BDD2230D6514D4089EFC4AC17034C407BDD2230D6514D4089EFC4AC17034C408335CEA623504D404FCB0F5CE5FF4B408335CEA623504D40
64377	11108	55.612569999999998	55.621912999999999	58.769140999999998	58.764651999999998	Ленина	0103000020E610000001000000050000005F419AB168CE4B401669E21DE0614D405F419AB168CE4B40A181583673624D4087FA5DD89ACF4B40A181583673624D4087FA5DD89ACF4B401669E21DE0614D405F419AB168CE4B401669E21DE0614D40
53840	32732	55.495547000000002	55.528092999999998	58.449711999999998	58.433014	Дениса Лузина	0103000020E61000000100000005000000C25087156EBF4B40E65AB4006D374D40C25087156EBF4B40334FAE2990394D408E1F2A8D98C34B40334FAE2990394D408E1F2A8D98C34B40E65AB4006D374D40C25087156EBF4B40E65AB4006D374D40
52064	6064	56.059752000000003	56.073954000000001	58.844420999999997	58.837054999999999	 Школьная	0103000020E6100000010000000500000070EF1AF4A5074C4005FA449E246B4D4070EF1AF4A5074C401E87C1FC156C4D4046B41D5377094C401E87C1FC156C4D4046B41D5377094C4005FA449E246B4D4070EF1AF4A5074C4005FA449E246B4D40
52192	5465	55.514052	55.541198999999999	58.563730999999997	58.545414999999998	Победы	0103000020E61000000100000005000000C138B874CCC14B40B9DFA128D0454D40C138B874CCC14B40E55E605628484D405FD0420246C54B40E55E605628484D405FD0420246C54B40B9DFA128D0454D40C138B874CCC14B40B9DFA128D0454D40
53831	4996	55.649104999999999	55.665930000000003	58.554684999999999	58.540849999999999	Дзержинского	0103000020E61000000100000005000000C55565DF15D34B405305A3923A454D40C55565DF15D34B40774A07EBFF464D4070B6B9313DD54B40774A07EBFF464D4070B6B9313DD54B405305A3923A454D40C55565DF15D34B405305A3923A454D40
63478	32662	55.828327999999999	55.848233999999998	58.578747	58.570014999999998	Октябрьская	0103000020E61000000100000005000000382EE3A606EA4B405E9D6340F6484D40382EE3A606EA4B403DD4B661144A4D4079AD84EE92EC4B403DD4B661144A4D4079AD84EE92EC4B405E9D6340F6484D40382EE3A606EA4B405E9D6340F6484D40
52077	56273	55.370114999999998	55.407215000000001	58.589640000000003	58.571047	Советская	0103000020E610000001000000050000002861A6ED5FAF4B404DBD6E1118494D402861A6ED5FAF4B40EC34D252794B4D4067B8019F1FB44B40EC34D252794B4D4067B8019F1FB44B404DBD6E1118494D402861A6ED5FAF4B404DBD6E1118494D40
64471	56325	56.038659000000003	56.055124999999997	58.407767	58.397987000000001	Школьная	0103000020E61000000100000005000000195932C7F2044C40D89DEE3CF1324D40195932C7F2044C40ABB184B531344D40931804560E074C40ABB184B531344D40931804560E074C40D89DEE3CF1324D40195932C7F2044C40D89DEE3CF1324D40
52243	56325	56.038659000000003	56.055124999999997	58.407767	58.397987000000001	Центральная	0103000020E61000000100000005000000195932C7F2044C40D89DEE3CF1324D40195932C7F2044C40ABB184B531344D40931804560E074C40ABB184B531344D40931804560E074C40D89DEE3CF1324D40195932C7F2044C40D89DEE3CF1324D40
52070	32643	55.639887999999999	55.733313000000003	58.586013999999999	58.544424999999997	Чкалова	0103000020E610000001000000050000002A8D98D9E7D14B40F90FE9B7AF454D402A8D98D9E7D14B40C37FBA81024B4D40A75D4C33DDDD4B40C37FBA81024B4D40A75D4C33DDDD4B40F90FE9B7AF454D402A8D98D9E7D14B40F90FE9B7AF454D40
63893	32643	55.639887999999999	55.733313000000003	58.586013999999999	58.544424999999997	Рабочая	0103000020E610000001000000050000002A8D98D9E7D14B40F90FE9B7AF454D402A8D98D9E7D14B40C37FBA81024B4D40A75D4C33DDDD4B40C37FBA81024B4D40A75D4C33DDDD4B40F90FE9B7AF454D402A8D98D9E7D14B40F90FE9B7AF454D40
52029	32643	55.639887999999999	55.733313000000003	58.586013999999999	58.544424999999997	Механизаторов	0103000020E610000001000000050000002A8D98D9E7D14B40F90FE9B7AF454D402A8D98D9E7D14B40C37FBA81024B4D40A75D4C33DDDD4B40C37FBA81024B4D40A75D4C33DDDD4B40F90FE9B7AF454D402A8D98D9E7D14B40F90FE9B7AF454D40
52033	32643	55.639887999999999	55.733313000000003	58.586013999999999	58.544424999999997	Ленина	0103000020E610000001000000050000002A8D98D9E7D14B40F90FE9B7AF454D402A8D98D9E7D14B40C37FBA81024B4D40A75D4C33DDDD4B40C37FBA81024B4D40A75D4C33DDDD4B40F90FE9B7AF454D402A8D98D9E7D14B40F90FE9B7AF454D40
51447	32643	55.639887999999999	55.733313000000003	58.586013999999999	58.544424999999997	50 лет Октября	0103000020E610000001000000050000002A8D98D9E7D14B40F90FE9B7AF454D402A8D98D9E7D14B40C37FBA81024B4D40A75D4C33DDDD4B40C37FBA81024B4D40A75D4C33DDDD4B40F90FE9B7AF454D402A8D98D9E7D14B40F90FE9B7AF454D40
53353	32791	55.618149000000003	55.647163999999997	58.787880000000001	58.771624000000003	Аликина	0103000020E610000001000000050000000E87A5811FCF4B4084674293C4624D400E87A5811FCF4B4014967840D9644D4003931B45D6D24B4014967840D9644D4003931B45D6D24B4084674293C4624D400E87A5811FCF4B4084674293C4624D40
53843	32763	55.721383000000003	55.764780999999999	58.631213000000002	58.616908000000002	Трактовая	0103000020E61000000100000005000000F871344756DC4B40055262D7F64E4D40F871344756DC4B40B0E76B96CB504D4014CD0358E4E14B40B0E76B96CB504D4014CD0358E4E14B40055262D7F64E4D40F871344756DC4B40055262D7F64E4D40
53832	32725	55.795161999999998	55.847586999999997	58.440109	58.423698999999999	Культуры	0103000020E61000000100000005000000CF8250DEC7E54B40882CD2C43B364D40CF8250DEC7E54B406FD6E07D55384D40E3C116BB7DEC4B406FD6E07D55384D40E3C116BB7DEC4B40882CD2C43B364D40CF8250DEC7E54B40882CD2C43B364D40
64543	58262	55.907352000000003	55.921429000000003	58.588827999999999	58.581280999999997	Центральная	0103000020E61000000100000005000000E8FA3E1C24F44B40A164726A674A4D40E8FA3E1C24F44B400B7C45B75E4B4D40024BAE62F1F54B400B7C45B75E4B4D40024BAE62F1F54B40A164726A674A4D40E8FA3E1C24F44B40A164726A674A4D40
52168	56296	55.846015000000001	55.855915000000003	58.599975999999998	58.593682999999999	Молодежная	0103000020E61000000100000005000000757632384AEC4B407898F6CDFD4B4D40757632384AEC4B4044317903CC4C4D40F3936A9F8EED4B4044317903CC4C4D40F3936A9F8EED4B407898F6CDFD4B4D40757632384AEC4B407898F6CDFD4B4D40
52242	4812	55.254815999999998	55.280031999999999	56.834175999999999	56.820177999999999	Советская	0103000020E61000000100000005000000AF3F89CF9DA04B400873BB97FB684C40AF3F89CF9DA04B40D68D7747C66A4C40AFEAAC16D8A34B40D68D7747C66A4C40AFEAAC16D8A34B400873BB97FB684C40AF3F89CF9DA04B400873BB97FB684C40
52630	48374	54.893334000000003	54.935141999999999	56.770164000000001	56.748617000000003	пр. Солнечный	0103000020E61000000100000005000000D333BDC458724B40651D8EAED25F4C40D333BDC458724B403D47E4BB94624C40DA8EA9BBB2774B403D47E4BB94624C40DA8EA9BBB2774B40651D8EAED25F4C40D333BDC458724B40651D8EAED25F4C40
52241	4427	54.608199999999997	54.630011000000003	57.035592999999999	57.011533	Заречная	0103000020E61000000100000005000000AEB6627FD94D4B4092E9D0E979814C40AEB6627FD94D4B40B77BB94F8E844C40658F5033A4504B40B77BB94F8E844C40658F5033A4504B4092E9D0E979814C40AEB6627FD94D4B4092E9D0E979814C40
53339	4145	55.161490000000001	55.210673	56.831428000000002	56.812649999999998	Ленина	0103000020E61000000100000005000000C6504EB4AB944B40158C4AEA04684C40C6504EB4AB944B40467D923B6C6A4C403A933655F79A4B40467D923B6C6A4C403A933655F79A4B40158C4AEA04684C40C6504EB4AB944B40158C4AEA04684C40
52646	4751	54.412942000000001	54.434403000000003	56.964818999999999	56.952843999999999	Третья	0103000020E610000001000000050000008A929048DB344B404C18CDCAF6794C408A929048DB344B409BC761307F7B4C4064247B849A374B409BC761307F7B4C4064247B849A374B404C18CDCAF6794C408A929048DB344B404C18CDCAF6794C40
53052	4411	55.051977000000001	55.084629999999997	57.013033	56.990105999999997	Центральная	0103000020E610000001000000050000007592AD2EA7864B4064C91CCBBB7E4C407592AD2EA7864B406762BA10AB814C405721E527D58A4B406762BA10AB814C405721E527D58A4B4064C91CCBBB7E4C407592AD2EA7864B4064C91CCBBB7E4C40
53828	32593	54.714174	54.739462000000003	56.944253000000003	56.927374	Юбилейная	0103000020E61000000100000005000000A6D3BA0D6A5B4B409294F430B4764C40A6D3BA0D6A5B4B4030134548DD784C404051D9B0A65E4B4030134548DD784C404051D9B0A65E4B409294F430B4764C40A6D3BA0D6A5B4B409294F430B4764C40
53824	4256	55.046182000000002	55.070976000000002	56.892881000000003	56.864353999999999	Центральная	0103000020E61000000100000005000000FAD4B14AE9854B405915E126A36E4C40FAD4B14AE9854B40221CB3EC49724C408466D7BD15894B40221CB3EC49724C408466D7BD15894B405915E126A36E4C40FAD4B14AE9854B405915E126A36E4C40
52240	4247	54.949334999999998	54.972043999999997	56.912905000000002	56.883076000000003	Советская	0103000020E610000001000000050000005DF92CCF83794B40F6F065A208714C405DF92CCF83794B406DAD2F12DA744C40F22213F06B7C4B406DAD2F12DA744C40F22213F06B7C4B40F6F065A208714C405DF92CCF83794B40F6F065A208714C40
53821	4165	54.888464999999997	54.92456	56.812157999999997	56.789402000000003	Белокаменная	0103000020E6100000010000000500000000529B38B9714B40D1B2EE1F0B654C4000529B38B9714B40A69718CBF4674C404A9869FB57764B40A69718CBF4674C404A9869FB57764B40D1B2EE1F0B654C4000529B38B9714B40D1B2EE1F0B654C40
52623	4535	55.21096	55.248626999999999	56.831786999999998	56.818080000000002	Центральная	0103000020E61000000100000005000000D061BEBC009B4B407FC16ED8B6684C40D061BEBC009B4B40751E15FF776A4C4088F37002D39F4B40751E15FF776A4C4088F37002D39F4B407FC16ED8B6684C40D061BEBC009B4B407FC16ED8B6684C40
53334	32562	55.042831999999997	55.072853000000002	57.131262999999997	57.100943999999998	Большая Северная	0103000020E61000000100000005000000739CDB847B854B401C5DA5BBEB8C4C40739CDB847B854B406116DA39CD904C402F35423F53894B406116DA39CD904C402F35423F53894B401C5DA5BBEB8C4C40739CDB847B854B401C5DA5BBEB8C4C40
64401	32606	54.977604999999997	54.997188000000001	57.020021	57.001494999999998	Уральская	0103000020E61000000100000005000000FAB31F29227D4B40C30DF8FC30804C40FAB31F29227D4B40DA1D520C90824C4059FB3BDBA37F4B40DA1D520C90824C4059FB3BDBA37F4B40C30DF8FC30804C40FAB31F29227D4B40C30DF8FC30804C40
51579	48037	54.892147999999999	54.950933999999997	57.063563000000002	57.033135000000001	Комсомольская	0103000020E610000001000000050000008D98D9E731724B402EAD86C43D844C408D98D9E731724B402A1E17D522884C40C5538F34B8794B402A1E17D522884C40C5538F34B8794B402EAD86C43D844C408D98D9E731724B402EAD86C43D844C40
51754	48037	54.892147999999999	54.950933999999997	57.063563000000002	57.033135000000001	Карла Маркса	0103000020E610000001000000050000008D98D9E731724B402EAD86C43D844C408D98D9E731724B402A1E17D522884C40C5538F34B8794B402A1E17D522884C40C5538F34B8794B402EAD86C43D844C408D98D9E731724B402EAD86C43D844C40
51446	48037	54.892147999999999	54.950933999999997	57.063563000000002	57.033135000000001	Белинского	0103000020E610000001000000050000008D98D9E731724B402EAD86C43D844C408D98D9E731724B402A1E17D522884C40C5538F34B8794B402A1E17D522884C40C5538F34B8794B402EAD86C43D844C408D98D9E731724B402EAD86C43D844C40
52170	56295	54.531609000000003	54.564892	57.015237999999997	56.982121999999997	Школьная	0103000020E6100000010000000500000030A182C30B444B404F57772CB67D4C4030A182C30B444B4006D49B51F3814C40D2E28C614E484B4006D49B51F3814C40D2E28C614E484B404F57772CB67D4C4030A182C30B444B404F57772CB67D4C40
52166	56295	54.531609000000003	54.564892	57.015237999999997	56.982121999999997	Чапаева	0103000020E6100000010000000500000030A182C30B444B404F57772CB67D4C4030A182C30B444B4006D49B51F3814C40D2E28C614E484B4006D49B51F3814C40D2E28C614E484B404F57772CB67D4C4030A182C30B444B404F57772CB67D4C40
52134	56288	54.768881999999998	54.794241	56.821513000000003	56.80791	Мира	0103000020E61000000100000005000000D53DB2B96A624B40410E4A9869674C40D53DB2B96A624B40931E865627694C40381268B0A9654B40931E865627694C40381268B0A9654B40410E4A9869674C40D53DB2B96A624B40410E4A9869674C40
53818	3647	54.825242000000003	54.870409000000002	56.870911999999997	56.852567999999998	Злыгостева	0103000020E6100000010000000500000090A4A487A1694B40DDCEBEF2206D4C4090A4A487A1694B40D3D85E0B7A6F4C407192E68F696F4B40D3D85E0B7A6F4C407192E68F696F4B40DDCEBEF2206D4C4090A4A487A1694B40DDCEBEF2206D4C40
52090	56275	56.561892	56.569420000000001	58.469748000000003	58.463459999999998	Центральная	0103000020E6100000010000000500000028F1B913EC474C40888043A8523B4D4028F1B913EC474C4043AED4B3203C4D401BD82AC1E2484C4043AED4B3203C4D401BD82AC1E2484C40888043A8523B4D4028F1B913EC474C40888043A8523B4D40
51666	56234	56.752712000000002	56.763052000000002	58.489204000000001	58.482387000000003	 Советская	0103000020E6100000010000000500000044A7E7DD58604C40FE8172DBBE3D4D4044A7E7DD58604C404489963C9E3E4D40DE921CB0AB614C404489963C9E3E4D40DE921CB0AB614C40FE8172DBBE3D4D4044A7E7DD58604C40FE8172DBBE3D4D40
51442	2132	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	Трухина	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
52181	2132	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	Советская	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
51793	2132	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	Пяткина	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
51441	2132	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	Нефтяников	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
51440	2132	56.394033	56.436450999999998	58.307009999999998	58.283129000000002	Дружбы	0103000020E61000000100000005000000BB4560AC6F324C404CC631923D244D40BB4560AC6F324C40C1C58A1A4C274D403BA759A0DD374C40C1C58A1A4C274D403BA759A0DD374C404CC631923D244D40BB4560AC6F324C404CC631923D244D40
64449	2810	56.958381000000003	56.991089000000002	58.634815000000003	58.619818000000002	Береговая	0103000020E61000000100000005000000CC0D863AAC7A4C406FBC3B32564F4D40CC0D863AAC7A4C405001309E41514D4072361D01DC7E4C405001309E41514D4072361D01DC7E4C406FBC3B32564F4D40CC0D863AAC7A4C406FBC3B32564F4D40
64440	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Яйвинская	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
51689	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Юбилейная	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
51544	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Свердлова	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
51782	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Пятилетки	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
51530	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Преображенского	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
51683	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Мира	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
51424	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Ленина проспект	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
51781	10959	56.309932000000003	56.316203000000002	59.010202	59.008223000000001	Карла Маркса	0103000020E61000000100000005000000F0FD0DDAAB274C409A0986730D814D40F0FD0DDAAB274C40492D944C4E814D40D4F2035779284C40492D944C4E814D40D4F2035779284C409A0986730D814D40F0FD0DDAAB274C409A0986730D814D40
52118	56285	57.769174	57.794074999999999	58.864612999999999	58.835169	Пионеров	0103000020E610000001000000050000007D772B4B74E24C4007D15AD1E66A4D407D772B4B74E24C40255987A3AB6E4D401DC9E53FA4E54C40255987A3AB6E4D401DC9E53FA4E54C4007D15AD1E66A4D407D772B4B74E24C4007D15AD1E66A4D40
52263	842	57.472352000000001	57.604152999999997	58.986113000000003	58.918013999999999	Углеуральская	0103000020E61000000100000005000000A019C40776BC4C4094A2957B81754D40A019C40776BC4C408A9466F3387E4D40E063B0E254CD4C408A9466F3387E4D40E063B0E254CD4C4094A2957B81754D40A019C40776BC4C4094A2957B81754D40
51576	842	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	Мира	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
52016	842	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	Белинского	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
52309	842	57.620466999999998	57.621347	58.964970999999998	58.964688000000002	Базовая	0103000020E61000000100000005000000A59F70766BCF4C40FD6B79E57A7B4D40A59F70766BCF4C40514B732B847B4D40DE3B6A4C88CF4C40514B732B847B4D40DE3B6A4C88CF4C40FD6B79E57A7B4D40A59F70766BCF4C40FD6B79E57A7B4D40
51531	842	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	2я Коммунистическая	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
52015	842	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	2ая Коммунистическая	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
52180	842	57.525739000000002	57.64208	58.971879000000001	58.905202000000003	150 лет КУБ	0103000020E61000000100000005000000AA9D616A4BC34C400C23BDA8DD734D40AA9D616A4BC34C40A855F487667C4D4035B56CAD2FD24C40A855F487667C4D4035B56CAD2FD24C400C23BDA8DD734D40AA9D616A4BC34C400C23BDA8DD734D40
65680	58231	57.772452999999999	57.790320000000001	58.876235000000001	58.863909999999997	Зеленая	0103000020E610000001000000050000003A596ABDDFE24C40FB57569A946E4D403A596ABDDFE24C40274EEE7728704D40F7AFAC3429E54C40274EEE7728704D40F7AFAC3429E54C40FB57569A946E4D403A596ABDDFE24C40FB57569A946E4D40
51696	56239	57.644748	57.714179000000001	58.763896000000003	58.731568000000003	Мира	0103000020E61000000100000005000000A9143B1A87D24C406B662D05A45D4D40A9143B1A87D24C40CAC51858C7614D40B83EAC376ADB4C40CAC51858C7614D40B83EAC376ADB4C406B662D05A45D4D40A9143B1A87D24C406B662D05A45D4D40
51785	31675	59.050117	59.092626000000003	58.546204000000003	58.509211999999998	Советская	0103000020E61000000100000005000000A0FCDD3B6A864D40895DDBDB2D414D40A0FCDD3B6A864D40E2783E03EA454D403161342BDB8B4D40E2783E03EA454D403161342BDB8B4D40895DDBDB2D414D40A0FCDD3B6A864D40895DDBDB2D414D40
51571	31675	59.050117	59.092626000000003	58.546204000000003	58.509211999999998	1го Мая	0103000020E61000000100000005000000A0FCDD3B6A864D40895DDBDB2D414D40A0FCDD3B6A864D40E2783E03EA454D403161342BDB8B4D40E2783E03EA454D403161342BDB8B4D40895DDBDB2D414D40A0FCDD3B6A864D40895DDBDB2D414D40
52609	31827	58.866627999999999	58.903934999999997	58.426220000000001	58.404674	Октябрьская	0103000020E6100000010000000500000021E692AAED6E4D4050C58D5BCC334D4021E692AAED6E4D40587380608E364D40D95A5F24B4734D40587380608E364D40D95A5F24B4734D4050C58D5BCC334D4021E692AAED6E4D4050C58D5BCC334D40
52081	31755	58.750179000000003	58.773966000000001	58.554732000000001	58.531761000000003	Кирова	0103000020E61000000100000005000000B0928FDD05604D40E62494BE10444D40B0928FDD05604D40B8054B7501474D40A41B615111634D40B8054B7501474D40A41B615111634D40E62494BE10444D40B0928FDD05604D40E62494BE10444D40
52018	31891	59.134369999999997	59.174892999999997	58.570084999999999	58.555055000000003	Советская	0103000020E6100000010000000500000021C8410933914D409B3DD00A0C474D4021C8410933914D405778978BF8484D4050A6D1E462964D405778978BF8484D4050A6D1E462964D409B3DD00A0C474D4021C8410933914D409B3DD00A0C474D40
51690	31444	58.235892999999997	58.307875000000003	58.446722000000001	58.416983000000002	Ленина	0103000020E610000001000000050000007B2DE8BD311E4D4076FEEDB25F354D407B2DE8BD311E4D40AD33BE2F2E394D40C520B07268274D40AD33BE2F2E394D40C520B07268274D4076FEEDB25F354D407B2DE8BD311E4D4076FEEDB25F354D40
52185	32691	59.093874	59.114337999999996	58.747269000000003	58.732880999999999	Строек Коммунизма	0103000020E61000000100000005000000ECF82F10048C4D400D6E6B0BCF5D4D40ECF82F10048C4D404628B682A65F4D405358A9A0A28E4D404628B682A65F4D405358A9A0A28E4D400D6E6B0BCF5D4D40ECF82F10048C4D400D6E6B0BCF5D4D40
51921	56256	58.354956000000001	58.410516999999999	58.298754000000002	58.263758000000003	Ленина	0103000020E610000001000000050000006EC2BD326F2D4D40790778D2C2214D406EC2BD326F2D4D404CC631923D264D40DCB930D28B344D404CC631923D264D40DCB930D28B344D40790778D2C2214D406EC2BD326F2D4D40790778D2C2214D40
51688	31256	58.295470000000002	58.344706000000002	58.397803000000003	58.366931999999998	Свердлова	0103000020E610000001000000050000007D7901F6D1254D408DEDB5A0F72E4D407D7901F6D1254D4017A06D35EB324D40145E82531F2C4D4017A06D35EB324D40145E82531F2C4D408DEDB5A0F72E4D407D7901F6D1254D408DEDB5A0F72E4D40
51429	31256	58.295470000000002	58.344706000000002	58.397803000000003	58.366931999999998	30 лет Победы	0103000020E610000001000000050000007D7901F6D1254D408DEDB5A0F72E4D407D7901F6D1254D4017A06D35EB324D40145E82531F2C4D4017A06D35EB324D40145E82531F2C4D408DEDB5A0F72E4D407D7901F6D1254D408DEDB5A0F72E4D40
64569	28242	58.237186999999999	58.270577000000003	58.644734999999997	58.634515999999998	Советская	0103000020E61000000100000005000000A704C4245C1E4D40F564FED137514D40A704C4245C1E4D4014CB2DAD86524D4060066344A2224D4014CB2DAD86524D4060066344A2224D40F564FED137514D40A704C4245C1E4D40F564FED137514D40
52216	56308	58.850870999999998	58.890324999999997	58.520370999999997	58.506118999999998	Советская	0103000020E61000000100000005000000B20E4757E96C4D402E71E481C8404D40B20E4757E96C4D40B66455849B424D40D5E76A2BF6714D40B66455849B424D40D5E76A2BF6714D402E71E481C8404D40B20E4757E96C4D402E71E481C8404D40
64758	48698	52.639847000000003	52.677306999999999	60.488098999999998	60.469549000000001	Больничная	0103000020E61000000100000005000000CCB8A981E6514A404C6F7F2E1A3C4E40CCB8A981E6514A40EB1A2D077A3E4E400A2DEBFEB1564A40EB1A2D077A3E4E400A2DEBFEB1564A404C6F7F2E1A3C4E40CCB8A981E6514A404C6F7F2E1A3C4E40
54620	8889	53.98997	54.007002	60.323025000000001	60.314787000000003	Школьная	0103000020E61000000100000005000000B4024356B7FE4A405D1ABFF04A284E40B4024356B7FE4A402C6519E258294E40D8800871E5004B402C6519E258294E40D8800871E5004B405D1ABFF04A284E40B4024356B7FE4A405D1ABFF04A284E40
64731	7772	53.832495999999999	53.847417	60.356701000000001	60.348292999999998	Центральная	0103000020E6100000010000000500000081069B3A8FEA4A407E3672DD942C4E4081069B3A8FEA4A40AAB9DC60A82D4E408789062978EC4A40AAB9DC60A82D4E408789062978EC4A407E3672DD942C4E4081069B3A8FEA4A407E3672DD942C4E40
52334	26717	53.951756000000003	53.957658000000002	60.676993000000003	60.671965	 Центральная	0103000020E61000000100000005000000CAE2FE23D3F94A404087F9F202564E40CAE2FE23D3F94A407B4FE5B4A7564E405B608F8994FA4A407B4FE5B4A7564E405B608F8994FA4A404087F9F202564E40CAE2FE23D3F94A404087F9F202564E40
54410	8032	53.636887000000002	53.661681000000002	60.412011999999997	60.403978000000002	Школьная	0103000020E61000000100000005000000B01F628385D14A40D926158DB5334E40B01F628385D14A409FC728CFBC344E403AB187F6B1D44A409FC728CFBC344E403AB187F6B1D44A40D926158DB5334E40B01F628385D14A40D926158DB5334E40
64782	58347	52.838061000000003	52.870094999999999	60.783154000000003	60.759464000000001	Ленина	0103000020E61000000100000005000000CB863595456B4A40A33EC91D36614E40CB863595456B4A40A5DDE8633E644E40E1B4E0455F6F4A40A5DDE8633E644E40E1B4E0455F6F4A40A33EC91D36614E40CB863595456B4A40A33EC91D36614E40
54587	7946	54.198639999999997	54.231231000000001	60.379866	60.356599000000003	Пионерская	0103000020E61000000100000005000000B6D617096D194B40A6643909A52D4E40B6D617096D194B40616EF7729F304E40236937FA981D4B40616EF7729F304E40236937FA981D4B40A6643909A52D4E40B6D617096D194B40A6643909A52D4E40
54569	48760	54.642910999999998	54.681519999999999	60.217475999999998	60.208486999999998	Кунгурская	0103000020E610000001000000050000008C9E5BE84A524B401152B7B3AF1A4E408C9E5BE84A524B401BD5E940D61B4E40F3C81F0C3C574B401BD5E940D61B4E40F3C81F0C3C574B401152B7B3AF1A4E408C9E5BE84A524B401152B7B3AF1A4E40
51860	56253	54.262905000000003	54.382317999999998	60.339545000000001	60.277566	Коммунистическая	0103000020E610000001000000050000003A7AFCDEA6214B40A33D5E4887234E403A7AFCDEA6214B409A42E735762B4E400856D5CBEF304B409A42E735762B4E400856D5CBEF304B40A33D5E4887234E403A7AFCDEA6214B40A33D5E4887234E40
52220	56253	54.262905000000003	54.382317999999998	60.339545000000001	60.277566	Дзержинского	0103000020E610000001000000050000003A7AFCDEA6214B40A33D5E4887234E403A7AFCDEA6214B409A42E735762B4E400856D5CBEF304B409A42E735762B4E400856D5CBEF304B40A33D5E4887234E403A7AFCDEA6214B40A33D5E4887234E40
66977	56253	54.262905000000003	54.382317999999998	60.339545000000001	60.277566	 Железнодорожная	0103000020E610000001000000050000003A7AFCDEA6214B40A33D5E4887234E403A7AFCDEA6214B409A42E735762B4E400856D5CBEF304B409A42E735762B4E400856D5CBEF304B40A33D5E4887234E403A7AFCDEA6214B40A33D5E4887234E40
54657	56550	54.651535000000003	54.707940000000001	60.243910999999997	60.227339000000001	Карла Маркса	0103000020E610000001000000050000008599B67F65534B407C0DC171191D4E408599B67F65534B403C11C479381F4E40DFC325C79D5A4B403C11C479381F4E40DFC325C79D5A4B407C0DC171191D4E408599B67F65534B407C0DC171191D4E40
53047	33099	54.594608000000001	54.623462000000004	58.036349999999999	58.023598	Советская	0103000020E6100000010000000500000051F86C1D1C4C4B4021205F4205034D4051F86C1D1C4C4B40D49AE61DA7044D403E26529ACD4F4B40D49AE61DA7044D403E26529ACD4F4B4021205F4205034D4051F86C1D1C4C4B4021205F4205034D40
52596	30749	54.820571000000001	54.846693999999999	58.11985	58.109029	Центральная	0103000020E61000000100000005000000E485747808694B4065A88AA9F40D4D40E485747808694B407A36AB3E570F4D4016DC0F78606C4B407A36AB3E570F4D4016DC0F78606C4B4065A88AA9F40D4D40E485747808694B4065A88AA9F40D4D40
51687	30997	54.110551000000001	54.159384000000003	58.193967000000001	58.171788999999997	Ленина	0103000020E6100000010000000500000022C50089260E4B400168942EFD154D4022C50089260E4B406AC020E9D3184D40BAC0E5B166144B406AC020E9D3184D40BAC0E5B166144B400168942EFD154D4022C50089260E4B400168942EFD154D40
52072	33096	54.648974000000003	54.667012999999997	58.064343999999998	58.054284000000003	Птицеводов	0103000020E6100000010000000500000027FA7C9411534B40195932C7F2064D4027FA7C9411534B40CFD8976C3C084D40E08096AE60554B40CFD8976C3C084D40E08096AE60554B40195932C7F2064D4027FA7C9411534B40195932C7F2064D40
51567	30848	54.278131999999999	54.457543000000001	58.077129999999997	58.033476999999998	Комсомольская	0103000020E610000001000000050000004CFC51D499234B4087156EF948044D404CFC51D499234B402EC55565DF094D40C2C1DEC4903A4B402EC55565DF094D40C2C1DEC4903A4B4087156EF948044D404CFC51D499234B4087156EF948044D40
52038	56266	54.385812999999999	54.398308	58.053725999999997	58.048791999999999	Школьная	0103000020E6100000010000000500000092AF045262314B403927F6D03E064D4092AF045262314B40F2785A7EE0064D401ADEACC1FB324B40F2785A7EE0064D401ADEACC1FB324B403927F6D03E064D4092AF045262314B403927F6D03E064D40
54463	10495	54.378760999999997	54.408225999999999	58.144002	58.134872000000001	Советская	0103000020E6100000010000000500000008008E3D7B304B40B492567C43114D4008008E3D7B304B40804754A86E124D403EB0E3BF40344B40804754A86E124D403EB0E3BF40344B40B492567C43114D4008008E3D7B304B40B492567C43114D40
52078	33126	54.555971999999997	54.580460000000002	58.199587000000001	58.185214000000002	 Гагарина	0103000020E61000000100000005000000F0BE2A172A474B407461A417B5174D40F0BE2A172A474B4077DA1A118C194D406E5166834C4A4B4077DA1A118C194D406E5166834C4A4B407461A417B5174D40F0BE2A172A474B407461A417B5174D40
53317	30818	54.903843999999999	54.915135999999997	58.110830999999997	58.100332000000002	Молодежная	0103000020E61000000100000005000000C9570229B1734B40035FD1ADD70C4D40C9570229B1734B400531D0B52F0E4D4035B22B2D23754B400531D0B52F0E4D4035B22B2D23754B40035FD1ADD70C4D40C9570229B1734B40035FD1ADD70C4D40
52012	30660	54.826428	54.853116999999997	58.156796999999997	58.141551	Ленина	0103000020E61000000100000005000000D53F8864C8694B40A9DBD9571E124D40D53F8864C8694B40328E91EC11144D40B05417F0326D4B40328E91EC11144D40B05417F0326D4B40A9DBD9571E124D40D53F8864C8694B40A9DBD9571E124D40
52010	56258	54.494706999999998	54.511235999999997	58.093288000000001	58.077739000000001	Молодежная	0103000020E61000000100000005000000170D198F523F4B40D74FFF59F3094D40170D198F523F4B40FC8D76DCF00B4D40D844662E70414B40FC8D76DCF00B4D40D844662E70414B40D74FFF59F3094D40170D198F523F4B40D74FFF59F3094D40
51425	30494	54.676391000000002	54.733846999999997	58.217401000000002	58.188008000000004	Пугачева	0103000020E610000001000000050000008527F4FA93564B4075B169A510184D408527F4FA93564B40118FC4CBD31B4D4044A2D0B2EE5D4B40118FC4CBD31B4D4044A2D0B2EE5D4B4075B169A510184D408527F4FA93564B4075B169A510184D40
51786	30494	54.676391000000002	54.733846999999997	58.217401000000002	58.188008000000004	Мичурина	0103000020E610000001000000050000008527F4FA93564B4075B169A510184D408527F4FA93564B40118FC4CBD31B4D4044A2D0B2EE5D4B40118FC4CBD31B4D4044A2D0B2EE5D4B4075B169A510184D408527F4FA93564B4075B169A510184D40
52179	30494	54.676391000000002	54.733846999999997	58.217401000000002	58.188008000000004	Ленина	0103000020E610000001000000050000008527F4FA93564B4075B169A510184D408527F4FA93564B40118FC4CBD31B4D4044A2D0B2EE5D4B40118FC4CBD31B4D4044A2D0B2EE5D4B4075B169A510184D408527F4FA93564B4075B169A510184D40
64474	58240	54.720542999999999	54.736469999999997	58.130681000000003	58.125244000000002	Ленина	0103000020E610000001000000050000004D2EC6C03A5C4B409702D2FE07104D404D2EC6C03A5C4B40B39AAE27BA104D40183E22A6445E4B40B39AAE27BA104D40183E22A6445E4B409702D2FE07104D404D2EC6C03A5C4B409702D2FE07104D40
52075	30305	54.609960999999998	54.648668999999998	58.167611999999998	58.137413000000002	Ленина	0103000020E61000000100000005000000F06AB933134E4B40CB85CABF96114D40F06AB933134E4B4065355D4F74154D40EA76F69507534B4065355D4F74154D40EA76F69507534B40CB85CABF96114D40F06AB933134E4B40CB85CABF96114D40
53298	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Энергетиков	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51421	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Ленина	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51566	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Коммунистическая	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51686	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Карла Маркса	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51422	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	К.Маркса	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
54505	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Звезды	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51420	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Железнодорожная	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
52318	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Дорожная	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
51684	10421	54.616472999999999	54.690773	58.102220000000003	58.063496999999998	Верещагинская	0103000020E61000000100000005000000FAEE5696E84E4B40723271AB20084D40FAEE5696E84E4B40A27F828B150D4D40DBFAE93F6B584B40A27F828B150D4D40DBFAE93F6B584B40723271AB20084D40FAEE5696E84E4B40723271AB20084D40
52014	56259	54.353572	54.400554	58.006526000000001	57.989078999999997	1 Мая	0103000020E610000001000000050000000264E8D8412D4B40871403249AFE4C400264E8D8412D4B406F490ED8D5004D4018247D5A45334B406F490ED8D5004D4018247D5A45334B40871403249AFE4C400264E8D8412D4B40871403249AFE4C40
52074	32535	54.750349	54.771765000000002	58.083078	58.071666	Центральная	0103000020E610000001000000050000000CCB9F6F0B604B40191EFB592C094D400CCB9F6F0B604B403082C64CA20A4D4046990D32C9624B403082C64CA20A4D4046990D32C9624B40191EFB592C094D400CCB9F6F0B604B40191EFB592C094D40
53805	29334	54.592722000000002	54.617578000000002	57.757351	57.733445000000003	Заречная	0103000020E6100000010000000500000053CF8250DE4B4B4016359886E1DD4C4053CF8250DE4B4B40E44BA8E0F0E04C40535DC0CB0C4F4B40E44BA8E0F0E04C40535DC0CB0C4F4B4016359886E1DD4C4053CF8250DE4B4B4016359886E1DD4C40
51540	29326	54.523784999999997	54.576138999999998	57.503166	57.486832	Ленина	0103000020E6100000010000000500000053910A630B434B40B952CF8250BE4C4053910A630B434B40C53A55BE67C04C409E7939ECBE494B40C53A55BE67C04C409E7939ECBE494B40B952CF8250BE4C4053910A630B434B40B952CF8250BE4C40
53295	29251	54.349305000000001	54.394868000000002	57.529853000000003	57.512236000000001	Молодежная	0103000020E6100000010000000500000026AAB706B62C4B40BCEA01F390C14C4026AAB706B62C4B4000581D39D2C34C40541EDD088B324B4000581D39D2C34C40541EDD088B324B40BCEA01F390C14C4026AAB706B62C4B40BCEA01F390C14C40
52303	28553	54.124628000000001	54.154029999999999	57.600766999999998	57.590257000000001	Молодежная	0103000020E610000001000000050000003C1570CFF30F4B40179E978A8DCB4C403C1570CFF30F4B400DC2DCEEE5CC4C402B4D4A41B7134B400DC2DCEEE5CC4C402B4D4A41B7134B40179E978A8DCB4C403C1570CFF30F4B40179E978A8DCB4C40
52593	29170	54.405782000000002	54.435336999999997	57.364190999999998	57.351559000000002	Центральная	0103000020E610000001000000050000001AA721AAF0334B40A7CEA3E2FFAC4C401AA721AAF0334B40AF3F89CF9DAE4C408FDE701FB9374B40AF3F89CF9DAE4C408FDE701FB9374B40A7CEA3E2FFAC4C401AA721AAF0334B40A7CEA3E2FFAC4C40
52176	29154	54.271025999999999	54.318933000000001	57.664017999999999	57.644477000000002	Гагарина	0103000020E61000000100000005000000CF2EDFFAB0224B401903EB387ED24C40CF2EDFFAB0224B4048FAB48AFED44C40BE4EEACBD2284B4048FAB48AFED44C40BE4EEACBD2284B401903EB387ED24C40CF2EDFFAB0224B401903EB387ED24C40
52306	29105	54.134293999999997	54.161737000000002	57.671610000000001	57.655794999999998	Мира	0103000020E610000001000000050000004606B98B30114B40AEF02E17F1D34C404606B98B30114B4052D50451F7D54C40CEC64ACCB3144B4052D50451F7D54C40CEC64ACCB3144B40AEF02E17F1D34C404606B98B30114B40AEF02E17F1D34C40
52307	29039	54.206904000000002	54.231752	57.353079000000001	57.326343999999999	Нагорная	0103000020E61000000100000005000000AFB48CD47B1A4B40779FE3A3C5A94C40AFB48CD47B1A4B40C3F352B131AD4C402C64AE0CAA1D4B40C3F352B131AD4C402C64AE0CAA1D4B40779FE3A3C5A94C40AFB48CD47B1A4B40779FE3A3C5A94C40
53284	29016	54.630918000000001	54.666392999999999	57.630023999999999	57.610087999999998	Ленина	0103000020E61000000100000005000000973AC8EBC1504B404DD7135D17CE4C40973AC8EBC1504B40F9D85DA0A4D04C4044A4A65D4C554B40F9D85DA0A4D04C4044A4A65D4C554B404DD7135D17CE4C40973AC8EBC1504B404DD7135D17CE4C40
64561	58272	54.16966	54.181382999999997	57.541352000000003	57.530757000000001	Центральная	0103000020E610000001000000050000003DB83B6BB7154B40C18F6AD8EFC34C403DB83B6BB7154B40E6CFB7054BC54C407286E28E37174B40E6CFB7054BC54C407286E28E37174B40C18F6AD8EFC34C403DB83B6BB7154B40C18F6AD8EFC34C40
53268	28959	54.351201000000003	54.374063	57.255678000000003	57.242375000000003	Школьная	0103000020E6100000010000000500000048A98427F42C4B401B2FDD24069F4C4048A98427F42C4B404227840EBAA04C4063D2DF4BE12F4B404227840EBAA04C4063D2DF4BE12F4B401B2FDD24069F4C4048A98427F42C4B401B2FDD24069F4C40
53801	28934	54.813124000000002	54.837477	57.642646999999997	57.623263000000001	Специалистов	0103000020E61000000100000005000000DECB7D7214684B4047E7FC14C7CF4C40DECB7D7214684B40AEEFC34142D24C407B134372326B4B40AEEFC34142D24C407B134372326B4B4047E7FC14C7CF4C40DECB7D7214684B4047E7FC14C7CF4C40
52347	29414	54.436945000000001	54.455899000000002	57.399211000000001	57.375329999999998	Октябрьская	0103000020E610000001000000050000004B9352D0ED374B40959A3DD00AB04C404B9352D0ED374B400B9A965819B34C40BAA3FFE55A3A4B400B9A965819B34C40BAA3FFE55A3A4B40959A3DD00AB04C404B9352D0ED374B40959A3DD00AB04C40
52591	28886	54.298065000000001	54.341912000000001	57.751520999999997	57.740184999999997	Новая	0103000020E61000000100000005000000878A71FE26264B40B0FECF61BEDE4C40878A71FE26264B40ECA012D731E04C40130EBDC5C32B4B40ECA012D731E04C40130EBDC5C32B4B40B0FECF61BEDE4C40878A71FE26264B40B0FECF61BEDE4C40
53263	28808	54.439019999999999	54.466410000000003	57.723621999999999	57.710917000000002	Школьная	0103000020E610000001000000050000001C25AFCE31384B40D1950854FFDA4C401C25AFCE31384B4043554CA59FDC4C408143A852B33B4B4043554CA59FDC4C408143A852B33B4B40D1950854FFDA4C401C25AFCE31384B40D1950854FFDA4C40
54328	56531	54.285497999999997	54.312241	57.535845000000002	57.518442999999998	Дружбы	0103000020E610000001000000050000006589CE328B244B4089EB18575CC24C406589CE328B244B40D15CA79196C44C4034BC5983F7274B40D15CA79196C44C4034BC5983F7274B4089EB18575CC24C406589CE328B244B4089EB18575CC24C40
51565	28580	54.575816000000003	54.627738000000001	57.689149	57.657716000000001	Ленина	0103000020E61000000100000005000000BC41B456B4494B402907B30930D44C40BC41B456B4494B401A89D00836D84C406D3A02B859504B401A89D00836D84C406D3A02B859504B402907B30930D44C40BC41B456B4494B402907B30930D44C40
52009	28705	54.443458	54.471665000000002	57.340145999999997	57.324151999999998	Набережная	0103000020E610000001000000050000002593533BC3384B406C770FD07DA94C402593533BC3384B40BFEE74E789AB4C407CD5CA845F3C4B40BFEE74E789AB4C407CD5CA845F3C4B406C770FD07DA94C402593533BC3384B406C770FD07DA94C40
53799	28690	54.441499	54.473632000000002	57.646616000000002	57.632066999999999	переулок Полевой	0103000020E61000000100000005000000BD1B0B0A83384B40BFF04A92E7D04C40BD1B0B0A83384B4001892650C4D24C40672B2FF99F3C4B4001892650C4D24C40672B2FF99F3C4B40BFF04A92E7D04C40BD1B0B0A83384B40BFF04A92E7D04C40
52271	32904	57.305723999999998	57.331873999999999	57.659156000000003	57.653806000000003	Центральная	0103000020E6100000010000000500000018CDCAF621A74C40DCF63DEAAFD34C4018CDCAF621A74C40297B4B395FD44C404432E4D87AAA4C40297B4B395FD44C404432E4D87AAA4C40DCF63DEAAFD34C4018CDCAF621A74C40DCF63DEAAFD34C40
64419	48584	57.767825999999999	57.784202999999998	57.541182999999997	57.532041999999997	Центральная	0103000020E610000001000000050000005E82531F48E24C40990CC7F319C44C405E82531F48E24C4059130B7C45C54C4069368FC360E44C4059130B7C45C54C4069368FC360E44C40990CC7F319C44C405E82531F48E24C40990CC7F319C44C40
52183	56301	57.312057000000003	57.323115000000001	57.600811	57.592013000000001	Никольского	0103000020E6100000010000000500000073BED87BF1A74C4047E7FC14C7CB4C4073BED87BF1A74C40DD09F65FE7CC4C406CEC12D55BA94C40DD09F65FE7CC4C406CEC12D55BA94C4047E7FC14C7CB4C4073BED87BF1A74C4047E7FC14C7CB4C40
52275	27324	57.471238	57.488323999999999	57.649963	57.637034	Центральная	0103000020E61000000100000005000000F450DB8651BC4C40543882548AD14C40F450DB8651BC4C40164ED2FC31D34C400BED9C6681BE4C40164ED2FC31D34C400BED9C6681BE4C40543882548AD14C40F450DB8651BC4C40543882548AD14C40
53792	28175	57.615912000000002	57.635891000000001	57.437812000000001	57.427399999999999	Железнодорожная	0103000020E61000000100000005000000639B5434D6CE4C40BB270F0BB5B64C40639B5434D6CE4C40EFE53E390AB84C400E6954E064D14C40EFE53E390AB84C400E6954E064D14C40BB270F0BB5B64C40639B5434D6CE4C40BB270F0BB5B64C40
52590	28120	57.367196	57.389546000000003	57.530124000000001	57.520609	Садовая	0103000020E610000001000000050000006B9C4D4700AF4C406B80D250A3C24C406B9C4D4700AF4C4090696D1ADBC34C40D124B1A4DCB14C4090696D1ADBC34C40D124B1A4DCB14C406B80D250A3C24C406B9C4D4700AF4C406B80D250A3C24C40
52357	32771	57.652814999999997	57.685388000000003	57.738725000000002	57.731008000000003	Южная	0103000020E610000001000000050000004BAB21718FD34C40A48E8EAB91DD4C404BAB21718FD34C406ADE718A8EDE4C40128942CBBAD74C406ADE718A8EDE4C40128942CBBAD74C40A48E8EAB91DD4C404BAB21718FD34C40A48E8EAB91DD4C40
52302	28501	57.569056000000003	57.583410999999998	57.491011999999998	57.47898	Центральная	0103000020E61000000100000005000000DACBB6D3D6C84C4013B875374FBD4C40DACBB6D3D6C84C40C6F8307BD9BE4C4036902E36ADCA4C40C6F8307BD9BE4C4036902E36ADCA4C4013B875374FBD4C40DACBB6D3D6C84C4013B875374FBD4C40
53261	32918	57.735424000000002	57.777205000000002	57.540666000000002	57.527959000000003	Свободы	0103000020E61000000100000005000000C558A65F22DE4C407F50172994C34C40C558A65F22DE4C409207228B34C54C40D3A414747BE34C409207228B34C54C40D3A414747BE34C407F50172994C34C40C558A65F22DE4C407F50172994C34C40
64359	58214	57.764924999999998	57.787697000000001	57.556628000000003	57.546959999999999	 Центральная	0103000020E610000001000000050000004772F90FE9E14C402E1C08C902C64C404772F90FE9E14C40DA0418963FC74C4023145B41D3E44C40DA0418963FC74C4023145B41D3E44C402E1C08C902C64C404772F90FE9E14C402E1C08C902C64C40
51630	28641	57.785730000000001	57.816425000000002	57.561089000000003	57.549568000000001	Мелиораторов	0103000020E6100000010000000500000038BEF6CC92E44C40CD76853E58C64C4038BEF6CC92E44C409B92ACC3D1C74C408351499D80E84C409B92ACC3D1C74C408351499D80E84C40CD76853E58C64C4038BEF6CC92E44C40CD76853E58C64C40
52589	32878	57.320843000000004	57.331982000000004	57.719349000000001	57.704084000000002	Центральная	0103000020E610000001000000050000004513286211A94C4085D1AC6C1FDA4C404513286211A94C4085B4C6A013DC4C402B6EDC627EAA4C4085B4C6A013DC4C402B6EDC627EAA4C4085D1AC6C1FDA4C404513286211A94C4085D1AC6C1FDA4C40
53757	27524	57.177039999999998	57.196156000000002	57.624963999999999	57.613852999999999	Дружбы	0103000020E61000000100000005000000BB0A293FA9964C4097C62FBC92CE4C40BB0A293FA9964C40B39602D2FECF4C400475CAA31B994C40B39602D2FECF4C400475CAA31B994C4097C62FBC92CE4C40BB0A293FA9964C4097C62FBC92CE4C40
52308	56340	57.372909	57.675102000000003	57.694921999999998	57.599986000000001	Молодежная	0103000020E6100000010000000500000029B16B7BBBAF4C4068075C57CCCC4C4029B16B7BBBAF4C40ADA23F34F3D84C406BBB09BE69D64C40ADA23F34F3D84C406BBB09BE69D64C4068075C57CCCC4C4029B16B7BBBAF4C4068075C57CCCC4C40
64553	58266	57.448565000000002	57.468283	57.578668	57.570227000000003	Центральная	0103000020E61000000100000005000000AC90F2936AB94C40EA25C632FDC84C40AC90F2936AB94C40F19E03CB11CA4C40EA2285B2F0BB4C40F19E03CB11CA4C40EA2285B2F0BB4C40EA25C632FDC84C40AC90F2936AB94C40EA25C632FDC84C40
52299	27965	57.659973999999998	57.672362	57.614114000000001	57.607475000000001	 Центральная	0103000020E61000000100000005000000EB1A2D077AD44C409D11A5BDC1CD4C40EB1A2D077AD44C4004029D499BCE4C405D8940F50FD64C4004029D499BCE4C405D8940F50FD64C409D11A5BDC1CD4C40EB1A2D077AD44C409D11A5BDC1CD4C40
53754	32687	57.357053999999998	57.373448000000003	57.655462999999997	57.639476999999999	Школьная	0103000020E61000000100000005000000F7730AF2B3AD4C40A8C5E061DAD14C40F7730AF2B3AD4C40785E2A36E6D34C40D960E124CDAF4C40785E2A36E6D34C40D960E124CDAF4C40A8C5E061DAD14C40F7730AF2B3AD4C40A8C5E061DAD14C40
52300	32848	57.36168	57.386068999999999	57.575921999999998	57.563701000000002	Мичурина	0103000020E6100000010000000500000003CFBD874BAE4C407BDCB75A27C84C4003CFBD874BAE4C400186E5CFB7C94C40ED7F80B56AB14C400186E5CFB7C94C40ED7F80B56AB14C407BDCB75A27C84C4003CFBD874BAE4C407BDCB75A27C84C40
52277	27773	57.244287999999997	57.267643999999997	57.588684000000001	57.576264999999999	Школьная	0103000020E61000000100000005000000126745D4449F4C402B6A300DC3C94C40126745D4449F4C40D8D64FFF59CB4C403D7C992842A24C40D8D64FFF59CB4C403D7C992842A24C402B6A300DC3C94C40126745D4449F4C402B6A300DC3C94C40
53160	27698	57.174515999999997	57.293236999999998	57.617474000000001	57.527634999999997	Школьная	0103000020E610000001000000050000007A50508A56964C40CB9C2E8B89C34C407A50508A56964C40AE10566309CF4C40137D3ECA88A54C40AE10566309CF4C40137D3ECA88A54C40CB9C2E8B89C34C407A50508A56964C40CB9C2E8B89C34C40
52393	27910	57.647632000000002	57.66337	57.623835999999997	57.614490000000004	Мира	0103000020E61000000100000005000000EAEBF99AE5D24C400ADCBA9BA7CE4C40EAEBF99AE5D24C40A208A9DBD9CF4C40E292E34EE9D44C40A208A9DBD9CF4C40E292E34EE9D44C400ADCBA9BA7CE4C40EAEBF99AE5D24C400ADCBA9BA7CE4C40
52079	32745	57.165011999999997	57.189149	57.666618	57.655149999999999	Школьная	0103000020E6100000010000000500000049B9FB1C1F954C40B9FC87F4DBD34C4049B9FB1C1F954C40647616BD53D54C401A89D00836984C40647616BD53D54C401A89D00836984C40B9FC87F4DBD34C4049B9FB1C1F954C40B9FC87F4DBD34C40
52388	27866	57.234262999999999	57.265487999999998	57.769699000000003	57.758172000000002	Школьная	0103000020E61000000100000005000000D8D47954FC9D4C40185FB4C70BE14C40D8D47954FC9D4C40C861307F85E24C407FBDC282FBA14C40C861307F85E24C407FBDC282FBA14C40185FB4C70BE14C40D8D47954FC9D4C40185FB4C70BE14C40
52274	26862	57.658897000000003	57.686610000000002	57.525388	57.506912999999997	Советская	0103000020E610000001000000050000005D37A5BC56D44C4068757286E2C04C405D37A5BC56D44C40FDDAFAE93FC34C40A48D23D6E2D74C40FDDAFAE93FC34C40A48D23D6E2D74C4068757286E2C04C405D37A5BC56D44C4068757286E2C04C40
52340	26862	57.658897000000003	57.686610000000002	57.525388	57.506912999999997	Мира	0103000020E610000001000000050000005D37A5BC56D44C4068757286E2C04C405D37A5BC56D44C40FDDAFAE93FC34C40A48D23D6E2D74C40FDDAFAE93FC34C40A48D23D6E2D74C4068757286E2C04C405D37A5BC56D44C4068757286E2C04C40
63656	32743	57.208022999999997	57.223106000000001	57.686297000000003	57.681975999999999	Нагорная	0103000020E610000001000000050000006CE8667FA09A4C40155454FD4AD74C406CE8667FA09A4C40E52B8194D8D74C404CC5C6BC8E9C4C40E52B8194D8D74C404CC5C6BC8E9C4C40155454FD4AD74C406CE8667FA09A4C40155454FD4AD74C40
64506	32620	56.718333000000001	56.740414000000001	59.307817	59.298284000000002	Школьная	0103000020E610000001000000050000009C51F355F25B4C40C5758C2B2EA64D409C51F355F25B4C409013268C66A74D4012C0CDE2C55E4C409013268C66A74D4012C0CDE2C55E4C40C5758C2B2EA64D409C51F355F25B4C40C5758C2B2EA64D40
52059	8239	56.624999000000003	56.713437999999996	59.450980000000001	59.397725999999999	Чернышевского	0103000020E6100000010000000500000030849CF7FF4F4C406B6281AFE8B24D4030849CF7FF4F4C4036936FB6B9B94D40A0DCB6EF515B4C4036936FB6B9B94D40A0DCB6EF515B4C406B6281AFE8B24D4030849CF7FF4F4C406B6281AFE8B24D40
52161	8239	56.624999000000003	56.713437999999996	59.450980000000001	59.397725999999999	Солеваров	0103000020E6100000010000000500000030849CF7FF4F4C406B6281AFE8B24D4030849CF7FF4F4C4036936FB6B9B94D40A0DCB6EF515B4C4036936FB6B9B94D40A0DCB6EF515B4C406B6281AFE8B24D4030849CF7FF4F4C406B6281AFE8B24D40
52060	8239	56.624999000000003	56.713437999999996	59.450980000000001	59.397725999999999	Свободы	0103000020E6100000010000000500000030849CF7FF4F4C406B6281AFE8B24D4030849CF7FF4F4C4036936FB6B9B94D40A0DCB6EF515B4C4036936FB6B9B94D40A0DCB6EF515B4C406B6281AFE8B24D4030849CF7FF4F4C406B6281AFE8B24D40
52164	8239	56.624999000000003	56.713437999999996	59.450980000000001	59.397725999999999	Первомайская	0103000020E6100000010000000500000030849CF7FF4F4C406B6281AFE8B24D4030849CF7FF4F4C4036936FB6B9B94D40A0DCB6EF515B4C4036936FB6B9B94D40A0DCB6EF515B4C406B6281AFE8B24D4030849CF7FF4F4C406B6281AFE8B24D40
52165	8239	56.624999000000003	56.713437999999996	59.450980000000001	59.397725999999999	Елькина	0103000020E6100000010000000500000030849CF7FF4F4C406B6281AFE8B24D4030849CF7FF4F4C4036936FB6B9B94D40A0DCB6EF515B4C4036936FB6B9B94D40A0DCB6EF515B4C406B6281AFE8B24D4030849CF7FF4F4C406B6281AFE8B24D40
52163	8239	56.624999000000003	56.713437999999996	59.450980000000001	59.397725999999999	8 марта	0103000020E6100000010000000500000030849CF7FF4F4C406B6281AFE8B24D4030849CF7FF4F4C4036936FB6B9B94D40A0DCB6EF515B4C4036936FB6B9B94D40A0DCB6EF515B4C406B6281AFE8B24D4030849CF7FF4F4C406B6281AFE8B24D40
51755	47935	57.009746999999997	57.037083000000003	59.343245000000003	59.334781999999997	Центральная	0103000020E61000000100000005000000F71DC3633F814C400DA5F622DAAA4D40F71DC3633F814C40FDC1C073EFAB4D40691EC022BF844C40FDC1C073EFAB4D40691EC022BF844C400DA5F622DAAA4D40F71DC3633F814C400DA5F622DAAA4D40
53790	24341	55.819093000000002	55.863802	57.011180000000003	56.991821999999999	Советская	0103000020E61000000100000005000000F7B0170AD8E84B4006BAF605F47E4C40F7B0170AD8E84B40452FA3586E814C40151C5E1091EE4B40452FA3586E814C40151C5E1091EE4B4006BAF605F47E4C40F7B0170AD8E84B4006BAF605F47E4C40
52586	24305	55.793427999999999	55.816029999999998	57.061557000000001	57.047767	Центральная	0103000020E6100000010000000500000087DD770C8FE54B40FD69A33A1D864C4087DD770C8FE54B4081EB8A19E1874C400647C9AB73E84B4081EB8A19E1874C400647C9AB73E84B40FD69A33A1D864C4087DD770C8FE54B40FD69A33A1D864C40
52549	22773	55.601807999999998	55.617618999999998	56.999583000000001	56.985756000000002	Зеленая	0103000020E610000001000000050000004F3C670B08CD4B40FBEAAA402D7E4C404F3C670B08CD4B409C51F355F27F4C40B131AF230ECF4B409C51F355F27F4C40B131AF230ECF4B40FBEAAA402D7E4C404F3C670B08CD4B40FBEAAA402D7E4C40
52584	24253	55.266530000000003	55.301160000000003	57.057611999999999	57.042243999999997	Ленина	0103000020E6100000010000000500000092B3B0A71DA24B40E2395B4068854C4092B3B0A71DA24B40B7ED7BD45F874C40836E2F698CA64B40B7ED7BD45F874C40836E2F698CA64B40E2395B4068854C4092B3B0A71DA24B40E2395B4068854C40
53773	23069	55.431154999999997	55.457970000000003	56.788829999999997	56.781408999999996	Нагорная	0103000020E61000000100000005000000E140481630B74B4068E6C93505644C40E140481630B74B40450DA661F8644C404A46CEC29EBA4B40450DA661F8644C404A46CEC29EBA4B4068E6C93505644C40E140481630B74B4068E6C93505644C40
62693	58018	55.582549	55.605249000000001	57.063513999999998	57.049768999999998	Ленина	0103000020E61000000100000005000000A4A833F790CA4B4064ADA1D45E864C40A4A833F790CA4B40486B0C3A21884C40E6779ACC78CD4B40486B0C3A21884C40E6779ACC78CD4B4064ADA1D45E864C40A4A833F790CA4B4064ADA1D45E864C40
54326	56530	55.671768999999998	55.685854999999997	56.819912000000002	56.809348999999997	Ленина	0103000020E61000000100000005000000BABBCE86FCD54B4070067FBF98674C40BABBCE86FCD54B408ACC5CE0F2684C402766BD18CAD74B408ACC5CE0F2684C402766BD18CAD74B4070067FBF98674C40BABBCE86FCD54B4070067FBF98674C40
52582	24222	55.297970999999997	55.333643000000002	57.087466999999997	57.070433999999999	Советская	0103000020E610000001000000050000000514EAE923A64B40634337FB03894C400514EAE923A64B40573D601E328B4C4009C556D0B4AA4B40573D601E328B4C4009C556D0B4AA4B40634337FB03894C400514EAE923A64B40634337FB03894C40
52069	22415	55.606586999999998	55.636114999999997	56.832915	56.806342999999998	Ленина	0103000020E61000000100000005000000E1968FA4A4CD4B40E42D573F36674C40E1968FA4A4CD4B4086AC6EF59C6A4C405DBF60376CD14B4086AC6EF59C6A4C405DBF60376CD14B40E42D573F36674C40E1968FA4A4CD4B40E42D573F36674C40
52174	24095	55.819110999999999	55.849347999999999	56.781173000000003	56.763005999999997	Ленина	0103000020E610000001000000050000009D6516A1D8E84B406D533C2EAA614C409D6516A1D8E84B4055C2137AFD634C4025766D6FB7EC4B4055C2137AFD634C4025766D6FB7EC4B406D533C2EAA614C409D6516A1D8E84B406D533C2EAA614C40
52293	2044	55.758114999999997	55.787292999999998	56.852995999999997	56.841605999999999	Ленина	0103000020E61000000100000005000000B3CD8DE909E14B40060FD3BEB96B4C40B3CD8DE909E14B4035CF11F92E6D4C4053AF5B04C6E44B4035CF11F92E6D4C4053AF5B04C6E44B40060FD3BEB96B4C40B3CD8DE909E14B40060FD3BEB96B4C40
52297	24043	55.685198999999997	55.724401999999998	56.820231999999997	56.801882999999997	Мусы Джалиля	0103000020E610000001000000050000003E20D099B4D74B40F31B261AA4664C403E20D099B4D74B40FB90B75CFD684C4018946934B9DC4B40FB90B75CFD684C4018946934B9DC4B40F31B261AA4664C403E20D099B4D74B40F31B261AA4664C40
52295	22784	55.414779000000003	55.439734000000001	56.932437999999998	56.922249999999998	Ленина	0103000020E61000000100000005000000A708707A17B54B40355EBA490C764C40A708707A17B54B4019C6DD205A774C403A78263449B84B4019C6DD205A774C403A78263449B84B40355EBA490C764C40A708707A17B54B40355EBA490C764C40
53751	22541	55.655051999999998	55.673368000000004	56.814720000000001	56.806294000000001	Ленина	0103000020E61000000100000005000000F69672BED8D34B40037B4CA434674C40F69672BED8D34B40D5B2B5BE48684C40231631EC30D64B40D5B2B5BE48684C40231631EC30D64B40037B4CA434674C40F69672BED8D34B40037B4CA434674C40
51673	24005	55.733457000000001	55.782764999999998	56.788198999999999	56.766257000000003	Советская	0103000020E61000000100000005000000DA0242EBE1DD4B4061AA99B514624C40DA0242EBE1DD4B40B5DE6FB4E3644C400ABABDA431E44B40B5DE6FB4E3644C400ABABDA431E44B4061AA99B514624C40DA0242EBE1DD4B4061AA99B514624C40
53256	23862	56.013928999999997	56.035201000000001	56.834204999999997	56.817084999999999	Советская	0103000020E61000000100000005000000A5BBEB6CC8014C40AD86C43D96684C40A5BBEB6CC8014C407094BC3AC76A4C40ACE4637781044C407094BC3AC76A4C40ACE4637781044C40AD86C43D96684C40A5BBEB6CC8014C40AD86C43D96684C40
53254	32519	55.509658999999999	55.534362999999999	56.770293000000002	56.761629999999997	Дружбы	0103000020E61000000100000005000000588E90813CC14B4084D382177D614C40588E90813CC14B403BAB05F698624C40A298BC0166C44B403BAB05F698624C40A298BC0166C44B4084D382177D614C40588E90813CC14B4084D382177D614C40
53785	23597	55.683824999999999	55.697730999999997	56.686278000000001	56.657806000000001	Ленина	0103000020E61000000100000005000000F697DD9387D74B40698EACFC32544C40F697DD9387D74B406EFB1EF5D7574C40E333D93F4FD94B406EFB1EF5D7574C40E333D93F4FD94B40698EACFC32544C40F697DD9387D74B40698EACFC32544C40
52575	32931	55.483195000000002	55.515211000000001	56.733659000000003	56.714441999999998	Мира	0103000020E610000001000000050000009D4B7155D9BD4B40C571E0D5725B4C409D4B7155D9BD4B4042B5C189E85D4C400DC51D6FF2C14B4042B5C189E85D4C400DC51D6FF2C14B40C571E0D5725B4C409D4B7155D9BD4B40C571E0D5725B4C40
52538	32921	55.654746000000003	55.671391999999997	56.738230999999999	56.726371	Блюхера	0103000020E61000000100000005000000EA9788B7CED34B40A4E194B9F95C4C40EA9788B7CED34B405AF2785A7E5E4C40E4654D2CF0D54B405AF2785A7E5E4C40E4654D2CF0D54B40A4E194B9F95C4C40EA9788B7CED34B40A4E194B9F95C4C40
53983	23941	56.003751000000001	56.028508000000002	56.923262000000001	56.906973999999998	Советская	0103000020E61000000100000005000000E529ABE97A004C4041295AB917744C40E529ABE97A004C40DDD1FF722D764C4052D66F26A6034C40DDD1FF722D764C4052D66F26A6034C4041295AB917744C40E529ABE97A004C4041295AB917744C40
81099	32783	55.557035999999997	55.578415999999997	56.969794	56.957948000000002	Центральная	0103000020E61000000100000005000000EA58A5F44CC74B4062A2410A9E7A4C40EA58A5F44CC74B40B3EDB435227C4C40D7BD158909CA4B40B3EDB435227C4C40D7BD158909CA4B4062A2410A9E7A4C40EA58A5F44CC74B4062A2410A9E7A4C40
53775	23503	55.507728	55.540238000000002	57.026736999999997	57.013989000000002	Ленина	0103000020E61000000100000005000000BAA1293BFDC04B407BC03C64CA814C40BAA1293BFDC04B40EC4B361E6C834C403A07CF8426C54B40EC4B361E6C834C403A07CF8426C54B407BC03C64CA814C40BAA1293BFDC04B407BC03C64CA814C40
53783	23517	55.398825000000002	55.440893000000003	56.995640999999999	56.987363999999999	Ленина	0103000020E61000000100000005000000E2E995B20CB34B40B69F8CF1617E4C40E2E995B20CB34B4043C70E2A717F4C4086048C2E6FB84B4043C70E2A717F4C4086048C2E6FB84B40B69F8CF1617E4C40E2E995B20CB34B40B69F8CF1617E4C40
52071	23439	55.609766999999998	55.636024999999997	56.906540999999997	56.882289	Карла Маркса	0103000020E610000001000000050000000B9755D80CCE4B406E4F90D8EE704C400B9755D80CCE4B40D7BD158909744C401D38674469D14B40D7BD158909744C401D38674469D14B406E4F90D8EE704C400B9755D80CCE4B406E4F90D8EE704C40
51563	23400	55.592080000000003	55.612363999999999	56.913922999999997	56.879624	Ленина	0103000020E61000000100000005000000CF4E0647C9CB4B406B63EC8497704C40CF4E0647C9CB4B40F607CA6DFB744C40B69F8CF161CE4B40F607CA6DFB744C40B69F8CF161CE4B406B63EC8497704C40CF4E0647C9CB4B406B63EC8497704C40
53249	32840	55.546301999999997	55.572989999999997	57.066949999999999	57.055996	Ленина	0103000020E61000000100000005000000A4DE5339EDC54B40795A7EE02A874C40A4DE5339EDC54B40CD3B4ED191884C40AF777FBC57C94B40CD3B4ED191884C40AF777FBC57C94B40795A7EE02A874C40A4DE5339EDC54B40795A7EE02A874C40
52312	56343	55.897731	55.940913000000002	56.793951999999997	56.780245000000001	Ленина	0103000020E610000001000000050000007DCD72D9E8F24B400BEF7211DF634C407DCD72D9E8F24B40014C1938A0654C40CDB051D66FF84B40014C1938A0654C40CDB051D66FF84B400BEF7211DF634C407DCD72D9E8F24B400BEF7211DF634C40
52570	56371	56.018042999999999	56.035469999999997	56.783780999999998	56.771565000000002	Центральная	0103000020E61000000100000005000000FB75A73B4F024C407FDE54A4C2624C40FB75A73B4F024C40F31C91EF52644C409BFEEC478A044C40F31C91EF52644C409BFEEC478A044C407FDE54A4C2624C40FB75A73B4F024C407FDE54A4C2624C40
53766	32797	55.575873999999999	55.598250999999998	57.016302000000003	57.004088000000003	Ленина	0103000020E61000000100000005000000F04E3E3DB6C94B402D27A1F485804C40F04E3E3DB6C94B40016E162F16824C404FE61F7D93CC4B40016E162F16824C404FE61F7D93CC4B402D27A1F485804C40F04E3E3DB6C94B402D27A1F485804C40
53774	23254	55.675047999999997	55.701062999999998	57.039907999999997	57.026423999999999	Ленина	0103000020E61000000100000005000000779D0DF967D64B402DEA93DC61834C40779D0DF967D64B40A46C91B41B854C40C3B7B06EBCD94B40A46C91B41B854C40C3B7B06EBCD94B402DEA93DC61834C40779D0DF967D64B402DEA93DC61834C40
53787	23913	55.916587	55.95234	56.865319	56.852001999999999	Колхозная	0103000020E6100000010000000500000029780AB952F54B403410CB660E6D4C4029780AB952F54B40C0CDE2C5C26E4C401956F146E6F94B40C0CDE2C5C26E4C401956F146E6F94B403410CB660E6D4C4029780AB952F54B403410CB660E6D4C40
51416	23130	55.497504999999997	55.541370000000001	57.097135000000002	57.076838000000002	Советская	0103000020E61000000100000005000000594C6C3EAEBF4B40878BDCD3D5894C40594C6C3EAEBF4B40032670EB6E8C4C408C84B69C4BC54B40032670EB6E8C4C408C84B69C4BC54B40878BDCD3D5894C40594C6C3EAEBF4B40878BDCD3D5894C40
53198	23617	55.722909999999999	55.743679	56.608629999999998	56.598056999999997	Фрунзе	0103000020E61000000100000005000000C6F99B5088DC4B406A12BC218D4C4C40C6F99B5088DC4B40A7AE7C96E74D4C406ADC9BDF30DF4B40A7AE7C96E74D4C406ADC9BDF30DF4B406A12BC218D4C4C40C6F99B5088DC4B406A12BC218D4C4C40
64585	58283	55.517493000000002	55.550469999999997	56.717134999999999	56.707614999999997	Центральная	0103000020E610000001000000050000005874EB353DC24B405B94D920935A4C405874EB353DC24B4092E86514CB5B4C40EDB60BCD75C64B4092E86514CB5B4C40EDB60BCD75C64B405B94D920935A4C405874EB353DC24B405B94D920935A4C40
53245	22945	55.840958000000001	55.863576999999999	56.879009000000003	56.865716999999997	Молодежная	0103000020E61000000100000005000000A0A70183A4EB4B40AD4B8DD0CF6E4C40A0A70183A4EB4B40E1F1ED5D83704C40F549EEB089EE4B40E1F1ED5D83704C40F549EEB089EE4B40AD4B8DD0CF6E4C40A0A70183A4EB4B40AD4B8DD0CF6E4C40
51668	45514	55.406128000000002	55.447082999999999	56.857736000000003	56.834707000000002	Ленина	0103000020E61000000100000005000000B5FE9600FCB34B40035FD1ADD76A4C40B5FE9600FCB34B400A4D124BCA6D4C407DCC07043AB94B400A4D124BCA6D4C407DCC07043AB94B40035FD1ADD76A4C40B5FE9600FCB34B40035FD1ADD76A4C40
81100	62075	55.537660000000002	55.568255999999998	56.990409999999997	56.975372	Советская	0103000020E61000000100000005000000062FFA0AD2C44B4091B75CFDD87C4C40062FFA0AD2C44B40D0D03FC1C57E4C40BDE0D39CBCC84B40D0D03FC1C57E4C40BDE0D39CBCC84B4091B75CFDD87C4C40062FFA0AD2C44B4091B75CFDD87C4C40
53768	22949	55.799114000000003	55.816217999999999	56.899424000000003	56.887546	Мусы Джалиля	0103000020E610000001000000050000004CE3175E49E64B400AD9791B9B714C404CE3175E49E64B40679E5C5320734C400934D8D479E84B40679E5C5320734C400934D8D479E84B400AD9791B9B714C404CE3175E49E64B400AD9791B9B714C40
52298	32820	55.333410000000001	55.354717999999998	56.841757999999999	56.824424	Ленина	0103000020E610000001000000050000006614CB2DADAA4B40CD04C3B986694C406614CB2DADAA4B40BC92E4B9BE6B4C40B9A6406667AD4B40BC92E4B9BE6B4C40B9A6406667AD4B40CD04C3B986694C406614CB2DADAA4B40CD04C3B986694C40
51676	22601	55.562238000000001	55.615192999999998	56.941768000000003	56.908900000000003	Советская	0103000020E61000000100000005000000C3482F6AF7C74B40CEAACFD556744C40C3482F6AF7C74B40AD3594DA8B784C4033DDEBA4BECE4B40AD3594DA8B784C4033DDEBA4BECE4B40CEAACFD556744C40C3482F6AF7C74B40CEAACFD556744C40
51417	22601	55.562238000000001	55.615192999999998	56.941768000000003	56.908900000000003	Ленина	0103000020E61000000100000005000000C3482F6AF7C74B40CEAACFD556744C40C3482F6AF7C74B40AD3594DA8B784C4033DDEBA4BECE4B40AD3594DA8B784C4033DDEBA4BECE4B40CEAACFD556744C40C3482F6AF7C74B40CEAACFD556744C40
51756	22601	55.562238000000001	55.615192999999998	56.941768000000003	56.908900000000003	Кирова	0103000020E61000000100000005000000C3482F6AF7C74B40CEAACFD556744C40C3482F6AF7C74B40AD3594DA8B784C4033DDEBA4BECE4B40AD3594DA8B784C4033DDEBA4BECE4B40CEAACFD556744C40C3482F6AF7C74B40CEAACFD556744C40
51562	22601	55.562238000000001	55.615192999999998	56.941768000000003	56.908900000000003	Газовиков	0103000020E61000000100000005000000C3482F6AF7C74B40CEAACFD556744C40C3482F6AF7C74B40AD3594DA8B784C4033DDEBA4BECE4B40AD3594DA8B784C4033DDEBA4BECE4B40CEAACFD556744C40C3482F6AF7C74B40CEAACFD556744C40
63965	33006	55.936214999999997	55.963219000000002	57.006920999999998	56.996440999999997	Центральная	0103000020E610000001000000050000002783A3E4D5F74B405FB2F1608B7F4C402783A3E4D5F74B40EB538EC9E2804C4063F19BC24AFB4B40EB538EC9E2804C4063F19BC24AFB4B405FB2F1608B7F4C402783A3E4D5F74B405FB2F1608B7F4C40
52296	22505	55.602742999999997	55.625020999999997	56.853935999999997	56.836154999999998	Ленина	0103000020E610000001000000050000004B72C0AE26CD4B4085B18520076B4C404B72C0AE26CD4B4043705CC64D6D4C40172829B000D04B4043705CC64D6D4C40172829B000D04B4085B18520076B4C404B72C0AE26CD4B4085B18520076B4C40
63920	58143	55.219754999999999	55.258203000000002	56.968646	56.951208999999999	Ленина	0103000020E61000000100000005000000F5108DEE209C4B4097546D37C1794C40F5108DEE209C4B405BB39597FC7B4C40535DC0CB0CA14B405BB39597FC7B4C40535DC0CB0CA14B4097546D37C1794C40F5108DEE209C4B4097546D37C1794C40
63208	58080	57.553137999999997	57.572020000000002	59.146236000000002	59.132599999999996	9-ой Пятилетки	0103000020E610000001000000050000006116DA39CDC64C408CB96B09F9904D406116DA39CDC64C40BABF7ADCB7924D4037548CF337C94C40BABF7ADCB7924D4037548CF337C94C408CB96B09F9904D406116DA39CDC64C408CB96B09F9904D40
51559	9589	57.227552000000003	57.302256	59.354016999999999	59.316096999999999	Парковая	0103000020E61000000100000005000000D811876C209D4C408EAED2DD75A84D40D811876C209D4C40309DD66D50AD4D4088821953B0A64C40309DD66D50AD4D4088821953B0A64C408EAED2DD75A84D40D811876C209D4C408EAED2DD75A84D40
52068	9589	57.227552000000003	57.302256	59.354016999999999	59.316096999999999	Коммунистическая	0103000020E61000000100000005000000D811876C209D4C408EAED2DD75A84D40D811876C209D4C40309DD66D50AD4D4088821953B0A64C40309DD66D50AD4D4088821953B0A64C408EAED2DD75A84D40D811876C209D4C408EAED2DD75A84D40
51561	9589	57.227552000000003	57.302256	59.354016999999999	59.316096999999999	Заводская	0103000020E61000000100000005000000D811876C209D4C408EAED2DD75A84D40D811876C209D4C40309DD66D50AD4D4088821953B0A64C40309DD66D50AD4D4088821953B0A64C408EAED2DD75A84D40D811876C209D4C408EAED2DD75A84D40
51752	9589	57.227552000000003	57.302256	59.354016999999999	59.316096999999999	6 Пятилетки	0103000020E61000000100000005000000D811876C209D4C408EAED2DD75A84D40D811876C209D4C40309DD66D50AD4D4088821953B0A64C40309DD66D50AD4D4088821953B0A64C408EAED2DD75A84D40D811876C209D4C408EAED2DD75A84D40
52225	56314	57.131189999999997	57.152552	59.166601999999997	59.154223999999999	 Советская	0103000020E61000000100000005000000F7C77BD5CA904C401021AE9CBD934D40F7C77BD5CA904C405EB9DE3653954D403E78EDD286934C405EB9DE3653954D403E78EDD286934C401021AE9CBD934D40F7C77BD5CA904C401021AE9CBD934D40
52115	22358	57.819173999999997	57.839593000000001	59.397758000000003	59.385891000000001	Ленина	0103000020E61000000100000005000000E3DD91B1DAE84C400E6954E064B14D40E3DD91B1DAE84C4077DCF0BBE9B24D40AB798EC877EB4C4077DCF0BBE9B24D40AB798EC877EB4C400E6954E064B14D40E3DD91B1DAE84C400E6954E064B14D40
53224	22249	57.667816999999999	57.695574999999998	59.161014999999999	59.141824	Пушкина	0103000020E610000001000000050000003E5B07077BD54C40DAE4F04927924D403E5B07077BD54C402D95B7239C944D402575029A08D94C402D95B7239C944D402575029A08D94C40DAE4F04927924D403E5B07077BD54C40DAE4F04927924D40
51856	56252	57.449643000000002	57.490597000000001	59.198495000000001	59.179468	Мира	0103000020E610000001000000050000000BF0DDE68DB94C40DA56B3CEF8964D400BF0DDE68DB94C40B3B5BE4868994D400342EBE1CBBE4C40B3B5BE4868994D400342EBE1CBBE4C40DA56B3CEF8964D400BF0DDE68DB94C40DA56B3CEF8964D40
52145	56290	57.031109000000001	57.045786999999997	59.095177	59.089024999999999	Азина	0103000020E610000001000000050000003ECE3461FB834C4061C3D32B658B4D403ECE3461FB834C406B2A8BC22E8C4D407DCA3159DC854C406B2A8BC22E8C4D407DCA3159DC854C4061C3D32B658B4D403ECE3461FB834C4061C3D32B658B4D40
51858	22075	57.424373000000003	57.458374999999997	59.234929999999999	59.204056999999999	Луначарского	0103000020E610000001000000050000001827BEDA51B64C408BC22E8A1E9A4D401827BEDA51B64C40B56CAD2F129E4D40E9263108ACBA4C40B56CAD2F129E4D40E9263108ACBA4C408BC22E8A1E9A4D401827BEDA51B64C408BC22E8A1E9A4D40
52160	22075	57.424373000000003	57.458374999999997	59.234929999999999	59.204056999999999	Лоскутова	0103000020E610000001000000050000001827BEDA51B64C408BC22E8A1E9A4D401827BEDA51B64C40B56CAD2F129E4D40E9263108ACBA4C40B56CAD2F129E4D40E9263108ACBA4C408BC22E8A1E9A4D401827BEDA51B64C408BC22E8A1E9A4D40
64360	46220	57.1387	57.149200999999998	59.151528999999996	59.144713000000003	Центральная	0103000020E6100000010000000500000044FAEDEBC0914C402D27A1F485924D4044FAEDEBC0914C40A2B2614D65934D40E7C3B30419934C40A2B2614D65934D40E7C3B30419934C402D27A1F485924D4044FAEDEBC0914C402D27A1F485924D40
67055	58936	44.945830999999998	45.077632000000001	53.244073999999998	53.164938999999997	 Железнодорожная	0103000020E6100000010000000500000080457EFD10794640DF6A9DB81C954A4080457EFD10794640E6E61BD13D9F4A40C18F6AD8EF894640E6E61BD13D9F4A40C18F6AD8EF894640DF6A9DB81C954A4080457EFD10794640DF6A9DB81C954A40
53344	12202	44.997062	45.041510000000002	53.280237	53.259982999999998	Южная	0103000020E61000000100000005000000CC0A45BA9F7F46400B42791F47A14A40CC0A45BA9F7F4640881057CEDEA34A407E3A1E3350854640881057CEDEA34A407E3A1E33508546400B42791F47A14A40CC0A45BA9F7F46400B42791F47A14A40
53308	56420	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Строительный переулок	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53372	56420	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Советская	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53489	56420	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Сережникова	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53486	56420	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Ленина	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
15946	78	45.030003000000001	45.061757999999998	53.210506000000002	53.207949999999997	улица Чаадаева	0103000020E6100000010000000500000015E46723D7834640029A081B9E9A4A4015E46723D78346404FCE50DCF19A4A401822A7AFE78746404FCE50DCF19A4A401822A7AFE7874640029A081B9E9A4A4015E46723D7834640029A081B9E9A4A40
16304	78	44.936425	44.945013000000003	53.234167999999997	53.229095999999998	улица Минская	0103000020E6100000010000000500000012143FC6DC7746407CD28904539D4A4012143FC6DC77464086E28E37F99D4A40BEA59C2FF678464086E28E37F99D4A40BEA59C2FF67846407CD28904539D4A4012143FC6DC7746407CD28904539D4A40
7929	78	45.029086999999997	45.031880000000001	53.191583999999999	53.189867999999997	улица Касаткина	0103000020E610000001000000050000008FDE701FB9834640494739984D984A408FDE701FB9834640EB3713D385984A40C0B2D2A414844640EB3713D385984A40C0B2D2A414844640494739984D984A408FDE701FB9834640494739984D984A40
8141	78	44.964525000000002	44.978808000000001	53.215273000000003	53.205080000000002	улица 8 Марта	0103000020E610000001000000050000005396218E757B46402788BA0F409A4A405396218E757B46401D5BCF108E9B4A4016889E94497D46401D5BCF108E9B4A4016889E94497D46402788BA0F409A4A405396218E757B46402788BA0F409A4A40
53526	78	44.880262999999999	44.964713000000003	53.223339000000003	53.215192000000002	проспект Строителей	0103000020E610000001000000050000007E703E75AC704640302E55698B9B4A407E703E75AC704640EF75525F969C4A40568330B77B7B4640EF75525F969C4A40568330B77B7B4640302E55698B9B4A407E703E75AC704640302E55698B9B4A40
53493	78	44.910212999999999	44.987692000000003	53.234389	53.214216	проспект Победы	0103000020E6100000010000000500000070B20DDC81744640D5230D6E6B9B4A4070B20DDC8174464065C57075009E4A40AB4203B16C7E464065C57075009E4A40AB4203B16C7E4640D5230D6E6B9B4A4070B20DDC81744640D5230D6E6B9B4A40
53506	78	45.01925	45.028430999999998	53.198014000000001	53.183548999999999	набережная Реки Пензы	0103000020E610000001000000050000005839B4C876824640541B9C887E974A405839B4C8768246403813D38558994A40A69883A0A38346403813D38558994A40A69883A0A3834640541B9C887E974A405839B4C876824640541B9C887E974A40
53498	78	44.923093999999999	44.930810999999999	53.274706999999999	53.256658999999999	Юбилейная	0103000020E610000001000000050000002191B6F127764640AE9CBD33DAA04A402191B6F127764640BB7D569929A34A40E7E099D024774640BB7D569929A34A40E7E099D024774640AE9CBD33DAA04A402191B6F127764640AE9CBD33DAA04A40
53594	78	45.017957000000003	45.021917999999999	53.130288	53.130065999999999	Экспериментальная	0103000020E61000000100000005000000FDDD3B6A4C8246402829B000A6904A40FDDD3B6A4C824640D787F546AD904A40CC988235CE824640D787F546AD904A40CC988235CE8246402829B000A6904A40FDDD3B6A4C8246402829B000A6904A40
53595	78	45.105848000000002	45.113500999999999	53.174726	53.169598000000001	Школьная	0103000020E610000001000000050000006B2C616D8C8D4640C7BB2363B5954A406B2C616D8C8D464065E1EB6B5D964A401A886533878E464065E1EB6B5D964A401A886533878E4640C7BB2363B5954A406B2C616D8C8D4640C7BB2363B5954A40
53543	78	44.991070000000001	44.995911999999997	53.200991999999999	53.193762999999997	Шевченко	0103000020E61000000100000005000000FB05BB61DB7E46406116DA39CD984A40FB05BB61DB7E4640FA60191BBA994A40D3D85E0B7A7F4640FA60191BBA994A40D3D85E0B7A7F46406116DA39CD984A40FB05BB61DB7E46406116DA39CD984A40
53512	78	44.998939	45.019807	53.180965	53.177840000000003	Чкалова	0103000020E6100000010000000500000077D9AF3BDD7F4640D8F50B76C3964A4077D9AF3BDD7F46403E5C72DC29974A40AE9D2809898246403E5C72DC29974A40AE9D280989824640D8F50B76C3964A4077D9AF3BDD7F4640D8F50B76C3964A40
53509	78	45.028717999999998	45.077272000000001	53.210948000000002	53.207949999999997	Чаадаева	0103000020E610000001000000050000003C670B08AD834640029A081B9E9A4A403C670B08AD8346400C941458009B4A40C172840CE48946400C941458009B4A40C172840CE4894640029A081B9E9A4A403C670B08AD834640029A081B9E9A4A40
53796	78	45.022061999999998	45.023085999999999	53.129072000000001	53.11853	Центральная	0103000020E61000000100000005000000FF3D78EDD282464025CCB4FD2B8F4A40FF3D78EDD2824640276A696E85904A406B7F677BF4824640276A696E85904A406B7F677BF482464025CCB4FD2B8F4A40FF3D78EDD282464025CCB4FD2B8F4A40
53520	78	45.041915000000003	45.050556	53.202567000000002	53.199314000000001	Хользунова	0103000020E610000001000000050000001E1B81785D85464046D1031F83994A401E1B81785D854640DA1F28B7ED994A40EC4E779E78864640DA1F28B7ED994A40EC4E779E7886464046D1031F83994A401E1B81785D85464046D1031F83994A40
53440	78	44.867758000000002	45.126994000000003	53.263160999999997	53.103070000000002	Ушакова	0103000020E61000000100000005000000D36BB3B1126F46407099D365318D4A40D36BB3B1126F4640944A7842AFA14A40E564E25641904640944A7842AFA14A40E564E256419046407099D365318D4A40D36BB3B1126F46407099D365318D4A40
53523	78	44.910212999999999	44.944564	53.236561000000002	53.227414000000003	Ульяновская	0103000020E6100000010000000500000070B20DDC817446408753E6E61B9D4A4070B20DDC8174464029417FA1479E4A404E7D2079E778464029417FA1479E4A404E7D2079E77846408753E6E61B9D4A4070B20DDC817446408753E6E61B9D4A40
53500	78	45.014443999999997	45.022843000000002	53.168301999999997	53.129072000000001	Терновского	0103000020E61000000100000005000000CCCF0D4DD9814640276A696E85904A40CCCF0D4DD9814640FAEC80EB8A954A40A5F8F884EC824640FAEC80EB8A954A40A5F8F884EC824640276A696E85904A40CCCF0D4DD9814640276A696E85904A40
53557	78	44.960500000000003	44.961748999999998	53.155501999999998	53.148491999999997	Тепличная	0103000020E610000001000000050000006DE7FBA9F17A4640DBDB2DC901934A406DE7FBA9F17A4640363B527DE7934A40F8FA5A971A7B4640363B527DE7934A40F8FA5A971A7B4640DBDB2DC901934A406DE7FBA9F17A4640DBDB2DC901934A40
53519	78	45.036453000000002	45.040055000000002	53.196621999999998	53.190595999999999	Тарханова	0103000020E61000000100000005000000A96BED7DAA844640CC5F217365984A40A96BED7DAA84464049D6E1E82A994A404985B1852085464049D6E1E82A994A404985B18520854640CC5F217365984A40A96BED7DAA844640CC5F217365984A40
53545	78	44.999056000000003	45.008982000000003	53.174137000000002	53.172339999999998	Тамбовская	0103000020E61000000100000005000000B16F2711E17F464075E5B33C0F964A40B16F2711E17F46400403081F4A964A4058207A52268146400403081F4A964A4058207A522681464075E5B33C0F964A40B16F2711E17F464075E5B33C0F964A40
1579	78	45.014732000000002	45.015109000000002	53.143107000000001	53.138964000000001	Сухумский проезд	0103000020E61000000100000005000000331AF9BCE281464022A98592C9914A40331AF9BCE2814640126A865451924A4009707A17EF814640126A865451924A4009707A17EF81464022A98592C9914A40331AF9BCE281464022A98592C9914A40
53521	78	44.979598000000003	45.026373999999997	53.205145000000002	53.199908000000001	Суворова	0103000020E610000001000000050000000F9D9E77637D4640B91AD99596994A400F9D9E77637D46400EF8FC30429A4A407BBB2539608346400EF8FC30429A4A407BBB253960834640B91AD99596994A400F9D9E77637D4640B91AD99596994A40
53510	78	44.880262999999999	44.964713000000003	53.223339000000003	53.215192000000002	Строителей проспект	0103000020E610000001000000050000007E703E75AC704640302E55698B9B4A407E703E75AC704640EF75525F969C4A40568330B77B7B4640EF75525F969C4A40568330B77B7B4640302E55698B9B4A407E703E75AC704640302E55698B9B4A40
15374	78	44.880262999999999	44.943980000000003	53.223339000000003	53.218998999999997	Строителей проспект	0103000020E610000001000000050000007E703E75AC704640A86DC328089C4A407E703E75AC704640EF75525F969C4A40FF092E56D4784640EF75525F969C4A40FF092E56D4784640A86DC328089C4A407E703E75AC704640A86DC328089C4A40
53546	78	45.104850999999996	45.119205999999998	53.181714999999997	53.174596000000001	Спартаковская	0103000020E61000000100000005000000F8F9EFC16B8D46409701672959964A40F8F9EFC16B8D4640A818E76F42974A4055BE6724428F4640A818E76F42974A4055BE6724428F46409701672959964A40F8F9EFC16B8D46409701672959964A40
53445	78	45.074739000000001	45.078772000000001	53.184440000000002	53.182426999999997	Сосновка	0103000020E610000001000000050000002D5E2C0C91894640257497C459974A402D5E2C0C918946408109DCBA9B974A4096EB6D33158A46408109DCBA9B974A4096EB6D33158A4640257497C459974A402D5E2C0C91894640257497C459974A40
53280	78	44.941546000000002	44.950384999999997	53.181628000000003	53.175367999999999	Совхоз-техникум	0103000020E61000000100000005000000FED64E9484784640E961687572964A40FED64E9484784640DA0418963F974A40F2CD3637A6794640DA0418963F974A40F2CD3637A6794640E961687572964A40FED64E9484784640E961687572964A40
53499	78	45.010185999999997	45.011263999999997	53.185665	53.182642999999999	Советская	0103000020E6100000010000000500000043705CC64D814640F2EB87D860974A4043705CC64D8146408481E7DEC3974A40A2CF4719718146408481E7DEC3974A40A2CF471971814640F2EB87D860974A4043705CC64D814640F2EB87D860974A40
53516	78	44.909647	44.912413000000001	53.226934999999997	53.218902	Собинова	0103000020E61000000100000005000000C7F319506F744640B68311FB049C4A40C7F319506F744640ACA8C1340C9D4A40FEB8FDF2C9744640ACA8C1340C9D4A40FEB8FDF2C9744640B68311FB049C4A40C7F319506F744640B68311FB049C4A40
53534	78	45.041645000000003	45.046801000000002	53.209271000000001	53.209023000000002	Складская	0103000020E610000001000000050000005E85949F54854640508E0244C19A4A405E85949F5485464028806264C99A4A40C6353E93FD85464028806264C99A4A40C6353E93FD854640508E0244C19A4A405E85949F54854640508E0244C19A4A40
53530	78	45.008488	45.039057999999997	53.153007000000002	53.140785000000001	Ростовская	0103000020E61000000100000005000000483481221681464039622D3E05924A4048348122168146409087BEBB95934A40D65240DAFF8446409087BEBB95934A40D65240DAFF84464039622D3E05924A40483481221681464039622D3E05924A40
53559	78	44.980533000000001	44.980981999999997	53.171466000000002	53.169749000000003	Российская	0103000020E610000001000000050000000BD3F71A827D4640ADC3D155BA954A400BD3F71A827D46401F300F99F2954A407AFB73D1907D46401F300F99F2954A407AFB73D1907D4640ADC3D155BA954A400BD3F71A827D4640ADC3D155BA954A40
53570	78	44.908766	44.944591000000003	53.230955999999999	53.224169000000003	Рахманинова	0103000020E61000000100000005000000BEDBBC715274464076E3DD91B19C4A40BEDBBC7152744640516859F78F9D4A40488C9E5BE8784640516859F78F9D4A40488C9E5BE878464076E3DD91B19C4A40BEDBBC715274464076E3DD91B19C4A40
53514	78	44.976984000000002	45.019824999999997	53.200167	53.194372999999999	Пушкина	0103000020E610000001000000050000008E5BCCCF0D7D4640DA1CE736E1984A408E5BCCCF0D7D4640855E7F129F994A40545227A089824640855E7F129F994A40545227A089824640DA1CE736E1984A408E5BCCCF0D7D4640DA1CE736E1984A40
53581	78	45.030695000000001	45.036408000000002	53.213633999999999	53.210397999999998	Проходная	0103000020E610000001000000050000004B9352D0ED83464068925852EE9A4A404B9352D0ED83464026A8E15B589B4A4009A87004A984464026A8E15B589B4A4009A87004A984464068925852EE9A4A404B9352D0ED83464068925852EE9A4A40
53529	78	45.001418999999999	45.016995000000001	53.214328999999999	53.208984999999998	Пролетарская	0103000020E61000000100000005000000E84B6F7F2E804640622D3E05C09A4A40E84B6F7F2E804640CDCAF6216F9B4A40079964E42C824640CDCAF6216F9B4A40079964E42C824640622D3E05C09A4A40E84B6F7F2E804640622D3E05C09A4A40
53544	78	44.962161999999999	44.985536000000003	53.185977999999999	53.183506000000001	Попова	0103000020E610000001000000050000001BBAD91F287B4640554FE61F7D974A401BBAD91F287B464043E38920CE974A40ED832C0B267E464043E38920CE974A40ED832C0B267E4640554FE61F7D974A401BBAD91F287B4640554FE61F7D974A40
13	78	44.910212999999999	44.987692000000003	53.234389	53.214216	Победы проспект	0103000020E6100000010000000500000070B20DDC81744640D5230D6E6B9B4A4070B20DDC8174464065C57075009E4A40AB4203B16C7E464065C57075009E4A40AB4203B16C7E4640D5230D6E6B9B4A4070B20DDC81744640D5230D6E6B9B4A40
53571	78	45.010761000000002	45.011561	53.201886999999999	53.195915999999997	Плеханова	0103000020E610000001000000050000004089CF9D60814640AE6186C613994A404089CF9D60814640683EE76ED7994A405C74B2D47A814640683EE76ED7994A405C74B2D47A814640AE6186C613994A404089CF9D60814640AE6186C613994A40
53576	78	44.958416	44.964713000000003	53.168512999999997	53.166694	Пермская	0103000020E6100000010000000500000048FB1F60AD7A46403F389F3A56954A4048FB1F60AD7A4640B5F97FD591954A40568330B77B7B4640B5F97FD591954A40568330B77B7B46403F389F3A56954A4048FB1F60AD7A46403F389F3A56954A40
53564	78	45.035500999999996	45.046191	53.173938	53.173397999999999	Перекоп	0103000020E61000000100000005000000D6FCF84B8B8446408D98D9E731964A40D6FCF84B8B8446400DC4B29943964A404D2F3196E98546400DC4B29943964A404D2F3196E98546408D98D9E731964A40D6FCF84B8B8446408D98D9E731964A40
53462	78	44.867758000000002	45.126994000000003	53.263160999999997	53.103070000000002	Парковая	0103000020E61000000100000005000000D36BB3B1126F46407099D365318D4A40D36BB3B1126F4640944A7842AFA14A40E564E25641904640944A7842AFA14A40E564E256419046407099D365318D4A40D36BB3B1126F46407099D365318D4A40
53795	78	45.016573000000001	45.028503000000001	53.169285000000002	53.168064999999999	Отдельная	0103000020E61000000100000005000000917F66101F824640164D672783954A40917F66101F824640085A8121AB954A40406B7EFCA5834640085A8121AB954A40406B7EFCA5834640164D672783954A40917F66101F824640164D672783954A40
53583	78	44.954858999999999	44.970534000000001	53.211207000000002	53.204638000000003	Островского	0103000020E6100000010000000500000048A5D8D1387A46406AC2F693319A4A4048A5D8D1387A4640D8D7BAD4089B4A40FAD346753A7C4640D8D7BAD4089B4A40FAD346753A7C46406AC2F693319A4A4048A5D8D1387A46406AC2F693319A4A40
53538	78	44.930855999999999	44.940854000000002	53.217829000000002	53.217101	Онежская	0103000020E6100000010000000500000087A4164A26774640E6762FF7C99B4A4087A4164A26774640698F17D2E19B4A40C82764E76D784640698F17D2E19B4A40C82764E76D784640E6762FF7C99B4A4087A4164A26774640E6762FF7C99B4A40
53533	78	45.011561	45.018521999999997	53.201886999999999	53.201796000000002	Октябрьская	0103000020E610000001000000050000005C74B2D47A814640583B8A73D4994A405C74B2D47A814640683EE76ED7994A40D520CCED5E824640683EE76ED7994A40D520CCED5E824640583B8A73D4994A405C74B2D47A814640583B8A73D4994A40
53797	78	44.961677000000002	44.987791000000001	53.197932999999999	53.157801999999997	Окружная	0103000020E610000001000000050000005F28603B187B4640279F1EDB32944A405F28603B187B46404BE658DE55994A403E247CEF6F7E46404BE658DE55994A403E247CEF6F7E4640279F1EDB32944A405F28603B187B4640279F1EDB32944A40
54330	78	44.867758000000002	45.126994000000003	53.263160999999997	53.103070000000002	Новая	0103000020E61000000100000005000000D36BB3B1126F46407099D365318D4A40D36BB3B1126F4640944A7842AFA14A40E564E25641904640944A7842AFA14A40E564E256419046407099D365318D4A40D36BB3B1126F46407099D365318D4A40
53562	78	45.016590999999998	45.021388000000002	53.217019999999998	53.216836000000001	Насосная	0103000020E61000000100000005000000373465A71F824640384C3448C19B4A40373465A71F824640F949B54FC79B4A4070438CD7BC824640F949B54FC79B4A4070438CD7BC824640384C3448C19B4A40373465A71F824640384C3448C19B4A40
53553	78	44.906816999999997	44.932921999999998	53.228994	53.224223000000002	Мусоргского	0103000020E61000000100000005000000793A5794127446406901DA56B39C4A40793A579412744640787DE6AC4F9D4A4005DCF3FC69774640787DE6AC4F9D4A4005DCF3FC697746406901DA56B39C4A40793A5794127446406901DA56B39C4A40
53528	78	45.014121000000003	45.018729	53.204287000000001	53.185389999999998	Московская	0103000020E61000000100000005000000EA9788B7CE814640B28009DCBA974A40EA9788B7CE814640BDFF8F13269A4A404F3E3DB665824640BDFF8F13269A4A404F3E3DB665824640B28009DCBA974A40EA9788B7CE814640B28009DCBA974A40
53470	78	45.112395999999997	45.119546999999997	53.21902	53.209395000000001	Молодогвардейская	0103000020E61000000100000005000000C119FCFD628E464014799274CD9A4A40C119FCFD628E4640C095ECD8089C4A40DEAAEB504D8F4640C095ECD8089C4A40DEAAEB504D8F464014799274CD9A4A40C119FCFD628E464014799274CD9A4A40
53508	78	45.008201	45.009512000000001	53.246611999999999	53.241971999999997	Можайского	0103000020E61000000100000005000000B265F9BA0C8146401B4641F0F89E4A40B265F9BA0C8146408C6665FB909F4A40B47570B0378146408C6665FB909F4A40B47570B0378146401B4641F0F89E4A40B265F9BA0C8146401B4641F0F89E4A40
53556	78	44.962764	45.000070999999998	53.193936000000001	53.186771	Мира	0103000020E6100000010000000500000011E2CAD93B7B4640AD6BB41CE8974A4011E2CAD93B7B46402FC214E5D2984A40C9569753028046402FC214E5D2984A40C956975302804640AD6BB41CE8974A4011E2CAD93B7B4640AD6BB41CE8974A40
53554	78	44.936425	44.945013000000003	53.234167999999997	53.229095999999998	Минская	0103000020E6100000010000000500000012143FC6DC7746407CD28904539D4A4012143FC6DC77464086E28E37F99D4A40BEA59C2FF678464086E28E37F99D4A40BEA59C2FF67846407CD28904539D4A4012143FC6DC7746407CD28904539D4A40
53558	78	45.017426999999998	45.020049999999998	53.167330999999997	53.156737999999997	Мебельная	0103000020E61000000100000005000000A088450C3B8246402D05A4FD0F944A40A088450C3B824640B14D2A1A6B954A40742497FF90824640B14D2A1A6B954A40742497FF908246402D05A4FD0F944A40A088450C3B8246402D05A4FD0F944A40
53525	78	44.989696000000002	44.996478000000003	53.159906999999997	53.157412999999998	Маркина	0103000020E61000000100000005000000B37DC85BAE7E46408D7BF31B26944A40B37DC85BAE7E464063B323D577944A407D9752978C7F464063B323D577944A407D9752978C7F46408D7BF31B26944A40B37DC85BAE7E46408D7BF31B26944A40
53537	78	44.878008000000001	44.90016	53.227575999999999	53.222023	Лядова	0103000020E610000001000000050000002DD0EE9062704640DBFAE93F6B9C4A402DD0EE906270464060ADDA35219D4A406C9560713873464060ADDA35219D4A406C95607138734640DBFAE93F6B9C4A402DD0EE9062704640DBFAE93F6B9C4A40
53532	78	44.989668999999999	45.028376999999999	53.213811	53.205221000000002	Луначарского	0103000020E61000000100000005000000B96E4A79AD7E4640E9B985AE449A4A40B96E4A79AD7E46403543AA285E9B4A40B37A87DBA18346403543AA285E9B4A40B37A87DBA1834640E9B985AE449A4A40B96E4A79AD7E4640E9B985AE449A4A40
53566	78	45.038967999999997	45.041232000000001	53.179065000000001	53.171714000000001	Луговая	0103000020E6100000010000000500000096CB46E7FC844640F7216FB9FA954A4096CB46E7FC844640DB6D179AEB964A403BC6151747854640DB6D179AEB964A403BC6151747854640F7216FB9FA954A4096CB46E7FC844640F7216FB9FA954A40
53563	78	45.005738999999998	45.029482000000002	53.229225999999997	53.228622000000001	Литвинова	0103000020E61000000100000005000000E7A7380EBC804640B492567C439D4A40E7A7380EBC8046404AB20E47579D4A400CE9F010C68346404AB20E47579D4A400CE9F010C6834640B492567C439D4A40E7A7380EBC804640B492567C439D4A40
53524	78	44.981242000000002	45.015244000000003	53.183942999999999	53.181843999999998	Лермонтова	0103000020E6100000010000000500000017BB7D56997D4640A67C08AA46974A4017BB7D56997D464000AAB8718B974A40E9BAF083F381464000AAB8718B974A40E9BAF083F3814640A67C08AA46974A4017BB7D56997D4640A67C08AA46974A40
53531	78	44.979958000000003	44.981180000000002	53.189700999999999	53.185406	Ленинградская	0103000020E610000001000000050000000FBA84436F7D4640B83D4162BB974A400FBA84436F7D46405E82531F48984A40A1BE654E977D46405E82531F48984A40A1BE654E977D4640B83D4162BB974A400FBA84436F7D4640B83D4162BB974A40
53540	78	44.988940999999997	45.007159000000001	53.216189	53.213811	Ленина	0103000020E610000001000000050000003656629E957E46403543AA285E9B4A403656629E957E4640A260C614AC9B4A40A06F0B96EA804640A260C614AC9B4A40A06F0B96EA8046403543AA285E9B4A403656629E957E46403543AA285E9B4A40
53536	78	44.876499000000003	44.930748000000001	53.222524999999997	53.216109000000003	Ладожская	0103000020E6100000010000000500000005FD851E3170464086AFAF75A99B4A4005FD851E317046406DC5FEB27B9C4A40A1681EC0227746406DC5FEB27B9C4A40A1681EC02277464086AFAF75A99B4A4005FD851E3170464086AFAF75A99B4A40
53541	78	44.991383999999996	44.999676000000001	53.222136999999996	53.218848000000001	Крупской	0103000020E610000001000000050000008AE3C0ABE57E4640C3651536039C4A408AE3C0ABE57E4640A31D37FC6E9C4A404D4C1762F57F4640A31D37FC6E9C4A404D4C1762F57F4640C3651536039C4A408AE3C0ABE57E4640C3651536039C4A40
53565	78	45.044834000000002	45.052694000000002	53.219273999999999	53.217381000000003	Красносельская	0103000020E61000000100000005000000DBDFD91EBD854640CAE2FE23D39B4A40DBDFD91EBD8546407A6EA12B119C4A4004594FADBE8646407A6EA12B119C4A4004594FADBE864640CAE2FE23D39B4A40DBDFD91EBD854640CAE2FE23D39B4A40
53589	78	44.992103	45.007418999999999	53.170158999999998	53.163012000000002	Краснова	0103000020E61000000100000005000000BAA1293BFD7E4640836DC493DD944A40BAA1293BFD7E46405E0F26C5C7954A403C2F151BF38046405E0F26C5C7954A403C2F151BF3804640836DC493DD944A40BAA1293BFD7E4640836DC493DD944A40
53593	78	45.002522999999997	45.009996999999998	53.192965000000001	53.174132	Красная	0103000020E61000000100000005000000703E75AC52804640F29716F549964A40703E75AC52804640E622BE13B3984A407007EA9447814640E622BE13B3984A407007EA9447814640F29716F549964A40703E75AC52804640F29716F549964A40
53567	78	45.108147000000002	45.112054999999998	53.169074000000002	53.166606999999999	Конструкторская	0103000020E610000001000000050000008C14CAC2D78D46407024D06053954A408C14CAC2D78D46404D4D8237A4954A40382D78D1578E46404D4D8237A4954A40382D78D1578E46407024D06053954A408C14CAC2D78D46407024D06053954A40
53518	78	44.988329999999998	44.997646000000003	53.212544000000001	53.206386000000002	Коммунистическая	0103000020E61000000100000005000000EDD3F198817E4640172D40DB6A9A4A40EDD3F198817E4640037B4CA4349B4A401C7E37DDB27F4640037B4CA4349B4A401C7E37DDB27F4640172D40DB6A9A4A40EDD3F198817E4640172D40DB6A9A4A40
53507	78	45.029032999999998	45.042076000000002	53.223284999999997	53.209476000000002	Колхозная	0103000020E610000001000000050000009CC0745AB783464001A60C1CD09A4A409CC0745AB7834640FB57569A949C4A4027F911BF62854640FB57569A949C4A4027F911BF6285464001A60C1CD09A4A409CC0745AB783464001A60C1CD09A4A40
53551	78	45.015135999999998	45.020912000000003	53.198644999999999	53.181510000000003	Кирова	0103000020E61000000100000005000000027FF8F9EF814640D0F23CB83B974A40027FF8F9EF814640C84109336D994A40070C923EAD824640C84109336D994A40070C923EAD824640D0F23CB83B974A40027FF8F9EF814640D0F23CB83B974A40
53547	78	44.976444999999998	44.986102000000002	53.169575999999999	53.164011000000002	Кижеватова	0103000020E61000000100000005000000DEAB5626FC7C46409697FC4FFE944A40DEAB5626FC7C4640DF1797AAB4954A4096422097387E4640DF1797AAB4954A4096422097387E46409697FC4FFE944A40DEAB5626FC7C46409697FC4FFE944A40
53527	78	44.961092999999998	44.988025	53.213439000000001	53.199595000000002	Карпинского	0103000020E610000001000000050000000FB56D18057B4640FAB836548C994A400FB56D18057B464071581AF8519B4A40B1506B9A777E464071581AF8519B4A40B1506B9A777E4640FAB836548C994A400FB56D18057B4640FAB836548C994A40
53577	78	44.9878	45.015135999999998	53.181510000000003	53.157192000000002	Калинина	0103000020E61000000100000005000000917EFB3A707E4640AF9811DE1E944A40917EFB3A707E4640D0F23CB83B974A40027FF8F9EF814640D0F23CB83B974A40027FF8F9EF814640AF9811DE1E944A40917EFB3A707E4640AF9811DE1E944A40
53513	78	45.025260000000003	45.029184999999998	53.171207000000003	53.158265999999998	Индустриальная	0103000020E61000000100000005000000D0F23CB83B834640CC086F0F42944A40D0F23CB83B83464053EC681CEA954A4052448655BC83464053EC681CEA954A4052448655BC834640CC086F0F42944A40D0F23CB83B834640CC086F0F42944A40
53548	78	45.112395999999997	45.116123999999999	53.174028999999997	53.171919000000003	Зеленая	0103000020E61000000100000005000000C119FCFD628E4640D047197101964A40C119FCFD628E46401DC70F9546964A40EE23B726DD8E46401DC70F9546964A40EE23B726DD8E4640D047197101964A40C119FCFD628E4640D047197101964A40
53550	78	45.000070999999998	45.003529999999998	53.194302999999998	53.193936000000001	Захарова	0103000020E61000000100000005000000C9569753028046402FC214E5D2984A40C956975302804640E141B3EBDE984A400647C9AB73804640E141B3EBDE984A400647C9AB738046402FC214E5D2984A40C9569753028046402FC214E5D2984A40
53582	78	45.060878000000002	45.061245999999997	53.215142999999998	53.210160999999999	Дружбы	0103000020E61000000100000005000000E085ADD9CA87464084F23E8EE69A4A40E085ADD9CA8746404E7B4ACE899B4A406281AFE8D68746404E7B4ACE899B4A406281AFE8D687464084F23E8EE69A4A40E085ADD9CA87464084F23E8EE69A4A40
53574	78	44.985526999999998	44.988115000000001	53.225490000000001	53.222897000000003	Докучаева	0103000020E610000001000000050000009929ADBF257E464032B08EE3879C4A409929ADBF257E46409BC937DBDC9C4A40F1D7648D7A7E46409BC937DBDC9C4A40F1D7648D7A7E464032B08EE3879C4A409929ADBF257E464032B08EE3879C4A40
53535	78	45.002155000000002	45.018405999999999	53.181040000000003	53.163082000000003	Гоголя	0103000020E61000000100000005000000EE42739D468046407C48F8DEDF944A40EE42739D4680464049A297512C974A406C06B8205B82464049A297512C974A406C06B8205B8246407C48F8DEDF944A40EE42739D468046407C48F8DEDF944A40
53580	78	44.996648999999998	45.013033999999998	53.213720000000002	53.207216000000003	Герцена	0103000020E61000000100000005000000A94BC631927F46409E9ACB0D869A4A40A94BC631927F464025404D2D5B9B4A4037DE1D19AB81464025404D2D5B9B4A4037DE1D19AB8146409E9ACB0D869A4A40A94BC631927F46409E9ACB0D869A4A40
15349	78	44.972852000000003	44.984360000000002	53.233274000000002	53.227404	Германа Титова проезд	0103000020E6100000010000000500000092EC116A867C4640637D03931B9D4A4092EC116A867C4640E98024ECDB9D4A40CBBE2B82FF7D4640E98024ECDB9D4A40CBBE2B82FF7D4640637D03931B9D4A4092EC116A867C4640637D03931B9D4A40
53549	78	44.989353999999999	44.999423999999998	53.207949999999997	53.203752999999999	Ворошилова	0103000020E610000001000000050000005915E126A37E46401FBB0B94149A4A405915E126A37E4640029A081B9E9A4A40336B2920ED7F4640029A081B9E9A4A40336B2920ED7F46401FBB0B94149A4A405915E126A37E46401FBB0B94149A4A40
53575	78	44.981538999999998	44.991886999999998	53.166623999999999	53.160507000000003	Воронова	0103000020E61000000100000005000000D05FE811A37D4640B9E34D7E8B944A40D05FE811A37D4640465D6BEF53954A40ED293927F67E4640465D6BEF53954A40ED293927F67E4640B9E34D7E8B944A40D05FE811A37D4640B9E34D7E8B944A40
53552	78	45.011263999999997	45.016554999999997	53.201796000000002	53.185665	Володарского	0103000020E61000000100000005000000A2CF4719718146408481E7DEC3974A40A2CF471971814640583B8A73D4994A40EACA67791E824640583B8A73D4994A40EACA67791E8246408481E7DEC3974A40A2CF4719718146408481E7DEC3974A40
1189	78	44.987279000000001	44.997619	53.174962999999998	53.172097000000001	Водопьянова проезд	0103000020E61000000100000005000000888384285F7E4640AF5E454607964A40888384285F7E46404981053065964A40226FB9FAB17F46404981053065964A40226FB9FAB17F4640AF5E454607964A40888384285F7E4640AF5E454607964A40
53561	78	45.025278	45.031565999999998	53.137014000000001	53.136916999999997	Вадинская	0103000020E6100000010000000500000076A73B4F3C8346401AA20A7F86914A4076A73B4F3C8346400D8CBCAC89914A4030D5CC5A0A8446400D8CBCAC89914A4030D5CC5A0A8446401AA20A7F86914A4076A73B4F3C8346401AA20A7F86914A40
53591	78	44.978780999999998	44.983722	53.157327000000002	53.154998999999997	Бурмистрова	0103000020E610000001000000050000001C7920B2487D4640D3F4D901D7934A401C7920B2487D46408FE3874A23944A40882D3D9AEA7D46408FE3874A23944A40882D3D9AEA7D4640D3F4D901D7934A401C7920B2487D4640D3F4D901D7934A40
53569	78	44.908856	44.924056	53.227483999999997	53.224563000000003	Бородина	0103000020E61000000100000005000000FE62B664557446402272FA7ABE9C4A40FE62B664557446407F2E1A321E9D4A4017D68D77477646407F2E1A321E9D4A4017D68D77477646402272FA7ABE9C4A40FE62B664557446402272FA7ABE9C4A40
53587	78	44.959620000000001	44.968674999999998	53.138326999999997	53.133426999999998	Бийская	0103000020E61000000100000005000000344B02D4D47A4640A2B3CC2214914A40344B02D4D47A4640AF93FAB2B4914A40F5B9DA8AFD7B4640AF93FAB2B4914A40F5B9DA8AFD7B4640A2B3CC2214914A40344B02D4D47A4640A2B3CC2214914A40
53586	78	44.97587	44.998714999999997	53.228955999999997	53.219354000000003	Беляева	0103000020E61000000100000005000000E292E34EE97C4640971FB8CA139C4A40E292E34EE97C46408A1C226E4E9D4A402783A3E4D57F46408A1C226E4E9D4A402783A3E4D57F4640971FB8CA139C4A40E292E34EE97C4640971FB8CA139C4A40
53539	78	44.972501999999999	44.978422000000002	53.204464999999999	53.188567999999997	Бекешская	0103000020E61000000100000005000000B5A50EF27A7C46403B8908FF22984A40B5A50EF27A7C46409C16BCE82B9A4A40EDD79DEE3C7D46409C16BCE82B9A4A40EDD79DEE3C7D46403B8908FF22984A40B5A50EF27A7C46403B8908FF22984A40
53505	78	44.984009	45.030918999999997	53.202238000000001	53.197313000000001	Бакунина	0103000020E610000001000000050000001EFCC401F47D4640AF09698D41994A401EFCC401F47D464015014EEFE2994A409AE95E27F583464015014EEFE2994A409AE95E27F5834640AF09698D41994A401EFCC401F47D4640AF09698D41994A40
53555	78	45.011516	45.017184	53.257133000000003	53.2288	Аустрина	0103000020E61000000100000005000000BCB0355B7981464093A98251499D4A40BCB0355B7981464077DCF0BBE9A04A40DA01D7153382464077DCF0BBE9A04A40DA01D7153382464093A98251499D4A40BCB0355B7981464093A98251499D4A40
53496	78	45.051212	45.069142999999997	53.191561999999998	53.183861999999998	Антонова	0103000020E61000000100000005000000D594641D8E864640137D3ECA88974A40D594641D8E8646400394861A85984A40A8DF85ADD98846400394861A85984A40A8DF85ADD9884640137D3ECA88974A40D594641D8E864640137D3ECA88974A40
53515	78	44.867758000000002	45.126994000000003	53.263160999999997	53.103070000000002	8 Марта	0103000020E61000000100000005000000D36BB3B1126F46407099D365318D4A40D36BB3B1126F4640944A7842AFA14A40E564E25641904640944A7842AFA14A40E564E256419046407099D365318D4A40D36BB3B1126F46407099D365318D4A40
16239	78	44.934511999999998	44.944169000000002	53.223818999999999	53.222141999999998	5-й Виноградный проезд	0103000020E610000001000000050000001ADCD6169E774640B58828266F9C4A401ADCD6169E774640999CDA19A69C4A40D272A087DA784640999CDA19A69C4A40D272A087DA784640B58828266F9C4A401ADCD6169E774640B58828266F9C4A40
53584	78	45.055838999999999	45.060887000000001	53.214528999999999	53.210759000000003	 Медицинская	0103000020E61000000100000005000000B16B7BBB25874640392BA226FA9A4A40B16B7BBB258746409485AFAF759B4A4033E02C25CB8746409485AFAF759B4A4033E02C25CB874640392BA226FA9A4A40B16B7BBB25874640392BA226FA9A4A40
53588	78	44.986902000000001	44.997906	53.224055999999997	53.218567	 Леонова	0103000020E61000000100000005000000B22D03CE527E46400F7EE200FA9B4A40B22D03CE527E46407D3CF4DDAD9C4A40B83D4162BB7F46407D3CF4DDAD9C4A40B83D4162BB7F46400F7EE200FA9B4A40B22D03CE527E46400F7EE200FA9B4A40
53585	78	44.988329999999998	44.997646000000003	53.212544000000001	53.206386000000002	 Коммунистическая	0103000020E61000000100000005000000EDD3F198817E4640172D40DB6A9A4A40EDD3F198817E4640037B4CA4349B4A401C7E37DDB27F4640037B4CA4349B4A401C7E37DDB27F4640172D40DB6A9A4A40EDD3F198817E4640172D40DB6A9A4A40
53590	78	45.025260000000003	45.029184999999998	53.171207000000003	53.158265999999998	 Индустриальная	0103000020E61000000100000005000000D0F23CB83B834640CC086F0F42944A40D0F23CB83B83464053EC681CEA954A4052448655BC83464053EC681CEA954A4052448655BC834640CC086F0F42944A40D0F23CB83B834640CC086F0F42944A40
53416	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Фабричная	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53255	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Строителей	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53269	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Рабочая	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53266	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Правды	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53258	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Осипенко	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53448	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Орджоникидзе	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53257	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Октябрьская	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53262	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Минская	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53415	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Ленина	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53450	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Кирова	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53322	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Калинина	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53413	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Гагарина	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53331	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	Белинского	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53414	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	60-летия ВЛКСМ	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53673	7144	46.543574	46.664748000000003	53.139834	53.089671000000003	1-я Бутурлинская	0103000020E610000001000000050000005B7A34D5934547402733DE567A8B4A405B7A34D593454740376F9C14E6914A406C0A647616554740376F9C14E6914A406C0A6476165547402733DE567A8B4A405B7A34D5934547402733DE567A8B4A40
53466	56419	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Чернышевского	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53468	56419	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Коллективная	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53282	56419	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Гражданская	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
81152	60460	45.170158000000001	45.213177999999999	53.208385999999997	53.189976000000001	проезд Молодежный	0103000020E610000001000000050000008E93C2BCC79546403083312251984A408E93C2BCC7954640DD787764AC9A4A40041DAD6A499B4640DD787764AC9A4A40041DAD6A499B46403083312251984A408E93C2BCC79546403083312251984A40
81153	60460	45.170158000000001	45.213177999999999	53.208385999999997	53.189976000000001	Демакова	0103000020E610000001000000050000008E93C2BCC79546403083312251984A408E93C2BCC7954640DD787764AC9A4A40041DAD6A499B4640DD787764AC9A4A40041DAD6A499B46403083312251984A408E93C2BCC79546403083312251984A40
81145	58927	46.088487999999998	46.100085	53.897106000000001	53.890096999999997	проезд Молодежный	0103000020E61000000100000005000000520B2593530B474044A2D0B2EEF14A40520B2593530B4740CF85915ED4F24A40FBE8D495CF0C4740CF85915ED4F24A40FBE8D495CF0C474044A2D0B2EEF14A40520B2593530B474044A2D0B2EEF14A40
67034	58927	43.526187	43.533706000000002	53.450867000000002	53.447274	Ленина	0103000020E61000000100000005000000494A7A185AC34540F12C414640B94A40494A7A185AC345403EEC8502B6B94A40E9D66B7A50C445403EEC8502B6B94A40E9D66B7A50C44540F12C414640B94A40494A7A185AC34540F12C414640B94A40
53453	56427	43.380381999999997	43.434531999999997	52.975012999999997	52.954689999999999	Советская площадь	0103000020E6100000010000000500000058FE7C5BB0B04540BCE82B48337A4A4058FE7C5BB0B045406116DA39CD7C4A4061889CBE9EB745406116DA39CD7C4A4061889CBE9EB74540BCE82B48337A4A4058FE7C5BB0B04540BCE82B48337A4A40
53490	17853	45.356099999999998	45.417850999999999	52.908377999999999	52.871164999999998	Октябрьская	0103000020E61000000100000005000000840D4FAF94AD4640BD35B055826F4A40840D4FAF94AD4640F433F5BA45744A40EACC3D247CB54640F433F5BA45744A40EACC3D247CB54640BD35B055826F4A40840D4FAF94AD4640BD35B055826F4A40
53491	17853	45.356099999999998	45.417850999999999	52.908377999999999	52.871164999999998	Ленина	0103000020E61000000100000005000000840D4FAF94AD4640BD35B055826F4A40840D4FAF94AD4640F433F5BA45744A40EACC3D247CB54640F433F5BA45744A40EACC3D247CB54640BD35B055826F4A40840D4FAF94AD4640BD35B055826F4A40
54258	17755	45.283794999999998	45.323051	52.978738	52.954456	А.Ж. Богданова 	0103000020E6100000010000000500000058E2016553A4464049BC3C9D2B7A4A4058E2016553A446401DAD6A49477D4A4055F833BC59A946401DAD6A49477D4A4055F833BC59A9464049BC3C9D2B7A4A4058E2016553A4464049BC3C9D2B7A4A40
53313	17755	45.283794999999998	45.323051	52.978738	52.954456	А.Ж. Богданова	0103000020E6100000010000000500000058E2016553A4464049BC3C9D2B7A4A4058E2016553A446401DAD6A49477D4A4055F833BC59A946401DAD6A49477D4A4055F833BC59A9464049BC3C9D2B7A4A4058E2016553A4464049BC3C9D2B7A4A40
54236	9522	45.112468	45.148850000000003	52.867659000000003	52.854267999999998	Школьная	0103000020E610000001000000050000005BECF659658E4640790261A7586D4A405BECF659658E4640408A3A730F6F4A403B014D840D934640408A3A730F6F4A403B014D840D934640790261A7586D4A405BECF659658E4640790261A7586D4A40
54068	17589	45.262881999999998	45.295760999999999	52.887953000000003	52.863821000000002	Юбилейная	0103000020E61000000100000005000000815A0C1EA6A146408C4CC0AF916E4A40815A0C1EA6A146404BB1A371A8714A405437177FDBA546404BB1A371A8714A405437177FDBA546408C4CC0AF916E4A40815A0C1EA6A146408C4CC0AF916E4A40
53782	17562	45.210448	45.269170000000003	52.915041000000002	52.891033	  Школьная площадь	0103000020E610000001000000050000001AC1C6F5EF9A464011548D5E0D724A401AC1C6F5EF9A4640E4BF401020754A403C889D2974A24640E4BF401020754A403C889D2974A2464011548D5E0D724A401AC1C6F5EF9A464011548D5E0D724A40
53681	17493	45.145113000000002	45.187783000000003	52.947864000000003	52.901355000000002	Совхозная	0103000020E61000000100000005000000BB9C121093924640058BC3995F734A40BB9C1210939246402387889B53794A4055DFF945099846402387889B53794A4055DFF94509984640058BC3995F734A40BB9C121093924640058BC3995F734A40
53684	17654	45.402714000000003	45.442644000000001	53.032967999999997	53.014411000000003	Заречная 	0103000020E6100000010000000500000018D2E1218CB34640F1D93A38D8814A4018D2E1218CB3464042E8A04B38844A40A4E2FF8EA8B8464042E8A04B38844A40A4E2FF8EA8B84640F1D93A38D8814A4018D2E1218CB34640F1D93A38D8814A40
53834	9649	45.191223999999998	45.209639000000003	52.796812000000003	52.785680999999997	Лесная	0103000020E61000000100000005000000EB1A2D077A984640560BEC3191644A40EB1A2D077A984640BA8784EFFD654A40AB7B6473D59A4640BA8784EFFD654A40AB7B6473D59A4640560BEC3191644A40EB1A2D077A984640560BEC3191644A40
53646	17415	45.372107999999997	45.421498	52.694172999999999	52.671866000000001	Школьная	0103000020E610000001000000050000003C4A253CA1AF4640ADA580B4FF554A403C4A253CA1AF464013622EA9DA584A402AAA7EA5F3B5464013622EA9DA584A402AAA7EA5F3B54640ADA580B4FF554A403C4A253CA1AF4640ADA580B4FF554A40
54254	17407	45.364382999999997	45.395186000000002	52.817613000000001	52.795326000000003	Центральная	0103000020E61000000100000005000000F31B261AA4AE46404AD40B3ECD654A40F31B261AA4AE464069E4F38AA7684A4025EB707495B2464069E4F38AA7684A4025EB707495B246404AD40B3ECD654A40F31B261AA4AE46404AD40B3ECD654A40
54158	17340	45.569629999999997	45.586329999999997	53.037083000000003	53.025944000000003	 Молодежная	0103000020E610000001000000050000000569C6A2E9C8464083C30B2252834A400569C6A2E9C84640691EC022BF844A40F35487DC0CCB4640691EC022BF844A40F35487DC0CCB464083C30B2252834A400569C6A2E9C8464083C30B2252834A40
54157	17276	45.727392000000002	45.754997000000003	52.946106	52.921284999999997	Специалистов	0103000020E610000001000000050000009FAF592E1BDD4640CEA5B8AAEC754A409FAF592E1BDD464052465C001A794A4000CADFBDA3E0464052465C001A794A4000CADFBDA3E04640CEA5B8AAEC754A409FAF592E1BDD4640CEA5B8AAEC754A40
54067	17257	45.267705999999997	45.310628000000001	52.882758000000003	52.852500999999997	Чехманова	0103000020E61000000100000005000000B378B13044A246405567B5C01E6D4A40B378B13044A246402524D236FE704A40679C86A8C2A746402524D236FE704A40679C86A8C2A746405567B5C01E6D4A40B378B13044A246405567B5C01E6D4A40
9881	17209	45.614725	45.648969000000001	52.960661999999999	52.941243999999998	Ленина	0103000020E610000001000000050000004D840D4FAFCE464032C7F2AE7A784A404D840D4FAFCE46404641F0F8F67A4A40158F8B6A11D346404641F0F8F67A4A40158F8B6A11D3464032C7F2AE7A784A404D840D4FAFCE464032C7F2AE7A784A40
53942	17150	45.440201000000002	45.477310000000003	52.854692	52.845170000000003	Сельская	0103000020E610000001000000050000005055A18158B84640B9C7D2872E6C4A405055A18158B846409013268C666D4A40E2067C7E18BD46409013268C666D4A40E2067C7E18BD4640B9C7D2872E6C4A405055A18158B84640B9C7D2872E6C4A40
54162	32699	45.553209000000003	45.604241999999999	52.778655000000001	52.762113999999997	Октябрьская	0103000020E610000001000000050000002B6D718DCFC6464070E998F38C614A402B6D718DCFC64640F6EE8FF7AA634A40506F46CD57CD4640F6EE8FF7AA634A40506F46CD57CD464070E998F38C614A402B6D718DCFC6464070E998F38C614A40
54279	17059	45.530320000000003	45.558967000000003	53.083289000000001	53.070169999999997	Советская	0103000020E6100000010000000500000016359886E1C3464085949F54FB884A4016359886E1C34640EB8EC536A98A4A4089450C3B8CC74640EB8EC536A98A4A4089450C3B8CC7464085949F54FB884A4016359886E1C3464085949F54FB884A40
53933	16924	45.519728999999998	45.542537000000003	52.784962999999998	52.763035000000002	Школьная	0103000020E6100000010000000500000032E4D87A86C24640085A8121AB614A4032E4D87A86C24640F7C8E6AA79644A405BEF37DA71C54640F7C8E6AA79644A405BEF37DA71C54640085A8121AB614A4032E4D87A86C24640085A8121AB614A40
53932	16995	45.506371000000001	45.531208999999997	52.688097999999997	52.673357000000003	Лесная	0103000020E610000001000000050000004852D2C3D0C046402FC4EA8F30564A404852D2C3D0C04640B438639813584A40A12B11A8FEC34640B438639813584A40A12B11A8FEC346402FC4EA8F30564A404852D2C3D0C046402FC4EA8F30564A40
54252	16913	45.235277000000004	45.254564000000002	52.821187999999999	52.809677000000001	Молодежная	0103000020E610000001000000050000002140868E1D9E464065A9F57EA3674A402140868E1D9E46400FEF39B01C694A40965E9B8D95A046400FEF39B01C694A40965E9B8D95A0464065A9F57EA3674A402140868E1D9E464065A9F57EA3674A40
53781	16855	45.548870000000001	45.585099	52.875709000000001	52.852880999999996	Центральная	0103000020E61000000100000005000000B5E0455F41C646409C3061342B6D4A40B5E0455F41C646400CE8853B17704A400EF62686E4CA46400CE8853B17704A400EF62686E4CA46409C3061342B6D4A40B5E0455F41C646409C3061342B6D4A40
53644	16767	43.254950000000001	43.278557999999997	52.694674999999997	52.677064000000001	Новая	0103000020E61000000100000005000000BF0E9C33A2A0454044A67C08AA564A40BF0E9C33A2A04540A52C431CEB584A400305DEC9A7A34540A52C431CEB584A400305DEC9A7A3454044A67C08AA564A40BF0E9C33A2A0454044A67C08AA564A40
53642	15631	43.198554000000001	43.282798	52.556612999999999	52.525213000000001	Центральная	0103000020E61000000100000005000000B83EAC376A9945408F37F92D3A434A40B83EAC376A994540A4C343183F474A40E6AF90B932A44540A4C343183F474A40E6AF90B932A445408F37F92D3A434A40B83EAC376A9945408F37F92D3A434A40
53374	15631	43.198554000000001	43.282798	52.556612999999999	52.525213000000001	Транспортная	0103000020E61000000100000005000000B83EAC376A9945408F37F92D3A434A40B83EAC376A994540A4C343183F474A40E6AF90B932A44540A4C343183F474A40E6AF90B932A445408F37F92D3A434A40B83EAC376A9945408F37F92D3A434A40
53371	15631	43.198554000000001	43.282798	52.556612999999999	52.525213000000001	Советская	0103000020E61000000100000005000000B83EAC376A9945408F37F92D3A434A40B83EAC376A994540A4C343183F474A40E6AF90B932A44540A4C343183F474A40E6AF90B932A445408F37F92D3A434A40B83EAC376A9945408F37F92D3A434A40
54274	15631	43.198554000000001	43.282798	52.556612999999999	52.525213000000001	Пролетарская	0103000020E61000000100000005000000B83EAC376A9945408F37F92D3A434A40B83EAC376A994540A4C343183F474A40E6AF90B932A44540A4C343183F474A40E6AF90B932A445408F37F92D3A434A40B83EAC376A9945408F37F92D3A434A40
53802	15631	43.198554000000001	43.282798	52.556612999999999	52.525213000000001	Заводская	0103000020E61000000100000005000000B83EAC376A9945408F37F92D3A434A40B83EAC376A994540A4C343183F474A40E6AF90B932A44540A4C343183F474A40E6AF90B932A445408F37F92D3A434A40B83EAC376A9945408F37F92D3A434A40
53683	15631	43.198554000000001	43.282798	52.556612999999999	52.525213000000001	Железнодорожная	0103000020E61000000100000005000000B83EAC376A9945408F37F92D3A434A40B83EAC376A994540A4C343183F474A40E6AF90B932A44540A4C343183F474A40E6AF90B932A445408F37F92D3A434A40B83EAC376A9945408F37F92D3A434A40
53930	16614	43.462119000000001	43.481369999999998	52.774123000000003	52.762877000000003	Центральная	0103000020E610000001000000050000001CEE23B726BB454070EF1AF4A5614A401CEE23B726BB45406C0A647616634A4044A33B889DBD45406C0A647616634A4044A33B889DBD454070EF1AF4A5614A401CEE23B726BB454070EF1AF4A5614A40
53938	56468	43.177245999999997	43.185313000000001	52.826183999999998	52.819440999999998	Железнодорожная	0103000020E6100000010000000500000064AC36FFAF96454032005471E3684A4064AC36FFAF9645403E3DB665C0694A4007431D56B89745403E3DB665C0694A4007431D56B897454032005471E3684A4064AC36FFAF96454032005471E3684A40
53981	56476	43.306638999999997	43.323779000000002	52.631067000000002	52.621313999999998	Овражная	0103000020E61000000100000005000000CD565EF23FA7454002469737874F4A40CD565EF23FA74540DC4AAFCDC6504A40D8101C9771A94540DC4AAFCDC6504A40D8101C9771A9454002469737874F4A40CD565EF23FA7454002469737874F4A40
53817	19385	43.234971000000002	43.253107999999997	52.755181999999998	52.738664999999997	Иванова	0103000020E6100000010000000500000014419C87139E454094D920938C5E4A4014419C87139E45409143C4CDA9604A40902DCBD765A045409143C4CDA9604A40902DCBD765A0454094D920938C5E4A4014419C87139E454094D920938C5E4A40
53929	16141	43.398859999999999	43.417752	52.597340000000003	52.581710000000001	Центральная	0103000020E610000001000000050000005ED72FD80DB34540CAE02879754A4A405ED72FD80DB34540DC4B1AA3754C4A4057EBC4E578B54540DC4B1AA3754C4A4057EBC4E578B54540CAE02879754A4A405ED72FD80DB34540CAE02879754A4A40
54037	963	43.389338000000002	43.398285000000001	52.833936999999999	52.82226	Ленина	0103000020E61000000100000005000000878BDCD3D5B145408C67D0D03F694A40878BDCD3D5B1454051F69672BE6A4A4062BEBC00FBB2454051F69672BE6A4A4062BEBC00FBB245408C67D0D03F694A40878BDCD3D5B145408C67D0D03F694A40
54260	56510	43.500926999999997	43.522226000000003	52.714308000000003	52.706581999999997	Садовая	0103000020E6100000010000000500000079573D601EC045409CF86A47715A4A4079573D601EC04540B6A2CD716E5B4A407A8F334DD8C24540B6A2CD716E5B4A407A8F334DD8C245409CF86A47715A4A4079573D601EC045409CF86A47715A4A40
53791	19685	43.170239000000002	43.202407000000001	52.509588999999998	52.493454999999997	 Школьная	0103000020E610000001000000050000007BC03C64CA9545401A868F88293F4A407BC03C64CA9545405FB35C363A414A40A1BDFA78E89945405FB35C363A414A40A1BDFA78E89945401A868F88293F4A407BC03C64CA9545401A868F88293F4A40
53713	56448	43.278863000000001	43.296353000000003	52.742153999999999	52.734777000000001	Советская	0103000020E61000000100000005000000408864C8B1A345402F6D382C0D5E4A40408864C8B1A345403C4CFBE6FE5E4A40278925E5EEA545403C4CFBE6FE5E4A40278925E5EEA545402F6D382C0D5E4A40408864C8B1A345402F6D382C0D5E4A40
54264	19333	43.391807999999997	43.414076999999999	52.814352999999997	52.786934000000002	Центральная	0103000020E61000000100000005000000D427B9C326B24540240ED940BA644A40D427B9C326B24540223317B83C684A404D83A27900B54540223317B83C684A404D83A27900B54540240ED940BA644A40D427B9C326B24540240ED940BA644A40
53977	16628	43.184199	43.200656000000002	52.812170000000002	52.789749999999998	Передовик	0103000020E610000001000000050000005B7A34D5939745400C022B8716654A405B7A34D5939745406B65C22FF5674A4083DF8618AF9945406B65C22FF5674A4083DF8618AF9945400C022B8716654A405B7A34D5939745400C022B8716654A40
54155	16628	43.184199	43.200656000000002	52.812170000000002	52.789749999999998	Молодежная	0103000020E610000001000000050000005B7A34D5939745400C022B8716654A405B7A34D5939745406B65C22FF5674A4083DF8618AF9945406B65C22FF5674A4083DF8618AF9945400C022B8716654A405B7A34D5939745400C022B8716654A40
54250	16008	43.073877000000003	43.101301999999997	52.490571000000003	52.472636999999999	Мира	0103000020E610000001000000050000009B7631CD7489454095F0845E7F3C4A409B7631CD74894540DAAED007CB3E4A407B82C476F78C4540DAAED007CB3E4A407B82C476F78C454095F0845E7F3C4A409B7631CD7489454095F0845E7F3C4A40
54266	19772	43.375585000000001	43.401133000000002	52.389049	52.378076999999998	Центральная	0103000020E6100000010000000500000020EF552B13B04540552FBFD364304A4020EF552B13B0454050C58D5BCC314A40562C7E5358B3454050C58D5BCC314A40562C7E5358B34540552FBFD364304A4020EF552B13B04540552FBFD364304A40
54253	16182	43.375450000000001	43.435583000000001	52.531004000000003	52.506070000000001	Школьная	0103000020E6100000010000000500000040A4DFBE0EB045404DBED9E6C6404A4040A4DFBE0EB04540C90567F0F7434A40C7D8092FC1B74540C90567F0F7434A40C7D8092FC1B745404DBED9E6C6404A4040A4DFBE0EB045404DBED9E6C6404A40
54151	16318	43.592177	43.610844	52.781297000000002	52.762784000000003	Центральная	0103000020E61000000100000005000000C138B874CCCB4540BFF4F6E7A2614A40C138B874CCCB454041BB438A01644A409A7ADD2230CE454041BB438A01644A409A7ADD2230CE4540BFF4F6E7A2614A40C138B874CCCB4540BFF4F6E7A2614A40
54262	18722	43.386868	43.426780000000001	52.77178	52.755432999999996	Молодежная	0103000020E6100000010000000500000039EFFFE384B14540DAA84E07B2604A4039EFFFE384B145407BDAE1AFC9624A401F4B1FBAA0B645407BDAE1AFC9624A401F4B1FBAA0B64540DAA84E07B2604A4039EFFFE384B14540DAA84E07B2604A40
53788	19812	43.427695999999997	43.471992	52.652000999999998	52.626333000000002	 Крылова	0103000020E61000000100000005000000A45016BEBEB64540EAB303AE2B504A40A45016BEBEB64540CAFACDC474534A40A0FCDD3B6ABC4540CAFACDC474534A40A0FCDD3B6ABC4540EAB303AE2B504A40A45016BEBEB64540EAB303AE2B504A40
53928	16019	43.282105999999999	43.302300000000002	52.469586999999997	52.454315999999999	Центральная	0103000020E61000000100000005000000B000A60C1CA445405706D506273A4A40B000A60C1CA4454039D0436D1B3C4A4058CA32C4B1A6454039D0436D1B3C4A4058CA32C4B1A645405706D506273A4A40B000A60C1CA445405706D506273A4A40
53950	16306	43.381827999999999	43.407249999999998	52.664361999999997	52.646576000000003	Центральная	0103000020E610000001000000050000003A596ABDDFB0454073309B00C3524A403A596ABDDFB04540425A63D009554A40E3A59BC420B44540425A63D009554A40E3A59BC420B4454073309B00C3524A403A596ABDDFB0454073309B00C3524A40
53931	16809	43.202893000000003	43.240989999999996	52.605277000000001	52.582656	Молодёжная	0103000020E610000001000000050000002ECBD765F8994540BA68C878944A4A402ECBD765F8994540B0027CB7794D4A40DE54A4C2D89E4540B0027CB7794D4A40DE54A4C2D89E4540BA68C878944A4A402ECBD765F8994540BA68C878944A4A40
53959	56473	43.253773000000002	43.286382000000003	52.676501999999999	52.655208000000002	Середочка	0103000020E61000000100000005000000CDCD37A27BA04540EE0912DBDD534A40CDCD37A27BA04540DCD6169E97564A40E014562AA8A44540DCD6169E97564A40E014562AA8A44540EE0912DBDD534A40CDCD37A27BA04540EE0912DBDD534A40
54242	33029	46.368825000000001	46.399790000000003	53.449012000000003	53.441616000000003	Школьная	0103000020E610000001000000050000003E7958A8352F4740F7B182DF86B84A403E7958A8352F47407BC1A73979B94A4049A297512C3347407BC1A73979B94A4049A297512C334740F7B182DF86B84A403E7958A8352F4740F7B182DF86B84A40
54064	33024	46.463605999999999	46.484968000000002	53.422888	53.400253999999997	Лесная	0103000020E610000001000000050000005C1D0071573B4740ED0BE8853BB34A405C1D0071573B474078EFA83121B64A40A3CD716E133E474078EFA83121B64A40A3CD716E133E4740ED0BE8853BB34A405C1D0071573B4740ED0BE8853BB34A40
54241	14298	46.435076000000002	46.464225999999996	53.389820999999998	53.368248999999999	Песчаная	0103000020E6100000010000000500000023A30392B037474071E481C822AF4A4023A30392B0374740A2258FA7E5B14A40F8F9EFC16B3B4740A2258FA7E5B14A40F8F9EFC16B3B474071E481C822AF4A4023A30392B037474071E481C822AF4A40
53920	33016	46.202646000000001	46.221555000000002	53.366970999999999	53.359571000000003	Дачная	0103000020E610000001000000050000002655DB4DF019474086CB2A6C06AE4A402655DB4DF01947404BCADDE7F8AE4A40F5A10BEA5B1C47404BCADDE7F8AE4A40F5A10BEA5B1C474086CB2A6C06AE4A402655DB4DF019474086CB2A6C06AE4A40
53778	14236	46.233144000000003	46.256284000000001	53.339343999999997	53.317435000000003	Учительская	0103000020E610000001000000050000001BA19FA9D71D47408ACDC7B5A1A84A401BA19FA9D71D4740020CCB9F6FAB4A40793E03EACD204740020CCB9F6FAB4A40793E03EACD2047408ACDC7B5A1A84A401BA19FA9D71D47408ACDC7B5A1A84A40
53916	14170	45.995035999999999	46.020009000000002	53.427990999999999	53.418810000000001	Полевая	0103000020E61000000100000005000000DC2BF3565DFF46406F9EEA909BB54A40DC2BF3565DFF4640BDFDB968C8B64A401650A8A78F024740BDFDB968C8B64A401650A8A78F0247406F9EEA909BB54A40DC2BF3565DFF46406F9EEA909BB54A40
53637	32975	46.231329000000002	46.275984000000001	53.317435000000003	53.277534000000003	Театральная	0103000020E61000000100000005000000E6CE4C309C1D474098C3EE3B86A34A40E6CE4C309C1D47408ACDC7B5A1A84A40111C9771532347408ACDC7B5A1A84A40111C97715323474098C3EE3B86A34A40E6CE4C309C1D474098C3EE3B86A34A40
53405	32975	46.231329000000002	46.275984000000001	53.317435000000003	53.277534000000003	Ленина	0103000020E61000000100000005000000E6CE4C309C1D474098C3EE3B86A34A40E6CE4C309C1D47408ACDC7B5A1A84A40111C9771532347408ACDC7B5A1A84A40111C97715323474098C3EE3B86A34A40E6CE4C309C1D474098C3EE3B86A34A40
53312	32975	46.231329000000002	46.275984000000001	53.317435000000003	53.277534000000003	Кададинская	0103000020E61000000100000005000000E6CE4C309C1D474098C3EE3B86A34A40E6CE4C309C1D47408ACDC7B5A1A84A40111C9771532347408ACDC7B5A1A84A40111C97715323474098C3EE3B86A34A40E6CE4C309C1D474098C3EE3B86A34A40
53370	32975	46.231329000000002	46.275984000000001	53.317435000000003	53.277534000000003	Гагарина	0103000020E61000000100000005000000E6CE4C309C1D474098C3EE3B86A34A40E6CE4C309C1D47408ACDC7B5A1A84A40111C9771532347408ACDC7B5A1A84A40111C97715323474098C3EE3B86A34A40E6CE4C309C1D474098C3EE3B86A34A40
53919	13842	46.666015000000002	46.684393999999998	53.428629000000001	53.413356999999998	Новая	0103000020E610000001000000050000009ED2C1FA3F5547404D49D6E1E8B44A409ED2C1FA3F554740008FA850DDB64A4010CAFB389A574740008FA850DDB64A4010CAFB389A5747404D49D6E1E8B44A409ED2C1FA3F5547404D49D6E1E8B44A40
54244	13791	46.046796999999998	46.075606000000001	53.368898999999999	53.359490999999998	Центральная	0103000020E610000001000000050000008446B071FD054740691A14CD03AE4A408446B071FD05474078431A1538AF4A40D1B01875AD09474078431A1538AF4A40D1B01875AD094740691A14CD03AE4A408446B071FD054740691A14CD03AE4A40
54144	13701	46.549961000000003	46.571340999999997	53.448383999999997	53.434916999999999	Школьная	0103000020E61000000100000005000000A9893E1F65464740BABC395CABB74A40A9893E1F654647405B069CA564B94A4095EEAEB3214947405B069CA564B94A4095EEAEB321494740BABC395CABB74A40A9893E1F65464740BABC395CABB74A40
54243	13630	46.309797000000003	46.331806	53.462743000000003	53.446587999999998	Центральная	0103000020E6100000010000000500000010B3976DA72747409D64ABCB29B94A4010B3976DA7274740FAB9A1293BBB4A40EC4E779E782A4740FAB9A1293BBB4A40EC4E779E782A47409D64ABCB29B94A4010B3976DA72747409D64ABCB29B94A40
54145	13560	46.152366999999998	46.177044000000002	53.424900000000001	53.411783999999997	Школьная	0103000020E61000000100000005000000ACFE08C3801347400E828E56B5B44A40ACFE08C38013474003098A1F63B64A40FDF9B660A916474003098A1F63B64A40FDF9B660A91647400E828E56B5B44A40ACFE08C3801347400E828E56B5B44A40
54148	13508	45.989781000000001	46.031750000000002	53.259492999999999	53.238776000000001	Центральная	0103000020E61000000100000005000000E199D024B1FE4640EC884336909E4A40E199D024B1FE46403D450E1137A14A40F2D24D62100447403D450E1137A14A40F2D24D6210044740EC884336909E4A40E199D024B1FE4640EC884336909E4A40
54153	56498	46.124986	46.156480999999999	53.232891000000002	53.220654000000003	Куракина	0103000020E610000001000000050000009B3A8F8AFF0F4740A5DDE8633E9C4A409B3A8F8AFF0F474031444E5FCF9D4A4002B9C4910714474031444E5FCF9D4A4002B9C49107144740A5DDE8633E9C4A409B3A8F8AFF0F4740A5DDE8633E9C4A40
54239	13477	46.641193999999999	46.653922999999999	53.405676	53.374605000000003	Центральная	0103000020E610000001000000050000001A321EA51252474084F57F0EF3AF4A401A321EA512524740D462F030EDB34A40158DB5BFB3534740D462F030EDB34A40158DB5BFB353474084F57F0EF3AF4A401A321EA51252474084F57F0EF3AF4A40
54246	13351	46.273513999999999	46.300894999999997	53.433785	53.422635999999997	Садовая	0103000020E61000000100000005000000C37FBA81022347405E0EBBEF18B64A40C37FBA8102234740683F524486B74A40D44334BA83264740683F524486B74A40D44334BA832647405E0EBBEF18B64A40C37FBA81022347405E0EBBEF18B64A40
54269	56514	46.164934000000002	46.180520000000001	53.471111000000001	53.460839999999997	Новая	0103000020E61000000100000005000000CEFFAB8E1C15474025581CCEFCBA4A40CEFFAB8E1C15474097E4805D4DBC4A40102384471B17474097E4805D4DBC4A40102384471B17474025581CCEFCBA4A40CEFFAB8E1C15474025581CCEFCBA4A40
53682	9726	45.892152000000003	45.905428999999998	53.397736000000002	53.388049000000002	 Центральная	0103000020E61000000100000005000000CF87670932F246406D1FF296ABB14A40CF87670932F246408F386403E9B24A40CCECF318E5F346408F386403E9B24A40CCECF318E5F346406D1FF296ABB14A40CF87670932F246406D1FF296ABB14A40
53744	47732	46.350211999999999	46.370640000000002	53.439636999999998	53.432245000000002	Ленина	0103000020E6100000010000000500000058552FBFD32C4740056EDDCD53B74A4058552FBFD32C4740478E740646B84A40734BAB21712F4740478E740646B84A40734BAB21712F4740056EDDCD53B74A4058552FBFD32C4740056EDDCD53B74A40
54139	13285	46.012984000000003	46.037239	53.337457000000001	53.324680000000001	Веленка	0103000020E6100000010000000500000086AFAF75A901474028D53E1D8FA94A4086AFAF75A901474034677DCA31AB4A4060915F3FC404474034677DCA31AB4A4060915F3FC404474028D53E1D8FA94A4086AFAF75A901474028D53E1D8FA94A40
54012	56477	46.218958999999998	46.231544999999997	53.403469999999999	53.395544999999998	Школьная	0103000020E610000001000000050000001A1538D9061C4740548CF337A1B24A401A1538D9061C47406475ABE7A4B34A40B2463D44A31D47406475ABE7A4B34A40B2463D44A31D4740548CF337A1B24A401A1538D9061C4740548CF337A1B24A40
53487	13193	46.241191999999998	46.282514999999997	53.259422999999998	53.224384999999998	переулок Школьный	0103000020E6100000010000000500000046072461DF1E4740425BCEA5B89C4A4046072461DF1E4740446ADAC534A14A4091D0967329244740446ADAC534A14A4091D0967329244740425BCEA5B89C4A4046072461DF1E4740425BCEA5B89C4A40
53404	13193	46.241191999999998	46.282514999999997	53.259422999999998	53.224384999999998	переулок Центральный	0103000020E6100000010000000500000046072461DF1E4740425BCEA5B89C4A4046072461DF1E4740446ADAC534A14A4091D0967329244740446ADAC534A14A4091D0967329244740425BCEA5B89C4A4046072461DF1E4740425BCEA5B89C4A40
53596	25005	46.105870000000003	46.142691999999997	53.154685999999998	53.145299999999999	Складская	0103000020E6100000010000000500000053D0ED258D0D4740ED0DBE3099924A4053D0ED258D0D4740149337C0CC934A404EB340BB43124740149337C0CC934A404EB340BB43124740ED0DBE3099924A4053D0ED258D0D4740ED0DBE3099924A40
53283	25005	46.105870000000003	46.142691999999997	53.154685999999998	53.145299999999999	Коммунальная	0103000020E6100000010000000500000053D0ED258D0D4740ED0DBE3099924A4053D0ED258D0D4740149337C0CC934A404EB340BB43124740149337C0CC934A404EB340BB43124740ED0DBE3099924A4053D0ED258D0D4740ED0DBE3099924A40
53989	25005	46.105870000000003	46.142691999999997	53.154685999999998	53.145299999999999	Веселая	0103000020E6100000010000000500000053D0ED258D0D4740ED0DBE3099924A4053D0ED258D0D4740149337C0CC934A404EB340BB43124740149337C0CC934A404EB340BB43124740ED0DBE3099924A4053D0ED258D0D4740ED0DBE3099924A40
53914	32859	46.09872	46.126882000000002	53.323061000000003	53.309209000000003	Учительская	0103000020E6100000010000000500000006BB61DBA20C47407F50172994A74A4006BB61DBA20C474079CE16105AA94A40BD395CAB3D10474079CE16105AA94A40BD395CAB3D1047407F50172994A74A4006BB61DBA20C47407F50172994A74A40
53954	56472	45.945287	45.972380999999999	53.322712000000003	53.313723000000003	Школьная	0103000020E61000000100000005000000BF2A172AFFF846406380441328A84A40BF2A172AFFF846406D0377A04EA94A403A2009FB76FC46406D0377A04EA94A403A2009FB76FC46406380441328A84A40BF2A172AFFF846406380441328A84A40
54062	32844	45.981605999999999	46.005043000000001	53.292096000000001	53.265186	Водолейская	0103000020E6100000010000000500000058C7F143A5FD4640B4AD669DF1A14A4058C7F143A5FD46406EA5D76663A54A407009C03FA50047406EA5D76663A54A407009C03FA5004740B4AD669DF1A14A4058C7F143A5FD4640B4AD669DF1A14A40
54063	13000	46.061124999999997	46.087904000000002	53.404141000000003	53.390331000000003	Центральная	0103000020E61000000100000005000000E7FBA9F1D2074740B8CEBF5DF6B14A40E7FBA9F1D207474083FC6CE4BAB34A4003983270400B474083FC6CE4BAB34A4003983270400B4740B8CEBF5DF6B14A40E7FBA9F1D2074740B8CEBF5DF6B14A40
53918	12945	46.168052000000003	46.203462999999999	53.379111999999999	53.365600000000001	Центральная	0103000020E6100000010000000500000082035ABA8215474074B515FBCBAE4A4082035ABA82154740B5C2F4BD86B04A40187959130B1A4740B5C2F4BD86B04A40187959130B1A474074B515FBCBAE4A4082035ABA8215474074B515FBCBAE4A40
53922	12866	46.046384000000003	46.077312999999997	53.232965999999998	53.221165999999997	Центральная	0103000020E61000000100000005000000628731E9EF0547405A7EE02A4F9C4A40628731E9EF0547403B8A73D4D19D4A401F477364E50947403B8A73D4D19D4A401F477364E50947405A7EE02A4F9C4A40628731E9EF0547405A7EE02A4F9C4A40
53913	11034	43.931353999999999	43.951467999999998	52.557094999999997	52.538027	Орловка	0103000020E61000000100000005000000D87F9D9B36F74540B8AE9811DE444A40D87F9D9B36F74540EFE192E34E474A40639813B4C9F94540EFE192E34E474A40639813B4C9F94540B8AE9811DE444A40D87F9D9B36F74540B8AE9811DE444A40
53495	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Школьная площадь	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53779	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Школьная	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53318	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Тюрина	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53367	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Советская	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53717	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Слепцова	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53503	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Скворцовка	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53745	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Первомайская	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53742	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Новая	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53406	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Набережная	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53328	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Максима Горького	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53309	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Макарова	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53330	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Лесная	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53305	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Ленина	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53366	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Куйбышева	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53502	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Колхозная	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53403	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Калинина	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53304	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Гагарина	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53362	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	Балашовская	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53310	9330	44.172238	44.265113999999997	52.495215000000002	52.451988999999998	 Энергетиков	0103000020E61000000100000005000000719010E50B1646406C938AC6DA394A40719010E50B1646408CBE8234633F4A401ADB6B41EF2146408CBE8234633F4A401ADB6B41EF2146406C938AC6DA394A40719010E50B1646406C938AC6DA394A40
53609	11696	44.138596	44.212581	52.612150999999997	52.590167999999998	Школьная	0103000020E610000001000000050000009FAD8383BD114640A79201A08A4B4A409FAD8383BD1146405A9BC6F65A4E4A402060ADDA351B46405A9BC6F65A4E4A402060ADDA351B4640A79201A08A4B4A409FAD8383BD114640A79201A08A4B4A40
54125	11519	44.325104000000003	44.342801000000001	52.402692999999999	52.378264000000001	Центральная	0103000020E610000001000000050000003FE603029D29464088A06AF46A304A403FE603029D29464000AAB8718B334A409F0436E7E02B464000AAB8718B334A409F0436E7E02B464088A06AF46A304A403FE603029D29464088A06AF46A304A40
9888	40345	44.025956000000001	44.069803	52.557538000000001	52.535719999999998	Ленинская	0103000020E610000001000000050000004791B5865203464014E8137992444A404791B586520346407D23BA675D474A40D314014EEF0846407D23BA675D474A40D314014EEF08464014E8137992444A404791B5865203464014E8137992444A40
53777	11115	44.046923	44.087859000000002	52.485022000000001	52.464258999999998	Московская	0103000020E610000001000000050000001137A79201064640D4EFC2D66C3B4A401137A7920106464096EB6D33153E4A4063D4B5F63E0B464096EB6D33153E4A4063D4B5F63E0B4640D4EFC2D66C3B4A401137A79201064640D4EFC2D66C3B4A40
54060	11166	43.899545000000003	43.934885000000001	52.487287000000002	52.473047999999999	Светлая	0103000020E61000000100000005000000E223624A24F3454017B83CD68C3C4A40E223624A24F345400B62A06B5F3E4A40AF42CA4FAAF745400B62A06B5F3E4A40AF42CA4FAAF7454017B83CD68C3C4A40E223624A24F3454017B83CD68C3C4A40
54132	8739	44.265895999999998	44.285604999999997	52.485652000000002	52.479872	Садовая	0103000020E61000000100000005000000901150E108224640102219726C3D4A40901150E108224640569E40D8293E4A407B4963B48E244640569E40D8293E4A407B4963B48E244640102219726C3D4A40901150E108224640102219726C3D4A40
54105	33061	44.430539000000003	44.500185999999999	52.454754999999999	52.429288999999997	Новый Хутор	0103000020E610000001000000050000008753E6E61B3746402AC423F1F2364A408753E6E61B374640A3586E69353A4A4062F5471806404640A3586E69353A4A4062F54718064046402AC423F1F2364A408753E6E61B3746402AC423F1F2364A40
54195	33061	44.430539000000003	44.500185999999999	52.454754999999999	52.429288999999997	 Центральная	0103000020E610000001000000050000008753E6E61B3746402AC423F1F2364A408753E6E61B374640A3586E69353A4A4062F5471806404640A3586E69353A4A4062F54718064046402AC423F1F2364A408753E6E61B3746402AC423F1F2364A40
53911	10831	44.087733	44.103175	52.739341000000003	52.721922999999997	Комсомольская	0103000020E61000000100000005000000D6E3BED53A0B4640779D0DF9675C4A40D6E3BED53A0B4640C5CBD3B9A25E4A40E561A1D6340D4640C5CBD3B9A25E4A40E561A1D6340D4640779D0DF9675C4A40D6E3BED53A0B4640779D0DF9675C4A40
53700	56446	44.397067999999997	44.406626000000003	52.411681000000002	52.407094000000001	Победы	0103000020E61000000100000005000000E124CD1FD3324640EC32FCA71B344A40E124CD1FD33246403AB187F6B1344A4006DA1D520C3446403AB187F6B1344A4006DA1D520C344640EC32FCA71B344A40E124CD1FD3324640EC32FCA71B344A40
54078	10798	44.198154000000002	44.229855999999998	52.368696999999997	52.349975000000001	Советская	0103000020E610000001000000050000002AC93A1C5D19464074B515FBCB2C4A402AC93A1C5D19464010919A76312F4A400A65E1EB6B1D464010919A76312F4A400A65E1EB6B1D464074B515FBCB2C4A402AC93A1C5D19464074B515FBCB2C4A40
53961	32539	44.038389000000002	44.063549999999999	52.533579000000003	52.503284999999998	Луговая	0103000020E6100000010000000500000059C345EEE90446409FC893A46B404A4059C345EEE90446408C6A11514C444A4095D40968220846408C6A11514C444A4095D40968220846409FC893A46B404A4059C345EEE90446409FC893A46B404A40
53776	9037	44.422293000000003	44.457614	53.207804000000003	53.192354999999999	Школьная	0103000020E61000000100000005000000352A70B20D3646406D1CB1169F984A40352A70B20D3646402FFD4B52999A4A408B187618933A46402FFD4B52999A4A408B187618933A46406D1CB1169F984A40352A70B20D3646406D1CB1169F984A40
54051	9092	44.394866999999998	44.434645000000003	53.166094999999999	53.147174	Центральная	0103000020E6100000010000000500000083A279008B3246402769FE98D6924A4083A279008B324640BA83D89942954A405A2F8672A2374640BA83D89942954A405A2F8672A23746402769FE98D6924A4083A279008B3246402769FE98D6924A40
54255	17695	45.240343000000003	45.267750999999997	52.961388999999997	52.953122	Советская	0103000020E610000001000000050000004969368FC39E46408F8CD5E6FF794A404969368FC39E4640F8DD74CB0E7B4A40533C2EAA45A24640F8DD74CB0E7B4A40533C2EAA45A246408F8CD5E6FF794A404969368FC39E46408F8CD5E6FF794A40
53364	10758	44.939857000000003	44.975349000000001	52.988280000000003	52.966828999999997	Молодежная	0103000020E6100000010000000500000056F5F23B4D78464085E97B0DC17B4A4056F5F23B4D7846403CA583F57F7E4A40D9976C3CD87C46403CA583F57F7E4A40D9976C3CD87C464085E97B0DC17B4A4056F5F23B4D78464085E97B0DC17B4A40
53999	47018	44.49803	44.501604999999998	53.095326999999997	53.092807999999998	Софьевская	0103000020E61000000100000005000000A4367172BF3F46405167EE21E18B4A40A4367172BF3F464080B6D5AC338C4A404A41B7973440464080B6D5AC338C4A404A41B797344046405167EE21E18B4A40A4367172BF3F46405167EE21E18B4A40
54238	10337	44.885508999999999	44.906331999999999	52.971401	52.949258999999998	 Дачная	0103000020E6100000010000000500000026A8E15B587146408237A45181794A4026A8E15B587146409E2633DE567C4A40BDA8DDAF027446409E2633DE567C4A40BDA8DDAF027446408237A45181794A4026A8E15B587146408237A45181794A40
54061	10509	44.780819000000001	44.815485000000002	53.111643999999998	53.093845999999999	Школьная	0103000020E61000000100000005000000378C82E0F1634640226E4E25038C4A40378C82E0F1634640B665C0594A8E4A4075B0FECF61684640B665C0594A8E4A4075B0FECF61684640226E4E25038C4A40378C82E0F1634640226E4E25038C4A40
53483	10509	44.780819000000001	44.815485000000002	53.111643999999998	53.093845999999999	Советская	0103000020E61000000100000005000000378C82E0F1634640226E4E25038C4A40378C82E0F1634640B665C0594A8E4A4075B0FECF61684640B665C0594A8E4A4075B0FECF61684640226E4E25038C4A40378C82E0F1634640226E4E25038C4A40
54142	9896	44.341543000000001	44.375822999999997	53.032696999999999	53.017071000000001	Школьная	0103000020E61000000100000005000000C09657AEB72B4640E25AED612F824A40C09657AEB72B4640B2D6506A2F844A40D40AD3F71A304640B2D6506A2F844A40D40AD3F71A304640E25AED612F824A40C09657AEB72B4640E25AED612F824A40
53654	8977	44.625042000000001	44.643861999999999	53.143604000000003	53.136220000000002	Чапаева	0103000020E610000001000000050000002F50526001504640D3872EA86F914A402F5052600150464093C9A99D61924A408E91EC116A52464093C9A99D61924A408E91EC116A524640D3872EA86F914A402F50526001504640D3872EA86F914A40
54146	8977	44.625042000000001	44.643861999999999	53.143604000000003	53.136220000000002	Санаторская	0103000020E610000001000000050000002F50526001504640D3872EA86F914A402F5052600150464093C9A99D61924A408E91EC116A52464093C9A99D61924A408E91EC116A524640D3872EA86F914A402F50526001504640D3872EA86F914A40
53677	10266	44.871962000000003	44.892569999999999	52.989190000000001	52.966949	Школьная	0103000020E6100000010000000500000069AD68739C6F464030F31DFCC47B4A4069AD68739C6F4640DFC325C79D7E4A4003B2D7BB3F724640DFC325C79D7E4A4003B2D7BB3F72464030F31DFCC47B4A4069AD68739C6F464030F31DFCC47B4A40
53984	10266	44.871962000000003	44.892569999999999	52.989190000000001	52.966949	Рабочая	0103000020E6100000010000000500000069AD68739C6F464030F31DFCC47B4A4069AD68739C6F4640DFC325C79D7E4A4003B2D7BB3F724640DFC325C79D7E4A4003B2D7BB3F72464030F31DFCC47B4A4069AD68739C6F464030F31DFCC47B4A40
54072	56488	45.100906999999999	45.132815000000001	52.949534999999997	52.932820999999997	 Московская	0103000020E61000000100000005000000FF774485EA8C4640D102B4AD66774A40FF774485EA8C464024B4E55C8A794A4089B5F8140091464024B4E55C8A794A4089B5F81400914640D102B4AD66774A40FF774485EA8C4640D102B4AD66774A40
53680	8624	44.707113	44.731546999999999	52.999147000000001	52.985151999999999	Школьная	0103000020E61000000100000005000000C9C9C4AD825A464064CBF275197E4A40C9C9C4AD825A4640C172840CE47F4A40533E0455A35D4640C172840CE47F4A40533E0455A35D464064CBF275197E4A40C9C9C4AD825A464064CBF275197E4A40
53360	10031	44.884503000000002	44.906539000000002	53.053238	53.009816999999998	Набережная	0103000020E61000000100000005000000611BF16437714640F0F8F6AE41814A40611BF16437714640C573B680D0864A4037C64E7809744640C573B680D0864A4037C64E7809744640F0F8F6AE41814A40611BF16437714640F0F8F6AE41814A40
53833	8272	45.087603000000001	45.099271999999999	52.999386000000001	52.991131000000003	Новая	0103000020E6100000010000000500000008043A93368B4640A1866F61DD7E4A4008043A93368B4640460A65E1EB7F4A404AB4E4F1B48C4640460A65E1EB7F4A404AB4E4F1B48C4640A1866F61DD7E4A4008043A93368B4640A1866F61DD7E4A40
54056	9876	44.447634000000001	44.543008	53.028818999999999	52.983178000000002	переулок Школьный	0103000020E61000000100000005000000F14927124C394640C712D6C6D87D4A40F14927124C39464070404B57B0834A40B2BB40498145464070404B57B0834A40B2BB404981454640C712D6C6D87D4A40F14927124C394640C712D6C6D87D4A40
53311	10735	44.721871999999998	44.773254999999999	53.143059000000001	53.131686999999999	Советская	0103000020E61000000100000005000000F5F23B4D665C464078279F1EDB904A40F5F23B4D665C46400133DFC14F924A40F73B1405FA6246400133DFC14F924A40F73B1405FA62464078279F1EDB904A40F5F23B4D665C464078279F1EDB904A40
53652	56439	44.904715000000003	44.919663	53.079681000000001	53.065128000000001	Родниковая	0103000020E61000000100000005000000AF997CB3CD734640E606431D56884A40AF997CB3CD734640698EACFC328A4A40AE2B6684B7754640698EACFC328A4A40AE2B6684B7754640E606431D56884A40AF997CB3CD734640E606431D56884A40
53907	8836	44.391292	44.414962000000003	53.043163	53.034813999999997	Заречная	0103000020E61000000100000005000000DD9733DB15324640B2B8FFC874844A40DD9733DB15324640D9B27C5D86854A40988A8D791D354640D9B27C5D86854A40988A8D791D354640B2B8FFC874844A40DD9733DB15324640B2B8FFC874844A40
53706	8947	44.562007999999999	44.598461	53.162244999999999	53.141475999999997	Экспериментальная	0103000020E61000000100000005000000910BCEE0EF4746409E95B4E21B924A40910BCEE0EF4746404278B471C4944A403A77BB5E9A4C46404278B471C4944A403A77BB5E9A4C46409E95B4E21B924A40910BCEE0EF4746409E95B4E21B924A40
53482	8892	44.490240999999997	44.531204000000002	53.177450999999998	53.152833999999999	Октябрьская	0103000020E6100000010000000500000044149337C03E4640C2DB831090934A4044149337C03E46403DD2E0B6B6964A4090C01F7EFE4346403DD2E0B6B6964A4090C01F7EFE434640C2DB831090934A4044149337C03E4640C2DB831090934A40
53917	56465	44.624071999999998	44.670918999999998	53.272267999999997	53.251752000000003	Лесная	0103000020E61000000100000005000000B62C5F97E14F4640EF59D76839A04A40B62C5F97E14F4640A8DF85ADD9A24A40ECA17DACE0554640A8DF85ADD9A24A40ECA17DACE0554640EF59D76839A04A40B62C5F97E14F4640EF59D76839A04A40
53357	8802	44.939489000000002	44.980308000000001	53.063223000000001	53.044640999999999	 Советская	0103000020E61000000100000005000000D3F9F02C41784640C687D9CBB6854A40D3F9F02C4178464071ADF6B017884A40EB0088BB7A7D464071ADF6B017884A40EB0088BB7A7D4640C687D9CBB6854A40D3F9F02C41784640C687D9CBB6854A40
54050	9252	45.133308999999997	45.153655999999998	53.123539000000001	53.114730000000002	Возрожденская	0103000020E6100000010000000500000098A1F144109146405FEFFE78AF8E4A4098A1F14410914640E9633E20D08F4A40C66AF3FFAA934640E9633E20D08F4A40C66AF3FFAA9346405FEFFE78AF8E4A4098A1F144109146405FEFFE78AF8E4A40
53636	8553	44.680405999999998	44.709781	53.240749000000001	53.217908999999999	Набережная	0103000020E610000001000000050000004700378B1757464085402E71E49B4A404700378B17574640B9C5FCDCD09E4A403D29931ADA5A4640B9C5FCDCD09E4A403D29931ADA5A464085402E71E49B4A404700378B1757464085402E71E49B4A40
53307	8565	44.660867000000003	44.711505000000002	53.067112999999999	53.045777999999999	Садовая	0103000020E61000000100000005000000B900344A975446402A70B20DDC854A40B900344A975446407711A62897884A4062F88898125B46407711A62897884A4062F88898125B46402A70B20DDC854A40B900344A975446402A70B20DDC854A40
54308	56527	45.015019000000002	45.030039000000002	53.074092999999998	53.058827999999998	Центральная	0103000020E61000000100000005000000C9E88024EC814640670B08AD87874A40C9E88024EC81464067EE21E17B894A40624D6551D883464067EE21E17B894A40624D6551D8834640670B08AD87874A40C9E88024EC814640670B08AD87874A40
53299	8337	44.787754	44.821333000000003	53.224190999999998	53.197032	Советская	0103000020E6100000010000000500000087A5811FD5644640FB21365838994A4087A5811FD56446405D876A4AB29C4A4013109370216946405D876A4AB29C4A401310937021694640FB21365838994A4087A5811FD5644640FB21365838994A40
53947	56469	44.341543000000001	45.267750999999997	53.272267999999997	52.909365999999999	Центральная	0103000020E61000000100000005000000C09657AEB72B4640130CE71A66744A40C09657AEB72B4640A8DF85ADD9A24A40533C2EAA45A24640A8DF85ADD9A24A40533C2EAA45A24640130CE71A66744A40C09657AEB72B4640130CE71A66744A40
54054	10669	44.856943000000001	44.875456999999997	53.078789	53.063276999999999	Центральная	0103000020E61000000100000005000000A0C4E74EB06D464064CBF27519884A40A0C4E74EB06D46406C2409C2158A4A40F20698F90E7046406C2409C2158A4A40F20698F90E70464064CBF27519884A40A0C4E74EB06D464064CBF27519884A40
53399	8162	45.139220000000002	45.166313000000002	53.035870000000003	53.018847999999998	Школьная	0103000020E610000001000000050000007D7901F6D191464029CC7B9C69824A407D7901F6D19146402A745E6397844A4028F38FBE499546402A745E6397844A4028F38FBE4995464029CC7B9C69824A407D7901F6D191464029CC7B9C69824A40
53741	27918	45.132716000000002	45.144393999999998	53.163626999999998	53.155723000000002	Школьная	0103000020E61000000100000005000000F6D37FD6FC904640151E34BBEE934A40F6D37FD6FC9046400DDFC2BAF1944A408BDEA9807B9246400DDFC2BAF1944A408BDEA9807B924640151E34BBEE934A40F6D37FD6FC904640151E34BBEE934A40
53752	7858	43.073929999999997	43.127155999999999	53.413099000000003	53.400866000000001	 1-ая Садовая	0103000020E61000000100000005000000BD18CA8976894540070ABC934FB34A40BD18CA89768945405281936DE0B44A40BEBED6A5469045405281936DE0B44A40BEBED6A546904540070ABC934FB34A40BD18CA8976894540070ABC934FB34A40
54196	56501	43.309469	43.338977999999997	53.450904999999999	53.440485000000002	Центральная	0103000020E610000001000000050000001B1021AE9CA7454075B0FECF61B84A401B1021AE9CA745402B4D4A41B7B94A40200890A163AB45402B4D4A41B7B94A40200890A163AB454075B0FECF61B84A401B1021AE9CA7454075B0FECF61B84A40
54083	47986	43.228664999999999	43.253351000000002	53.169155000000003	53.155901	Школьная	0103000020E61000000100000005000000B35E0CE5449D4540F4346090F4934A40B35E0CE5449D45403A7AFCDEA6954A4057B439CE6DA045403A7AFCDEA6954A4057B439CE6DA04540F4346090F4934A40B35E0CE5449D4540F4346090F4934A40
53481	7513	43.618453000000002	43.690919999999998	53.322862000000001	53.268740999999999	Совхозная	0103000020E610000001000000050000007A8EC87729CF4540130CE71A66A24A407A8EC87729CF4540828FC18A53A94A407F130A1170D84540828FC18A53A94A407F130A1170D84540130CE71A66A24A407A8EC87729CF4540130CE71A66A24A40
54053	7957	43.012664999999998	43.034188999999998	53.456004	53.438440999999997	Школьная	0103000020E61000000100000005000000E466B8019F814540DE1CAED51EB84A40E466B8019F8145402F6CCD565EBA4A4004711E4E608445402F6CCD565EBA4A4004711E4E60844540DE1CAED51EB84A40E466B8019F814540DE1CAED51EB84A40
54130	32709	43.428674999999998	43.480741000000002	53.450690000000002	53.427866999999999	Советская	0103000020E6100000010000000500000070CE88D2DEB64540D1048A58C4B64A4070CE88D2DEB645402F51BD35B0B94A40556CCCEB88BD45402F51BD35B0B94A40556CCCEB88BD4540D1048A58C4B64A4070CE88D2DEB64540D1048A58C4B64A40
54265	56512	43.030029999999996	43.067436000000001	53.438312000000003	53.422168999999997	Центральная	0103000020E610000001000000050000000EF3E505D8834540483140A209B64A400EF3E505D8834540E1B88C9B1AB84A405A492BBEA1884540E1B88C9B1AB84A405A492BBEA1884540483140A209B64A400EF3E505D8834540483140A209B64A40
53675	32742	43.610467	43.634721999999996	53.231608000000001	53.212193999999997	Центральная	0103000020E61000000100000005000000C4245CC823CE45402634492C299B4A40C4245CC823CE4540F9BEB854A59D4A409E060C923ED14540F9BEB854A59D4A409E060C923ED145402634492C299B4A40C4245CC823CE45402634492C299B4A40
54098	56492	43.520024999999997	43.5456	53.236598999999998	53.208914999999998	 Центральная	0103000020E610000001000000050000001B0DE02D90C2454069520ABABD9A4A401B0DE02D90C2454016A243E0489E4A404B598638D6C5454016A243E0489E4A404B598638D6C5454069520ABABD9A4A401B0DE02D90C2454069520ABABD9A4A40
53297	6966	43.293173000000003	43.342069000000002	53.347236000000002	53.318660999999999	Новая	0103000020E61000000100000005000000FD885FB186A545405DC136E2C9A84A40FD885FB186A5454037FFAF3A72AC4A40DBFCBFEAC8AB454037FFAF3A72AC4A40DBFCBFEAC8AB45405DC136E2C9A84A40FD885FB186A545405DC136E2C9A84A40
53400	6966	43.293173000000003	43.342069000000002	53.347236000000002	53.318660999999999	Кирова	0103000020E61000000100000005000000FD885FB186A545405DC136E2C9A84A40FD885FB186A5454037FFAF3A72AC4A40DBFCBFEAC8AB454037FFAF3A72AC4A40DBFCBFEAC8AB45405DC136E2C9A84A40FD885FB186A545405DC136E2C9A84A40
53396	6966	43.293173000000003	43.342069000000002	53.347236000000002	53.318660999999999	Драгунова	0103000020E61000000100000005000000FD885FB186A545405DC136E2C9A84A40FD885FB186A5454037FFAF3A72AC4A40DBFCBFEAC8AB454037FFAF3A72AC4A40DBFCBFEAC8AB45405DC136E2C9A84A40FD885FB186A545405DC136E2C9A84A40
54156	7752	43.326833000000001	43.386733	53.255629999999996	53.231543000000002	Совхозная	0103000020E610000001000000050000007520EBA9D5A94540124F7633A39D4A407520EBA9D5A9454030F0DC7BB8A04A4059A4897780B1454030F0DC7BB8A04A4059A4897780B14540124F7633A39D4A407520EBA9D5A94540124F7633A39D4A40
54232	7773	43.223401000000003	43.252803	53.212311999999997	53.192188000000002	Школьная	0103000020E6100000010000000500000065726A67989C45408257CB9D99984A4065726A67989C45403046240A2D9B4A4054AA44D95BA045403046240A2D9B4A4054AA44D95BA045408257CB9D99984A4065726A67989C45408257CB9D99984A40
54129	7312	43.393901	43.449516000000003	53.395147999999999	53.379499000000003	Театральная	0103000020E610000001000000050000004C6E14596BB24540AFEE586C93B04A404C6E14596BB24540378AAC3594B24A40AE8383BD89B94540378AAC3594B24A40AE8383BD89B94540AFEE586C93B04A404C6E14596BB24540AFEE586C93B04A40
53903	7426	43.584659000000002	43.630355999999999	53.360425999999997	53.334403000000002	Новая	0103000020E61000000100000005000000F2272A1BD6CA45409757AEB7CDAA4A40F2272A1BD6CA454065506D7022AE4A402F6B6281AFD0454065506D7022AE4A402F6B6281AFD045409757AEB7CDAA4A40F2272A1BD6CA45409757AEB7CDAA4A40
53467	47307	43.750416000000001	43.769827999999997	53.206941	53.178552000000003	Школьная	0103000020E610000001000000050000009432A9A10DE045405551BCCADA964A409432A9A10DE04540CC99ED0A7D9A4A40C5C551B989E24540CC99ED0A7D9A4A40C5C551B989E245405551BCCADA964A409432A9A10DE045405551BCCADA964A40
54233	56507	43.349246000000001	43.381360999999998	53.372810999999999	53.350886000000003	Центральная	0103000020E610000001000000050000002121CA17B4AC4540E84F1BD5E9AC4A402121CA17B4AC4540664B5645B8AF4A40247CEF6FD0B04540664B5645B8AF4A40247CEF6FD0B04540E84F1BD5E9AC4A402121CA17B4AC4540E84F1BD5E9AC4A40
53829	7674	43.415461000000001	43.440021000000002	53.267206000000002	53.236114000000001	Орловская	0103000020E61000000100000005000000B9E177D32DB545405A10CAFB389E4A40B9E177D32DB54540C2A563CE33A24A40D046AE9B52B84540C2A563CE33A24A40D046AE9B52B845405A10CAFB389E4A40B9E177D32DB545405A10CAFB389E4A40
79369	61547	45.392895000000003	46.478321000000001	54.029561000000001	53.478597999999998	Школьный переулок	0103000020E6100000010000000500000087E123624AB246402BF702B342BD4A4087E123624AB24640581EA4A7C8034B40B9FE5D9F393D4740581EA4A7C8034B40B9FE5D9F393D47402BF702B342BD4A4087E123624AB246402BF702B342BD4A40
54267	56511	46.137391999999998	46.150686999999998	53.695644000000001	53.686307999999997	Центральная	0103000020E61000000100000005000000B35DA10F96114740D87DC7F0D8D74A40B35DA10F961147404ED4D2DC0AD94A4057772CB6491347404ED4D2DC0AD94A4057772CB649134740D87DC7F0D8D74A40B35DA10F96114740D87DC7F0D8D74A40
54131	5996	45.797576999999997	45.825271999999998	53.891986000000003	53.876891999999998	Новая	0103000020E610000001000000050000005985CD0017E64640E00F3FFF3DF04A405985CD0017E64640B43EE5982CF24A40FA264D83A2E94640B43EE5982CF24A40FA264D83A2E94640E00F3FFF3DF04A405985CD0017E64640E00F3FFF3DF04A40
53901	6687	45.818148999999998	45.85136	53.555897999999999	53.534709999999997	Посёлки	0103000020E61000000100000005000000A7203F1BB9E846400D6C956071C44A40A7203F1BB9E84640B6F468AA27C74A40B08F4E5DF9EC4640B6F468AA27C74A40B08F4E5DF9EC46400D6C956071C44A40A7203F1BB9E846400D6C956071C44A40
53705	56447	45.724032000000001	45.801026999999998	53.896532999999998	53.879556999999998	Сенная	0103000020E61000000100000005000000F5A0A014ADDC4640E3FBE25295F04A40F5A0A014ADDC46407364E597C1F24A40431B800D88E646407364E597C1F24A40431B800D88E64640E3FBE25295F04A40F5A0A014ADDC4640E3FBE25295F04A40
53789	56447	45.724032000000001	45.801026999999998	53.896532999999998	53.879556999999998	Пролетарская	0103000020E61000000100000005000000F5A0A014ADDC4640E3FBE25295F04A40F5A0A014ADDC46407364E597C1F24A40431B800D88E646407364E597C1F24A40431B800D88E64640E3FBE25295F04A40F5A0A014ADDC4640E3FBE25295F04A40
54046	56483	46.061880000000002	46.077995999999999	53.885883	53.869895	Набережная	0103000020E61000000100000005000000642310AFEB0747401AFA27B858EF4A40642310AFEB0747408B8A389D64F14A40029CDEC5FB0947408B8A389D64F14A40029CDEC5FB0947401AFA27B858EF4A40642310AFEB0747401AFA27B858EF4A40
54045	6174	46.273001999999998	46.290519000000003	53.702057000000003	53.676707999999998	Центральная	0103000020E610000001000000050000000DDFC2BAF12247408578245E9ED64A400DDFC2BAF1224740C576F700DDD94A40EEEE01BA2F254740C576F700DDD94A40EEEE01BA2F2547408578245E9ED64A400DDFC2BAF12247408578245E9ED64A40
54133	6319	46.352798999999997	46.379900999999997	53.577432999999999	53.554971999999999	Ленинская	0103000020E61000000100000005000000DF878384282D47400D198F5209C74A40DF878384282D4740CA501553E9C94A40DD5B9198A0304740CA501553E9C94A40DD5B9198A03047400D198F5209C74A40DF878384282D47400D198F5209C74A40
53623	45721	45.989843999999998	45.997408	53.812151	53.808396999999999	Центральная	0103000020E6100000010000000500000027124C35B3FE46409E978A8D79E74A4027124C35B3FE4640F4346090F4E74A406762BA10ABFF4640F4346090F4E74A406762BA10ABFF46409E978A8D79E74A4027124C35B3FE46409E978A8D79E74A40
53786	56451	46.090778999999998	46.121178	53.884757999999998	53.877375000000001	Центральная	0103000020E61000000100000005000000F01472A59E0B4740FCA9F1D24DF04A40F01472A59E0B4740EB6F09C03FF14A40527FBDC2820F4740EB6F09C03FF14A40527FBDC2820F4740FCA9F1D24DF04A40F01472A59E0B4740FCA9F1D24DF04A40
53356	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Школьная	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53397	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Советская	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53480	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Садовая	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53300	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Октябрьская	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53294	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Ленина	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53296	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Комсомольская	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53390	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Калинина	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53392	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Заводская	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53355	5175	46.019300000000001	46.115957999999999	53.749205000000003	53.669038	Белинского	0103000020E610000001000000050000000A68226C7802474000E48409A3D54A400A68226C78024740F67F0EF3E5DF4A40D3DA34B6D70E4740F67F0EF3E5DF4A40D3DA34B6D70E474000E48409A3D54A400A68226C7802474000E48409A3D54A40
53771	6580	45.656632000000002	45.692321999999997	53.610145000000003	53.557856000000001	Центральная	0103000020E61000000100000005000000E8C072840CD446404EF04DD367C74A40E8C072840CD44640B2683A3B19CE4A409126DE019ED84640B2683A3B19CE4A409126DE019ED846404EF04DD367C74A40E8C072840CD446404EF04DD367C74A40
53891	56458	45.941558999999998	45.997928999999999	53.806063000000002	53.770141000000002	Молодежная	0103000020E6100000010000000500000092205C0185F846408527F4FA93E24A4092205C0185F8464001C287122DE74A40705D3123BCFF464001C287122DE74A40705D3123BCFF46408527F4FA93E24A4092205C0185F846408527F4FA93E24A40
53704	6714	46.020583999999999	46.051855000000003	53.882598000000002	53.864888000000001	Школьная	0103000020E6100000010000000500000012691B7FA2024740F75965A6B4EE4A4012691B7FA2024740ECC1A4F8F8F04A402A91442FA3064740ECC1A4F8F8F04A402A91442FA3064740F75965A6B4EE4A4012691B7FA2024740F75965A6B4EE4A40
54128	6921	46.136611000000002	46.154854999999998	53.890239999999999	53.882899999999999	Центральная	0103000020E610000001000000050000000EA320787C114740B7D100DE02F14A400EA320787C114740A7CB6262F3F14A40A04FE449D2134740A7CB6262F3F14A40A04FE449D2134740B7D100DE02F14A400EA320787C114740B7D100DE02F14A40
54108	56493	45.946150000000003	45.961322000000003	53.870505999999999	53.867500999999997	Центральная	0103000020E61000000100000005000000228E75711BF94640A71FD4450AEF4A40228E75711BF94640637C98BD6CEF4A4071766B990CFB4640637C98BD6CEF4A4071766B990CFB4640A71FD4450AEF4A40228E75711BF94640A71FD4450AEF4A40
54047	32551	46.113066000000003	46.146717000000002	53.638779999999997	53.616554999999998	Октябрьская	0103000020E6100000010000000500000010255AF2780E4740B7973446EBCE4A4010255AF2780E474060AB048BC3D14A403562669FC712474060AB048BC3D14A403562669FC7124740B7973446EBCE4A4010255AF2780E4740B7973446EBCE4A40
54229	6637	45.775677000000002	45.843544000000001	53.628838000000002	53.592122000000003	Советская	0103000020E6100000010000000500000034A1496249E34640FE9E58A7CACB4A4034A1496249E34640B43D7AC37DD04A40575EF23FF9EB4640B43D7AC37DD04A40575EF23FF9EB4640FE9E58A7CACB4A4034A1496249E34640FE9E58A7CACB4A40
53639	6070	45.639491999999997	45.676825999999998	53.801175999999998	53.771358999999997	Центральная	0103000020E61000000100000005000000DD06B5DFDAD14640D53C47E4BBE24A40DD06B5DFDAD14640882B67EF8CE64A408F8AFF3BA2D64640882B67EF8CE64A408F8AFF3BA2D64640D53C47E4BBE24A40DD06B5DFDAD14640D53C47E4BBE24A40
53456	56416	46.088487999999998	46.100085	53.897106000000001	53.890096999999997	Братская	0103000020E61000000100000005000000520B2593530B474044A2D0B2EEF14A40520B2593530B4740CF85915ED4F24A40FBE8D495CF0C4740CF85915ED4F24A40FBE8D495CF0C474044A2D0B2EEF14A40520B2593530B474044A2D0B2EEF14A40
53902	5637	45.988694000000002	46.020026999999999	53.587189000000002	53.575893000000001	Центральная	0103000020E610000001000000050000002FE065868DFE4640677FA0DCB6C94A402FE065868DFE464015C9570229CB4A40BC04A73E9002474015C9570229CB4A40BC04A73E90024740677FA0DCB6C94A402FE065868DFE4640677FA0DCB6C94A40
54055	6385	46.236018000000001	46.274394000000001	53.605710999999999	53.589892999999996	Школьная	0103000020E6100000010000000500000038A27BD6351E4740D591239D81CB4A4038A27BD6351E4740EAE923F087CD4A40FC1BB4571F234740EAE923F087CD4A40FC1BB4571F234740D591239D81CB4A4038A27BD6351E4740D591239D81CB4A40
54126	6538	45.539239999999999	45.571587999999998	53.643177999999999	53.619295000000001	Нагорная	0103000020E61000000100000005000000F758FAD005C54640C5C9FD0E45CF4A40F758FAD005C54640DBC01DA853D24A409D64ABCB29C94640DBC01DA853D24A409D64ABCB29C94640C5C9FD0E45CF4A40F758FAD005C54640C5C9FD0E45CF4A40
53798	56453	43.282097	44.199294999999999	53.750599999999999	53.319693999999998	Жулябина	0103000020E610000001000000050000005DA626C11BA445401C5DA5BBEBA84A405DA626C11BA4454055302AA913E04A40CFA0A17F8219464055302AA913E04A40CFA0A17F821946401C5DA5BBEBA84A405DA626C11BA445401C5DA5BBEBA84A40
54228	3766	43.579520000000002	43.604826000000003	53.483350999999999	53.477435	Старая Мурава	0103000020E6100000010000000500000060B01BB62DCA45409E7B0F971CBD4A4060B01BB62DCA454094BE1072DEBD4A40A0E238F06ACD454094BE1072DEBD4A40A0E238F06ACD45409E7B0F971CBD4A4060B01BB62DCA45409E7B0F971CBD4A40
54041	56482	43.366681999999997	43.389077	53.629942999999997	53.610715999999996	Лесная	0103000020E6100000010000000500000014048F6FEFAE45406C921FF12BCE4A4014048F6FEFAE45400CACE3F8A1D04A401A506F46CDB145400CACE3F8A1D04A401A506F46CDB145406C921FF12BCE4A4014048F6FEFAE45406C921FF12BCE4A40
54227	3856	43.521740999999999	43.559190999999998	53.607548000000001	53.579518	Центральная	0103000020E61000000100000005000000BDFDB968C8C24540BFB854A52DCA4A40BDFDB968C8C2454007600322C4CD4A40D89B189293C7454007600322C4CD4A40D89B189293C74540BFB854A52DCA4A40BDFDB968C8C24540BFB854A52DCA4A40
54044	4002	43.789788999999999	43.813648000000001	53.623204000000001	53.607201000000003	Центральная	0103000020E61000000100000005000000CADE52CE17E545409C8C2AC3B8CD4A40CADE52CE17E54540425E0F26C5CF4A40583A1F9E25E84540425E0F26C5CF4A40583A1F9E25E845409C8C2AC3B8CD4A40CADE52CE17E545409C8C2AC3B8CD4A40
53635	3417	43.709631999999999	43.735567000000003	53.543213000000002	53.532060999999999	Новенькая	0103000020E61000000100000005000000F818AC38D5DA4540103D29931AC44A40F818AC38D5DA45408BE1EA0088C54A402882380F27DE45408BE1EA0088C54A402882380F27DE4540103D29931AC44A40F818AC38D5DA4540103D29931AC44A40
54225	2959	43.740282999999998	43.760854000000002	53.530022000000002	53.505955999999998	Кремщина	0103000020E610000001000000050000007364E597C1DE4540849B8C2AC3C04A407364E597C1DE45408C14CAC2D7C34A40F183F3A963E145408C14CAC2D7C34A40F183F3A963E14540849B8C2AC3C04A407364E597C1DE4540849B8C2AC3C04A40
53631	56435	43.633895000000003	43.652912999999998	53.541885999999998	53.517817000000001	Молодежная	0103000020E61000000100000005000000890CAB7823D145400B28D4D347C24A40890CAB7823D1454083143C855CC54A400E1137A792D3454083143C855CC54A400E1137A792D345400B28D4D347C24A40890CAB7823D145400B28D4D347C24A40
54224	3630	43.352615	43.379725999999998	53.514583000000002	53.504516000000002	Центральная	0103000020E610000001000000050000001E8A027D22AD45408527F4FA93C04A401E8A027D22AD4540EE0912DBDDC14A406FB88FDC9AB04540EE0912DBDDC14A406FB88FDC9AB045408527F4FA93C04A401E8A027D22AD45408527F4FA93C04A40
54121	2809	43.887633000000001	43.911160000000002	53.580869999999997	53.564669000000002	Парковая	0103000020E61000000100000005000000D9EC48F59DF145405308E41247C84A40D9EC48F59DF145401F9DBAF259CA4A4031B610E4A0F445401F9DBAF259CA4A4031B610E4A0F445405308E41247C84A40D9EC48F59DF145405308E41247C84A40
53770	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Южная	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53267	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Урицкого	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53389	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Толстого	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53327	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Розы Люксембург	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53349	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Рабочая	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53354	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Октябрьская	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53352	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Московская	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53395	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Маяковского	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53393	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Крылова	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53435	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Карла Либкнехта	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53291	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Заводская	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53769	4425	43.650173000000002	43.706003000000003	53.544535000000003	53.51885	Вокзальная	0103000020E6100000010000000500000001DF6DDE38D34540CAC342AD69C24A4001DF6DDE38D345408143A852B3C54A405FF0694E5EDA45408143A852B3C54A405FF0694E5EDA4540CAC342AD69C24A4001DF6DDE38D34540CAC342AD69C24A40
53895	3221	43.766514000000001	43.794155000000003	53.390884	53.361258999999997	Зеленая	0103000020E610000001000000050000008CF678211DE245405D3123BC3DAE4A408CF678211DE24540CC43A67C08B24A403A7AFCDEA6E54540CC43A67C08B24A403A7AFCDEA6E545405D3123BC3DAE4A408CF678211DE245405D3123BC3DAE4A40
54212	32130	43.682512000000003	43.710369	53.694727	53.672787999999997	Молодежная	0103000020E6100000010000000500000054909F8D5CD745401492CCEA1DD64A4054909F8D5CD74540F85278D0ECD84A40CE8B135FEDDA4540F85278D0ECD84A40CE8B135FEDDA45401492CCEA1DD64A4054909F8D5CD745401492CCEA1DD64A40
54123	3066	43.924948999999998	43.944623	53.412202999999998	53.374605000000003	Школьная	0103000020E61000000100000005000000E4BB94BA64F6454084F57F0EF3AF4A40E4BB94BA64F6454013286211C3B44A4053060E68E9F8454013286211C3B44A4053060E68E9F8454084F57F0EF3AF4A40E4BB94BA64F6454084F57F0EF3AF4A40
53388	3805	43.475199000000003	43.519019	53.638272000000001	53.608910999999999	Центральная	0103000020E61000000100000005000000C40B2252D3BC45405B96AFCBF0CD4A40C40B2252D3BC4540ECF99AE5B2D14A405680EF366FC24540ECF99AE5B2D14A405680EF366FC245405B96AFCBF0CD4A40C40B2252D3BC45405B96AFCBF0CD4A40
53293	3118	43.666063999999999	43.728191000000002	53.537129	53.499412	Школьная	0103000020E610000001000000050000007F85CC9541D545406F9D7FBBECBF4A407F85CC9541D54540D95DA0A4C0C44A40EB1ED95C35DD4540D95DA0A4C0C44A40EB1ED95C35DD45406F9D7FBBECBF4A407F85CC9541D545406F9D7FBBECBF4A40
54040	3118	43.666063999999999	43.728191000000002	53.537129	53.499412	Красноармейская	0103000020E610000001000000050000007F85CC9541D545406F9D7FBBECBF4A407F85CC9541D54540D95DA0A4C0C44A40EB1ED95C35DD4540D95DA0A4C0C44A40EB1ED95C35DD45406F9D7FBBECBF4A407F85CC9541D545406F9D7FBBECBF4A40
54034	4414	43.837471000000001	43.872847	53.612991999999998	53.603434999999998	площадь Центральная	0103000020E61000000100000005000000992CEE3F32EB45408121AB5B3DCD4A40992CEE3F32EB4540D55A988576CE4A40B3B45373B9EF4540D55A988576CE4A40B3B45373B9EF45408121AB5B3DCD4A40992CEE3F32EB45408121AB5B3DCD4A40
53837	3556	43.603369999999998	43.619971	53.512452000000003	53.496825000000001	Ленина	0103000020E610000001000000050000009AB1683A3BCD4540E86A2BF697BF4A409AB1683A3BCD45408962F20698C14A40F5BBB0355BCF45408962F20698C14A40F5BBB0355BCF4540E86A2BF697BF4A409AB1683A3BCD4540E86A2BF697BF4A40
54124	32992	44.023494999999997	44.063937000000003	53.627968000000003	53.615540000000003	Ленина	0103000020E610000001000000050000004C4F58E2010346409FB0C403CACE4A404C4F58E2010346409F77634161D04A408F006E162F0846409F77634161D04A408F006E162F0846409FB0C403CACE4A404C4F58E2010346409FB0C403CACE4A40
53897	4069	43.945467000000001	43.987355000000001	53.705734999999997	53.671005999999998	Новая Деревня	0103000020E610000001000000050000003F390A1005F94540BBB54C86E3D54A403F390A1005F945403F52448655DA4A4063450DA661FE45403F52448655DA4A4063450DA661FE4540BBB54C86E3D54A403F390A1005F94540BBB54C86E3D54A40
53253	56417	43.526187	43.533706000000002	53.450867000000002	53.447274	Конституции СССР	0103000020E61000000100000005000000494A7A185AC34540F12C414640B94A40494A7A185AC345403EEC8502B6B94A40E9D66B7A50C445403EEC8502B6B94A40E9D66B7A50C44540F12C414640B94A40494A7A185AC34540F12C414640B94A40
53900	33004	44.095441000000001	44.167270000000002	53.643819000000001	53.610508000000003	Московская	0103000020E6100000010000000500000049D92269370C464023F94A2025CE4A4049D92269370C46408FC536A968D24A400CCD751A691546408FC536A968D24A400CCD751A6915464023F94A2025CE4A4049D92269370C464023F94A2025CE4A40
54167	5024	43.635018000000002	43.685296999999998	53.510593999999998	53.489758999999999	Буденного	0103000020E61000000100000005000000882F134548D14540F9F5436CB0BE4A40882F134548D1454054C4E9245BC14A400186E5CFB7D7454054C4E9245BC14A400186E5CFB7D74540F9F5436CB0BE4A40882F134548D14540F9F5436CB0BE4A40
53699	2765	43.971662000000002	44.073917000000002	53.471319999999999	53.449806000000002	Школьная	0103000020E610000001000000050000000B62A06B5FFC4540B5C5353E93B94A400B62A06B5FFC4540B1F9B83654BC4A4029CFBC1C76094640B1F9B83654BC4A4029CFBC1C76094640B5C5353E93B94A400B62A06B5FFC4540B5C5353E93B94A40
53638	3465	43.521974	43.580688000000002	53.493257	53.450496999999999	Советская площадь 	0103000020E6100000010000000500000060AE450BD0C245401AF9BCE2A9B94A4060AE450BD0C24540F4C29D0B23BF4A40FF9600FC53CA4540F4C29D0B23BF4A40FF9600FC53CA45401AF9BCE2A9B94A4060AE450BD0C245401AF9BCE2A9B94A40
53767	3465	43.521974	43.580688000000002	53.493257	53.450496999999999	Советская площадь	0103000020E6100000010000000500000060AE450BD0C245401AF9BCE2A9B94A4060AE450BD0C24540F4C29D0B23BF4A40FF9600FC53CA4540F4C29D0B23BF4A40FF9600FC53CA45401AF9BCE2A9B94A4060AE450BD0C245401AF9BCE2A9B94A40
53325	3465	43.521974	43.580688000000002	53.493257	53.450496999999999	Московская	0103000020E6100000010000000500000060AE450BD0C245401AF9BCE2A9B94A4060AE450BD0C24540F4C29D0B23BF4A40FF9600FC53CA4540F4C29D0B23BF4A40FF9600FC53CA45401AF9BCE2A9B94A4060AE450BD0C245401AF9BCE2A9B94A40
53702	3465	43.521974	43.580688000000002	53.493257	53.450496999999999	Белинского 	0103000020E6100000010000000500000060AE450BD0C245401AF9BCE2A9B94A4060AE450BD0C24540F4C29D0B23BF4A40FF9600FC53CA4540F4C29D0B23BF4A40FF9600FC53CA45401AF9BCE2A9B94A4060AE450BD0C245401AF9BCE2A9B94A40
53763	2969	43.907800999999999	43.939224000000003	53.456583000000002	53.432749000000001	Средняя	0103000020E610000001000000050000005723BBD232F445403830B95164B74A405723BBD232F445406D74CE4F71BA4A4025CFF57D38F845406D74CE4F71BA4A4025CFF57D38F845403830B95164B74A405723BBD232F445403830B95164B74A40
53894	32841	43.761769999999999	43.789439000000002	53.565894	53.530365000000003	Центральная	0103000020E610000001000000050000007689EAAD81E14540B6F81400E3C34A407689EAAD81E145405680EF366FC84A40EE974F560CE545405680EF366FC84A40EE974F560CE54540B6F81400E3C34A407689EAAD81E14540B6F81400E3C34A40
53893	2711	43.910027999999997	43.968077999999998	53.50835	53.466436999999999	Новая	0103000020E61000000100000005000000DE3829CC7BF445407A522635B4BB4A40DE3829CC7BF44540F775E09C11C14A4011FDDAFAE9FB4540F775E09C11C14A4011FDDAFAE9FB45407A522635B4BB4A40DE3829CC7BF445407A522635B4BB4A40
54043	4155	43.966217999999998	44.001486	53.613275000000002	53.595286000000002	Центральная	0103000020E610000001000000050000003C670B08ADFB454022E2E65432CC4A403C670B08ADFB45402A3A92CB7FCE4A4070B378B1300046402A3A92CB7FCE4A4070B378B13000464022E2E65432CC4A403C670B08ADFB454022E2E65432CC4A40
53892	2622	46.746028000000003	46.756394	52.701791	52.697108999999998	Школьная	0103000020E610000001000000050000003DF372D87D5F4740A65F22DE3A594A403DF372D87D5F474046D09849D4594A400072C284D160474046D09849D4594A400072C284D1604740A65F22DE3A594A403DF372D87D5F4740A65F22DE3A594A40
54035	2615	46.502350999999997	46.524270000000001	52.772772000000003	52.763421999999998	Школьная	0103000020E61000000100000005000000730E9E094D4047400186E5CFB7614A40730E9E094D404740DCA16131EA624A40102384471B434740DCA16131EA624A40102384471B4347400186E5CFB7614A40730E9E094D4047400186E5CFB7614A40
53628	2468	46.631106000000003	46.654822000000003	52.844853999999998	52.826357999999999	Победы	0103000020E610000001000000050000009A27D714C8504740DC645419C6694A409A27D714C850474088F2052D246C4A40C5591135D153474088F2052D246C4A40C5591135D1534740DC645419C6694A409A27D714C8504740DC645419C6694A40
53898	2391	46.663409999999999	46.694167999999998	52.760348	52.730164000000002	Центральная	0103000020E6100000010000000500000070EB6E9EEA544740B85B9203765D4A4070EB6E9EEA5447401DCA501553614A4001F73C7FDA5847401DCA501553614A4001F73C7FDA584740B85B9203765D4A4070EB6E9EEA544740B85B9203765D4A40
53476	2284	46.469076999999999	46.513032000000003	52.876818	52.862614000000001	переулок Советский	0103000020E61000000100000005000000242713B70A3C47402F89B3226A6E4A40242713B70A3C4740A6457D923B704A4097E65608AB414740A6457D923B704A4097E65608AB4147402F89B3226A6E4A40242713B70A3C47402F89B3226A6E4A40
53772	2284	46.469076999999999	46.513032000000003	52.876818	52.862614000000001	 пер.Советский	0103000020E61000000100000005000000242713B70A3C47402F89B3226A6E4A40242713B70A3C4740A6457D923B704A4097E65608AB414740A6457D923B704A4097E65608AB4147402F89B3226A6E4A40242713B70A3C47402F89B3226A6E4A40
54226	2266	46.861370999999998	46.891061000000001	52.883316999999998	52.870784999999998	Центральная	0103000020E61000000100000005000000855CA967416E4740766C04E2756F4A40855CA967416E47401B800D8810714A40DBDE6E490E7247401B800D8810714A40DBDE6E490E724740766C04E2756F4A40855CA967416E4740766C04E2756F4A40
53753	1925	46.707445	46.756233000000002	52.800334999999997	52.775637000000003	Полевая	0103000020E61000000100000005000000FF5BC98E8D5A4740A648BE1248634A40FF5BC98E8D5A47400D6C956071664A40F793313ECC6047400D6C956071664A40F793313ECC604740A648BE1248634A40FF5BC98E8D5A4740A648BE1248634A40
54119	1925	46.707445	46.756233000000002	52.800334999999997	52.775637000000003	Николаева	0103000020E61000000100000005000000FF5BC98E8D5A4740A648BE1248634A40FF5BC98E8D5A47400D6C956071664A40F793313ECC6047400D6C956071664A40F793313ECC604740A648BE1248634A40FF5BC98E8D5A4740A648BE1248634A40
53627	1925	46.707445	46.756233000000002	52.800334999999997	52.775637000000003	Молодежная	0103000020E61000000100000005000000FF5BC98E8D5A4740A648BE1248634A40FF5BC98E8D5A47400D6C956071664A40F793313ECC6047400D6C956071664A40F793313ECC604740A648BE1248634A40FF5BC98E8D5A4740A648BE1248634A40
53350	1925	46.707445	46.756233000000002	52.800334999999997	52.775637000000003	Ленина	0103000020E61000000100000005000000FF5BC98E8D5A4740A648BE1248634A40FF5BC98E8D5A47400D6C956071664A40F793313ECC6047400D6C956071664A40F793313ECC604740A648BE1248634A40FF5BC98E8D5A4740A648BE1248634A40
53670	1925	46.707445	46.756233000000002	52.800334999999997	52.775637000000003	Комсомольская	0103000020E61000000100000005000000FF5BC98E8D5A4740A648BE1248634A40FF5BC98E8D5A47400D6C956071664A40F793313ECC6047400D6C956071664A40F793313ECC604740A648BE1248634A40FF5BC98E8D5A4740A648BE1248634A40
54223	1914	46.706654999999998	46.715862000000001	52.698822999999997	52.689838999999999	Школьная	0103000020E610000001000000050000000647C9AB735A4740AF40F4A44C584A400647C9AB735A4740A758350873594A407E39B35DA15B4740A758350873594A407E39B35DA15B4740AF40F4A44C584A400647C9AB735A4740AF40F4A44C584A40
54122	1833	46.646161999999997	46.660400000000003	52.821492999999997	52.812328000000001	Молодежная	0103000020E610000001000000050000007FF5B86FB552474003D0285DFA674A407FF5B86FB55247404B72C0AE26694A40A323B9FC875447404B72C0AE26694A40A323B9FC8754474003D0285DFA674A407FF5B86FB552474003D0285DFA674A40
53761	1783	46.743243	46.766851000000003	52.678778999999999	52.666755000000002	Мостовая	0103000020E610000001000000050000008FFD2C96225F4740E5B8533A58554A408FFD2C96225F4740151BF33AE2564A40D4F36E2C28624740151BF33AE2564A40D4F36E2C28624740E5B8533A58554A408FFD2C96225F4740E5B8533A58554A40
54116	1723	46.785356	46.805523000000001	52.757050999999997	52.742851999999999	Новая	0103000020E61000000100000005000000D3DB9F8B8664474054E23AC6155F4A40D3DB9F8B86644740B933130CE7604A408196AE601B674740B933130CE7604A408196AE601B67474054E23AC6155F4A40D3DB9F8B8664474054E23AC6155F4A40
54221	1665	46.582076000000001	46.596898000000003	52.799295000000001	52.793196999999999	Дружбы	0103000020E61000000100000005000000ACE46377814A47408524B37A87654A40ACE46377814A47409C6D6E4C4F664A401F865627674C47409C6D6E4C4F664A401F865627674C47408524B37A87654A40ACE46377814A47408524B37A87654A40
54036	1605	46.917560999999999	46.950161000000001	52.800319000000002	52.789548000000003	Центральная	0103000020E61000000100000005000000E38A8BA372754740A54FABE80F654A40E38A8BA37275474008AF5DDA70664A40A3772AE09E79474008AF5DDA70664A40A3772AE09E794740A54FABE80F654A40E38A8BA372754740A54FABE80F654A40
53890	1554	46.609096999999998	46.626561000000002	52.701490999999997	52.692349999999998	Центральная	0103000020E61000000100000005000000BD8BF7E3F64D47405BB1BFEC9E584A40BD8BF7E3F64D47401BB80375CA594A407BF99D26335047401BB80375CA594A407BF99D26335047405BB1BFEC9E584A40BD8BF7E3F64D47405BB1BFEC9E584A40
54029	1502	46.639622000000003	46.661262999999998	52.811968999999998	52.802622	Школьная	0103000020E61000000100000005000000ACE63922DF5147406A865451BC664A40ACE63922DF514740D32EA699EE674A4005871744A4544740D32EA699EE674A4005871744A45447406A865451BC664A40ACE63922DF5147406A865451BC664A40
53998	1446	46.387743999999998	46.438758999999997	52.899742000000003	52.876437000000003	Центральная	0103000020E61000000100000005000000309C6B98A13147408F006E162F704A40309C6B98A1314740386BF0BE2A734A40AFE9414129384740386BF0BE2A734A40AFE94141293847408F006E162F704A40309C6B98A13147408F006E162F704A40
53667	1446	46.387743999999998	46.438758999999997	52.899742000000003	52.876437000000003	 Центральная	0103000020E61000000100000005000000309C6B98A13147408F006E162F704A40309C6B98A1314740386BF0BE2A734A40AFE9414129384740386BF0BE2A734A40AFE94141293847408F006E162F704A40309C6B98A13147408F006E162F704A40
53672	1376	46.795380999999999	46.828277	52.786667000000001	52.775871000000002	Речная	0103000020E610000001000000050000000D6E6B0BCF6547401975ADBD4F634A400D6E6B0BCF654740D5EB1681B1644A40B68311FB046A4740D5EB1681B1644A40B68311FB046A47401975ADBD4F634A400D6E6B0BCF6547401975ADBD4F634A40
54031	1317	46.812719000000001	46.837332000000004	52.818255000000001	52.801364	Центральная	0103000020E610000001000000050000003EEB1A2D076847408B18761893664A403EEB1A2D07684740ED647094BC684A4078F2E9B12D6B4740ED647094BC684A4078F2E9B12D6B47408B18761893664A403EEB1A2D076847408B18761893664A40
54220	1282	46.843845000000002	46.864398999999999	52.855905	52.835084999999999	Центральная	0103000020E6100000010000000500000052F2EA1C036C4740A930B610E46A4A4052F2EA1C036C4740CFBD874B8E6D4A40F9D85DA0A46E4740CFBD874B8E6D4A40F9D85DA0A46E4740A930B610E46A4A4052F2EA1C036C4740A930B610E46A4A40
53624	1222	46.771720000000002	46.807895000000002	52.890946	52.873654999999999	Дубровка	0103000020E61000000100000005000000A6D590B8C7624740527E52EDD36F4A40A6D590B8C76247404240BE840A724A400CCD751A696747404240BE840A724A400CCD751A69674740527E52EDD36F4A40A6D590B8C7624740527E52EDD36F4A40
54028	1109	46.676380999999999	46.692371000000001	52.812458999999997	52.803291000000002	Набережная	0103000020E61000000100000005000000615111A793564740E8154F3DD2664A40615111A793564740A12B11A8FE674A4073D9E89C9F584740A12B11A8FE674A4073D9E89C9F584740E8154F3DD2664A40615111A793564740E8154F3DD2664A40
53701	1106	46.863581000000003	46.889308999999997	52.793337999999999	52.776797000000002	Центральная	0103000020E6100000010000000500000037397CD2896E4740C25087156E634A4037397CD2896E474047567E198C654A40EC8497E0D471474047567E198C654A40EC8497E0D4714740C25087156E634A4037397CD2896E4740C25087156E634A40
54025	620	43.655715000000001	43.678829	53.910924999999999	53.901021	Старая Шиловка	0103000020E61000000100000005000000923F1878EED345402E01F8A754F34A40923F1878EED34540ED0DBE3099F44A40C74961DEE3D64540ED0DBE3099F44A40C74961DEE3D645402E01F8A754F34A40923F1878EED345402E01F8A754F34A40
9832	484	43.516674000000002	43.545321000000001	53.988273	53.974621999999997	Первомайская	0103000020E61000000100000005000000C558A65F22C2454026FBE769C0FC4A40C558A65F22C245408942CBBA7FFE4A4038691A14CDC545408942CBBA7FFE4A4038691A14CDC5454026FBE769C0FC4A40C558A65F22C2454026FBE769C0FC4A40
54024	537	43.542572999999997	43.571202	53.972282	53.957540000000002	Пролетарская	0103000020E61000000100000005000000A758350873C54540514EB4AB90FA4A40A758350873C54540A73E90BC73FC4A4074B4AA251DC94540A73E90BC73FC4A4074B4AA251DC94540514EB4AB90FA4A40A758350873C54540514EB4AB90FA4A40
54014	31354	43.479610000000001	43.499040000000001	53.819204999999997	53.803213	Горького	0103000020E61000000100000005000000D36A48DC63BD45406C5CFFAECFE64A40D36A48DC63BD45401EDC9DB5DBE84A40ABB2EF8AE0BF45401EDC9DB5DBE84A40ABB2EF8AE0BF45406C5CFFAECFE64A40D36A48DC63BD45406C5CFFAECFE64A40
54088	56491	43.777625999999998	43.790965999999997	53.748294000000001	53.740541	 Шведская	0103000020E610000001000000050000007842AF3F89E345406F2C280CCADE4A407842AF3F89E3454082E50819C8DF4A40BC1FB75F3EE5454082E50819C8DF4A40BC1FB75F3EE545406F2C280CCADE4A407842AF3F89E345406F2C280CCADE4A40
54285	56522	43.408318999999999	43.973844999999997	54.014549000000002	53.664396000000004	Школьная	0103000020E61000000100000005000000EFAA07CC43B44540EFCB99ED0AD54A40EFAA07CC43B445404298DBBDDC014B40C22FF5F3A6FC45404298DBBDDC014B40C22FF5F3A6FC4540EFCB99ED0AD54A40EFAA07CC43B44540EFCB99ED0AD54A40
54270	32482	43.559479000000003	43.581955000000001	53.834288000000001	53.826917000000002	Советская	0103000020E610000001000000050000003FE603029DC74540D3C08F6AD8E94A403FE603029DC74540FEB8FDF2C9EA4A40315F5E807DCA4540FEB8FDF2C9EA4A40315F5E807DCA4540D3C08F6AD8E94A403FE603029DC74540D3C08F6AD8E94A40
54213	368	43.437308000000002	43.464365000000001	53.883685999999997	53.872905000000003	Новинка	0103000020E61000000100000005000000BC2363B5F9B74540E8C1DD59BBEF4A40BC2363B5F9B745406EF7729F1CF14A401A34F44F70BB45406EF7729F1CF14A401A34F44F70BB4540E8C1DD59BBEF4A40BC2363B5F9B74540E8C1DD59BBEF4A40
54268	56513	43.673960000000001	43.697631000000001	53.757095	53.742719000000001	Подлужная	0103000020E61000000100000005000000F5673F5244D64540158F8B6A11DF4A40F5673F5244D64540897B2C7DE8E04A4080D6FCF84BD94540897B2C7DE8E04A4080D6FCF84BD94540158F8B6A11DF4A40F5673F5244D64540158F8B6A11DF4A40
54111	32326	43.664177000000002	43.690902000000001	53.817467000000001	53.797342	Ленина	0103000020E61000000100000005000000B1E07EC003D5454016DD7A4D0FE64A40B1E07EC003D54540954737C2A2E84A40D95E0B7A6FD84540954737C2A2E84A40D95E0B7A6FD8454016DD7A4D0FE64A40B1E07EC003D5454016DD7A4D0FE64A40
53885	90	43.482016999999999	43.497818000000002	53.840589000000001	53.831961	Комсомольская	0103000020E61000000100000005000000DA8EA9BBB2BD45401346B3B27DEA4A40DA8EA9BBB2BD45404D309C6B98EB4A4019AE0E80B8BF45404D309C6B98EB4A4019AE0E80B8BF45401346B3B27DEA4A40DA8EA9BBB2BD45401346B3B27DEA4A40
54018	423	43.487434	43.514536	53.935633000000003	53.918560999999997	 Зеленая	0103000020E61000000100000005000000AF7AC03C64BE4540C630276893F54A40AF7AC03C64BE4540790778D2C2F74A40AD4ECE50DCC14540790778D2C2F74A40AD4ECE50DCC14540C630276893F54A40AF7AC03C64BE4540C630276893F54A40
54219	743	43.659821000000001	43.701242000000001	53.949497000000001	53.940190999999999	 Молодежная	0103000020E61000000100000005000000651BB80375D445402C7FBE2D58F84A40651BB80375D445403753211E89F94A40734A404CC2D945403753211E89F94A40734A404CC2D945402C7FBE2D58F84A40651BB80375D445402C7FBE2D58F84A40
53665	32062	43.768625	43.810440999999997	53.812443000000002	53.794049999999999	Молодёжная	0103000020E61000000100000005000000AAF1D24D62E24540C4B12E6EA3E54A40AAF1D24D62E245409C6ED921FEE74A40342BDB87BCE745409C6ED921FEE74A40342BDB87BCE74540C4B12E6EA3E54A40AAF1D24D62E24540C4B12E6EA3E54A40
53386	850	43.676834999999997	43.713754999999999	53.899180000000001	53.861314999999998	Советская	0103000020E61000000100000005000000E2E47E87A2D64540F146E6913FEE4A40E2E47E87A2D64540D09B8A5418F34A40A12DE7525CDB4540D09B8A5418F34A40A12DE7525CDB4540F146E6913FEE4A40E2E47E87A2D64540F146E6913FEE4A40
53351	850	43.676834999999997	43.713754999999999	53.899180000000001	53.861314999999998	Ленина	0103000020E61000000100000005000000E2E47E87A2D64540F146E6913FEE4A40E2E47E87A2D64540D09B8A5418F34A40A12DE7525CDB4540D09B8A5418F34A40A12DE7525CDB4540F146E6913FEE4A40E2E47E87A2D64540F146E6913FEE4A40
54026	1031	43.622495999999998	43.666603000000002	53.893869000000002	53.882752000000004	Малинская	0103000020E6100000010000000500000006F2ECF2ADCF4540433D7D04FEF04A4006F2ECF2ADCF454041F4A44C6AF24A402F35423F53D5454041F4A44C6AF24A402F35423F53D54540433D7D04FEF04A4006F2ECF2ADCF4540433D7D04FEF04A40
54006	32417	43.590074999999999	43.618318000000002	53.801735000000001	53.791145999999998	Садовая	0103000020E61000000100000005000000F697DD9387CB45403C2EAA4544E54A40F697DD9387CB45407F87A2409FE64A409A43520B25CF45407F87A2409FE64A409A43520B25CF45403C2EAA4544E54A40F697DD9387CB45403C2EAA4544E54A40
54217	633	43.602283999999997	43.634874000000003	53.961830999999997	53.953195999999998	Сорокина	0103000020E61000000100000005000000B87361A417CD4540C956975302FA4A40B87361A417CD4540B5A338471DFB4A40558A1D8D43D14540B5A338471DFB4A40558A1D8D43D14540C956975302FA4A40B87361A417CD4540C956975302FA4A40
53887	239	43.523339999999997	43.545824000000003	53.859631	53.846874	Молодежная	0103000020E6100000010000000500000025581CCEFCC2454096EA025E66EC4A4025581CCEFCC245405BD07B6308EE4A409BAF928FDDC545405BD07B6308EE4A409BAF928FDDC5454096EA025E66EC4A4025581CCEFCC2454096EA025E66EC4A40
54218	32270	43.681362	43.712308999999998	53.785640000000001	53.769821	Молодёжная	0103000020E610000001000000050000005B5EB9DE36D745401363997E89E24A405B5EB9DE36D74540F836FDD98FE44A40BFD2F9F02CDB4540F836FDD98FE44A40BFD2F9F02CDB45401363997E89E24A405B5EB9DE36D745401363997E89E24A40
53755	32270	43.681362	43.712308999999998	53.785640000000001	53.769821	Молодежная	0103000020E610000001000000050000005B5EB9DE36D745401363997E89E24A405B5EB9DE36D74540F836FDD98FE44A40BFD2F9F02CDB4540F836FDD98FE44A40BFD2F9F02CDB45401363997E89E24A405B5EB9DE36D745401363997E89E24A40
54166	252	43.591099999999997	43.612074999999997	53.854022999999998	53.846842000000002	Заречная	0103000020E610000001000000050000003255302AA9CB45408B70935165EC4A403255302AA9CB454012842BA050ED4A407FD93D7958CE454012842BA050ED4A407FD93D7958CE45408B70935165EC4A403255302AA9CB45408B70935165EC4A40
53632	32182	43.687793999999997	43.713521999999998	53.723292999999998	53.703704000000002	Советская	0103000020E61000000100000005000000483140A209D845403E0801F912DA4A40483140A209D845407E3672DD94DC4A40FE7C5BB054DB45407E3672DD94DC4A40FE7C5BB054DB45403E0801F912DA4A40483140A209D845403E0801F912DA4A40
53884	32106	43.761645000000001	43.777400999999998	53.714709999999997	53.702499000000003	Центральная	0103000020E61000000100000005000000BA1457957DE14540823CBB7CEBD94A40BA1457957DE14540E40F069E7BDB4A4058703FE081E34540E40F069E7BDB4A4058703FE081E34540823CBB7CEBD94A40BA1457957DE14540823CBB7CEBD94A40
53784	56450	43.679485	43.717789000000003	53.849795	53.829458000000002	Молодежная	0103000020E61000000100000005000000B08F4E5DF9D64540EAB303AE2BEA4A40B08F4E5DF9D64540F4A62215C6EC4A40DB368C82E0DB4540F4A62215C6EC4A40DB368C82E0DB4540EAB303AE2BEA4A40B08F4E5DF9D64540EAB303AE2BEA4A40
54059	32587	43.765993000000002	43.788001000000001	53.940541000000003	53.921345000000002	Лысовка	0103000020E6100000010000000500000083FB010F0CE24540A4AA09A2EEF54A4083FB010F0CE2454009C6C1A563F84A408F1B7E37DDE4454009C6C1A563F84A408F1B7E37DDE44540A4AA09A2EEF54A4083FB010F0CE24540A4AA09A2EEF54A40
54319	30328	44.592576999999999	44.616419	53.629643999999999	53.610556000000003	Центральная	0103000020E610000001000000050000004FAE2990D94B46403430F2B226CE4A404FAE2990D94B4640B20FB22C98D04A4007D15AD1E64E4640B20FB22C98D04A4007D15AD1E64E46403430F2B226CE4A404FAE2990D94B46403430F2B226CE4A40
54312	31207	44.153903	44.201666000000003	53.46969	53.443970999999998	Мирная	0103000020E61000000100000005000000CEE0EF17B3134640ABAFAE0AD4B84A40CEE0EF17B31346400EA14ACD1EBC4A408A5B0531D01946400EA14ACD1EBC4A408A5B0531D0194640ABAFAE0AD4B84A40CEE0EF17B3134640ABAFAE0AD4B84A40
54291	30990	44.322786000000001	44.350507999999998	53.600639999999999	53.568615999999999	Базарная площадь	0103000020E61000000100000005000000A7CD380D51294640BDFDB968C8C84A40A7CD380D51294640B05582C5E1CC4A40417E3672DD2C4640B05582C5E1CC4A40417E3672DD2C4640BDFDB968C8C84A40A7CD380D51294640BDFDB968C8C84A40
54307	30251	44.730117999999997	44.772967999999999	53.616101	53.598427999999998	Центральная	0103000020E61000000100000005000000471CB281745D46405E81E84999CC4A40471CB281745D46403604C765DCCE4A40616D8C9DF06246403604C765DCCE4A40616D8C9DF06246405E81E84999CC4A40471CB281745D46405E81E84999CC4A40
54010	56480	44.357821000000001	44.365070000000003	53.662939999999999	53.657631000000002	Клещёвка	0103000020E6100000010000000500000038691A14CD2D4640FBEAAA402DD44A4038691A14CD2D4640E99AC937DBD44A4018601F9DBA2E4640E99AC937DBD44A4018601F9DBA2E4640FBEAAA402DD44A4038691A14CD2D4640FBEAAA402DD44A40
54295	30493	44.381867999999997	44.407640999999998	53.328741000000001	53.308579999999999	Ермакова	0103000020E61000000100000005000000C8B1F50CE13046408F19A88C7FA74A40C8B1F50CE13046405BED612F14AA4A401EC18D942D3446405BED612F14AA4A401EC18D942D3446408F19A88C7FA74A40C8B1F50CE13046408F19A88C7FA74A40
54303	31544	44.761667000000003	44.785418999999997	53.532654999999998	53.516092999999998	Маливиновка	0103000020E61000000100000005000000A2B8E34D7E614640E658DE550FC24A40A2B8E34D7E6146408386FE092EC44A4019541B9C886446408386FE092EC44A4019541B9C88644640E658DE550FC24A40A2B8E34D7E614640E658DE550FC24A40
54300	31438	44.375706000000001	44.399780999999997	53.546809000000003	53.531874000000002	Демин Конец	0103000020E610000001000000050000009B745B2217304640DECB7D7214C44A409B745B221730464049145AD6FDC54A40F54718062C33464049145AD6FDC54A40F54718062C334640DECB7D7214C44A409B745B2217304640DECB7D7214C44A40
54315	30427	44.519849999999998	44.541848999999999	53.466903000000002	53.454239999999999	Школьная	0103000020E61000000100000005000000AD69DE718A4246407C444C8924BA4A40AD69DE718A424640C0B33D7AC3BB4A40662FDB4E5B454640C0B33D7AC3BB4A40662FDB4E5B4546407C444C8924BA4A40AD69DE718A4246407C444C8924BA4A40
54289	30944	44.685777999999999	44.767102000000001	53.316881000000002	53.272333000000003	Желиховского	0103000020E610000001000000050000007C28D192C7574640904FC8CEDBA24A407C28D192C7574640A5DC7D8E8FA84A401D59F96530624640A5DC7D8E8FA84A401D59F96530624640904FC8CEDBA24A407C28D192C7574640904FC8CEDBA24A40
54318	30737	44.730333999999999	44.750456	53.283963	53.270668999999998	Строительная	0103000020E610000001000000050000001494A2957B5D464040852348A5A24A401494A2957B5D464014234BE658A44A40228B34F10E60464014234BE658A44A40228B34F10E60464040852348A5A24A401494A2957B5D464040852348A5A24A40
54293	31163	44.058017	44.118113999999998	53.526649999999997	53.506802999999998	Ленина	0103000020E6100000010000000500000057CEDE196D074640E141B3EBDEC04A4057CEDE196D0746401D38674469C34A4091990B5C1E0F46401D38674469C34A4091990B5C1E0F4640E141B3EBDEC04A4057CEDE196D074640E141B3EBDEC04A40
54325	31091	44.328158000000002	44.345585999999997	53.447879999999998	53.438205000000004	Малая Хомяковка	0103000020E61000000100000005000000DCF5D214012A4640CBF8F71917B84A40DCF5D214012A46402844C02154B94A404CFA7B293C2C46402844C02154B94A404CFA7B293C2C4640CBF8F71917B84A40DCF5D214012A4640CBF8F71917B84A40
54305	31261	44.442442	44.462015999999998	53.484149000000002	53.469234999999998	 Садовая	0103000020E610000001000000050000003C3080F0A1384640BC9179E40FBC4A403C3080F0A138464010B22C98F8BD4A40471D1D57233B464010B22C98F8BD4A40471D1D57233B4640BC9179E40FBC4A403C3080F0A1384640BC9179E40FBC4A40
54324	31689	44.575769999999999	44.587510999999999	53.393541999999997	53.38458	Рабочая	0103000020E610000001000000050000004B02D4D4B24946400C59DDEA39B14A404B02D4D4B24946401CCD91955FB24A402785798F334B46401CCD91955FB24A402785798F334B46400C59DDEA39B14A404B02D4D4B24946400C59DDEA39B14A40
54301	30856	44.284337999999998	44.302323000000001	53.262261000000002	53.253270999999998	Школьная	0103000020E6100000010000000500000049810530652446403A03232F6BA04A4049810530652446401502B9C491A14A4010EA2285B22646401502B9C491A14A4010EA2285B22646403A03232F6BA04A4049810530652446403A03232F6BA04A40
54316	30564	44.446727000000003	44.481814999999997	53.286175	53.262095000000002	Совхозная	0103000020E61000000100000005000000BF9EAF592E394640FAB836548CA14A40BF9EAF592E39464066F7E461A1A44A4072DC291DAC3D464066F7E461A1A44A4072DC291DAC3D4640FAB836548CA14A40BF9EAF592E394640FAB836548CA14A40
53385	30564	44.446727000000003	44.481814999999997	53.286175	53.262095000000002	Рабочая	0103000020E61000000100000005000000BF9EAF592E394640FAB836548CA14A40BF9EAF592E39464066F7E461A1A44A4072DC291DAC3D464066F7E461A1A44A4072DC291DAC3D4640FAB836548CA14A40BF9EAF592E394640FAB836548CA14A40
54287	30303	44.694553999999997	44.722034000000001	53.642031000000003	53.623514	Школьная	0103000020E610000001000000050000002AA73D25E7584640904C874ECFCF4A402AA73D25E7584640540262122ED24A40CF4C309C6B5C4640540262122ED24A40CF4C309C6B5C4640904C874ECFCF4A402AA73D25E7584640904C874ECFCF4A40
54323	31739	44.582211000000001	44.643304999999998	53.465927999999998	53.413426999999999	Студенческая	0103000020E610000001000000050000008C2FDAE3854A464046240A2DEBB44A408C2FDAE3854A464035255987A3BB4A40382D78D15752464035255987A3BB4A40382D78D15752464046240A2DEBB44A408C2FDAE3854A464046240A2DEBB44A40
54309	31739	44.582211000000001	44.643304999999998	53.465927999999998	53.413426999999999	Советская	0103000020E610000001000000050000008C2FDAE3854A464046240A2DEBB44A408C2FDAE3854A464035255987A3BB4A40382D78D15752464035255987A3BB4A40382D78D15752464046240A2DEBB44A408C2FDAE3854A464046240A2DEBB44A40
65265	31739	44.582211000000001	44.643304999999998	53.465927999999998	53.413426999999999	Победы	0103000020E610000001000000050000008C2FDAE3854A464046240A2DEBB44A408C2FDAE3854A464035255987A3BB4A40382D78D15752464035255987A3BB4A40382D78D15752464046240A2DEBB44A408C2FDAE3854A464046240A2DEBB44A40
54297	31739	44.582211000000001	44.643304999999998	53.465927999999998	53.413426999999999	Куйбышева	0103000020E610000001000000050000008C2FDAE3854A464046240A2DEBB44A408C2FDAE3854A464035255987A3BB4A40382D78D15752464035255987A3BB4A40382D78D15752464046240A2DEBB44A408C2FDAE3854A464046240A2DEBB44A40
54296	31739	44.582211000000001	44.643304999999998	53.465927999999998	53.413426999999999	Красное Польцо	0103000020E610000001000000050000008C2FDAE3854A464046240A2DEBB44A408C2FDAE3854A464035255987A3BB4A40382D78D15752464035255987A3BB4A40382D78D15752464046240A2DEBB44A408C2FDAE3854A464046240A2DEBB44A40
54286	31739	44.582211000000001	44.643304999999998	53.465927999999998	53.413426999999999	1-я Разведка	0103000020E610000001000000050000008C2FDAE3854A464046240A2DEBB44A408C2FDAE3854A464035255987A3BB4A40382D78D15752464035255987A3BB4A40382D78D15752464046240A2DEBB44A408C2FDAE3854A464046240A2DEBB44A40
54120	31260	44.469239000000002	44.504480000000001	53.480929000000003	53.460090000000001	Центральная	0103000020E61000000100000005000000FE800706103C4640BB9BA73AE4BA4A40FE800706103C46405859DB148FBD4A4038BEF6CC924046405859DB148FBD4A4038BEF6CC92404640BB9BA73AE4BA4A40FE800706103C4640BB9BA73AE4BA4A40
54322	31260	44.469239000000002	44.504480000000001	53.480929000000003	53.460090000000001	Советская	0103000020E61000000100000005000000FE800706103C4640BB9BA73AE4BA4A40FE800706103C46405859DB148FBD4A4038BEF6CC924046405859DB148FBD4A4038BEF6CC92404640BB9BA73AE4BA4A40FE800706103C4640BB9BA73AE4BA4A40
54302	31590	44.705036999999997	44.716455000000003	53.368174000000003	53.358829999999998	Совхозная	0103000020E6100000010000000500000027BC04A73E5A46406E693524EEAD4A4027BC04A73E5A4640679E5C5320AF4A40210725CCB45B4640679E5C5320AF4A40210725CCB45B46406E693524EEAD4A4027BC04A73E5A46406E693524EEAD4A40
53475	48787	44.854678999999997	44.868279000000001	53.660207999999997	53.649962000000002	 Фабричная	0103000020E61000000100000005000000FBC9181F666D464046D26EF431D34A40FBC9181F666D46405E471CB281D44A40DC662AC4236F46405E471CB281D44A40DC662AC4236F464046D26EF431D34A40FBC9181F666D464046D26EF431D34A40
54118	56495	44.220835999999998	44.238677000000003	53.409922000000002	53.406588999999997	Молодежная	0103000020E61000000100000005000000C5E3A25A441C4640E8F4BC1B0BB44A40C5E3A25A441C464099F4F75278B44A4059A7CAF78C1E464099F4F75278B44A4059A7CAF78C1E4640E8F4BC1B0BB44A40C5E3A25A441C4640E8F4BC1B0BB44A40
54310	31403	44.469507999999998	44.491813	53.538440000000001	53.519204000000002	Центральная	0103000020E61000000100000005000000ED9A90D6183C4640E8F9D34675C24A40ED9A90D6183C4640DB6D179AEBC44A40B35F77BAF33E4640DB6D179AEBC44A40B35F77BAF33E4640E8F9D34675C24A40ED9A90D6183C4640E8F9D34675C24A40
53302	31488	44.653708000000002	44.681466	53.556074000000002	53.541496000000002	Шоссейное	0103000020E61000000100000005000000199128B4AC5346401975ADBD4FC54A40199128B4AC534640F513CE6E2DC74A4000AB23473A574640F513CE6E2DC74A4000AB23473A5746401975ADBD4FC54A40199128B4AC5346401975ADBD4FC54A40
53363	31488	44.653708000000002	44.681466	53.556074000000002	53.541496000000002	Шоссейная	0103000020E61000000100000005000000199128B4AC5346401975ADBD4FC54A40199128B4AC534640F513CE6E2DC74A4000AB23473A574640F513CE6E2DC74A4000AB23473A5746401975ADBD4FC54A40199128B4AC5346401975ADBD4FC54A40
54313	31488	44.653708000000002	44.681466	53.556074000000002	53.541496000000002	Пановка	0103000020E61000000100000005000000199128B4AC5346401975ADBD4FC54A40199128B4AC534640F513CE6E2DC74A4000AB23473A574640F513CE6E2DC74A4000AB23473A5746401975ADBD4FC54A40199128B4AC5346401975ADBD4FC54A40
65029	58421	44.389702	44.405593000000003	53.312550000000002	53.301402000000003	улица Ленина	0103000020E61000000100000005000000C89750C1E131464079793A5794A64A40C89750C1E1314640B22E6EA301A84A40473EAF78EA334640B22E6EA301A84A40473EAF78EA33464079793A5794A64A40C89750C1E131464079793A5794A64A40
54306	30809	44.524296	44.552548000000002	53.354401000000003	53.337339	Центральная	0103000020E6100000010000000500000039B69E211C4346402A55A2EC2DAB4A4039B69E211C434640B95510035DAD4A4030BC92E4B9464640B95510035DAD4A4030BC92E4B94646402A55A2EC2DAB4A4039B69E211C4346402A55A2EC2DAB4A40
54321	31079	44.192396000000002	44.289064000000003	53.627187999999997	53.605907999999999	Школьная	0103000020E61000000100000005000000CCF09F6EA01846404031B2648ECD4A40CCF09F6EA0184640C93846B247D04A40B939950C00254640C93846B247D04A40B939950C002546404031B2648ECD4A40CCF09F6EA01846404031B2648ECD4A40
54163	31079	44.192396000000002	44.289064000000003	53.627187999999997	53.605907999999999	Придорожная	0103000020E61000000100000005000000CCF09F6EA01846404031B2648ECD4A40CCF09F6EA0184640C93846B247D04A40B939950C00254640C93846B247D04A40B939950C002546404031B2648ECD4A40CCF09F6EA01846404031B2648ECD4A40
54292	30895	44.231085999999998	44.246735000000001	53.362301000000002	53.352137999999997	Ждановская	0103000020E610000001000000050000001F48DE39941D4640E4D6A4DB12AD4A401F48DE39941D4640702711E15FAE4A40A8E33103951F4640702711E15FAE4A40A8E33103951F4640E4D6A4DB12AD4A401F48DE39941D4640E4D6A4DB12AD4A40
54311	30384	44.518932999999997	44.539720000000003	53.451816000000001	53.435228000000002	Центральная	0103000020E6100000010000000500000057E883656C424640D926158DB5B74A4057E883656C4246409FE74F1BD5B94A40A27F828B154546409FE74F1BD5B94A40A27F828B15454640D926158DB5B74A4057E883656C424640D926158DB5B74A40
53472	48009	44.855531999999997	44.861524000000003	53.649973000000003	53.642606999999998	Центральная	0103000020E610000001000000050000003A579412826D4640209738F240D24A403A579412826D46403A24B55032D34A400C5C1E6B466E46403A24B55032D34A400C5C1E6B466E4640209738F240D24A403A579412826D4640209738F240D24A40
54320	30174	44.338507	44.350625000000001	53.648254000000001	53.640006999999997	Алексеевка	0103000020E61000000100000005000000C93B8732542B4640041BD7BFEBD14A40C93B8732542B464027C0B0FCF9D24A407B14AE47E12C464027C0B0FCF9D24A407B14AE47E12C4640041BD7BFEBD14A40C93B8732542B4640041BD7BFEBD14A40
54109	30161	44.797187000000001	44.827837000000002	52.480936	52.467140000000001	Луговая	0103000020E61000000100000005000000EFE53E390A664640A453573ECB3B4A40EFE53E390A6646400ABC934F8F3D4A409AB51490F66946400ABC934F8F3D4A409AB51490F6694640A453573ECB3B4A40EFE53E390A664640A453573ECB3B4A40
54190	29523	45.253216000000002	45.280974000000001	52.510860999999998	52.483097000000001	Центральная	0103000020E610000001000000050000007769C36169A04640DAE55B1FD63D4A407769C36169A04640A3E6ABE463414A405E83BEF4F6A34640A3E6ABE463414A405E83BEF4F6A34640DAE55B1FD63D4A407769C36169A04640DAE55B1FD63D4A40
54214	29246	45.013195000000003	45.045490000000001	52.371160000000003	52.354683999999999	Зажигина	0103000020E6100000010000000500000041BCAE5FB08146400D350A49662D4A4041BCAE5FB0814640ACCABE2B822F4A40C425C79DD2854640ACCABE2B822F4A40C425C79DD28546400D350A49662D4A4041BCAE5FB08146400D350A49662D4A40
53698	29598	45.105722	45.156046000000003	52.581856999999999	52.548065999999999	Садовая	0103000020E61000000100000005000000DE3B6A4C888D46405706D50627464A40DE3B6A4C888D46406EF9484A7A4A4A40F855B950F99346406EF9484A7A4A4A40F855B950F99346405706D50627464A40DE3B6A4C888D46405706D50627464A40
54104	29325	45.065370000000001	45.109242999999999	52.465553999999997	52.449584999999999	Советская	0103000020E61000000100000005000000DC114E0B5E884640D6E253008C394A40DC114E0B5E884640D0420246973B4A409128B4ACFB8D4640D0420246973B4A409128B4ACFB8D4640D6E253008C394A40DC114E0B5E884640D6E253008C394A40
54112	29666	45.120750999999998	45.146613000000002	52.537764000000003	52.518352	Набережная	0103000020E61000000100000005000000CAFACDC4748F464079E8BB5B59424A40CAFACDC4748F4640AB7B6473D5444A409015FC36C4924640AB7B6473D5444A409015FC36C492464079E8BB5B59424A40CAFACDC4748F464079E8BB5B59424A40
53881	29791	44.951526000000001	44.992373000000001	52.664603	52.651018000000001	Кооперативная	0103000020E6100000010000000500000098A59D9ACB794640BD8DCD8E54534A4098A59D9ACB79464068E90AB611554A407A371614067F464068E90AB611554A407A371614067F4640BD8DCD8E54534A4098A59D9ACB794640BD8DCD8E54534A40
54013	29789	45.027963999999997	45.052900999999999	52.644592000000003	52.619219999999999	Звездная	0103000020E6100000010000000500000090BB085394834640BA83D899424F4A4090BB085394834640B2A19BFD81524A407D76C075C5864640B2A19BFD81524A407D76C075C5864640BA83D899424F4A4090BB085394834640BA83D899424F4A40
53882	30089	44.821243000000003	44.843629	52.508411000000002	52.492775999999999	 Школьная	0103000020E61000000100000005000000D388997D1E6946407920B248133F4A40D388997D1E6946409DF6949C13414A40857AFA08FC6B46409DF6949C13414A40857AFA08FC6B46407920B248133F4A40D388997D1E6946407920B248133F4A40
53889	30005	44.845471000000003	44.881717999999999	52.559317999999998	52.546641999999999	Школьная	0103000020E61000000100000005000000B45BCB64386C46405D4F745DF8454A40B45BCB64386C4640350873BB97474A40B325AB22DC704640350873BB97474A40B325AB22DC7046405D4F745DF8454A40B45BCB64386C46405D4F745DF8454A40
53750	19673	44.912557	44.997134000000003	52.486902999999998	52.445577999999998	Строительная	0103000020E61000000100000005000000315EF3AACE74464096E82CB308394A40315EF3AACE74464082A966D6523E4A4066DD3F16A27F464082A966D6523E4A4066DD3F16A27F464096E82CB308394A40315EF3AACE74464096E82CB308394A40
53663	19673	44.912557	44.997134000000003	52.486902999999998	52.445577999999998	Советская	0103000020E61000000100000005000000315EF3AACE74464096E82CB308394A40315EF3AACE74464082A966D6523E4A4066DD3F16A27F464082A966D6523E4A4066DD3F16A27F464096E82CB308394A40315EF3AACE74464096E82CB308394A40
54101	19673	44.912557	44.997134000000003	52.486902999999998	52.445577999999998	Пацаева	0103000020E61000000100000005000000315EF3AACE74464096E82CB308394A40315EF3AACE74464082A966D6523E4A4066DD3F16A27F464082A966D6523E4A4066DD3F16A27F464096E82CB308394A40315EF3AACE74464096E82CB308394A40
53743	19673	44.912557	44.997134000000003	52.486902999999998	52.445577999999998	Октябрьская	0103000020E61000000100000005000000315EF3AACE74464096E82CB308394A40315EF3AACE74464082A966D6523E4A4066DD3F16A27F464082A966D6523E4A4066DD3F16A27F464096E82CB308394A40315EF3AACE74464096E82CB308394A40
53749	19673	44.912557	44.997134000000003	52.486902999999998	52.445577999999998	Ленинская	0103000020E61000000100000005000000315EF3AACE74464096E82CB308394A40315EF3AACE74464082A966D6523E4A4066DD3F16A27F464082A966D6523E4A4066DD3F16A27F464096E82CB308394A40315EF3AACE74464096E82CB308394A40
54005	19673	44.912557	44.997134000000003	52.486902999999998	52.445577999999998	Калинина	0103000020E61000000100000005000000315EF3AACE74464096E82CB308394A40315EF3AACE74464082A966D6523E4A4066DD3F16A27F464082A966D6523E4A4066DD3F16A27F464096E82CB308394A40315EF3AACE74464096E82CB308394A40
54106	29412	45.303324000000003	45.335089000000004	52.438952999999998	52.421376000000002	2-я Молодежная	0103000020E61000000100000005000000C40B2252D3A64640DFA815A6EF354A40C40B2252D3A6464094BDA59C2F384A40EB1F4432E4AA464094BDA59C2F384A40EB1F4432E4AA4640DFA815A6EF354A40C40B2252D3A64640DFA815A6EF354A40
54107	29412	45.303324000000003	45.335089000000004	52.438952999999998	52.421376000000002	2-ая Молодежная	0103000020E61000000100000005000000C40B2252D3A64640DFA815A6EF354A40C40B2252D3A6464094BDA59C2F384A40EB1F4432E4AA464094BDA59C2F384A40EB1F4432E4AA4640DFA815A6EF354A40C40B2252D3A64640DFA815A6EF354A40
54215	29922	44.948354999999999	44.984521000000001	52.592942000000001	52.572335000000002	Школьная	0103000020E61000000100000005000000C1FF56B26379464097ADF54542494A40C1FF56B26379464061360186E54B4A40D49CBCC8047E464061360186E54B4A40D49CBCC8047E464097ADF54542494A40C1FF56B26379464097ADF54542494A40
54007	29954	44.862898000000001	44.888285000000003	52.605747000000001	52.586289000000001	 Дворянская	0103000020E6100000010000000500000054E41071736E4640958098840B4B4A4054E41071736E46403753211E894D4A408143A852B37146403753211E894D4A408143A852B3714640958098840B4B4A4054E41071736E4640958098840B4B4A40
54009	29705	45.184325000000001	45.203547999999998	52.626890000000003	52.609651999999997	Главная	0103000020E61000000100000005000000E86A2BF69797464072F8A413094E4A40E86A2BF697974640401878EE3D504A40469561DC0D9A4640401878EE3D504A40469561DC0D9A464072F8A413094E4A40E86A2BF69797464072F8A413094E4A40
54193	29878	45.024262999999998	45.045282999999998	52.617607999999997	52.602350999999999	Набережная	0103000020E610000001000000050000005DC0CB0C1B83464040DB6AD6194D4A405DC0CB0C1B834640BDDF68C70D4F4A404A0856D5CB854640BDDF68C70D4F4A404A0856D5CB85464040DB6AD6194D4A405DC0CB0C1B83464040DB6AD6194D4A40
54076	29510	45.247107999999997	45.275854000000002	52.403979	52.393011000000001	Студеная	0103000020E610000001000000050000003C4A253CA19F4640F0FB372F4E324A403C4A253CA19F4640A9A27895B5334A40433C122F4FA34640A9A27895B5334A40433C122F4FA34640F0FB372F4E324A403C4A253CA19F4640F0FB372F4E324A40
53877	32661	45.132446999999999	45.169736	53.693452999999998	53.681615000000001	Садовая	0103000020E6100000010000000500000006BAF605F490464045BB0A293FD74A4006BAF605F490464013286211C3D84A40187AC4E8B995464013286211C3D84A40187AC4E8B995464045BB0A293FD74A4006BAF605F490464045BB0A293FD74A40
54102	32549	44.931251000000003	44.953879999999998	53.663179999999997	53.649529999999999	Совхозная	0103000020E6100000010000000500000004AF963B33774640ACE28DCC23D34A4004AF963B337746403EAE0D15E3D44A407C2766BD187A46403EAE0D15E3D44A407C2766BD187A4640ACE28DCC23D34A4004AF963B33774640ACE28DCC23D34A40
53993	28693	45.153934999999997	45.179805999999999	53.770049999999998	53.759134000000003	Центральная	0103000020E61000000100000005000000D95A5F24B49346400EA48B4D2BE14A40D95A5F24B4934640742497FF90E24A40F2CF0CE203974640742497FF90E24A40F2CF0CE2039746400EA48B4D2BE14A40D95A5F24B49346400EA48B4D2BE14A40
54222	28370	45.318973	45.353163000000002	53.652768999999999	53.638347000000003	Максима Горького	0103000020E610000001000000050000004CA7751BD4A84640F73FC05AB5D14A404CA7751BD4A84640DB6B41EF8DD34A402194F77134AD4640DB6B41EF8DD34A402194F77134AD4640F73FC05AB5D14A404CA7751BD4A84640F73FC05AB5D14A40
54207	27695	45.203980000000001	45.229599999999998	53.564439	53.552956000000002	Титова	0103000020E61000000100000005000000E08442041C9A464041102043C7C64A40E08442041C9A464021CB82893FC84A40AF946588639D464021CB82893FC84A40AF946588639D464041102043C7C64A40E08442041C9A464041102043C7C64A40
53694	56444	45.086480000000002	45.269862000000003	53.829419999999999	53.624625000000002	Школьная	0103000020E6100000010000000500000009E1D1C6118B4640CBA145B6F3CF4A4009E1D1C6118B4640FC523F6F2AEA4A40723788D68AA24640FC523F6F2AEA4A40723788D68AA24640CBA145B6F3CF4A4009E1D1C6118B4640CBA145B6F3CF4A40
53992	27777	45.434621999999997	45.480822000000003	53.821443000000002	53.805117000000003	Бобровская	0103000020E61000000100000005000000A10F96B1A1B74640113AE8120EE74A40A10F96B1A1B746409A43520B25E94A40429946938BBD46409A43520B25E94A40429946938BBD4640113AE8120EE74A40A10F96B1A1B74640113AE8120EE74A40
53936	19285	45.121352999999999	45.141682000000003	53.784683000000001	53.776031000000003	Черокманова	0103000020E61000000100000005000000C022BF7E888F464052D7DAFB54E34A40C022BF7E888F4640145D177E70E44A404837C2A222924640145D177E70E44A404837C2A22292464052D7DAFB54E34A40C022BF7E888F464052D7DAFB54E34A40
53662	28235	45.239643000000001	45.269511999999999	53.611998	53.593981999999997	Свердлова	0103000020E6100000010000000500000090DB2F9FAC9E4640D234289A07CC4A4090DB2F9FAC9E4640D49B51F355CE4A4095F0845E7FA24640D49B51F355CE4A4095F0845E7FA24640D234289A07CC4A4090DB2F9FAC9E4640D234289A07CC4A40
53341	45614	45.182726000000002	45.247826000000003	53.606859	53.557550999999997	Юбилейная	0103000020E610000001000000050000008010C99063974640116DC7D45DC74A408010C990639746404224438EADCD4A409C8C2AC3B89F46404224438EADCD4A409C8C2AC3B89F4640116DC7D45DC74A408010C99063974640116DC7D45DC74A40
53477	45614	45.182726000000002	45.247826000000003	53.606859	53.557550999999997	Советская	0103000020E610000001000000050000008010C99063974640116DC7D45DC74A408010C990639746404224438EADCD4A409C8C2AC3B89F46404224438EADCD4A409C8C2AC3B89F4640116DC7D45DC74A408010C99063974640116DC7D45DC74A40
53384	45614	45.182726000000002	45.247826000000003	53.606859	53.557550999999997	Мясникова	0103000020E610000001000000050000008010C99063974640116DC7D45DC74A408010C990639746404224438EADCD4A409C8C2AC3B89F46404224438EADCD4A409C8C2AC3B89F4640116DC7D45DC74A408010C99063974640116DC7D45DC74A40
53333	45614	45.182726000000002	45.247826000000003	53.606859	53.557550999999997	Мичурина	0103000020E610000001000000050000008010C99063974640116DC7D45DC74A408010C990639746404224438EADCD4A409C8C2AC3B89F46404224438EADCD4A409C8C2AC3B89F4640116DC7D45DC74A408010C99063974640116DC7D45DC74A40
54272	45614	45.182726000000002	45.247826000000003	53.606859	53.557550999999997	Максима Горького	0103000020E610000001000000050000008010C99063974640116DC7D45DC74A408010C990639746404224438EADCD4A409C8C2AC3B89F46404224438EADCD4A409C8C2AC3B89F4640116DC7D45DC74A408010C99063974640116DC7D45DC74A40
53361	45614	45.182726000000002	45.247826000000003	53.606859	53.557550999999997	Ломоносова	0103000020E610000001000000050000008010C99063974640116DC7D45DC74A408010C990639746404224438EADCD4A409C8C2AC3B89F46404224438EADCD4A409C8C2AC3B89F4640116DC7D45DC74A408010C99063974640116DC7D45DC74A40
53660	56440	45.356343000000003	45.397224999999999	53.709775	53.686931999999999	Школьная	0103000020E610000001000000050000004B94BDA59CAD4640B6494563EDD74A404B94BDA59CAD46405B423EE8D9DA4A40A913D044D8B246405B423EE8D9DA4A40A913D044D8B24640B6494563EDD74A404B94BDA59CAD4640B6494563EDD74A40
54117	32668	45.043514000000002	45.073086000000004	53.671967000000002	53.653266000000002	Звездная	0103000020E610000001000000050000008675E3DD918546405CCB64389ED34A408675E3DD91854640E17EC00303D64A40D2E5CDE15A894640E17EC00303D64A40D2E5CDE15A8946405CCB64389ED34A408675E3DD918546405CCB64389ED34A40
53659	27831	45.457152000000001	45.500872999999999	53.783188000000003	53.765754999999999	 Большая дорога	0103000020E6100000010000000500000087A6ECF483BA4640CEDF844204E24A4087A6ECF483BA4640514F1F813FE44A408639419B1CC04640514F1F813FE44A408639419B1CC04640CEDF844204E24A4087A6ECF483BA4640CEDF844204E24A40
54033	56481	44.879095	45.677697000000002	53.926175999999998	53.384799999999998	Колхозная	0103000020E61000000100000005000000DF89592F867046401AC05B2041B14A40DF89592F86704640882B67EF8CF64A4075CC79C6BED64640882B67EF8CF64A4075CC79C6BED646401AC05B2041B14A40DF89592F867046401AC05B2041B14A40
54192	19083	45.403171999999998	45.445338999999997	53.757829999999998	53.737164999999997	Школьная	0103000020E61000000100000005000000DA54DD239BB34640BF60376C5BDE4A40DA54DD239BB34640BEF6CC9200E14A4011514CDE00B94640BEF6CC9200E14A4011514CDE00B94640BF60376C5BDE4A40DA54DD239BB34640BF60376C5BDE4A40
54284	33050	45.312182	45.335098000000002	53.542197000000002	53.528908999999999	 Заводская	0103000020E610000001000000050000002F336C94F5A74640B0C7444AB3C34A402F336C94F5A74640A27E17B666C54A403E7AC37DE4AA4640A27E17B666C54A403E7AC37DE4AA4640B0C7444AB3C34A402F336C94F5A74640B0C7444AB3C34A40
53661	28050	45.289095000000003	45.312047	53.572893999999998	53.550452	Юбилейная	0103000020E61000000100000005000000F437A11001A5464047020D3675C64A40F437A11001A546408D09319754C94A404FE8F527F1A746408D09319754C94A404FE8F527F1A7464047020D3675C64A40F437A11001A5464047020D3675C64A40
53879	32556	45.196424999999998	45.229841999999998	53.531381000000003	53.509276999999997	Сельская площадь	0103000020E61000000100000005000000F38E53742499464070CD1DFD2FC14A40F38E5374249946409F5BE84A04C44A40A59F70766B9D46409F5BE84A04C44A40A59F70766B9D464070CD1DFD2FC14A40F38E53742499464070CD1DFD2FC14A40
54209	27868	45.310079999999999	45.350872000000003	53.8705	53.860990999999999	Центральная	0103000020E61000000100000005000000649291B3B0A746403E93FDF334EE4A40649291B3B0A746408195438B6CEF4A40838AAA5FE9AC46408195438B6CEF4A40838AAA5FE9AC46403E93FDF334EE4A40649291B3B0A746403E93FDF334EE4A40
53408	27763	45.466529999999999	45.524543000000001	53.833337	53.788412000000001	Базарная	0103000020E610000001000000050000002B4D4A41B7BB464011E335AFEAE44A402B4D4A41B7BB4640FCC56CC9AAEA4A40412C9B3924C34640FCC56CC9AAEA4A40412C9B3924C3464011E335AFEAE44A402B4D4A41B7BB464011E335AFEAE44A40
53658	33130	44.946837000000002	44.973776999999998	53.596423999999999	53.589097000000002	Муханова	0103000020E6100000010000000500000046D26EF431794640FB95CE8767CB4A4046D26EF4317946405646239F57CC4A406A4C88B9A47C46405646239F57CC4A406A4C88B9A47C4640FB95CE8767CB4A4046D26EF431794640FB95CE8767CB4A40
53880	27539	45.751009000000003	45.776466999999997	52.655377000000001	52.638871000000002	Молодежная	0103000020E6100000010000000500000037001B1021E0464071AE6186C6514A4037001B1021E046407AC6BE64E3534A402CB6494563E346407AC6BE64E3534A402CB6494563E3464071AE6186C6514A4037001B1021E0464071AE6186C6514A40
53883	33120	45.907361000000002	45.923305999999997	52.508119999999998	52.496619000000003	Центральная	0103000020E610000001000000050000003B55BE6724F446403FC91D36913F4A403B55BE6724F44640C5387F130A414A40AC1919E42EF64640C5387F130A414A40AC1919E42EF646403FC91D36913F4A403B55BE6724F446403FC91D36913F4A40
53696	27364	45.902428999999998	45.928829999999998	52.655869000000003	52.635953000000001	Верхняя	0103000020E6100000010000000500000022FB20CB82F3464084656CE866514A4022FB20CB82F34640E9BAF083F3534A4097C5C4E6E3F64640E9BAF083F3534A4097C5C4E6E3F6464084656CE866514A4022FB20CB82F3464084656CE866514A40
53620	27464	45.808033999999999	45.832512999999999	52.478023	52.462387999999997	Центральная	0103000020E610000001000000050000002D077AA86DE746400B08AD872F3B4A402D077AA86DE746402FDE8FDB2F3D4A40573F36C98FEA46402FDE8FDB2F3D4A40573F36C98FEA46400B08AD872F3B4A402D077AA86DE746400B08AD872F3B4A40
53736	27393	45.761015999999998	45.794676000000003	52.541932000000003	52.526510999999999	Центральная	0103000020E61000000100000005000000CADDE7F868E14640FCFD62B664434A40CADDE7F868E14640F4531C075E454A40437573F1B7E54640F4531C075E454A40437573F1B7E54640FCFD62B664434A40CADDE7F868E14640FCFD62B664434A40
53836	56459	45.480561999999999	45.501725999999998	52.437745	52.421562999999999	Центральная	0103000020E61000000100000005000000A5D93C0E83BD4640111AC1C6F5354A40A5D93C0E83BD4640677E350708384A40C5C6BC8E38C04640677E350708384A40C5C6BC8E38C04640111AC1C6F5354A40A5D93C0E83BD4640111AC1C6F5354A40
53876	27244	45.854081000000001	45.887067999999999	52.706189000000002	52.670096999999998	Центральная	0103000020E610000001000000050000004791B58652ED4640E8120EBDC5554A404791B58652ED4640C1E5B166645A4A4000AAB8718BF14640C1E5B166645A4A4000AAB8718BF14640E8120EBDC5554A404791B58652ED4640E8120EBDC5554A40
54667	56552	45.273761	46.182496999999998	52.770297999999997	52.385739999999998	Песчаная	0103000020E61000000100000005000000CBF5B6990AA346402861A6ED5F314A40CBF5B6990AA346404C16F71F99624A401E4FCB0F5C1747404C16F71F99624A401E4FCB0F5C1747402861A6ED5F314A40CBF5B6990AA346402861A6ED5F314A40
53994	33087	45.414931000000003	45.440821	52.495384999999999	52.479756999999999	Школьная	0103000020E610000001000000050000005D8C81751CB54640778368AD683D4A405D8C81751CB54640E8F692C6683F4A40EC3191D26CB84640E8F692C6683F4A40EC3191D26CB84640778368AD683D4A405D8C81751CB54640778368AD683D4A40
53951	56471	45.833779999999997	45.857657000000003	52.606496	52.592258000000001	 Колхозная	0103000020E610000001000000050000008907944DB9EA4640AE65321CCF4B4A408907944DB9EA4640D19332A9A14D4A40BE175FB4C7ED4640D19332A9A14D4A40BE175FB4C7ED4640AE65321CCF4B4A408907944DB9EA4640AE65321CCF4B4A40
54206	27103	45.677976000000001	45.705751999999997	52.706893000000001	52.691526000000003	Центральная	0103000020E6100000010000000500000088BCE5EAC7D64640B72A89EC83584A4088BCE5EAC7D64640BB6246787B5A4A40158BDF1456DA4640BB6246787B5A4A40158BDF1456DA4640B72A89EC83584A4088BCE5EAC7D64640B72A89EC83584A40
53991	33059	45.481676	45.503801000000003	52.593938000000001	52.584297999999997	Мостовая	0103000020E6100000010000000500000051A2258FA7BD4640218FE046CA4A4A4051A2258FA7BD464003ED0E29064C4A409758198D7CC0464003ED0E29064C4A409758198D7CC04640218FE046CA4A4A4051A2258FA7BD4640218FE046CA4A4A40
54204	26973	45.998494999999998	46.031525999999999	52.583362000000001	52.572231000000002	Центральная	0103000020E61000000100000005000000191C25AFCEFF4640F2608BDD3E494A40191C25AFCEFF464055DD239BAB4A4A40A27C410B0904474055DD239BAB4A4A40A27C410B09044740F2608BDD3E494A40191C25AFCEFF4640F2608BDD3E494A40
54099	26831	45.579422000000001	45.608626000000001	52.624425000000002	52.612577000000002	Центральная	0103000020E610000001000000050000009D4A06802ACA464012A452EC684E4A409D4A06802ACA464004E78C28ED4F4A4066BFEE74E7CD464004E78C28ED4F4A4066BFEE74E7CD464012A452EC684E4A409D4A06802ACA464012A452EC684E4A40
54203	33046	45.960433000000002	45.983438999999997	52.488515	52.475259000000001	Школьная	0103000020E61000000100000005000000E57FF277EFFA464099107349D53C4A40E57FF277EFFA46407F4DD6A8873E4A40334E4354E1FD46407F4DD6A8873E4A40334E4354E1FD464099107349D53C4A40E57FF277EFFA464099107349D53C4A40
53619	56433	45.345526999999997	45.399687	52.561497000000003	52.518006999999997	Школьная	0103000020E6100000010000000500000047718E3A3AAC4640AE0CAA0D4E424A4047718E3A3AAC4640ACE63922DF474A4074D190F128B34640ACE63922DF474A4074D190F128B34640AE0CAA0D4E424A4047718E3A3AAC4640AE0CAA0D4E424A40
54100	26641	45.874724999999998	45.908878999999999	52.553870000000003	52.52919	Центральная	0103000020E610000001000000050000002EFF21FDF6EF464064AF777FBC434A402EFF21FDF6EF4640261E5036E5464A40B682A62556F44640261E5036E5464A40B682A62556F4464064AF777FBC434A402EFF21FDF6EF464064AF777FBC434A40
54021	33030	45.675299000000003	45.692743999999998	52.627862999999998	52.618543000000003	Советская	0103000020E61000000100000005000000C102983270D64640BA15C26A2C4F4A40C102983270D6464029AF95D05D504A400740DCD5ABD8464029AF95D05D504A400740DCD5ABD84640BA15C26A2C4F4A40C102983270D64640BA15C26A2C4F4A40
54281	56519	45.273761	46.182496999999998	52.770297999999997	52.385739999999998	Центральная	0103000020E61000000100000005000000CBF5B6990AA346402861A6ED5F314A40CBF5B6990AA346404C16F71F99624A401E4FCB0F5C1747404C16F71F99624A401E4FCB0F5C1747402861A6ED5F314A40CBF5B6990AA346402861A6ED5F314A40
53973	26560	45.535350000000001	45.565128999999999	52.558512999999998	52.535500999999996	Центральная	0103000020E61000000100000005000000F1F44A5986C44640D6FCF84B8B444A40F1F44A5986C4464007B29E5A7D474A40B682A62556C8464007B29E5A7D474A40B682A62556C84640D6FCF84B8B444A40F1F44A5986C44640D6FCF84B8B444A40
54202	26447	45.656820000000003	45.671903	52.745316000000003	52.727519000000001	Центральная	0103000020E61000000100000005000000EBAD81AD12D44640FC1BB4571F5D4A40EBAD81AD12D44640C097C283665F4A40CA8AE1EA00D64640C097C283665F4A40CA8AE1EA00D64640FC1BB4571F5D4A40EBAD81AD12D44640FC1BB4571F5D4A40
54201	33025	45.597405999999999	45.625433000000001	52.624228000000002	52.611843999999998	Мирная	0103000020E610000001000000050000009337C0CC77CC46407D2079E7504E4A409337C0CC77CC4640AE9FFEB3E64F4A406A6B44300ED04640AE9FFEB3E64F4A406A6B44300ED046407D2079E7504E4A409337C0CC77CC46407D2079E7504E4A40
53988	26351	45.708571999999997	45.724491	52.472692000000002	52.462822000000003	Садовая	0103000020E610000001000000050000003F6EBF7CB2DA464046EF54C03D3B4A403F6EBF7CB2DA4640598AE42B813C4A40889FFF1EBCDC4640598AE42B813C4A40889FFF1EBCDC464046EF54C03D3B4A403F6EBF7CB2DA464046EF54C03D3B4A40
54097	33007	45.868786999999998	45.890248	52.443492999999997	52.428382999999997	Молодежная	0103000020E610000001000000050000005018946934EF4640C8940F41D5364A405018946934EF4640A180ED60C4384A402AAA7EA5F3F14640A180ED60C4384A402AAA7EA5F3F14640C8940F41D5364A405018946934EF4640C8940F41D5364A40
54734	56563	46.124294999999996	46.973579999999998	53.408644000000002	52.848199000000001	Школьная	0103000020E61000000100000005000000350708E6E80F4740FDBFEAC8916C4A40350708E6E80F474073DA53724EB44A401405FA449E7C474073DA53724EB44A401405FA449E7C4740FDBFEAC8916C4A40350708E6E80F4740FDBFEAC8916C4A40
53382	25884	46.646602000000001	46.66986	53.045561999999997	53.033368000000003	Заводская	0103000020E610000001000000050000009CC3B5DAC3524740D15D126745844A409CC3B5DAC35247405DF8C1F9D4854A400473F4F8BD5547405DF8C1F9D4854A400473F4F8BD554740D15D126745844A409CC3B5DAC3524740D15D126745844A40
53747	24603	46.799100000000003	46.814712999999998	53.282637999999999	53.259466000000003	Сурская	0103000020E61000000100000005000000E71DA7E8486647404436902E36A14A40E71DA7E848664740AD4D637B2DA44A402250FD8348684740AD4D637B2DA44A402250FD83486847404436902E36A14A40E71DA7E8486647404436902E36A14A40
53972	24399	46.642865	46.653061000000001	53.267685	53.243966	Центральная	0103000020E610000001000000050000001C5F7B664952474000AB23473A9F4A401C5F7B66495247409C50888043A24A4083A5BA80975347409C50888043A24A4083A5BA809753474000AB23473A9F4A401C5F7B664952474000AB23473A9F4A40
53655	25471	46.607391	46.642541999999999	52.992789999999999	52.968012000000002	Сидорова	0103000020E610000001000000050000003F7100FDBE4D47405A1135D1E77B4A403F7100FDBE4D4740DEE522BE137F4A403927F6D03E524740DEE522BE137F4A403927F6D03E5247405A1135D1E77B4A403F7100FDBE4D47405A1135D1E77B4A40
53982	19980	46.721952999999999	46.772339000000002	53.364390999999998	53.349564000000001	Часовская	0103000020E61000000100000005000000E21FB6F4685C4740F2ED5D83BEAC4A40E21FB6F4685C474076FA415DA4AE4A4072361D01DC62474076FA415DA4AE4A4072361D01DC624740F2ED5D83BEAC4A40E21FB6F4685C4740F2ED5D83BEAC4A40
54199	25402	46.351640000000003	46.374547	52.992134	52.977187000000001	Блохина	0103000020E6100000010000000500000094FB1D8A022D4740C689AF76147D4A4094FB1D8A022D4740F59F353FFE7E4A404FE8F527F12F4740F59F353FFE7E4A404FE8F527F12F4740C689AF76147D4A4094FB1D8A022D4740C689AF76147D4A40
53980	20128	46.737924999999997	46.749316	53.276113000000002	53.267679999999999	Центральная	0103000020E610000001000000050000004DF38E53745E47408AE5965643A24A404DF38E53745E47400F80B8AB57A34A404D2F3196E95F47400F80B8AB57A34A404D2F3196E95F47408AE5965643A24A404DF38E53745E47408AE5965643A24A40
53471	26123	46.910077999999999	46.941392999999998	53.101162000000002	53.090741999999999	Школьная	0103000020E610000001000000050000009067976F7D744740D32F116F9D8B4A409067976F7D7447408ACC5CE0F28C4A4077D7D9907F7847408ACC5CE0F28C4A4077D7D9907F784740D32F116F9D8B4A409067976F7D744740D32F116F9D8B4A40
53944	25573	46.367666	46.388255999999998	53.238290999999997	53.212958999999998	Центральная	0103000020E61000000100000005000000F2ECF2AD0F2F4740C631923D429B4A40F2ECF2AD0F2F47402FF7C951809E4A40E63C635FB23147402FF7C951809E4A40E63C635FB2314740C631923D429B4A40F2ECF2AD0F2F4740C631923D429B4A40
53979	24979	46.367666	46.388255999999998	53.238290999999997	53.212958999999998	Центральная	0103000020E61000000100000005000000F2ECF2AD0F2F4740C631923D429B4A40F2ECF2AD0F2F47402FF7C951809E4A40E63C635FB23147402FF7C951809E4A40E63C635FB2314740C631923D429B4A40F2ECF2AD0F2F4740C631923D429B4A40
53859	25067	46.177700000000002	46.242925999999997	53.153401000000002	53.138429000000002	Московская	0103000020E61000000100000005000000E63FA4DFBE164740B4E89D0AB8914A40E63FA4DFBE1647403C16DBA4A2934A408EACFC32181F47403C16DBA4A2934A408EACFC32181F4740B4E89D0AB8914A40E63FA4DFBE164740B4E89D0AB8914A40
54261	25067	46.177700000000002	46.242925999999997	53.153401000000002	53.138429000000002	Зелёная	0103000020E61000000100000005000000E63FA4DFBE164740B4E89D0AB8914A40E63FA4DFBE1647403C16DBA4A2934A408EACFC32181F47403C16DBA4A2934A408EACFC32181F4740B4E89D0AB8914A40E63FA4DFBE164740B4E89D0AB8914A40
53657	25803	46.622599000000001	46.642569000000002	53.084960000000002	53.074001000000003	Зеленая	0103000020E61000000100000005000000DBC2F352B14F4740876F61DD78894A40DBC2F352B14F4740EDBB22F8DF8A4A40333674B33F524740EDBB22F8DF8A4A40333674B33F524740876F61DD78894A40DBC2F352B14F4740876F61DD78894A40
53733	19989	46.162697999999999	46.215519	53.086080000000003	53.065885000000002	Ленина	0103000020E61000000100000005000000F38FBE49D3144740032670EB6E884A40F38FBE49D31447407B6B60AB048B4A4054556820961B47407B6B60AB048B4A4054556820961B4740032670EB6E884A40F38FBE49D3144740032670EB6E884A40
53873	25985	46.800007000000001	46.812798999999998	52.989201000000001	52.977333000000002	Совхозная	0103000020E6100000010000000500000019C91EA1666647409A266C3F197D4A4019C91EA166664740D3156C239E7E4A405A9C31CC09684740D3156C239E7E4A405A9C31CC096847409A266C3F197D4A4019C91EA1666647409A266C3F197D4A40
53286	25448	46.405728000000003	46.460884	53.060625000000002	53.031689999999998	Центральная	0103000020E61000000100000005000000278925E5EE3347401CCEFC6A0E844A40278925E5EE334740F6285C8FC2874A40F59F353FFE3A4740F6285C8FC2874A40F59F353FFE3A47401CCEFC6A0E844A40278925E5EE3347401CCEFC6A0E844A40
53326	24780	46.461109	46.529246000000001	53.143664000000001	53.126764999999999	Советская	0103000020E610000001000000050000001572A59E053B474083A3E4D539904A401572A59E053B474068CEFA9463924A40F8C43A55BE43474068CEFA9463924A40F8C43A55BE43474083A3E4D539904A401572A59E053B474083A3E4D539904A40
53324	24780	46.461109	46.529246000000001	53.143664000000001	53.126764999999999	Ново-Зеленая	0103000020E610000001000000050000001572A59E053B474083A3E4D539904A401572A59E053B474068CEFA9463924A40F8C43A55BE43474068CEFA9463924A40F8C43A55BE43474083A3E4D539904A401572A59E053B474083A3E4D539904A40
53329	25621	46.579524999999997	46.617711999999997	53.044733000000001	53.020679000000001	Заводская	0103000020E61000000100000005000000711B0DE02D4A4740645B069CA5824A40711B0DE02D4A4740A7069ACFB9854A40622CD32F114F4740A7069ACFB9854A40622CD32F114F4740645B069CA5824A40711B0DE02D4A4740645B069CA5824A40
53289	24858	46.376434000000003	46.461692999999997	53.182616000000003	53.145457	им.Терехина М.А	0103000020E610000001000000050000001E8D43FD2E304740B5FCC0559E924A401E8D43FD2E304740F9DC09F65F974A4064E597C1183B4740F9DC09F65F974A4064E597C1183B4740B5FCC0559E924A401E8D43FD2E304740B5FCC0559E924A40
53970	25321	46.311476999999996	46.337392999999999	52.968445000000003	52.957337000000003	Садовая	0103000020E61000000100000005000000643A747ADE2747401920D1048A7A4A40643A747ADE274740C47C7901F67B4A401D739EB12F2B4740C47C7901F67B4A401D739EB12F2B47401920D1048A7A4A40643A747ADE2747401920D1048A7A4A40
54247	14770	46.733801999999997	46.777234999999997	53.284225999999997	53.274481000000002	 Школьная	0103000020E61000000100000005000000A4DE5339ED5D4740CB2F833122A34A40A4DE5339ED5D474021567F8461A44A403D27BD6F7C63474021567F8461A44A403D27BD6F7C634740CB2F833122A34A40A4DE5339ED5D4740CB2F833122A34A40
53695	26086	46.856251	46.876759999999997	53.088437999999996	53.073524999999997	Больничная	0103000020E610000001000000050000006A15FDA1996D47401D38674469894A406A15FDA1996D4740A0DCB6EF518B4A407138F3AB39704740A0DCB6EF518B4A407138F3AB397047401D38674469894A406A15FDA1996D47401D38674469894A40
53734	25891	46.70449	46.731546999999999	52.994436999999998	52.976612000000003	Молодежная	0103000020E61000000100000005000000F52D73BA2C5A4740CA703C9F017D4A40F52D73BA2C5A474057772CB6497F4A40533E0455A35D474057772CB6497F4A40533E0455A35D4740CA703C9F017D4A40F52D73BA2C5A4740CA703C9F017D4A40
53976	24556	46.711362000000001	46.734636999999999	53.172491000000001	53.160431000000003	Графская	0103000020E61000000100000005000000FFCEF6E80D5B4740DE21C50089944A40FFCEF6E80D5B47405BED612F14964A403DB7D095085E47405BED612F14964A403DB7D095085E4740DE21C50089944A40FFCEF6E80D5B4740DE21C50089944A40
53875	25726	46.501156000000002	46.519660999999999	53.095506	53.07808	Озерная	0103000020E61000000100000005000000DB183BE125404740603C8386FE894A40DB183BE1254047403049658A398C4A40DA006C40844247403049658A398C4A40DA006C4084424740603C8386FE894A40DB183BE125404740603C8386FE894A40
54096	24494	46.774774000000001	46.789802999999999	53.231118000000002	53.214232000000003	Школьный переулок	0103000020E6100000010000000500000043E55FCB2B634740DBE044F46B9B4A4043E55FCB2B6347402BC24D46959D4A402FA4C343186547402BC24D46959D4A402FA4C34318654740DBE044F46B9B4A4043E55FCB2B634740DBE044F46B9B4A40
53985	25790	46.663094999999998	46.672617000000002	53.062806000000002	53.055439999999997	Центральная	0103000020E610000001000000050000001092054CE0544740F3716DA818874A401092054CE05447400DFFE9060A884A40E8DD5850185647400DFFE9060A884A40E8DD585018564740F3716DA818874A401092054CE0544740F3716DA818874A40
53303	20101	46.813158999999999	46.850178	53.123522999999999	53.099853000000003	Центральный переулок	0103000020E610000001000000050000005AB917981568474029B4ACFBC78C4A405AB9179815684740E3A6069ACF8F4A40ACE3F8A1D26C4740E3A6069ACF8F4A40ACE3F8A1D26C474029B4ACFBC78C4A405AB917981568474029B4ACFBC78C4A40
53473	20101	46.813158999999999	46.850178	53.123522999999999	53.099853000000003	Центральная	0103000020E610000001000000050000005AB917981568474029B4ACFBC78C4A405AB9179815684740E3A6069ACF8F4A40ACE3F8A1D26C4740E3A6069ACF8F4A40ACE3F8A1D26C474029B4ACFBC78C4A405AB917981568474029B4ACFBC78C4A40
54205	25972	46.623775999999999	46.631276999999997	53.282454999999999	53.278143	Дорожная	0103000020E61000000100000005000000CD0358E4D74F4740404E98309AA34A40CD0358E4D74F4740BCCB457C27A44A40C6DB4AAFCD504740BCCB457C27A44A40C6DB4AAFCD504740404E98309AA34A40CD0358E4D74F4740404E98309AA34A40
53380	25210	46.353912999999999	46.376846999999998	52.920959000000003	52.905330999999997	Проспект Победы	0103000020E610000001000000050000008B506C054D2D47400987DEE2E1734A408B506C054D2D47407BFA08FCE1754A40404CC2853C3047407BFA08FCE1754A40404CC2853C3047400987DEE2E1734A408B506C054D2D47400987DEE2E1734A40
53290	26050	46.875312999999998	46.910896000000001	53.097679999999997	53.082082999999997	Прудная	0103000020E61000000100000005000000BF61A2410A7047405E471CB2818A4A40BF61A2410A70474094BC3AC7808C4A405307793D9874474094BC3AC7808C4A405307793D987447405E471CB2818A4A40BF61A2410A7047405E471CB2818A4A40
53856	24695	46.406491000000003	46.433666000000002	53.104832999999999	53.094765000000002	Центральная	0103000020E61000000100000005000000268FA7E50734474019E76F42218C4A40268FA7E5073447405245F12A6B8D4A408EB1135E823747405245F12A6B8D4A408EB1135E8237474019E76F42218C4A40268FA7E50734474019E76F42218C4A40
53497	24906	46.298954000000002	46.332749	53.194356999999997	53.183933000000003	Центральная	0103000020E610000001000000050000001381EA1F44264740DDD3D51D8B974A401381EA1F44264740D45FAFB0E0984A406B63EC84972A4740D45FAFB0E0984A406B63EC84972A4740DDD3D51D8B974A401381EA1F44264740DDD3D51D8B974A40
53407	25296	46.360191999999998	46.408414	53.037083000000003	52.997895	Юбилейная	0103000020E61000000100000005000000F2237EC51A2E4740C4EBFA05BB7F4A40F2237EC51A2E4740691EC022BF844A40419DF2E846344740691EC022BF844A40419DF2E846344740C4EBFA05BB7F4A40F2237EC51A2E4740C4EBFA05BB7F4A40
53874	25666	46.546503000000001	46.562313000000003	53.078046999999998	53.066009999999999	Школьная	0103000020E610000001000000050000003C1570CFF3454740BF9A030473884A403C1570CFF34547408446B071FD894A40CE8E54DFF94747408446B071FD894A40CE8E54DFF9474740BF9A030473884A403C1570CFF3454740BF9A030473884A40
54136	9760	44.744850999999997	44.764712000000003	52.923445999999998	52.914622999999999	Центральная	0103000020E610000001000000050000004AB20E47575F4640AF95D05D12754A404AB20E47575F46409ECF807A33764A40EC6D3315E26146409ECF807A33764A40EC6D3315E2614640AF95D05D12754A404AB20E47575F4640AF95D05D12754A40
54216	56505	44.880352999999999	44.89584	52.888914	52.877524000000001	 Вольновка	0103000020E61000000100000005000000BEF73768AF70464041BAD8B452704A40BEF73768AF704640707A17EFC7714A406D3997E2AA724640707A17EFC7714A406D3997E2AA72464041BAD8B452704A40BEF73768AF70464041BAD8B452704A40
53910	10432	44.822456000000003	44.852262000000003	52.772444999999998	52.753945000000002	Совхозная	0103000020E610000001000000050000001233FB3C46694640CAFD0E4581604A401233FB3C46694640B77A4E7ADF624A40D1CFD4EB166D4640B77A4E7ADF624A40D1CFD4EB166D4640CAFD0E4581604A401233FB3C46694640CAFD0E4581604A40
54058	10493	44.7074	44.919699000000001	52.889012000000001	52.734819999999999	Даманская	0103000020E610000001000000050000005F984C158C5A46402E39EE940E5E4A405F984C158C5A464033E02C25CB714A40FB9463B2B875464033E02C25CB714A40FB9463B2B87546402E39EE940E5E4A405F984C158C5A46402E39EE940E5E4A40
53365	9370	45.019376000000001	45.070642999999997	52.842972000000003	52.805720000000001	Южная	0103000020E61000000100000005000000E529ABE97A824640D7DD3CD521674A40E529ABE97A824640CCB8A981E66B4A407D586FD40A894640CCB8A981E66B4A407D586FD40A894640D7DD3CD521674A40E529ABE97A824640D7DD3CD521674A40
54134	9370	45.019376000000001	45.070642999999997	52.842972000000003	52.805720000000001	Совхозная	0103000020E61000000100000005000000E529ABE97A824640D7DD3CD521674A40E529ABE97A824640CCB8A981E66B4A407D586FD40A894640CCB8A981E66B4A407D586FD40A894640D7DD3CD521674A40E529ABE97A824640D7DD3CD521674A40
53301	9370	45.019376000000001	45.070642999999997	52.842972000000003	52.805720000000001	Осипова	0103000020E61000000100000005000000E529ABE97A824640D7DD3CD521674A40E529ABE97A824640CCB8A981E66B4A407D586FD40A894640CCB8A981E66B4A407D586FD40A894640D7DD3CD521674A40E529ABE97A824640D7DD3CD521674A40
54137	9566	44.998480999999998	45.051931000000003	52.762614999999997	52.752571000000003	Луговая	0103000020E61000000100000005000000B456B439CE7F464082751C3F54604A40B456B439CE7F464032384A5E9D614A400553CDACA586464032384A5E9D614A400553CDACA586464082751C3F54604A40B456B439CE7F464082751C3F54604A40
53685	56442	44.925358000000003	44.960985000000001	52.911380999999999	52.886589000000001	Центральная	0103000020E61000000100000005000000C68B85217276464026FF93BF7B714A40C68B8521727646400F99F221A8744A402979758E017B46400F99F221A8744A402979758E017B464026FF93BF7B714A40C68B85217276464026FF93BF7B714A40
54140	10592	44.812772000000002	44.829121999999998	52.821362000000001	52.803749000000003	Молодежная	0103000020E61000000100000005000000618DB3E908684640AB984A3FE1664A40618DB3E908684640AD16D86322694A40723271AB206A4640AD16D86322694A40723271AB206A4640AB984A3FE1664A40618DB3E908684640AB984A3FE1664A40
54237	9588	45.188681000000003	45.224093000000003	52.768968999999998	52.732638999999999	Центральная	0103000020E610000001000000050000003430F2B2269846401763601DC75D4A403430F2B226984640A45181936D624A409B215514AF9C4640A45181936D624A409B215514AF9C46401763601DC75D4A403430F2B2269846401763601DC75D4A40
54049	8721	45.116906	45.131746	52.716625999999998	52.701169	Дорожная	0103000020E61000000100000005000000645A9BC6F68E464009FCE1E7BF594A40645A9BC6F68E46404DBB9866BA5B4A407DB08C0DDD9046404DBB9866BA5B4A407DB08C0DDD90464009FCE1E7BF594A40645A9BC6F68E464009FCE1E7BF594A40
53678	8674	45.178925999999997	45.221865000000001	52.711815000000001	52.670124000000001	Школьная	0103000020E61000000100000005000000B933130CE7964640E2218C9FC6554A40B933130CE7964640B0E600C11C5B4A4043908312669C4640B0E600C11C5B4A4043908312669C4640E2218C9FC6554A40B933130CE7964640E2218C9FC6554A40
54084	46905	44.828403000000002	44.859476000000001	52.733767999999998	52.718480999999997	Кошелевского	0103000020E610000001000000050000004374081C096A464010E6762FF75B4A404374081C096A4640F86C1D1CEC5D4A4034D93F4F036E4640F86C1D1CEC5D4A4034D93F4F036E464010E6762FF75B4A404374081C096A464010E6762FF75B4A40
53690	32646	44.487060999999997	44.505763999999999	52.866191000000001	52.851989000000003	Центральная	0103000020E610000001000000050000001A14CD03583E4640A0C6BDF90D6D4A401A14CD03583E4640768BC058DF6E4A4040BFEFDFBC404640768BC058DF6E4A4040BFEFDFBC404640A0C6BDF90D6D4A401A14CD03583E4640A0C6BDF90D6D4A40
53820	56457	44.678483	44.702782999999997	52.771698000000001	52.759095000000002	Школьная	0103000020E610000001000000050000002CF2EB87D856464050C763062A614A402CF2EB87D8564640BE310400C7624A40A69718CBF4594640BE310400C7624A40A69718CBF459464050C763062A614A402CF2EB87D856464050C763062A614A40
54198	56502	44.653762	44.692973000000002	52.534356000000002	52.519875999999996	Школьная	0103000020E610000001000000050000000CAF2479AE534640D6FCF84B8B424A400CAF2479AE534640F03504C765444A406901DA56B3584640F03504C765444A406901DA56B3584640D6FCF84B8B424A400CAF2479AE534640D6FCF84B8B424A40
53953	32741	44.323855000000002	44.347625000000001	52.911734000000003	52.900948	Садовая	0103000020E61000000100000005000000B3D2A41474294640C4B2994352734A40B3D2A414742946405D5320B3B3744A40D122DBF97E2C46405D5320B3B3744A40D122DBF97E2C4640C4B2994352734A40B3D2A41474294640C4B2994352734A40
53735	32636	44.541741999999999	44.570298999999999	52.924939000000002	52.901224999999997	пер.Школьный	0103000020E61000000100000005000000506F46CD5745464036AB3E575B734A40506F46CD57454640C1E5B16664764A4083F8C08EFF484640C1E5B16664764A4083F8C08EFF48464036AB3E575B734A40506F46CD5745464036AB3E575B734A40
53731	23795	44.707875999999999	44.751983000000003	52.707112000000002	52.691110999999999	Центральная	0103000020E61000000100000005000000C8CF46AE9B5A4640F373435376584A40C8CF46AE9B5A4640F94D61A5825A4A40F1129CFA40604640F94D61A5825A4A40F1129CFA40604640F373435376584A40C8CF46AE9B5A4640F373435376584A40
53732	23714	44.398280999999997	44.412196000000002	52.738909999999997	52.730168999999997	Центральная	0103000020E6100000010000000500000020CF2EDFFA324640C9C6832D765D4A4020CF2EDFFA324640FB57569A945E4A4061C5A9D6C2344640FB57569A945E4A4061C5A9D6C2344640C9C6832D765D4A4020CF2EDFFA324640C9C6832D765D4A40
53978	23613	44.398218	44.421869999999998	52.674028	52.656556999999999	Центральная	0103000020E61000000100000005000000DA56B3CEF8324640DD7A4D0F0A544A40DA56B3CEF83246404D4BAC8C46564A40EE940ED6FF3546404D4BAC8C46564A40EE940ED6FF354640DD7A4D0F0A544A40DA56B3CEF8324640DD7A4D0F0A544A40
53316	23513	44.493330999999998	44.530476999999998	52.680635000000002	52.653180999999996	Пензенская	0103000020E610000001000000050000002E8D5F78253F46402DAF5C6F9B534A402E8D5F78253F4640A9C1340C1F574A40DD239BABE6434640A9C1340C1F574A40DD239BABE64346402DAF5C6F9B534A402E8D5F78253F46402DAF5C6F9B534A40
54152	15062	44.209060000000001	44.225408999999999	52.831705999999997	52.819664000000003	Новая	0103000020E610000001000000050000006D73637AC21A4640B2DAFCBFEA684A406D73637AC21A464088F19A57756A4A40AE9CBD33DA1C464088F19A57756A4A40AE9CBD33DA1C4640B2DAFCBFEA684A406D73637AC21A4640B2DAFCBFEA684A40
53383	48241	44.489891	44.540627999999998	52.576079	52.553618	Мало Садовая	0103000020E6100000010000000500000068CD8FBFB43E46400C3D62F4DC464A4068CD8FBFB43E4640C974E8F4BC494A40A4A65D4C33454640C974E8F4BC494A40A4A65D4C334546400C3D62F4DC464A4068CD8FBFB43E46400C3D62F4DC464A40
53320	24055	44.514622000000003	44.569355999999999	52.712622000000003	52.685924999999997	Терешкина	0103000020E61000000100000005000000ACE63922DF4146402041F163CC574A40ACE63922DF4146407F349C32375B4A4004E44BA8E04846407F349C32375B4A4004E44BA8E04846402041F163CC574A40ACE63922DF4146402041F163CC574A40
53379	24055	44.514622000000003	44.569355999999999	52.712622000000003	52.685924999999997	Строителей	0103000020E61000000100000005000000ACE63922DF4146402041F163CC574A40ACE63922DF4146407F349C32375B4A4004E44BA8E04846407F349C32375B4A4004E44BA8E04846402041F163CC574A40ACE63922DF4146402041F163CC574A40
53288	24055	44.514622000000003	44.569355999999999	52.712622000000003	52.685924999999997	Садовая	0103000020E61000000100000005000000ACE63922DF4146402041F163CC574A40ACE63922DF4146407F349C32375B4A4004E44BA8E04846407F349C32375B4A4004E44BA8E04846402041F163CC574A40ACE63922DF4146402041F163CC574A40
53474	24055	44.514622000000003	44.569355999999999	52.712622000000003	52.685924999999997	Пензенская	0103000020E61000000100000005000000ACE63922DF4146402041F163CC574A40ACE63922DF4146407F349C32375B4A4004E44BA8E04846407F349C32375B4A4004E44BA8E04846402041F163CC574A40ACE63922DF4146402041F163CC574A40
53265	24055	44.514622000000003	44.569355999999999	52.712622000000003	52.685924999999997	Остапенко	0103000020E61000000100000005000000ACE63922DF4146402041F163CC574A40ACE63922DF4146407F349C32375B4A4004E44BA8E04846407F349C32375B4A4004E44BA8E04846402041F163CC574A40ACE63922DF4146402041F163CC574A40
53692	23421	44.244219999999999	44.284868000000003	52.809367000000002	52.783284999999999	Советская	0103000020E61000000100000005000000BA83D899421F46404339D1AE42644A40BA83D899421F464017BB7D5699674A40A6D6FB8D7624464017BB7D5699674A40A6D6FB8D762446404339D1AE42644A40BA83D899421F46404339D1AE42644A40
54194	20591	44.752828000000001	44.756968999999998	52.643030000000003	52.637106000000003	Школьная	0103000020E61000000100000005000000ADC1FBAA5C604640EE0A7DB08C514A40ADC1FBAA5C604640672C9ACE4E524A40FC8A355CE4604640672C9ACE4E524A40FC8A355CE4604640EE0A7DB08C514A40ADC1FBAA5C604640EE0A7DB08C514A40
53899	56462	44.384149999999998	44.391551999999997	52.712693000000002	52.697557000000003	Петрова Слобода	0103000020E610000001000000050000001361C3D32B314640460C3B8C49594A401361C3D32B314640488B3386395B4A4079573D601E324640488B3386395B4A4079573D601E324640460C3B8C49594A401361C3D32B314640460C3B8C49594A40
54187	56499	44.533988999999998	44.541409000000002	52.873193000000001	52.863131000000003	Центральная	0103000020E610000001000000050000003DB665C059444640F7949C137B6E4A403DB665C0594446404E0CC9C9C46F4A404A61DEE34C4546404E0CC9C9C46F4A404A61DEE34C454640F7949C137B6E4A403DB665C059444640F7949C137B6E4A40
53819	33095	44.455835999999998	44.484788000000002	52.669927999999999	52.664073000000002	Центральная	0103000020E61000000100000005000000732B84D5583A46400C94145800554A40732B84D5583A46405C566133C0554A4023BF7E880D3E46405C566133C0554A4023BF7E880D3E46400C94145800554A40732B84D5583A46400C94145800554A40
53617	20580	45.892178999999999	45.924275999999999	52.765737999999999	52.733756999999997	Школьная	0103000020E61000000100000005000000C896E5EB32F24640041BD7BFEB5D4A40C896E5EB32F24640F8A6E9B303624A40253D0CAD4EF64640F8A6E9B303624A40253D0CAD4EF64640041BD7BFEB5D4A40C896E5EB32F24640041BD7BFEB5D4A40
53730	22718	46.341903000000002	46.383180000000003	52.774819999999998	52.756332	Лесная	0103000020E61000000100000005000000C0B33D7AC32B47408A75AA7CCF604A40C0B33D7AC32B4740B324404D2D634A409B3DD00A0C314740B324404D2D634A409B3DD00A0C3147408A75AA7CCF604A40C0B33D7AC32B47408A75AA7CCF604A40
53728	22718	46.341903000000002	46.383180000000003	52.774819999999998	52.756332	 Лесная	0103000020E61000000100000005000000C0B33D7AC32B47408A75AA7CCF604A40C0B33D7AC32B4740B324404D2D634A409B3DD00A0C314740B324404D2D634A409B3DD00A0C3147408A75AA7CCF604A40C0B33D7AC32B47408A75AA7CCF604A40
53729	23034	46.071931999999997	46.114736999999998	52.89564	52.835769999999997	Техническая	0103000020E6100000010000000500000097C45911350947402C7DE882FA6A4A4097C4591135094740A67EDE54A4724A401152B7B3AF0E4740A67EDE54A4724A401152B7B3AF0E47402C7DE882FA6A4A4097C45911350947402C7DE882FA6A4A40
53376	23034	46.071931999999997	46.114736999999998	52.89564	52.835769999999997	Радищева	0103000020E6100000010000000500000097C45911350947402C7DE882FA6A4A4097C4591135094740A67EDE54A4724A401152B7B3AF0E4740A67EDE54A4724A401152B7B3AF0E47402C7DE882FA6A4A4097C45911350947402C7DE882FA6A4A40
53651	23034	46.071931999999997	46.114736999999998	52.89564	52.835769999999997	Коммунальная	0103000020E6100000010000000500000097C45911350947402C7DE882FA6A4A4097C4591135094740A67EDE54A4724A401152B7B3AF0E4740A67EDE54A4724A401152B7B3AF0E47402C7DE882FA6A4A4097C45911350947402C7DE882FA6A4A40
53746	23034	46.071931999999997	46.114736999999998	52.89564	52.835769999999997	Кирова	0103000020E6100000010000000500000097C45911350947402C7DE882FA6A4A4097C4591135094740A67EDE54A4724A401152B7B3AF0E4740A67EDE54A4724A401152B7B3AF0E47402C7DE882FA6A4A4097C45911350947402C7DE882FA6A4A40
54188	20515	46.041443000000001	46.074869	52.665886	52.648536999999997	Центральная	0103000020E61000000100000005000000F6D214014E0547407B9FAA4203534A40F6D214014E054740A06EA0C03B554A40FB3DB14E95094740A06EA0C03B554A40FB3DB14E950947407B9FAA4203534A40F6D214014E0547407B9FAA4203534A40
53845	33135	46.130986999999998	46.159148999999999	52.764926000000003	52.752217000000002	Центральная	0103000020E61000000100000005000000BF99982EC4104740643F8BA548604A40BF99982EC410474018EE5C18E9614A40761893FE5E14474018EE5C18E9614A40761893FE5E144740643F8BA548604A40BF99982EC4104740643F8BA548604A40
53656	22691	46.207011999999999	46.257578000000002	52.921154999999999	52.903717999999998	Гагарина	0103000020E6100000010000000500000095F0845E7F1A47403C670B08AD734A4095F0845E7F1A474000C63368E8754A40A515DF50F820474000C63368E8754A40A515DF50F82047403C670B08AD734A4095F0845E7F1A47403C670B08AD734A40
53969	22413	46.133943000000002	46.157100999999997	52.959529000000003	52.939034999999997	Центральная	0103000020E610000001000000050000009A43520B251147405166834C32784A409A43520B251147402448A5D8D17A4A409E95B4E21B1447402448A5D8D17A4A409E95B4E21B1447405166834C32784A409A43520B251147405166834C32784A40
53949	56470	45.823493999999997	45.845771999999997	52.864103999999998	52.838217999999998	Школьный	0103000020E61000000100000005000000E2395B4068E94640927538BA4A6B4A40E2395B4068E94640E02BBAF59A6E4A40AEEFC34142EC4640E02BBAF59A6E4A40AEEFC34142EC4640927538BA4A6B4A40E2395B4068E94640927538BA4A6B4A40
53726	20786	45.970773000000001	46.013109999999998	52.852615	52.835047000000003	Центральная	0103000020E610000001000000050000007F6B274A42FC4640BCCFF1D1E26A4A407F6B274A42FC46401E8A027D226D4A4012A0A696AD0147401E8A027D226D4A4012A0A696AD014740BCCFF1D1E26A4A407F6B274A42FC4640BCCFF1D1E26A4A40
53967	18556	45.804512000000003	45.858294999999998	52.840155000000003	52.815795000000001	Молодежная	0103000020E61000000100000005000000AA9ECC3FFAE64640C39E76F86B684A40AA9ECC3FFAE646401349F4328A6B4A4000A94D9CDCED46401349F4328A6B4A4000A94D9CDCED4640C39E76F86B684A40AA9ECC3FFAE64640C39E76F86B684A40
53854	33127	46.345621999999999	46.366695999999997	52.726650999999997	52.715862000000001	Сухая	0103000020E61000000100000005000000996379573D2C47407E39B35DA15B4A40996379573D2C4740874D64E6025D4A4079C9FFE4EF2E4740874D64E6025D4A4079C9FFE4EF2E47407E39B35DA15B4A40996379573D2C47407E39B35DA15B4A40
53853	20336	46.073549	46.096465000000002	52.720433999999997	52.699936000000001	Сосновская	0103000020E61000000100000005000000A6D3BA0D6A09474083A5BA8097594A40A6D3BA0D6A09474096766A2E375C4A40B51A12F7580C474096766A2E375C4A40B51A12F7580C474083A5BA8097594A40A6D3BA0D6A09474083A5BA8097594A40
53722	14786	45.834831000000001	45.867466	52.958247999999998	52.927636999999997	Новая	0103000020E61000000100000005000000EF5701BEDBEA46409FC728CFBC764A40EF5701BEDBEA46408CBAD6DEA77A4A402B323A2009EF46408CBAD6DEA77A4A402B323A2009EF46409FC728CFBC764A40EF5701BEDBEA46409FC728CFBC764A40
53825	20684	46.069730999999997	46.098278999999998	52.937829999999998	52.928294000000001	Школьная	0103000020E61000000100000005000000394206F2EC08474059897956D2764A40394206F2EC084740959A3DD00A784A4019710168940C4740959A3DD00A784A4019710168940C474059897956D2764A40394206F2EC08474059897956D2764A40
54189	20451	46.176468999999997	46.210388999999999	52.630498000000003	52.609268999999998	Центральная	0103000020E6100000010000000500000000E1438996164740BABBCE86FC4D4A4000E1438996164740C2189128B4504A401538D906EE1A4740C2189128B4504A401538D906EE1A4740BABBCE86FC4D4A4000E1438996164740BABBCE86FC4D4A40
54057	56486	45.887121999999998	45.909723	52.877177000000003	52.865685999999997	 Центральная	0103000020E61000000100000005000000F3C7B4368DF14640724D81CCCE6E4A40F3C7B4368DF14640D6E6FF5547704A40A2B5A2CD71F44640D6E6FF5547704A40A2B5A2CD71F44640724D81CCCE6E4A40F3C7B4368DF14640724D81CCCE6E4A40
53689	56443	44.218311999999997	44.284823000000003	53.187007999999999	53.150593000000001	Центральная	0103000020E610000001000000050000008429CAA5F11B4640D600A5A146934A408429CAA5F11B4640910BCEE0EF974A4006137F1475244640910BCEE0EF974A4006137F1475244640D600A5A146934A408429CAA5F11B4640D600A5A146934A40
54182	21678	44.141272999999998	44.173279999999998	53.063623	53.048853000000001	Зеленая	0103000020E610000001000000050000006667D13B15124640DFA7AAD040864A406667D13B15124640FF2268CC24884A408386FE092E164640FF2268CC24884A408386FE092E164640DFA7AAD040864A406667D13B15124640DFA7AAD040864A40
53960	21967	43.662137999999999	43.676628000000001	53.192976000000002	53.183199000000002	Кушкин	0103000020E610000001000000050000002CB81FF0C0D4454078D4981073974A402CB81FF0C0D44540DA740470B3984A4069C70DBF9BD64540DA740470B3984A4069C70DBF9BD6454078D4981073974A402CB81FF0C0D4454078D4981073974A40
54173	32951	44.064915999999997	44.092934	52.976509	52.963189999999997	Ивановка	0103000020E610000001000000050000005A7EE02A4F084640C8EA56CF497B4A405A7EE02A4F084640F59F353FFE7C4A40DE57E542E50B4640F59F353FFE7C4A40DE57E542E50B4640C8EA56CF497B4A405A7EE02A4F084640C8EA56CF497B4A40
54176	21113	43.936771	43.959822000000003	53.361296000000003	53.328068000000002	Речная	0103000020E61000000100000005000000AD6BB41CE8F745409C6ED921FEA94A40AD6BB41CE8F745407B1684F23EAE4A409CFD8172DBFA45407B1684F23EAE4A409CFD8172DBFA45409C6ED921FEA94A40AD6BB41CE8F745409C6ED921FEA94A40
53725	21982	44.200327999999999	44.233566000000003	52.942791	52.913086	Драгунова	0103000020E610000001000000050000008E3C1059A4194640BD378600E0744A408E3C1059A419464048FB1F60AD784A4091BA9D7DE51D464048FB1F60AD784A4091BA9D7DE51D4640BD378600E0744A408E3C1059A4194640BD378600E0744A40
54081	56489	44.050148	44.084921000000001	53.339359999999999	53.321097999999999	Центральная	0103000020E61000000100000005000000DBFAE93F6B064640CF6740BD19A94A40DBFAE93F6B06464008C9022670AB4A402FDFFAB0DE0A464008C9022670AB4A402FDFFAB0DE0A4640CF6740BD19A94A40DBFAE93F6B064640CF6740BD19A94A40
54113	21766	44.182865	44.191209999999998	53.124381999999997	53.116297000000003	 Шоссейная	0103000020E61000000100000005000000A14ACD1E68174640BCCFF1D1E28E4A40A14ACD1E68174640041BD7BFEB8F4A408655BC9179184640041BD7BFEB8F4A408655BC9179184640BCCFF1D1E28E4A40A14ACD1E68174640BCCFF1D1E28E4A40
53816	33067	43.954054999999997	43.976297000000002	53.096020000000003	53.082141999999997	Максимовская	0103000020E61000000100000005000000EACA67791EFA454063D009A1838A4A40EACA67791EFA454087E123624A8C4A406A17D34CF7FC454087E123624A8C4A406A17D34CF7FC454063D009A1838A4A40EACA67791EFA454063D009A1838A4A40
53615	33078	44.238568999999998	44.254083000000001	53.107438000000002	53.099376999999997	Верхний порядок	0103000020E61000000100000005000000726BD26D891E4640BF7CB262B88C4A40726BD26D891E4640802C4487C08D4A401BBCAFCA85204640802C4487C08D4A401BBCAFCA85204640BF7CB262B88C4A40726BD26D891E4640BF7CB262B88C4A40
53952	21307	44.118572	44.148063999999998	53.176194000000002	53.156419	Центральная	0103000020E61000000100000005000000541C075E2D0F46408CBCAC8905944A40541C075E2D0F46402FE065868D964A4083DBDAC2F31246402FE065868D964A4083DBDAC2F31246408CBCAC8905944A40541C075E2D0F46408CBCAC8905944A40
53975	33041	43.82414	43.877923000000003	52.853794999999998	52.836765999999997	Майская	0103000020E61000000100000005000000A8A9656B7DE94540CE33F6251B6B4A40A8A9656B7DE94540813E9127496D4A40FFB3E6C75FF04540813E9127496D4A40FFB3E6C75FF04540CE33F6251B6B4A40A8A9656B7DE94540CE33F6251B6B4A40
53794	56452	43.953552000000002	43.968643	53.259013000000003	53.236975999999999	Школьная	0103000020E610000001000000050000008884EFFD0DFA4540ECF7C43A559E4A408884EFFD0DFA4540931E865627A14A40EA3F6B7EFCFB4540931E865627A14A40EA3F6B7EFCFB4540ECF7C43A559E4A408884EFFD0DFA4540ECF7C43A559E4A40
54094	21253	44.116864999999997	44.153993	52.890391999999999	52.872458999999999	Степная	0103000020E610000001000000050000000586AC6EF50E4640E90C8CBCAC6F4A400586AC6EF50E46405D4F745DF8714A400E68E90AB61346405D4F745DF8714A400E68E90AB6134640E90C8CBCAC6F4A400586AC6EF50E4640E90C8CBCAC6F4A40
53469	21479	43.747092000000002	43.810172000000001	53.150517000000001	53.126257000000003	Центральная	0103000020E61000000100000005000000378DEDB5A0DF45400FF27A3029904A40378DEDB5A0DF4540FB3E1C2444934A40451152B7B3E74540FB3E1C2444934A40451152B7B3E745400FF27A3029904A40378DEDB5A0DF45400FF27A3029904A40
53319	21391	43.865246999999997	43.913541000000002	53.174936000000002	53.146504999999998	Ленина	0103000020E6100000010000000500000026FBE769C0EE4540A9D903ADC0924A4026FBE769C0EE45405072874D64964A400F4757E9EEF445405072874D64964A400F4757E9EEF44540A9D903ADC0924A4026FBE769C0EE4540A9D903ADC0924A40
53612	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Юдина	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53375	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Чернышевского	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53724	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Театральный проезд	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53285	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Суворова	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53377	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Садовая	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53315	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Маловского	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53373	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Космонавтов	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53444	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Коммунистическая	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53378	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Ворошилова	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53461	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Болгарская	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53463	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Баумана	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53723	19569	43.961134000000001	44.091174000000002	53.205075000000001	53.165398000000003	Автохозяйская	0103000020E610000001000000050000006E895C7006FB45407369FCC22B954A406E895C7006FB4540151DC9E53F9A4A406D1FF296AB0B4640151DC9E53F9A4A406D1FF296AB0B46407369FCC22B954A406E895C7006FB45407369FCC22B954A40
53321	19569	44.030653999999998	44.031498999999997	53.179022000000003	53.178837999999999	  Белинская	0103000020E61000000100000005000000ECBE6378EC0346401AA4E029E4964A40ECBE6378EC034640DCA16131EA964A40A86DC32808044640DCA16131EA964A40A86DC328080446401AA4E029E4964A40ECBE6378EC0346401AA4E029E4964A40
54181	21666	44.211350000000003	44.248351999999997	53.024557000000001	53.003591	Школьная	0103000020E610000001000000050000003B014D840D1B4640ACC77DAB75804A403B014D840D1B4640A6F10BAF24834A40B6F292FFC91F4640A6F10BAF24834A40B6F292FFC91F4640ACC77DAB75804A403B014D840D1B4640ACC77DAB75804A40
53965	56474	44.02769	44.042135000000002	53.133572999999998	53.117778000000001	Центральная	0103000020E610000001000000050000008F368E588B0346401A187959138F4A408F368E588B034640765089EB18914A402C82FFAD64054640765089EB18914A402C82FFAD640546401A187959138F4A408F368E588B0346401A187959138F4A40
9808	21205	43.981444000000003	44.029522	52.912689999999998	52.890462999999997	Совхозная	0103000020E610000001000000050000007F6DFDF49FFD454026A60BB1FA714A407F6DFDF49FFD454070B1A206D3744A409A417C60C703464070B1A206D3744A409A417C60C703464026A60BB1FA714A407F6DFDF49FFD454026A60BB1FA714A40
53616	21027	43.983663	44.017305	53.319619000000003	53.304200000000002	Первомайская	0103000020E6100000010000000500000083A44FABE8FD4540BBB88D06F0A64A4083A44FABE8FD454012178046E9A84A405587DC0C3702464012178046E9A84A405587DC0C37024640BBB88D06F0A64A4083A44FABE8FD4540BBB88D06F0A64A40
54103	32940	44.009704999999997	44.047128999999998	53.087145	53.062913999999999	Советская	0103000020E61000000100000005000000C8CD70033E014640F33AE2900D884A40C8CD70033E01464045813E91278B4A40BAD8B4520806464045813E91278B4A40BAD8B45208064640F33AE2900D884A40C8CD70033E014640F33AE2900D884A40
53814	18446	44.177456999999997	44.200436000000003	53.327525000000001	53.296385999999998	Центральная	0103000020E610000001000000050000001FB935E9B6164640027FF8F9EFA54A401FB935E9B6164640ABCFD556ECA94A40757808E3A7194640ABCFD556ECA94A40757808E3A7194640027FF8F9EFA54A401FB935E9B6164640027FF8F9EFA54A40
53822	20739	44.126494999999998	44.168114000000003	53.258555999999999	53.245334	Школьная	0103000020E61000000100000005000000C30DF8FC30104640664CC11A679F4A40C30DF8FC30104640A017EE5C18A14A40F8FF71C284154640A017EE5C18A14A40F8FF71C284154640664CC11A679F4A40C30DF8FC30104640664CC11A679F4A40
54074	21402	43.872317000000002	43.883617999999998	53.102870000000003	53.090741999999999	Новая	0103000020E61000000100000005000000575F5D15A8EF4540D32F116F9D8B4A40575F5D15A8EF4540A9DE1AD82A8D4A40161406651AF14540A9DE1AD82A8D4A40161406651AF14540D32F116F9D8B4A40575F5D15A8EF4540D32F116F9D8B4A40
53648	33066	43.943840999999999	43.963011000000002	53.181558000000003	53.173506000000003	Советская	0103000020E61000000100000005000000DDCF29C8CFF8454074D4D17135964A40DDCF29C8CFF84540E129E44A3D974A401958C7F143FB4540E129E44A3D974A401958C7F143FB454074D4D17135964A40DDCF29C8CFF8454074D4D17135964A40
53905	56463	44.178902999999998	44.205592000000003	52.903722999999999	52.887692000000001	Центральная	0103000020E610000001000000050000000114234BE6164640DE7536E49F714A400114234BE61646404ED2FC31AD734A40DD28B2D6501A46404ED2FC31AD734A40DD28B2D6501A4640DE7536E49F714A400114234BE6164640DE7536E49F714A40
54082	47856	43.694307000000002	43.731065999999998	53.102654000000001	53.085214999999998	Центральная	0103000020E610000001000000050000002331410DDFD8454077103B53E88A4A402331410DDFD84540DC662AC4238D4A40D89B189293DD4540DC662AC4238D4A40D89B189293DD454077103B53E88A4A402331410DDFD8454077103B53E88A4A40
53808	19036	44.769545000000001	44.792622999999999	53.869045999999997	53.861494999999998	Центральная	0103000020E6100000010000000500000071E65773806246407155D97745EE4A4071E65773806246401C5C3AE63CEF4A405987A3AB746546401C5C3AE63CEF4A405987A3AB746546407155D97745EE4A4071E65773806246407155D97745EE4A40
54283	56521	44.734896999999997	44.748570000000001	53.779266999999997	53.760565999999997	Центральная	0103000020E61000000100000005000000D976DA1A115E46408A39083A5AE14A40D976DA1A115E46400FED6305BFE34A4024624A24D15F46400FED6305BFE34A4024624A24D15F46408A39083A5AE14A40D976DA1A115E46408A39083A5AE14A40
53815	46505	44.758451000000001	44.781779999999998	53.753703999999999	53.736781000000001	Центральная	0103000020E610000001000000050000002B4F20EC1461464037A8FDD64EDE4A402B4F20EC14614640A46E675F79E04A405C55F65D11644640A46E675F79E04A405C55F65D1164464037A8FDD64EDE4A402B4F20EC1461464037A8FDD64EDE4A40
53812	46458	45.079248999999997	45.102488000000001	53.798389999999998	53.781139000000003	Центральная	0103000020E61000000100000005000000CF9ECBD4248A4640A950DD5CFCE34A40CF9ECBD4248A46400ABABDA431E64A40C11DA8531E8D46400ABABDA431E64A40C11DA8531E8D4640A950DD5CFCE34A40CF9ECBD4248A4640A950DD5CFCE34A40
54002	46195	45.099865000000001	45.127837999999997	53.871949999999998	53.858643999999998	Проезжая	0103000020E61000000100000005000000ED815660C88C46400C74ED0BE8ED4A40ED815660C88C4640A4DFBE0E9CEF4A40D097DEFE5C904640A4DFBE0E9CEF4A40D097DEFE5C9046400C74ED0BE8ED4A40ED815660C88C46400C74ED0BE8ED4A40
53940	18569	45.128360000000001	45.16572	53.900660000000002	53.875622999999997	Центральная	0103000020E61000000100000005000000AA0EB9196E9046400D501A6A14F04A40AA0EB9196E9046405E68AED348F34A4085251E50369546405E68AED348F34A4085251E50369546400D501A6A14F04A40AA0EB9196E9046400D501A6A14F04A40
53813	19120	44.618566000000001	44.640484000000001	53.852429999999998	53.844541999999997	Центральная	0103000020E610000001000000050000007235B22B2D4F4640990CC7F319EC4A407235B22B2D4F46408C101E6D1CED4A403ECE3461FB5146408C101E6D1CED4A403ECE3461FB514640990CC7F319EC4A407235B22B2D4F4640990CC7F319EC4A40
53934	18680	45.166851999999999	45.206980000000001	53.918922000000002	53.896951999999999	Нагорная	0103000020E61000000100000005000000D7A205685B954640780AB952CFF24A40D7A205685B95464097C9703C9FF54A408A7615527E9A464097C9703C9FF54A408A7615527E9A4640780AB952CFF24A40D7A205685B954640780AB952CFF24A40
54211	56504	44.829031999999998	44.848229000000003	53.793411999999996	53.779054000000002	Молодежная	0103000020E6100000010000000500000032AB77B81D6A4640B4E89D0AB8E34A4032AB77B81D6A4640812040868EE54A40684293C4926C4640812040868EE54A40684293C4926C4640B4E89D0AB8E34A4032AB77B81D6A4640B4E89D0AB8E34A40
54160	46075	45.024236000000002	45.045831	53.889316000000001	53.877862999999998	Речная	0103000020E6100000010000000500000064B14D2A1A83464029AF95D05DF04A4064B14D2A1A8346409FE74F1BD5F14A404D124BCADD8546409FE74F1BD5F14A404D124BCADD85464029AF95D05DF04A4064B14D2A1A83464029AF95D05DF04A40
53809	19098	44.727297999999998	44.735247999999999	53.826540000000001	53.815308999999999	Центральная	0103000020E610000001000000050000001D39D219185D46403691990B5CE84A401D39D219185D4640FD6A0E10CCE94A408639419B1C5E4640FD6A0E10CCE94A408639419B1C5E46403691990B5CE84A401D39D219185D46403691990B5CE84A40
54161	46298	44.6922	44.717308000000003	53.854118999999997	53.844728000000003	Набережная	0103000020E61000000100000005000000462575029A584640FC010F0C20EC4A40462575029A58464034F279C553ED4A406094A0BFD05B464034F279C553ED4A406094A0BFD05B4640FC010F0C20EC4A40462575029A584640FC010F0C20EC4A40
53459	18745	44.812089999999998	44.885939999999998	53.882407000000001	53.860194	Черокманова	0103000020E610000001000000050000004EB4AB90F2674640931B45D61AEE4A404EB4AB90F267464078616BB6F2F04A40EF1B5F7B6671464078616BB6F2F04A40EF1B5F7B66714640931B45D61AEE4A404EB4AB90F2674640931B45D61AEE4A40
53314	18745	44.812089999999998	44.885939999999998	53.882407000000001	53.860194	Садовая	0103000020E610000001000000050000004EB4AB90F2674640931B45D61AEE4A404EB4AB90F267464078616BB6F2F04A40EF1B5F7B6671464078616BB6F2F04A40EF1B5F7B66714640931B45D61AEE4A404EB4AB90F2674640931B45D61AEE4A40
53457	18745	44.812089999999998	44.885939999999998	53.882407000000001	53.860194	Калинина	0103000020E610000001000000050000004EB4AB90F2674640931B45D61AEE4A404EB4AB90F267464078616BB6F2F04A40EF1B5F7B6671464078616BB6F2F04A40EF1B5F7B66714640931B45D61AEE4A404EB4AB90F2674640931B45D61AEE4A40
54159	18993	44.672896000000001	44.693629000000001	53.901387	53.885404999999999	Демократическая	0103000020E61000000100000005000000FBCDC47421564640815B77F354F14A40FBCDC47421564640100533A660F34A405247C7D5C8584640100533A660F34A405247C7D5C8584640815B77F354F14A40FBCDC47421564640815B77F354F14A40
54038	16455	45.063913999999997	45.088807000000003	53.907116000000002	53.885899000000002	Молодежная	0103000020E61000000100000005000000D6E07D552E8846409147702365F14A40D6E07D552E884640D4D688601CF44A40F4531C075E8B4640D4D688601CF44A40F4531C075E8B46409147702365F14A40D6E07D552E8846409147702365F14A40
53687	46029	44.988168000000002	45.004212000000003	53.887979000000001	53.871434999999998	Школьная	0103000020E61000000100000005000000147AFD497C7E46407DCB9C2E8BEF4A40147AFD497C7E46407444BE4BA9F14A401920D1048A8046407444BE4BA9F14A401920D1048A8046407DCB9C2E8BEF4A40147AFD497C7E46407DCB9C2E8BEF4A40
53915	46029	44.988168000000002	45.004212000000003	53.887979000000001	53.871434999999998	Снежная	0103000020E61000000100000005000000147AFD497C7E46407DCB9C2E8BEF4A40147AFD497C7E46407444BE4BA9F14A401920D1048A8046407444BE4BA9F14A401920D1048A8046407DCB9C2E8BEF4A40147AFD497C7E46407DCB9C2E8BEF4A40
54070	19191	44.990648	45.010896000000002	53.831254000000001	53.822586000000001	Приовражная	0103000020E6100000010000000500000085ECBC8DCD7E4640E012807F4AE94A4085ECBC8DCD7E4640A855F48766EA4A4020D4450A65814640A855F48766EA4A4020D4450A65814640E012807F4AE94A4085ECBC8DCD7E4640E012807F4AE94A40
53653	56438	44.939120000000003	44.958298999999997	53.761294999999997	53.747432000000003	Горка	0103000020E6100000010000000500000080828B1535784640F0FD0DDAABDF4A4080828B1535784640DDCD531D72E14A400E65A88AA97A4640DDCD531D72E14A400E65A88AA97A4640F0FD0DDAABDF4A4080828B1535784640F0FD0DDAABDF4A40
54004	56479	44.921306999999999	44.933110999999997	53.818497999999998	53.813113000000001	 Крюковка	0103000020E61000000100000005000000B6494563ED754640EA79371614E84A40B6494563ED754640B3EBDE8AC4E84A40D844662E70774640B3EBDE8AC4E84A40D844662E70774640EA79371614E84A40B6494563ED754640EA79371614E84A40
53640	56436	42.664774999999999	42.683190000000003	53.711714999999998	53.687806000000002	Центральная	0103000020E610000001000000050000006519E258175545400DFFE9060AD84A406519E258175545404C89247A19DB4A40257A19C5725745404C89247A19DB4A40257A19C5725745400DFFE9060AD84A406519E258175545400DFFE9060AD84A40
54095	17698	42.211081	42.288192000000002	53.812603000000003	53.795422000000002	Школьная	0103000020E610000001000000050000004BE7C3B3041B45406C425A63D0E54A404BE7C3B3041B4540D5D0066003E84A40037CB779E3244540D5D0066003E84A40037CB779E32445406C425A63D0E54A404BE7C3B3041B45406C425A63D0E54A40
53614	18250	42.785660999999998	42.838679999999997	53.488151000000002	53.457751999999999	Советская	0103000020E610000001000000050000000F5F268A90644540DCD6169E97BA4A400F5F268A906445403E4162BB7BBE4A4096E7C1DD596B45403E4162BB7BBE4A4096E7C1DD596B4540DCD6169E97BA4A400F5F268A90644540DCD6169E97BA4A40
54032	17207	42.509518999999997	42.555207000000003	53.408982999999999	53.384746	Вторая часть	0103000020E6100000010000000500000066D828EB3741454027A25F5B3FB14A4066D828EB374145405BCF108E59B44A4051C1E105114745405BCF108E59B44A4051C1E1051147454027A25F5B3FB14A4066D828EB3741454027A25F5B3FB14A40
53835	18006	42.580835999999998	42.624071999999998	53.649861000000001	53.610871000000003	Советская	0103000020E61000000100000005000000732B84D5584A454094895B0531CE4A40732B84D5584A454012F92EA52ED34A40B62C5F97E14F454012F92EA52ED34A40B62C5F97E14F454094895B0531CE4A40732B84D5584A454094895B0531CE4A40
53811	18093	42.606546000000002	42.618915999999999	53.523358000000002	53.507010999999999	Юбилейная	0103000020E6100000010000000500000083C2A04CA34D45402BDB87BCE5C04A4083C2A04CA34D4540CC0C1B65FDC24A404E7CB5A3384F4540CC0C1B65FDC24A404E7CB5A3384F45402BDB87BCE5C04A4083C2A04CA34D45402BDB87BCE5C04A40
53621	17418	42.432766999999998	42.479596000000001	53.612164	53.589706	Молодёжная	0103000020E61000000100000005000000DEE4B7E864374540A320787C7BCB4A40DEE4B7E864374540EFE4D3635BCE4A406EA5D766633D4540EFE4D3635BCE4A406EA5D766633D4540A320787C7BCB4A40DEE4B7E864374540A320787C7BCB4A40
53868	17344	42.415852000000001	42.508009999999999	53.490369000000001	53.472965000000002	Лесная	0103000020E61000000100000005000000F4FC69A33A3545408A93FB1D8ABC4A40F4FC69A33A35454072FC5069C4BE4A403E05C0780641454072FC5069C4BE4A403E05C078064145408A93FB1D8ABC4A40F4FC69A33A3545408A93FB1D8ABC4A40
54127	56496	42.082307	42.906098	53.853619999999999	53.325498000000003	Центральная	0103000020E61000000100000005000000AE9D2809890A4540EB7420EBA9A94A40AE9D2809890A4540139B8F6B43ED4A404A7CEE04FB734540139B8F6B43ED4A404A7CEE04FB734540EB7420EBA9A94A40AE9D2809890A4540EB7420EBA9A94A40
53434	21331	42.397589000000004	42.430574999999997	53.660997999999999	53.636029999999998	Ленина	0103000020E61000000100000005000000EB1F4432E43245402FA3586E69D14A40EB1F4432E4324540575C1C959BD44A40D3BCE3141D374540575C1C959BD44A40D3BCE3141D3745402FA3586E69D14A40EB1F4432E43245402FA3586E69D14A40
53871	21331	42.397589000000004	42.430574999999997	53.660997999999999	53.636029999999998	40 лет Победы	0103000020E61000000100000005000000EB1F4432E43245402FA3586E69D14A40EB1F4432E4324540575C1C959BD44A40D3BCE3141D374540575C1C959BD44A40D3BCE3141D3745402FA3586E69D14A40EB1F4432E43245402FA3586E69D14A40
54091	17408	42.464280000000002	42.547203000000003	53.547504000000004	53.527388999999999	Новая	0103000020E61000000100000005000000EC17EC866D3B454094A2957B81C34A40EC17EC866D3B4540F0366F9C14C64A40F5A276BF0A464540F0366F9C14C64A40F5A276BF0A46454094A2957B81C34A40EC17EC866D3B454094A2957B81C34A40
54093	17659	42.307361999999998	42.336790999999998	53.748171999999997	53.729841	Заводская	0103000020E610000001000000050000003E0455A357274540D5230D6E6BDD4A403E0455A35727454036E49F19C4DF4A40274BADF71B2B454036E49F19C4DF4A40274BADF71B2B4540D5230D6E6BDD4A403E0455A357274540D5230D6E6BDD4A40
53676	17147	42.684959999999997	42.738985	53.451897000000002	53.419834999999999	Центральная	0103000020E61000000100000005000000B988EFC4AC574540AB5B3D27BDB54A40B988EFC4AC5745408C14CAC2D7B94A40069E7B0F975E45408C14CAC2D7B94A40069E7B0F975E4540AB5B3D27BDB54A40B988EFC4AC574540AB5B3D27BDB54A40
53643	18201	42.779364000000001	42.836928	53.541612999999998	53.507835999999998	Ивановка	0103000020E6100000010000000500000002D71533C2634540A0DD21C500C14A4002D71533C2634540520B259353C54A40A88DEA74206B4540520B259353C54A40A88DEA74206B4540A0DD21C500C14A4002D71533C2634540A0DD21C500C14A40
53866	17491	42.537878999999997	42.559024999999998	53.603001999999996	53.585943	Луговая	0103000020E61000000100000005000000431A1538D9444540FA28232E00CB4A40431A1538D944454017B6662B2FCD4A40BD5296218E47454017B6662B2FCD4A40BD5296218E474540FA28232E00CB4A40431A1538D9444540FA28232E00CB4A40
53804	17911	42.671664999999997	42.702117999999999	53.684041999999998	53.650416	Ленина	0103000020E61000000100000005000000156F641EF9554540C765DCD440D34A40156F641EF9554540938B31B08ED74A406AF7AB00DF594540938B31B08ED74A406AF7AB00DF594540C765DCD440D34A40156F641EF9554540C765DCD440D34A40
53941	17911	42.671664999999997	42.702117999999999	53.684041999999998	53.650416	 Новый Посёлок	0103000020E61000000100000005000000156F641EF9554540C765DCD440D34A40156F641EF9554540938B31B08ED74A406AF7AB00DF594540938B31B08ED74A406AF7AB00DF594540C765DCD440D34A40156F641EF9554540C765DCD440D34A40
53869	17752	42.642226999999998	42.707813000000002	53.782069999999997	53.742452999999998	Школьный переулок	0103000020E61000000100000005000000D9CD8C7E3452454096E82CB308DF4A40D9CD8C7E345245406397A8DE1AE44A408257CB9D995A45406397A8DE1AE44A408257CB9D995A454096E82CB308DF4A40D9CD8C7E3452454096E82CB308DF4A40
53810	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Советская	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53428	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Смирнова	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53458	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Пушкина	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53426	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Молодёжная	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53431	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Ленина	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53433	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Кулакова	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53346	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Кирова	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53347	16772	42.558611999999997	42.649026999999997	53.511294999999997	53.476320000000001	Белинского	0103000020E610000001000000050000009A931799804745402237C30DF8BC4A409A93179980474540DDCD531D72C14A40499C155113534540DDCD531D72C14A40499C1551135345402237C30DF8BC4A409A931799804745402237C30DF8BC4A40
53867	17253	42.302717999999999	42.370396999999997	53.404677999999997	53.374175000000001	Ленинская	0103000020E610000001000000050000008CF4A276BF2645408BFD65F7E4AF4A408CF4A276BF26454091B41B7DCCB34A40ACC43C2B692F454091B41B7DCCB34A40ACC43C2B692F45408BFD65F7E4AF4A408CF4A276BF2645408BFD65F7E4AF4A40
54092	17850	42.580351	42.609115000000003	53.738059	53.718296000000002	Первомайская	0103000020E61000000100000005000000B7990AF1484A45407F6C921FF1DB4A40B7990AF1484A45405DC2A1B778DE4A406440F67AF74D45405DC2A1B778DE4A406440F67AF74D45407F6C921FF1DB4A40B7990AF1484A45407F6C921FF1DB4A40
53645	18063	42.652971000000001	42.698596000000002	53.616325000000003	53.574646999999999	Ленина	0103000020E61000000100000005000000431EC18D945345404CDF6B088EC94A40431EC18D94534540865AD3BCE3CE4A40E78EFE976B594540865AD3BCE3CE4A40E78EFE976B5945404CDF6B088EC94A40431EC18D945345404CDF6B088EC94A40
53610	18159	42.803626999999999	42.865225000000002	53.574289	53.541448000000003	Садовая	0103000020E610000001000000050000005F97E13FDD664540083E062B4EC54A405F97E13FDD664540EDB94C4D82C94A403F575BB1BF6E4540EDB94C4D82C94A403F575BB1BF6E4540083E062B4EC54A405F97E13FDD664540083E062B4EC54A40
54071	56487	42.201756000000003	42.238722000000003	53.682867999999999	53.671272999999999	Центральная	0103000020E61000000100000005000000CAE2FE23D31945400AD80E46ECD54A40CAE2FE23D319454012BEF73768D74A40F96A47718E1E454012BEF73768D74A40F96A47718E1E45400AD80E46ECD54A40CAE2FE23D31945400AD80E46ECD54A40
81159	62102	\N	\N	\N	\N	проспект Мира	\N
81160	62102	\N	\N	\N	\N	Проспект Мира 	\N
81161	62102	\N	\N	\N	\N	Литке	\N
81143	62102	43.526187	43.533706000000002	53.450867000000002	53.447274	Ленина	0103000020E61000000100000005000000494A7A185AC34540F12C414640B94A40494A7A185AC345403EEC8502B6B94A40E9D66B7A50C445403EEC8502B6B94A40E9D66B7A50C44540F12C414640B94A40494A7A185AC34540F12C414640B94A40
81148	62102	46.088487999999998	46.100085	53.897106000000001	53.890096999999997	Конституции СССР	0103000020E61000000100000005000000520B2593530B474044A2D0B2EEF14A40520B2593530B4740CF85915ED4F24A40FBE8D495CF0C4740CF85915ED4F24A40FBE8D495CF0C474044A2D0B2EEF14A40520B2593530B474044A2D0B2EEF14A40
81158	62102	\N	\N	\N	\N	Комсомольская	\N
81146	62102	43.526187	43.533706000000002	53.450867000000002	53.447274	Зеленая	0103000020E61000000100000005000000494A7A185AC34540F12C414640B94A40494A7A185AC345403EEC8502B6B94A40E9D66B7A50C445403EEC8502B6B94A40E9D66B7A50C44540F12C414640B94A40494A7A185AC34540F12C414640B94A40
81147	62102	45.170158000000001	45.213177999999999	53.208385999999997	53.189976000000001	Заречная	0103000020E610000001000000050000008E93C2BCC79546403083312251984A408E93C2BCC7954640DD787764AC9A4A40041DAD6A499B4640DD787764AC9A4A40041DAD6A499B46403083312251984A408E93C2BCC79546403083312251984A40
53608	15481	45.624274	45.66778	53.352702999999998	53.328499000000001	Советская	0103000020E610000001000000050000001EDFDE35E8CF464065E256410CAA4A401EDFDE35E8CF4640BD19355F25AD4A402176A6D079D54640BD19355F25AD4A402176A6D079D5464065E256410CAA4A401EDFDE35E8CF464065E256410CAA4A40
53721	16090	45.941299000000001	45.998468000000003	53.127014000000003	53.106498000000002	Молодёжная	0103000020E61000000100000005000000F660527C7CF84640728BF9B9A18D4A40F660527C7CF846402C11A8FE41904A40200DA7CCCDFF46402C11A8FE41904A40200DA7CCCDFF4640728BF9B9A18D4A40F660527C7CF84640728BF9B9A18D4A40
53281	16090	45.941299000000001	45.998468000000003	53.127014000000003	53.106498000000002	Ленина	0103000020E61000000100000005000000F660527C7CF84640728BF9B9A18D4A40F660527C7CF846402C11A8FE41904A40200DA7CCCDFF46402C11A8FE41904A40200DA7CCCDFF4640728BF9B9A18D4A40F660527C7CF84640728BF9B9A18D4A40
53348	16174	45.868940000000002	45.947595999999997	53.148750999999997	53.133372999999999	Строителей	0103000020E61000000100000005000000D717096D39EF4640AF95D05D12914A40D717096D39EF4640A71FD4450A934A4003E962D34AF94640A71FD4450A934A4003E962D34AF94640AF95D05D12914A40D717096D39EF4640AF95D05D12914A40
53287	16174	45.868940000000002	45.947595999999997	53.148750999999997	53.133372999999999	Заводская	0103000020E61000000100000005000000D717096D39EF4640AF95D05D12914A40D717096D39EF4640A71FD4450A934A4003E962D34AF94640A71FD4450A934A4003E962D34AF94640AF95D05D12914A40D717096D39EF4640AF95D05D12914A40
54180	16015	45.912821999999998	45.935972	53.195931999999999	53.173440999999997	Ленинская	0103000020E61000000100000005000000DF88EE59D7F446408C648F5033964A40DF88EE59D7F44640B41EBE4C14994A4061FC34EECDF74640B41EBE4C14994A4061FC34EECDF746408C648F5033964A40DF88EE59D7F446408C648F5033964A40
53607	15271	45.722532000000001	45.748727000000002	53.086491000000002	53.053393999999997	Садовая	0103000020E610000001000000050000002028B7ED7BDC4640BCE6559DD5864A402028B7ED7BDC4640FD321823128B4A40EC504D49D6DF4640FD321823128B4A40EC504D49D6DF4640BCE6559DD5864A402028B7ED7BDC4640BCE6559DD5864A40
53641	15271	45.722532000000001	45.748727000000002	53.086491000000002	53.053393999999997	Мира	0103000020E610000001000000050000002028B7ED7BDC4640BCE6559DD5864A402028B7ED7BDC4640FD321823128B4A40EC504D49D6DF4640FD321823128B4A40EC504D49D6DF4640BCE6559DD5864A402028B7ED7BDC4640BCE6559DD5864A40
53277	15049	45.675612999999998	45.716557999999999	53.090141000000003	53.065159999999999	переулок Лесной	0103000020E6100000010000000500000050E09D7C7AD64640F180B22957884A4050E09D7C7AD64640AE8383BD898B4A40F5D72B2CB8DB4640AE8383BD898B4A40F5D72B2CB8DB4640F180B22957884A4050E09D7C7AD64640F180B22957884A40
53278	15049	45.675612999999998	45.716557999999999	53.090141000000003	53.065159999999999	Школьная площадь	0103000020E6100000010000000500000050E09D7C7AD64640F180B22957884A4050E09D7C7AD64640AE8383BD898B4A40F5D72B2CB8DB4640AE8383BD898B4A40F5D72B2CB8DB4640F180B22957884A4050E09D7C7AD64640F180B22957884A40
53342	15049	45.675612999999998	45.716557999999999	53.090141000000003	53.065159999999999	Садовая	0103000020E6100000010000000500000050E09D7C7AD64640F180B22957884A4050E09D7C7AD64640AE8383BD898B4A40F5D72B2CB8DB4640AE8383BD898B4A40F5D72B2CB8DB4640F180B22957884A4050E09D7C7AD64640F180B22957884A40
54179	15629	45.611652999999997	45.623116000000003	53.478523000000003	53.463419000000002	Шкафтинская	0103000020E6100000010000000500000009C03FA54ACE46402AAC545051BB4A4009C03FA54ACE464021B1DD3D40BD4A40A3CEDC43C2CF464021B1DD3D40BD4A40A3CEDC43C2CF46402AAC545051BB4A4009C03FA54ACE46402AAC545051BB4A40
53872	56461	45.673340000000003	45.712076000000003	53.036952999999997	53.017353	Театральная	0103000020E61000000100000005000000598B4F0130D6464066BE839F38824A40598B4F0130D646409A3E3BE0BA844A401D226E4E25DB46409A3E3BE0BA844A401D226E4E25DB464066BE839F38824A40598B4F0130D6464066BE839F38824A40
53963	16320	45.884138999999998	45.909463000000002	53.111730000000001	53.085825999999997	Луговая	0103000020E610000001000000050000001F0F7D772BF14640C092AB58FC8A4A401F0F7D772BF14640B5FD2B2B4D8E4A4006F6984869F44640B5FD2B2B4D8E4A4006F6984869F44640C092AB58FC8A4A401F0F7D772BF14640C092AB58FC8A4A40
53864	15433	45.505293000000002	45.531658	53.269477999999999	53.257074000000003	Молодежная	0103000020E61000000100000005000000E9F2E670ADC04640725303CDE7A04A40E9F2E670ADC04640E97E4E417EA24A4011548D5E0DC44640E97E4E417EA24A4011548D5E0DC44640725303CDE7A04A40E9F2E670ADC04640725303CDE7A04A40
54294	56524	45.420105	45.450890999999999	53.133415999999997	53.120297000000001	Школьная	0103000020E610000001000000050000006BF12900C6B54640496760E4658F4A406BF12900C6B54640AE6186C613914A40C687D9CBB6B94640AE6186C613914A40C687D9CBB6B94640496760E4658F4A406BF12900C6B54640496760E4658F4A40
53264	16398	46.002482999999998	46.032890999999999	53.106498000000002	53.085538999999997	Центральная	0103000020E61000000100000005000000E2E5E95C510047402AC423F1F28A4A40E2E5E95C51004740728BF9B9A18D4A4097AAB4C535044740728BF9B9A18D4A4097AAB4C5350447402AC423F1F28A4A40E2E5E95C510047402AC423F1F28A4A40
53968	15339	45.621659999999999	45.648834000000001	53.197329000000003	53.167687000000001	Школьная	0103000020E610000001000000050000009D9D0C8E92CF4640707B82C476954A409D9D0C8E92CF4640B5C6A01342994A40354415FE0CD34640B5C6A01342994A40354415FE0CD34640707B82C476954A409D9D0C8E92CF4640707B82C476954A40
54020	15349	45.627428000000002	45.646597999999997	53.229247000000001	53.213143000000002	Центральная	0103000020E610000001000000050000001F4C8A8F4FD04640882F1345489B4A401F4C8A8F4FD0464062DA37F7579D4A405AD427B9C3D2464062DA37F7579D4A405AD427B9C3D24640882F1345489B4A401F4C8A8F4FD04640882F1345489B4A40
54019	15520	45.800604999999997	45.821373999999999	53.463928000000003	53.447386999999999	Молодежная	0103000020E61000000100000005000000CD0182397AE64640E9D32AFA43B94A40CD0182397AE646406FD921FE61BB4A4071E481C822E946406FD921FE61BB4A4071E481C822E94640E9D32AFA43B94A40CD0182397AE64640E9D32AFA43B94A40
53606	14940	45.525568	45.608598999999998	53.114908	53.103054	Советская	0103000020E610000001000000050000007DE9EDCF45C346406ADC9BDF308D4A407DE9EDCF45C346403E062B4EB58E4A406CB07092E6CD46403E062B4EB58E4A406CB07092E6CD46406ADC9BDF308D4A407DE9EDCF45C346406ADC9BDF308D4A40
54200	16490	46.073109000000002	46.095342000000002	53.029843	53.008429999999997	Молодежная	0103000020E610000001000000050000008A05BEA25B0947401327F73B14814A408A05BEA25B094740DC813AE5D1834A40B6F7A92A340C4740DC813AE5D1834A40B6F7A92A340C47401327F73B14814A408A05BEA25B0947401327F73B14814A40
54298	56525	45.611204000000001	45.638646999999999	53.087372000000002	53.073698	Заводская	0103000020E610000001000000050000009A97C3EE3BCE4640EBE3A1EF6E894A409A97C3EE3BCE4640064B75012F8B4A402158552FBFD14640064B75012F8B4A402158552FBFD14640EBE3A1EF6E894A409A97C3EE3BCE4640EBE3A1EF6E894A40
53424	15710	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	Октябрьская	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
53425	15710	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	Набережная	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
53345	15710	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	Московская	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
53522	15710	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	Ленина	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
53765	15710	45.680644000000001	45.720547000000003	53.292312000000003	53.261755000000001	А.Матросова	0103000020E61000000100000005000000FC1BB4571FD746404148163081A14A40FC1BB4571FD746403B1DC87A6AA54A408F1D54E23ADC46403B1DC87A6AA54A408F1D54E23ADC46404148163081A14A40FC1BB4571FD746404148163081A14A40
54183	15646	45.458095	45.499364	53.438885999999997	53.405825999999998	Молодежная	0103000020E6100000010000000500000006BB61DBA2BA4640E9EE3A1BF2B34A4006BB61DBA2BA46400C569C6A2DB84A405E66D828EBBF46400C569C6A2DB84A405E66D828EBBF4640E9EE3A1BF2B34A4006BB61DBA2BA4640E9EE3A1BF2B34A40
53863	15574	45.571382	45.626547000000002	53.521290999999998	53.496509000000003	Молодежная	0103000020E61000000100000005000000F4C29D0B23C94640B8955E9B8DBF4A40F4C29D0B23C946407D59DAA9B9C24A4016342DB132D046407D59DAA9B9C24A4016342DB132D04640B8955E9B8DBF4A40F4C29D0B23C94640B8955E9B8DBF4A40
53906	56464	46.041837999999998	46.048206999999998	53.061523999999999	53.040320999999999	Новая	0103000020E6100000010000000500000072DD94F25A054740C72B103D29854A4072DD94F25A054740A5F5B704E0874A401938A0A52B064740A5F5B704E0874A401938A0A52B064740C72B103D29854A4072DD94F25A054740C72B103D29854A40
54240	16002	45.842691000000002	45.881793999999999	53.189323000000002	53.161776000000003	Сибирь	0103000020E6100000010000000500000018D1764CDDEB46408CA37213B5944A4018D1764CDDEB4640B8B06EBC3B984A408EE733A0DEF04640B8B06EBC3B984A408EE733A0DEF046408CA37213B5944A4018D1764CDDEB46408CA37213B5944A40
53478	16002	45.842691000000002	45.881793999999999	53.189323000000002	53.161776000000003	Ленина	0103000020E6100000010000000500000018D1764CDDEB46408CA37213B5944A4018D1764CDDEB4640B8B06EBC3B984A408EE733A0DEF04640B8B06EBC3B984A408EE733A0DEF046408CA37213B5944A4018D1764CDDEB46408CA37213B5944A40
54231	16002	45.842691000000002	45.881793999999999	53.189323000000002	53.161776000000003	Гагарина	0103000020E6100000010000000500000018D1764CDDEB46408CA37213B5944A4018D1764CDDEB4640B8B06EBC3B984A408EE733A0DEF04640B8B06EBC3B984A408EE733A0DEF046408CA37213B5944A4018D1764CDDEB46408CA37213B5944A40
53865	14766	43.152740000000001	43.175952000000002	53.669981999999997	53.650740999999996	Школьная	0103000020E610000001000000050000004165FCFB8C9345404A95287B4BD34A404165FCFB8C9345404F745DF8C1D54A4039D55A98859645404F745DF8C1D54A4039D55A98859645404A95287B4BD34A404165FCFB8C9345404A95287B4BD34A40
53861	14766	43.152740000000001	43.175952000000002	53.669981999999997	53.650740999999996	Верхняя	0103000020E610000001000000050000004165FCFB8C9345404A95287B4BD34A404165FCFB8C9345404F745DF8C1D54A4039D55A98859645404F745DF8C1D54A4039D55A98859645404A95287B4BD34A404165FCFB8C9345404A95287B4BD34A40
53860	14653	42.886443	42.905603999999997	53.786076000000001	53.77319	Школьная	0103000020E610000001000000050000005262D7F67671454010CCD1E3F7E24A405262D7F676714540D3156C239EE44A403A90F5D4EA734540D3156C239EE44A403A90F5D4EA73454010CCD1E3F7E24A405262D7F67671454010CCD1E3F7E24A40
53857	14614	42.782822000000003	42.816445999999999	53.753453999999998	53.740025000000003	Советская	0103000020E610000001000000050000006F4BE48233644540789CA223B9DE4A406F4BE482336445402B85402E71E04A409A79724D816845402B85402E71E04A409A79724D81684540789CA223B9DE4A406F4BE48233644540789CA223B9DE4A40
54178	14000	42.793089999999999	42.824252999999999	53.699392000000003	53.683396000000002	Плант	0103000020E610000001000000050000006F641EF983654540CE1B278579D74A406F641EF983654540C28A53AD85D94A40A0504F1F81694540C28A53AD85D94A40A0504F1F81694540CE1B278579D74A406F641EF983654540CE1B278579D74A40
54011	48955	42.974333999999999	43.017867000000003	53.597706000000002	53.569124000000002	Советская	0103000020E61000000100000005000000C0B0FCF9B67C454032AF230ED9C84A40C0B0FCF9B67C4540BE4F55A181CC4A40BD56427749824540BE4F55A181CC4A40BD5642774982454032AF230ED9C84A40C0B0FCF9B67C454032AF230ED9C84A40
53718	48955	42.974333999999999	43.017867000000003	53.597706000000002	53.569124000000002	 Советская	0103000020E61000000100000005000000C0B0FCF9B67C454032AF230ED9C84A40C0B0FCF9B67C4540BE4F55A181CC4A40BD56427749824540BE4F55A181CC4A40BD5642774982454032AF230ED9C84A40C0B0FCF9B67C454032AF230ED9C84A40
53664	56441	42.930765999999998	42.951481000000001	53.793841999999998	53.782027999999997	Финская	0103000020E61000000100000005000000471D1D57237745403447567E19E44A40471D1D57237745407A185A9D9CE54A40F8E12021CA7945407A185A9D9CE54A40F8E12021CA7945403447567E19E44A40471D1D57237745403447567E19E44A40
54147	13420	43.307250000000003	43.320725000000003	53.636809999999997	53.631027000000003	Молодежная	0103000020E6100000010000000500000017D9CEF753A745404EF2237EC5D04A4017D9CEF753A7454004E275FD82D14A403B014D840DA9454004E275FD82D14A403B014D840DA945404EF2237EC5D04A4017D9CEF753A745404EF2237EC5D04A40
54185	14883	43.226517999999999	43.273364999999998	53.573701	53.555025999999998	Село	0103000020E6100000010000000500000048FAB48AFE9C454000378B170BC74A4048FAB48AFE9C45405C57CC086FC94A407E6FD39FFDA245405C57CC086FC94A407E6FD39FFDA2454000378B170BC74A4048FAB48AFE9C454000378B170BC74A40
54090	14573	43.112853999999999	43.167661000000003	53.576507999999997	53.534784999999999	Советская	0103000020E61000000100000005000000849CF7FF718E454018B2BAD573C44A40849CF7FF718E4540F1F09E03CBC94A4047E867EA75954540F1F09E03CBC94A4047E867EA7595454018B2BAD573C44A40849CF7FF718E454018B2BAD573C44A40
54073	13513	43.231028000000002	43.25159	53.675716000000001	53.661686000000003	Центральная	0103000020E61000000100000005000000EB3A5453929D45404C1C7920B2D44A40EB3A5453929D454025B1A4DC7DD64A401500E31934A0454025B1A4DC7DD64A401500E31934A045404C1C7920B2D44A40EB3A5453929D45404C1C7920B2D44A40
54016	14709	42.999091999999997	43.015251999999997	53.804876999999998	53.777898999999998	Молодежная	0103000020E61000000100000005000000FDD8243FE27F4540A94BC63192E34A40FDD8243FE27F4540BB26A43506E74A406B990CC7F3814540BB26A43506E74A406B990CC7F3814540A94BC63192E34A40FDD8243FE27F4540A94BC63192E34A40
53630	3418	43.018675000000002	43.088222999999999	53.710616999999999	53.662416999999998	Школьная	0103000020E610000001000000050000005C2041F1638245403FA88B14CAD44A405C2041F163824540A67D737FF5DA4A40A4E029E44A8B4540A67D737FF5DA4A40A4E029E44A8B45403FA88B14CAD44A405C2041F1638245403FA88B14CAD44A40
54177	3418	43.018675000000002	43.088222999999999	53.710616999999999	53.662416999999998	Шаландина	0103000020E610000001000000050000005C2041F1638245403FA88B14CAD44A405C2041F163824540A67D737FF5DA4A40A4E029E44A8B4540A67D737FF5DA4A40A4E029E44A8B45403FA88B14CAD44A405C2041F1638245403FA88B14CAD44A40
53850	3418	43.018675000000002	43.088222999999999	53.710616999999999	53.662416999999998	Площадь Ленина	0103000020E610000001000000050000005C2041F1638245403FA88B14CAD44A405C2041F163824540A67D737FF5DA4A40A4E029E44A8B4540A67D737FF5DA4A40A4E029E44A8B45403FA88B14CAD44A405C2041F1638245403FA88B14CAD44A40
53720	3418	43.018675000000002	43.088222999999999	53.710616999999999	53.662416999999998	Молодёжная	0103000020E610000001000000050000005C2041F1638245403FA88B14CAD44A405C2041F163824540A67D737FF5DA4A40A4E029E44A8B4540A67D737FF5DA4A40A4E029E44A8B45403FA88B14CAD44A405C2041F1638245403FA88B14CAD44A40
53851	3418	43.018675000000002	43.088222999999999	53.710616999999999	53.662416999999998	Максютова	0103000020E610000001000000050000005C2041F1638245403FA88B14CAD44A405C2041F163824540A67D737FF5DA4A40A4E029E44A8B4540A67D737FF5DA4A40A4E029E44A8B45403FA88B14CAD44A405C2041F1638245403FA88B14CAD44A40
54089	3418	43.018675000000002	43.088222999999999	53.710616999999999	53.662416999999998	Дорожная	0103000020E610000001000000050000005C2041F1638245403FA88B14CAD44A405C2041F163824540A67D737FF5DA4A40A4E029E44A8B4540A67D737FF5DA4A40A4E029E44A8B45403FA88B14CAD44A405C2041F1638245403FA88B14CAD44A40
53849	13905	42.879257000000003	42.917335999999999	53.722372	53.694077	Советская	0103000020E61000000100000005000000B9E34D7E8B704540F1F3DF83D7D84A40B9E34D7E8B704540E7C589AF76DC4A40C3B81B446B754540E7C589AF76DC4A40C3B81B446B754540F1F3DF83D7D84A40B9E34D7E8B704540F1F3DF83D7D84A40
67061	58938	44.724333000000001	45.472306000000003	53.606757999999999	53.035533999999998	Нефтяников	0103000020E61000000100000005000000F03499F1B65C4640B2F2CB608C844A40F03499F1B65C46400E4B033FAACD4A4030DAE38574BC46400E4B033FAACD4A4030DAE38574BC4640B2F2CB608C844A40F03499F1B65C4640B2F2CB608C844A40
53756	13005	44.937601999999998	44.980927999999999	53.413888	53.395609999999998	Центральная	0103000020E610000001000000050000000455A357037846403BFC3559A3B24A400455A357037846407A1A3048FAB44A4087DD770C8F7D46407A1A3048FAB44A4087DD770C8F7D46403BFC3559A3B24A400455A357037846403BFC3559A3B24A40
53343	13763	45.220886	45.277408000000001	53.256836999999997	53.208440000000003	Спортивная	0103000020E61000000100000005000000771211FE459C4640D1967329AE9A4A40771211FE459C46408DB3E908E0A04A400BD3F71A82A346408DB3E908E0A04A400BD3F71A82A34640D1967329AE9A4A40771211FE459C4640D1967329AE9A4A40
53279	13763	45.220886	45.277408000000001	53.256836999999997	53.208440000000003	Генералова	0103000020E61000000100000005000000771211FE459C4640D1967329AE9A4A40771211FE459C46408DB3E908E0A04A400BD3F71A82A346408DB3E908E0A04A400BD3F71A82A34640D1967329AE9A4A40771211FE459C4640D1967329AE9A4A40
54085	13696	45.373491999999999	45.398986000000001	53.241207000000003	53.219295000000002	Совхозная	0103000020E61000000100000005000000A8A8FA95CEAF46409296CADB119C4A40A8A8FA95CEAF46407C48F8DEDF9E4A40EBC726F911B346407C48F8DEDF9E4A40EBC726F911B346409296CADB119C4A40A8A8FA95CEAF46409296CADB119C4A40
53764	13230	44.941428999999999	44.967813	53.337882	53.324857999999999	Колхозная	0103000020E61000000100000005000000C440D7BE8078464007EC6AF294A94A40C440D7BE807846401BF4A5B73FAB4A4063D2DF4BE17B46401BF4A5B73FAB4A4063D2DF4BE17B464007EC6AF294A94A40C440D7BE8078464007EC6AF294A94A40
53760	13629	45.393830000000001	45.449849	53.262250999999999	53.243023000000001	 Дорожная	0103000020E6100000010000000500000083177D0569B246408196AE601B9F4A4083177D0569B24640F12BD67091A14A40B491EBA694B94640F12BD67091A14A40B491EBA694B946408196AE601B9F4A4083177D0569B246408196AE601B9F4A40
54086	13419	45.284927000000003	45.326554999999999	53.295406	53.263919999999999	Заречная	0103000020E61000000100000005000000AB5FE97C78A4464052616C21C8A14A40AB5FE97C78A44640668522DDCFA54A4032ACE28DCCA94640668522DDCFA54A4032ACE28DCCA9464052616C21C8A14A40AB5FE97C78A4464052616C21C8A14A40
53292	13419	45.284927000000003	45.326554999999999	53.295406	53.263919999999999	Дорожная	0103000020E61000000100000005000000AB5FE97C78A4464052616C21C8A14A40AB5FE97C78A44640668522DDCFA54A4032ACE28DCCA94640668522DDCFA54A4032ACE28DCCA9464052616C21C8A14A40AB5FE97C78A4464052616C21C8A14A40
53715	13296	45.064174999999999	45.145724000000001	53.499491999999996	53.446733000000002	Центральная	0103000020E61000000100000005000000431CEBE236884640A185048C2EB94A40431CEBE2368846408B4E965AEFBF4A40041F8315A79246408B4E965AEFBF4A40041F8315A7924640A185048C2EB94A40431CEBE236884640A185048C2EB94A40
54186	13348	45.131072000000003	45.169089	53.539676	53.501483999999998	Школьная	0103000020E61000000100000005000000EEB5A0F7C6904640CFBBB1A030C04A40EEB5A0F7C6904640D237691A14C54A40828E56B5A4954640D237691A14C54A40828E56B5A4954640CFBBB1A030C04A40EEB5A0F7C6904640CFBBB1A030C04A40
53714	13631	45.36741	45.401986000000001	53.361006000000003	53.337629	Интернациональная	0103000020E61000000100000005000000971C774A07AF46403197546D37AB4A40971C774A07AF464074D4D17135AE4A4095B9F94674B3464074D4D17135AE4A4095B9F94674B346403197546D37AB4A40971C774A07AF46403197546D37AB4A40
53674	13570	45.31776	45.343533000000001	53.328848000000001	53.300626999999999	Завядя	0103000020E610000001000000050000000DFD135CACA84640B5A50EF27AA64A400DFD135CACA8464071ADF6B017AA4A40630CACE3F8AB464071ADF6B017AA4A40630CACE3F8AB4640B5A50EF27AA64A400DFD135CACA84640B5A50EF27AA64A40
53762	13844	45.227587	45.243442999999999	53.203418999999997	53.191001	Центральная	0103000020E6100000010000000500000054FF2092219D46406C4084B872984A4054FF2092219D4640483140A2099A4A4056B8E523299F4640483140A2099A4A4056B8E523299F46406C4084B872984A4054FF2092219D46406C4084B872984A40
53449	56426	45.219341	45.259369999999997	53.160685000000001	53.121279999999999	Школьная	0103000020E6100000010000000500000002D6AA5D139C464056D4601A868F4A4002D6AA5D139C464098FA795391944A4021C8410933A1464098FA795391944A4021C8410933A1464056D4601A868F4A4002D6AA5D139C464056D4601A868F4A40
53340	13061	45.273833000000003	45.306773999999997	53.230476000000003	53.197960000000002	Молодежная	0103000020E6100000010000000500000065C8B1F50CA3464045F5D6C056994A4065C8B1F50CA34640A741D13C809D4A40ADA1D45E44A74640A741D13C809D4A40ADA1D45E44A7464045F5D6C056994A4065C8B1F50CA3464045F5D6C056994A40
53423	13061	45.273833000000003	45.306773999999997	53.230476000000003	53.197960000000002	Большая Дорога	0103000020E6100000010000000500000065C8B1F50CA3464045F5D6C056994A4065C8B1F50CA34640A741D13C809D4A40ADA1D45E44A74640A741D13C809D4A40ADA1D45E44A7464045F5D6C056994A4065C8B1F50CA3464045F5D6C056994A40
53409	9271	45.308858000000001	45.340560000000004	53.097014999999999	53.051543000000002	Ленина	0103000020E61000000100000005000000D28DB0A888A746403BAB05F698864A40D28DB0A888A74640581CCEFC6A8C4A40B329577897AB4640581CCEFC6A8C4A40B329577897AB46403BAB05F698864A40D28DB0A888A746403BAB05F698864A40
53605	12688	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	Юбилейная	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
53602	12688	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	Центральная	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
53711	12688	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	Спиртзаводская	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
53259	12688	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	Советская	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
53603	12688	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	Ново-Западная	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
53712	12688	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	Лесная	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
53671	12688	45.038474000000001	45.085751999999999	53.408247000000003	53.348779	Западная Поляна	0103000020E6100000010000000500000087DF4DB7EC8446400B444FCAA4AC4A4087DF4DB7EC84464056D80C7041B44A4086C8E9EBF98A464056D80C7041B44A4086C8E9EBF98A46400B444FCAA4AC4A4087DF4DB7EC8446400B444FCAA4AC4A40
53460	12622	45.055677000000003	45.102424999999997	53.450363000000003	53.410409999999999	Новая	0103000020E61000000100000005000000D811876C20874640C6F99B5088B44A40D811876C208746400B2AAA7EA5B94A407AA52C431C8D46400B2AAA7EA5B94A407AA52C431C8D4640C6F99B5088B44A40D811876C20874640C6F99B5088B44A40
54165	12622	45.055677000000003	45.102424999999997	53.450363000000003	53.410409999999999	Ера	0103000020E61000000100000005000000D811876C20874640C6F99B5088B44A40D811876C208746400B2AAA7EA5B94A407AA52C431C8D46400B2AAA7EA5B94A407AA52C431C8D4640C6F99B5088B44A40D811876C20874640C6F99B5088B44A40
53759	13201	44.882868000000002	44.913195000000002	53.338016000000003	53.322760000000002	Молодежная	0103000020E61000000100000005000000AC5791D1017146407E3A1E3350A94A40AC5791D1017146402BC3B81B44AB4A4074EFE192E37446402BC3B81B44AB4A4074EFE192E37446407E3A1E3350A94A40AC5791D1017146407E3A1E3350A94A40
53430	12290	45.033856999999998	45.049793000000001	53.338591999999998	53.334107000000003	Центральная	0103000020E61000000100000005000000CEDE196D55844640AE2EA704C4AA4A40CEDE196D55844640F7578FFB56AB4A40ED48F59D5F864640F7578FFB56AB4A40ED48F59D5F864640AE2EA704C4AA4A40CEDE196D55844640AE2EA704C4AA4A40
53422	12290	45.033856999999998	45.049793000000001	53.338591999999998	53.334107000000003	Сурская	0103000020E61000000100000005000000CEDE196D55844640AE2EA704C4AA4A40CEDE196D55844640F7578FFB56AB4A40ED48F59D5F864640F7578FFB56AB4A40ED48F59D5F864640AE2EA704C4AA4A40CEDE196D55844640AE2EA704C4AA4A40
53338	12290	45.033856999999998	45.049793000000001	53.338591999999998	53.334107000000003	Садовая	0103000020E61000000100000005000000CEDE196D55844640AE2EA704C4AA4A40CEDE196D55844640F7578FFB56AB4A40ED48F59D5F864640F7578FFB56AB4A40ED48F59D5F864640AE2EA704C4AA4A40CEDE196D55844640AE2EA704C4AA4A40
53439	12290	45.033856999999998	45.049793000000001	53.338591999999998	53.334107000000003	Комсомольская	0103000020E61000000100000005000000CEDE196D55844640AE2EA704C4AA4A40CEDE196D55844640F7578FFB56AB4A40ED48F59D5F864640F7578FFB56AB4A40ED48F59D5F864640AE2EA704C4AA4A40CEDE196D55844640AE2EA704C4AA4A40
53276	12290	45.033856999999998	45.049793000000001	53.338591999999998	53.334107000000003	Кирова	0103000020E61000000100000005000000CEDE196D55844640AE2EA704C4AA4A40CEDE196D55844640F7578FFB56AB4A40ED48F59D5F864640F7578FFB56AB4A40ED48F59D5F864640AE2EA704C4AA4A40CEDE196D55844640AE2EA704C4AA4A40
53455	12290	45.033856999999998	45.049793000000001	53.338591999999998	53.334107000000003	Жилгородок	0103000020E61000000100000005000000CEDE196D55844640AE2EA704C4AA4A40CEDE196D55844640F7578FFB56AB4A40ED48F59D5F864640F7578FFB56AB4A40ED48F59D5F864640AE2EA704C4AA4A40CEDE196D55844640AE2EA704C4AA4A40
54000	47894	43.538117	43.558633999999998	52.961925999999998	52.948087000000001	Центральная	0103000020E61000000100000005000000F8359204E1C44540A26131EA5A794A40F8359204E1C4454007962364207B4A408237A45181C7454007962364207B4A408237A45181C74540A26131EA5A794A40F8359204E1C44540A26131EA5A794A40
53604	48070	42.975788999999999	43.014228000000003	52.980223000000002	52.968764999999998	Центральная	0103000020E61000000100000005000000F56569A7E67C45403541D47D007C4A40F56569A7E67C4540BDE47FF2777D4A4000581D39D2814540BDE47FF2777D4A4000581D39D28145403541D47D007C4A40F56569A7E67C45403541D47D007C4A40
53806	56454	43.117668999999999	43.146101000000002	53.087978	53.073042999999998	Центральная	0103000020E6100000010000000500000063601DC70F8F4540D219187959894A4063601DC70F8F45403D62F4DC428B4A40DA740470B39245403D62F4DC428B4A40DA740470B3924540D219187959894A4063601DC70F8F4540D219187959894A40
53402	56425	43.30292	43.307977000000001	52.919004999999999	52.916665000000002	Ленинская	0103000020E61000000100000005000000F4A62215C6A64540A5315A4755754A40F4A62215C6A6454024EEB1F4A1754A40C97553CA6BA7454024EEB1F4A1754A40C97553CA6BA74540A5315A4755754A40F4A62215C6A64540A5315A4755754A40
53844	11037	43.350315000000002	43.373832999999998	52.974243000000001	52.961844999999997	Библиотечная	0103000020E610000001000000050000002D26361FD7AC45401A69A9BC1D7B4A402D26361FD7AC4540B0AD9FFEB37C4A4031957EC2D9AF4540B0AD9FFEB37C4A4031957EC2D9AF45401A69A9BC1D7B4A402D26361FD7AC45401A69A9BC1D7B4A40
53827	11105	43.526573999999997	43.541691999999998	53.100475000000003	53.072443	Садовая	0103000020E610000001000000050000004276DEC666C345407DE9EDCF45894A404276DEC666C345406688635DDC8C4A409E40D82956C545406688635DDC8C4A409E40D82956C545407DE9EDCF45894A404276DEC666C345407DE9EDCF45894A40
53748	7395	43.096487000000003	43.134180000000001	53.010055000000001	52.985179000000002	Центральная	0103000020E610000001000000050000009DBE9EAF598C45405EDA70581A7E4A409DBE9EAF598C4540A514747B49814A407EE36BCF2C914540A514747B49814A407EE36BCF2C9145405EDA70581A7E4A409DBE9EAF598C45405EDA70581A7E4A40
53908	7395	43.096487000000003	43.134180000000001	53.010055000000001	52.985179000000002	Октябрьская	0103000020E610000001000000050000009DBE9EAF598C45405EDA70581A7E4A409DBE9EAF598C4540A514747B49814A407EE36BCF2C914540A514747B49814A407EE36BCF2C9145405EDA70581A7E4A409DBE9EAF598C45405EDA70581A7E4A40
54170	10894	43.656129	43.671731999999999	52.883116000000001	52.865864999999999	 Поселковая	0103000020E61000000100000005000000857AFA08FCD3454022E010AAD46E4A40857AFA08FCD345408449F1F109714A409DD66D50FBD545408449F1F109714A409DD66D50FBD5454022E010AAD46E4A40857AFA08FCD3454022E010AAD46E4A40
54172	12073	43.044187000000001	43.100521000000001	52.990670000000001	52.973987999999999	Нагорная	0103000020E6100000010000000500000045F46BEBA7854540255987A3AB7C4A4045F46BEBA78545406D904946CE7E4A40D6C743DFDD8C45406D904946CE7E4A40D6C743DFDD8C4540255987A3AB7C4A4045F46BEBA7854540255987A3AB7C4A40
53740	47606	43.731048000000001	43.776485000000001	52.854235000000003	52.836433999999997	Школьная	0103000020E6100000010000000500000032E719FB92DD454098A1F144106B4A4032E719FB92DD45409E0C8E92576D4A40D36A48DC63E345409E0C8E92576D4A40D36A48DC63E3454098A1F144106B4A4032E719FB92DD454098A1F144106B4A40
54169	11349	43.26202	43.284001000000004	52.956333000000001	52.944271999999998	Сокоровка	0103000020E61000000100000005000000EF7211DF89A14540A643A7E7DD784A40EF7211DF89A14540F48AA71E697A4A4002840F255AA44540F48AA71E697A4A4002840F255AA44540A643A7E7DD784A40EF7211DF89A14540A643A7E7DD784A40
53420	11907	43.349111000000001	43.412298999999997	52.937071000000003	52.925753	Пригородная	0103000020E6100000010000000500000041D653ABAFAC4540429605137F764A4041D653ABAFAC4540D88349F1F1774A403596B036C6B44540D88349F1F1774A403596B036C6B44540429605137F764A4041D653ABAFAC4540429605137F764A40
53454	11788	43.161687000000001	43.208848000000003	53.039881999999999	53.014843999999997	 Московская	0103000020E610000001000000050000001C98DC28B29445405A457F68E6814A401C98DC28B29445407BD976DA1A854A40E2EA0088BB9A45407BD976DA1A854A40E2EA0088BB9A45405A457F68E6814A401C98DC28B29445405A457F68E6814A40
53758	56449	43.285663	43.380274	53.125824999999999	53.089070999999997	 Сельская	0103000020E61000000100000005000000B056ED9A90A44540D102B4AD668B4A40B056ED9A90A4454075029A081B904A4072C284D1ACB0454075029A081B904A4072C284D1ACB04540D102B4AD668B4A40B056ED9A90A44540D102B4AD668B4A40
54027	56422	43.136920000000003	43.158219000000003	52.907156000000001	52.894444999999997	Садовая	0103000020E610000001000000050000008C153598869145400D897B2C7D724A408C15359886914540622F14B01D744A408C4D2B8540944540622F14B01D744A408C4D2B85409445400D897B2C7D724A408C153598869145400D897B2C7D724A40
53387	56422	43.136920000000003	43.158219000000003	52.907156000000001	52.894444999999997	Пионерская	0103000020E610000001000000050000008C153598869145400D897B2C7D724A408C15359886914540622F14B01D744A408C4D2B8540944540622F14B01D744A408C4D2B85409445400D897B2C7D724A408C153598869145400D897B2C7D724A40
53274	47825	43.644756000000001	43.678119000000002	52.997407000000003	52.985275999999999	Центральная	0103000020E610000001000000050000002CF3565D87D2454050C422861D7E4A402CF3565D87D2454097E65608AB7F4A40EBE5779ACCD6454097E65608AB7F4A40EBE5779ACCD6454050C422861D7E4A402CF3565D87D2454050C422861D7E4A40
67020	58918	42.827046000000003	43.875200999999997	53.188195	52.723095000000001	Молодежная	0103000020E61000000100000005000000D124B1A4DC694540587380608E5C4A40D124B1A4DC694540A72215C616984A4097361C9606F04540A72215C616984A4097361C9606F04540587380608E5C4A40D124B1A4DC694540587380608E5C4A40
53709	11945	43.296990999999998	43.336562000000001	52.915393999999999	52.903950999999999	Центральная	0103000020E61000000100000005000000691A14CD03A64540DF1797AAB4734A40691A14CD03A64540317A6EA12B754A40C689AF7614AB4540317A6EA12B754A40C689AF7614AB4540DF1797AAB4734A40691A14CD03A64540DF1797AAB4734A40
53847	47893	43.581892000000003	43.610773000000002	52.983454999999999	52.969807000000003	Центральная	0103000020E61000000100000005000000EBE6E26F7BCA45404837C2A2227C4A40EBE6E26F7BCA4540390B7BDAE17D4A40D12346CF2DCE4540390B7BDAE17D4A40D12346CF2DCE45404837C2A2227C4A40EBE6E26F7BCA45404837C2A2227C4A40
53669	11315	43.198687999999997	43.233812999999998	53.004370999999999	52.978634999999997	Мостовая	0103000020E61000000100000005000000C70DBF9B6E99454048DC63E9437D4A40C70DBF9B6E99454081069B3A8F804A4098309A95ED9D454081069B3A8F804A4098309A95ED9D454048DC63E9437D4A40C70DBF9B6E99454048DC63E9437D4A40
53611	56432	43.200215999999998	43.2258	52.940707000000003	52.927604000000002	Дружная	0103000020E6100000010000000500000066118AADA0994540C4D155BABB764A4066118AADA0994540240F441669784A40E9B7AF03E79C4540240F441669784A40E9B7AF03E79C4540C4D155BABB764A4066118AADA0994540C4D155BABB764A40
53855	56460	43.482430000000001	43.497332999999998	53.020516000000001	53.005059000000003	Пролетарка	0103000020E61000000100000005000000FD4D2844C0BD454076C6F7C5A5804A40FD4D2844C0BD4540BA85AE44A0824A405C1C959BA8BF4540BA85AE44A0824A405C1C959BA8BF454076C6F7C5A5804A40FD4D2844C0BD454076C6F7C5A5804A40
53848	11081	43.444971000000002	43.500180999999998	53.136771000000003	53.114130000000003	Даманская	0103000020E610000001000000050000008F554ACFF4B845400ABFD4CF9B8E4A408F554ACFF4B8454047054EB681914A40508A56EE05C0454047054EB681914A40508A56EE05C045400ABFD4CF9B8E4A408F554ACFF4B845400ABFD4CF9B8E4A40
53666	47699	43.419134999999997	43.459055999999997	52.933689000000001	52.913037000000003	Мира	0103000020E61000000100000005000000F2CD3637A6B54540DC847B65DE744A40F2CD3637A6B5454046D1031F83774A402B84D558C2BA454046D1031F83774A402B84D558C2BA4540DC847B65DE744A40F2CD3637A6B54540DC847B65DE744A40
54174	11531	43.760396	43.782504000000003	53.069099000000001	53.056328000000001	Школьная	0103000020E610000001000000050000002E01F8A754E14540AFEC82C135874A402E01F8A754E14540D9976C3CD8884A409E7E501729E44540D9976C3CD8884A409E7E501729E44540AFEC82C135874A402E01F8A754E14540AFEC82C135874A40
53707	47633	43.428882000000002	43.469062999999998	52.979356000000003	52.957059999999998	Взлётная	0103000020E61000000100000005000000EAEBF99AE5B64540A6272CF1807A4A40EAEBF99AE5B64540199293895B7D4A40BF61A2410ABC4540199293895B7D4A40BF61A2410ABC4540A6272CF1807A4A40EAEBF99AE5B64540A6272CF1807A4A40
53693	11218	43.526474999999998	43.567473999999997	52.902811	52.887169999999998	Молодёжная	0103000020E61000000100000005000000AF94658863C3454004FF5BC98E714A40AF94658863C345400ABC934F8F734A4047AAEFFCA2C845400ABC934F8F734A4047AAEFFCA2C8454004FF5BC98E714A40AF94658863C3454004FF5BC98E714A40
53336	10730	43.380381999999997	43.434531999999997	52.975012999999997	52.954689999999999	Ленина	0103000020E6100000010000000500000058FE7C5BB0B04540BCE82B48337A4A4058FE7C5BB0B045406116DA39CD7C4A4061889CBE9EB745406116DA39CD7C4A4061889CBE9EB74540BCE82B48337A4A4058FE7C5BB0B04540BCE82B48337A4A40
53272	10730	43.380381999999997	43.434531999999997	52.975012999999997	52.954689999999999	Белинская	0103000020E6100000010000000500000058FE7C5BB0B04540BCE82B48337A4A4058FE7C5BB0B045406116DA39CD7C4A4061889CBE9EB745406116DA39CD7C4A4061889CBE9EB74540BCE82B48337A4A4058FE7C5BB0B04540BCE82B48337A4A40
54080	10834	43.592410999999998	43.644064	52.881388000000001	52.867001000000002	Центральная	0103000020E610000001000000050000003465A71FD4CB4540B64C86E3F96E4A403465A71FD4CB45401E8B6D52D1704A40F6436CB070D245401E8B6D52D1704A40F6436CB070D24540B64C86E3F96E4A403465A71FD4CB4540B64C86E3F96E4A40
53990	10175	43.739465000000003	43.772362000000001	52.728397000000001	52.708263000000002	Центральная	0103000020E61000000100000005000000B1C403CAA6DE4540C2FBAA5CA85A4A40B1C403CAA6DE454094C0E61C3C5D4A402A560DC2DCE2454094C0E61C3C5D4A402A560DC2DCE24540C2FBAA5CA85A4A40B1C403CAA6DE4540C2FBAA5CA85A4A40
53803	10489	43.472467999999999	43.536256999999999	52.434032999999999	52.410671000000001	Центральная усадьба	0103000020E610000001000000050000000934D8D479BC4540333509DE90344A400934D8D479BC45404031B2648E374A4023A0C211A4C445404031B2648E374A4023A0C211A4C44540333509DE90344A400934D8D479BC4540333509DE90344A40
54175	10489	43.472467999999999	43.536256999999999	52.434032999999999	52.410671000000001	Комсомольская	0103000020E610000001000000050000000934D8D479BC4540333509DE90344A400934D8D479BC45404031B2648E374A4023A0C211A4C445404031B2648E374A4023A0C211A4C44540333509DE90344A400934D8D479BC4540333509DE90344A40
54001	10489	43.472467999999999	43.536256999999999	52.434032999999999	52.410671000000001	 Почтовая	0103000020E610000001000000050000000934D8D479BC4540333509DE90344A400934D8D479BC45404031B2648E374A4023A0C211A4C445404031B2648E374A4023A0C211A4C44540333509DE90344A400934D8D479BC4540333509DE90344A40
53335	10666	43.584783999999999	43.626232999999999	52.442076	52.420689000000003	Огородная	0103000020E61000000100000005000000AE9CBD33DACA4540BB641C23D9354A40AE9CBD33DACA45405A2C45F295384A408656276728D045405A2C45F295384A408656276728D04540BB641C23D9354A40AE9CBD33DACA4540BB641C23D9354A40
54154	16392	43.577176000000001	43.584578	52.673127999999998	52.667017000000001	Молодежная	0103000020E610000001000000050000009F0436E7E0C94540227024D060554A409F0436E7E0C94540CD02ED0E29564A4005FBAF73D3CA4540CD02ED0E29564A4005FBAF73D3CA4540227024D060554A409F0436E7E0C94540227024D060554A40
53668	10118	43.867438999999997	43.893040999999997	52.625785999999998	52.604182999999999	Садовая	0103000020E610000001000000050000003123BC3D08EF45404BE658DE554D4A403123BC3D08EF4540B72572C119504A405A7EE02A4FF24540B72572C119504A405A7EE02A4FF245404BE658DE554D4A403123BC3D08EF45404BE658DE554D4A40
53601	56431	43.719144999999997	43.743921	52.502282000000001	52.490813000000003	Спортивная	0103000020E610000001000000050000007C0A80F10CDC4540D0B9DBF5D23E4A407C0A80F10CDC45404BAFCDC64A404A4060E7A6CD38DF45404BAFCDC64A404A4060E7A6CD38DF4540D0B9DBF5D23E4A407C0A80F10CDC4540D0B9DBF5D23E4A40
54069	10073	43.789178	43.846356	52.627743000000002	52.605232999999998	Красная	0103000020E61000000100000005000000815CE2C803E54540E0BA6246784D4A40815CE2C803E545407FA5F3E159504A40FE62B66455EC45407FA5F3E159504A40FE62B66455EC4540E0BA6246784D4A40815CE2C803E54540E0BA6246784D4A40
53599	9897	43.807189000000001	43.837947999999997	52.554904999999998	52.534838999999998	Садовая	0103000020E6100000010000000500000071581AF851E745400BD0B69A75444A4071581AF851E7454085B1852007474A40D2DF4BE141EB454085B1852007474A40D2DF4BE141EB45400BD0B69A75444A4071581AF851E745400BD0B69A75444A40
54079	10329	43.557844000000003	43.597665999999997	52.553514	52.521399000000002	Школьная	0103000020E610000001000000050000008A22A46E67C745406495D233BD424A408A22A46E67C7454067F0F78BD9464A402FF7C95180CC454067F0F78BD9464A402FF7C95180CC45406495D233BD424A408A22A46E67C745406495D233BD424A40
53997	10207	43.641423000000003	43.674804999999999	52.695532	52.681852999999997	Почтовая	0103000020E610000001000000050000007CF31B261AD24540F9D687F546574A407CF31B261AD2454026A94C3107594A40B1169F0260D6454026A94C3107594A40B1169F0260D64540F9D687F546574A407CF31B261AD24540F9D687F546574A40
53647	56437	43.476393999999999	43.488269000000003	52.579411	52.575640999999997	Школьная	0103000020E610000001000000050000005C01857AFABC45404D9EB29AAE494A405C01857AFABC4540A9F8BF232A4A4A4048533D997FBE4540A9F8BF232A4A4A4048533D997FBE45404D9EB29AAE494A405C01857AFABC45404D9EB29AAE494A40
54077	10030	43.781362999999999	43.807907999999998	52.652067000000002	52.631749999999997	Центральная	0103000020E61000000100000005000000F8A6E9B303E44540BE9F1A2FDD504A40F8A6E9B303E4454082E673EE76534A40A016838769E7454082E673EE76534A40A016838769E74540BE9F1A2FDD504A40F8A6E9B303E44540BE9F1A2FDD504A40
53842	10348	43.601267999999997	43.621040000000001	52.589123999999998	52.581353999999997	Школьная	0103000020E61000000100000005000000CF108E59F6CC45400BB3D0CE694A4A40CF108E59F6CC4540F4A44C6A684B4A4001C11C3D7ECF4540F4A44C6A684B4A4001C11C3D7ECF45400BB3D0CE694A4A40CF108E59F6CC45400BB3D0CE694A4A40
53987	9870	43.770879000000001	43.794927000000001	52.528976999999998	52.502665999999998	Шоссейная	0103000020E610000001000000050000002B16BF29ACE24540D367075C57404A402B16BF29ACE2454008ABB184B5434A408CDAFD2AC0E5454008ABB184B5434A408CDAFD2AC0E54540D367075C57404A402B16BF29ACE24540D367075C57404A40
53429	10602	43.542149999999999	43.613629000000003	52.455024000000002	52.432935000000001	Школьная	0103000020E6100000010000000500000061C3D32B65C545409A25016A6A374A4061C3D32B65C545409372F7393E3A4A40487023658BCE45409372F7393E3A4A40487023658BCE45409A25016A6A374A4061C3D32B65C545409A25016A6A374A40
53739	9568	43.640112000000002	43.724392000000002	52.482717999999998	52.434632000000001	Подбеково	0103000020E610000001000000050000007AE3A430EFD14540C5E57805A2374A407AE3A430EFD14540639813B4C93D4A40F5BD86E0B8DC4540639813B4C93D4A40F5BD86E0B8DC4540C5E57805A2374A407AE3A430EFD14540C5E57805A2374A40
53337	9568	43.640112000000002	43.724392000000002	52.482717999999998	52.434632000000001	Первомайская	0103000020E610000001000000050000007AE3A430EFD14540C5E57805A2374A407AE3A430EFD14540639813B4C93D4A40F5BD86E0B8DC4540639813B4C93D4A40F5BD86E0B8DC4540C5E57805A2374A407AE3A430EFD14540C5E57805A2374A40
53419	9568	43.640112000000002	43.724392000000002	52.482717999999998	52.434632000000001	Базарная	0103000020E610000001000000050000007AE3A430EFD14540C5E57805A2374A407AE3A430EFD14540639813B4C93D4A40F5BD86E0B8DC4540639813B4C93D4A40F5BD86E0B8DC4540C5E57805A2374A407AE3A430EFD14540C5E57805A2374A40
53686	9568	43.640112000000002	43.724392000000002	52.482717999999998	52.434632000000001	2-я Октябрьская	0103000020E610000001000000050000007AE3A430EFD14540C5E57805A2374A407AE3A430EFD14540639813B4C93D4A40F5BD86E0B8DC4540639813B4C93D4A40F5BD86E0B8DC4540C5E57805A2374A407AE3A430EFD14540C5E57805A2374A40
53958	10258	43.585780999999997	43.604413000000001	52.684435000000001	52.676344	Молодежная	0103000020E6100000010000000500000020CF2EDFFACA4540446CB07092564A4020CF2EDFFACA45406F9EEA909B574A407D23BA675DCD45406F9EEA909B574A407D23BA675DCD4540446CB07092564A4020CF2EDFFACA4540446CB07092564A40
53923	14905	43.259199000000002	43.279833000000004	53.820056000000001	53.810864000000002	Цепаево	0103000020E61000000100000005000000F513CE6E2DA145407BC03C64CAE74A40F513CE6E2DA14540BD715298F7E84A40B9AB5791D1A34540BD715298F7E84A40B9AB5791D1A345407BC03C64CAE74A40F513CE6E2DA145407BC03C64CAE74A40
53925	15332	43.240729999999999	43.265127999999997	53.996640999999997	53.988151000000002	Школьная	0103000020E6100000010000000500000042959A3DD09E45403E4162BB7BFE4A4042959A3DD09E4540266DAAEE91FF4A407FA0DCB6EFA14540266DAAEE91FF4A407FA0DCB6EFA145403E4162BB7BFE4A4042959A3DD09E45403E4162BB7BFE4A40
53927	15351	43.166573999999997	43.205793999999997	53.943117000000001	53.909885000000003	Совхозная	0103000020E61000000100000005000000942EFD4B529545407C0F971C77F44A40942EFD4B529545409CA6CF0EB8F84A4044DB3175579A45409CA6CF0EB8F84A4044DB3175579A45407C0F971C77F44A40942EFD4B529545407C0F971C77F44A40
53488	15351	43.166573999999997	43.205793999999997	53.943117000000001	53.909885000000003	Советская площадь	0103000020E61000000100000005000000942EFD4B529545407C0F971C77F44A40942EFD4B529545409CA6CF0EB8F84A4044DB3175579A45409CA6CF0EB8F84A4044DB3175579A45407C0F971C77F44A40942EFD4B529545407C0F971C77F44A40
53780	15351	43.166573999999997	43.205793999999997	53.943117000000001	53.909885000000003	Ленина	0103000020E61000000100000005000000942EFD4B529545407C0F971C77F44A40942EFD4B529545409CA6CF0EB8F84A4044DB3175579A45409CA6CF0EB8F84A4044DB3175579A45407C0F971C77F44A40942EFD4B529545407C0F971C77F44A40
53411	15351	43.166573999999997	43.205793999999997	53.943117000000001	53.909885000000003	Красная	0103000020E61000000100000005000000942EFD4B529545407C0F971C77F44A40942EFD4B529545409CA6CF0EB8F84A4044DB3175579A45409CA6CF0EB8F84A4044DB3175579A45407C0F971C77F44A40942EFD4B529545407C0F971C77F44A40
53368	15351	43.166573999999997	43.205793999999997	53.943117000000001	53.909885000000003	Коммунальная	0103000020E61000000100000005000000942EFD4B529545407C0F971C77F44A40942EFD4B529545409CA6CF0EB8F84A4044DB3175579A45409CA6CF0EB8F84A4044DB3175579A45407C0F971C77F44A40942EFD4B529545407C0F971C77F44A40
54150	15212	43.137081999999999	43.154086999999997	53.789352999999998	53.780197999999999	Садовая	0103000020E61000000100000005000000656F29E78B914540CA332F87DDE34A40656F29E78B914540EFFFE38409E54A408FDE701FB9934540EFFFE38409E54A408FDE701FB9934540CA332F87DDE34A40656F29E78B914540CA332F87DDE34A40
54317	56529	43.045571000000002	43.604394999999997	54.025922000000001	53.677599000000001	Калинина	0103000020E61000000100000005000000B1524145D5854540B2666490BBD64A40B1524145D58545409B1F7F6951034B40D66EBBD05CCD45409B1F7F6951034B40D66EBBD05CCD4540B2666490BBD64A40B1524145D5854540B2666490BBD64A40
53926	15132	43.302408	43.325800000000001	53.737468	53.71593	 Совхозная	0103000020E610000001000000050000003E062B4EB5A64540D61C2098A3DB4A403E062B4EB5A645405BECF65965DE4A40B6847CD0B3A945405BECF65965DE4A40B6847CD0B3A94540D61C2098A3DB4A403E062B4EB5A64540D61C2098A3DB4A40
53921	14513	43.148589000000001	43.168595000000003	53.956147000000001	53.930422	Школьная	0103000020E61000000100000005000000CEC5DFF6049345404DBD6E1118F74A40CEC5DFF60493454092955F0663FA4A4073A25D859495454092955F0663FA4A4073A25D85949545404DBD6E1118F74A40CEC5DFF6049345404DBD6E1118F74A40
54066	14513	43.148589000000001	43.168595000000003	53.956147000000001	53.930422	Центральная	0103000020E61000000100000005000000CEC5DFF6049345404DBD6E1118F74A40CEC5DFF60493454092955F0663FA4A4073A25D859495454092955F0663FA4A4073A25D85949545404DBD6E1118F74A40CEC5DFF6049345404DBD6E1118F74A40
54248	14850	43.343569000000002	43.366627999999999	53.825929000000002	53.821261999999997	Красный Восток	0103000020E61000000100000005000000B075A911FAAB454049B9FB1C1FE94A40B075A911FAAB4540B4E89D0AB8E94A4021E692AAEDAE4540B4E89D0AB8E94A4021E692AAEDAE454049B9FB1C1FE94A40B075A911FAAB454049B9FB1C1FE94A40
53924	15046	43.254078999999997	43.268622000000001	53.926388000000003	53.906086999999999	Рабочая	0103000020E61000000100000005000000D9CC21A985A04540562AA8A8FAF34A40D9CC21A985A0454014B4C9E193F64A40397EA83462A2454014B4C9E193F64A40397EA83462A24540562AA8A8FAF34A40D9CC21A985A04540562AA8A8FAF34A40
54197	14989	43.374578999999997	43.394261	53.721764	53.710436000000001	Сельская	0103000020E610000001000000050000005A626534F2AF454056F31C91EFDA4A405A626534F2AF45400FB743C362DC4A404C8BFA2477B245400FB743C362DC4A404C8BFA2477B2454056F31C91EFDA4A405A626534F2AF454056F31C91EFDA4A40
54273	14989	43.374578999999997	43.394261	53.721764	53.710436000000001	Новая	0103000020E610000001000000050000005A626534F2AF454056F31C91EFDA4A405A626534F2AF45400FB743C362DC4A404C8BFA2477B245400FB743C362DC4A404C8BFA2477B2454056F31C91EFDA4A405A626534F2AF454056F31C91EFDA4A40
54110	22609	43.282555000000002	43.339903999999997	53.832673	53.808971999999997	Молодежная	0103000020E61000000100000005000000202922C32AA445409AB0FD648CE74A40202922C32AA4454090A1630795EA4A40C9E369F981AB454090A1630795EA4A40C9E369F981AB45409AB0FD648CE74A40202922C32AA445409AB0FD648CE74A40
54245	14612	43.178629000000001	43.196055999999999	53.870860999999998	53.848785999999997	Московская	0103000020E61000000100000005000000008FA850DD964540BDA60705A5EC4A40008FA850DD964540512E8D5F78EF4A40A017EE5C18994540512E8D5F78EF4A40A017EE5C18994540BDA60705A5EC4A40008FA850DD964540BDA60705A5EC4A40
54149	7677	43.340083	43.360726999999997	53.784773000000001	53.767719	Школьная	0103000020E610000001000000050000007976F9D687AB454048C2BE9D44E24A407976F9D687AB454054E4107173E44A4060E4654D2CAE454054E4107173E44A4060E4654D2CAE454048C2BE9D44E24A407976F9D687AB454048C2BE9D44E24A40
53955	15187	43.234271	43.255479999999999	53.733569000000003	53.715412999999998	Новая	0103000020E610000001000000050000005BB39597FC9D45400E1137A792DB4A405BB39597FC9D4540022EC896E5DD4A401B649291B3A04540022EC896E5DD4A401B649291B3A045400E1137A792DB4A405BB39597FC9D45400E1137A792DB4A40
54065	14701	43.332447999999999	43.359146000000003	53.800601999999998	53.793751999999998	Центральная	0103000020E6100000010000000500000070CFF3A78DAA45403A9160AA99E54A4070CFF3A78DAA45405C8E57207AE64A409F3E027FF8AD45405C8E57207AE64A409F3E027FF8AD45403A9160AA99E54A4070CFF3A78DAA45403A9160AA99E54A40
54075	14461	43.332788999999998	43.363188000000001	53.943626000000002	53.924919000000003	Центральная	0103000020E61000000100000005000000F9BB77D498AA45407A39ECBE63F64A40F9BB77D498AA4540E1D39CBCC8F84A405B26C3F17CAE4540E1D39CBCC8F84A405B26C3F17CAE45407A39ECBE63F64A40F9BB77D498AA45407A39ECBE63F64A40
54280	56518	43.055945999999999	43.083129	53.185912999999999	53.16075	Школьная	0103000020E61000000100000005000000C72B103D298745407F6ABC7493944A40C72B103D298745405C7347FFCB974A40B22C98F8A38A45405C7347FFCB974A40B22C98F8A38A45407F6ABC7493944A40C72B103D298745407F6ABC7493944A40
53823	46225	42.561100000000003	42.587770999999996	53.305157999999999	53.284495999999997	Запрудная	0103000020E610000001000000050000008FE4F21FD2474540E1EB6B5D6AA44A408FE4F21FD24745406F0ED76A0FA74A40C34483143C4B45406F0ED76A0FA74A40C34483143C4B4540E1EB6B5D6AA44A408FE4F21FD2474540E1EB6B5D6AA44A40
54052	56485	42.778942000000001	42.817605	53.280662	53.258383000000002	Школьная	0103000020E610000001000000050000008CBD175FB4634540D36BB3B112A14A408CBD175FB46345406F9D7FBBECA34A40E605D847A76845406F9D7FBBECA34A40E605D847A7684540D36BB3B112A14A408CBD175FB4634540D36BB3B112A14A40
53418	46936	42.847051999999998	42.876472	53.293059999999997	53.275078999999998	Советская	0103000020E6100000010000000500000075012F336C6C45407F68E6C935A34A4075012F336C6C454004E275FD82A54A400BEE073C3070454004E275FD82A54A400BEE073C307045407F68E6C935A34A4075012F336C6C45407F68E6C935A34A40
54114	56494	42.890126000000002	42.900905999999999	53.306072	53.298834999999997	1-ая Заводская	0103000020E61000000100000005000000DFA815A6EF71454038F3AB3940A64A40DFA815A6EF714540541C075E2DA74A40956247E350734540541C075E2DA74A40956247E35073454038F3AB3940A64A40DFA815A6EF71454038F3AB3940A64A40
53273	9190	42.649377999999999	42.680585000000001	53.250841000000001	53.224254999999999	Красноармейская	0103000020E61000000100000005000000F65E7CD11E534540747B4963B49C4A40F65E7CD11E5345407BBFD18E1BA04A40F792C6681D5745407BBFD18E1BA04A40F792C6681D574540747B4963B49C4A40F65E7CD11E534540747B4963B49C4A40
53839	9165	42.629471000000002	42.653950000000002	53.173079999999999	53.155819999999999	Молодежная	0103000020E61000000100000005000000E5637781925045400708E6E8F1934A40E563778192504540BCCB457C27964A400F9C33A2B4534540BCCB457C27964A400F9C33A2B45345400708E6E8F1934A40E5637781925045400708E6E8F1934A40
53830	46822	42.781303999999999	42.799737999999998	53.219380999999998	53.182535000000001	Школьная	0103000020E61000000100000005000000F31DFCC4016445400CB08F4E5D974A40F31DFCC401644540902E36AD149C4A4029AF95D05D664540902E36AD149C4A4029AF95D05D6645400CB08F4E5D974A40F31DFCC4016445400CB08F4E5D974A40
53966	46880	42.736477999999998	42.776049	53.104443000000003	53.080329999999996	Красная	0103000020E610000001000000050000009B1C3EE9445E45409F71E140488A4A409B1C3EE9445E4540E8A562635E8D4A40F88BD99255634540E8A562635E8D4A40F88BD992556345409F71E140488A4A409B1C3EE9445E45409F71E140488A4A40
53939	46960	42.891483000000001	42.911470000000001	53.294722999999998	53.275300000000001	Центральная	0103000020E6100000010000000500000051F86C1D1C7245405E4BC8073DA34A4051F86C1D1C7245408330B77BB9A54A407FA4880CAB7445408330B77BB9A54A407FA4880CAB7445405E4BC8073DA34A4051F86C1D1C7245405E4BC8073DA34A40
53697	56445	42.829337000000002	42.856098000000003	53.067433000000001	53.048338999999999	Ясная	0103000020E610000001000000050000006F2EFEB6276A4540880FECF82F864A406F2EFEB6276A4540E9D500A5A1884A40E415889E946D4540E9D500A5A1884A40E415889E946D4540880FECF82F864A406F2EFEB6276A4540880FECF82F864A40
53597	47005	43.066276999999999	43.112540000000003	53.132195000000003	53.093873000000002	Центральная	0103000020E610000001000000050000000EBDC5C37B8845401C7DCC07048C4A400EBDC5C37B884540EDD808C4EB904A40F5BEF1B5678E4540EDD808C4EB904A40F5BEF1B5678E45401C7DCC07048C4A400EBDC5C37B8845401C7DCC07048C4A40
54171	46851	42.937548	42.964137999999998	53.095824999999998	53.084299999999999	Мира	0103000020E610000001000000050000001137A79201784540C286A757CA8A4A401137A79201784540D1915CFE438C4A40596ABDDF687B4540D1915CFE438C4A40596ABDDF687B4540C286A757CA8A4A401137A79201784540C286A757CA8A4A40
54208	40464	42.696871999999999	42.748102000000003	53.289786999999997	53.264066	Садовая	0103000020E61000000100000005000000C2BF081A3359454026FE28EACCA14A40C2BF081A3359454029E78BBD17A54A403E096CCEC15F454029E78BBD17A54A403E096CCEC15F454026FE28EACCA14A40C2BF081A3359454026FE28EACCA14A40
54023	56478	42.683055000000003	42.712341000000002	53.351128000000003	53.333407999999999	Центральная	0103000020E61000000100000005000000452FA3586E574540C51C041DADAA4A40452FA3586E574540DE5A26C3F1AC4A40CB4C69FD2D5B4540DE5A26C3F1AC4A40CB4C69FD2D5B4540C51C041DADAA4A40452FA3586E574540C51C041DADAA4A40
54168	8952	42.871566999999999	42.921773999999999	53.204071999999996	53.186706000000001	Школьная	0103000020E61000000100000005000000ECA2E8818F6F4540C6FB71FBE5974A40ECA2E8818F6F4540C00303081F9A4A40CC26C0B0FC754540C00303081F9A4A40CC26C0B0FC754540C6FB71FBE5974A40ECA2E8818F6F4540C6FB71FBE5974A40
53737	46737	42.912027000000002	42.965997999999999	53.340677999999997	53.301186000000001	Совхозная	0103000020E61000000100000005000000D508FD4CBD744540AC014A438DA64A40D508FD4CBD744540BC3B32569BAB4A402E008DD2A57B4540BC3B32569BAB4A402E008DD2A57B4540AC014A438DA64A40D508FD4CBD744540AC014A438DA64A40
53956	46599	42.735759999999999	42.748308999999999	53.142010999999997	53.134841999999999	Новая	0103000020E610000001000000050000003CDA38622D5E45404910AE8042914A403CDA38622D5E45400C569C6A2D924A40B726DD96C85F45400C569C6A2D924A40B726DD96C85F45404910AE8042914A403CDA38622D5E45404910AE8042914A40
53841	47037	43.163978	43.183371999999999	53.243561999999997	53.228810000000003	Школьная	0103000020E61000000100000005000000BAA1293BFD944540B77F65A5499D4A40BAA1293BFD9445403046240A2D9F4A404580D3BB789745403046240A2D9F4A404580D3BB78974540B77F65A5499D4A40BAA1293BFD944540B77F65A5499D4A40
53948	48064	42.805917999999998	42.838265999999997	53.149383	53.121740000000003	Школьная	0103000020E61000000100000005000000FDA02E5228674540BA4E232D958F4A40FDA02E522867454008CA6DFB1E934A40A3ACDF4C4C6B454008CA6DFB1E934A40A3ACDF4C4C6B4540BA4E232D958F4A40FDA02E5228674540BA4E232D958F4A40
53270	8564	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	Строителей	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
53417	8564	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	Советская	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
53451	8564	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	Лермонтова	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
53727	8564	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	Ленинская	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
53271	8564	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	Калинина	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
53275	8564	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	Губкина	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
53252	8564	42.998444999999997	43.058065999999997	53.238297000000003	53.195580999999997	 Шайкова	0103000020E6100000010000000500000067EDB60BCD7F4540075C57CC08994A4067EDB60BCD7F454012DE1E84809E4A403881E9B46E87454012DE1E84809E4A403881E9B46E874540075C57CC08994A4067EDB60BCD7F4540075C57CC08994A40
54616	56544	43.057293999999999	43.076256999999998	53.069628999999999	53.061042	Школьная	0103000020E61000000100000005000000E620E868558745405AD76839D0874A40E620E8685587454035ED629AE9884A40A88B14CAC289454035ED629AE9884A40A88B14CAC28945405AD76839D0874A40E620E868558745405AD76839D0874A40
49843	56044	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	Школьная	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
49865	19350	59.791218999999998	59.928769000000003	51.045537000000003	51.002949999999998	Свердлова	0103000020E61000000100000005000000A67C08AA46E54D40F8C264AA60804940A67C08AA46E54D4005E10A28D4854940F24410E7E1F64D4005E10A28D4854940F24410E7E1F64D40F8C264AA60804940A67C08AA46E54D40F8C264AA60804940
49829	19350	59.791218999999998	59.928769000000003	51.045537000000003	51.002949999999998	Парковая	0103000020E61000000100000005000000A67C08AA46E54D40F8C264AA60804940A67C08AA46E54D4005E10A28D4854940F24410E7E1F64D4005E10A28D4854940F24410E7E1F64D40F8C264AA60804940A67C08AA46E54D40F8C264AA60804940
49749	22512	55.023204	55.052174000000001	51.731254	51.725642000000001	 Буденного	0103000020E6100000010000000500000075914259F8824B40514D49D6E1DC494075914259F8824B40DB8827BB99DD4940CBD93BA3AD864B40DB8827BB99DD4940CBD93BA3AD864B40514D49D6E1DC494075914259F8824B40514D49D6E1DC4940
50214	56057	55.082816000000001	55.104590999999999	51.780431	51.774830999999999	Степная	0103000020E61000000100000005000000F3CAF5B6998A4B40A77686A92DE34940F3CAF5B6998A4B406DE4BA29E5E349405C3AE63C638D4B406DE4BA29E5E349405C3AE63C638D4B40A77686A92DE34940F3CAF5B6998A4B40A77686A92DE34940
51177	45531	53.098303000000001	53.115856000000001	53.622520999999999	53.616062999999997	Молодежная	0103000020E61000000100000005000000A20C5531958C4A4048A30227DBCE4A40A20C5531958C4A405F09A4C4AECF4A40CF85915ED48E4A405F09A4C4AECF4A40CF85915ED48E4A4048A30227DBCE4A40A20C5531958C4A4048A30227DBCE4A40
51367	56181	55.112110000000001	55.113672999999999	51.721960000000003	51.703097999999997	Центральная	0103000020E61000000100000005000000FCC6D79E598E4B4006F1811DFFD94940FCC6D79E598E4B4095826E2F69DC494017B83CD68C8E4B4095826E2F69DC494017B83CD68C8E4B4006F1811DFFD94940FCC6D79E598E4B4006F1811DFFD94940
51028	56137	54.223289999999999	54.244292000000002	52.768320000000003	52.748548	Центральная	0103000020E610000001000000050000000DC347C4941C4B403CBEBD6BD05F4A400DC347C4941C4B406E6E4C4F58624A405456D3F5441F4B406E6E4C4F58624A405456D3F5441F4B403CBEBD6BD05F4A400DC347C4941C4B403CBEBD6BD05F4A40
50213	56056	55.091169999999998	55.106459000000001	51.780292000000003	51.754914999999997	Советская	0103000020E610000001000000050000002B306475AB8B4B404221020EA1E049402B306475AB8B4B404CAAB69BE0E34940B4AED172A08D4B404CAAB69BE0E34940B4AED172A08D4B404221020EA1E049402B306475AB8B4B404221020EA1E04940
50215	56058	54.994871000000003	55.015459999999997	51.858699999999999	51.842309999999998	Советская	0103000020E61000000100000005000000925ED4EE577F4B40008C67D0D0EB4940925ED4EE577F4B40A089B0E1E9ED4940B532E197FA814B40A089B0E1E9ED4940B532E197FA814B40008C67D0D0EB4940925ED4EE577F4B40008C67D0D0EB4940
50114	56048	53.125152999999997	53.187344000000003	52.452894999999998	52.399681999999999	Карла Маркса	0103000020E6100000010000000500000086FF740305904A4062669FC728334A4086FF740305904A40CEC29E76F8394A40098D60E3FA974A40CEC29E76F8394A40098D60E3FA974A4062669FC728334A4086FF740305904A4062669FC728334A40
50007	56048	53.125152999999997	53.187344000000003	52.452894999999998	52.399681999999999	2-микрорайон	0103000020E6100000010000000500000086FF740305904A4062669FC728334A4086FF740305904A40CEC29E76F8394A40098D60E3FA974A40CEC29E76F8394A40098D60E3FA974A4062669FC728334A4086FF740305904A4062669FC728334A40
49938	56040	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Шевченко	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49802	56040	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Вокзальная	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
50501	49250	54.943010999999998	54.957734000000002	51.816778999999997	51.804847000000002	Центральная	0103000020E6100000010000000500000056629E95B4784B4051A4FB3905E7494056629E95B4784B40A087DA368CE8494036221807977A4B40A087DA368CE8494036221807977A4B4051A4FB3905E7494056629E95B4784B4051A4FB3905E74940
50839	56119	55.013294999999999	55.021783999999997	51.666708	51.658987000000003	Школьная	0103000020E61000000100000005000000A4198BA6B3814B409DBE9EAF59D44940A4198BA6B3814B40A4FD0FB056D54940BCC96FD1C9824B40A4FD0FB056D54940BCC96FD1C9824B409DBE9EAF59D44940A4198BA6B3814B409DBE9EAF59D44940
50842	49163	54.922251000000003	54.937873000000003	51.879286999999998	51.870874000000001	Липовая	0103000020E6100000010000000500000006DA1D520C764B40E6779ACC78EF494006DA1D520C764B402366F6798CF049409566F3380C784B402366F6798CF049409566F3380C784B40E6779ACC78EF494006DA1D520C764B40E6779ACC78EF4940
49835	49507	55.259065	55.284630999999997	51.769576000000001	51.754953999999998	Школьная	0103000020E61000000100000005000000E544BB0A29A14B4000FE2955A2E04940E544BB0A29A14B40ACE4637781E24940C136E2C96EA44B40ACE4637781E24940C136E2C96EA44B4000FE2955A2E04940E544BB0A29A14B4000FE2955A2E04940
49953	49507	55.259065	55.284630999999997	51.769576000000001	51.754953999999998	Советская	0103000020E61000000100000005000000E544BB0A29A14B4000FE2955A2E04940E544BB0A29A14B40ACE4637781E24940C136E2C96EA44B40ACE4637781E24940C136E2C96EA44B4000FE2955A2E04940E544BB0A29A14B4000FE2955A2E04940
49783	19872	54.951948999999999	54.992832	51.851796	51.823928000000002	Кооперативная	0103000020E61000000100000005000000DE3AFF76D9794B401D21037976E94940DE3AFF76D9794B408B6EBDA607ED49400D36751E157F4B408B6EBDA607ED49400D36751E157F4B401D21037976E94940DE3AFF76D9794B401D21037976E94940
49828	19872	54.951948999999999	54.992832	51.851796	51.823928000000002	 Кооперативная	0103000020E61000000100000005000000DE3AFF76D9794B401D21037976E94940DE3AFF76D9794B408B6EBDA607ED49400D36751E157F4B408B6EBDA607ED49400D36751E157F4B401D21037976E94940DE3AFF76D9794B401D21037976E94940
51071	49245	55.146631999999997	55.171712999999997	51.724169000000003	51.717390000000002	Садовая	0103000020E6100000010000000500000006465ED6C4924B401D3D7E6FD3DB494006465ED6C4924B4076E3DD91B1DC494026A60BB1FA954B4076E3DD91B1DC494026A60BB1FA954B401D3D7E6FD3DB494006465ED6C4924B401D3D7E6FD3DB4940
49849	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	пр. Ленина	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49761	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Яблочная	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49760	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Юлина	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49883	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Ю Фучика	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49854	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Энтузиастов	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49755	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Энгельса	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50045	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Чкалова	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49887	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Центральная	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49949	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Тагильская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50052	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Спортивная	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
64040	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Сорокина	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49910	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Сормовская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49756	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Советская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49762	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Севастопольская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50095	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Рыбалко	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49852	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Просвещения	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49759	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Подзорова	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50022	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Орское шоссе	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50883	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Орский проспект	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49853	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Огородная	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50058	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Новая биофабрика	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50021	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Никельщиков проспект	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49700	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Молодогвардейская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49847	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Макаренко	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
66956	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Макаренко	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49757	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Коммунистов-большевиков	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49959	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Комарова	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50508	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Кирпичная	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50043	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Карла Маркса	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49758	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Камчатская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49908	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Заводской переулок	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
66957	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Елшанская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49898	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Гомельская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49869	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Гайское шоссе	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
64066	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Гагарина площадь	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49884	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Вокзальное шоссе	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50047	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Вокзальная	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
64071	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Верхняя	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49851	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Братская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50056	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Больничный переулок	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
64023	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Беляева	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49855	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Байкальская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49885	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Андреева	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
49888	24158	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	1-й Домбаровский переулок	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
4491	1555	55.078997999999999	55.094458000000003	51.799472000000002	51.799238000000003	улица Юркина	0103000020E610000001000000050000008639419B1C8A4B4038DC476E4DE649408639419B1C8A4B40AB08371955E649403C6C2233178C4B40AB08371955E649403C6C2233178C4B4038DC476E4DE649408639419B1C8A4B4038DC476E4DE64940
4822	1555	55.116745000000002	55.145302999999998	51.774352	51.763750999999999	улица Чкалова	0103000020E610000001000000050000005B7C0A80F18E4B40C6A4BF97C2E149405B7C0A80F18E4B40CDCB61F71DE349405E81E84999924B40CDCB61F71DE349405E81E84999924B40C6A4BF97C2E149405B7C0A80F18E4B40C6A4BF97C2E14940
1963	1555	55.112110000000001	55.113672999999999	51.721960000000003	51.703097999999997	улица Центральная	0103000020E61000000100000005000000FCC6D79E598E4B4006F1811DFFD94940FCC6D79E598E4B4095826E2F69DC494017B83CD68C8E4B4095826E2F69DC494017B83CD68C8E4B4006F1811DFFD94940FCC6D79E598E4B4006F1811DFFD94940
4786	1555	55.113348999999999	55.144063000000003	51.778269000000002	51.767507999999999	улица Туркестанская	0103000020E6100000010000000500000064045438828E4B408DB5BFB33DE2494064045438828E4B40CD3E8F519EE3494026C808A870924B40CD3E8F519EE3494026C808A870924B408DB5BFB33DE2494064045438828E4B408DB5BFB33DE24940
3667	1555	55.102246000000001	55.107914999999998	51.823771999999998	51.768127	улица Терешковой	0103000020E61000000100000005000000CB129D65168D4B4059164CFC51E24940CB129D65168D4B4025AE635C71E94940B9DFA128D08D4B4025AE635C71E94940B9DFA128D08D4B4059164CFC51E24940CB129D65168D4B4059164CFC51E24940
3734	1555	55.125064000000002	55.138601000000001	51.843890000000002	51.825018999999998	улица Театральная	0103000020E6100000010000000500000017F4DE1802904B4010CAFB389AE9494017F4DE1802904B40F2B5679604EC4940B11875ADBD914B40F2B5679604EC4940B11875ADBD914B4010CAFB389AE9494017F4DE1802904B4010CAFB389AE94940
5408	1555	55.129815999999998	55.146721999999997	51.794888	51.778525999999999	улица Совхозная	0103000020E61000000100000005000000AF3F89CF9D904B40F88A6EBDA6E34940AF3F89CF9D904B40CEFDD5E3BEE5494046CD57C9C7924B40CEFDD5E3BEE5494046CD57C9C7924B40F88A6EBDA6E34940AF3F89CF9D904B40F88A6EBDA6E34940
3883	1555	55.133229	55.174129000000001	51.845165000000001	51.815376000000001	улица Салмышская	0103000020E610000001000000050000007CF0DAA50D914B40BEF8A23D5EE849407CF0DAA50D914B40A75CE15D2EEC49408124ECDB49964B40A75CE15D2EEC49408124ECDB49964B40BEF8A23D5EE849407CF0DAA50D914B40BEF8A23D5EE84940
3984	1555	55.139454999999998	55.156199000000001	51.838175999999997	51.823861000000001	улица Родимцева	0103000020E61000000100000005000000C02154A9D9914B4095B9F94674E94940C02154A9D9914B406325E65949EB49407E552E54FE934B406325E65949EB49407E552E54FE934B4095B9F94674E94940C02154A9D9914B4095B9F94674E94940
1476	1555	55.090685000000001	55.114490000000004	51.788527000000002	51.788443000000001	улица Октябрьская	0103000020E610000001000000050000006F9EEA909B8B4B404CE141B3EBE449406F9EEA909B8B4B40AA81E673EEE449400ADCBA9BA78E4B40AA81E673EEE449400ADCBA9BA78E4B404CE141B3EBE449406F9EEA909B8B4B404CE141B3EBE44940
6195	1555	55.105148	55.105372000000003	51.826560000000001	51.821683999999998	улица Нефтяников	0103000020E61000000100000005000000B29E5A7D758D4B40BFD2F9F02CE94940B29E5A7D758D4B404417D4B7CCE9494002F566D47C8D4B404417D4B7CCE9494002F566D47C8D4B40BFD2F9F02CE94940B29E5A7D758D4B40BFD2F9F02CE94940
4552	1555	55.085366999999998	55.088304000000001	51.813433000000003	51.799985	улица Народная	0103000020E610000001000000050000002D944C4EED8A4B40312592E865E649402D944C4EED8A4B405C3E92921EE84940910DA48B4D8B4B405C3E92921EE84940910DA48B4D8B4B40312592E865E649402D944C4EED8A4B40312592E865E64940
5357	1555	55.112971999999999	55.116717999999999	51.797967999999997	51.786655000000003	улица Мискинова	0103000020E610000001000000050000008EAED2DD758E4B40111E6D1CB1E449408EAED2DD758E4B4094A0BFD023E64940616D8C9DF08E4B4094A0BFD023E64940616D8C9DF08E4B40111E6D1CB1E449408EAED2DD758E4B40111E6D1CB1E44940
1614	1555	55.169772999999999	55.170527	51.791060999999999	51.775489	улица Мира	0103000020E61000000100000005000000355F251FBB954B4031B43A3943E34940355F251FBB954B400E12A27C41E54940E10A28D4D3954B400E12A27C41E54940E10A28D4D3954B4031B43A3943E34940355F251FBB954B4031B43A3943E34940
4232	1555	55.061984000000002	55.071514999999998	51.778230000000001	51.775861999999996	улица Мебельная	0103000020E6100000010000000500000009707A17EF874B40C51A2E724FE3494009707A17EF874B400F62670A9DE3494033164D6727894B400F62670A9DE3494033164D6727894B40C51A2E724FE3494009707A17EF874B40C51A2E724FE34940
6506	1555	55.078772999999998	55.088160999999999	51.722529000000002	51.721753	улица Кутузова	0103000020E610000001000000050000006667D13B158A4B401B65FD6662DC49406667D13B158A4B40AFB48CD47BDC49402EE411DC488B4B40AFB48CD47BDC49402EE411DC488B4B401B65FD6662DC49406667D13B158A4B401B65FD6662DC4940
16233	1555	55.117859000000003	55.135762	51.769091000000003	51.762853999999997	улица Карла Маркса	0103000020E610000001000000050000000745F300168F4B40B7CF2A33A5E149400745F300168F4B40F052EA9271E24940100533A660914B40F052EA9271E24940100533A660914B40B7CF2A33A5E149400745F300168F4B40B7CF2A33A5E14940
5338	1555	55.088053000000002	55.090865000000001	51.815137	51.813538999999999	улица Каргалинская	0103000020E6100000010000000500000048A81952458B4B40A182C30B22E8494048A81952458B4B403961C26856E84940EFACDD76A18B4B403961C26856E84940EFACDD76A18B4B40A182C30B22E8494048A81952458B4B40A182C30B22E84940
4573	1555	55.070175999999996	55.089345999999999	51.820664999999998	51.810226	улица Калининградская	0103000020E61000000100000005000000677BF486FB884B40382F4E7CB5E74940677BF486FB884B4065FCFB8C0BE94940A30392B06F8B4B4065FCFB8C0BE94940A30392B06F8B4B40382F4E7CB5E74940677BF486FB884B40382F4E7CB5E74940
3996	1555	55.141942999999998	55.149228000000001	51.836233999999997	51.831252999999997	улица Дружбы	0103000020E61000000100000005000000B4722F302B924B40D7D9907F66EA4940B4722F302B924B40D1E638B709EB4940E1D231E719934B40D1E638B709EB4940E1D231E719934B40D7D9907F66EA4940B4722F302B924B40D7D9907F66EA4940
1187	1555	55.151572999999999	55.166718000000003	51.837079000000003	51.825964999999997	улица Джангильдина	0103000020E6100000010000000500000072FA7ABE66934B4000529B38B9E9494072FA7ABE66934B408E95986725EB4940C8D3F20357954B408E95986725EB4940C8D3F20357954B4000529B38B9E9494072FA7ABE66934B4000529B38B9E94940
3975	1555	55.132078999999997	55.151572999999999	51.836694999999999	51.825964999999997	улица Брестская	0103000020E6100000010000000500000083BEF4F6E7904B4000529B38B9E9494083BEF4F6E7904B4005DD5ED218EB494072FA7ABE66934B4005DD5ED218EB494072FA7ABE66934B4000529B38B9E9494083BEF4F6E7904B4000529B38B9E94940
4510	1555	55.077426000000003	55.088214999999998	51.808010000000003	51.807982000000003	улица Братьев Башиловых	0103000020E6100000010000000500000018EE5C18E9894B40DBE044F46BE7494018EE5C18E9894B40A56B26DF6CE7494021020EA14A8B4B40A56B26DF6CE7494021020EA14A8B4B40DBE044F46BE7494018EE5C18E9894B40DBE044F46BE74940
6276	1555	55.107312999999998	55.110807000000001	51.770494999999997	51.769576000000001	улица Богдана Хмельницкого	0103000020E61000000100000005000000C3B7B06EBC8D4B40ACE4637781E24940C3B7B06EBC8D4B40A25D85949FE249407D957CEC2E8E4B40A25D85949FE249407D957CEC2E8E4B40ACE4637781E24940C3B7B06EBC8D4B40ACE4637781E24940
4012	1555	55.137613000000002	55.144072000000001	51.830055999999999	51.826160000000002	улица 70 Лет ВЛКСМ	0103000020E610000001000000050000009240834D9D914B40B6A1629CBFE949409240834D9D914B409EEC66463FEA4940792288F370924B409EEC66463FEA4940792288F370924B40B6A1629CBFE949409240834D9D914B40B6A1629CBFE94940
50100	1555	55.129555000000003	55.145868	51.795312000000003	51.788811000000003	Ялтинская	0103000020E6100000010000000500000043041C4295904B40CFDC43C2F7E4494043041C4295904B40E50E9BC8CCE5494037C478CDAB924B40E50E9BC8CCE5494037C478CDAB924B40CFDC43C2F7E4494043041C4295904B40CFDC43C2F7E44940
50164	1555	55.087100999999997	55.088214999999998	51.769342000000002	51.75826	Яицкая	0103000020E6100000010000000500000075392520268B4B40B7EEE6A90EE1494075392520268B4B4039B874CC79E2494021020EA14A8B4B4039B874CC79E2494021020EA14A8B4B40B7EEE6A90EE1494075392520268B4B40B7EEE6A90EE14940
50222	1555	55.136867000000002	55.147728000000001	51.841498000000001	51.834097	Юных Ленинцев	0103000020E6100000010000000500000069739CDB84914B408A58C4B0C3EA494069739CDB84914B4020D3DA34B6EB49400C5A48C0E8924B4020D3DA34B6EB49400C5A48C0E8924B408A58C4B0C3EA494069739CDB84914B408A58C4B0C3EA4940
49877	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Юношеская	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50226	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Школьная улица	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50423	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Школьная	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50174	1555	55.087074000000001	55.166142999999998	51.798158000000001	51.785010999999997	Шевченко	0103000020E610000001000000050000007C2AA73D258B4B4008008E3D7BE449407C2AA73D258B4B403885950A2AE64940CBBA7F2C44954B403885950A2AE64940CBBA7F2C44954B4008008E3D7BE449407C2AA73D258B4B4008008E3D7BE44940
50191	1555	55.116745000000002	55.145302999999998	51.774352	51.763750999999999	Чкалова	0103000020E610000001000000050000005B7C0A80F18E4B40C6A4BF97C2E149405B7C0A80F18E4B40CDCB61F71DE349405E81E84999924B40CDCB61F71DE349405E81E84999924B40C6A4BF97C2E149405B7C0A80F18E4B40C6A4BF97C2E14940
50201	1555	55.088079999999998	55.093136999999999	51.769804000000001	51.74973	Чичерина	0103000020E6100000010000000500000041B79734468B4B40406A1327F7DF494041B79734468B4B403D2AFEEF88E249401686C8E9EB8B4B403D2AFEEF88E249401686C8E9EB8B4B40406A1327F7DF494041B79734468B4B40406A1327F7DF4940
50194	1555	55.107421000000002	55.118515000000002	51.762146000000001	51.759107999999998	Челюскинцев	0103000020E61000000100000005000000AAF3A8F8BF8D4B40E41071732AE14940AAF3A8F8BF8D4B407C6308008EE14940F08AE07F2B8F4B407C6308008EE14940F08AE07F2B8F4B40E41071732AE14940AAF3A8F8BF8D4B40E41071732AE14940
50145	1555	55.112110000000001	55.113672999999999	51.721960000000003	51.703097999999997	Центральная	0103000020E61000000100000005000000FCC6D79E598E4B4006F1811DFFD94940FCC6D79E598E4B4095826E2F69DC494017B83CD68C8E4B4095826E2F69DC494017B83CD68C8E4B4006F1811DFFD94940FCC6D79E598E4B4006F1811DFFD94940
50220	1555	55.035259000000003	55.040415000000003	51.793149999999997	51.785251000000002	Химическая	0103000020E61000000100000005000000E1F1ED5D83844B405E13D21A83E44940E1F1ED5D83844B4044696FF085E5494049A297512C854B4044696FF085E5494049A297512C854B405E13D21A83E44940E1F1ED5D83844B405E13D21A83E44940
50225	1555	55.123365999999997	55.141925000000001	51.781205999999997	51.77487	Харьковская	0103000020E610000001000000050000001BB80375CA8F4B406553AEF02EE349401BB80375CA8F4B4030B8E68EFEE349400EBE30992A924B4030B8E68EFEE349400EBE30992A924B406553AEF02EE349401BB80375CA8F4B406553AEF02EE34940
5437	1555	55.145679999999999	55.146354000000002	51.79251	51.791851999999999	Флотский переулок	0103000020E6100000010000000500000034D769A4A5924B40D7A205685BE5494034D769A4A5924B4061E0B9F770E54940C4D155BABB924B4061E0B9F770E54940C4D155BABB924B40D7A205685BE5494034D769A4A5924B40D7A205685BE54940
50147	1555	55.126519000000002	55.138224000000001	51.775939999999999	51.763756999999998	Уральская	0103000020E610000001000000050000004CA94BC631904B40A88B14CAC2E149404CA94BC631904B4041D47D0052E34940DBC2F352B1914B4041D47D0052E34940DBC2F352B1914B40A88B14CAC2E149404CA94BC631904B40A88B14CAC2E14940
50172	1555	55.113348999999999	55.144063000000003	51.778269000000002	51.767507999999999	Туркестанская	0103000020E6100000010000000500000064045438828E4B408DB5BFB33DE2494064045438828E4B40CD3E8F519EE3494026C808A870924B40CD3E8F519EE3494026C808A870924B408DB5BFB33DE2494064045438828E4B408DB5BFB33DE24940
50190	1555	55.143084000000002	55.166251000000003	51.820943999999997	51.813372000000001	Транспортная	0103000020E610000001000000050000005A4A969350924B40B6BDDD921CE849405A4A969350924B4078EC67B114E94940B2F677B647954B4078EC67B114E94940B2F677B647954B40B6BDDD921CE849405A4A969350924B40B6BDDD921CE84940
50131	1555	55.114795999999998	55.116601000000003	51.715448000000002	51.704253000000001	Тобольская	0103000020E6100000010000000500000016DBA4A2B18E4B40118E59F624DA494016DBA4A2B18E4B408BFED0CC93DB494028D714C8EC8E4B408BFED0CC93DB494028D714C8EC8E4B40118E59F624DA494016DBA4A2B18E4B40118E59F624DA4940
50197	1555	55.054715999999999	55.071344000000003	51.792855000000003	51.785350999999999	Ткачева	0103000020E61000000100000005000000B24813EF00874B40C170AE6186E44940B24813EF00874B402CBCCB457CE549400762D9CC21894B402CBCCB457CE549400762D9CC21894B40C170AE6186E44940B24813EF00874B40C170AE6186E44940
50192	1555	55.102246000000001	55.107914999999998	51.823771999999998	51.768127	Терешковой	0103000020E61000000100000005000000CB129D65168D4B4059164CFC51E24940CB129D65168D4B4025AE635C71E94940B9DFA128D08D4B4025AE635C71E94940B9DFA128D08D4B4059164CFC51E24940CB129D65168D4B4059164CFC51E24940
50227	1555	55.085141999999998	55.120032999999999	51.783183999999999	51.779451000000002	Сухарева	0103000020E610000001000000050000000DC2DCEEE58A4B40D1EAE40CC5E349400DC2DCEEE58A4B400F60915F3FE449406BB8C83D5D8F4B400F60915F3FE449406BB8C83D5D8F4B40D1EAE40CC5E349400DC2DCEEE58A4B40D1EAE40CC5E34940
41569	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Строителей проспект	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50234	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Строителей проспект	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50184	1555	55.089643000000002	55.092032000000003	51.81615	51.814903000000001	Станционная	0103000020E610000001000000050000005DA8FC6B798B4B40C634D3BD4EE849405DA8FC6B798B4B40B1506B9A77E84940BE175FB4C78B4B40B1506B9A77E84940BE175FB4C78B4B40C634D3BD4EE849405DA8FC6B798B4B40C634D3BD4EE84940
49969	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Станиславского	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
49879	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Станиславского	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50180	1555	55.091169999999998	55.106459000000001	51.780292000000003	51.754914999999997	Советская	0103000020E610000001000000050000002B306475AB8B4B404221020EA1E049402B306475AB8B4B404CAAB69BE0E34940B4AED172A08D4B404CAAB69BE0E34940B4AED172A08D4B404221020EA1E049402B306475AB8B4B404221020EA1E04940
50181	1555	55.122332999999998	55.132367000000002	51.83005	51.824401000000002	Сергея Лазо	0103000020E610000001000000050000005C1C959BA88F4B4015E5D2F885E949405C1C959BA88F4B40BC0512143FEA4940EA08E066F1904B40BC0512143FEA4940EA08E066F1904B4015E5D2F885E949405C1C959BA88F4B4015E5D2F885E94940
50144	1555	55.103422999999999	55.108085000000003	51.755288999999998	51.754280000000001	Свердлова	0103000020E61000000100000005000000BD5301F73C8D4B4071033E3F8CE04940BD5301F73C8D4B40A703594FADE049401618B2BAD58D4B40A703594FADE049401618B2BAD58D4B4071033E3F8CE04940BD5301F73C8D4B4071033E3F8CE04940
50207	1555	55.116214999999997	55.135727000000003	51.795724	51.778007000000002	Самолетная	0103000020E61000000100000005000000FE261422E08E4B409087BEBB95E34940FE261422E08E4B403752B648DAE54940941799805F914B403752B648DAE54940941799805F914B409087BEBB95E34940FE261422E08E4B409087BEBB95E34940
50159	1555	55.133229	55.174129000000001	51.845165000000001	51.815376000000001	Салмышская	0103000020E610000001000000050000007CF0DAA50D914B40BEF8A23D5EE849407CF0DAA50D914B40A75CE15D2EEC49408124ECDB49964B40A75CE15D2EEC49408124ECDB49964B40BEF8A23D5EE849407CF0DAA50D914B40BEF8A23D5EE84940
50202	1555	55.086229000000003	55.107303999999999	51.776212999999998	51.770105000000001	Рыбаковская	0103000020E61000000100000005000000C07B478D098B4B4038BEF6CC92E24940C07B478D098B4B4072DD94F25AE34940705D3123BC8D4B4072DD94F25AE34940705D3123BC8D4B4038BEF6CC92E24940C07B478D098B4B4038BEF6CC92E24940
50167	1555	55.142940000000003	55.168371	51.844113	51.831848000000001	Просторная	0103000020E6100000010000000500000027A5A0DB4B924B401B9FC9FE79EA494027A5A0DB4B924B40719010E50BEC4940234C512E8D954B40719010E50BEC4940234C512E8D954B401B9FC9FE79EA494027A5A0DB4B924B401B9FC9FE79EA4940
49934	1555	55.137217999999997	55.143847000000001	51.875700000000002	51.872163999999998	Просвещения	0103000020E610000001000000050000001536035C90914B40D05FE811A3EF49401536035C90914B40B98D06F016F049405950189469924B40B98D06F016F049405950189469924B40D05FE811A3EF49401536035C90914B40D05FE811A3EF4940
50120	1555	55.142051000000002	55.151913999999998	51.807887000000001	51.799917999999998	Промышленная	0103000020E610000001000000050000009BAE27BA2E924B40A9BD88B663E649409BAE27BA2E924B4089EE59D768E74940FBE6FEEA71934B4089EE59D768E74940FBE6FEEA71934B40A9BD88B663E649409BAE27BA2E924B40A9BD88B663E64940
4712	1555	55.186498999999998	55.187424999999998	51.781986000000003	51.774447000000002	Промысловый проезд	0103000020E610000001000000050000004CDE0033DF974B401FBE4C1421E349404CDE0033DF974B4006F7031E18E44940F5B9DA8AFD974B4006F7031E18E44940F5B9DA8AFD974B401FBE4C1421E349404CDE0033DF974B401FBE4C1421E34940
50640	1555	55.094161	55.105606000000002	51.814301999999998	51.758505999999997	Пролетарская	0103000020E6100000010000000500000082C7B7770D8C4B40EEE87FB916E1494082C7B7770D8C4B40A088450C3BE849407521567F848D4B40A088450C3BE849407521567F848D4B40EEE87FB916E1494082C7B7770D8C4B40EEE87FB916E14940
16128	1555	55.076869000000002	55.079393000000003	51.775756000000001	51.775015000000003	Привокзальная площадь	0103000020E61000000100000005000000C289E8D7D6894B40697407B133E34940C289E8D7D6894B4080D6FCF84BE349400344C18C298A4B4080D6FCF84BE349400344C18C298A4B40697407B133E34940C289E8D7D6894B40697407B133E34940
3655	1555	55.103000999999999	55.144987999999998	51.825029999999998	51.771571000000002	Победы проспект	0103000020E61000000100000005000000473A03232F8D4B4061C5A9D6C2E24940473A03232F8D4B40041C42959AE94940FE277FF78E924B40041C42959AE94940FE277FF78E924B4061C5A9D6C2E24940473A03232F8D4B4061C5A9D6C2E24940
50211	1555	55.086579999999998	55.087541000000002	51.760997000000003	51.759051999999997	Пионерская	0103000020E610000001000000050000006C3EAE0D158B4B4050FBAD9D28E149406C3EAE0D158B4B4054AD855968E149409207228B348B4B4054AD855968E149409207228B348B4B4050FBAD9D28E149406C3EAE0D158B4B4050FBAD9D28E14940
50112	1555	55.135035000000002	55.137011000000001	51.767780999999999	51.767068000000002	Пикетная	0103000020E610000001000000050000005E68AED348914B4071E7C2482FE249405E68AED348914B40BEBED6A546E249409C18929389914B40BEBED6A546E249409C18929389914B4071E7C2482FE249405E68AED348914B4071E7C2482FE24940
4135	1555	55.079393000000003	55.096361999999999	51.775015000000003	51.768912	Парковый проспект	0103000020E610000001000000050000000344C18C298A4B4040C05AB56BE249400344C18C298A4B40697407B133E34940E0490B97558C4B40697407B133E34940E0490B97558C4B4040C05AB56BE249400344C18C298A4B4040C05AB56BE24940
50204	1555	55.100664999999999	55.105435	51.797935000000003	51.762408000000001	Орджоникидзе	0103000020E61000000100000005000000096D3997E28C4B40B91AD99596E14940096D3997E28C4B40B9AAECBB22E64940486DE2E47E8D4B40B9AAECBB22E64940486DE2E47E8D4B40B91AD99596E14940096D3997E28C4B40B91AD99596E14940
50168	1555	55.099381000000001	55.104384000000003	51.824278	51.820993999999999	Онежская	0103000020E61000000100000005000000016C4084B88C4B402A1BD65416E94940016C4084B88C4B40F96706F181E94940E31C75745C8D4B40F96706F181E94940E31C75745C8D4B402A1BD65416E94940016C4084B88C4B402A1BD65416E94940
50111	1555	55.154437999999999	55.165308000000003	51.777054	51.777037999999997	Омская	0103000020E610000001000000050000003CA1D79FC4934B40E7DF2EFB75E349403CA1D79FC4934B40ED9C668176E3494033E202D028954B40ED9C668176E3494033E202D028954B40E7DF2EFB75E349403CA1D79FC4934B40E7DF2EFB75E34940
51378	1555	55.090685000000001	55.114490000000004	51.788527000000002	51.788443000000001	Октябрьская	0103000020E610000001000000050000006F9EEA909B8B4B404CE141B3EBE449406F9EEA909B8B4B40AA81E673EEE449400ADCBA9BA78E4B40AA81E673EEE449400ADCBA9BA78E4B404CE141B3EBE449406F9EEA909B8B4B404CE141B3EBE44940
50169	1555	55.126007000000001	55.142715000000003	51.796871000000003	51.780002000000003	Одесская	0103000020E61000000100000005000000960854FF20904B404568041BD7E34940960854FF20904B40BF1072DEFFE5494007D3307C44924B40BF1072DEFFE5494007D3307C44924B404568041BD7E34940960854FF20904B404568041BD7E34940
50205	1555	55.055812000000003	55.107078999999999	51.816355999999999	51.776285000000001	Ноябрьская	0103000020E61000000100000005000000B85CFDD824874B400CB08F4E5DE34940B85CFDD824874B405AF2785A7EE84940508BC1C3B48D4B405AF2785A7EE84940508BC1C3B48D4B400CB08F4E5DE34940B85CFDD824874B400CB08F4E5DE34940
50179	1555	55.063107000000002	55.077390000000001	51.786676999999997	51.779395000000001	Ногина	0103000020E610000001000000050000000893E2E313884B403DD52137C3E349400893E2E313884B40F8C1F9D4B1E44940CB845FEAE7894B40F8C1F9D4B1E44940CB845FEAE7894B403DD52137C3E349400893E2E313884B403DD52137C3E34940
50177	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Новая	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50173	1555	55.105148	55.105372000000003	51.826560000000001	51.821683999999998	Нефтянников	0103000020E61000000100000005000000B29E5A7D758D4B40BFD2F9F02CE94940B29E5A7D758D4B404417D4B7CCE9494002F566D47C8D4B404417D4B7CCE9494002F566D47C8D4B40BFD2F9F02CE94940B29E5A7D758D4B40BFD2F9F02CE94940
50217	1555	55.083229000000003	55.114984	51.785283999999997	51.782269999999997	Невельская	0103000020E61000000100000005000000168A743FA78A4B402A52616C21E44940168A743FA78A4B403909A52F84E4494019C8B3CBB78E4B403909A52F84E4494019C8B3CBB78E4B402A52616C21E44940168A743FA78A4B402A52616C21E44940
50107	1555	55.084172000000002	55.090065000000003	51.729246000000003	51.715772000000001	Нахимова	0103000020E61000000100000005000000959EE925C68A4B403EB2B96A9EDB4940959EE925C68A4B40925ED4EE57DD4940D3C1FA3F878B4B40925ED4EE57DD4940D3C1FA3F878B4B403EB2B96A9EDB4940959EE925C68A4B403EB2B96A9EDB4940
50643	1555	55.096874	55.103369000000001	51.754375000000003	51.753962000000001	Набережная	0103000020E6100000010000000500000096EA025E668C4B40A036AAD381E0494096EA025E668C4B40C3F5285C8FE04940CA3505323B8D4B40C3F5285C8FE04940CA3505323B8D4B40A036AAD381E0494096EA025E668C4B40A036AAD381E04940
50178	1555	55.134765000000002	55.158974999999998	51.804406999999998	51.799911999999999	Монтажников	0103000020E610000001000000050000009ED2C1FA3F914B40C7D6338463E649409ED2C1FA3F914B4034D6FECEF6E64940D8F0F44A59944B4034D6FECEF6E64940D8F0F44A59944B40C7D6338463E649409ED2C1FA3F914B40C7D6338463E64940
50044	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Молодежная	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
49982	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Мира проспект	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
49845	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Мира проспект	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50126	1555	55.169772999999999	55.170527	51.791060999999999	51.775489	Мира	0103000020E61000000100000005000000355F251FBB954B4031B43A3943E34940355F251FBB954B400E12A27C41E54940E10A28D4D3954B400E12A27C41E54940E10A28D4D3954B4031B43A3943E34940355F251FBB954B4031B43A3943E34940
50223	1555	55.087890999999999	55.094458000000003	51.800246000000001	51.800179999999997	Минская	0103000020E610000001000000050000006E4E2503408B4B40E674594C6CE649406E4E2503408B4B409E60FF756EE649403C6C2233178C4B409E60FF756EE649403C6C2233178C4B40E674594C6CE649406E4E2503408B4B40E674594C6CE64940
50182	1555	55.094278000000003	55.107888000000003	51.736257000000002	51.725776000000003	Механизаторов	0103000020E61000000100000005000000BC5D2F4D118C4B40611C5C3AE6DC4940BC5D2F4D118C4B40BD395CAB3DDE4940C0D02346CF8D4B40BD395CAB3DDE4940C0D02346CF8D4B40611C5C3AE6DC4940BC5D2F4D118C4B40611C5C3AE6DC4940
50148	1555	55.153190000000002	55.164696999999997	51.780337000000003	51.780264000000003	Медногорская	0103000020E610000001000000050000008109DCBA9B934B40821FD5B0DFE349408109DCBA9B934B40EC6D3315E2E34940E95F92CA14954B40EC6D3315E2E34940E95F92CA14954B40821FD5B0DFE349408109DCBA9B934B40821FD5B0DFE34940
50116	1555	55.020536	55.021515000000001	51.790092000000001	51.788041999999997	Манежная	0103000020E61000000100000005000000013274ECA0824B40EDEF6C8FDEE44940013274ECA0824B40666A12BC21E54940CDAFE600C1824B40666A12BC21E54940CDAFE600C1824B40EDEF6C8FDEE44940013274ECA0824B40EDEF6C8FDEE44940
51379	1555	55.153675	55.154060999999999	51.774434999999997	51.769430999999997	Мало-Восточная	0103000020E610000001000000050000003D9B559FAB934B40A8C30AB77CE249403D9B559FAB934B405AF0A2AF20E34940664B5645B8934B405AF0A2AF20E34940664B5645B8934B40A8C30AB77CE249403D9B559FAB934B40A8C30AB77CE24940
50098	1555	55.093136999999999	55.110053000000001	51.759068999999997	51.754368999999997	Максима Горького	0103000020E610000001000000050000001686C8E9EB8B4B40E00ED4298FE049401686C8E9EB8B4B402634492C29E14940D1E97937168E4B402634492C29E14940D1E97937168E4B40E00ED4298FE049401686C8E9EB8B4B40E00ED4298FE04940
4763	1555	55.144978999999999	55.153199000000001	51.777070999999999	51.777048999999998	Майский проезд	0103000020E61000000100000005000000ABCDFFAB8E924B40DB31755776E34940ABCDFFAB8E924B40C3D5011077E34940D4635B069C934B40C3D5011077E34940D4635B069C934B40DB31755776E34940ABCDFFAB8E924B40DB31755776E34940
50137	1555	55.040415000000003	55.060259000000002	51.796425999999997	51.793149999999997	Магнитогорская	0103000020E6100000010000000500000049A297512C854B4044696FF085E5494049A297512C854B4090D78349F1E5494014252191B6874B4090D78349F1E5494014252191B6874B4044696FF085E5494049A297512C854B4044696FF085E54940
50187	1555	55.067993999999999	55.078997999999999	51.799627999999998	51.796142000000003	Львовская	0103000020E6100000010000000500000080290307B4884B406C7C26FBE7E5494080290307B4884B40A27BD6355AE649408639419B1C8A4B40A27BD6355AE649408639419B1C8A4B406C7C26FBE7E5494080290307B4884B406C7C26FBE7E54940
50183	1555	55.159208	55.159253	51.788553999999998	51.774858999999999	Луговая	0103000020E610000001000000050000007BA180ED60944B40710168942EE349407BA180ED60944B40A3906456EFE449401B65FD6662944B40A3906456EFE449401B65FD6662944B40710168942EE349407BA180ED60944B40710168942EE34940
51353	1555	55.058695999999998	55.068190999999999	51.764871999999997	51.76097	Луганская	0103000020E61000000100000005000000F833BC5983874B405A9E077767E14940F833BC5983874B4024D06053E7E14940D670917BBA884B4024D06053E7E14940D670917BBA884B405A9E077767E14940F833BC5983874B405A9E077767E14940
49867	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Ленинского Комсомола	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
41565	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Ленина проспект	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
66975	1555	55.094889000000002	55.097349999999999	51.768912	51.767603000000001	Ленина площадь	0103000020E6100000010000000500000005E09F52258C4B40DFA7AAD040E2494005E09F52258C4B4040C05AB56BE24940FF21FDF6758C4B4040C05AB56BE24940FF21FDF6758C4B40DFA7AAD040E2494005E09F52258C4B40DFA7AAD040E24940
50113	1555	55.085312999999999	55.085583	51.765645999999997	51.762636000000001	Курача	0103000020E610000001000000050000003A765089EB8A4B404A60730E9EE149403A765089EB8A4B40172829B000E24940FA0B3D62F48A4B40172829B000E24940FA0B3D62F48A4B404A60730E9EE149403A765089EB8A4B404A60730E9EE14940
50203	1555	55.058363999999997	55.072746000000002	51.790225999999997	51.783095000000003	Красина	0103000020E61000000100000005000000C2A1B77878874B40A054FB743CE44940C2A1B77878874B407539252026E549401975ADBD4F894B407539252026E549401975ADBD4F894B40A054FB743CE44940C2A1B77878874B40A054FB743CE44940
49699	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Короленко	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50188	1555	55.119925000000002	55.137388000000001	51.836100000000002	51.826444000000002	Конституции	0103000020E61000000100000005000000857CD0B3598F4B40DBFCBFEAC8E94940857CD0B3598F4B40C217265305EB4940726E13EE95914B40C217265305EB4940726E13EE95914B40DBFCBFEAC8E94940857CD0B3598F4B40DBFCBFEAC8E94940
49882	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Коларова	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50139	1555	55.091816999999999	55.099471000000001	51.767837	51.755071000000001	Кобозева	0103000020E61000000100000005000000C11BD2A8C08B4B403A94A12AA6E04940C11BD2A8C08B4B4052D4997B48E2494041F33977BB8C4B4052D4997B48E2494041F33977BB8C4B403A94A12AA6E04940C11BD2A8C08B4B403A94A12AA6E04940
50209	1555	55.089292999999998	55.106476999999998	51.764938000000001	51.760762999999997	Кирова	0103000020E610000001000000050000008061F9F36D8B4B40E08096AE60E149408061F9F36D8B4B40DCBB067DE9E149405A63D009A18D4B40DCBB067DE9E149405A63D009A18D4B40E08096AE60E149408061F9F36D8B4B40E08096AE60E14940
5382	1555	55.122872000000001	55.128630000000001	51.796587000000002	51.794448000000003	Квартальный переулок	0103000020E610000001000000050000000CCC0A45BA8F4B40B22FD978B0E549400CCC0A45BA8F4B409AB51490F6E549406AA4A5F276904B409AB51490F6E549406AA4A5F276904B40B22FD978B0E549400CCC0A45BA8F4B40B22FD978B0E54940
50094	1555	55.091278000000003	55.106603	51.718651000000001	51.717289999999998	Карачинская	0103000020E61000000100000005000000126C5CFFAE8B4B40B9DFA128D0DB4940126C5CFFAE8B4B406D1E87C1FCDB4940E753C72AA58D4B406D1E87C1FCDB4940E753C72AA58D4B40B9DFA128D0DB4940126C5CFFAE8B4B40B9DFA128D0DB4940
4746	1555	55.144063000000003	55.153190000000002	51.780337000000003	51.778269000000002	Знаменский проезд	0103000020E6100000010000000500000026C808A870924B40CD3E8F519EE3494026C808A870924B40EC6D3315E2E349408109DCBA9B934B40EC6D3315E2E349408109DCBA9B934B40CD3E8F519EE3494026C808A870924B40CD3E8F519EE34940
50634	1555	55.054805999999999	55.067301999999998	51.796419999999998	51.792119999999997	Зиновьева	0103000020E61000000100000005000000F2CF0CE203874B40F6402B3064E54940F2CF0CE203874B40AEF02E17F1E549404A7A185A9D884B40AEF02E17F1E549404A7A185A9D884B40F6402B3064E54940F2CF0CE203874B40F6402B3064E54940
50229	1555	55.08614	55.092041000000002	51.826149000000001	51.822436000000003	Заводская	0103000020E610000001000000050000005070B1A2068B4B40CB86359545E949405070B1A2068B4B40C24F1C40BFE949401172DEFFC78B4B40C24F1C40BFE949401172DEFFC78B4B40CB86359545E949405070B1A2068B4B40CB86359545E94940
49786	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Журевского	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50103	1555	55.079284999999999	55.083930000000002	51.771141999999998	51.768996000000001	Железнодорожная	0103000020E610000001000000050000001C08C902268A4B409E60FF756EE249401C08C902268A4B403849F3C7B4E249409F93DE37BE8A4B403849F3C7B4E249409F93DE37BE8A4B409E60FF756EE249401C08C902268A4B409E60FF756EE24940
50175	1555	55.141942999999998	55.149228000000001	51.836233999999997	51.831252999999997	Дружбы	0103000020E61000000100000005000000B4722F302B924B40D7D9907F66EA4940B4722F302B924B40D1E638B709EB4940E1D231E719934B40D1E638B709EB4940E1D231E719934B40D7D9907F66EA4940B4722F302B924B40D7D9907F66EA4940
50212	1555	55.159747000000003	55.169466999999997	51.822436000000003	51.815019999999997	Диагностики	0103000020E610000001000000050000002B51F69672944B40FFCA4A9352E849402B51F69672944B40CB86359545E9494028603B18B1954B40CB86359545E9494028603B18B1954B40FFCA4A9352E849402B51F69672944B40FFCA4A9352E84940
3791	1555	55.107968999999997	55.142876999999999	51.843952000000002	51.824145000000001	Дзержинского проспект	0103000020E61000000100000005000000ACFD9DEDD18D4B40BA1457957DE94940ACFD9DEDD18D4B4068B27F9E06EC4940E02C25CB49924B4068B27F9E06EC4940E02C25CB49924B40BA1457957DE94940ACFD9DEDD18D4B40BA1457957DE94940
50133	1555	55.065299000000003	55.091889000000002	51.828141000000002	51.822358000000001	Гастелло	0103000020E6100000010000000500000013BBB6B75B884B404FCDE50643E9494013BBB6B75B884B4006BD378600EA49405BEECC04C38B4B4006BD378600EA49405BEECC04C38B4B404FCDE50643E9494013BBB6B75B884B404FCDE50643E94940
1275	1555	55.145221999999997	55.271552	51.775449999999999	51.770344999999999	Гагарина проспект	0103000020E6100000010000000500000071546EA296924B408DD13AAA9AE2494071546EA296924B4073D712F241E34940EA944737C2A24B4073D712F241E34940EA944737C2A24B408DD13AAA9AE2494071546EA296924B408DD13AAA9AE24940
50170	1555	55.145221999999997	55.271552	51.775449999999999	51.770344999999999	Гагарина проспект	0103000020E6100000010000000500000071546EA296924B408DD13AAA9AE2494071546EA296924B4073D712F241E34940EA944737C2A24B4073D712F241E34940EA944737C2A24B408DD13AAA9AE2494071546EA296924B408DD13AAA9AE24940
50208	1555	55.128898999999997	55.135142999999999	51.842188	51.838732	Всесоюзная	0103000020E6100000010000000500000059BE2EC37F904B40E90DF7915BEB494059BE2EC37F904B40B58AFED0CCEB494044A4A65D4C914B40B58AFED0CCEB494044A4A65D4C914B40E90DF7915BEB494059BE2EC37F904B40E90DF7915BEB4940
50092	1555	55.153117999999999	55.154546000000003	51.789011000000002	51.774602999999999	Восточная	0103000020E61000000100000005000000E736E15E99934B401631EC3026E34940E736E15E99934B409697FC4FFEE4494023DDCF29C8934B409697FC4FFEE4494023DDCF29C8934B401631EC3026E34940E736E15E99934B401631EC3026E34940
50199	1555	55.119925000000002	55.143217999999997	51.850583999999998	51.836067	Волгоградская	0103000020E61000000100000005000000857CD0B3598F4B40E621533E04EB4940857CD0B3598F4B401C40BFEFDFEC49406919A9F754924B401C40BFEFDFEC49406919A9F754924B40E621533E04EB4940857CD0B3598F4B40E621533E04EB4940
49873	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Вечерняя	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50086	1555	55.113179000000002	55.120302000000002	51.715665999999999	51.715158000000002	Весенняя	0103000020E6100000010000000500000008CC43A67C8E4B4084BC1E4C8ADB494008CC43A67C8E4B40F86D88F19ADB49405BD2510E668F4B40F86D88F19ADB49405BD2510E668F4B4084BC1E4C8ADB494008CC43A67C8E4B4084BC1E4C8ADB4940
50219	1555	55.132078999999997	55.151572999999999	51.836694999999999	51.825964999999997	Брестская	0103000020E6100000010000000500000083BEF4F6E7904B4000529B38B9E9494083BEF4F6E7904B4005DD5ED218EB494072FA7ABE66934B4005DD5ED218EB494072FA7ABE66934B4000529B38B9E9494083BEF4F6E7904B4000529B38B9E94940
4204	1555	55.047682999999999	55.079546000000001	51.811846000000003	51.784939000000001	Братьев Коростелевых проезд	0103000020E610000001000000050000009FC9FE791A864B406F2D93E178E449409FC9FE791A864B40B8B1D991EAE74940894336902E8A4B40B8B1D991EAE74940894336902E8A4B406F2D93E178E449409FC9FE791A864B406F2D93E178E44940
50176	1555	55.111821999999997	55.119700999999999	51.833201000000003	51.828758999999998	Братская	0103000020E61000000100000005000000957CEC2E508E4B4001A260C614EA4940957CEC2E508E4B404CFF9254A6EA49403526C45C528F4B404CFF9254A6EA49403526C45C528F4B4001A260C614EA4940957CEC2E508E4B4001A260C614EA4940
49945	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	Березовая Ростошь	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
50110	1555	55.114435999999998	55.11741	51.729948	51.721870000000003	Беляевская	0103000020E6100000010000000500000016BEBED6A58E4B4055FB743C66DC494016BEBED6A58E4B40EBE3A1EF6EDD4940971C774A078F4B40EBE3A1EF6EDD4940971C774A078F4B4055FB743C66DC494016BEBED6A58E4B4055FB743C66DC4940
50189	1555	55.047907000000002	55.061363999999998	51.802200999999997	51.787719000000003	Бебеля	0103000020E61000000100000005000000EF1F0BD121864B400BB8E7F9D3E44940EF1F0BD121864B40C4E8B985AEE649406C938AC6DA874B40C4E8B985AEE649406C938AC6DA874B400BB8E7F9D3E44940EF1F0BD121864B400BB8E7F9D3E44940
50196	1555	55.09064	55.091600999999997	51.797956999999997	51.784849999999999	Астраханская	0103000020E61000000100000005000000CFDA6D179A8B4B40FF21FDF675E44940CFDA6D179A8B4B40A04E797423E64940F4A3E194B98B4B40A04E797423E64940F4A3E194B98B4B40FF21FDF675E44940CFDA6D179A8B4B40FF21FDF675E44940
50186	1555	55.104187000000003	55.123365999999997	51.775165000000001	51.770935999999999	Аксакова	0103000020E610000001000000050000008DD5E6FF558D4B408FA7E507AEE249408DD5E6FF558D4B407E00529B38E349401BB80375CA8F4B407E00529B38E349401BB80375CA8F4B408FA7E507AEE249408DD5E6FF558D4B408FA7E507AEE24940
3788	1555	55.178091000000002	55.178280000000001	51.791055999999998	51.785808000000003	75-я линия	0103000020E61000000100000005000000215B96AFCB964B40B477465B95E44940215B96AFCB964B40FCA6B05241E54940F4C308E1D1964B40FCA6B05241E54940F4C308E1D1964B40B477465B95E44940215B96AFCB964B40B477465B95E44940
50185	1555	55.017634000000001	55.388934999999996	51.948718	51.682088999999998	70 Лет ВЛКСМ	0103000020E610000001000000050000001AA6B6D441824B400DFB3DB14ED749401AA6B6D441824B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B400DFB3DB14ED749401AA6B6D441824B400DFB3DB14ED74940
4720	1555	55.170375	55.186588999999998	51.781607000000001	51.781295	10-я линия	0103000020E610000001000000050000002B8716D9CE954B40A0C37C7901E449402B8716D9CE954B408FA9BBB20BE449408C65FA25E2974B408FA9BBB20BE449408C65FA25E2974B40A0C37C7901E449402B8716D9CE954B40A0C37C7901E44940
50210	1555	55.136867000000002	55.147728000000001	51.841498000000001	51.834097	 Юных Ленинцев	0103000020E6100000010000000500000069739CDB84914B408A58C4B0C3EA494069739CDB84914B4020D3DA34B6EB49400C5A48C0E8924B4020D3DA34B6EB49400C5A48C0E8924B408A58C4B0C3EA494069739CDB84914B408A58C4B0C3EA4940
50122	1555	55.122045	55.129313000000003	51.717562999999998	51.712612999999997	 Южная	0103000020E61000000100000005000000F6D1A92B9F8F4B402BDA1CE736DB4940F6D1A92B9F8F4B40EAE8B81AD9DB49404DF910548D904B40EAE8B81AD9DB49404DF910548D904B402BDA1CE736DB4940F6D1A92B9F8F4B402BDA1CE736DB4940
50200	1555	55.035259000000003	55.040415000000003	51.793149999999997	51.785251000000002	 Химическая	0103000020E61000000100000005000000E1F1ED5D83844B405E13D21A83E44940E1F1ED5D83844B4044696FF085E5494049A297512C854B4044696FF085E5494049A297512C854B405E13D21A83E44940E1F1ED5D83844B405E13D21A83E44940
50193	1555	55.086804000000001	55.153010000000002	51.797389000000003	51.789000000000001	 Томилинская	0103000020E61000000100000005000000BC94BA641C8B4B40A245B6F3FDE44940BC94BA641C8B4B405798BED710E6494001FBE8D495934B405798BED710E6494001FBE8D495934B40A245B6F3FDE44940BC94BA641C8B4B40A245B6F3FDE44940
51363	1555	55.127012999999998	55.144978999999999	51.787151000000001	51.777070999999999	 Ленинградская	0103000020E610000001000000050000005B9544F641904B40C3D5011077E349405B9544F641904B40C1012D5DC1E44940ABCDFFAB8E924B40C1012D5DC1E44940ABCDFFAB8E924B40C3D5011077E349405B9544F641904B40C3D5011077E34940
50198	1555	55.065344000000003	55.074686	51.789329000000002	51.785117	 Культурная	0103000020E61000000100000005000000B37E33315D884B404E44BFB67EE44940B37E33315D884B40676490BB08E549400ABC934F8F894B40676490BB08E549400ABC934F8F894B404E44BFB67EE44940B37E33315D884B404E44BFB67EE44940
49703	1555	55.080381000000003	55.088690999999997	51.824362000000001	51.823236999999999	 Ворошилова	0103000020E61000000100000005000000221CB3EC498A4B40B7ED7BD45FE94940221CB3EC498A4B405708ABB184E949408A39083A5A8B4B405708ABB184E949408A39083A5A8B4B40B7ED7BD45FE94940221CB3EC498A4B40B7ED7BD45FE94940
50039	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Черемных	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49742	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Фрунзе	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49850	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Уральская	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49848	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Уметбаева	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49817	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	3 Линия	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49925	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Советская	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49746	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Северная	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
50041	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Рудницкого	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49932	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Пушкина	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49846	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Орская	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
50038	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Мира	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49858	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Металлургов	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
50040	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Марии Корецкой	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49842	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	М.Корецкой	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49933	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Комсомольский	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49745	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Зеленая	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49929	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Горького	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
50609	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Гвардеец труда	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
50036	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Гагарина	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
50049	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	Воинов-Интернационалистов	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49744	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	 Советская	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
49697	9385	58.251919000000001	58.406627	51.241717999999999	51.175060000000002	 Зеленая	0103000020E61000000100000005000000DA1EBDE13E204D403C6BB75D68964940DA1EBDE13E204D40616D8C9DF09E4940D655815A0C344D40616D8C9DF09E4940D655815A0C344D403C6BB75D68964940DA1EBDE13E204D403C6BB75D68964940
51370	56164	55.112110000000001	55.113672999999999	51.721960000000003	51.703097999999997	 Центральная	0103000020E61000000100000005000000FCC6D79E598E4B4006F1811DFFD94940FCC6D79E598E4B4095826E2F69DC494017B83CD68C8E4B4095826E2F69DC494017B83CD68C8E4B4006F1811DFFD94940FCC6D79E598E4B4006F1811DFFD94940
49924	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	переулок Коммунальный	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
50011	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Тульская	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
49739	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Советская	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
9918	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Моторная	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
50479	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Молодежная	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
50292	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Мало-Садовая	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
50605	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Лесная	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
49798	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Комсомольская	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
50612	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Коминтерна	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
50281	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Ключевая	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
80956	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	Гагарина проспект	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
49737	4803	57.549633999999998	57.660764999999998	51.475105999999997	51.382691000000001	 Советская	0103000020E6100000010000000500000084622B685AC64C409DBCC804FCB0494084622B685AC64C401211FE45D0BC4940B4AB90F293D44C401211FE45D0BC4940B4AB90F293D44C409DBCC804FCB0494084622B685AC64C409DBCC804FCB04940
49950	49307	55.049092999999999	55.068362	51.878191000000001	51.864255999999997	Ленинская	0103000020E6100000010000000500000034BBEEAD48864B4096AFCBF09FEE494034BBEEAD48864B401E520C9068F0494003250516C0884B401E520C9068F0494003250516C0884B4096AFCBF09FEE494034BBEEAD48864B4096AFCBF09FEE4940
49832	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	пр. Мира	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49920	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Школьная	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49919	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Фестивальная	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49986	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Строителей	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49734	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Северная	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
50358	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Сакмарская	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
50474	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	С.Юлаева	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
50426	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Речная	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
50006	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Оренбургская	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49917	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	Молодёжная	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49831	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	М. Жукова	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49732	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	20 лет Октября	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49918	622	57.298636000000002	57.424751000000001	51.500444000000002	51.442585999999999	 Молодёжная	0103000020E6100000010000000500000042B456B439A64C406FD575A8A6B8494042B456B439A64C405EBD8A8C0EC04940BEF8A23D5EB64C405EBD8A8C0EC04940BEF8A23D5EB64C406FD575A8A6B8494042B456B439A64C406FD575A8A6B84940
49875	49471	54.962909000000003	54.997036000000001	51.740879999999997	51.728202000000003	Центральная	0103000020E610000001000000050000001503249A407B4B40DF701FB935DD49401503249A407B4B405721E527D5DE4940A3772AE09E7F4B405721E527D5DE4940A3772AE09E7F4B40DF701FB935DD49401503249A407B4B40DF701FB935DD4940
49692	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	пр.Победы	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49726	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	пер.Парковый	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49788	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Школьный переулок	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
50000	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Советская	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49790	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Парковый переулок	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49977	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Октябрьская	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49782	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Молодежная	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49727	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Ленина	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49819	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Коммунистическая	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
50626	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Калинина	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49731	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	Декабристов	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
49983	19668	58.391804999999998	58.488301999999997	51.494731000000002	51.427526999999998	 Ленина	0103000020E6100000010000000500000063B48EAA26324D4018946934B9B6494063B48EAA26324D40A0A86C5853BF4940234910AE803E4D40A0A86C5853BF4940234910AE803E4D4018946934B9B6494063B48EAA26324D4018946934B9B64940
50216	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Щорса	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49947	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Челюскинцев	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49718	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Фрунзе	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49818	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Суворова	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49720	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Серго	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49721	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Свердловская	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49816	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Рожкова	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
50342	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Пушкина	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
50382	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Объездная	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49975	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Московская	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49993	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Мельничная	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
50595	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Максима Горького	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
50495	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Линейная	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49722	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Лизы Чайкиной	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49992	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Ленина	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49902	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Крестьянская	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49948	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Кирова/Рожкова	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49909	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Заводская	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49815	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Гая	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49901	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Галактионова	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49997	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	Вокзальная	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49964	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	4 микрорайон	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49725	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	3 микрорайон	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49724	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	1 микрорайон	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
49719	19770	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	1 Линия	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
50268	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	переулок Щорса	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49971	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	пер.Электриков	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49889	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Широкая	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49797	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Челюскина	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49811	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Чапаевская	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49813	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Строителей	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49890	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Победная	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49812	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Некрасова	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49979	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Московская	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49891	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Ленинградская	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49958	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Куйбышевская	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49715	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Красногвардейская	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49712	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Коммунистическая	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49892	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	Белинского	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49814	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	3-й микрорайон	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49716	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	2-й микрорайон	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49895	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	1-й Микрорайон	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
49878	16051	52.379317999999998	52.469985000000001	53.674255000000002	53.583105000000003	 Геологов	0103000020E610000001000000050000005E64027E8D304A402A91442FA3CA4A405E64027E8D304A400E15E3FC4DD64A40274EEE77283C4A400E15E3FC4DD64A40274EEE77283C4A402A91442FA3CA4A405E64027E8D304A402A91442FA3CA4A40
51373	56183	55.112110000000001	55.113672999999999	51.721960000000003	51.703097999999997	Центральная	0103000020E61000000100000005000000FCC6D79E598E4B4006F1811DFFD94940FCC6D79E598E4B4095826E2F69DC494017B83CD68C8E4B4095826E2F69DC494017B83CD68C8E4B4006F1811DFFD94940FCC6D79E598E4B4006F1811DFFD94940
49807	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	Школьная	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
49789	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	Советская	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
49941	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	Снежинская	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
49940	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	Пролетарская	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
49805	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	Коммунистическая	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
49708	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	Комарова	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
49705	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	Заводская	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
49707	3235	53.619694000000003	53.671939999999999	53.713073999999999	53.645057000000001	 Чкалова	0103000020E6100000010000000500000083C30B2252CF4A4027874F3A91D24A4083C30B2252CF4A405FD0420246DB4A40E76F422102D64A405FD0420246DB4A40E76F422102D64A4027874F3A91D24A4083C30B2252CF4A4027874F3A91D24A40
66966	58203	59.791218999999998	59.928769000000003	51.045537000000003	51.002949999999998	Западная	0103000020E61000000100000005000000A67C08AA46E54D40F8C264AA60804940A67C08AA46E54D4005E10A28D4854940F24410E7E1F64D4005E10A28D4854940F24410E7E1F64D40F8C264AA60804940A67C08AA46E54D40F8C264AA60804940
66970	58901	59.256343999999999	60.535876999999999	51.351573000000002	50.812868999999999	Ленина	0103000020E610000001000000050000004E4354E1CFA04D40537765170C6849404E4354E1CFA04D400C94145800AD4940DCD6169E97444E400C94145800AD4940DCD6169E97444E40537765170C6849404E4354E1CFA04D40537765170C684940
50831	19027	60.107362999999999	60.134770000000003	51.234037000000001	51.213002000000003	Центральная	0103000020E6100000010000000500000075E61E12BE0D4E40C6FD47A6439B494075E61E12BE0D4E40E886A6ECF49D4940B03DB32440114E40E886A6ECF49D4940B03DB32440114E40C6FD47A6439B494075E61E12BE0D4E40C6FD47A6439B4940
51156	19090	60.301048000000002	60.324520999999997	51.265101000000001	51.247051999999996	Школьная	0103000020E610000001000000050000005B43A9BD88264E40A83462669F9F49405B43A9BD88264E4086915ED4EEA14940BFEE74E789294E4086915ED4EEA14940BFEE74E789294E40A83462669F9F49405B43A9BD88264E40A83462669F9F4940
50239	19136	60.054721000000001	60.083511999999999	51.077067999999997	51.060341999999999	Набережная	0103000020E61000000100000005000000C4B3041901074E40A1496249B9874940C4B3041901074E40B8C83D5DDD8949406A696E85B00A4E40B8C83D5DDD8949406A696E85B00A4E40A1496249B9874940C4B3041901074E40A1496249B9874940
51089	18381	60.116740999999998	60.151964	51.175714999999997	51.158760000000001	Школьная	0103000020E61000000100000005000000198D7C5EF10E4E40DCF4673F52944940198D7C5EF10E4E40543541D47D964940AD156D8E73134E40543541D47D964940AD156D8E73134E40DCF4673F52944940198D7C5EF10E4E40DCF4673F52944940
51015	18846	60.121896999999997	60.142118000000004	50.976410000000001	50.959449999999997	 Новая	0103000020E61000000100000005000000813D26529A0F4E40D712F241CF7A4940813D26529A0F4E4062BEBC00FB7C4940231631EC30124E4062BEBC00FB7C4940231631EC30124E40D712F241CF7A4940813D26529A0F4E40D712F241CF7A4940
50242	18992	60.067988999999997	60.108485999999999	51.199216999999997	51.180034999999997	Центральная	0103000020E610000001000000050000006EBE11DDB3084E4053910A630B9749406EBE11DDB3084E4053E751F17F994940740987DEE20D4E4053E751F17F994940740987DEE20D4E4053910A630B9749406EBE11DDB3084E4053910A630B974940
51004	18921	60.146034999999998	60.164000999999999	50.947177000000003	50.927788	Школьная	0103000020E6100000010000000500000022895E46B1124E4085CFD6C1C176494022895E46B1124E40FF428F183D79494072C119FCFD144E40FF428F183D79494072C119FCFD144E4085CFD6C1C176494022895E46B1124E4085CFD6C1C1764940
50435	18748	59.769326999999997	59.802349	50.905771999999999	50.888216999999997	Пролетарская	0103000020E610000001000000050000000377A04E79E24D4028603B18B17149400377A04E79E24D40F6D03E56F0734940397D3D5FB3E64D40F6D03E56F0734940397D3D5FB3E64D4028603B18B17149400377A04E79E24D4028603B18B1714940
50879	18670	60.376641999999997	60.402828	50.970874999999999	50.961385	Садовая	0103000020E61000000100000005000000672618CE35304E40B7EEE6A90E7B4940672618CE35304E4083C0CAA1457C4940E0F42EDE8F334E4083C0CAA1457C4940E0F42EDE8F334E40B7EEE6A90E7B4940672618CE35304E40B7EEE6A90E7B4940
50823	18815	59.864072	59.901819000000003	50.909032000000003	50.899887	Центральная	0103000020E61000000100000005000000D5B14AE999EE4D403B8C497F2F734940D5B14AE999EE4D403D821B295B744940AAF413CE6EF34D403D821B295B744940AAF413CE6EF34D403B8C497F2F734940D5B14AE999EE4D403B8C497F2F734940
50826	18445	59.381587000000003	59.430391999999998	51.110714000000002	51.092377999999997	Советская	0103000020E6100000010000000500000015CAC2D7D7B04D40586FD40AD38B494015CAC2D7D7B04D40CC9A58E02B8E4940E23AC61517B74D40CC9A58E02B8E4940E23AC61517B74D40586FD40AD38B494015CAC2D7D7B04D40586FD40AD38B4940
50829	16686	54.915827999999998	54.934899000000001	52.983367999999999	52.972951999999999	Центральная	0103000020E610000001000000050000006B6116DA39754B40F549EEB0897C4A406B6116DA39754B406AF7AB00DF7D4A4014083BC5AA774B406AF7AB00DF7D4A4014083BC5AA774B40F549EEB0897C4A406B6116DA39754B40F549EEB0897C4A40
50854	16904	55.034180999999997	55.048734000000003	52.585430000000002	52.578097999999997	Советская	0103000020E610000001000000050000008192020B60844B4006F1811DFF494A408192020B60844B40740CC85EEF4A4A40051A6CEA3C864B40740CC85EEF4A4A40051A6CEA3C864B4006F1811DFF494A408192020B60844B4006F1811DFF494A40
49779	18115	54.716805999999998	54.779859000000002	52.940148000000001	52.904386000000002	Советская	0103000020E61000000100000005000000CDC98B4CC05B4B40EA7AA2EBC2734A40CDC98B4CC05B4B402DB308C556784A40E23E726BD2634B402DB308C556784A40E23E726BD2634B40EA7AA2EBC2734A40CDC98B4CC05B4B40EA7AA2EBC2734A40
49736	18115	54.716805999999998	54.779859000000002	52.940148000000001	52.904386000000002	Родимцева	0103000020E61000000100000005000000CDC98B4CC05B4B40EA7AA2EBC2734A40CDC98B4CC05B4B402DB308C556784A40E23E726BD2634B402DB308C556784A40E23E726BD2634B40EA7AA2EBC2734A40CDC98B4CC05B4B40EA7AA2EBC2734A40
49780	18115	54.716805999999998	54.779859000000002	52.940148000000001	52.904386000000002	 Калининская	0103000020E61000000100000005000000CDC98B4CC05B4B40EA7AA2EBC2734A40CDC98B4CC05B4B402DB308C556784A40E23E726BD2634B402DB308C556784A40E23E726BD2634B40EA7AA2EBC2734A40CDC98B4CC05B4B40EA7AA2EBC2734A40
50852	46827	54.452558000000003	54.470981999999999	52.902887	52.895695000000003	Мира	0103000020E6100000010000000500000087C5A86BED394B406A183E22A6724A4087C5A86BED394B40E57D1CCD91734A4099805F23493C4B40E57D1CCD91734A4099805F23493C4B406A183E22A6724A4087C5A86BED394B406A183E22A6724A40
51323	47179	54.695695999999998	54.711461	52.798653000000002	52.782837999999998	Молодежная	0103000020E61000000100000005000000A0FA07910C594B4074081C0934644A40A0FA07910C594B4018EDF1423A664A4092B06F27115B4B4018EDF1423A664A4092B06F27115B4B4074081C0934644A40A0FA07910C594B4074081C0934644A40
51202	17852	55.288556999999997	55.323663000000003	52.809714999999997	52.792467000000002	Клубная	0103000020E6100000010000000500000014048F6FEFA44B406214048F6F654A4014048F6FEFA44B40520ABABDA4674A406FF607CA6DA94B40520ABABDA4674A406FF607CA6DA94B406214048F6F654A4014048F6FEFA44B406214048F6F654A40
50238	17708	54.605046999999999	54.652208000000002	53.096668000000001	53.085186999999998	Школьная	0103000020E610000001000000050000007EC51A2E724D4B40AD855968E78A4A407EC51A2E724D4B40ED48F59D5F8C4A4044183F8D7B534B40ED48F59D5F8C4A4044183F8D7B534B40AD855968E78A4A407EC51A2E724D4B40AD855968E78A4A40
51157	56150	55.180418000000003	55.220581000000003	52.687933999999998	52.671495	Молодежная	0103000020E610000001000000050000000CCEE0EF17974B40B936548CF3554A400CCEE0EF17974B403AE7A7380E584A403B8F8AFF3B9C4B403AE7A7380E584A403B8F8AFF3B9C4B40B936548CF3554A400CCEE0EF17974B40B936548CF3554A40
50897	46312	54.582023	54.612592999999997	52.858111999999998	52.837466999999997	Школьная	0103000020E610000001000000050000008942CBBA7F4A4B40573D601E326B4A408942CBBA7F4A4B400F27309DD66D4A4017618A72694E4B400F27309DD66D4A4017618A72694E4B40573D601E326B4A408942CBBA7F4A4B40573D601E326B4A40
51153	46312	54.582023	54.612592999999997	52.858111999999998	52.837466999999997	Молодежная	0103000020E610000001000000050000008942CBBA7F4A4B40573D601E326B4A408942CBBA7F4A4B400F27309DD66D4A4017618A72694E4B400F27309DD66D4A4017618A72694E4B40573D601E326B4A408942CBBA7F4A4B40573D601E326B4A40
50828	17611	54.440969000000003	54.489586000000003	53.076230000000002	53.033839999999998	Советская	0103000020E6100000010000000500000061C614AC71384B40F8A57EDE54844A4061C614AC71384B40AF7C96E7C1894A402C4A09C1AA3E4B40AF7C96E7C1894A402C4A09C1AA3E4B40F8A57EDE54844A4061C614AC71384B40F8A57EDE54844A40
50410	46949	54.761676999999999	54.800277999999999	53.148541000000002	53.130617999999998	Мира	0103000020E61000000100000005000000C58EC6A17E614B406C223317B8904A40C58EC6A17E614B40BD8E386403934A40A9DA6E826F664B40BD8E386403934A40A9DA6E826F664B406C223317B8904A40C58EC6A17E614B406C223317B8904A40
50859	32504	54.732688000000003	54.751139999999999	52.897953999999999	52.889690999999999	Школьная	0103000020E61000000100000005000000F9156BB8C85D4B40D4450A65E1714A40F9156BB8C85D4B40FCA71B28F0724A40D55B035B25604B40FCA71B28F0724A40D55B035B25604B40D4450A65E1714A40F9156BB8C85D4B40D4450A65E1714A40
51327	14080	54.977936999999997	55.030174000000002	52.897460000000002	52.876432000000001	пер. Школьный	0103000020E610000001000000050000003046240A2D7D4B407D957CEC2E704A403046240A2D7D4B40EDBB22F8DF724A404298DBBDDC834B40EDBB22F8DF724A404298DBBDDC834B407D957CEC2E704A403046240A2D7D4B407D957CEC2E704A40
51331	14080	54.977936999999997	55.030174000000002	52.897460000000002	52.876432000000001	Школьный переулок	0103000020E610000001000000050000003046240A2D7D4B407D957CEC2E704A403046240A2D7D4B40EDBB22F8DF724A404298DBBDDC834B40EDBB22F8DF724A404298DBBDDC834B407D957CEC2E704A403046240A2D7D4B407D957CEC2E704A40
64073	58162	55.266171	55.292788000000002	52.785752000000002	52.764915000000002	Красноармейская	0103000020E6100000010000000500000062122EE411A24B40249C16BCE8614A4062122EE411A24B402062838593644A40A454C2137AA54B402062838593644A40A454C2137AA54B40249C16BCE8614A4062122EE411A24B40249C16BCE8614A40
51013	47094	54.677737999999998	54.702055999999999	53.022775000000003	53.015932999999997	Школьная	0103000020E61000000100000005000000D3A0681EC0564B40ADF6B0170A824A40D3A0681EC0564B404D158C4AEA824A40F4FA93F8DC594B404D158C4AEA824A40F4FA93F8DC594B40ADF6B0170A824A40D3A0681EC0564B40ADF6B0170A824A40
51325	46863	55.107897000000001	55.151716999999998	52.797781999999998	52.779156	Парадеевская	0103000020E61000000100000005000000132BA391CF8D4B40B83D4162BB634A40132BA391CF8D4B4032AB77B81D664A40A59F70766B934B4032AB77B81D664A40A59F70766B934B40B83D4162BB634A40132BA391CF8D4B40B83D4162BB634A40
50877	16963	54.806843999999998	54.832903999999999	52.756348000000003	52.741287	пер.Культурный	0103000020E61000000100000005000000A67C08AA46674B4098F90E7EE25E4A40A67C08AA46674B409032E202D0604A40925A28999C6A4B409032E202D0604A40925A28999C6A4B4098F90E7EE25E4A40A67C08AA46674B4098F90E7EE25E4A40
50436	16983	54.405540000000002	54.434403000000003	52.934275999999997	52.911658000000003	Школьная	0103000020E61000000100000005000000249C16BCE8334B4082919735B1744A40249C16BCE8334B4006B8205B96774A4064247B849A374B4006B8205B96774A4064247B849A374B4082919735B1744A40249C16BCE8334B4082919735B1744A40
51414	56205	54.851365000000001	54.885626999999999	52.926746999999999	52.904522	Родимцева	0103000020E61000000100000005000000C2FA3F87F96C4B409A417C60C7734A40C2FA3F87F96C4B4043554CA59F764A4030BABC395C714B4043554CA59F764A4030BABC395C714B409A417C60C7734A40C2FA3F87F96C4B409A417C60C7734A40
50857	47216	54.775402999999997	54.787278999999998	52.841259000000001	52.828153	Верхняя	0103000020E61000000100000005000000321CCF6740634B40CA8AE1EA006A4A40321CCF6740634B409B3BFA5FAE6B4A40EEE9EA8EC5644B409B3BFA5FAE6B4A40EEE9EA8EC5644B40CA8AE1EA006A4A40321CCF6740634B40CA8AE1EA006A4A40
51404	56200	54.759359000000003	54.773345999999997	53.044901000000003	53.033580000000001	Школьная	0103000020E610000001000000050000002E76FBAC32614B405CE674594C844A402E76FBAC32614B406347E350BF854A40073F7100FD624B406347E350BF854A40073F7100FD624B405CE674594C844A402E76FBAC32614B405CE674594C844A40
50821	46645	54.955452999999999	54.995769000000003	52.964176999999999	52.945715999999997	Центральная	0103000020E61000000100000005000000BBEEAD484C7A4B40E7A6CD380D794A40BBEEAD484C7A4B401747E5266A7B4A4071AFCC5B757F4B401747E5266A7B4A4071AFCC5B757F4B40E7A6CD380D794A40BBEEAD484C7A4B40E7A6CD380D794A40
51098	16596	54.857545000000002	54.881996999999998	52.718508	52.695483000000003	Средняя	0103000020E6100000010000000500000096ECD808C46D4B4045F6419605594A4096ECD808C46D4B400AF5F411F85B4A40C6151747E5704B400AF5F411F85B4A40C6151747E5704B4045F6419605594A4096ECD808C46D4B4045F6419605594A40
50999	18348	54.665844999999997	54.723804000000001	52.978949	52.953902999999997	Библиотечный переулок	0103000020E61000000100000005000000419AB1683A554B403447567E197A4A40419AB1683A554B40D8B969334E7D4A40645B069CA55C4B40D8B969334E7D4A40645B069CA55C4B403447567E197A4A40419AB1683A554B403447567E197A4A40
51152	16761	54.543152999999997	54.573174999999999	52.896769999999997	52.865164	Новая	0103000020E61000000100000005000000B5DC990986454B4099D6A6B1BD6E4A40B5DC990986454B405704FF5BC9724A4041F163CC5D494B405704FF5BC9724A4041F163CC5D494B4099D6A6B1BD6E4A40B5DC990986454B4099D6A6B1BD6E4A40
50847	56120	54.879662000000003	54.896163999999999	53.213341999999997	53.202739000000001	Мира	0103000020E6100000010000000500000059C4B0C398704B40D74FFF59F3994A4059C4B0C398704B407E6E68CA4E9B4A4020ED7F80B5724B407E6E68CA4E9B4A4020ED7F80B5724B40D74FFF59F3994A4059C4B0C398704B40D74FFF59F3994A40
51155	47019	54.652568000000002	54.688222000000003	53.222217000000001	53.203921000000001	Школьная	0103000020E610000001000000050000004435255987534B40DBFB54151A9A4A404435255987534B40C0CE4D9B719C4A40A13193A817584B40C0CE4D9B719C4A40A13193A817584B40DBFB54151A9A4A404435255987534B40DBFB54151A9A4A40
61844	16521	54.903216	54.937027999999998	52.681852999999997	52.661943000000001	Центральная	0103000020E61000000100000005000000AA9CF6949C734B407768588CBA544A40AA9CF6949C734B40F9D687F546574A40D8B79388F0774B40F9D687F546574A40D8B79388F0774B407768588CBA544A40AA9CF6949C734B407768588CBA544A40
50824	16521	54.903216	54.937027999999998	52.681852999999997	52.661943000000001	Салмыш	0103000020E61000000100000005000000AA9CF6949C734B407768588CBA544A40AA9CF6949C734B40F9D687F546574A40D8B79388F0774B40F9D687F546574A40D8B79388F0774B407768588CBA544A40AA9CF6949C734B407768588CBA544A40
51322	46582	54.542102	54.548965000000003	53.113444000000001	53.104999999999997	Школьная	0103000020E61000000100000005000000508C2C9963454B403D0AD7A3708D4A40508C2C9963454B40B6F63E55858E4A4007D3307C44464B40B6F63E55858E4A4007D3307C44464B403D0AD7A3708D4A40508C2C9963454B403D0AD7A3708D4A40
50723	46945	54.956494999999997	54.967212000000004	52.850634999999997	52.842911999999998	Советская	0103000020E61000000100000005000000CDE49B6D6E7A4B40F6B3588AE46B4A40CDE49B6D6E7A4B409EEA909BE16C4A403E26529ACD7B4B409EEA909BE16C4A403E26529ACD7B4B40F6B3588AE46B4A40CDE49B6D6E7A4B40F6B3588AE46B4A40
51104	46547	55.049506000000001	55.064140000000002	52.733223000000002	52.684713000000002	Молодежная	0103000020E61000000100000005000000577A6D3656864B40B212F3ACA4574A40577A6D3656864B4067D65240DA5D4A40C72E51BD35884B4067D65240DA5D4A40C72E51BD35884B40B212F3ACA4574A40577A6D3656864B40B212F3ACA4574A40
51324	17996	54.649890999999997	54.672187000000001	52.841123000000003	52.822814999999999	Новая	0103000020E610000001000000050000007C7BD7A02F534B4041D47D0052694A407C7BD7A02F534B40EB7420EBA96B4A40EFE53E390A564B40EB7420EBA96B4A40EFE53E390A564B4041D47D0052694A407C7BD7A02F534B4041D47D0052694A40
49777	14996	56.135649999999998	56.178823000000001	52.357092999999999	52.333661999999997	Октябрьская	0103000020E61000000100000005000000E8D9ACFA5C114C407FF5B86FB52A4A40E8D9ACFA5C114C40B5503239B52D4A40E5620CACE3164C40B5503239B52D4A40E5620CACE3164C407FF5B86FB52A4A40E8D9ACFA5C114C407FF5B86FB52A4A40
49735	14996	56.135649999999998	56.178823000000001	52.357092999999999	52.333661999999997	М.Горького	0103000020E61000000100000005000000E8D9ACFA5C114C407FF5B86FB52A4A40E8D9ACFA5C114C40B5503239B52D4A40E5620CACE3164C40B5503239B52D4A40E5620CACE3164C407FF5B86FB52A4A40E8D9ACFA5C114C407FF5B86FB52A4A40
80944	45989	56.368817	56.404299999999999	52.337997999999999	52.310707999999998	площадь Коммунаров	0103000020E61000000100000005000000BB9A3C65352F4C40834D9D47C5274A40BB9A3C65352F4C40840EBA84432B4A40EBE2361AC0334C40840EBA84432B4A40EBE2361AC0334C40834D9D47C5274A40BB9A3C65352F4C40834D9D47C5274A40
49774	12374	56.210380999999998	56.260103000000001	52.423743000000002	52.394770000000001	Довженко	0103000020E610000001000000050000009259BDC3ED1A4C4091B8C7D287324A409259BDC3ED1A4C405874EB353D364A40B64B1B0E4B214C405874EB353D364A40B64B1B0E4B214C4091B8C7D287324A409259BDC3ED1A4C4091B8C7D287324A40
80953	46187	55.858601	55.891308000000002	52.490170999999997	52.477227999999997	Советская	0103000020E610000001000000050000000DA837A3E6ED4B40245E9ECE153D4A400DA837A3E6ED4B404B395FECBD3E4A40E3546B6116F24B404B395FECBD3E4A40E3546B6116F24B40245E9ECE153D4A400DA837A3E6ED4B40245E9ECE153D4A40
80945	62031	56.409968999999997	56.427000999999997	52.421441999999999	52.393988999999998	Николаевская	0103000020E61000000100000005000000D9AF3BDD79344C40EBFD463B6E324A40D9AF3BDD79344C409694BBCFF1354A40FD2D01F8A7364C409694BBCFF1354A40FD2D01F8A7364C40EBFD463B6E324A40D9AF3BDD79344C40EBFD463B6E324A40
80975	62041	56.188085000000001	56.202646999999999	52.297415000000001	52.283555	Ленинская	0103000020E6100000010000000500000020EF552B13184C4003CFBD874B244A4020EF552B13184C40802BD9B111264A40F6D03E56F0194C40802BD9B111264A40F6D03E56F0194C4003CFBD874B244A4020EF552B13184C4003CFBD874B244A40
80979	46391	56.087887000000002	56.120477999999999	52.184767000000001	52.162354000000001	Школьная	0103000020E610000001000000050000002D5F97E13F0B4C40F92F1004C8144A402D5F97E13F0B4C40A530EF71A6174A4099F1B6D26B0F4C40A530EF71A6174A4099F1B6D26B0F4C40F92F1004C8144A402D5F97E13F0B4C40F92F1004C8144A40
80949	62036	56.012490999999997	56.027520000000003	52.507227	52.492902000000001	Молодежная	0103000020E61000000100000005000000463F1A4E99014C400611A969173F4A40463F1A4E99014C40F85278D0EC404A4033FE7DC685034C40F85278D0EC404A4033FE7DC685034C400611A969173F4A40463F1A4E99014C400611A969173F4A40
80946	62033	56.283738	56.327423000000003	52.329292000000002	52.316665	Мира	0103000020E61000000100000005000000F450DB8651244C40D8648D7A88284A40F450DB8651244C40CF6A813D262A4A40A77A32FFE8294C40CF6A813D262A4A40A77A32FFE8294C40D8648D7A88284A40F450DB8651244C40D8648D7A88284A40
80970	46290	56.029226999999999	56.058638000000002	52.290508000000003	52.274149999999999	Мельник	0103000020E610000001000000050000008194D8B5BD034C406519E25817234A408194D8B5BD034C40FA9CBB5D2F254A40C426327381074C40FA9CBB5D2F254A40C426327381074C406519E25817234A408194D8B5BD034C406519E25817234A40
64181	46435	55.752851	55.778345000000002	52.222541	52.207284000000001	Школьная	0103000020E6100000010000000500000065E1EB6B5DE04B40F67D3848881A4A4065E1EB6B5DE04B40738236397C1C4A40A80018CFA0E34B40738236397C1C4A40A80018CFA0E34B40F67D3848881A4A4065E1EB6B5DE04B40F67D3848881A4A40
80982	46435	55.752851	55.778345000000002	52.222541	52.207284000000001	Екатериновка	0103000020E6100000010000000500000065E1EB6B5DE04B40F67D3848881A4A4065E1EB6B5DE04B40738236397C1C4A40A80018CFA0E34B40738236397C1C4A40A80018CFA0E34B40F67D3848881A4A4065E1EB6B5DE04B40F67D3848881A4A40
80958	46206	55.994928999999999	56.027295000000002	52.357593999999999	52.348517999999999	переулок Быстроновского	0103000020E61000000100000005000000C66B5ED559FF4B409E08E23C9C2C4A40C66B5ED559FF4B40779FE3A3C52D4A40132C0E677E034C40779FE3A3C52D4A40132C0E677E034C409E08E23C9C2C4A40C66B5ED559FF4B409E08E23C9C2C4A40
80984	46485	55.951090999999998	55.973064000000001	52.198762000000002	52.185662000000001	Молодежная	0103000020E610000001000000050000008D429259BDF94B40130EBDC5C3174A408D429259BDF94B4002D8800871194A401D75745C8DFC4B4002D8800871194A401D75745C8DFC4B40130EBDC5C3174A408D429259BDF94B40130EBDC5C3174A40
80963	46250	55.937635	55.956004999999998	52.365611999999999	52.354788999999997	Школьная	0103000020E61000000100000005000000E04A766C04F84B4082FDD7B9692D4A40E04A766C04F84B403883BF5FCC2E4A40FFE7305F5EFA4B403883BF5FCC2E4A40FFE7305F5EFA4B4082FDD7B9692D4A40E04A766C04F84B4082FDD7B9692D4A40
50586	46763	55.966712999999999	55.990428999999999	52.205131999999999	52.199959999999997	пер. Аксаковский	0103000020E610000001000000050000001CCF6740BDFB4B400B410E4A98194A401CCF6740BDFB4B4079AEEFC3411A4A404701A260C6FE4B4079AEEFC3411A4A404701A260C6FE4B400B410E4A98194A401CCF6740BDFB4B400B410E4A98194A40
49906	13158	52.797888	52.865611999999999	52.558601000000003	52.534317999999999	Победы	0103000020E6100000010000000500000078EFA83121664A4002D53F8864444A4078EFA83121664A40A741D13C80474A403883BF5FCC6E4A40A741D13C80474A403883BF5FCC6E4A4002D53F8864444A4078EFA83121664A4002D53F8864444A40
49776	13158	52.797888	52.865611999999999	52.558601000000003	52.534317999999999	Жукова	0103000020E6100000010000000500000078EFA83121664A4002D53F8864444A4078EFA83121664A40A741D13C80474A403883BF5FCC6E4A40A741D13C80474A403883BF5FCC6E4A4002D53F8864444A4078EFA83121664A4002D53F8864444A40
50075	13014	52.709242000000003	52.795183999999999	52.537084	52.509248999999997	Терешковой	0103000020E610000001000000050000008E791D71C85A4A40A6423C122F414A408E791D71C85A4A40399A232BBF444A40B726DD96C8654A40399A232BBF444A40B726DD96C8654A40A6423C122F414A408E791D71C85A4A40A6423C122F414A40
9890	13014	52.709242000000003	52.795183999999999	52.537084	52.509248999999997	Красная Площадь	0103000020E610000001000000050000008E791D71C85A4A40A6423C122F414A408E791D71C85A4A40399A232BBF444A40B726DD96C8654A40399A232BBF444A40B726DD96C8654A40A6423C122F414A408E791D71C85A4A40A6423C122F414A40
50235	14497	52.385435000000001	52.409528000000002	52.434835	52.425488999999999	Победы	0103000020E61000000100000005000000ECDD1FEF55314A4064E76D6C76364A40ECDD1FEF55314A40FD135CACA8374A40ED65DB696B344A40FD135CACA8374A40ED65DB696B344A4064E76D6C76364A40ECDD1FEF55314A4064E76D6C76364A40
50816	45617	52.288687000000003	52.301569000000001	52.165967000000002	52.158244000000003	Мира	0103000020E61000000100000005000000E3E313B2F3244A40E564E25641144A40E3E313B2F3244A408D9B1A683E154A40643E20D099264A408D9B1A683E154A40643E20D099264A40E564E25641144A40E3E313B2F3244A40E564E25641144A40
50837	13714	52.580559000000001	52.589334999999998	52.242161000000003	52.230474000000001	Парковая	0103000020E610000001000000050000000133DFC14F4A4A40064A0A2C801D4A400133DFC14F4A4A40EFAEB321FF1E4A40AFB14B546F4B4A40EFAEB321FF1E4A40AFB14B546F4B4A40064A0A2C801D4A400133DFC14F4A4A40064A0A2C801D4A40
50815	14193	52.443708999999998	52.458602999999997	52.158088999999997	52.149464000000002	Центральная	0103000020E610000001000000050000006EF8DD74CB384A40F5F6E7A221134A406EF8DD74CB384A40BD6DA6423C144A407A6CCB80B33A4A40BD6DA6423C144A407A6CCB80B33A4A40F5F6E7A221134A406EF8DD74CB384A40F5F6E7A221134A40
51074	13893	52.750034999999997	52.769582	52.092525000000002	52.082071999999997	Рябинная	0103000020E610000001000000050000007CED992501604A406AF5D555810A4A407CED992501604A40FD87F4DBD70B4A408ECBB8A981624A40FD87F4DBD70B4A408ECBB8A981624A406AF5D555810A4A407CED992501604A406AF5D555810A4A40
51382	56189	52.628743999999998	52.641616999999997	52.315955000000002	52.296368000000001	Советская	0103000020E6100000010000000500000032C7F2AE7A504A405CCAF962EF254A4032C7F2AE7A504A40FC00A43671284A4060C77F8120524A40FC00A43671284A4060C77F8120524A405CCAF962EF254A4032C7F2AE7A504A405CCAF962EF254A40
49907	49542	52.777450999999999	52.830865000000003	52.511178999999998	52.501201999999999	2-я линия	0103000020E610000001000000050000000A9FAD8383634A404B581B6327404A400A9FAD8383634A4074B33F506E414A400E32C9C8596A4A4074B33F506E414A400E32C9C8596A4A404B581B6327404A400A9FAD8383634A404B581B6327404A40
51348	14813	52.483764999999998	52.530486000000003	52.620817000000002	52.589188999999998	Элеваторная	0103000020E6100000010000000500000087F9F202EC3D4A40DB148F8B6A4B4A4087F9F202EC3D4A4082E673EE764F4A40317E1AF7E6434A4082E673EE764F4A40317E1AF7E6434A40DB148F8B6A4B4A4087F9F202EC3D4A40DB148F8B6A4B4A40
50247	14813	52.483764999999998	52.530486000000003	52.620817000000002	52.589188999999998	Ленина	0103000020E6100000010000000500000087F9F202EC3D4A40DB148F8B6A4B4A4087F9F202EC3D4A4082E673EE764F4A40317E1AF7E6434A4082E673EE764F4A40317E1AF7E6434A40DB148F8B6A4B4A4087F9F202EC3D4A40DB148F8B6A4B4A40
51312	49454	52.615090000000002	52.627181	52.573337000000002	52.567031	Майская	0103000020E610000001000000050000005F0CE544BB4E4A40BA68C87894484A405F0CE544BB4E4A401B4B581B63494A4017D68D7747504A401B4B581B63494A4017D68D7747504A40BA68C87894484A405F0CE544BB4E4A40BA68C87894484A40
51375	56185	52.697187	52.716670999999998	52.424588999999997	52.397001000000003	Центральная	0103000020E610000001000000050000002219726C3D594A405ABDC3EDD0324A402219726C3D594A40E49EAEEE58364A40ED7E15E0BB5B4A40E49EAEEE58364A40ED7E15E0BB5B4A405ABDC3EDD0324A402219726C3D594A405ABDC3EDD0324A40
50853	45684	52.178077000000002	52.190635999999998	52.106959000000003	52.094185000000003	Центральная	0103000020E61000000100000005000000BC95253ACB164A400B630B410E0C4A40BC95253ACB164A40A6811FD5B00D4A405AB8ACC266184A40A6811FD5B00D4A405AB8ACC266184A400B630B410E0C4A40BC95253ACB164A400B630B410E0C4A40
51326	46022	52.543889	52.554687000000001	52.138852999999997	52.130611000000002	Шоссейная	0103000020E61000000100000005000000BBD39D279E454A40BABF7ADCB7104A40BBD39D279E454A40CAF962EFC5114A401842CEFBFF464A40CAF962EFC5114A401842CEFBFF464A40BABF7ADCB7104A40BBD39D279E454A40BABF7ADCB7104A40
50813	13524	52.776274000000001	52.790683000000001	52.330249999999999	52.315503	Центральная	0103000020E61000000100000005000000185E49F25C634A401B65FD6662284A40185E49F25C634A4083C0CAA1452A4A406840BD1935654A4083C0CAA1452A4A406840BD1935654A401B65FD6662284A40185E49F25C634A401B65FD6662284A40
50817	45639	52.255395	52.275868000000003	52.161929000000001	52.154398999999998	Центральная	0103000020E61000000100000005000000ED478AC8B0204A407EC4AF58C3134A40ED478AC8B0204A4012A3E716BA144A40A80183A44F234A4012A3E716BA144A40A80183A44F234A407EC4AF58C3134A40ED478AC8B0204A407EC4AF58C3134A40
50660	13977	52.725878999999999	52.738725000000002	52.104436999999997	52.095435999999999	1-я сторона	0103000020E6100000010000000500000035ED629AE95C4A40376E313F370C4A4035ED629AE95C4A4005BF0D315E0D4A406ADE718A8E5E4A4005BF0D315E0D4A406ADE718A8E5E4A40376E313F370C4A4035ED629AE95C4A40376E313F370C4A40
51321	45361	52.654975	52.674100000000003	52.357258000000002	52.345222	Новая	0103000020E610000001000000050000004B598638D6534A400BEE073C302C4A404B598638D6534A40001E51A1BA2D4A40E71DA7E848564A40001E51A1BA2D4A40E71DA7E848564A400BEE073C302C4A404B598638D6534A400BEE073C302C4A40
51318	13951	52.751921000000003	52.770301000000003	52.168182000000002	52.154508999999997	Нахаловка	0103000020E610000001000000050000007B1684F23E604A4005F86EF3C6134A407B1684F23E604A4050E3DEFC86154A40BE89213999624A4050E3DEFC86154A40BE89213999624A4005F86EF3C6134A407B1684F23E604A4005F86EF3C6134A40
50820	14356	52.35624	52.384627000000002	52.165922999999999	52.156255000000002	Центральная	0103000020E6100000010000000500000076C3B645992D4A40126BF12900144A4076C3B645992D4A40BD5301F73C154A404D1421753B314A40BD5301F73C154A404D1421753B314A40126BF12900144A4076C3B645992D4A40126BF12900144A40
51076	14656	52.317729	52.347957999999998	52.383195000000001	52.363428999999996	Большой Плант	0103000020E61000000100000005000000D2FE0758AB284A4080B56AD7842E4A40D2FE0758AB284A40D07EA4880C314A40D73043E3892C4A40D07EA4880C314A40D73043E3892C4A4080B56AD7842E4A40D2FE0758AB284A4080B56AD7842E4A40
50846	14474	52.300356000000001	52.312932000000004	52.177069000000003	52.167259999999999	Центральная	0103000020E610000001000000050000002594BE1072264A40E8F692C668154A402594BE1072264A4056116E32AA164A409AEFE0270E284A4056116E32AA164A409AEFE0270E284A40E8F692C668154A402594BE1072264A40E8F692C668154A40
51079	13808	52.713580999999998	52.733524000000003	52.225416000000003	52.210501999999998	Центральная	0103000020E610000001000000050000000306499F565B4A400DDFC2BAF11A4A400306499F565B4A4061FF756EDA1C4A40626A4B1DE45D4A4061FF756EDA1C4A40626A4B1DE45D4A400DDFC2BAF11A4A400306499F565B4A400DDFC2BAF11A4A40
50818	56117	52.447535999999999	52.466211999999999	52.405006	52.386206999999999	Казанская	0103000020E610000001000000050000002EE411DC48394A403E3E213B6F314A402EE411DC48394A408657923CD7334A405A80B6D5AC3B4A408657923CD7334A405A80B6D5AC3B4A403E3E213B6F314A402EE411DC48394A403E3E213B6F314A40
51078	14715	52.390214	52.405064000000003	52.456938999999998	52.444695000000003	Центральная	0103000020E610000001000000050000007E384888F2314A40EDD808C4EB384A407E384888F2314A402BA226FA7C3A4A40BB641C23D9334A402BA226FA7C3A4A40BB641C23D9334A40EDD808C4EB384A407E384888F2314A40EDD808C4EB384A40
51175	14132	52.450186000000002	52.472949	52.114697	52.103606999999997	Школьная	0103000020E61000000100000005000000FC8EE1B19F394A407E5182FE420D4A40FC8EE1B19F394A4083F92B64AE0E4A4084D6C397893C4A4083F92B64AE0E4A4084D6C397893C4A407E5182FE420D4A40FC8EE1B19F394A407E5182FE420D4A40
50849	14869	52.454714000000003	52.472689000000003	52.532412000000001	52.521628999999997	Мира	0103000020E6100000010000000500000045847F11343A4A4095D233BDC4424A4045847F11343A4A40BDFF8F1326444A40E816BA12813C4A40BDFF8F1326444A40E816BA12813C4A4095D233BDC4424A4045847F11343A4A4095D233BDC4424A40
50851	45717	52.363517000000002	52.378456	52.284860999999999	52.276674	Дружнинская	0103000020E6100000010000000500000020459DB9872E4A40A6D3BA0D6A234A4020459DB9872E4A40F373435376244A40CC7C073F71304A40F373435376244A40CC7C073F71304A40A6D3BA0D6A234A4020459DB9872E4A40A6D3BA0D6A234A40
50433	13853	52.646261000000003	52.661155000000001	52.115088999999998	52.107435000000002	Молодёжная	0103000020E6100000010000000500000013D731AEB8524A400FB9196EC00D4A4013D731AEB8524A408E90813CBB0E4A401F4B1FBAA0544A408E90813CBB0E4A401F4B1FBAA0544A400FB9196EC00D4A4013D731AEB8524A400FB9196EC00D4A40
51077	14045	52.667254999999997	52.686506000000001	52.108269999999997	52.102361999999999	Центральная	0103000020E61000000100000005000000D68BA19C68554A40342DB1321A0D4A40D68BA19C68554A40A79196CADB0D4A40FF40B96DDF574A40A79196CADB0D4A40FF40B96DDF574A40342DB1321A0D4A40D68BA19C68554A40342DB1321A0D4A40
50540	45368	52.605854999999998	52.638024000000001	52.200947999999997	52.167541999999997	пер. Парковый	0103000020E610000001000000050000001D8F19A88C4D4A406C5A290472154A401D8F19A88C4D4A402A1900AAB8194A4014083BC5AA514A402A1900AAB8194A4014083BC5AA514A406C5A290472154A401D8F19A88C4D4A406C5A290472154A40
51319	13724	52.596719	52.609278000000003	52.137366	52.129272999999998	Школьная	0103000020E610000001000000050000006FF3C649614C4A40BEA085048C104A406FF3C649614C4A408ACA863595114A400E164ED2FC4D4A408ACA863595114A400E164ED2FC4D4A40BEA085048C104A406FF3C649614C4A40BEA085048C104A40
50533	49363	53.068389000000003	53.089103999999999	51.726858	51.709392999999999	Комарова	0103000020E61000000100000005000000FD3383F8C0884A407381CB63CDDA4940FD3383F8C0884A40016BD5AE09DD4940ADF886C2678B4A40016BD5AE09DD4940ADF886C2678B4A407381CB63CDDA4940FD3383F8C0884A407381CB63CDDA4940
50997	11227	52.866698999999997	52.882896000000002	51.766320999999998	51.759324999999997	 Центральная	0103000020E61000000100000005000000EA3C2AFEEF6E4A408104C58F31E14940EA3C2AFEEF6E4A40779E78CE16E2494076E272BC02714A40779E78CE16E2494076E272BC02714A408104C58F31E14940EA3C2AFEEF6E4A408104C58F31E14940
50810	49035	52.649962000000002	52.672105999999999	51.993121000000002	51.983243999999999	Подгорная	0103000020E6100000010000000500000046D26EF431534A407EFE7BF0DAFD494046D26EF431534A4044FCC3961EFF494002B9C49107564A4044FCC3961EFF494002B9C49107564A407EFE7BF0DAFD494046D26EF431534A407EFE7BF0DAFD4940
50993	12764	52.845759000000001	52.879536000000002	52.088303000000003	52.073210000000003	Молодежная	0103000020E610000001000000050000001AA6B6D4416C4A40BEDEFDF15E094A401AA6B6D4416C4A40C19140834D0B4A40CCD3B9A294704A40C19140834D0B4A40CCD3B9A294704A40BEDEFDF15E094A401AA6B6D4416C4A40BEDEFDF15E094A40
50862	25520	52.930757999999997	52.947242000000003	51.803527000000003	51.792698999999999	Нагорная	0103000020E61000000100000005000000C43E011423774A4034492C2977E54940C43E011423774A40FC3905F9D9E64940E6B2D1393F794A40FC3905F9D9E64940E6B2D1393F794A4034492C2977E54940C43E011423774A4034492C2977E54940
50253	12602	52.666499999999999	52.687719000000001	51.905754000000002	51.893355999999997	Советская	0103000020E610000001000000050000005A643BDF4F554A40BAD7497D59F249405A643BDF4F554A40501C40BFEFF349403EEB1A2D07584A40501C40BFEFF349403EEB1A2D07584A40BAD7497D59F249405A643BDF4F554A40BAD7497D59F24940
51072	12705	52.680594999999997	52.692255000000003	51.879136000000003	51.859555999999998	Школьная	0103000020E610000001000000050000001A69A9BC1D574A40508A56EE05EE49401A69A9BC1D574A403E5E488787F049400ABFD4CF9B584A403E5E488787F049400ABFD4CF9B584A40508A56EE05EE49401A69A9BC1D574A40508A56EE05EE4940
50071	49229	52.727666999999997	52.766824	51.776598	51.751748999999997	Советская	0103000020E6100000010000000500000070B03731245D4A407DE6AC4F39E0494070B03731245D4A40CB11329067E34940DAE4F04927624A40CB11329067E34940DAE4F04927624A407DE6AC4F39E0494070B03731245D4A407DE6AC4F39E04940
51081	46279	52.502028000000003	52.531295	51.774346000000001	51.757798000000001	Горная	0103000020E6100000010000000500000091D6187442404A40B37C5D86FFE0494091D6187442404A40EBE40CC51DE34940A0C37C7901444A40EBE40CC51DE34940A0C37C7901444A40B37C5D86FFE0494091D6187442404A40B37C5D86FFE04940
51068	56143	53.030856999999997	53.052785	52.073244000000003	52.059103	Советская	0103000020E6100000010000000500000024ED461FF3834A40390CE6AF90074A4024ED461FF3834A406A50340F60094A40145CACA8C1864A406A50340F60094A40145CACA8C1864A40390CE6AF90074A4024ED461FF3834A40390CE6AF90074A40
51320	49405	53.001652999999997	53.026114	51.807665	51.797139000000001	Восточная	0103000020E610000001000000050000005B785E2A36804A40DEAE97A608E649405B785E2A36804A40DA8F149161E74940DFFB1BB457834A40DA8F149161E74940DFFB1BB457834A40DEAE97A608E649405B785E2A36804A40DEAE97A608E64940
50404	11890	52.595847999999997	52.616580999999996	51.503056999999998	51.485813999999998	Набережная	0103000020E6100000010000000500000089B14CBF444C4A402FF834272FBE494089B14CBF444C4A400E83F92B64C04940E02A4F20EC4E4A400E83F92B64C04940E02A4F20EC4E4A402FF834272FBE494089B14CBF444C4A402FF834272FBE4940
51067	11985	52.403131999999999	52.416435999999997	51.688392999999998	51.677610999999999	Центральная	0103000020E610000001000000050000004CFC51D499334A4076340EF5BBD649404CFC51D499334A40CDE506431DD8494043705CC64D354A40CDE506431DD8494043705CC64D354A4076340EF5BBD649404CFC51D499334A4076340EF5BBD64940
51402	56201	52.855550999999998	52.869816	51.862526000000003	51.852826	Школьная	0103000020E61000000100000005000000B187F6B1826D4A40D996016729ED4940B187F6B1826D4A4090F9804067EE4940CEC47421566F4A4090F9804067EE4940CEC47421566F4A40D996016729ED4940B187F6B1826D4A40D996016729ED4940
50401	49061	53.187567999999999	53.220644	51.894201000000002	51.872948000000001	Центральная	0103000020E6100000010000000500000058E36C3A02984A40E78D93C2BCEF494058E36C3A02984A407786A92D75F24940810706103E9C4A407786A92D75F24940810706103E9C4A40E78D93C2BCEF494058E36C3A02984A40E78D93C2BCEF4940
51234	11613	52.746361	52.760913000000002	51.948374000000001	51.941611999999999	Центральная	0103000020E610000001000000050000004301DBC1885F4A40B5C2F4BD86F849404301DBC1885F4A403830B95164F94940F60CE19865614A403830B95164F94940F60CE19865614A40B5C2F4BD86F849404301DBC1885F4A40B5C2F4BD86F84940
50995	11604	52.693989000000002	52.718333000000001	51.939329999999998	51.916677	Центральная	0103000020E610000001000000050000005264ADA1D4584A4069FF03AC55F549405264ADA1D4584A406A1327F73BF849409C51F355F25B4A406A1327F73BF849409C51F355F25B4A4069FF03AC55F549405264ADA1D4584A4069FF03AC55F54940
51070	11915	52.472824000000003	52.481205000000003	51.658226999999997	51.643312999999999	 Школьная	0103000020E61000000100000005000000C861307F853C4A40BB0B941458D24940C861307F853C4A400E2C47C840D44940FAD51C20983D4A400E2C47C840D44940FAD51C20983D4A40BB0B941458D24940C861307F853C4A40BB0B941458D24940
50806	48756	52.912567000000003	52.932679999999998	51.939768999999998	51.929329000000003	Школьная	0103000020E610000001000000050000005534D6FECE744A40B91CAF40F4F649405534D6FECE744A40B665C0594AF849400FD1E80E62774A40B665C0594AF849400FD1E80E62774A40B91CAF40F4F649405534D6FECE744A40B91CAF40F4F64940
51313	12105	52.975718000000001	53.004401999999999	52.093626	52.085873999999997	Дружбы	0103000020E610000001000000050000002C0FD253E47C4A40D1C952EBFD0A4A402C0FD253E47C4A401407D0EFFB0B4A40BC04A73E90804A401407D0EFFB0B4A40BC04A73E90804A40D1C952EBFD0A4A402C0FD253E47C4A40D1C952EBFD0A4A40
51314	49283	52.640970000000003	52.658568000000002	51.649141999999998	51.641038000000002	Центральная	0103000020E61000000100000005000000CBDB114E0B524A4023BF7E880DD24940CBDB114E0B524A40E23AC61517D349409818CBF44B544A40E23AC61517D349409818CBF44B544A4023BF7E880DD24940CBDB114E0B524A4023BF7E880DD24940
51196	56154	53.061641999999999	53.071739000000001	51.879914999999997	51.869472999999999	Молодежная	0103000020E61000000100000005000000AF0793E2E3874A40A4E029E44AEF4940AF0793E2E3874A404221020EA1F04940836C59BE2E894A404221020EA1F04940836C59BE2E894A40A4E029E44AEF4940AF0793E2E3874A40A4E029E44AEF4940
50812	48912	52.711174	52.731178999999997	51.833067	51.823360000000001	Коммунаров	0103000020E61000000100000005000000FCE1E7BF075B4A40D36A48DC63E94940FCE1E7BF075B4A403C3080F0A1EA4940D0420246975D4A403C3080F0A1EA4940D0420246975D4A40D36A48DC63E94940FCE1E7BF075B4A40D36A48DC63E94940
49905	11513	52.967264999999998	53.012189999999997	51.630954000000003	51.598253999999997	Молодежная	0103000020E6100000010000000500000060C8EA56CF7B4A40C0594A9693CC494060C8EA56CF7B4A40E4A3C519C3D049404BAB21718F814A40E4A3C519C3D049404BAB21718F814A40C0594A9693CC494060C8EA56CF7B4A40C0594A9693CC4940
51317	11411	52.606430000000003	52.623570000000001	51.828180000000003	51.815972000000002	Молодежная	0103000020E610000001000000050000001AA88C7F9F4D4A40D2393FC571E849401AA88C7F9F4D4A40C4995FCD01EA494024624A24D14F4A40C4995FCD01EA494024624A24D14F4A40D2393FC571E849401AA88C7F9F4D4A40D2393FC571E84940
50991	12104	52.910285000000002	52.930712999999997	52.094926999999998	52.083117999999999	Дружбы	0103000020E610000001000000050000000A85083884744A40BEDA519CA30A4A400A85083884744A40F2406491260C4A40247B849A21774A40F2406491260C4A40247B849A21774A40BEDA519CA30A4A400A85083884744A40BEDA519CA30A4A40
50530	48901	52.704875999999999	52.721738000000002	51.854644999999998	51.841887	Центральная	0103000020E610000001000000050000001EDE7360395A4A40BAF605F4C2EB49401EDE7360395A4A404F58E20165ED4940E62329E9615C4A404F58E20165ED4940E62329E9615C4A40BAF605F4C2EB49401EDE7360395A4A40BAF605F4C2EB4940
50659	11093	52.657580000000003	52.684925	51.52852	51.515726000000001	Центральная	0103000020E610000001000000050000007940D9942B544A4034D93F4F03C249407940D9942B544A4016A4198BA6C349403D9B559FAB574A4016A4198BA6C349403D9B559FAB574A4034D93F4F03C249407940D9942B544A4034D93F4F03C24940
50998	49386	52.945858000000001	52.958606000000003	51.696672999999997	51.685183000000002	Победы	0103000020E610000001000000050000007A54FCDF11794A4039639813B4D749407A54FCDF11794A40CB80B3942CD94940ECDFF599B37A4A40CB80B3942CD94940ECDFF599B37A4A4039639813B4D749407A54FCDF11794A4039639813B4D74940
50996	11243	53.154877999999997	53.180543	51.950200000000002	51.927140999999999	Центральная	0103000020E61000000100000005000000586FD40AD3934A40EFE3688EACF64940586FD40AD3934A4061545227A0F94940C84274081C974A4061545227A0F94940C84274081C974A40EFE3688EACF64940586FD40AD3934A40EFE3688EACF64940
50992	21395	52.374215	52.384672000000002	51.800347000000002	51.788843999999997	Клубная	0103000020E610000001000000050000001956F146E62F4A40AAD216D7F8E449401956F146E62F4A40D2393FC571E64940EDD79DEE3C314A40D2393FC571E64940EDD79DEE3C314A40AAD216D7F8E449401956F146E62F4A40AAD216D7F8E44940
51073	12243	52.599432	52.617659000000003	51.683273	51.675069000000001	Школьная	0103000020E6100000010000000500000083161230BA4C4A408FC536A968D6494083161230BA4C4A40B29E5A7D75D74940408A3A730F4F4A40B29E5A7D75D74940408A3A730F4F4A408FC536A968D6494083161230BA4C4A408FC536A968D64940
51021	12663	52.568888999999999	52.592713000000003	51.906410000000001	51.897919000000002	Центральная	0103000020E61000000100000005000000EE06D15AD1484A4080BA8102EFF24940EE06D15AD1484A4039622D3E05F4494000750305DE4B4A4039622D3E05F4494000750305DE4B4A4080BA8102EFF24940EE06D15AD1484A4080BA8102EFF24940
51315	48825	52.999847000000003	53.022691000000002	51.827556999999999	51.811022000000001	Школьная	0103000020E610000001000000050000007A008BFCFA7F4A40132BA391CFE749407A008BFCFA7F4A40B6494563EDE94940EF74E789E7824A40B6494563EDE94940EF74E789E7824A40132BA391CFE749407A008BFCFA7F4A40132BA391CFE74940
51064	49377	53.108148	53.127282000000001	51.731605000000002	51.721536	Центральная	0103000020E610000001000000050000005C902DCBD78D4A407E71A94A5BDC49405C902DCBD78D4A40884B8E3BA5DD49404BAFCDC64A904A40884B8E3BA5DD49404BAFCDC64A904A407E71A94A5BDC49405C902DCBD78D4A407E71A94A5BDC4940
50811	11764	52.82367	52.849863999999997	51.985517999999999	51.971189000000003	Центральная	0103000020E610000001000000050000002159C0046E694A40139ED0EB4FFC49402159C0046E694A4046CF2D7425FE49401C06F357C86C4A4046CF2D7425FE49401C06F357C86C4A40139ED0EB4FFC49402159C0046E694A40139ED0EB4FFC4940
51007	11526	52.813437999999998	52.843783000000002	51.577218999999999	51.564287999999998	Советская	0103000020E610000001000000050000006DA983BC1E684A403BC3D4963AC849406DA983BC1E684A409ED0EB4FE2C94940DCF5D214016C4A409ED0EB4FE2C94940DCF5D214016C4A403BC3D4963AC849406DA983BC1E684A403BC3D4963AC84940
50807	48767	52.719932	52.736991000000003	51.674728999999999	51.661954000000001	Центральная	0103000020E6100000010000000500000004AC55BB265C4A406BBA9EE8BAD4494004AC55BB265C4A40D65416855DD64940223999B8555E4A40D65416855DD64940223999B8555E4A406BBA9EE8BAD4494004AC55BB265C4A406BBA9EE8BAD44940
50237	10908	53.037325000000003	53.063349000000002	52.011102000000001	51.995244999999997	Советская	0103000020E610000001000000050000005F29CB10C7844A40F6402B3064FF49405F29CB10C7844A40C97553CA6B014A40FE9DEDD11B884A40C97553CA6B014A40FE9DEDD11B884A40F6402B3064FF49405F29CB10C7844A40F6402B3064FF4940
51065	12781	52.813068999999999	52.839030999999999	52.084651000000001	52.075994999999999	Центральная	0103000020E610000001000000050000001A321EA512684A406BD44334BA094A401A321EA512684A406F490ED8D50A4A4043AA285E656B4A406F490ED8D50A4A4043AA285E656B4A406BD44334BA094A401A321EA512684A406BD44334BA094A40
51062	56141	52.782769000000002	53.819344000000001	52.786596000000003	52.087302000000001	 Пушкина	0103000020E610000001000000050000004CA94BC631644A400D7041B62C0B4A404CA94BC631644A400C957F2DAF644A404016A243E0E84A400C957F2DAF644A404016A243E0E84A400D7041B62C0B4A404CA94BC631644A400D7041B62C0B4A40
50871	7107	53.019395000000003	53.046587000000002	52.579695999999998	52.567436000000001	Молодежная	0103000020E610000001000000050000005C5A0D897B824A405A492BBEA1484A405C5A0D897B824A409ECF807A334A4A409AB51490F6854A409ECF807A334A4A409AB51490F6854A405A492BBEA1484A405C5A0D897B824A405A492BBEA1484A40
50398	10520	52.914560999999999	52.934781999999998	52.362549000000001	52.336832000000001	Центральная	0103000020E610000001000000050000003999B85510754A40861F9C4F1D2B4A403999B85510754A4048197101682E4A40DA71C3EFA6774A4048197101682E4A40DA71C3EFA6774A40861F9C4F1D2B4A403999B85510754A40861F9C4F1D2B4A40
50453	10520	52.914560999999999	52.934781999999998	52.362549000000001	52.336832000000001	 Центральная	0103000020E610000001000000050000003999B85510754A40861F9C4F1D2B4A403999B85510754A4048197101682E4A40DA71C3EFA6774A4048197101682E4A40DA71C3EFA6774A40861F9C4F1D2B4A403999B85510754A40861F9C4F1D2B4A40
51003	9880	53.073805	53.093532000000003	52.531101999999997	52.519964000000002	Центральная	0103000020E6100000010000000500000001A4367172894A40768C2B2E8E424A4001A4367172894A408B6B7C26FB434A40939048DBF88B4A408B6B7C26FB434A40939048DBF88B4A40768C2B2E8E424A4001A4367172894A40768C2B2E8E424A40
51060	10492	52.974164000000002	52.991250000000001	52.314490999999997	52.294578000000001	Молодежная	0103000020E610000001000000050000006478EC67B17C4A40800F5EBBB4254A406478EC67B17C4A4073F1B73D41284A407B14AE47E17E4A4073F1B73D41284A407B14AE47E17E4A40800F5EBBB4254A406478EC67B17C4A40800F5EBBB4254A40
50531	10425	53.266942999999998	53.293731000000001	52.575597000000002	52.543356000000003	Гречушкина	0103000020E61000000100000005000000B4722F302BA24A40EE0A7DB08C454A40B4722F302BA24A407E569929AD494A40236937FA98A54A407E569929AD494A40236937FA98A54A40EE0A7DB08C454A40B4722F302BA24A40EE0A7DB08C454A40
51086	3171	53.202255999999998	53.226922999999999	52.336832000000001	52.320838000000002	Центральная	0103000020E61000000100000005000000BBB54C86E3994A4033A8363811294A40BBB54C86E3994A40861F9C4F1D2B4A40E8DA17D00B9D4A40861F9C4F1D2B4A40E8DA17D00B9D4A4033A8363811294A40BBB54C86E3994A4033A8363811294A40
50712	9364	53.101249000000003	53.112684999999999	52.355063999999999	52.347880000000004	Школьная	0103000020E6100000010000000500000059E02BBAF58C4A405C77F354872C4A4059E02BBAF58C4A4054FEB5BC722D4A40F8DF4A766C8E4A4054FEB5BC722D4A40F8DF4A766C8E4A405C77F354872C4A4059E02BBAF58C4A405C77F354872C4A40
50804	9657	52.917633000000002	52.953000000000003	52.214998999999999	52.204011000000001	Центральная	0103000020E610000001000000050000007D5D86FF74754A401B834E081D1A4A407D5D86FF74754A401BD65416851B4A40448B6CE7FB794A401BD65416851B4A40448B6CE7FB794A401B834E081D1A4A407D5D86FF74754A401B834E081D1A4A40
49870	10211	53.322530999999998	53.347225999999999	52.436278999999999	52.424232000000003	Садовая	0103000020E610000001000000050000001C7920B248A94A4056F5F23B4D364A401C7920B248A94A403E7782FDD7374A401329CDE671AC4A403E7782FDD7374A401329CDE671AC4A4056F5F23B4D364A401C7920B248A94A4056F5F23B4D364A40
50527	10111	52.886201	52.932724999999998	52.722943000000001	52.691710999999998	Ленинская	0103000020E610000001000000050000005C57CC086F714A4048A46DFC89584A405C57CC086F714A40A2EF6E65895C4A40AF94658863774A40A2EF6E65895C4A40AF94658863774A4048A46DFC89584A405C57CC086F714A4048A46DFC89584A40
50805	10029	53.10398	53.128926	52.199469000000001	52.190322000000002	Центральная	0103000020E6100000010000000500000013B875374F8D4A40CBDAA6785C184A4013B875374F8D4A406DC83F3388194A4053CDACA580904A406DC83F3388194A4053CDACA580904A40CBDAA6785C184A4013B875374F8D4A40CBDAA6785C184A40
50716	10061	53.512470999999998	53.55603	52.518895000000001	52.501548	Советская	0103000020E61000000100000005000000FF9254A698C14A40E6AF90B932404A40FF9254A698C14A406A87BF266B424A4025CCB4FD2BC74A406A87BF266B424A4025CCB4FD2BC74A40E6AF90B932404A40FF9254A698C14A40E6AF90B932404A40
51362	56178	53.099767	53.118721000000001	52.124384999999997	52.116804000000002	Центральная	0103000020E610000001000000050000002A1C412AC58C4A406005F86EF30E4A402A1C412AC58C4A40758E01D9EB0F4A40992CEE3F328F4A40758E01D9EB0F4A40992CEE3F328F4A406005F86EF30E4A402A1C412AC58C4A406005F86EF30E4A40
50711	9903	53.124372000000001	53.146110999999998	52.590567999999998	52.575077	Центральная	0103000020E61000000100000005000000E144F46BEB8F4A4045D7851F9C494A40E144F46BEB8F4A40350873BB974B4A40FD4AE7C3B3924A40350873BB974B4A40FD4AE7C3B3924A4045D7851F9C494A40E144F46BEB8F4A4045D7851F9C494A40
50432	9825	52.976410000000001	53.022843999999999	52.506394	52.497419999999998	Центральная	0103000020E6100000010000000500000062BEBC00FB7C4A402B306475AB3F4A4062BEBC00FB7C4A400072C284D1404A4075745C8DEC824A400072C284D1404A4075745C8DEC824A402B306475AB3F4A4062BEBC00FB7C4A402B306475AB3F4A40
50910	9825	52.976410000000001	53.022843999999999	52.506394	52.497419999999998	Нагорная	0103000020E6100000010000000500000062BEBC00FB7C4A402B306475AB3F4A4062BEBC00FB7C4A400072C284D1404A4075745C8DEC824A400072C284D1404A4075745C8DEC824A402B306475AB3F4A4062BEBC00FB7C4A402B306475AB3F4A40
51217	9259	53.394503999999998	53.417672000000003	52.326337000000002	52.316335000000002	Центральная	0103000020E610000001000000050000001212691B7FB24A4043CA4FAA7D284A401212691B7FB24A40C53C2B69C5294A403B3AAE4676B54A40C53C2B69C5294A403B3AAE4676B54A4043CA4FAA7D284A401212691B7FB24A4043CA4FAA7D284A40
51310	9721	53.379736000000001	53.405310999999998	52.485388999999998	52.471550999999998	Школьная	0103000020E61000000100000005000000938E72309BB04A40B3B27DC85B3C4A40938E72309BB04A40486B0C3A213E4A40C2DA183BE1B34A40486B0C3A213E4A40C2DA183BE1B34A40B3B27DC85B3C4A40938E72309BB04A40B3B27DC85B3C4A40
50802	9590	53.002299999999998	53.023930999999997	52.241168000000002	52.223953999999999	Молодежная	0103000020E61000000100000005000000F163CC5D4B804A4079E75086AA1C4A40F163CC5D4B804A40BE6BD097DE1E4A40272EC72B10834A40BE6BD097DE1E4A40272EC72B10834A4079E75086AA1C4A40F163CC5D4B804A4079E75086AA1C4A40
51087	9569	53.275621000000001	53.298338999999999	52.169525	52.145960000000002	Центральная	0103000020E61000000100000005000000A08B868C47A34A40184339D1AE124A40A08B868C47A34A405D6DC5FEB2154A40880FECF82FA64A405D6DC5FEB2154A40880FECF82FA64A40184339D1AE124A40A08B868C47A34A40184339D1AE124A40
51309	9750	53.367438	53.403585999999997	52.466343999999999	52.450524000000001	Московская	0103000020E6100000010000000500000061A7583508AF4A4014083BC5AA394A4061A7583508AF4A40C9570229B13B4A40CD8FBFB4A8B34A40C9570229B13B4A40CD8FBFB4A8B34A4014083BC5AA394A4061A7583508AF4A4014083BC5AA394A40
49824	56041	53.050871000000001	53.071102000000003	52.646006999999997	52.627268000000001	Кольцевая	0103000020E610000001000000050000004CA8E0F082864A40E6E95C514A504A404CA8E0F082864A4058FE7C5BB0524A401157CEDE19894A4058FE7C5BB0524A401157CEDE19894A40E6E95C514A504A404CA8E0F082864A40E6E95C514A504A40
50623	9441	53.439725000000003	53.462605000000003	52.287241000000002	52.252560000000003	Садовая	0103000020E61000000100000005000000E71DA7E848B84A408E23D6E253204A40E71DA7E848B84A4001892650C4244A40A9FB00A436BB4A4001892650C4244A40A9FB00A436BB4A408E23D6E253204A40E71DA7E848B84A408E23D6E253204A40
50541	9441	53.439725000000003	53.462605000000003	52.287241000000002	52.252560000000003	Молодежная	0103000020E61000000100000005000000E71DA7E848B84A408E23D6E253204A40E71DA7E848B84A4001892650C4244A40A9FB00A436BB4A4001892650C4244A40A9FB00A436BB4A408E23D6E253204A40E71DA7E848B84A408E23D6E253204A40
50254	9276	53.145724999999999	53.165326	52.258723000000003	52.246104000000003	Победы	0103000020E61000000100000005000000D49AE61DA7924A4018B5FB55801F4A40D49AE61DA7924A408CDCD3D51D214A40D996016729954A408CDCD3D51D214A40D996016729954A4018B5FB55801F4A40D49AE61DA7924A4018B5FB55801F4A40
50255	9184	53.314078000000002	53.361274999999999	52.342801999999999	52.311314000000003	Центральная	0103000020E61000000100000005000000513239B533A84A40BB641C23D9274A40513239B533A84A406F8099EFE02B4A4063EE5A423EAE4A406F8099EFE02B4A4063EE5A423EAE4A40BB641C23D9274A40513239B533A84A40BB641C23D9274A40
51085	9114	52.989544000000002	53.023705999999997	52.648891999999996	52.637357000000002	Молодежная	0103000020E61000000100000005000000FDF9B660A97E4A40377007EA94514A40FDF9B660A97E4A4069519FE40E534A40075C57CC08834A4069519FE40E534A40075C57CC08834A40377007EA94514A40FDF9B660A97E4A40377007EA94514A40
51218	9519	53.304600999999998	53.336193999999999	52.220616	52.203366000000003	Молодежная	0103000020E6100000010000000500000019AA622AFDA64A40268FA7E5071A4A4019AA622AFDA64A40B77C24253D1C4A40438EAD6708AB4A40B77C24253D1C4A40438EAD6708AB4A40268FA7E5071A4A4019AA622AFDA64A40268FA7E5071A4A40
50656	56093	54.911714000000003	54.923400999999998	51.182552999999999	51.175941000000002	Центральная	0103000020E6100000010000000500000016A75A0BB3744B404583143C8596494016A75A0BB3744B40B2648EE55D974940FE0B040132764B40B2648EE55D974940FE0B040132764B404583143C8596494016A75A0BB3744B404583143C85964940
50575	7874	55.091636999999999	55.114490000000004	51.208229000000003	51.188282999999998	Центральная	0103000020E61000000100000005000000410DDFC2BA8B4B4046B247A819984940410DDFC2BA8B4B40168A743FA79A49400ADCBA9BA78E4B40168A743FA79A49400ADCBA9BA78E4B4046B247A819984940410DDFC2BA8B4B4046B247A819984940
50230	7048	55.321461999999997	55.336858999999997	51.108673000000003	51.102038999999998	Южная	0103000020E610000001000000050000001074B4AA25A94B4051F52B9D0F8D49401074B4AA25A94B40A77A32FFE88D49407F2E1A321EAB4B40A77A32FFE88D49407F2E1A321EAB4B4051F52B9D0F8D49401074B4AA25A94B4051F52B9D0F8D4940
51057	7239	54.601641999999998	54.618476999999999	51.120598000000001	51.110996999999998	Элеваторная	0103000020E6100000010000000500000034F3E49A024D4B40207A5226358E494034F3E49A024D4B4044FB58C16F8F4940022A1C412A4F4B4044FB58C16F8F4940022A1C412A4F4B40207A5226358E494034F3E49A024D4B40207A5226358E4940
50532	8027	54.862189999999998	54.892327999999999	51.099567	51.076847000000001	пер.Почтовый	0103000020E610000001000000050000001878EE3D5C6E4B40DAE55B1FD68949401878EE3D5C6E4B406361889CBE8C49400DA7CCCD37724B406361889CBE8C49400DA7CCCD37724B40DAE55B1FD68949401878EE3D5C6E4B40DAE55B1FD6894940
50422	8027	54.862189999999998	54.892327999999999	51.099567	51.076847000000001	Кооперативная	0103000020E610000001000000050000001878EE3D5C6E4B40DAE55B1FD68949401878EE3D5C6E4B406361889CBE8C49400DA7CCCD37724B406361889CBE8C49400DA7CCCD37724B40DAE55B1FD68949401878EE3D5C6E4B40DAE55B1FD6894940
50709	8136	54.605307000000003	54.63364	50.709485000000001	50.684797000000003	Школьная	0103000020E610000001000000050000001B8524B37A4D4B4010B3976DA75749401B8524B37A4D4B4054008C67D05A4940FEB7921D1B514B4054008C67D05A4940FEB7921D1B514B4010B3976DA75749401B8524B37A4D4B4010B3976DA7574940
50555	8066	55.003045	55.028754999999997	51.090341000000002	51.076847000000001	Центральная	0103000020E610000001000000050000004AB54FC763804B40DAE55B1FD68949404AB54FC763804B40753E3C4B908B4940594C6C3EAE834B40753E3C4B908B4940594C6C3EAE834B40DAE55B1FD68949404AB54FC763804B40DAE55B1FD6894940
51235	21017	55.230345999999997	55.247853999999997	51.209532000000003	51.190660000000001	Тополиная	0103000020E61000000100000005000000D8614CFA7B9D4B40E353008C67984940D8614CFA7B9D4B4095BBCFF1D19A494065170CAEB99F4B4095BBCFF1D19A494065170CAEB99F4B40E353008C67984940D8614CFA7B9D4B40E353008C67984940
50302	21017	55.230345999999997	55.247853999999997	51.209532000000003	51.190660000000001	Молодежная	0103000020E61000000100000005000000D8614CFA7B9D4B40E353008C67984940D8614CFA7B9D4B4095BBCFF1D19A494065170CAEB99F4B4095BBCFF1D19A494065170CAEB99F4B40E353008C67984940D8614CFA7B9D4B40E353008C67984940
50059	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Южная	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49927	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Цвиллинга	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49801	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Уральская	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
50250	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Украинская	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49939	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Орджоникидзе	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49701	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Московская	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49936	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Молодежная	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
50819	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Ленинградская	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49915	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Кирова	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49803	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Гонтаренко	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49935	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Володарского	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49806	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	Вокзальная	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
49799	8389	54.953916	55.025018000000003	51.174878999999997	51.143630000000002	 Челкарская	0103000020E61000000100000005000000C99063EB197A4B40BC5CC47762924940C99063EB197A4B40EBE0606F62964940DAE731CA33834B40EBE0606F62964940DAE731CA33834B40BC5CC47762924940C99063EB197A4B40BC5CC47762924940
50717	22504	55.356946000000001	55.381729999999997	51.465501000000003	51.452392000000003	Новая	0103000020E6100000010000000500000011381268B0AD4B406C7C26FBE7B9494011381268B0AD4B40AEA0698995BB494077F35487DCB04B40AEA0698995BB494077F35487DCB04B406C7C26FBE7B9494011381268B0AD4B406C7C26FBE7B94940
50421	7949	54.898535000000003	54.924900999999998	51.212533999999998	51.183072000000003	Калинина	0103000020E61000000100000005000000DBA7E33103734B401B683EE76E974940DBA7E33103734B40DFA46950349B4940D384ED2763764B40DFA46950349B4940D384ED2763764B401B683EE76E974940DBA7E33103734B401B683EE76E974940
50830	52595	54.412537999999998	54.428877999999997	51.257508999999999	51.248804999999997	Центральная	0103000020E61000000100000005000000BA2D910BCE344B40670A9DD7D89F4940BA2D910BCE344B407CB60E0EF6A04940A8FC6B79E5364B407CB60E0EF6A04940A8FC6B79E5364B40670A9DD7D89F4940BA2D910BCE344B40670A9DD7D89F4940
50233	7843	54.523910999999998	54.553491999999999	50.925136000000002	50.906163999999997	Ахметгалиева	0103000020E61000000100000005000000E08101840F434B400168942EFD734940E08101840F434B40172D40DB6A7649407F4C6BD3D8464B40172D40DB6A7649407F4C6BD3D8464B400168942EFD734940E08101840F434B400168942EFD734940
51058	7676	55.290362999999999	55.313637999999997	51.367984	51.351999999999997	Советская	0103000020E61000000100000005000000F67B629D2AA54B40931804560EAD4940F67B629D2AA54B40C3B986191AAF494034643C4A25A84B40C3B986191AAF494034643C4A25A84B40931804560EAD4940F67B629D2AA54B40931804560EAD4940
50231	7600	54.214692999999997	54.241148000000003	51.002332000000003	50.990642999999999	Советская	0103000020E610000001000000050000000ED76A0F7B1B4B407381CB63CD7E49400ED76A0F7B1B4B40FDDD3B6A4C80494077BF0AF0DD1E4B40FDDD3B6A4C80494077BF0AF0DD1E4B407381CB63CD7E49400ED76A0F7B1B4B407381CB63CD7E4940
51198	56155	54.003804000000002	55.629665000000003	51.500000999999997	50.527413000000003	Островского	0103000020E6100000010000000500000008CC43A67C004B401D3EE9448243494008CC43A67C004B40D07B630800C04940CA37DBDC98D04B40D07B630800C04940CA37DBDC98D04B401D3EE9448243494008CC43A67C004B401D3EE94482434940
50983	7682	55.258651999999998	55.283723999999999	51.395259000000003	51.380898000000002	Советская	0103000020E61000000100000005000000C2853C821BA14B40508E0244C1B04940C2853C821BA14B408F39CFD897B249408F8B6A1151A44B408F39CFD897B249408F8B6A1151A44B40508E0244C1B04940C2853C821BA14B40508E0244C1B04940
51052	56139	54.95044	54.967202999999998	51.332178999999996	51.321215000000002	Элеваторная	0103000020E61000000100000005000000B6679604A8794B4009FEB7921DA94940B6679604A8794B4080B56AD784AA4940EACBD24ECD7B4B4080B56AD784AA4940EACBD24ECD7B4B4009FEB7921DA94940B6679604A8794B4009FEB7921DA94940
50534	56078	55.131729	55.152327	51.363114000000003	51.340107000000003	Целинная	0103000020E61000000100000005000000A777F17EDC904B4002124DA088AB4940A777F17EDC904B40215C01857AAE49401EA67D737F934B40215C01857AAE49401EA67D737F934B4002124DA088AB4940A777F17EDC904B4002124DA088AB4940
50834	56118	55.151285000000001	55.159396999999998	51.372774	51.364744999999999	Первомайская	0103000020E610000001000000050000000CB08F4E5D934B409430D3F6AFAE49400CB08F4E5D934B404966F50EB7AF49404E0AF31E67944B404966F50EB7AF49404E0AF31E67944B409430D3F6AFAE49400CB08F4E5D934B409430D3F6AFAE4940
49773	7521	54.099393999999997	54.133448999999999	51.155676	51.130614999999999	Кызыл-Юлдузская	0103000020E6100000010000000500000095B54DF1B80C4B40FBAE08FEB790494095B54DF1B80C4B40D462F030ED9349408A5759DB14114B40D462F030ED9349408A5759DB14114B40FBAE08FEB790494095B54DF1B80C4B40FBAE08FEB7904940
50632	56088	55.120230999999997	55.138142999999999	51.078884000000002	51.063110999999999	Центральная	0103000020E61000000100000005000000917BBABA638F4B404982700514884940917BBABA638F4B40BE16F4DE188A4940EE9579ABAE914B40BE16F4DE188A4940EE9579ABAE914B404982700514884940917BBABA638F4B404982700514884940
51306	6996	55.377372999999999	55.401384999999998	51.107852999999999	51.098685000000003	Школьная	0103000020E610000001000000050000005BB22AC24DB04B408ACDC7B5A18C49405BB22AC24DB04B4043E38920CE8D49406F0D6C9560B34B4043E38920CE8D49406F0D6C9560B34B408ACDC7B5A18C49405BB22AC24DB04B408ACDC7B5A18C4940
49864	7217	54.554156999999996	54.586064999999998	51.047043000000002	51.020992999999997	Максима Горького	0103000020E61000000100000005000000BBECD79DEE464B40F3380CE6AF824940BBECD79DEE464B40BC40498105864940452A8C2D044B4B40BC40498105864940452A8C2D044B4B40F3380CE6AF824940BBECD79DEE464B40F3380CE6AF824940
51308	7496	55.001815000000001	55.017014000000003	51.326275000000003	51.313564999999997	Магистральная	0103000020E6100000010000000500000035D252793B804B40CA15DEE522A8494035D252793B804B404F401361C3A949407EC9C6832D824B404F401361C3A949407EC9C6832D824B40CA15DEE522A8494035D252793B804B40CA15DEE522A84940
51125	56148	55.102542999999997	55.125081000000002	50.965792	50.955914999999997	Школьная	0103000020E6100000010000000500000084B70721208D4B40BF60376C5B7A494084B70721208D4B40855E7F129F7B4940ED2C7AA702904B40855E7F129F7B4940ED2C7AA702904B40BF60376C5B7A494084B70721208D4B40BF60376C5B7A4940
50399	7147	55.040936000000002	55.059503999999997	51.428604999999997	51.411306000000003	Речная	0103000020E61000000100000005000000529D0E643D854B400553CDACA5B44940529D0E643D854B4077F35487DCB6494097FDBAD39D874B4077F35487DCB6494097FDBAD39D874B400553CDACA5B44940529D0E643D854B400553CDACA5B44940
50251	8250	54.493915999999999	54.529130000000002	51.196399999999997	51.183641999999999	Советская	0103000020E610000001000000050000004E7CB5A3383F4B400516C094819749404E7CB5A3383F4B409A779CA2239949408FAA2688BA434B409A779CA2239949408FAA2688BA434B400516C094819749404E7CB5A3383F4B400516C09481974940
49772	6917	55.286904	55.324039999999997	51.110973999999999	51.095726999999997	Советская	0103000020E61000000100000005000000B98B3045B9A44B400E2C47C8408C4940B98B3045B9A44B40685A6265348E4940444C89247AA94B40685A6265348E4940444C89247AA94B400E2C47C8408C4940B98B3045B9A44B400E2C47C8408C4940
51051	6963	55.222926000000001	55.246606	51.114440999999999	51.105998	Луговая	0103000020E61000000100000005000000CCB6D3D6889C4B4080B8AB57918D4940CCB6D3D6889C4B402829B000A68E4940AA7F10C9909F4B402829B000A68E4940AA7F10C9909F4B4080B8AB57918D4940CCB6D3D6889C4B4080B8AB57918D4940
50396	6841	54.768180999999998	54.806440000000002	51.089509999999997	51.071945999999997	Советская	0103000020E610000001000000050000004C3448C153624B40FC89CA86358949404C3448C153624B401D554D10758B4940D717096D39674B401D554D10758B4940D717096D39674B40FC89CA86358949404C3448C153624B40FC89CA8635894940
49863	6837	54.453060999999998	54.484079999999999	50.985585999999998	50.966717000000003	Советская	0103000020E61000000100000005000000E90B21E7FD394B405EBEF561BD7B4940E90B21E7FD394B409EB29AAE277E4940E7525C55F63D4B409EB29AAE277E4940E7525C55F63D4B405EBEF561BD7B4940E90B21E7FD394B405EBEF561BD7B4940
50425	6707	54.884540000000001	54.909764000000003	51.284545999999999	51.273864000000003	Таврическая	0103000020E610000001000000050000007E00529B38714B40A0C6BDF90DA349407E00529B38714B40931ADA006CA44940018A912573744B40931ADA006CA44940018A912573744B40A0C6BDF90DA349407E00529B38714B40A0C6BDF90DA34940
51334	56162	55.155543000000002	55.176501000000002	51.395162999999997	51.381875999999998	Зеленая	0103000020E61000000100000005000000950F41D5E8934B404B901150E1B04940950F41D5E8934B406CCB80B394B249400C5BB39597964B406CCB80B394B249400C5BB39597964B404B901150E1B04940950F41D5E8934B404B901150E1B04940
50696	46300	53.015172	53.042760000000001	54.261713999999998	54.246771000000003	Центральная	0103000020E610000001000000050000004FE8F527F1814A40F54C2F31961F4B404FE8F527F1814A40E27327D87F214B40DAC9E02879854A40E27327D87F214B40DAC9E02879854A40F54C2F31961F4B404FE8F527F1814A40F54C2F31961F4B40
50799	6172	52.983694999999997	53.015667000000001	54.031491000000003	54.021420999999997	Бадановка	0103000020E610000001000000050000008E1EBFB7E97D4A404B395FECBD024B408E1EBFB7E97D4A40268FA7E507044B402F50526001824A40268FA7E507044B402F50526001824A404B395FECBD024B408E1EBFB7E97D4A404B395FECBD024B40
51171	5023	52.439306999999999	52.454901999999997	54.105051000000003	54.092849999999999	Центральная	0103000020E61000000100000005000000B2F336363B384A4080B74082E20B4B40B2F336363B384A40C0B4A84F720D4B4047718E3A3A3A4A40C0B4A84F720D4B4047718E3A3A3A4A4080B74082E20B4B40B2F336363B384A4080B74082E20B4B40
51053	46744	52.616213000000002	52.640647000000001	54.037641000000001	54.017479999999999	Центральная	0103000020E610000001000000050000005E2F4D11E04E4A40C32ADEC83C024B405E2F4D11E04E4A408FFE976BD1044B40E8A38CB800524A408FFE976BD1044B40E8A38CB800524A40C32ADEC83C024B405E2F4D11E04E4A40C32ADEC83C024B40
50867	6633	52.559142999999999	52.593521000000003	54.259216000000002	54.243588000000003	Молодежная	0103000020E61000000100000005000000C76471FF91474A405AD93EE42D1F4B40C76471FF91474A40CB4C69FD2D214B409F3E027FF84B4A40CB4C69FD2D214B409F3E027FF84B4A405AD93EE42D1F4B40C76471FF91474A405AD93EE42D1F4B40
50985	6570	52.436081999999999	52.486721000000003	54.250579999999999	54.216293999999998	Советская	0103000020E61000000100000005000000E82FF488D1374A4017299485AF1B4B40E82FF488D1374A400E84640113204B4062A3ACDF4C3E4A400E84640113204B4062A3ACDF4C3E4A4017299485AF1B4B40E82FF488D1374A4017299485AF1B4B40
50392	6377	52.467739000000002	52.507274000000002	54.13588	54.112631	Школьная	0103000020E6100000010000000500000029081EDFDE3B4A4005C24EB16A0E4B4029081EDFDE3B4A401A170E8464114B40390EBC5AEE404A401A170E8464114B40390EBC5AEE404A4005C24EB16A0E4B4029081EDFDE3B4A4005C24EB16A0E4B40
51038	46500	53.213476	53.240254	54.060482999999998	54.019208999999996	Центральная	0103000020E610000001000000050000008E3D7B2E539B4A40F964C57075024B408E3D7B2E539B4A40637B2DE8BD074B40D95DA0A4C09E4A40637B2DE8BD074B40D95DA0A4C09E4A40F964C57075024B408E3D7B2E539B4A40F964C57075024B40
51049	6388	52.875224000000003	52.920813000000003	54.163258999999996	54.144820000000003	Школьная	0103000020E6100000010000000500000050560C5707704A4043E7357689124B4050560C5707704A408AE3C0ABE5144B40A75D4C33DD754A408AE3C0ABE5144B40A75D4C33DD754A4043E7357689124B4050560C5707704A4043E7357689124B40
50067	46889	52.516347000000003	52.558244000000002	54.103102999999997	54.083342999999999	Советская	0103000020E61000000100000005000000A13193A817424A40DEACC1FBAA0A4B40A13193A817424A404B8FA67A320D4B401898158A74474A404B8FA67A320D4B401898158A74474A40DEACC1FBAA0A4B40A13193A817424A40DEACC1FBAA0A4B40
50091	46889	52.516347000000003	52.558244000000002	54.103102999999997	54.083342999999999	Осенняя	0103000020E61000000100000005000000A13193A817424A40DEACC1FBAA0A4B40A13193A817424A404B8FA67A320D4B401898158A74474A404B8FA67A320D4B401898158A74474A40DEACC1FBAA0A4B40A13193A817424A40DEACC1FBAA0A4B40
50800	46788	52.515349999999998	52.536980999999997	53.996758	53.976460000000003	Центральная	0103000020E610000001000000050000002EFF21FDF6414A4014ED2AA4FCFC4A402EFF21FDF6414A40600322C495FF4A4064C91CCBBB444A40600322C495FF4A4064C91CCBBB444A4014ED2AA4FCFC4A402EFF21FDF6414A4014ED2AA4FCFC4A40
50524	6094	52.908929000000001	52.959584999999997	54.037916000000003	54.018695999999998	пл.Центральная	0103000020E6100000010000000500000068B114C957744A4073486AA164024B4068B114C957744A4061FF756EDA044B40B75D68AED37A4A4061FF756EDA044B40B75D68AED37A4A4073486AA164024B4068B114C957744A4073486AA164024B40
51083	5387	52.712440000000001	52.999595999999997	54.169431000000003	54.023060000000001	Центральная	0103000020E610000001000000050000005E2EE23B315B4A4042EC4CA1F3024B405E2EE23B315B4A40DCF63DEAAF154B40309B00C3F27F4A40DCF63DEAAF154B40309B00C3F27F4A4042EC4CA1F3024B405E2EE23B315B4A4042EC4CA1F3024B40
50567	49269	52.875205999999999	52.890810000000002	54.225701000000001	54.213487999999998	бульвар Молодежный	0103000020E61000000100000005000000A9A10DC006704A40520B2593531B4B40A9A10DC006704A4056D636C5E31C4B409279E40F06724A4056D636C5E31C4B409279E40F06724A40520B2593531B4B40A9A10DC006704A40520B2593531B4B40
50490	45370	52.445262999999997	52.465673000000002	53.956698000000003	53.937775000000002	Луначарского	0103000020E61000000100000005000000368FC360FE384A40D200DE0209F84A40368FC360FE384A4006137F1475FA4A40ABD0402C9B3B4A4006137F1475FA4A40ABD0402C9B3B4A40D200DE0209F84A40368FC360FE384A40D200DE0209F84A40
50518	45370	52.445262999999997	52.465673000000002	53.956698000000003	53.937775000000002	Железнодорожная	0103000020E61000000100000005000000368FC360FE384A40D200DE0209F84A40368FC360FE384A4006137F1475FA4A40ABD0402C9B3B4A4006137F1475FA4A40ABD0402C9B3B4A40D200DE0209F84A40368FC360FE384A40D200DE0209F84A40
50984	5741	52.871648999999998	52.891609000000003	54.304546999999999	54.291806000000001	 Молодежная	0103000020E61000000100000005000000A94BC631926F4A40676325E659254B40A94BC631926F4A40268C6665FB264B40DEE8633E20724A40268C6665FB264B40DEE8633E20724A40676325E659254B40A94BC631926F4A40676325E659254B40
50797	5673	52.929257999999997	52.964750000000002	54.140985999999998	54.125391999999998	Южная	0103000020E61000000100000005000000EFC517EDF1764A400B9755D80C104B40EFC517EDF1764A40D09849D40B124B40736891ED7C7B4A40D09849D40B124B40736891ED7C7B4A400B9755D80C104B40EFC517EDF1764A400B9755D80C104B40
51307	5632	53.005318000000003	53.026707000000002	54.140917000000002	54.126542000000001	Чукаевская	0103000020E61000000100000005000000420A9E42AE804A4004C93B8732104B40420A9E42AE804A40A839799109124B4082C98D226B834A40A839799109124B4082C98D226B834A4004C93B8732104B40420A9E42AE804A4004C93B8732104B40
51094	45872	52.697339999999997	52.704391000000001	54.328895000000003	54.323146000000001	Центральная	0103000020E61000000100000005000000A818E76F42594A40A7EA1ED95C294B40A818E76F42594A40B2683A3B192A4B40624CFA7B295A4A40B2683A3B192A4B40624CFA7B295A4A40A7EA1ED95C294B40A818E76F42594A40A7EA1ED95C294B40
51413	56202	53.196488000000002	53.209415	54.082904999999997	54.068541000000003	Лесная	0103000020E610000001000000050000003A07CF8426994A40B3B794F3C5084B403A07CF8426994A4062D68BA19C0A4B405B25581CCE9A4A4062D68BA19C0A4B405B25581CCE9A4A40B3B794F3C5084B403A07CF8426994A40B3B794F3C5084B40
50798	5467	52.690458	52.716492000000002	54.235636999999997	54.222679999999997	Заречная	0103000020E610000001000000050000007BA180ED60584A4094BC3AC7801C4B407BA180ED60584A40205D6C5A291E4B403EEC8502B65B4A40205D6C5A291E4B403EEC8502B65B4A4094BC3AC7801C4B407BA180ED60584A4094BC3AC7801C4B40
50796	5162	53.135277000000002	53.17015	54.062311000000001	54.049748000000001	Широкая	0103000020E610000001000000050000005473B9C150914A404D8578245E064B405473B9C150914A402D978DCEF9074B400BB5A679C7954A402D978DCEF9074B400BB5A679C7954A404D8578245E064B405473B9C150914A404D8578245E064B40
51046	46534	52.702486999999998	52.720847999999997	53.999701000000002	53.98516	Черемушки	0103000020E61000000100000005000000BD6E1118EB594A40E7A90EB919FE4A40BD6E1118EB594A40A663CE33F6FF4A4089B14CBF445C4A40A663CE33F6FF4A4089B14CBF445C4A40E7A90EB919FE4A40BD6E1118EB594A40E7A90EB919FE4A40
50986	46996	52.472608000000001	52.488239	54.201739000000003	54.186109999999999	Центральная	0103000020E61000000100000005000000FBE93F6B7E3C4A40B2BAD573D2174B40FBE93F6B7E3C4A40F4A96395D2194B40DDD0949D7E3E4A40F4A96395D2194B40DDD0949D7E3E4A40B2BAD573D2174B40FBE93F6B7E3C4A40B2BAD573D2174B40
51035	5095	52.774056000000002	52.816913999999997	54.172536000000001	54.161962000000003	Центральная	0103000020E61000000100000005000000E4A25A4414634A40EE98BA2BBB144B40E4A25A4414634A40FBB0DEA815164B4080D250A390684A40FBB0DEA815164B4080D250A390684A40EE98BA2BBB144B40E4A25A4414634A40EE98BA2BBB144B40
51304	4920	53.172908	53.204025000000001	53.974532000000004	53.959130000000002	Молодежная	0103000020E61000000100000005000000BF9B6ED921964A40664E97C5C4FA4A40BF9B6ED921964A40E773EE76BDFC4A408048BF7D1D9A4A40E773EE76BDFC4A408048BF7D1D9A4A40664E97C5C4FA4A40BF9B6ED921964A40664E97C5C4FA4A40
50713	46384	52.81315	52.823219999999999	54.284247999999998	54.274186999999998	Горная	0103000020E61000000100000005000000075F984C15684A4082FE428F18234B40075F984C15684A4009FA0B3D62244B40E1B4E0455F694A4009FA0B3D62244B40E1B4E0455F694A4082FE428F18234B40075F984C15684A4082FE428F18234B40
51042	46987	52.485795000000003	52.506385000000002	54.301631999999998	54.294265000000003	Вокзальная	0103000020E61000000100000005000000B9C7D2872E3E4A40C1ADBB79AA254B40B9C7D2872E3E4A40AAB69BE09B264B40AD174339D1404A40AAB69BE09B264B40AD174339D1404A40C1ADBB79AA254B40B9C7D2872E3E4A40C1ADBB79AA254B40
51063	56142	52.558199000000002	52.571890000000003	53.939439	53.916265000000003	Молодежная	0103000020E6100000010000000500000078D4981073474A4017BCE82B48F54A4078D4981073474A4021CB82893FF84A40697407B133494A4021CB82893FF84A40697407B133494A4017BCE82B48F54A4078D4981073474A4017BCE82B48F54A40
50801	46854	52.614325999999998	52.636702999999997	54.134492000000002	54.122805999999997	Луговая	0103000020E610000001000000050000008F8AFF3BA24E4A4054E0641BB80F4B408F8AFF3BA24E4A406DC9AA0837114B40EE21E17B7F514A406DC9AA0837114B40EE21E17B7F514A4054E0641BB80F4B408F8AFF3BA24E4A4054E0641BB80F4B40
50395	4994	52.395524000000002	52.413589000000002	54.137878999999998	54.115428000000001	Речная	0103000020E610000001000000050000003D64CA87A0324A4077853E58C60E4B403D64CA87A0324A4010E7E104A6114B40207EFE7BF0344A4010E7E104A6114B40207EFE7BF0344A4077853E58C60E4B403D64CA87A0324A4077853E58C60E4B40
51039	4884	53.077812000000002	53.132429999999999	54.008792	53.976672000000001	 Центральная	0103000020E61000000100000005000000419E5DBEF5894A409F758D9603FD4A40419E5DBEF5894A40B43BA41820014B4030815B77F3904A40B43BA41820014B4030815B77F3904A409F758D9603FD4A40419E5DBEF5894A409F758D9603FD4A40
50528	46352	60.703088999999999	60.749946000000001	50.847630000000002	50.826793000000002	Воронежская	0103000020E61000000100000005000000B39602D2FE594E40E7C75F5AD4694940B39602D2FE594E40E38DCC237F6C49400DE2033BFE5F4E40E38DCC237F6C49400DE2033BFE5F4E40E7C75F5AD4694940B39602D2FE594E40E7C75F5AD4694940
50529	4809	61.145195000000001	61.169369000000003	51.448591999999998	51.433019000000002	Бугурусланская	0103000020E610000001000000050000007845F0BF95924E40F8C5A52A6DB749407845F0BF95924E40A59F70766BB9494066FA25E2AD954E40A59F70766BB9494066FA25E2AD954E40F8C5A52A6DB749407845F0BF95924E40F8C5A52A6DB74940
50073	46060	60.807805999999999	60.914256000000002	50.840133000000002	50.809874999999998	Торговая	0103000020E610000001000000050000009CC1DF2F66674E408B6CE7FBA96749409CC1DF2F66674E402BA5677A896B4940FD15325706754E402BA5677A896B4940FD15325706754E408B6CE7FBA96749409CC1DF2F66674E408B6CE7FBA9674940
50066	46060	60.807805999999999	60.914256000000002	50.840133000000002	50.809874999999998	Промышленная	0103000020E610000001000000050000009CC1DF2F66674E408B6CE7FBA96749409CC1DF2F66674E402BA5677A896B4940FD15325706754E402BA5677A896B4940FD15325706754E408B6CE7FBA96749409CC1DF2F66674E408B6CE7FBA9674940
49770	46060	60.807805999999999	60.914256000000002	50.840133000000002	50.809874999999998	Овечкина	0103000020E610000001000000050000009CC1DF2F66674E408B6CE7FBA96749409CC1DF2F66674E402BA5677A896B4940FD15325706754E402BA5677A896B4940FD15325706754E408B6CE7FBA96749409CC1DF2F66674E408B6CE7FBA9674940
49769	46060	60.807805999999999	60.914256000000002	50.840133000000002	50.809874999999998	Мира	0103000020E610000001000000050000009CC1DF2F66674E408B6CE7FBA96749409CC1DF2F66674E402BA5677A896B4940FD15325706754E402BA5677A896B4940FD15325706754E408B6CE7FBA96749409CC1DF2F66674E408B6CE7FBA9674940
50461	46660	61.337254999999999	61.352859000000002	50.883006999999999	50.868889000000003	Комсомольская	0103000020E61000000100000005000000CCB4FD2B2BAB4E40556D37C1376F4940CCB4FD2B2BAB4E40CD91955F06714940B58CD47B2AAD4E40CD91955F06714940B58CD47B2AAD4E40556D37C1376F4940CCB4FD2B2BAB4E40556D37C1376F4940
50523	46231	60.885312999999996	60.930166	51.119562999999999	51.098379999999999	Чкалова	0103000020E61000000100000005000000A0DCB6EF51714E404D4A41B7978C4940A0DCB6EF51714E40E46723D74D8F4940F2ECF2AD0F774E40E46723D74D8F4940F2ECF2AD0F774E404D4A41B7978C4940A0DCB6EF51714E404D4A41B7978C4940
51311	46212	61.125396000000002	61.143030000000003	51.148421999999997	51.139375000000001	квартал Новоселов	0103000020E610000001000000050000004D86E3F90C904E40A4703D0AD79149404D86E3F90C904E40E200FA7DFF924940672C9ACE4E924E40E200FA7DFF924940672C9ACE4E924E40A4703D0AD79149404D86E3F90C904E40A4703D0AD7914940
50573	46180	61.290776000000001	61.325757000000003	51.439205999999999	51.420574000000002	Советская	0103000020E61000000100000005000000193BE12538A54E4022C66B5ED5B54940193BE12538A54E407E1AF7E637B84940B7B8C667B2A94E407E1AF7E637B84940B7B8C667B2A94E4022C66B5ED5B54940193BE12538A54E4022C66B5ED5B54940
51173	46149	61.441611999999999	61.474795999999998	51.206389000000001	51.196592000000003	Целинная	0103000020E61000000100000005000000B5C2F4BD86B84E40DF5339ED29994940B5C2F4BD86B84E4088A06AF46A9A4940C422861DC6BC4E4088A06AF46A9A4940C422861DC6BC4E40DF5339ED29994940B5C2F4BD86B84E40DF5339ED29994940
50394	3641	56.454039999999999	56.473435000000002	51.752851999999997	51.743870000000001	Центральная	0103000020E61000000100000005000000B58993FB1D3A4C40DE3CD52137DF4940B58993FB1D3A4C40355D4F745DE0494011E4A084993C4C40355D4F745DE0494011E4A084993C4C40DE3CD52137DF4940B58993FB1D3A4C40DE3CD52137DF4940
49771	1907	55.977134	56.048755999999997	51.894184000000003	51.871163000000003	Ленинская	0103000020E61000000100000005000000A3E716BA12FD4B401D3EE94482EF4940A3E716BA12FD4B40A14D0E9F74F24940ECBDF8A23D064C40A14D0E9F74F24940ECBDF8A23D064C401D3EE94482EF4940A3E716BA12FD4B401D3EE94482EF4940
51056	1907	55.977134	56.048755999999997	51.894184000000003	51.871163000000003	Вокзальная	0103000020E61000000100000005000000A3E716BA12FD4B401D3EE94482EF4940A3E716BA12FD4B40A14D0E9F74F24940ECBDF8A23D064C40A14D0E9F74F24940ECBDF8A23D064C401D3EE94482EF4940A3E716BA12FD4B401D3EE94482EF4940
49795	45506	56.314469000000003	56.353653000000001	51.817815000000003	51.801828	Советская	0103000020E610000001000000050000008C4D2B8540284C403082C64CA2E649408C4D2B8540284C40D1967329AEE84940EF906280442D4C40D1967329AEE84940EF906280442D4C403082C64CA2E649408C4D2B8540284C403082C64CA2E64940
50390	2775	56.164862999999997	56.186926	51.851951999999997	51.843550999999998	Советская	0103000020E6100000010000000500000004A9143B1A154C4009C1AA7AF9EB494004A9143B1A154C4082E15CC30CED4940D462F030ED174C4082E15CC30CED4940D462F030ED174C4009C1AA7AF9EB494004A9143B1A154C4009C1AA7AF9EB4940
51302	2876	56.361936	56.370955000000002	51.844830999999999	51.834397000000003	Центральная	0103000020E610000001000000050000005E9F39EB532E4C40B5705985CDEA49405E9F39EB532E4C40D0D2156C23EC4940D3A414747B2F4C40D0D2156C23EC4940D3A414747B2F4C40B5705985CDEA49405E9F39EB532E4C40B5705985CDEA4940
51099	49570	55.850704999999998	55.868921999999998	51.871969	51.856352000000001	Школьный	0103000020E6100000010000000500000097C5C4E6E3EC4B409EEE3CF19CED494097C5C4E6E3EC4B401B1021AE9CEF494030630AD638EF4B401B1021AE9CEF494030630AD638EF4B409EEE3CF19CED494097C5C4E6E3EC4B409EEE3CF19CED4940
50697	3120	56.393503000000003	56.415636999999997	52.064076	52.047744999999999	Заречная	0103000020E610000001000000050000005FF0694E5E324C4015C616821C064A405FF0694E5E324C40B03A72A433084A40F700DD9733354C40B03A72A433084A40F700DD9733354C4015C616821C064A405FF0694E5E324C4015C616821C064A40
50543	48749	56.527710999999996	56.556393999999997	52.016894000000001	51.996431999999999	Луговая	0103000020E61000000100000005000000A65EB7088C434C400C5872158BFF4940A65EB7088C434C40D3BF249529024A4066D828EB37474C40D3BF249529024A4066D828EB37474C400C5872158BFF4940A65EB7088C434C400C5872158BFF4940
49900	1607	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	переулок Заводской	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
50437	1607	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	Промышленная	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
49904	1607	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	Первомайская	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
50069	1607	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	Мира	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
49775	1607	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	Красноармейская	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
81002	1607	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	Комсомольская	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
49862	1607	56.328761	56.395451999999999	51.800642000000003	51.758187999999997	Геологов	0103000020E61000000100000005000000A29927D7142A4C401D1CEC4D0CE14940A29927D7142A4C40EBE6E26F7BE64940A391CF2B9E324C40EBE6E26F7BE64940A391CF2B9E324C401D1CEC4D0CE14940A29927D7142A4C401D1CEC4D0CE14940
50658	21774	55.798279000000001	55.820988	51.951687999999997	51.935026999999998	Большая	0103000020E61000000100000005000000B30A9B012EE64B4041F0F8F6AEF74940B30A9B012EE64B4071FF91E9D0F949404834812216E94B4071FF91E9D0F949404834812216E94B4041F0F8F6AEF74940B30A9B012EE64B4041F0F8F6AEF74940
51037	3064	56.485543999999997	56.497447000000001	51.903497999999999	51.892000000000003	Центральная	0103000020E610000001000000050000006F62484E263E4C401904560E2DF249406F62484E263E4C402E008DD2A5F34940253FE257AC3F4C402E008DD2A5F34940253FE257AC3F4C401904560E2DF249406F62484E263E4C401904560E2DF24940
50554	45743	56.556682000000002	56.593234000000002	51.878864	51.854038000000003	 Школьная	0103000020E61000000100000005000000CD22145B41474C4048C5FF1D51ED4940CD22145B41474C40DDD0949D7EF0494009707A17EF4B4C40DDD0949D7EF0494009707A17EF4B4C4048C5FF1D51ED4940CD22145B41474C4048C5FF1D51ED4940
50982	46034	55.915230999999999	55.943562999999997	51.666165999999997	51.649991	Лабужского	0103000020E6100000010000000500000087A4164A26F54B40E0D8B3E732D3494087A4164A26F54B4083DA6FED44D549409A5B21ACC6F84B4083DA6FED44D549409A5B21ACC6F84B40E0D8B3E732D3494087A4164A26F54B40E0D8B3E732D34940
51384	56191	56.297122000000002	56.338228999999998	52.101742999999999	52.086627	Школьный переулок	0103000020E610000001000000050000000876FC1708264C40ADF9F197160B4A400876FC1708264C4068CC24EA050D4A4086C77E164B2B4C4068CC24EA050D4A4086C77E164B2B4C40ADF9F197160B4A400876FC1708264C40ADF9F197160B4A40
81005	62049	56.221043999999999	56.246465999999998	51.544021000000001	51.532541999999999	Кольцевая	0103000020E610000001000000050000000F7D772B4B1C4C408BDF14562AC449400F7D772B4B1C4C402AABE97AA2C54940B8C9A8328C1F4C402AABE97AA2C54940B8C9A8328C1F4C408BDF14562AC449400F7D772B4B1C4C408BDF14562AC44940
81012	62056	56.638697999999998	56.654859000000002	51.623344000000003	51.612026	Культурная	0103000020E61000000100000005000000A30227DBC0514C409E2633DE56CE4940A30227DBC0514C40341477BCC9CF4940E23E726BD2534C40341477BCC9CF4940E23E726BD2534C409E2633DE56CE4940A30227DBC0514C409E2633DE56CE4940
51033	45591	56.420892000000002	56.463678999999999	51.970883999999998	51.958852999999998	Заводская	0103000020E61000000100000005000000F392FFC9DF354C40F355F2B1BBFA4940F392FFC9DF354C40D61A4AED45FC4940C66B5ED5593B4C40D61A4AED45FC4940C66B5ED5593B4C40F355F2B1BBFA4940F392FFC9DF354C40F355F2B1BBFA4940
81015	62057	56.471556999999997	56.508091999999998	52.162824000000001	52.152531000000003	переулок Школьный	0103000020E610000001000000050000009599D2FA5B3C4C402750C42286134A409599D2FA5B3C4C408080B56AD7144A40FBAD9D2809414C408080B56AD7144A40FBAD9D2809414C402750C42286134A409599D2FA5B3C4C402750C42286134A40
81003	45367	55.992835999999997	56.026980999999999	51.997340999999999	51.981247000000003	Парковая	0103000020E610000001000000050000004E25034015FF4B4029266F8099FD49404E25034015FF4B40DFFAB0DEA8FF4940834E081D74034C40DFFAB0DEA8FF4940834E081D74034C4029266F8099FD49404E25034015FF4B4029266F8099FD4940
50578	45355	56.140698999999998	56.158962000000002	51.865046	51.852108000000001	Культурная	0103000020E610000001000000050000003ACAC16C02124C407A54FCDF11ED49403ACAC16C02124C408FC4CBD3B9EE494044A7E7DD58144C408FC4CBD3B9EE494044A7E7DD58144C407A54FCDF11ED49403ACAC16C02124C407A54FCDF11ED4940
51027	47665	56.498040000000003	56.509357999999999	51.793495999999998	51.787736000000002	Л.Толстого	0103000020E61000000100000005000000C80C54C6BF3F4C40E1F08288D4E44940C80C54C6BF3F4C40DFC0E44691E549405DFA97A432414C40DFC0E44691E549405DFA97A432414C40E1F08288D4E44940C80C54C6BF3F4C40E1F08288D4E44940
50482	21972	56.144686999999998	56.163668999999999	52.117030999999997	52.089432000000002	пер.Школьный	0103000020E610000001000000050000000394861A85124C40A29BFD81720B4A400394861A85124C4020CF2EDFFA0E4A403C2F151BF3144C4020CF2EDFFA0E4A403C2F151BF3144C40A29BFD81720B4A400394861A85124C40A29BFD81720B4A40
50648	2975	56.273991000000002	56.291373	51.880471	51.870401000000001	Центральная	0103000020E61000000100000005000000FD32182312234C40EEB3CA4C69EF4940FD32182312234C40C8091346B3F04940FDF7E0B54B254C40C8091346B3F04940FDF7E0B54B254C40EEB3CA4C69EF4940FD32182312234C40EEB3CA4C69EF4940
50704	45986	56.111314999999998	56.132658999999997	51.570535	51.561140999999999	Центральная	0103000020E61000000100000005000000F146E6913F0E4C40EDB8E177D3C74940F146E6913F0E4C40971C774A07C94940914259F8FA104C40971C774A07C94940914259F8FA104C40EDB8E177D3C74940F146E6913F0E4C40EDB8E177D3C74940
50795	3762	56.684584000000001	56.697806999999997	51.535029999999999	51.520355000000002	Школьная	0103000020E61000000100000005000000B4AED172A0574C40B1A71DFE9AC24940B4AED172A0574C407F30F0DC7BC44940BEF561BD51594C407F30F0DC7BC44940BEF561BD51594C40B1A71DFE9AC24940B4AED172A0574C40B1A71DFE9AC24940
51193	4066	56.236513000000002	56.252915999999999	51.619396999999999	51.606068999999998	Школьная	0103000020E61000000100000005000000180AD80E461E4C40490F43AB93CD4940180AD80E461E4C40C91EA16648CF49404C512E8D5F204C40C91EA16648CF49404C512E8D5F204C40490F43AB93CD4940180AD80E461E4C40490F43AB93CD4940
51091	3499	56.521512999999999	56.555486999999999	51.789357000000003	51.782705	Заречная	0103000020E610000001000000050000002CB81FF0C0424C4035B56CAD2FE449402CB81FF0C0424C4031EF71A609E54940342DB1321A474C4031EF71A609E54940342DB1321A474C4035B56CAD2FE449402CB81FF0C0424C4035B56CAD2FE44940
50860	2275	56.000562000000002	56.018348000000003	51.933715999999997	51.919542999999997	Школьная	0103000020E6100000010000000500000068CF656A12004C400322C495B3F5494068CF656A12004C403FE0810184F7494038F92D3A59024C403FE0810184F7494038F92D3A59024C400322C495B3F5494068CF656A12004C400322C495B3F54940
64166	58180	56.035308000000001	56.046681	51.943555000000003	51.937286999999998	Центральная	0103000020E61000000100000005000000C2A4F8F884044C40A4FB3905F9F74940C2A4F8F884044C40187D0569C6F849401B2C9CA4F9054C40187D0569C6F849401B2C9CA4F9054C40A4FB3905F9F74940C2A4F8F884044C40A4FB3905F9F74940
50989	2129	56.094427000000003	56.113875	51.881031999999998	51.869050000000001	 Полевая	0103000020E61000000100000005000000016E162F160C4C405E4BC8073DEF4940016E162F160C4C405F5D15A8C5F049407F6ABC74930E4C405F5D15A8C5F049407F6ABC74930E4C405E4BC8073DEF4940016E162F160C4C405E4BC8073DEF4940
49926	3730	56.580640000000002	56.596854	51.640300000000003	51.624222000000003	Советская	0103000020E61000000100000005000000EE5F5969524A4C40CCB8A981E6CF4940EE5F5969524A4C407DD0B359F5D149404F3E3DB6654C4C407DD0B359F5D149404F3E3DB6654C4C40CCB8A981E6CF4940EE5F5969524A4C40CCB8A981E6CF4940
50494	45380	56.142468000000001	56.162177	51.952970000000001	51.923459000000001	Школьная	0103000020E61000000100000005000000FF5C34643C124C4033198EE733F64940FF5C34643C124C40D908C4EBFAF94940EA944737C2144C40D908C4EBFAF94940EA944737C2144C4033198EE733F64940FF5C34643C124C4033198EE733F64940
50475	2430	55.965176999999997	55.983071000000002	52.100022000000003	52.077925999999998	Школьная	0103000020E61000000100000005000000FAEC80EB8AFB4B4009C1AA7AF9094A40FAEC80EB8AFB4B40B5705985CD0C4A40B1524145D5FD4B40B5705985CD0C4A40B1524145D5FD4B4009C1AA7AF9094A40FAEC80EB8AFB4B4009C1AA7AF9094A40
50521	48857	56.416634000000002	56.438670000000002	51.765602000000001	51.749239000000003	Школьная	0103000020E610000001000000050000006A334E4354354C40A2F14410E7DF49406A334E4354354C4048E00F3FFFE1494040DEAB5626384C4048E00F3FFFE1494040DEAB5626384C40A2F14410E7DF49406A334E4354354C40A2F14410E7DF4940
50249	45554	56.404552000000002	56.437358000000003	51.864829	51.85351	Школьная	0103000020E6100000010000000500000005C4245CC8334C408C67D0D03FED494005C4245CC8334C40F2D077B7B2EE49406E52D158FB374C40F2D077B7B2EE49406E52D158FB374C408C67D0D03FED494005C4245CC8334C408C67D0D03FED4940
9915	3308	56.508082999999999	56.527054999999997	52.114834999999999	52.099556999999997	Зеленая	0103000020E61000000100000005000000A8531EDD08414C403F8BA548BE0C4A40A8531EDD08414C40D4B7CCE9B20E4A40BD18CA8976434C40D4B7CCE9B20E4A40BD18CA8976434C403F8BA548BE0C4A40A8531EDD08414C403F8BA548BE0C4A40
50845	2385	56.044407999999997	56.057155000000002	51.911805000000001	51.903036999999998	Сакмарская	0103000020E6100000010000000500000023D74D29AF054C40FA0967B796F3494023D74D29AF054C4026AAB706B6F44940C5E6E3DA50074C4026AAB706B6F44940C5E6E3DA50074C40FA0967B796F3494023D74D29AF054C40FA0967B796F34940
81007	62051	56.633515000000003	56.649549	51.947812999999996	51.930923	Школьная	0103000020E610000001000000050000004243FF0417514C400F0C207C28F749404243FF0417514C40A0DCB6EF51F949402313F06B24534C40A0DCB6EF51F949402313F06B24534C400F0C207C28F749404243FF0417514C400F0C207C28F74940
64079	45840	56.280557000000002	56.305171000000001	51.818299000000003	51.806255999999998	Рощепкина	0103000020E61000000100000005000000FAD4B14AE9234C40151A886533E74940FAD4B14AE9234C40BDAC8905BEE849400458E4D70F274C40BDAC8905BEE849400458E4D70F274C40151A886533E74940FAD4B14AE9234C40151A886533E74940
50576	49320	55.572721000000001	55.598115999999997	52.102975999999998	52.053859000000003	Лесная	0103000020E61000000100000005000000C05DF6EB4EC94B4032CC09DAE4064A40C05DF6EB4EC94B40EE224C512E0D4A406F9BA9108FCC4B40EE224C512E0D4A406F9BA9108FCC4B4032CC09DAE4064A40C05DF6EB4EC94B4032CC09DAE4064A40
50988	49295	55.841461000000002	55.874968000000003	52.093986000000001	52.074655	Советская	0103000020E6100000010000000500000003EE79FEB4EB4B40CFBD874B8E094A4003EE79FEB4EB4B401424B6BB070C4A40F58590F3FEEF4B401424B6BB070C4A40F58590F3FEEF4B40CFBD874B8E094A4003EE79FEB4EB4B40CFBD874B8E094A40
49764	539	55.150899000000003	55.196218999999999	51.961750000000002	51.938969	Советская	0103000020E61000000100000005000000E3FF8EA850934B409A7ADD2230F84940E3FF8EA850934B40C976BE9F1AFB49404AED45B41D994B40C976BE9F1AFB49404AED45B41D994B409A7ADD2230F84940E3FF8EA850934B409A7ADD2230F84940
49765	539	55.150899000000003	55.196218999999999	51.961750000000002	51.938969	Комсомольская	0103000020E61000000100000005000000E3FF8EA850934B409A7ADD2230F84940E3FF8EA850934B40C976BE9F1AFB49404AED45B41D994B40C976BE9F1AFB49404AED45B41D994B409A7ADD2230F84940E3FF8EA850934B409A7ADD2230F84940
64198	58187	55.202696000000003	55.209128	52.151277	52.147331000000001	 Школьная	0103000020E61000000100000005000000D88349F1F1994B40EF5701BEDB124A40D88349F1F1994B4089D1730B5D134A40C556D0B4C49A4B4089D1730B5D134A40C556D0B4C49A4B40EF5701BEDB124A40D88349F1F1994B40EF5701BEDB124A40
50715	56102	55.353262999999998	55.379097999999999	51.971637999999999	51.950887999999999	 Железнодорожная	0103000020E6100000010000000500000084F1D3B837AD4B405514AFB2B6F9494084F1D3B837AD4B4082C64CA25EFC494050FD834886B04B4082C64CA25EFC494050FD834886B04B405514AFB2B6F9494084F1D3B837AD4B405514AFB2B6F94940
49897	241	55.308247999999999	55.346210999999997	51.999065999999999	51.974640000000001	Советская	0103000020E610000001000000050000005987A3AB74A74B40CDAFE600C1FC49405987A3AB74A74B40D4450A65E1FF4940FA415DA450AC4B40D4450A65E1FF4940FA415DA450AC4B40CDAFE600C1FC49405987A3AB74A74B40CDAFE600C1FC4940
49861	241	55.308247999999999	55.346210999999997	51.999065999999999	51.974640000000001	Ленина	0103000020E610000001000000050000005987A3AB74A74B40CDAFE600C1FC49405987A3AB74A74B40D4450A65E1FF4940FA415DA450AC4B40D4450A65E1FF4940FA415DA450AC4B40CDAFE600C1FC49405987A3AB74A74B40CDAFE600C1FC4940
78084	241	55.308247999999999	55.346210999999997	51.999065999999999	51.974640000000001	50 Лет Победы	0103000020E610000001000000050000005987A3AB74A74B40CDAFE600C1FC49405987A3AB74A74B40D4450A65E1FF4940FA415DA450AC4B40D4450A65E1FF4940FA415DA450AC4B40CDAFE600C1FC49405987A3AB74A74B40CDAFE600C1FC4940
49914	49380	55.680177	55.714277000000003	52.035763000000003	52.022553000000002	В.Т.Обухова	0103000020E61000000100000005000000E63E390A10D74B409EB64604E3024A40E63E390A10D74B4014B4C9E193044A407BA4C16D6DDB4B4014B4C9E193044A407BA4C16D6DDB4B409EB64604E3024A40E63E390A10D74B409EB64604E3024A40
50356	49349	55.279752999999999	55.290596000000001	52.107605999999997	52.093234000000002	Школьная	0103000020E610000001000000050000009CFA40F2CEA34B4009707A17EF0B4A409CFA40F2CEA34B403B6D8D08C60D4A40992CEE3F32A54B403B6D8D08C60D4A40992CEE3F32A54B4009707A17EF0B4A409CFA40F2CEA34B4009707A17EF0B4A40
50128	56053	54.641706999999997	55.935406999999998	53.089627999999998	51.938969	Краснокоммунарская	0103000020E61000000100000005000000A04E797423524B409A7ADD2230F84940A04E797423524B40276728EE788B4A4088B9A46ABBF74B40276728EE788B4A4088B9A46ABBF74B409A7ADD2230F84940A04E797423524B409A7ADD2230F84940
50981	49368	55.377372999999999	55.396346000000001	52.051848999999997	52.040537999999998	Янгизская	0103000020E610000001000000050000005BB22AC24DB04B40641F645930054A405BB22AC24DB04B4047AAEFFCA2064A4041F33977BBB24B4047AAEFFCA2064A4041F33977BBB24B40641F645930054A405BB22AC24DB04B40641F645930054A40
50405	56069	55.023536	55.037585999999997	52.130018999999997	52.120890000000003	Культурная	0103000020E61000000100000005000000AB23473A03834B40EC34D252790F4A40AB23473A03834B40E76D6C76A4104A40CB64389ECF844B40E76D6C76A4104A40CB64389ECF844B40EC34D252790F4A40AB23473A03834B40EC34D252790F4A40
71746	49556	55.497864	55.531478999999997	52.009672000000002	51.978544999999997	улица Центральная	0103000020E6100000010000000500000089EDEE01BABF4B4008556AF640FD494089EDEE01BABF4B40EDD79DEE3C014A4061C1FD8007C44B40EDD79DEE3C014A4061C1FD8007C44B4008556AF640FD494089EDEE01BABF4B4008556AF640FD4940
50228	628	55.615183999999999	55.630859999999998	52.011761999999997	52.000629000000004	Школьная	0103000020E61000000100000005000000E0826C59BECE4B40F0366F9C14004A40E0826C59BECE4B40F3AACE6A81014A40622D3E05C0D04B40F3AACE6A81014A40622D3E05C0D04B40F0366F9C14004A40E0826C59BECE4B40F0366F9C14004A40
50383	49442	54.826203	54.854751	52.175341000000003	52.157349000000004	Школьная	0103000020E61000000100000005000000B56D1805C1694B407787140324144A40B56D1805C1694B40F052EA9271164A40959C137B686D4B40F052EA9271164A40959C137B686D4B407787140324144A40B56D1805C1694B407787140324144A40
50419	49339	55.421686999999999	55.431604999999998	52.059075999999997	52.040388999999998	Школьная	0103000020E61000000100000005000000FD12F1D6F9B54B401F0F7D772B054A40FD12F1D6F9B54B403FFD67CD8F074A4021E527D53EB74B403FFD67CD8F074A4021E527D53EB74B401F0F7D772B054A40FD12F1D6F9B54B401F0F7D772B054A40
51187	31490	53.815984999999998	53.830249999999999	53.139930999999997	53.122815000000003	Центральная	0103000020E6100000010000000500000066834C3272E84A40A83AE466B88F4A4066834C3272E84A4029594E42E9914A4083C0CAA145EA4A4029594E42E9914A4083C0CAA145EA4A40A83AE466B88F4A4066834C3272E84A40A83AE466B88F4A40
50692	31449	53.959446	53.995243000000002	53.284517000000001	53.257257000000003	Совхозная	0103000020E6100000010000000500000096236420CFFA4A4063D520CCEDA04A4096236420CFFA4A40F913950D6BA44A405649641F64FF4A40F913950D6BA44A405649641F64FF4A4063D520CCEDA04A4096236420CFFA4A4063D520CCEDA04A40
49793	48773	54.422517999999997	54.468268999999999	53.202513000000003	53.145381	Казанская	0103000020E6100000010000000500000054FCDF1115364B40DA3A38D89B924A4054FCDF1115364B40E7012CF2EB994A40855D143DF03B4B40E7012CF2EB994A40855D143DF03B4B40DA3A38D89B924A4054FCDF1115364B40DA3A38D89B924A40
50868	48700	53.784705000000002	53.815634000000003	53.403309	53.390158999999997	переулок Садовый 	0103000020E61000000100000005000000FC00A43671E44A40BA9EE8BAF0B14A40FC00A43671E44A405B971AA19FB34A40BAC0E5B166E84A405B971AA19FB34A40BAC0E5B166E84A40BA9EE8BAF0B14A40FC00A43671E44A40BA9EE8BAF0B14A40
51195	48695	53.999834	54.028965999999997	53.369802	53.355153999999999	Южная	0103000020E61000000100000005000000E5B67D8FFAFF4A409485AFAF75AD4A40E5B67D8FFAFF4A4069FF03AC55AF4A4014596B28B5034B4069FF03AC55AF4A4014596B28B5034B409485AFAF75AD4A40E5B67D8FFAFF4A409485AFAF75AD4A40
51179	49103	54.050454000000002	54.092666000000001	53.045535000000001	53.014367999999997	Крестьянская	0103000020E61000000100000005000000E8F9D34675064B40F10D85CFD6814A40E8F9D34675064B4064E94317D4854A40BFB9BF7ADC0B4B4064E94317D4854A40BFB9BF7ADC0B4B40F10D85CFD6814A40E8F9D34675064B40F10D85CFD6814A40
51388	22619	54.422671000000001	54.432848999999997	53.113757	53.099572000000002	Оренбургская	0103000020E61000000100000005000000DBFB54151A364B4075CC79C6BE8C4A40DBFB54151A364B407558E1968F8E4A409B8D959867374B407558E1968F8E4A409B8D959867374B4075CC79C6BE8C4A40DBFB54151A364B4075CC79C6BE8C4A40
51166	23222	54.061475999999999	54.084985000000003	53.221193	53.204276999999998	Советская	0103000020E6100000010000000500000094BE1072DE074B409929ADBF259A4A4094BE1072DE074B40548D5E0D509C4A4046D3D9C9E00A4B40548D5E0D509C4A4046D3D9C9E00A4B409929ADBF259A4A4094BE1072DE074B409929ADBF259A4A40
49911	22961	54.107101999999998	54.144300999999999	53.343989000000001	53.299684999999997	Советская	0103000020E6100000010000000500000008ABB184B50D4B40060DFD135CA64A4008ABB184B50D4B408597E0D407AC4A40DAE3857478124B408597E0D407AC4A40DAE3857478124B40060DFD135CA64A4008ABB184B50D4B40060DFD135CA64A40
51090	22961	54.107101999999998	54.144300999999999	53.343989000000001	53.299684999999997	Заречная	0103000020E6100000010000000500000008ABB184B50D4B40060DFD135CA64A4008ABB184B50D4B408597E0D407AC4A40DAE3857478124B408597E0D407AC4A40DAE3857478124B40060DFD135CA64A4008ABB184B50D4B40060DFD135CA64A40
49796	22961	54.107101999999998	54.144300999999999	53.343989000000001	53.299684999999997	Гагарина	0103000020E6100000010000000500000008ABB184B50D4B40060DFD135CA64A4008ABB184B50D4B408597E0D407AC4A40DAE3857478124B408597E0D407AC4A40DAE3857478124B40060DFD135CA64A4008ABB184B50D4B40060DFD135CA64A40
50861	22942	53.921509999999998	53.937472999999997	53.183230999999999	53.156716000000003	Центральная	0103000020E61000000100000005000000EE77280AF4F54A40466117450F944A40EE77280AF4F54A40834E081D74974A4006F1811DFFF74A40834E081D74974A4006F1811DFFF74A40466117450F944A40EE77280AF4F54A40466117450F944A40
51169	22848	54.516993999999997	54.536459999999998	53.253756000000003	53.226987999999999	Школьная	0103000020E61000000100000005000000361D01DC2C424B40CF4A5AF10D9D4A40361D01DC2C424B40F7949C137BA04A405BCEA5B8AA444B40F7949C137BA04A405BCEA5B8AA444B40CF4A5AF10D9D4A40361D01DC2C424B40CF4A5AF10D9D4A40
50470	22881	54.139584999999997	54.161225000000002	53.298619000000002	53.278691999999999	Школьная	0103000020E610000001000000050000008E01D9EBDD114B4013D4F02DACA34A408E01D9EBDD114B406C7BBB2539A64A4018265305A3144B406C7BBB2539A64A4018265305A3144B4013D4F02DACA34A408E01D9EBDD114B4013D4F02DACA34A40
50542	22881	54.139584999999997	54.161225000000002	53.298619000000002	53.278691999999999	Советская	0103000020E610000001000000050000008E01D9EBDD114B4013D4F02DACA34A408E01D9EBDD114B406C7BBB2539A64A4018265305A3144B406C7BBB2539A64A4018265305A3144B4013D4F02DACA34A408E01D9EBDD114B4013D4F02DACA34A40
50858	48962	54.344068	54.378976999999999	53.231721	53.198807000000002	Молодежная	0103000020E61000000100000005000000D1CC936B0A2C4B40A29BFD8172994A40D1CC936B0A2C4B40F165A208A99D4A40D5777E5182304B40F165A208A99D4A40D5777E5182304B40A29BFD8172994A40D1CC936B0A2C4B40A29BFD8172994A40
50870	48633	54.388741000000003	54.428690000000003	53.368319	53.350875000000002	Центральная	0103000020E61000000100000005000000A3CEDC43C2314B40F4FDD478E9AC4A40A3CEDC43C2314B406ABFB51325AF4A40A60F5D50DF364B406ABFB51325AF4A40A60F5D50DF364B40F4FDD478E9AC4A40A3CEDC43C2314B40F4FDD478E9AC4A40
51165	22726	54.194130000000001	54.217343	53.210721999999997	53.181460999999999	Калинина	0103000020E6100000010000000500000014967840D9184B40EE3F321D3A974A4014967840D9184B401B4641F0F89A4A40DC813AE5D11B4B401B4641F0F89A4A40DC813AE5D11B4B40EE3F321D3A974A4014967840D9184B40EE3F321D3A974A40
50844	48948	54.189476999999997	54.207641000000002	53.085706999999999	53.072935000000001	Набережная	0103000020E610000001000000050000000E2C47C840184B40ECDD1FEF55894A400E2C47C840184B40E6046D72F88A4A408527F4FA931A4B40E6046D72F88A4A408527F4FA931A4B40ECDD1FEF55894A400E2C47C840184B40ECDD1FEF55894A40
51410	22688	53.852015999999999	53.892879999999998	53.395620000000001	53.368721999999998	Центральная	0103000020E6100000010000000500000099D53BDC0EED4A4069A8514832AF4A4099D53BDC0EED4A405FD218ADA3B24A4051A04FE449F24A405FD218ADA3B24A4051A04FE449F24A4069A8514832AF4A4099D53BDC0EED4A4069A8514832AF4A40
50386	31899	54.320191000000001	54.343781	53.133389000000001	53.124592999999997	Центральная	0103000020E610000001000000050000009DBCC804FC284B40BF27D6A9F28F4A409DBCC804FC284B40B55208E412914A403BFE0B04012C4B40B55208E412914A403BFE0B04012C4B40BF27D6A9F28F4A409DBCC804FC284B40BF27D6A9F28F4A40
64115	23314	54.337294999999997	54.345936999999999	53.183349999999997	53.175082000000003	Центральная	0103000020E610000001000000050000005A0D897B2C2B4B40240F441669964A405A0D897B2C2B4B405DDC460378974A40F9BCE2A9472C4B405DDC460378974A40F9BCE2A9472C4B40240F441669964A405A0D897B2C2B4B40240F441669964A40
50556	45672	54.203733	54.260838999999997	53.178238999999998	53.149555999999997	Рабочий городок	0103000020E61000000100000005000000D80E46EC131A4B40D575A8A624934A40D80E46EC131A4B4095EF1989D0964A40BB421F2C63214B4095EF1989D0964A40BB421F2C63214B40D575A8A624934A40D80E46EC131A4B40D575A8A624934A40
50742	20129	54.498703999999996	54.522384000000002	53.290401000000003	53.253577999999997	Верхняя	0103000020E6100000010000000500000033315D88D53F4B40177E703E75A04A4033315D88D53F4B40E4DC26DC2BA54A4012FA997ADD424B40E4DC26DC2BA54A4012FA997ADD424B40177E703E75A04A4033315D88D53F4B40177E703E75A04A40
51191	48819	54.003463000000004	54.019902000000002	53.438113999999999	53.414043999999997	Молодежная	0103000020E610000001000000050000007FDFBF7971004B40718DCF64FFB44A407FDFBF7971004B40BAF59A1E14B84A40009013268C024B40BAF59A1E14B84A40009013268C024B40718DCF64FFB44A407FDFBF7971004B40718DCF64FFB44A40
50856	16024	53.862859	53.899977	53.232593999999999	53.213411999999998	Центральная	0103000020E610000001000000050000009607E92972EE4A4077499C15519B4A409607E92972EE4A40779FE3A3C59D4A407B13437232F34A40779FE3A3C59D4A407B13437232F34A4077499C15519B4A409607E92972EE4A4077499C15519B4A40
51164	1596	54.002052999999997	54.026316000000001	53.176921999999998	53.161316999999997	Центральная	0103000020E61000000100000005000000E9EDCF4543004B40F8A41309A6944A40E9EDCF4543004B40B1F84D61A5964A4047AE9B525E034B40B1F84D61A5964A4047AE9B525E034B40F8A41309A6944A40E9EDCF4543004B40F8A41309A6944A40
64212	56125	54.269257000000003	54.295262999999998	53.057459000000001	53.028753999999999	Самарская	0103000020E610000001000000050000000B9C6C0377224B4089D00836AE834A400B9C6C0377224B4031EE06D15A874A40035C902DCB254B4031EE06D15A874A40035C902DCB254B4089D00836AE834A400B9C6C0377224B4089D00836AE834A40
50974	29153	54.306122999999999	54.328266999999997	52.058323000000001	52.044676000000003	Школьная	0103000020E61000000100000005000000D6C6D8092F274B40437573F1B7054A40D6C6D8092F274B4064CDC82077074A4092AD2EA7042A4B4064CDC82077074A4092AD2EA7042A4B40437573F1B7054A40D6C6D8092F274B40437573F1B7054A40
51397	49278	54.214325000000002	54.228265999999998	51.838476	51.826366	Южная	0103000020E610000001000000050000008CDB68006F1B4B405F43705CC6E949408CDB68006F1B4B408E3D7B2E53EB4940F564FED1371D4B408E3D7B2E53EB4940F564FED1371D4B405F43705CC6E949408CDB68006F1B4B405F43705CC6E94940
50814	56116	54.657831999999999	54.677540999999998	51.757998000000001	51.749367999999997	Школьная	0103000020E610000001000000050000009221C7D633544B409F55664AEBDF49409221C7D633544B407A37161406E149407D59DAA9B9564B407A37161406E149407D59DAA9B9564B409F55664AEBDF49409221C7D633544B409F55664AEBDF4940
50065	56049	54.068196	54.103374000000002	51.667512000000002	51.647666000000001	Кушмухаметовых	0103000020E61000000100000005000000E8DB82A5BA084B40965D30B8E6D24940E8DB82A5BA084B4002D8800871D54940DCA0F65B3B0D4B4002D8800871D54940DCA0F65B3B0D4B40965D30B8E6D24940E8DB82A5BA084B40965D30B8E6D24940
50690	31254	54.266651000000003	54.295802000000002	51.973275000000001	51.954796000000002	Молодежная	0103000020E610000001000000050000000D39B69E21224B40022D5DC136FA49400D39B69E21224B40D881734694FC4940B30B06D7DC254B40D881734694FC4940B30B06D7DC254B40022D5DC136FA49400D39B69E21224B40022D5DC136FA4940
50577	48465	54.297103999999997	54.323999999999998	51.698604000000003	51.686221000000003	Советская	0103000020E6100000010000000500000061C1FD8007264B400A6AF816D6D7494061C1FD8007264B406A6D1ADB6BD94940B6F3FDD478294B406A6D1ADB6BD94940B6F3FDD478294B400A6AF816D6D7494061C1FD8007264B400A6AF816D6D74940
50627	56084	54.514218	54.544249000000001	51.885317999999998	51.866447000000001	Железнодорожная	0103000020E61000000100000005000000DC813AE5D1414B40D15B3CBCE7EE4940DC813AE5D1414B40B247A81952F14940BBF083F3A9454B40B247A81952F14940BBF083F3A9454B40D15B3CBCE7EE4940DC813AE5D1414B40D15B3CBCE7EE4940
50694	29639	54.420972999999996	54.430880999999999	52.008752000000001	52.005308999999997	Школьный пер	0103000020E61000000100000005000000DFBF7971E2354B40EEAF1EF7AD004A40DFBF7971E2354B4026E318C91E014A40E0BBCD1B27374B4026E318C91E014A40E0BBCD1B27374B40EEAF1EF7AD004A40DFBF7971E2354B40EEAF1EF7AD004A40
50977	48288	54.310111999999997	54.323900999999999	52.282933	52.273251999999999	Заречная	0103000020E610000001000000050000006F0C01C0B1274B4086C8E9EBF9224A406F0C01C0B1274B40C6FA062637244A402312859675294B40C6FA062637244A402312859675294B4086C8E9EBF9224A406F0C01C0B1274B4086C8E9EBF9224A40
50236	48344	54.493467000000003	54.524827000000002	52.296770000000002	52.278801000000001	Горького	0103000020E61000000100000005000000DF5339ED293F4B40CA8B4CC0AF234A40DF5339ED293F4B408B37328FFC254A406687F8872D434B408B37328FFC254A406687F8872D434B40CA8B4CC0AF234A40DF5339ED293F4B40CA8B4CC0AF234A40
51032	48146	54.378411	54.403500999999999	52.162149999999997	52.149540999999999	Садовая	0103000020E610000001000000050000002CB98AC56F304B40A034D42824134A402CB98AC56F304B40F085C954C1144A409F73B7EBA5334B40F085C954C1144A409F73B7EBA5334B40A034D42824134A402CB98AC56F304B40A034D42824134A40
50232	47871	54.078544000000001	54.098171999999998	51.801115000000003	51.780859999999997	Центральная	0103000020E6100000010000000500000005A6D3BA0D0A4B4095607138F3E3494005A6D3BA0D0A4B40E3AAB2EF8AE6494003B16CE6900C4B40E3AAB2EF8AE6494003B16CE6900C4B4095607138F3E3494005A6D3BA0D0A4B4095607138F3E34940
51300	30659	54.491095000000001	54.513948999999997	51.724487000000003	51.712451999999999	Северная	0103000020E61000000100000005000000541D7233DC3E4B4022FC8BA031DB4940541D7233DC3E4B4047B071FDBBDC4940EC67B114C9414B4047B071FDBBDC4940EC67B114C9414B4022FC8BA031DB4940541D7233DC3E4B4022FC8BA031DB4940
50979	29939	54.476156000000003	54.491697000000002	52.345629000000002	52.332517000000003	Родничная	0103000020E61000000100000005000000A8E507AEF23C4B40992EC4EA8F2A4A40A8E507AEF23C4B404CC631923D2C4A404A4563EDEF3E4B404CC631923D2C4A404A4563EDEF3E4B40992EC4EA8F2A4A40A8E507AEF23C4B40992EC4EA8F2A4A40
50702	56101	54.536847000000002	54.568162000000001	51.814512999999998	51.790432000000003	улица Школьная	0103000020E6100000010000000500000055FA0967B7444B401FDB32E02CE5494055FA0967B7444B405B9544F641E849403C6A4C88B9484B405B9544F641E849403C6A4C88B9484B401FDB32E02CE5494055FA0967B7444B401FDB32E02CE54940
50972	29236	54.188327000000001	54.202852999999998	52.024842	52.013696000000003	Молодежная	0103000020E6100000010000000500000016FA60191B184B40030B60CAC0014A4016FA60191B184B409BC8CC052E034A409F724C16F7194B409BC8CC052E034A409F724C16F7194B40030B60CAC0014A4016FA60191B184B40030B60CAC0014A40
51355	56174	54.351928000000001	54.370576999999997	52.033968000000002	52.024647999999999	Центральная	0103000020E61000000100000005000000FA4509FA0B2D4B40B6F468AA27034A40FA4509FA0B2D4B40268E3C1059044A402CD32F116F2F4B40268E3C1059044A402CD32F116F2F4B40B6F468AA27034A40FA4509FA0B2D4B40B6F468AA27034A40
49893	30165	54.306438	54.339523	52.254550000000002	52.233193	Парковая	0103000020E610000001000000050000003620425C39274B40FC53AA44D91D4A403620425C39274B4031992A1895204A40B29E5A7D752B4B4031992A1895204A40B29E5A7D752B4B40FC53AA44D91D4A403620425C39274B40FC53AA44D91D4A40
49859	30843	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	Советская	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
50389	30843	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	Пионерская	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
50424	30843	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	Молодежная	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
49860	30843	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	Лениская	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
49894	30843	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	Ленинская	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
50062	30843	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	Космическая	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
49766	30843	54.156742999999999	54.230888999999998	51.896107000000001	51.862098000000003	Западная	0103000020E610000001000000050000003F70952710144B4038F92D3A59EE49403F70952710144B40BC5B59A2B3F24940C90050C58D1D4B40BC5B59A2B3F24940C90050C58D1D4B4038F92D3A59EE49403F70952710144B4038F92D3A59EE4940
50224	30039	54.041739999999997	54.064926	51.930017999999997	51.918698999999997	Клубная	0103000020E61000000100000005000000AF777FBC57054B4017EFC7ED97F54940AF777FBC57054B407D586FD40AF749407E54C37E4F084B407D586FD40AF749407E54C37E4F084B4017EFC7ED97F54940AF777FBC57054B4017EFC7ED97F54940
50675	30394	54.567883000000002	54.585462999999997	52.278078999999998	52.270353	Уран	0103000020E61000000100000005000000297AE063B0484B4010B056ED9A224A40297AE063B0484B40295AB91798234A404F029B73F04A4B40295AB91798234A404F029B73F04A4B4010B056ED9A224A40297AE063B0484B4010B056ED9A224A40
51339	56167	54.255369000000002	54.265340000000002	52.329931000000002	52.325251999999999	Солнечная	0103000020E61000000100000005000000C4B46FEEAF204B40B37A87DBA1294A40C4B46FEEAF204B40E277D32D3B2A4A400B293FA9F6214B40E277D32D3B2A4A400B293FA9F6214B40B37A87DBA1294A40C4B46FEEAF204B40B37A87DBA1294A40
50569	48170	54.438372999999999	54.475591000000001	52.306452	52.291367000000001	Пионерская	0103000020E610000001000000050000008639419B1C384B401B118C834B254A408639419B1C384B409BE5B2D139274A40CFA2772AE03C4B409BE5B2D139274A40CFA2772AE03C4B401B118C834B254A408639419B1C384B401B118C834B254A40
51029	48426	54.434331	54.458936000000001	51.763043000000003	51.752690999999999	Набережная	0103000020E61000000100000005000000CA51802898374B402C7FBE2D58E04940CA51802898374B408B389D64ABE14940817A336ABE3A4B408B389D64ABE14940817A336ABE3A4B402C7FBE2D58E04940CA51802898374B402C7FBE2D58E04940
50631	56087	54.386451000000001	54.422230999999996	52.324728999999998	52.310741	Ленинская	0103000020E61000000100000005000000D540F33977314B405F43705CC6274A40D540F33977314B40098849B890294A40BE2D58AA0B364B40098849B890294A40BE2D58AA0B364B405F43705CC6274A40D540F33977314B405F43705CC6274A40
51034	29599	54.523173999999997	54.542982000000002	52.027451999999997	52.011102000000001	Центральная	0103000020E610000001000000050000000A0F9A5DF7424B40C97553CA6B014A400A0F9A5DF7424B40DA1A118C83034A408928266F80454B40DA1A118C83034A408928266F80454B40C97553CA6B014A400A0F9A5DF7424B40C97553CA6B014A40
51301	48230	54.100929999999998	54.125427000000002	51.966866000000003	51.951444000000002	Школьная	0103000020E61000000100000005000000B7973446EB0C4B40DBFCBFEAC8F94940B7973446EB0C4B40A3CEDC43C2FB49408884EFFD0D104B40A3CEDC43C2FB49408884EFFD0D104B40DBFCBFEAC8F94940B7973446EB0C4B40DBFCBFEAC8F94940
51350	56172	54.368564999999997	54.386999000000003	52.227682999999999	52.221950999999997	Раздольная	0103000020E61000000100000005000000A1B94E232D2F4B404128EFE3681C4A40A1B94E232D2F4B40766D6FB7241D4A40D84AE82E89314B40766D6FB7241D4A40D84AE82E89314B404128EFE3681C4A40A1B94E232D2F4B404128EFE3681C4A40
50647	29505	54.211224999999999	54.240141999999999	51.703443999999998	51.682994000000001	Восточная	0103000020E610000001000000050000007E8CB96B091B4B409FAEEE586CD749407E8CB96B091B4B40A148F7730ADA4940B1321AF9BC1E4B40A148F7730ADA4940B1321AF9BC1E4B409FAEEE586CD749407E8CB96B091B4B409FAEEE586CD74940
50564	29521	54.180807999999999	54.208224999999999	51.676442999999999	51.661740999999999	Центральная	0103000020E61000000100000005000000766D6FB724174B400FB6D8EDB3D44940766D6FB724174B40D74D29AF95D64940D49AE61DA71A4B40D74D29AF95D64940D49AE61DA71A4B400FB6D8EDB3D44940766D6FB724174B400FB6D8EDB3D44940
50522	29407	54.397463999999999	54.423327	51.908627000000003	51.88832	Советская	0103000020E610000001000000050000002EABB019E0324B40FD304278B4F149402EABB019E0324B409DA1B8E34DF44940C44142942F364B409DA1B8E34DF44940C44142942F364B40FD304278B4F149402EABB019E0324B40FD304278B4F14940
50976	48107	54.446548	54.461782999999997	52.340232	52.328190999999997	Центральная	0103000020E610000001000000050000000F0C207C28394B40B7EBA529022A4A400F0C207C28394B40BE86E0B88C2B4A40A46C91B41B3B4B40BE86E0B88C2B4A40A46C91B41B3B4B40B7EBA529022A4A400F0C207C28394B40B7EBA529022A4A40
50978	29786	54.370901000000003	54.388776999999997	52.335852000000003	52.326149999999998	Школьная	0103000020E61000000100000005000000E08618AF792F4B4092CB7F48BF294A40E08618AF792F4B40EA25C632FD2A4A40EF37DA71C3314B40EA25C632FD2A4A40EF37DA71C3314B4092CB7F48BF294A40E08618AF792F4B4092CB7F48BF294A40
50841	48366	54.604210999999999	54.616239999999998	52.273218999999997	52.266571999999996	Школьная	0103000020E6100000010000000500000015713AC9564D4B40C00303081F224A4015713AC9564D4B40AAD216D7F8224A40573ECBF3E04E4B40AAD216D7F8224A40573ECBF3E04E4B40C00303081F224A4015713AC9564D4B40C00303081F224A40
50674	30497	54.545282	54.557004999999997	52.245562999999997	52.232272000000002	Союзная	0103000020E610000001000000050000007A8CF2CCCB454B4065E3C116BB1D4A407A8CF2CCCB454B40C70DBF9B6E1F4A40AF5A99F04B474B40C70DBF9B6E1F4A40AF5A99F04B474B4065E3C116BB1D4A407A8CF2CCCB454B4065E3C116BB1D4A40
50990	47837	54.192855000000002	54.217683999999998	52.082160999999999	52.066915999999999	Школьная	0103000020E610000001000000050000005FEFFE78AF184B4021CA17B490084A405FEFFE78AF184B40DA006C40840A4A40656EBE11DD1B4B40DA006C40840A4A40656EBE11DD1B4B4021CA17B490084A405FEFFE78AF184B4021CA17B490084A40
51296	29108	54.262752999999996	54.292253000000002	52.099961	52.086499000000003	Школьная	0103000020E6100000010000000500000083F6EAE3A1214B4080113466120B4A4083F6EAE3A1214B400FF0A485CB0C4A403694DA8B68254B400FF0A485CB0C4A403694DA8B68254B4080113466120B4A4083F6EAE3A1214B4080113466120B4A40
50252	47087	51.279905999999997	51.308239	51.707155	51.68683	Молодежная	0103000020E6100000010000000500000022FAB5F5D3A34940B2F4A10BEAD7494022FAB5F5D3A34940F819170E84DA4940062D246074A74940F819170E84DA4940062D246074A74940B2F4A10BEAD7494022FAB5F5D3A34940B2F4A10BEAD74940
50509	47697	51.612884000000001	51.627006000000002	52.070841000000001	52.060780999999999	Рабочая	0103000020E61000000100000005000000EF1EA0FB72CE4940ED9BFBABC7074A40EF1EA0FB72CE4940A41B615111094A40A9328CBB41D04940A41B615111094A40A9328CBB41D04940ED9BFBABC7074A40EF1EA0FB72CE4940ED9BFBABC7074A40
51293	47277	52.234428999999999	52.246628000000001	51.761845000000001	51.751430999999997	Школьная	0103000020E61000000100000005000000F31DFCC4011E4A40AC1919E42EE04940F31DFCC4011E4A4081CF0F2384E1494092239D81911F4A4081CF0F2384E1494092239D81911F4A40AC1919E42EE04940F31DFCC4011E4A40AC1919E42EE04940
51226	27239	51.509515	51.533132000000002	51.524698000000001	51.515165000000003	Кооперативная	0103000020E6100000010000000500000025E99AC937C149409D853DEDF0C1494025E99AC937C149406823D74D29C34940BD395CAB3DC449406823D74D29C34940BD395CAB3DC449409D853DEDF0C1494025E99AC937C149409D853DEDF0C14940
50667	28232	51.689017	51.701503000000002	51.930428999999997	51.92557	Гагарина	0103000020E61000000100000005000000ABB184B531D849405114E81379F64940ABB184B531D84940FF1F274C18F74940E085ADD9CAD94940FF1F274C18F74940E085ADD9CAD949405114E81379F64940ABB184B531D849405114E81379F64940
50456	47615	51.751520999999997	51.769100999999999	52.054395999999997	52.030127999999998	Валерия Карпова	0103000020E61000000100000005000000ECA012D731E04940D158FB3BDB034A40ECA012D731E049404084B872F6064A401329CDE671E249404084B872F6064A401329CDE671E24940D158FB3BDB034A40ECA012D731E04940D158FB3BDB034A40
50565	47455	51.708303000000001	51.740516999999997	51.953674999999997	51.930534999999999	Комсомольская	0103000020E61000000100000005000000505436ACA9DA4940456458C51BF74940505436ACA9DA4940A301BC0512FA4940E690D442C9DE4940A301BC0512FA4940E690D442C9DE4940456458C51BF74940505436ACA9DA4940456458C51BF74940
50967	21961	51.879190000000001	51.917592999999997	51.942661000000001	51.923580999999999	Центральная	0103000020E61000000100000005000000317C444C89F049407E1AF7E637F64940317C444C89F049407A1B9B1DA9F84940EE04FBAF73F549407A1B9B1DA9F84940EE04FBAF73F549407E1AF7E637F64940317C444C89F049407E1AF7E637F64940
50980	21961	51.879190000000001	51.917592999999997	51.942661000000001	51.923580999999999	Первоцилинников	0103000020E61000000100000005000000317C444C89F049407E1AF7E637F64940317C444C89F049407A1B9B1DA9F84940EE04FBAF73F549407A1B9B1DA9F84940EE04FBAF73F549407E1AF7E637F64940317C444C89F049407E1AF7E637F64940
50512	47784	52.169130000000003	52.202933999999999	52.010980000000004	51.989632999999998	Школьная	0103000020E61000000100000005000000E162450DA6154A406C054D4BACFE4940E162450DA6154A407E74EACA67014A408C9FC6BDF9194A407E74EACA67014A408C9FC6BDF9194A406C054D4BACFE4940E162450DA6154A406C054D4BACFE4940
51115	56145	51.594127	51.614870000000003	51.890098999999999	51.878897000000002	 Строительная	0103000020E61000000100000005000000D655815A0CCC4940B9C667B27FF04940D655815A0CCC4940E59997C3EEF1494051A5660FB4CE4940E59997C3EEF1494051A5660FB4CE4940B9C667B27FF04940D655815A0CCC4940B9C667B27FF04940
49987	47508	51.628191999999999	51.666243999999999	51.913437999999999	51.89564	Нефтяников	0103000020E61000000100000005000000EECD6F9868D04940A67EDE54A4F24940EECD6F9868D049403A765089EBF44940FF93BF7B47D549403A765089EBF44940FF93BF7B47D54940A67EDE54A4F24940EECD6F9868D04940A67EDE54A4F24940
49856	47508	51.628191999999999	51.666243999999999	51.913437999999999	51.89564	Гагарина	0103000020E61000000100000005000000EECD6F9868D04940A67EDE54A4F24940EECD6F9868D049403A765089EBF44940FF93BF7B47D549403A765089EBF44940FF93BF7B47D54940A67EDE54A4F24940EECD6F9868D04940A67EDE54A4F24940
50319	27455	51.454835000000003	51.472189999999998	51.797027	51.784443000000003	Центральная	0103000020E61000000100000005000000C009850838BA4940BF49D3A068E44940C009850838BA4940B68311FB04E64940C6BFCFB870BC4940B68311FB04E64940C6BFCFB870BC4940BF49D3A068E44940C009850838BA4940BF49D3A068E44940
51383	56190	51.920261000000004	51.946384000000002	51.941712000000003	51.933138999999997	Рязанская	0103000020E610000001000000050000006364C91CCBF54940A2CF471971F749406364C91CCBF549401920D1048AF8494095BA641C23F949401920D1048AF8494095BA641C23F94940A2CF471971F749406364C91CCBF54940A2CF471971F74940
50644	49115	52.036413000000003	52.068339000000002	51.998966000000003	51.980159	Центральная	0103000020E610000001000000050000001B13622EA9044A40A6F0A0D975FD49401B13622EA9044A4071E82D1EDEFF49404B051555BF084A4071E82D1EDEFF49404B051555BF084A40A6F0A0D975FD49401B13622EA9044A40A6F0A0D975FD4940
50561	27535	51.223590000000002	51.249471	51.772629999999999	51.755423	Клубная	0103000020E6100000010000000500000038DBDC989E9C4940B7D26BB3B1E0494038DBDC989E9C494049F4328AE5E2494074266DAAEE9F494049F4328AE5E2494074266DAAEE9F4940B7D26BB3B1E0494038DBDC989E9C4940B7D26BB3B1E04940
50968	47594	51.529907000000001	51.545008000000003	51.857419999999998	51.848069000000002	Школьная	0103000020E61000000100000005000000F37519FED3C349402FE065868DEC4940F37519FED3C34940D97745F0BFED4940790778D2C2C54940D97745F0BFED4940790778D2C2C549402FE065868DEC4940F37519FED3C349402FE065868DEC4940
51376	56186	51.469253000000002	51.489275999999997	51.852586000000002	51.844658000000003	Степная	0103000020E610000001000000050000006346787B10BC49400327DBC01DEC49406346787B10BC49408483BD8921ED4940DD5B9198A0BE49408483BD8921ED4940DD5B9198A0BE49400327DBC01DEC49406346787B10BC49400327DBC01DEC4940
51030	47409	51.654063000000001	51.667833999999999	51.944687999999999	51.937426000000002	Набережная	0103000020E6100000010000000500000007431D56B8D34940C6353E93FDF7494007431D56B8D349403A765089EBF849401494A2957BD549403A765089EBF849401494A2957BD54940C6353E93FDF7494007431D56B8D34940C6353E93FDF74940
50537	47339	51.369745999999999	51.408994	51.944381999999997	51.932473000000002	Школьная	0103000020E61000000100000005000000D5E940D653AF494096B377465BF74940D5E940D653AF49402D776682E1F849404F2157EA59B449402D776682E1F849404F2157EA59B4494096B377465BF74940D5E940D653AF494096B377465BF74940
50850	21779	50.966662999999997	50.984872000000003	51.808309999999999	51.797851999999999	Молодежная	0103000020E610000001000000050000006AA0F99CBB7B49402B86AB0320E649406AA0F99CBB7B4940CF83BBB376E74940815F2349107E4940CF83BBB376E74940815F2349107E49402B86AB0320E649406AA0F99CBB7B49402B86AB0320E64940
50513	40384	51.473177999999997	51.497118	51.586329999999997	51.571072999999998	Ленина	0103000020E61000000100000005000000E597C11891BC4940765089EB18C94940E597C11891BC4940F35487DC0CCB494060200890A1BF4940F35487DC0CCB494060200890A1BF4940765089EB18C94940E597C11891BC4940765089EB18C94940
50966	47054	51.443973999999997	51.464194999999997	51.633268000000001	51.62482	Школьная	0103000020E610000001000000050000001C23D923D4B8494080F10C1AFACF49401C23D923D4B849403ACD02ED0ED14940BDFBE3BD6ABB49403ACD02ED0ED14940BDFBE3BD6ABB494080F10C1AFACF49401C23D923D4B8494080F10C1AFACF4940
51297	47374	51.410665000000002	51.419395999999999	51.983266	51.976686999999998	Набережная	0103000020E61000000100000005000000514EB4AB90B44940D4B6611404FD4940514EB4AB90B4494066A208A9DBFD49405F09A4C4AEB5494066A208A9DBFD49405F09A4C4AEB54940D4B6611404FD4940514EB4AB90B44940D4B6611404FD4940
50646	48174	51.622559000000003	51.636096999999999	51.556638999999997	51.550517999999997	Школьная	0103000020E610000001000000050000004D6A6803B0CF4940FEEDB25F77C649404D6A6803B0CF4940CD565EF23FC74940B70A62A06BD14940CD565EF23FC74940B70A62A06BD14940FEEDB25F77C649404D6A6803B0CF4940FEEDB25F77C64940
50670	27394	51.264786999999998	51.276671999999998	51.713579000000003	51.700636000000003	Наумова	0103000020E61000000100000005000000F6B3588AE4A149403C33C170AED94940F6B3588AE4A14940630E828E56DB494005DCF3FC69A34940630E828E56DB494005DCF3FC69A349403C33C170AED94940F6B3588AE4A149403C33C170AED94940
51299	27623	51.139606999999998	51.161095000000003	51.842526999999997	51.830880000000001	Школьная	0103000020E6100000010000000500000076A565A4DE91494043739D465AEA494076A565A4DE9149409D7FBBECD7EB49404A46CEC29E9449409D7FBBECD7EB49404A46CEC29E94494043739D465AEA494076A565A4DE91494043739D465AEA4940
51295	27783	52.04898	52.069228000000003	51.715850000000003	51.706468999999998	Центральная	0103000020E610000001000000050000003C1405FA44064A40A45181936DDA49403C1405FA44064A40BA6B09F9A0DB4940D7FB8D76DC084A40BA6B09F9A0DB4940D7FB8D76DC084A40A45181936DDA49403C1405FA44064A40A45181936DDA4940
51298	47643	51.612929000000001	51.623727000000002	52.044732000000003	52.031668000000003	Заречная	0103000020E610000001000000050000008FE21C7574CE4940352A70B20D044A408FE21C7574CE4940D78A36C7B9054A40EC504D49D6CF4940D78A36C7B9054A40EC504D49D6CF4940352A70B20D044A408FE21C7574CE4940352A70B20D044A40
51291	25574	58.706358999999999	58.725844000000002	51.196536000000002	51.188808000000002	Центральная	0103000020E610000001000000050000001D1EC2F8695A4D40919C4CDC2A9849401D1EC2F8695A4D404B3E761728994940B9FFC874E85C4D404B3E761728994940B9FFC874E85C4D40919C4CDC2A9849401D1EC2F8695A4D40919C4CDC2A984940
50848	46004	55.668149	55.688414999999999	51.746395999999997	51.736497	Школьная	0103000020E6100000010000000500000074ED0BE885D54B40124DA08845DE494074ED0BE885D54B40BFEE74E789DF4940B58993FB1DD84B40BFEE74E789DF4940B58993FB1DD84B40124DA08845DE494074ED0BE885D54B40124DA08845DE4940
49827	22071	54.847008000000002	54.890585000000002	51.891615999999999	51.874321000000002	Мира	0103000020E61000000100000005000000A6B915C26A6C4B405F9A22C0E9EF4940A6B915C26A6C4B40904B1C7920F2494072A774B0FE714B40904B1C7920F2494072A774B0FE714B405F9A22C0E9EF4940A6B915C26A6C4B405F9A22C0E9EF4940
50502	49436	55.023077999999998	55.035725999999997	51.540134000000002	51.527517000000003	Лесная	0103000020E61000000100000005000000E8A04B38F4824B40C28A53AD85C34940E8A04B38F4824B4095BA641C23C54940F6CE68AB92844B4095BA641C23C54940F6CE68AB92844B40C28A53AD85C34940E8A04B38F4824B40C28A53AD85C34940
50497	49436	55.023077999999998	55.035725999999997	51.540134000000002	51.527517000000003	Культурная	0103000020E61000000100000005000000E8A04B38F4824B40C28A53AD85C34940E8A04B38F4824B4095BA641C23C54940F6CE68AB92844B4095BA641C23C54940F6CE68AB92844B40C28A53AD85C34940E8A04B38F4824B40C28A53AD85C34940
51346	26981	55.650165000000001	55.673358999999998	51.824952000000003	51.809691000000001	Центральная	0103000020E610000001000000050000007E00529B38D34B40CA6E66F4A3E749407E00529B38D34B408962F20698E94940CFBBB1A030D64B408962F20698E94940CFBBB1A030D64B40CA6E66F4A3E749407E00529B38D34B40CA6E66F4A3E74940
49792	20738	55.357295999999998	55.376071000000003	51.732045999999997	51.712283999999997	Ленина	0103000020E61000000100000005000000ED7E15E0BBAD4B4066BB421F2CDB4940ED7E15E0BBAD4B407495EEAEB3DD4940ADFC321823B04B407495EEAEB3DD4940ADFC321823B04B4066BB421F2CDB4940ED7E15E0BBAD4B4066BB421F2CDB4940
49825	49050	55.680464999999998	55.728489000000003	51.947485999999998	51.927957999999997	Школьная	0103000020E610000001000000050000004C89247A19D74B40E107E753C7F649404C89247A19D74B407CB5A33847F94940753FA7203FDD4B407CB5A33847F94940753FA7203FDD4B40E107E753C7F649404C89247A19D74B40E107E753C7F64940
50387	49050	55.680464999999998	55.728489000000003	51.947485999999998	51.927957999999997	Мало-Элеваторная	0103000020E610000001000000050000004C89247A19D74B40E107E753C7F649404C89247A19D74B407CB5A33847F94940753FA7203FDD4B407CB5A33847F94940753FA7203FDD4B40E107E753C7F649404C89247A19D74B40E107E753C7F64940
49857	49050	55.680464999999998	55.728489000000003	51.947485999999998	51.927957999999997	8 Марта	0103000020E610000001000000050000004C89247A19D74B40E107E753C7F649404C89247A19D74B407CB5A33847F94940753FA7203FDD4B407CB5A33847F94940753FA7203FDD4B40E107E753C7F649404C89247A19D74B40E107E753C7F64940
51031	21867	54.800618999999998	54.821002	51.999043999999998	51.983981	Просторная	0103000020E6100000010000000500000032C7F2AE7A664B405471E316F3FD494032C7F2AE7A664B40ECA17DACE0FF4940ADF9F19716694B40ECA17DACE0FF4940ADF9F19716694B405471E316F3FD494032C7F2AE7A664B405471E316F3FD4940
9950	40364	54.887594	54.908614	51.746161000000001	51.730885999999998	Центральная	0103000020E610000001000000050000001B1021AE9C714B40588D25AC8DDD49401B1021AE9C714B407C46223482DF49400858AB764D744B407C46223482DF49400858AB764D744B40588D25AC8DDD49401B1021AE9C714B40588D25AC8DDD4940
51303	22959	55.080174999999997	55.100306000000003	51.502760000000002	51.491961000000003	Центральная	0103000020E61000000100000005000000787AA52C438A4B4028F4FA93F8BE4940787AA52C438A4B4055DE8E705AC04940DACBB6D3D68C4B4055DE8E705AC04940DACBB6D3D68C4B4028F4FA93F8BE4940787AA52C438A4B4028F4FA93F8BE4940
49778	15513	55.478245000000001	55.534092999999999	51.729551999999998	51.717044000000001	 Школьная	0103000020E61000000100000005000000DE3CD52137BD4B4082E50819C8DB4940DE3CD52137BD4B409E5DBEF561DD4940E202D0285DC44B409E5DBEF561DD4940E202D0285DC44B4082E50819C8DB4940DE3CD52137BD4B4082E50819C8DB4940
50441	21311	55.634911000000002	55.662678	51.762251999999997	51.747689000000001	Центральная	0103000020E61000000100000005000000726F7EC344D14B401B4AED45B4DF4940726F7EC344D14B40C1A7397991E14940ACE3F8A1D2D44B40C1A7397991E14940ACE3F8A1D2D44B401B4AED45B4DF4940726F7EC344D14B401B4AED45B4DF4940
51272	47531	54.966214000000001	55.030434999999997	51.548659000000001	51.515439999999998	Центральная	0103000020E61000000100000005000000FB777DE6AC7B4B406E861BF0F9C14940FB777DE6AC7B4B40FAD346753AC64940AED3484BE5834B40FAD346753AC64940AED3484BE5834B406E861BF0F9C14940FB777DE6AC7B4B406E861BF0F9C14940
49876	47531	54.966214000000001	55.030434999999997	51.548659000000001	51.515439999999998	Березина	0103000020E61000000100000005000000FB777DE6AC7B4B406E861BF0F9C14940FB777DE6AC7B4B40FAD346753AC64940AED3484BE5834B40FAD346753AC64940AED3484BE5834B406E861BF0F9C14940FB777DE6AC7B4B406E861BF0F9C14940
50511	47531	54.966214000000001	55.030434999999997	51.548659000000001	51.515439999999998	 Воронова	0103000020E61000000100000005000000FB777DE6AC7B4B406E861BF0F9C14940FB777DE6AC7B4B40FAD346753AC64940AED3484BE5834B40FAD346753AC64940AED3484BE5834B406E861BF0F9C14940FB777DE6AC7B4B406E861BF0F9C14940
50652	56092	55.251969000000003	55.277624000000003	51.571370000000002	51.558425	Молодежная	0103000020E610000001000000050000008C4D2B8540A04B4068226C787AC749408C4D2B8540A04B4030F5F3A622C94940D84AE82E89A34B4030F5F3A622C94940D84AE82E89A34B4068226C787AC749408C4D2B8540A04B4068226C787AC74940
49960	22547	54.776319999999998	54.827533000000003	51.740679999999998	51.703482999999999	Советская	0103000020E61000000100000005000000889D29745E634B405F251FBB0BDA4940889D29745E634B4090662C9ACEDE49402EAEF199EC694B4090662C9ACEDE49402EAEF199EC694B405F251FBB0BDA4940889D29745E634B405F251FBB0BDA4940
50562	22547	54.776319999999998	54.827533000000003	51.740679999999998	51.703482999999999	Коммунальная	0103000020E61000000100000005000000889D29745E634B405F251FBB0BDA4940889D29745E634B4090662C9ACEDE49402EAEF199EC694B4090662C9ACEDE49402EAEF199EC694B405F251FBB0BDA4940889D29745E634B405F251FBB0BDA4940
49750	22547	54.776319999999998	54.827533000000003	51.740679999999998	51.703482999999999	50 лет Октября	0103000020E61000000100000005000000889D29745E634B405F251FBB0BDA4940889D29745E634B4090662C9ACEDE49402EAEF199EC694B4090662C9ACEDE49402EAEF199EC694B405F251FBB0BDA4940889D29745E634B405F251FBB0BDA4940
49752	21125	55.351815999999999	55.386383000000002	51.774535999999998	51.757742	Куйбышева	0103000020E61000000100000005000000D21A834E08AD4B401F679AB0FDE04940D21A834E08AD4B408EC9E2FE23E349407D5D86FF74B14B408EC9E2FE23E349407D5D86FF74B14B401F679AB0FDE04940D21A834E08AD4B401F679AB0FDE04940
51010	21475	55.873100000000001	55.887112999999999	51.785936	51.769486000000001	Школьная	0103000020E610000001000000050000009D11A5BDC1EF4B406C5D6A847EE249409D11A5BDC1EF4B40E15F048D99E44940A06D35EB8CF14B40E15F048D99E44940A06D35EB8CF14B406C5D6A847EE249409D11A5BDC1EF4B406C5D6A847EE24940
49872	20635	55.620016999999997	55.658735	51.708880000000001	51.689453999999998	Советская	0103000020E6100000010000000500000065FB90B75CCF4B40560C570740D8494065FB90B75CCF4B40ED647094BCDA494083DDB06D51D44B40ED647094BCDA494083DDB06D51D44B40560C570740D8494065FB90B75CCF4B40560C570740D84940
51290	21247	55.553829	55.575263	51.781734999999998	51.767892000000003	Центральная	0103000020E61000000100000005000000C74961DEE3C64B40166EF9484AE24940C74961DEE3C64B40BC9179E40FE44940A7CCCD37A2C94B40BC9179E40FE44940A7CCCD37A2C94B40166EF9484AE24940C74961DEE3C64B40166EF9484AE24940
51025	20960	55.474328	55.489303	51.515366999999998	51.502972999999997	Прудная	0103000020E61000000100000005000000DEC9A7C7B6BC4B40B0E2546B61C04940DEC9A7C7B6BC4B400438BD8BF7C14940D76A0F7BA1BE4B400438BD8BF7C14940D76A0F7BA1BE4B40B0E2546B61C04940DEC9A7C7B6BC4B40B0E2546B61C04940
49753	22687	54.599639000000003	54.643737000000002	51.695076	51.673645	Рабочая	0103000020E61000000100000005000000FD3383F8C04C4B40950ED6FF39D64940FD3383F8C04C4B40041E1840F8D84940D21C59F965524B40041E1840F8D84940D21C59F965524B40950ED6FF39D64940FD3383F8C04C4B40950ED6FF39D64940
49946	56047	54.361207999999998	54.409412000000003	51.649124999999998	51.626677000000001	Больничная	0103000020E61000000100000005000000DB8651103C2E4B40E413B2F336D04940DB8651103C2E4B400C022B8716D34940844BC79C67344B400C022B8716D34940844BC79C67344B40E413B2F336D04940DB8651103C2E4B40E413B2F336D04940
50526	48321	54.904105000000001	54.922367999999999	51.916609999999999	51.899203	переулок Тупой	0103000020E6100000010000000500000036936FB6B9734B4088BB7A1519F3494036936FB6B9734B40E197FA7953F549403F70952710764B40E197FA7953F549403F70952710764B4088BB7A1519F3494036936FB6B9734B4088BB7A1519F34940
51002	48981	55.779997999999999	55.803623999999999	51.711905000000002	51.701400999999997	Новая	0103000020E61000000100000005000000037976F9D6E34B40DB300A82C7D94940037976F9D6E34B40F06DFAB31FDB4940EE23B726DDE64B40F06DFAB31FDB4940EE23B726DDE64B40DB300A82C7D94940037976F9D6E34B40DB300A82C7D94940
50838	21661	55.553946000000003	55.573709000000001	51.899813999999999	51.885980000000004	Молодежная	0103000020E6100000010000000500000001E0D8B3E7C64B407E74EACA67F1494001E0D8B3E7C64B40D13DEB1A2DF34940DF35E84B6FC94B40D13DEB1A2DF34940DF35E84B6FC94B407E74EACA67F1494001E0D8B3E7C64B407E74EACA67F14940
50218	22162	54.643619999999999	54.681727000000002	51.958736999999999	51.946308999999999	переулок Школьный	0103000020E610000001000000050000009886E12362524B408A743FA720F949409886E12362524B408A3BDEE4B7FA49406DE690D442574B408A3BDEE4B7FA49406DE690D442574B408A743FA720F949409886E12362524B408A743FA720F94940
50557	20778	55.311599000000001	55.336472999999998	51.720844	51.709705999999997	Центральная	0103000020E61000000100000005000000B03BDD79E2A74B4032E36DA5D7DA4940B03BDD79E2A74B4048C2BE9D44DC4940567E198C11AB4B4048C2BE9D44DC4940567E198C11AB4B4032E36DA5D7DA4940B03BDD79E2A74B4032E36DA5D7DA4940
51288	48719	55.719658000000003	55.758339999999997	51.676085999999998	51.663747000000001	Береговая	0103000020E610000001000000050000000327DBC01DDC4B40B8E864A9F5D449400327DBC01DDC4B4048A46DFC89D64940D39FFD4811E14B4048A46DFC89D64940D39FFD4811E14B40B8E864A9F5D449400327DBC01DDC4B40B8E864A9F5D44940
51022	21683	55.759121	55.773170999999998	51.855885000000001	51.846527999999999	Молодежная	0103000020E61000000100000005000000795A7EE02AE14B40FB928D075BEC4940795A7EE02AE14B408811C2A38DED4940999B6F44F7E24B408811C2A38DED4940999B6F44F7E24B40FB928D075BEC4940795A7EE02AE14B40FB928D075BEC4940
64124	58173	58.411667000000001	58.709969999999998	51.301600000000001	51.160229000000001	Новосибирская	0103000020E61000000100000005000000D5EB1681B1344D40766F456282944940D5EB1681B1344D409F3C2CD49AA649401092054CE05A4D409F3C2CD49AA649401092054CE05A4D40766F456282944940D5EB1681B1344D40766F456282944940
50803	12520	55.129365999999997	55.140883000000002	52.358275999999996	52.348588999999997	Гагарина	0103000020E610000001000000050000006F9BA9108F904B40675F79909E2C4A406F9BA9108F904B408978EBFCDB2D4A40FCC7427408924B408978EBFCDB2D4A40FCC7427408924B40675F79909E2C4A406F9BA9108F904B40675F79909E2C4A40
51163	45447	54.954473	54.974784	52.536504000000001	52.519058999999999	Советская	0103000020E610000001000000050000001FF5D72B2C7A4B40E4D87A8670424A401FF5D72B2C7A4B402B16BF29AC444A400055DCB8C57C4B402B16BF29AC444A400055DCB8C57C4B40E4D87A8670424A401FF5D72B2C7A4B40E4D87A8670424A40
50499	12698	54.907321000000003	54.951310999999997	52.230986999999999	52.208443000000003	Больничная	0103000020E61000000100000005000000ADFC321823744B40420A9E42AE1A4A40ADFC321823744B408C6665FB901D4A409BA9108FC4794B408C6665FB901D4A409BA9108FC4794B40420A9E42AE1A4A40ADFC321823744B40420A9E42AE1A4A40
50961	11759	55.290937	55.296947000000003	52.207178999999996	52.202565	Набережная	0103000020E610000001000000050000002219726C3DA54B40392861A6ED194A402219726C3DA54B4080B56AD7841A4A409AD2FA5B02A64B4080B56AD7841A4A409AD2FA5B02A64B40392861A6ED194A402219726C3DA54B40392861A6ED194A40
50417	45457	54.972754000000002	54.995823000000001	52.416262000000003	52.398611000000002	переулок Солнечный	0103000020E61000000100000005000000CF86FC33837C4B40B6696CAF05334A40CF86FC33837C4B40A648BE1248354A4064CDC820777F4B40A648BE1248354A4064CDC820777F4B40B6696CAF05334A40CF86FC33837C4B40B6696CAF05334A40
50964	12656	54.89911	54.917803999999997	52.263556999999999	52.248381000000002	Придорожная	0103000020E61000000100000005000000D7C0560916734B4051F9D7F2CA1F4A40D7C0560916734B40E1D05B3CBC214A40A911FA997A754B40E1D05B3CBC214A40A911FA997A754B4051F9D7F2CA1F4A40D7C0560916734B4051F9D7F2CA1F4A40
9698	40277	54.657913000000001	55.892431000000002	52.675196999999997	52.103900000000003	Ленина	0103000020E610000001000000050000007F4E417E36544B40F7065F984C0D4A407F4E417E36544B40BCADF4DA6C564A40E277D32D3BF24B40BCADF4DA6C564A40E277D32D3BF24B40F7065F984C0D4A407F4E417E36544B40F7065F984C0D4A40
50318	46406	55.468677999999997	55.522379000000001	52.363720000000001	52.336765999999997	Центральный	0103000020E61000000100000005000000662D05A4FDBB4B40CE33F6251B2B4A40662D05A4FDBB4B40587380608E2E4A40008FA850DDC24B40587380608E2E4A40008FA850DDC24B40CE33F6251B2B4A40662D05A4FDBB4B40CE33F6251B2B4A40
50863	46406	55.468677999999997	55.522379000000001	52.363720000000001	52.336765999999997	Молодежная	0103000020E61000000100000005000000662D05A4FDBB4B40CE33F6251B2B4A40662D05A4FDBB4B40587380608E2E4A40008FA850DDC24B40587380608E2E4A40008FA850DDC24B40CE33F6251B2B4A40662D05A4FDBB4B40CE33F6251B2B4A40
50538	46406	55.468677999999997	55.522379000000001	52.363720000000001	52.336765999999997	Луначарского	0103000020E61000000100000005000000662D05A4FDBB4B40CE33F6251B2B4A40662D05A4FDBB4B40587380608E2E4A40008FA850DDC24B40587380608E2E4A40008FA850DDC24B40CE33F6251B2B4A40662D05A4FDBB4B40CE33F6251B2B4A40
50418	46406	55.468677999999997	55.522379000000001	52.363720000000001	52.336765999999997	Дедовская	0103000020E61000000100000005000000662D05A4FDBB4B40CE33F6251B2B4A40662D05A4FDBB4B40587380608E2E4A40008FA850DDC24B40587380608E2E4A40008FA850DDC24B40CE33F6251B2B4A40662D05A4FDBB4B40CE33F6251B2B4A40
51151	49546	55.296255000000002	55.322719999999997	52.382947000000001	52.356020999999998	Луговая	0103000020E61000000100000005000000642310AFEBA54B4038D89B18922D4A40642310AFEBA54B40F88C446804314A40EFE192E34EA94B40F88C446804314A40EFE192E34EA94B4038D89B18922D4A40642310AFEBA54B4038D89B18922D4A40
50314	9273	55.560540000000003	55.583751999999997	52.374250000000004	52.355443000000001	Школьная	0103000020E61000000100000005000000C80C54C6BFC74B40CB4BFE277F2D4A40C80C54C6BFC74B4096438B6CE72F4A40BF7CB262B8CA4B4096438B6CE72F4A40BF7CB262B8CA4B40CB4BFE277F2D4A40C80C54C6BFC74B40CB4BFE277F2D4A40
51016	11286	55.337209999999999	55.352696999999999	52.283473000000001	52.271768999999999	Новобиккуловская	0103000020E610000001000000050000002CF180B229AB4B4087889B53C9224A402CF180B229AB4B404626E0D748244A40DB32E02C25AD4B404626E0D748244A40DB32E02C25AD4B4087889B53C9224A402CF180B229AB4B4087889B53C9224A40
50498	11976	55.418525000000002	55.439438000000003	52.487056000000003	52.449052999999999	 Центральная	0103000020E610000001000000050000007AC7293A92B54B40D99596917A394A407AC7293A92B54B4009A9DBD9573E4A40514F1F813FB84B4009A9DBD9573E4A40514F1F813FB84B40D99596917A394A407AC7293A92B54B40D99596917A394A40
50958	9640	55.372521999999996	55.381639999999997	52.416482000000002	52.402825	Школьная	0103000020E610000001000000050000002F8507CDAEAF4B406F8104C58F334A402F8507CDAEAF4B40B4AF3C484F354A40376C5B94D9B04B40B4AF3C484F354A40376C5B94D9B04B406F8104C58F334A402F8507CDAEAF4B406F8104C58F334A40
50328	56065	55.264454999999998	55.290999999999997	52.255597999999999	52.232118	Школьная	0103000020E61000000100000005000000C02154A9D9A14B400E68E90AB61D4A40C02154A9D9A14B4025766D6FB7204A406891ED7C3FA54B4025766D6FB7204A406891ED7C3FA54B400E68E90AB61D4A40C02154A9D9A14B400E68E90AB61D4A40
50963	56133	55.403962999999997	55.436033000000002	52.661811999999998	52.644581000000002	Школьная	0103000020E61000000100000005000000A3E5400FB5B34B40BE4F55A181524A40A3E5400FB5B34B40D80C7041B6544A40077DE9EDCFB74B40D80C7041B6544A40077DE9EDCFB74B40BE4F55A181524A40A3E5400FB5B34B40BE4F55A181524A40
50304	49388	55.526772000000001	55.540560999999997	52.338917000000002	52.326594999999998	Интернатская	0103000020E610000001000000050000006939D0436DC34B40C0046EDDCD294A406939D0436DC34B407B87DBA1612B4A401C3F541A31C54B407B87DBA1612B4A401C3F541A31C54B40C0046EDDCD294A406939D0436DC34B40C0046EDDCD294A40
51287	45509	54.803556	54.831108	52.293846000000002	52.281075999999999	Центральная	0103000020E6100000010000000500000096404AECDA664B4062D8614CFA234A4096404AECDA664B40BC07E8BE9C254A40D4B837BF616A4B40BC07E8BE9C254A40D4B837BF616A4B4062D8614CFA234A4096404AECDA664B4062D8614CFA234A40
50794	49521	55.200270000000003	55.235672999999998	52.308053999999998	52.297376	Центральная	0103000020E610000001000000050000005A2F8672A2994B40C24EB16A10264A405A2F8672A2994B4074B33F506E274A406DC669882A9E4B4074B33F506E274A406DC669882A9E4B40C24EB16A10264A405A2F8672A2994B40C24EB16A10264A40
64220	49521	55.200270000000003	55.235672999999998	52.308053999999998	52.297376	Садовая	0103000020E610000001000000050000005A2F8672A2994B40C24EB16A10264A405A2F8672A2994B4074B33F506E274A406DC669882A9E4B4074B33F506E274A406DC669882A9E4B40C24EB16A10264A405A2F8672A2994B40C24EB16A10264A40
50610	11630	55.308157999999999	55.325657	52.217471000000003	52.204695999999998	Школьная	0103000020E610000001000000050000001900AAB871A74B409ECF807A331A4A401900AAB871A74B400A6AF816D61B4A40535BEA20AFA94B400A6AF816D61B4A40535BEA20AFA94B409ECF807A331A4A401900AAB871A74B409ECF807A331A4A40
50791	11699	55.308157999999999	55.325657	52.217471000000003	52.204695999999998	Центральная	0103000020E610000001000000050000001900AAB871A74B409ECF807A331A4A401900AAB871A74B400A6AF816D61B4A40535BEA20AFA94B400A6AF816D61B4A40535BEA20AFA94B409ECF807A331A4A401900AAB871A74B409ECF807A331A4A40
50970	49409	55.6798	55.703344999999999	52.263821999999998	52.258243999999998	Центральная	0103000020E6100000010000000500000010E9B7AF03D74B40B131AF230E214A4010E9B7AF03D74B408FFB56EBC4214A400E677E3507DA4B408FFB56EBC4214A400E677E3507DA4B40B131AF230E214A4010E9B7AF03D74B40B131AF230E214A40
51186	23946	55.549543999999997	55.577939999999998	52.226033000000001	52.216344999999997	Майская	0103000020E6100000010000000500000044DB317557C64B4099D36531B11B4A4044DB317557C64B408C683BA6EE1C4A406E861BF0F9C94B408C683BA6EE1C4A406E861BF0F9C94B4099D36531B11B4A4044DB317557C64B4099D36531B11B4A40
50792	12098	55.362309000000003	55.381478999999999	52.567250000000001	52.555796999999998	Центральная	0103000020E61000000100000005000000F3052D2460AE4B40821B295B24474A40F3052D2460AE4B40F853E3A59B484A402E8ECA4DD4B04B40F853E3A59B484A402E8ECA4DD4B04B40821B295B24474A40F3052D2460AE4B40821B295B24474A40
50614	45492	54.972368000000003	54.998167000000002	52.335543999999999	52.306573	Школьная	0103000020E61000000100000005000000A6D6FB8D767C4B40166BB8C83D274A40A6D6FB8D767C4B403C2F151BF32A4A402579AEEFC37F4B403C2F151BF32A4A402579AEEFC37F4B40166BB8C83D274A40A6D6FB8D767C4B40166BB8C83D274A40
49916	45420	55.142257000000001	55.179797999999998	52.465998999999996	52.441724999999998	Гагарина	0103000020E610000001000000050000004450357A35924B40AD69DE718A384A404450357A35924B40FE7BF0DAA53B4A406FF1F09E03974B40FE7BF0DAA53B4A406FF1F09E03974B40AD69DE718A384A404450357A35924B40AD69DE718A384A40
50962	49440	55.405050000000003	55.433706999999998	52.196207000000001	52.182535999999999	Новая	0103000020E61000000100000005000000569FABADD8B34B40DC2BF3565D174A40569FABADD8B34B40861F9C4F1D194A40EC8502B683B74B40861F9C4F1D194A40EC8502B683B74B40DC2BF3565D174A40569FABADD8B34B40DC2BF3565D174A40
51018	49525	55.299211	55.321165999999998	52.324751999999997	52.311340999999999	Школьная	0103000020E610000001000000050000003ECDC98B4CA64B40B4739A05DA274A403ECDC98B4CA64B40C1A7397991294A40274BADF71BA94B40C1A7397991294A40274BADF71BA94B40B4739A05DA274A403ECDC98B4CA64B40B4739A05DA274A40
51284	45424	55.069943000000002	55.099237000000002	52.533639000000001	52.504792999999999	Школьная	0103000020E61000000100000005000000C5CA68E4F3884B40F71F990E9D404A40C5CA68E4F3884B40616F62484E444A40CEC64ACCB38C4B40616F62484E444A40CEC64ACCB38C4B40F71F990E9D404A40C5CA68E4F3884B40F71F990E9D404A40
50965	12779	55.334451999999999	55.346452999999997	52.153343	52.138244999999998	Центральная	0103000020E61000000100000005000000780AB952CFAA4B40F2EA1C03B2114A40780AB952CFAA4B40070951BEA0134A40F04C689258AC4B40070951BEA0134A40F04C689258AC4B40F2EA1C03B2114A40780AB952CFAA4B40F2EA1C03B2114A40
49838	48493	54.011277999999997	54.053804999999997	52.584659000000002	52.562131999999998	Парковая	0103000020E610000001000000050000000795B88E71014B407D04FEF0F3474A400795B88E71014B40F2272A1BD64A4A403EAE0D15E3064B40F2272A1BD64A4A403EAE0D15E3064B407D04FEF0F3474A400795B88E71014B407D04FEF0F3474A40
51276	47849	53.596004999999998	53.615777000000001	51.961939000000001	51.946508999999999	Пушкина	0103000020E6100000010000000500000051A04FE449CC4A40512FF83427F9494051A04FE449CC4A409CDF30D120FB49408350DEC7D1CE4A409CDF30D120FB49408350DEC7D1CE4A40512FF83427F9494051A04FE449CC4A40512FF83427F94940
50793	8859	53.963586999999997	53.980933	52.461060000000003	52.453498000000003	Лесная	0103000020E61000000100000005000000E5EC9DD156FB4A409566F3380C3A4A40E5EC9DD156FB4A4034BF9A03043B4A40994869368FFD4A4034BF9A03043B4A40994869368FFD4A409566F3380C3A4A40E5EC9DD156FB4A409566F3380C3A4A40
50297	9327	53.797578000000001	53.81682	52.132474000000002	52.122200999999997	Советская	0103000020E610000001000000050000002A01310917E64A40ED444948A40F4A402A01310917E64A4000C974E8F4104A40FF5BC98E8DE84A4000C974E8F4104A40FF5BC98E8DE84A40ED444948A40F4A402A01310917E64A40ED444948A40F4A40
50515	8552	54.062581000000002	54.098756000000002	52.342840000000002	52.328395	Советская	0103000020E61000000100000005000000ED2C7AA702084B40C095ECD8082A4A40ED2C7AA702084B405DE15D2EE22B4A4053245F09A40C4B405DE15D2EE22B4A4053245F09A40C4B40C095ECD8082A4A40ED2C7AA702084B40C095ECD8082A4A40
50295	47900	53.227497999999997	53.253945000000002	52.100039000000002	52.078502	Кооперативная	0103000020E61000000100000005000000E4F38AA71E9D4A40D655815A0C0A4A40E4F38AA71E9D4A408BA9F413CE0C4A40CAFD0E4581A04A408BA9F413CE0C4A40CAFD0E4581A04A40D655815A0C0A4A40E4F38AA71E9D4A40D655815A0C0A4A40
50553	8921	53.949789000000003	53.973522000000003	52.404555999999999	52.39228	Школьная	0103000020E61000000100000005000000DF8C9AAF92F94A40FC6F253B36324A40DF8C9AAF92F94A4046B3B27DC8334A40E0F76F5E9CFC4A4046B3B27DC8334A40E0F76F5E9CFC4A40FC6F253B36324A40DF8C9AAF92F94A40FC6F253B36324A40
50300	7872	53.950876000000001	53.977223000000002	51.865290999999999	51.843668000000001	Чапаева	0103000020E610000001000000050000009146054EB6F94A4043572250FDEB49409146054EB6F94A40F64201DBC1EE494013F3ACA415FD4A40F64201DBC1EE494013F3ACA415FD4A4043572250FDEB49409146054EB6F94A4043572250FDEB4940
51337	56165	53.524652000000003	53.532539	52.178356000000001	52.170994	Луговая	0103000020E61000000100000005000000F8E3F6CB27C34A40F7E7A221E3154A40F8E3F6CB27C34A40CF85915ED4164A401A6CEA3C2AC44A40CF85915ED4164A401A6CEA3C2AC44A40F7E7A221E3154A40F8E3F6CB27C34A40F7E7A221E3154A40
50952	48047	53.484309000000003	53.509830000000001	51.839827999999997	51.827807	Центральная	0103000020E6100000010000000500000049145AD6FDBD4A402F336C94F5E9494049145AD6FDBD4A40EE21E17B7FEB49408542041C42C14A40EE21E17B7FEB49408542041C42C14A402F336C94F5E9494049145AD6FDBD4A402F336C94F5E94940
51399	56198	54.206904000000002	54.217306999999998	52.321190000000001	52.314374999999998	Советская	0103000020E61000000100000005000000AFB48CD47B1A4B400AD7A3703D284A40AFB48CD47B1A4B40B0E600C11C294A408F183DB7D01B4B40B0E600C11C294A408F183DB7D01B4B400AD7A3703D284A40AFB48CD47B1A4B400AD7A3703D284A40
50973	48507	53.829009999999997	53.841973000000003	52.627595999999997	52.620171999999997	Заречная	0103000020E610000001000000050000004A07EBFF1CEA4A408CF2CCCB614F4A404A07EBFF1CEA4A40DA8CD31055504A40B98E71C5C5EB4A40DA8CD31055504A40B98E71C5C5EB4A408CF2CCCB614F4A404A07EBFF1CEA4A408CF2CCCB614F4A40
50507	56075	53.849321000000003	53.894038999999999	51.999482	51.977829999999997	Красноармейская	0103000020E610000001000000050000002C67EF8CB6EC4A401A868F8829FD49402C67EF8CB6EC4A406878B306EFFF49409D2CB5DE6FF24A406878B306EFFF49409D2CB5DE6FF24A401A868F8829FD49402C67EF8CB6EC4A401A868F8829FD4940
50506	56075	53.849321000000003	53.894038999999999	51.999482	51.977829999999997	Кооперативная	0103000020E610000001000000050000002C67EF8CB6EC4A401A868F8829FD49402C67EF8CB6EC4A406878B306EFFF49409D2CB5DE6FF24A406878B306EFFF49409D2CB5DE6FF24A401A868F8829FD49402C67EF8CB6EC4A401A868F8829FD4940
50486	8131	53.889448999999999	53.920377999999999	51.980575000000002	51.965257000000001	Совхозная	0103000020E61000000100000005000000DE3AFF76D9F14A40179E978A8DFB4940DE3AFF76D9F14A403A234A7B83FD49409CFA40F2CEF54A403A234A7B83FD49409CFA40F2CEF54A40179E978A8DFB4940DE3AFF76D9F14A40179E978A8DFB4940
49836	6849	53.62838	53.678218999999999	52.113396999999999	52.059607	Проспект Калинина	0103000020E61000000100000005000000F1BA7EC16ED04A406CCEC133A1074A40F1BA7EC16ED04A40753BFBCA830E4A404E4354E1CFD64A40753BFBCA830E4A404E4354E1CFD64A406CCEC133A1074A40F1BA7EC16ED04A406CCEC133A1074A40
50034	6849	53.62838	53.678218999999999	52.113396999999999	52.059607	Мичурина	0103000020E61000000100000005000000F1BA7EC16ED04A406CCEC133A1074A40F1BA7EC16ED04A40753BFBCA830E4A404E4354E1CFD64A40753BFBCA830E4A404E4354E1CFD64A406CCEC133A1074A40F1BA7EC16ED04A406CCEC133A1074A40
50028	6849	53.62838	53.678218999999999	52.113396999999999	52.059607	Маяковского	0103000020E61000000100000005000000F1BA7EC16ED04A406CCEC133A1074A40F1BA7EC16ED04A40753BFBCA830E4A404E4354E1CFD64A40753BFBCA830E4A404E4354E1CFD64A406CCEC133A1074A40F1BA7EC16ED04A406CCEC133A1074A40
50032	6849	53.62838	53.678218999999999	52.113396999999999	52.059607	Красногвардейская	0103000020E61000000100000005000000F1BA7EC16ED04A406CCEC133A1074A40F1BA7EC16ED04A40753BFBCA830E4A404E4354E1CFD64A40753BFBCA830E4A404E4354E1CFD64A406CCEC133A1074A40F1BA7EC16ED04A406CCEC133A1074A40
49837	6849	53.62838	53.678218999999999	52.113396999999999	52.059607	Карла Маркса	0103000020E61000000100000005000000F1BA7EC16ED04A406CCEC133A1074A40F1BA7EC16ED04A40753BFBCA830E4A404E4354E1CFD64A40753BFBCA830E4A404E4354E1CFD64A406CCEC133A1074A40F1BA7EC16ED04A406CCEC133A1074A40
49923	6849	53.62838	53.678218999999999	52.113396999999999	52.059607	Горького	0103000020E61000000100000005000000F1BA7EC16ED04A406CCEC133A1074A40F1BA7EC16ED04A40753BFBCA830E4A404E4354E1CFD64A40753BFBCA830E4A404E4354E1CFD64A406CCEC133A1074A40F1BA7EC16ED04A406CCEC133A1074A40
50786	7387	53.276690000000002	53.298195999999997	51.955061999999998	51.945343000000001	 Дружбы	0103000020E61000000100000005000000AC90F2936AA34A405340DAFF00F94940AC90F2936AA34A4080D3BB783FFA494025E659492BA64A4080D3BB783FFA494025E659492BA64A405340DAFF00F94940AC90F2936AA34A405340DAFF00F94940
51285	7429	53.386814000000001	53.400109999999998	52.006179000000003	51.988241000000002	переулок Тупой	0103000020E6100000010000000500000046D1031F83B14A407EC85BAE7EFE494046D1031F83B14A4004763579CA004A40BA66F2CD36B34A4004763579CA004A40BA66F2CD36B34A407EC85BAE7EFE494046D1031F83B14A407EC85BAE7EFE4940
50959	8465	54.140582000000002	54.150868000000003	52.345613	52.340418999999997	Центральная	0103000020E6100000010000000500000001344A97FE114B40F0F78BD9922B4A4001344A97FE114B404609FA0B3D2C4A40A80183A44F134B404609FA0B3D2C4A40A80183A44F134B40F0F78BD9922B4A4001344A97FE114B40F0F78BD9922B4A40
50613	48614	53.687615000000001	53.727510000000002	52.438535000000002	52.421743999999997	Грейдерная	0103000020E61000000100000005000000999EB0C403D84A4061A417B5FB354A40999EB0C403D84A40609335EA21384A40A9C1340C1FDD4A40609335EA21384A40A9C1340C1FDD4A4061A417B5FB354A40999EB0C403D84A4061A417B5FB354A40
50290	7603	53.370680999999998	53.419674999999998	51.81664	51.800831000000002	Школьная	0103000020E61000000100000005000000D11F9A7972AF4A40BE4F55A181E64940D11F9A7972AF4A407F4DD6A887E8494072F90FE9B7B54A407F4DD6A887E8494072F90FE9B7B54A40BE4F55A181E64940D11F9A7972AF4A40BE4F55A181E64940
51097	48351	54.035578000000001	54.053679000000002	52.153740999999997	52.145645000000002	Центральная	0103000020E61000000100000005000000823AE5D18D044B40B8E9CF7EA4124A40823AE5D18D044B40F486FBC8AD134A40B2BD16F4DE064B40F486FBC8AD134A40B2BD16F4DE064B40B8E9CF7EA4124A40823AE5D18D044B40B8E9CF7EA4124A40
50790	48710	53.793678999999997	53.807108999999997	52.161580999999998	52.157465000000002	Речная	0103000020E61000000100000005000000D042024697E54A40E0A128D027144A40D042024697E54A40D653ABAFAE144A4054A703594FE74A40D653ABAFAE144A4054A703594FE74A40E0A128D027144A40D042024697E54A40E0A128D027144A40
51274	7105	53.578766000000002	53.590705	52.030997999999997	52.024005000000002	Советская	0103000020E61000000100000005000000B404190115CA4A4062F8889812034A40B404190115CA4A40E61E12BEF7034A40B64AB0389CCB4A40E61E12BEF7034A40B64AB0389CCB4A4062F8889812034A40B404190115CA4A4062F8889812034A40
51190	7497	53.476457000000003	53.502203000000002	51.975194000000002	51.961312	Правительственная	0103000020E61000000100000005000000A379008BFCBC4A404DA088450CFB4940A379008BFCBC4A40B2A03028D3FC4940FF791A3048C04A40B2A03028D3FC4940FF791A3048C04A404DA088450CFB4940A379008BFCBC4A404DA088450CFB4940
51412	56204	53.958950999999999	53.976298	52.601776000000001	52.591334000000003	Степная	0103000020E61000000100000005000000B6BB07E8BEFA4A40A6811FD5B04B4A40B6BB07E8BEFA4A4044C2F7FE064D4A403A933655F7FC4A4044C2F7FE064D4A403A933655F7FC4A40A6811FD5B04B4A40B6BB07E8BEFA4A40A6811FD5B04B4A40
50478	7744	53.620736000000001	53.662292000000001	51.897140999999998	51.862560000000002	Центральная	0103000020E6100000010000000500000095B9F94674CF4A403C6BB75D68EE494095B9F94674CF4A404B732B84D5F249408333F8FBC5D44A404B732B84D5F249408333F8FBC5D44A403C6BB75D68EE494095B9F94674CF4A403C6BB75D68EE4940
51292	48331	53.889754000000003	53.913066000000001	52.163851999999999	52.149065999999998	переулок Клубный	0103000020E610000001000000050000001BBE8575E3F14A4007793D9814134A401BBE8575E3F14A402DB1321AF9144A40768BC058DFF44A402DB1321AF9144A40768BC058DFF44A4007793D9814134A401BBE8575E3F14A4007793D9814134A40
51168	56152	53.604782	53.630077999999997	52.219948000000002	52.207923999999998	Садовая	0103000020E61000000100000005000000D09A1F7F69CD4A40D906EE409D1A4A40D09A1F7F69CD4A400A698D41271C4A40ECF65965A6D04A400A698D41271C4A40ECF65965A6D04A40D906EE409D1A4A40D09A1F7F69CD4A40D906EE409D1A4A40
50822	47033	53.800561000000002	53.820943	52.017504000000002	52.006323000000002	Новая	0103000020E61000000100000005000000FEB968C878E64A40371B2B31CF004A40FEB968C878E64A404CC631923D024A40A87004A914E94A404CC631923D024A40A87004A914E94A40371B2B31CF004A40FEB968C878E64A40371B2B31CF004A40
50872	48940	53.656309	53.671598000000003	52.474699000000001	52.463918999999997	Центральная	0103000020E610000001000000050000000589EDEE01D44A401B7FA2B2613B4A400589EDEE01D44A40D238D4EFC23C4A408E075BECF6D54A40D238D4EFC23C4A408E075BECF6D54A401B7FA2B2613B4A400589EDEE01D44A401B7FA2B2613B4A40
50788	8638	54.032245000000003	54.050767999999998	52.354761000000003	52.345272000000001	Мира	0103000020E61000000100000005000000D23AAA9A20044B40BD1C76DF312C4A40D23AAA9A20044B40B972F6CE682D4A4077D7D9907F064B40B972F6CE682D4A4077D7D9907F064B40BD1C76DF312C4A40D23AAA9A20044B40BD1C76DF312C4A40
51150	56149	53.309272	53.336472999999998	51.811540000000001	51.791027999999997	Школьная	0103000020E61000000100000005000000C5C8923996A74A40321CCF6740E54940C5C8923996A74A40ABB2EF8AE0E74940567E198C11AB4A40ABB2EF8AE0E74940567E198C11AB4A40321CCF6740E54940C5C8923996A74A40321CCF6740E54940
50785	7043	53.713935999999997	53.736941999999999	52.044227999999997	52.033906999999999	Советская	0103000020E61000000100000005000000F1B73D4162DB4A40800D881057044A40F1B73D4162DB4A40A3C85A43A9054A4040868E1D54DE4A40A3C85A43A9054A4040868E1D54DE4A40800D881057044A40F1B73D4162DB4A40800D881057044A40
51281	48077	53.676377000000002	53.695825999999997	51.913876999999999	51.902375999999997	Солнечная	0103000020E610000001000000050000002062838593D64A40FF58880E81F349402062838593D64A4086C8E9EBF9F449406EDA8CD310D94A4086C8E9EBF9F449406EDA8CD310D94A40FF58880E81F349402062838593D64A40FF58880E81F34940
50956	9047	53.913173	53.925632999999998	52.388345000000001	52.379885000000002	Школьная	0103000020E610000001000000050000008C4B55DAE2F44A40D89E5912A0304A408C4B55DAE2F44A405648F949B5314A40978C63247BF64A405648F949B5314A40978C63247BF64A40D89E5912A0304A408C4B55DAE2F44A40D89E5912A0304A40
81113	62082	54.056058999999998	54.069175000000001	52.149000000000001	52.143031000000001	Школьная	0103000020E61000000100000005000000BFD2F9F02C074B4037A8FDD64E124A40BFD2F9F02C074B40508D976E12134A40B459F5B9DA084B40508D976E12134A40B459F5B9DA084B4037A8FDD64E124A40BFD2F9F02C074B4037A8FDD64E124A40
50303	47993	53.262478999999999	53.295034000000001	51.787736000000002	51.776831999999999	Победы	0103000020E61000000100000005000000827170E998A14A403E3E213B6FE34940827170E998A14A40E1F08288D4E44940A29A92ACC3A54A40E1F08288D4E44940A29A92ACC3A54A403E3E213B6FE34940827170E998A14A403E3E213B6FE34940
51279	7833	53.794147000000002	53.826082	51.802568999999998	51.790660000000003	Ленина	0103000020E61000000100000005000000B79BE09BA6E54A40B020CD5834E54940B79BE09BA6E54A4047E4BB94BAE649403AE8120EBDE94A4047E4BB94BAE649403AE8120EBDE94A40B020CD5834E54940B79BE09BA6E54A40B020CD5834E54940
51282	8169	53.967899000000003	53.993113999999998	51.954690999999997	51.940035000000002	Луговая	0103000020E61000000100000005000000626A4B1DE4FB4A40350C1F1153F84940626A4B1DE4FB4A408C648F5033FA494091990B5C1EFF4A408C648F5033FA494091990B5C1EFF4A40350C1F1153F84940626A4B1DE4FB4A40350C1F1153F84940
50784	47933	53.264940000000003	53.277732	52.016013000000001	52.006838999999999	Центральная	0103000020E610000001000000050000007DB3CD8DE9A14A402EABB019E0004A407DB3CD8DE9A14A40CAA7C7B60C024A40BE86E0B88CA34A40CAA7C7B60C024A40BE86E0B88CA34A402EABB019E0004A407DB3CD8DE9A14A402EABB019E0004A40
50957	8907	54.091731000000003	54.104937	52.457569999999997	52.452005999999997	Старая	0103000020E61000000100000005000000C38366D7BD0B4B4042CC2555DB394A40C38366D7BD0B4B40BBD05CA7913A4A40F7915B936E0D4B40BBD05CA7913A4A40F7915B936E0D4B4042CC2555DB394A40C38366D7BD0B4B4042CC2555DB394A40
50375	47860	53.479331999999999	53.498637000000002	52.211241000000001	52.190581000000002	Центральная	0103000020E6100000010000000500000090F63FC05ABD4A40971E4DF564184A4090F63FC05ABD4A408449F1F1091B4A40ACC95356D3BF4A408449F1F1091B4A40ACC95356D3BF4A40971E4DF564184A4090F63FC05ABD4A40971E4DF564184A40
50787	48400	54.115096999999999	54.125687999999997	52.342663999999999	52.333683999999998	Подгорная	0103000020E61000000100000005000000116F9D7FBB0E4B4067994528B62A4A40116F9D7FBB0E4B401EC2F869DC2B4A40F4BF5C8B16104B401EC2F869DC2B4A40F4BF5C8B16104B4067994528B62A4A40116F9D7FBB0E4B4067994528B62A4A40
81114	62083	53.912365000000001	53.926971000000002	52.055598000000003	52.043219000000001	Центральная	0103000020E61000000100000005000000ED815660C8F44A406DC83F3388054A40ED815660C8F44A408CDCD3D51D074A4093AB58FCA6F64A408CDCD3D51D074A4093AB58FCA6F64A406DC83F3388054A40ED815660C8F44A406DC83F3388054A40
50551	56063	59.030569999999997	59.030813000000002	51.364142999999999	51.364024999999998	Мостовая	0103000020E610000001000000050000008E1EBFB7E9834D4094F6065F98AE49408E1EBFB7E9834D409E08E23C9CAE494055A52DAEF1834D409E08E23C9CAE494055A52DAEF1834D4094F6065F98AE49408E1EBFB7E9834D4094F6065F98AE4940
49990	5939	58.766663000000001	58.845534999999998	51.760702000000002	51.723376999999999	Правдухина	0103000020E61000000100000005000000D106600322624D40DCD6169E97DC4940D106600322624D403B00E2AE5EE14940CA4FAA7D3A6C4D403B00E2AE5EE14940CA4FAA7D3A6C4D40DCD6169E97DC4940D106600322624D40DCD6169E97DC4940
49740	5939	58.766663000000001	58.845534999999998	51.760702000000002	51.723376999999999	Пионерская	0103000020E61000000100000005000000D106600322624D40DCD6169E97DC4940D106600322624D403B00E2AE5EE14940CA4FAA7D3A6C4D403B00E2AE5EE14940CA4FAA7D3A6C4D40DCD6169E97DC4940D106600322624D40DCD6169E97DC4940
66982	58904	59.279708999999997	59.302875999999998	51.766064	51.753984000000003	Школьная	0103000020E61000000100000005000000CCB22781CDA34D4088DA368C82E04940CCB22781CDA34D404C5299620EE24940245F09A4C4A64D404C5299620EE24940245F09A4C4A64D4088DA368C82E04940CCB22781CDA34D4088DA368C82E04940
50492	6403	59.167527	59.203163000000004	51.376232000000002	51.356253000000002	Школьная	0103000020E610000001000000050000003719558671954D400B0DC4B299AD49403719558671954D40B6DAC35E28B04940EE60C43E019A4D40B6DAC35E28B04940EE60C43E019A4D400B0DC4B299AD49403719558671954D400B0DC4B299AD4940
50054	5581	58.936993000000001	58.967534999999998	51.386941	51.377333999999998	 Ленина	0103000020E610000001000000050000005CCAF962EF774D409DD5027B4CB049405CCAF962EF774D40A33D5E4887B14940205ED72FD87B4D40A33D5E4887B14940205ED72FD87B4D409DD5027B4CB049405CCAF962EF774D409DD5027B4CB04940
50516	56076	58.765341999999997	58.794725999999997	51.286606999999997	51.269446000000002	Школьная	0103000020E61000000100000005000000AB2006BAF6614D40DE04DF347DA24940AB2006BAF6614D40FFE6C589AFA44940F4A3E194B9654D40FFE6C589AFA44940F4A3E194B9654D40DE04DF347DA24940AB2006BAF6614D40DE04DF347DA24940
50641	6383	59.140253999999999	59.158445	51.523667000000003	51.512188999999999	Центральная	0103000020E610000001000000050000000C91D3D7F3914D407B2FBE688FC149400C91D3D7F3914D404A7F2F8507C349407C9BFEEC47944D404A7F2F8507C349407C9BFEEC47944D407B2FBE688FC149400C91D3D7F3914D407B2FBE688FC14940
51277	6089	58.707858999999999	58.723399999999998	51.532274000000001	51.526148999999997	Центральная	0103000020E61000000100000005000000F296AB1F9B5A4D405BE9B5D958C34940F296AB1F9B5A4D406C41EF8D21C4494094F6065F985C4D406C41EF8D21C4494094F6065F985C4D405BE9B5D958C34940F296AB1F9B5A4D405BE9B5D958C34940
49751	56038	58.952227999999998	59.062936000000001	51.399017999999998	51.355960000000003	микрорайон Водстроя	0103000020E61000000100000005000000F12A6B9BE2794D409357E71890AD4940F12A6B9BE2794D40F641960513B34940DBDE6E490E884D40F641960513B34940DBDE6E490E884D409357E71890AD4940F12A6B9BE2794D409357E71890AD4940
49743	56038	58.952227999999998	59.062936000000001	51.399017999999998	51.355960000000003	Школьная	0103000020E61000000100000005000000F12A6B9BE2794D409357E71890AD4940F12A6B9BE2794D40F641960513B34940DBDE6E490E884D40F641960513B34940DBDE6E490E884D409357E71890AD4940F12A6B9BE2794D409357E71890AD4940
50101	56038	58.952227999999998	59.062936000000001	51.399017999999998	51.355960000000003	Ленина	0103000020E61000000100000005000000F12A6B9BE2794D409357E71890AD4940F12A6B9BE2794D40F641960513B34940DBDE6E490E884D40F641960513B34940DBDE6E490E884D409357E71890AD4940F12A6B9BE2794D409357E71890AD4940
50298	56038	58.952227999999998	59.062936000000001	51.399017999999998	51.355960000000003	Клецова	0103000020E61000000100000005000000F12A6B9BE2794D409357E71890AD4940F12A6B9BE2794D40F641960513B34940DBDE6E490E884D40F641960513B34940DBDE6E490E884D409357E71890AD4940F12A6B9BE2794D409357E71890AD4940
51088	45800	59.280256999999999	59.296768	51.301076999999999	51.294420000000002	 Комсомольская	0103000020E61000000100000005000000CFBC1C76DFA34D40E8A4F78DAFA54940CFBC1C76DFA34D40F549EEB089A64940EA3F6B7EFCA54D40F549EEB089A64940EA3F6B7EFCA54D40E8A4F78DAFA54940CFBC1C76DFA34D40E8A4F78DAFA54940
51289	6568	59.054546000000002	59.071469999999998	51.154637000000001	51.141781999999999	Школьный переулок	0103000020E610000001000000050000005610035DFB864D40AB949EE9259249405610035DFB864D4033E02C25CB9349409352D0ED25894D4033E02C25CB9349409352D0ED25894D40AB949EE9259249405610035DFB864D40AB949EE925924940
50954	6542	59.094323000000003	59.114356000000001	51.257666999999998	51.244706000000001	Степная	0103000020E610000001000000050000005C21ACC6128C4D404791B586529F49405C21ACC6128C4D401421753BFBA04940FA0CA837A38E4D401421753BFBA04940FA0CA837A38E4D404791B586529F49405C21ACC6128C4D404791B586529F4940
49741	6631	58.827506	58.870381999999999	51.331166000000003	51.310879999999997	Садовая	0103000020E61000000100000005000000349F73B7EB694D40807D74EACAA74940349F73B7EB694D4009C6C1A563AA4940778368AD686F4D4009C6C1A563AA4940778368AD686F4D40807D74EACAA74940349F73B7EB694D40807D74EACAA74940
50221	56059	58.927075000000002	58.956719999999997	51.184766000000003	51.168740999999997	Центральная	0103000020E6100000010000000500000038F8C264AA764D40463F1A4E9995494038F8C264AA764D40D5B48B69A6974940EDB60BCD757A4D40D5B48B69A6974940EDB60BCD757A4D40463F1A4E9995494038F8C264AA764D40463F1A4E99954940
50782	6704	58.797601	58.811973999999999	51.429071	51.408603999999997	Севастопольская	0103000020E61000000100000005000000E22021CA17664D40E481C8224DB44940E22021CA17664D40BD546CCCEBB64940E59997C3EE674D40BD546CCCEBB64940E59997C3EE674D40E481C8224DB44940E22021CA17664D40E481C8224DB44940
50611	6322	59.383940000000003	59.400953999999999	51.381708000000003	51.362945000000003	Ленина	0103000020E6100000010000000500000029D027F224B14D40959F54FB74AE494029D027F224B14D40904FC8CEDBB04940A699EE7552B34D40904FC8CEDBB04940A699EE7552B34D40959F54FB74AE494029D027F224B14D40959F54FB74AE4940
51278	6176	58.939552999999997	58.959440999999998	51.709024999999997	51.695321999999997	Школьная	0103000020E61000000100000005000000E9EDCF4543784D403B18B14F00D94940E9EDCF4543784D40F085C954C1DA494084B872F6CE7A4D40F085C954C1DA494084B872F6CE7A4D403B18B14F00D94940E9EDCF4543784D403B18B14F00D94940
50241	6220	59.252049999999997	59.279753999999997	51.694322999999997	51.67474	Комсомольская	0103000020E61000000100000005000000787AA52C43A04D40CAA65CE15DD64940787AA52C43A04D4028EE7893DFD849406C76A4FACEA34D4028EE7893DFD849406C76A4FACEA34D40CAA65CE15DD64940787AA52C43A04D40CAA65CE15DD64940
50477	5850	59.102578999999999	59.129277000000002	51.419562999999997	51.409643000000003	Школьная	0103000020E61000000100000005000000D120054F218D4D4086048C2E6FB44940D120054F218D4D404ACE893DB4B54940009013268C904D404ACE893DB4B54940009013268C904D4086048C2E6FB44940D120054F218D4D4086048C2E6FB44940
50483	6465	59.024020999999998	59.049622999999997	51.301487999999999	51.279380000000003	Шушаева	0103000020E6100000010000000500000067B5C01E13834D4008944DB9C2A3494067B5C01E13834D407711A62897A649409010E50B5A864D407711A62897A649409010E50B5A864D4008944DB9C2A3494067B5C01E13834D4008944DB9C2A34940
50371	6065	58.956305999999998	58.995463999999998	51.634945000000002	51.611125000000001	Костюхина	0103000020E61000000100000005000000FA7B293C687A4D404E62105839CE4940FA7B293C687A4D401EE1B4E045D14940342C465D6B7F4D401EE1B4E045D14940342C465D6B7F4D404E62105839CE4940FA7B293C687A4D404E62105839CE4940
81001	62047	57.616971999999997	57.677123000000002	51.479196000000002	51.458840000000002	Горняков	0103000020E610000001000000050000001B4641F0F8CE4C405F0CE544BBBA49401B4641F0F8CE4C40E02F664B56BD4940492F6AF7ABD64C40E02F664B56BD4940492F6AF7ABD64C405F0CE544BBBA49401B4641F0F8CE4C405F0CE544BBBA4940
51148	46861	53.42201	53.446066999999999	53.399034999999998	53.381255000000003	Школьная	0103000020E61000000100000005000000E04A766C04B64A40DF37BEF6CCB04A40E04A766C04B64A40CC7A319413B34A40946934B918B94A40CC7A319413B34A40946934B918B94A40DF37BEF6CCB04A40E04A766C04B64A40DF37BEF6CCB04A40
51185	46142	53.458571999999997	53.480894999999997	53.558593999999999	53.546926999999997	Центральная	0103000020E610000001000000050000003F6EBF7CB2BA4A40522635B401C64A403F6EBF7CB2BA4A40F4DE180280C74A40ABE7A4F78DBD4A40F4DE180280C74A40ABE7A4F78DBD4A40522635B401C64A403F6EBF7CB2BA4A40522635B401C64A40
50720	56104	53.735666000000002	53.763019999999997	53.428001000000002	53.415418000000003	Центральная	0103000020E61000000100000005000000BB63B14D2ADE4A40BA15C26A2CB54A40BB63B14D2ADE4A40E1D39CBCC8B64A40D218ADA3AAE14A40E1D39CBCC8B64A40D218ADA3AAE14A40BA15C26A2CB54A40BB63B14D2ADE4A40BA15C26A2CB54A40
9838	4157	53.361006000000003	53.429538000000001	53.618734000000003	53.596936999999997	Советская	0103000020E6100000010000000500000074D4D17135AE4A40DC627E6E68CC4A4074D4D17135AE4A402E76FBAC32CF4A40D331E719FBB64A402E76FBAC32CF4A40D331E719FBB64A40DC627E6E68CC4A4074D4D17135AE4A40DC627E6E68CC4A40
50282	4157	53.361006000000003	53.429538000000001	53.618734000000003	53.596936999999997	 Советская	0103000020E6100000010000000500000074D4D17135AE4A40DC627E6E68CC4A4074D4D17135AE4A402E76FBAC32CF4A40D331E719FBB64A402E76FBAC32CF4A40D331E719FBB64A40DC627E6E68CC4A4074D4D17135AE4A40DC627E6E68CC4A40
50835	4422	53.566792	53.583832999999998	53.456164999999999	53.448787000000003	Школьная	0103000020E6100000010000000500000035D1E7A38CC84A405BEF37DA71B94A4035D1E7A38CC84A40384A5E9D63BA4A40ACA92C0ABBCA4A40384A5E9D63BA4A40ACA92C0ABBCA4A405BEF37DA71B94A4035D1E7A38CC84A405BEF37DA71B94A40
50780	46767	53.338206999999997	53.354520000000001	53.558995000000003	53.544995	Набережная	0103000020E610000001000000050000009E23F25D4AAB4A40E4BD6A65C2C54A409E23F25D4AAB4A4053D0ED258DC74A4093E34EE960AD4A4053D0ED258DC74A4093E34EE960AD4A40E4BD6A65C2C54A409E23F25D4AAB4A40E4BD6A65C2C54A40
64122	58172	53.767538000000002	53.796796999999998	53.241115000000001	53.230480999999997	Зеленая	0103000020E61000000100000005000000F83768AF3EE24A40B8ACC266809D4A40F83768AF3EE24A409BC937DBDC9E4A408446B071FDE54A409BC937DBDC9E4A408446B071FDE54A40B8ACC266809D4A40F83768AF3EE24A40B8ACC266809D4A40
50840	26852	53.603470000000002	53.643751000000002	53.374507999999999	53.362833000000002	Садовая	0103000020E61000000100000005000000FE0E45813ECD4A406D74CE4F71AE4A40FE0E45813ECD4A40910BCEE0EFAF4A4037E2C96E66D24A40910BCEE0EFAF4A4037E2C96E66D24A406D74CE4F71AE4A40FE0E45813ECD4A406D74CE4F71AE4A40
9746	4007	53.417447000000003	53.441997999999998	53.239896999999999	53.223193000000002	Школьная	0103000020E610000001000000050000001B683EE76EB54A401BD99596919C4A401B683EE76EB54A404AB4E4F1B49E4A40DE72F56393B84A404AB4E4F1B49E4A40DE72F56393B84A401BD99596919C4A401B683EE76EB54A401BD99596919C4A40
50836	4007	53.417447000000003	53.441997999999998	53.239896999999999	53.223193000000002	Центральная	0103000020E610000001000000050000001B683EE76EB54A401BD99596919C4A401B683EE76EB54A404AB4E4F1B49E4A40DE72F56393B84A404AB4E4F1B49E4A40DE72F56393B84A401BD99596919C4A401B683EE76EB54A401BD99596919C4A40
50833	3944	53.307008000000003	53.328432999999997	53.341371000000002	53.323377999999998	Верхняя	0103000020E6100000010000000500000021CEC3094CA74A40791F477364A94A4021CEC3094CA74A40C366800BB2AB4A40ADF6B0170AAA4A40C366800BB2AB4A40ADF6B0170AAA4A40791F477364A94A4021CEC3094CA74A40791F477364A94A40
50657	3506	53.657674	53.677436999999998	53.262003	53.252651	Речная	0103000020E61000000100000005000000FAB660A92ED44A409E2633DE56A04A40FAB660A92ED44A40193A765089A14A40D80C7041B6D64A40193A765089A14A40D80C7041B6D64A409E2633DE56A04A40FAB660A92ED44A409E2633DE56A04A40
50684	46680	53.456370999999997	53.476125000000003	53.226832000000002	53.203802000000003	Степная	0103000020E61000000100000005000000E1EB6B5D6ABA4A40016E162F169A4A40E1EB6B5D6ABA4A40D8D7BAD4089D4A406DE7FBA9F1BC4A40D8D7BAD4089D4A406DE7FBA9F1BC4A40016E162F169A4A40E1EB6B5D6ABA4A40016E162F169A4A40
49839	46119	53.460107999999998	53.497478000000001	53.526446	53.492319000000002	Комсомольская	0103000020E610000001000000050000006150A6D1E4BA4A4087191A4F04BF4A406150A6D1E4BA4A40158E209562C34A40603DEE5BADBF4A40158E209562C34A40603DEE5BADBF4A4087191A4F04BF4A406150A6D1E4BA4A4087191A4F04BF4A40
50950	3463	53.794460999999998	53.824464999999996	53.293123999999999	53.265455000000003	Молодежная	0103000020E610000001000000050000004679E6E5B0E54A40A4C7EF6DFAA14A404679E6E5B0E54A401BD6541685A54A402BD9B11188E94A401BD6541685A54A402BD9B11188E94A40A4C7EF6DFAA14A404679E6E5B0E54A40A4C7EF6DFAA14A40
50438	26639	53.480328999999998	53.517187	53.289496	53.271163999999999	Парковая	0103000020E610000001000000050000000229B16B7BBD4A4020ED7F80B5A24A400229B16B7BBD4A40522976340EA54A404B75012F33C24A40522976340EA54A404B75012F33C24A4020ED7F80B5A24A400229B16B7BBD4A4020ED7F80B5A24A40
51354	26639	53.480328999999998	53.517187	53.289496	53.271163999999999	Луговая	0103000020E610000001000000050000000229B16B7BBD4A4020ED7F80B5A24A400229B16B7BBD4A40522976340EA54A404B75012F33C24A40522976340EA54A404B75012F33C24A4020ED7F80B5A24A400229B16B7BBD4A4020ED7F80B5A24A40
51161	46054	53.717771999999997	53.746769	53.239601	53.224508999999998	Ковешникова	0103000020E6100000010000000500000004FEF0F3DFDB4A402E54FEB5BC9C4A4004FEF0F3DFDB4A40618BDD3EAB9E4A405455682096DF4A40618BDD3EAB9E4A405455682096DF4A402E54FEB5BC9C4A4004FEF0F3DFDB4A402E54FEB5BC9C4A40
51275	46495	53.602293000000003	53.619073999999998	53.185918000000001	53.168497000000002	Школьная	0103000020E610000001000000050000000CCEE0EF17CD4A40B03C484F91954A400CCEE0EF17CD4A406EDE3829CC974A40E6E61BD13DCF4A406EDE3829CC974A40E6E61BD13DCF4A40B03C484F91954A400CCEE0EF17CD4A40B03C484F91954A40
50953	3415	53.756157000000002	53.781049000000003	53.254250999999996	53.244025000000001	Центральная	0103000020E610000001000000050000001CD2A8C0C9E04A40053411363C9F4A401CD2A8C0C9E04A40D6FCF84B8BA04A4069C9E369F9E34A40D6FCF84B8BA04A4069C9E369F9E34A40053411363C9F4A401CD2A8C0C9E04A40053411363C9F4A40
50781	46899	53.498547000000002	53.534992000000003	53.410350999999999	53.394615999999999	Молодежная	0103000020E610000001000000050000006C425A63D0BF4A403A3DEFC682B24A406C425A63D0BF4A40C170AE6186B44A4092CF2B9E7AC44A40C170AE6186B44A4092CF2B9E7AC44A403A3DEFC682B24A406C425A63D0BF4A403A3DEFC682B24A40
51159	3637	53.541252999999998	53.564653999999997	53.333300999999999	53.322868	Центральная	0103000020E6100000010000000500000052EE3EC747C54A40647616BD53A94A4052EE3EC747C54A40AF5C6F9BA9AA4A401DC70F9546C84A40AF5C6F9BA9AA4A401DC70F9546C84A40647616BD53A94A4052EE3EC747C54A40647616BD53A94A40
51180	45889	53.464438000000001	53.479726999999997	53.302967000000002	53.296498999999997	Центральная	0103000020E61000000100000005000000848252B472BB4A40FA25E2ADF3A54A40848252B472BB4A403562669FC7A64A400C01C0B167BD4A403562669FC7A64A400C01C0B167BD4A40FA25E2ADF3A54A40848252B472BB4A40FA25E2ADF3A54A40
49899	56045	55.020463999999997	55.274084999999999	51.836356000000002	51.682088999999998	Никельщиков проспект	0103000020E61000000100000005000000675F79909E824B400DFB3DB14ED74940675F79909E824B401DE8A1B60DEB49407EA99F3715A34B401DE8A1B60DEB49407EA99F3715A34B400DFB3DB14ED74940675F79909E824B400DFB3DB14ED74940
51149	2387	51.896158999999997	51.913766000000003	52.236049999999999	52.225817999999997	Зеленая	0103000020E610000001000000050000000E828E56B5F249408F6CAE9AE71C4A400E828E56B5F24940431CEBE2361E4A402F19C748F6F44940431CEBE2361E4A402F19C748F6F449408F6CAE9AE71C4A400E828E56B5F249408F6CAE9AE71C4A40
50779	2484	51.960504999999998	51.989386000000003	52.256005999999999	52.239966000000003	Крестьянская	0103000020E610000001000000050000007E52EDD3F1FA49407313B534B71E4A407E52EDD3F1FA494036CAFACDC4204A40658F5033A4FE494036CAFACDC4204A40658F5033A4FE49407313B534B71E4A407E52EDD3F1FA49407313B534B71E4A40
51266	2041	52.027942000000003	52.055044000000002	52.641264999999997	52.626311000000001	8 Марта	0103000020E61000000100000005000000A9177C9A93034A40021077F52A504A40A9177C9A93034A40E388B5F814524A40A7EB89AE0B074A40E388B5F814524A40A7EB89AE0B074A40021077F52A504A40A9177C9A93034A40021077F52A504A40
50943	1927	52.128895	52.153894999999999	52.573478999999999	52.559229999999999	Набережная	0103000020E6100000010000000500000018CFA0A17F104A40967840D994474A4018CFA0A17F104A40ADF886C267494A404B02D4D4B2134A40ADF886C267494A404B02D4D4B2134A40967840D994474A4018CFA0A17F104A40967840D994474A40
51270	2960	51.526152000000003	51.545780000000001	52.255361000000001	52.241163	Дорожная	0103000020E61000000100000005000000CD5CE0F258C34940AC00DF6DDE1E4A40CD5CE0F258C3494041D653ABAF204A40CB67791EDCC5494041D653ABAF204A40CB67791EDCC54940AC00DF6DDE1E4A40CD5CE0F258C34940AC00DF6DDE1E4A40
50949	56132	51.690111999999999	51.716289000000003	52.531782	52.519153000000003	Школьная	0103000020E61000000100000005000000E0490B9755D84940664F029B73424A40E0490B9755D84940FD4CBD6E11444A4006BEA25BAFDB4940FD4CBD6E11444A4006BEA25BAFDB4940664F029B73424A40E0490B9755D84940664F029B73424A40
50008	2268	51.779215999999998	51.831417000000002	52.496065000000002	52.477974000000003	Дорожная	0103000020E610000001000000050000008D429259BDE349404E2B85402E3D4A408D429259BDE349405AD8D30E7F3F4A40522B4CDF6BEA49405AD8D30E7F3F4A40522B4CDF6BEA49404E2B85402E3D4A408D429259BDE349404E2B85402E3D4A40
51265	1767	51.919981999999997	51.947650000000003	52.455770000000001	52.449914999999997	Мира	0103000020E610000001000000050000004F745DF8C1F549406B7D91D096394A404F745DF8C1F54940BC3FDEAB563A4A40F7065F984CF94940BC3FDEAB563A4A40F7065F984CF949406B7D91D096394A404F745DF8C1F549406B7D91D096394A40
51271	2866	51.487183000000002	51.508302	52.326374999999999	52.308219000000001	Советская	0103000020E61000000100000005000000661536035CBE4940BF805EB873274A40661536035CBE4940B29DEFA7C6294A40E63E390A10C14940B29DEFA7C6294A40E63E390A10C14940BF805EB873274A40661536035CBE4940BF805EB873274A40
50947	1911	52.219884999999998	52.231589999999997	52.632793999999997	52.617094000000002	Центральная	0103000020E61000000100000005000000C3F01131251C4A406747AAEFFC4E4A40C3F01131251C4A40718DCF64FF504A40520ABABDA41D4A40718DCF64FF504A40520ABABDA41D4A406747AAEFFC4E4A40C3F01131251C4A406747AAEFFC4E4A40
50457	1911	52.219884999999998	52.231589999999997	52.632793999999997	52.617094000000002	Парковая	0103000020E61000000100000005000000C3F01131251C4A406747AAEFFC4E4A40C3F01131251C4A40718DCF64FF504A40520ABABDA41D4A40718DCF64FF504A40520ABABDA41D4A406747AAEFFC4E4A40C3F01131251C4A406747AAEFFC4E4A40
50472	2623	51.929361	51.960847000000001	52.408890999999997	52.384084999999999	Ленина	0103000020E61000000100000005000000C4961E4DF5F649402CF180B229314A40C4961E4DF5F649407A50508A56344A40D8BAD408FDFA49407A50508A56344A40D8BAD408FDFA49402CF180B229314A40C4961E4DF5F649402CF180B229314A40
51147	2754	51.660862999999999	51.698332000000001	52.425033999999997	52.411060999999997	Победы	0103000020E610000001000000050000007711A62897D449409DD497A59D344A407711A62897D4494012D89C8367364A4009E066F162D9494012D89C8367364A4009E066F162D949409DD497A59D344A407711A62897D449409DD497A59D344A40
49748	1819	52.156886	52.194445000000002	52.620041000000001	52.595999999999997	Зорина	0103000020E61000000100000005000000A29927D714144A403F355EBA494C4A40A29927D714144A40EE96E4805D4F4A4074EFE192E3184A40EE96E4805D4F4A4074EFE192E3184A403F355EBA494C4A40A29927D714144A403F355EBA494C4A40
50283	1724	51.975982999999999	51.998081999999997	52.446461999999997	52.436273	Крестьянская	0103000020E61000000100000005000000DA39CD02EDFC49405C902DCBD7374A40DA39CD02EDFC49401074B4AA25394A40F65CA626C1FF49401074B4AA25394A40F65CA626C1FF49405C902DCBD7374A40DA39CD02EDFC49405C902DCBD7374A40
50080	56050	52.048208000000002	52.093384	52.526161000000002	52.492479000000003	Строительная	0103000020E61000000100000005000000EAB303AE2B064A40C07B478D093F4A40EAB303AE2B064A4020B75F3E59434A401EFCC401F40B4A4020B75F3E59434A401EFCC401F40B4A40C07B478D093F4A40EAB303AE2B064A40C07B478D093F4A40
51294	2712	51.906480999999999	51.915644	52.378489000000002	52.364027999999998	Мира	0103000020E6100000010000000500000002B9C49107F44940056A3178982E4A4002B9C49107F44940A872DA5372304A40AA6395D233F54940A872DA5372304A40AA6395D233F54940056A3178982E4A4002B9C49107F44940056A3178982E4A40
50945	2538	51.937624999999997	51.953166000000003	52.337712000000003	52.329622000000001	Набережная	0103000020E61000000100000005000000BC74931804F849406405BF0D312A4A40BC74931804F84940BFBB95253A2B4A405FD4EE5701FA4940BFBB95253A2B4A405FD4EE5701FA49406405BF0D312A4A40BC74931804F849406405BF0D312A4A40
50476	2814	51.581443	51.631974	52.389592999999998	52.366942999999999	Центральная	0103000020E610000001000000050000007BBE66B96CCA4940813FFCFCF72E4A407BBE66B96CCA494011E0F42EDE314A400EF62686E4D0494011E0F42EDE314A400EF62686E4D04940813FFCFCF72E4A407BBE66B96CCA4940813FFCFCF72E4A40
50363	1667	52.031616	52.062437000000003	52.485487999999997	52.466920000000002	пл.Свердлова	0103000020E61000000100000005000000E2033BFE0B044A4096ECD808C43B4A40E2033BFE0B044A40DB4C8578243E4A40BA8784EFFD074A40DB4C8578243E4A40BA8784EFFD074A4096ECD808C43B4A40E2033BFE0B044A4096ECD808C43B4A40
49833	3112	52.017018	52.079765999999999	52.220990999999998	52.197966999999998	Первомайская	0103000020E61000000100000005000000BFB854A52D024A40F7578FFB56194A40BFB854A52D024A40ECDADE6E491C4A4097AAB4C5350A4A40ECDADE6E491C4A4097AAB4C5350A4A40F7578FFB56194A40BFB854A52D024A40F7578FFB56194A40
51286	3311	52.204658000000002	52.215510000000002	52.291125000000001	52.279963000000002	Восточная	0103000020E61000000100000005000000B16EBC3B321A4A40878BDCD3D5234A40B16EBC3B321A4A402506819543254A4001FBE8D4951B4A402506819543254A4001FBE8D4951B4A40878BDCD3D5234A40B16EBC3B321A4A40878BDCD3D5234A40
50955	2976	51.696013999999998	51.735557999999997	52.249169000000002	52.235906999999997	Пролетарская	0103000020E6100000010000000500000071C79BFC16D94940E0F25833321E4A4071C79BFC16D94940A91611C5E41F4A40D427B9C326DE4940A91611C5E41F4A40D427B9C326DE4940E0F25833321E4A4071C79BFC16D94940E0F25833321E4A40
50843	21682	51.839861999999997	51.864161000000003	52.179029999999997	52.162011999999997	Крестьянская	0103000020E610000001000000050000009A93179980EB49409FC728CFBC144A409A93179980EB49405E807D74EA164A4045BDE0D39CEE49405E807D74EA164A4045BDE0D39CEE49409FC728CFBC144A409A93179980EB49409FC728CFBC144A40
50606	2082	51.618561999999997	51.648952000000001	52.532105000000001	52.519694999999999	Центральная	0103000020E610000001000000050000003046240A2DCF49408672A25D85424A403046240A2DCF4940E08442041C444A403F56F0DB10D34940E08442041C444A403F56F0DB10D349408672A25D85424A403046240A2DCF49408672A25D85424A40
50550	3228	52.126981000000001	52.161772999999997	52.184269999999998	52.175699999999999	Мутного	0103000020E61000000100000005000000501BD5E940104A401FF46C567D164A40501BD5E940104A4024D1CB2896174A401A3048FAB4144A4024D1CB2896174A401A3048FAB4144A401FF46C567D164A40501BD5E940104A401FF46C567D164A40
50866	46916	51.561760999999997	51.598250999999998	52.554971000000002	52.537878999999997	Школьная	0103000020E610000001000000050000008995D1C8E7C74940431A1538D9444A408995D1C8E7C749403D9D2B4A09474A404FE61F7D93CC49403D9D2B4A09474A404FE61F7D93CC4940431A1538D9444A408995D1C8E7C74940431A1538D9444A40
50946	2621	51.938110000000002	51.959203000000002	52.303185999999997	52.290407999999999	Советская	0103000020E6100000010000000500000079060DFD13F84940963FDF162C254A4079060DFD13F84940724D81CCCE264A40D09CF529C7FA4940724D81CCCE264A40D09CF529C7FA4940963FDF162C254A4079060DFD13F84940963FDF162C254A40
50414	2279	51.895493999999999	51.929864000000002	52.326281999999999	52.305790999999999	Ленинская	0103000020E61000000100000005000000D2E1218C9FF24940A034D42824274A40D2E1218C9FF2494001A3CB9BC3294A4027DD96C805F7494001A3CB9BC3294A4027DD96C805F74940A034D42824274A40D2E1218C9FF24940A034D42824274A40
50273	56061	56.841807000000003	56.843953999999997	51.527504999999998	51.527090999999999	Рабочая	0103000020E610000001000000050000009E45EF54C06B4C400A82C7B777C349409E45EF54C06B4C40FDBCA94885C3494008AA46AF066C4C40FDBCA94885C3494008AA46AF066C4C400A82C7B777C349409E45EF54C06B4C400A82C7B777C34940
50938	491	57.815302000000003	57.829891000000003	51.309246999999999	51.286776000000003	Школьная	0103000020E61000000100000005000000842EE1D05BE84C408CA37213B5A44940842EE1D05BE84C406CB1DB6795A74940541F48DE39EA4C406CB1DB6795A74940541F48DE39EA4C408CA37213B5A44940842EE1D05BE84C408CA37213B5A44940
51254	30812	56.801642999999999	56.818100000000001	51.553296000000003	51.542149999999999	Юлаева	0103000020E610000001000000050000009E08E23C9C664C4061C3D32B65C549409E08E23C9C664C40FA804067D2C64940C66D3480B7684C40FA804067D2C64940C66D3480B7684C4061C3D32B65C549409E08E23C9C664C4061C3D32B65C54940
51267	56159	57.523251000000002	57.547514	51.642318000000003	51.629198000000002	Школьная	0103000020E61000000100000005000000B64C86E3F9C24C40B45A608F89D04940B64C86E3F9C24C40EAD0E97937D24940130D52F014C64C40EAD0E97937D24940130D52F014C64C40B45A608F89D04940B64C86E3F9C24C40B45A608F89D04940
51257	31088	56.983777000000003	57.003028	51.683881999999997	51.668970000000002	Центральная	0103000020E610000001000000050000004CC79C67EC7D4C40A80018CFA0D549404CC79C67EC7D4C405A29047289D74940747CB43863804C405A29047289D74940747CB43863804C40A80018CFA0D549404CC79C67EC7D4C40A80018CFA0D54940
50348	31450	57.405310999999998	57.434902000000001	51.176997	51.162911999999999	переулок Школьный	0103000020E61000000100000005000000C2DA183BE1B34C401F10E84CDA944940C2DA183BE1B34C40BC3E73D6A7964940857B65DEAAB74C40BC3E73D6A7964940857B65DEAAB74C401F10E84CDA944940C2DA183BE1B34C401F10E84CDA944940
50655	32489	57.984796000000003	58.013568999999997	51.739246000000001	51.728487000000001	Центральная	0103000020E61000000100000005000000A69D9ACB0DFE4C40D447E00F3FDD4940A69D9ACB0DFE4C4073D9E89C9FDE4940A59E05A1BC014D4073D9E89C9FDE4940A59E05A1BC014D40D447E00F3FDD4940A69D9ACB0DFE4C40D447E00F3FDD4940
50350	431	57.813236000000003	57.930089000000002	51.476587000000002	51.356752999999998	Элеваторная	0103000020E6100000010000000500000006F7031E18E84C40FCDF1115AAAD494006F7031E18E84C40715985CD00BD494047AF06280DF74C40715985CD00BD494047AF06280DF74C40FCDF1115AAAD494006F7031E18E84C40FCDF1115AAAD4940
50361	431	57.813236000000003	57.930089000000002	51.476587000000002	51.356752999999998	Центральная	0103000020E6100000010000000500000006F7031E18E84C40FCDF1115AAAD494006F7031E18E84C40715985CD00BD494047AF06280DF74C40715985CD00BD494047AF06280DF74C40FCDF1115AAAD494006F7031E18E84C40FCDF1115AAAD4940
51162	20157	57.499561999999997	57.534309	51.386704999999999	51.370345	Центральная	0103000020E610000001000000050000008429CAA5F1BF4C405A9E077767AF49408429CAA5F1BF4C408F19A88C7FB14940AF7AC03C64C44C408F19A88C7FB14940AF7AC03C64C44C405A9E077767AF49408429CAA5F1BF4C405A9E077767AF4940
51261	30896	57.045760000000001	57.073087000000001	51.526783000000002	51.517798999999997	 Школьная	0103000020E6100000010000000500000084BBB376DB854C406473D53C47C2494084BBB376DB854C405D8B16A06DC34940A26131EA5A894C405D8B16A06DC34940A26131EA5A894C406473D53C47C2494084BBB376DB854C406473D53C47C24940
51009	31493	57.270555000000002	57.285404	51.104567000000003	51.095008	Ровненская	0103000020E610000001000000050000007862D68BA1A24C40DF6DDE38298C49407862D68BA1A24C40D49E9273628D4940E412471E88A44C40D49E9273628D4940E412471E88A44C40DF6DDE38298C49407862D68BA1A24C40DF6DDE38298C4940
51096	17201	57.437013	57.446966000000003	51.531047000000001	51.523671999999998	Центральная	0103000020E61000000100000005000000A376BF0AF0B74C405BEA20AF07C34940A376BF0AF0B74C40C8D11C59F9C349404436902E36B94C40C8D11C59F9C349404436902E36B94C405BEA20AF07C34940A376BF0AF0B74C405BEA20AF07C34940
50789	56114	58.023010999999997	58.045540000000003	51.690967000000001	51.678241999999997	Центральная	0103000020E6100000010000000500000060394206F2024D40066344A2D0D6494060394206F2024D40C0CE4D9B71D8494076543541D4054D40C0CE4D9B71D8494076543541D4054D40066344A2D0D6494060394206F2024D40066344A2D0D64940
51146	31404	57.595143	57.622352999999997	51.192183999999997	51.184804999999997	Школьная	0103000020E61000000100000005000000BFB854A52DCC4C409291B3B0A7974940BFB854A52DCC4C4040683D7C99984940A3C85A43A9CF4C4040683D7C99984940A3C85A43A9CF4C409291B3B0A7974940BFB854A52DCC4C409291B3B0A7974940
50909	31685	57.004787999999998	57.022584000000002	51.337130999999999	51.333517999999998	Центральная	0103000020E61000000100000005000000E5B4A7E49C804C404C50C3B7B0AA4940E5B4A7E49C804C40E0BBCD1B27AB4940D9B45208E4824C40E0BBCD1B27AB4940D9B45208E4824C404C50C3B7B0AA4940E5B4A7E49C804C404C50C3B7B0AA4940
51269	32120	57.422828000000003	57.446122000000003	51.393331000000003	51.379852999999997	Центральная	0103000020E61000000100000005000000A3EA573A1FB64C40CC24EA059FB04940A3EA573A1FB64C4062C092AB58B24940580394861AB94C4062C092AB58B24940580394861AB94C40CC24EA059FB04940A3EA573A1FB64C40CC24EA059FB04940
50471	32321	57.754019	57.776305999999998	51.638221000000001	51.627654999999997	Мира	0103000020E6100000010000000500000004C8D0B183E04C40DF15C1FF56D0494004C8D0B183E04C406A4FC939B1D1494023D8B8FE5DE34C406A4FC939B1D1494023D8B8FE5DE34C40DF15C1FF56D0494004C8D0B183E04C40DF15C1FF56D04940
50604	31586	57.222898999999998	57.254007999999999	51.255462999999999	51.235340000000001	Советская	0103000020E61000000100000005000000D2A755F4879C4C4067B8019F1F9E4940D2A755F4879C4C40452BF702B3A0494010768A5583A04C40452BF702B3A0494010768A5583A04C4067B8019F1F9E4940D2A755F4879C4C4067B8019F1F9E4940
50607	32412	57.859445000000001	57.902887999999997	51.780704	51.763004000000002	Мира	0103000020E61000000100000005000000F9DA334B02EE4C40CD5B751DAAE14940F9DA334B02EE4C409EEDD11BEEE34940B5F97FD591F34C409EEDD11BEEE34940B5F97FD591F34C40CD5B751DAAE14940F9DA334B02EE4C40CD5B751DAAE14940
50941	115	57.887113999999997	57.916694999999997	51.489207	51.477865999999999	Школьная	0103000020E6100000010000000500000070E998F38CF14C4067EF8CB62ABD494070E998F38CF14C40B5FCC0559EBE49400FB4024356F54C40B5FCC0559EBE49400FB4024356F54C4067EF8CB62ABD494070E998F38CF14C4067EF8CB62ABD4940
50934	31006	57.238430999999999	57.258580000000002	51.543729999999996	51.530413000000003	Центральная	0103000020E6100000010000000500000021AD31E8849E4C40C72FBC92E4C3494021AD31E8849E4C4052EDD3F198C5494029B3412619A14C4052EDD3F198C5494029B3412619A14C40C72FBC92E4C3494021AD31E8849E4C40C72FBC92E4C34940
50951	31006	57.238430999999999	57.258580000000002	51.543729999999996	51.530413000000003	Новосамарская	0103000020E6100000010000000500000021AD31E8849E4C40C72FBC92E4C3494021AD31E8849E4C4052EDD3F198C5494029B3412619A14C4052EDD3F198C5494029B3412619A14C40C72FBC92E4C3494021AD31E8849E4C40C72FBC92E4C34940
51268	32176	57.876171999999997	57.912554	51.538615	51.521889999999999	Молодёжная	0103000020E61000000100000005000000E0D5726726F04C40020EA14ACDC24940E0D5726726F04C4049111956F1C44940C0EAC891CEF44C4049111956F1C44940C0EAC891CEF44C40020EA14ACDC24940E0D5726726F04C40020EA14ACDC24940
51264	32401	57.677788	57.707557999999999	51.642161000000002	51.629243000000002	Горная	0103000020E6100000010000000500000085CFD6C1C1D64C40541EDD088BD0494085CFD6C1C1D64C4022E2E65432D24940F702B34291DA4C4022E2E65432D24940F702B34291DA4C40541EDD088BD0494085CFD6C1C1D64C40541EDD088BD04940
50703	56100	57.094728000000003	57.119278999999999	51.359250000000003	51.348866999999998	Молодёжная	0103000020E61000000100000005000000FC010F0C208C4C40AAD381ACA7AC4940FC010F0C208C4C40448B6CE7FBAD4940BF0CC688448F4C40448B6CE7FBAD4940BF0CC688448F4C40AAD381ACA7AC4940FC010F0C208C4C40AAD381ACA7AC4940
50275	31078	56.953360000000004	56.965487000000003	51.528536000000003	51.522075000000001	Советская	0103000020E6100000010000000500000044A852B3077A4C409487855AD3C2494044A852B3077A4C401C615111A7C3494049DBF813957B4C401C615111A7C3494049DBF813957B4C409487855AD3C2494044A852B3077A4C409487855AD3C24940
51260	238	58.005341000000001	58.032766000000002	51.503819	51.490558999999998	Центральная	0103000020E61000000100000005000000FA298E03AF004D4015E126A3CABE4940FA298E03AF004D403D0D18247DC04940DB3521AD31044D403D0D18247DC04940DB3521AD31044D4015E126A3CABE4940FA298E03AF004D4015E126A3CABE4940
50940	372	57.821778999999999	57.840229999999998	51.461196999999999	51.446829000000001	Центральная	0103000020E6100000010000000500000011C5E40D30E94C40C3F352B131B9494011C5E40D30E94C40B401D88008BB49401D8F19A88CEB4C40B401D88008BB49401D8F19A88CEB4C40C3F352B131B9494011C5E40D30E94C40C3F352B131B94940
50603	31198	57.123868999999999	57.165703000000001	51.558795000000003	51.542974000000001	Клубная	0103000020E610000001000000050000007EFE7BF0DA8F4C40064A0A2C80C549407EFE7BF0DA8F4C408C15359886C74940AFEC82C135954C408C15359886C74940AFEC82C135954C40064A0A2C80C549407EFE7BF0DA8F4C40064A0A2C80C54940
51258	31352	57.247055000000003	57.271039999999999	51.308678	51.286912000000001	Школьная	0103000020E610000001000000050000001AA88C7F9F9F4C403C6A4C88B9A449401AA88C7F9F9F4C40527FBDC282A7494034F44F70B1A24C40527FBDC282A7494034F44F70B1A24C403C6A4C88B9A449401AA88C7F9F9F4C403C6A4C88B9A44940
50685	31758	57.205750000000002	57.247881	51.384979000000001	51.369304999999997	Центральная	0103000020E6100000010000000500000075931804569A4C40E89FE06245AF494075931804569A4C40CA52EBFD46B149405F268A90BA9F4C40CA52EBFD46B149405F268A90BA9F4C40E89FE06245AF494075931804569A4C40E89FE06245AF4940
51000	20274	57.523062000000003	57.543776999999999	51.299641000000001	51.286855000000003	Молодежная	0103000020E61000000100000005000000E3E313B2F3C24C40D8D825AAB7A44940E3E313B2F3C24C4037C5E3A25AA6494093A8177C9AC54C4037C5E3A25AA6494093A8177C9AC54C40D8D825AAB7A44940E3E313B2F3C24C40D8D825AAB7A44940
51262	32205	57.886654999999998	57.914924999999997	51.646644000000002	51.625982999999998	Школьная	0103000020E61000000100000005000000DDEA39E97DF14C400D6D003620D04940DDEA39E97DF14C40CB13083BC5D249407AA52C431CF54C40CB13083BC5D249407AA52C431CF54C400D6D003620D04940DDEA39E97DF14C400D6D003620D04940
50682	31269	57.035277000000001	57.062621999999998	51.624608000000002	51.609436000000002	Кайраклинская	0103000020E6100000010000000500000087A6ECF483844C40A680B4FF01CE494087A6ECF483844C40F568AA27F3CF49404B0169FF03884C40F568AA27F3CF49404B0169FF03884C40A680B4FF01CE494087A6ECF483844C40A680B4FF01CE4940
50343	31264	57.341728000000003	57.368265000000001	51.24474	51.225740999999999	Новая	0103000020E6100000010000000500000052103CBEBDAB4C40E42EC214E59C494052103CBEBDAB4C40F302ECA3539F494077A1B94E23AF4C40F302ECA3539F494077A1B94E23AF4C40E42EC214E59C494052103CBEBDAB4C40E42EC214E59C4940
51330	20191	57.511913999999997	57.526287000000004	51.424987999999999	51.407738000000002	Салавата Юлаева	0103000020E61000000100000005000000A92EE06586C14C4011AB3FC230B44940A92EE06586C14C40A298BC0166B64940ADA7565F5DC34C40A298BC0166B64940ADA7565F5DC34C4011AB3FC230B44940A92EE06586C14C4011AB3FC230B44940
50278	31895	57.430140999999999	57.458644	51.515047000000003	51.497971999999997	Советская	0103000020E6100000010000000500000099D53BDC0EB74C406F29E78BBDBF494099D53BDC0EB74C409373620FEDC14940D940BAD8B4BA4C409373620FEDC14940D940BAD8B4BA4C406F29E78BBDBF494099D53BDC0EB74C406F29E78BBDBF4940
49830	30743	56.891177999999996	56.926867999999999	51.570954999999998	51.552937	Садовый переулок	0103000020E610000001000000050000001475E61E12724C40CADFBDA3C6C649401475E61E12724C406C3EAE0D15C94940BEDA519CA3764C406C3EAE0D15C94940BEDA519CA3764C40CADFBDA3C6C649401475E61E12724C40CADFBDA3C6C64940
50936	266	57.940733999999999	57.962373999999997	51.425049999999999	51.414732000000001	Центральная	0103000020E610000001000000050000001D1EC2F869F84C40664D2CF015B549401D1EC2F869F84C401895D40968B64940A6423C122FFB4C401895D40968B64940A6423C122FFB4C40664D2CF015B549401D1EC2F869F84C40664D2CF015B54940
50705	32328	57.713208999999999	57.738154999999999	51.748336000000002	51.728403	Школьная	0103000020E610000001000000050000003F1BB96E4ADB4C4076A73B4F3CDD49403F1BB96E4ADB4C40B1355B79C9DF49407F30F0DC7BDE4C40B1355B79C9DF49407F30F0DC7BDE4C4076A73B4F3CDD49403F1BB96E4ADB4C4076A73B4F3CDD4940
50939	32057	57.144629000000002	57.15849	51.517961999999997	51.505007999999997	Луговая	0103000020E61000000100000005000000CF86FC3383924C40F31B261AA4C04940CF86FC3383924C400E492D944CC249401C5F7B6649944C400E492D944CC249401C5F7B6649944C40F31B261AA4C04940CF86FC3383924C40F31B261AA4C04940
50366	56066	57.547649	57.582495000000002	51.500830999999998	51.485920999999998	Совхозная	0103000020E61000000100000005000000F357C85C19C64C4045B8C9A832BE4940F357C85C19C64C4057E9EE3A1BC04940B18A37328FCA4C4057E9EE3A1BC04940B18A37328FCA4C4045B8C9A832BE4940F357C85C19C64C4045B8C9A832BE4940
51333	20323	57.714224000000002	57.745871000000001	51.405687999999998	51.392792	Центральная	0103000020E61000000100000005000000580229B16BDB4C40B2101D0247B24940580229B16BDB4C4098309A95EDB34940750470B378DF4C4098309A95EDB34940750470B378DF4C40B2101D0247B24940580229B16BDB4C40B2101D0247B24940
50932	30855	56.991636999999997	57.003152999999998	51.548166000000002	51.537730000000003	Советская	0103000020E61000000100000005000000744012F6ED7E4C40FF092E56D4C44940744012F6ED7E4C40BB63B14D2AC6494030F1475167804C40BB63B14D2AC6494030F1475167804C40FF092E56D4C44940744012F6ED7E4C40FF092E56D4C44940
50778	31154	56.938797999999998	56.953251999999999	51.65963	51.647063000000003	Школьная	0103000020E610000001000000050000006DC669882A784C40D0B9DBF5D2D249406DC669882A784C40F1BA7EC16ED449405D6C5A29047A4C40F1BA7EC16ED449405D6C5A29047A4C40D0B9DBF5D2D249406DC669882A784C40D0B9DBF5D2D24940
50911	31880	57.317680000000003	57.329951000000001	51.340732000000003	51.334316999999999	Дорожная	0103000020E61000000100000005000000F14BFDBCA9A84C4098BF42E6CAAA4940F14BFDBCA9A84C40B0592E1B9DAB4940292499D53BAA4C40B0592E1B9DAB4940292499D53BAA4C4098BF42E6CAAA4940F14BFDBCA9A84C4098BF42E6CAAA4940
50602	30298	53.425649	53.459353	52.694997000000001	52.672733999999998	площадь Мира	0103000020E610000001000000050000009D499BAA7BB64A402174D0251C564A409D499BAA7BB64A40B8E864A9F5584A40E5284014CCBA4A40B8E864A9F5584A40E5284014CCBA4A402174D0251C564A409D499BAA7BB64A402174D0251C564A40
67474	59069	53.068964000000001	54.045630000000003	53.140298000000001	52.526598999999997	Школьная	0103000020E61000000100000005000000F94CF6CFD3884A409B8D959867434A40F94CF6CFD3884A40DCD8EC48F5914A40B6DB2E34D7054B40DCD8EC48F5914A40B6DB2E34D7054B409B8D959867434A40F94CF6CFD3884A409B8D959867434A40
50699	30091	53.762219999999999	53.776116999999999	52.716920999999999	52.704880000000003	Южная	0103000020E61000000100000005000000B62DCA6C90E14A4060CD0182395A4A40B62DCA6C90E14A4066683C11C45B4A40506F46CD57E34A4066683C11C45B4A40506F46CD57E34A4060CD0182395A4A40B62DCA6C90E14A4060CD0182395A4A40
50902	30038	53.722695000000002	53.749087000000003	52.786847000000002	52.774292000000003	Школьная	0103000020E61000000100000005000000CAFD0E4581DC4A40F8C610001C634A40CAFD0E4581DC4A4055FA0967B7644A40EC6D3315E2DF4A4055FA0967B7644A40EC6D3315E2DF4A40F8C610001C634A40CAFD0E4581DC4A40F8C610001C634A40
51247	28806	53.934068000000003	53.950192999999999	52.972262999999998	52.960428999999998	Школьная	0103000020E61000000100000005000000BD1E4C8A8FF74A40A3906456EF7A4A40BD1E4C8A8FF74A40300E2E1D737C4A40AEF199EC9FF94A40300E2E1D737C4A40AEF199EC9FF94A40A3906456EF7A4A40BD1E4C8A8FF74A40A3906456EF7A4A40
50466	28958	53.379950999999998	53.411132000000002	52.875534999999999	52.864196	пер.Школьный	0103000020E610000001000000050000008F8AFF3BA2B04A40C1AA7AF99D6E4A408F8AFF3BA2B04A406EC0E78711704A40672B2FF99FB44A406EC0E78711704A40672B2FF99FB44A40C1AA7AF99D6E4A408F8AFF3BA2B04A40C1AA7AF99D6E4A40
51006	48903	53.345258000000001	53.472963	52.778432000000002	52.605572000000002	Степная	0103000020E610000001000000050000005857056A31AC4A40C9AF1F62834D4A405857056A31AC4A407714E7A8A3634A40E99B340D8ABC4A407714E7A8A3634A40E99B340D8ABC4A40C9AF1F62834D4A405857056A31AC4A40C9AF1F62834D4A40
50407	48903	53.345258000000001	53.472963	52.778432000000002	52.605572000000002	Нижняя	0103000020E610000001000000050000005857056A31AC4A40C9AF1F62834D4A405857056A31AC4A407714E7A8A3634A40E99B340D8ABC4A407714E7A8A3634A40E99B340D8ABC4A40C9AF1F62834D4A405857056A31AC4A40C9AF1F62834D4A40
50777	29918	53.629179999999998	53.651511999999997	52.848329	52.840578999999998	Победы	0103000020E610000001000000050000000DA661F888D04A40295AB917986B4A400DA661F888D04A40CB9F6F0B966C4A40CC79C6BE64D34A40CB9F6F0B966C4A40CC79C6BE64D34A40295AB917986B4A400DA661F888D04A40295AB917986B4A40
51141	48198	53.591414999999998	53.612256000000002	53.119281000000001	53.101691000000002	 Советская	0103000020E6100000010000000500000092AE997CB3CB4A4016A6EF35048D4A4092AE997CB3CB4A4060048D99448F4A40D06394675ECE4A4060048D99448F4A40D06394675ECE4A4016A6EF35048D4A4092AE997CB3CB4A4016A6EF35048D4A40
50698	30019	53.886035	53.911088999999997	52.761628999999999	52.742797000000003	Центральная	0103000020E61000000100000005000000410E4A9869F14A409148DBF8135F4A40410E4A9869F14A40B4571F0F7D614A40675F79909EF44A40B4571F0F7D614A40675F79909EF44A409148DBF8135F4A40410E4A9869F14A409148DBF8135F4A40
50654	29112	53.406317000000001	53.421911999999999	52.909323000000001	52.897106999999998	Дружбы	0103000020E610000001000000050000008867093202B44A409F01F566D4724A408867093202B44A40144031B264744A401DE5603601B64A40144031B264744A401DE5603601B64A409F01F566D4724A408867093202B44A409F01F566D4724A40
50467	48951	53.66001	53.684201999999999	52.674356000000003	52.654372000000002	Школьная	0103000020E6100000010000000500000038842A357BD44A4085B53176C2534A4038842A357BD44A4042EE224C51564A40CCED5EEE93D74A4042EE224C51564A40CCED5EEE93D74A4085B53176C2534A4038842A357BD44A4085B53176C2534A40
50411	48743	53.862634	53.878903000000001	52.765900999999999	52.746699999999997	Пушкинская	0103000020E61000000100000005000000763579CA6AEE4A402BF697DD935F4A40763579CA6AEE4A40A27C410B09624A409BADBCE47FF04A40A27C410B09624A409BADBCE47FF04A402BF697DD935F4A40763579CA6AEE4A402BF697DD935F4A40
51142	48432	53.258445000000002	53.280130999999997	52.888973999999997	52.880546000000002	Школьная	0103000020E610000001000000050000004968CBB914A14A40D34F38BBB5704A404968CBB914A14A40457F68E6C9714A4042CC2555DBA34A40457F68E6C9714A4042CC2555DBA34A40D34F38BBB5704A404968CBB914A14A40D34F38BBB5704A40
51255	48258	53.877609	53.901108999999998	52.97569	52.954217999999997	Молодежная	0103000020E610000001000000050000006FD6E07D55F04A4094A0BFD0237A4A406FD6E07D55F04A406284F068E37C4A40CD902A8A57F34A406284F068E37C4A40CD902A8A57F34A4094A0BFD0237A4A406FD6E07D55F04A4094A0BFD0237A4A40
64143	58175	53.807352000000002	53.827033999999998	52.978043999999997	52.969507999999998	Новая	0103000020E610000001000000050000001B2E724F57E74A40ED9A90D6187C4A401B2E724F57E74A404606B98B307D4A400C570740DCE94A404606B98B307D4A400C570740DCE94A40ED9A90D6187C4A401B2E724F57E74A40ED9A90D6187C4A40
50547	48671	53.555957999999997	53.612606	52.840513999999999	52.824660000000002	Центральная	0103000020E610000001000000050000008BF9B9A129C74A40E12879758E694A408BF9B9A129C74A4042EA76F6956B4A40ACAA97DF69CE4A4042EA76F6956B4A40ACAA97DF69CE4A40E12879758E694A408BF9B9A129C74A40E12879758E694A40
49730	29494	53.478226999999997	53.499004999999997	52.869295000000001	52.829231	Советская	0103000020E610000001000000050000003788D68A36BD4A4029EACC3D246A4A403788D68A36BD4A40C5C9FD0E456F4A402EC55565DFBF4A40C5C9FD0E456F4A402EC55565DFBF4A4029EACC3D246A4A403788D68A36BD4A4029EACC3D246A4A40
50601	29494	53.478226999999997	53.499004999999997	52.869295000000001	52.829231	Ленина	0103000020E610000001000000050000003788D68A36BD4A4029EACC3D246A4A403788D68A36BD4A40C5C9FD0E456F4A402EC55565DFBF4A40C5C9FD0E456F4A402EC55565DFBF4A4029EACC3D246A4A403788D68A36BD4A4029EACC3D246A4A40
49886	29494	53.478226999999997	53.499004999999997	52.869295000000001	52.829231	Дружбы	0103000020E610000001000000050000003788D68A36BD4A4029EACC3D246A4A403788D68A36BD4A40C5C9FD0E456F4A402EC55565DFBF4A40C5C9FD0E456F4A402EC55565DFBF4A4029EACC3D246A4A403788D68A36BD4A4029EACC3D246A4A40
50827	18570	53.630958999999997	53.667664000000002	53.020932999999999	52.971010999999997	Дружбы	0103000020E61000000100000005000000F50EB743C3D04A403387A4164A7C4A40F50EB743C3D04A401E34BBEEAD824A40B85B920376D54A401E34BBEEAD824A40B85B920376D54A403387A4164A7C4A40F50EB743C3D04A403387A4164A7C4A40
50937	48884	53.588225999999999	53.618327999999998	52.670408000000002	52.653334000000001	Зеленая	0103000020E61000000100000005000000155454FD4ACB4A40B4AED172A0534A40155454FD4ACB4A40077DE9EDCF554A40BD19355F25CF4A40077DE9EDCF554A40BD19355F25CF4A40B4AED172A0534A40155454FD4ACB4A40B4AED172A0534A40
50332	29151	53.388942999999998	53.417492000000003	52.986491000000001	52.962045000000003	Центральная	0103000020E610000001000000050000000A815CE2C8B14A40E223624A247B4A400A815CE2C8B14A4030664B56457E4A40BB2BBB6070B54A4030664B56457E4A40BB2BBB6070B54A40E223624A247B4A400A815CE2C8B14A40E223624A247B4A40
50769	29045	53.382997000000003	53.399363999999998	52.917212999999997	52.910735000000003	Мира	0103000020E61000000100000005000000AABBB20B06B14A404A29E8F692744A40AABBB20B06B14A40A73B4F3C67754A4091990B5C1EB34A40A73B4F3C67754A4091990B5C1EB34A404A29E8F692744A40AABBB20B06B14A404A29E8F692744A40
51436	56209	53.288961	53.310107000000002	52.892310000000002	52.882019	Центральная	0103000020E61000000100000005000000E4688EACFCA44A40AEB9A3FFE5704A40E4688EACFCA44A4067F2CD3637724A405EA10F96B1A74A4067F2CD3637724A405EA10F96B1A74A40AEB9A3FFE5704A40E4688EACFCA44A40AEB9A3FFE5704A40
51139	29635	53.528488000000003	53.536267000000002	52.867305999999999	52.862091999999997	Центральная	0103000020E610000001000000050000000B2AAA7EA5C34A405512D907596E4A400B2AAA7EA5C34A40F2CF0CE2036F4A404776A565A4C44A40F2CF0CE2036F4A404776A565A4C44A405512D907596E4A400B2AAA7EA5C34A405512D907596E4A40
50334	29796	53.536375	53.56071	52.84196	52.833703	Центральная	0103000020E610000001000000050000002DB29DEFA7C44A40DEC9A7C7B66A4A402DB29DEFA7C44A4024456458C56B4A4024456458C5C74A4024456458C56B4A4024456458C5C74A40DEC9A7C7B66A4A402DB29DEFA7C44A40DEC9A7C7B66A4A40
51253	29662	53.599266	53.621023000000001	52.781182999999999	52.763236999999997	Мира	0103000020E6100000010000000500000068CD8FBFB4CC4A406F0C01C0B1614A4068CD8FBFB4CC4A407898F6CDFD634A402B8881AE7DCF4A407898F6CDFD634A402B8881AE7DCF4A406F0C01C0B1614A4068CD8FBFB4CC4A406F0C01C0B1614A40
50774	28627	53.463324	53.490633000000003	53.020381	53.002772999999998	Центральная	0103000020E61000000100000005000000D8B969334EBB4A40E9279CDD5A804A40D8B969334EBB4A40DA3A38D89B824A4050ABE80FCDBE4A40DA3A38D89B824A4050ABE80FCDBE4A40E9279CDD5A804A40D8B969334EBB4A40E9279CDD5A804A40
51140	29876	53.630671	53.663271000000002	52.825150000000001	52.811114000000003	Пушкинская	0103000020E610000001000000050000008FC4CBD3B9D04A40F4A96395D2674A408FC4CBD3B9D04A40AF25E4839E694A404FB16A10E6D44A40AF25E4839E694A404FB16A10E6D44A40F4A96395D2674A408FC4CBD3B9D04A40F4A96395D2674A40
50341	30162	53.236077000000002	53.279609999999998	52.697535000000002	52.678910000000002	Школьная	0103000020E610000001000000050000003D2B69C5379E4A40B476DB85E6564A403D2B69C5379E4A405E68AED348594A4039D1AE42CAA34A405E68AED348594A4039D1AE42CAA34A40B476DB85E6564A403D2B69C5379E4A40B476DB85E6564A40
51144	29702	53.524481000000002	53.536904999999997	52.799577999999997	52.775925999999998	Садовая	0103000020E61000000100000005000000CB2F833122C34A40DC0E0D8B51634A40CB2F833122C34A40F04C689258664A408907944DB9C44A40F04C689258664A408907944DB9C44A40DC0E0D8B51634A40CB2F833122C34A40DC0E0D8B51634A40
51143	29245	53.188358999999998	53.205382	52.883251999999999	52.864913999999999	Центральная	0103000020E610000001000000050000002174D0251C984A4020ED7F80B56E4A402174D0251C984A403410CB660E714A40F29716F5499A4A403410CB660E714A40F29716F5499A4A4020ED7F80B56E4A402174D0251C984A4020ED7F80B56E4A40
64111	45648	53.780932	53.805241000000002	52.862701000000001	52.835977	Береговая	0103000020E610000001000000050000002F336C94F5E34A40A69A594B016B4A402F336C94F5E34A40FE9C82FC6C6E4A40FD32182312E74A40FE9C82FC6C6E4A40FD32182312E74A40A69A594B016B4A402F336C94F5E34A40A69A594B016B4A40
51184	45648	53.780932	53.805241000000002	52.862701000000001	52.835977	 Школьная	0103000020E610000001000000050000002F336C94F5E34A40A69A594B016B4A402F336C94F5E34A40FE9C82FC6C6E4A40FD32182312E74A40FE9C82FC6C6E4A40FD32182312E74A40A69A594B016B4A402F336C94F5E34A40A69A594B016B4A40
50864	5582	53.830052000000002	53.853534000000003	53.023788000000003	53.008060999999998	Чулпан	0103000020E610000001000000050000005DFDD8243FEA4A40C0AF912408814A405DFDD8243FEA4A40C504357C0B834A401503249A40ED4A40C504357C0B834A401503249A40ED4A40C0AF912408814A405DFDD8243FEA4A40C0AF912408814A40
50706	5582	53.830052000000002	53.853534000000003	53.023788000000003	53.008060999999998	Восточная	0103000020E610000001000000050000005DFDD8243FEA4A40C0AF912408814A405DFDD8243FEA4A40C504357C0B834A401503249A40ED4A40C504357C0B834A401503249A40ED4A40C0AF912408814A405DFDD8243FEA4A40C0AF912408814A40
50929	28695	53.737974999999999	53.795834999999997	52.921366999999996	52.895645999999999	Школьная	0103000020E61000000100000005000000FF21FDF675DE4A4088653387A4724A40FF21FDF675DE4A408B4E965AEF754A408E01D9EBDDE54A408B4E965AEF754A408E01D9EBDDE54A4088653387A4724A40FF21FDF675DE4A4088653387A4724A40
50906	48937	53.759436000000001	53.770000000000003	52.631847999999998	52.625807999999999	Орская	0103000020E61000000100000005000000D9B3E73235E14A409FC9FE791A504A40D9B3E73235E14A4081053065E0504A40C3F5285C8FE24A4081053065E0504A40C3F5285C8FE24A409FC9FE791A504A40D9B3E73235E14A409FC9FE791A504A40
51181	22602	53.411293999999998	53.445169	52.866745999999999	52.855083999999998	Советская	0103000020E6100000010000000500000040852348A5B44A409BAA7B64736D4A4040852348A5B44A402BF86D88F16E4A40B5183C4CFBB84A402BF86D88F16E4A40B5183C4CFBB84A409BAA7B64736D4A4040852348A5B44A409BAA7B64736D4A40
51145	48838	53.264373999999997	53.306631000000003	52.664389999999997	52.653973000000001	Школьная	0103000020E61000000100000005000000D3F4D901D7A14A40C7BB2363B5534A40D3F4D901D7A14A400CE544BB0A554A404B7842AF3FA74A400CE544BB0A554A404B7842AF3FA74A40C7BB2363B5534A40D3F4D901D7A14A40C7BB2363B5534A40
50773	29512	53.444693000000001	53.468722999999997	52.892820999999998	52.886522999999997	М.Бурангулова	0103000020E610000001000000050000004CE141B3EBB84A406E13EE9579714A404CE141B3EBB84A404C1762F547724A4006F1811DFFBB4A404C1762F547724A4006F1811DFFBB4A406E13EE9579714A404CE141B3EBB84A406E13EE9579714A40
51170	46849	53.241503000000002	53.258741999999998	52.616864	52.598916000000003	 Касьянова	0103000020E610000001000000050000006571FF91E99E4A408C868C47A94C4A406571FF91E99E4A40350A4966F54E4A40020D36751EA14A40350A4966F54E4A40020D36751EA14A408C868C47A94C4A406571FF91E99E4A408C868C47A94C4A40
51252	47545	59.759112999999999	59.890914000000002	52.069412999999997	51.988112999999998	Школьная	0103000020E61000000100000005000000F67B629D2AE14D4050E09D7C7AFE4940F67B629D2AE14D4068757286E2084A4037C64E7809F24D4068757286E2084A4037C64E7809F24D4050E09D7C7AFE4940F67B629D2AE14D4050E09D7C7AFE4940
51263	56158	58.824657999999999	58.834575999999998	52.057884999999999	52.048713999999997	 Речная	0103000020E610000001000000050000004031B2648E694D40BD6DA6423C064A404031B2648E694D40E8F692C668074A406403E962D36A4D40E8F692C668074A406403E962D36A4D40BD6DA6423C064A404031B2648E694D40BD6DA6423C064A40
50427	28236	58.833632000000001	58.850394999999999	52.213690999999997	52.196781000000001	Центральная	0103000020E6100000010000000500000015731074B46A4D40B2BCAB1E30194A4015731074B46A4D408A39083A5A1B4A4049D74CBED96C4D408A39083A5A1B4A4049D74CBED96C4D40B2BCAB1E30194A4015731074B46A4D40B2BCAB1E30194A40
51095	47943	58.907609000000001	58.926357000000003	52.199623000000003	52.189725000000003	 Школьная	0103000020E6100000010000000500000013471E882C744D40E71DA7E848184A4013471E882C744D40C443183F8D194A40D9B5BDDD92764D40C443183F8D194A40D9B5BDDD92764D40E71DA7E848184A4013471E882C744D40E71DA7E848184A40
50599	28359	58.927165000000002	58.947907000000001	52.042648999999997	52.029013999999997	Кооперативный	0103000020E61000000100000005000000787FBC57AD764D40259012BBB6034A40787FBC57AD764D40821ABE8575054A4022533E0455794D40821ABE8575054A4022533E0455794D40259012BBB6034A40787FBC57AD764D40259012BBB6034A40
51475	56212	59.714708999999999	59.738819999999997	52.419837999999999	52.405517000000003	Центральная	0103000020E610000001000000050000001494A2957BDB4D406C7C26FBE7334A401494A2957BDB4D401CCF6740BD354A40BBD05CA791DE4D401CCF6740BD354A40BBD05CA791DE4D406C7C26FBE7334A401494A2957BDB4D406C7C26FBE7334A40
50558	47882	59.311464000000001	59.345680999999999	52.217294000000003	52.197504000000002	Школьный	0103000020E61000000100000005000000D0F0660DDEA74D40236AA2CF47194A40D0F0660DDEA74D40FBCE2F4AD01B4A409EEC66463FAC4D40FBCE2F4AD01B4A409EEC66463FAC4D40236AA2CF47194A40D0F0660DDEA74D40236AA2CF47194A40
50608	48150	58.872781000000003	58.911434999999997	51.890020999999997	51.876539999999999	Школьная	0103000020E61000000100000005000000FCC8AD49B76F4D4063D1747632F04940FCC8AD49B76F4D4069E04735ECF1494002B7EEE6A9744D4069E04735ECF1494002B7EEE6A9744D4063D1747632F04940FCC8AD49B76F4D4063D1747632F04940
64161	47156	58.824936999999998	58.834575999999998	52.135171	52.127265999999999	Школьная	0103000020E6100000010000000500000053211E8997694D4045F295404A104A4053211E8997694D400E2F88484D114A406403E962D36A4D400E2F88484D114A406403E962D36A4D4045F295404A104A4053211E8997694D4045F295404A104A40
51329	47156	58.824936999999998	58.834575999999998	52.135171	52.127265999999999	Рыжкова	0103000020E6100000010000000500000053211E8997694D4045F295404A104A4053211E8997694D400E2F88484D114A406403E962D36A4D400E2F88484D114A406403E962D36A4D4045F295404A104A4053211E8997694D4045F295404A104A40
50583	46271	59.653874999999999	59.677751999999998	52.000262999999997	51.988163	пер.Школьный	0103000020E6100000010000000500000004560E2DB2D34D40020F0C207CFE494004560E2DB2D34D400D33349E08004A403866D993C0D64D400D33349E08004A403866D993C0D64D40020F0C207CFE494004560E2DB2D34D40020F0C207CFE4940
51395	56196	59.414428999999998	59.434992000000001	52.413049000000001	52.401401999999997	Школьная	0103000020E61000000100000005000000CAC16C020CB54D404546072461334A40CAC16C020CB54D40A05225CADE344A40C5025FD1ADB74D40A05225CADE344A40C5025FD1ADB74D404546072461334A40CAC16C020CB54D404546072461334A40
50775	27630	59.565750000000001	59.585127	52.416614000000003	52.403858	Новая	0103000020E6100000010000000500000023DBF97E6AC84D402E1D739EB1334A4023DBF97E6AC84D402387889B53354A40D8800871E5CA4D402387889B53354A40D8800871E5CA4D402E1D739EB1334A4023DBF97E6AC84D402E1D739EB1334A40
51154	47655	59.674095999999999	59.689754000000001	52.179620999999997	52.17069	Школьная	0103000020E61000000100000005000000A52E19C748D64D408BE07F2BD9154A40A52E19C748D64D40605628D2FD164A408124ECDB49D84D40605628D2FD164A408124ECDB49D84D408BE07F2BD9154A40A52E19C748D64D408BE07F2BD9154A40
51250	27523	59.848261999999998	59.859095000000003	52.180360999999998	52.171937999999997	Степная	0103000020E61000000100000005000000433866D993EC4D4046787B1002164A40433866D993EC4D40A73CBA1116174A401D9430D3F6ED4D40A73CBA1116174A401D9430D3F6ED4D4046787B1002164A40433866D993EC4D4046787B1002164A40
50272	27176	59.879029000000003	59.926001999999997	51.978394999999999	51.949067999999997	Газовая	0103000020E61000000100000005000000289EB30584F04D400ED76A0F7BF94940289EB30584F04D40F3C81F0C3CFD4940EA03C93B87F64D40F3C81F0C3CFD4940EA03C93B87F64D400ED76A0F7BF94940289EB30584F04D400ED76A0F7BF94940
49922	27176	59.879029000000003	59.926001999999997	51.978394999999999	51.949067999999997	Вокзальная	0103000020E61000000100000005000000289EB30584F04D400ED76A0F7BF94940289EB30584F04D40F3C81F0C3CFD4940EA03C93B87F64D40F3C81F0C3CFD4940EA03C93B87F64D400ED76A0F7BF94940289EB30584F04D400ED76A0F7BF94940
50313	47831	59.360773000000002	59.388710000000003	52.382320999999997	52.365958999999997	пер. Школьный	0103000020E61000000100000005000000D12346CF2DAE4D40A35698BED72E4A40D12346CF2DAE4D4079C9FFE4EF304A4068D0D03FC1B14D4079C9FFE4EF304A4068D0D03FC1B14D40A35698BED72E4A40D12346CF2DAE4D40A35698BED72E4A40
50598	47647	59.608870000000003	59.635738000000003	52.159652999999999	52.142207999999997	 им.Кирова	0103000020E61000000100000005000000FDC1C073EFCD4D40629D2ADF33124A40FDC1C073EFCD4D40A9DA6E826F144A408869DFDC5FD14D40A9DA6E826F144A408869DFDC5FD14D40629D2ADF33124A40FDC1C073EFCD4D40629D2ADF33124A40
49733	26924	59.708537999999997	59.744191999999998	52.096038999999998	52.071416999999997	Центральная	0103000020E6100000010000000500000093FC885FB1DA4D4070B0373124094A4093FC885FB1DA4D40FD1186014B0C4A40F0F8F6AE41DF4D40FD1186014B0C4A40F0F8F6AE41DF4D4070B0373124094A4093FC885FB1DA4D4070B0373124094A40
50933	27528	59.878382000000002	59.909103999999999	52.384514000000003	52.367724000000003	Центральная	0103000020E6100000010000000500000092B245D26EF04D4027FA7C94112F4A4092B245D26EF04D40556D37C137314A40D65416855DF44D40556D37C137314A40D65416855DF44D4027FA7C94112F4A4092B245D26EF04D4027FA7C94112F4A40
50948	56131	59.956454999999998	59.981473000000001	51.937514999999998	51.925657999999999	Октябрьская	0103000020E610000001000000050000003F8C101E6DFA4D40F0A31AF67BF649403F8C101E6DFA4D403541D47D00F84940197442E8A0FD4D403541D47D00F84940197442E8A0FD4D40F0A31AF67BF649403F8C101E6DFA4D40F0A31AF67BF64940
51251	28551	58.82349	58.833416999999997	51.786136999999997	51.778604000000001	Речная	0103000020E61000000100000005000000A14ACD1E68694D407444BE4BA9E34940A14ACD1E68694D4078962023A0E4494018778368AD6A4D4078962023A0E4494018778368AD6A4D407444BE4BA9E34940A14ACD1E68694D407444BE4BA9E34940
50892	48158	58.980237000000002	58.988672999999999	51.944999000000003	51.935654	Центральная	0103000020E6100000010000000500000022AAF067787D4D40902FA182C3F7494022AAF067787D4D4059E02BBAF5F8494017B83CD68C7E4D4059E02BBAF5F8494017B83CD68C7E4D40902FA182C3F7494022AAF067787D4D40902FA182C3F74940
50429	27903	59.295160000000003	59.318786000000003	52.137974	52.116964000000003	Советская	0103000020E610000001000000050000002F8B89CDC7A54D40996725ADF80E4A402F8B89CDC7A54D4062D9CC21A9114A401A36CAFACDA84D4062D9CC21A9114A401A36CAFACDA84D40996725ADF80E4A402F8B89CDC7A54D40996725ADF80E4A40
51011	47959	58.881062999999997	58.898634000000001	52.172933	52.166277000000001	Школьная	0103000020E610000001000000050000009A5B21ACC6704D40DB89929048154A409A5B21ACC6704D4018B325AB22164A406E895C7006734D4018B325AB22164A406E895C7006734D40DB89929048154A409A5B21ACC6704D40DB89929048154A40
50923	27369	59.955241999999998	59.966031000000001	52.236700999999996	52.225647000000002	Лесная	0103000020E6100000010000000500000000E2AE5E45FA4D4063B83A00E21C4A4000E2AE5E45FA4D401AF7E6374C1E4A400AF65FE7A6FB4D401AF7E6374C1E4A400AF65FE7A6FB4D4063B83A00E21C4A4000E2AE5E45FA4D4063B83A00E21C4A40
50776	56112	58.950646999999996	58.974182999999996	52.370153999999999	52.356729999999999	Верхняя	0103000020E610000001000000050000002F8507CDAE794D4044C02154A92D4A402F8507CDAE794D40E63DCE34612F4A40DAA84E07B27C4D40E63DCE34612F4A40DAA84E07B27C4D4044C02154A92D4A402F8507CDAE794D4044C02154A92D4A40
50925	47720	59.596563000000003	59.614941999999999	52.271461000000002	52.259379000000003	Раздольная	0103000020E610000001000000050000007880272D5CCC4D407522C15433214A407880272D5CCC4D40DA91EA3BBF224A40EA77616BB6CE4D40DA91EA3BBF224A40EA77616BB6CE4D407522C15433214A407880272D5CCC4D407522C15433214A40
50645	45624	58.685383000000002	58.700861000000003	52.155979000000002	52.150204000000002	 Центральная	0103000020E61000000100000005000000001E51A1BA574D403CDD79E239134A40001E51A1BA574D4070EEAF1EF7134A405C0531D0B5594D4070EEAF1EF7134A405C0531D0B5594D403CDD79E239134A40001E51A1BA574D403CDD79E239134A40
64133	45624	58.685383000000002	58.700861000000003	52.155979000000002	52.150204000000002	 Советская	0103000020E61000000100000005000000001E51A1BA574D403CDD79E239134A40001E51A1BA574D4070EEAF1EF7134A405C0531D0B5594D4070EEAF1EF7134A405C0531D0B5594D403CDD79E239134A40001E51A1BA574D403CDD79E239134A40
50464	27402	59.771456000000001	59.809454000000002	52.237346000000002	52.216892000000001	Школьная	0103000020E61000000100000005000000C826F911BFE24D40CC61F71DC31B4A40C826F911BFE24D4010EB8D5A611E4A40E6CE4C309CE74D4010EB8D5A611E4A40E6CE4C309CE74D40CC61F71DC31B4A40C826F911BFE24D40CC61F71DC31B4A40
50240	23600	59.757271000000003	59.774428999999998	52.059108999999999	52.044566000000003	Школьная	0103000020E61000000100000005000000C89A9141EEE04D40BC41B456B4054A40C89A9141EEE04D401BF33AE290074A4078094E7D20E34D401BF33AE290074A4078094E7D20E34D40BC41B456B4054A40C89A9141EEE04D40BC41B456B4054A40
50463	26860	53.293506000000001	53.329025999999999	51.622281999999998	51.607747000000003	Октябрьская	0103000020E610000001000000050000000397C79A91A54A40FE9E58A7CACD49400397C79A91A54A40DA71C3EFA6CF494050C422861DAA4A40DA71C3EFA6CF494050C422861DAA4A40FE9E58A7CACD49400397C79A91A54A40FE9E58A7CACD4940
51248	47017	53.536473999999998	53.561563999999997	51.544015000000002	51.533579000000003	Центральная	0103000020E61000000100000005000000C093162EABC44A408C6A11514CC44940C093162EABC44A4048C49448A2C54940334E4354E1C74A4048C49448A2C54940334E4354E1C74A408C6A11514CC44940C093162EABC44A408C6A11514CC44940
49823	26555	53.142491	53.184863999999997	51.600938999999997	51.584763000000002	 Бокова	0103000020E61000000100000005000000B77C24253D924A4097749483D9CA4940B77C24253D924A400AF2B391EBCC4940971AA19FA9974A400AF2B391EBCC4940971AA19FA9974A4097749483D9CA4940B77C24253D924A4097749483D9CA4940
50473	56071	53.022862000000003	54.412923999999997	51.783200000000001	51.162838999999998	Школьная	0103000020E610000001000000050000001C295B24ED824A40B5C189E8D79449401C295B24ED824A40151DC9E53FE44940E3DD91B1DA344B40151DC9E53FE44940E3DD91B1DA344B40B5C189E8D79449401C295B24ED824A40B5C189E8D7944940
50629	56085	53.604179999999999	53.64667	51.609906000000002	51.591059000000001	Мира	0103000020E61000000100000005000000DA722EC555CD4A40D48041D2A7CB4940DA722EC555CD4A402DD1596611CE4940F4A62215C6D24A402DD1596611CE4940F4A62215C6D24A40D48041D2A7CB4940DA722EC555CD4A40D48041D2A7CB4940
50927	47413	53.267266999999997	53.284576999999999	51.617780000000003	51.604978000000003	Школьная	0103000020E61000000100000005000000672618CE35A24A4056664AEB6FCD4940672618CE35A24A40BB0F406A13CF4940CE18E6046DA44A40BB0F406A13CF4940CE18E6046DA44A4056664AEB6FCD4940672618CE35A24A4056664AEB6FCD4940
49822	47214	53.671688000000003	53.706766999999999	51.367713999999999	51.348011999999997	площадь Победы	0103000020E61000000100000005000000CE8E54DFF9D54A40CA4E3FA88BAC4940CE8E54DFF9D54A4003249A4011AF49402E724F5777DA4A4003249A4011AF49402E724F5777DA4A40CA4E3FA88BAC4940CE8E54DFF9D54A40CA4E3FA88BAC4940
51244	47050	53.738782999999998	53.765517000000003	51.543762999999998	51.531495	Московская	0103000020E610000001000000050000009EEBFB7090DE4A40677E350708C449409EEBFB7090DE4A402EE3A6069AC549401AC40776FCE14A402EE3A6069AC549401AC40776FCE14A40677E350708C449409EEBFB7090DE4A40677E350708C44940
49913	47090	53.890006	53.933439	51.623769000000003	51.598880999999999	Советская	0103000020E61000000100000005000000349F73B7EBF14A400F99F221A8CC4940349F73B7EBF14A401BA19FA9D7CF4940CDE7DCED7AF74A401BA19FA9D7CF4940CDE7DCED7AF74A400F99F221A8CC4940349F73B7EBF14A400F99F221A8CC4940
50465	26711	53.376421000000001	53.407853000000003	51.617758000000002	51.605319000000001	Советская	0103000020E61000000100000005000000894336902EB04A40DF52CE177BCD4940894336902EB04A40D36BB3B112CF4940AA49F08634B44A40D36BB3B112CF4940AA49F08634B44A40DF52CE177BCD4940894336902EB04A40DF52CE177BCD4940
50922	47399	53.052812000000003	53.101851000000003	51.585451999999997	51.572997999999998	Центральная	0103000020E610000001000000050000000E6B2A8BC2864A4032569BFF57C949400E6B2A8BC2864A405BB05417F0CA49404F081D74098D4A405BB05417F0CA49404F081D74098D4A4032569BFF57C949400E6B2A8BC2864A4032569BFF57C94940
50596	47039	53.639358000000001	53.675623000000002	51.544676000000003	51.526155000000003	Ленина	0103000020E61000000100000005000000CE37A27BD6D14A403ED00A0C59C34940CE37A27BD6D14A40437573F1B7C5494074B680D07AD64A40437573F1B7C5494074B680D07AD64A403ED00A0C59C34940CE37A27BD6D14A403ED00A0C59C34940
49943	14488	54.125337000000002	54.181572000000003	51.610247000000001	51.576138999999998	Советская	0103000020E6100000010000000500000048FDF50A0B104B409E7939ECBEC9494048FDF50A0B104B40B6BDDD921CCE494046EF54C03D174B40B6BDDD921CCE494046EF54C03D174B409E7939ECBEC9494048FDF50A0B104B409E7939ECBEC94940
49709	14488	54.125337000000002	54.181572000000003	51.610247000000001	51.576138999999998	России	0103000020E6100000010000000500000048FDF50A0B104B409E7939ECBEC9494048FDF50A0B104B40B6BDDD921CCE494046EF54C03D174B40B6BDDD921CCE494046EF54C03D174B409E7939ECBEC9494048FDF50A0B104B409E7939ECBEC94940
49711	14488	54.125337000000002	54.181572000000003	51.610247000000001	51.576138999999998	Липова	0103000020E6100000010000000500000048FDF50A0B104B409E7939ECBEC9494048FDF50A0B104B40B6BDDD921CCE494046EF54C03D174B40B6BDDD921CCE494046EF54C03D174B409E7939ECBEC9494048FDF50A0B104B409E7939ECBEC94940
49821	25979	53.874752000000001	53.953651000000001	51.550938000000002	51.522249000000002	Советская	0103000020E61000000100000005000000280EA0DFF7EF4A4032AF230ED9C24940280EA0DFF7EF4A40D40FEA2285C649401B66683C11FA4A40D40FEA2285C649401B66683C11FA4A4032AF230ED9C24940280EA0DFF7EF4A4032AF230ED9C24940
51372	25979	53.874752000000001	53.953651000000001	51.550938000000002	51.522249000000002	Кузнецова	0103000020E61000000100000005000000280EA0DFF7EF4A4032AF230ED9C24940280EA0DFF7EF4A40D40FEA2285C649401B66683C11FA4A40D40FEA2285C649401B66683C11FA4A4032AF230ED9C24940280EA0DFF7EF4A4032AF230ED9C24940
49738	25675	53.363027000000002	53.421534000000001	51.542839000000001	51.513826000000002	Токмаковская	0103000020E61000000100000005000000524832AB77AE4A40D1EAE40CC5C14940524832AB77AE4A4026FF93BF7BC5494077137CD3F4B54A4026FF93BF7BC5494077137CD3F4B54A40D1EAE40CC5C14940524832AB77AE4A40D1EAE40CC5C14940
50003	25675	53.363027000000002	53.421534000000001	51.542839000000001	51.513826000000002	Октябрьская	0103000020E61000000100000005000000524832AB77AE4A40D1EAE40CC5C14940524832AB77AE4A4026FF93BF7BC5494077137CD3F4B54A4026FF93BF7BC5494077137CD3F4B54A40D1EAE40CC5C14940524832AB77AE4A40D1EAE40CC5C14940
49820	25675	53.363027000000002	53.421534000000001	51.542839000000001	51.513826000000002	 Пионерская	0103000020E61000000100000005000000524832AB77AE4A40D1EAE40CC5C14940524832AB77AE4A4026FF93BF7BC5494077137CD3F4B54A4026FF93BF7BC5494077137CD3F4B54A40D1EAE40CC5C14940524832AB77AE4A40D1EAE40CC5C14940
50335	26507	53.575479000000001	53.603631999999998	51.421669000000001	51.410868000000001	Советская	0103000020E610000001000000050000007444BE4BA9C94A40897C975297B449407444BE4BA9C94A40575EF23FF9B54940D76839D043CD4A40575EF23FF9B54940D76839D043CD4A40897C975297B449407444BE4BA9C94A40897C975297B44940
50928	26572	53.222019000000003	53.234119	51.604508000000003	51.597693999999997	Центральная	0103000020E610000001000000050000009A0B5C1E6B9C4A40F981AB3C81CC49409A0B5C1E6B9C4A40CF15A58460CD4940A52F849CF79D4A40CF15A58460CD4940A52F849CF79D4A40F981AB3C81CC49409A0B5C1E6B9C4A40F981AB3C81CC4940
50004	47123	54.225301999999999	54.244264999999999	51.43956	51.423724999999997	Школьная	0103000020E6100000010000000500000098DC28B2D61C4B40B1BFEC9E3CB6494098DC28B2D61C4B409C50888043B849405A475513441F4B409C50888043B849405A475513441F4B40B1BFEC9E3CB6494098DC28B2D61C4B40B1BFEC9E3CB64940
50760	25302	59.946986000000003	59.965536999999998	50.759601000000004	50.745463000000001	переулок Ярославский	0103000020E610000001000000050000008BE255D636F94D4064B0E2546B5F49408BE255D636F94D402481069B3A614940FA0967B796FB4D402481069B3A614940FA0967B796FB4D4064B0E2546B5F49408BE255D636F94D4064B0E2546B5F4940
51328	19978	58.742840000000001	58.762953000000003	51.014482999999998	51.006759000000002	Центральная	0103000020E6100000010000000500000090149161155F4D4012FA997ADD80494090149161155F4D408AAC3594DA8149404BB1A371A8614D408AAC3594DA8149404BB1A371A8614D4012FA997ADD80494090149161155F4D4012FA997ADD804940
51259	46740	59.510638999999998	59.534489000000001	50.709969999999998	50.695776000000002	Центральная	0103000020E61000000100000005000000F487669E5CC14D40BDAB1E300F594940F487669E5CC14D401092054CE05A49402F89B3226AC44D401092054CE05A49402F89B3226AC44D40BDAB1E300F594940F487669E5CC14D40BDAB1E300F594940
50765	25129	59.520412	59.556182999999997	50.861203000000003	50.840805000000003	переулок Торговый	0103000020E61000000100000005000000153944DC9CC24D401AA88C7F9F6B4940153944DC9CC24D40CA1B60E63B6E4940ABCB290131C74D40CA1B60E63B6E4940ABCB290131C74D401AA88C7F9F6B4940153944DC9CC24D401AA88C7F9F6B4940
51241	24684	59.055399000000001	59.071758000000003	50.714367000000003	50.703467000000003	Первая	0103000020E61000000100000005000000959D7E5017874D405A68E7340B5A4940959D7E5017874D40BB2BBB60705B4940FA9CBB5D2F894D40BB2BBB60705B4940FA9CBB5D2F894D405A68E7340B5A4940959D7E5017874D405A68E7340B5A4940
50454	24910	58.786417	58.806099000000003	51.017502999999998	51.004576999999998	Новая	0103000020E610000001000000050000005C02F04FA9644D402AA8A8FA958049405C02F04FA9644D407B4ACE893D8249404E2B85402E674D407B4ACE893D8249404E2B85402E674D402AA8A8FA958049405C02F04FA9644D402AA8A8FA95804940
51381	56188	59.244000999999997	59.25797	50.946956	50.925834999999999	Школьная	0103000020E610000001000000050000007C98BD6C3B9F4D40FF3EE3C2817649407C98BD6C3B9F4D402060ADDA35794940B0AC342905A14D402060ADDA35794940B0AC342905A14D40FF3EE3C2817649407C98BD6C3B9F4D40FF3EE3C281764940
51242	24935	58.769035000000002	58.799639999999997	50.941349000000002	50.925902999999998	Школьная	0103000020E610000001000000050000005C3D27BD6F624D40572250FD837649405C3D27BD6F624D40A88FC01F7E7849406649809A5A664D40A88FC01F7E7849406649809A5A664D40572250FD837649405C3D27BD6F624D40572250FD83764940
50771	25206	59.708798000000002	59.725200999999998	50.705817000000003	50.693401999999999	Конторская	0103000020E6100000010000000500000030BC92E4B9DA4D40917D9065C158494030BC92E4B9DA4D40FDFA2136585A49406403E962D3DC4D40FDFA2136585A49406403E962D3DC4D40917D9065C158494030BC92E4B9DA4D40917D9065C1584940
51135	24594	59.227023000000003	59.262030000000003	50.864443000000001	50.845996999999997	Школьная	0103000020E610000001000000050000004C38F4160F9D4D40CEC133A1496C49404C38F4160F9D4D40C9207711A66E49401349F4328AA14D40C9207711A66E49401349F4328AA14D40CEC133A1496C49404C38F4160F9D4D40CEC133A1496C4940
51343	56168	59.083238000000001	59.097171000000003	50.918669000000001	50.905016000000003	Набережная	0103000020E6100000010000000500000069E4F38AA78A4D40AA2D7590D773494069E4F38AA78A4D40AD6C1FF296754940508F6D19708C4D40AD6C1FF296754940508F6D19708C4D40AA2D7590D773494069E4F38AA78A4D40AA2D7590D7734940
50975	56134	59.595529999999997	59.621428000000002	50.937603000000003	50.919469999999997	Школьная	0103000020E61000000100000005000000B8E4B8533ACC4D4099D36531B1754940B8E4B8533ACC4D40D5D0066003784940CB68E4F38ACF4D40D5D0066003784940CB68E4F38ACF4D4099D36531B1754940B8E4B8533ACC4D4099D36531B1754940
49729	25307	59.515166000000001	59.571643000000002	50.793446000000003	50.727699999999999	торговая площадь	0103000020E610000001000000050000006D01A1F5F0C14D404CA60A46255D49406D01A1F5F0C14D402E9276A38F65494061FE0A992BC94D402E9276A38F65494061FE0A992BC94D404CA60A46255D49406D01A1F5F0C14D404CA60A46255D4940
50597	25307	59.515166000000001	59.571643000000002	50.793446000000003	50.727699999999999	Стахановская	0103000020E610000001000000050000006D01A1F5F0C14D404CA60A46255D49406D01A1F5F0C14D402E9276A38F65494061FE0A992BC94D402E9276A38F65494061FE0A992BC94D404CA60A46255D49406D01A1F5F0C14D404CA60A46255D4940
49728	25307	59.515166000000001	59.571643000000002	50.793446000000003	50.727699999999999	Рабочая	0103000020E610000001000000050000006D01A1F5F0C14D404CA60A46255D49406D01A1F5F0C14D402E9276A38F65494061FE0A992BC94D402E9276A38F65494061FE0A992BC94D404CA60A46255D49406D01A1F5F0C14D404CA60A46255D4940
49912	25307	59.515166000000001	59.571643000000002	50.793446000000003	50.727699999999999	Куйбышева	0103000020E610000001000000050000006D01A1F5F0C14D404CA60A46255D49406D01A1F5F0C14D402E9276A38F65494061FE0A992BC94D402E9276A38F65494061FE0A992BC94D404CA60A46255D49406D01A1F5F0C14D404CA60A46255D4940
50766	25307	59.515166000000001	59.571643000000002	50.793446000000003	50.727699999999999	Весенняя	0103000020E610000001000000050000006D01A1F5F0C14D404CA60A46255D49406D01A1F5F0C14D402E9276A38F65494061FE0A992BC94D402E9276A38F65494061FE0A992BC94D404CA60A46255D49406D01A1F5F0C14D404CA60A46255D4940
50468	25307	59.515166000000001	59.571643000000002	50.793446000000003	50.727699999999999	 осипенко	0103000020E610000001000000050000006D01A1F5F0C14D404CA60A46255D49406D01A1F5F0C14D402E9276A38F65494061FE0A992BC94D402E9276A38F65494061FE0A992BC94D404CA60A46255D49406D01A1F5F0C14D404CA60A46255D4940
50546	24504	59.313718999999999	59.344647999999999	50.873958999999999	50.846269999999997	Школьная	0103000020E610000001000000050000002191B6F127A84D40FFCA4A93526C49402191B6F127A84D40BE8575E3DD6F4940DF50F86C1DAC4D40BE8575E3DD6F4940DF50F86C1DAC4D40FFCA4A93526C49402191B6F127A84D40FFCA4A93526C4940
50458	24775	59.330392000000003	59.341746000000001	50.882221999999999	50.876806000000002	Газовиков	0103000020E61000000100000005000000166EF9484AAA4D40E277D32D3B704940166EF9484AAA4D40E6E786A6EC704940F8C43A55BEAB4D40E6E786A6EC704940F8C43A55BEAB4D40E277D32D3B704940166EF9484AAA4D40E277D32D3B704940
51134	24691	59.283410000000003	59.312128999999999	50.761208000000003	50.742699000000002	Центральная	0103000020E6100000010000000500000000AE64C746A44D40CEE2C5C2105F494000AE64C746A44D400FBA84436F6149400C91D3D7F3A74D400FBA84436F6149400C91D3D7F3A74D40CEE2C5C2105F494000AE64C746A44D40CEE2C5C2105F4940
51137	24795	59.706040000000002	59.744264000000001	50.834302999999998	50.824545999999998	Набережная	0103000020E610000001000000050000007CD5CA845FDA4D4018062CB98A6949407CD5CA845FDA4D4033FAD170CA6A49408ACBF10A44DF4D4033FAD170CA6A49408ACBF10A44DF4D4018062CB98A6949407CD5CA845FDA4D4018062CB98A694940
50921	24795	59.706040000000002	59.744264000000001	50.834302999999998	50.824545999999998	Молодёжная	0103000020E610000001000000050000007CD5CA845FDA4D4018062CB98A6949407CD5CA845FDA4D4033FAD170CA6A49408ACBF10A44DF4D4033FAD170CA6A49408ACBF10A44DF4D4018062CB98A6949407CD5CA845FDA4D4018062CB98A694940
50117	56052	59.097036000000003	59.126510000000003	51.065928999999997	51.038978999999998	Клубная	0103000020E610000001000000050000007044F7AC6B8C4D408A1D8D43FD8449407044F7AC6B8C4D40D26D895C70884940F94ECC7A31904D40D26D895C70884940F94ECC7A31904D408A1D8D43FD8449407044F7AC6B8C4D408A1D8D43FD844940
50770	46457	59.249623999999997	59.268965000000001	50.799185000000001	50.785411000000003	Школьная	0103000020E61000000100000005000000FA25E2ADF39F4D409775FF5888644940FA25E2ADF39F4D40153AAFB14B6649406362F3716DA24D40153AAFB14B6649406362F3716DA24D409775FF5888644940FA25E2ADF39F4D409775FF5888644940
50762	24983	59.041682000000002	59.052812000000003	51.002637999999997	50.995978000000001	 Молодёжная	0103000020E610000001000000050000007B6AF5D555854D408BC404357C7F49407B6AF5D555854D4009DD2571568049400E6B2A8BC2864D4009DD2571568049400E6B2A8BC2864D408BC404357C7F49407B6AF5D555854D408BC404357C7F4940
49942	56046	55.150899000000003	55.196218999999999	51.961750000000002	51.938969	Советская	0103000020E61000000100000005000000E3FF8EA850934B409A7ADD2230F84940E3FF8EA850934B40C976BE9F1AFB49404AED45B41D994B40C976BE9F1AFB49404AED45B41D994B409A7ADD2230F84940E3FF8EA850934B409A7ADD2230F84940
51014	48178	52.823884999999997	52.844493	53.021566999999997	53.011307000000002	Старохуторская	0103000020E610000001000000050000001D554D1075694A40A29BFD8172814A401D554D1075694A401FD61BB5C2824A40B859BC58186C4A401FD61BB5C2824A40B859BC58186C4A40A29BFD8172814A401D554D1075694A40A29BFD8172814A40
51215	46299	52.922421	52.943702000000002	53.047088000000002	53.029528999999997	Центральная	0103000020E6100000010000000500000062122EE411764A404CA4349BC7834A4062122EE411764A405C04C6FA06864A40BC95253ACB784A405C04C6FA06864A40BC95253ACB784A404CA4349BC7834A4062122EE411764A404CA4349BC7834A40
50768	46338	53.075108	53.095759999999999	53.069667000000003	53.049919000000003	Степная	0103000020E6100000010000000500000080D591239D894A407A39ECBE63864A4080D591239D894A40234E27D9EA884A40EA211ADD418C4A40234E27D9EA884A40EA211ADD418C4A407A39ECBE63864A4080D591239D894A407A39ECBE63864A40
50245	24054	53.047727000000002	53.079949999999997	53.147007000000002	53.130541999999998	Майская	0103000020E610000001000000050000006F1118EB1B864A409160AA99B5904A406F1118EB1B864A403CA41820D1924A4058A835CD3B8A4A403CA41820D1924A4058A835CD3B8A4A409160AA99B5904A406F1118EB1B864A409160AA99B5904A40
51213	23954	52.914012999999997	52.965018999999998	52.823849000000003	52.804538000000001	Строительная	0103000020E61000000100000005000000368FC360FE744A40D331E719FB664A40368FC360FE744A40D1EB4FE273694A4062821ABE857B4A40D1EB4FE273694A4062821ABE857B4A40D331E719FB664A40368FC360FE744A40D331E719FB664A40
50767	46304	53.282528999999997	53.305813000000001	53.012141	52.993445000000001	Центральная	0103000020E61000000100000005000000F69507E929A44A40F7AFAC34297F4A40F69507E929A44A406AF816D68D814A4088D860E124A74A406AF816D68D814A4088D860E124A74A40F7AFAC34297F4A40F69507E929A44A40F7AFAC34297F4A40
50688	56099	53.022269000000001	53.051976000000003	52.952188999999997	52.938118000000003	Первомайская	0103000020E61000000100000005000000795BE9B5D9824A40FCE4284014784A40795BE9B5D9824A40334E4354E1794A40A5164A26A7864A40334E4354E1794A40A5164A26A7864A40FCE4284014784A40795BE9B5D9824A40FCE4284014784A40
51138	24098	52.924621999999999	52.938851999999997	53.109309000000003	53.094078000000003	Молодежная	0103000020E61000000100000005000000C09481035A764A40F5A276BF0A8C4A40C09481035A764A4049145AD6FD8D4A4060E4654D2C784A4049145AD6FD8D4A4060E4654D2C784A40F5A276BF0A8C4A40C09481035A764A40F5A276BF0A8C4A40
64942	17882	53.054285	53.089390999999999	52.802076999999997	52.784162000000002	Ветеранов	0103000020E61000000100000005000000E9D495CFF2864A400B62A06B5F644A40E9D495CFF2864A40D8EF8975AA664A4043C70E2A718B4A40D8EF8975AA664A4043C70E2A718B4A400B62A06B5F644A40E9D495CFF2864A400B62A06B5F644A40
50680	46096	52.776795	52.792552000000001	53.108308999999998	53.090319999999998	Сеннореченская	0103000020E610000001000000050000002159C0046E634A405D16139B8F8B4A402159C0046E634A40656EBE11DD8D4A4090300C5872654A40656EBE11DD8D4A4090300C5872654A405D16139B8F8B4A402159C0046E634A405D16139B8F8B4A40
50637	56090	53.020302000000001	53.064086000000003	53.023674	53.013609000000002	 Мира	0103000020E610000001000000050000008E05854199824A4034F790F0BD814A408E05854199824A40FCE1E7BF07834A40D41055F833884A40FCE1E7BF07834A40D41055F833884A4034F790F0BD814A408E05854199824A4034F790F0BD814A40
50695	49499	53.113959999999999	53.136507999999999	52.874084000000003	52.856465	Советская	0103000020E61000000100000005000000AD86C43D968E4A40969526A5A06D4A40AD86C43D968E4A407BFA08FCE16F4A4039D2191879914A407BFA08FCE16F4A4039D2191879914A40969526A5A06D4A40AD86C43D968E4A40969526A5A06D4A40
51246	24011	52.815629999999999	52.830235999999999	52.790512	52.779020000000003	Школьная	0103000020E6100000010000000500000078D1579066684A40087767EDB6634A4078D1579066684A403B8C497F2F654A401EFB592C456A4A403B8C497F2F654A401EFB592C456A4A40087767EDB6634A4078D1579066684A40087767EDB6634A40
50809	47232	52.937702000000002	52.942005000000002	53.102080999999998	53.092553000000002	Зеленая	0103000020E6100000010000000500000068B27F9E06784A40C712D6C6D88B4A4068B27F9E06784A4080457EFD108D4A4091D5AD9E93784A4080457EFD108D4A4091D5AD9E93784A40C712D6C6D88B4A4068B27F9E06784A40C712D6C6D88B4A40
50481	56074	52.72401	52.744850999999997	52.959642000000002	52.942286000000003	переулок Центральный	0103000020E610000001000000050000000DFD135CAC5C4A4045BDE0D39C784A400DFD135CAC5C4A401CEF8E8CD57A4A404AB20E47575F4A401CEF8E8CD57A4A404AB20E47575F4A4045BDE0D39C784A400DFD135CAC5C4A4045BDE0D39C784A40
51225	46010	53.147421999999999	53.165244999999999	52.917050000000003	52.912070999999997	Озерная	0103000020E61000000100000005000000FF5A5EB9DE924A40A45016BEBE744A40FF5A5EB9DE924A40FE65F7E461754A40EC6987BF26954A40FE65F7E461754A40EC6987BF26954A40A45016BEBE744A40FF5A5EB9DE924A40A45016BEBE744A40
51136	23712	52.963177999999999	52.995885999999999	53.021712999999998	53.012650000000001	Шевченко	0103000020E61000000100000005000000041DAD6A497B4A40AF25E4839E814A40041DAD6A497B4A40F372D87DC7824A40AA454431797F4A40F372D87DC7824A40AA454431797F4A40AF25E4839E814A40041DAD6A497B4A40AF25E4839E814A40
49930	48869	52.827910000000003	52.894815999999999	52.929080999999996	52.910936	Юбилейная	0103000020E61000000100000005000000040473F4F8694A40E15F048D99744A40040473F4F8694A40E02A4F20EC764A4001F8A75489724A40E02A4F20EC764A4001F8A75489724A40E15F048D99744A40040473F4F8694A40E15F048D99744A40
49967	48869	52.827910000000003	52.894815999999999	52.929080999999996	52.910936	 Советская	0103000020E61000000100000005000000040473F4F8694A40E15F048D99744A40040473F4F8694A40E02A4F20EC764A4001F8A75489724A40E02A4F20EC764A4001F8A75489724A40E15F048D99744A40040473F4F8694A40E15F048D99744A40
49767	47571	52.799999	52.805649000000003	53.053102000000003	53.047359	Володарского	0103000020E6100000010000000500000096EA025E66664A40EC1516DC0F864A4096EA025E66664A4015ADDC0BCC864A400E87A5811F674A4015ADDC0BCC864A400E87A5811F674A40EC1516DC0F864A4096EA025E66664A40EC1516DC0F864A40
50677	56098	53.056980000000003	53.089112999999998	52.960559000000003	52.947972999999998	Советская	0103000020E610000001000000050000005743E21E4B874A40D93EE42D57794A405743E21E4B874A407270E998F37A4A400053060E688B4A407270E998F37A4A400053060E688B4A40D93EE42D57794A405743E21E4B874A40D93EE42D57794A40
81097	40525	53.303576999999997	53.340972999999998	53.088172999999998	53.069310000000002	 Центральная	0103000020E61000000100000005000000AD68739CDBA64A4094A46B26DF884A40AD68739CDBA64A40F2B1BB40498B4A40D5E8D500A5AB4A40F2B1BB40498B4A40D5E8D500A5AB4A4094A46B26DF884A40AD68739CDBA64A4094A46B26DF884A40
51080	23916	52.959854	52.988734999999998	52.946334	52.939323000000002	Новая	0103000020E61000000100000005000000A777F17EDC7A4A40B8B06EBC3B784A40A777F17EDC7A4A40E38BF67821794A408DB454DE8E7E4A40E38BF67821794A408DB454DE8E7E4A40B8B06EBC3B784A40A777F17EDC7A4A40B8B06EBC3B784A40
51178	45552	57.859706000000003	57.874654	51.247722000000003	51.238515	Центральная	0103000020E610000001000000050000006616A1D80AEE4C407F4DD6A8879E49406616A1D80AEE4C40F73FC05AB59F494065A88AA9F4EF4C40F73FC05AB59F494065A88AA9F4EF4C407F4DD6A8879E49406616A1D80AEE4C407F4DD6A8879E4940
50918	45372	58.115079000000001	58.138596999999997	51.405171000000003	51.394022	Ленина	0103000020E610000001000000050000006BBA9EE8BA0E4D40C7F319506FB249406BBA9EE8BA0E4D40D124B1A4DCB349406F29E78BBD114D40D124B1A4DCB349406F29E78BBD114D40C7F319506FB249406BBA9EE8BA0E4D40C7F319506FB24940
51075	49455	58.628430000000002	58.661416000000003	51.596206000000002	51.586286000000001	Нижняя	0103000020E61000000100000005000000A3E9EC6470504D40240D6E6B0BCB4940A3E9EC6470504D40E9D66B7A50CC49408C868C47A9544D40E9D66B7A50CC49408C868C47A9544D40240D6E6B0BCB4940A3E9EC6470504D40240D6E6B0BCB4940
50888	22328	58.167369999999998	58.191274	51.316785000000003	51.301487999999999	Молодежная	0103000020E610000001000000050000006F2A52616C154D407711A62897A649406F2A52616C154D40836E2F698CA849409D499BAA7B184D40836E2F698CA849409D499BAA7B184D407711A62897A649406F2A52616C154D407711A62897A64940
51103	49429	58.604095000000001	58.619222999999998	51.644565	51.633436000000003	Центральная	0103000020E61000000100000005000000AC5626FC524D4D40F60D4C6E14D14940AC5626FC524D4D40B8921D1B81D249402BF702B3424F4D40B8921D1B81D249402BF702B3424F4D40F60D4C6E14D14940AC5626FC524D4D40F60D4C6E14D14940
50679	22158	58.101101	58.120406000000003	51.450927	51.441063999999997	Дальняя	0103000020E61000000100000005000000E44BA8E0F00C4D40B2B8FFC874B84940E44BA8E0F00C4D4013F1D6F9B7B94940001FBC76690F4D4013F1D6F9B7B94940001FBC76690F4D40B2B8FFC874B84940E44BA8E0F00C4D40B2B8FFC874B84940
67057	58937	58.444643999999997	58.461019999999998	51.404294	51.387773000000003	улица Молодежная	0103000020E610000001000000050000006A2E3718EA384D40CBA2B08BA2B149406A2E3718EA384D4009FCE1E7BFB34940A5660FB4023B4D4009FCE1E7BFB34940A5660FB4023B4D40CBA2B08BA2B149406A2E3718EA384D40CBA2B08BA2B14940
50352	21880	58.397069000000002	58.412376000000002	51.347658000000003	51.330191999999997	Центральная	0103000020E61000000100000005000000B2A03028D3324D404EB340BB43AA4940B2A03028D3324D40AD18AE0E80AC4940E1D39CBCC8344D40AD18AE0E80AC4940E1D39CBCC8344D404EB340BB43AA4940B2A03028D3324D404EB340BB43AA4940
51092	49548	58.416238999999997	58.441885999999997	51.538201000000001	51.525258000000001	Школьная	0103000020E61000000100000005000000ED28CE5147354D402FFB75A73BC34940ED28CE5147354D4056D636C5E3C44940B6476FB88F384D4056D636C5E3C44940B6476FB88F384D402FFB75A73BC34940ED28CE5147354D402FFB75A73BC34940
51377	56187	58.682679	58.698041000000003	51.434899999999999	51.426088999999997	улица Молодежная	0103000020E610000001000000050000003F55850662574D40B91798158AB649403F55850662574D40E4839ECDAAB749403222516859594D40E4839ECDAAB749403222516859594D40B91798158AB649403F55850662574D40B91798158AB64940
50649	46871	58.390160999999999	58.400841999999997	51.604866000000001	51.579518999999998	Степная	0103000020E610000001000000050000005B96AFCBF0314D408F34B8AD2DCA49405B96AFCBF0314D402E3BC43F6CCD49407E6E68CA4E334D402E3BC43F6CCD49407E6E68CA4E334D408F34B8AD2DCA49405B96AFCBF0314D408F34B8AD2DCA4940
51102	22422	58.157794000000003	58.180306000000002	51.652130999999997	51.629075	Школьная	0103000020E61000000100000005000000A5C0029832144D4098DD938785D04940A5C0029832144D4098DA520779D34940E4A25A4414174D4098DA520779D34940E4A25A4414174D4098DD938785D04940A5C0029832144D4098DD938785D04940
50330	49595	58.330603000000004	58.370173999999999	51.653874999999999	51.623176999999998	Школьная	0103000020E61000000100000005000000D17AF832512A4D40484F9143C4CF4940D17AF832512A4D4004560E2DB2D349402DEA93DC612F4D4004560E2DB2D349402DEA93DC612F4D40484F9143C4CF4940D17AF832512A4D40484F9143C4CF4940
51232	45537	58.146044000000003	58.177906999999998	51.537785999999997	51.518465999999997	Школьная	0103000020E6100000010000000500000076E3DD91B1124D40410B09185DC2494076E3DD91B1124D40921FF12BD6C449405F5D15A8C5164D40921FF12BD6C449405F5D15A8C5164D40410B09185DC2494076E3DD91B1124D40410B09185DC24940
50920	22153	58.144337	58.167656999999998	51.412272000000002	51.395927	Новая	0103000020E61000000100000005000000274D83A279124D403C4D66BCADB24940274D83A279124D403C873254C5B4494005F9D9C875154D403C873254C5B4494005F9D9C875154D403C4D66BCADB24940274D83A279124D403C4D66BCADB24940
51210	21494	58.660716000000001	58.674855000000001	51.565871999999999	51.558951999999998	Центральная	0103000020E61000000100000005000000D3F8855792544D40530438BD8BC74940D3F8855792544D406EDC627E6EC8494063450DA661564D406EDC627E6EC8494063450DA661564D40530438BD8BC74940D3F8855792544D40530438BD8BC74940
50889	22246	58.190114999999999	58.203608000000003	51.39405	51.385243000000003	Школьная	0103000020E6100000010000000500000051BD35B055184D40A80183A44FB1494051BD35B055184D40917EFB3A70B249401C9AB2D30F1A4D40917EFB3A70B249401C9AB2D30F1A4D40A80183A44FB1494051BD35B055184D40A80183A44FB14940
51365	56180	58.036701000000001	58.059994000000003	51.391274000000003	51.375191999999998	Новостройка	0103000020E61000000100000005000000815D4D9EB2044D4044DC9C4A06B04940815D4D9EB2044D4037E3344415B2494066FA25E2AD074D4037E3344415B2494066FA25E2AD074D4044DC9C4A06B04940815D4D9EB2044D4044DC9C4A06B04940
50263	21578	58.711066000000002	58.736973999999996	51.496665	51.472642999999998	Школьная	0103000020E6100000010000000500000016A6EF35045B4D4077D7D9907FBC494016A6EF35045B4D40AF08FEB792BF49404B00FE29555E4D40AF08FEB792BF49404B00FE29555E4D4077D7D9907FBC494016A6EF35045B4D4077D7D9907FBC4940
50876	21905	58.419742999999997	58.445945999999999	51.518785999999999	51.503684999999997	Центральная	0103000020E61000000100000005000000CADC7C23BA354D402D3E05C078C04940CADC7C23BA354D40B3CF639467C2494019E42EC214394D40B3CF639467C2494019E42EC214394D402D3E05C078C04940CADC7C23BA354D402D3E05C078C04940
51008	49591	58.277970000000003	58.292406	51.465601999999997	51.450679999999998	Школьная	0103000020E6100000010000000500000073A25D8594234D400B7BDAE1AFB9494073A25D8594234D40E179A9D898BB4940BC934F8F6D254D40E179A9D898BB4940BC934F8F6D254D400B7BDAE1AFB9494073A25D8594234D400B7BDAE1AFB94940
51239	22412	58.002744999999997	58.043573000000002	51.295434	51.280540000000002	Новостройка	0103000020E610000001000000050000001F9DBAF259004D40249C16BCE8A349401F9DBAF259004D40301004C8D0A549408BFED0CC93054D40301004C8D0A549408BFED0CC93054D40249C16BCE8A349401F9DBAF259004D40249C16BCE8A34940
51340	10984	57.937275	57.955547000000003	51.139741999999998	51.132728999999998	Уральская	0103000020E61000000100000005000000E02D90A0F8F74C408A1D8D43FD904940E02D90A0F8F74C4056F0DB10E39149403D65355D4FFA4C4056F0DB10E39149403D65355D4FFA4C408A1D8D43FD904940E02D90A0F8F74C408A1D8D43FD904940
51209	22287	58.292819999999999	58.307713999999997	51.364063999999999	51.355966000000002	Школьная	0103000020E61000000100000005000000AFCE31207B254D40753E3C4B90AD4940AFCE31207B254D4052D32EA699AE4940BB421F2C63274D4052D32EA699AE4940BB421F2C63274D40753E3C4B90AD4940AFCE31207B254D40753E3C4B90AD4940
51132	49424	58.529625000000003	58.551597000000001	51.710225000000001	51.688834	Школьная	0103000020E610000001000000050000006F1283C0CA434D40BA2F67B62BD849406F1283C0CA434D409BE61DA7E8DA49402EC901BB9A464D409BE61DA7E8DA49402EC901BB9A464D40BA2F67B62BD849406F1283C0CA434D40BA2F67B62BD84940
50891	22618	58.080530000000003	58.096851999999998	51.224629	51.21443	Центральная	0103000020E61000000100000005000000672C9ACE4E0A4D4001A43671729B4940672C9ACE4E0A4D40D95DA0A4C09C4940AE4676A5650C4D40D95DA0A4C09C4940AE4676A5650C4D4001A43671729B4940672C9ACE4E0A4D4001A43671729B4940
50898	21665	58.720804000000001	58.742390999999998	51.359661000000003	51.341897000000003	Школьная	0103000020E61000000100000005000000BA69334E435C4D40DECCE847C3AB4940BA69334E435C4D40C652245F09AE494020EC14AB065F4D40C652245F09AE494020EC14AB065F4D40DECCE847C3AB4940BA69334E435C4D40DECCE847C3AB4940
50428	18455	52.495524000000003	52.524037	52.867213	52.850085999999997	Школьная	0103000020E610000001000000050000000A3197546D3F4A40CB64389ECF6C4A400A3197546D3F4A4041D5E8D5006F4A406D72F8A413434A4041D5E8D5006F4A406D72F8A413434A40CB64389ECF6C4A400A3197546D3F4A40CB64389ECF6C4A40
50600	19187	51.985073999999997	52.053714999999997	52.808228999999997	52.774858000000002	Центральная	0103000020E61000000100000005000000E811A3E716FE4940A185048C2E634A40E811A3E716FE4940E256410C74674A40FE261422E0064A40E256410C74674A40FE261422E0064A40A185048C2E634A40E811A3E716FE4940A185048C2E634A40
50280	56062	52.497391999999998	52.547455999999997	53.113157000000001	53.099156000000001	 Садовая	0103000020E6100000010000000500000061A5828AAA3F4A40E199D024B18C4A4061A5828AAA3F4A402028B7ED7B8E4A40DEFFC70913464A402028B7ED7B8E4A40DEFFC70913464A40E199D024B18C4A4061A5828AAA3F4A40E199D024B18C4A40
51230	48845	52.398713000000001	52.420146000000003	53.017353	52.99615	Пушкина	0103000020E61000000100000005000000BABE0F0709334A4088F4DBD7817F4A40BABE0F0709334A4066BE839F38824A40CAC51858C7354A4066BE839F38824A40CAC51858C7354A4088F4DBD7817F4A40BABE0F0709334A4088F4DBD7817F4A40
49988	19274	52.360768	52.456977000000002	52.833866	52.796512999999997	Центральная	0103000020E61000000100000005000000BFB854A52D2E4A405FEB5223F4654A40BFB854A52D2E4A40889FFF1EBC6A4A401903EB387E3A4A40889FFF1EBC6A4A401903EB387E3A4A405FEB5223F4654A40BFB854A52D2E4A405FEB5223F4654A40
51131	18736	52.560130999999998	52.583540999999997	52.786112000000003	52.766320999999998	Молодежная	0103000020E61000000100000005000000E63C635FB2474A40779E78CE16624A40E63C635FB2474A40207F69519F644A400470B378B14A4A40207F69519F644A400470B378B14A4A40779E78CE16624A40E63C635FB2474A40779E78CE16624A40
50452	19577	51.910586000000002	51.964852999999998	52.666437999999999	52.647433999999997	Центральная	0103000020E61000000100000005000000051901158EF44940C328081EDF524A40051901158EF44940E46723D74D554A404739984D80FB4940E46723D74D554A404739984D80FB4940C328081EDF524A40051901158EF44940C328081EDF524A40
50448	18926	52.505952999999998	52.523471000000001	53.000132999999998	52.977311999999998	Центральная	0103000020E6100000010000000500000013286211C3404A4082FE428F187D4A4013286211C3404A403F53AF5B04804A40C4B3041901434A403F53AF5B04804A40C4B3041901434A4082FE428F187D4A4013286211C3404A4082FE428F187D4A40
50758	18598	52.225419000000002	52.262393000000003	52.678648000000003	52.664603	Центральная	0103000020E61000000100000005000000D272A087DA1C4A4068E90AB611554A40D272A087DA1C4A4077BF0AF0DD564A4084D9041896214A4077BF0AF0DD564A4084D9041896214A4068E90AB611554A40D272A087DA1C4A4068E90AB611554A40
50924	48127	52.129109999999997	52.142530999999998	53.005878000000003	52.996177000000003	Центральная	0103000020E6100000010000000500000014CB2DAD86104A4082035ABA827F4A4014CB2DAD86104A4009E23C9CC0804A4045D5AF743E124A4009E23C9CC0804A4045D5AF743E124A4082035ABA827F4A4014CB2DAD86104A4082035ABA827F4A40
49717	18822	52.174906	52.243295000000003	52.847878000000001	52.831200000000003	Советская	0103000020E61000000100000005000000E5EFDE5163164A40B537F8C2646A4A40E5EFDE5163164A40BB7F2C44876C4A40E223624A241F4A40BB7F2C44876C4A40E223624A241F4A40B537F8C2646A4A40E5EFDE5163164A40B537F8C2646A4A40
50763	48636	52.584781	52.628151000000003	52.841427000000003	52.818232999999999	Нижний конец	0103000020E610000001000000050000003D29931ADA4A4A4005C1E3DBBB684A403D29931ADA4A4A40577C43E1B36B4A4090F9804067504A40577C43E1B36B4A4090F9804067504A4005C1E3DBBB684A403D29931ADA4A4A4005C1E3DBBB684A40
50917	48722	52.542110999999998	52.561577	52.965620000000001	52.948684	Центральная	0103000020E61000000100000005000000A3E6ABE463454A40861E317A6E794A40A3E6ABE463454A40882EA86F997B4A40C89750C1E1474A40882EA86F997B4A40C89750C1E1474A40861E317A6E794A40A3E6ABE463454A40861E317A6E794A40
50907	18854	52.123038000000001	52.160147000000002	52.844597999999998	52.833615999999999	Южная	0103000020E6100000010000000500000027158DB5BF0F4A400FB6D8EDB36A4A4027158DB5BF0F4A402D228AC91B6C4A40B9C667B27F144A402D228AC91B6C4A40B9C667B27F144A400FB6D8EDB36A4A4027158DB5BF0F4A400FB6D8EDB36A4A40
51130	17951	52.502639000000002	52.517136999999998	52.732742999999999	52.720520999999998	переулок Школьный	0103000020E61000000100000005000000DA58897956404A40658A39083A5C4A40DA58897956404A40BCAFCA85CA5D4A409946938B31424A40BCAFCA85CA5D4A409946938B31424A40658A39083A5C4A40DA58897956404A40658A39083A5C4A40
51126	17449	52.629517	52.654463	52.723483000000002	52.692605999999998	Центральная	0103000020E6100000010000000500000055A3570394504A40B6813B50A7584A4055A3570394504A40221B48179B5C4A4095B88E71C5534A40221B48179B5C4A4095B88E71C5534A40B6813B50A7584A4055A3570394504A40B6813B50A7584A40
50311	18508	52.129370999999999	52.176245000000002	53.162958000000003	53.144278999999997	Молодежная	0103000020E6100000010000000500000081069B3A8F104A40F23FF9BB77924A4081069B3A8F104A40904FC8CEDB944A40B18A37328F164A40904FC8CEDB944A40B18A37328F164A40F23FF9BB77924A4081069B3A8F104A40F23FF9BB77924A40
50261	48512	52.381402000000001	52.401829999999997	52.945824000000002	52.933841000000001	Гагарина	0103000020E610000001000000050000008350DEC7D1304A40FC54151A88774A408350DEC7D1304A40CEE2C5C210794A409D465A2A6F334A40CEE2C5C210794A409D465A2A6F334A40FC54151A88774A408350DEC7D1304A40FC54151A88774A40
50450	48487	52.028930000000003	52.061449000000003	52.714477000000002	52.691214000000002	Молодежная	0103000020E61000000100000005000000C8EF6DFAB3034A40C8444AB379584A40C8EF6DFAB3034A40425F7AFB735B4A409BAF928FDD074A40425F7AFB735B4A409BAF928FDD074A40C8444AB379584A40C8EF6DFAB3034A40C8444AB379584A40
50593	48384	52.340879000000001	52.381168000000002	52.690085000000003	52.669207	Советская	0103000020E6100000010000000500000054724EECA12B4A408CA03193A8554A4054724EECA12B4A40E73A8DB454584A401024EF1CCA304A40E73A8DB454584A401024EF1CCA304A408CA03193A8554A4054724EECA12B4A408CA03193A8554A40
49896	48384	52.340879000000001	52.381168000000002	52.690085000000003	52.669207	Октябрьская	0103000020E6100000010000000500000054724EECA12B4A408CA03193A8554A4054724EECA12B4A40E73A8DB454584A401024EF1CCA304A40E73A8DB454584A401024EF1CCA304A408CA03193A8554A4054724EECA12B4A408CA03193A8554A40
51386	56193	52.503338999999997	52.530890999999997	53.239299000000003	53.219171000000003	Школьная	0103000020E6100000010000000500000092E68F696D404A40A69D9ACB0D9C4A4092E68F696D404A40967B8159A19E4A40D05E7D3CF4434A40967B8159A19E4A40D05E7D3CF4434A40A69D9ACB0D9C4A4092E68F696D404A40A69D9ACB0D9C4A40
49866	19505	52.006535	52.055456999999997	52.952947999999999	52.930757999999997	пер.Школьный	0103000020E61000000100000005000000C2A38D23D6004A40C43E011423774A40C2A38D23D6004A40F1643733FA794A40C9AA083719074A40F1643733FA794A40C9AA083719074A40C43E011423774A40C2A38D23D6004A40C43E011423774A40
49981	19505	52.006535	52.055456999999997	52.952947999999999	52.930757999999997	Советская	0103000020E61000000100000005000000C2A38D23D6004A40C43E011423774A40C2A38D23D6004A40F1643733FA794A40C9AA083719074A40F1643733FA794A40C9AA083719074A40C43E011423774A40C2A38D23D6004A40C43E011423774A40
50594	19505	52.006535	52.055456999999997	52.952947999999999	52.930757999999997	Заречная	0103000020E61000000100000005000000C2A38D23D6004A40C43E011423774A40C2A38D23D6004A40F1643733FA794A40C9AA083719074A40F1643733FA794A40C9AA083719074A40C43E011423774A40C2A38D23D6004A40C43E011423774A40
50759	48414	52.305242999999997	52.320594999999997	52.642128	52.632055999999999	Садовая	0103000020E610000001000000050000009D2ADF3312274A40CB9E0436E7504A409D2ADF3312274A4046EC134031524A406C21C84109294A4046EC134031524A406C21C84109294A40CB9E0436E7504A409D2ADF3312274A40CB9E0436E7504A40
50916	17885	52.498291000000002	52.520201	52.672898000000004	52.654671999999998	Центральная	0103000020E610000001000000050000001172DEFFC73F4A40AFCDC64ACC534A401172DEFFC73F4A409CC58B8521564A405A2C45F295424A409CC58B8521564A405A2C45F295424A40AFCDC64ACC534A401172DEFFC73F4A40AFCDC64ACC534A40
50271	56060	52.150418000000002	52.179380000000002	52.765351000000003	52.743848999999997	 Школьная	0103000020E61000000100000005000000685DA3E540134A40C614AC71365F4A40685DA3E540134A40FF7A8505F7614A403BC780ECF5164A40FF7A8505F7614A403BC780ECF5164A40C614AC71365F4A40685DA3E540134A40C614AC71365F4A40
50588	17791	52.694510000000001	52.716303000000003	53.079183	53.063206999999998	Речная	0103000020E610000001000000050000005B5F24B4E5584A406BF0BE2A17884A405B5F24B4E5584A4018B325AB228A4A406B8313D1AF5B4A4018B325AB228A4A406B8313D1AF5B4A406BF0BE2A17884A405B5F24B4E5584A406BF0BE2A17884A40
49978	17760	52.000813000000001	52.049177999999998	52.883991000000002	52.857748000000001	Советская	0103000020E61000000100000005000000B134F0A31A004A40CE1ABCAFCA6D4A40B134F0A31A004A40AB7AF99D26714A4062D7F6764B064A40AB7AF99D26714A4062D7F6764B064A40CE1ABCAFCA6D4A40B134F0A31A004A40CE1ABCAFCA6D4A40
50761	46964	52.301065999999999	52.329577999999998	52.706882	52.687148000000001	Школьная	0103000020E6100000010000000500000001F8A75489264A4083C13577F4574A4001F8A75489264A40C710001C7B5A4A4094BDA59C2F2A4A40C710001C7B5A4A4094BDA59C2F2A4A4083C13577F4574A4001F8A75489264A4083C13577F4574A40
50913	48191	52.312348999999998	52.381203999999997	53.218739999999997	53.204552	Советская	0103000020E610000001000000050000001AF8510DFB274A406B2A8BC22E9A4A401AF8510DFB274A40DC291DACFF9B4A405C8DEC4ACB304A40DC291DACFF9B4A405C8DEC4ACB304A406B2A8BC22E9A4A401AF8510DFB274A406B2A8BC22E9A4A40
51240	48273	52.235013000000002	52.267153999999998	52.932875000000003	52.919206000000003	Молодежная	0103000020E610000001000000050000004391EEE7141E4A40BC24CE8AA8754A404391EEE7141E4A40C520B07268774A406F7F2E1A32224A40C520B07268774A406F7F2E1A32224A40BC24CE8AA8754A404391EEE7141E4A40BC24CE8AA8754A40
50590	17355	52.666716000000001	52.700502	52.766179000000001	52.743746000000002	Калинина	0103000020E6100000010000000500000027DC2BF356554A40F243A511335F4A4027DC2BF356554A40E5F0492712624A402C64AE0CAA594A40E5F0492712624A402C64AE0CAA594A40F243A511335F4A4027DC2BF356554A40F243A511335F4A40
51231	48476	52.458666000000001	52.480575999999999	53.259428	53.237730999999997	Заречная	0103000020E61000000100000005000000C1E44691B53A4A40681F2BF86D9E4A40C1E44691B53A4A4056D5CBEF34A14A400A9FAD83833D4A4056D5CBEF34A14A400A9FAD83833D4A40681F2BF86D9E4A40C1E44691B53A4A40681F2BF86D9E4A40
51347	56170	52.312645000000003	52.323011999999999	52.791373	52.785850000000003	Лесная	0103000020E61000000100000005000000042159C004284A40E3C798BB96644A40042159C004284A40FDF7E0B54B654A40971B0C7558294A40FDF7E0B54B654A40971B0C7558294A40E3C798BB96644A40042159C004284A40E3C798BB96644A40
51245	48847	52.412582999999998	52.426586999999998	53.092916000000002	53.075581	Центральная	0103000020E610000001000000050000005AF10D85CF344A40789961A3AC894A405AF10D85CF344A4038A3E6ABE48B4A400AF31E679A364A4038A3E6ABE48B4A400AF31E679A364A40789961A3AC894A405AF10D85CF344A40789961A3AC894A40
50317	17218	51.839350000000003	51.862805000000002	52.826771000000001	52.809448000000003	Садовая	0103000020E61000000100000005000000E5F21FD26FEB494004E8F7FD9B674A40E5F21FD26FEB4940FF23D3A1D3694A40A3E9EC6470EE4940FF23D3A1D3694A40A3E9EC6470EE494004E8F7FD9B674A40E5F21FD26FEB494004E8F7FD9B674A40
49999	56042	52.203499999999998	52.294319000000002	52.817318999999998	52.735588999999997	Школьная	0103000020E61000000100000005000000355EBA490C1A4A400F26C5C7275E4A40355EBA490C1A4A4020B3B3E89D684A40B4CBB73EAC254A4020B3B3E89D684A40B4CBB73EAC254A400F26C5C7275E4A40355EBA490C1A4A400F26C5C7275E4A40
51001	19688	52.568565999999997	52.595551	53.793922000000002	53.784230000000001	Центральная	0103000020E610000001000000050000000BCF4BC5C6484A4063450DA661E44A400BCF4BC5C6484A4097C9703C9FE54A40D00CE2033B4C4A4097C9703C9FE54A40D00CE2033B4C4A4063450DA661E44A400BCF4BC5C6484A4063450DA661E44A40
50881	15082	52.455404999999999	52.469661000000002	53.771652000000003	53.750993999999999	Центральная	0103000020E61000000100000005000000AAB706B64A3A4A4001BF469220E04A40AAB706B64A3A4A404EF2237EC5E24A40749A05DA1D3C4A404EF2237EC5E24A40749A05DA1D3C4A4001BF469220E04A40AAB706B64A3A4A4001BF469220E04A40
51356	56175	52.926921999999998	52.961651000000003	53.884067999999999	53.856991999999998	Заречная	0103000020E61000000100000005000000B1F84D61A5764A408177F2E9B1ED4A40B1F84D61A5764A4056B8E52329F14A4036954561177B4A4056B8E52329F14A4036954561177B4A408177F2E9B1ED4A40B1F84D61A5764A408177F2E9B1ED4A40
51216	15322	52.715369000000003	52.743296999999998	53.742336000000002	53.730697999999997	Центральная	0103000020E610000001000000050000003FC91D36915B4A4055A0168387DD4A403FC91D36915B4A405D52B5DD04DF4A40821B295B245F4A405D52B5DD04DF4A40821B295B245F4A4055A0168387DD4A403FC91D36915B4A4055A0168387DD4A40
50750	14281	52.309815	52.331339	53.751409000000002	53.744039999999998	Центральная	0103000020E61000000100000005000000B6679604A8274A403A75E5B33CDF4A40B6679604A8274A40C5758C2B2EE04A40D671FC50692A4A40C5758C2B2EE04A40D671FC50692A4A403A75E5B33CDF4A40B6679604A8274A403A75E5B33CDF4A40
50747	14411	52.384509999999999	52.406410999999999	53.853524	53.842019000000001	Центральная	0103000020E61000000100000005000000137EA99F37314A4029CE5147C7EB4A40137EA99F37314A40F12C414640ED4A4009DE904605344A40F12C414640ED4A4009DE904605344A4029CE5147C7EB4A40137EA99F37314A4029CE5147C7EB4A40
51129	15794	52.815449999999998	52.832895000000001	53.933332999999998	53.897556999999999	Новая	0103000020E61000000100000005000000F8C264AA60684A40DFA5D425E3F24A40F8C264AA60684A4087A3AB7477F74A403F00A94D9C6A4A4087A3AB7477F74A403F00A94D9C6A4A40DFA5D425E3F24A40F8C264AA60684A40DFA5D425E3F24A40
51123	15005	52.541015000000002	52.554839999999999	53.396538999999997	53.390788000000001	Школьная	0103000020E610000001000000050000009ED2C1FA3F454A40AAD5575705B24A409ED2C1FA3F454A40554B3ACAC1B24A409E4143FF04474A40554B3ACAC1B24A409E4143FF04474A40AAD5575705B24A409ED2C1FA3F454A40AAD5575705B24A40
51005	47410	52.465277999999998	52.486306999999996	53.362951000000002	53.350552999999998	Степная	0103000020E610000001000000050000002EC6C03A8E3B4A40E141B3EBDEAC4A402EC6C03A8E3B4A407786A92D75AE4A406E68CA4E3F3E4A407786A92D75AE4A406E68CA4E3F3E4A40E141B3EBDEAC4A402EC6C03A8E3B4A40E141B3EBDEAC4A40
50757	47523	52.591858999999999	52.609161	53.785645000000002	53.757978999999999	Центральная	0103000020E61000000100000005000000F06B2409C24B4A400307B47405E14A40F06B2409C24B4A400AA2EE0390E44A40D47FD6FCF84D4A400AA2EE0390E44A40D47FD6FCF84D4A400307B47405E14A40F06B2409C24B4A400307B47405E14A40
50589	15665	52.469715000000001	52.506231999999997	53.556978000000001	53.535592999999999	Центральная	0103000020E6100000010000000500000067B8019F1F3C4A40B77BB94F8EC44A4067B8019F1F3C4A40B64B1B0E4BC74A402618CE35CC404A40B64B1B0E4BC74A402618CE35CC404A40B77BB94F8EC44A4067B8019F1F3C4A40B77BB94F8EC44A40
67101	58962	52.078265999999999	53.146254999999996	54.026699000000001	53.254396999999997	Дорожная	0103000020E61000000100000005000000C231CB9E040A4A40AA99B51490A04A40C231CB9E040A4A40FFEA71DF6A034B4030F0DC7BB8924A40FFEA71DF6A034B4030F0DC7BB8924A40AA99B51490A04A40C231CB9E040A4A40AA99B51490A04A40
50243	47398	52.388283000000001	52.432758999999997	53.410491	53.395223000000001	Чапаевская	0103000020E61000000100000005000000E04BE141B3314A4042D0D1AA96B24A40E04BE141B3314A40B32616F88AB44A405B069CA564374A40B32616F88AB44A405B069CA564374A4042D0D1AA96B24A40E04BE141B3314A4042D0D1AA96B24A40
51332	33163	52.273802000000003	52.30686	53.678030999999997	53.663862999999999	улица Центральная	0103000020E610000001000000050000002ACAA5F10B234A4021037976F9D44A402ACAA5F10B234A404B5645B8C9D64A40AC39403047274A404B5645B8C9D64A40AC39403047274A4021037976F9D44A402ACAA5F10B234A4021037976F9D44A40
50901	14750	52.216849000000003	52.240608999999999	53.621339999999996	53.594383000000001	Школьная	0103000020E61000000100000005000000CD9541B5C11B4A403126FDBD14CC4A40CD9541B5C11B4A402BD9B11188CF4A40C70F9546CC1E4A402BD9B11188CF4A40C70F9546CC1E4A403126FDBD14CC4A40CD9541B5C11B4A403126FDBD14CC4A40
51116	15161	52.978234	53.003818000000003	53.895806	53.872172999999997	Советская	0103000020E61000000100000005000000EAEA8EC5367D4A4023BA675DA3EF4A40EAEA8EC5367D4A40C1C760C5A9F24A406D91B41B7D804A40C1C760C5A9F24A406D91B41B7D804A4023BA675DA3EF4A40EAEA8EC5367D4A4023BA675DA3EF4A40
50756	15759	52.509726000000001	52.540655000000001	53.806877	53.785502000000001	Школьная	0103000020E61000000100000005000000E0F599B33E414A40A7785C548BE44A40E0F599B33E414A408272DBBE47E74A409EB5DB2E34454A408272DBBE47E74A409EB5DB2E34454A40A7785C548BE44A40E0F599B33E414A40A7785C548BE44A40
50357	46875	52.450302999999998	52.475734000000003	53.683987999999999	53.668179000000002	Транспортная	0103000020E6100000010000000500000035255987A3394A40DF6FB4E386D54A4035255987A3394A40A06D35EB8CD74A4032CC09DAE43C4A40A06D35EB8CD74A4032CC09DAE43C4A40DF6FB4E386D54A4035255987A3394A40DF6FB4E386D54A40
50413	46875	52.450302999999998	52.475734000000003	53.683987999999999	53.668179000000002	Рабочая	0103000020E6100000010000000500000035255987A3394A40DF6FB4E386D54A4035255987A3394A40A06D35EB8CD74A4032CC09DAE43C4A40A06D35EB8CD74A4032CC09DAE43C4A40DF6FB4E386D54A4035255987A3394A40DF6FB4E386D54A40
50246	46875	52.450302999999998	52.475734000000003	53.683987999999999	53.668179000000002	Полевая	0103000020E6100000010000000500000035255987A3394A40DF6FB4E386D54A4035255987A3394A40A06D35EB8CD74A4032CC09DAE43C4A40A06D35EB8CD74A4032CC09DAE43C4A40DF6FB4E386D54A4035255987A3394A40DF6FB4E386D54A40
50912	46875	52.450302999999998	52.475734000000003	53.683987999999999	53.668179000000002	Калинина Н.С	0103000020E6100000010000000500000035255987A3394A40DF6FB4E386D54A4035255987A3394A40A06D35EB8CD74A4032CC09DAE43C4A40A06D35EB8CD74A4032CC09DAE43C4A40DF6FB4E386D54A4035255987A3394A40DF6FB4E386D54A40
50931	56129	52.479973999999999	52.520766999999999	53.626147000000003	53.604412000000004	Центральная	0103000020E610000001000000050000001477BCC96F3D4A40ADA7565F5DCD4A401477BCC96F3D4A4088BEBB9525D04A4003EB387EA8424A4088BEBB9525D04A4003EB387EA8424A40ADA7565F5DCD4A401477BCC96F3D4A40ADA7565F5DCD4A40
51223	47177	53.012253000000001	53.079904999999997	53.840297	53.815314000000001	Почтовая	0103000020E6100000010000000500000092239D8191814A4048FC8A355CE84A4092239D8191814A40A5F622DA8EEB4A40B8E4B8533A8A4A40A5F622DA8EEB4A40B8E4B8533A8A4A4048FC8A355CE84A4092239D8191814A4048FC8A355CE84A40
50905	14864	52.217396999999998	52.248218000000001	53.460529000000001	53.444502	Широкая	0103000020E61000000100000005000000CF9F36AAD31B4A40D8800871E5B84A40CF9F36AAD31B4A4007EE409DF2BA4A40A723809BC51F4A4007EE409DF2BA4A40A723809BC51F4A40D8800871E5B84A40CF9F36AAD31B4A40D8800871E5B84A40
51120	14810	52.352314999999997	52.371538999999999	53.486769000000002	53.468617999999999	Школьная	0103000020E61000000100000005000000F3716DA8182D4A409128B4ACFBBB4A40F3716DA8182D4A4073DA53724EBE4A40221807978E2F4A4073DA53724EBE4A40221807978E2F4A409128B4ACFBBB4A40F3716DA8182D4A409128B4ACFBBB4A40
51122	46373	52.617291000000002	52.633299000000001	53.577930000000002	53.568230999999997	Дорожная	0103000020E61000000100000005000000BD8E3864034F4A4064C91CCBBBC84A40BD8E3864034F4A404BB0389CF9C94A4075CB0EF10F514A404BB0389CF9C94A4075CB0EF10F514A4064C91CCBBBC84A40BD8E3864034F4A4064C91CCBBBC84A40
50259	47099	52.282884000000003	52.339550000000003	53.58914	53.559086000000001	Молодежная	0103000020E61000000100000005000000E547FC8A35244A4063D34A2190C74A40E547FC8A35244A40FA6184F068CB4A40ACADD85F762B4A40FA6184F068CB4A40ACADD85F762B4A4063D34A2190C74A40E547FC8A35244A4063D34A2190C74A40
64206	56127	52.519795999999999	52.537861999999997	53.312426000000002	53.295003000000001	Центральная	0103000020E61000000100000005000000BA4BE2AC88424A40679C86A8C2A54A40BA4BE2AC88424A40C6353E93FDA74A406DE179A9D8444A40C6353E93FDA74A406DE179A9D8444A40679C86A8C2A54A40BA4BE2AC88424A40679C86A8C2A54A40
50754	15522	52.419193999999997	52.435462999999999	53.422915000000003	53.408552999999998	пер. Озерный	0103000020E61000000100000005000000F7562426A8354A4062D7F6764BB44A40F7562426A8354A4072FE261422B64A401CCF6740BD374A4072FE261422B64A401CCF6740BD374A4062D7F6764BB44A40F7562426A8354A4062D7F6764BB44A40
51228	47913	52.268186999999998	52.281222	53.654482000000002	53.645868	Центральная	0103000020E610000001000000050000002E1B9DF353224A4037C478CDABD24A402E1B9DF353224A400CE9F010C6D34A4036751E15FF234A400CE9F010C6D34A4036751E15FF234A4037C478CDABD24A402E1B9DF353224A4037C478CDABD24A40
50587	14493	52.545811999999998	52.58717	53.605480999999997	53.585751000000002	Привокзальная	0103000020E61000000100000005000000D6E1E82ADD454A40B64C86E3F9CA4A40D6E1E82ADD454A40B8ACC26680CD4A409E98F562284B4A40B8ACC26680CD4A409E98F562284B4A40B64C86E3F9CA4A40D6E1E82ADD454A40B64C86E3F9CA4A40
51221	47427	52.321187999999999	52.340690000000002	53.328853000000002	53.317295000000001	Фурманова	0103000020E610000001000000050000000FEF39B01C294A409817601F9DA84A400FEF39B01C294A408318E8DA17AA4A408109DCBA9B2B4A408318E8DA17AA4A408109DCBA9B2B4A409817601F9DA84A400FEF39B01C294A409817601F9DA84A40
50265	14477	52.602873000000002	52.642237000000002	53.705506	53.688611000000002	Советская	0103000020E610000001000000050000001A5245F12A4D4A403B55BE6724D84A401A5245F12A4D4A40DE9046054EDA4A40FDA36FD234524A40DE9046054EDA4A40FDA36FD234524A403B55BE6724D84A401A5245F12A4D4A403B55BE6724D84A40
51222	46838	53.035806999999998	53.065550000000002	53.724460000000001	53.713845999999997	Заречная	0103000020E61000000100000005000000E3FBE25295844A40B130444E5FDB4A40E3FBE25295844A404DA1F31ABBDC4A405C2041F163884A404DA1F31ABBDC4A405C2041F163884A40B130444E5FDB4A40E3FBE25295844A40B130444E5FDB4A40
51128	47626	52.800637000000002	52.8249	53.749524000000001	53.742910999999999	Молодежная	0103000020E61000000100000005000000D97BF1457B664A40596B28B517DF4A40D97BF1457B664A4097C80567F0DF4A40363CBD5296694A4097C80567F0DF4A40363CBD5296694A40596B28B517DF4A40D97BF1457B664A40596B28B517DF4A40
50651	15140	53.016717999999997	53.046227000000002	53.946418999999999	53.905233000000003	Совхозная	0103000020E6100000010000000500000094A0BFD023824A404721C9ACDEF34A4094A0BFD023824A4011A8FE4124F94A409A982EC4EA854A4011A8FE4124F94A409A982EC4EA854A404721C9ACDEF34A4094A0BFD023824A404721C9ACDEF34A40
50440	46893	52.391598000000002	52.405234	53.677610000000001	53.654797000000002	Чапаевская	0103000020E61000000100000005000000EA961DE21F324A406C425A63D0D34A40EA961DE21F324A40A6B8AAECBBD64A40179D2CB5DE334A40A6B8AAECBBD64A40179D2CB5DE334A406C425A63D0D34A40EA961DE21F324A406C425A63D0D34A40
50903	46826	53.002460999999997	53.033847999999999	53.728929999999998	53.717469999999999	 Центральная	0103000020E61000000100000005000000FA415DA450804A4039EE940ED6DB4A40FA415DA450804A40618907944DDD4A407B849A2155844A40618907944DDD4A407B849A2155844A4039EE940ED6DB4A40FA415DA450804A4039EE940ED6DB4A40
50585	14052	52.378500000000003	52.400221999999999	53.594425000000001	53.582200999999998	Придорожная	0103000020E610000001000000050000009CC420B072304A406859F78F85CA4A409CC420B072304A4060764F1E16CC4A40E29178793A334A4060764F1E16CC4A40E29178793A334A406859F78F85CA4A409CC420B072304A406859F78F85CA4A40
51124	56147	52.523749000000002	52.547114000000001	53.864724000000002	53.8446	Московская	0103000020E6100000010000000500000007280D350A434A40CE1951DA1BEC4A4007280D350A434A407D08AA46AFEE4A408597E0D407464A407D08AA46AFEE4A408597E0D407464A40CE1951DA1BEC4A4007280D350A434A40CE1951DA1BEC4A40
51205	46450	55.960118999999999	55.976514000000002	51.408901	51.399940000000001	Школьная	0103000020E6100000010000000500000055A2EC2DE5FA4B405E2EE23B31B3494055A2EC2DE5FA4B409E2633DE56B44940070B2769FEFC4B409E2633DE56B44940070B2769FEFC4B405E2EE23B31B3494055A2EC2DE5FA4B405E2EE23B31B34940
50749	46228	56.204264000000002	56.220272000000001	51.489705999999998	51.481254	Школьная	0103000020E6100000010000000500000005E09F52251A4C40DB8827BB99BD494005E09F52251A4C40D653ABAFAEBE4940BD1C76DF311C4C40D653ABAFAEBE4940BD1C76DF311C4C40DB8827BB99BD494005E09F52251A4C40DB8827BB99BD4940
51113	13011	55.687795000000001	55.719766	51.458374999999997	51.440986000000002	Ленинская	0103000020E6100000010000000500000019ADA3AA09D84B4037FFAF3A72B8494019ADA3AA09D84B40E9263108ACBA4940E962D34A21DC4B40E9263108ACBA4940E962D34A21DC4B4037FFAF3A72B8494019ADA3AA09D84B4037FFAF3A72B84940
81060	13149	56.074294999999999	56.103005000000003	51.228048000000001	51.215868999999998	Центральная	0103000020E61000000100000005000000CFA0A17F82094C40309C6B98A19B4940CFA0A17F82094C4088F546AD309D4940892991442F0D4C4088F546AD309D4940892991442F0D4C40309C6B98A19B4940CFA0A17F82094C40309C6B98A19B4940
51117	46571	56.550069999999998	56.565018000000002	51.393320000000003	51.384388999999999	Центральная	0103000020E610000001000000050000005F419AB168464C4098F8A3A833B149405F419AB168464C406E6E4C4F58B249405FD3838252484C406E6E4C4F58B249405FD3838252484C4098F8A3A833B149405F419AB168464C4098F8A3A833B14940
51214	56157	56.570165000000003	56.597259000000001	51.045377999999999	51.020873999999999	Школьная	0103000020E610000001000000050000007429AE2AFB484C4019ABCDFFAB8249407429AE2AFB484C409CFA40F2CE854940EF1EA0FB724C4C409CFA40F2CE854940EF1EA0FB724C4C4019ABCDFFAB8249407429AE2AFB484C4019ABCDFFAB824940
51112	46538	56.743046	56.760824	51.355319000000001	51.345267	Школьная	0103000020E6100000010000000500000039B69E211C5F4C40ABB184B531AC494039B69E211C5F4C40DF52CE177BAD494086014BAE62614C40DF52CE177BAD494086014BAE62614C40ABB184B531AC494039B69E211C5F4C40ABB184B531AC4940
49954	12865	55.922775999999999	55.961655999999998	51.575735999999999	51.556179999999998	Центральная	0103000020E6100000010000000500000050C422861DF64B403A58FFE730C7494050C422861DF64B409F909DB7B1C949404700378B17FB4B409F909DB7B1C949404700378B17FB4B403A58FFE730C7494050C422861DF64B403A58FFE730C74940
50904	13527	56.872107	56.892156999999997	51.355336000000001	51.342728999999999	Школьная	0103000020E610000001000000050000006CCEC133A16F4C4005323B8BDEAB49406CCEC133A16F4C40B58B69A67BAD4940E0F2583332724C40B58B69A67BAD4940E0F2583332724C4005323B8BDEAB49406CCEC133A16F4C4005323B8BDEAB4940
81041	46344	55.786034999999998	55.813082999999999	51.374443999999997	51.359127000000001	Советская	0103000020E6100000010000000500000074417DCB9CE44B40280EA0DFF7AD494074417DCB9CE44B407A17EFC7EDAF49407FF78E1A13E84B407A17EFC7EDAF49407FF78E1A13E84B40280EA0DFF7AD494074417DCB9CE44B40280EA0DFF7AD4940
81070	62065	56.404076000000003	56.428977000000003	51.255361000000001	51.244221000000003	Комсомольская	0103000020E610000001000000050000009C8C2AC3B8334C408BFF3BA2429F49409C8C2AC3B8334C4041D653ABAFA049403CDEE4B7E8364C4041D653ABAFA049403CDEE4B7E8364C408BFF3BA2429F49409C8C2AC3B8334C408BFF3BA2429F4940
50739	12709	56.473965	56.490313999999998	51.389026000000001	51.372121999999997	Центральная	0103000020E610000001000000050000006D3997E2AA3C4C40A10F96B1A1AF49406D3997E2AA3C4C4098A59D9ACBB14940AE62F19BC23E4C4098A59D9ACBB14940AE62F19BC23E4C40A10F96B1A1AF49406D3997E2AA3C4C40A10F96B1A1AF4940
51212	13804	56.622374999999998	56.643118000000001	51.459783000000002	51.442518	Первомайская	0103000020E610000001000000050000008B6CE7FBA94F4C4017F2086EA4B849408B6CE7FBA94F4C40DE205A2BDABA494006BCCCB051524C40DE205A2BDABA494006BCCCB051524C4017F2086EA4B849408B6CE7FBA94F4C4017F2086EA4B84940
50005	46608	56.852946000000003	56.871909000000002	51.396737000000002	51.386828000000001	Советская	0103000020E6100000010000000500000084A0A3552D6D4C40AB96749483B1494084A0A3552D6D4C407C0E2C47C8B24940460BD0B69A6F4C407C0E2C47C8B24940460BD0B69A6F4C40AB96749483B1494084A0A3552D6D4C40AB96749483B14940
81081	46608	56.852946000000003	56.871909000000002	51.396737000000002	51.386828000000001	Казачья	0103000020E6100000010000000500000084A0A3552D6D4C40AB96749483B1494084A0A3552D6D4C407C0E2C47C8B24940460BD0B69A6F4C407C0E2C47C8B24940460BD0B69A6F4C40AB96749483B1494084A0A3552D6D4C40AB96749483B14940
50447	12769	56.322679000000001	56.354300000000002	51.435308999999997	51.415529999999997	Южная	0103000020E61000000100000005000000910DA48B4D294C40E140481630B54940910DA48B4D294C40C5538F34B8B74940857CD0B3592D4C40C5538F34B8B74940857CD0B3592D4C40E140481630B54940910DA48B4D294C40E140481630B54940
50896	13719	56.389854999999997	56.416049999999998	51.479044000000002	51.466875999999999	Победы	0103000020E610000001000000050000004E97C5C4E6314C40C6A4BF97C2BB49404E97C5C4E6314C402AAC545051BD49401AC05B2041354C402AAC545051BD49401AC05B2041354C40C6A4BF97C2BB49404E97C5C4E6314C40C6A4BF97C2BB4940
50746	13609	56.695228999999998	56.717030999999999	51.407907000000002	51.393881999999998	Форштадская	0103000020E610000001000000050000008A1D8D43FD584C40D53DB2B96AB249408A1D8D43FD584C409D67EC4B36B44940ED9BFBABC75B4C409D67EC4B36B44940ED9BFBABC75B4C40D53DB2B96AB249408A1D8D43FD584C40D53DB2B96AB24940
51121	56146	56.298254	56.323200999999997	51.278607999999998	51.267992	Центральная	0103000020E610000001000000050000005AF3E32F2D264C4079CBD58F4DA249405AF3E32F2D264C40B5334C6DA9A349406A847EA65E294C40B5334C6DA9A349406A847EA65E294C4079CBD58F4DA249405AF3E32F2D264C4079CBD58F4DA24940
50258	13100	55.982990999999998	55.998351999999997	51.374512000000003	51.355808000000003	Спортивная	0103000020E6100000010000000500000094A12AA6D2FD4B40DDD3D51D8BAD494094A12AA6D2FD4B40D3FA5B02F0AF4940B6F292FFC9FF4B40D3FA5B02F0AF4940B6F292FFC9FF4B40DDD3D51D8BAD494094A12AA6D2FD4B40DDD3D51D8BAD4940
50416	13375	56.678933000000001	56.722861000000002	51.360111000000003	51.344647999999999	Центральная	0103000020E610000001000000050000006C96CB46E7564C40DF50F86C1DAC49406C96CB46E7564C4006F7031E18AE4940E54691B5865C4C4006F7031E18AE4940E54691B5865C4C40DF50F86C1DAC49406C96CB46E7564C40DF50F86C1DAC4940
51114	12846	56.036879999999996	56.052402999999998	51.516672999999997	51.504806000000002	Центральная	0103000020E6100000010000000500000030F0DC7BB8044C408C69A67B9DC0494030F0DC7BB8044C40F4DC425722C249402C9B3924B5064C40F4DC425722C249402C9B3924B5064C408C69A67B9DC0494030F0DC7BB8044C408C69A67B9DC04940
51160	13040	55.706623999999998	55.729585	51.35069	51.337412	Центральная	0103000020E61000000100000005000000CB48BDA772DA4B4094A3005130AB4940CB48BDA772DA4B406284F068E3AC49407A53910A63DD4B406284F068E3AC49407A53910A63DD4B4094A3005130AB4940CB48BDA772DA4B4094A3005130AB4940
81087	13886	56.388866999999998	56.437474999999999	51.406973999999998	51.389699999999998	Ленинская	0103000020E610000001000000050000002FBFD364C6314C4027A089B0E1B149402FBFD364C6314C4041295AB917B44940A7E8482EFF374C4041295AB917B44940A7E8482EFF374C4027A089B0E1B149402FBFD364C6314C4027A089B0E1B14940
49747	13886	56.388866999999998	56.437474999999999	51.406973999999998	51.389699999999998	Комсомольская	0103000020E610000001000000050000002FBFD364C6314C4027A089B0E1B149402FBFD364C6314C4041295AB917B44940A7E8482EFF374C4041295AB917B44940A7E8482EFF374C4027A089B0E1B149402FBFD364C6314C4027A089B0E1B14940
49714	13886	56.388866999999998	56.437474999999999	51.406973999999998	51.389699999999998	Банковская	0103000020E610000001000000050000002FBFD364C6314C4027A089B0E1B149402FBFD364C6314C4041295AB917B44940A7E8482EFF374C4041295AB917B44940A7E8482EFF374C4027A089B0E1B149402FBFD364C6314C4027A089B0E1B14940
50745	46648	56.516832000000001	56.547401999999998	51.577952000000003	51.561056999999998	Школьлная	0103000020E610000001000000050000005DC30C8D27424C408F183DB7D0C749405DC30C8D27424C403354C554FAC94940EBE1CB4411464C403354C554FAC94940EBE1CB4411464C408F183DB7D0C749405DC30C8D27424C408F183DB7D0C74940
51118	13712	56.504120999999998	56.519661999999997	51.448351000000002	51.437021999999999	Советская	0103000020E61000000100000005000000081D740987404C40F6D03E56F0B74940081D740987404C408010C99063B94940AA7CCF4884424C408010C99063B94940AA7CCF4884424C40F6D03E56F0B74940081D740987404C40F6D03E56F0B74940
64203	58189	53.004562999999997	53.049227999999999	53.602612000000001	53.58117	 Центральная	0103000020E61000000100000005000000C5E2378595804A404AB54FC763CA4A40C5E2378595804A40AD16D86322CD4A401406651A4D864A40AD16D86322CD4A401406651A4D864A404AB54FC763CA4A40C5E2378595804A404AB54FC763CA4A40
50895	46139	52.811425999999997	52.866501	53.424067999999998	53.412326999999998	Киселева	0103000020E61000000100000005000000E28FA2CEDC674A40FF209221C7B44A40E28FA2CEDC674A40DBA337DC47B64A40C4793881E96E4A40DBA337DC47B64A40C4793881E96E4A40FF209221C7B44A40E28FA2CEDC674A40FF209221C7B44A40
51069	12469	53.102227999999997	53.121200999999999	53.560941999999997	53.549778000000003	Центральная	0103000020E61000000100000005000000245E9ECE158D4A40B80721205FC64A40245E9ECE158D4A40F6798CF2CCC74A400A9FAD83838F4A40F6798CF2CCC74A400A9FAD83838F4A40B80721205FC64A40245E9ECE158D4A40B80721205FC64A40
49710	46134	52.905802999999999	52.967184000000003	53.506321	53.478104999999999	переулок Парковый	0103000020E6100000010000000500000031CF4A5AF1734A40EC866D8B32BD4A4031CF4A5AF1734A4096236420CFC04A40749B70AFCC7B4A4096236420CFC04A40749B70AFCC7B4A40EC866D8B32BD4A4031CF4A5AF1734A40EC866D8B32BD4A40
50893	26176	53.132897	53.160080000000001	53.610663000000002	53.601804999999999	Привокзальная	0103000020E61000000100000005000000465ED6C402914A40DEC83CF207CD4A40465ED6C402914A404AF086342ACE4A40315F5E807D944A404AF086342ACE4A40315F5E807D944A40DEC83CF207CD4A40465ED6C402914A40DEC83CF207CD4A40
50260	46097	52.801974999999999	52.825727000000001	53.368217000000001	53.357630999999998	Садовая	0103000020E61000000100000005000000D49AE61DA7664A40948444DAC6AD4A40D49AE61DA7664A40666A12BC21AF4A404C361E6CB1694A40666A12BC21AF4A404C361E6CB1694A40948444DAC6AD4A40D49AE61DA7664A40948444DAC6AD4A40
50687	12110	52.811191999999998	52.844977999999998	53.547387000000001	53.539436000000002	Центральная	0103000020E610000001000000050000006F63B323D5674A407D24253D0CC54A406F63B323D5674A40B6A0F7C610C64A4074EB353D286C4A40B6A0F7C610C64A4074EB353D286C4A407D24253D0CC54A406F63B323D5674A407D24253D0CC54A40
50322	12420	53.06617	53.085439000000001	53.489699999999999	53.471668000000001	Центральная	0103000020E61000000100000005000000F8FC304278884A40ED48F59D5FBC4A40F8FC304278884A40F46C567DAEBE4A40C76647AAEF8A4A40F46C567DAEBE4A40C76647AAEF8A4A40ED48F59D5FBC4A40F8FC304278884A40ED48F59D5FBC4A40
50257	12295	52.991906	53.048096000000001	53.484990000000003	53.464646000000002	Центральная	0103000020E61000000100000005000000645A9BC6F67E4A40CE1B278579BB4A40645A9BC6F67E4A408B71FE2614BE4A40C2887D0228864A408B71FE2614BE4A40C2887D0228864A40CE1B278579BB4A40645A9BC6F67E4A40CE1B278579BB4A40
51167	56153	52.869520000000001	52.873624999999997	53.584313000000002	53.583399	Пришкольная	0103000020E61000000100000005000000E59B6D6E4C6F4A4072C284D1ACCA4A40E59B6D6E4C6F4A4057D0B4C4CACA4A40E7FBA9F1D26F4A4057D0B4C4CACA4A40E7FBA9F1D26F4A4072C284D1ACCA4A40E59B6D6E4C6F4A4072C284D1ACCA4A40
51249	48066	52.964812999999999	52.986004000000001	53.470317000000001	53.451666000000003	Школьная	0103000020E61000000100000005000000B9E00CFE7E7B4A408A5B0531D0B94A40B9E00CFE7E7B4A405DE0F25833BC4A40D3DC0A61357E4A405DE0F25833BC4A40D3DC0A61357E4A408A5B0531D0B94A40B9E00CFE7E7B4A408A5B0531D0B94A40
51093	12035	53.172395999999999	53.196317999999998	53.751766000000003	53.731769	Центральная	0103000020E6100000010000000500000009FB761211964A40029D499BAADD4A4009FB761211964A40541F48DE39E04A40DDCEBEF220994A40541F48DE39E04A40DDCEBEF220994A40029D499BAADD4A4009FB761211964A40029D499BAADD4A40
50270	45967	53.162244999999999	53.202354	53.404752999999999	53.384757	Центральная	0103000020E610000001000000050000004278B471C4944A401BF4A5B73FB14A404278B471C4944A409CFA40F2CEB34A407E1B62BCE6994A409CFA40F2CEB34A407E1B62BCE6994A401BF4A5B73FB14A404278B471C4944A401BF4A5B73FB14A40
64208	58190	52.633262999999999	52.648031000000003	53.483206000000003	53.470633999999997	 Народная	0103000020E61000000100000005000000286211C30E514A405D3123BC3DBC4A40286211C30E514A40919DB7B1D9BD4A40A8E507AEF2524A40919DB7B1D9BD4A40A8E507AEF2524A405D3123BC3DBC4A40286211C30E514A405D3123BC3DBC4A40
50581	45894	52.849173	52.891950999999999	53.541061999999997	53.523485999999998	Центральная	0103000020E61000000100000005000000B7D26BB3B16C4A40F9F4D89601C34A40B7D26BB3B16C4A40DE8D058541C54A4037514B732B724A40DE8D058541C54A4037514B732B724A40F9F4D89601C34A40B7D26BB3B16C4A40F9F4D89601C34A40
51111	12322	52.935150999999998	52.963572999999997	53.452589000000003	53.438671999999997	Новая	0103000020E610000001000000050000002DE92807B3774A40E0D5726726B84A402DE92807B3774A40C2C3B46FEEB94A4080272D5C567B4A40C2C3B46FEEB94A4080272D5C567B4A40E0D5726726B84A402DE92807B3774A40E0D5726726B84A40
51203	12370	52.947870999999999	52.971910000000001	53.512430999999999	53.497467	Центральная	0103000020E61000000100000005000000D5E940D653794A406CEBA7FFACBF4A40D5E940D653794A40713AC95697C14A40E353008C677C4A40713AC95697C14A40E353008C677C4A406CEBA7FFACBF4A40D5E940D653794A406CEBA7FFACBF4A40
50899	45854	53.136741000000001	53.176177000000003	53.694082000000002	53.682516	Школьная	0103000020E61000000100000005000000DC82A5BA80914A40957F2DAF5CD74A40DC82A5BA80914A40035FD1ADD7D84A4059A7CAF78C964A40035FD1ADD7D84A4059A7CAF78C964A40957F2DAF5CD74A40DC82A5BA80914A40957F2DAF5CD74A40
50894	45816	53.167554000000003	53.230030999999997	53.657432999999997	53.628084999999999	Центральная	0103000020E610000001000000050000003128D36872954A40D80DDB1665D04A403128D36872954A40D427B9C326D44A407808E3A7719D4A40D427B9C326D44A407808E3A7719D4A40D80DDB1665D04A403128D36872954A40D80DDB1665D04A40
50737	11803	52.726894000000001	52.746746999999999	53.484112000000003	53.464168999999998	Садовая	0103000020E610000001000000050000004ED4D2DC0A5D4A409468C9E369BB4A404ED4D2DC0A5D4A40F3CCCB61F7BD4A406CB1DB67955F4A40F3CCCB61F7BD4A406CB1DB67955F4A409468C9E369BB4A404ED4D2DC0A5D4A409468C9E369BB4A40
50544	11762	53.219898000000001	53.252400000000002	53.528731999999998	53.506647000000001	Центральная	0103000020E61000000100000005000000583A1F9E259C4A40EACE13CFD9C04A40583A1F9E259C4A40A12C7C7DADC34A4055C1A8A44EA04A40A12C7C7DADC34A4055C1A8A44EA04A40EACE13CFD9C04A40583A1F9E259C4A40EACE13CFD9C04A40
50748	12195	52.805802	52.811892999999998	53.479294000000003	53.464737	Центральная	0103000020E6100000010000000500000094861A8524674A40DE1E84807CBB4A4094861A8524674A40A3957B8159BD4A40F86C1D1CEC674A40A3957B8159BD4A40F86C1D1CEC674A40DE1E84807CBB4A4094861A8524674A40DE1E84807CBB4A40
50445	45739	52.902479	52.923445000000001	53.233165999999997	53.214641999999998	Садовая	0103000020E61000000100000005000000D4298F6E84734A408C2C9963799B4A40D4298F6E84734A4002452C62D89D4A40CE531D7233764A4002452C62D89D4A40CE531D7233764A408C2C9963799B4A40D4298F6E84734A408C2C9963799B4A40
50914	11621	52.842328000000002	52.866843000000003	53.660203000000003	53.647598000000002	Молодежная	0103000020E61000000100000005000000A7406667D16B4A403E7AC37DE4D24A40A7406667D16B4A404DDC2A8881D44A401EE21FB6F46E4A404DDC2A8881D44A401EE21FB6F46E4A403E7AC37DE4D24A40A7406667D16B4A403E7AC37DE4D24A40
50855	46712	52.568888999999999	52.585993000000002	53.361843999999998	53.349091000000001	Центральная	0103000020E61000000100000005000000EE06D15AD1484A40FA298E03AFAC4A40EE06D15AD1484A407D2079E750AE4A40AC5791D1014B4A407D2079E750AE4A40AC5791D1014B4A40FA298E03AFAC4A40EE06D15AD1484A40FA298E03AFAC4A40
50738	11822	52.658648999999997	52.672168999999997	53.430013000000002	53.411022000000003	Зеленая	0103000020E610000001000000050000008445459C4E544A40E0F76F5E9CB44A408445459C4E544A406CED7DAA0AB74A40483140A209564A406CED7DAA0AB74A40483140A209564A40E0F76F5E9CB44A408445459C4E544A40E0F76F5E9CB44A40
49713	56037	52.707742000000003	52.767471	53.561033000000002	53.544305000000001	Партизанская	0103000020E61000000100000005000000B900344A975A4A404F0647C9ABC54A40B900344A975A4A40077DE9EDCFC74A4070D05E7D3C624A40077DE9EDCFC74A4070D05E7D3C624A404F0647C9ABC54A40B900344A975A4A404F0647C9ABC54A40
50734	45697	53.089579999999998	53.109253000000002	53.215192000000002	53.204579000000003	Набережная	0103000020E610000001000000050000001630815B778B4A40653909A52F9A4A401630815B778B4A40302E55698B9B4A40B5FE9600FC8D4A40302E55698B9B4A40B5FE9600FC8D4A40653909A52F9A4A401630815B778B4A40653909A52F9A4A40
50969	49563	53.121676999999998	53.165163999999997	53.481256000000002	53.472006	Центральная	0103000020E6100000010000000500000073D6A71C938F4A4005C24EB16ABC4A4073D6A71C938F4A407C80EECB99BD4A40FF3C0D1824954A407C80EECB99BD4A40FF3C0D1824954A4005C24EB16ABC4A4073D6A71C938F4A4005C24EB16ABC4A40
64141	58174	53.009756000000003	53.053592999999999	53.287995000000002	53.267211000000003	 Центральная	0103000020E610000001000000050000004B7842AF3F814A40D41055F833A24A404B7842AF3F814A40AD342905DDA44A40B325AB22DC864A40AD342905DDA44A40B325AB22DC864A40D41055F833A24A404B7842AF3F814A40D41055F833A24A40
50678	11135	52.879545	52.906655999999998	53.359361999999997	53.352567999999998	Набережная	0103000020E610000001000000050000001F2E39EE94704A40DDCEBEF220AD4A401F2E39EE94704A406BB6F292FFAD4A40705CC64D0D744A406BB6F292FFAD4A40705CC64D0D744A40DDCEBEF220AD4A401F2E39EE94704A40DDCEBEF220AD4A40
50536	45662	52.635041000000001	52.668441000000001	53.325783000000001	53.293807999999999	Золотухина	0103000020E61000000100000005000000404F030649514A40CEA623809BA54A40404F030649514A40E04BE141B3A94A401C2785798F554A40E04BE141B3A94A401C2785798F554A40CEA623809BA54A40404F030649514A40CEA623809BA54A40
49791	11193	52.778771999999996	52.885877999999998	53.592624000000001	53.567413000000002	Советская	0103000020E610000001000000050000002F8507CDAE634A40A2293BFDA0C84A402F8507CDAE634A4090696D1ADBCB4A40791F477364714A4090696D1ADBCB4A40791F477364714A40A2293BFDA0C84A402F8507CDAE634A40A2293BFDA0C84A40
49944	11193	52.778771999999996	52.885877999999998	53.592624000000001	53.567413000000002	Набережная	0103000020E610000001000000050000002F8507CDAE634A40A2293BFDA0C84A402F8507CDAE634A4090696D1ADBCB4A40791F477364714A4090696D1ADBCB4A40791F477364714A40A2293BFDA0C84A402F8507CDAE634A40A2293BFDA0C84A40
51204	11417	53.104528000000002	53.153432000000002	53.269176999999999	53.258592999999998	Школьная	0103000020E6100000010000000500000016C26A2C618D4A40BDFC4E9319A14A4016C26A2C618D4A40EEEA556474A24A407714E7A8A3934A40EEEA556474A24A407714E7A8A3934A40BDFC4E9319A14A4016C26A2C618D4A40BDFC4E9319A14A40
51197	9152	54.200220999999999	54.223595000000003	52.975608999999999	52.956355000000002	Советская	0103000020E61000000100000005000000787C7BD7A0194B40DC2E34D7697A4A40787C7BD7A0194B40755776C1E07C4A404A46CEC29E1C4B40755776C1E07C4A404A46CEC29E1C4B40DC2E34D7697A4A40787C7BD7A0194B40DC2E34D7697A4A40
79086	9152	54.200220999999999	54.223595000000003	52.975608999999999	52.956355000000002	Комсомольская	0103000020E61000000100000005000000787C7BD7A0194B40DC2E34D7697A4A40787C7BD7A0194B40755776C1E07C4A404A46CEC29E1C4B40755776C1E07C4A404A46CEC29E1C4B40DC2E34D7697A4A40787C7BD7A0194B40DC2E34D7697A4A40
50725	9067	54.351129	54.370164000000003	52.853175	52.836123999999998	Школьная	0103000020E61000000100000005000000AED689CBF12C4B404AB3791C066B4A40AED689CBF12C4B40E561A1D6346D4A400A14B188612F4B40E561A1D6346D4A400A14B188612F4B404AB3791C066B4A40AED689CBF12C4B404AB3791C066B4A40
79117	61390	54.262374999999999	54.274512000000001	52.808805999999997	52.802159000000003	Центральная	0103000020E61000000100000005000000DD24068195214B4096986725AD664A40DD24068195214B407F677BF486674A40062E8F3523234B407F677BF486674A40062E8F3523234B4096986725AD664A40DD24068195214B4096986725AD664A40
51220	10151	54.340538000000002	54.359662999999998	52.539056000000002	52.525032000000003	Совхозная	0103000020E61000000100000005000000CB85CABF962B4B403FADA23F34434A40CB85CABF962B4B40365B79C9FF444A40664AEB6F092E4B40365B79C9FF444A40664AEB6F092E4B403FADA23F34434A40CB85CABF962B4B403FADA23F34434A40
51107	9401	54.162519000000003	54.174771999999997	52.842390000000002	52.819757000000003	Советская	0103000020E6100000010000000500000044FD2E6CCD144B4063D520CCED684A4044FD2E6CCD144B401D3D7E6FD36B4A40D520CCED5E164B401D3D7E6FD36B4A40D520CCED5E164B4063D520CCED684A4044FD2E6CCD144B4063D520CCED684A40
50535	10032	54.231347999999997	54.257227999999998	52.475807000000003	52.458015000000003	Советская	0103000020E610000001000000050000005CFFAECF9C1D4B40EA094B3CA03A4A405CFFAECF9C1D4B409C1A683EE73C4A40C8CEDBD8EC204B409C1A683EE73C4A40C8CEDBD8EC204B40EA094B3CA03A4A405CFFAECF9C1D4B40EA094B3CA03A4A40
50735	56108	54.353949999999998	54.380091	52.401775999999998	52.391905999999999	Октябрьская	0103000020E61000000100000005000000A835CD3B4E2D4B40978DCEF929324A40A835CD3B4E2D4B40AA285E656D334A40814067D2A6304B40AA285E656D334A40814067D2A6304B40978DCEF929324A40A835CD3B4E2D4B40978DCEF929324A40
50869	49241	54.058152	54.086179999999999	52.789068999999998	52.769464999999997	Советская	0103000020E610000001000000050000003719558671074B40543541D47D624A403719558671074B40CAA4863600654A40DEC83CF2070B4B40CAA4863600654A40DEC83CF2070B4B40543541D47D624A403719558671074B40543541D47D624A40
79109	61386	54.223289999999999	54.244292000000002	52.768320000000003	52.748548	Школьная	0103000020E610000001000000050000000DC347C4941C4B403CBEBD6BD05F4A400DC347C4941C4B406E6E4C4F58624A405456D3F5441F4B406E6E4C4F58624A405456D3F5441F4B403CBEBD6BD05F4A400DC347C4941C4B403CBEBD6BD05F4A40
51105	9052	54.366742000000002	54.388095	52.801996000000003	52.789428000000001	Советская	0103000020E61000000100000005000000EA08E066F12E4B40FA4509FA0B654A40EA08E066F12E4B40ECC20FCEA7664A40DD5ED218AD314B40ECC20FCEA7664A40DD5ED218AD314B40FA4509FA0B654A40EA08E066F12E4B40FA4509FA0B654A40
51200	45360	54.685482	54.698462999999997	52.679172000000001	52.669114	Центральная	0103000020E6100000010000000500000093FFC9DFBD574B40DBA50D87A5554A4093FFC9DFBD574B40F12DAC1BEF564A40A73B4F3C67594B40F12DAC1BEF564A40A73B4F3C67594B40DBA50D87A5554A4093FFC9DFBD574B40DBA50D87A5554A40
79130	61399	54.271996000000001	54.305827000000001	52.462761	52.447702999999997	Гагарина	0103000020E610000001000000050000004852D2C3D0224B4019A9F7544E394A404852D2C3D0224B40A06EA0C03B3B4A40ED9DD15625274B40A06EA0C03B3B4A40ED9DD15625274B4019A9F7544E394A404852D2C3D0224B4019A9F7544E394A40
51026	10336	54.035766000000002	54.051541	52.934004000000002	52.925710000000002	Октябрьская	0103000020E610000001000000050000008527F4FA93044B4043CA4FAA7D764A408527F4FA93044B40A62A6D718D774A409AB33EE598064B40A62A6D718D774A409AB33EE598064B4043CA4FAA7D764A408527F4FA93044B4043CA4FAA7D764A40
51199	9953	54.127026000000001	54.148944999999998	52.556142000000001	52.540934999999998	Центральная	0103000020E61000000100000005000000F0DE516342104B408121AB5B3D454A40F0DE516342104B404DF73AA92F474A408CF337A110134B404DF73AA92F474A408CF337A110134B408121AB5B3D454A40F0DE516342104B408121AB5B3D454A40
50874	857	54.556331	54.592739999999999	52.403122000000003	52.384793999999999	Школьная	0103000020E610000001000000050000002060ADDA35474B4038D906EE40314A402060ADDA35474B4029266F8099334A40F98381E7DE4B4B4029266F8099334A40F98381E7DE4B4B4038D906EE40314A402060ADDA35474B4038D906EE40314A40
50942	857	54.556331	54.592739999999999	52.403122000000003	52.384793999999999	Центральная	0103000020E610000001000000050000002060ADDA35474B4038D906EE40314A402060ADDA35474B4029266F8099334A40F98381E7DE4B4B4029266F8099334A40F98381E7DE4B4B4038D906EE40314A402060ADDA35474B4038D906EE40314A40
50693	45994	54.491678999999998	54.524602999999999	52.433121999999997	52.417493	 Хуторская	0103000020E61000000100000005000000A3906456EF3E4B408BA71E6970354A40A3906456EF3E4B40CC96AC8A70374A401631EC3026434B40CC96AC8A70374A401631EC3026434B408BA71E6970354A40A3906456EF3E4B408BA71E6970354A40
79098	49366	53.980718000000003	54.018537000000002	52.884062	52.867719000000001	Пролетарская	0103000020E610000001000000050000009D4CDC2A88FD4A40158F8B6A116F4A409D4CDC2A88FD4A4074D190F128714A400B62A06B5F024B4074D190F128714A400B62A06B5F024B40158F8B6A116F4A409D4CDC2A88FD4A40158F8B6A116F4A40
51208	45414	54.528789000000003	54.544725	52.562285000000003	52.551690999999998	Новая	0103000020E6100000010000000500000006BEA25BAF434B40AF3F89CF9D464A4006BEA25BAF434B40040473F4F8474A4024287E8CB9454B40040473F4F8474A4024287E8CB9454B40AF3F89CF9D464A4006BEA25BAF434B40AF3F89CF9D464A40
79158	61422	54.720489000000001	54.740549000000001	52.577227999999998	52.570753000000003	переулок Школьный	0103000020E610000001000000050000005A10CAFB385C4B40058C2E6F0E494A405A10CAFB385C4B40F12A6B9BE2494A40F20A444FCA5E4B40F12A6B9BE2494A40F20A444FCA5E4B40058C2E6F0E494A405A10CAFB385C4B40058C2E6F0E494A40
50743	56109	54.057281000000003	54.067594	52.574201000000002	52.570101999999999	Мира	0103000020E6100000010000000500000052D7DAFB54074B402DB1321AF9484A4052D7DAFB54074B404E2A1A6B7F494A40F2B391EBA6084B404E2A1A6B7F494A40F2B391EBA6084B402DB1321AF9484A4052D7DAFB54074B402DB1321AF9484A40
79065	61374	54.390008000000002	54.403931999999998	52.752451000000001	52.743113000000001	Майская	0103000020E61000000100000005000000D5963AC8EB314B40C11DA8531E5F4A40D5963AC8EB314B40D76B7A5050604A4068E7340BB4334B40D76B7A5050604A4068E7340BB4334B40C11DA8531E5F4A40D5963AC8EB314B40C11DA8531E5F4A40
51188	9647	54.325132000000004	54.344355999999998	52.617733000000001	52.607322000000003	Новая	0103000020E610000001000000050000000971E5EC9D294B40171230BABC4D4A400971E5EC9D294B407A54FCDF114F4A4037177FDB132C4B407A54FCDF114F4A4037177FDB132C4B40171230BABC4D4A400971E5EC9D294B40171230BABC4D4A40
50832	9856	54.049132999999998	54.064486000000002	52.673859	52.668644	Центральная	0103000020E61000000100000005000000C2137AFD49064B405455682096554A40C2137AFD49064B40C18EFF0241564A406286C61341084B40C18EFF0241564A406286C61341084B405455682096554A40C2137AFD49064B405455682096554A40
50884	9824	54.143672000000002	54.154846999999997	52.652186999999998	52.642826999999997	Сагита Агиша	0103000020E61000000100000005000000EBAC16D863124B402EFEB62748524A40EBAC16D863124B402CF015DD7A534A401D71C806D2134B402CF015DD7A534A401D71C806D2134B402EFEB62748524A40EBAC16D863124B402EFEB62748524A40
51405	56195	54.266058999999998	54.280548000000003	52.625185000000002	52.618017999999999	Сагита Агиша	0103000020E610000001000000050000003AE7A7380E224B406F2BBD361B4F4A403AE7A7380E224B409279E40F06504A40A77A32FFE8234B409279E40F06504A40A77A32FFE8234B406F2BBD361B4F4A403AE7A7380E224B406F2BBD361B4F4A40
51100	10114	54.291300999999997	54.308377999999998	52.426850999999999	52.406550000000003	Советская	0103000020E610000001000000050000006325E65949254B402B1895D409344A406325E65949254B40E8A1B60DA3364A40276728EE78274B40E8A1B60DA3364A40276728EE78274B402B1895D409344A406325E65949254B402B1895D409344A40
79153	61418	54.361738000000003	54.384672000000002	52.449761000000002	52.440589000000003	Мира	0103000020E6100000010000000500000038DC476E4D2E4B401AFD683865384A4038DC476E4D2E4B401502B9C491394A40EDD79DEE3C314B401502B9C491394A40EDD79DEE3C314B401AFD683865384A4038DC476E4D2E4B401AFD683865384A40
50248	49184	54.062598999999999	54.117100000000001	52.916426000000001	52.889197000000003	Советская	0103000020E6100000010000000500000093E1783E03084B40C5591135D1714A4093E1783E03084B40209A79724D754A40492EFF21FD0E4B40209A79724D754A40492EFF21FD0E4B40C5591135D1714A4093E1783E03084B40C5591135D1714A40
50730	45436	54.564155	54.5839	52.539648	52.531201000000003	Советская	0103000020E61000000100000005000000FC6F253B36484B401F4DF564FE434A40FC6F253B36484B4008AD872F13454A403411363CBD4A4B4008AD872F13454A403411363CBD4A4B401F4DF564FE434A40FC6F253B36484B401F4DF564FE434A40
51385	56192	54.310578999999997	54.332776000000003	52.636040000000001	52.622413000000002	Ленина	0103000020E6100000010000000500000085E97B0DC1274B4079CDAB3AAB4F4A4085E97B0DC1274B4053793BC269514A4065726A67982A4B4053793BC269514A4065726A67982A4B4079CDAB3AAB4F4A4085E97B0DC1274B4079CDAB3AAB4F4A40
51106	49571	54.886730999999997	54.908596000000003	52.605013999999997	52.596235	Школьная	0103000020E61000000100000005000000B8ACC26680714B4083DDB06D514C4A40B8ACC26680714B40A2CF4719714D4A4062A3ACDF4C744B40A2CF4719714D4A4062A3ACDF4C744B4083DDB06D514C4A40B8ACC26680714B4083DDB06D514C4A40
49874	10251	54.382714	54.420307999999999	52.411510999999997	52.389603999999999	Ленина	0103000020E6100000010000000500000055DCB8C5FC304B4005323B8BDE314A4055DCB8C5FC304B40DD787764AC344A40A31F0DA7CC354B40DD787764AC344A40A31F0DA7CC354B4005323B8BDE314A4055DCB8C5FC304B4005323B8BDE314A40
50729	49597	54.630721000000001	54.679355000000001	52.651181999999999	52.624741999999998	Центральная	0103000020E6100000010000000500000041F33977BB504B400438BD8BF74F4A4041F33977BB504B4037DF88EE59534A40E2AFC91AF5564B4037DF88EE59534A40E2AFC91AF5564B400438BD8BF74F4A4041F33977BB504B400438BD8BF74F4A40
50919	56128	54.765808999999997	54.797258999999997	52.5047	52.492621999999997	Центральная	0103000020E61000000100000005000000C1FD800706624B4022A5D93C0E3F4A40C1FD800706624B40462575029A404A4088B839950C664B40462575029A404A4088B839950C664B4022A5D93C0E3F4A40C1FD800706624B4022A5D93C0E3F4A40
51183	49218	53.870054000000003	53.885451000000003	52.93421	52.926496999999998	Молодежная	0103000020E6100000010000000500000083E0F1ED5DEF4A40CA6B257497764A4083E0F1ED5DEF4A404FCC7A3194774A40F29A577556F14A404FCC7A3194774A40F29A577556F14A40CA6B257497764A4083E0F1ED5DEF4A40CA6B257497764A40
50753	48459	54.105027	54.132308000000002	52.669381000000001	52.655862999999997	Школьная	0103000020E6100000010000000500000037195586710D4B4006D49B51F3534A4037195586710D4B402AC8CF46AE554A40E57FF277EF104B402AC8CF46AE554A40E57FF277EF104B4006D49B51F3534A4037195586710D4B4006D49B51F3534A40
50732	56107	54.607787000000002	54.623741000000003	52.701599999999999	52.680399999999999	Советская	0103000020E610000001000000050000008CF7E3F6CB4D4B406519E25817574A408CF7E3F6CB4D4B40D26F5F07CE594A405116BEBED64F4B40D26F5F07CE594A405116BEBED64F4B406519E25817574A408CF7E3F6CB4D4B406519E25817574A40
51201	49108	54.417504999999998	54.436990000000002	52.642198999999998	52.631241000000003	Буранная	0103000020E610000001000000050000004F75C8CD70354B407A724D81CC504A404F75C8CD70354B400F43AB9333524A40EB56CF49EF374B400F43AB9333524A40EB56CF49EF374B407A724D81CC504A404F75C8CD70354B407A724D81CC504A40
50560	49105	54.777127999999998	54.787809000000003	52.588428999999998	52.575969000000001	Центральная	0103000020E61000000100000005000000276728EE78634B404241295AB9494A40276728EE78634B404D8237A4514B4A404B3FE1ECD6644B404D8237A4514B4A404B3FE1ECD6644B404241295AB9494A40276728EE78634B404241295AB9494A40
79166	56095	54.402036000000003	54.430377999999997	52.69068	52.669338000000003	Эстрадная	0103000020E6100000010000000500000047E867EA75334B402BFC19DEAC554A4047E867EA75334B402A00C63368584A407D7555A016374B402A00C63368584A407D7555A016374B402BFC19DEAC554A4047E867EA75334B402BFC19DEAC554A40
79035	56095	54.402036000000003	54.430377999999997	52.69068	52.669338000000003	Мичурина	0103000020E6100000010000000500000047E867EA75334B402BFC19DEAC554A4047E867EA75334B402A00C63368584A407D7555A016374B402A00C63368584A407D7555A016374B402BFC19DEAC554A4047E867EA75334B402BFC19DEAC554A40
51059	10953	54.419347000000002	54.430557999999998	52.601239999999997	52.591006	Советская	0103000020E610000001000000050000007E569929AD354B40B1DEA815A64B4A407E569929AD354B400586AC6EF54C4A40FD8348861C374B400586AC6EF54C4A40FD8348861C374B40B1DEA815A64B4A407E569929AD354B40B1DEA815A64B4A40
50315	8811	55.352525999999997	55.394513000000003	50.781584000000002	50.759321999999997	Центральная	0103000020E61000000100000005000000AE7E6C921FAD4B4010919A7631614940AE7E6C921FAD4B40D789CBF10A644940666CE8667FB24B40D789CBF10A644940666CE8667FB24B4010919A7631614940AE7E6C921FAD4B4010919A7631614940
50630	56086	55.561708000000003	55.584919999999997	50.742641999999996	50.723041000000002	Центральная	0103000020E6100000010000000500000067F3380CE6C74B406555849B8C5C494067F3380CE6C74B4069519FE40E5F49405E6397A8DECA4B4069519FE40E5F49405E6397A8DECA4B406555849B8C5C494067F3380CE6C74B406555849B8C5C4940
81092	56220	55.977860999999997	55.991191999999998	50.826355	50.816806999999997	Тамдинская	0103000020E6100000010000000500000055849B8C2AFD4B406A12BC218D68494055849B8C2AFD4B406BF12900C669494046072461DFFE4B406BF12900C669494046072461DFFE4B406A12BC218D68494055849B8C2AFD4B406A12BC218D684940
50878	8723	55.991875	56.009957999999997	50.766773999999998	50.749907999999998	Новая	0103000020E61000000100000005000000295C8FC2F5FE4B401F813FFCFC5F4940295C8FC2F5FE4B4028B682A625624940B22AC24D46014C4028B682A625624940B22AC24D46014C401F813FFCFC5F4940295C8FC2F5FE4B401F813FFCFC5F4940
50545	47487	56.270927999999998	56.312106	51.122497000000003	51.095771999999997	Центральная	0103000020E610000001000000050000000CC9C9C4AD224C40AEEFC341428C49400CC9C9C4AD224C40D76D50FBAD8F49405471E316F3274C40D76D50FBAD8F49405471E316F3274C40AEEFC341428C49400CC9C9C4AD224C40AEEFC341428C4940
50568	47487	56.270927999999998	56.312106	51.122497000000003	51.095771999999997	Заречная	0103000020E610000001000000050000000CC9C9C4AD224C40AEEFC341428C49400CC9C9C4AD224C40D76D50FBAD8F49405471E316F3274C40D76D50FBAD8F49405471E316F3274C40AEEFC341428C49400CC9C9C4AD224C40AEEFC341428C4940
50574	8547	55.891452000000001	55.920377999999999	50.909542999999999	50.894205999999997	Советская	0103000020E6100000010000000500000016FA60191BF24B4088F19A577572494016FA60191BF24B4022A7AFE76B7449409CFA40F2CEF54B4022A7AFE76B7449409CFA40F2CEF54B4088F19A577572494016FA60191BF24B4088F19A5775724940
51040	49384	56.282784999999997	56.301084000000003	51.153799999999997	51.143189	Центральная	0103000020E610000001000000050000005166834C32244C40CF126404549249405166834C32244C40F90FE9B7AF934940A8ACA6EB89264C40F90FE9B7AF934940A8ACA6EB89264C40CF126404549249405166834C32244C40CF12640454924940
51101	8495	55.46698	55.489133000000002	50.879097000000002	50.862112000000003	Центральная	0103000020E610000001000000050000006BF12900C6BB4B409DBE9EAF596E49406BF12900C6BB4B4080812040867049407B32FFE89BBE4B4080812040867049407B32FFE89BBE4B409DBE9EAF596E49406BF12900C6BB4B409DBE9EAF596E4940
50434	48893	55.588459	55.623322999999999	51.149467000000001	51.130704999999999	Центральная	0103000020E61000000100000005000000B804E09F52CB4B403B3602F1BA904940B804E09F52CB4B40666A12BC219349401CEC4D0CC9CF4B40666A12BC219349401CEC4D0CC9CF4B403B3602F1BA904940B804E09F52CB4B403B3602F1BA904940
50669	7966	55.408158999999998	55.430931000000001	51.036876999999997	51.026103999999997	Центральная	0103000020E61000000100000005000000B648DA8D3EB44B40BB25396057834940B648DA8D3EB44B40BF7CB262B884494092EA3BBF28B74B40BF7CB262B884494092EA3BBF28B74B40BB25396057834940B648DA8D3EB44B40BB25396057834940
50316	8291	55.892916	55.906661	51.230590999999997	51.212139000000001	Победы	0103000020E610000001000000050000009E094D124BF24B40639AE95E279B49409E094D124BF24B403FE08101849D494082C7B7770DF44B403FE08101849D494082C7B7770DF44B40639AE95E279B49409E094D124BF24B40639AE95E279B4940
49723	48571	55.795529999999999	55.805833999999997	51.220990999999998	51.208222999999997	Центральная	0103000020E61000000100000005000000527E52EDD3E54B4033A31F0DA79A4940527E52EDD3E54B40ECDADE6E499C49409F008A9125E74B40ECDADE6E499C49409F008A9125E74B4033A31F0DA79A4940527E52EDD3E54B4033A31F0DA79A4940
50722	8034	55.491943999999997	55.504187999999999	50.978129000000003	50.963937999999999	Нагумановская	0103000020E6100000010000000500000051BB5F05F8BE4B4092AF0452627B494051BB5F05F8BE4B407522C154337D494090847D3B89C04B407522C154337D494090847D3B89C04B4092AF0452627B494051BB5F05F8BE4B4092AF0452627B4940
51050	7652	55.655347999999996	55.665112999999998	51.081102000000001	51.072409999999998	Заводская	0103000020E61000000100000005000000DFBF7971E2D34B40A1F31ABB44894940DFBF7971E2D34B40F2D1E28C618A49407D923B6C22D54B40F2D1E28C618A49407D923B6C22D54B40A1F31ABB44894940DFBF7971E2D34B40A1F31ABB44894940
51109	48910	55.579799999999999	55.598987999999999	51.277582000000002	51.265889999999999	Школьная	0103000020E61000000100000005000000431CEBE236CA4B40AE2AFBAE08A24940431CEBE236CA4B40A9FA95CE87A34940255987A3ABCC4B40A9FA95CE87A34940255987A3ABCC4B40AE2AFBAE08A24940431CEBE236CA4B40AE2AFBAE08A24940
50672	48704	55.665498999999997	55.685406	50.940452000000001	50.930188999999999	Центральная	0103000020E61000000100000005000000A6423C122FD54B40AA0CE36E10774940A6423C122FD54B4099BA2BBB60784940B83D4162BBD74B4099BA2BBB60784940B83D4162BBD74B40AA0CE36E10774940A6423C122FD54B40AA0CE36E10774940
51048	48741	55.367007000000001	55.388970999999998	51.056617000000003	51.048724999999997	Биканова	0103000020E610000001000000050000009833DB15FAAE4B40B1BFEC9E3C8649409833DB15FAAE4B40E6B2D1393F874940D40B3ECDC9B14B40E6B2D1393F874940D40B3ECDC9B14B40B1BFEC9E3C8649409833DB15FAAE4B40B1BFEC9E3C864940
50671	7696	55.544370000000001	55.571157999999997	51.030262	51.016590999999998	Центральная	0103000020E61000000100000005000000367689EAADC54B40373465A71F824940367689EAADC54B40E1270EA0DF834940A46C91B41BC94B40E1270EA0DF834940A46C91B41BC94B40373465A71F824940367689EAADC54B40373465A71F824940
51233	48956	55.949680999999998	55.975579000000003	50.882285000000003	50.870280999999999	Украинская	0103000020E61000000100000005000000F850A2258FF94B4043AA285E656F4940F850A2258FF94B402D6002B7EE7049400BD5CDC5DFFC4B402D6002B7EE7049400BD5CDC5DFFC4B4043AA285E656F4940F850A2258FF94B4043AA285E656F4940
51108	48871	56.049565000000001	56.073836999999997	51.123311000000001	51.108198000000002	Центральная	0103000020E610000001000000050000005C035B2558064C400EBF9B6ED98D49405C035B2558064C40581EA4A7C88F49400C1EA67D73094C40581EA4A7C88F49400C1EA67D73094C400EBF9B6ED98D49405C035B2558064C400EBF9B6ED98D4940
50726	8216	55.929288999999997	55.959625000000003	51.173225000000002	51.158410000000003	Гайко	0103000020E610000001000000050000002AC423F1F2F64B4000AE64C7469449402AC423F1F2F64B40C0EC9E3C2C96494046B6F3FDD4FA4B40C0EC9E3C2C96494046B6F3FDD4FA4B4000AE64C7469449402AC423F1F2F64B4000AE64C746944940
50724	8070	56.157012000000002	56.182965000000003	51.000149999999998	50.988500000000002	Семенова	0103000020E610000001000000050000002F8A1EF818144C404A0C022B877E49402F8A1EF818144C40158C4AEA0480494005A8A9656B174C40158C4AEA0480494005A8A9656B174C404A0C022B877E49402F8A1EF818144C404A0C022B877E4940
50325	48670	55.909005000000001	55.935056000000003	50.980074000000002	50.960720999999999	Школьная	0103000020E6100000010000000500000043739D465AF44B404BCADDE7F87A494043739D465AF44B4078D49810737D4940DCF63DEAAFF74B4078D49810737D4940DCF63DEAAFF74B404BCADDE7F87A494043739D465AF44B404BCADDE7F87A4940
50309	48723	55.550595000000001	55.583339000000002	50.981893999999997	50.968055999999997	Набережная	0103000020E61000000100000005000000AA2B9FE579C64B4029594E42E97B4940AA2B9FE579C64B40BE11DDB3AE7D49409DBD33DAAACA4B40BE11DDB3AE7D49409DBD33DAAACA4B4029594E42E97B4940AA2B9FE579C64B4029594E42E97B4940
51236	8132	56.255898999999999	56.284995000000002	50.958371999999997	50.937341000000004	Центральная	0103000020E61000000100000005000000200A664CC1204C40981936CAFA774940200A664CC1204C4078B306EFAB7A4940034356B77A244C4078B306EFAB7A4940034356B77A244C40981936CAFA774940200A664CC1204C40981936CAFA774940
81090	8632	55.877887999999999	55.896617999999997	50.853389999999997	50.8461	Абдешева	0103000020E6100000010000000500000082C64CA25EF04B40A3923A014D6C494082C64CA25EF04B40E15D2EE23B6D4940A180ED60C4F24B40E15D2EE23B6D4940A180ED60C4F24B40A3923A014D6C494082C64CA25EF04B40A3923A014D6C4940
49868	7311	55.587085000000002	55.644362000000001	51.023741000000001	50.987423	Терещенко	0103000020E61000000100000005000000707CED9925CB4B40BB287AE0637E4940707CED9925CB4B408449F1F10983494080643A747AD24B408449F1F10983494080643A747AD24B40BB287AE0637E4940707CED9925CB4B40BB287AE0637E4940
49696	7311	55.587085000000002	55.644362000000001	51.023741000000001	50.987423	Советская	0103000020E61000000100000005000000707CED9925CB4B40BB287AE0637E4940707CED9925CB4B408449F1F10983494080643A747AD24B408449F1F10983494080643A747AD24B40BB287AE0637E4940707CED9925CB4B40BB287AE0637E4940
49706	7311	55.587085000000002	55.644362000000001	51.023741000000001	50.987423	Оренбургская	0103000020E61000000100000005000000707CED9925CB4B40BB287AE0637E4940707CED9925CB4B408449F1F10983494080643A747AD24B408449F1F10983494080643A747AD24B40BB287AE0637E4940707CED9925CB4B40BB287AE0637E4940
49871	7311	55.587085000000002	55.644362000000001	51.023741000000001	50.987423	Комсомольская	0103000020E61000000100000005000000707CED9925CB4B40BB287AE0637E4940707CED9925CB4B408449F1F10983494080643A747AD24B408449F1F10983494080643A747AD24B40BB287AE0637E4940707CED9925CB4B40BB287AE0637E4940
49810	7311	55.587085000000002	55.644362000000001	51.023741000000001	50.987423	Горбунова	0103000020E61000000100000005000000707CED9925CB4B40BB287AE0637E4940707CED9925CB4B408449F1F10983494080643A747AD24B408449F1F10983494080643A747AD24B40BB287AE0637E4940707CED9925CB4B40BB287AE0637E4940
50676	56097	59.126761999999999	61.008606	52.056756	51.177289999999999	Школьная	0103000020E610000001000000050000001230BABC39904D4034F44F70B19649401230BABC39904D4007EDD5C743074A4052465C001A814E4007EDD5C743074A4052465C001A814E4034F44F70B19649401230BABC39904D4034F44F70B1964940
50666	56094	59.697012000000001	59.828812999999997	51.367882999999999	51.285305999999999	Старый	0103000020E61000000100000005000000B47570B037D94D4021AD31E884A44940B47570B037D94D408FE046CA16AF4940F4BF5C8B16EA4D408FE046CA16AF4940F4BF5C8B16EA4D4021AD31E884A44940B47570B037D94D4021AD31E884A44940
49841	56043	59.126761999999999	61.008606	52.056756	51.177289999999999	Волгоградская	0103000020E610000001000000050000001230BABC39904D4034F44F70B19649401230BABC39904D4007EDD5C743074A4052465C001A814E4007EDD5C743074A4052465C001A814E4034F44F70B19649401230BABC39904D4034F44F70B1964940
50642	56091	59.334003000000003	59.361105000000002	51.655467000000002	51.631720000000001	Советская	0103000020E6100000010000000500000009E23C9CC0AA4D40541D7233DCD0494009E23C9CC0AA4D40BA4DB857E6D3494007B64AB038AE4D40BA4DB857E6D3494007B64AB038AE4D40541D7233DCD0494009E23C9CC0AA4D40541D7233DCD04940
50886	56126	59.580519000000002	59.600524	51.867738000000003	51.847056000000002	Школьная	0103000020E6100000010000000500000073DA53724ECA4D40B7F0BC546CEC494073DA53724ECA4D408CBFED0912EF4940473B6EF8DDCC4D408CBFED0912EF4940473B6EF8DDCC4D40B7F0BC546CEC494073DA53724ECA4D40B7F0BC546CEC4940
49809	7121	59.749141000000002	59.789431	51.828414000000002	51.798057999999997	Садовая	0103000020E61000000100000005000000DF8B2FDAE3DF4D40D427B9C326E64940DF8B2FDAE3DF4D4037C64E7809EA49406BB933130CE54D4037C64E7809EA49406BB933130CE54D40D427B9C326E64940DF8B2FDAE3DF4D40D427B9C326E64940
50442	7121	59.749141000000002	59.789431	51.828414000000002	51.798057999999997	Комсомольская	0103000020E61000000100000005000000DF8B2FDAE3DF4D40D427B9C326E64940DF8B2FDAE3DF4D4037C64E7809EA49406BB933130CE54D4037C64E7809EA49406BB933130CE54D40D427B9C326E64940DF8B2FDAE3DF4D40D427B9C326E64940
50636	56089	59.989558000000002	60.012104999999998	51.677622	51.663969999999999	Мира	0103000020E6100000010000000500000062BF27D6A9FE4D4037C30DF8FCD4494062BF27D6A9FE4D406A865451BCD649401D8F19A88C014E406A865451BCD649401D8F19A88C014E4037C30DF8FCD4494062BF27D6A9FE4D4037C30DF8FCD44940
50865	56122	59.331451999999999	59.348869999999998	51.593995999999997	51.579037999999997	Школьная	0103000020E61000000100000005000000CE18E6046DAA4D401492CCEA1DCA4940CE18E6046DAA4D4037FA980F08CC49401B47ACC5A7AC4D4037FA980F08CC49401B47ACC5A7AC4D401492CCEA1DCA4940CE18E6046DAA4D401492CCEA1DCA4940
50733	56105	60.830101999999997	60.851626000000003	51.321052000000002	51.307839000000001	Комсомольская	0103000020E610000001000000050000000E2C47C8406A4E4078B7B24467A749400E2C47C8406A4E405F28603B18A949402F36AD14026D4E405F28603B18A949402F36AD14026D4E4078B7B24467A749400E2C47C8406A4E4078B7B24467A74940
51158	56151	60.020297999999997	60.046897000000001	51.577745	51.555714999999999	Школьная	0103000020E610000001000000050000004C16F71F99024E40C5724BAB21C749404C16F71F99024E40B936548CF3C94940E8A38CB800064E40B936548CF3C94940E8A38CB800064E40C5724BAB21C749404C16F71F99024E40C5724BAB21C74940
51394	56151	60.020297999999997	60.046897000000001	51.577745	51.555714999999999	 Советская	0103000020E610000001000000050000004C16F71F99024E40C5724BAB21C749404C16F71F99024E40B936548CF3C94940E8A38CB800064E40B936548CF3C94940E8A38CB800064E40C5724BAB21C749404C16F71F99024E40C5724BAB21C74940
51411	56203	59.787176000000002	59.802464999999998	51.399276999999998	51.383657999999997	Октябрьская	0103000020E610000001000000050000001A19E42EC2E44D40A46C91B41BB149401A19E42EC2E44D40C2853C821BB34940A297512CB7E64D40C2853C821BB34940A297512CB7E64D40A46C91B41BB149401A19E42EC2E44D40A46C91B41BB14940
51403	56199	59.872785999999998	59.909886	51.773598999999997	51.765278000000002	Советская	0103000020E610000001000000050000000D349F73B7EF4D40952C27A1F4E149400D349F73B7EF4D40F19BC24A05E349404C8BFA2477F44D40F19BC24A05E349404C8BFA2477F44D40952C27A1F4E149400D349F73B7EF4D40952C27A1F4E14940
50305	6435	59.386536	59.410018000000001	51.912937999999997	51.903309	Советская	0103000020E61000000100000005000000035DFB027AB14D405B971AA19FF34940035DFB027AB14D4048A30227DBF44940BB6246787BB44D4048A30227DBF44940BB6246787BB44D405B971AA19FF34940035DFB027AB14D405B971AA19FF34940
51398	56197	60.134841999999999	60.156123000000001	51.437555000000003	51.421905000000002	Советская	0103000020E610000001000000050000004910AE8042114E406B82A8FB00B649404910AE8042114E40C4995FCD01B84940A393A5D6FB134E40C4995FCD01B84940A393A5D6FB134E406B82A8FB00B649404910AE8042114E406B82A8FB00B64940
64189	58185	60.614902000000001	60.658344	51.577840000000002	51.557181999999997	Школьная	0103000020E610000001000000050000005C1FD61BB54E4E40BEF561BD51C749405C1FD61BB54E4E400B293FA9F6C9494048C2BE9D44544E400B293FA9F6C9494048C2BE9D44544E40BEF561BD51C749405C1FD61BB54E4E40BEF561BD51C74940
50728	56106	60.400365999999998	60.430737999999998	51.724319999999999	51.712457000000001	Школьный	0103000020E6100000010000000500000015376E313F334E4034677DCA31DB494015376E313F334E405BEB8B84B6DC49407D923B6C22374E405BEB8B84B6DC49407D923B6C22374E4034677DCA31DB494015376E313F334E4034677DCA31DB4940
51369	56179	60.191301000000003	60.220443000000003	51.631636	51.617030999999997	Островского	0103000020E610000001000000050000009758198D7C184E4020CF2EDFFACE49409758198D7C184E40F67CCD72D9D04940EAD0E979371C4E40F67CCD72D9D04940EAD0E979371C4E4020CF2EDFFACE49409758198D7C184E4020CF2EDFFACE4940
77523	61196	59.727474000000001	59.755339999999997	51.775834000000003	51.754302000000003	Ленина	0103000020E610000001000000050000005C5837DE1DDD4D4059A7CAF78CE049405C5837DE1DDD4D40FC8F4C874EE3494029AE2AFBAEE04D40FC8F4C874EE3494029AE2AFBAEE04D4059A7CAF78CE049405C5837DE1DDD4D4059A7CAF78CE04940
50751	56110	59.722408000000001	59.740597999999999	51.642178000000001	51.632832000000001	Тюлигенова	0103000020E61000000100000005000000342F87DD77DC4D405FEE93A300D14940342F87DD77DC4D40F81A82E332D24940D3BD4EEACBDE4D40F81A82E332D24940D3BD4EEACBDE4D405FEE93A300D14940342F87DD77DC4D405FEE93A300D14940
51371	56182	59.889592999999998	59.916038999999998	51.473669999999998	51.458216999999998	улица Октябрьская	0103000020E6100000010000000500000011E0F42EDEF14D4051BCCADAA6BA494011E0F42EDEF14D40548CF337A1BC4940266E15C440F54D40548CF337A1BC4940266E15C440F54D4051BCCADAA6BA494011E0F42EDEF14D4051BCCADAA6BA4940
50374	56068	60.240330999999998	60.282884000000003	51.676319999999997	51.655768999999999	Целинная	0103000020E61000000100000005000000849B8C2AC31E4E40855D143DF0D34940849B8C2AC31E4E40BBD05CA791D64940E547FC8A35244E40BBD05CA791D64940E547FC8A35244E40855D143DF0D34940849B8C2AC31E4E40855D143DF0D34940
51054	56140	59.629980000000003	59.648189000000002	51.634967000000003	51.625256999999998	Школьная	0103000020E610000001000000050000002A91442FA3D04D402B4CDF6B08D049402A91442FA3D04D400685419946D1494040506EDBF7D24D400685419946D1494040506EDBF7D24D402B4CDF6B08D049402A91442FA3D04D402B4CDF6B08D04940
50618	56080	60.216140000000003	60.265619000000001	51.501094999999999	51.485573000000002	Ленина	0103000020E61000000100000005000000C1ADBB79AA1B4E400A698D4127BE4940C1ADBB79AA1B4E40359886E123C049401E19ABCDFF214E40359886E123C049401E19ABCDFF214E400A698D4127BE4940C1ADBB79AA1B4E400A698D4127BE4940
50665	5751	60.220883000000001	60.240709000000003	51.718812999999997	51.702997000000003	Советская	0103000020E61000000100000005000000069FE6E4451C4E40D31742CEFBD94940069FE6E4451C4E4046787B1002DC49402B6D718DCF1E4E4046787B1002DC49402B6D718DCF1E4E40D31742CEFBD94940069FE6E4451C4E40D31742CEFBD94940
51390	56136	59.525137999999998	59.552204000000003	51.648342	51.633251000000001	Советская	0103000020E6100000010000000500000084F1D3B837C34D406494675E0ED1494084F1D3B837C34D40C64FE3DEFCD24940365CE49EAEC64D40C64FE3DEFCD24940365CE49EAEC64D406494675E0ED1494084F1D3B837C34D406494675E0ED14940
49808	5098	59.919767	59.956518000000003	51.539164	51.504094000000002	Школьная	0103000020E610000001000000050000005378D0ECBAF54D400F0EF62686C049405378D0ECBAF54D401C97715303C5494086048C2E6FFA4D401C97715303C5494086048C2E6FFA4D400F0EF62686C049405378D0ECBAF54D400F0EF62686C04940
49693	5098	59.919767	59.956518000000003	51.539164	51.504094000000002	Пушкинская	0103000020E610000001000000050000005378D0ECBAF54D400F0EF62686C049405378D0ECBAF54D401C97715303C5494086048C2E6FFA4D401C97715303C5494086048C2E6FFA4D400F0EF62686C049405378D0ECBAF54D400F0EF62686C04940
49794	5098	59.919767	59.956518000000003	51.539164	51.504094000000002	Майская	0103000020E610000001000000050000005378D0ECBAF54D400F0EF62686C049405378D0ECBAF54D401C97715303C5494086048C2E6FFA4D401C97715303C5494086048C2E6FFA4D400F0EF62686C049405378D0ECBAF54D400F0EF62686C04940
51283	47778	53.616056	53.623781000000001	53.792236000000003	53.787075999999999	Черемушки	0103000020E6100000010000000500000096404AECDACE4A40B6BB07E8BEE44A4096404AECDACE4A40605B3FFD67E54A40DF6E490ED8CF4A40605B3FFD67E54A40DF6E490ED8CF4A40B6BB07E8BEE44A4096404AECDACE4A40B6BB07E8BEE44A40
50408	4990	53.559021000000001	53.577590000000001	53.913550000000001	53.894601999999999	Тукаевская	0103000020E610000001000000050000007C6308008EC74A40D5777E5182F24A407C6308008EC74A4062A1D634EFF44A40923F1878EEC94A4062A1D634EFF44A40923F1878EEC94A40D5777E5182F24A407C6308008EC74A40D5777E5182F24A40
50256	4931	53.325271000000001	53.347630000000002	53.737009999999998	53.716692000000002	Оренбургская	0103000020E610000001000000050000002AABE97AA2A94A4005A73E90BCDB4A402AABE97AA2A94A409869FB5756DE4A40E38DCC237FAC4A409869FB5756DE4A40E38DCC237FAC4A4005A73E90BCDB4A402AABE97AA2A94A4005A73E90BCDB4A40
51045	5015	53.381433999999999	53.428874	53.921233999999998	53.893211000000001	Садовая	0103000020E610000001000000050000008ECA4DD4D2B04A40B7B6F0BC54F24A408ECA4DD4D2B04A404CFBE6FEEAF54A40670DDE57E5B64A404CFBE6FEEAF54A40670DDE57E5B64A40B7B6F0BC54F24A408ECA4DD4D2B04A40B7B6F0BC54F24A40
50320	4878	53.223474000000003	53.257815999999998	53.933512999999998	53.912928999999998	пер.Школьный	0103000020E61000000100000005000000CFC0C8CB9A9C4A40F54883DBDAF44A40CFC0C8CB9A9C4A4007B29E5A7DF74A4059315C1D00A14A4007B29E5A7DF74A4059315C1D00A14A40F54883DBDAF44A40CFC0C8CB9A9C4A40F54883DBDAF44A40
50689	4347	53.598070999999997	53.613422999999997	53.599497	53.580956	Центральная	0103000020E61000000100000005000000CFD72C978DCC4A401E3526C45CCA4A40CFD72C978DCC4A406A865451BCCC4A409ECE15A584CE4A406A865451BCCC4A409ECE15A584CE4A401E3526C45CCA4A40CFD72C978DCC4A401E3526C45CCA4A40
50355	46032	53.304358000000001	53.359316999999997	53.800581000000001	53.757621999999998	Советская	0103000020E610000001000000050000005323F433F5A64A40745DF8C1F9E04A405323F433F5A64A4045662E7079E64A40CBF27519FEAD4A4045662E7079E64A40CBF27519FEAD4A40745DF8C1F9E04A405323F433F5A64A40745DF8C1F9E04A40
51012	4148	53.483015000000002	53.502068000000001	53.680591	53.664428000000001	Коммунистическая	0103000020E610000001000000050000001D3D7E6FD3BD4A40FA4509FA0BD54A401D3D7E6FD3BD4A40D9791B9B1DD74A401F2FA4C343C04A40D9791B9B1DD74A401F2FA4C343C04A40FA4509FA0BD54A401D3D7E6FD3BD4A40FA4509FA0BD54A40
50430	47511	53.556812000000001	53.594315999999999	53.674084000000001	53.650196999999999	Школьная	0103000020E610000001000000050000009B02999D45C74A40897AC1A739D34A409B02999D45C74A40E1606F6248D64A40A9BEF38B12CC4A40E1606F6248D64A40A9BEF38B12CC4A40897AC1A739D34A409B02999D45C74A40897AC1A739D34A40
51024	3810	53.502895000000002	53.521785999999999	54.012394999999998	53.991152	Центральная	0103000020E61000000100000005000000352905DD5EC04A40B8AE9811DEFE4A40352905DD5EC04A4024D1CB2896014B405DC136E2C9C24A4024D1CB2896014B405DC136E2C9C24A40B8AE9811DEFE4A40352905DD5EC04A40B8AE9811DEFE4A40
51237	4510	53.918787999999999	53.946266999999999	53.520268999999999	53.499540000000003	Родниковая	0103000020E6100000010000000500000087FA5DD89AF54A409D853DEDF0BF4A4087FA5DD89AF54A40B20FB22C98C24A405B24ED461FF94A40B20FB22C98C24A405B24ED461FF94A409D853DEDF0BF4A4087FA5DD89AF54A409D853DEDF0BF4A40
51044	4412	53.350990000000003	53.382871000000002	53.821309999999997	53.802441999999999	Садовая	0103000020E610000001000000050000008D9C853DEDAC4A40EA77616BB6E64A408D9C853DEDAC4A405AF0A2AF20E94A401DCBBBEA01B14A405AF0A2AF20E94A401DCBBBEA01B14A40EA77616BB6E64A408D9C853DEDAC4A40EA77616BB6E64A40
51017	4261	53.676358999999998	53.706102999999999	53.548167999999997	53.523876999999999	Школьная	0103000020E6100000010000000500000079AD84EE92D64A403410CB660EC34A4079AD84EE92D64A405B5B785E2AC64A40C24D469561DA4A405B5B785E2AC64A40C24D469561DA4A403410CB660EC34A4079AD84EE92D64A403410CB660EC34A40
50488	47366	53.618993000000003	53.635494999999999	53.768065	53.757899000000002	Молодежная	0103000020E61000000100000005000000FAB9A1293BCF4A40E7559DD502E14A40FAB9A1293BCF4A40E31934F44FE24A40C1E270E657D14A40E31934F44FE24A40C1E270E657D14A40E7559DD502E14A40FAB9A1293BCF4A40E7559DD502E14A40
51020	4823	53.170904	53.196731	53.824328999999999	53.814830000000001	Школьная	0103000020E61000000100000005000000B760A92EE0954A405CE674594CE84A40B760A92EE0954A407B12D89C83E94A40008E3D7B2E994A407B12D89C83E94A40008E3D7B2E994A405CE674594CE84A40B760A92EE0954A405CE674594CE84A40
51041	56138	53.378658000000001	53.40558	53.669006000000003	53.650863999999999	Центральная	0103000020E61000000100000005000000342F87DD77B04A406612F5824FD34A40342F87DD77B04A40F56915FDA1D54A40B2F4A10BEAB34A40F56915FDA1D54A40B2F4A10BEAB34A406612F5824FD34A40342F87DD77B04A406612F5824FD34A40
51238	3945	53.810352000000002	53.836933000000002	53.560744	53.529904000000002	Васильевская	0103000020E61000000100000005000000C51F459DB9E74A408202EFE4D3C34A40C51F459DB9E74A40D0B69A75C6C74A40BAF8DB9E20EB4A40D0B69A75C6C74A40BAF8DB9E20EB4A408202EFE4D3C34A40C51F459DB9E74A408202EFE4D3C34A40
51043	3995	53.879756	53.931355000000003	53.476239999999997	53.452969000000003	Молодежная	0103000020E61000000100000005000000DA3A38D89BF04A40098D60E3FAB94A40DA3A38D89BF04A400586AC6EF5BC4A40A9FB00A436F74A400586AC6EF5BC4A40A9FB00A436F74A40098D60E3FAB94A40DA3A38D89BF04A40098D60E3FAB94A40
50266	47384	53.633195000000001	53.654736999999997	53.716372	53.702728999999998	Совхозная	0103000020E61000000100000005000000D07EA4880CD14A40B3791C06F3D94A40D07EA4880CD14A4093E2E313B2DB4A40963D096CCED34A4093E2E313B2DB4A40963D096CCED34A40B3791C06F3D94A40D07EA4880CD14A40B3791C06F3D94A40
50661	47584	53.133794999999999	53.145553999999997	53.847830000000002	53.829452000000003	Центральная	0103000020E6100000010000000500000025AFCE3120914A4008CDAE7B2BEA4A4025AFCE3120914A40AA4885B185EC4A40A7E67283A1924A40AA4885B185EC4A40A7E67283A1924A4008CDAE7B2BEA4A4025AFCE3120914A4008CDAE7B2BEA4A40
51280	56161	53.757100000000001	53.779594000000003	53.651094000000001	53.631512999999998	 Московская	0103000020E610000001000000050000009BE61DA7E8E04A40DAFF006BD5D04A409BE61DA7E8E04A40984F560C57D34A40341477BCC9E34A40984F560C57D34A40341477BCC9E34A40DAFF006BD5D04A409BE61DA7E8E04A40DAFF006BD5D04A40
51047	3897	53.403846999999999	53.426673000000001	53.763823000000002	53.750520000000002	Центральная	0103000020E610000001000000050000003ACB2C42B1B34A40397F130A11E04A403ACB2C42B1B34A406077BAF3C4E14A40098B8A389DB64A406077BAF3C4E14A40098B8A389DB64A40397F130A11E04A403ACB2C42B1B34A40397F130A11E04A40
50664	4428	53.411113999999998	53.460270000000001	53.809550999999999	53.785310000000003	 Школьная	0103000020E61000000100000005000000C07630629FB44A40639CBF0985E44A40C07630629FB44A40D8B8FE5D9FE74A403BAA9A20EABA4A40D8B8FE5D9FE74A403BAA9A20EABA4A40639CBF0985E44A40C07630629FB44A40639CBF0985E44A40
50559	3849	53.494225999999998	53.530383	53.728568000000003	53.708329999999997	Советская	0103000020E610000001000000050000009C6A2DCC42BF4A404963B48EAADA4A409C6A2DCC42BF4A40C1745AB741DD4A405CAD1397E3C34A40C1745AB741DD4A405CAD1397E3C34A404963B48EAADA4A409C6A2DCC42BF4A404963B48EAADA4A40
50663	47435	53.763415000000002	53.790401000000003	53.490524999999998	53.470730000000003	Школьна	0103000020E610000001000000050000004F232D95B7E14A40809F71E140BC4A404F232D95B7E14A40696FF085C9BE4A40E4DC26DC2BE54A40696FF085C9BE4A40E4DC26DC2BE54A40809F71E140BC4A404F232D95B7E14A40809F71E140BC4A40
50662	47192	53.490687000000001	53.508392000000001	54.051909999999999	54.033411000000001	Школьная	0103000020E6100000010000000500000043C9E4D4CEBE4A40D029C8CF46044B4043C9E4D4CEBE4A40ED2AA4FCA4064B4026C632FD12C14A40ED2AA4FCA4064B4026C632FD12C14A40D029C8CF46044B4043C9E4D4CEBE4A40D029C8CF46044B40
19482	50037	43.756003	43.757413999999997	56.263072000000001	56.258527999999998	Полевая	0103000020E61000000100000005000000C556D0B4C4E04540D68C0C7217214C40C556D0B4C4E04540253FE257AC214C402AC423F1F2E04540253FE257AC214C402AC423F1F2E04540D68C0C7217214C40C556D0B4C4E04540D68C0C7217214C40
16721	8797	44.022947000000002	44.032029000000001	56.212439000000003	56.201003999999998	Центральная	0103000020E610000001000000050000004A4563EDEF024640BE2EC37FBA194C404A4563EDEF0246408EB27E33311B4C4005C3B986190446408EB27E33311B4C4005C3B98619044640BE2EC37FBA194C404A4563EDEF024640BE2EC37FBA194C40
17283	49771	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Ленина	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17325	49771	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Казамазова	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17715	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	проспект Музрукова	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
18573	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Юности 	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17684	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Юности	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17777	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Шверника 	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17718	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Шверника	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
16843	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Чапаева	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17274	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Павлика Морозова	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17748	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Московская 	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17643	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Московская	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17280	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Ленина	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
16811	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Курчатова	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17081	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Куйбышева	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17624	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Зернова	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17134	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Гоголя 	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
19408	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Гоголя	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17937	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Герцена 	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
18417	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Гагарина 	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
16710	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Гагарина	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17732	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Александровича	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17141	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Академика Харитона	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17770	629	43.311705000000003	43.327210000000001	54.962260999999998	54.948529999999998	Академика Сахарова	0103000020E61000000100000005000000F67F0EF3E5A745402FA3586E69794B40F67F0EF3E5A74540AE9B525E2B7B4B404B766C04E2A94540AE9B525E2B7B4B404B766C04E2A945402FA3586E69794B40F67F0EF3E5A745402FA3586E69794B40
17347	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Чкалова	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17719	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Трудовая	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17723	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Суворова	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17356	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Пионерская	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17153	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Маяковского	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17669	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	М. Горького	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
9709	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Куйбышева	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17733	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Высокая	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17736	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	Аллея Ильича	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
17139	12248	43.040225999999997	43.123455	56.007237000000003	55.936599999999999	9-я Северная	0103000020E61000000100000005000000753925202685454080B74082E2F74B4075392520268545401C295B24ED004C408BC3995FCD8F45401C295B24ED004C408BC3995FCD8F454080B74082E2F74B40753925202685454080B74082E2F74B40
16800	42	43.851916000000003	43.878542000000003	56.232694000000002	56.219532000000001	шоссе Южное	0103000020E6100000010000000500000036785F950BED45407636E49F191C4C4036785F950BED4540DBFCBFEAC81D4C40CB14731074F04540DBFCBFEAC81D4C40CB14731074F045407636E49F191C4C4036785F950BED45407636E49F191C4C40
16676	42	43.851916000000003	43.878542000000003	56.232694000000002	56.219532000000001	шоссе Южное	0103000020E6100000010000000500000036785F950BED45407636E49F191C4C4036785F950BED4540DBFCBFEAC81D4C40CB14731074F04540DBFCBFEAC81D4C40CB14731074F045407636E49F191C4C4036785F950BED45407636E49F191C4C40
17962	42	43.936726	43.952680000000001	56.237442000000001	56.229571	улица Тропинина	0103000020E610000001000000050000000DA837A3E6F74540158E2095621D4C400DA837A3E6F745403259DC7F641E4C40D2C6116BF1F945403259DC7F641E4C40D2C6116BF1F94540158E2095621D4C400DA837A3E6F74540158E2095621D4C40
3630	42	43.812885000000001	43.823655000000002	56.368887999999998	56.360835999999999	улица Стрелковая	0103000020E6100000010000000500000059349D9D0CE84540179CC1DF2F2E4C4059349D9D0CE8454084F1D3B8372F4C40EC17EC866DE9454084F1D3B8372F4C40EC17EC866DE94540179CC1DF2F2E4C4059349D9D0CE84540179CC1DF2F2E4C40
3405	42	43.857782	43.865839999999999	56.348218000000003	56.345498999999997	улица Павла Мочалова	0103000020E610000001000000050000007A8CF2CCCBED45407DE6AC4F392C4C407A8CF2CCCBED454074F04C68922C4C40C9C859D8D3EE454074F04C68922C4C40C9C859D8D3EE45407DE6AC4F392C4C407A8CF2CCCBED45407DE6AC4F392C4C40
3263	42	43.745125000000002	43.758823999999997	56.386344000000001	56.384394999999998	улица Меднолитейная	0103000020E610000001000000050000004C37894160DF45407ADFF8DA33314C404C37894160DF4540BF805EB873314C40BFB5132521E14540BF805EB873314C40BFB5132521E145407ADFF8DA33314C404C37894160DF45407ADFF8DA33314C40
17309	42	43.985683999999999	43.988163999999998	56.307996000000003	56.301833000000002	улица Кулибина	0103000020E610000001000000050000006118B0E42AFE454042EDB776A2264C406118B0E42AFE454040A6B5696C274C40D28A6F287CFE454040A6B5696C274C40D28A6F287CFE454042EDB776A2264C406118B0E42AFE454042EDB776A2264C40
1553	42	43.906892999999997	43.921680000000002	56.33813	56.324984999999998	улица Куйбышева	0103000020E6100000010000000500000054FCDF1115F445406458C51B99294C4054FCDF1115F44540F3E505D8472B4C404BB0389CF9F54540F3E505D8472B4C404BB0389CF9F545406458C51B99294C4054FCDF1115F445406458C51B99294C40
7851	42	43.849617000000002	43.853731000000003	56.257832999999998	56.242924000000002	улица Краснодонцев	0103000020E610000001000000050000001590F63FC0EC4540EEB43522181F4C401590F63FC0EC45402F6AF7AB00214C406B4AB20E47ED45402F6AF7AB00214C406B4AB20E47ED4540EEB43522181F4C401590F63FC0EC4540EEB43522181F4C40
7456	42	43.779153000000001	43.795628000000001	56.201774999999998	56.199010999999999	улица Земляничная	0103000020E6100000010000000500000047CA1649BBE34540AA45443179194C4047CA1649BBE34540401361C3D3194C4015E46723D7E54540401361C3D3194C4015E46723D7E54540AA45443179194C4047CA1649BBE34540AA45443179194C40
17452	42	43.968454999999999	43.995395000000002	56.251491999999999	56.247295999999999	улица Героя Советского Союза Шапошникова	0103000020E61000000100000005000000E7525C55F6FB45403F373465A71F4C40E7525C55F6FB4540529ACDE330204C400CCD751A69FF4540529ACDE330204C400CCD751A69FF45403F373465A71F4C40E7525C55F6FB45403F373465A71F4C40
7169	42	43.842348999999999	43.871841000000003	56.241394	56.228805999999999	улица Героя Советского Союза Смирнова	0103000020E61000000100000005000000BE688F17D2EB45407590D783491D4C40BE688F17D2EB4540AEB9A3FFE51E4C40EE27637C98EF4540AEB9A3FFE51E4C40EE27637C98EF45407590D783491D4C40BE688F17D2EB45407590D783491D4C40
16795	42	44.001297000000001	44.033439000000001	56.317388000000001	56.309128999999999	улица Генкиной	0103000020E610000001000000050000009D4A06802A004640629F008A91274C409D4A06802A0046404912842BA0284C409AB4A9BA470446404912842BA0284C409AB4A9BA47044640629F008A91274C409D4A06802A004640629F008A91274C40
17498	42	44.014007999999997	44.041379999999997	56.317782000000001	56.280352000000001	улица Ванеева	0103000020E61000000100000005000000F1F09E03CB01464021AF0793E2234C40F1F09E03CB014640F5A0A014AD284C40AF5A99F04B054640F5A0A014AD284C40AF5A99F04B05464021AF0793E2234C40F1F09E03CB01464021AF0793E2234C40
17601	42	43.975659	43.983950999999998	56.270881000000003	56.268591000000001	улица Бонч-Бруевича	0103000020E610000001000000050000002786E464E2FC4540FE7F9C3061224C402786E464E2FC4540CC0D863AAC224C40E9EE3A1BF2FD4540CC0D863AAC224C40E9EE3A1BF2FD4540FE7F9C3061224C402786E464E2FC4540FE7F9C3061224C40
17219	42	43.982244000000001	44.034077000000003	56.295774999999999	56.289225000000002	улица Бекетова	0103000020E610000001000000050000009B58E02BBAFD4540C217265305254C409B58E02BBAFD4540B9FC87F4DB254C40DD4598A25C044640B9FC87F4DB254C40DD4598A25C044640C217265305254C409B58E02BBAFD4540C217265305254C40
19428	42	43.953479999999999	43.958770999999999	56.235444999999999	56.232748999999998	улица Академика Лебедева	0103000020E61000000100000005000000EEB1F4A10BFA45409E961FB8CA1D4C40EEB1F4A10BFA4540DC80CF0F231E4C4036AD1402B9FA4540DC80CF0F231E4C4036AD1402B9FA45409E961FB8CA1D4C40EEB1F4A10BFA45409E961FB8CA1D4C40
16688	42	43.953479999999999	43.958770999999999	56.235444999999999	56.232748999999998	улица Академика Лебедева	0103000020E61000000100000005000000EEB1F4A10BFA45409E961FB8CA1D4C40EEB1F4A10BFA4540DC80CF0F231E4C4036AD1402B9FA4540DC80CF0F231E4C4036AD1402B9FA45409E961FB8CA1D4C40EEB1F4A10BFA45409E961FB8CA1D4C40
7896	42	43.863126999999999	43.868561999999997	56.257447999999997	56.241269000000003	проспект Октября	0103000020E61000000100000005000000B5A50EF27AEE4540F24410E7E11E4C40B5A50EF27AEE4540D6355A0EF4204C403046240A2DEF4540D6355A0EF4204C403046240A2DEF4540F24410E7E11E4C40B5A50EF27AEE4540F24410E7E11E4C40
7645	42	43.800434000000003	43.863945000000001	56.247326000000001	56.240073000000002	проспект Молодежный	0103000020E61000000100000005000000A14D0E9F74E6454089D349B6BA1E4C40A14D0E9F74E64540AAB9DC60A81F4C407845F0BF95EE4540AAB9DC60A81F4C407845F0BF95EE454089D349B6BA1E4C40A14D0E9F74E6454089D349B6BA1E4C40
478	42	43.863630000000001	43.940283999999998	56.301338999999999	56.240862999999997	проспект Ленина	0103000020E6100000010000000500000018EC866D8BEE454081E84999D41E4C4018EC866D8BEE45403201BF4692264C40DD79E2395BF845403201BF4692264C40DD79E2395BF8454081E84999D41E4C4018EC866D8BEE454081E84999D41E4C40
3665	42	43.801735999999998	43.827311999999999	56.367562	56.358905999999998	проспект Кораблестроителей	0103000020E610000001000000050000004F0306499FE64540492BBEA1F02D4C404F0306499FE645404DA088450C2F4C404FCB0F5CE5E945404DA088450C2F4C404FCB0F5CE5E94540492BBEA1F02D4C404F0306499FE64540492BBEA1F02D4C40
7863	42	43.841225999999999	43.875677000000003	56.250526999999998	56.246746000000002	проспект Кирова	0103000020E61000000100000005000000BF45274BADEB45409C35785F951F4C40BF45274BADEB4540EBE1CB4411204C40016E162F16F04540EBE1CB4411204C40016E162F16F045409C35785F951F4C40BF45274BADEB45409C35785F951F4C40
17191	42	43.881148000000003	43.898018	56.323766999999997	56.315066000000002	проспект Героев	0103000020E61000000100000005000000C9772975C9F04540700A2B1554284C40C9772975C9F045401343723271294C40139CFA40F2F245401343723271294C40139CFA40F2F24540700A2B1554284C40C9772975C9F04540700A2B1554284C40
1454	42	43.881148000000003	43.898018	56.323766999999997	56.315066000000002	проспект Героев	0103000020E61000000100000005000000C9772975C9F04540700A2B1554284C40C9772975C9F045401343723271294C40139CFA40F2F245401343723271294C40139CFA40F2F24540700A2B1554284C40C9772975C9F04540700A2B1554284C40
19572	42	43.937876000000003	43.985595000000004	56.308241000000002	56.220218000000003	проспект Гагарина	0103000020E6100000010000000500000006DA1D520CF84540CAFE791A301C4C4006DA1D520CF84540A724EB7074274C40F20C1AFA27FE4540A724EB7074274C40F20C1AFA27FE4540CAFE791A301C4C4006DA1D520CF84540CAFE791A301C4C40
16810	42	43.937876000000003	43.985595000000004	56.308241000000002	56.220218000000003	проспект Гагарина	0103000020E6100000010000000500000006DA1D520CF84540CAFE791A301C4C4006DA1D520CF84540A724EB7074274C40F20C1AFA27FE4540A724EB7074274C40F20C1AFA27FE4540CAFE791A301C4C4006DA1D520CF84540CAFE791A301C4C40
16788	42	43.937876000000003	43.985595000000004	56.308241000000002	56.220218000000003	проспект Гагарина	0103000020E6100000010000000500000006DA1D520CF84540CAFE791A301C4C4006DA1D520CF84540A724EB7074274C40F20C1AFA27FE4540A724EB7074274C40F20C1AFA27FE4540CAFE791A301C4C4006DA1D520CF84540CAFE791A301C4C40
19802	42	43.937876000000003	43.985595000000004	56.308241000000002	56.220218000000003	проспект Гагарина	0103000020E6100000010000000500000006DA1D520CF84540CAFE791A301C4C4006DA1D520CF84540A724EB7074274C40F20C1AFA27FE4540A724EB7074274C40F20C1AFA27FE4540CAFE791A301C4C4006DA1D520CF84540CAFE791A301C4C40
2297	42	43.937876000000003	43.985595000000004	56.308241000000002	56.220218000000003	проспект Гагарина	0103000020E6100000010000000500000006DA1D520CF84540CAFE791A301C4C4006DA1D520CF84540A724EB7074274C40F20C1AFA27FE4540A724EB7074274C40F20C1AFA27FE4540CAFE791A301C4C4006DA1D520CF84540CAFE791A301C4C40
8023	42	43.882269999999998	43.902859999999997	56.274180000000001	56.257823000000002	проспект Бусыгина	0103000020E61000000100000005000000F71E2E39EEF045400C94145800214C40F71E2E39EEF04540D09B8A5418234C40EB6E9EEA90F34540D09B8A5418234C40EB6E9EEA90F345400C94145800214C40F71E2E39EEF045400C94145800214C40
16826	42	43.607072000000002	44.170639000000001	56.421180999999997	56.155709000000002	поселок Мостоотряд	0103000020E610000001000000050000009E280989B4CD4540B058C345EE134C409E280989B4CD454029594E42E9354C400936AE7FD715464029594E42E9354C400936AE7FD7154640B058C345EE134C409E280989B4CD4540B058C345EE134C40
2098	42	44.014017000000003	44.015841000000002	56.318635999999998	56.317782000000001	площадь Свободы	0103000020E61000000100000005000000454B1E4FCB014640F5A0A014AD284C40454B1E4FCB01464004AA7F10C9284C40CD77F0130702464004AA7F10C9284C40CD77F01307024640F5A0A014AD284C40454B1E4FCB014640F5A0A014AD284C40
19562	42	43.945951999999998	43.948754999999998	56.322335000000002	56.321137	площадь Революции	0103000020E61000000100000005000000FBCA83F414F945408D4468041B294C40FBCA83F414F9454097ADF54542294C404F75C8CD70F9454097ADF54542294C404F75C8CD70F945408D4468041B294C40FBCA83F414F945408D4468041B294C40
1992	42	43.997632000000003	44.002949999999998	56.319200000000002	56.319020000000002	переулок Холодный	0103000020E61000000100000005000000B7B8C667B2FF45408D62B9A5D5284C40B7B8C667B2FF45400D71AC8BDB284C40F8C264AA600046400D71AC8BDB284C40F8C264AA600046408D62B9A5D5284C40B7B8C667B2FF45408D62B9A5D5284C40
1907	42	43.987876	43.988002000000002	56.324250999999997	56.323188000000002	переулок Урожайный	0103000020E610000001000000050000006C4084B872FE4540D63A71395E294C406C4084B872FE4540FF58880E81294C40F9307BD976FE4540FF58880E81294C40F9307BD976FE4540D63A71395E294C406C4084B872FE4540D63A71395E294C40
3299	42	43.826422000000001	43.831569999999999	56.380194000000003	56.378279999999997	переулок Общественный	0103000020E61000000100000005000000F3583332C8E945408D5DA27A6B304C40F3583332C8E9454056116E32AA304C40D82AC1E270EA454056116E32AA304C40D82AC1E270EA45408D5DA27A6B304C40F3583332C8E945408D5DA27A6B304C40
17269	42	43.90842	44.050812000000001	56.284103999999999	56.183503000000002	микрорайон Щербинки-I	0103000020E610000001000000050000002384471B47F44540E4DBBB067D174C402384471B47F44540D65416855D244C40471FF30181064640D65416855D244C40471FF30181064640E4DBBB067D174C402384471B47F44540E4DBBB067D174C40
17476	42	43.607072000000002	44.170639000000001	56.421180999999997	56.155709000000002	микрорайон Щербинки-I	0103000020E610000001000000050000009E280989B4CD4540B058C345EE134C409E280989B4CD454029594E42E9354C400936AE7FD715464029594E42E9354C400936AE7FD7154640B058C345EE134C409E280989B4CD4540B058C345EE134C40
302	42	43.950029999999998	43.959130000000002	56.329805999999998	56.326472000000003	бульвар Мира	0103000020E61000000100000005000000041C42959AF94540A587A1D5C9294C40041C42959AF9454025034015372A4C40664E97C5C4FA454025034015372A4C40664E97C5C4FA4540A587A1D5C9294C40041C42959AF94540A587A1D5C9294C40
888	42	43.928694999999998	43.948296999999997	56.287636999999997	56.282235	бульвар Заречный	0103000020E61000000100000005000000B77A4E7ADFF64540AE64C74620244C40B77A4E7ADFF645404D0F0A4AD1244C408CF2CCCB61F945404D0F0A4AD1244C408CF2CCCB61F94540AE64C74620244C40B77A4E7ADFF64540AE64C74620244C40
17023	42	44.035936	44.051513	56.285029000000002	56.281936000000002	бульвар 60-летия Октября	0103000020E61000000100000005000000E15F048D9904464054C8957A16244C40E15F048D99044640AFB48CD47B244C40D0285DFA97064640AFB48CD47B244C40D0285DFA9706464054C8957A16244C40E15F048D9904464054C8957A16244C40
19625	42	43.886159999999997	43.890337000000002	56.312280000000001	56.312190000000001	Якорная	0103000020E61000000100000005000000FD82DDB06DF14540B21188D7F5274C40FD82DDB06DF14540F29881CAF8274C409AB51490F6F14540F29881CAF8274C409AB51490F6F14540B21188D7F5274C40FD82DDB06DF14540B21188D7F5274C40
19667	42	44.048701000000001	44.059023000000003	56.312863999999998	56.309843000000001	Яблоневая	0103000020E61000000100000005000000292499D53B06464080F277EFA8274C40292499D53B064640410C74ED0B284C401D5BCF108E074640410C74ED0B284C401D5BCF108E07464080F277EFA8274C40292499D53B06464080F277EFA8274C40
19579	42	43.866218000000003	43.884256000000001	56.242769000000003	56.228431	Юлиуса Фучика	0103000020E61000000100000005000000709A3E3BE0EE454040321D3A3D1D4C40709A3E3BE0EE4540C7BDF90D131F4C4059A5F44C2FF14540C7BDF90D131F4C4059A5F44C2FF1454040321D3A3D1D4C40709A3E3BE0EE454040321D3A3D1D4C40
19645	42	43.864753	43.872182000000002	56.345348999999999	56.338583999999997	Энгельса	0103000020E61000000100000005000000170FEF39B0EE4540747973B8562B4C40170FEF39B0EE4540685A6265342C4C407714E7A8A3EF4540685A6265342C4C407714E7A8A3EF4540747973B8562B4C40170FEF39B0EE4540747973B8562B4C40
19744	42	43.849409999999999	43.884633000000001	56.303485999999999	56.293166999999997	Электровозная	0103000020E610000001000000050000009B728577B9EC45401AA20A7F86254C409B728577B9EC45409D6516A1D8264C402FFB75A73BF145409D6516A1D8264C402FFB75A73BF145401AA20A7F86254C409B728577B9EC45401AA20A7F86254C40
19604	42	43.852806000000001	43.856560999999999	56.257537999999997	56.242623999999999	Школьная	0103000020E6100000010000000500000092EA3BBF28ED4540C39CA04D0E1F4C4092EA3BBF28ED454016BD5301F7204C40B80375CAA3ED454016BD5301F7204C40B80375CAA3ED4540C39CA04D0E1F4C4092EA3BBF28ED4540C39CA04D0E1F4C40
19566	42	43.916145999999998	43.924357000000001	56.329103000000003	56.32526	Шаляпина	0103000020E610000001000000050000003C2EAA4544F545403659A31EA2294C403C2EAA4544F54540FC010F0C202A4C40126A865451F64540FC010F0C202A4C40126A865451F645403659A31EA2294C403C2EAA4544F545403659A31EA2294C40
19777	42	43.935603	43.945548000000002	56.319884000000002	56.313153999999997	Чкалова	0103000020E610000001000000050000000E85CFD6C1F74540484E266E15284C400E85CFD6C1F74540C0417BF5F1284C402C6684B707F94540C0417BF5F1284C402C6684B707F94540484E266E15284C400E85CFD6C1F74540484E266E15284C40
19731	42	43.845080000000003	43.853704	56.339047999999998	56.329557000000001	Черняховского	0103000020E610000001000000050000007940D9942BEC45407D957CEC2E2A4C407940D9942BEC454019E3C3EC652B4C40713B342C46ED454019E3C3EC652B4C40713B342C46ED45407D957CEC2E2A4C407940D9942BEC45407D957CEC2E2A4C40
19662	42	43.85604	43.859893	56.259858000000001	56.242289	Челюскинцев	0103000020E61000000100000005000000AF08FEB792ED45401C977153031F4C40AF08FEB792ED45404FCDE50643214C4098874CF910EE45404FCDE50643214C4098874CF910EE45401C977153031F4C40AF08FEB792ED45401C977153031F4C40
19697	42	43.857045999999997	43.861555000000003	56.361983000000002	56.360616	Чайковского	0103000020E610000001000000050000007495EEAEB3ED4540093543AA282E4C407495EEAEB3ED45409F5A7D75552E4C40475A2A6F47EE45409F5A7D75552E4C40475A2A6F47EE4540093543AA282E4C407495EEAEB3ED4540093543AA282E4C40
19733	42	43.814933000000003	43.861645000000003	56.331812999999997	56.325704000000002	Чаадаева	0103000020E6100000010000000500000031B77BB94FE8454094162EABB0294C4031B77BB94FE845409EB12FD9782A4C4087E123624AEE45409EB12FD9782A4C4087E123624AEE454094162EABB0294C4031B77BB94FE8454094162EABB0294C40
19760	42	43.814933000000003	43.861645000000003	56.331812999999997	56.325704000000002	Чаадаева	0103000020E6100000010000000500000031B77BB94FE8454094162EABB0294C4031B77BB94FE845409EB12FD9782A4C4087E123624AEE45409EB12FD9782A4C4087E123624AEE454094162EABB0294C4031B77BB94FE8454094162EABB0294C40
19599	42	44.054836999999999	44.056399999999996	56.319673999999999	56.3155	Фруктовая	0103000020E610000001000000050000002DCE18E604074640AAF1D24D62284C402DCE18E604074640D5B0DF13EB284C4048BF7D1D38074640D5B0DF13EB284C4048BF7D1D38074640AAF1D24D62284C402DCE18E604074640AAF1D24D62284C40
19524	42	43.78951	43.834220000000002	56.351658999999998	56.337291999999998	Федосеенко	0103000020E61000000100000005000000B7EEE6A90EE54540E9995E622C2B4C40B7EEE6A90EE545400A2C8029032D4C40A6D590B8C7EA45400A2C8029032D4C40A6D590B8C7EA4540E9995E622C2B4C40B7EEE6A90EE54540E9995E622C2B4C40
19703	42	43.845241999999999	43.853856999999998	56.303102000000003	56.291308999999998	Ухтомского	0103000020E61000000100000005000000529ACDE330EC4540E603029D49254C40529ACDE330EC454015ADDC0BCC264C40F73AA92F4BED454015ADDC0BCC264C40F73AA92F4BED4540E603029D49254C40529ACDE330EC4540E603029D49254C40
19804	42	44.008159999999997	44.026387	56.326546999999998	56.322299999999998	Ульянова	0103000020E6100000010000000500000053910A630B0146401AC05B2041294C4053910A630B014640AFCDC64ACC294C40100533A660034640AFCDC64ACC294C40100533A6600346401AC05B2041294C4053910A630B0146401AC05B2041294C40
16749	42	43.977285000000002	43.983348999999997	56.265957	56.265506999999999	Углова	0103000020E6100000010000000500000089EFC4AC17FD4540F6ED2422FC214C4089EFC4AC17FD4540369204E10A224C40F3C64961DEFD4540369204E10A224C40F3C64961DEFD4540F6ED2422FC214C4089EFC4AC17FD4540F6ED2422FC214C40
19616	42	43.941226999999998	43.948566	56.303012000000003	56.302453	Тургайская	0103000020E610000001000000050000005C8E57207AF84540DEC9A7C7B6264C405C8E57207AF84540D525E318C9264C407C0C569C6AF94540D525E318C9264C407C0C569C6AF94540DEC9A7C7B6264C405C8E57207AF84540DEC9A7C7B6264C40
19636	42	43.930492000000001	43.941955	56.326053000000002	56.322105000000001	Тонкинская 	0103000020E610000001000000050000004698A25C1AF74540657094BC3A294C404698A25C1AF74540A0E1CD1ABC294C40DFA63FFB91F84540A0E1CD1ABC294C40DFA63FFB91F84540657094BC3A294C404698A25C1AF74540657094BC3A294C40
19686	42	43.930492000000001	43.941955	56.326053000000002	56.322105000000001	Тонкинская	0103000020E610000001000000050000004698A25C1AF74540657094BC3A294C404698A25C1AF74540A0E1CD1ABC294C40DFA63FFB91F84540A0E1CD1ABC294C40DFA63FFB91F84540657094BC3A294C404698A25C1AF74540657094BC3A294C40
17284	42	43.977671999999998	43.990122	56.276029000000001	56.274369	Терешковой	0103000020E61000000100000005000000821B295B24FD4540A304FD851E234C40821B295B24FD4540B1DF13EB54234C406A865451BCFE4540B1DF13EB54234C406A865451BCFE4540A304FD851E234C40821B295B24FD4540A304FD851E234C40
19556	42	43.808788	43.817286000000003	56.311326000000001	56.308770000000003	Тепличная	0103000020E61000000100000005000000D9B27C5D86E7454033FE7DC685274C40D9B27C5D86E745407F32C687D9274C4045BDE0D39CE845407F32C687D9274C4045BDE0D39CE8454033FE7DC685274C40D9B27C5D86E7454033FE7DC685274C40
19728	42	43.930968	43.934921000000003	56.284633999999997	56.281556000000002	Сухопутная	0103000020E61000000100000005000000AFCF9CF529F745400DFFE9060A244C40AFCF9CF529F7454032AA0CE36E244C40FCABC77DABF7454032AA0CE36E244C40FCABC77DABF745400DFFE9060A244C40AFCF9CF529F745400DFFE9060A244C40
19690	42	43.842143	43.863602999999998	56.265256999999998	56.254317	Строкина	0103000020E6100000010000000500000015C78157CBEB45408EE89E758D204C4015C78157CBEB45407D04FEF0F3214C401EDD088B8AEE45407D04FEF0F3214C401EDD088B8AEE45408EE89E758D204C4015C78157CBEB45408EE89E758D204C40
19626	42	43.852302999999999	43.862704999999998	56.234744999999997	56.226494000000002	Старых производственников	0103000020E610000001000000050000002FA4C34318ED4540C05E61C1FD1C4C402FA4C34318ED454023F3C81F0C1E4C403F8C101E6DEE454023F3C81F0C1E4C403F8C101E6DEE4540C05E61C1FD1C4C402FA4C34318ED4540C05E61C1FD1C4C40
19680	42	43.852302999999999	43.862704999999998	56.234744999999997	56.226494000000002	Старых Производственников	0103000020E610000001000000050000002FA4C34318ED4540C05E61C1FD1C4C402FA4C34318ED454023F3C81F0C1E4C403F8C101E6DEE454023F3C81F0C1E4C403F8C101E6DEE4540C05E61C1FD1C4C402FA4C34318ED4540C05E61C1FD1C4C40
19785	42	43.832799999999999	43.839843000000002	56.357235000000003	56.350586999999997	Станиславского	0103000020E61000000100000005000000ED0DBE3099EA45408DB3E908E02C4C40ED0DBE3099EA454048FE60E0B92D4C402463B5F97FEB454048FE60E0B92D4C402463B5F97FEB45408DB3E908E02C4C40ED0DBE3099EA45408DB3E908E02C4C40
19620	42	43.827095999999997	43.835441000000003	56.241064000000001	56.239542999999998	Спутника	0103000020E6100000010000000500000082531F48DEE945402C7E5358A91E4C4082531F48DEE94540191F662FDB1E4C40685E0EBBEFEA4540191F662FDB1E4C40685E0EBBEFEA45402C7E5358A91E4C4082531F48DEE945402C7E5358A91E4C40
19654	42	43.827095999999997	43.835441000000003	56.241064000000001	56.239542999999998	Спутника	0103000020E6100000010000000500000082531F48DEE945402C7E5358A91E4C4082531F48DEE94540191F662FDB1E4C40685E0EBBEFEA4540191F662FDB1E4C40685E0EBBEFEA45402C7E5358A91E4C4082531F48DEE945402C7E5358A91E4C40
19708	42	43.877312000000003	43.878399000000002	56.335729999999998	56.333365000000001	Софьи Перовской	0103000020E61000000100000005000000B63176C24BF04540C6504EB4AB2A4C40B63176C24BF045409E245D33F92A4C4068EBE0606FF045409E245D33F92A4C4068EBE0606FF04540C6504EB4AB2A4C40B63176C24BF04540C6504EB4AB2A4C40
19711	42	43.877312000000003	43.878399000000002	56.335729999999998	56.333365000000001	Софьи Перовской	0103000020E61000000100000005000000B63176C24BF04540C6504EB4AB2A4C40B63176C24BF045409E245D33F92A4C4068EBE0606FF045409E245D33F92A4C4068EBE0606FF04540C6504EB4AB2A4C40B63176C24BF04540C6504EB4AB2A4C40
19795	42	43.845790000000001	43.856560999999999	56.258702999999997	56.257537999999997	Советской Армии	0103000020E6100000010000000500000055A4C2D842EC454016BD5301F7204C4055A4C2D842EC454044300E2E1D214C40B80375CAA3ED454044300E2E1D214C40B80375CAA3ED454016BD5301F7204C4055A4C2D842EC454016BD5301F7204C40
19725	42	43.908304000000001	43.920889000000003	56.290833999999997	56.274209999999997	Снежная	0103000020E61000000100000005000000BA69334E43F445403A1E335019234C40BA69334E43F445404D486B0C3A254C40821FD5B0DFF545404D486B0C3A254C40821FD5B0DFF545403A1E335019234C40BA69334E43F445403A1E335019234C40
19740	42	43.996743000000002	44.005949999999999	56.313538000000001	56.312564999999999	Славянская 	0103000020E610000001000000050000002BC24D4695FF4540E76F422102284C402BC24D4695FF4540D106600322284C40A2B437F8C2004640D106600322284C40A2B437F8C2004640E76F422102284C402BC24D4695FF4540E76F422102284C40
19771	42	43.996743000000002	44.005949999999999	56.313538000000001	56.312564999999999	Славянская	0103000020E610000001000000050000002BC24D4695FF4540E76F422102284C402BC24D4695FF4540D106600322284C40A2B437F8C2004640D106600322284C40A2B437F8C2004640E76F422102284C402BC24D4695FF4540E76F422102284C40
19607	42	43.928507000000003	43.946814000000003	56.339576999999998	56.331533	Сергея Есенина	0103000020E61000000100000005000000B58D3F51D9F64540BB4560AC6F2A4C40B58D3F51D9F64540A5BC5642772B4C408EB27E3331F94540A5BC5642772B4C408EB27E3331F94540BB4560AC6F2A4C40B58D3F51D9F64540BB4560AC6F2A4C40
19671	42	43.922578000000001	43.945126000000002	56.349499999999999	56.330325000000002	Сергея Акимова	0103000020E610000001000000050000002A01310917F645408E06F016482A4C402A01310917F64540DBF97E6ABC2C4C40B64C86E3F9F84540DBF97E6ABC2C4C40B64C86E3F9F845408E06F016482A4C402A01310917F645408E06F016482A4C40
18198	42	43.607072000000002	44.170639000000001	56.421180999999997	56.155709000000002	Свирская	0103000020E610000001000000050000009E280989B4CD4540B058C345EE134C409E280989B4CD454029594E42E9354C400936AE7FD715464029594E42E9354C400936AE7FD7154640B058C345EE134C409E280989B4CD4540B058C345EE134C40
19794	42	43.831524999999999	43.838019000000003	56.240253000000003	56.237206999999998	Сазанова	0103000020E61000000100000005000000386744696FEA4540EEB089CC5C1E4C40386744696FEA454009E23C9CC01E4C409C36E33444EB454009E23C9CC01E4C409C36E33444EB4540EEB089CC5C1E4C40386744696FEA4540EEB089CC5C1E4C40
19684	42	43.926782000000003	43.937489999999997	56.300370000000001	56.297953	Рубо	0103000020E61000000100000005000000C042E6CAA0F645405F5FEB5223264C40C042E6CAA0F645408A592F8672264C40DC291DACFFF745408A592F8672264C40DC291DACFFF745405F5FEB5223264C40C042E6CAA0F645405F5FEB5223264C40
19534	42	44.041946000000003	44.080393999999998	56.321435999999999	56.298541999999998	Родионова	0103000020E6100000010000000500000059198D7C5E054640C03DCF9F36264C4059198D7C5E054640E7E099D024294C40B665C0594A0A4640E7E099D024294C40B665C0594A0A4640C03DCF9F36264C4059198D7C5E054640C03DCF9F36264C40
19742	42	44.042979000000003	44.045242999999999	56.321271000000003	56.315845000000003	Радужная	0103000020E6100000010000000500000018B5FB558005464075CDE49B6D284C4018B5FB55800546409D137B681F294C40BCAFCA85CA0546409D137B681F294C40BCAFCA85CA05464075CDE49B6D284C4018B5FB558005464075CDE49B6D284C40
19769	42	43.846949000000002	43.873638	56.296599000000001	56.286881999999999	Путейская	0103000020E61000000100000005000000A13028D368EC4540D1E7A38CB8244C40A13028D368EC45405E83BEF4F6254C407C45B75ED3EF45405E83BEF4F6254C407C45B75ED3EF4540D1E7A38CB8244C40A13028D368EC4540D1E7A38CB8244C40
19609	42	43.851216000000001	43.864393999999997	56.351664	56.350298000000002	Пугачева	0103000020E610000001000000050000007DEA58A5F4EC454057ED9A90D62C4C407DEA58A5F4EC45401C977153032D4C40E76D6C76A4EE45401C977153032D4C40E76D6C76A4EE454057ED9A90D62C4C407DEA58A5F4EC454057ED9A90D62C4C40
19683	42	43.867393999999997	43.881461999999999	56.326546999999998	56.323766999999997	Просвещенская 	0103000020E61000000100000005000000915F3FC406EF45401343723271294C40915F3FC406EF4540AFCDC64ACC294C4058552FBFD3F04540AFCDC64ACC294C4058552FBFD3F045401343723271294C40915F3FC406EF45401343723271294C40
19745	42	43.913899999999998	43.924878	56.292493	56.290799	Премудрова	0103000020E610000001000000050000003EE8D9ACFAF44540D15AD1E638254C403EE8D9ACFAF445408BA71E6970254C401B65FD6662F645408BA71E6970254C401B65FD6662F64540D15AD1E638254C403EE8D9ACFAF44540D15AD1E638254C40
19674	42	43.911070000000002	43.911942000000003	56.298976000000003	56.293382000000001	Порт-Артурская 	0103000020E61000000100000005000000F12E17F19DF44540179E978A8D254C40F12E17F19DF44540FB2477D844264C40A7ECF483BAF44540FB2477D844264C40A7ECF483BAF44540179E978A8D254C40F12E17F19DF44540179E978A8D254C40
1916	42	43.991101	43.994200999999997	56.323498000000001	56.320827000000001	Плотничный переулок	0103000020E610000001000000050000003604C765DCFE45403F56F0DB10294C403604C765DCFE45402429E96168294C40435376FA41FF45402429E96168294C40435376FA41FF45403F56F0DB10294C403604C765DCFE45403F56F0DB10294C40
19717	42	44.002375000000001	44.016855999999997	56.329371999999999	56.323922000000003	Пискунова	0103000020E61000000100000005000000FCA9F1D24D0046403B3AAE4676294C40FCA9F1D24D004640EB1B98DC282A4C40E55E605628024640EB1B98DC282A4C40E55E6056280246403B3AAE4676294C40FCA9F1D24D0046403B3AAE4676294C40
19668	42	43.861277000000001	43.884695999999998	56.274180000000001	56.266171999999997	Пермякова	0103000020E6100000010000000500000004E621533EEE4540328E91EC11224C4004E621533EEE4540D09B8A5418234C407573F1B73DF14540D09B8A5418234C407573F1B73DF14540328E91EC11224C4004E621533EEE4540328E91EC11224C40
19647	42	43.930168999999999	43.935298000000003	56.268666000000003	56.265506999999999	Партизанская	0103000020E6100000010000000500000063601DC70FF74540F6ED2422FC214C4063601DC70FF7454009C6C1A563224C40D20149D8B7F7454009C6C1A563224C40D20149D8B7F74540F6ED2422FC214C4063601DC70FF74540F6ED2422FC214C40
16827	42	44.006993000000001	44.023989	56.324122000000003	56.304724999999998	Ошарская улица	0103000020E6100000010000000500000085268925E500464005A3923A01274C4085268925E500464002F566D47C294C405C3B51121203464002F566D47C294C405C3B51121203464005A3923A01274C4085268925E500464005A3923A01274C40
19714	42	44.006993000000001	44.023989	56.324122000000003	56.304724999999998	Ошарская	0103000020E6100000010000000500000085268925E500464005A3923A01274C4085268925E500464002F566D47C294C405C3B51121203464002F566D47C294C405C3B51121203464005A3923A01274C4085268925E500464005A3923A01274C40
19698	42	43.932181	43.946168	56.315955000000002	56.299556000000003	Октябрьской Революции	0103000020E61000000100000005000000EE79FEB451F7454009A9DBD957264C40EE79FEB451F74540FC00A43671284C40C84274081CF94540FC00A43671284C40C84274081CF9454009A9DBD957264C40EE79FEB451F7454009A9DBD957264C40
16456	42	43.997847999999998	44.010899999999999	56.322499000000001	56.321865000000003	Октябрьская улица	0103000020E610000001000000050000008330B77BB9FF4540105D50DF32294C408330B77BB9FF454011FFB0A547294C4061C3D32B6501464011FFB0A547294C4061C3D32B65014640105D50DF32294C408330B77BB9FF4540105D50DF32294C40
19608	42	43.927554999999998	43.938791999999999	56.316203999999999	56.310253000000003	Обухова	0103000020E61000000100000005000000E21E4B1FBAF64540323ECC5EB6274C40E21E4B1FBAF64540A46E675F79284C408BDF14562AF84540A46E675F79284C408BDF14562AF84540323ECC5EB6274C40E21E4B1FBAF64540323ECC5EB6274C40
19650	42	43.921491000000003	43.928075999999997	56.276409000000001	56.274889000000002	Норильская	0103000020E610000001000000050000007847C66AF3F54540DC8310902F234C407847C66AF3F54540F8A8BF5E61234C40EB19C231CBF64540F8A8BF5E61234C40EB19C231CBF64540DC8310902F234C407847C66AF3F54540DC8310902F234C40
19746	42	43.844253999999999	43.853074999999997	56.348596999999998	56.344386	Никиты Рыбакова	0103000020E6100000010000000500000033C2DB8310EC4540A29927D7142C4C4033C2DB8310EC4540EA3D95D39E2C4C408104C58F31ED4540EA3D95D39E2C4C408104C58F31ED4540A29927D7142C4C4033C2DB8310EC4540A29927D7142C4C40
17613	42	43.975318000000001	44.014133999999999	56.331927	56.323118000000001	Нижневолжская набережная	0103000020E610000001000000050000009E996038D7FC4540DD5F3DEE5B294C409E996038D7FC454067D47C957C2A4C407EE19524CF01464067D47C957C2A4C407EE19524CF014640DD5F3DEE5B294C409E996038D7FC4540DD5F3DEE5B294C40
19613	42	44.013388999999997	44.018841000000002	56.328887999999999	56.322474	Нестерова	0103000020E61000000100000005000000259012BBB6014640B8E7F9D346294C40259012BBB6014640FF058200192A4C407769C36169024640FF058200192A4C407769C36169024640B8E7F9D346294C40259012BBB6014640B8E7F9D346294C40
19546	42	44.000902000000004	44.031975000000003	56.318950000000001	56.309303999999997	Невзоровых	0103000020E610000001000000050000002140868E1D004640D042024697274C402140868E1D0046409487855AD3284C4012A5BDC1170446409487855AD3284C4012A5BDC117044640D042024697274C402140868E1D004640D042024697274C40
19793	42	43.99288	43.995575000000002	56.290523999999998	56.281095999999998	Нартова	0103000020E610000001000000050000001E6D1CB116FF4540A98427F4FA234C401E6D1CB116FF4540FF59F3E32F254C408CDB68006FFF4540FF59F3E32F254C408CDB68006FFF4540A98427F4FA234C401E6D1CB116FF4540A98427F4FA234C40
19689	42	43.901018000000001	43.924805999999997	56.336533000000003	56.330590000000001	Народная	0103000020E61000000100000005000000BD8DCD8E54F345403C31EBC5502A4C40BD8DCD8E54F345402C836A83132B4C408192020B60F645402C836A83132B4C408192020B60F645403C31EBC5502A4C40BD8DCD8E54F345403C31EBC5502A4C40
17245	42	43.901018000000001	43.924805999999997	56.336533000000003	56.330590000000001	Народная	0103000020E61000000100000005000000BD8DCD8E54F345403C31EBC5502A4C40BD8DCD8E54F345402C836A83132B4C408192020B60F645402C836A83132B4C408192020B60F645403C31EBC5502A4C40BD8DCD8E54F345403C31EBC5502A4C40
19533	42	43.901018000000001	43.924805999999997	56.336533000000003	56.330590000000001	Народная	0103000020E61000000100000005000000BD8DCD8E54F345403C31EBC5502A4C40BD8DCD8E54F345402C836A83132B4C408192020B60F645402C836A83132B4C408192020B60F645403C31EBC5502A4C40BD8DCD8E54F345403C31EBC5502A4C40
19633	42	44.031830999999997	44.055591	56.302987000000002	56.300244999999997	Надежды Сусловой	0103000020E61000000100000005000000DEFFC70913044640CDE49B6D6E264C40DEFFC709130446407C0E2C47C8264C40D9791B9B1D0746407C0E2C47C8264C40D9791B9B1D074640CDE49B6D6E264C40DEFFC70913044640CDE49B6D6E264C40
17296	42	44.031830999999997	44.055591	56.302987000000002	56.300244999999997	Надежды Сусловой	0103000020E61000000100000005000000DEFFC70913044640CDE49B6D6E264C40DEFFC709130446407C0E2C47C8264C40D9791B9B1D0746407C0E2C47C8264C40D9791B9B1D074640CDE49B6D6E264C40DEFFC70913044640CDE49B6D6E264C40
17564	42	43.799669999999999	43.953677999999996	56.326393000000003	56.310817	Московское шоссе	0103000020E61000000100000005000000D1CB28965BE645403A05F9D9C8274C40D1CB28965BE645405952EE3EC7294C401475E61E12FA45405952EE3EC7294C401475E61E12FA45403A05F9D9C8274C40D1CB28965BE645403A05F9D9C8274C40
145	42	43.799669999999999	43.953677999999996	56.326393000000003	56.310817	Московское шоссе	0103000020E61000000100000005000000D1CB28965BE645403A05F9D9C8274C40D1CB28965BE645405952EE3EC7294C401475E61E12FA45405952EE3EC7294C401475E61E12FA45403A05F9D9C8274C40D1CB28965BE645403A05F9D9C8274C40
19498	42	43.799669999999999	43.953677999999996	56.326393000000003	56.310817	Московское шоссе	0103000020E61000000100000005000000D1CB28965BE645403A05F9D9C8274C40D1CB28965BE645405952EE3EC7294C401475E61E12FA45405952EE3EC7294C401475E61E12FA45403A05F9D9C8274C40D1CB28965BE645403A05F9D9C8274C40
19653	42	43.820008000000001	43.835836999999998	56.236671000000001	56.224801999999997	Мончегорская	0103000020E61000000100000005000000AC3AAB05F6E84540A609DB4FC61C4C40AC3AAB05F6E84540B0743E3C4B1E4C40B4E4F1B4FCEA4540B0743E3C4B1E4C40B4E4F1B4FCEA4540A609DB4FC61C4C40AC3AAB05F6E84540A609DB4FC61C4C40
19756	42	43.826053999999999	43.839303999999998	56.358685999999999	56.354083000000003	Мокроусова	0103000020E61000000100000005000000705D3123BCE94540E8887C97522D4C40705D3123BCE945403BC43F6CE92D4C4074B33F506EEB45403BC43F6CE92D4C4074B33F506EEB4540E8887C97522D4C40705D3123BCE94540E8887C97522D4C40
19675	42	43.826053999999999	43.839303999999998	56.358685999999999	56.354083000000003	Мокроусова	0103000020E61000000100000005000000705D3123BCE94540E8887C97522D4C40705D3123BCE945403BC43F6CE92D4C4074B33F506EEB45403BC43F6CE92D4C4074B33F506EEB4540E8887C97522D4C40705D3123BCE94540E8887C97522D4C40
19540	42	43.836635999999999	43.840220000000002	56.337052	56.331482999999999	Мирошникова	0103000020E61000000100000005000000005471E316EB45400917F2086E2A4C40005471E316EB454094861A85242B4C40FAB836548CEB454094861A85242B4C40FAB836548CEB45400917F2086E2A4C40005471E316EB45400917F2086E2A4C40
19587	42	44.008600999999999	44.034579999999998	56.328927999999998	56.323327999999997	Минина	0103000020E6100000010000000500000040DB6AD619014640C7F0D8CF62294C4040DB6AD6190146408D5E0D501A2A4C403F8C101E6D0446408D5E0D501A2A4C403F8C101E6D044640C7F0D8CF62294C4040DB6AD619014640C7F0D8CF62294C40
19617	42	43.832853999999998	43.839556000000002	56.341478000000002	56.326456999999998	Мечникова	0103000020E61000000100000005000000E02BBAF59AEA45406F46CD57C9294C40E02BBAF59AEA4540D926158DB52B4C408E942D9276EB4540D926158DB52B4C408E942D9276EB45406F46CD57C9294C40E02BBAF59AEA45406F46CD57C9294C40
19796	42	43.884292000000002	43.901170999999998	56.265771999999998	56.259107999999998	Мельникова	0103000020E61000000100000005000000A60EF27A30F14540E41071732A214C40A60EF27A30F14540A41820D104224C40438D429259F34540A41820D104224C40438D429259F34540E41071732A214C40A60EF27A30F14540E41071732A214C40
17522	42	44.041379999999997	44.052061000000002	56.281731000000001	56.278801999999999	Маршала Малиновского	0103000020E61000000100000005000000AF5A99F04B0546409A07B0C8AF234C40AF5A99F04B0546407BA2EBC20F244C40D33252EFA90646407BA2EBC20F244C40D33252EFA90646409A07B0C8AF234C40AF5A99F04B0546409A07B0C8AF234C40
19623	42	43.927492000000001	43.930698999999997	56.333159999999999	56.319913999999997	Маршала Казакова	0103000020E610000001000000050000009CA6CF0EB8F645402AC423F1F2284C409CA6CF0EB8F64540ED2AA4FCA42A4C40BFB5132521F74540ED2AA4FCA42A4C40BFB5132521F745402AC423F1F2284C409CA6CF0EB8F645402AC423F1F2284C40
19695	42	43.956659999999999	43.962435999999997	56.332121999999998	56.329687	Мануфактурная	0103000020E6100000010000000500000018B2BAD573FA45404B75012F332A4C4018B2BAD573FA45401C2444F9822A4C401C3F541A31FB45401C2444F9822A4C401C3F541A31FB45404B75012F332A4C4018B2BAD573FA45404B75012F332A4C40
1827	42	43.982801000000002	43.993985000000002	56.317672000000002	56.316274	Малая Покровская улица	0103000020E61000000100000005000000F1BC546CCCFD45409D499BAA7B284C40F1BC546CCCFD45406E6DE179A9284C4077DB85E63AFF45406E6DE179A9284C4077DB85E63AFF45409D499BAA7B284C40F1BC546CCCFD45409D499BAA7B284C40
19722	42	43.863602999999998	43.889637	56.271805000000001	56.261378000000001	Львовская	0103000020E610000001000000050000001EDD088B8AEE45406BF294D574214C401EDD088B8AEE4540D4F19881CA224C40E1270EA0DFF14540D4F19881CA224C40E1270EA0DFF145406BF294D574214C401EDD088B8AEE45406BF294D574214C40
19736	42	43.617663	43.617716999999999	56.338175	56.335900000000002	Лучистая	0103000020E610000001000000050000008179C8940FCF4540FB5C6DC5FE2A4C408179C8940FCF454093A98251492B4C407497C45911CF454093A98251492B4C407497C45911CF4540FB5C6DC5FE2A4C408179C8940FCF4540FB5C6DC5FE2A4C40
19770	42	43.859605999999999	43.863523000000001	56.255682999999998	56.241948999999998	Лоскутова	0103000020E6100000010000000500000002B9C49107EE45406326512FF81E4C4002B9C49107EE454053927538BA204C40022CF2EB87EE454053927538BA204C40022CF2EB87EE45406326512FF81E4C4002B9C49107EE45406326512FF81E4C40
19635	42	43.840713999999998	43.845241999999999	56.312424999999998	56.303102000000003	Лесной Городок	0103000020E6100000010000000500000009A52F849CEB454015ADDC0BCC264C4009A52F849CEB4540F5B9DA8AFD274C40529ACDE330EC4540F5B9DA8AFD274C40529ACDE330EC454015ADDC0BCC264C4009A52F849CEB454015ADDC0BCC264C40
19660	42	43.843319000000001	43.870663999999998	56.238621999999999	56.227975000000001	Лескова	0103000020E61000000100000005000000378C82E0F1EB45401EA7E8482E1D4C40378C82E0F1EB4540950D6B2A8B1E4C40FBE6FEEA71EF4540950D6B2A8B1E4C40FBE6FEEA71EF45401EA7E8482E1D4C40378C82E0F1EB45401EA7E8482E1D4C40
19655	42	43.904791000000003	43.908240999999997	56.351309999999998	56.348157999999998	Левинка	0103000020E610000001000000050000008A5B0531D0F345409EEBFB70902C4C408A5B0531D0F34540FE60E0B9F72C4C4073F1B73D41F44540FE60E0B9F72C4C4073F1B73D41F445409EEBFB70902C4C408A5B0531D0F345409EEBFB70902C4C40
19634	42	43.834220000000002	43.868319999999997	56.349265000000003	56.342824999999998	Культуры	0103000020E61000000100000005000000A6D590B8C7EA454027A089B0E12B4C40A6D590B8C7EA454098512CB7B42C4C403A3B191C25EF454098512CB7B42C4C403A3B191C25EF454027A089B0E12B4C40A6D590B8C7EA454027A089B0E12B4C40
19661	42	43.906892999999997	43.921680000000002	56.33813	56.324984999999998	Куйбышева	0103000020E6100000010000000500000054FCDF1115F445406458C51B99294C4054FCDF1115F44540F3E505D8472B4C404BB0389CF9F54540F3E505D8472B4C404BB0389CF9F545406458C51B99294C4054FCDF1115F445406458C51B99294C40
19726	42	44.023989	44.035899999999998	56.304724999999998	56.291443999999998	Кузнечихинская	0103000020E610000001000000050000005C3B511212034640C64E78094E254C405C3B51121203464005A3923A01274C4094F6065F9804464005A3923A01274C4094F6065F98044640C64E78094E254C405C3B511212034640C64E78094E254C40
19656	42	43.836680999999999	43.842143	56.254317	56.240253000000003	Красных Партизан	0103000020E61000000100000005000000A017EE5C18EB454009E23C9CC01E4C40A017EE5C18EB45408EE89E758D204C4015C78157CBEB45408EE89E758D204C4015C78157CBEB454009E23C9CC01E4C40A017EE5C18EB454009E23C9CC01E4C40
19758	42	43.867601000000001	43.877068999999999	56.335459999999998	56.313803	Красных Зорь	0103000020E610000001000000050000000B7DB08C0DEF45407F315BB22A284C400B7DB08C0DEF4540DE8E705AF02A4C40EFAA07CC43F04540DE8E705AF02A4C40EFAA07CC43F045407F315BB22A284C400B7DB08C0DEF45407F315BB22A284C40
19612	42	43.779888999999997	43.792807000000003	56.383952000000001	56.381239999999998	Красносормовская	0103000020E610000001000000050000004CC11A67D3E34540A9F6E978CC304C404CC11A67D3E34540ED9DD15625314C401B8524B37AE54540ED9DD15625314C401B8524B37AE54540A9F6E978CC304C404CC11A67D3E34540A9F6E978CC304C40
19658	42	43.975543000000002	43.983142000000001	56.309323999999997	56.308444999999999	Красносельская	0103000020E61000000100000005000000BE6BD097DEFC4540AFCE31207B274C40BE6BD097DEFC454017EFC7ED97274C407AA9D898D7FD454017EFC7ED97274C407AA9D898D7FD4540AFCE31207B274C40BE6BD097DEFC4540AFCE31207B274C40
19590	42	43.990805000000002	43.991452000000002	56.312793999999997	56.308669999999999	Костина	0103000020E610000001000000050000004DDBBFB2D2FE4540CFA0A17F82274C404DDBBFB2D2FE4540483140A209284C40E3C62DE6E7FE4540483140A209284C40E3C62DE6E7FE4540CFA0A17F82274C404DDBBFB2D2FE4540CFA0A17F82274C40
19582	42	43.927230999999999	43.938532000000002	56.284154000000001	56.271965000000002	Космонавта Комарова	0103000020E610000001000000050000002F6B6281AFF645400D54C6BFCF224C402F6B6281AFF64540888384285F244C40EF1F0BD121F84540888384285F244C40EF1F0BD121F845400D54C6BFCF224C402F6B6281AFF645400D54C6BFCF224C40
19791	42	43.823385999999999	43.838711000000004	56.230196999999997	56.217920999999997	Космическая 	0103000020E61000000100000005000000FCFD62B664E94540490ED8D5E41B4C40FCFD62B664E9454093516518771D4C40D2E5CDE15AEB454093516518771D4C40D2E5CDE15AEB4540490ED8D5E41B4C40FCFD62B664E94540490ED8D5E41B4C40
2314	42	43.986815999999997	43.990481000000003	56.279307000000003	56.278972000000003	Корейский переулок	0103000020E61000000100000005000000B39597FC4FFE4540F73FC05AB5234C40B39597FC4FFE45409E45EF54C0234C409A27D714C8FE45409E45EF54C0234C409A27D714C8FE4540F73FC05AB5234C40B39597FC4FFE4540F73FC05AB5234C40
17028	42	43.989196999999997	43.99288	56.281095999999998	56.273029999999999	Корейская	0103000020E610000001000000050000009126DE019EFE4540D769A4A5F2224C409126DE019EFE4540A98427F4FA234C401E6D1CB116FF4540A98427F4FA234C401E6D1CB116FF4540D769A4A5F2224C409126DE019EFE4540D769A4A5F2224C40
16685	42	43.989196999999997	43.99288	56.281095999999998	56.273029999999999	Корейская	0103000020E610000001000000050000009126DE019EFE4540D769A4A5F2224C409126DE019EFE4540A98427F4FA234C401E6D1CB116FF4540A98427F4FA234C401E6D1CB116FF4540D769A4A5F2224C409126DE019EFE4540D769A4A5F2224C40
19774	42	43.939484	43.946804999999998	56.300289999999997	56.296788999999997	Комсомольская	0103000020E61000000100000005000000C18EFF0241F845400168942EFD254C40C18EFF0241F845406DA818E76F264C403A58FFE730F945406DA818E76F264C403A58FFE730F945400168942EFD254C40C18EFF0241F845400168942EFD254C40
19606	42	43.950794000000002	43.954405000000001	56.323642	56.314726999999998	Коммунистическая	0103000020E61000000100000005000000D49D279EB3F9454087156EF948284C40D49D279EB3F9454057CEDE196D294C40C7116BF129FA454057CEDE196D294C40C7116BF129FA454087156EF948284C40D49D279EB3F9454087156EF948284C40
19781	42	43.862310000000001	43.882359999999998	56.361089999999997	56.338738999999997	Коминтерна	0103000020E61000000100000005000000C381902C60EE45409B70AFCC5B2B4C40C381902C60EE4540D1747632382E4C4037A6272CF1F04540D1747632382E4C4037A6272CF1F045409B70AFCC5B2B4C40C381902C60EE45409B70AFCC5B2B4C40
19663	42	43.977150000000002	43.983493000000003	56.249040999999998	56.231082999999998	Кащенко	0103000020E61000000100000005000000A9A44E4013FD4540AED4B320941D4C40A9A44E4013FD45407B2E5393E01F4C40276C3F19E3FD45407B2E5393E01F4C40276C3F19E3FD4540AED4B320941D4C40A9A44E4013FD4540AED4B320941D4C40
19721	42	43.946517999999998	43.951009999999997	56.278252999999999	56.274569	Каширская	0103000020E61000000100000005000000A489778027F945406ABFB51325234C40A489778027F94540C78157CB9D234C40A01518B2BAF94540C78157CB9D234C40A01518B2BAF945406ABFB51325234C40A489778027F945406ABFB51325234C40
19639	42	43.923242999999999	43.943463999999999	56.345509	56.339920999999997	Карла Маркса	0103000020E6100000010000000500000066A19DD32CF645409F1C0588822B4C4066A19DD32CF64540A1BC8FA3392C4C40077AA86DC3F84540A1BC8FA3392C4C40077AA86DC3F845409F1C0588822B4C4066A19DD32CF645409F1C0588822B4C40
31	42	43.839824999999998	43.851987999999999	56.305613999999998	56.303511	Камчатский переулок	0103000020E610000001000000050000007DAEB6627FEB4540F67CCD72D9264C407DAEB6627FEB454091990B5C1E274C40CF4A5AF10DED454091990B5C1E274C40CF4A5AF10DED4540F67CCD72D9264C407DAEB6627FEB4540F67CCD72D9264C40
16751	42	44.075211000000003	44.083601000000002	56.298541999999998	56.275644	Казанское шоссе	0103000020E6100000010000000500000055A69883A009464058AB764D48234C4055A69883A0094640C03DCF9F36264C40DA740470B30A4640C03DCF9F36264C40DA740470B30A464058AB764D48234C4055A69883A009464058AB764D48234C40
1794	42	44.075211000000003	44.083601000000002	56.298541999999998	56.275644	Казанское шоссе	0103000020E6100000010000000500000055A69883A009464058AB764D48234C4055A69883A0094640C03DCF9F36264C40DA740470B30A4640C03DCF9F36264C40DA740470B30A464058AB764D48234C4055A69883A009464058AB764D48234C40
19642	42	43.939833999999998	43.945467000000001	56.311985	56.301068999999998	Июльских дней	0103000020E610000001000000050000009DD5027B4CF84540726BD26D89264C409DD5027B4CF84540D9EBDD1FEF274C403F390A1005F94540D9EBDD1FEF274C403F390A1005F94540726BD26D89264C409DD5027B4CF84540726BD26D89264C40
19589	42	43.939833999999998	43.945467000000001	56.311985	56.301068999999998	Июльских Дней	0103000020E610000001000000050000009DD5027B4CF84540726BD26D89264C409DD5027B4CF84540D9EBDD1FEF274C403F390A1005F94540D9EBDD1FEF274C403F390A1005F94540726BD26D89264C409DD5027B4CF84540726BD26D89264C40
19694	42	43.983142000000001	43.995835	56.329805999999998	56.308444999999999	Ильинская	0103000020E610000001000000050000007AA9D898D7FD4540AFCE31207B274C407AA9D898D7FD454025034015372A4C40289B728577FF454025034015372A4C40289B728577FF4540AFCE31207B274C407AA9D898D7FD4540AFCE31207B274C40
19713	42	43.789527999999997	43.80612	56.374467000000003	56.367162999999998	Зайцева	0103000020E610000001000000050000005DA3E5400FE545408FA67A32FF2E4C405DA3E5400FE545403337DF88EE2F4C406553AEF02EE745403337DF88EE2F4C406553AEF02EE745408FA67A32FF2E4C405DA3E5400FE545408FA67A32FF2E4C40
19783	42	43.909714000000001	43.911008000000002	56.303046999999999	56.301957999999999	Завкомовская	0103000020E610000001000000050000004F5B238271F44540FE614B8FA6264C404F5B238271F4454051137D3ECA264C407B32FFE89BF4454051137D3ECA264C407B32FFE89BF44540FE614B8FA6264C404F5B238271F44540FE614B8FA6264C40
17456	42	43.947650000000003	43.963092000000003	56.238007000000003	56.228596000000003	Жукова	0103000020E61000000100000005000000F7065F984CF945408BFF3BA2421D4C40F7065F984CF945400B9C6C03771E4C400685419946FB45400B9C6C03771E4C400685419946FB45408BFF3BA2421D4C40F7065F984CF945408BFF3BA2421D4C40
19665	42	43.867772000000002	43.897533000000003	56.268695999999998	56.256127999999997	Дьяконова	0103000020E610000001000000050000003831242713EF454081CB63CDC8204C403831242713EF454073486AA164224C40570A815CE2F2454073486AA164224C40570A815CE2F2454081CB63CDC8204C403831242713EF454081CB63CDC8204C40
19757	42	43.738791999999997	43.742780000000003	56.392642000000002	56.386831999999998	Дубравная	0103000020E61000000100000005000000F1457BBC90DE4540EC8502B683314C40F1457BBC90DE45409D84D21742324C40BB0F406A13DF45409D84D21742324C40BB0F406A13DF4540EC8502B683314C40F1457BBC90DE4540EC8502B683314C40
19640	42	43.901845000000002	43.927222	56.289814999999997	56.284159000000002	Дружбы	0103000020E61000000100000005000000D3872EA86FF345409AEE75525F244C40D3872EA86FF34540F3716DA818254C40DC10E335AFF64540F3716DA818254C40DC10E335AFF645409AEE75525F244C40D3872EA86FF345409AEE75525F244C40
19776	42	43.875497000000003	43.887552999999997	56.266236999999997	56.256512999999998	Дружаева	0103000020E61000000100000005000000815F234910F04540DAFF006BD5204C40815F234910F0454019FED30D14224C40BC3B32569BF1454019FED30D14224C40BC3B32569BF14540DAFF006BD5204C40815F234910F04540DAFF006BD5204C40
19741	42	43.875497000000003	43.887552999999997	56.266236999999997	56.256512999999998	Дружаева	0103000020E61000000100000005000000815F234910F04540DAFF006BD5204C40815F234910F0454019FED30D14224C40BC3B32569BF1454019FED30D14224C40BC3B32569BF14540DAFF006BD5204C40815F234910F04540DAFF006BD5204C40
19750	42	44.046607999999999	44.047362999999997	56.320832000000003	56.315849999999998	Донецкая 	0103000020E61000000100000005000000B1DD3D40F70546408638D6C56D284C40B1DD3D40F705464051C1E10511294C402D05A4FD0F06464051C1E10511294C402D05A4FD0F0646408638D6C56D284C40B1DD3D40F70546408638D6C56D284C40
19805	42	43.840418	43.852446	56.293166999999997	56.286861999999999	Движенцев	0103000020E61000000100000005000000207C28D192EB45408A3BDEE4B7244C40207C28D192EB45401AA20A7F86254C4092CD55F31CED45401AA20A7F86254C4092CD55F31CED45408A3BDEE4B7244C40207C28D192EB45408A3BDEE4B7244C40
19501	42	43.933366999999997	43.952806000000002	56.292723000000002	56.290399999999998	Даргомыжского	0103000020E610000001000000050000003315E29178F745401361C3D32B254C403315E29178F74540BDE47FF277254C405FB7088CF5F94540BDE47FF277254C405FB7088CF5F945401361C3D32B254C403315E29178F745401361C3D32B254C40
19549	42	43.928739999999998	43.931184000000002	56.261848000000001	56.259557999999998	Грекова	0103000020E61000000100000005000000573ECBF3E0F6454024B5503239214C40573ECBF3E0F64540F2423A3C84214C407C478D0931F74540F2423A3C84214C407C478D0931F7454024B5503239214C40573ECBF3E0F6454024B5503239214C40
19798	42	43.848143	43.873700999999997	56.295610000000003	56.285293000000003	Гороховецкая 	0103000020E6100000010000000500000069AA27F38FEC45408D63247B84244C4069AA27F38FEC45406F2F698CD6254C40C2BD326FD5EF45406F2F698CD6254C40C2BD326FD5EF45408D63247B84244C4069AA27F38FEC45408D63247B84244C40
19513	42	43.924805999999997	43.947434000000001	56.333879000000003	56.324131999999999	Гордеевская	0103000020E610000001000000050000008192020B60F6454025CB49287D294C408192020B60F645401DE90C8CBC2A4C402A8F6E8445F945401DE90C8CBC2A4C402A8F6E8445F9454025CB49287D294C408192020B60F6454025CB49287D294C40
19637	42	43.997785	44.009903000000001	56.275154000000001	56.273829999999997	Горбатовская	0103000020E610000001000000050000003DB83B6BB7FF4540F35487DC0C234C403DB83B6BB7FF45408AAE0B3F38234C40EF906280440146408AAE0B3F38234C40EF90628044014640F35487DC0C234C403DB83B6BB7FF4540F35487DC0C234C40
19753	42	43.932980000000001	43.946275	56.282055999999997	56.279181999999999	Гончарова	0103000020E610000001000000050000003AE97DE36BF74540E1D05B3CBC234C403AE97DE36BF74540FED137691A244C40DE02098A1FF94540FED137691A244C40DE02098A1FF94540E1D05B3CBC234C403AE97DE36BF74540E1D05B3CBC234C40
19780	42	43.944901000000002	43.953102999999999	56.290399999999998	56.282935000000002	Голубева	0103000020E61000000100000005000000967A1684F2F8454067F2CD3637244C40967A1684F2F845401361C3D32B254C40185C7347FFF945401361C3D32B254C40185C7347FFF9454067F2CD3637244C40967A1684F2F8454067F2CD3637244C40
19510	42	43.985692999999998	43.986179	56.324306	56.317228	Гоголя	0103000020E61000000100000005000000B4722F302BFE454010B056ED9A284C40B4722F302BFE4540C3F2E7DB82294C4041800C1D3BFE4540C3F2E7DB82294C4041800C1D3BFE454010B056ED9A284C40B4722F302BFE454010B056ED9A284C40
19611	42	43.922775000000001	43.933177999999998	56.278782	56.277203	Героя Советского Союза Чугунова	0103000020E610000001000000050000008048BF7D1DF6454032AD4D637B234C408048BF7D1DF64540535BEA20AF234C4060AC6F6072F74540535BEA20AF234C4060AC6F6072F7454032AD4D637B234C408048BF7D1DF6454032AD4D637B234C40
19569	42	43.842348999999999	43.871841000000003	56.241394	56.228805999999999	Героя Советского Союза Смирнова	0103000020E61000000100000005000000BE688F17D2EB45407590D783491D4C40BE688F17D2EB4540AEB9A3FFE51E4C40EE27637C98EF4540AEB9A3FFE51E4C40EE27637C98EF45407590D783491D4C40BE688F17D2EB45407590D783491D4C40
19544	42	43.912391	43.924869000000001	56.290449000000002	56.287497000000002	Героя Советского Союза Самочкина	0103000020E610000001000000050000001615713AC9F445405C59A2B3CC244C401615713AC9F44540F513CE6E2D254C40C80A7E1B62F64540F513CE6E2D254C40C80A7E1B62F645405C59A2B3CC244C401615713AC9F445405C59A2B3CC244C40
19688	42	43.865938999999997	43.871220999999998	56.330449999999999	56.316299000000001	Героя Советского Союза Рябцева	0103000020E610000001000000050000005CAAD216D7EE4540F660527C7C284C405CAAD216D7EE45404A7B832F4C2A4C40514B732B84EF45404A7B832F4C2A4C40514B732B84EF4540F660527C7C284C405CAAD216D7EE4540F660527C7C284C40
19678	42	43.916963000000003	43.942233000000002	56.265307	56.250742000000002	Героя Советского Союза Попова	0103000020E610000001000000050000002F52280B5FF54540E8DD585018204C402F52280B5FF545402F336C94F5214C40221B48179BF845402F336C94F5214C40221B48179BF84540E8DD585018204C402F52280B5FF54540E8DD585018204C40
19632	42	43.754700999999997	43.767654	56.214302000000004	56.205585999999997	Героя Советского Союза Ляхова	0103000020E6100000010000000500000016A1D80A9AE04540FA415DA4501A4C4016A1D80A9AE04540D4BB783F6E1B4C4061527C7C42E24540D4BB783F6E1B4C4061527C7C42E24540FA415DA4501A4C4016A1D80A9AE04540FA415DA4501A4C40
19761	42	43.867807999999997	43.869540999999998	56.326148000000003	56.320292999999999	Героя Советского Союза Давыдова	0103000020E61000000100000005000000849A215514EF4540A1116C5CFF284C40849A215514EF4540F2D3B837BF294C40FCC3961E4DEF4540F2D3B837BF294C40FCC3961E4DEF4540A1116C5CFF284C40849A215514EF4540A1116C5CFF284C40
19784	42	43.867807999999997	43.869540999999998	56.326148000000003	56.320292999999999	Героя Советского Союза Давыдова	0103000020E61000000100000005000000849A215514EF4540A1116C5CFF284C40849A215514EF4540F2D3B837BF294C40FCC3961E4DEF4540F2D3B837BF294C40FCC3961E4DEF4540A1116C5CFF284C40849A215514EF4540A1116C5CFF284C40
19521	42	43.842348999999999	43.871841000000003	56.241394	56.228805999999999	Героя Смирнова	0103000020E61000000100000005000000BE688F17D2EB45407590D783491D4C40BE688F17D2EB4540AEB9A3FFE51E4C40EE27637C98EF4540AEB9A3FFE51E4C40EE27637C98EF45407590D783491D4C40BE688F17D2EB45407590D783491D4C40
19573	42	43.745313000000003	43.748350000000002	56.248615999999998	56.24532	Героя Бахтина	0103000020E610000001000000050000004F24986A66DF4540018750A5661F4C404F24986A66DF454094A12AA6D21F4C4016FBCBEEC9DF454094A12AA6D21F4C4016FBCBEEC9DF4540018750A5661F4C404F24986A66DF4540018750A5661F4C40
19705	42	43.811905000000003	43.824221000000001	56.362530999999997	56.356985999999999	Героев Космоса	0103000020E61000000100000005000000BD3AC780ECE745409F909DB7B12D4C40BD3AC780ECE74540A164726A672E4C4095D6DF1280E94540A164726A672E4C4095D6DF1280E945409F909DB7B12D4C40BD3AC780ECE745409F909DB7B12D4C40
16699	42	44.045926000000001	44.055394	56.302937	56.281731000000001	Генерала Ивлиева	0103000020E610000001000000050000009F0436E7E00546407BA2EBC20F244C409F0436E7E0054640CADFBDA3C6264C4083328D2617074640CADFBDA3C6264C4083328D26170746407BA2EBC20F244C409F0436E7E00546407BA2EBC20F244C40
19724	42	43.934255999999998	43.944048000000002	56.328009999999999	56.324300999999998	Генерала Зимина	0103000020E61000000100000005000000BF0B5BB395F74540B187F6B182294C40BF0B5BB395F7454067614F3BFC294C4057ED9A90D6F8454067614F3BFC294C4057ED9A90D6F84540B187F6B182294C40BF0B5BB395F74540B187F6B182294C40
19673	42	43.904387	43.907378000000001	56.292777000000001	56.289405000000002	Гвоздильная	0103000020E61000000100000005000000BAF605F4C2F34540422619390B254C40BAF605F4C2F34540B0027CB779254C40118E59F624F44540B0027CB779254C40118E59F624F44540422619390B254C40BAF605F4C2F34540422619390B254C40
19545	42	43.874518000000002	43.885908999999998	56.336199000000001	56.334777000000003	Гвардейцев	0103000020E61000000100000005000000B5E1B034F0EF4540FC3905F9D92A4C40B5E1B034F0EF454055F99E91082B4C40B41D537765F1454055F99E91082B4C40B41D537765F14540FC3905F9D92A4C40B5E1B034F0EF4540FC3905F9D92A4C40
19790	42	43.882935000000003	43.896841000000002	56.266086999999999	56.260187999999999	Газовская	0103000020E6100000010000000500000034BF9A0304F14540E46723D74D214C4034BF9A0304F14540047289230F224C40215B96AFCBF24540047289230F224C40215B96AFCBF24540E46723D74D214C4034BF9A0304F14540E46723D74D214C40
19799	42	43.839303999999998	43.847586	56.362530999999997	56.358685999999999	Вузовская 	0103000020E6100000010000000500000074B33F506EEB45403BC43F6CE92D4C4074B33F506EEB4540A164726A672E4C401346B3B27DEC4540A164726A672E4C401346B3B27DEC45403BC43F6CE92D4C4074B33F506EEB45403BC43F6CE92D4C40
19610	42	43.841693999999997	43.863208	56.353659	56.348153000000003	Вождей Революции	0103000020E61000000100000005000000A59E05A1BCEB45408D800A47902C4C40A59E05A1BCEB4540D177B7B2442D4C40A2D288997DEE4540D177B7B2442D4C40A2D288997DEE45408D800A47902C4C40A59E05A1BCEB45408D800A47902C4C40
17987	42	43.607072000000002	44.170639000000001	56.421180999999997	56.155709000000002	Ветлужская	0103000020E610000001000000050000009E280989B4CD4540B058C345EE134C409E280989B4CD454029594E42E9354C400936AE7FD715464029594E42E9354C400936AE7FD7154640B058C345EE134C409E280989B4CD4540B058C345EE134C40
16693	42	43.962435999999997	44.080222999999997	56.320442999999997	56.243634999999998	Верхняя	0103000020E610000001000000050000001C3F541A31FB45409A94826E2F1F4C401C3F541A31FB4540B69DB64604294C4089B14CBF440A4640B69DB64604294C4089B14CBF440A46409A94826E2F1F4C401C3F541A31FB45409A94826E2F1F4C40
17005	42	44.067844000000001	44.069740000000003	56.299540999999998	56.284849000000001	Верхнепечерская улица	0103000020E610000001000000050000006B9DB81CAF0846402FA699EE75244C406B9DB81CAF084640D367075C57264C408D9C853DED084640D367075C57264C408D9C853DED0846402FA699EE75244C406B9DB81CAF0846402FA699EE75244C40
19788	42	43.861043000000002	43.880878000000003	56.240572999999998	56.227088999999999	Веденяпина	0103000020E6100000010000000500000091B932A836EE454003249A40111D4C4091B932A836EE45407AA69718CB1E4C4009E23C9CC0F045407AA69718CB1E4C4009E23C9CC0F0454003249A40111D4C4091B932A836EE454003249A40111D4C40
19603	42	43.885458999999997	43.892763000000002	56.268211000000001	56.262492000000002	Васнецова	0103000020E61000000100000005000000747973B856F1454017BB7D5699214C40747973B856F14540B7B6F0BC54224C40180AD80E46F24540B7B6F0BC54224C40180AD80E46F2454017BB7D5699214C40747973B856F1454017BB7D5699214C40
19505	42	43.819378999999998	43.833455999999998	56.369785999999998	56.360346999999997	Василия Иванова	0103000020E61000000100000005000000BC033C69E1E84540191BBAD91F2E4C40BC033C69E1E845406342CC25552F4C40D653ABAFAEEA45406342CC25552F4C40D653ABAFAEEA4540191BBAD91F2E4C40BC033C69E1E84540191BBAD91F2E4C40
19583	42	44.006399999999999	44.015841000000002	56.326402999999999	56.318116000000003	Варварская	0103000020E61000000100000005000000E25817B7D1004640CC2A6C06B8284C40E25817B7D10046407C28D192C7294C40CD77F013070246407C28D192C7294C40CD77F01307024640CC2A6C06B8284C40E25817B7D1004640CC2A6C06B8284C40
19677	42	44.014007999999997	44.041379999999997	56.317782000000001	56.280352000000001	Ванеева	0103000020E61000000100000005000000F1F09E03CB01464021AF0793E2234C40F1F09E03CB014640F5A0A014AD284C40AF5A99F04B054640F5A0A014AD284C40AF5A99F04B05464021AF0793E2234C40F1F09E03CB01464021AF0793E2234C40
19691	42	43.867772000000002	43.895547999999998	56.270311	56.259903000000001	Бурденко	0103000020E610000001000000050000003831242713EF4540EF90628044214C403831242713EF4540E15F048D99224C40C5FF1D51A1F24540E15F048D99224C40C5FF1D51A1F24540EF90628044214C403831242713EF4540EF90628044214C40
16802	42	44.023440999999998	44.035442000000003	56.311700999999999	56.308160999999998	Бориса Панина	0103000020E6100000010000000500000059315C1D000346408A73D4D171274C4059315C1D00034640B49080D1E5274C40D2730B5D89044640B49080D1E5274C40D2730B5D890446408A73D4D171274C4059315C1D000346408A73D4D171274C40
16761	42	44.041434000000002	44.045324000000001	56.302307999999996	56.296824000000001	Бориса Корнилова	0103000020E61000000100000005000000A37895B54D0546407E552E54FE254C40A37895B54D054640DAA84E07B2264C40A9DC442DCD054640DAA84E07B2264C40A9DC442DCD0546407E552E54FE254C40A37895B54D0546407E552E54FE254C40
19670	42	43.835144999999997	43.847416000000003	56.369287	56.365926999999999	Большая Починковская 	0103000020E610000001000000050000007E350708E6EA454098DC28B2D62E4C407E350708E6EA454042EBE1CB442F4C40B70DA32078EC454042EBE1CB442F4C40B70DA32078EC454098DC28B2D62E4C407E350708E6EA454098DC28B2D62E4C40
19666	42	43.984876	44.004683999999997	56.326037999999997	56.308241000000002	Большая Покровская	0103000020E61000000100000005000000C24EB16A10FE4540A724EB7074274C40C24EB16A10FE45406AA0F99CBB294C4040683D7C990046406AA0F99CBB294C4040683D7C99004640A724EB7074274C40C24EB16A10FE4540A724EB7074274C40
19692	42	44.013953999999998	44.041946000000003	56.326706999999999	56.321210999999998	Большая Печерская 	0103000020E61000000100000005000000FED2A23EC9014640C70E2A711D294C40FED2A23EC9014640E82FF488D1294C4059198D7C5E054640E82FF488D1294C4059198D7C5E054640C70E2A711D294C40FED2A23EC9014640C70E2A711D294C40
19564	42	44.013953999999998	44.041946000000003	56.326706999999999	56.321210999999998	Большая Печерская	0103000020E61000000100000005000000FED2A23EC9014640C70E2A711D294C40FED2A23EC9014640E82FF488D1294C4059198D7C5E054640E82FF488D1294C4059198D7C5E054640C70E2A711D294C40FED2A23EC9014640C70E2A711D294C40
19638	42	43.870502999999999	43.885584999999999	56.338644000000002	56.314081999999999	Берёзовская	0103000020E61000000100000005000000F2086EA46CEF45409221C7D633284C40F2086EA46CEF45404A7EC4AF582B4C40016A6AD95AF145404A7EC4AF582B4C40016A6AD95AF145409221C7D633284C40F2086EA46CEF45409221C7D633284C40
17035	42	43.982244000000001	44.034077000000003	56.295774999999999	56.289225000000002	Бекетова	0103000020E610000001000000050000009B58E02BBAFD4540C217265305254C409B58E02BBAFD4540B9FC87F4DB254C40DD4598A25C044640B9FC87F4DB254C40DD4598A25C044640C217265305254C409B58E02BBAFD4540C217265305254C40
19747	42	43.814843000000003	43.827311999999999	56.370294000000001	56.367097999999999	Баренца	0103000020E61000000100000005000000F12F82C64CE84540A8363811FD2E4C40F12F82C64CE84540D8F335CB652F4C404FCB0F5CE5E94540D8F335CB652F4C404FCB0F5CE5E94540A8363811FD2E4C40F12F82C64CE84540A8363811FD2E4C40
19749	42	43.814843000000003	43.827311999999999	56.370294000000001	56.367097999999999	Баренца	0103000020E61000000100000005000000F12F82C64CE84540A8363811FD2E4C40F12F82C64CE84540D8F335CB652F4C404FCB0F5CE5E94540D8F335CB652F4C404FCB0F5CE5E94540A8363811FD2E4C40F12F82C64CE84540A8363811FD2E4C40
19723	42	43.984068000000001	44.017853000000002	56.303167000000002	56.296987999999999	Артельная	0103000020E610000001000000050000002385B2F0F5FD4540F8A6E9B303264C402385B2F0F5FD4540FC1C1F2DCE264C405891D10149024640FC1C1F2DCE264C405891D10149024640F8A6E9B303264C402385B2F0F5FD4540F8A6E9B303264C40
19748	42	43.826107999999998	43.851916000000003	56.222265	56.213515999999998	Аркадия Гайдара	0103000020E61000000100000005000000637B2DE8BDE945401C96067E541B4C40637B2DE8BDE94540D105F52D731C4C4036785F950BED4540D105F52D731C4C4036785F950BED45401C96067E541B4C40637B2DE8BDE945401C96067E541B4C40
19752	42	43.826107999999998	43.851916000000003	56.222265	56.213515999999998	Аркадия Гайдара	0103000020E61000000100000005000000637B2DE8BDE945401C96067E541B4C40637B2DE8BDE94540D105F52D731C4C4036785F950BED4540D105F52D731C4C4036785F950BED45401C96067E541B4C40637B2DE8BDE945401C96067E541B4C40
19602	42	43.831093000000003	43.840355000000002	56.230347000000002	56.222484999999999	Академика Павлова	0103000020E610000001000000050000009F77634161EA4540DF6C73637A1C4C409F77634161EA4540A9DDAF027C1D4C40DA03ADC090EB4540A9DDAF027C1D4C40DA03ADC090EB4540DF6C73637A1C4C409F77634161EA4540DF6C73637A1C4C40
19651	42	43.931336000000002	43.944065999999999	56.289614999999998	56.288836000000003	Академика Баха	0103000020E6100000010000000500000032CB9E0436F7454028F4FA93F8244C4032CB9E0436F745402CB7B41A12254C40FDA19927D7F845402CB7B41A12254C40FDA19927D7F8454028F4FA93F8244C4032CB9E0436F7454028F4FA93F8244C40
19659	42	43.917907	43.930841999999998	56.271650000000001	56.264747	Адмирала Нахимова	0103000020E610000001000000050000007EE200FA7DF54540685BCD3AE3214C407EE200FA7DF54540ADFA5C6DC5224C4022DFA5D425F74540ADFA5C6DC5224C4022DFA5D425F74540685BCD3AE3214C407EE200FA7DF54540685BCD3AE3214C40
19729	42	43.943652	43.949572000000003	56.293076999999997	56.282935000000002	Адмирала Макарова	0103000020E610000001000000050000000A67B796C9F8454067F2CD3637244C400A67B796C9F84540DA1A118C83254C40429946938BF94540DA1A118C83254C40429946938BF9454067F2CD3637244C400A67B796C9F8454067F2CD3637244C40
19664	42	43.858671999999999	43.871464000000003	56.234654999999997	56.229692	Автомеханическая	0103000020E61000000100000005000000D6FECEF6E8ED45409013268C661D4C40D6FECEF6E8ED4540E36BCF2C091E4C4018D2E1218CEF4540E36BCF2C091E4C4018D2E1218CEF45409013268C661D4C40D6FECEF6E8ED45409013268C661D4C40
19630	42	43.881148000000003	43.887569999999997	56.338239999999999	56.323762000000002	50-летия Победы	0103000020E61000000100000005000000C9772975C9F0454002D8800871294C40C9772975C9F045407A19C5724B2B4C409274CDE49BF145407A19C5724B2B4C409274CDE49BF1454002D8800871294C40C9772975C9F0454002D8800871294C40
16746	42	43.607072000000002	44.170639000000001	56.421180999999997	56.155709000000002	40 Лет Победы	0103000020E610000001000000050000009E280989B4CD4540B058C345EE134C409E280989B4CD454029594E42E9354C400936AE7FD715464029594E42E9354C400936AE7FD7154640B058C345EE134C409E280989B4CD4540B058C345EE134C40
17071	42	43.607072000000002	44.170639000000001	56.421180999999997	56.155709000000002	40 Лет Октября	0103000020E610000001000000050000009E280989B4CD4540B058C345EE134C409E280989B4CD454029594E42E9354C400936AE7FD715464029594E42E9354C400936AE7FD7154640B058C345EE134C409E280989B4CD4540B058C345EE134C40
19739	42	43.978901999999998	43.979810000000001	56.313903000000003	56.311121999999997	3-я Ямская	0103000020E6100000010000000500000097FE25A94CFD454076887FD8D2274C4097FE25A94CFD4540E38E37F92D284C409A25016A6AFD4540E38E37F92D284C409A25016A6AFD454076887FD8D2274C4097FE25A94CFD454076887FD8D2274C40
19516	42	43.753397999999997	43.753919000000003	56.269711000000001	56.265517000000003	19-я Линия	0103000020E61000000100000005000000976F7D586FE045401AC40776FC214C40976F7D586FE045408C2FDAE385224C40A16AF46A80E045408C2FDAE385224C40A16AF46A80E045401AC40776FC214C40976F7D586FE045401AC40776FC214C40
19773	42	43.982801000000002	43.991191000000001	56.317672000000002	56.314712	 Маслякова	0103000020E61000000100000005000000F1BC546CCCFD454052D4997B48284C40F1BC546CCCFD45406E6DE179A9284C40768BC058DFFE45406E6DE179A9284C40768BC058DFFE454052D4997B48284C40F1BC546CCCFD454052D4997B48284C40
17185	49760	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	Новая	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
17338	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	площадь Ленина	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17437	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	Циолковского	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17324	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	О.Кошевого	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17916	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	Мира	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17144	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	Маряхина	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17255	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	Гоголя	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17438	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	Воровского	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17034	13322	42.473621999999999	42.566113000000001	55.438420000000001	55.393160000000002	60 лет ВЛКСМ	0103000020E6100000010000000500000043554CA59F3C4540350C1F1153B24B4043554CA59F3C4540C7F484251EB84B40946B0A6476484540C7F484251EB84B40946B0A6476484540350C1F1153B24B4043554CA59F3C4540350C1F1153B24B40
17493	49702	41.776566000000003	47.770995999999997	58.091237	54.461975000000002	проспект Капитана Рачкова	0103000020E61000000100000005000000C097C28366E34440E9482EFF213B4B40C097C28366E34440B3976DA7AD0B4D4064AC36FFAFE24740B3976DA7AD0B4D4064AC36FFAFE24740E9482EFF213B4B40C097C28366E34440E9482EFF213B4B40
19488	49702	43.751997000000003	43.754404000000001	56.263706999999997	56.256442999999997	Школьная	0103000020E6100000010000000500000056D80C7041E04540E124CD1FD3204C4056D80C7041E04540F65CA626C1214C405DFC6D4F90E04540F65CA626C1214C405DFC6D4F90E04540E124CD1FD3204C4056D80C7041E04540E124CD1FD3204C40
19720	49702	44.032989999999998	44.041209000000002	56.321606000000003	56.316733999999997	Тургенева	0103000020E610000001000000050000002A8C2D043904464000C45DBD8A284C402A8C2D04390446404419AA622A294C4083A62556460546404419AA622A294C4083A625564605464000C45DBD8A284C402A8C2D043904464000C45DBD8A284C40
19649	49702	43.803614000000003	43.835118000000001	55.395766999999999	55.390782000000002	Свободы	0103000020E61000000100000005000000CB4DD4D2DCE64540C8EE022505B24B40CB4DD4D2DCE6454003EB387EA8B24B4085268925E5EA454003EB387EA8B24B4085268925E5EA4540C8EE022505B24B40CB4DD4D2DCE64540C8EE022505B24B40
17233	49702	43.818812999999999	43.833311999999999	55.406174999999998	55.400266000000002	Парковая	0103000020E61000000100000005000000134548DDCEE84540B2D991EA3BB34B40134548DDCEE84540F5B9DA8AFDB34B40A3AEB5F7A9EA4540F5B9DA8AFDB34B40A3AEB5F7A9EA4540B2D991EA3BB34B40134548DDCEE84540B2D991EA3BB34B40
19676	49702	43.733806000000001	43.736645000000003	56.262852000000002	56.254432000000001	Островского	0103000020E61000000100000005000000E6CDE15AEDDD454027874F3A91204C40E6CDE15AEDDD454017D86322A5214C4087E123624ADE454017D86322A5214C4087E123624ADE454027874F3A91204C40E6CDE15AEDDD454027874F3A91204C40
19732	49702	43.949176999999999	43.952967999999998	56.237020999999999	56.235109999999999	3 микрорайон	0103000020E61000000100000005000000C58EC6A17EF94540357BA015181E4C40C58EC6A17EF945408CBB41B4561E4C403811FDDAFAF945408CBB41B4561E4C403811FDDAFAF94540357BA015181E4C40C58EC6A17EF94540357BA015181E4C40
3664	9699	43.406683999999998	43.406837000000003	56.226754	56.221645000000002	улица Рудольфа Удриса	0103000020E610000001000000050000003AE7A7380EB44540352905DD5E1C4C403AE7A7380EB445405C1E6B46061D4C40C1E61C3C13B445405C1E6B46061D4C40C1E61C3C13B44540352905DD5E1C4C403AE7A7380EB44540352905DD5E1C4C40
3128	9699	43.471426000000001	43.474964999999997	56.254691999999999	56.242784	улица Пирогова	0103000020E61000000100000005000000F73DEAAF57BC4540FCFECD8B131F4C40F73DEAAF57BC4540C34659BF99204C4050DF32A7CBBC4540C34659BF99204C4050DF32A7CBBC4540FCFECD8B131F4C40F73DEAAF57BC4540FCFECD8B131F4C40
3219	9699	43.455589000000003	43.460943	56.244079999999997	56.239403000000003	улица Кирова	0103000020E610000001000000050000006CB587BD50BA45403BC8EBC1A41E4C406CB587BD50BA4540C8CD70033E1F4C40FA28232E00BB4540C8CD70033E1F4C40FA28232E00BB45403BC8EBC1A41E4C406CB587BD50BA45403BC8EBC1A41E4C40
3532	9699	43.400432000000002	43.410673000000003	56.230862000000002	56.227924999999999	улица Галкина	0103000020E61000000100000005000000CD22145B41B345406C787AA52C1D4C40CD22145B41B34540D0F1D1E28C1D4C40D42CD0EE90B44540D0F1D1E28C1D4C40D42CD0EE90B445406C787AA52C1D4C40CD22145B41B345406C787AA52C1D4C40
3330	9699	43.371138000000002	43.460169999999998	56.237471999999997	56.226573999999999	проспект Циолковского	0103000020E61000000100000005000000C426327381AF4540DC0F7860001D4C40C426327381AF45409CDB847B651E4C40D74CBED9E6BA45409CDB847B651E4C40D74CBED9E6BA4540DC0F7860001D4C40C426327381AF4540DC0F7860001D4C40
3608	9699	43.388952000000003	43.391126	56.261203000000002	56.220939000000001	проспект Свердлова	0103000020E610000001000000050000005EDBDB2DC9B145409AB4A9BA471C4C405EDBDB2DC9B14540FD4E93196F214C40C24EB16A10B24540FD4E93196F214C40C24EB16A10B245409AB4A9BA471C4C405EDBDB2DC9B145409AB4A9BA471C4C40
3501	9699	43.406514000000001	43.420698000000002	56.246481000000003	56.228169999999999	проспект Ленинского Комсомола	0103000020E61000000100000005000000DEAE97A608B44540D3F6AFAC341D4C40DEAE97A608B44540EE0A7DB08C1F4C400EBF9B6ED9B54540EE0A7DB08C1F4C400EBF9B6ED9B54540D3F6AFAC341D4C40DEAE97A608B44540D3F6AFAC341D4C40
2942	9699	43.420670999999999	43.506442	56.246496	56.237402000000003	проспект Ленина	0103000020E6100000010000000500000014B01D8CD8B54540A4005130631E4C4014B01D8CD8B54540234C512E8D1F4C4011A96917D3C04540234C512E8D1F4C4011A96917D3C04540A4005130631E4C4014B01D8CD8B54540A4005130631E4C40
2794	9699	43.462235999999997	43.490704000000001	56.249487000000002	56.239027999999998	проспект Дзержинского	0103000020E6100000010000000500000055849B8C2ABB4540056A3178981E4C4055849B8C2ABB45407AE3A430EF1F4C4019028063CFBE45407AE3A430EF1F4C4019028063CFBE4540056A3178981E4C4055849B8C2ABB4540056A3178981E4C40
3625	9699	43.399552	43.400512999999997	56.226788999999997	56.221805000000003	бульвар Химиков	0103000020E6100000010000000500000094861A8524B345406E8B321B641C4C4094861A8524B34540D80B056C071D4C40B94F8E0244B34540D80B056C071D4C40B94F8E0244B345406E8B321B641C4C4094861A8524B345406E8B321B641C4C40
3216	9699	43.442518	43.452247	56.247560999999997	56.233980000000003	бульвар Мира	0103000020E6100000010000000500000017F2086EA4B8454084F57F0EF31D4C4017F2086EA4B84540ED612F14B01F4C40685BCD3AE3B94540ED612F14B01F4C40685BCD3AE3B9454084F57F0EF31D4C4017F2086EA4B8454084F57F0EF31D4C40
3781	9699	43.373060000000002	43.389823	56.229500999999999	56.229416000000001	бульвар Космонавтов	0103000020E610000001000000050000000FB9196EC0AF4540EE96E4805D1D4C400FB9196EC0AF45401CB3EC49601D4C40431D56B8E5B145401CB3EC49601D4C40431D56B8E5B14540EE96E4805D1D4C400FB9196EC0AF4540EE96E4805D1D4C40
19786	9699	43.394485000000003	43.408327999999997	56.241853999999996	56.241559000000002	Щорса	0103000020E610000001000000050000009CE1067C7EB24540F986C267EB1E4C409CE1067C7EB2454011346612F51E4C404205871744B4454011346612F51E4C404205871744B44540F986C267EB1E4C409CE1067C7EB24540F986C267EB1E4C40
19707	9699	43.474992	43.487560000000002	56.247306000000002	56.236611000000003	Черняховского	0103000020E610000001000000050000004AEEB089CCBC4540DB6FED44491E4C404AEEB089CCBC4540630D17B9A71F4C403C6BB75D68BE4540630D17B9A71F4C403C6BB75D68BE4540DB6FED44491E4C404AEEB089CCBC4540DB6FED44491E4C40
19531	9699	43.406683999999998	43.406837000000003	56.226754	56.221645000000002	Удриса	0103000020E610000001000000050000003AE7A7380EB44540352905DD5E1C4C403AE7A7380EB445405C1E6B46061D4C40C1E61C3C13B445405C1E6B46061D4C40C1E61C3C13B44540352905DD5E1C4C403AE7A7380EB44540352905DD5E1C4C40
19706	9699	43.419637999999999	43.453684000000003	56.229376000000002	56.225838000000003	Терешковой	0103000020E610000001000000050000005514AFB2B6B54540D7187442E81C4C405514AFB2B6B54540603E59315C1D4C40F75B3B5112BA4540603E59315C1D4C40F75B3B5112BA4540D7187442E81C4C405514AFB2B6B54540D7187442E81C4C40
19669	9699	43.389913	43.409092000000001	56.233324000000003	56.231113000000001	Строителей	0103000020E6100000010000000500000083A44FABE8B1454019575C1C951D4C4083A44FABE8B145409BAF928FDD1D4C4012876C205DB445409BAF928FDD1D4C4012876C205DB4454019575C1C951D4C4083A44FABE8B1454019575C1C951D4C40
19554	9699	43.454070000000002	43.466870999999998	56.256838000000002	56.255482000000001	Советская	0103000020E61000000100000005000000200C3CF71EBA4540BC5B59A2B3204C40200C3CF71EBA45405E2F4D11E0204C40B439CE6DC2BB45405E2F4D11E0204C40B439CE6DC2BB4540BC5B59A2B3204C40200C3CF71EBA4540BC5B59A2B3204C40
19628	9699	43.421722000000003	43.422558000000002	56.246445999999999	56.233083999999998	Самохвалова	0103000020E610000001000000050000007A008BFCFAB54540459C4EB2D51D4C407A008BFCFAB54540711DE38A8B1F4C40E3546B6116B64540711DE38A8B1F4C40E3546B6116B64540459C4EB2D51D4C407A008BFCFAB54540459C4EB2D51D4C40
19581	9699	43.431171999999997	43.439742000000003	56.248986000000002	56.240792999999996	Пожарского	0103000020E61000000100000005000000B779E3A430B74540880D164ED21E4C40B779E3A430B74540B894F3C5DE1F4C40BD56427749B84540B894F3C5DE1F4C40BD56427749B84540880D164ED21E4C40B779E3A430B74540880D164ED21E4C40
19561	9699	43.471426000000001	43.474964999999997	56.254691999999999	56.242784	Пирогова	0103000020E61000000100000005000000F73DEAAF57BC4540FCFECD8B131F4C40F73DEAAF57BC4540C34659BF99204C4050DF32A7CBBC4540C34659BF99204C4050DF32A7CBBC4540FCFECD8B131F4C40F73DEAAF57BC4540FCFECD8B131F4C40
19629	9699	43.410673000000003	43.436858999999998	56.235590999999999	56.230862000000002	Петрищева	0103000020E61000000100000005000000D42CD0EE90B44540D0F1D1E28C1D4C40D42CD0EE90B44540B01D8CD8271E4C404CFBE6FEEAB74540B01D8CD8271E4C404CFBE6FEEAB74540D0F1D1E28C1D4C40D42CD0EE90B44540D0F1D1E28C1D4C40
19735	9699	43.458167000000003	43.497540000000001	56.238746999999996	56.231073000000002	Октябрьская 	0103000020E61000000100000005000000A08D5C37A5BA45408BFED0CC931D4C40A08D5C37A5BA45405182FE428F1E4C40D6390664AFBF45405182FE428F1E4C40D6390664AFBF45408BFED0CC931D4C40A08D5C37A5BA45408BFED0CC931D4C40
19580	9699	43.458167000000003	43.497540000000001	56.238746999999996	56.231073000000002	Октябрьская	0103000020E61000000100000005000000A08D5C37A5BA45408BFED0CC931D4C40A08D5C37A5BA45405182FE428F1E4C40D6390664AFBF45405182FE428F1E4C40D6390664AFBF45408BFED0CC931D4C40A08D5C37A5BA45408BFED0CC931D4C40
2917	9699	43.460475000000002	43.486949000000003	56.231343000000003	56.226658999999998	Окская набережная	0103000020E6100000010000000500000014D044D8F0BA45400A2C8029031D4C4014D044D8F0BA45404B94BDA59C1D4C40F3E8465854BE45404B94BDA59C1D4C40F3E8465854BE45400A2C8029031D4C4014D044D8F0BA45400A2C8029031D4C40
19619	9699	43.435034999999999	43.471398999999998	56.250452000000003	56.242379	Маяковского	0103000020E61000000100000005000000C4CE143AAFB745405C1E6B46061F4C40C4CE143AAFB74540E19BA6CF0E204C40FD2E6CCD56BC4540E19BA6CF0E204C40FD2E6CCD56BC45405C1E6B46061F4C40C4CE143AAFB745405C1E6B46061F4C40
19622	9699	43.449570000000001	43.477867000000003	56.252462000000001	56.249721999999998	Матросова	0103000020E61000000100000005000000A1A17F828BB94540BD8BF7E3F61F4C40A1A17F828BB94540CBBDC0AC50204C40386BF0BE2ABD4540CBBDC0AC50204C40386BF0BE2ABD4540BD8BF7E3F61F4C40A1A17F828BB94540BD8BF7E3F61F4C40
19710	9699	43.433230000000002	43.443460999999999	56.242724000000003	56.239423000000002	Марковникова	0103000020E61000000100000005000000B3D2A41474B745408274B169A51E4C40B3D2A41474B7454027FA7C94111F4C4096067E54C3B8454027FA7C94111F4C4096067E54C3B845408274B169A51E4C40B3D2A41474B745408274B169A51E4C40
19596	9699	43.378486000000002	43.401088000000001	56.234960000000001	56.227013999999997	Комбрига Патоличева	0103000020E6100000010000000500000037FFAF3A72B04540F8DD74CB0E1D4C4037FFAF3A72B0454020EF552B131E4C40B66801DA56B3454020EF552B131E4C40B66801DA56B34540F8DD74CB0E1D4C4037FFAF3A72B04540F8DD74CB0E1D4C40
19768	9699	43.455589000000003	43.460943	56.244079999999997	56.239403000000003	Кирова	0103000020E610000001000000050000006CB587BD50BA45403BC8EBC1A41E4C406CB587BD50BA4540C8CD70033E1F4C40FA28232E00BB4540C8CD70033E1F4C40FA28232E00BB45403BC8EBC1A41E4C406CB587BD50BA45403BC8EBC1A41E4C40
19687	9699	43.449272999999998	43.454816000000001	56.243865	56.229250999999998	Грибоедова	0103000020E61000000100000005000000E7FC14C781B94540A3C9C518581D4C40E7FC14C781B94540CCD1E3F7361F4C4049D9226937BA4540CCD1E3F7361F4C4049D9226937BA4540A3C9C518581D4C40E7FC14C781B94540A3C9C518581D4C40
19555	9699	43.400432000000002	43.410673000000003	56.230862000000002	56.227924999999999	Галкина	0103000020E61000000100000005000000CD22145B41B345406C787AA52C1D4C40CD22145B41B34540D0F1D1E28C1D4C40D42CD0EE90B44540D0F1D1E28C1D4C40D42CD0EE90B445406C787AA52C1D4C40CD22145B41B345406C787AA52C1D4C40
19627	9699	43.435628000000001	43.448726000000001	56.249961999999996	56.229196000000002	Гайдара	0103000020E61000000100000005000000679C86A8C2B74540E02F664B561D4C40679C86A8C2B74540129F3BC1FE1F4C40B56E83DA6FB94540129F3BC1FE1F4C40B56E83DA6FB94540E02F664B561D4C40679C86A8C2B74540E02F664B561D4C40
19685	9699	43.45487	43.465335000000003	56.241204000000003	56.238787000000002	Гагарина	0103000020E610000001000000050000003CF71E2E39BA4540E0DA8992901E4C403CF71E2E39BA45400BD5CDC5DF1E4C409357E71890BB45400BD5CDC5DF1E4C409357E71890BB4540E0DA8992901E4C403CF71E2E39BA4540E0DA8992901E4C40
17768	9699	43.369970000000002	43.508660999999996	56.264617000000001	56.212358999999999	Встречная	0103000020E6100000010000000500000025404D2D5BAF4540710168942E1B4C4025404D2D5BAF45409A7B48F8DE214C4015E0BBCD1BC145409A7B48F8DE214C4015E0BBCD1BC14540710168942E1B4C4025404D2D5BAF4540710168942E1B4C40
19681	9699	43.447549000000002	43.476968999999997	56.247830999999998	56.245075	Ватутина	0103000020E61000000100000005000000C32D1F4949B945409A081B9E5E1F4C40C32D1F4949B94540ADF71BEDB81F4C40581AF8510DBD4540ADF71BEDB81F4C40581AF8510DBD45409A081B9E5E1F4C40C32D1F4949B945409A081B9E5E1F4C40
19624	9699	43.429797999999998	43.456685	56.249586999999998	56.240107999999999	Бутлерова	0103000020E610000001000000050000006FF1F09E03B7454005C1E3DBBB1E4C406FF1F09E03B74540DD408177F21F4C4071C971A774BA4540DD408177F21F4C4071C971A774BA454005C1E3DBBB1E4C406FF1F09E03B7454005C1E3DBBB1E4C40
19550	9699	43.408256000000002	43.435628000000001	56.238396999999999	56.234805000000001	Буденного	0103000020E61000000100000005000000A9328CBB41B44540F9F719170E1E4C40A9328CBB41B44540753BFBCA831E4C40679C86A8C2B74540753BFBCA831E4C40679C86A8C2B74540F9F719170E1E4C40A9328CBB41B44540F9F719170E1E4C40
17568	5618	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	Титова	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
17291	5618	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	Свердлова	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
16698	5618	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	Новая	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
16696	5618	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	Нахимова	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
18594	5618	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	Набережная Революции	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
17692	5618	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	Механизаторов	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
16691	5618	43.442383	43.503594999999997	56.669401000000001	56.610135999999997	Мелиораторов	0103000020E6100000010000000500000037A79201A0B845405E0EBBEF184E4C4037A79201A0B84540717495EEAE554C40EDB60BCD75C04540717495EEAE554C40EDB60BCD75C045405E0EBBEF184E4C4037A79201A0B845405E0EBBEF184E4C40
17194	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	микрорайон Южный	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17635	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	микрорайон Гоголя	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17399	138	41.776566000000003	47.770995999999997	58.091237	54.461975000000002	м-н Гоголя	0103000020E61000000100000005000000C097C28366E34440E9482EFF213B4B40C097C28366E34440B3976DA7AD0B4D4064AC36FFAFE24740B3976DA7AD0B4D4064AC36FFAFE24740E9482EFF213B4B40C097C28366E34440E9482EFF213B4B40
17230	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Школьный переулок	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
19438	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Чкалова	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17189	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Ульянова	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17546	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Стахановская	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
16732	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Слепнева	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17199	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Романова	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17668	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Поселок Строитель	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17606	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Первомайская	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
16978	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Островского	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
16789	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Новая	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17828	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Лепсе	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
16735	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Красные Зори	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
16702	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Гастелло	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17354	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	Амбулаторная	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
16836	138	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	1 Мая	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
16793	138	41.776566000000003	47.770995999999997	58.091237	54.461975000000002	 м-н Жуковского	0103000020E61000000100000005000000C097C28366E34440E9482EFF213B4B40C097C28366E34440B3976DA7AD0B4D4064AC36FFAFE24740B3976DA7AD0B4D4064AC36FFAFE24740E9482EFF213B4B40C097C28366E34440E9482EFF213B4B40
19567	50053	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Республиканская	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19563	50053	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Октябрьская	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19743	50053	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Молодежная	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
77528	50053	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Молодежная	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19592	50053	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Максима Горького 	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19699	50053	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Коммунистическая	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19535	50053	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	8 Марта	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17444	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	переулок Советский	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16913	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Энгельса	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16906	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Фигнер	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16914	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Суворова	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17107	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Строительная	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16900	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Стеклозаводское шоссе	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19444	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Профсоюзная	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17675	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Плеханова	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16759	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Первомайская	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17031	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Октябрьская	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19476	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Нахимова	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19474	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Мира	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
9911	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Махалова	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17146	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Лермонтова	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16915	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Ленина	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16904	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Коммунистическая	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16744	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Кольцова	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16909	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Интернациональная	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16905	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Воровского	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
16903	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	Ванеева	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
19527	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	8 Марта	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17052	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	2-й Микрорайон	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17038	40353	43.774239000000001	43.8033	56.200543000000003	56.190421000000001	2 микрорайон	0103000020E61000000100000005000000D52478431AE345405EBC1FB75F184C40D52478431AE345408B389D64AB194C403B70CE88D2E645408B389D64AB194C403B70CE88D2E645405EBC1FB75F184C40D52478431AE345405EBC1FB75F184C40
17581	14518	43.476447999999998	43.560988000000002	56.117361000000002	56.086072999999999	Механизаторов	0103000020E610000001000000050000004F1F813FFCBC4540C808A870040B4C404F1F813FFCBC4540B6696CAF050F4C4067B96C74CEC74540B6696CAF050F4C4067B96C74CEC74540C808A870040B4C404F1F813FFCBC4540C808A870040B4C40
17171	14518	43.476447999999998	43.560988000000002	56.117361000000002	56.086072999999999	Героя Усилова	0103000020E610000001000000050000004F1F813FFCBC4540C808A870040B4C404F1F813FFCBC4540B6696CAF050F4C4067B96C74CEC74540B6696CAF050F4C4067B96C74CEC74540C808A870040B4C404F1F813FFCBC4540C808A870040B4C40
17652	49824	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	40 лет Пионерской организации	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
3323	6490	43.818812999999999	43.833311999999999	55.406174999999998	55.400266000000002	улица Парковая	0103000020E61000000100000005000000134548DDCEE84540B2D991EA3BB34B40134548DDCEE84540F5B9DA8AFDB34B40A3AEB5F7A9EA4540F5B9DA8AFDB34B40A3AEB5F7A9EA4540B2D991EA3BB34B40134548DDCEE84540B2D991EA3BB34B40
3184	6490	43.835737999999999	43.855060000000002	55.406891000000002	55.404243000000001	улица Мира	0103000020E6100000010000000500000021037976F9EA45408751103CBEB34B4021037976F9EA4540B404190115B44B40130F289B72ED4540B404190115B44B40130F289B72ED45408751103CBEB34B4021037976F9EA45408751103CBEB34B40
3064	6490	43.846615999999997	43.853461000000003	55.412773999999999	55.394038999999999	улица 9 Мая	0103000020E610000001000000050000009A22C0E95DEC45409D2CB5DE6FB24B409A22C0E95DEC4540CE5147C7D5B44B40ABB4C5353EED4540CE5147C7D5B44B40ABB4C5353EED45409D2CB5DE6FB24B409A22C0E95DEC45409D2CB5DE6FB24B40
3260	6490	43.826683000000003	43.838521999999998	55.409309	55.393881	проспект Ленина	0103000020E610000001000000050000006094A0BFD0E9454005C24EB16AB24B406094A0BFD0E94540AF7AC03C64B44B40FE7C5BB054EB4540AF7AC03C64B44B40FE7C5BB054EB454005C24EB16AB24B406094A0BFD0E9454005C24EB16AB24B40
3487	6490	43.812390000000001	43.816181	55.388005999999997	55.386006000000002	площадь Соборная	0103000020E6100000010000000500000079CC4065FCE74540A70705A568B14B4079CC4065FCE745406D533C2EAAB14B40EC4E779E78E845406D533C2EAAB14B40EC4E779E78E84540A70705A568B14B4079CC4065FCE74540A70705A568B14B40
19530	6490	43.899400999999997	43.899635000000004	55.375030000000002	55.369055000000003	Центральная	0103000020E61000000100000005000000AE7E6C921FF3454070B6B9313DAF4B40AE7E6C921FF345406B82A8FB00B04B4022AB5B3D27F345406B82A8FB00B04B4022AB5B3D27F3454070B6B9313DAF4B40AE7E6C921FF3454070B6B9313DAF4B40
19646	6490	43.810862999999998	43.821553000000002	55.386445999999999	55.383111999999997	Урицкого	0103000020E61000000100000005000000AA44D95BCAE74540425A63D009B14B40AA44D95BCAE74540C3D5011077B14B40217711A628E94540C3D5011077B14B40217711A628E94540425A63D009B14B40AA44D95BCAE74540425A63D009B14B40
19696	6490	43.798107000000002	43.808796999999998	55.410452999999997	55.406813999999997	Семашко	0103000020E61000000100000005000000B6DAC35E28E6454008C72C7B12B44B40B6DAC35E28E64540C5C551B989B44B402C0DFCA886E74540C5C551B989B44B402C0DFCA886E7454008C72C7B12B44B40B6DAC35E28E6454008C72C7B12B44B40
19701	6490	43.833240000000004	43.847254	55.400174	55.397398000000003	Севастопольская	0103000020E610000001000000050000000ADCBA9BA7EA454077BF0AF0DDB24B400ADCBA9BA7EA4540D15AD1E638B34B40DDB3AED172EC4540D15AD1E638B34B40DDB3AED172EC454077BF0AF0DDB24B400ADCBA9BA7EA454077BF0AF0DDB24B40
19779	6490	43.803614000000003	43.835118000000001	55.395766999999999	55.390782000000002	Свободы	0103000020E61000000100000005000000CB4DD4D2DCE64540C8EE022505B24B40CB4DD4D2DCE6454003EB387EA8B24B4085268925E5EA454003EB387EA8B24B4085268925E5EA4540C8EE022505B24B40CB4DD4D2DCE64540C8EE022505B24B40
78479	6490	43.824418999999999	43.836114999999999	55.400762	55.377890000000001	Пушкина	0103000020E61000000100000005000000BB99D18F86E9454023BE13B35EB04B40BB99D18F86E9454062BD512B4CB34B40F758FAD005EB454062BD512B4CB34B40F758FAD005EB454023BE13B35EB04B40BB99D18F86E9454023BE13B35EB04B40
19702	6490	43.809570000000001	43.818821999999997	55.406058000000002	55.400419999999997	Пландина	0103000020E610000001000000050000004FE960FD9FE7454008556AF640B34B404FE960FD9FE74540BC2363B5F9B34B40669FC728CFE84540BC2363B5F9B34B40669FC728CFE8454008556AF640B34B404FE960FD9FE7454008556AF640B34B40
19560	6490	43.818812999999999	43.833311999999999	55.406174999999998	55.400266000000002	Парковая	0103000020E61000000100000005000000134548DDCEE84540B2D991EA3BB34B40134548DDCEE84540F5B9DA8AFDB34B40A3AEB5F7A9EA4540F5B9DA8AFDB34B40A3AEB5F7A9EA4540B2D991EA3BB34B40134548DDCEE84540B2D991EA3BB34B40
19576	6490	43.840004999999998	43.850828999999997	55.409849999999999	55.398595	Нижегородская	0103000020E61000000100000005000000FDBCA94885EB4540B0AC342905B34B40FDBCA94885EB4540FF21FDF675B44B4083BEF4F6E7EC4540FF21FDF675B44B4083BEF4F6E7EC4540B0AC342905B34B40FDBCA94885EB4540B0AC342905B34B40
19552	6490	43.835737999999999	43.855060000000002	55.406891000000002	55.404243000000001	Мира	0103000020E6100000010000000500000021037976F9EA45408751103CBEB34B4021037976F9EA4540B404190115B44B40130F289B72ED4540B404190115B44B40130F289B72ED45408751103CBEB34B4021037976F9EA45408751103CBEB34B40
19500	6490	43.809992000000001	43.833230999999998	55.391171	55.387320000000003	Максима Горького	0103000020E61000000100000005000000C5025FD1ADE745401A8BA6B393B14B40C5025FD1ADE7454062122EE411B24B40B6813B50A7EA454062122EE411B24B40B6813B50A7EA45401A8BA6B393B14B40C5025FD1ADE745401A8BA6B393B14B40
19682	6490	43.809829999999998	43.917403999999998	55.388379	55.379295999999997	Ленина	0103000020E61000000100000005000000EBA86A82A8E7454076C075C58CB04B40EBA86A82A8E7454002BA2F67B6B14B401B9C887E6DF5454002BA2F67B6B14B401B9C887E6DF5454076C075C58CB04B40EBA86A82A8E7454076C075C58CB04B40
19800	6490	43.838531000000003	43.860557999999997	55.418793000000001	55.409314000000002	Красный путь	0103000020E6100000010000000500000052D7DAFB54EB4540C1E5B16664B44B4052D7DAFB54EB454099654F029BB54B40D427B9C326EE454099654F029BB54B40D427B9C326EE4540C1E5B16664B44B4052D7DAFB54EB4540C1E5B16664B44B40
19778	6490	43.816181	43.825650000000003	55.397689999999997	55.387433000000001	Карла Маркса	0103000020E61000000100000005000000EC4E779E78E845401232906797B14B40EC4E779E78E845401EF98381E7B24B40A1F831E6AEE945401EF98381E7B24B40A1F831E6AEE945401232906797B14B40EC4E779E78E845401232906797B14B40
19559	6490	43.808473999999997	43.864348999999997	55.401063999999998	55.391202	Калинина	0103000020E6100000010000000500000049D576137CE745409D103AE812B24B4049D576137CE745402DCDAD1056B34B4047AAEFFCA2EE45402DCDAD1056B34B4047AAEFFCA2EE45409D103AE812B24B4049D576137CE745409D103AE812B24B40
19709	6490	43.807001	43.814259	55.418838999999998	55.408214999999998	Зеленая	0103000020E610000001000000050000006E6B0BCF4BE745404A5E9D6340B44B406E6B0BCF4BE7454009A52F849CB54B40A1BC8FA339E8454009A52F849CB54B40A1BC8FA339E845404A5E9D6340B44B406E6B0BCF4BE745404A5E9D6340B44B40
19648	6490	43.818812999999999	43.820079999999997	55.406067999999998	55.398820000000001	Жуковского	0103000020E61000000100000005000000134548DDCEE84540D07EA4880CB34B40134548DDCEE84540DFF94509FAB34B40450DA661F8E84540DFF94509FAB34B40450DA661F8E84540D07EA4880CB34B40134548DDCEE84540D07EA4880CB34B40
19751	6490	43.816208000000003	43.836114999999999	55.384312999999999	55.366194999999998	Володарского	0103000020E61000000100000005000000E65DF58079E84540B77A4E7ADFAE4B40E65DF58079E84540BD361B2B31B14B40F758FAD005EB4540BD361B2B31B14B40F758FAD005EB4540B77A4E7ADFAE4B40E65DF58079E84540B77A4E7ADFAE4B40
19565	6490	43.819307999999999	43.833374999999997	55.377281000000004	55.375010000000003	Вахтерова	0103000020E61000000100000005000000F3ACA415DFE8454024D6E25300B04B40F3ACA415DFE845407B336ABE4AB04B40E9263108ACEA45407B336ABE4AB04B40E9263108ACEA454024D6E25300B04B40F3ACA415DFE8454024D6E25300B04B40
19605	6490	43.757432000000001	43.917816999999999	55.430314000000003	55.346246000000001	9 Мая	0103000020E61000000100000005000000D1782288F3E04540772FF7C951AC4B40D1782288F3E045406781768714B74B403E5B07077BF545406781768714B74B403E5B07077BF54540772FF7C951AC4B40D1782288F3E04540772FF7C951AC4B40
19801	6490	43.832332999999998	43.841532000000001	55.375895	55.371163000000003	11 микрорайон 	0103000020E61000000100000005000000D73043E389EA45401D3EE94482AF4B40D73043E389EA45406EDDCD531DB04B40CC441152B7EB45406EDDCD531DB04B40CC441152B7EB45401D3EE94482AF4B40D73043E389EA45401D3EE94482AF4B40
19808	6490	43.832332999999998	43.841532000000001	55.375895	55.371163000000003	11 микрорайон	0103000020E61000000100000005000000D73043E389EA45401D3EE94482AF4B40D73043E389EA45406EDDCD531DB04B40CC441152B7EB45406EDDCD531DB04B40CC441152B7EB45401D3EE94482AF4B40D73043E389EA45401D3EE94482AF4B40
19548	6490	43.757432000000001	43.917816999999999	55.430314000000003	55.346246000000001	1 Мая	0103000020E61000000100000005000000D1782288F3E04540772FF7C951AC4B40D1782288F3E045406781768714B74B403E5B07077BF545406781768714B74B403E5B07077BF54540772FF7C951AC4B40D1782288F3E04540772FF7C951AC4B40
16767	7520	46.571198000000003	46.668574999999997	57.692487999999997	57.646365000000003	Черняховского	0103000020E6100000010000000500000033C51C041D494740B8239C16BCD24C4033C51C041D494740AC6F6072A3D84C402BF697DD93554740AC6F6072A3D84C402BF697DD93554740B8239C16BCD24C4033C51C041D494740B8239C16BCD24C40
17700	7520	46.571198000000003	46.668574999999997	57.692487999999997	57.646365000000003	Чапаева	0103000020E6100000010000000500000033C51C041D494740B8239C16BCD24C4033C51C041D494740AC6F6072A3D84C402BF697DD93554740AC6F6072A3D84C402BF697DD93554740B8239C16BCD24C4033C51C041D494740B8239C16BCD24C40
17846	7520	46.571198000000003	46.668574999999997	57.692487999999997	57.646365000000003	Советская	0103000020E6100000010000000500000033C51C041D494740B8239C16BCD24C4033C51C041D494740AC6F6072A3D84C402BF697DD93554740AC6F6072A3D84C402BF697DD93554740B8239C16BCD24C4033C51C041D494740B8239C16BCD24C40
17123	7520	46.571198000000003	46.668574999999997	57.692487999999997	57.646365000000003	Пасхина	0103000020E6100000010000000500000033C51C041D494740B8239C16BCD24C4033C51C041D494740AC6F6072A3D84C402BF697DD93554740AC6F6072A3D84C402BF697DD93554740B8239C16BCD24C4033C51C041D494740B8239C16BCD24C40
16814	7520	46.571198000000003	46.668574999999997	57.692487999999997	57.646365000000003	Ленина	0103000020E6100000010000000500000033C51C041D494740B8239C16BCD24C4033C51C041D494740AC6F6072A3D84C402BF697DD93554740AC6F6072A3D84C402BF697DD93554740B8239C16BCD24C4033C51C041D494740B8239C16BCD24C40
17126	7520	46.571198000000003	46.668574999999997	57.692487999999997	57.646365000000003	Комсомольская	0103000020E6100000010000000500000033C51C041D494740B8239C16BCD24C4033C51C041D494740AC6F6072A3D84C402BF697DD93554740AC6F6072A3D84C402BF697DD93554740B8239C16BCD24C4033C51C041D494740B8239C16BCD24C40
17721	8916	46.385497999999998	46.422669999999997	57.542051999999998	57.526659000000002	Октябрьская	0103000020E6100000010000000500000032569BFF573147407192E68F69C34C4032569BFF573147409E5DBEF561C54C400A80F10C1A3647409E5DBEF561C54C400A80F10C1A3647407192E68F69C34C4032569BFF573147407192E68F69C34C40
16738	49638	46.601992000000003	46.628509999999999	57.720982999999997	57.710296999999997	Молодежная	0103000020E61000000100000005000000113AE8120E4D474034B91803EBDA4C40113AE8120E4D474069FCC22B49DC4C40BF9A03047350474069FCC22B49DC4C40BF9A03047350474034B91803EBDA4C40113AE8120E4D474034B91803EBDA4C40
16705	8135	46.276595	46.381104999999998	58.033647999999999	58.006788	Просвещения	0103000020E610000001000000050000005A9E077767234740AC00DF6DDE004D405A9E077767234740B4C9E1934E044D40C9AB730CC8304740B4C9E1934E044D40C9AB730CC8304740AC00DF6DDE004D405A9E077767234740AC00DF6DDE004D40
17708	8135	46.276595	46.381104999999998	58.033647999999999	58.006788	Ленина	0103000020E610000001000000050000005A9E077767234740AC00DF6DDE004D405A9E077767234740B4C9E1934E044D40C9AB730CC8304740B4C9E1934E044D40C9AB730CC8304740AC00DF6DDE004D405A9E077767234740AC00DF6DDE004D40
17520	8298	46.616858999999998	46.634619000000001	57.650627999999998	57.632317	Молодежная	0103000020E61000000100000005000000239F573CF54E474038DA71C3EFD04C40239F573CF54E474052EE3EC747D34C40CA3505323B51474052EE3EC747D34C40CA3505323B51474038DA71C3EFD04C40239F573CF54E474038DA71C3EFD04C40
16690	8692	46.387303000000003	46.397948	57.625411999999997	57.619667	Новая	0103000020E6100000010000000500000044520B259331474089B48D3F51CF4C4044520B259331474052431B800DD04C401AC1C6F5EF32474052431B800DD04C401AC1C6F5EF32474089B48D3F51CF4C4044520B259331474089B48D3F51CF4C40
17420	8726	46.289512999999999	46.315007000000001	57.764375000000001	57.750368000000002	Центральная	0103000020E61000000100000005000000286211C30E25474083FB010F0CE04C40286211C30E254740A4703D0AD7E14C406B813D2652284740A4703D0AD7E14C406B813D265228474083FB010F0CE04C40286211C30E25474083FB010F0CE04C40
17588	16037	46.364413999999996	46.384670999999997	57.648913	57.635097999999999	Полевая	0103000020E610000001000000050000002E1A321EA52E4740A4E029E44AD14C402E1A321EA52E47408179C8940FD34C401C5C3AE63C3147408179C8940FD34C401C5C3AE63C314740A4E029E44AD14C402E1A321EA52E4740A4E029E44AD14C40
17332	8563	46.372481000000001	46.412627000000001	57.909632999999999	57.893090000000001	Центральная	0103000020E61000000100000005000000D1B01875AD2F47403C31EBC550F24C40D1B01875AD2F4740622EA9DA6EF44C402A3927F6D0344740622EA9DA6EF44C402A3927F6D03447403C31EBC550F24C40D1B01875AD2F47403C31EBC550F24C40
17061	7914	46.650384000000003	46.716734000000002	57.982590000000002	57.946216	Ленина	0103000020E61000000100000005000000BCEB6CC83F534740D9791B9B1DF94C40BCEB6CC83F53474036B05582C5FD4C4034F790F0BD5B474036B05582C5FD4C4034F790F0BD5B4740D9791B9B1DF94C40BCEB6CC83F534740D9791B9B1DF94C40
17129	7914	46.650384000000003	46.716734000000002	57.982590000000002	57.946216	Карповская	0103000020E61000000100000005000000BCEB6CC83F534740D9791B9B1DF94C40BCEB6CC83F53474036B05582C5FD4C4034F790F0BD5B474036B05582C5FD4C4034F790F0BD5B4740D9791B9B1DF94C40BCEB6CC83F534740D9791B9B1DF94C40
17472	8814	46.193438	46.220557999999997	57.640912999999998	57.625551999999999	Широковская	0103000020E61000000100000005000000DEE68D93C218474044F9821612D04C40DEE68D93C2184740664AEB6F09D24C40826F9A3E3B1C4740664AEB6F09D24C40826F9A3E3B1C474044F9821612D04C40DEE68D93C218474044F9821612D04C40
17330	8492	46.279415999999998	46.298496	57.708646999999999	57.694715000000002	Школьная	0103000020E6100000010000000500000054FD4AE7C32347403485CE6BECD84C4054FD4AE7C32347404AB4E4F1B4DA4C4050FEEE1D352647404AB4E4F1B4DA4C4050FEEE1D352647403485CE6BECD84C4054FD4AE7C32347403485CE6BECD84C40
17525	8742	46.184069000000001	46.198225999999998	57.747611999999997	57.735568000000001	Школьная	0103000020E610000001000000050000008D9AAF928F174740F8FD9B1727DE4C408D9AAF928F1747406F0C01C0B1DF4C40C39B35785F1947406F0C01C0B1DF4C40C39B35785F194740F8FD9B1727DE4C408D9AAF928F174740F8FD9B1727DE4C40
18284	8221	46.532085000000002	46.554102999999998	57.606606999999997	57.598861999999997	Новая	0103000020E6100000010000000500000099D87C5C1B44474098689082A7CC4C4099D87C5C1B4447402843554CA5CD4C40C8CEDBD8EC4647402843554CA5CD4C40C8CEDBD8EC46474098689082A7CC4C4099D87C5C1B44474098689082A7CC4C40
19558	50059	43.781300000000002	44.838698000000001	55.386097999999997	55.028925000000001	Ленина	0103000020E61000000100000005000000B22E6EA301E44540B6847CD0B3834B40B22E6EA301E445408786C5A86BB14B403D9CC0745A6B46408786C5A86BB14B403D9CC0745A6B4640B6847CD0B3834B40B22E6EA301E44540B6847CD0B3834B40
17312	7305	44.596736999999997	44.620002999999997	55.253943	55.243895000000002	Мира	0103000020E6100000010000000500000015A8C5E0614C464037548CF3379F4B4015A8C5E0614C46402906483481A04B40003620425C4F46402906483481A04B40003620425C4F464037548CF3379F4B4015A8C5E0614C464037548CF3379F4B40
17097	5962	44.092700999999998	44.158709000000002	55.204777	55.165770000000002	Центральная	0103000020E610000001000000050000003BA759A0DD0B464037548CF337954B403BA759A0DD0B46408BFCFA21369A4B405A4A9693501446408BFCFA21369A4B405A4A96935014464037548CF337954B403BA759A0DD0B464037548CF337954B40
17101	5962	44.092700999999998	44.158709000000002	55.204777	55.165770000000002	Ленина	0103000020E610000001000000050000003BA759A0DD0B464037548CF337954B403BA759A0DD0B46408BFCFA21369A4B405A4A9693501446408BFCFA21369A4B405A4A96935014464037548CF337954B403BA759A0DD0B464037548CF337954B40
17678	5962	44.092700999999998	44.158709000000002	55.204777	55.165770000000002	Железнодорожная	0103000020E610000001000000050000003BA759A0DD0B464037548CF337954B403BA759A0DD0B46408BFCFA21369A4B405A4A9693501446408BFCFA21369A4B405A4A96935014464037548CF337954B403BA759A0DD0B464037548CF337954B40
17286	5962	44.092700999999998	44.158709000000002	55.204777	55.165770000000002	1 Микрорайон	0103000020E610000001000000050000003BA759A0DD0B464037548CF337954B403BA759A0DD0B46408BFCFA21369A4B405A4A9693501446408BFCFA21369A4B405A4A96935014464037548CF337954B403BA759A0DD0B464037548CF337954B40
17491	5962	44.092700999999998	44.158709000000002	55.204777	55.165770000000002	1 Мая	0103000020E610000001000000050000003BA759A0DD0B464037548CF337954B403BA759A0DD0B46408BFCFA21369A4B405A4A9693501446408BFCFA21369A4B405A4A96935014464037548CF337954B403BA759A0DD0B464037548CF337954B40
17727	7238	44.699539999999999	44.736046999999999	55.280163999999999	55.261659000000002	Центральная	0103000020E61000000100000005000000361FD7868A5946401FDAC70A7EA14B40361FD7868A5946401EC2F869DCA34B40D2A8C0C9365E46401EC2F869DCA34B40D2A8C0C9365E46401FDAC70A7EA14B40361FD7868A5946401FDAC70A7EA14B40
17488	6674	44.328634000000001	44.360156000000003	55.230159	55.205922999999999	60 лет Октября	0103000020E61000000100000005000000452DCDAD102A4640423F53AF5B9A4B40452DCDAD102A4640A6F0A0D9759D4B40A6BA8097192E4640A6F0A0D9759D4B40A6BA8097192E4640423F53AF5B9A4B40452DCDAD102A4640423F53AF5B9A4B40
17512	6938	44.328814000000001	44.368330999999998	55.109440999999997	55.090974000000003	Советская	0103000020E61000000100000005000000C53BC093162A4640A6643909A58B4B40C53BC093162A4640B7EBA529028E4B402E8D5F78252F4640B7EBA529028E4B402E8D5F78252F4640A6643909A58B4B40C53BC093162A4640A6643909A58B4B40
17310	49777	43.877428999999999	43.893453999999998	55.126282000000003	55.109394000000002	Советская	0103000020E61000000100000005000000EFC7ED974FF045407730629F008E4B40EFC7ED974FF04540680932022A904B407D3D5FB35CF24540680932022A904B407D3D5FB35CF245407730629F008E4B40EFC7ED974FF045407730629F008E4B40
17120	6923	44.044479000000003	44.062975999999999	55.250639	55.236795999999998	Молодежная	0103000020E61000000100000005000000ED2DE57CB10546406CE9D1544F9E4B40ED2DE57CB1054640130D52F014A04B406937FA980F084640130D52F014A04B406937FA980F0846406CE9D1544F9E4B40ED2DE57CB10546406CE9D1544F9E4B40
17041	6588	43.889726000000003	43.916218000000001	55.222538999999998	55.207084000000002	Советская	0103000020E610000001000000050000005133A48AE2F145402FC37FBA819A4B405133A48AE2F14540D28A6F287C9C4B40D600A5A146F54540D28A6F287C9C4B40D600A5A146F545402FC37FBA819A4B405133A48AE2F145402FC37FBA819A4B40
17326	7011	\N	\N	\N	\N	Коммунистическая	\N
17686	6261	43.928030999999997	43.937454000000002	55.099387	55.093102000000002	Электриков	0103000020E610000001000000050000004B5645B8C9F645409A982EC4EA8B4B404B5645B8C9F64540E35295B6B88C4B4090C01F7EFEF74540E35295B6B88C4B4090C01F7EFEF745409A982EC4EA8B4B404B5645B8C9F645409A982EC4EA8B4B40
19509	50044	43.967672999999998	44.001944000000002	55.279944	55.254733000000002	Молодежная	0103000020E61000000100000005000000711C78B5DCFB4540221B48179BA04B40711C78B5DCFB4540105B7A34D5A34B40333674B33F004640105B7A34D5A34B40333674B33F004640221B48179BA04B40711C78B5DCFB4540221B48179BA04B40
16757	6742	44.464666000000001	44.495100999999998	55.310437	55.299655000000001	Школьная	0103000020E6100000010000000500000015C8EC2C7A3B46409C8A54185BA64B4015C8EC2C7A3B4640F33B4D66BCA74B40C39B35785F3F4640F33B4D66BCA74B40C39B35785F3F46409C8A54185BA64B4015C8EC2C7A3B46409C8A54185BA64B40
17691	49832	43.982081999999998	44.004036999999997	55.117153999999999	55.104950000000002	Центральная	0103000020E61000000100000005000000C1FEEBDCB4FD45408CDB68006F8D4B40C1FEEBDCB4FD45403C4CFBE6FE8E4B40AA7CCF48840046403C4CFBE6FE8E4B40AA7CCF48840046408CDB68006F8D4B40C1FEEBDCB4FD45408CDB68006F8D4B40
16714	7205	44.498379999999997	44.539234999999998	55.270733	55.241083000000003	Учительская	0103000020E61000000100000005000000807D74EACA3F4640904FC8CEDB9E4B40807D74EACA3F464057790261A7A24B40E5ED08A70545464057790261A7A24B40E5ED08A705454640904FC8CEDB9E4B40807D74EACA3F4640904FC8CEDB9E4B40
17070	6790	44.597876999999997	44.624000000000002	55.340712000000003	55.326326999999999	Центральная	0103000020E61000000100000005000000EA03C93B874C4640A1664815C5A94B40EA03C93B874C464069AD68739CAB4B401D5A643BDF4F464069AD68739CAB4B401D5A643BDF4F4640A1664815C5A94B40EA03C93B874C4640A1664815C5A94B40
16988	5067	46.636541000000001	46.663598	57.328229	57.318334999999998	Центральная	0103000020E6100000010000000500000015C8EC2C7A51474009168733BFA84C4015C8EC2C7A514740A54C6A6803AA4C4073D87DC7F0544740A54C6A6803AA4C4073D87DC7F054474009168733BFA84C4015C8EC2C7A51474009168733BFA84C40
17407	4903	46.500033000000002	46.578169000000003	57.194352000000002	57.153146	Парковая	0103000020E61000000100000005000000DCF5D21401404740B1C1C2499A934C40DCF5D21401404740C3F4BD86E0984C40D0471971014A4740C3F4BD86E0984C40D0471971014A4740B1C1C2499A934C40DCF5D21401404740B1C1C2499A934C40
17454	4903	46.500033000000002	46.578169000000003	57.194352000000002	57.153146	Ленина	0103000020E61000000100000005000000DCF5D21401404740B1C1C2499A934C40DCF5D21401404740C3F4BD86E0984C40D0471971014A4740C3F4BD86E0984C40D0471971014A4740B1C1C2499A934C40DCF5D21401404740B1C1C2499A934C40
17667	4903	46.500033000000002	46.578169000000003	57.194352000000002	57.153146	Большевиков	0103000020E61000000100000005000000DCF5D21401404740B1C1C2499A934C40DCF5D21401404740C3F4BD86E0984C40D0471971014A4740C3F4BD86E0984C40D0471971014A4740B1C1C2499A934C40DCF5D21401404740B1C1C2499A934C40
17445	5816	46.471628000000003	46.493924	57.180529	57.166989000000001	Молодежная	0103000020E610000001000000050000005FF0694E5E3C474058E542E55F954C405FF0694E5E3C4740637D03931B974C40D15AD1E6383F4740637D03931B974C40D15AD1E6383F474058E542E55F954C405FF0694E5E3C474058E542E55F954C40
17672	5691	46.470109999999998	46.502324000000002	56.971325	56.958213000000001	Колхозная	0103000020E61000000100000005000000E3C281902C3C474010CD3CB9A67A4C40E3C281902C3C4740C364AA60547C4C407AFF1F274C404740C364AA60547C4C407AFF1F274C40474010CD3CB9A67A4C40E3C281902C3C474010CD3CB9A67A4C40
17482	5523	46.529031000000003	46.558692999999998	57.058942999999999	57.041528999999997	Учительская	0103000020E61000000100000005000000FCC8AD49B7434740F46A80D250854C40FCC8AD49B743474000AAB8718B874C4087C091408347474000AAB8718B874C4087C0914083474740F46A80D250854C40FCC8AD49B7434740F46A80D250854C40
18070	5903	46.557876	46.571683	57.139122	57.132024999999999	Колхозная	0103000020E61000000100000005000000959C137B6847474090A0F831E6904C40959C137B68474740BA13ECBFCE914C40EF5696E82C494740BA13ECBFCE914C40EF5696E82C49474090A0F831E6904C40959C137B6847474090A0F831E6904C40
17058	5205	46.622959000000002	46.654722999999997	57.243124999999999	57.229647	Заречная	0103000020E61000000100000005000000DBDFD91EBD4F4740F04FA912659D4C40DBDFD91EBD4F474085EB51B81E9F4C40317898F6CD53474085EB51B81E9F4C40317898F6CD534740F04FA912659D4C40DBDFD91EBD4F4740F04FA912659D4C40
16937	5619	46.384715999999997	46.399889000000002	57.049402000000001	57.040163	Центральная	0103000020E61000000100000005000000BC1FB75F3E3147402FC1A90F24854C40BC1FB75F3E314740B22D03CE52864C40DC8310902F334740B22D03CE52864C40DC8310902F3347402FC1A90F24854C40BC1FB75F3E3147402FC1A90F24854C40
17743	5335	46.693216	46.747599999999998	57.133645999999999	57.115631999999998	Советская	0103000020E610000001000000050000002F88484DBB5847407F2F8507CD8E4C402F88484DBB584740E09EE74F1B914C40AB3E575BB15F4740E09EE74F1B914C40AB3E575BB15F47407F2F8507CD8E4C402F88484DBB5847407F2F8507CD8E4C40
17412	5159	46.625411	46.644123	57.281179999999999	57.267719999999997	Главная	0103000020E6100000010000000500000082C7B7770D504740183E22A644A24C4082C7B7770D5047400725CCB4FDA34C40FBCC599F725247400725CCB4FDA34C40FBCC599F72524740183E22A644A24C4082C7B7770D504740183E22A644A24C40
17024	3827	43.196488000000002	43.269385999999997	56.780127	56.750245999999997	пл.Чкалова	0103000020E610000001000000050000003A07CF842699454037FA980F08604C403A07CF842699454001DD9733DB634C4008008E3D7BA2454001DD9733DB634C4008008E3D7BA2454037FA980F08604C403A07CF842699454037FA980F08604C40
17259	3827	43.196488000000002	43.269385999999997	56.780127	56.750245999999997	Матросова	0103000020E610000001000000050000003A07CF842699454037FA980F08604C403A07CF842699454001DD9733DB634C4008008E3D7BA2454001DD9733DB634C4008008E3D7BA2454037FA980F08604C403A07CF842699454037FA980F08604C40
16807	3827	43.196488000000002	43.269385999999997	56.780127	56.750245999999997	Ломоносова	0103000020E610000001000000050000003A07CF842699454037FA980F08604C403A07CF842699454001DD9733DB634C4008008E3D7BA2454001DD9733DB634C4008008E3D7BA2454037FA980F08604C403A07CF842699454037FA980F08604C40
17240	3827	43.196488000000002	43.269385999999997	56.780127	56.750245999999997	Комсомольская	0103000020E610000001000000050000003A07CF842699454037FA980F08604C403A07CF842699454001DD9733DB634C4008008E3D7BA2454001DD9733DB634C4008008E3D7BA2454037FA980F08604C403A07CF842699454037FA980F08604C40
17591	4635	43.147053	43.162072999999999	56.771284000000001	56.760322000000002	Парковая	0103000020E61000000100000005000000ACE3F8A1D2924540F436363B52614C40ACE3F8A1D2924540CBF6216FB9624C404548DDCEBE944540CBF6216FB9624C404548DDCEBE944540F436363B52614C40ACE3F8A1D2924540F436363B52614C40
17560	4690	43.041285999999999	43.089075999999999	56.654193999999997	56.633184	Ленина	0103000020E610000001000000050000002EE411DC48854540DC2C5E2C0C514C402EE411DC48854540A59E05A1BC534C40E36DA5D7668B4540A59E05A1BC534C40E36DA5D7668B4540DC2C5E2C0C514C402EE411DC48854540DC2C5E2C0C514C40
17447	4552	43.041932000000003	43.062109	56.755358000000001	56.746011000000003	Кооперативная	0103000020E61000000100000005000000F4531C075E85454067BAD7497D5F4C40F4531C075E854540D0622992AF604C40C5E40D30F3874540D0622992AF604C40C5E40D30F387454067BAD7497D5F4C40F4531C075E85454067BAD7497D5F4C40
16729	1368	42.924469000000002	42.933577999999997	56.749890000000001	56.744213999999999	площадь Центральная	0103000020E610000001000000050000003A950C0055764540D89C8367425F4C403A950C005576454079CC4065FC5F4C40EE21E17B7F77454079CC4065FC5F4C40EE21E17B7F774540D89C8367425F4C403A950C0055764540D89C8367425F4C40
17436	4139	43.211004000000003	43.23516	56.840242000000003	56.824607	Чкалова	0103000020E61000000100000005000000A0A9D72D029B4540BE86E0B88C694C40A0A9D72D029B4540E25CC30C8D6B4C40E7A90EB9199E4540E25CC30C8D6B4C40E7A90EB9199E4540BE86E0B88C694C40A0A9D72D029B4540BE86E0B88C694C40
16985	4139	43.211004000000003	43.23516	56.840242000000003	56.824607	Садовая	0103000020E61000000100000005000000A0A9D72D029B4540BE86E0B88C694C40A0A9D72D029B4540E25CC30C8D6B4C40E7A90EB9199E4540E25CC30C8D6B4C40E7A90EB9199E4540BE86E0B88C694C40A0A9D72D029B4540BE86E0B88C694C40
19514	50047	43.200135000000003	43.225898000000001	56.627985000000002	56.614643999999998	Чкалова	0103000020E610000001000000050000007AE40F069E994540605793A7AC4E4C407AE40F069E99454075B0FECF61504C40AC1DC539EA9C454075B0FECF61504C40AC1DC539EA9C4540605793A7AC4E4C407AE40F069E994540605793A7AC4E4C40
17207	4243	42.985860000000002	42.997402999999998	56.795786	56.787641999999998	Центральная	0103000020E61000000100000005000000A03715A9307E45405F7AFB73D1644C40A03715A9307E4540AD4ECE50DC654C4055F7C8E6AA7F4540AD4ECE50DC654C4055F7C8E6AA7F45405F7AFB73D1644C40A03715A9307E45405F7AFB73D1644C40
17614	3709	45.636132000000003	45.697181999999998	57.444834999999998	57.42221	Октябрьская	0103000020E6100000010000000500000034F8FBC56CD14640A7052FFA0AB64C4034F8FBC56CD14640DE8E705AF0B84C4010AE80423DD94640DE8E705AF0B84C4010AE80423DD94640A7052FFA0AB64C4034F8FBC56CD14640A7052FFA0AB64C40
17911	3709	45.636132000000003	45.697181999999998	57.444834999999998	57.42221	Коммунистическая	0103000020E6100000010000000500000034F8FBC56CD14640A7052FFA0AB64C4034F8FBC56CD14640DE8E705AF0B84C4010AE80423DD94640DE8E705AF0B84C4010AE80423DD94640A7052FFA0AB64C4034F8FBC56CD14640A7052FFA0AB64C40
17392	1616	45.735754999999997	45.848108000000003	57.484065000000001	57.445155	Центральная	0103000020E610000001000000050000002A6F47382DDE46405053CBD6FAB84C402A6F47382DDE4640B21188D7F5BD4C40EDBC8DCD8EEC4640B21188D7F5BD4C40EDBC8DCD8EEC46405053CBD6FAB84C402A6F47382DDE46405053CBD6FAB84C40
17395	1616	45.735754999999997	45.848108000000003	57.484065000000001	57.445155	Труда	0103000020E610000001000000050000002A6F47382DDE46405053CBD6FAB84C402A6F47382DDE4640B21188D7F5BD4C40EDBC8DCD8EEC4640B21188D7F5BD4C40EDBC8DCD8EEC46405053CBD6FAB84C402A6F47382DDE46405053CBD6FAB84C40
16730	1616	45.735754999999997	45.848108000000003	57.484065000000001	57.445155	Льнозавод	0103000020E610000001000000050000002A6F47382DDE46405053CBD6FAB84C402A6F47382DDE4640B21188D7F5BD4C40EDBC8DCD8EEC4640B21188D7F5BD4C40EDBC8DCD8EEC46405053CBD6FAB84C402A6F47382DDE46405053CBD6FAB84C40
17575	1616	45.735754999999997	45.848108000000003	57.484065000000001	57.445155	Ленина	0103000020E610000001000000050000002A6F47382DDE46405053CBD6FAB84C402A6F47382DDE4640B21188D7F5BD4C40EDBC8DCD8EEC4640B21188D7F5BD4C40EDBC8DCD8EEC46405053CBD6FAB84C402A6F47382DDE46405053CBD6FAB84C40
16792	1616	45.735754999999997	45.848108000000003	57.484065000000001	57.445155	Индустриальная	0103000020E610000001000000050000002A6F47382DDE46405053CBD6FAB84C402A6F47382DDE4640B21188D7F5BD4C40EDBC8DCD8EEC4640B21188D7F5BD4C40EDBC8DCD8EEC46405053CBD6FAB84C402A6F47382DDE46405053CBD6FAB84C40
17872	2992	45.791271000000002	45.811726	57.594149999999999	57.573335	Комсомольская	0103000020E61000000100000005000000F9A23D5E48E546407A53910A63C94C40F9A23D5E48E546408E75711B0DCC4C400DA837A3E6E746408E75711B0DCC4C400DA837A3E6E746407A53910A63C94C40F9A23D5E48E546407A53910A63C94C40
17897	3639	45.867564999999999	45.890355	57.501154	57.482337999999999	Молодежная	0103000020E61000000100000005000000BE13B35E0CEF46401CCF6740BDBD4C40BE13B35E0CEF46403A2174D025C04C40406A1327F7F146403A2174D025C04C40406A1327F7F146401CCF6740BDBD4C40BE13B35E0CEF46401CCF6740BDBD4C40
17231	3451	45.705401000000002	45.727553999999998	57.350461000000003	57.321877999999998	Смирнова	0103000020E6100000010000000500000069C878944ADA4640A4A65D4C33A94C4069C878944ADA464001C3F2E7DBAC4C4078094E7D20DD464001C3F2E7DBAC4C4078094E7D20DD4640A4A65D4C33A94C4069C878944ADA4640A4A65D4C33A94C40
17607	3345	46.188972999999997	46.237769999999998	57.575299999999999	57.560051000000001	Ленина	0103000020E61000000100000005000000DB696B4430184740CA8B4CC0AFC74C40DB696B4430184740C4B12E6EA3C94C4026FC523F6F1E4740C4B12E6EA3C94C4026FC523F6F1E4740CA8B4CC0AFC74C40DB696B4430184740CA8B4CC0AFC74C40
17882	3302	45.526654999999998	45.542617999999997	57.368371000000003	57.357643000000003	Репина	0103000020E610000001000000050000002FA3586E69C346405952EE3EC7AD4C402FA3586E69C34640BDE5EAC726AF4C40471CB28174C54640BDE5EAC726AF4C40471CB28174C546405952EE3EC7AD4C402FA3586E69C346405952EE3EC7AD4C40
17907	3676	45.584910000000001	45.594405000000002	57.466082	57.458544000000003	Комсомольская	0103000020E610000001000000050000003B8DB454DECA464076E3DD91B1BA4C403B8DB454DECA46408CA03193A8BB4C4019CA897615CC46408CA03193A8BB4C4019CA897615CC464076E3DD91B1BA4C403B8DB454DECA464076E3DD91B1BA4C40
17877	3100	45.791352000000003	45.814556000000003	57.686258000000002	57.666699999999999	Махалова	0103000020E61000000100000005000000E6CFB7054BE54640211FF46C56D54C40E6CFB7054BE54640274F594DD7D74C405B61FA5E43E84640274F594DD7D74C405B61FA5E43E84640211FF46C56D54C40E6CFB7054BE54640211FF46C56D54C40
17220	2844	45.711123999999998	45.741612000000003	57.663257999999999	57.650328999999999	Школьная	0103000020E610000001000000050000004AB3791C06DB4640F8510DFB3DD34C404AB3791C06DB4640BA675DA3E5D44C401C295B24EDDE4640BA675DA3E5D44C401C295B24EDDE4640F8510DFB3DD34C404AB3791C06DB4640F8510DFB3DD34C40
16989	2650	45.704017999999998	45.725344	57.466106000000003	57.461967000000001	Мира	0103000020E61000000100000005000000CDE506431DDA4640666A12BC21BB4C40CDE506431DDA4640153C855CA9BB4C40C72C7B12D8DC4640153C855CA9BB4C40C72C7B12D8DC4640666A12BC21BB4C40CDE506431DDA4640666A12BC21BB4C40
17881	3219	45.990184999999997	46.010784000000001	57.655472000000003	57.640922000000003	Советская	0103000020E61000000100000005000000B0FECF61BEFE4640BAA46ABB09D24C40B0FECF61BEFE4640CCB8A981E6D34C40F8A8BF5E61014740CCB8A981E6D34C40F8A8BF5E61014740BAA46ABB09D24C40B0FECF61BEFE4640BAA46ABB09D24C40
16982	2497	46.068230999999997	46.089916000000002	57.491456999999997	57.482236	Центральная	0103000020E6100000010000000500000064C91CCBBB084740187AC4E8B9BD4C4064C91CCBBB084740F4311F10E8BE4C408EB1135E820B4740F4311F10E8BE4C408EB1135E820B4740187AC4E8B9BD4C4064C91CCBBB084740187AC4E8B9BD4C40
17864	2748	45.753003	45.771687999999997	57.514141000000002	57.504626000000002	Молодежная	0103000020E610000001000000050000001B65FD6662E046400C5BB39597C04C401B65FD6662E0464031444E5FCFC14C409A5B21ACC6E2464031444E5FCFC14C409A5B21ACC6E246400C5BB39597C04C401B65FD6662E046400C5BB39597C04C40
17409	2609	45.659478999999997	45.683535999999997	57.498311000000001	57.490958999999997	Школьная	0103000020E610000001000000050000000BB3D0CE69D44640A35698BED7BE4C400BB3D0CE69D44640581EA4A7C8BF4C40BFD18E1B7ED74640581EA4A7C8BF4C40BFD18E1B7ED74640A35698BED7BE4C400BB3D0CE69D44640A35698BED7BE4C40
17421	3523	45.610117000000002	45.627364999999998	57.305813000000001	57.298811999999998	Первомайская	0103000020E61000000100000005000000E8DD585018CE464080D3BB783FA64C40E8DD585018CE464088D860E124A74C40D8D30E7F4DD0464088D860E124A74C40D8D30E7F4DD0464080D3BB783FA64C40E8DD585018CE464080D3BB783FA64C40
16801	3050	46.069237000000001	46.096814999999999	57.410280999999998	57.392004	Школьная	0103000020E610000001000000050000002A560DC2DC0847405AF3E32F2DB24C402A560DC2DC084740C8957A1684B44C409161156F640C4740C8957A1684B44C409161156F640C47405AF3E32F2DB24C402A560DC2DC0847405AF3E32F2DB24C40
17855	2509	46.129773999999998	46.147731999999998	57.523198999999998	57.506675999999999	Центральная	0103000020E6100000010000000500000080EF366F9C10474084D558C2DAC04C4080EF366F9C1047406326512FF8C24C404D49D6E1E81247406326512FF8C24C404D49D6E1E812474084D558C2DAC04C4080EF366F9C10474084D558C2DAC04C40
17406	2423	45.94182	45.969676999999997	57.514826999999997	57.496923000000002	Центральная	0103000020E61000000100000005000000FF5BC98E8DF84640ABD0402C9BBF4C40FF5BC98E8DF84640840CE4D9E5C14C4079573D601EFC4640840CE4D9E5C14C4079573D601EFC4640ABD0402C9BBF4C40FF5BC98E8DF84640ABD0402C9BBF4C40
16736	2166	45.949159000000002	45.991703000000001	57.501154	57.477122000000001	Юбилейная	0103000020E610000001000000050000001FDAC70A7EF94640DF196D5512BD4C401FDAC70A7EF946403A2174D025C04C402C2CB81FF0FE46403A2174D025C04C402C2CB81FF0FE4640DF196D5512BD4C401FDAC70A7EF94640DF196D5512BD4C40
16976	2166	45.949159000000002	45.991703000000001	57.501154	57.477122000000001	Школьная	0103000020E610000001000000050000001FDAC70A7EF94640DF196D5512BD4C401FDAC70A7EF946403A2174D025C04C402C2CB81FF0FE46403A2174D025C04C402C2CB81FF0FE4640DF196D5512BD4C401FDAC70A7EF94640DF196D5512BD4C40
17202	2166	45.949159000000002	45.991703000000001	57.501154	57.477122000000001	Строителей	0103000020E610000001000000050000001FDAC70A7EF94640DF196D5512BD4C401FDAC70A7EF946403A2174D025C04C402C2CB81FF0FE46403A2174D025C04C402C2CB81FF0FE4640DF196D5512BD4C401FDAC70A7EF94640DF196D5512BD4C40
16975	2166	45.949159000000002	45.991703000000001	57.501154	57.477122000000001	Карла Маркса	0103000020E610000001000000050000001FDAC70A7EF94640DF196D5512BD4C401FDAC70A7EF946403A2174D025C04C402C2CB81FF0FE46403A2174D025C04C402C2CB81FF0FE4640DF196D5512BD4C401FDAC70A7EF94640DF196D5512BD4C40
16728	1435	47.438153	47.451529000000001	57.613497000000002	57.604514000000002	Центральная	0103000020E6100000010000000500000078D2C26515B84740B1FCF9B660CD4C4078D2C26515B84740D998D71187CE4C400919C8B3CBB94740D998D71187CE4C400919C8B3CBB94740B1FCF9B660CD4C4078D2C26515B84740B1FCF9B660CD4C40
16949	635	47.048786999999997	47.072960999999999	57.809210999999998	57.797711	Молодежная	0103000020E6100000010000000500000027BC04A73E8647406954E0641BE64C4027BC04A73E8647401F48DE3994E74C4015713AC9568947401F48DE3994E74C4015713AC9568947406954E0641BE64C4027BC04A73E8647406954E0641BE64C40
19433	920	46.845202	46.875402999999999	57.779423000000001	57.759256999999998	Вокзальная	0103000020E61000000100000005000000C44142942F6C4740292158552FE14C40C44142942F6C474007600322C4E34C40FFE89B340D70474007600322C4E34C40FFE89B340D704740292158552FE14C40C44142942F6C4740292158552FE14C40
16723	261	46.989587999999998	47.061579000000002	57.748590999999998	57.723055000000002	Свердлова	0103000020E61000000100000005000000CC41D0D1AA7E4740CA1AF5108DDC4C40CC41D0D1AA7E47403B8A73D4D1DF4C40698F17D2E18747403B8A73D4D1DF4C40698F17D2E1874740CA1AF5108DDC4C40CC41D0D1AA7E4740CA1AF5108DDC4C40
16947	261	46.989587999999998	47.061579000000002	57.748590999999998	57.723055000000002	Заречная	0103000020E61000000100000005000000CC41D0D1AA7E4740CA1AF5108DDC4C40CC41D0D1AA7E47403B8A73D4D1DF4C40698F17D2E18747403B8A73D4D1DF4C40698F17D2E1874740CA1AF5108DDC4C40CC41D0D1AA7E4740CA1AF5108DDC4C40
17558	741	47.073751000000001	47.152776000000003	57.875686999999999	57.845585	Кирова	0103000020E610000001000000050000000E863AAC708947407C7E18213CEC4C400E863AAC708947402444F98216F04C408ECEF9298E9347402444F98216F04C408ECEF9298E9347407C7E18213CEC4C400E863AAC708947407C7E18213CEC4C40
17561	741	47.073751000000001	47.152776000000003	57.875686999999999	57.845585	Калинина	0103000020E610000001000000050000000E863AAC708947407C7E18213CEC4C400E863AAC708947402444F98216F04C408ECEF9298E9347402444F98216F04C408ECEF9298E9347407C7E18213CEC4C400E863AAC708947407C7E18213CEC4C40
17077	1149	47.094242000000001	47.114310000000003	57.591028999999999	57.575009999999999	Центральная	0103000020E610000001000000050000006FF4311F108C4740BD6F7CED99C94C406FF4311F108C474069FE98D6A6CB4C408ACDC7B5A18E474069FE98D6A6CB4C408ACDC7B5A18E4740BD6F7CED99C94C406FF4311F108C4740BD6F7CED99C94C40
16786	1214	47.341467000000002	47.382618999999998	57.960877000000004	57.940378000000003	Октябрская 	0103000020E61000000100000005000000E5D4CE30B5AB47405FF0694E5EF84C40E5D4CE30B5AB4740433D7D04FEFA4C4003EACDA8F9B04740433D7D04FEFA4C4003EACDA8F9B047405FF0694E5EF84C40E5D4CE30B5AB47405FF0694E5EF84C40
17471	1570	47.163663	47.185744	57.716723999999999	57.706651999999998	Центральная	0103000020E610000001000000050000005A48C0E8F294474095D39E9273DA4C405A48C0E8F29447401021AE9CBDDB4C40D0B69A75C69747401021AE9CBDDB4C40D0B69A75C697474095D39E9273DA4C405A48C0E8F294474095D39E9273DA4C40
17815	624	47.132752000000004	47.149515000000001	57.8369	57.829017999999998	Центральная	0103000020E61000000100000005000000433D7D04FE904740CDE506431DEA4C40433D7D04FE904740DE02098A1FEB4C4077A1B94E23934740DE02098A1FEB4C4077A1B94E23934740CDE506431DEA4C40433D7D04FE904740CDE506431DEA4C40
16957	964	46.969411999999998	46.985734000000001	57.697909000000003	57.690784999999998	Центральная	0103000020E61000000100000005000000CB2C42B1157C47409FC893A46BD84C40CB2C42B1157C4740C34A051555D94C4013471E882C7E4740C34A051555D94C4013471E882C7E47409FC893A46BD84C40CB2C42B1157C47409FC893A46BD84C40
16720	50	46.058224000000003	46.082118999999999	57.332121000000001	57.319181	Хутор	0103000020E61000000100000005000000D1EB4FE27307474096404AECDAA84C40D1EB4FE2730747404CA8E0F082AA4C40ABB019E0820A47404CA8E0F082AA4C40ABB019E0820A474096404AECDAA84C40D1EB4FE27307474096404AECDAA84C40
17209	32150	46.419266	46.480198000000001	57.389211000000003	57.355899999999998	Ленина	0103000020E6100000010000000500000091291F82AA354740BD5296218EAD4C4091291F82AA3547402A1F82AAD1B14C4064CDC820773D47402A1F82AAD1B14C4064CDC820773D4740BD5296218EAD4C4091291F82AA354740BD5296218EAD4C40
17441	32150	46.419266	46.480198000000001	57.389211000000003	57.355899999999998	Гагарина	0103000020E6100000010000000500000091291F82AA354740BD5296218EAD4C4091291F82AA3547402A1F82AAD1B14C4064CDC820773D47402A1F82AAD1B14C4064CDC820773D4740BD5296218EAD4C4091291F82AA354740BD5296218EAD4C40
17160	130	45.953910999999998	45.977052	57.274222000000002	57.265720000000002	Центральная	0103000020E61000000100000005000000B72572C119FA464052F2EA1C03A24C40B72572C119FA4640FFEBDCB419A34C40E63E390A10FD4640FFEBDCB419A34C40E63E390A10FD464052F2EA1C03A24C40B72572C119FA464052F2EA1C03A24C40
17368	250	45.951225000000001	45.975757999999999	57.227488000000001	57.215310000000002	Центральная	0103000020E610000001000000050000009D11A5BDC1F946403A4030478F9B4C409D11A5BDC1F94640C11DA8531E9D4C40BA675DA3E5FC4640C11DA8531E9D4C40BA675DA3E5FC46403A4030478F9B4C409D11A5BDC1F946403A4030478F9B4C40
16695	14876	46.179819999999999	46.201981000000004	57.286501999999999	57.27122	Молодежная	0103000020E6100000010000000500000057957D5704174740B4024356B7A24C4057957D57041747408A1EF818ACA44C40EAB46E83DA1947408A1EF818ACA44C40EAB46E83DA194740B4024356B7A24C4057957D5704174740B4024356B7A24C40
17480	14952	46.049878	46.088371000000002	57.276581999999998	57.264541999999999	Центральная	0103000020E610000001000000050000001B65FD66620647408F352383DCA14C401B65FD6662064740C554FA0967A34C401975ADBD4F0B4740C554FA0967A34C401975ADBD4F0B47408F352383DCA14C401B65FD66620647408F352383DCA14C40
17550	32345	46.657876000000002	46.681133000000003	57.384830000000001	57.372520000000002	Центральная	0103000020E610000001000000050000006269E047355447408F8D40BCAEAF4C406269E047355447408542041C42B14C40FA9CBB5D2F5747408542041C42B14C40FA9CBB5D2F5747408F8D40BCAEAF4C406269E047355447408F8D40BCAEAF4C40
17105	32444	46.163460999999998	46.185389000000001	57.332787000000003	57.323588999999998	Специалистов	0103000020E61000000100000005000000F295404AEC144740342C465D6BA94C40F295404AEC14474059C4B0C398AA4C40E204A6D3BA17474059C4B0C398AA4C40E204A6D3BA174740342C465D6BA94C40F295404AEC144740342C465D6BA94C40
16942	32222	46.300113000000003	46.331249	57.394506999999997	57.384587000000003	Молодежная	0103000020E610000001000000050000005F0D501A6A264740BFBB95253AB14C405F0D501A6A264740838593347FB24C4096EA025E662A4740838593347FB24C4096EA025E662A4740BFBB95253AB14C405F0D501A6A264740BFBB95253AB14C40
17598	32250	46.506644999999999	46.543925000000002	57.431708	57.412477000000003	Школьная	0103000020E6100000010000000500000049D74CBED940474015ADDC0BCCB44C4049D74CBED9404740F6B52E3542B74C40083D9B559F454740F6B52E3542B74C40083D9B559F45474015ADDC0BCCB44C4049D74CBED940474015ADDC0BCCB44C40
18536	32043	45.739798	45.764015999999998	55.866312999999998	55.848866999999998	Рабочая	0103000020E61000000100000005000000B7D26BB3B1DE4640AAD381ACA7EC4B40B7D26BB3B1DE4640C18C2958E3EE4B4074CFBA46CBE14640C18C2958E3EE4B4074CFBA46CBE14640AAD381ACA7EC4B40B7D26BB3B1DE4640AAD381ACA7EC4B40
16747	10350	45.61795	45.635818	55.747936000000003	55.731419000000002	Полевая	0103000020E61000000100000005000000174850FC18CF4640265646239FDD4B40174850FC18CF464023C0E95DBCDF4B40A41AF67B62D1464023C0E95DBCDF4B40A41AF67B62D14640265646239FDD4B40174850FC18CF4640265646239FDD4B40
17466	31961	45.545492000000003	45.600369999999998	55.818361000000003	55.796819999999997	Энгельса	0103000020E61000000100000005000000651D8EAED2C546403C66A032FEE54B40651D8EAED2C5464033A9A10DC0E84B40F0BF95ECD8CC464033A9A10DC0E84B40F0BF95ECD8CC46403C66A032FEE54B40651D8EAED2C546403C66A032FEE54B40
17148	31961	45.545492000000003	45.600369999999998	55.818361000000003	55.796819999999997	Советская	0103000020E61000000100000005000000651D8EAED2C546403C66A032FEE54B40651D8EAED2C5464033A9A10DC0E84B40F0BF95ECD8CC464033A9A10DC0E84B40F0BF95ECD8CC46403C66A032FEE54B40651D8EAED2C546403C66A032FEE54B40
17763	21589	45.671697000000002	45.707529999999998	55.869444999999999	55.847174000000003	площадь Революции	0103000020E6100000010000000500000021E9D32AFAD54640C102983270EC4B4021E9D32AFAD54640DA5548F949EF4B402D78D15790DA4640DA5548F949EF4B402D78D15790DA4640C102983270EC4B4021E9D32AFAD54640C102983270EC4B40
18258	21589	45.671697000000002	45.707529999999998	55.869444999999999	55.847174000000003	Центральная 	0103000020E6100000010000000500000021E9D32AFAD54640C102983270EC4B4021E9D32AFAD54640DA5548F949EF4B402D78D15790DA4640DA5548F949EF4B402D78D15790DA4640C102983270EC4B4021E9D32AFAD54640C102983270EC4B40
17633	21589	45.671697000000002	45.707529999999998	55.869444999999999	55.847174000000003	Октябрьская	0103000020E6100000010000000500000021E9D32AFAD54640C102983270EC4B4021E9D32AFAD54640DA5548F949EF4B402D78D15790DA4640DA5548F949EF4B402D78D15790DA4640C102983270EC4B4021E9D32AFAD54640C102983270EC4B40
17025	31643	45.487110999999999	45.517716	55.791263000000001	55.776532000000003	Советская	0103000020E61000000100000005000000CC423BA759BE464014268C6665E34B40CC423BA759BE464076C4211B48E54B40D74E948444C2464076C4211B48E54B40D74E948444C2464014268C6665E34B40CC423BA759BE464014268C6665E34B40
16770	31549	45.659947000000003	45.692627000000002	55.949939000000001	55.937220000000003	Молодежная	0103000020E61000000100000005000000F20BAF2479D446401D9430D3F6F74B40F20BAF2479D44640F418E59997F94B40CEA96400A8D84640F418E59997F94B40CEA96400A8D846401D9430D3F6F74B40F20BAF2479D446401D9430D3F6F74B40
16923	31749	45.713341999999997	45.741441999999999	55.825361000000001	55.815337	Торговая	0103000020E610000001000000050000007E6E68CA4EDB4640001C7BF65CE84B407E6E68CA4EDB46406A32E36DA5E94B40BFF04A92E7DE46406A32E36DA5E94B40BFF04A92E7DE4640001C7BF65CE84B407E6E68CA4EDB4640001C7BF65CE84B40
17426	31395	45.729728000000001	45.760055000000001	55.943038000000001	55.919840999999998	Советская	0103000020E61000000100000005000000DD7C23BA67DD46408D429259BDF54B40DD7C23BA67DD464050711C78B5F84B40A514747B49E1464050711C78B5F84B40A514747B49E146408D429259BDF54B40DD7C23BA67DD46408D429259BDF54B40
17272	31118	45.697101000000004	45.726125000000003	55.775646000000002	55.761290000000002	Мира	0103000020E610000001000000050000002481069B3AD94640CC6262F371E14B402481069B3AD94640F9A23D5E48E34B406DE7FBA9F1DC4640F9A23D5E48E34B406DE7FBA9F1DC4640CC6262F371E14B402481069B3AD94640CC6262F371E14B40
18453	31587	45.634830000000001	45.656891999999999	55.983035999999998	55.972256999999999	Почтовая	0103000020E610000001000000050000008542041C42D146404E27D9EA72FC4B408542041C42D146403465A71FD4FD4B4084807C0915D446403465A71FD4FD4B4084807C0915D446404E27D9EA72FC4B408542041C42D146404E27D9EA72FC4B40
17357	31905	45.623753000000001	45.650550000000003	55.849589999999999	55.831271000000001	Свободы	0103000020E6100000010000000500000015E46723D7CF46407E8E8F1667EA4B4015E46723D7CF46401B81785DBFEC4B40D734EF3845D346401B81785DBFEC4B40D734EF3845D346407E8E8F1667EA4B4015E46723D7CF46407E8E8F1667EA4B40
17646	31178	45.456190999999997	45.488098999999998	55.911763999999998	55.901172000000003	Центральная	0103000020E6100000010000000500000061DD787764BA46401409A69A59F34B4061DD787764BA4640C7D5C8AEB4F44B40EB1A2D077ABE4640C7D5C8AEB4F44B40EB1A2D077ABE46401409A69A59F34B4061DD787764BA46401409A69A59F34B40
17661	31141	45.447217000000002	45.481056000000002	55.864156000000001	55.844757999999999	Центральная	0103000020E610000001000000050000008D9B1A683EB946406684B70721EC4B408D9B1A683EB946403352EFA99CEE4B40B5C5353E93BD46403352EFA99CEE4B40B5C5353E93BD46406684B70721EC4B408D9B1A683EB946406684B70721EC4B40
17069	31068	45.668965999999998	45.691971000000002	55.764014000000003	55.746617999999998	Молодежная	0103000020E6100000010000000500000066118AADA0D546406E4DBA2D91DF4B4066118AADA0D54640D4D7F335CBE14B40E563778192D84640D4D7F335CBE14B40E563778192D846406E4DBA2D91DF4B4066118AADA0D546406E4DBA2D91DF4B40
17538	32100	45.801170999999997	45.830230999999998	55.878191999999999	55.865595999999996	Молодежная	0103000020E6100000010000000500000076C075C58CE6464032C687D9CBEE4B4076C075C58CE64640EECD6F9868F04B400C90680245EA4640EECD6F9868F04B400C90680245EA464032C687D9CBEE4B4076C075C58CE6464032C687D9CBEE4B40
17068	30970	43.375073	43.394863000000001	55.878934999999998	55.866883999999999	Восточная	0103000020E610000001000000050000006A4E5E6402B045407CB60E0EF6EE4B406A4E5E6402B04540A6272CF180F04B4042B3EBDE8AB24540A6272CF180F04B4042B3EBDE8AB245407CB60E0EF6EE4B406A4E5E6402B045407CB60E0EF6EE4B40
16700	49625	43.233677999999998	43.250908000000003	55.814027000000003	55.805771	Фрунзе	0103000020E61000000100000005000000B8E52329E99D454059880E8123E74B40B8E52329E99D4540CF87670932E84B400327DBC01DA04540CF87670932E84B400327DBC01DA0454059880E8123E74B40B8E52329E99D454059880E8123E74B40
17526	9266	43.137189999999997	43.195400999999997	55.816374000000003	55.785260000000001	Совхозная	0103000020E610000001000000050000004BAB21718F914540B16D516683E44B404BAB21718F91454001A777F17EE84B40874D64E60299454001A777F17EE84B40874D64E602994540B16D516683E44B404BAB21718F914540B16D516683E44B40
17313	9266	43.137189999999997	43.195400999999997	55.816374000000003	55.785260000000001	Профсоюзная	0103000020E610000001000000050000004BAB21718F914540B16D516683E44B404BAB21718F91454001A777F17EE84B40874D64E60299454001A777F17EE84B40874D64E602994540B16D516683E44B404BAB21718F914540B16D516683E44B40
16833	9266	43.137189999999997	43.195400999999997	55.816374000000003	55.785260000000001	Октябрьская	0103000020E610000001000000050000004BAB21718F914540B16D516683E44B404BAB21718F91454001A777F17EE84B40874D64E60299454001A777F17EE84B40874D64E602994540B16D516683E44B404BAB21718F914540B16D516683E44B40
17502	9266	43.137189999999997	43.195400999999997	55.816374000000003	55.785260000000001	Нижегородская	0103000020E610000001000000050000004BAB21718F914540B16D516683E44B404BAB21718F91454001A777F17EE84B40874D64E60299454001A777F17EE84B40874D64E602994540B16D516683E44B404BAB21718F914540B16D516683E44B40
17331	9266	43.137189999999997	43.195400999999997	55.816374000000003	55.785260000000001	Ленина	0103000020E610000001000000050000004BAB21718F914540B16D516683E44B404BAB21718F91454001A777F17EE84B40874D64E60299454001A777F17EE84B40874D64E602994540B16D516683E44B404BAB21718F914540B16D516683E44B40
16991	9266	43.137189999999997	43.195400999999997	55.816374000000003	55.785260000000001	Комсомольская	0103000020E610000001000000050000004BAB21718F914540B16D516683E44B404BAB21718F91454001A777F17EE84B40874D64E60299454001A777F17EE84B40874D64E602994540B16D516683E44B404BAB21718F914540B16D516683E44B40
17462	14359	43.463638000000003	43.503145000000004	55.793211999999997	55.774340000000002	пер. Северный	0103000020E6100000010000000500000068976F7D58BB454009FEB7921DE34B4068976F7D58BB4540BA6587F887E54B40AE122C0E67C04540BA6587F887E54B40AE122C0E67C0454009FEB7921DE34B4068976F7D58BB454009FEB7921DE34B40
17124	30259	43.098579999999998	43.116411999999997	55.739721000000003	55.729852999999999	Фабричная	0103000020E610000001000000050000001405FA449E8C454099F1B6D26BDD4B401405FA449E8C45400C957F2DAFDE4B40546EA296E68E45400C957F2DAFDE4B40546EA296E68E454099F1B6D26BDD4B401405FA449E8C454099F1B6D26BDD4B40
17270	30756	43.187136000000002	43.215989999999998	55.664501999999999	55.646914000000002	Микрорайон	0103000020E61000000100000005000000BFF38B12F49745408BA9F413CED24B40BFF38B12F49745403410CB660ED54B40AB21718FA59B45403410CB660ED54B40AB21718FA59B45408BA9F413CED24B40BFF38B12F49745408BA9F413CED24B40
17518	30563	42.937072000000001	42.949559000000001	55.739874	55.730553	Шуваловой	0103000020E61000000100000005000000A8FFACF9F1774540527FBDC282DD4B40A8FFACF9F17745409294F430B4DE4B40AD4F39268B7945409294F430B4DE4B40AD4F39268B794540527FBDC282DD4B40A8FFACF9F1774540527FBDC282DD4B40
17064	30478	42.915368999999998	42.941113999999999	55.763199	55.742271000000002	Советская	0103000020E61000000100000005000000D862B7CF2A75454076E272BC02DF4B40D862B7CF2A75454082AB3C81B0E14B4064E76D6C7678454082AB3C81B0E14B4064E76D6C7678454076E272BC02DF4B40D862B7CF2A75454076E272BC02DF4B40
17125	30354	43.076912999999998	43.091222999999999	55.829861000000001	55.819569999999999	Младенцева	0103000020E6100000010000000500000091D10149D8894540306475ABE7E84B4091D10149D8894540E99C9FE238EA4B404ED2FC31AD8B4540E99C9FE238EA4B404ED2FC31AD8B4540306475ABE7E84B4091D10149D8894540306475ABE7E84B40
17321	30177	42.998364000000002	43.026868	55.767068000000002	55.759450999999999	Совхозная	0103000020E610000001000000050000007BC03C64CA7F45400EF5BBB035E14B407BC03C64CA7F454071E7C2482FE24B408BA71E697083454071E7C2482FE24B408BA71E69708345400EF5BBB035E14B407BC03C64CA7F45400EF5BBB035E14B40
18216	30249	43.114417000000003	43.133569999999999	55.779260999999998	55.766404999999999	Советская	0103000020E61000000100000005000000A08D5C37A58E4540D53E1D8F19E24B40A08D5C37A58E45402D060FD3BEE34B4005DD5ED2189145402D060FD3BEE34B4005DD5ED218914540D53E1D8F19E24B40A08D5C37A58E4540D53E1D8F19E24B40
17703	30159	43.049011	43.065289	55.758584999999997	55.747647000000001	Овражная	0103000020E61000000100000005000000771211FE45864540ECF99AE5B2DF4B40771211FE458645403A1E335019E14B40EFE4D3635B8845403A1E335019E14B40EFE4D3635B884540ECF99AE5B2DF4B40771211FE45864540ECF99AE5B2DF4B40
18187	30070	43.024182000000003	43.049720999999998	55.820095999999999	55.798211999999999	Парковая	0103000020E6100000010000000500000071935165188345402BA391CF2BE64B4071935165188345404BCADDE7F8E84B405376FA415D8645404BCADDE7F8E84B405376FA415D8645402BA391CF2BE64B4071935165188345402BA391CF2BE64B40
17317	29885	43.204393000000003	43.224758000000001	55.768897000000003	55.755611000000002	Ленина	0103000020E610000001000000050000000344C18C299A4540BABF7ADCB7E04B400344C18C299A45400B7F86376BE24B40D7C1C1DEC49C45400B7F86376BE24B40D7C1C1DEC49C4540BABF7ADCB7E04B400344C18C299A4540BABF7ADCB7E04B40
17111	29798	43.196064999999997	43.215909000000003	55.810718999999999	55.796365000000002	Белова	0103000020E61000000100000005000000F3716DA818994540EB56CF49EFE54B40F3716DA818994540779FE3A3C5E74B40BFF4F6E7A29B4540779FE3A3C5E74B40BFF4F6E7A29B4540EB56CF49EFE54B40F3716DA818994540EB56CF49EFE54B40
17112	29692	43.034880999999999	43.060923000000003	55.611103999999997	55.593522	Советская	0103000020E610000001000000050000003A2009FB768445406FBA6587F8CB4B403A2009FB76844540363AE7A738CE4B4080492A53CC874540363AE7A738CE4B4080492A53CC8745406FBA6587F8CB4B403A2009FB768445406FBA6587F8CB4B40
18200	30080	42.966096999999998	42.979194	55.824010000000001	55.813606999999998	Молодежная	0103000020E61000000100000005000000C1E10511A97B4540F965304624E84B40C1E10511A97B4540DAC9E02879E94B403F389F3A567D4540DAC9E02879E94B403F389F3A567D4540F965304624E84B40C1E10511A97B4540F965304624E84B40
17143	9199	43.309460000000001	43.334038	55.835194999999999	55.825133000000001	Молодежная	0103000020E61000000100000005000000C8B5A1629CA74540D9EC48F59DE94B40C8B5A1629CA74540306475ABE7EA4B4085CFD6C1C1AA4540306475ABE7EA4B4085CFD6C1C1AA4540D9EC48F59DE94B40C8B5A1629CA74540D9EC48F59DE94B40
17102	28718	43.613377999999997	43.6267	57.044021000000001	57.036965000000002	Восточная	0103000020E61000000100000005000000FE0A992B83CE45405F0CE544BB844C40FE0A992B83CE45402AABE97AA2854C409C33A2B437D045402AABE97AA2854C409C33A2B437D045405F0CE544BB844C40FE0A992B83CE45405F0CE544BB844C40
18245	21394	43.146577000000001	43.181736999999998	57.165123999999999	57.120894999999997	Садовая	0103000020E6100000010000000500000043ACFE08C3924540FD9FC37C798F4C4043ACFE08C392454071E481C822954C4090BC73284397454071E481C822954C4090BC732843974540FD9FC37C798F4C4043ACFE08C3924540FD9FC37C798F4C40
17261	21394	43.146577000000001	43.181736999999998	57.165123999999999	57.120894999999997	Калинина	0103000020E6100000010000000500000043ACFE08C3924540FD9FC37C798F4C4043ACFE08C392454071E481C822954C4090BC73284397454071E481C822954C4090BC732843974540FD9FC37C798F4C4043ACFE08C3924540FD9FC37C798F4C40
17374	21394	43.146577000000001	43.181736999999998	57.165123999999999	57.120894999999997	Докучаева	0103000020E6100000010000000500000043ACFE08C3924540FD9FC37C798F4C4043ACFE08C392454071E481C822954C4090BC73284397454071E481C822954C4090BC732843974540FD9FC37C798F4C4043ACFE08C3924540FD9FC37C798F4C40
16995	15740	43.258408000000003	43.270454999999998	57.318131000000001	57.313650000000003	Большое Бухарино	0103000020E610000001000000050000002C836A8313A14540F931E6AE25A84C402C836A8313A14540016C4084B8A84C401405FA449EA24540016C4084B8A84C401405FA449EA24540F931E6AE25A84C402C836A8313A14540F931E6AE25A84C40
17067	15717	43.249918999999998	43.260879000000003	57.272840000000002	57.265521	Школьная	0103000020E6100000010000000500000013D38558FD9F45405BB39597FCA14C4013D38558FD9F45403485CE6BECA24C404A9BAA7B64A145403485CE6BECA24C404A9BAA7B64A145405BB39597FCA14C4013D38558FD9F45405BB39597FCA14C40
17289	28190	43.174596000000001	43.188124000000002	57.130817999999998	57.122419999999998	Зеленая	0103000020E6100000010000000500000097016729599645402B306475AB8F4C40970167295996454033DDEBA4BE904C40DECB7D721498454033DDEBA4BE904C40DECB7D72149845402B306475AB8F4C4097016729599645402B306475AB8F4C40
17689	10240	43.392850000000003	43.410798999999997	57.399590000000003	57.390428	Школьная	0103000020E61000000100000005000000E71DA7E848B24540AAB8718BF9B14C40E71DA7E848B2454082E7DEC325B34C40601DC70F95B4454082E7DEC325B34C40601DC70F95B44540AAB8718BF9B14C40E71DA7E848B24540AAB8718BF9B14C40
17762	28643	43.408580000000001	43.432555999999998	56.933062	56.926893	Школьная	0103000020E610000001000000050000005CE674594CB4454017F2086EA4764C405CE674594CB44540F7915B936E774C4023D8B8FE5DB74540F7915B936E774C4023D8B8FE5DB7454017F2086EA4764C405CE674594CB4454017F2086EA4764C40
17305	23156	43.269260000000003	43.283211000000001	57.035181999999999	57.027712000000001	Центральная	0103000020E610000001000000050000007C0F971C77A2454077DA1A118C834C407C0F971C77A2454035B401D880844C40096F0F4240A4454035B401D880844C40096F0F4240A4454077DA1A118C834C407C0F971C77A2454077DA1A118C834C40
16835	10252	43.463278000000003	43.487927999999997	57.457082	57.445053000000001	Шелехонская	0103000020E61000000100000005000000687A89B14CBB45404CFE277FF7B84C40687A89B14CBB45408ECBB8A981BA4C40BE66B96C74BE45408ECBB8A981BA4C40BE66B96C74BE45404CFE277FF7B84C40687A89B14CBB45404CFE277FF7B84C40
16817	10120	43.315928	43.325566000000002	57.352268000000002	57.345275000000001	Придорожная	0103000020E6100000010000000500000002F2255470A845402E90A0F831AC4C4002F2255470A84540B3B6291E17AD4C4043588D25ACA94540B3B6291E17AD4C4043588D25ACA945402E90A0F831AC4C4002F2255470A845402E90A0F831AC4C40
17671	28412	43.521695999999999	43.539285	57.295237	57.278177999999997	Центральная	0103000020E610000001000000050000001D3A3DEFC6C24540BC3B32569BA34C401D3A3DEFC6C24540DAC87553CAA54C40971C774A07C54540DAC87553CAA54C40971C774A07C54540BC3B32569BA34C401D3A3DEFC6C24540BC3B32569BA34C40
17693	28972	43.206117999999996	43.225602000000002	57.200096000000002	57.190353000000002	Поселковая	0103000020E61000000100000005000000F78E1A13629A454006D9B27C5D984C40F78E1A13629A4540BC07E8BE9C994C40C3F4BD86E09C4540BC07E8BE9C994C40C3F4BD86E09C454006D9B27C5D984C40F78E1A13629A454006D9B27C5D984C40
17215	28209	43.315595000000002	43.337155000000003	57.182744	57.176416000000003	Соколова	0103000020E61000000100000005000000FCE3BD6A65A84540DE3EABCC94964C40FCE3BD6A65A8454026C5C72764974C40695721E527AB454026C5C72764974C40695721E527AB4540DE3EABCC94964C40FCE3BD6A65A84540DE3EABCC94964C40
17170	29180	43.349784999999997	43.365271999999997	57.262663000000003	57.255079000000002	Молодежная	0103000020E61000000100000005000000D0D03FC1C5AC4540BD72BD6DA6A04C40D0D03FC1C5AC4540446FF1F09EA14C407F129F3BC1AE4540446FF1F09EA14C407F129F3BC1AE4540BD72BD6DA6A04C40D0D03FC1C5AC4540BD72BD6DA6A04C40
17092	15228	43.487560000000002	43.509101000000001	57.271223999999997	57.262059999999998	Молодежная	0103000020E610000001000000050000003C6BB75D68BE45407DCB9C2E8BA14C403C6BB75D68BE4540F5F1D077B7A24C4032AEB8382AC14540F5F1D077B7A24C4032AEB8382AC145407DCB9C2E8BA14C403C6BB75D68BE45407DCB9C2E8BA14C40
16755	28792	43.240855000000003	43.261462999999999	57.008023999999999	56.991022999999998	Молодежная	0103000020E61000000100000005000000FF092E56D49E4540BA4A77D7D97E4C40FF092E56D49E4540A3CA30EE06814C40990E9D9E77A14540A3CA30EE06814C40990E9D9E77A14540BA4A77D7D97E4C40FF092E56D49E4540BA4A77D7D97E4C40
17298	28603	43.327049000000002	43.346443000000001	56.950890000000001	56.942081999999999	Школьная	0103000020E610000001000000050000004298DBBDDCA945403C139A2496784C404298DBBDDCA94540F60B76C3B6794C40CD76853E58AC4540F60B76C3B6794C40CD76853E58AC45403C139A2496784C404298DBBDDCA945403C139A2496784C40
17513	28879	43.312280000000001	43.332070000000002	57.072777000000002	57.064526999999998	Центральная	0103000020E61000000100000005000000F29881CAF8A74540C05AB56B42884C40F29881CAF8A745405473B9C150894C40CAFD0E4581AA45405473B9C150894C40CAFD0E4581AA4540C05AB56B42884C40F29881CAF8A74540C05AB56B42884C40
17408	15467	43.520591000000003	43.553567999999999	57.049039999999998	57.038214000000004	Молодежная	0103000020E61000000100000005000000C5CBD3B9A2C24540EB1F4432E4844C40C5CBD3B9A2C24540111956F146864C405A0EF450DBC64540111956F146864C405A0EF450DBC64540EB1F4432E4844C40C5CBD3B9A2C24540EB1F4432E4844C40
17161	10154	43.495275999999997	43.512551000000002	57.362284000000002	57.350971000000001	Школьная	0103000020E61000000100000005000000313F373465BF4540166C239EECAC4C40313F373465BF45409AEE75525FAE4C401C446B459BC145409AEE75525FAE4C401C446B459BC14540166C239EECAC4C40313F373465BF4540166C239EECAC4C40
17787	28900	43.264597999999999	43.290441999999999	57.103594000000001	57.094327999999997	Центральная	0103000020E61000000100000005000000234BE658DEA145406D8C9DF0128C4C40234BE658DEA14540EA077591428D4C4042B115342DA54540EA077591428D4C4042B115342DA545406D8C9DF0128C4C40234BE658DEA145406D8C9DF0128C4C40
18073	28535	43.475225999999999	43.495429000000001	56.968229000000001	56.957633999999999	Школьная	0103000020E61000000100000005000000BD1AA034D4BC4540D2C43BC0937A4C40BD1AA034D4BC4540F70489EDEE7B4C40B83EAC376ABF4540F70489EDEE7B4C40B83EAC376ABF4540D2C43BC0937A4C40BD1AA034D4BC4540D2C43BC0937A4C40
19526	50050	45.961815999999999	45.978399000000003	55.221507000000003	55.212159	Школьная	0103000020E61000000100000005000000806264C91CFB4640AA46AF06289B4B40806264C91CFB4640E46A64575A9C4B4035B8AD2D3CFD4640E46A64575A9C4B4035B8AD2D3CFD4640AA46AF06289B4B40806264C91CFB4640AA46AF06289B4B40
19621	50070	45.867403000000003	45.881480000000003	55.132205999999996	55.124186999999999	Молодежная	0103000020E61000000100000005000000E5B9BE0F07EF46404FCB0F5CE58F4B40E5B9BE0F07EF4640E02A4F20EC904B40FF092E56D4F04640E02A4F20EC904B40FF092E56D4F046404FCB0F5CE58F4B40E5B9BE0F07EF46404FCB0F5CE58F4B40
17453	27707	45.906982999999997	45.940499000000003	55.263669999999998	55.245517	Центральная	0103000020E610000001000000050000009483D90418F4464057CEDE196D9F4B409483D90418F44640D97745F0BFA14B40DA756F4562F84640D97745F0BFA14B40DA756F4562F8464057CEDE196D9F4B409483D90418F4464057CEDE196D9F4B40
17056	27795	45.800156000000001	45.808878	55.064070999999998	55.053856000000003	Центральная	0103000020E610000001000000050000005ED905836BE64640C158DFC0E4864B405ED905836BE646409ECF807A33884B40193A765089E746409ECF807A33884B40193A765089E74640C158DFC0E4864B405ED905836BE64640C158DFC0E4864B40
17451	27546	45.870457999999999	45.911735	55.240938999999997	55.213900000000002	площадь Советская	0103000020E610000001000000050000005245F12A6BEF4640A54E4013619B4B405245F12A6BEF46405CAAD216D79E4B402DCF83BBB3F446405CAAD216D79E4B402DCF83BBB3F44640A54E4013619B4B405245F12A6BEF4640A54E4013619B4B40
17932	27073	46.023944	46.054783	55.227268000000002	55.214368	Школьная	0103000020E61000000100000005000000BC77D498100347408BA71E69709B4B40BC77D49810034740B3B6291E179D4B403AB01C2103074740B3B6291E179D4B403AB01C21030747408BA71E69709B4B40BC77D498100347408BA71E69709B4B40
17043	27452	46.144390000000001	46.197803999999998	55.344417999999997	55.318787999999998	Большая линия	0103000020E610000001000000050000004AEF1B5F7B124740BA2D910BCEA84B404AEF1B5F7B124740AD1397E315AC4B404D8237A451194740AD1397E315AC4B404D8237A451194740BA2D910BCEA84B404AEF1B5F7B124740BA2D910BCEA84B40
17935	27140	45.982433	46.007486999999998	55.184392000000003	55.175961000000001	Школьная	0103000020E610000001000000050000006EC1525DC0FD46408C2FDAE385964B406EC1525DC0FD464070D234289A974B4094128255F500474070D234289A974B4094128255F50047408C2FDAE385964B406EC1525DC0FD46408C2FDAE385964B40
17042	27396	46.194794000000002	46.222903000000002	55.303750000000001	55.284675999999997	Кооперативная	0103000020E6100000010000000500000080BA8102EF18474061FA5E4370A44B4080BA8102EF1847407B14AE47E1A64B401497E315881C47407B14AE47E1A64B401497E315881C474061FA5E4370A44B4080BA8102EF18474061FA5E4370A44B40
17260	27495	45.910981	45.938845999999998	55.199547000000003	55.182684999999999	Центральная	0103000020E61000000100000005000000812381069BF44640213CDA3862974B40812381069BF44640E9818FC18A994B407EFD101B2CF84640E9818FC18A994B407EFD101B2CF84640213CDA3862974B40812381069BF44640213CDA3862974B40
17625	27303	46.000757999999998	46.032252999999997	55.052349999999997	55.034022999999998	Школьная	0103000020E61000000100000005000000ED9A90D618004740E9279CDD5A844B40ED9A90D61800474009F9A067B3864B405419C6DD2004474009F9A067B3864B405419C6DD20044740E9279CDD5A844B40ED9A90D618004740E9279CDD5A844B40
17627	27275	45.627516999999997	45.956471000000001	55.372824999999999	55.224961999999998	Почтовая	0103000020E610000001000000050000008E57207A52D04640DF6B088ECB9C4B408E57207A52D04640CB10C7BAB8AF4B40454948A46DFA4640CB10C7BAB8AF4B40454948A46DFA4640DF6B088ECB9C4B408E57207A52D04640DF6B088ECB9C4B40
19719	50073	46.009185000000002	46.059525999999998	55.337080999999998	55.313045000000002	Советская	0103000020E61000000100000005000000904E5DF92C0147409296CADB11A84B40904E5DF92C0147402E8D5F7825AB4B407FA1478C9E0747402E8D5F7825AB4B407FA1478C9E0747409296CADB11A84B40904E5DF92C0147409296CADB11A84B40
17248	27048	46.088425000000001	46.147741000000003	55.253203999999997	55.234112000000003	Колхозная	0103000020E610000001000000050000000C93A982510B4740F3CCCB61F79D4B400C93A982510B4740B29B19FD68A04B40A1A3552DE9124740B29B19FD68A04B40A1A3552DE9124740F3CCCB61F79D4B400C93A982510B4740F3CCCB61F79D4B40
17565	26766	45.793166999999997	45.815219999999997	55.262931999999999	55.246943999999999	Школьная	0103000020E610000001000000050000001AA20A7F86E54640C2F869DC9B9F4B401AA20A7F86E5464033897AC1A7A14B40C685032159E8464033897AC1A7A14B40C685032159E84640C2F869DC9B9F4B401AA20A7F86E54640C2F869DC9B9F4B40
17963	27741	45.741019999999999	45.762380999999998	55.035054000000002	55.016022	Запрудная	0103000020E6100000010000000500000049D74CBED9DE46401D0247020D824B4049D74CBED9DE464008CC43A67C844B40BF0B5BB395E1464008CC43A67C844B40BF0B5BB395E146401D0247020D824B4049D74CBED9DE46401D0247020D824B40
17016	26817	45.645420999999999	45.661797	55.208773999999998	55.191346000000003	Малые Выселки	0103000020E610000001000000050000006893C3279DD24640371C96067E984B406893C3279DD24640A7203F1BB99A4B40A3CB9BC3B5D44640A7203F1BB99A4B40A3CB9BC3B5D44640371C96067E984B406893C3279DD24640371C96067E984B40
16737	26748	45.817780999999997	45.842547000000003	55.336134000000001	55.318542000000001	Школьная	0103000020E6100000010000000500000024253D0CADE846408333F8FBC5A84B4024253D0CADE846406E895C7006AB4B40E52B8194D8EB46406E895C7006AB4B40E52B8194D8EB46408333F8FBC5A84B4024253D0CADE846408333F8FBC5A84B40
17431	26905	45.912903	45.945304999999998	55.152448999999997	55.131666000000003	Краснопартизанская	0103000020E61000000100000005000000CCB56801DAF4464061FF756EDA904B40CCB56801DAF4464069A7E67283934B4065DF15C1FFF8464069A7E67283934B4065DF15C1FFF8464061FF756EDA904B40CCB56801DAF4464061FF756EDA904B40
17428	26707	45.818795999999999	45.837355000000002	55.276344000000002	55.263782999999997	Молодежная	0103000020E610000001000000050000003D0CAD4ECEE84640D11E2FA4C3A14B403D0CAD4ECEE8464011397D3D5FA34B403012DA722EEB464011397D3D5FA34B403012DA722EEB4640D11E2FA4C3A14B403D0CAD4ECEE84640D11E2FA4C3A14B40
17424	26602	45.791001999999999	45.839035000000003	55.188004999999997	55.16901	Первомайская	0103000020E610000001000000050000000989B48D3FE546403659A31EA2954B400989B48D3FE54640033E3F8C10984B408599B67F65EB4640033E3F8C10984B408599B67F65EB46403659A31EA2954B400989B48D3FE546403659A31EA2954B40
17425	26613	45.809883999999997	45.831004	55.352521000000003	55.334941000000001	Андреева	0103000020E61000000100000005000000DEC66647AAE74640768BC058DFAA4B40DEC66647AAE746409D137B681FAD4B402F6CCD565EEA46409D137B681FAD4B402F6CCD565EEA4640768BC058DFAA4B40DEC66647AAE74640768BC058DFAA4B40
17227	26307	45.292859	45.324649999999998	55.481760000000001	55.463180999999999	Школьная	0103000020E610000001000000050000006DAB59677CA546407590D78349BB4B406DAB59677CA54640AF42CA4FAABD4B40BD5296218EA94640AF42CA4FAABD4B40BD5296218EA946407590D78349BB4B406DAB59677CA546407590D78349BB4B40
17592	26236	45.378010000000003	45.410466	55.481143000000003	55.473739999999999	Советская	0103000020E61000000100000005000000CEC7B5A162B046404D672783A3BC4B40CEC7B5A162B0464084D9041896BD4B405A0F5F268AB4464084D9041896BD4B405A0F5F268AB446404D672783A3BC4B40CEC7B5A162B046404D672783A3BC4B40
17844	25375	45.272216	45.308363999999997	55.635330000000003	55.609807000000004	Южная	0103000020E6100000010000000500000056B950F9D7A246409AEFE0270ECE4B4056B950F9D7A246407715527E52D14B40C2A1B77878A746407715527E52D14B40C2A1B77878A746409AEFE0270ECE4B4056B950F9D7A246409AEFE0270ECE4B40
17414	26037	45.714295	45.743471999999997	55.499310999999999	55.484040999999998	Садовая	0103000020E610000001000000050000002159C0046EDB46402976340EF5BD4B402159C0046EDB46403BC43F6CE9BF4B40F0BE2A172ADF46403BC43F6CE9BF4B40F0BE2A172ADF46402976340EF5BD4B402159C0046EDB46402976340EF5BD4B40
17405	25690	45.539589999999997	45.566324000000002	55.716538999999997	55.698041000000003	Молодежная	0103000020E61000000100000005000000D39FFD4811C546403222516859D94B40D39FFD4811C546407EA7C98CB7DB4B404F78094E7DC846407EA7C98CB7DB4B404F78094E7DC846403222516859D94B40D39FFD4811C546403222516859D94B40
17218	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	пос. Молодежный	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
17394	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	микрорайон  Юбилейный	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
16969	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	Ульянова	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
17572	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	Советская	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
16966	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	Свердлова	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
16965	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	М. Горького	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
17571	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	Лесная	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
16790	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	Краснодонцев	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
16974	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	Гусева	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
17576	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	Вокзальная	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
17552	11618	45.430382000000002	45.512093	55.545715999999999	55.507615999999999	60 лет Октября	0103000020E61000000100000005000000BF64E3C116B746409276A38FF9C04B40BF64E3C116B74640B4739A05DAC54B4059C16F438CC14640B4739A05DAC54B4059C16F438CC146409276A38FF9C04B40BF64E3C116B746409276A38FF9C04B40
18100	15135	45.273643999999997	45.319412999999997	55.385269999999998	55.373387999999998	Центральная	0103000020E61000000100000005000000915F3FC406A34640035C902DCBAF4B40915F3FC406A34640A110018750B14B4068757286E2A84640A110018750B14B4068757286E2A84640035C902DCBAF4B40915F3FC406A34640035C902DCBAF4B40
17157	25768	45.375486000000002	45.398302999999999	55.584187	55.570003	Школьная	0103000020E610000001000000050000008D0DDDEC0FB046409ACFB9DBF5C84B408D0DDDEC0FB04640CADFBDA3C6CA4B400873BB97FBB24640CADFBDA3C6CA4B400873BB97FBB246409ACFB9DBF5C84B408D0DDDEC0FB046409ACFB9DBF5C84B40
17205	26549	45.181880999999997	45.207923000000001	55.562911999999997	55.553075	Луговая	0103000020E61000000100000005000000C36169E0479746401B9E5E29CBC64B40C36169E04797464052431B800DC84B40098B8A389D9A464052431B800DC84B40098B8A389D9A46401B9E5E29CBC64B40C36169E0479746401B9E5E29CBC64B40
16980	25525	45.210942000000003	45.240046999999997	55.414082000000001	55.399898	Ивлиева	0103000020E610000001000000050000002AADBF25009B46402FDE8FDB2FB34B402AADBF25009B46405FEE93A300B54B405F402FDCB99E46405FEE93A300B54B405F402FDCB99E46402FDE8FDB2FB34B402AADBF25009B46402FDE8FDB2FB34B40
19704	50072	45.176338999999999	45.202191999999997	55.400885000000002	55.389003000000002	Зеленая	0103000020E610000001000000050000003201BF4692964640E085ADD9CAB14B403201BF46929646407E3A1E3350B34B40A4C16D6DE19946407E3A1E3350B34B40A4C16D6DE1994640E085ADD9CAB14B403201BF4692964640E085ADD9CAB14B40
17195	25435	45.180120000000002	45.222718999999998	55.543872999999998	55.524003	Почтовая	0103000020E6100000010000000500000082AD122C0E974640C100C28712C34B4082AD122C0E974640B51666A19DC54B405299620E829C4640B51666A19DC54B405299620E829C4640C100C28712C34B4082AD122C0E974640C100C28712C34B40
17859	26112	45.761726000000003	45.788728999999996	55.487025000000003	55.479812000000003	Колхозная	0103000020E61000000100000005000000A741D13C80E146403B1DC87A6ABD4B40A741D13C80E14640CEAACFD556BE4B4011346612F5E44640CEAACFD556BE4B4011346612F5E446403B1DC87A6ABD4B40A741D13C80E146403B1DC87A6ABD4B40
17895	26486	45.201023999999997	45.232968	55.473730000000003	55.462890000000002	Школьная	0103000020E6100000010000000500000005DB8827BB9946409ED2C1FA3FBB4B4005DB8827BB9946402A91442FA3BC4B40DC813AE5D19D46402A91442FA3BC4B40DC813AE5D19D46409ED2C1FA3FBB4B4005DB8827BB9946409ED2C1FA3FBB4B40
17416	26165	45.654350000000001	45.684075	55.461691000000002	55.452365	Овражная	0103000020E610000001000000050000009D11A5BDC1D34640726DA818E7B94B409D11A5BDC1D34640C4EDD0B018BB4B406F8104C58FD74640C4EDD0B018BB4B406F8104C58FD74640726DA818E7B94B409D11A5BDC1D34640726DA818E7B94B40
17201	25623	45.710917000000002	45.744954	55.683990000000001	55.667085999999998	Советская	0103000020E61000000100000005000000D1950854FFDA46404ACFF41263D54B40D1950854FFDA46404165FCFB8CD74B401F8315A75ADF46404165FCFB8CD74B401F8315A75ADF46404ACFF41263D54B40D1950854FFDA46404ACFF41263D54B40
18509	25838	45.496974000000002	45.525621000000001	55.734329000000002	55.722116999999997	Зеленая	0103000020E610000001000000050000002D7B12D89CBF46405C7171546EDC4B402D7B12D89CBF464090C01F7EFEDD4B40A08B868C47C3464090C01F7EFEDD4B40A08B868C47C346405C7171546EDC4B402D7B12D89CBF46405C7171546EDC4B40
17595	25721	45.513736999999999	45.548951000000002	55.603938999999997	55.588669000000003	Молодежная	0103000020E6100000010000000500000061DF4E22C2C14640A3957B8159CB4B4061DF4E22C2C14640B4E386DF4DCD4B40A20DC00644C64640B4E386DF4DCD4B40A20DC00644C64640A3957B8159CB4B4061DF4E22C2C14640A3957B8159CB4B40
17221	26023	45.562848000000002	45.600577000000001	55.570323999999999	55.556094999999999	Ленина	0103000020E610000001000000050000003C4F3C670BC846400C3CF71E2EC74B403C4F3C670BC84640DC0F786000C94B406ADD06B5DFCC4640DC0F786000C94B406ADD06B5DFCC46400C3CF71E2EC74B403C4F3C670BC846400C3CF71E2EC74B40
17222	25888	45.572927	45.602553	55.699106	55.67127	пос. Молодежный	0103000020E6100000010000000500000069FF03AC55C946409964E42CECD54B4069FF03AC55C94640FC372F4E7CD94B40A88DEA7420CD4640FC372F4E7CD94B40A88DEA7420CD46409964E42CECD54B4069FF03AC55C946409964E42CECD54B40
16799	25963	45.573079	45.616225999999997	55.612355000000001	55.595815999999999	Советская	0103000020E610000001000000050000001F8315A75AC946407E37DDB243CC4B401F8315A75AC9464063450DA661CE4B40F2785A7EE0CE464063450DA661CE4B40F2785A7EE0CE46407E37DDB243CC4B401F8315A75AC946407E37DDB243CC4B40
17851	25591	45.605347000000002	45.648699999999998	55.472735	55.462491999999997	Центральная	0103000020E61000000100000005000000A9DDAF027CCD4640B05417F032BB4B40A9DDAF027CCD464058569A9482BC4B402575029A08D3464058569A9482BC4B402575029A08D34640B05417F032BB4B40A9DDAF027CCD4640B05417F032BB4B40
17860	26376	45.264705999999997	45.291440000000001	55.363886999999998	55.345007000000003	Молодежная	0103000020E610000001000000050000000987DEE2E1A146400FF27A3029AC4B400987DEE2E1A14640433866D993AE4B40855FEAE74DA54640433866D993AE4B40855FEAE74DA546400FF27A3029AC4B400987DEE2E1A146400FF27A3029AC4B40
17540	49810	44.827855	44.868459000000001	56.862352000000001	56.853538	Октябрьская	0103000020E61000000100000005000000406A1327F769464056F2B1BB406D4C40406A1327F7694640F2D1E28C616E4C405C751DAA296F4640F2D1E28C616E4C405C751DAA296F464056F2B1BB406D4C40406A1327F769464056F2B1BB406D4C40
17582	49816	44.725743999999999	44.778609000000003	56.851647999999997	56.838552999999997	Новая	0103000020E6100000010000000500000055A2EC2DE55C4640397B67B4556B4C4055A2EC2DE55C464016DA39CD026D4C4086AFAF75A963464016DA39CD026D4C4086AFAF75A9634640397B67B4556B4C4055A2EC2DE55C4640397B67B4556B4C40
17002	49721	44.660139999999998	44.691696999999998	56.662762999999998	56.645108999999998	Центральная	0103000020E610000001000000050000000664AF777F54464079AD84EE92524C400664AF777F544640DAFF006BD5544C40E3DEFC8689584640DAFF006BD5544C40E3DEFC868958464079AD84EE92524C400664AF777F54464079AD84EE92524C40
16725	49634	44.202852	44.214889999999997	56.670513999999997	56.658538	Центральная	0103000020E61000000100000005000000CFF6E80DF71946402D9622F94A544C40CFF6E80DF71946404CC11A67D3554C40641EF983811B46404CC11A67D3554C40641EF983811B46402D9622F94A544C40CFF6E80DF71946402D9622F94A544C40
17350	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	пл. Ленина	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
17346	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	Чернышевского	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
17277	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	Центральная	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
17724	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	Пионерская	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
16773	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	Октябрьская	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
18113	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	Красноармейская	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
16779	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	Колхозная	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
16927	10423	44.454174000000002	44.536945000000003	56.808895999999997	56.764831999999998	1-е Мая	0103000020E61000000100000005000000C558A65F223A46409677D503E6614C40C558A65F223A4640BFEE74E789674C4018601F9DBA444640BFEE74E789674C4018601F9DBA4446409677D503E6614C40C558A65F223A46409677D503E6614C40
17396	49788	44.483648000000002	44.499952	56.680078000000002	56.669307000000003	Школьная	0103000020E610000001000000050000004E637B2DE83D4640F0FD0DDAAB554C404E637B2DE83D4640535DC0CB0C574C40EFC8586DFE3F4640535DC0CB0C574C40EFC8586DFE3F4640F0FD0DDAAB554C404E637B2DE83D4640F0FD0DDAAB554C40
17292	49772	44.355736	44.376415999999999	56.964033000000001	56.948577999999998	Ковернинская	0103000020E610000001000000050000004301DBC1882D464040DAFF006B794C404301DBC1882D4640E4A1EF6E657B4C4077D844662E304640E4A1EF6E657B4C4077D844662E30464040DAFF006B794C404301DBC1882D464040DAFF006B794C40
17174	49758	44.273055999999997	44.293016000000001	56.781444	56.771214999999998	И.Козлова	0103000020E6100000010000000500000000FDBE7FF3224640A297512CB7624C4000FDBE7FF3224640E5D3635B06644C40359A5C8C81254640E5D3635B06644C40359A5C8C81254640A297512CB7624C4000FDBE7FF3224640A297512CB7624C40
16785	49645	44.290995000000002	44.361170999999999	56.741360999999998	56.726607999999999	Лесная	0103000020E610000001000000050000005726FC523F2546408881AE7D015D4C405726FC523F254640D2C3D0EAE45E4C40BEA1F0D93A2E4640D2C3D0EAE45E4C40BEA1F0D93A2E46408881AE7D015D4C405726FC523F2546408881AE7D015D4C40
17366	23787	44.621915999999999	44.641688000000002	57.057675000000003	57.04833	Верхняя	0103000020E61000000100000005000000F86D88F19A4F464035B56CAD2F864C40F86D88F19A4F4640FE65F7E461874C402A1E17D522524640FE65F7E461874C402A1E17D52252464035B56CAD2F864C40F86D88F19A4F464035B56CAD2F864C40
16944	49712	44.460093999999998	44.492441999999997	56.752521000000002	56.737712999999999	Нижняя	0103000020E61000000100000005000000FC8A355CE43A4640C26A2C616D5E4C40FC8A355CE43A4640D046AE9B52604C40A296E656083F4640D046AE9B52604C40A296E656083F4640C26A2C616D5E4C40FC8A355CE43A4640C26A2C616D5E4C40
17379	49782	44.252330999999998	44.276487000000003	56.758614999999999	56.744945000000001	Центральная	0103000020E610000001000000050000002C62D8614C204640CC28965B5A5F4C402C62D8614C204640A5A0DB4B1A614C4074620FED63234640A5A0DB4B1A614C4074620FED63234640CC28965B5A5F4C402C62D8614C204640CC28965B5A5F4C40
16933	49711	44.617837999999999	44.638885000000002	56.913809999999998	56.899988999999998	Новая	0103000020E61000000100000005000000EF1CCA50154F46403FE1ECD632734C40EF1CCA50154F4640FE60E0B9F7744C40D673D2FBC6514640FE60E0B9F7744C40D673D2FBC65146403FE1ECD632734C40EF1CCA50154F46403FE1ECD632734C40
16818	49654	44.366489000000001	44.417189999999998	57.254612000000002	57.237552999999998	Медведева	0103000020E6100000010000000500000000AC8E1CE92E46408908FF22689E4C4000AC8E1CE92E4640A795422097A04C40EF1B5F7B66354640A795422097A04C40EF1B5F7B663546408908FF22689E4C4000AC8E1CE92E46408908FF22689E4C40
17386	49786	44.105637000000002	44.134194000000001	56.859437999999997	56.848291000000003	Панельная	0103000020E61000000100000005000000B01F6283850D4640DE3EABCC946C4C40B01F6283850D464046787B10026E4C40E3A8DC442D11464046787B10026E4C40E3A8DC442D114640DE3EABCC946C4C40B01F6283850D4640DE3EABCC946C4C40
16967	49719	44.593197000000004	44.621144000000001	56.838504	56.825794000000002	Школьная	0103000020E61000000100000005000000EC8A19E1ED4B4640D49D279EB3694C40EC8A19E1ED4B464058C85C19546B4C40A60D87A5814F464058C85C19546B4C40A60D87A5814F4640D49D279EB3694C40EC8A19E1ED4B4640D49D279EB3694C40
16781	49644	44.232793000000001	44.248550000000002	56.879308999999999	56.868648999999998	Молодежная	0103000020E610000001000000050000006EDE3829CC1D4640FF59F3E32F6F4C406EDE3829CC1D46400B0A83328D704C40DDB5847CD01F46400B0A83328D704C40DDB5847CD01F4640FF59F3E32F6F4C406EDE3829CC1D4640FF59F3E32F6F4C40
17599	49819	44.508468000000001	44.529739999999997	56.788533999999999	56.778480000000002	Центральная	0103000020E610000001000000050000000188BB7A15414640884B8E3BA5634C400188BB7A154146405CE49EAEEE644C4007B13385CE4346405CE49EAEEE644C4007B13385CE434640884B8E3BA5634C400188BB7A15414640884B8E3BA5634C40
17059	49735	44.575958	44.641112999999997	56.924942000000001	56.910429000000001	Мичуринская	0103000020E610000001000000050000004EEFE2FDB84946403D2AFEEF88744C404EEFE2FDB84946403259DC7F64764C402D05A4FD0F5246403259DC7F64764C402D05A4FD0F5246403D2AFEEF88744C404EEFE2FDB84946403D2AFEEF88744C40
17073	20994	44.744670999999997	44.772545999999998	54.666576999999997	54.658296999999997	Большая	0103000020E61000000100000005000000CAA31B61515F464007077B1343544B40CAA31B61515F464005A2276552554B40EB538EC9E262464005A2276552554B40EB538EC9E262464007077B1343544B40CAA31B61515F464007077B1343544B40
17132	21593	44.474654999999998	44.511450000000004	54.566876999999998	54.547302999999999	Центральная	0103000020E6100000010000000500000002F1BA7EC13C4640580053060E464B4002F1BA7EC13C464063EDEF6C8F484B4005C58F317741464063EDEF6C8F484B4005C58F3177414640580053060E464B4002F1BA7EC13C4640580053060E464B40
16701	21554	44.885553999999999	44.924379000000002	54.889474999999997	54.865622000000002	Ленина	0103000020E61000000100000005000000C66B5ED5597146405C59A2B3CC6E4B40C66B5ED55971464007CE1951DA714B40FA0D130D5276464007CE1951DA714B40FA0D130D527646405C59A2B3CC6E4B40C66B5ED5597146405C59A2B3CC6E4B40
17730	21516	44.747096999999997	44.788096000000003	54.717557999999997	54.696361000000003	1 Мая	0103000020E6100000010000000500000048F8DEDFA05F4640DD9A745B22594B4048F8DEDFA05F4640D87DC7F0D85B4B40E10D6954E0644640D87DC7F0D85B4B40E10D6954E0644640DD9A745B22594B4048F8DEDFA05F4640DD9A745B22594B40
17501	21207	44.745893000000002	44.773938000000001	54.777583	54.759087999999998	Парковая	0103000020E610000001000000050000005DA8FC6B795F46409D64ABCB29614B405DA8FC6B795F46407976F9D687634B40DA907F66106346407976F9D687634B40DA907F66106346409D64ABCB29614B405DA8FC6B795F46409D64ABCB29614B40
17345	21387	44.942013000000003	44.987405000000003	54.543464	54.518543999999999	Школьная	0103000020E6100000010000000500000014B4C9E193784640BDC458A65F424B4014B4C9E193784640D446753A90454B4015747B49637E4640D446753A90454B4015747B49637E4640BDC458A65F424B4014B4C9E193784640BDC458A65F424B40
17506	21300	44.983758000000002	45.017632999999996	54.724297	54.708274000000003	Ленина	0103000020E61000000100000005000000D5963AC8EB7D4640B64DF1B8A85A4B40D5963AC8EB7D4640A3CB9BC3B55C4B40492A53CC41824640A3CB9BC3B55C4B40492A53CC41824640B64DF1B8A85A4B40D5963AC8EB7D4640B64DF1B8A85A4B40
19553	50058	44.741069000000003	44.78302	54.795015999999997	54.779353999999998	Комсомольская	0103000020E610000001000000050000002B8A5759DB5E4640DE0033DFC1634B402B8A5759DB5E4640FBE59315C3654B40950ED6FF39644640FBE59315C3654B40950ED6FF39644640DE0033DFC1634B402B8A5759DB5E4640DE0033DFC1634B40
17300	11881	44.823228999999998	44.884467000000001	54.723283000000002	54.678364000000002	площадь Ленина	0103000020E61000000100000005000000340F60915F6946405264ADA1D4564B40340F60915F6946405B608F89945C4B4014B2F336367146405B608F89945C4B4014B2F336367146405264ADA1D4564B40340F60915F6946405264ADA1D4564B40
18079	11881	44.823228999999998	44.884467000000001	54.723283000000002	54.678364000000002	пл.Ленина	0103000020E61000000100000005000000340F60915F6946405264ADA1D4564B40340F60915F6946405B608F89945C4B4014B2F336367146405B608F89945C4B4014B2F336367146405264ADA1D4564B40340F60915F6946405264ADA1D4564B40
17062	11881	44.823228999999998	44.884467000000001	54.723283000000002	54.678364000000002	Луначарского	0103000020E61000000100000005000000340F60915F6946405264ADA1D4564B40340F60915F6946405B608F89945C4B4014B2F336367146405B608F89945C4B4014B2F336367146405264ADA1D4564B40340F60915F6946405264ADA1D4564B40
17307	11881	44.823228999999998	44.884467000000001	54.723283000000002	54.678364000000002	Коммунистическая	0103000020E61000000100000005000000340F60915F6946405264ADA1D4564B40340F60915F6946405B608F89945C4B4014B2F336367146405B608F89945C4B4014B2F336367146405264ADA1D4564B40340F60915F6946405264ADA1D4564B40
16794	11881	44.823228999999998	44.884467000000001	54.723283000000002	54.678364000000002	Заречная	0103000020E61000000100000005000000340F60915F6946405264ADA1D4564B40340F60915F6946405B608F89945C4B4014B2F336367146405B608F89945C4B4014B2F336367146405264ADA1D4564B40340F60915F6946405264ADA1D4564B40
18175	21119	44.916815	44.956133999999999	54.609530999999997	54.583424999999998	Центральная	0103000020E61000000100000005000000BABDA4315A7546409B559FABAD4A4B40BABDA4315A754640F7729F1C054E4B40FD4B5299627A4640F7729F1C054E4B40FD4B5299627A46409B559FABAD4A4B40BABDA4315A7546409B559FABAD4A4B40
18172	21037	45.022691000000002	45.041843	54.521093999999998	54.499040999999998	Комсомольская	0103000020E61000000100000005000000EF74E789E78246407B2E5393E03F4B40EF74E789E782464027124C35B3424B408448861C5B85464027124C35B3424B408448861C5B8546407B2E5393E03F4B40EF74E789E78246407B2E5393E03F4B40
17489	19915	44.809807999999997	44.831287000000003	54.654386000000002	54.631399000000002	Ленина	0103000020E610000001000000050000000305DEC9A767464012DDB3AED1504B400305DEC9A7674640EA7AA2EBC2534B40844BC79C676A4640EA7AA2EBC2534B40844BC79C676A464012DDB3AED1504B400305DEC9A767464012DDB3AED1504B40
19461	26121	44.773076000000003	44.781537999999998	54.848903	54.831986000000001	Первомайская	0103000020E6100000010000000500000048A98427F46246406C5D6A847E6A4B4048A98427F4624640F73C7FDAA86C4B40664AEB6F09644640F73C7FDAA86C4B40664AEB6F096446406C5D6A847E6A4B4048A98427F46246406C5D6A847E6A4B40
16992	20961	44.720883999999998	44.756475000000002	54.632817000000003	54.608545999999997	Ленина	0103000020E61000000100000005000000D61A4AED455C4640490ED8D5E44D4B40D61A4AED455C46402AADBF2500514B40ED9E3C2CD46046402AADBF2500514B40ED9E3C2CD4604640490ED8D5E44D4B40D61A4AED455C4640490ED8D5E44D4B40
17720	20897	44.528149999999997	44.570864999999998	54.647713000000003	54.609797	Агафонова	0103000020E61000000100000005000000F2B0506B9A4346407619FED30D4E4B40F2B0506B9A434640D7187442E8524B402CB7B41A12494640D7187442E8524B402CB7B41A124946407619FED30D4E4B40F2B0506B9A4346407619FED30D4E4B40
16840	18187	44.810985000000002	44.848785999999997	54.544252999999998	54.517592999999998	Ленина	0103000020E61000000100000005000000F645425BCE674640BBD1C77C40424B40F645425BCE674640FCDF1115AA454B40BDA60705A56C4640FCDF1115AA454B40BDA60705A56C4640BBD1C77C40424B40F645425BCE674640BBD1C77C40424B40
17108	20558	44.620066000000001	44.644868000000002	54.588914000000003	54.571303	Мира	0103000020E6100000010000000500000047AE9B525E4F4640A88DEA7420494B4047AE9B525E4F46400A14B188614B4B40541EDD088B5246400A14B188614B4B40541EDD088B524640A88DEA7420494B4047AE9B525E4F4640A88DEA7420494B40
18164	20518	44.965620999999999	45.022959999999998	54.771163999999999	54.741368999999999	Советская	0103000020E6100000010000000500000058AA0B78997B464055A2EC2DE55E4B4058AA0B78997B464020ED7F80B5624B40DE8E705AF082464020ED7F80B5624B40DE8E705AF082464055A2EC2DE55E4B4058AA0B78997B464055A2EC2DE55E4B40
17118	21480	44.852953999999997	44.868144999999998	54.509998000000003	54.498142000000001	Советская	0103000020E61000000100000005000000067FBF982D6D4640CC61F71DC33F4B40067FBF982D6D464041834D9D47414B40CC9717601F6F464041834D9D47414B40CC9717601F6F4640CC61F71DC33F4B40067FBF982D6D4640CC61F71DC33F4B40
16753	20396	44.869258000000002	44.912629000000003	54.775252000000002	54.757024999999999	Ленина	0103000020E61000000100000005000000A8E49CD8436F464090A0F831E6604B40A8E49CD8436F46404D1421753B634B40CB30EE06D17446404D1421753B634B40CB30EE06D174464090A0F831E6604B40A8E49CD8436F464090A0F831E6604B40
17508	21401	44.920848999999997	44.944268000000001	54.505487000000002	54.491259999999997	Центральная	0103000020E61000000100000005000000F3C64961DE7546409EEA909BE13E4B40F3C64961DE754640CEC64ACCB3404B40655419C6DD784640CEC64ACCB3404B40655419C6DD7846409EEA909BE13E4B40F3C64961DE7546409EEA909BE13E4B40
17496	20205	44.658118000000002	44.698183	54.666806999999999	54.644795999999999	Кооперативная	0103000020E610000001000000050000005874EB353D544640BA4BE2AC88524B405874EB353D54464037DF88EE59554B40C4CF7F0F5E59464037DF88EE59554B40C4CF7F0F5E594640BA4BE2AC88524B405874EB353D544640BA4BE2AC88524B40
18020	20119	44.708145999999999	44.748651000000002	54.564166999999998	54.54101	Молодежная	0103000020E6100000010000000500000088653387A45A46408C67D0D03F454B4088653387A45A4640C03DCF9F36484B40118FC4CBD35F4640C03DCF9F36484B40118FC4CBD35F46408C67D0D03F454B4088653387A45A46408C67D0D03F454B40
17314	20011	44.740116999999998	44.774962000000002	54.898519999999998	54.878210000000003	1 Мая	0103000020E61000000100000005000000581B6327BC5E464095826E2F69704B40581B6327BC5E4640A5660FB402734B4046D26EF431634640A5660FB402734B4046D26EF43163464095826E2F69704B40581B6327BC5E464095826E2F69704B40
17695	20317	44.839649999999999	44.867587999999998	54.789628	54.763736999999999	Макарова	0103000020E610000001000000050000000F0BB5A6796B464061DF4E22C2614B400F0BB5A6796B4640C100C28712654B407633A31F0D6F4640C100C28712654B407633A31F0D6F464061DF4E22C2614B400F0BB5A6796B464061DF4E22C2614B40
17275	20108	44.683315999999998	44.717488000000003	54.870424999999997	54.850836999999999	Заводская	0103000020E61000000100000005000000B16A10E676574640069D103AE86C4B40B16A10E676574640764F1E166A6F4B40E0A293A5D65B4640764F1E166A6F4B40E0A293A5D65B4640069D103AE86C4B40B16A10E676574640069D103AE86C4B40
17053	18541	45.794370000000001	45.825668	55.498240000000003	55.480122999999999	Школьная	0103000020E61000000100000005000000367689EAADE546405987A3AB74BD4B40367689EAADE546408FC70C54C6BF4B4047AD307DAFE946408FC70C54C6BF4B4047AD307DAFE946405987A3AB74BD4B40367689EAADE546405987A3AB74BD4B40
17590	11990	45.991793000000001	46.037329	55.54128	55.524090000000001	Советская	0103000020E610000001000000050000006CB3B112F3FE46409014916115C34B406CB3B112F3FE46404CFDBCA948C54B40A0185932C70447404CFDBCA948C54B40A0185932C70447409014916115C34B406CB3B112F3FE46409014916115C34B40
16717	11990	45.991793000000001	46.037329	55.54128	55.524090000000001	Новая	0103000020E610000001000000050000006CB3B112F3FE46409014916115C34B406CB3B112F3FE46404CFDBCA948C54B40A0185932C70447404CFDBCA948C54B40A0185932C70447409014916115C34B406CB3B112F3FE46409014916115C34B40
17597	19588	45.8889	45.926045999999999	55.435594999999999	55.411234999999998	Набережная	0103000020E610000001000000050000000BB5A679C7F146403BFC3559A3B44B400BB5A679C7F146408BA6B393C1B74B40BA4BE2AC88F646408BA6B393C1B74B40BA4BE2AC88F646403BFC3559A3B44B400BB5A679C7F146403BFC3559A3B44B40
17930	11816	45.906705000000002	45.940930999999999	55.577897	55.543790999999999	Юбилейная	0103000020E61000000100000005000000520FD1E80EF44640F86D88F19AC54B40520FD1E80EF446406FBA6587F8C94B407365506D70F846406FBA6587F8C94B407365506D70F84640F86D88F19AC54B40520FD1E80EF44640F86D88F19AC54B40
17200	11816	45.906705000000002	45.940930999999999	55.577897	55.543790999999999	Тарлыкова	0103000020E61000000100000005000000520FD1E80EF44640F86D88F19AC54B40520FD1E80EF446406FBA6587F8C94B407365506D70F846406FBA6587F8C94B407365506D70F84640F86D88F19AC54B40520FD1E80EF44640F86D88F19AC54B40
17435	11816	45.906705000000002	45.940930999999999	55.577897	55.543790999999999	Блохина	0103000020E61000000100000005000000520FD1E80EF44640F86D88F19AC54B40520FD1E80EF446406FBA6587F8C94B407365506D70F846406FBA6587F8C94B407365506D70F84640F86D88F19AC54B40520FD1E80EF44640F86D88F19AC54B40
18039	12101	46.213155999999998	46.252735999999999	55.462758000000001	55.447177000000003	Полевая	0103000020E610000001000000050000001C7920B2481B4740FF428F183DB94B401C7920B2481B47402FFB75A73BBB4B40CC423BA7592047402FFB75A73BBB4B40CC423BA759204740FF428F183DB94B401C7920B2481B4740FF428F183DB94B40
17089	19144	46.257452000000001	46.289709999999999	55.456755000000001	55.43629	Пролетарская	0103000020E610000001000000050000001825E82FF420474032C9C859D8B74B401825E82FF42047406AA4A5F276BA4B407EA99F37152547406AA4A5F276BA4B407EA99F371525474032C9C859D8B74B401825E82FF420474032C9C859D8B74B40
16822	19046	46.120809000000001	46.198846000000003	55.498128000000001	55.462665999999999	Гагарина	0103000020E61000000100000005000000FF0758AB760F47404E7CB5A338BB4B40FF0758AB760F4740679C86A8C2BF4B40607825C973194740679C86A8C2BF4B40607825C9731947404E7CB5A338BB4B40FF0758AB760F47404E7CB5A338BB4B40
16743	18083	45.831246	45.853273000000002	55.774664000000001	55.762079999999997	Молодежная	0103000020E610000001000000050000002577D84466EA4640C47762D68BE14B402577D84466EA4640BCB1A03028E34B40A8C7B60C38ED4640BCB1A03028E34B40A8C7B60C38ED4640C47762D68BE14B402577D84466EA4640C47762D68BE14B40
17046	18237	46.042924999999997	46.099789000000001	55.841251	55.819358000000001	Трудовая	0103000020E610000001000000050000002497FF907E054740A5DB12B9E0E84B402497FF907E054740185DDE1CAEEB4B4012C0CDE2C50C4740185DDE1CAEEB4B4012C0CDE2C50C4740A5DB12B9E0E84B402497FF907E054740A5DB12B9E0E84B40
16824	19289	46.092584000000002	46.128678000000001	55.399248999999998	55.367075	Кооперативная	0103000020E610000001000000050000000211E2CAD90B4740F0164850FCAE4B400211E2CAD90B4740F8FA5A971AB34B407BDB4C8578104740F8FA5A971AB34B407BDB4C8578104740F0164850FCAE4B400211E2CAD90B4740F0164850FCAE4B40
17637	18767	45.940823000000002	45.965544000000001	55.518310999999997	55.504873000000003	Центральная	0103000020E610000001000000050000008D2958E36CF8464014D1AFAD9FC04B408D2958E36CF846401A14CD0358C24B40AD6C1FF296FB46401A14CD0358C24B40AD6C1FF296FB464014D1AFAD9FC04B408D2958E36CF8464014D1AFAD9FC04B40
17297	19454	46.023350999999998	46.039538999999998	55.438507000000001	55.423678000000002	Школьная	0103000020E6100000010000000500000019AA622AFD0247407104A9143BB64B4019AA622AFD024740960854FF20B84B4051F52B9D0F054740960854FF20B84B4051F52B9D0F0547407104A9143BB64B4019AA622AFD0247407104A9143BB64B40
17457	18634	45.854531000000001	45.881714000000002	55.499158000000001	55.485709	Советская	0103000020E610000001000000050000008735954561ED4640BA2F67B62BBE4B408735954561ED4640B5C4CA68E4BF4B4072361D01DCF04640B5C4CA68E4BF4B4072361D01DCF04640BA2F67B62BBE4B408735954561ED4640BA2F67B62BBE4B40
17943	18153	45.915598000000003	45.939636999999998	55.800888	55.788063999999999	Октябрьская	0103000020E610000001000000050000003A24B55032F54640D593F947DFE44B403A24B55032F5464022E17B7F83E64B40478E740646F8464022E17B7F83E64B40478E740646F84640D593F947DFE44B403A24B55032F54640D593F947DFE44B40
17278	18052	45.851306000000001	45.884058000000003	55.736331	55.715108999999998	Нагорная	0103000020E61000000100000005000000BD715298F7EC4640A20914B188DB4B40BD715298F7EC4640F7031E1840DE4B4033E202D028F14640F7031E1840DE4B4033E202D028F14640A20914B188DB4B40BD715298F7EC4640A20914B188DB4B40
17049	18427	45.754053999999996	45.784174999999998	55.570217	55.558171999999999	Давыдова	0103000020E6100000010000000500000080B56AD784E046407EC51A2E72C74B4080B56AD784E04640C64FE3DEFCC84B409FABADD85FE44640C64FE3DEFCC84B409FABADD85FE446407EC51A2E72C74B4080B56AD784E046407EC51A2E72C74B40
16772	19234	46.192036999999999	46.219678000000002	55.388727000000003	55.368026999999998	Фролова	0103000020E610000001000000050000009C4F1DAB94184740C2853C821BAF4B409C4F1DAB941847403E096CCEC1B14B404AD3A0681E1C47403E096CCEC1B14B404AD3A0681E1C4740C2853C821BAF4B409C4F1DAB94184740C2853C821BAF4B40
17267	18714	45.942691000000003	45.967629000000002	55.484907999999997	55.471597000000003	Колхозная	0103000020E61000000100000005000000E59D4319AAF8464024F25D4A5DBC4B40E59D4319AAF84640CDC8207711BE4B40A2D45E44DBFB4640CDC8207711BE4B40A2D45E44DBFB464024F25D4A5DBC4B40E59D4319AAF8464024F25D4A5DBC4B40
17666	18976	46.098126999999998	46.122238000000003	55.516714999999998	55.503093999999997	Лесная	0103000020E6100000010000000500000063EDEF6C8F0C47402B685A6265C04B4063EDEF6C8F0C4740232D95B723C24B400B2AAA7EA50F4740232D95B723C24B400B2AAA7EA50F47402B685A6265C04B4063EDEF6C8F0C47402B685A6265C04B40
17439	17968	45.858770999999997	45.887138999999998	55.652405000000002	55.639704999999999	Молодежная	0103000020E6100000010000000500000069E04735ECED4640390B7BDAE1D14B4069E04735ECED46409A5FCD0182D34B40C90050C58DF146409A5FCD0182D34B40C90050C58DF14640390B7BDAE1D14B4069E04735ECED4640390B7BDAE1D14B40
17187	29440	44.553716000000001	44.575330000000001	55.693717999999997	55.682397000000002	Микрорайон	0103000020E61000000100000005000000CFA2772AE0464640BBF1EEC858D74B40CFA2772AE0464640C1525DC0CBD84B402F34D769A4494640C1525DC0CBD84B402F34D769A4494640BBF1EEC858D74B40CFA2772AE0464640BBF1EEC858D74B40
17252	49766	44.595469999999999	44.615772	55.601909999999997	55.596696000000001	Центральная	0103000020E61000000100000005000000E3DF675C384C4640B7D3D68860CC4B40E3DF675C384C464053910A630BCD4B4071E5EC9DD14E464053910A630BCD4B4071E5EC9DD14E4640B7D3D68860CC4B40E3DF675C384C4640B7D3D68860CC4B40
17235	17443	44.367010000000001	44.409329999999997	55.57976	55.563203000000001	Молодежная	0103000020E6100000010000000500000009A7052FFA2E46402A01310917C84B4009A7052FFA2E4640B5C35F9335CA4B40C6A2E9EC64344640B5C35F9335CA4B40C6A2E9EC643446402A01310917C84B4009A7052FFA2E46402A01310917C84B40
17615	17375	44.503455000000002	44.520280999999997	55.635818	55.625836	Молодежная	0103000020E61000000100000005000000FC00A436714046406954E0641BD04B40FC00A43671404640A41AF67B62D14B4076DD5B9198424640A41AF67B62D14B4076DD5B91984246406954E0641BD04B40FC00A436714046406954E0641BD04B40
17232	17182	44.46649	44.488273999999997	55.429884999999999	55.413181999999999	Центральная	0103000020E610000001000000050000009DF4BEF1B53B4640DFA5D425E3B44B409DF4BEF1B53B46403E05C07806B74B4059BE2EC37F3E46403E05C07806B74B4059BE2EC37F3E4640DFA5D425E3B44B409DF4BEF1B53B4640DFA5D425E3B44B40
19459	16731	44.519382999999998	44.580567000000002	55.605521000000003	55.583081999999997	пр-т Советский	0103000020E61000000100000005000000978C63247B4246407171546EA2CA4B40978C63247B42464047054EB681CD4B408411FB04504A464047054EB681CD4B408411FB04504A46407171546EA2CA4B40978C63247B4246407171546EA2CA4B40
17604	16731	44.519382999999998	44.580567000000002	55.605521000000003	55.583081999999997	Советский проспект	0103000020E61000000100000005000000978C63247B4246407171546EA2CA4B40978C63247B42464047054EB681CD4B408411FB04504A464047054EB681CD4B408411FB04504A46407171546EA2CA4B40978C63247B4246407171546EA2CA4B40
17009	16731	44.519382999999998	44.580567000000002	55.605521000000003	55.583081999999997	4 микрорайон	0103000020E61000000100000005000000978C63247B4246407171546EA2CA4B40978C63247B42464047054EB681CD4B408411FB04504A464047054EB681CD4B408411FB04504A46407171546EA2CA4B40978C63247B4246407171546EA2CA4B40
17459	17279	44.472580000000001	44.497410000000002	55.761071999999999	55.745269999999998	Шиянова	0103000020E61000000100000005000000315F5E807D3C46404F58E20165DF4B40315F5E807D3C46405EF3AACE6AE14B40085A8121AB3F46405EF3AACE6AE14B40085A8121AB3F46404F58E20165DF4B40315F5E807D3C46404F58E20165DF4B40
17242	17346	44.349772000000002	44.375230000000002	55.733310000000003	55.724145	Школьная	0103000020E610000001000000050000003C873254C52C4640ED478AC8B0DC4B403C873254C52C464036EA211ADDDD4B40323D61890730464036EA211ADDDD4B40323D618907304640ED478AC8B0DC4B403C873254C52C4640ED478AC8B0DC4B40
17008	17152	44.477530000000002	44.516705999999999	55.456648000000001	55.435814999999998	Кирова	0103000020E61000000100000005000000F06DFAB31F3D4640990D32C9C8B74B40F06DFAB31F3D464054E4107173BA4B40D0D2156C2342464054E4107173BA4B40D0D2156C23424640990D32C9C8B74B40F06DFAB31F3D4640990D32C9C8B74B40
17503	17030	44.634484	44.687483999999998	55.598771999999997	55.588042999999999	Центральная	0103000020E61000000100000005000000EAEA8EC53651464024D236FE44CB4B40EAEA8EC53651464058E1968FA4CC4B40FA42C879FF57464058E1968FA4CC4B40FA42C879FF57464024D236FE44CB4B40EAEA8EC53651464024D236FE44CB4B40
17015	17556	44.632471000000002	44.669328999999998	55.664558	55.646588999999999	Молодежная	0103000020E610000001000000050000008F554ACFF4504640077AA86DC3D24B408F554ACFF4504640C8258E3C10D54B40D7A19A92AC554640C8258E3C10D54B40D7A19A92AC554640077AA86DC3D24B408F554ACFF4504640077AA86DC3D24B40
17889	17093	44.632651000000003	44.662286999999999	55.52646	55.513987999999998	Центральная	0103000020E610000001000000050000000F643DB5FA504640AA44D95BCAC14B400F643DB5FA5046407A53910A63C34B4071C806D2C55446407A53910A63C34B4071C806D2C5544640AA44D95BCAC14B400F643DB5FA504640AA44D95BCAC14B40
16984	16338	44.094299999999997	44.135137	54.877682	54.857367000000004	Больничная	0103000020E61000000100000005000000A301BC05120C4640B7D5AC33BE6D4B40A301BC05120C4640D9243FE257704B4062BD512B4C114640D9243FE257704B4062BD512B4C114640B7D5AC33BE6D4B40A301BC05120C4640B7D5AC33BE6D4B40
19462	16645	43.744649000000003	43.778865000000003	55.143317000000003	55.125165000000003	Кооперативная	0103000020E61000000100000005000000E3FF8EA850DF45404BCD1E6805904B40E3FF8EA850DF4540FDFA213658924B40E17F2BD9B1E34540FDFA213658924B40E17F2BD9B1E345404BCD1E6805904B40E3FF8EA850DF45404BCD1E6805904B40
17404	16187	43.801223999999998	43.836914	55.033414	55.012388000000001	1 мая	0103000020E6100000010000000500000099620E828EE64540726E13EE95814B4099620E828EE64540419DF2E846844B4043C879FF1FEB4540419DF2E846844B4043C879FF1FEB4540726E13EE95814B4099620E828EE64540726E13EE95814B40
17589	16283	43.948951999999998	43.980789000000001	54.878639999999997	54.867227999999997	Центральная	0103000020E61000000100000005000000A5BC564277F945407616BD53016F4B40A5BC564277F945408D7A884677704B4066A3737E8AFD45408D7A884677704B4066A3737E8AFD45407616BD53016F4B40A5BC564277F945407616BD53016F4B40
19447	12521	43.772720999999997	43.84075	54.888708000000001	54.845311000000002	Октябрьская	0103000020E6100000010000000500000059F78F85E8E245407BF99D26336C4B4059F78F85E8E24540C7D8092FC1714B40560E2DB29DEB4540C7D8092FC1714B40560E2DB29DEB45407BF99D26336C4B4059F78F85E8E245407BF99D26336C4B40
17850	12521	43.772720999999997	43.84075	54.888708000000001	54.845311000000002	Мочалина	0103000020E6100000010000000500000059F78F85E8E245407BF99D26336C4B4059F78F85E8E24540C7D8092FC1714B40560E2DB29DEB4540C7D8092FC1714B40560E2DB29DEB45407BF99D26336C4B4059F78F85E8E245407BF99D26336C4B40
17585	12521	43.772720999999997	43.84075	54.888708000000001	54.845311000000002	Ленина	0103000020E6100000010000000500000059F78F85E8E245407BF99D26336C4B4059F78F85E8E24540C7D8092FC1714B40560E2DB29DEB4540C7D8092FC1714B40560E2DB29DEB45407BF99D26336C4B4059F78F85E8E245407BF99D26336C4B40
17584	12521	43.772720999999997	43.84075	54.888708000000001	54.845311000000002	 площадь Ульянова	0103000020E6100000010000000500000059F78F85E8E245407BF99D26336C4B4059F78F85E8E24540C7D8092FC1714B40560E2DB29DEB4540C7D8092FC1714B40560E2DB29DEB45407BF99D26336C4B4059F78F85E8E245407BF99D26336C4B40
16987	16409	44.038702999999998	44.073019000000002	54.883566000000002	54.871217000000001	Полевая	0103000020E61000000100000005000000E8A04B38F4044640105CE509846F4B40E8A04B38F4044640C4EDD0B018714B404A7EC4AF58094640C4EDD0B018714B404A7EC4AF58094640105CE509846F4B40E8A04B38F4044640105CE509846F4B40
16797	16416	43.976612000000003	44.002312000000003	54.819336	54.808374000000001	Молодежная	0103000020E61000000100000005000000CA703C9F01FD4540E6779ACC78674B40CA703C9F01FD4540BD378600E0684B40B63176C24B004640BD378600E0684B40B63176C24B004640E6779ACC78674B40CA703C9F01FD4540E6779ACC78674B40
17413	16595	43.704368000000002	43.729134999999999	55.112160000000003	55.092947000000002	Клубная	0103000020E61000000100000005000000AA2C0ABB28DA454073A1F2AFE58B4B40AA2C0ABB28DA4540AEF545425B8E4B403AAFB14B54DD4540AEF545425B8E4B403AAFB14B54DD454073A1F2AFE58B4B40AA2C0ABB28DA454073A1F2AFE58B4B40
16998	16717	43.521363000000001	43.554188000000003	55.033842	55.006368000000002	Школьная	0103000020E61000000100000005000000172CD505BCC24540D7DEA7AAD0804B40172CD505BCC24540999D45EF54844B40F7EAE3A1EFC64540999D45EF54844B40F7EAE3A1EFC64540D7DEA7AAD0804B40172CD505BCC24540D7DEA7AAD0804B40
16997	16556	43.663575999999999	43.700082999999999	55.072153999999998	55.056516999999999	Молодежная	0103000020E610000001000000050000008B34F10EF0D445408255F5F23B874B408B34F10EF0D4454046239F573C894B4027BEDA519CD9454046239F573C894B4027BEDA519CD945408255F5F23B874B408B34F10EF0D445408255F5F23B874B40
16981	16242	43.683922000000003	43.734489000000004	54.952837000000002	54.940809999999999	Советская	0103000020E61000000100000005000000E9818FC18AD74540F8DF4A766C784B40E9818FC18AD745409AB51490F6794B40C9224DBC03DE45409AB51490F6794B40C9224DBC03DE4540F8DF4A766C784B40E9818FC18AD74540F8DF4A766C784B40
17573	12474	43.203116999999999	43.216636999999999	55.965364999999998	55.952796999999997	Центральная	0103000020E610000001000000050000007D21E4BCFF9945400B5D8940F5F94B407D21E4BCFF994540FDD98F1491FB4B40410DDFC2BA9B4540FDD98F1491FB4B40410DDFC2BA9B45400B5D8940F5F94B407D21E4BCFF9945400B5D8940F5F94B40
17184	15727	43.136955999999998	43.15945	56.123804	56.115765000000003	Школьная	0103000020E61000000100000005000000D87E32C687914540BF823463D10E4C40D87E32C687914540978E39CFD80F4C4071AC8BDB68944540978E39CFD80F4C4071AC8BDB68944540BF823463D10E4C40D87E32C687914540BF823463D10E4C40
17779	14707	42.994411999999997	43.054257	56.005620999999998	55.981434	Школьная	0103000020E61000000100000005000000FE5F75E4487F45405B971AA19FFD4B40FE5F75E4487F4540DD955D30B8004C401F4AB4E4F1864540DD955D30B8004C401F4AB4E4F18645405B971AA19FFD4B40FE5F75E4487F45405B971AA19FFD4B40
17164	14707	42.994411999999997	43.054257	56.005620999999998	55.981434	Пролетарская	0103000020E61000000100000005000000FE5F75E4487F45405B971AA19FFD4B40FE5F75E4487F4540DD955D30B8004C401F4AB4E4F1864540DD955D30B8004C401F4AB4E4F18645405B971AA19FFD4B40FE5F75E4487F45405B971AA19FFD4B40
17773	14707	42.994411999999997	43.054257	56.005620999999998	55.981434	Буденного	0103000020E61000000100000005000000FE5F75E4487F45405B971AA19FFD4B40FE5F75E4487F4540DD955D30B8004C401F4AB4E4F1864540DD955D30B8004C401F4AB4E4F18645405B971AA19FFD4B40FE5F75E4487F45405B971AA19FFD4B40
17831	15613	43.027191000000002	43.048552999999998	55.934719000000001	55.920133999999997	Школьная	0103000020E610000001000000050000006EDFA3FE7A83454005F86EF3C6F54B406EDFA3FE7A83454094F947DFA4F74B40B48F15FC3686454094F947DFA4F74B40B48F15FC3686454005F86EF3C6F54B406EDFA3FE7A83454005F86EF3C6F54B40
17382	12363	42.872151000000002	42.890664999999998	55.943739000000001	55.935118000000003	Центральная	0103000020E610000001000000050000003C16DBA4A26F454052F355F2B1F74B403C16DBA4A26F4540D97A8670CCF84B408E588B4F01724540D97A8670CCF84B408E588B4F0172454052F355F2B1F74B403C16DBA4A26F454052F355F2B1F74B40
17545	40284	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Пилота	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
19414	40286	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Чкалова	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
19415	40286	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Покровская	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
19429	40286	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Лермонтова	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
19412	40286	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Коммунистическая	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
17389	15661	43.005344000000001	43.018405999999999	55.909816999999997	55.903892999999997	Новая	0103000020E610000001000000050000006B9DB81CAF804540AA0A0DC4B2F34B406B9DB81CAF804540232C2AE274F44B406C06B8205B824540232C2AE274F44B406C06B8205B824540AA0A0DC4B2F34B406B9DB81CAF804540AA0A0DC4B2F34B40
19439	15266	43.071809999999999	43.095804000000001	55.923366999999999	55.902197000000001	Заводская	0103000020E610000001000000050000004CC3F0113189454050C6F8307BF34B404CC3F01131894540529ACDE330F64B40BA69334E438C4540529ACDE330F64B40BA69334E438C454050C6F8307BF34B404CC3F0113189454050C6F8307BF34B40
16954	14937	43.249173999999996	43.274388999999999	56.038764999999998	56.028354	Центральная	0103000020E61000000100000005000000BA8102EFE49F4540FB5A971AA1034C40BA8102EFE49F45405E9D6340F6044C40EAB0C22D1FA345405E9D6340F6044C40EAB0C22D1FA34540FB5A971AA1034C40BA8102EFE49F4540FB5A971AA1034C40
16756	15211	43.262405999999999	43.276482999999999	55.956501000000003	55.949148000000001	Нагорная	0103000020E610000001000000050000001823128596A145402B8881AE7DF94B401823128596A14540B0CBF09F6EFA4B40327381CB63A34540B0CBF09F6EFA4B40327381CB63A345402B8881AE7DF94B401823128596A145402B8881AE7DF94B40
16727	49635	43.314858999999998	43.345939999999999	55.965057999999999	55.944586000000001	Школьная	0103000020E61000000100000005000000F6ECB94C4DA845403621AD31E8F84B40F6ECB94C4DA84540205F420587FB4B406A300DC347AC4540205F420587FB4B406A300DC347AC45403621AD31E8F84B40F6ECB94C4DA845403621AD31E8F84B40
17371	14544	43.034171000000001	43.099558999999999	56.1389	56.117927999999999	Набережная	0103000020E610000001000000050000005EBC1FB75F8445402FA4C343180F4C405EBC1FB75F8445400BB5A679C7114C40E0826C59BE8C45400BB5A679C7114C40E0826C59BE8C45402FA4C343180F4C405EBC1FB75F8445402FA4C343180F4C40
17363	14262	43.249057000000001	43.293937	56.012244000000003	55.968882000000001	Строителей	0103000020E6100000010000000500000081EB8A19E19F45406FD74B5304FC4B4081EB8A19E19F45403FC91D3691014C40CC0A45BA9FA545403FC91D3691014C40CC0A45BA9FA545406FD74B5304FC4B4081EB8A19E19F45406FD74B5304FC4B40
16940	14262	43.249057000000001	43.293937	56.012244000000003	55.968882000000001	Ленина	0103000020E6100000010000000500000081EB8A19E19F45406FD74B5304FC4B4081EB8A19E19F45403FC91D3691014C40CC0A45BA9FA545403FC91D3691014C40CC0A45BA9FA545406FD74B5304FC4B4081EB8A19E19F45406FD74B5304FC4B40
17759	14262	43.249057000000001	43.293937	56.012244000000003	55.968882000000001	Гагарина	0103000020E6100000010000000500000081EB8A19E19F45406FD74B5304FC4B4081EB8A19E19F45403FC91D3691014C40CC0A45BA9FA545403FC91D3691014C40CC0A45BA9FA545406FD74B5304FC4B4081EB8A19E19F45406FD74B5304FC4B40
17159	14262	43.249057000000001	43.293937	56.012244000000003	55.968882000000001	Весенняя	0103000020E6100000010000000500000081EB8A19E19F45406FD74B5304FC4B4081EB8A19E19F45403FC91D3691014C40CC0A45BA9FA545403FC91D3691014C40CC0A45BA9FA545406FD74B5304FC4B4081EB8A19E19F45406FD74B5304FC4B40
17789	14990	42.908963999999997	42.924675000000001	55.950266999999997	55.934854999999999	Школьная	0103000020E61000000100000005000000E49EAEEE5874454044C02154A9F74B40E49EAEEE58744540E8BB5B59A2F94B40E3361AC05B764540E8BB5B59A2F94B40E3361AC05B76454044C02154A9F74B40E49EAEEE5874454044C02154A9F74B40
17180	15439	43.104509	43.140864000000001	55.953664000000003	55.938208000000003	Озерная	0103000020E610000001000000050000009F91088D608D45403C6C223317F84B409F91088D608D4540B0AF75A911FA4B408597E0D407924540B0AF75A911FA4B408597E0D4079245403C6C223317F84B409F91088D608D45403C6C223317F84B40
16726	28807	42.658064000000003	42.685938999999998	55.521985000000001	55.508696999999998	Школьная	0103000020E610000001000000050000006556EF703B5445406249B9FB1CC14B406556EF703B54454054008C67D0C24B40850662D9CC57454054008C67D0C24B40850662D9CC5745406249B9FB1CC14B406556EF703B5445406249B9FB1CC14B40
17173	28668	42.424968999999997	42.444634000000001	55.611688999999998	55.591579000000003	Трудовая	0103000020E610000001000000050000002B685A62653645400D0055DCB8CB4B402B685A626536454056293DD34BCE4B40475854C4E938454056293DD34BCE4B40475854C4E93845400D0055DCB8CB4B402B685A62653645400D0055DCB8CB4B40
17147	29001	42.833019999999998	42.858083000000001	55.621845999999998	55.609425999999999	Советская	0103000020E61000000100000005000000FB743C66A06A454082AAD1AB01CE4B40FB743C66A06A4540FF9254A698CF4B407520EBA9D56D4540FF9254A698CF4B407520EBA9D56D454082AAD1AB01CE4B40FB743C66A06A454082AAD1AB01CE4B40
17979	28968	42.690618999999998	42.706716999999998	55.584629	55.566313000000001	Школьная	0103000020E61000000100000005000000847F1134665845405B26C3F17CC84B40847F11346658454087A5811FD5CA4B407C43E1B3755A454087A5811FD5CA4B407C43E1B3755A45405B26C3F17CC84B40847F1134665845405B26C3F17CC84B40
17783	10060	42.228346000000002	42.251244	55.642305999999998	55.626120999999998	Богатова	0103000020E61000000100000005000000121615713A1D45405E2BA1BB24D04B40121615713A1D45402503401537D24B407AA86DC3282045402503401537D24B407AA86DC3282045405E2BA1BB24D04B40121615713A1D45405E2BA1BB24D04B40
17778	28415	42.232182000000002	42.250939000000002	55.596151999999996	55.582155999999998	Пролетарская	0103000020E61000000100000005000000255CC823B81D4540C8957A1684CA4B40255CC823B81D4540F5B86FB54ECC4B403E25E7C41E204540F5B86FB54ECC4B403E25E7C41E204540C8957A1684CA4B40255CC823B81D4540C8957A1684CA4B40
17562	28795	42.502673999999999	42.536557999999999	55.538803999999999	55.521562000000003	Кооперативная	0103000020E610000001000000050000005646239F574045400E6B2A8BC2C24B405646239F574045401C7A8B87F7C44B401E34BBEEAD4445401C7A8B87F7C44B401E34BBEEAD4445400E6B2A8BC2C24B405646239F574045400E6B2A8BC2C24B40
17991	9126	42.167862999999997	42.224393999999997	55.556716000000002	55.499988999999999	Трудовая	0103000020E61000000100000005000000AE9AE7887C1545400CAEB9A3FFBF4B40AE9AE7887C15454079944A7842C74B4095B54DF1B81C454079944A7842C74B4095B54DF1B81C45400CAEB9A3FFBF4B40AE9AE7887C1545400CAEB9A3FFBF4B40
16782	9126	42.167862999999997	42.224393999999997	55.556716000000002	55.499988999999999	Советская	0103000020E61000000100000005000000AE9AE7887C1545400CAEB9A3FFBF4B40AE9AE7887C15454079944A7842C74B4095B54DF1B81C454079944A7842C74B4095B54DF1B81C45400CAEB9A3FFBF4B40AE9AE7887C1545400CAEB9A3FFBF4B40
16946	9126	42.167862999999997	42.224393999999997	55.556716000000002	55.499988999999999	Почтовая	0103000020E61000000100000005000000AE9AE7887C1545400CAEB9A3FFBF4B40AE9AE7887C15454079944A7842C74B4095B54DF1B81C454079944A7842C74B4095B54DF1B81C45400CAEB9A3FFBF4B40AE9AE7887C1545400CAEB9A3FFBF4B40
16945	9126	42.167862999999997	42.224393999999997	55.556716000000002	55.499988999999999	Лепсе	0103000020E61000000100000005000000AE9AE7887C1545400CAEB9A3FFBF4B40AE9AE7887C15454079944A7842C74B4095B54DF1B81C454079944A7842C74B4095B54DF1B81C45400CAEB9A3FFBF4B40AE9AE7887C1545400CAEB9A3FFBF4B40
17555	9126	42.167862999999997	42.224393999999997	55.556716000000002	55.499988999999999	Ленина	0103000020E61000000100000005000000AE9AE7887C1545400CAEB9A3FFBF4B40AE9AE7887C15454079944A7842C74B4095B54DF1B81C454079944A7842C74B4095B54DF1B81C45400CAEB9A3FFBF4B40AE9AE7887C1545400CAEB9A3FFBF4B40
17007	9126	42.167862999999997	42.224393999999997	55.556716000000002	55.499988999999999	50 лет Октября	0103000020E61000000100000005000000AE9AE7887C1545400CAEB9A3FFBF4B40AE9AE7887C15454079944A7842C74B4095B54DF1B81C454079944A7842C74B4095B54DF1B81C45400CAEB9A3FFBF4B40AE9AE7887C1545400CAEB9A3FFBF4B40
16959	28646	42.349187999999998	42.383915999999999	55.750418000000003	55.733193	Зеленая	0103000020E61000000100000005000000EC134031B22C4540FC53AA44D9DD4B40EC134031B22C4540352A70B20DE04B40A034D42824314540352A70B20DE04B40A034D42824314540FC53AA44D9DD4B40EC134031B22C4540FC53AA44D9DD4B40
19431	28602	42.267854	42.283439999999999	55.675240000000002	55.665162000000002	Школьная	0103000020E61000000100000005000000280D350A492245405F45460724D54B40280D350A49224540BC79AA436ED64B406A300DC347244540BC79AA436ED64B406A300DC3472445405F45460724D54B40280D350A492245405F45460724D54B40
17168	28525	42.267594000000003	42.290095999999998	55.728408000000002	55.709358000000002	Молодежная	0103000020E610000001000000050000008C4D2B8540224540F793313ECCDA4B408C4D2B854022454088122D793CDD4B40A759A0DD2125454088122D793CDD4B40A759A0DD21254540F793313ECCDA4B408C4D2B8540224540F793313ECCDA4B40
17811	28716	42.422364000000002	42.454110999999997	55.631076	55.619599000000001	Советская	0103000020E61000000100000005000000FE8007061036454031D120054FCF4B40FE800706103645402FA52E19C7D04B407EE02A4F203A45402FA52E19C7D04B407EE02A4F203A454031D120054FCF4B40FE8007061036454031D120054FCF4B40
16963	49718	42.572310999999999	42.581178000000001	55.521363999999998	55.519565	Советская	0103000020E610000001000000050000000E12A27C41494540B8921D1B81C24B400E12A27C41494540E7A7380EBCC24B40CD936B0A644A4540E7A7380EBCC24B40CD936B0A644A4540B8921D1B81C24B400E12A27C41494540B8921D1B81C24B40
16706	16552	45.011074999999998	45.064911000000002	56.05406	56.001508999999999	Мичурина	0103000020E61000000100000005000000CF66D5E76A81464028D3687231004C40CF66D5E76A814640C9022670EB064C404913EF004F884640C9022670EB064C404913EF004F88464028D3687231004C40CF66D5E76A81464028D3687231004C40
17660	16552	45.011074999999998	45.064911000000002	56.05406	56.001508999999999	50 лет ВЛКСМ	0103000020E61000000100000005000000CF66D5E76A81464028D3687231004C40CF66D5E76A814640C9022670EB064C404913EF004F884640C9022670EB064C404913EF004F88464028D3687231004C40CF66D5E76A81464028D3687231004C40
18204	25722	44.704687	44.738446000000003	55.046253999999998	55.031700999999998	Ватракшонка	0103000020E610000001000000050000004B75012F335A4640102043C70E844B404B75012F335A464093A7ACA6EB854B4057EE0566855E464093A7ACA6EB854B4057EE0566855E4640102043C70E844B404B75012F335A4640102043C70E844B40
17308	49776	44.383493999999999	44.433602	55.050967999999997	55.036436999999999	1 Мая	0103000020E610000001000000050000002A1BD65416314640A3AEB5F7A9844B402A1BD654163146403E92921E86864B4077BD3445803746403E92921E86864B4077BD344580374640A3AEB5F7A9844B402A1BD65416314640A3AEB5F7A9844B40
17271	24476	44.635005	44.670892000000002	54.964312999999997	54.934102000000003	Ленина	0103000020E61000000100000005000000F3E505D847514640699082A790774B40F3E505D847514640C70DBF9B6E7B4B40F392FFC9DF554640C70DBF9B6E7B4B40F392FFC9DF554640699082A790774B40F3E505D847514640699082A790774B40
17341	25209	44.513534999999997	44.531573000000002	55.092525000000002	55.077798000000001	Аряева	0103000020E61000000100000005000000F92CCF83BB414640DCD8EC48F5894B40F92CCF83BB414640FD87F4DBD78B4B40E33785950A444640FD87F4DBD78B4B40E33785950A444640DCD8EC48F5894B40F92CCF83BB414640DCD8EC48F5894B40
17680	49831	44.210982000000001	44.228929999999998	54.849639000000003	54.829103000000003	Центральная	0103000020E61000000100000005000000B8054B75011B4640FC010F0C206A4B40B8054B75011B4640FD3383F8C06C4B40618907944D1D4640FD3383F8C06C4B40618907944D1D4640FC010F0C206A4B40B8054B75011B4640FC010F0C206A4B40
19441	25035	44.264009999999999	44.287222	55.026659000000002	55.015000000000001	Базарная	0103000020E6100000010000000500000092E86514CB21464052B81E85EB814B4092E86514CB2146407192E68F69834B408A58C4B0C32446407192E68F69834B408A58C4B0C324464052B81E85EB814B4092E86514CB21464052B81E85EB814B40
17316	25518	44.671278999999998	44.718556999999997	55.130029	55.112551000000003	Молодежная	0103000020E61000000100000005000000ECBE6378EC554640E9103812688E4B40ECBE6378EC5546400B444FCAA4904B40EBA7FFACF95B46400B444FCAA4904B40EBA7FFACF95B4640E9103812688E4B40ECBE6378EC554640E9103812688E4B40
16834	25104	44.306373999999998	44.331041999999997	55.081792	55.067354999999999	Школьная	0103000020E610000001000000050000001F2C6343372746406D1CB1169F884B401F2C63433727464087890629788A4B401CCD91955F2A464087890629788A4B401CCD91955F2A46406D1CB1169F884B401F2C6343372746406D1CB1169F884B40
16734	9391	44.589469000000001	44.631250000000001	56.049757	56.028565999999998	Ленина	0103000020E61000000100000005000000BF805EB8734B464086E3F90CA8034C40BF805EB8734B4640A0DFF76F5E064C40CDCCCCCCCC504640A0DFF76F5E064C40CDCCCCCCCC50464086E3F90CA8034C40BF805EB8734B464086E3F90CA8034C40
16831	49657	44.306365	44.341085	54.763789000000003	54.736972000000002	Центральная	0103000020E61000000100000005000000CCD1E3F736274640AB083719555E4B40CCD1E3F736274640B40584D6C3614B40FD135CACA82B4640B40584D6C3614B40FD135CACA82B4640AB083719555E4B40CCD1E3F736274640AB083719555E4B40
17116	25713	44.814084000000001	44.841411000000001	55.077824	55.060245000000002	Советская	0103000020E6100000010000000500000033198EE733684640AF5FB01BB6874B4033198EE733684640056C0723F6894B4051BF0B5BB36B4640056C0723F6894B4051BF0B5BB36B4640AF5FB01BB6874B4033198EE733684640AF5FB01BB6874B40
17110	49746	44.302681999999997	44.337141000000003	54.816949999999999	54.786538999999998	Школьная	0103000020E610000001000000050000003F8BA548BE264640A703594FAD644B403F8BA548BE264640CD3B4ED191684B400492B06F272B4640CD3B4ED191684B400492B06F272B4640A703594FAD644B403F8BA548BE264640A703594FAD644B40
18176	25422	44.575563000000002	44.594706000000002	55.187686999999997	55.175837999999999	Золина	0103000020E61000000100000005000000D2E4620CAC49464070B20DDC81964B40D2E4620CAC4946403271AB2006984B40145E82531F4C46403271AB2006984B40145E82531F4C464070B20DDC81964B40D2E4620CAC49464070B20DDC81964B40
17117	25695	44.763365	44.797213999999997	55.072550999999997	55.060167999999997	Клубная	0103000020E610000001000000050000009DF4BEF1B56146400322C495B3874B409DF4BEF1B56146406325E65949894B40E8F4BC1B0B6646406325E65949894B40E8F4BC1B0B6646400322C495B3874B409DF4BEF1B56146400322C495B3874B40
19460	50030	44.392234999999999	44.420890999999997	54.831431000000002	54.812581999999999	Кадышева	0103000020E610000001000000050000005CACA8C134324640BDA8DDAF02684B405CACA8C134324640B7F0BC546C6A4B4022179CC1DF354640B7F0BC546C6A4B4022179CC1DF354640BDA8DDAF02684B405CACA8C134324640BDA8DDAF02684B40
16922	25769	44.717945999999998	44.749217000000002	55.009048	54.996268000000001	Советская	0103000020E61000000100000005000000A2258FA7E55B46409206B7B5857F4B40A2258FA7E55B46400F0C207C28814B40BA4DB857E65F46400F0C207C28814B40BA4DB857E65F46409206B7B5857F4B40A2258FA7E55B46409206B7B5857F4B40
19445	25152	44.387940999999998	44.432443999999997	55.138274000000003	55.118879	Западная	0103000020E6100000010000000500000086E3F90CA83146403197546D378F4B4086E3F90CA83146408DF161F6B2914B40FBAC32535A3746408DF161F6B2914B40FBAC32535A3746403197546D378F4B4086E3F90CA83146403197546D378F4B40
19465	50031	44.527377999999999	44.555737000000001	54.915373000000002	54.903168999999998	Новикова	0103000020E61000000100000005000000A0504F1F8143464069E1B20A9B734B40A0504F1F814346401A5245F12A754B40AD16D863224746401A5245F12A754B40AD16D8632247464069E1B20A9B734B40A0504F1F8143464069E1B20A9B734B40
16765	25886	44.914866000000004	44.943046000000002	55.005867000000002	54.995838999999997	Заречная	0103000020E61000000100000005000000761C3F541A754640698A00A7777F4B40761C3F541A7546401590F63FC0804B40D34F38BBB57846401590F63FC0804B40D34F38BBB5784640698A00A7777F4B40761C3F541A754640698A00A7777F4B40
17676	23883	44.436422999999998	44.515276999999998	55.047445000000003	55.021571000000002	площадь  Мира	0103000020E61000000100000005000000711C78B5DC37464061C5A9D6C2824B40711C78B5DC374640EBAD81AD12864B40C4B0C398F4414640EBAD81AD12864B40C4B0C398F441464061C5A9D6C2824B40711C78B5DC37464061C5A9D6C2824B40
17679	23883	44.436422999999998	44.515276999999998	55.047445000000003	55.021571000000002	Микрорайон №1	0103000020E61000000100000005000000711C78B5DC37464061C5A9D6C2824B40711C78B5DC374640EBAD81AD12864B40C4B0C398F4414640EBAD81AD12864B40C4B0C398F441464061C5A9D6C2824B40711C78B5DC37464061C5A9D6C2824B40
17758	23883	44.436422999999998	44.515276999999998	55.047445000000003	55.021571000000002	Кирова	0103000020E61000000100000005000000711C78B5DC37464061C5A9D6C2824B40711C78B5DC374640EBAD81AD12864B40C4B0C398F4414640EBAD81AD12864B40C4B0C398F441464061C5A9D6C2824B40711C78B5DC37464061C5A9D6C2824B40
17490	24277	44.439585000000001	44.477440000000001	55.030890999999997	55.011308999999997	Державина	0103000020E61000000100000005000000F5673F52443846404293C49272814B40F5673F5244384640D05E7D3CF4834B40B0E600C11C3D4640D05E7D3CF4834B40B0E600C11C3D46404293C49272814B40F5673F52443846404293C49272814B40
17511	25900	44.846082000000003	44.873902999999999	54.964204000000002	54.954931000000002	Лесная	0103000020E61000000100000005000000FDDD3B6A4C6C4640E277D32D3B7A4B40FDDD3B6A4C6C4640115663096B7B4B402A70B20DDC6F4640115663096B7B4B402A70B20DDC6F4640E277D32D3B7A4B40FDDD3B6A4C6C4640E277D32D3B7A4B40
17127	17483	44.261701000000002	44.320602999999998	54.906559000000001	54.876852999999997	Школьная	0103000020E610000001000000050000004E2A1A6B7F214640223317B83C704B404E2A1A6B7F2146407E7214200A744B40EFFFE384092946407E7214200A744B40EFFFE38409294640223317B83C704B404E2A1A6B7F214640223317B83C704B40
17688	24368	44.362392999999997	44.400849999999998	55.008924	54.981375999999997	пл.Победы	0103000020E6100000010000000500000050A6D1E4622E4640268A90BA9D7D4B4050A6D1E4622E46402313F06B24814B40014D840D4F3346402313F06B24814B40014D840D4F334640268A90BA9D7D4B4050A6D1E4622E4640268A90BA9D7D4B40
17122	25830	44.811335	44.852074000000002	55.004483999999998	54.987121000000002	Советская	0103000020E61000000100000005000000D28C45D3D9674640F0181EFB597E4B40D28C45D3D967464079AD84EE92804B40CEE2C5C2106D464079AD84EE92804B40CEE2C5C2106D4640F0181EFB597E4B40D28C45D3D9674640F0181EFB597E4B40
17504	25587	44.708945	44.727027999999997	55.074117999999999	55.060085000000001	Зеленая	0103000020E61000000100000005000000D4D4B2B5BE5A464076FD82DDB0874B40D4D4B2B5BE5A4640C005D9B27C894B405DA3E5400F5D4640C005D9B27C894B405DA3E5400F5D464076FD82DDB0874B40D4D4B2B5BE5A464076FD82DDB0874B40
17655	24574	44.460067000000002	44.503069000000004	54.880727999999998	54.866342000000003	1-Мая	0103000020E61000000100000005000000037CB779E33A46405C936E4BE46E4B40037CB779E33A4640F355F2B1BB704B40D350A39064404640F355F2B1BB704B40D350A390644046405C936E4BE46E4B40037CB779E33A46405C936E4BE46E4B40
17729	25376	44.535705	44.568547000000002	55.164721	55.148915000000002	Чкалова	0103000020E61000000100000005000000DFA63FFB9144464022718FA50F934B40DFA63FFB9144464072FBE59315954B40959EE925C648464072FBE59315954B40959EE925C648464022718FA50F934B40DFA63FFB9144464022718FA50F934B40
18507	26021	44.909331999999999	44.951875999999999	55.044454000000002	55.022385999999997	Советская	0103000020E61000000100000005000000679AB0FD64744640B2F1608BDD824B40679AB0FD6474464094162EABB0854B4074ECA012D779464094162EABB0854B4074ECA012D7794640B2F1608BDD824B40679AB0FD64744640B2F1608BDD824B40
19518	50045	44.483072999999997	44.515574000000001	55.0169	54.995519000000002	Колхозная	0103000020E61000000100000005000000514A0856D53D4640F8C5A52A6D7F4B40514A0856D53D4640B5A679C729824B407E552E54FE414640B5A679C729824B407E552E54FE414640F8C5A52A6D7F4B40514A0856D53D4640F8C5A52A6D7F4B40
16763	25483	44.615358999999998	44.681024999999998	55.074437000000003	55.051644000000003	Сластяева	0103000020E610000001000000050000004E266E15C44E46406F8445459C864B404E266E15C44E4640624ED02687894B401361C3D32B574640624ED02687894B401361C3D32B5746406F8445459C864B404E266E15C44E46406F8445459C864B40
16686	23303	42.694284000000003	42.721431000000003	55.412911999999999	55.402858000000002	Школьная	0103000020E610000001000000050000006B11514CDE5845404B77D7D990B34B406B11514CDE5845401F10E84CDAB44B4009A9DBD9575C45401F10E84CDAB44B4009A9DBD9575C45404B77D7D990B34B406B11514CDE5845404B77D7D990B34B40
17036	17593	42.289827000000002	42.341202000000003	55.471530999999999	55.442546	Революции	0103000020E61000000100000005000000B83F170D19254540E17CEA58A5B84B40B83F170D192545406C06B8205BBC4B4037AAD381AC2B45406C06B8205BBC4B4037AAD381AC2B4540E17CEA58A5B84B40B83F170D19254540E17CEA58A5B84B40
17083	17555	42.564594999999997	42.577243000000003	55.448816000000001	55.438042000000003	Рабочая	0103000020E61000000100000005000000183E22A6444845402123A0C211B84B40183E22A644484540F5F57CCD72B94B40276C3F19E3494540F5F57CCD72B94B40276C3F19E34945402123A0C211B84B40183E22A6444845402123A0C211B84B40
17638	17715	42.772609000000003	42.810886000000004	55.428525999999998	55.411158999999998	Школьная	0103000020E6100000010000000500000032CC09DAE4624540603AADDBA0B44B4032CC09DAE46245402BBEA1F0D9B64B406364C91CCB6745402BBEA1F0D9B64B406364C91CCB674540603AADDBA0B44B4032CC09DAE4624540603AADDBA0B44B40
80901	49765	42.219794	43.078898000000002	55.508293999999999	55.157598	Некрасова	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
17247	49765	42.219794	43.078898000000002	55.508293999999999	55.157598	Адмирала Макарова	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
17022	49731	42.219794	43.078898000000002	55.508293999999999	55.157598	Циолковского	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
17198	49731	42.219794	43.078898000000002	55.508293999999999	55.157598	Степана Разина	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
17641	49731	42.219794	43.078898000000002	55.508293999999999	55.157598	Догадина	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
19792	16722	43.005811000000001	43.055722000000003	55.402622999999998	55.385986000000003	площадь Свободы	0103000020E61000000100000005000000817A336ABE804540605B3FFD67B14B40817A336ABE80454007CF842689B34B4078D503E62187454007CF842689B34B4078D503E621874540605B3FFD67B14B40817A336ABE804540605B3FFD67B14B40
16704	16722	43.005811000000001	43.055722000000003	55.402622999999998	55.385986000000003	Ленина	0103000020E61000000100000005000000817A336ABE804540605B3FFD67B14B40817A336ABE80454007CF842689B34B4078D503E62187454007CF842689B34B4078D503E621874540605B3FFD67B14B40817A336ABE804540605B3FFD67B14B40
17509	16722	43.005811000000001	43.055722000000003	55.402622999999998	55.385986000000003	Гагарина	0103000020E61000000100000005000000817A336ABE804540605B3FFD67B14B40817A336ABE80454007CF842689B34B4078D503E62187454007CF842689B34B4078D503E621874540605B3FFD67B14B40817A336ABE804540605B3FFD67B14B40
18034	23574	42.406258000000001	42.432775999999997	55.345002000000001	55.327356999999999	Первомайская	0103000020E6100000010000000500000083DE1B4300344540EF8E8CD5E6A94B4083DE1B4300344540FD86890629AC4B40313F373465374540FD86890629AC4B40313F373465374540EF8E8CD5E6A94B4083DE1B4300344540EF8E8CD5E6A94B40
16823	23574	42.406258000000001	42.432775999999997	55.345002000000001	55.327356999999999	 Первомайская	0103000020E6100000010000000500000083DE1B4300344540EF8E8CD5E6A94B4083DE1B4300344540FD86890629AC4B40313F373465374540FD86890629AC4B40313F373465374540EF8E8CD5E6A94B4083DE1B4300344540EF8E8CD5E6A94B40
19405	50018	42.219794	43.078898000000002	55.508293999999999	55.157598	Футбольная 	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
17873	21520	44.151594000000003	44.185057	56.035702999999998	56.016325000000002	Школьная	0103000020E610000001000000050000008A22A46E67134640B98D06F016024C408A22A46E671346403EAF78EA91044C40AC72A1F2AF1746403EAF78EA91044C40AC72A1F2AF174640B98D06F016024C408A22A46E67134640B98D06F016024C40
17234	22101	44.450023999999999	44.472751000000002	55.969577000000001	55.959344000000002	Молькова	0103000020E610000001000000050000002235ED629A39464092CEC0C8CBFA4B402235ED629A39464016FA60191BFC4B405E13D21A833C464016FA60191BFC4B405E13D21A833C464092CEC0C8CBFA4B402235ED629A39464092CEC0C8CBFA4B40
17237	49764	44.450023999999999	44.472751000000002	55.969577000000001	55.959344000000002	Молькова	0103000020E610000001000000050000002235ED629A39464092CEC0C8CBFA4B402235ED629A39464016FA60191BFC4B405E13D21A833C464016FA60191BFC4B405E13D21A833C464092CEC0C8CBFA4B402235ED629A39464092CEC0C8CBFA4B40
16776	9450	44.217027999999999	44.262383999999997	56.127637999999997	56.114213999999997	Ленина	0103000020E610000001000000050000007C28D192C71B4640675F79909E0E4C407C28D192C71B464009DD257156104C40307F85CC9521464009DD257156104C40307F85CC95214640675F79909E0E4C407C28D192C71B4640675F79909E0E4C40
19457	13037	44.326352999999997	44.348863999999999	56.125691000000003	56.115434	Школьная	0103000020E61000000100000005000000CAF962EFC5294640596C938AC60E4C40CAF962EFC5294640663387A416104C4039605793A72C4640663387A416104C4039605793A72C4640596C938AC60E4C40CAF962EFC5294640596C938AC60E4C40
19486	50036	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	Талалушкина	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
17474	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	площадь Мира	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
19471	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	площадь Ленина	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
19615	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	бульвар Мира	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
19403	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	Чванова	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
19766	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	Советская	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
17586	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	Лукерьинская	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
19532	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	Зеленая	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
16908	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	Береговая	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
17079	49700	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	2 микрорайон	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
16936	21219	44.249294999999996	44.274034999999998	56.162726999999997	56.152118999999999	Центральная	0103000020E61000000100000005000000350708E6E81F4640D40CA9A278134C40350708E6E81F46408D96033DD4144C40CC7A3194132346408D96033DD4144C40CC7A319413234640D40CA9A278134C40350708E6E81F4640D40CA9A278134C40
17832	20407	44.094830000000002	44.116219000000001	56.220168000000001	56.200432999999997	Зеленая	0103000020E610000001000000050000000057B263230C46400305DEC9A7194C400057B263230C464018D00B772E1C4C404016A243E00E464018D00B772E1C4C404016A243E00E46400305DEC9A7194C400057B263230C46400305DEC9A7194C40
16952	49715	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	Широкая	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
17611	21980	44.560336999999997	44.584403000000002	56.053019999999997	56.043728999999999	Центральная	0103000020E610000001000000050000008FDE701FB9474640827170E998054C408FDE701FB94746405704FF5BC9064C409757AEB7CD4A46405704FF5BC9064C409757AEB7CD4A4640827170E998054C408FDE701FB9474640827170E998054C40
16741	21393	44.288119999999999	44.311971	56.110897000000001	56.097667999999999	Магистральная	0103000020E6100000010000000500000069A9BC1DE1244640D0EE9062800C4C4069A9BC1DE1244640BD1C76DF310E4C4074266DAAEE274640BD1C76DF310E4C4074266DAAEE274640D0EE9062800C4C4069A9BC1DE1244640D0EE9062800C4C40
17212	12964	44.225138999999999	44.247346	56.161233000000003	56.145806	Школьная	0103000020E61000000100000005000000EE06D15AD11C4640C1C760C5A9124C40EE06D15AD11C46409B046F48A3144C40F165A208A91F46409B046F48A3144C40F165A208A91F4640C1C760C5A9124C40EE06D15AD11C4640C1C760C5A9124C40
17536	49807	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	площадь Жданова	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
19499	50042	43.922722	43.942449000000003	56.187331	56.186127999999997	Центральная	0103000020E610000001000000050000005DA626C11BF64540586FD40AD3174C405DA626C11BF6454074435376FA174C40EF92382BA2F8454074435376FA174C40EF92382BA2F84540586FD40AD3174C405DA626C11BF64540586FD40AD3174C40
17203	21118	44.32461	44.365178	56.154946000000002	56.135899999999999	Веры Архангельской	0103000020E610000001000000050000002FFA0AD28C29464061C3D32B65114C402FFA0AD28C294640B1524145D5134C40FE9B1727BE2E4640B1524145D5134C40FE9B1727BE2E464061C3D32B65114C402FFA0AD28C29464061C3D32B65114C40
19467	49649	44.089044999999999	44.097048999999998	56.270591000000003	56.255077	Магистральная	0103000020E61000000100000005000000A86F99D3650B46401C7BF65CA6204C40A86F99D3650B4640C5CBD3B9A2224C40048E041A6C0C4640C5CBD3B9A2224C40048E041A6C0C46401C7BF65CA6204C40A86F99D3650B46401C7BF65CA6204C40
18000	18890	45.707962000000002	45.749319999999997	55.340142999999998	55.320574999999998	Школьная	0103000020E61000000100000005000000C767B27F9EDA46402575029A08A94B40C767B27F9EDA46404E7B4ACE89AB4B408E1EBFB7E9DF46404E7B4ACE89AB4B408E1EBFB7E9DF46402575029A08A94B40C767B27F9EDA46402575029A08A94B40
17751	18518	45.60134	45.635773	55.410238999999997	55.391553999999999	Кооперативная	0103000020E6100000010000000500000069E388B5F8CC46401A4F04711EB24B4069E388B5F8CC4640994528B682B44B400457790261D14640994528B682B44B400457790261D146401A4F04711EB24B4069E388B5F8CC46401A4F04711EB24B40
19515	50048	45.497163	45.524633000000001	55.414991000000001	55.408700000000003	Центральная	0103000020E6100000010000000500000000E48409A3BF464007F0164850B44B4000E48409A3BF46403291D26C1EB54B4081B3942C27C346403291D26C1EB54B4081B3942C27C3464007F0164850B44B4000E48409A3BF464007F0164850B44B40
17464	18405	45.581578	45.608463999999998	55.457887999999997	55.444941	Ленина	0103000020E610000001000000050000005B09DD2571CA464024D3A1D3F3B84B405B09DD2571CA46408C9DF0129CBA4B408C65FA25E2CD46408C9DF0129CBA4B408C65FA25E2CD464024D3A1D3F3B84B405B09DD2571CA464024D3A1D3F3B84B40
19738	50076	45.461903999999997	45.510350000000003	55.267342999999997	55.239485999999999	 1 Мая	0103000020E610000001000000050000001FF296AB1FBB4640C8EC2C7AA79E4B401FF296AB1FBB464042E8A04B38A24B40BEC1172653C1464042E8A04B38A24B40BEC1172653C14640C8EC2C7AA79E4B401FF296AB1FBB4640C8EC2C7AA79E4B40
17359	18432	45.557268999999998	45.585709999999999	55.474775999999999	55.456632999999997	Кооператвная	0103000020E610000001000000050000008D09319754C746401EA33CF372BA4B408D09319754C746407D76C075C5BC4B405778978BF8CA46407D76C075C5BC4B405778978BF8CA46401EA33CF372BA4B408D09319754C746401EA33CF372BA4B40
18560	18771	45.680545000000002	45.702337999999997	55.454110999999997	55.442464000000001	Колхозная	0103000020E61000000100000005000000693A3B191CD7464024D40CA9A2B84B40693A3B191CD746407EE02A4F20BA4B40785E2A36E6D946407EE02A4F20BA4B40785E2A36E6D9464024D40CA9A2B84B40693A3B191CD7464024D40CA9A2B84B40
18534	18302	45.482070999999998	45.499336999999997	55.157217000000003	55.145544999999998	Центральная	0103000020E61000000100000005000000CDACA580B4BD4640548CF337A1924B40CDACA580B4BD464008B0C8AF1F944B4064575A46EABF464008B0C8AF1F944B4064575A46EABF4640548CF337A1924B40CDACA580B4BD4640548CF337A1924B40
17018	49729	45.650540999999997	45.70382	55.308818000000002	55.286568000000003	Ленина	0103000020E6100000010000000500000083DA6FED44D34640420A9E42AEA44B4083DA6FED44D346404435255987A74B40A72215C616DA46404435255987A74B40A72215C616DA4640420A9E42AEA44B4083DA6FED44D34640420A9E42AEA44B40
17177	49759	45.214499000000004	45.849491	55.479995000000002	55.086233999999997	Школьная	0103000020E610000001000000050000002A0307B4749B4640D1E638B7098B4B402A0307B4749B46402C9FE57970BD4B40889FFF1EBCEC46402C9FE57970BD4B40889FFF1EBCEC4640D1E638B7098B4B402A0307B4749B4640D1E638B7098B4B40
17645	17962	45.413494	45.428280000000001	55.226517999999999	55.216448	Молодежная	0103000020E61000000100000005000000CE8B135FEDB446406EA46C91B49B4B40CE8B135FEDB4464048FAB48AFE9C4B40F4C308E1D1B6464048FAB48AFE9C4B40F4C308E1D1B646406EA46C91B49B4B40CE8B135FEDB446406EA46C91B49B4B40
19494	50041	45.603631	45.619126999999999	55.426059000000002	55.418078000000001	Школьная	0103000020E6100000010000000500000007EDD5C743CD4640AB96749483B54B4007EDD5C743CD46404F95EF1989B64B400989B48D3FCF46404F95EF1989B64B400989B48D3FCF4640AB96749483B54B4007EDD5C743CD4640AB96749483B54B40
17156	18702	45.566270000000003	45.586796999999997	55.396458000000003	55.388384000000002	Советская	0103000020E610000001000000050000005C5A0D897BC8464014252191B6B14B405C5A0D897BC84640691EC022BFB24B400932022A1CCB4640691EC022BFB24B400932022A1CCB464014252191B6B14B405C5A0D897BC8464014252191B6B14B40
17060	17899	45.473717000000001	45.500594	55.222965000000002	55.206600999999999	Гавриловка	0103000020E61000000100000005000000954737C2A2BC46401329CDE6719A4B40954737C2A2BC46408A93FB1D8A9C4B407349D57613C046408A93FB1D8A9C4B407349D57613C046401329CDE6719A4B40954737C2A2BC46401329CDE6719A4B40
16919	17804	45.375486000000002	45.39188	55.324724000000003	55.306224999999998	Советская	0103000020E610000001000000050000008D0DDDEC0FB04640DA1B7C6132A74B408D0DDDEC0FB04640F81C588E90A94B406EFAB31F29B24640F81C588E90A94B406EFAB31F29B24640DA1B7C6132A74B408D0DDDEC0FB04640DA1B7C6132A74B40
16709	17717	45.401789000000001	45.423248999999998	55.420729999999999	55.407555000000002	Центральная	0103000020E610000001000000050000003F726BD26DB34640202922C32AB44B403F726BD26DB3464019390B7BDAB54B404888F2052DB6464019390B7BDAB54B404888F2052DB64640202922C32AB44B403F726BD26DB34640202922C32AB44B40
17460	18310	45.555796000000001	45.579313999999997	55.156441000000001	55.13937	Центральная	0103000020E61000000100000005000000B29FC55224C7464092054CE0D6914B40B29FC55224C746407460394206944B40B60E0EF626CA46407460394206944B40B60E0EF626CA464092054CE0D6914B40B29FC55224C7464092054CE0D6914B40
16769	17652	45.440334999999997	45.476951	55.38552	55.372042999999998	Школьная	0103000020E610000001000000050000005F24B4E55CB8464055DAE21A9FAF4B405F24B4E55CB846401AFA27B858B14B40B265F9BA0CBD46401AFA27B858B14B40B265F9BA0CBD464055DAE21A9FAF4B405F24B4E55CB8464055DAE21A9FAF4B40
16842	17559	45.752670999999999	45.803497	55.418706	55.402945000000003	Колхозная	0103000020E61000000100000005000000E5D2F88557E046401A8BA6B393B34B40E5D2F88557E04640CA51802898B54B4091B75CFDD8E64640CA51802898B54B4091B75CFDD8E646401A8BA6B393B34B40E5D2F88557E046401A8BA6B393B34B40
18551	18677	45.586526999999997	45.613728000000002	55.418700999999999	55.408290999999998	Кооперативная	0103000020E61000000100000005000000499C155113CB4640252026E142B44B40499C155113CB4640B8E68EFE97B54B40DB519CA38ECE4640B8E68EFE97B54B40DB519CA38ECE4640252026E142B44B40499C155113CB4640252026E142B44B40
18411	17438	45.269241999999998	45.295023999999998	55.220720999999998	55.207433000000002	Северная	0103000020E61000000100000005000000D55A988576A246403B8E1F2A8D9A4B40D55A988576A246402C45F295409C4B407EC4AF58C3A546402C45F295409C4B407EC4AF58C3A546403B8E1F2A8D9A4B40D55A988576A246403B8E1F2A8D9A4B40
19480	50035	45.371174000000003	45.391593	55.194347	55.183117000000003	Колхозная	0103000020E6100000010000000500000011902FA182AF4640BB2BBB6070974B4011902FA182AF4640B189CC5CE0984B40D82B2CB81FB24640B189CC5CE0984B40D82B2CB81FB24640BB2BBB6070974B4011902FA182AF4640BB2BBB6070974B40
18543	18546	45.624004999999997	45.648637000000001	55.381807000000002	55.369233999999999	Школьная	0103000020E610000001000000050000002EC55565DFCF46401F49490F43AF4B402EC55565DFCF46402331410DDFB04B40DFFC868906D346402331410DDFB04B40DFFC868906D346401F49490F43AF4B402EC55565DFCF46401F49490F43AF4B40
17334	17281	45.357968999999997	45.402453000000001	57.310558	57.289099	Сельсоветская	0103000020E61000000100000005000000ACFD9DEDD1AD464035272F3201A54C40ACFD9DEDD1AD46406EC1525DC0A74C40AB96749483B346406EC1525DC0A74C40AB96749483B3464035272F3201A54C40ACFD9DEDD1AD464035272F3201A54C40
17714	17281	45.357968999999997	45.402453000000001	57.310558	57.289099	Свободы	0103000020E61000000100000005000000ACFD9DEDD1AD464035272F3201A54C40ACFD9DEDD1AD46406EC1525DC0A74C40AB96749483B346406EC1525DC0A74C40AB96749483B3464035272F3201A54C40ACFD9DEDD1AD464035272F3201A54C40
17000	17028	44.989336000000002	45.011910999999998	57.237454999999997	57.225543999999999	Школьная	0103000020E61000000100000005000000B360E28FA27E46408EE733A0DE9C4C40B360E28FA27E4640C6A2E9EC649E4C4038BBB54C86814640C6A2E9EC649E4C4038BBB54C868146408EE733A0DE9C4C40B360E28FA27E46408EE733A0DE9C4C40
16766	17096	45.146568000000002	45.171028999999997	57.108984999999997	57.098401000000003	Новая	0103000020E61000000100000005000000F0517FBDC292464065726A67988C4C40F0517FBDC292464095607138F38D4C4073D53C47E495464095607138F38D4C4073D53C47E495464065726A67988C4C40F0517FBDC292464065726A67988C4C40
19595	50067	44.778412000000003	44.790961000000003	57.200935000000001	57.192894000000003	Центральная	0103000020E6100000010000000500000030682101A36346401DCC26C0B0984C4030682101A363464096CFF23CB8994C40ABB4C5353E65464096CFF23CB8994C40ABB4C5353E6546401DCC26C0B0984C4030682101A36346401DCC26C0B0984C40
17082	17247	45.560934000000003	45.597352000000001	57.248618	57.232224000000002	Молодежная	0103000020E61000000100000005000000749B70AFCCC7464054AC1A84B99D4C40749B70AFCCC746403599F1B6D29F4C40A019C40776CC46403599F1B6D29F4C40A019C40776CC464054AC1A84B99D4C40749B70AFCCC7464054AC1A84B99D4C40
17322	16425	45.119340000000001	45.175764000000001	57.143478000000002	57.112034999999999	имени Чкалова	0103000020E61000000100000005000000658D7A88468F4640F180B229578E4C40658D7A88468F464006D9B27C5D924C4036E84B6F7F96464006D9B27C5D924C4036E84B6F7F964640F180B229578E4C40658D7A88468F4640F180B229578E4C40
17705	16425	45.119340000000001	45.175764000000001	57.143478000000002	57.112034999999999	им.Синявина	0103000020E61000000100000005000000658D7A88468F4640F180B229578E4C40658D7A88468F464006D9B27C5D924C4036E84B6F7F96464006D9B27C5D924C4036E84B6F7F964640F180B229578E4C40658D7A88468F4640F180B229578E4C40
17121	16425	45.119340000000001	45.175764000000001	57.143478000000002	57.112034999999999	 имени Мичурина	0103000020E61000000100000005000000658D7A88468F4640F180B229578E4C40658D7A88468F464006D9B27C5D924C4036E84B6F7F96464006D9B27C5D924C4036E84B6F7F964640F180B229578E4C40658D7A88468F4640F180B229578E4C40
17717	17187	45.415469999999999	45.447845000000001	57.128571000000001	57.106693	имени генерала Тихомирова	0103000020E610000001000000050000000C3CF71E2EB5464027DBC01DA88D4C400C3CF71E2EB54640651BB80375904C40AC5626FC52B94640651BB80375904C40AC5626FC52B9464027DBC01DA88D4C400C3CF71E2EB5464027DBC01DA88D4C40
19586	50060	44.689497000000003	45.912697000000001	57.380299000000001	56.904299999999999	Береговая 	0103000020E6100000010000000500000056D80C7041584640EBE2361AC0734C4056D80C7041584640CBD93BA3ADB04C4023145B41D3F44640CBD93BA3ADB04C4023145B41D3F44640EBE2361AC0734C4056D80C7041584640EBE2361AC0734C40
17519	16862	45.099837999999998	45.111722999999998	57.196663000000001	57.188786999999998	Молодежная	0103000020E61000000100000005000000F372D87DC78C46407974232C2A984C40F372D87DC78C4640A8AAD0402C994C40029B73F04C8E4640A8AAD0402C994C40029B73F04C8E46407974232C2A984C40F372D87DC78C46407974232C2A984C40
17128	16723	45.097079999999998	45.160600000000002	57.183197	57.156177	им.Чкалова	0103000020E610000001000000050000003F8C101E6D8C464096B1A19BFD934C403F8C101E6D8C4640D7DCD1FF72974C406ADE718A8E944640D7DCD1FF72974C406ADE718A8E94464096B1A19BFD934C403F8C101E6D8C464096B1A19BFD934C40
16750	16723	45.097079999999998	45.160600000000002	57.183197	57.156177	Фестивальная	0103000020E610000001000000050000003F8C101E6D8C464096B1A19BFD934C403F8C101E6D8C4640D7DCD1FF72974C406ADE718A8E944640D7DCD1FF72974C406ADE718A8E94464096B1A19BFD934C403F8C101E6D8C464096B1A19BFD934C40
17131	17151	45.241565000000001	45.413556999999997	57.251038000000001	57.223205	Центральная	0103000020E61000000100000005000000DB6D179AEB9E4640DFA63FFB919C4C40DB6D179AEB9E4640D106600322A04C4014048F6FEFB44640D106600322A04C4014048F6FEFB44640DFA63FFB919C4C40DB6D179AEB9E4640DFA63FFB919C4C40
16844	15826	43.557834999999997	43.579188000000002	57.174551999999998	57.162162000000002	Сельская	0103000020E6100000010000000500000036C8242367C74540B55373B9C1944C4036C8242367C74540C7B94DB857964C402A1E17D522CA4540C7B94DB857964C402A1E17D522CA4540B55373B9C1944C4036C8242367C74540B55373B9C1944C40
17411	16107	43.881309000000002	43.911304000000001	56.980007999999998	56.961137999999998	Центральная	0103000020E61000000100000005000000D255BABBCEF04540AF78EA91067B4C40D255BABBCEF04540C0E8F2E6707D4C40645B069CA5F44540C0E8F2E6707D4C40645B069CA5F44540AF78EA91067B4C40D255BABBCEF04540AF78EA91067B4C40
16994	15980	43.769190999999999	43.792295000000003	57.030234999999998	57.009763999999997	Юбилейная	0103000020E6100000010000000500000053B0C6D974E24540CD565EF23F814C4053B0C6D974E24540E71890BDDE834C4065E42CEC69E54540E71890BDDE834C4065E42CEC69E54540CD565EF23F814C4053B0C6D974E24540CD565EF23F814C40
17833	16036	43.774940000000001	43.799903999999998	56.954988999999998	56.941012000000001	Центральная	0103000020E610000001000000050000005E2EE23B31E345406092CA1473784C405E2EE23B31E3454016855D143D7A4C4044F8174163E6454016855D143D7A4C4044F8174163E645406092CA1473784C405E2EE23B31E345406092CA1473784C40
19475	49745	43.901144000000002	43.908852000000003	57.284410000000001	57.277137000000003	Октябрьская	0103000020E610000001000000050000004A7EC4AF58F345407BC1A73979A34C404A7EC4AF58F34540E353008C67A44C40BD73284355F44540E353008C67A44C40BD73284355F445407BC1A73979A34C404A7EC4AF58F345407BC1A73979A34C40
18196	15529	43.793228999999997	43.869514000000002	57.142462000000002	57.110657000000003	пер. Рабочий	0103000020E61000000100000005000000909E228788E54540680932022A8E4C40909E228788E545401D76DF313C924C4003B5183C4CEF45401D76DF313C924C4003B5183C4CEF4540680932022A8E4C40909E228788E54540680932022A8E4C40
16832	15529	43.793228999999997	43.869514000000002	57.142462000000002	57.110657000000003	Карла Маркса	0103000020E61000000100000005000000909E228788E54540680932022A8E4C40909E228788E545401D76DF313C924C4003B5183C4CEF45401D76DF313C924C4003B5183C4CEF4540680932022A8E4C40909E228788E54540680932022A8E4C40
16921	15956	43.907513000000002	43.920098000000003	57.055061000000002	57.045858000000003	Заречная	0103000020E61000000100000005000000F1D8CF6229F445404721C9ACDE854C40F1D8CF6229F445407D24253D0C874C40B98E71C5C5F545407D24253D0C874C40B98E71C5C5F545404721C9ACDE854C40F1D8CF6229F445404721C9ACDE854C40
17505	16274	44.192053999999999	44.226433	57.238760999999997	57.221314999999997	Медведева	0103000020E610000001000000050000007288B839951846409F8EC70C549C4C407288B83995184640B6476FB88F9E4C401ADEACC1FB1C4640B6476FB88F9E4C401ADEACC1FB1C46409F8EC70C549C4C407288B839951846409F8EC70C549C4C40
17529	49806	43.767699	43.791460000000001	57.096269999999997	57.081592999999998	Садовая	0103000020E610000001000000050000000116F9F543E24540904AB1A3718A4C400116F9F543E24540FFCA4A93528C4C40CC0BB08F4EE54540FFCA4A93528C4C40CC0BB08F4EE54540904AB1A3718A4C400116F9F543E24540904AB1A3718A4C40
17510	15655	43.830922999999999	43.839177999999997	57.154331999999997	57.143785999999999	Северня	0103000020E61000000100000005000000423F53AF5BEA4540B3CF639467924C40423F53AF5BEA4540F65CA626C1934C40E7C2482F6AEB4540F65CA626C1934C40E7C2482F6AEB4540B3CF639467924C40423F53AF5BEA4540B3CF639467924C40
16839	15804	43.731928000000003	43.760710000000003	57.229368999999998	57.216261000000003	Молодежная	0103000020E610000001000000050000006B8313D1AFDD45403C33C170AE9B4C406B8313D1AFDD4540ADDBA0F65B9D4C40BEDEFDF15EE14540ADDBA0F65B9D4C40BEDEFDF15EE145403C33C170AE9B4C406B8313D1AFDD45403C33C170AE9B4C40
17706	15719	43.960765000000002	43.976467999999997	57.099497	57.094006	Молодежная	0103000020E610000001000000050000001B12F758FAFA45405BD07B63088C4C401B12F758FAFA45406A865451BC8C4C4096CB46E7FCFC45406A865451BC8C4C4096CB46E7FCFC45405BD07B63088C4C401B12F758FAFA45405BD07B63088C4C40
17507	16406	44.168078000000001	44.199779999999997	57.320751000000001	57.311962999999999	Школьная	0103000020E61000000100000005000000AB96749483154640F1475167EEA74C40AB967494831546406494675E0EA94C408B321B64921946406494675E0EA94C408B321B6492194640F1475167EEA74C40AB96749483154640F1475167EEA74C40
17078	15221	45.270527000000001	45.283920999999999	55.795737000000003	55.781717	Школьная	0103000020E61000000100000005000000AED7F4A0A0A2464016DD7A4D0FE44B40AED7F4A0A0A24640CC9BC3B5DAE54B40E5D2F88557A44640CC9BC3B5DAE54B40E5D2F88557A4464016DD7A4D0FE44B40AED7F4A0A0A2464016DD7A4D0FE44B40
17106	15373	45.220041999999999	45.257178000000003	55.731743999999999	55.709955999999998	Центральная	0103000020E610000001000000050000008BDF14562A9C4640ABCC94D6DFDA4B408BDF14562A9C4640A98592C9A9DD4B4017A06D35EBA04640A98592C9A9DD4B4017A06D35EBA04640ABCC94D6DFDA4B408BDF14562A9C4640ABCC94D6DFDA4B40
17166	15079	45.307806999999997	45.328476999999999	55.813566000000002	55.799917000000001	Советская	0103000020E610000001000000050000006C3D433866A74640D94125AE63E64B406C3D433866A746409B9141EE22E84B407D3ECA880BAA46409B9141EE22E84B407D3ECA880BAA4640D94125AE63E64B406C3D433866A74640D94125AE63E64B40
17497	15314	45.138924000000003	45.162882000000003	55.884216000000002	55.876308999999999	Садовая	0103000020E610000001000000050000009450FA42C89146406118B0E42AF04B409450FA42C8914640CB4C69FD2DF14B40B58D3F51D9944640CB4C69FD2DF14B40B58D3F51D99446406118B0E42AF04B409450FA42C89146406118B0E42AF04B40
17100	521	45.003548000000002	45.060392999999998	55.830123999999998	55.805861999999998	Свободы	0103000020E61000000100000005000000ADFBC74274804640698B6B7C26E74B40ADFBC74274804640F6CFD38041EA4B4023F433F5BA874640F6CFD38041EA4B4023F433F5BA874640698B6B7C26E74B40ADFBC74274804640698B6B7C26E74B40
17065	521	45.003548000000002	45.060392999999998	55.830123999999998	55.805861999999998	Октябрьская	0103000020E61000000100000005000000ADFBC74274804640698B6B7C26E74B40ADFBC74274804640F6CFD38041EA4B4023F433F5BA874640F6CFD38041EA4B4023F433F5BA874640698B6B7C26E74B40ADFBC74274804640698B6B7C26E74B40
17492	13152	45.140127	45.162765	55.756127999999997	55.745372000000003	Молодежная	0103000020E61000000100000005000000AF2479AEEF91464054AD855968DF4B40AF2479AEEF91464081CB63CDC8E04B407BF7C77BD594464081CB63CDC8E04B407BF7C77BD594464054AD855968DF4B40AF2479AEEF91464054AD855968DF4B40
16918	15033	45.255516	45.293128000000003	55.851256999999997	55.832721999999997	Малкина	0103000020E6100000010000000500000068CD8FBFB4A0464071546EA296EA4B4068CD8FBFB4A04640DBBE47FDF5EC4B405DC5E23785A54640DBBE47FDF5EC4B405DC5E23785A5464071546EA296EA4B4068CD8FBFB4A0464071546EA296EA4B40
19764	50078	43.245446000000001	43.268272000000003	55.003255000000003	54.991768999999998	Лесная	0103000020E610000001000000050000008E7747C66A9F4540E3175E49F27E4B408E7747C66A9F45403546EBA86A804B405D37A5BC56A245403546EBA86A804B405D37A5BC56A24540E3175E49F27E4B408E7747C66A9F4540E3175E49F27E4B40
17302	14540	43.437865000000002	43.483787	55.096367999999998	55.075535000000002	Молодежная	0103000020E610000001000000050000001288D7F50BB84540085A8121AB894B401288D7F50BB84540C23060C9558C4B406F9D7FBBECBD4540C23060C9558C4B406F9D7FBBECBD4540085A8121AB894B401288D7F50BB84540085A8121AB894B40
17294	14525	43.495733999999999	43.522306999999998	55.178789000000002	55.166943000000003	Молодежная	0103000020E61000000100000005000000F4C1323674BF4540E8A562635E954B40F4C1323674BF454039F1D58EE2964B4066BCADF4DAC2454039F1D58EE2964B4066BCADF4DAC24540E8A562635E954B40F4C1323674BF4540E8A562635E954B40
17087	14385	43.249065999999999	43.266278	55.023918999999999	55.012073000000001	Новая	0103000020E61000000100000005000000D4450A65E19F45401215AA9B8B814B40D4450A65E19F454063601DC70F834B4078D2C26515A2454063601DC70F834B4078D2C26515A245401215AA9B8B814B40D4450A65E19F45401215AA9B8B814B40
17287	14266	43.528270999999997	43.552463000000003	55.222856999999998	55.206626999999997	Школьная	0103000020E610000001000000050000006D3656629EC345403CBCE7C0729A4B406D3656629EC34540A3570394869C4B4002A08A1BB7C64540A3570394869C4B4002A08A1BB7C645403CBCE7C0729A4B406D3656629EC345403CBCE7C0729A4B40
16935	14190	43.343460999999998	43.368183000000002	55.118080999999997	55.102832999999997	Кооперативная	0103000020E61000000100000005000000C939B187F6AB45408BF9B9A1298D4B40C939B187F6AB4540B5A338471D8F4B40BAF8DB9E20AF4540B5A338471D8F4B40BAF8DB9E20AF45408BF9B9A1298D4B40C939B187F6AB45408BF9B9A1298D4B40
17086	14108	43.358525999999998	43.402624000000003	55.013399999999997	54.992203000000003	Новостройка	0103000020E610000001000000050000000262122EE4AD45401EFF0582007F4B400262122EE4AD454019E25817B7814B40D84AE82E89B3454019E25817B7814B40D84AE82E89B345401EFF0582007F4B400262122EE4AD45401EFF0582007F4B40
17465	13984	43.422863	43.451402000000002	55.164253000000002	55.14432	Микрорайон	0103000020E610000001000000050000001FD8F15F20B645405114E81379924B401FD8F15F20B645408CA2073E06954B40ACAC6D8AC7B945408CA2073E06954B40ACAC6D8AC7B945405114E81379924B401FD8F15F20B645405114E81379924B40
16815	13953	43.317633999999998	43.351132999999997	55.077623000000003	55.054639999999999	9 Мая	0103000020E61000000100000005000000800C1D3BA8A84540D7868A71FE864B40800C1D3BA8A845406E35EB8CEF894B40EFC517EDF1AC45406E35EB8CEF894B40EFC517EDF1AC4540D7868A71FE864B40800C1D3BA8A84540D7868A71FE864B40
17063	13789	43.216358	43.273949000000002	55.057088999999998	55.022447999999997	Октябрьская	0103000020E610000001000000050000002E1D739EB19B454028EE7893DF824B402E1D739EB19B45400DFB3DB14E874B40CEE2C5C210A345400DFB3DB14E874B40CEE2C5C210A3454028EE7893DF824B402E1D739EB19B454028EE7893DF824B40
16986	13744	43.516665000000003	43.550505000000001	55.121488999999997	55.098145000000002	Почтовая	0103000020E6100000010000000500000072FE261422C245400AA2EE03908C4B4072FE261422C2454070E998F38C8F4B406AA4A5F276C6454070E998F38C8F4B406AA4A5F276C645400AA2EE03908C4B4072FE261422C245400AA2EE03908C4B40
16683	13692	43.595410999999999	43.619917000000001	55.173878999999999	55.157710999999999	Советская	0103000020E61000000100000005000000DE567A6D36CC4540179CC1DF2F944B40DE567A6D36CC4540083BC5AA41964B40029EB47059CF4540083BC5AA41964B40029EB47059CF4540179CC1DF2F944B40DE567A6D36CC4540179CC1DF2F944B40
17531	13657	43.210079	43.252039000000003	55.099133999999999	55.084204	Центральная	0103000020E61000000100000005000000C74961DEE39A4540A0185932C78A4B40C74961DEE39A4540F9F5436CB08C4B4085285FD042A04540F9F5436CB08C4B4085285FD042A04540A0185932C78A4B40C74961DEE39A4540A0185932C78A4B40
19528	50051	43.732017999999997	43.734884000000001	56.262742000000003	56.254797000000003	улица Весенняя	0103000020E61000000100000005000000AA0A0DC4B2DD4540390F27309D204C40AA0A0DC4B2DD454090A4A487A1214C40452DCDAD10DE454090A4A487A1214C40452DCDAD10DE4540390F27309D204C40AA0A0DC4B2DD4540390F27309D204C40
17400	49789	43.328136000000001	43.373868999999999	56.321097000000002	56.288896000000001	Чкалова	0103000020E61000000100000005000000F451465C00AA4540FDF84B8BFA244C40F451465C00AA4540FFEBDCB419294C407EFE7BF0DAAF4540FFEBDCB419294C407EFE7BF0DAAF4540FDF84B8BFA244C40F451465C00AA4540FDF84B8BFA244C40
16956	49643	43.555822999999997	43.669297999999998	56.234720000000003	56.206901999999999	п. Петряевка	0103000020E61000000100000005000000ABAE433525C745400EBDC5C37B1A4C40ABAE433525C74540CBDB114E0B1E4C409CA38E8EABD54540CBDB114E0B1E4C409CA38E8EABD545400EBDC5C37B1A4C40ABAE433525C745400EBDC5C37B1A4C40
19718	49642	43.885503999999997	43.939152	55.777504999999998	55.741855000000001	Центральная	0103000020E61000000100000005000000143DF03158F14540E2AFC91AF5DE4B40143DF03158F14540FDBCA94885E34B408BFCFA2136F84540FDBCA94885E34B408BFCFA2136F84540E2AFC91AF5DE4B40143DF03158F14540E2AFC91AF5DE4B40
16775	49642	43.885503999999997	43.939152	55.777504999999998	55.741855000000001	М.Горького	0103000020E61000000100000005000000143DF03158F14540E2AFC91AF5DE4B40143DF03158F14540FDBCA94885E34B408BFCFA2136F84540FDBCA94885E34B408BFCFA2136F84540E2AFC91AF5DE4B40143DF03158F14540E2AFC91AF5DE4B40
18010	8587	44.008547	44.030698999999998	55.786445000000001	55.775621000000001	Шоссейная	0103000020E610000001000000050000004DBD6E1118014640A08B868C47E34B404DBD6E1118014640268DD13AAAE44B408C82E0F1ED034640268DD13AAAE44B408C82E0F1ED034640A08B868C47E34B404DBD6E1118014640A08B868C47E34B40
17654	8928	44.127249999999997	44.154181000000001	55.933422999999998	55.918343	Центральная	0103000020E610000001000000050000003F355EBA4910464059C16F438CF54B403F355EBA49104640C72AA5677AF74B401155F833BC134640C72AA5677AF74B401155F833BC13464059C16F438CF54B403F355EBA4910464059C16F438CF54B40
17074	8532	43.976754999999997	43.990876999999998	55.717055999999999	55.702494999999999	Шоссейная	0103000020E610000001000000050000002C9ACE4E06FD4540404D2D5BEBD94B402C9ACE4E06FD454046B3B27DC8DB4B40E6ADBA0ED5FE454046B3B27DC8DB4B40E6ADBA0ED5FE4540404D2D5BEBD94B402C9ACE4E06FD4540404D2D5BEBD94B40
17427	8609	44.303705999999998	44.323146000000001	55.781959999999998	55.768116999999997	Молодежная	0103000020E61000000100000005000000ABCC94D6DF264640354069A851E24B40ABCC94D6DF264640DC63E94317E44B40A7EA1ED95C294640DC63E94317E44B40A7EA1ED95C294640354069A851E24B40ABCC94D6DF264640354069A851E24B40
17742	9198	43.972515000000001	44.006596999999999	56.010896000000002	56.000407000000003	Ленина	0103000020E610000001000000050000004AEF1B5F7BFC454041D829560D004C404AEF1B5F7BFC454020D4450A65014C4038A0A52BD800464020D4450A65014C4038A0A52BD800464041D829560D004C404AEF1B5F7BFC454041D829560D004C40
16932	49710	43.972515000000001	44.006596999999999	56.010896000000002	56.000407000000003	50 лет Октября	0103000020E610000001000000050000004AEF1B5F7BFC454041D829560D004C404AEF1B5F7BFC454020D4450A65014C4038A0A52BD800464020D4450A65014C4038A0A52BD800464041D829560D004C404AEF1B5F7BFC454041D829560D004C40
17722	8708	44.195791	44.215276000000003	55.687984	55.670752	Новоселов	0103000020E61000000100000005000000F2ECF2AD0F19464001DD9733DBD54B40F2ECF2AD0F194640EC1516DC0FD84B408ECEF9298E1B4640EC1516DC0FD84B408ECEF9298E1B464001DD9733DBD54B40F2ECF2AD0F19464001DD9733DBD54B40
17469	8686	44.177619	44.198307	55.770603000000001	55.755139999999997	40 лет Победы	0103000020E61000000100000005000000F9122A38BC16464062F3716DA8E04B40F9122A38BC16464089997D1EA3E24B40B0C8AF1F6219464089997D1EA3E24B40B0C8AF1F6219464062F3716DA8E04B40F9122A38BC16464062F3716DA8E04B40
16716	9134	44.170234000000001	44.188138000000002	55.848179999999999	55.837024999999997	Молодежная	0103000020E6100000010000000500000069554B3ACA1546409A779CA223EB4B4069554B3ACA154640868F882991EC4B404391EEE714184640868F882991EC4B404391EEE7141846409A779CA223EB4B4069554B3ACA1546409A779CA223EB4B40
19507	9406	44.245181000000002	44.262805999999998	55.948577999999998	55.937244999999997	Центральная	0103000020E61000000100000005000000E04C4C17621F464075ABE7A4F7F74B40E04C4C17621F464040DAFF006BF94B40A69883A0A321464040DAFF006BF94B40A69883A0A321464075ABE7A4F7F74B40E04C4C17621F464075ABE7A4F7F74B40
17276	8308	44.072623	44.112059000000002	55.821036999999997	55.797544000000002	Советская	0103000020E61000000100000005000000FDF7E0B54B0946407E8FFAEB15E64B40FDF7E0B54B09464029E78BBD17E94B407A1C06F3570E464029E78BBD17E94B407A1C06F3570E46407E8FFAEB15E64B40FDF7E0B54B0946407E8FFAEB15E64B40
17223	8308	44.072623	44.112059000000002	55.821036999999997	55.797544000000002	Пионерская	0103000020E61000000100000005000000FDF7E0B54B0946407E8FFAEB15E64B40FDF7E0B54B09464029E78BBD17E94B407A1C06F3570E464029E78BBD17E94B407A1C06F3570E46407E8FFAEB15E64B40FDF7E0B54B0946407E8FFAEB15E64B40
17337	8308	44.072623	44.112059000000002	55.821036999999997	55.797544000000002	Молодежная	0103000020E61000000100000005000000FDF7E0B54B0946407E8FFAEB15E64B40FDF7E0B54B09464029E78BBD17E94B407A1C06F3570E464029E78BBD17E94B407A1C06F3570E46407E8FFAEB15E64B40FDF7E0B54B0946407E8FFAEB15E64B40
18539	9324	44.253301999999998	44.280079999999998	55.838282999999997	55.825178000000001	Центральная	0103000020E6100000010000000500000075012F336C20464079B0C56E9FE94B4075012F336C20464079E57ADB4CEB4B40C02154A9D923464079E57ADB4CEB4B40C02154A9D923464079B0C56E9FE94B4075012F336C20464079B0C56E9FE94B40
16931	8979	43.883465000000001	43.917977999999998	55.856129000000003	55.848467999999997	 Центральная	0103000020E610000001000000050000009014916115F14540ECD973999AEC4B409014916115F145401F1494A295ED4B404739984D80F545401F1494A295ED4B404739984D80F54540ECD973999AEC4B409014916115F14540ECD973999AEC4B40
17515	7583	43.390819999999998	43.424138999999997	56.725575999999997	56.709358999999999	Молодежная	0103000020E61000000100000005000000B54FC76306B24540C70F9546CC5A4C40B54FC76306B245409961A3ACDF5C4C40A4FACE2F4AB645409961A3ACDF5C4C40A4FACE2F4AB64540C70F9546CC5A4C40B54FC76306B24540C70F9546CC5A4C40
16996	7419	43.678083000000001	43.694163000000003	56.903455000000001	56.890338999999997	Школьная	0103000020E610000001000000050000009E7C7A6CCBD645403AADDBA0F6714C409E7C7A6CCBD645402F34D769A4734C40F08B4B55DAD845402F34D769A4734C40F08B4B55DAD845403AADDBA0F6714C409E7C7A6CCBD645403AADDBA0F6714C40
17196	7341	43.557699999999997	43.601376000000002	56.934033999999997	56.915942000000001	Мира	0103000020E61000000100000005000000567DAEB662C74540348463963D754C40567DAEB662C7454010AD156D8E774C40B64C86E3F9CC454010AD156D8E774C40B64C86E3F9CC4540348463963D754C40567DAEB662C74540348463963D754C40
19406	7844	43.568263999999999	43.574992999999999	56.706226000000001	56.703142999999997	проспект Ленина	0103000020E6100000010000000500000040BFEFDFBCC84540A6B4FE96005A4C4040BFEFDFBCC84540DECA129D655A4C40E736E15E99C94540DECA129D655A4C40E736E15E99C94540A6B4FE96005A4C4040BFEFDFBCC84540A6B4FE96005A4C40
17524	7700	43.553837000000001	43.568237000000003	56.762799000000001	56.751815000000001	Центральная	0103000020E610000001000000050000004A287D21E4C6454035D252793B604C404A287D21E4C64540F435CB65A3614C4047B071FDBBC84540F435CB65A3614C4047B071FDBBC8454035D252793B604C404A287D21E4C6454035D252793B604C40
17415	8091	43.820537999999999	43.848951999999997	56.545268999999998	56.534122000000004	Молодежная	0103000020E610000001000000050000000890A16307E945407D09151C5E444C400890A16307E94540E542E55FCB454C40D8EF8975AAEC4540E542E55FCB454C40D8EF8975AAEC45407D09151C5E444C400890A16307E945407D09151C5E444C40
17650	8167	43.864483999999997	43.887858000000001	56.478729999999999	56.469313999999997	Комсомольская	0103000020E6100000010000000500000027F56569A7EE454008C72C7B123C4C4027F56569A7EE45409ACE4E06473D4C40F9BEB854A5F145409ACE4E06473D4C40F9BEB854A5F1454008C72C7B123C4C4027F56569A7EE454008C72C7B123C4C40
16768	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	пр. Дзержинского	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
18109	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	Школьная	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
16971	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	Пушкина	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
17032	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	Пономарева	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
17875	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	Пирогова	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
18185	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	Молодежная	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
16764	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	Мичурина	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
18182	6492	43.343693999999999	43.433984000000002	56.651561999999998	56.617283999999998	Грунина	0103000020E610000001000000050000006CEA3C2AFEAB45400A2C8029034F4C406CEA3C2AFEAB45407EA8346266534C405F7EA7C98CB745407EA8346266534C405F7EA7C98CB745400A2C8029034F4C406CEA3C2AFEAB45400A2C8029034F4C40
17479	49802	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	пл. Ватутина	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
17687	49802	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	Кирова	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
17647	7414	43.609793000000003	43.647756000000001	56.865805999999999	56.852336999999999	Школьная	0103000020E61000000100000005000000352A70B20DCE4540DB15FA60196D4C40352A70B20DCE45401D5723BBD26E4C40D6E429ABE9D245401D5723BBD26E4C40D6E429ABE9D24540DB15FA60196D4C40352A70B20DCE4540DB15FA60196D4C40
17450	4541	44.945534000000002	44.965404999999997	55.330010000000001	55.314233000000002	Ленина	0103000020E61000000100000005000000C7A0134207794640782975C938A84B40C7A01342077946402EAD86C43DAA4B408B321B64927B46402EAD86C43DAA4B408B321B64927B4640782975C938A84B40C7A0134207794640782975C938A84B40
17925	3837	45.019573999999999	45.048068000000001	55.258833000000003	55.243730999999997	Школьная	0103000020E610000001000000050000000BED9C6681824640BC02D193329F4B400BED9C66818246401310937021A14B40F8FD9B17278646401310937021A14B40F8FD9B1727864640BC02D193329F4B400BED9C6681824640BC02D193329F4B40
17440	3922	45.028503000000001	45.049478000000001	55.275379999999998	55.261879999999998	Центральная	0103000020E61000000100000005000000406B7EFCA5834640FDBCA94885A14B40406B7EFCA58346407AFCDEA63FA34B408DEF8B4B558646407AFCDEA63FA34B408DEF8B4B55864640FDBCA94885A14B40406B7EFCA5834640FDBCA94885A14B40
17473	5077	44.753169	44.775151000000001	55.195461999999999	55.183179000000003	Героя Платова	0103000020E6100000010000000500000036AE7FD7676046403128D36872974B4036AE7FD7676046402DCE18E604994B40193BE125386346402DCE18E604994B40193BE125386346403128D36872974B4036AE7FD7676046403128D36872974B40
17249	4024	45.008083999999997	45.033785000000002	55.188555000000001	55.174928000000001	Центральная	0103000020E6100000010000000500000078CF81E508814640CD936B0A64964B4078CF81E508814640A73FFB9122984B40350C1F1153844640A73FFB9122984B40350C1F1153844640CD936B0A64964B4078CF81E508814640CD936B0A64964B40
17040	4305	45.188124000000002	45.205407999999998	55.227905	55.220340999999998	Центральная	0103000020E61000000100000005000000DECB7D7214984640E57B4622349C4B40DECB7D721498464025CCB4FD2B9D4B401B2B31CF4A9A464025CCB4FD2B9D4B401B2B31CF4A9A4640E57B4622349C4B40DECB7D7214984640E57B4622349C4B40
17365	4143	45.139229	45.173437	55.190637000000002	55.174109999999999	Центральная	0103000020E61000000100000005000000D0D38041D29146400AF4893C49964B40D0D38041D29146402B3410CB66984B404B75012F339646402B3410CB66984B404B75012F339646400AF4893C49964B40D0D38041D29146400AF4893C49964B40
17618	3926	45.057248999999999	45.080047999999998	55.201664000000001	55.188715000000002	Калинина	0103000020E61000000100000005000000465D6BEF53874640E0A128D027984B40465D6BEF53874640E9633E20D0994B401B0E4B033F8A4640E9633E20D0994B401B0E4B033F8A4640E0A128D027984B40465D6BEF53874640E0A128D027984B40
16684	4722	44.923544	44.952531999999998	55.353617	55.341223999999997	Колхозная	0103000020E61000000100000005000000613596B0367646401E4E603AADAB4B40613596B036764640A227655243AD4B405D328E91EC794640A227655243AD4B405D328E91EC7946401E4E603AADAB4B40613596B0367646401E4E603AADAB4B40
19407	50019	44.820901999999997	44.844501000000001	55.381597999999997	55.361794000000003	Савинская	0103000020E61000000100000005000000499C155113694640CCF10A444FAE4B40499C155113694640081C0934D8B04B403B38D89B186C4640081C0934D8B04B403B38D89B186C4640CCF10A444FAE4B40499C155113694640CCF10A444FAE4B40
17093	5528	44.793512	44.825493000000002	55.126719000000001	55.115563000000002	Высокая	0103000020E61000000100000005000000E57D1CCD9165464057D0B4C4CA8E4B40E57D1CCD916546401364045438904B40D9092FC1A96946401364045438904B40D9092FC1A969464057D0B4C4CA8E4B40E57D1CCD9165464057D0B4C4CA8E4B40
17047	4526	45.070194000000001	45.090684000000003	55.377214000000002	55.359051999999998	Трудовая	0103000020E610000001000000050000000E30F31DFC8846401DC87A6AF5AD4B400E30F31DFC884640F3CB608C48B04B409F2287889B8B4640F3CB608C48B04B409F2287889B8B46401DC87A6AF5AD4B400E30F31DFC8846401DC87A6AF5AD4B40
19454	4901	44.896864000000001	44.921000999999997	55.364500999999997	55.352634000000002	Центральная	0103000020E61000000100000005000000D97A8670CC72464095BA641C23AD4B40D97A8670CC724640FD2D01F8A7AE4B40A94A5B5CE3754640FD2D01F8A7AE4B40A94A5B5CE375464095BA641C23AD4B40D97A8670CC72464095BA641C23AD4B40
16816	4924	44.858353000000001	44.877478000000004	55.257899000000002	55.247652000000002	Школьная	0103000020E6100000010000000500000035B6D782DE6D4640FE648C0FB39F4B4035B6D782DE6D4640E7559DD502A14B40D17AF83251704640E7559DD502A14B40D17AF83251704640FE648C0FB39F4B4035B6D782DE6D4640FE648C0FB39F4B40
17559	4636	44.986649999999997	45.008299999999998	55.362791999999999	55.346071999999999	Центральная	0103000020E61000000100000005000000984C158C4A7E4640D90759164CAC4B40984C158C4A7E46400EA0DFF76FAE4B40454772F90F8146400EA0DFF76FAE4B40454772F90F814640D90759164CAC4B40984C158C4A7E4640D90759164CAC4B40
16694	5302	44.984206999999998	45.02084	55.140230000000003	55.119532999999997	Зверева	0103000020E6100000010000000500000044BFB67EFA7D464079E57ADB4C8F4B4044BFB67EFA7D464084F57F0EF3914B406D3997E2AA82464084F57F0EF3914B406D3997E2AA82464079E57ADB4C8F4B4044BFB67EFA7D464079E57ADB4C8F4B40
17443	4250	45.114642000000003	45.136704999999999	55.231098000000003	55.214613999999997	Мира	0103000020E61000000100000005000000C05FCC96AC8E4640C2A1B778789B4B40C05FCC96AC8E4640E415889E949D4B408F19A88C7F914640E415889E949D4B408F19A88C7F914640C2A1B778789B4B40C05FCC96AC8E4640C2A1B778789B4B40
17455	4699	44.985230999999999	45.017336999999998	55.316231000000002	55.300576999999997	Зеленая	0103000020E61000000100000005000000B000A60C1C7E46400377A04E79A64B40B000A60C1C7E46409E7DE5417AA84B4060014C19388246409E7DE5417AA84B4060014C19388246400377A04E79A64B40B000A60C1C7E46400377A04E79A64B40
18025	5000	44.882913000000002	44.907409999999999	55.225321999999998	55.215246	Центральная	0103000020E610000001000000050000004C1B0E4B03714640234C512E8D9B4B404C1B0E4B03714640DF88EE59D79C4B401C08C90226744640DF88EE59D79C4B401C08C90226744640234C512E8D9B4B404C1B0E4B03714640234C512E8D9B4B40
18032	5165	44.853645999999998	44.900762	55.195914000000002	55.174846000000002	Ленина	0103000020E610000001000000050000003C2EAA45446D464010EB8D5A61964B403C2EAA45446D46400E6ABFB513994B4062BD512B4C7346400E6ABFB513994B4062BD512B4C73464010EB8D5A61964B403C2EAA45446D464010EB8D5A61964B40
17862	5546	44.724648000000002	44.762027000000003	55.157418	55.135511000000001	Центральная	0103000020E61000000100000005000000508E0244C15C4640C79FA86C58914B40508E0244C15C46409FE6E44526944B40A2D5C9198A6146409FE6E44526944B40A2D5C9198A614640C79FA86C58914B40508E0244C15C4640C79FA86C58914B40
17446	4154	45.186093999999997	45.217103999999999	55.173127999999998	55.153250999999997	Большая дорога	0103000020E61000000100000005000000ACFD9DEDD1974640268A90BA9D934B40ACFD9DEDD1974640CD02ED0E29964B4057EA5910CA9B4640CD02ED0E29964B4057EA5910CA9B4640268A90BA9D934B40ACFD9DEDD1974640268A90BA9D934B40
17090	5411	45.006207000000003	45.028089999999999	55.089005999999998	55.068534999999997	Запрудная	0103000020E61000000100000005000000CE001764CB804640D0D03FC1C5884B40CE001764CB804640EA92718C648B4B401DACFF7398834640EA92718C648B4B401DACFF7398834640D0D03FC1C5884B40CE001764CB804640D0D03FC1C5884B40
17670	5215	44.941806	44.965665999999999	55.152355999999997	55.142504000000002	Центральная	0103000020E610000001000000050000009A9658198D7846404CC631923D924B409A9658198D784640B8ACC26680934B40F86D88F19A7B4640B8ACC26680934B40F86D88F19A7B46404CC631923D924B409A9658198D7846404CC631923D924B40
17027	3711	45.009377999999998	45.060096999999999	55.241852000000002	55.225050000000003	Терехина	0103000020E61000000100000005000000A4A65D4C338146407FFB3A70CE9C4B40A4A65D4C33814640713C9F01F59E4B403ACB2C42B1874640713C9F01F59E4B403ACB2C42B18746407FFB3A70CE9C4B40A4A65D4C338146407FFB3A70CE9C4B40
17281	3711	45.009377999999998	45.060096999999999	55.241852000000002	55.225050000000003	Ленина	0103000020E61000000100000005000000A4A65D4C338146407FFB3A70CE9C4B40A4A65D4C33814640713C9F01F59E4B403ACB2C42B1874640713C9F01F59E4B403ACB2C42B18746407FFB3A70CE9C4B40A4A65D4C338146407FFB3A70CE9C4B40
17617	3711	45.009377999999998	45.060096999999999	55.241852000000002	55.225050000000003	Коммунистическая	0103000020E61000000100000005000000A4A65D4C338146407FFB3A70CE9C4B40A4A65D4C33814640713C9F01F59E4B403ACB2C42B1874640713C9F01F59E4B403ACB2C42B18746407FFB3A70CE9C4B40A4A65D4C338146407FFB3A70CE9C4B40
17632	4454	45.043289000000001	45.075592	55.301341000000001	55.283543000000002	Школьная	0103000020E6100000010000000500000066A3737E8A8546403F0114234BA44B4066A3737E8A854640D3F8855792A64B406CEBA7FFAC894640D3F8855792A64B406CEBA7FFAC8946403F0114234BA44B4066A3737E8A8546403F0114234BA44B40
18050	5330	44.943621	44.966267000000002	55.092967999999999	55.078147999999999	Рябовой	0103000020E61000000100000005000000CF68AB92C8784640B81FF0C0008A4B40CF68AB92C87846408AC91B60E68B4B401E1A16A3AE7B46408AC91B60E68B4B401E1A16A3AE7B4640B81FF0C0008A4B40CF68AB92C8784640B81FF0C0008A4B40
17419	49795	42.005366000000002	42.053201999999999	55.333441000000001	55.316513	микрорайон Совхозный	0103000020E61000000100000005000000534145D5AF00454022E17B7F83A84B40534145D5AF004540A112D731AEAA4B40780AB952CF064540A112D731AEAA4B40780AB952CF06454022E17B7F83A84B40534145D5AF00454022E17B7F83A84B40
17003	49722	42.031300999999999	42.055518999999997	55.297286999999997	55.286726999999999	Калинина	0103000020E6100000010000000500000082AAD1AB01044540AAF06778B3A44B4082AAD1AB0104454052431B800DA64B403FA7203F1B07454052431B800DA64B403FA7203F1B074540AAF06778B3A44B4082AAD1AB01044540AAF06778B3A44B40
16950	49714	42.090786999999999	42.138685000000002	55.418660000000003	55.367944999999999	Гагарина	0103000020E6100000010000000500000073F38DE89E0B454005DD5ED218AF4B4073F38DE89E0B45405A12A0A696B54B400FB9196EC01145405A12A0A696B54B400FB9196EC011454005DD5ED218AF4B4073F38DE89E0B454005DD5ED218AF4B40
16970	49720	42.094982000000002	42.118364999999997	55.241652000000002	55.215964999999997	Школьная	0103000020E61000000100000005000000B6DAC35E280C4540520ABABDA49B4B40B6DAC35E280C4540AA81E673EE9E4B40DAFE9595260F4540AA81E673EE9E4B40DAFE9595260F4540520ABABDA49B4B40B6DAC35E280C4540520ABABDA49B4B40
16805	49650	42.089359000000002	42.128894000000003	55.311399999999999	55.298209999999997	Ленина	0103000020E61000000100000005000000384D9F1D700B45408AABCABE2BA64B40384D9F1D700B4540B9FC87F4DBA74B4048533D997F104540B9FC87F4DBA74B4048533D997F1045408AABCABE2BA64B40384D9F1D700B45408AABCABE2BA64B40
17013	49724	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	микрорайон  Гоголя	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
17594	49724	42.106507999999998	42.222884000000001	55.365653000000002	55.292797	1 Мая	0103000020E610000001000000050000009561DC0DA20D4540F7AE415F7AA54B409561DC0DA20D45409757AEB7CDAE4B409D668176871C45409757AEB7CDAE4B409D668176871C4540F7AE415F7AA54B409561DC0DA20D4540F7AE415F7AA54B40
18564	32226	45.010033	45.035617000000002	56.824449000000001	56.813468	Фабричная	0103000020E61000000100000005000000BD70E7C248814640D82B2CB81F684C40BD70E7C248814640261C7A8B87694C4040170D198F844640261C7A8B87694C4040170D198F844640D82B2CB81F684C40BD70E7C248814640D82B2CB81F684C40
17158	32299	45.435493000000001	45.461500000000001	57.005363000000003	56.982269000000002	Школьная	0103000020E610000001000000050000008751103CBEB74640F46F97FDBA7D4C408751103CBEB74640E2CD1ABCAF804C40508D976E12BB4640E2CD1ABCAF804C40508D976E12BB4640F46F97FDBA7D4C408751103CBEB74640F46F97FDBA7D4C40
16961	872	45.821212000000003	45.835324999999997	56.963512999999999	56.955043000000003	Железнодорожная	0103000020E61000000100000005000000988A8D791DE946400AA359D93E7A4C40988A8D791DE94640AB22DC64547B4C40FE43FAEDEBEA4640AB22DC64547B4C40FE43FAEDEBEA46400AA359D93E7A4C40988A8D791DE946400AA359D93E7A4C40
17556	32394	45.351905000000002	45.373339000000001	56.909972000000003	56.897773000000001	Молодежная	0103000020E61000000100000005000000422619390BAD4640AC1DC539EA724C40422619390BAD46404B2366F679744C4022A98592C9AF46404B2366F679744C4022A98592C9AF4640AC1DC539EA724C40422619390BAD4640AC1DC539EA724C40
17553	32343	45.368245999999999	45.394063000000003	56.952843999999999	56.940024999999999	Новая	0103000020E61000000100000005000000007157AF22AF464011363CBD52784C40007157AF22AF46404C18CDCAF6794C4026C808A870B246404C18CDCAF6794C4026C808A870B2464011363CBD52784C40007157AF22AF464011363CBD52784C40
17754	32149	45.157249	45.175611000000004	56.924933000000003	56.916285999999999	Интернациональная	0103000020E61000000100000005000000132A38BC209446402EE411DC48754C40132A38BC20944640DFFE5C3464764C40B0E8D66B7A964640DFFE5C3464764C40B0E8D66B7A9646402EE411DC48754C40132A38BC209446402EE411DC48754C40
17383	49785	45.532305000000001	45.574992999999999	56.625287	56.617041	Школьная	0103000020E61000000100000005000000A73FFB9122C4464044A51133FB4E4C40A73FFB9122C4464096CE876709504C40E736E15E99C9464096CE876709504C40E736E15E99C9464044A51133FB4E4C40A73FFB9122C4464044A51133FB4E4C40
17165	366	45.324703999999997	45.345545000000001	56.56682	56.552514000000002	Зеленая	0103000020E61000000100000005000000B07092E68FA94640844A5CC7B8464C40B07092E68FA94640FF5BC98E8D484C40EE258DD13AAC4640FF5BC98E8D484C40EE258DD13AAC4640844A5CC7B8464C40B07092E68FA94640844A5CC7B8464C40
17181	1013	45.592959	45.611339000000001	57.042600999999998	57.030484999999999	Больничная	0103000020E61000000100000005000000376F9C14E6CB46406002B7EEE6834C40376F9C14E6CB464071E316F373854C407AE2395B40CE464071E316F373854C407AE2395B40CE46406002B7EEE6834C40376F9C14E6CB46406002B7EEE6834C40
17169	49757	45.363934	45.381047000000002	56.753819	56.746040999999998	Прямая	0103000020E6100000010000000500000084F3A96395AE4640D13C80457E5F4C4084F3A96395AE46403D0D18247D604C40959EE925C6B046403D0D18247D604C40959EE925C6B04640D13C80457E5F4C4084F3A96395AE4640D13C80457E5F4C40
17373	255	45.719800999999997	45.746293000000001	56.775998999999999	56.752865999999997	Советская	0103000020E6100000010000000500000065506D7022DC46409A22C0E95D604C4065506D7022DC4640465D6BEF53634C40EB1D6E8786DF4640465D6BEF53634C40EB1D6E8786DF46409A22C0E95D604C4065506D7022DC46409A22C0E95D604C40
19420	32499	45.355696000000002	45.378171999999999	56.837096000000003	56.826129000000002	Клубная	0103000020E61000000100000005000000B5A84F7287AD46407BA35698BE694C40B5A84F7287AD464064CE33F6256B4C40A721AAF067B0464064CE33F6256B4C40A721AAF067B046407BA35698BE694C40B5A84F7287AD46407BA35698BE694C40
17547	49811	45.420760999999999	45.456119000000001	56.821719999999999	56.799472999999999	Береговая	0103000020E610000001000000050000005437177FDBB546407B849A2155664C405437177FDBB546400C3CF71E2E694C40C80A7E1B62BA46400C3CF71E2E694C40C80A7E1B62BA46407B849A2155664C405437177FDBB546407B849A2155664C40
17378	31911	45.461678999999997	45.484082999999998	56.807747999999997	56.793750000000003	 Мира	0103000020E61000000100000005000000FF1F274C18BB46409A99999999654C40FF1F274C18BB464067B4554964674C4058C6866EF6BD464067B4554964674C4058C6866EF6BD46409A99999999654C40FF1F274C18BB46409A99999999654C40
16955	619	45.466529999999999	45.485143000000001	56.896548000000003	56.885505000000002	Школьная	0103000020E610000001000000050000002B4D4A41B7BB4640E5B8533A58714C402B4D4A41B7BB4640A9A5B915C2724C401171732A19BE4640A9A5B915C2724C401171732A19BE4640E5B8533A58714C402B4D4A41B7BB4640E5B8533A58714C40
18579	32466	45.235618000000002	45.254249000000002	56.647519000000003	56.636178999999998	Набережная	0103000020E61000000100000005000000AA2C0ABB289E464074B33F506E514C40AA2C0ABB289E4640F24410E7E1524C403605323B8BA04640F24410E7E1524C403605323B8BA0464074B33F506E514C40AA2C0ABB289E464074B33F506E514C40
17167	374	45.612667999999999	45.636096000000002	56.597264000000003	56.583995999999999	Центральная	0103000020E6100000010000000500000022A7AFE76BCE4640567F8461C04A4C4022A7AFE76BCE4640018A9125734C4C40E78EFE976BD14640018A9125734C4C40E78EFE976BD14640567F8461C04A4C4022A7AFE76BCE4640567F8461C04A4C40
17360	32005	45.684336000000002	45.701034999999997	56.731575999999997	56.722276000000001	Центральная	0103000020E61000000100000005000000DCBC715298D74640C5573B8A735C4C40DCBC715298D74640ED444948A45D4C40F92CCF83BBD94640ED444948A45D4C40F92CCF83BBD94640C5573B8A735C4C40DCBC715298D74640C5573B8A735C4C40
17557	511	45.481613000000003	45.500163000000001	56.875329999999998	56.863782999999998	Школьная	0103000020E610000001000000050000000B2AAA7EA5BD46409EEBFB70906E4C400B2AAA7EA5BD4640959A3DD00A704C40AAD5575705C04640959A3DD00A704C40AAD5575705C046409EEBFB70906E4C400B2AAA7EA5BD46409EEBFB70906E4C40
17149	31963	45.600209	45.638646999999999	56.759408999999998	56.746775999999997	Пролетарская	0103000020E61000000100000005000000E7E104A6D3CC464006B8205B965F4C40E7E104A6D3CC4640DFA4695034614C402158552FBFD14640DFA4695034614C402158552FBFD1464006B8205B965F4C40E7E104A6D3CC464006B8205B965F4C40
18522	31639	45.420670999999999	45.446606000000003	56.855541000000002	56.821375000000003	пл. Ленина	0103000020E6100000010000000500000014B01D8CD8B546404260E5D022694C4014B01D8CD8B546408EB1135E826D4C404419AA622AB946408EB1135E826D4C404419AA622AB946404260E5D022694C4014B01D8CD8B546404260E5D022694C40
16929	31639	45.420670999999999	45.446606000000003	56.855541000000002	56.821375000000003	Ленина	0103000020E6100000010000000500000014B01D8CD8B546404260E5D022694C4014B01D8CD8B546408EB1135E826D4C404419AA622AB946408EB1135E826D4C404419AA622AB946404260E5D022694C4014B01D8CD8B546404260E5D022694C40
17176	634	45.596623999999998	45.629142999999999	56.966996999999999	56.952829000000001	Ленина	0103000020E610000001000000050000001D01DC2C5ECC464017D7F84CF6794C401D01DC2C5ECC4640412AC58EC67B4C40F0C000C287D04640412AC58EC67B4C40F0C000C287D0464017D7F84CF6794C401D01DC2C5ECC464017D7F84CF6794C40
17175	916	45.920726999999999	45.945233999999999	56.923502999999997	56.913254000000002	Новая	0103000020E61000000100000005000000A8C5E061DAF546407978CF81E5744C40A8C5E061DAF546400261A75835764C409C887E6DFDF846400261A75835764C409C887E6DFDF846407978CF81E5744C40A8C5E061DAF546407978CF81E5744C40
19437	744	45.495365999999997	45.528495999999997	56.970441999999998	56.955897	Луговая	0103000020E6100000010000000500000071C6302768BF464019AC38D55A7A4C4071C6302768BF464019558671377C4C408D08C6C1A5C3464019558671377C4C408D08C6C1A5C3464019AC38D55A7A4C4071C6302768BF464019AC38D55A7A4C40
16777	31847	45.509172999999997	45.565165	56.786937000000002	56.767702999999997	Комсомольская	0103000020E61000000100000005000000CB80B3942CC146404205871744624C40CB80B3942CC146409581035ABA644C4003ECA35357C846409581035ABA644C4003ECA35357C846404205871744624C40CB80B3942CC146404205871744624C40
17658	32091	45.304582000000003	45.317841000000001	56.946202	56.937398000000002	Советская	0103000020E61000000100000005000000A379008BFCA64640FCAA5CA8FC774C40A379008BFCA6464074B4AA251D794C40FA298E03AFA8464074B4AA251D794C40FA298E03AFA84640FCAA5CA8FC774C40A379008BFCA64640FCAA5CA8FC774C40
17367	32263	45.235888000000003	45.255192999999998	56.815345000000001	56.806165999999997	Советская	0103000020E610000001000000050000006AC2F693319E4640D5928E7230674C406AC2F693319E464083FA96395D684C4085950A2AAAA0464083FA96395D684C4085950A2AAAA04640D5928E7230674C406AC2F693319E4640D5928E7230674C40
19803	50080	45.959553	45.974555000000002	56.091025000000002	56.080151000000001	Советская	0103000020E61000000100000005000000ACE3F8A1D2FA4640F0DE5163420A4C40ACE3F8A1D2FA4640280F0BB5A60B4C409F93DE37BEFC4640280F0BB5A60B4C409F93DE37BEFC4640F0DE5163420A4C40ACE3F8A1D2FA4640F0DE5163420A4C40
17344	31557	45.671022999999998	45.723188	56.071041999999998	56.057765000000003	Советская	0103000020E6100000010000000500000091EEE714E4D546403EEDF0D764074C4091EEE714E4D546403B527DE717094C40096EA46C91DC46403B527DE717094C40096EA46C91DC46403EEDF0D764074C4091EEE714E4D546403EEDF0D764074C40
18475	31483	45.786169000000001	45.840606999999999	56.172811000000003	56.148980000000002	Мира	0103000020E610000001000000050000008410902FA1E4464009E1D1C611134C408410902FA1E44640CDB1BCAB1E164C40F3E49A0299EB4640CDB1BCAB1E164C40F3E49A0299EB464009E1D1C611134C408410902FA1E4464009E1D1C611134C40
17527	31390	45.69782	45.744469000000002	56.137785999999998	56.124747999999997	Свободы	0103000020E61000000100000005000000533F6F2A52D94640E61E12BEF70F4C40533F6F2A52D946405FECBDF8A2114C4063F19BC24ADF46405FECBDF8A2114C4063F19BC24ADF4640E61E12BEF70F4C40533F6F2A52D94640E61E12BEF70F4C40
17726	31340	45.964951999999997	46.003813000000001	56.032131999999997	56.011584999999997	Малова	0103000020E61000000100000005000000DA1A118C83FB4640E40F069E7B014C40DA1A118C83FB4640D993C0E61C044C405B26C3F17C004740D993C0E61C044C405B26C3F17C004740E40F069E7B014C40DA1A118C83FB4640E40F069E7B014C40
17339	31280	45.668948	45.690426000000002	56.200097	56.173983	Ленина	0103000020E61000000100000005000000C05C8B16A0D54640AD872F1345164C40C05C8B16A0D546408C834BC79C194C40702711E15FD846408C834BC79C194C40702711E15FD84640AD872F1345164C40C05C8B16A0D54640AD872F1345164C40
18017	31223	45.779457999999998	45.819622000000003	55.973370000000003	55.958517000000001	Советская	0103000020E61000000100000005000000834D9D47C5E346407CD45FAFB0FA4B40834D9D47C5E346402A745E6397FC4B40838AAA5FE9E846402A745E6397FC4B40838AAA5FE9E846407CD45FAFB0FA4B40834D9D47C5E346407CD45FAFB0FA4B40
17523	31147	45.880428999999999	45.908321999999998	56.126964999999998	56.117224999999998	Молодежная	0103000020E6100000010000000500000099B9C0E5B1F0464005A3923A010F4C4099B9C0E5B1F046404A5E9D6340104C40601E32E543F446404A5E9D6340104C40601E32E543F4464005A3923A010F4C4099B9C0E5B1F0464005A3923A010F4C40
17340	31122	45.826538999999997	45.860900000000001	56.102347999999999	56.094470000000001	Петровская	0103000020E610000001000000050000002CEFAA07CCE94640003ACC97170C4C402CEFAA07CCE94640CF6740BD190D4C402E90A0F831EE4640CF6740BD190D4C402E90A0F831EE4640003ACC97170C4C402CEFAA07CCE94640003ACC97170C4C40
17336	31180	45.879100000000001	45.924869000000001	56.039188000000003	56.009320000000002	Кооперативная	0103000020E61000000100000005000000F1F44A5986F046407099D36531014C40F1F44A5986F04640A532C51C04054C40C80A7E1B62F64640A532C51C04054C40C80A7E1B62F646407099D36531014C40F1F44A5986F046407099D36531014C40
17716	31067	45.753138	45.802509000000001	56.197398	56.174725000000002	Победы	0103000020E61000000100000005000000FBAF73D366E04640956588635D164C40FBAF73D366E04640DD25715644194C4072DF6A9DB8E64640DD25715644194C4072DF6A9DB8E64640956588635D164C40FBAF73D366E04640956588635D164C40
17133	30966	45.529232999999998	45.563090000000003	56.053019999999997	56.044820000000001	Центральная	0103000020E61000000100000005000000637B2DE8BDC34640761A69A9BC054C40637B2DE8BDC346405704FF5BC9064C40325A475513C846405704FF5BC9064C40325A475513C84640761A69A9BC054C40637B2DE8BDC34640761A69A9BC054C40
17279	30988	45.950209999999998	45.966774999999998	56.110756000000002	56.103422000000002	Сурская	0103000020E61000000100000005000000842A357BA0F94640EDD79DEE3C0D4C40842A357BA0F94640FBEAAA402D0E4C4092CB7F48BFFB4640FBEAAA402D0E4C4092CB7F48BFFB4640EDD79DEE3C0D4C40842A357BA0F94640EDD79DEE3C0D4C40
17349	30758	45.473241000000002	45.495178000000003	56.387664000000001	56.373854000000001	Центральная	0103000020E610000001000000050000002C103D2993BC464049BDA772DA2F4C402C103D2993BC464014EB54F99E314C406FD921FE61BF464014EB54F99E314C406FD921FE61BF464049BDA772DA2F4C402C103D2993BC464049BDA772DA2F4C40
17470	30797	45.598123999999999	45.620879000000002	56.010080000000002	56.000714000000002	Береговая	0103000020E61000000100000005000000F279C5538FCC46401E53776517004C40F279C5538FCC4640FE2B2B4D4A014C40F8E28BF678CF4640FE2B2B4D4A014C40F8E28BF678CF46401E53776517004C40F279C5538FCC46401E53776517004C40
17521	30674	45.562165	45.606684999999999	56.210811999999997	56.174819999999997	Заводская	0103000020E6100000010000000500000059FAD005F5C74640E657738060164C4059FAD005F5C746405BCD3AE3FB1A4C40A4FCA4DAA7CD46405BCD3AE3FB1A4C40A4FCA4DAA7CD4640E657738060164C4059FAD005F5C74640E657738060164C40
17711	30562	45.816864000000002	45.839942000000001	56.034385	56.015269000000004	Нагорная	0103000020E61000000100000005000000CFA3E2FF8EE8464042D2A755F4014C40CFA3E2FF8EE846408A3C49BA66044C40B7442E3883EB46408A3C49BA66044C40B7442E3883EB464042D2A755F4014C40CFA3E2FF8EE8464042D2A755F4014C40
17514	26604	45.826171000000002	45.883994999999999	56.070771000000001	56.049821999999999	Микройрайон Молодежный	0103000020E61000000100000005000000AAF3A8F8BFE94640874F3A9160064C40AAF3A8F8BFE94640AB402D060F094C40EC6987BF26F14640AB402D060F094C40EC6987BF26F14640874F3A9160064C40AAF3A8F8BFE94640874F3A9160064C40
18004	26604	45.826171000000002	45.883994999999999	56.070771000000001	56.049821999999999	Космонавтов	0103000020E61000000100000005000000AAF3A8F8BFE94640874F3A9160064C40AAF3A8F8BFE94640AB402D060F094C40EC6987BF26F14640AB402D060F094C40EC6987BF26F14640874F3A9160064C40AAF3A8F8BFE94640874F3A9160064C40
18220	26604	45.826171000000002	45.883994999999999	56.070771000000001	56.049821999999999	Зубова 	0103000020E61000000100000005000000AAF3A8F8BFE94640874F3A9160064C40AAF3A8F8BFE94640AB402D060F094C40EC6987BF26F14640AB402D060F094C40EC6987BF26F14640874F3A9160064C40AAF3A8F8BFE94640874F3A9160064C40
18249	26604	45.826171000000002	45.883994999999999	56.070771000000001	56.049821999999999	Демьяна Бедного	0103000020E61000000100000005000000AAF3A8F8BFE94640874F3A9160064C40AAF3A8F8BFE94640AB402D060F094C40EC6987BF26F14640AB402D060F094C40EC6987BF26F14640874F3A9160064C40AAF3A8F8BFE94640874F3A9160064C40
17707	30355	45.662712999999997	45.700513999999998	55.994159000000003	55.978149999999999	Школьная	0103000020E6100000010000000500000028D192C7D3D446408C4AEA0434FD4B4028D192C7D3D446401503249A40FF4B40F0315871AAD946401503249A40FF4B40F0315871AAD946408C4AEA0434FD4B4028D192C7D3D446408C4AEA0434FD4B40
18269	30462	46.007801000000001	46.029584999999997	55.972009999999997	55.954566	Школьная	0103000020E6100000010000000500000024F0879FFF004740D0EFFB372FFA4B4024F0879FFF00474046B1DCD26AFC4B40E0B9F770C903474046B1DCD26AFC4B40E0B9F770C9034740D0EFFB372FFA4B4024F0879FFF004740D0EFFB372FFA4B40
17712	30380	46.065463999999999	46.110289999999999	55.998499000000002	55.988529999999997	Горького	0103000020E610000001000000050000005D88D51F61084740B48EAA2688FE4B405D88D51F610847405B0BB3D0CEFF4B40B58993FB1D0E47405B0BB3D0CEFF4B40B58993FB1D0E4740B48EAA2688FE4B405D88D51F61084740B48EAA2688FE4B40
17323	30267	45.748269000000001	45.776090000000003	56.022216999999998	56.004826000000001	 Центральная	0103000020E6100000010000000500000029CE5147C7DF4640D3156C239E004C4029CE5147C7DF46402635B401D8024C405760C8EA56E346402635B401D8024C405760C8EA56E34640D3156C239E004C4029CE5147C7DF4640D3156C239E004C40
17225	29115	43.212108999999998	43.245958000000002	56.258927999999997	56.240403000000001	Центральная	0103000020E61000000100000005000000F8174163269B45401E6E8786C51E4C40F8174163269B454064027E8D24214C4044183F8D7B9F454064027E8D24214C4044183F8D7B9F45401E6E8786C51E4C40F8174163269B45401E6E8786C51E4C40
18193	29792	42.774009999999997	42.811362000000003	56.310203000000001	56.279302000000001	Мирошниченко 	0103000020E6100000010000000500000073637AC2126345408CDAFD2AC0234C4073637AC212634540800F5EBBB4274C40CC9BC3B5DA674540800F5EBBB4274C40CC9BC3B5DA6745408CDAFD2AC0234C4073637AC2126345408CDAFD2AC0234C40
17702	29872	42.627988999999999	42.666930999999998	56.433231999999997	56.406635000000001	Школьная	0103000020E61000000100000005000000B69F8CF16150454059349D9D0C344C40B69F8CF16150454053CA6B2574374C4023D8B8FE5D55454053CA6B2574374C4023D8B8FE5D55454059349D9D0C344C40B69F8CF16150454059349D9D0C344C40
16697	29634	43.058228	43.106062999999999	56.292757999999999	56.267152000000003	1 Мая	0103000020E6100000010000000500000012DBDD0374874540CF87670932224C4012DBDD037487454039D2191879254C406728EE78938D454039D2191879254C406728EE78938D4540CF87670932224C4012DBDD0374874540CF87670932224C40
18162	28797	43.273319999999998	43.313817	56.226714000000001	56.209440999999998	Кирова 	0103000020E61000000100000005000000DEAB5626FCA2454084B872F6CE1A4C40DEAB5626FCA24540CEC5DFF6041D4C40E4F6CB272BA84540CEC5DFF6041D4C40E4F6CB272BA8454084B872F6CE1A4C40DEAB5626FCA2454084B872F6CE1A4C40
16829	28797	43.273319999999998	43.313817	56.226714000000001	56.209440999999998	Кирова	0103000020E61000000100000005000000DEAB5626FCA2454084B872F6CE1A4C40DEAB5626FCA24540CEC5DFF6041D4C40E4F6CB272BA84540CEC5DFF6041D4C40E4F6CB272BA8454084B872F6CE1A4C40DEAB5626FCA2454084B872F6CE1A4C40
17495	28797	43.273319999999998	43.313817	56.226714000000001	56.209440999999998	Затылкова	0103000020E61000000100000005000000DEAB5626FCA2454084B872F6CE1A4C40DEAB5626FCA24540CEC5DFF6041D4C40E4F6CB272BA84540CEC5DFF6041D4C40E4F6CB272BA8454084B872F6CE1A4C40DEAB5626FCA2454084B872F6CE1A4C40
18451	29430	43.014642000000002	43.057006000000001	56.292268	56.279131999999997	Танковая  	0103000020E61000000100000005000000F392FFC9DF8145402FA2ED98BA234C40F392FFC9DF8145406BD5AE0969254C4080D6FCF84B8745406BD5AE0969254C4080D6FCF84B8745402FA2ED98BA234C40F392FFC9DF8145402FA2ED98BA234C40
16689	29430	43.014642000000002	43.057006000000001	56.292268	56.279131999999997	Танковая	0103000020E61000000100000005000000F392FFC9DF8145402FA2ED98BA234C40F392FFC9DF8145406BD5AE0969254C4080D6FCF84B8745406BD5AE0969254C4080D6FCF84B8745402FA2ED98BA234C40F392FFC9DF8145402FA2ED98BA234C40
17500	29537	42.775770999999999	42.814695	56.238731999999999	56.223751999999998	Советская	0103000020E61000000100000005000000B517D1764C6345401135D1E7A31C4C40B517D1764C6345401C412AC58E1E4C407C9BFEEC476845401C412AC58E1E4C407C9BFEEC476845401135D1E7A31C4C40B517D1764C6345401135D1E7A31C4C40
17311	6817	42.930459999999997	42.993675000000003	56.331268999999999	56.301383999999999	Новая 	0103000020E610000001000000050000003A1E335019774540D2C43BC093264C403A1E335019774540DD96C805672A4C4029ED0DBE307F4540DD96C805672A4C4029ED0DBE307F4540D2C43BC093264C403A1E335019774540D2C43BC093264C40
16762	6817	42.930459999999997	42.993675000000003	56.331268999999999	56.301383999999999	Новая	0103000020E610000001000000050000003A1E335019774540D2C43BC093264C403A1E335019774540DD96C805672A4C4029ED0DBE307F4540DD96C805672A4C4029ED0DBE307F4540D2C43BC093264C403A1E335019774540D2C43BC093264C40
16724	6817	42.930459999999997	42.993675000000003	56.331268999999999	56.301383999999999	Гвардейская 	0103000020E610000001000000050000003A1E335019774540D2C43BC093264C403A1E335019774540DD96C805672A4C4029ED0DBE307F4540DD96C805672A4C4029ED0DBE307F4540D2C43BC093264C403A1E335019774540D2C43BC093264C40
17319	29186	43.046514000000002	43.083264	56.220137999999999	56.200228000000003	Ленина	0103000020E610000001000000050000003067B62BF48545402BDF3312A1194C403067B62BF4854540AD4D637B2D1C4C4092770E65A88A4540AD4D637B2D1C4C4092770E65A88A45402BDF3312A1194C403067B62BF48545402BDF3312A1194C40
18226	29240	42.938087000000003	42.997753000000003	56.235399999999998	56.218136000000001	Угарова 	0103000020E61000000100000005000000C1E61C3C13784540460A65E1EB1B4C40C1E61C3C137845403CBD5296211E4C40323ECC5EB67F45403CBD5296211E4C40323ECC5EB67F4540460A65E1EB1B4C40C1E61C3C13784540460A65E1EB1B4C40
17318	29240	42.938087000000003	42.997753000000003	56.235399999999998	56.218136000000001	Угарова	0103000020E61000000100000005000000C1E61C3C13784540460A65E1EB1B4C40C1E61C3C137845403CBD5296211E4C40323ECC5EB67F45403CBD5296211E4C40323ECC5EB67F4540460A65E1EB1B4C40C1E61C3C13784540460A65E1EB1B4C40
18414	29392	42.964821000000001	42.997627999999999	56.289234999999998	56.267741999999998	Школьная 	0103000020E610000001000000050000003CBF28417F7B454000E2AE5E45224C403CBF28417F7B4540E5ED08A705254C4075C93846B27F4540E5ED08A705254C4075C93846B27F454000E2AE5E45224C403CBF28417F7B454000E2AE5E45224C40
17682	9050	43.127640999999997	43.229050999999998	56.247830999999998	56.2089	Октябрьская	0103000020E610000001000000050000007A50508A569045403411363CBD1A4C407A50508A56904540ADF71BEDB81F4C40DC0E0D8B519D4540ADF71BEDB81F4C40DC0E0D8B519D45403411363CBD1A4C407A50508A569045403411363CBD1A4C40
17621	9050	43.127640999999997	43.229050999999998	56.247830999999998	56.2089	Мичурина 	0103000020E610000001000000050000007A50508A569045403411363CBD1A4C407A50508A56904540ADF71BEDB81F4C40DC0E0D8B519D4540ADF71BEDB81F4C40DC0E0D8B519D45403411363CBD1A4C407A50508A569045403411363CBD1A4C40
17033	9050	43.127640999999997	43.229050999999998	56.247830999999998	56.2089	Мичурина	0103000020E610000001000000050000007A50508A569045403411363CBD1A4C407A50508A56904540ADF71BEDB81F4C40DC0E0D8B519D4540ADF71BEDB81F4C40DC0E0D8B519D45403411363CBD1A4C407A50508A569045403411363CBD1A4C40
16740	9050	43.127640999999997	43.229050999999998	56.247830999999998	56.2089	Клубная	0103000020E610000001000000050000007A50508A569045403411363CBD1A4C407A50508A56904540ADF71BEDB81F4C40DC0E0D8B519D4540ADF71BEDB81F4C40DC0E0D8B519D45403411363CBD1A4C407A50508A569045403411363CBD1A4C40
16993	28722	42.884439999999998	42.915917	54.796579000000001	54.780107000000001	Советская	0103000020E610000001000000050000001AA3755435714540BA30D28BDA634B401AA375543571454017D7F84CF6654B40DB6CACC43C75454017D7F84CF6654B40DB6CACC43C754540BA30D28BDA634B401AA3755435714540BA30D28BDA634B40
17690	28596	42.965612	42.991726	54.869425	54.853422999999999	Советская	0103000020E6100000010000000500000005508C2C997B4540BD5301F73C6D4B4005508C2C997B454093A98251496F4B40E44BA8E0F07E454093A98251496F4B40E44BA8E0F07E4540BD5301F73C6D4B4005508C2C997B4540BD5301F73C6D4B40
17483	28316	42.681977000000003	42.707759000000003	54.852231000000003	54.837865999999998	Школьная	0103000020E61000000100000005000000E6CFB7054B57454015376E313F6B4B40E6CFB7054B57454096D1C8E7156D4B408F39CFD8975A454096D1C8E7156D4B408F39CFD8975A454015376E313F6B4B40E6CFB7054B57454015376E313F6B4B40
17640	28647	42.627495000000003	42.659295	54.864907000000002	54.840319000000001	Молодежная	0103000020E61000000100000005000000A7B393C1515045408D9AAF928F6B4B40A7B393C1515045406E8AC745B56E4B404AB54FC7635445406E8AC745B56E4B404AB54FC7635445408D9AAF928F6B4B40A7B393C1515045408D9AAF928F6B4B40
17673	28220	42.746035999999997	42.775303000000001	54.848888000000002	54.830207999999999	Кооперативная	0103000020E61000000100000005000000BFD18E1B7E5F454054707841446A4B40BFD18E1B7E5F4540C2FBAA5CA86C4B40CFBEF2203D634540C2FBAA5CA86C4B40CFBEF2203D63454054707841446A4B40BFD18E1B7E5F454054707841446A4B40
17484	28439	43.028897999999998	43.071640000000002	54.896320000000003	54.869543999999998	Ленина	0103000020E61000000100000005000000BC75FEEDB28345406D37C1374D6F4B40BC75FEEDB283454018601F9DBA724B40F08AE07F2B89454018601F9DBA724B40F08AE07F2B8945406D37C1374D6F4B40BC75FEEDB28345406D37C1374D6F4B40
17213	28411	42.884988	42.923391000000002	54.924841999999998	54.897179000000001	Ленина	0103000020E610000001000000050000001DAD6A494771454039D4EFC2D6724B401DAD6A4947714540CEFBFF3861764B40DB3521AD31764540CEFBFF3861764B40DB3521AD3176454039D4EFC2D6724B401DAD6A494771454039D4EFC2D6724B40
17683	28333	42.518915	42.543170000000003	54.843279000000003	54.828552999999999	Советская	0103000020E61000000100000005000000B13385CE6B424540580053060E6A4B40B13385CE6B424540A933F790F06B4B408C15359886454540A933F790F06B4B408C15359886454540580053060E6A4B40B13385CE6B424540580053060E6A4B40
17982	28666	42.849935000000002	42.86553	55.008541999999998	55.000988	Мелькинская	0103000020E61000000100000005000000E65C8AABCA6C45401FD8F15F20804B40E65C8AABCA6C45403B527DE717814B407BDAE1AFC96E45403B527DE717814B407BDAE1AFC96E45401FD8F15F20804B40E65C8AABCA6C45401FD8F15F20804B40
17095	28267	42.640799000000001	42.668449000000003	54.831384999999997	54.808675000000001	Советская	0103000020E610000001000000050000009E279EB305524540E10B93A982674B409E279EB30552454046B1DCD26A6A4B409F05A1BC8F55454046B1DCD26A6A4B409F05A1BC8F554540E10B93A982674B409E279EB305524540E10B93A982674B40
17304	28494	43.097124999999998	43.117668999999999	54.833423000000003	54.822479999999999	Заречная	0103000020E61000000100000005000000DF4F8D976E8C45409ACE4E0647694B40DF4F8D976E8C4540FB5DD89AAD6A4B4063601DC70F8F4540FB5DD89AAD6A4B4063601DC70F8F45409ACE4E0647694B40DF4F8D976E8C45409ACE4E0647694B40
17745	27729	42.710822	42.801220000000001	54.906689	54.881059	Садовая	0103000020E610000001000000050000007FA31D37FC5A4540596C938AC6704B407FA31D37FC5A45404C5299620E744B40587380608E6645404C5299620E744B40587380608E664540596C938AC6704B407FA31D37FC5A4540596C938AC6704B40
17282	27729	42.710822	42.801220000000001	54.906689	54.881059	Индустриальная	0103000020E610000001000000050000007FA31D37FC5A4540596C938AC6704B407FA31D37FC5A45404C5299620E744B40587380608E6645404C5299620E744B40587380608E664540596C938AC6704B407FA31D37FC5A4540596C938AC6704B40
16680	27729	42.710822	42.801220000000001	54.906689	54.881059	Заречная 	0103000020E610000001000000050000007FA31D37FC5A4540596C938AC6704B407FA31D37FC5A45404C5299620E744B40587380608E6645404C5299620E744B40587380608E664540596C938AC6704B407FA31D37FC5A4540596C938AC6704B40
18044	27998	42.703617999999999	42.724539999999998	55.016604999999998	55.003641999999999	Первомайская	0103000020E610000001000000050000003F709527105A45402E724F5777804B403F709527105A45409CF9D51C20824B4069520ABABD5C45409CF9D51C20824B4069520ABABD5C45402E724F5777804B403F709527105A45402E724F5777804B40
17622	27925	43.131323999999999	43.163680999999997	54.912976999999998	54.894258999999998	Ленина	0103000020E6100000010000000500000007978E39CF904540AB93331477724B4007978E39CF90454006802A6EDC744B4000FDBE7FF394454006802A6EDC744B4000FDBE7FF3944540AB93331477724B4007978E39CF904540AB93331477724B40
17623	21964	45.084530999999998	45.134369	58.012238000000004	57.980041	Ленина	0103000020E61000000100000005000000C43F6CE9D18A46409CDEC5FB71FD4C40C43F6CE9D18A46405DE2C80391014D40514CDE00339146405DE2C80391014D40514CDE00339146409CDEC5FB71FD4C40C43F6CE9D18A46409CDEC5FB71FD4C40
17263	16344	45.168936000000002	45.198841000000002	57.942484999999998	57.923442999999999	Ленинская	0103000020E61000000100000005000000FC8EE1B19F9546402D5C566133F64C40FC8EE1B19F9546403BFC3559A3F84C404E0D349F739946403BFC3559A3F84C404E0D349F739946402D5C566133F64C40FC8EE1B19F9546402D5C566133F64C40
16679	26608	45.734228000000002	45.816164000000001	57.874965000000003	57.841835000000003	Бахирева	0103000020E610000001000000050000005CE7DF2EFBDD464068D0D03FC1EB4C405CE7DF2EFBDD4640841266DAFEEF4C401616DC0F78E84640841266DAFEEF4C401616DC0F78E8464068D0D03FC1EB4C405CE7DF2EFBDD464068D0D03FC1EB4C40
17254	49767	45.734228000000002	45.816164000000001	57.874965000000003	57.841835000000003	Спортивная	0103000020E610000001000000050000005CE7DF2EFBDD464068D0D03FC1EB4C405CE7DF2EFBDD4640841266DAFEEF4C401616DC0F78E84640841266DAFEEF4C401616DC0F78E8464068D0D03FC1EB4C405CE7DF2EFBDD464068D0D03FC1EB4C40
17616	49767	45.734228000000002	45.816164000000001	57.874965000000003	57.841835000000003	Бахирева	0103000020E610000001000000050000005CE7DF2EFBDD464068D0D03FC1EB4C405CE7DF2EFBDD4640841266DAFEEF4C401616DC0F78E84640841266DAFEEF4C401616DC0F78E8464068D0D03FC1EB4C405CE7DF2EFBDD464068D0D03FC1EB4C40
17602	26022	42.628438000000003	42.654713999999998	55.902918999999997	55.888542999999999	Советская	0103000020E6100000010000000500000026C808A8705045407C0BEBC6BBF14B4026C808A870504540F0F78BD992F34B40DE1D19ABCD534540F0F78BD992F34B40DE1D19ABCD5345407C0BEBC6BBF14B4026C808A8705045407C0BEBC6BBF14B40
17906	26328	42.742640999999999	42.770479999999999	55.962181000000001	55.947463999999997	Набережная	0103000020E6100000010000000500000099D53BDC0E5F45409411178046F94B4099D53BDC0E5F454092EA3BBF28FB4B406D1CB1169F62454092EA3BBF28FB4B406D1CB1169F6245409411178046F94B4099D53BDC0E5F45409411178046F94B40
17229	26036	42.461899000000003	42.524296	55.770097	55.737228000000002	Больничная	0103000020E610000001000000050000000E87A5811F3B454006D9B27C5DDE4B400E87A5811F3B4540B5DFDA8992E24B4039B69E211C434540B5DFDA8992E24B4039B69E211C43454006D9B27C5DDE4B400E87A5811F3B454006D9B27C5DDE4B40
17600	25887	42.722203999999998	42.752153999999997	55.847295000000003	55.833637000000003	Школьная	0103000020E610000001000000050000002B85402E715C454027DE019EB4EA4B402B85402E715C45403C889D2974EC4B401DC70F95466045403C889D2974EC4B401DC70F954660454027DE019EB4EA4B402B85402E715C454027DE019EB4EA4B40
19464	25835	42.665826000000003	42.707363999999998	55.819372999999999	55.784540999999997	Ленина	0103000020E61000000100000005000000CB694FC93955454081AFE8D66BE44B40CB694FC939554540DA1CE736E1E84B40122F4FE78A5A4540DA1CE736E1E84B40122F4FE78A5A454081AFE8D66BE44B40CB694FC93955454081AFE8D66BE44B40
17853	25344	42.849432	42.863517999999999	55.836064	55.819893999999998	Медоварцево	0103000020E6100000010000000500000083161230BA6C4540E3175E49F2E84B4083161230BA6C454075AE282504EB4B40F0C000C2876E454075AE282504EB4B40F0C000C2876E4540E3175E49F2E84B4083161230BA6C4540E3175E49F2E84B40
17246	25956	42.632139000000002	42.650995000000002	55.844025000000002	55.828747999999997	Школьная	0103000020E6100000010000000500000059C345EEE95045400D501A6A14EA4B4059C345EEE9504540D200DE0209EC4B40056EDDCD53534540D200DE0209EC4B40056EDDCD535345400D501A6A14EA4B4059C345EEE95045400D501A6A14EA4B40
16990	25528	42.752961999999997	42.782947999999998	55.773034000000003	55.754573000000001	Заводская	0103000020E61000000100000005000000BC900E0F61604540E9B81AD995E04B40BC900E0F61604540195932C7F2E24B40FB3BDBA337644540195932C7F2E24B40FB3BDBA337644540E9B81AD995E04B40BC900E0F61604540E9B81AD995E04B40
17863	25590	42.754390999999998	42.775708000000002	55.736797000000003	55.728515000000002	молодежная	0103000020E61000000100000005000000C8B260E28F6045409ED2C1FA3FDD4B40C8B260E28F6045403D65355D4FDE4B406F9F55664A6345403D65355D4FDE4B406F9F55664A6345409ED2C1FA3FDD4B40C8B260E28F6045409ED2C1FA3FDD4B40
17418	26164	42.620623000000002	42.645093000000003	55.701627999999999	55.687080999999999	Большая слобода	0103000020E610000001000000050000009D121093704F4540FB592C45F2D74B409D121093704F45409CFA40F2CED94B4074F04C68925245409CFA40F2CED94B4074F04C6892524540FB592C45F2D74B409D121093704F4540FB592C45F2D74B40
19452	25299	42.897419999999997	42.920147999999998	55.881515	55.871481000000003	Зеленая	0103000020E610000001000000050000005E6397A8DE724540EE0A7DB08CEF4B405E6397A8DE7245407BF7C77BD5F04B406ABDDF68C77545407BF7C77BD5F04B406ABDDF68C7754540EE0A7DB08CEF4B405E6397A8DE724540EE0A7DB08CEF4B40
16687	21807	42.706671999999998	42.797618	55.814886999999999	55.789805999999999	Советская	0103000020E61000000100000005000000DC7F643A745A4540A017EE5C18E54B40DC7F643A745A4540C0779B374EE84B40B859BC5818664540C0779B374EE84B40B859BC5818664540A017EE5C18E54B40DC7F643A745A4540A017EE5C18E54B40
16678	21807	42.706671999999998	42.797618	55.814886999999999	55.789805999999999	Ленина	0103000020E61000000100000005000000DC7F643A745A4540A017EE5C18E54B40DC7F643A745A4540C0779B374EE84B40B859BC5818664540C0779B374EE84B40B859BC5818664540A017EE5C18E54B40DC7F643A745A4540A017EE5C18E54B40
17243	21807	42.706671999999998	42.797618	55.814886999999999	55.789805999999999	Больничная	0103000020E61000000100000005000000DC7F643A745A4540A017EE5C18E54B40DC7F643A745A4540C0779B374EE84B40B859BC5818664540C0779B374EE84B40B859BC5818664540A017EE5C18E54B40DC7F643A745A4540A017EE5C18E54B40
18098	25770	42.784923999999997	42.799925999999999	55.783437999999997	55.77355	Большой порядок	0103000020E6100000010000000500000039ECBE637864454010E9B7AF03E34B4039ECBE6378644540C93846B247E44B402C9CA4F963664540C93846B247E44B402C9CA4F96366454010E9B7AF03E34B4039ECBE637864454010E9B7AF03E34B40
17848	25205	42.856853000000001	42.882418999999999	55.878737999999998	55.869799	Пестрякова	0103000020E61000000100000005000000603DEE5BAD6D4540F88BD99255EF4B40603DEE5BAD6D454050E09D7C7AF04B403C2F151BF370454050E09D7C7AF04B403C2F151BF3704540F88BD99255EF4B40603DEE5BAD6D4540F88BD99255EF4B40
17197	25205	42.856853000000001	42.882418999999999	55.878737999999998	55.869799	Первомайская	0103000020E61000000100000005000000603DEE5BAD6D4540F88BD99255EF4B40603DEE5BAD6D454050E09D7C7AF04B403C2F151BF370454050E09D7C7AF04B403C2F151BF3704540F88BD99255EF4B40603DEE5BAD6D4540F88BD99255EF4B40
17217	25688	42.810220999999999	42.836675999999997	55.802199000000002	55.789841000000003	Советская	0103000020E6100000010000000500000026C45C52B56745401D05888219E54B4026C45C52B567454024F1F274AEE64B408EACFC32186B454024F1F274AEE64B408EACFC32186B45401D05888219E54B4026C45C52B56745401D05888219E54B40
16972	24800	44.635300999999998	44.649242999999998	57.367249000000001	57.355758999999999	Советская	0103000020E61000000100000005000000DC0E0D8B51514640FB20CB8289AD4C40DC0E0D8B515146408E3EE60302AF4C40161406651A5346408E3EE60302AF4C40161406651A534640FB20CB8289AD4C40DC0E0D8B51514640FB20CB8289AD4C40
16791	25105	44.560400000000001	44.601712999999997	57.495533999999999	57.468767999999997	Молодежная	0103000020E61000000100000005000000D656EC2FBB474640A6B4FE9600BC4C40D656EC2FBB4746402D077AA86DBF4C40FD497CEE044D46402D077AA86DBF4C40FD497CEE044D4640A6B4FE9600BC4C40D656EC2FBB474640A6B4FE9600BC4C40
16917	25072	44.805613000000001	44.820588000000001	57.343409999999999	57.335881000000001	Центральная	0103000020E61000000100000005000000C11DA8531E674640842C0B26FEAA4C40C11DA8531E674640478FDFDBF4AB4C40BABE0F0709694640478FDFDBF4AB4C40BABE0F0709694640842C0B26FEAA4C40C11DA8531E674640842C0B26FEAA4C40
17834	24962	45.039003999999998	45.068486999999998	57.433345000000003	57.422727999999999	Школьная	0103000020E61000000100000005000000E3344415FE8446403F8D7BF31BB64C40E3344415FE8446404C7155D977B74C40BF99982EC48846404C7155D977B74C40BF99982EC48846403F8D7BF31BB64C40E3344415FE8446403F8D7BF31BB64C40
16787	24878	45.010086999999999	45.024667000000001	57.300348	57.292406999999997	Молодежная	0103000020E61000000100000005000000B08EE3874A8146408C0FB3976DA54C40B08EE3874A814640A2B5A2CD71A64C402D25CB4928834640A2B5A2CD71A64C402D25CB49288346408C0FB3976DA54C40B08EE3874A8146408C0FB3976DA54C40
17179	24652	44.999091999999997	45.023077000000001	57.720742999999999	57.710489000000003	Ленинская	0103000020E61000000100000005000000FDD8243FE27F46407995B54DF1DA4C40FDD8243FE27F464014E97E4E41DC4C401825E82FF482464014E97E4E41DC4C401825E82FF48246407995B54DF1DA4C40FDD8243FE27F46407995B54DF1DA4C40
16968	24703	44.710239000000001	44.730423999999999	57.239978000000001	57.228467999999999	Центральная	0103000020E6100000010000000500000000AC8E1CE95A46405D177E703E9D4C4000AC8E1CE95A464037E15E99B79E4C40541B9C887E5D464037E15E99B79E4C40541B9C887E5D46405D177E703E9D4C4000AC8E1CE95A46405D177E703E9D4C40
17137	24490	45.050699999999999	45.109360000000002	57.410291000000001	57.39085	III Интернационала	0103000020E610000001000000050000001FF46C567D86464020D26F5F07B24C401FF46C567D864640EC6B5D6A84B44C40CBBE2B82FF8D4640EC6B5D6A84B44C40CBBE2B82FF8D464020D26F5F07B24C401FF46C567D86464020D26F5F07B24C40
16973	24934	44.998894	45.022179000000001	57.366948000000001	57.353442999999999	Первомайская	0103000020E61000000100000005000000D71533C2DB7F46400400C79E3DAD4C40D71533C2DB7F464093AAED26F8AE4C4039D4EFC2D682464093AAED26F8AE4C4039D4EFC2D68246400400C79E3DAD4C40D71533C2DB7F46400400C79E3DAD4C40
16964	24614	45.056691999999998	45.093648999999999	57.671249000000003	57.658684000000001	Антонихинская	0103000020E61000000100000005000000F0F8F6AE418746400133DFC14FD44C40F0F8F6AE41874640823CBB7CEBD54C40CC26C0B0FC8B4640823CBB7CEBD54C40CC26C0B0FC8B46400133DFC14FD44C40F0F8F6AE418746400133DFC14FD44C40
16784	23879	44.047569000000003	44.065283999999998	55.498235000000001	55.484923000000002	Микрорайон	0103000020E61000000100000005000000D7A6B1BD16064640030AF5F411BE4B40D7A6B1BD160646407D5C1B2AC6BF4B40DD79E2395B0846407D5C1B2AC6BF4B40DD79E2395B084640030AF5F411BE4B40D7A6B1BD16064640030AF5F411BE4B40
17566	24479	44.116838999999999	44.137033000000002	55.411679999999997	55.402479999999997	Майская	0103000020E61000000100000005000000DCF29194F40E4640A4A5F27684B34B40DCF29194F40E4640693524EEB1B44B4084BC1E4C8A114640693524EEB1B44B4084BC1E4C8A114640A4A5F27684B34B40DCF29194F40E4640A4A5F27684B34B40
17381	23064	44.322426999999998	44.345531999999999	55.466703000000003	55.450006000000002	Центральная	0103000020E61000000100000005000000772CB649452946407C80EECB99B94B40772CB64945294640F9F884ECBCBB4B4059DC7F643A2C4640F9F884ECBCBB4B4059DC7F643A2C46407C80EECB99B94B40772CB649452946407C80EECB99B94B40
16958	22935	44.298963000000001	44.324376000000001	55.653334999999998	55.643073000000001	Молодежная	0103000020E6100000010000000500000066DB696B4426464066F84F3750D24B4066DB696B44264640842A357BA0D34B40BCCD1B2785294640842A357BA0D34B40BCCD1B278529464066F84F3750D24B4066DB696B4426464066F84F3750D24B40
17384	25423	44.162087	44.192953000000003	55.449368	55.431789999999999	Микрорайон	0103000020E61000000100000005000000AA0D4E44BF144640B35E0CE544B74B40AA0D4E44BF14464039EFFFE384B94B40225514AFB218464039EFFFE384B94B40225514AFB2184640B35E0CE544B74B40AA0D4E44BF144640B35E0CE544B74B40
17563	24150	44.307614000000001	44.334544999999999	55.525609000000003	55.506036000000002	Лопатинская	0103000020E6100000010000000500000058E542E55F274640A14CA3C9C5C04B4058E542E55F274640DCBDDC2747C34B402905DD5ED22A4640DCBDDC2747C34B402905DD5ED22A4640A14CA3C9C5C04B4058E542E55F274640A14CA3C9C5C04B40
16951	22857	44.051485999999997	44.088757000000001	55.597428999999998	55.577007000000002	Микрорайон	0103000020E61000000100000005000000D619DF17970646401348895DDBC94B40D619DF17970646404B57B08D78CC4B404225AE635C0B46404B57B08D78CC4B404225AE635C0B46401348895DDBC94B40D619DF17970646401348895DDBC94B40
16953	22864	44.192521999999997	44.234122999999997	55.622369999999997	55.610793999999999	Садовая	0103000020E6100000010000000500000058E1968FA4184640E84B6F7F2ECE4B4058E1968FA41846407901F6D1A9CF4B40E61E12BEF71D46407901F6D1A9CF4B40E61E12BEF71D4640E84B6F7F2ECE4B4058E1968FA4184640E84B6F7F2ECE4B40
16713	22706	44.173127000000001	44.224896999999999	55.548909999999999	55.516663999999999	Просвещения	0103000020E61000000100000005000000FD86890629164640A182C30B22C24B40FD868906291646404339D1AE42C64B40F8FBC56CC91C46404339D1AE42C64B40F8FBC56CC91C4640A182C30B22C24B40FD86890629164640A182C30B22C24B40
17066	22706	44.173127000000001	44.224896999999999	55.548909999999999	55.516663999999999	50 пет Октября	0103000020E61000000100000005000000FD86890629164640A182C30B22C24B40FD868906291646404339D1AE42C64B40F8FBC56CC91C46404339D1AE42C64B40F8FBC56CC91C4640A182C30B22C24B40FD86890629164640A182C30B22C24B40
19483	49733	44.359932000000001	44.384329999999999	55.482545999999999	55.458868000000002	улица Центральная	0103000020E6100000010000000500000056647440122E46402997C62FBCBA4B4056647440122E464066683C11C4BD4B40936FB6B93131464066683C11C4BD4B40936FB6B9313146402997C62FBCBA4B4056647440122E46402997C62FBCBA4B40
16938	22482	44.993343000000003	45.014749999999999	55.543118999999997	55.534891999999999	Советская	0103000020E61000000100000005000000F35A09DD257F46402E724F5777C44B40F35A09DD257F4640096B63EC84C54B40D9CEF753E3814640096B63EC84C54B40D9CEF753E38146402E724F5777C44B40F35A09DD257F46402E724F5777C44B40
17154	22535	45.09187	45.115900000000003	55.471055999999997	55.460481000000001	Октябрьская	0103000020E61000000100000005000000E4BD6A65C28B4640F6B6990AF1BA4B40E4BD6A65C28B4640D34A21904BBC4B409FCDAACFD58E4640D34A21904BBC4B409FCDAACFD58E4640F6B6990AF1BA4B40E4BD6A65C28B4640F6B6990AF1BA4B40
17904	21970	44.779165999999996	44.800043000000002	55.594962000000002	55.582940000000001	Сутягина	0103000020E61000000100000005000000DB1324B6BB634640DFC325C79DCA4B40DB1324B6BB6346406F2EFEB627CC4B4066321CCF676646406F2EFEB627CC4B4066321CCF67664640DFC325C79DCA4B40DB1324B6BB634640DFC325C79DCA4B40
17750	23109	44.752414999999999	44.774872000000002	55.526353	55.515053999999999	Мира	0103000020E610000001000000050000008A027D224F60464045D61A4AEDC14B408A027D224F6046406493FC885FC34B40064B75012F6346406493FC885FC34B40064B75012F63464045D61A4AEDC14B408A027D224F60464045D61A4AEDC14B40
17362	22450	44.797806000000001	44.831305	55.461956000000001	55.450251000000002	Центральная	0103000020E61000000100000005000000BB46CB811E664640E3FE23D3A1B94B40BB46CB811E6646407218CC5F21BB4B402A00C633686A46407218CC5F21BB4B402A00C633686A4640E3FE23D3A1B94B40BB46CB811E664640E3FE23D3A1B94B40
16930	22983	45.125027000000003	45.149811	55.646360000000001	55.628728000000002	Ленина	0103000020E61000000100000005000000FA0E7EE2009046402D0ABB287AD04B40FA0E7EE200904640A6B8AAECBBD24B4060CAC0012D934640A6B8AAECBBD24B4060CAC0012D9346402D0ABB287AD04B40FA0E7EE2009046402D0ABB287AD04B40
16939	23144	44.973489999999998	45.006475999999999	55.453130999999999	55.436253999999998	Центральная	0103000020E61000000100000005000000D47D00529B7C4640E55FCB2BD7B74B40D47D00529B7C4640E2E6543200BA4B40BD1AA034D4804640E2E6543200BA4B40BD1AA034D4804640E55FCB2BD7B74B40D47D00529B7C4640E55FCB2BD7B74B40
16778	23062	44.695461000000002	44.730620999999999	55.483866999999996	55.467911999999998	Новая	0103000020E610000001000000050000005D52B5DD04594640F6B3588AE4BB4B405D52B5DD045946408B4E965AEFBD4B40AA622AFD845D46408B4E965AEFBD4B40AA622AFD845D4640F6B3588AE4BB4B405D52B5DD04594640F6B3588AE4BB4B40
17150	22342	44.972915	44.994430000000001	55.478306000000003	55.467336000000003	Нагорная	0103000020E61000000100000005000000D8648D7A887C46402A1F82AAD1BB4B40D8648D7A887C464084BD892139BD4B40A514747B497F464084BD892139BD4B40A514747B497F46402A1F82AAD1BB4B40D8648D7A887C46402A1F82AAD1BB4B40
17740	22938	45.004167000000002	45.024577000000001	55.599947	55.580528000000001	1 Мая	0103000020E61000000100000005000000795C548B88804640C634D3BD4ECA4B40795C548B88804640AA2A3410CBCC4B40ED9DD15625834640AA2A3410CBCC4B40ED9DD15625834640C634D3BD4ECA4B40795C548B88804640C634D3BD4ECA4B40
17753	22410	44.861469999999997	44.891751999999997	55.431994000000003	55.418114000000003	Школьная	0103000020E61000000100000005000000183E22A6446E4640F8FF71C284B54B40183E22A6446E4640BC0853944BB74B404012F6ED24724640BC0853944BB74B404012F6ED24724640F8FF71C284B54B40183E22A6446E4640F8FF71C284B54B40
17739	22860	44.850645	44.880414999999999	55.605378000000002	55.592601999999999	Молодежная	0103000020E61000000100000005000000C2C073EFE16C4640A8C5E061DACB4B40C2C073EFE16C4640E4DBBB067DCD4B4034F44F70B1704640E4DBBB067DCD4B4034F44F70B1704640A8C5E061DACB4B40C2C073EFE16C4640A8C5E061DACB4B40
17532	18239	44.861784	44.935662000000001	55.586663999999999	55.561548000000002	П.Бегина	0103000020E61000000100000005000000A81B28F04E6E46402E910BCEE0C74B40A81B28F04E6E4640CADE52CE17CB4B40130EBDC5C3774640CADE52CE17CB4B40130EBDC5C37746402E910BCEE0C74B40A81B28F04E6E46402E910BCEE0C74B40
16771	18239	44.861784	44.935662000000001	55.586663999999999	55.561548000000002	Ленина	0103000020E61000000100000005000000A81B28F04E6E46402E910BCEE0C74B40A81B28F04E6E4640CADE52CE17CB4B40130EBDC5C3774640CADE52CE17CB4B40130EBDC5C37746402E910BCEE0C74B40A81B28F04E6E46402E910BCEE0C74B40
17737	18239	44.861784	44.935662000000001	55.586663999999999	55.561548000000002	Комсомольская	0103000020E61000000100000005000000A81B28F04E6E46402E910BCEE0C74B40A81B28F04E6E4640CADE52CE17CB4B40130EBDC5C3774640CADE52CE17CB4B40130EBDC5C37746402E910BCEE0C74B40A81B28F04E6E46402E910BCEE0C74B40
17551	22626	44.760967000000001	44.794015999999999	55.384031999999998	55.365155999999999	Центральная	0103000020E61000000100000005000000E92ADD5D6761464016F88A6EBDAE4B40E92ADD5D67614640094FE8F527B14B401840F850A2654640094FE8F527B14B401840F850A265464016F88A6EBDAE4B40E92ADD5D6761464016F88A6EBDAE4B40
17648	22679	44.552647	44.574413	55.388731999999997	55.376154999999997	Спортивная	0103000020E61000000100000005000000C39D0B23BD4646400A9DD7D825B04B40C39D0B23BD4646404F745DF8C1B14B40D9B27C5D864946404F745DF8C1B14B40D9B27C5D864946400A9DD7D825B04B40C39D0B23BD4646400A9DD7D825B04B40
17738	22862	44.723390000000002	44.758989999999997	55.669432	55.648209000000001	Первомайская	0103000020E610000001000000050000007120240B985C464087FC3383F8D24B407120240B985C4640AC72A1F2AFD54B40DAFE959526614640AC72A1F2AFD54B40DAFE95952661464087FC3383F8D24B407120240B985C464087FC3383F8D24B40
16948	49713	44.526254999999999	44.567253999999998	56.260067999999997	56.236550999999999	Школьная	0103000020E61000000100000005000000A12DE7525C434640056B9C4D471E4C40A12DE7525C434640395E81E849214C40394371C79B484640395E81E849214C40394371C79B484640056B9C4D471E4C40A12DE7525C434640056B9C4D471E4C40
16920	49707	44.405773000000003	44.42991	56.257958000000002	56.246636000000002	Ленина	0103000020E61000000100000005000000C74CA25EF03346401502B9C4911F4C40C74CA25EF0334640ECDE8AC404214C40971C774A07374640ECDE8AC404214C40971C774A073746401502B9C4911F4C40C74CA25EF03346401502B9C4911F4C40
17115	21041	44.017296000000002	44.071455999999998	56.451697000000003	56.439478000000001	Центральная	0103000020E61000000100000005000000022D5DC136024640DFA7AAD040384C40022D5DC136024640C5591135D1394C402E8D5F7825094640C5591135D1394C402E8D5F7825094640DFA7AAD040384C40022D5DC136024640DFA7AAD040384C40
19422	50024	44.764747999999997	44.788257000000002	56.196055999999999	56.178448000000003	Школьная	0103000020E6100000010000000500000038D73043E3614640B0045262D7164C4038D73043E3614640A017EE5C18194C40EAEBF99AE5644640A017EE5C18194C40EAEBF99AE5644640B0045262D7164C4038D73043E3614640B0045262D7164C40
17145	49742	44.475554000000002	44.510919999999999	56.116447999999998	56.097943999999998	Школьная	0103000020E61000000100000005000000B2BD16F4DE3C4640726BD26D890C4C40B2BD16F4DE3C4640A1D79FC4E70E4C40A86F99D365414640A1D79FC4E70E4C40A86F99D365414640726BD26D890C4C40B2BD16F4DE3C4640726BD26D890C4C40
17088	49742	44.475554000000002	44.510919999999999	56.116447999999998	56.097943999999998	Зеленая	0103000020E61000000100000005000000B2BD16F4DE3C4640726BD26D890C4C40B2BD16F4DE3C4640A1D79FC4E70E4C40A86F99D365414640A1D79FC4E70E4C40A86F99D365414640726BD26D890C4C40B2BD16F4DE3C4640726BD26D890C4C40
16711	49629	44.331913	44.443179000000001	56.393847999999998	56.259763	Школьная	0103000020E61000000100000005000000020F0C207C2A4640FDDAFAE93F214C40020F0C207C2A464029CC7B9C69324C4012A3E716BA38464029CC7B9C69324C4012A3E716BA384640FDDAFAE93F214C40020F0C207C2A4640FDDAFAE93F214C40
17155	49756	43.790453999999997	45.221066	56.896185000000003	56.052326000000001	Победы	0103000020E61000000100000005000000067FBF982DE54540815D4D9EB2064C40067FBF982DE545403815A930B6724C40F72004E44B9C46403815A930B6724C40F72004E44B9C4640815D4D9EB2064C40067FBF982DE54540815D4D9EB2064C40
17610	20794	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	кварт. Дружба	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
17698	20794	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	Лесная	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
17315	20794	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	Клубная	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
17534	20794	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	Дружбы	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
17697	20794	43.970440000000004	44.019955000000003	56.418337999999999	56.393712999999998	Вокзальная	0103000020E61000000100000005000000795DBF6037FC45404981053065324C40795DBF6037FC454047567E198C354C402332ACE28D02464047567E198C354C402332ACE28D0246404981053065324C40795DBF6037FC45404981053065324C40
16719	8243	44.080044000000001	44.126379	56.630808000000002	56.604582000000001	Школьная	0103000020E61000000100000005000000DA1EBDE13E0A464009E066F1624D4C40DA1EBDE13E0A464010070951BE504C405AF3E32F2D10464010070951BE504C405AF3E32F2D10464009E066F1624D4C40DA1EBDE13E0A464009E066F1624D4C40
17333	8243	44.080044000000001	44.126379	56.630808000000002	56.604582000000001	Дзержинского	0103000020E61000000100000005000000DA1EBDE13E0A464009E066F1624D4C40DA1EBDE13E0A464010070951BE504C405AF3E32F2D10464010070951BE504C405AF3E32F2D10464009E066F1624D4C40DA1EBDE13E0A464009E066F1624D4C40
16912	49703	44.179900000000004	44.194597000000002	56.437905000000001	56.428950999999998	Центральная	0103000020E61000000100000005000000744694F606174640124BCADDE7364C40744694F606174640A0E062450D384C402A73F38DE8184640A0E062450D384C402A73F38DE8184640124BCADDE7364C40744694F606174640124BCADDE7364C40
17475	49801	44.025281999999997	44.053857999999998	56.498896999999999	56.490107000000002	Совхозная	0103000020E61000000100000005000000B796C9703C034640354580D3BB3E4C40B796C9703C03464048895DDBDB3F4C406150A6D1E406464048895DDBDB3F4C406150A6D1E4064640354580D3BB3E4C40B796C9703C034640354580D3BB3E4C40
17677	49830	44.49644	44.523847000000004	56.225838000000003	56.210566999999998	Клубная	0103000020E610000001000000050000008F368E588B3F4640F44E05DCF31A4C408F368E588B3F4640D7187442E81C4C40CA8D226B0D434640D7187442E81C4C40CA8D226B0D434640F44E05DCF31A4C408F368E588B3F4640F44E05DCF31A4C40
16752	14639	44.033107000000001	44.077178000000004	56.488328000000003	56.463495999999999	Центральная	0103000020E610000001000000050000006422A5D93C044640D5E940D6533B4C406422A5D93C0446404DDC2A88813E4C4040FCFCF7E00946404DDC2A88813E4C4040FCFCF7E0094640D5E940D6533B4C406422A5D93C044640D5E940D6533B4C40
19811	50081	44.021329999999999	44.052231999999997	56.395556999999997	56.379964999999999	Филатова	0103000020E610000001000000050000003B3602F1BA024640F44F70B1A2304C403B3602F1BA024640185A9D9CA1324C40FFE6C589AF064640185A9D9CA1324C40FFE6C589AF064640F44F70B1A2304C403B3602F1BA024640F44F70B1A2304C40
17393	49787	44.182344000000001	44.201127	56.357106000000002	56.341667000000001	1 Мая	0103000020E61000000100000005000000984F560C57174640AC8F87BEBB2B4C40984F560C571746404A9A3FA6B52D4C40DAAB8F87BE1946404A9A3FA6B52D4C40DAAB8F87BE194640AC8F87BEBB2B4C40984F560C57174640AC8F87BEBB2B4C40
18012	18050	44.745480000000001	44.795408000000002	55.796394999999997	55.762064000000002	п.Меховщиков	0103000020E610000001000000050000003AE97DE36B5F4640BFBA2A508BE14B403AE97DE36B5F464055D97745F0E54B40077DE9EDCF65464055D97745F0E54B40077DE9EDCF654640BFBA2A508BE14B403AE97DE36B5F4640BFBA2A508BE14B40
17264	18050	44.745480000000001	44.795408000000002	55.796394999999997	55.762064000000002	Спортивная	0103000020E610000001000000050000003AE97DE36B5F4640BFBA2A508BE14B403AE97DE36B5F464055D97745F0E54B40077DE9EDCF65464055D97745F0E54B40077DE9EDCF654640BFBA2A508BE14B403AE97DE36B5F4640BFBA2A508BE14B40
17951	18050	44.745480000000001	44.795408000000002	55.796394999999997	55.762064000000002	Свободы	0103000020E610000001000000050000003AE97DE36B5F4640BFBA2A508BE14B403AE97DE36B5F464055D97745F0E54B40077DE9EDCF65464055D97745F0E54B40077DE9EDCF654640BFBA2A508BE14B403AE97DE36B5F4640BFBA2A508BE14B40
17956	18050	44.745480000000001	44.795408000000002	55.796394999999997	55.762064000000002	6-й микрорайон	0103000020E610000001000000050000003AE97DE36B5F4640BFBA2A508BE14B403AE97DE36B5F464055D97745F0E54B40077DE9EDCF65464055D97745F0E54B40077DE9EDCF654640BFBA2A508BE14B403AE97DE36B5F4640BFBA2A508BE14B40
17939	18000	45.099775000000001	45.127218999999997	54.988742000000002	54.971336000000001	Восточная	0103000020E61000000100000005000000ADFA5C6DC58C4640B7B6F0BC547C4B40ADFA5C6DC58C464040170D198F7E4B40043752B64890464040170D198F7E4B40043752B648904640B7B6F0BC547C4B40ADFA5C6DC58C4640B7B6F0BC547C4B40
17257	17964	45.350971000000001	45.384864	55.134821000000002	55.115785000000002	Центральная	0103000020E61000000100000005000000166C239EECAC4640062FFA0AD28E4B40166C239EECAC464032E884D041914B4031B43A3943B1464032E884D041914B4031B43A3943B14640062FFA0AD28E4B40166C239EECAC4640062FFA0AD28E4B40
17039	17901	45.348877999999999	45.368282000000001	55.112901000000001	55.096549000000003	Центральная	0103000020E610000001000000050000009E25C808A8AC464013BBB6B75B8C4B409E25C808A8AC4640C5573B8A738E4B404DDA54DD23AF4640C5573B8A738E4B404DDA54DD23AF464013BBB6B75B8C4B409E25C808A8AC464013BBB6B75B8C4B40
17253	17797	45.07508	45.083272999999998	55.044499999999999	55.034821999999998	Школьная	0103000020E61000000100000005000000B64AB0389C89464035971B0C75844B40B64AB0389C89464004560E2DB2854B40E5D18DB0A88A464004560E2DB2854B40E5D18DB0A88A464035971B0C75844B40B64AB0389C89464035971B0C75844B40
16813	17721	45.232357	45.265639999999998	55.139952000000001	55.120958999999999	Балашова	0103000020E6100000010000000500000093FFC9DFBD9D46401494A2957B8F4B4093FFC9DFBD9D4640418177F2E9914B403541D47D00A24640418177F2E9914B403541D47D00A246401494A2957B8F4B4093FFC9DFBD9D46401494A2957B8F4B40
17256	17817	45.169862000000002	45.207644999999999	55.007468000000003	54.990189000000001	Ленина	0103000020E61000000100000005000000A56ABB09BE954640F2ED5D83BE7E4B40A56ABB09BE9546401EE21FB6F4804B40C616821C949A46401EE21FB6F4804B40C616821C949A4640F2ED5D83BE7E4B40A56ABB09BE954640F2ED5D83BE7E4B40
16681	17646	45.359980999999998	45.387172999999997	54.990772	54.969113999999998	Ленина	0103000020E6100000010000000500000037177FDB13AE4640410C74ED0B7C4B4037177FDB13AE464071E5EC9DD17E4B40757286E28EB1464071E5EC9DD17E4B40757286E28EB14640410C74ED0B7C4B4037177FDB13AE4640410C74ED0B7C4B40
16812	17714	45.192230000000002	45.224344000000002	54.979835999999999	54.968525	Молодежная	0103000020E61000000100000005000000B1A71DFE9A984640E02D90A0F87B4B40B1A71DFE9A984640C3B81B446B7D4B40E486DF4DB79C4640C3B81B446B7D4B40E486DF4DB79C4640E02D90A0F87B4B40B1A71DFE9A984640E02D90A0F87B4B40
19539	50055	45.114696000000002	45.154842000000002	54.932234000000001	54.911352000000001	Советская	0103000020E61000000100000005000000B37DC85BAE8E46407592AD2EA7744B40B37DC85BAE8E4640111C977153774B400C06D7DCD1934640111C977153774B400C06D7DCD19346407592AD2EA7744B40B37DC85BAE8E46407592AD2EA7744B40
17549	17447	45.136049	45.167552999999998	55.054639999999999	55.040078999999999	Советская	0103000020E61000000100000005000000A6D3BA0D6A914640D120054F21854B40A6D3BA0D6A914640D7868A71FE864B4060AC6F6072954640D7868A71FE864B4060AC6F6072954640D120054F21854B40A6D3BA0D6A914640D120054F21854B40
17239	15909	45.283929999999998	45.335529000000001	55.013641999999997	54.987094999999997	Пушкинская	0103000020E61000000100000005000000382D78D157A44640C6850321597E4B40382D78D157A446400FED6305BF814B4007EE409DF2AA46400FED6305BF814B4007EE409DF2AA4640C6850321597E4B40382D78D157A44640C6850321597E4B40
16999	15909	45.283929999999998	45.335529000000001	55.013641999999997	54.987094999999997	Красная	0103000020E61000000100000005000000382D78D157A44640C6850321597E4B40382D78D157A446400FED6305BF814B4007EE409DF2AA46400FED6305BF814B4007EE409DF2AA4640C6850321597E4B40382D78D157A44640C6850321597E4B40
17355	15909	45.283929999999998	45.335529000000001	55.013641999999997	54.987094999999997	Кооперативная	0103000020E61000000100000005000000382D78D157A44640C6850321597E4B40382D78D157A446400FED6305BF814B4007EE409DF2AA46400FED6305BF814B4007EE409DF2AA4640C6850321597E4B40382D78D157A44640C6850321597E4B40
16677	15909	45.283929999999998	45.335529000000001	55.013641999999997	54.987094999999997	Восточная	0103000020E61000000100000005000000382D78D157A44640C6850321597E4B40382D78D157A446400FED6305BF814B4007EE409DF2AA46400FED6305BF814B4007EE409DF2AA4640C6850321597E4B40382D78D157A44640C6850321597E4B40
16722	17099	45.405363999999999	45.427911999999999	55.095728999999999	55.071654000000002	Гагарина	0103000020E61000000100000005000000E57CB1F7E2B34640555051F52B894B40E57CB1F7E2B34640AF230ED9408C4B4071C806D2C5B64640AF230ED9408C4B4071C806D2C5B64640555051F52B894B40E57CB1F7E2B34640555051F52B894B40
17186	17036	45.28013	45.314185000000002	55.078313000000001	55.056877999999998	Ленина	0103000020E610000001000000050000007250C24CDBA3464052EE3EC747874B407250C24CDBA3464003ED0E29068A4B4067F2CD3637A8464003ED0E29068A4B4067F2CD3637A8464052EE3EC747874B407250C24CDBA3464052EE3EC747874B40
16712	49630	43.588917000000002	43.612614000000001	56.184465000000003	56.175116000000003	Совхозная	0103000020E610000001000000050000007B87DBA161CB4540D0807A336A164C407B87DBA161CB4540DA20938C9C174C402F89B3226ACE4540DA20938C9C174C402F89B3226ACE4540D0807A336A164C407B87DBA161CB4540D0807A336A164C40
17072	49736	43.867564999999999	43.875785	56.165132999999997	56.162470999999996	улица Пушкина	0103000020E61000000100000005000000BE13B35E0CEF454032C687D9CB144C40BE13B35E0CEF4540C43E011423154C40E7A90EB919F04540C43E011423154C40E7A90EB919F0454032C687D9CB144C40BE13B35E0CEF454032C687D9CB144C40
17867	16278	43.547207999999998	43.567959000000002	55.848882000000003	55.841512999999999	Дорожная	0103000020E61000000100000005000000060E68E90AC645405514AFB2B6EB4B40060E68E90AC64540E014562AA8EC4B40043C69E1B2C84540E014562AA8EC4B40043C69E1B2C845405514AFB2B6EB4B40060E68E90AC645405514AFB2B6EB4B40
17856	15986	43.845457000000003	43.875255000000003	56.075327999999999	56.058061000000002	Зеленая	0103000020E610000001000000050000004F965AEF37EC45402716F88A6E074C404F965AEF37EC45408E3C1059A4094C408B54185B08F045408E3C1059A4094C408B54185B08F045402716F88A6E074C404F965AEF37EC45402716F88A6E074C40
17397	49641	43.458454000000003	43.478064000000003	56.109416000000003	56.094147999999997	3-ий микрорайон	0103000020E61000000100000005000000365CE49EAEBA4540ED7DAA0A0D0C4C40365CE49EAEBA45405FD4EE57010E4C408EB27E3331BD45405FD4EE57010E4C408EB27E3331BD4540ED7DAA0A0D0C4C40365CE49EAEBA4540ED7DAA0A0D0C4C40
19453	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	переулок Карла Маркса	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
17192	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	Чернышевского	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
19436	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	Урицкого	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
17390	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	Пушкина	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
17006	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	Ленина	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
19402	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	Добролюбова	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
17182	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	Данилова	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
19442	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	Героя Салова	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
17388	49723	43.205911	43.939017	56.199882000000002	55.823377999999998	3-ий микрорайон	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
17841	15801	43.551672000000003	43.594774000000001	56.130226	56.117361000000002	Комсомольская	0103000020E61000000100000005000000390F27309DC64540B6696CAF050F4C40390F27309DC64540618BDD3EAB104C406C41EF8D21CC4540618BDD3EAB104C406C41EF8D21CC4540B6696CAF050F4C40390F27309DC64540B6696CAF050F4C40
19772	49817	43.104849999999999	43.717312999999997	56.644509999999997	56.371102	Пушкина	0103000020E61000000100000005000000287E8CB96B8D454077BD3445802F4C40287E8CB96B8D4540F4F8BD4D7F524C4071FF91E9D0DB4540F4F8BD4D7F524C4071FF91E9D0DB454077BD3445802F4C40287E8CB96B8D454077BD3445802F4C40
19789	49817	43.104849999999999	43.717312999999997	56.644509999999997	56.371102	Матросова	0103000020E61000000100000005000000287E8CB96B8D454077BD3445802F4C40287E8CB96B8D4540F4F8BD4D7F524C4071FF91E9D0DB4540F4F8BD4D7F524C4071FF91E9D0DB454077BD3445802F4C40287E8CB96B8D454077BD3445802F4C40
17593	49817	43.104849999999999	43.717312999999997	56.644509999999997	56.371102	Большая Школьная	0103000020E61000000100000005000000287E8CB96B8D454077BD3445802F4C40287E8CB96B8D4540F4F8BD4D7F524C4071FF91E9D0DB4540F4F8BD4D7F524C4071FF91E9D0DB454077BD3445802F4C40287E8CB96B8D454077BD3445802F4C40
17701	7288	43.346415999999998	43.378666000000003	56.625127999999997	56.605741999999999	Центральная	0103000020E61000000100000005000000D367075C57AC454025E82FF4884D4C40D367075C57AC45402DE8BD3104504C40B70DA32078B045402DE8BD3104504C40B70DA32078B0454025E82FF4884D4C40D367075C57AC454025E82FF4884D4C40
16780	13950	43.661679999999997	43.694864000000003	56.450915999999999	56.428742	Октября	0103000020E61000000100000005000000693524EEB1D44540F8359204E1364C40693524EEB1D445401F9F909DB7394C407995B54DF1D845401F9F909DB7394C407995B54DF1D84540F8359204E1364C40693524EEB1D44540F8359204E1364C40
17542	13792	43.611230999999997	43.655805000000001	56.455984999999998	56.424903999999998	Победы	0103000020E6100000010000000500000093A641D13CCE454044F8174163364C4093A641D13CCE4540B83B6BB75D3A4C40D2C6116BF1D34540B83B6BB75D3A4C40D2C6116BF1D3454044F8174163364C4093A641D13CCE454044F8174163364C40
18576	14272	43.445571999999999	43.470922999999999	56.537066000000003	56.523741999999999	Генерала Маргелова	0103000020E61000000100000005000000B401D88008B9454054C554FA09434C40B401D88008B9454093E52494BE444C4094F7713447BC454093E52494BE444C4094F7713447BC454054C554FA09434C40B401D88008B9454054C554FA09434C40
16934	13602	43.515433999999999	43.569952999999998	56.493580999999999	56.451557999999999	Садовая	0103000020E610000001000000050000008C9FC6BDF9C14540A31F0DA7CC394C408C9FC6BDF9C14540A77686A92D3F4C40E8A04B38F4C84540A77686A92D3F4C40E8A04B38F4C84540A31F0DA7CC394C408C9FC6BDF9C14540A31F0DA7CC394C40
17539	13602	43.515433999999999	43.569952999999998	56.493580999999999	56.451557999999999	Административная	0103000020E610000001000000050000008C9FC6BDF9C14540A31F0DA7CC394C408C9FC6BDF9C14540A77686A92D3F4C40E8A04B38F4C84540A77686A92D3F4C40E8A04B38F4C84540A31F0DA7CC394C408C9FC6BDF9C14540A31F0DA7CC394C40
17894	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	проспект Дзержинского	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
17735	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	пр.Дзержинского	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
17662	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Энгельса	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
17725	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Синякова	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
17734	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Свердлова	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
16715	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Олимпийская	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
16708	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Дзержинского	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
16774	40312	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Горького	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
16928	12841	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	проезд Дзержинского	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
17140	12841	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	пр.Дхержинского	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
16924	12841	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	площадь Минина	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
16910	12841	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	ЦКК	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
17136	12841	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Первомайская	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
9755	12841	43.551484000000002	43.635485000000003	56.511688999999997	56.465300999999997	Волжский рейд	0103000020E610000001000000050000003622180797C64540E6E5B0FB8E3B4C403622180797C64540895C70067F414C409E0C8E9257D14540895C70067F414C409E0C8E9257D14540E6E5B0FB8E3B4C403622180797C64540E6E5B0FB8E3B4C40
17152	13890	43.629215000000002	43.665103000000002	56.427064999999999	56.40802	Садовая	0103000020E610000001000000050000008A93FB1D8AD04540950ED6FF39344C408A93FB1D8AD045401422E010AA364C405ABC581822D545401422E010AA364C405ABC581822D54540950ED6FF39344C408A93FB1D8AD04540950ED6FF39344C40
17946	8877	43.404375999999999	43.432429999999997	55.395502	55.380415999999997	Советская	0103000020E61000000100000005000000C6A4BF97C2B345400470B378B1B04B40C6A4BF97C2B3454055C03DCF9FB24B4096E7C1DD59B7454055C03DCF9FB24B4096E7C1DD59B745400470B378B1B04B40C6A4BF97C2B345400470B378B1B04B40
17694	10680	43.722999000000002	43.800505999999999	55.612003999999999	55.587809	Ленина	0103000020E610000001000000050000003605323B8BDC4540B1A547533DCB4B403605323B8BDC4540B682A62556CE4B403A2009FB76E64540B682A62556CE4B403A2009FB76E64540B1A547533DCB4B403605323B8BDC4540B1A547533DCB4B40
16828	10623	43.725648999999997	43.769486999999998	55.445911000000002	55.425925999999997	Советская	0103000020E6100000010000000500000003B00111E2DC45400F4240BE84B64B4003B00111E2DC45409DF6949C13B94B403CD9CD8C7EE245409DF6949C13B94B403CD9CD8C7EE245400F4240BE84B64B4003B00111E2DC45400F4240BE84B64B40
17463	10589	43.501196	43.521247000000002	55.339528999999999	55.324083999999999	Центральная	0103000020E610000001000000050000006971C63027C045401494A2957BA94B406971C63027C045409485AFAF75AB4B40AE11C138B8C245409485AFAF75AB4B40AE11C138B8C245401494A2957BA94B406971C63027C045401494A2957BA94B40
16825	10512	43.533365000000003	43.555149	55.376154999999997	55.355325999999998	Центральная	0103000020E6100000010000000500000060EAE74D45C4454091B586527BAD4B4060EAE74D45C445400A9DD7D825B04B401CB4571F0FC745400A9DD7D825B04B401CB4571F0FC7454091B586527BAD4B4060EAE74D45C4454091B586527BAD4B40
17094	10010	43.589581000000003	43.619774	55.666203000000003	55.654884000000003	Красная	0103000020E61000000100000005000000E7ABE46377CB45403B56293DD3D34B40E7ABE46377CB4540A1BFD02346D54B409F7422C154CF4540A1BFD02346D54B409F7422C154CF45403B56293DD3D34B40E7ABE46377CB45403B56293DD3D34B40
17293	9767	43.890858000000001	43.923135000000002	55.490386000000001	55.478178999999997	Новая	0103000020E61000000100000005000000A3B08BA207F2454026512FF834BD4B40A3B08BA207F245404835ECF7C4BE4B408065A54929F645404835ECF7C4BE4B408065A54929F6454026512FF834BD4B40A3B08BA207F2454026512FF834BD4B40
18170	10868	43.703145999999997	43.722496	55.630826999999996	55.613574999999997	Фабричная	0103000020E61000000100000005000000172829B000DA4540545227A089CE4B40172829B000DA454086376BF0BED04B40D3BEB9BF7ADC454086376BF0BED04B40D3BEB9BF7ADC4540545227A089CE4B40172829B000DA4540545227A089CE4B40
18076	10225	43.901755000000001	43.941828999999998	55.317214999999997	55.291967	Юбилейная	0103000020E61000000100000005000000930035B56CF345407041B62C5FA54B40930035B56CF345407B6649809AA84B4052B648DA8DF845407B6649809AA84B4052B648DA8DF845407041B62C5FA54B40930035B56CF345407041B62C5FA54B40
17485	10308	43.568371999999997	43.611778999999999	55.541193	55.528269000000002	Центральная	0103000020E6100000010000000500000026FBE769C0C84540CD3E8F519EC34B4026FBE769C0C845407DE9EDCF45C54B4096B036C64ECE45407DE9EDCF45C54B4096B036C64ECE4540CD3E8F519EC34B4026FBE769C0C84540CD3E8F519EC34B40
16916	10077	43.480589000000002	43.513620000000003	55.649352	55.635345000000001	ул.Молодежная	0103000020E610000001000000050000009FE8BAF083BD4540AC5626FC52D14B409FE8BAF083BD4540CDCB61F71DD34B402849D74CBEC14540CDCB61F71DD34B402849D74CBEC14540AC5626FC52D14B409FE8BAF083BD4540AC5626FC52D14B40
17477	9865	43.822882999999997	43.856380999999999	55.597285999999997	55.575332000000003	Лесная	0103000020E6100000010000000500000099B7EA3A54E94540D02B9E7AA4C94B4099B7EA3A54E94540E82D1EDE73CC4B4038F581E49DED4540E82D1EDE73CC4B4038F581E49DED4540D02B9E7AA4C94B4099B7EA3A54E94540D02B9E7AA4C94B40
17290	9691	43.929997999999998	43.957774000000001	55.449863000000001	55.437117000000001	Советская	0103000020E6100000010000000500000036ACA92C0AF7454048C32973F3B74B4036ACA92C0AF7454019575C1C95B94B40C47AA35698FA454019575C1C95B94B40C47AA35698FA454048C32973F3B74B4036ACA92C0AF7454048C32973F3B74B40
17628	8525	43.615839000000001	43.646830999999999	55.412140000000001	55.401952999999999	Центральная	0103000020E61000000100000005000000F94CF6CFD3CE4540B9C3263273B34B40F94CF6CFD3CE4540CDAFE600C1B44B40FD84B35BCBD24540CDAFE600C1B44B40FD84B35BCBD24540B9C3263273B34B40F94CF6CFD3CE4540B9C3263273B34B40
17449	9077	43.974240000000002	43.995871000000001	55.609817	55.602804999999996	Центральная	0103000020E610000001000000050000003F3A75E5B3FC4540C16ED8B628CD4B403F3A75E5B3FC4540BDC5C37B0ECE4B40750470B378FF4540BDC5C37B0ECE4B40750470B378FF4540C16ED8B628CD4B403F3A75E5B3FC4540C16ED8B628CD4B40
17934	8683	43.480983999999999	43.505642999999999	55.468668000000001	55.451058000000003	Кирова	0103000020E610000001000000050000001BF33AE290BD4540B24CBF44BCB94B401BF33AE290BD454043572250FDBB4B40C539EAE8B8C0454043572250FDBB4B40C539EAE8B8C04540B24CBF44BCB94B401BF33AE290BD4540B24CBF44BCB94B40
16692	9602	43.703991000000002	43.738118	55.416483999999997	55.400675	Новая линия	0103000020E61000000100000005000000D4D688601CDA454093A9825149B34B40D4D688601CDA454054A703594FB54B40624B8FA67ADE454054A703594FB54B40624B8FA67ADE454093A9825149B34B40D4D688601CDA454093A9825149B34B40
17929	8590	43.701915999999997	43.718975	55.442560999999998	55.434128999999999	пл.Заводская	0103000020E6100000010000000500000002452C62D8D94540629F008A91B74B4002452C62D8D9454016BEBED6A5B84B4020D26F5F07DC454016BEBED6A5B84B4020D26F5F07DC4540629F008A91B74B4002452C62D8D94540629F008A91B74B40
17657	9382	43.790939000000002	43.812973999999997	55.215308	55.202706999999997	Садовая	0103000020E61000000100000005000000C310397D3DE54540CBD58F4DF2994B40C310397D3DE54540994869368F9B4B40C83F33880FE84540994869368F9B4B40C83F33880FE84540CBD58F4DF2994B40C310397D3DE54540CBD58F4DF2994B40
17433	8453	43.690426000000002	43.704340999999999	55.416181999999999	55.401432	Большая площадь	0103000020E61000000100000005000000702711E15FD84540B0C8AF1F62B34B40702711E15FD845408997A77345B54B40B01D8CD827DA45408997A77345B54B40B01D8CD827DA4540B0C8AF1F62B34B40702711E15FD84540B0C8AF1F62B34B40
17631	9027	43.760700999999997	43.800666999999997	55.393864999999998	55.365310000000001	ул. 5 линия	0103000020E610000001000000050000006A847EA65EE145406D73637AC2AE4B406A847EA65EE14540FF04172B6AB24B4043FE99417CE64540FF04172B6AB24B4043FE99417CE645406D73637AC2AE4B406A847EA65EE145406D73637AC2AE4B40
17965	9027	43.760700999999997	43.800666999999997	55.393864999999998	55.365310000000001	Сельхозтехника	0103000020E610000001000000050000006A847EA65EE145406D73637AC2AE4B406A847EA65EE14540FF04172B6AB24B4043FE99417CE64540FF04172B6AB24B4043FE99417CE645406D73637AC2AE4B406A847EA65EE145406D73637AC2AE4B40
17262	9027	43.760700999999997	43.800666999999997	55.393864999999998	55.365310000000001	Куликова	0103000020E610000001000000050000006A847EA65EE145406D73637AC2AE4B406A847EA65EE14540FF04172B6AB24B4043FE99417CE64540FF04172B6AB24B4043FE99417CE645406D73637AC2AE4B406A847EA65EE145406D73637AC2AE4B40
17639	9027	43.760700999999997	43.800666999999997	55.393864999999998	55.365310000000001	7 Линия	0103000020E610000001000000050000006A847EA65EE145406D73637AC2AE4B406A847EA65EE14540FF04172B6AB24B4043FE99417CE64540FF04172B6AB24B4043FE99417CE645406D73637AC2AE4B406A847EA65EE145406D73637AC2AE4B40
17045	8984	43.899455000000003	43.922713000000002	55.595520999999998	55.576075000000003	К.Маркса	0103000020E61000000100000005000000A29C685721F3454088855AD3BCC94B40A29C685721F34540658A39083ACC4B400A4CA7751BF64540658A39083ACC4B400A4CA7751BF6454088855AD3BCC94B40A29C685721F3454088855AD3BCC94B40
17044	8930	43.550764999999998	43.597199000000003	55.409196000000001	55.393022000000002	площадь Кирова	0103000020E610000001000000050000000664AF777FC64540E44D7E8B4EB24B400664AF777FC64540B7D3D68860B44B401A1A4F0471CC4540B7D3D68860B44B401A1A4F0471CC4540E44D7E8B4EB24B400664AF777FC64540E44D7E8B4EB24B40
17634	10411	43.474732000000003	43.495213	55.330553000000002	55.317081999999999	Центральная	0103000020E61000000100000005000000AE2EA704C4BC45403C139A2496A84B40AE2EA704C4BC45401F4C8A8F4FAA4B40EBC6BB2363BF45401F4C8A8F4FAA4B40EBC6BB2363BF45403C139A2496A84B40AE2EA704C4BC45403C139A2496A84B40
17434	8460	43.649839999999998	43.668804000000002	55.381740999999998	55.370072999999998	К.Маркса	0103000020E61000000100000005000000FAD005F52DD34540F910548D5EAF4B40FAD005F52DD345406B459BE3DCB04B408DB7955E9BD545406B459BE3DCB04B408DB7955E9BD54540F910548D5EAF4B40FAD005F52DD34540F910548D5EAF4B40
16926	49709	42.484293999999998	44.395738000000001	55.719186000000001	55.202706999999997	Школьная	0103000020E6100000010000000500000013D38558FD3D4540CBD58F4DF2994B4013D38558FD3D4540DBDE6E490EDC4B4069E4F38AA7324640DBDE6E490EDC4B4069E4F38AA7324640CBD58F4DF2994B4013D38558FD3D4540CBD58F4DF2994B40
17629	8612	43.346649999999997	43.380147999999998	55.487549999999999	55.451281999999999	Советская	0103000020E610000001000000050000004694F6065FAC454001A3CB9BC3B94B404694F6065FAC45401895D40968BE4B40E5D18DB0A8B045401895D40968BE4B40E5D18DB0A8B0454001A3CB9BC3B94B404694F6065FAC454001A3CB9BC3B94B40
18057	8401	43.64649	43.679332000000002	55.416953999999997	55.40043	пл.Победы	0103000020E6100000010000000500000074982F2FC0D245402C2B4D4A41B34B4074982F2FC0D24540DBF7A8BF5EB54B402A90D959F4D64540DBF7A8BF5EB54B402A90D959F4D645402C2B4D4A41B34B4074982F2FC0D245402C2B4D4A41B34B40
17019	8318	42.881439	42.907221	55.144325000000002	55.129818	Советская	0103000020E61000000100000005000000A0353FFED2704540503750E09D904B40A0353FFED2704540637FD93D79924B40499F56D11F744540637FD93D79924B40499F56D11F744540503750E09D904B40A0353FFED2704540503750E09D904B40
17241	8307	43.181252000000001	43.210645	55.189424000000002	55.167858000000003	Центральная	0103000020E61000000100000005000000D42AFA43339745409D2FF65E7C954B40D42AFA4333974540EC89AE0B3F984B407008556AF69A4540EC89AE0B3F984B407008556AF69A45409D2FF65E7C954B40D42AFA43339745409D2FF65E7C954B40
16674	8171	43.392006000000002	43.439481999999998	55.304493000000001	55.290126000000001	Садовая	0103000020E61000000100000005000000FBEAAA402DB2454012DC48D922A54B40FBEAAA402DB24540336E6AA0F9A64B40209738F240B84540336E6AA0F9A64B40209738F240B8454012DC48D922A54B40FBEAAA402DB2454012DC48D922A54B40
17869	7870	43.107886999999998	43.129050999999997	55.325032	55.311016000000002	Центральная	0103000020E61000000100000005000000EF54C03DCF8D454031444E5FCFA74B40EF54C03DCF8D4540A51309A69AA94B400F4240BE84904540A51309A69AA94B400F4240BE8490454031444E5FCFA74B40EF54C03DCF8D454031444E5FCFA74B40
17620	7123	43.104716000000003	43.132041999999998	55.268245999999998	55.253332	Школьная	0103000020E6100000010000000500000019AF7955678D4540E083D72E6DA04B4019AF7955678D454033A48AE255A24B4066D993C0E690454033A48AE255A24B4066D993C0E6904540E083D72E6DA04B4019AF7955678D4540E083D72E6DA04B40
17076	7853	43.270985000000003	43.298293999999999	55.186920999999998	55.175781000000001	Гусева	0103000020E61000000100000005000000715AF0A2AFA245400C21E7FD7F964B40715AF0A2AFA24540C2F7FE06ED974B40E84B6F7F2EA64540C2F7FE06ED974B40E84B6F7F2EA645400C21E7FD7F964B40715AF0A2AFA245400C21E7FD7F964B40
17251	7270	43.160491999999998	43.221235999999998	55.478617999999997	55.452706999999997	Школьная	0103000020E6100000010000000500000083A279008B944540CBD58F4DF2B94B4083A279008B94454072A3C85A43BD4B4053591476519C454072A3C85A43BD4B4053591476519C4540CBD58F4DF2B94B4083A279008B944540CBD58F4DF2B94B40
16838	7270	43.160491999999998	43.221235999999998	55.478617999999997	55.452706999999997	Почтовая	0103000020E6100000010000000500000083A279008B944540CBD58F4DF2B94B4083A279008B94454072A3C85A43BD4B4053591476519C454072A3C85A43BD4B4053591476519C4540CBD58F4DF2B94B4083A279008B944540CBD58F4DF2B94B40
17048	7798	43.124110000000002	43.149307999999998	55.141789000000003	55.126188999999997	Советская	0103000020E61000000100000005000000A48D23D6E28F4540B60E0EF626904B40A48D23D6E28F45405EF7562426924B40FD8348861C9345405EF7562426924B40FD8348861C934540B60E0EF626904B40A48D23D6E28F4540B60E0EF626904B40
17268	7727	43.299767000000003	43.330983000000003	55.385674000000002	55.372902000000003	Центральная	0103000020E61000000100000005000000C4B5DAC35EA64540774EB340BBAF4B40C4B5DAC35EA64540717500C45DB14B401844A4A65DAA4540717500C45DB14B401844A4A65DAA4540774EB340BBAF4B40C4B5DAC35EA64540774EB340BBAF4B40
17051	7704	43.199820000000003	43.245868000000002	55.378089000000003	55.369484999999997	Центральная	0103000020E610000001000000050000001A8BA6B39399454068AED3484BAF4B401A8BA6B3939945401AFD683865B04B400491459A789F45401AFD683865B04B400491459A789F454068AED3484BAF4B401A8BA6B39399454068AED3484BAF4B40
17208	7115	43.074074000000003	43.095607000000001	55.302269000000003	55.280538999999997	Новая	0103000020E61000000100000005000000F1BDBF417B8945405320B3B3E8A34B40F1BDBF417B8945401DCC26C0B0A64B406422A5D93C8C45401DCC26C0B0A64B406422A5D93C8C45405320B3B3E8A34B40F1BDBF417B8945405320B3B3E8A34B40
17010	8083	43.201590000000003	43.222349999999999	55.274769999999997	55.260396999999998	Школьная	0103000020E61000000100000005000000AF997CB3CD994540FE7C5BB054A14B40AF997CB3CD99454001F6D1A92BA34B40FF21FDF6759C454001F6D1A92BA34B40FF21FDF6759C4540FE7C5BB054A14B40AF997CB3CD994540FE7C5BB054A14B40
17949	7542	42.796754999999997	42.813374000000003	55.139457999999998	55.132545999999998	1 Мая	0103000020E6100000010000000500000055F65D11FC654540999B6F44F7904B4055F65D11FC65454031957EC2D9914B4057B5A4A31C68454031957EC2D9914B4057B5A4A31C684540999B6F44F7904B4055F65D11FC654540999B6F44F7904B40
17075	8003	43.480176	43.500611999999997	55.246142999999996	55.230517999999996	Лесная	0103000020E610000001000000050000007C293C6876BD4540D591239D819D4B407C293C6876BD4540D591239D819F4B4019FED30D14C04540D591239D819F4B4019FED30D14C04540D591239D819D4B407C293C6876BD4540D591239D819D4B40
17653	7483	43.010869	43.033901	55.191566999999999	55.177221000000003	Молодежная	0103000020E6100000010000000500000026C5C727648145400C957F2DAF964B4026C5C7276481454015FF774485984B409E2633DE5684454015FF774485984B409E2633DE568445400C957F2DAF964B4026C5C727648145400C957F2DAF964B40
16745	7662	43.269286999999998	43.286005000000003	55.365099999999998	55.356293000000001	Школьная	0103000020E61000000100000005000000751E15FF77A2454099654F029BAD4B40751E15FF77A2454082E2C798BBAE4B400ABFD4CF9BA4454082E2C798BBAE4B400ABFD4CF9BA4454099654F029BAD4B40751E15FF77A2454099654F029BAD4B40
16841	7413	42.970283000000002	42.994366999999997	55.505037000000002	55.494216000000002	Северная	0103000020E61000000100000005000000B16EBC3B327C454079944A7842BF4B40B16EBC3B327C45408E226B0DA5C04B405E9CF86A477F45408E226B0DA5C04B405E9CF86A477F454079944A7842BF4B40B16EBC3B327C454079944A7842BF4B40
17430	8244	43.238501999999997	43.265469000000003	55.161116	55.148584999999997	Школьная	0103000020E61000000100000005000000EA03C93B879E45408CD651D504934B40EA03C93B879E4540616EF7729F944B40098D60E3FAA14540616EF7729F944B40098D60E3FAA145408CD651D504934B40EA03C93B879E45408CD651D504934B40
17596	36370	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	Суслова	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
17398	36370	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	Свердлова	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
17206	36370	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	Зуева	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
16979	36370	46.252951000000003	46.278419	54.777287000000001	54.754151999999998	30 лет ВЛКСМ	0103000020E61000000100000005000000C93EC8B260204740431B800D88604B40C93EC8B260204740904DF2237E634B40E2CAD93BA3234740904DF2237E634B40E2CAD93BA3234740431B800D88604B40C93EC8B260204740431B800D88604B40
17210	49761	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	Кооперативная	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
17214	49761	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	Зуева	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
17353	49751	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Шмидта	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
17528	49751	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Чапаева	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
17343	49751	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Суворова	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
19399	49751	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	Высокая	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
17096	49743	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	Шишкина	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
17099	49743	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	Фурманова	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
17685	49743	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	Краснофлотская	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
17328	49743	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	Зафабричная	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
48753	55970	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Свободы	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
49109	55970	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Ленина	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48729	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	проспект Гагарина	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48809	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Школьная	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48798	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Советская	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48730	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Слободская	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48807	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Первомайская	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48728	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Ленина	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48745	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Корто	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48934	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Кирова	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48933	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Железнодорожная	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48878	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Грина	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48721	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Гоголя	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48781	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	Вятская	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
48935	6838	50.143824000000002	50.251514	58.758141999999999	58.687725	 Ленина	0103000020E61000000100000005000000A13028D36812494020D26F5F07584D40A13028D368124940ADDC0BCC0A614D403A3E5A9C31204940ADDC0BCC0A614D403A3E5A9C3120494020D26F5F07584D40A13028D36812494020D26F5F07584D40
49084	31734	49.789465999999997	49.792161	58.606290999999999	58.604294000000003	Сосновая	0103000020E61000000100000005000000E7A6CD380DE54840A3957B81594D4D40E7A6CD380DE54840F86D88F19A4D4D4055151A8865E54840F86D88F19A4D4D4055151A8865E54840A3957B81594D4D40E7A6CD380DE54840A3957B81594D4D40
48802	55978	48.860427999999999	48.920993000000003	58.555990000000001	58.524299999999997	В.Сокованова	0103000020E6100000010000000500000006483481226E48407AA52C431C434D4006483481226E4840977329AE2A474D40276C3F19E3754840977329AE2A474D40276C3F19E37548407AA52C431C434D4006483481226E48407AA52C431C434D40
48792	55977	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Свободы	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
49095	55977	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Садовая	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
49488	55977	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Пригородная	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48949	55977	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Комсомольская	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48788	55977	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Воровского	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48871	55983	48.942166	49.026266	59.413870000000003	59.377640999999997	Пионерская	0103000020E610000001000000050000009AB33EE5987848407A50508A56B04D409AB33EE598784840D46531B1F9B44D40957F2DAF5C834840D46531B1F9B44D40957F2DAF5C8348407A50508A56B04D409AB33EE5987848407A50508A56B04D40
48865	55983	48.942166	49.026266	59.413870000000003	59.377640999999997	Кирова	0103000020E610000001000000050000009AB33EE5987848407A50508A56B04D409AB33EE598784840D46531B1F9B44D40957F2DAF5C834840D46531B1F9B44D40957F2DAF5C8348407A50508A56B04D409AB33EE5987848407A50508A56B04D40
49234	55976	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	Октябрьская	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
48786	55976	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	Карла Маркса	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
48838	55975	47.200395999999998	47.313448999999999	60.63908	60.604889	Рабочая	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
48782	55975	47.200395999999998	47.313448999999999	60.63908	60.604889	Калинина	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
48832	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Школьная	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
48834	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Урицкого	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
48767	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Советская	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
48765	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Победы	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
48778	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Октябрьская	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
48859	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Мелиораторов	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
49191	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Заречная	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
48946	1207	48.263911	48.390466000000004	58.331446999999997	58.291857999999998	Дениса Белых	0103000020E61000000100000005000000FF06EDD5C7214840B9895A9A5B254D40FF06EDD5C7214840BCADF4DA6C2A4D40981936CAFA314840BCADF4DA6C2A4D40981936CAFA314840B9895A9A5B254D40FF06EDD5C7214840B9895A9A5B254D40
48829	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	проспект Мира	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
48827	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	Фестивальная	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
48831	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	Революции	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
49678	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	Островского	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
48911	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	Лермонтова проезд	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
49374	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	Комсомольская	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
77489	55981	46.262419999999999	53.931992999999999	61.065370999999999	56.058951	Ком. Утробина	0103000020E610000001000000050000007DE882FA962147408388D4B48B074C407DE882FA96214740AC8DB1135E884E40EB8CEF8B4BF74A40AC8DB1135E884E40EB8CEF8B4BF74A408388D4B48B074C407DE882FA962147408388D4B48B074C40
77531	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	А.Некрасова	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
49072	55981	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	60 лет Октября	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
6977	369	49.619092000000002	49.628928000000002	58.613964000000003	58.609361999999997	улица Физкультурников	0103000020E610000001000000050000008D9B1A683ECF48406BB6F292FF4D4D408D9B1A683ECF4840EF75525F964E4D40F4C473B680D04840EF75525F964E4D40F4C473B680D048406BB6F292FF4D4D408D9B1A683ECF48406BB6F292FF4D4D40
2348	369	49.582126000000002	49.631165000000003	58.602961999999998	58.580947999999999	улица Солнечная	0103000020E610000001000000050000005E13D21A83CA48409B560A815C4A4D405E13D21A83CA4840895DDBDB2D4D4D409FB0C403CAD04840895DDBDB2D4D4D409FB0C403CAD048409B560A815C4A4D405E13D21A83CA48409B560A815C4A4D40
16124	369	49.616441000000002	49.625883000000002	58.647793	58.637335	улица Свердлова	0103000020E61000000100000005000000EF74E789E7CE48404FCC7A3194514D40EF74E789E7CE4840F3C98AE1EA524D40AA0F24EF1CD04840F3C98AE1EA524D40AA0F24EF1CD048404FCC7A3194514D40EF74E789E7CE48404FCC7A3194514D40
15338	369	49.651817000000001	49.686087999999998	58.612029	58.611212999999999	улица Розы Люксембург	0103000020E6100000010000000500000009FD4CBD6ED34840EDF1423A3C4E4D4009FD4CBD6ED348400F9A5DF7564E4D40CA1649BBD1D748400F9A5DF7564E4D40CA1649BBD1D74840EDF1423A3C4E4D4009FD4CBD6ED34840EDF1423A3C4E4D40
5824	369	49.585431999999997	49.596535000000003	58.586754999999997	58.586652000000001	улица Риммы Юровской	0103000020E6100000010000000500000014048F6FEFCA48400611A969174B4D4014048F6FEFCA4840DAE1AFC91A4B4D40AEF545425BCC4840DAE1AFC91A4B4D40AEF545425BCC48400611A969174B4D4014048F6FEFCA48400611A969174B4D40
15562	369	49.656461	49.684767000000001	58.615580999999999	58.614578000000002	улица Профсоюзная	0103000020E61000000100000005000000BB0CFFE906D44840A96BED7DAA4E4D40BB0CFFE906D44840FD84B35BCB4E4D40A530EF71A6D74840FD84B35BCB4E4D40A530EF71A6D74840A96BED7DAA4E4D40BB0CFFE906D44840A96BED7DAA4E4D40
16111	369	49.691118000000003	49.703425000000003	58.511920000000003	58.505530999999998	улица Орджоникидзе	0103000020E61000000100000005000000A6D6FB8D76D848409D0E643DB5404D40A6D6FB8D76D848408C15359886414D402B1895D409DA48408C15359886414D402B1895D409DA48409D0E643DB5404D40A6D6FB8D76D848409D0E643DB5404D40
49031	369	49.675784	49.681066000000001	58.617047999999997	58.581924000000001	Свободы	0103000020E610000001000000050000007D94111780D64840F660527C7C4A4D407D94111780D64840F607CA6DFB4E4D407235B22B2DD74840F607CA6DFB4E4D407235B22B2DD74840F660527C7C4A4D407D94111780D64840F660527C7C4A4D40
6662	369	49.613154000000002	49.618633000000003	58.642730999999998	58.639325999999997	улица Олега Кошевого	0103000020E61000000100000005000000AFB48CD47BCE4840C2BD326FD5514D40AFB48CD47BCE48400C90680245524D40FA9CBB5D2FCF48400C90680245524D40FA9CBB5D2FCF4840C2BD326FD5514D40AFB48CD47BCE4840C2BD326FD5514D40
7127	369	49.595312999999997	49.603425000000001	58.610557	58.596978999999997	улица Менделеева	0103000020E610000001000000050000001BF1643733CC48400BB3D0CE694C4D401BF1643733CC484004AC55BB264E4D405E4BC8073DCD484004AC55BB264E4D405E4BC8073DCD48400BB3D0CE694C4D401BF1643733CC48400BB3D0CE694C4D40
7056	369	49.598627999999998	49.613567000000003	58.615633000000003	58.602597000000003	улица Ломоносова	0103000020E61000000100000005000000253CA1D79FCC484078D503E6214D4D40253CA1D79FCC484050ABE80FCD4E4D40D2730B5D89CE484050ABE80FCD4E4D40D2730B5D89CE484078D503E6214D4D40253CA1D79FCC484078D503E6214D4D40
1164	369	49.716828	49.718812999999997	58.500791999999997	58.498736999999998	улица Лермонтова	0103000020E61000000100000005000000B56D1805C1DB48400F27309DD63F4D40B56D1805C1DB4840990CC7F319404D4046787B1002DC4840990CC7F319404D4046787B1002DC48400F27309DD63F4D40B56D1805C1DB48400F27309DD63F4D40
15362	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	улица Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
3636	369	49.655788000000001	49.672721000000003	58.620254000000003	58.582251999999997	улица Карла Маркса	0103000020E61000000100000005000000FC8D76DCF0D34840EA03C93B874A4D40FC8D76DCF0D348404A9BAA7B644F4D408D2AC3B81BD648404A9BAA7B644F4D408D2AC3B81BD64840EA03C93B874A4D40FC8D76DCF0D34840EA03C93B874A4D40
15717	369	49.620358000000003	49.650900999999998	58.587698000000003	58.587145	улица Калинина	0103000020E61000000100000005000000EFE714E467CF484045813E91274B4D40EFE714E467CF48405AF624B0394B4D4083F755B950D348405AF624B0394B4D4083F755B950D3484045813E91274B4D40EFE714E467CF484045813E91274B4D40
5810	369	49.657637999999999	49.691136	58.602272999999997	58.601570000000002	улица Дрелевского	0103000020E61000000100000005000000AD4D637B2DD448409B20EA3E004D4D40AD4D637B2DD44840C4211B48174D4D404C8BFA2477D84840C4211B48174D4D404C8BFA2477D848409B20EA3E004D4D40AD4D637B2DD448409B20EA3E004D4D40
6221	369	49.609730999999996	49.616028	58.576414999999997	58.575744999999998	слобода Петелины	0103000020E61000000100000005000000BE2D58AA0BCE4840F2EA1C03B2494D40BE2D58AA0BCE484040F67AF7C7494D40CCB56801DACE484040F67AF7C7494D40CCB56801DACE4840F2EA1C03B2494D40BE2D58AA0BCE4840F2EA1C03B2494D40
5691	369	49.590381000000001	49.59066	58.602170000000001	58.586736000000002	проспект Строителей	0103000020E610000001000000050000000397C79A91CB484064B14D2A1A4B4D400397C79A91CB4840F05014E8134D4D40168733BF9ACB4840F05014E8134D4D40168733BF9ACB484064B14D2A1A4B4D400397C79A91CB484064B14D2A1A4B4D40
6293	369	49.600155000000001	49.604143999999998	58.596711999999997	58.596412000000001	площадь Маршала Конева	0103000020E61000000100000005000000F4C308E1D1CC48409278793A574C4D40F4C308E1D1CC4840BC900E0F614C4D408D09319754CD4840BC900E0F614C4D408D09319754CD48409278793A574C4D40F4C308E1D1CC48409278793A574C4D40
48969	369	49.747056999999998	49.751610999999997	58.611265000000003	58.610308000000003	переулок Школьный	0103000020E61000000100000005000000BA9F53909FDF48405C3E92921E4E4D40BA9F53909FDF4840401878EE3D4E4D402C280CCA34E04840401878EE3D4E4D402C280CCA34E048405C3E92921E4E4D40BA9F53909FDF48405C3E92921E4E4D40
16231	369	49.747056999999998	49.751610999999997	58.611265000000003	58.610308000000003	переулок Школьный	0103000020E61000000100000005000000BA9F53909FDF48405C3E92921E4E4D40BA9F53909FDF4840401878EE3D4E4D402C280CCA34E04840401878EE3D4E4D402C280CCA34E048405C3E92921E4E4D40BA9F53909FDF48405C3E92921E4E4D40
49075	369	49.645842999999999	49.684173999999999	58.605437999999999	58.603172999999998	Энгельса	0103000020E61000000100000005000000DEACC1FBAAD24840446ADAC5344D4D40DEACC1FBAAD24840B9E00CFE7E4D4D4002637D0393D74840B9E00CFE7E4D4D4002637D0393D74840446ADAC5344D4D40DEACC1FBAAD24840446ADAC5344D4D40
49035	369	49.709614999999999	49.715696000000001	58.499358000000001	58.489212999999999	Школьная	0103000020E6100000010000000500000022E010AAD4DA484097E315889E3E4D4022E010AAD4DA48407C7F83F6EA3F4D4063F030ED9BDB48407C7F83F6EA3F4D4063F030ED9BDB484097E315889E3E4D4022E010AAD4DA484097E315889E3E4D40
49026	369	49.625613000000001	49.638477000000002	58.627549000000002	58.622352999999997	Шинников	0103000020E61000000100000005000000EA79371614D04840A3C85A43A94F4D40EA79371614D048409AD18F8653504D40C51F459DB9D148409AD18F8653504D40C51F459DB9D14840A3C85A43A94F4D40EA79371614D04840A3C85A43A94F4D40
49242	369	49.669235	49.673799000000002	58.535302999999999	58.534799999999997	Центральная	0103000020E61000000100000005000000562B137EA9D548404DF38E5374444D40562B137EA9D54840B03907CF84444D40EC89AE0B3FD64840B03907CF84444D40EC89AE0B3FD648404DF38E5374444D40562B137EA9D548404DF38E5374444D40
49025	369	49.651566000000003	49.655698000000001	58.569898000000002	58.569175000000001	Харьковская	0103000020E61000000100000005000000C097C28366D34840B459F5B9DA484D40C097C28366D348402507EC6AF2484D40BC067DE9EDD348402507EC6AF2484D40BC067DE9EDD34840B459F5B9DA484D40C097C28366D34840B459F5B9DA484D40
48953	369	49.650343999999997	49.662965	58.566833000000003	58.556811000000003	Фестивальная	0103000020E610000001000000050000002D93E1783ED34840CB86359545474D402D93E1783ED3484094A5D6FB8D484D4042B28009DCD4484094A5D6FB8D484D4042B28009DCD44840CB86359545474D402D93E1783ED34840CB86359545474D40
48988	369	49.625594999999997	49.629350000000002	58.635039999999996	58.633465999999999	Уральская	0103000020E6100000010000000500000043C5387F13D048406090F46915514D4043C5387F13D048406FD39FFD48514D406ADE718A8ED048406FD39FFD48514D406ADE718A8ED048406090F46915514D4043C5387F13D048406090F46915514D40
49100	369	49.67962	49.679952	58.527847000000001	58.525409000000003	Трудовая	0103000020E6100000010000000500000090DAC4C9FDD648401503249A40434D4090DAC4C9FDD648405725917D90434D40C66CC9AA08D748405725917D90434D40C66CC9AA08D748401503249A40434D4090DAC4C9FDD648401503249A40434D40
49029	369	49.651485000000001	49.686196000000002	58.610312999999998	58.608137999999997	Труда	0103000020E61000000100000005000000D36A48DC63D3484038BA4A77D74D4D40D36A48DC63D348406DA983BC1E4E4D40B1524145D5D748406DA983BC1E4E4D40B1524145D5D7484038BA4A77D74D4D40D36A48DC63D3484038BA4A77D74D4D40
49057	369	49.714357999999997	49.722819999999999	58.504703999999997	58.501229000000002	Тренера Пушкарёва	0103000020E6100000010000000500000067D13B1570DB48404567994528404D4067D13B1570DB4840871403249A404D408672A25D85DC4840871403249A404D408672A25D85DC48404567994528404D4067D13B1570DB48404567994528404D40
49044	369	49.637380999999998	49.638944000000002	58.593387	58.578316000000001	Сурикова	0103000020E61000000100000005000000BF0B5BB395D1484074603942064A4D40BF0B5BB395D148408F6FEF1AF44B4D40DBFCBFEAC8D148408F6FEF1AF44B4D40DBFCBFEAC8D1484074603942064A4D40BF0B5BB395D1484074603942064A4D40
6989	369	49.617573	49.618659999999998	58.609591000000002	58.596387999999997	Студенческий проезд	0103000020E6100000010000000500000041F2CEA10CCF484009DD2571564C4D4041F2CEA10CCF4840CD77F013074E4D40F3AB394030CF4840CD77F013074E4D40F3AB394030CF484009DD2571564C4D4041F2CEA10CCF484009DD2571564C4D40
49020	369	49.590381000000001	49.59066	58.602170000000001	58.586736000000002	Строителей проспек	0103000020E610000001000000050000000397C79A91CB484064B14D2A1A4B4D400397C79A91CB4840F05014E8134D4D40168733BF9ACB4840F05014E8134D4D40168733BF9ACB484064B14D2A1A4B4D400397C79A91CB484064B14D2A1A4B4D40
48973	369	49.789465999999997	49.792161	58.606290999999999	58.604294000000003	Сосновая	0103000020E61000000100000005000000E7A6CD380DE54840A3957B81594D4D40E7A6CD380DE54840F86D88F19A4D4D4055151A8865E54840F86D88F19A4D4D4055151A8865E54840A3957B81594D4D40E7A6CD380DE54840A3957B81594D4D40
48980	369	49.789465999999997	49.792161	58.606290999999999	58.604294000000003	Сосновая	0103000020E61000000100000005000000E7A6CD380DE54840A3957B81594D4D40E7A6CD380DE54840F86D88F19A4D4D4055151A8865E54840F86D88F19A4D4D4055151A8865E54840A3957B81594D4D40E7A6CD380DE54840A3957B81594D4D40
49103	369	49.789465999999997	49.792161	58.606290999999999	58.604294000000003	Сосновая	0103000020E61000000100000005000000E7A6CD380DE54840A3957B81594D4D40E7A6CD380DE54840F86D88F19A4D4D4055151A8865E54840F86D88F19A4D4D4055151A8865E54840A3957B81594D4D40E7A6CD380DE54840A3957B81594D4D40
48997	369	49.602364999999999	49.636321000000002	58.620015000000002	58.614460999999999	Сормовская	0103000020E61000000100000005000000A5A0DB4B1ACD48406FD575A8A64E4D40A5A0DB4B1ACD4840C503CAA65C4F4D4007616EF772D14840C503CAA65C4F4D4007616EF772D148406FD575A8A64E4D40A5A0DB4B1ACD48406FD575A8A64E4D40
49049	369	49.582126000000002	49.631165000000003	58.602961999999998	58.580947999999999	Солнечная	0103000020E610000001000000050000005E13D21A83CA48409B560A815C4A4D405E13D21A83CA4840895DDBDB2D4D4D409FB0C403CAD04840895DDBDB2D4D4D409FB0C403CAD048409B560A815C4A4D405E13D21A83CA48409B560A815C4A4D40
15632	369	49.683563999999997	49.741216999999999	58.532530999999999	58.482171000000001	Советская улица	0103000020E61000000100000005000000895C70067FD74840310A82C7B73D4D40895C70067FD74840978DCEF929444D409F1EDB32E0DE4840978DCEF929444D409F1EDB32E0DE4840310A82C7B73D4D40895C70067FD74840310A82C7B73D4D40
49023	369	49.683563999999997	49.741216999999999	58.532530999999999	58.482171000000001	Советская	0103000020E61000000100000005000000895C70067FD74840310A82C7B73D4D40895C70067FD74840978DCEF929444D409F1EDB32E0DE4840978DCEF929444D409F1EDB32E0DE4840310A82C7B73D4D40895C70067FD74840310A82C7B73D4D40
49254	369	49.683563999999997	49.741216999999999	58.532530999999999	58.482171000000001	Советская	0103000020E61000000100000005000000895C70067FD74840310A82C7B73D4D40895C70067FD74840978DCEF929444D409F1EDB32E0DE4840978DCEF929444D409F1EDB32E0DE4840310A82C7B73D4D40895C70067FD74840310A82C7B73D4D40
48966	369	49.683563999999997	49.741216999999999	58.532530999999999	58.482171000000001	Советская	0103000020E61000000100000005000000895C70067FD74840310A82C7B73D4D40895C70067FD74840978DCEF929444D409F1EDB32E0DE4840978DCEF929444D409F1EDB32E0DE4840310A82C7B73D4D40895C70067FD74840310A82C7B73D4D40
49077	369	49.683563999999997	49.741216999999999	58.532530999999999	58.482171000000001	Советская	0103000020E61000000100000005000000895C70067FD74840310A82C7B73D4D40895C70067FD74840978DCEF929444D409F1EDB32E0DE4840978DCEF929444D409F1EDB32E0DE4840310A82C7B73D4D40895C70067FD74840310A82C7B73D4D40
49055	369	49.683563999999997	49.741216999999999	58.532530999999999	58.482171000000001	Советская	0103000020E61000000100000005000000895C70067FD74840310A82C7B73D4D40895C70067FD74840978DCEF929444D409F1EDB32E0DE4840978DCEF929444D409F1EDB32E0DE4840310A82C7B73D4D40895C70067FD74840310A82C7B73D4D40
49665	369	49.683563999999997	49.741216999999999	58.532530999999999	58.482171000000001	Советская	0103000020E61000000100000005000000895C70067FD74840310A82C7B73D4D40895C70067FD74840978DCEF929444D409F1EDB32E0DE4840978DCEF929444D409F1EDB32E0DE4840310A82C7B73D4D40895C70067FD74840310A82C7B73D4D40
49036	369	49.728228000000001	49.741864	58.647554	58.644145000000002	Семашко	0103000020E6100000010000000500000008043A9336DD4840E370E65773524D4008043A9336DD48406E32AA0CE3524D40350A4966F5DE48406E32AA0CE3524D40350A4966F5DE4840E370E65773524D4008043A9336DD4840E370E65773524D40
49043	369	49.675784	49.681066000000001	58.617047999999997	58.581924000000001	Свободы	0103000020E610000001000000050000007D94111780D64840F660527C7C4A4D407D94111780D64840F607CA6DFB4E4D407235B22B2DD74840F607CA6DFB4E4D407235B22B2DD74840F660527C7C4A4D407D94111780D64840F660527C7C4A4D40
49063	369	49.632063000000002	49.637148000000003	58.617536000000001	58.602958000000001	Романа Ердякова	0103000020E610000001000000050000007E01BD70E7D04840486E4DBA2D4D4D407E01BD70E7D04840240D6E6B0B4F4D401D5BCF108ED14840240D6E6B0B4F4D401D5BCF108ED14840486E4DBA2D4D4D407E01BD70E7D04840486E4DBA2D4D4D40
49027	369	49.651817000000001	49.686087999999998	58.612029	58.611212999999999	Розы Люксембург	0103000020E6100000010000000500000009FD4CBD6ED34840EDF1423A3C4E4D4009FD4CBD6ED348400F9A5DF7564E4D40CA1649BBD1D748400F9A5DF7564E4D40CA1649BBD1D74840EDF1423A3C4E4D4009FD4CBD6ED34840EDF1423A3C4E4D40
49079	369	49.651817000000001	49.686087999999998	58.612029	58.611212999999999	Розы Люксембург	0103000020E6100000010000000500000009FD4CBD6ED34840EDF1423A3C4E4D4009FD4CBD6ED348400F9A5DF7564E4D40CA1649BBD1D748400F9A5DF7564E4D40CA1649BBD1D74840EDF1423A3C4E4D4009FD4CBD6ED34840EDF1423A3C4E4D40
49001	369	49.651817000000001	49.686087999999998	58.612029	58.611212999999999	Розы Люксембург	0103000020E6100000010000000500000009FD4CBD6ED34840EDF1423A3C4E4D4009FD4CBD6ED348400F9A5DF7564E4D40CA1649BBD1D748400F9A5DF7564E4D40CA1649BBD1D74840EDF1423A3C4E4D4009FD4CBD6ED34840EDF1423A3C4E4D40
49008	369	49.683824000000001	49.701323000000002	58.515158999999997	58.509644999999999	Пушкина	0103000020E61000000100000005000000261C7A8B87D74840F3C81F0C3C414D40261C7A8B87D74840BA9EE8BAF0414D406077BAF3C4D94840BA9EE8BAF0414D406077BAF3C4D94840F3C81F0C3C414D40261C7A8B87D74840F3C81F0C3C414D40
48970	369	49.683824000000001	49.701323000000002	58.515158999999997	58.509644999999999	Пушкина	0103000020E61000000100000005000000261C7A8B87D74840F3C81F0C3C414D40261C7A8B87D74840BA9EE8BAF0414D406077BAF3C4D94840BA9EE8BAF0414D406077BAF3C4D94840F3C81F0C3C414D40261C7A8B87D74840F3C81F0C3C414D40
49019	369	49.683824000000001	49.701323000000002	58.515158999999997	58.509644999999999	Пушкина	0103000020E61000000100000005000000261C7A8B87D74840F3C81F0C3C414D40261C7A8B87D74840BA9EE8BAF0414D406077BAF3C4D94840BA9EE8BAF0414D406077BAF3C4D94840F3C81F0C3C414D40261C7A8B87D74840F3C81F0C3C414D40
48986	369	49.625137000000002	49.626161000000003	58.589269000000002	58.572957000000002	Пугачева	0103000020E6100000010000000500000081423D7D04D04840D481ACA756494D4081423D7D04D04840F8C5A52A6D4B4D40ED832C0B26D04840F8C5A52A6D4B4D40ED832C0B26D04840D481ACA756494D4081423D7D04D04840D481ACA756494D40
49090	369	49.656461	49.684767000000001	58.615580999999999	58.614578000000002	Профсоюзная	0103000020E61000000100000005000000BB0CFFE906D44840A96BED7DAA4E4D40BB0CFFE906D44840FD84B35BCB4E4D40A530EF71A6D74840FD84B35BCB4E4D40A530EF71A6D74840A96BED7DAA4E4D40BB0CFFE906D44840A96BED7DAA4E4D40
49059	369	49.656461	49.684767000000001	58.615580999999999	58.614578000000002	Профсоюзная	0103000020E61000000100000005000000BB0CFFE906D44840A96BED7DAA4E4D40BB0CFFE906D44840FD84B35BCB4E4D40A530EF71A6D74840FD84B35BCB4E4D40A530EF71A6D74840A96BED7DAA4E4D40BB0CFFE906D44840A96BED7DAA4E4D40
49004	369	49.658257999999996	49.688440999999997	58.589682000000003	58.589179999999999	Пролетарская	0103000020E61000000100000005000000492A53CC41D4484088BA0F406A4B4D40492A53CC41D448401B8524B37A4B4D40DE1CAED51ED848401B8524B37A4B4D40DE1CAED51ED8484088BA0F406A4B4D40492A53CC41D4484088BA0F406A4B4D40
49069	369	49.609363000000002	49.614151	58.602597000000003	58.560763999999999	Производственная	0103000020E610000001000000050000003C32569BFFCD48401763601DC7474D403C32569BFFCD484078D503E6214D4D4021E7FD7F9CCE484078D503E6214D4D4021E7FD7F9CCE48401763601DC7474D403C32569BFFCD48401763601DC7474D40
48998	369	49.709947	49.725093000000001	58.495859000000003	58.491033000000002	Проектная	0103000020E610000001000000050000005872158BDFDA4840DE205A2BDA3E4D405872158BDFDA4840B136C64E783F4D407EC7F0D8CFDC4840B136C64E783F4D407EC7F0D8CFDC4840DE205A2BDA3E4D405872158BDFDA4840DE205A2BDA3E4D40
49644	369	49.621938999999998	49.629340999999997	58.572961999999997	58.563490999999999	Потребкооперации	0103000020E61000000100000005000000B08D78B29BCF4840904B1C7920484D40B08D78B29BCF4840E5EC9DD156494D401684F23E8ED04840E5EC9DD156494D401684F23E8ED04840904B1C7920484D40B08D78B29BCF4840904B1C7920484D40
48858	369	49.629798999999998	49.630949000000001	58.593218	58.573323000000002	Попова	0103000020E61000000100000005000000D906EE409DD04840B685E7A562494D40D906EE409DD0484003B34291EE4B4D40D238D4EFC2D0484003B34291EE4B4D40D238D4EFC2D04840B685E7A562494D40D906EE409DD04840B685E7A562494D40
49011	369	49.693804	49.708185999999998	58.616827999999998	58.614986000000002	Первомайская	0103000020E61000000100000005000000C0EAC891CED84840BABF7ADCB74E4D40C0EAC891CED84840E8A04B38F44E4D4016BEBED6A5DA4840E8A04B38F44E4D4016BEBED6A5DA4840BABF7ADCB74E4D40C0EAC891CED84840BABF7ADCB74E4D40
49058	369	49.661636000000001	49.739448000000003	58.671818999999999	58.627788000000002	Павла Корчагина	0103000020E610000001000000050000009AED0A7DB0D448401F69705B5B504D409AED0A7DB0D448406CEA3C2AFE554D40DB8B683BA6DE48406CEA3C2AFE554D40DB8B683BA6DE48401F69705B5B504D409AED0A7DB0D448401F69705B5B504D40
49080	369	49.665391	49.691567999999997	58.596313000000002	58.595371	Орловская	0103000020E61000000100000005000000C00644882BD5484050FEEE1D354C4D40C00644882BD54840FF9600FC534C4D40E57ADB4C85D84840FF9600FC534C4D40E57ADB4C85D8484050FEEE1D354C4D40C00644882BD5484050FEEE1D354C4D40
49081	369	49.693292	49.699050999999997	58.510255999999998	58.506067000000002	Опарина	0103000020E610000001000000050000000A4AD1CABDD84840DC4AAFCDC6404D400A4AD1CABDD848403C4B901150414D40389ECF807AD948403C4B901150414D40389ECF807AD94840DC4AAFCDC6404D400A4AD1CABDD84840DC4AAFCDC6404D40
142	369	49.611797000000003	49.658788000000001	58.638061	58.581074000000001	Октябрьский проспект	0103000020E610000001000000050000003D65355D4FCE4840284701A2604A4D403D65355D4FCE484031ED9BFBAB514D40A67F492A53D4484031ED9BFBAB514D40A67F492A53D44840284701A2604A4D403D65355D4FCE4840284701A2604A4D40
49074	369	49.737237999999998	49.742151999999997	58.646140000000003	58.645170999999998	Октябрьская	0103000020E6100000010000000500000029AF95D05DDE4840EFA99CF694524D4029AF95D05DDE484098512CB7B4524D409B5434D6FEDE484098512CB7B4524D409B5434D6FEDE4840EFA99CF694524D4029AF95D05DDE4840EFA99CF694524D40
49022	369	49.737237999999998	49.742151999999997	58.646140000000003	58.645170999999998	Октябрьская	0103000020E6100000010000000500000029AF95D05DDE4840EFA99CF694524D4029AF95D05DDE484098512CB7B4524D409B5434D6FEDE484098512CB7B4524D409B5434D6FEDE4840EFA99CF694524D4029AF95D05DDE4840EFA99CF694524D40
48849	369	49.617753	49.658670999999998	58.582664999999999	58.582045000000001	Некрасова	0103000020E61000000100000005000000C100C28712CF484071E65773804A4D40C100C28712CF48400DC347C4944A4D406CE9D1544FD448400DC347C4944A4D406CE9D1544FD4484071E65773804A4D40C100C28712CF484071E65773804A4D40
6272	369	49.584560000000003	49.690255999999998	58.603867000000001	58.600909000000001	Московская улица	0103000020E610000001000000050000005F46B1DCD2CA4840A06F0B96EA4C4D405F46B1DCD2CA48401B118C834B4D4D4013EF004F5AD848401B118C834B4D4D4013EF004F5AD84840A06F0B96EA4C4D405F46B1DCD2CA4840A06F0B96EA4C4D40
48977	369	49.584560000000003	49.690255999999998	58.603867000000001	58.600909000000001	Московская	0103000020E610000001000000050000005F46B1DCD2CA4840A06F0B96EA4C4D405F46B1DCD2CA48401B118C834B4D4D4013EF004F5AD848401B118C834B4D4D4013EF004F5AD84840A06F0B96EA4C4D405F46B1DCD2CA4840A06F0B96EA4C4D40
49056	369	49.643543999999999	49.692286000000003	58.598816999999997	58.597724999999997	Молодой Гвардии	0103000020E61000000100000005000000BDC458A65FD248403480B740824C4D40BDC458A65FD24840F8A41309A64C4D4045BDE0D39CD84840F8A41309A64C4D4045BDE0D39CD848403480B740824C4D40BDC458A65FD248403480B740824C4D40
49655	369	49.603569	49.60718	58.634205999999999	58.628762999999999	Молодежная	0103000020E6100000010000000500000091F0BDBF41CD4840A9F7544E7B504D4091F0BDBF41CD4840A77686A92D514D4084640113B8CD4840A77686A92D514D4084640113B8CD4840A9F7544E7B504D4091F0BDBF41CD4840A9F7544E7B504D40
49078	369	49.605437000000002	49.617510000000003	58.617522000000001	58.611105000000002	Мира	0103000020E61000000100000005000000E964A9F57ECD484007B64AB0384E4D40E964A9F57ECD4840BF47FDF50A4F4D40FB7953910ACF4840BF47FDF50A4F4D40FB7953910ACF484007B64AB0384E4D40E964A9F57ECD484007B64AB0384E4D40
48861	369	49.605437000000002	49.617510000000003	58.617522000000001	58.611105000000002	Мира	0103000020E61000000100000005000000E964A9F57ECD484007B64AB0384E4D40E964A9F57ECD4840BF47FDF50A4F4D40FB7953910ACF4840BF47FDF50A4F4D40FB7953910ACF484007B64AB0384E4D40E964A9F57ECD484007B64AB0384E4D40
49021	369	49.658312000000002	49.687983000000003	58.587533999999998	58.586910000000003	Милицейская	0103000020E610000001000000050000003D484F9143D4484002D9EBDD1F4B4D403D484F9143D44840DFA46950344B4D401C9AB2D30FD84840DFA46950344B4D401C9AB2D30FD8484002D9EBDD1F4B4D403D484F9143D4484002D9EBDD1F4B4D40
49034	369	49.658312000000002	49.687983000000003	58.587533999999998	58.586910000000003	Милицейская	0103000020E610000001000000050000003D484F9143D4484002D9EBDD1F4B4D403D484F9143D44840DFA46950344B4D401C9AB2D30FD84840DFA46950344B4D401C9AB2D30FD8484002D9EBDD1F4B4D403D484F9143D4484002D9EBDD1F4B4D40
48854	369	49.600155000000001	49.604143999999998	58.596711999999997	58.596412000000001	Маршала Конева	0103000020E61000000100000005000000F4C308E1D1CC48409278793A574C4D40F4C308E1D1CC4840BC900E0F614C4D408D09319754CD4840BC900E0F614C4D408D09319754CD48409278793A574C4D40F4C308E1D1CC48409278793A574C4D40
49052	369	49.613702000000004	49.619532	58.641860000000001	58.639583999999999	Макаренко	0103000020E61000000100000005000000B2BE81C98DCE4840BE8575E3DD514D40B2BE81C98DCE4840274EEE7728524D40A96917D34CCF4840274EEE7728524D40A96917D34CCF4840BE8575E3DD514D40B2BE81C98DCE4840BE8575E3DD514D40
6737	369	49.584353999999998	49.613342000000003	58.639738000000001	58.606707999999998	Луганская улица	0103000020E61000000100000005000000B5A4A31CCCCA48405C1C959BA84D4D40B5A4A31CCCCA484015014EEFE2514D40B2A19BFD81CE484015014EEFE2514D40B2A19BFD81CE48405C1C959BA84D4D40B5A4A31CCCCA48405C1C959BA84D4D40
48975	369	49.598627999999998	49.613567000000003	58.615633000000003	58.602597000000003	Ломоносова	0103000020E61000000100000005000000253CA1D79FCC484078D503E6214D4D40253CA1D79FCC484050ABE80FCD4E4D40D2730B5D89CE484050ABE80FCD4E4D40D2730B5D89CE484078D503E6214D4D40253CA1D79FCC484078D503E6214D4D40
7493	369	49.697477999999997	49.702311000000002	58.596176999999997	58.591206	Лесозаводская улица	0103000020E61000000100000005000000F9D687F546D94840789961A3AC4B4D40F9D687F546D948404ED026874F4C4D407F4FAC53E5D948404ED026874F4C4D407F4FAC53E5D94840789961A3AC4B4D40F9D687F546D94840789961A3AC4B4D40
49013	369	49.613351000000002	49.647370000000002	58.624724000000001	58.607396999999999	Лепсе	0103000020E6100000010000000500000005FC1A4982CE48402158552FBF4D4D4005FC1A4982CE48405E83BEF4F64F4D40AD342905DDD248405E83BEF4F64F4D40AD342905DDD248402158552FBF4D4D4005FC1A4982CE48402158552FBF4D4D40
6695	369	49.613118	49.619298000000001	58.636591000000003	58.632973999999997	Ленинградская улица	0103000020E61000000100000005000000624B8FA67ACE4840F19BC24A05514D40624B8FA67ACE4840C7F65AD07B514D40363D282845CF4840C7F65AD07B514D40363D282845CF4840F19BC24A05514D40624B8FA67ACE4840F19BC24A05514D40
49073	369	49.613118	49.619298000000001	58.636591000000003	58.632973999999997	Ленинградская	0103000020E61000000100000005000000624B8FA67ACE4840F19BC24A05514D40624B8FA67ACE4840C7F65AD07B514D40363D282845CF4840C7F65AD07B514D40363D282845CF4840F19BC24A05514D40624B8FA67ACE4840F19BC24A05514D40
49272	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49003	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49247	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49000	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49053	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49030	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49253	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49087	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49041	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49016	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
48985	369	49.702553999999999	49.711509999999997	58.621420999999998	58.619976999999999	Красный Химик	0103000020E6100000010000000500000045D61A4AEDD94840D7A205685B4F4D4045D61A4AEDD9484018062CB98A4F4D4073637AC212DB484018062CB98A4F4D4073637AC212DB4840D7A205685B4F4D4045D61A4AEDD94840D7A205685B4F4D40
15454	369	49.641316000000003	49.688558	58.591932999999997	58.590694999999997	Красноармейская улица	0103000020E61000000100000005000000663387A416D248409274CDE49B4B4D40663387A416D248402A36E675C44B4D4018B325AB22D848402A36E675C44B4D4018B325AB22D848409274CDE49B4B4D40663387A416D248409274CDE49B4B4D40
49046	369	49.618535000000001	49.647495999999997	58.580694000000001	58.575983999999998	Красина	0103000020E610000001000000050000003737A6272CCF48407782FDD7B9494D403737A6272CCF4840E17D552E544A4D4039252026E1D24840E17D552E544A4D4039252026E1D248407782FDD7B9494D403737A6272CCF48407782FDD7B9494D40
49226	369	49.530445999999998	49.794128000000001	58.681148999999998	58.481724	Космонавтов	0103000020E61000000100000005000000A2258FA7E5C3484062D9CC21A93D4D40A2258FA7E5C34840FF59F3E32F574D40406B7EFCA5E54840FF59F3E32F574D40406B7EFCA5E5484062D9CC21A93D4D40A2258FA7E5C3484062D9CC21A93D4D40
48808	369	49.590587999999997	49.599921000000002	58.592087999999997	58.591960999999998	Космонавта Волкова	0103000020E610000001000000050000007CB4386398CB4840F4C0C760C54B4D407CB4386398CB4840512D228AC94B4D4081971936CACC4840512D228AC94B4D4081971936CACC4840F4C0C760C54B4D407CB4386398CB4840F4C0C760C54B4D40
48994	369	49.626151999999998	49.670071	58.585248999999997	58.572952999999998	Комсомольская	0103000020E610000001000000050000009929ADBF25D0484092921E8656494D409929ADBF25D0484023827170E94A4D40BF7FF3E2C4D5484023827170E94A4D40BF7FF3E2C4D5484092921E8656494D409929ADBF25D0484092921E8656494D40
49015	369	49.626151999999998	49.670071	58.585248999999997	58.572952999999998	Комсомольская	0103000020E610000001000000050000009929ADBF25D0484092921E8656494D409929ADBF25D0484023827170E94A4D40BF7FF3E2C4D5484023827170E94A4D40BF7FF3E2C4D5484092921E8656494D409929ADBF25D0484092921E8656494D40
49070	369	49.626151999999998	49.670071	58.585248999999997	58.572952999999998	Комсомольская	0103000020E610000001000000050000009929ADBF25D0484092921E8656494D409929ADBF25D0484023827170E94A4D40BF7FF3E2C4D5484023827170E94A4D40BF7FF3E2C4D5484092921E8656494D409929ADBF25D0484092921E8656494D40
49258	369	49.626151999999998	49.670071	58.585248999999997	58.572952999999998	Комсомольская	0103000020E610000001000000050000009929ADBF25D0484092921E8656494D409929ADBF25D0484023827170E94A4D40BF7FF3E2C4D5484023827170E94A4D40BF7FF3E2C4D5484092921E8656494D409929ADBF25D0484092921E8656494D40
49661	369	49.626151999999998	49.670071	58.585248999999997	58.572952999999998	Комсомольская	0103000020E610000001000000050000009929ADBF25D0484092921E8656494D409929ADBF25D0484023827170E94A4D40BF7FF3E2C4D5484023827170E94A4D40BF7FF3E2C4D5484092921E8656494D409929ADBF25D0484092921E8656494D40
48999	369	49.591557999999999	49.607574999999997	58.609614999999998	58.605189000000003	Кольцова	0103000020E61000000100000005000000F5D72B2CB8CB4840117349D5764D4D40F5D72B2CB8CB4840551344DD074E4D40006F8104C5CD4840551344DD074E4D40006F8104C5CD4840117349D5764D4D40F5D72B2CB8CB4840117349D5764D4D40
49066	369	49.700181999999998	49.704521	58.588932	58.577997000000003	Ключевая	0103000020E61000000100000005000000BA9F53909FD94840D31742CEFB494D40BA9F53909FD94840B0C8AF1F624B4D40302C7FBE2DDA4840B0C8AF1F624B4D40302C7FBE2DDA4840D31742CEFB494D40BA9F53909FD94840D31742CEFB494D40
49005	369	49.717933000000002	49.723636999999997	58.642066	58.641072999999999	Клубная	0103000020E610000001000000050000000EDC813AE5DB48409FAC18AE0E524D400EDC813AE5DB4840D0EFFB372F524D4078962023A0DC4840D0EFFB372F524D4078962023A0DC48409FAC18AE0E524D400EDC813AE5DB48409FAC18AE0E524D40
49062	369	49.655788000000001	49.672721000000003	58.620254000000003	58.582251999999997	Карла Маркса	0103000020E61000000100000005000000FC8D76DCF0D34840EA03C93B874A4D40FC8D76DCF0D348404A9BAA7B644F4D408D2AC3B81BD648404A9BAA7B644F4D408D2AC3B81BD64840EA03C93B874A4D40FC8D76DCF0D34840EA03C93B874A4D40
49007	369	49.620358000000003	49.650900999999998	58.587698000000003	58.587145	Калинина	0103000020E61000000100000005000000EFE714E467CF484045813E91274B4D40EFE714E467CF48405AF624B0394B4D4083F755B950D348405AF624B0394B4D4083F755B950D3484045813E91274B4D40EFE714E467CF484045813E91274B4D40
48955	369	49.704242999999998	49.707197999999998	58.506090999999998	58.504581999999999	Индустриальная	0103000020E61000000100000005000000EDB776A224DA48403C139A2496404D40EDB776A224DA484064E60297C7404D40F7E5CC7685DA484064E60297C7404D40F7E5CC7685DA48403C139A2496404D40EDB776A224DA48403C139A2496404D40
49009	369	49.704242999999998	49.707197999999998	58.506090999999998	58.504581999999999	Индустриальная	0103000020E61000000100000005000000EDB776A224DA48403C139A2496404D40EDB776A224DA484064E60297C7404D40F7E5CC7685DA484064E60297C7404D40F7E5CC7685DA48403C139A2496404D40EDB776A224DA48403C139A2496404D40
49256	369	49.727617000000002	49.731110999999999	58.637512999999998	58.636380000000003	Заречная	0103000020E61000000100000005000000BF81C98D22DD48400CEA5BE674514D40BF81C98D22DD48402EE3A6069A514D40785F950B95DD48402EE3A6069A514D40785F950B95DD48400CEA5BE674514D40BF81C98D22DD48400CEA5BE674514D40
48996	369	49.650128000000002	49.654943000000003	58.575721000000001	58.573971	Есенина	0103000020E61000000100000005000000611BF16437D348401CEDB8E177494D40611BF16437D348406A4FC939B1494D4040DF162CD5D348406A4FC939B1494D4040DF162CD5D348401CEDB8E177494D40611BF16437D348401CEDB8E177494D40
48958	369	49.600425000000001	49.634821000000002	58.634576000000003	58.630524000000001	Дзержинского	0103000020E61000000100000005000000B459F5B9DACC4840EBABAB02B5504D40B459F5B9DACC4840CB694FC939514D4032E884D041D14840CB694FC939514D4032E884D041D14840EBABAB02B5504D40B459F5B9DACC4840EBABAB02B5504D40
48992	369	49.650083000000002	49.652436999999999	58.603313999999997	58.579531000000003	Горького	0103000020E61000000100000005000000C15774EB35D34840540262122E4A4D40C15774EB35D34840069CA564394D4D40A5D93C0E83D34840069CA564394D4D40A5D93C0E83D34840540262122E4A4D40C15774EB35D34840540262122E4A4D40
49028	369	49.651367999999998	49.651907000000001	58.611162	58.605110000000003	Горбуновой	0103000020E6100000010000000500000099D4D00660D34840C53D963E744D4D4099D4D00660D348406B47718E3A4E4D40498446B071D348406B47718E3A4E4D40498446B071D34840C53D963E744D4D4099D4D00660D34840C53D963E744D4D40
48974	369	49.635477000000002	49.642367	58.628228999999997	58.625497000000003	Гайдара	0103000020E610000001000000050000001B2E724F57D14840815F234910504D401B2E724F57D148400BB3D0CE69504D40CB83F41439D248400BB3D0CE69504D40CB83F41439D24840815F234910504D401B2E724F57D14840815F234910504D40
49089	369	49.743634	49.751367999999999	58.608105000000002	58.605677	Вятская Набережная	0103000020E61000000100000005000000CA181F662FDF48403E78EDD2864D4D40CA181F662FDF48405DC47762D64D4D4066A19DD32CE048405DC47762D64D4D4066A19DD32CE048403E78EDD2864D4D40CA181F662FDF48403E78EDD2864D4D40
49065	369	49.743634	49.751367999999999	58.608105000000002	58.605677	Вятская	0103000020E61000000100000005000000CA181F662FDF48403E78EDD2864D4D40CA181F662FDF48405DC47762D64D4D4066A19DD32CE048405DC47762D64D4D4066A19DD32CE048403E78EDD2864D4D40CA181F662FDF48403E78EDD2864D4D40
49018	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
48990	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
49061	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
48995	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
49071	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
49050	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
49068	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
49067	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
49047	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
49082	369	49.605589999999999	49.611320999999997	58.61703	58.613655000000001	Вологодская	0103000020E610000001000000050000006F641EF983CD484071033E3F8C4E4D406F641EF983CD48405053CBD6FA4E4D40D32D3BC43FCE48405053CBD6FA4E4D40D32D3BC43FCE484071033E3F8C4E4D406F641EF983CD484071033E3F8C4E4D40
49060	369	49.798889000000003	49.808861	58.610055000000003	58.606820999999997	Боровицкая	0103000020E610000001000000050000002C11A8FE41E6484054C37E4FAC4D4D402C11A8FE41E6484072E14048164E4D404301DBC188E7484072E14048164E4D404301DBC188E7484054C37E4FAC4D4D402C11A8FE41E6484054C37E4FAC4D4D40
49037	369	49.734462000000001	49.741469000000002	58.649132000000002	58.639125	Боровая	0103000020E61000000100000005000000CF13CFD902DE48402B8716D9CE514D40CF13CFD902DE4840BF64E3C116534D40B9FFC874E8DE4840BF64E3C116534D40B9FFC874E8DE48402B8716D9CE514D40CF13CFD902DE48402B8716D9CE514D40
49054	369	49.683095999999999	49.685594000000002	58.615408000000002	58.586168999999998	Большевиков	0103000020E61000000100000005000000A30392B06FD74840EA76F695074B4D40A30392B06FD7484030D978B0C54E4D40BB2A508BC1D7484030D978B0C54E4D40BB2A508BC1D74840EA76F695074B4D40A30392B06FD74840EA76F695074B4D40
49038	369	49.667268	49.688882	58.586126999999998	58.580661999999997	Блюхера	0103000020E610000001000000050000006BD5AE0969D54840D503E621534A4D406BD5AE0969D54840BB26A435064B4D40CB660E492DD84840BB26A435064B4D40CB660E492DD84840D503E621534A4D406BD5AE0969D54840D503E621534A4D40
48978	369	49.651035999999998	49.685594000000002	58.586168999999998	58.585006	Азина	0103000020E610000001000000050000006342CC2555D348405DFB027AE14A4D406342CC2555D34840EA76F695074B4D40BB2A508BC1D74840EA76F695074B4D40BB2A508BC1D748405DFB027AE14A4D406342CC2555D348405DFB027AE14A4D40
49064	369	49.651035999999998	49.685594000000002	58.586168999999998	58.585006	Азина	0103000020E610000001000000050000006342CC2555D348405DFB027AE14A4D406342CC2555D34840EA76F695074B4D40BB2A508BC1D74840EA76F695074B4D40BB2A508BC1D748405DFB027AE14A4D406342CC2555D348405DFB027AE14A4D40
48769	369	49.590542999999997	49.591943999999998	58.608606999999999	58.602175000000003	А.Упита	0103000020E61000000100000005000000DCF0BBE996CB484002BC0512144D4D40DCF0BBE996CB4840EF8E8CD5E64D4D401E882CD2C4CB4840EF8E8CD5E64D4D401E882CD2C4CB484002BC0512144D4D40DCF0BBE996CB484002BC0512144D4D40
49039	369	49.672694	49.683473999999997	58.662042999999997	58.657676000000002	60-летия Комсомола	0103000020E61000000100000005000000931B45D61AD648409BAE27BA2E544D40931B45D61AD64840DAC534D3BD544D4049D576137CD74840DAC534D3BD544D4049D576137CD748409BAE27BA2E544D40931B45D61AD648409BAE27BA2E544D40
49040	369	49.651232999999998	49.669918000000003	58.567020999999997	58.556303999999997	4-й Пятилетки	0103000020E61000000100000005000000B9895A9A5BD3484026512FF834474D40B9895A9A5BD348409692E52494484D4039807EDFBFD548409692E52494484D4039807EDFBFD5484026512FF834474D40B9895A9A5BD3484026512FF834474D40
48989	369	49.709614999999999	49.715696000000001	58.499358000000001	58.489212999999999	 Школьная	0103000020E6100000010000000500000022E010AAD4DA484097E315889E3E4D4022E010AAD4DA48407C7F83F6EA3F4D4063F030ED9BDB48407C7F83F6EA3F4D4063F030ED9BDB484097E315889E3E4D4022E010AAD4DA484097E315889E3E4D40
48993	369	49.789465999999997	49.792161	58.606290999999999	58.604294000000003	 Сосновая	0103000020E61000000100000005000000E7A6CD380DE54840A3957B81594D4D40E7A6CD380DE54840F86D88F19A4D4D4055151A8865E54840F86D88F19A4D4D4055151A8865E54840A3957B81594D4D40E7A6CD380DE54840A3957B81594D4D40
48987	369	49.612344999999998	49.624993000000003	58.640745000000003	58.639181000000001	 Подгорная	0103000020E610000001000000050000003F6F2A5261CE4840BF9CD9AED0514D403F6F2A5261CE4840AB09A2EE03524D404E9D47C5FFCF4840AB09A2EE03524D404E9D47C5FFCF4840BF9CD9AED0514D403F6F2A5261CE4840BF9CD9AED0514D40
49048	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	 Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49476	369	49.679602000000003	49.685333	58.617891999999998	58.563110999999999	 Ленина	0103000020E61000000100000005000000EA25C632FDD648404982700514484D40EA25C632FDD64840E23AC615174F4D404EEFE2FDB8D74840E23AC615174F4D404EEFE2FDB8D748404982700514484D40EA25C632FDD648404982700514484D40
49650	369	49.655788000000001	49.672721000000003	58.620254000000003	58.582251999999997	 Карла Маркса	0103000020E61000000100000005000000FC8D76DCF0D34840EA03C93B874A4D40FC8D76DCF0D348404A9BAA7B644F4D408D2AC3B81BD648404A9BAA7B644F4D408D2AC3B81BD64840EA03C93B874A4D40FC8D76DCF0D34840EA03C93B874A4D40
48984	369	49.657637999999999	49.691136	58.602272999999997	58.601570000000002	 Дрелевского	0103000020E61000000100000005000000AD4D637B2DD448409B20EA3E004D4D40AD4D637B2DD44840C4211B48174D4D404C8BFA2477D84840C4211B48174D4D404C8BFA2477D848409B20EA3E004D4D40AD4D637B2DD448409B20EA3E004D4D40
49042	369	49.650083000000002	49.652436999999999	58.603313999999997	58.579531000000003	 Горького	0103000020E61000000100000005000000C15774EB35D34840540262122E4A4D40C15774EB35D34840069CA564394D4D40A5D93C0E83D34840069CA564394D4D40A5D93C0E83D34840540262122E4A4D40C15774EB35D34840540262122E4A4D40
49045	369	49.585000000000001	49.690669	58.597003000000001	58.593209000000002	 Воровского	0103000020E610000001000000050000007B14AE47E1CA4840B058C345EE4B4D407B14AE47E1CA4840944E24986A4C4D4036AE7FD767D84840944E24986A4C4D4036AE7FD767D84840B058C345EE4B4D407B14AE47E1CA4840B058C345EE4B4D40
77522	369	49.210089000000004	49.848134999999999	58.671959999999999	58.470393000000001	 Аэропорт	0103000020E61000000100000005000000EB1F4432E49A484038A27BD6353C4D40EB1F4432E49A48402E1C08C902564D40E6CB0BB08FEC48402E1C08C902564D40E6CB0BB08FEC484038A27BD6353C4D40EB1F4432E49A484038A27BD6353C4D40
9800	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Шорина	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48773	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Школьная	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48888	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Тойменка	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48818	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Советская	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48824	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Пароходная	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48904	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Ленина	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48762	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Кукина	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48893	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Кирова	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48913	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Дзержинского	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48890	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Гагарина	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48910	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	Азина	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48912	11679	51.011381	51.097242000000001	56.249260999999997	56.203082000000002	 Ленина	0103000020E61000000100000005000000DC65BFEE7481494001344A97FE194C40DC65BFEE748149408995D1C8E71F4C4019E6046D728C49408995D1C8E71F4C4019E6046D728C494001344A97FE194C40DC65BFEE7481494001344A97FE194C40
48822	55980	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Здравоохранения	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
48748	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Чапаева	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48755	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Тургенева	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
49316	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Северная	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48819	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Садовая	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48752	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Некрасова	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48797	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Мира	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48816	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Кирова	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
49161	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	Карла Маркса	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48814	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	 Рудницкого	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
48751	6761	47.832019000000003	47.906632999999999	57.317028000000001	57.280912000000001	 Кирова	0103000020E6100000010000000500000048533D997FEA4740E886A6ECF4A34C4048533D997FEA474049F59D5F94A84C40B83CD68C0CF4474049F59D5F94A84C40B83CD68C0CF44740E886A6ECF4A34C4048533D997FEA4740E886A6ECF4A34C40
58541	57427	47.396191999999999	48.555711000000002	57.462997999999999	56.957776000000003	Мира	0103000020E61000000100000005000000EA77616BB6B2474065726A67987A4C40EA77616BB6B24740840EBA8443BB4C408483BD8921474840840EBA8443BB4C408483BD892147484065726A67987A4C40EA77616BB6B2474065726A67987A4C40
49420	104	47.938980999999998	47.960729999999998	57.129206000000003	57.118056000000003	Октябрьская	0103000020E610000001000000050000005E48878730F847405D8C81751C8F4C405E48878730F8474037397CD289904C409E245D33F9FA474037397CD289904C409E245D33F9FA47405D8C81751C8F4C405E48878730F847405D8C81751C8F4C40
49548	31873	47.459218	47.486742999999997	57.282176999999997	57.269317000000001	Набережная	0103000020E6100000010000000500000005DEC9A7C7BA4740E0A0BDFA78A24C4005DEC9A7C7BA474079573D601EA44C40494739984DBE474079573D601EA44C40494739984DBE4740E0A0BDFA78A24C4005DEC9A7C7BA4740E0A0BDFA78A24C40
49319	32416	48.278823000000003	48.299996	57.285310000000003	57.274334000000003	Школьная	0103000020E61000000100000005000000B22FD978B0234840271763601DA34C40B22FD978B0234840639CBF0985A44C402577D84466264840639CBF0985A44C402577D84466264840271763601DA34C40B22FD978B0234840271763601DA34C40
49111	32310	48.040320000000001	48.074204999999999	57.111761999999999	57.095585	Свободы	0103000020E61000000100000005000000F7AFAC34290548407C7E18213C8C4C40F7AFAC3429054840C0779B374E8E4C408F19A88C7F094840C0779B374E8E4C408F19A88C7F0948407C7E18213C8C4C40F7AFAC34290548407C7E18213C8C4C40
49553	32068	48.099348999999997	48.128813000000001	57.428601999999998	57.412981000000002	Черепановская	0103000020E61000000100000005000000F5F1D077B70C4840486FB88FDCB44C40F5F1D077B70C484006802A6EDCB64C405B26C3F17C10484006802A6EDCB64C405B26C3F17C104840486FB88FDCB44C40F5F1D077B70C4840486FB88FDCB44C40
49450	56009	47.832521999999997	47.866083000000003	57.395240000000001	57.385553000000002	Школьный переулок	0103000020E61000000100000005000000AA99B51490EA4740F6EFFACC59B14C40AA99B51490EA474018096D3997B24C40904FC8CEDBEE474018096D3997B24C40904FC8CEDBEE4740F6EFFACC59B14C40AA99B51490EA4740F6EFFACC59B14C40
49599	32251	48.212617000000002	48.219453000000001	57.334229000000001	57.329307999999997	Школьная	0103000020E610000001000000050000006DC9AA08371B4840D427B9C326AA4C406DC9AA08371B4840F92F1004C8AA4C402A013109171C4840F92F1004C8AA4C402A013109171C4840D427B9C326AA4C406DC9AA08371B4840D427B9C326AA4C40
49551	6826	47.935864000000002	47.957424000000003	57.357939000000002	57.340373999999997	Советская	0103000020E610000001000000050000007BC03C64CAF7474050340F6091AB4C407BC03C64CAF74740427BF5F1D0AD4C40E833A0DE8CFA4740427BF5F1D0AD4C40E833A0DE8CFA474050340F6091AB4C407BC03C64CAF7474050340F6091AB4C40
49554	31967	47.554133999999998	47.571300999999998	57.147520999999998	57.13711	Центральная	0103000020E6100000010000000500000003CDE7DCEDC647402FFA0AD28C914C4003CDE7DCEDC64740923CD7F7E1924C400796236420C94740923CD7F7E1924C400796236420C947402FFA0AD28C914C4003CDE7DCEDC647402FFA0AD28C914C40
49166	32157	47.900686	47.934255999999998	57.392363000000003	57.376693000000003	Школьная	0103000020E6100000010000000500000087FBC8AD49F34740EAD0E97937B04C4087FBC8AD49F347408A9466F338B24C40BF0B5BB395F747408A9466F338B24C40BF0B5BB395F74740EAD0E97937B04C4087FBC8AD49F34740EAD0E97937B04C40
49217	32135	48.257767000000001	48.447885999999997	57.369754	57.181874999999998	Труда	0103000020E61000000100000005000000787E5182FE204840E17A14AE47974C40787E5182FE20484058C85C1954AF4C400A2B15545439484058C85C1954AF4C400A2B155454394840E17A14AE47974C40787E5182FE204840E17A14AE47974C40
49327	31988	48.055213999999999	48.095818000000001	57.389772999999998	57.374723000000003	Никольская	0103000020E6100000010000000500000003249A40110748408E075BECF6AF4C4003249A401107484091EEE714E4B14C401F2FA4C3430C484091EEE714E4B14C401F2FA4C3430C48408E075BECF6AF4C4003249A40110748408E075BECF6AF4C40
49603	32467	48.185865	48.210352999999998	57.240713999999997	57.233018000000001	Центральная	0103000020E610000001000000050000004B3CA06CCA1748408EB0A888D39D4C404B3CA06CCA1748403CD862B7CF9E4C40C8CEDBD8EC1A48403CD862B7CF9E4C40C8CEDBD8EC1A48408EB0A888D39D4C404B3CA06CCA1748408EB0A888D39D4C40
49314	30232	47.897084	47.916541000000002	57.186587000000003	57.172224999999997	Мира	0103000020E61000000100000005000000E7E104A6D3F24740DC4603780B964C40E7E104A6D3F24740EC6D3315E2974C40B9382A3751F54740EC6D3315E2974C40B9382A3751F54740DC4603780B964C40E7E104A6D3F24740DC4603780B964C40
49598	31804	47.6646	47.690219999999997	57.402436000000002	57.388953000000001	Школьная	0103000020E61000000100000005000000F775E09C11D547402E573F36C9B14C40F775E09C11D54740D55DD90583B34C40C685032159D84740D55DD90583B34C40C685032159D847402E573F36C9B14C40F775E09C11D547402E573F36C9B14C40
49550	32518	47.628352999999997	47.650199999999998	57.210845999999997	57.201870999999997	Свободы	0103000020E61000000100000005000000F7AB00DF6DD047406281AFE8D6994C40F7AB00DF6DD04740073F7100FD9A4C40FAEDEBC039D34740073F7100FD9A4C40FAEDEBC039D347406281AFE8D6994C40F7AB00DF6DD047406281AFE8D6994C40
49317	31786	47.631407000000003	47.680517999999999	57.316575999999998	57.305638000000002	Зелёная	0103000020E6100000010000000500000095BBCFF1D1D047401A355F251FA74C4095BBCFF1D1D047406859F78F85A84C406F2BBD361BD747406859F78F85A84C406F2BBD361BD747401A355F251FA74C4095BBCFF1D1D047401A355F251FA74C40
49427	119	47.907890999999999	47.937562	57.038952999999999	57.024400999999997	Космодемьянская	0103000020E6100000010000000500000097AAB4C535F44740AE7E6C921F834C4097AAB4C535F44740618A7269FC844C4076FC170802F84740618A7269FC844C4076FC170802F84740AE7E6C921F834C4097AAB4C535F44740AE7E6C921F834C40
49110	30923	47.822918999999999	47.849086999999997	57.252893	57.238342000000003	Колхозная	0103000020E61000000100000005000000E620E86855E94740B2A19BFD819E4C40E620E86855E9474094313ECC5EA04C40B83A00E2AEEC474094313ECC5EA04C40B83A00E2AEEC4740B2A19BFD819E4C40E620E86855E94740B2A19BFD819E4C40
49235	30923	47.822918999999999	47.849086999999997	57.252893	57.238342000000003	Кирова	0103000020E61000000100000005000000E620E86855E94740B2A19BFD819E4C40E620E86855E9474094313ECC5EA04C40B83A00E2AEEC474094313ECC5EA04C40B83A00E2AEEC4740B2A19BFD819E4C40E620E86855E94740B2A19BFD819E4C40
49422	31694	47.912624999999998	47.945323999999999	57.298971999999999	57.283442000000001	Центральная	0103000020E61000000100000005000000894160E5D0F447400B28D4D347A44C40894160E5D0F44740B935E9B644A64C40DC0F786000F94740B935E9B644A64C40DC0F786000F947400B28D4D347A44C40894160E5D0F447400B28D4D347A44C40
49423	31609	47.852986000000001	48.061314000000003	57.229861	57.068930999999999	Лобова	0103000020E6100000010000000500000012F92EA52EED47401D5723BBD2884C4012F92EA52EED47401CD0D2156C9D4C40BB641C23D90748401CD0D2156C9D4C40BB641C23D90748401D5723BBD2884C4012F92EA52EED47401D5723BBD2884C40
49601	32330	48.154451000000002	48.175947999999998	57.143169999999998	57.129558000000003	Полевая	0103000020E61000000100000005000000D1EAE40CC5134840B477465B95904C40D1EAE40CC513484058E2016553924C40F7E5CC768516484058E2016553924C40F7E5CC7685164840B477465B95904C40D1EAE40CC5134840B477465B95904C40
48942	30617	49.242643999999999	49.314337999999999	59.054067000000003	59.027614999999997	Энгельса	0103000020E610000001000000050000000A4966F50E9F484084F068E388834D400A4966F50E9F48407C65DEAAEB864D40EDF1423A3CA848407C65DEAAEB864D40EDF1423A3CA8484084F068E388834D400A4966F50E9F484084F068E388834D40
48944	30617	49.242643999999999	49.314337999999999	59.054067000000003	59.027614999999997	Ленина	0103000020E610000001000000050000000A4966F50E9F484084F068E388834D400A4966F50E9F48407C65DEAAEB864D40EDF1423A3CA848407C65DEAAEB864D40EDF1423A3CA8484084F068E388834D400A4966F50E9F484084F068E388834D40
48945	30617	49.242643999999999	49.314337999999999	59.054067000000003	59.027614999999997	Дачная	0103000020E610000001000000050000000A4966F50E9F484084F068E388834D400A4966F50E9F48407C65DEAAEB864D40EDF1423A3CA848407C65DEAAEB864D40EDF1423A3CA8484084F068E388834D400A4966F50E9F484084F068E388834D40
49311	30011	49.279591000000003	49.313448999999999	59.086367000000003	59.068913999999999	Юбилейная	0103000020E61000000100000005000000C3A04CA3C9A34840471E882CD2884D40C3A04CA3C9A34840113AE8120E8B4D4061FBC9181FA84840113AE8120E8B4D4061FBC9181FA84840471E882CD2884D40C3A04CA3C9A34840471E882CD2884D40
49318	30551	49.470007000000003	49.503326000000001	58.810648999999998	58.798305999999997	Кольцевая	0103000020E610000001000000050000000FF27A3029BC4840AC1919E42E664D400FF27A3029BC48407EC4AF58C3674D40FE9C82FC6CC048407EC4AF58C3674D40FE9C82FC6CC04840AC1919E42E664D400FF27A3029BC4840AC1919E42E664D40
49702	56035	49.270544999999998	49.299965	59.071629000000001	59.053327000000003	 Волкова	0103000020E61000000100000005000000548CF337A1A24840357F4C6BD3864D40548CF337A1A24840FC389A232B894D40EA78CC4065A64840FC389A232B894D40EA78CC4065A64840357F4C6BD3864D40548CF337A1A24840357F4C6BD3864D40
48744	30788	49.433607000000002	49.495600000000003	58.751975000000002	58.726215000000003	Набережная	0103000020E610000001000000050000008928266F80B74840AD6EF59CF45C4D408928266F80B748406E3480B740604D40E5F21FD26FBF48406E3480B740604D40E5F21FD26FBF4840AD6EF59CF45C4D408928266F80B74840AD6EF59CF45C4D40
48747	30788	49.433607000000002	49.495600000000003	58.751975000000002	58.726215000000003	Красных курсантов	0103000020E610000001000000050000008928266F80B74840AD6EF59CF45C4D408928266F80B748406E3480B740604D40E5F21FD26FBF48406E3480B740604D40E5F21FD26FBF4840AD6EF59CF45C4D408928266F80B74840AD6EF59CF45C4D40
49597	30296	49.401223000000002	49.424804000000002	58.902841000000002	58.890089000000003	 Тополиная	0103000020E6100000010000000500000096B377465BB34840C2C3B46FEE714D4096B377465BB34840753E3C4B90734D40E19A3BFA5FB64840753E3C4B90734D40E19A3BFA5FB64840C2C3B46FEE714D4096B377465BB34840C2C3B46FEE714D40
49268	56001	49.339671000000003	49.369486000000002	58.783752	58.769570999999999	Советская	0103000020E610000001000000050000002733DE567AAB48409A79724D81624D402733DE567AAB484059164CFC51644D40392A37514BAF484059164CFC51644D40392A37514BAF48409A79724D81624D402733DE567AAB48409A79724D81624D40
49600	30318	49.580894999999998	49.602024	58.893869000000002	58.878123000000002	Исаковская	0103000020E6100000010000000500000078B471C45ACA4840C66E9F5566704D4078B471C45ACA484041F4A44C6A724D401CB4571F0FCD484041F4A44C6A724D401CB4571F0FCD4840C66E9F5566704D4078B471C45ACA4840C66E9F5566704D40
49545	56010	49.419215999999999	49.427095000000001	58.917907	58.912233999999998	Школьная	0103000020E61000000100000005000000DFFAB0DEA8B548404E266E15C4744D40DFFAB0DEA8B548407EE200FA7D754D407FA4880CABB648407EE200FA7D754D407FA4880CABB648404E266E15C4744D40DFFAB0DEA8B548404E266E15C4744D40
49421	30111	49.537973999999998	49.563189000000001	58.993929000000001	58.980246000000001	Центральная	0103000020E61000000100000005000000950C0055DCC44840750470B3787D4D40950C0055DCC44840E3C5C210397F4D40C53BC09316C84840E3C5C210397F4D40C53BC09316C84840750470B3787D4D40950C0055DCC44840750470B3787D4D40
49418	30032	49.313377000000003	49.342382999999998	59.03895	59.029111	Колхозная	0103000020E61000000100000005000000C828CFBC1CA84840187AC4E8B9834D40C828CFBC1CA84840F0164850FC844D406ADAC534D3AB4840F0164850FC844D406ADAC534D3AB4840187AC4E8B9834D40C828CFBC1CA84840187AC4E8B9834D40
49162	30402	49.594845999999997	49.631264000000002	58.821846999999998	58.806781000000001	Советская	0103000020E610000001000000050000000514EAE923CC484060048D9944674D400514EAE923CC484069A8514832694D4032923D42CDD0484069A8514832694D4032923D42CDD0484060048D9944674D400514EAE923CC484060048D9944674D40
49220	30447	49.534964000000002	49.571921000000003	58.737864000000002	58.722617	Заводская	0103000020E61000000100000005000000C8444AB379C448404E44BFB67E5C4D40C8444AB379C44840A872DA53725E4D40A47213B534C94840A872DA53725E4D40A47213B534C948404E44BFB67E5C4D40C8444AB379C448404E44BFB67E5C4D40
49602	30149	49.289535999999998	49.317213000000002	58.994132999999998	58.983691999999998	Советская	0103000020E61000000100000005000000E08101840FA548401DAB949EE97D4D40E08101840FA54840EB6F09C03F7F4D40DB6E826F9AA84840EB6F09C03F7F4D40DB6E826F9AA848401DAB949EE97D4D40E08101840FA548401DAB949EE97D4D40
49595	29930	49.131351000000002	49.165649000000002	59.157800000000002	59.146217999999998	Советская	0103000020E6100000010000000500000001A60C1CD0904840130B7C45B7924D4001A60C1CD090484087A757CA32944D40BCCE86FC3395484087A757CA32944D40BCCE86FC33954840130B7C45B7924D4001A60C1CD0904840130B7C45B7924D40
49160	30172	49.169269	49.187325000000001	59.038598	59.019925999999998	Сычугова	0103000020E61000000100000005000000029D499BAA954840882B67EF8C824D40029D499BAA95484073D87DC7F0844D40925CFE43FA97484073D87DC7F0844D40925CFE43FA974840882B67EF8C824D40029D499BAA954840882B67EF8C824D40
49552	30597	49.032563000000003	49.066619000000003	58.900917	58.888629000000002	Центральная	0103000020E61000000100000005000000A3073E062B8448407BA35698BE714D40A3073E062B84484089B48D3F51734D406825ADF88688484089B48D3F51734D406825ADF8868848407BA35698BE714D40A3073E062B8448407BA35698BE714D40
49546	56011	49.020893999999998	49.049720999999998	59.233387999999998	59.217098	Комсомольская	0103000020E61000000100000005000000605793A7AC824840750305DEC99B4D40605793A7AC824840B1A371A8DF9D4D405376FA415D864840B1A371A8DF9D4D405376FA415D864840750305DEC99B4D40605793A7AC824840750305DEC99B4D40
49167	29838	47.375908000000003	47.428989999999999	58.695810999999999	58.676586999999998	Набережная	0103000020E610000001000000050000000327DBC01DB047400AF31E679A564D400327DBC01DB047403999B85510594D40D027F224E9B647403999B85510594D40D027F224E9B647400AF31E679A564D400327DBC01DB047400AF31E679A564D40
49206	55999	47.389733	47.394899000000002	58.657442000000003	58.654801999999997	Первомайская	0103000020E6100000010000000500000003965CC5E2B147407DAD4B8DD0534D4003965CC5E2B147402882380F27544D408F1CE90C8CB247402882380F27544D408F1CE90C8CB247407DAD4B8DD0534D4003965CC5E2B147407DAD4B8DD0534D40
49594	29823	47.120499000000002	47.141646000000001	58.559885999999999	58.542076000000002	Советская	0103000020E61000000100000005000000B119E0826C8F474027F911BF62454D40B119E0826C8F47407FBE2D58AA474D40FBCDC474219247407FBE2D58AA474D40FBCDC4742192474027F911BF62454D40B119E0826C8F474027F911BF62454D40
49674	29677	47.106772999999997	47.124209	58.198098000000002	58.186039999999998	Мира	0103000020E61000000100000005000000438CD7BCAA8D4740B9DFA128D0174D40438CD7BCAA8D474096B377465B194D40376F9C14E68F474096B377465B194D40376F9C14E68F4740B9DFA128D0174D40438CD7BCAA8D4740B9DFA128D0174D40
49417	29356	47.339913000000003	47.355291999999999	58.301076000000002	58.288134999999997	Победы	0103000020E610000001000000050000001D3EE94482AB47409EEA909BE1244D401D3EE94482AB474025CE8AA889264D40E54350357AAD474025CE8AA889264D40E54350357AAD47409EEA909BE1244D401D3EE94482AB47409EEA909BE1244D40
49216	29700	47.046990000000001	47.101500000000001	58.463290000000001	58.433993999999998	Кооперативная	0103000020E61000000100000005000000999EB0C40386474082548A1D8D374D40999EB0C4038647402C4833164D3B4D40A245B6F3FD8C47402C4833164D3B4D40A245B6F3FD8C474082548A1D8D374D40999EB0C40386474082548A1D8D374D40
49593	29421	46.666696999999999	46.699612000000002	58.528322000000003	58.512906999999998	Запрудная	0103000020E61000000100000005000000B0ABC95356554740DA71C3EFA6414D40B0ABC95356554740F0E0270EA0434D40D0F1D1E28C594740F0E0270EA0434D40D0F1D1E28C594740DA71C3EFA6414D40B0ABC95356554740DA71C3EFA6414D40
49416	29296	47.309469	47.329627000000002	58.388345999999999	58.377693000000001	 Центральная	0103000020E610000001000000050000001B1021AE9CA74740CD76853E58304D401B1021AE9CA7474026C45C52B5314D407670B03731AA474026C45C52B5314D407670B03731AA4740CD76853E58304D401B1021AE9CA74740CD76853E58304D40
48964	55969	47.076113999999997	47.137369999999997	58.326366999999998	58.291437000000002	Фрунзе	0103000020E610000001000000050000004562821ABE89474014ECBFCE4D254D404562821ABE8947402FBFD364C6294D40CBB91457959147402FBFD364C6294D40CBB914579591474014ECBFCE4D254D404562821ABE89474014ECBFCE4D254D40
48821	55969	47.076113999999997	47.137369999999997	58.326366999999998	58.291437000000002	Площадь Ленина	0103000020E610000001000000050000004562821ABE89474014ECBFCE4D254D404562821ABE8947402FBFD364C6294D40CBB91457959147402FBFD364C6294D40CBB914579591474014ECBFCE4D254D404562821ABE89474014ECBFCE4D254D40
48749	55969	47.076113999999997	47.137369999999997	58.326366999999998	58.291437000000002	Гусарова	0103000020E610000001000000050000004562821ABE89474014ECBFCE4D254D404562821ABE8947402FBFD364C6294D40CBB91457959147402FBFD364C6294D40CBB914579591474014ECBFCE4D254D404562821ABE89474014ECBFCE4D254D40
49155	29404	46.662700000000001	46.702513000000003	58.340721000000002	58.322941	Школьная	0103000020E610000001000000050000009487855AD3544740CEC4742156294D409487855AD3544740BC07E8BE9C2B4D40E7012CF2EB594740BC07E8BE9C2B4D40E7012CF2EB594740CEC4742156294D409487855AD3544740CEC4742156294D40
49309	29564	47.069664000000003	47.104725000000002	58.152422999999999	58.130495000000003	Свободы	0103000020E61000000100000005000000B2DAFCBFEA88474051A5660FB4104D40B2DAFCBFEA8847404014CC9882134D406C09F9A0678D47404014CC9882134D406C09F9A0678D474051A5660FB4104D40B2DAFCBFEA88474051A5660FB4104D40
49331	29629	47.172637999999999	47.214202999999998	58.249600999999998	58.236541000000003	Школьная	0103000020E61000000100000005000000FF05820019964740E294B9F9461E4D40FF058200199647404206F2ECF21F4D4040DAFF006B9B47404206F2ECF21F4D4040DAFF006B9B4740E294B9F9461E4D40FF05820019964740E294B9F9461E4D40
49312	29776	46.881027000000003	46.914434999999997	58.551558	58.533597999999998	Советская	0103000020E610000001000000050000004EF2237EC5704740029B73F04C444D404EF2237EC570474070ECD97399464D40ACA8C1340C75474070ECD97399464D40ACA8C1340C754740029B73F04C444D404EF2237EC5704740029B73F04C444D40
49163	55998	51.671669999999999	51.686861	57.890228999999998	57.882491999999999	Советская	0103000020E6100000010000000500000027DA5548F9D54940A67D737FF5F04C4027DA5548F9D54940B3791C06F3F14C40EDF2AD0FEBD74940B3791C06F3F14C40EDF2AD0FEBD74940A67D737FF5F04C4027DA5548F9D54940A67D737FF5F04C40
49591	28857	51.362217999999999	51.397846000000001	57.988686999999999	57.959124000000003	Коммуны	0103000020E61000000100000005000000E202D0285DAE494084674293C4FA4C40E202D0285DAE49407C7DAD4B8DFE4C40166C239EECB249407C7DAD4B8DFE4C40166C239EECB2494084674293C4FA4C40E202D0285DAE494084674293C4FA4C40
48813	28963	51.554422000000002	51.654494	58.376885999999999	58.330941000000003	Первомайская	0103000020E610000001000000050000006A17D34CF7C64940E9F351465C2A4D406A17D34CF7C64940FE28EACC3D304D40D0B69A75C6D34940FE28EACC3D304D40D0B69A75C6D34940E9F351465C2A4D406A17D34CF7C64940E9F351465C2A4D40
48743	28963	51.554422000000002	51.654494	58.376885999999999	58.330941000000003	Коммуны	0103000020E610000001000000050000006A17D34CF7C64940E9F351465C2A4D406A17D34CF7C64940FE28EACC3D304D40D0B69A75C6D34940FE28EACC3D304D40D0B69A75C6D34940E9F351465C2A4D406A17D34CF7C64940E9F351465C2A4D40
48941	28963	51.554422000000002	51.654494	58.376885999999999	58.330941000000003	Воробьева	0103000020E610000001000000050000006A17D34CF7C64940E9F351465C2A4D406A17D34CF7C64940FE28EACC3D304D40D0B69A75C6D34940FE28EACC3D304D40D0B69A75C6D34940E9F351465C2A4D406A17D34CF7C64940E9F351465C2A4D40
49156	28963	51.554422000000002	51.654494	58.376885999999999	58.330941000000003	Береговая	0103000020E610000001000000050000006A17D34CF7C64940E9F351465C2A4D406A17D34CF7C64940FE28EACC3D304D40D0B69A75C6D34940FE28EACC3D304D40D0B69A75C6D34940E9F351465C2A4D406A17D34CF7C64940E9F351465C2A4D40
49218	28800	51.480238999999997	51.533850999999999	58.028691999999999	58.001170000000002	Ленина	0103000020E61000000100000005000000C2A1B77878BD494040DEAB5626004D40C2A1B77878BD494013D4F02DAC034D40ECF7C43A55C4494013D4F02DAC034D40ECF7C43A55C4494040DEAB5626004D40C2A1B77878BD494040DEAB5626004D40
49549	28774	51.570098000000002	51.595537999999998	58.212190999999997	58.194445999999999	Свердлова	0103000020E61000000100000005000000ECC1A4F8F8C84940446B459BE3184D40ECC1A4F8F8C84940B5C01E13291B4D403BC3D4963ACC4940B5C01E13291B4D403BC3D4963ACC4940446B459BE3184D40ECC1A4F8F8C84940446B459BE3184D40
49584	28701	51.197215999999997	51.215145999999997	57.920614	57.902656	Садовая	0103000020E61000000100000005000000BC1FB75F3E994940E3C4573B8AF34C40BC1FB75F3E994940B01EF7ADD6F54C40BFEE74E7899B4940B01EF7ADD6F54C40BFEE74E7899B4940E3C4573B8AF34C40BC1FB75F3E994940E3C4573B8AF34C40
49587	28676	51.388331999999998	51.417177000000002	58.137836	58.123818	Советская	0103000020E61000000100000005000000C1FEEBDCB4B14940FC53AA44D90F4D40C1FEEBDCB4B14940111B2C9CA4114D405BD2510E66B54940111B2C9CA4114D405BD2510E66B54940FC53AA44D90F4D40C1FEEBDCB4B14940FC53AA44D90F4D40
49313	28612	51.498744000000002	51.522415000000002	58.147745	58.135854999999999	Труда	0103000020E61000000100000005000000C289E8D7D6BF4940C1FF56B263114D40C289E8D7D6BF4940E292E34EE9124D404DF8A57EDEC24940E292E34EE9124D404DF8A57EDEC24940C1FF56B263114D40C289E8D7D6BF4940C1FF56B263114D40
49303	28586	51.518138999999998	51.538459000000003	57.934162000000001	57.921053999999998	Труда	0103000020E610000001000000050000001DE4F56052C24940CCECF318E5F54C401DE4F56052C249403E95D39E92F74C40529E7939ECC449403E95D39E92F74C40529E7939ECC44940CCECF318E5F54C401DE4F56052C24940CCECF318E5F54C40
49225	28395	51.509874000000003	51.547288999999999	58.214717999999998	58.194251000000001	Садовая	0103000020E61000000100000005000000558A1D8D43C149408F1B7E37DD184D40558A1D8D43C1494067EE21E17B1B4D40F33AE2900DC6494067EE21E17B1B4D40F33AE2900DC649408F1B7E37DD184D40558A1D8D43C149408F1B7E37DD184D40
49544	28526	51.741092000000002	51.781416999999998	58.409534999999998	58.391308000000002	Юбилейная	0103000020E61000000100000005000000E3A9471ADCDE4940E3546B6116324D40E3A9471ADCDE49409FC893A46B344D40EBC4E57805E449409FC893A46B344D40EBC4E57805E44940E3546B6116324D40E3A9471ADCDE4940E3546B6116324D40
49649	28526	51.741092000000002	51.781416999999998	58.409534999999998	58.391308000000002	 Школьная	0103000020E61000000100000005000000E3A9471ADCDE4940E3546B6116324D40E3A9471ADCDE49409FC893A46B344D40EBC4E57805E449409FC893A46B344D40EBC4E57805E44940E3546B6116324D40E3A9471ADCDE4940E3546B6116324D40
49579	28496	51.558616999999998	51.593544000000001	58.470393000000001	58.446857999999999	Школьная	0103000020E61000000100000005000000ACFE08C380C749405DFA97A432394D40ACFE08C380C7494038A27BD6353C4D40575EF23FF9CB494038A27BD6353C4D40575EF23FF9CB49405DFA97A432394D40ACFE08C380C749405DFA97A432394D40
49578	28442	51.542608999999999	51.565111999999999	58.278455000000001	58.264524999999999	Баранниковская	0103000020E61000000100000005000000F4C1323674C54940B9FC87F4DB214D40F4C1323674C549402F34D769A4234D40E0490B9755C849402F34D769A4234D40E0490B9755C84940B9FC87F4DB214D40F4C1323674C54940B9FC87F4DB214D40
49213	28341	51.490443999999997	51.511986	58.406134999999999	58.389436000000003	Школьная	0103000020E610000001000000050000007C4276DEC6BE49404AF1F109D9314D407C4276DEC6BE494067614F3BFC334D404301DBC188C1494067614F3BFC334D404301DBC188C149404AF1F109D9314D407C4276DEC6BE49404AF1F109D9314D40
49575	28300	51.616126999999999	51.654179999999997	58.068519000000002	58.040280000000003	Юбилейная	0103000020E610000001000000050000005F97E13FDDCE4940695721E527054D405F97E13FDDCE4940CB13083BC5084D4040D9942BBCD34940CB13083BC5084D4040D9942BBCD34940695721E527054D405F97E13FDDCE4940695721E527054D40
49114	28246	51.311131000000003	51.347082	58.034863000000001	58.015250999999999	Пионерская	0103000020E61000000100000005000000CAE2FE23D3A749409B1DA9BEF3014D40CAE2FE23D3A74940946B0A6476044D40E083D72E6DAC4940946B0A6476044D40E083D72E6DAC49409B1DA9BEF3014D40CAE2FE23D3A749409B1DA9BEF3014D40
49415	28222	51.658518999999998	51.699356000000002	57.989699000000002	57.973174	Школьная	0103000020E61000000100000005000000B665C0594AD44940A4A833F790FC4C40B665C0594AD4494024F1F274AEFE4C407521567F84D9494024F1F274AEFE4C407521567F84D94940A4A833F790FC4C40B665C0594AD44940A4A833F790FC4C40
49164	1836	50.32161	50.372292999999999	56.985300000000002	56.950355000000002	пер.Школьный	0103000020E61000000100000005000000850838842A294940884B8E3BA5794C40850838842A294940D95F764F1E7E4C40CEC3094CA72F4940D95F764F1E7E4C40CEC3094CA72F4940884B8E3BA5794C40850838842A294940884B8E3BA5794C40
49299	1836	50.32161	50.372292999999999	56.985300000000002	56.950355000000002	Пролетарская	0103000020E61000000100000005000000850838842A294940884B8E3BA5794C40850838842A294940D95F764F1E7E4C40CEC3094CA72F4940D95F764F1E7E4C40CEC3094CA72F4940884B8E3BA5794C40850838842A294940884B8E3BA5794C40
49543	27997	50.048639000000001	50.074807	57.050367000000001	57.034216999999998	Кирова	0103000020E61000000100000005000000B32781CD39064940CEFBFF3861844C40B32781CD3906494019E6046D72864C40854199469309494019E6046D72864C408541994693094940CEFBFF3861844C40B32781CD39064940CEFBFF3861844C40
49301	27802	50.080762999999997	50.106274999999997	57.188046	57.172840000000001	Кирова	0103000020E6100000010000000500000009DD2571560A494067B8019F1F964C4009DD2571560A494062122EE411984C40F2B0506B9A0D494062122EE411984C40F2B0506B9A0D494067B8019F1F964C4009DD2571560A494067B8019F1F964C40
49391	25893	49.983474999999999	50.016272999999998	57.134047000000002	57.085495999999999	Новокузнечная	0103000020E6100000010000000500000080B74082E2FD48402BF86D88F18A4C4080B74082E2FD48403F90BC7328914C406667D13B150249403F90BC7328914C406667D13B150249402BF86D88F18A4C4080B74082E2FD48402BF86D88F18A4C40
48883	25893	49.983474999999999	50.016272999999998	57.134047000000002	57.085495999999999	Красная	0103000020E6100000010000000500000080B74082E2FD48402BF86D88F18A4C4080B74082E2FD48403F90BC7328914C406667D13B150249403F90BC7328914C406667D13B150249402BF86D88F18A4C4080B74082E2FD48402BF86D88F18A4C40
48882	25893	49.983474999999999	50.016272999999998	57.134047000000002	57.085495999999999	Кировский тракт	0103000020E6100000010000000500000080B74082E2FD48402BF86D88F18A4C4080B74082E2FD48403F90BC7328914C406667D13B150249403F90BC7328914C406667D13B150249402BF86D88F18A4C4080B74082E2FD48402BF86D88F18A4C40
48739	25893	49.983474999999999	50.016272999999998	57.134047000000002	57.085495999999999	Кирова	0103000020E6100000010000000500000080B74082E2FD48402BF86D88F18A4C4080B74082E2FD48403F90BC7328914C406667D13B150249403F90BC7328914C406667D13B150249402BF86D88F18A4C4080B74082E2FD48402BF86D88F18A4C40
48741	25893	49.983474999999999	50.016272999999998	57.134047000000002	57.085495999999999	Дрелевского	0103000020E6100000010000000500000080B74082E2FD48402BF86D88F18A4C4080B74082E2FD48403F90BC7328914C406667D13B150249403F90BC7328914C406667D13B150249402BF86D88F18A4C4080B74082E2FD48402BF86D88F18A4C40
48740	25893	49.983474999999999	50.016272999999998	57.134047000000002	57.085495999999999	Гоголя	0103000020E6100000010000000500000080B74082E2FD48402BF86D88F18A4C4080B74082E2FD48403F90BC7328914C406667D13B150249403F90BC7328914C406667D13B150249402BF86D88F18A4C4080B74082E2FD48402BF86D88F18A4C40
49569	26903	50.405009999999997	50.445532999999998	56.95917	56.943973	Садовая	0103000020E61000000100000005000000C746205ED73349404CA7751BD4784C40C746205ED7334940F4A62215C67A4C40F624B03907394940F4A62215C67A4C40F624B039073949404CA7751BD4784C40C746205ED73349404CA7751BD4784C40
49571	27787	49.97813	49.992942999999997	56.922657999999998	56.912256999999997	Комсомольская	0103000020E61000000100000005000000459E245D33FD484006465ED6C4744C40459E245D33FD484046B247A819764C4064E597C118FF484046B247A819764C4064E597C118FF484006465ED6C4744C40459E245D33FD484006465ED6C4744C40
49304	27884	49.979298	49.992755000000002	57.136611000000002	57.122371000000001	Советская	0103000020E61000000100000005000000E48409A359FD48404A7D59DAA98F4C40E48409A359FD48400EA320787C914C4062F8889812FF48400EA320787C914C4062F8889812FF48404A7D59DAA98F4C40E48409A359FD48404A7D59DAA98F4C40
49539	26590	50.312950000000001	50.352099000000003	56.847113999999998	56.834603999999999	Молодежная	0103000020E6100000010000000500000040A4DFBE0E2849402E8ECA4DD46A4C4040A4DFBE0E284940EBFD463B6E6C4C4027FA7C94112D4940EBFD463B6E6C4C4027FA7C94112D49402E8ECA4DD46A4C4040A4DFBE0E2849402E8ECA4DD46A4C40
49535	26430	49.940401000000001	49.960245	57.095908000000001	57.085887	Садовая	0103000020E6100000010000000500000017105A0F5FF8484066136058FE8A4C4017105A0F5FF848405FB69DB6468C4C40E292E34EE9FA48405FB69DB6468C4C40E292E34EE9FA484066136058FE8A4C4017105A0F5FF8484066136058FE8A4C40
49541	6669	50.008502	50.027250000000002	57.028995999999999	57.019913000000003	Лесная	0103000020E61000000100000005000000ADF9F19716014940F4E159828C824C40ADF9F197160149407FDB1324B6834C40736891ED7C0349407FDB1324B6834C40736891ED7C034940F4E159828C824C40ADF9F19716014940F4E159828C824C40
49306	27688	50.105511	50.130564999999997	56.966633999999999	56.950733	Юбилейная	0103000020E61000000100000005000000232F6B62810D49402E1D739EB1794C40232F6B62810D4940D099B4A9BA7B4C4049809A5AB6104940D099B4A9BA7B4C4049809A5AB61049402E1D739EB1794C40232F6B62810D49402E1D739EB1794C40
49302	27543	50.079424000000003	50.098863999999999	57.129503999999997	57.117978000000001	 8 марта	0103000020E610000001000000050000003E42CD902A0A4940E1D231E7198F4C403E42CD902A0A4940C0594A9693904C4039605793A70C4940C0594A9693904C4039605793A70C4940E1D231E7198F4C403E42CD902A0A4940E1D231E7198F4C40
48943	27609	50.199232000000002	50.246071000000001	57.069000000000003	57.048335000000002	Пристанская	0103000020E610000001000000050000008928266F8019494047205ED72F864C408928266F8019494046B6F3FDD4884C403CBF28417F1F494046B6F3FDD4884C403CBF28417F1F494047205ED72F864C408928266F8019494047205ED72F864C40
49403	26488	49.892898000000002	49.965446	57.037058000000002	57.023347000000001	Трудовая	0103000020E61000000100000005000000F8544E7B4AF24840D8BAD408FD824C40F8544E7B4AF2484010070951BE844C40EA060ABC93FB484010070951BE844C40EA060ABC93FB4840D8BAD408FD824C40F8544E7B4AF24840D8BAD408FD824C40
49411	27437	49.970827	49.987040999999998	57.285299999999999	57.277209999999997	Труда	0103000020E610000001000000050000007289230F44FC4840E40F069E7BA34C407289230F44FC48403FC6DCB584A44C40D367075C57FE48403FC6DCB584A44C40D367075C57FE4840E40F069E7BA34C407289230F44FC4840E40F069E7BA34C40
49412	27318	49.896850999999998	49.927878	57.129592000000002	57.121198	Молодежная	0103000020E6100000010000000500000044317903CCF24840992B836A838F4C4044317903CCF2484060E97C7896904C40C556D0B4C4F6484060E97C7896904C40C556D0B4C4F64840992B836A838F4C4044317903CCF24840992B836A838F4C40
49572	27337	50.444194000000003	50.472400999999998	57.001759999999997	56.975876999999997	Советская	0103000020E610000001000000050000002B8A5759DB38494094F59B89E97C4C402B8A5759DB3849407138F3AB39804C4081CCCEA2773C49407138F3AB39804C4081CCCEA2773C494094F59B89E97C4C402B8A5759DB38494094F59B89E97C4C40
49255	27161	49.963272000000003	49.983583000000003	57.342078999999998	57.318869999999997	Кирова	0103000020E610000001000000050000008693347F4CFB484077D66EBBD0A84C408693347F4CFB4840FED2A23EC9AB4C4067F3380CE6FD4840FED2A23EC9AB4C4067F3380CE6FD484077D66EBBD0A84C408693347F4CFB484077D66EBBD0A84C40
49542	27254	49.960980999999997	49.976880999999999	57.367418999999998	57.360968	Советская	0103000020E61000000100000005000000E789E76C01FB484086730D3334AE4C40E789E76C01FB4840EA76F69507AF4C40B98AC56F0AFD4840EA76F69507AF4C40B98AC56F0AFD484086730D3334AE4C40E789E76C01FB484086730D3334AE4C40
48956	55988	50.018078000000003	50.044237000000003	56.87621	56.864384000000001	 Железнодорожная	0103000020E610000001000000050000007863416150024940C4978922A46E4C407863416150024940CE3637A627704C40F722DA8EA9054940CE3637A627704C40F722DA8EA9054940C4978922A46E4C407863416150024940C4978922A46E4C40
49555	27138	49.765875999999999	49.806786000000002	57.010871999999999	56.993107000000002	Школьная	0103000020E6100000010000000500000049658A3908E24840DF3653211E7F4C4049658A3908E248409738F24064814C40726F7EC344E748409738F24064814C40726F7EC344E74840DF3653211E7F4C4049658A3908E24840DF3653211E7F4C40
49540	6645	49.876036999999997	49.891227000000001	56.933979999999998	56.927869999999999	Молодёжная	0103000020E61000000100000005000000008BFCFA21F048404278B471C4764C40008BFCFA21F048401D8F19A88C774C40F627F1B913F248401D8F19A88C774C40F627F1B913F248404278B471C4764C40008BFCFA21F048404278B471C4764C40
49567	26298	49.859462999999998	49.879036999999997	57.227566000000003	57.213098000000002	Центральная	0103000020E610000001000000050000009F8F32E202EE4840E86B96CB469B4C409F8F32E202EE48403DD7F7E1209D4C40AA7CCF4884F048403DD7F7E1209D4C40AA7CCF4884F04840E86B96CB469B4C409F8F32E202EE4840E86B96CB469B4C40
49537	26607	50.388508000000002	50.409151000000001	56.799813	56.789786999999997	Центральная	0103000020E61000000100000005000000001E51A1BA31494029E78BBD17654C40001E51A1BA31494034F5BA4560664C4017105A0F5F34494034F5BA4560664C4017105A0F5F34494029E78BBD17654C40001E51A1BA31494029E78BBD17654C40
49687	56029	50.275212000000003	50.303894999999997	57.007843000000001	56.99494	Школьная	0103000020E61000000100000005000000BFBB95253A234940BABDA4315A7F4C40BFBB95253A2349405340DAFF00814C407E350708E62649405340DAFF00814C407E350708E6264940BABDA4315A7F4C40BFBB95253A234940BABDA4315A7F4C40
49691	56032	49.947650000000003	49.988639999999997	56.963842	56.941149000000003	Школьная	0103000020E61000000100000005000000F7065F984CF94840E1D4079277784C40F7065F984CF948407041B62C5F7B4C403BC269C18BFE48407041B62C5F7B4C403BC269C18BFE4840E1D4079277784C40F7065F984CF94840E1D4079277784C40
49653	56022	49.573250000000002	49.613199000000002	57.118949999999998	57.102967999999997	Кооперативная	0103000020E610000001000000050000004C37894160C948406B44300E2E8D4C404C37894160C94840FAEDEBC0398F4C404F78094E7DCE4840FAEDEBC0398F4C404F78094E7DCE48406B44300E2E8D4C404C37894160C948406B44300E2E8D4C40
49212	26792	50.183692000000001	50.219085	56.832959000000002	56.817473999999997	Октябрьская,	0103000020E61000000100000005000000B7442E388317494047AAEFFCA2684C40B7442E388317494056F487669E6A4C40A7052FFA0A1C494056F487669E6A4C40A7052FFA0A1C494047AAEFFCA2684C40B7442E388317494047AAEFFCA2684C40
49663	56025	50.209032999999998	50.256059999999998	57.037968999999997	57.013649999999998	Новая	0103000020E610000001000000050000007364E597C11A494092CB7F48BF814C407364E597C11A494083A10E2BDC844C4029E8F692C620494083A10E2BDC844C4029E8F692C620494092CB7F48BF814C407364E597C11A494092CB7F48BF814C40
49298	26234	49.844352999999998	49.858896999999999	57.197350999999998	57.175727999999999	Полевая	0103000020E61000000100000005000000C6A354C213EC4840E97E4E417E964C40C6A354C213EC48409C6A2DCC42994C40F6D03E56F0ED48409C6A2DCC42994C40F6D03E56F0ED4840E97E4E417E964C40C6A354C213EC4840E97E4E417E964C40
49538	26778	50.113605	50.148665999999999	56.895220999999999	56.881929999999997	Советская	0103000020E61000000100000005000000BFD4CF9B8A0E49403EAE0D15E3704C40BFD4CF9B8A0E4940A1D80A9A96724C407903CC7C07134940A1D80A9A96724C407903CC7C071349403EAE0D15E3704C40BFD4CF9B8A0E49403EAE0D15E3704C40
49582	27963	50.065581000000002	50.077933000000002	57.170887999999998	57.163908999999997	Трактовая	0103000020E61000000100000005000000971E4DF564084940914259F8FA944C40971E4DF564084940B1A371A8DF954C40BC2363B5F9094940B1A371A8DF954C40BC2363B5F9094940914259F8FA944C40971E4DF564084940914259F8FA944C40
49158	26725	50.509627000000002	50.542461000000003	56.907814000000002	56.884709000000001	Лесная	0103000020E610000001000000050000004D1421753B4149400ABDFE243E714C404D1421753B414940EC6CC83F33744C40802DAF5C6F454940EC6CC83F33744C40802DAF5C6F4549400ABDFE243E714C404D1421753B4149400ABDFE243E714C40
49409	26982	49.894855999999997	49.923763999999998	56.904299999999999	56.896518999999998	Зеленая	0103000020E610000001000000050000008F5033A48AF248400E9F7422C1724C408F5033A48AF24840EBE2361AC0734C406F9C14E63DF64840EBE2361AC0734C406F9C14E63DF648400E9F7422C1724C408F5033A48AF248400E9F7422C1724C40
49410	27219	49.882702000000002	49.918858999999998	57.267034000000002	57.257576	Трудовая	0103000020E61000000100000005000000910E0F61FCF04840041E1840F8A04C40910E0F61FCF04840C5758C2B2EA24C405051F52B9DF54840C5758C2B2EA24C405051F52B9DF54840041E1840F8A04C40910E0F61FCF04840041E1840F8A04C40
49440	28129	50.318376000000001	50.328626	56.956009000000002	56.945945999999999	Майская	0103000020E6100000010000000500000068EA758BC028494019E42EC214794C4068EA758BC028494041D7BE805E7A4C40C24EB16A102A494041D7BE805E7A4C40C24EB16A102A494019E42EC214794C4068EA758BC028494019E42EC214794C40
48742	26697	49.696238999999998	49.741514000000002	57.098650999999997	57.071334	Кирова	0103000020E6100000010000000500000091990B5C1ED94840E38BF67821894C4091990B5C1ED94840DD5B9198A08C4C4059C345EEE9DE4840DD5B9198A08C4C4059C345EEE9DE4840E38BF67821894C4091990B5C1ED94840E38BF67821894C40
49104	26516	50.386352000000002	50.415520000000001	56.869402000000001	56.851731000000001	Трудовая	0103000020E61000000100000005000000425F7AFB73314940A4FE7A85056D4C40425F7AFB73314940DB899290486F4C40BE6A65C22F354940DB899290486F4C40BE6A65C22F354940A4FE7A85056D4C40425F7AFB73314940A4FE7A85056D4C40
49568	26408	50.015903999999999	50.031176000000002	57.081837999999998	57.055574999999997	Школьная	0103000020E6100000010000000500000013F06B2409024940D3BCE3141D874C4013F06B2409024940F7C8E6AA798A4C40C6353E93FD034940F7C8E6AA798A4C40C6353E93FD034940D3BCE3141D874C4013F06B2409024940D3BCE3141D874C40
49107	26326	49.505139999999997	49.549607000000002	57.217913000000003	57.184874999999998	Школьная	0103000020E6100000010000000500000062F3716DA8C048408B6CE7FBA9974C4062F3716DA8C04840C72FBC92E49B4C408B53AD8559C64840C72FBC92E49B4C408B53AD8559C648408B6CE7FBA9974C4062F3716DA8C048408B6CE7FBA9974C40
49547	26964	49.937624999999997	49.959598	56.993827000000003	56.981096000000001	Почтовая	0103000020E61000000100000005000000BC74931804F84840431EC18D947D4C40BC74931804F84840DF701FB9357F4C404CA7751BD4FA4840DF701FB9357F4C404CA7751BD4FA4840431EC18D947D4C40BC74931804F84840431EC18D947D4C40
49414	27904	50.018949999999997	50.059913000000002	57.161971999999999	57.147004000000003	Центральная	0103000020E610000001000000050000002D211FF46C024940CB30EE06D1924C402D211FF46C024940116F9D7FBB944C4079CDAB3AAB074940116F9D7FBB944C4079CDAB3AAB074940CB30EE06D1924C402D211FF46C024940CB30EE06D1924C40
49106	26205	50.530828	50.540906999999997	57.073403999999996	57.066401999999997	Молодежная	0103000020E610000001000000050000008AE6012CF2434940CA3159DC7F884C408AE6012CF2434940A2B2614D65894C40B796C9703C454940A2B2614D65894C40B796C9703C454940CA3159DC7F884C408AE6012CF2434940CA3159DC7F884C40
49413	27724	50.175193999999998	50.209150000000001	56.938876	56.926572999999998	Садовая	0103000020E610000001000000050000004B3ACAC16C164940A52DAEF199764C404B3ACAC16C164940E97FB9162D784C40ADFA5C6DC51A4940E97FB9162D784C40ADFA5C6DC51A4940A52DAEF199764C404B3ACAC16C164940A52DAEF199764C40
49308	27498	49.650900999999998	49.665174999999998	57.234893	57.221597000000003	Школьная	0103000020E6100000010000000500000083F755B950D3484024F25D4A5D9C4C4083F755B950D3484098874CF9109E4C40F38E537424D5484098874CF9109E4C40F38E537424D5484024F25D4A5D9C4C4083F755B950D3484024F25D4A5D9C4C40
49563	25877	51.183795000000003	51.196182999999998	57.529361000000002	57.519497000000001	Профсоюзная	0103000020E610000001000000050000008C1535988697494060AFB0E07EC24C408C153598869749409163EB19C2C34C40FD8348861C9949409163EB19C2C34C40FD8348861C99494060AFB0E07EC24C408C1535988697494060AFB0E07EC24C40
49564	25805	51.749077999999997	51.765543999999998	57.704219000000002	57.694358999999999	Советская	0103000020E610000001000000050000009813B4C9E1DF4940755776C1E0D84C409813B4C9E1DF4940651C23D923DA4C4013D38558FDE14940651C23D923DA4C4013D38558FDE14940755776C1E0D84C409813B4C9E1DF4940755776C1E0D84C40
48738	25612	51.469334000000003	51.517699	57.768033000000003	57.736812999999998	Ленина	0103000020E610000001000000050000005073F22213BC494042226DE34FDE4C405073F22213BC4940D89FC4E74EE24C400116F9F543C24940D89FC4E74EE24C400116F9F543C2494042226DE34FDE4C405073F22213BC494042226DE34FDE4C40
48940	25612	51.469334000000003	51.517699	57.768033000000003	57.736812999999998	Колхозная	0103000020E610000001000000050000005073F22213BC494042226DE34FDE4C405073F22213BC4940D89FC4E74EE24C400116F9F543C24940D89FC4E74EE24C400116F9F543C2494042226DE34FDE4C405073F22213BC494042226DE34FDE4C40
48737	25612	51.469334000000003	51.517699	57.768033000000003	57.736812999999998	40 лет Победы	0103000020E610000001000000050000005073F22213BC494042226DE34FDE4C405073F22213BC4940D89FC4E74EE24C400116F9F543C24940D89FC4E74EE24C400116F9F543C2494042226DE34FDE4C405073F22213BC494042226DE34FDE4C40
49566	25580	51.576314000000004	51.600864999999999	57.831879000000001	57.817408999999998	Школьный	0103000020E610000001000000050000000D1D3BA8C4C94940603AADDBA0E84C400D1D3BA8C4C94940569DD5027BEA4C40D027F224E9CC4940569DD5027BEA4C40D027F224E9CC4940603AADDBA0E84C400D1D3BA8C4C94940603AADDBA0E84C40
49293	25509	51.667456999999999	51.705742999999998	57.803638999999997	57.790030999999999	Советская	0103000020E610000001000000050000003E3E213B6FD54940C0E95DBC1FE54C403E3E213B6FD5494023658BA4DDE64C40C23060C955DA494023658BA4DDE64C40C23060C955DA4940C0E95DBC1FE54C403E3E213B6FD54940C0E95DBC1FE54C40
49533	25380	51.407494	51.544091000000002	57.649509999999999	57.631219000000002	Кооперативная	0103000020E610000001000000050000007AA86DC328B4494092CEC0C8CBD04C407AA86DC328B449406536C82423D34C4023861DC6A4C549406536C82423D34C4023861DC6A4C5494092CEC0C8CBD04C407AA86DC328B4494092CEC0C8CBD04C40
49532	25284	51.262802000000001	51.288331999999997	57.694243999999998	57.679198999999997	 Центральная	0103000020E6100000010000000500000065A9F57EA3A14940EA3C2AFEEFD64C4065A9F57EA3A14940DCB8C5FCDCD84C40F4311F10E8A44940DCB8C5FCDCD84C40F4311F10E8A44940EA3C2AFEEFD64C4065A9F57EA3A14940EA3C2AFEEFD64C40
49419	25165	51.241404000000003	51.269674000000002	57.616957999999997	57.605333999999999	Новая	0103000020E61000000100000005000000D28F8653E69E49401494A2957BCD4C40D28F8653E69E4940B680D07AF8CE4C406F4A79AD84A24940B680D07AF8CE4C406F4A79AD84A249401494A2957BCD4C40D28F8653E69E49401494A2957BCD4C40
49290	25146	51.588701999999998	51.614843	57.677875999999998	57.665174	 Административная	0103000020E610000001000000050000007E8B4E965ACB49402313F06B24D54C407E8B4E965ACB4940245F09A4C4D64C405796E82CB3CE4940245F09A4C4D64C405796E82CB3CE49402313F06B24D54C407E8B4E965ACB49402313F06B24D54C40
49389	25085	51.194915999999999	51.222827000000002	57.829492000000002	57.816954000000003	Центральная	0103000020E61000000100000005000000CBBBEA01F39849400F2BDCF291E84C40CBBBEA01F398494096253ACB2CEA4C4039D55A98859C494096253ACB2CEA4C4039D55A98859C49400F2BDCF291E84C40CBBBEA01F39849400F2BDCF291E84C40
49286	25068	51.847605000000001	51.877105999999998	57.799970000000002	57.788241999999997	Центральная	0103000020E610000001000000050000008A7615527EEC4940B4AA251DE5E44C408A7615527EEC4940FCE3BD6A65E64C400C90680245F04940FCE3BD6A65E64C400C90680245F04940B4AA251DE5E44C408A7615527EEC4940B4AA251DE5E44C40
49394	25008	51.628667999999998	51.649706000000002	57.603675000000003	57.591631999999997	Молодёжная	0103000020E6100000010000000500000057056A3178D049402FA2ED98BACB4C4057056A3178D04940D734EF3845CD4C40EB01F39029D34940D734EF3845CD4C40EB01F39029D349402FA2ED98BACB4C4057056A3178D049402FA2ED98BACB4C40
49390	24964	51.041573999999997	51.079348000000003	57.732464	57.711499000000003	Коммунальная	0103000020E61000000100000005000000942EFD4B528549408011346612DB4C40942EFD4B52854940A9BF5E61C1DD4C4063804413288A4940A9BF5E61C1DD4C4063804413288A49408011346612DB4C40942EFD4B528549408011346612DB4C40
49560	24938	51.237326000000003	51.286633999999999	57.829861000000001	57.813482999999998	Советская	0103000020E61000000100000005000000C93EC8B2609E49400D6D003620E84C40C93EC8B2609E4940E99C9FE238EA4C40F9F5436CB0A44940E99C9FE238EA4C40F9F5436CB0A449400D6D003620E84C40C93EC8B2609E49400D6D003620E84C40
49637	24092	47.557322999999997	47.590004	57.480266999999998	57.462131999999997	Центральная	0103000020E6100000010000000500000080272D5C56C74740B037312427BB4C4080272D5C56C747408C2C996379BD4C402D41464085CB47408C2C996379BD4C402D41464085CB4740B037312427BB4C4080272D5C56C74740B037312427BB4C40
48880	3719	47.892825999999999	47.965572000000002	57.671878999999997	57.582644000000002	Фокина	0103000020E610000001000000050000005E82531F48F24740F69A1E1494CA4C405E82531F48F2474041EF8D2100D64C4077F700DD97FB474041EF8D2100D64C4077F700DD97FB4740F69A1E1494CA4C405E82531F48F24740F69A1E1494CA4C40
48735	3719	47.892825999999999	47.965572000000002	57.671878999999997	57.582644000000002	Набережная	0103000020E610000001000000050000005E82531F48F24740F69A1E1494CA4C405E82531F48F2474041EF8D2100D64C4077F700DD97FB474041EF8D2100D64C4077F700DD97FB4740F69A1E1494CA4C405E82531F48F24740F69A1E1494CA4C40
48936	3719	47.892825999999999	47.965572000000002	57.671878999999997	57.582644000000002	 Горького	0103000020E610000001000000050000005E82531F48F24740F69A1E1494CA4C405E82531F48F2474041EF8D2100D64C4077F700DD97FB474041EF8D2100D64C4077F700DD97FB4740F69A1E1494CA4C405E82531F48F24740F69A1E1494CA4C40
49283	24719	47.829709999999999	47.853155999999998	57.500805999999997	57.474435999999997	Центральная	0103000020E610000001000000050000000395F1EF33EA4740C405A051BABC4C400395F1EF33EA4740FED137691AC04C406E313F3734ED4740FED137691AC04C406E313F3734ED4740C405A051BABC4C400395F1EF33EA4740C405A051BABC4C40
49388	24642	48.155493	48.174833999999997	57.577148000000001	57.558376000000003	Центральная	0103000020E61000000100000005000000E3E0D231E7134840876F61DD78C74C40E3E0D231E7134840D57954FCDFC94C404B1DE4F560164840D57954FCDFC94C404B1DE4F560164840876F61DD78C74C40E3E0D231E7134840876F61DD78C74C40
49281	24625	47.946562999999998	47.965184999999998	57.499578	57.481375	Советская	0103000020E61000000100000005000000444DF4F928F94740560E2DB29DBD4C40444DF4F928F947408AE6012CF2BF4C407DCB9C2E8BFB47408AE6012CF2BF4C407DCB9C2E8BFB4740560E2DB29DBD4C40444DF4F928F94740560E2DB29DBD4C40
49559	24550	47.702652999999998	47.745224	57.520865000000001	57.504665000000003	Центральная	0103000020E61000000100000005000000D8B79388F0D94740CA37DBDC98C04C40D8B79388F0D94740C6504EB4ABC24C40DF18028063DF4740C6504EB4ABC24C40DF18028063DF4740CA37DBDC98C04C40D8B79388F0D94740CA37DBDC98C04C40
49558	24495	47.665750000000003	47.698008000000002	57.787680000000002	57.774915999999997	Школьная	0103000020E61000000100000005000000F0A7C64B37D54740D5928E7230E34C40F0A7C64B37D547404DDBBFB2D2E44C40562C7E5358D947404DDBBFB2D2E44C40562C7E5358D94740D5928E7230E34C40F0A7C64B37D54740D5928E7230E34C40
49557	24387	48.077178000000004	48.099178000000002	57.528678999999997	57.510641	Школьная	0103000020E6100000010000000500000040FCFCF7E0094840957F2DAF5CC14C4040FCFCF7E00948407E8AE3C0ABC34C40C93D5DDDB10C48407E8AE3C0ABC34C40C93D5DDDB10C4840957F2DAF5CC14C4040FCFCF7E0094840957F2DAF5CC14C40
49214	23408	50.043069000000003	50.087293000000003	57.845858	57.793729999999996	Советская	0103000020E61000000100000005000000583CF5488305494052EDD3F198E54C40583CF54883054940AD872F1345EC4C40BA15C26A2C0B4940AD872F1345EC4C40BA15C26A2C0B494052EDD3F198E54C40583CF5488305494052EDD3F198E54C40
48811	23408	50.043069000000003	50.087293000000003	57.845858	57.793729999999996	Дружбы	0103000020E61000000100000005000000583CF5488305494052EDD3F198E54C40583CF54883054940AD872F1345EC4C40BA15C26A2C0B4940AD872F1345EC4C40BA15C26A2C0B494052EDD3F198E54C40583CF5488305494052EDD3F198E54C40
49536	52566	49.949151000000001	49.974680999999997	57.786769	57.774656999999998	Школьная	0103000020E610000001000000050000009CFBABC77DF94840094FE8F527E34C409CFBABC77DF94840D940BAD8B4E44C402B84D558C2FC4840D940BAD8B4E44C402B84D558C2FC4840094FE8F527E34C409CFBABC77DF94840094FE8F527E34C40
49528	24014	50.235965	50.256149999999998	57.827983000000003	57.817548000000002	Школьная	0103000020E610000001000000050000001500E319341E49408274B169A5E84C401500E319341E49406E52D158FBE94C40696FF085C92049406E52D158FBE94C40696FF085C92049408274B169A5E84C401500E319341E49408274B169A5E84C40
49596	56015	\N	\N	\N	\N	Механизаторская	\N
49384	52550	50.290878999999997	50.321286999999998	57.890253000000001	57.875582000000001	Советская	0103000020E61000000100000005000000ED0BE8853B254940AF7B2B1213F04C40ED0BE8853B2549403C1570CFF3F14C40A2D0B2EE1F2949403C1570CFF3F14C40A2D0B2EE1F294940AF7B2B1213F04C40ED0BE8853B254940AF7B2B1213F04C40
49556	23679	50.280358999999997	50.309159000000001	57.938630000000003	57.927697000000002	Школьная	0103000020E61000000100000005000000D311C0CDE223494075CC79C6BEF64C40D311C0CDE2234940B285200725F84C40CD21A98592274940B285200725F84C40CD21A9859227494075CC79C6BEF64C40D311C0CDE223494075CC79C6BEF64C40
49383	52536	49.904342999999997	49.933788999999997	57.873845000000003	57.86103	Школьная	0103000020E61000000100000005000000EAAEEC82C1F34840FC6F253B36EE4C40EAAEEC82C1F34840F6622827DAEF4C40A92EE06586F74840F6622827DAEF4C40A92EE06586F74840FC6F253B36EE4C40EAAEEC82C1F34840FC6F253B36EE4C40
49381	23576	50.263641999999997	50.274386	57.814968999999998	57.810822000000002	Космонавтов	0103000020E610000001000000050000000FED6305BF2149404C70EA03C9E74C400FED6305BF2149407D2079E750E84C40793D98141F2349407D2079E750E84C40793D98141F2349404C70EA03C9E74C400FED6305BF2149404C70EA03C9E74C40
49698	56034	49.553891999999998	50.477592999999999	58.043796	57.713999000000001	Школьная	0103000020E610000001000000050000000DC2DCEEE5C648403830B95164DB4C400DC2DCEEE5C648400AD9791B9B054D4036E675C4213D49400AD9791B9B054D4036E675C4213D49403830B95164DB4C400DC2DCEEE5C648403830B95164DB4C40
49275	52555	50.104154999999999	50.122183999999997	57.760697999999998	57.748432999999999	Центральная	0103000020E61000000100000005000000815B77F3540D4940A31F0DA7CCDF4C40815B77F3540D4940F910548D5EE14C40170CAEB9A30F4940F910548D5EE14C40170CAEB9A30F4940A31F0DA7CCDF4C40815B77F3540D4940A31F0DA7CCDF4C40
49278	23525	49.838056000000002	49.862580000000001	57.921235000000003	57.904133000000002	Лопатина	0103000020E61000000100000005000000B91B446B45EB4840001E51A1BAF34C40B91B446B45EB48401D774A07EBF54C4083177D0569EE48401D774A07EBF54C4083177D0569EE4840001E51A1BAF34C40B91B446B45EB4840001E51A1BAF34C40
49531	52572	49.813657999999997	49.832943999999998	57.80782	57.800445000000003	Молодёжная	0103000020E610000001000000050000007B1002F225E84840959F54FB74E64C407B1002F225E84840018750A566E74C4020B3B3E89DEA4840018750A566E74C4020B3B3E89DEA4840959F54FB74E64C407B1002F225E84840959F54FB74E64C40
49157	23480	50.058214999999997	50.095925999999999	57.858218999999998	57.844814	переулок Центральный	0103000020E610000001000000050000007D91D09673074940FA997ADD22EC4C407D91D0967307494025E7C41EDAED4C40056B9C4D470C494025E7C41EDAED4C40056B9C4D470C4940FA997ADD22EC4C407D91D09673074940FA997ADD22EC4C40
49669	56026	48.873175000000003	48.908020999999998	57.142184	57.122356000000003	Молодежная	0103000020E61000000100000005000000A857CA32C46F4840153C855CA98F4C40A857CA32C46F4840DA01D71533924C40658A39083A744840DA01D71533924C40658A39083A744840153C855CA98F4C40A857CA32C46F4840153C855CA98F4C40
49530	23293	49.042921	49.056224999999998	57.414696999999997	57.404108999999998	Ветеранов	0103000020E61000000100000005000000E3A7716F7E8548407782FDD7B9B34C40E3A7716F7E854840E95F92CA14B54C40DA1B7C6132874840E95F92CA14B54C40DA1B7C61328748407782FDD7B9B34C40E3A7716F7E8548407782FDD7B9B34C40
49265	23240	49.132753000000001	49.152138000000001	57.748975999999999	57.738216000000001	Лесная	0103000020E6100000010000000500000013B9E00CFE90484025B1A4DC7DDE4C4013B9E00CFE90484094BE1072DEDF4C404B3D0B427993484094BE1072DEDF4C404B3D0B427993484025B1A4DC7DDE4C4013B9E00CFE90484025B1A4DC7DDE4C40
48879	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Советская	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
48938	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Олега Кошевого	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
49101	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Мира	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
48736	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Ленина	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
48731	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Крупской	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
48750	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Красноармейская	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
48732	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Карла Маркса	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
48881	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	Карла Либкнехта	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
48733	22835	48.935653000000002	49.028826000000002	57.630249999999997	57.568953	 Ленина	0103000020E61000000100000005000000C0B33D7AC377484005FBAF73D3C84C40C0B33D7AC3774840E9263108ACD04C4023A30392B0834840E9263108ACD04C4023A30392B083484005FBAF73D3C84C40C0B33D7AC377484005FBAF73D3C84C40
49590	22782	49.232653999999997	49.263627999999997	57.632313000000003	57.62133	Центральная	0103000020E610000001000000050000004CA4349BC79D48400803CFBD87CF4C404CA4349BC79D4840F7EAE3A1EFD04C40AA27F38FBEA14840F7EAE3A1EFD04C40AA27F38FBEA148400803CFBD87CF4C404CA4349BC79D48400803CFBD87CF4C40
48810	22757	48.920102999999997	48.941060999999998	57.579566	57.563986	Юбилейная	0103000020E61000000100000005000000CAF962EFC575484070B378B130C84C40CAF962EFC5754840D0EFFB372FCA4C404145D5AF74784840D0EFFB372FCA4C404145D5AF7478484070B378B130C84C40CAF962EFC575484070B378B130C84C40
49365	22696	49.288088999999999	49.305472000000002	57.735788999999997	57.717868000000003	Школьная	0103000020E610000001000000050000002EABB019E0A44840276C3F19E3DB4C402EABB019E0A44840D6E07D552EDE4C40FFEBDCB419A74840D6E07D552EDE4C40FFEBDCB419A74840276C3F19E3DB4C402EABB019E0A44840276C3F19E3DB4C40
49675	56028	\N	\N	\N	\N	Фабричная	\N
49262	22612	48.955767000000002	48.982140999999999	57.363604000000002	57.344614999999997	Советская	0103000020E610000001000000050000004BCCB392567A4840035B25581CAC4C404BCCB392567A4840EF586C938AAE4C40C687D9CBB67D4840EF586C938AAE4C40C687D9CBB67D4840035B25581CAC4C404BCCB392567A4840035B25581CAC4C40
49676	22590	49.167471999999997	49.198680000000003	57.443387000000001	57.431519000000002	Кирова	0103000020E61000000100000005000000737FF5B86F954840234DBC033CB74C40737FF5B86F9548405C3CBCE7C0B84C40452FA3586E9948405C3CBCE7C0B84C40452FA3586E994840234DBC033CB74C40737FF5B86F954840234DBC033CB74C40
49527	22520	48.892408000000003	48.929149000000002	57.230513999999999	57.215691	Советская	0103000020E610000001000000050000002A58E36C3A72484051853FC39B9B4C402A58E36C3A72484094A2957B819D4C40390EBC5AEE76484094A2957B819D4C40390EBC5AEE76484051853FC39B9B4C402A58E36C3A72484051853FC39B9B4C40
49525	22490	48.761659000000002	48.784593000000001	57.567118999999998	57.560273000000002	Советская	0103000020E610000001000000050000001FDAC70A7E61484079EA9106B7C74C401FDAC70A7E61484059F8FA5A97C84C40D4D51D8B6D64484059F8FA5A97C84C40D4D51D8B6D64484079EA9106B7C74C401FDAC70A7E61484079EA9106B7C74C40
48937	22420	48.768082	48.817901999999997	57.432279000000001	57.402582000000002	Советская	0103000020E61000000100000005000000B952CF8250624840A9FA95CE87B34C40B952CF8250624840B1DF13EB54B74C409FAA4203B1684840B1DF13EB54B74C409FAA4203B1684840A9FA95CE87B34C40B952CF8250624840A9FA95CE87B34C40
49524	22401	48.904347000000001	48.928952000000002	57.80245	57.788150999999999	Советская	0103000020E610000001000000050000002C9E7AA4C1734840A4A7C821E2E44C402C9E7AA4C17348406D567DAEB6E64C40E3C62DE6E77648406D567DAEB6E64C40E3C62DE6E7764840A4A7C821E2E44C402C9E7AA4C1734840A4A7C821E2E44C40
49210	22365	48.909979	48.941806999999997	57.205522999999999	57.182172999999999	Ленина	0103000020E61000000100000005000000FD851E317A7448406B9BE27151974C40FD851E317A744840B4C9E1934E9A4C406A12BC218D784840B4C9E1934E9A4C406A12BC218D7848406B9BE27151974C40FD851E317A7448406B9BE27151974C40
49522	22234	48.821719999999999	48.852290000000004	57.771085999999997	57.756535	Молодежная	0103000020E610000001000000050000000C3CF71E2E694840C2A38D23D6E04C400C3CF71E2E694840A43330F2B2E24C409B5AB6D6176D4840A43330F2B2E24C409B5AB6D6176D4840C2A38D23D6E04C400C3CF71E2E694840C2A38D23D6E04C40
49656	22164	48.976346999999997	48.996684999999999	57.486362999999997	57.477184000000001	Школьная	0103000020E610000001000000050000001B4641F0F87C48405516855D14BD4C401B4641F0F87C4840027E8D2441BE4C40F6B4C35F937F4840027E8D2441BE4C40F6B4C35F937F48405516855D14BD4C401B4641F0F87C48405516855D14BD4C40
48825	24482	48.923121999999999	48.930407000000002	57.309964999999998	57.306196999999997	Центральная	0103000020E61000000100000005000000EB1B98DC2876484010919A7631A74C40EB1B98DC28764840CBF3E0EEACA74C40187C9A9317774840CBF3E0EEACA74C40187C9A931777484010919A7631A74C40EB1B98DC2876484010919A7631A74C40
49105	22142	49.001283999999998	49.035150999999999	57.601688000000003	57.585341	Красная	0103000020E610000001000000050000000801F9122A80484004013274ECCA4C400801F9122A804840A532C51C04CD4C40FAB5F5D37F844840A532C51C04CD4C40FAB5F5D37F84484004013274ECCA4C400801F9122A80484004013274ECCA4C40
49496	22079	49.129491999999999	49.153576000000001	57.374679999999998	57.361842000000003	Школьная	0103000020E61000000100000005000000FC8BA03193904840DD28B2D650AE4C40FC8BA031939048408E3BA583F5AF4C40AAB9DC60A89348408E3BA583F5AF4C40AAB9DC60A8934840DD28B2D650AE4C40FC8BA03193904840DD28B2D650AE4C40
49361	22036	48.874541000000001	48.896656999999998	57.576501	57.565674999999999	Советская	0103000020E610000001000000050000006D01A1F5F06F48401895D40968C84C406D01A1F5F06F48403F8EE6C8CAC94C405F5D15A8C57248403F8EE6C8CAC94C405F5D15A8C57248401895D40968C84C406D01A1F5F06F48401895D40968C84C40
49354	21988	48.870013	48.889623999999998	57.312128000000001	57.303440999999999	Ленина	0103000020E61000000100000005000000240C03965C6F4840FDA19927D7A64C40240C03965C6F48403C1570CFF3A74C404CDE0033DF7148403C1570CFF3A74C404CDE0033DF714840FDA19927D7A64C40240C03965C6F4840FDA19927D7A64C40
49380	21904	48.705675999999997	48.727432999999998	57.737777999999999	57.723751999999998	Краснооктябрьская	0103000020E610000001000000050000003AC95697535A48401135D1E7A3DC4C403AC95697535A4840A9DA6E826FDE4C40FD8348861C5D4840A9DA6E826FDE4C40FD8348861C5D48401135D1E7A3DC4C403AC95697535A48401135D1E7A3DC4C40
49378	21832	48.664191000000002	48.697141999999999	57.613053000000001	57.599575999999999	Набережная	0103000020E6100000010000000500000016A6EF3504554840B6BB07E8BECC4C4016A6EF35045548407BDB4C8578CE4C408255F5F23B5948407BDB4C8578CE4C408255F5F23B594840B6BB07E8BECC4C4016A6EF3504554840B6BB07E8BECC4C40
49529	23321	48.791896000000001	48.818980000000003	57.499858000000003	57.482666999999999	Советская	0103000020E61000000100000005000000A7EA1ED95C654840E1ED4108C8BD4C40A7EA1ED95C6548406E52D158FBBF4C40FF092E56D46848406E52D158FBBF4C40FF092E56D4684840E1ED4108C8BD4C40A7EA1ED95C654840E1ED4108C8BD4C40
49097	19429	49.804917000000003	49.846823000000001	58.637045000000001	58.625065999999997	Солнечная	0103000020E610000001000000050000004A7F2F8507E74840B7EBA52902504D404A7F2F8507E74840488AC8B08A514D40144031B264EC4840488AC8B08A514D40144031B264EC4840B7EBA52902504D404A7F2F8507E74840B7EBA52902504D40
9925	20712	50.156122000000003	50.184176999999998	58.946458999999997	58.917943999999999	Советская	0103000020E61000000100000005000000D31742CEFB1349409BC761307F754D40D31742CEFB1349409F008A9125794D4073D6A71C931749409F008A9125794D4073D6A71C931749409BC761307F754D40D31742CEFB1349409BC761307F754D40
49521	20866	50.262186	50.293511000000002	59.063755999999998	59.042195	Советская	0103000020E610000001000000050000000ABC934F8F214940018750A566854D400ABC934F8F2149403E76172829884D401502B9C4912549403E76172829884D401502B9C491254940018750A566854D400ABC934F8F214940018750A566854D40
49203	20866	50.262186	50.293511000000002	59.063755999999998	59.042195	Профсоюзная	0103000020E610000001000000050000000ABC934F8F214940018750A566854D400ABC934F8F2149403E76172829884D401502B9C4912549403E76172829884D401502B9C491254940018750A566854D400ABC934F8F214940018750A566854D40
49589	20972	49.951639	49.983339999999998	59.125599999999999	59.099023000000003	Советская	0103000020E61000000100000005000000904C874ECFF94840A24621C9AC8C4D40904C874ECFF9484055302AA913904D40A06CCA15DEFD484055302AA913904D40A06CCA15DEFD4840A24621C9AC8C4D40904C874ECFF94840A24621C9AC8C4D40
49386	19396	49.846392000000002	49.865589	58.550472999999997	58.541682000000002	Набережная	0103000020E610000001000000050000004BCCB39256EC48407B6AF5D555454D404BCCB39256EC48405E2A36E675464D408063CF9ECBEE48405E2A36E675464D408063CF9ECBEE48407B6AF5D555454D404BCCB39256EC48407B6AF5D555454D40
48806	19943	50.129496000000003	50.170045999999999	58.727536999999998	58.711668000000003	Трактовая	0103000020E610000001000000050000003E7B2E53931049400CCEE0EF175B4D403E7B2E5393104940A2D0B2EE1F5D4D4066683C11C4154940A2D0B2EE1F5D4D4066683C11C41549400CCEE0EF175B4D403E7B2E53931049400CCEE0EF175B4D40
49586	20602	50.200426999999998	50.213552	58.778337000000001	58.768949999999997	Заводская	0103000020E61000000100000005000000211E8997A71949402D211FF46C624D40211E8997A71949402522FC8BA0634D4069FF03AC551B49402522FC8BA0634D4069FF03AC551B49402D211FF46C624D40211E8997A71949402D211FF46C624D40
49585	6534	49.916289999999996	49.935290000000002	58.858874999999998	58.848812000000002	Молодежная	0103000020E610000001000000050000006FD39FFD48F54840E73922DFA56C4D406FD39FFD48F548400E2DB29DEF6D4D404F232D95B7F748400E2DB29DEF6D4D404F232D95B7F74840E73922DFA56C4D406FD39FFD48F54840E73922DFA56C4D40
49151	20434	50.351129	50.368268	58.647970999999998	58.640183	Молодежная	0103000020E61000000100000005000000AED689CBF12C4940433A3C84F1514D40AED689CBF12C4940D2E0B6B6F0524D40E814E467232F4940D2E0B6B6F0524D40E814E467232F4940433A3C84F1514D40AED689CBF12C4940433A3C84F1514D40
49202	20148	50.296340000000001	50.314306999999999	58.753548000000002	58.746082999999999	Молодежная	0103000020E61000000100000005000000923F1878EE254940008DD2A57F5F4D40923F1878EE254940ADFBC74274604D40B2F336363B284940ADFBC74274604D40B2F336363B284940008DD2A57F5F4D40923F1878EE254940008DD2A57F5F4D40
49518	6452	50.718755000000002	50.743135000000002	58.554777999999999	58.547753999999998	Советская	0103000020E61000000100000005000000126BF129005C4940682096CD1C464D40126BF129005C494028452BF702474D40A9C1340C1F5F494028452BF702474D40A9C1340C1F5F4940682096CD1C464D40126BF129005C4940682096CD1C464D40
49201	6342	50.425311999999998	50.446458	58.862848999999997	58.846837999999998	Ленина	0103000020E61000000100000005000000554CA59F7036494049810530656C4D40554CA59F70364940723106D6716E4D40CF84268925394940723106D6716E4D40CF8426892539494049810530656C4D40554CA59F7036494049810530656C4D40
49580	19322	49.809677999999998	49.818994000000004	58.683819999999997	58.678969000000002	Санаторная	0103000020E6100000010000000500000035255987A3E74840B9FFC874E8564D4035255987A3E74840E42CEC6987574D4064CF9ECBD4E84840E42CEC6987574D4064CF9ECBD4E84840B9FFC874E8564D4035255987A3E74840B9FFC874E8564D40
49523	20845	49.943553999999999	49.969282	59.044666999999997	59.025872999999997	Профсоюзная	0103000020E610000001000000050000004701A260C6F84840B96C74CE4F834D404701A260C6F84840EF1AF4A5B7854D40FD4CBD6E11FC4840EF1AF4A5B7854D40FD4CBD6E11FC4840B96C74CE4F834D404701A260C6F84840B96C74CE4F834D40
77488	61182	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	проспект Мира	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
77492	61182	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	проспект Кирова	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
77473	61182	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	проезд Лермонтова	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
77496	61182	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	пр.Кирова	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
77507	61182	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	пр.Кирова	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
77512	61182	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	Мелиораторов	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
49208	20507	50.319589000000001	50.348506	58.630969	58.609426999999997	К.Маркса	0103000020E61000000100000005000000A794D74AE8284940522635B4014E4D40A794D74AE828494019E59997C3504D40DA3A38D89B2C494019E59997C3504D40DA3A38D89B2C4940522635B4014E4D40A794D74AE8284940522635B4014E4D40
48877	20169	50.418745000000001	50.453842000000002	58.785459000000003	58.773429	Набережная	0103000020E61000000100000005000000882EA86F993549409563B2B8FF624D40882EA86F99354940A8ACA6EB89644D408FC6A17E173A4940A8ACA6EB89644D408FC6A17E173A49409563B2B8FF624D40882EA86F993549409563B2B8FF624D40
49199	19495	49.857702000000003	49.910739	58.659182999999999	58.643171000000002	Труда	0103000020E610000001000000050000005EDBDB2DC9ED4840295E656D53524D405EDBDB2DC9ED4840228AC91B60544D408B18761893F44840228AC91B60544D408B18761893F44840295E656D53524D405EDBDB2DC9ED4840295E656D53524D40
49520	6447	50.567039000000001	50.589073999999997	58.623899000000002	58.607205	Советская	0103000020E610000001000000050000003D47E4BB94484940DD7BB8E4B84D4D403D47E4BB94484940E98024ECDB4F4D404276DEC6664B4940E98024ECDB4F4D404276DEC6664B4940DD7BB8E4B84D4D403D47E4BB94484940DD7BB8E4B84D4D40
49207	20564	50.129019999999997	50.140456	58.765225999999998	58.75732	Советская	0103000020E61000000100000005000000D44334BA83104940A94D9CDCEF604D40D44334BA831049404206F2ECF2614D4074435376FA1149404206F2ECF2614D4074435376FA114940A94D9CDCEF604D40D44334BA83104940A94D9CDCEF604D40
49351	1746	49.957478000000002	49.988847	58.645873000000002	58.632862000000003	Верхняя	0103000020E61000000100000005000000DB519CA38EFA4840CA703C9F01514D40DB519CA38EFA4840492F6AF7AB524D40B5DFDA8992FE4840492F6AF7AB524D40B5DFDA8992FE4840CA703C9F01514D40DB519CA38EFA4840CA703C9F01514D40
48932	19524	49.998781999999999	50.054020000000001	58.698073999999998	58.670214000000001	пер.Школьный	0103000020E61000000100000005000000AFEAAC16D8FF484022A98592C9554D40AFEAAC16D8FF48400D18247D5A594D403BAA9A20EA0649400D18247D5A594D403BAA9A20EA06494022A98592C9554D40AFEAAC16D8FF484022A98592C9554D40
48805	19524	49.998781999999999	50.054020000000001	58.698073999999998	58.670214000000001	Ленина	0103000020E61000000100000005000000AFEAAC16D8FF484022A98592C9554D40AFEAAC16D8FF48400D18247D5A594D403BAA9A20EA0649400D18247D5A594D403BAA9A20EA06494022A98592C9554D40AFEAAC16D8FF484022A98592C9554D40
48725	19524	49.998781999999999	50.054020000000001	58.698073999999998	58.670214000000001	Горького	0103000020E61000000100000005000000AFEAAC16D8FF484022A98592C9554D40AFEAAC16D8FF48400D18247D5A594D403BAA9A20EA0649400D18247D5A594D403BAA9A20EA06494022A98592C9554D40AFEAAC16D8FF484022A98592C9554D40
48726	19524	49.998781999999999	50.054020000000001	58.698073999999998	58.670214000000001	 Ленина	0103000020E61000000100000005000000AFEAAC16D8FF484022A98592C9554D40AFEAAC16D8FF48400D18247D5A594D403BAA9A20EA0649400D18247D5A594D403BAA9A20EA06494022A98592C9554D40AFEAAC16D8FF484022A98592C9554D40
49519	19227	49.752195	49.775075000000001	58.709415	58.692739000000003	Советская	0103000020E610000001000000050000007C9BFEEC47E04840F6D4EAABAB584D407C9BFEEC47E048405B25581CCE5A4D403E7958A835E348405B25581CCE5A4D403E7958A835E34840F6D4EAABAB584D407C9BFEEC47E04840F6D4EAABAB584D40
49238	19227	49.752195	49.775075000000001	58.709415	58.692739000000003	Мира	0103000020E610000001000000050000007C9BFEEC47E04840F6D4EAABAB584D407C9BFEEC47E048405B25581CCE5A4D403E7958A835E348405B25581CCE5A4D403E7958A835E34840F6D4EAABAB584D407C9BFEEC47E04840F6D4EAABAB584D40
49340	6305	47.565058000000001	47.606793000000003	58.277816000000001	58.255771000000003	Коммуны	0103000020E61000000100000005000000ED2B0FD253C84740F321A81ABD204D40ED2B0FD253C847401C2785798F234D408B389D64ABCD47401C2785798F234D408B389D64ABCD4740F321A81ABD204D40ED2B0FD253C84740F321A81ABD204D40
49296	1740	47.783267000000002	47.820672999999999	58.268686000000002	58.251291000000002	Свободы	0103000020E610000001000000050000009D84D21742E44740BB63B14D2A204D409D84D21742E447405072874D64224D40E8DA17D00BE947405072874D64224D40E8DA17D00BE94740BB63B14D2A204D409D84D21742E44740BB63B14D2A204D40
49154	5914	47.544539999999998	47.562381000000002	58.549439999999997	58.525564000000003	Кооперативная	0103000020E6100000010000000500000092AE997CB3C547403CFA5FAE45434D4092AE997CB3C547409F8EC70C54464D402672C119FCC747409F8EC70C54464D402672C119FCC747403CFA5FAE45434D4092AE997CB3C547403CFA5FAE45434D40
48876	294	47.476312999999998	47.540371999999998	58.306154999999997	58.267933999999997	Свободы	0103000020E610000001000000050000006FD40AD3F7BC474044BE4BA94B224D406FD40AD3F7BC4740E140481630274D4049D6E1E82AC54740E140481630274D4049D6E1E82AC5474044BE4BA94B224D406FD40AD3F7BC474044BE4BA94B224D40
48724	294	47.476312999999998	47.540371999999998	58.306154999999997	58.267933999999997	Привокзальная	0103000020E610000001000000050000006FD40AD3F7BC474044BE4BA94B224D406FD40AD3F7BC4740E140481630274D4049D6E1E82AC54740E140481630274D4049D6E1E82AC5474044BE4BA94B224D406FD40AD3F7BC474044BE4BA94B224D40
49335	294	47.476312999999998	47.540371999999998	58.306154999999997	58.267933999999997	Мира	0103000020E610000001000000050000006FD40AD3F7BC474044BE4BA94B224D406FD40AD3F7BC4740E140481630274D4049D6E1E82AC54740E140481630274D4049D6E1E82AC5474044BE4BA94B224D406FD40AD3F7BC474044BE4BA94B224D40
49673	6138	47.474274000000001	47.493012999999998	58.278345999999999	58.270271999999999	Труда	0103000020E61000000100000005000000EBABAB02B5BC47402383DC4598224D40EBABAB02B5BC4740787C7BD7A0234D405DC0CB0C1BBF4740787C7BD7A0234D405DC0CB0C1BBF47402383DC4598224D40EBABAB02B5BC47402383DC4598224D40
49346	6020	47.503819999999997	47.527481000000002	58.332920999999999	58.323225000000001	Механизаторов	0103000020E610000001000000050000000D897B2C7DC04740F31FD26F5F294D400D897B2C7DC047406893C3279D2A4D407521567F84C347406893C3279D2A4D407521567F84C34740F31FD26F5F294D400D897B2C7DC04740F31FD26F5F294D40
49099	6012	47.761510000000001	47.778506	58.442162000000003	58.430630000000001	Советская	0103000020E61000000100000005000000DAC9E02879E14740975643E21E374D40DAC9E02879E1474059C4B0C398384D40B1DEA815A6E3474059C4B0C398384D40B1DEA815A6E34740975643E21E374D40DAC9E02879E14740975643E21E374D40
49348	5187	47.590820999999998	47.614429000000001	58.413286999999997	58.398572000000001	Советская	0103000020E610000001000000050000001F65C405A0CB4740F88C446804334D401F65C405A0CB4740546EA296E6344D40645B069CA5CE4740546EA296E6344D40645B069CA5CE4740F88C446804334D401F65C405A0CB4740F88C446804334D40
49581	5930	47.651431000000002	47.686860000000003	58.518777999999998	58.488446000000003	Советская	0103000020E61000000100000005000000E04C4C1762D3474057EE0566853E4D40E04C4C1762D3474030F1475167424D401D774A07EBD7474030F1475167424D401D774A07EBD7474057EE0566853E4D40E04C4C1762D3474057EE0566853E4D40
49526	6109	47.401716999999998	47.437002999999997	58.40399	58.392507000000002	Мира	0103000020E61000000100000005000000A59F70766BB34740BD395CAB3D324D40A59F70766BB347409DF4BEF1B5334D407FA0DCB6EFB747409DF4BEF1B5334D407FA0DCB6EFB74740BD395CAB3D324D40A59F70766BB34740BD395CAB3D324D40
48856	4868	47.576456999999998	47.580832000000001	58.666344000000002	58.663003000000003	Школьный переулок	0103000020E610000001000000050000006F46CD57C9C9474030134548DD544D406F46CD57C9C9474063F19BC24A554D40323CF6B358CA474063F19BC24A554D40323CF6B358CA474030134548DD544D406F46CD57C9C9474030134548DD544D40
49376	5834	47.487209999999997	47.502481000000003	58.473658999999998	58.462890000000002	Центральная	0103000020E610000001000000050000005F24B4E55CBE47409ED2C1FA3F3B4D405F24B4E55CBE4740603AADDBA03C4D4042EE224C51C04740603AADDBA03C4D4042EE224C51C047409ED2C1FA3F3B4D405F24B4E55CBE47409ED2C1FA3F3B4D40
49372	6236	47.740822000000001	47.767816000000003	58.345765	58.336241999999999	Калинина	0103000020E6100000010000000500000023145B41D3DE474054C554FA092B4D4023145B41D3DE4740FC8C0B07422C4D403BAC70CB47E24740FC8C0B07422C4D403BAC70CB47E2474054C554FA092B4D4023145B41D3DE474054C554FA092B4D40
49326	18217	47.168883000000001	47.211022999999997	56.967227999999999	56.949908000000001	Центральная	0103000020E61000000100000005000000D9EC48F59D954740B91AD99596794C40D9EC48F59D95474043E38920CE7B4C4016DA39CD029B474043E38920CE7B4C4016DA39CD029B4740B91AD99596794C40D9EC48F59D954740B91AD99596794C40
49096	17458	47.224533000000001	47.265649000000003	56.949416999999997	56.930075000000002	Яранская	0103000020E61000000100000005000000B7EF517FBD9C4740E2E995B20C774C40B7EF517FBD9C47401AA20A7F86794C40899B53C900A247401AA20A7F86794C40899B53C900A24740E2E995B20C774C40B7EF517FBD9C4740E2E995B20C774C40
49152	17458	47.224533000000001	47.265649000000003	56.949416999999997	56.930075000000002	Свердлова	0103000020E61000000100000005000000B7EF517FBD9C4740E2E995B20C774C40B7EF517FBD9C47401AA20A7F86794C40899B53C900A247401AA20A7F86794C40899B53C900A24740E2E995B20C774C40B7EF517FBD9C4740E2E995B20C774C40
48930	17458	47.224533000000001	47.265649000000003	56.949416999999997	56.930075000000002	Ленина	0103000020E61000000100000005000000B7EF517FBD9C4740E2E995B20C774C40B7EF517FBD9C47401AA20A7F86794C40899B53C900A247401AA20A7F86794C40899B53C900A24740E2E995B20C774C40B7EF517FBD9C4740E2E995B20C774C40
48931	17458	47.224533000000001	47.265649000000003	56.949416999999997	56.930075000000002	Зевахина	0103000020E61000000100000005000000B7EF517FBD9C4740E2E995B20C774C40B7EF517FBD9C47401AA20A7F86794C40899B53C900A247401AA20A7F86794C40899B53C900A24740E2E995B20C774C40B7EF517FBD9C4740E2E995B20C774C40
49576	18317	47.103135000000002	47.116160999999998	56.949074000000003	56.940300000000001	Центральная	0103000020E6100000010000000500000057091687338D4740E3361AC05B784C4057091687338D4740F1BDBF417B794C400B09185DDE8E4740F1BDBF417B794C400B09185DDE8E4740E3361AC05B784C4057091687338D4740E3361AC05B784C40
49215	18152	47.429420999999998	47.445582000000002	57.070540999999999	57.059412999999999	Школьная	0103000020E61000000100000005000000999B6F44F7B6474087FA5DD89A874C40999B6F44F7B647407903CC7C07894C40D8D7BAD408B947407903CC7C07894C40D8D7BAD408B9474087FA5DD89A874C40999B6F44F7B6474087FA5DD89A874C40
49517	17854	47.238771999999997	47.264525999999996	57.078721000000002	57.070497000000003	Заречная	0103000020E61000000100000005000000AA99B514909E4740AABBB20B06894C40AA99B514909E474014419C87138A4C408978EBFCDBA1474014419C87138A4C408978EBFCDBA14740AABBB20B06894C40AA99B514909E4740AABBB20B06894C40
49284	18057	46.830855999999997	46.863895999999997	56.977868999999998	56.956612999999997	Школьная	0103000020E61000000100000005000000BAD7497D596A4740D7F6764B727A4C40BAD7497D596A4740D862B7CF2A7D4C409692E524946E4740D862B7CF2A7D4C409692E524946E4740D7F6764B727A4C40BAD7497D596A4740D7F6764B727A4C40
49369	18193	47.552320000000002	47.567798000000003	57.037312999999997	57.028511000000002	Лесная 	0103000020E610000001000000050000009F76F86BB2C64740C3499A3FA6834C409F76F86BB2C647409A5B21ACC6844C40FB5DD89AADC847409A5B21ACC6844C40FB5DD89AADC84740C3499A3FA6834C409F76F86BB2C64740C3499A3FA6834C40
49371	18283	47.144340999999997	47.161183999999999	57.024267999999999	57.016204000000002	Приозерная	0103000020E61000000100000005000000683C11C4799247403E0801F912824C40683C11C4799247406F2BBD361B834C40B95164ADA19447406F2BBD361B834C40B95164ADA19447403E0801F912824C40683C11C4799247403E0801F912824C40
49153	17894	46.909297000000002	46.943280000000001	57.115276000000001	57.097003000000001	Дзржинского	0103000020E61000000100000005000000EBAC16D863744740944E24986A8C4C40EBAC16D863744740C1012D5DC18E4C40467C2766BD784740C1012D5DC18E4C40467C2766BD784740944E24986A8C4C40EBAC16D863744740944E24986A8C4C40
49205	17689	47.277417	47.298105	56.956378000000001	56.947561999999998	Школьная	0103000020E610000001000000050000005E2D776682A3474057772CB649794C405E2D776682A34740944E24986A7A4C4015E3FC4D28A64740944E24986A7A4C4015E3FC4D28A6474057772CB649794C405E2D776682A3474057772CB649794C40
49367	17776	47.314310999999996	47.326151000000003	57.008867000000002	56.995562999999997	Свободы	0103000020E61000000100000005000000F3E2C4573BA84740C70DBF9B6E7F4C40F3E2C4573BA84740BF81C98D22814C406347E350BFA94740BF81C98D22814C406347E350BFA94740C70DBF9B6E7F4C40F3E2C4573BA84740C70DBF9B6E7F4C40
49368	18067	46.939570000000003	46.967768	57.000715999999997	56.987437999999997	Советская	0103000020E61000000100000005000000C0266BD443784740F0694E5E647E4C40C0266BD443784740BE4A3E7617804C40C30E63D2DF7B4740BE4A3E7617804C40C30E63D2DF7B4740F0694E5E647E4C40C0266BD443784740F0694E5E647E4C40
49375	17935	46.931789999999999	46.947062000000003	57.062280999999999	57.051428999999999	Речная	0103000020E61000000100000005000000B35E0CE5447747407288B83995864C40B35E0CE544774740C214E5D2F8874C4066A4DE5339794740C214E5D2F8874C4066A4DE53397947407288B83995864C40B35E0CE5447747407288B83995864C40
49377	18452	47.364814000000003	47.392958	56.915937	56.898539	Школьная	0103000020E61000000100000005000000BD8FA339B2AE47401C97715303734C40BD8FA339B2AE47402219726C3D754C40CD599F724CB247402219726C3D754C40CD599F724CB247401C97715303734C40BD8FA339B2AE47401C97715303734C40
49373	2100	46.881269000000003	46.942238000000003	60.234803999999997	60.210624000000003	Мира	0103000020E6100000010000000500000044FD2E6CCD70474059E02BBAF51A4E4044FD2E6CCD704740287CB60E0E1E4E40348639419B784740287CB60E0E1E4E40348639419B78474059E02BBAF51A4E4044FD2E6CCD70474059E02BBAF51A4E40
48968	55991	47.046630999999998	47.088861000000001	60.292605999999999	60.260429999999999	улица Боровая	0103000020E6100000010000000500000069FD2D01F8854740DA722EC555214E4069FD2D01F8854740834E081D74254E40E77118CC5F8B4740834E081D74254E40E77118CC5F8B4740DA722EC555214E4069FD2D01F8854740DA722EC555214E40
48961	55989	47.754044999999998	47.806058	60.262768999999999	60.239615000000001	Индустриальная	0103000020E610000001000000050000002D5BEB8B84E04740C6504EB4AB1E4E402D5BEB8B84E0474089B3226AA2214E40EF5696E82CE7474089B3226AA2214E40EF5696E82CE74740C6504EB4AB1E4E402D5BEB8B84E04740C6504EB4AB1E4E40
49280	246	47.461599	47.499535000000002	60.473126999999998	60.460132000000002	Мира	0103000020E61000000100000005000000E36E10AD15BB4740EAEBF99AE53A4E40E36E10AD15BB474063EDEF6C8F3C4E408B1A4CC3F0BF474063EDEF6C8F3C4E408B1A4CC3F0BF4740EAEBF99AE53A4E40E36E10AD15BB4740EAEBF99AE53A4E40
49086	55995	47.026814000000002	47.034782	60.377704000000001	60.373398999999999	 Школьная	0103000020E61000000100000005000000988922A46E834740F7ADD689CB2F4E40988922A46E834740C1C8CB9A58304E40A73E90BC73844740C1C8CB9A58304E40A73E90BC73844740F7ADD689CB2F4E40988922A46E834740F7ADD689CB2F4E40
49408	16146	48.629821999999997	48.653770999999999	57.354588999999997	57.338746999999998	Труда	0103000020E610000001000000050000009126DE019E5048401E4FCB0F5CAB4C409126DE019E504840BB421F2C63AD4C405F09A4C4AE534840BB421F2C63AD4C405F09A4C4AE5348401E4FCB0F5CAB4C409126DE019E5048401E4FCB0F5CAB4C40
49516	16431	48.334086999999997	48.349673000000003	57.333258000000001	57.327306	Молодежная	0103000020E610000001000000050000006682E15CC32A48406DE4BA29E5A94C406682E15CC32A4840B090B932A8AA4C40A9A5B915C22C4840B090B932A8AA4C40A9A5B915C22C48406DE4BA29E5A94C406682E15CC32A48406DE4BA29E5A94C40
48803	15893	48.495972999999999	48.563023000000001	57.469527999999997	57.450845999999999	Труда	0103000020E610000001000000050000007959130B7C3F484026C45C52B5B94C407959130B7C3F48403447567E19BC4C40AAF23D23114848403447567E19BC4C40AAF23D231148484026C45C52B5B94C407959130B7C3F484026C45C52B5B94C40
48720	15893	48.495972999999999	48.563023000000001	57.469527999999997	57.450845999999999	Заречная	0103000020E610000001000000050000007959130B7C3F484026C45C52B5B94C407959130B7C3F48403447567E19BC4C40AAF23D23114848403447567E19BC4C40AAF23D231148484026C45C52B5B94C407959130B7C3F484026C45C52B5B94C40
48926	16524	48.404173999999998	48.443224000000001	57.537908000000002	57.521638000000003	Октябрьская	0103000020E610000001000000050000005EF23FF9BB334840E92CB308C5C24C405EF23FF9BB334840DE205A2BDAC44C40B2666490BB384840DE205A2BDAC44C40B2666490BB384840E92CB308C5C24C405EF23FF9BB334840E92CB308C5C24C40
49198	16494	48.595847999999997	48.631286000000003	57.583666999999998	57.565356999999999	Коммуны	0103000020E6100000010000000500000089B14CBF444C484047C8409E5DC84C4089B14CBF444C48409160AA99B5CA4C401A36CAFACD5048409160AA99B5CA4C401A36CAFACD50484047C8409E5DC84C4089B14CBF444C484047C8409E5DC84C40
49279	16020	48.477682999999999	48.503959000000002	57.419795999999998	57.408667000000001	Северная	0103000020E61000000100000005000000766D6FB7243D48402BFA43334FB44C40766D6FB7243D4840ED7E15E0BBB54C402FC37FBA81404840ED7E15E0BBB54C402FC37FBA814048402BFA43334FB44C40766D6FB7243D48402BFA43334FB44C40
49277	15994	48.637943	48.643844999999999	57.393149000000001	57.386237000000001	Черемушки	0103000020E6100000010000000500000027DBC01DA8514840A9C0C93670B14C4027DBC01DA851484041BAD8B452B24C40B85851836952484041BAD8B452B24C40B858518369524840A9C0C93670B14C4027DBC01DA8514840A9C0C93670B14C40
49276	16235	48.439737999999998	48.453617000000001	57.320847999999998	57.307802000000002	Советская	0103000020E610000001000000050000007B67B455493848405BD2510E66A74C407B67B45549384840567E198C11A94C406FF4311F103A4840567E198C11A94C406FF4311F103A48405BD2510E66A74C407B67B455493848405BD2510E66A74C40
49363	16317	48.651094000000001	48.658703000000003	57.236398000000001	57.231200999999999	Мира	0103000020E61000000100000005000000984F560C57534840B8E68EFE979D4C40984F560C575348407F6B274A429E4C4078634161505448407F6B274A429E4C407863416150544840B8E68EFE979D4C40984F560C57534840B8E68EFE979D4C40
49149	16285	48.530898999999998	48.566392	57.289833999999999	57.275253999999997	Школьная	0103000020E61000000100000005000000533D997FF4434840ED0BE8853BA34C40533D997FF44348406AA2CF4719A54C40A75B76887F4848406AA2CF4719A54C40A75B76887F484840ED0BE8853BA34C40533D997FF4434840ED0BE8853BA34C40
49382	56005	48.431851000000002	48.440869999999997	57.540246000000003	57.535936999999997	Центральная	0103000020E6100000010000000500000059DFC0E446374840B1DB679599C44C4059DFC0E446374840BDE5EAC726C54C40CDE49B6D6E384840BDE5EAC726C54C40CDE49B6D6E384840B1DB679599C44C4059DFC0E446374840B1DB679599C44C40
48722	16405	48.323262999999997	48.355376999999997	57.428300999999998	57.415103999999999	 Школьная	0103000020E61000000100000005000000E08096AE602948402A38BC2022B54C40E08096AE602948400BEC3191D2B64C40136058FE7C2D48400BEC3191D2B64C40136058FE7C2D48402A38BC2022B54C40E08096AE602948402A38BC2022B54C40
49407	16100	48.492657999999999	48.510939	57.374552999999999	57.356957999999999	Советская	0103000020E610000001000000050000006F0ED76A0F3F4840D505BCCCB0AD4C406F0ED76A0F3F484031CF4A5AF1AF4C401FA0FB726641484031CF4A5AF1AF4C401FA0FB7266414840D505BCCCB0AD4C406F0ED76A0F3F4840D505BCCCB0AD4C40
49405	15429	48.605451000000002	48.623040000000003	58.687739000000001	58.676062999999999	Мира	0103000020E610000001000000050000004E2A1A6B7F4D484090847D3B89564D404E2A1A6B7F4D48408597E0D407584D40C80C54C6BF4F48408597E0D407584D40C80C54C6BF4F484090847D3B89564D404E2A1A6B7F4D484090847D3B89564D40
49570	15791	49.053189000000003	49.073428	58.839849000000001	58.819530999999998	Заречная	0103000020E61000000100000005000000E4C0ABE5CE86484072874D64E6684D40E4C0ABE5CE864840064A0A2C806B4D402B4EB51666894840064A0A2C806B4D402B4EB5166689484072874D64E6684D40E4C0ABE5CE86484072874D64E6684D40
49232	15741	49.175198000000002	49.205624	58.739279000000003	58.714860000000002	Мира	0103000020E610000001000000050000008D2958E36C964840FA9B5088805B4D408D2958E36C9648404FCFBBB1A05E4D40E8A221E3519A48404FCFBBB1A05E4D40E8A221E3519A4840FA9B5088805B4D408D2958E36C964840FA9B5088805B4D40
49270	5604	48.499960999999999	48.536217000000001	58.638280999999999	58.625563	Кирова	0103000020E610000001000000050000004223D8B8FE3F4840384BC97212504D404223D8B8FE3F48403F541A31B3514D40954737C2A24448403F541A31B3514D40954737C2A2444840384BC97212504D404223D8B8FE3F4840384BC97212504D40
49636	15596	48.802756000000002	48.827953999999998	58.712215	58.702997000000003	Новая	0103000020E610000001000000050000007A5567B5C0664840D31742CEFB594D407A5567B5C06648403E5C72DC295B4D40D34B8C65FA6948403E5C72DC295B4D40D34B8C65FA694840D31742CEFB594D407A5567B5C0664840D31742CEFB594D40
49406	15458	48.549944000000004	48.574252000000001	58.729937999999997	58.722706000000002	Молодежная	0103000020E61000000100000005000000D350A39064464840BE4F55A1815C4D40D350A39064464840C70DBF9B6E5D4D40D0D4EB1681494840C70DBF9B6E5D4D40D0D4EB1681494840BE4F55A1815C4D40D350A39064464840BE4F55A1815C4D40
49273	15382	48.704183999999998	48.724594000000003	58.623730999999999	58.609572	Советская,	0103000020E61000000100000005000000E82E89B3225A484056478E74064E4D40E82E89B3225A48402D40DB6AD64F4D405D70067FBF5C48402D40DB6AD64F4D405D70067FBF5C484056478E74064E4D40E82E89B3225A484056478E74064E4D40
49269	15274	48.662350000000004	48.692776000000002	58.563144000000001	58.556050999999997	Советская	0103000020E61000000100000005000000B84082E2C75448403CF4DDAD2C474D40B84082E2C75448402578431A15484D4013BA4BE2AC5848402578431A15484D4013BA4BE2AC5848403CF4DDAD2C474D40B84082E2C75448403CF4DDAD2C474D40
48874	14931	48.860427999999999	48.920993000000003	58.555990000000001	58.524299999999997	Строителей	0103000020E6100000010000000500000006483481226E48407AA52C431C434D4006483481226E4840977329AE2A474D40276C3F19E3754840977329AE2A474D40276C3F19E37548407AA52C431C434D4006483481226E48407AA52C431C434D40
48723	14931	48.860427999999999	48.920993000000003	58.555990000000001	58.524299999999997	Ст.Халтурина	0103000020E6100000010000000500000006483481226E48407AA52C431C434D4006483481226E4840977329AE2A474D40276C3F19E3754840977329AE2A474D40276C3F19E37548407AA52C431C434D4006483481226E48407AA52C431C434D40
48927	14931	48.860427999999999	48.920993000000003	58.555990000000001	58.524299999999997	Ленина	0103000020E6100000010000000500000006483481226E48407AA52C431C434D4006483481226E4840977329AE2A474D40276C3F19E3754840977329AE2A474D40276C3F19E37548407AA52C431C434D4006483481226E48407AA52C431C434D40
49404	15156	48.844276999999998	48.849074000000002	58.528688000000002	58.526485000000001	Мира	0103000020E61000000100000005000000EBE1CB44116C4840D36A48DC63434D40EBE1CB44116C4840D2E4620CAC434D4024F1F274AE6C4840D2E4620CAC434D4024F1F274AE6C4840D36A48DC63434D40EBE1CB44116C4840D36A48DC63434D40
49143	15702	49.019151999999998	49.036723000000002	58.665880999999999	58.656332999999997	Школьная	0103000020E6100000010000000500000095D39E92738248408D2441B802544D4095D39E92738248408E03AF963B554D406901DA56B38448408E03AF963B554D406901DA56B38448408D2441B802544D4095D39E92738248408D2441B802544D40
49514	15577	48.892588000000003	48.931655999999997	58.650883	58.633166000000003	Шубина	0103000020E61000000100000005000000AA66D6524072484036785F950B514D40AA66D65240724840DD42572250534D40A38FF98040774840DD42572250534D40A38FF9804077484036785F950B514D40AA66D6524072484036785F950B514D40
49266	14081	48.880560000000003	48.918298	58.358071000000002	58.317991999999997	Труда	0103000020E610000001000000050000003815A930B6704840DF313CF6B3284D403815A930B6704840B1524145D52D4D40B9FDF2C98A754840B1524145D52D4D40B9FDF2C98A754840DF313CF6B3284D403815A930B6704840DF313CF6B3284D40
49565	14019	49.235923999999997	49.262909000000001	58.344777999999998	58.333658	Советская	0103000020E61000000100000005000000B62BF4C1329E48403E062B4EB52A4D40B62BF4C1329E4840AD307DAF212C4D407B698A00A7A14840AD307DAF212C4D407B698A00A7A148403E062B4EB52A4D40B62BF4C1329E48403E062B4EB52A4D40
48801	13986	49.186086000000003	49.221739999999997	58.500109999999999	58.483088000000002	Юбилейная	0103000020E610000001000000050000002A1F82AAD1974840878BDCD3D53D4D402A1F82AAD19748408733BF9A03404D40861BF0F9619C48408733BF9A03404D40861BF0F9619C4840878BDCD3D53D4D402A1F82AAD1974840878BDCD3D53D4D40
49264	13930	48.519446000000002	48.546852999999999	58.081069999999997	58.057187999999996	Ленина	0103000020E61000000100000005000000DE04DF347D424840A0DCB6EF51074D40DE04DF347D424840E6577380600A4D40185C7347FF454840E6577380600A4D40185C7347FF454840A0DCB6EF51074D40DE04DF347D424840A0DCB6EF51074D40
49194	14733	49.242669999999997	49.284649000000002	58.473339000000003	58.453955000000001	Рабочая	0103000020E6100000010000000500000033DC80CF0F9F4840876D8B321B3A4D4033DC80CF0F9F4840EF75525F963C4D4068EBE0606FA44840EF75525F963C4D4068EBE0606FA44840876D8B321B3A4D4033DC80CF0F9F4840876D8B321B3A4D40
48872	14733	49.242669999999997	49.284649000000002	58.473339000000003	58.453955000000001	Комсомольская	0103000020E6100000010000000500000033DC80CF0F9F4840876D8B321B3A4D4033DC80CF0F9F4840EF75525F963C4D4068EBE0606FA44840EF75525F963C4D4068EBE0606FA44840876D8B321B3A4D4033DC80CF0F9F4840876D8B321B3A4D40
49150	14733	49.242669999999997	49.284649000000002	58.473339000000003	58.453955000000001	Кирова	0103000020E6100000010000000500000033DC80CF0F9F4840876D8B321B3A4D4033DC80CF0F9F4840EF75525F963C4D4068EBE0606FA44840EF75525F963C4D4068EBE0606FA44840876D8B321B3A4D4033DC80CF0F9F4840876D8B321B3A4D40
49263	13894	48.976545000000002	49.019125000000003	58.414088999999997	58.394520999999997	Советская	0103000020E610000001000000050000004209336DFF7C4840E84A04AA7F324D404209336DFF7C484011514CDE00354D409CC420B07282484011514CDE00354D409CC420B072824840E84A04AA7F324D404209336DFF7C4840E84A04AA7F324D40
49211	13795	49.018990000000002	49.039157000000003	58.329788000000001	58.317028000000001	Старосельская	0103000020E61000000100000005000000BC79AA436E82484049F59D5F94284D40BC79AA436E8248407F4E417E362A4D406A34B918038548407F4E417E362A4D406A34B9180385484049F59D5F94284D40BC79AA436E82484049F59D5F94284D40
49515	13728	48.695632000000003	48.719302999999996	58.242111999999999	58.226444000000001	Школьная	0103000020E610000001000000050000008A0629780A5948400E30F31DFC1C4D408A0629780A5948400DFCA886FD1E4D401475E61E125C48400DFCA886FD1E4D401475E61E125C48400E30F31DFC1C4D408A0629780A5948400E30F31DFC1C4D40
49400	13688	49.021388000000002	49.099048000000003	58.413980000000002	58.385572000000003	Якимовой	0103000020E6100000010000000500000070438CD7BC8248406D205D6C5A314D4070438CD7BC8248405B99F04BFD344D40FB5DD89AAD8C48405B99F04BFD344D40FB5DD89AAD8C48406D205D6C5A314D4070438CD7BC8248406D205D6C5A314D40
48924	13688	49.021388000000002	49.099048000000003	58.413980000000002	58.385572000000003	Юбилейная	0103000020E6100000010000000500000070438CD7BC8248406D205D6C5A314D4070438CD7BC8248405B99F04BFD344D40FB5DD89AAD8C48405B99F04BFD344D40FB5DD89AAD8C48406D205D6C5A314D4070438CD7BC8248406D205D6C5A314D40
48799	13688	49.021388000000002	49.099048000000003	58.413980000000002	58.385572000000003	Молодая Гвардия	0103000020E6100000010000000500000070438CD7BC8248406D205D6C5A314D4070438CD7BC8248405B99F04BFD344D40FB5DD89AAD8C48405B99F04BFD344D40FB5DD89AAD8C48406D205D6C5A314D4070438CD7BC8248406D205D6C5A314D40
49200	13688	49.021388000000002	49.099048000000003	58.413980000000002	58.385572000000003	Комсомольская	0103000020E6100000010000000500000070438CD7BC8248406D205D6C5A314D4070438CD7BC8248405B99F04BFD344D40FB5DD89AAD8C48405B99F04BFD344D40FB5DD89AAD8C48406D205D6C5A314D4070438CD7BC8248406D205D6C5A314D40
48719	13688	49.021388000000002	49.099048000000003	58.413980000000002	58.385572000000003	Карла Маркса	0103000020E6100000010000000500000070438CD7BC8248406D205D6C5A314D4070438CD7BC8248405B99F04BFD344D40FB5DD89AAD8C48405B99F04BFD344D40FB5DD89AAD8C48406D205D6C5A314D4070438CD7BC8248406D205D6C5A314D40
49098	13688	49.021388000000002	49.099048000000003	58.413980000000002	58.385572000000003	40 лет победы	0103000020E6100000010000000500000070438CD7BC8248406D205D6C5A314D4070438CD7BC8248405B99F04BFD344D40FB5DD89AAD8C48405B99F04BFD344D40FB5DD89AAD8C48406D205D6C5A314D4070438CD7BC8248406D205D6C5A314D40
49401	13824	48.843018999999998	48.866052000000003	58.239663	58.226396999999999	Советская	0103000020E610000001000000050000000C74ED0BE86B4840CD74AF93FA1C4D400C74ED0BE86B4840D787F546AD1E4D405551BCCADA6E4840D787F546AD1E4D405551BCCADA6E4840CD74AF93FA1C4D400C74ED0BE86B4840CD74AF93FA1C4D40
48962	55979	48.621234000000001	48.653905999999999	58.320827999999999	58.291767999999998	Степана Халтурина	0103000020E61000000100000005000000E6948098844F4840790261A758254D40E6948098844F48400FD253E410294D403F541A31B35348400FD253E410294D403F541A31B3534840790261A758254D40E6948098844F4840790261A758254D40
48804	55979	48.621234000000001	48.653905999999999	58.320827999999999	58.291767999999998	Радченко	0103000020E61000000100000005000000E6948098844F4840790261A758254D40E6948098844F48400FD253E410294D403F541A31B35348400FD253E410294D403F541A31B3534840790261A758254D40E6948098844F4840790261A758254D40
49147	13611	49.442734000000002	49.468919999999997	58.213599000000002	58.204433999999999	Советская	0103000020E61000000100000005000000E469F981ABB848406118B0E42A1A4D40E469F981ABB84840AABA4736571B4D405C38109205BC4840AABA4736571B4D405C38109205BC48406118B0E42A1A4D40E469F981ABB848406118B0E42A1A4D40
48922	13555	49.263925	49.302247000000001	58.224719	58.195314000000003	Почтовая	0103000020E6100000010000000500000064CC5D4BC8A14840B939950C00194D4064CC5D4BC8A1484019E59997C31C4D4035289A07B0A6484019E59997C31C4D4035289A07B0A64840B939950C00194D4064CC5D4BC8A14840B939950C00194D40
49193	13519	48.777800999999997	48.800879000000002	58.420234999999998	58.411076000000001	Степана Халтурина	0103000020E61000000100000005000000E6E5B0FB8E634840D3156C239E344D40E6E5B0FB8E63484039D1AE42CA354D40CF86FC338366484039D1AE42CA354D40CF86FC3383664840D3156C239E344D40E6E5B0FB8E634840D3156C239E344D40
49197	13457	49.010841999999997	49.040585	58.504717999999997	58.490633000000003	Комсомольская	0103000020E610000001000000050000002CB649456381484050ABE80FCD3E4D402CB6494563814840ECD973999A404D40A5DAA7E331854840ECD973999A404D40A5DAA7E33185484050ABE80FCD3E4D402CB649456381484050ABE80FCD3E4D40
49315	14122	48.825169000000002	48.843961999999998	58.352991000000003	58.347087999999999	Советская	0103000020E61000000100000005000000265646239F694840C26A2C616D2C4D40265646239F694840246420CF2E2D4D408B8862F2066C4840246420CF2E2D4D408B8862F2066C4840C26A2C616D2C4D40265646239F694840C26A2C616D2C4D40
49402	14211	48.727316000000002	48.749549000000002	58.333086000000002	58.325204999999997	Советская	0103000020E61000000100000005000000C4EDD0B0185D484072BF4351A0294D40C4EDD0B0185D4840B360E28FA22A4D40F0DFBC38F15F4840B360E28FA22A4D40F0DFBC38F15F484072BF4351A0294D40C4EDD0B0185D484072BF4351A0294D40
49148	13412	49.201563999999998	49.234101000000003	58.538530000000002	58.523172000000002	Моковская	0103000020E61000000100000005000000850662D9CC9948406A17D34CF7424D40850662D9CC9948401BF5108DEE444D40FF7A8505F79D48401BF5108DEE444D40FF7A8505F79D48406A17D34CF7424D40850662D9CC9948406A17D34CF7424D40
49237	12784	49.468794000000003	49.500891000000003	58.352929000000003	58.333691000000002	Советская	0103000020E61000000100000005000000D047197101BC48401AFCFD62B62A4D40D047197101BC4840AE6708C72C2D4D402DEE3F321DC04840AE6708C72C2D4D402DEE3F321DC048401AFCFD62B62A4D40D047197101BC48401AFCFD62B62A4D40
48870	12737	48.250211999999998	48.308827000000001	59.861584000000001	59.837589000000001	пер. Советский	0103000020E610000001000000050000008B8862F206204840A33EC91D36EB4D408B8862F206204840E1606F6248EE4D40978FA4A487274840E1606F6248EE4D40978FA4A487274840A33EC91D36EB4D408B8862F206204840A33EC91D36EB4D40
49267	13128	47.589554999999997	47.609093000000001	59.720281	59.711469000000001	Советская	0103000020E61000000100000005000000BD18CA8976CB4740158F8B6A11DB4D40BD18CA8976CB47401077F52A32DC4D407C9C69C2F6CD47401077F52A32DC4D407C9C69C2F6CD4740158F8B6A11DB4D40BD18CA8976CB4740158F8B6A11DB4D40
49562	13073	48.167898999999998	48.192853999999997	59.952173000000002	59.942394	Центральная	0103000020E61000000100000005000000FB03E5B67D1548402BF9D85DA0F84D40FB03E5B67D1548402E910BCEE0F94D408E739B70AF1848402E910BCEE0F94D408E739B70AF1848402BF9D85DA0F84D40FB03E5B67D1548402BF9D85DA0F84D40
49398	12987	47.403792000000003	47.422854000000001	59.435882999999997	59.426006999999998	Школьная	0103000020E610000001000000050000007731CD74AFB34740FC6EBA6587B64D407731CD74AFB34740F1F09E03CBB74D40CC7D721420B64740F1F09E03CBB74D40CC7D721420B64740FC6EBA6587B64D407731CD74AFB34740FC6EBA6587B64D40
49310	12621	52.192154000000002	52.214925999999998	58.568795000000001	58.554844000000003	Новая	0103000020E61000000100000005000000D6E5948098184A40E030D12005474D40D6E5948098184A406D904946CE484D40B187F6B1821B4A406D904946CE484D40B187F6B1821B4A40E030D12005474D40D6E5948098184A40E030D12005474D40
48718	12381	51.683824000000001	51.734057999999997	58.860363999999997	58.841864999999999	Ленина	0103000020E61000000100000005000000261C7A8B87D74940D252793BC26B4D40261C7A8B87D74940EF535568206E4D40FFAECF9CF5DD4940EF535568206E4D40FFAECF9CF5DD4940D252793BC26B4D40261C7A8B87D74940D252793BC26B4D40
49307	12445	52.204227000000003	52.222867000000001	58.647979999999997	58.635095999999997	Центральная	0103000020E61000000100000005000000E8FA3E1C241A4A4003E962D34A514D40E8FA3E1C241A4A40253B3602F1524D40C72DE6E7861C4A40253B3602F1524D40C72DE6E7861C4A4003E962D34A514D40E8FA3E1C241A4A4003E962D34A514D40
49195	55992	52.334034000000003	52.334302999999998	59.052095999999999	59.051619000000002	Шлаковая	0103000020E6100000010000000500000044E048A0C12A4A40166D8E739B864D4044E048A0C12A4A404F20EC14AB864D4033FAD170CA2A4A404F20EC14AB864D4033FAD170CA2A4A40166D8E739B864D4044E048A0C12A4A40166D8E739B864D40
49285	55992	52.315213999999997	52.389279999999999	59.059475999999997	59.022210000000001	Ленина	0103000020E61000000100000005000000E49EAEEE58284A4074D2FBC6D7824D40E49EAEEE58284A40CD72D9E89C874D40527E52EDD3314A40CD72D9E89C874D40527E52EDD3314A4074D2FBC6D7824D40E49EAEEE58284A4074D2FBC6D7824D40
48982	55992	52.315213999999997	52.389279999999999	59.059475999999997	59.022210000000001	Ленина	0103000020E61000000100000005000000E49EAEEE58284A4074D2FBC6D7824D40E49EAEEE58284A40CD72D9E89C874D40527E52EDD3314A40CD72D9E89C874D40527E52EDD3314A4074D2FBC6D7824D40E49EAEEE58284A4074D2FBC6D7824D40
48981	55992	52.315213999999997	52.389279999999999	59.059475999999997	59.022210000000001	 Школьная	0103000020E61000000100000005000000E49EAEEE58284A4074D2FBC6D7824D40E49EAEEE58284A40CD72D9E89C874D40527E52EDD3314A40CD72D9E89C874D40527E52EDD3314A4074D2FBC6D7824D40E49EAEEE58284A4074D2FBC6D7824D40
49186	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Трудовых Резервов	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48846	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Северная	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
49145	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Пролетарская	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48867	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Кооперации	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
49184	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Комсомольская	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48951	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Коковихина	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48952	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Западная	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48785	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	Воровского	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
49395	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	9 Мая	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
48851	5413	52.115769999999998	52.25253	58.701515000000001	58.642656000000002	30 лет Победы	0103000020E61000000100000005000000D0ED258DD10E4A40024A438D42524D40D0ED258DD10E4A40A453573ECB594D4023A12DE752204A40A453573ECB594D4023A12DE752204A40024A438D42524D40D0ED258DD10E4A40024A438D42524D40
49358	11909	52.319651999999998	52.342531999999999	58.866343999999998	58.858669999999996	Лесная	0103000020E61000000100000005000000ED0C535BEA284A40350708E6E86D4D40ED0C535BEA284A40FC8A355CE46E4D40AFEAAC16D82B4A40FC8A355CE46E4D40AFEAAC16D82B4A40350708E6E86D4D40ED0C535BEA284A40350708E6E86D4D40
48852	12234	52.402773000000003	52.433413999999999	59.010415000000002	58.989001000000002	Комсомольская	0103000020E610000001000000050000001D5BCF108E334A400C5BB395977E4D401D5BCF108E334A40A5315A4755814D4074D0251C7A374A40A5315A4755814D4074D0251C7A374A400C5BB395977E4D401D5BCF108E334A400C5BB395977E4D40
49510	12085	52.330342000000002	52.353957999999999	59.132793999999997	59.119836999999997	Комсомольская	0103000020E61000000100000005000000643F8BA5482A4A40E5EC9DD1568F4D40643F8BA5482A4A40718DCF64FF904D402B14E97E4E2D4A40718DCF64FF904D402B14E97E4E2D4A40E5EC9DD1568F4D40643F8BA5482A4A40E5EC9DD1568F4D40
49397	12289	52.380170999999997	52.395173	58.876973999999997	58.868028000000002	Школьная	0103000020E610000001000000050000009DF17D71A9304A409301A08A1B6F4D409DF17D71A9304A409DB81CAF40704D4090A1630795324A409DB81CAF40704D4090A1630795324A409301A08A1B6F4D409DF17D71A9304A409301A08A1B6F4D40
49196	12535	52.494689000000001	52.519050999999997	58.679763999999999	58.653154000000001	Октябрьская	0103000020E6100000010000000500000071581AF8513F4A4034A0DE8C9A534D4071581AF8513F4A40C37FBA8102574D4061FA5E4370424A40C37FBA8102574D4061FA5E4370424A4034A0DE8C9A534D4071581AF8513F4A4034A0DE8C9A534D40
49561	12307	52.320433000000001	52.340124000000003	58.719481999999999	58.700659000000002	Логовая	0103000020E6100000010000000500000093C7D3F203294A40F452B131AF594D4093C7D3F203294A40C40776FC175C4D40D84AE82E892B4A40C40776FC175C4D40D84AE82E892B4A40F452B131AF594D4093C7D3F203294A40F452B131AF594D40
48793	11741	52.237034000000001	52.257956	58.790809000000003	58.776283999999997	Пионерская	0103000020E6100000010000000500000021054F21571E4A403B342C465D634D4021054F21571E4A40F530B43A39654D404BE7C3B304214A40F530B43A39654D404BE7C3B304214A403B342C465D634D4021054F21571E4A403B342C465D634D40
48795	11741	52.237034000000001	52.257956	58.790809000000003	58.776283999999997	Азина	0103000020E6100000010000000500000021054F21571E4A403B342C465D634D4021054F21571E4A40F530B43A39654D404BE7C3B304214A40F530B43A39654D404BE7C3B304214A403B342C465D634D4021054F21571E4A403B342C465D634D40
48875	11741	52.237034000000001	52.257956	58.790809000000003	58.776283999999997	30 лет Победы	0103000020E6100000010000000500000021054F21571E4A403B342C465D634D4021054F21571E4A40F530B43A39654D404BE7C3B304214A40F530B43A39654D404BE7C3B304214A403B342C465D634D4021054F21571E4A403B342C465D634D40
48853	11878	52.273657999999998	52.312843000000001	58.781374	58.766482000000003	Русских	0103000020E61000000100000005000000F624B03907234A40817C09151C624D40F624B03907234A40ECF82F1004644D402AE44A3D0B284A40ECF82F1004644D402AE44A3D0B284A40817C09151C624D40F624B03907234A40817C09151C624D40
49146	12564	52.467452000000002	52.501390000000001	58.678387999999998	58.667181999999997	Ленина	0103000020E6100000010000000500000093399677D53B4A406C3D433866554D4093399677D53B4A40DAFF006BD5564D404E452A8C2D404A40DAFF006BD5564D404E452A8C2D404A406C3D433866554D4093399677D53B4A406C3D433866554D40
49508	10635	50.137509000000001	50.162491000000003	57.477639000000003	57.465167000000001	Школьный переулок	0103000020E61000000100000005000000EDF318E599114940D7169E978ABB4C40EDF318E599114940A725564623BD4C407A724D81CC144940A725564623BD4C407A724D81CC144940D7169E978ABB4C40EDF318E599114940D7169E978ABB4C40
49140	11058	49.606155999999999	49.631219000000002	57.545482	57.527330999999997	 Советская	0103000020E610000001000000050000001823128596CD48405F950B957FC34C401823128596CD48404147AB5AD2C54C4092CEC0C8CBD048404147AB5AD2C54C4092CEC0C8CBD048405F950B957FC34C401823128596CD48405F950B957FC34C40
49509	11119	49.448106000000003	49.474041	57.537719000000003	57.526465999999999	Луговая	0103000020E61000000100000005000000199293895BB948405C3AE63C63C34C40199293895BB948400BB8E7F9D3C44C4048FB1F60ADBC48400BB8E7F9D3C44C4048FB1F60ADBC48405C3AE63C63C34C40199293895BB948405C3AE63C63C34C40
49139	10942	49.542428999999998	49.584273000000003	57.826161999999997	57.803134999999997	Большевиков	0103000020E6100000010000000500000074B33F506EC54840F0A2AF20CDE64C4074B33F506EC54840569929ADBFE94C40C9772975C9CA4840569929ADBFE94C40C9772975C9CA4840F0A2AF20CDE64C4074B33F506EC54840F0A2AF20CDE64C40
49141	10752	49.894810999999997	49.915446000000003	57.553860999999998	57.539076999999999	Строителей	0103000020E61000000100000005000000EF8CB62A89F248404D83A27900C54C40EF8CB62A89F24840D2C3D0EAE4C64C4084A0A3552DF54840D2C3D0EAE4C64C4084A0A3552DF548404D83A27900C54C40EF8CB62A89F248404D83A27900C54C40
49320	56002	49.844928000000003	49.871015	57.537323000000001	57.527881999999998	Шварихинское шоссе	0103000020E61000000100000005000000C3BCC79926EC4840D3122BA391C34C40C3BCC79926EC4840BE310400C7C44C40A8A9656B7DEF4840BE310400C7C44C40A8A9656B7DEF4840D3122BA391C34C40C3BCC79926EC4840D3122BA391C34C40
49093	10698	49.987805000000002	50.020116999999999	57.562286	57.550437000000002	Советская	0103000020E61000000100000005000000A3E9EC6470FE484012C138B874C64C40A3E9EC6470FE4840D47FD6FCF8C74C40FC8BA03193024940D47FD6FCF8C74C40FC8BA0319302494012C138B874C64C40A3E9EC6470FE484012C138B874C64C40
48869	10116	49.909652000000001	49.963227000000003	57.571902000000001	57.545158000000001	Фрунзе	0103000020E61000000100000005000000D95E0B7A6FF448408E93C2BCC7C54C40D95E0B7A6FF448402D42B11534C94C40E6CFB7054BFB48402D42B11534C94C40E6CFB7054BFB48408E93C2BCC7C54C40D95E0B7A6FF448408E93C2BCC7C54C40
48947	10116	49.909652000000001	49.963227000000003	57.571902000000001	57.545158000000001	Спартака	0103000020E61000000100000005000000D95E0B7A6FF448408E93C2BCC7C54C40D95E0B7A6FF448402D42B11534C94C40E6CFB7054BFB48402D42B11534C94C40E6CFB7054BFB48408E93C2BCC7C54C40D95E0B7A6FF448408E93C2BCC7C54C40
48844	10116	49.909652000000001	49.963227000000003	57.571902000000001	57.545158000000001	Ленина	0103000020E61000000100000005000000D95E0B7A6FF448408E93C2BCC7C54C40D95E0B7A6FF448402D42B11534C94C40E6CFB7054BFB48402D42B11534C94C40E6CFB7054BFB48408E93C2BCC7C54C40D95E0B7A6FF448408E93C2BCC7C54C40
48845	10553	50.006867	50.061709	57.400951999999997	57.373024999999998	Герцена	0103000020E61000000100000005000000F8359204E100494092CB7F48BFAF4C40F8359204E100494005A2276552B34C40376F9C14E607494005A2276552B34C40376F9C14E607494092CB7F48BFAF4C40F8359204E100494092CB7F48BFAF4C40
49360	10477	49.690579	49.724238999999997	57.740675000000003	57.721113000000003	Советская	0103000020E61000000100000005000000F62686E464D8484038DC476E4DDC4C40F62686E464D848407FFB3A70CEDE4C406EBE11DDB3DC48407FFB3A70CEDE4C406EBE11DDB3DC484038DC476E4DDC4C40F62686E464D8484038DC476E4DDC4C40
49138	10383	50.145882	50.166516000000001	57.654398	57.630101000000003	Полевая	0103000020E610000001000000050000009C89E942AC124940A5164A26A7D04C409C89E942AC124940AE484C50C3D34C406021736550154940AE484C50C3D34C406021736550154940A5164A26A7D04C409C89E942AC124940A5164A26A7D04C40
49505	5126	49.550730000000001	49.567070000000001	57.861001000000002	57.851663000000002	Коммуны	0103000020E610000001000000050000008A7615527EC648404C1B0E4B03ED4C408A7615527EC648406269E04735EE4C407845F0BF95C848406269E04735EE4C407845F0BF95C848404C1B0E4B03ED4C408A7615527EC648404C1B0E4B03ED4C40
49356	5266	49.460171000000003	49.497045999999997	57.704132000000001	57.681981	Школьная	0103000020E61000000100000005000000A8C821E2E6BA484027BF45274BD74C40A8C821E2E6BA4840960854FF20DA4C40C64D0D349FBF4840960854FF20DA4C40C64D0D349FBF484027BF45274BD74C40A8C821E2E6BA484027BF45274BD74C40
49507	10847	49.774141	49.813504999999999	57.495384999999999	57.478040999999997	Зеленая	0103000020E6100000010000000500000012BF620D17E34840D5928E7230BD4C4012BF620D17E34840E8F692C668BF4C40F5108DEE20E84840E8F692C668BF4C40F5108DEE20E84840D5928E7230BD4C4012BF620D17E34840D5928E7230BD4C40
49635	5275	49.856292000000003	49.890507999999997	57.492308000000001	57.475631	Школьная	0103000020E61000000100000005000000C9E9EBF99AED48405DFB027AE1BC4C40C9E9EBF99AED484093C7D3F203BF4C40C669882AFCF1484093C7D3F203BF4C40C669882AFCF148405DFB027AE1BC4C40C9E9EBF99AED48405DFB027AE1BC4C40
48847	10264	50.029243999999998	50.068131999999999	57.294775000000001	57.271355999999997	Заводская	0103000020E6100000010000000500000057CD7344BE03494064C91CCBBBA24C4057CD7344BE034940D656EC2FBBA54C40D1E7A38CB8084940D656EC2FBBA54C40D1E7A38CB808494064C91CCBBBA24C4057CD7344BE03494064C91CCBBBA24C40
48991	55993	49.638890000000004	49.770564999999998	58.563124999999999	58.481727999999997	Конституции	0103000020E61000000100000005000000E8DEC325C7D14840A3C85A43A93D4D40E8DEC325C7D14840AE47E17A14484D409B38B9DFA1E24840AE47E17A14484D409B38B9DFA1E24840A3C85A43A93D4D40E8DEC325C7D14840A3C85A43A93D4D40
49651	10076	50.392254000000001	50.413066999999998	57.662573999999999	57.652380999999998	Центральная	0103000020E61000000100000005000000D3DC0A613532494011C4793881D34C40D3DC0A613532494007978E39CFD44C4046072461DF34494007978E39CFD44C4046072461DF34494011C4793881D34C40D3DC0A613532494011C4793881D34C40
49387	10045	50.636747999999997	50.674135999999997	57.560972999999997	57.544809999999998	 Школьная	0103000020E610000001000000050000008EE55DF58051494052448655BCC54C408EE55DF580514940317898F6CDC74C403387A4164A564940317898F6CDC74C403387A4164A56494052448655BCC54C408EE55DF58051494052448655BCC54C40
48727	5108	50.459474	50.548389999999998	57.518118999999999	57.492652	Советская	0103000020E6100000010000000500000060AE450BD03A49408D2782380FBF4C4060AE450BD03A4940D63730B951C24C400ABABDA431464940D63730B951C24C400ABABDA4314649408D2782380FBF4C4060AE450BD03A49408D2782380FBF4C40
49359	5108	50.459474	50.548389999999998	57.518118999999999	57.492652	Набережная	0103000020E6100000010000000500000060AE450BD03A49408D2782380FBF4C4060AE450BD03A4940D63730B951C24C400ABABDA431464940D63730B951C24C400ABABDA4314649408D2782380FBF4C4060AE450BD03A49408D2782380FBF4C40
49353	9774	50.619222000000001	50.645426	57.625388000000001	57.609943000000001	переулок Советский	0103000020E610000001000000050000005B7B9FAA424F49404AB6BA9C12CE4C405B7B9FAA424F4940CAA7C7B60CD04C407AFEB4519D524940CAA7C7B60CD04C407AFEB4519D5249404AB6BA9C12CE4C405B7B9FAA424F49404AB6BA9C12CE4C40
78894	61367	50.378276	50.408799999999999	57.755454	57.731686000000003	Советская	0103000020E610000001000000050000004C6E14596B304940757808E3A7DD4C404C6E14596B304940F2D077B7B2E04C406A4DF38E53344940F2D077B7B2E04C406A4DF38E53344940757808E3A7DD4C404C6E14596B304940757808E3A7DD4C40
49671	9676	50.268115000000002	50.295397000000001	57.700530000000001	57.686138	переулок Центральный	0103000020E610000001000000050000009548A297512249407C45B75ED3D74C409548A29751224940F6EE8FF7AAD94C40132BA391CF254940F6EE8FF7AAD94C40132BA391CF2549407C45B75ED3D74C409548A297512249407C45B75ED3D74C40
49506	9600	50.288947	50.315457000000002	57.569642999999999	57.556694999999998	Школьная	0103000020E610000001000000050000007FA31D37FC244940616C21C841C74C407FA31D37FC2449409AB2D30FEAC84C40AB251DE5602849409AB2D30FEAC84C40AB251DE560284940616C21C841C74C407FA31D37FC244940616C21C841C74C40
78875	61365	50.179037999999998	50.229236	57.646428	57.626145000000001	Молодежная	0103000020E61000000100000005000000E15E99B7EA164940E7C6F48425D04C40E15E99B7EA164940FE9B1727BED24C406E88F19A571D4940FE9B1727BED24C406E88F19A571D4940E7C6F48425D04C40E15E99B7EA164940E7C6F48425D04C40
48790	9445	50.674486000000002	50.723956000000001	59.724133000000002	59.698326999999999	Октябрьская	0103000020E6100000010000000500000010CEA78E55564940F77475C762D94D4010CEA78E55564940297AE063B0DC4D401ADF1797AA5C4940297AE063B0DC4D401ADF1797AA5C4940F77475C762D94D4010CEA78E55564940F77475C762D94D40
48866	8569	50.777450999999999	50.823714000000002	59.348222999999997	59.293506000000001	Советская	0103000020E610000001000000050000000A9FAD83836349400397C79A91A54D400A9FAD8383634940855B3E9292AC4D40F1A0D9756F694940855B3E9292AC4D40F1A0D9756F6949400397C79A91A54D400A9FAD83836349400397C79A91A54D40
49633	8569	50.777450999999999	50.823714000000002	59.348222999999997	59.293506000000001	Мехнизаторов	0103000020E610000001000000050000000A9FAD83836349400397C79A91A54D400A9FAD8383634940855B3E9292AC4D40F1A0D9756F694940855B3E9292AC4D40F1A0D9756F6949400397C79A91A54D400A9FAD83836349400397C79A91A54D40
48791	8569	50.777450999999999	50.823714000000002	59.348222999999997	59.293506000000001	Леушина	0103000020E610000001000000050000000A9FAD83836349400397C79A91A54D400A9FAD8383634940855B3E9292AC4D40F1A0D9756F694940855B3E9292AC4D40F1A0D9756F6949400397C79A91A54D400A9FAD83836349400397C79A91A54D40
49355	9115	50.893225999999999	50.922125000000001	59.342028999999997	59.326855000000002	Советская	0103000020E61000000100000005000000ECF7C43A557249405DC47762D6A94D40ECF7C43A557249404CA4349BC7AB4D4079E92631087649404CA4349BC7AB4D4079E92631087649405DC47762D6A94D40ECF7C43A557249405DC47762D6A94D40
49393	9365	50.773201999999998	50.793081999999998	59.598233	59.58522	Советская	0103000020E61000000100000005000000D4997B48F8624940897B2C7DE8CA4D40D4997B48F8624940A93121E692CC4D40EC8502B683654940A93121E692CC4D40EC8502B683654940897B2C7DE8CA4D40D4997B48F8624940897B2C7DE8CA4D40
49503	9200	50.053767999999998	50.078705999999997	59.485878999999997	59.473508000000002	Ленина	0103000020E6100000010000000500000021C9ACDEE10649407B32FFE89BBC4D4021C9ACDEE10649401668774831BE4D40DEFFC709130A49401668774831BE4D40DEFFC709130A49407B32FFE89BBC4D4021C9ACDEE10649407B32FFE89BBC4D40
49660	56023	48.604407999999999	48.638607	59.634557999999998	59.616802999999997	Первомайская	0103000020E610000001000000050000006BB8C83D5D4D48408F899466F3CE4D406BB8C83D5D4D484024B5503239D14D4093FFC9DFBD51484024B5503239D14D4093FFC9DFBD5148408F899466F3CE4D406BB8C83D5D4D48408F899466F3CE4D40
49190	7854	48.869554999999998	48.918900000000001	59.451999999999998	59.433484999999997	Футбольная	0103000020E61000000100000005000000618907944D6F48403D27BD6F7CB74D40618907944D6F484060E5D022DBB94D40AF25E4839E75484060E5D022DBB94D40AF25E4839E7548403D27BD6F7CB74D40618907944D6F48403D27BD6F7CB74D40
49231	7854	48.869554999999998	48.918900000000001	59.451999999999998	59.433484999999997	Коммунистическая	0103000020E61000000100000005000000618907944D6F48403D27BD6F7CB74D40618907944D6F484060E5D022DBB94D40AF25E4839E75484060E5D022DBB94D40AF25E4839E7548403D27BD6F7CB74D40618907944D6F48403D27BD6F7CB74D40
48784	7625	48.942166	49.026266	59.413870000000003	59.377640999999997	Халтурина	0103000020E610000001000000050000009AB33EE5987848407A50508A56B04D409AB33EE598784840D46531B1F9B44D40957F2DAF5C834840D46531B1F9B44D40957F2DAF5C8348407A50508A56B04D409AB33EE5987848407A50508A56B04D40
48864	7625	48.942166	49.026266	59.413870000000003	59.377640999999997	Пионерская	0103000020E610000001000000050000009AB33EE5987848407A50508A56B04D409AB33EE598784840D46531B1F9B44D40957F2DAF5C834840D46531B1F9B44D40957F2DAF5C8348407A50508A56B04D409AB33EE5987848407A50508A56B04D40
48954	7625	48.942166	49.026266	59.413870000000003	59.377640999999997	К.Маркса	0103000020E610000001000000050000009AB33EE5987848407A50508A56B04D409AB33EE598784840D46531B1F9B44D40957F2DAF5C834840D46531B1F9B44D40957F2DAF5C8348407A50508A56B04D409AB33EE5987848407A50508A56B04D40
48850	7915	48.783146000000002	48.830711999999998	59.517957000000003	59.501432999999999	Почтовая	0103000020E6100000010000000500000022FFCC203E6448404D11E0F42EC04D4022FFCC203E644840FDDD3B6A4CC24D40873254C5546A4840FDDD3B6A4CC24D40873254C5546A48404D11E0F42EC04D4022FFCC203E6448404D11E0F42EC04D40
48787	7915	48.783146000000002	48.830711999999998	59.517957000000003	59.501432999999999	Первомайская	0103000020E6100000010000000500000022FFCC203E6448404D11E0F42EC04D4022FFCC203E644840FDDD3B6A4CC24D40873254C5546A4840FDDD3B6A4CC24D40873254C5546A48404D11E0F42EC04D4022FFCC203E6448404D11E0F42EC04D40
49192	7143	50.448900999999999	50.475321000000001	56.661817999999997	56.643143999999999	Мира	0103000020E6100000010000000500000023128596753949402F4FE78A52524C402312859675394940BAF3C473B6544C400F0D8B51D73C4940BAF3C473B6544C400F0D8B51D73C49402F4FE78A52524C4023128596753949402F4FE78A52524C40
49136	7103	50.54954	50.577835999999998	56.567881	56.550460000000001	Садовая	0103000020E6100000010000000500000003ECA35357464940CAE0287975464C4003ECA3535746494088821953B0484C40C939B187F649494088821953B0484C40C939B187F6494940CAE0287975464C4003ECA35357464940CAE0287975464C40
49630	6441	50.792865999999997	50.815423000000003	56.424734999999998	56.415025999999997	Школьная	0103000020E610000001000000050000001F0E12A27C654940AE7E6C921F354C401F0E12A27C654940B83B6BB75D364C40FFB3E6C75F684940B83B6BB75D364C40FFB3E6C75F684940AE7E6C921F354C401F0E12A27C654940AE7E6C921F354C40
49500	6116	50.881295999999999	50.907131999999997	56.392820999999998	56.378504	Центральная	0103000020E610000001000000050000003D0CAD4ECE704940DDB3AED172304C403D0CAD4ECE7049404C1762F547324C40D993C0E61C7449404C1762F547324C40D993C0E61C744940DDB3AED172304C403D0CAD4ECE704940DDB3AED172304C40
49091	7200	50.485408999999997	50.522015000000003	56.75067	56.740729000000002	Набережная	0103000020E610000001000000050000008F17D2E1213E494072193735D05E4C408F17D2E1213E49404E0B5EF415604C40BF823463D14249404E0B5EF415604C40BF823463D142494072193735D05E4C408F17D2E1213E494072193735D05E4C40
48841	7008	50.620685999999999	50.650950000000002	56.541958999999999	56.529038999999997	Октябрьская	0103000020E61000000100000005000000E38A8BA3724F49407EA7C98CB7434C40E38A8BA3724F4940ED629AE95E454C4065AA605452534940ED629AE95E454C4065AA6054525349407EA7C98CB7434C40E38A8BA3724F49407EA7C98CB7434C40
48840	6913	50.490654999999997	50.541876999999999	56.694637	56.668585	Молодежная	0103000020E61000000100000005000000374F75C8CD3E49404FCC7A3194554C40374F75C8CD3E4940B8CB7EDDE9584C4030BABC395C454940B8CB7EDDE9584C4030BABC395C4549404FCC7A3194554C40374F75C8CD3E49404FCC7A3194554C40
49350	6827	50.107038000000003	50.132981999999998	56.657673000000003	56.645564	Школьная	0103000020E61000000100000005000000F2B6D26BB30D4940CBBC55D7A1524C40F2B6D26BB30D49402A3BFDA02E544C40747ADE8D051149402A3BFDA02E544C40747ADE8D05114940CBBC55D7A1524C40F2B6D26BB30D4940CBBC55D7A1524C40
49357	6646	50.993110000000001	51.015163000000001	56.464376000000001	56.452469000000001	Шахтерская	0103000020E6100000010000000500000050AA7D3A1E7F494017BA1281EA394C4050AA7D3A1E7F49400E863AAC703B4C40FC8D76DCF08149400E863AAC703B4C40FC8D76DCF081494017BA1281EA394C4050AA7D3A1E7F494017BA1281EA394C40
49294	6765	50.244875999999998	50.263139000000002	56.6464	56.636263	Ленина	0103000020E61000000100000005000000A3C9C518581F4940D253E41071514C40A3C9C518581F49403411363CBD524C40ADA6EB89AE2149403411363CBD524C40ADA6EB89AE214940D253E41071514C40A3C9C518581F4940D253E41071514C40
49229	6737	50.547266999999998	50.571863	56.832737999999999	56.81335	Советская	0103000020E610000001000000050000000B9755D80C464940CE1951DA1B684C400B9755D80C4649407711A628976A4C406F6589CE324949407711A628976A4C406F6589CE32494940CE1951DA1B684C400B9755D80C464940CE1951DA1B684C40
49182	6334	50.693413999999997	50.699261999999997	56.514575000000001	56.509552999999997	Большая	0103000020E61000000100000005000000554B3ACAC1584940124A5F0839414C40554B3ACAC15849406B2BF697DD414C40F3AACE6A815949406B2BF697DD414C40F3AACE6A81594940124A5F0839414C40554B3ACAC1584940124A5F0839414C40
48862	6666	50.649351000000003	50.680495999999998	56.409025999999997	56.391928999999998	Школьная	0103000020E61000000100000005000000FD4FFEEE1D5349404FADBEBA2A324C40FD4FFEEE1D5349405A9BC6F65A344C408787307E1A5749405A9BC6F65A344C408787307E1A5749404FADBEBA2A324C40FD4FFEEE1D5349404FADBEBA2A324C40
49501	6131	51.039121000000002	51.054608000000002	56.605271000000002	56.593676000000002	Школьная	0103000020E610000001000000050000001DCBBBEA01854940C6353E93FD4B4C401DCBBBEA01854940CE1B2785794D4C40CC0C1B65FD864940CE1B2785794D4C40CC0C1B65FD864940C6353E93FD4B4C401DCBBBEA01854940C6353E93FD4B4C40
49352	7032	50.554813000000003	50.575904999999999	56.608956999999997	56.599300999999997	Центральная	0103000020E61000000100000005000000A532C51C04474940E4BA29E5B54C4C40A532C51C04474940CBD58F4DF24D4C402B4D4A41B7494940CBD58F4DF24D4C402B4D4A41B7494940E4BA29E5B54C4C40A532C51C04474940E4BA29E5B54C4C40
49632	6531	50.788634999999999	50.822870000000002	56.661284000000002	56.643692999999999	Юбилейная	0103000020E6100000010000000500000090BDDEFDF164494002D53F8864524C4090BDDEFDF16449401DAF40F4A4544C40056EDDCD536949401DAF40F4A4544C40056EDDCD5369494002D53F8864524C4090BDDEFDF164494002D53F8864524C40
49181	6556	50.851418000000002	50.882418999999999	56.512200999999997	56.488497000000002	Школьная	0103000020E61000000100000005000000E59CD843FB6C4940D998D711873E4C40E59CD843FB6C49403FFD67CD8F414C403C2F151BF37049403FFD67CD8F414C403C2F151BF3704940D998D711873E4C40E59CD843FB6C4940D998D711873E4C40
49305	6011	50.757491000000002	50.777549999999998	56.360711000000002	56.349195000000002	Центральная	0103000020E61000000100000005000000D6011077F56049409F76F86BB22C4C40D6011077F56049405B272EC72B2E4C409D8026C2866349405B272EC72B2E4C409D8026C2866349409F76F86BB22C4C40D6011077F56049409F76F86BB22C4C40
48842	7316	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	Чернышевского	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
49233	7316	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	Тимирязева	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
48863	7316	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	Лесная	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
48843	7316	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	Комсомольская	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
49228	7316	50.649557999999999	50.747115000000001	56.531854000000003	56.507432000000001	Карла Маркса	0103000020E61000000100000005000000766D6FB724534940D1782288F3404C40766D6FB724534940971FB8CA13444C40EFACDD76A15F4940971FB8CA13444C40EFACDD76A15F4940D1782288F3404C40766D6FB724534940D1782288F3404C40
49347	6451	50.860320999999999	50.893180999999998	56.695996999999998	56.677908000000002	переулок Школьный	0103000020E61000000100000005000000F0879FFF1E6E494030D978B0C5564C40F0879FFF1E6E49409B8E006E16594C404C3448C1537249409B8E006E16594C404C3448C15372494030D978B0C5564C40F0879FFF1E6E494030D978B0C5564C40
49631	7250	50.447220999999999	50.468116000000002	56.797181000000002	56.781551999999998	Школьная	0103000020E61000000100000005000000CE8AA8893E394940CB0F5CE509644C40CE8AA8893E3949400DFFE9060A664C40FF5D9F39EB3B49400DFFE9060A664C40FF5D9F39EB3B4940CB0F5CE509644C40CE8AA8893E394940CB0F5CE509644C40
48839	6243	50.621907999999998	50.654058999999997	56.514679000000001	56.495429000000001	Пролетарская	0103000020E61000000100000005000000758F6CAE9A4F4940B83EAC376A3F4C40758F6CAE9A4F494010786000E1414C40C5538F34B853494010786000E1414C40C5538F34B8534940B83EAC376A3F4C40758F6CAE9A4F4940B83EAC376A3F4C40
49628	6225	51.105542999999997	51.123806000000002	56.534379999999999	56.527267000000002	Молодежная	0103000020E610000001000000050000002EA9DA6E828D494049A12C7C7D434C402EA9DA6E828D494078D1579066444C40388600E0D88F494078D1579066444C40388600E0D88F494049A12C7C7D434C402EA9DA6E828D494049A12C7C7D434C40
49349	6962	50.681781000000001	50.707805	56.601506000000001	56.588075000000003	пер.Мирный	0103000020E6100000010000000500000060048D9944574940304CA60A464B4C4060048D9944574940842C0B26FE4C4C40FF78AF5A995A4940842C0B26FE4C4C40FF78AF5A995A4940304CA60A464B4C4060048D9944574940304CA60A464B4C40
49499	5916	50.933020999999997	50.946863999999998	56.535001000000001	56.517007999999997	Зеленая	0103000020E6100000010000000500000098BD6C3B6D7749409BE271512D424C4098BD6C3B6D774940E529ABE97A444C403FE1ECD632794940E529ABE97A444C403FE1ECD6327949409BE271512D424C4098BD6C3B6D7749409BE271512D424C40
49627	5932	50.733325999999998	50.769796999999997	56.346575999999999	56.334867000000003	Тишина	0103000020E610000001000000050000003BA759A0DD5D49403CC1FEEBDC2A4C403BA759A0DD5D49400CCA349A5C2C4C408AC745B5886249400CCA349A5C2C4C408AC745B5886249403CC1FEEBDC2A4C403BA759A0DD5D49403CC1FEEBDC2A4C40
49135	5839	50.809655999999997	50.839623000000003	56.594785999999999	56.585090999999998	Школьная	0103000020E610000001000000050000004D81CCCEA26749408B170B43E44A4C404D81CCCEA2674940300F99F2214C4C4016FC36C4786B4940300F99F2214C4C4016FC36C4786B49408B170B43E44A4C404D81CCCEA26749408B170B43E44A4C40
49227	5762	50.246195999999998	50.286701000000001	56.746395999999997	56.731827000000003	Советская	0103000020E61000000100000005000000F833BC59831F494037AAD381AC5D4C40F833BC59831F4940BFEE74E7895F4C40815D4D9EB2244940BFEE74E7895F4C40815D4D9EB224494037AAD381AC5D4C40F833BC59831F494037AAD381AC5D4C40
49295	4840	47.180408	47.190640000000002	60.654279000000002	60.644050999999997	Озерная	0103000020E61000000100000005000000E8F7FD9B1797474061FA5E4370524E40E8F7FD9B17974740D4BA0D6ABF534E409CA73AE466984740D4BA0D6ABF534E409CA73AE46698474061FA5E4370524E40E8F7FD9B1797474061FA5E4370524E40
49189	4539	47.200395999999998	47.313448999999999	60.63908	60.604889	О.Кошевого	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
48836	4539	47.200395999999998	47.313448999999999	60.63908	60.604889	Маяковского	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
49224	4539	47.200395999999998	47.313448999999999	60.63908	60.604889	Космодемьянской	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
48837	4539	47.200395999999998	47.313448999999999	60.63908	60.604889	В. Козлова	0103000020E61000000100000005000000E61F7D93A6994740E65AB4006D4D4E40E61F7D93A69947408BC3995FCD514E4061FBC9181FA847408BC3995FCD514E4061FBC9181FA84740E65AB4006D4D4E40E61F7D93A6994740E65AB4006D4D4E40
48950	4943	47.567573000000003	47.607126000000001	60.748035000000002	60.719399000000003	Набережный переулок	0103000020E61000000100000005000000DB8B683BA6C8474037E33444155C4E40DB8B683BA6C84740B6A1629CBF5F4E409146054EB6CD4740B6A1629CBF5F4E409146054EB6CD474037E33444155C4E40DB8B683BA6C8474037E33444155C4E40
49142	4943	47.567573000000003	47.607126000000001	60.748035000000002	60.719399000000003	Клубная	0103000020E61000000100000005000000DB8B683BA6C8474037E33444155C4E40DB8B683BA6C84740B6A1629CBF5F4E409146054EB6CD4740B6A1629CBF5F4E409146054EB6CD474037E33444155C4E40DB8B683BA6C8474037E33444155C4E40
49681	4448	49.235321999999996	49.256981000000003	57.334918999999999	57.326464999999999	Центральная	0103000020E61000000100000005000000C00303081F9E4840F224E99AC9A94C40C00303081F9E48408EE733A0DEAA4C40C158DFC0E4A048408EE733A0DEAA4C40C158DFC0E4A04840F224E99AC9A94C40C00303081F9E4840F224E99AC9A94C40
49668	4088	49.489438	49.520797999999999	57.434551999999996	57.40457	Центральная	0103000020E61000000100000005000000B7B585E7A5BE4840AB7823F3C8B34C40B7B585E7A5BE4840A83462669FB74C403EE94482A9C24840A83462669FB74C403EE94482A9C24840AB7823F3C8B34C40B7B585E7A5BE4840AB7823F3C8B34C40
49680	4399	49.353378999999997	49.382260000000002	57.345954999999996	57.328113000000002	Советская	0103000020E61000000100000005000000ED0BE8853BAD48403C32569BFFA94C40ED0BE8853BAD48409F71E14048AC4C40D4484BE5EDB048409F71E14048AC4C40D4484BE5EDB048403C32569BFFA94C40ED0BE8853BAD48403C32569BFFA94C40
49677	4341	49.502625000000002	49.517536999999997	57.379299000000003	57.366312999999998	Производственная	0103000020E610000001000000050000007593180456C04840C18C2958E3AE4C407593180456C04840E833A0DE8CB04C4027BC04A73EC24840E833A0DE8CB04C4027BC04A73EC24840C18C2958E3AE4C407593180456C04840C18C2958E3AE4C40
49679	4262	49.657369000000003	49.674320000000002	57.387096	57.377882	Молодежная	0103000020E61000000100000005000000BE33DAAA24D44840A0DFF76F5EB04C40BE33DAAA24D44840CA349A5C8CB14C40F584251E50D64840CA349A5C8CB14C40F584251E50D64840A0DFF76F5EB04C40BE33DAAA24D44840A0DFF76F5EB04C40
49672	3967	49.480750999999998	49.495932000000003	57.246470000000002	57.243057	Центральная	0103000020E610000001000000050000007842AF3F89BD48402D08E57D1C9F4C407842AF3F89BD4840FAB836548C9F4C401B8524B37ABF4840FAB836548C9F4C401B8524B37ABF48402D08E57D1C9F4C407842AF3F89BD48402D08E57D1C9F4C40
49689	56030	49.478802000000002	49.564025000000001	57.437947999999999	57.39378	Комсомольская	0103000020E6100000010000000500000034A1496249BD4840D1E80E6267B24C4034A1496249BD48409FAC18AE0EB84C402E90A0F831C848409FAC18AE0EB84C402E90A0F831C84840D1E80E6267B24C4034A1496249BD4840D1E80E6267B24C40
49683	4226	49.209513999999999	49.260312999999996	57.202485000000003	57.181485000000002	Советская	0103000020E61000000100000005000000EE06D15AD19A484077DB85E63A974C40EE06D15AD19A48401D774A07EB994C40A0DCB6EF51A148401D774A07EB994C40A0DCB6EF51A1484077DB85E63A974C40EE06D15AD19A484077DB85E63A974C40
49682	4093	49.251455999999997	49.268982000000001	57.057132000000003	57.045099	Мира	0103000020E610000001000000050000000531D0B52FA04840890AD5CDC5854C400531D0B52FA048400DC7F31950874C40399B8E006EA248400DC7F31950874C40399B8E006EA24840890AD5CDC5854C400531D0B52FA04840890AD5CDC5854C40
49667	3977	49.470762000000001	49.493264000000003	57.471445000000003	57.459358000000002	Центральная	0103000020E610000001000000050000008B19E1ED41BC4840F793313ECCBA4C408B19E1ED41BC48406E6E4C4F58BC4C40A725564623BF48406E6E4C4F58BC4C40A725564623BF4840F793313ECCBA4C408B19E1ED41BC4840F793313ECCBA4C40
49688	3877	49.548986999999997	49.573179000000003	57.255794999999999	57.245564999999999	Северная	0103000020E61000000100000005000000EE76BD3445C64840680586AC6E9F4C40EE76BD3445C648407BBDFBE3BDA04C4083E0F1ED5DC948407BBDFBE3BDA04C4083E0F1ED5DC94840680586AC6E9F4C40EE76BD3445C64840680586AC6E9F4C40
49685	3874	49.403908999999999	49.426690000000001	57.130789	57.116424000000002	Полевая	0103000020E61000000100000005000000B0C7444AB3B34840193C4CFBE68E4C40B0C7444AB3B3484099D6A6B1BD904C40DFC325C79DB6484099D6A6B1BD904C40DFC325C79DB64840193C4CFBE68E4C40B0C7444AB3B34840193C4CFBE68E4C40
49684	3799	49.387641000000002	49.421362999999999	57.165450999999997	57.150342999999999	Центральная	0103000020E610000001000000050000005CCB64389EB148405D177E703E934C405CCB64389EB14840950B957F2D954C404A5F0839EFB54840950B957F2D954C404A5F0839EFB548405D177E703E934C405CCB64389EB148405D177E703E934C40
49362	56004	49.298968000000002	49.322763999999999	57.083627999999997	57.07741	Октябрьская	0103000020E6100000010000000500000078465B9544A6484012312592E8894C4078465B9544A64840D3838252B48A4C40BF29AC5450A94840D3838252B48A4C40BF29AC5450A9484012312592E8894C4078465B9544A6484012312592E8894C40
49666	3759	49.334423999999999	49.364984999999997	57.460451999999997	57.447034000000002	Новая	0103000020E61000000100000005000000AE7FD767CEAA48409C19FD6838B94C40AE7FD767CEAA48405BB05417F0BA4C40E94317D4B7AE48405BB05417F0BA4C40E94317D4B7AE48409C19FD6838B94C40AE7FD767CEAA48409C19FD6838B94C40
49686	3710	49.520519	49.542428999999998	57.332787000000003	57.318120999999998	Черёмушки	0103000020E610000001000000050000002BF9D85DA0C24840DD955D30B8A84C402BF9D85DA0C2484059C4B0C398AA4C4074B33F506EC5484059C4B0C398AA4C4074B33F506EC54840DD955D30B8A84C402BF9D85DA0C24840DD955D30B8A84C40
49664	3679	49.799976000000001	49.829953000000003	57.350889000000002	57.336463999999999	Тополиная	0103000020E61000000100000005000000DECA129D65E6484003249A4011AB4C40DECA129D65E6484059C345EEE9AC4C40CA1B60E63BEA484059C345EEE9AC4C40CA1B60E63BEA484003249A4011AB4C40DECA129D65E6484003249A4011AB4C40
49670	3582	49.705176999999999	49.737704999999998	57.298583000000001	57.283116	Свободы	0103000020E6100000010000000500000019726C3D43DA4840B77C24253DA44C4019726C3D43DA48401F12BEF737A64C403F8C101E6DDE48401F12BEF737A64C403F8C101E6DDE4840B77C24253DA44C4019726C3D43DA4840B77C24253DA44C40
49626	3006	49.750075000000002	49.776350999999998	58.048563999999999	58.033810000000003	Молодёжная	0103000020E610000001000000050000000B46257502E048408E23D6E253044D400B46257502E04840A8E15B5837064D40C39B35785FE34840A8E15B5837064D40C39B35785FE348408E23D6E253044D400B46257502E048408E23D6E253044D40
49222	3047	49.799239999999998	49.833959999999998	58.294578000000001	58.281587000000002	Ленина	0103000020E61000000100000005000000D8D30E7F4DE6484048FDF50A0B244D40D8D30E7F4DE64840800F5EBBB4254D4009168733BFEA4840800F5EBBB4254D4009168733BFEA484048FDF50A0B244D40D8D30E7F4DE6484048FDF50A0B244D40
49624	2560	49.899788000000001	49.920521000000001	58.171300000000002	58.160328999999997	Октябрьская	0103000020E61000000100000005000000A8AAD0402CF34840D9CC21A985144D40A8AAD0402CF3484004E78C28ED154D40FF23D3A1D3F5484004E78C28ED154D40FF23D3A1D3F54840D9CC21A985144D40A8AAD0402CF34840D9CC21A985144D40
49370	2340	49.957495999999999	49.984104000000002	58.141280999999999	58.129525999999998	Мира	0103000020E6100000010000000500000081069B3A8FFA4840A8FDD64E94104D4081069B3A8FFA4840E945ED7E15124D4070EEAF1EF7FD4840E945ED7E15124D4070EEAF1EF7FD4840A8FDD64E94104D4081069B3A8FFA4840A8FDD64E94104D40
49223	3097	49.816011000000003	49.839188	58.273519	58.257272	Мира	0103000020E610000001000000050000009016670C73E848409816F549EE204D409016670C73E84840D5EAABAB02234D400B992B836AEB4840D5EAABAB02234D400B992B836AEB48409816F549EE204D409016670C73E848409816F549EE204D40
49241	3396	49.502265999999999	49.538890000000002	58.208578000000003	58.182361999999998	Октябрьский	0103000020E6100000010000000500000045F295404AC048403E0455A357174D4045F295404AC04840225514AFB21A4D401B12F758FAC44840225514AFB21A4D401B12F758FAC448403E0455A357174D4045F295404AC048403E0455A357174D40
48776	3396	49.502265999999999	49.538890000000002	58.208578000000003	58.182361999999998	Курортная	0103000020E6100000010000000500000045F295404AC048403E0455A357174D4045F295404AC04840225514AFB21A4D401B12F758FAC44840225514AFB21A4D401B12F758FAC448403E0455A357174D4045F295404AC048403E0455A357174D40
49385	3357	49.890985000000001	49.913128	58.060698000000002	58.043824999999998	Труда	0103000020E61000000100000005000000001DE6CB0BF24840A4DFBE0E9C054D40001DE6CB0BF248406077BAF3C4074D40EC87D860E1F448406077BAF3C4074D40EC87D860E1F44840A4DFBE0E9C054D40001DE6CB0BF24840A4DFBE0E9C054D40
48833	3164	49.890400999999997	49.959139999999998	58.120714999999997	58.089081999999998	Поселковая	0103000020E61000000100000005000000B0A9F3A8F8F14840C554FA09670B4D40B0A9F3A8F8F148407D91D096730F4D4089247A19C5FA48407D91D096730F4D4089247A19C5FA4840C554FA09670B4D40B0A9F3A8F8F14840C554FA09670B4D40
48775	3164	49.890400999999997	49.959139999999998	58.120714999999997	58.089081999999998	Гагарина	0103000020E61000000100000005000000B0A9F3A8F8F14840C554FA09670B4D40B0A9F3A8F8F148407D91D096730F4D4089247A19C5FA48407D91D096730F4D4089247A19C5FA4840C554FA09670B4D40B0A9F3A8F8F14840C554FA09670B4D40
48774	2776	50.162348000000001	50.183709999999998	58.164673999999998	58.149484000000001	Краснооктябрьская	0103000020E610000001000000050000001749BBD1C71449403CA3AD4A22134D401749BBD1C71449403140A20914154D405DF92CCF831749403140A20914154D405DF92CCF831749403CA3AD4A22134D401749BBD1C71449403CA3AD4A22134D40
49379	2448	50.464073999999997	50.484051999999998	58.048611999999999	58.038556	Новая	0103000020E610000001000000050000004276DEC6663B494044882B67EF044D404276DEC6663B4940B91803EB38064D401DC87A6AF53D4940B91803EB38064D401DC87A6AF53D494044882B67EF044D404276DEC6663B494044882B67EF044D40
49178	2663	50.189808999999997	50.208584000000002	58.163629	58.152769999999997	Заречная	0103000020E6100000010000000500000044BE4BA94B184940ABE7A4F78D134D4044BE4BA94B184940AED689CBF1144D40043C69E1B21A4940AED689CBF1144D40043C69E1B21A4940ABE7A4F78D134D4044BE4BA94B184940ABE7A4F78D134D40
48860	2541	50.069794000000002	50.101370000000003	58.202148000000001	58.187069000000001	Северихина	0103000020E6100000010000000500000080BA8102EF084940378C82E0F1174D4080BA8102EF084940D57954FCDF194D40D46531B1F90C4940D57954FCDF194D40D46531B1F90C4940378C82E0F1174D4080BA8102EF084940378C82E0F1174D40
49498	2436	50.348784000000002	50.378419000000001	58.090204999999997	58.075648999999999	Хохрякова	0103000020E610000001000000050000001DAF40F4A42C4940D07CCEDDAE094D401DAF40F4A42C4940C47762D68B0B4D40AF97A60870304940C47762D68B0B4D40AF97A60870304940D07CCEDDAE094D401DAF40F4A42C4940D07CCEDDAE094D40
49287	2911	49.677024000000003	49.704143999999999	58.128898999999997	58.113079999999997	Советская	0103000020E61000000100000005000000B64DF1B8A8D6484074EACA67790E4D40B64DF1B8A8D6484059BE2EC37F104D405AD6FD6321DA484059BE2EC37F104D405AD6FD6321DA484074EACA67790E4D40B64DF1B8A8D6484074EACA67790E4D40
49260	2326	50.004379	50.03246	58.089210999999999	58.078437999999998	Советская	0103000020E6100000010000000500000004E5B67D8F004940BF61A2410A0A4D4004E5B67D8F004940C3B81B446B0B4D40CE3637A627044940C3B81B446B0B4D40CE3637A627044940BF61A2410A0A4D4004E5B67D8F004940BF61A2410A0A4D40
49634	2214	50.593916	50.629013	58.059707000000003	58.046135	Юбилейная	0103000020E610000001000000050000001B498270054C4940B9196EC0E7054D401B498270054C4940D02B9E7AA4074D4022E17B7F83504940D02B9E7AA4074D4022E17B7F83504940B9196EC0E7054D401B498270054C4940B9196EC0E7054D40
49282	2214	50.593916	50.629013	58.059707000000003	58.046135	Центральный	0103000020E610000001000000050000001B498270054C4940B9196EC0E7054D401B498270054C4940D02B9E7AA4074D4022E17B7F83504940D02B9E7AA4074D4022E17B7F83504940B9196EC0E7054D401B498270054C4940B9196EC0E7054D40
49271	2791	50.238138999999997	50.254190999999999	58.084648000000001	58.069732999999999	Клубная	0103000020E610000001000000050000007973B8567B1E4940DA39CD02ED084D407973B8567B1E4940FED5E3BED50A4D4001F8A75489204940FED5E3BED50A4D4001F8A75489204940DA39CD02ED084D407973B8567B1E4940DA39CD02ED084D40
49092	3486	49.549543999999997	49.578792999999997	58.210143000000002	58.196713000000003	Новая	0103000020E6100000010000000500000044DB317557C648405AD93EE42D194D4044DB317557C64840DE3D40F7E51A4D40AD1397E315CA4840DE3D40F7E51A4D40AD1397E315CA48405AD93EE42D194D4044DB317557C648405AD93EE42D194D40
49261	2678	50.212977000000002	50.234357000000003	58.151910000000001	58.141333000000003	Дружбы	0103000020E610000001000000050000006DE690D4421B49403C6C223317124D406DE690D4421B4940BAF770C971134D405A4B0169FF1D4940BAF770C971134D405A4B0169FF1D49403C6C223317124D406DE690D4421B49403C6C223317124D40
49513	161	47.939205999999999	47.983322000000001	58.272666999999998	58.255828000000001	Кооперативная	0103000020E610000001000000050000007E1AF7E637F8474057B3CEF8BE204D407E1AF7E637F8474066D993C0E6224D40FAB7CB7EDDFD474066D993C0E6224D40FAB7CB7EDDFD474057B3CEF8BE204D407E1AF7E637F8474057B3CEF8BE204D40
48768	55972	49.618974999999999	49.649813999999999	58.556168	58.538153999999999	Советская	0103000020E610000001000000050000005305A3923ACF4840151BF33AE2444D405305A3923ACF4840768A558330474D40D13DEB1A2DD34840768A558330474D40D13DEB1A2DD34840151BF33AE2444D405305A3923ACF4840151BF33AE2444D40
48717	31044	49.703012000000001	49.729107999999997	58.470528999999999	58.460315000000001	Октябрьская	0103000020E610000001000000050000000859164CFCD94840DB6D179AEB3A4D400859164CFCD94840E868554B3A3C4D4040A0336953DD4840E868554B3A3C4D4040A0336953DD4840DB6D179AEB3A4D400859164CFCD94840DB6D179AEB3A4D40
48770	30948	50.479191999999998	50.504282000000003	58.306106999999997	58.296593000000001	 Заева	0103000020E610000001000000050000009E40D829563D49407C9C69C2F6254D409E40D829563D4940D009A1832E274D4012FB04508C404940D009A1832E274D4012FB04508C4049407C9C69C2F6254D409E40D829563D49407C9C69C2F6254D40
9724	30888	49.945225000000001	49.983924000000002	58.420169000000001	58.401122999999998	Советская	0103000020E61000000100000005000000492EFF21FDF8484032569BFF57334D40492EFF21FDF8484082E50819C8354D40F0DFBC38F1FD484082E50819C8354D40F0DFBC38F1FD484032569BFF57334D40492EFF21FDF8484032569BFF57334D40
49583	56013	49.357278000000001	49.372342000000003	58.475593000000003	58.467399	Школьная	0103000020E6100000010000000500000047CA1649BBAD48407097FDBAD33B4D4047CA1649BBAD4840709A3E3BE03C4D40B07614E7A8AF4840709A3E3BE03C4D40B07614E7A8AF48407097FDBAD33B4D4047CA1649BBAD48407097FDBAD33B4D40
49085	30784	50.662781000000003	50.724271000000002	58.328086999999996	58.278809000000003	Новая	0103000020E6100000010000000500000081B4FF01D65449404D6A6803B0234D4081B4FF01D6544940129F3BC1FE294D407A3881E9B45C4940129F3BC1FE294D407A3881E9B45C49404D6A6803B0234D4081B4FF01D65449404D6A6803B0234D40
48830	30740	50.200966000000001	50.250984000000003	58.450916999999997	58.433517999999999	Большевиков	0103000020E61000000100000005000000D1CDFE40B9194940191D90847D374D40D1CDFE40B9194940EF1AF4A5B7394D40DEE8633E20204940EF1AF4A5B7394D40DEE8633E20204940191D90847D374D40D1CDFE40B9194940191D90847D374D40
49183	30678	49.976495	49.991245999999997	58.522053	58.512568999999999	Комсомольская	0103000020E6100000010000000500000090DAC4C9FDFC4840C2F869DC9B414D4090DAC4C9FDFC4840ACE3F8A1D2424D4039252026E1FE4840ACE3F8A1D2424D4039252026E1FE4840C2F869DC9B414D4090DAC4C9FDFC4840C2F869DC9B414D40
48789	30569	50.329093	50.352350000000001	58.378542000000003	58.361660000000001	Петра Родыгина	0103000020E61000000100000005000000D82B2CB81F2A4940BC22F8DF4A2E4D40D82B2CB81F2A4940CB14731074304D40705F07CE192D4940CB14731074304D40705F07CE192D4940BC22F8DF4A2E4D40D82B2CB81F2A4940BC22F8DF4A2E4D40
48828	30529	49.495367000000002	49.52899	58.516672	58.494945999999999	Школьная	0103000020E610000001000000050000004242942F68BF48409CA4F9635A3F4D404242942F68BF48402461DF4E22424D409DF4BEF1B5C348402461DF4E22424D409DF4BEF1B5C348409CA4F9635A3F4D404242942F68BF48409CA4F9635A3F4D40
49364	30472	50.443097999999999	50.479191999999998	58.247019999999999	58.234997	Березовая	0103000020E6100000010000000500000025766D6FB73849403DD4B661141E4D4025766D6FB73849409DBAF2599E1F4D409E40D829563D49409DBAF2599E1F4D409E40D829563D49403DD4B661141E4D4025766D6FB73849403DD4B661141E4D40
49165	30375	50.348604000000002	50.382173999999999	58.447870999999999	58.430480000000003	Новая	0103000020E610000001000000050000009DA04D0E9F2C494082CAF8F719374D409DA04D0E9F2C4940D5E940D653394D40D5B0DF13EB304940D5E940D653394D40D5B0DF13EB30494082CAF8F719374D409DA04D0E9F2C494082CAF8F719374D40
48925	30434	49.762354999999999	49.788891	58.452556000000001	58.436939000000002	Советская	0103000020E61000000100000005000000967840D994E1484069ACFD9DED374D40967840D994E14840E6CDE15AED394D40EB8D5A61FAE44840E6CDE15AED394D40EB8D5A61FAE4484069ACFD9DED374D40967840D994E1484069ACFD9DED374D40
48892	30344	50.250687999999997	50.257497000000001	58.343763000000003	58.341414999999998	Дружбы	0103000020E61000000100000005000000F4BF5C8B1620494092AE997CB32B4D40F4BF5C8B1620494095490D6D002C4D40B8E864A9F520494095490D6D002C4D40B8E864A9F520494092AE997CB32B4D40F4BF5C8B1620494092AE997CB32B4D40
48857	32285	50.170476999999998	50.217235000000002	58.567537000000002	58.545453000000002	 Лесная	0103000020E610000001000000050000002FDCB930D2154940A7406667D1454D402FDCB930D21549408E226B0DA5484D40F645425BCE1B49408E226B0DA5484D40F645425BCE1B4940A7406667D1454D402FDCB930D2154940A7406667D1454D40
48777	30278	50.568350000000002	50.596423000000001	58.212361000000001	58.198700000000002	Школьная	0103000020E610000001000000050000003F575BB1BF4849408CDB68006F194D403F575BB1BF48494012F92EA52E1B4D4086CABF96574C494012F92EA52E1B4D4086CABF96574C49408CDB68006F194D403F575BB1BF4849408CDB68006F194D40
49259	30243	49.770969999999998	49.802652999999999	58.400933999999999	58.381548000000002	Безымянная	0103000020E610000001000000050000003B191C25AFE2484057ED9A90D6304D403B191C25AFE248405FED28CE51334D40A5846055BDE648405FED28CE51334D40A5846055BDE6484057ED9A90D6304D403B191C25AFE2484057ED9A90D6304D40
49221	30106	49.77026	49.816657999999997	58.354771	58.314627000000002	Школьная	0103000020E610000001000000050000005FB532E197E2484024B891B245284D405FB532E197E24840DC48D922692D4D402502D53F88E84840DC48D922692D4D402502D53F88E8484024B891B245284D405FB532E197E2484024B891B245284D40
77143	60509	49.935586000000001	50.291409000000002	58.618271999999997	58.519398000000002	проспект Мира	0103000020E61000000100000005000000384C3448C1F74840CDCD37A27B424D40384C3448C1F7484029047289234F4D404A61DEE34C25494029047289234F4D404A61DEE34C254940CDCD37A27B424D40384C3448C1F74840CDCD37A27B424D40
48734	55968	49.519413999999998	49.575468999999998	58.605944000000001	58.588486000000003	Бамовский переулок	0103000020E61000000100000005000000D28A6F287CC24840B2135E82534B4D40D28A6F287CC248408D9AAF928F4D4D40506EDBF7A8C948408D9AAF928F4D4D40506EDBF7A8C94840B2135E82534B4D40D28A6F287CC24840B2135E82534B4D40
48812	28131	49.274084999999999	49.323483000000003	58.579023999999997	58.551125999999996	Коммуны	0103000020E610000001000000050000007EA99F3715A34840D6FCF84B8B464D407EA99F3715A34840AFCC5B751D4A4D40EFE714E467A94840AFCC5B751D4A4D40EFE714E467A94840D6FCF84B8B464D407EA99F3715A34840D6FCF84B8B464D40
48965	55990	49.752868999999997	49.773646999999997	58.585953000000003	58.576025999999999	Центральная	0103000020E610000001000000050000000B96EA025EE04840A6D24F38BB494D400B96EA025EE048401EFF0582004B4D4002D369DD06E348401EFF0582004B4D4002D369DD06E34840A6D24F38BB494D400B96EA025EE04840A6D24F38BB494D40
48948	55987	49.422235000000001	49.492842000000003	58.534443000000003	58.508366000000002	Молодежный проезд	0103000020E61000000100000005000000001DE6CB0BB64840FD32182312414D40001DE6CB0BB64840BF49D3A068444D40310C587215BF4840BF49D3A068444D40310C587215BF4840FD32182312414D40001DE6CB0BB64840FD32182312414D40
48967	55987	49.422235000000001	49.492842000000003	58.534443000000003	58.508366000000002	Комсомольская	0103000020E61000000100000005000000001DE6CB0BB64840FD32182312414D40001DE6CB0BB64840BF49D3A068444D40310C587215BF4840BF49D3A068444D40310C587215BF4840FD32182312414D40001DE6CB0BB64840FD32182312414D40
48920	27972	49.469341999999997	49.502212	58.617189000000003	58.607875999999997	Парковая	0103000020E61000000100000005000000D2510E6613BC4840FB027AE1CE4D4D40D2510E6613BC4840B939950C004F4D4052D4997B48C04840B939950C004F4D4052D4997B48C04840FB027AE1CE4D4D40D2510E6613BC4840FB027AE1CE4D4D40
48772	28078	49.386051000000002	49.433751000000001	58.622925000000002	58.605573999999997	Юбилейная	0103000020E6100000010000000500000047CB811E6AB1484069A7E672834D4D4047CB811E6AB148402F6EA301BC4F4D40BCCD1B2785B748402F6EA301BC4F4D40BCCD1B2785B7484069A7E672834D4D4047CB811E6AB1484069A7E672834D4D40
49534	20567	50.961004000000003	50.981484999999999	57.126055000000001	57.118335000000002	Советская	0103000020E61000000100000005000000A0A9D72D027B4940707CED99258F4C40A0A9D72D027B4940A73FFB9122904C40DD41EC4CA17D4940A73FFB9122904C40DD41EC4CA17D4940707CED99258F4C40A0A9D72D027B4940707CED99258F4C40
49128	19823	50.784638000000001	50.804023000000001	56.989561000000002	56.978247000000003	пер. Школьный	0103000020E6100000010000000500000074999A046F6449407F349C32377D4C4074999A046F644940D33252EFA97E4C40AC1DC539EA664940D33252EFA97E4C40AC1DC539EA6649407F349C32377D4C4074999A046F6449407F349C32377D4C40
49623	20014	50.970086000000002	50.994447999999998	56.960774999999998	56.948194999999998	Школьная	0103000020E610000001000000050000005B272EC72B7C4940889D29745E794C405B272EC72B7C49403EE8D9ACFA7A4C404BC972124A7F49403EE8D9ACFA7A4C404BC972124A7F4940889D29745E794C405B272EC72B7C4940889D29745E794C40
49629	20839	50.915855000000001	50.933200999999997	57.312978999999999	57.303387000000001	Лесная	0103000020E61000000100000005000000657094BC3A7549400A849D62D5A64C40657094BC3A754940DAAA24B20FA84C4018CC5F2173774940DAAA24B20FA84C4018CC5F21737749400A849D62D5A64C40657094BC3A7549400A849D62D5A64C40
49494	20049	50.722518999999998	50.747096999999997	56.936135999999998	56.928887000000003	Советская	0103000020E610000001000000050000008BDEA9807B5C4940FC56EBC4E5764C408BDEA9807B5C4940DB4DF04DD3774C4048F8DEDFA05F4940DB4DF04DD3774C4048F8DEDFA05F4940FC56EBC4E5764C408BDEA9807B5C4940FC56EBC4E5764C40
49493	19924	50.824244	50.843262000000003	57.089213000000001	57.080350000000003	Школьная	0103000020E610000001000000050000004DF6CFD380694940E71DA7E8488A4C404DF6CFD38069494064B0E2546B8B4C40D3FA5B02F06B494064B0E2546B8B4C40D3FA5B02F06B4940E71DA7E8488A4C404DF6CFD380694940E71DA7E8488A4C40
49300	20716	50.973526	50.993558999999998	57.222572	57.203923000000003	Школьная	0103000020E6100000010000000500000021E7FD7F9C7C49407CF31B261A9A4C4021E7FD7F9C7C4940AE80423D7D9C4C40BFD2F9F02C7F4940AE80423D7D9C4C40BFD2F9F02C7F49407CF31B261A9A4C4021E7FD7F9C7C49407CF31B261A9A4C40
49292	20503	51.121460999999996	51.139589000000001	57.092205999999997	57.078285999999999	Советская	0103000020E61000000100000005000000A65EB7088C8F494009DE9046058A4C40A65EB7088C8F49405B3FFD67CD8B4C40D0F0660DDE9149405B3FFD67CD8B4C40D0F0660DDE91494009DE9046058A4C40A65EB7088C8F494009DE9046058A4C40
49461	20428	50.837279000000002	50.855747999999998	57.421716000000004	57.410280999999998	 Школьная	0103000020E61000000100000005000000555051F52B6B4940C8957A1684B44C40555051F52B6B4940981936CAFAB54C4007CF8426896D4940981936CAFAB54C4007CF8426896D4940C8957A1684B44C40555051F52B6B4940C8957A1684B44C40
49622	20271	51.483105000000002	51.501170000000002	56.861677	56.851978000000003	Верхняя	0103000020E610000001000000050000005DC47762D6BD4940AC74779D0D6D4C405DC47762D6BD4940925B936E4B6E4C4040DEAB5626C04940925B936E4B6E4C4040DEAB5626C04940AC74779D0D6D4C405DC47762D6BD4940AC74779D0D6D4C40
49497	20403	51.460126000000002	51.491405	56.890132000000001	56.872241000000002	Набережная	0103000020E610000001000000050000000805A568E5BA49407C9DD497A56F4C400805A568E5BA4940C18F6AD8EF714C40A20BEA5BE6BE4940C18F6AD8EF714C40A20BEA5BE6BE49407C9DD497A56F4C400805A568E5BA49407C9DD497A56F4C40
49502	19811	51.198051	51.227829999999997	56.849319999999999	56.835298000000002	Красиловская	0103000020E6100000010000000500000055F833BC5999494005357C0BEB6A4C4055F833BC599949405BEB8B84B66C4C401A868F88299D49405BEB8B84B66C4C401A868F88299D494005357C0BEB6A4C4055F833BC5999494005357C0BEB6A4C40
49236	20156	51.020598	51.051509000000003	56.935668999999997	56.919204000000001	 Зеленая	0103000020E61000000100000005000000772E8CF4A28249401B2D077AA8754C40772E8CF4A2824940C5707500C4774C408F39CFD897864940C5707500C4774C408F39CFD8978649401B2D077AA8754C40772E8CF4A28249401B2D077AA8754C40
49462	20878	50.795265000000001	50.809629000000001	57.247118	57.239803000000002	Центральная	0103000020E61000000100000005000000A453573ECB654940C93D5DDDB19E4C40A453573ECB65494060200890A19F4C4054724EECA167494060200890A19F4C4054724EECA1674940C93D5DDDB19E4C40A453573ECB654940C93D5DDDB19E4C40
48916	19528	51.042706000000003	51.311500000000002	57.007494999999999	56.932977999999999	Школьная	0103000020E61000000100000005000000E7ABE4637785494099F1B6D26B774C40E7ABE4637785494017F19D98F5804C401D5A643BDFA7494017F19D98F5804C401D5A643BDFA7494099F1B6D26B774C40E7ABE4637785494099F1B6D26B774C40
49125	19528	51.042706000000003	51.311500000000002	57.007494999999999	56.932977999999999	Скобелева	0103000020E61000000100000005000000E7ABE4637785494099F1B6D26B774C40E7ABE4637785494017F19D98F5804C401D5A643BDFA7494017F19D98F5804C401D5A643BDFA7494099F1B6D26B774C40E7ABE4637785494099F1B6D26B774C40
9852	19528	51.042706000000003	51.311500000000002	57.007494999999999	56.932977999999999	Больничная	0103000020E61000000100000005000000E7ABE4637785494099F1B6D26B774C40E7ABE4637785494017F19D98F5804C401D5A643BDFA7494017F19D98F5804C401D5A643BDFA7494099F1B6D26B774C40E7ABE4637785494099F1B6D26B774C40
49621	19716	51.290649999999999	51.308418000000003	56.981670000000001	56.968705	Молодежная	0103000020E610000001000000050000008C4AEA0434A54940603C8386FE7B4C408C4AEA0434A549406FBBD05CA77D4C40B6BFB33D7AA749406FBBD05CA77D4C40B6BFB33D7AA74940603C8386FE7B4C408C4AEA0434A54940603C8386FE7B4C40
49643	56019	50.948517000000002	50.972439000000001	57.249499	57.236150000000002	Школьная	0103000020E610000001000000050000009B594B0169794940A779C7293A9E4C409B594B01697949403EB14E95EF9F4C406F2D93E1787C49403EB14E95EF9F4C406F2D93E1787C4940A779C7293A9E4C409B594B0169794940A779C7293A9E4C40
49344	19939	51.194170999999997	51.215515000000003	56.930301	56.922446999999998	Школьная	0103000020E61000000100000005000000726A6798DA9849408BA548BE12764C40726A6798DA984940D237691A14774C401366DAFE959B4940D237691A14774C401366DAFE959B49408BA548BE12764C40726A6798DA9849408BA548BE12764C40
49392	56007	51.416880999999997	51.437891999999998	56.844056999999999	56.836686999999998	Центральная	0103000020E6100000010000000500000071A94A5B5CB5494082FE428F186B4C4071A94A5B5CB54940DD7A4D0F0A6C4C400B9755D80CB84940DD7A4D0F0A6C4C400B9755D80CB8494082FE428F186B4C4071A94A5B5CB5494082FE428F186B4C40
49495	4444	51.234442000000001	51.276294999999998	56.804125999999997	56.788707000000002	Советская	0103000020E6100000010000000500000088670932029E49402A90D959F4644C4088670932029E494080EECB99ED664C402F8672A25DA3494080EECB99ED664C402F8672A25DA349402A90D959F4644C4088670932029E49402A90D959F4644C40
49463	4391	51.327409000000003	51.355463	56.924382000000001	56.909514999999999	Школьная	0103000020E6100000010000000500000042B5C189E8A94940581CCEFC6A744C4042B5C189E8A949406B813D2652764C4012F8C3CF7FAD49406B813D2652764C4012F8C3CF7FAD4940581CCEFC6A744C4042B5C189E8A94940581CCEFC6A744C40
49492	19601	51.036605999999999	51.066285999999998	56.782952999999999	56.766938000000003	Школьная	0103000020E610000001000000050000002F6B6281AF844940A3073E062B624C402F6B6281AF8449400DA7CCCD37644C406117450F7C8849400DA7CCCD37644C406117450F7C884940A3073E062B624C402F6B6281AF844940A3073E062B624C40
49297	20678	50.800708	50.857069000000003	56.779747	56.765794	пер. Школьный	0103000020E61000000100000005000000A2D288997D6649408CBCAC8905624C40A2D288997D664940BA13ECBFCE634C402DB5DE6FB46D4940BA13ECBFCE634C402DB5DE6FB46D49408CBCAC8905624C40A2D288997D6649408CBCAC8905624C40
49460	20302	51.410449	51.425863999999997	56.792498000000002	56.779752000000002	Заречная	0103000020E6100000010000000500000084D6C39789B44940CC7EDDE9CE634C4084D6C39789B449409D12109370654C40994528B682B649409D12109370654C40994528B682B64940CC7EDDE9CE634C4084D6C39789B44940CC7EDDE9CE634C40
49188	19026	47.046415000000003	47.074703	57.228482	57.206254000000001	Советская	0103000020E610000001000000050000009D853DEDF0854740A855F487669A4C409D853DEDF0854740C2DCEEE53E9D4C40E0F42EDE8F894740C2DCEEE53E9D4C40E0F42EDE8F894740A855F487669A4C409D853DEDF0854740A855F487669A4C40
49485	18853	47.163124000000003	47.186138999999997	57.214647999999997	57.178030999999997	 Просвещения	0103000020E61000000100000005000000AB984A3FE19447404B5645B8C9964C40AB984A3FE19447406E13EE95799B4C404CC11A67D39747406E13EE95799B4C404CC11A67D39747404B5645B8C9964C40AB984A3FE19447404B5645B8C9964C40
49457	19291	46.943171999999997	46.964784999999999	57.445270999999998	57.430801000000002	Кооперативный переулок	0103000020E610000001000000050000005F402FDCB9784740C40AB77C24B74C405F402FDCB9784740B96DDFA3FEB84C40EF552B137E7B4740B96DDFA3FEB84C40EF552B137E7B4740C40AB77C24B74C405F402FDCB9784740C40AB77C24B74C40
49620	19497	47.268039000000002	47.287666999999999	57.375194	57.363590000000002	Труда	0103000020E61000000100000005000000BA86191A4FA247408A93FB1D8AAE4C40BA86191A4FA24740E5D3635B06B04C40B891B245D2A44740E5D3635B06B04C40B891B245D2A447408A93FB1D8AAE4C40BA86191A4FA247408A93FB1D8AAE4C40
49617	19225	46.788274999999999	46.838303000000003	57.391854000000002	57.372461999999999	Молодежная	0103000020E6100000010000000500000090A0F831E66447405A80B6D5ACAF4C4090A0F831E66447404567994528B24C40C19140834D6B47404567994528B24C40C19140834D6B47405A80B6D5ACAF4C4090A0F831E66447405A80B6D5ACAF4C40
49454	18798	47.323061000000003	47.349597000000003	57.267223999999999	57.251252000000001	Советская	0103000020E6100000010000000500000079CE16105AA94740FD86890629A04C4079CE16105AA94740685A626534A24C40CEE33098BFAC4740685A626534A24C40CEE33098BFAC4740FD86890629A04C4079CE16105AA94740FD86890629A04C40
49343	19109	46.867103	46.894635999999998	57.226100000000002	57.211517999999998	Полевая	0103000020E61000000100000005000000BAA1293BFD6E4740F6419605139B4C40BAA1293BFD6E474014D044D8F09C4C4081E9B46E8372474014D044D8F09C4C4081E9B46E83724740F6419605139B4C40BAA1293BFD6E4740F6419605139B4C40
49465	19389	47.095489999999998	47.135088000000003	57.444195999999998	57.433016000000002	Труда	0103000020E610000001000000050000002A8C2D04398C474087527B116DB74C402A8C2D04398C4740CB811E6ADBB84C40810A47904A914740CB811E6ADBB84C40810A47904A91474087527B116DB74C402A8C2D04398C474087527B116DB74C40
49619	19421	47.357053000000001	47.379834000000002	57.477159999999998	57.462494999999997	Кирова	0103000020E6100000010000000500000027F8A6E9B3AD474021C8410933BB4C4027F8A6E9B3AD4740CC7A319413BD4C4056F487669EB04740CC7A319413BD4C4056F487669EB0474021C8410933BB4C4027F8A6E9B3AD474021C8410933BB4C40
48764	18607	47.177605	47.254699000000002	57.319108	57.291580000000003	Советская	0103000020E61000000100000005000000944DB9C2BB9647407715527E52A54C40944DB9C2BB9647402CF2EB87D8A84C4076A911FA99A047402CF2EB87D8A84C4076A911FA99A047407715527E52A54C40944DB9C2BB9647407715527E52A54C40
48763	18607	47.177605	47.254699000000002	57.319108	57.291580000000003	Пушкина	0103000020E61000000100000005000000944DB9C2BB9647407715527E52A54C40944DB9C2BB9647402CF2EB87D8A84C4076A911FA99A047402CF2EB87D8A84C4076A911FA99A047407715527E52A54C40944DB9C2BB9647407715527E52A54C40
48939	18607	47.177605	47.254699000000002	57.319108	57.291580000000003	Просвещения	0103000020E61000000100000005000000944DB9C2BB9647407715527E52A54C40944DB9C2BB9647402CF2EB87D8A84C4076A911FA99A047402CF2EB87D8A84C4076A911FA99A047407715527E52A54C40944DB9C2BB9647407715527E52A54C40
49458	19317	47.112566999999999	47.133597000000002	57.340922999999997	57.323690999999997	Новая	0103000020E61000000100000005000000EECD6F98688E47403881E9B46EA94C40EECD6F98688E474023BA675DA3AB4C40FFEBDCB41991474023BA675DA3AB4C40FFEBDCB4199147403881E9B46EA94C40EECD6F98688E47403881E9B46EA94C40
49489	19087	46.977424999999997	46.993899999999996	57.216076000000001	57.206498000000003	Центральная	0103000020E610000001000000050000007AA52C431C7D47403F58C6866E9A4C407AA52C431C7D4740AAB9DC60A89B4C4048BF7D1D387F4740AAB9DC60A89B4C4048BF7D1D387F47403F58C6866E9A4C407AA52C431C7D47403F58C6866E9A4C40
49339	18742	47.405642999999998	47.458148999999999	57.374879	57.35389	Школьная	0103000020E61000000100000005000000F86C1D1CECB34740D3307C444CAD4C40F86C1D1CECB34740857AFA08FCAF4C40F9D85DA0A4BA4740857AFA08FCAF4C40F9D85DA0A4BA4740D3307C444CAD4C40F86C1D1CECB34740D3307C444CAD4C40
49123	18557	51.166286999999997	51.214652000000001	58.513306999999998	58.462862000000001	Железнодорожная	0103000020E61000000100000005000000FE5F75E448954940D447E00F3F3B4D40FE5F75E44895494068E7340BB4414D40B0027CB7799B494068E7340BB4414D40B0027CB7799B4940D447E00F3F3B4D40FE5F75E448954940D447E00F3F3B4D40
49179	18474	51.263421999999998	51.292293999999998	58.186352999999997	58.169919	Коммунистическая	0103000020E610000001000000050000000186E5CFB7A1494009FCE1E7BF154D400186E5CFB7A149407841446ADA174D409468C9E369A549407841446ADA174D409468C9E369A5494009FCE1E7BF154D400186E5CFB7A1494009FCE1E7BF154D40
49452	18385	51.103090000000002	51.121837999999997	58.304476000000001	58.290140999999998	Кирова	0103000020E61000000100000005000000B745990D328D4940471D1D5723254D40B745990D328D49405D35CF11F9264D407CB43863988F49405D35CF11F9264D407CB43863988F4940471D1D5723254D40B745990D328D4940471D1D5723254D40
49219	18293	51.212766000000002	51.247844999999998	58.279093000000003	58.260126999999997	Центральная	0103000020E61000000100000005000000B2D991EA3B9B49403EE76ED74B214D40B2D991EA3B9B494072C5C551B9234D4012BD8C62B99F494072C5C551B9234D4012BD8C62B99F49403EE76ED74B214D40B2D991EA3B9B49403EE76ED74B214D40
49180	18224	50.781844	50.812691999999998	58.453921999999999	58.440593999999997	Ленина	0103000020E610000001000000050000007349D576136449402B685A6265384D407349D57613644940AB77B81D1A3A4D4044DC9C4A06684940AB77B81D1A3A4D4044DC9C4A066849402B685A6265384D407349D576136449402B685A6265384D40
49616	18156	51.019115999999997	51.047350000000002	58.474553	58.457599000000002	Новая	0103000020E61000000100000005000000486AA1647282494056D7A19A923A4D40486AA16472824940FE9B1727BE3C4D4099BB96900F864940FE9B1727BE3C4D4099BB96900F86494056D7A19A923A4D40486AA1647282494056D7A19A923A4D40
49448	17931	50.794815999999997	50.831431000000002	58.202651000000003	58.189512000000001	Кирова	0103000020E61000000100000005000000342BDB87BC6549408B19E1ED41184D40342BDB87BC65494038C0CC77F0194D40B7F0BC546C6A494038C0CC77F0194D40B7F0BC546C6A49408B19E1ED41184D40342BDB87BC6549408B19E1ED41184D40
49455	18451	51.171137999999999	51.188268999999998	58.205267999999997	58.197015999999998	Торговая	0103000020E610000001000000050000002A8D98D9E7954940F564FED137194D402A8D98D9E79549402975C938461A4D40E1ECD632199849402975C938461A4D40E1ECD63219984940F564FED137194D402A8D98D9E7954940F564FED137194D40
49338	17773	50.838734000000002	50.889263999999997	58.072104000000003	58.058331000000003	Школьная	0103000020E610000001000000050000008A05BEA25B6B4940E7ABE46377074D408A05BEA25B6B494095F430B43A094D404CC11A67D371494095F430B43A094D404CC11A67D3714940E7ABE46377074D408A05BEA25B6B4940E7ABE46377074D40
48873	14165	50.962620999999999	50.967768	58.446764000000002	58.444060999999998	70 Лет октября 	0103000020E61000000100000005000000AEB8382A377B4940EB36A8FDD6384D40AEB8382A377B4940DC8310902F394D40C30E63D2DF7B4940DC8310902F394D40C30E63D2DF7B4940EB36A8FDD6384D40AEB8382A377B4940EB36A8FDD6384D40
49121	17549	51.256360999999998	51.300153999999999	58.420994	58.391779999999997	Свободы	0103000020E61000000100000005000000247CEF6FD0A049400A9DD7D825324D40247CEF6FD0A04940F7E7A221E3354D40BDE13E726BA64940F7E7A221E3354D40BDE13E726BA649400A9DD7D825324D40247CEF6FD0A049400A9DD7D825324D40
49122	17549	51.256360999999998	51.300153999999999	58.420994	58.391779999999997	Никулина	0103000020E61000000100000005000000247CEF6FD0A049400A9DD7D825324D40247CEF6FD0A04940F7E7A221E3354D40BDE13E726BA64940F7E7A221E3354D40BDE13E726BA649400A9DD7D825324D40247CEF6FD0A049400A9DD7D825324D40
49177	17549	51.256360999999998	51.300153999999999	58.420994	58.391779999999997	Кирова	0103000020E61000000100000005000000247CEF6FD0A049400A9DD7D825324D40247CEF6FD0A04940F7E7A221E3354D40BDE13E726BA64940F7E7A221E3354D40BDE13E726BA649400A9DD7D825324D40247CEF6FD0A049400A9DD7D825324D40
49337	18324	51.237181999999997	51.265478999999999	58.339331999999999	58.322029000000001	 Советская	0103000020E610000001000000050000009599D2FA5B9E49408AAE0B3F38294D409599D2FA5B9E49403E3E213B6F2B4D402C634337FBA149403E3E213B6F2B4D402C634337FBA149408AAE0B3F38294D409599D2FA5B9E49408AAE0B3F38294D40
49185	17765	50.996972	51.054366000000002	58.435667000000002	58.420782000000003	Школьная	0103000020E610000001000000050000008C834BC79C7F49406C5F402FDC354D408C834BC79C7F49402579AEEFC3374D40D6011077F58649402579AEEFC3374D40D6011077F58649406C5F402FDC354D408C834BC79C7F49406C5F402FDC354D40
49647	56020	51.113492999999998	51.139014000000003	58.389623999999998	58.372771	Молодежная	0103000020E6100000010000000500000097A949F0868E4940D8F2CAF5B62F4D4097A949F0868E49404CDE0033DF314D40D4D7F335CB9149404CDE0033DF314D40D4D7F335CB914940D8F2CAF5B62F4D4097A949F0868E4940D8F2CAF5B62F4D40
49176	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	Южная	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
48900	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	Торговая	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
48766	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	Свердлова	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
48826	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	Пушкина	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
49245	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	Куйбышева	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
48895	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	Исполкомовская	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
48917	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	Восточная	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
49187	17066	51.086894000000001	51.184638999999997	58.422054000000003	58.385365	1-я Советская	0103000020E61000000100000005000000FC1BB4571F8B4940F302ECA353314D40FC1BB4571F8B4940B0928FDD05364D4077483140A2974940B0928FDD05364D4077483140A2974940F302ECA353314D40FC1BB4571F8B4940F302ECA353314D40
49512	18060	51.064121	51.079528000000003	58.114882000000001	58.103023999999998	Полевая	0103000020E6100000010000000500000050FEEE1D35884940FF59F3E32F0D4D4050FEEE1D3588494015731074B40E4D40E38E37F92D8A494015731074B40E4D40E38E37F92D8A4940FF59F3E32F0D4D4050FEEE1D35884940FF59F3E32F0D4D40
49453	18079	50.990388000000003	51.017391000000003	58.328691999999997	58.319840999999997	Школьная	0103000020E61000000100000005000000E92CB308C57E4940C075C58CF0284D40E92CB308C57E4940793A5794122A4D40541F48DE39824940793A5794122A4D40541F48DE39824940C075C58CF0284D40E92CB308C57E4940C075C58CF0284D40
49456	52226	50.617137999999997	50.645550999999998	58.467277000000003	58.454345000000004	Новая	0103000020E61000000100000005000000368FC360FE4E4940F20C1AFA273A4D40368FC360FE4E4940259694BBCF3B4D403673486AA1524940259694BBCF3B4D403673486AA1524940F20C1AFA273A4D40368FC360FE4E4940F20C1AFA273A4D40
49342	16683	47.792520000000003	47.809013	58.788131999999997	58.775714999999998	Советская	0103000020E6100000010000000500000085B69C4B71E5474021020EA14A634D4085B69C4B71E547402D776682E1644D40F984ECBC8DE747402D776682E1644D40F984ECBC8DE7474021020EA14A634D4085B69C4B71E5474021020EA14A634D40
49662	56024	47.907989999999998	47.930070000000001	59.222651999999997	59.215504000000003	Школьная	0103000020E610000001000000050000002A8C2D0439F447401F1494A2959B4D402A8C2D0439F44740CA3159DC7F9C4D40D07EA4880CF74740CA3159DC7F9C4D40D07EA4880CF747401F1494A2959B4D402A8C2D0439F447401F1494A2959B4D40
49336	16663	47.987229999999997	48.023871999999997	58.918711000000002	58.905946	Советская	0103000020E61000000100000005000000A6D0798D5DFE474094F8DC09F6734D40A6D0798D5DFE4740DCBC715298754D4022A5D93C0E034840DCBC715298754D4022A5D93C0E03484094F8DC09F6734D40A6D0798D5DFE474094F8DC09F6734D40
49618	16589	48.423892000000002	48.449404000000001	58.794609000000001	58.782100999999997	Молодёжная	0103000020E610000001000000050000009D84D217423648409E95B4E21B644D409D84D21742364840BB0D6ABFB5654D408658FD1186394840BB0D6ABFB5654D408658FD11863948409E95B4E21B644D409D84D217423648409E95B4E21B644D40
49615	16523	47.906804000000001	47.926988999999999	59.267018	59.251327000000003	Набережная	0103000020E61000000100000005000000E5F0492712F4474008CDAE7B2BA04D40E5F0492712F44740BFB854A52DA24D4039605793A7F64740BFB854A52DA24D4039605793A7F6474008CDAE7B2BA04D40E5F0492712F4474008CDAE7B2BA04D40
49133	16502	47.864403000000003	47.898674	59.214900999999998	59.196375000000003	Труда	0103000020E610000001000000050000003BC8EBC1A4EE47404260E5D022994D403BC8EBC1A4EE474058703FE0819B4D40FCE1E7BF07F3474058703FE0819B4D40FCE1E7BF07F347404260E5D022994D403BC8EBC1A4EE47404260E5D022994D40
49137	9235	48.292710999999997	48.324314000000001	58.889921999999999	58.876584000000001	Строителей	0103000020E61000000100000005000000F816D68D7725484033198EE733704D40F816D68D77254840D6FECEF6E8714D4046D1031F83294840D6FECEF6E8714D4046D1031F8329484033198EE733704D40F816D68D7725484033198EE733704D40
49132	9235	48.292710999999997	48.324314000000001	58.889921999999999	58.876584000000001	Мира	0103000020E61000000100000005000000F816D68D7725484033198EE733704D40F816D68D77254840D6FECEF6E8714D4046D1031F83294840D6FECEF6E8714D4046D1031F8329484033198EE733704D40F816D68D7725484033198EE733704D40
49334	16321	48.237465	48.266452999999998	59.067318	59.054622999999999	Набережная	0103000020E61000000100000005000000EA78CC40651E4840014EEFE2FD864D40EA78CC40651E4840503750E09D884D40E675C4211B224840503750E09D884D40E675C4211B224840014EEFE2FD864D40EA78CC40651E4840014EEFE2FD864D40
48894	16143	47.925488999999999	47.997875000000001	58.779335000000003	58.753323999999999	Советская	0103000020E6100000010000000500000064E76D6C76F647405DA5BBEB6C604D4064E76D6C76F6474068D0D03FC1634D407D3F355EBAFF474068D0D03FC1634D407D3F355EBAFF47405DA5BBEB6C604D4064E76D6C76F647405DA5BBEB6C604D40
48715	16143	47.925488999999999	47.997875000000001	58.779335000000003	58.753323999999999	Октябрьская	0103000020E6100000010000000500000064E76D6C76F647405DA5BBEB6C604D4064E76D6C76F6474068D0D03FC1634D407D3F355EBAFF474068D0D03FC1634D407D3F355EBAFF47405DA5BBEB6C604D4064E76D6C76F647405DA5BBEB6C604D40
48915	16143	47.925488999999999	47.997875000000001	58.779335000000003	58.753323999999999	Кооперативная	0103000020E6100000010000000500000064E76D6C76F647405DA5BBEB6C604D4064E76D6C76F6474068D0D03FC1634D407D3F355EBAFF474068D0D03FC1634D407D3F355EBAFF47405DA5BBEB6C604D4064E76D6C76F647405DA5BBEB6C604D40
49169	16143	47.925488999999999	47.997875000000001	58.779335000000003	58.753323999999999	Зеленая	0103000020E6100000010000000500000064E76D6C76F647405DA5BBEB6C604D4064E76D6C76F6474068D0D03FC1634D407D3F355EBAFF474068D0D03FC1634D407D3F355EBAFF47405DA5BBEB6C604D4064E76D6C76F647405DA5BBEB6C604D40
49486	16023	47.823062999999998	47.842250999999997	59.095325000000003	59.083573999999999	Школьная	0103000020E6100000010000000500000019C6DD205AE94740E065868DB28A4D4019C6DD205AE94740E0BE0E9C338C4D40FB027AE1CEEB4740E0BE0E9C338C4D40FB027AE1CEEB4740E065868DB28A4D4019C6DD205AE94740E065868DB28A4D40
49332	15984	47.646247000000002	47.677419	58.863760999999997	58.855486999999997	Кооперативная	0103000020E61000000100000005000000AE11C138B8D247409A931799806D4D40AE11C138B8D24740B6476FB88F6E4D40325871AAB5D64740B6476FB88F6E4D40325871AAB5D647409A931799806D4D40AE11C138B8D247409A931799806D4D40
49614	16104	47.881920000000001	48.075184	58.846107000000003	58.817270999999998	Набережная	0103000020E610000001000000050000001BD82AC1E2F047400F7C0C569C684D401BD82AC1E2F0474056F5F23B4D6C4D405B971AA19F09484056F5F23B4D6C4D405B971AA19F0948400F7C0C569C684D401BD82AC1E2F047400F7C0C569C684D40
49646	16104	47.881920000000001	48.075184	58.846107000000003	58.817270999999998	Зеленая	0103000020E610000001000000050000001BD82AC1E2F047400F7C0C569C684D401BD82AC1E2F0474056F5F23B4D6C4D405B971AA19F09484056F5F23B4D6C4D405B971AA19F0948400F7C0C569C684D401BD82AC1E2F047400F7C0C569C684D40
49424	15897	48.387528000000003	48.400723999999997	58.918585	58.901879000000001	Центральная	0103000020E6100000010000000500000064247B849A3148407FF964C570734D4064247B849A3148404FCC7A3194754D40745C8DEC4A3348404FCC7A3194754D40745C8DEC4A3348407FF964C570734D4064247B849A3148407FF964C570734D40
49484	14934	51.363826000000003	51.392321000000003	56.167518999999999	56.160662000000002	Молодежная	0103000020E610000001000000050000009EB7B1D991AE4940E0DA899290144C409EB7B1D991AE4940B43A394371154C405B44149337B24940B43A394371154C405B44149337B24940E0DA899290144C409EB7B1D991AE4940E0DA899290144C40
49174	15003	51.142175999999999	51.170186000000001	56.177436	56.161343000000002	Школьная	0103000020E610000001000000050000005723BBD23292494022382EE3A6144C405723BBD23292494008910C39B6164C40581EA4A7C895494008910C39B6164C40581EA4A7C895494022382EE3A6144C405723BBD23292494022382EE3A6144C40
9873	14889	51.328774000000003	51.349910999999999	56.200477999999997	56.187922	Октябрьская	0103000020E6100000010000000500000037E3344415AA49407619FED30D184C4037E3344415AA4940A3C85A43A9194C405DC136E2C9AC4940A3C85A43A9194C405DC136E2C9AC49407619FED30D184C4037E3344415AA49407619FED30D184C40
49613	48794	50.916097000000001	50.959251999999999	56.208474000000002	56.198484999999998	Школьная	0103000020E610000001000000050000005B7B9FAA427549408FDFDBF467194C405B7B9FAA427549407D08AA46AF1A4C40B14F00C5C87A49407D08AA46AF1A4C40B14F00C5C87A49408FDFDBF467194C405B7B9FAA427549408FDFDBF467194C40
49611	14597	50.940792000000002	50.967390999999999	56.254502000000002	56.243609999999997	Центральная	0103000020E61000000100000005000000522B4CDF6B784940417DCB9C2E1F4C40522B4CDF6B7849402062838593204C40EDB8E177D37B49402062838593204C40EDB8E177D37B4940417DCB9C2E1F4C40522B4CDF6B784940417DCB9C2E1F4C40
49120	14721	51.224874999999997	51.251016	56.129544000000003	56.117184999999999	Советская	0103000020E61000000100000005000000105839B4C89C4940774A07EBFF0E4C40105839B4C89C49404FB2D5E594104C40E962D34A21A049404FB2D5E594104C40E962D34A21A04940774A07EBFF0E4C40105839B4C89C4940774A07EBFF0E4C40
48757	13515	51.234541	51.313124999999999	56.264946999999999	56.238332	Спортивная	0103000020E610000001000000050000001B498270059E49408ECBB8A9811E4C401B498270059E49402F1686C8E9214C40AE47E17A14A849402F1686C8E9214C40AE47E17A14A849408ECBB8A9811E4C401B498270059E49408ECBB8A9811E4C40
48823	13515	51.234541	51.313124999999999	56.264946999999999	56.238332	Пролетарская	0103000020E610000001000000050000001B498270059E49408ECBB8A9811E4C401B498270059E49402F1686C8E9214C40AE47E17A14A849402F1686C8E9214C40AE47E17A14A849408ECBB8A9811E4C401B498270059E49408ECBB8A9811E4C40
48891	13515	51.234541	51.313124999999999	56.264946999999999	56.238332	Куйбышева	0103000020E610000001000000050000001B498270059E49408ECBB8A9811E4C401B498270059E49402F1686C8E9214C40AE47E17A14A849402F1686C8E9214C40AE47E17A14A849408ECBB8A9811E4C401B498270059E49408ECBB8A9811E4C40
48909	13515	51.234541	51.313124999999999	56.264946999999999	56.238332	Комсомольская	0103000020E610000001000000050000001B498270059E49408ECBB8A9811E4C401B498270059E49402F1686C8E9214C40AE47E17A14A849402F1686C8E9214C40AE47E17A14A849408ECBB8A9811E4C401B498270059E49408ECBB8A9811E4C40
48761	13515	51.234541	51.313124999999999	56.264946999999999	56.238332	Дзержинского	0103000020E610000001000000050000001B498270059E49408ECBB8A9811E4C401B498270059E49402F1686C8E9214C40AE47E17A14A849402F1686C8E9214C40AE47E17A14A849408ECBB8A9811E4C401B498270059E49408ECBB8A9811E4C40
49172	13515	51.234541	51.313124999999999	56.264946999999999	56.238332	Ворошилова	0103000020E610000001000000050000001B498270059E49408ECBB8A9811E4C401B498270059E49402F1686C8E9214C40AE47E17A14A849402F1686C8E9214C40AE47E17A14A849408ECBB8A9811E4C401B498270059E49408ECBB8A9811E4C40
49459	14858	51.189715	51.215155000000003	56.142735999999999	56.130367	Кирова	0103000020E61000000100000005000000C347C4944898494023BDA8DDAF104C40C347C494489849401EFB592C45124C401349F4328A9B49401EFB592C45124C401349F4328A9B494023BDA8DDAF104C40C347C4944898494023BDA8DDAF104C40
49173	14468	51.005640999999997	51.052424999999999	56.327070999999997	56.315246000000002	Молодёжная	0103000020E61000000100000005000000244223D8B8804940F0181EFB59284C40244223D8B8804940293C6876DD294C40143FC6DCB5864940293C6876DD294C40143FC6DCB5864940F0181EFB59284C40244223D8B8804940F0181EFB59284C40
49447	14538	50.880316999999998	50.901940000000003	56.370562999999997	56.359538999999998	Центральная	0103000020E61000000100000005000000718E3A3AAE7049407A51BB5F052E4C40718E3A3AAE704940C70DBF9B6E2F4C40257A19C572734940C70DBF9B6E2F4C40257A19C5727349407A51BB5F052E4C40718E3A3AAE7049407A51BB5F052E4C40
49171	14628	50.974226999999999	51.044556	56.251302000000003	56.233924999999999	Центральная	0103000020E61000000100000005000000AAF06778B37C4940C05B2041F11D4C40AAF06778B37C4940AFB5F7A92A204C40986BD102B4854940AFB5F7A92A204C40986BD102B4854940C05B2041F11D4C40AAF06778B37C4940C05B2041F11D4C40
49144	14804	51.265999999999998	51.312685000000002	56.123905000000001	56.114534999999997	Центральная	0103000020E61000000100000005000000355EBA490CA24940A99F3715A90E4C40355EBA490CA24940CB67791EDC0F4C409279E40F06A84940CB67791EDC0F4C409279E40F06A84940A99F3715A90E4C40355EBA490CA24940A99F3715A90E4C40
49449	14523	51.039292000000003	51.052487999999997	56.295515000000002	56.283988999999998	Центральная	0103000020E610000001000000050000004A7F2F85078549403DB665C059244C404A7F2F85078549401D3D7E6FD3254C405AB741EDB78649401D3D7E6FD3254C405AB741EDB78649403DB665C059244C404A7F2F85078549403DB665C059244C40
48928	55985	51.055084000000001	51.064875999999998	56.265191999999999	56.254427	Советская	0103000020E61000000100000005000000354415FE0C874940151C5E1091204C40354415FE0C8749409694BBCFF1214C40CC2555DB4D8849409694BBCFF1214C40CC2555DB4D884940151C5E1091204C40354415FE0C874940151C5E1091204C40
49610	14180	51.234667000000002	51.256397	56.190466000000001	56.179845999999998	Большая	0103000020E61000000100000005000000A8397991099E49408028983105174C40A8397991099E4940FE7F9C3061184C4071E5EC9DD1A04940FE7F9C3061184C4071E5EC9DD1A049408028983105174C40A8397991099E49408028983105174C40
49175	14274	51.225459000000001	51.255526000000003	56.220989000000003	56.202131000000001	Школьная	0103000020E6100000010000000500000060CB2BD7DB9C4940FF40B96DDF194C4060CB2BD7DB9C49404CE3175E491C4C408CA37213B5A049404CE3175E491C4C408CA37213B5A04940FF40B96DDF194C4060CB2BD7DB9C4940FF40B96DDF194C40
49446	13822	51.123015000000002	51.211364000000003	56.262791999999997	56.236530999999999	Сосновая	0103000020E610000001000000050000006FF59CF4BE8F4940BEBED6A5461E4C406FF59CF4BE8F494041D3122BA3214C40A0C6BDF90D9B494041D3122BA3214C40A0C6BDF90D9B4940BEBED6A5461E4C406FF59CF4BE8F4940BEBED6A5461E4C40
49126	13822	51.123015000000002	51.211364000000003	56.262791999999997	56.236530999999999	Свободы	0103000020E610000001000000050000006FF59CF4BE8F4940BEBED6A5461E4C406FF59CF4BE8F494041D3122BA3214C40A0C6BDF90D9B494041D3122BA3214C40A0C6BDF90D9B4940BEBED6A5461E4C406FF59CF4BE8F4940BEBED6A5461E4C40
48889	13822	51.123015000000002	51.211364000000003	56.262791999999997	56.236530999999999	Молодежная	0103000020E610000001000000050000006FF59CF4BE8F4940BEBED6A5461E4C406FF59CF4BE8F494041D3122BA3214C40A0C6BDF90D9B494041D3122BA3214C40A0C6BDF90D9B4940BEBED6A5461E4C406FF59CF4BE8F4940BEBED6A5461E4C40
48758	13822	51.123015000000002	51.211364000000003	56.262791999999997	56.236530999999999	Дружбы	0103000020E610000001000000050000006FF59CF4BE8F4940BEBED6A5461E4C406FF59CF4BE8F494041D3122BA3214C40A0C6BDF90D9B494041D3122BA3214C40A0C6BDF90D9B4940BEBED6A5461E4C406FF59CF4BE8F4940BEBED6A5461E4C40
49490	14307	51.178781999999998	51.195922000000003	56.416839000000003	56.407646	Школьная	0103000020E61000000100000005000000868E1D54E2964940302C7FBE2D344C40868E1D54E29649404359F8FA5A354C409148DBF8139949404359F8FA5A354C409148DBF813994940302C7FBE2D344C40868E1D54E2964940302C7FBE2D344C40
49119	15013	51.017220000000002	51.036903000000002	56.179034000000001	56.157859000000002	Молодежная	0103000020E61000000100000005000000276BD443348249408C3045B934144C40276BD44334824940A06F0B96EA164C40E90FCD3CB9844940A06F0B96EA164C40E90FCD3CB98449408C3045B934144C40276BD443348249408C3045B934144C40
49134	14370	51.171047999999999	51.195301999999998	56.379646000000001	56.368738999999998	Новая	0103000020E61000000100000005000000EA059FE6E49549403FE1ECD6322F4C40EA059FE6E49549405307793D98304C40F46BEBA7FF9849405307793D98304C40F46BEBA7FF9849403FE1ECD6322F4C40EA059FE6E49549403FE1ECD6322F4C40
49483	14125	51.321390000000001	51.335053000000002	56.290764000000003	56.281120999999999	Центральная	0103000020E6100000010000000500000077A1B94E23A94940029CDEC5FB234C4077A1B94E23A94940556D37C137254C409EB64604E3AA4940556D37C137254C409EB64604E3AA4940029CDEC5FB234C4077A1B94E23A94940029CDEC5FB234C40
49487	14399	51.150511999999999	51.177371999999998	56.427742000000002	56.416206000000003	Новая	0103000020E61000000100000005000000E9D32AFA439349401233FB3C46354C40E9D32AFA439349401590F63FC0364C40F19C2D20B49649401590F63FC0364C40F19C2D20B49649401233FB3C46354C40E9D32AFA439349401233FB3C46354C40
49481	1986	49.447702	49.481254	58.083067999999997	58.068348	Школьная	0103000020E61000000100000005000000492D944C4EB948409E5F94A0BF084D40492D944C4EB948400CACE3F8A10A4D40DB8827BB99BD48400CACE3F8A10A4D40DB8827BB99BD48409E5F94A0BF084D40492D944C4EB948409E5F94A0BF084D40
49444	1403	49.437793999999997	49.458508999999999	58.131835000000002	58.114839000000003	Школьный	0103000020E61000000100000005000000483140A209B8484016A75A0BB30E4D40483140A209B84840EDBB22F8DF104D40F9F5436CB0BA4840EDBB22F8DF104D40F9F5436CB0BA484016A75A0BB30E4D40483140A209B8484016A75A0BB30E4D40
49116	2208	49.420743000000002	49.457610000000003	58.008184999999997	57.992694999999998	Школьная	0103000020E61000000100000005000000AE8218E8DAB548408CF337A110FF4C40AE8218E8DAB54840ACA8C1340C014D404A29E8F692BA4840ACA8C1340C014D404A29E8F692BA48408CF337A110FF4C40AE8218E8DAB548408CF337A110FF4C40
49441	1383	49.107410999999999	49.113743999999997	58.140825	58.137588999999998	Советская	0103000020E61000000100000005000000861DC6A4BF8D484009A52F849C114D40861DC6A4BF8D4840C7BAB88D06124D40E00ED4298F8E4840C7BAB88D06124D40E00ED4298F8E484009A52F849C114D40861DC6A4BF8D484009A52F849C114D40
49609	1335	49.029249	49.072592	57.882573999999998	57.863706000000001	Школьная	0103000020E610000001000000050000006938656EBE834840F3AD0FEB8DEE4C406938656EBE8348406326512FF8F04C40C2F9D4B14A8948406326512FF8F04C40C2F9D4B14A894840F3AD0FEB8DEE4C406938656EBE834840F3AD0FEB8DEE4C40
49607	1237	48.933722000000003	48.963231999999998	58.035758999999999	58.023049999999998	Школьная	0103000020E6100000010000000500000022C7D633847748401E166A4DF3024D4022C7D63384774840D2C43BC093044D40F73AA92F4B7B4840D2C43BC093044D40F73AA92F4B7B48401E166A4DF3024D4022C7D633847748401E166A4DF3024D40
49445	1226	49.596023000000002	49.633589999999998	58.043514999999999	58.027177000000002	Школьная	0103000020E61000000100000005000000F8544E7B4ACC4840091A33897A034D40F8544E7B4ACC484056F146E691054D404C89247A19D1484056F146E691054D404C89247A19D14840091A33897A034D40F8544E7B4ACC4840091A33897A034D40
49491	1158	49.254016	49.280031000000001	57.877386000000001	57.862217000000001	Советская	0103000020E610000001000000050000009354A69883A0484012876C205DEE4C409354A69883A04840F0FB372F4EF04C40DF6E490ED8A34840F0FB372F4EF04C40DF6E490ED8A3484012876C205DEE4C409354A69883A0484012876C205DEE4C40
49573	2319	49.470914	49.501772000000003	57.943803000000003	57.930138999999997	Советская	0103000020E61000000100000005000000419DF2E846BC4840F8DD74CB0EF74C40419DF2E846BC4840F06E6589CEF84C4036069D103AC04840F06E6589CEF84C4036069D103AC04840F8DD74CB0EF74C40419DF2E846BC4840F8DD74CB0EF74C40
48898	664	49.066268000000001	49.138655	58.028778000000003	57.978127999999998	Школьная	0103000020E61000000100000005000000BB6246787B884840A4A65D4C33FD4C40BB6246787B884840126C5CFFAE034D40A4367172BF914840126C5CFFAE034D40A4367172BF914840A4A65D4C33FD4C40BB6246787B884840A4A65D4C33FD4C40
48907	664	49.066268000000001	49.138655	58.028778000000003	57.978127999999998	Пионерская	0103000020E61000000100000005000000BB6246787B884840A4A65D4C33FD4C40BB6246787B884840126C5CFFAE034D40A4367172BF914840126C5CFFAE034D40A4367172BF914840A4A65D4C33FD4C40BB6246787B884840A4A65D4C33FD4C40
48716	664	49.066268000000001	49.138655	58.028778000000003	57.978127999999998	Кирова	0103000020E61000000100000005000000BB6246787B884840A4A65D4C33FD4C40BB6246787B884840126C5CFFAE034D40A4367172BF914840126C5CFFAE034D40A4367172BF914840A4A65D4C33FD4C40BB6246787B884840A4A65D4C33FD4C40
49439	2665	48.888410999999998	48.914434999999997	57.902264000000002	57.882075999999998	Попова	0103000020E610000001000000050000000D349F73B7714840124BCADDE7F04C400D349F73B7714840D82D02637DF34C40ACA8C1340C754840D82D02637DF34C40ACA8C1340C754840124BCADDE7F04C400D349F73B7714840124BCADDE7F04C40
49612	12732	52.820929999999997	52.84169	59.723624999999998	59.712367	Комсомольская	0103000020E610000001000000050000001327F73B14694A40F4DF83D72EDB4D401327F73B14694A40B4C876BE9FDC4D4064AF777FBC6B4A40B4C876BE9FDC4D4064AF777FBC6B4A40F4DF83D72EDB4D401327F73B14694A40F4DF83D72EDB4D40
49442	12881	53.443786000000003	53.464294000000002	60.061788999999997	60.053030999999997	Школьная	0103000020E610000001000000050000001A36CAFACDB84A404B5645B8C9064E401A36CAFACDB84A405320B3B3E8074E4051DD5CFC6DBB4A405320B3B3E8074E4051DD5CFC6DBB4A404B5645B8C9064E401A36CAFACDB84A404B5645B8C9064E40
49239	12305	52.226784000000002	52.269229000000003	59.758544999999998	59.720802999999997	Набережная	0103000020E61000000100000005000000C7A01342071D4A40E9EDCF4543DC4D40C7A01342071D4A40ACC5A70018E14D4041118B1876224A40ACC5A70018E14D4041118B1876224A40E9EDCF4543DC4D40C7A01342071D4A40E9EDCF4543DC4D40
49112	12305	52.226784000000002	52.269229000000003	59.758544999999998	59.720802999999997	Коммунальная	0103000020E61000000100000005000000C7A01342071D4A40E9EDCF4543DC4D40C7A01342071D4A40ACC5A70018E14D4041118B1876224A40ACC5A70018E14D4041118B1876224A40E9EDCF4543DC4D40C7A01342071D4A40E9EDCF4543DC4D40
48820	12075	52.338884999999998	52.388454000000003	59.428230999999997	59.410587	Новая	0103000020E610000001000000050000006F0D6C95602B4A40D594641D8EB44D406F0D6C95602B4A401211FE45D0B64D400D0055DCB8314A401211FE45D0B64D400D0055DCB8314A40D594641D8EB44D406F0D6C95602B4A40D594641D8EB44D40
48905	12075	52.338884999999998	52.388454000000003	59.428230999999997	59.410587	Дзержинского	0103000020E610000001000000050000006F0D6C95602B4A40D594641D8EB44D406F0D6C95602B4A401211FE45D0B64D400D0055DCB8314A401211FE45D0B64D400D0055DCB8314A40D594641D8EB44D406F0D6C95602B4A40D594641D8EB44D40
48906	12151	52.434978000000001	52.504049000000002	59.624516999999997	59.592157	Строительная	0103000020E61000000100000005000000603DEE5BAD374A407A8CF2CCCBCB4D40603DEE5BAD374A40E4654D2CF0CF4D406F4A79AD84404A40E4654D2CF0CF4D406F4A79AD84404A407A8CF2CCCBCB4D40603DEE5BAD374A407A8CF2CCCBCB4D40
48759	12151	52.434978000000001	52.504049000000002	59.624516999999997	59.592157	Пушкина	0103000020E61000000100000005000000603DEE5BAD374A407A8CF2CCCBCB4D40603DEE5BAD374A40E4654D2CF0CF4D406F4A79AD84404A40E4654D2CF0CF4D406F4A79AD84404A407A8CF2CCCBCB4D40603DEE5BAD374A407A8CF2CCCBCB4D40
49479	12662	52.896289000000003	52.918092000000001	59.901187999999998	59.886293000000002	Новая	0103000020E61000000100000005000000DD611399B9724A403DD68C0C72F14D40DD611399B9724A4019C6DD205AF34D40105CE50984754A4019C6DD205AF34D40105CE50984754A403DD68C0C72F14D40DD611399B9724A403DD68C0C72F14D40
49443	12016	52.315879000000002	52.338273999999998	59.196292999999997	59.182040000000001	Нижняя	0103000020E61000000100000005000000213F1BB96E284A402C4833164D974D40213F1BB96E284A4084B7072120994D40268BFB8F4C2B4A4084B7072120994D40268BFB8F4C2B4A402C4833164D974D40213F1BB96E284A402C4833164D974D40
49341	12782	52.771343000000002	52.800960000000003	59.542834999999997	59.531717	Октябрьская	0103000020E61000000100000005000000D07F0F5EBB624A4016DD7A4D0FC44D40D07F0F5EBB624A40E40F069E7BC54D40BCB376DB85664A40E40F069E7BC54D40BCB376DB85664A4016DD7A4D0FC44D40D07F0F5EBB624A4016DD7A4D0FC44D40
49130	12569	52.612107000000002	52.677936000000003	59.739472999999997	59.717399999999998	Падерина	0103000020E610000001000000050000008B53AD85594E4A40401361C3D3DB4D408B53AD85594E4A4033A31F0DA7DE4D40FA635A9BC6564A4033A31F0DA7DE4D40FA635A9BC6564A40401361C3D3DB4D408B53AD85594E4A40401361C3D3DB4D40
49118	12569	52.612107000000002	52.677936000000003	59.739472999999997	59.717399999999998	 Ленина	0103000020E610000001000000050000008B53AD85594E4A40401361C3D3DB4D408B53AD85594E4A4033A31F0DA7DE4D40FA635A9BC6564A4033A31F0DA7DE4D40FA635A9BC6564A40401361C3D3DB4D408B53AD85594E4A40401361C3D3DB4D40
49288	12424	52.111324000000003	52.146942000000003	59.806182999999997	59.772958000000003	Центральная	0103000020E6100000010000000500000045A165DD3F0E4A403E97A949F0E24D4045A165DD3F0E4A40ABCB290131E74D405534D6FECE124A40ABCB290131E74D405534D6FECE124A403E97A949F0E24D4045A165DD3F0E4A403E97A949F0E24D40
49330	12424	52.111324000000003	52.146942000000003	59.806182999999997	59.772958000000003	Мопра	0103000020E6100000010000000500000045A165DD3F0E4A403E97A949F0E24D4045A165DD3F0E4A40ABCB290131E74D405534D6FECE124A40ABCB290131E74D405534D6FECE124A403E97A949F0E24D4045A165DD3F0E4A403E97A949F0E24D40
48908	12424	52.111324000000003	52.146942000000003	59.806182999999997	59.772958000000003	Ленина	0103000020E6100000010000000500000045A165DD3F0E4A403E97A949F0E24D4045A165DD3F0E4A40ABCB290131E74D405534D6FECE124A40ABCB290131E74D405534D6FECE124A403E97A949F0E24D4045A165DD3F0E4A403E97A949F0E24D40
49608	11958	52.246276999999999	52.257559999999998	59.235888000000003	59.222417	Новая	0103000020E61000000100000005000000E5603601861F4A4087890629789C4D40E5603601861F4A406AC2F693319E4D40FE60E0B9F7204A406AC2F693319E4D40FE60E0B9F7204A4087890629789C4D40E5603601861F4A4087890629789C4D40
48914	544	52.188893	52.282938000000001	59.369613000000001	59.324064	Набережная	0103000020E61000000100000005000000BFB854A52D184A40CDE7DCED7AA94D40BFB854A52D184A409696917A4FAF4D40D865F84F37244A409696917A4FAF4D40D865F84F37244A40CDE7DCED7AA94D40BFB854A52D184A40CDE7DCED7AA94D40
48902	544	52.188893	52.282938000000001	59.369613000000001	59.324064	Ленина	0103000020E61000000100000005000000BFB854A52D184A40CDE7DCED7AA94D40BFB854A52D184A409696917A4FAF4D40D865F84F37244A409696917A4FAF4D40D865F84F37244A40CDE7DCED7AA94D40BFB854A52D184A40CDE7DCED7AA94D40
48756	544	52.188893	52.282938000000001	59.369613000000001	59.324064	Кирова	0103000020E61000000100000005000000BFB854A52D184A40CDE7DCED7AA94D40BFB854A52D184A409696917A4FAF4D40D865F84F37244A409696917A4FAF4D40D865F84F37244A40CDE7DCED7AA94D40BFB854A52D184A40CDE7DCED7AA94D40
49437	544	52.188893	52.282938000000001	59.369613000000001	59.324064	Индустриальная	0103000020E61000000100000005000000BFB854A52D184A40CDE7DCED7AA94D40BFB854A52D184A409696917A4FAF4D40D865F84F37244A409696917A4FAF4D40D865F84F37244A40CDE7DCED7AA94D40BFB854A52D184A40CDE7DCED7AA94D40
49482	12719	52.957554000000002	52.989229000000002	59.965449	59.952606000000003	Дзержинского	0103000020E61000000100000005000000B6132521917A4A4098FC4FFEEEF94D40B6132521917A4A405B7A34D593FB4D409DA04D0E9F7E4A405B7A34D593FB4D409DA04D0E9F7E4A4098FC4FFEEEF94D40B6132521917A4A4098FC4FFEEEF94D40
49345	11910	51.919192000000002	51.936359000000003	59.382334	59.372084999999998	Советская	0103000020E61000000100000005000000575F5D15A8F54940842A357BA0AF4D40575F5D15A8F549400E130D52F0B04D405B28999CDAF749400E130D52F0B04D405B28999CDAF74940842A357BA0AF4D40575F5D15A8F54940842A357BA0AF4D40
49606	11559	50.585912	50.641266999999999	57.781246000000003	57.761149000000003	 Молодежная	0103000020E61000000100000005000000BF2A172AFF4A49400A3197546DE14C40BF2A172AFF4A4940BF1072DEFFE34C4084807C0915524940BF1072DEFFE34C4084807C09155249400A3197546DE14C40BF2A172AFF4A49400A3197546DE14C40
49436	11495	50.974083	51.028961000000002	57.940617000000003	57.906801999999999	 Кирова	0103000020E61000000100000005000000774B72C0AE7C494044F9821612F44C40774B72C0AE7C4940E4874A2366F84C4003EE79FEB4834940E4874A2366F84C4003EE79FEB483494044F9821612F44C40774B72C0AE7C494044F9821612F44C40
49604	11441	50.548479999999998	50.594312000000002	57.979210999999999	57.964824999999998	Мира	0103000020E610000001000000050000004A41B797344649407DAEB6627FFB4C404A41B7973446494015713AC956FD4C4068CF656A124C494015713AC956FD4C4068CF656A124C49407DAEB6627FFB4C404A41B797344649407DAEB6627FFB4C40
49435	11424	50.892614999999999	50.949154999999998	57.805791999999997	57.787934999999997	Советская	0103000020E61000000100000005000000A375543541724940D72FD80DDBE44C40A37554354172494070B0373124E74C40DDEA39E97D79494070B0373124E74C40DDEA39E97D794940D72FD80DDBE44C40A375543541724940D72FD80DDBE44C40
49329	750	50.454982999999999	50.495550999999999	57.897567000000002	57.879224000000001	Заречная	0103000020E61000000100000005000000349E08E23C3A4940DDED7A698AF04C40349E08E23C3A4940037CB779E3F24C40034015376E3F4940037CB779E3F24C40034015376E3F4940DDED7A698AF04C40349E08E23C3A4940DDED7A698AF04C40
49480	11288	50.480584999999998	50.530873	57.970067	57.936317000000003	Новая	0103000020E610000001000000050000005DF92CCF833D49402CD8463CD9F74C405DF92CCF833D4940E4F6CB272BFC4C402AAA7EA5F3434940E4F6CB272BFC4C402AAA7EA5F34349402CD8463CD9F74C405DF92CCF833D49402CD8463CD9F74C40
49478	11271	51.094188000000003	51.117373999999998	57.981158000000001	57.966439000000001	Советская	0103000020E610000001000000050000007CD6355A0E8C49401B4AED45B4FB4C407CD6355A0E8C4940B91AD99596FD4C404AB3791C068F4940B91AD99596FD4C404AB3791C068F49401B4AED45B4FB4C407CD6355A0E8C49401B4AED45B4FB4C40
49433	1647	50.735768999999998	50.763168	57.940913000000002	57.932552000000001	Юбилейная	0103000020E610000001000000050000008F34B8AD2D5E4940E2E82ADD5DF74C408F34B8AD2D5E4940CDB051D66FF84C4047AD307DAF614940CDB051D66FF84C4047AD307DAF614940E2E82ADD5DF74C408F34B8AD2D5E4940E2E82ADD5DF74C40
49248	55997	50.712466999999997	50.787835999999999	57.846960000000003	57.813651	Советская	0103000020E61000000100000005000000573D601E325B4940C9AD49B725E84C40573D601E325B494095826E2F69EC4C40444E5FCFD764494095826E2F69EC4C40444E5FCFD7644940C9AD49B725E84C40573D601E325B4940C9AD49B725E84C40
49113	55997	50.712466999999997	50.787835999999999	57.846960000000003	57.813651	Коммуны	0103000020E61000000100000005000000573D601E325B4940C9AD49B725E84C40573D601E325B494095826E2F69EC4C40444E5FCFD764494095826E2F69EC4C40444E5FCFD7644940C9AD49B725E84C40573D601E325B4940C9AD49B725E84C40
49102	55997	50.712466999999997	50.787835999999999	57.846960000000003	57.813651	1 Мая	0103000020E61000000100000005000000573D601E325B4940C9AD49B725E84C40573D601E325B494095826E2F69EC4C40444E5FCFD764494095826E2F69EC4C40444E5FCFD7644940C9AD49B725E84C40573D601E325B4940C9AD49B725E84C40
49475	10763	51.002209999999998	51.015225999999998	59.011698000000003	59.002809999999997	Советская	0103000020E61000000100000005000000B1DCD26A48804940060DFD135C804D40B1DCD26A48804940DDB6EF517F814D404206F2ECF2814940DDB6EF517F814D404206F2ECF2814940060DFD135C804D40B1DCD26A48804940060DFD135C804D40
49477	10902	51.347199000000003	51.365057	59.224341000000003	59.209252999999997	Набережная	0103000020E610000001000000050000001A1A4F0471AC494081CB63CDC89A4D401A1A4F0471AC49407313B534B79C4D4083161230BAAE49407313B534B79C4D4083161230BAAE494081CB63CDC89A4D401A1A4F0471AC494081CB63CDC89A4D40
49473	10539	50.690027000000001	50.718620000000001	59.045653000000001	59.029671	Советская	0103000020E61000000100000005000000B22D03CE52584940DF516342CC834D40B22D03CE525849406EFB1EF5D7854D4032207BBDFB5B49406EFB1EF5D7854D4032207BBDFB5B4940DF516342CC834D40B22D03CE52584940DF516342CC834D40
49472	10638	50.912567000000003	50.934531	58.961074000000004	58.950321000000002	Луговая	0103000020E610000001000000050000005534D6FECE744940DCD9571EA4794D405534D6FECE74494099840B79047B4D40910C39B69E77494099840B79047B4D40910C39B69E774940DCD9571EA4794D405534D6FECE744940DCD9571EA4794D40
49432	10470	50.578591000000003	50.608640000000001	58.915291000000003	58.900931	Новая	0103000020E61000000100000005000000466117450F4A4940EE79FEB451734D40466117450F4A49405DA9674128754D40CB845FEAE74D49405DA9674128754D40CB845FEAE74D4940EE79FEB451734D40466117450F4A4940EE79FEB451734D40
49117	10755	50.808982	50.845129999999997	59.198388999999999	59.175916999999998	Энгельса	0103000020E61000000100000005000000BE86E0B88C674940BCE7C07284964D40BE86E0B88C6749406D718DCF64994D402A6F47382D6C49406D718DCF64994D402A6F47382D6C4940BCE7C07284964D40BE86E0B88C674940BCE7C07284964D40
49131	3046	51.436490999999997	51.492393	59.359144000000001	59.339257000000003	Свободы	0103000020E61000000100000005000000C9FFE4EFDEB7494034F8FBC56CAB4D40C9FFE4EFDEB74940FE463B6EF8AD4D40C1E3DBBB06BF4940FE463B6EF8AD4D40C1E3DBBB06BF494034F8FBC56CAB4D40C9FFE4EFDEB7494034F8FBC56CAB4D40
49170	10843	51.219261000000003	51.257393999999998	58.896895999999998	58.878211999999998	Кооперации	0103000020E61000000100000005000000E62494BE109C4940357A354069704D40E62494BE109C4940E4F4F57CCD724D40E3175E49F2A04940E4F4F57CCD724D40E3175E49F2A04940357A354069704D40E62494BE109C4940357A354069704D40
49438	3009	51.498438999999998	51.518048999999998	59.157499999999999	59.148705	Школьная	0103000020E61000000100000005000000850662D9CCBF494037E0F3C308934D40850662D9CCBF49405C8FC2F528944D40DD5CFC6D4FC249405C8FC2F528944D40DD5CFC6D4FC2494037E0F3C308934D40850662D9CCBF494037E0F3C308934D40
49605	10693	50.979436999999997	51.016061999999998	59.136848000000001	59.124630000000003	Советская	0103000020E6100000010000000500000005BF0D315E7D4940DD0C37E0F38F4D4005BF0D315E7D4940F2423A3C84914D40AB5AD2510E824940F2423A3C84914D40AB5AD2510E824940DD0C37E0F38F4D4005BF0D315E7D4940DD0C37E0F38F4D40
48754	10815	51.140532	51.172063000000001	59.234166000000002	59.219335999999998	Свободы	0103000020E610000001000000050000004F05DCF3FC914940F06AB933139C4D404F05DCF3FC914940E6EAC726F99D4D4003ED0E2906964940E6EAC726F99D4D4003ED0E2906964940F06AB933139C4D404F05DCF3FC914940F06AB933139C4D40
49431	10412	50.666876999999999	50.688338000000002	58.795941999999997	58.785170000000001	 Советская	0103000020E6100000010000000500000030BABC395C55494071E6577380644D4030BABC395C554940A4C16D6DE1654D400A4CA7751B584940A4C16D6DE1654D400A4CA7751B58494071E6577380644D4030BABC395C55494071E6577380644D40
49289	10554	50.842813	50.872402999999998	59.063816000000003	59.052081999999999	Школьная	0103000020E6100000010000000500000063D2DF4BE16B4940EA5A7B9FAA864D4063D2DF4BE16B4940147B681F2B884D4055F7C8E6AA6F4940147B681F2B884D4055F7C8E6AA6F4940EA5A7B9FAA864D4063D2DF4BE16B4940EA5A7B9FAA864D40
49470	10384	50.782401	50.813806	58.7562	58.742930999999999	Советская	0103000020E61000000100000005000000C9AD49B725644940A017EE5C185F4D40C9AD49B7256449401B9E5E29CB604D40F0A485CB2A6849401B9E5E29CB604D40F0A485CB2A684940A017EE5C185F4D40C9AD49B725644940A017EE5C185F4D40
48899	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Школьная	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
48901	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Строителей	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
48885	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Смирнова	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
49434	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Салтыкова	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
49204	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Победы	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
49328	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Новая	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
49469	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Мелиораторов	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
49209	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Западная	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
49129	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	Бастракова	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
48887	2909	50.788240000000002	50.887791	58.862271999999997	58.822569000000001	 Советская	0103000020E6100000010000000500000014B35E0CE56449400ADAE4F049694D4014B35E0CE5644940D520CCED5E6E4D407157AF22A3714940D520CCED5E6E4D407157AF22A37149400ADAE4F049694D4014B35E0CE56449400ADAE4F049694D40
49464	1035	52.937494999999998	52.954445999999997	58.705548999999998	58.696699000000002	Школьная	0103000020E61000000100000005000000EE940ED6FF774A40F513CE6E2D594D40EE940ED6FF774A40DD5CFC6D4F5A4D4025E659492B7A4A40DD5CFC6D4F5A4D4025E659492B7A4A40F513CE6E2D594D40EE940ED6FF774A40F513CE6E2D594D40
49592	1633	53.397576000000001	53.427841000000001	59.000149999999998	58.988120000000002	Центральная	0103000020E6100000010000000500000056D636C5E3B24A40034356B77A7E4D4056D636C5E3B24A40158C4AEA04804D40A8716F7EC3B64A40158C4AEA04804D40A8716F7EC3B64A40034356B77A7E4D4056D636C5E3B24A40034356B77A7E4D40
49324	1519	53.172279000000003	53.195590000000003	59.024942000000003	59.014690999999999	Школьная	0103000020E61000000100000005000000D064FF3C0D964A40D4450A65E1814D40D064FF3C0D964A40FF25A94C31834D405BB6D61709994A40FF25A94C31834D405BB6D61709994A40D4450A65E1814D40D064FF3C0D964A40D4450A65E1814D40
49325	2893	53.323160000000001	53.339446000000002	58.787717000000001	58.772505000000002	Центральная	0103000020E610000001000000050000000CB08F4E5DA94A408D7F9F71E1624D400CB08F4E5DA94A406AC020E9D3644D4007616EF772AB4A406AC020E9D3644D4007616EF772AB4A408D7F9F71E1624D400CB08F4E5DA94A408D7F9F71E1624D40
49474	1081	53.109665999999997	53.138691000000001	58.830399	58.820314000000003	Центральная	0103000020E61000000100000005000000D7BD1589098E4A40B939950C00694D40D7BD1589098E4A40C8D0B1834A6A4D40F19F6EA0C0914A40C8D0B1834A6A4D40F19F6EA0C0914A40B939950C00694D40D7BD1589098E4A40B939950C00694D40
49333	9233	52.994242	53.011524999999999	58.565434000000003	58.554679999999998	Советская	0103000020E61000000100000005000000A2276552437F4A4065DF15C1FF464D40A2276552437F4A40F3052D2460484D400F0BB5A679814A40F3052D2460484D400F0BB5A679814A4065DF15C1FF464D40A2276552437F4A4065DF15C1FF464D40
49468	1506	53.311166999999998	53.33146	58.773713999999998	58.760947000000002	Северная	0103000020E61000000100000005000000164CFC51D4A74A40A27E17B666614D40164CFC51D4A74A408A3A730F09634D4051F701486DAA4A408A3A730F09634D4051F701486DAA4A40A27E17B666614D40164CFC51D4A74A40A27E17B666614D40
49115	2784	53.538881000000003	53.563971000000002	58.571728	58.551209999999998	Мира	0103000020E61000000100000005000000C8B7770DFAC44A40349D9D0C8E464D40C8B7770DFAC44A408F1A13622E494D403B72A43330C84A408F1A13622E494D403B72A43330C84A40349D9D0C8E464D40C8B7770DFAC44A40349D9D0C8E464D40
49577	2559	53.165173000000003	53.191045000000003	59.150024999999999	59.139650000000003	Труда	0103000020E6100000010000000500000053978C6324954A4076711B0DE0914D4053978C6324954A408C4AEA0434934D403C889D2974984A408C4AEA0434934D403C889D2974984A4076711B0DE0914D4053978C6324954A4076711B0DE0914D40
49322	1851	53.430185000000002	53.436734000000001	58.659328000000002	58.655203999999998	Школьная	0103000020E61000000100000005000000691D554D10B74A40AC1A84B9DD534D40691D554D10B74A4026AB22DC64544D40908653E6E6B74A4026AB22DC64544D40908653E6E6B74A40AC1A84B9DD534D40691D554D10B74A40AC1A84B9DD534D40
49396	2457	53.605428000000003	53.621841000000003	58.516793999999997	58.509391000000001	Новая	0103000020E61000000100000005000000960A2AAA7ECD4A4039F06AB933414D40960A2AAA7ECD4A406F62484E26424D40EE27637C98CF4A406F62484E26424D40EE27637C98CF4A4039F06AB933414D40960A2AAA7ECD4A4039F06AB933414D40
49257	56000	53.072009000000001	53.096235999999998	59.198233000000002	59.182653999999999	Гагарина	0103000020E610000001000000050000004302469737894A40E63DCE3461974D404302469737894A4076FEEDB25F994D4053591476518C4A4076FEEDB25F994D4053591476518C4A40E63DCE3461974D404302469737894A40E63DCE3461974D40
49127	2782	53.245339000000001	53.275100000000002	59.080351	59.055084999999998	Советская	0103000020E6100000010000000500000078B7B244679F4A4005C078060D874D4078B7B244679F4A40B7990AF1488A4D4097900F7A36A34A40B7990AF1488A4D4097900F7A36A34A4005C078060D874D4078B7B244679F4A4005C078060D874D40
48886	2668	53.224983000000002	53.301825000000001	58.887256999999998	58.832486000000003	Красных Партизан	0103000020E61000000100000005000000F793313ECC9C4A405E30B8E68E6A4D40F793313ECC9C4A40D3122BA391714D40BF0E9C33A2A64A40D3122BA391714D40BF0E9C33A2A64A405E30B8E68E6A4D40F793313ECC9C4A405E30B8E68E6A4D40
49429	7009	48.245882000000002	48.286135000000002	57.836004000000003	57.813282000000001	Первомайская	0103000020E610000001000000050000006956B60F791F48407636E49F19E84C406956B60F791F4840A0A9D72D02EB4C40D89E5912A0244840A0A9D72D02EB4C40D89E5912A02448407636E49F19E84C406956B60F791F48407636E49F19E84C40
49574	8369	48.619599000000001	48.644472999999998	57.811124	57.790107999999996	Механизаторов	0103000020E6100000010000000500000031D120054F4F48406B274A4222E54C4031D120054F4F4840178046E9D2E74C40D7135D177E524840178046E9D2E74C40D7135D177E5248406B274A4222E54C4031D120054F4F48406B274A4222E54C40
49168	8348	48.492119000000002	48.545686000000003	57.870058999999998	57.851931999999998	 Советская	0103000020E61000000100000005000000C05E61C1FD3E48403B35971B0CED4C40C05E61C1FD3E4840944BE3175EEF4C404AF1F109D9454840944BE3175EEF4C404AF1F109D94548403B35971B0CED4C40C05E61C1FD3E48403B35971B0CED4C40
49428	8273	47.936169999999997	47.954225999999998	57.802210000000002	57.780901	Советская	0103000020E6100000010000000500000087BF266BD4F74740F4346090F4E34C4087BF266BD4F74740184339D1AEE64C40177FDB1324FA4740184339D1AEE64C40177FDB1324FA4740F4346090F4E34C4087BF266BD4F74740F4346090F4E34C40
49471	8236	48.270352000000003	48.289234999999998	57.770937000000004	57.755713	Октябрьская	0103000020E610000001000000050000004034F3E49A224840BE141E34BBE04C404034F3E49A22484060234910AEE24C40E5ED08A70525484060234910AEE24C40E5ED08A705254840BE141E34BBE04C404034F3E49A224840BE141E34BBE04C40
49425	8173	48.401325999999997	48.422257000000002	57.922654999999999	57.912185999999998	Труда	0103000020E610000001000000050000006A847EA65E3348403DEFC682C2F44C406A847EA65E334840D53E1D8F19F64C40E8C072840C364840D53E1D8F19F64C40E8C072840C3648403DEFC682C2F44C406A847EA65E3348403DEFC682C2F44C40
49321	2337	48.378526999999998	48.400778000000003	57.884894000000003	57.874485999999997	Советская	0103000020E6100000010000000500000095D39E9273304840A9674128EFEF4C4095D39E92733048409C36E33444F14C40687A89B14C3348409C36E33444F14C40687A89B14C334840A9674128EFEF4C4095D39E9273304840A9674128EFEF4C40
49426	8053	48.386450000000004	48.405557000000002	57.746502	57.738047000000002	Молодежная	0103000020E6100000010000000500000005C58F317731484099F4F75278DE4C4005C58F31773148400533A6608DDF4C40FAD4B14AE93348400533A6608DDF4C40FAD4B14AE933484099F4F75278DE4C4005C58F317731484099F4F75278DE4C40
49323	6954	48.053758999999999	48.069910999999998	57.772502000000003	57.764975	Свободы	0103000020E61000000100000005000000CE6E2D93E1064840F9A067B3EAE14C40CE6E2D93E10648401C0C7558E1E24C40B950F9D7F20848401C0C7558E1E24C40B950F9D7F2084840F9A067B3EAE14C40CE6E2D93E1064840F9A067B3EAE14C40
49467	7982	48.132389000000003	48.172930000000001	57.676243999999997	57.667369000000001	Школьная	0103000020E61000000100000005000000D2AC6C1FF21048409FAEEE586CD54C40D2AC6C1FF2104840E00ED4298FD64C40A73FFB9122164840E00ED4298FD64C40A73FFB91221648409FAEEE586CD54C40D2AC6C1FF21048409FAEEE586CD54C40
49466	7924	48.462752999999999	48.489550000000001	57.660369000000003	57.652472000000003	Новая	0103000020E610000001000000050000001D90847D3B3B484022C7D63384D34C401D90847D3B3B48406825ADF886D44C40DFE00B93A93E48406825ADF886D44C40DFE00B93A93E484022C7D63384D34C401D90847D3B3B484022C7D63384D34C40
48796	6910	48.280673999999998	48.337069999999997	57.692137000000002	57.665630999999998	Советская	0103000020E61000000100000005000000336B2920ED234840151A886533D54C40336B2920ED23484000ADF9F197D84C403A3B191C252B484000ADF9F197D84C403A3B191C252B4840151A886533D54C40336B2920ED234840151A886533D54C40
79383	61558	157.72459900000001	190.343693	71.612297999999996	61.808397999999997	Гагарина	0103000020E61000000100000005000000DCF63DEA2FB763406E13EE9579E74E40DCF63DEA2FB76340FF59F3E32FE75140A75B7688FFCA6740FF59F3E32FE75140A75B7688FFCA67406E13EE9579E74E40DCF63DEA2FB763406E13EE9579E74E40
45978	55649	177.15205	178.20670799999999	64.962370000000007	64.511729000000003	Советская	0103000020E610000001000000050000006B2BF697DD2466408CDAFD2AC02050406B2BF697DD246640B3295778973D50404A7A185A9D466640B3295778973D50404A7A185A9D4666408CDAFD2AC02050406B2BF697DD2466408CDAFD2AC0205040
45974	55649	177.15205	178.20670799999999	64.962370000000007	64.511729000000003	Портовая	0103000020E610000001000000050000006B2BF697DD2466408CDAFD2AC02050406B2BF697DD246640B3295778973D50404A7A185A9D466640B3295778973D50404A7A185A9D4666408CDAFD2AC02050406B2BF697DD2466408CDAFD2AC0205040
45972	55648	169.84854899999999	170.90320700000001	69.879572999999993	69.513324999999995	Пугачева	0103000020E61000000100000005000000B6813B50273B654007CE1951DA605140B6813B50273B6540745C8DEC4A78514096D05D12E75C6540745C8DEC4A78514096D05D12E75C654007CE1951DA605140B6813B50273B654007CE1951DA605140
45967	55646	165.91016400000001	166.964822	68.252239000000003	67.857735000000005	Ленина	0103000020E61000000100000005000000E4BF401020BD64409D685721E5F65040E4BF401020BD6440A6F10BAF24105140C30E63D2DFDE6440A6F10BAF24105140C30E63D2DFDE64409D685721E5F65040E4BF401020BD64409D685721E5F65040
45281	21786	176.95003700000001	178.004695	64.961044999999999	64.510382000000007	Строителей	0103000020E61000000100000005000000AE9FFEB3661E6640E59D4319AA205040AE9FFEB3661E6640FF3EE3C2813D50408DEE207626406640FF3EE3C2813D50408DEE207626406640E59D4319AA205040AE9FFEB3661E6640E59D4319AA205040
45285	21786	176.95003700000001	178.004695	64.961044999999999	64.510382000000007	Отке	0103000020E61000000100000005000000AE9FFEB3661E6640E59D4319AA205040AE9FFEB3661E6640FF3EE3C2813D50408DEE207626406640FF3EE3C2813D50408DEE207626406640E59D4319AA205040AE9FFEB3661E6640E59D4319AA205040
45284	21786	176.95003700000001	178.004695	64.961044999999999	64.510382000000007	Ленина	0103000020E61000000100000005000000AE9FFEB3661E6640E59D4319AA205040AE9FFEB3661E6640FF3EE3C2813D50408DEE207626406640FF3EE3C2813D50408DEE207626406640E59D4319AA205040AE9FFEB3661E6640E59D4319AA205040
45980	21786	176.95003700000001	178.004695	64.961044999999999	64.510382000000007	Колхозная	0103000020E61000000100000005000000AE9FFEB3661E6640E59D4319AA205040AE9FFEB3661E6640FF3EE3C2813D50408DEE207626406640FF3EE3C2813D50408DEE207626406640E59D4319AA205040AE9FFEB3661E6640E59D4319AA205040
45968	21786	176.95003700000001	178.004695	64.961044999999999	64.510382000000007	 Мира	0103000020E61000000100000005000000AE9FFEB3661E6640E59D4319AA205040AE9FFEB3661E6640FF3EE3C2813D50408DEE207626406640FF3EE3C2813D50408DEE207626406640E59D4319AA205040AE9FFEB3661E6640E59D4319AA205040
45323	13399	184.06794600000001	192.50544400000001	67.200055000000006	63.695833	Ленина	0103000020E610000001000000050000009CFC169D2C026740213D450E11D94F409CFC169D2C026740AF997CB3CDCC5040B43EE5982C106840AF997CB3CDCC5040B43EE5982C106840213D450E11D94F409CFC169D2C026740213D450E11D94F40
45312	23419	184.76483200000001	193.20232999999999	67.274854000000005	63.781399	Советская	0103000020E61000000100000005000000E65DF580791867404510E7E104E44F40E65DF58079186740304B3B3597D15040FD9FC37C79266840304B3B3597D15040FD9FC37C792668404510E7E104E44F40E65DF580791867404510E7E104E44F40
45971	24099	170.01742300000001	171.072081	70.100233000000003	69.737840000000006	Заозерная	0103000020E6100000010000000500000058E6ADBA8E406540906B43C5386F514058E6ADBA8E406540B83EAC376A8651403735D07C4E626540B83EAC376A8651403735D07C4E626540906B43C5386F514058E6ADBA8E406540906B43C5386F5140
45295	23934	169.84854899999999	170.90320700000001	69.879572999999993	69.513324999999995	Советская	0103000020E61000000100000005000000B6813B50273B654007CE1951DA605140B6813B50273B6540745C8DEC4A78514096D05D12E75C6540745C8DEC4A78514096D05D12E75C654007CE1951DA605140B6813B50273B654007CE1951DA605140
45278	23934	169.84854899999999	170.90320700000001	69.879572999999993	69.513324999999995	Полярная 	0103000020E61000000100000005000000B6813B50273B654007CE1951DA605140B6813B50273B6540745C8DEC4A78514096D05D12E75C6540745C8DEC4A78514096D05D12E75C654007CE1951DA605140B6813B50273B654007CE1951DA605140
45275	55367	176.06889699999999	185.40589700000001	68.312197999999995	64.948198000000005	Советская	0103000020E610000001000000050000005C397B67340266407D08AA46AF3C50405C397B67340266401AF8510DFB1351406D91B41BFD2C67401AF8510DFB1351406D91B41BFD2C67407D08AA46AF3C50405C397B67340266407D08AA46AF3C5040
45973	52771	176.89049700000001	185.32799499999999	68.638737000000006	65.342815000000002	Северная	0103000020E61000000100000005000000F58590F37E1C6640026553AEF0555040F58590F37E1C6640B16F2711E12851400CC85EEF7E2A6740B16F2711E12851400CC85EEF7E2A6740026553AEF0555040F58590F37E1C6640026553AEF0555040
45975	23159	165.62069099999999	166.67534900000001	68.041569999999993	67.643431000000007	Кавракая	0103000020E610000001000000050000007D3D5FB3DCB36440E38E37F92DE950407D3D5FB3DCB36440A99F3715A90251405D8C81759CD56440A99F3715A90251405D8C81759CD56440E38E37F92DE950407D3D5FB3DCB36440E38E37F92DE95040
45259	22792	165.91016400000001	166.964822	68.252239000000003	67.857735000000005	Ленина	0103000020E61000000100000005000000E4BF401020BD64409D685721E5F65040E4BF401020BD6440A6F10BAF24105140C30E63D2DFDE6440A6F10BAF24105140C30E63D2DFDE64409D685721E5F65040E4BF401020BD64409D685721E5F65040
45305	22792	165.91016400000001	166.964822	68.252239000000003	67.857735000000005	Березина	0103000020E61000000100000005000000E4BF401020BD64409D685721E5F65040E4BF401020BD6440A6F10BAF24105140C30E63D2DFDE6440A6F10BAF24105140C30E63D2DFDE64409D685721E5F65040E4BF401020BD64409D685721E5F65040
45257	22792	165.91016400000001	166.964822	68.252239000000003	67.857735000000005	Арктика	0103000020E61000000100000005000000E4BF401020BD64409D685721E5F65040E4BF401020BD6440A6F10BAF24105140C30E63D2DFDE6440A6F10BAF24105140C30E63D2DFDE64409D685721E5F65040E4BF401020BD64409D685721E5F65040
45298	55373	165.305194	179.75699399999999	68.272299000000004	62.253399000000002	Мандрикова	0103000020E61000000100000005000000EF1D3526C4A9644068EBE0606F204F40EF1D3526C4A96440F2EEC8586D11514095287B4B39786640F2EEC8586D11514095287B4B3978664068EBE0606F204F40EF1D3526C4A9644068EBE0606F204F40
45969	55647	177.15205	178.20670799999999	64.962370000000007	64.511729000000003	Первомайская	0103000020E610000001000000050000006B2BF697DD2466408CDAFD2AC02050406B2BF697DD246640B3295778973D50404A7A185A9D466640B3295778973D50404A7A185A9D4666408CDAFD2AC02050406B2BF697DD2466408CDAFD2AC0205040
45318	52702	169.88493099999999	170.93958900000001	64.899139000000005	64.447434000000001	Березина	0103000020E61000000100000005000000EE06D15A513C6540954737C2A21C5040EE06D15A513C6540B9E34D7E8B395040CE55F31C115E6540B9E34D7E8B395040CE55F31C115E6540954737C2A21C5040EE06D15A513C6540954737C2A21C5040
45981	55651	165.305194	179.75699399999999	68.272299000000004	62.253399000000002	Центральная	0103000020E61000000100000005000000EF1D3526C4A9644068EBE0606F204F40EF1D3526C4A96440F2EEC8586D11514095287B4B39786640F2EEC8586D11514095287B4B3978664068EBE0606F204F40EF1D3526C4A9644068EBE0606F204F40
22769	50556	135.018674	135.021252	48.546545000000002	48.543002000000001	Речная	0103000020E61000000100000005000000236937FA98E06040D0D4EB1681454840236937FA98E060406B65C22FF5454840309FAC18AEE060406B65C22FF5454840309FAC18AEE06040D0D4EB1681454840236937FA98E06040D0D4EB1681454840
2077	718	135.038464	135.049567	48.539732999999998	48.533427000000003	улица профессора Даниловского	0103000020E6100000010000000500000059C2DA183BE16040D6E6FF554744484059C2DA183BE1604036C98FF815454840BF7E880D96E1604036C98FF815454840BF7E880D96E16040D6E6FF554744484059C2DA183BE16040D6E6FF5547444840
664	718	135.102981	135.11301499999999	48.459961	48.453226999999998	улица Юности	0103000020E610000001000000050000008063CF9E4BE360400455A357033A48408063CF9E4BE36040BD378600E03A4840A31EA2D19DE36040BD378600E03A4840A31EA2D19DE360400455A357033A48408063CF9E4BE360400455A357033A4840
1482	718	135.14245299999999	135.146387	48.445601000000003	48.442965999999998	улица Шмаковская	0103000020E61000000100000005000000F20698F98EE46040B69E211CB3384840F20698F98EE460404F081D7409394840E831CA33AFE460404F081D7409394840E831CA33AFE46040B69E211CB3384840F20698F98EE46040B69E211CB3384840
218	718	135.132643	135.13498799999999	48.435136	48.426228000000002	улица Школьная	0103000020E610000001000000050000006361889C3EE46040DB519CA38E3648406361889C3EE46040F8A75489B237484047AB5AD251E46040F8A75489B237484047AB5AD251E46040DB519CA38E3648406361889C3EE46040DB519CA38E364840
2644	718	135.06341	135.08678399999999	48.483238999999998	48.466479	улица Шеронова	0103000020E61000000100000005000000A987687407E26040A9A27895B53B4840A987687407E260406C938AC6DA3D48401D3A3DEFC6E260406C938AC6DA3D48401D3A3DEFC6E26040A9A27895B53B4840A987687407E26040A9A27895B53B4840
1925	718	135.05148	135.07067699999999	48.520693999999999	48.510488000000002	улица Шелеста	0103000020E61000000100000005000000BD8C62B9A5E160400F80B8AB57414840BD8C62B9A5E16040999CDA19A64248408A7269FC42E26040999CDA19A64248408A7269FC42E260400F80B8AB57414840BD8C62B9A5E160400F80B8AB57414840
2406	718	135.08770000000001	135.09060199999999	48.491205000000001	48.489133000000002	улица Шабадина	0103000020E610000001000000050000007FFB3A70CEE260407B32FFE89B3E48407FFB3A70CEE26040DB5031CEDF3E4840785E2A36E6E26040DB5031CEDF3E4840785E2A36E6E260407B32FFE89B3E48407FFB3A70CEE260407B32FFE89B3E4840
1652	718	135.03411600000001	135.037655	48.510596	48.505372999999999	улица Чкалова	0103000020E61000000100000005000000A708707A17E1604005A4FD0FB0404840A708707A17E16040F5BBB0355B414840FD30427834E16040F5BBB0355B414840FD30427834E1604005A4FD0FB0404840A708707A17E1604005A4FD0FB0404840
513	718	135.06919500000001	135.07057800000001	48.507401999999999	48.504328000000001	улица Чехова	0103000020E610000001000000050000007FC16ED836E26040823AE5D18D4048407FC16ED836E2604066F6798CF2404840263ACB2C42E2604066F6798CF2404840263ACB2C42E26040823AE5D18D4048407FC16ED836E26040823AE5D18D404840
1202	718	135.113733	135.121881	48.398150000000001	48.393417999999997	улица Черняховского	0103000020E610000001000000050000003B6F63B3A3E3604030D461855B3248403B6F63B3A3E3604082734694F63248401FA0FB72E6E3604082734694F63248401FA0FB72E6E3604030D461855B3248403B6F63B3A3E3604030D461855B324840
1030	718	135.103466	135.10656499999999	48.404203000000003	48.395422000000003	улица Фурманова	0103000020E61000000100000005000000EFC7ED974FE36040390F27309D324840EFC7ED974FE36040F9F884ECBC334840BEBC00FB68E36040F9F884ECBC334840BEBC00FB68E36040390F27309D324840EFC7ED974FE36040390F27309D324840
1782	718	135.056026	135.07129699999999	48.481268	48.469847999999999	улица Фрунзе	0103000020E6100000010000000500000039B709F7CAE16040A60BB1FA233C484039B709F7CAE16040404E98309A3D4840B169A51048E26040404E98309A3D4840B169A51048E26040A60BB1FA233C484039B709F7CAE16040A60BB1FA233C4840
1946	718	135.04176000000001	135.049845	48.518121999999998	48.515763999999997	улица Фоломеева	0103000020E61000000100000005000000FE48111956E16040213A048E04424840FE48111956E1604047AB5AD251424840D09B8A5498E1604047AB5AD251424840D09B8A5498E16040213A048E04424840FE48111956E16040213A048E04424840
842	718	135.10541499999999	135.12186299999999	48.438124000000002	48.433957999999997	улица Флегонтова	0103000020E610000001000000050000004030478F5FE3604035EB8CEF8B3748404030478F5FE36040DECB7D7214384840F5F23B4DE6E36040DECB7D7214384840F5F23B4DE6E3604035EB8CEF8B3748404030478F5FE3604035EB8CEF8B374840
901	718	135.109601	135.11735400000001	48.407654999999998	48.406140999999998	улица Ургальская	0103000020E610000001000000050000007CD3F4D981E360404948A46DFC3348407CD3F4D981E360408386FE092E344840C1012D5DC1E360408386FE092E344840C1012D5DC1E360404948A46DFC3348407CD3F4D981E360404948A46DFC334840
1561	718	135.00213600000001	135.041608	48.368380000000002	48.355173999999998	улица Ульяновская	0103000020E610000001000000050000009E44847F11E06040DB317557762D48409E44847F11E0604010406A13272F484010E84CDA54E1604010406A13272F484010E84CDA54E16040DB317557762D48409E44847F11E06040DB317557762D4840
2135	718	135.01606000000001	135.038464	48.539202000000003	48.527597999999998	улица Уборевича	0103000020E61000000100000005000000C3D8429083E06040AEB7CD5488434840C3D8429083E060400AF835920445484059C2DA183BE160400AF835920445484059C2DA183BE16040AEB7CD5488434840C3D8429083E06040AEB7CD5488434840
2052	718	135.01815300000001	135.03638799999999	48.544671999999998	48.53783	улица Трехгорная	0103000020E6100000010000000500000061AA99B594E0604062670A9DD744484061AA99B594E060400186E5CFB7454840F0BE2A172AE160400186E5CFB7454840F0BE2A172AE1604062670A9DD744484061AA99B594E0604062670A9DD7444840
1458	718	135.03553500000001	135.05213599999999	48.556379	48.484684000000001	улица Тихоокеанская	0103000020E61000000100000005000000A1DB4B1A23E160407E7214200A3E4840A1DB4B1A23E160403197546D3747484037DE1D19ABE160403197546D3747484037DE1D19ABE160407E7214200A3E4840A1DB4B1A23E160407E7214200A3E4840
1464	718	135.08541	135.09018900000001	48.373043000000003	48.360711999999999	улица Ташкентская	0103000020E610000001000000050000000B98C0ADBBE260402BA391CF2B2E48400B98C0ADBBE2604039807EDFBF2F4840B0AE0AD4E2E2604039807EDFBF2F4840B0AE0AD4E2E260402BA391CF2B2E48400B98C0ADBBE260402BA391CF2B2E4840
934	718	135.10283699999999	135.10846900000001	48.402552999999997	48.401612999999998	улица Сурикова	0103000020E6100000010000000500000033FAD1704AE360400053060E6833484033FAD1704AE360400EF450DB8633484028F4FA9378E360400EF450DB8633484028F4FA9378E360400053060E6833484033FAD1704AE360400053060E68334840
1123	718	135.09481500000001	135.16102100000001	48.399172999999998	48.392060000000001	улица Суворова	0103000020E61000000100000005000000738577B908E36040EE08A7052F324840738577B908E360401D39D21918334840041F831527E560401D39D21918334840041F831527E56040EE08A7052F324840738577B908E36040EE08A7052F324840
1393	718	135.09107800000001	135.10740000000001	48.377082999999999	48.368769	улица Строительная	0103000020E6100000010000000500000053EC681CEAE26040AA6395D2332F484053EC681CEAE260405470784144304840E5F21FD26FE360405470784144304840E5F21FD26FE36040AA6395D2332F484053EC681CEAE26040AA6395D2332F4840
1042	718	135.089991	135.10167799999999	48.406756999999999	48.375723999999998	улица Союзная	0103000020E61000000100000005000000E63DCE34E1E2604041295AB917304840E63DCE34E1E26040A435069D10344840209738F240E36040A435069D10344840209738F240E3604041295AB917304840E63DCE34E1E2604041295AB917304840
242	718	135.04678200000001	135.057095	48.491784000000003	48.483626999999998	улица Советская	0103000020E610000001000000050000005401F73C7FE16040363B527DE73D48405401F73C7FE16040195932C7F23E48407CB8E4B8D3E16040195932C7F23E48407CB8E4B8D3E16040363B527DE73D48405401F73C7FE16040363B527DE73D4840
561	718	135.08024399999999	135.086038	48.474890000000002	48.470416	улица Слободская	0103000020E610000001000000050000006876DD5B91E26040F0C16B97363C48406876DD5B91E2604046990D32C93C4840D386C3D2C0E2604046990D32C93C4840D386C3D2C0E26040F0C16B97363C48406876DD5B91E26040F0C16B97363C4840
6638	718	135.06764100000001	135.08667600000001	48.506352	48.502679999999998	улица Сигнальная	0103000020E61000000100000005000000CD5B751D2AE26040382D78D157404840CD5B751D2AE26040D1217024D0404840242BBF0CC6E26040D1217024D0404840242BBF0CC6E26040382D78D157404840CD5B751D2AE26040382D78D157404840
466	718	135.04936900000001	135.066078	48.498716000000002	48.477195000000002	улица Серышева	0103000020E61000000100000005000000F60D4C6E94E160404968CBB9143D4840F60D4C6E94E16040F8FE06EDD53F4840861F9C4F1DE26040F8FE06EDD53F4840861F9C4F1DE260404968CBB9143D4840F60D4C6E94E160404968CBB9143D4840
15461	718	135.108442	135.121621	48.562126999999997	48.554983999999997	улица Сергеевская	0103000020E6100000010000000500000069705B5B78E36040D1E638B70947484069705B5B78E360406B990CC7F34748403830B951E4E360406B990CC7F34748403830B951E4E36040D1E638B70947484069705B5B78E36040D1E638B709474840
359	718	135.09210200000001	135.102217	48.503098000000001	48.497433000000001	улица Свердлова	0103000020E61000000100000005000000AEBCE47FF2E26040C07971E2AB3F4840AEBCE47FF2E260406D57E883654048400C03965C45E360406D57E883654048400C03965C45E36040C07971E2AB3F4840AEBCE47FF2E26040C07971E2AB3F4840
2157	718	135.02638999999999	135.02967799999999	48.531905999999999	48.522114000000002	улица Санаторная	0103000020E61000000100000005000000205ED72FD8E060405264ADA1D4424840205ED72FD8E06040E945ED7E1544484024ED461FF3E06040E945ED7E1544484024ED461FF3E060405264ADA1D4424840205ED72FD8E060405264ADA1D4424840
2245	718	135.03519399999999	135.04447300000001	48.577961999999999	48.555646000000003	улица Руднева	0103000020E610000001000000050000007EE02A4F20E160409D137B681F4748407EE02A4F20E16040562AA8A8FA494840C311A4526CE16040562AA8A8FA494840C311A4526CE160409D137B681F4748407EE02A4F20E160409D137B681F474840
1232	718	135.11016699999999	135.12264500000001	48.389755999999998	48.387991	улица Рокоссовского	0103000020E6100000010000000500000026C3F17C86E36040381268B0A931484026C3F17C86E36040BBB54C86E3314840930035B5ECE36040BBB54C86E3314840930035B5ECE36040381268B0A931484026C3F17C86E36040381268B0A9314840
631	718	135.08885900000001	135.09316200000001	48.457636999999998	48.454248999999997	улица Ремесленная	0103000020E61000000100000005000000925ED4EED7E26040CF9ECBD4243A4840925ED4EED7E26040433866D9933A48405CE7DF2EFBE26040433866D9933A48405CE7DF2EFBE26040CF9ECBD4243A4840925ED4EED7E26040CF9ECBD4243A4840
2806	718	135.066114	135.08045100000001	48.485424999999999	48.474936999999997	улица Пушкина	0103000020E61000000100000005000000D9791B9B1DE26040865451BCCA3C4840D9791B9B1DE2604095D40968223E4840C7BDF90D93E2604095D40968223E4840C7BDF90D93E26040865451BCCA3C4840D9791B9B1DE26040865451BCCA3C4840
759	718	135.11028400000001	135.11165800000001	48.447932000000002	48.447341000000002	улица Путевая	0103000020E61000000100000005000000B5A84F7287E3604079944A7842394840B5A84F7287E360407B6AF5D555394840C74ACCB392E360407B6AF5D555394840C74ACCB392E3604079944A7842394840B5A84F7287E3604079944A7842394840
2647	718	135.08258000000001	135.08929000000001	48.480742999999997	48.475892999999999	улица Постышева	0103000020E61000000100000005000000B8E9CF7EA4E260409AB2D30FEA3C4840B8E9CF7EA4E26040F56393FC883D484084BBB376DBE26040F56393FC883D484084BBB376DBE260409AB2D30FEA3C4840B8E9CF7EA4E260409AB2D30FEA3C4840
2311	718	135.031645	135.04465300000001	48.580561000000003	48.577931999999997	улица Портовая	0103000020E610000001000000050000009F02603C03E16040EBA7FFACF94948409F02603C03E16040A22AA6D24F4A484063D520CC6DE16040A22AA6D24F4A484063D520CC6DE16040EBA7FFACF94948409F02603C03E16040EBA7FFACF9494840
7463	718	135.024665	135.07599500000001	48.563380000000002	48.556050999999997	улица Победы	0103000020E61000000100000005000000630B410ECAE060403CF4DDAD2C474840630B410ECAE06040399CF9D51C4848401BF5108D6EE26040399CF9D51C4848401BF5108D6EE260403CF4DDAD2C474840630B410ECAE060403CF4DDAD2C474840
1478	718	135.08277699999999	135.094222	48.358012000000002	48.346229000000001	улица Пассажирская	0103000020E610000001000000050000008D7BF31BA6E26040A1F65B3B512C48408D7BF31BA6E26040ACC95356D32D48400A12DBDD03E36040ACC95356D32D48400A12DBDD03E36040A1F65B3B512C48408D7BF31BA6E26040A1F65B3B512C4840
2748	718	135.07155700000001	135.077459	48.491193000000003	48.486750999999998	улица Панькова	0103000020E6100000010000000500000099D9E7314AE26040CC2555DB4D3E484099D9E7314AE2604017838769DF3E4840FDF84B8B7AE2604017838769DF3E4840FDF84B8B7AE26040CC2555DB4D3E484099D9E7314AE26040CC2555DB4D3E4840
1081	718	135.11056199999999	135.12550100000001	48.385347000000003	48.384065999999997	улица Панфиловцев	0103000020E61000000100000005000000C5C551B989E36040B5C01E1329314840C5C551B989E360404D4EED0C53314840B153AC1A04E460404D4EED0C53314840B153AC1A04E46040B5C01E1329314840C5C551B989E36040B5C01E1329314840
1707	718	135.03980200000001	135.048821	48.496692000000003	48.492513000000002	улица Орджоникидзе	0103000020E61000000100000005000000180AD80E46E160406CED7DAA0A3F4840180AD80E46E16040A9177C9A933F484075CB0EF18FE16040A9177C9A933F484075CB0EF18FE160406CED7DAA0A3F4840180AD80E46E160406CED7DAA0A3F4840
205	718	135.13863499999999	135.148157	48.428482000000002	48.425545999999997	улица Огородная	0103000020E6100000010000000500000097E2AAB26FE46040C878944A7836484097E2AAB26FE460405C76887FD83648408DB5BFB3BDE460405C76887FD83648408DB5BFB3BDE46040C878944A7836484097E2AAB26FE46040C878944A78364840
2489	718	135.08005600000001	135.08936199999999	48.483006000000003	48.477488000000001	улица Мухина	0103000020E6100000010000000500000028BB99D18FE26040C11DA8531E3D484028BB99D18FE26040CAE2FE23D33D48402A70B20DDCE26040CAE2FE23D33D48402A70B20DDCE26040C11DA8531E3D484028BB99D18FE26040C11DA8531E3D4840
2689	718	135.057571	135.070875	48.479739000000002	48.472465	улица Муравьева-Амурского	0103000020E610000001000000050000005646239FD7E1604098C0ADBB793C48405646239FD7E16040D1CE6916683D484054E3A59B44E26040D1CE6916683D484054E3A59B44E2604098C0ADBB793C48405646239FD7E1604098C0ADBB793C4840
2811	718	135.07703699999999	135.08125000000001	48.489927000000002	48.487085	улица Московская	0103000020E610000001000000050000009F724C1677E26040A3AF20CD583E48409F724C1677E26040B5368DEDB53E48409A99999999E26040B5368DEDB53E48409A99999999E26040A3AF20CD583E48409F724C1677E26040A3AF20CD583E4840
1377	718	135.09464399999999	135.09812099999999	48.385370999999999	48.371653999999999	улица Монтажная	0103000020E610000001000000050000006798DA5207E36040BBB6B75B922F48406798DA5207E36040D5E940D653314840A0C1A6CE23E36040D5E940D653314840A0C1A6CE23E36040BBB6B75B922F48406798DA5207E36040BBB6B75B922F4840
444	718	135.14350400000001	135.14603700000001	48.513185999999997	48.511221999999997	улица Мирная	0103000020E610000001000000050000000C5BB39597E46040737FF5B86F4148400C5BB39597E46040ED612F14B04148403160C955ACE46040ED612F14B04148403160C955ACE46040737FF5B86F4148400C5BB39597E46040737FF5B86F414840
1514	718	135.03936200000001	135.049261	48.367032999999999	48.360436999999997	улица Мате Залки	0103000020E6100000010000000500000091D6187442E1604059A2B3CC222E484091D6187442E16040C1C6F5EFFA2E4840FCFECD8B93E16040C1C6F5EFFA2E4840FCFECD8B93E1604059A2B3CC222E484091D6187442E1604059A2B3CC222E4840
1318	718	135.120282	135.12439599999999	48.393465999999997	48.380744999999997	улица Малиновского	0103000020E610000001000000050000008509A359D9E36040C98E8D40BC3048408509A359D9E36040410B09185D3248401AF8510DFBE36040410B09185D3248401AF8510DFBE36040C98E8D40BC3048408509A359D9E36040C98E8D40BC304840
2242	718	135.027827	135.03746599999999	48.56521	48.560273000000002	улица Майская	0103000020E6100000010000000500000044DE72F5E3E0604079EA9106B747484044DE72F5E3E06040A3AF20CD58484840C896E5EB32E16040A3AF20CD58484840C896E5EB32E1604079EA9106B747484044DE72F5E3E0604079EA9106B7474840
1890	718	135.05889099999999	135.07445899999999	48.492083000000001	48.482821000000001	улица Льва Толстого	0103000020E61000000100000005000000EBE0606FE2E1604038691A14CD3D4840EBE0606FE2E1604073F56393FC3E4840923CD7F761E2604073F56393FC3E4840923CD7F761E2604038691A14CD3D4840EBE0606FE2E1604038691A14CD3D4840
2610	718	135.08894000000001	135.095471	48.483370999999998	48.475546999999999	улица Лермонтова	0103000020E61000000100000005000000CDE9B298D8E26040FF5A5EB9DE3C4840CDE9B298D8E26040DB6AD619DF3D4840EDD632190EE36040DB6AD619DF3D4840EDD632190EE36040FF5A5EB9DE3C4840CDE9B298D8E26040FF5A5EB9DE3C4840
2423	718	135.06493699999999	135.126993	48.496823999999997	48.476728999999999	улица Ленинградская	0103000020E610000001000000050000009C69C2F613E260400307B474053D48409C69C2F613E2604017EFC7ED973F484045BA9F5310E4604017EFC7ED973F484045BA9F5310E460400307B474053D48409C69C2F613E260400307B474053D4840
2433	718	135.06587099999999	135.09357499999999	48.483561999999999	48.467005	улица Ленина	0103000020E6100000010000000500000027D87F9D1BE26040C408E1D1C63B484027D87F9D1BE260404FCB0F5CE53D48402497FF90FEE260404FCB0F5CE53D48402497FF90FEE26040C408E1D1C63B484027D87F9D1BE26040C408E1D1C63B4840
3226	718	135.07719	135.09385399999999	48.509652000000003	48.499546000000002	улица Лазо	0103000020E6100000010000000500000081B2295778E260407F6C921FF13F484081B2295778E26040A62BD8463C41484029931ADA00E36040A62BD8463C41484029931ADA00E360407F6C921FF13F484081B2295778E260407F6C921FF13F4840
7625	718	135.101876	135.11102	48.446516000000003	48.442977999999997	улица Кубяка	0103000020E61000000100000005000000EA07759142E360407A6CCB80B3384840EA07759142E360400492B06F2739484076A6D0798DE360400492B06F2739484076A6D0798DE360407A6CCB80B3384840EA07759142E360407A6CCB80B3384840
2273	718	135.04453599999999	135.04593800000001	48.574725000000001	48.564827999999999	улица Краснофлотская	0103000020E61000000100000005000000D4EFC2D66CE16040BBEEAD484C484840D4EFC2D66CE16040C898BB969049484099F4F75278E16040C898BB969049484099F4F75278E16040BBEEAD484C484840D4EFC2D66CE16040BBEEAD484C484840
787	718	135.07308499999999	135.112799	48.446516000000003	48.342660000000002	улица Краснореченская	0103000020E61000000100000005000000809A5AB656E26040DDD26A48DC2B4840809A5AB656E260400492B06F27394840B000A60C9CE360400492B06F27394840B000A60C9CE36040DDD26A48DC2B4840809A5AB656E26040DDD26A48DC2B4840
383	718	135.10184899999999	135.11385899999999	48.524560999999999	48.503312999999999	улица Краснодарская	0103000020E610000001000000050000002B84D55842E360406953758F6C4048402B84D55842E36040E7E099D0244348405E2BA1BBA4E36040E7E099D0244348405E2BA1BBA4E360406953758F6C4048402B84D55842E360406953758F6C404840
2771	718	135.07044400000001	135.07134199999999	48.489085000000003	48.487586999999998	улица Красина	0103000020E610000001000000050000006286C61341E26040357A3540693E48406286C61341E260406AFB57569A3E4840999A046F48E260406AFB57569A3E4840999A046F48E26040357A3540693E48406286C61341E26040357A3540693E4840
4813	718	135.122995	135.13172700000001	48.479028999999997	48.478408000000002	улица Костромская	0103000020E610000001000000050000004AD23593EFE3604088122D793C3D48404AD23593EFE36040F46A80D2503D484002A08A1B37E46040F46A80D2503D484002A08A1B37E4604088122D793C3D48404AD23593EFE3604088122D793C3D4840
685	718	135.11545799999999	135.11797300000001	48.461114000000002	48.454028000000001	улица Космическая	0103000020E61000000100000005000000F8C1F9D4B1E36040F1BBE9961D3A4840F8C1F9D4B1E3604027DD96C8053B4840F419506FC6E3604027DD96C8053B4840F419506FC6E36040F1BBE9961D3A4840F8C1F9D4B1E36040F1BBE9961D3A4840
697	718	135.10794799999999	135.11224200000001	48.456549000000003	48.453764999999997	улица Королева	0103000020E6100000010000000500000065355D4F74E36040E388B5F8143A484065355D4F74E36040C1029832703A48409BE7887C97E36040C1029832703A48409BE7887C97E36040E388B5F8143A484065355D4F74E36040E388B5F8143A4840
186	718	135.12853799999999	135.13199599999999	48.442307999999997	48.430352999999997	улица Клубная	0103000020E610000001000000050000006249B9FB1CE46040245E9ECE153748406249B9FB1CE460402C616D8C9D3848407DE6AC4F39E460402C616D8C9D3848407DE6AC4F39E46040245E9ECE153748406249B9FB1CE46040245E9ECE15374840
298	718	135.07026400000001	135.14374599999999	48.509431999999997	48.479661999999998	улица Карла Маркса	0103000020E61000000100000005000000C2C2499A3FE2604025917D90653D4840C2C2499A3FE2604097C4591135414840C91D369199E4604097C4591135414840C91D369199E4604025917D90653D4840C2C2499A3FE2604025917D90653D4840
1766	718	135.04749200000001	135.07262600000001	48.485449000000003	48.464621000000001	улица Калинина	0103000020E610000001000000050000004B5AF10D85E16040750470B3783B48404B5AF10D85E160401E705D31233E4840DCDAC2F352E260401E705D31233E4840DCDAC2F352E26040750470B3783B48404B5AF10D85E16040750470B3783B4840
2337	718	135.038814	135.052513	48.575243999999998	48.573419000000001	улица Ильича	0103000020E610000001000000050000001094DBF63DE16040D8F335CB654948401094DBF63DE16040309C6B98A1494840AD33BE2FAEE16040309C6B98A1494840AD33BE2FAEE16040D8F335CB654948401094DBF63DE16040D8F335CB65494840
2216	718	135.03141199999999	135.036236	48.560910999999997	48.557256000000002	улица Зои Космодемьянской	0103000020E610000001000000050000007616BD5301E16040F9BF232A544748407616BD5301E16040BB7B80EECB474840035E66D828E16040BB7B80EECB474840035E66D828E16040F9BF232A544748407616BD5301E16040F9BF232A54474840
1426	718	135.04706899999999	135.06214299999999	48.493008000000003	48.487175000000001	улица Знаменщикова	0103000020E61000000100000005000000F9F4D89681E16040E3361AC05B3E4840F9F4D89681E160404C55DAE21A3F48409C155113FDE160404C55DAE21A3F48409C155113FDE16040E3361AC05B3E4840F9F4D89681E16040E3361AC05B3E4840
6536	718	135.132239	135.143719	48.452222999999996	48.448290999999998	улица Зеленая	0103000020E610000001000000050000002F88484D3BE46040AA0B7899613948402F88484D3BE46040DFBF7971E23948400B9A965899E46040DFBF7971E23948400B9A965899E46040AA0B7899613948402F88484D3BE46040AA0B789961394840
1832	718	135.04416800000001	135.075097	48.491419999999998	48.464621000000001	улица Запарина	0103000020E61000000100000005000000F47002D369E16040750470B3783B4840F47002D369E16040D74CBED9E63E4840E3E0D23167E26040D74CBED9E63E4840E3E0D23167E26040750470B3783B4840F47002D369E16040750470B3783B4840
1683	718	135.041653	135.047087	48.498251000000003	48.493963999999998	улица Забайкальская	0103000020E61000000100000005000000F818AC3855E160405FB35C363A3F4840F818AC3855E16040831953B0C63F484023A298BC81E16040831953B0C63F484023A298BC81E160405FB35C363A3F4840F818AC3855E160405FB35C363A3F4840
2591	718	135.17335499999999	135.18338	48.461221999999999	48.460527999999996	улица Жуковского	0103000020E6100000010000000500000023F3C81F8CE560403672DD94F23A484023F3C81F8CE560400D198F52093B4840B2D7BB3FDEE560400D198F52093B4840B2D7BB3FDEE560403672DD94F23A484023F3C81F8CE560403672DD94F23A4840
2552	718	135.05854099999999	135.07454899999999	48.483089999999997	48.471305999999998	улица Дзержинского	0103000020E61000000100000005000000340F6091DFE160404C3448C1533C4840340F6091DFE160402783A3E4D53D4840629E95B462E260402783A3E4D53D4840629E95B462E260404C3448C1533C4840340F6091DFE160404C3448C1533C4840
405	718	135.14728500000001	135.15664599999999	48.510553999999999	48.510368999999997	улица Данчука	0103000020E610000001000000050000002046088FB6E4604034F279C5534148402046088FB6E46040C66B5ED55941484093E1783E03E56040C66B5ED55941484093E1783E03E5604034F279C5534148402046088FB6E4604034F279C553414840
2383	718	135.173822	135.19096200000001	48.475624000000003	48.458168000000001	улица Горького	0103000020E6100000010000000500000069AA27F38FE560407009C03FA53A484069AA27F38FE56040AB984A3FE13C4840EC18575C1CE66040AB984A3FE13C4840EC18575C1CE660407009C03FA53A484069AA27F38FE560407009C03FA53A4840
1061	718	135.092704	135.10366300000001	48.396636000000001	48.392161000000002	улица Герцена	0103000020E61000000100000005000000AB06616EF7E2604022E2E65432324840AB06616EF7E260404835ECF7C4324840C559113551E360404835ECF7C4324840C559113551E3604022E2E65432324840AB06616EF7E2604022E2E65432324840
2925	718	135.18465499999999	135.18496099999999	48.461233	48.452097000000002	улица Гагарина	0103000020E610000001000000050000005F419AB1E8E5604053CF8250DE3948405F419AB1E8E56040016BD5AE093B484022C15433EBE56040016BD5AE093B484022C15433EBE5604053CF8250DE3948405F419AB1E8E5604053CF8250DE394840
6256	718	135.07373999999999	135.07885200000001	48.511353999999997	48.503247000000002	улица Вяземская	0103000020E61000000100000005000000060DFD135CE26040B267CF656A404840060DFD135CE26040E256410C744148402D27A1F485E26040E256410C744148402D27A1F485E26040B267CF656A404840060DFD135CE26040B267CF656A404840
1011	718	135.106179	135.113733	48.401708999999997	48.384658000000002	улица Ворошилова	0103000020E61000000100000005000000B49080D165E3604088122D793C314840B49080D165E3604022C154336B3348403B6F63B3A3E3604022C154336B3348403B6F63B3A3E3604088122D793C314840B49080D165E3604088122D793C314840
1306	718	135.065943	135.07267100000001	48.528951999999997	48.498669	улица Воронежская	0103000020E61000000100000005000000CE8C7E341CE26040B743C362D43F4840CE8C7E341CE26040AF93FAB2B4434840C40B225253E26040AF93FAB2B4434840C40B225253E26040B743C362D43F4840CE8C7E341CE26040B743C362D43F4840
1431	718	135.17794499999999	135.18958699999999	48.457104999999999	48.456955000000001	улица Воровского	0103000020E61000000100000005000000936FB6B9B1E56040315F5E807D3A4840936FB6B9B1E5604046EBA86A823A4840E597C11811E6604046EBA86A823A4840E597C11811E66040315F5E807D3A4840936FB6B9B1E56040315F5E807D3A4840
544	718	135.07644400000001	135.11102	48.472178	48.446491999999999	улица Волочаевская	0103000020E6100000010000000500000037FFAF3A72E260407BF65CA62639484037FFAF3A72E2604002F22554703C484076A6D0798DE3604002F22554703C484076A6D0798DE360407BF65CA62639484037FFAF3A72E260407BF65CA626394840
1210	718	135.12444099999999	135.12874400000001	48.409765999999998	48.394320999999998	улица Вологодская	0103000020E610000001000000050000000229B16BFBE3604021904B1C793248400229B16BFBE36040A181583673344840CDB1BCAB1EE46040A181583673344840CDB1BCAB1EE4604021904B1C793248400229B16BFBE3604021904B1C79324840
1682	718	135.04131100000001	135.06138000000001	48.499057000000001	48.489772000000002	улица Брестская	0103000020E61000000100000005000000E23E726B52E160408E3F51D9B03E4840E23E726B52E1604081EB8A19E13F48401D9430D3F6E1604081EB8A19E13F48401D9430D3F6E160408E3F51D9B03E4840E23E726B52E160408E3F51D9B03E4840
484	718	135.07061400000001	135.09903700000001	48.510553999999999	48.497205999999998	улица Большая	0103000020E6100000010000000500000079944A7842E26040FFAF3A72A43F484079944A7842E26040C66B5ED5594148400283A44F2BE36040C66B5ED5594148400283A44F2BE36040FFAF3A72A43F484079944A7842E26040FFAF3A72A43F4840
5393	718	135.06421800000001	135.068566	48.512779999999999	48.507359999999998	улица Больничная	0103000020E61000000100000005000000113AE8120EE2604037A6272CF1404840113AE8120EE260407D0569C6A2414840C3F352B131E260407D0569C6A2414840C3F352B131E2604037A6272CF1404840113AE8120EE2604037A6272CF1404840
1976	718	135.03381899999999	135.03838300000001	48.511812999999997	48.506017	улица Бойко-Павлова	0103000020E61000000100000005000000785F950B15E160402A1C412AC5404840785F950B15E160407555A016834148401E37FC6E3AE160407555A016834148401E37FC6E3AE160402A1C412AC5404840785F950B15E160402A1C412AC5404840
15468	718	135.11527799999999	135.12087500000001	48.557417000000001	48.554732999999999	улица Богородская	0103000020E6100000010000000500000058FE7C5BB0E360408881AE7D0147484058FE7C5BB0E36040029EB47059474840EE7C3F35DEE36040029EB47059474840EE7C3F35DEE360408881AE7D0147484058FE7C5BB0E360408881AE7D01474840
1565	718	135.00930399999999	135.017515	48.360227000000002	48.357683000000002	улица Балашовская	0103000020E610000001000000050000001AF7E6374CE06040E7AA798EC82D48401AF7E6374CE060406F1118EB1B2E484010069E7B8FE060406F1118EB1B2E484010069E7B8FE06040E7AA798EC82D48401AF7E6374CE06040E7AA798EC82D4840
953	718	135.11005900000001	135.12550100000001	48.408718999999998	48.405692999999999	улица Аксенова	0103000020E610000001000000050000002DB4739A85E36040AA9B8BBFED3348402DB4739A85E360407D2079E750344840B153AC1A04E460407D2079E750344840B153AC1A04E46040AA9B8BBFED3348402DB4739A85E36040AA9B8BBFED334840
1499	718	135.041572	135.08125899999999	48.370547000000002	48.363746999999996	улица Автобусная	0103000020E61000000100000005000000BD8DCD8E54E160405182FE428F2E4840BD8DCD8E54E16040C25087156E2F48402E7079AC99E26040C25087156E2F48402E7079AC99E260405182FE428F2E4840BD8DCD8E54E160405182FE428F2E4840
2307	718	135.04363799999999	135.04563200000001	48.577120999999998	48.571595000000002	улица Авроры	0103000020E610000001000000050000009CDB847B65E1604050C763062A4948409CDB847B65E16040DB6AD619DF494840D6743DD175E16040DB6AD619DF494840D6743DD175E1604050C763062A4948409CDB847B65E1604050C763062A494840
18940	718	135.00712100000001	135.13892200000001	48.540799999999997	48.453203000000002	станция Хабаровск-1	0103000020E61000000100000005000000ADC3D1553AE060407CB94F8E023A4840ADC3D1553AE06040A1D634EF384548403DD68C0C72E46040A1D634EF384548403DD68C0C72E460407CB94F8E023A4840ADC3D1553AE060407CB94F8E023A4840
22350	718	135.094572	135.13958700000001	48.499139999999997	48.394207999999999	проспект 60-летия Октября	0103000020E61000000100000005000000C1E3DBBB06E3604029E9616875324840C1E3DBBB06E360400E10CCD1E33F48404CFE277F77E460400E10CCD1E33F48404CFE277F77E4604029E9616875324840C1E3DBBB06E3604029E9616875324840
22496	718	135.09508400000001	135.09754599999999	48.476030000000002	48.462589999999999	пер. Облачный	0103000020E61000000100000005000000EFCB99ED0AE3604073BA2C26363B4840EFCB99ED0AE360401BF5108DEE3C484061FBC9181FE360401BF5108DEE3C484061FBC9181FE3604073BA2C26363B4840EFCB99ED0AE3604073BA2C26363B4840
21711	718	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	кв.ДОС (Большой Аэродром)	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
22573	718	135.11447000000001	135.120632	48.563994000000001	48.559784000000001	кв-л Энергетик	0103000020E61000000100000005000000F14BFDBCA9E360407B698A00A7474840F14BFDBCA9E36040F39194F4304848403CDBA337DCE36040F39194F4304848403CDBA337DCE360407B698A00A7474840F14BFDBCA9E360407B698A00A7474840
77141	718	135.094572	135.13958700000001	48.499139999999997	48.394207999999999	кв-л 70Лет Октября	0103000020E61000000100000005000000C1E3DBBB06E3604029E9616875324840C1E3DBBB06E360400E10CCD1E33F48404CFE277F77E460400E10CCD1E33F48404CFE277F77E4604029E9616875324840C1E3DBBB06E3604029E9616875324840
22319	718	135.11879999999999	135.13142099999999	48.467087999999997	48.464638999999998	Шкотова	0103000020E610000001000000050000007958A835CDE360401BB96E4A793B48407958A835CDE36040512D228AC93B48403E20D09934E46040512D228AC93B48403E20D09934E460401BB96E4A793B48407958A835CDE360401BB96E4A793B4840
22235	718	135.10523499999999	135.10837900000001	48.450172999999999	48.447310999999999	Шимановского	0103000020E61000000100000005000000A06CCA155EE360400E12A27C41394840A06CCA155EE360406745D4449F39484058923CD777E360406745D4449F39484058923CD777E360400E12A27C41394840A06CCA155EE360400E12A27C41394840
22356	718	135.06919500000001	135.07057800000001	48.507401999999999	48.504328000000001	Чехова	0103000020E610000001000000050000007FC16ED836E26040823AE5D18D4048407FC16ED836E2604066F6798CF2404840263ACB2C42E2604066F6798CF2404840263ACB2C42E26040823AE5D18D4048407FC16ED836E26040823AE5D18D404840
22765	718	135.109601	135.11530500000001	48.425576	48.407654999999998	Центральная	0103000020E610000001000000050000007CD3F4D981E360408386FE092E3448407CD3F4D981E3604033FB3C467936484017821C94B0E3604033FB3C467936484017821C94B0E360408386FE092E3448407CD3F4D981E360408386FE092E344840
22592	718	135.10541499999999	135.12186299999999	48.438124000000002	48.433957999999997	Флегонтова	0103000020E610000001000000050000004030478F5FE3604035EB8CEF8B3748404030478F5FE36040DECB7D7214384840F5F23B4DE6E36040DECB7D7214384840F5F23B4DE6E3604035EB8CEF8B3748404030478F5FE3604035EB8CEF8B374840
1600	718	135.07930999999999	135.08085500000001	48.466729999999998	48.465732000000003	Фабричный переулок	0103000020E61000000100000005000000DD0720B589E26040B0592E1B9D3B4840DD0720B589E26040F20703CFBD3B4840FB96395D96E26040F20703CFBD3B4840FB96395D96E26040B0592E1B9D3B4840DD0720B589E26040B0592E1B9D3B4840
621	718	135.088131	135.096306	48.462052	48.4572	Трубный переулок	0103000020E6100000010000000500000071581AF8D1E2604098DD9387853A484071581AF8D1E2604094861A85243B4840130D52F014E3604094861A85243B4840130D52F014E3604098DD9387853A484071581AF8D1E2604098DD9387853A4840
22351	718	135.08024399999999	135.086038	48.474890000000002	48.470416	Слободская	0103000020E610000001000000050000006876DD5B91E26040F0C16B97363C48406876DD5B91E2604046990D32C93C4840D386C3D2C0E2604046990D32C93C4840D386C3D2C0E26040F0C16B97363C48406876DD5B91E26040F0C16B97363C4840
22535	718	135.04936900000001	135.066078	48.498716000000002	48.477195000000002	Серышева	0103000020E61000000100000005000000F60D4C6E94E160404968CBB9143D4840F60D4C6E94E16040F8FE06EDD53F4840861F9C4F1DE26040F8FE06EDD53F4840861F9C4F1DE260404968CBB9143D4840F60D4C6E94E160404968CBB9143D4840
22570	718	135.11016699999999	135.12264500000001	48.389755999999998	48.387991	Рокоссовского	0103000020E6100000010000000500000026C3F17C86E36040381268B0A931484026C3F17C86E36040BBB54C86E3314840930035B5ECE36040BBB54C86E3314840930035B5ECE36040381268B0A931484026C3F17C86E36040381268B0A9314840
22324	718	135.075052	135.09060199999999	48.464621000000001	48.458556999999999	Пионерская	0103000020E61000000100000005000000FBAF73D366E260400A2DEBFEB13A4840FBAF73D366E26040750470B3783B4840785E2A36E6E26040750470B3783B4840785E2A36E6E260400A2DEBFEB13A4840FBAF73D366E260400A2DEBFEB13A4840
22571	718	135.11056199999999	135.12550100000001	48.385347000000003	48.384065999999997	Панфиловцев	0103000020E61000000100000005000000C5C551B989E36040B5C01E1329314840C5C551B989E360404D4EED0C53314840B153AC1A04E460404D4EED0C53314840B153AC1A04E46040B5C01E1329314840C5C551B989E36040B5C01E1329314840
22768	718	135.17816099999999	135.18539200000001	48.495265000000003	48.470002999999998	Новая	0103000020E61000000100000005000000868DB27EB3E56040CD02ED0E293C4840868DB27EB3E560403EEDF0D7643F4840151E34BBEEE560403EEDF0D7643F4840151E34BBEEE56040CD02ED0E293C4840868DB27EB3E56040CD02ED0E293C4840
22192	718	134.89181400000001	135.22114500000001	48.599291000000001	48.321784999999998	Насыпная	0103000020E61000000100000005000000AE8383BD89DC6040F3AB394030294840AE8383BD89DC6040C1E44691B54C484091D5AD9E13E76040C1E44691B54C484091D5AD9E13E76040F3AB394030294840AE8383BD89DC6040F3AB394030294840
22619	718	135.06031100000001	135.06181100000001	48.466658000000002	48.464692999999997	Набережная	0103000020E61000000100000005000000DA925511EEE160400ED76A0F7B3B4840DA925511EEE1604059350873BB3B48400FF10F5BFAE1604059350873BB3B48400FF10F5BFAE160400ED76A0F7B3B4840DA925511EEE160400ED76A0F7B3B4840
18981	718	135.057571	135.070875	48.479739000000002	48.472465	Муравьева-Амурского	0103000020E610000001000000050000005646239FD7E1604098C0ADBB793C48405646239FD7E16040D1CE6916683D484054E3A59B44E26040D1CE6916683D484054E3A59B44E2604098C0ADBB793C48405646239FD7E1604098C0ADBB793C4840
1629	718	135.08678399999999	135.09285700000001	48.464376000000001	48.461598000000002	Молдавский переулок	0103000020E610000001000000050000001D3A3DEFC6E2604013F3ACA4153B48401D3A3DEFC6E260400E863AAC703B48408D463EAFF8E260400E863AAC703B48408D463EAFF8E2604013F3ACA4153B48401D3A3DEFC6E2604013F3ACA4153B4840
416	718	135.143531	135.20542399999999	48.548817	48.509414	Матвеевское шоссе	0103000020E61000000100000005000000CADE52CE97E46040F10F5B7A34414840CADE52CE97E46040923EADA23F464840083A5AD592E66040923EADA23F464840083A5AD592E66040F10F5B7A34414840CADE52CE97E46040F10F5B7A34414840
22557	718	135.04353	135.05074400000001	48.366087999999998	48.360922000000002	Магаданская	0103000020E61000000100000005000000A3CC069964E1604016342DB1322E4840A3CC069964E16040A1BAB9F8DB2E4840FC8EE1B19FE16040A1BAB9F8DB2E4840FC8EE1B19FE1604016342DB1322E4840A3CC069964E1604016342DB1322E4840
1607	718	135.06544	135.079463	48.496955	48.493253000000003	Ленинградский переулок	0103000020E61000000100000005000000357BA01518E26040B3D30FEA223F4840357BA01518E26040B64AB0389C3F4840BF47FDF58AE26040B64AB0389C3F4840BF47FDF58AE26040B3D30FEA223F4840357BA01518E26040B3D30FEA223F4840
22333	718	135.07308499999999	135.112799	48.446516000000003	48.342660000000002	Краснореченская	0103000020E61000000100000005000000809A5AB656E26040DDD26A48DC2B4840809A5AB656E260400492B06F27394840B000A60C9CE360400492B06F27394840B000A60C9CE36040DDD26A48DC2B4840809A5AB656E26040DDD26A48DC2B4840
22537	718	135.12853799999999	135.13199599999999	48.442307999999997	48.430352999999997	Клубная	0103000020E610000001000000050000006249B9FB1CE46040245E9ECE153748406249B9FB1CE460402C616D8C9D3848407DE6AC4F39E460402C616D8C9D3848407DE6AC4F39E46040245E9ECE153748406249B9FB1CE46040245E9ECE15374840
22525	718	135.07902200000001	135.08302900000001	48.382427	48.379997000000003	Каширская	0103000020E610000001000000050000004435255987E2604000CADFBDA33048404435255987E26040BF0D315EF3304840D4F36E2CA8E26040BF0D315EF3304840D4F36E2CA8E2604000CADFBDA33048404435255987E2604000CADFBDA3304840
22472	718	135.08973	135.092524	48.469118999999999	48.465828000000002	Казарменный	0103000020E610000001000000050000000BEF7211DFE26040D2C77C40A03B48400BEF7211DFE26040537765170C3C48400B43E4F4F5E26040537765170C3C48400B43E4F4F5E26040D2C77C40A03B48400BEF7211DFE26040D2C77C40A03B4840
2210	718	135.09255099999999	135.095147	48.482360999999997	48.480719000000001	Кадровый переулок	0103000020E61000000100000005000000C9C6832DF6E260406DC83F33883D4840C9C6832DF6E26040D4EE5701BE3D484000AAB8710BE36040D4EE5701BE3D484000AAB8710BE360406DC83F33883D4840C9C6832DF6E260406DC83F33883D4840
893	718	135.10484	135.10552300000001	48.416547000000001	48.414831	Иртышский проезд	0103000020E61000000100000005000000016A6AD95AE36040F92EA52E19354840016A6AD95AE360409B1F7F69513548403A3FC57160E360409B1F7F69513548403A3FC57160E36040F92EA52E19354840016A6AD95AE36040F92EA52E19354840
7453	718	135.078744	135.08417900000001	48.468307000000003	48.465164999999999	Дзержинского переулок	0103000020E610000001000000050000003318231285E26040361FD7868A3B48403318231285E2604073BED87BF13B484052802898B1E2604073BED87BF13B484052802898B1E26040361FD7868A3B48403318231285E26040361FD7868A3B4840
21918	718	134.89181400000001	135.22114500000001	48.599291000000001	48.321784999999998	Георгиевская	0103000020E61000000100000005000000AE8383BD89DC6040F3AB394030294840AE8383BD89DC6040C1E44691B54C484091D5AD9E13E76040C1E44691B54C484091D5AD9E13E76040F3AB394030294840AE8383BD89DC6040F3AB394030294840
22353	718	135.071405	135.09001799999999	48.478873	48.468283	Гамарника	0103000020E61000000100000005000000AB7823F348E26040EA2285B2F03B4840AB7823F348E26040FDF7E0B54B3D4840A4C16D6DE1E26040FDF7E0B54B3D4840A4C16D6DE1E26040EA2285B2F03B4840AB7823F348E26040EA2285B2F03B4840
1568	718	135.126993	135.141761	48.480122000000001	48.476973999999998	Восточное шоссе	0103000020E6100000010000000500000045BA9F5310E460406A85E97B0D3D484045BA9F5310E46040890B40A3743D4840255B5D4E89E46040890B40A3743D4840255B5D4E89E460406A85E97B0D3D484045BA9F5310E460406A85E97B0D3D4840
22555	718	135.106179	135.113733	48.401708999999997	48.384658000000002	Ворошилова	0103000020E61000000100000005000000B49080D165E3604088122D793C314840B49080D165E3604022C154336B3348403B6F63B3A3E3604022C154336B3348403B6F63B3A3E3604088122D793C314840B49080D165E3604088122D793C314840
22559	718	135.082742	135.08402599999999	48.466926999999998	48.462840999999997	Блюхера	0103000020E610000001000000050000002E008DD2A5E26040BC1FB75F3E3B48402E008DD2A5E26040484F9143C43B484070404B57B0E26040484F9143C43B484070404B57B0E26040BC1FB75F3E3B48402E008DD2A5E26040BC1FB75F3E3B4840
22323	718	135.118539	135.12696600000001	48.440240000000003	48.422365999999997	Балтийская	0103000020E610000001000000050000009E094D12CBE360409E78CE16103648409E094D12CBE360400E32C9C8593848408736001B10E460400E32C9C8593848408736001B10E460409E78CE16103648409E094D12CBE360409E78CE1610364840
816	718	135.10370800000001	135.11207200000001	48.442207000000003	48.440694999999998	Байкальский переулок	0103000020E61000000100000005000000AD8A709351E360405F419AB168384840AD8A709351E36040F9872D3D9A38484084D9041896E36040F9872D3D9A38484084D9041896E360405F419AB168384840AD8A709351E360405F419AB168384840
22541	718	135.081187	135.093773	48.383743000000003	48.366087999999998	Артемовская	0103000020E6100000010000000500000088BB7A1599E26040A1BAB9F8DB2E484088BB7A1599E26040D388997D1E314840EE073C3000E36040D388997D1E314840EE073C3000E36040A1BAB9F8DB2E484088BB7A1599E26040A1BAB9F8DB2E4840
1802	718	135.051444	135.07323700000001	48.496262000000002	48.475372999999998	Амурский бульвар	0103000020E610000001000000050000006A32E36DA5E160406133C005D93C48406A32E36DA5E16040B01F6283853F48406EFB1EF557E26040B01F6283853F48406EFB1EF557E260406133C005D93C48406A32E36DA5E160406133C005D93C4840
22330	718	135.065853	135.07004800000001	48.382648000000003	48.377107000000002	Алеутская	0103000020E61000000100000005000000FE2AC0771BE26040DD0BCC0A45304840FE2AC0771BE260409EF0129CFA304840CFA44DD53DE260409EF0129CFA304840CFA44DD53DE26040DD0BCC0A45304840FE2AC0771BE26040DD0BCC0A45304840
264	718	135.12802600000001	135.136236	48.430168000000002	48.424703000000001	60 Лет Октября проспект	0103000020E610000001000000050000003561FBC918E46040ADC1FBAA5C3648403561FBC918E4604093E4B9BE0F3748403691990B5CE4604093E4B9BE0F3748403691990B5CE46040ADC1FBAA5C3648403561FBC918E46040ADC1FBAA5C364840
22764	718	135.057355	135.06791000000001	48.494418000000003	48.489724000000002	 Герасимова	0103000020E61000000100000005000000632827DAD5E160407D08AA46AF3E4840632827DAD5E16040E146CA16493F484049A297512CE26040E146CA16493F484049A297512CE260407D08AA46AF3E4840632827DAD5E160407D08AA46AF3E4840
22495	718	135.12095600000001	135.123696	48.406517999999998	48.397114999999999	 Архангельская	0103000020E6100000010000000500000029081EDFDEE3604022E010AAD432484029081EDFDEE360401F9E25C808344840AC545051F5E360401F9E25C808344840AC545051F5E3604022E010AAD432484029081EDFDEE3604022E010AAD4324840
79395	61564	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	Коммунистическая	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
21868	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Октябрьский	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21930	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Московский	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22252	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Мира	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21946	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Ленина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21925	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Копылова	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22242	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Интернациональный	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22063	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Щорса	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22086	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Чапаева	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22267	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Сусанина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21970	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Сортировочная	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22040	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Советская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22278	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Северное шоссе	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21944	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Севастопольская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22273	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Пирогова	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22293	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Пермская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22294	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Партизанская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22102	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Охотская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22018	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Орехова	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21940	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Орджоникидзе	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22400	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Мира	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22307	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Мачтовая	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21906	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Ломоносова	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22255	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Летчиков	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21786	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Ленинградская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22072	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Лазо	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21848	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Культурная	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22104	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Копровая	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22069	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Комсомольская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22166	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Кирова	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21779	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Калинина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22173	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Дикопольцева	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21876	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Дзержинского	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22250	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Вокзальная	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
21937	49990	136.86117200000001	137.15650199999999	50.699987	50.516188	Аллея Труда	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22276	50483	136.86117200000001	137.15650199999999	50.699987	50.516188	Гамарника	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
79407	61571	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	Центральная	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
18954	49969	135.61096000000001	135.645464	47.798434	47.758094999999997	Набережная	0103000020E610000001000000050000004165FCFB8CF360406C21C84109E147404165FCFB8CF36040DA01D71533E64740DA571EA4A7F46040DA01D71533E64740DA571EA4A7F460406C21C84109E147404165FCFB8CF360406C21C84109E14740
22466	50509	135.10047399999999	135.10642100000001	48.477595000000001	48.474871999999998	Призывной переулок	0103000020E610000001000000050000002503401537E360409FE40E9BC83C48402503401537E36040D7DD3CD5213D4840725303CD67E36040D7DD3CD5213D4840725303CD67E360409FE40E9BC83C48402503401537E360409FE40E9BC83C4840
19183	3570	135.25022300000001	135.258668	48.516939999999998	48.509341999999997	Центральная	0103000020E61000000100000005000000A036AAD301E86040573D601E32414840A036AAD301E8604043FF04172B424840B2101D0247E8604043FF04172B424840B2101D0247E86040573D601E32414840A036AAD301E86040573D601E32414840
24158	50956	135.30088799999999	135.326661	48.475768000000002	48.461418999999999	Центральная	0103000020E6100000010000000500000048F8DEDFA0E9604063601DC70F3B484048F8DEDFA0E96040DE3D40F7E53C48401EFCC40174EA6040DE3D40F7E53C48401EFCC40174EA604063601DC70F3B484048F8DEDFA0E9604063601DC70F3B4840
22202	2564	136.003218	136.043903	48.884793000000002	48.87238	Набережная	0103000020E610000001000000050000004698A25C1A0061409DD7D825AA6F48404698A25C1A006140685DA3E54071484048A643A767016140685DA3E54071484048A643A7670161409DD7D825AA6F48404698A25C1A0061409DD7D825AA6F4840
21941	2073	135.16967099999999	135.178978	48.602967	48.590657	Зеленая	0103000020E610000001000000050000008C82E0F16DE56040A51309A69A4B48408C82E0F16DE560409BC8CC052E4D484083161230BAE560409BC8CC052E4D484083161230BAE56040A51309A69A4B48408C82E0F16DE56040A51309A69A4B4840
19272	2548	134.22504799999999	134.23687000000001	48.762174999999999	48.757133000000003	Юбилейная	0103000020E61000000100000005000000F700DD9733C7604077DCF0BBE9604840F700DD9733C76040166A4DF38E614840EAEC647094C76040166A4DF38E614840EAEC647094C7604077DCF0BBE9604840F700DD9733C7604077DCF0BBE9604840
22320	50488	135.168342	135.18362200000001	48.510572000000003	48.504793999999997	Школьная	0103000020E610000001000000050000006211C30E63E56040C79BFC169D4048406211C30E63E560406D205D6C5A414840709A3E3BE0E560406D205D6C5A414840709A3E3BE0E56040C79BFC169D4048406211C30E63E56040C79BFC169D404840
21742	2914	135.58428900000001	135.617616	48.607118999999997	48.597396000000003	Интернациональная	0103000020E61000000100000005000000344DD87EB2F260407061DD78774C4840344DD87EB2F26040DEE34C13B64D4840902FA182C3F36040DEE34C13B64D4840902FA182C3F360407061DD78774C4840344DD87EB2F260407061DD78774C4840
21934	50445	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	площадь Мира	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
22289	50445	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	Шоссейная	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
22309	1372	135.30306200000001	135.32139699999999	48.561864999999997	48.556409000000002	Молодежная	0103000020E61000000100000005000000225514AFB2E960409C19FD6838474840225514AFB2E960402EE23B31EB4748400A815CE248EA60402EE23B31EB4748400A815CE248EA60409C19FD6838474840225514AFB2E960409C19FD6838474840
19276	2749	135.63094699999999	135.647908	48.753158999999997	48.747633999999998	Октябрьская	0103000020E610000001000000050000004C50C3B730F4604057B08D78B25F48404C50C3B730F4604012D89C836760484023DA8EA9BBF4604012D89C836760484023DA8EA9BBF4604057B08D78B25F48404C50C3B730F4604057B08D78B25F4840
19282	3462	135.36960099999999	135.39810399999999	48.478000999999999	48.467058000000002	Партизанская	0103000020E6100000010000000500000034F279C5D3EB6040E7AA798EC83B484034F279C5D3EB6040473A03232F3D4840048D9944BDEC6040473A03232F3D4840048D9944BDEC6040E7AA798EC83B484034F279C5D3EB6040E7AA798EC83B4840
21990	50449	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	Центральная	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
19268	2364	134.316892	134.33811900000001	49.067233999999999	49.037393999999999	переулок Безымянный	0103000020E61000000100000005000000A60BB1FA23CA604087889B53C9844840A60BB1FA23CA6040F296AB1F9B88484000E5EFDED1CA6040F296AB1F9B88484000E5EFDED1CA604087889B53C9844840A60BB1FA23CA604087889B53C9844840
22125	2902	135.514229	135.551851	48.691659999999999	48.673856999999998	Советская	0103000020E61000000100000005000000F434609074F06040209738F240564840F434609074F06040C6F99B50885848407AA86DC3A8F16040C6F99B50885848407AA86DC3A8F16040209738F240564840F434609074F06040209738F240564840
21861	2415	134.334014	134.36148399999999	49.069454	49.056578999999999	Пионерская	0103000020E61000000100000005000000FFCC203EB0CA6040F8510DFB3D874840FFCC203EB0CA6040C74961DEE3884840DFC0E44691CB6040C74961DEE3884840DFC0E44691CB6040F8510DFB3D874840FFCC203EB0CA6040F8510DFB3D874840
22122	2469	134.304495	134.32118600000001	48.860035000000003	48.840246	Советская	0103000020E6100000010000000500000075594C6CBEC96040234C512E8D6B484075594C6CBEC960402B357BA0156E4840DCBDDC2747CA60402B357BA0156E4840DCBDDC2747CA6040234C512E8D6B484075594C6CBEC96040234C512E8D6B4840
19290	1021	135.22432499999999	135.249864	48.354486000000001	48.342731000000001	Ленина	0103000020E610000001000000050000009B559FAB2DE76040A629029CDE2B48409B559FAB2DE76040E77118CC5F2D4840548EC9E2FEE76040E77118CC5F2D4840548EC9E2FEE76040A629029CDE2B48409B559FAB2DE76040A629029CDE2B4840
21860	2320	133.422493	133.43119799999999	48.999740000000003	48.987910999999997	Центральная	0103000020E610000001000000050000003F390A1085AD6040E82D1EDE737E48403F390A1085AD60406440F67AF77F48403883BF5FCCAD60406440F67AF77F48403883BF5FCCAD6040E82D1EDE737E48403F390A1085AD6040E82D1EDE737E4840
22121	50467	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	Центральная	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
22338	50493	135.10552300000001	135.117884	48.619503000000002	48.618121000000002	Парковая	0103000020E610000001000000050000003A3FC57160E3604044FCC3961E4F48403A3FC57160E360400F63D2DF4B4F48401897AAB4C5E360400F63D2DF4B4F48401897AAB4C5E3604044FCC3961E4F48403A3FC57160E3604044FCC3961E4F4840
22198	3678	135.218504	135.22675899999999	48.490673999999999	48.481172999999998	Рабочая	0103000020E6100000010000000500000072C119FCFDE66040EE5BAD13973D484072C119FCFDE66040AE7FD767CE3E48405B22179C41E76040AE7FD767CE3E48405B22179C41E76040EE5BAD13973D484072C119FCFDE66040EE5BAD13973D4840
21983	50447	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	Центральная	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
22342	50447	135.16849500000001	135.20078899999999	48.562562999999997	48.535800999999999	40 Лет Победы	0103000020E610000001000000050000004451A04F64E5604001158E20954448404451A04F64E5604046787B1002484840B08C0DDD6CE6604046787B1002484840B08C0DDD6CE6604001158E20954448404451A04F64E5604001158E2095444840
21871	2805	135.59921	135.62263799999999	48.740850000000002	48.720329999999997	Первомайская	0103000020E61000000100000005000000F52D73BA2CF36040F12900C6335C4840F52D73BA2CF36040ED9E3C2CD45E4840E6E786A6ECF36040ED9E3C2CD45E4840E6E786A6ECF36040F12900C6335C4840F52D73BA2CF36040F12900C6335C4840
18901	2216	133.46163300000001	133.48387500000001	49.210217	49.183089000000002	Новая	0103000020E6100000010000000500000024B891B2C5AE6040F1A0D9756F97484024B891B2C5AE604018080264E89A4840448B6CE77BAF604018080264E89A4840448B6CE77BAF6040F1A0D9756F97484024B891B2C5AE6040F1A0D9756F974840
19156	1761	134.982022	135.00561200000001	48.357562999999999	48.342570000000002	Мостовая	0103000020E610000001000000050000007BBE66B96CDF60409D4B7155D92B48407BBE66B96CDF60403CA1D79FC42D4840E38E37F92DE060403CA1D79FC42D4840E38E37F92DE060409D4B7155D92B48407BBE66B96CDF60409D4B7155D92B4840
19262	1848	135.03270499999999	135.085454	48.240186000000001	48.204816999999998	Таежная	0103000020E610000001000000050000004D2D5BEB0BE1604019558671371A48404D2D5BEB0BE16040817A336ABE1E4840FFE9060ABCE26040817A336ABE1E4840FFE9060ABCE2604019558671371A48404D2D5BEB0BE1604019558671371A4840
19263	1848	135.03270499999999	135.085454	48.240186000000001	48.204816999999998	Владивостокская	0103000020E610000001000000050000004D2D5BEB0BE1604019558671371A48404D2D5BEB0BE16040817A336ABE1E4840FFE9060ABCE26040817A336ABE1E4840FFE9060ABCE2604019558671371A48404D2D5BEB0BE1604019558671371A4840
21980	1714	134.94758100000001	134.97416200000001	48.354246000000003	48.343677999999997	Школьная	0103000020E61000000100000005000000F4A9639552DE6040662D05A4FD2B4840F4A9639552DE6040925ED4EE572D48403160C9552CDF6040925ED4EE572D48403160C9552CDF6040662D05A4FD2B4840F4A9639552DE6040662D05A4FD2B4840
21773	1514	135.43286900000001	135.45529999999999	48.590096000000003	48.582039000000002	Международная	0103000020E6100000010000000500000079CE1610DAED60408FFF0241804A484079CE1610DAED60400EC00644884B4840CD3B4ED191EE60400EC00644884B4840CD3B4ED191EE60408FFF0241804A484079CE1610DAED60408FFF0241804A4840
22012	3138	135.44840099999999	135.47366099999999	48.497700999999999	48.456339999999997	квартал ДОС	0103000020E61000000100000005000000CCCF0D4D59EE6040A6ED5F59693A4840CCCF0D4D59EE6040DF1797AAB43F4840800C1D3B28EF6040DF1797AAB43F4840800C1D3B28EF6040A6ED5F59693A4840CCCF0D4D59EE6040A6ED5F59693A4840
21756	3138	135.44840099999999	135.47366099999999	48.497700999999999	48.456339999999997	Никитенко	0103000020E61000000100000005000000CCCF0D4D59EE6040A6ED5F59693A4840CCCF0D4D59EE6040DF1797AAB43F4840800C1D3B28EF6040DF1797AAB43F4840800C1D3B28EF6040A6ED5F59693A4840CCCF0D4D59EE6040A6ED5F59693A4840
19179	3374	135.417957	135.430533	48.438077	48.427818000000002	Авиаторов	0103000020E610000001000000050000004CC45BE75FED6040F0517FBDC23648404CC45BE75FED60409D103AE812384840295B24EDC6ED60409D103AE812384840295B24EDC6ED6040F0517FBDC23648404CC45BE75FED6040F0517FBDC2364840
19155	1521	134.71367799999999	134.74773300000001	48.275098999999997	48.261015999999998	Новожилова	0103000020E61000000100000005000000FDBB3E73D6D66040CADDE7F868214840FDBB3E73D6D66040C614AC71362348407BA4C16DEDD76040C614AC71362348407BA4C16DEDD76040CADDE7F868214840FDBB3E73D6D66040CADDE7F868214840
22435	50505	135.10335799999999	135.12651600000001	48.369607000000002	48.367758000000002	Совхозная	0103000020E61000000100000005000000F5B86FB54EE36040D36BB3B1122F4840F5B86FB54EE36040B4AF3C484F2F4840774D486B0CE46040B4AF3C484F2F4840774D486B0CE46040D36BB3B1122F4840F5B86FB54EE36040D36BB3B1122F4840
22114	1318	135.22217800000001	135.24033299999999	48.605809000000001	48.592753999999999	Петра Черкасова	0103000020E61000000100000005000000817C09151CE760405E49F25CDF4B4840817C09151CE76040AD4F39268B4D4840C9E4D4CEB0E76040AD4F39268B4D4840C9E4D4CEB0E760405E49F25CDF4B4840817C09151CE760405E49F25CDF4B4840
22203	2659	135.84096500000001	135.876295	48.813223999999998	48.787041000000002	Новая	0103000020E6100000010000000500000095826E2FE9FA60403ACE6DC2BD64484095826E2FE9FA604041295AB917684840BFD4CF9B0AFC604041295AB917684840BFD4CF9B0AFC60403ACE6DC2BD64484095826E2FE9FA60403ACE6DC2BD644840
21740	3693	135.30387999999999	135.32558299999999	48.393118999999999	48.377291999999997	Центральная	0103000020E6100000010000000500000012BD8C62B9E960406E85B01A4B30484012BD8C62B9E96040D63730B95132484046240A2D6BEA6040D63730B95132484046240A2D6BEA60406E85B01A4B30484012BD8C62B9E960406E85B01A4B304840
21993	50451	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	ДОС	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
22334	50491	135.20813699999999	135.22640899999999	48.448847000000001	48.441454	Центральная	0103000020E61000000100000005000000CD02ED0EA9E660401D588E9081384840CD02ED0EA9E6604030F488D173394840A45016BE3EE7604030F488D173394840A45016BE3EE760401D588E9081384840CD02ED0EA9E660401D588E9081384840
21851	1418	135.358183	135.38048800000001	48.566592999999997	48.559766000000003	Мира	0103000020E6100000010000000500000076DF313C76EB6040D5B48B69A647484076DF313C76EB60403E92921E86484840A8902BF52CEC60403E92921E86484840A8902BF52CEC6040D5B48B69A647484076DF313C76EB6040D5B48B69A6474840
18941	2703	135.70427699999999	135.74295799999999	48.748341000000003	48.730486999999997	Набережная	0103000020E61000000100000005000000664AEB6F89F660409A931799805D4840664AEB6F89F66040C3A04CA3C95F4840A609DB4FC6F76040C3A04CA3C95F4840A609DB4FC6F760409A931799805D4840664AEB6F89F660409A931799805D4840
19255	3583	135.25652099999999	135.274801	48.488232000000004	48.477122999999999	Клубная	0103000020E610000001000000050000009737876B35E86040AF95D05D123D48409737876B35E860402B6EDC627E3E48400F7D772BCBE860402B6EDC627E3E48400F7D772BCBE86040AF95D05D123D48409737876B35E86040AF95D05D123D4840
22193	1619	134.82088300000001	134.834034	48.304000000000002	48.296334000000002	Новая	0103000020E61000000100000005000000F5DA6CAC44DA6040B058C345EE254840F5DA6CAC44DA6040F4FDD478E926484011381268B0DA6040F4FDD478E926484011381268B0DA6040B058C345EE254840F5DA6CAC44DA6040B058C345EE254840
19177	3359	135.47912299999999	135.49073799999999	48.429779000000003	48.416702999999998	Школьная	0103000020E610000001000000050000005DF8C1F954EF604092921E86563548405DF8C1F954EF6040F9C08EFF02374840F19C2D20B4EF6040F9C08EFF02374840F19C2D20B4EF604092921E86563548405DF8C1F954EF604092921E8656354840
22128	2999	135.55301	135.57950099999999	48.581842000000002	48.567999999999998	Бойко Павлова	0103000020E610000001000000050000008D0B0742B2F1604062105839B44848408D0B0742B2F1604039B874CC794A4840FA5FAE458BF2604039B874CC794A4840FA5FAE458BF2604062105839B44848408D0B0742B2F1604062105839B4484840
22575	50522	137.44999999999999	141.18033500000001	53.570599999999999	50.820295000000002	Набережная	0103000020E6100000010000000500000066666666662E61404209336DFF68494066666666662E61407E8CB96B09C94A4060EAE74DC5A561407E8CB96B09C94A4060EAE74DC5A561404209336DFF68494066666666662E61404209336DFF684940
21714	823	139.22343599999999	139.26288099999999	51.348506999999998	51.333579999999998	Железнодорожная	0103000020E61000000100000005000000F817416326676140C24CDBBFB2AA4940F817416326676140AAB69BE09BAC4940AC376A8569686140AAB69BE09BAC4940AC376A8569686140C24CDBBFB2AA4940F817416326676140C24CDBBFB2AA4940
19239	32152	140.393168	140.399879	52.378928999999999	52.373700999999997	Центральная	0103000020E61000000100000005000000AEBA0ED5948C6140C2BD326FD52F4A40AEBA0ED5948C6140C440D7BE80304A406E6B0BCFCB8C6140C440D7BE80304A406E6B0BCFCB8C6140C2BD326FD52F4A40AEBA0ED5948C6140C2BD326FD52F4A40
22100	32067	139.74989400000001	139.77669	52.935479999999998	52.925873000000003	Ленина	0103000020E61000000100000005000000EFAEB321FF776140ED9FA70183764A40EFAEB321FF776140F20703CFBD774A402BA4FCA4DA786140F20703CFBD774A402BA4FCA4DA786140ED9FA70183764A40EFAEB321FF776140ED9FA70183764A40
21829	4028	139.835476	139.855491	53.137462999999997	53.122329000000001	Комсомольская	0103000020E61000000100000005000000F9122A38BC7A61401B2D077AA88F4A40F9122A38BC7A61407CB4386398914A40B760A92E607B61407CB4386398914A40B760A92E607B61401B2D077AA88F4A40F9122A38BC7A61401B2D077AA88F4A40
22299	32079	140.06734	140.09330199999999	52.798777999999999	52.772897	Центральная	0103000020E61000000100000005000000CE3637A6278261409816F549EE624A40CE3637A627826140D461855B3E664A40D8D47954FC826140D461855B3E664A40D8D47954FC8261409816F549EE624A40CE3637A6278261409816F549EE624A40
22308	532	139.83011300000001	139.86822900000001	51.578422000000003	51.558211999999997	Центральная	0103000020E61000000100000005000000815F2349907A61400C1EA67D73C74940815F2349907A6140BAA46ABB09CA49400B0E2F88C87B6140BAA46ABB09CA49400B0E2F88C87B61400C1EA67D73C74940815F2349907A61400C1EA67D73C74940
22109	532	139.83011300000001	139.86822900000001	51.578422000000003	51.558211999999997	Кирова	0103000020E61000000100000005000000815F2349907A61400C1EA67D73C74940815F2349907A6140BAA46ABB09CA49400B0E2F88C87B6140BAA46ABB09CA49400B0E2F88C87B61400C1EA67D73C74940815F2349907A61400C1EA67D73C74940
22028	32409	140.23095900000001	140.270207	52.265574999999998	52.248254000000003	Школьная	0103000020E61000000100000005000000F1F6200464876140F48C7DC9C61F4A40F1F62004648761404ED1915CFE214A40CF842689A58861404ED1915CFE214A40CF842689A5886140F48C7DC9C61F4A40F1F6200464876140F48C7DC9C61F4A40
22304	32495	140.364575	140.37713299999999	52.173225000000002	52.148077000000001	Амурская	0103000020E610000001000000050000000EBE3099AA8B61401825E82FF4124A400EBE3099AA8B6140C0EC9E3C2C164A40C1A73979118C6140C0EC9E3C2C164A40C1A73979118C61401825E82FF4124A400EBE3099AA8B61401825E82FF4124A40
19152	813	139.524102	139.54412600000001	51.421737	51.411631999999997	Советская	0103000020E6100000010000000500000095B88E71C570614058FE7C5BB0B4494095B88E71C5706140AF415F7AFBB54940E8DCED7A69716140AF415F7AFBB54940E8DCED7A6971614058FE7C5BB0B4494095B88E71C570614058FE7C5BB0B44940
22302	32134	140.41851	140.433009	52.444761	52.432989999999997	Амурская	0103000020E610000001000000050000009161156F648D61405DBF60376C374A409161156F648D6140A4C4AEEDED384A40F5BBB035DB8D6140A4C4AEEDED384A40F5BBB035DB8D61405DBF60376C374A409161156F648D61405DBF60376C374A40
21978	208	140.17047600000001	140.22700699999999	51.731689000000003	51.722518000000001	Ленина	0103000020E610000001000000050000001898158A74856140BB6246787BDC49401898158A74856140E6EB32FCA7DD4940D11E2FA443876140E6EB32FCA7DD4940D11E2FA443876140BB6246787BDC49401898158A74856140BB6246787BDC4940
21835	318	140.18556799999999	140.22010800000001	51.720486999999999	51.698642999999997	Пионерская	0103000020E61000000100000005000000E4654D2CF0856140274A42226DD94940E4654D2CF0856140B91803EB38DC4940D1B2EE1F0B876140B91803EB38DC4940D1B2EE1F0B876140274A42226DD94940E4654D2CF0856140274A42226DD94940
19137	32405	140.174419	140.18280100000001	52.233159999999998	52.224947	Озерная	0103000020E61000000100000005000000A29927D794856140AA2A3410CB1C4A40A29927D794856140205ED72FD81D4A40A3957B81D9856140205ED72FD81D4A40A3957B81D9856140AA2A3410CB1C4A40A29927D794856140AA2A3410CB1C4A40
22111	971	138.97479999999999	138.99614399999999	51.467587999999999	51.461815000000001	Школьный	0103000020E610000001000000050000008104C58F315F6140B0E600C11CBB49408104C58F315F6140430070ECD9BB494069C36169E05F6140430070ECD9BB494069C36169E05F6140B0E600C11CBB49408104C58F315F6140B0E600C11CBB4940
21964	30490	139.730715	139.740407	52.977670000000003	52.967219999999998	Школьный	0103000020E610000001000000050000004B766C0462776140C0046EDDCD7B4A404B766C0462776140E223624A247D4A405857056AB1776140E223624A247D4A405857056AB1776140C0046EDDCD7B4A404B766C0462776140C0046EDDCD7B4A40
19351	663	139.70511300000001	139.71534399999999	51.550562999999997	51.541870000000003	Таежная	0103000020E61000000100000005000000815F2349907661407E5704FF5BC54940815F2349907661409EB12FD978C6494079AC1919E47661409EB12FD978C6494079AC1919E47661407E5704FF5BC54940815F2349907661407E5704FF5BC54940
19349	32415	140.185801	140.207415	52.097715000000001	52.085740999999999	Школьная	0103000020E610000001000000050000000D52F014F28561409276A38FF90A4A400D52F014F285614011AAD4EC810C4A406536C824A386614011AAD4EC810C4A406536C824A38661409276A38FF90A4A400D52F014F28561409276A38FF90A4A40
21837	482	140.75187500000001	140.78603699999999	51.486570999999998	51.464799999999997	Клубная	0103000020E61000000100000005000000C3F5285C0F9861402497FF907EBB4940C3F5285C0F9861404C1762F547BE4940450E1137279961404C1762F547BE4940450E1137279961402497FF907EBB4940C3F5285C0F9861402497FF907EBB4940
19150	713	139.462029	139.47973400000001	51.439267999999998	51.424909999999997	Набережная	0103000020E61000000100000005000000B7990AF1C86E614026DF6C7363B64940B7990AF1C86E6140F4160FEF39B84940F0181EFB596F6140F4160FEF39B84940F0181EFB596F614026DF6C7363B64940B7990AF1C86E614026DF6C7363B64940
22599	50527	140.39860300000001	140.42361199999999	51.956266999999997	51.916432	Советская	0103000020E61000000100000005000000CD22145BC18C61400281CEA44DF54940CD22145BC18C61403C9F01F566FA49402EC6C03A8E8D61403C9F01F566FA49402EC6C03A8E8D61400281CEA44DF54940CD22145BC18C61400281CEA44DF54940
19242	434	140.45486500000001	140.46910299999999	51.650706	51.640478999999999	Аптечная	0103000020E610000001000000050000000B630B418E8E61402C634337FBD149400B630B418E8E6140CEA78E554AD34940936E4BE4028F6140CEA78E554AD34940936E4BE4028F61402C634337FBD149400B630B418E8E61402C634337FBD14940
19136	32220	140.427457	140.480323	52.385326999999997	52.356076000000002	Партизанская	0103000020E61000000100000005000000486E4DBAAD8D6140FC71FBE5932D4A40486E4DBAAD8D614005A2276552314A40881057CE5E8F614005A2276552314A40881057CE5E8F6140FC71FBE5932D4A40486E4DBAAD8D6140FC71FBE5932D4A40
21830	32220	140.427457	140.480323	52.385326999999997	52.356076000000002	Парковая	0103000020E61000000100000005000000486E4DBAAD8D6140FC71FBE5932D4A40486E4DBAAD8D614005A2276552314A40881057CE5E8F614005A2276552314A40881057CE5E8F6140FC71FBE5932D4A40486E4DBAAD8D6140FC71FBE5932D4A40
22184	32220	140.427457	140.480323	52.385326999999997	52.356076000000002	Ключевая	0103000020E61000000100000005000000486E4DBAAD8D6140FC71FBE5932D4A40486E4DBAAD8D614005A2276552314A40881057CE5E8F614005A2276552314A40881057CE5E8F6140FC71FBE5932D4A40486E4DBAAD8D6140FC71FBE5932D4A40
19301	32059	140.16386399999999	140.17759100000001	52.771861999999999	52.761350999999998	Центральная	0103000020E61000000100000005000000BC1FB75F3E85614071E316F373614A40BC1FB75F3E8561403883BF5FCC624A400C2252D3AE8561403883BF5FCC624A400C2252D3AE85614071E316F373614A40BC1FB75F3E85614071E316F373614A40
21957	31714	135.298607	135.328	54.723247000000001	54.708055999999999	Таранца	0103000020E610000001000000050000006A6B44308EE9604048DE3994A15A4B406A6B44308EE960400EF7915B935C4B40D122DBF97EEA60400EF7915B935C4B40D122DBF97EEA604048DE3994A15A4B406A6B44308EE9604048DE3994A15A4B40
22097	31845	134.39827	134.420998	54.519939000000001	54.503839999999997	Совхозная	0103000020E610000001000000050000004B1FBAA0BECC6040543541D47D404B404B1FBAA0BECC60401D75745C8D424B40CE35CCD078CD60401D75745C8D424B40CE35CCD078CD6040543541D47D404B404B1FBAA0BECC6040543541D47D404B40
21953	31629	136.80541400000001	136.83752899999999	53.777563999999998	53.769151000000001	Карпова	0103000020E61000000100000005000000B3B794F3C5196140C5573B8A73E24A40B3B794F3C51961400246973787E34A40730E9E09CD1A61400246973787E34A40730E9E09CD1A6140C5573B8A73E24A40B3B794F3C5196140C5573B8A73E24A40
22298	31709	135.80735000000001	135.81618900000001	54.539009	54.528399	Центральная	0103000020E610000001000000050000009FCDAACFD5F960409B1E1494A2434B409FCDAACFD5F96040F59F353FFE444B405CCB64381EFA6040F59F353FFE444B405CCB64381EFA60409B1E1494A2434B409FCDAACFD5F960409B1E1494A2434B40
21960	31774	135.26677000000001	135.27798999999999	54.694023999999999	54.688920000000003	Мира	0103000020E61000000100000005000000BA313D6189E86040B9C7D2872E584B40BA313D6189E86040CE5147C7D5584B40AED3484BE5E86040CE5147C7D5584B40AED3484BE5E86040B9C7D2872E584B40BA313D6189E86040B9C7D2872E584B40
21962	31834	135.18959599999999	135.19812099999999	54.701376000000003	54.696663000000001	переулок Победы	0103000020E610000001000000050000007A6EA12B11E66040A8AAD0402C594B407A6EA12B11E66040831953B0C6594B40D3F4D90157E66040831953B0C6594B40D3F4D90157E66040A8AAD0402C594B407A6EA12B11E66040A8AAD0402C594B40
24161	50959	134.21499600000001	138.11319900000001	52.368796000000003	50.373199	Школьная	0103000020E61000000100000005000000AB984A3FE1C6604030F31DFCC42F4940AB984A3FE1C66040A47213B5342F4A40145E82539F436140A47213B5342F4A40145E82539F43614030F31DFCC42F4940AB984A3FE1C6604030F31DFCC42F4940
22083	31327	136.316676	136.36165500000001	51.403682000000003	51.387441000000003	Вокзальная	0103000020E61000000100000005000000B3EDB435220A61409510ACAA97B14940B3EDB435220A6140F0FD0DDAABB34940EBAD81AD920B6140F0FD0DDAABB34940EBAD81AD920B61409510ACAA97B14940B3EDB435220A61409510ACAA97B14940
19048	30954	136.87608399999999	136.91430800000001	51.028568	50.996822000000002	Клубная	0103000020E61000000100000005000000901150E1081C614077F700DD977F4940901150E1081C614027DBC01DA883494014CFD902421D614027DBC01DA883494014CFD902421D614077F700DD977F4940901150E1081C614077F700DD977F4940
22170	31283	136.51684800000001	136.532622	51.302636	51.283351000000003	Юбилейная	0103000020E610000001000000050000001920D1048A106140FB2477D844A449401920D1048A106140CF4BC5C6BCA649402AE44A3D0B116140CF4BC5C6BCA649402AE44A3D0B116140FB2477D844A449401920D1048A106140FB2477D844A44940
21948	4616	136.885031	136.900195	50.701537999999999	50.691975999999997	Южная	0103000020E61000000100000005000000471E882C521C6140F6CE68AB92584940471E882C521C61405C7347FFCB594940BAA0BE65CE1C61405C7347FFCB594940BAA0BE65CE1C6140F6CE68AB92584940471E882C521C6140F6CE68AB92584940
21939	30438	136.60209800000001	136.65409299999999	50.736108999999999	50.699325000000002	Парковая	0103000020E61000000100000005000000965F0663441361403A234A7B83594940965F06634413614048A5D8D1385E49405C717154EE14614048A5D8D1385E49405C717154EE1461403A234A7B83594940965F0663441361403A234A7B83594940
19205	30438	136.60209800000001	136.65409299999999	50.736108999999999	50.699325000000002	Ленина	0103000020E61000000100000005000000965F0663441361403A234A7B83594940965F06634413614048A5D8D1385E49405C717154EE14614048A5D8D1385E49405C717154EE1461403A234A7B83594940965F0663441361403A234A7B83594940
19287	31055	136.93220199999999	136.93607399999999	50.823669000000002	50.821331000000001	Весны	0103000020E6100000010000000500000081E84999D41D61407218CC5F2169494081E84999D41D614051DD5CFC6D69494059147651F41D614051DD5CFC6D69494059147651F41D61407218CC5F2169494081E84999D41D61407218CC5F21694940
21947	31186	136.57341500000001	136.59050999999999	51.267901999999999	51.255687999999999	А. Самара	0103000020E6100000010000000500000026016A6A5912614065FD6662BAA0494026016A6A591261403944DC9C4AA24940C03E3A75E51261403944DC9C4AA24940C03E3A75E512614065FD6662BAA0494026016A6A5912614065FD6662BAA04940
19298	31407	135.78227799999999	135.835781	51.576490999999997	51.555273	А. Никифорова	0103000020E610000001000000050000002B4CDF6B08F9604008AD872F13C749402B4CDF6B08F960401BB80375CAC94940C8B3CBB7BEFA60401BB80375CAC94940C8B3CBB7BEFA604008AD872F13C749402B4CDF6B08F9604008AD872F13C74940
9689	4678	134.634401	134.65492800000001	51.125539000000003	51.115254999999998	Центральная	0103000020E61000000100000005000000977153034DD46040A9D903ADC08E4940977153034DD46040B0AF75A91190494083A7902BF5D46040B0AF75A91190494083A7902BF5D46040A9D903ADC08E4940977153034DD46040A9D903ADC08E4940
21765	30907	136.41617400000001	136.46598499999999	50.769548999999998	50.758826999999997	Комсомольская	0103000020E6100000010000000500000042EE224C510D614030293E3E2161494042EE224C510D6140B2D5E59480624940A6ED5F59E90E6140B2D5E59480624940A6ED5F59E90E614030293E3E2161494042EE224C510D614030293E3E21614940
22041	31113	136.633306	136.67885899999999	51.211055999999999	51.185336	Центральная	0103000020E610000001000000050000008ACBF10A44146140BF620D17B99749408ACBF10A44146140F2CF0CE2039B49400C738236B9156140F2CF0CE2039B49400C738236B9156140BF620D17B99749408ACBF10A44146140BF620D17B9974940
18933	31113	136.633306	136.67885899999999	51.211055999999999	51.185336	Вокзальная	0103000020E610000001000000050000008ACBF10A44146140BF620D17B99749408ACBF10A44146140F2CF0CE2039B49400C738236B9156140F2CF0CE2039B49400C738236B9156140BF620D17B99749408ACBF10A44146140BF620D17B9974940
22090	31451	135.640254	135.71128400000001	51.695579000000002	51.654595	Школьная	0103000020E6100000010000000500000043E4F4F57CF460400490DAC4C9D3494043E4F4F57CF46040676490BB08D9494061C5A9D6C2F66040676490BB08D9494061C5A9D6C2F660400490DAC4C9D3494043E4F4F57CF460400490DAC4C9D34940
22088	31451	135.640254	135.71128400000001	51.695579000000002	51.654595	Пионерская	0103000020E6100000010000000500000043E4F4F57CF460400490DAC4C9D3494043E4F4F57CF46040676490BB08D9494061C5A9D6C2F66040676490BB08D9494061C5A9D6C2F660400490DAC4C9D3494043E4F4F57CF460400490DAC4C9D34940
21950	31550	135.06253799999999	135.111964	51.421140999999999	51.409351000000001	Ленина	0103000020E610000001000000050000003B18B14F00E26040DECA129D65B449403B18B14F00E260409B00C3F2E7B549408ACA863595E360409B00C3F2E7B549408ACA863595E36040DECA129D65B449403B18B14F00E26040DECA129D65B44940
21838	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Чкалова	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
19288	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Флерова	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
22188	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Суворова	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
22189	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Сахалинская	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
22107	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Полины Осипенко	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
22306	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Пионерская	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
22106	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Первомайская	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
19211	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Ленина	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
19243	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Кишиневская	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
19148	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Киевская	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
22108	4353	140.218176	140.320504	48.998918000000003	48.924950000000003	Калинина	0103000020E61000000100000005000000B5183C4CFB866140B537F8C264764840B5183C4CFB86614060B1868BDC7F484097C79A91418A614060B1868BDC7F484097C79A91418A6140B537F8C264764840B5183C4CFB866140B537F8C264764840
19246	15043	140.19774899999999	140.258385	49.012399000000002	48.986286	Черемховская	0103000020E6100000010000000500000022FAB5F5538661405740A19E3E7E484022FAB5F55386614066C0594A96814840DD989EB04488614066C0594A96814840DD989EB0448861405740A19E3E7E484022FAB5F5538661405740A19E3E7E4840
21721	15043	140.19774899999999	140.258385	49.012399000000002	48.986286	Селенгинская	0103000020E6100000010000000500000022FAB5F5538661405740A19E3E7E484022FAB5F55386614066C0594A96814840DD989EB04488614066C0594A96814840DD989EB0448861405740A19E3E7E484022FAB5F5538661405740A19E3E7E4840
21722	15248	140.30569	140.32902000000001	49.006388999999999	48.991506000000001	Украинская	0103000020E61000000100000005000000DB166536C8896140D6E429ABE97E4840DB166536C8896140EE06D15AD18048405C77F354878A6140EE06D15AD18048405C77F354878A6140D6E429ABE97E4840DB166536C8896140D6E429ABE97E4840
22168	15144	140.21072899999999	140.33070799999999	49.057394000000002	49.009633000000001	Николаева	0103000020E61000000100000005000000336ABE4ABE8661402FFB75A73B814840336ABE4ABE8661404A7EC4AF58874840D190F128958A61404A7EC4AF58874840D190F128958A61402FFB75A73B814840336ABE4ABE8661402FFB75A73B814840
21982	15144	140.21072899999999	140.33070799999999	49.057394000000002	49.009633000000001	Невельского	0103000020E61000000100000005000000336ABE4ABE8661402FFB75A73B814840336ABE4ABE8661404A7EC4AF58874840D190F128958A61404A7EC4AF58874840D190F128958A61402FFB75A73B814840336ABE4ABE8661402FFB75A73B814840
21767	5623	140.12432899999999	140.13952	48.902172	48.889118000000003	Клубная	0103000020E61000000100000005000000389ECF80FA83614079245E9ECE714840389ECF80FA836140F7AE415F7A7348406AA4A5F276846140F7AE415F7A7348406AA4A5F27684614079245E9ECE714840389ECF80FA83614079245E9ECE714840
22771	50557	132.982552	133.06769499999999	51.137645999999997	51.11703	 Речная	0103000020E61000000100000005000000D253E410719F60405053CBD6FA8E4940D253E410719F60406D3656629E9149404963B48E2AA260406D3656629E9149404963B48E2AA260405053CBD6FA8E4940D253E410719F60405053CBD6FA8E4940
79698	50411	135.024665	135.07599500000001	48.563380000000002	48.556050999999997	Победы	0103000020E61000000100000005000000630B410ECAE060403CF4DDAD2C474840630B410ECAE06040399CF9D51C4848401BF5108D6EE26040399CF9D51C4848401BF5108D6EE260403CF4DDAD2C474840630B410ECAE060403CF4DDAD2C474840
79662	50411	135.06587099999999	135.09357499999999	48.483561999999999	48.467005	Ленина	0103000020E6100000010000000500000027D87F9D1BE26040C408E1D1C63B484027D87F9D1BE260404FCB0F5CE53D48402497FF90FEE260404FCB0F5CE53D48402497FF90FEE26040C408E1D1C63B484027D87F9D1BE26040C408E1D1C63B4840
21696	50411	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	Карпинского	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
79690	50411	135.080163	135.08408900000001	48.47925	48.477505999999998	Вострецова	0103000020E610000001000000050000002DEBFEB190E2604067D2A6EA1E3D48402DEBFEB190E26040D34D6210583D4840821E6ADBB0E26040D34D6210583D4840821E6ADBB0E2604067D2A6EA1E3D48402DEBFEB190E2604067D2A6EA1E3D4840
79676	50411	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	40 Лет Победы	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
79486	61617	135.109601	135.11530500000001	48.425576	48.407654999999998	Центральная	0103000020E610000001000000050000007CD3F4D981E360408386FE092E3448407CD3F4D981E3604033FB3C467936484017821C94B0E3604033FB3C467936484017821C94B0E360408386FE092E3448407CD3F4D981E360408386FE092E344840
79432	61579	134.130833	134.209597	52.065277000000002	52.023677999999997	Таежная	0103000020E610000001000000050000009A07B0C82FC460403DD175E107034A409A07B0C82FC460402B172AFF5A084A40DF8AC404B5C660402B172AFF5A084A40DF8AC404B5C660403DD175E107034A409A07B0C82FC460403DD175E107034A40
19163	16616	140.87322800000001	140.88675699999999	53.088161999999997	53.079849000000003	Центральная	0103000020E6100000010000000500000073BED87BF19B614025CFF57D388A4A4073BED87BF19B6140FE5F75E4488B4A40F84F3750609C6140FE5F75E4488B4A40F84F3750609C614025CFF57D388A4A4073BED87BF19B614025CFF57D388A4A40
21760	16931	140.18423799999999	140.21232800000001	53.545675000000003	53.538905999999997	Центральная	0103000020E61000000100000005000000C6151747E585614020CF2EDFFAC44A40C6151747E5856140569FABADD8C54A40CE001764CB866140569FABADD8C54A40CE001764CB86614020CF2EDFFAC44A40C6151747E585614020CF2EDFFAC44A40
21870	50439	138.73109600000001	141.54502400000001	54.358401999999998	51.755795999999997	Набережная	0103000020E6100000010000000500000091477023655761404B395FECBDE0494091477023655761401669E21DE02D4B4020F12BD670B161401669E21DE02D4B4020F12BD670B161404B395FECBDE0494091477023655761404B395FECBDE04940
22005	16520	141.093863	141.10122899999999	53.012661000000001	53.005813000000003	Школьная	0103000020E61000000100000005000000BE69FAEC00A361402272FA7ABE804A40BE69FAEC00A36140A3772AE09E814A40048D99443DA36140A3772AE09E814A40048D99443DA361402272FA7ABE804A40BE69FAEC00A361402272FA7ABE804A40
19275	7277	141.239543	141.25673699999999	53.049633	53.033617999999997	Невельского	0103000020E610000001000000050000008BDF1456AAA76140494739984D844A408BDF1456AAA76140B4E6C75F5A864A408A55833037A86140B4E6C75F5A864A408A55833037A86140494739984D844A408BDF1456AAA76140494739984D844A40
19247	7166	140.633072	140.81411	53.162585	53.127408000000003	Школьная	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21725	7166	140.633072	140.81411	53.162585	53.127408000000003	Чихачёва	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21739	7166	140.633072	140.81411	53.162585	53.127408000000003	Чихачева	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21755	7166	140.633072	140.81411	53.162585	53.127408000000003	Читинская	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21862	7166	140.633072	140.81411	53.162585	53.127408000000003	Хабаровская	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21856	7166	140.633072	140.81411	53.162585	53.127408000000003	Советская	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
19203	7166	140.633072	140.81411	53.162585	53.127408000000003	Сибирская	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
22117	7166	140.633072	140.81411	53.162585	53.127408000000003	Северная	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21855	7166	140.633072	140.81411	53.162585	53.127408000000003	Свободная	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
18902	7166	140.633072	140.81411	53.162585	53.127408000000003	Приамурская	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
22118	7166	140.633072	140.81411	53.162585	53.127408000000003	Попова	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21751	7166	140.633072	140.81411	53.162585	53.127408000000003	Пионерская	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
22120	7166	140.633072	140.81411	53.162585	53.127408000000003	М.Горького	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
19038	7166	140.633072	140.81411	53.162585	53.127408000000003	Луначарского	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
21749	7166	140.633072	140.81411	53.162585	53.127408000000003	Кантера	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
19274	7166	140.633072	140.81411	53.162585	53.127408000000003	Аэродромная	0103000020E610000001000000050000006D00362042946140D89FC4E74E904A406D00362042946140FBE8D495CF944A40172B6A300D9A6140FBE8D495CF944A40172B6A300D9A6140D89FC4E74E904A406D00362042946140D89FC4E74E904A40
18919	17109	141.195256	141.221496	52.863858999999998	52.851374999999997	Центральная	0103000020E6100000010000000500000021CB82893FA66140E5D022DBF96C4A4021CB82893FA6614079AD84EE926E4A403C86C77E16A7614079AD84EE926E4A403C86C77E16A76140E5D022DBF96C4A4021CB82893FA66140E5D022DBF96C4A40
19284	17212	141.27849399999999	141.31485799999999	52.124529000000003	52.112496	Школьная	0103000020E610000001000000050000003BC43F6CE9A861402577D844660E4A403BC43F6CE9A86140A933F790F00F4A40499C155113AA6140A933F790F00F4A40499C155113AA61402577D844660E4A403BC43F6CE9A861402577D844660E4A40
21878	17006	139.89010300000001	139.94605899999999	53.943679000000003	53.925978999999998	Черкашина	0103000020E610000001000000050000004A6249B97B7C614032E4D87A86F64A404A6249B97B7C614004763579CAF84A40C422861D467E614004763579CAF84A40C422861D467E614032E4D87A86F64A404A6249B97B7C614032E4D87A86F64A40
22129	16748	140.13344699999999	140.21090899999999	53.27496	53.246692000000003	Мира	0103000020E61000000100000005000000FA97A43245846140A9177C9A939F4A40FA97A43245846140A5DAA7E331A34A40D32D3BC4BF866140A5DAA7E331A34A40D32D3BC4BF866140A9177C9A939F4A40FA97A43245846140A9177C9A939F4A40
19173	16748	140.13344699999999	140.21090899999999	53.27496	53.246692000000003	50 лет ССР	0103000020E61000000100000005000000FA97A43245846140A9177C9A939F4A40FA97A43245846140A5DAA7E331A34A40D32D3BC4BF866140A5DAA7E331A34A40D32D3BC4BF866140A9177C9A939F4A40FA97A43245846140A9177C9A939F4A40
19281	17133	141.50176999999999	141.531361	52.228532000000001	52.204684999999998	Портовая	0103000020E61000000100000005000000A583F57F0EB06140AA7D3A1E331A4A40A583F57F0EB06140740B5D89401D4A40D6ABC8E800B16140740B5D89401D4A40D6ABC8E800B16140AA7D3A1E331A4A40A583F57F0EB06140AA7D3A1E331A4A40
22006	16615	140.838616	140.878681	53.129148000000001	53.098274000000004	Советская	0103000020E61000000100000005000000E0BC38F1D59A61400806103E948C4A40E0BC38F1D59A6140022CF2EB87904A40BBD39D271E9C6140022CF2EB87904A40BBD39D271E9C61400806103E948C4A40E0BC38F1D59A61400806103E948C4A40
21879	17041	140.77229299999999	140.789963	53.086717999999998	53.074764000000002	Строительная	0103000020E61000000100000005000000C03DCF9FB69861408675E3DD91894A40C03DCF9FB6986140BDFC4E93198B4A409A417C6047996140BDFC4E93198B4A409A417C60479961408675E3DD91894A40C03DCF9FB69861408675E3DD91894A40
19170	16706	140.311035	140.33372700000001	53.237402000000003	53.226227999999999	Центральная	0103000020E610000001000000050000002A1DACFFF389614041B8020AF59C4A402A1DACFFF3896140A4005130639E4A405AD93EE4AD8A6140A4005130639E4A405AD93EE4AD8A614041B8020AF59C4A402A1DACFFF389614041B8020AF59C4A40
19226	28833	136.51595900000001	136.582075	49.449967000000001	49.429465	Шоссейная	0103000020E6100000010000000500000076E272BC8210614069E388B5F8B6484076E272BC82106140BEA3C68498B94840371AC05BA0126140BEA3C68498B94840371AC05BA012614069E388B5F8B6484076E272BC8210614069E388B5F8B64840
21943	28833	136.51595900000001	136.582075	49.449967000000001	49.429465	Кола Бельды	0103000020E6100000010000000500000076E272BC8210614069E388B5F8B6484076E272BC82106140BEA3C68498B94840371AC05BA0126140BEA3C68498B94840371AC05BA012614069E388B5F8B6484076E272BC8210614069E388B5F8B64840
22110	28833	136.51595900000001	136.582075	49.449967000000001	49.429465	Калинина	0103000020E6100000010000000500000076E272BC8210614069E388B5F8B6484076E272BC82106140BEA3C68498B94840371AC05BA0126140BEA3C68498B94840371AC05BA012614069E388B5F8B6484076E272BC8210614069E388B5F8B64840
22284	28833	136.51595900000001	136.582075	49.449967000000001	49.429465	40 лет Победы	0103000020E6100000010000000500000076E272BC8210614069E388B5F8B6484076E272BC82106140BEA3C68498B94840371AC05BA0126140BEA3C68498B94840371AC05BA012614069E388B5F8B6484076E272BC8210614069E388B5F8B64840
22045	29048	136.76552899999999	136.790663	49.472141999999998	49.465755000000001	Набережная	0103000020E610000001000000050000007764AC367F18614068791EDC9DBB48407764AC367F186140B58828266FBC484008E57D1C4D196140B58828266FBC484008E57D1C4D19614068791EDC9DBB48407764AC367F18614068791EDC9DBB4840
19304	28410	136.27248800000001	136.31499700000001	48.974820000000001	48.946089999999998	Пассара	0103000020E61000000100000005000000AE11C138B80861404C89247A19794840AE11C138B80861404DBED9E6C67C4840D2AA9674140A61404DBED9E6C67C4840D2AA9674140A61404C89247A19794840AE11C138B80861404C89247A19794840
21840	28672	136.62284	136.63702499999999	49.330925999999998	49.323498000000001	Почтовая	0103000020E6100000010000000500000080D4264EEE1361402429E96168A9484080D4264EEE136140B3B27DC85BAA484080B7408262146140B3B27DC85BAA484080B74082621461402429E96168A9484080D4264EEE1361402429E96168A94840
19292	28593	136.459464	136.473837	49.296385999999998	49.272486000000001	Школьная	0103000020E610000001000000050000000FB6D8EDB30E6140164F3DD2E0A248400FB6D8EDB30E6140027FF8F9EFA54840505436AC290F6140027FF8F9EFA54840505436AC290F6140164F3DD2E0A248400FB6D8EDB30E6140164F3DD2E0A24840
22151	28327	136.23101299999999	136.25613899999999	48.925708	48.906146	Центральная	0103000020E610000001000000050000006DFE5F75640761405BB39597FC7348406DFE5F7564076140A2D288997D7648405D876A4A32086140A2D288997D7648405D876A4A320861405BB39597FC7348406DFE5F75640761405BB39597FC734840
22263	29087	136.883397	136.914254	49.514074000000001	49.501795000000001	Первомайская	0103000020E610000001000000050000004E0CC9C9441C6140EE258DD13AC048404E0CC9C9441C6140A9DC442DCDC1484097C79A91411D6140A9DC442DCDC1484097C79A91411D6140EE258DD13AC048404E0CC9C9441C6140EE258DD13AC04840
22049	29190	136.88599300000001	136.916077	49.694873999999999	49.666347000000002	Школьная	0103000020E6100000010000000500000085EFFD0D5A1C6140D464C6DB4AD5484085EFFD0D5A1C61409C6B98A1F1D84840C573B680501D61409C6B98A1F1D84840C573B680501D6140D464C6DB4AD5484085EFFD0D5A1C6140D464C6DB4AD54840
79647	61764	136.49204499999999	136.50666100000001	49.114297000000001	49.095275000000001	Юбилейная	0103000020E6100000010000000500000021E527D5BE0F61402E90A0F8318C484021E527D5BE0F6140F583BA48A18E48401425219136106140F583BA48A18E484014252191361061402E90A0F8318C484021E527D5BE0F61402E90A0F8318C4840
22047	29148	136.92701	136.96492799999999	49.681294000000001	49.659407999999999	Комсомольская	0103000020E610000001000000050000001422E010AA1D6140425C397B67D448401422E010AA1D6140037B4CA434D74840D45FAFB0E01E6140037B4CA434D74840D45FAFB0E01E6140425C397B67D448401422E010AA1D6140425C397B67D44840
18960	28606	136.509221	136.516929	49.441040999999998	49.435791999999999	Калинина	0103000020E61000000100000005000000F7ADD6894B106140E1ED4108C8B74840F7ADD6894B106140FA980F0874B8484054ABAFAE8A106140FA980F0874B8484054ABAFAE8A106140E1ED4108C8B74840F7ADD6894B106140E1ED4108C8B74840
19204	28533	136.465294	136.48074500000001	49.270564	49.257053999999997	Зеленая	0103000020E61000000100000005000000CD203EB0E30E61402AA73D25E7A04840CD203EB0E30E6140CBBC55D7A1A24840E6965643620F6140CBBC55D7A1A24840E6965643620F61402AA73D25E7A04840CD203EB0E30E61402AA73D25E7A04840
21857	28507	136.46512300000001	136.47975700000001	49.175333000000002	49.162073999999997	Лесная	0103000020E61000000100000005000000C233A149E20E614015C440D7BE944840C233A149E20E61406D74CE4F71964840DE205A2B5A0F61406D74CE4F71964840DE205A2B5A0F614015C440D7BE944840C233A149E20E614015C440D7BE944840
22270	28734	137.06726399999999	137.08543700000001	49.327626000000002	49.318348999999998	Комсомольская	0103000020E610000001000000050000005706D506272261406EDBF7A8BFA848405706D50627226140DFA815A6EFA94840CA1B60E6BB226140DFA815A6EFA94840CA1B60E6BB2261406EDBF7A8BFA848405706D506272261406EDBF7A8BFA84840
18966	29225	136.77652399999999	136.81365099999999	49.851058000000002	49.837057999999999	Зеленая	0103000020E61000000100000005000000E411DC48D9186140766D6FB724EB4840E411DC48D9186140E57FF277EFEC4840726BD26D091A6140E57FF277EFEC4840726BD26D091A6140766D6FB724EB4840E411DC48D9186140766D6FB724EB4840
22271	28768	137.060733	137.09156300000001	49.221057000000002	49.208450999999997	Лесопильная	0103000020E6100000010000000500000037195586F1216140C4E8B985AE9A484037195586F1216140A4C684984B9C4840C2508715EE226140A4C684984B9C4840C2508715EE226140C4E8B985AE9A484037195586F1216140C4E8B985AE9A4840
22462	50489	135.03553500000001	135.05213599999999	48.556379	48.484684000000001	Тихоокеанская	0103000020E61000000100000005000000A1DB4B1A23E160407E7214200A3E4840A1DB4B1A23E160403197546D3747484037DE1D19ABE160403197546D3747484037DE1D19ABE160407E7214200A3E4840A1DB4B1A23E160407E7214200A3E4840
22065	25108	138.42271400000001	138.440303	51.074815000000001	51.061616000000001	Школьная	0103000020E61000000100000005000000F7B182DF864D614086747808E3874940F7B182DF864D61400820B58993894940952A51F6164E61400820B58993894940952A51F6164E614086747808E3874940F7B182DF864D614086747808E3874940
21852	25430	136.840125	136.90018599999999	50.419280999999998	50.394508999999999	Добровольского	0103000020E61000000100000005000000AAF1D24DE21A6140247D5A457F324940AAF1D24DE21A6140C66AF3FFAA35494025CADE52CE1C6140C66AF3FFAA35494025CADE52CE1C6140247D5A457F324940AAF1D24DE21A6140247D5A457F324940
22194	25430	136.840125	136.90018599999999	50.419280999999998	50.394508999999999	Гайдара	0103000020E61000000100000005000000AAF1D24DE21A6140247D5A457F324940AAF1D24DE21A6140C66AF3FFAA35494025CADE52CE1C6140C66AF3FFAA35494025CADE52CE1C6140247D5A457F324940AAF1D24DE21A6140247D5A457F324940
21727	24943	138.476011	138.49540500000001	50.345362000000002	50.335065999999998	Центральная	0103000020E6100000010000000500000029B16B7B3B4F614032005471E32A494029B16B7B3B4F6140FDA36FD2342C4940CC28965BDA4F6140FDA36FD2342C4940CC28965BDA4F614032005471E32A494029B16B7B3B4F614032005471E32A4940
22311	24867	137.911923	137.961411	50.277264000000002	50.257075999999998	Торговая	0103000020E610000001000000050000000CAF24792E3D6140124BCADDE72049400CAF24792E3D6140D82D02637D234940786000E1C33E6140D82D02637D234940786000E1C33E6140124BCADDE72049400CAF24792E3D6140124BCADDE7204940
22204	25827	137.472691	137.53684000000001	50.375342000000003	50.351950000000002	Садовая	0103000020E61000000100000005000000A243E048202F6140E2E995B20C2D4940A243E048202F61405A68E7340B304940E96514CB2D3161405A68E7340B304940E96514CB2D316140E2E995B20C2D4940A243E048202F6140E2E995B20C2D4940
22228	50477	137.24467200000001	137.276544	50.655465	50.644705000000002	УИК-ул. Набережная	0103000020E61000000100000005000000E7C75F5AD4276140AA4885B185524940E7C75F5AD42761401956F146E6534940F67CCD72D92861401956F146E6534940F67CCD72D9286140AA4885B185524940E7C75F5AD4276140AA4885B185524940
22002	25686	137.05960099999999	137.114497	50.513427999999998	50.470781000000002	Совгаванская	0103000020E61000000100000005000000E2395B40E8216140024A438D423C4940E2395B40E8216140E36C3A02B8414940AFCF9CF5A9236140E36C3A02B8414940AFCF9CF5A9236140024A438D423C4940E2395B40E8216140024A438D423C4940
22000	25586	136.956726	136.983271	50.463206999999997	50.441733999999997	Центральная	0103000020E610000001000000050000007427D87F9D1E614000C45DBD8A3849407427D87F9D1E61409E23F25D4A3B49405E83BEF4761F61409E23F25D4A3B49405E83BEF4761F614000C45DBD8A3849407427D87F9D1E614000C45DBD8A384940
22099	25018	138.620397	138.630539	51.182727999999997	51.176414999999999	Школьная	0103000020E610000001000000050000002B31CF4ADA5361400DC347C4949649402B31CF4ADA536140200890A16397494048FB1F602D546140200890A16397494048FB1F602D5461400DC347C4949649402B31CF4ADA5361400DC347C494964940
19266	25191	137.91999799999999	137.93190100000001	50.799947000000003	50.793411999999996	Школьная	0103000020E61000000100000005000000554CA59F703D6140812040868E654940554CA59F703D614044C4CDA96466494083C30B22D23D614044C4CDA96466494083C30B22D23D6140812040868E654940554CA59F703D6140812040868E654940
22201	25145	138.176602	138.19946400000001	50.931641999999997	50.906464999999997	Кретова	0103000020E6100000010000000500000010CD3CB9A6456140FCFB8C0B0774494010CD3CB9A64561403ECA880B4077494057975302624661403ECA880B407749405797530262466140FCFB8C0B0774494010CD3CB9A6456140FCFB8C0B07744940
21998	25527	136.93246300000001	136.95949300000001	50.386296000000002	50.370728999999997	Таёжная	0103000020E610000001000000050000005D37A5BCD61D6140E256410C742F49405D37A5BCD61D6140AE49B72572314940B6F7A92AB41E6140AE49B72572314940B6F7A92AB41E6140E256410C742F49405D37A5BCD61D6140E256410C742F4940
22373	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Победы	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22376	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Первостроителей	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
18907	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Октябрьский	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22374	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Московский	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19235	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Ленина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19220	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	проспект Интернациональный	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
24150	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	пр.Ленина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19313	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	переулок Сельский	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19144	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	мкр.Дружба	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19019	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	бульвар Юности	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
18974	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Щорса	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22412	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Тепличная	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19058	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Советская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19036	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Севастопольская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19236	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Пирогова	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19066	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Пионерская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22388	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Первостроителей	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19237	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Магистральное шоссе	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19047	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Культурная	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22348	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Краснофлотская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19072	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Красногвардейская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22362	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Комсомольское шоссе	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19317	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Комсомольская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22181	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Комитетская	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19230	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Кирова	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
18947	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Калинина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19221	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Гагарина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19219	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Восточное шоссе	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19079	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Вокзальная	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19025	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Васянина	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
22300	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Вагонная	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19225	5366	136.86117200000001	137.15650199999999	50.699987	50.516188	Аллея Труда	0103000020E61000000100000005000000640795B88E1B6140384BC97212424940640795B88E1B614005508C2C9959494046787B100225614005508C2C9959494046787B1002256140384BC97212424940640795B88E1B6140384BC97212424940
19256	24952	138.578508	138.60357999999999	50.199005999999997	50.184859000000003	Пионерская	0103000020E610000001000000050000002E8F35238352614086AFAF75A91749402E8F35238352614098DA520779194940A11001875053614098DA520779194940A11001875053614086AFAF75A91749402E8F35238352614086AFAF75A9174940
22191	24785	137.378162	137.397727	50.195010000000003	50.181992999999999	Центральная	0103000020E61000000100000005000000E1D231E7192C6140EB8CEF8B4B174940E1D231E7192C61404D327216F61849408F37F92DBA2C61404D327216F61849408F37F92DBA2C6140EB8CEF8B4B174940E1D231E7192C6140EB8CEF8B4B174940
21724	24883	138.080195	138.12707800000001	50.326469000000003	50.304456000000002	Школьная	0103000020E61000000100000005000000B0C91AF5904261401689096AF8264940B0C91AF590426140341477BCC929494051C1E10511446140341477BCC929494051C1E105114461401689096AF8264940B0C91AF5904261401689096AF8264940
22119	25336	137.192273	137.21296100000001	50.728178999999997	50.709553	Советская	0103000020E61000000100000005000000ECDCB41927266140ACE3F8A1D25A4940ECDCB4192726614026512FF8345D49405A4A9693D026614026512FF8345D49405A4A9693D0266140ACE3F8A1D25A4940ECDCB41927266140ACE3F8A1D25A4940
21864	7927	137.223175	137.26113799999999	50.379449999999999	50.352983999999999	Октябрьская	0103000020E610000001000000050000001DC9E53F24276140710168942E2D49401DC9E53F24276140CD3B4ED191304940C537143E5B286140CD3B4ED191304940C537143E5B286140710168942E2D49401DC9E53F24276140710168942E2D4940
21986	25629	137.07649799999999	137.08873299999999	50.430236000000001	50.417869000000003	Школьная	0103000020E61000000100000005000000B306EFAB7222614091813CBB7C354940B306EFAB72226140EBC726F9113749406EA296E6D6226140EBC726F9113749406EA296E6D622614091813CBB7C354940B306EFAB7222614091813CBB7C354940
19159	25230	137.39103399999999	137.408354	50.671863000000002	50.663237000000002	Набережная	0103000020E61000000100000005000000F833BC59832C6140A33F34F3E4544940F833BC59832C61403C32569BFF5549401B66683C112D61403C32569BFF5549401B66683C112D6140A33F34F3E4544940F833BC59832C6140A33F34F3E4544940
19248	5849	137.365846	137.40232599999999	50.395772000000001	50.376714999999997	Хабаровская	0103000020E61000000100000005000000EBABAB02B52B6140D174763238304940EBABAB02B52B614015562AA8A8324940938AC6DADF2C614015562AA8A8324940938AC6DADF2C6140D174763238304940EBABAB02B52B6140D174763238304940
21996	25393	137.40196700000001	137.41730100000001	51.100093000000001	51.09205	Школьная	0103000020E6100000010000000500000048E2E5E9DC2C614064CC5D4BC88B494048E2E5E9DC2C61407EC7F0D8CF8C4940D272A0875A2D61407EC7F0D8CF8C4940D272A0875A2D614064CC5D4BC88B494048E2E5E9DC2C614064CC5D4BC88B4940
22288	50482	135.03411600000001	135.037655	48.510596	48.505372999999999	улица Чкалова	0103000020E61000000100000005000000A708707A17E1604005A4FD0FB0404840A708707A17E16040F5BBB0355B414840FD30427834E16040F5BBB0355B414840FD30427834E1604005A4FD0FB0404840A708707A17E1604005A4FD0FB0404840
19199	30036	136.467602	136.515366	52.435225000000003	52.408302999999997	Школьная	0103000020E610000001000000050000006A317898F60E6140E9EDCF4543344A406A317898F60E614068B3EA73B5374A400D6FD6E07D10614068B3EA73B5374A400D6FD6E07D106140E9EDCF4543344A406A317898F60E6140E9EDCF4543344A40
19293	30036	136.467602	136.515366	52.435225000000003	52.408302999999997	Центральная	0103000020E610000001000000050000006A317898F60E6140E9EDCF4543344A406A317898F60E614068B3EA73B5374A400D6FD6E07D10614068B3EA73B5374A400D6FD6E07D106140E9EDCF4543344A406A317898F60E6140E9EDCF4543344A40
21745	30036	136.467602	136.515366	52.435225000000003	52.408302999999997	Амгуньская	0103000020E610000001000000050000006A317898F60E6140E9EDCF4543344A406A317898F60E614068B3EA73B5374A400D6FD6E07D10614068B3EA73B5374A400D6FD6E07D106140E9EDCF4543344A406A317898F60E6140E9EDCF4543344A40
19295	30036	136.467602	136.515366	52.435225000000003	52.408302999999997	60 лет Октября	0103000020E610000001000000050000006A317898F60E6140E9EDCF4543344A406A317898F60E614068B3EA73B5374A400D6FD6E07D10614068B3EA73B5374A400D6FD6E07D106140E9EDCF4543344A406A317898F60E6140E9EDCF4543344A40
22249	50481	138.84538000000001	138.86873600000001	52.907943000000003	52.902935999999997	Набережная	0103000020E6100000010000000500000029965B5A0D5B6140C630276893734A4029965B5A0D5B6140EAD0E97937744A40749B70AFCC5B6140EAD0E97937744A40749B70AFCC5B6140C630276893734A4029965B5A0D5B6140C630276893734A40
22236	50479	135.81780599999999	135.85297499999999	52.327717999999997	52.303097999999999	Черенева	0103000020E610000001000000050000001F0F7D772BFA6040D3BD4EEACB264A401F0F7D772BFA6040BF27D6A9F2294A40C7293A924BFB6040BF27D6A9F2294A40C7293A924BFB6040D3BD4EEACB264A401F0F7D772BFA6040D3BD4EEACB264A40
22148	27791	135.59532899999999	135.60513	47.116630000000001	47.107559999999999	Школьная	0103000020E61000000100000005000000882B67EF0CF36040CB2DAD86C48D4740882B67EF0CF36040C2DD59BBED8E474083FA96395DF36040C2DD59BBED8E474083FA96395DF36040CB2DAD86C48D4740882B67EF0CF36040CB2DAD86C48D4740
22015	26440	134.67576	134.705772	48.011736999999997	48.000354999999999	Первомайская	0103000020E610000001000000050000003D7E6FD39FD56040EEB1F4A10B0048403D7E6FD39FD560409A93179980014840D74D29AF95D660409A93179980014840D74D29AF95D66040EEB1F4A10B0048403D7E6FD39FD56040EEB1F4A10B004840
22135	26529	134.914963	135.000698	47.897385	47.869884999999996	переулок Степной	0103000020E610000001000000050000009A417C6047DD6040F623456458EF47409A417C6047DD6040E275FD82DDF2474086E5CFB705E06040E275FD82DDF2474086E5CFB705E06040F623456458EF47409A417C6047DD6040F623456458EF4740
22132	26529	134.914963	135.000698	47.897385	47.869884999999996	Советская	0103000020E610000001000000050000009A417C6047DD6040F623456458EF47409A417C6047DD6040E275FD82DDF2474086E5CFB705E06040E275FD82DDF2474086E5CFB705E06040F623456458EF47409A417C6047DD6040F623456458EF4740
21886	26529	134.914963	135.000698	47.897385	47.869884999999996	Менделеева	0103000020E610000001000000050000009A417C6047DD6040F623456458EF47409A417C6047DD6040E275FD82DDF2474086E5CFB705E06040E275FD82DDF2474086E5CFB705E06040F623456458EF47409A417C6047DD6040F623456458EF4740
22209	26529	134.914963	135.000698	47.897385	47.869884999999996	Ленина	0103000020E610000001000000050000009A417C6047DD6040F623456458EF47409A417C6047DD6040E275FD82DDF2474086E5CFB705E06040E275FD82DDF2474086E5CFB705E06040F623456458EF47409A417C6047DD6040F623456458EF4740
21883	26529	134.914963	135.000698	47.897385	47.869884999999996	Безымянная	0103000020E610000001000000050000009A417C6047DD6040F623456458EF47409A417C6047DD6040E275FD82DDF2474086E5CFB705E06040E275FD82DDF2474086E5CFB705E06040F623456458EF47409A417C6047DD6040F623456458EF4740
22021	50454	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	Центральная	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
22004	25851	136.77251699999999	136.837277	48.005443	47.9666	Центральная	0103000020E6100000010000000500000054539275B818614024287E8CB9FB474054539275B8186140FE7E315BB20048402D9622F9CA1A6140FE7E315BB20048402D9622F9CA1A614024287E8CB9FB474054539275B818614024287E8CB9FB4740
22196	25851	136.77251699999999	136.837277	48.005443	47.9666	Городская	0103000020E6100000010000000500000054539275B818614024287E8CB9FB474054539275B8186140FE7E315BB20048402D9622F9CA1A6140FE7E315BB20048402D9622F9CA1A614024287E8CB9FB474054539275B818614024287E8CB9FB4740
21776	27935	136.21442099999999	136.24623	47.682146000000003	47.673184999999997	Центральная	0103000020E610000001000000050000006BD26D89DC066140319413ED2AD647406BD26D89DC066140728C648F50D7474069A9BC1DE1076140728C648F50D7474069A9BC1DE1076140319413ED2AD647406BD26D89DC066140319413ED2AD64740
22312	27877	136.08731	136.09985900000001	47.157865000000001	47.146185000000003	Школьная	0103000020E61000000100000005000000A453573ECB0261403815A930B6924740A453573ECB0261406E179AEB34944740C366800B320361406E179AEB34944740C366800B320361403815A930B6924740A453573ECB0261403815A930B6924740
18928	27185	135.373436	135.40778800000001	48.013309999999997	47.995308999999999	Специалистов	0103000020E61000000100000005000000C5E40D30F3EB60400D350A4966FF4740C5E40D30F3EB6040D95A5F24B401484071766B990CED6040D95A5F24B401484071766B990CED60400D350A4966FF4740C5E40D30F3EB60400D350A4966FF4740
19309	28081	135.38634500000001	135.450952	48.146939000000003	48.116962000000001	Клубная	0103000020E61000000100000005000000247F30F05CEC6040F86F5E9CF80E4840247F30F05CEC6040E4C0ABE5CE1248401B82E3326EEE6040E4C0ABE5CE1248401B82E3326EEE6040F86F5E9CF80E4840247F30F05CEC6040F86F5E9CF80E4840
18958	28314	136.02249599999999	136.05930000000001	48.132966000000003	48.106054999999998	Пушкина	0103000020E610000001000000050000004E098849B8006140E449D235930D48404E098849B80061406FBDA60705114840E4141DC9E50161406FBDA60705114840E4141DC9E5016140E449D235930D48404E098849B8006140E449D235930D4840
22014	27460	135.398966	135.44282200000001	47.863242	47.843215999999998	Юбилейная	0103000020E61000000100000005000000E9465854C4EC604062BB7B80EEEB4740E9465854C4EC60404E44BFB67EEE474061FE0A992BEE60404E44BFB67EEE474061FE0A992BEE604062BB7B80EEEB4740E9465854C4EC604062BB7B80EEEB4740
22130	4496	135.61492999999999	135.63110900000001	47.873578000000002	47.864342000000001	Зеленая	0103000020E6100000010000000500000089EAAD81ADF36040954737C2A2EE474089EAAD81ADF36040A7406667D1EF4740C366800B32F46040A7406667D1EF4740C366800B32F46040954737C2A2EE474089EAAD81ADF36040954737C2A2EE4740
22030	27330	135.583687	135.61483200000001	47.909109999999998	47.887132000000001	Колхозная	0103000020E6100000010000000500000036035C90ADF26040179E978A8DF1474036035C90ADF26040B83B6BB75DF44740199128B4ACF36040B83B6BB75DF44740199128B4ACF36040179E978A8DF1474036035C90ADF26040179E978A8DF14740
19267	27327	135.53063299999999	135.55086299999999	47.947603999999998	47.923301000000002	Центральная	0103000020E61000000100000005000000B5A50EF2FAF060409BAE27BA2EF64740B5A50EF2FAF0604086C77E164BF94740723271ABA0F1604086C77E164BF94740723271ABA0F160409BAE27BA2EF64740B5A50EF2FAF060409BAE27BA2EF64740
19192	26090	135.03562500000001	135.121486	47.983488999999999	47.948703000000002	переулок Ленина	0103000020E61000000100000005000000713D0AD723E16040FD4E93196FF94740713D0AD723E16040E57CB1F7E2FD4740809D9B36E3E36040E57CB1F7E2FD4740809D9B36E3E36040FD4E93196FF94740713D0AD723E16040FD4E93196FF94740
19251	26090	135.03562500000001	135.121486	47.983488999999999	47.948703000000002	Центральная	0103000020E61000000100000005000000713D0AD723E16040FD4E93196FF94740713D0AD723E16040E57CB1F7E2FD4740809D9B36E3E36040E57CB1F7E2FD4740809D9B36E3E36040FD4E93196FF94740713D0AD723E16040FD4E93196FF94740
19278	26090	135.03562500000001	135.121486	47.983488999999999	47.948703000000002	Октябрьская	0103000020E61000000100000005000000713D0AD723E16040FD4E93196FF94740713D0AD723E16040E57CB1F7E2FD4740809D9B36E3E36040E57CB1F7E2FD4740809D9B36E3E36040FD4E93196FF94740713D0AD723E16040FD4E93196FF94740
22260	28164	135.66415799999999	135.710781	48.113419	48.080002999999998	Мира	0103000020E610000001000000050000000E2C47C840F560407B4ACE893D0A48400E2C47C840F560405DDF8783840E4840C8B3CBB7BEF660405DDF8783840E4840C8B3CBB7BEF660407B4ACE893D0A48400E2C47C840F560407B4ACE893D0A4840
22138	26918	134.93325300000001	134.97825800000001	47.858145	47.841540999999999	Советская	0103000020E610000001000000050000009B3C6535DDDD60401F9F909DB7EB47409B3C6535DDDD6040EB1C03B2D7ED47409DA1B8E34DDF6040EB1C03B2D7ED47409DA1B8E34DDF60401F9F909DB7EB47409B3C6535DDDD60401F9F909DB7EB4740
22207	26505	134.669085	134.677233	48.120517	48.107444999999998	Центральная	0103000020E61000000100000005000000D027F22469D56040328FFCC1C00D4840D027F22469D5604057CEDE196D0F4840B4588AE4ABD5604057CEDE196D0F4840B4588AE4ABD56040328FFCC1C00D4840D027F22469D56040328FFCC1C00D4840
19277	25982	136.09305900000001	136.15683899999999	48.211446000000002	48.184618999999998	Спортивная	0103000020E610000001000000050000002733DE56FA026140309C6B98A11748402733DE56FA0261405D6F9BA9101B484098F738D3040561405D6F9BA9101B484098F738D304056140309C6B98A11748402733DE56FA026140309C6B98A1174840
19167	25982	136.09305900000001	136.15683899999999	48.211446000000002	48.184618999999998	Комсомольская	0103000020E610000001000000050000002733DE56FA026140309C6B98A11748402733DE56FA0261405D6F9BA9101B484098F738D3040561405D6F9BA9101B484098F738D304056140309C6B98A11748402733DE56FA026140309C6B98A1174840
22009	25982	136.09305900000001	136.15683899999999	48.211446000000002	48.184618999999998	Кедровая	0103000020E610000001000000050000002733DE56FA026140309C6B98A11748402733DE56FA0261405D6F9BA9101B484098F738D3040561405D6F9BA9101B484098F738D304056140309C6B98A11748402733DE56FA026140309C6B98A1174840
19253	26325	134.92489900000001	134.966329	47.976481	47.960203999999997	Советская	0103000020E610000001000000050000004DA3C9C598DD604083BEF4F6E7FA47404DA3C9C598DD60402B155454FDFC4740A585CB2AECDE60402B155454FDFC4740A585CB2AECDE604083BEF4F6E7FA47404DA3C9C598DD604083BEF4F6E7FA4740
21912	27249	135.44915499999999	135.47534099999999	47.981270000000002	47.961773000000001	Набережная	0103000020E61000000100000005000000B77A4E7A5FEE60408196AE601BFB4740B77A4E7A5FEE6040E1455F419AFD4740552E54FE35EF6040E1455F419AFD4740552E54FE35EF60408196AE601BFB4740B77A4E7A5FEE60408196AE601BFB4740
22256	27708	135.70026999999999	135.73579000000001	47.700184	47.680925999999999	Центральная	0103000020E61000000100000005000000D68BA19C68F66040807F4A9528D74740D68BA19C68F660405B971AA19FD947402A5778978BF760405B971AA19FD947402A5778978BF76040807F4A9528D74740D68BA19C68F66040807F4A9528D74740
19305	28005	135.11190099999999	135.13599400000001	48.113461000000001	48.093978	Пионерская	0103000020E6100000010000000500000078EC67B194E3604091459A78070C484078EC67B194E360408C2FDAE3850E484079CE16105AE460408C2FDAE3850E484079CE16105AE4604091459A78070C484078EC67B194E3604091459A78070C4840
21762	26881	134.97951599999999	135.010751	47.858942999999996	47.849831999999999	Центральная	0103000020E61000000100000005000000143DF03158DF6040118C834BC7EC4740143DF03158DF604066101FD8F1ED4740C72C7B1258E0604066101FD8F1ED4740C72C7B1258E06040118C834BC7EC4740143DF03158DF6040118C834BC7EC4740
22208	27508	135.62841399999999	135.64784499999999	47.835583999999997	47.821658999999997	Магазинная	0103000020E61000000100000005000000274BADF71BF4604066BB421F2CE94740274BADF71BF46040CA87A06AF4EA474011FC6F25BBF46040CA87A06AF4EA474011FC6F25BBF4604066BB421F2CE94740274BADF71BF4604066BB421F2CE94740
21882	26377	134.82231100000001	134.835983	47.994433999999998	47.977240999999999	Набережная	0103000020E610000001000000050000008484285F50DA6040B9A7AB3B16FD47408484285F50DA6040E603029D49FF474062A06B5FC0DA6040E603029D49FF474062A06B5FC0DA6040B9A7AB3B16FD47408484285F50DA6040B9A7AB3B16FD4740
21914	27832	136.09145100000001	136.10061400000001	47.397092000000001	47.389394000000003	Набережная	0103000020E61000000100000005000000F8C5A52AED0261401BA19FA9D7B14740F8C5A52AED0261406AC020E9D3B24740A2F0D93A380361406AC020E9D3B24740A2F0D93A380361401BA19FA9D7B14740F8C5A52AED0261401BA19FA9D7B14740
19310	28142	136.379639	136.41363200000001	48.068756999999998	48.054665999999997	Пионерская	0103000020E610000001000000050000002829B000260C6140001AA54BFF0648402829B000260C61407F2F8507CD08484088122D793C0D61407F2F8507CD08484088122D793C0D6140001AA54BFF0648402829B000260C6140001AA54BFF064840
19258	28048	135.11648199999999	135.13585900000001	48.067883999999999	48.061518999999997	Совхозная	0103000020E6100000010000000500000053927538BAE36040938AC6DADF07484053927538BAE36040F9F5436CB0084840C13BF9F458E46040F9F5436CB0084840C13BF9F458E46040938AC6DADF07484053927538BAE36040938AC6DADF074840
24167	50963	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	Новикова	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
21907	28248	135.822091	135.86810299999999	48.094448	48.077998000000001	Комсомольская	0103000020E61000000100000005000000C0EAC8914EFA6040A393A5D6FB094840C0EAC8914EFA604018963FDF160C4840E751F17FC7FB604018963FDF160C4840E751F17FC7FB6040A393A5D6FB094840C0EAC8914EFA6040A393A5D6FB094840
22137	26808	135.00130899999999	135.02665999999999	47.887397999999997	47.88364	Центральная	0103000020E6100000010000000500000018062CB90AE06040FEB7921D1BF1474018062CB90AE060409544F64196F1474090831266DAE060409544F64196F1474090831266DAE06040FEB7921D1BF1474018062CB90AE06040FEB7921D1BF14740
21913	27718	135.615362	135.629986	47.380426	47.369349999999997	переулок Пионерский	0103000020E610000001000000050000007026A60BB1F3604088635DDC46AF47407026A60BB1F36040284696CCB1B04740035E66D828F46040284696CCB1B04740035E66D828F4604088635DDC46AF47407026A60BB1F3604088635DDC46AF4740
21881	26314	134.99685400000001	135.02567199999999	47.971462000000002	47.941110000000002	Первомайская	0103000020E61000000100000005000000611C5C3AE6DF604023F8DF4A76F84740611C5C3AE6DF604044A7E7DD58FC4740880D164ED2E0604044A7E7DD58FC4740880D164ED2E0604023F8DF4A76F84740611C5C3AE6DF604023F8DF4A76F84740
21890	27002	135.230874	135.28949800000001	47.967576999999999	47.949572000000003	Центральная	0103000020E61000000100000005000000E5EFDE5163E76040429946938BF94740E5EFDE5163E760404FAE2990D9FB47403D484F9143E960404FAE2990D9FB47403D484F9143E96040429946938BF94740E5EFDE5163E76040429946938BF94740
21915	27957	136.17590999999999	136.18817200000001	47.673105999999997	47.660842000000002	Джанси Кимонко	0103000020E610000001000000050000004221020EA105614060E97C7896D447404221020EA1056140E55E605628D64740BC40498105066140E55E605628D64740BC4049810506614060E97C7896D447404221020EA105614060E97C7896D44740
19302	27222	135.448185	135.46302499999999	47.904429	47.890546000000001	Центральная	0103000020E61000000100000005000000D9B1118857EE6040B4CA4C69FDF14740D9B1118857EE6040E9465854C4F347405F07CE19D1EE6040E9465854C4F347405F07CE19D1EE6040B4CA4C69FDF14740D9B1118857EE6040B4CA4C69FDF14740
22134	27553	135.61096000000001	135.645464	47.798434	47.758094999999997	Школьная	0103000020E610000001000000050000004165FCFB8CF360406C21C84109E147404165FCFB8CF36040DA01D71533E64740DA571EA4A7F46040DA01D71533E64740DA571EA4A7F460406C21C84109E147404165FCFB8CF360406C21C84109E14740
45210	55348	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	Комсомольская	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
19353	24185	134.97542000000001	134.99387100000001	47.285044999999997	47.273325999999997	Центральная	0103000020E61000000100000005000000A9FB00A436DF6040C092AB58FCA24740A9FB00A436DF6040B471C45A7CA447402C2E8ECACDDF6040B471C45A7CA447402C2E8ECACDDF6040C092AB58FCA24740A9FB00A436DF6040C092AB58FCA24740
24148	50951	134.25298599999999	134.26691	47.369131000000003	47.358851999999999	Центральная	0103000020E61000000100000005000000118B187618C86040560DC2DCEEAD4740118B187618C860404B7842AF3FAF4740361FD7868AC860404B7842AF3FAF4740361FD7868AC86040560DC2DCEEAD4740118B187618C86040560DC2DCEEAD4740
22305	23791	134.68708799999999	134.714944	47.507134999999998	47.480682000000002	Шоссейная	0103000020E610000001000000050000002B2FF99FFCD5604050E3DEFC86BD47402B2FF99FFCD5604017D4B7CCE9C04740164F3DD2E0D6604017D4B7CCE9C04740164F3DD2E0D6604050E3DEFC86BD47402B2FF99FFCD5604050E3DEFC86BD4740
19352	24170	135.20166900000001	135.212422	47.35754	47.349854000000001	Школьная	0103000020E61000000100000005000000BFF38B1274E66040F92F1004C8AC4740BFF38B1274E660408481E7DEC3AD47406EDE3829CCE660408481E7DEC3AD47406EDE3829CCE66040F92F1004C8AC4740BFF38B1274E66040F92F1004C8AC4740
22029	4463	134.76066900000001	134.77549099999999	47.766731999999998	47.752879	Набережная	0103000020E6100000010000000500000098C2836657D860402F6CCD565EE0474098C2836657D86040F965304624E24740F46A80D2D0D86040F965304624E24740F46A80D2D0D860402F6CCD565EE0474098C2836657D860402F6CCD565EE04740
22185	23899	134.84383500000001	134.89376300000001	47.649510999999997	47.633696	Центральная	0103000020E610000001000000050000000C0742B200DB604092CD55F31CD147400C0742B200DB604035B22B2D23D34740FFEBDCB499DC604035B22B2D23D34740FFEBDCB499DC604092CD55F31CD147400C0742B200DB604092CD55F31CD14740
21977	23691	134.50746000000001	134.584464	47.425764999999998	47.405503000000003	Центральная	0103000020E61000000100000005000000E700C11C3DD0604007B7B585E7B34740E700C11C3DD060400664AF777FB647400FB6D8EDB3D260400664AF777FB647400FB6D8EDB3D2604007B7B585E7B34740E700C11C3DD0604007B7B585E7B34740
21973	23604	134.35361499999999	134.377205	47.433396999999999	47.424002999999999	Школьная	0103000020E61000000100000005000000008C67D050CB6040F433F5BA45B64740008C67D050CB60409E978A8D79B74740685C381012CC60409E978A8D79B74740685C381012CC6040F433F5BA45B64740008C67D050CB6040F433F5BA45B64740
19149	24103	135.05227099999999	135.07824099999999	47.678463000000001	47.664472000000004	Центральная	0103000020E61000000100000005000000EF703B34ACE16040CA8D226B0DD54740EF703B34ACE16040E54526E0D7D647409A0645F380E26040E54526E0D7D647409A0645F380E26040CA8D226B0DD54740EF703B34ACE16040CA8D226B0DD54740
22024	7890	134.67947899999999	134.69522599999999	47.621009999999998	47.605459000000003	Центральная	0103000020E61000000100000005000000336ABE4ABED56040D10836AE7FCD4740336ABE4ABED56040963E74417DCF474086AA984A3FD66040963E74417DCF474086AA984A3FD66040D10836AE7FCD4740336ABE4ABED56040D10836AE7FCD4740
21842	24058	134.88279399999999	134.927378	47.778868000000003	47.760415000000002	Пашина	0103000020E610000001000000050000005CE333D93FDC6040A5315A4755E147405CE333D93FDC604052F355F2B1E34740F5A0A014ADDD604052F355F2B1E34740F5A0A014ADDD6040A5315A4755E147405CE333D93FDC6040A5315A4755E14740
22186	23955	134.90928600000001	134.922572	47.718755000000002	47.704161999999997	Центральная	0103000020E61000000100000005000000BE16F4DE18DD6040008BFCFA21DA4740BE16F4DE18DD6040126BF12900DC47409206B7B585DD6040126BF12900DC47409206B7B585DD6040008BFCFA21DA4740BE16F4DE18DD6040008BFCFA21DA4740
21834	23481	134.35604000000001	134.37185099999999	47.259611	47.252332000000003	Бонивура	0103000020E610000001000000050000002C82FFAD64CB6040FDDD3B6A4CA047402C82FFAD64CB60404757E9EE3AA14740847F1134E6CB60404757E9EE3AA14740847F1134E6CB6040FDDD3B6A4CA047402C82FFAD64CB6040FDDD3B6A4CA04740
22169	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Шолохова	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
21849	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Чехова	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
22115	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Театральная	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
21716	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Стоцкого	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
19244	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Морозова	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
21981	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Милицейская	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
19153	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Котляра	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
22112	24302	134.721394	134.793745	47.564903000000001	47.512205000000002	Коммунистическая	0103000020E61000000100000005000000FBB0DEA815D7604081ECF5EE8FC14740FBB0DEA815D76040C634D3BD4EC84740A20BEA5B66D96040C634D3BD4EC84740A20BEA5B66D9604081ECF5EE8FC14740FBB0DEA815D7604081ECF5EE8FC14740
21718	24302	134.68285599999999	134.81465700000001	47.581608000000003	47.492353999999999	Вяземская	0103000020E61000000100000005000000137CD3F4D9D560400307B47405BF4740137CD3F4D9D56040C68B852172CA4740A48E8EAB11DA6040C68B852172CA4740A48E8EAB11DA60400307B47405BF4740137CD3F4D9D560400307B47405BF4740
19240	23629	134.49169499999999	134.502565	47.440229000000002	47.424936000000002	Центральная	0103000020E610000001000000050000006A1327F7BBCF60405072874D64B647406A1327F7BBCF60401AE0826C59B84740A8E3310315D060401AE0826C59B84740A8E3310315D060405072874D64B647406A1327F7BBCF60405072874D64B64740
22344	23629	134.49169499999999	134.502565	47.440229000000002	47.424936000000002	Мира	0103000020E610000001000000050000006A1327F7BBCF60405072874D64B647406A1327F7BBCF60401AE0826C59B84740A8E3310315D060401AE0826C59B84740A8E3310315D060405072874D64B647406A1327F7BBCF60405072874D64B64740
19348	23422	134.16141099999999	134.17180500000001	47.243285	47.236648000000002	Центральная	0103000020E61000000100000005000000DEC666472AC56040F8544E7B4A9E4740DEC666472AC56040BE4D7FF6239F47404209336D7FC56040BE4D7FF6239F47404209336D7FC56040F8544E7B4A9E4740DEC666472AC56040F8544E7B4A9E4740
19146	23725	134.56799799999999	134.58487700000001	47.488177999999998	47.472490000000001	Кооперативная	0103000020E610000001000000050000003046240A2DD26040F1D7648D7ABC47403046240A2DD260403750E09D7CBE4740D865F84FB7D260403750E09D7CBE4740D865F84FB7D26040F1D7648D7ABC47403046240A2DD26040F1D7648D7ABC4740
22145	23768	134.64536100000001	134.669669	47.486387000000001	47.475816000000002	Садовая	0103000020E61000000100000005000000A5A31CCCA6D46040EF74E789E7BC4740A5A31CCCA6D460408B19E1ED41BE4740A4C4AEED6DD560408B19E1ED41BE4740A4C4AEED6DD56040EF74E789E7BC4740A5A31CCCA6D46040EF74E789E7BC4740
22096	22922	131.52346399999999	131.53256400000001	51.525145999999999	51.519889999999997	Школьная	0103000020E6100000010000000500000044149337C07060403BC269C18BC2494044149337C070604007D0EFFB37C34940DD60A8C30A71604007D0EFFB37C34940DD60A8C30A7160403BC269C18BC2494044149337C07060403BC269C18BC24940
19080	23022	132.29985099999999	132.31717900000001	50.849927000000001	50.835520000000002	Амурская	0103000020E6100000010000000500000088D51F6198896040B493C151F26A494088D51F6198896040637E6E68CA6C49404CFF9254268A6040637E6E68CA6C49404CFF9254268A6040B493C151F26A494088D51F6198896040B493C151F26A4940
21816	22040	133.256449	133.26242199999999	51.635973999999997	51.631010000000003	Центральная	0103000020E61000000100000005000000F18288D434A8604078B988EFC4D04940F18288D434A860409B8D959867D149400778D2C265A860409B8D959867D149400778D2C265A8604078B988EFC4D04940F18288D434A8604078B988EFC4D04940
19193	7707	132.25061400000001	132.261942	50.873463999999998	50.860174000000001	Центральная	0103000020E610000001000000050000006FBDA607058860404C6F7F2E1A6E49406FBDA60705886040DE1D19ABCD6F49405D6E30D461886040DE1D19ABCD6F49405D6E30D4618860404C6F7F2E1A6E49406FBDA607058860404C6F7F2E1A6E4940
22080	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Центральная	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
22290	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Ургальская	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
22078	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Строительная	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
22238	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Пионерская	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
22077	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Парковая	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
19332	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Магистральная	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
22303	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Лесная	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
45233	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	Амурская	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
22167	7825	132.94245100000001	133.06385	51.156885000000003	51.109656999999999	60 лет Октября	0103000020E61000000100000005000000A4E2FF8E289E60408463963D098E4940A4E2FF8E289E6040D21DC4CE1494494030BB270F0BA26040D21DC4CE1494494030BB270F0BA260408463963D098E4940A4E2FF8E289E60408463963D098E4940
19336	23066	132.24915899999999	132.28280100000001	50.420819000000002	50.406433999999997	Школьная	0103000020E6100000010000000500000021904B1CF9876040C1FD80070634494021904B1CF98760408944A165DD354940D6C8AEB40C8960408944A165DD354940D6C8AEB40C896040C1FD80070634494021904B1CF9876040C1FD800706344940
21954	22839	132.51341600000001	132.524124	51.137154000000002	51.126607	Центральная	0103000020E61000000100000005000000C82764E76D906040EB387EA834904940C82764E76D906040FF4124438E9149408FE1B19FC5906040FF4124438E9149408FE1B19FC5906040EB387EA834904940C82764E76D906040EB387EA834904940
22101	7796	132.122263	132.188433	50.063462999999999	50.025455999999998	Октябрьская	0103000020E6100000010000000500000059501894E983604055BE67244203494059501894E9836040C6C03A8E1F084940978FA4A407866040C6C03A8E1F084940978FA4A40786604055BE67244203494059501894E983604055BE672442034940
19342	7796	132.122263	132.188433	50.063462999999999	50.025455999999998	Вокзальная	0103000020E6100000010000000500000059501894E983604055BE67244203494059501894E9836040C6C03A8E1F084940978FA4A407866040C6C03A8E1F084940978FA4A40786604055BE67244203494059501894E983604055BE672442034940
21952	22763	133.56682499999999	133.59784400000001	50.659193999999999	50.644950999999999	40 лет Победы	0103000020E61000000100000005000000C4B12E6E23B26040E1421EC18D524940C4B12E6E23B2604016DC0F78605449408483BD8921B3604016DC0F78605449408483BD8921B36040E1421EC18D524940C4B12E6E23B26040E1421EC18D524940
19328	22096	132.92858100000001	132.95385099999999	51.165317999999999	51.150754999999997	Советская	0103000020E61000000100000005000000FC5580EFB69D6040AF5A99F04B934940FC5580EFB69D604056B8E52329954940384888F2859E604056B8E52329954940384888F2859E6040AF5A99F04B934940FC5580EFB69D6040AF5A99F04B934940
22076	21999	133.974706	134.001924	52.260190000000001	52.251947999999999	Советская	0103000020E61000000100000005000000E126A3CA30BF6040742502D53F204A40E126A3CA30BF6040855FEAE74D214A407BA2EBC20FC06040855FEAE74D214A407BA2EBC20FC06040742502D53F204A40E126A3CA30BF6040742502D53F204A40
22239	22731	133.21942000000001	133.23344299999999	50.822491999999997	50.813893	Центральная	0103000020E61000000100000005000000D482177D05A76040BFB854A52D684940D482177D05A760405E9CF86A476949405D4F745D78A760405E9CF86A476949405D4F745D78A76040BFB854A52D684940D482177D05A76040BFB854A52D684940
21963	7720	132.26792399999999	132.294209	50.345052000000003	50.333824	Центральная	0103000020E61000000100000005000000083A5AD592886040594FADBEBA2A4940083A5AD592886040AFB5F7A92A2C49400B26FE286A896040AFB5F7A92A2C49400B26FE286A896040594FADBEBA2A4940083A5AD592886040594FADBEBA2A4940
22089	22643	132.54962699999999	132.61161100000001	51.083812000000002	51.061061000000002	Донецкая	0103000020E61000000100000005000000F4BF5C8B96916040D107CBD8D0874940F4BF5C8B969160409581035ABA8A4940F75B3B51929360409581035ABA8A4940F75B3B5192936040D107CBD8D0874940F4BF5C8B96916040D107CBD8D0874940
19333	22643	132.54962699999999	132.61161100000001	51.083812000000002	51.061061000000002	60 лет образования СССР	0103000020E61000000100000005000000F4BF5C8B96916040D107CBD8D0874940F4BF5C8B969160409581035ABA8A4940F75B3B51929360409581035ABA8A4940F75B3B5192936040D107CBD8D0874940F4BF5C8B96916040D107CBD8D0874940
22094	22796	134.11337800000001	134.12313399999999	50.807268000000001	50.801364999999997	Школьная	0103000020E61000000100000005000000C042E6CAA0C360405B94D92093664940C042E6CAA0C36040BD8DCD8E54674940D2E0B6B6F0C36040BD8DCD8E54674940D2E0B6B6F0C360405B94D92093664940C042E6CAA0C360405B94D92093664940
21956	22887	132.434957	132.45253700000001	51.372577999999997	51.336342999999999	Сергея Лазо	0103000020E610000001000000050000005245F12AEB8D6040889E94490DAB49405245F12AEB8D6040C39ACAA2B0AF49405CE7DF2E7B8E6040C39ACAA2B0AF49405CE7DF2E7B8E6040889E94490DAB49405245F12AEB8D6040889E94490DAB4940
19343	23299	131.98125400000001	131.99896000000001	50.018042000000001	50.008420999999998	Советская	0103000020E6100000010000000500000037E2C96E667F6040C0CC77F01301494037E2C96E667F60402BFA43334F0249406440F67AF77F60402BFA43334F0249406440F67AF77F6040C0CC77F01301494037E2C96E667F6040C0CC77F013014940
19319	21704	140.027671	140.0548	49.353558999999997	49.344268999999997	Киевская	0103000020E6100000010000000500000086014BAEE28061406803B00111AC484086014BAEE28061406D1ADB6B41AD484044FAEDEBC08161406D1ADB6B41AD484044FAEDEBC08161406803B00111AC484086014BAEE28061406803B00111AC4840
19227	7656	140.06239099999999	140.11667600000001	49.677937	49.646658000000002	Комсомольская,	0103000020E610000001000000050000001212691BFF81614030D978B0C5D248401212691BFF816140CADFBDA3C6D648404D874ECFBB836140CADFBDA3C6D648404D874ECFBB83614030D978B0C5D248401212691BFF81614030D978B0C5D24840
22164	21819	139.945897	139.96571399999999	49.893324	49.874924	Центральная	0103000020E610000001000000050000004E0CC9C9447E6140253E7782FDEF48404E0CC9C9447E6140AF5DDA7058F2484042E90B21E77E6140AF5DDA7058F2484042E90B21E77E6140253E7782FDEF48404E0CC9C9447E6140253E7782FDEF4840
21814	21452	140.30781899999999	140.32849899999999	49.137348000000003	49.107537999999998	переулок Магаданский	0103000020E61000000100000005000000CC423BA7D9896140E38920CEC38D4840CC423BA7D9896140E415889E9491484099B85510838A6140E415889E9491484099B85510838A6140E38920CEC38D4840CC423BA7D9896140E38920CEC38D4840
22285	21452	140.30781899999999	140.32849899999999	49.137348000000003	49.107537999999998	Железнодорожная	0103000020E61000000100000005000000CC423BA7D9896140E38920CEC38D4840CC423BA7D9896140E415889E9491484099B85510838A6140E415889E9491484099B85510838A6140E38920CEC38D4840CC423BA7D9896140E38920CEC38D4840
22286	21452	140.30781899999999	140.32849899999999	49.137348000000003	49.107537999999998	Амурская	0103000020E61000000100000005000000CC423BA7D9896140E38920CEC38D4840CC423BA7D9896140E415889E9491484099B85510838A6140E415889E9491484099B85510838A6140E38920CEC38D4840CC423BA7D9896140E38920CEC38D4840
22143	20909	140.22118599999999	140.29294300000001	49.084637999999998	49.040973000000001	Центральная	0103000020E61000000100000005000000A88AA9F4138761406F826F9A3E854840A88AA9F413876140DAFF006BD58A4840F392FFC95F896140DAFF006BD58A4840F392FFC95F8961406F826F9A3E854840A88AA9F4138761406F826F9A3E854840
18982	20909	140.22118599999999	140.29294300000001	49.084637999999998	49.040973000000001	Новодорожная	0103000020E61000000100000005000000A88AA9F4138761406F826F9A3E854840A88AA9F413876140DAFF006BD58A4840F392FFC95F896140DAFF006BD58A4840F392FFC95F8961406F826F9A3E854840A88AA9F4138761406F826F9A3E854840
19299	20909	140.22118599999999	140.29294300000001	49.084637999999998	49.040973000000001	Космонавтов	0103000020E61000000100000005000000A88AA9F4138761406F826F9A3E854840A88AA9F413876140DAFF006BD58A4840F392FFC95F896140DAFF006BD58A4840F392FFC95F8961406F826F9A3E854840A88AA9F4138761406F826F9A3E854840
19314	20909	140.22118599999999	140.29294300000001	49.084637999999998	49.040973000000001	Дарвина	0103000020E61000000100000005000000A88AA9F4138761406F826F9A3E854840A88AA9F413876140DAFF006BD58A4840F392FFC95F896140DAFF006BD58A4840F392FFC95F8961406F826F9A3E854840A88AA9F4138761406F826F9A3E854840
19270	4386	140.209768	140.25115400000001	49.245834000000002	49.230400000000003	Театральная	0103000020E61000000100000005000000EA77616BB6866140CC7F48BF7D9D4840EA77616BB6866140581F0F7D779F48404F081D7409886140581F0F7D779F48404F081D7409886140CC7F48BF7D9D4840EA77616BB6866140CC7F48BF7D9D4840
19206	21859	139.55477099999999	139.59724299999999	50.141713000000003	50.124262999999999	Советская	0103000020E610000001000000050000009DB81CAFC07161402A8D98D9E70F49409DB81CAFC07161408335CEA6231249407A185A9D1C7361408335CEA6231249407A185A9D1C7361402A8D98D9E70F49409DB81CAFC07161402A8D98D9E70F4940
22287	21617	140.35836800000001	140.37716	49.293225	49.272509999999997	Шуляпина	0103000020E61000000100000005000000DBFD2AC0778B61409EEA909BE1A24840DBFD2AC0778B61404FAF946588A54840802BD9B1118C61404FAF946588A54840802BD9B1118C61409EEA909BE1A24840DBFD2AC0778B61409EEA909BE1A24840
21911	21914	139.108182	139.15546900000001	50.116638999999999	50.089858999999997	Октябрьская	0103000020E610000001000000050000008200193A766361402920ED7F800B49408200193A766361401538D906EE0E494057D11F9AF96461401538D906EE0E494057D11F9AF96461402920ED7F800B49408200193A766361402920ED7F800B4940
21804	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	площадь Маяковского	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
19231	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	Чехова	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
19315	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	Невского	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
22243	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	Молодежная	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
22279	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	Мира	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
22283	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	Клубная	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
19202	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	Киевская	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
21806	21080	140.23673600000001	140.311835	49.111778000000001	49.074652999999998	2 Линия	0103000020E6100000010000000500000026396057938761402EC6C03A8E8948402639605793876140C634D3BD4E8E4840F1D7648DFA896140C634D3BD4E8E4840F1D7648DFA8961402EC6C03A8E89484026396057938761402EC6C03A8E894840
19217	20253	134.36957799999999	134.389341	47.139969999999998	47.127893999999998	Кирова	0103000020E6100000010000000500000046EA3D95D3CB604064ADA1D45E90474046EA3D95D3CB6040E7357689EA914740BEBF417B75CC6040E7357689EA914740BEBF417B75CC604064ADA1D45E90474046EA3D95D3CB604064ADA1D45E904740
21782	20087	134.019972	134.03120999999999	46.722386	46.709850000000003	Центральная	0103000020E61000000100000005000000BEDA519CA3C060406688635DDC5A4740BEDA519CA3C060404C8BFA24775C4740DC291DACFFC060404C8BFA24775C4740DC291DACFFC060406688635DDC5A4740BEDA519CA3C060406688635DDC5A4740
19311	19212	134.23083299999999	134.24882600000001	46.808225	46.789872000000003	Мира	0103000020E61000000100000005000000CD3AE3FB62C76040580394861A654740CD3AE3FB62C76040A167B3EA73674740A08CF161F6C76040A167B3EA73674740A08CF161F6C76040580394861A654740CD3AE3FB62C76040580394861A654740
22291	20358	134.208223	134.23260300000001	47.104156000000003	47.086807	Уссурийская	0103000020E61000000100000005000000CDE847C3A9C660402D08E57D1C8B4740CDE847C3A9C6604052D7DAFB548D474073BED87B71C7604052D7DAFB548D474073BED87B71C760402D08E57D1C8B4740CDE847C3A9C660402D08E57D1C8B4740
22262	20141	134.32532699999999	134.36117899999999	46.746738999999998	46.720131000000002	переулок Красноармейский	0103000020E610000001000000050000002F302B1469CA6040FBEAAA402D5C47402F302B1469CA6040E9D2BF24955F4740102043C78ECB6040E9D2BF24955F4740102043C78ECB6040FBEAAA402D5C47402F302B1469CA6040FBEAAA402D5C4740
21931	20460	134.27361999999999	134.35245599999999	47.167575999999997	47.134073000000001	Южный городок	0103000020E6100000010000000500000002F1BA7EC1C860406823D74D2991474002F1BA7EC1C8604018CC5F2173954740ED28CE5147CB604018CC5F2173954740ED28CE5147CB60406823D74D2991474002F1BA7EC1C860406823D74D29914740
21932	20460	134.27361999999999	134.35245599999999	47.167575999999997	47.134073000000001	Центральная	0103000020E6100000010000000500000002F1BA7EC1C860406823D74D2991474002F1BA7EC1C8604018CC5F2173954740ED28CE5147CB604018CC5F2173954740ED28CE5147CB60406823D74D2991474002F1BA7EC1C860406823D74D29914740
19260	20460	134.27361999999999	134.35245599999999	47.167575999999997	47.134073000000001	Пролетарская	0103000020E6100000010000000500000002F1BA7EC1C860406823D74D2991474002F1BA7EC1C8604018CC5F2173954740ED28CE5147CB604018CC5F2173954740ED28CE5147CB60406823D74D2991474002F1BA7EC1C860406823D74D29914740
18967	20460	134.27361999999999	134.35245599999999	47.167575999999997	47.134073000000001	22б	0103000020E6100000010000000500000002F1BA7EC1C860406823D74D2991474002F1BA7EC1C8604018CC5F2173954740ED28CE5147CB604018CC5F2173954740ED28CE5147CB60406823D74D2991474002F1BA7EC1C860406823D74D29914740
19218	20377	134.318365	134.32750100000001	47.213577000000001	47.199938000000003	Центральная	0103000020E610000001000000050000001DE6CB0B30CA6040249D8191979947401DE6CB0B30CA6040C216BB7D569B4740098D60E37ACA6040C216BB7D569B4740098D60E37ACA6040249D8191979947401DE6CB0B30CA6040249D819197994740
18965	20225	134.319605	134.33502899999999	46.990476000000001	46.973809000000003	Центральная	0103000020E610000001000000050000006BD443343ACA604076C6F7C5A57C47406BD443343ACA604088BCE5EAC77E4740C5C6BC8EB8CA604088BCE5EAC77E4740C5C6BC8EB8CA604076C6F7C5A57C47406BD443343ACA604076C6F7C5A57C4740
19229	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	переулок Энергетический	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
9708	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Фабричная	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
21780	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Первомайская	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
19026	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Октябрьская	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
22257	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Набережная	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
18983	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Зеленая	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
21935	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Зачеславского	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
18916	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Железнодорожная	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
21916	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Дзержинского	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
21798	13440	134.21148299999999	134.29397599999999	46.854604999999999	46.794080000000001	Восточный городок	0103000020E610000001000000050000001E15FF77C4C660402F34D769A46547401E15FF77C4C66040C1FF56B2636D4740E2395B4068C96040C1FF56B2636D4740E2395B4068C960402F34D769A46547401E15FF77C4C660402F34D769A4654740
22781	50562	134.63354799999999	134.94936000000001	54.484769999999997	54.309449000000001	 Советская	0103000020E61000000100000005000000478E740646D46040D4635B069C274B40478E740646D460407C0A80F10C3E4B402E04392861DE60407C0A80F10C3E4B402E04392861DE6040D4635B069C274B40478E740646D46040D4635B069C274B40
79700	50495	135.07308499999999	135.082131	48.52937	48.514176999999997	Совхозная	0103000020E61000000100000005000000809A5AB656E260407DAD4B8DD0414840809A5AB656E26040E4BD6A65C24348409CDF30D1A0E26040E4BD6A65C24348409CDF30D1A0E260407DAD4B8DD0414840809A5AB656E260407DAD4B8DD0414840
79709	61809	135.04678200000001	135.057095	48.491784000000003	48.483626999999998	Советская	0103000020E610000001000000050000005401F73C7FE16040363B527DE73D48405401F73C7FE16040195932C7F23E48407CB8E4B8D3E16040195932C7F23E48407CB8E4B8D3E16040363B527DE73D48405401F73C7FE16040363B527DE73D4840
79412	61574	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	40 Лет Победы	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
22162	50470	136.70577299999999	136.83757299999999	50.369103000000003	50.284728999999999	Вокзальная	0103000020E61000000100000005000000CB2C42B195166140849CF7FF71244940CB2C42B19516614081ED60C43E2F49406760E465CD1A614081ED60C43E2F49406760E465CD1A6140849CF7FF71244940CB2C42B195166140849CF7FF71244940
19285	7360	136.474277	136.52242699999999	50.120001000000002	50.068939	Школьная	0103000020E61000000100000005000000D787F5462D0F6140A0353FFED2084940D787F5462D0F6140603E59315C0F494084F1D3B8B7106140603E59315C0F494084F1D3B8B7106140A0353FFED2084940D787F5462D0F6140A0353FFED2084940
22147	7360	136.474277	136.52242699999999	50.120001000000002	50.068939	Центральная	0103000020E61000000100000005000000D787F5462D0F6140A0353FFED2084940D787F5462D0F6140603E59315C0F494084F1D3B8B7106140603E59315C0F494084F1D3B8B7106140A0353FFED2084940D787F5462D0F6140A0353FFED2084940
18956	7360	136.474277	136.52242699999999	50.120001000000002	50.068939	Микрорайон 2	0103000020E61000000100000005000000D787F5462D0F6140A0353FFED2084940D787F5462D0F6140603E59315C0F494084F1D3B8B7106140603E59315C0F494084F1D3B8B7106140A0353FFED2084940D787F5462D0F6140A0353FFED2084940
21775	7360	136.474277	136.52242699999999	50.120001000000002	50.068939	Микрорайон 1	0103000020E61000000100000005000000D787F5462D0F6140A0353FFED2084940D787F5462D0F6140603E59315C0F494084F1D3B8B7106140603E59315C0F494084F1D3B8B7106140A0353FFED2084940D787F5462D0F6140A0353FFED2084940
21853	19399	135.14618100000001	135.171199	49.090218999999998	49.08128	Школьная	0103000020E610000001000000050000007EC9C683ADE46040D1E80E62678A48407EC9C683ADE46040293DD34B8C8B4840744353767AE56040293DD34B8C8B4840744353767AE56040D1E80E62678A48407EC9C683ADE46040D1E80E62678A4840
22140	19145	135.165144	135.19451000000001	49.376921000000003	49.358611000000003	Молодежная	0103000020E610000001000000050000002EE411DC48E56040317E1AF7E6AD48402EE411DC48E560407B1684F23EB04840D717096D39E660407B1684F23EB04840D717096D39E66040317E1AF7E6AD48402EE411DC48E56040317E1AF7E6AD4840
21885	18825	136.63856100000001	136.65489199999999	50.226733000000003	50.204886999999999	Станционная	0103000020E6100000010000000500000009707A176F1461401230BABC391A494009707A176F14614045F64196051D49402F4D11E0F414614045F64196051D49402F4D11E0F41461401230BABC391A494009707A176F1461401230BABC391A4940
18957	7437	136.782534	136.794939	50.096297	50.084494999999997	Центральная	0103000020E610000001000000050000004240BE840A19614077D66EBBD00A49404240BE840A196140F9D9C875530C494014EAE92370196140F9D9C875530C494014EAE9237019614077D66EBBD00A49404240BE840A19614077D66EBBD00A4940
21777	18852	136.668654	136.69263000000001	50.312919000000001	50.296745999999999	переулок Пионерский	0103000020E61000000100000005000000DECA129D65156140029CDEC5FB254940DECA129D6515614005A6D3BA0D28494050C763062A16614005A6D3BA0D28494050C763062A166140029CDEC5FB254940DECA129D65156140029CDEC5FB254940
22199	19295	135.15165099999999	135.19158100000001	49.258206999999999	49.220838999999998	Таежная	0103000020E61000000100000005000000FBAC3253DAE460403657CD73449C4840FBAC3253DAE46040944C4EED0CA148401F317A6E21E66040944C4EED0CA148401F317A6E21E660403657CD73449C4840FBAC3253DAE460403657CD73449C4840
22043	19323	135.15925999999999	135.18162799999999	49.188352999999999	49.170043999999997	Горная	0103000020E61000000100000005000000F3716DA818E56040C5707500C4954840F3716DA818E560403F8D7BF31B984840360186E5CFE560403F8D7BF31B984840360186E5CFE56040C5707500C4954840F3716DA818E56040C5707500C4954840
22042	7461	136.62958699999999	136.66021000000001	50.263365	50.249651999999998	Центральная	0103000020E6100000010000000500000093DFA29325146140C4B0C398F41F494093DFA293251461409DF4BEF1B5214940C0CFB870201561409DF4BEF1B5214940C0CFB87020156140C4B0C398F41F494093DFA29325146140C4B0C398F41F4940
22023	7558	136.24746099999999	136.26421500000001	49.853380999999999	49.847427000000003	Центральная	0103000020E6100000010000000500000022C15433EB076140AB5FE97C78EC484022C15433EB0761408E03AF963BED48409B030473740861408E03AF963BED48409B03047374086140AB5FE97C78EC484022C15433EB076140AB5FE97C78EC4840
19198	18933	136.91168400000001	136.952809	50.139645999999999	50.123305000000002	Шерого	0103000020E610000001000000050000002B89EC832C1D614076374F75C80F49402B89EC832C1D614034828DEBDF114940B4CA4C697D1E614034828DEBDF114940B4CA4C697D1E614076374F75C80F49402B89EC832C1D614076374F75C80F4940
22136	19052	136.121329	136.16707099999999	49.919466	49.877287000000003	Вокзальная	0103000020E61000000100000005000000CEE15AEDE10361405D1ABFF04AF04840CEE15AEDE103614058E4D70FB1F54840852348A55805614058E4D70FB1F54840852348A5580561405D1ABFF04AF04840CEE15AEDE10361405D1ABFF04AF04840
19307	7548	136.60242099999999	136.64057299999999	49.893748000000002	49.882111000000002	Советская	0103000020E610000001000000050000008EAD6708471361408F386403E9F048408EAD670847136140C66E9F5566F248406BB6F2927F146140C66E9F5566F248406BB6F2927F1461408F386403E9F048408EAD6708471361408F386403E9F04840
18963	6510	136.754749	136.927468	50.337826	50.212122000000001	проспект Строителей	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
19194	6510	136.754749	136.927468	50.337826	50.212122000000001	проспект Победы	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
19207	6510	136.754749	136.927468	50.337826	50.212122000000001	проспект Октябрьский	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
19196	6510	136.754749	136.927468	50.337826	50.212122000000001	проспект Мира	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
19191	6510	136.754749	136.927468	50.337826	50.212122000000001	проспект Комсомольский	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
21761	6510	136.754749	136.927468	50.337826	50.212122000000001	Школьная	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
21884	6510	136.754749	136.927468	50.337826	50.212122000000001	Лесная	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
21828	6510	136.754749	136.927468	50.337826	50.212122000000001	Комсомольский	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
18926	6510	136.754749	136.927468	50.337826	50.212122000000001	Амурская	0103000020E610000001000000050000000AF65FE7261861408D614ED0261B49400AF65FE72618614087DEE2E13D2B4940C5025FD1AD1D614087DEE2E13D2B4940C5025FD1AD1D61408D614ED0261B49400AF65FE7261861408D614ED0261B4940
79378	61554	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	Нагорная	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
79364	61541	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	пл.Ленина	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
45924	23754	142.69998799999999	142.71203399999999	47.050490000000003	47.043219999999998	село Новая Деревня	0103000020E61000000100000005000000F5F23B4D66D661403D44A33B88854740F5F23B4D66D661403563D174768647407BF486FBC8D661403563D174768647407BF486FBC8D661403D44A33B88854740F5F23B4D66D661403D44A33B88854740
45746	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	проспект Победы	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45727	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	проспект Мира	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45939	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	площадь район Хомутово	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45847	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	переулок Железнодорожный	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45792	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	пер.Мартовский	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45793	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	им. В.Гайдука	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45944	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	жилой квартал Весточка	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45920	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Центральная	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45799	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Хабаровская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45856	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Усадебная	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45743	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Украинская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45797	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Тихоокеанская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45810	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Советская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45916	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Северный городок	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45849	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Северная	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45869	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Сахалинская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45826	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Садовая	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45802	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Пуркаева	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45798	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Поповича	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45800	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Пограничная	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45791	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Науки	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45794	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Ленина	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45795	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Курильская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
77156	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Крайняя	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45747	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Комсомольская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45796	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Коммунистический проспект	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45843	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Коммунистическая	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45848	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Комарова	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45828	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Железнодорожная	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45801	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Емельянова	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45846	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Дружбы	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45806	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Достоевского	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45850	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Деповская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45851	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Горького	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45745	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Вокзальная	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45827	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Антона Буюклы	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45764	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	Амурская,	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45803	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	2-я Центральная	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45825	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	2-я Красносельская	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45818	23754	142.679551	142.87785400000001	47.070065999999997	46.851888000000002	 Чехова	0103000020E61000000100000005000000DA1EBDE1BED561406CED7DAA0A6D4740DA1EBDE1BED56140E04735ECF78847403695456117DC6140E04735ECF78847403695456117DC61406CED7DAA0A6D4740DA1EBDE1BED561406CED7DAA0A6D4740
45790	55616	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	Победы	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
45744	55616	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	Заводская	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
79392	61562	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	Парковая	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
45735	55614	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	Октябрьская	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
45741	55614	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	2-я Восточная	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
45953	55642	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	Клубная	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
45873	55615	142.90475000000001	142.973848	53.609161999999998	53.562835	Школьная	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45736	55615	142.90475000000001	142.973848	53.609161999999998	53.562835	Ленина	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45773	55615	142.90475000000001	142.973848	53.609161999999998	53.562835	Карла Маркса	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45771	55615	142.90475000000001	142.973848	53.609161999999998	53.562835	50 лет Октября	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45733	55613	142.76570899999999	142.791436	48.636825999999999	48.606327	Милютина	0103000020E61000000100000005000000172829B080D8614045D7851F9C4D4840172829B080D861400A9FAD8383514840111C977153D961400A9FAD8383514840111C977153D9614045D7851F9C4D4840172829B080D8614045D7851F9C4D4840
79379	61555	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	Андрея Евдокимова	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
45781	55620	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Овражная	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45762	55620	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Краснофлотская	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45763	55620	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Восточная	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45754	55618	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	Ленина	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
45757	55618	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	Калинина	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
45946	55618	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	Заречная	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
45885	55628	142.12698900000001	142.19465	50.936836	50.868848999999997	Цапко	0103000020E61000000100000005000000753E3C4B10C46140C614AC71366F4940753E3C4B10C4614094DBF63DEA7749405305A3923AC6614094DBF63DEA7749405305A3923AC66140C614AC71366F4940753E3C4B10C46140C614AC71366F4940
45854	55625	142.65743499999999	142.69002599999999	47.014142	46.985514999999999	Новая	0103000020E61000000100000005000000DD0720B509D56140D55B035B257E4740DD0720B509D5614001C0B167CF81474078EC67B114D6614001C0B167CF81474078EC67B114D66140D55B035B257E4740DD0720B509D56140D55B035B257E4740
79398	61567	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	Торговая	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
45888	55629	142.044613	142.07168799999999	47.207033000000003	47.114311999999998	Центральная	0103000020E610000001000000050000003FFF3D786DC161402AC58EC6A18E47403FFF3D786DC16140AD18AE0E809A474080F0A1444BC26140AD18AE0E809A474080F0A1444BC261402AC58EC6A18E47403FFF3D786DC161402AC58EC6A18E4740
45929	55629	142.044613	142.07168799999999	47.207033000000003	47.114311999999998	Зеленая	0103000020E610000001000000050000003FFF3D786DC161402AC58EC6A18E47403FFF3D786DC16140AD18AE0E809A474080F0A1444BC26140AD18AE0E809A474080F0A1444BC261402AC58EC6A18E47403FFF3D786DC161402AC58EC6A18E4740
45852	24431	141.96551600000001	142.01910100000001	47.452922999999998	47.433287	переулок Бумажный	0103000020E610000001000000050000007978CF81E5BE61401764CBF275B747407978CF81E5BE6140984D8061F9B94740454AB3799CC06140984D8061F9B94740454AB3799CC061401764CBF275B747407978CF81E5BE61401764CBF275B74740
45824	24431	141.96551600000001	142.01910100000001	47.452922999999998	47.433287	Ленина	0103000020E610000001000000050000007978CF81E5BE61401764CBF275B747407978CF81E5BE6140984D8061F9B94740454AB3799CC06140984D8061F9B94740454AB3799CC061401764CBF275B747407978CF81E5BE61401764CBF275B74740
45789	25404	142.21859000000001	142.24353600000001	46.974153000000001	46.955506999999997	Речная	0103000020E6100000010000000500000072A774B0FEC66140AE0CAA0D4E7A474072A774B0FEC661407026A60BB17C4740C26C020CCBC761407026A60BB17C4740C26C020CCBC76140AE0CAA0D4E7A474072A774B0FEC66140AE0CAA0D4E7A4740
45787	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	пл.Ленина	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45823	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Школьная	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45731	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Советская	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45786	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Победы	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45943	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Переселенческая	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45822	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Первомайская	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45785	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Морская	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45845	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Матросова	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45904	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Макарова	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45784	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Крузенштерна	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45788	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Комсомольская	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45742	24822	142.02431999999999	142.08760599999999	47.114691999999998	47.000131000000003	Капитанская	0103000020E610000001000000050000007094BC3AC7C061409F5BE84A048047407094BC3AC7C06140718E3A3AAE8E4740DE1D19ABCDC26140718E3A3AAE8E4740DE1D19ABCDC261409F5BE84A048047407094BC3AC7C061409F5BE84A04804740
45829	55623	141.94359800000001	142.519193	47.632323	46.818998999999998	Центральная	0103000020E6100000010000000500000046D26EF431BE6140753A90F5D468474046D26EF431BE61401AC1C6F5EFD04740FD69A33A9DD061401AC1C6F5EFD04740FD69A33A9DD06140753A90F5D468474046D26EF431BE6140753A90F5D4684740
45942	24582	142.01892100000001	142.03880100000001	47.272702000000002	47.252325999999996	Школьная	0103000020E61000000100000005000000A58636009BC061401AF7E6374CA04740A58636009BC06140E3C62DE6E7A24740AB4198DB3DC16140E3C62DE6E7A24740AB4198DB3DC161401AF7E6374CA04740A58636009BC061401AF7E6374CA04740
45949	24427	141.96500399999999	141.96840900000001	47.471496999999999	47.459356999999997	Новосибирское	0103000020E610000001000000050000004B901150E1BE61402618CE35CCBA47404B901150E1BE6140C09481035ABC4740DE04DF34FDBE6140C09481035ABC4740DE04DF34FDBE61402618CE35CCBA47404B901150E1BE61402618CE35CCBA4740
45783	24540	142.00475499999999	142.034651	47.328176999999997	47.281781000000002	Центральная	0103000020E61000000100000005000000C22FF5F326C061402DD1596611A44740C22FF5F326C06140522635B401AA4740C2F869DC1BC16140522635B401AA4740C2F869DC1BC161402DD1596611A44740C22FF5F326C061402DD1596611A44740
45881	23403	142.05405400000001	142.160586	49.187275999999997	49.153413	Победы	0103000020E61000000100000005000000FA4674CFBAC1614000E48409A3934840FA4674CFBAC16140B0A9F3A8F89748404146408523C56140B0A9F3A8F89748404146408523C5614000E48409A3934840FA4674CFBAC1614000E48409A3934840
45777	23403	142.05405400000001	142.160586	49.187275999999997	49.153413	Мира	0103000020E61000000100000005000000FA4674CFBAC1614000E48409A3934840FA4674CFBAC16140B0A9F3A8F89748404146408523C56140B0A9F3A8F89748404146408523C5614000E48409A3934840FA4674CFBAC1614000E48409A3934840
45841	23403	142.05405400000001	142.160586	49.187275999999997	49.153413	Ленина	0103000020E61000000100000005000000FA4674CFBAC1614000E48409A3934840FA4674CFBAC16140B0A9F3A8F89748404146408523C56140B0A9F3A8F89748404146408523C5614000E48409A3934840FA4674CFBAC1614000E48409A3934840
45780	23403	142.05405400000001	142.160586	49.187275999999997	49.153413	Коммунистическая	0103000020E61000000100000005000000FA4674CFBAC1614000E48409A3934840FA4674CFBAC16140B0A9F3A8F89748404146408523C56140B0A9F3A8F89748404146408523C5614000E48409A3934840FA4674CFBAC1614000E48409A3934840
45914	23827	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	Угольная	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
45860	23827	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	Приморская	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
45778	23827	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	Победы	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
45902	23827	142.01387299999999	142.11098100000001	49.104647999999997	49.024935999999997	Войтинского	0103000020E610000001000000050000008429CAA571C061401C3F541A318348408429CAA571C06140C0CB0C1B658D484047AF06288DC36140C0CB0C1B658D484047AF06288DC361401C3F541A318348408429CAA571C061401C3F541A31834840
45921	23371	142.095305	142.161798	49.407353000000001	49.363382000000001	Советская	0103000020E61000000100000005000000A64412BD0CC3614040FA264D83AE4840A64412BD0CC36140B876A22424B44840DDD1FF722DC56140B876A22424B44840DDD1FF722DC5614040FA264D83AE4840A64412BD0CC3614040FA264D83AE4840
45918	24276	142.09328400000001	142.11201399999999	49.065823999999999	49.056372000000003	Центральная	0103000020E61000000100000005000000AF27BA2EFCC261407F349C3237874840AF27BA2EFCC261405DA5BBEB6C8848403656629E95C361405DA5BBEB6C8848403656629E95C361407F349C3237874840AF27BA2EFCC261407F349C3237874840
45917	24125	142.261269	142.275983	48.900514000000001	48.889704000000002	Есенина	0103000020E61000000100000005000000AD4ECE505CC86140698F17D2E1714840AD4ECE505CC861408ACBF10A4473484010E84CDAD4C861408ACBF10A4473484010E84CDAD4C86140698F17D2E1714840AD4ECE505CC86140698F17D2E1714840
9819	23357	142.11546300000001	142.150228	49.450536	49.435335000000002	Пионерская 	0103000020E61000000100000005000000BD1C76DFB1C36140EFE6A90EB9B74840BD1C76DFB1C36140D8D5E429ABB94840315EF3AACEC46140D8D5E429ABB94840315EF3AACEC46140EFE6A90EB9B74840BD1C76DFB1C36140EFE6A90EB9B74840
45895	24224	142.18342999999999	142.223432	48.949711000000001	48.935077	Новая	0103000020E610000001000000050000005E6397A8DEC56140F31E679AB07748405E6397A8DEC5614063D34A2190794840289CDD5A26C7614063D34A2190794840289CDD5A26C76140F31E679AB07748405E6397A8DEC56140F31E679AB0774840
45874	23264	142.15630100000001	142.1935	49.66384	49.638117999999999	Советская	0103000020E61000000100000005000000A16AF46A00C56140957EC2D9ADD14840A16AF46A00C5614069E388B5F8D44840D578E92631C6614069E388B5F8D44840D578E92631C66140957EC2D9ADD14840A16AF46A00C56140957EC2D9ADD14840
45940	23264	142.15630100000001	142.1935	49.66384	49.638117999999999	Заводская	0103000020E61000000100000005000000A16AF46A00C56140957EC2D9ADD14840A16AF46A00C5614069E388B5F8D44840D578E92631C6614069E388B5F8D44840D578E92631C66140957EC2D9ADD14840A16AF46A00C56140957EC2D9ADD14840
45840	23098	142.703159	142.72249099999999	50.648909000000003	50.633046	Титова	0103000020E610000001000000050000006B9C4D4780D661408B6EBDA6075149406B9C4D4780D66140408A3A730F534940F01472A51ED76140408A3A730F534940F01472A51ED761408B6EBDA6075149406B9C4D4780D661408B6EBDA607514940
45938	22458	142.68213800000001	142.690529	51.207923999999998	51.198459999999997	Советская	0103000020E610000001000000050000007C2B1213D4D5614036C82423679949407C2B1213D4D56140D906EE409D9A494011FE45D018D66140D906EE409D9A494011FE45D018D6614036C82423679949407C2B1213D4D5614036C8242367994940
45839	22735	142.63856999999999	142.68678299999999	50.870229999999999	50.827322000000002	Харитонова	0103000020E610000001000000050000009D465A2A6FD4614073A1F2AFE56949409D465A2A6FD46140C1FF56B2636F49405C8E5720FAD56140C1FF56B2636F49405C8E5720FAD5614073A1F2AFE56949409D465A2A6FD4614073A1F2AFE5694940
45842	22735	142.63856999999999	142.68678299999999	50.870229999999999	50.827322000000002	Торговая	0103000020E610000001000000050000009D465A2A6FD4614073A1F2AFE56949409D465A2A6FD46140C1FF56B2636F49405C8E5720FAD56140C1FF56B2636F49405C8E5720FAD5614073A1F2AFE56949409D465A2A6FD4614073A1F2AFE5694940
45894	22735	142.63856999999999	142.68678299999999	50.870229999999999	50.827322000000002	Советская	0103000020E610000001000000050000009D465A2A6FD4614073A1F2AFE56949409D465A2A6FD46140C1FF56B2636F49405C8E5720FAD56140C1FF56B2636F49405C8E5720FAD5614073A1F2AFE56949409D465A2A6FD4614073A1F2AFE5694940
45776	22735	142.63856999999999	142.68678299999999	50.870229999999999	50.827322000000002	Криворучко	0103000020E610000001000000050000009D465A2A6FD4614073A1F2AFE56949409D465A2A6FD46140C1FF56B2636F49405C8E5720FAD56140C1FF56B2636F49405C8E5720FAD5614073A1F2AFE56949409D465A2A6FD4614073A1F2AFE5694940
45775	22735	142.63856999999999	142.68678299999999	50.870229999999999	50.827322000000002	Кировская	0103000020E610000001000000050000009D465A2A6FD4614073A1F2AFE56949409D465A2A6FD46140C1FF56B2636F49405C8E5720FAD56140C1FF56B2636F49405C8E5720FAD5614073A1F2AFE56949409D465A2A6FD4614073A1F2AFE5694940
45893	22604	142.646152	142.65813499999999	51.021706999999999	51.013134000000001	Советская	0103000020E61000000100000005000000D787F546ADD461409B3BFA5FAE814940D787F546ADD46140118C834BC78249404BAB21710FD56140118C834BC78249404BAB21710FD561409B3BFA5FAE814940D787F546ADD461409B3BFA5FAE814940
45901	22993	142.66181900000001	142.68469899999999	50.796315	50.776617999999999	Новая	0103000020E61000000100000005000000E31B0A9F2DD5614012BEF73768634940E31B0A9F2DD56140392861A6ED6549405393E00DE9D56140392861A6ED6549405393E00DE9D5614012BEF73768634940E31B0A9F2DD5614012BEF73768634940
45872	23000	142.710408	142.736019	50.724398000000001	50.693584999999999	Центральная	0103000020E6100000010000000500000023DA8EA9BBD6614082FFAD64C758494023DA8EA9BBD66140D7A4DB12B95C494082C7B7778DD76140D7A4DB12B95C494082C7B7778DD7614082FFAD64C758494023DA8EA9BBD6614082FFAD64C7584940
45941	55640	142.23749900000001	143.317993	51.527493999999997	50.295797	Школьная	0103000020E61000000100000005000000A6BA809799C76140A1A014ADDC254940A6BA809799C76140096B63EC84C349406CEBA7FF2CEA6140096B63EC84C349406CEBA7FF2CEA6140A1A014ADDC254940A6BA809799C76140A1A014ADDC254940
45884	22907	142.58826500000001	142.61743300000001	50.841816999999999	50.828375000000001	Космическая	0103000020E61000000100000005000000350C1F11D3D2614079E92631086A4940350C1F11D3D26140C11BD2A8C06B494014CFD902C2D36140C11BD2A8C06B494014CFD902C2D3614079E92631086A4940350C1F11D3D2614079E92631086A4940
45896	22658	142.662699	142.68433899999999	50.908071999999997	50.891154999999998	Школьная	0103000020E61000000100000005000000F18288D434D561405C55F65D11724940F18288D434D56140E7340BB43B744940130CE71AE6D56140E7340BB43B744940130CE71AE6D561405C55F65D11724940F18288D434D561405C55F65D11724940
45962	23184	142.857606	142.867659	50.699342000000001	50.686064000000002	Советская	0103000020E610000001000000050000004F5B238271DB6140427BF5F1D05749404F5B238271DB6140105CE5098459494090A2CEDCC3DB6140105CE5098459494090A2CEDCC3DB6140427BF5F1D05749404F5B238271DB6140427BF5F1D0574940
45891	22452	142.71958900000001	142.74131	51.357855999999998	51.339387000000002	Комсомольская	0103000020E61000000100000005000000F7B182DF06D7614002D8800871AB4940F7B182DF06D76140B456B439CEAD494054C6BFCFB8D76140B456B439CEAD494054C6BFCFB8D7614002D8800871AB4940F7B182DF06D7614002D8800871AB4940
45965	22564	142.659402	142.683953	51.140132000000001	51.124482	Советская	0103000020E61000000100000005000000581D39D219D561406878B306EF8F4940581D39D219D56140C18F6AD8EF91494009E066F1E2D56140C18F6AD8EF91494009E066F1E2D561406878B306EF8F4940581D39D219D561406878B306EF8F4940
45937	22295	142.18034	142.20004	47.908022000000003	47.900176000000002	Ленина	0103000020E6100000010000000500000024456458C5C56140725298F738F3474024456458C5C5614036069D103AF447408A3C49BA66C6614036069D103AF447408A3C49BA66C66140725298F738F3474024456458C5C56140725298F738F34740
45820	22305	142.04894300000001	142.098997	47.774138999999998	47.756005000000002	Новая	0103000020E61000000100000005000000C80BE9F090C16140664E97C5C4E04740C80BE9F090C1614071C79BFC16E34740DEACC1FB2AC3614071C79BFC16E34740DEACC1FB2AC36140664E97C5C4E04740C80BE9F090C16140664E97C5C4E04740
45890	22305	142.04894300000001	142.098997	47.774138999999998	47.756005000000002	Калинина	0103000020E61000000100000005000000C80BE9F090C16140664E97C5C4E04740C80BE9F090C1614071C79BFC16E34740DEACC1FB2AC3614071C79BFC16E34740DEACC1FB2AC36140664E97C5C4E04740C80BE9F090C16140664E97C5C4E04740
45821	22305	142.04894300000001	142.098997	47.774138999999998	47.756005000000002	А.Буюклы	0103000020E61000000100000005000000C80BE9F090C16140664E97C5C4E04740C80BE9F090C1614071C79BFC16E34740DEACC1FB2AC3614071C79BFC16E34740DEACC1FB2AC36140664E97C5C4E04740C80BE9F090C16140664E97C5C4E04740
45963	22208	142.136394	142.16578699999999	47.904477	47.890993000000002	Вокзальная	0103000020E61000000100000005000000DC2BF3565DC4614083FB010F0CF24740DC2BF3565DC46140FA7DFFE6C5F3474043E389204EC56140FA7DFFE6C5F3474043E389204EC5614083FB010F0CF24740DC2BF3565DC4614083FB010F0CF24740
45960	22069	142.14571799999999	142.16319100000001	48.326098000000002	48.315727000000003	Центральная	0103000020E61000000100000005000000088ECBB8A9C461406BBB09BE69284840088ECBB8A9C4614040A54A94BD2948400D0055DC38C5614040A54A94BD2948400D0055DC38C561406BBB09BE69284840088ECBB8A9C461406BBB09BE69284840
45857	21922	142.06959499999999	142.11361299999999	48.437162000000001	48.385669999999998	Победы	0103000020E61000000100000005000000E21E4B1F3AC261402F8672A25D314840E21E4B1F3AC26140E886A6ECF4374840D0ECBAB7A2C36140E886A6ECF4374840D0ECBAB7A2C361402F8672A25D314840E21E4B1F3AC261402F8672A25D314840
45889	21922	142.06959499999999	142.11361299999999	48.437162000000001	48.385669999999998	Карла Маркса	0103000020E61000000100000005000000E21E4B1F3AC261402F8672A25D314840E21E4B1F3AC26140E886A6ECF4374840D0ECBAB7A2C36140E886A6ECF4374840D0ECBAB7A2C361402F8672A25D314840E21E4B1F3AC261402F8672A25D314840
45928	55637	142.19209000000001	142.22664800000001	48.000771	47.976866999999999	пер.Гвардейский	0103000020E61000000100000005000000707CED9925C6614054C554FA09FD4740707CED9925C6614082E49D431900484086764EB340C7614082E49D431900484086764EB340C7614054C554FA09FD4740707CED9925C6614054C554FA09FD4740
45961	55637	142.19209000000001	142.22664800000001	48.000771	47.976866999999999	Ломоносова	0103000020E61000000100000005000000707CED9925C6614054C554FA09FD4740707CED9925C6614082E49D431900484086764EB340C7614082E49D431900484086764EB340C7614054C554FA09FD4740707CED9925C6614054C554FA09FD4740
45883	21544	142.80573799999999	142.85561200000001	49.767164000000001	49.729277000000003	Центральная	0103000020E610000001000000050000009FE40E9BC8D96140CD5CE0F258DD48409FE40E9BC8D961409355116E32E2484016C26A2C61DB61409355116E32E2484016C26A2C61DB6140CD5CE0F258DD48409FE40E9BC8D96140CD5CE0F258DD4840
45959	21544	142.80573799999999	142.85561200000001	49.767164000000001	49.729277000000003	Торговая	0103000020E610000001000000050000009FE40E9BC8D96140CD5CE0F258DD48409FE40E9BC8D961409355116E32E2484016C26A2C61DB61409355116E32E2484016C26A2C61DB6140CD5CE0F258DD48409FE40E9BC8D96140CD5CE0F258DD4840
45809	21544	142.80573799999999	142.85561200000001	49.767164000000001	49.729277000000003	Маяковского	0103000020E610000001000000050000009FE40E9BC8D96140CD5CE0F258DD48409FE40E9BC8D961409355116E32E2484016C26A2C61DB61409355116E32E2484016C26A2C61DB6140CD5CE0F258DD48409FE40E9BC8D96140CD5CE0F258DD4840
45819	21544	142.80573799999999	142.85561200000001	49.767164000000001	49.729277000000003	8 марта	0103000020E610000001000000050000009FE40E9BC8D96140CD5CE0F258DD48409FE40E9BC8D961409355116E32E2484016C26A2C61DB61409355116E32E2484016C26A2C61DB6140CD5CE0F258DD48409FE40E9BC8D96140CD5CE0F258DD4840
45958	21343	142.75406699999999	142.77832100000001	49.964627999999998	49.954236999999999	Парковая	0103000020E61000000100000005000000C5FF1D5121D861400BD1217024FA4840C5FF1D5121D86140276728EE78FB484048197101E8D86140276728EE78FB484048197101E8D861400BD1217024FA4840C5FF1D5121D861400BD1217024FA4840
45739	21442	142.80189300000001	142.84940499999999	49.851522000000003	49.821705000000001	Центральная	0103000020E61000000100000005000000863C821BA9D96140D7FA22A12DE94840863C821BA9D961408AE942ACFEEC4840E20165532EDB61408AE942ACFEEC4840E20165532EDB6140D7FA22A12DE94840863C821BA9D96140D7FA22A12DE94840
45899	21436	143.24833799999999	143.276949	49.987864000000002	49.951078000000003	Суворова	0103000020E61000000100000005000000548B8862F2E76140F9F884ECBCF94840548B8862F2E76140A872DA5372FE48401E3526C4DCE86140A872DA5372FE48401E3526C4DCE86140F9F884ECBCF94840548B8862F2E76140F9F884ECBCF94840
45738	21266	142.66142300000001	142.72402700000001	50.200482000000001	50.182170999999997	Транспортная	0103000020E61000000100000005000000503A91602AD56140CAA31B6151174940503A91602AD56140E5B7E864A919494079CDAB3A2BD76140E5B7E864A919494079CDAB3A2BD76140CAA31B6151174940503A91602AD56140CAA31B6151174940
45900	21728	142.84867700000001	142.884197	49.559089999999998	49.529570999999997	Школьная	0103000020E61000000100000005000000C2FBAA5C28DB61407BF486FBC8C34840C2FBAA5C28DB6140A4C2D84290C7484015C781574BDC6140A4C2D84290C7484015C781574BDC61407BF486FBC8C34840C2FBAA5C28DB61407BF486FBC8C34840
45897	21728	142.84867700000001	142.884197	49.559089999999998	49.529570999999997	Космонавтов	0103000020E61000000100000005000000C2FBAA5C28DB61407BF486FBC8C34840C2FBAA5C28DB6140A4C2D84290C7484015C781574BDC6140A4C2D84290C7484015C781574BDC61407BF486FBC8C34840C2FBAA5C28DB61407BF486FBC8C34840
45911	20917	142.884152	142.914649	49.210510999999997	49.197555999999999	Ленина	0103000020E610000001000000050000002D9622F94ADC61407590D783499948402D9622F94ADC614060394206F29A484036CAFACD44DD614060394206F29A484036CAFACD44DD61407590D783499948402D9622F94ADC61407590D78349994840
45879	20174	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	проспект А.Буюклы	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
45936	20174	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	Торфяная	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
45817	20174	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	Победы	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
45724	20174	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	Октябрьская	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
45770	20174	143.06164100000001	143.14920000000001	49.247669000000002	49.198044000000003	Гагарина	0103000020E61000000100000005000000F8E28BF6F8E16140A3957B8159994840F8E28BF6F8E16140D49D279EB39F48400612143FC6E46140D49D279EB39F48400612143FC6E46140A3957B8159994840F8E28BF6F8E16140A3957B8159994840
45913	21163	142.89545200000001	142.91706600000001	49.470824999999998	49.460133999999996	Школьная	0103000020E6100000010000000500000069E4F38AA7DC61408AE3C0ABE5BA484069E4F38AA7DC6140D1915CFE43BC4840C1C8CB9A58DD6140D1915CFE43BC4840C1C8CB9A58DD61408AE3C0ABE5BA484069E4F38AA7DC61408AE3C0ABE5BA4840
45910	21062	142.86946399999999	142.90890899999999	49.298501000000002	49.287109000000001	Ленина	0103000020E6100000010000000500000094A12AA6D2DB614092B1DAFCBFA4484094A12AA6D2DB61406269E04735A6484048C153C815DD61406269E04735A6484048C153C815DD614092B1DAFCBFA4484094A12AA6D2DB614092B1DAFCBFA44840
45875	20983	142.85062600000001	142.888823	49.288513000000002	49.272669	Калинина	0103000020E610000001000000050000001364045438DB614007D15AD1E6A248401364045438DB614045BC75FEEDA44840D89DEE3C71DC614045BC75FEEDA44840D89DEE3C71DC614007D15AD1E6A248401364045438DB614007D15AD1E6A24840
45912	21068	142.85744500000001	142.87323699999999	49.363387000000003	49.355905999999997	Советская	0103000020E61000000100000005000000CD237F3070DB61409F39EB538EAD4840CD237F3070DB61405265187783AE48400795B88EF1DB61405265187783AE48400795B88EF1DB61409F39EB538EAD4840CD237F3070DB61409F39EB538EAD4840
45870	20863	142.923327	142.96531400000001	49.108364000000002	49.094743999999999	Центральная	0103000020E61000000100000005000000719010E58BDD614001BF4692208C4840719010E58BDD614029081EDFDE8D4840DF8B2FDAE3DE614029081EDFDE8D4840DF8B2FDAE3DE614001BF4692208C4840719010E58BDD614001BF4692208C4840
45772	20851	142.90613300000001	142.92580599999999	48.988207000000003	48.973756000000002	Гагарина	0103000020E61000000100000005000000721AA20AFFDC614053245F09A47C4840721AA20AFFDC6140D25625917D7E4840198EE733A0DD6140D25625917D7E4840198EE733A0DD614053245F09A47C4840721AA20AFFDC614053245F09A47C4840
45805	20755	142.841554	142.90716599999999	48.998646000000001	48.979610000000001	Центральная	0103000020E610000001000000050000002D7AA702EEDA6140D36A48DC637D48402D7AA702EEDA6140FF23D3A1D37F484061C1FD8007DD6140FF23D3A1D37F484061C1FD8007DD6140D36A48DC637D48402D7AA702EEDA6140D36A48DC637D4840
45838	19837	142.946495	142.96482	53.397129	53.380921999999998	Нефтяников	0103000020E610000001000000050000007BDAE1AF49DE6140D829560DC2B04A407BDAE1AF49DE614087A5811FD5B24A40DB5031CEDFDE614087A5811FD5B24A40DB5031CEDFDE6140D829560DC2B04A407BDAE1AF49DE6140D829560DC2B04A40
45737	15958	142.90475000000001	142.973848	53.609161999999998	53.562835	Советская	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45835	15958	142.90475000000001	142.973848	53.609161999999998	53.562835	Победы	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45769	15958	142.90475000000001	142.973848	53.609161999999998	53.562835	Карла Маркса	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45836	15958	142.90475000000001	142.973848	53.609161999999998	53.562835	Дзержинского	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45812	15958	142.90475000000001	142.973848	53.609161999999998	53.562835	60 лет СССР	0103000020E61000000100000005000000CBA145B6F3DC6140A7052FFA0AC84A40CBA145B6F3DC6140A4FB3905F9CD4A40CDE847C329DF6140A4FB3905F9CD4A40CDE847C329DF6140A7052FFA0AC84A40CBA145B6F3DC6140A7052FFA0AC84A40
45882	19884	142.61603099999999	142.634276	53.687869999999997	53.671197999999997	Октябрьская	0103000020E610000001000000050000004FCAA486B6D36140FF91E9D0E9D54A404FCAA486B6D3614023F3C81F0CD84A4068942EFD4BD4614023F3C81F0CD84A4068942EFD4BD46140FF91E9D0E9D54A404FCAA486B6D36140FF91E9D0E9D54A40
45957	20042	142.49665400000001	142.51622900000001	53.596632	53.571759999999998	Советская	0103000020E61000000100000005000000AFEDED96E4CF61409A94826E2FC94A40AFEDED96E4CF6140A0DFF76F5ECC4A40E607AEF284D06140A0DFF76F5ECC4A40E607AEF284D061409A94826E2FC94A40AFEDED96E4CF61409A94826E2FC94A40
45923	55636	141.628828	143.32529600000001	54.424470999999997	51.893394999999998	Ленина	0103000020E61000000100000005000000E4D9E55B1FB4614078B471C45AF24940E4D9E55B1FB46140DA8CD31055364B40A13028D368EA6140DA8CD31055364B40A13028D368EA614078B471C45AF24940E4D9E55B1FB4614078B471C45AF24940
45865	55626	143.02812499999999	143.075861	53.498710000000003	53.450138000000003	Школьная	0103000020E6100000010000000500000066666666E6E06140EB573A1F9EB94A4066666666E6E061401618B2BAD5BF4A4057410C746DE261401618B2BAD5BF4A4057410C746DE26140EB573A1F9EB94A4066666666E6E06140EB573A1F9EB94A40
45880	19216	142.747311	142.78050400000001	51.544043000000002	51.531785999999997	Советская	0103000020E610000001000000050000001D1EC2F8E9D761403E3C4B9011C449401D1EC2F8E9D76140124F7633A3C54940B64C86E3F9D86140124F7633A3C54940B64C86E3F9D861403E3C4B9011C449401D1EC2F8E9D761403E3C4B9011C44940
45871	18843	143.10432	143.18010200000001	51.822636000000003	51.768867999999998	Штернберга	0103000020E61000000100000005000000338AE59656E36140707841446AE24940338AE59656E361409241EE224CE9494037FE4465C3E561409241EE224CE9494037FE4465C3E56140707841446AE24940338AE59656E36140707841446AE24940
45767	18843	143.10432	143.18010200000001	51.822636000000003	51.768867999999998	Советская	0103000020E61000000100000005000000338AE59656E36140707841446AE24940338AE59656E361409241EE224CE9494037FE4465C3E561409241EE224CE9494037FE4465C3E56140707841446AE24940338AE59656E36140707841446AE24940
45752	18843	143.10432	143.18010200000001	51.822636000000003	51.768867999999998	Пограничная	0103000020E61000000100000005000000338AE59656E36140707841446AE24940338AE59656E361409241EE224CE9494037FE4465C3E561409241EE224CE9494037FE4465C3E56140707841446AE24940338AE59656E36140707841446AE24940
45768	18843	143.10432	143.18010200000001	51.822636000000003	51.768867999999998	Мостовая	0103000020E61000000100000005000000338AE59656E36140707841446AE24940338AE59656E361409241EE224CE9494037FE4465C3E561409241EE224CE9494037FE4465C3E56140707841446AE24940338AE59656E36140707841446AE24940
45927	19158	143.21501900000001	143.25100599999999	51.718445000000003	51.698481999999998	Советская	0103000020E6100000010000000500000099A0866FE1E661401E6CB1DB67D9494099A0866FE1E66140C47C7901F6DB49403123BC3D08E86140C47C7901F6DB49403123BC3D08E861401E6CB1DB67D9494099A0866FE1E661401E6CB1DB67D94940
45834	55624	143.00032200000001	143.13212300000001	52.383260999999997	52.302536000000003	Комсомольская	0103000020E61000000100000005000000056F48A302E061406CEEE87FB9264A40056F48A302E06140876A4AB20E314A409581035A3AE46140876A4AB20E314A409581035A3AE461406CEEE87FB9264A40056F48A302E061406CEEE87FB9264A40
45919	55634	141.89299500000001	141.91377299999999	46.752358000000001	46.746473999999999	Заречная	0103000020E61000000100000005000000BB0F406A93BC61403BA8C4758C5F4740BB0F406A93BC6140267156444D604740F8DEDFA03DBD6140267156444D604740F8DEDFA03DBD61403BA8C4758C5F4740BB0F406A93BC61403BA8C4758C5F4740
45892	18692	141.847352	141.872613	46.437610999999997	46.417448	Дачная	0103000020E610000001000000050000006806F1811DBB6140EBE3A1EF6E3547406806F1811DBB614057AF22A30338474010221972ECBB614057AF22A30338474010221972ECBB6140EBE3A1EF6E3547406806F1811DBB6140EBE3A1EF6E354740
45782	18212	141.84986699999999	141.889411	46.720081	46.641136000000003	Школьная	0103000020E61000000100000005000000635E471C32BB6140E62494BE10524740635E471C32BB614049BC3C9D2B5C47407CB60E0E76BC614049BC3C9D2B5C47407CB60E0E76BC6140E62494BE10524740635E471C32BB6140E62494BE10524740
45766	18212	141.84986699999999	141.889411	46.720081	46.641136000000003	Приморская	0103000020E61000000100000005000000635E471C32BB6140E62494BE10524740635E471C32BB614049BC3C9D2B5C47407CB60E0E76BC614049BC3C9D2B5C47407CB60E0E76BC6140E62494BE10524740635E471C32BB6140E62494BE10524740
45761	18212	141.84986699999999	141.889411	46.720081	46.641136000000003	Победы	0103000020E61000000100000005000000635E471C32BB6140E62494BE10524740635E471C32BB614049BC3C9D2B5C47407CB60E0E76BC614049BC3C9D2B5C47407CB60E0E76BC6140E62494BE10524740635E471C32BB6140E62494BE10524740
45765	18212	141.84986699999999	141.889411	46.720081	46.641136000000003	Ленина	0103000020E61000000100000005000000635E471C32BB6140E62494BE10524740635E471C32BB614049BC3C9D2B5C47407CB60E0E76BC614049BC3C9D2B5C47407CB60E0E76BC6140E62494BE10524740635E471C32BB6140E62494BE10524740
45734	18212	141.84986699999999	141.889411	46.720081	46.641136000000003	Гоголя	0103000020E61000000100000005000000635E471C32BB6140E62494BE10524740635E471C32BB614049BC3C9D2B5C47407CB60E0E76BC614049BC3C9D2B5C47407CB60E0E76BC6140E62494BE10524740635E471C32BB6140E62494BE10524740
45956	18463	141.89089300000001	141.92207400000001	46.659112999999998	46.643622999999998	Гагарина	0103000020E610000001000000050000008867093282BC614009FA0B3D625247408867093282BC614029AF95D05D544740BE4F55A181BD614029AF95D05D544740BE4F55A181BD614009FA0B3D625247408867093282BC614009FA0B3D62524740
45774	55621	141.82046500000001	141.87423000000001	46.582158999999997	46.542155999999999	Советская	0103000020E6100000010000000500000068D0D03F41BA614043AA285E6545474068D0D03F41BA61403909A52F844A4740D46531B1F9BB61403909A52F844A4740D46531B1F9BB614043AA285E6545474068D0D03F41BA614043AA285E65454740
45837	55621	141.82046500000001	141.87423000000001	46.582158999999997	46.542155999999999	Клубная	0103000020E6100000010000000500000068D0D03F41BA614043AA285E6545474068D0D03F41BA61403909A52F844A4740D46531B1F9BB61403909A52F844A4740D46531B1F9BB614043AA285E6545474068D0D03F41BA614043AA285E65454740
45954	17857	142.741454	142.759986	48.57544	48.565043000000003	Школьная	0103000020E61000000100000005000000A12FBDFDB9D76140B8EA3A5453484840A12FBDFDB9D76140B6679604A84948405FED28CE51D86140B6679604A84948405FED28CE51D86140B8EA3A5453484840A12FBDFDB9D76140B8EA3A5453484840
45906	55631	\N	\N	\N	\N	Центральная	\N
45728	17867	142.76570899999999	142.791436	48.636825999999999	48.606327	50 лет Октября	0103000020E61000000100000005000000172829B080D8614045D7851F9C4D4840172829B080D861400A9FAD8383514840111C977153D961400A9FAD8383514840111C977153D9614045D7851F9C4D4840172829B080D8614045D7851F9C4D4840
45948	18070	142.78089	142.82707300000001	48.758665000000001	48.742620000000002	Шахтерская	0103000020E61000000100000005000000C078060DFDD8614082AD122C0E5F4840C078060DFDD8614057CF49EF1B614840F3CCCB6177DA614057CF49EF1B614840F3CCCB6177DA614082AD122C0E5F4840C078060DFDD8614082AD122C0E5F4840
45915	55633	142.617774	142.63452799999999	48.282989000000001	48.261592	Привокзальная	0103000020E6100000010000000500000036CAFACDC4D361409772BED87B21484036CAFACDC4D361405A10CAFB38244840AE0CAA0D4ED461405A10CAFB38244840AE0CAA0D4ED461409772BED87B21484036CAFACDC4D361409772BED87B214840
79372	61550	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	Мира	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
45864	16479	142.92597699999999	142.96667099999999	46.787503000000001	46.775117999999999	Школьная	0103000020E61000000100000005000000247B849AA1DD61403D450E1137634740247B849AA1DD61403E40F7E5CC644740BB5F05F8EEDE61403E40F7E5CC644740BB5F05F8EEDE61403D450E1137634740247B849AA1DD61403D450E1137634740
45866	16669	142.73614499999999	142.76309499999999	46.742885999999999	46.715817999999999	Центральная	0103000020E61000000100000005000000A583F57F8ED76140AEF199EC9F5B4740A583F57F8ED76140005471E3165F4740B79734466BD86140005471E3165F4740B79734466BD86140AEF199EC9F5B4740A583F57F8ED76140AEF199EC9F5B4740
45955	16560	142.80901700000001	142.81973300000001	46.654170999999998	46.643908000000003	Школьная	0103000020E610000001000000050000000F9D9E77E3D96140FFD0CC936B5247400F9D9E77E3D96140ED7E15E0BB534740774EB3403BDA6140ED7E15E0BB534740774EB3403BDA6140FFD0CC936B5247400F9D9E77E3D96140FFD0CC936B524740
45964	55644	143.32846699999999	143.338663	46.611615	46.601678999999997	Крутая	0103000020E6100000010000000500000016DA39CD82EA614051D845D1034D474016DA39CD82EA61401C5F7B66494E4740B0ABC953D6EA61401C5F7B66494E4740B0ABC953D6EA614051D845D1034D474016DA39CD82EA614051D845D1034D4740
45926	16361	143.14946900000001	143.16206299999999	46.866706999999998	46.851714999999999	Центральная	0103000020E6100000010000000500000082583673C8E461409E4143FF046D474082583673C8E461406D1B4641F06E4740889CBE9E2FE561406D1B4641F06E4740889CBE9E2FE561409E4143FF046D474082583673C8E461409E4143FF046D4740
45760	55619	143.111785	143.154706	46.614846999999997	46.599988000000003	Центральная	0103000020E61000000100000005000000DEE522BE93E3614009FF2268CC4C4740DEE522BE93E361409885764EB34E4740D74FFF59F3E461409885764EB34E4740D74FFF59F3E4614009FF2268CC4C4740DEE522BE93E3614009FF2268CC4C4740
45862	16254	143.34894	143.377138	46.378877000000003	46.359183999999999	Советская	0103000020E61000000100000005000000850838842AEB61408C9FC6BDF92D4740850838842AEB6140721AA20A7F3047408602B68311EC6140721AA20A7F3047408602B68311EC61408C9FC6BDF92D4740850838842AEB61408C9FC6BDF92D4740
45947	16418	143.06965400000001	143.09295599999999	46.909841999999998	46.904381000000001	Морская	0103000020E610000001000000050000002481069B3AE26140D80FB1C1C27347402481069B3AE261407C43E1B375744740F17EDC7EF9E261407C43E1B375744740F17EDC7EF9E26140D80FB1C1C27347402481069B3AE26140D80FB1C1C2734740
45759	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Советская	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45925	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Портовая	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45815	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Подгорная	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45816	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Первомайская	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45813	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Окружная	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45814	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Невельская	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45726	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Морская	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45725	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Молодежный	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45758	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Корсаковская	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45858	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Зеленая	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45867	16799	142.75138100000001	142.81208000000001	46.660330999999999	46.604191999999998	Железнодорожная	0103000020E61000000100000005000000BFBA2A500BD861409E40D829564D4740BFBA2A500BD861407AC4E8B9855447408B37328FFCD961407AC4E8B9855447408B37328FFCD961409E40D829564D4740BFBA2A500BD861409E40D829564D4740
45832	16061	142.59061800000001	142.647661	47.327669999999998	47.304485999999997	Ленина	0103000020E61000000100000005000000BA4DB857E6D26140800BB265F9A64740BA4DB857E6D26140AEF02E17F1A94740A1BC8FA3B9D46140AEF02E17F1A94740A1BC8FA3B9D46140800BB265F9A64740BA4DB857E6D26140800BB265F9A64740
45749	15493	142.79485	142.84313499999999	47.416187000000001	47.404052	Набережная	0103000020E61000000100000005000000386744696FD9614013F1D6F9B7B34740386744696FD961409B02999D45B547409D6340F6FADA61409B02999D45B547409D6340F6FADA614013F1D6F9B7B34740386744696FD9614013F1D6F9B7B34740
45833	15819	142.73407900000001	142.77646200000001	47.299670999999996	47.208123000000001	Совхозная	0103000020E61000000100000005000000C6353E937DD76140D04543C6A39A4740C6353E937DD76140A1478C9E5BA64740C712D6C6D8D86140A1478C9E5BA64740C712D6C6D8D86140D04543C6A39A4740C6353E937DD76140D04543C6A39A4740
45804	15819	142.73407900000001	142.77646200000001	47.299670999999996	47.208123000000001	Лесная	0103000020E61000000100000005000000C6353E937DD76140D04543C6A39A4740C6353E937DD76140A1478C9E5BA64740C712D6C6D8D86140A1478C9E5BA64740C712D6C6D8D86140D04543C6A39A4740C6353E937DD76140D04543C6A39A4740
45898	15393	142.63981899999999	142.685633	47.507379	47.482526999999997	Центральная	0103000020E61000000100000005000000800BB26579D46140EF37DA71C3BD4740800BB26579D46140AED689CBF1C04740DE019EB4F0D56140AED689CBF1C04740DE019EB4F0D56140EF37DA71C3BD4740800BB26579D46140EF37DA71C3BD4740
45868	16053	142.700311	142.70847699999999	47.330778000000002	47.322270000000003	Березовая	0103000020E61000000100000005000000EE409DF268D66140B03DB32440A94740EE409DF268D661403F1EFAEE56AA4740FB1EF5D7ABD661403F1EFAEE56AA4740FB1EF5D7ABD66140B03DB32440A94740EE409DF268D66140B03DB32440A94740
45811	15503	142.77762000000001	142.808145	47.343034000000003	47.310198999999997	Хабаровская	0103000020E61000000100000005000000E6965643E2D861403E20D099B4A74740E6965643E2D8614042B5C189E8AB4740A12DE752DCD9614042B5C189E8AB4740A12DE752DCD961403E20D099B4A74740E6965643E2D861403E20D099B4A74740
45876	15503	142.77762000000001	142.808145	47.343034000000003	47.310198999999997	Советская	0103000020E61000000100000005000000E6965643E2D861403E20D099B4A74740E6965643E2D8614042B5C189E8AB4740A12DE752DCD9614042B5C189E8AB4740A12DE752DCD961403E20D099B4A74740E6965643E2D861403E20D099B4A74740
45831	15503	142.77762000000001	142.808145	47.343034000000003	47.310198999999997	Октябрьская	0103000020E61000000100000005000000E6965643E2D861403E20D099B4A74740E6965643E2D8614042B5C189E8AB4740A12DE752DCD9614042B5C189E8AB4740A12DE752DCD961403E20D099B4A74740E6965643E2D861403E20D099B4A74740
45756	15503	142.77762000000001	142.808145	47.343034000000003	47.310198999999997	Ленина	0103000020E61000000100000005000000E6965643E2D861403E20D099B4A74740E6965643E2D8614042B5C189E8AB4740A12DE752DCD9614042B5C189E8AB4740A12DE752DCD961403E20D099B4A74740E6965643E2D861403E20D099B4A74740
45755	15503	142.77762000000001	142.808145	47.343034000000003	47.310198999999997	Комсомольская	0103000020E61000000100000005000000E6965643E2D861403E20D099B4A74740E6965643E2D8614042B5C189E8AB4740A12DE752DCD9614042B5C189E8AB4740A12DE752DCD961403E20D099B4A74740E6965643E2D861403E20D099B4A74740
45750	15503	142.77762000000001	142.808145	47.343034000000003	47.310198999999997	Владивостокская	0103000020E61000000100000005000000E6965643E2D861403E20D099B4A74740E6965643E2D8614042B5C189E8AB4740A12DE752DCD9614042B5C189E8AB4740A12DE752DCD961403E20D099B4A74740E6965643E2D861403E20D099B4A74740
45877	15297	142.502206	142.53053	47.860086000000003	47.840822000000003	Пионерская	0103000020E610000001000000050000005C3B511212D06140F0E0270EA0EB47405C3B511212D06140ADDF4C4C17EE474080F10C1AFAD06140ADDF4C4C17EE474080F10C1AFAD06140F0E0270EA0EB47405C3B511212D06140F0E0270EA0EB4740
45808	55622	142.49592699999999	142.62772799999999	47.362704000000001	47.273074999999999	Шахтерская	0103000020E6100000010000000500000082C64CA2DECF6140772D211FF4A2474082C64CA2DECF61406F10AD156DAE474012D9075916D461406F10AD156DAE474012D9075916D46140772D211FF4A2474082C64CA2DECF6140772D211FF4A24740
45933	14739	142.57368500000001	142.59304399999999	46.858204000000001	46.846594000000003	переулок Почтовый	0103000020E610000001000000050000009626A5A05BD26140B37E33315D6C47409626A5A05BD26140F0A5F0A0D96D4740D9226937FAD26140F0A5F0A0D96D4740D9226937FAD26140B37E33315D6C47409626A5A05BD26140B37E33315D6C4740
45730	14624	142.62735900000001	142.663319	46.934165999999998	46.908850999999999	Центральная	0103000020E610000001000000050000003E7B2E5313D46140ECF7C43A557447403E7B2E5313D461407F8461C092774740187AC4E839D561407F8461C092774740187AC4E839D56140ECF7C43A557447403E7B2E5313D46140ECF7C43A55744740
45855	14624	142.62735900000001	142.663319	46.934165999999998	46.908850999999999	Советская	0103000020E610000001000000050000003E7B2E5313D46140ECF7C43A557447403E7B2E5313D461407F8461C092774740187AC4E839D561407F8461C092774740187AC4E839D56140ECF7C43A557447403E7B2E5313D46140ECF7C43A55744740
45861	14624	142.62735900000001	142.663319	46.934165999999998	46.908850999999999	Невельская	0103000020E610000001000000050000003E7B2E5313D46140ECF7C43A557447403E7B2E5313D461407F8461C092774740187AC4E839D561407F8461C092774740187AC4E839D56140ECF7C43A557447403E7B2E5313D46140ECF7C43A55744740
45886	14968	142.41501500000001	142.443106	46.638488000000002	46.611305999999999	Лесная	0103000020E610000001000000050000002F8B89CD47CD61409EEC66463F4E47402F8B89CD47CD6140B9718BF9B95147402A55A2EC2DCE6140B9718BF9B95147402A55A2EC2DCE61409EEC66463F4E47402F8B89CD47CD61409EEC66463F4E4740
45935	14912	142.51648	142.53980899999999	46.706476000000002	46.696736000000001	Береговая	0103000020E6100000010000000500000038A1100187D0614012F92EA52E59474038A1100187D0614057B439CE6D5A4740C422861D46D1614057B439CE6D5A4740C422861D46D1614012F92EA52E59474038A1100187D0614012F92EA52E594740
45905	15023	142.37849900000001	142.4034	46.78219	46.774327999999997	Школьная	0103000020E610000001000000050000003352EFA91CCC614044300E2E1D6347403352EFA91CCC61400EA14ACD1E6447409BE61DA7E8CC61400EA14ACD1E6447409BE61DA7E8CC614044300E2E1D6347403352EFA91CCC614044300E2E1D634740
45931	14635	142.680216	142.69379900000001	46.895803999999998	46.887287999999998	Центральная	0103000020E61000000100000005000000E9465854C4D561400E1137A792714740E9465854C4D5614020D099B4A9724740ECDFF59933D6614020D099B4A9724740ECDFF59933D661400E1137A792714740E9465854C4D561400E1137A792714740
45932	14677	142.72177199999999	142.74061900000001	46.811093	46.799719000000003	Рабочая	0103000020E6100000010000000500000064E597C118D76140B37E33315D66474064E597C118D76140DC813AE5D16747407BF99D26B3D76140DC813AE5D16747407BF99D26B3D76140B37E33315D66474064E597C118D76140B37E33315D664740
45966	55645	142.65781200000001	142.67464699999999	47.083419999999997	47.072440999999998	Советская	0103000020E61000000100000005000000535DC0CB0CD56140DCF126BF45894740535DC0CB0CD5614089EAAD81AD8A4740062B4EB596D5614089EAAD81AD8A4740062B4EB596D56140DCF126BF45894740535DC0CB0CD56140DCF126BF45894740
45908	15093	142.30848399999999	142.32420500000001	46.817075000000003	46.810457999999997	Луговая	0103000020E61000000100000005000000DB6AD619DFC961400A647616BD674740DB6AD619DFC961408AB0E1E99568474064062AE35FCA61408AB0E1E99568474064062AE35FCA61400A647616BD674740DB6AD619DFC961400A647616BD674740
45934	14820	142.521062	142.540941	46.762421000000003	46.738352999999996	Новая	0103000020E610000001000000050000000726378AACD06140A5F3E159825E47400726378AACD061404E64E60297614740190280634FD161404E64E60297614740190280634FD16140A5F3E159825E47400726378AACD06140A5F3E159825E4740
45863	15097	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	Победы	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
45748	15097	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	Ленина	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
45922	15097	142.51085699999999	142.54226199999999	46.725535999999998	46.708212000000003	 им. Пудова	0103000020E61000000100000005000000D87DC7F058D061404051D9B0A65A4740D87DC7F058D061400B09185DDE5C4740A27BD6355AD161400B09185DDE5C4740A27BD6355AD161404051D9B0A65A4740D87DC7F058D061404051D9B0A65A4740
81103	29759	142.17029600000001	142.18561299999999	50.837232	50.823846000000003	Бугайского	0103000020E6100000010000000500000078D4981073C56140607825C97369494078D4981073C5614014950D6B2A6B4940CC96AC8AF0C5614014950D6B2A6B4940CC96AC8AF0C56140607825C97369494078D4981073C56140607825C973694940
45859	14068	142.25115400000001	142.301953	51.055021000000004	51.040666000000002	Советская	0103000020E610000001000000050000004F081D7409C861409207228B348549404F081D7409C86140EFCB99ED0A874940BB7D5699A9C96140EFCB99ED0A874940BB7D5699A9C961409207228B348549404F081D7409C861409207228B34854940
45951	14057	142.25654399999999	142.266704	51.099725999999997	51.095211999999997	переулок Школьный	0103000020E61000000100000005000000853FC39B35C86140E71725E82F8C4940853FC39B35C86140CB4752D2C38C4940CCB6D3D688C86140CB4752D2C38C4940CCB6D3D688C86140E71725E82F8C4940853FC39B35C86140E71725E82F8C4940
45952	14245	142.10036299999999	142.12202099999999	50.832869000000002	50.816612999999997	Чехова	0103000020E610000001000000050000004F57772C36C36140853E58C6866849404F57772C36C36140166D8E739B6A49409B8D9598E7C36140166D8E739B6A49409B8D9598E7C36140853E58C6866849404F57772C36C36140853E58C686684940
45950	14113	142.25216	142.28477799999999	50.949305000000003	50.941631999999998	Советская	0103000020E61000000100000005000000802BD9B111C86140FC6EBA6587784940802BD9B111C86140F37684D382794940D993C0E61CC96140F37684D382794940D993C0E61CC96140FC6EBA6587784940802BD9B111C86140FC6EBA6587784940
9813	14250	142.12698900000001	142.19465	50.936836	50.868848999999997	Советская	0103000020E61000000100000005000000753E3C4B10C46140C614AC71366F4940753E3C4B10C4614094DBF63DEA7749405305A3923AC6614094DBF63DEA7749405305A3923AC66140C614AC71366F4940753E3C4B10C46140C614AC71366F4940
45830	14250	142.12698900000001	142.19465	50.936836	50.868848999999997	Кирова	0103000020E61000000100000005000000753E3C4B10C46140C614AC71366F4940753E3C4B10C4614094DBF63DEA7749405305A3923AC6614094DBF63DEA7749405305A3923AC66140C614AC71366F4940753E3C4B10C46140C614AC71366F4940
45807	14250	142.12698900000001	142.19465	50.936836	50.868848999999997	Дальневосточная	0103000020E61000000100000005000000753E3C4B10C46140C614AC71366F4940753E3C4B10C4614094DBF63DEA7749405305A3923AC6614094DBF63DEA7749405305A3923AC66140C614AC71366F4940753E3C4B10C46140C614AC71366F4940
45930	14250	142.12698900000001	142.19465	50.936836	50.868848999999997	Аболтина	0103000020E61000000100000005000000753E3C4B10C46140C614AC71366F4940753E3C4B10C4614094DBF63DEA7749405305A3923AC6614094DBF63DEA7749405305A3923AC66140C614AC71366F4940753E3C4B10C46140C614AC71366F4940
79585	61702	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45565	55508	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Братья Габышевых	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79689	61795	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79578	61699	124.531184	124.537616	56.257872999999996	56.224077000000001	Павлова	0103000020E61000000100000005000000240A2DEBFE215F4095641D8EAE1C4C40240A2DEBFE215F40BDC282FB01214C409B73F04C68225F40BDC282FB01214C409B73F04C68225F4095641D8EAE1C4C40240A2DEBFE215F4095641D8EAE1C4C40
79599	61719	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная улица	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79646	61763	126.330878	126.332369	58.666330000000002	58.665553000000003	Лесная	0103000020E61000000100000005000000D13DEB1A2D955F409A6038D730554D40D13DEB1A2D955F40FE2B2B4D4A554D40124DA08845955F40FE2B2B4D4A554D40124DA08845955F409A6038D730554D40D13DEB1A2D955F409A6038D730554D40
79586	61706	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Новая улица	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79518	61643	125.210086	125.219509	62.626300000000001	62.624070000000003	Героя Кондакова	0103000020E610000001000000050000003DD68C0C724D5F4016359886E14F4F403DD68C0C724D5F400EBE30992A504F405F0B7A6F0C4E5F400EBE30992A504F405F0B7A6F0C4E5F4016359886E14F4F403DD68C0C724D5F4016359886E14F4F40
79473	61605	130.816283	130.933019	61.481555999999998	61.453932000000002	Терешкина Н.Д	0103000020E61000000100000005000000FCA886FD1E5A6040CF4D9B711ABA4E40FCA886FD1E5A6040A69883A0A3BD4E407E71A94ADB5D6040A69883A0A3BD4E407E71A94ADB5D6040CF4D9B711ABA4E40FCA886FD1E5A6040CF4D9B711ABA4E40
79531	61655	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Окоемова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
78673	61348	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Петрова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79575	61693	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Петра Алексеева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79583	61704	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Егорова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79620	61739	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Рыбацкая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79622	61742	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Чапаева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45465	55443	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленинская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45165	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Ярославского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45291	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Я.Потапова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45244	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Я. Потапова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45293	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Энергетиков переулок	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45245	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Шавкунова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45217	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Чайковского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45288	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Халтурина	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45296	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Ф. Попова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45407	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Тургенева	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45243	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Стадухина	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45253	639	34.889361999999998	34.910778000000001	56.339218000000002	56.331372999999999	С. Данилова	0103000020E610000001000000050000000F27309DD671414082E3326E6A2A4C400F27309DD6714140761BD47E6B2B4C4049F59D5F94744140761BD47E6B2B4C4049F59D5F9474414082E3326E6A2A4C400F27309DD671414082E3326E6A2A4C40
45436	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Рыдзинского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45289	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Птицефабрика	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45231	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Пояркова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45171	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Пионерская	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45246	639	39.920413000000003	39.923313999999998	57.553266999999998	57.552267000000001	П. Алексеева	0103000020E6100000010000000500000019E8DA17D0F543407CD45FAFB0C64C4019E8DA17D0F543405F7AFB73D1C64C402FF834272FF643405F7AFB73D1C64C402FF834272FF643407CD45FAFB0C64C4019E8DA17D0F543407CD45FAFB0C64C40
45240	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Очиченко	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45313	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Островского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45334	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Ойунского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45222	639	129.593334	129.81023300000001	62.10642	61.949759999999998	О. Кошевого	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
79428	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Молодежная	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45249	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Можайского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45237	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Маяковского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45221	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Маганский тракт	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45247	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Лизы Чайкиной	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45310	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Лермонтова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45180	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Ленина	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45250	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Кулаковского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45218	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Кузьмина	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45290	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Красильникова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45164	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Кирова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45241	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Кальвица	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45224	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Каландаришвили	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45198	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Кааландаришвили	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45307	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Заводская	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45270	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Жуковского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45316	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Жорницкого	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45174	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Дзержинского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45213	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Газовиков	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45269	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Богатырева	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45215	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Билибина	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
9945	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Бестужева-Марлинского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45337	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Белинского	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45252	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Бекетова	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45214	639	129.593334	129.81023300000001	62.10642	61.949759999999998	Автодорожная	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45242	639	129.593334	129.81023300000001	62.10642	61.949759999999998	50 лет Советской Армии	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45338	639	129.593334	129.81023300000001	62.10642	61.949759999999998	202 микрорайон	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
45705	55602	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Юрях-Кюеринская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45549	55496	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Алроса	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
35830	54265	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	К. Урастырова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79798	61866	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45219	55346	129.97073499999999	130.025756	61.681325999999999	61.672682000000002	Пекарского	0103000020E61000000100000005000000A4C2D842103F6040CF4D9B711AD64E40A4C2D842103F60400EF5BBB035D74E40A0353FFED24060400EF5BBB035D74E40A0353FFED2406040CF4D9B711AD64E40A4C2D842103F6040CF4D9B711AD64E40
45207	55346	129.97073499999999	130.025756	61.681325999999999	61.672682000000002	Ойунского	0103000020E61000000100000005000000A4C2D842103F6040CF4D9B711AD64E40A4C2D842103F60400EF5BBB035D74E40A0353FFED24060400EF5BBB035D74E40A0353FFED2406040CF4D9B711AD64E40A4C2D842103F6040CF4D9B711AD64E40
45561	55503	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
79618	61737	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45697	55597	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Самырова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45523	55476	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45722	55560	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Сатыс	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45635	55560	128.62236300000001	128.70619400000001	61.308162000000003	61.292637999999997	Булгунняхтах	0103000020E61000000100000005000000B267CF65EA1360408EC8772975A54E40B267CF65EA1360405BEF37DA71A74E4035D42824991660405BEF37DA71A74E4035D42824991660408EC8772975A54E40B267CF65EA1360408EC8772975A54E40
45386	55403	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Спортивная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45659	55573	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ларионова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79559	61682	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Колёсова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45220	55351	130.91417200000001	130.985499	61.608524000000003	61.602384999999998	Охлопкова	0103000020E61000000100000005000000685DA3E5405D6040EC4CA1F31ACD4E40685DA3E5405D6040626A4B1DE4CD4E40B4E73235895F6040626A4B1DE4CD4E40B4E73235895F6040EC4CA1F31ACD4E40685DA3E5405D6040EC4CA1F31ACD4E40
45346	55351	130.91417200000001	130.985499	61.608524000000003	61.602384999999998	Магаданская	0103000020E61000000100000005000000685DA3E5405D6040EC4CA1F31ACD4E40685DA3E5405D6040626A4B1DE4CD4E40B4E73235895F6040626A4B1DE4CD4E40B4E73235895F6040EC4CA1F31ACD4E40685DA3E5405D6040EC4CA1F31ACD4E40
45677	55582	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Черского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45365	55376	37.842888000000002	37.906523999999997	50.795580999999999	50.729849000000002	Новый Город	0103000020E610000001000000050000006E1805C1E3EB4240580229B16B5D49406E1805C1E3EB4240D4282499D565494001857AFA08F44240D4282499D565494001857AFA08F44240580229B16B5D49406E1805C1E3EB4240580229B16B5D4940
45699	55598	128.473647	128.48162400000001	62.429627000000004	62.424838000000001	Коммунаров	0103000020E6100000010000000500000027DBC01D280F60408D0C721761364F4027DBC01D280F6040433D7D04FE364F40001FBC76690F6040433D7D04FE364F40001FBC76690F60408D0C721761364F4027DBC01D280F60408D0C721761364F40
79645	61762	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45663	55574	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	С.Платонова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45553	55497	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
45479	55448	126.201494	126.301108	58.990118000000002	58.908116	Зеленая	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
45500	55458	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45582	55523	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45478	55444	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Академика Федорова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45467	55444	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	50 лет СевМорПути	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79696	61800	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45301	55357	130.50110900000001	130.524259	58.687725	58.656739999999999	Папанина	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
45396	55357	130.50110900000001	130.524259	58.687725	58.656739999999999	Вилюйская	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
45235	55357	130.50110900000001	130.524259	58.687725	58.656739999999999	В.Павлова	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
45631	55557	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	М. Харачаса	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45595	55531	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Набережная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45432	55428	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Аммосова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45199	55085	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ярославского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
42093	55085	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Навроцкого	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45383	55401	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45503	55401	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	К. Маркса	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45394	55409	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ойунского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79621	61741	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	улица Школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45304	39557	124.28842299999999	124.30423399999999	56.525270999999996	56.460903999999999	Советская	0103000020E61000000100000005000000821ABE8575125F403C4CFBE6FE3A4C40821ABE8575125F40C34483143C434C403315E29178135F40C34483143C434C403315E29178135F403C4CFBE6FE3A4C40821ABE8575125F403C4CFBE6FE3A4C40
79643	61760	128.64537799999999	128.66276999999999	62.178863	62.171241999999999	Центральная	0103000020E61000000100000005000000DA71C3EFA6146040CFD90242EB154F40DA71C3EFA614604073BB97FBE4164F40A3586E693515604073BB97FBE4164F40A3586E6935156040CFD90242EB154F40DA71C3EFA6146040CFD90242EB154F40
45526	55477	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45524	55477	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45638	55561	128.667216	128.676074	61.821333000000003	61.818987999999997	Октябрьская	0103000020E61000000100000005000000C66B5ED55915604081E84999D4E84E40C66B5ED5591560401310937021E94E40A1F5F065A21560401310937021E94E40A1F5F065A215604081E84999D4E84E40C66B5ED55915604081E84999D4E84E40
45366	55391	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Алданская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45347	55381	124.275595	124.371814	61.296478999999998	61.198366	Ленина	0103000020E610000001000000050000003BFC3559A3115F40B5519D0E64994E403BFC3559A3115F40B3791C06F3A54E407A8CF2CCCB175F40B3791C06F3A54E407A8CF2CCCB175F40B5519D0E64994E403BFC3559A3115F40B5519D0E64994E40
45329	55378	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Космонавтов	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45348	55378	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Гидростроителей	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45315	55377	130.91417200000001	130.985499	61.608524000000003	61.602384999999998	Кудрявого	0103000020E61000000100000005000000685DA3E5405D6040EC4CA1F31ACD4E40685DA3E5405D6040626A4B1DE4CD4E40B4E73235895F6040626A4B1DE4CD4E40B4E73235895F6040EC4CA1F31ACD4E40685DA3E5405D6040EC4CA1F31ACD4E40
45433	55377	130.91417200000001	130.985499	61.608524000000003	61.602384999999998	Алданская	0103000020E61000000100000005000000685DA3E5405D6040EC4CA1F31ACD4E40685DA3E5405D6040626A4B1DE4CD4E40B4E73235895F6040626A4B1DE4CD4E40B4E73235895F6040EC4CA1F31ACD4E40685DA3E5405D6040EC4CA1F31ACD4E40
45476	55369	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Трудовая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45280	55369	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45547	55474	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Первомайская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45519	55474	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Горького	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45520	55474	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Алданский переулок	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45609	55534	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Горбунова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45178	55335	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45392	55408	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Пристанская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45422	55408	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45357	55386	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
45450	55420	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45399	55412	128.070088	128.09794500000001	61.591523000000002	61.562134	Трохачева	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
45482	55412	128.070088	128.09794500000001	61.591523000000002	61.562134	Аммосова	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
45360	55389	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Речная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45238	55359	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Энтузиастов	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45279	55359	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
45331	55359	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Бойко	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45443	55432	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Набережная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79684	55342	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кузьмина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45345	55342	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Гагарина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45201	55342	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	50 лет Победы	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45551	55338	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Спасская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45434	55338	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Первомайская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45186	55338	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45558	55338	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мелиораторов	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79650	61767	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мира	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79634	61752	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	П. Николаева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45397	55411	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Энергетик	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45501	55411	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Убоян	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45424	55411	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Степана Васильева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45427	55411	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Переулок Чусовского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45425	55411	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45499	55411	130.40742399999999	130.57229100000001	61.081111999999997	61.045479999999998	Манчары	0103000020E6100000010000000500000060730E9E094D6040A04FE449D2854E4060730E9E094D604015A8C5E0618A4E40721937355052604015A8C5E0618A4E407219373550526040A04FE449D2854E4060730E9E094D6040A04FE449D2854E40
45428	55411	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45449	55411	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Комсомольская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45716	55609	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Набережная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45274	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Южно-Якутская	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45177	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Чурапчинская	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45189	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Ленина	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45183	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Кравченко	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45185	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Карла Маркса	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45228	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Железнодорожная	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45192	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Дружбы Народов	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
79384	26979	125.358901	125.364569	56.059348	56.055441999999999	Геологическая	0103000020E610000001000000050000001C60E63BF8565F40946934B918074C401C60E63BF8565F40A08A1BB798074C40AB08371955575F40A08A1BB798074C40AB08371955575F40946934B918074C401C60E63BF8565F40946934B918074C40
45232	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	Аммосова	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45401	26979	124.687545	124.746914	56.673901999999998	56.648072999999997	70 лет Отктября	0103000020E61000000100000005000000D061BEBC002C5F40D6355A0EF4524C40D061BEBC002C5F40C05AB56B42564C402CBB6070CD2F5F40C05AB56B42564C402CBB6070CD2F5F40D6355A0EF4524C40D061BEBC002C5F40D6355A0EF4524C40
45531	55482	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45176	55334	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Платонова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45205	55345	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Студенческая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45193	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Тихонова	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45325	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Советская	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45314	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Ленинградский проспект	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45184	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Ленина	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45344	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Куницына	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45239	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Комсомольская	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45441	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Звездная	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45473	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Вилюйская	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45194	33793	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	40 Лет Октября	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
45541	55491	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45678	55583	34.107118	34.117277999999999	56.792428999999998	56.786684999999999	Строда	0103000020E610000001000000050000000E68E90AB60D41407BA01518B2644C400E68E90AB60D414074B33F506E654C4028452BF7020F414074B33F506E654C4028452BF7020F41407BA01518B2644C400E68E90AB60D41407BA01518B2644C40
79659	61776	129.769386	129.77163200000001	61.890825999999997	61.888834000000003	Советская	0103000020E61000000100000005000000028063CF9E38604054C90050C5F14E40028063CF9E38604097361C9606F24E4082919735B138604097361C9606F24E4082919735B138604054C90050C5F14E40028063CF9E38604054C90050C5F14E40
79656	61773	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45507	55463	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45390	55406	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мегежекского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79726	61818	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Линдинская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45410	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Якутская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45322	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Проспект Дружбы	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45262	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Пролетарская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45271	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Победы	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45398	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Первомайская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45356	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ойунского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45636	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Нюйская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45639	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мелиораторов	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45173	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45261	55333	129.50936899999999	129.590846	61.756875999999998	61.708815000000001	Каландарашвили	0103000020E61000000100000005000000149337C04C30604006F52D73BADA4E40149337C04C3060404B901150E1E04E401EDFDE35E83260404B901150E1E04E401EDFDE35E832604006F52D73BADA4E40149337C04C30604006F52D73BADA4E40
45409	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Бамовский проезд	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45320	55333	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Айхальская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79723	61811	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45518	55473	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45508	55464	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	В.Крыжановского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45668	55579	124.19354300000001	124.232557	57.267248000000002	57.219926000000001	Куду	0103000020E61000000100000005000000AAD72D02630C5F4022C50089269C4C40AAD72D02630C5F40F1F5B52E35A24C402D5DC136E20E5F40F1F5B52E35A24C402D5DC136E20E5F4022C50089269C4C40AAD72D02630C5F4022C50089269C4C40
45642	55563	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Братьев Семеновых	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
78682	61352	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Г.Миронова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45370	55394	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кычкина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45717	55581	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Тихоновой	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45674	55581	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Доры Жирковой	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45515	55470	126.362669	126.383914	61.107719000000003	61.102449999999997	Зеленая	0103000020E61000000100000005000000799109F835975F40D3BCE3141D8D4E40799109F835975F40341477BCC98D4E40809E060C92985F40341477BCC98D4E40809E060C92985F40D3BCE3141D8D4E40799109F835975F40D3BCE3141D8D4E40
45517	55472	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Марыкчанская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45455	55436	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Боярова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79499	61624	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Декабристов	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45521	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ярославского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
35831	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Чиряева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45488	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Чапаева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45489	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Партизана Семенова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45544	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мира	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45363	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Марка Жиркова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45406	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45387	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Иона Попова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79482	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Б.Н.Степанова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45509	54266	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Аммосова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45419	55421	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Новгородова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79846	61879	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ветеринаров	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45282	54711	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38893	54711	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Героя Васильева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79687	61793	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79449	61588	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кириллина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45504	55460	128.92620099999999	128.962322	56.443404000000001	56.344092000000003	Анисимова	0103000020E61000000100000005000000B8904770A31D60405A68E7340B2C4C40B8904770A31D604032755776C1384C4015C78157CB1E604032755776C1384C4015C78157CB1E60405A68E7340B2C4C40B8904770A31D60405A68E7340B2C4C40
45634	55559	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
79611	61731	130.088899	130.13783000000001	62.385922000000001	62.335152000000001	Жиркова	0103000020E61000000100000005000000B534B742D84260403198BF42E62A4F40B534B742D8426040496760E465314F400CCD751A69446040496760E465314F400CCD751A694460403198BF42E62A4F40B534B742D84260403198BF42E62A4F40
79517	55440	129.541708	129.71032199999999	60.015269000000004	59.792558	Колхозная	0103000020E6100000010000000500000069FF03AC553160407217618A72E54D4069FF03AC5531604042D2A755F4014E4023F433F5BA36604042D2A755F4014E4023F433F5BA3660407217618A72E54D4069FF03AC553160407217618A72E54D40
79435	61582	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ягловского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45358	55388	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Щадрина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45606	55540	129.06565499999999	129.07191599999999	61.288846999999997	61.285822000000003	Егорова	0103000020E6100000010000000500000034BA83D819226040193DB7D095A44E4034BA83D8192260401B4641F0F8A44E40E481C8224D2260401B4641F0F8A44E40E481C8224D226040193DB7D095A44E4034BA83D819226040193DB7D095A44E40
79653	61770	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьный переулок	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45326	55366	127.111891	127.11817000000001	59.653989000000003	59.644809000000002	Партизанская	0103000020E61000000100000005000000DF6DDE3829C75F404F95EF1989D24D40DF6DDE3829C75F40CD785BE9B5D34D409357E71890C75F40CD785BE9B5D34D409357E71890C75F404F95EF1989D24D40DF6DDE3829C75F404F95EF1989D24D40
45273	55366	127.111891	127.11817000000001	59.653989000000003	59.644809000000002	Ленина	0103000020E61000000100000005000000DF6DDE3829C75F404F95EF1989D24D40DF6DDE3829C75F40CD785BE9B5D34D409357E71890C75F40CD785BE9B5D34D409357E71890C75F404F95EF1989D24D40DF6DDE3829C75F404F95EF1989D24D40
45381	55366	127.111891	127.11817000000001	59.653989000000003	59.644809000000002	 Короленко	0103000020E61000000100000005000000DF6DDE3829C75F404F95EF1989D24D40DF6DDE3829C75F40CD785BE9B5D34D409357E71890C75F40CD785BE9B5D34D409357E71890C75F404F95EF1989D24D40DF6DDE3829C75F404F95EF1989D24D40
81072	62066	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Баронова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45420	55422	130.12072599999999	130.129099	62.235957999999997	62.233258999999997	Партизанская	0103000020E61000000100000005000000DCB8C5FCDC436040B33F506EDB1D4F40DCB8C5FCDC436040629D2ADF331E4F4048DE399421446040629D2ADF331E4F4048DE399421446040B33F506EDB1D4F40DCB8C5FCDC436040B33F506EDB1D4F40
45657	55422	130.12072599999999	130.129099	62.235957999999997	62.233258999999997	Кудрина-Абагинского	0103000020E61000000100000005000000DCB8C5FCDC436040B33F506EDB1D4F40DCB8C5FCDC436040629D2ADF331E4F4048DE399421446040629D2ADF331E4F4048DE399421446040B33F506EDB1D4F40DCB8C5FCDC436040B33F506EDB1D4F40
45226	55354	129.607348	129.653719	61.915723	61.894140999999998	Совхозная	0103000020E6100000010000000500000050A912656F336040A181583673F24E4050A912656F336040F698486936F54E40C3B81B44EB346040F698486936F54E40C3B81B44EB346040A181583673F24E4050A912656F336040A181583673F24E40
45308	55374	129.86085299999999	129.89397399999999	62.264173	62.240282000000001	Первомайская	0103000020E610000001000000050000003B35971B8C3B6040A3E8818FC11E4F403B35971B8C3B60403CBEBD6BD0214F402DAF5C6F9B3C60403CBEBD6BD0214F402DAF5C6F9B3C6040A3E8818FC11E4F403B35971B8C3B6040A3E8818FC11E4F40
45430	55426	129.65176099999999	129.71181300000001	61.994204000000003	61.957112000000002	Совхозная	0103000020E61000000100000005000000DD79E239DB346040F94D61A582FA4E40DD79E239DB346040B5C6A01342FF4E40C47B0E2CC7366040B5C6A01342FF4E40C47B0E2CC7366040F94D61A582FA4E40DD79E239DB346040F94D61A582FA4E40
45415	29293	129.687622	129.79934499999999	62.141185999999998	62.070025999999999	Советская	0103000020E610000001000000050000005340DAFF0036604052EFA99CF6084F405340DAFF003660409753026212124F401327F73B943960409753026212124F401327F73B9439604052EFA99CF6084F405340DAFF0036604052EFA99CF6084F40
45272	29293	129.687622	129.79934499999999	62.141185999999998	62.070025999999999	Кошевого	0103000020E610000001000000050000005340DAFF0036604052EFA99CF6084F405340DAFF003660409753026212124F401327F73B943960409753026212124F401327F73B9439604052EFA99CF6084F405340DAFF0036604052EFA99CF6084F40
45264	55363	129.50870399999999	129.54111499999999	62.115442000000002	62.096764	Алымова	0103000020E61000000100000005000000056B9C4D473060400FB743C3620C4F40056B9C4D47306040DC4AAFCDC60E4F40008C67D050316040DC4AAFCDC60E4F40008C67D0503160400FB743C3620C4F40056B9C4D473060400FB743C3620C4F40
45385	55402	129.911688	129.94914800000001	62.331133999999999	62.320934999999999	Семенова	0103000020E61000000100000005000000FB04508C2C3D60402592E86514294F40FB04508C2C3D6040FD4B5299622A4F400B62A06B5F3E6040FD4B5299622A4F400B62A06B5F3E60402592E86514294F40FB04508C2C3D60402592E86514294F40
45251	55337	129.79662300000001	129.850585	62.176431999999998	62.135316000000003	Строда	0103000020E61000000100000005000000BA8784EF7D3960401250E10852114F40BA8784EF7D396040E3FBE25295164F40FBAE08FE373B6040E3FBE25295164F40FBAE08FE373B60401250E10852114F40BA8784EF7D3960401250E10852114F40
45181	55337	129.79662300000001	129.850585	62.176431999999998	62.135316000000003	Северная	0103000020E61000000100000005000000BA8784EF7D3960401250E10852114F40BA8784EF7D396040E3FBE25295164F40FBAE08FE373B6040E3FBE25295164F40FBAE08FE373B60401250E10852114F40BA8784EF7D3960401250E10852114F40
45333	27669	124.871646	124.929722	56.897934999999997	56.823878000000001	Циолковского	0103000020E610000001000000050000001CEC4D0CC9375F406BF294D574694C401CEC4D0CC9375F408577B988EF724C40CA17B490803B5F408577B988EF724C40CA17B490803B5F406BF294D574694C401CEC4D0CC9375F406BF294D574694C40
45276	27669	124.871646	124.929722	56.897934999999997	56.823878000000001	Геологическая	0103000020E610000001000000050000001CEC4D0CC9375F406BF294D574694C401CEC4D0CC9375F408577B988EF724C40CA17B490803B5F408577B988EF724C40CA17B490803B5F406BF294D574694C401CEC4D0CC9375F406BF294D574694C40
45330	27669	124.871646	124.929722	56.897934999999997	56.823878000000001	Гаражная	0103000020E610000001000000050000001CEC4D0CC9375F406BF294D574694C401CEC4D0CC9375F408577B988EF724C40CA17B490803B5F408577B988EF724C40CA17B490803B5F406BF294D574694C401CEC4D0CC9375F406BF294D574694C40
45236	55358	124.871646	124.929722	56.897934999999997	56.823878000000001	Островского	0103000020E610000001000000050000001CEC4D0CC9375F406BF294D574694C401CEC4D0CC9375F408577B988EF724C40CA17B490803B5F408577B988EF724C40CA17B490803B5F406BF294D574694C401CEC4D0CC9375F406BF294D574694C40
45445	28028	124.82907400000001	124.863884	56.226703999999998	56.220047999999998	40 лет Победы	0103000020E61000000100000005000000B1FD648C0F355F406DC669882A1C4C40B1FD648C0F355F40AAEFFCA2041D4C4069E21DE049375F40AAEFFCA2041D4C4069E21DE049375F406DC669882A1C4C40B1FD648C0F355F406DC669882A1C4C40
45190	27941	124.762518	124.79236	56.588535999999998	56.564230999999999	Школьная	0103000020E6100000010000000500000020274C18CD305F40D731AEB838484C4020274C18CD305F406342CC25554B4C4026AAB706B6325F406342CC25554B4C4026AAB706B6325F40D731AEB838484C4020274C18CD305F40D731AEB838484C40
9761	27941	124.762518	124.79236	56.588535999999998	56.564230999999999	Муссы Джалиля	0103000020E6100000010000000500000020274C18CD305F40D731AEB838484C4020274C18CD305F406342CC25554B4C4026AAB706B6325F406342CC25554B4C4026AAB706B6325F40D731AEB838484C4020274C18CD305F40D731AEB838484C40
45709	55604	129.57959	129.65125800000001	61.865523000000003	61.810952	Лесная	0103000020E61000000100000005000000D6E253008C3260401A506F46CDE74E40D6E253008C326040C9772975C9EE4E404568041BD7346040C9772975C9EE4E404568041BD73460401A506F46CDE74E40D6E253008C3260401A506F46CDE74E40
45711	55605	129.80495999999999	129.84421599999999	62.285254999999999	62.271144	Труда	0103000020E61000000100000005000000D252793BC2396040D940BAD8B4224F40D252793BC23960409F02603C83244F4051D845D1033B60409F02603C83244F4051D845D1033B6040D940BAD8B4224F40D252793BC2396040D940BAD8B4224F40
79631	61749	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Национальный переулок	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79597	61717	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79857	61886	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79476	61608	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Монастырева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79745	61827	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Партизанская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79747	61829	130.27191300000001	130.30632700000001	62.649144	62.633139999999997	Комсомольская	0103000020E610000001000000050000006F4BE482B34860400CE544BB0A514F406F4BE482B348604083328D2617534F4038DC476ECD49604083328D2617534F4038DC476ECD4960400CE544BB0A514F406F4BE482B34860400CE544BB0A514F40
79688	61794	130.816283	130.933019	61.481555999999998	61.453932000000002	Новая	0103000020E61000000100000005000000FCA886FD1E5A6040CF4D9B711ABA4E40FCA886FD1E5A6040A69883A0A3BD4E407E71A94ADB5D6040A69883A0A3BD4E407E71A94ADB5D6040CF4D9B711ABA4E40FCA886FD1E5A6040CF4D9B711ABA4E40
79761	61841	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38912	54732	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Сергеева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45679	55584	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Протодьяконова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45378	55398	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Спортивная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45384	55398	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45654	55569	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Эрилик-Эристина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38902	54722	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Хомподоева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79500	61626	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Новгородова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45536	55486	130.11952299999999	130.14219600000001	58.63223	58.628857000000004	Макарова	0103000020E61000000100000005000000D503E621D34360402B6EDC627E504D40D503E621D343604069C6A2E9EC504D40E833A0DE8C44604069C6A2E9EC504D40E833A0DE8C4460402B6EDC627E504D40D503E621D34360402B6EDC627E504D40
79582	61703	130.78766300000001	130.80640099999999	61.908704	61.905116	Мельницкая	0103000020E610000001000000050000009E280989345960400D8B51D7DAF34E409E2809893459604048DFA46950F44E40C64E7809CE59604048DFA46950F44E40C64E7809CE5960400D8B51D7DAF34E409E280989345960400D8B51D7DAF34E40
45620	55547	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Телейская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45389	55405	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Петровского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
35828	54261	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Амгинская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45514	55469	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октярьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45516	55471	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Карла-Маркса	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45573	55511	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Сивцева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45632	8207	127.730013	127.759073	61.200130000000001	61.189796000000001	Центральная	0103000020E61000000100000005000000E9297288B8EE5F40B0743E3C4B984E40E9297288B8EE5F4068791EDC9D994E40B491EBA694F05F4068791EDC9D994E40B491EBA694F05F40B0743E3C4B984E40E9297288B8EE5F40B0743E3C4B984E40
45592	8207	127.730013	127.759073	61.200130000000001	61.189796000000001	Мира	0103000020E61000000100000005000000E9297288B8EE5F40B0743E3C4B984E40E9297288B8EE5F4068791EDC9D994E40B491EBA694F05F4068791EDC9D994E40B491EBA694F05F40B0743E3C4B984E40E9297288B8EE5F40B0743E3C4B984E40
45591	32622	128.77081899999999	128.78727599999999	61.427832000000002	61.420921	Михайлова	0103000020E6100000010000000500000055849B8CAA1860408D9944BDE0B54E4055849B8CAA1860405517F032C3B64E409F1D705D311960405517F032C3B64E409F1D705D311960408D9944BDE0B54E4055849B8CAA1860408D9944BDE0B54E40
45361	8957	129.37662499999999	129.42210700000001	61.666846	61.650632999999999	Сосновая	0103000020E61000000100000005000000643BDF4F0D2C6040645930F147D34E40643BDF4F0D2C6040F5BBB0355BD54E40350D8AE6812D6040F5BBB0355BD54E40350D8AE6812D6040645930F147D34E40643BDF4F0D2C6040645930F147D34E40
45612	8957	129.37662499999999	129.42210700000001	61.666846	61.650632999999999	Саввина	0103000020E61000000100000005000000643BDF4F0D2C6040645930F147D34E40643BDF4F0D2C6040F5BBB0355BD54E40350D8AE6812D6040F5BBB0355BD54E40350D8AE6812D6040645930F147D34E40643BDF4F0D2C6040645930F147D34E40
79464	33145	129.39662100000001	129.42567299999999	61.540992000000003	61.530593000000003	Варламовых	0103000020E6100000010000000500000005FD851EB12C6040473EAF78EAC34E4005FD851EB12C6040E6B2D1393FC54E4049B9FB1C9F2D6040E6B2D1393FC54E4049B9FB1C9F2D6040473EAF78EAC34E4005FD851EB12C6040473EAF78EAC34E40
45676	32628	127.90673	127.920096	61.219620999999997	61.215423000000001	Октябрьская	0103000020E61000000100000005000000551344DD07FA5F4032E719FB929B4E40551344DD07FA5F40E5417A8A1C9C4E408C4B55DAE2FA5F40E5417A8A1C9C4E408C4B55DAE2FA5F4032E719FB929B4E40551344DD07FA5F4032E719FB929B4E40
45645	32628	127.90673	127.920096	61.219620999999997	61.215423000000001	Набережная	0103000020E61000000100000005000000551344DD07FA5F4032E719FB929B4E40551344DD07FA5F40E5417A8A1C9C4E408C4B55DAE2FA5F40E5417A8A1C9C4E408C4B55DAE2FA5F4032E719FB929B4E40551344DD07FA5F4032E719FB929B4E40
79519	20054	128.667216	128.676074	61.821333000000003	61.818987999999997	Саввинова	0103000020E61000000100000005000000C66B5ED55915604081E84999D4E84E40C66B5ED5591560401310937021E94E40A1F5F065A21560401310937021E94E40A1F5F065A215604081E84999D4E84E40C66B5ED55915604081E84999D4E84E40
78681	20054	128.667216	128.676074	61.821333000000003	61.818987999999997	С. Буучугураса	0103000020E61000000100000005000000C66B5ED55915604081E84999D4E84E40C66B5ED5591560401310937021E94E40A1F5F065A21560401310937021E94E40A1F5F065A215604081E84999D4E84E40C66B5ED55915604081E84999D4E84E40
45429	8871	128.24842200000001	128.2775	61.304909000000002	61.294244999999997	Трофимова	0103000020E610000001000000050000006CB3B112F30760407901F6D1A9A54E406CB3B112F3076040C7A0134207A74E407B14AE47E1086040C7A0134207A74E407B14AE47E10860407901F6D1A9A54E406CB3B112F30760407901F6D1A9A54E40
45529	8871	128.24842200000001	128.2775	61.304909000000002	61.294244999999997	Ленская	0103000020E610000001000000050000006CB3B112F30760407901F6D1A9A54E406CB3B112F3076040C7A0134207A74E407B14AE47E1086040C7A0134207A74E407B14AE47E10860407901F6D1A9A54E406CB3B112F30760407901F6D1A9A54E40
45469	9020	129.44345100000001	129.48191600000001	61.719793000000003	61.705446999999999	Октябрьская	0103000020E610000001000000050000001DCC26C0302E6040D90759164CDA4E401DCC26C0302E6040E371512D22DC4E406A6D1ADB6B2F6040E371512D22DC4E406A6D1ADB6B2F6040D90759164CDA4E401DCC26C0302E6040D90759164CDA4E40
45650	8059	127.50830000000001	127.54468199999999	61.182237000000001	61.173948000000003	Школьная	0103000020E61000000100000005000000A323B9FC87E05F40319A95ED43964E40A323B9FC87E05F40828FC18A53974E40122EE411DCE25F40828FC18A53974E40122EE411DCE25F40319A95ED43964E40A323B9FC87E05F40319A95ED43964E40
79465	8059	127.50830000000001	127.54468199999999	61.182237000000001	61.173948000000003	Семилетка	0103000020E61000000100000005000000A323B9FC87E05F40319A95ED43964E40A323B9FC87E05F40828FC18A53974E40122EE411DCE25F40828FC18A53974E40122EE411DCE25F40319A95ED43964E40A323B9FC87E05F40319A95ED43964E40
45393	32527	129.29582099999999	129.33371199999999	61.494118	61.471915000000003	Жданова	0103000020E610000001000000050000000A0F9A5D77296040F5BEF1B567BC4E400A0F9A5D77296040B62E35423FBF4E400CC9C9C4AD2A6040B62E35423FBF4E400CC9C9C4AD2A6040F5BEF1B567BC4E400A0F9A5D77296040F5BEF1B567BC4E40
45589	32663	127.70256000000001	127.74992899999999	61.228253000000002	61.218564000000001	Центральная	0103000020E6100000010000000500000094DE37BEF6EC5F409E0AB8E7F99B4E4094DE37BEF6EC5F40611BF164379D4E409B5434D6FEEF5F40611BF164379D4E409B5434D6FEEF5F409E0AB8E7F99B4E4094DE37BEF6EC5F409E0AB8E7F99B4E40
45613	55543	129.44345100000001	129.48191600000001	61.719793000000003	61.705446999999999	Каландрашвили	0103000020E610000001000000050000001DCC26C0302E6040D90759164CDA4E401DCC26C0302E6040E371512D22DC4E406A6D1ADB6B2F6040E371512D22DC4E406A6D1ADB6B2F6040D90759164CDA4E401DCC26C0302E6040D90759164CDA4E40
45403	8043	126.812186	126.85305099999999	61.137900000000002	61.127752999999998	Орджоникидзе	0103000020E610000001000000050000003811FDDAFAB35F40A27BD6355A904E403811FDDAFAB35F40280F0BB5A6914E407CB4386398B65F40280F0BB5A6914E407CB4386398B65F40A27BD6355A904E403811FDDAFAB35F40A27BD6355A904E40
45462	8642	129.11896999999999	129.18293	61.503086000000003	61.470089000000002	Южная	0103000020E6100000010000000500000090662C9ACE236040CC9A58E02BBC4E4090662C9ACE236040A9893E1F65C04E40A2EE0390DA256040A9893E1F65C04E40A2EE0390DA256040CC9A58E02BBC4E4090662C9ACE236040CC9A58E02BBC4E40
45283	8642	129.11896999999999	129.18293	61.503086000000003	61.470089000000002	Орджоникидзе	0103000020E6100000010000000500000090662C9ACE236040CC9A58E02BBC4E4090662C9ACE236040A9893E1F65C04E40A2EE0390DA256040A9893E1F65C04E40A2EE0390DA256040CC9A58E02BBC4E4090662C9ACE236040CC9A58E02BBC4E40
45610	55350	129.11896999999999	129.18293	61.503086000000003	61.470089000000002	Центральная	0103000020E6100000010000000500000090662C9ACE236040CC9A58E02BBC4E4090662C9ACE236040A9893E1F65C04E40A2EE0390DA256040A9893E1F65C04E40A2EE0390DA256040CC9A58E02BBC4E4090662C9ACE236040CC9A58E02BBC4E40
45216	55350	129.11896999999999	129.18293	61.503086000000003	61.470089000000002	Б.Ксенофонтова	0103000020E6100000010000000500000090662C9ACE236040CC9A58E02BBC4E4090662C9ACE236040A9893E1F65C04E40A2EE0390DA256040A9893E1F65C04E40A2EE0390DA256040CC9A58E02BBC4E4090662C9ACE236040CC9A58E02BBC4E40
45286	9009	129.405676	129.44616300000001	61.683152	61.667276999999999	Е.Андреева	0103000020E61000000100000005000000B5183C4CFB2C6040BE2F2E5569D54E40B5183C4CFB2C60403719558671D74E40EEB5A0F7462E60403719558671D74E40EEB5A0F7462E6040BE2F2E5569D54E40B5183C4CFB2C6040BE2F2E5569D54E40
45258	55361	124.434498	130.3169	62.006096999999997	60.552097000000003	Ленина	0103000020E610000001000000050000005B0BB3D0CE1B5F40209C4F1DAB464E405B0BB3D0CE1B5F4046CD57C9C7004F404703780B244A604046CD57C9C7004F404703780B244A6040209C4F1DAB464E405B0BB3D0CE1B5F40209C4F1DAB464E40
45336	8545	128.911486	128.97080199999999	61.405099999999997	61.389145999999997	Комсомольская	0103000020E610000001000000050000006118B0E42A1D604042AF3F89CFB14E406118B0E42A1D604007CE1951DAB34E40861C5BCF101F604007CE1951DAB34E40861C5BCF101F604042AF3F89CFB14E406118B0E42A1D604042AF3F89CFB14E40
45212	8545	128.911486	128.97080199999999	61.405099999999997	61.389145999999997	Заводская	0103000020E610000001000000050000006118B0E42A1D604042AF3F89CFB14E406118B0E42A1D604007CE1951DAB34E40861C5BCF101F604007CE1951DAB34E40861C5BCF101F604042AF3F89CFB14E406118B0E42A1D604042AF3F89CFB14E40
45382	32537	129.17983100000001	129.20927800000001	61.435757000000002	61.425460999999999	Школьная	0103000020E61000000100000005000000D3F9F02CC12560409A5C8C8175B64E40D3F9F02CC12560406500A8E2C6B74E40B7B8C667B22660406500A8E2C6B74E40B7B8C667B22660409A5C8C8175B64E40D3F9F02CC12560409A5C8C8175B64E40
45708	33037	125.889302	125.93849400000001	60.975031000000001	60.954234999999997	И.Никифорова	0103000020E610000001000000050000001D91EF52EA785F406AD95A5F247A4E401D91EF52EA785F4008CBD8D0CD7C4E40815F2349107C5F4008CBD8D0CD7C4E40815F2349107C5F406AD95A5F247A4E401D91EF52EA785F406AD95A5F247A4E40
79560	61683	124.434498	130.3169	62.006096999999997	60.552097000000003	Центральная	0103000020E610000001000000050000005B0BB3D0CE1B5F40209C4F1DAB464E405B0BB3D0CE1B5F4046CD57C9C7004F404703780B244A604046CD57C9C7004F404703780B244A6040209C4F1DAB464E405B0BB3D0CE1B5F40209C4F1DAB464E40
45611	9223	129.01370499999999	129.035112	61.363066000000003	61.356019000000003	Ларионова	0103000020E6100000010000000500000055D977457020604098E0D40792AD4E4055D977457020604010255AF278AE4E404F7633A31F21604010255AF278AE4E404F7633A31F21604098E0D40792AD4E4055D977457020604098E0D40792AD4E40
45490	9227	128.918421	128.964361	61.328330999999999	61.310304000000002	Ленина	0103000020E61000000100000005000000B5DE6FB4631D6040B4E89D0AB8A74E40B5DE6FB4631D6040A9A10DC006AA4E403691990BDC1E6040A9A10DC006AA4E403691990BDC1E6040B4E89D0AB8A74E40B5DE6FB4631D6040B4E89D0AB8A74E40
45585	7895	125.299244	125.34963	60.815188999999997	60.807971000000002	Юбилейная	0103000020E610000001000000050000008D614ED026535F40E78EFE976B674E408D614ED026535F408B87F71C58684E40D5EC815660565F408B87F71C58684E40D5EC815660565F40E78EFE976B674E408D614ED026535F40E78EFE976B674E40
45680	29555	126.362669	126.383914	61.107719000000003	61.102449999999997	Октябрьская	0103000020E61000000100000005000000799109F835975F40D3BCE3141D8D4E40799109F835975F40341477BCC98D4E40809E060C92985F40341477BCC98D4E40809E060C92985F40D3BCE3141D8D4E40799109F835975F40D3BCE3141D8D4E40
45335	14110	128.62236300000001	128.70619400000001	61.308162000000003	61.292637999999997	Советская	0103000020E61000000100000005000000B267CF65EA1360408EC8772975A54E40B267CF65EA1360405BEF37DA71A74E4035D42824991660405BEF37DA71A74E4035D42824991660408EC8772975A54E40B267CF65EA1360408EC8772975A54E40
45211	55349	128.83053000000001	128.90285299999999	61.37771	61.348604999999999	Новая	0103000020E610000001000000050000001A8BA6B3931A60406D1CB1169FAC4E401A8BA6B3931A6040A3AF20CD58B04E400E83F92BE41C6040A3AF20CD58B04E400E83F92BE41C60406D1CB1169FAC4E401A8BA6B3931A60406D1CB1169FAC4E40
79490	55349	128.83053000000001	128.90285299999999	61.37771	61.348604999999999	Нагорная	0103000020E610000001000000050000001A8BA6B3931A60406D1CB1169FAC4E401A8BA6B3931A6040A3AF20CD58B04E400E83F92BE41C6040A3AF20CD58B04E400E83F92BE41C60406D1CB1169FAC4E401A8BA6B3931A60406D1CB1169FAC4E40
79380	20228	127.33996399999999	127.35001699999999	61.136141000000002	61.132745	Семенова	0103000020E610000001000000050000004F745DF8C1D55F4090DAC4C9FD904E404F745DF8C1D55F4087527B116D914E40D102B4AD66D65F4087527B116D914E40D102B4AD66D65F4090DAC4C9FD904E404F745DF8C1D55F4090DAC4C9FD904E40
79773	61853	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Иннокентия Барабанского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79774	61854	128.667216	128.676074	61.821333000000003	61.818987999999997	Набережная	0103000020E61000000100000005000000C66B5ED55915604081E84999D4E84E40C66B5ED5591560401310937021E94E40A1F5F065A21560401310937021E94E40A1F5F065A215604081E84999D4E84E40C66B5ED55915604081E84999D4E84E40
79772	61852	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Барона Толля	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79776	61858	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мира	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79777	61859	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	50 лет Октября	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79778	61860	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79775	61855	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	м-н Арктика	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38904	54723	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	А.Иванова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45686	55588	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мирушниченко	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79635	61753	126.330878	126.332369	58.666330000000002	58.665553000000003	Лесная	0103000020E61000000100000005000000D13DEB1A2D955F409A6038D730554D40D13DEB1A2D955F40FE2B2B4D4A554D40124DA08845955F40FE2B2B4D4A554D40124DA08845955F409A6038D730554D40D13DEB1A2D955F409A6038D730554D40
79570	61692	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79769	61849	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Промплощадка	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45562	55504	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79481	61613	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Дражников	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
43251	55135	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	Айхал	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
45643	32751	130.52319	130.53984399999999	62.623643999999999	62.620471000000002	Сынахская	0103000020E610000001000000050000000473F4F8BD506040E78EFE976B4F4F400473F4F8BD5060405E2C0C91D34F4F40239EEC66465160405E2C0C91D34F4F40239EEC6646516040E78EFE976B4F4F400473F4F8BD506040E78EFE976B4F4F40
79502	61628	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	Героя Бурцева	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
45617	5597	130.10444899999999	130.13588999999999	62.482996	62.458393000000001	Тимофея Татаринова	0103000020E6100000010000000500000032E36DA55743604090DB2F9FAC3A4F4032E36DA557436040A60C1CD0D23D4F404F3BFC3559446040A60C1CD0D23D4F404F3BFC355944604090DB2F9FAC3A4F4032E36DA55743604090DB2F9FAC3A4F40
45683	55586	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	Ивана Бурнашева	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
45437	55429	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	Героя Егорова	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
45586	5721	130.26932600000001	130.29499999999999	62.561981000000003	62.549666999999999	Ноторская	0103000020E61000000100000005000000CD3E8F519E4860406058FE7C5B464F40CD3E8F519E48604098FC4FFEEE474F403D0AD7A37049604098FC4FFEEE474F403D0AD7A3704960406058FE7C5B464F40CD3E8F519E4860406058FE7C5B464F40
45372	5721	130.26932600000001	130.29499999999999	62.561981000000003	62.549666999999999	Аммосова	0103000020E61000000100000005000000CD3E8F519E4860406058FE7C5B464F40CD3E8F519E48604098FC4FFEEE474F403D0AD7A37049604098FC4FFEEE474F403D0AD7A3704960406058FE7C5B464F40CD3E8F519E4860406058FE7C5B464F40
79506	61632	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	Андросова	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
45495	5119	130.862672	130.90413799999999	62.567042000000001	62.556480000000001	Елизаветы Бурцевой	0103000020E6100000010000000500000099654F029B5B6040657094BC3A474F4099654F029B5B6040AEBA0ED594484F4044A2D0B2EE5C6040AEBA0ED594484F4044A2D0B2EE5C6040657094BC3A474F4099654F029B5B6040657094BC3A474F40
45614	5668	130.64024900000001	130.665582	62.478926999999999	62.473506	Остойкинская	0103000020E610000001000000050000007F8978EB7C546040DA3A38D89B3C4F407F8978EB7C546040F015DD7A4D3D4F40CD599F724C556040F015DD7A4D3D4F40CD599F724C556040DA3A38D89B3C4F407F8978EB7C546040DA3A38D89B3C4F40
45405	5589	130.124841	130.157656	62.462027999999997	62.435318000000002	Анатолия Константинова	0103000020E6100000010000000500000066868DB2FE43604019AE0E80B8374F4066868DB2FE4360400BEBC6BB233B4F40958098840B4560400BEBC6BB233B4F40958098840B45604019AE0E80B8374F4066868DB2FE43604019AE0E80B8374F40
45583	55524	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	Центральная	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
45627	55553	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	Михаила Николаева	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
45311	5493	130.91839400000001	130.97061299999999	62.454013000000003	62.448616000000001	Центральная	0103000020E61000000100000005000000F75AD07B635D60402E3BC43F6C394F40F75AD07B635D6040BC7A15191D3A4F405182FE420F5F6040BC7A15191D3A4F405182FE420F5F60402E3BC43F6C394F40F75AD07B635D60402E3BC43F6C394F40
79470	5493	130.91839400000001	130.97061299999999	62.454013000000003	62.448616000000001	Комсомольская	0103000020E61000000100000005000000F75AD07B635D60402E3BC43F6C394F40F75AD07B635D6040BC7A15191D3A4F405182FE420F5F6040BC7A15191D3A4F405182FE420F5F60402E3BC43F6C394F40F75AD07B635D60402E3BC43F6C394F40
78667	5493	130.91839400000001	130.97061299999999	62.454013000000003	62.448616000000001	Зверева	0103000020E61000000100000005000000F75AD07B635D60402E3BC43F6C394F40F75AD07B635D6040BC7A15191D3A4F405182FE420F5F6040BC7A15191D3A4F405182FE420F5F60402E3BC43F6C394F40F75AD07B635D60402E3BC43F6C394F40
45706	5493	130.91839400000001	130.97061299999999	62.454013000000003	62.448616000000001	Данилова	0103000020E61000000100000005000000F75AD07B635D60402E3BC43F6C394F40F75AD07B635D6040BC7A15191D3A4F405182FE420F5F6040BC7A15191D3A4F405182FE420F5F60402E3BC43F6C394F40F75AD07B635D60402E3BC43F6C394F40
45718	5230	130.038872	130.059991	62.513807	62.505173999999997	Аржакова	0103000020E610000001000000050000005D177E703E4160400E65A88AA9404F405D177E703E4160405ABA826DC4414F40BDE13E72EB4160405ABA826DC4414F40BDE13E72EB4160400E65A88AA9404F405D177E703E4160400E65A88AA9404F40
79548	61671	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
79760	61840	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
79751	61833	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Петра Алексеева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79562	61685	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Авиационная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45696	55596	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Феклы Павловой	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79544	61667	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Амгинская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79630	61748	37.517698000000003	38.180959999999999	56.742446999999999	55.649484000000001	Центральная	0103000020E61000000100000005000000319A95ED43C242403CA3AD4A22D34B40319A95ED43C24240B401D880085F4C402CF180B229174340B401D880085F4C402CF180B2291743403CA3AD4A22D34B40319A95ED43C242403CA3AD4A22D34B40
45533	55483	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79542	61665	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	И.Слепцова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45688	55590	130.27191300000001	130.30632700000001	62.649144	62.633139999999997	Табахырова	0103000020E610000001000000050000006F4BE482B34860400CE544BB0A514F406F4BE482B348604083328D2617534F4038DC476ECD49604083328D2617534F4038DC476ECD4960400CE544BB0A514F406F4BE482B34860400CE544BB0A514F40
45480	55449	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	А.Данилова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45494	55456	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Сабарайкина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79427	61577	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кашкина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45400	55413	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кулаковского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79576	61697	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45402	55414	130.50110900000001	130.524259	58.687725	58.656739999999999	Октябрьская	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
45431	55427	130.50110900000001	130.524259	58.687725	58.656739999999999	Ленина	0103000020E6100000010000000500000067D7BD1509506040CEFC6A0E10544D4067D7BD150950604020D26F5F07584D404774CFBAC650604020D26F5F07584D404774CFBAC6506040CEFC6A0E10544D4067D7BD1509506040CEFC6A0E10544D40
79758	61839	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Юбилейная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79563	61686	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская улица	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79766	61846	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кузнецкая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45411	55417	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Сивцева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79535	61659	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45619	55546	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	 Кэскил	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79668	61781	130.78766300000001	130.80640099999999	61.908704	61.905116	Кокорина	0103000020E610000001000000050000009E280989345960400D8B51D7DAF34E409E2809893459604048DFA46950F44E40C64E7809CE59604048DFA46950F44E40C64E7809CE5960400D8B51D7DAF34E409E280989345960400D8B51D7DAF34E40
79485	61616	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Геодезическая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45629	55555	128.56082000000001	128.61522199999999	61.847062999999999	61.798488999999996	Хаппар	0103000020E610000001000000050000002BDEC83CF21160409D9B36E334E64E402BDEC83CF21160406953758F6CEC4E40F3380CE6AF1360406953758F6CEC4E40F3380CE6AF1360409D9B36E334E64E402BDEC83CF21160409D9B36E334E64E40
79607	61727	128.70544000000001	128.711872	62.352764999999998	62.350923999999999	Ананьева	0103000020E610000001000000050000004A29E8F692166040D5B0DF13EB2C4F404A29E8F69216604033164D67272D4F4005DEC9A7C716604033164D67272D4F4005DEC9A7C7166040D5B0DF13EB2C4F404A29E8F692166040D5B0DF13EB2C4F40
79543	61666	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
35832	54267	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Федорова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45689	55591	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Самсонова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79633	61751	129.52371500000001	129.52887999999999	60.701197999999998	60.697957000000002	Советская	0103000020E6100000010000000500000097ADF545C2306040D481ACA756594E4097ADF545C2306040A30227DBC0594E4045F0BF95EC306040A30227DBC0594E4045F0BF95EC306040D481ACA756594E4097ADF545C2306040D481ACA756594E40
38889	54707	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Сунтарская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45391	55407	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Мира	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79598	61718	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79626	61745	126.33634000000001	126.39474800000001	59.553789999999999	59.531913000000003	40 Лет Победы	0103000020E610000001000000050000008C15359886955F409CA8A5B915C44D408C15359886955F40096D3997E2C64D40558A1D8D43995F40096D3997E2C64D40558A1D8D43995F409CA8A5B915C44D408C15359886955F409CA8A5B915C44D40
79569	61691	127.848016	127.90814899999999	61.011884000000002	60.971848000000001	Чукрова	0103000020E61000000100000005000000069FE6E445F65F406D57E883657C4E40069FE6E445F65F403FAC376A85814E4049B9FB1C1FFA5F403FAC376A85814E4049B9FB1C1FFA5F406D57E883657C4E40069FE6E445F65F406D57E883657C4E40
79594	61714	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45354	55385	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская улица	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45559	55501	36.052697999999999	36.078102999999999	52.992897999999997	52.967827	Октябрьская	0103000020E610000001000000050000004548DDCEBE064240C89750C1E17B4A404548DDCEBE064240C4211B48177F4A40185C7347FF094240C4211B48177F4A40185C7347FF094240C89750C1E17B4A404548DDCEBE064240C89750C1E17B4A40
45556	55499	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	60 Лет Октября	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
35829	54262	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Карла Миллера	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79681	61789	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Центральная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
45587	55526	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Центральная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79495	61622	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	пер.Школьный	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79672	61784	\N	\N	\N	\N	Верхняя	\N
79754	61836	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Алеши Алексеева	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79558	61681	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Центральная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
38905	54724	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Ойунского	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79555	61678	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Советская	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
45675	31751	124.04082099999999	124.08444299999999	60.590223000000002	60.580964999999999	Гагарина	0103000020E610000001000000050000005CFFAECF9C025F40718FA50F5D4A4E405CFFAECF9C025F406B2C616D8C4B4E4012D89C8367055F406B2C616D8C4B4E4012D89C8367055F40718FA50F5D4A4E405CFFAECF9C025F40718FA50F5D4A4E40
45197	54730	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Урицкого	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
38910	54730	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Тахватулина	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79640	61757	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Центральная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
45647	55565	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Лесная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
45673	31756	124.723226	124.738479	60.685955	60.682563000000002	Лесная	0103000020E610000001000000050000007B67B455492E5F40D63A71395E574E407B67B455492E5F408BC3995FCD574E4019726C3D432F5F408BC3995FCD574E4019726C3D432F5F40D63A71395E574E407B67B455492E5F40D63A71395E574E40
79704	61801	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Центральная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
42073	55084	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Майская	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79701	61803	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Карташова	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
45597	55533	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	мкрн.Нижний	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79695	61798	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Центральная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79666	61779	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Партизанская улица	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
79477	61609	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	Центральная	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
45695	55433	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	м-н Нерский	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45656	55433	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	м-н Индигирский	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45444	55433	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45672	55433	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45463	55433	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Коммунистическая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45671	55580	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Автотранспортная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79523	61648	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79767	61847	\N	\N	\N	\N	П.С. Егорова	\N
45712	55606	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45505	55461	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Амосова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79768	61848	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Дмитрия Федорова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45426	55425	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79505	61631	130.55717300000001	130.560667	61.967955000000003	61.966597	Ленина	0103000020E61000000100000005000000DBA6785CD4516040B3B45373B9FB4E40DBA6785CD4516040F67F0EF3E5FB4E40499EEBFBF0516040F67F0EF3E5FB4E40499EEBFBF0516040B3B45373B9FB4E40DBA6785CD4516040B3B45373B9FB4E40
79540	61663	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Револия Иванова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45640	55558	127.494259	127.498769	61.731065999999998	61.729272000000002	Арангастахская	0103000020E610000001000000050000003C3080F0A1DF5F40BBF1EEC858DD4E403C3080F0A1DF5F40D89B189293DD4E408DD0CFD4EBDF5F40D89B189293DD4E408DD0CFD4EBDF5F40BBF1EEC858DD4E403C3080F0A1DF5F40BBF1EEC858DD4E40
81112	62081	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Набережная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45340	55380	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская 	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
9891	40346	124.000989	131.00103899999999	58.566597999999999	55.489896000000002	Карла Маркса	0103000020E61000000100000005000000F8A92A3410005F407A3881E9B4BE4B40F8A92A3410005F4050FD834886484D40A8E0F0820860604050FD834886484D40A8E0F082086060407A3881E9B4BE4B40F8A92A3410005F407A3881E9B4BE4B40
45630	55556	127.924498	130.263666	62.667146000000002	62.297699999999999	Д.Потапова	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
59514	57575	127.924498	130.263666	62.667146000000002	62.297699999999999	Решетникова	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45721	55612	127.924498	130.263666	62.667146000000002	62.297699999999999	Лена	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45510	55465	129.84232	129.90908300000001	62.466611999999998	62.450763000000002	Центральная	0103000020E6100000010000000500000089981249F43A6040999F1B9AB2394F4089981249F43A6040E8F527F1B93B4F40304B3B35173D6040E8F527F1B93B4F40304B3B35173D6040999F1B9AB2394F4089981249F43A6040999F1B9AB2394F40
79524	61649	127.924498	130.263666	62.667146000000002	62.297699999999999	Леонтьева	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
35827	54260	127.924498	130.263666	62.667146000000002	62.297699999999999	Слепцова	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
79469	61602	127.924498	130.263666	62.667146000000002	62.297699999999999	Н.Ф.Собакина	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45491	25839	129.76008899999999	129.77769599999999	62.592838999999998	62.577451000000003	Школьная	0103000020E6100000010000000500000094A12AA652386040710514EAE9494F4094A12AA6523860408C65FA25E24B4F405CC7B8E2E23860408C65FA25E24B4F405CC7B8E2E2386040710514EAE9494F4094A12AA652386040710514EAE9494F40
45652	55567	129.70910000000001	129.720698	62.632561000000003	62.618729000000002	Е.Протопопова	0103000020E61000000100000005000000FFB27BF2B03660401C0B0A83324F4F40FFB27BF2B0366040CFDC43C2F7504F405D8940F50F376040CFDC43C2F7504F405D8940F50F3760401C0B0A83324F4F40FFB27BF2B03660401C0B0A83324F4F40
45545	54203	127.924498	130.263666	62.667146000000002	62.297699999999999	Чернышевского	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
38903	54203	127.924498	130.263666	62.667146000000002	62.297699999999999	Ойунского	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45417	54203	127.924498	130.263666	62.667146000000002	62.297699999999999	Винокурова	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45537	55487	127.924498	130.263666	62.667146000000002	62.297699999999999	Ленина	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45581	55521	127.924498	130.263666	62.667146000000002	62.297699999999999	Захара Винокурова	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
79410	16869	129.74370300000001	129.781576	62.543301	62.521554000000002	Северная	0103000020E61000000100000005000000FDDD3B6ACC3760408B8C0E48C2424F40FDDD3B6ACC3760402A711DE38A454F40D5EAABAB023960402A711DE38A454F40D5EAABAB023960408B8C0E48C2424F40FDDD3B6ACC3760408B8C0E48C2424F40
45373	16869	129.74370300000001	129.781576	62.543301	62.521554000000002	Ленина	0103000020E61000000100000005000000FDDD3B6ACC3760408B8C0E48C2424F40FDDD3B6ACC3760402A711DE38A454F40D5EAABAB023960402A711DE38A454F40D5EAABAB023960408B8C0E48C2424F40FDDD3B6ACC3760408B8C0E48C2424F40
45364	16869	129.74370300000001	129.781576	62.543301	62.521554000000002	Интернациональная	0103000020E61000000100000005000000FDDD3B6ACC3760408B8C0E48C2424F40FDDD3B6ACC3760402A711DE38A454F40D5EAABAB023960402A711DE38A454F40D5EAABAB023960408B8C0E48C2424F40FDDD3B6ACC3760408B8C0E48C2424F40
45451	16869	129.74370300000001	129.781576	62.543301	62.521554000000002	Газовиков	0103000020E61000000100000005000000FDDD3B6ACC3760408B8C0E48C2424F40FDDD3B6ACC3760402A711DE38A454F40D5EAABAB023960402A711DE38A454F40D5EAABAB023960408B8C0E48C2424F40FDDD3B6ACC3760408B8C0E48C2424F40
45448	16869	129.74370300000001	129.781576	62.543301	62.521554000000002	Аммосова	0103000020E61000000100000005000000FDDD3B6ACC3760408B8C0E48C2424F40FDDD3B6ACC3760402A711DE38A454F40D5EAABAB023960402A711DE38A454F40D5EAABAB023960408B8C0E48C2424F40FDDD3B6ACC3760408B8C0E48C2424F40
45456	26078	129.69434999999999	129.713673	62.667352000000001	62.649754999999999	Охлопкова - Соттоя	0103000020E6100000010000000500000048BF7D1D38366040CCB4FD2B2B534F4048BF7D1D38366040C97553CA6B554F403961C268D6366040C97553CA6B554F403961C268D6366040CCB4FD2B2B534F4048BF7D1D38366040CCB4FD2B2B534F40
45703	25937	127.924498	130.263666	62.667146000000002	62.297699999999999	Аммосова	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45539	55489	127.924498	130.263666	62.667146000000002	62.297699999999999	Центральная	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
79651	61768	127.924498	130.263666	62.667146000000002	62.297699999999999	Центральная	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
45655	55570	127.924498	130.263666	62.667146000000002	62.297699999999999	Лена	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
79753	61835	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45580	55519	129.37947299999999	129.389884	62.335203	62.330699000000003	Тихона Толомона	0103000020E61000000100000005000000E1968FA4242C6040F3E84658542A4F40E1968FA4242C6040B34291EEE72A4F407AA702EE792C6040B34291EEE72A4F407AA702EE792C6040F3E84658542A4F40E1968FA4242C6040F3E84658542A4F40
45578	55516	126.555942	126.57952299999999	59.217692	59.187263000000002	Н.И.Слепцова	0103000020E61000000100000005000000431EC18D94A35F401C60E63BF8974D40431EC18D94A35F40E84CDA54DD9B4D40E811A3E716A55F40E84CDA54DD9B4D40E811A3E716A55F401C60E63BF8974D40431EC18D94A35F401C60E63BF8974D40
45579	55517	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	М.Черемкина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38911	54731	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кэскил	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79694	61799	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79538	61661	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Иванова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45457	55437	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Энтузиастов	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45540	55490	129.18697299999999	129.28692799999999	56.905033000000003	56.823050000000002	50 лет ЯАССР	0103000020E610000001000000050000008507CDAEFB256040857CD0B359694C408507CDAEFB2560408066101FD8734C40D009A1832E2960408066101FD8734C40D009A1832E296040857CD0B359694C408507CDAEFB256040857CD0B359694C40
45223	55352	126.00095399999999	126.04079400000001	57.71172	57.705046000000003	Тихонова	0103000020E6100000010000000500000039B35DA10F805F407B1684F23EDA4C4039B35DA10F805F405EF415A419DB4C40E0F76F5E9C825F405EF415A419DB4C40E0F76F5E9C825F407B1684F23EDA4C4039B35DA10F805F407B1684F23EDA4C40
43252	55136	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Иванова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79625	61744	129.57499999999999	130.999045	62.456595999999998	60.834598	Центральная	0103000020E6100000010000000500000066666666663260404CA7751BD46A4E40666666666632604001BEDBBC713A4F406F47382DF85F604001BEDBBC713A4F406F47382DF85F60404CA7751BD46A4E4066666666663260404CA7751BD46A4E40
45339	55379	129.97073499999999	130.025756	61.681325999999999	61.672682000000002	Ойунского	0103000020E61000000100000005000000A4C2D842103F6040CF4D9B711AD64E40A4C2D842103F60400EF5BBB035D74E40A0353FFED24060400EF5BBB035D74E40A0353FFED2406040CF4D9B711AD64E40A4C2D842103F6040CF4D9B711AD64E40
45574	55512	130.353453	130.381058	61.735267	61.724204999999998	Скрябина	0103000020E610000001000000050000008A75AA7C4F4B6040C24CDBBFB2DC4E408A75AA7C4F4B6040FD69A33A1DDE4E4022FC8BA0314C6040FD69A33A1DDE4E4022FC8BA0314C6040C24CDBBFB2DC4E408A75AA7C4F4B6040C24CDBBFB2DC4E40
45649	32761	130.72016300000001	130.75614999999999	61.576037999999997	61.559396	Советская	0103000020E61000000100000005000000429946930B576040B1C1C2499AC74E40429946930B5760406AA0F99CBBC94E40DA1B7C61325860406AA0F99CBBC94E40DA1B7C6132586040B1C1C2499AC74E40429946930B576040B1C1C2499AC74E40
45496	23557	130.73342199999999	130.769993	61.842368	61.824790999999998	Сергучева	0103000020E6100000010000000500000057056A31785760407F8461C092E94E4057056A31785760403599F1B6D2EB4E40C4245CC8A35860403599F1B6D2EB4E40C4245CC8A35860407F8461C092E94E4057056A31785760407F8461C092E94E40
78657	5873	129.851034	129.86443700000001	61.843328	61.837344999999999	Ленина	0103000020E6100000010000000500000017B9A7AB3B3B60400C3CF71E2EEB4E4017B9A7AB3B3B60408AE6012CF2EB4E407A8EC877A93B60408AE6012CF2EB4E407A8EC877A93B60400C3CF71E2EEB4E4017B9A7AB3B3B60400C3CF71E2EEB4E40
45692	32666	129.87848700000001	129.89446799999999	61.546140000000001	61.538834999999999	 Лукина	0103000020E61000000100000005000000C2DEC4901C3C60405778978BF8C44E40C2DEC4901C3C6040CB845FEAE7C54E4031EA5A7B9F3C6040CB845FEAE7C54E4031EA5A7B9F3C60405778978BF8C44E40C2DEC4901C3C60405778978BF8C44E40
45359	23463	129.760188	129.81833499999999	61.799194999999997	61.769666999999998	Советская	0103000020E61000000100000005000000F9D9C87553386040BCE7C07284E24E40F9D9C87553386040381092054CE64E4082C5E1CC2F3A6040381092054CE64E4082C5E1CC2F3A6040BCE7C07284E24E40F9D9C87553386040BCE7C07284E24E40
45470	55446	129.57499999999999	130.999045	62.456595999999998	60.834598	М. Потаповой	0103000020E6100000010000000500000066666666663260404CA7751BD46A4E40666666666632604001BEDBBC713A4F406F47382DF85F604001BEDBBC713A4F406F47382DF85F60404CA7751BD46A4E4066666666663260404CA7751BD46A4E40
45439	23662	130.693366	130.73576700000001	62.201749999999997	62.183926999999997	Партизанская	0103000020E6100000010000000500000011C5E40D30566040FAEC80EB8A174F4011C5E40D30566040E7FBA9F1D2194F403C4F3C678B576040E7FBA9F1D2194F403C4F3C678B576040FAEC80EB8A174F4011C5E40D30566040FAEC80EB8A174F40
45660	2972	130.01630599999999	130.06029699999999	62.159984000000001	62.145667000000003	Пономарева	0103000020E610000001000000050000005017299485406040A08D5C37A5124F4050172994854060400FF10F5B7A144F408061F9F3ED4160400FF10F5B7A144F408061F9F3ED416040A08D5C37A5124F405017299485406040A08D5C37A5124F40
45486	2972	130.01630599999999	130.06029699999999	62.159984000000001	62.145667000000003	Баягантайская	0103000020E610000001000000050000005017299485406040A08D5C37A5124F4050172994854060400FF10F5B7A144F408061F9F3ED4160400FF10F5B7A144F408061F9F3ED416040A08D5C37A5124F405017299485406040A08D5C37A5124F40
45648	32752	130.68195800000001	130.703113	61.387656	61.376640999999999	Саввина	0103000020E61000000100000005000000DC679599D255604097AAB4C535B04E40DC679599D2556040910C39B69EB14E408F8CD5E67F566040910C39B69EB14E408F8CD5E67F56604097AAB4C535B04E40DC679599D255604097AAB4C535B04E40
45438	23407	130.90844100000001	130.97844699999999	61.674292000000001	61.654246999999998	Совхозная	0103000020E610000001000000050000000F2BDCF2115D6040C8409E5DBED34E400F2BDCF2115D60402BFA43334FD64E40D13B15704F5F60402BFA43334FD64E40D13B15704F5F6040C8409E5DBED34E400F2BDCF2115D6040C8409E5DBED34E40
45570	22997	130.93938800000001	130.97850099999999	61.929544	61.916744000000001	Колесова	0103000020E6100000010000000500000028486C770F5E6040F1660DDE57F54E4028486C770F5E6040B5183C4CFBF64E404E4354E14F5F6040B5183C4CFBF64E404E4354E14F5F6040F1660DDE57F54E4028486C770F5E6040F1660DDE57F54E40
45566	22808	130.55766700000001	130.57662999999999	61.912796	61.899023	Птицына	0103000020E61000000100000005000000DFE17668D851604008AD872F13F34E40DFE17668D8516040B6F5D37FD6F44E408FFCC1C073526040B6F5D37FD6F44E408FFCC1C07352604008AD872F13F34E40DFE17668D851604008AD872F13F34E40
45567	22808	130.55766700000001	130.57662999999999	61.912796	61.899023	Калинина	0103000020E61000000100000005000000DFE17668D851604008AD872F13F34E40DFE17668D8516040B6F5D37FD6F44E408FFCC1C073526040B6F5D37FD6F44E408FFCC1C07352604008AD872F13F34E40DFE17668D851604008AD872F13F34E40
45637	32801	129.64036999999999	129.667427	61.684517999999997	61.667541999999997	Петрова-Халлааскы	0103000020E61000000100000005000000DDEA39E97D3460406C5A290472D54E40DDEA39E97D346040FCC22B499ED74E40F52EDE8F5B356040FCC22B499ED74E40F52EDE8F5B3560406C5A290472D54E40DDEA39E97D3460406C5A290472D54E40
45375	23563	130.24700300000001	130.26623499999999	61.730060000000002	61.722321000000001	Харанская	0103000020E6100000010000000500000072E0D572E7476040651BB80375DC4E4072E0D572E7476040130F289B72DD4E409E4143FF84486040130F289B72DD4E409E4143FF84486040651BB80375DC4E4072E0D572E7476040651BB80375DC4E40
45170	22306	129.81975499999999	129.87845100000001	61.893946	61.856884000000001	Молодежная	0103000020E610000001000000050000007077D66E3B3A60409B3BFA5FAEED4E407077D66E3B3A6040EC3191D26CF24E406F8445451C3C6040EC3191D26CF24E406F8445451C3C60409B3BFA5FAEED4E407077D66E3B3A60409B3BFA5FAEED4E40
45309	55375	129.88257400000001	129.94662400000001	61.986345	61.932842000000001	Ленина	0103000020E610000001000000050000009949D40B3E3C6040E92ADD5D67F74E409949D40B3E3C60405CC98E8D40FE4E407B336ABE4A3E60405CC98E8D40FE4E407B336ABE4A3E6040E92ADD5D67F74E409949D40B3E3C6040E92ADD5D67F74E40
45300	18838	129.88257400000001	129.94662400000001	61.986345	61.932842000000001	Ленина	0103000020E610000001000000050000009949D40B3E3C6040E92ADD5D67F74E409949D40B3E3C60405CC98E8D40FE4E407B336ABE4A3E60405CC98E8D40FE4E407B336ABE4A3E6040E92ADD5D67F74E409949D40B3E3C6040E92ADD5D67F74E40
45568	22998	130.61081999999999	130.672687	62.360912999999996	62.350206	Механизаторов	0103000020E61000000100000005000000C47762D68B536040766EDA8CD32C4F40C47762D68B536040C2D9AD65322E4F40382EE3A686556040C2D9AD65322E4F40382EE3A686556040766EDA8CD32C4F40C47762D68B536040766EDA8CD32C4F40
45306	22074	130.24759499999999	130.32193100000001	61.749476000000001	61.720446000000003	Манчаары	0103000020E61000000100000005000000E674594CEC4760405B44149337DC4E40E674594CEC47604086915ED4EEDF4E4032923D424D4A604086915ED4EEDF4E4032923D424D4A60405B44149337DC4E40E674594CEC4760405B44149337DC4E40
45175	22074	130.24759499999999	130.32193100000001	61.749476000000001	61.720446000000003	Майинская	0103000020E61000000100000005000000E674594CEC4760405B44149337DC4E40E674594CEC47604086915ED4EEDF4E4032923D424D4A604086915ED4EEDF4E4032923D424D4A60405B44149337DC4E40E674594CEC4760405B44149337DC4E40
45172	22074	130.24759499999999	130.32193100000001	61.749476000000001	61.720446000000003	 Героя Попова	0103000020E61000000100000005000000E674594CEC4760405B44149337DC4E40E674594CEC47604086915ED4EEDF4E4032923D424D4A604086915ED4EEDF4E4032923D424D4A60405B44149337DC4E40E674594CEC4760405B44149337DC4E40
79420	32831	130.07096899999999	130.10709900000001	61.641672999999997	61.632201999999999	Семена Назарова	0103000020E61000000100000005000000F4C0C760454260409F3BC1FEEBD04E40F4C0C76045426040F4DC425722D24E40E6CDE15A6D436040F4DC425722D24E40E6CDE15A6D4360409F3BC1FEEBD04E40F4C0C760454260409F3BC1FEEBD04E40
78872	22665	130.36280400000001	130.38419300000001	60.981678000000002	60.966036000000003	Советская	0103000020E61000000100000005000000755B22179C4B60401C615111A77B4E40755B22179C4B6040F299EC9FA77D4E40454B1E4F4B4C6040F299EC9FA77D4E40454B1E4F4B4C60401C615111A77B4E40755B22179C4B60401C615111A77B4E40
79385	22559	130.36749399999999	130.39058900000001	61.790273999999997	61.782817999999999	Октябрьская	0103000020E610000001000000050000003DEFC682C24B60402D5C566133E44E403DEFC682C24B60408670CCB227E54E40ADA580B47F4C60408670CCB227E54E40ADA580B47F4C60402D5C566133E44E403DEFC682C24B60402D5C566133E44E40
45646	22466	130.927638	130.959214	61.483983000000002	61.476039999999998	Матросова	0103000020E61000000100000005000000DC10E335AF5D60403ECBF3E0EEBC4E40DC10E335AF5D6040F568AA27F3BD4E40B1FB8EE1B15E6040F568AA27F3BD4E40B1FB8EE1B15E60403ECBF3E0EEBC4E40DC10E335AF5D60403ECBF3E0EEBC4E40
79509	5485	130.84695099999999	130.876497	62.402309000000002	62.387096999999997	Пестрякова	0103000020E6100000010000000500000010CAFB381A5B60409AB0FD648C314F4010CAFB381A5B604078F17EDC7E334F4059C16F430C5C604078F17EDC7E334F4059C16F430C5C60409AB0FD648C314F4010CAFB381A5B60409AB0FD648C314F40
45413	6203	130.68780599999999	130.74738199999999	62.260387999999999	62.247736000000003	Балыктахская	0103000020E61000000100000005000000C37FBA81025660405C0531D0B51F4F40C37FBA8102566040AB22DC6454214F40CFF3A78DEA576040AB22DC6454214F40CFF3A78DEA5760405C0531D0B51F4F40C37FBA81025660405C0531D0B51F4F40
79588	61708	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьный переулок	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45720	55611	127.33996399999999	127.35001699999999	61.136141000000002	61.132745	Центральная	0103000020E610000001000000050000004F745DF8C1D55F4090DAC4C9FD904E404F745DF8C1D55F4087527B116D914E40D102B4AD66D65F4087527B116D914E40D102B4AD66D65F4090DAC4C9FD904E404F745DF8C1D55F4090DAC4C9FD904E40
79533	61657	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Полярная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79728	61820	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	пер. Клубный	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45704	55601	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79685	61790	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Боровая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45362	55390	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45277	55368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45423	55368	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Аэропорт	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79587	61707	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79730	61821	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45459	55439	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38891	54709	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Углестроителей	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45621	55341	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Фурманова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45195	55341	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Победы	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45191	55341	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45576	55514	124.738686	124.837357	60.036707999999997	59.925313000000003	Лесная	0103000020E61000000100000005000000D600A5A1462F5F4026C808A870F64D40D600A5A1462F5F4033C005D9B2044E40E884D04197355F4033C005D9B2044E40E884D04197355F4026C808A870F64D40D600A5A1462F5F4026C808A870F64D40
79592	61712	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
45452	37846	43.581513999999999	43.651322999999998	54.078014000000003	54.054960000000001	Тимирязева	0103000020E610000001000000050000004415FE0C6FCA4540494BE5ED08074B404415FE0C6FCA4540A950DD5CFC094B40F910548D5ED34540A950DD5CFC094B40F910548D5ED34540494BE5ED08074B404415FE0C6FCA4540494BE5ED08074B40
79566	61689	127.50627	127.63908499999999	62.667233000000003	62.344907999999997	Кирова	0103000020E610000001000000050000008A3C49BA66E05F407B1002F2252C4F408A3C49BA66E05F40EFE714E467554F404E97C5C4E6E85F40EFE714E467554F404E97C5C4E6E85F407B1002F2252C4F408A3C49BA66E05F407B1002F2252C4F40
79654	61771	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38906	54726	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Алексеева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38886	54704	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ламутского	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45605	55441	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
45700	55441	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Нефтебаза	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45599	55441	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45461	55441	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кочнева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79443	55441	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Геолог	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79488	55441	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Алексеева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45607	55541	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Кралина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45563	55505	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Калинина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45421	55423	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Терехова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45601	55536	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Иванова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
35833	54268	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Шемякова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79665	61778	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Чкалова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79421	17311	126.647256	126.656724	61.86965	61.866100000000003	Гоголева	0103000020E61000000100000005000000F2086EA46CA95F406688635DDCEE4E40F2086EA46CA95F40B37BF2B050EF4E40E49F19C407AA5F40B37BF2B050EF4E40E49F19C407AA5F406688635DDCEE4E40F2086EA46CA95F406688635DDCEE4E40
79376	18486	125.107849	125.154822	62.573528000000003	62.560605000000002	Мира	0103000020E6100000010000000500000001FA7DFFE6465F40AF7C96E7C1474F4001FA7DFFE6465F408FAB915D69494F40E2AC889AE8495F408FAB915D69494F40E2AC889AE8495F40AF7C96E7C1474F4001FA7DFFE6465F40AF7C96E7C1474F40
45374	18163	128.04916600000001	128.07037600000001	62.153753000000002	62.143742000000003	Октябрьская	0103000020E61000000100000005000000684293C492016040E4874A2366124F40684293C492016040B954A52DAE134F408C4D2B8540026040B954A52DAE134F408C4D2B8540026040E4874A2366124F40684293C492016040E4874A2366124F40
45669	18526	126.82892200000001	126.85102000000001	62.577289999999998	62.566113999999999	Школьная	0103000020E61000000100000005000000D63BDC0E0DB55F4064E76D6C76484F40D63BDC0E0DB55F40672783A3E4494F407C0F971C77B65F40672783A3E4494F407C0F971C77B65F4064E76D6C76484F40D63BDC0E0DB55F4064E76D6C76484F40
79377	18479	124.42398799999999	124.46343299999999	62.346749000000003	62.335340000000002	Советская	0103000020E610000001000000050000005F79909E221B5F403485CE6BEC2A4F405F79909E221B5F40DA756F45622C4F40C7B8E2E2A81D5F40DA756F45622C4F40C7B8E2E2A81D5F403485CE6BEC2A4F405F79909E221B5F403485CE6BEC2A4F40
79375	18273	124.001034	128.640896	62.667183000000001	61.194400000000002	Строда	0103000020E61000000100000005000000C80BE9F010005F40D42B6519E2984E40C80BE9F010005F403DB9A64066554F4064045438821460403DB9A64066554F406404543882146040D42B6519E2984E40C80BE9F010005F40D42B6519E2984E40
79448	18273	124.001034	128.640896	62.667183000000001	61.194400000000002	Озерная	0103000020E61000000100000005000000C80BE9F010005F40D42B6519E2984E40C80BE9F010005F403DB9A64066554F4064045438821460403DB9A64066554F406404543882146040D42B6519E2984E40C80BE9F010005F40D42B6519E2984E40
79552	61675	124.001034	128.640896	62.667183000000001	61.194400000000002	Лонгинова	0103000020E61000000100000005000000C80BE9F010005F40D42B6519E2984E40C80BE9F010005F403DB9A64066554F4064045438821460403DB9A64066554F406404543882146040D42B6519E2984E40C80BE9F010005F40D42B6519E2984E40
45268	18066	126.67786099999999	126.72544499999999	62.115614999999998	62.079703000000002	С.П.Данилова	0103000020E61000000100000005000000F78E1A1362AB5F40513239B5330A4F40F78E1A1362AB5F40A9F6E978CC0E4F40FD82DDB06DAE5F40A9F6E978CC0E4F40FD82DDB06DAE5F40513239B5330A4F40F78E1A1362AB5F40513239B5330A4F40
45341	18066	126.67786099999999	126.72544499999999	62.115614999999998	62.079703000000002	Октябрьская	0103000020E61000000100000005000000F78E1A1362AB5F40513239B5330A4F40F78E1A1362AB5F40A9F6E978CC0E4F40FD82DDB06DAE5F40A9F6E978CC0E4F40FD82DDB06DAE5F40513239B5330A4F40F78E1A1362AB5F40513239B5330A4F40
45328	18066	126.67786099999999	126.72544499999999	62.115614999999998	62.079703000000002	Данилова	0103000020E61000000100000005000000F78E1A1362AB5F40513239B5330A4F40F78E1A1362AB5F40A9F6E978CC0E4F40FD82DDB06DAE5F40A9F6E978CC0E4F40FD82DDB06DAE5F40513239B5330A4F40F78E1A1362AB5F40513239B5330A4F40
45670	18357	126.625444	126.65511600000001	62.366667	62.357332	Чээмпи	0103000020E61000000100000005000000AF5E454607A85F403AE8120EBD2D4F40AF5E454607A85F40DFC2BAF1EE2E4F4087C5A86BEDA95F40DFC2BAF1EE2E4F4087C5A86BEDA95F403AE8120EBD2D4F40AF5E454607A85F403AE8120EBD2D4F40
79541	61664	125.210086	125.219509	62.626300000000001	62.624070000000003	Ст. Гоголева	0103000020E610000001000000050000003DD68C0C724D5F4016359886E14F4F403DD68C0C724D5F400EBE30992A504F405F0B7A6F0C4E5F400EBE30992A504F405F0B7A6F0C4E5F4016359886E14F4F403DD68C0C724D5F4016359886E14F4F40
79755	61837	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Победы	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45525	55478	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Комсомольская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79613	61733	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
45502	55459	130.54242300000001	130.70477500000001	56.628554999999999	56.624133	Ойунского	0103000020E6100000010000000500000025B37A875B5160405CAD1397E34F4C4025B37A875B5160405F5E807D74504C403B014D848D5660405F5E807D74504C403B014D848D5660405CAD1397E34F4C4025B37A875B5160405CAD1397E34F4C40
45543	55493	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79530	61654	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Тюнгская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45603	55538	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
81101	62076	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Юбилейная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38907	54727	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	М.А.Алексеева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79513	61638	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ф.Константинова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
41201	55009	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Миронова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79595	61715	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
79744	61826	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79859	61887	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45691	55593	130.01630599999999	130.06029699999999	62.159984000000001	62.145667000000003	Центральная	0103000020E610000001000000050000005017299485406040A08D5C37A5124F4050172994854060400FF10F5B7A144F408061F9F3ED4160400FF10F5B7A144F408061F9F3ED416040A08D5C37A5124F405017299485406040A08D5C37A5124F40
38887	54705	130.01630599999999	130.06029699999999	62.159984000000001	62.145667000000003	Эллэ	0103000020E610000001000000050000005017299485406040A08D5C37A5124F4050172994854060400FF10F5B7A144F408061F9F3ED4160400FF10F5B7A144F408061F9F3ED416040A08D5C37A5124F405017299485406040A08D5C37A5124F40
38900	54720	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Аргаа	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79638	61755	128.028074	128.10887700000001	60.585610000000003	60.577947000000002	Центральная	0103000020E61000000100000005000000C6FB71FBE500604021E9D32AFA494E40C6FB71FBE5006040F41ABB44F54A4E402C499EEB7B036040F41ABB44F54A4E402C499EEB7B03604021E9D32AFA494E40C6FB71FBE500604021E9D32AFA494E40
79628	61746	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Колхозная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45624	55550	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Шадрина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45698	55475	128.070088	128.09794500000001	61.591523000000002	61.562134	Центральная	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
45522	55475	128.070088	128.09794500000001	61.591523000000002	61.562134	Ленина	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
79608	61728	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79521	61645	128.070088	128.09794500000001	61.591523000000002	61.562134	Малоозерная	0103000020E61000000100000005000000F27A30293E0260401EFCC401F4C74E40F27A30293E02604079EA9106B7CB4E40D1798D5D2203604079EA9106B7CB4E40D1798D5D220360401EFCC401F4C74E40F27A30293E0260401EFCC401F4C74E40
79577	61698	125.269599	125.296791	57.101042	57.019354	Портовская	0103000020E6100000010000000500000032022A1C41515F40FD851E317A824C4032022A1C41515F40DFC2BAF1EE8C4C40D1AFAD9FFE525F40DFC2BAF1EE8C4C40D1AFAD9FFE525F40FD851E317A824C4032022A1C41515F40FD851E317A824C40
79520	61644	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Дорожная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79507	61633	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Спортивная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79434	55595	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Молодежная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45694	55595	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79442	55595	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Заводская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38890	54708	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Текки Одулока	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79749	61831	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79616	61735	129.851034	129.86443700000001	61.843328	61.837344999999999	Хомустах	0103000020E6100000010000000500000017B9A7AB3B3B60400C3CF71E2EEB4E4017B9A7AB3B3B60408AE6012CF2EB4E407A8EC877A93B60408AE6012CF2EB4E407A8EC877A93B60400C3CF71E2EEB4E4017B9A7AB3B3B60400C3CF71E2EEB4E40
79512	61637	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Передовиков	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
59516	57576	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	П. Васильева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79707	61807	124.82076499999999	124.879227	55.941454999999998	55.884827000000001	Советская	0103000020E61000000100000005000000E42CEC6987345F4014CFD90242F14B40E42CEC6987345F40EDD3F19881F84B40A7B0524145385F40EDD3F19881F84B40A7B0524145385F4014CFD90242F14B40E42CEC6987345F4014CFD90242F14B40
79567	61690	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Проезжая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
78683	61353	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Школьная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79770	61842	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Будургэй	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79579	61700	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Октябрьская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79557	61680	128.62236300000001	128.70619400000001	61.308162000000003	61.292637999999997	Булгунняхтах	0103000020E61000000100000005000000B267CF65EA1360408EC8772975A54E40B267CF65EA1360405BEF37DA71A74E4035D42824991660405BEF37DA71A74E4035D42824991660408EC8772975A54E40B267CF65EA1360408EC8772975A54E40
45713	55607	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Семена Руфова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79537	61660	129.52892499999999	129.571416	61.803918000000003	61.754356000000001	Набережная	0103000020E610000001000000050000002D211FF4EC3060404CC5C6BC8EE04E402D211FF4EC3060403755F7C8E6E64E40280D350A493260403755F7C8E6E64E40280D350A493260404CC5C6BC8EE04E402D211FF4EC3060404CC5C6BC8EE04E40
81094	62073	128.42406	128.43574699999999	62.470998999999999	62.466433000000002	Комсомольская	0103000020E6100000010000000500000056F146E6910D604039639813B43B4F4056F146E6910D60406FB9FAB1493C4F40904AB1A3F10D60406FB9FAB1493C4F40904AB1A3F10D604039639813B43B4F4056F146E6910D604039639813B43B4F40
79771	61851	126.698325	126.759743	59.975351000000003	59.907722	Центральная	0103000020E61000000100000005000000AB3E575BB1AC5F400BEE073C30F44D40AB3E575BB1AC5F407A8F334DD8FC4D405B971AA19FB05F407A8F334DD8FC4D405B971AA19FB05F400BEE073C30F44D40AB3E575BB1AC5F400BEE073C30F44D40
79471	61603	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45564	55506	130.77075600000001	130.78001800000001	61.969687999999998	61.965184999999998	Тамах	0103000020E6100000010000000500000044A67C08AA5860407DCB9C2E8BFB4E4044A67C08AA5860406DA983BC1EFC4E4053094FE8F55860406DA983BC1EFC4E4053094FE8F55860407DCB9C2E8BFB4E4044A67C08AA5860407DCB9C2E8BFB4E40
79669	61782	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79765	61845	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Чыыйык	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45506	55462	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Дмитрия Спиридонова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79461	61597	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	П.А.Васильева	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79589	61709	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79503	61629	129.89029099999999	129.92540600000001	56.665266000000003	56.529420999999999	Боороо	0103000020E610000001000000050000008A1D8D437D3C604066683C11C4434C408A1D8D437D3C60400492B06F27554C40B6300BED9C3D60400492B06F27554C40B6300BED9C3D604066683C11C4434C408A1D8D437D3C604066683C11C4434C40
81107	62077	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45667	55578	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	 Береговая	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45535	55485	127.50100500000001	127.508686	58.336838	58.302115999999998	Советская	0103000020E610000001000000050000007B88467710E05F4096CCB1BCAB264D407B88467710E05F406806F1811D2B4D40B77BB94F8EE05F406806F1811D2B4D40B77BB94F8EE05F4096CCB1BCAB264D407B88467710E05F4096CCB1BCAB264D40
79752	61834	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Авиаторов	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45416	55419	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	50 лет МТС	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
79750	61832	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	Ленина	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
45492	3441	130.024283	130.029188	60.501742999999998	60.498961000000001	Николаева	0103000020E61000000100000005000000295B24EDC64060405F7D3CF4DD3F4E40295B24EDC64060409BFF571D39404E40F12DAC1BEF4060409BFF571D39404E40F12DAC1BEF4060405F7D3CF4DD3F4E40295B24EDC64060405F7D3CF4DD3F4E40
79390	3441	130.024283	130.029188	60.501742999999998	60.498961000000001	Исидора Барахова	0103000020E61000000100000005000000295B24EDC64060405F7D3CF4DD3F4E40295B24EDC64060409BFF571D39404E40F12DAC1BEF4060409BFF571D39404E40F12DAC1BEF4060405F7D3CF4DD3F4E40295B24EDC64060405F7D3CF4DD3F4E40
79483	61614	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	Октябрьская	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
78752	32707	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	П. Яковлева	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
79596	61716	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	Мира	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
45546	55494	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	Ленина	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
45483	55451	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	М.Нестерева	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
45472	55447	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	Петрова	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
79493	61621	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Щерьачкова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79677	61786	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Центральная	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79692	61797	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	улица Победы	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
79691	61796	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	Центральная	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
78830	11395	125.70159	125.721542	58.535128999999998	58.525346999999996	Октябрьская	0103000020E61000000100000005000000D74CBED9E66C5F409E060C923E434D40D74CBED9E66C5F401212691B7F444D40302C7FBE2D6E5F401212691B7F444D40302C7FBE2D6E5F409E060C923E434D40D74CBED9E66C5F409E060C923E434D40
79619	61738	125.830157	125.84365	58.900131000000002	58.89273	Советская	0103000020E61000000100000005000000E962D34A21755F403C1405FA44724D40E962D34A21755F40D28E1B7E37734D404ED1915CFE755F40D28E1B7E37734D404ED1915CFE755F403C1405FA44724D40E962D34A21755F403C1405FA44724D40
45666	55577	126.677187	126.701415	58.584935000000002	58.574820000000003	Буровая	0103000020E61000000100000005000000B091240857AB5F401A8BA6B393494D40B091240857AB5F4094A46B26DF4A4D40207BBDFBE3AC5F4094A46B26DF4A4D40207BBDFBE3AC5F401A8BA6B393494D40B091240857AB5F401A8BA6B393494D40
79458	55576	130.59747999999999	130.61462900000001	58.765936000000004	58.735039	Северная	0103000020E610000001000000050000007380608E1E5360406C2409C2155E4D407380608E1E5360401F6ADB300A624D408BC56F0AAB5360401F6ADB300A624D408BC56F0AAB5360406C2409C2155E4D407380608E1E5360406C2409C2155E4D40
45665	55576	130.59747999999999	130.61462900000001	58.765936000000004	58.735039	Матросова	0103000020E610000001000000050000007380608E1E5360406C2409C2155E4D407380608E1E5360401F6ADB300A624D408BC56F0AAB5360401F6ADB300A624D408BC56F0AAB5360406C2409C2155E4D407380608E1E5360406C2409C2155E4D40
45471	11467	125.138257	125.169257	58.93141	58.910960000000003	50 лет Октября	0103000020E610000001000000050000005B5CE333D9485F406AFB57569A744D405B5CE333D9485F406C95607138774D409FE74F1BD54A5F406C95607138774D409FE74F1BD54A5F406AFB57569A744D405B5CE333D9485F406AFB57569A744D40
79446	32561	128.364295	128.36779899999999	60.662818999999999	60.660058999999997	Школьная	0103000020E6100000010000000500000015E3FC4DA80B6040193735D07C544E4015E3FC4DA80B60406E15C440D7544E400C906802C50B60406E15C440D7544E400C906802C50B6040193735D07C544E4015E3FC4DA80B6040193735D07C544E40
45702	55600	127.42307700000001	127.435914	60.318770000000001	60.310904999999998	Центральная	0103000020E6100000010000000500000026AC8DB113DB5F40D9942BBCCB274E4026AC8DB113DB5F4014799274CD284E409677D503E6DB5F4014799274CD284E409677D503E6DB5F40D9942BBCCB274E4026AC8DB113DB5F40D9942BBCCB274E40
78842	11481	125.288158	125.295677	59.258586999999999	59.249389999999998	Центральная	0103000020E610000001000000050000002B85402E71525F4087F9F202EC9F4D402B85402E71525F40DB15FA6019A14D407B4B395FEC525F40DB15FA6019A14D407B4B395FEC525F4087F9F202EC9F4D402B85402E71525F4087F9F202EC9F4D40
45302	10962	126.201494	126.301108	58.990118000000002	58.908116	Школьная	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
45685	10962	126.201494	126.301108	58.990118000000002	58.908116	Укуланская	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
79387	10962	126.201494	126.301108	58.990118000000002	58.908116	Совхозная	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
45263	10962	126.201494	126.301108	58.990118000000002	58.908116	Ленина	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
45169	10962	126.201494	126.301108	58.990118000000002	58.908116	Захарова	0103000020E61000000100000005000000C6151747E58C5F40B77C24253D744D40C6151747E58C5F402997C62FBC7E4D4018247D5A45935F402997C62FBC7E4D4018247D5A45935F40B77C24253D744D40C6151747E58C5F40B77C24253D744D40
45388	55404	128.45330000000001	128.491164	58.576917999999999	58.518965999999999	Степана Попова	0103000020E61000000100000005000000DC68006F810E604033DE567A6D424D40DC68006F810E6040A33CF372D8494D401F9F909DB70F6040A33CF372D8494D401F9F909DB70F604033DE567A6D424D40DC68006F810E604033DE567A6D424D40
78678	61350	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	Горбунова	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
45321	55364	125.501356	125.543379	58.842632999999999	58.799830999999998	Юбилейная	0103000020E61000000100000005000000D1E9793716605F40DAA9B9DC60664D40D1E9793716605F40E3C3EC65DB6B4D405395B6B8C6625F40E3C3EC65DB6B4D405395B6B8C6625F40DAA9B9DC60664D40D1E9793716605F40DAA9B9DC60664D40
45267	55364	125.501356	125.543379	58.842632999999999	58.799830999999998	Школьная	0103000020E61000000100000005000000D1E9793716605F40DAA9B9DC60664D40D1E9793716605F40E3C3EC65DB6B4D405395B6B8C6625F40E3C3EC65DB6B4D405395B6B8C6625F40DAA9B9DC60664D40D1E9793716605F40DAA9B9DC60664D40
79525	61650	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	Слепцова	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
45351	11327	125.42565500000001	125.45608900000001	58.581341999999999	58.560913999999997	Ленина	0103000020E61000000100000005000000401878EE3D5B5F402CEFAA07CC474D40401878EE3D5B5F4047E5266A694A4D402FC4EA8F305D5F4047E5266A694A4D402FC4EA8F305D5F402CEFAA07CC474D40401878EE3D5B5F402CEFAA07CC474D40
45474	11335	125.483847	125.518666	58.498953	58.485647	Октябрьская	0103000020E6100000010000000500000022516859F75E5F4044334FAE293E4D4022516859F75E5F40DC9E20B1DD3F4D4004E3E0D231615F40DC9E20B1DD3F4D4004E3E0D231615F4044334FAE293E4D4022516859F75E5F4044334FAE293E4D40
79641	61758	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	Школьная	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
45684	10605	125.475628	125.49019	58.762701999999997	58.747833999999997	Разрезная	0103000020E61000000100000005000000F6436CB0705E5F401E6B4606B95F4D40F6436CB0705E5F40014C1938A0614D40E1B4E0455F5F5F40014C1938A0614D40E1B4E0455F5F5F401E6B4606B95F4D40F6436CB0705E5F401E6B4606B95F4D40
79720	61815	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	Советская	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
45569	11281	125.476634	125.48713499999999	58.043295999999998	58.040671000000003	Школьная	0103000020E61000000100000005000000598AE42B815E5F40A47213B534054D40598AE42B815E5F4018062CB98A054D402A6F47382D5F5F4018062CB98A054D402A6F47382D5F5F40A47213B534054D40598AE42B815E5F40A47213B534054D40
45166	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	Строителей	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
45317	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	Пролетарская	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
45256	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	Октябрьская	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
45254	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	Ленина	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
45255	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	Калинина	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
45327	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	Гагарина 	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
45265	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	Билибина	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
45324	10186	125.313554	125.425798	58.636688999999997	58.578310999999999	50 лет ВЛКСМ	0103000020E61000000100000005000000EBE1CB4411545F4062F54718064A4D40EBE1CB4411545F40895C70067F514D40F12C4146405B5F40895C70067F514D40F12C4146405B5F4062F54718064A4D40EBE1CB4411545F4062F54718064A4D40
79573	61695	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Маркова С.П	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
38901	54721	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ефимова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45693	55594	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Оттох-Атахская	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45203	55343	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ефимова	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
45530	55481	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ленина	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
79606	61726	129.769386	129.77163200000001	61.890825999999997	61.888834000000003	Советская	0103000020E61000000100000005000000028063CF9E38604054C90050C5F14E40028063CF9E38604097361C9606F24E4082919735B138604097361C9606F24E4082919735B138604054C90050C5F14E40028063CF9E38604054C90050C5F14E40
45593	55529	129.41587200000001	129.51896300000001	60.701597999999997	60.696455	Лукина	0103000020E610000001000000050000004FEACBD24E2D60405E11FC6F25594E404FEACBD24E2D6040317898F6CD594E40B11A4B589B306040317898F6CD594E40B11A4B589B3060405E11FC6F25594E404FEACBD24E2D60405E11FC6F25594E40
38908	54728	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	Ильяховой	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
44392	55256	132.322326	132.46548200000001	43.008889000000003	42.884895	Центральная	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
44463	55256	132.322326	132.46548200000001	43.008889000000003	42.884895	Усатого	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
44461	55256	132.322326	132.46548200000001	43.008889000000003	42.884895	Постникова	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
44466	55256	132.322326	132.46548200000001	43.008889000000003	42.884895	Карла Маркса	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
44851	55256	132.322326	132.46548200000001	43.008889000000003	42.884895	Дальняя	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
44421	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Чичерина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44573	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Тургенева	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44591	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Топоркова	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44376	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Теодора Тихого	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44367	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Советская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44373	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Слободская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44893	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Сельскохозяйственная	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44590	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Садовая	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44370	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Русская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
43253	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Раздольная	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44366	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Пушкина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44519	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Проспект Блюхера	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44422	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Переулок Тихий	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44789	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Переулок Мурзинцева	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44417	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Октябрьская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44604	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Никитина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
43254	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Некрасова	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44374	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Ленинградская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44408	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Ленина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44517	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Крестьянская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44420	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Короленко	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44369	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Комсомольская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44522	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Комарова	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44416	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Карбышева	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44355	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Ильюшина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44419	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Горького	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
42825	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Владивостокское шоссе	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44518	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Амурская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44515	8394	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Агеева	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
59508	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	проспект Блюхера	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
59478	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Тимирязева	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
59477	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Пушкина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
59490	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Полушкина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
45161	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Пионерская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
59500	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Краснознаменная	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
59497	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Калинина	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
59480	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Дальневосточная	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44927	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Володарского	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44787	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Вокзальная площадь	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44576	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Артемовская	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44784	55268	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	Андрея Кушнира	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
44662	55285	131.93786499999999	131.944818	43.096882000000001	43.09498	Полины Осипенко	0103000020E6100000010000000500000004E275FD027E604015E3FC4D288C454004E275FD027E604019C91EA1668C45408255F5F23B7E604019C91EA1668C45408255F5F23B7E604015E3FC4D288C454004E275FD027E604015E3FC4D288C4540
44772	55288	132.189573	132.189888	43.360610999999999	43.358441999999997	Квартальная улица	0103000020E610000001000000050000008C6665FB10866040A4C16D6DE1AD45408C6665FB10866040F7C9518028AE4540E4BCFF8F13866040F7C9518028AE4540E4BCFF8F13866040A4C16D6DE1AD45408C6665FB10866040A4C16D6DE1AD4540
59505	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Цементная	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
59495	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Советская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
59507	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Складская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
59509	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Приморская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
59506	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Октябрьская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
59489	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Краснознаменная	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44783	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Красногвардейская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
59499	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Комсомольская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
59511	55290	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	9-го Октября	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44913	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	переулок Мухинский	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44365	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Цементная	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44371	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Советская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44824	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Мухинский переулок	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44415	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Ленинская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44364	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Краснознаменная	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
9716	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Красногвардейская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44949	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Заводская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44363	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Ершова	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44507	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Дербенева	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44509	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Герцена	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44860	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Вокзальная	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44840	4638	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	Ангарская	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44448	55259	132.759501	132.86632800000001	44.617342000000001	44.556027999999998	1-я Загородная	0103000020E61000000100000005000000F0880AD54D98604084D4EDEC2B474640F0880AD54D9860403F390A10054F46407E737FF5B89B60403F390A10054F46407E737FF5B89B604084D4EDEC2B474640F0880AD54D98604084D4EDEC2B474640
44671	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Центральная	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
59488	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Техникумовская	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
59502	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Тепличная	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
59504	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Советская	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
59498	55286	133.12568099999999	133.313366	43.279910999999998	43.000323999999999	Партизанская	0103000020E610000001000000050000005017299405A46040B3B3E89D0A8045405017299405A460403465A71FD4A34540B535221807AA60403465A71FD4A34540B535221807AA6040B3B3E89D0A8045405017299405A46040B3B3E89D0A804540
59503	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Осиновая	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
59493	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Ленинская	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
45167	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Клубная	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
59492	55286	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	50 Лет ВЛКСМ	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44358	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Центральная	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44885	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Свердлова	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44730	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Садовая	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44627	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Пушкинская	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44357	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Партизанская	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44761	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Обогатительная	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44706	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Ленинская	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44575	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Лазо	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44703	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Коренова	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44638	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Кирова	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
45155	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Калинина	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44502	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	Индустриальная	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44652	9761	133.07543799999999	133.20171400000001	43.173552999999998	43.056080000000001	50 Лет ВЛКСМ	0103000020E6100000010000000500000005DCF3FC69A26040D7FA22A12D87454005DCF3FC69A26040B48F15FC36964540A724EB7074A66040B48F15FC36964540A724EB7074A66040D7FA22A12D87454005DCF3FC69A26040D7FA22A12D874540
44400	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	проспект Мира	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44353	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Юбилейная	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44473	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Шоссейная	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44570	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Школьный переулок	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44406	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Спортивная	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44354	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Северная	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44345	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Пугачева	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44346	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Постышева	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44402	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Пограничная	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44571	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Пирогова	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44352	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Находкинский проспект	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44349	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Нахимовская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44494	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Набережная	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44498	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Молодежная	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44401	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Мичурина	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44344	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Малиновского	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44430	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Макарова	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44350	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Луначарского	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44496	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Ленинская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44493	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Комсомольская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44572	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Кирова	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44372	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Заводская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44403	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Добролюбова	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44495	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Дзержинского	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44347	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Владивостокская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
42808	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Верхне-Морская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44407	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Бокситогорская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
44601	1410	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Арсеньева	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
59476	55271	132.11981	132.123987	43.349946000000003	43.344872000000002	Спортивная	0103000020E610000001000000050000007BF7C77BD58360402FA704C424AC45407BF7C77BD5836040DAAED007CBAC454022C495B3F7836040DAAED007CBAC454022C495B3F78360402FA704C424AC45407BF7C77BD58360402FA704C424AC4540
44574	55271	132.189502	132.196392	43.350549000000001	43.346380000000003	Садовая	0103000020E61000000100000005000000DA907F661086604087FE092E56AC4540DA907F6610866040A05225CADEAC45404626E0D748866040A05225CADEAC45404626E0D74886604087FE092E56AC4540DA907F661086604087FE092E56AC4540
59475	55271	132.15496999999999	132.15977599999999	43.342275999999998	43.339443000000003	Мичурина	0103000020E610000001000000050000008E3BA583F584604096ED43DE72AB45408E3BA583F5846040541A31B3CFAB4540F1D58EE21C856040541A31B3CFAB4540F1D58EE21C85604096ED43DE72AB45408E3BA583F584604096ED43DE72AB4540
44692	55271	132.19413700000001	132.194334	43.357596000000001	43.353886000000003	Красноармейская	0103000020E61000000100000005000000323ECC5E368660409241EE224CAD4540323ECC5E368660401897AAB4C5AD454007D0EFFB378660401897AAB4C5AD454007D0EFFB378660409241EE224CAD4540323ECC5E368660409241EE224CAD4540
59483	55271	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Восточный проспект	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
59486	55271	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	Верхне-Морская	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
59481	55271	132.36596700000001	133.420625	43.188212999999998	42.411586	Астафьева	0103000020E610000001000000050000004A0D6D00B68B6040E8BE9CD9AE3445404A0D6D00B68B60404DD7135D17984540295C8FC275AD60404DD7135D17984540295C8FC275AD6040E8BE9CD9AE3445404A0D6D00B68B6040E8BE9CD9AE344540
44545	55276	132.66364100000001	132.72727800000001	42.893244000000003	42.855100999999998	Набережная	0103000020E610000001000000050000001DE90C8C3C95604071E316F3736D45401DE90C8C3C95604093ACC3D155724540362383DC4597604093ACC3D155724540362383DC4597604071E316F3736D45401DE90C8C3C95604071E316F3736D4540
59482	55280	133.325987	133.462118	45.510340999999997	45.438733999999997	Кравчука	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
59510	55280	133.325987	133.462118	45.510340999999997	45.438733999999997	Григоренко	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44561	55280	133.325987	133.462118	45.510340999999997	45.438733999999997	Вокзальная	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44880	88	133.325987	133.462118	45.510340999999997	45.438733999999997	имени Двенадцати	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44486	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Юго-Западный микрорайон	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44336	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Челюскина	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
43197	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Урицкого	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44395	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Пушкинская	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44484	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Пролетарская	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44555	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Паровозная	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44776	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Октябрьская	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44554	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Мира	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44337	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Ленинская	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
43244	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Калининская	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44553	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Дзержинского	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
44828	88	133.325987	133.462118	45.510340999999997	45.438733999999997	Белова	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
43242	88	133.325987	133.462118	45.510340999999997	45.438733999999997	9 Января	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
45015	55306	131.87441699999999	131.87951100000001	43.117234000000003	43.112614000000001	Набережная	0103000020E6100000010000000500000020425C39FB7B60402F89B3226A8E454020425C39FB7B604059FD1186018F45401DAF40F4247C604059FD1186018F45401DAF40F4247C60402F89B3226A8E454020425C39FB7B60402F89B3226A8E4540
45168	55332	133.676357	133.838584	45.963492000000002	45.905858000000002	Хоровского	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
59474	55332	133.676357	133.838584	45.963492000000002	45.905858000000002	Советская	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
59501	55332	133.676357	133.838584	45.963492000000002	45.905858000000002	Рябухи	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
59491	55332	133.676357	133.838584	45.963492000000002	45.905858000000002	Ленина	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
45159	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Ясная	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44629	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Рябухи	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44628	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Полтавская	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44621	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Личенко	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44619	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Ленина	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44646	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Кошевого	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44626	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Калинина	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44654	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Заводская	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44645	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	Героев Даманского	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44631	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	50 лет Октября	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
44624	32880	133.676357	133.838584	45.963492000000002	45.905858000000002	45 лет Октября	0103000020E61000000100000005000000766D6FB7A4B56040F568AA27F3F34640766D6FB7A4B5604094FAB2B453FB46405DDE1CAED5BA604094FAB2B453FB46405DDE1CAED5BA6040F568AA27F3F34640766D6FB7A4B56040F568AA27F3F34640
59472	55263	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	Проспект 50 лет Октября	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
44478	55263	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	Пионерская	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
44831	4988	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	Школьная	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
43180	4988	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	Химиков	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
43110	4988	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	Проспект 50 лет Октября	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
43098	4988	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	Приморская	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
44615	4988	135.47583499999999	135.660484	44.576739000000003	44.528249000000002	Первомайская 	0103000020E610000001000000050000005969520A3AEF60408692C9A99D4346405969520A3AEF6040F4A96395D2494640007157AF22F56040F4A96395D2494640007157AF22F560408692C9A99D4346405969520A3AEF60408692C9A99D434640
619	1538	131.93746100000001	131.957089	43.128585000000001	43.125064000000002	улица адмирала Юмашева	0103000020E61000000100000005000000D10836AEFF7D604017F4DE1802904540D10836AEFF7D6040CAE0287975904540904B1C79A07E6040CAE0287975904540904B1C79A07E604017F4DE1802904540D10836AEFF7D604017F4DE1802904540
5394	1538	131.912443	131.91820999999999	43.091101999999999	43.087178000000002	улица Каштановая	0103000020E61000000100000005000000DA8EA9BB327D6040217711A6288B4540DA8EA9BB327D6040D34CF73AA98B4540861BF0F9617D6040D34CF73AA98B4540861BF0F9617D6040217711A6288B4540DA8EA9BB327D6040217711A6288B4540
6152	1538	131.96468899999999	131.97080700000001	43.216200999999998	43.210313999999997	улица Верещагина	0103000020E61000000100000005000000F33977BBDE7E60400AF2B391EB9A4540F33977BBDE7E6040662E7079AC9B45404B77D7D9107F6040662E7079AC9B45404B77D7D9107F60400AF2B391EB9A4540F33977BBDE7E60400AF2B391EB9A4540
44618	1538	131.598051	132.258905	43.319028000000003	42.948588999999998	проспект 100-летия Владивостока	0103000020E61000000100000005000000E2CAD93B23736040342C465D6B794540E2CAD93B237360401041D5E8D5A84540AB7823F3488860401041D5E8D5A84540AB7823F348886040342C465D6B794540E2CAD93B23736040342C465D6B794540
44668	1538	131.93746100000001	131.957089	43.128585000000001	43.125064000000002	адмирала Юмашева	0103000020E61000000100000005000000D10836AEFF7D604017F4DE1802904540D10836AEFF7D6040CAE0287975904540904B1C79A07E6040CAE0287975904540904B1C79A07E604017F4DE1802904540D10836AEFF7D604017F4DE1802904540
44768	1538	131.87979799999999	131.888701	43.118029999999997	43.116345000000003	адмирала Фокина	0103000020E61000000100000005000000C2A2224E277C6040CD069964E48E4540C2A2224E277C604033F9669B1B8F4540855D143D707C604033F9669B1B8F4540855D143D707C6040CD069964E48E4540C2A2224E277C6040CD069964E48E4540
44912	1538	132.08862999999999	132.09520499999999	43.210630000000002	43.206017000000003	адмирала Угрюмова	0103000020E6100000010000000500000039EE940ED6826040C4B5DAC35E9A454039EE940ED68260403BC780ECF59A45404D2D5BEB0B8360403BC780ECF59A45404D2D5BEB0B836040C4B5DAC35E9A454039EE940ED6826040C4B5DAC35E9A4540
44738	1538	131.94370499999999	131.95621800000001	43.125545000000002	43.115884999999999	адмирала Кузнецова	0103000020E610000001000000050000004B02D4D4327E6040698CD651D58E45404B02D4D4327E60409296CADB1190454017BB7D56997E60409296CADB1190454017BB7D56997E6040698CD651D58E45404B02D4D4327E6040698CD651D58E4540
44705	1538	131.854547	131.86004399999999	43.089692999999997	43.088375999999997	Ялтинская	0103000020E61000000100000005000000A33CF372587B60402AE09EE74F8B4540A33CF372587B60400ED76A0F7B8B4540DFA3FE7A857B60400ED76A0F7B8B4540DFA3FE7A857B60402AE09EE74F8B4540A33CF372587B60402AE09EE74F8B4540
44368	1538	131.598051	132.258905	43.319028000000003	42.948588999999998	Щитовая	0103000020E61000000100000005000000E2CAD93B23736040342C465D6B794540E2CAD93B237360401041D5E8D5A84540AB7823F3488860401041D5E8D5A84540AB7823F348886040342C465D6B794540E2CAD93B23736040342C465D6B794540
44643	1538	131.91945899999999	131.931083	43.155042000000002	43.150694999999999	Шошина	0103000020E6100000010000000500000069E047356C7D6040DA5548F94993454069E047356C7D6040D3C08F6AD8934540925B936ECB7D6040D3C08F6AD8934540925B936ECB7D6040DA5548F94993454069E047356C7D6040DA5548F949934540
44736	1538	131.92171400000001	131.93235000000001	43.123755000000003	43.117313000000003	Шилкинская	0103000020E610000001000000050000007EC85BAE7E7D6040A532C51C048F45407EC85BAE7E7D6040B6DB2E34D78F45409FCDAACFD57D6040B6DB2E34D78F45409FCDAACFD57D6040A532C51C048F45407EC85BAE7E7D6040A532C51C048F4540
44687	1538	131.93871899999999	131.94083900000001	43.118326000000003	43.109264000000003	Шепеткова	0103000020E6100000010000000500000048A46DFC097E6040A950DD5CFC8D454048A46DFC097E60401D226E4E258F4540A5F9635A1B7E60401D226E4E258F4540A5F9635A1B7E6040A950DD5CFC8D454048A46DFC097E6040A950DD5CFC8D4540
44698	1538	131.91353899999999	131.91781499999999	43.182980000000001	43.175761999999999	Чкалова	0103000020E61000000100000005000000DB1324B63B7D604095F0845E7F964540DB1324B63B7D60403AE97DE36B974540E71890BD5E7D60403AE97DE36B974540E71890BD5E7D604095F0845E7F964540DB1324B63B7D604095F0845E7F964540
44665	1538	131.90180699999999	131.91100599999999	43.101990000000001	43.093846999999997	Черемуховая	0103000020E61000000100000005000000B9895A9ADB7C6040F2E9B12D038C4540B9895A9ADB7C6040704221020E8D4540B60E0EF6267D6040704221020E8D4540B60E0EF6267D6040F2E9B12D038C4540B9895A9ADB7C6040F2E9B12D038C4540
44759	1538	131.91451799999999	131.91999799999999	43.192439	43.180923	Чапаева	0103000020E610000001000000050000004EB340BB437D60400F0C207C289745404EB340BB437D6040CBBC55D7A1984540554CA59F707D6040CBBC55D7A1984540554CA59F707D60400F0C207C289745404EB340BB437D60400F0C207C28974540
44709	1538	131.89046999999999	131.895546	43.094512000000002	43.092399	Херсонская	0103000020E610000001000000050000003602F1BA7E7C60407097FDBAD38B45403602F1BA7E7C60402F8A1EF8188C454009C21550A87C60402F8A1EF8188C454009C21550A87C60407097FDBAD38B45403602F1BA7E7C60407097FDBAD38B4540
44641	1538	131.90473600000001	131.913476	43.100957000000001	43.098495	Харьковская	0103000020E610000001000000050000007270E998F37C6040E6E8F17B9B8C45407270E998F37C6040B1A6B228EC8C4540CA3505323B7D6040B1A6B228EC8C4540CA3505323B7D6040E6E8F17B9B8C45407270E998F37C6040E6E8F17B9B8C4540
44660	1538	131.89023700000001	131.90001899999999	43.135210000000001	43.130315000000003	Хабаровская	0103000020E610000001000000050000000E164ED27C7C6040D1967329AE9045400E164ED27C7C6040CC0BB08F4E914540EA58A5F4CC7C6040CC0BB08F4E914540EA58A5F4CC7C6040D1967329AE9045400E164ED27C7C6040D1967329AE904540
45150	1538	131.939312	131.98455100000001	43.108184000000001	43.097540000000002	Фадеева	0103000020E61000000100000005000000B1170AD80E7E6040A306D3307C8C4540B1170AD80E7E6040A9F92AF9D88D4540D0471971817F6040A9F92AF9D88D4540D0471971817F6040A306D3307C8C4540B1170AD80E7E6040A306D3307C8C4540
44749	1538	132.01154500000001	132.02827199999999	43.241793000000001	43.230989000000001	Успенского	0103000020E61000000100000005000000D6AD9E935E8060402D5E2C0C919D4540D6AD9E935E8060406CB3B112F39E45408F6CAE9AE78060406CB3B112F39E45408F6CAE9AE78060402D5E2C0C919D4540D6AD9E935E8060402D5E2C0C919D4540
44647	1538	131.88828699999999	131.89245600000001	43.124229	43.115253000000003	Уборевича	0103000020E61000000100000005000000C8CEDBD86C7C604009E23C9CC08E4540C8CEDBD86C7C60407E1B62BCE68F4540CFA3E2FF8E7C60407E1B62BCE68F4540CFA3E2FF8E7C604009E23C9CC08E4540C8CEDBD86C7C604009E23C9CC08E4540
44653	1538	131.92768799999999	131.935126	43.160547000000001	43.156028999999997	Тухачевского	0103000020E61000000100000005000000889CBE9EAF7D6040211D1EC2F8934540889CBE9EAF7D6040473CD9CD8C94454075745C8DEC7D6040473CD9CD8C94454075745C8DEC7D6040211D1EC2F8934540889CBE9EAF7D6040211D1EC2F8934540
44679	1538	131.921426	131.93015800000001	43.116858999999998	43.114258999999997	Тунгусская	0103000020E61000000100000005000000E4F560527C7D60400723F609A08E4540E4F560527C7D6040239F573CF58E45409CC3B5DAC37D6040239F573CF58E45409CC3B5DAC37D60400723F609A08E4540E4F560527C7D60400723F609A08E4540
44702	1538	131.90921800000001	131.92171400000001	43.125366999999997	43.118003999999999	Толстого	0103000020E61000000100000005000000E8DD5850187D60400A664CC11A8F4540E8DD5850187D6040B27F9E060C9045407EC85BAE7E7D6040B27F9E060C9045407EC85BAE7E7D60400A664CC11A8F4540E8DD5850187D60400A664CC11A8F4540
44713	1538	131.94779199999999	131.95023499999999	43.099035000000001	43.097883000000003	Талалихина	0103000020E61000000100000005000000226DE34F547E6040CDEA1D6E878C4540226DE34F547E60406614CB2DAD8C454077103B53687E60406614CB2DAD8C454077103B53687E6040CDEA1D6E878C4540226DE34F547E6040CDEA1D6E878C4540
44757	1538	131.88912300000001	131.90779900000001	43.119200999999997	43.116562000000002	Суханова	0103000020E61000000100000005000000E3E313B2737C60406AFAEC80EB8E4540E3E313B2737C6040435376FA418F4540EE0A7DB00C7D6040435376FA418F4540EE0A7DB00C7D60406AFAEC80EB8E4540E3E313B2737C60406AFAEC80EB8E4540
44690	1538	131.86458999999999	131.87610599999999	43.110638999999999	43.101864999999997	Станюковича	0103000020E610000001000000050000005BCEA5B8AA7B6040B3CD8DE9098D45405BCEA5B8AA7B6040C154336B298E45408A3A730F097C6040C154336B298E45408A3A730F097C6040B3CD8DE9098D45405BCEA5B8AA7B6040B3CD8DE9098D4540
44739	1538	131.93924899999999	131.94387499999999	43.118931000000003	43.111995	Спиридонова	0103000020E610000001000000050000009F39EB530E7E6040632827DA558E45409F39EB530E7E604084BD8921398F454062105839347E604084BD8921398F454062105839347E6040632827DA558E45409F39EB530E7E6040632827DA558E4540
44634	1538	131.90624500000001	131.980086	43.14855	43.136150999999998	Снеговая	0103000020E610000001000000050000003CA583F5FF7C6040AA285E656D9145403CA583F5FF7C604010E9B7AF039345408FA850DD5C7F604010E9B7AF039345408FA850DD5C7F6040AA285E656D9145403CA583F5FF7C6040AA285E656D914540
44724	1538	131.939447	131.942061	43.134447000000002	43.130682999999998	Сельская	0103000020E6100000010000000500000069AA27F30F7E604053927538BA90454069AA27F30F7E6040CD052E8F35914540C93A1C5D257E6040CD052E8F35914540C93A1C5D257E604053927538BA90454069AA27F30F7E604053927538BA904540
44661	1538	131.87948399999999	131.924463	43.116931000000001	43.112127000000001	Светланская	0103000020E610000001000000050000005E2BA1BB247C6040D2FF722D5A8E45405E2BA1BB247C6040BD715298F78E454096EB6D33957D6040BD715298F78E454096EB6D33957D6040D2FF722D5A8E45405E2BA1BB247C6040D2FF722D5A8E4540
44656	1538	131.96600100000001	131.97148899999999	43.099575000000002	43.090035	Сахалинская	0103000020E61000000100000005000000E8DCED7AE97E6040683F5244868B4540E8DCED7AE97E6040E63FA4DFBE8C45408F6D1970167F6040E63FA4DFBE8C45408F6D1970167F6040683F5244868B4540E8DCED7AE97E6040683F5244868B4540
44697	1538	131.94156699999999	131.95576	43.132334999999998	43.127504999999999	Сабанеева	0103000020E61000000100000005000000C5FF1D51217E6040CA89761552904540C5FF1D51217E6040DE8E705AF090454066DAFE95957E6040DE8E705AF090454066DAFE95957E6040CA89761552904540C5FF1D51217E6040CA89761552904540
44667	1538	131.90456499999999	131.944594	43.176833999999999	43.164873999999998	Русская	0103000020E6100000010000000500000066834C32F27C6040F8FA5A971A95454066834C32F27C604012691B7FA2964540EE3F321D3A7E604012691B7FA2964540EE3F321D3A7E6040F8FA5A971A95454066834C32F27C6040F8FA5A971A954540
44684	1538	131.89655200000001	131.91746499999999	43.117049000000002	43.113680000000002	Пушкинская	0103000020E610000001000000050000003BE5D18DB07C6040CA1AF5108D8E45403BE5D18DB07C6040C7832D76FB8E454030478FDF5B7D6040C7832D76FB8E454030478FDF5B7D6040CA1AF5108D8E45403BE5D18DB07C6040CA1AF5108D8E4540
44744	1538	132.05664999999999	132.07637700000001	43.313335000000002	43.296487999999997	Путятинская	0103000020E61000000100000005000000302AA913D081604006D49B51F3A54540302AA913D081604099D87C5C1BA8454055A52DAE7182604099D87C5C1BA8454055A52DAE7182604006D49B51F3A54540302AA913D081604006D49B51F3A54540
44755	1538	131.89524	131.901726	43.088475000000003	43.087217000000003	Приморская	0103000020E6100000010000000500000046425BCEA57C6040DF5339ED298B454046425BCEA57C6040BEC11726538B45407EFE7BF0DA7C6040BEC11726538B45407EFE7BF0DA7C6040DF5339ED298B454046425BCEA57C6040DF5339ED298B4540
45141	1538	131.88175699999999	131.89179100000001	43.123300999999998	43.121082999999999	Прапорщика Комарова	0103000020E610000001000000050000009CC0745A377C6040008DD2A57F8F45409CC0745A377C60403448C153C88F4540C07B478D897C60403448C153C88F4540C07B478D897C6040008DD2A57F8F45409CC0745A377C6040008DD2A57F8F4540
44720	1538	131.911832	131.923609	43.161658000000003	43.155358	Постышева	0103000020E61000000100000005000000486E4DBA2D7D604003965CC5E2934540486E4DBA2D7D604082919735B1944540522976348E7D604082919735B1944540522976348E7D604003965CC5E2934540486E4DBA2D7D604003965CC5E2934540
44695	1538	131.90222900000001	131.905068	43.085756000000003	43.085676999999997	Поселковая 2-я	0103000020E6100000010000000500000017105A0FDF7C60407B82C476F78A454017105A0FDF7C6040C8B7770DFA8A4540FF942A51F67C6040C8B7770DFA8A4540FF942A51F67C60407B82C476F78A454017105A0FDF7C60407B82C476F78A4540
44644	1538	132.07247799999999	132.090462	43.308146000000001	43.297268000000003	Порт-Артурская	0103000020E61000000100000005000000BEF561BD51826040DC12B9E00CA64540BEF561BD518260405532005471A74540FC709010E58260405532005471A74540FC709010E5826040DC12B9E00CA64540BEF561BD51826040DC12B9E00CA64540
44715	1538	131.928586	131.935665	43.099719	43.096915000000003	Полярная	0103000020E61000000100000005000000C0B0FCF9B67D6040F5BEF1B5678C4540C0B0FCF9B67D604019E59997C38C454061E0B9F7F07D604019E59997C38C454061E0B9F7F07D6040F5BEF1B5678C4540C0B0FCF9B67D6040F5BEF1B5678C4540
44756	1538	132.04232200000001	132.051323	43.262129000000002	43.253146999999998	Подгорная	0103000020E61000000100000005000000D8BCAAB35A8160404E0AF31E67A04540D8BCAAB35A816040A62A6D718DA145400BD12170A4816040A62A6D718DA145400BD12170A48160404E0AF31E67A04540D8BCAAB35A8160404E0AF31E67A04540
45146	1538	131.879143	131.88206199999999	43.125307999999997	43.116128000000003	Пограничная	0103000020E610000001000000050000003C3080F0217C604030134548DD8E45403C3080F0217C6040ADF6B0170A9045406B6116DA397C6040ADF6B0170A9045406B6116DA397C604030134548DD8E45403C3080F0217C604030134548DD8E4540
44673	1538	131.91718599999999	131.920312	43.127591000000002	43.126742	Писаревская	0103000020E610000001000000050000002B4B7496597D6040CB83F414399045402B4B7496597D6040C921E2E654904540B9C32632737D6040C921E2E654904540B9C32632737D6040CB83F414399045402B4B7496597D6040CB83F41439904540
44745	1538	131.95488900000001	131.95672099999999	43.216825999999998	43.215491999999998	Пирогова	0103000020E61000000100000005000000ED4960738E7E60405A46EA3D959B4540ED4960738E7E6040147651F4C09B4540AFCC5B759D7E6040147651F4C09B4540AFCC5B759D7E60405A46EA3D959B4540ED4960738E7E60405A46EA3D959B4540
44740	1538	131.97642099999999	131.97974500000001	43.094585000000002	43.092306999999998	Пацаева	0103000020E6100000010000000500000015C440D73E7F60408F183DB7D08B454015C440D73E7F604099D87C5C1B8C45406DAD2F125A7F604099D87C5C1B8C45406DAD2F125A7F60408F183DB7D08B454015C440D73E7F60408F183DB7D08B4540
1551	1538	131.88895199999999	131.910988	43.132452999999998	43.123728999999997	Партизанский проспект	0103000020E61000000100000005000000D7F6764B727C60408C48145AD68F4540D7F6764B727C6040E8A04B38F49045408D614ED0267D6040E8A04B38F49045408D614ED0267D60408C48145AD68F4540D7F6764B727C60408C48145AD68F4540
44765	1538	131.91913600000001	131.92362700000001	43.204262	43.195580999999997	Пальчевского	0103000020E610000001000000050000007192E68F697D6040075C57CC089945407192E68F697D604064E8D841259A45407CD6355A8E7D604064E8D841259A45407CD6355A8E7D6040075C57CC089945407192E68F697D6040075C57CC08994540
5825	1538	131.89846499999999	131.90229199999999	43.137618000000003	43.128386999999996	Острякова проспект	0103000020E6100000010000000500000038F3AB39C07C6040A31D37FC6E90454038F3AB39C07C6040A4AB74779D91454028EE7893DF7C6040A4AB74779D91454028EE7893DF7C6040A31D37FC6E90454038F3AB39C07C6040A31D37FC6E904540
44642	1538	132.02327700000001	132.031003	43.259306000000002	43.256436999999998	Опорная	0103000020E61000000100000005000000F83768AFBE806040FF3D78EDD2A04540F83768AFBE8060400BD462F030A145407EE200FAFD8060400BD462F030A145407EE200FAFD806040FF3D78EDD2A04540F83768AFBE806040FF3D78EDD2A04540
44753	1538	131.908401	131.91788700000001	43.093254999999999	43.092708000000002	Олега Кошевого	0103000020E61000000100000005000000EB54F99E117D6040EE0912DBDD8B4540EB54F99E117D60402098A3C7EF8B45408ECD8E545F7D60402098A3C7EF8B45408ECD8E545F7D6040EE0912DBDD8B4540EB54F99E117D6040EE0912DBDD8B4540
44726	1538	131.88546700000001	131.88862	43.124873999999998	43.124386999999999	Октябрьская	0103000020E61000000100000005000000FED5E3BE557C60401686C8E9EB8F4540FED5E3BE557C6040730F09DFFB8F45404AD235936F7C6040730F09DFFB8F45404AD235936F7C60401686C8E9EB8F4540FED5E3BE557C60401686C8E9EB8F4540
5915	1538	131.88551200000001	131.90980200000001	43.133465999999999	43.115758999999997	Океанский проспект	0103000020E61000000100000005000000E606431D567C6040DC9BDF30D18E4540E606431D567C60406090F46915914540BC7A15191D7D60406090F46915914540BC7A15191D7D6040DC9BDF30D18E4540E606431D567C6040DC9BDF30D18E4540
44721	1538	131.90451999999999	131.91057499999999	43.155752	43.148820000000001	Овчинникова	0103000020E610000001000000050000007E52EDD3F17C6040D07EA4880C9345407E52EDD3F17C6040AF2479AEEF934540C4B12E6E237D6040AF2479AEEF934540C4B12E6E237D6040D07EA4880C9345407E52EDD3F17C6040D07EA4880C934540
44670	1538	131.949759	131.95516699999999	43.097422000000002	43.090752999999999	Никифорова	0103000020E610000001000000050000009D82FC6C647E6040C78157CB9D8B45409D82FC6C647E604099F4F752788C4540FD6662BA907E604099F4F752788C4540FD6662BA907E6040C78157CB9D8B45409D82FC6C647E6040C78157CB9D8B4540
44639	1538	131.89171899999999	131.90293	43.126004999999999	43.122464999999998	Нерчинская	0103000020E6100000010000000500000019C748F6887C6040CBF3E0EEAC8F454019C748F6887C6040F5108DEE20904540799274CDE47C6040F5108DEE20904540799274CDE47C6040CBF3E0EEAC8F454019C748F6887C6040CBF3E0EEAC8F4540
546	1538	131.895995	131.89654300000001	43.118780000000001	43.116759999999999	Некрасовский переулок	0103000020E6100000010000000500000025CCB4FDAB7C604090BDDEFDF18E454025CCB4FDAB7C60409EB5DB2E348F4540A60EF27AB07C60409EB5DB2E348F4540A60EF27AB07C604090BDDEFDF18E454025CCB4FDAB7C604090BDDEFDF18E4540
44686	1538	131.90010899999999	131.917599	43.132261999999997	43.118234000000001	Некрасовская	0103000020E61000000100000005000000BABA63B1CD7C60403CA3AD4A228F4540BABA63B1CD7C6040744012F6ED904540F4FA93F85C7D6040744012F6ED904540F4FA93F85C7D60403CA3AD4A228F4540BABA63B1CD7C60403CA3AD4A228F4540
44746	1538	131.95519400000001	131.963054	43.125076999999997	43.103755	Нейбута	0103000020E61000000100000005000000BCEA01F3907E6040F3E505D8478D4540BCEA01F3907E6040AB3DEC850290454006499F56D17E6040AB3DEC850290454006499F56D17E6040F3E505D8478D4540BCEA01F3907E6040F3E505D8478D4540
44731	1538	131.91153600000001	131.920896	43.150649000000001	43.147972000000003	Невская	0103000020E610000001000000050000000EA48B4D2B7D6040A35C1ABFF09245400EA48B4D2B7D60406A166877489345408D60E3FA777D60406A166877489345408D60E3FA777D6040A35C1ABFF09245400EA48B4D2B7D6040A35C1ABFF0924540
44693	1538	131.94039900000001	131.95630800000001	43.118496999999998	43.109580000000001	Невельского	0103000020E610000001000000050000001EC6A4BF177E6040D925AAB7068E45401EC6A4BF177E604049D6E1E82A8F4540E71C3C139A7E604049D6E1E82A8F4540E71C3C139A7E6040D925AAB7068E45401EC6A4BF177E6040D925AAB7068E4540
44640	1538	131.91443699999999	131.917689	43.152793000000003	43.152056000000002	Нахимова	0103000020E6100000010000000500000013286211437D60408E942D927693454013286211437D6040640795B88E934540C45C52B55D7D6040640795B88E934540C45C52B55D7D60408E942D927693454013286211437D60408E942D9276934540
5855	1538	131.90975700000001	131.92568399999999	43.133459999999999	43.122872999999998	Народный проспект	0103000020E61000000100000005000000D449B6BA1C7D6040DC476E4DBA8F4540D449B6BA1C7D60407EA99F3715914540C64D0D349F7D60407EA99F3715914540C64D0D349F7D6040DC476E4DBA8F4540D449B6BA1C7D6040DC476E4DBA8F4540
44750	1538	131.87441699999999	131.87951100000001	43.117234000000003	43.112614000000001	Набережная	0103000020E6100000010000000500000020425C39FB7B60402F89B3226A8E454020425C39FB7B604059FD1186018F45401DAF40F4247C604059FD1186018F45401DAF40F4247C60402F89B3226A8E454020425C39FB7B60402F89B3226A8E4540
44737	1538	131.92444499999999	131.924678	43.114206000000003	43.110284	Муравьева-Амурского	0103000020E610000001000000050000006C3EAE0D957D6040D3A23EC91D8E45406C3EAE0D957D6040E5805D4D9E8E4540952A51F6967D6040E5805D4D9E8E4540952A51F6967D6040D3A23EC91D8E45406C3EAE0D957D6040D3A23EC91D8E4540
44727	1538	131.86220900000001	131.86326	43.093840999999998	43.090825000000002	Морозова	0103000020E61000000100000005000000242A5437977B604061545227A08B4540242A5437977B604010035DFB028C45403D7E6FD39F7B604010035DFB028C45403D7E6FD39F7B604061545227A08B4540242A5437977B604061545227A08B4540
44920	1538	132.04098300000001	132.04549299999999	43.259483000000003	43.254336000000002	Минеральная	0103000020E61000000100000005000000259694BB4F816040051901158EA04540259694BB4F8160401A6F2BBD36A145404D66BCAD748160401A6F2BBD36A145404D66BCAD74816040051901158EA04540259694BB4F816040051901158EA04540
44769	1538	131.94741500000001	132.04129699999999	43.245688000000001	43.199064	Маковского	0103000020E61000000100000005000000AD174339517E6040CDE7DCED7A994540AD174339517E6040848252B4729F4540880D164E52816040848252B4729F4540880D164E52816040CDE7DCED7A994540AD174339517E6040CDE7DCED7A994540
44742	1538	131.93553900000001	131.94798900000001	43.134354999999999	43.111370000000001	Луговая	0103000020E610000001000000050000003E247CEFEF7D6040B5E0455F418E45403E247CEFEF7D6040EC866D8B32914540F8FE06ED557E6040EC866D8B32914540F8FE06ED557E6040B5E0455F418E45403E247CEFEF7D6040B5E0455F418E4540
44725	1538	132.060036	132.08275499999999	43.315316000000003	43.285713000000001	Лермонтова	0103000020E61000000100000005000000A5129ED0EB81604062855B3E92A44540A5129ED0EB816040E9F351465CA845409352D0EDA5826040E9F351465CA845409352D0EDA582604062855B3E92A44540A5129ED0EB81604062855B3E92A44540
44767	1538	132.060036	132.08275499999999	43.315316000000003	43.285713000000001	Лермонтова	0103000020E61000000100000005000000A5129ED0EB81604062855B3E92A44540A5129ED0EB816040E9F351465CA845409352D0EDA5826040E9F351465CA845409352D0EDA582604062855B3E92A44540A5129ED0EB81604062855B3E92A44540
44741	1538	131.945932	131.947307	43.109422000000002	43.107591999999997	Куйбышева	0103000020E61000000100000005000000AD872F13457E6040D6A71C93C58D4540AD872F13457E604041BB438A018E4540B308C556507E604041BB438A018E4540B308C556507E6040D6A71C93C58D4540AD872F13457E6040D6A71C93C58D4540
397	1538	131.88842199999999	131.93297899999999	43.129393999999998	43.118523000000003	Красного Знамени проспект	0103000020E610000001000000050000008061F9F36D7C60407369FCC22B8F45408061F9F36D7C604039268BFB8F9045405A9BC6F6DA7D604039268BFB8F9045405A9BC6F6DA7D60407369FCC22B8F45408061F9F36D7C60407369FCC22B8F4540
44732	1538	131.92634000000001	131.938378	43.133420000000001	43.128287999999998	Котельникова	0103000020E61000000100000005000000419FC893A47D6040103CBEBD6B904540419FC893A47D6040F05014E81391454026A94C31077E6040F05014E81391454026A94C31077E6040103CBEBD6B904540419FC893A47D6040103CBEBD6B904540
44711	1538	131.966746	131.97474099999999	43.091661999999999	43.087777000000003	Космонавтов	0103000020E610000001000000050000003EB14E95EF7E6040A62BD8463C8B45403EB14E95EF7E60409A249694BB8B454040A20914317F60409A249694BB8B454040A20914317F6040A62BD8463C8B45403EB14E95EF7E6040A62BD8463C8B4540
44664	1538	131.92358200000001	131.92658299999999	43.115062000000002	43.112357000000003	Ковальчука	0103000020E6100000010000000500000094A5D6FB8D7D6040043DD4B6618E454094A5D6FB8D7D60409581035ABA8E4540F2406491A67D60409581035ABA8E4540F2406491A67D6040043DD4B6618E454094A5D6FB8D7D6040043DD4B6618E4540
44766	1538	131.90967599999999	131.91122100000001	43.184873000000003	43.166970999999997	Кирова	0103000020E6100000010000000500000098BED7101C7D6040B130444E5F95454098BED7101C7D6040EB7420EBA9974540B64DF1B8287D6040EB7420EBA9974540B64DF1B8287D6040B130444E5F95454098BED7101C7D6040B130444E5F954540
44717	1538	131.92219	131.932413	43.156495	43.153148000000002	Карбышева	0103000020E6100000010000000500000058569A94827D604052B9895A9A93454058569A94827D6040677E350708944540B0ABC953D67D6040677E350708944540B0ABC953D67D604052B9895A9A93454058569A94827D604052B9895A9A934540
44689	1538	131.94226699999999	131.95368500000001	43.116081999999999	43.111877	Каплунова	0103000020E6100000010000000500000033A31F0D277E604059164CFC518E454033A31F0D277E6040BFD364C6DB8E4540F2B56796847E6040BFD364C6DB8E4540F2B56796847E604059164CFC518E454033A31F0D277E604059164CFC518E4540
44659	1538	131.91589300000001	131.925837	43.141598000000002	43.138328000000001	Камская	0103000020E610000001000000050000005534D6FE4E7D6040800F5EBBB49145405534D6FE4E7D6040EA961DE21F924540A88DEA74A07D6040EA961DE21F924540A88DEA74A07D6040800F5EBBB49145405534D6FE4E7D6040800F5EBBB4914540
44669	1538	131.8827	131.93767700000001	43.104827	43.090108000000001	Калинина	0103000020E61000000100000005000000BC0512143F7C6040D28DB0A8888B4540BC0512143F7C6040705E9CF86A8D4540C4263273017E6040705E9CF86A8D4540C4263273017E6040D28DB0A8888B4540BC0512143F7C6040D28DB0A8888B4540
44648	1538	131.861616	131.86327800000001	43.095782999999997	43.093986000000001	Казанская	0103000020E61000000100000005000000BBB6B75B927B60401424B6BB078C4540BBB6B75B927B6040A2410A9E428C4540672B2FF99F7B6040A2410A9E428C4540672B2FF99F7B60401424B6BB078C4540BBB6B75B927B60401424B6BB078C4540
44672	1538	131.912398	131.93385000000001	43.165334000000001	43.159573000000002	Иртышская	0103000020E61000000100000005000000F25D4A5D327D60408D2958E36C944540F25D4A5D327D60405C751DAA29954540D42B6519E27D60405C751DAA29954540D42B6519E27D60408D2958E36C944540F25D4A5D327D60408D2958E36C944540
44675	1538	131.91303600000001	131.920241	43.101477000000003	43.099746000000003	Интернациональная	0103000020E6100000010000000500000043024697377D604013F4177AC48C454043024697377D6040EA25C632FD8C454007EE409D727D6040EA25C632FD8C454007EE409D727D604013F4177AC48C454043024697377D604013F4177AC48C4540
44719	1538	131.907386	131.911383	43.154108000000001	43.144359999999999	Ильичева	0103000020E61000000100000005000000255B5D4E097D6040DF6C73637A924540255B5D4E097D6040A7069ACFB99345402C64AE0C2A7D6040A7069ACFB99345402C64AE0C2A7D6040DF6C73637A924540255B5D4E097D6040DF6C73637A924540
44758	1538	131.92111199999999	131.92644799999999	43.133420000000001	43.124031000000002	Жигура	0103000020E61000000100000005000000807EDFBF797D60405858703FE08F4540807EDFBF797D6040F05014E8139145403AAE4676A57D6040F05014E8139145403AAE4676A57D60405858703FE08F4540807EDFBF797D60405858703FE08F4540
44710	1538	131.966531	131.97869399999999	43.096316000000002	43.089950000000002	Добровольского	0103000020E610000001000000050000003F726BD2ED7E60403A234A7B838B45403F726BD2ED7E6040700A2B15548C454053591476517F6040700A2B15548C454053591476517F60403A234A7B838B45403F726BD2ED7E60403A234A7B838B4540
5815	1538	131.913961	131.91607200000001	43.144590999999998	43.142538000000002	Днепровский переулок	0103000020E61000000100000005000000399A232B3F7D6040F83768AF3E924540399A232B3F7D6040E12538F58192454001193A76507D6040E12538F58192454001193A76507D6040F83768AF3E924540399A232B3F7D6040F83768AF3E924540
44922	1538	131.899148	131.90107	43.121451999999998	43.119622	Державина	0103000020E6100000010000000500000071C806D2C57C6040E9F010C64F8F454071C806D2C57C6040530438BD8B8F454004ADC090D57C6040530438BD8B8F454004ADC090D57C6040E9F010C64F8F454071C806D2C57C6040E9F010C64F8F4540
44747	1538	131.918543	131.92660100000001	43.181488000000002	43.168489999999998	Давыдова	0103000020E61000000100000005000000081F4AB4647D6040FDD98F1491954540081F4AB4647D6040E84EB0FF3A9745401CEE23B7A67D6040E84EB0FF3A9745401CEE23B7A67D6040FDD98F1491954540081F4AB4647D6040FDD98F1491954540
44714	1538	131.93653599999999	131.948421	43.099778999999998	43.096671999999998	Гризодубовой	0103000020E61000000100000005000000DA70581AF87D60402E3883BF5F8C4540DA70581AF87D6040EEE9EA8EC58C4540DE3AFF76597E6040EEE9EA8EC58C4540DE3AFF76597E60402E3883BF5F8C4540DA70581AF87D60402E3883BF5F8C4540
44637	1538	131.899382	131.910269	43.127195999999998	43.119208	Гоголя	0103000020E610000001000000050000008E93C2BCC77C6040F6B52E35428F45408E93C2BCC77C60404C1762F547904540013274EC207D60404C1762F547904540013274EC207D6040F6B52E35428F45408E93C2BCC77C6040F6B52E35428F4540
44754	1538	131.91826399999999	131.926187	43.092643000000002	43.088026999999997	Героев-Тихоокеанцев	0103000020E6100000010000000500000003232F6B627D60401E15FF77448B454003232F6B627D6040079ACFB9DB8B45405F5FEB52A37D6040079ACFB9DB8B45405F5FEB52A37D60401E15FF77448B454003232F6B627D60401E15FF77448B4540
44696	1538	131.92902599999999	131.930778	43.163690000000003	43.160159	Героев Варяга	0103000020E6100000010000000500000047E4BB94BA7D60407D9411178094454047E4BB94BA7D604054573ECBF3944540C3BAF1EEC87D604054573ECBF3944540C3BAF1EEC87D60407D9411178094454047E4BB94BA7D60407D94111780944540
44752	1538	131.92136300000001	131.92188400000001	43.099364000000001	43.093879999999999	Вязовая	0103000020E61000000100000005000000D31742CE7B7D6040CEDF8442048C4540D31742CE7B7D60402B33A5F5B78C454095D6DF12807D60402B33A5F5B78C454095D6DF12807D6040CEDF8442048C4540D31742CE7B7D6040CEDF8442048C4540
44722	1538	131.90819400000001	131.925837	43.151496999999999	43.141162999999999	Вострецова	0103000020E610000001000000050000008D0DDDEC0F7D6040DF3312A1119245408D0DDDEC0F7D60409738F24064934540A88DEA74A07D60409738F24064934540A88DEA74A07D6040DF3312A1119245408D0DDDEC0F7D6040DF3312A111924540
6069	1538	132.044522	132.05488	43.265259999999998	43.262121999999998	Восточный проспект	0103000020E610000001000000050000007BBE66B96C816040F3C7B4368DA145407BBE66B96C816040EE77280AF4A145408BA6B393C1816040EE77280AF4A145408BA6B393C1816040F3C7B4368DA145407BBE66B96C816040F3C7B4368DA14540
44704	1538	131.93920399999999	131.95130399999999	43.110185000000001	43.103109000000003	Воропаева	0103000020E61000000100000005000000B7088CF50D7E60402E76FBAC328D4540B7088CF50D7E604040C1C58A1A8E4540BA111615717E604040C1C58A1A8E4540BA111615717E60402E76FBAC328D4540B7088CF50D7E60402E76FBAC328D4540
44743	1538	131.91425799999999	131.91887500000001	43.151463999999997	43.150253999999997	Волховская	0103000020E610000001000000050000006743FE99417D6040ED0BE8853B9345406743FE99417D6040BB421F2C6393454096438B6C677D6040BB421F2C6393454096438B6C677D6040ED0BE8853B9345406743FE99417D6040ED0BE8853B934540
43081	1538	131.915201	131.92666299999999	43.136032	43.132012000000003	Военное шоссе	0103000020E6100000010000000500000087889B53497D6040FC56EBC4E590454087889B53497D6040D09A1F7F6991454039ED2939A77D6040D09A1F7F6991454039ED2939A77D6040FC56EBC4E590454087889B53497D6040FC56EBC4E5904540
44718	1538	131.92256699999999	131.934775	43.103208000000002	43.098436	Вилкова	0103000020E61000000100000005000000CDAB3AAB857D6040E15F048D998C4540CDAB3AAB857D6040C15774EB358D4540CAC342ADE97D6040C15774EB358D4540CAC342ADE97D6040E15F048D998C4540CDAB3AAB857D6040E15F048D998C4540
44676	1538	131.861006	131.88085799999999	43.111356999999998	43.095782999999997	Верхнепортовая	0103000020E610000001000000050000001D75745C8D7B6040A2410A9E428C45401D75745C8D7B6040209738F2408E454070CD1DFD2F7C6040209738F2408E454070CD1DFD2F7C6040A2410A9E428C45401D75745C8D7B6040A2410A9E428C4540
44333	1538	131.598051	132.258905	43.319028000000003	42.948588999999998	Верхненабережная	0103000020E61000000100000005000000E2CAD93B23736040342C465D6B794540E2CAD93B237360401041D5E8D5A84540AB7823F3488860401041D5E8D5A84540AB7823F348886040342C465D6B794540E2CAD93B23736040342C465D6B794540
44678	1538	131.95258899999999	131.95855399999999	43.110455000000002	43.104846999999999	Ватутина	0103000020E61000000100000005000000F030ED9B7B7E6040B70A62A06B8D4540F030ED9B7B7E60400057B263238E4540662E7079AC7E60400057B263238E4540662E7079AC7E6040B70A62A06B8D4540F030ED9B7B7E6040B70A62A06B8D4540
44708	1538	131.95258899999999	131.95855399999999	43.110455000000002	43.104846999999999	Ватутина	0103000020E61000000100000005000000F030ED9B7B7E6040B70A62A06B8D4540F030ED9B7B7E60400057B263238E4540662E7079AC7E60400057B263238E4540662E7079AC7E6040B70A62A06B8D4540F030ED9B7B7E6040B70A62A06B8D4540
44748	1538	131.913611	131.94099199999999	43.169035999999998	43.163393999999997	Бородинская	0103000020E6100000010000000500000082C8224D3C7D60406A2E3718EA94454082C8224D3C7D60405FECBDF8A29545408639419B1C7E60405FECBDF8A29545408639419B1C7E60406A2E3718EA94454082C8224D3C7D60406A2E3718EA944540
44694	1538	131.937479	131.96668299999999	43.104478999999998	43.083154999999998	Борисенко	0103000020E61000000100000005000000FAB5F5D3FF7D6040DBBFB2D2A48A4540FAB5F5D3FF7D6040340F60915F8D45402CD32F11EF7E6040340F60915F8D45402CD32F11EF7E6040DBBFB2D2A48A4540FAB5F5D3FF7D6040DBBFB2D2A48A4540
44636	1538	131.87542400000001	131.88067000000001	43.124090000000002	43.120215000000002	Батарейная	0103000020E6100000010000000500000046443179037C60408CBE8234638F454046443179037C60405DE15D2EE28F45403012DA722E7C60405DE15D2EE28F45403012DA722E7C60408CBE8234638F454046443179037C60408CBE8234638F4540
44723	1538	131.92749000000001	131.93894299999999	43.133558999999998	43.12921	Баляева	0103000020E61000000100000005000000BF2B82FFAD7D604078280AF489904540BF2B82FFAD7D6040118B187618914540DCB930D20B7E6040118B187618914540DCB930D20B7E604078280AF489904540BF2B82FFAD7D604078280AF489904540
44701	1538	131.88862	131.90777199999999	43.136814999999999	43.131959999999999	Амурская	0103000020E610000001000000050000004AD235936F7C6040A930B610E49045404AD235936F7C6040164D6727839145402F87DD770C7D6040164D6727839145402F87DD770C7D6040A930B610E49045404AD235936F7C6040A930B610E4904540
45147	1538	131.88085799999999	131.88525100000001	43.123714999999997	43.111356999999998	Алеутская	0103000020E6100000010000000500000070CD1DFD2F7C6040209738F2408E454070CD1DFD2F7C60402783A3E4D58F45400BB8E7F9537C60402783A3E4D58F45400BB8E7F9537C6040209738F2408E454070CD1DFD2F7C6040209738F2408E4540
44655	1538	131.94370499999999	131.95621800000001	43.125545000000002	43.115884999999999	Адмирала Кузнецова	0103000020E610000001000000050000004B02D4D4327E6040698CD651D58E45404B02D4D4327E60409296CADB1190454017BB7D56997E60409296CADB1190454017BB7D56997E6040698CD651D58E45404B02D4D4327E6040698CD651D58E4540
44663	1538	\N	\N	\N	\N	6-я	\N
44919	1538	131.598051	132.258905	43.319028000000003	42.948588999999998	50 Лет Октября	0103000020E61000000100000005000000E2CAD93B23736040342C465D6B794540E2CAD93B237360401041D5E8D5A84540AB7823F3488860401041D5E8D5A84540AB7823F348886040342C465D6B794540E2CAD93B23736040342C465D6B794540
44716	1538	131.598051	132.258905	43.319028000000003	42.948588999999998	50 Лет ВЛКСМ	0103000020E61000000100000005000000E2CAD93B23736040342C465D6B794540E2CAD93B237360401041D5E8D5A84540AB7823F3488860401041D5E8D5A84540AB7823F348886040342C465D6B794540E2CAD93B23736040342C465D6B794540
44763	1538	132.05086499999999	132.06867800000001	43.281224000000002	43.266224999999999	4-я Восточная	0103000020E610000001000000050000005AF0A2AFA081604055302AA913A245405AF0A2AFA0816040D76CE525FFA345408D7E349C32826040D76CE525FFA345408D7E349C3282604055302AA913A245405AF0A2AFA081604055302AA913A24540
44733	1538	131.95453800000001	131.95746700000001	43.096797000000002	43.090041999999997	2-я Строительная	0103000020E61000000100000005000000429946938B7E60401AA20A7F868B4540429946938B7E6040EBAC16D8638C4540FA7FD591A37E6040EBAC16D8638C4540FA7FD591A37E60401AA20A7F868B4540429946938B7E60401AA20A7F868B4540
44762	1538	131.90222900000001	131.905068	43.085756000000003	43.085676999999997	2-я Поселковая	0103000020E6100000010000000500000017105A0FDF7C60407B82C476F78A454017105A0FDF7C6040C8B7770DFA8A4540FF942A51F67C6040C8B7770DFA8A4540FF942A51F67C60407B82C476F78A454017105A0FDF7C60407B82C476F78A4540
44614	1538	131.91303600000001	131.92124699999999	43.174250000000001	43.168239999999997	100 Лет Владивостоку проспект	0103000020E6100000010000000500000043024697377D604084F068E38895454043024697377D6040FCA9F1D24D9645403811FDDA7A7D6040FCA9F1D24D9645403811FDDA7A7D604084F068E38895454043024697377D604084F068E388954540
44481	1538	131.91303600000001	131.92124699999999	43.174250000000001	43.168239999999997	100 Лет Владивостоку проспект	0103000020E6100000010000000500000043024697377D604084F068E38895454043024697377D6040FCA9F1D24D9645403811FDDA7A7D6040FCA9F1D24D9645403811FDDA7A7D604084F068E38895454043024697377D604084F068E388954540
8193	1538	131.91303600000001	131.92124699999999	43.174250000000001	43.168239999999997	100 Лет Владивостоку проспект	0103000020E6100000010000000500000043024697377D604084F068E38895454043024697377D6040FCA9F1D24D9645403811FDDA7A7D6040FCA9F1D24D9645403811FDDA7A7D604084F068E38895454043024697377D604084F068E388954540
45145	1538	\N	\N	\N	\N	10-я	\N
44700	1538	131.924463	131.933266	43.112127000000001	43.111462000000003	 Ивановская	0103000020E6100000010000000500000096EB6D33957D6040965F0663448E454096EB6D33957D6040D2FF722D5A8E4540008FA850DD7D6040D2FF722D5A8E4540008FA850DD7D6040965F0663448E454096EB6D33957D6040965F0663448E4540
44616	55124	132.31584100000001	132.383196	43.139045000000003	43.067574	Прибрежная	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
44510	55124	132.31584100000001	132.383196	43.139045000000003	43.067574	Карла Маркса	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
44335	55124	132.31584100000001	132.383196	43.139045000000003	43.067574	Гагарина	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
44508	55124	132.31584100000001	132.383196	43.139045000000003	43.067574	Аллея Труда	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
43055	55124	132.31584100000001	132.383196	43.139045000000003	43.067574	Академика Курчатова	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
3854	1306	132.1275	132.202437	43.353918999999998	43.332289000000003	улица Фрунзе	0103000020E61000000100000005000000AE47E17A1484604008E9297288AA4540AE47E17A148460406D37C1374DAD454003D0285D7A8660406D37C1374DAD454003D0285D7A86604008E9297288AA4540AE47E17A1484604008E9297288AA4540
3960	1306	132.171077	132.26515800000001	43.378214	43.353465999999997	улица Кирова	0103000020E610000001000000050000002103797679856040BC1FB75F3EAD45402103797679856040D671FC5069B04540BB48A12C7C886040D671FC5069B04540BB48A12C7C886040BC1FB75F3EAD45402103797679856040BC1FB75F3EAD4540
1291	1306	132.17892800000001	132.18155100000001	43.353945000000003	43.352601	площадь Ленина	0103000020E61000000100000005000000D78A36C7B9856040B9C4910722AD4540D78A36C7B985604097CADB114EAD4540CCF10A44CF85604097CADB114EAD4540CCF10A44CF856040B9C4910722AD4540D78A36C7B9856040B9C4910722AD4540
44729	1306	132.13801000000001	132.156632	43.354672000000001	43.351256999999997	Щорса	0103000020E61000000100000005000000AC90F2936A846040DBBE47FDF5AC4540AC90F2936A846040496760E465AD45403AB01C2103856040496760E465AD45403AB01C2103856040DBBE47FDF5AC4540AC90F2936A846040DBBE47FDF5AC4540
44751	1306	132.17225400000001	132.17415800000001	43.368633000000003	43.358303999999997	Чайковского	0103000020E610000001000000050000005E13D21A838560405303CDE7DCAD45405E13D21A83856040FA9CBB5D2FAF4540C74ACCB392856040FA9CBB5D2FAF4540C74ACCB3928560405303CDE7DCAD45405E13D21A838560405303CDE7DCAD4540
44445	1306	132.167879	132.17460700000001	43.357726999999997	43.355196999999997	Хмельницкого	0103000020E61000000100000005000000EDD5C7435F8560409351651877AD4540EDD5C7435F856040B6F292FFC9AD4540E3546B6196856040B6F292FFC9AD4540E3546B61968560409351651877AD4540EDD5C7435F8560409351651877AD4540
44680	1306	132.1275	132.202437	43.353918999999998	43.332289000000003	Фрунзе	0103000020E61000000100000005000000AE47E17A1484604008E9297288AA4540AE47E17A148460406D37C1374DAD454003D0285D7A8660406D37C1374DAD454003D0285D7A86604008E9297288AA4540AE47E17A1484604008E9297288AA4540
44827	1306	132.047541	132.33355499999999	43.479103000000002	43.309058	Стрельникова	0103000020E610000001000000050000000307B47485816040994869368FA745400307B474858160402F35423F53BD45405A0D897BAC8A60402F35423F53BD45405A0D897BAC8A6040994869368FA745400307B47485816040994869368FA74540
44829	1306	132.047541	132.33355499999999	43.479103000000002	43.309058	Силина	0103000020E610000001000000050000000307B47485816040994869368FA745400307B474858160402F35423F53BD45405A0D897BAC8A60402F35423F53BD45405A0D897BAC8A6040994869368FA745400307B47485816040994869368FA74540
44734	1306	132.148574	132.16300100000001	43.348005999999998	43.343895000000003	Севастопольская	0103000020E6100000010000000500000026E1421EC1846040042159C004AC454026E1421EC1846040E867EA758BAC4540E486DF4D37856040E867EA758BAC4540E486DF4D37856040042159C004AC454026E1421EC1846040042159C004AC4540
44650	1306	132.08242200000001	132.108869	43.336401000000002	43.330368	Сахалинская	0103000020E61000000100000005000000124F7633A38260408DD2A57F49AA4540124F7633A3826040BDAB1E300FAB45408B51D7DA7B836040BDAB1E300FAB45408B51D7DA7B8360408DD2A57F49AA4540124F7633A38260408DD2A57F49AA4540
44674	1306	132.09911299999999	132.10120599999999	43.331364999999998	43.327837000000002	Ремзаводская	0103000020E6100000010000000500000078B306EF2B8360409AB51490F6A9454078B306EF2B836040FF04172B6AAA454016855D143D836040FF04172B6AAA454016855D143D8360409AB51490F6A9454078B306EF2B8360409AB51490F6A94540
44666	1306	132.17732000000001	132.17816500000001	43.353256999999999	43.343671999999998	Первомайская	0103000020E61000000100000005000000A81DFE9AAC8560408446B071FDAB4540A81DFE9AAC856040A20A7F8637AD454057091687B3856040A20A7F8637AD454057091687B38560408446B071FDAB4540A81DFE9AAC8560408446B071FDAB4540
1481	1306	132.17586499999999	132.175937	43.353276000000001	43.348989000000003	Партизанская улица	0103000020E610000001000000050000005AF0A2AFA0856040F6D4EAABABAC45405AF0A2AFA0856040193BE12538AD454001A5A146A1856040193BE12538AD454001A5A146A1856040F6D4EAABABAC45405AF0A2AFA0856040F6D4EAABABAC4540
44876	1306	132.047541	132.33355499999999	43.479103000000002	43.309058	Мухина	0103000020E610000001000000050000000307B47485816040994869368FA745400307B474858160402F35423F53BD45405A0D897BAC8A60402F35423F53BD45405A0D897BAC8A6040994869368FA745400307B47485816040994869368FA74540
44683	1306	132.28383400000001	132.286933	43.459167999999998	43.454901	Михайловская	0103000020E61000000100000005000000C66F0A2B1589604077F52A323ABA4540C66F0A2B1589604053AF5B04C6BA454095641D8E2E89604053AF5B04C6BA454095641D8E2E89604077F52A323ABA4540C66F0A2B1589604077F52A323ABA4540
44635	1306	132.18547699999999	132.201458	43.357602	43.357334000000002	Лазо	0103000020E610000001000000050000002025766DEF856040DBDFD91EBDAD45402025766DEF856040FA7DFFE6C5AD454090300C5872866040FA7DFFE6C5AD454090300C5872866040DBDFD91EBDAD45402025766DEF856040DBDFD91EBDAD4540
44682	1306	132.18543199999999	132.18547699999999	43.357550000000003	43.353164999999997	Кооперативная	0103000020E6100000010000000500000038F4160FEF856040C18BBE8234AD454038F4160FEF856040A857CA32C4AD45402025766DEF856040A857CA32C4AD45402025766DEF856040C18BBE8234AD454038F4160FEF856040C18BBE8234AD4540
44685	1306	132.171077	132.26515800000001	43.378214	43.353465999999997	Кирова	0103000020E610000001000000050000002103797679856040BC1FB75F3EAD45402103797679856040D671FC5069B04540BB48A12C7C886040D671FC5069B04540BB48A12C7C886040BC1FB75F3EAD45402103797679856040BC1FB75F3EAD4540
3769	1306	132.09853799999999	132.12137300000001	43.341213000000003	43.338256000000001	Карагандинская улица	0103000020E6100000010000000500000039ED29392783604080D6FCF84BAB454039ED2939278360402BFC19DEACAB4540C233A149E28360402BFC19DEACAB4540C233A149E283604080D6FCF84BAB454039ED29392783604080D6FCF84BAB4540
44918	1306	132.20542900000001	132.20806999999999	43.363396999999999	43.362065999999999	Калинина	0103000020E61000000100000005000000CD94D6DF928660402C7FBE2D58AE4540CD94D6DF92866040753BFBCA83AE4540EBA86A82A8866040753BFBCA83AE4540EBA86A82A88660402C7FBE2D58AE4540CD94D6DF928660402C7FBE2D58AE4540
4042	1306	132.19050799999999	132.19782000000001	43.374766999999999	43.346327000000002	Интернациональная улица	0103000020E610000001000000050000000BB43BA418866040645C717154AC45400BB43BA4188660405D4F745DF8AF4540D5CF9B8A548660405D4F745DF8AF4540D5CF9B8A54866040645C717154AC45400BB43BA418866040645C717154AC4540
44921	1306	132.18879200000001	132.205051	43.373475999999997	43.367958000000002	Достоевского	0103000020E61000000100000005000000E33785950A8660409A266C3F19AF4540E33785950A866040A2EBC20FCEAF454063601DC78F866040A2EBC20FCEAF454063601DC78F8660409A266C3F19AF4540E33785950A8660409A266C3F19AF4540
3817	1306	132.11546200000001	132.127149	43.349907000000002	43.345179999999999	Донбасская улица	0103000020E61000000100000005000000C93D5DDDB1836040DC9DB5DB2EAC4540C93D5DDDB18360401CD2A8C0C9AC45400397C79A118460401CD2A8C0C9AC45400397C79A11846040DC9DB5DB2EAC4540C93D5DDDB1836040DC9DB5DB2EAC4540
4223	1306	132.31002000000001	132.31912800000001	43.370716999999999	43.367657000000001	Днепростроевская улица	0103000020E61000000100000005000000642310AFEB8960409F9273620FAF4540642310AFEB8960401E8997A773AF45409D67EC4B368A60401E8997A773AF45409D67EC4B368A60409F9273620FAF4540642310AFEB8960409F9273620FAF4540
44651	1306	132.31002000000001	132.31912800000001	43.370716999999999	43.367657000000001	Днепростроевская	0103000020E61000000100000005000000642310AFEB8960409F9273620FAF4540642310AFEB8960401E8997A773AF45409D67EC4B368A60401E8997A773AF45409D67EC4B368A60409F9273620FAF4540642310AFEB8960409F9273620FAF4540
345	1306	132.16443899999999	132.16640599999999	43.358428000000004	43.358035000000001	Дальнереченский переулок	0103000020E61000000100000005000000FBE593154385604064E94317D4AD4540FBE593154385604040FCFCF7E0AD454076FBAC325385604040FCFCF7E0AD454076FBAC325385604064E94317D4AD4540FBE593154385604064E94317D4AD4540
44630	1306	132.071687	132.084408	43.345213000000001	43.315631000000003	Гагарина	0103000020E610000001000000050000008C1189424B826040494DBB9866A845408C1189424B826040B89388F02FAC4540AAF06778B3826040B89388F02FAC4540AAF06778B3826040494DBB9866A845408C1189424B826040494DBB9866A84540
44623	1306	132.282872	132.28733700000001	43.383533999999997	43.377650000000003	Ворошилова	0103000020E61000000100000005000000889E94490D896040CEAACFD556B04540889E94490D896040B87361A417B14540C93D5DDD31896040B87361A417B14540C93D5DDD31896040CEAACFD556B04540889E94490D896040CEAACFD556B04540
4068	1306	132.18863899999999	132.19181	43.378633000000001	43.370742999999997	Волочаевская улица	0103000020E6100000010000000500000001F8A75409866040471CB28174AF454001F8A75409866040DB17D00B77B0454077A1B94E23866040DB17D00B77B0454077A1B94E23866040471CB28174AF454001F8A75409866040471CB28174AF4540
45134	1306	132.23433600000001	132.23955599999999	43.388133000000003	43.381214999999997	Виноградная	0103000020E61000000100000005000000D10836AE7F87604050DF32A7CBB04540D10836AE7F876040CBBF9657AEB14540F0315871AA876040CBBF9657AEB14540F0315871AA87604050DF32A7CBB04540D10836AE7F87604050DF32A7CBB04540
44681	1306	132.16065699999999	132.16551699999999	43.346668000000001	43.342230000000001	Ватутина	0103000020E61000000100000005000000F31B261A24856040E4DA5031CEAB4540F31B261A24856040ED48F59D5FAC4540D3BD4EEA4B856040ED48F59D5FAC4540D3BD4EEA4B856040E4DA5031CEAB4540F31B261A24856040E4DA5031CEAB4540
44735	1306	132.22994399999999	132.239879	43.376503	43.374386999999999	Бабушкина	0103000020E610000001000000050000002AFD84B35B8760401686C8E9EBAF45402AFD84B35B87604046EC134031B04540E97FB916AD87604046EC134031B04540E97FB916AD8760401686C8E9EBAF45402AFD84B35B8760401686C8E9EBAF4540
3768	1306	132.08296100000001	132.1275	43.332289000000003	43.329017	1-я Рабочая улица	0103000020E61000000100000005000000FEBAD39DA7826040FD69A33A1DAA4540FEBAD39DA782604008E9297288AA4540AE47E17A1484604008E9297288AA4540AE47E17A14846040FD69A33A1DAA4540FEBAD39DA7826040FD69A33A1DAA4540
44788	55291	132.189708	132.197541	43.401378999999999	43.394933000000002	Авиационная 	0103000020E6100000010000000500000044F98216128660403B8E1F2A8DB2454044F98216128660408D26176360B34540D0D38041528660408D26176360B34540D0D38041528660403B8E1F2A8DB2454044F98216128660403B8E1F2A8DB24540
44806	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Таежная	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44351	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Садовая	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44465	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Мира	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44560	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Луговая	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
42958	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Ломоносова	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44447	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Ленинская	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44610	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Клиновая	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44455	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Калининская	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44464	11414	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	25 лет Арсеньеву	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44499	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Советская	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44513	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Сазыкина	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
59496	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Островского	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44450	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Олега Кошевого	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
59471	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Октябрьская	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44469	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Кирзаводская	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44511	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Калининская	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44512	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	Жуковского	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
59485	55260	133.23792499999999	133.29827399999999	44.185927999999997	44.125478000000001	9 Мая	0103000020E61000000100000005000000D3BCE3149DA760400A2FC1A90F104640D3BCE3149DA7604091B41B7DCC174640E867EA758BA9604091B41B7DCC174640E867EA758BA960400A2FC1A90F104640D3BCE3149DA760400A2FC1A90F104640
44889	55294	133.22132400000001	133.24415099999999	43.249122	43.196520999999997	Советская	0103000020E610000001000000050000003DBA111615A7604015FDA199279945403DBA111615A76040685BCD3AE39F45402409C215D0A76040685BCD3AE39F45402409C215D0A7604015FDA199279945403DBA111615A7604015FDA19927994540
45092	11702	132.83280300000001	132.91310300000001	43.201830999999999	43.116174000000001	Тигровая	0103000020E6100000010000000500000058207A52A69A6040A05225CADE8E454058207A52A69A6040D4282499D5994540255CC823389D6040D4282499D5994540255CC823389D6040A05225CADE8E454058207A52A69A6040A05225CADE8E4540
44915	55297	133.21164999999999	133.23218499999999	43.209158000000002	43.191650000000003	Луговая	0103000020E61000000100000005000000598638D6C5A66040A323B9FC87984540598638D6C5A6604030D978B0C59A4540E5B33C0F6EA7604030D978B0C59A4540E5B33C0F6EA76040A323B9FC87984540598638D6C5A66040A323B9FC87984540
45044	55309	133.00887299999999	133.04164299999999	43.299098999999998	43.281768999999997	Советская	0103000020E61000000100000005000000289A07B048A060406803B00111A44540289A07B048A0604016A243E048A645406F63B32355A1604016A243E048A645406F63B32355A160406803B00111A44540289A07B048A060406803B00111A44540
44914	55296	133.21084999999999	133.248786	43.286375999999997	43.254828000000003	Кирова	0103000020E6100000010000000500000092CB7F48BFA66040740D33349EA0454092CB7F48BFA66040FD2D01F8A7A445407CB60E0EF6A76040FD2D01F8A7A445407CB60E0EF6A76040740D33349EA0454092CB7F48BFA66040740D33349EA04540
45063	55311	132.53489500000001	133.00569300000001	42.998998999999998	42.737496999999998	Светлая	0103000020E6100000010000000500000068791EDC1D916040F5F23B4D665E454068791EDC1D9160404CDE0033DF7F45401E1A16A32EA060404CDE0033DF7F45401E1A16A32EA06040F5F23B4D665E454068791EDC1D916040F5F23B4D665E4540
44568	55281	132.66364100000001	132.72727800000001	42.893244000000003	42.855100999999998	Луговая	0103000020E610000001000000050000001DE90C8C3C95604071E316F3736D45401DE90C8C3C95604093ACC3D155724540362383DC4597604093ACC3D155724540362383DC4597604071E316F3736D45401DE90C8C3C95604071E316F3736D4540
45018	55307	132.67684700000001	132.706221	42.933442999999997	42.922102000000002	Комарова	0103000020E61000000100000005000000AA2C0ABBA8956040C1C9367007764540AA2C0ABBA89560400ED76A0F7B774540F357C85C999660400ED76A0F7B774540F357C85C99966040C1C9367007764540AA2C0ABBA8956040C1C9367007764540
44338	55248	133.37516099999999	133.46794800000001	45.513890000000004	45.455592000000003	Будника	0103000020E610000001000000050000008237A45101AC6040DD28B2D650BA46408237A45101AC6040E8DEC325C7C146405187156EF9AE6040E8DEC325C7C146405187156EF9AE6040DD28B2D650BA46408237A45101AC6040DD28B2D650BA4640
44388	55255	132.335936	132.38544200000001	43.356907999999997	43.307149000000003	Советская	0103000020E6100000010000000500000092B1DAFCBF8A6040E3FF8EA850A7454092B1DAFCBF8A604023D74D29AFAD45402810768A558C604023D74D29AFAD45402810768A558C6040E3FF8EA850A7454092B1DAFCBF8A6040E3FF8EA850A74540
44800	460	132.678967	132.70105599999999	43.348785999999997	43.332289000000003	Чапаева	0103000020E6100000010000000500000006820019BA95604008E9297288AA454006820019BA956040BDA60705A5AC45404415FE0C6F966040BDA60705A5AC45404415FE0C6F96604008E9297288AA454006820019BA95604008E9297288AA4540
44383	28253	132.322326	132.46548200000001	43.008889000000003	42.884895	Комсомольская	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
43027	28253	132.322326	132.46548200000001	43.008889000000003	42.884895	Карла Маркса	0103000020E61000000100000005000000D1949D7E508A60406CB2463D44714540D1949D7E508A6040A7255646238145400EDC813AE58E6040A7255646238145400EDC813AE58E60406CB2463D44714540D1949D7E508A60406CB2463D44714540
44969	591	132.47149200000001	132.48052000000001	43.350647000000002	43.34198	Центральная	0103000020E610000001000000050000006C0A6476168F60406BF12900C6AB45406C0A6476168F604063B83A00E2AC45405EA27A6B608F604063B83A00E2AC45405EA27A6B608F60406BF12900C6AB45406C0A6476168F60406BF12900C6AB4540
44541	55275	132.44353599999999	132.480322	43.315342000000001	43.245707000000003	Школьная	0103000020E6100000010000000500000028D36872318E6040FBB2B453739F454028D36872318E604012876C205DA8454094313ECC5E8F604012876C205DA8454094313ECC5E8F6040FBB2B453739F454028D36872318E6040FBB2B453739F4540
44869	55275	132.44353599999999	132.480322	43.315342000000001	43.245707000000003	Пушкинская	0103000020E6100000010000000500000028D36872318E6040FBB2B453739F454028D36872318E604012876C205DA8454094313ECC5E8F604012876C205DA8454094313ECC5E8F6040FBB2B453739F454028D36872318E6040FBB2B453739F4540
44611	55275	132.44353599999999	132.480322	43.315342000000001	43.245707000000003	Маяковского	0103000020E6100000010000000500000028D36872318E6040FBB2B453739F454028D36872318E604012876C205DA8454094313ECC5E8F604012876C205DA8454094313ECC5E8F6040FBB2B453739F454028D36872318E6040FBB2B453739F4540
44543	1068	132.436125	132.47599199999999	43.242213999999997	43.228794999999998	Ленинская	0103000020E61000000100000005000000FA7E6ABCF48D6040813E9127499D4540FA7E6ABCF48D604011514CDE009F45400B2593533B8F604011514CDE009F45400B2593533B8F6040813E9127499D4540FA7E6ABCF48D6040813E9127499D4540
44900	28675	132.40388400000001	132.42208400000001	42.86627	42.854824000000001	Центральная	0103000020E61000000100000005000000166C239EEC8C6040FFEA71DF6A6D4540166C239EEC8C6040C2C073EFE16E454047054EB6818D6040C2C073EFE16E454047054EB6818D6040FFEA71DF6A6D4540166C239EEC8C6040FFEA71DF6A6D4540
44612	55282	132.375956	132.40553700000001	43.162098999999998	43.134315000000001	Школьная	0103000020E610000001000000050000008597E0D4078C60405E2EE23B319145408597E0D4078C60406EDBF7A8BF9445402D0ABB28FA8C60406EDBF7A8BF9445402D0ABB28FA8C60405E2EE23B319145408597E0D4078C60405E2EE23B31914540
44602	859	132.56529399999999	132.62847199999999	43.230725999999997	43.204374000000001	Почтовая	0103000020E61000000100000005000000005471E3169260408C135FED289A4540005471E3169260401F2BF86D889D454074CE4F711C9460401F2BF86D889D454074CE4F711C9460408C135FED289A4540005471E3169260408C135FED289A4540
44910	331	132.42733899999999	132.48105000000001	43.477258999999997	43.424287	Зальпе	0103000020E61000000100000005000000C5A9D6C2AC8D6040198F52094FB64540C5A9D6C2AC8D60405F5CAAD216BD4540B537F8C2648F60405F5CAAD216BD4540B537F8C2648F6040198F52094FB64540C5A9D6C2AC8D6040198F52094FB64540
44386	28704	132.320494	132.369731	42.894010000000002	42.866481	Морская	0103000020E610000001000000050000000E12A27C418A60407DCD72D9E86E45400E12A27C418A6040032670EB6E724540282A1BD6D48B6040032670EB6E724540282A1BD6D48B60407DCD72D9E86E45400E12A27C418A60407DCD72D9E86E4540
44429	28704	132.320494	132.369731	42.894010000000002	42.866481	Ленина	0103000020E610000001000000050000000E12A27C418A60407DCD72D9E86E45400E12A27C418A6040032670EB6E724540282A1BD6D48B6040032670EB6E724540282A1BD6D48B60407DCD72D9E86E45400E12A27C418A60407DCD72D9E86E4540
44535	55273	132.320494	132.369731	42.894010000000002	42.866481	Морская	0103000020E610000001000000050000000E12A27C418A60407DCD72D9E86E45400E12A27C418A6040032670EB6E724540282A1BD6D48B6040032670EB6E724540282A1BD6D48B60407DCD72D9E86E45400E12A27C418A60407DCD72D9E86E4540
43034	15899	132.31584100000001	132.383196	43.139045000000003	43.067574	Маслакова	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
43064	15899	132.31584100000001	132.383196	43.139045000000003	43.067574	Ленина	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
43041	15899	132.31584100000001	132.383196	43.139045000000003	43.067574	Карла Маркса	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
59484	57572	132.31584100000001	132.383196	43.139045000000003	43.067574	Адмирала Макарова	0103000020E610000001000000050000008DB7955E1B8A6040AB07CC43A68845408DB7955E1B8A60400FD6FF39CC914540A8FE4124438C60400FD6FF39CC914540A8FE4124438C6040AB07CC43A68845408DB7955E1B8A6040AB07CC43A6884540
44821	759	132.75582600000001	132.82332600000001	43.193812999999999	43.161276000000001	Смольная	0103000020E61000000100000005000000EEEE01BA2F9860409AD024B1A4944540EEEE01BA2F986040134548DDCE9845404A7EC4AF589A6040134548DDCE9845404A7EC4AF589A60409AD024B1A4944540EEEE01BA2F9860409AD024B1A4944540
44477	3734	132.51849200000001	132.60686799999999	44.355773999999997	44.322023000000002	Октябрьская	0103000020E610000001000000050000009BE7887C97906040A8C7B60C382946409BE7887C9790604030629F008A2D4640A59F70766B93604030629F008A2D4640A59F70766B936040A8C7B60C382946409BE7887C97906040A8C7B60C38294640
44530	3734	132.51849200000001	132.60686799999999	44.355773999999997	44.322023000000002	Ленинская	0103000020E610000001000000050000009BE7887C97906040A8C7B60C382946409BE7887C9790604030629F008A2D4640A59F70766B93604030629F008A2D4640A59F70766B936040A8C7B60C382946409BE7887C97906040A8C7B60C38294640
44528	3734	132.51849200000001	132.60686799999999	44.355773999999997	44.322023000000002	Заводская	0103000020E610000001000000050000009BE7887C97906040A8C7B60C382946409BE7887C9790604030629F008A2D4640A59F70766B93604030629F008A2D4640A59F70766B936040A8C7B60C382946409BE7887C97906040A8C7B60C38294640
44382	3734	132.51849200000001	132.60686799999999	44.355773999999997	44.322023000000002	Буденного	0103000020E610000001000000050000009BE7887C97906040A8C7B60C382946409BE7887C9790604030629F008A2D4640A59F70766B93604030629F008A2D4640A59F70766B936040A8C7B60C382946409BE7887C97906040A8C7B60C38294640
44815	26889	132.40233000000001	132.43120200000001	44.282136000000001	44.249008000000003	Советская	0103000020E6100000010000000500000064062AE3DF8C6040A038807EDF1F464064062AE3DF8C60401B834E081D24464009FF2268CC8D60401B834E081D24464009FF2268CC8D6040A038807EDF1F464064062AE3DF8C6040A038807EDF1F4640
44899	26352	132.571223	132.59688800000001	44.092422999999997	44.074556999999999	Парковая	0103000020E6100000010000000500000023F77475479260400C5872158B09464023F7747547926040F8325184D40B4640FFEBDCB419936040F8325184D40B4640FFEBDCB4199360400C5872158B09464023F77475479260400C5872158B094640
45109	26048	132.58245199999999	132.59792100000001	44.464846000000001	44.450955999999998	Советская	0103000020E61000000100000005000000AC6F6072A3926040ADF71BEDB8394640AC6F6072A392604095D6DF12803B4640EF92382B2293604095D6DF12803B4640EF92382B22936040ADF71BEDB8394640AC6F6072A3926040ADF71BEDB8394640
45052	55310	132.416955	132.48074399999999	44.218167000000001	44.183813999999998	Заводская	0103000020E61000000100000005000000EB1C03B2578D60400246973787174640EB1C03B2578D6040810871E5EC1B4640F1B73D41628F6040810871E5EC1B4640F1B73D41628F60400246973787174640EB1C03B2578D60400246973787174640
44600	26487	132.416955	132.48074399999999	44.218167000000001	44.183813999999998	Постышева	0103000020E61000000100000005000000EB1C03B2578D60400246973787174640EB1C03B2578D6040810871E5EC1B4640F1B73D41628F6040810871E5EC1B4640F1B73D41628F60400246973787174640EB1C03B2578D60400246973787174640
44384	26487	132.416955	132.48074399999999	44.218167000000001	44.183813999999998	Ленинская	0103000020E61000000100000005000000EB1C03B2578D60400246973787174640EB1C03B2578D6040810871E5EC1B4640F1B73D41628F6040810871E5EC1B4640F1B73D41628F60400246973787174640EB1C03B2578D60400246973787174640
44426	26487	132.416955	132.48074399999999	44.218167000000001	44.183813999999998	Кутузова	0103000020E61000000100000005000000EB1C03B2578D60400246973787174640EB1C03B2578D6040810871E5EC1B4640F1B73D41628F6040810871E5EC1B4640F1B73D41628F60400246973787174640EB1C03B2578D60400246973787174640
44863	26487	132.416955	132.48074399999999	44.218167000000001	44.183813999999998	Красноармейская	0103000020E61000000100000005000000EB1C03B2578D60400246973787174640EB1C03B2578D6040810871E5EC1B4640F1B73D41628F6040810871E5EC1B4640F1B73D41628F60400246973787174640EB1C03B2578D60400246973787174640
45117	26427	132.37531799999999	132.39608699999999	44.157950999999997	44.136017000000002	Центральная	0103000020E6100000010000000500000034F3E49A028C60409B594B016911464034F3E49A028C60406CAF05BD37144640DDEBA4BEAC8C60406CAF05BD37144640DDEBA4BEAC8C60409B594B016911464034F3E49A028C60409B594B0169114640
44532	26769	132.44851299999999	132.52437599999999	44.205005999999997	44.183270999999998	Титова	0103000020E61000000100000005000000965AEF375A8E604011A7936C75174640965AEF375A8E6040ECBDF8A23D1A4640D5592DB0C7906040ECBDF8A23D1A4640D5592DB0C790604011A7936C75174640965AEF375A8E604011A7936C75174640
45108	26122	132.777242	132.80165	44.385685000000002	44.373095999999997	Центральная	0103000020E610000001000000050000007C629D2ADF9860405B22179CC12F46407C629D2ADF98604065C746205E314640D49AE61DA799604065C746205E314640D49AE61DA79960405B22179CC12F46407C629D2ADF9860405B22179CC12F4640
44962	26287	132.62832900000001	132.65670600000001	44.150590999999999	44.127425000000002	Ленинская	0103000020E610000001000000050000001C446B451B946040AED85F764F1046401C446B451B9460403509DE9046134640C9224DBC039560403509DE9046134640C9224DBC03956040AED85F764F1046401C446B451B946040AED85F764F104640
44973	26125	132.522794	132.53984500000001	44.412882000000003	44.389690999999999	Комсомольская	0103000020E6100000010000000500000071917BBABA906040D4450A65E131464071917BBABA906040B58D3F51D9344640187D056946916040B58D3F51D9344640187D056946916040D4450A65E131464071917BBABA906040D4450A65E1314640
45011	26404	132.46042399999999	132.48572999999999	44.082808	44.068359000000001	Клубная	0103000020E6100000010000000500000064C91CCBBB8E604092B1DAFCBF08464064C91CCBBB8E604070ECD973990A4640F415A4198B8F604070ECD973990A4640F415A4198B8F604092B1DAFCBF08464064C91CCBBB8E604092B1DAFCBF084640
44597	24474	132.20559	132.24407400000001	44.197716999999997	44.143399000000002	проспект Ленина	0103000020E610000001000000050000004FCC7A3194866040BAA3FFE55A1246404FCC7A31948660407E6E68CA4E194640BAF94674CF8760407E6E68CA4E194640BAF94674CF876040BAA3FFE55A1246404FCC7A3194866040BAA3FFE55A124640
44862	24474	132.20559	132.24407400000001	44.197716999999997	44.143399000000002	Школьная	0103000020E610000001000000050000004FCC7A3194866040BAA3FFE55A1246404FCC7A31948660407E6E68CA4E194640BAF94674CF8760407E6E68CA4E194640BAF94674CF876040BAA3FFE55A1246404FCC7A3194866040BAA3FFE55A124640
44598	24474	132.20559	132.24407400000001	44.197716999999997	44.143399000000002	Советская	0103000020E610000001000000050000004FCC7A3194866040BAA3FFE55A1246404FCC7A31948660407E6E68CA4E194640BAF94674CF8760407E6E68CA4E194640BAF94674CF876040BAA3FFE55A1246404FCC7A3194866040BAA3FFE55A124640
44476	24474	132.20559	132.24407400000001	44.197716999999997	44.143399000000002	Матросова	0103000020E610000001000000050000004FCC7A3194866040BAA3FFE55A1246404FCC7A31948660407E6E68CA4E194640BAF94674CF8760407E6E68CA4E194640BAF94674CF876040BAA3FFE55A1246404FCC7A3194866040BAA3FFE55A124640
44529	55270	132.20559	132.24407400000001	44.197716999999997	44.143399000000002	Матросова	0103000020E610000001000000050000004FCC7A3194866040BAA3FFE55A1246404FCC7A31948660407E6E68CA4E194640BAF94674CF8760407E6E68CA4E194640BAF94674CF876040BAA3FFE55A1246404FCC7A3194866040BAA3FFE55A124640
44961	55304	132.090067	132.11259699999999	44.458632000000001	44.442982999999998	Новая	0103000020E610000001000000050000005D6E30D4E18260408CD7BCAAB33846405D6E30D4E182604015731074B43A4640161406659A83604015731074B43A4640161406659A8360408CD7BCAAB33846405D6E30D4E18260408CD7BCAAB3384640
44394	24819	132.04640000000001	132.10177200000001	44.446199999999997	44.402836999999998	Ленинская	0103000020E610000001000000050000001A51DA1B7C816040334FAE29903346401A51DA1B7C816040D3BCE3141D394640C1745AB741836040D3BCE3141D394640C1745AB741836040334FAE29903346401A51DA1B7C816040334FAE2990334640
44396	24819	132.04640000000001	132.10177200000001	44.446199999999997	44.402836999999998	Лазо	0103000020E610000001000000050000001A51DA1B7C816040334FAE29903346401A51DA1B7C816040D3BCE3141D394640C1745AB741836040D3BCE3141D394640C1745AB741836040334FAE29903346401A51DA1B7C816040334FAE2990334640
44599	24819	132.04640000000001	132.10177200000001	44.446199999999997	44.402836999999998	Красноармейская	0103000020E610000001000000050000001A51DA1B7C816040334FAE29903346401A51DA1B7C816040D3BCE3141D394640C1745AB741836040D3BCE3141D394640C1745AB741836040334FAE29903346401A51DA1B7C816040334FAE2990334640
45107	24819	132.04640000000001	132.10177200000001	44.446199999999997	44.402836999999998	Комсомольская	0103000020E610000001000000050000001A51DA1B7C816040334FAE29903346401A51DA1B7C816040D3BCE3141D394640C1745AB741836040D3BCE3141D394640C1745AB741836040334FAE29903346401A51DA1B7C816040334FAE2990334640
44381	24819	132.04640000000001	132.10177200000001	44.446199999999997	44.402836999999998	Волочаевская	0103000020E610000001000000050000001A51DA1B7C816040334FAE29903346401A51DA1B7C816040D3BCE3141D394640C1745AB741836040D3BCE3141D394640C1745AB741836040334FAE29903346401A51DA1B7C816040334FAE2990334640
45010	25501	131.833382	131.843785	44.245502000000002	44.238166	Центральная	0103000020E610000001000000050000006762BA10AB7A6040738236397C1E46406762BA10AB7A6040228D0A9C6C1F46405F7B6649007B6040228D0A9C6C1F46405F7B6649007B6040738236397C1E46406762BA10AB7A6040738236397C1E4640
44816	25618	132.345934	132.38431	44.492277000000001	44.467137000000001	Центральная	0103000020E6100000010000000500000062122EE4118B604033E02C25CB3B464062122EE4118B604058C9C7EE023F4640D3307C444C8C604058C9C7EE023F4640D3307C444C8C604033E02C25CB3B464062122EE4118B604033E02C25CB3B4640
44972	25405	131.95863499999999	131.973232	44.315702999999999	44.307110999999999	Ленинская	0103000020E61000000100000005000000A1B94E23AD7E6040F59ECA694F274640A1B94E23AD7E6040E21FB6F468284640766D6FB7247F6040E21FB6F468284640766D6FB7247F6040F59ECA694F274640A1B94E23AD7E6040F59ECA694F274640
45104	25417	131.81939600000001	131.841072	44.348450999999997	44.330651000000003	Центральная	0103000020E6100000010000000500000025CFF57D387A6040E2B19FC5522A464025CFF57D387A604016A1D80A9A2C46409AB2D30FEA7A604016A1D80A9A2C46409AB2D30FEA7A6040E2B19FC5522A464025CFF57D387A6040E2B19FC5522A4640
44814	25127	131.95452	132.00319099999999	44.457498999999999	44.424734999999998	Первомайская	0103000020E6100000010000000500000018EC866D8B7E6040B83B6BB75D36464018EC866D8B7E6040F279C5538F3A4640871403241A806040F279C5538F3A4640871403241A806040B83B6BB75D36464018EC866D8B7E6040B83B6BB75D364640
45050	25708	132.26146600000001	132.28720200000001	44.388995999999999	44.374428999999999	Юбилейная	0103000020E6100000010000000500000083E0F1ED5D88604045D61A4AED2F464083E0F1ED5D8860402D23F59ECA31464011AB3FC2308960402D23F59ECA31464011AB3FC23089604045D61A4AED2F464083E0F1ED5D88604045D61A4AED2F4640
44404	25609	132.16189600000001	132.21257	44.501857000000001	44.484940000000002	Лазо	0103000020E610000001000000050000004E2B85402E856040D9429083123E46404E2B85402E8560406422A5D93C4046408BC3995FCD8660406422A5D93C4046408BC3995FCD866040D9429083123E46404E2B85402E856040D9429083123E4640
45053	25333	132.15896799999999	132.18711200000001	44.364879999999999	44.351700000000001	Центральная	0103000020E6100000010000000500000089230F441685604069006F81042D464089230F4416856040747B4963B42E46400E164ED2FC856040747B4963B42E46400E164ED2FC85604069006F81042D464089230F441685604069006F81042D4640
44864	25540	132.24451400000001	132.27334099999999	44.301685999999997	44.273868999999998	Колхозная	0103000020E61000000100000005000000412D060FD3876040B131AF230E234640412D060FD38760409DD497A59D264640FDF49F35BF8860409DD497A59D264640FDF49F35BF886040B131AF230E234640412D060FD3876040B131AF230E234640
45088	55313	132.07731100000001	132.09786399999999	44.542929999999998	44.533171000000003	Центральная	0103000020E61000000100000005000000E013EB54798260407B1684F23E444640E013EB54798260403602F1BA7E45464095EEAEB3218360403602F1BA7E45464095EEAEB3218360407B1684F23E444640E013EB54798260407B1684F23E444640
44898	25197	132.152635	132.19946400000001	44.447642000000002	44.412714999999999	Гагарина	0103000020E6100000010000000500000033A7CB62E2846040C9C859D8D334464033A7CB62E2846040742843554C3946405797530262866040742843554C3946405797530262866040C9C859D8D334464033A7CB62E2846040C9C859D8D3344640
45058	24764	132.089528	132.12598199999999	44.155830000000002	44.143250000000002	Павлика Морозова	0103000020E610000001000000050000007102D369DD82604075931804561246407102D369DD8260402BDEC83CF21346404F3C670B088460402BDEC83CF21346404F3C670B0884604075931804561246407102D369DD8260407593180456124640
44444	24683	132.17564999999999	132.21414200000001	44.202117999999999	44.177090999999997	Первомайская	0103000020E610000001000000050000005BB1BFEC9E8560403DB5FAEAAA1646405BB1BFEC9E8560406AF7AB00DF19464067D65240DA8660406AF7AB00DF19464067D65240DA8660403DB5FAEAAA1646405BB1BFEC9E8560403DB5FAEAAA164640
44870	25280	132.077293	132.10830300000001	44.327117999999999	44.315663999999998	Октябрьская	0103000020E61000000100000005000000B6662B2F7982604024438EAD67284640B6662B2F798260406AF7AB00DF294640E161DA37778360406AF7AB00DF294640E161DA377783604024438EAD67284640B6662B2F7982604024438EAD67284640
44956	23377	130.77668499999999	130.78822	42.763899000000002	42.751739000000001	Молодежная	0103000020E610000001000000050000006649809ADA5860405A10CAFB386045406649809ADA5860403B394371C7614540B3412619395960403B394371C7614540B3412619395960405A10CAFB386045406649809ADA5860405A10CAFB38604540
44796	55292	130.639081	130.65660700000001	42.434108000000002	42.414361999999997	Вокзальная	0103000020E61000000100000005000000D74FFF5973546040425A63D009354540D74FFF59735460404B77D7D99037454064EAAEEC025560404B77D7D99037454064EAAEEC02556040425A63D009354540D74FFF5973546040425A63D009354540
44971	24289	131.53042600000001	131.54652300000001	43.243125999999997	43.233274999999999	Комарова	0103000020E61000000100000005000000575EF23FF9706040B9FC87F4DB9D4540575EF23FF97060405567B5C01E9F45406170CD1D7D7160405567B5C01E9F45406170CD1D7D716040B9FC87F4DB9D4540575EF23FF9706040B9FC87F4DB9D4540
44793	23713	131.368064	131.435788	42.909933000000002	42.851995000000002	Нерпинская	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
44812	23713	131.368064	131.435788	42.909933000000002	42.851995000000002	Набережная	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
44378	23713	131.368064	131.435788	42.909933000000002	42.851995000000002	Молодежная	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
44443	23713	131.368064	131.435788	42.909933000000002	42.851995000000002	Ленинская	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
44380	55254	131.368064	131.435788	42.909933000000002	42.851995000000002	Молодежная	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
44551	55254	131.368064	131.435788	42.909933000000002	42.851995000000002	Героев Хасана	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
44608	55254	131.368064	131.435788	42.909933000000002	42.851995000000002	50 лет Октября	0103000020E61000000100000005000000B85A272EC76B604082AD122C0E6D4540B85A272EC76B60408D463EAF78744540A8FFACF9F16D60408D463EAF78744540A8FFACF9F16D604082AD122C0E6D4540B85A272EC76B604082AD122C0E6D4540
44527	55269	131.55654000000001	131.60701599999999	43.111311000000001	43.055717999999999	Центральная	0103000020E610000001000000050000004F5DF92CCF71604036E675C4218745404F5DF92CCF716040B05758703F8E4540C284D1AC6C736040B05758703F8E4540C284D1AC6C73604036E675C4218745404F5DF92CCF71604036E675C421874540
44548	55278	130.788884	130.82382000000001	42.666715000000003	42.643123000000003	Портовая	0103000020E61000000100000005000000CE8AA8893E5960401827BEDA51524540CE8AA8893E5960405760C8EA565545404EB9C2BB5C5A60405760C8EA565545404EB9C2BB5C5A60401827BEDA51524540CE8AA8893E5960401827BEDA51524540
45156	55330	131.54768200000001	131.562253	43.028927000000003	43.018664999999999	Лазо	0103000020E6100000010000000500000074D3669C86716040384A5E9D6382454074D3669C86716040577C43E1B38345407EE200FAFD716040577C43E1B38345407EE200FAFD716040384A5E9D6382454074D3669C86716040384A5E9D63824540
44379	55253	130.76770200000001	130.80082300000001	42.727880999999996	42.700046	Ленина	0103000020E610000001000000050000005DE2C803915860400AD9791B9B5945405DE2C803915860409C3061342B5D45404F5C8E57A05960409C3061342B5D45404F5C8E57A05960400AD9791B9B5945405DE2C803915860400AD9791B9B594540
44549	55279	131.05132699999999	131.094797	42.664918999999998	42.6267	Нагорная	0103000020E61000000100000005000000DB4C8578A46160409C33A2B437504540DB4C8578A461604098BED7101C55454049D8B7930863604098BED7101C55454049D8B793086360409C33A2B437504540DB4C8578A46160409C33A2B437504540
44391	23591	131.05132699999999	131.094797	42.664918999999998	42.6267	Строительная	0103000020E61000000100000005000000DB4C8578A46160409C33A2B437504540DB4C8578A461604098BED7101C55454049D8B7930863604098BED7101C55454049D8B793086360409C33A2B437504540DB4C8578A46160409C33A2B437504540
44795	24373	131.58428000000001	131.62054499999999	43.310310999999999	43.293049000000003	Центральная	0103000020E610000001000000050000009F76F86BB272604011902FA182A545409F76F86BB2726040664B5645B8A7454048163081DB736040664B5645B8A7454048163081DB73604011902FA182A545409F76F86BB272604011902FA182A54540
44792	23520	130.89386099999999	130.93846300000001	42.696559999999998	42.685222000000003	Новая	0103000020E610000001000000050000006F4562829A5C6040F73FC05AB55745406F4562829A5C6040D3D9C9E02859454032B08EE3075E6040D3D9C9E02859454032B08EE3075E6040F73FC05AB55745406F4562829A5C6040F73FC05AB5574540
44861	24064	131.47974300000001	131.49565200000001	42.981912000000001	42.957504	Переулок Школьный	0103000020E6100000010000000500000085EFFD0D5A6F604004E5B67D8F7A454085EFFD0D5A6F604065C6DB4AAF7D45404E469561DC6F604065C6DB4AAF7D45404E469561DC6F604004E5B67D8F7A454085EFFD0D5A6F604004E5B67D8F7A4540
44596	24201	131.46964600000001	131.515343	43.202238000000001	43.177793000000001	Школьная	0103000020E6100000010000000500000050560C57076F6040973AC8EBC196454050560C57076F604015014EEFE29945401F679AB07D70604015014EEFE29945401F679AB07D706040973AC8EBC196454050560C57076F6040973AC8EBC1964540
44526	24201	131.46964600000001	131.515343	43.202238000000001	43.177793000000001	Восточная Слобода	0103000020E6100000010000000500000050560C57076F6040973AC8EBC196454050560C57076F604015014EEFE29945401F679AB07D70604015014EEFE29945401F679AB07D706040973AC8EBC196454050560C57076F6040973AC8EBC1964540
44811	23677	131.12469300000001	131.15528900000001	42.659514999999999	42.638267999999997	Набережная	0103000020E6100000010000000500000049A12C7CFD636040AA0A0DC4B251454049A12C7CFD636040581CCEFC6A544540B70DA320F8646040581CCEFC6A544540B70DA320F8646040AA0A0DC4B251454049A12C7CFD636040AA0A0DC4B2514540
45101	23230	131.973645	131.98896199999999	45.245871000000001	45.226315999999997	Пограничная	0103000020E610000001000000050000003F1D8F19287F6040E04735ECF79C46403F1D8F19287F6040750470B3789F464093DFA293A57F6040750470B3789F464093DFA293A57F6040E04735ECF79C46403F1D8F19287F6040E04735ECF79C4640
44959	23308	131.77901600000001	131.80111500000001	45.187674999999999	45.178654000000002	Рабочая	0103000020E61000000100000005000000F261F6B2ED78604059A65F22DE964640F261F6B2ED7860406EA301BC05984640B9AAECBBA27960406EA301BC05984640B9AAECBBA279604059A65F22DE964640F261F6B2ED78604059A65F22DE964640
44957	23122	131.971732	132.00478100000001	45.061236000000001	45.031278999999998	Ленина	0103000020E61000000100000005000000410FB56D187F60409A0645F300844640410FB56D187F60403FABCC94D68746408DD47B2A278060403FABCC94D68746408DD47B2A278060409A0645F300844640410FB56D187F60409A0645F300844640
45049	23236	131.840677	131.86947699999999	45.143540000000002	45.127943999999999	Ленина	0103000020E61000000100000005000000FBAF73D3E67A604016DC0F7860904640FBAF73D3E67A60407CD5CA845F924640F9F36DC1D27B60407CD5CA845F924640F9F36DC1D27B604016DC0F7860904640FBAF73D3E67A604016DC0F7860904640
45106	22437	131.958742	131.97353799999999	44.769024999999999	44.756954999999998	Центральная	0103000020E61000000100000005000000A7E9B303AE7E604097C5C4E6E3604640A7E9B303AE7E6040386744696F62464039ED2939277F6040386744696F62464039ED2939277F604097C5C4E6E3604640A7E9B303AE7E604097C5C4E6E3604640
44960	22966	132.00487100000001	132.02122900000001	44.921444999999999	44.914717000000003	Советская	0103000020E610000001000000050000005D363AE727806040310C5872157546405D363AE7278060400708E6E8F1754640429770E8AD8060400708E6E8F1754640429770E8AD806040310C5872157546405D363AE727806040310C587215754640
44858	22528	131.84275199999999	131.86963800000001	44.663705	44.646552999999997	Пролетарская	0103000020E610000001000000050000006FD40AD3F77A6040BA10AB3FC25246406FD40AD3F77A604089981249F45446407C2B1213D47B604089981249F45446407C2B1213D47B6040BA10AB3FC25246406FD40AD3F77A6040BA10AB3FC2524640
44931	22869	132.09039000000001	132.10612	44.895923000000003	44.883904999999999	Жданова	0103000020E6100000010000000500000056BC9179E4826040ACE28DCC2371464056BC9179E4826040FB5DD89AAD724640732EC55565836040FB5DD89AAD724640732EC55565836040ACE28DCC2371464056BC9179E4826040ACE28DCC23714640
44813	23163	131.98775800000001	132.02364600000001	45.108741999999999	45.089934999999997	Калинина	0103000020E61000000100000005000000994BAAB69B7F604004E275FD828B4640994BAAB69B7F6040CFD90242EB8D4640CD9541B5C1806040CFD90242EB8D4640CD9541B5C180604004E275FD828B4640994BAAB69B7F604004E275FD828B4640
44901	22694	131.92793	131.96060199999999	44.584809	44.560369999999999	Ленинская	0103000020E61000000100000005000000465F419AB17D60406BD44334BA474640465F419AB17D604007B47405DB4A46401CCF6740BD7E604007B47405DB4A46401CCF6740BD7E60406BD44334BA474640465F419AB17D60406BD44334BA474640
44903	22911	131.98535000000001	132.004997	44.949781000000002	44.932637999999997	Почтовая	0103000020E61000000100000005000000A323B9FC877F6040E08096AE60774640A323B9FC877F60405CAE7E6C9279464080F277EF288060405CAE7E6C9279464080F277EF28806040E08096AE60774640A323B9FC877F6040E08096AE60774640
45013	22838	132.031407	132.045511	44.902473000000001	44.887991999999997	Новая	0103000020E61000000100000005000000B2BB404901816040088ECBB8A9714640B2BB404901816040F2423A3C8473464077137CD374816040F2423A3C8473464077137CD374816040088ECBB8A9714640B2BB404901816040088ECBB8A9714640
45051	23023	131.77221599999999	131.79497900000001	45.001964000000001	44.978811	Советская	0103000020E61000000100000005000000552E54FEB578604087FBC8AD497D4640552E54FEB57860407AE2395B4080464038C0CC77707960407AE2395B4080464038C0CC777079604087FBC8AD497D4640552E54FEB578604087FBC8AD497D4640
44897	22154	132.018103	132.06115	44.762689000000002	44.707585000000002	Трактовая	0103000020E61000000100000005000000B41EBE4C94806040F1113125925A4640B41EBE4C948060406D020CCB9F614640D044D8F0F48160406D020CCB9F614640D044D8F0F4816040F1113125925A4640B41EBE4C94806040F1113125925A4640
44390	22154	132.018103	132.06115	44.762689000000002	44.707585000000002	Пионерская	0103000020E61000000100000005000000B41EBE4C94806040F1113125925A4640B41EBE4C948060406D020CCB9F614640D044D8F0F48160406D020CCB9F614640D044D8F0F4816040F1113125925A4640B41EBE4C94806040F1113125925A4640
44524	22154	132.018103	132.06115	44.762689000000002	44.707585000000002	Мира	0103000020E61000000100000005000000B41EBE4C94806040F1113125925A4640B41EBE4C948060406D020CCB9F614640D044D8F0F48160406D020CCB9F614640D044D8F0F4816040F1113125925A4640B41EBE4C94806040F1113125925A4640
44544	22154	132.018103	132.06115	44.762689000000002	44.707585000000002	Кирова	0103000020E61000000100000005000000B41EBE4C94806040F1113125925A4640B41EBE4C948060406D020CCB9F614640D044D8F0F48160406D020CCB9F614640D044D8F0F4816040F1113125925A4640B41EBE4C94806040F1113125925A4640
42663	22805	131.94363300000001	131.99852899999999	44.910670000000003	44.878374000000001	Столетия	0103000020E61000000100000005000000A54DD53D327E60400FD4298F6E704640A54DD53D327E604063B9A5D59074464071E316F3F37F604063B9A5D59074464071E316F3F37F60400FD4298F6E704640A54DD53D327E60400FD4298F6E704640
45102	23060	131.57638299999999	131.59103500000001	44.886477999999997	44.869706000000001	Сидельникова	0103000020E610000001000000050000000DDFC2BA717260404791B586526F46400DDFC2BA71726040CE4F711C7871464053793BC2E9726040CE4F711C7871464053793BC2E97260404791B586526F46400DDFC2BA717260404791B586526F4640
44896	22500	132.08004199999999	132.09634600000001	44.665956000000001	44.653202999999998	Молодежная	0103000020E61000000100000005000000CE893DB48F8260401553E9279C534640CE893DB48F8260409949D40B3E55464037E33444158360409949D40B3E55464037E33444158360401553E9279C534640CE893DB48F8260401553E9279C534640
44605	22392	132.04054300000001	132.07990699999999	44.734324000000001	44.707706999999999	Березюка	0103000020E610000001000000050000009E62D5204C8160403C139A24965A46409E62D5204C8160407E552E54FE5D464016F71F998E8260407E552E54FE5D464016F71F998E8260403C139A24965A46409E62D5204C8160403C139A24965A4640
44932	22647	131.87774099999999	131.89108999999999	44.728848999999997	44.715584999999997	Школьная	0103000020E61000000100000005000000772B4B74167C60400B410E4A985B4640772B4B74167C6040745C8DEC4A5D46405DF92CCF837C6040745C8DEC4A5D46405DF92CCF837C60400B410E4A985B4640772B4B74167C60400B410E4A985B4640
44951	21042	131.686804	131.703531	43.744453999999998	43.721238	Центральная	0103000020E6100000010000000500000062D8614CFA756040F450DB8651DC454062D8614CFA7560402DB0C7444ADF45401C977153837660402DB0C7444ADF45401C97715383766040F450DB8651DC454062D8614CFA756040F450DB8651DC4540
45100	21459	131.93550300000001	131.948466	43.755113999999999	43.745502000000002	Раздольная	0103000020E61000000100000005000000EBC9FCA3EF7D6040228D0A9C6CDF4540EBC9FCA3EF7D604039605793A7E04540C66B5ED5597E604039605793A7E04540C66B5ED5597E6040228D0A9C6CDF4540EBC9FCA3EF7D6040228D0A9C6CDF4540
45046	20848	131.65459999999999	131.67234099999999	43.862395999999997	43.856870999999998	Новая	0103000020E61000000100000005000000C5FEB27BF274604006F2ECF2ADED4540C5FEB27BF2746040C119FCFD62EE454051D845D183756040C119FCFD62EE454051D845D18375604006F2ECF2ADED4540C5FEB27BF274604006F2ECF2ADED4540
44594	21217	131.95045999999999	131.96262300000001	43.868245000000002	43.851208999999997	Воложенина	0103000020E61000000100000005000000FF04172B6A7E6040CA87A06AF4EC4540FF04172B6A7E604030F5F3A622EF454014ECBFCECD7E604030F5F3A622EF454014ECBFCECD7E6040CA87A06AF4EC4540FF04172B6A7E6040CA87A06AF4EC4540
44790	21209	131.79996499999999	131.82281800000001	43.975990000000003	43.968159999999997	Центральная	0103000020E610000001000000050000003A1E335099796040CEA5B8AAECFB45403A1E3350997960408D9C853DEDFC4540ED116A86547A60408D9C853DEDFC4540ED116A86547A6040CEA5B8AAECFB45403A1E335099796040CEA5B8AAECFB4540
44895	21330	132.156408	132.17848799999999	43.818525999999999	43.795555	Советская	0103000020E61000000100000005000000A69A594B01856040AB9509BFD4E54540A69A594B018560407D76C075C5E845404F57772CB68560407D76C075C5E845404F57772CB6856040AB9509BFD4E54540A69A594B01856040AB9509BFD4E54540
45099	21575	131.951134	131.96940499999999	43.706511999999996	43.676346000000002	Партизанская	0103000020E61000000100000005000000A30392B06F7E6040E563778192D64540A30392B06F7E6040A31D37FC6EDA45408672A25D057F6040A31D37FC6EDA45408672A25D057F6040E563778192D64540A30392B06F7E6040E563778192D64540
44375	21147	131.841306	131.88082199999999	43.872878	43.839643000000002	Советская	0103000020E61000000100000005000000B77D8FFAEB7A60405DA8FC6B79EB4540B77D8FFAEB7A6040EEB25F77BAEF45401D739EB12F7C6040EEB25F77BAEF45401D739EB12F7C60405DA8FC6B79EB4540B77D8FFAEB7A60405DA8FC6B79EB4540
44953	20609	131.35484099999999	131.38009299999999	43.882983000000003	43.872923999999998	Пархоменко	0103000020E61000000100000005000000F54883DB5A6B60405EF23FF9BBEF4540F54883DB5A6B604045F6419605F14540088ECBB8296C604045F6419605F14540088ECBB8296C60405EF23FF9BBEF4540F54883DB5A6B60405EF23FF9BBEF4540
45048	20881	131.452012	131.462234	43.749084000000003	43.740324000000001	Угловая	0103000020E61000000100000005000000C9ACDEE1766E6040D238D4EFC2DE4540C9ACDEE1766E60407BFA08FCE1DF45402D23F59ECA6E60407BFA08FCE1DF45402D23F59ECA6E6040D238D4EFC2DE4540C9ACDEE1766E6040D238D4EFC2DE4540
45045	21572	131.83163099999999	131.84775500000001	43.740982000000002	43.728501999999999	Центральная	0103000020E61000000100000005000000DF6A9DB89C7A60400989B48D3FDD4540DF6A9DB89C7A60405C76887FD8DE4540A80018CF207B60405C76887FD8DE4540A80018CF207B60400989B48D3FDD4540DF6A9DB89C7A60400989B48D3FDD4540
45097	20989	131.64423300000001	131.67705799999999	43.754429999999999	43.748725999999998	Советская	0103000020E610000001000000050000002140868E9D7460401BD5E940D6DF45402140868E9D746040868F882991E04540D8EF8975AA756040868F882991E04540D8EF8975AA7560401BD5E940D6DF45402140868E9D7460401BD5E940D6DF4540
44954	21510	131.911742	131.91923399999999	43.704771999999998	43.684365	Советская	0103000020E61000000100000005000000780C8FFD2C7D604076C3B64599D74540780C8FFD2C7D6040799109F835DA4540E1EB6B5D6A7D6040799109F835DA4540E1EB6B5D6A7D604076C3B64599D74540780C8FFD2C7D604076C3B64599D74540
44424	20952	131.686508	131.70549800000001	43.787973999999998	43.770693000000001	Комсомольская	0103000020E61000000100000005000000280EA0DFF7756040C9207711A6E24540280EA0DFF7756040950C0055DCE4454097AC8A7093766040950C0055DCE4454097AC8A7093766040C9207711A6E24540280EA0DFF7756040C9207711A6E24540
44958	21696	132.159255	132.16661199999999	43.634473	43.616194	Баневура	0103000020E610000001000000050000002F17F19D18856040E7FEEA71DFCE45402F17F19D18856040F698486936D14540E063B0E254856040F698486936D14540E063B0E254856040E7FEEA71DFCE45402F17F19D18856040E7FEEA71DFCE4540
44808	21791	132.22621599999999	132.23643899999999	43.625455000000002	43.613871000000003	Школьная	0103000020E610000001000000050000009F3A56293D8760403E7B2E5393CE45409F3A56293D876040520FD1E80ED04540F78F85E890876040520FD1E80ED04540F78F85E8908760403E7B2E5393CE45409F3A56293D8760403E7B2E5393CE4540
44810	21869	132.10137700000001	132.11119500000001	43.702419999999996	43.693804	Пионерская	0103000020E610000001000000050000002272FA7A3E836040C0EAC891CED845402272FA7A3E836040350708E6E8D94540520FD1E88E836040350708E6E8D94540520FD1E88E836040C0EAC891CED845402272FA7A3E836040C0EAC891CED84540
45004	21664	132.126485	132.13315	43.666322999999998	43.65401	Садовая	0103000020E61000000100000005000000E84D452A0C846040E4A08499B6D34540E84D452A0C8460404BC972124AD54540CCEEC9C3428460404BC972124AD54540CCEEC9C342846040E4A08499B6D34540E84D452A0C846040E4A08499B6D34540
45136	55321	132.146275	132.16745700000001	43.701585999999999	43.694468000000001	Солнечная	0103000020E610000001000000050000001EA7E848AE8460402C0FD253E4D845401EA7E848AE8460406DAAEE91CDD94540904FC8CE5B8560406DAAEE91CDD94540904FC8CE5B8560402C0FD253E4D845401EA7E848AE8460402C0FD253E4D84540
45047	21361	132.08758800000001	132.11098899999999	43.768290999999998	43.756500000000003	Октябрьская	0103000020E61000000100000005000000B5705985CD82604046B6F3FDD4E04540B5705985CD826040D367075C57E24540E7A6CD388D836040D367075C57E24540E7A6CD388D83604046B6F3FDD4E04540B5705985CD82604046B6F3FDD4E04540
42840	21289	131.89197100000001	131.96609100000001	43.921902000000003	43.869472999999999	Чайковского	0103000020E61000000100000005000000603FC4068B7C6040A4E029E44AEF4540603FC4068B7C6040FA0E7EE200F64540B83EAC37EA7E6040FA0E7EE200F64540B83EAC37EA7E6040A4E029E44AEF4540603FC4068B7C6040A4E029E44AEF4540
44523	21289	131.89197100000001	131.96609100000001	43.921902000000003	43.869472999999999	Ленинская	0103000020E61000000100000005000000603FC4068B7C6040A4E029E44AEF4540603FC4068B7C6040FA0E7EE200F64540B83EAC37EA7E6040FA0E7EE200F64540B83EAC37EA7E6040A4E029E44AEF4540603FC4068B7C6040A4E029E44AEF4540
44859	21289	131.89197100000001	131.96609100000001	43.921902000000003	43.869472999999999	Жуковского	0103000020E61000000100000005000000603FC4068B7C6040A4E029E44AEF4540603FC4068B7C6040FA0E7EE200F64540B83EAC37EA7E6040FA0E7EE200F64540B83EAC37EA7E6040A4E029E44AEF4540603FC4068B7C6040A4E029E44AEF4540
44475	21092	131.79978500000001	131.82713000000001	43.820244000000002	43.792431999999998	Советская	0103000020E610000001000000050000009B5AB6D697796040E5266A696EE545409B5AB6D697796040C05E61C1FDE845404C7155D9777A6040C05E61C1FDE845404C7155D9777A6040E5266A696EE545409B5AB6D697796040E5266A696EE54540
45095	21418	132.26022599999999	132.27719500000001	43.823925000000003	43.814442	Новая	0103000020E6100000010000000500000034F279C553886040923EADA23FE8454034F279C553886040ACADD85F76E94540AC730CC8DE886040ACADD85F76E94540AC730CC8DE886040923EADA23FE8454034F279C553886040923EADA23FE84540
45009	20787	131.60136600000001	131.62401199999999	43.812300999999998	43.800643000000001	Центральная	0103000020E61000000100000005000000A5DDE8633E736040BB6246787BE64540A5DDE8633E73604009C1AA7AF9E74540F88903E8F773604009C1AA7AF9E74540F88903E8F7736040BB6246787BE64540A5DDE8633E736040BB6246787BE64540
45062	21876	132.03502700000001	132.049993	43.723075999999999	43.714956999999998	Школьная	0103000020E61000000100000005000000446FF1F01E816040EC8502B683DB4540446FF1F01E816040E1421EC18DDC4540ED80EB8A99816040E1421EC18DDC4540ED80EB8A99816040EC8502B683DB4540446FF1F01E816040EC8502B683DB4540
44999	17063	137.995385	138.01343199999999	46.175984999999997	46.166860999999997	Советская	0103000020E61000000100000005000000BABDA431DA3F61402AFD84B35B154740BABDA431DA3F614014CB2DAD861647400917F2086E40614014CB2DAD861647400917F2086E4061402AFD84B35B154740BABDA431DA3F61402AFD84B35B154740
44514	16771	136.53975500000001	136.633386	45.109703000000003	45.036113999999998	Партизанская	0103000020E61000000100000005000000481B47AC45116140C07630629F844640481B47AC45116140F5A276BF0A8E4640D177B7B244146140F5A276BF0A8E4640D177B7B244146140C07630629F844640481B47AC45116140C07630629F844640
44516	55267	136.53975500000001	136.633386	45.109703000000003	45.036113999999998	Партизанская	0103000020E61000000100000005000000481B47AC45116140C07630629F844640481B47AC45116140F5A276BF0A8E4640D177B7B244146140F5A276BF0A8E4640D177B7B244146140C07630629F844640481B47AC45116140C07630629F844640
44857	17091	138.31090900000001	138.33873	46.545273999999999	46.536993000000002	Школьная	0103000020E6100000010000000500000007616EF7F24961402997C62FBC44474007616EF7F2496140F7ADD689CB45474092054CE0D64A6140F7ADD689CB45474092054CE0D64A61402997C62FBC44474007616EF7F24961402997C62FBC444740
45123	17203	138.79512800000001	138.81429800000001	47.254027000000001	47.241669999999999	Береговая	0103000020E61000000100000005000000498446B0715961405036E50AEF9E4740498446B07159614087A6ECF483A0474058E6ADBA0E5A614087A6ECF483A0474058E6ADBA0E5A61405036E50AEF9E4740498446B0715961405036E50AEF9E4740
44586	16633	136.25904	136.31914699999999	44.772052000000002	44.747647000000001	Третий квартал	0103000020E61000000100000005000000630B410E4A086140ECF99AE5B25F4640630B410E4A086140DC679599D2624640BAF3C473360A6140DC679599D2624640BAF3C473360A6140ECF99AE5B25F4640630B410E4A086140ECF99AE5B25F4640
44506	16633	136.25904	136.31914699999999	44.772052000000002	44.747647000000001	Лермонтова	0103000020E61000000100000005000000630B410E4A086140ECF99AE5B25F4640630B410E4A086140DC679599D2624640BAF3C473360A6140DC679599D2624640BAF3C473360A6140ECF99AE5B25F4640630B410E4A086140ECF99AE5B25F4640
45118	17160	138.62097199999999	138.64395099999999	47.186974999999997	47.181694999999998	Школьная	0103000020E610000001000000050000006AF7AB00DF536140616C21C8419747406AF7AB00DF536140B515FBCBEE9747403FA7203F9B546140B515FBCBEE9747403FA7203F9B546140616C21C8419747406AF7AB00DF536140616C21C841974740
44871	16866	137.13732300000001	137.16214400000001	45.4191	45.403700000000001	Спортивная	0103000020E61000000100000005000000A33F34F36424614096B20C71ACB34640A33F34F36424614076E09C11A5B54640C4279D483025614076E09C11A5B54640C4279D483025614096B20C71ACB34640A33F34F36424614096B20C71ACB34640
44906	16912	137.66731100000001	137.68888899999999	45.856819999999999	45.836962999999997	Молодежная	0103000020E610000001000000050000005B28999C5A356140247B849A21EB46405B28999C5A35614084471B47ACED46405FB2F1600B36614084471B47ACED46405FB2F1600B366140247B849A21EB46405B28999C5A356140247B849A21EB4640
45121	17256	138.389431	138.39777599999999	47.594577000000001	47.590293000000003	Крючкова	0103000020E610000001000000050000008E210038764C6140640795B88ECB47408E210038764C614016FA60191BCC474047E4BB94BA4C614016FA60191BCC474047E4BB94BA4C6140640795B88ECB47408E210038764C6140640795B88ECB4740
44431	4015	133.026704	133.06321199999999	44.857503000000001	44.812618999999998	Торговый	0103000020E6100000010000000500000084D558C2DAA06040DA8D3EE60368464084D558C2DAA06040679C86A8C26D4640DF162CD505A26040679C86A8C26D4640DF162CD505A26040DA8D3EE60368464084D558C2DAA06040DA8D3EE603684640
44433	4015	133.026704	133.06321199999999	44.857503000000001	44.812618999999998	Терешкевича	0103000020E6100000010000000500000084D558C2DAA06040DA8D3EE60368464084D558C2DAA06040679C86A8C26D4640DF162CD505A26040679C86A8C26D4640DF162CD505A26040DA8D3EE60368464084D558C2DAA06040DA8D3EE603684640
44818	31650	132.874054	132.90650099999999	44.648310000000002	44.593995	 Советская	0103000020E61000000100000005000000041E1840F89B6040677E3507084C4640041E1840F89B6040BBD573D2FB5246405299620E029D6040BBD573D2FB5246405299620E029D6040677E3507084C4640041E1840F89B6040677E3507084C4640
45113	31573	133.05146199999999	133.077181	44.620319000000002	44.609462000000001	переулок Новый	0103000020E6100000010000000500000093DFA293A5A16040CF13CFD9024E464093DFA293A5A16040310BED9C664F4640ECDB494478A26040310BED9C664F4640ECDB494478A26040CF13CFD9024E464093DFA293A5A16040CF13CFD9024E4640
44966	31562	132.73879400000001	132.751047	44.709077000000001	44.685459999999999	Центральная	0103000020E61000000100000005000000658F5033A4976040AB5B3D27BD574640658F5033A497604043ACFE08C35A464049D8B7930898604043ACFE08C35A464049D8B79308986040AB5B3D27BD574640658F5033A4976040AB5B3D27BD574640
44537	30579	132.77627200000001	132.811567	44.637498000000001	44.591106000000003	переулок Студенческий	0103000020E610000001000000050000009E996038D7986040153C855CA94B46409E996038D7986040F9A1D2889951464069705B5BF8996040F9A1D2889951464069705B5BF8996040153C855CA94B46409E996038D7986040153C855CA94B4640
44539	30579	132.77627200000001	132.811567	44.637498000000001	44.591106000000003	Комсомольская	0103000020E610000001000000050000009E996038D7986040153C855CA94B46409E996038D7986040F9A1D2889951464069705B5BF8996040F9A1D2889951464069705B5BF8996040153C855CA94B46409E996038D7986040153C855CA94B4640
44387	30579	132.77627200000001	132.811567	44.637498000000001	44.591106000000003	70 лет Октября	0103000020E610000001000000050000009E996038D7986040153C855CA94B46409E996038D7986040F9A1D2889951464069705B5BF8996040F9A1D2889951464069705B5BF8996040153C855CA94B46409E996038D7986040153C855CA94B4640
45012	31363	132.79651100000001	132.81239299999999	44.814723000000001	44.790841999999998	Советская	0103000020E61000000100000005000000F0FCA2047D996040D026874F3A654640F0FCA2047D9960404626E0D748684640FACF9A1FFF9960404626E0D748684640FACF9A1FFF996040D026874F3A654640F0FCA2047D996040D026874F3A654640
45060	31303	132.89174199999999	132.928258	44.583081999999997	44.565623000000002	Преображенская	0103000020E6100000010000000500000007CF8426899C6040C66E9F556648464007CF8426899C60407171546EA24A464003081F4AB49D60407171546EA24A464003081F4AB49D6040C66E9F556648464007CF8426899C6040C66E9F5566484640
44446	31233	133.06605999999999	133.08684700000001	44.829549	44.795645999999998	Партизанская	0103000020E610000001000000050000005C72DC291DA26040BB9866BAD76546405C72DC291DA26040FAB660A92E6A46402F185C73C7A26040FAB660A92E6A46402F185C73C7A26040BB9866BAD76546405C72DC291DA26040BB9866BAD7654640
44905	31155	132.677044	132.73985400000001	44.537129	44.505096999999999	Ленинская	0103000020E610000001000000050000007FBE2D58AA9560406327BC04A74046407FBE2D58AA956040D95DA0A4C044464013BA4BE2AC976040D95DA0A4C044464013BA4BE2AC9760406327BC04A74046407FBE2D58AA9560406327BC04A7404640
44902	31109	132.685767	132.712456	44.780490999999998	44.765627000000002	Центральная	0103000020E61000000100000005000000A2B5A2CDF1956040A1F7C61000624640A2B5A2CDF195604042E90B21E7634640D97A8670CC96604042E90B21E7634640D97A8670CC966040A1F7C61000624640A2B5A2CDF1956040A1F7C61000624640
44974	31013	133.09845300000001	133.140916	44.617674999999998	44.584654999999998	Центральная	0103000020E610000001000000050000002EE6E78626A36040B0389CF9D54A46402EE6E78626A36040454772F90F4F4640766F456282A46040454772F90F4F4640766F456282A46040B0389CF9D54A46402EE6E78626A36040B0389CF9D54A4640
44965	30968	132.794679	132.807399	44.568776	44.559573999999998	Тополиная	0103000020E610000001000000050000002D7AA7026E99604090D8EE1EA04746402D7AA7026E996040F65FE7A6CD484640577A6D36D6996040F65FE7A6CD484640577A6D36D699604090D8EE1EA04746402D7AA7026E99604090D8EE1EA0474640
9665	30887	133.10665399999999	133.12993	44.640749	44.631211999999998	Садовая	0103000020E610000001000000050000009A3FA6B569A36040DF6B088ECB5046409A3FA6B569A36040ECF82F10045246409E98F56228A46040ECF82F10045246409E98F56228A46040DF6B088ECB5046409A3FA6B569A36040DF6B088ECB504640
45057	30880	132.68802199999999	132.69722899999999	44.473421000000002	44.465226000000001	Октябрьский переулок	0103000020E61000000100000005000000B69DB64604966040DC9F8B868C3B4640B69DB64604966040AC1E300F993C4640541A31B34F966040AC1E300F993C4640541A31B34F966040DC9F8B868C3B4640B69DB64604966040DC9F8B868C3B4640
45138	55319	133.085014	133.107283	44.728433000000003	44.710621000000003	Борисова	0103000020E6100000010000000500000078B6476FB8A26040E86C01A1F55A464078B6476FB8A26040E129E44A3D5D4640560DC2DC6EA36040E129E44A3D5D4640560DC2DC6EA36040E86C01A1F55A464078B6476FB8A26040E86C01A1F55A4640
44963	30295	132.81386699999999	132.845371	44.535297999999997	44.502795999999996	Октябрьская	0103000020E610000001000000050000006589CE320B9A6040A1478C9E5B4046406589CE320B9A60409ECE15A58444464094BF7B470D9B60409ECE15A58444464094BF7B470D9B6040A1478C9E5B4046406589CE320B9A6040A1478C9E5B404640
45111	30685	132.98547199999999	133.002486	44.679845999999998	44.665031999999997	Средняя	0103000020E61000000100000005000000F56393FC889F60409065C1C41F554640F56393FC889F604080289831055746405516855D14A0604080289831055746405516855D14A060409065C1C41F554640F56393FC889F60409065C1C41F554640
45114	30532	133.06485599999999	133.087008	44.922139999999999	44.913913000000001	Школьная	0103000020E6100000010000000500000061DEE34C13A26040D331E719FB74464061DEE34C13A26040AE2AFBAE08764640B14F00C5C8A26040AE2AFBAE08764640B14F00C5C8A26040D331E719FB74464061DEE34C13A26040D331E719FB744640
44975	30499	133.01154099999999	133.03123199999999	44.530099	44.518191000000002	Первомайская	0103000020E6100000010000000500000005323B8B5EA06040700A2B155442464005323B8B5EA060403752B648DA434640D65240DAFFA060403752B648DA434640D65240DAFFA06040700A2B155442464005323B8B5EA06040700A2B1554424640
45056	30460	132.88036	132.904596	44.420324999999998	44.40455	Кедровая	0103000020E610000001000000050000009C16BCE82B9C604064CC5D4BC83346409C16BCE82B9C60407958A835CD354640F5824F73F29C60407958A835CD354640F5824F73F29C604064CC5D4BC83346409C16BCE82B9C604064CC5D4BC8334640
44803	30366	133.132203	133.15911600000001	44.887327999999997	44.868907	Переулок Школьный	0103000020E61000000100000005000000DC2DC9013BA46040FB213658386F4640DC2DC9013BA460409C69C2F693714640A708707A17A560409C69C2F693714640A708707A17A56040FB213658386F4640DC2DC9013BA46040FB213658386F4640
44798	30360	132.83981900000001	132.865645	44.564537999999999	44.53434	Молодежная	0103000020E61000000100000005000000E77118CCDF9A6040EA78CC4065444640E77118CCDF9A6040B4ACFBC742484640459E245DB39B6040B4ACFBC742484640459E245DB39B6040EA78CC4065444640E77118CCDF9A6040EA78CC4065444640
45055	30222	132.76574400000001	132.78699800000001	44.762791999999997	44.733888999999998	Ленинская	0103000020E6100000010000000500000077A38FF98098604073F22213F05D464077A38FF98098604041D3122BA36146408F006E162F99604041D3122BA36146408F006E162F99604073F22213F05D464077A38FF98098604073F22213F05D4640
44817	30194	132.72478100000001	132.74977200000001	44.584732000000002	44.562451000000003	пер.Школьный	0103000020E610000001000000050000006478EC67319760401F4DF564FE4746406478EC67319760405C76887FD84A46409C6ED921FE9760405C76887FD84A46409C6ED921FE9760401F4DF564FE4746406478EC67319760401F4DF564FE474640
44866	30147	132.850123	132.869248	44.465310000000002	44.444507999999999	Переулок Школьный	0103000020E610000001000000050000007A522635349B6040BA675DA3E53846407A522635349B60403A4030478F3B4640A1832EE1D09B60403A4030478F3B4640A1832EE1D09B6040BA675DA3E53846407A522635349B6040BA675DA3E5384640
44904	30054	132.971341	132.99453600000001	44.642122000000001	44.627541999999998	Советская	0103000020E610000001000000050000007288B839159F6040E76ED74B535046407288B839159F60406405BF0D315246403B56293DD39F60406405BF0D315246403B56293DD39F6040E76ED74B535046407288B839159F6040E76ED74B53504640
45162	30054	132.971341	132.99453600000001	44.642122000000001	44.627541999999998	Светлая	0103000020E610000001000000050000007288B839159F6040E76ED74B535046407288B839159F60406405BF0D315246403B56293DD39F60406405BF0D315246403B56293DD39F6040E76ED74B535046407288B839159F6040E76ED74B53504640
45125	29943	132.94175999999999	132.95505499999999	44.712735000000002	44.698718	Гагарина	0103000020E61000000100000005000000CA15DEE5229E6040329067976F594640CA15DEE5229E604077DB85E63A5B464033DC80CF8F9E604077DB85E63A5B464033DC80CF8F9E6040329067976F594640CA15DEE5229E6040329067976F594640
44479	29915	132.94254100000001	132.96464900000001	44.788079000000003	44.754356000000001	Уборевича	0103000020E610000001000000050000007444BE4B299E60404CC5C6BC8E6046407444BE4B299E60400BD5CDC5DF644640D0639467DE9E60400BD5CDC5DF644640D0639467DE9E60404CC5C6BC8E6046407444BE4B299E60404CC5C6BC8E604640
45140	55323	135.40334100000001	135.415469	46.607349999999997	46.598632000000002	Широкая	0103000020E610000001000000050000005A84622BE8EC6040672B2FF99F4C47405A84622BE8EC6040E09C11A5BD4D47400FF0A4854BED6040E09C11A5BD4D47400FF0A4854BED6040672B2FF99F4C47405A84622BE8EC6040672B2FF99F4C4740
44782	14943	134.26192399999999	134.28085999999999	46.542614999999998	46.527723999999999	Советская	0103000020E6100000010000000500000033C170AE61C860403BA8C4758C43474033C170AE61C86040D6A887687445474025581CCEFCC86040D6A887687445474025581CCEFCC860403BA8C4758C43474033C170AE61C860403BA8C4758C434740
45122	55315	135.42721800000001	135.44460100000001	46.679816000000002	46.672224	Родниковая	0103000020E61000000100000005000000674815C5ABED60400CCB9F6F0B564740674815C5ABED604016A6EF35045747409B58E02B3AEE604016A6EF35045747409B58E02B3AEE60400CCB9F6F0B564740674815C5ABED60400CCB9F6F0B564740
42655	14998	134.43489400000001	134.451639	46.864871000000001	46.856971999999999	Хомякова	0103000020E610000001000000050000004167D2A6EACD60403ACB2C42B16D47404167D2A6EACD60402121CA17B46E474024D3A1D373CE60402121CA17B46E474024D3A1D373CE60403ACB2C42B16D47404167D2A6EACD60403ACB2C42B16D4740
44361	14228	134.05082899999999	134.07665499999999	46.264341000000002	46.245572000000003	Ленинская	0103000020E6100000010000000500000007962364A0C160401B683EE76E1F474007962364A0C16040F8FE06EDD521474065C22FF573C26040F8FE06EDD521474065C22FF573C260401B683EE76E1F474007962364A0C160401B683EE76E1F4740
45040	14179	134.00275099999999	134.020771	46.228411000000001	46.219400999999998	Центральная	0103000020E6100000010000000500000000E1438916C06040D7DAFB54151C474000E1438916C06040F98557923C1D474091B6F127AAC06040F98557923C1D474091B6F127AAC06040D7DAFB54151C474000E1438916C06040D7DAFB54151C4740
44440	14099	133.921516	133.94568100000001	46.192613000000001	46.174325000000003	Заводская	0103000020E61000000100000005000000B4571F0F7DBD604007F0164850164740B4571F0F7DBD604069E4F38AA71847405BEECC0443BE604069E4F38AA71847405BEECC0443BE604007F0164850164740B4571F0F7DBD604007F0164850164740
45000	14289	134.10737800000001	134.12904499999999	46.282020000000003	46.271655000000003	Зелёная	0103000020E61000000100000005000000EBC9FCA36FC36040BF654E97C5224740EBC9FCA36FC36040B2683A3B19244740CBD6FA2221C46040B2683A3B19244740CBD6FA2221C46040BF654E97C5224740EBC9FCA36FC36040BF654E97C5224740
44837	14514	134.373558	134.400803	46.346003000000003	46.330204999999999	Юбилейная	0103000020E610000001000000050000001825E82FF4CB6040E3FC4D28442A47401825E82FF4CB6040B1A888D3492C47407024D060D3CC6040B1A888D3492C47407024D060D3CC6040E3FC4D28442A47401825E82FF4CB6040E3FC4D28442A4740
44823	14565	134.27604500000001	134.31674799999999	46.451582000000002	46.431778999999999	третий микрорайон	0103000020E610000001000000050000002EE7525CD5C86040BF0CC688443747402EE7525CD5C860402CBB6070CD39474059A2B3CC22CA60402CBB6070CD39474059A2B3CC22CA6040BF0CC688443747402EE7525CD5C86040BF0CC68844374740
44362	14565	134.27604500000001	134.31674799999999	46.451582000000002	46.431778999999999	первый микрорайон	0103000020E610000001000000050000002EE7525CD5C86040BF0CC688443747402EE7525CD5C860402CBB6070CD39474059A2B3CC22CA60402CBB6070CD39474059A2B3CC22CA6040BF0CC688443747402EE7525CD5C86040BF0CC68844374740
44582	55266	134.27604500000001	134.31674799999999	46.451582000000002	46.431778999999999	второй микрорайон	0103000020E610000001000000050000002EE7525CD5C86040BF0CC688443747402EE7525CD5C860402CBB6070CD39474059A2B3CC22CA60402CBB6070CD39474059A2B3CC22CA6040BF0CC688443747402EE7525CD5C86040BF0CC68844374740
45142	55324	131.945088	131.96247	43.644877999999999	43.633434999999999	Свободы	0103000020E61000000100000005000000F27A30293E7E60402592E86514D14540F27A30293E7E604077F4BF5C8BD2454032ACE28DCC7E604077F4BF5C8BD2454032ACE28DCC7E60402592E86514D14540F27A30293E7E60402592E86514D14540
44585	55266	134.27604500000001	134.31674799999999	46.451582000000002	46.431778999999999	Четвертый микрорайон	0103000020E610000001000000050000002EE7525CD5C86040BF0CC688443747402EE7525CD5C860402CBB6070CD39474059A2B3CC22CA60402CBB6070CD39474059A2B3CC22CA6040BF0CC688443747402EE7525CD5C86040BF0CC68844374740
44581	55266	134.27604500000001	134.31674799999999	46.451582000000002	46.431778999999999	Ленина	0103000020E610000001000000050000002EE7525CD5C86040BF0CC688443747402EE7525CD5C860402CBB6070CD39474059A2B3CC22CA60402CBB6070CD39474059A2B3CC22CA6040BF0CC688443747402EE7525CD5C86040BF0CC68844374740
45094	14377	134.11302800000001	134.15886900000001	46.400086000000002	46.361105000000002	Вокзальная	0103000020E610000001000000050000000971E5EC9DC3604007B64AB0382E47400971E5EC9DC3604032CB9E043633474025EB707415C5604032CB9E043633474025EB707415C5604007B64AB0382E47400971E5EC9DC3604007B64AB0382E4740
45093	4555	135.351428	135.37030100000001	46.547511999999998	46.534990000000001	Арсеньева	0103000020E61000000100000005000000C2DCEEE53EEB6040F1D7648D7A444740C2DCEEE53EEB604072158BDF14464740A3957B81D9EB604072158BDF14464740A3957B81D9EB6040F1D7648D7A444740C2DCEEE53EEB6040F1D7648D7A444740
45041	14463	134.12615299999999	134.142448	46.411999000000002	46.400632999999999	Советская	0103000020E610000001000000050000005A29047209C46040645930F1473347405A29047209C460400B7E1B62BC3447402EAC1BEF8EC460400B7E1B62BC3447402EAC1BEF8EC46040645930F1473347405A29047209C46040645930F147334740
45039	14029	133.95557099999999	133.98731799999999	46.173813000000003	46.149768999999999	Веселая	0103000020E610000001000000050000003140A20994BE6040317A6EA12B1347403140A20994BE6040514F1F813F1647401118EB1B98BF6040514F1F813F1647401118EB1B98BF6040317A6EA12B1347403140A20994BE6040317A6EA12B134740
44979	14301	134.033931	134.04897800000001	46.369456999999997	46.356223	Пограничная	0103000020E6100000010000000500000042EA76F615C16040A08A1BB7982D474042EA76F615C160409E23F25D4A2F474027874F3A91C160409E23F25D4A2F474027874F3A91C16040A08A1BB7982D474042EA76F615C16040A08A1BB7982D4740
44785	14150	133.93954500000001	133.966037	46.210839	46.193356000000001	Совхозная	0103000020E61000000100000005000000DA03ADC010BE6040213EB0E3BF184740DA03ADC010BE604055DCB8C5FC1A47403B376DC6E9BE604055DCB8C5FC1A47403B376DC6E9BE6040213EB0E3BF184740DA03ADC010BE6040213EB0E3BF184740
44505	55265	134.65544	134.69240600000001	46.575215	46.555016999999999	Школьная	0103000020E61000000100000005000000B08F4E5DF9D46040ADDC0BCC0A474740B08F4E5DF9D46040969526A5A0494740BCB1A03028D66040969526A5A0494740BCB1A03028D66040ADDC0BCC0A474740B08F4E5DF9D46040ADDC0BCC0A474740
45037	13423	131.55781500000001	131.565136	44.386284000000003	44.379010000000001	Центральная	0103000020E61000000100000005000000FCC6D79ED9716040B16D516683304640FCC6D79ED9716040EA7B0DC1713146405AB9179815726040EA7B0DC1713146405AB9179815726040B16D516683304640FCC6D79ED9716040B16D516683304640
44995	13343	131.343513	131.35491300000001	44.305086000000003	44.295195999999997	Центральная	0103000020E610000001000000050000000798F90EFE6A60407BF486FBC82546400798F90EFE6A6040D63BDC0E0D2746409CFD81725B6B6040D63BDC0E0D2746409CFD81725B6B60407BF486FBC82546400798F90EFE6A60407BF486FBC8254640
44887	13567	131.64525699999999	131.678585	44.346832999999997	44.318269999999998	Колхозная	0103000020E610000001000000050000007B1002F2A574604022A64412BD2846407B1002F2A574604037161406652C4640CCD1E3F7B675604037161406652C4640CCD1E3F7B675604022A64412BD2846407B1002F2A574604022A64412BD284640
45152	55328	131.59719699999999	131.604555	44.408071999999997	44.398155000000003	Верхняя	0103000020E610000001000000050000009E08E23C1C73604094DE37BEF63246409E08E23C1C736040E7340BB43B3446404434BA8358736040E7340BB43B3446404434BA835873604094DE37BEF63246409E08E23C1C73604094DE37BEF6324640
45091	13920	131.68790000000001	131.70409699999999	44.695591	44.686478999999999	Набережная	0103000020E61000000100000005000000645DDC460376604005323B8BDE574640645DDC46037660402B323A2009594640C6866EF6877660402B323A2009594640C6866EF68776604005323B8BDE574640645DDC460376604005323B8BDE574640
44413	55258	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	Орлова	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
44868	55258	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	Лазо	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
44578	55258	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	Дубовика	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
44579	55258	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	Гагарина	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
44865	12859	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	Советская	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
44504	12859	131.354491	131.41143500000001	44.423917000000003	44.391823000000002	Лазо	0103000020E610000001000000050000003E7782FD576B60400A698D41273246403E7782FD576B6040F69B89E942364640C1ADBB792A6D6040F69B89E942364640C1ADBB792A6D60400A698D41273246403E7782FD576B60400A698D4127324640
44888	13703	131.752184	131.768317	44.462704000000002	44.441786	Советская	0103000020E6100000010000000500000062122EE41178604053EA92718C38464062122EE4117860403CDD79E2393B4640BF7E880D967860403CDD79E2393B4640BF7E880D9678604053EA92718C38464062122EE41178604053EA92718C384640
44360	13750	131.69384700000001	131.75915499999999	44.607871000000003	44.575055999999996	Кооперативная	0103000020E61000000100000005000000B0AD9FFE337660402DAF5C6F9B494640B0AD9FFE33766040EA9788B7CE4D464009336DFF4A786040EA9788B7CE4D464009336DFF4A7860402DAF5C6F9B494640B0AD9FFE337660402DAF5C6F9B494640
45116	13906	131.52314899999999	131.54610099999999	44.604436999999997	44.585894000000003	Ленина 	0103000020E61000000100000005000000ECBDF8A2BD70604019761893FE4A4640ECBDF8A2BD70604005BF0D315E4D464003EACDA87971604005BF0D315E4D464003EACDA87971604019761893FE4A4640ECBDF8A2BD70604019761893FE4A4640
45038	13200	131.46128200000001	131.47734399999999	44.470919000000002	44.458618999999999	Ленина	0103000020E61000000100000005000000790778D2C26E604080290307B43A4640790778D2C26E60405308E412473C4640239EEC66466F60405308E412473C4640239EEC66466F604080290307B43A4640790778D2C26E604080290307B43A4640
44890	13793	131.56424699999999	131.58850200000001	44.500404000000003	44.475467000000002	Школьная	0103000020E61000000100000005000000B77BB94F0E726040E3A9471ADC3C4640B77BB94F0E726040D064FF3C0D4046402E742502D5726040D064FF3C0D4046402E742502D5726040E3A9471ADC3C4640B77BB94F0E726040E3A9471ADC3C4640
44409	13225	131.43445	131.47034600000001	44.381239000000001	44.357649000000002	Победы	0103000020E61000000100000005000000E9B7AF03E76D60403B394371C72D4640E9B7AF03E76D6040D97A8670CC304640BEF90D130D6F6040D97A8670CC304640BEF90D130D6F60403B394371C72D4640E9B7AF03E76D60403B394371C72D4640
45096	12498	133.11532299999999	133.131574	42.789496	42.777335000000001	40 лет Победы	0103000020E61000000100000005000000402FDCB9B0A36040A18499B67F634540402FDCB9B0A36040522976340E6545402060ADDA35A46040522976340E6545402060ADDA35A46040A18499B67F634540402FDCB9B0A36040A18499B67F634540
44886	11975	133.25264899999999	133.282185	43.219065999999998	43.203144999999999	Партизанская	0103000020E61000000100000005000000BF0B5BB315A8604047ACC5A7009A4540BF0B5BB315A8604030D5CC5A0A9C45407F4DD6A807A9604030D5CC5A0A9C45407F4DD6A807A9604047ACC5A7009A4540BF0B5BB315A8604047ACC5A7009A4540
44359	11834	133.13889499999999	133.37734399999999	43.360624000000001	42.998584000000001	Школьный переулок	0103000020E610000001000000050000007E52EDD371A460408927BB99D17F45407E52EDD371A460408C135FED28AE4540F06AB93313AC60408C135FED28AE4540F06AB93313AC60408927BB99D17F45407E52EDD371A460408927BB99D17F4540
44835	11834	133.13889499999999	133.37734399999999	43.360624000000001	42.998584000000001	Ручейная	0103000020E610000001000000050000007E52EDD371A460408927BB99D17F45407E52EDD371A460408C135FED28AE4540F06AB93313AC60408C135FED28AE4540F06AB93313AC60408927BB99D17F45407E52EDD371A460408927BB99D17F4540
45148	55326	132.50149500000001	133.75279499999999	43.821798000000001	42.679794000000001	Черняховского	0103000020E6100000010000000500000071033E3F0C9060402E02637D0357454071033E3F0C90604088F546AD30E94540F4328AE516B8604088F546AD30E94540F4328AE516B860402E02637D0357454071033E3F0C9060402E02637D03574540
44836	12793	132.78312600000001	132.80918600000001	42.928418999999998	42.898158000000002	Черняховского	0103000020E61000000100000005000000B7D4415E0F996040055262D7F6724540B7D4415E0F99604015FE0C6FD676454032CC09DAE499604015FE0C6FD676454032CC09DAE4996040055262D7F6724540B7D4415E0F996040055262D7F6724540
42775	12197	133.157984	133.185338	43.059828000000003	43.049188999999998	Лазо	0103000020E61000000100000005000000522976340EA5604056293DD34B864540522976340EA560404BB1A371A88745409816F549EEA560404BB1A371A88745409816F549EEA5604056293DD34B864540522976340EA5604056293DD34B864540
45036	12573	133.09703400000001	133.11278999999999	43.025322000000003	43.003943999999997	Центральная	0103000020E6100000010000000500000034130CE71AA36040F981AB3C8180454034130CE71AA3604046EF54C03D8345401B2AC6F99BA3604046EF54C03D8345401B2AC6F99BA36040F981AB3C8180454034130CE71AA36040F981AB3C81804540
44603	12005	133.185059	133.22960699999999	43.107953999999999	43.075437000000001	Фадеева	0103000020E61000000100000005000000931ADA00ECA5604045F46BEBA7894540931ADA00ECA5604077BCC96FD18D4540D87DC7F058A7604077BCC96FD18D4540D87DC7F058A7604045F46BEBA7894540931ADA00ECA5604045F46BEBA7894540
44779	11796	133.357743	133.37413699999999	43.484585000000003	43.468373999999997	Ключевая	0103000020E61000000100000005000000EFAB72A172AB6040FA25E2ADF3BB4540EFAB72A172AB6040EB909BE106BE4540276728EEF8AB6040EB909BE106BE4540276728EEF8AB6040FA25E2ADF3BB4540EFAB72A172AB6040FA25E2ADF3BB4540
44405	12340	133.096396	133.14505700000001	42.966338	42.922866999999997	Центральная	0103000020E61000000100000005000000E36E10AD15A3604060C77F8120764540E36E10AD15A36040E770ADF6B07B4540CAE1934EA4A46040E770ADF6B07B4540CAE1934EA4A4604060C77F8120764540E36E10AD15A3604060C77F8120764540
44838	12340	133.096396	133.14505700000001	42.966338	42.922866999999997	Летная	0103000020E61000000100000005000000E36E10AD15A3604060C77F8120764540E36E10AD15A36040E770ADF6B07B4540CAE1934EA4A46040E770ADF6B07B4540CAE1934EA4A4604060C77F8120764540E36E10AD15A3604060C77F8120764540
44412	12686	133.02268000000001	133.06990400000001	42.934829000000001	42.910316000000002	Советская	0103000020E61000000100000005000000BF4868CBB9A060404583143C85744540BF4868CBB9A060401B2D077AA8774540823B50A73CA260401B2D077AA8774540823B50A73CA260404583143C85744540BF4868CBB9A060404583143C85744540
44414	12686	133.02268000000001	133.06990400000001	42.934829000000001	42.910316000000002	Молодежная	0103000020E61000000100000005000000BF4868CBB9A060404583143C85744540BF4868CBB9A060401B2D077AA8774540823B50A73CA260401B2D077AA8774540823B50A73CA260404583143C85744540BF4868CBB9A060404583143C85744540
44998	12762	132.97862699999999	133.007229	42.884571000000001	42.865966	60 лет СССР	0103000020E6100000010000000500000071FF91E9509F604056B950F9D76E454071FF91E9509F6040B9FE5D9F39714540A6D24F383BA06040B9FE5D9F39714540A6D24F383BA0604056B950F9D76E454071FF91E9509F604056B950F9D76E4540
44566	55252	133.02174600000001	133.12417199999999	42.744278000000001	42.714216999999998	Первостроителей	0103000020E6100000010000000500000034DAAA24B2A06040A59F70766B5B454034DAAA24B2A06040EF906280445F454086E28E37F9A36040EF906280445F454086E28E37F9A36040A59F70766B5B454034DAAA24B2A06040A59F70766B5B4540
59515	55252	133.02174600000001	133.12417199999999	42.744278000000001	42.714216999999998	Железнодорожная	0103000020E6100000010000000500000034DAAA24B2A06040A59F70766B5B454034DAAA24B2A06040EF906280445F454086E28E37F9A36040EF906280445F454086E28E37F9A36040A59F70766B5B454034DAAA24B2A06040A59F70766B5B4540
45001	55252	133.02174600000001	133.12417199999999	42.744278000000001	42.714216999999998	Внутрипортовая	0103000020E6100000010000000500000034DAAA24B2A06040A59F70766B5B454034DAAA24B2A06040EF906280445F454086E28E37F9A36040EF906280445F454086E28E37F9A36040A59F70766B5B454034DAAA24B2A06040A59F70766B5B4540
44348	55252	133.02174600000001	133.12417199999999	42.744278000000001	42.714216999999998	Бабкина	0103000020E6100000010000000500000034DAAA24B2A06040A59F70766B5B454034DAAA24B2A06040EF906280445F454086E28E37F9A36040EF906280445F454086E28E37F9A36040A59F70766B5B454034DAAA24B2A06040A59F70766B5B4540
44873	5168	132.73781500000001	132.77363099999999	42.919545999999997	42.910204	Озерная	0103000020E61000000100000005000000F2EF332E9C9760401D588E9081744540F2EF332E9C9760407495EEAEB37545407F85CC95C19860407495EEAEB37545407F85CC95C19860401D588E9081744540F2EF332E9C9760401D588E9081744540
44411	12433	133.05974399999999	133.098264	42.904459000000003	42.87735	Лазо	0103000020E610000001000000050000003BC43F6CE9A16040A3923A014D7045403BC43F6CE9A1604054C90050C5734540F94B8BFA24A3604054C90050C5734540F94B8BFA24A36040A3923A014D7045403BC43F6CE9A16040A3923A014D704540
44474	12433	133.05974399999999	133.098264	42.904459000000003	42.87735	Комсомольская	0103000020E610000001000000050000003BC43F6CE9A16040A3923A014D7045403BC43F6CE9A1604054C90050C5734540F94B8BFA24A3604054C90050C5734540F94B8BFA24A36040A3923A014D7045403BC43F6CE9A16040A3923A014D704540
44854	12620	133.057355	133.07481799999999	42.962966999999999	42.942214	Первомайская	0103000020E61000000100000005000000632827DAD5A16040ABEAE5779A784540632827DAD5A160404910AE80427B4540DEE4B7E864A260404910AE80427B4540DEE4B7E864A26040ABEAE5779A784540632827DAD5A16040ABEAE5779A784540
44996	9408	134.624304	134.633602	43.577283000000001	43.561802999999998	Центральная	0103000020E6100000010000000500000062D8614CFAD36040B8E52329E9C7454062D8614CFAD36040B5C4CA68E4C94540C495B37746D46040B5C4CA68E4C94540C495B37746D46040B8E52329E9C7454062D8614CFAD36040B8E52329E9C74540
44947	9369	134.673146	134.69833399999999	43.978552999999998	43.972701000000001	Центральная	0103000020E61000000100000005000000DDED7A698AD56040ACE4637781FC4540DDED7A698AD560408B33863941FD4540EA758BC058D660408B33863941FD4540EA758BC058D66040ACE4637781FC4540DDED7A698AD56040ACE4637781FC4540
44849	9651	135.42975200000001	135.47320300000001	43.878967000000003	43.857118	Ленина	0103000020E61000000100000005000000802C4487C0ED60400E68E90AB6ED4540802C4487C0ED6040B2A19BFD81F04540D02B9E7A24EF6040B2A19BFD81F04540D02B9E7A24EF60400E68E90AB6ED4540802C4487C0ED60400E68E90AB6ED4540
45033	9733	135.44020800000001	135.45840799999999	43.945239999999998	43.932347999999998	Адмирала Федюковского	0103000020E61000000100000005000000016E162F16EE6040D93EE42D57F74540016E162F16EE60407E6FD39FFDF8454031074147ABEE60407E6FD39FFDF8454031074147ABEE6040D93EE42D57F74540016E162F16EE6040D93EE42D57F74540
44833	9196	135.16664399999999	135.182311	43.772483000000001	43.761651000000001	Центральная	0103000020E610000001000000050000006342CC2555E560409CFBABC77DE145406342CC2555E56040A5DB12B9E0E245406FD6E07DD5E56040A5DB12B9E0E245406FD6E07DD5E560409CFBABC77DE145406342CC2555E560409CFBABC77DE14540
44356	9089	135.27192700000001	135.32840400000001	43.788442000000003	43.738363999999997	Партизанская	0103000020E61000000100000005000000C87C40A0B3E86040994528B682DE4540C87C40A0B3E860407C65DEAAEBE4454005FC1A4982EA60407C65DEAAEBE4454005FC1A4982EA6040994528B682DE4540C87C40A0B3E86040994528B682DE4540
45119	9281	135.01989499999999	135.03157300000001	43.828926000000003	43.81597	Центральная	0103000020E6100000010000000500000053CBD6FAA2E06040314278B471E8454053CBD6FAA2E06040ED66463F1AEA4540F94D61A502E16040ED66463F1AEA4540F94D61A502E16040314278B471E8454053CBD6FAA2E06040314278B471E84540
44834	9523	134.77183500000001	134.79855000000001	43.360492999999998	43.340702	Школьная	0103000020E61000000100000005000000105D50DFB2D8604045D7851F9CAB4540105D50DFB2D86040EDB776A224AE454011C7BAB88DD96040EDB776A224AE454011C7BAB88DD9604045D7851F9CAB4540105D50DFB2D8604045D7851F9CAB4540
44993	9447	134.74025	134.766391	43.419879999999999	43.401857	Школьная	0103000020E61000000100000005000000A69BC420B0D760409755D80C70B34540A69BC420B0D760404B1FBAA0BEB545405C1E6B4686D860404B1FBAA0BEB545405C1E6B4686D860409755D80C70B34540A69BC420B0D760409755D80C70B34540
44948	9593	134.526433	134.54281800000001	43.332898999999998	43.323940999999998	Таежная	0103000020E6100000010000000500000020D1048AD8D06040B16A10E676A9454020D1048AD8D0604080EF366F9CAA4540C4B5DAC35ED1604080EF366F9CAA4540C4B5DAC35ED16040B16A10E676A9454020D1048AD8D06040B16A10E676A94540
45008	9257	135.11637400000001	135.12820500000001	43.778607999999998	43.768649000000003	Буденного	0103000020E610000001000000050000005A83F755B9E36040338D261763E245405A83F755B9E36040B5334C6DA9E34540E1455F411AE46040B5334C6DA9E34540E1455F411AE46040338D261763E245405A83F755B9E36040338D261763E24540
44832	9039	135.44724199999999	135.51880199999999	43.970936999999999	43.921843000000003	Набережная	0103000020E61000000100000005000000B96C74CE4FEE6040F58590F3FEF54540B96C74CE4FEE6040F9BCE2A947FC45402EE3A6069AF06040F9BCE2A947FC45402EE3A6069AF06040F58590F3FEF54540B96C74CE4FEE6040F58590F3FEF54540
45103	7952	131.60318899999999	131.67637500000001	43.961204000000002	43.930504999999997	Красноармейская	0103000020E61000000100000005000000D28904534D736040DAE1AFC91AF74540D28904534D736040676490BB08FB4540A01A2FDDA4756040676490BB08FB4540A01A2FDDA4756040DAE1AFC91AF74540D28904534D736040DAE1AFC91AF74540
45153	55329	131.384063	132.06049400000001	43.662703999999998	43.274470000000001	РВС-1	0103000020E6100000010000000500000051137D3E4A6C6040D7DD3CD521A3454051137D3E4A6C6040D576137CD3D4454056F31C91EF816040D576137CD3D4454056F31C91EF816040D7DD3CD521A3454051137D3E4A6C6040D7DD3CD521A34540
45149	55327	131.79383000000001	131.80855299999999	43.519137000000001	43.506898999999997	Таежная	0103000020E61000000100000005000000AE122C0E6779604003B00111E2C04540AE122C0E677960406092CA1473C24540A5828AAADF7960406092CA1473C24540A5828AAADF79604003B00111E2C04540AE122C0E6779604003B00111E2C04540
44991	4267	131.93805399999999	131.94961499999999	43.517567999999997	43.506506000000002	Центральная	0103000020E61000000100000005000000397CD289047E6040289D4830D5C04540397CD289047E604062BA10AB3FC245405019FF3E637E604062BA10AB3FC245405019FF3E637E6040289D4830D5C04540397CD289047E6040289D4830D5C04540
45085	3629	131.91056599999999	131.926637	43.647781000000002	43.635365999999998	Ленина	0103000020E610000001000000050000002FDB4E5B237D6040C37E4FAC53D145402FDB4E5B237D60402FFCE07CEAD245406F48A302A77D60402FFCE07CEAD245406F48A302A77D6040C37E4FAC53D145402FDB4E5B237D6040C37E4FAC53D14540
44945	4432	131.953101	131.960296	43.478991999999998	43.473287999999997	Мира	0103000020E610000001000000050000001E19ABCD7F7E60406CCB80B394BC45401E19ABCD7F7E6040D7851F9C4FBD4540594FADBEBA7E6040D7851F9C4FBD4540594FADBEBA7E60406CCB80B394BC45401E19ABCD7F7E60406CCB80B394BC4540
44712	55289	131.384063	132.06049400000001	43.662703999999998	43.274470000000001	Парковая	0103000020E6100000010000000500000051137D3E4A6C6040D7DD3CD521A3454051137D3E4A6C6040D576137CD3D4454056F31C91EF816040D576137CD3D4454056F31C91EF816040D7DD3CD521A3454051137D3E4A6C6040D7DD3CD521A34540
45024	4997	132.04609400000001	132.05803299999999	43.400782999999997	43.389870000000002	Центральная	0103000020E6100000010000000500000057D11F9A7981604084D89942E7B1454057D11F9A7981604079E57ADB4CB34540D7A20568DB81604079E57ADB4CB34540D7A20568DB81604084D89942E7B1454057D11F9A7981604084D89942E7B14540
44778	3907	131.87057300000001	131.945537	43.575847000000003	43.493310000000001	Пирогова	0103000020E61000000100000005000000FB78E8BBDB7B6040176536C824BF4540FB78E8BBDB7B6040F73FC05AB5C945400E85CFD6417E6040F73FC05AB5C945400E85CFD6417E6040176536C824BF4540FB78E8BBDB7B6040176536C824BF4540
44397	3907	131.87057300000001	131.945537	43.575847000000003	43.493310000000001	Ленинская	0103000020E61000000100000005000000FB78E8BBDB7B6040176536C824BF4540FB78E8BBDB7B6040F73FC05AB5C945400E85CFD6417E6040F73FC05AB5C945400E85CFD6417E6040176536C824BF4540FB78E8BBDB7B6040176536C824BF4540
44399	3907	131.87057300000001	131.945537	43.575847000000003	43.493310000000001	Лазо	0103000020E61000000100000005000000FB78E8BBDB7B6040176536C824BF4540FB78E8BBDB7B6040F73FC05AB5C945400E85CFD6417E6040F73FC05AB5C945400E85CFD6417E6040176536C824BF4540FB78E8BBDB7B6040176536C824BF4540
44563	3907	131.87057300000001	131.945537	43.575847000000003	43.493310000000001	Котовского	0103000020E61000000100000005000000FB78E8BBDB7B6040176536C824BF4540FB78E8BBDB7B6040F73FC05AB5C945400E85CFD6417E6040F73FC05AB5C945400E85CFD6417E6040176536C824BF4540FB78E8BBDB7B6040176536C824BF4540
44439	4922	131.95933500000001	132.09113600000001	43.384261000000002	43.288055999999997	Амурская	0103000020E61000000100000005000000105D50DFB27E604052B5DD04DFA44540105D50DFB27E60406B10E6762FB14540A06F0B96EA8260406B10E6762FB14540A06F0B96EA82604052B5DD04DFA44540105D50DFB27E604052B5DD04DFA44540
44847	4169	131.85057599999999	131.866297	43.604883000000001	43.580652999999998	Шоссейная	0103000020E6100000010000000500000066D828EB377B604082A966D652CA454066D828EB377B604004745FCE6CCD4540EF737CB4B87B604004745FCE6CCD4540EF737CB4B87B604082A966D652CA454066D828EB377B604082A966D652CA4540
44688	55287	\N	\N	\N	\N	Первомайская	\N
45089	3776	131.76400599999999	131.77704900000001	43.460541999999997	43.450260999999998	Шоссейная	0103000020E6100000010000000500000054FEB5BC7278604006D50627A2B9454054FEB5BC727860409B374E0AF3BA4540774CDD95DD7860409B374E0AF3BA4540774CDD95DD78604006D50627A2B9454054FEB5BC7278604006D50627A2B94540
44872	4415	131.91980899999999	131.943579	43.457552	43.436418000000003	Пролетарская	0103000020E6100000010000000500000020B248136F7D604060B1868BDCB7454020B248136F7D6040151C5E1091BA4540284696CC317E6040151C5E1091BA4540284696CC317E604060B1868BDCB7454020B248136F7D604060B1868BDCB74540
44882	4345	131.91598300000001	131.931164	43.484042000000002	43.470768999999997	Советская	0103000020E61000000100000005000000259694BB4F7D60403D7C992842BC4540259694BB4F7D6040FAF19716F5BD4540CDE67118CC7D6040FAF19716F5BD4540CDE67118CC7D60403D7C992842BC4540259694BB4F7D60403D7C992842BC4540
45031	4551	131.96137400000001	131.97192999999999	43.363658999999998	43.354568	Курбаева	0103000020E6100000010000000500000031276893C37E6040A41AF67B62AD454031276893C37E6040B2F2CB608CAE45400A80F10C1A7F6040B2F2CB608CAE45400A80F10C1A7F6040A41AF67B62AD454031276893C37E6040A41AF67B62AD4540
44907	55295	131.384063	132.06049400000001	43.662703999999998	43.274470000000001	Набивайло	0103000020E6100000010000000500000051137D3E4A6C6040D7DD3CD521A3454051137D3E4A6C6040D576137CD3D4454056F31C91EF816040D576137CD3D4454056F31C91EF816040D7DD3CD521A3454051137D3E4A6C6040D7DD3CD521A34540
44492	4640	131.96900099999999	132.010683	43.385643999999999	43.356225999999999	Пушкина	0103000020E610000001000000050000005299620E027F604011FE45D098AD45405299620E027F604006F357C85CB14540F1F3DF835780604006F357C85CB14540F1F3DF835780604011FE45D098AD45405299620E027F604011FE45D098AD4540
44438	4640	131.96900099999999	132.010683	43.385643999999999	43.356225999999999	Ленина	0103000020E610000001000000050000005299620E027F604011FE45D098AD45405299620E027F604006F357C85CB14540F1F3DF835780604006F357C85CB14540F1F3DF835780604011FE45D098AD45405299620E027F604011FE45D098AD4540
44564	4640	131.96900099999999	132.010683	43.385643999999999	43.356225999999999	Дрегиса	0103000020E610000001000000050000005299620E027F604011FE45D098AD45405299620E027F604006F357C85CB14540F1F3DF835780604006F357C85CB14540F1F3DF835780604011FE45D098AD45405299620E027F604011FE45D098AD4540
44946	55303	131.922909	131.93760499999999	43.656475999999998	43.643835000000003	Тополинная	0103000020E61000000100000005000000E4857478887D604095826E2F69D24540E4857478887D6040F04DD36707D445401D7233DC007E6040F04DD36707D445401D7233DC007E604095826E2F69D24540E4857478887D604095826E2F69D24540
44950	4251	131.96075500000001	132.000191	43.562842000000003	43.554518999999999	Ленина	0103000020E61000000100000005000000FE0E4581BE7E60405C01857AFAC64540FE0E4581BE7E60405A68E7340BC845401D588E90018060405A68E7340BC845401D588E90018060405C01857AFAC64540FE0E4581BE7E60405C01857AFAC64540
44881	3455	132.554361	132.58528999999999	43.990059000000002	43.968944999999998	Октябрьская	0103000020E61000000100000005000000B1A54753BD916040B54FC76306FC4540B1A54753BD916040240ED940BAFE4540A01518B2BA926040240ED940BAFE4540A01518B2BA926040B54FC76306FC4540B1A54753BD916040B54FC76306FC4540
45087	3502	132.64852300000001	132.66476399999999	43.999229	43.984883000000004	Ломоносова	0103000020E6100000010000000500000086764EB3C094604075B169A510FE454086764EB3C09460407E1B62BCE6FF4540DCF126BF459560407E1B62BCE6FF4540DCF126BF4595604075B169A510FE454086764EB3C094604075B169A510FE4540
44990	2480	131.84188	131.862865	44.088273000000001	44.072724999999998	Совхозная	0103000020E61000000100000005000000026553AEF07A6040014D840D4F094640026553AEF07A6040560F98874C0B46409E7B0F979C7B6040560F98874C0B46409E7B0F979C7B6040014D840D4F094640026553AEF07A6040014D840D4F094640
44942	2390	132.10296700000001	132.11532800000001	43.910674	43.901127000000002	Флотская	0103000020E61000000100000005000000273273814B8360407445292158F34540273273814B836040A4A833F790F44540058A58C4B0836040A4A833F790F44540058A58C4B08360407445292158F34540273273814B8360407445292158F34540
44489	2521	131.9691	131.993336	44.009188999999999	43.995117999999998	Школьная	0103000020E61000000100000005000000B7D100DE027F604099D4D00660FF4540B7D100DE027F6040D13DEB1A2D014640103E9468C97F6040D13DEB1A2D014640103E9468C97F604099D4D00660FF4540B7D100DE027F604099D4D00660FF4540
45029	3419	132.525409	132.53742800000001	43.815702999999999	43.810186999999999	Садовая	0103000020E61000000100000005000000C5008926D09060407A522635B4E74540C5008926D0906040E21FB6F468E845408D7E349C32916040E21FB6F468E845408D7E349C329160407A522635B4E74540C5008926D09060407A522635B4E74540
44491	3076	132.22599099999999	132.25827699999999	43.981355000000001	43.939293999999997	Комсомольская	0103000020E6100000010000000500000017467A513B8760401DAA29C93AF8454017467A513B8760400F62670A9DFD4540E38920CE438860400F62670A9DFD4540E38920CE438860401DAA29C93AF8454017467A513B8760401DAA29C93AF84540
44559	2822	132.14984100000001	132.184031	44.034267999999997	44.012462999999997	Ленинская	0103000020E6100000010000000500000033535A7FCB8460407CB438639801464033535A7FCB84604050A6D1E46204464068CEFA94E385604050A6D1E46204464068CEFA94E38560407CB438639801464033535A7FCB8460407CB4386398014640
44340	55250	132.14984100000001	132.184031	44.034267999999997	44.012462999999997	Ленинская	0103000020E6100000010000000500000033535A7FCB8460407CB438639801464033535A7FCB84604050A6D1E46204464068CEFA94E385604050A6D1E46204464068CEFA94E38560407CB438639801464033535A7FCB8460407CB4386398014640
45027	2752	131.91612599999999	131.93546699999999	44.242699000000002	44.227088999999999	Центральная	0103000020E610000001000000050000007D2079E7507D604003249A40111D46407D2079E7507D6040CEE2C5C2101F4640976F7D58EF7D6040CEE2C5C2101F4640976F7D58EF7D604003249A40111D46407D2079E7507D604003249A40111D4640
45082	3319	132.43507399999999	132.45945399999999	43.899535999999998	43.877738999999998	Ленинская	0103000020E61000000100000005000000E02A4F20EC8D60403DB665C059F04540E02A4F20EC8D60408EC9E2FE23F345408600E0D8B38E60408EC9E2FE23F345408600E0D8B38E60403DB665C059F04540E02A4F20EC8D60403DB665C059F04540
44941	2435	132.058482	132.071157	43.985610000000001	43.975737000000002	Школьная	0103000020E61000000100000005000000F3ACA415DF816040A33F34F3E4FC4540F3ACA415DF816040274EEE7728FE4540357C0BEB46826040274EEE7728FE4540357C0BEB46826040A33F34F3E4FC4540F3ACA415DF816040A33F34F3E4FC4540
44780	2182	131.985063	132.03508099999999	43.954085999999997	43.911771999999999	Ленинская	0103000020E61000000100000005000000FD2FD7A2857F60404AB4E4F1B4F44540FD2FD7A2857F604025C9737D1FFA4540C07630621F81604025C9737D1FFA4540C07630621F8160404AB4E4F1B4F44540FD2FD7A2857F60404AB4E4F1B4F44540
44398	2182	131.985063	132.03508099999999	43.954085999999997	43.911771999999999	Красноармейская	0103000020E61000000100000005000000FD2FD7A2857F60404AB4E4F1B4F44540FD2FD7A2857F604025C9737D1FFA4540C07630621F81604025C9737D1FFA4540C07630621F8160404AB4E4F1B4F44540FD2FD7A2857F60404AB4E4F1B4F44540
44556	2182	131.985063	132.03508099999999	43.954085999999997	43.911771999999999	Колхозная	0103000020E61000000100000005000000FD2FD7A2857F60404AB4E4F1B4F44540FD2FD7A2857F604025C9737D1FFA4540C07630621F81604025C9737D1FFA4540C07630621F8160404AB4E4F1B4F44540FD2FD7A2857F60404AB4E4F1B4F44540
44884	2965	132.35391999999999	132.39866499999999	44.089016999999998	44.060203999999999	Школьная	0103000020E61000000100000005000000CF2C0950538B6040508BC1C3B4074640CF2C0950538B6040DEE4B7E8640B4640EA211ADDC18C6040DEE4B7E8640B4640EA211ADDC18C6040508BC1C3B4074640CF2C0950538B6040508BC1C3B4074640
45084	3547	132.618133	132.62944200000001	43.96696	43.953443	Ленина	0103000020E610000001000000050000008272DBBEC7936040D1CC936B0AFA45408272DBBEC793604024456458C5FB454053978C632494604024456458C5FB454053978C6324946040D1CC936B0AFA45408272DBBEC7936040D1CC936B0AFA4540
44490	2964	132.22073599999999	132.296446	44.062905000000001	44.007516000000003	Колхозная	0103000020E6100000010000000500000098A1F144108760402F19C748F600464098A1F14410876040A0E062450D084640F660527C7C896040A0E062450D084640F660527C7C8960402F19C748F600464098A1F144108760402F19C748F6004640
42706	3312	132.45491799999999	132.50448700000001	43.983722	43.950581	Краснознаменная	0103000020E61000000100000005000000938B31B08E8E6040789961A3ACF94540938B31B08E8E6040882D3D9AEAFD45403BC8EBC124906040882D3D9AEAFD45403BC8EBC124906040789961A3ACF94540938B31B08E8E6040789961A3ACF94540
45077	2610	131.94710000000001	131.96383599999999	44.064933000000003	44.052112999999999	40 лет Победы	0103000020E6100000010000000500000055C1A8A44E7E6040255987A3AB06464055C1A8A44E7E604031B77BB94F084640A35698BED77E604031B77BB94F084640A35698BED77E6040255987A3AB06464055C1A8A44E7E6040255987A3AB064640
45115	3115	132.25987599999999	132.29843099999999	43.913648999999999	43.890610000000002	Ленинская 	0103000020E610000001000000050000007D2079E750886040CBBE2B82FFF145407D2079E750886040F5824F73F2F445409A232BBF8C896040F5824F73F2F445409A232BBF8C896040CBBE2B82FFF145407D2079E750886040CBBE2B82FFF14540
44794	2714	131.98543100000001	132.01611800000001	44.168801999999999	44.149628	Калинина	0103000020E61000000100000005000000DEAE97A6887F60406F48A30227134640DEAE97A6887F6040ECBFCE4D9B154640105CE50984806040ECBFCE4D9B154640105CE509848060406F48A30227134640DEAE97A6887F60406F48A30227134640
45098	55314	132.33367200000001	132.34609599999999	43.989753999999998	43.982911999999999	Ленина	0103000020E61000000100000005000000E9F2E670AD8A6040486C770FD0FD4540E9F2E670AD8A6040E78A5242B0FE4540D828EB37138B6040E78A5242B0FE4540D828EB37138B6040486C770FD0FD4540E9F2E670AD8A6040486C770FD0FD4540
45028	3216	132.37046699999999	132.40362400000001	43.957479999999997	43.946019	Ленинская	0103000020E61000000100000005000000E9279CDDDA8B604083328D2617F94540E9279CDDDA8B60407B4963B48EFA45402FFCE07CEA8C60407B4963B48EFA45402FFCE07CEA8C604083328D2617F94540E9279CDDDA8B604083328D2617F94540
44848	2628	132.01061100000001	132.047235	44.094940999999999	44.085385000000002	Советская	0103000020E610000001000000050000004B3FE1EC56806040D4484BE5ED0A46404B3FE1EC568060405706D506270C46404087F9F2828160405706D506270C46404087F9F282816040D4484BE5ED0A46404B3FE1EC56806040D4484BE5ED0A4640
44987	1557	133.501383	133.52644599999999	45.57197	45.543281999999998	Почтовая	0103000020E61000000100000005000000A7785C540BB06040B340BB438AC54640A7785C540BB0604085251E5036C94640852348A5D8B0604085251E5036C94640852348A5D8B06040B340BB438AC54640A7785C540BB06040B340BB438AC54640
44830	1322	133.45661100000001	133.46590900000001	45.503898	45.498565999999997	Ленинская	0103000020E61000000100000005000000CEFFAB8E9CAE6040E272BC02D1BF4640CEFFAB8E9CAE60408942CBBA7FC0464030BDFDB9E8AE60408942CBBA7FC0464030BDFDB9E8AE6040E272BC02D1BF4640CEFFAB8E9CAE6040E272BC02D1BF4640
45025	1378	133.64294000000001	133.65282999999999	45.473582	45.456204999999997	Октябрьская	0103000020E610000001000000050000004A29E8F692B46040C6A2E9EC64BA46404A29E8F692B46040B5FCC0559EBC4640207BBDFBE3B46040B5FCC0559EBC4640207BBDFBE3B46040C6A2E9EC64BA46404A29E8F692B46040C6A2E9EC64BA4640
44846	1829	133.45804799999999	133.48271600000001	45.289000000000001	45.255997999999998	Советская	0103000020E61000000100000005000000F17F4754A8AE6040B3EBDE8AC4A04640F17F4754A8AE6040A245B6F3FDA446403128D36872AF6040A245B6F3FDA446403128D36872AF6040B3EBDE8AC4A04640F17F4754A8AE6040B3EBDE8AC4A04640
44983	1102	133.60247100000001	133.63164800000001	45.579073999999999	45.571548	Центральная	0103000020E610000001000000050000003B39437147B360400F0C207C28C946403B39437147B3604061FBC9181FCA4640AFD2DD7536B4604061FBC9181FCA4640AFD2DD7536B460400F0C207C28C946403B39437147B360400F0C207C28C94640
44822	1450	133.56564900000001	133.59104400000001	45.527605999999999	45.512627000000002	Советская	0103000020E610000001000000050000007C80EECB19B26040F705F4C29DC146407C80EECB19B260403196E99788C34640E84F1BD5E9B260403196E99788C34640E84F1BD5E9B26040F705F4C29DC146407C80EECB19B26040F705F4C29DC14640
44855	1912	133.37472099999999	133.395274	45.438557000000003	45.425319000000002	Дзержинского	0103000020E61000000100000005000000FB03E5B6FDAB604008AF5DDA70B64640FB03E5B6FDAB60404837C2A222B84640B1DEA815A6AC60404837C2A222B84640B1DEA815A6AC604008AF5DDA70B64640FB03E5B6FDAB604008AF5DDA70B64640
44775	1224	133.57925800000001	133.60593800000001	45.646790000000003	45.630746000000002	Центральная	0103000020E6100000010000000500000049BE124889B260409A0AF148BCD0464049BE124889B260409FB0C403CAD24640EBAC16D863B360409FB0C403CAD24640EBAC16D863B360409A0AF148BCD0464049BE124889B260409A0AF148BCD04640
45022	1280	133.66037600000001	133.68158500000001	45.728234999999998	45.707985999999998	Центральная	0103000020E610000001000000050000000762D9CC21B560404F0306499FDA46400762D9CC21B56040BA66F2CD36DD4640378E588BCFB56040BA66F2CD36DD4640378E588BCFB560404F0306499FDA46400762D9CC21B560404F0306499FDA4640
44878	2040	133.33570700000001	133.36224300000001	45.556454000000002	45.540301999999997	Волкова	0103000020E610000001000000050000003A419B1CBEAA604050FBAD9D28C546403A419B1CBEAA60403CDD79E239C746408FC6A17E97AB60403CDD79E239C746408FC6A17E97AB604050FBAD9D28C546403A419B1CBEAA604050FBAD9D28C54640
45081	1779	133.54212200000001	133.558166	45.473258999999999	45.463436999999999	Школьная	0103000020E61000000100000005000000268E3C1059B16040D06053E751BB4640268E3C1059B16040D2C43BC093BC4640A777F17EDCB16040D2C43BC093BC4640A777F17EDCB16040D06053E751BB4640268E3C1059B16040D06053E751BB4640
44777	1611	133.48218600000001	133.509863	45.415303999999999	45.392902999999997	Советская	0103000020E61000000100000005000000DA9255116EAF604009C03FA54AB24640DA9255116EAF6040F1F274AE28B5464018CE35CC50B06040F1F274AE28B5464018CE35CC50B0604009C03FA54AB24640DA9255116EAF604009C03FA54AB24640
44988	1718	133.58682200000001	133.609576	45.264665000000001	45.245237000000003	Школьная	0103000020E610000001000000050000005952EE3EC7B2604074620FED639F46405952EE3EC7B26040ABB2EF8AE0A14640A60D87A581B36040ABB2EF8AE0A14640A60D87A581B3604074620FED639F46405952EE3EC7B2604074620FED639F4640
44940	1121	133.763071	133.781181	45.651224999999997	45.639695000000003	Центральная	0103000020E61000000100000005000000D5B0DF136BB8604016359886E1D14640D5B0DF136BB8604036AB3E575BD3464036E84B6FFFB8604036AB3E575BD3464036E84B6FFFB8604016359886E1D14640D5B0DF136BB8604016359886E1D14640
45006	1497	133.70403400000001	133.72144399999999	45.560158000000001	45.551437	Центральная	0103000020E61000000100000005000000B5A84F7287B66040F566D47C95C64640B5A84F7287B66040E04BE141B3C74640A73CBA1116B76040E04BE141B3C74640A73CBA1116B76040F566D47C95C64640B5A84F7287B66040F566D47C95C64640
45083	1919	133.35230799999999	133.36322200000001	45.398890000000002	45.395308	Молодежная	0103000020E61000000100000005000000D0436D1B46AB604070ECD97399B24640D0436D1B46AB6040C959D8D30EB346400266BE839FAB6040C959D8D30EB346400266BE839FAB604070ECD97399B24640D0436D1B46AB604070ECD97399B24640
44943	1663	133.501608	133.521353	45.313104000000003	45.300533000000001	Центральная	0103000020E610000001000000050000002F6D382C0DB06040342F87DD77A646402F6D382C0DB06040971FB8CA13A846407D957CECAEB06040971FB8CA13A846407D957CECAEB06040342F87DD77A646402F6D382C0DB06040342F87DD77A64640
45076	31679	133.550737	133.56033099999999	43.063094999999997	43.040551000000001	Центральная	0103000020E610000001000000050000004F7633A39FB16040F96871C6308545404F7633A39FB1604043C5387F13884540EBFD463BEEB1604043C5387F13884540EBFD463BEEB16040F96871C6308545404F7633A39FB16040F96871C630854540
44985	32105	134.27001799999999	134.28450799999999	43.230837999999999	43.216194999999999	Шевченко	0103000020E610000001000000050000009AEAC9FCA3C8604084471B47AC9B45409AEAC9FCA3C8604047567E198C9D4540696E85B01AC9604047567E198C9D4540696E85B01AC9604084471B47AC9B45409AEAC9FCA3C8604084471B47AC9B4540
45032	31986	134.04564500000001	134.06553400000001	43.360073999999997	43.353865999999996	Центральная	0103000020E610000001000000050000003BC780EC75C160404A95287B4BAD45403BC780EC75C16040E811A3E716AE4540D658C2DA18C26040E811A3E716AE4540D658C2DA18C260404A95287B4BAD45403BC780EC75C160404A95287B4BAD4540
45086	32061	134.214708	134.24688599999999	43.299498999999997	43.289603999999997	Шоссейная	0103000020E6100000010000000500000011C64FE3DEC6604038656EBE11A5454011C64FE3DEC66040A417B5FB55A64540E3FA777DE6C76040A417B5FB55A64540E3FA777DE6C7604038656EBE11A5454011C64FE3DEC6604038656EBE11A54540
45163	55331	133.891063	133.924858	42.907516000000001	42.893687	30 лет Победы	0103000020E610000001000000050000009F758D9683BC604020EEEA55647245409F758D9683BC6040624CFA7B2974454035EECD6F98BD6040624CFA7B2974454035EECD6F98BD604020EEEA55647245409F758D9683BC604020EEEA5564724540
44483	4416	133.891063	133.924858	42.907516000000001	42.893687	Морская	0103000020E610000001000000050000009F758D9683BC604020EEEA55647245409F758D9683BC6040624CFA7B2974454035EECD6F98BD6040624CFA7B2974454035EECD6F98BD604020EEEA55647245409F758D9683BC604020EEEA5564724540
44826	4416	133.891063	133.924858	42.907516000000001	42.893687	Заречная	0103000020E610000001000000050000009F758D9683BC604020EEEA55647245409F758D9683BC6040624CFA7B2974454035EECD6F98BD6040624CFA7B2974454035EECD6F98BD604020EEEA55647245409F758D9683BC604020EEEA5564724540
44552	4416	133.891063	133.924858	42.907516000000001	42.893687	30 лет Победы	0103000020E610000001000000050000009F758D9683BC604020EEEA55647245409F758D9683BC6040624CFA7B2974454035EECD6F98BD6040624CFA7B2974454035EECD6F98BD604020EEEA55647245409F758D9683BC604020EEEA5564724540
44924	55298	133.89232100000001	133.92265699999999	43.400337999999998	43.364386000000003	Центральная	0103000020E610000001000000050000001711C5E48DBC6040658F5033A4AE45401711C5E48DBC60404BAC8C463EB345409D0DF96786BD60404BAC8C463EB345409D0DF96786BD6040658F5033A4AE45401711C5E48DBC6040658F5033A4AE4540
44916	55298	133.89232100000001	133.92265699999999	43.400337999999998	43.364386000000003	Советская	0103000020E610000001000000050000001711C5E48DBC6040658F5033A4AE45401711C5E48DBC60404BAC8C463EB345409D0DF96786BD60404BAC8C463EB345409D0DF96786BD6040658F5033A4AE45401711C5E48DBC6040658F5033A4AE4540
45158	55298	133.89232100000001	133.92265699999999	43.400337999999998	43.364386000000003	Некрасовская	0103000020E610000001000000050000001711C5E48DBC6040658F5033A4AE45401711C5E48DBC60404BAC8C463EB345409D0DF96786BD60404BAC8C463EB345409D0DF96786BD6040658F5033A4AE45401711C5E48DBC6040658F5033A4AE4540
45079	31759	133.851448	133.863045	43.270276000000003	43.262779000000002	Школьная	0103000020E61000000100000005000000D447E00F3FBB6040AD8905BEA2A14540D447E00F3FBB604065726A6798A245403E3F8C109EBB604065726A6798A245403E3F8C109EBB6040AD8905BEA2A14540D447E00F3FBB6040AD8905BEA2A14540
45074	31659	133.68790899999999	133.72037499999999	42.914278000000003	42.900660999999999	50 лет Октября	0103000020E61000000100000005000000F833BC5903B660402EE411DC48734540F833BC5903B66040E5B9BE0F07754540643BDF4F0DB76040E5B9BE0F07754540643BDF4F0DB760402EE411DC48734540F833BC5903B660402EE411DC48734540
9974	32137	134.379154	134.38993400000001	43.231140000000003	43.21837	Партизанская	0103000020E61000000100000005000000B9C4910722CC6040B936548CF39B4540B9C4910722CC60401366DAFE959D45402733DE567ACC60401366DAFE959D45402733DE567ACC6040B936548CF39B4540B9C4910722CC6040B936548CF39B4540
45075	32217	134.16399000000001	134.183986	43.075543000000003	43.066237000000001	Тигровая	0103000020E61000000100000005000000E0DBF4673FC5604080643A747A884540E0DBF4673FC560408B389D64AB894540809D9B36E3C560408B389D64AB894540809D9B36E3C5604080643A747A884540E0DBF4673FC5604080643A747A884540
44801	32185	134.282792	134.314278	43.13015	43.106177000000002	Первомайская	0103000020E6100000010000000500000041F2CEA10CC96040304B3B35978D454041F2CEA10CC9604086C954C1A8904540467BBC900ECA604086C954C1A8904540467BBC900ECA6040304B3B35978D454041F2CEA10CC96040304B3B35978D4540
44845	31744	133.74741399999999	133.76869500000001	43.177872000000001	43.157178999999999	Центральная	0103000020E6100000010000000500000052D2C3D0EAB760401A4F04711E94454052D2C3D0EAB76040E36F7B82C496454029B3412699B86040E36F7B82C496454029B3412699B860401A4F04711E94454052D2C3D0EAB760401A4F04711E944540
45157	31351	135.817339	135.83264600000001	46.460298999999999	46.439784000000003	Молодежная	0103000020E61000000100000005000000DA571EA427FA6040ECA694D74A384740DA571EA427FA6040D5B0DF13EB3A4740A6643909A5FA6040D5B0DF13EB3A4740A6643909A5FA6040ECA694D74A384740DA571EA427FA6040ECA694D74A384740
45071	29679	133.36456100000001	133.37768500000001	45.124738999999998	45.110981000000002	пер. Школьный	0103000020E61000000100000005000000B58CD47BAAAB60401BBD1AA0348E4640B58CD47BAAAB604093C49272F78F46401366DAFE15AC604093C49272F78F46401366DAFE15AC60401BBD1AA0348E4640B58CD47BAAAB60401BBD1AA0348E4640
44939	30170	133.94610299999999	133.979026	45.047131999999998	45.037272999999999	Петровская	0103000020E61000000100000005000000B874CC7946BE60400C03965CC5844640B874CC7946BE60402B4CDF6B08864640E17D552E54BF60402B4CDF6B08864640E17D552E54BF60400C03965CC5844640B874CC7946BE60400C03965CC5844640
44875	30345	133.50175200000001	133.52386799999999	45.203693999999999	45.188971000000002	Школьная	0103000020E610000001000000050000007CD6355A0EB060403B72A433309846407CD6355A0EB060401A321EA5129A464078EDD286C3B060401A321EA5129A464078EDD286C3B060403B72A433309846407CD6355A0EB060403B72A43330984640
44843	29270	133.463313	133.49169000000001	45.054715999999999	45.037329999999997	Первомайская	0103000020E61000000100000005000000F9D9C875D3AE60407094BC3AC7844640F9D9C875D3AE6040B24813EF00874640A6B8AAECBBAF6040B24813EF00874640A6B8AAECBBAF60407094BC3AC7844640F9D9C875D3AE60407094BC3AC7844640
45061	29177	133.48063200000001	133.49536499999999	44.960847999999999	44.946176999999999	Центральная	0103000020E61000000100000005000000282D5C5661AF60401B9DF3531C794640282D5C5661AF6040A8363811FD7A4640A852B307DAAF6040A8363811FD7A4640A852B307DAAF60401B9DF3531C794640282D5C5661AF60401B9DF3531C794640
44977	29078	133.32907700000001	133.36047300000001	44.972625999999998	44.95711	Кооперативная	0103000020E61000000100000005000000B51B7DCC87AA604058569A94827A4640B51B7DCC87AA6040A19E3E027F7C4640EA42ACFE88AB6040A19E3E027F7C4640EA42ACFE88AB604058569A94827A4640B51B7DCC87AA604058569A94827A4640
45042	55308	133.385096	133.40132	45.181728999999997	45.160404	Центральная	0103000020E6100000010000000500000041BAD8B452AC6040E412471E8894464041BAD8B452AC60400DDE57E54297464062670A9DD7AC60400DDE57E54297464062670A9DD7AC6040E412471E8894464041BAD8B452AC6040E412471E88944640
45035	29860	133.62092200000001	133.63675000000001	45.082833000000001	45.06841	Советская	0103000020E61000000100000005000000BE6BD097DEB36040145CACA8C1884640BE6BD097DEB36040C90391459A8A46404C37894160B46040C90391459A8A46404C37894160B46040145CACA8C1884640BE6BD097DEB36040145CACA8C1884640
44770	29831	133.25166999999999	133.27661599999999	45.138886999999997	45.120998999999998	Почтовая	0103000020E610000001000000050000004C6C3EAE0DA86040A2EC2DE57C8F46404C6C3EAE0DA86040766B990CC79146409C31CC09DAA86040766B990CC79146409C31CC09DAA86040A2EC2DE57C8F46404C6C3EAE0DA86040A2EC2DE57C8F4640
44984	29996	133.63504399999999	133.648967	44.937640000000002	44.925414000000004	Шоссейная	0103000020E61000000100000005000000AC70CB4752B460405AA148F773764640AC70CB4752B46040F2B5679604784640DD257156C4B46040F2B5679604784640DD257156C4B460405AA148F773764640AC70CB4752B460405AA148F773764640
45007	30253	133.71721199999999	133.74683899999999	44.801006000000001	44.785359999999997	Почтовая 	0103000020E610000001000000050000008F899466F3B6604014CB2DAD866446408F899466F3B660402CF3565D87664640130CE71AE6B760402CF3565D87664640130CE71AE6B7604014CB2DAD866446408F899466F3B6604014CB2DAD86644640
45017	29331	133.431342	133.441834	45.113405	45.107387000000003	Центральная	0103000020E6100000010000000500000085ECBC8DCDAD6040FE8172DBBE8D464085ECBC8DCDAD6040F819170E848E464059880E8123AE6040F819170E848E464059880E8123AE6040FE8172DBBE8D464085ECBC8DCDAD6040FE8172DBBE8D4640
44934	29005	133.28282300000001	133.30193	45.015416000000002	44.988641999999999	Советская	0103000020E61000000100000005000000D0F1D1E20CA96040DCB930D28B7E4640D0F1D1E20CA96040E6EAC726F9814640CD751A69A9A96040E6EAC726F9814640CD751A69A9A96040DCB930D28B7E4640D0F1D1E20CA96040DCB930D28B7E4640
44911	3421	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Уткинская	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
44802	3421	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Советская	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
44825	3421	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Набережная	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
44482	3421	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Ленинская	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
44879	55293	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Пролетарская	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
45078	55293	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Площадь Свободы	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
44955	55293	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Колхозная	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
44809	55293	133.472206	133.52669800000001	45.106839999999998	45.073700000000002	Гагарина	0103000020E6100000010000000500000033DFC14F1CAF60408CDB68006F89464033DFC14F1CAF6040CBF3E0EEAC8D4640CC9BC3B5DAB06040CBF3E0EEAC8D4640CC9BC3B5DAB060408CDB68006F89464033DFC14F1CAF60408CDB68006F894640
45072	55312	133.940471	133.96450999999999	44.850569999999998	44.836772000000003	Приисковая	0103000020E61000000100000005000000C47AA35618BE6040B11A4B581B6B4640C47AA35618BE6040B77A4E7ADF6C464047551344DDBE6040B77A4E7ADF6C464047551344DDBE6040B11A4B581B6B4640C47AA35618BE6040B11A4B581B6B4640
44982	3635	133.4879	133.51319599999999	45.249907	45.216088999999997	проспект Лазурный	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
44774	3635	133.4879	133.51319599999999	45.249907	45.216088999999997	Юбилейная	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
44844	3635	133.4879	133.51319599999999	45.249907	45.216088999999997	Санаторная	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
44471	3635	133.4879	133.51319599999999	45.249907	45.216088999999997	60 лет СССР	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
44944	55302	133.4879	133.51319599999999	45.249907	45.216088999999997	Юбилейная	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
45023	55302	133.4879	133.51319599999999	45.249907	45.216088999999997	Профсоюзная	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
44980	55302	133.4879	133.51319599999999	45.249907	45.216088999999997	Октябрьская	0103000020E61000000100000005000000FDF675E09CAF60403E03EACDA89B4640FDF675E09CAF60404F05DCF3FC9F4640048E041A6CB060404F05DCF3FC9F4640048E041A6CB060403E03EACDA89B4640FDF675E09CAF60403E03EACDA89B4640
45005	30182	133.670635	133.67946499999999	44.863126000000001	44.852302000000002	Центральная	0103000020E61000000100000005000000B21188D775B560405F28603B186D4640B21188D775B56040E529ABE97A6E4640DA38622DBEB56040E529ABE97A6E4640DA38622DBEB560405F28603B186D4640B21188D775B560405F28603B186D4640
45073	30102	133.84914800000001	133.861581	44.933371999999999	44.911710999999997	Верхняя	0103000020E61000000100000005000000D82E6D382CBB6040A43330F2B2744640D82E6D382CBB60404580D3BB787746405C3B511292BB60404580D3BB787746405C3B511292BB6040A43330F2B2744640D82E6D382CBB6040A43330F2B2744640
45066	29144	133.39433099999999	133.409198	44.934277999999999	44.918163999999997	Первомайская	0103000020E6100000010000000500000091990B5C9EAC6040A92EE0658675464091990B5C9EAC6040A7AFE76B96774640D672672618AD6040A7AFE76B96774640D672672618AD6040A92EE0658675464091990B5C9EAC6040A92EE06586754640
44937	29952	133.544781	133.56468699999999	45.065418000000001	45.045355000000001	Центральная	0103000020E610000001000000050000006E4F90D86EB16040E4DA5031CE8546406E4F90D86EB16040ED48F59D5F8846403EAF78EA11B26040ED48F59D5F8846403EAF78EA11B26040E4DA5031CE8546406E4F90D86EB16040E4DA5031CE854640
44935	29071	133.319807	133.34727699999999	44.917876999999997	44.900531999999998	Центральная	0103000020E6100000010000000500000005C1E3DB3BAA60403080F0A14473464005C1E3DB3BAA6040136058FE7C754640E5B4A7E41CAB6040136058FE7C754640E5B4A7E41CAB60403080F0A14473464005C1E3DB3BAA60403080F0A144734640
45021	29781	133.30112199999999	133.32475600000001	45.140095000000002	45.11759	Центральная	0103000020E6100000010000000500000065C39ACAA2A96040172B6A300D8F464065C39ACAA2A96040A4AA09A2EE914640C1E5B16664AA6040A4AA09A2EE914640C1E5B16664AA6040172B6A300D8F464065C39ACAA2A96040172B6A300D8F4640
44771	28681	135.08054999999999	135.109511	44.364705999999998	44.334029999999998	Фрунзе	0103000020E610000001000000050000002BF697DD93E2604002F1BA7EC12A46402BF697DD93E26040D653ABAFAE2E4640AC71361D81E36040D653ABAFAE2E4640AC71361D81E3604002F1BA7EC12A46402BF697DD93E2604002F1BA7EC12A4640
44436	28681	135.08054999999999	135.109511	44.364705999999998	44.334029999999998	Комсомольская	0103000020E610000001000000050000002BF697DD93E2604002F1BA7EC12A46402BF697DD93E26040D653ABAFAE2E4640AC71361D81E36040D653ABAFAE2E4640AC71361D81E3604002F1BA7EC12A46402BF697DD93E2604002F1BA7EC12A4640
45067	28015	135.218962	135.23719800000001	44.256517000000002	44.247781000000003	Центральная	0103000020E6100000010000000500000023A298BC01E76040FCC8AD49B71F464023A298BC01E760401CEF8E8CD5204640A795422097E760401CEF8E8CD5204640A795422097E76040FCC8AD49B71F464023A298BC01E76040FCC8AD49B71F4640
44933	27970	135.345732	135.348814	44.255212999999998	44.243138000000002	Вобликова	0103000020E61000000100000005000000C8258E3C10EB60401A355F251F1F4640C8258E3C10EB6040CC41D0D1AA204640624CFA7B29EB6040CC41D0D1AA204640624CFA7B29EB60401A355F251F1F4640C8258E3C10EB60401A355F251F1F4640
44938	28062	135.11264600000001	135.13234600000001	44.241311000000003	44.230079000000003	Речная	0103000020E61000000100000005000000CFC0C8CB9AE360408A3F8A3A731D4640CFC0C8CB9AE3604021956247E31E464035B8AD2D3CE4604021956247E31E464035B8AD2D3CE460408A3F8A3A731D4640CFC0C8CB9AE360408A3F8A3A731D4640
44773	28837	134.936172	134.98049499999999	44.348689999999998	44.271416000000002	Поворотная	0103000020E61000000100000005000000CA6DFB1EF5DD60403ACE6DC2BD224640CA6DFB1EF5DD60409B38B9DFA12C464087DC0C3760DF60409B38B9DFA12C464087DC0C3760DF60403ACE6DC2BD224640CA6DFB1EF5DD60403ACE6DC2BD224640
44339	55249	135.027738	135.086658	44.344293999999998	44.247897000000002	Арсеньева	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
44546	55277	135.027738	135.086658	44.344293999999998	44.247897000000002	Арсеньева	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
43213	28261	135.027738	135.086658	44.344293999999998	44.247897000000002	Рабочая	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
44468	28261	135.027738	135.086658	44.344293999999998	44.247897000000002	Первомайская	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
43199	28261	135.027738	135.086658	44.344293999999998	44.247897000000002	Гагарина	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
42651	28261	135.027738	135.086658	44.344293999999998	44.247897000000002	Арсеньева	0103000020E61000000100000005000000685BCD3AE3E0604065E3C116BB1F4640685BCD3AE3E06040C11A67D3112C4640FA7DFFE6C5E26040C11A67D3112C4640FA7DFFE6C5E2604065E3C116BB1F4640685BCD3AE3E0604065E3C116BB1F4640
45016	27885	135.54452900000001	135.561049	44.222346999999999	44.211984999999999	Школьная	0103000020E6100000010000000500000028D714C86CF160400C1F1153221B464028D714C86CF160408EAED2DD751C4640834E081DF4F160408EAED2DD751C4640834E081DF4F160400C1F1153221B464028D714C86CF160400C1F1153221B4640
44393	55257	135.08529300000001	135.126364	44.287517999999999	44.243377000000002	Строительная	0103000020E610000001000000050000007DB262B8BAE260409FCC3FFA261F46407DB262B8BAE260407381CB63CD24464089EC832C0BE460407381CB63CD24464089EC832C0BE460409FCC3FFA261F46407DB262B8BAE260409FCC3FFA261F4640
44820	55257	135.08529300000001	135.126364	44.287517999999999	44.243377000000002	Советская	0103000020E610000001000000050000007DB262B8BAE260409FCC3FFA261F46407DB262B8BAE260407381CB63CD24464089EC832C0BE460407381CB63CD24464089EC832C0BE460409FCC3FFA261F46407DB262B8BAE260409FCC3FFA261F4640
45003	28066	135.38435100000001	135.41299799999999	44.411388000000002	44.402689000000002	Арсеньева	0103000020E61000000100000005000000EBE5779A4CEC6040BFBA2A508B334640EBE5779A4CEC6040C2FBAA5CA834464007EA944737ED6040C2FBAA5CA834464007EA944737ED6040BFBA2A508B334640EBE5779A4CEC6040BFBA2A508B334640
44929	27919	135.442553	135.46831599999999	44.257589000000003	44.240555000000001	Рабочая	0103000020E61000000100000005000000E5B7E86429EE6040D4F19881CA1E4640E5B7E86429EE6040996725ADF82046403106D671FCEE6040996725ADF82046403106D671FCEE6040D4F19881CA1E4640E5B7E86429EE6040D4F19881CA1E4640
44964	32238	134.306579	134.321563	45.583236999999997	45.571250999999997	Центральная	0103000020E610000001000000050000007E54C37ECFC960405567B5C01EC946407E54C37ECFC9604098689082A7CA464051137D3E4ACA604098689082A7CA464051137D3E4ACA60405567B5C01EC946407E54C37ECFC960405567B5C01EC94640
44967	31896	134.04037199999999	134.06163599999999	45.836787000000001	45.825622000000003	Лободы	0103000020E61000000100000005000000927538BA4AC16040D76D50FBADE94640927538BA4AC16040E65B1FD61BEB464033880FECF8C16040E65B1FD61BEB464033880FECF8C16040D76D50FBADE94640927538BA4AC16040D76D50FBADE94640
44968	31878	133.951987	133.969235	45.890535	45.876902999999999	Центральная	0103000020E61000000100000005000000F3E670AD76BE6040D461855B3EF04640F3E670AD76BE6040C078060DFDF146406F641EF903BF6040C078060DFDF146406F641EF903BF6040D461855B3EF04640F3E670AD76BE6040D461855B3EF04640
44542	32045	133.74727899999999	133.77301600000001	45.979219999999998	45.965271000000001	Советская	0103000020E610000001000000050000009A3FA6B5E9B760407C6308008EFB46409A3FA6B5E9B7604068CBB91457FD46401DE90C8CBCB8604068CBB91457FD46401DE90C8CBCB860407C6308008EFB46409A3FA6B5E9B760407C6308008EFB4640
44970	32421	134.376441	134.39032900000001	45.124859000000001	45.108258999999997	Школьная	0103000020E61000000100000005000000F4FBFECD0BCC6040B33F506EDB8D4640F4FBFECD0BCC60403ECE3461FB8F4640C6353E937DCC60403ECE3461FB8F4640C6353E937DCC6040B33F506EDB8D4640F4FBFECD0BCC6040B33F506EDB8D4640
45059	31973	134.100739	134.11962199999999	45.799363999999997	45.780762000000003	Пионерская	0103000020E61000000100000005000000D1CDFE4039C36040D3FA5B02F0E34640D1CDFE4039C36040C4CC3E8F51E646403A3C84F1D3C36040C4CC3E8F51E646403A3C84F1D3C36040D3FA5B02F0E34640D1CDFE4039C36040D3FA5B02F0E34640
44976	32020	134.09283400000001	134.12106800000001	45.713492000000002	45.690852	П.Марценюка	0103000020E610000001000000050000009F3E027FF8C2604027309DD66DD846409F3E027FF8C2604094FAB2B453DB4640F392FFC9DFC3604094FAB2B453DB4640F392FFC9DFC3604027309DD66DD846409F3E027FF8C2604027309DD66DD84640
44799	32245	134.28841499999999	134.31602899999999	45.414571000000002	45.396802000000001	Школьная	0103000020E61000000100000005000000A01518B23AC96040637E6E68CAB24640A01518B23AC960405D6F9BA910B54640CD72D9E81CCA60405D6F9BA910B54640CD72D9E81CCA6040637E6E68CAB24640A01518B23AC96040637E6E68CAB24640
45110	31176	134.239125	134.25969599999999	45.678063999999999	45.673020000000001	Центральная	0103000020E61000000100000005000000FED478E9A6C76040E7C6F48425D64640FED478E9A6C76040274C18CDCAD64640DD5CFC6D4FC86040274C18CDCAD64640DD5CFC6D4FC86040E7C6F48425D64640FED478E9A6C76040E7C6F48425D64640
44633	27782	133.62723700000001	133.69152099999999	45.887129000000002	45.853926999999999	Некрасовская	0103000020E61000000100000005000000EB3A545312B46040F015DD7A4DED4640EB3A545312B46040A62A6D718DF14640E9EFA5F020B66040A62A6D718DF14640E9EFA5F020B66040F015DD7A4DED4640EB3A545312B46040F015DD7A4DED4640
44807	27782	133.578405	133.710206	45.921289000000002	45.829227000000003	Лазо	0103000020E61000000100000005000000F9DA334B82B26040E8FA3E1C24EA4640F9DA334B82B26040109546CCECF5464089EDEE01BAB66040109546CCECF5464089EDEE01BAB66040E8FA3E1C24EA4640F9DA334B82B26040E8FA3E1C24EA4640
44622	27782	133.62723700000001	133.69152099999999	45.887129000000002	45.853926999999999	Калинина	0103000020E61000000100000005000000EB3A545312B46040F015DD7A4DED4640EB3A545312B46040A62A6D718DF14640E9EFA5F020B66040A62A6D718DF14640E9EFA5F020B66040F015DD7A4DED4640EB3A545312B46040F015DD7A4DED4640
45112	32324	134.24740700000001	134.26413400000001	45.480589999999999	45.466723999999999	Майская	0103000020E61000000100000005000000A6B915C2EAC760401021AE9CBDBB4640A6B915C2EAC760406F641EF983BD4640607825C973C860406F641EF983BD4640607825C973C860401021AE9CBDBB4640A6B915C2EAC760401021AE9CBDBB4640
44819	1239	133.60812100000001	133.61992499999999	45.824396999999998	45.817450999999998	Лазо	0103000020E6100000010000000500000059E02BBA75B360408F8AFF3BA2E8464059E02BBA75B36040D3F544D785E94640211FF46CD6B36040D3F544D785E94640211FF46CD6B360408F8AFF3BA2E8464059E02BBA75B360408F8AFF3BA2E84640
44389	31824	133.88699399999999	133.92910699999999	45.884186999999997	45.868268	Мелехина	0103000020E61000000100000005000000F1B73D4162BC6040E814E46723EF4640F1B73D4162BC60403046240A2DF14640826F9A3EBBBD60403046240A2DF14640826F9A3EBBBD6040E814E46723EF4640F1B73D4162BC6040E814E46723EF4640
44617	26692	135.73957200000001	135.75741199999999	44.454520000000002	44.434545	Линейная 	0103000020E610000001000000050000003221E692AAF76040F6D1A92B9F3746403221E692AAF7604060B01BB62D3A4640223317B83CF8604060B01BB62D3A4640223317B83CF86040F6D1A92B9F3746403221E692AAF76040F6D1A92B9F374640
44620	55283	135.79778300000001	135.84286	44.384614999999997	44.344718999999998	Арсеньева	0103000020E61000000100000005000000C1C9367087F96040A8A78FC01F2C4640C1C9367087F96040884677103B31464069E388B5F8FA6040884677103B31464069E388B5F8FA6040A8A78FC01F2C4640C1C9367087F96040A8A78FC01F2C4640
44467	55262	135.41949299999999	135.50874099999999	44.620241999999998	44.545102	Центральная	0103000020E61000000100000005000000D47C957C6CED6040FA7DFFE6C5454640D47C957C6CED604085CD0017644F46404CA4349B47F0604085CD0017644F46404CA4349B47F06040FA7DFFE6C5454640D47C957C6CED6040FA7DFFE6C5454640
44936	26738	135.76141000000001	135.78601499999999	44.399963999999997	44.373108999999999	Школьная	0103000020E610000001000000050000001E1B81785DF86040F06B2409C22F46401E1B81785DF86040E6C93505323346404BE5ED0827F96040E6C93505323346404BE5ED0827F96040F06B2409C22F46401E1B81785DF86040F06B2409C22F4640
44459	25907	135.31290799999999	135.38204200000001	44.64799	44.611477000000001	Октябрьская	0103000020E610000001000000050000000455A35703EA6040CBA0DAE0444E46400455A35703EA604049111956F15246405AF624B039EC604049111956F15246405AF624B039EC6040CBA0DAE0444E46400455A35703EA6040CBA0DAE0444E4640
45020	15709	132.15443099999999	132.169254	43.459947	43.447080999999997	Чернышева	0103000020E61000000100000005000000A2CF4719F1846040DCD440F339B94540A2CF4719F18460405872158BDFBA4540F3565D876A8560405872158BDFBA4540F3565D876A856040DCD440F339B94540A2CF4719F1846040DCD440F339B94540
44432	259	132.35720800000001	132.38187600000001	43.395299999999999	43.381909	Гидроузла	0103000020E61000000100000005000000D4BB783F6E8B60402786E464E2B04540D4BB783F6E8B6040ED0DBE3099B2454013640454388C6040ED0DBE3099B2454013640454388C60402786E464E2B04540D4BB783F6E8B60402786E464E2B04540
44632	15214	132.32328799999999	132.330986	43.424359000000003	43.416567000000001	Ярославская	0103000020E610000001000000050000000E661360588A6040E2CB441152B545400E661360588A6040B3614D6551B64540E2ADF36F978A6040B3614D6551B64540E2ADF36F978A6040E2CB441152B545400E661360588A6040E2CB441152B54540
4388	15571	132.18475799999999	132.188468	43.404870000000003	43.404443999999998	переулок Чуркина	0103000020E6100000010000000500000094F59B89E98560401E882CD2C4B3454094F59B89E9856040D690B8C7D2B34540F60A0BEE07866040D690B8C7D2B34540F60A0BEE078660401E882CD2C4B3454094F59B89E98560401E882CD2C4B34540
44449	12199	133.097375	133.16551200000001	44.212992	44.178699999999999	Советская	0103000020E61000000100000005000000560E2DB21DA36040C9E53FA4DF164640560E2DB21DA36040A2276552431B46400F63D2DF4BA56040A2276552431B46400F63D2DF4BA56040C9E53FA4DF164640560E2DB21DA36040C9E53FA4DF164640
44981	12007	133.01063400000001	133.04511099999999	44.192177999999998	44.168833999999997	Молодежная	0103000020E6100000010000000500000039471D1D57A06040F7393E5A9C15464039471D1D57A060405E81E8499918464013B69F8C71A160405E81E8499918464013B69F8C71A16040F7393E5A9C15464039471D1D57A06040F7393E5A9C154640
44989	11504	133.211263	133.23873399999999	44.108626000000001	44.093173999999998	Советская	0103000020E610000001000000050000005B7B9FAAC2A66040336B2920ED0B46405B7B9FAAC2A6604066BFEE74E70D46402F4E7CB5A3A7604066BFEE74E70D46402F4E7CB5A3A76040336B2920ED0B46405B7B9FAAC2A66040336B2920ED0B4640
44997	11351	133.11608699999999	133.124145	44.008209999999998	43.996026000000001	Комарова	0103000020E61000000100000005000000B48F15FCB6A360409CFBABC77DFF4540B48F15FCB6A3604005C078060D014640C85EEFFEF8A3604005C078060D014640C85EEFFEF8A360409CFBABC77DFF4540B48F15FCB6A360409CFBABC77DFF4540
45019	11840	132.920119	132.937825	43.891195000000003	43.882015000000003	Мира	0103000020E61000000100000005000000B4AD669D719D60406DCA15DEE5F04540B4AD669D719D6040EBAD81AD12F24540E10B93A9029E6040EBAD81AD12F24540E10B93A9029E60406DCA15DEE5F04540B4AD669D719D60406DCA15DEE5F04540
45070	11695	132.899135	132.91330099999999	43.854672999999998	43.847060999999997	Центральная	0103000020E610000001000000050000000C76C3B6C59C6040C85BAE7E6CEC45400C76C3B6C59C604019E3C3EC65ED4540EECC04C3399D604019E3C3EC65ED4540EECC04C3399D6040C85BAE7E6CEC45400C76C3B6C59C6040C85BAE7E6CEC4540
44926	11898	133.102441	133.12773799999999	44.228400000000001	44.215052999999997	Увальная	0103000020E61000000100000005000000A018593247A360400EF450DB861B4640A018593247A36040053411363C1D46409B8E006E16A46040053411363C1D46409B8E006E16A460400EF450DB861B4640A018593247A360400EF450DB861B4640
44805	11913	133.24526499999999	133.28149400000001	44.213154000000003	44.183019000000002	Школьная	0103000020E610000001000000050000004F3BFC35D9A76040F8C5A52A6D1746404F3BFC35D9A760407C8159A1481B4640A680B4FF01A960407C8159A1481B4640A680B4FF01A96040F8C5A52A6D1746404F3BFC35D9A76040F8C5A52A6D174640
45124	12091	133.037556	133.057121	44.161405000000002	44.146355	Молодежная	0103000020E6100000010000000500000098F8A3A833A16040944DB9C2BB12464098F8A3A833A16040983446EBA8144640465D6BEFD3A16040983446EBA8144640465D6BEFD3A16040944DB9C2BB12464098F8A3A833A16040944DB9C2BB124640
44804	11433	133.12924699999999	133.15497500000001	44.040677000000002	44.024428999999998	Комсомольская	0103000020E6100000010000000500000065C39ACA22A4604078094E7D2003464065C39ACA22A46040865968E7340546405396218EF5A46040865968E7340546405396218EF5A4604078094E7D2003464065C39ACA22A4604078094E7D20034640
9961	11250	132.97720699999999	132.99014299999999	43.975543000000002	43.968496999999999	Ленинская	0103000020E61000000100000005000000834D9D47459F604016A3AEB5F7FB4540834D9D47459F6040BE6BD097DEFC4540A06B5F40AF9F6040BE6BD097DEFC4540A06B5F40AF9F604016A3AEB5F7FB4540834D9D47459F604016A3AEB5F7FB4540
45014	11615	133.257769	133.279526	43.890642999999997	43.876134	Партизанская	0103000020E61000000100000005000000861DC6A43FA86040F374AE2825F04540861DC6A43FA86040A6B4FE9600F24540378C82E0F1A86040A6B4FE9600F24540378C82E0F1A86040F374AE2825F04540861DC6A43FA86040F374AE2825F04540
44928	12112	133.16205400000001	133.177774	44.149614999999997	44.131507999999997	Первомайская	0103000020E61000000100000005000000F4C5DE8B2FA56040C8940F41D5104640F4C5DE8B2FA56040DAFE95952613464088821953B0A56040DAFE95952613464088821953B0A56040C8940F41D5104640F4C5DE8B2FA56040C8940F41D5104640
45068	11791	132.96221399999999	132.966589	43.747430000000001	43.734690000000001	Центральная	0103000020E610000001000000050000001BB80375CA9E6040605969520ADE45401BB80375CA9E60404F0647C9ABDF45408CF50D4CEE9E60404F0647C9ABDF45408CF50D4CEE9E6040605969520ADE45401BB80375CA9E6040605969520ADE4540
45065	11600	133.22269	133.23441299999999	43.840584999999997	43.830806000000003	Школьный	0103000020E61000000100000005000000AE64C74620A7604009A9DBD957EA4540AE64C74620A760400B410E4A98EB45403B18B14F80A760400B410E4A98EB45403B18B14F80A7604009A9DBD957EA4540AE64C74620A7604009A9DBD957EA4540
44925	11310	133.13857200000001	133.154427	43.863928999999999	43.855434000000002	Центральная	0103000020E6100000010000000500000086048C2E6FA4604078F17EDC7EED454086048C2E6FA460407288B83995EE4540D253E410F1A460407288B83995EE4540D253E410F1A4604078F17EDC7EED454086048C2E6FA4604078F17EDC7EED4540
44842	11972	133.16420099999999	133.18599399999999	44.231389999999998	44.205768999999997	Юбилейная	0103000020E610000001000000050000000E9F742241A56040EBC37AA3561A46400E9F742241A560408B4F01309E1D46401268B0A9F3A560408B4F01309E1D46401268B0A9F3A56040EBC37AA3561A46400E9F742241A56040EBC37AA3561A4640
45064	11737	132.942092	132.96127100000001	43.765017	43.757933000000001	Советская	0103000020E61000000100000005000000583A1F9E259E604093C7D3F203E14540583A1F9E259E604028F1B913ECE14540FC7266BBC29E604028F1B913ECE14540FC7266BBC29E604093C7D3F203E14540583A1F9E259E604093C7D3F203E14540
44923	11101	133.03010900000001	133.07240200000001	43.972461000000003	43.953885	Центральная	0103000020E61000000100000005000000174A26A7F6A060408E9257E718FA4540174A26A7F6A0604057D11F9A79FC454048C5FF1D51A2604057D11F9A79FC454048C5FF1D51A260408E9257E718FA4540174A26A7F6A060408E9257E718FA4540
44558	11101	133.03010900000001	133.07240200000001	43.972461000000003	43.953885	Лазо	0103000020E61000000100000005000000174A26A7F6A060408E9257E718FA4540174A26A7F6A0604057D11F9A79FC454048C5FF1D51A2604057D11F9A79FC454048C5FF1D51A260408E9257E718FA4540174A26A7F6A060408E9257E718FA4540
9957	11101	133.03010900000001	133.07240200000001	43.972461000000003	43.953885	Горького	0103000020E61000000100000005000000174A26A7F6A060408E9257E718FA4540174A26A7F6A0604057D11F9A79FC454048C5FF1D51A2604057D11F9A79FC454048C5FF1D51A260408E9257E718FA4540174A26A7F6A060408E9257E718FA4540
46013	55653	150.233071	151.28772900000001	60.175257000000002	59.645619000000003	Гагарина	0103000020E61000000100000005000000AC54505175C762408F56B5A4A3D24D40AC54505175C7624092B245D26E164E408CA3721335E9624092B245D26E164E408CA3721335E962408F56B5A4A3D24D40AC54505175C762408F56B5A4A3D24D40
46008	55652	147.62070800000001	148.675366	63.017885	62.534747000000003	Ленина	0103000020E61000000100000005000000B30B06D7DC7362402B51F69672444F40B30B06D7DC736240630B410E4A824F40925A28999C956240630B410E4A824F40925A28999C9562402B51F69672444F40B30B06D7DC7362402B51F69672444F40
46028	55654	150.233071	151.28772900000001	60.175257000000002	59.645619000000003	Гагарина	0103000020E61000000100000005000000AC54505175C762408F56B5A4A3D24D40AC54505175C7624092B245D26E164E408CA3721335E9624092B245D26E164E408CA3721335E962408F56B5A4A3D24D40AC54505175C762408F56B5A4A3D24D40
46005	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Шандора Шимича	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45983	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Ш.Шимича	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46000	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Речная	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45994	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Пушкина	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45999	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Пролетарская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45996	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Портовая	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46032	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Пионерская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46026	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Первомайская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46016	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Парковая	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46001	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Октябрьская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45997	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Новая	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46017	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Наровчатова	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45988	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Набережная р. Магаданки	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46025	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Марчеканская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46019	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Майская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45985	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Лукса	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46014	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Красноярская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45995	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Комсомольская площадь	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46010	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Комсомольская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45998	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Колымская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45979	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Карла Маркса	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45982	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Зайцева	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
45984	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Берзина	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46035	231	150.28574900000001	151.340407	59.82291	59.287596000000001	Арманская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46022	231	150.28574900000001	151.340407	59.82291	59.287596000000001	 Марчеканское шоссе	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46027	231	150.28574900000001	151.340407	59.82291	59.287596000000001	 Колымская	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46004	231	150.28574900000001	151.340407	59.82291	59.287596000000001	 Карла Маркса	0103000020E61000000100000005000000AC3B16DB24C96240EF3A1BF2CFA44D40AC3B16DB24C9624093C6681D55E94D408B8A389DE4EA624093C6681D55E94D408B8A389DE4EA6240EF3A1BF2CFA44D40AC3B16DB24C96240EF3A1BF2CFA44D40
46054	31995	149.09912800000001	150.153786	62.769500999999998	62.282251000000002	Школьная	0103000020E61000000100000005000000C6C37B0E2CA36240B421FFCC20244F40C6C37B0E2CA36240A19E3E027F624F40A5129ED0EBC46240A19E3E027F624F40A5129ED0EBC46240B421FFCC20244F40C6C37B0E2CA36240B421FFCC20244F40
46055	31995	149.09912800000001	150.153786	62.769500999999998	62.282251000000002	Ленина	0103000020E61000000100000005000000C6C37B0E2CA36240B421FFCC20244F40C6C37B0E2CA36240A19E3E027F624F40A5129ED0EBC46240A19E3E027F624F40A5129ED0EBC46240B421FFCC20244F40C6C37B0E2CA36240B421FFCC20244F40
46051	32187	149.952887	151.00754499999999	62.329037	61.834516999999998	Когодовского	0103000020E6100000010000000500000013B9E00C7EBE62405F7AFB73D1EA4E4013B9E00C7EBE6240441669E21D2A4F40F20703CF3DE06240441669E21D2A4F40F20703CF3DE062405F7AFB73D1EA4E4013B9E00C7EBE62405F7AFB73D1EA4E40
46056	32081	149.15223599999999	150.20689400000001	62.789022000000003	62.302095000000001	Подгорная	0103000020E61000000100000005000000C328081EDFA462407FA4880CAB264F40C328081EDFA462408AE942ACFE644F40A3772AE09EC662408AE942ACFE644F40A3772AE09EC662407FA4880CAB264F40C328081EDFA462407FA4880CAB264F40
46052	32214	151.14549	152.20014800000001	62.498088000000003	62.006354999999999	Спортивная	0103000020E61000000100000005000000A4FCA4DAA7E4624042959A3DD0004F40A4FCA4DAA7E46240D943FB58C13F4F40844BC79C67066340D943FB58C13F4F40844BC79C6706634042959A3DD0004F40A4FCA4DAA7E4624042959A3DD0004F40
46058	32142	150.22042300000001	151.275081	62.587404999999997	62.097147	Мацкевича	0103000020E61000000100000005000000290989B40DC76240C7F319506F0C4F40290989B40DC76240E1404816304B4F400858AB76CDE86240E1404816304B4F400858AB76CDE86240C7F319506F0C4F40290989B40DC76240C7F319506F0C4F40
46053	31953	148.573847	149.62850499999999	62.892856000000002	62.407646999999997	Нагорная	0103000020E610000001000000050000000C3D62F45C92624000A8E2C62D344F400C3D62F45C926240C904FC1A49724F40EB8B84B61CB46240C904FC1A49724F40EB8B84B61CB4624000A8E2C62D344F400C3D62F45C92624000A8E2C62D344F40
46043	31926	151.86837299999999	152.92303200000001	61.396185000000003	60.886367	Зеленая	0103000020E6100000010000000500000057772CB6C9FB624077A04E7974714E4057772CB6C9FB62403815A930B6B24E402BA5677A891D63403815A930B6B24E402BA5677A891D634077A04E7974714E4057772CB6C9FB624077A04E7974714E40
46012	31617	150.213919	151.26857699999999	60.317723000000001	59.790385000000001	Советская	0103000020E61000000100000005000000C79FA86CD8C66240DE1FEF552BE54D40C79FA86CD8C66240F017B325AB284E40A6EECA2E98E86240F017B325AB284E40A6EECA2E98E86240DE1FEF552BE54D40C79FA86CD8C66240DE1FEF552BE54D40
45993	140	150.410551	151.46521000000001	60.365841000000003	59.839280000000002	Юбилейная	0103000020E61000000100000005000000E2CAD93B23CD6240EC17EC866DEB4D40E2CAD93B23CD62409A44BDE0D32E4E40B6F81400E3EE62409A44BDE0D32E4E40B6F81400E3EE6240EC17EC866DEB4D40E2CAD93B23CD6240EC17EC866DEB4D40
46046	140	150.410551	151.46521000000001	60.365841000000003	59.839280000000002	Цареградского	0103000020E61000000100000005000000E2CAD93B23CD6240EC17EC866DEB4D40E2CAD93B23CD62409A44BDE0D32E4E40B6F81400E3EE62409A44BDE0D32E4E40B6F81400E3EE6240EC17EC866DEB4D40E2CAD93B23CD6240EC17EC866DEB4D40
46020	140	150.410551	151.46521000000001	60.365841000000003	59.839280000000002	Ленина	0103000020E61000000100000005000000E2CAD93B23CD6240EC17EC866DEB4D40E2CAD93B23CD62409A44BDE0D32E4E40B6F81400E3EE62409A44BDE0D32E4E40B6F81400E3EE6240EC17EC866DEB4D40E2CAD93B23CD6240EC17EC866DEB4D40
46048	31861	151.256495	152.31115299999999	61.097658000000003	60.582971999999998	Санаторная	0103000020E61000000100000005000000CD92003535E86240EA3D95D39E4A4E40CD92003535E86240AD18AE0E808C4E40ACE122F7F4096340AD18AE0E808C4E40ACE122F7F4096340EA3D95D39E4A4E40CD92003535E86240EA3D95D39E4A4E40
46044	55655	146.09569200000001	151.218999	62.501299000000003	60.403796	Гагарина	0103000020E61000000100000005000000A54FABE80F436240B8205B96AF334E40A54FABE80F4362403E42CD902A404F406ADB300A02E762403E42CD902A404F406ADB300A02E76240B8205B96AF334E40A54FABE80F436240B8205B96AF334E40
45992	31358	149.100853	150.15551099999999	61.373939	60.863757	Победы	0103000020E61000000100000005000000831612303AA362407558E1968F6E4E40831612303AA3624077D9AF3BDDAF4E40626534F2F9C4624077D9AF3BDDAF4E40626534F2F9C462407558E1968F6E4E40831612303AA362407558E1968F6E4E40
46002	31358	149.100853	150.15551099999999	61.373939	60.863757	Горняцкая	0103000020E61000000100000005000000831612303AA362407558E1968F6E4E40831612303AA3624077D9AF3BDDAF4E40626534F2F9C4624077D9AF3BDDAF4E40626534F2F9C462407558E1968F6E4E40831612303AA362407558E1968F6E4E40
46042	31467	147.66072800000001	148.715386	61.749374000000003	61.245331999999998	Шоссейная	0103000020E61000000100000005000000A6F10BAF24756240C554FA09679F4E40A6F10BAF24756240823CBB7CEBDF4E4085402E71E4966240823CBB7CEBDF4E4085402E71E4966240C554FA09679F4E40A6F10BAF24756240C554FA09679F4E40
46036	31563	147.34008299999999	148.39474100000001	61.892347999999998	61.390650000000001	Новая	0103000020E610000001000000050000009E5DBEF5E16A62405917B7D100B24E409E5DBEF5E16A62405453927538F24E407EACE0B7A18C62405453927538F24E407EACE0B7A18C62405917B7D100B24E409E5DBEF5E16A62405917B7D100B24E40
46038	31563	147.34008299999999	148.39474100000001	61.892347999999998	61.390650000000001	Клубная	0103000020E610000001000000050000009E5DBEF5E16A62405917B7D100B24E409E5DBEF5E16A62405453927538F24E407EACE0B7A18C62405453927538F24E407EACE0B7A18C62405917B7D100B24E409E5DBEF5E16A62405917B7D100B24E40
46034	31071	147.51244299999999	148.56710100000001	63.313248000000002	62.835011999999999	Октябрьская	0103000020E610000001000000050000000DC2DCEE657062403FE257ACE16A4F400DC2DCEE65706240CAC4AD8218A84F40ED10FFB025926240CAC4AD8218A84F40ED10FFB0259262403FE257ACE16A4F400DC2DCEE657062403FE257ACE16A4F40
46030	31085	147.38267200000001	148.43733	62.957286000000003	62.473143999999998	Халезина	0103000020E610000001000000050000000AA359D93E6C624039268BFB8F3C4F400AA359D93E6C62409775FF58887A4F40E9F17B9BFE8D62409775FF58887A4F40E9F17B9BFE8D624039268BFB8F3C4F400AA359D93E6C624039268BFB8F3C4F40
45989	30873	147.62070800000001	148.675366	63.017885	62.534747000000003	Советская	0103000020E61000000100000005000000B30B06D7DC7362402B51F69672444F40B30B06D7DC736240630B410E4A824F40925A28999C956240630B410E4A824F40925A28999C9562402B51F69672444F40B30B06D7DC7362402B51F69672444F40
46037	30873	147.62070800000001	148.675366	63.017885	62.534747000000003	Светлая	0103000020E61000000100000005000000B30B06D7DC7362402B51F69672444F40B30B06D7DC736240630B410E4A824F40925A28999C956240630B410E4A824F40925A28999C9562402B51F69672444F40B30B06D7DC7362402B51F69672444F40
46021	30873	147.62070800000001	148.675366	63.017885	62.534747000000003	Пионерская	0103000020E61000000100000005000000B30B06D7DC7362402B51F69672444F40B30B06D7DC736240630B410E4A824F40925A28999C956240630B410E4A824F40925A28999C9562402B51F69672444F40B30B06D7DC7362402B51F69672444F40
45991	31253	146.66383099999999	147.71848900000001	63.283200000000001	62.804464000000003	Октябрьская	0103000020E610000001000000050000004562821A3E556240996725ADF8664F404562821A3E556240151DC9E53FA44F4025B1A4DCFD766240151DC9E53FA44F4025B1A4DCFD766240996725ADF8664F404562821A3E556240996725ADF8664F40
46040	31166	146.53304499999999	147.587703	63.252476000000001	62.773229999999998	Клубная	0103000020E610000001000000050000007B4963B40E5162409E245D33F9624F407B4963B40E5162403083312251A04F405B988576CE7262403083312251A04F405B988576CE7262409E245D33F9624F407B4963B40E5162409E245D33F9624F40
46047	31156	147.04834600000001	148.103004	62.933005999999999	62.448461999999999	Трассовская	0103000020E610000001000000050000008F1CE90C8C616240D7BFEB3367394F408F1CE90C8C616240637C98BD6C774F406E6B0BCF4B836240637C98BD6C774F406E6B0BCF4B836240D7BFEB3367394F408F1CE90C8C616240D7BFEB3367394F40
46015	30704	151.85754	152.91219799999999	63.170126000000003	62.689512999999998	Промышленная	0103000020E6100000010000000500000061E0B9F770FB62405B9544F641584F4061E0B9F770FB6240831953B0C6954F40402FDCB9301D6340831953B0C6954F40402FDCB9301D63405B9544F641584F4061E0B9F770FB62405B9544F641584F40
45990	30704	151.85754	152.91219799999999	63.170126000000003	62.689512999999998	Дзержинского	0103000020E6100000010000000500000061E0B9F770FB62405B9544F641584F4061E0B9F770FB6240831953B0C6954F40402FDCB9301D6340831953B0C6954F40402FDCB9301D63405B9544F641584F4061E0B9F770FB62405B9544F641584F40
46057	30776	151.94049000000001	152.995148	62.962153000000001	62.478090999999999	Холодченко	0103000020E61000000100000005000000E2067C7E18FE624087C1FC15323D4F40E2067C7E18FE6240C85F5AD4277B4F40C1559E40D81F6340C85F5AD4277B4F40C1559E40D81F634087C1FC15323D4F40E2067C7E18FE624087C1FC15323D4F40
46009	30480	158.70060000000001	159.755258	62.169426999999999	61.672280999999998	Победы	0103000020E610000001000000050000007CF2B0506BD66340705CC64D0DD64E407CF2B0506BD663409A07B0C8AF154F405B41D3122BF863409A07B0C8AF154F405B41D3122BF86340705CC64D0DD64E407CF2B0506BD66340705CC64D0DD64E40
46024	30327	155.23810700000001	156.292765	62.759310999999997	62.271892999999999	Ленина	0103000020E610000001000000050000005C3E92929E6763407381CB63CD224F405C3E92929E6763401C3F541A31614F403B8DB4545E8963401C3F541A31614F403B8DB4545E8963407381CB63CD224F405C3E92929E6763407381CB63CD224F40
46023	30458	154.82330099999999	155.877959	62.817104	62.330641	проспект Победы	0103000020E6100000010000000500000073B8567B585A6340BEDBBC71522A4F4073B8567B585A634024B726DD96684F405307793D187C634024B726DD96684F405307793D187C6340BEDBBC71522A4F4073B8567B585A6340BEDBBC71522A4F40
46033	30160	147.673025	148.72768400000001	60.777228000000001	60.257333000000003	Годяева	0103000020E610000001000000050000007E8CB96B897562403E97A949F0204E407E8CB96B897562408BC404357C634E4052BAF42F499762408BC404357C634E4052BAF42F499762403E97A949F0204E407E8CB96B897562403E97A949F0204E40
46029	29749	153.609308	154.66396700000001	59.848208	59.313301000000003	Набережная	0103000020E610000001000000050000001EA67D737F336340ED66463F1AA84D401EA67D737F336340501A6A1492EC4D40F2D3B8373F556340501A6A1492EC4D40F2D3B8373F556340ED66463F1AA84D401EA67D737F336340ED66463F1AA84D40
46041	29727	154.137168	155.19182599999999	60.462226000000001	59.937224000000001	Советская	0103000020E61000000100000005000000D94125AE634463405E83BEF4F6F74D40D94125AE6344634032AEB8382A3B4E40B89047702366634032AEB8382A3B4E40B8904770236663405E83BEF4F6F74D40D94125AE634463405E83BEF4F6F74D40
46050	30207	148.79586599999999	149.85052400000001	59.985579000000001	59.452883	50 лет Октября	0103000020E61000000100000005000000F23FF9BB779962400AF5F411F8B94D40F23FF9BB77996240EC4FE27327FE4D40D28E1B7E37BB6240EC4FE27327FE4D40D28E1B7E37BB62400AF5F411F8B94D40F23FF9BB779962400AF5F411F8B94D40
46039	30291	148.125103	149.17976100000001	60.030470000000001	59.498496000000003	Молодежная	0103000020E6100000010000000500000035B401D800846240EA9788B7CEBF4D4035B401D8008462402BC1E270E6034E401503249AC0A562402BC1E270E6034E401503249AC0A56240EA9788B7CEBF4D4035B401D800846240EA9788B7CEBF4D40
45987	75	150.77232100000001	151.82697899999999	59.838959000000003	59.303902999999998	площадь Ленина	0103000020E6100000010000000500000073A087DAB6D862400114234BE6A64D4073A087DAB6D86240AAD72D0263EB4D4052EFA99C76FA6240AAD72D0263EB4D4052EFA99C76FA62400114234BE6A64D4073A087DAB6D862400114234BE6A64D40
45986	75	150.77232100000001	151.82697899999999	59.838959000000003	59.303902999999998	Советская	0103000020E6100000010000000500000073A087DAB6D862400114234BE6A64D4073A087DAB6D86240AAD72D0263EB4D4052EFA99C76FA6240AAD72D0263EB4D4052EFA99C76FA62400114234BE6A64D4073A087DAB6D862400114234BE6A64D40
46011	75	150.77232100000001	151.82697899999999	59.838959000000003	59.303902999999998	Ленина	0103000020E6100000010000000500000073A087DAB6D862400114234BE6A64D4073A087DAB6D86240AAD72D0263EB4D4052EFA99C76FA6240AAD72D0263EB4D4052EFA99C76FA62400114234BE6A64D4073A087DAB6D862400114234BE6A64D40
46018	75	150.77232100000001	151.82697899999999	59.838959000000003	59.303902999999998	Кирова	0103000020E6100000010000000500000073A087DAB6D862400114234BE6A64D4073A087DAB6D86240AAD72D0263EB4D4052EFA99C76FA6240AAD72D0263EB4D4052EFA99C76FA62400114234BE6A64D4073A087DAB6D862400114234BE6A64D40
46045	29804	150.952451	152.00710900000001	60.019927000000003	59.487783999999998	Школьная	0103000020E610000001000000050000005C01857A7ADE62408BC1C3B46FBE4D405C01857A7ADE624059A7CAF78C024E403C50A73C3A00634059A7CAF78C024E403C50A73C3A0063408BC1C3B46FBE4D405C01857A7ADE62408BC1C3B46FBE4D40
46031	29868	150.79047600000001	151.845134	59.930312999999998	59.396726999999998	Центральная	0103000020E61000000100000005000000BC0853944BD96240583849F3C7B24D40BC0853944BD962409605137F14F74D409B5775560BFB62409605137F14F74D409B5775560BFB6240583849F3C7B24D40BC0853944BD96240583849F3C7B24D40
46049	30230	148.57231100000001	149.626969	59.925294999999998	59.391627999999997	Советская	0103000020E610000001000000050000008484285F509262405419C6DD20B24D408484285F509262407F130A1170F64D4063D34A2110B462407F130A1170F64D4063D34A2110B462405419C6DD20B24D408484285F509262405419C6DD20B24D40
46003	30075	149.61142799999999	150.66608600000001	59.939968999999998	59.406537999999998	Пушкина	0103000020E610000001000000050000007AFB73D190B36240664AEB6F09B44D407AFB73D190B362407D2079E750F84D405A4A969350D562407D2079E750F84D405A4A969350D56240664AEB6F09B44D407AFB73D190B36240664AEB6F09B44D40
46072	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	проспект Рыбаков	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46069	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	проспект Победы	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46094	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	проспект Карла Маркса	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46073	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	проспект 50 лет Октября	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46059	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	площадь Щедрина	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46144	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	бульвар рыбацкой славы	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46076	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Якорная	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46198	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Щорса	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46140	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Чубарова	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46171	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Спортивная	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46134	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Светлая	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46065	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Сахалинская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46153	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Садовая	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46152	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Савченко	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46115	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Рябиковская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46112	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Пономарева	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46083	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Пограничная	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46064	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Петра Ильичева	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46170	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Первомайская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46110	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Океанская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46155	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Новая	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46098	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Молчанова	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46149	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Ленинская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46116	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Ленинградская 	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46118	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Курильская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46117	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Кроноцкая	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46151	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Космонавтов	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46070	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Космический проезд	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46071	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Комсомольская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46111	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Ключевская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46147	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Кирова	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46062	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Капитана Драбкина	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46156	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Зеленая Роща	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46066	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Звездная	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46086	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Заводская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46089	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Дзержинского	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46113	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Дальняя	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46122	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Давыдова	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46125	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Гастелло	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46092	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Г.Ф. Кирдищева	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46061	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Вольского	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46121	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Ватутина	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46091	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Бохняка	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46077	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Бийская	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46150	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Беринга	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46060	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Атласова	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46194	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Аммональная падь	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46090	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	Академика Королева	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46193	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	2-я Шевченко	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46074	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	 проспект Победы	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46204	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	 Фурманова	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46120	23070	158.095145	159.14980299999999	53.378059	52.742710000000002	 Зеркальная	0103000020E6100000010000000500000018EC866D0BC36340C2340C1F115F4A4018EC866D0BC36340AF7AC03C64B04A40F73AA92FCBE46340AF7AC03C64B04A40F73AA92FCBE46340C2340C1F115F4A4018EC866D0BC36340C2340C1F115F4A40
46168	55668	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Санаторная	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46135	55668	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Рабочей смены	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46164	55668	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Мурманская	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46100	55660	157.88167799999999	158.93633600000001	53.257224999999998	52.620072999999998	Победы	0103000020E6100000010000000500000049F3C7B436BC6340F910548D5E4F4A4049F3C7B436BC6340575BB1BFECA04A402942EA76F6DD6340575BB1BFECA04A402942EA76F6DD6340F910548D5E4F4A4049F3C7B436BC6340F910548D5E4F4A40
46129	55660	157.88167799999999	158.93633600000001	53.257224999999998	52.620072999999998	Мира	0103000020E6100000010000000500000049F3C7B436BC6340F910548D5E4F4A4049F3C7B436BC6340575BB1BFECA04A402942EA76F6DD6340575BB1BFECA04A402942EA76F6DD6340F910548D5E4F4A4049F3C7B436BC6340F910548D5E4F4A40
46215	55660	157.88167799999999	158.93633600000001	53.257224999999998	52.620072999999998	Владивостокская	0103000020E6100000010000000500000049F3C7B436BC6340F910548D5E4F4A4049F3C7B436BC6340575BB1BFECA04A402942EA76F6DD6340575BB1BFECA04A402942EA76F6DD6340F910548D5E4F4A4049F3C7B436BC6340F910548D5E4F4A40
46166	55660	157.88167799999999	158.93633600000001	53.257224999999998	52.620072999999998	50 лет ВЛКСМ	0103000020E6100000010000000500000049F3C7B436BC6340F910548D5E4F4A4049F3C7B436BC6340575BB1BFECA04A402942EA76F6DD6340575BB1BFECA04A402942EA76F6DD6340F910548D5E4F4A4049F3C7B436BC6340F910548D5E4F4A40
46109	30428	161.950525	163.00518299999999	56.517578999999998	55.930034999999997	Советская	0103000020E61000000100000005000000F9A067B36A3E644053910A630BF74B40F9A067B36A3E6440560C570740424C40D8EF89752A606440560C570740424C40D8EF89752A60644053910A630BF74B40F9A067B36A3E644053910A630BF74B40
46175	30428	161.950525	163.00518299999999	56.517578999999998	55.930034999999997	Кирова	0103000020E61000000100000005000000F9A067B36A3E644053910A630BF74B40F9A067B36A3E6440560C570740424C40D8EF89752A606440560C570740424C40D8EF89752A60644053910A630BF74B40F9A067B36A3E644053910A630BF74B40
46148	30428	161.950525	163.00518299999999	56.517578999999998	55.930034999999997	Горького	0103000020E61000000100000005000000F9A067B36A3E644053910A630BF74B40F9A067B36A3E6440560C570740424C40D8EF89752A606440560C570740424C40D8EF89752A60644053910A630BF74B40F9A067B36A3E644053910A630BF74B40
46199	30247	159.53535099999999	160.59000900000001	56.545085999999998	55.957968000000001	Комсомольская	0103000020E61000000100000005000000309C6B9821F16340A94E07B29EFA4B40309C6B9821F16340F4C0C760C5454C4010EB8D5AE1126440F4C0C760C5454C4010EB8D5AE1126440A94E07B29EFA4B40309C6B9821F16340A94E07B29EFA4B40
46190	30537	162.18317999999999	163.23783800000001	56.541978999999998	55.954813000000001	Новая	0103000020E6100000010000000500000000A94D9CDC456440D865F84F37FA4B4000A94D9CDC456440340F60915F454C40E0F76F5E9C676440340F60915F454C40E0F76F5E9C676440D865F84F37FA4B4000A94D9CDC456440D865F84F37FA4B40
46108	30204	159.33936499999999	160.394023	56.335430000000002	55.745063000000002	Ленинская	0103000020E61000000100000005000000060DFD13DCEA6340D63A71395EDF4B40060DFD13DCEA6340740CC85EEF2A4C40E65B1FD69B0C6440740CC85EEF2A4C40E65B1FD69B0C6440D63A71395EDF4B40060DFD13DCEA6340D63A71395EDF4B40
46130	55666	159.09459200000001	163.36289199999999	57.595799999999997	54.980797000000003	Красноармейская	0103000020E61000000100000005000000D34ECDE506E36340E9818FC18A7D4B40D34ECDE506E36340787AA52C43CC4C405CFFAECF9C6B6440787AA52C43CC4C405CFFAECF9C6B6440E9818FC18A7D4B40D34ECDE506E36340E9818FC18A7D4B40
46205	55674	156.00669600000001	158.09539599999999	53.631497000000003	51.081696000000001	улица Блюхера	0103000020E6100000010000000500000073A087DA36806340651BB803758A494073A087DA36806340D542C9E4D4D04A406A85E97B0DC36340D542C9E4D4D04A406A85E97B0DC36340651BB803758A494073A087DA36806340651BB803758A4940
46063	29738	155.74825100000001	156.802909	53.139601999999996	52.500698	Ленинская	0103000020E6100000010000000500000061C614ACF177634018963FDF16404A4061C614ACF1776340643A747ADE914A404015376EB1996340643A747ADE914A404015376EB199634018963FDF16404A4061C614ACF177634018963FDF16404A40
46178	29578	156.28557799999999	157.340236	51.796191999999998	51.137470999999998	Энергетиков	0103000020E61000000100000005000000A04E797423896340FF9254A698914940A04E7974238963401DAB949EE9E54940809D9B36E3AA63401DAB949EE9E54940809D9B36E3AA6340FF9254A698914940A04E797423896340FF9254A698914940
46107	48905	155.715813	156.77047099999999	52.975110000000001	52.333761000000003	Комсомольская	0103000020E61000000100000005000000A721AAF0E776634013D731AEB82A4A40A721AAF0E776634054008C67D07C4A408670CCB2A798634054008C67D07C4A408670CCB2A798634013D731AEB82A4A40A721AAF0E776634013D731AEB82A4A40
46084	29640	155.97389899999999	157.02855700000001	51.816696	51.158275000000003	Октябрьская	0103000020E610000001000000050000006D533C2E2A7F63402063EE5A429449406D533C2E2A7F63401363997E89E849404DA25EF0E9A063401363997E89E849404DA25EF0E9A063402063EE5A429449406D533C2E2A7F63402063EE5A42944940
46163	29630	155.99447000000001	157.049128	51.832611	51.174422	Центральная	0103000020E610000001000000050000004DDBBFB2D27F6340F9D9C875539649404DDBBFB2D27F63401AA54BFF92EA49402C2AE27492A163401AA54BFF92EA49402C2AE27492A16340F9D9C875539649404DDBBFB2D27F6340F9D9C87553964940
46157	29867	156.60625899999999	157.66091700000001	53.242964000000001	52.605598999999998	Юбилейная	0103000020E61000000100000005000000FB3C467966936340C2BE9D44844D4A40FB3C4679669363407C0DC171199F4A40DB8B683B26B563407C0DC171199F4A40DB8B683B26B56340C2BE9D44844D4A40FB3C467966936340C2BE9D44844D4A40
46197	52608	156.49097800000001	157.545636	57.135351	56.557425000000002	Набережная	0103000020E61000000100000005000000C7A17E17B68F6340857CD0B359474C40C7A17E17B68F63408E3D7B2E53914C40A6F0A0D975B163408E3D7B2E53914C40A6F0A0D975B16340857CD0B359474C40C7A17E17B68F6340857CD0B359474C40
46169	52611	156.20993999999999	157.26459800000001	57.385159999999999	56.811143000000001	Школьная	0103000020E61000000100000005000000E94317D4B78663408EB0A888D3674C40E94317D4B78663401ADD41EC4CB14C40C992399677A863401ADD41EC4CB14C40C992399677A863408EB0A888D3674C40E94317D4B78663408EB0A888D3674C40
46131	52624	158.1481	159.20275799999999	58.042195	57.47851	Партизанская	0103000020E610000001000000050000003411363CBDC463408C67D0D03FBD4C403411363CBDC46340018750A566054D40136058FE7CE66340018750A566054D40136058FE7CE663408C67D0D03FBD4C403411363CBDC463408C67D0D03FBD4C40
46192	52622	157.761852	158.81650999999999	58.007736999999999	57.443508000000001	Советская	0103000020E610000001000000050000008D0C721761B86340D7C1C1DEC4B84C408D0C721761B863400DFCA886FD004D406C5B94D920DA63400DFCA886FD004D406C5B94D920DA6340D7C1C1DEC4B84C408D0C721761B86340D7C1C1DEC4B84C40
46068	55656	159.42327700000001	160.477935	59.353254999999997	58.810406999999998	Поротова	0103000020E61000000100000005000000C504357C8BED634088B9A46ABB674D40C504357C8BED63400113B87537AD4D40A453573E4B0F64400113B87537AD4D40A453573E4B0F644088B9A46ABB674D40C504357C8BED634088B9A46ABB674D40
46208	52631	160.02884900000001	161.083507	59.730856000000003	59.194062000000002	Депутатская	0103000020E61000000100000005000000B7F0BC54EC006440BCB20B06D7984D40B7F0BC54EC006440EE0A7DB08CDD4D40963FDF16AC226440EE0A7DB08CDD4D40963FDF16AC226440BCB20B06D7984D40B7F0BC54EC006440BCB20B06D7984D40
46202	52614	156.35291599999999	157.40757400000001	57.483899999999998	56.911431	50 лет Октября	0103000020E6100000010000000500000086C77E164B8B6340C1C760C5A9744C4086C77E164B8B63406744696FF0BD4C406616A1D80AAD63406744696FF0BD4C406616A1D80AAD6340C1C760C5A9744C4086C77E164B8B6340C1C760C5A9744C40
46209	52628	158.860366	159.91502399999999	58.584057999999999	58.028950000000002	Гагарина	0103000020E61000000100000005000000E412471E88DB63400F9C33A2B4034D40E412471E88DB6340CC7B9C69C24A4D40C36169E047FD6340CC7B9C69C24A4D40C36169E047FD63400F9C33A2B4034D40E412471E88DB63400F9C33A2B4034D40
46128	55665	155.41593700000001	156.470595	54.605578999999999	53.988700999999999	Советская	0103000020E6100000010000000500000049861C5B4F6D6340E1421EC18DFE4A4049861C5B4F6D63407B12D89C834D4B4028D53E1D0F8F63407B12D89C834D4B4028D53E1D0F8F6340E1421EC18DFE4A4049861C5B4F6D6340E1421EC18DFE4A40
46220	55665	155.41593700000001	156.470595	54.605578999999999	53.988700999999999	Речная	0103000020E6100000010000000500000049861C5B4F6D6340E1421EC18DFE4A4049861C5B4F6D63407B12D89C834D4B4028D53E1D0F8F63407B12D89C834D4B4028D53E1D0F8F6340E1421EC18DFE4A4049861C5B4F6D6340E1421EC18DFE4A40
46206	55665	155.41593700000001	156.470595	54.605578999999999	53.988700999999999	Заводская	0103000020E6100000010000000500000049861C5B4F6D6340E1421EC18DFE4A4049861C5B4F6D63407B12D89C834D4B4028D53E1D0F8F63407B12D89C834D4B4028D53E1D0F8F6340E1421EC18DFE4A4049861C5B4F6D6340E1421EC18DFE4A40
46226	55680	155.07975200000001	156.13441	55.901470000000003	55.304400999999999	Геологическая	0103000020E610000001000000050000004DF910548D62634052EFA99CF6A64B404DF910548D6263409E29745E63F34B402C4833164D8463409E29745E63F34B402C4833164D84634052EFA99CF6A64B404DF910548D62634052EFA99CF6A64B40
46222	55678	166.17098100000001	167.225639	62.300514	61.805525000000003	Центральная	0103000020E61000000100000005000000996725AD78C56440228E75711BE74E40996725AD78C56440BDFE243E77264F4078B6476F38E76440BDFE243E77264F4078B6476F38E76440228E75711BE74E40996725AD78C56440228E75711BE74E40
46224	55679	167.44143199999999	168.49609100000001	63.403579999999998	62.926845	Давыдова	0103000020E610000001000000050000000D6D003620EE644006BB61DBA2764F400D6D003620EE6440EBA86A82A8B34F40E19A3BFADF0F6540EBA86A82A8B34F40E19A3BFADF0F654006BB61DBA2764F400D6D003620EE644006BB61DBA2764F40
46187	31872	166.050185	167.10484299999999	62.950094999999997	62.465834000000001	Мира	0103000020E61000000100000005000000FEB7921D9BC16440B4AED172A03B4F40FEB7921D9BC16440EB8B84B69C794F40DD06B5DF5AE36440EB8B84B69C794F40DD06B5DF5AE36440B4AED172A03B4F40FEB7921D9BC16440B4AED172A03B4F40
46183	55671	164.79425000000001	165.84890799999999	62.733758999999999	62.245918000000003	Ленинская	0103000020E6100000010000000500000023DBF97E6A996440B6BFB33D7A1F4F4023DBF97E6A996440A5129ED0EB5D4F40022A1C412ABB6440A5129ED0EB5D4F40022A1C412ABB6440B6BFB33D7A1F4F4023DBF97E6A996440B6BFB33D7A1F4F40
46229	55676	165.68137200000001	166.73603	62.714348999999999	62.226188	Ленина	0103000020E61000000100000005000000200DA7CCCDB56440B35F77BAF31C4F40200DA7CCCDB564401477BCC96F5B4F40FF5BC98E8DD764401477BCC96F5B4F40FF5BC98E8DD76440B35F77BAF31C4F40200DA7CCCDB56440B35F77BAF31C4F40
46223	55677	167.05389	168.10854800000001	63.955694999999999	63.488163	60 Лет Октября	0103000020E610000001000000050000009B728577B9E16440020F0C207CBE4F409B728577B9E16440B1F9B83654FA4F407BC1A73979036540B1F9B83654FA4F407BC1A73979036540020F0C207CBE4F409B728577B9E16440020F0C207CBE4F40
46173	52666	166.31554700000001	167.370205	61.211238000000002	60.698400999999997	Центральная	0103000020E610000001000000050000003BAB05F618CA6440313F373465594E403BAB05F618CA644013D6C6D8099B4E401AFA27B8D8EB644013D6C6D8099B4E401AFA27B8D8EB6440313F373465594E403BAB05F618CA6440313F373465594E40
46085	52662	165.52123900000001	166.575897	60.692998000000003	60.171734999999998	Молодежная	0103000020E61000000100000005000000CB4C69FDADB064400E4A9869FB154E40CB4C69FDADB06440C2189128B4584E40AA9B8BBF6DD26440C2189128B4584E40AA9B8BBF6DD264400E4A9869FB154E40CB4C69FDADB064400E4A9869FB154E40
46213	55675	164.08439200000001	174.49339599999999	62.548397999999999	59.590699999999998	Центральная	0103000020E610000001000000050000006901DA56B3826440A4DFBE0E9CCB4D406901DA56B38264408D98D9E731464F40457F68E6C9CF65408D98D9E731464F40457F68E6C9CF6540A4DFBE0E9CCB4D406901DA56B3826440A4DFBE0E9CCB4D40
46188	52669	168.61536899999999	169.670027	60.819695000000003	60.300488999999999	Центральная	0103000020E610000001000000050000001C3F541AB113654064E76D6C76264E401C3F541AB1136540EDD808C4EB684E40FC8D76DC70356540EDD808C4EB684E40FC8D76DC7035654064E76D6C76264E401C3F541AB113654064E76D6C76264E40
46211	52661	165.487776	166.54243399999999	60.631698	60.109442000000001	Советская	0103000020E61000000100000005000000C2F869DC9BAF644088670932020E4E40C2F869DC9BAF64406C79E57ADB504E40A1478C9E5BD164406C79E57ADB504E40A1478C9E5BD1644088670932020E4E40C2F869DC9BAF644088670932020E4E40
46179	52658	164.92821599999999	165.98287400000001	60.449993999999997	59.924793999999999	Центральная	0103000020E61000000100000005000000F7730AF2B39D6440BDC458A65FF64D40F7730AF2B39D6440B7B2446799394E40D7C22CB473BF6440B7B2446799394E40D7C22CB473BF6440BDC458A65FF64D40F7730AF2B39D6440BDC458A65FF64D40
46219	52678	169.97252599999999	171.02718400000001	61.262047000000003	60.750039000000001	Каюю	0103000020E610000001000000050000004F90D8EE1E3F6540BEDC274701604E404F90D8EE1E3F6540E9818FC18AA14E402FDFFAB0DE606540E9818FC18AA14E402FDFFAB0DE606540BEDC274701604E404F90D8EE1E3F6540BEDC274701604E40
46189	52673	169.05177900000001	170.106437	60.717115	60.196244	Морская	0103000020E61000000100000005000000D4F36E2CA8216540A304FD851E194E40D4F36E2CA82165404B3CA06CCA5B4E40B34291EE674365404B3CA06CCA5B4E40B34291EE67436540A304FD851E194E40D4F36E2CA8216540A304FD851E194E40
46203	29162	157.68627599999999	158.74093500000001	54.704315999999999	54.088935999999997	Советская	0103000020E61000000100000005000000F30016F9F5B56340F1B73D41620B4B40F30016F9F5B563405706D506275A4B40C72E51BDB5D763405706D506275A4B40C72E51BDB5D76340F1B73D41620B4B40F30016F9F5B56340F1B73D41620B4B40
46185	45451	158.84442000000001	159.899079	55.572487000000002	54.970359999999999	Крупская	0103000020E61000000100000005000000D482177D05DB63405CACA8C1347C4B40D482177D05DB63404D31074147C94B40A7B05241C5FC63404D31074147C94B40A7B05241C5FC63405CACA8C1347C4B40D482177D05DB63405CACA8C1347C4B40
46201	48693	157.48738900000001	158.54204799999999	54.476573000000002	53.857740999999997	Центральная	0103000020E61000000100000005000000C4EDD0B098AF63401BB80375CAED4A40C4EDD0B098AF63400C941458003D4B40971B0C7558D163400C941458003D4B40971B0C7558D163401BB80375CAED4A40C4EDD0B098AF63401BB80375CAED4A40
46127	29250	158.09467799999999	159.14933600000001	54.999816000000003	54.388930999999999	Строительная	0103000020E61000000100000005000000D234289A07C3634046B3B27DC8314B40D234289A07C363403F027FF8F97F4B40B2834A5CC7E463403F027FF8F97F4B40B2834A5CC7E4634046B3B27DC8314B40D234289A07C3634046B3B27DC8314B40
46141	29250	158.09467799999999	159.14933600000001	54.999816000000003	54.388930999999999	Победы	0103000020E61000000100000005000000D234289A07C3634046B3B27DC8314B40D234289A07C363403F027FF8F97F4B40B2834A5CC7E463403F027FF8F97F4B40B2834A5CC7E4634046B3B27DC8314B40D234289A07C3634046B3B27DC8314B40
46145	29250	158.09467799999999	159.14933600000001	54.999816000000003	54.388930999999999	Партизанская	0103000020E61000000100000005000000D234289A07C3634046B3B27DC8314B40D234289A07C363403F027FF8F97F4B40B2834A5CC7E463403F027FF8F97F4B40B2834A5CC7E4634046B3B27DC8314B40D234289A07C3634046B3B27DC8314B40
46080	29250	158.09467799999999	159.14933600000001	54.999816000000003	54.388930999999999	 Томская	0103000020E61000000100000005000000D234289A07C3634046B3B27DC8314B40D234289A07C363403F027FF8F97F4B40B2834A5CC7E463403F027FF8F97F4B40B2834A5CC7E4634046B3B27DC8314B40D234289A07C3634046B3B27DC8314B40
46195	48840	159.234217	160.28887499999999	55.837116000000002	55.239055	Омская	0103000020E610000001000000050000005A65A6B47EE76340FF78AF5A999E4B405A65A6B47EE76340AB7AF99D26EB4B4039B4C8763E096440AB7AF99D26EB4B4039B4C8763E096440FF78AF5A999E4B405A65A6B47EE76340FF78AF5A999E4B40
46214	45404	158.53715199999999	159.59181000000001	55.422221999999998	54.817791	Елисеевская	0103000020E61000000100000005000000641F645930D1634048FB1F60AD684B40641F645930D163406BD3D85E0BB64B40446E861BF0F263406BD3D85E0BB64B40446E861BF0F2634048FB1F60AD684B40641F645930D1634048FB1F60AD684B40
46176	29501	159.11202900000001	160.166687	55.903277000000003	55.306235000000001	Ленинградская	0103000020E610000001000000050000008466D7BD95E36340FEF15EB532A74B408466D7BD95E36340501DAB949EF34B4063B5F97F55056440501DAB949EF34B4063B5F97F55056440FEF15EB532A74B408466D7BD95E36340FEF15EB532A74B40
46210	52655	162.651579	163.70623800000001	59.757719999999999	59.221358000000002	Комарова	0103000020E6100000010000000500000055F833BCD95464409F5A7D75559C4D4055F833BCD954644037C30DF8FCE04D4029266F809976644037C30DF8FCE04D4029266F80997664409F5A7D75559C4D4055F833BCD95464409F5A7D75559C4D40
46133	55667	162.53523899999999	163.58989700000001	59.515926	58.975682999999997	Советская	0103000020E6100000010000000500000066118AAD20516440AF21382EE37C4D4066118AAD20516440FB93F8DC09C24D404660AC6FE0726440FB93F8DC09C24D404660AC6FE0726440AF21382EE37C4D4066118AAD20516440AF21382EE37C4D40
46207	52643	162.64778899999999	163.70244700000001	59.305419000000001	58.761805000000003	Центральная	0103000020E61000000100000005000000AC36FFAFBA546440F37684D382614D40AC36FFAFBA546440DC4944F817A74D408C8521727A766440DC4944F817A74D408C8521727A766440F37684D382614D40AC36FFAFBA546440F37684D382614D40
46217	52650	162.59601900000001	163.650677	59.377847000000003	58.835391999999999	Обухова	0103000020E610000001000000050000006E1970961253644086AB0320EE6A4D406E1970961253644024F25D4A5DB04D404D689258D274644024F25D4A5DB04D404D689258D274644086AB0320EE6A4D406E1970961253644086AB0320EE6A4D40
46184	52653	163.65144000000001	164.706098	60.221297	59.692402000000001	Калининская	0103000020E61000000100000005000000CDE9B298D8746440AED7F4A0A0D84D40CDE9B298D8746440F9D9C875531C4E40AC38D55A98966440F9D9C875531C4E40AC38D55A98966440AED7F4A0A0D84D40CDE9B298D8746440AED7F4A0A0D84D40
46174	52640	161.77157199999999	162.82623000000001	58.839047999999998	58.287993	Левченко	0103000020E610000001000000050000004C50C3B7B03864400C3D62F4DC244D404C50C3B7B038644019E3C3EC656B4D402C9FE579705A644019E3C3EC656B4D402C9FE579705A64400C3D62F4DC244D404C50C3B7B03864400C3D62F4DC244D40
46180	55670	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Молодежная	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46119	55664	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Центральная	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46161	28618	157.69248400000001	158.747142	53.250556000000003	52.613303999999999	Ленина	0103000020E610000001000000050000001BA034D428B66340C440D7BE804E4A401BA034D428B6634086E8103812A04A40FAEE5696E8D7634086E8103812A04A40FAEE5696E8D76340C440D7BE804E4A401BA034D428B66340C440D7BE804E4A40
46167	28618	157.69248400000001	158.747142	53.250556000000003	52.613303999999999	Крашенинникова	0103000020E610000001000000050000001BA034D428B66340C440D7BE804E4A401BA034D428B6634086E8103812A04A40FAEE5696E8D7634086E8103812A04A40FAEE5696E8D76340C440D7BE804E4A401BA034D428B66340C440D7BE804E4A40
46162	28472	157.76879600000001	158.823454	53.390808999999997	52.755651	Центральная	0103000020E6100000010000000500000076A911FA99B863404818062CB9604A4076A911FA99B86340C1FD800706B24A4055F833BC59DA6340C1FD800706B24A4055F833BC59DA63404818062CB9604A4076A911FA99B863404818062CB9604A40
46132	29086	157.166089	158.22074699999999	53.461961000000002	52.827865000000003	Юбилейная	0103000020E6100000010000000500000036E7E09950A563406440F67AF7694A4036E7E09950A563408483BD8921BB4A401536035C10C763408483BD8921BB4A401536035C10C763406440F67AF7694A4036E7E09950A563406440F67AF7694A40
46191	55673	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Дачная	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46139	28698	157.76091700000001	158.81557599999999	53.583415000000002	52.951135999999998	Ролдугина	0103000020E610000001000000050000000EBF9B6E59B863402D060FD3BE794A400EBF9B6E59B86340787FBC57ADCA4A40E1ECD63219DA6340787FBC57ADCA4A40E1ECD63219DA63402D060FD3BE794A400EBF9B6E59B863402D060FD3BE794A40
46158	27493	158.004864	159.05952199999999	53.410963000000002	52.776105999999999	Бонивура	0103000020E61000000100000005000000B01D8CD827C063405C1D007157634A40B01D8CD827C06340DB6E826F9AB44A408F6CAE9AE7E16340DB6E826F9AB44A408F6CAE9AE7E163405C1D007157634A40B01D8CD827C063405C1D007157634A40
46177	28540	157.72131099999999	158.775969	53.277662999999997	52.640816000000001	Нагорная	0103000020E61000000100000005000000D767CEFA14B763407460394206524A40D767CEFA14B76340952710768AA34A40B7B6F0BCD4D86340952710768AA34A40B7B6F0BCD4D863407460394206524A40D767CEFA14B763407460394206524A40
46154	28540	157.72131099999999	158.775969	53.277662999999997	52.640816000000001	Мирная	0103000020E61000000100000005000000D767CEFA14B763407460394206524A40D767CEFA14B76340952710768AA34A40B7B6F0BCD4D86340952710768AA34A40B7B6F0BCD4D863407460394206524A40D767CEFA14B763407460394206524A40
46106	28456	157.807962	158.86261999999999	53.360881999999997	52.725276999999998	Елизовская	0103000020E6100000010000000500000025CD1FD3DAB963403FC571E0D55C4A4025CD1FD3DAB9634087DBA16131AE4A40041C42959ADB634087DBA16131AE4A40041C42959ADB63403FC571E0D55C4A4025CD1FD3DAB963403FC571E0D55C4A40
46087	55659	157.991039	159.04569699999999	53.435786	52.801299	Первомайская	0103000020E61000000100000005000000F0C16B97B6BF6340A4A833F790664A40F0C16B97B6BF6340FF06EDD5C7B74A40CF108E5976E16340FF06EDD5C7B74A40CF108E5976E16340A4A833F790664A40F0C16B97B6BF6340A4A833F790664A40
46160	29006	157.49830399999999	158.55296200000001	53.566231000000002	52.933695	Школьная	0103000020E61000000100000005000000E9EE3A1BF2AF634028B8585183774A40E9EE3A1BF2AF63409E7DE5417AC84A40C93D5DDDB1D163409E7DE5417AC84A40C93D5DDDB1D1634028B8585183774A40E9EE3A1BF2AF634028B8585183774A40
46172	28769	157.68032099999999	158.73497900000001	53.595669999999998	52.963574999999999	Геологов	0103000020E6100000010000000500000006B98B30C5B56340211FF46C567B4A4006B98B30C5B56340AA9A20EA3ECC4A40E607AEF284D76340AA9A20EA3ECC4A40E607AEF284D76340211FF46C567B4A4006B98B30C5B56340211FF46C567B4A40
46126	28769	157.68032099999999	158.73497900000001	53.595669999999998	52.963574999999999	Вилкова	0103000020E6100000010000000500000006B98B30C5B56340211FF46C567B4A4006B98B30C5B56340AA9A20EA3ECC4A40E607AEF284D76340AA9A20EA3ECC4A40E607AEF284D76340211FF46C567B4A4006B98B30C5B56340211FF46C567B4A40
46182	28926	157.64958899999999	158.70424700000001	53.587043999999999	52.954819999999998	Атласова	0103000020E61000000100000005000000ECDADE6EC9B463408AC8B08A377A4A40ECDADE6EC9B4634011A8FE4124CB4A40CC29013189D6634011A8FE4124CB4A40CC29013189D663408AC8B08A377A4A40ECDADE6EC9B463408AC8B08A377A4A40
46075	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Тимирязевский переулок	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46078	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Рябикова	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46105	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Пограничная	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46137	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Ленина	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46102	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Котельная	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46104	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Зеленая	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46101	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Звездная	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46099	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Завойко	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46079	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Виталия Кручины	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
9722	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	Беринга	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46136	27738	157.85516000000001	158.909818	53.498753000000001	52.865206999999998	40 лет Октября	0103000020E610000001000000050000001E1B81785DBB634098A25C1ABF6E4A401E1B81785DBB634015E46723D7BF4A40FD69A33A1DDD634015E46723D7BF4A40FD69A33A1DDD634098A25C1ABF6E4A401E1B81785DBB634098A25C1ABF6E4A40
46200	27674	157.972677	159.02733499999999	53.453226999999998	52.819001	Центральная	0103000020E610000001000000050000004912842B20BF634016325706D5684A404912842B20BF63400455A35703BA4A402861A6EDDFE063400455A35703BA4A402861A6EDDFE0634016325706D5684A404912842B20BF634016325706D5684A40
46146	55669	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	 Вилкова	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46096	55658	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Центральный	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46097	55658	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Спортивная	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46082	55658	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Приморская	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46093	55658	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Мира	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46103	55658	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Кронштадтская	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46095	55658	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Крашенинникова	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46123	55658	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	Гусарова	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
46159	28947	157.55922799999999	158.61388600000001	53.579234999999997	52.946893000000003	Строительная	0103000020E610000001000000050000003D601E32E5B16340DAE731CA33794A403D601E32E5B163406AD95A5F24CA4A401DAF40F4A4D363406AD95A5F24CA4A401DAF40F4A4D36340DAE731CA33794A403D601E32E5B16340DAE731CA33794A40
46124	29890	158.16732400000001	159.221982	56.225417999999998	55.633347999999998	Южная	0103000020E61000000100000005000000C07ADCB75AC56340567E198C11D14B40C07ADCB75AC5634001F73C7FDA1C4C409FC9FE791AE7634001F73C7FDA1C4C409FC9FE791AE76340567E198C11D14B40C07ADCB75AC56340567E198C11D14B40
46196	29940	158.44434699999999	159.49900500000001	56.350861000000002	55.760731999999997	Советская	0103000020E610000001000000050000006C22331738CE6340A5828AAA5FE14B406C22331738CE63408F386403E92C4C404C7155D9F7EF63408F386403E92C4C404C7155D9F7EF6340A5828AAA5FE14B406C22331738CE6340A5828AAA5FE14B40
46186	55672	165.486752	166.54141000000001	55.502589	54.899389999999997	50 лет Октября	0103000020E610000001000000050000006728EE7893AF6440BA2C26361F734B406728EE7893AF6440282A1BD654C04B404777103B53D16440282A1BD654C04B404777103B53D16440BA2C26361F734B406728EE7893AF6440BA2C26361F734B40
46232	55681	131.17627400000001	131.21327500000001	49.134630999999999	49.115777000000001	Ленина	0103000020E6100000010000000500000053245F09A46560408350DEC7D18E484053245F09A46560408E03AF963B914840BEC11726D36660408E03AF963B914840BEC11726D36660408350DEC7D18E484053245F09A46560408350DEC7D18E4840
46244	55686	131.03078300000001	131.083505	49.049754	48.973348000000001	Тварковского	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
46280	55686	131.03078300000001	131.083505	49.049754	48.973348000000001	Районная	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
46290	55691	134.564809	134.58585600000001	48.581353	48.551124999999999	Школьная	0103000020E6100000010000000500000091EF52EA12D26040068195438B46484091EF52EA12D260403B376DC6694A48404B051555BFD260403B376DC6694A48404B051555BFD26040068195438B46484091EF52EA12D26040068195438B464840
46292	55684	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	проспект 60-летия СССР	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46247	55684	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Шолом-Алейхема	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46240	55684	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Комсомольская	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46259	55684	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Карла Маркса	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46268	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Юбилейная	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46243	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Шолом-Алейхема	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46267	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Школьная	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46257	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Широкая	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46251	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Швейный	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46324	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Черноморская	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46231	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Чапаева	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46304	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Транспортная	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46254	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Строительная	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46233	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Советская	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46327	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Пригородная	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46238	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Пионерская	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46230	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Осенняя	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46255	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Ленина	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46242	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Космонавтов	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46258	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Карла Маркса	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46308	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Гоголя	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46265	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Волочаевская	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46225	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Бумагина	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46299	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	Биршоссе 2-ой км	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46253	16582	132.80461399999999	132.99031400000001	48.824429000000002	48.734045999999999	40 лет Победы	0103000020E61000000100000005000000EBFCDB65BF9960403BE12538F55D4840EBFCDB65BF996040DF6FB4E386694840AC58FCA6B09F6040DF6FB4E386694840AC58FCA6B09F60403BE12538F55D4840EBFCDB65BF9960403BE12538F55D4840
46288	45455	134.96798200000001	134.98416900000001	48.559151999999997	48.532699000000001	Школьная	0103000020E61000000100000005000000BC2363B5F9DE604053CE177B2F444840BC2363B5F9DE60401ABFF04A924748409697FC4F7EDF60401ABFF04A924748409697FC4F7EDF604053CE177B2F444840BC2363B5F9DE604053CE177B2F444840
46235	55682	133.78368800000001	133.85586699999999	48.611044999999997	48.586132999999997	Советская	0103000020E610000001000000050000009148DBF813B960409D0DF967064B48409148DBF813B9604031B1F9B8364E484038D7304363BB604031B1F9B8364E484038D7304363BB60409D0DF967064B48409148DBF813B960409D0DF967064B4840
46273	55682	133.78368800000001	133.85586699999999	48.611044999999997	48.586132999999997	Лермонтова	0103000020E610000001000000050000009148DBF813B960409D0DF967064B48409148DBF813B9604031B1F9B8364E484038D7304363BB604031B1F9B8364E484038D7304363BB60409D0DF967064B48409148DBF813B960409D0DF967064B4840
46261	19715	133.78368800000001	133.85586699999999	48.611044999999997	48.586132999999997	Кирова	0103000020E610000001000000050000009148DBF813B960409D0DF967064B48409148DBF813B9604031B1F9B8364E484038D7304363BB604031B1F9B8364E484038D7304363BB60409D0DF967064B48409148DBF813B960409D0DF967064B4840
46275	55683	134.889568	134.92329100000001	48.543365000000001	48.497802999999998	Дзержинского	0103000020E610000001000000050000002E724F5777DC6040E36C3A02B83F48402E724F5777DC60404165FCFB8C4548401E3691998BDD60404165FCFB8C4548401E3691998BDD6040E36C3A02B83F48402E724F5777DC6040E36C3A02B83F4840
46237	55683	134.889568	134.92329100000001	48.543365000000001	48.497802999999998	Вокзальная	0103000020E610000001000000050000002E724F5777DC6040E36C3A02B83F48402E724F5777DC60404165FCFB8C4548401E3691998BDD60404165FCFB8C4548401E3691998BDD6040E36C3A02B83F48402E724F5777DC6040E36C3A02B83F4840
46287	49474	133.85235499999999	133.86783299999999	48.621183000000002	48.606476000000001	40 лет Победы	0103000020E61000000100000005000000A032FE7D46BB60408AE76C01A14D4840A032FE7D46BB604064EAAEEC824F4840772CB649C5BB604064EAAEEC824F4840772CB649C5BB60408AE76C01A14D4840A032FE7D46BB60408AE76C01A14D4840
46282	49485	134.44448	134.46842000000001	48.575201999999997	48.563529000000003	Партизанская	0103000020E610000001000000050000003CF71E2E39CE60407EACE0B7214848403CF71E2E39CE6040014C1938A04948405B99F04BFDCE6040014C1938A04948405B99F04BFDCE60407EACE0B7214848403CF71E2E39CE60407EACE0B721484840
46277	55685	134.74839800000001	134.80835999999999	48.576256999999998	48.527239999999999	Строительная	0103000020E610000001000000050000008ACC5CE0F2D760404F92AE997C4348408ACC5CE0F2D76040A88B14CAC2494840A06CCA15DED96040A88B14CAC2494840A06CCA15DED960404F92AE997C4348408ACC5CE0F2D760404F92AE997C434840
46241	55685	134.74839800000001	134.80835999999999	48.576256999999998	48.527239999999999	Лазо	0103000020E610000001000000050000008ACC5CE0F2D760404F92AE997C4348408ACC5CE0F2D76040A88B14CAC2494840A06CCA15DED96040A88B14CAC2494840A06CCA15DED960404F92AE997C4348408ACC5CE0F2D760404F92AE997C434840
46263	55685	134.74839800000001	134.80835999999999	48.576256999999998	48.527239999999999	Кубанская	0103000020E610000001000000050000008ACC5CE0F2D760404F92AE997C4348408ACC5CE0F2D76040A88B14CAC2494840A06CCA15DED96040A88B14CAC2494840A06CCA15DED960404F92AE997C4348408ACC5CE0F2D760404F92AE997C434840
46236	45354	134.74839800000001	134.80835999999999	48.576256999999998	48.527239999999999	Комсомольская	0103000020E610000001000000050000008ACC5CE0F2D760404F92AE997C4348408ACC5CE0F2D76040A88B14CAC2494840A06CCA15DED96040A88B14CAC2494840A06CCA15DED960404F92AE997C4348408ACC5CE0F2D760404F92AE997C434840
46344	20264	134.719481	134.73462599999999	48.538592999999999	48.531672999999998	Советская	0103000020E61000000100000005000000FDA204FD05D76040469561DC0D444840FDA204FD05D76040616D8C9DF04448405299620E82D76040616D8C9DF04448405299620E82D76040469561DC0D444840FDA204FD05D76040469561DC0D444840
46353	46672	134.59681599999999	134.61695599999999	48.599023000000003	48.585304999999998	Садовая	0103000020E610000001000000050000005837DE1D19D36040B7973446EB4A48405837DE1D19D36040A24621C9AC4C48404562821ABED36040A24621C9AC4C48404562821ABED36040B7973446EB4A48405837DE1D19D36040B7973446EB4A4840
46284	19999	134.564809	134.58585600000001	48.581353	48.551124999999999	Советская	0103000020E6100000010000000500000091EF52EA12D26040068195438B46484091EF52EA12D260403B376DC6694A48404B051555BFD260403B376DC6694A48404B051555BFD26040068195438B46484091EF52EA12D26040068195438B464840
46301	19957	134.46802400000001	134.50973300000001	48.568005999999997	48.557308999999997	Вокзальная	0103000020E61000000100000005000000C8B7770DFACE60401B62BCE655474840C8B7770DFACE604044F7AC6BB4484840259694BB4FD0604044F7AC6BB4484840259694BB4FD060401B62BCE655474840C8B7770DFACE60401B62BCE655474840
46325	19650	133.71685299999999	133.73601400000001	48.601120000000002	48.588678000000002	Шоссейная	0103000020E6100000010000000500000043E1B375F0B66040F6EFFACC594B484043E1B375F0B660405B7C0A80F14C4840BE6C3B6D8DB760405B7C0A80F14C4840BE6C3B6D8DB76040F6EFFACC594B484043E1B375F0B66040F6EFFACC594B4840
46350	21065	131.044805	131.06407400000001	47.925710000000002	47.909332999999997	Верхняя	0103000020E610000001000000050000005036E50A6F6160403716140665F447405036E50A6F61604043CA4FAA7DF64740C4D0EAE40C62604043CA4FAA7DF64740C4D0EAE40C6260403716140665F447405036E50A6F6160403716140665F44740
46313	21055	131.210059	131.239407	47.842574999999997	47.820411999999997	Почтовая	0103000020E6100000010000000500000060E7A6CDB86660407B9FAA4203E9474060E7A6CDB8666040AEB6627FD9EB4740DF6DDE38A9676040AEB6627FD9EB4740DF6DDE38A96760407B9FAA4203E9474060E7A6CDB86660407B9FAA4203E94740
46314	45668	131.43562600000001	131.457213	47.768222000000002	47.756920000000001	Школьная	0103000020E6100000010000000500000032E9EFA5F06D60401BD82AC1E2E0474032E9EFA5F06D6040AB08371955E24740CB49287DA16E6040AB08371955E24740CB49287DA16E60401BD82AC1E2E0474032E9EFA5F06D60401BD82AC1E2E04740
46328	45735	131.63588799999999	131.646659	47.825029000000001	47.817653999999997	Ленина	0103000020E61000000100000005000000677DCA3159746040C7B8E2E2A8E84740677DCA315974604034A0DE8C9AE947404015376EB174604034A0DE8C9AE947404015376EB1746040C7B8E2E2A8E84740677DCA3159746040C7B8E2E2A8E84740
46289	20991	131.19644099999999	131.235185	47.742494999999998	47.728701999999998	пер.Клубный	0103000020E61000000100000005000000FED2A23E49666040D0436D1B46DD4740FED2A23E49666040C5387F130ADF47405070B1A286676040C5387F130ADF47405070B1A286676040D0436D1B46DD4740FED2A23E49666040D0436D1B46DD4740
46322	45626	131.239093	131.26260199999999	47.850423999999997	47.833195000000003	Советская	0103000020E610000001000000050000007BF65CA6A66760406A183E22A6EA47407BF65CA6A6676040E3DD91B1DAEC4740A73B4F3C67686040E3DD91B1DAEC4740A73B4F3C676860406A183E22A6EA47407BF65CA6A66760406A183E22A6EA4740
46337	45532	131.12904900000001	131.141482	47.757404000000001	47.743319	Амурская	0103000020E610000001000000050000009C525E2B216460406ABFB51325DF47409C525E2B2164604007EE409DF2E04740205F42058764604007EE409DF2E04740205F4205876460406ABFB51325DF47409C525E2B216460406ABFB51325DF4740
46323	21299	131.52248399999999	131.54493299999999	47.750450000000001	47.73695	Центральная	0103000020E61000000100000005000000DD955D30B8706040C364AA6054DE4740DD955D30B870604040A4DFBE0EE047405BB054177071604040A4DFBE0EE047405BB0541770716040C364AA6054DE4740DD955D30B8706040C364AA6054DE4740
46348	45635	131.321451	131.33855399999999	47.849226999999999	47.832324	Магистральная	0103000020E6100000010000000500000087889B53496A604084D6C39789EA474087889B53496A6040AAF06778B3EC4740C2BD326FD56A6040AAF06778B3EC4740C2BD326FD56A604084D6C39789EA474087889B53496A604084D6C39789EA4740
46276	20883	130.95768699999999	130.97644399999999	47.768155	47.731059999999999	Пограничная	0103000020E61000000100000005000000BD19355FA55E6040F6B4C35F93DD4740BD19355FA55E604023A12DE752E2474003CC7C073F5F604023A12DE752E2474003CC7C073F5F6040F6B4C35F93DD4740BD19355FA55E6040F6B4C35F93DD4740
46321	21366	131.668982	131.68695700000001	47.770626	47.759869999999999	Советская	0103000020E610000001000000050000009B73F04C68756040139B8F6B43E147409B73F04C6875604041B96DDFA3E2474044183F8DFB75604041B96DDFA3E2474044183F8DFB756040139B8F6B43E147409B73F04C68756040139B8F6B43E14740
46320	55695	131.36466799999999	131.396478	47.774175	47.761431999999999	улица Советская	0103000020E61000000100000005000000BABC395CAB6B60405E10919A76E14740BABC395CAB6B6040BE30992A18E34740AC72A1F2AF6C6040BE30992A18E34740AC72A1F2AF6C60405E10919A76E14740BABC395CAB6B60405E10919A76E14740
9847	20785	131.06270000000001	131.127657	47.702354999999997	47.688054000000001	Крупской	0103000020E61000000100000005000000B22E6EA301626040E5F0492712D84740B22E6EA3016260404E97C5C4E6D94740600322C4156460404E97C5C4E6D94740600322C415646040E5F0492712D84740B22E6EA301626040E5F0492712D84740
46245	20785	131.06270000000001	131.127657	47.702354999999997	47.688054000000001	Калинина	0103000020E61000000100000005000000B22E6EA301626040E5F0492712D84740B22E6EA3016260404E97C5C4E6D94740600322C4156460404E97C5C4E6D94740600322C415646040E5F0492712D84740B22E6EA301626040E5F0492712D84740
46270	55687	131.850289	131.92113900000001	49.019683999999998	48.998097000000001	Лазо	0103000020E61000000100000005000000C1E44691357B60402C9E7AA4C17F4840C1E44691357B604092205C01858248403F027FF8797D604092205C01858248403F027FF8797D60402C9E7AA4C17F4840C1E44691357B60402C9E7AA4C17F4840
46249	55687	131.850289	131.92113900000001	49.019683999999998	48.998097000000001	Бонивура	0103000020E61000000100000005000000C1E44691357B60402C9E7AA4C17F4840C1E44691357B604092205C01858248403F027FF8797D604092205C01858248403F027FF8797D60402C9E7AA4C17F4840C1E44691357B60402C9E7AA4C17F4840
46318	18919	130.590509	130.606706	48.605040000000002	48.589888000000002	Центральная	0103000020E61000000100000005000000CC5F2173E5526040C4263273814B4840CC5F2173E5526040CC6262F3714D48402F89B3226A536040CC6262F3714D48402F89B3226A536040C4263273814B4840CC5F2173E5526040C4263273814B4840
46307	49205	130.641336	130.66311099999999	48.894384000000002	48.882446999999999	Набережная	0103000020E61000000100000005000000EB3713D38554604006BAF605F4704840EB3713D3855460406808C72C7B724840C5538F34385560406808C72C7B724840C5538F343855604006BAF605F4704840EB3713D38554604006BAF605F4704840
46281	55688	131.03078300000001	131.083505	49.049754	48.973348000000001	Ключевая	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
46264	55688	131.03078300000001	131.083505	49.049754	48.973348000000001	Интернациональная	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
46262	18371	131.03078300000001	131.083505	49.049754	48.973348000000001	Пролетарская	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
46286	18371	131.03078300000001	131.083505	49.049754	48.973348000000001	Денисова	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
46295	18371	131.03078300000001	131.083505	49.049754	48.973348000000001	Горького	0103000020E61000000100000005000000BB48A12CFC60604042D0D1AA967C4840BB48A12CFC6060402F6CCD565E864840AE81AD12AC6260402F6CCD565E864840AE81AD12AC62604042D0D1AA967C4840BB48A12CFC60604042D0D1AA967C4840
46306	55693	131.920815	132.01342299999999	49.029798	49.001767000000001	Комсомольская	0103000020E6100000010000000500000052D50451777D6040249BABE63980484052D50451777D60403CBEBD6BD0834840744012F66D8060403CBEBD6BD0834840744012F66D806040249BABE63980484052D50451777D6040249BABE639804840
46250	19325	131.61451700000001	131.653998	49.215860999999997	49.191561999999998	Раскопенского	0103000020E61000000100000005000000C13A8E1FAA7360400394861A85984840C13A8E1FAA736040ADBD4F55A19B4840C8B4368DED746040ADBD4F55A19B4840C8B4368DED7460400394861A85984840C13A8E1FAA7360400394861A85984840
46271	55689	131.522323	131.58410900000001	49.006537000000002	48.972934000000002	Ведина	0103000020E610000001000000050000005B5EB9DEB67060404F95EF19897C48405B5EB9DEB6706040639B5434D680484094895B05B1726040639B5434D680484094895B05B17260404F95EF19897C48405B5EB9DEB67060404F95EF19897C4840
46345	19471	132.22074499999999	132.25653399999999	49.020937000000004	49.006590000000003	Школьная	0103000020E610000001000000050000002D78D15710876040863DEDF0D78048402D78D1571087604060234910AE824840FC89CA863588604060234910AE824840FC89CA8635886040863DEDF0D78048402D78D15710876040863DEDF0D7804840
46272	19140	131.69599400000001	131.765964	49.012889000000001	48.987208000000003	Октябрьская	0103000020E61000000100000005000000CB86359545766040BF2CEDD45C7E4840CB8635954576604034BDC458A68148403A3DEFC68278604034BDC458A68148403A3DEFC682786040BF2CEDD45C7E4840CB86359545766040BF2CEDD45C7E4840
46234	19386	132.44315	132.48958400000001	49.013781999999999	48.988272000000002	Победы	0103000020E610000001000000050000001EA7E8482E8E6040B9C667B27F7E48401EA7E8482E8E604001A3CB9BC3814840A39410ACAA8F604001A3CB9BC3814840A39410ACAA8F6040B9C667B27F7E48401EA7E8482E8E6040B9C667B27F7E4840
46283	55690	132.44315	132.48958400000001	49.013781999999999	48.988272000000002	Онищенко	0103000020E610000001000000050000001EA7E8482E8E6040B9C667B27F7E48401EA7E8482E8E604001A3CB9BC3814840A39410ACAA8F604001A3CB9BC3814840A39410ACAA8F6040B9C667B27F7E48401EA7E8482E8E6040B9C667B27F7E4840
46336	18981	130.58836199999999	130.60432499999999	48.703631000000001	48.68824	переулок Амурский	0103000020E61000000100000005000000B1868BDCD352604047E6913F18584840B1868BDCD3526040D4B9A294105A4840F7E461A156536040D4B9A294105A4840F7E461A15653604047E6913F18584840B1868BDCD352604047E6913F18584840
46347	22622	132.65636499999999	132.672337	48.081893000000001	48.072923000000003	им. 27 съезда КПСС	0103000020E61000000100000005000000A6272CF1009560402810768A55094840A6272CF100956040BB6246787B0A4840815CE2C883956040BB6246787B0A4840815CE2C8839560402810768A55094840A6272CF1009560402810768A55094840
46343	22836	132.39657199999999	132.428777	48.219971999999999	48.201124	Центральная	0103000020E610000001000000050000004C50C3B7B08C60406938656EBE1948404C50C3B7B08C60409204E10A281C4840DD088B8AB88D60409204E10A281C4840DD088B8AB88D60406938656EBE1948404C50C3B7B08C60406938656EBE194840
46332	46489	131.89182700000001	131.90975700000001	47.900249000000002	47.880473000000002	Школьная	0103000020E6100000010000000500000013D6C6D8897C60406901DA56B3F0474013D6C6D8897C6040DCA0F65B3BF34740D449B6BA1C7D6040DCA0F65B3BF34740D449B6BA1C7D60406901DA56B3F0474013D6C6D8897C60406901DA56B3F04740
46355	23583	131.88637399999999	131.90785299999999	48.104027000000002	48.074975999999999	пер. Школьный	0103000020E61000000100000005000000CAC0012D5D7C604011FE45D098094840CAC0012D5D7C60405473B9C1500D48406A12BC210D7D60405473B9C1500D48406A12BC210D7D604011FE45D098094840CAC0012D5D7C604011FE45D098094840
46311	46326	132.51107999999999	132.52329800000001	48.096908999999997	48.088025999999999	Юбилейная	0103000020E6100000010000000500000078B471C45A9060404E999B6F440B484078B471C45A90604012D89C83670C4840FE8172DBBE90604012D89C83670C4840FE8172DBBE9060404E999B6F440B484078B471C45A9060404E999B6F440B4840
46330	46443	131.95170899999999	131.97268399999999	48.263517999999998	48.242904000000003	Центральная	0103000020E61000000100000005000000E2C96E66747E6040A708707A171F4840E2C96E66747E604023F433F5BA214840F52A323A207F604023F433F5BA214840F52A323A207F6040A708707A171F4840E2C96E66747E6040A708707A171F4840
46319	55694	\N	\N	\N	\N	Шоссейная	\N
46335	46221	132.65772999999999	132.680485	47.966912999999998	47.955613	переулок Вилкова	0103000020E6100000010000000500000023F3C81F0C956040F450DB8651FA474023F3C81F0C956040E38920CEC3FB4740658D7A88C6956040E38920CEC3FB4740658D7A88C6956040F450DB8651FA474023F3C81F0C956040F450DB8651FA4740
46248	45545	132.60779299999999	132.64625000000001	47.963287999999999	47.925795000000001	Школьная	0103000020E610000001000000050000009B374E0A7393604071E6577380F647409B374E0A739360408B506C054DFB474048E17A14AE9460408B506C054DFB474048E17A14AE94604071E6577380F647409B374E0A7393604071E6577380F64740
46246	45545	132.60779299999999	132.64625000000001	47.963287999999999	47.925795000000001	Октябрьская	0103000020E610000001000000050000009B374E0A7393604071E6577380F647409B374E0A739360408B506C054DFB474048E17A14AE9460408B506C054DFB474048E17A14AE94604071E6577380F647409B374E0A7393604071E6577380F64740
46297	45545	132.60779299999999	132.64625000000001	47.963287999999999	47.925795000000001	Ленина	0103000020E610000001000000050000009B374E0A7393604071E6577380F647409B374E0A739360408B506C054DFB474048E17A14AE9460408B506C054DFB474048E17A14AE94604071E6577380F647409B374E0A7393604071E6577380F64740
46310	22542	132.600202	132.62829300000001	47.989876000000002	47.971631000000002	Школьная	0103000020E61000000100000005000000CD1FD3DA34936040D06394675EFC4740CD1FD3DA34936040338CBB41B4FE4740C9E9EBF91A946040338CBB41B4FE4740C9E9EBF91A946040D06394675EFC4740CD1FD3DA34936040D06394675EFC4740
46309	22868	132.42988199999999	132.45782800000001	48.248598999999999	48.231436000000002	Ушакова	0103000020E610000001000000050000007364E597C18D6040FC8EE1B19F1D48407364E597C18D6040BE688F17D21F48402EE6E786A68E6040BE688F17D21F48402EE6E786A68E6040FC8EE1B19F1D48407364E597C18D6040FC8EE1B19F1D4840
46305	46606	132.512248	132.530565	47.895952999999999	47.883415999999997	Комсомольская	0103000020E6100000010000000500000020EEEA5564906040AE6186C613F1474020EEEA556490604065E08096AEF24740DF6C7363FA90604065E08096AEF24740DF6C7363FA906040AE6186C613F1474020EEEA5564906040AE6186C613F14740
46334	46518	132.04924800000001	132.06846300000001	47.860328000000003	47.849687000000003	Кооперативная	0103000020E6100000010000000500000097AC8A70938160400E6B2A8BC2EC474097AC8A7093816040A3EA573A1FEE47408E3F51D930826040A3EA573A1FEE47408E3F51D9308260400E6B2A8BC2EC474097AC8A70938160400E6B2A8BC2EC4740
46333	46549	132.12094200000001	132.13887199999999	47.784765	47.774605000000001	Центральная	0103000020E61000000100000005000000D0D6C1C1DE836040B728B34126E34740D0D6C1C1DE836040D105F52D73E44740904AB1A371846040D105F52D73E44740904AB1A371846040B728B34126E34740D0D6C1C1DE836040B728B34126E34740
46360	46246	132.590599	132.602125	48.014448999999999	48.003248999999997	Школьная	0103000020E610000001000000050000009CC1DF2FE6926040525F96766A0048409CC1DF2FE6926040DE3AFF76D901484054E3A59B44936040DE3AFF76D901484054E3A59B44936040525F96766A0048409CC1DF2FE6926040525F96766A004840
46303	23200	132.17929699999999	132.210531	47.805084999999998	47.789723000000002	Пограничная	0103000020E61000000100000005000000ABE80FCDBC85604013F3ACA415E54740ABE80FCDBC85604005C078060DE747406AF981ABBC86604005C078060DE747406AF981ABBC86604013F3ACA415E54740ABE80FCDBC85604013F3ACA415E54740
46312	46383	132.424995	132.445953	48.144029000000003	48.124270000000003	Центральная	0103000020E61000000100000005000000D53E1D8F998D6040DDEF5014E80F4840D53E1D8F998D60407A56D28A6F124840B3D1393F458E60407A56D28A6F124840B3D1393F458E6040DDEF5014E80F4840D53E1D8F998D6040DDEF5014E80F4840
46317	46309	132.876497	132.89527200000001	48.048830000000002	48.036932	Советская	0103000020E6100000010000000500000059C16F430C9C604083161230BA04484059C16F430C9C60402788BA0F40064840C9207711A69C60402788BA0F40064840C9207711A69C604083161230BA04484059C16F430C9C604083161230BA044840
46341	23078	131.92742699999999	131.94637299999999	47.791539	47.772539999999999	Центральная	0103000020E61000000100000005000000AD4D637BAD7D6040096D3997E2E24740AD4D637BAD7D60401841632651E54740289A07B0487E60401841632651E54740289A07B0487E6040096D3997E2E24740AD4D637BAD7D6040096D3997E2E24740
46279	22975	131.92391499999999	131.951583	47.991793000000001	47.95767	Пионерская	0103000020E6100000010000000500000015A930B6907D60401F2E39EE94FA474015A930B6907D60406CB3B112F3FE4740BF0D315E737E60406CB3B112F3FE4740BF0D315E737E60401F2E39EE94FA474015A930B6907D60401F2E39EE94FA4740
46354	23638	132.02110300000001	132.041935	47.949300000000001	47.931482000000003	Новая	0103000020E610000001000000050000001FDB32E0AC80604006685BCD3AF747401FDB32E0AC806040E10B93A982F94740D9B1118857816040E10B93A982F94740D9B111885781604006685BCD3AF747401FDB32E0AC80604006685BCD3AF74740
46252	22742	132.459158	132.505439	48.142730999999998	48.106247000000003	Ленина	0103000020E610000001000000050000004C361E6CB18E604029266F80990D48404C361E6CB18E60400C90680245124840EFE3688E2C9060400C90680245124840EFE3688E2C90604029266F80990D48404C361E6CB18E604029266F80990D4840
46349	45900	133.226966	133.23943399999999	48.324499000000003	48.316068999999999	Школьная	0103000020E61000000100000005000000BA69334E43A76040C423F1F274284840BA69334E43A76040D84AE82E892948409DF17D71A9A76040D84AE82E892948409DF17D71A9A76040C423F1F274284840BA69334E43A76040C423F1F274284840
46352	55696	132.82701800000001	132.843807	48.865138000000002	48.832560999999998	Набережная	0103000020E6100000010000000500000082E673EE769A60406876DD5B916A484082E673EE769A604070438CD7BC6E484059A48977009B604070438CD7BC6E484059A48977009B60406876DD5B916A484082E673EE769A60406876DD5B916A4840
46278	21451	132.940924	132.96256500000001	48.761059000000003	48.72137	Переселенческая	0103000020E61000000100000005000000B000A60C1C9E6040632827DA555C4840B000A60C1C9E6040CAA99D616A614840C7681D55CD9E6040CAA99D616A614840C7681D55CD9E6040632827DA555C4840B000A60C1C9E6040632827DA555C4840
46291	21451	132.940924	132.96256500000001	48.761059000000003	48.72137	40 лет Победы	0103000020E61000000100000005000000B000A60C1C9E6040632827DA555C4840B000A60C1C9E6040CAA99D616A614840C7681D55CD9E6040CAA99D616A614840C7681D55CD9E6040632827DA555C4840B000A60C1C9E6040632827DA555C4840
46340	45819	132.97364099999999	132.99178699999999	48.621366999999999	48.609431000000001	Юбилейная	0103000020E610000001000000050000006EA12B11289F60409415C3D5014E48406EA12B11289F604025E82FF4884F4840223317B8BC9F604025E82FF4884F4840223317B8BC9F60409415C3D5014E48406EA12B11289F60409415C3D5014E4840
46315	45876	133.173687	133.18803299999999	48.406332999999997	48.397168999999998	Садовая	0103000020E61000000100000005000000B1170AD88EA5604015FE0C6FD6324840B1170AD88EA560408D2441B8023448403332C85D04A660408D2441B8023448403332C85D04A6604015FE0C6FD6324840B1170AD88EA5604015FE0C6FD6324840
46331	22178	132.685677	132.70797300000001	48.412840000000003	48.401536	Дорожная	0103000020E61000000100000005000000D253E410F195604055151A8865334840D253E410F1956040863DEDF0D73448406F2EFEB6A7966040863DEDF0D73448406F2EFEB6A796604055151A8865334840D253E410F195604055151A8865334840
46256	21755	133.091814	133.11539500000001	48.498286	48.482396999999999	Школьная	0103000020E6100000010000000500000014EAE923F0A260402158552FBF3D484014EAE923F0A26040FF06EDD5C73F4840E7E3DA50B1A36040FF06EDD5C73F4840E7E3DA50B1A360402158552FBF3D484014EAE923F0A260402158552FBF3D4840
46346	22005	133.18078299999999	133.19606400000001	48.305881999999997	48.286802999999999	Центральная	0103000020E6100000010000000500000087156EF9C8A5604085B2F0F5B524484087156EF9C8A56040B037312427274840897D022846A66040B037312427274840897D022846A6604085B2F0F5B524484087156EF9C8A5604085B2F0F5B5244840
46326	46080	132.52837299999999	132.54251300000001	48.286425000000001	48.276375999999999	Юбилейная	0103000020E61000000100000005000000DC627E6EE89060401CB3EC4960234840DC627E6EE8906040DFE00B93A9244840F51439445C916040DFE00B93A9244840F51439445C9160401CB3EC4960234840DC627E6EE89060401CB3EC4960234840
46351	46112	132.84868499999999	132.87197900000001	48.888430999999997	48.871065000000002	Центральная	0103000020E6100000010000000500000062F3716D289B60405AD8D30E7F6F484062F3716D289B604054E0641BB871484090F98040E79B604054E0641BB871484090F98040E79B60405AD8D30E7F6F484062F3716D289B60405AD8D30E7F6F4840
46339	45939	133.04959400000001	133.066554	48.470368000000001	48.456871999999997	Школьная	0103000020E610000001000000050000007E02284696A16040A33A1DC87A3A48407E02284696A16040DF8AC404353C484060ADDA3521A26040DF8AC404353C484060ADDA3521A26040A33A1DC87A3A48407E02284696A16040A33A1DC87A3A4840
81111	62080	132.299994	133.34759199999999	48.960963	48.099556999999997	Центральная	0103000020E61000000100000005000000E15F048D998960403F8BA548BE0C4840E15F048D9989604041D5E8D5007B48403D0B42791FAB604041D5E8D5007B48403D0B42791FAB60403F8BA548BE0C4840E15F048D998960403F8BA548BE0C4840
46329	21685	133.04265899999999	133.064694	48.577019999999997	48.562770999999998	Центральная	0103000020E61000000100000005000000293C68765DA16040901150E108484840293C68765DA16040A79196CADB494840EBC726F911A26040A79196CADB494840EBC726F911A26040901150E108484840293C68765DA16040901150E108484840
46296	45941	133.10345599999999	133.12195299999999	48.408347999999997	48.381791999999997	40 лет Победы	0103000020E610000001000000050000006612F5824FA36040EDEF6C8FDE3048406612F5824FA3604089B14CBF44344840C554FA09E7A3604089B14CBF44344840C554FA09E7A36040EDEF6C8FDE3048406612F5824FA36040EDEF6C8FDE304840
46342	45985	133.18966800000001	133.20261300000001	48.209302999999998	48.200422000000003	пер. Юбилейный	0103000020E610000001000000050000002123A0C211A6604010B3976DA71948402123A0C211A6604033FAD170CA1A4840D31742CE7BA6604033FAD170CA1A4840D31742CE7BA6604010B3976DA71948402123A0C211A6604010B3976DA7194840
46298	21530	132.96048099999999	132.988122	48.702471000000003	48.672606999999999	пер. Молодежный	0103000020E61000000100000005000000BD6DA642BC9E6040C40776FC17564840BD6DA642BC9E6040B8B1D991EA594840A94E07B29E9F6040B8B1D991EA594840A94E07B29E9F6040C40776FC17564840BD6DA642BC9E6040C40776FC17564840
46338	21530	132.96048099999999	132.988122	48.702471000000003	48.672606999999999	Центральная	0103000020E61000000100000005000000BD6DA642BC9E6040C40776FC17564840BD6DA642BC9E6040B8B1D991EA594840A94E07B29E9F6040B8B1D991EA594840A94E07B29E9F6040C40776FC17564840BD6DA642BC9E6040C40776FC17564840
46300	22120	132.783477	132.80994999999999	48.429575999999997	48.410812	Центральная	0103000020E6100000010000000500000062855B3E12996040F566D47C9534484062855B3E12996040C092AB58FC364840A52C431CEB996040C092AB58FC364840A52C431CEB996040F566D47C9534484062855B3E12996040F566D47C95344840
46316	46018	132.81772900000001	132.84086099999999	48.390982999999999	48.381402999999999	Советская	0103000020E61000000100000005000000B5FF01D62A9A604053CC41D0D1304840B5FF01D62A9A60405F251FBB0B3248406BEF5355E89A60405F251FBB0B3248406BEF5355E89A604053CC41D0D1304840B5FF01D62A9A604053CC41D0D1304840
46775	3781	131.01082199999999	131.04402400000001	48.986539999999998	48.969185000000003	Центральная	0103000020E61000000100000005000000790261A7586060400B630B410E7C4840790261A758606040111956F1467E4840A70705A568616040111956F1467E4840A70705A5686160400B630B410E7C4840790261A7586060400B630B410E7C4840
46471	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	микрорайон 2	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46423	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	микрорайон 1	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46420	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Пограничная	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46422	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Плеханова	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46524	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Первомайская	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46523	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Некрасова	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46419	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Ленина	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46550	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Красноармейская	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46474	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Гайдара	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46468	6039	127.635007	127.71719400000001	52.025030000000001	51.972898000000001	Ворошилова	0103000020E61000000100000005000000CA6E66F4A3E85F40022CF2EB87FC4940CA6E66F4A3E85F409EB5DB2E34034A40CCB8A981E6ED5F409EB5DB2E34034A40CCB8A981E6ED5F40022CF2EB87FC4940CA6E66F4A3E85F40022CF2EB87FC4940
46764	55748	129.387674	129.409153	50.859059000000002	50.846730999999998	Школьная	0103000020E610000001000000050000004EF04DD3672C604033C170AE616C49404EF04DD3672C6040D02A33A5F56D4940EE4108C8172D6040D02A33A5F56D4940EE4108C8172D604033C170AE616C49404EF04DD3672C604033C170AE616C4940
46659	55733	126.517224	126.556669	52.797134	52.768363999999998	переулок Школьный	0103000020E61000000100000005000000342DB1321AA15F403DB665C059624A40342DB1321AA15F40CC43A67C08664A409C6C0377A0A35F40CC43A67C08664A409C6C0377A0A35F403DB665C059624A40342DB1321AA15F403DB665C059624A40
46466	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Школьная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46820	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Чкалова	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46819	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Хвойная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46522	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Фестивальная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46416	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Спортивная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46561	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Сосновая	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46593	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Советская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46892	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Свердловская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
47143	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Радистов	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46418	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Профсоюзная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46681	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Победы	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46646	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Первомайская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46545	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Октябрьская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46469	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Московский Бульвар	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46460	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Мира	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46592	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Летная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46534	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Лесная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46655	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Ленинская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46695	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Ленина	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46520	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Красная Пресня	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46547	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Кирова	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46526	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Киевская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46658	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Железнодорожная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46821	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Дружная	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46733	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Геологов	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46620	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Амурская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46647	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	Алтайская	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46680	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	8-е Марта	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46633	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	70 лет Октября	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46473	3466	124.68052	124.79870200000001	55.177864	55.102131999999997	 Красная Пресня	0103000020E610000001000000050000008811C2A38D2B5F4002F04FA9128D4B408811C2A38D2B5F4060915F3FC4964B40FD4FFEEE1D335F4060915F3FC4964B40FD4FFEEE1D335F4002F04FA9128D4B408811C2A38D2B5F4002F04FA9128D4B40
46615	55729	126.729523	126.77889500000001	52.647165999999999	52.621451	Амурская	0103000020E6100000010000000500000082AB3C81B0AE5F408388D4B48B4F4A4082AB3C81B0AE5F40A48AE255D6524A4026016A6AD9B15F40A48AE255D6524A4026016A6AD9B15F408388D4B48B4F4A4082AB3C81B0AE5F408388D4B48B4F4A40
46408	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Чубаровых	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46543	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Управленческая	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46532	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Театральный	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46644	7235	128.08741699999999	128.21921699999999	51.386485999999998	51.303942999999997	Михайло-Чесноковская	0103000020E61000000100000005000000A983BC1ECC0260408F6CAE9AE7A64940A983BC1ECC026040512E8D5F78B1494045B75ED303076040512E8D5F78B1494045B75ED3030760408F6CAE9AE7A64940A983BC1ECC0260408F6CAE9AE7A64940
46517	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Механический	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46409	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Матросова	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46512	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Малиновского	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46406	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Лермонтова	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46413	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Ленина	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46515	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Кручинина	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46514	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Котовского	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46516	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Комарова	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46535	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Кирпичный	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46463	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Кирова	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46464	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Каменчука	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46511	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	Бузулинское шоссе	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46513	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	50 лет Октября	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46407	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	40 лет Октября	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46533	7235	128.07401400000001	128.183042	51.462021999999997	51.323478000000001	 50 лет Октября	0103000020E6100000010000000500000047AE9B525E026040DD7C23BA67A9494047AE9B525E0260402904728923BB49406C79E57ADB0560402904728923BB49406C79E57ADB056040DD7C23BA67A9494047AE9B525E026040DD7C23BA67A94940
46461	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Шахтерская	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46559	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Северная	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46459	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Пономаренко	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46402	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Победы	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46405	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Пионерская	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46531	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Музыкальная	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46507	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Ворошилова	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46505	8466	129.372142	129.46579199999999	49.826307999999997	49.741281999999998	Апанасенко	0103000020E61000000100000005000000FAEE5696E82B6040868E1D54E2DE4840FAEE5696E82B60402A36E675C4E94840A1D79FC4E72E60402A36E675C4E94840A1D79FC4E72E6040868E1D54E2DE4840FAEE5696E82B6040868E1D54E2DE4840
46608	55717	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	Набережная	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
46536	55717	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	Ленинградская	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
46689	55737	129.57268199999999	129.61483999999999	49.7958	49.769520999999997	Поярковская	0103000020E6100000010000000500000040A0336953326040E84A04AA7FE2484040A033695332604012143FC6DCE54840B988EFC4AC33604012143FC6DCE54840B988EFC4AC336040E84A04AA7FE2484040A0336953326040E84A04AA7FE24840
46397	55701	125.785169	125.835313	53.470981999999999	53.434648000000003	Калинина	0103000020E6100000010000000500000050357A3540725F40CBA2B08BA2B74A4050357A3540725F4099805F2349BC4A401D3BA8C475755F4099805F2349BC4A401D3BA8C475755F40CBA2B08BA2B74A4050357A3540725F40CBA2B08BA2B74A40
46672	16732	127.143557	127.314273	53.772472	53.707222000000002	мкр.Солнечный	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46499	16732	127.143557	127.314273	53.772472	53.707222000000002	мкр.Светлый	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46367	16732	127.143557	127.314273	53.772472	53.707222000000002	Шохина	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46452	16732	127.143557	127.314273	53.772472	53.707222000000002	Народная	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46498	16732	127.143557	127.314273	53.772472	53.707222000000002	Мухина	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46566	16732	127.143557	127.314273	53.772472	53.707222000000002	Ленина	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46451	16732	127.143557	127.314273	53.772472	53.707222000000002	Б.Хмельницкого	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46509	16732	127.143557	127.314273	53.772472	53.707222000000002	 пр.40-летия Победы	0103000020E610000001000000050000002907B30930C95F408081204086DA4A402907B30930C95F40B189CC5CE0E24A400341800C1DD45F40B189CC5CE0E24A400341800C1DD45F408081204086DA4A402907B30930C95F408081204086DA4A40
46582	55722	121.93104599999999	121.97144400000001	53.971577000000003	53.945120000000003	Партизанская	0103000020E610000001000000050000009544F641967B5E40D46531B1F9F84A409544F641967B5E40DD4598A25CFC4A404F7974232C7E5E40DD4598A25CFC4A404F7974232C7E5E40D46531B1F9F84A409544F641967B5E40D46531B1F9F84A40
46610	55725	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	Октбярьская	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
46594	55725	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	Амурская	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
46493	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	переулок Южный	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46421	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Строителей	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46500	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Садовая	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46387	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Октябрьская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46487	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Ленина	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46385	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Кантемирова	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46491	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Игнатьевское шоссе	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46391	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Зейская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46440	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Дьяченко	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46388	55698	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Горького	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46555	55699	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Ломоносова	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46782	55699	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Авиационная	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46389	55699	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	50 лет ВЛКСМ	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46710	55741	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	Калинина	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
46472	6663	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	Ленинградская	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
46684	6663	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	Бурейская	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
46826	55704	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	Тишкина	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
46552	55704	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	Советская	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
46424	55704	129.60435699999999	129.7243	49.773285000000001	49.721403000000002	Крымская	0103000020E610000001000000050000007AC37DE4563360403F1EFAEE56DC48407AC37DE45633604062BEBC00FBE24840C58F31772D37604062BEBC00FBE24840C58F31772D3760403F1EFAEE56DC48407AC37DE4563360403F1EFAEE56DC4840
46683	55735	129.57268199999999	129.61483999999999	49.7958	49.769520999999997	Светлая	0103000020E6100000010000000500000040A0336953326040E84A04AA7FE2484040A033695332604012143FC6DCE54840B988EFC4AC33604012143FC6DCE54840B988EFC4AC336040E84A04AA7FE2484040A0336953326040E84A04AA7FE24840
46827	55735	129.57268199999999	129.61483999999999	49.7958	49.769520999999997	Депутатская	0103000020E6100000010000000500000040A0336953326040E84A04AA7FE2484040A033695332604012143FC6DCE54840B988EFC4AC33604012143FC6DCE54840B988EFC4AC336040E84A04AA7FE2484040A0336953326040E84A04AA7FE24840
9697	40273	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	9 Мая	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
47055	5998	128.20017300000001	128.241918	52.144948999999997	52.119259	Советская	0103000020E610000001000000050000005A1135D167066040786000E1430F4A405A1135D167066040404B57B08D124A400A4AD1CABD076040404B57B08D124A400A4AD1CABD076040786000E1430F4A405A1135D167066040786000E1430F4A40
47053	5943	126.54921299999999	126.571905	51.887787000000003	51.864629000000001	Школьная	0103000020E610000001000000050000006F62484E26A35F402B16BF29ACEE49406F62484E26A35F4030682101A3F14940CFDA6D179AA45F4030682101A3F14940CFDA6D179AA45F402B16BF29ACEE49406F62484E26A35F402B16BF29ACEE4940
47187	5889	128.12040300000001	128.13894400000001	52.457653000000001	52.434230999999997	Октябрьская	0103000020E61000000100000005000000E46A6457DA03604066F4A3E194374A40E46A6457DA03604049F59D5F943A4A4037FFAF3A7204604049F59D5F943A4A4037FFAF3A7204604066F4A3E194374A40E46A6457DA03604066F4A3E194374A40
46824	5851	126.982327	127.011639	51.475594000000001	51.463048999999998	Советская	0103000020E6100000010000000500000094BE1072DEBE5F4006B98B3045BB494094BE1072DEBE5F404016A243E0BC4940EC1681B1BEC05F404016A243E0BC4940EC1681B1BEC05F4006B98B3045BB494094BE1072DEBE5F4006B98B3045BB4940
47150	5775	127.89382999999999	127.914177	51.925269999999998	51.911538	Школьная	0103000020E61000000100000005000000C18BBE8234F95F40D787F546ADF44940C18BBE8234F95F4026FC523F6FF6494058703FE081FA5F4026FC523F6FF6494058703FE081FA5F40D787F546ADF44940C18BBE8234F95F40D787F546ADF44940
46735	5743	127.278493	127.296109	51.970151000000001	51.958981000000001	Центральная	0103000020E610000001000000050000008ECA4DD4D2D15F40213EB0E3BFFA49408ECA4DD4D2D15F40429770E82DFC494048C32973F3D25F40429770E82DFC494048C32973F3D25F40213EB0E3BFFA49408ECA4DD4D2D15F40213EB0E3BFFA4940
47152	5679	127.83010299999999	127.843273	51.954391000000001	51.950266999999997	Советская	0103000020E61000000100000005000000EF53556820F55F40E8BB5B59A2F94940EF53556820F55F40624CFA7B29FA49406326512FF8F55F40624CFA7B29FA49406326512FF8F55F40E8BB5B59A2F94940EF53556820F55F40E8BB5B59A2F94940
46825	5630	126.90861099999999	126.930333	51.656652000000001	51.638807999999997	Школьная	0103000020E610000001000000050000004B72C0AE26BA5F402A36E675C4D149404B72C0AE26BA5F402F6D382C0DD44940EF586C938ABB5F402F6D382C0DD44940EF586C938ABB5F402A36E675C4D149404B72C0AE26BA5F402A36E675C4D14940
46657	5543	127.647763	127.662271	52.062381000000002	52.043818000000002	Советская	0103000020E61000000100000005000000C423F1F274E95F40F27C06D49B054A40C423F1F274E95F402672C119FC074A40B685E7A562EA5F402672C119FC074A40B685E7A562EA5F40F27C06D49B054A40C423F1F274E95F40F27C06D49B054A40
47151	5544	127.10023099999999	127.118278	51.860674000000003	51.837864000000003	Советская	0103000020E61000000100000005000000E7C2482F6AC65F40753FA7203FEB4940E7C2482F6AC65F403E42CD902AEE49408675E3DD91C75F403E42CD902AEE49408675E3DD91C75F40753FA7203FEB4940E7C2482F6AC65F40753FA7203FEB4940
46742	5461	126.552789	126.58394199999999	52.114597000000003	52.095286000000002	Советская	0103000020E61000000100000005000000AB251DE560A35F4022E2E654320C4A40AB251DE560A35F40209C4F1DAB0E4A40B130444E5FA55F40209C4F1DAB0E4A40B130444E5FA55F4022E2E654320C4A40AB251DE560A35F4022E2E654320C4A40
46682	5382	127.194464	127.232607	52.282294	52.260393999999998	Калинина	0103000020E61000000100000005000000F50F221972CC5F408D09319754214A40F50F221972CC5F40B3EDB43522244A4086747808E3CE5F40B3EDB43522244A4086747808E3CE5F408D09319754214A40F50F221972CC5F408D09319754214A40
46762	5373	127.765326	127.779771	52.025086000000002	52.017726000000003	Советская	0103000020E61000000100000005000000D331E719FBF05F40FB2477D844024A40D331E719FBF05F4032CB9E0436034A40A1D79FC4E7F15F4032CB9E0436034A40A1D79FC4E7F15F40FB2477D844024A40D331E719FBF05F40FB2477D844024A40
46822	5294	128.096283	128.11074600000001	52.425153999999999	52.413901000000003	Баргулинская	0103000020E61000000100000005000000250516C0140360400F643DB5FA344A40250516C014036040BDE13E726B364A403605323B8B036040BDE13E726B364A403605323B8B0360400F643DB5FA344A40250516C0140360400F643DB5FA344A40
46731	5232	127.216617	127.22743199999999	52.310670000000002	52.303229999999999	Мухина	0103000020E610000001000000050000007DB08C0DDDCD5F4042959A3DD0264A407DB08C0DDDCD5F4096ECD808C4274A401684F23E8ECE5F4096ECD808C4274A401684F23E8ECE5F4042959A3DD0264A407DB08C0DDDCD5F4042959A3DD0264A40
47063	5147	127.463842	127.484728	52.167127000000001	52.158194000000002	им. Сергея Лазо	0103000020E61000000100000005000000B8205B96AFDD5F40333674B33F144A40B8205B96AFDD5F40A9A3E36A64154A4027DD96C805DF5F40A9A3E36A64154A4027DD96C805DF5F40333674B33F144A40B8205B96AFDD5F40333674B33F144A40
47052	5069	127.669628	127.681657	52.142721999999999	52.136381999999998	Школьная	0103000020E61000000100000005000000191F662FDBEA5F40ACE122F774114A40191F662FDBEA5F40B935E9B644124A40BA85AE44A0EB5F40B935E9B644124A40BA85AE44A0EB5F40ACE122F774114A40191F662FDBEA5F40ACE122F774114A40
46786	4984	126.57991800000001	126.597911	52.169933	52.158161	Управленческая	0103000020E61000000100000005000000271763601DA55F405740A19E3E144A40271763601DA55F406EC1525DC0154A40CBBA7F2C44A65F406EC1525DC0154A40CBBA7F2C44A65F405740A19E3E144A40271763601DA55F405740A19E3E144A40
46823	4949	127.23806	127.260535	51.741343000000001	51.735616	Трудовая	0103000020E61000000100000005000000179F02603CCF5F40093543AA28DE4940179F02603CCF5F402C0FD253E4DE4940A81DFE9AACD05F402C0FD253E4DE4940A81DFE9AACD05F40093543AA28DE4940179F02603CCF5F40093543AA28DE4940
78612	61339	123.156519	123.175797	55.318351999999997	55.307982000000003	Зейская	0103000020E61000000100000005000000F88C446804CA5E40DBE044F46BA74B40F88C446804CA5E40DF4E22C2BFA84B40096F0F4240CB5E40DF4E22C2BFA84B40096F0F4240CB5E40DBE044F46BA74B40F88C446804CA5E40DBE044F46BA74B40
46553	55720	119.656153	128.14549299999999	57.053058999999998	53.859296999999998	 Школьная	0103000020E61000000100000005000000070B2769FEE95D408446B071FDED4A40070B2769FEE95D4015E126A3CA864C408099EFE0A704604015E126A3CA864C408099EFE0A70460408446B071FDED4A40070B2769FEE95D408446B071FDED4A40
78579	61333	127.44693599999999	127.46969900000001	55.030689000000002	55.015892999999998	Подмосковная	0103000020E61000000100000005000000ECD973999ADC5F401F9E25C808824B40ECD973999ADC5F4069ACFD9DED834B40B1FD648C0FDE5F4069ACFD9DED834B40B1FD648C0FDE5F401F9E25C808824B40ECD973999ADC5F401F9E25C808824B40
78599	55759	124.819948	124.85669799999999	55.117221000000001	55.106042000000002	Центральная	0103000020E61000000100000005000000EB1A2D077A345F405000C5C8928D4B40EB1A2D077A345F40C4B30419018F4B401C23D923D4365F40C4B30419018F4B401C23D923D4365F405000C5C8928D4B40EB1A2D077A345F405000C5C8928D4B40
46850	55759	124.819948	124.85669799999999	55.117221000000001	55.106042000000002	Полевая партия	0103000020E61000000100000005000000EB1A2D077A345F405000C5C8928D4B40EB1A2D077A345F40C4B30419018F4B401C23D923D4365F40C4B30419018F4B401C23D923D4365F405000C5C8928D4B40EB1A2D077A345F405000C5C8928D4B40
78449	61297	123.856217	123.87128199999999	54.437240000000003	54.421008999999998	Лесная	0103000020E61000000100000005000000DF516342CCF65E402C29779FE3354B40DF516342CCF65E406440F67AF7374B40FBE59315C3F75E406440F67AF7374B40FBE59315C3F75E402C29779FE3354B40DF516342CCF65E402C29779FE3354B40
79382	61557	119.656153	128.14549299999999	57.053058999999998	53.859296999999998	Тульская	0103000020E61000000100000005000000070B2769FEE95D408446B071FDED4A40070B2769FEE95D4015E126A3CA864C408099EFE0A704604015E126A3CA864C408099EFE0A70460408446B071FDED4A40070B2769FEE95D408446B071FDED4A40
79393	61563	119.656153	128.14549299999999	57.053058999999998	53.859296999999998	Мира	0103000020E61000000100000005000000070B2769FEE95D408446B071FDED4A40070B2769FEE95D4015E126A3CA864C408099EFE0A704604015E126A3CA864C408099EFE0A70460408446B071FDED4A40070B2769FEE95D408446B071FDED4A40
78476	61303	124.20170899999999	124.21955	55.214928	55.180089000000002	Первостроителей	0103000020E61000000100000005000000C493DDCCE80C5F4047AF06280D974B40C493DDCCE80C5F40527FBDC2829B4B408E75711B0D0E5F40527FBDC2829B4B408E75711B0D0E5F4047AF06280D974B40C493DDCCE80C5F4047AF06280D974B40
78686	61354	123.964051	123.976124	54.627412	54.622810000000001	Мира	0103000020E61000000100000005000000452BF702B3FD5E4096CFF23CB84F4B40452BF702B3FD5E40198F52094F504B40CE35CCD078FE5E40198F52094F504B40CE35CCD078FE5E4096CFF23CB84F4B40452BF702B3FD5E4096CFF23CB84F4B40
47031	1301	128.18623099999999	128.22815600000001	50.160530000000001	50.147826000000002	Луговая	0103000020E610000001000000050000000BD0B69AF5056040CFBF5DF6EB1249400BD0B69AF505604071033E3F8C1449405CCCCF0D4D07604071033E3F8C1449405CCCCF0D4D076040CFBF5DF6EB1249400BD0B69AF5056040CFBF5DF6EB124940
46667	47548	127.919414	127.95672999999999	50.211239999999997	50.196209000000003	Пионерская	0103000020E61000000100000005000000035FD1ADD7FA5F40271763601D194940035FD1ADD7FA5F40B3CD8DE9091B4940884677103BFD5F40B3CD8DE9091B4940884677103BFD5F40271763601D194940035FD1ADD7FA5F40271763601D194940
46538	47199	128.03628499999999	128.083868	50.113138999999997	50.084519	Техническая	0103000020E61000000100000005000000BB0A293F290160400072C284D10A4940BB0A293F290160407973B8567B0E4940CAA5F10BAF0260407973B8567B0E4940CAA5F10BAF0260400072C284D10A4940BB0A293F290160400072C284D10A4940
46417	47199	128.03628499999999	128.083868	50.113138999999997	50.084519	Ленинская	0103000020E61000000100000005000000BB0A293F290160400072C284D10A4940BB0A293F290160407973B8567B0E4940CAA5F10BAF0260407973B8567B0E4940CAA5F10BAF0260400072C284D10A4940BB0A293F290160400072C284D10A4940
47040	962	127.96086200000001	127.98292499999999	49.974193999999997	49.959150999999999	Свободная	0103000020E61000000100000005000000077E54C37EFD5F407D76C075C5FA4840077E54C37EFD5F40CEFA9463B2FC4840EE5A423EE8FE5F40CEFA9463B2FC4840EE5A423EE8FE5F407D76C075C5FA4840077E54C37EFD5F407D76C075C5FA4840
46660	47493	127.864158	127.881604	50.163144000000003	50.149766	Юбилейная	0103000020E61000000100000005000000EA245B5D4EF75F40C00644882B134940EA245B5D4EF75F40F24410E7E114494075012F336CF85F40F24410E7E114494075012F336CF85F40C00644882B134940EA245B5D4EF75F40C00644882B134940
47146	47598	127.88751499999999	127.90467200000001	50.009960999999997	50.000385000000001	Озёрная	0103000020E6100000010000000500000067EDB60BCDF85F4059349D9D0C00494067EDB60BCDF85F40239EEC6646014940D8666325E6F95F40239EEC6646014940D8666325E6F95F4059349D9D0C00494067EDB60BCDF85F4059349D9D0C004940
46726	1865	127.741062	127.761337	49.820717000000002	49.812823999999999	Школьная	0103000020E61000000100000005000000BC934F8F6DEF5F40B3B3E89D0AE84840BC934F8F6DEF5F40B82231410DE94840060FD3BEB9F05F40B82231410DE94840060FD3BEB9F05F40B3B3E89D0AE84840BC934F8F6DEF5F40B3B3E89D0AE84840
46530	55716	127.80744799999999	127.843093	50.032429	50.007651000000003	Ленина	0103000020E610000001000000050000001E4E603AADF35F400F643DB5FA0049401E4E603AADF35F4093382BA226044940239F573CF5F55F4093382BA226044940239F573CF5F55F400F643DB5FA0049401E4E603AADF35F400F643DB5FA004940
46816	47269	128.15566200000001	128.176377	50.070396000000002	50.057026	Ленина	0103000020E610000001000000050000005CE7DF2EFB046040C782C2A04C0749405CE7DF2EFB04604076E272BC0209494088D860E1A405604076E272BC0209494088D860E1A4056040C782C2A04C0749405CE7DF2EFB046040C782C2A04C074940
46753	55746	128.136402	128.154269	49.974187999999998	49.965896999999998	Пионерская	0103000020E610000001000000050000007D23BA675D046040FA264D83A2FB48407D23BA675D046040EC134031B2FC48402CB98AC5EF046040EC134031B2FC48402CB98AC5EF046040FA264D83A2FB48407D23BA675D046040FA264D83A2FB4840
46913	1478	128.074274	128.090192	50.2089	50.198839	Школьная	0103000020E610000001000000050000002E1EDE7360026040AD156D8E731949402E1EDE73600260403411363CBD1A49408C4B55DAE20260403411363CBD1A49408C4B55DAE2026040AD156D8E731949402E1EDE7360026040AD156D8E73194940
10067	40510	128.26400699999999	128.291945	50.009689000000002	49.992114999999998	Центральная	0103000020E6100000010000000500000048DDCEBE720860407E6FD39FFDFE484048DDCEBE72086040C310397D3D01494062670A9D57096040C310397D3D01494062670A9D570960407E6FD39FFDFE484048DDCEBE720860407E6FD39FFDFE4840
46699	55740	127.655767	127.68083	50.073656999999997	50.049114000000003	Амурская	0103000020E61000000100000005000000F2B22616F8E95F404CE3175E49064940F2B22616F8E95F408C0FB3976D094940AF08FEB792EB5F408C0FB3976D094940AF08FEB792EB5F404CE3175E49064940F2B22616F8E95F404CE3175E49064940
46780	46089	128.16309100000001	128.18214399999999	50.217269999999999	50.206167000000001	Озёрная	0103000020E61000000100000005000000B4E89D0A38056040D94125AE631A4940B4E89D0A380560407233DC80CF1B49403465A71FD40560407233DC80CF1B49403465A71FD4056040D94125AE631A4940B4E89D0A38056040D94125AE631A4940
47140	1058	128.29916800000001	128.31083699999999	50.059201000000002	50.052070000000001	Набережная	0103000020E610000001000000050000005000C5C892096040268DD13AAA0649405000C5C892096040FC71FBE59307494060AC6F60F2096040FC71FBE59307494060AC6F60F2096040268DD13AAA0649405000C5C892096040268DD13AAA064940
46624	47558	127.848977	127.87310600000001	50.091495000000002	50.075778	Ленина	0103000020E610000001000000050000009983A0A355F65F40CEE0EF17B30949409983A0A355F65F40AF5FB01BB60B494040FCFCF7E0F75F40AF5FB01BB60B494040FCFCF7E0F75F40CEE0EF17B30949409983A0A355F65F40CEE0EF17B3094940
47048	47418	128.325839	128.357585	50.230738000000002	50.218693000000002	Центральная	0103000020E610000001000000050000005D18E9456D0A60409C6ED921FE1B49405D18E9456D0A6040E4F8A1D2881D494049111956710B6040E4F8A1D2881D494049111956710B60409C6ED921FE1B49405D18E9456D0A60409C6ED921FE1B4940
47051	2090	127.65542600000001	127.680004	50.006348000000003	49.9863	переулок Школьный	0103000020E61000000100000005000000AEBCE47FF2E95F40BC0512143FFE4840AEBCE47FF2E95F409032E202D00049408C497F2F85EB5F409032E202D00049408C497F2F85EB5F40BC0512143FFE4840AEBCE47FF2E95F40BC0512143FFE4840
47047	40404	127.505308	127.524694	49.996423999999998	49.971963000000002	Центральная	0103000020E610000001000000050000000F9A5DF756E05F4006F6984869FC48400F9A5DF756E05F40897956D28AFF4840139A249694E15F40897956D28AFF4840139A249694E15F4006F6984869FC48400F9A5DF756E05F4006F6984869FC4840
46691	55739	128.01502099999999	128.037803	50.070413000000002	50.052723	Речная улица	0103000020E610000001000000050000001AF8510D7B0060409E5F94A0BF0649401AF8510D7B0060404C1B0E4B030949401A16A3AE350160404C1B0E4B030949401A16A3AE350160409E5F94A0BF0649401AF8510D7B0060409E5F94A0BF064940
46810	1983	127.53895	127.55261400000001	49.904336999999998	49.887259	Набережная	0103000020E61000000100000005000000780B24287EE25F40740AF2B391F14840780B24287EE25F4008C89750C1F34840F4531C075EE35F4008C89750C1F34840F4531C075EE35F40740AF2B391F14840780B24287EE25F40740AF2B391F14840
46401	1183	128.224006	128.26858899999999	50.147896000000003	50.131199000000002	Комсомольская	0103000020E610000001000000050000007383A10E2B0760404B22FB20CB1049407383A10E2B076040C89A9141EE1249401762F54798086040C89A9141EE1249401762F547980860404B22FB20CB1049407383A10E2B0760404B22FB20CB104940
46619	47311	127.997648	128.03030200000001	50.031561000000004	50.004756	пер.Школьный	0103000020E61000000100000005000000DE3AFF76D9FF5F40DA3A38D89B004940DE3AFF76D9FF5F401F6ADB300A0449401C60E63BF80060401F6ADB300A0449401C60E63BF8006040DA3A38D89B004940DE3AFF76D9FF5F40DA3A38D89B004940
47144	47726	127.70501299999999	127.71484	49.957430000000002	49.945431999999997	Центральная	0103000020E610000001000000050000004F90D8EE1EED5F40C24B70EA03F948404F90D8EE1EED5F40CA1AF5108DFA4840D97745F0BFED5F40CA1AF5108DFA4840D97745F0BFED5F40C24B70EA03F948404F90D8EE1EED5F40C24B70EA03F94840
47066	1770	127.853657	127.881783	49.915139000000003	49.893439999999998	Садовая	0103000020E610000001000000050000001840F850A2F65F401878EE3D5CF248401840F850A2F65F40A725564623F54840CDCAF6216FF85F40A725564623F54840CDCAF6216FF85F401878EE3D5CF248401840F850A2F65F401878EE3D5CF24840
47062	1770	127.853657	127.881783	49.915139000000003	49.893439999999998	Калинина	0103000020E610000001000000050000001840F850A2F65F401878EE3D5CF248401840F850A2F65F40A725564623F54840CDCAF6216FF85F40A725564623F54840CDCAF6216FF85F401878EE3D5CF248401840F850A2F65F401878EE3D5CF24840
46597	32076	122.86241099999999	122.91728000000001	54.060287000000002	54.029496999999999	Карьерская	0103000020E610000001000000050000007B2DE8BD31B75E40412AC58EC6034B407B2DE8BD31B75E40DEAF027CB7074B4098512CB7B4BA5E40DEAF027CB7074B4098512CB7B4BA5E40412AC58EC6034B407B2DE8BD31B75E40412AC58EC6034B40
46621	32259	123.582437	123.626311	54.119993000000001	54.102120999999997	Якимаса	0103000020E61000000100000005000000BEBED6A546E55E400E9E094D120D4B40BEBED6A546E55E40DD5F3DEE5B0F4B400188BB7A15E85E40DD5F3DEE5B0F4B400188BB7A15E85E400E9E094D120D4B40BEBED6A546E55E400E9E094D120D4B40
46479	32462	124.79263	124.832838	53.703805000000003	53.677743	Лисина	0103000020E6100000010000000500000006F52D73BA325F40E50B5A48C0D64A4006F52D73BA325F4072E1404816DA4A406D37C1374D355F4072E1404816DA4A406D37C1374D355F40E50B5A48C0D64A4006F52D73BA325F40E50B5A48C0D64A40
47179	32304	123.663151	123.678135	54.138131999999999	54.124152000000002	Пионерская	0103000020E61000000100000005000000D253E41071EA5E40D3DD7536E40F4B40D253E41071EA5E40FA43334FAE114B4078D1579066EB5E40FA43334FAE114B4078D1579066EB5E40D3DD7536E40F4B40D253E41071EA5E40D3DD7536E40F4B40
46415	45	123.904349	123.987137	53.996434999999998	53.970412000000003	Победы	0103000020E61000000100000005000000E6CAA0DAE0F95E40AFD2DD7536FC4A40E6CAA0DAE0F95E407DCB9C2E8BFF4A40FBEAAA402DFF5E407DCB9C2E8BFF4A40FBEAAA402DFF5E40AFD2DD7536FC4A40E6CAA0DAE0F95E40AFD2DD7536FC4A40
46414	45	123.904349	123.987137	53.996434999999998	53.970412000000003	Дзержинского	0103000020E61000000100000005000000E6CAA0DAE0F95E40AFD2DD7536FC4A40E6CAA0DAE0F95E407DCB9C2E8BFF4A40FBEAAA402DFF5E407DCB9C2E8BFF4A40FBEAAA402DFF5E40AFD2DD7536FC4A40E6CAA0DAE0F95E40AFD2DD7536FC4A40
46675	45	123.904349	123.987137	53.996434999999998	53.970412000000003	Воровского	0103000020E61000000100000005000000E6CAA0DAE0F95E40AFD2DD7536FC4A40E6CAA0DAE0F95E407DCB9C2E8BFF4A40FBEAAA402DFF5E407DCB9C2E8BFF4A40FBEAAA402DFF5E40AFD2DD7536FC4A40E6CAA0DAE0F95E40AFD2DD7536FC4A40
46645	45	123.904349	123.987137	53.996434999999998	53.970412000000003	Василевского	0103000020E61000000100000005000000E6CAA0DAE0F95E40AFD2DD7536FC4A40E6CAA0DAE0F95E407DCB9C2E8BFF4A40FBEAAA402DFF5E407DCB9C2E8BFF4A40FBEAAA402DFF5E40AFD2DD7536FC4A40E6CAA0DAE0F95E40AFD2DD7536FC4A40
46540	45	123.904349	123.987137	53.996434999999998	53.970412000000003	60 лет СССР	0103000020E61000000100000005000000E6CAA0DAE0F95E40AFD2DD7536FC4A40E6CAA0DAE0F95E407DCB9C2E8BFF4A40FBEAAA402DFF5E407DCB9C2E8BFF4A40FBEAAA402DFF5E40AFD2DD7536FC4A40E6CAA0DAE0F95E40AFD2DD7536FC4A40
46998	18893	123.689678	123.69696399999999	53.500627999999999	53.497616999999998	Амурская	0103000020E6100000010000000500000053B131AF23EC5E408177F2E9B1BF4A4053B131AF23EC5E401FBB0B9414C04A40519FE40E9BEC5E401FBB0B9414C04A40519FE40E9BEC5E408177F2E9B1BF4A4053B131AF23EC5E408177F2E9B1BF4A40
46590	32378	124.10272399999999	124.18000600000001	54.006855000000002	53.970688000000003	Партизанская	0103000020E61000000100000005000000EA20AF0793065F40514F1F813FFC4A40EA20AF0793065F403468E89FE0004B405DC5E237850B5F403468E89FE0004B405DC5E237850B5F40514F1F813FFC4A40EA20AF0793065F40514F1F813FFC4A40
46477	55710	121.93104599999999	121.97144400000001	53.971577000000003	53.945120000000003	Пушкина	0103000020E610000001000000050000009544F641967B5E40D46531B1F9F84A409544F641967B5E40DD4598A25CFC4A404F7974232C7E5E40DD4598A25CFC4A404F7974232C7E5E40D46531B1F9F84A409544F641967B5E40D46531B1F9F84A40
46519	55710	121.93104599999999	121.97144400000001	53.971577000000003	53.945120000000003	Октябрьская	0103000020E610000001000000050000009544F641967B5E40D46531B1F9F84A409544F641967B5E40DD4598A25CFC4A404F7974232C7E5E40DD4598A25CFC4A404F7974232C7E5E40D46531B1F9F84A409544F641967B5E40D46531B1F9F84A40
46755	462	121.93104599999999	121.97144400000001	53.971577000000003	53.945120000000003	Пионерская	0103000020E610000001000000050000009544F641967B5E40D46531B1F9F84A409544F641967B5E40DD4598A25CFC4A404F7974232C7E5E40DD4598A25CFC4A404F7974232C7E5E40D46531B1F9F84A409544F641967B5E40D46531B1F9F84A40
46654	32334	123.682528	123.709396	54.122394	54.112594000000001	Амурская	0103000020E61000000100000005000000ADA6EB89AEEB5E40E8DCED7A690E4B40ADA6EB89AEEB5E40029D499BAA0F4B4072FA7ABE66ED5E40029D499BAA0F4B4072FA7ABE66ED5E40E8DCED7A690E4B40ADA6EB89AEEB5E40E8DCED7A690E4B40
46837	46504	129.05554000000001	129.08473499999999	50.940372000000004	50.926329000000003	Октябрьская	0103000020E61000000100000005000000D673D2FBC62160400F2BDCF291764940D673D2FBC62160407D09151C5E78494073BA2C26B62260407D09151C5E78494073BA2C26B62260400F2BDCF291764940D673D2FBC62160400F2BDCF291764940
46806	46454	128.743537	128.76076699999999	51.067571000000001	51.047088000000002	Октябрьская	0103000020E61000000100000005000000B64B1B0ECB1760405C04C6FA06864940B64B1B0ECB1760403A94A12AA6884940081C0934581860403A94A12AA6884940081C0934581860405C04C6FA06864940B64B1B0ECB1760405C04C6FA06864940
46809	55752	128.48978099999999	128.536089	51.153145000000002	51.141052999999999	Советская	0103000020E6100000010000000500000078263449AC0F6040580053060E92494078263449AC0F6040E1455F419A934940DA571EA427116040E1455F419A934940DA571EA427116040580053060E92494078263449AC0F6040580053060E924940
47160	30986	128.31305499999999	128.32971900000001	51.097366999999998	51.089238000000002	Центральная	0103000020E610000001000000050000002D5BEB8B040A6040BDC799266C8B49402D5BEB8B040A6040D55A9885768C4940D63BDC0E8D0A6040D55A9885768C4940D63BDC0E8D0A6040BDC799266C8B49402D5BEB8B040A6040BDC799266C8B4940
46618	45877	128.388182	128.424824	50.963807000000003	50.952204999999999	Украинская	0103000020E61000000100000005000000AB5CA8FC6B0C6040390B7BDAE1794940AB5CA8FC6B0C6040F4531C075E7B4940CA518028980D6040F4531C075E7B4940CA518028980D6040390B7BDAE1794940AB5CA8FC6B0C6040390B7BDAE1794940
46600	45877	128.388182	128.424824	50.963807000000003	50.952204999999999	Ленина	0103000020E61000000100000005000000AB5CA8FC6B0C6040390B7BDAE1794940AB5CA8FC6B0C6040F4531C075E7B4940CA518028980D6040F4531C075E7B4940CA518028980D6040390B7BDAE1794940AB5CA8FC6B0C6040390B7BDAE1794940
46722	46143	128.31523799999999	128.352384	50.963030000000003	50.954242000000001	Центральная	0103000020E610000001000000050000009B8E006E160A60401D3C139A247A49409B8E006E160A604090882991447B49404774CFBA460B604090882991447B49404774CFBA460B60401D3C139A247A49409B8E006E160A60401D3C139A247A4940
46836	46390	128.74751699999999	128.77900299999999	51.169401999999998	51.160184000000001	Центральная	0103000020E610000001000000050000008786C5A8EB176040D6ABC8E8809449408786C5A8EB17604041F0F8F6AE9549408C0FB397ED18604041F0F8F6AE9549408C0FB397ED186040D6ABC8E8809449408786C5A8EB176040D6ABC8E880944940
47010	46552	129.194096	129.21346399999999	51.014114999999997	51.006169	Центральная	0103000020E610000001000000050000001A89D00836266040E09F5225CA8049401A89D0083626604007B13385CE814940F25B74B2D426604007B13385CE814940F25B74B2D4266040E09F5225CA8049401A89D00836266040E09F5225CA804940
46542	55703	128.358384	128.40905799999999	51.104861	51.078221999999997	им.Святителя Иннокентия	0103000020E610000001000000050000001CEDB8E1770B6040F2E9B12D038A49401CEDB8E1770B60401CD0D2156C8D49405985CD00170D60401CD0D2156C8D49405985CD00170D6040F2E9B12D038A49401CEDB8E1770B6040F2E9B12D038A4940
46521	55703	128.358384	128.40905799999999	51.104861	51.078221999999997	Чехова	0103000020E610000001000000050000001CEDB8E1770B6040F2E9B12D038A49401CEDB8E1770B60401CD0D2156C8D49405985CD00170D60401CD0D2156C8D49405985CD00170D6040F2E9B12D038A49401CEDB8E1770B6040F2E9B12D038A4940
46412	55703	128.358384	128.40905799999999	51.104861	51.078221999999997	Советская	0103000020E610000001000000050000001CEDB8E1770B6040F2E9B12D038A49401CEDB8E1770B60401CD0D2156C8D49405985CD00170D60401CD0D2156C8D49405985CD00170D6040F2E9B12D038A49401CEDB8E1770B6040F2E9B12D038A4940
46539	55718	128.358384	128.40905799999999	51.104861	51.078221999999997	Горького	0103000020E610000001000000050000001CEDB8E1770B6040F2E9B12D038A49401CEDB8E1770B60401CD0D2156C8D49405985CD00170D60401CD0D2156C8D49405985CD00170D6040F2E9B12D038A49401CEDB8E1770B6040F2E9B12D038A4940
46737	46208	128.85809900000001	128.882237	50.913910000000001	50.901812999999997	пер.Пионерский	0103000020E610000001000000050000005FB7088C751B6040C70DBF9B6E7349405FB7088C751B604062BEBC00FB74494047CA16493B1C604062BEBC00FB74494047CA16493B1C6040C70DBF9B6E7349405FB7088C751B6040C70DBF9B6E734940
46616	46357	128.39352700000001	128.42533599999999	51.070802999999998	51.058309999999999	Школьная	0103000020E61000000100000005000000FA62EFC5970C6040CF83BBB376874940FA62EFC5970C6040B6BA9C1210894940F7393E5A9C0D6040B6BA9C1210894940F7393E5A9C0D6040CF83BBB376874940FA62EFC5970C6040CF83BBB376874940
47006	30677	128.696133	128.732946	50.916772999999999	50.906044000000001	Советская	0103000020E610000001000000050000005395B6B846166040575EF23FF97349405395B6B8461660408B6D52D1587549407D772B4B741760408B6D52D1587549407D772B4B74176040575EF23FF97349405395B6B846166040575EF23FF9734940
46808	46258	128.25815	128.27777	51.255755999999998	51.243172000000001	переулок Релочный	0103000020E61000000100000005000000CCEEC9C342086040C6A69542209F4940CCEEC9C342086040BDE0D39CBCA04940EB39E97DE3086040BDE0D39CBCA04940EB39E97DE3086040C6A69542209F4940CCEEC9C342086040C6A69542209F4940
47214	55773	128.552448	128.57599200000001	51.221283999999997	51.217464999999997	Центральная улица	0103000020E61000000100000005000000B3976DA7AD1160402783A3E4D59B4940B3976DA7AD1160406490BB08539C49403F58C6866E1260406490BB08539C49403F58C6866E1260402783A3E4D59B4940B3976DA7AD1160402783A3E4D59B4940
46866	30292	128.940628	128.95939300000001	51.032544000000001	51.027894000000003	Южная	0103000020E610000001000000050000007636E49F191E604098E0D407928349407636E49F191E60402CD7DB662A8449405DE0F258B31E60402CD7DB662A8449405DE0F258B31E604098E0D407928349407636E49F191E604098E0D40792834940
47199	55772	128.22855100000001	128.24560099999999	51.060456000000002	51.049715999999997	Секрышевская	0103000020E61000000100000005000000FBCE2F4A50076040410B09185D864940FBCE2F4A500760406A6CAF05BD874940ADDBA0F6DB0760406A6CAF05BD874940ADDBA0F6DB076040410B09185D864940FBCE2F4A50076040410B09185D864940
46840	55758	128.81825900000001	128.85098500000001	51.270184	51.257919999999999	Школьная	0103000020E610000001000000050000000C957F2D2F1A6040FE7DC68503A149400C957F2D2F1A604084F3A96395A249405F0CE5443B1B604084F3A96395A249405F0CE5443B1B6040FE7DC68503A149400C957F2D2F1A6040FE7DC68503A14940
46835	46151	128.67565099999999	128.693196	51.350059999999999	51.338982000000001	Ленина	0103000020E610000001000000050000004F90D8EE9E15604062F71DC363AB49404F90D8EE9E156040A2D11DC4CEAC4940FAB660A92E166040A2D11DC4CEAC4940FAB660A92E16604062F71DC363AB49404F90D8EE9E15604062F71DC363AB4940
47139	46157	128.124122	128.17413999999999	50.992429000000001	50.976371	Иванова	0103000020E61000000100000005000000DA56B3CEF8036040A4E194B9F97C4940DA56B3CEF80360400E4DD9E9077F49409D9D0C8E920560400E4DD9E9077F49409D9D0C8E92056040A4E194B9F97C4940DA56B3CEF8036040A4E194B9F97C4940
47168	46016	128.21124	128.22073599999999	51.235514999999999	51.221617000000002	Центральная	0103000020E610000001000000050000006D73637AC20660406B9E23F25D9C49406D73637AC2066040D55B035B259E494098A1F14410076040D55B035B259E494098A1F144100760406B9E23F25D9C49406D73637AC20660406B9E23F25D9C4940
46730	46082	128.04499799999999	128.071732	51.075251000000002	51.062358000000003	Кирова	0103000020E61000000100000005000000554CA59F700160406E52D158FB874940554CA59F70016040E3FE23D3A18949407442E8A04B026040E3FE23D3A18949407442E8A04B0260406E52D158FB874940554CA59F700160406E52D158FB874940
47009	46320	128.38900799999999	128.40493499999999	51.224443000000001	51.202404999999999	Центральная	0103000020E610000001000000050000003CBCE7C0720C604000C63368E89949403CBCE7C0720C60407768588CBA9C49402FC03E3AF50C60407768588CBA9C49402FC03E3AF50C604000C63368E89949403CBCE7C0720C604000C63368E8994940
47007	31133	128.83430300000001	128.86486400000001	51.165663000000002	51.156682000000004	Центральная	0103000020E610000001000000050000008D7E349CB21A60409AEFE0270E9449408D7E349CB21A60402194F771349549409C6F44F7AC1B60402194F771349549409C6F44F7AC1B60409AEFE0270E9449408D7E349CB21A60409AEFE0270E944940
46732	30213	128.91924800000001	128.934968	51.089022999999997	51.073785000000001	Переселенческая	0103000020E610000001000000050000003B1DC87A6A1D6040BAF770C9718949403B1DC87A6A1D6040C0CB0C1B658B4940CFD90242EB1D6040C0CB0C1B658B4940CFD90242EB1D6040BAF770C9718949403B1DC87A6A1D6040BAF770C971894940
47124	26814	128.68324200000001	128.709608	51.198658000000002	51.181919999999998	Партизанская	0103000020E610000001000000050000001EA8531EDD156040813E9127499749401EA8531EDD1560405D8B16A06D9949405C1FD61BB51660405D8B16A06D9949405C1FD61BB5166040813E9127499749401EA8531EDD156040813E912749974940
47224	55777	128.20095499999999	128.21952300000001	51.318288000000003	51.304782000000003	Центральная	0103000020E61000000100000005000000F71E2E396E0660406A34B91803A74940F71E2E396E066040C95A43A9BDA849400937195506076040C95A43A9BDA8494009371955060760406A34B91803A74940F71E2E396E0660406A34B91803A74940
46670	49413	128.42476099999999	128.47061099999999	50.965021	50.946035999999999	Школьная	0103000020E61000000100000005000000B87361A4970D6040596B28B517794940B87361A4970D6040037AE1CE857B494069C4CC3E0F0F6040037AE1CE857B494069C4CC3E0F0F6040596B28B517794940B87361A4970D6040596B28B517794940
46744	31240	128.555125	128.582379	51.050621999999997	51.042744999999996	Советская	0103000020E6100000010000000500000025068195C3116040A4880CAB7885494025068195C3116040A33A1DC87A86494012DC48D9A2126040A33A1DC87A86494012DC48D9A2126040A4880CAB7885494025068195C3116040A4880CAB78854940
46591	30125	128.139501	128.16238100000001	51.19679	51.166786999999999	Школьная	0103000020E610000001000000050000004C18CDCA76046040F032C346599549404C18CDCA7604604005172B6A30994940BD8FA3393205604005172B6A30994940BD8FA33932056040F032C346599549404C18CDCA76046040F032C34659954940
46738	46286	128.342502	128.36152000000001	51.143076000000001	51.119247000000001	Колхозная	0103000020E61000000100000005000000111AC1C6F50A6040B492567C438F4940111AC1C6F50A6040D76B7A5050924940331B6492910B6040D76B7A5050924940331B6492910B6040B492567C438F4940111AC1C6F50A6040B492567C438F4940
46956	48724	128.586862	128.61502400000001	50.931449000000001	50.923546999999999	Центральная	0103000020E610000001000000050000007C28D192C7126040D2A8C0C9367649407C28D192C71260402A7288B8397749402AC8CF46AE1360402A7288B8397749402AC8CF46AE136040D2A8C0C9367649407C28D192C7126040D2A8C0C936764940
46596	55726	128.17212799999999	128.25038000000001	51.289862999999997	51.256714000000002	Серышевская	0103000020E610000001000000050000003A5794128205604072361D01DCA049403A5794128205604004A9143B1AA5494052F2EA1C0308604004A9143B1AA5494052F2EA1C0308604072361D01DCA049403A5794128205604072361D01DCA04940
47175	31114	128.999629	129.032929	51.185923000000003	51.169604999999997	пер.Школьный	0103000020E6100000010000000500000043E4F4F5FC1F6040791EDC9DB595494043E4F4F5FC1F604080492A53CC974940E1421EC10D21604080492A53CC974940E1421EC10D216040791EDC9DB595494043E4F4F5FC1F6040791EDC9DB5954940
46589	55724	132.92833899999999	132.95901599999999	53.075536999999997	53.064776000000002	Центральная	0103000020E610000001000000050000003E93FDF3B49D604069C878944A884A403E93FDF3B49D6040A8514832AB894A40E78A5242B09E6040A8514832AB894A40E78A5242B09E604069C878944A884A403E93FDF3B49D604069C878944A884A40
46694	29490	132.92833899999999	132.95901599999999	53.075536999999997	53.064776000000002	Советская	0103000020E610000001000000050000003E93FDF3B49D604069C878944A884A403E93FDF3B49D6040A8514832AB894A40E78A5242B09E6040A8514832AB894A40E78A5242B09E604069C878944A884A403E93FDF3B49D604069C878944A884A40
47195	29755	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	Звёздная	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
46807	55751	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	Юбилейная	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
46697	55702	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	Центральная	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
46537	55702	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	Магистральная	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
46410	55702	130.82619099999999	130.90284500000001	52.471600000000002	52.426971999999999	Ленина	0103000020E61000000100000005000000FCA71B28705A60406327BC04A7364A40FCA71B28705A6040956588635D3C4A406E8B321BE45C6040956588635D3C4A406E8B321BE45C60406327BC04A7364A40FCA71B28705A60406327BC04A7364A40
46661	55734	132.86998399999999	132.89764299999999	53.148141000000003	53.121836999999999	Ворожейкина	0103000020E610000001000000050000006281AFE8D69B6040AC38D55A988F4A406281AFE8D69B60402F19C748F6924A40770FD07DB99C60402F19C748F6924A40770FD07DB99C6040AC38D55A988F4A406281AFE8D69B6040AC38D55A988F4A40
46613	29693	131.68225000000001	131.72739000000001	52.798358999999998	52.782429999999998	Майская	0103000020E6100000010000000500000046B6F3FDD475604063B48EAA26644A4046B6F3FDD4756040CFBBB1A030664A4000AE64C746776040CFBBB1A030664A4000AE64C74677604063B48EAA26644A4046B6F3FDD475604063B48EAA26644A40
47226	29582	132.536134	132.555691	52.771464000000002	52.758343000000004	Садыкова	0103000020E61000000100000005000000C2887D02289160404513286211614A40C2887D02289160404B051555BF624A40CFF57D38C89160404B051555BF624A40CFF57D38C89160404513286211614A40C2887D02289160404513286211614A40
47162	30031	129.88555600000001	129.91095200000001	52.339984000000001	52.328808000000002	Новая	0103000020E61000000100000005000000DA588979563C6040E3546B61162A4A40DA588979563C6040E6948098842B4A403A07CF84263D6040E6948098842B4A403A07CF84263D6040E3546B61162A4A40DA588979563C6040E3546B61162A4A40
46783	8932	132.718897	132.735893	52.967730000000003	52.950305999999998	Центральная	0103000020E610000001000000050000002906483401976040A69883A0A3794A402906483401976040D6AD9E93DE7B4A405F0B7A6F8C976040D6AD9E93DE7B4A405F0B7A6F8C976040A69883A0A3794A402906483401976040A69883A0A3794A40
46727	30025	131.02300299999999	131.033514	51.764330999999999	51.753120000000003	Центральная	0103000020E61000000100000005000000B796C970BC60604055FB743C66E04940B796C970BC606040D4282499D5E14940A9BEF38B12616040D4282499D5E14940A9BEF38B1261604055FB743C66E04940B796C970BC60604055FB743C66E04940
46743	29391	133.401679	133.412576	52.867897999999997	52.859281000000003	Ленина	0103000020E61000000100000005000000AE0FEB8DDAAC60407F8978EBFC6D4A40AE0FEB8DDAAC6040C4211B48176F4A40AA6395D233AD6040C4211B48176F4A40AA6395D233AD60407F8978EBFC6D4A40AE0FEB8DDAAC60407F8978EBFC6D4A40
46908	55761	126.892792	128.69869299999999	51.947696999999998	50.887262999999997	ФРУНЗЕ	0103000020E6100000010000000500000059880E8123B95F40B5F97FD59171494059880E8123B95F4037C2A2224EF94940361E6CB15B16604037C2A2224EF94940361E6CB15B166040B5F97FD59171494059880E8123B95F40B5F97FD591714940
47169	27042	128.15301199999999	128.16554300000001	51.478667999999999	51.467426000000003	Сосновый бор	0103000020E61000000100000005000000A8FC6B79E50460406AA67B9DD4BB4940A8FC6B79E504604024D236FE44BD49409E62D5204C05604024D236FE44BD49409E62D5204C0560406AA67B9DD4BB4940A8FC6B79E50460406AA67B9DD4BB4940
46725	27175	128.13774900000001	128.15629000000001	51.662444999999998	51.628923999999998	Распоповой	0103000020E61000000100000005000000D141977068046040B2D5E59480D04940D14197706804604009336DFFCAD4494024D6E2530005604009336DFFCAD4494024D6E25300056040B2D5E59480D04940D141977068046040B2D5E59480D04940
46799	27175	128.13774900000001	128.15629000000001	51.662444999999998	51.628923999999998	Новая	0103000020E61000000100000005000000D141977068046040B2D5E59480D04940D14197706804604009336DFFCAD4494024D6E2530005604009336DFFCAD4494024D6E25300056040B2D5E59480D04940D141977068046040B2D5E59480D04940
47131	26337	128.243481	128.27321499999999	51.473652999999999	51.457746	Октябрьская	0103000020E610000001000000050000005186AA98CA076040FAEFC16B97BA49405186AA98CA0760407E5358A9A0BC4940DA38622DBE0860407E5358A9A0BC4940DA38622DBE086040FAEFC16B97BA49405186AA98CA076040FAEFC16B97BA4940
46801	26950	128.12938600000001	128.15946199999999	51.459204999999997	51.437072000000001	Южная	0103000020E61000000100000005000000EED11BEE23046040A8FFACF9F1B74940EED11BEE230460407094BC3AC7BA49408D5E0D501A0560407094BC3AC7BA49408D5E0D501A056040A8FFACF9F1B74940EED11BEE23046040A8FFACF9F1B74940
46510	55714	128.104682	128.13192799999999	51.771163999999999	51.752473000000002	Маршала Неделина	0103000020E610000001000000050000005BCF108E59036040BF0F070951E049405BCF108E5903604020ED7F80B5E24940A7AD11C13804604020ED7F80B5E24940A7AD11C138046040BF0F070951E049405BCF108E59036040BF0F070951E04940
46862	28121	127.23677499999999	127.27759399999999	51.545347999999997	51.535674	Калинина	0103000020E61000000100000005000000AA60545227CF5F40A4A833F790C44940AA60545227CF5F40317898F6CDC5494036E49F19C4D15F40317898F6CDC5494036E49F19C4D15F40A4A833F790C44940AA60545227CF5F40A4A833F790C44940
47178	27680	127.44549000000001	127.48046100000001	51.156104999999997	51.140025000000001	Школьная	0103000020E610000001000000050000007C2C7DE882DC5F40ABCFD556EC9149407C2C7DE882DC5F40FCDEA63FFB93494039807EDFBFDE5F40FCDEA63FFB93494039807EDFBFDE5F40ABCFD556EC9149407C2C7DE882DC5F40ABCFD556EC914940
47001	27958	127.839742	127.86632299999999	51.529791000000003	51.521324	Центральная	0103000020E61000000100000005000000F8C43A55BEF55F40594FADBEBAC24940F8C43A55BEF55F408A5B0531D0C34940723106D671F75F408A5B0531D0C34940723106D671F75F40594FADBEBAC24940F8C43A55BEF55F40594FADBEBAC24940
46803	27547	127.77220699999999	127.78850199999999	51.371536999999996	51.353197999999999	Центральная	0103000020E6100000010000000500000081AFE8D66BF15F409D81919735AD494081AFE8D66BF15F40812040868EAF494028B517D176F25F40812040868EAF494028B517D176F25F409D81919735AD494081AFE8D66BF15F409D81919735AD4940
47038	27916	127.74678400000001	127.76610700000001	51.540346	51.526710000000001	Дзержинского	0103000020E61000000100000005000000454B1E4FCBEF5F40F33CB83B6BC34940454B1E4FCBEF5F402043C70E2AC54940268FA7E507F15F402043C70E2AC54940268FA7E507F15F40F33CB83B6BC34940454B1E4FCBEF5F40F33CB83B6BC34940
47134	27449	127.82227899999999	127.847872	51.281323	51.259419999999999	Центральная	0103000020E61000000100000005000000014C1938A0F45F40D3F6AFAC34A14940014C1938A0F45F406A4E5E6402A449406CCCEB8843F65F406A4E5E6402A449406CCCEB8843F65F40D3F6AFAC34A14940014C1938A0F45F40D3F6AFAC34A14940
47059	7438	128.13526999999999	128.14664300000001	51.697738999999999	51.688070000000003	Сосновая	0103000020E610000001000000050000002844C02154046040EBAD81AD12D849402844C021540460406612F5824FD94940FF25A94CB10460406612F5824FD94940FF25A94CB1046040EBAD81AD12D849402844C02154046040EBAD81AD12D84940
46724	26617	128.09120799999999	128.104467	51.321722000000001	51.303401999999998	Центральная	0103000020E6100000010000000500000046240A2DEB0260403FC571E0D5A6494046240A2DEB026040AD33BE2F2EA949405C902DCB57036040AD33BE2F2EA949405C902DCB570360403FC571E0D5A6494046240A2DEB0260403FC571E0D5A64940
46834	27878	126.917523	126.933854	51.116804000000002	51.100088	Центральная	0103000020E61000000100000005000000FB9463B2B8BA5F406C5CFFAECF8C4940FB9463B2B8BA5F406005F86EF38E4940484F9143C4BB5F406005F86EF38E4940484F9143C4BB5F406C5CFFAECF8C4940FB9463B2B8BA5F406C5CFFAECF8C4940
47159	28085	127.267309	127.293504	51.409855999999998	51.395494999999997	Центральная	0103000020E610000001000000050000004B3B35971BD15F40A25D85949FB249404B3B35971BD15F40E108522976B44940B14F00C5C8D25F40E108522976B44940B14F00C5C8D25F40A25D85949FB249404B3B35971BD15F40A25D85949FB24940
46833	27123	128.27897300000001	128.29478399999999	51.671740999999997	51.664808000000001	Центральная	0103000020E61000000100000005000000F2EEC858ED086040410FB56D18D54940F2EEC858ED086040F030ED9BFBD549404AECDADE6E096040F030ED9BFBD549404AECDADE6E096040410FB56D18D54940F2EEC858ED086040410FB56D18D54940
46831	26532	128.622624	128.64568399999999	51.621510000000001	51.614179	Старожилов	0103000020E610000001000000050000008DB62A89EC136040EB71DF6A9DCE49408DB62A89EC1360408811C2A38DCF49409DF17D71A91460408811C2A38DCF49409DF17D71A9146040EB71DF6A9DCE49408DB62A89EC136040EB71DF6A9DCE4940
47126	27395	127.971435	127.999948	51.406866999999998	51.393594999999998	Нижняя	0103000020E6100000010000000500000025CCB4FD2BFE5F403F6F2A5261B2494025CCB4FD2BFE5F402B69C53714B44940D76CE525FFFF5F402B69C53714B44940D76CE525FFFF5F403F6F2A5261B2494025CCB4FD2BFE5F403F6F2A5261B24940
46632	26584	128.10137599999999	128.116603	51.239654000000002	51.226439999999997	Центральная	0103000020E610000001000000050000002D93E1783E036040CC4065FCFB9C49402D93E1783E036040842D76FBAC9E4940B2F33636BB036040842D76FBAC9E4940B2F33636BB036040CC4065FCFB9C49402D93E1783E036040CC4065FCFB9C4940
46648	27082	128.17069900000001	128.22464299999999	51.633766000000001	51.616097000000003	Ленина	0103000020E61000000100000005000000B8CEBF5D76056040F5143944DCCE4940B8CEBF5D760560408BA8893E1FD14940CF488446300760408BA8893E1FD14940CF48844630076040F5143944DCCE4940B8CEBF5D76056040F5143944DCCE4940
46832	26851	127.958967	127.986051	51.151229999999998	51.137346000000001	Гагарина	0103000020E610000001000000050000005EBC1FB75FFD5F40431EC18D949149405EBC1FB75FFD5F40481630815B9349400A4CA7751BFF5F40481630815B9349400A4CA7751BFF5F40431EC18D949149405EBC1FB75FFD5F40431EC18D94914940
47004	28002	127.694422	127.710537	51.581237999999999	51.568593	Лазо	0103000020E61000000100000005000000DEE7F86871EC5F4005DEC9A7C7C84940DEE7F86871EC5F40A298BC0166CA494045662E7079ED5F40A298BC0166CA494045662E7079ED5F4005DEC9A7C7C84940DEE7F86871EC5F4005DEC9A7C7C84940
46882	27636	127.679644	127.688924	51.273936999999997	51.266661999999997	Зеленая	0103000020E610000001000000050000000C3B8C497FEB5F40008BFCFA21A249400C3B8C497FEB5F4009151C5E10A349407D5BB05417EC5F4009151C5E10A349407D5BB05417EC5F40008BFCFA21A249400C3B8C497FEB5F40008BFCFA21A24940
47153	26736	128.06219200000001	128.08336499999999	51.239004999999999	51.217301999999997	Советская	0103000020E6100000010000000500000055C2137AFD0160407DAD4B8DD09B494055C2137AFD0160404D4A41B7979E4940319413EDAA0260404D4A41B7979E4940319413EDAA0260407DAD4B8DD09B494055C2137AFD0160407DAD4B8DD09B4940
47135	27494	127.668092	127.690406	51.327046000000003	51.309235999999999	Лермонтова	0103000020E6100000010000000500000008AEF204C2EA5F40785F950B95A7494008AEF204C2EA5F40D124B1A4DCA9494094BDA59C2FEC5F40D124B1A4DCA9494094BDA59C2FEC5F40785F950B95A7494008AEF204C2EA5F40785F950B95A74940
46687	28036	127.585887	127.62238600000001	51.482908999999999	51.448306000000002	Косова	0103000020E61000000100000005000000B309302C7FE55F40E04C4C1762B94940B309302C7FE55F40D7F84CF6CFBD494040DF162CD5E75F40D7F84CF6CFBD494040DF162CD5E75F40E04C4C1762B94940B309302C7FE55F40E04C4C1762B94940
47216	55774	127.948241	127.96547	51.112082999999998	51.104663000000002	60 лет Октября	0103000020E610000001000000050000007CEE04FBAFFC5F40F60CE198658D49407CEE04FBAFFC5F4002B859BC588E494039D1AE42CAFD5F4002B859BC588E494039D1AE42CAFD5F40F60CE198658D49407CEE04FBAFFC5F40F60CE198658D4940
46804	27596	127.615675	127.65468	51.352545999999997	51.345728000000001	Ждановская	0103000020E61000000100000005000000BF7D1D3867E75F40DFA7AAD040AC4940BF7D1D3867E75F40F52A323A20AD49401956F146E6E95F40F52A323A20AD49401956F146E6E95F40DFA7AAD040AC4940BF7D1D3867E75F40DFA7AAD040AC4940
47011	27775	127.23808699999999	127.259907	51.151439000000003	51.127612999999997	Советская	0103000020E6100000010000000500000093A641D13CCF5F40B0C56E9F5590494093A641D13CCF5F40632B685A629349401840F850A2D05F40632B685A629349401840F850A2D05F40B0C56E9F5590494093A641D13CCF5F40B0C56E9F55904940
46830	26480	128.49311399999999	128.502825	51.552869999999999	51.542144999999998	Центральная	0103000020E6100000010000000500000064E60297C70F60404F58E20165C5494064E60297C70F60404278B471C4C649408F537424171060404278B471C4C649408F537424171060404F58E20165C5494064E60297C70F60404F58E20165C54940
47037	26398	128.430196	128.463874	51.536200999999998	51.520758000000001	Молодежная	0103000020E61000000100000005000000D7DB662AC40D6040B090B932A8C24940D7DB662AC40D60408F8AFF3BA2C44940DF6E490ED80E60408F8AFF3BA2C44940DF6E490ED80E6040B090B932A8C24940D7DB662AC40D6040B090B932A8C24940
46630	26998	128.12488500000001	128.14664300000001	51.505147999999998	51.485202999999998	Трудовая	0103000020E610000001000000050000005AD8D30EFF036040E675C4211BBE49405AD8D30EFF036040E5D18DB0A8C04940FF25A94CB1046040E5D18DB0A8C04940FF25A94CB1046040E675C4211BBE49405AD8D30EFF036040E675C4211BBE4940
47156	27734	127.287997	127.301912	51.015757999999998	51.001793999999997	Школьная	0103000020E610000001000000050000002716F88A6ED25F401DAA29C93A8049402716F88A6ED25F403F53AF5B048249404791B58652D35F403F53AF5B048249404791B58652D35F401DAA29C93A8049402716F88A6ED25F401DAA29C93A804940
47125	27346	127.95752899999999	127.976816	51.792197999999999	51.775511000000002	Кирова	0103000020E610000001000000050000002EFEB62748FD5F401958C7F143E349402EFEB62748FD5F4072FA7ABE66E54940698D412784FE5F4072FA7ABE66E54940698D412784FE5F401958C7F143E349402EFEB62748FD5F401958C7F143E34940
47127	27301	128.06098800000001	128.07509200000001	51.752350999999997	51.738638000000002	Клубная	0103000020E610000001000000050000005A2E1B9DF30160409BCAA2B08BDE49405A2E1B9DF3016040730E9E094DE049401F86562767026040730E9E094DE049401F865627670260409BCAA2B08BDE49405A2E1B9DF30160409BCAA2B08BDE4940
46723	26434	128.35595900000001	128.38727399999999	51.515653	51.501537999999996	Центральная	0103000020E61000000100000005000000F1F62004640B6040C2D9AD6532C04940F1F62004640B6040CA8AE1EA00C24940EA92718C640C6040CA8AE1EA00C24940EA92718C640C6040C2D9AD6532C04940F1F62004640B6040C2D9AD6532C04940
47068	8841	126.90214400000001	126.92611100000001	51.229768	51.208967999999999	Центральная	0103000020E61000000100000005000000171230BABCB95F408CF4A276BF9A4940171230BABCB95F406BD5AE09699D4940D15D126745BB5F406BD5AE09699D4940D15D126745BB5F408CF4A276BF9A4940171230BABCB95F408CF4A276BF9A4940
47132	26681	128.128128	128.14148599999999	51.289231999999998	51.274206999999997	Набережная	0103000020E610000001000000050000007636E49F19046040C9AA083719A349407636E49F19046040747ADE8D05A54940F0DAA50D87046040747ADE8D05A54940F0DAA50D87046040C9AA083719A349407636E49F19046040C9AA083719A34940
47116	25363	129.46617800000001	129.47484700000001	50.862107000000002	50.853935999999997	Трудовая	0103000020E61000000100000005000000AC0320EEEA2E604043705CC64D6D4940AC0320EEEA2E60408B53AD85596E494052F355F2312F60408B53AD85596E494052F355F2312F604043705CC64D6D4940AC0320EEEA2E604043705CC64D6D4940
47026	55763	129.135445	129.17348000000001	50.638666999999998	50.623184000000002	Школьная	0103000020E6100000010000000500000004ADC09055246040FBB1497EC44F494004ADC0905524604068041BD7BF51494053D0ED258D25604068041BD7BF51494053D0ED258D256040FBB1497EC44F494004ADC09055246040FBB1497EC44F4940
46462	25789	129.277074	129.313267	50.738007000000003	50.705931	Школьная	0103000020E610000001000000050000004D124BCADD286040C51D6FF25B5A49404D124BCADD2860400B9C6C03775E494050FD8348062A60400B9C6C03775E494050FD8348062A6040C51D6FF25B5A49404D124BCADD286040C51D6FF25B5A4940
46404	25789	129.277074	129.313267	50.738007000000003	50.705931	Гагарина	0103000020E610000001000000050000004D124BCADD286040C51D6FF25B5A49404D124BCADD2860400B9C6C03775E494050FD8348062A60400B9C6C03775E494050FD8348062A6040C51D6FF25B5A49404D124BCADD286040C51D6FF25B5A4940
47123	26250	128.62108799999999	128.66542899999999	50.516731999999998	50.503632000000003	Советская	0103000020E6100000010000000500000004FEF0F3DF1360400B9C6C037740494004FEF0F3DF136040F965304624424940EB19C2314B156040F965304624424940EB19C2314B1560400B9C6C037740494004FEF0F3DF1360400B9C6C0377404940
46656	9034	128.86490900000001	128.903806	50.600023	50.578417000000002	Мелиоративная	0103000020E6100000010000000500000084A0A355AD1B6040A8397991094A494084A0A355AD1B604085ECBC8DCD4C4940B77D8FFAEB1C604085ECBC8DCD4C4940B77D8FFAEB1C6040A8397991094A494084A0A355AD1B6040A8397991094A4940
46622	9034	128.86490900000001	128.903806	50.600023	50.578417000000002	Дзержинского	0103000020E6100000010000000500000084A0A355AD1B6040A8397991094A494084A0A355AD1B604085ECBC8DCD4C4940B77D8FFAEB1C604085ECBC8DCD4C4940B77D8FFAEB1C6040A8397991094A494084A0A355AD1B6040A8397991094A4940
46714	25624	129.11136099999999	129.12386599999999	50.920383999999999	50.911309000000003	Рабочая	0103000020E6100000010000000500000098A1F1449023604076C6F7C5A574494098A1F144902360407EE19524CF754940C362D4B5F62360407EE19524CF754940C362D4B5F623604076C6F7C5A574494098A1F1449023604076C6F7C5A5744940
47057	26042	128.83680899999999	128.859869	50.622304	50.612782000000003	Центральная	0103000020E61000000100000005000000F3FFAA23C71A6040EBC9FCA36F4E4940F3FFAA23C71A6040C21550A8A74F4940043BFE0B841B6040C21550A8A74F4940043BFE0B841B6040EBC9FCA36F4E4940F3FFAA23C71A6040EBC9FCA36F4E4940
46796	25567	129.5318	129.53821400000001	50.750678000000001	50.738081000000001	Трудовая	0103000020E6100000010000000500000069006F810431604045662E70795E494069006F8104316040D1E9793716604940FB07910C39316040D1E9793716604940FB07910C3931604045662E70795E494069006F810431604045662E70795E4940
47028	25855	129.192398	129.230433	50.630051999999999	50.613633999999998	Советская	0103000020E610000001000000050000001BBAD91F2826604059DB148F8B4E49401BBAD91F28266040C3633F8BA55049406ADD06B55F276040C3633F8BA55049406ADD06B55F27604059DB148F8B4E49401BBAD91F2826604059DB148F8B4E4940
47060	8975	129.19948600000001	129.23281399999999	50.802663000000003	50.782541000000002	70 Лет Октября	0103000020E6100000010000000500000051C0763062266040BB63B14D2A64494051C0763062266040C95A43A9BD664940A181583673276040C95A43A9BD664940A181583673276040BB63B14D2A64494051C0763062266040BB63B14D2A644940
46718	25736	129.36892599999999	129.394924	50.686618000000003	50.672817000000002	Зеленая	0103000020E610000001000000050000009C14E63DCE2B6040AF9811DE1E5649409C14E63DCE2B6040276C3F19E3574940FA0CA837A32C6040276C3F19E3574940FA0CA837A32C6040AF9811DE1E5649409C14E63DCE2B6040AF9811DE1E564940
47117	25965	129.01685900000001	129.09277499999999	50.627885999999997	50.616297000000003	Центральная	0103000020E6100000010000000500000096B4E21B8A206040BCCFF1D1E24E494096B4E21B8A206040E1CE85915E5049405DDC4603F8226040E1CE85915E5049405DDC4603F8226040BCCFF1D1E24E494096B4E21B8A206040BCCFF1D1E24E4940
47154	26162	128.862672	128.89531700000001	50.524715999999998	50.509779000000002	Садовая	0103000020E6100000010000000500000099654F029B1B6040039832704041494099654F029B1B60400ED8D5E429434940B151D66FA61C60400ED8D5E429434940B151D66FA61C6040039832704041494099654F029B1B60400398327040414940
46805	26198	128.77402599999999	128.806231	50.528472000000001	50.510638	Восточная	0103000020E610000001000000050000001E882CD2C4186040240C03965C4149401E882CD2C4186040056D72F8A4434940AF40F4A4CC196040056D72F8A4434940AF40F4A4CC196040240C03965C4149401E882CD2C4186040240C03965C414940
47035	26280	128.68107699999999	128.71100000000001	50.611626999999999	50.602612000000001	Набережная	0103000020E61000000100000005000000D921FE61CB156040AD16D863224D4940D921FE61CB156040E02C25CB494E4940986E1283C0166040E02C25CB494E4940986E1283C0166040AD16D863224D4940D921FE61CB156040AD16D863224D4940
46736	26001	128.90306000000001	128.94572099999999	50.612651	50.606014000000002	Зеленая	0103000020E610000001000000050000006DCA15DEE51C60408675E3DD914D49406DCA15DEE51C60404C6E14596B4E49407EC4AF58431E60404C6E14596B4E49407EC4AF58431E60408675E3DD914D49406DCA15DEE51C60408675E3DD914D4940
46795	25470	129.41712100000001	129.42921200000001	50.795358999999998	50.775803000000003	Советская	0103000020E6100000010000000500000032AF230E592D6040C19140834D63494032AF230E592D604025CADE52CE654940A0E1CD1ABC2D604025CADE52CE654940A0E1CD1ABC2D6040C19140834D63494032AF230E592D6040C19140834D634940
47025	25526	129.581423	129.60691700000001	50.690942999999997	50.681731999999997	Советская	0103000020E610000001000000050000008D4468049B3260407E5182FE425749408D4468049B3260403733FAD1705849405E4C33DD6B3360403733FAD1705849405E4C33DD6B3360407E5182FE425749408D4468049B3260407E5182FE42574940
46794	24240	128.99391600000001	129.010795	50.305705000000003	50.297269999999997	Ветеранов	0103000020E61000000100000005000000145FED28CE1F60407C0A80F10C264940145FED28CE1F6040A29C685721274940BB7EC16E58206040A29C685721274940BB7EC16E582060407C0A80F10C264940145FED28CE1F60407C0A80F10C264940
47073	49182	128.78050300000001	128.790762	50.295917000000003	50.291383000000003	Северная	0103000020E61000000100000005000000C26D6DE1F918604021CEC3094C254940C26D6DE1F91860404CAAB69BE02549406D1D1CEC4D1960404CAAB69BE02549406D1D1CEC4D19604021CEC3094C254940C26D6DE1F918604021CEC3094C254940
47223	55776	128.832156	128.84577400000001	50.090488999999998	50.077975000000002	Центральная	0103000020E6100000010000000500000072A59E05A11A6040EB73B515FB09494072A59E05A11A6040E9D2BF24950B4940D4B9A294101B6040E9D2BF24950B4940D4B9A294101B6040EB73B515FB09494072A59E05A11A6040EB73B515FB094940
47165	55771	128.714495	128.744696	50.026097999999998	50.014423999999998	Веселая	0103000020E61000000100000005000000FA449E24DD166040852348A5D8014940FA449E24DD166040D93EE42D57034940C9AEB48CD4176040D93EE42D57034940C9AEB48CD4176040852348A5D8014940FA449E24DD166040852348A5D8014940
46916	47107	129.19891999999999	129.22078500000001	50.554771000000002	50.518816999999999	Школьная	0103000020E61000000100000005000000A6D0798D5D266040EECD6F9868424940A6D0798D5D26604076E272BC02474940514EB4AB1027604076E272BC02474940514EB4AB10276040EECD6F9868424940A6D0798D5D266040EECD6F9868424940
46986	24124	129.172528	129.19376399999999	50.233457999999999	50.216346999999999	Лесная	0103000020E610000001000000050000009EB47059852560403ACB2C42B11B49409EB4705985256040AA7EA5F3E11D49408C648F5033266040AA7EA5F3E11D49408C648F50332660403ACB2C42B11B49409EB47059852560403ACB2C42B11B4940
46900	23959	129.282544	129.31456	50.364075	50.335979999999999	Центральная	0103000020E61000000100000005000000CBF5B6990A296040170E8464012B4940CBF5B6990A296040462575029A2E4940271422E0102A6040462575029A2E4940271422E0102A6040170E8464012B4940CBF5B6990A296040170E8464012B4940
47308	55787	129.169419	129.19264100000001	50.422913999999999	50.413294	Молодежная	0103000020E61000000100000005000000460A65E16B25604007D15AD1E6344940460A65E16B256040A182C30B22364940CD5B751D2A266040A182C30B22364940CD5B751D2A26604007D15AD1E6344940460A65E16B25604007D15AD1E6344940
46720	23893	128.631688	128.65329199999999	50.434379	50.425168999999997	Советская	0103000020E61000000100000005000000D2A8C0C936146040F22213F06B364940D2A8C0C936146040DB8827BB99374940A1D79FC4E7146040DB8827BB99374940A1D79FC4E7146040F22213F06B364940D2A8C0C936146040F22213F06B364940
46703	23460	128.62765400000001	128.662204	50.167130999999998	50.156385999999998	Центральная	0103000020E610000001000000050000008466D7BD15146040B0C6D974041449408466D7BD15146040EA92718C64154940F96871C630156040EA92718C64154940F96871C630156040B0C6D974041449408466D7BD15146040B0C6D97404144940
46586	23748	128.64442600000001	128.71749500000001	50.339343	50.31897	Чкалова	0103000020E61000000100000005000000265646239F146040DB334B02D4284940265646239F146040329067976F2B4940650113B8F5166040329067976F2B4940650113B8F5166040DB334B02D4284940265646239F146040DB334B02D4284940
46839	23836	128.776748	128.81229400000001	50.424101999999998	50.405171000000003	Первая	0103000020E6100000010000000500000078279F1EDB186040D124B1A4DC33494078279F1EDB18604087156EF9483649409697FC4FFE19604087156EF9483649409697FC4FFE196040D124B1A4DC33494078279F1EDB186040D124B1A4DC334940
46797	24221	128.879865	128.897041	50.252336	50.237768000000003	Молодежная	0103000020E61000000100000005000000A4FCA4DA271C604086048C2E6F1E4940A4FCA4DA271C60403ECDC98B4C2049407AC5538FB41C60403ECDC98B4C2049407AC5538FB41C604086048C2E6F1E4940A4FCA4DA271C604086048C2E6F1E4940
46793	24110	129.23791600000001	129.26585399999999	50.242187000000001	50.221787999999997	Рабочая	0103000020E610000001000000050000003FE603029D2760409752978C631C49403FE603029D2760401842CEFBFF1E494058703FE0812860401842CEFBFF1E494058703FE0812860409752978C631C49403FE603029D2760409752978C631C4940
46666	23427	128.475785	128.521537	50.174332	50.156184000000003	Мухина	0103000020E61000000100000005000000ADDD76A1390F604049145AD6FD134940ADDD76A1390F6040B952CF8250164940EDD45C6EB0106040B952CF8250164940EDD45C6EB010604049145AD6FD134940ADDD76A1390F604049145AD6FD134940
46717	55743	128.974952	128.99063699999999	50.405493	50.397430999999997	Нагорная	0103000020E610000001000000050000006F6589CE321F604052B5DD04DF3249406F6589CE321F6040E3E0D231E7334940A4A65D4CB31F6040E3E0D231E7334940A4A65D4CB31F604052B5DD04DF3249406F6589CE321F604052B5DD04DF324940
46690	55738	128.668429	128.69633999999999	50.264062000000003	50.249687000000002	Центральная	0103000020E6100000010000000500000056D636C563156040419E5DBEF51F494056D636C563156040E50E9BC8CC214940B1DCD26A48166040E50E9BC8CC214940B1DCD26A48166040419E5DBEF51F494056D636C563156040419E5DBEF51F4940
46800	23989	129.443433	129.45977300000001	50.320712	50.307937000000003	Новая	0103000020E61000000100000005000000F31E679A302E60403B1DC87A6A274940F31E679A302E6040A6B73F170D294940AFD2DD75B62E6040A6B73F170D294940AFD2DD75B62E60403B1DC87A6A274940F31E679A302E60403B1DC87A6A274940
46706	23621	128.79315099999999	128.817127	50.170442999999999	50.153933000000002	Ленина	0103000020E6100000010000000500000045B9347E6119604039639813B413494045B9347E61196040836A8313D1154940B7B585E7251A6040836A8313D1154940B7B585E7251A604039639813B413494045B9347E6119604039639813B4134940
46843	20443	129.00885500000001	129.03383700000001	50.485346999999997	50.467415000000003	Линейная	0103000020E61000000100000005000000FFEC478A4820604076543541D43B4940FFEC478A48206040191BBAD91F3E4940A20C553115216040191BBAD91F3E4940A20C55311521604076543541D43B4940FFEC478A4820604076543541D43B4940
46702	23595	128.538443	128.55976899999999	49.983955000000002	49.966000999999999	Центральная	0103000020E610000001000000050000005378D0EC3A1160409F73B7EBA5FB48405378D0EC3A1160402BDEC83CF2FD4840118AADA0E91160402BDEC83CF2FD4840118AADA0E91160409F73B7EBA5FB48405378D0EC3A1160409F73B7EBA5FB4840
47033	24419	129.071135	129.13511299999999	50.387163000000001	50.352789000000001	микрорайон Таёжный	0103000020E610000001000000050000003B53E8BC46226040BCB1A030282D49403B53E8BC46226040529CA38E8E31494076887FD852246040529CA38E8E31494076887FD852246040BCB1A030282D49403B53E8BC46226040BCB1A030282D4940
46587	24419	129.071135	129.13511299999999	50.387163000000001	50.352789000000001	Южная	0103000020E610000001000000050000003B53E8BC46226040BCB1A030282D49403B53E8BC46226040529CA38E8E31494076887FD852246040529CA38E8E31494076887FD852246040BCB1A030282D49403B53E8BC46226040BCB1A030282D4940
46721	24419	129.071135	129.13511299999999	50.387163000000001	50.352789000000001	Пролетарская	0103000020E610000001000000050000003B53E8BC46226040BCB1A030282D49403B53E8BC46226040529CA38E8E31494076887FD852246040529CA38E8E31494076887FD852246040BCB1A030282D49403B53E8BC46226040BCB1A030282D4940
46527	24419	129.071135	129.13511299999999	50.387163000000001	50.352789000000001	Ленина	0103000020E610000001000000050000003B53E8BC46226040BCB1A030282D49403B53E8BC46226040529CA38E8E31494076887FD852246040529CA38E8E31494076887FD852246040BCB1A030282D49403B53E8BC46226040BCB1A030282D4940
46614	24419	129.071135	129.13511299999999	50.387163000000001	50.352789000000001	Куйбышевская	0103000020E610000001000000050000003B53E8BC46226040BCB1A030282D49403B53E8BC46226040529CA38E8E31494076887FD852246040529CA38E8E31494076887FD852246040BCB1A030282D49403B53E8BC46226040BCB1A030282D4940
46403	24419	129.071135	129.13511299999999	50.387163000000001	50.352789000000001	Коммунальная	0103000020E610000001000000050000003B53E8BC46226040BCB1A030282D49403B53E8BC46226040529CA38E8E31494076887FD852246040529CA38E8E31494076887FD852246040BCB1A030282D49403B53E8BC46226040BCB1A030282D4940
46746	45454	129.08193299999999	129.10205500000001	50.531421000000002	50.516961999999999	Георгиевская	0103000020E61000000100000005000000D26EF4319F2260402BA391CF2B424940D26EF4319F2260402DB4739A0544494096ECD808442360402DB4739A0544494096ECD808442360402BA391CF2B424940D26EF4319F2260402BA391CF2B424940
46525	55715	129.08632499999999	129.142236	50.364162	50.328505	Юбилейная	0103000020E61000000100000005000000787AA52CC322604047C9AB730C2A4940787AA52CC3226040153944DC9C2E49400B0A83328D246040153944DC9C2E49400B0A83328D24604047C9AB730C2A4940787AA52CC322604047C9AB730C2A4940
46458	23808	128.54348200000001	128.584913	50.357174000000001	50.333742999999998	Молодежная	0103000020E61000000100000005000000DFFE5C34641160406C223317B82A4940DFFE5C3464116040A27DACE0B72D49402BC0779BB7126040A27DACE0B72D49402BC0779BB71260406C223317B82A4940DFFE5C34641160406C223317B82A4940
46791	23540	128.59515300000001	128.633026	50.046123000000001	50.026885	Молодежная	0103000020E61000000100000005000000B9E34D7E0B13604061E0B9F770034940B9E34D7E0B136040F54BC45BE705494091F0BDBF41146040F54BC45BE705494091F0BDBF4114604061E0B9F770034940B9E34D7E0B13604061E0B9F770034940
47087	8194	129.02741399999999	129.044194	50.095793999999998	50.074778000000002	Центральная	0103000020E610000001000000050000007B2E5393E0206040EB3A5453920949407B2E5393E0206040969350FA420C4940BE1589096A216040969350FA420C4940BE1589096A216040EB3A5453920949407B2E5393E0206040EB3A545392094940
47118	55767	128.84857700000001	128.980378	49.871754000000003	49.786495000000002	Железнодорожная	0103000020E6100000010000000500000069E4F38A271B6040D8BB3FDEABE4484069E4F38A271B60401F1494A295EF4840F9F6AE415F1F60401F1494A295EF4840F9F6AE415F1F6040D8BB3FDEABE4484069E4F38A271B6040D8BB3FDEABE44840
47121	55769	128.498369	128.51492500000001	49.920011000000002	49.903171	Центральная	0103000020E61000000100000005000000E38A8BA3F20F60400AD9791B9BF34840E38A8BA3F20F6040EA7AA2EBC2F54840925CFE437A106040EA7AA2EBC2F54840925CFE437A1060400AD9791B9BF34840E38A8BA3F20F60400AD9791B9BF34840
46899	22690	128.836037	128.848299	49.783318999999999	49.773674999999997	Центральная	0103000020E61000000100000005000000DFA7AAD0C01A6040CC5D4BC807E34840DFA7AAD0C01A6040EFAA07CC43E4484058C7F143251B6040EFAA07CC43E4484058C7F143251B6040CC5D4BC807E34840DFA7AAD0C01A6040CC5D4BC807E34840
47012	22471	129.04185000000001	129.05358200000001	49.900821000000001	49.889789999999998	Рабочая	0103000020E61000000100000005000000CEAACFD556216040672783A3E4F14840CEAACFD55621604067463F1A4EF34840F03499F1B621604067463F1A4EF34840F03499F1B6216040672783A3E4F14840CEAACFD556216040672783A3E4F14840
47111	23291	128.826604	128.83971099999999	49.588585000000002	49.580443000000002	Центральная	0103000020E61000000100000005000000C5573B8A731A60409818CBF44BCA4840C5573B8A731A604045F5D6C056CB4840ED629AE9DE1A604045F5D6C056CB4840ED629AE9DE1A60409818CBF44BCA4840C5573B8A731A60409818CBF44BCA4840
46642	23239	128.80553900000001	128.82430500000001	49.571722000000001	49.545448999999998	Ленина	0103000020E61000000100000005000000E294B9F9C61960406551D845D1C54840E294B9F9C6196040AD33BE2F2EC94840BD1DE1B4601A6040AD33BE2F2EC94840BD1DE1B4601A60406551D845D1C54840E294B9F9C61960406551D845D1C54840
47015	22955	128.64069799999999	128.655844	49.745969000000002	49.731558999999997	Садовая	0103000020E610000001000000050000009A93179980146040170CAEB9A3DD48409A93179980146040386A85E97BDF4840E4688EACFC146040386A85E97BDF4840E4688EACFC146040170CAEB9A3DD48409A93179980146040170CAEB9A3DD4840
46829	22707	128.86380399999999	128.87548200000001	49.672835999999997	49.667898000000001	Полевая	0103000020E61000000100000005000000ED444948A41B60402B8881AE7DD54840ED444948A41B604025C9737D1FD6484093C7D3F2031C604025C9737D1FD6484093C7D3F2031C60402B8881AE7DD54840ED444948A41B60402B8881AE7DD54840
46627	8362	128.61974000000001	128.69544999999999	49.638457000000002	49.612791999999999	Советская	0103000020E61000000100000005000000BD00FBE8D41360400EA0DFF76FCE4840BD00FBE8D41360407E737FF5B8D148401AC05B20411660407E737FF5B8D148401AC05B20411660400EA0DFF76FCE4840BD00FBE8D41360400EA0DFF76FCE4840
46439	8362	128.61974000000001	128.69544999999999	49.638457000000002	49.612791999999999	Садовая	0103000020E61000000100000005000000BD00FBE8D41360400EA0DFF76FCE4840BD00FBE8D41360407E737FF5B8D148401AC05B20411660407E737FF5B8D148401AC05B20411660400EA0DFF76FCE4840BD00FBE8D41360400EA0DFF76FCE4840
46677	8362	128.61974000000001	128.69544999999999	49.638457000000002	49.612791999999999	Пионерская	0103000020E61000000100000005000000BD00FBE8D41360400EA0DFF76FCE4840BD00FBE8D41360407E737FF5B8D148401AC05B20411660407E737FF5B8D148401AC05B20411660400EA0DFF76FCE4840BD00FBE8D41360400EA0DFF76FCE4840
46400	8362	128.61974000000001	128.69544999999999	49.638457000000002	49.612791999999999	Ленина	0103000020E61000000100000005000000BD00FBE8D41360400EA0DFF76FCE4840BD00FBE8D41360407E737FF5B8D148401AC05B20411660407E737FF5B8D148401AC05B20411660400EA0DFF76FCE4840BD00FBE8D41360400EA0DFF76FCE4840
46503	8362	128.61974000000001	128.69544999999999	49.638457000000002	49.612791999999999	Кольцевая	0103000020E61000000100000005000000BD00FBE8D41360400EA0DFF76FCE4840BD00FBE8D41360407E737FF5B8D148401AC05B20411660407E737FF5B8D148401AC05B20411660400EA0DFF76FCE4840BD00FBE8D41360400EA0DFF76FCE4840
46585	8362	128.61974000000001	128.69544999999999	49.638457000000002	49.612791999999999	Гарнизонная	0103000020E61000000100000005000000BD00FBE8D41360400EA0DFF76FCE4840BD00FBE8D41360407E737FF5B8D148401AC05B20411660407E737FF5B8D148401AC05B20411660400EA0DFF76FCE4840BD00FBE8D41360400EA0DFF76FCE4840
46785	22279	128.879839	128.907174	49.984540000000003	49.971870000000003	Центральная	0103000020E61000000100000005000000DA571EA4271C604055FB743C66FC4840DA571EA4271C60404BCD1E6805FE484002B9C491071D60404BCD1E6805FE484002B9C491071D604055FB743C66FC4840DA571EA4271C604055FB743C66FC4840
46665	23176	129.001138	129.018574	49.576161999999997	49.555736000000003	Совхозная	0103000020E610000001000000050000000D198F5209206040DD9A745B22C748400D198F5209206040569929ADBFC94840CA51802898206040569929ADBFC94840CA51802898206040DD9A745B22C748400D198F5209206040DD9A745B22C74840
47120	55768	128.53089700000001	128.547121	49.920203000000001	49.906396999999998	Октябрьская	0103000020E610000001000000050000006D91B41BFD106040A41820D104F448406D91B41BFD1060402E573F36C9F548408E3EE603821160402E573F36C9F548408E3EE60382116040A41820D104F448406D91B41BFD106040A41820D104F44840
47110	22798	128.69228799999999	128.706616	49.838766	49.824598999999999	Центральная	0103000020E6100000010000000500000039ED2939271660403BA8C4758CE9484039ED293927166040957F2DAF5CEB4840925A28999C166040957F2DAF5CEB4840925A28999C1660403BA8C4758CE9484039ED2939271660403BA8C4758CE94840
46628	22223	128.82512199999999	128.86054300000001	49.931244999999997	49.901674	Михайловских партизан	0103000020E61000000100000005000000B9A64066671A6040A6D3BA0D6AF34840B9A64066671A604021C8410933F74840A8397991891B604021C8410933F74840A8397991891B6040A6D3BA0D6AF34840B9A64066671A6040A6D3BA0D6AF34840
47184	23096	128.998299	129.021377	49.470649000000002	49.461252000000002	Набережная	0103000020E610000001000000050000002594BE10F21F6040789B374E0ABB48402594BE10F21F60409372F7393EBC48405F7CD11EAF2060409372F7393EBC48405F7CD11EAF206040789B374E0ABB48402594BE10F21F6040789B374E0ABB4840
46700	22928	128.729083	128.752475	49.847358	49.833483999999999	Партизанская	0103000020E610000001000000050000003A22DFA554176040A0DE8C9AAFEA48403A22DFA5541760408200193A76EC4840D8817346141860408200193A76EC4840D881734614186040A0DE8C9AAFEA48403A22DFA554176040A0DE8C9AAFEA4840
46788	22813	128.58626000000001	128.60921200000001	49.726818999999999	49.710039000000002	Центральная	0103000020E610000001000000050000007FDE54A4C212604039F1D58EE2DA48407FDE54A4C2126040438EAD6708DD4840960A2AAA7E136040438EAD6708DD4840960A2AAA7E13604039F1D58EE2DA48407FDE54A4C212604039F1D58EE2DA4840
47024	23342	128.754524	128.784976	49.607590999999999	49.597070000000002	Центральная	0103000020E610000001000000050000008201840F251860401CB62DCA6CCC48408201840F25186040062CB98AC5CD4840A304FD851E196040062CB98AC5CD4840A304FD851E1960401CB62DCA6CCC48408201840F251860401CB62DCA6CCC4840
46787	22747	128.629873	128.65484599999999	49.783603999999997	49.760711000000001	Специалистов	0103000020E6100000010000000500000045F46BEB271460408E5A61FA5EE1484045F46BEB27146040E481C8224DE44840533D997FF4146040E481C8224DE44840533D997FF41460408E5A61FA5EE1484045F46BEB271460408E5A61FA5EE14840
46704	23083	129.27551	129.29203899999999	49.398342999999997	49.380000000000003	Шадрина	0103000020E6100000010000000500000012F758FAD0286040713D0AD7A3B0484012F758FAD028604096CB46E7FCB2484002452C625829604096CB46E7FCB2484002452C6258296040713D0AD7A3B0484012F758FAD0286040713D0AD7A3B04840
47107	22546	128.95759699999999	128.97026299999999	49.751108000000002	49.731583000000001	Дорожная	0103000020E61000000100000005000000EDB776A2A41E6040A0A70183A4DD4840EDB776A2A41E6040CAE1934E24E048409AB0FD640C1F6040CAE1934E24E048409AB0FD640C1F6040A0A70183A4DD4840EDB776A2A41E6040A0A70183A4DD4840
46617	55730	128.62313599999999	128.64165	49.692863000000003	49.677126000000001	Центральная	0103000020E61000000100000005000000BA9EE8BAF0136040BAA29410ACD64840BA9EE8BAF0136040E2CD1ABCAFD848404FAF946588146040E2CD1ABCAFD848404FAF946588146040BAA29410ACD64840BA9EE8BAF0136040BAA29410ACD64840
47023	22650	128.762878	128.79405800000001	49.720185999999998	49.707931000000002	Советская	0103000020E61000000100000005000000D09A1F7F691860408C69A67B9DDA4840D09A1F7F69186040BE840A0E2FDC484012A452EC68196040BE840A0E2FDC484012A452EC681960408C69A67B9DDA4840D09A1F7F691860408C69A67B9DDA4840
46641	23372	128.42487800000001	128.444299	49.663232999999998	49.641508000000002	Центральная	0103000020E610000001000000050000004759BF99980D6040AA0F24EF1CD248404759BF99980D60406150A6D1E4D44840A85489B2370E60406150A6D1E4D44840A85489B2370E6040AA0F24EF1CD248404759BF99980D6040AA0F24EF1CD24840
47114	46528	128.965349	128.98979199999999	49.845528000000002	49.821193999999998	Школьная	0103000020E610000001000000050000003E079623E41E6040F1D58EE21CE948403E079623E41E604018EDF1423AEC4840F5BA4560AC1F604018EDF1423AEC4840F5BA4560AC1F6040F1D58EE21CE948403E079623E41E6040F1D58EE21CE94840
46740	46528	128.965349	128.98979199999999	49.845528000000002	49.821193999999998	Центральная	0103000020E610000001000000050000003E079623E41E6040F1D58EE21CE948403E079623E41E604018EDF1423AEC4840F5BA4560AC1F604018EDF1423AEC4840F5BA4560AC1F6040F1D58EE21CE948403E079623E41E6040F1D58EE21CE94840
46790	23008	129.28719799999999	129.30240599999999	49.546162000000002	49.529798999999997	Шадрина	0103000020E61000000100000005000000402FDCB9302960400C3A2174D0C34840402FDCB930296040B328ECA2E8C54840A703594FAD296040B328ECA2E8C54840A703594FAD2960400C3A2174D0C34840402FDCB9302960400C3A2174D0C34840
46828	22317	128.850967	128.88900100000001	49.991050000000001	49.967803000000004	переулок Школьный	0103000020E61000000100000005000000355F251F3B1B604040FCFCF7E0FB4840355F251F3B1B6040B459F5B9DAFE484090A339B2721C6040B459F5B9DAFE484090A339B2721C604040FCFCF7E0FB4840355F251F3B1B604040FCFCF7E0FB4840
46971	20946	128.84014199999999	128.847948	51.549391999999997	51.538581999999998	Центральная	0103000020E61000000100000005000000DFBF7971E21A60406D1B4641F0C44940DFBF7971E21A60408E57207A52C64940AD16D863221B60408E57207A52C64940AD16D863221B60406D1B4641F0C44940DFBF7971E21A60406D1B4641F0C44940
46848	21145	128.79438200000001	128.80688599999999	51.495241	51.486128000000001	Озерная	0103000020E61000000100000005000000FFD0CC936B196040BFD53A7139BE4940FFD0CC936B196040B5519D0E64BF494035B39602D2196040B5519D0E64BF494035B39602D2196040BFD53A7139BE4940FFD0CC936B196040BFD53A7139BE4940
46844	20615	129.568218	129.596622	51.943959999999997	51.929862999999997	Центральная	0103000020E61000000100000005000000F4DF83D72E326040566133C005F74940F4DF83D72E326040B75D68AED3F849405F42058717336040B75D68AED3F849405F42058717336040566133C005F74940F4DF83D72E326040566133C005F74940
46747	20555	129.35295400000001	129.374729	51.956471999999998	51.929729000000002	Центральная	0103000020E61000000100000005000000C2DF2F664B2B60404792205C01F74940C2DF2F664B2B604015C5ABAC6DFA49409CFBABC7FD2B604015C5ABAC6DFA49409CFBABC7FD2B60404792205C01F74940C2DF2F664B2B60404792205C01F74940
46767	20305	129.066104	129.09088	51.772730000000003	51.755299999999998	Советская	0103000020E6100000010000000500000050C422861D2260409B559FABADE0494050C422861D226040AD510FD1E8E24940897B2C7DE8226040AD510FD1E8E24940897B2C7DE82260409B559FABADE0494050C422861D2260409B559FABADE04940
46765	21511	128.84338500000001	128.85335599999999	51.687299000000003	51.671869000000001	Зейская	0103000020E61000000100000005000000FC1D8A02FD1A60401E19ABCDFFD54940FC1D8A02FD1A604069C9E369F9D749400DFB3DB14E1B604069C9E369F9D749400DFB3DB14E1B60401E19ABCDFFD54940FC1D8A02FD1A60401E19ABCDFFD54940
46771	21225	128.84766099999999	128.87638000000001	51.418416999999998	51.404046999999998	30 лет Победы	0103000020E610000001000000050000000723F609201B60400186E5CFB7B349400723F609201B6040938B31B08EB54940CBDB114E0B1C6040938B31B08EB54940CBDB114E0B1C60400186E5CFB7B349400723F609201B60400186E5CFB7B34940
46846	21033	129.048147	129.06243000000001	51.537702000000003	51.528182999999999	Цветочная	0103000020E61000000100000005000000D1CC936B8A216040CEA623809BC34940D1CC936B8A216040357F4C6BD3C449404209336DFF216040357F4C6BD3C449404209336DFF216040CEA623809BC34940D1CC936B8A216040CEA623809BC34940
46845	20988	129.018835	129.042991	51.553083000000001	51.543438000000002	Амурская	0103000020E61000000100000005000000A5A0DB4B9A206040ABB35A608FC54940A5A0DB4B9A2060409E7C7A6CCBC64940B760A92E602160409E7C7A6CCBC64940B760A92E60216040ABB35A608FC54940A5A0DB4B9A206040ABB35A608FC54940
46693	20254	129.044634	129.068602	51.762262999999997	51.750695	Джалова	0103000020E61000000100000005000000454948A46D216040A72215C616E04940454948A46D216040B5F97FD591E14940164ED2FC31226040B5F97FD591E14940164ED2FC31226040A72215C616E04940454948A46D216040A72215C616E04940
47105	21455	128.70756	128.74127300000001	51.651465999999999	51.630265999999999	Советская	0103000020E61000000100000005000000A67EDE54A4166040EFE3688EACD04940A67EDE54A41660405C3AE63C63D349400D8D2782B81760405C3AE63C63D349400D8D2782B8176040EFE3688EACD04940A67EDE54A4166040EFE3688EACD04940
46770	21797	128.34360699999999	128.366083	51.400215000000003	51.378352	Центральная	0103000020E61000000100000005000000A7751BD4FE0A604027309DD66DB04940A7751BD4FE0A6040302FC03E3AB34940E413B2F3B60B6040302FC03E3AB34940E413B2F3B60B604027309DD66DB04940A7751BD4FE0A604027309DD66DB04940
46741	20202	128.94765200000001	128.963067	51.717820000000003	51.711503	Центральная	0103000020E61000000100000005000000A67F492A531E6040C100C28712DB4940A67F492A531E604016359886E1DB49406B9BE271D11E604016359886E1DB49406B9BE271D11E6040C100C28712DB4940A67F492A531E6040C100C28712DB4940
46994	21540	128.58292700000001	128.598872	51.493653999999999	51.484793000000003	Центральная	0103000020E61000000100000005000000931E8656A7126040352A70B20DBE4940931E8656A712604011C5E40D30BF4940AFCF9CF52913604011C5E40D30BF4940AFCF9CF529136040352A70B20DBE4940931E8656A7126040352A70B20DBE4940
46880	21353	129.080738	129.099063	51.333326999999997	51.321412000000002	Минская	0103000020E610000001000000050000006CB1DB67952260405F45460724A949406CB1DB6795226040D8EF8975AAAA4940CC272B862B236040D8EF8975AAAA4940CC272B862B2360405F45460724A949406CB1DB67952260405F45460724A94940
46750	20668	129.45674600000001	129.47190900000001	52.156061999999999	52.141533000000003	Набережная	0103000020E610000001000000050000008692C9A99D2E60400327DBC01D124A408692C9A99D2E6040FD12F1D6F9134A400536E7E0192F6040FD12F1D6F9134A400536E7E0192F60400327DBC01D124A408692C9A99D2E60400327DBC01D124A40
46650	20022	128.89639399999999	128.93175199999999	51.672629000000001	51.643161999999997	пер. Амурский	0103000020E61000000100000005000000944A7842AF1C6040D503E62153D24940944A7842AF1C6040ACAB02B518D6494071FF91E9D01D6040ACAB02B518D6494071FF91E9D01D6040D503E62153D24940944A7842AF1C6040D503E62153D24940
46399	20022	128.89639399999999	128.93175199999999	51.672629000000001	51.643161999999997	Школьная	0103000020E61000000100000005000000944A7842AF1C6040D503E62153D24940944A7842AF1C6040ACAB02B518D6494071FF91E9D01D6040ACAB02B518D6494071FF91E9D01D6040D503E62153D24940944A7842AF1C6040D503E62153D24940
46502	20022	128.89639399999999	128.93175199999999	51.672629000000001	51.643161999999997	Луговая	0103000020E61000000100000005000000944A7842AF1C6040D503E62153D24940944A7842AF1C6040ACAB02B518D6494071FF91E9D01D6040ACAB02B518D6494071FF91E9D01D6040D503E62153D24940944A7842AF1C6040D503E62153D24940
46639	19950	128.907408	128.92475400000001	51.680950000000003	51.670791000000001	Колхозная	0103000020E610000001000000050000001F84807C091D6040BFB9BF7ADCD549401F84807C091D6040091B9E5E29D749400C5BB395971D6040091B9E5E29D749400C5BB395971D6040BFB9BF7ADCD549401F84807C091D6040BFB9BF7ADCD54940
47016	21844	128.31883199999999	128.36819399999999	51.378464000000001	51.361409999999999	Олимпийская	0103000020E61000000100000005000000629D2ADF330A60404339D1AE42AE4940629D2ADF330A60404F5B238271B04940AB92C83EC80B60404F5B238271B04940AB92C83EC80B60404339D1AE42AE4940629D2ADF330A60404339D1AE42AE4940
46997	21633	128.65700200000001	128.67790600000001	51.455945	51.447687999999999	Центральная	0103000020E6100000010000000500000003ED0E2906156040E46723D74DB9494003ED0E29061560402AE3DF675CBA49406478EC67B11560402AE3DF675CBA49406478EC67B1156040E46723D74DB9494003ED0E2906156040E46723D74DB94940
46992	21421	129.202226	129.22307599999999	51.341845999999997	51.325161000000001	Новая	0103000020E61000000100000005000000D40CA9A278266040A3772AE09EA94940D40CA9A2782660405B22179CC1AB4940B8904770232760405B22179CC1AB4940B890477023276040A3772AE09EA94940D40CA9A278266040A3772AE09EA94940
46752	20733	129.56875700000001	129.592544	52.292661000000003	52.279991000000003	переулок Лесной	0103000020E61000000100000005000000E04BE141333260405116BEBED6234A40E04BE1413332604047E867EA75254A401DAED51EF632604047E867EA75254A401DAED51EF63260405116BEBED6234A40E04BE141333260405116BEBED6234A40
46584	20822	128.80604199999999	128.842963	51.634168000000003	51.622981000000003	Ленина	0103000020E610000001000000050000007AA69718CB196040C38366D7BDCF49407AA69718CB196040BA15C26A2CD149409E978A8DF91A6040BA15C26A2CD149409E978A8DF91A6040C38366D7BDCF49407AA69718CB196040C38366D7BDCF4940
46583	21739	128.386259	128.45155800000001	51.467055000000002	51.440688000000002	Школьная	0103000020E610000001000000050000002499D53B5C0C6040ADDEE17668B849402499D53B5C0C604076374F75C8BB4940E947C329730E604076374F75C8BB4940E947C329730E6040ADDEE17668B849402499D53B5C0C6040ADDEE17668B84940
46768	20386	129.19	129.20701399999999	51.835638000000003	51.821840000000002	Центральная	0103000020E61000000100000005000000AE47E17A14266040B745990D32E94940AE47E17A14266040BEA59C2FF6EA49400DFAD2DB9F266040BEA59C2FF6EA49400DFAD2DB9F266040B745990D32E94940AE47E17A14266040B745990D32E94940
47101	20768	129.53496200000001	129.56045599999999	52.290253999999997	52.276122999999998	Больничная	0103000020E610000001000000050000004AD3A0681E31604032569BFF57234A404AD3A0681E3160403FC4060B27254A401ADB6B41EF3160403FC4060B27254A401ADB6B41EF31604032569BFF57234A404AD3A0681E31604032569BFF57234A40
46847	21084	129.001183	129.00792000000001	51.492415000000001	51.487031000000002	Орловой	0103000020E61000000100000005000000F549EEB009206040B091240857BE4940F549EEB009206040A987687407BF4940809F71E140206040A987687407BF4940809F71E140206040B091240857BE4940F549EEB009206040B091240857BE4940
46849	21313	128.92356000000001	128.93868699999999	51.350425000000001	51.337114	переулок Школьный	0103000020E610000001000000050000009A7CB3CD8D1D60400A83328D26AB49409A7CB3CD8D1D6040B459F5B9DAAC4940C5C551B9091E6040B459F5B9DAAC4940C5C551B9091E60400A83328D26AB49409A7CB3CD8D1D60400A83328D26AB4940
47058	20504	129.22150400000001	129.24926199999999	51.871847000000002	51.860035000000003	Молодежная	0103000020E61000000100000005000000DD7D8E8F162760402B357BA015EE4940DD7D8E8F16276040D00EB8AE98EF494056444DF4F9276040D00EB8AE98EF494056444DF4F92760402B357BA015EE4940DD7D8E8F162760402B357BA015EE4940
46989	21265	128.839585	128.86388400000001	51.388356999999999	51.375202999999999	Школьная	0103000020E61000000100000005000000CAA65CE1DD1A6040382EE3A606B04940CAA65CE1DD1A60401A16A3AEB5B1494035F10EF0A41B60401A16A3AEB5B1494035F10EF0A41B6040382EE3A606B04940CAA65CE1DD1A6040382EE3A606B04940
46640	20868	128.754784	128.79406700000001	51.602488999999998	51.583359000000002	пер.Школьный	0103000020E610000001000000050000006971C63027186040E469F981ABCA49406971C6302718604091990B5C1ECD4940A77A32FF6819604091990B5C1ECD4940A77A32FF68196040E469F981ABCA49406971C63027186040E469F981ABCA4940
47103	21596	128.565428	128.57465400000001	51.479162000000002	51.473221000000002	Центральная	0103000020E61000000100000005000000C40776FC17126040E563778192BC4940C40776FC1712604034BE2F2E55BD49408010C9906312604034BE2F2E55BD49408010C99063126040E563778192BC4940C40776FC17126040E563778192BC4940
46754	21174	128.775544	128.78722200000001	51.438684000000002	51.43139	Лесная	0103000020E610000001000000050000007D93A641D118604025E99AC937B749407D93A641D1186040A5A31CCC26B84940231631EC30196040A5A31CCC26B84940231631EC3019604025E99AC937B749407D93A641D118604025E99AC937B74940
46637	19196	125.986751	126.014482	52.804380000000002	52.777358999999997	Мухинская	0103000020E61000000100000005000000E692AAED267F5F402920ED7F80634A40E692AAED267F5F403BC780ECF5664A405D18E945ED805F403BC780ECF5664A405D18E945ED805F402920ED7F80634A40E692AAED267F5F402920ED7F80634A40
46739	19630	126.42698900000001	126.44257399999999	52.957667999999998	52.942768999999998	Советская	0103000020E610000001000000050000001DB0ABC9539B5F40605793A7AC784A401DB0ABC9539B5F407E3672DD947A4A40D503E621539C5F407E3672DD947A4A40D503E621539C5F40605793A7AC784A401DB0ABC9539B5F40605793A7AC784A40
46478	19465	126.517224	126.556669	52.797134	52.768363999999998	Комсомольская	0103000020E61000000100000005000000342DB1321AA15F403DB665C059624A40342DB1321AA15F40CC43A67C08664A409C6C0377A0A35F40CC43A67C08664A409C6C0377A0A35F403DB665C059624A40342DB1321AA15F403DB665C059624A40
46457	19713	126.30533	126.34843100000001	53.125965000000001	53.096159999999998	Советская	0103000020E61000000100000005000000361FD7868A935F4078978BF84E8C4A40361FD7868A935F4067B8019F1F904A40687A89B14C965F4067B8019F1F904A40687A89B14C965F4078978BF84E8C4A40361FD7868A935F4078978BF84E8C4A40
46874	19284	125.42144999999999	125.46216200000001	53.140152999999998	53.129964000000001	Погрничная	0103000020E610000001000000050000008CB96B09F95A5F4024D40CA9A2904A408CB96B09F95A5F40D8B79388F0914A400EDDEC0F945D5F40D8B79388F0914A400EDDEC0F945D5F4024D40CA9A2904A408CB96B09F95A5F4024D40CA9A2904A40
46571	19362	126.729523	126.77889500000001	52.647165999999999	52.621451	Вокзальная	0103000020E6100000010000000500000082AB3C81B0AE5F408388D4B48B4F4A4082AB3C81B0AE5F40A48AE255D6524A4026016A6AD9B15F40A48AE255D6524A4026016A6AD9B15F408388D4B48B4F4A4082AB3C81B0AE5F408388D4B48B4F4A40
46455	55708	125.785169	125.835313	53.470981999999999	53.434648000000003	К.Маркса	0103000020E6100000010000000500000050357A3540725F40CBA2B08BA2B74A4050357A3540725F4099805F2349BC4A401D3BA8C475755F4099805F2349BC4A401D3BA8C475755F40CBA2B08BA2B74A4050357A3540725F40CBA2B08BA2B74A40
46569	18969	125.785169	125.835313	53.470981999999999	53.434648000000003	Комсомольская	0103000020E6100000010000000500000050357A3540725F40CBA2B08BA2B74A4050357A3540725F4099805F2349BC4A401D3BA8C475755F4099805F2349BC4A401D3BA8C475755F40CBA2B08BA2B74A4050357A3540725F40CBA2B08BA2B74A40
46570	18969	125.785169	125.835313	53.470981999999999	53.434648000000003	К.Маркса	0103000020E6100000010000000500000050357A3540725F40CBA2B08BA2B74A4050357A3540725F4099805F2349BC4A401D3BA8C475755F4099805F2349BC4A401D3BA8C475755F40CBA2B08BA2B74A4050357A3540725F40CBA2B08BA2B74A40
46749	19232	126.15107999999999	126.175676	52.567951000000001	52.560544	Амурская	0103000020E6100000010000000500000019C5724BAB895F4009FCE1E7BF474A4019C5724BAB895F40815D4D9EB2484A404BAC8C463E8B5F40815D4D9EB2484A404BAC8C463E8B5F4009FCE1E7BF474A4019C5724BAB895F4009FCE1E7BF474A40
46612	19793	126.161519	126.18574599999999	53.344704	53.329535999999997	Проезжая	0103000020E61000000100000005000000B0ABC953568A5F40656D533C2EAA4A40B0ABC953568A5F407366BB421FAC4A4038D73043E38B5F407366BB421FAC4A4038D73043E38B5F40656D533C2EAA4A40B0ABC953568A5F40656D533C2EAA4A40
47099	19900	125.22629999999999	125.249109	53.691949000000001	53.680666000000002	Школьная	0103000020E610000001000000050000006DC5FEB27B4E5F40E4BF401020D74A406DC5FEB27B4E5F40FDBFEAC891D84A40EA08E066F14F5F40FDBFEAC891D84A40EA08E066F14F5F40E4BF401020D74A406DC5FEB27B4E5F40E4BF401020D74A40
46649	19856	125.36606	125.387665	53.590640999999998	53.573621000000003	Кооперативная	0103000020E61000000100000005000000EC17EC866D575F4040A6B5696CC94A40EC17EC866D575F409F56D11F9ACB4A407233DC80CF585F409F56D11F9ACB4A407233DC80CF585F4040A6B5696CC94A40EC17EC866D575F4040A6B5696CC94A40
46920	23569	128.183671	128.19893400000001	49.825512000000003	49.807772	Молодежная	0103000020E61000000100000005000000284701A2E0056040F04FA91265E74840284701A2E0056040503A9160AAE948400002D6AA5D066040503A9160AAE948400002D6AA5D066040F04FA91265E74840284701A2E0056040F04FA91265E74840
46701	8734	127.765011	127.79761999999999	49.750461999999999	49.736001999999999	 Ленина	0103000020E610000001000000050000002385B2F0F5F05F4032E5435035DE48402385B2F0F5F05F40047289230FE04840ACA8C1340CF35F40047289230FE04840ACA8C1340CF35F4032E5435035DE48402385B2F0F5F05F4032E5435035DE4840
46745	45855	127.864383	127.875055	49.693026000000003	49.680267999999998	Центральная	0103000020E61000000100000005000000FA0D130D52F75F40F641960513D74840FA0D130D52F75F408CA37213B5D84840E2CCAFE600F85F408CA37213B5D84840E2CCAFE600F85F40F641960513D74840FA0D130D52F75F40F641960513D74840
46715	55742	128.06676400000001	128.089743	49.822930999999997	49.800573999999997	Советская	0103000020E610000001000000050000009B9141EE220260409203763579E648409B9141EE22026040AAEE91CD55E948407041B62CDF026040AAEE91CD55E948407041B62CDF0260409203763579E648409B9141EE220260409203763579E64840
46838	55756	128.256866	128.28351900000001	49.581991000000002	49.565652	Стрельцова	0103000020E610000001000000050000008AAE0B3F380860406075E44867C848408AAE0B3F380860407EC85BAE7ECA48406E197096120960407EC85BAE7ECA48406E197096120960406075E44867C848408AAE0B3F380860406075E44867C84840
46541	5772	128.22655700000001	128.250182	49.727395999999999	49.699086000000001	Пионерская	0103000020E61000000100000005000000C23577F43F076040B58B69A67BD94840C23577F43F076040E09EE74F1BDD48408881AE7D01086040E09EE74F1BDD48408881AE7D01086040B58B69A67BD94840C23577F43F076040B58B69A67BD94840
46603	19589	127.95187	127.990183	49.786273999999999	49.762211999999998	Школьная	0103000020E61000000100000005000000C9022670EBFC5F40334FAE2990E14840C9022670EBFC5F40F9D85DA0A4E44840888384285FFF5F40F9D85DA0A4E44840888384285FFF5F40334FAE2990E14840C9022670EBFC5F40334FAE2990E14840
46453	45804	127.963548	128.02076199999999	49.633217000000002	49.59843	Ленина	0103000020E6100000010000000500000014083BC5AAFD5F40FF78AF5A99CC484014083BC5AAFD5F40B82231410DD14840FCDF1115AA006040B82231410DD14840FCDF1115AA006040FF78AF5A99CC484014083BC5AAFD5F40FF78AF5A99CC4840
47072	31788	127.826429	127.854457	49.721933	49.708758000000003	Ленина	0103000020E61000000100000005000000D3DD7536E4F45F40A2630795B8DA4840D3DD7536E4F45F409B73F04C68DC4840A6B5696CAFF65F409B73F04C68DC4840A6B5696CAFF65F40A2630795B8DA4840D3DD7536E4F45F40A2630795B8DA4840
46609	45674	128.060225	128.097092	49.739862000000002	49.723232000000003	Школьная	0103000020E61000000100000005000000DAACFA5CED016040D9B5BDDD92DC4840DAACFA5CED016040CEC64ACCB3DE48408196AE601B036040CEC64ACCB3DE48408196AE601B036040D9B5BDDD92DC4840DAACFA5CED016040D9B5BDDD92DC4840
46922	30128	128.365409	128.37820099999999	49.846694999999997	49.828201999999997	Школьная	0103000020E610000001000000050000004015376EB10B6040AB3DEC8502EA48404015376EB10B6040E657738060EC484010CAFB381A0C6040E657738060EC484010CAFB381A0C6040AB3DEC8502EA48404015376EB10B6040AB3DEC8502EA4840
46769	29340	128.36842799999999	128.38143500000001	49.921084	49.900286999999999	Советская	0103000020E61000000100000005000000C85D8429CA0B6040C901BB9A3CF34840C85D8429CA0B6040376F9C14E6F5484098512CB7340C6040376F9C14E6F5484098512CB7340C6040C901BB9A3CF34840C85D8429CA0B6040C901BB9A3CF34840
46858	47101	128.17670000000001	128.19181	49.618161999999998	49.607194	Центральная	0103000020E610000001000000050000008126C286A7056040E9297288B8CD48408126C286A7056040A2D0B2EE1FCF484077A1B94E23066040A2D0B2EE1FCF484077A1B94E23066040E9297288B8CD48408126C286A7056040E9297288B8CD4840
46604	18743	128.19017500000001	128.22336799999999	49.910190999999998	49.884253000000001	Советская	0103000020E610000001000000050000008AB0E1E915066040E831CA332FF148408AB0E1E915066040880E812381F4484022DFA5D425076040880E812381F4484022DFA5D425076040E831CA332FF148408AB0E1E915066040E831CA332FF14840
46792	29483	127.986221	128.00493299999999	49.862400000000001	49.847793000000003	Ленина	0103000020E610000001000000050000003868AF3E1EFF5F408D63247B84EC48403868AF3E1EFF5F4003098A1F63EE48407A3540692800604003098A1F63EE48407A354069280060408D63247B84EC48403868AF3E1EFF5F408D63247B84EC4840
46679	18706	127.78378600000001	127.806055	50.431595999999999	50.383792	Кирова	0103000020E610000001000000050000000344C18C29F25F40B43BA418203149400344C18C29F25F40CE8AA8893E374940BFF1B56796F35F40CE8AA8893E374940BFF1B56796F35F40B43BA418203149400344C18C29F25F40B43BA41820314940
47093	17590	128.05976699999999	128.08155099999999	50.292856	50.277828	Дрогошевского	0103000020E6100000010000000500000029CC7B9CE9016040E0F42EDE8F23494029CC7B9CE9016040FC372F4E7C25494098BED7109C026040FC372F4E7C25494098BED7109C026040E0F42EDE8F23494029CC7B9CE9016040E0F42EDE8F234940
46968	18340	127.927543	127.95178900000001	50.771628	50.751857000000001	Комсомольская	0103000020E610000001000000050000008FA850DD5CFB5F406422A5D93C6049408FA850DD5CFB5F40C556D0B4C462494053EC681CEAFC5F40C556D0B4C462494053EC681CEAFC5F406422A5D93C6049408FA850DD5CFB5F406422A5D93C604940
46728	55744	127.659998	128.610793	50.812998999999998	50.205694000000001	Строителей	0103000020E610000001000000050000003A5B40683DEA5F40E17D552E541A49403A5B40683DEA5F402157EA591068494006F4C29D8B1360402157EA591068494006F4C29D8B136040E17D552E541A49403A5B40683DEA5F40E17D552E541A4940
46626	18264	128.02245099999999	128.075065	50.699798000000001	50.660656000000003	Молодежная	0103000020E6100000010000000500000066D828EBB7006040FEF334609054494066D828EBB700604032E719FB925949406002B7EE6602604032E719FB925949406002B7EE66026040FEF334609054494066D828EBB7006040FEF3346090544940
46470	18100	127.98185599999999	128.024193	50.669682000000002	50.646225000000001	Садовая	0103000020E6100000010000000500000068588CBAD6FE5F40C66D3480B752494068588CBAD6FE5F40255CC823B855494059F96530C6006040255CC823B855494059F96530C6006040C66D3480B752494068588CBAD6FE5F40C66D3480B7524940
46568	18100	127.98185599999999	128.024193	50.669682000000002	50.646225000000001	Амурская	0103000020E6100000010000000500000068588CBAD6FE5F40C66D3480B752494068588CBAD6FE5F40255CC823B855494059F96530C6006040255CC823B855494059F96530C6006040C66D3480B752494068588CBAD6FE5F40C66D3480B7524940
47100	18384	127.972944	127.996202	50.608083000000001	50.597593000000003	Зеленая	0103000020E61000000100000005000000B935E9B644FE5F40C6A86BED7D4C4940B935E9B644FE5F407520EBA9D54D49406D8D08C6C1FF5F407520EBA9D54D49406D8D08C6C1FF5F40C6A86BED7D4C4940B935E9B644FE5F40C6A86BED7D4C4940
46678	18429	127.809873	127.841081	50.655625000000001	50.634490999999997	Кирова	0103000020E61000000100000005000000753A90F5D4F35F409C4D470037514940753A90F5D4F35F4052B81E85EB5349405E126745D4F55F4052B81E85EB5349405E126745D4F55F409C4D470037514940753A90F5D4F35F409C4D470037514940
46841	17648	128.17728399999999	128.20134100000001	50.33222	50.320931000000002	Центральная	0103000020E6100000010000000500000054C37E4FAC056040E4A25A441429494054C37E4FAC056040DF89592F862A4940024BAE6271066040DF89592F862A4940024BAE6271066040E4A25A441429494054C37E4FAC056040E4A25A4414294940
46580	18578	127.79037099999999	127.809658	50.519665000000003	50.491553000000003	Кооперативный	0103000020E610000001000000050000003C2D3F7095F25F4017A06D35EB3E49403C2D3F7095F25F401CF0F9618442494077BCC96FD1F35F401CF0F9618442494077BCC96FD1F35F4017A06D35EB3E49403C2D3F7095F25F4017A06D35EB3E4940
46814	17975	128.20081999999999	128.230366	50.619782999999998	50.603549999999998	Школьная	0103000020E610000001000000050000003F8C101E6D0660401AC05B20414D49403F8C101E6D066040F2CEA10C554F4940888384285F076040F2CEA10C554F4940888384285F0760401AC05B20414D49403F8C101E6D0660401AC05B20414D4940
46686	18039	128.065507	128.10038800000001	50.565196999999998	50.546489000000001	Гвардейская	0103000020E6100000010000000500000017D522A218026040D74FFF59F345494017D522A2180260400E66136058484940261DE560360360400E66136058484940261DE56036036040D74FFF59F345494017D522A218026040D74FFF59F3454940
47097	17953	128.324195	128.361996	50.605397000000004	50.592405999999997	Центральная	0103000020E61000000100000005000000DB5031CE5F0A604022FAB5F5D34B4940DB5031CE5F0A60405B0C1EA67D4D49400DA9A278950B60405B0C1EA67D4D49400DA9A278950B604022FAB5F5D34B4940DB5031CE5F0A604022FAB5F5D34B4940
46977	17476	128.108473	128.13860299999999	50.428806999999999	50.423051000000001	Садовая	0103000020E61000000100000005000000F86F5E9C7803604022C5008926364940F86F5E9C78036040DFA5D425E336494014048F6F6F046040DFA5D425E336494014048F6F6F04604022C5008926364940F86F5E9C7803604022C5008926364940
47174	15350	127.950424	127.96713200000001	50.276895000000003	50.268408999999998	Центральная	0103000020E6100000010000000500000058552FBFD3FC5F40DD79E2395B22494058552FBFD3FC5F4085B69C4B7123494091BA9D7DE5FD5F4085B69C4B7123494091BA9D7DE5FD5F40DD79E2395B22494058552FBFD3FC5F40DD79E2395B224940
46673	17839	128.25980300000001	128.31797800000001	50.467823000000003	50.448112000000002	Ветеранов	0103000020E61000000100000005000000E38C614E50086040FB78E8BB5B394940E38C614E5008604087A8C29FE13B49401FDB32E02C0A604087A8C29FE13B49401FDB32E02C0A6040FB78E8BB5B394940E38C614E50086040FB78E8BB5B394940
46395	17342	127.96568600000001	128.023888	50.372923999999998	50.348846000000002	Пионерская	0103000020E61000000100000005000000200DA7CCCDFD5F4093AB58FCA62C4940200DA7CCCDFD5F405EF23FF9BB2F49408A58C4B0C30060405EF23FF9BB2F49408A58C4B0C300604093AB58FCA62C4940200DA7CCCDFD5F4093AB58FCA62C4940
46454	17342	127.96568600000001	128.023888	50.372923999999998	50.348846000000002	Партизанская	0103000020E61000000100000005000000200DA7CCCDFD5F4093AB58FCA62C4940200DA7CCCDFD5F405EF23FF9BB2F49408A58C4B0C30060405EF23FF9BB2F49408A58C4B0C300604093AB58FCA62C4940200DA7CCCDFD5F4093AB58FCA62C4940
46567	17342	127.96568600000001	128.023888	50.372923999999998	50.348846000000002	Галушкина	0103000020E61000000100000005000000200DA7CCCDFD5F4093AB58FCA62C4940200DA7CCCDFD5F405EF23FF9BB2F49408A58C4B0C30060405EF23FF9BB2F49408A58C4B0C300604093AB58FCA62C4940200DA7CCCDFD5F4093AB58FCA62C4940
46638	17891	128.386484	128.457999	50.485576000000002	50.460465999999997	Советская	0103000020E61000000100000005000000AC8DB1135E0C6040C075C58CF03A4940AC8DB1135E0C60407BDCB75A273E494039D384EDA70E60407BDCB75A273E494039D384EDA70E6040C075C58CF03A4940AC8DB1135E0C6040C075C58CF03A4940
46611	17534	127.914931	127.953649	50.415435000000002	50.400554999999997	Набережная	0103000020E610000001000000050000002EC6C03A8EFA5F40E89FE062453349402EC6C03A8EFA5F40904E5DF92C3549403DB7D09508FD5F40904E5DF92C3549403DB7D09508FD5F40E89FE062453349402EC6C03A8EFA5F40E89FE06245334940
47095	17742	128.142807	128.167969	50.392676999999999	50.388191999999997	Центральная	0103000020E610000001000000050000007A54FCDF91046040CF488446B03149407A54FCDF9104604019726C3D43324940BD3786006005604019726C3D43324940BD37860060056040CF488446B03149407A54FCDF91046040CF488446B0314940
46980	18665	127.804411	127.829474	50.455883999999998	50.439461999999999	Партизанская	0103000020E61000000100000005000000BB6246787BF35F40D9EA724A40384940BB6246787BF35F4084622B685A3A494078B81D1A16F55F4084622B685A3A494078B81D1A16F55F40D9EA724A40384940BB6246787BF35F40D9EA724A40384940
46501	18493	127.842141	127.89286	50.588735	50.553054000000003	Юбилейная	0103000020E61000000100000005000000BA675DA3E5F55F4004763579CA464940BA675DA3E5F55F405A8121AB5B4B494005FA449E24F95F405A8121AB5B4B494005FA449E24F95F4004763579CA464940BA675DA3E5F55F4004763579CA464940
46394	18493	127.842141	127.89286	50.588735	50.553054000000003	Ленина	0103000020E61000000100000005000000BA675DA3E5F55F4004763579CA464940BA675DA3E5F55F405A8121AB5B4B494005FA449E24F95F405A8121AB5B4B494005FA449E24F95F4004763579CA464940BA675DA3E5F55F4004763579CA464940
46842	17800	128.33061799999999	128.375542	50.388306	50.373112999999996	Молодежный	0103000020E61000000100000005000000012F336C940A6040315BB22AC22F4940012F336C940A6040986BD102B4314940C808A870040C6040986BD102B4314940C808A870040C6040315BB22AC22F4940012F336C940A6040315BB22AC22F4940
46817	17686	128.23034799999999	128.259929	50.293914999999998	50.281264	Центральная	0103000020E610000001000000050000005ED6C4025F07604065C57075002449405ED6C4025F076040E466B8019F25494006499F5651086040E466B8019F25494006499F565108604065C57075002449405ED6C4025F07604065C5707500244940
46983	15998	127.343118	127.370696	53.139175000000002	53.118043	Центральная	0103000020E61000000100000005000000D02A33A5F5D55F40C84274081C8F4A40D02A33A5F5D55F40DDB5847CD0914A408330B77BB9D75F40DDB5847CD0914A408330B77BB9D75F40C84274081C8F4A40D02A33A5F5D55F40C84274081C8F4A40
46962	15788	127.021871	127.056771	53.344194000000002	53.330354	 Амурская	0103000020E61000000100000005000000C66E9F5566C15F40280D350A49AA4A40C66E9F5566C15F405EBD8A8C0EAC4A401E17D522A2C35F405EBD8A8C0EAC4A401E17D522A2C35F40280D350A49AA4A40C66E9F5566C15F40280D350A49AA4A40
46969	16328	127.824929	127.84056	54.605673000000003	54.589852999999998	Первооткрывателей	0103000020E61000000100000005000000682101A3CBF45F404739984D804B4B40682101A3CBF45F40FD885FB1864D4B40D9942BBCCBF55F40FD885FB1864D4B40D9942BBCCBF55F404739984D804B4B40682101A3CBF45F404739984D804B4B40
46898	15886	127.116535	127.146297	53.273307000000003	53.258398999999997	Универсальная	0103000020E61000000100000005000000B875374F75C75F40D828EB3713A14A40B875374F75C75F404A6249B9FBA24A4030A017EE5CC95F404A6249B9FBA24A4030A017EE5CC95F40D828EB3713A14A40B875374F75C75F40D828EB3713A14A40
46652	55732	127.15942099999999	127.18461000000001	53.706662000000001	53.694146000000003	Новая	0103000020E61000000100000005000000EB5223F433CA5F401A53B0C6D9D84A40EB5223F433CA5F40B9A981E673DA4A40EF2076A6D0CB5F40B9A981E673DA4A40EF2076A6D0CB5F401A53B0C6D9D84A40EB5223F433CA5F401A53B0C6D9D84A40
46959	16237	127.94738700000001	127.97745399999999	54.203598	54.184277000000002	Ленина	0103000020E61000000100000005000000F56915FDA1FC5F40D733846396174B40F56915FDA1FC5F40F8C3CF7F0F1A4B400AD6389B8EFE5F40F8C3CF7F0F1A4B400AD6389B8EFE5F40D733846396174B40F56915FDA1FC5F40D733846396174B40
46981	15855	126.939019	126.96682199999999	53.304575999999997	53.294432	Трейберта	0103000020E61000000100000005000000A6D425E318BC5F40AC72A1F2AFA54A40A6D425E318BC5F40C092AB58FCA64A4069C36169E0BD5F40C092AB58FCA64A4069C36169E0BD5F40AC72A1F2AFA54A40A6D425E318BC5F40AC72A1F2AFA54A40
47193	15940	127.168054	127.17735999999999	53.243141000000001	53.228940000000001	Центральная	0103000020E61000000100000005000000917D9065C1CA5F40855FEAE74D9D4A40917D9065C1CA5F408BA8893E1F9F4A4096E7C1DD59CB5F408BA8893E1F9F4A4096E7C1DD59CB5F40855FEAE74D9D4A40917D9065C1CA5F40855FEAE74D9D4A40
46759	16042	127.527389	127.55241599999999	53.004192000000003	52.981301999999999	Рабочая	0103000020E610000001000000050000004AD1CABDC0E15F40ECBFCE4D9B7D4A404AD1CABDC0E15F40D2730B5D89804A406072A3C85AE35F40D2730B5D89804A406072A3C85AE35F40ECBFCE4D9B7D4A404AD1CABDC0E15F40ECBFCE4D9B7D4A40
46988	16124	128.61055999999999	128.67034200000001	53.057026	53.000480000000003	Чехова	0103000020E61000000100000005000000DD0720B589136040AB2688BA0F804A40DD0720B589136040C782C2A04C874A4054E4107173156040C782C2A04C874A4054E4107173156040AB2688BA0F804A40DD0720B589136040AB2688BA0F804A40
46623	16124	128.61055999999999	128.67034200000001	53.057026	53.000480000000003	Спортивная	0103000020E61000000100000005000000DD0720B589136040AB2688BA0F804A40DD0720B589136040C782C2A04C874A4054E4107173156040C782C2A04C874A4054E4107173156040AB2688BA0F804A40DD0720B589136040AB2688BA0F804A40
47182	16548	129.130325	129.152432	53.966943000000001	53.955086999999999	Первостроителей 	0103000020E610000001000000050000003D9B559F2B246040D9EA724A40FA4A403D9B559F2B2460404E0CC9C9C4FB4A40A5DB12B9E02460404E0CC9C9C4FB4A40A5DB12B9E0246040D9EA724A40FA4A403D9B559F2B246040D9EA724A40FA4A40
46366	15421	126.875967	126.92308300000001	53.596606000000001	53.551949999999998	переулок Светлый	0103000020E610000001000000050000000458E4D70FB85F407B832F4CA6C64A400458E4D70FB85F40774CDD955DCC4A40971FB8CA13BB5F40774CDD955DCC4A40971FB8CA13BB5F407B832F4CA6C64A400458E4D70FB85F407B832F4CA6C64A40
46364	15421	126.875967	126.92308300000001	53.596606000000001	53.551949999999998	Ленина	0103000020E610000001000000050000000458E4D70FB85F407B832F4CA6C64A400458E4D70FB85F40774CDD955DCC4A40971FB8CA13BB5F40774CDD955DCC4A40971FB8CA13BB5F407B832F4CA6C64A400458E4D70FB85F407B832F4CA6C64A40
46930	15601	127.02569800000001	127.038436	53.600116	53.592122000000003	Центральная	0103000020E61000000100000005000000A6643909A5C15F40FE9E58A7CACB4A40A6643909A5C15F4036E7E099D0CC4A404DBF44BC75C25F4036E7E099D0CC4A404DBF44BC75C25F40FE9E58A7CACB4A40A6643909A5C15F40FE9E58A7CACB4A40
46895	15507	126.719067	126.738264	53.641880999999998	53.619722000000003	Советская	0103000020E610000001000000050000008028983105AE5F404D4EED0C53CF4A408028983105AE5F403E76172829D24A401BF4A5B73FAF5F403E76172829D24A401BF4A5B73FAF5F404D4EED0C53CF4A408028983105AE5F404D4EED0C53CF4A40
46760	16080	126.62282999999999	126.636602	54.285057999999999	54.276074000000001	Школьная	0103000020E61000000100000005000000EE3D5C72DCA75F4051A3906456234B40EE3D5C72DCA75F4049BBD1C77C244B405DA45016BEA85F4049BBD1C77C244B405DA45016BEA85F4051A3906456234B40EE3D5C72DCA75F4051A3906456234B40
46599	55727	127.246405	127.294878	53.735619999999997	53.707839999999997	Школьная	0103000020E6100000010000000500000089247A19C5CF5F407B6649809ADA4A4089247A19C5CF5F404A24D1CB28DE4A40D593F947DFD25F404A24D1CB28DE4A40D593F947DFD25F407B6649809ADA4A4089247A19C5CF5F407B6649809ADA4A40
46651	16640	129.99468400000001	130.00990100000001	53.357985999999997	53.343795999999998	пл.Тухачевского	0103000020E61000000100000005000000583B8A73D43F6040703FE08101AC4A40583B8A73D43F60408236397CD2AD4A4054E6E61B514060408236397CD2AD4A4054E6E61B51406040703FE08101AC4A40583B8A73D43F6040703FE08101AC4A40
46685	16401	128.40733399999999	128.42901900000001	54.654885999999998	54.639878000000003	Советская	0103000020E61000000100000005000000901150E1080D604007B7B585E7514B40901150E1080D6040DB4DF04DD3534B409BCB0D86BA0D6040DB4DF04DD3534B409BCB0D86BA0D604007B7B585E7514B40901150E1080D604007B7B585E7514B40
46813	16429	128.837447	128.858261	54.714193000000002	54.703187	Федосеева	0103000020E6100000010000000500000044A4A65DCC1A604076FC1708025A4B4044A4A65DCC1A60401D041DAD6A5B4B40D5CDC5DF761B60401D041DAD6A5B4B40D5CDC5DF761B604076FC1708025A4B4044A4A65DCC1A604076FC1708025A4B40
47190	15698	126.959321	126.970613	53.471753999999997	53.455747000000002	Почтовая	0103000020E610000001000000050000006D57E88365BD5F400420EEEA55BA4A406D57E88365BD5F40EBE0606F62BC4A40A304FD851EBE5F40EBE0606F62BC4A40A304FD851EBE5F400420EEEA55BA4A406D57E88365BD5F400420EEEA55BA4A40
46465	16264	127.465504	127.499838	54.367750999999998	54.349099000000002	Ленина	0103000020E610000001000000050000000F0A4AD1CADD5F407D08AA46AF2C4B400F0A4AD1CADD5F402009FB76122F4B4013D38558FDDF5F402009FB76122F4B4013D38558FDDF5F407D08AA46AF2C4B400F0A4AD1CADD5F407D08AA46AF2C4B40
47180	15558	126.787339	126.798828	53.514550999999997	53.500884999999997	Юбилейная	0103000020E6100000010000000500000062F71DC363B25F404A07EBFF1CC04A4062F71DC363B25F40E28FA2CEDCC14A4043C879FF1FB35F40E28FA2CEDCC14A4043C879FF1FB35F404A07EBFF1CC04A4062F71DC363B25F404A07EBFF1CC04A40
47188	15641	126.946844	126.965852	53.598908999999999	53.591625000000001	Центральная	0103000020E610000001000000050000007C9A931799BC5F407D3F355EBACB4A407C9A931799BC5F40D923D40CA9CC4A40AD31E884D0BD5F40D923D40CA9CC4A40AD31E884D0BD5F407D3F355EBACB4A407C9A931799BC5F407D3F355EBACB4A40
47192	15743	126.975024	126.99523600000001	53.398536	53.383124000000002	пер. Сосновый 	0103000020E610000001000000050000002B3410CB66BE5F4007280D350AB14A402B3410CB66BE5F40AB23473A03B34A4052F355F2B1BF5F40AB23473A03B34A4052F355F2B1BF5F4007280D350AB14A402B3410CB66BE5F4007280D350AB14A40
46852	55760	129.439246	129.49319	50.153812000000002	50.129744000000002	Центральная	0103000020E61000000100000005000000C39CA04D0E2E6040166D8E739B104940C39CA04D0E2E6040BEDD921CB0134940DB166536C82F6040BEDD921CB0134940DB166536C82F6040166D8E739B104940C39CA04D0E2E6040166D8E739B104940
47080	14124	129.263958	129.28149300000001	49.924106000000002	49.914275000000004	Южная	0103000020E6100000010000000500000090300C5872286040744694F606F5484090300C5872286040C904FC1A49F64840B2A19BFD01296040C904FC1A49F64840B2A19BFD01296040744694F606F5484090300C5872286040744694F606F54840
47092	14459	129.24365599999999	129.255334	50.118389000000001	50.091656	Центральная	0103000020E610000001000000050000002CEFAA07CC276040B83D4162BB0B49402CEFAA07CC276040639AE95E270F4940D27135B22B286040639AE95E270F4940D27135B22B286040B83D4162BB0B49402CEFAA07CC276040B83D4162BB0B4940
46748	14232	129.42839499999999	129.44419600000001	50.047026000000002	50.034771999999997	Центральная	0103000020E61000000100000005000000A3586E69B52D60408368AD6873044940A3586E69B52D6040E607AEF20406494073A087DA362E6040E607AEF20406494073A087DA362E60408368AD6873044940A3586E69B52D60408368AD6873044940
47083	14172	129.18337	129.202451	49.894699000000003	49.883800000000001	Чкалова	0103000020E610000001000000050000002922C32ADE256040371AC05B20F148402922C32ADE256040C861307F85F248405C01857A7A266040C861307F85F248405C01857A7A266040371AC05B20F148402922C32ADE256040371AC05B20F14840
46812	55753	129.320336	129.35785899999999	50.211787999999999	50.206679999999999	Центральная	0103000020E6100000010000000500000068774831402A60405F5E807D741A494068774831402A6040B6D782DE1B1B494089B2B794732B6040B6D782DE1B1B494089B2B794732B60405F5E807D741A494068774831402A60405F5E807D741A4940
47141	13976	129.30951200000001	129.32432499999999	49.815671999999999	49.809981000000001	Свободная	0103000020E6100000010000000500000007B7B585E7296040D1B01875ADE7484007B7B585E7296040A721AAF067E84840CE88D2DE602A6040A721AAF067E84840CE88D2DE602A6040D1B01875ADE7484007B7B585E7296040D1B01875ADE74840
47079	8062	129.324828	129.34141099999999	49.965839000000003	49.951061000000003	Комсомольская	0103000020E61000000100000005000000679AB0FD642A604023C0E95DBCF94840679AB0FD642A6040C619C39CA0FB4840D4EFC2D6EC2A6040C619C39CA0FB4840D4EFC2D6EC2A604023C0E95DBCF94840679AB0FD642A604023C0E95DBCF94840
46957	8142	129.321774	129.34397999999999	50.097146000000002	50.089801000000001	Школьная	0103000020E6100000010000000500000080D6FCF84B2A6040F51263997E0B494080D6FCF84B2A6040F777B6476F0C49404C4F58E2012B6040F777B6476F0C49404C4F58E2012B6040F51263997E0B494080D6FCF84B2A6040F51263997E0B4940
46954	14320	129.169545	129.18717000000001	49.977170999999998	49.966023999999997	Центральная	0103000020E6100000010000000500000069C6A2E96C2560405793A7ACA6FB484069C6A2E96C256040C0CC77F013FD48405B99F04BFD256040C0CC77F013FD48405B99F04BFD2560405793A7ACA6FB484069C6A2E96C2560405793A7ACA6FB4840
46528	14592	129.41032100000001	129.468154	50.135038999999999	50.077067	Чкалова	0103000020E61000000100000005000000967B8159212D6040E84CDA54DD094940967B8159212D60409F573CF548114940BBEF181EFB2E60409F573CF548114940BBEF181EFB2E6040E84CDA54DD094940967B8159212D6040E84CDA54DD094940
46363	14592	129.41032100000001	129.468154	50.135038999999999	50.077067	Линейная	0103000020E61000000100000005000000967B8159212D6040E84CDA54DD094940967B8159212D60409F573CF548114940BBEF181EFB2E60409F573CF548114940BBEF181EFB2E6040E84CDA54DD094940967B8159212D6040E84CDA54DD094940
46361	14592	129.41032100000001	129.468154	50.135038999999999	50.077067	Куйбышева	0103000020E61000000100000005000000967B8159212D6040E84CDA54DD094940967B8159212D60409F573CF548114940BBEF181EFB2E60409F573CF548114940BBEF181EFB2E6040E84CDA54DD094940967B8159212D6040E84CDA54DD094940
46496	14592	129.41032100000001	129.468154	50.135038999999999	50.077067	Красноармейская	0103000020E61000000100000005000000967B8159212D6040E84CDA54DD094940967B8159212D60409F573CF548114940BBEF181EFB2E60409F573CF548114940BBEF181EFB2E6040E84CDA54DD094940967B8159212D6040E84CDA54DD094940
46386	14592	129.41032100000001	129.468154	50.135038999999999	50.077067	Кооперативная	0103000020E61000000100000005000000967B8159212D6040E84CDA54DD094940967B8159212D60409F573CF548114940BBEF181EFB2E60409F573CF548114940BBEF181EFB2E6040E84CDA54DD094940967B8159212D6040E84CDA54DD094940
46450	14592	129.41032100000001	129.468154	50.135038999999999	50.077067	Комсомольская	0103000020E61000000100000005000000967B8159212D6040E84CDA54DD094940967B8159212D60409F573CF548114940BBEF181EFB2E60409F573CF548114940BBEF181EFB2E6040E84CDA54DD094940967B8159212D6040E84CDA54DD094940
46719	14363	129.21965299999999	129.22663299999999	49.997767000000003	49.986421999999997	Нижняя	0103000020E61000000100000005000000FC6EBA650727604007077B1343FE4840FC6EBA650727604097033DD4B6FF48403866D9934027604097033DD4B6FF48403866D9934027604007077B1343FE4840FC6EBA650727604007077B1343FE4840
46758	8294	129.68455800000001	129.70902799999999	50.226000999999997	50.209446999999997	Центральная	0103000020E61000000100000005000000E3C62DE6E7356040669FC728CF1A4940E3C62DE6E735604080EECB99ED1C494058FE7C5BB036604080EECB99ED1C494058FE7C5BB0366040669FC728CF1A4940E3C62DE6E7356040669FC728CF1A4940
46860	14259	129.554913	129.57109199999999	50.064641999999999	50.050646999999998	Центральная	0103000020E610000001000000050000000264E8D8C1316040FC51D4997B0649400264E8D8C131604059F96530460849403BE0BA624632604059F96530460849403BE0BA6246326040FC51D4997B0649400264E8D8C1316040FC51D4997B064940
47171	15064	129.47890699999999	129.510501	50.228641000000003	50.220336000000003	Октябрьская	0103000020E610000001000000050000006ADAC534532F6040D41055F8331C49406ADAC534532F60402BC3B81B441D494069723106563060402BC3B81B441D49406972310656306040D41055F8331C49406ADAC534532F6040D41055F8331C4940
47085	8231	129.17560900000001	129.21835100000001	50.189773000000002	50.176605000000002	Центральная	0103000020E6100000010000000500000044FCC3969E256040B1A71DFE9A16494044FCC3969E256040F8544E7B4A18494091813CBBFC266040F8544E7B4A18494091813CBBFC266040B1A71DFE9A16494044FCC3969E256040B1A71DFE9A164940
46965	15114	129.418172	129.43428800000001	50.273325999999997	50.252037000000001	Центральная	0103000020E610000001000000050000004B033FAA612D6040E43098BF422049404B033FAA612D6040C092AB58FC22494073A1F2AFE52D6040C092AB58FC22494073A1F2AFE52D6040E43098BF422049404B033FAA612D6040E43098BF42204940
47091	13743	129.68332799999999	129.71341200000001	49.680157999999999	49.669775000000001	Центральная	0103000020E610000001000000050000001D8EAED2DD356040D656EC2FBBD548401D8EAED2DD3560406F0ED76A0FD748405E126745D43660406F0ED76A0FD748405E126745D4366040D656EC2FBBD548401D8EAED2DD356040D656EC2FBBD54840
46692	48	129.221441	129.24502200000001	49.760956	49.740856999999998	Центральная	0103000020E61000000100000005000000CB9F6F0B162760409F01F566D4DE4840CB9F6F0B16276040F5D8960167E148409E996038D7276040F5D8960167E148409E996038D72760409F01F566D4DE4840CB9F6F0B162760409F01F566D4DE4840
46961	48402	129.751645	129.78381300000001	50.022863000000001	50.013243000000003	Школьная	0103000020E6100000010000000500000076A6D0790D38604052F355F2B101494076A6D0790D386040ECA4BE2CED024940C02500FF14396040ECA4BE2CED024940C02500FF1439604052F355F2B101494076A6D0790D38604052F355F2B1014940
46448	12980	129.84680299999999	129.89233899999999	49.815370000000001	49.785437000000002	Советская	0103000020E61000000100000005000000F3E49A02193B6040C0081A3389E44840F3E49A02193B6040DC114E0B5EE8484040BE840A8E3C6040DC114E0B5EE8484040BE840A8E3C6040C0081A3389E44840F3E49A02193B6040C0081A3389E44840
46396	55700	129.84680299999999	129.89233899999999	49.815370000000001	49.785437000000002	Чайковского	0103000020E61000000100000005000000F3E49A02193B6040C0081A3389E44840F3E49A02193B6040DC114E0B5EE8484040BE840A8E3C6040DC114E0B5EE8484040BE840A8E3C6040C0081A3389E44840F3E49A02193B6040C0081A3389E44840
46495	55700	129.84680299999999	129.89233899999999	49.815370000000001	49.785437000000002	Советская	0103000020E61000000100000005000000F3E49A02193B6040C0081A3389E44840F3E49A02193B6040DC114E0B5EE8484040BE840A8E3C6040DC114E0B5EE8484040BE840A8E3C6040C0081A3389E44840F3E49A02193B6040C0081A3389E44840
46447	55700	129.84680299999999	129.89233899999999	49.815370000000001	49.785437000000002	Лесная	0103000020E61000000100000005000000F3E49A02193B6040C0081A3389E44840F3E49A02193B6040DC114E0B5EE8484040BE840A8E3C6040DC114E0B5EE8484040BE840A8E3C6040C0081A3389E44840F3E49A02193B6040C0081A3389E44840
46588	55723	129.889689	129.94521399999999	49.801184999999997	49.781191	Юбилейная	0103000020E610000001000000050000008DD31055783C6040FB761211FEE348408DD31055783C6040DB85E63A8DE6484015376E313F3E6040DB85E63A8DE6484015376E313F3E6040FB761211FEE348408DD31055783C6040FB761211FEE34840
46398	48373	129.813107	129.860727	49.792323000000003	49.771382000000003	Октябрьская	0103000020E61000000100000005000000C2A4F8F8043A60408E5C37A5BCE24840C2A4F8F8043A60402F6F0ED76AE54840187959138B3B60402F6F0ED76AE54840187959138B3B60408E5C37A5BCE24840C2A4F8F8043A60408E5C37A5BCE24840
47090	13887	129.874166	129.884658	49.905759000000003	49.887183999999998	Молодёжная	0103000020E61000000100000005000000CEA8F92AF93B604069C4CC3E8FF14840CEA8F92AF93B6040628731E9EFF34840A2444B1E4F3C6040628731E9EFF34840A2444B1E4F3C604069C4CC3E8FF14840CEA8F92AF93B604069C4CC3E8FF14840
46789	49255	129.402164	129.41974400000001	49.670963999999998	49.654865000000001	переулок Школьный	0103000020E610000001000000050000001D740987DE2C6040C425C79DD2D348401D740987DE2C60408C65FA25E2D548402716F88A6E2D60408C65FA25E2D548402716F88A6E2D6040C425C79DD2D348401D740987DE2C6040C425C79DD2D34840
46578	13380	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	Кировская	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
46449	55707	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	Октябрьская	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
46676	55707	129.78004000000001	129.83434299999999	49.824373000000001	49.792892999999999	Мухинская	0103000020E610000001000000050000004D327216F6386040191D90847DE548404D327216F63860404B5AF10D85E94840B05417F0B23A60404B5AF10D85E94840B05417F0B23A6040191D90847DE548404D327216F6386040191D90847DE54840
46664	30127	129.011594	129.03446600000001	49.820118000000001	49.805486999999999	Центральная	0103000020E610000001000000050000008E5A61FA5E206040342DB1321AE748408E5A61FA5E206040336E6AA0F9E848405EDA70581A216040336E6AA0F9E848405EDA70581A216040342DB1321AE748408E5A61FA5E206040342DB1321AE74840
46756	48446	129.44772699999999	129.470472	49.572212999999998	49.553216999999997	Новая	0103000020E6100000010000000500000028D192C7532E6040AD4B8DD0CFC6484028D192C7532E60404BAC8C463EC94840E1B54B1B0E2F60404BAC8C463EC94840E1B54B1B0E2F6040AD4B8DD0CFC6484028D192C7532E6040AD4B8DD0CFC64840
46635	7764	127.49753800000001	127.524658	50.344223999999997	50.329103000000003	Тепличная	0103000020E610000001000000050000001BA19FA9D7DF5F40FC010F0C202A49401BA19FA9D7DF5F40C83F33880F2C49406DE525FF93E15F40C83F33880F2C49406DE525FF93E15F40FC010F0C202A49401BA19FA9D7DF5F40FC010F0C202A4940
46368	7764	127.49753800000001	127.524658	50.344223999999997	50.329103000000003	Новая	0103000020E610000001000000050000001BA19FA9D7DF5F40FC010F0C202A49401BA19FA9D7DF5F40C83F33880F2C49406DE525FF93E15F40C83F33880F2C49406DE525FF93E15F40FC010F0C202A49401BA19FA9D7DF5F40FC010F0C202A4940
46379	7361	127.725441	127.771973	50.337589999999999	50.314374000000001	Ленина	0103000020E610000001000000050000005D8B16A06DEE5F403A5B40683D2849405D8B16A06DEE5F4073BA2C26362B49404819710168F15F4073BA2C26362B49404819710168F15F403A5B40683D2849405D8B16A06DEE5F403A5B40683D284940
46939	7695	127.79410799999999	127.81020599999999	50.142873000000002	50.134236000000001	Свободная	0103000020E610000001000000050000007C5F5CAAD2F25F4012F92EA52E1149407C5F5CAAD2F25F409F3D97A9491249407841446ADAF35F409F3D97A9491249407841446ADAF35F4012F92EA52E1149407C5F5CAAD2F25F4012F92EA52E114940
46475	8057	127.277666	127.31368000000001	50.764023000000002	50.718006000000003	Пограничная	0103000020E61000000100000005000000834D9D47C5D15F40782AE09EE75B4940834D9D47C5D15F4027327381CB614940325A475513D45F4027327381CB614940325A475513D45F40782AE09EE75B4940834D9D47C5D15F40782AE09EE75B4940
47078	7247	127.76408600000001	127.781648	50.298990000000003	50.282553999999998	Центральная	0103000020E610000001000000050000003755F7C8E6F05F404FADBEBA2A2449403755F7C8E6F05F4060EAE74D45264940F73E558506F25F4060EAE74D45264940F73E558506F25F404FADBEBA2A2449403755F7C8E6F05F404FADBEBA2A244940
47076	8289	127.779124	127.789643	50.877636000000003	50.855584999999998	Центральная	0103000020E61000000100000005000000D6E1E82ADDF15F405DF92CCF836D4940D6E1E82ADDF15F4069E55E6056704940FB20CB8289F25F4069E55E6056704940FB20CB8289F25F405DF92CCF836D4940D6E1E82ADDF15F405DF92CCF836D4940
46432	55706	127.48012900000001	127.498966	50.316186000000002	50.301389999999998	Центральная	0103000020E610000001000000050000001E37FC6EBADE5F40B4AB90F2932649401E37FC6EBADE5F40FEB968C87828494038F4160FEFDF5F40FEB968C87828494038F4160FEFDF5F40B4AB90F2932649401E37FC6EBADE5F40B4AB90F293264940
46712	7742	127.706118	127.73409100000001	50.134270999999998	50.124090000000002	Центральная	0103000020E610000001000000050000007C478D0931ED5F405DE15D2EE20F49407C478D0931ED5F408EE6C8CA2F1149406E52D158FBEE5F408EE6C8CA2F1149406E52D158FBEE5F405DE15D2EE20F49407C478D0931ED5F405DE15D2EE20F4940
46636	47342	127.544673	127.568505	50.508232	50.488028999999997	Гагарина	0103000020E61000000100000005000000E98024ECDBE25F40F23FF9BB773E4940E98024ECDBE25F40ED6305BF0D41494033A7CB6262E45F40ED6305BF0D41494033A7CB6262E45F40F23FF9BB773E4940E98024ECDBE25F40F23FF9BB773E4940
46606	8224	127.748707	127.765703	50.792814	50.773935000000002	Школьная	0103000020E6100000010000000500000052D2C3D0EAEF5F40691D554D1063494052D2C3D0EAEF5F40CDE7DCED7A654940BEDC274701F15F40CDE7DCED7A654940BEDC274701F15F40691D554D1063494052D2C3D0EAEF5F40691D554D10634940
46949	8377	127.65600999999999	127.675907	50.647497999999999	50.638924000000003	Центральная	0103000020E6100000010000000500000055F65D11FCE95F409450FA42C851494055F65D11FCE95F40DA1CE736E1524940CC086F0F42EB5F40DA1CE736E1524940CC086F0F42EB5F409450FA42C851494055F65D11FCE95F409450FA42C8514940
46802	7975	127.359027	127.392633	50.643380000000001	50.619703000000001	Коммунальная	0103000020E6100000010000000500000062D8614CFAD65F40D61D8B6D524F494062D8614CFAD65F4043739D465A524940259529E620D95F4043739D465A524940259529E620D95F40D61D8B6D524F494062D8614CFAD65F40D61D8B6D524F4940
46577	7928	127.359143	127.382015	50.550198000000002	50.536883000000003	60 лет Октября	0103000020E6100000010000000500000097E5EB32FCD65F40A2630795B844494097E5EB32FCD65F408D2958E36C46494036E50AEF72D85F408D2958E36C46494036E50AEF72D85F40A2630795B844494097E5EB32FCD65F40A2630795B8444940
46784	55750	127.62853	127.641942	50.209228000000003	50.200015	Центральная	0103000020E6100000010000000500000083A3E4D539E85F40CFDA6D179A19494083A3E4D539E85F4029B4ACFBC71A494072FBE59315E95F4029B4ACFBC71A494072FBE59315E95F40CFDA6D179A19494083A3E4D539E85F40CFDA6D179A194940
46575	7868	127.38598500000001	127.399388	50.449109999999997	50.441648000000001	Школьная	0103000020E61000000100000005000000C8EF6DFAB3D85F40022CF2EB87384940C8EF6DFAB3D85F403D27BD6F7C3949408D9AAF928FD95F403D27BD6F7C3949408D9AAF928FD95F40022CF2EB87384940C8EF6DFAB3D85F40022CF2EB87384940
46751	55745	127.66885600000001	127.676141	50.250545000000002	50.247065999999997	Магистральная	0103000020E61000000100000005000000F06E6589CEEA5F400DFAD2DB9F1F4940F06E6589CEEA5F409296CADB11204940069FE6E445EB5F409296CADB11204940069FE6E445EB5F400DFAD2DB9F1F4940F06E6589CEEA5F400DFAD2DB9F1F4940
46716	8359	127.69380200000001	127.705794	50.692461000000002	50.679226999999997	пер. Клубный	0103000020E6100000010000000500000090F9804067EC5F40B4C70BE9F056494090F9804067EC5F40B360E28FA2584940A2ED98BA2BED5F40B360E28FA2584940A2ED98BA2BED5F40B4C70BE9F056494090F9804067EC5F40B4C70BE9F0564940
46815	7654	127.828343	127.838134	50.177787000000002	50.170270000000002	переулок Новый	0103000020E61000000100000005000000B7B75B9203F55F40B6BE4868CB154940B7B75B9203F55F40B55373B9C11649409AEAC9FCA3F55F40B55373B9C11649409AEAC9FCA3F55F40B6BE4868CB154940B7B75B9203F55F40B6BE4868CB154940
46975	7486	127.565073	127.586112	50.129432000000001	50.114508000000001	Центральная	0103000020E6100000010000000500000091B6F1272AE45F40B090B932A80E494091B6F1272AE45F4027874F3A91104940C3F2E7DB82E55F4027874F3A91104940C3F2E7DB82E55F40B090B932A80E494091B6F1272AE45F40B090B932A80E4940
46688	55736	127.745311	127.75728599999999	50.210715999999998	50.196088000000003	Центральная	0103000020E610000001000000050000005796E82CB3EF5F40AC915D69191949405796E82CB3EF5F40395FECBDF81A4940FEEDB25F77F05F40395FECBDF81A4940FEEDB25F77F05F40AC915D69191949405796E82CB3EF5F40AC915D6919194940
46951	7302	127.631162	127.63878	50.304254999999998	50.296602	Центральная	0103000020E61000000100000005000000971E4DF564E85F40CFF6E80DF7254940971E4DF564E85F407E52EDD3F1264940B05582C5E1E85F407E52EDD3F1264940B05582C5E1E85F40CFF6E80DF7254940971E4DF564E85F40CFF6E80DF7254940
46629	7847	127.389039	127.45218199999999	50.291918000000003	50.274603999999997	Ленина	0103000020E610000001000000050000009677D503E6D85F40E6AC4F39262349409677D503E6D85F408F8EAB915D254940C075C58CF0DC5F408F8EAB915D254940C075C58CF0DC5F40E6AC4F39262349409677D503E6D85F40E6AC4F3926234940
46558	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	п. Аэропорт	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46671	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Школьная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46443	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Широкая	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46595	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Шимановского	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46446	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Чайковского	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46554	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Центральная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46563	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Фрунзе	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46494	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Трудовая	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46436	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Тенистая	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46441	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Театральная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46438	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Студенческая	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46445	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Северная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46377	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Свободная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46380	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Релочная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46560	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Рабочая	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46381	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Пушкина	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46497	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Политехническая	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46488	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Пограничная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46373	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Пионерская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46392	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Первомайская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46444	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Островского	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46384	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Октябрьская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46506	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Нагорная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46378	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Ломоносова	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46562	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Ленина,	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46359	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Ленина	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46508	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Лазо	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46383	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Краснофлотская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46435	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Красноармейская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46557	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Комсомольская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46374	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Калинина	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46362	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Институтская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46467	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Игнатьевское шоссе	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46358	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Зейская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46375	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Загородная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46504	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Заводская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46376	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Горького	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46625	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Воронкова	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46431	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Б. Хмельницкого	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46365	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	Амурская	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46564	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	 Театральная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46565	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	 Свободная	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46442	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	 Островского	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46390	7446	127.38209500000001	127.62738	50.438510000000001	50.243730999999997	 Дьяченко	0103000020E61000000100000005000000C53D963E74D85F40BC02D193321F4940C53D963E74D85F40077C7E1821384940878A71FE26E85F40077C7E1821384940878A71FE26E85F40BC02D193321F4940C53D963E74D85F40BC02D193321F4940
46940	8141	127.210823	127.22781000000001	50.811827000000001	50.800904000000003	Лесная	0103000020E61000000100000005000000A88FC01F7ECD5F40289EB30584664940A88FC01F7ECD5F40418177F2E9674940EAEC647094CE5F40418177F2E9674940EAEC647094CE5F40289EB30584664940A88FC01F7ECD5F40289EB30584664940
46766	5308	128.04744199999999	128.080994	50.741616	50.721004999999998	Школьная	0103000020E610000001000000050000009ECE15A58401604051A04FE4495C49409ECE15A5840160405D18E945ED5E494083A5BA80970260405D18E945ED5E494083A5BA809702604051A04FE4495C49409ECE15A58401604051A04FE4495C4940
46698	5308	128.04744199999999	128.080994	50.741616	50.721004999999998	Центральная	0103000020E610000001000000050000009ECE15A58401604051A04FE4495C49409ECE15A5840160405D18E945ED5E494083A5BA80970260405D18E945ED5E494083A5BA809702604051A04FE4495C49409ECE15A58401604051A04FE4495C4940
46357	4992	128.21610000000001	128.274338	50.794032000000001	50.766843000000001	Комсомольская	0103000020E610000001000000050000004D158C4AEA066040511553E9276249404D158C4AEA0660401EFD2FD7A26549409A417C60C70860401EFD2FD7A26549409A417C60C7086040511553E9276249404D158C4AEA066040511553E927624940
46713	5536	127.95248100000001	127.980903	50.991238000000003	50.978026999999997	Школьная	0103000020E61000000100000005000000EE43DE72F5FC5F4070CD1DFD2F7D4940EE43DE72F5FC5F40B74604E3E07E49401763601DC7FE5F40B74604E3E07E49401763601DC7FE5F4070CD1DFD2F7D4940EE43DE72F5FC5F4070CD1DFD2F7D4940
47019	4947	128.20952500000001	128.218526	50.696615000000001	50.687559	Центральная	0103000020E6100000010000000500000039D6C56DB40660400589EDEE0158494039D6C56DB4066040977329AE2A5949406CEA3C2AFE066040977329AE2A5949406CEA3C2AFE0660400589EDEE0158494039D6C56DB40660400589EDEE01584940
46669	4603	128.511574	128.53144499999999	50.832436999999999	50.819902999999996	Садовая	0103000020E610000001000000050000007CEF6FD05E1060403672DD94F26849407CEF6FD05E1060407C7DAD4B8D6A4940EDD3F198011160407C7DAD4B8D6A4940EDD3F198011160403672DD94F26849407CEF6FD05E1060403672DD94F2684940
47129	5072	128.318005	128.334903	50.740862999999997	50.719476999999998	Почтовая	0103000020E61000000100000005000000DD5ED2182D0A6040B29C84D2175C4940DD5ED2182D0A604081E84999D45E4940A20A7F86B70A604081E84999D45E4940A20A7F86B70A6040B29C84D2175C4940DD5ED2182D0A6040B29C84D2175C4940
46851	3899	128.709338	128.74067199999999	50.876556000000001	50.867694999999998	Центральная	0103000020E61000000100000005000000ECF99AE5B21660408CF337A1106F4940ECF99AE5B2166040698EACFC327049400322C495B3176040698EACFC327049400322C495B31760408CF337A1106F4940ECF99AE5B21660408CF337A1106F4940
47045	4470	128.718762	128.77330699999999	50.648080999999998	50.637884999999997	Центральная	0103000020E6100000010000000500000071732A1900176040F2CD3637A651494071732A190017604059147651F4524940925852EEBE18604059147651F4524940925852EEBE186040F2CD3637A651494071732A1900176040F2CD3637A6514940
46761	4786	128.41888599999999	128.44738100000001	50.620851999999999	50.616314000000003	Центральная	0103000020E6100000010000000500000012D89C83670D604092088D60E34E494012D89C83670D6040FED30D14784F4940427BF5F1500E6040FED30D14784F4940427BF5F1500E604092088D60E34E494012D89C83670D604092088D60E34E4940
47061	4817	128.44974300000001	128.46929	50.695627999999999	50.687525000000001	Нижняя	0103000020E610000001000000050000005C936E4B640E60405917B7D1005849405C936E4B640E604048179B560A594940E04A766C040F604048179B560A594940E04A766C040F60405917B7D1005849405C936E4B640E60405917B7D100584940
47203	3996	\N	\N	\N	\N	Школьная	\N
47013	5393	127.870572	127.889635	50.888109	50.868882999999997	Набережная	0103000020E610000001000000050000000D349F73B7F75F407286E28E376F49400D349F73B7F75F404224438EAD7149402098A3C7EFF85F404224438EAD7149402098A3C7EFF85F407286E28E376F49400D349F73B7F75F407286E28E376F4940
46371	5687	128.277725	128.30211399999999	50.932647000000003	50.914422000000002	пер.Школьный	0103000020E6100000010000000500000003098A1FE3086040185FB4C70B75494003098A1FE308604034DB15FA607749403DB5FAEAAA09604034DB15FA607749403DB5FAEAAA096040185FB4C70B75494003098A1FE3086040185FB4C70B754940
46757	55747	128.398045	128.416146	50.861964	50.850535999999998	Новая	0103000020E61000000100000005000000C32ADEC8BC0C60400B09185DDE6C4940C32ADEC8BC0C6040282A1BD6546E49408F8B6A11510D6040282A1BD6546E49408F8B6A11510D60400B09185DDE6C4940C32ADEC8BC0C60400B09185DDE6C4940
47054	4734	128.34262799999999	128.36267799999999	50.684866	50.67051	Садовая	0103000020E6100000010000000500000034D6FECEF60A60400BD28C45D355494034D6FECEF60A6040381268B0A9574940519FE40E9B0B6040381268B0A9574940519FE40E9B0B60400BD28C45D355494034D6FECEF60A60400BD28C45D3554940
47064	4553	128.599636	128.610973	50.746141000000001	50.736165999999997	Центральная	0103000020E610000001000000050000002330D63730136040AC36FFAF3A5E49402330D63730136040359A5C8C815F4940A6B73F178D136040359A5C8C815F4940A6B73F178D136040AC36FFAF3A5E49402330D63730136040AC36FFAF3A5E4940
47039	3786	128.57759999999999	128.58983499999999	50.907480999999997	50.901215999999998	 Юбилейная	0103000020E610000001000000050000006DC5FEB27B126040E350BF0B5B7349406DC5FEB27B126040E55E6056287449402861A6EDDF126040E55E6056287449402861A6EDDF126040E350BF0B5B7349406DC5FEB27B126040E350BF0B5B734940
46778	5208	128.19192699999999	128.21805000000001	50.841355999999998	50.828153	Садовая	0103000020E610000001000000050000000587174424066040CA8AE1EA006A494005871744240660408D25AC8DB16B4940925CFE43FA0660408D25AC8DB16B4940925CFE43FA066040CA8AE1EA006A49400587174424066040CA8AE1EA006A4940
46995	4087	129.04726700000001	129.05986100000001	50.765635000000003	50.756450000000001	Центральная	0103000020E61000000100000005000000C3651536832160409487855AD3604940C36515368321604024D6E25300624940CAA99D61EA21604024D6E25300624940CAA99D61EA2160409487855AD3604940C3651536832160409487855AD3604940
46668	4877	128.193184	128.23198300000001	50.741781000000003	50.723896000000003	Школьная	0103000020E61000000100000005000000894336902E06604045DAC69FA85C4940894336902E066040A8E507AEF25E49404CC79C676C076040A8E507AEF25E49404CC79C676C07604045DAC69FA85C4940894336902E06604045DAC69FA85C4940
46605	47510	128.314583	128.320458	50.781402	50.776823	Школьная	0103000020E61000000100000005000000151C5E10110A6040EBE3A1EF6E634940151C5E10110A6040B68311FB04644940BBB72231410A6040B68311FB04644940BBB72231410A6040EBE3A1EF6E634940151C5E10110A6040EBE3A1EF6E634940
46763	5133	128.25230199999999	128.273898	50.807166000000002	50.793224000000002	Центральная	0103000020E61000000100000005000000E4D6A4DB120860407F33315D88654940E4D6A4DB12086040B9382A3751674940130EBDC5C3086040B9382A3751674940130EBDC5C30860407F33315D88654940E4D6A4DB120860407F33315D88654940
46928	3949	128.84449000000001	128.85933	50.879761999999999	50.866847999999997	Сельская	0103000020E610000001000000050000009279E40F061B60402F4D11E0F46E49409279E40F061B6040BC218D0A9C70494018CFA0A17F1B6040BC218D0A9C70494018CFA0A17F1B60402F4D11E0F46E49409279E40F061B60402F4D11E0F46E4940
46777	5383	127.980733	128.004457	50.869588	50.853327999999998	Новая	0103000020E61000000100000005000000E9465854C4FE5F406B6116DA396D4940E9465854C4FE5F403D7FDAA84E6F4940A0A70183240060403D7FDAA84E6F4940A0A70183240060406B6116DA396D4940E9465854C4FE5F406B6116DA396D4940
46779	5638	128.159021	128.17909	50.944918000000001	50.933902000000003	 Рабочая	0103000020E61000000100000005000000124C35B316056040A2D5C9198A774940124C35B3160560406CB3B112F37849404DA1F31ABB0560406CB3B112F37849404DA1F31ABB056040A2D5C9198A774940124C35B316056040A2D5C9198A774940
46711	5547	128.11596499999999	128.13077799999999	50.943714999999997	50.932096000000001	Школьная	0103000020E61000000100000005000000614F3BFCB5036040C05DF6EB4E774940614F3BFCB503604050DF32A7CB784940292158552F04604050DF32A7CB784940292158552F046040C05DF6EB4E774940614F3BFCB5036040C05DF6EB4E774940
46781	55749	128.226099	128.240184	50.883149000000003	50.878909	Степная	0103000020E610000001000000050000001155F8333C0760407D941117807049401155F8333C076040603FC4060B714940B8205B96AF076040603FC4060B714940B8205B96AF0760407D941117807049401155F8333C0760407D94111780704940
46945	4377	128.612931	128.64221599999999	50.633902999999997	50.612147999999998	Комсомольская	0103000020E610000001000000050000008CF678219D136040E9279CDD5A4E49408CF678219D1360400BEBC6BB23514940F99E91088D1460400BEBC6BB23514940F99E91088D146040E9279CDD5A4E49408CF678219D136040E9279CDD5A4E4940
47198	4132	128.85081400000001	128.86482799999999	50.686937	50.680664999999998	Центральная	0103000020E61000000100000005000000541F48DE391B60401344DD0720574940541F48DE391B6040C8B4368DED5749404815C5ABAC1B6040C8B4368DED5749404815C5ABAC1B60401344DD0720574940541F48DE391B60401344DD0720574940
46370	4220	128.68810199999999	128.74230600000001	50.745674000000001	50.714407000000001	м-н Южный	0103000020E61000000100000005000000FD497CEE04166040498446B0715B4940FD497CEE041660401FBDE13E725F4940FD3383F8C01760401FBDE13E725F4940FD3383F8C0176040498446B0715B4940FD497CEE04166040498446B0715B4940
46774	4220	128.68810199999999	128.74230600000001	50.745674000000001	50.714407000000001	Центральная	0103000020E61000000100000005000000FD497CEE04166040498446B0715B4940FD497CEE041660401FBDE13E725F4940FD3383F8C01760401FBDE13E725F4940FD3383F8C0176040498446B0715B4940FD497CEE04166040498446B0715B4940
46492	4220	128.68810199999999	128.74230600000001	50.745674000000001	50.714407000000001	Гагарина	0103000020E61000000100000005000000FD497CEE04166040498446B0715B4940FD497CEE041660401FBDE13E725F4940FD3383F8C01760401FBDE13E725F4940FD3383F8C0176040498446B0715B4940FD497CEE04166040498446B0715B4940
46634	5455	127.895132	127.925118	50.932640999999997	50.900767000000002	Мира	0103000020E610000001000000050000009966BAD749F95F40742843554C7349409966BAD749F95F4051F4C0C76077494038BC202235FB5F4051F4C0C76077494038BC202235FB5F40742843554C7349409966BAD749F95F40742843554C734940
46482	3865	128.59866600000001	128.62678299999999	50.896051999999997	50.879016999999997	Школьная	0103000020E61000000100000005000000456799452813604063D009A1837049404567994528136040F8C1F9D4B17249400AD6389B0E146040F8C1F9D4B17249400AD6389B0E14604063D009A183704940456799452813604063D009A183704940
47050	4642	128.48870299999999	128.499402	50.775832000000001	50.762883000000002	Школьная	0103000020E61000000100000005000000A04E7974A30F604052D66F26A6614940A04E7974A30F60405B9885764E634940D331E719FB0F60405B9885764E634940D331E719FB0F604052D66F26A6614940A04E7974A30F604052D66F26A6614940
46486	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	пер. Летний	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46548	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Шевченко	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46425	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Ударная	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46433	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Производственная	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46428	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Партизанская	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46434	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Никольское шоссе	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46372	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Набережная	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46544	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Матросская	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
9933	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Ленина	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46484	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Красноармейская	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46485	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Кирова	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46430	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Калининская	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46864	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Вокзальная	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46549	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Благовещенская	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46551	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	Авиационная	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46427	5033	128.36645100000001	128.568141	50.934871999999999	50.870002999999997	9 мая	0103000020E61000000100000005000000C59272F7B90B6040003620425C6F4940C59272F7B90B60401AF9BCE2A977494089D008362E1260401AF9BCE2A977494089D008362E126040003620425C6F4940C59272F7B90B6040003620425C6F4940
46573	4175	128.727026	128.74871999999999	50.748398000000002	50.733783000000003	Школьная	0103000020E61000000100000005000000EFAA07CC431760402EAEF199EC5D4940EFAA07CC4317604027327381CB5F49408E3BA583F517604027327381CB5F49408E3BA583F51760402EAEF199EC5D4940EFAA07CC431760402EAEF199EC5D4940
46904	2672	130.25470999999999	130.27755400000001	49.437806999999999	49.430917999999998	Зеленая	0103000020E61000000100000005000000DAFE959526486040FDA02E5228B74840DAFE959526486040DD7A4D0F0AB84840F81BEDB8E1486040DD7A4D0F0AB84840F81BEDB8E1486040FDA02E5228B74840DAFE959526486040FDA02E5228B74840
46861	3704	129.93078700000001	129.94702799999999	49.623251000000003	49.614660000000001	Советская	0103000020E610000001000000050000005891D101C93D60406614CB2DADCE48405891D101C93D6040831953B0C6CF4840AE0CAA0D4E3E6040831953B0C6CF4840AE0CAA0D4E3E60406614CB2DADCE48405891D101C93D60406614CB2DADCE4840
46943	3671	130.46976699999999	130.49058099999999	49.234217999999998	49.223998999999999	Лесная	0103000020E61000000100000005000000AEB7CD54084F604019ABCDFFAB9C4840AEB7CD54084F60403811FDDAFA9D48403FE1ECD6B24F60403811FDDAFA9D48403FE1ECD6B24F604019ABCDFFAB9C4840AEB7CD54084F604019ABCDFFAB9C4840
46776	3620	129.54682	129.56637599999999	49.456567999999997	49.443238000000001	Амурская	0103000020E610000001000000050000008F19A88C7F316040172CD505BCB848408F19A88C7F3160403733FAD170BA4840A8A78FC01F3260403733FAD170BA4840A8A78FC01F326040172CD505BCB848408F19A88C7F316040172CD505BCB84840
46574	3479	130.088764	130.13015899999999	49.366919000000003	49.345578000000003	Центральная	0103000020E61000000100000005000000FDA19927D7426040CA1B60E63BAC4840FDA19927D7426040F9A3A833F7AE4840F60835432A446040F9A3A833F7AE4840F60835432A446040CA1B60E63BAC4840FDA19927D7426040CA1B60E63BAC4840
46708	3338	129.77282700000001	129.79552699999999	49.657629	49.647306	Школьная	0103000020E61000000100000005000000E84EB0FFBA38604096404AECDAD24840E84EB0FFBA3860405AF3E32F2DD44840B8020AF5743960405AF3E32F2DD44840B8020AF57439604096404AECDAD24840E84EB0FFBA38604096404AECDAD24840
46773	3477	130.288702	130.302572	49.243723000000003	49.228552000000001	Центральная	0103000020E610000001000000050000004609FA0B3D496040BBB72231419D48404609FA0B3D4960403A24B550329F4840EE9579ABAE4960403A24B550329F4840EE9579ABAE496040BBB72231419D48404609FA0B3D496040BBB72231419D4840
47136	3477	130.288702	130.302572	49.243723000000003	49.228552000000001	Октябрьская	0103000020E610000001000000050000004609FA0B3D496040BBB72231419D48404609FA0B3D4960403A24B550329F4840EE9579ABAE4960403A24B550329F4840EE9579ABAE496040BBB72231419D48404609FA0B3D496040BBB72231419D4840
47196	3134	130.198296	130.21348599999999	48.912208999999997	48.900111000000003	Центральная	0103000020E61000000100000005000000AF5DDA70584660408BE255D636734840AF5DDA7058466040F50EB743C3744840EC8497E0D4466040F50EB743C3744840EC8497E0D44660408BE255D636734840AF5DDA70584660408BE255D636734840
47017	3250	129.92855	129.969064	49.268935999999997	49.246398999999997	Ленинская	0103000020E610000001000000050000006D567DAEB63D604030629F008A9F48406D567DAEB63D6040C85BAE7E6CA2484064778192023F6040C85BAE7E6CA2484064778192023F604030629F008A9F48406D567DAEB63D604030629F008A9F4840
46598	3142	130.742064	130.76969600000001	49.119225999999998	49.089688000000002	Центральная	0103000020E610000001000000050000003F7100FDBE576040FD6B79E57A8B48403F7100FDBE5760409C6A2DCC428F4840967B8159A15860409C6A2DCC428F4840967B8159A1586040FD6B79E57A8B48403F7100FDBE576040FD6B79E57A8B4840
47003	3284	130.02705	130.051053	49.293942000000001	49.276947999999997	Центральная	0103000020E610000001000000050000006B2BF697DD406040A758350873A348406B2BF697DD406040DE7536E49FA548409BABE639A2416040DE7536E49FA548409BABE639A2416040A758350873A348406B2BF697DD406040A758350873A34840
46926	2991	130.05869799999999	130.087605	48.980207	48.966174000000002	Гапонова	0103000020E61000000100000005000000E6CAA0DAE04160406D1FF296AB7B4840E6CAA0DAE0416040B727486C777D4840EA3E00A9CD426040B727486C777D4840EA3E00A9CD4260406D1FF296AB7B4840E6CAA0DAE04160406D1FF296AB7B4840
47205	3578	130.17449099999999	130.189897	49.318835999999997	49.304405000000003	Центральная	0103000020E61000000100000005000000484E266E9545604094DE37BEF6A64840484E266E95456040CB64389ECFA848407993DFA213466040CB64389ECFA848407993DFA21346604094DE37BEF6A64840484E266E9545604094DE37BEF6A64840
46707	2924	129.674183	129.721147	49.307771000000002	49.290422999999997	Калинина	0103000020E610000001000000050000009D103AE892356040CB80B3942CA548409D103AE89235604020D4450A65A748407993DFA21337604020D4450A65A748407993DFA213376040CB80B3942CA548409D103AE892356040CB80B3942CA54840
46923	3032	129.99064100000001	130.004853	49.086674000000002	49.074263999999999	Центральная	0103000020E610000001000000050000007522C154B33F604094A2957B818948407522C154B33F6040EEB43522188B484033897AC127406040EEB43522188B484033897AC12740604094A2957B818948407522C154B33F604094A2957B81894840
47200	3382	129.85555299999999	129.884613	49.690713000000002	49.679755	Центральная	0103000020E61000000100000005000000D45FAFB0603B604070253B3602D74840D45FAFB0603B604006F6984869D84840BA13ECBF4E3C604006F6984869D84840BA13ECBF4E3C604070253B3602D74840D45FAFB0603B604070253B3602D74840
46772	2879	130.37007199999999	130.37667400000001	49.482075000000002	49.463366000000001	Центральная	0103000020E610000001000000050000004A253CA1D74B6040070ABC934FBB48404A253CA1D74B60400F9C33A2B4BD48401DE8A1B60D4C60400F9C33A2B4BD48401DE8A1B60D4C6040070ABC934FBB48404A253CA1D74B6040070ABC934FBB4840
46483	55705	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	Школьная	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
46429	55705	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	Ленина	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
46356	2322	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	Восточная	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
46369	2322	130.05819500000001	130.11057500000001	49.445082999999997	49.398941000000001	Больничная	0103000020E610000001000000050000004EB9C2BBDC4160404B04AA7F10B348404EB9C2BBDC416040B680D07AF8B848402B1895D489436040B680D07AF8B848402B1895D4894360404B04AA7F10B348404EB9C2BBDC4160404B04AA7F10B34840
46572	2669	130.12449899999999	130.16335100000001	49.409849999999999	49.397762	Паромная	0103000020E610000001000000050000004FAC53E5FB436040B8CB7EDDE9B248404FAC53E5FB436040FF21FDF675B448409B58E02B3A456040FF21FDF675B448409B58E02B3A456040B8CB7EDDE9B248404FAC53E5FB436040B8CB7EDDE9B24840
47138	2769	129.93104700000001	129.95115100000001	49.436799999999998	49.425539000000001	Центральная	0103000020E610000001000000050000003F011423CB3D60401616DC0F78B648403F011423CB3D60404772F90FE9B74840D9D138D46F3E60404772F90FE9B74840D9D138D46F3E60401616DC0F78B648403F011423CB3D60401616DC0F78B64840
\.


--
-- Data for Name: sub_area; Type: TABLE DATA; Schema: public; Owner: -
--

COPY sub_area (id, name, district_id, area_id, bounds_left, bounds_right, bounds_top, bounds_bottom, box) FROM stdin;
1925	Яшкульский район	\N	19	44.694994000000001	46.730297999999998	46.911394000000001	45.829196000000003	0103000020E6100000010000000500000047753A90F5584640ADFC321823EA464047753A90F5584640A4E2FF8EA8744740C72AA5677A5D4740A4E2FF8EA8744740C72AA5677A5D4740ADFC321823EA464047753A90F5584640ADFC321823EA4640
417	Яшалтинский район	\N	19	42.042862	42.924818999999999	46.560828999999998	45.968722999999997	0103000020E61000000100000005000000DE1E84807C05454006F1811DFFFB4640DE1E84807C054540FED2A23EC947474016DC0F7860764540FED2A23EC947474016DC0F786076454006F1811DFFFB4640DE1E84807C05454006F1811DFFFB4640
1559	Юстинский район	\N	19	45.695492999999999	47.252372000000001	47.641357999999997	46.446168	0103000020E6100000010000000500000068CC24EA05D94640C84274081C39474068CC24EA05D946409483D90418D247408B36C7B94DA047409483D90418D247408B36C7B94DA04740C84274081C39474068CC24EA05D94640C84274081C394740
7420	Элиста городской округ	\N	19	44.192413999999999	44.325805000000003	46.373187999999999	46.290489000000001	0103000020E6100000010000000500000072A59E05A1184640836C59BE2E25474072A59E05A11846403CA1D79FC42F4740C8EF6DFAB32946403CA1D79FC42F4740C8EF6DFAB3294640836C59BE2E25474072A59E05A1184640836C59BE2E254740
1928	Черноземельский район	\N	19	45.264293000000002	47.158830999999999	46.375694000000003	44.863036000000001	0103000020E61000000100000005000000E7C75F5AD4A14640A5A2B1F6776E4640E7C75F5AD4A14640D7A6B1BD16304740A54BFF9254944740D7A6B1BD16304740A54BFF9254944740A5A2B1F6776E4640E7C75F5AD4A14640A5A2B1F6776E4640
1607	Целинный район	\N	19	43.793391	45.076895	46.908346000000002	46.153396000000001	0103000020E610000001000000050000006AF816D68DE545402AABE97AA21347406AF816D68DE54540E9B985AE44744740EB1C03B2D7894640E9B985AE44744740EB1C03B2D78946402AABE97AA21347406AF816D68DE545402AABE97AA2134740
1927	Сарпинский район	\N	19	43.668103000000002	44.913598999999998	47.898781	47.259042000000001	0103000020E6100000010000000500000004AE2B6684D545402D25CB4928A1474004AE2B6684D5454012A27C410BF347404354E1CFF074464012A27C410BF347404354E1CFF07446402D25CB4928A1474004AE2B6684D545402D25CB4928A14740
1542	Приютненский район	\N	19	42.777531000000003	44.296393999999999	46.446131000000001	45.785632999999997	0103000020E610000001000000050000002750C4228663454045D4449F8FE446402750C42286634540AB5D13D21A394740855D143DF0254640AB5D13D21A394740855D143DF025464045D4449F8FE446402750C4228663454045D4449F8FE44640
1926	Октябрьский район	\N	19	45.029392000000001	45.925047999999997	47.987096000000001	47.174093999999997	0103000020E61000000100000005000000CC61F71DC3834640043752B648964740CC61F71DC38346409701672959FE4740779D0DF967F646409701672959FE4740779D0DF967F64640043752B648964740CC61F71DC3834640043752B648964740
1491	Малодербетовский район	\N	19	44.326667	45.757683	48.272261999999998	47.532595999999998	0103000020E610000001000000050000005AD76839D02946407EFD101B2CC447405AD76839D0294640C6F8307BD92248401ADEACC1FBE04640C6F8307BD92248401ADEACC1FBE046407EFD101B2CC447405AD76839D02946407EFD101B2CC44740
1930	Лаганский район	\N	19	46.635319000000003	47.569828000000001	45.669832999999997	44.745938000000002	0103000020E6100000010000000500000083C30B2252514740FD6B79E57A5F464083C30B22525147400A647616BDD546402C2CB81FF0C847400A647616BDD546402C2CB81FF0C84740FD6B79E57A5F464083C30B2252514740FD6B79E57A5F4640
1371	Кетченеровский район	\N	19	44.262014999999998	45.799993999999998	47.578800000000001	46.740298000000003	0103000020E61000000100000005000000DD0720B589214640A9A5B915C25E4740DD0720B58921464060764F1E16CA4740847F113466E6464060764F1E16CA4740847F113466E64640A9A5B915C25E4740DD0720B589214640A9A5B915C25E4740
1357	Ики-Бурульский район	\N	19	44.092044999999999	45.446596999999997	46.231996000000002	45.213790000000003	0103000020E6100000010000000500000052616C21C80B46401E1B81785D9B464052616C21C80B4640C366800BB21D4740F0BE2A172AB94640C366800BB21D4740F0BE2A172AB946401E1B81785D9B464052616C21C80B46401E1B81785D9B4640
1289	Городовиковский район	\N	19	41.637039000000001	42.210667000000001	46.298740000000002	45.932108999999997	0103000020E6100000010000000500000066A3737E8AD1444054A703594FF7464066A3737E8AD14440E700C11C3D26474058ACE122F71A4540E700C11C3D26474058ACE122F71A454054A703594FF7464066A3737E8AD1444054A703594FF74640
7419	Городовиковский	\N	19	41.659820000000003	42.176451	46.297102000000002	45.942011999999998	0103000020E61000000100000005000000959F54FB74D44440433866D993F84640959F54FB74D44440C1C93670072647405A2C45F295164540C1C93670072647405A2C45F295164540433866D993F84640959F54FB74D44440433866D993F84640
1763	Шовгеновский район	\N	18	39.887956000000003	40.365850999999999	45.122836999999997	44.913594000000003	0103000020E61000000100000005000000BC24CE8AA8F1434032E9EFA5F0744640BC24CE8AA8F143408FDE701FB98F4640BD1AA034D42E44408FDE701FB98F4640BD1AA034D42E444032E9EFA5F0744640BC24CE8AA8F1434032E9EFA5F0744640
1298	Теучежский район	\N	18	39.072951000000003	39.651007999999997	45.030616999999999	44.806161000000003	0103000020E61000000100000005000000F29A577556894340C4279D4830674640F29A577556894340CFD90242EB83464099B7EA3A54D34340CFD90242EB83464099B7EA3A54D34340C4279D4830674640F29A577556894340C4279D4830674640
1196	Тахтамукайский район	\N	18	38.683145000000003	39.131898	45.064495000000001	44.819180000000003	0103000020E6100000010000000500000085B69C4B71574340C6C4E6E3DA68464085B69C4B71574340B5E0455F4188464033349E08E2904340B5E0455F4188464033349E08E2904340C6C4E6E3DA68464085B69C4B71574340C6C4E6E3DA684640
1243	Майкопский район	\N	18	39.765732	40.482658999999998	44.793356000000003	43.761000000000003	0103000020E6100000010000000500000016C0948103E24340C520B07268E1454016C0948103E24340EE0A7DB08C6546405E0F26C5C73D4440EE0A7DB08C6546405E0F26C5C73D4440C520B07268E1454016C0948103E24340C520B07268E14540
1167	Красногвардейский район	\N	18	39.293630999999998	40.017412999999998	45.218488999999998	44.957397	0103000020E61000000100000005000000BF0B5BB395A54340EE2422FC8B7A4640BF0B5BB395A5434093C49272F79B46403BC3D4963A02444093C49272F79B46403BC3D4963A024440EE2422FC8B7A4640BF0B5BB395A54340EE2422FC8B7A4640
7417	Кошехабльский район	\N	18	38.683145000000003	40.768467000000001	45.218488999999998	43.761000000000003	0103000020E6100000010000000500000085B69C4B71574340C520B07268E1454085B69C4B7157434093C49272F79B464012876C205D62444093C49272F79B464012876C205D624440C520B07268E1454085B69C4B71574340C520B07268E14540
1319	Гиагинский район	\N	18	39.933033999999999	40.463335999999998	44.989699999999999	44.709968000000003	0103000020E610000001000000050000002D077AA86DF74340709A3E3BE05A46402D077AA86DF74340F46C567DAE7E46409C8713984E3B4440F46C567DAE7E46409C8713984E3B4440709A3E3BE05A46402D077AA86DF74340709A3E3BE05A4640
320	городской округ Донецк	\N	23	39.839914999999998	40.104675	48.368757000000002	48.269970999999998	0103000020E61000000100000005000000BD35B05582EB434028EFE3688E224840BD35B05582EB4340E695EB6D332F4840BADA8AFD650D4440E695EB6D332F4840BADA8AFD650D444028EFE3688E224840BD35B05582EB434028EFE3688E224840
374	городской округ Шахты	\N	23	40.074474000000002	40.388938000000003	47.814931000000001	47.659356000000002	0103000020E610000001000000050000007F33315D88094440F03504C765D447407F33315D8809444090BFB4A84FE84740F9156BB8C831444090BFB4A84FE84740F9156BB8C8314440F03504C765D447407F33315D88094440F03504C765D44740
1638	городской округ Новошахтинск	\N	23	39.783132000000002	40.032297999999997	47.888885000000002	47.702390999999999	0103000020E61000000100000005000000BD395CAB3DE443409B00C3F2E7D94740BD395CAB3DE44340D673D2FBC6F14740F4DC425722044440D673D2FBC6F14740F4DC4257220444409B00C3F2E7D94740BD395CAB3DE443409B00C3F2E7D94740
1247	городской округ Каменск-Шахтинский	\N	23	40.124105999999998	40.331949000000002	48.420661000000003	48.129748999999997	0103000020E61000000100000005000000629E95B4E20F444027D87F9D9B104840629E95B4E20F4440F1D93A38D83548404F78094E7D2A4440F1D93A38D83548404F78094E7D2A444027D87F9D9B104840629E95B4E20F444027D87F9D9B104840
1370	городской округ Гуково	\N	23	39.848241999999999	40.053462000000003	48.081634000000001	48.009368000000002	0103000020E61000000100000005000000FC8BA03193EC434081D07AF832014840FC8BA03193EC4340EF1EA0FB720A484015CAC2D7D7064440EF1EA0FB720A484015CAC2D7D706444081D07AF832014840FC8BA03193EC434081D07AF832014840
265	городской округ Волгодонск	\N	23	42.030276999999998	42.394058000000001	47.618611000000001	47.462536999999998	0103000020E610000001000000050000001669E21DE00345405018946934BB47401669E21DE003454012F92EA52ECF4740145D177E7032454012F92EA52ECF4740145D177E703245405018946934BB47401669E21DE00345405018946934BB4740
758	городской округ Белая Калитва	\N	23	40.754651000000003	40.814236000000001	48.201346000000001	48.143092000000003	0103000020E6100000010000000500000065726A6798604440DD28B2D65012484065726A67986044401897AAB4C5194840E99C9FE2386844401897AAB4C5194840E99C9FE238684440DD28B2D65012484065726A6798604440DD28B2D650124840
418	городской округ Батайск	\N	23	39.668515999999997	39.818956999999997	47.175257999999999	47.041187000000001	0103000020E61000000100000005000000266DAAEE91D543409B02999D45854740266DAAEE91D54340622EA9DA6E96474046EA3D95D3E84340622EA9DA6E96474046EA3D95D3E843409B02999D45854740266DAAEE91D543409B02999D45854740
183	городской округ Азов	\N	23	39.364373000000001	39.505974999999999	47.140503000000002	47.035617000000002	0103000020E61000000100000005000000D04543C6A3AE434040170D198F844740D04543C6A3AE4340B5FE9600FC914740FBCBEEC9C3C04340B5FE9600FC914740FBCBEEC9C3C0434040170D198F844740D04543C6A3AE434040170D198F844740
290	Шолоховский район	\N	23	41.303764000000001	42.185622000000002	49.966214999999998	49.319986999999998	0103000020E61000000100000005000000E0D91EBDE1A6444094128255F5A84840E0D91EBDE1A64440CBF3E0EEACFB484085B53176C2174540CBF3E0EEACFB484085B53176C217454094128255F5A84840E0D91EBDE1A6444094128255F5A84840
355	Чертковский район	\N	23	40.004683999999997	41.156306000000001	49.673307999999999	49.127687000000002	0103000020E6100000010000000500000040683D7C99004440EB8F300C5890484040683D7C990044404D11E0F42ED648409415C3D5019444404D11E0F42ED648409415C3D501944440EB8F300C5890484040683D7C99004440EB8F300C58904840
254	Цимлянский район	\N	23	41.714007000000002	42.757373000000001	48.050395999999999	47.535997000000002	0103000020E61000000100000005000000BB0ED59464DB444087E0B88C9BC44740BB0ED59464DB4440B3EC496073064840CCEF3499F1604540B3EC496073064840CCEF3499F160454087E0B88C9BC44740BB0ED59464DB444087E0B88C9BC44740
238	Целинский район	\N	23	40.704138999999998	41.33596	46.917597999999998	46.229301999999997	0103000020E61000000100000005000000486B0C3A215A4440257497C4591D4740486B0C3A215A44400070ECD973754740D061BEBC00AB44400070ECD973754740D061BEBC00AB4440257497C4591D4740486B0C3A215A4440257497C4591D4740
221	Усть-Донецкий район	\N	23	40.371563999999999	41.076185000000002	47.925148999999998	47.425550999999999	0103000020E610000001000000050000007B2FBE688F2F4440DAE3857478B647407B2FBE688F2F4440AB764D486BF647400FB9196EC0894440AB764D486BF647400FB9196EC0894440DAE3857478B647407B2FBE688F2F4440DAE3857478B64740
76	Тацинский район	\N	23	41.037773000000001	41.683301999999998	48.554696999999997	47.853580999999998	0103000020E61000000100000005000000FED5E3BED584444055BE672442ED4740FED5E3BED58444403B18B14F004748404CA59F7076D744403B18B14F004748404CA59F7076D7444055BE672442ED4740FED5E3BED584444055BE672442ED4740
1878	Тарасовский район	\N	23	39.660539	41.283102999999997	48.860444000000001	48.504179000000001	0103000020E61000000100000005000000C45DBD8A8CD443403D2AFEEF88404840C45DBD8A8CD443400C056C07236E4840223317B83CA444400C056C07236E4840223317B83CA444403D2AFEEF88404840C45DBD8A8CD443403D2AFEEF88404840
1373	Советский район	\N	23	39.501958999999999	39.668883999999998	47.261530999999998	47.166412000000001	0103000020E610000001000000050000006877483140C04340BBD408FD4C9547406877483140C04340F1F109D979A14740A968ACFD9DD54340F1F109D979A14740A968ACFD9DD54340BBD408FD4C9547406877483140C04340BBD408FD4C954740
264	Семикаракорский район	\N	23	40.603096000000001	41.399389999999997	47.637174999999999	47.150708000000002	0103000020E61000000100000005000000992CEE3F324D44406F9F55664A934740992CEE3F324D4440166A4DF38ED14740BA2C26361FB34440166A4DF38ED14740BA2C26361FB344406F9F55664A934740992CEE3F324D44406F9F55664A934740
461	Сальский район	\N	23	41.118279999999999	42.177439	47.041088999999999	46.143811999999997	0103000020E61000000100000005000000ACE28DCC238F4440DC627E6E68124740ACE28DCC238F4440D89C83674285474079043752B6164540D89C83674285474079043752B6164540DC627E6E68124740ACE28DCC238F4440DC627E6E68124740
1729	Родионово-Несветайский район	\N	23	39.189849000000002	39.901862000000001	47.872266000000003	47.417949	0103000020E61000000100000005000000D316D7F84C984340AD32535A7FB54740D316D7F84C984340D5B48B69A6EF4740A9C0C93670F34340D5B48B69A6EF4740A9C0C93670F34340AD32535A7FB54740D316D7F84C984340AD32535A7FB54740
989	Ремонтненский район	\N	23	42.914029999999997	43.979944000000003	46.782035999999998	46.157060999999999	0103000020E610000001000000050000000CC85EEFFE744540103D29931A1447400CC85EEFFE744540B72572C119644740AAF413CE6EFD4540B72572C119644740AAF413CE6EFD4540103D29931A1447400CC85EEFFE744540103D29931A144740
924	Пролетарский район	\N	23	39.732844	39.850639999999999	47.257586000000003	47.179195999999997	0103000020E61000000100000005000000F0880AD5CDDD434079C9FFE4EF964740F0880AD5CDDD434028F4FA93F8A04740B05582C5E1EC434028F4FA93F8A04740B05582C5E1EC434079C9FFE4EF964740F0880AD5CDDD434079C9FFE4EF964740
845	Песчанокопский район	\N	23	40.967534000000001	41.715254999999999	46.375078000000002	45.951694000000003	0103000020E6100000010000000500000050E27327D87B444054E6E61BD1F9464050E27327D87B44407CB94F8E0230474076A6D0798DDB44407CB94F8E0230474076A6D0798DDB444054E6E61BD1F9464050E27327D87B444054E6E61BD1F94640
529	Орловский район	\N	23	41.778900999999998	42.96951	47.157504000000003	46.368046	0103000020E610000001000000050000002DE92807B3E3444039B69E211C2F47402DE92807B3E344409E7E5017299447408E9257E7187C45409E7E5017299447408E9257E7187C454039B69E211C2F47402DE92807B3E3444039B69E211C2F4740
898	Октябрьский район	\N	23	39.614060000000002	39.715803000000001	47.345292999999998	47.225712999999999	0103000020E6100000010000000500000011E4A08499CE43401AA4E029E49C474011E4A08499CE4340D4449F8F32AC474079B0C56E9FDB4340D4449F8F32AC474079B0C56E9FDB43401AA4E029E49C474011E4A08499CE43401AA4E029E49C4740
1758	Обливский район	\N	23	41.932262000000001	42.749386999999999	48.921238000000002	48.450561999999998	0103000020E61000000100000005000000DBA6785C54F744400169FF03AC394840DBA6785C54F744408EEA7420EB7548401686C8E9EB5F45408EEA7420EB7548401686C8E9EB5F45400169FF03AC394840DBA6785C54F744400169FF03AC394840
73	Неклиновский район	\N	23	38.221195000000002	39.363070999999998	47.563547	47.114545	0103000020E61000000100000005000000F584251E501C4340CD751A69A98E4740F584251E501C43402461DF4E22C8474021904B1C79AE43402461DF4E22C8474021904B1C79AE4340CD751A69A98E4740F584251E501C4340CD751A69A98E4740
1296	Мясниковский район	\N	23	39.228225000000002	39.735773000000002	47.539037999999998	47.201664000000001	0103000020E6100000010000000500000097900F7A369D4340E9633E20D099474097900F7A369D43408FA67A32FFC44740D12346CF2DDE43408FA67A32FFC44740D12346CF2DDE4340E9633E20D099474097900F7A369D4340E9633E20D0994740
351	Морозовский район	\N	23	41.463476	42.183008000000001	48.550480999999998	47.801200000000001	0103000020E610000001000000050000008E3D7B2E53BB444011C7BAB88DE647408E3D7B2E53BB4440E10852297646484004745FCE6C174540E10852297646484004745FCE6C17454011C7BAB88DE647408E3D7B2E53BB444011C7BAB88DE64740
167	Милютинский район	\N	23	41.273328999999997	42.028336000000003	48.992640999999999	48.463963999999997	0103000020E610000001000000050000003106D671FCA24440BB421F2C633B48403106D671FCA2444099D53BDC0E7F484055A69883A003454099D53BDC0E7F484055A69883A0034540BB421F2C633B48403106D671FCA24440BB421F2C633B4840
1388	Миллеровский район	\N	23	39.663755000000002	41.040889999999997	49.283524	48.766871999999999	0103000020E610000001000000050000003BC780ECF5D44340EB1B98DC286248403BC780ECF5D44340C8D0B1834AA44840E15D2EE23B854440C8D0B1834AA44840E15D2EE23B854440EB1B98DC286248403BC780ECF5D44340EB1B98DC28624840
431	Матвеево-Курганский район	\N	23	38.285218	39.229779000000001	47.739544000000002	47.399830999999999	0103000020E61000000100000005000000821DFF0582244340A77686A92DB34740821DFF0582244340FDF9B660A9DE47405F27F565699D4340FDF9B660A9DE47405F27F565699D4340A77686A92DB34740821DFF0582244340A77686A92DB34740
406	Мартыновский район	\N	23	41.139021999999997	42.137742000000003	47.462287000000003	47.098942000000001	0103000020E6100000010000000500000056B60F79CB914440B519A721AA8C474056B60F79CB914440D82E6D382CBB474090A4A487A1114540D82E6D382CBB474090A4A487A1114540B519A721AA8C474056B60F79CB914440B519A721AA8C4740
141	Куйбышевский район	\N	23	38.783729000000001	39.402408000000001	47.876334	47.625540000000001	0103000020E61000000100000005000000A1F65B3B51644340802BD9B111D04740A1F65B3B51644340BA2F67B62BF047400BD3F71A82B34340BA2F67B62BF047400BD3F71A82B34340802BD9B111D04740A1F65B3B51644340802BD9B111D04740
1337	Красносулинский район	\N	23	39.711841999999997	40.609977000000001	48.190980000000003	47.727884000000003	0103000020E61000000100000005000000A9F57EA31DDB43400EA48B4D2BDD4740A9F57EA31DDB434055185B0872184840F627F1B9134E444055185B0872184840F627F1B9134E44400EA48B4D2BDD4740A9F57EA31DDB43400EA48B4D2BDD4740
182	Константиновский район	\N	23	40.880738999999998	41.789788999999999	47.987836999999999	47.536172999999998	0103000020E61000000100000005000000E7A7380EBC704440C5FF1D51A1C44740E7A7380EBC704440AE635C7171FE4740CADE52CE17E54440AE635C7171FE4740CADE52CE17E54440C5FF1D51A1C44740E7A7380EBC704440C5FF1D51A1C44740
1731	Кашарский район	\N	23	40.846091000000001	41.936222999999998	49.387560000000001	48.691898000000002	0103000020E610000001000000050000005038BBB54C6C44407B15191D905848405038BBB54C6C44406F9EEA909BB14840AA61BF27D6F744406F9EEA909BB14840AA61BF27D6F744407B15191D905848405038BBB54C6C44407B15191D90584840
1602	Каменский район	\N	23	39.845771999999997	40.861460999999998	48.639951000000003	48.097757000000001	0103000020E61000000100000005000000AEEFC34142EC434040FA264D830C4840AEEFC34142EC4340710514EAE9514840C5E3A25A446E4440710514EAE9514840C5E3A25A446E444040FA264D830C4840AEEFC34142EC434040FA264D830C4840
1052	Кагальницкий район	\N	23	39.702489999999997	40.390151000000003	47.132123999999997	46.728574999999999	0103000020E610000001000000050000002EE23B31EBD9434073D712F2415D47402EE23B31EBD9434023827170E990474038C0CC77F031444023827170E990474038C0CC77F031444073D712F2415D47402EE23B31EBD9434073D712F2415D4740
66	Зимовниковский район	\N	23	41.960334000000003	43.336965999999997	47.469591000000001	46.600470999999999	0103000020E61000000100000005000000529E7939ECFA44402499D53BDC4C4740529E7939ECFA44407BBFD18E1BBC474095EEAEB321AB45407BBFD18E1BBC474095EEAEB321AB45402499D53BDC4C4740529E7939ECFA44402499D53BDC4C4740
1220	Зерноградский район	\N	23	40.057343000000003	41.129652999999998	47.132435999999998	46.448228999999998	0103000020E61000000100000005000000C8D3F20357074440340F60915F394740C8D3F203570744401268B0A9F3904740056A3178989044401268B0A9F3904740056A317898904440340F60915F394740C8D3F20357074440340F60915F394740
1766	Заветинский район	\N	23	43.266483999999998	44.325786999999998	47.550856000000003	46.724634000000002	0103000020E610000001000000050000002174D0251CA24540EBC891CEC05C47402174D0251CA2454017670C7382C64740213B6F63B329464017670C7382C64740213B6F63B3294640EBC891CEC05C47402174D0251CA24540EBC891CEC05C4740
1286	Егорлыкский район	\N	23	40.248325000000001	40.873156999999999	46.715614000000002	46.271866000000003	0103000020E61000000100000005000000BDE3141DC91F44407A724D81CC224740BDE3141DC91F4440A647533D995B474001A3CB9BC36F4440A647533D995B474001A3CB9BC36F44407A724D81CC224740BDE3141DC91F44407A724D81CC224740
480	Дубовский район	\N	23	42.280520000000003	43.490397999999999	47.775942999999998	46.851401000000003	0103000020E61000000100000005000000DDEF5014E82345400F643DB5FA6C4740DDEF5014E8234540B247A81952E347400C03965CC5BE4540B247A81952E347400C03965CC5BE45400F643DB5FA6C4740DDEF5014E82345400F643DB5FA6C4740
82	Волгодонской район	\N	23	41.326132000000001	42.361521000000003	47.612037999999998	47.311793000000002	0103000020E61000000100000005000000EC1681B1BEA94440950F41D5E8A74740EC1681B1BEA9444062F4DC4257CE47409BE8F351462E454062F4DC4257CE47409BE8F351462E4540950F41D5E8A74740EC1681B1BEA94440950F41D5E8A74740
1846	Веселовский район	\N	23	40.494256	41.168109999999999	47.361538000000003	46.933883000000002	0103000020E6100000010000000500000007EDD5C7433F44402BA5677A8977474007EDD5C7433F444071218FE046AE4740B610E4A08495444071218FE046AE4740B610E4A0849544402BA5677A8977474007EDD5C7433F44402BA5677A89774740
1585	Верхнедонской район	\N	23	40.666229999999999	41.618273000000002	50.214013000000001	49.382446000000002	0103000020E610000001000000050000009ACE4E0647554440363E93FDF3B048409ACE4E06475544409DF529C7641B4940FA7FD59123CF44409DF529C7641B4940FA7FD59123CF4440363E93FDF3B048409ACE4E0647554440363E93FDF3B04840
1522	Боковский район	\N	23	41.197664000000003	42.107146	49.5062	49.059199999999997	0103000020E610000001000000050000005CCCCF0D4D9944402BF697DD938748405CCCCF0D4D9944401B9E5E29CBC04840D8F2CAF5B60D45401B9E5E29CBC04840D8F2CAF5B60D45402BF697DD938748405CCCCF0D4D9944402BF697DD93874840
7337	Белокалитвинский район	\N	23	38.221195000000002	44.325786999999998	50.214013000000001	45.951694000000003	0103000020E61000000100000005000000F584251E501C434054E6E61BD1F94640F584251E501C43409DF529C7641B4940213B6F63B32946409DF529C7641B4940213B6F63B329464054E6E61BD1F94640F584251E501C434054E6E61BD1F94640
855	Белокалитвенский район	\N	23	40.551873999999998	41.350251999999998	48.682910999999997	47.839599999999997	0103000020E61000000100000005000000A0C1A6CEA34644405DDC460378EB4740A0C1A6CEA3464440118AADA069574840E6ADBA0ED5AC4440118AADA069574840E6ADBA0ED5AC44405DDC460378EB4740A0C1A6CEA34644405DDC460378EB4740
1141	Багаевский район	\N	23	40.085172999999998	40.738050000000001	47.452795000000002	47.094285999999997	0103000020E6100000010000000500000048C0E8F2E60A44403E3C4B90118C474048C0E8F2E60A44406B65C22FF5B947400A68226C785E44406B65C22FF5B947400A68226C785E44403E3C4B90118C474048C0E8F2E60A44403E3C4B90118C4740
88	Аксайский район	\N	23	39.696750000000002	40.233583000000003	47.526961999999997	47.004052000000001	0103000020E6100000010000000500000077BE9F1A2FD94340E0BDA3C68480474077BE9F1A2FD943400C1EA67D73C3474067F3380CE61D44400C1EA67D73C3474067F3380CE61D4440E0BDA3C68480474077BE9F1A2FD94340E0BDA3C684804740
779	Азовский район	\N	23	38.687412000000002	39.801727	47.238801000000002	46.560704999999999	0103000020E610000001000000050000006170CD1DFD57434012DA722EC54747406170CD1DFD57434045A0FA07919E4740FCA886FD9EE6434045A0FA07919E4740FCA886FD9EE6434012DA722EC54747406170CD1DFD57434012DA722EC5474740
479	Славянский район	\N	20	38.928134	38.938428000000002	45.067734999999999	45.065691999999999	0103000020E6100000010000000500000020274C18CD764340EECD6F986888464020274C18CD764340B4E55C8AAB8846404AD3A0681E784340B4E55C8AAB8846404AD3A0681E784340EECD6F986888464020274C18CD764340EECD6F9868884640
842	городской округ Сочи	\N	20	39.144672	40.662725999999999	44.123750000000001	43.459992999999997	0103000020E61000000100000005000000CE52B29C84924340C8B1F50CE1BA4540CE52B29C84924340A4703D0AD70F4640BD1AA034D4544440A4703D0AD70F4640BD1AA034D4544440C8B1F50CE1BA4540CE52B29C84924340C8B1F50CE1BA4540
1844	городской округ Новороссийск	\N	20	37.424219000000001	37.916550000000001	45.010274000000003	44.648502999999998	0103000020E61000000100000005000000C1ABE5CE4CB64240CF2D742502534640C1ABE5CE4CB64240E3FF8EA8508146400C93A98251F54240E3FF8EA8508146400C93A98251F54240CF2D742502534640C1ABE5CE4CB64240CF2D742502534640
1783	городской округ Геленджик	\N	20	37.863225999999997	38.687026000000003	44.767040999999999	44.333146999999997	0103000020E61000000100000005000000488787307EEE424058E1968FA42A4640488787307EEE424077D844662E62464038C0CC77F057434077D844662E62464038C0CC77F057434058E1968FA42A4640488787307EEE424058E1968FA42A4640
776	Щербиновский район	\N	20	38.389871999999997	38.934897999999997	46.881073000000001	46.374786	0103000020E6100000010000000500000024D06053E7314340D47FD6FCF82F474024D06053E7314340BE310400C7704740438CD7BCAA774340BE310400C7704740438CD7BCAA774340D47FD6FCF82F474024D06053E7314340D47FD6FCF82F4740
421	Усть-Лабинский район	\N	20	39.363331000000002	40.132567999999999	45.459978999999997	45.081713000000001	0103000020E61000000100000005000000BE4F55A181AE43403B545392758A4640BE4F55A181AE434063EC8497E0BA4640813FFCFCF710444063EC8497E0BA4640813FFCFCF71044403B545392758A4640BE4F55A181AE43403B545392758A4640
251	Успенский район	\N	20	41.159863000000001	41.653962999999997	45.048780999999998	44.607691000000003	0103000020E61000000100000005000000946B0A64769444406A8995D1C84D4640946B0A647694444045D5AF743E864640A3E5400FB5D3444045D5AF743E864640A3E5400FB5D344406A8995D1C84D4640946B0A64769444406A8995D1C84D4640
541	Туапсинский район	\N	20	38.604399000000001	39.581513999999999	44.514412	44.029049999999998	0103000020E61000000100000005000000185E49F25C4D434072F90FE9B7034640185E49F25C4D4340C1559E40D84146404415FE0C6FCA4340C1559E40D84146404415FE0C6FCA434072F90FE9B7034640185E49F25C4D434072F90FE9B7034640
7087	Туапсинский	\N	20	38.604399000000001	39.581513999999999	44.514412	44.029049999999998	0103000020E61000000100000005000000185E49F25C4D434072F90FE9B7034640185E49F25C4D4340C1559E40D84146404415FE0C6FCA4340C1559E40D84146404415FE0C6FCA434072F90FE9B7034640185E49F25C4D434072F90FE9B7034640
1034	Тихорецкий район	\N	20	39.815911999999997	40.565761999999999	46.090192999999999	45.566361000000001	0103000020E61000000100000005000000FC34EECD6FE843406C5D6A847EC84640FC34EECD6FE8434000AAB8718B0B4740E7A8A3E36A48444000AAB8718B0B4740E7A8A3E36A4844406C5D6A847EC84640FC34EECD6FE843406C5D6A847EC84640
1377	Тимашевский район	\N	20	38.560048999999999	39.396946	45.773119000000001	45.363337999999999	0103000020E61000000100000005000000299485AFAF47434070B20DDC81AE4640299485AFAF47434047753A90F5E2464096236420CFB2434047753A90F5E2464096236420CFB2434070B20DDC81AE4640299485AFAF47434070B20DDC81AE4640
699	Темрюкский район	\N	20	36.597921999999997	37.711114000000002	45.450723000000004	45.078530999999998	0103000020E610000001000000050000008AC745B5884C4240705CC64D0D8A46408AC745B5884C42400B47904AB1B9464027DD96C805DB42400B47904AB1B9464027DD96C805DB4240705CC64D0D8A46408AC745B5884C4240705CC64D0D8A4640
1525	Тбилисский район	\N	20	39.909139000000003	40.401873999999999	45.595984000000001	45.176715999999999	0103000020E610000001000000050000005342B0AA5EF44340085740A19E9646405342B0AA5EF443403A78263449CC46406D8E739B703344403A78263449CC46406D8E739B70334440085740A19E9646405342B0AA5EF44340085740A19E964640
1478	Староминский район	\N	20	38.742334999999997	39.328305999999998	46.682369999999999	46.318193999999998	0103000020E610000001000000050000008CD651D5045F434047E4BB94BA2847408CD651D5045F4340C1E270E657574740508A56EE05AA4340C1E270E657574740508A56EE05AA434047E4BB94BA2847408CD651D5045F434047E4BB94BA284740
85	Северский район	\N	20	38.386234000000002	39.054895000000002	45.085430000000002	44.489049000000001	0103000020E61000000100000005000000384D9F1D703143401D925A28993E4640384D9F1D70314340740CC85EEF8A464062DBA2CC06874340740CC85EEF8A464062DBA2CC068743401D925A28993E4640384D9F1D703143401D925A28993E4640
1082	Приморско-Ахтарский район	\N	20	37.768633000000001	38.719876999999997	46.263792000000002	45.666791000000003	0103000020E610000001000000050000002DD0EE9062E242403222516859D546402DD0EE9062E242402579AEEFC32147404012F6ED245C43402579AEEFC32147404012F6ED245C43403222516859D546402DD0EE9062E242403222516859D54640
1079	Павловский район	\N	20	39.495195000000002	40.361369000000003	46.284804000000001	45.880980999999998	0103000020E610000001000000050000004512BD8C62BF4340DDB243FCC3F046404512BD8C62BF43408FE21C7574244740E564E256412E44408FE21C7574244740E564E256412E4440DDB243FCC3F046404512BD8C62BF4340DDB243FCC3F04640
1027	Отрадненский район	\N	20	41.050367000000001	41.743183999999999	44.639223000000001	43.976140000000001	0103000020E6100000010000000500000019E6046D72864440A228D027F2FC454019E6046D72864440EEEC2B0FD25146408A743FA720DF4440EEEC2B0FD25146408A743FA720DF4440A228D027F2FC454019E6046D72864440A228D027F2FC4540
1132	Новопокровский район	\N	20	40.235585999999998	40.977558999999999	46.287021000000003	45.652245999999998	0103000020E610000001000000050000009EB29AAE271E4440317903CC7CD346409EB29AAE271E4440F321A81ABD2447408A743FA7207D4440F321A81ABD2447408A743FA7207D4440317903CC7CD346409EB29AAE271E4440317903CC7CD34640
937	Новокубанский район	\N	20	40.734520000000003	41.431783000000003	45.263959999999997	44.519610999999998	0103000020E61000000100000005000000042159C0045E444028D2FD9C82424640042159C0045E4440E0B9F770C9A1464001FC53AA44B74440E0B9F770C9A1464001FC53AA44B7444028D2FD9C82424640042159C0045E444028D2FD9C82424640
1395	Мостовский район	\N	20	40.338892999999999	40.933128000000004	44.762593000000003	43.532556999999997	0103000020E61000000100000005000000F2EB87D8602B4440C020E9D32AC44540F2EB87D8602B44404B94BDA59C614640AF7D01BD707744404B94BDA59C614640AF7D01BD70774440C020E9D32AC44540F2EB87D8602B4440C020E9D32AC44540
1358	Ленинградский район	\N	20	39.077998999999998	39.745761999999999	46.461168000000001	45.992753	0103000020E61000000100000005000000730F09DFFB894340C100C28712FF4640730F09DFFB8943401AFB928D073B4740BE4C142175DF43401AFB928D073B4740BE4C142175DF4340C100C28712FF4640730F09DFFB894340C100C28712FF4640
7075	Лазаревский район	\N	20	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
1002	Лабинский район	\N	20	40.653464999999997	41.230758000000002	44.793861999999997	44.086686	0103000020E61000000100000005000000520ABABDA4534440B282DF86180B4640520ABABDA4534440C1C41F459D6546402BA5677A899D4440C1C41F459D6546402BA5677A899D4440B282DF86180B4640520ABABDA4534440B282DF86180B4640
1015	Кущевский район	\N	20	39.230407999999997	40.146104999999999	46.819085000000001	46.311957	0103000020E610000001000000050000004E5E64027E9D43400F61FC34EE2747404E5E64027E9D434074D2FBC6D76847401B649291B312444074D2FBC6D76847401B649291B31244400F61FC34EE2747404E5E64027E9D43400F61FC34EE274740
821	Курганинский район	\N	20	40.087615999999997	41.021073000000001	45.220412000000003	44.690497000000001	0103000020E610000001000000050000009C4D4700370B4440397EA834625846409C4D4700370B4440AFD2DD75369C464010EA2285B2824440AFD2DD75369C464010EA2285B2824440397EA834625846409C4D4700370B4440397EA83462584640
433	Крымский район	\N	20	37.449767000000001	38.216011999999999	45.189314000000003	44.736687000000003	0103000020E61000000100000005000000F7E80DF791B94240B63176C24B5E4640F7E80DF791B942406556EF703B98464093C5FD47A61B43406556EF703B98464093C5FD47A61B4340B63176C24B5E4640F7E80DF791B94240B63176C24B5E4640
98	Крыловский район	\N	20	39.674650999999997	40.434195000000003	46.595480000000002	46.207191000000002	0103000020E610000001000000050000005A9BC6F65AD643404583143C851A47405A9BC6F65AD6434007B64AB0384C47401A8BA6B39337444007B64AB0384C47401A8BA6B3933744404583143C851A47405A9BC6F65AD643404583143C851A4740
1322	Красноармейский район	\N	20	38.025990999999998	38.803384000000001	45.597591999999999	45.057772	0103000020E61000000100000005000000C37E4FAC53034340F04FA91265874640C37E4FAC53034340F52C08E57DCC464099107349D5664340F52C08E57DCC464099107349D5664340F04FA91265874640C37E4FAC53034340F04FA91265874640
6957	Кошехаблинский район	\N	20	40.266092999999998	40.768467000000001	45.042718000000001	44.463605000000001	0103000020E61000000100000005000000E658DE550F2244408CA19C68573B4640E658DE550F224440AB798EC87785464012876C205D624440AB798EC87785464012876C205D6244408CA19C68573B4640E658DE550F2244408CA19C68573B4640
1193	Кореновский район	\N	20	39.115566999999999	39.669226000000002	45.814667999999998	45.306694999999998	0103000020E6100000010000000500000098BF42E6CA8E4340616C21C841A7464098BF42E6CA8E4340828C800A47E8464003D19332A9D54340828C800A47E8464003D19332A9D54340616C21C841A7464098BF42E6CA8E4340616C21C841A74640
5147	Кировский район	\N	20	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
7084	Карасунский	\N	20	39.079616000000001	39.081583999999999	45.022576999999998	45.021762000000003	0103000020E61000000100000005000000821E6ADB308A4340D525E318C9824640821E6ADB308A434026529ACDE38246403DF03158718A434026529ACDE38246403DF03158718A4340D525E318C9824640821E6ADB308A4340D525E318C9824640
1033	Каневский район	\N	20	38.508324000000002	39.522091000000003	46.395363000000003	45.880440999999998	0103000020E61000000100000005000000CEE2C5C2104143405D876A4AB2F04640CEE2C5C210414340348639419B3247409A44BDE0D3C24340348639419B3247409A44BDE0D3C243405D876A4AB2F04640CEE2C5C2104143405D876A4AB2F04640
977	Калининский район	\N	20	37.930751999999998	38.865692000000003	45.790604000000002	45.270634000000001	0103000020E61000000100000005000000E257ACE122F74240C4978922A4A24640E257ACE122F742401C0B0A8332E546405534D6FECE6E43401C0B0A8332E546405534D6FECE6E4340C4978922A4A24640E257ACE122F74240C4978922A4A24640
91	Кавказский район	\N	20	40.218544999999999	40.955083000000002	45.694766999999999	45.354742999999999	0103000020E6100000010000000500000027DA5548F91B444012BEF73768AD464027DA5548F91B444086AB0320EED8464098FBE428407A444086AB0320EED8464098FBE428407A444012BEF73768AD464027DA5548F91B444012BEF73768AD4640
301	Ейский район	\N	20	37.695096999999997	38.58822	46.743633000000003	46.139491	0103000020E610000001000000050000001B4641F0F8D842400D8B51D7DA1147401B4641F0F8D84240FA9CBB5D2F5F4740336DFFCA4A4B4340FA9CBB5D2F5F4740336DFFCA4A4B43400D8B51D7DA1147401B4641F0F8D842400D8B51D7DA114740
2678	Дубовский район	\N	20	36.597921999999997	41.743183999999999	46.881073000000001	43.385041000000001	0103000020E610000001000000050000008AC745B5884C4240404F030649B145408AC745B5884C4240BE310400C77047408A743FA720DF4440BE310400C77047408A743FA720DF4440404F030649B145408AC745B5884C4240404F030649B14540
175	Динской район	\N	20	38.640825	39.503145000000004	45.42597	45.077900999999997	0103000020E61000000100000005000000C7BAB88D06524340B0A9F3A8F8894640C7BAB88D06524340DF89592F86B64640AE122C0E67C04340DF89592F86B64640AE122C0E67C04340B0A9F3A8F8894640C7BAB88D06524340B0A9F3A8F8894640
1188	Гулькевичский район	\N	20	40.264350999999998	41.035617000000002	45.444527000000001	45.058148000000003	0103000020E610000001000000050000001BD5E940D6214440F629C764718746401BD5E940D62144403198BF42E6B8464040170D198F8444403198BF42E6B8464040170D198F844440F629C764718746401BD5E940D6214440F629C76471874640
7074	Горячий Ключ	\N	20	38.878456999999997	39.607726999999997	44.845579999999998	44.386805000000003	0103000020E610000001000000050000009CF86A4771704340F37684D3823146409CF86A47717043406A1327F73B6C4640B6F292FFC9CD43406A1327F73B6C4640B6F292FFC9CD4340F37684D3823146409CF86A4771704340F37684D382314640
1739	Выселковский район	\N	20	39.520510000000002	40.168716000000003	45.909495	45.419049999999999	0103000020E61000000100000005000000D89E5912A0C24340C4B12E6EA3B54640D89E5912A0C24340117008556AF44640EE27637C98154440117008556AF44640EE27637C98154440C4B12E6EA3B54640D89E5912A0C24340C4B12E6EA3B54640
1198	Брюховецкий район	\N	20	38.595531999999999	39.523806	46.004309999999997	45.706361999999999	0103000020E6100000010000000500000059DC7F643A4C43408E91EC116ADA464059DC7F643A4C4340DB85E63A8D0047406BB933130CC34340DB85E63A8D0047406BB933130CC343408E91EC116ADA464059DC7F643A4C43408E91EC116ADA4640
440	Большой Сочи Центральный район	\N	20	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
148	Большой Сочи Хостинский район	\N	20	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
1078	Большой Сочи Лазаревский район	\N	20	39.882243000000003	40.043723999999997	43.565396	43.385041000000001	0103000020E61000000100000005000000FE0FB056EDF04340404F030649B14540FE0FB056EDF0434005A568E55EC8454070067FBF9805444005A568E55EC8454070067FBF98054440404F030649B14540FE0FB056EDF04340404F030649B14540
7073	Большой Сочи Адлерский район	\N	20	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
164	Большой Сочи Адлеровский район	\N	20	39.148372999999999	39.735539000000003	44.033127	43.640534000000002	0103000020E61000000100000005000000014EEFE2FD924340F0FCA204FDD14540014EEFE2FD924340ABCE6A813D0446405EF7562426DE4340ABCE6A813D0446405EF7562426DE4340F0FCA204FDD14540014EEFE2FD924340F0FCA204FDD14540
1205	Белореченский район	\N	20	39.470436999999997	40.030106000000004	45.057785000000003	44.512644000000002	0103000020E6100000010000000500000007EA944737BC4340CD3E8F519E41464007EA944737BC43408599B67F65874640EAB46E83DA0344408599B67F65874640EAB46E83DA034440CD3E8F519E41464007EA944737BC4340CD3E8F519E414640
1501	Белоглинский район	\N	20	40.529739999999997	41.273428000000003	46.298608999999999	45.674473999999996	0103000020E6100000010000000500000007B13385CE4344404B00FE2955D6464007B13385CE43444048A5D8D138264740C5E74EB0FFA2444048A5D8D138264740C5E74EB0FFA244404B00FE2955D6464007B13385CE4344404B00FE2955D64640
722	Апшеронский район	\N	20	39.251455	40.096150000000002	44.665058000000002	43.932341999999998	0103000020E6100000010000000500000035B56CAD2FA04340F7578FFB56F7454035B56CAD2FA04340BAF8DB9E2055464055C1A8A44E0C4440BAF8DB9E2055464055C1A8A44E0C4440F7578FFB56F7454035B56CAD2FA04340F7578FFB56F74540
1018	Анапский район	\N	20	36.882939	37.655760000000001	45.199342999999999	44.704247000000002	0103000020E6100000010000000500000075AE2825047142402FA704C4245A464075AE282504714240E0D7481284994640320395F1EFD34240E0D7481284994640320395F1EFD342402FA704C4245A464075AE2825047142402FA704C4245A4640
755	Абинский район	\N	20	37.978192	38.588912000000001	45.189314000000003	44.583634000000004	0103000020E61000000100000005000000BB9A3C6535FD4240B66AD784B44A4640BB9A3C6535FD42406556EF703B984640691CEA77614B43406556EF703B984640691CEA77614B4340B66AD784B44A4640BB9A3C6535FD4240B66AD784B44A4640
7114	Михайловка городской округ	\N	22	43.191403000000001	43.300539000000001	50.100273000000001	50.035553	0103000020E610000001000000050000009BADBCE47F98454029232E008D0449409BADBCE47F984540FED5E3BED50C49401616DC0F78A64540FED5E3BED50C49401616DC0F78A6454029232E008D0449409BADBCE47F98454029232E008D044940
6895	Камышин городской округ	\N	22	45.331432999999997	45.471040000000002	50.143768000000001	50.053747000000001	0103000020E6100000010000000500000057E883656CAA46400AA1832EE106494057E883656CAA46400D1B65FD66124940CE8DE9094BBC46400D1B65FD66124940CE8DE9094BBC46400AA1832EE106494057E883656CAA46400AA1832EE1064940
1170	Чернышковский район	\N	22	42.018211999999998	42.993890999999998	48.520992	47.803959999999996	0103000020E61000000100000005000000873254C55402454065A54929E8E64740873254C55402454023BDA8DDAF424840F564FED1377F454023BDA8DDAF424840F564FED1377F454065A54929E8E64740873254C55402454065A54929E8E64740
1121	Фроловский район	\N	22	43.235295000000001	44.268293999999997	50.2181	49.486494	0103000020E61000000100000005000000C7F484251E9E4540A1D9756F45BE4840C7F484251E9E4540F9A067B3EA1B494044DB317557224640F9A067B3EA1B494044DB317557224640A1D9756F45BE4840C7F484251E9E4540A1D9756F45BE4840
7113	Фролово городской округ	\N	22	43.581226999999998	43.688296999999999	49.804324000000001	49.735373000000003	0103000020E61000000100000005000000AE4676A565CA454043AED4B320DE4840AE4676A565CA4540A7B1BD16F4E64840AB77B81D1AD84540A7B1BD16F4E64840AB77B81D1AD8454043AED4B320DE4840AE4676A565CA454043AED4B320DE4840
1385	Урюпинский район	\N	22	41.170481000000002	42.415492	51.196699000000002	50.396897000000003	0103000020E6100000010000000500000071CB4752D2954440B5705985CD32494071CB4752D2954440F513CE6E2D994940F4DF83D72E354540F513CE6E2D994940F4DF83D72E354540B5705985CD32494071CB4752D2954440B5705985CD324940
940	Суровикинский район	\N	22	42.48433	43.528092000000001	48.967398000000003	48.136496000000001	0103000020E61000000100000005000000603C8386FE3D4540750470B378114840603C8386FE3D4540A01B9AB2D37B4840BEA3C68498C34540A01B9AB2D37B4840BEA3C68498C34540750470B378114840603C8386FE3D4540750470B378114840
871	Старополтавский район	\N	22	45.677185000000001	47.432510999999998	50.758633000000003	50.136296999999999	0103000020E61000000100000005000000BF2B82FFADD646407EC51A2E72114940BF2B82FFADD646404C55DAE21A61494083143C855CB747404C55DAE21A61494083143C855CB747407EC51A2E72114940BF2B82FFADD646407EC51A2E72114940
629	Среднеахтубинский район	\N	22	44.508296999999999	45.411391999999999	49.146594999999998	48.521296	0103000020E61000000100000005000000D4D347E00F4146408FC4CBD3B9424840D4D347E00F414640E960FD9FC392484003EB387EA8B44640E960FD9FC392484003EB387EA8B446408FC4CBD3B9424840D4D347E00F4146408FC4CBD3B9424840
313	Серафимовичский район	\N	22	42.022101999999997	43.456595	49.893498000000001	49.104954999999997	0103000020E610000001000000050000008D96033DD40245409D465A2A6F8D48408D96033DD40245404D8578245EF24840314278B471BA45404D8578245EF24840314278B471BA45409D465A2A6F8D48408D96033DD40245409D465A2A6F8D4840
6	Светлоярский район	\N	22	43.856299999999997	45.080713000000003	48.706490000000002	48.049607000000002	0103000020E610000001000000050000004BC8073D9BED45408B53AD85590648404BC8073D9BED4540BC79AA436E5A484058AEB7CD548A4640BC79AA436E5A484058AEB7CD548A46408B53AD85590648404BC8073D9BED45408B53AD8559064840
1917	Руднянский район	\N	22	44.023395999999998	44.715494	51.086098	50.519098	0103000020E61000000100000005000000B96DDFA3FE024640A2B5A2CD71424940B96DDFA3FE02464021205F42058B4940FB3DB14E955B464021205F42058B4940FB3DB14E955B4640A2B5A2CD71424940B96DDFA3FE024640A2B5A2CD71424940
862	Палласовский район	\N	22	45.619010000000003	47.352184000000001	50.316496000000001	48.613343999999998	0103000020E61000000100000005000000D0F23CB83BCF46405299620E824E4840D0F23CB83BCF46404CA8E0F0822849405516855D14AD47404CA8E0F0822849405516855D14AD47405299620E824E4840D0F23CB83BCF46405299620E824E4840
1835	Ольховский район	\N	22	44.028390000000002	45.173696999999997	50.159699000000003	49.478392999999997	0103000020E6100000010000000500000048C49448A203464052D158FB3BBD484048C49448A20346401A1A4F0471144940E7340BB43B9646401A1A4F0471144940E7340BB43B96464052D158FB3BBD484048C49448A203464052D158FB3BBD4840
1226	Октябрьский район	\N	22	42.957293	44.425454999999999	48.348396000000001	47.718701000000003	0103000020E6100000010000000500000049D8B793887A45401F4DF564FEDB474049D8B793887A45405307793D982C4840B875374F753646405307793D982C4840B875374F753646401F4DF564FEDB474049D8B793887A45401F4DF564FEDB4740
1775	Новониколаевский район	\N	22	42.172992000000001	43.167400000000001	51.247807000000002	50.709296000000002	0103000020E610000001000000050000001D3C139A2416454081971936CA5A49401D3C139A24164540255CC823B89F4940DAACFA5C6D954540255CC823B89F4940DAACFA5C6D95454081971936CA5A49401D3C139A2416454081971936CA5A4940
1723	Новоаннинский район	\N	22	42.13449	43.449291000000002	50.867888000000001	50.214894999999999	0103000020E61000000100000005000000CCD1E3F7361145407689EAAD811B4940CCD1E3F736114540A14B38F4166F49408EB1135E82B94540A14B38F4166F49408EB1135E82B945407689EAAD811B4940CCD1E3F7361145407689EAAD811B4940
1688	Николаевский район	\N	22	45.374299999999998	46.520200000000003	50.329493999999997	49.710493999999997	0103000020E610000001000000050000004772F90FE9AF46408A00A777F1DA48404772F90FE9AF4640361D01DC2C2A49408AB0E1E995424740361D01DC2C2A49408AB0E1E9954247408A00A777F1DA48404772F90FE9AF46408A00A777F1DA4840
1657	Нехаевский район	\N	22	41.383023000000001	42.031094000000003	50.685197000000002	49.952330000000003	0103000020E61000000100000005000000D34ECDE506B14440F67F0EF3E5F94840D34ECDE506B144409E280989B4574940098D60E3FA0345409E280989B4574940098D60E3FA034540F67F0EF3E5F94840D34ECDE506B14440F67F0EF3E5F94840
1310	Михайловский район	\N	22	42.650294000000002	43.754798999999998	50.588797999999997	49.820798000000003	0103000020E610000001000000050000007C6473D53C534540A54FABE80FE948407C6473D53C534540A0F99CBB5D4B4940D906EE409DE04540A0F99CBB5D4B4940D906EE409DE04540A54FABE80FE948407C6473D53C534540A54FABE80FE94840
1151	Ленинский район	\N	22	44.928395000000002	45.670493	49.302097000000003	48.431196	0103000020E610000001000000050000008D62B9A5D57646404015376E313748408D62B9A5D5764640209C4F1DABA648403599F1B6D2D54640209C4F1DABA648403599F1B6D2D546404015376E313748408D62B9A5D57646404015376E31374840
1624	Кумылженский район	\N	22	41.831102000000001	42.977595000000001	50.135095999999997	49.575794000000002	0103000020E61000000100000005000000F2D1E28C61EA4440D49D279EB3C94840F2D1E28C61EA444003E962D34A114940D7DD3CD5217D454003E962D34A114940D7DD3CD5217D4540D49D279EB3C94840F2D1E28C61EA4440D49D279EB3C94840
1459	Котовский район	\N	22	44.386691999999996	45.218891999999997	50.658298000000002	50.069597999999999	0103000020E61000000100000005000000FACF9A1F7F314640FAEE5696E8084940FACF9A1F7F314640D882DE1B4354494092AD2EA7049C4640D882DE1B4354494092AD2EA7049C4640FAEE5696E8084940FACF9A1F7F314640FAEE5696E8084940
1259	Котельниковский район	\N	22	42.746161999999998	43.748798999999998	48.037896000000003	47.444178000000001	0103000020E610000001000000050000004CC2853C825F454025CD1FD3DAB847404CC2853C825F45401A53B0C6D9044840852348A5D8DF45401A53B0C6D9044840852348A5D8DF454025CD1FD3DAB847404CC2853C825F454025CD1FD3DAB84740
1353	Клетский район	\N	22	42.352161000000002	43.610799999999998	49.516798999999999	48.853200999999999	0103000020E610000001000000050000009DF6949C132D45400EF5BBB0356D48409DF6949C132D454081CD397826C24840CA32C4B12ECE454081CD397826C24840CA32C4B12ECE45400EF5BBB0356D48409DF6949C132D45400EF5BBB0356D4840
5103	Кишертский район	\N	22	41.131593000000002	47.432187999999996	51.247875000000001	47.444153999999997	0103000020E61000000100000005000000F7B0170AD89044409C31CC09DAB84740F7B0170AD89044407D3F355EBA9F4940A0DCB6EF51B747407D3F355EBA9F4940A0DCB6EF51B747409C31CC09DAB84740F7B0170AD89044409C31CC09DAB84740
1306	Киквидзенский район	\N	22	42.812296000000003	43.510097999999999	51.134678999999998	50.464593999999998	0103000020E61000000100000005000000F855B950F96745407BF5F1D0773B4940F855B950F96745409F3A56293D914940A4E029E44AC145409F3A56293D914940A4E029E44AC145407BF5F1D0773B4940F855B950F96745407BF5F1D0773B4940
1024	Камышинский район	\N	22	44.787196999999999	45.896293	50.612558999999997	49.751992999999999	0103000020E6100000010000000500000031410DDFC264464014E97E4E41E0484031410DDFC26446406BEF5355684E49401E51A1BAB9F246406BEF5355684E49401E51A1BAB9F2464014E97E4E41E0484031410DDFC264464014E97E4E41E04840
1048	Калачевский район	\N	22	43.183596999999999	44.190195000000003	49.169896999999999	48.201695000000001	0103000020E610000001000000050000006552431B8097454024624A24D11948406552431B809745402158552FBF9548406E6E4C4F581846402158552FBF9548406E6E4C4F5818464024624A24D11948406552431B8097454024624A24D1194840
917	Иловлинский район	\N	22	43.394395000000003	44.520496000000001	49.659198000000004	48.936101000000001	0103000020E610000001000000050000005C5A0D897BB245405F605628D27748405C5A0D897BB2454058CB9D9960D4484073D9E89C9F42464058CB9D9960D4484073D9E89C9F4246405F605628D27748405C5A0D897BB245405F605628D2774840
471	Жирновский район	\N	22	44.209482000000001	45.323456	51.210666000000003	50.563400000000001	0103000020E61000000100000005000000E38C614ED01A46408048BF7D1D484940E38C614ED01A464088307E1AF79A4940F5D8960167A9464088307E1AF79A4940F5D8960167A946408048BF7D1D484940E38C614ED01A46408048BF7D1D484940
599	Еланский район	\N	22	43.317597999999997	44.269193000000001	51.160218	50.472299999999997	0103000020E6100000010000000500000033A31F0DA7A845404DF38E53743C494033A31F0DA7A84540821DFF0582944940F4A78DEA74224640821DFF0582944940F4A78DEA742246404DF38E53743C494033A31F0DA7A845404DF38E53743C4940
348	Дубовский район	\N	22	44.325400000000002	45.303800000000003	49.779497999999997	48.930495999999998	0103000020E61000000100000005000000280F0BB5A62946408787307E1A774840280F0BB5A629464011A62897C6E348402D431CEBE2A6464011A62897C6E348402D431CEBE2A646408787307E1A774840280F0BB5A62946408787307E1A774840
145	Даниловский район	\N	22	43.646794999999997	44.630792	50.724096000000003	50.0503	0103000020E61000000100000005000000B01BB62DCAD24540917EFB3A70064940B01BB62DCAD245400C957F2DAF5C49400A4AD1CABD5046400C957F2DAF5C49400A4AD1CABD504640917EFB3A70064940B01BB62DCAD24540917EFB3A70064940
3	Городищенский район	\N	22	43.760100000000001	44.744895999999997	49.108600000000003	48.589596	0103000020E6100000010000000500000045D8F0F44AE145401CEDB8E1774B484045D8F0F44AE145403D2CD49AE68D4840EA758BC0585F46403D2CD49AE68D4840EA758BC0585F46401CEDB8E1774B484045D8F0F44AE145401CEDB8E1774B4840
1901	Волжский городской округ	\N	22	44.624423	44.879193999999998	48.930495999999998	48.753979000000001	0103000020E6100000010000000500000063EFC517ED4F4640766F45628260484063EFC517ED4F46408787307E1A774840726BD26D897046408787307E1A774840726BD26D89704640766F45628260484063EFC517ED4F4640766F456282604840
1923	Волгоград городской округ	\N	22	44.144497999999999	44.693700999999997	48.866033000000002	48.434317	0103000020E61000000100000005000000302B14E97E124640658C0FB397374840302B14E97E124640DE205A2BDA6E4840EB19C231CB584640DE205A2BDA6E4840EB19C231CB584640658C0FB397374840302B14E97E124640658C0FB397374840
1346	Быковский район	\N	22	44.937800000000003	46.052798000000003	49.949193999999999	49.099800000000002	0103000020E610000001000000050000002B1895D4097846400612143FC68C48402B1895D4097846409BC761307FF94840A9A5B915C20647409BC761307FF94840A9A5B915C20647400612143FC68C48402B1895D4097846400612143FC68C4840
521	Алексеевский район	\N	22	41.665146999999997	42.738292999999999	50.530195999999997	49.912419	0103000020E610000001000000050000002904728923D54440E09F5225CAF448402904728923D54440293C6876DD434940D0EE9062805E4540293C6876DD434940D0EE9062805E4540E09F5225CAF448402904728923D54440E09F5225CAF44840
1383	Черноярский район	\N	21	44.971505000000001	46.293798000000002	48.515113999999997	47.713183999999998	0103000020E6100000010000000500000043739D465A7C4640E603029D49DB474043739D465A7C46401ADB6B41EF414840ABD0402C9B2547401ADB6B41EF414840ABD0402C9B254740E603029D49DB474043739D465A7C4640E603029D49DB4740
996	Харабалинский район	\N	21	46.730297999999998	48.346088999999999	47.837344000000002	46.848196000000002	0103000020E61000000100000005000000C72AA5677A5D47408C4CC0AF916C4740C72AA5677A5D47403CC093162EEB4740AF40F4A44C2C48403CC093162EEB4740AF40F4A44C2C48408C4CC0AF916C4740C72AA5677A5D47408C4CC0AF916C4740
7418	Приволжский район,	\N	21	47.916586000000002	48.230853000000003	46.559001000000002	46.236626999999999	0103000020E6100000010000000500000059FCA6B052F54740E02C25CB491E474059FCA6B052F5474035B742588D4747407D9752978C1D484035B742588D4747407D9752978C1D4840E02C25CB491E474059FCA6B052F54740E02C25CB491E4740
1232	Приволжский район	\N	21	47.916586000000002	48.230853000000003	46.559001000000002	46.236626999999999	0103000020E6100000010000000500000059FCA6B052F54740E02C25CB491E474059FCA6B052F5474035B742588D4747407D9752978C1D484035B742588D4747407D9752978C1D4840E02C25CB491E474059FCA6B052F54740E02C25CB491E4740
1186	Наримановский район	\N	21	47.877643999999997	48.070979999999999	46.559125000000002	46.265911000000003	0103000020E61000000100000005000000EBC37AA356F04740C652245F09224740EBC37AA356F0474021B0726891474740C55565DF1509484021B0726891474740C55565DF15094840C652245F09224740EBC37AA356F04740C652245F09224740
1098	Лиманский район	\N	21	46.911856999999998	47.686959000000002	46.172795999999998	45.414918	0103000020E6100000010000000500000078D0ECBAB7744740C84274081CB5464078D0ECBAB77447409770E82D1E164740B058C345EED747409770E82D1E164740B058C345EED74740C84274081CB5464078D0ECBAB7744740C84274081CB54640
961	Красноярский район	\N	21	47.811096999999997	49.014012999999998	47.519995000000002	46.405698000000001	0103000020E610000001000000050000001D71C806D2E74740BC067DE9ED3347401D71C806D2E74740B18A37328FC24740035C902DCB814840B18A37328FC24740035C902DCB814840BC067DE9ED3347401D71C806D2E74740BC067DE9ED334740
783	Камызякский район	\N	21	47.759892999999998	48.613211999999997	46.210895000000001	45.413229000000001	0103000020E61000000100000005000000CBBA7F2C44E14740206118B0E4B44640CBBA7F2C44E14740E9F17B9BFE1A4740E3C116BB7D4E4840E9F17B9BFE1A4740E3C116BB7D4E4840206118B0E4B44640CBBA7F2C44E14740206118B0E4B44640
544	Икрянинский район	\N	21	47.884048999999997	47.926206999999998	46.267200000000003	46.233547999999999	0103000020E61000000100000005000000DF87838428F14740EA059FE6E41D4740DF87838428F14740E0BE0E9C33224740C32973F38DF64740E0BE0E9C33224740C32973F38DF64740EA059FE6E41D4740DF87838428F14740EA059FE6E41D4740
403	Енотаевский район	\N	21	45.900739999999999	47.754800000000003	47.910994000000002	46.675303	0103000020E610000001000000050000007A19C5724BF3464002F22554705647407A19C5724BF34640166D8E739BF44740AA8251499DE04740166D8E739BF44740AA8251499DE0474002F22554705647407A19C5724BF3464002F2255470564740
60	Володарский район	\N	21	48.260793999999997	49.483787	46.496194000000003	45.583615999999999	0103000020E610000001000000050000001B7FA2B2612148400FB6D8EDB3CA46401B7FA2B261214840583CF548833F47406F9D7FBBECBD4840583CF548833F47406F9D7FBBECBD48400FB6D8EDB3CA46401B7FA2B2612148400FB6D8EDB3CA4640
1175	Ахтубинский район	\N	21	45.203772999999998	47.210375999999997	48.863928999999999	47.663894999999997	0103000020E610000001000000050000006667D13B159A46402C7DE882FAD447406667D13B159A46407288B839956E484080EECB99ED9A47407288B839956E484080EECB99ED9A47402C7DE882FAD447406667D13B159A46402C7DE882FAD44740
585	Ярославский район	\N	17	39.248859000000003	40.474062000000004	57.922286999999997	57.273944999999998	0103000020E610000001000000050000005B28999CDA9F43408CF337A110A34C405B28999CDA9F434052431B800DF64C4060234910AE3C444052431B800DF64C4060234910AE3C44408CF337A110A34C405B28999CDA9F43408CF337A110A34C40
802	Череповецкий район	\N	17	37.706443	38.136699999999998	58.730536000000001	58.509099999999997	0103000020E610000001000000050000007BBE66B96CDA4240613255302A414D407BBE66B96CDA42407C462234825D4D407DAEB6627F1143407C462234825D4D407DAEB6627F114340613255302A414D407BBE66B96CDA4240613255302A414D40
330	Угличский район	\N	17	37.801403999999998	38.871296999999998	57.727597000000003	57.079498999999998	0103000020E610000001000000050000001971016894E642404888F2052D8A4C401971016894E6424078D503E621DD4C402C0DFCA8866F434078D503E621DD4C402C0DFCA8866F43404888F2052D8A4C401971016894E642404888F2052D8A4C40
31	Тутаевский район	\N	17	39.195867	39.924095999999999	58.216698999999998	57.662401000000003	0103000020E61000000100000005000000CDAE7B2B129943403AEB538EC9D44C40CDAE7B2B12994340B709F7CABC1B4D40A52E19C748F64340B709F7CABC1B4D40A52E19C748F643403AEB538EC9D44C40CDAE7B2B129943403AEB538EC9D44C40
1894	Рыбинский район	\N	17	38.321061	39.421497000000002	58.353402000000003	57.810999000000002	0103000020E61000000100000005000000B282DF86182943405B0BB3D0CEE74C40B282DF8618294340A62BD8463C2D4D405A2E1B9DF3B54340A62BD8463C2D4D405A2E1B9DF3B543405B0BB3D0CEE74C40B282DF86182943405B0BB3D0CEE74C40
1827	Ростовский район	\N	17	38.733792000000001	39.863019000000001	57.413398000000001	56.761693999999999	0103000020E61000000100000005000000810871E5EC5D43409BC761307F614C40810871E5EC5D4340AC1DC539EAB44C40CF69166877EE4340AC1DC539EAB44C40CF69166877EE43409BC761307F614C40810871E5EC5D43409BC761307F614C40
1803	Пошехонский район	\N	17	38.484994999999998	39.721696000000001	58.952451000000003	58.196300000000001	0103000020E610000001000000050000009CDCEF50143E4340371AC05B20194D409CDCEF50143E4340710514EAE9794D40B7D3D68860DC4340710514EAE9794D40B7D3D68860DC4340371AC05B20194D409CDCEF50143E4340371AC05B20194D40
830	Переславский район	\N	17	38.109372999999998	39.392563000000003	57.131765999999999	56.537199999999999	0103000020E610000001000000050000005F0839EFFF0D4340A2B437F8C2444C405F0839EFFF0D4340C45C52B5DD904C40514F1F813FB24340C45C52B5DD904C40514F1F813FB24340A2B437F8C2444C405F0839EFFF0D4340A2B437F8C2444C40
1593	Первомайский район	\N	17	39.360097000000003	40.535291000000001	58.841861000000002	58.288896999999999	0103000020E61000000100000005000000A13193A817AE4340CD74AF93FA244D40A13193A817AE43409163EB19C26B4D40EC6B5D6A844444409163EB19C26B4D40EC6B5D6A84444440CD74AF93FA244D40A13193A817AE4340CD74AF93FA244D40
1699	Некрасовский район	\N	17	40.051000999999999	40.715997000000002	57.911797999999997	57.312624	0103000020E610000001000000050000001A88653387064440ECF82F1004A84C401A886533870644407347FFCBB5F44C405E8429CAA55B44407347FFCBB5F44C405E8429CAA55B4440ECF82F1004A84C401A88653387064440ECF82F1004A84C40
820	Некоузский район	\N	17	37.330983000000003	38.431545	58.210996000000002	57.690699000000002	0103000020E610000001000000050000001844A4A65DAA4240A13028D368D84C401844A4A65DAA42401DCBBBEA011B4D404CE0D6DD3C3743401DCBBBEA011B4D404CE0D6DD3C374340A13028D368D84C401844A4A65DAA4240A13028D368D84C40
1633	Мышкинский район	\N	17	37.633895000000003	38.646296	57.959176999999997	57.613298999999998	0103000020E61000000100000005000000890CAB7823D14240B2D5E59480CE4C40890CAB7823D14240A609DB4FC6FA4C408FC4CBD3B9524340A609DB4FC6FA4C408FC4CBD3B9524340B2D5E59480CE4C40890CAB7823D14240B2D5E59480CE4C40
818	Любимский район	\N	17	40.383099000000001	41.194017000000002	58.596528999999997	57.981931000000003	0103000020E61000000100000005000000AE10566309314440DCF63DEAAFFD4C40AE10566309314440CB0EF10F5B4C4D401CEF8E8CD5984440CB0EF10F5B4C4D401CEF8E8CD5984440DCF63DEAAFFD4C40AE10566309314440DCF63DEAAFFD4C40
1488	Даниловский район	\N	17	39.515093	40.692191000000001	58.393996999999999	57.872998000000003	0103000020E6100000010000000500000003B34291EEC1434099BC0166BEEF4C4003B34291EEC143406EDC627E6E324D40F3CAF5B6995844406EDC627E6E324D40F3CAF5B69958444099BC0166BEEF4C4003B34291EEC1434099BC0166BEEF4C40
1422	Гаврилов-Ямский район	\N	17	39.333696000000003	40.438516	57.507497999999998	57.166867000000003	0103000020E610000001000000050000002C67EF8CB6AA43400DE4D9E55B954C402C67EF8CB6AA43408864C8B1F5C04C40E962D34A213844408864C8B1F5C04C40E962D34A213844400DE4D9E55B954C402C67EF8CB6AA43400DE4D9E55B954C40
1332	Брейтовский район	\N	17	37.329438000000003	38.279622000000003	58.451784000000004	58.073597999999997	0103000020E61000000100000005000000A3073E062BAA42408786C5A86B094D40A3073E062BAA4240946DE00ED4394D40FE9E58A7CA234340946DE00ED4394D40FE9E58A7CA2343408786C5A86B094D40A3073E062BAA42408786C5A86B094D40
785	Борисоглебский район	\N	17	38.598694000000002	39.376896000000002	57.601196000000002	57.056294999999999	0103000020E61000000100000005000000DD274701A24C4340D3F6AFAC34874C40DD274701A24C4340363E93FDF3CC4C4022FFCC203EB04340363E93FDF3CC4C4022FFCC203EB04340D3F6AFAC34874C40DD274701A24C4340D3F6AFAC34874C40
1276	Большесельский район	\N	17	38.570793000000002	39.436292999999999	57.906300000000002	57.505893	0103000020E6100000010000000500000093E4B9BE0F4943403E23111AC1C04C4093E4B9BE0F494340B22E6EA301F44C40A33CF372D8B74340B22E6EA301F44C40A33CF372D8B743403E23111AC1C04C4093E4B9BE0F4943403E23111AC1C04C40
7109	мкр. Центральный	\N	16	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
7110	мкр Центральный,	\N	16	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
1206	Ясногорский район	\N	16	37.473339000000003	38.102231000000003	54.840246	54.283202000000003	0103000020E61000000100000005000000EF75525F96BC4240B61490F63F244B40EF75525F96BC4240234C512E8D6B4B4096D1C8E7150D4340234C512E8D6B4B4096D1C8E7150D4340B61490F63F244B40EF75525F96BC4240B61490F63F244B40
1060	Щекинский район	\N	16	37.013779	37.719729000000001	54.087800999999999	53.699258	0103000020E61000000100000005000000902FA182C3814240B2BB404981D94A40902FA182C38142402EC72B103D0B4B40CC7D721420DC42402EC72B103D0B4B40CC7D721420DC4240B2BB404981D94A40902FA182C3814240B2BB404981D94A40
943	Чернский район	\N	16	36.380502	37.504600000000003	53.650495999999997	53.256169	0103000020E6100000010000000500000003081F4AB4304240E09F5225CAA04A4003081F4AB4304240E316F37343D34A40E3C798BB96C04240E316F37343D34A40E3C798BB96C04240E09F5225CAA04A4003081F4AB4304240E09F5225CAA04A40
606	Узловский район	\N	16	38.002293999999999	38.542639000000001	54.076397	53.736094000000001	0103000020E610000001000000050000000F7D772B4B0043401364045438DE4A400F7D772B4B0043409A417C60C7094B405F44DB31754543409A417C60C7094B405F44DB31754543401364045438DE4A400F7D772B4B0043401364045438DE4A40
7509	Тула городской округ	\N	16	37.483750000000001	37.862453000000002	54.272525000000002	54.029412999999998	0103000020E6100000010000000500000052B81E85EBBD4240E38920CEC3034B4052B81E85EBBD4240D42B6519E2224B4026AB22DC64EE4240D42B6519E2224B4026AB22DC64EE4240E38920CEC3034B4052B81E85EBBD4240E38920CEC3034B40
695	Тепло-Огаревский район	\N	16	37.389094999999998	37.909094000000003	53.794789000000002	53.344698999999999	0103000020E61000000100000005000000C0046EDDCDB1424061FBC9181FAC4A40C0046EDDCDB142403B1C5DA5BBE54A40B37E33315DF442403B1C5DA5BBE54A40B37E33315DF4424061FBC9181FAC4A40C0046EDDCDB1424061FBC9181FAC4A40
442	Суворовский район	\N	16	35.968525999999997	36.856996000000002	54.310682999999997	53.933799	0103000020E61000000100000005000000B0A9F3A8F8FB4140CD04C3B986F74A40B0A9F3A8F8FB41402A36E675C4274B40C366800BB26D42402A36E675C4274B40C366800BB26D4240CD04C3B986F74A40B0A9F3A8F8FB4140CD04C3B986F74A40
7111	Привокзальный	\N	16	37.570078000000002	37.572566999999999	54.199928	54.198695000000001	0103000020E61000000100000005000000A515DF50F8C842407A7077D66E194B40A515DF50F8C8424000C79E3D97194B4069E21DE049C9424000C79E3D97194B4069E21DE049C942407A7077D66E194B40A515DF50F8C842407A7077D66E194B40
210	Плавский район	\N	16	36.950591000000003	37.536796000000002	53.831195000000001	53.369194999999998	0103000020E610000001000000050000009C6F44F7AC794240616C21C841AF4A409C6F44F7AC794240A3CC069964EA4A40D34F38BBB5C44240A3CC069964EA4A40D34F38BBB5C44240616C21C841AF4A409C6F44F7AC794240616C21C841AF4A40
39	Одоевский район	\N	16	36.402897000000003	37.113796999999998	54.131400999999997	53.751398000000002	0103000020E610000001000000050000000954FF2092334240D12346CF2DE04A400954FF2092334240B2D47ABFD1104B4003B16CE6908E4240B2D47ABFD1104B4003B16CE6908E4240D12346CF2DE04A400954FF2092334240D12346CF2DE04A40
1812	Новомосковский район	\N	16	38.122345000000003	38.800699000000002	54.287616999999997	53.976953000000002	0103000020E6100000010000000500000021EA3E00A90F4340535DC0CB0CFD4A4021EA3E00A90F4340066344A2D0244B404F78094E7D664340066344A2D0244B404F78094E7D664340535DC0CB0CFD4A4021EA3E00A90F4340535DC0CB0CFD4A40
1162	Ленинский район	\N	16	37.169798	38.028030999999999	54.409027000000002	54.039316999999997	0103000020E610000001000000050000008E76DCF0BB954240A296E65608054B408E76DCF0BB9542402B172AFF5A344B4018231285960343402B172AFF5A344B401823128596034340A296E65608054B408E76DCF0BB954240A296E65608054B40
1762	Куркинский район	\N	16	38.245297000000001	38.945956000000002	53.633136	53.298597999999998	0103000020E61000000100000005000000496760E4651F43405453927538A64A40496760E4651F4340CBF5B6990AD14A403DBA111615794340CBF5B6990AD14A403DBA1116157943405453927538A64A40496760E4651F43405453927538A64A40
6182	Кувшиновский район	\N	16	35.898718000000002	38.950609	54.852640999999998	52.945552999999997	0103000020E61000000100000005000000CC29013109F341403DD175E107794A40CC29013109F34140471D1D57236D4B404224438EAD794340471D1D57236D4B404224438EAD7943403DD175E107794A40CC29013109F341403DD175E107794A40
1223	Киреевский район	\N	16	37.662999999999997	38.111691	54.253894000000003	53.778494999999999	0103000020E61000000100000005000000BE9F1A2FDDD44240BD8C62B9A5E34A40BE9F1A2FDDD4424048533D997F204B40F72004E44B0E434048533D997F204B40F72004E44B0E4340BD8C62B9A5E34A40BE9F1A2FDDD44240BD8C62B9A5E34A40
153	Кимовский район	\N	16	38.404515000000004	38.950626999999997	54.075246	53.613297000000003	0103000020E61000000100000005000000E8DEC325C733434012DE1E8480CE4A40E8DEC325C7334340D19332A9A1094B40E8D84125AE794340D19332A9A1094B40E8D84125AE79434012DE1E8480CE4A40E8DEC325C733434012DE1E8480CE4A40
1565	Каменский район	\N	16	37.454681000000001	37.989196	53.401795	53.077495999999996	0103000020E61000000100000005000000698EACFC32BA424010C99063EB894A40698EACFC32BA42402159C0046EB34A40C1AA7AF99DFE42402159C0046EB34A40C1AA7AF99DFE424010C99063EB894A40698EACFC32BA424010C99063EB894A40
1518	Заокский район	\N	16	37.150897999999998	37.772119000000004	54.833843000000002	54.450355000000002	0103000020E6100000010000000500000012842BA050934240884B8E3BA5394B4012842BA050934240D07F0F5EBB6A4B4064CF9ECBD4E24240D07F0F5EBB6A4B4064CF9ECBD4E24240884B8E3BA5394B4012842BA050934240884B8E3BA5394B40
328	Ефремовский район	\N	16	37.818615000000001	38.670954999999999	53.382598000000002	52.945591	0103000020E61000000100000005000000ED815660C8E842402B323A2009794A40ED815660C8E84240ECC1A4F8F8B04A40390B7BDAE1554340ECC1A4F8F8B04A40390B7BDAE15543402B323A2009794A40ED815660C8E842402B323A2009794A40
1415	Дубенский район	\N	16	36.661397000000001	37.275593000000001	54.298453000000002	54.007496000000003	0103000020E6100000010000000500000015562AA8A8544240E86C01A1F5004B4015562AA8A8544240513239B533264B40D600A5A146A34240513239B533264B40D600A5A146A34240E86C01A1F5004B4015562AA8A8544240E86C01A1F5004B40
1270	Воловский район	\N	16	37.737192	38.409697999999999	53.676298000000003	53.315299000000003	0103000020E61000000100000005000000B96FB54E5CDE424013BBB6B75BA84A40B96FB54E5CDE4240D42CD0EE90D64A40499EEBFB70344340D42CD0EE90D64A40499EEBFB7034434013BBB6B75BA84A40B96FB54E5CDE424013BBB6B75BA84A40
777	Веневский район	\N	16	37.89199	38.494408999999997	54.709257000000001	54.105393999999997	0103000020E61000000100000005000000F52D73BA2CF24240E998F38C7D0D4B40F52D73BA2CF24240C3BAF1EEC85A4B408DEC4ACB483F4340C3BAF1EEC85A4B408DEC4ACB483F4340E998F38C7D0D4B40F52D73BA2CF24240E998F38C7D0D4B40
1094	Богородицкий район	\N	16	37.863593999999999	38.602997000000002	53.863894999999999	53.569096999999999	0103000020E61000000100000005000000CB82893F8AEE424038A0A52BD8C84A40CB82893F8AEE4240C616821C94EE4A40064B75012F4D4340C616821C94EE4A40064B75012F4D434038A0A52BD8C84A40CB82893F8AEE424038A0A52BD8C84A40
827	Белевский район	\N	16	35.898592000000001	36.524394999999998	53.982098999999998	53.540275999999999	0103000020E610000001000000050000003F390A1005F34140276893C327C54A403F390A1005F341409737876BB5FD4A40CC9717601F4342409737876BB5FD4A40CC9717601F434240276893C327C54A403F390A1005F34140276893C327C54A40
453	Арсеньевский район	\N	16	36.271393000000003	37.038994000000002	53.806897999999997	53.455081999999997	0103000020E6100000010000000500000082AE7D01BD224240C77F812040BA4A4082AE7D01BD224240999A046F48E74A40C05E61C1FD844240999A046F48E74A40C05E61C1FD844240C77F812040BA4A4082AE7D01BD224240C77F812040BA4A40
487	Алексинский район	\N	16	36.855477999999998	37.497396000000002	54.673293999999999	54.266199999999998	0103000020E610000001000000050000004739984D806D4240FC1873D712224B404739984D806D4240E84B6F7F2E564B40A39410ACAABF4240E84B6F7F2E564B40A39410ACAABF4240FC1873D712224B404739984D806D4240FC1873D712224B40
7112	 Пролетарский	\N	16	38.224285999999999	38.236044	53.353321000000001	53.346128999999998	0103000020E61000000100000005000000AF795567B51C43403D997FF44DAC4A40AF795567B51C4340B9FE5D9F39AD4A40613596B0361E4340B9FE5D9F39AD4A40613596B0361E43403D997FF44DAC4A40AF795567B51C43403D997FF44DAC4A40
1908	Фировский район	\N	15	33.231116999999998	34.094496999999997	57.730595000000001	57.183796999999998	0103000020E610000001000000050000005A46EA3D959D40402C0DFCA886974C405A46EA3D959D404081CF0F2384DD4C40F9484A7A180C414081CF0F2384DD4C40F9484A7A180C41402C0DFCA886974C405A46EA3D959D40402C0DFCA886974C40
1881	Удомельский район	\N	15	34.373199	35.517096000000002	58.245759999999997	57.665394999999997	0103000020E6100000010000000500000030F31DFCC42F414001F6D1A92BD54C4030F31DFCC42F41401D554D10751F4D403B72A43330C241401D554D10751F4D403B72A43330C2414001F6D1A92BD54C4030F31DFCC42F414001F6D1A92BD54C40
1790	Торопецкий район	\N	15	30.770308	32.163297999999998	56.988084999999998	56.300859000000003	0103000020E61000000100000005000000E0D8B3E732C53E4088DA368C82264C40E0D8B3E732C53E408655BC91797E4C4048C0E8F2E61440408655BC91797E4C4048C0E8F2E614404088DA368C82264C40E0D8B3E732C53E4088DA368C82264C40
1463	Торжокский район	\N	15	34.355896999999999	35.405794	57.304398999999997	56.589998000000001	0103000020E610000001000000050000004CDF6B088E2D41404B5AF10D854B4C404CDF6B088E2D4140B1F7E28BF6A64C40DE74CB0EF1B34140B1F7E28BF6A64C40DE74CB0EF1B341404B5AF10D854B4C404CDF6B088E2D41404B5AF10D854B4C40
693	Старицкий район	\N	15	33.758994000000001	35.508237999999999	56.972698000000001	56.291722999999998	0103000020E610000001000000050000001CEE23B726E14040D93EE42D57254C401CEE23B726E140403B71395E817C4C40CF4A5AF10DC141403B71395E817C4C40CF4A5AF10DC14140D93EE42D57254C401CEE23B726E14040D93EE42D57254C40
1462	Спировский район	\N	15	34.631895999999998	35.723996	57.707594	57.194996000000003	0103000020E61000000100000005000000923CD7F7E1504140E86C01A1F5984C40923CD7F7E1504140446CB07092DA4C40A837A3E6ABDC4140446CB07092DA4C40A837A3E6ABDC4140E86C01A1F5984C40923CD7F7E1504140E86C01A1F5984C40
1429	Сонковский район	\N	15	36.879390999999998	37.653827999999997	57.983907000000002	57.632896000000002	0103000020E61000000100000005000000C8B260E28F70424076E272BC02D14C40C8B260E28F7042401AA721AAF0FD4C40C39ACAA2B0D342401AA721AAF0FD4C40C39ACAA2B0D3424076E272BC02D14C40C8B260E28F70424076E272BC02D14C40
1327	Селижаровский район	\N	15	32.878599999999999	34.022694000000001	57.071897	56.461998999999999	0103000020E61000000100000005000000FF21FDF67570404071E481C8223B4C40FF21FDF6757040401BD7BFEB33894C4060E811A3E70241401BD7BFEB33894C4060E811A3E702414071E481C8223B4C40FF21FDF67570404071E481C8223B4C40
1317	Сандовский район	\N	15	35.765695000000001	36.902298000000002	58.607571	58.167797	0103000020E61000000100000005000000F9DA334B02E24140F7AE415F7A154D40F9DA334B02E24140BF7FF3E2C44D4D40849F38807E734240BF7FF3E2C44D4D40849F38807E734240F7AE415F7A154D40F9DA334B02E24140F7AE415F7A154D40
928	Ржевский район	\N	15	33.627991999999999	34.834699000000001	56.664099	55.993775999999997	0103000020E610000001000000050000002713B70A62D040405CC64D0D34FF4B402713B70A62D0404035272F3201554C408080B56AD76A414035272F3201554C408080B56AD76A41405CC64D0D34FF4B402713B70A62D040405CC64D0D34FF4B40
1150	Рамешковский район	\N	15	35.736598999999998	36.790897999999999	57.539197000000001	56.972399000000003	0103000020E6100000010000000500000016A243E048DE4140E1D40792777C4C4016A243E048DE4140F88C446804C54C40643C4A253C654240F88C446804C54C40643C4A253C654240E1D40792777C4C4016A243E048DE4140E1D40792777C4C40
741	Пеновский район	\N	15	31.924292999999999	32.976596999999998	57.263300999999998	56.616698999999997	0103000020E61000000100000005000000F6EB4E779EEC3F40EA3C2AFEEF4E4C40F6EB4E779EEC3F408600E0D8B3A14C40942F6821017D40408600E0D8B3A14C40942F6821017D4040EA3C2AFEEF4E4C40F6EB4E779EEC3F40EA3C2AFEEF4E4C40
1026	Осташковский район	\N	15	32.376603000000003	33.768597	57.467441999999998	56.865501000000002	0103000020E61000000100000005000000AA49F08634304040E1D39CBCC86E4C40AA49F086343040406F63B323D5BB4C40E066F16261E240406F63B323D5BB4C40E066F16261E24040E1D39CBCC86E4C40AA49F08634304040E1D39CBCC86E4C40
608	Оленинский район	\N	15	33.035401	33.9358	56.531495999999997	55.880893999999998	0103000020E61000000100000005000000739F1C05888440400E9F7422C1F04B40739F1C058884404037FA980F08444C4064CC5D4BC8F7404037FA980F08444C4064CC5D4BC8F740400E9F7422C1F04B40739F1C05888440400E9F7422C1F04B40
804	Нелидовский район	\N	15	32.262498999999998	33.241492000000001	56.572899999999997	55.950695000000003	0103000020E61000000100000005000000C91D36919921404041BCAE5FB0F94B40C91D3691992140406FF085C954494C40711FB935E99E40406FF085C954494C40711FB935E99E404041BCAE5FB0F94B40C91D36919921404041BCAE5FB0F94B40
697	Молоковский район	\N	15	36.166299000000002	37.036991	58.326500000000003	57.967097000000003	0103000020E61000000100000005000000C32D1F4949154240A587A1D5C9FB4C40C32D1F49491542406F1283C0CA294D40889FFF1EBC8442406F1283C0CA294D40889FFF1EBC844240A587A1D5C9FB4C40C32D1F4949154240A587A1D5C9FB4C40
545	Максатихинский район	\N	15	35.277892000000001	36.278894000000001	58.183596000000001	57.478399000000003	0103000020E61000000100000005000000F7E80DF791A3414035B8AD2D3CBD4C40F7E80DF791A3414095D6DF1280174D407B8670CCB223424095D6DF1280174D407B8670CCB223424035B8AD2D3CBD4C40F7E80DF791A3414035B8AD2D3CBD4C40
333	Лихославльский район	\N	15	35.108792999999999	35.979899000000003	57.577399	56.985000999999997	0103000020E610000001000000050000005184D4EDEC8D41407EC34483147E4C405184D4EDEC8D41401EDFDE35E8C94C400A3197546DFD41401EDFDE35E8C94C400A3197546DFD41407EC34483147E4C405184D4EDEC8D41407EC34483147E4C40
211	Лесной район	\N	15	35.126840999999999	36.110298	58.459975999999997	58.023898000000003	0103000020E610000001000000050000005E656D533C9041404C38F4160F034D405E656D533C904140F2785A7EE03A4D403868AF3E1E0E4240F2785A7EE03A4D403868AF3E1E0E42404C38F4160F034D405E656D533C9041404C38F4160F034D40
45	Кувшиновский район	\N	15	33.629600000000003	34.628993999999999	57.274996000000002	56.814492999999999	0103000020E61000000100000005000000E3C798BB96D0404014E97E4E41684C40E3C798BB96D04040F243A51133A34C40ABB019E082504140F243A51133A34C40ABB019E08250414014E97E4E41684C40E3C798BB96D0404014E97E4E41684C40
1266	Краснохолмский район	\N	15	36.818593	37.716225000000001	58.377999000000003	57.851897999999998	0103000020E6100000010000000500000005DEC9A7C76842408FC360FE0AED4C4005DEC9A7C7684240DA756F4562304D40EFC9C342ADDB4240DA756F4562304D40EFC9C342ADDB42408FC360FE0AED4C4005DEC9A7C76842408FC360FE0AED4C40
1850	Конаковский район	\N	15	36.000075000000002	37.149253999999999	57.006763999999997	56.371969	0103000020E610000001000000050000000B462575020042401B1021AE9C2F4C400B4625750200424023658BA4DD804C400A664CC11A93424023658BA4DD804C400A664CC11A9342401B1021AE9C2F4C400B462575020042401B1021AE9C2F4C40
1769	Кимрский район	\N	15	36.623542	37.674930000000003	57.322763000000002	56.769064	0103000020E610000001000000050000005AD76839D04F4240F6436CB070624C405AD76839D04F4240EFAD484C50A94C406E8B321B64D64240EFAD484C50A94C406E8B321B64D64240F6436CB070624C405AD76839D04F4240F6436CB070624C40
1794	Кесовогорский район	\N	15	36.845497000000002	37.784390000000002	57.708402	57.410997999999999	0103000020E61000000100000005000000DDEEE53E396C4240575C1C959BB44C40DDEEE53E396C4240E335AFEAACDA4C409CA73AE466E44240E335AFEAACDA4C409CA73AE466E44240575C1C959BB44C40DDEEE53E396C4240575C1C959BB44C40
1760	Кашинский район	\N	15	36.760750000000002	38.016540999999997	57.625951999999998	57.113497000000002	0103000020E610000001000000050000004C37894160614240D998D711878E4C404C37894160614240D26EF4311FD04C408505F7031E024340D26EF4311FD04C408505F7031E024340D998D711878E4C404C37894160614240D998D711878E4C40
203	Калязинский район	\N	15	37.430380999999997	38.304963000000001	57.362890999999998	56.764713	0103000020E61000000100000005000000EEE87FB916B74240BCE9961DE2614C40EEE87FB916B74240A181583673AE4C40BABE0F0709274340A181583673AE4C40BABE0F0709274340BCE9961DE2614C40EEE87FB916B74240BCE9961DE2614C40
1614	Калининский район	\N	15	35.231881000000001	36.695649000000003	57.091096	56.405450000000002	0103000020E610000001000000050000002AC8CF46AE9D4140E4141DC9E5334C402AC8CF46AE9D4140F165A208A98B4C40603FC4060B594240F165A208A98B4C40603FC4060B594240E4141DC9E5334C402AC8CF46AE9D4140E4141DC9E5334C40
1572	Зубцовский район	\N	15	34.383332000000003	35.475530999999997	56.389538000000002	55.904473000000003	0103000020E6100000010000000500000051C1E10511314140B98E71C5C5F34B4051C1E105113141404E469561DC314C40F99D2633DEBC41404E469561DC314C40F99D2633DEBC4140B98E71C5C5F34B4051C1E10511314140B98E71C5C5F34B40
1504	Западнодвинский район	\N	15	31.350636999999999	32.403697000000001	56.488	55.718820999999998	0103000020E610000001000000050000007EC4AF58C3593F40C956975302DC4B407EC4AF58C3593F405839B4C8763E4C40253FE257AC3340405839B4C8763E4C40253FE257AC334040C956975302DC4B407EC4AF58C3593F40C956975302DC4B40
1467	Жарковский район	\N	15	31.636796	32.597498999999999	56.1601	55.649118999999999	0103000020E610000001000000050000003F390A1005A33F402A1BD65416D34B403F390A1005A33F40780B24287E144C404432E4D87A4C4040780B24287E144C404432E4D87A4C40402A1BD65416D34B403F390A1005A33F402A1BD65416D34B40
848	Вышневолоцкий район	\N	15	33.916899999999998	35.422798999999998	57.877294999999997	57.215797999999999	0103000020E61000000100000005000000E8D9ACFA5CF540406745D4449F9B4C40E8D9ACFA5CF54040DFF8DA334BF04C4008E412471EB64140DFF8DA334BF04C4008E412471EB641406745D4449F9B4C40E8D9ACFA5CF540406745D4449F9B4C40
1246	Весьегонский район	\N	15	36.585892999999999	37.639653000000003	58.863194	58.287700000000001	0103000020E6100000010000000500000048FAB48AFE4A42409487855AD3244D4048FAB48AFE4A42403D0D18247D6E4D40E7E44526E0D142403D0D18247D6E4D40E7E44526E0D142409487855AD3244D4048FAB48AFE4A42409487855AD3244D40
6917	Бологое городской округ	\N	15	34.001997000000003	34.195673999999997	57.915714000000001	57.822701000000002	0103000020E6100000010000000500000056D80C704100414079B130444EE94C4056D80C7041004140A33EC91D36F54C40B8567BD80B194140A33EC91D36F54C40B8567BD80B19414079B130444EE94C4056D80C704100414079B130444EE94C40
711	Бологовский район	\N	15	33.528422999999997	34.618313000000001	58.213959000000003	57.615796000000003	0103000020E6100000010000000500000023BA675DA3C34040FA804067D2CE4C4023BA675DA3C34040AAD72D02631B4D4088D860E1244F4140AAD72D02631B4D4088D860E1244F4140FA804067D2CE4C4023BA675DA3C34040FA804067D2CE4C40
1143	Бельский район	\N	15	32.322094	33.653280000000002	56.066298000000003	55.631462999999997	0103000020E61000000100000005000000711E4E603A29404028D192C7D3D04B40711E4E603A29404026E5EE737C084C40C190D5AD9ED3404026E5EE737C084C40C190D5AD9ED3404028D192C7D3D04B40711E4E603A29404028D192C7D3D04B40
591	Бежецкий район	\N	15	36.111896999999999	37.013095999999997	58.135299000000003	57.382496000000003	0103000020E61000000100000005000000A0C211A4520E4240E86C01A1F5B04C40A0C211A4520E42403C17467A51114D40ADDA3521AD8142403C17467A51114D40ADDA3521AD814240E86C01A1F5B04C40A0C211A4520E4240E86C01A1F5B04C40
995	Андреапольский район	\N	15	31.394995999999999	32.936594999999997	57.131228	56.424695	0103000020E61000000100000005000000020D36751E653F402AE3DF675C364C40020D36751E653F40E5284014CC904C406E4C4F58E2774040E5284014CC904C406E4C4F58E27740402AE3DF675C364C40020D36751E653F402AE3DF675C364C40
7107	Мичуринск городской округ	\N	14	40.429847000000002	40.544293000000003	52.928136000000002	52.856437	0103000020E6100000010000000500000051A4FB3905374440CC0A45BA9F6D4A4051A4FB3905374440C11E1329CD764A408B389D64AB454440C11E1329CD764A408B389D64AB454440CC0A45BA9F6D4A4051A4FB3905374440CC0A45BA9F6D4A40
548	Уметский район	\N	14	42.700097	43.245536000000001	52.869996	52.347693	0103000020E610000001000000050000008C834BC79C59454029064834812C4A408C834BC79C5945404ED367075C6F4A40CEFE40B96D9F45404ED367075C6F4A40CEFE40B96D9F454029064834812C4A408C834BC79C59454029064834812C4A40
16	Уваровский район	\N	14	41.890894000000003	42.654794000000003	52.185997999999998	51.628740000000001	0103000020E61000000100000005000000F01989D008F24440F1D7648D7AD04940F01989D008F244408A8F4FC8CE174A40FBCE2F4AD05345408A8F4FC8CE174A40FBCE2F4AD0534540F1D7648D7AD04940F01989D008F24440F1D7648D7AD04940
7105	Уварово городской округ	\N	14	42.201064000000002	42.294210999999997	52.031286000000001	51.931834000000002	0103000020E6100000010000000500000094331477BC19454083A6255646F7494094331477BC1945404D69FD2D01044A40CD8FBFB4A82545404D69FD2D01044A40CD8FBFB4A825454083A6255646F7494094331477BC19454083A6255646F74940
569	Токаревский район	\N	14	40.880378999999998	41.547494999999998	52.280397999999998	51.717573999999999	0103000020E61000000100000005000000E78A5242B0704440DE3AFF76D9DB4940E78A5242B070444091EEE714E4234A409CDCEF5014C6444091EEE714E4234A409CDCEF5014C64440DE3AFF76D9DB4940E78A5242B0704440DE3AFF76D9DB4940
156	Тамбовский район	\N	14	40.766598999999999	41.865192999999998	53.115394999999999	52.459595	0103000020E61000000100000005000000BA1281EA1F624440DB334B02D43A4A40BA1281EA1F6244409B8F6B43C58E4A4033DDEBA4BEEE44409B8F6B43C58E4A4033DDEBA4BEEE4440DB334B02D43A4A40BA1281EA1F624440DB334B02D43A4A40
1702	Тамбов городской округ	\N	14	41.356118000000002	41.509056000000001	52.776645000000002	52.671920999999998	0103000020E610000001000000050000002BC24D4695AD4440703FE08101564A402BC24D4695AD44400CCD751A69634A4092EA3BBF28C144400CCD751A69634A4092EA3BBF28C14440703FE08101564A402BC24D4695AD4440703FE08101564A40
806	Староюрьевский район	\N	14	40.408439999999999	41.033999999999999	53.556165	53.169598000000001	0103000020E610000001000000050000006A300DC347344440C7BB2363B5954A406A300DC34734444005172B6A30C74A403108AC1C5A84444005172B6A30C74A403108AC1C5A844440C7BB2363B5954A406A300DC347344440C7BB2363B5954A40
799	Сосновский район	\N	14	40.850096999999998	41.852096000000003	53.501767999999998	52.873894	0103000020E61000000100000005000000BFB67EFACF6C4440D71533C2DB6F4A40BFB67EFACF6C4440F4160FEF39C04A40B686527B11ED4440F4160FEF39C04A40B686527B11ED4440D71533C2DB6F4A40BFB67EFACF6C4440D71533C2DB6F4A40
610	Сампурский район	\N	14	41.361696999999999	41.978794000000001	52.455495999999997	52.046100000000003	0103000020E61000000100000005000000D90759164CAE44403D2CD49AE6054A40D90759164CAE4440BABA63B14D3A4A40B1C22D1F49FD4440BABA63B14D3A4A40B1C22D1F49FD44403D2CD49AE6054A40D90759164CAE44403D2CD49AE6054A40
684	Ржаксинский район	\N	14	41.635494000000001	42.366596999999999	52.427796000000001	51.911299	0103000020E61000000100000005000000F1660DDE57D1444052F01472A5F44940F1660DDE57D1444008AEF204C2364A40E6E786A6EC2E454008AEF204C2364A40E6E786A6EC2E454052F01472A5F44940F1660DDE57D1444052F01472A5F44940
128	Рассказовский район	\N	14	41.507196999999998	42.374296000000001	52.890495000000001	52.348298	0103000020E610000001000000050000008DD0CFD4EBC0444090A16307952C4A408DD0CFD4EBC0444032207BBDFB714A4006836BEEE82F454032207BBDFB714A4006836BEEE82F454090A16307952C4A408DD0CFD4EBC0444090A16307952C4A40
7106	Рассказово городской округ	\N	14	41.826476	41.968805000000003	52.707084000000002	52.626283999999998	0103000020E61000000100000005000000E6762FF7C9E944400801F9122A504A40E6762FF7C9E944402FC37FBA815A4A40C4995FCD01FC44402FC37FBA815A4A40C4995FCD01FC44400801F9122A504A40E6762FF7C9E944400801F9122A504A40
137	Пичаевский район	\N	14	41.798296000000001	42.570236000000001	53.414897000000003	53.018993999999999	0103000020E61000000100000005000000894336902EE64440FD6838656E824A40894336902EE64440B11A4B581BB54A403D80457EFD484540B11A4B581BB54A403D80457EFD484540FD6838656E824A40894336902EE64440FD6838656E824A40
800	Петровский район	\N	14	39.918759999999999	40.922600000000003	52.800798	52.325291	0103000020E61000000100000005000000BD6F7CED99F543407157AF22A3294A40BD6F7CED99F54340E259828C80664A4012A5BDC117764440E259828C80664A4012A5BDC1177644407157AF22A3294A40BD6F7CED99F543407157AF22A3294A40
814	Первомайский район	\N	14	40.086905999999999	40.634798000000004	53.391700999999998	53.017536999999997	0103000020E61000000100000005000000C0E95DBC1F0B444027BC04A73E824A40C0E95DBC1F0B4440BE67244223B24A407AC8940F41514440BE67244223B24A407AC8940F4151444027BC04A73E824A40C0E95DBC1F0B444027BC04A73E824A40
753	Никифоровский район	\N	14	40.568393999999998	41.118693	53.179696	52.549802	0103000020E610000001000000050000000E9F7422C148444040A374E95F464A400E9F7422C14844406B9C4D4700974A40CFA10C55318F44406B9C4D4700974A40CFA10C55318F444040A374E95F464A400E9F7422C148444040A374E95F464A40
558	Мучкапский район	\N	14	42.141649999999998	42.818351	52.091495999999999	51.588171000000003	0103000020E610000001000000050000003CBD52962112454052BAF42F49CB49403CBD5296211245407FDB1324B60B4A400FD3BEB9BF6845407FDB1324B60B4A400FD3BEB9BF68454052BAF42F49CB49403CBD52962112454052BAF42F49CB4940
127	Моршанский район	\N	14	41.182392999999998	42.319102999999998	53.823213000000003	53.187396999999997	0103000020E61000000100000005000000790261A7589744402B2FF99FFC974A40790261A7589744402F52280B5FE94A401A87FA5DD82845402F52280B5FE94A401A87FA5DD82845402B2FF99FFC974A40790261A7589744402B2FF99FFC974A40
217	Мордовский район	\N	14	40.529694999999997	41.120193	52.451298000000001	51.890076999999998	0103000020E6100000010000000500000067EDB60BCD434440FDF50A0BEEF1494067EDB60BCD43444007600322C4394A40A41AF67B628F444007600322C4394A40A41AF67B628F4440FDF50A0BEEF1494067EDB60BCD434440FDF50A0BEEF14940
1811	Мичуринский район	\N	14	40.034560999999997	40.857194	53.206493000000002	52.676195999999997	0103000020E61000000100000005000000C85BAE7E6C044440CFD72C978D564A40C85BAE7E6C0444402DEDD45C6E9A4A40E9297288B86D44402DEDD45C6E9A4A40E9297288B86D4440CFD72C978D564A40C85BAE7E6C044440CFD72C978D564A40
6963	Котовск городской округ	\N	14	41.469593000000003	41.547198999999999	52.617001000000002	52.568399999999997	0103000020E610000001000000050000001CB7989F1BBC4440F085C954C1484A401CB7989F1BBC4440B64C86E3F94E4A40B3B3E89D0AC64440B64C86E3F94E4A40B3B3E89D0AC64440F085C954C1484A401CB7989F1BBC4440F085C954C1484A40
407	Кирсановский район	\N	14	42.181390999999998	42.884799000000001	52.906700000000001	52.438397999999999	0103000020E61000000100000005000000F564FED137174540DF50F86C1D384A40F564FED13717454040A4DFBE0E744A404A44F8174171454040A4DFBE0E744A404A44F81741714540DF50F86C1D384A40F564FED137174540DF50F86C1D384A40
512	Инжавинский район	\N	14	42.110793000000001	42.941797000000001	52.560696999999998	52.0715	0103000020E6100000010000000500000018D00B772E0E4540FED478E926094A4018D00B772E0E45408FFB56EBC4474A40473CD9CD8C7845408FFB56EBC4474A40473CD9CD8C784540FED478E926094A4018D00B772E0E4540FED478E926094A40
1673	Знаменский район	\N	14	40.914299999999997	41.704000000000001	52.584997999999999	52.206494999999997	0103000020E61000000100000005000000CC5D4BC807754440CDE49B6D6E1A4A40CC5D4BC807754440DA1CE736E14A4A40273108AC1CDA4440DA1CE736E14A4A40273108AC1CDA4440CDE49B6D6E1A4A40CC5D4BC807754440CDE49B6D6E1A4A40
1070	Жердевский район	\N	14	41.124200000000002	42.060999000000002	52.067697000000003	51.653618000000002	0103000020E61000000100000005000000E4141DC9E58F4440D9092FC1A9D34940E4141DC9E58F4440C784984BAA084A405B0BB3D0CE074540C784984BAA084A405B0BB3D0CE074540D9092FC1A9D34940E4141DC9E58F4440D9092FC1A9D34940
169	Гавриловский район	\N	14	42.287391999999997	43.012098999999999	53.130591000000003	52.753694000000003	0103000020E61000000100000005000000E690D442C92445408198840B79604A40E690D442C92445407313B534B7904A403BA8C4758C8145407313B534B7904A403BA8C4758C8145408198840B79604A40E690D442C92445408198840B79604A40
230	Бондарский район	\N	14	41.656793	42.506095999999999	53.128694000000003	52.804994999999998	0103000020E61000000100000005000000F19E03CB11D44440C5387F130A674A40F19E03CB11D444408198840B79904A407651F4C0C74045408198840B79904A407651F4C0C7404540C5387F130A674A40F19E03CB11D44440C5387F130A674A40
987	Ярцевский район	\N	13	32.399394000000001	33.065997000000003	55.552897000000002	54.884596000000002	0103000020E61000000100000005000000FC1BB4571F334040121615713A714B40FC1BB4571F3340403C873254C5C64B402B51F696728840403C873254C5C64B402B51F69672884040121615713A714B40FC1BB4571F334040121615713A714B40
1216	Шумячский район	\N	13	31.759208999999998	32.695694000000003	54.086798000000002	53.713106000000003	0103000020E6100000010000000500000030D461855BC23F406B4AB20E47DB4A4030D461855BC23F40DAAD65321C0B4B40000341800C594040DAAD65321C0B4B40000341800C5940406B4AB20E47DB4A4030D461855BC23F406B4AB20E47DB4A40
7242	Шахунский район	\N	13	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
1213	Холм-Жирковский район	\N	13	32.668295000000001	33.918795000000003	55.756847	55.345601000000002	0103000020E61000000100000005000000488AC8B08A554040823B50A73CAC4B40488AC8B08A554040B189CC5CE0E04B403A5D16139BF54040B189CC5CE0E04B403A5D16139BF54040823B50A73CAC4B40488AC8B08A554040823B50A73CAC4B40
883	Хиславичский район	\N	13	31.753442	32.476891000000002	54.307495000000003	53.931196	0103000020E61000000100000005000000CE6E2D93E1C03F404015376E31F74A40CE6E2D93E1C03F407E5704FF5B274B40DD60A8C30A3D40407E5704FF5B274B40DD60A8C30A3D40404015376E31F74A40CE6E2D93E1C03F404015376E31F74A40
1127	Угранский район	\N	13	33.652993000000002	34.927998000000002	55.069602000000003	54.507159999999999	0103000020E610000001000000050000002BC24D4695D3404070EB6E9EEA404B402BC24D4695D340403CDEE4B7E8884B40706072A3C87641403CDEE4B7E8884B40706072A3C876414070EB6E9EEA404B402BC24D4695D3404070EB6E9EEA404B40
3320	Торжокский район	\N	13	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
1064	Темкинский район	\N	13	34.697428000000002	35.301383000000001	55.480837000000001	54.914037999999998	0103000020E6100000010000000500000048A81952455941408FA67A32FF744B4048A819524559414077DA1A118CBD4B400249D8B793A6414077DA1A118CBD4B400249D8B793A641408FA67A32FF744B4048A81952455941408FA67A32FF744B40
7207	Тарусский район	\N	13	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
1051	Сычевский район	\N	13	33.533355	34.599997000000002	56.066941999999997	55.656995999999999	0103000020E610000001000000050000003C1405FA44C4404029CDE67118D44B403C1405FA44C440404A5D328E91084C405C59A2B3CC4C41404A5D328E91084C405C59A2B3CC4C414029CDE67118D44B403C1405FA44C4404029CDE67118D44B40
7204	Сухиничский район	\N	13	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
7210	Старожиловский район	\N	13	30.748856	35.390658000000002	56.066927	53.412878999999997	0103000020E61000000100000005000000D369DD06B5BF3E40431A1538D9B44A40D369DD06B5BF3E40151C5E1091084C40DCF5D21401B24140151C5E1091084C40DCF5D21401B24140431A1538D9B44A40D369DD06B5BF3E40431A1538D9B44A40
452	Смоленский район	\N	13	31.341079000000001	32.323754999999998	55.207715999999998	54.509616999999999	0103000020E61000000100000005000000365A0EF450573F40293E3E213B414B40365A0EF450573F408F6D1970969A4B404F75C8CD702940408F6D1970969A4B404F75C8CD70294040293E3E213B414B40365A0EF450573F40293E3E213B414B40
1173	Сафоновский район	\N	13	32.921494000000003	33.949993999999997	55.427697999999999	54.959485000000001	0103000020E61000000100000005000000E9BAF083F375404054008C67D07A4B40E9BAF083F37540404548DDCEBEB64B40B7B2446799F940404548DDCEBEB64B40B7B2446799F9404054008C67D07A4B40E9BAF083F375404054008C67D07A4B40
170	Руднянский район	\N	13	30.749521000000001	31.581792	55.454197999999998	54.725098000000003	0103000020E610000001000000050000004CAAB69BE0BF3E409032E202D05C4B404CAAB69BE0BF3E404DF4F92823BA4B400E130D52F0943F404DF4F92823BA4B400E130D52F0943F409032E202D05C4B404CAAB69BE0BF3E409032E202D05C4B40
1164	Рославльский район	\N	13	32.575094999999997	33.689608	54.391579	53.667394999999999	0103000020E61000000100000005000000EB8B84B69C494040C84109336DD54A40EB8B84B69C4940407366BB421F324B40AD872F1345D840407366BB421F324B40AD872F1345D84040C84109336DD54A40EB8B84B69C494040C84109336DD54A40
1740	Починковский район	\N	13	32.098196999999999	33.090997999999999	54.684199	54.043298	0103000020E610000001000000050000005CC823B8910C4040B9FDF2C98A054B405CC823B8910C40405B7A34D593574B402E008DD2A58B40405B7A34D593574B402E008DD2A58B4040B9FDF2C98A054B405CC823B8910C4040B9FDF2C98A054B40
1419	Новодугинский район	\N	13	33.448276	34.739899999999999	55.816398999999997	55.398896000000001	0103000020E6100000010000000500000075CAA31B61B94040AB402D060FB34B4075CAA31B61B9404059BE2EC37FE84B40BB270F0BB55E414059BE2EC37FE84B40BB270F0BB55E4140AB402D060FB34B4075CAA31B61B94040AB402D060FB34B40
1859	Монастырщинский район	\N	13	31.286282	32.146993999999999	54.553798999999998	54.103008000000003	0103000020E61000000100000005000000F86EF3C649493F40FA9CBB5D2F0D4B40F86EF3C649493F405CC7B8E2E2464B40A75A0BB3D01240405CC7B8E2E2464B40A75A0BB3D0124040FA9CBB5D2F0D4B40F86EF3C649493F40FA9CBB5D2F0D4B40
382	Краснинский район	\N	13	30.911944999999999	31.871193000000002	54.788595000000001	54.323996000000001	0103000020E610000001000000050000002FC03E3A75E93E40750470B378294B402FC03E3A75E93E40026553AEF0644B400F81238106DF3F40026553AEF0644B400F81238106DF3F40750470B378294B402FC03E3A75E93E40750470B378294B40
1378	Кардымовский район	\N	13	32.135998999999998	32.832102999999996	55.080894999999998	54.654297999999997	0103000020E61000000100000005000000F4A44C6A681140404AEB6F09C0534B40F4A44C6A6811404078B471C45A8A4B40A5F3E159826A404078B471C45A8A4B40A5F3E159826A40404AEB6F09C0534B40F4A44C6A681140404AEB6F09C0534B40
1586	Ершичский район	\N	13	32.413083999999998	33.087198000000001	53.803398999999999	53.412863000000002	0103000020E610000001000000050000001C40BFEFDF3440403E5DDDB1D8B44A401C40BFEFDF344040CE5147C7D5E64A406823D74D298B4040CE5147C7D5E64A406823D74D298B40403E5DDDB1D8B44A401C40BFEFDF3440403E5DDDB1D8B44A40
1248	Ельнинский район	\N	13	32.863796000000001	33.783499999999997	54.772799999999997	54.283197000000001	0103000020E61000000100000005000000333509DE906E4040A4A99ECC3F244B40333509DE906E4040A52C431CEB624B403F355EBA49E44040A52C431CEB624B403F355EBA49E44040A4A99ECC3F244B40333509DE906E4040A4A99ECC3F244B40
1480	Духовщинский район	\N	13	31.906092999999998	32.756348000000003	55.740628999999998	55.025869999999998	0103000020E610000001000000050000007022FAB5F5E73F4048F949B54F834B407022FAB5F5E73F400EBC5AEECCDE4B409032E202D06040400EBC5AEECCDE4B409032E202D060404048F949B54F834B407022FAB5F5E73F4048F949B54F834B40
303	Дорогобужский район	\N	13	32.779291000000001	33.844495000000002	55.062595999999999	54.635198000000003	0103000020E610000001000000050000009888B7CEBF634040083E062B4E514B409888B7CEBF634040226E4E2503884B405951836918EC4040226E4E2503884B405951836918EC4040083E062B4E514B409888B7CEBF634040083E062B4E514B40
1341	Демидовский район	\N	13	31.171396999999999	32.147298999999997	55.787385999999998	55.035699000000001	0103000020E61000000100000005000000ECA17DACE02B3F40FDBFEAC891844B40ECA17DACE02B3F4004AA7F10C9E44B40E3DD91B1DA12404004AA7F10C9E44B40E3DD91B1DA124040FDBFEAC891844B40ECA17DACE02B3F40FDBFEAC891844B40
1311	Глинковский район	\N	13	32.471491999999998	33.138294000000002	54.886398999999997	54.4114	0103000020E61000000100000005000000AE2990D9593C404086C954C1A8344B40AE2990D9593C4040821ABE8575714B40D49D279EB3914040821ABE8575714B40D49D279EB391404086C954C1A8344B40AE2990D9593C404086C954C1A8344B40
1219	Гагаринский район	\N	13	34.441012999999998	35.333084999999997	55.982688000000003	55.281450999999997	0103000020E61000000100000005000000300E2E1D7338414097361C9606A44B40300E2E1D73384140F9156BB8C8FD4B40E2E47E87A2AA4140F9156BB8C8FD4B40E2E47E87A2AA414097361C9606A44B40300E2E1D7338414097361C9606A44B40
291	Вяземский район	\N	13	33.683292999999999	34.923794000000001	55.533695000000002	54.840696999999999	0103000020E61000000100000005000000F94A202576D74040336C94F59B6B4B40F94A202576D74040F584251E50C44B40DA1EBDE13E764140F584251E50C44B40DA1EBDE13E764140336C94F59B6B4B40F94A202576D74040336C94F59B6B4B40
1097	Велижский район	\N	13	30.889883000000001	31.777785999999999	55.760525000000001	55.362096000000001	0103000020E6100000010000000500000031444E5FCFE33E409701672959AE4B4031444E5FCFE33E402C6519E258E14B406249B9FB1CC73F402C6519E258E14B406249B9FB1CC73F409701672959AE4B4031444E5FCFE33E409701672959AE4B40
114	Шиловский район	\N	12	40.340797000000002	41.488593000000002	54.856797	54.083596999999997	0103000020E6100000010000000500000097C9703C9F2B44409885764EB30A4B4097C9703C9F2B4440CC272B86AB6D4B40FB0626378ABE4440CC272B86AB6D4B40FB0626378ABE44409885764EB30A4B4097C9703C9F2B44409885764EB30A4B40
1207	Шацкий район	\N	12	41.262692999999999	42.445981000000003	54.241294000000003	53.772956000000001	0103000020E61000000100000005000000AEF199EC9FA144409D9FE238F0E24A40AEF199EC9FA144404B5CC7B8E21E4B4096D1C8E7153945404B5CC7B8E21E4B4096D1C8E7153945409D9FE238F0E24A40AEF199EC9FA144409D9FE238F0E24A40
363	Чучковский район	\N	12	41.167695999999999	41.738593999999999	54.510599999999997	54.083798000000002	0103000020E61000000100000005000000C3D501107795444030BC92E4B90A4B40C3D501107795444036AB3E575B414B40CB82893F8ADE444036AB3E575B414B40CB82893F8ADE444030BC92E4B90A4B40C3D501107795444030BC92E4B90A4B40
1014	Ухоловский район	\N	12	40.216794	40.819598999999997	53.968097999999998	53.515397	0103000020E6100000010000000500000009FCE1E7BF1B44406FBA6587F8C14A4009FCE1E7BF1B444058A9A0A2EAFB4A40CA6ABA9EE868444058A9A0A2EAFB4A40CA6ABA9EE86844406FBA6587F8C14A4009FCE1E7BF1B44406FBA6587F8C14A40
885	Старожиловский район	\N	12	39.635494000000001	40.353895000000001	54.443795000000001	54.086095	0103000020E61000000100000005000000F1660DDE57D14340B0AC3429050B4B40F1660DDE57D143406D904946CE384B40E59B6D6E4C2D44406D904946CE384B40E59B6D6E4C2D4440B0AC3429050B4B40F1660DDE57D14340B0AC3429050B4B40
124	Спасский район	\N	12	40.014592	41.031395000000003	54.880597999999999	54.136898000000002	0103000020E6100000010000000500000041649126DE014440A471A8DF85114B4041649126DE01444025766D6FB7704B40042159C00484444025766D6FB7704B40042159C004844440A471A8DF85114B4041649126DE014440A471A8DF85114B40
712	Скопинский район	\N	12	38.789146000000002	39.963890999999997	53.988796999999998	53.624299000000001	0103000020E6100000010000000500000076E272BC0265434077F69507E9CF4A4076E272BC0265434003B16CE690FE4A4051F4C0C760FB434003B16CE690FE4A4051F4C0C760FB434077F69507E9CF4A4076E272BC0265434077F69507E9CF4A40
281	Сасовский район	\N	12	41.556299000000003	42.689855999999999	54.557198	54.070205000000001	0103000020E6100000010000000500000015E63DCE34C744400282397AFC084B4015E63DCE34C74440C4B2994352474B4085798F334D584540C4B2994352474B4085798F334D5845400282397AFC084B4015E63DCE34C744400282397AFC084B40
75	Сараевский район	\N	12	40.687196999999998	41.451644999999999	54.016300000000001	53.415455999999999	0103000020E6100000010000000500000064744012F6574440A77686A92DB54A4064744012F657444060764F1E16024B407233DC80CFB9444060764F1E16024B407233DC80CFB94440A77686A92DB54A4064744012F6574440A77686A92DB54A40
637	Сапожковский район	\N	12	40.332093	41.061892999999998	54.141697999999998	53.820098000000002	0103000020E61000000100000005000000821DFF05822A4440ECC1A4F8F8E84A40821DFF05822A44404DF4F92823124B40F86C1D1CEC8744404DF4F92823124B40F86C1D1CEC874440ECC1A4F8F8E84A40821DFF05822A4440ECC1A4F8F8E84A40
1339	Рязанский район	\N	12	39.353898999999998	40.449835	54.975015999999997	54.337452999999996	0103000020E61000000100000005000000268BFB8F4CAD4340F277EFA8312B4B40268BFB8F4CAD4340D2890453CD7C4B404FCC7A3194394440D2890453CD7C4B404FCC7A3194394440F277EFA8312B4B40268BFB8F4CAD4340F277EFA8312B4B40
757	Ряжский район	\N	12	39.707889000000002	40.398890999999999	53.8596	53.497489000000002	0103000020E610000001000000050000005D19541B9CDA4340548F34B8ADBF4A405D19541B9CDA434020D26F5F07EE4A4099D53BDC0E33444020D26F5F07EE4A4099D53BDC0E334440548F34B8ADBF4A405D19541B9CDA4340548F34B8ADBF4A40
703	Рыбновский район	\N	12	38.832993000000002	39.884929	54.991790000000002	54.454773000000003	0103000020E610000001000000050000000266BE839F6A43404A0D6D00363A4B400266BE839F6A4340FB3F87F9F27E4B4018247D5A45F14340FB3F87F9F27E4B4018247D5A45F143404A0D6D00363A4B400266BE839F6A43404A0D6D00363A4B40
7324	Рыбновский	\N	12	38.832993000000002	39.884929	54.991790000000002	54.454773000000003	0103000020E610000001000000050000000266BE839F6A43404A0D6D00363A4B400266BE839F6A4340FB3F87F9F27E4B4018247D5A45F14340FB3F87F9F27E4B4018247D5A45F143404A0D6D00363A4B400266BE839F6A43404A0D6D00363A4B40
507	Путятинский район	\N	12	40.668799	41.559891999999998	54.275300999999999	53.949798999999999	0103000020E610000001000000050000007B4CA4349B55444002637D0393F94A407B4CA4349B5544402EC72B103D234B4061A5828AAAC744402EC72B103D234B4061A5828AAAC7444002637D0393F94A407B4CA4349B55444002637D0393F94A40
415	Пронский район	\N	12	39.276392000000001	39.931992000000001	54.426597999999998	53.945295000000002	0103000020E61000000100000005000000227024D060A343404209336DFFF84A40227024D060A34340FE4465C39A364B401B118C834BF74340FE4465C39A364B401B118C834BF743404209336DFFF84A40227024D060A343404209336DFFF84A40
1568	Пителинский район	\N	12	41.460493	42.033897000000003	54.785096000000003	54.434899000000001	0103000020E61000000100000005000000BA84436FF1BA444014083BC5AA374B40BA84436FF1BA4440371C96067E644B405D37A5BC56044540371C96067E644B405D37A5BC5604454014083BC5AA374B40BA84436FF1BA444014083BC5AA374B40
1538	Новодеревенский район	\N	12	39.922604	40.647491000000002	53.624395	53.309004999999999	0103000020E6100000010000000500000053944BE317F6434076A6D0798DA74A4053944BE317F643409964E42CECCF4A4028BA2EFCE05244409964E42CECCF4A4028BA2EFCE052444076A6D0798DA74A4053944BE317F6434076A6D0798DA74A40
1071	Михайловский район	\N	12	38.682786	39.923133999999997	54.412176000000002	53.937413999999997	0103000020E6100000010000000500000055151A88655743400168942EFDF74A4055151A88655743401A19E42EC2344B40AFE9414129F643401A19E42EC2344B40AFE9414129F643400168942EFDF74A4055151A88655743400168942EFDF74A40
759	Милославский район	\N	12	38.875241000000003	39.763890000000004	53.776595	53.390079	0103000020E61000000100000005000000268FA7E5077043409EEDD11BEEB14A40268FA7E5077043405A9E077767E34A40E8DEC325C7E143405A9E077767E34A40E8DEC325C7E143409EEDD11BEEB14A40268FA7E5077043409EEDD11BEEB14A40
1174	Кораблинский район	\N	12	39.672593999999997	40.438794000000001	54.137298999999999	53.806998999999998	0103000020E610000001000000050000002FBE688F17D64340CD7344BE4BE74A402FBE688F17D6434002637D0393114B402CD7DB662A38444002637D0393114B402CD7DB662A384440CD7344BE4BE74A402FBE688F17D64340CD7344BE4BE74A40
478	Клепиковский район	\N	12	39.779125999999998	41.187117999999998	55.344551000000003	54.828211000000003	0103000020E610000001000000050000004DBB9866BAE34340FF976BD1026A4B404DBB9866BAE34340ED66463F1AAC4B40183F8D7BF3974440ED66463F1AAC4B40183F8D7BF3974440FF976BD1026A4B404DBB9866BAE34340FF976BD1026A4B40
780	Касимовский район	\N	12	40.684393999999998	42.073476999999997	55.234101000000003	54.596795999999998	0103000020E6100000010000000500000010CAFB389A5744401A31B3CF634C4B4010CAFB389A574440FF7A8505F79D4B400C01C0B167094540FF7A8505F79D4B400C01C0B1670945401A31B3CF634C4B4010CAFB389A5744401A31B3CF634C4B40
725	Кадомский район	\N	12	41.978892999999999	42.692208999999998	54.712434999999999	54.311193000000003	0103000020E6100000010000000500000044A4A65D4CFD444040DF162CD5274B4044A4A65D4CFD44404CC3F011315B4B40997FF44D9A5845404CC3F011315B4B40997FF44D9A58454040DF162CD5274B4044A4A65D4CFD444040DF162CD5274B40
401	Захаровский район	\N	12	38.789693999999997	39.638691999999999	54.633119000000001	54.241061999999999	0103000020E6100000010000000500000078EC67B11465434078279F1EDB1E4B4078EC67B114654340F5BC1B0B0A514B40C11BD2A8C0D14340F5BC1B0B0A514B40C11BD2A8C0D1434078279F1EDB1E4B4078EC67B11465434078279F1EDB1E4B40
388	Ермишинский район	\N	12	41.841090999999999	42.507156000000002	55.024579000000003	54.563493999999999	0103000020E61000000100000005000000DFFAB0DEA8EB444001BF469220484B40DFFAB0DEA8EB44408E95986725834B402FFCE07CEA4045408E95986725834B402FFCE07CEA40454001BF469220484B40DFFAB0DEA8EB444001BF469220484B40
2131	Щигровский район	\N	11	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
1822	Шаблыкинский район	\N	11	34.794454999999999	35.456297999999997	53.021940999999998	52.695875999999998	0103000020E61000000100000005000000649291B3B06541402009FB7612594A40649291B3B065414084B872F6CE824A40779D0DF967BA414084B872F6CE824A40779D0DF967BA41402009FB7612594A40649291B3B06541402009FB7612594A40
570	Хотынецкий район	\N	11	35.104804999999999	35.628692999999998	53.335054	52.944097999999997	0103000020E6100000010000000500000088BA0F406A8D4140081C0934D8784A4088BA0F406A8D41406E32AA0CE3AA4A40B01C210379D041406E32AA0CE3AA4A40B01C210379D04140081C0934D8784A4088BA0F406A8D4140081C0934D8784A40
509	Урицкий район	\N	11	35.371091999999997	35.898995999999997	53.200296000000002	52.806694	0103000020E6100000010000000500000053E751F17FAF414091F0BDBF41674A4053E751F17FAF414083C2A04CA3994A400E9E094D12F3414083C2A04CA3994A400E9E094D12F3414091F0BDBF41674A4053E751F17FAF414091F0BDBF41674A40
1495	Троснянский район	\N	11	35.535097999999998	36.125191999999998	52.543897999999999	52.249676000000001	0103000020E61000000100000005000000D7135D177EC441404D4C1762F51F4A40D7135D177EC441400E2E1D739E454A4044DC9C4A061042400E2E1D739E454A4044DC9C4A061042404D4C1762F51F4A40D7135D177EC441404D4C1762F51F4A40
1493	Сосковский район	\N	11	35.181099000000003	35.670492000000003	52.909697000000001	52.574798000000001	0103000020E610000001000000050000004E2B85402E97414032E719FB92494A404E2B85402E974140792288F370744A40651D8EAED2D54140792288F370744A40651D8EAED2D5414032E719FB92494A404E2B85402E97414032E719FB92494A40
1212	Свердловский район	\N	11	35.945700000000002	36.678896000000002	52.847394000000001	52.506098000000001	0103000020E61000000100000005000000E2E995B20CF941401749BBD1C7404A40E2E995B20CF94140CF691668776C4A404FB16A10E6564240CF691668776C4A404FB16A10E65642401749BBD1C7404A40E2E995B20CF941401749BBD1C7404A40
1470	Покровский район	\N	11	36.585597	37.248094999999999	52.788894999999997	52.355398999999998	0103000020E610000001000000050000005FD1ADD7F44A4240FB03E5B67D2D4A405FD1ADD7F44A42402C7DE882FA644A408BA6B393C19F42402C7DE882FA644A408BA6B393C19F4240FB03E5B67D2D4A405FD1ADD7F44A4240FB03E5B67D2D4A40
1598	Орловский район	\N	11	35.665847999999997	36.453805000000003	53.265433999999999	52.720973999999998	0103000020E61000000100000005000000B20DDC813AD5414016A243E0485C4A40B20DDC813AD541408C9FC6BDF9A14A4072E14048163A42408C9FC6BDF9A14A4072E14048163A424016A243E0485C4A40B20DDC813AD5414016A243E0485C4A40
1532	Новосильский район	\N	11	36.785598	37.315199	53.200597999999999	52.872295999999999	0103000020E61000000100000005000000C9E6AA798E6442403F373465A76F4A40C9E6AA798E6442404ED2FC31AD994A40AF5DDA7058A842404ED2FC31AD994A40AF5DDA7058A842403F373465A76F4A40C9E6AA798E6442403F373465A76F4A40
1144	Новодеревеньковский район	\N	11	37.228898000000001	37.87697	53.128359000000003	52.796697999999999	0103000020E61000000100000005000000560F98874C9D4240F1643733FA654A40560F98874C9D4240DA9255116E904A405CC98E8D40F04240DA9255116E904A405CC98E8D40F04240F1643733FA654A40560F98874C9D4240F1643733FA654A40
1037	Мценский район	\N	11	36.113514000000002	37.032598	53.462496999999999	53.026094999999998	0103000020E61000000100000005000000AFD172A0870E424068CBB91457834A40AFD172A0870E4240C2BF081A33BB4A401FF5D72B2C844240C2BF081A33BB4A401FF5D72B2C84424068CBB91457834A40AFD172A0870E424068CBB91457834A40
1381	Малоархангельский район	\N	11	36.275596999999998	36.875698999999997	52.576500000000003	52.207064000000003	0103000020E6100000010000000500000017F032C346234240E816BA12811A4A4017F032C3462342406F1283C0CA494A40E811A3E7167042406F1283C0CA494A40E811A3E716704240E816BA12811A4A4017F032C346234240E816BA12811A4A40
6911	Ливны городской округ	\N	11	37.529015999999999	37.645887000000002	52.446719999999999	52.395825000000002	0103000020E61000000100000005000000C687D9CBB6C3424038F8C264AA324A40C687D9CBB6C342400C3CF71E2E394A40AEF4DA6CACD242400C3CF71E2E394A40AEF4DA6CACD2424038F8C264AA324A40C687D9CBB6C3424038F8C264AA324A40
1236	Ливенский район	\N	11	37.211291000000003	38.065660999999999	52.652597	52.169502999999999	0103000020E6100000010000000500000036785F950B9B424075C93846B2154A4036785F950B9B4240DE3B6A4C88534A40B3CF639467084340DE3B6A4C88534A40B3CF63946708434075C93846B2154A4036785F950B9B424075C93846B2154A40
1180	Кромский район	\N	11	35.468595999999998	36.094892000000002	52.845196999999999	52.487198999999997	0103000020E61000000100000005000000A98427F4FABB41406BD26D895C3E4A40A98427F4FABB4140B2D6506A2F6C4A407653CA6B250C4240B2D6506A2F6C4A407653CA6B250C42406BD26D895C3E4A40A98427F4FABB41406BD26D895C3E4A40
1135	Краснозоренский район	\N	11	37.392392000000001	37.901242000000003	52.885593999999998	52.600670999999998	0103000020E61000000100000005000000249BABE639B24240EB538EC9E24C4A40249BABE639B2424054C4E9245B714A400DE4D9E55BF3424054C4E9245B714A400DE4D9E55BF34240EB538EC9E24C4A40249BABE639B24240EB538EC9E24C4A40
1571	Корсаковский район	\N	11	36.988194999999997	37.609290000000001	53.301901999999998	53.049594999999997	0103000020E610000001000000050000000D897B2C7D7E4240C685032159864A400D897B2C7D7E42406A4C88B9A4A64A40D2E3F736FDCD42406A4C88B9A4A64A40D2E3F736FDCD4240C685032159864A400D897B2C7D7E4240C685032159864A40
1062	Колпнянский район	\N	11	36.635866	37.338698999999998	52.409999999999997	52.073791999999997	0103000020E61000000100000005000000B5519D0E645142406C5A290472094A40B5519D0E6451424014AE47E17A344A400D18247D5AAB424014AE47E17A344A400D18247D5AAB42406C5A290472094A40B5519D0E645142406C5A290472094A40
7147	Каменский район	\N	11	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
1166	Знаменский район	\N	11	35.370491000000001	35.880598999999997	53.523850000000003	53.155997999999997	0103000020E610000001000000050000002E3BC43F6CAF4140E61E12BEF7934A402E3BC43F6CAF41403B014D840DC34A40F5F1D077B7F041403B014D840DC34A40F5F1D077B7F04140E61E12BEF7934A402E3BC43F6CAF4140E61E12BEF7934A40
973	Залегощенский район	\N	11	36.301999000000002	37.044995	53.078496000000001	52.727497	0103000020E610000001000000050000005D363AE7A72642401478279F1E5D4A405D363AE7A7264240F46E2C280C8A4A40E4BD6A65C2854240F46E2C280C8A4A40E4BD6A65C28542401478279F1E5D4A405D363AE7A72642401478279F1E5D4A40
6867	Железногорский район	\N	11	34.794482000000002	38.065508000000001	53.652197999999999	51.934215999999999	0103000020E610000001000000050000005EA10F96B165414031B3CF6394F749405EA10F96B165414020425C397BD34A402DD0EE906208434020425C397BD34A402DD0EE906208434031B3CF6394F749405EA10F96B165414031B3CF6394F74940
896	Должанский район	\N	11	37.176571000000003	37.796427000000001	52.252301000000003	51.936410000000002	0103000020E610000001000000050000000536E7E099964240DDD26A48DCF749400536E7E099964240C2DF2F664B204A406153E751F1E54240C2DF2F664B204A406153E751F1E54240DDD26A48DCF749400536E7E099964240DDD26A48DCF74940
832	Дмитровский район	\N	11	34.848739999999999	35.592095999999998	52.717095	52.319968000000003	0103000020E610000001000000050000004D672783A36C41401EE21FB6F4284A404D672783A36C41400490DAC4C95B4A40D40B3ECDC9CB41400490DAC4C95B4A40D40B3ECDC9CB41401EE21FB6F4284A404D672783A36C41401EE21FB6F4284A40
691	Глазуновский район	\N	11	35.976996999999997	36.529496999999999	52.585698000000001	52.312018000000002	0103000020E6100000010000000500000022A5D93C0EFD4140B5E1B034F0274A4022A5D93C0EFD414093AAED26F84A4A40412AC58EC643424093AAED26F84A4A40412AC58EC6434240B5E1B034F0274A4022A5D93C0EFD4140B5E1B034F0274A40
603	Верховский район	\N	11	36.897294000000002	37.564796000000001	52.971499000000001	52.459299000000001	0103000020E61000000100000005000000D272A087DA724240F20A444FCA3A4A40D272A087DA724240618C48145A7C4A40B0743E3C4BC84240618C48145A7C4A40B0743E3C4BC84240F20A444FCA3A4A40D272A087DA724240F20A444FCA3A4A40
434	Болховский район	\N	11	35.612532999999999	36.383654999999997	53.652293999999998	53.21922	0103000020E61000000100000005000000425C397B67CE41408750A5660F9C4A40425C397B67CE414042B0AA5E7ED34A4033F9669B1B31424042B0AA5E7ED34A4033F9669B1B3142408750A5660F9C4A40425C397B67CE41408750A5660F9C4A40
7460	городской округ Реутов	\N	10	37.842367000000003	37.888944000000002	55.781427999999998	55.744475000000001	0103000020E61000000100000005000000651D8EAED2EB424045D8F0F44ADF4B40651D8EAED2EB4240DF162CD505E44B40DBFCBFEAC8F14240DF162CD505E44B40DBFCBFEAC8F1424045D8F0F44ADF4B40651D8EAED2EB424045D8F0F44ADF4B40
490	городской округ Черноголовка	\N	10	38.258969	38.475670000000001	56.088487999999998	55.979208	0103000020E61000000100000005000000C3D66CE525214340A4FD0FB056FD4B40C3D66CE525214340520B2593530B4C401BD82AC1E23C4340520B2593530B4C401BD82AC1E23C4340A4FD0FB056FD4B40C3D66CE525214340A4FD0FB056FD4B40
1692	городской округ Серпухов	\N	10	37.348024000000002	37.489193999999998	54.957039999999999	54.891986000000003	0103000020E610000001000000050000008F1CE90C8CAC4240B43EE5982C724B408F1CE90C8CAC42405F7B6649807A4B4020B3B3E89DBE42405F7B6649807A4B4020B3B3E89DBE4240B43EE5982C724B408F1CE90C8CAC4240B43EE5982C724B40
89	городской округ Подольск	\N	10	37.471479000000002	37.610287	55.487789999999997	55.389907999999998	0103000020E610000001000000050000001AE0826C59BC424071395E81E8B14B401AE0826C59BC42406DA818E76FBE4B40441669E21DCE42406DA818E76FBE4B40441669E21DCE424071395E81E8B14B401AE0826C59BC424071395E81E8B14B40
1767	городской округ Краснознаменск (ЗАТО)	\N	10	37.009943	37.067318	55.609074999999997	55.580508000000002	0103000020E610000001000000050000007DE9EDCF458142407F880D164ECA4B407DE9EDCF45814240D5E76A2BF6CD4B40503750E09D884240D5E76A2BF6CD4B40503750E09D8842407F880D164ECA4B407DE9EDCF458142407F880D164ECA4B40
1433	городской округ Коломна	\N	10	38.691049999999997	38.906771999999997	55.146625	55.025497999999999	0103000020E610000001000000050000004DF38E5374584340840EBA8443834B404DF38E537458434054E3A59BC4924B40D976DA1A1174434054E3A59BC4924B40D976DA1A11744340840EBA8443834B404DF38E5374584340840EBA8443834B40
7481	городской округ Климовск	\N	10	37.486893999999999	37.602705	55.389524000000002	55.339272999999999	0103000020E610000001000000050000002F4FE78A52BE424039B5334C6DAB4B402F4FE78A52BE4240E98024ECDBB14B405E11FC6F25CD4240E98024ECDBB14B405E11FC6F25CD424039B5334C6DAB4B402F4FE78A52BE424039B5334C6DAB4B40
974	городской округ Звенигород	\N	10	36.776606000000001	36.963949	55.762774	55.684676000000003	0103000020E610000001000000050000004EF04DD367634240952D9276A3D74B404EF04DD3676342409B1E1494A2E14B4086014BAE627B42409B1E1494A2E14B4086014BAE627B4240952D9276A3D74B404EF04DD367634240952D9276A3D74B40
344	городской округ Домодедово	\N	10	37.604996	38.120728	55.523214000000003	55.124428999999999	0103000020E61000000100000005000000FC1A498270CD424045D61A4AED8F4B40FC1A498270CD4240996725ADF8C24B4012DBDD03740F4340996725ADF8C24B4012DBDD03740F434045D61A4AED8F4B40FC1A498270CD424045D61A4AED8F4B40
1549	городской округ Власиха (ЗАТО)	\N	10	37.167893999999997	37.212172000000002	55.692881	55.677351999999999	0103000020E61000000100000005000000E998F38C7D954240AAF06778B3D64B40E998F38C7D95424088821953B0D84B403F90BC73289B424088821953B0D84B403F90BC73289B4240AAF06778B3D64B40E998F38C7D954240AAF06778B3D64B40
915	городской округ Балашиха	\N	10	37.740130000000001	38.157854999999998	55.891672999999997	55.695214999999997	0103000020E61000000100000005000000ED647094BCDE424025581CCEFCD84B40ED647094BCDE4240F4DC425722F24B404A41B79734144340F4DC425722F24B404A41B7973414434025581CCEFCD84B40ED647094BCDE424025581CCEFCD84B40
930	городской округ  Молодежный (ЗАТО)	\N	10	36.776597000000002	36.832974999999998	55.340881000000003	55.316620999999998	0103000020E61000000100000005000000FB95CE8767634240081D740987A84B40FB95CE8767634240F56915FDA1AB4B405BB1BFEC9E6A4240F56915FDA1AB4B405BB1BFEC9E6A4240081D740987A84B40FB95CE8767634240081D740987A84B40
78	Щелковский район	\N	10	37.896535	38.547103999999997	56.230891999999997	55.818644999999997	0103000020E61000000100000005000000145CACA8C1F242405704FF5BC9E84B40145CACA8C1F242403A747ADE8D1D4C4061C1FD80074643403A747ADE8D1D4C4061C1FD80074643405704FF5BC9E84B40145CACA8C1F242405704FF5BC9E84B40
957	Шаховской район	\N	10	35.143180999999998	35.752149000000003	56.243063999999997	55.757485000000003	0103000020E610000001000000050000004C3448C153924140F41ABB44F5E04B404C3448C153924140DF6A9DB81C1F4C400C5C1E6B46E04140DF6A9DB81C1F4C400C5C1E6B46E04140F41ABB44F5E04B404C3448C153924140F41ABB44F5E04B40
794	Шатурский район	\N	10	39.331251999999999	40.204334000000003	55.842700999999998	55.009785999999998	0103000020E61000000100000005000000075E2D7766AA4340B5FAEAAA40814B40075E2D7766AA43403BA759A0DDEB4B40FEBAD39D271A44403BA759A0DDEB4B40FEBAD39D271A4440B5FAEAAA40814B40075E2D7766AA4340B5FAEAAA40814B40
565	Чеховский район	\N	10	37.051625000000001	37.738782	55.308956000000002	55.002625000000002	0103000020E61000000100000005000000F853E3A59B8642407593180456804B40F853E3A59B86424095F3C5DE8BA74B40CE6F986890DE424095F3C5DE8BA74B40CE6F986890DE42407593180456804B40F853E3A59B8642407593180456804B40
1865	Талдомский район	\N	10	37.175052999999998	38.065984	56.961320000000001	56.504441999999997	0103000020E610000001000000050000008908FF22689642404A5D328E91404C408908FF2268964240D07EA4880C7B4C409607E92972084340D07EA4880C7B4C409607E929720843404A5D328E91404C408908FF22689642404A5D328E91404C40
675	Ступинский район	\N	10	37.676276999999999	38.462662000000002	55.287348000000001	54.825077999999998	0103000020E61000000100000005000000BC04A73E90D642401553E9279C694B40BC04A73E90D642401749BBD1C7A44B400D8D2782383B43401749BBD1C7A44B400D8D2782383B43401553E9279C694B40BC04A73E90D642401553E9279C694B40
143	Солнечногорский район	\N	10	36.709896999999998	37.427757999999997	56.365741999999997	55.884878	0103000020E61000000100000005000000A643A7E7DD5A42409679ABAE43F14B40A643A7E7DD5A4240066344A2D02E4C401A4D2EC6C0B64240066344A2D02E4C401A4D2EC6C0B642409679ABAE43F14B40A643A7E7DD5A42409679ABAE43F14B40
532	Серпуховский район	\N	10	37.081969999999998	37.898152000000003	55.062838999999997	54.718364000000001	0103000020E6100000010000000500000066A032FE7D8A4240D74FFF59F35B4B4066A032FE7D8A4240E8F4BC1B0B884B40236B0DA5F6F24240E8F4BC1B0B884B40236B0DA5F6F24240D74FFF59F35B4B4066A032FE7D8A4240D74FFF59F35B4B40
560	Серебряно-Прудский район	\N	10	38.377071000000001	38.940466999999998	54.667161	54.256076	0103000020E6100000010000000500000090A2CEDC433043402FA52E19C7204B4090A2CEDC4330434055151A8865554B40CEFBFF386178434055151A8865554B40CEFBFF38617843402FA52E19C7204B4090A2CEDC433043402FA52E19C7204B40
506	Сергиево-Посадский район	\N	10	37.741998000000002	38.447758999999998	56.795504999999999	56.168576000000002	0103000020E6100000010000000500000045D95BCAF9DE4240FC71FBE593154C4045D95BCAF9DE4240F9669B1BD3654C40ADBEBA2A50394340F9669B1BD3654C40ADBEBA2A50394340FC71FBE593154C4045D95BCAF9DE4240FC71FBE593154C40
792	Рузский район	\N	10	35.808374000000001	36.612141999999999	56.003774	55.3934	0103000020E61000000100000005000000E6779ACC78E741408A1F63EE5AB24B40E6779ACC78E741409D499BAA7B004C40074147AB5A4E42409D499BAA7B004C40074147AB5A4E42408A1F63EE5AB24B40E6779ACC78E741408A1F63EE5AB24B40
443	Раменский район	\N	10	37.905850999999998	38.645837999999998	55.709555999999999	55.239927999999999	0103000020E610000001000000050000004206F2ECF2F3424085B2F0F5B59E4B404206F2ECF2F342401D5723BBD2DA4B40CC41D0D1AA5243401D5723BBD2DA4B40CC41D0D1AA52434085B2F0F5B59E4B404206F2ECF2F3424085B2F0F5B59E4B40
367	Пушкинский район	\N	10	37.689267000000001	38.187525999999998	56.230736999999998	55.942810999999999	0103000020E61000000100000005000000249BABE639D842408FA7E507AEF84B40249BABE639D84240137D3ECA881D4C4029931ADA00184340137D3ECA881D4C4029931ADA001843408FA7E507AEF84B40249BABE639D842408FA7E507AEF84B40
7541	Пушкинский	\N	10	37.997388999999998	38.011159999999997	56.103512000000002	56.095815000000002	0103000020E61000000100000005000000F0315871AAFF4240AEBB79AA430C4C40F0315871AAFF42402D5F97E13F0D4C40FD82DDB06D0143402D5F97E13F0D4C40FD82DDB06D014340AEBB79AA430C4C40F0315871AAFF4240AEBB79AA430C4C40
377	Подольский район	\N	10	36.943458999999997	37.727345999999997	55.521434999999997	55.135134999999998	0103000020E61000000100000005000000F50EB743C3784240C1C58A1A4C914B40F50EB743C3784240B0FECF61BEC24B402E7079AC19DD4240B0FECF61BEC24B402E7079AC19DD4240C1C58A1A4C914B40F50EB743C3784240C1C58A1A4C914B40
273	Павлово-Посадский район	\N	10	38.479066000000003	38.866625999999997	55.989708	55.595939000000001	0103000020E610000001000000050000001250E108523D43409AB4A9BA47CC4B401250E108523D4340774B72C0AEFE4B4080EECB99ED6E4340774B72C0AEFE4B4080EECB99ED6E43409AB4A9BA47CC4B401250E108523D43409AB4A9BA47CC4B40
554	Орехово-Зуевский район	\N	10	38.585039999999999	39.538322999999998	55.95384	55.395761999999998	0103000020E61000000100000005000000096D3997E24A4340F17F4754A8B24B40096D3997E24A4340EECEDA6D17FA4B40A1D79FC4E7C44340EECEDA6D17FA4B40A1D79FC4E7C44340F17F4754A8B24B40096D3997E24A4340F17F4754A8B24B40
1241	Озерский район	\N	10	38.302734999999998	38.803986000000002	55.020899999999997	54.743780000000001	0103000020E61000000100000005000000622D3E05C02643409EB5DB2E345F4B40622D3E05C0264340423EE8D9AC824B408F386403E9664340423EE8D9AC824B408F386403E96643409EB5DB2E345F4B40622D3E05C02643409EB5DB2E345F4B40
108	Одинцовский район	\N	10	36.383924999999998	37.417706000000003	55.848165000000002	55.492241999999997	0103000020E61000000100000005000000F38E537424314240DBDB2DC901BF4B40F38E537424314240514EB4AB90EC4B40E7ABE46377B54240514EB4AB90EC4B40E7ABE46377B54240DBDB2DC901BF4B40F38E537424314240DBDB2DC901BF4B40
152	Ногинский район	\N	10	38.051853999999999	38.646816999999999	56.080758000000003	55.674081999999999	0103000020E610000001000000050000005915E126A30643404069A85148D64B405915E126A3064340F8713447560A4C4098BF42E6CA524340F8713447560A4C4098BF42E6CA5243404069A85148D64B405915E126A30643404069A85148D64B40
260	Наро-Фоминский район	\N	10	35.868256000000002	37.351689	55.623544000000003	55.170650000000002	0103000020E6100000010000000500000024473A0323EF4140FD87F4DBD7954B4024473A0323EF4140FBCE2F4AD0CF4B4075AE282504AD4240FBCE2F4AD0CF4B4075AE282504AD4240FD87F4DBD7954B4024473A0323EF4140FD87F4DBD7954B40
464	Мытищинский район	\N	10	37.436678999999998	37.857323999999998	56.165337999999998	55.868445000000001	0103000020E61000000100000005000000CCECF318E5B74240F7AFAC3429EF4B40CCECF318E5B742409D64ABCB29154C40B709F7CABCED42409D64ABCB29154C40B709F7CABCED4240F7AFAC3429EF4B40CCECF318E5B74240F7AFAC3429EF4B40
7507	Московская область	\N	10	35.144106000000001	40.204334000000003	56.961320000000001	54.256076	0103000020E610000001000000050000002594BE10729241402FA52E19C7204B402594BE1072924140D07EA4880C7B4C40FEBAD39D271A4440D07EA4880C7B4C40FEBAD39D271A44402FA52E19C7204B402594BE10729241402FA52E19C7204B40
670	Можайский район	\N	10	35.257680000000001	36.268329999999999	55.820936000000003	55.229500999999999	0103000020E61000000100000005000000A96A82A8FBA041401CB3EC49609D4B40A96A82A8FBA04140F60D4C6E14E94B4091442FA358224240F60D4C6E14E94B4091442FA3582242401CB3EC49609D4B40A96A82A8FBA041401CB3EC49609D4B40
227	Люберецкий район	\N	10	37.856901999999998	38.087139999999998	55.720849000000001	55.566679000000001	0103000020E6100000010000000500000041F0F8F6AEED42403D2AFEEF88C84B4041F0F8F6AEED42405A2DB0C744DC4B4033164D67270B43405A2DB0C744DC4B4033164D67270B43403D2AFEEF88C84B4041F0F8F6AEED42403D2AFEEF88C84B40
109	Луховицкий район	\N	10	38.756042999999998	39.592447	55.138438999999998	54.703811000000002	0103000020E6100000010000000500000053AF5B04C660434054C8957A165A4B4053AF5B04C6604340D7BE805EB8914B4081CEA44DD5CB4340D7BE805EB8914B4081CEA44DD5CB434054C8957A165A4B4053AF5B04C660434054C8957A165A4B40
993	Лотошинский район	\N	10	35.406477000000002	36.128785000000001	56.478113999999998	56.111899999999999	0103000020E61000000100000005000000C1C9367007B4414011363CBD520E4C40C1C9367007B441403FE1ECD6323D4C40919BE1067C1042403FE1ECD6323D4C40919BE1067C10424011363CBD520E4C40C1C9367007B4414011363CBD520E4C40
150	Ленинский район	\N	10	37.215899999999998	37.965210999999996	55.664755999999997	55.450961	0103000020E610000001000000050000006B9A779CA29B4240BF620D17B9B94B406B9A779CA29B4240EEE87FB916D54B40A65EB7088CFB4240EEE87FB916D54B40A65EB7088CFB4240BF620D17B9B94B406B9A779CA29B4240BF620D17B9B94B40
292	Красногорский район	\N	10	37.076327999999997	37.411085999999997	55.916919999999998	55.732053000000001	0103000020E6100000010000000500000071E2AB1DC589424027F8A6E9B3DD4B4071E2AB1DC58942402F8672A25DF54B40F6EB4E779EB442402F8672A25DF54B40F6EB4E779EB4424027F8A6E9B3DD4B4071E2AB1DC589424027F8A6E9B3DD4B40
1350	Коломенский район	\N	10	38.391570000000002	39.326438000000003	55.264716999999997	54.936062	0103000020E61000000100000005000000200C3CF71E324340A1832EE1D0774B40200C3CF71E324340FDD8243FE2A14B40F9156BB8C8A94340FDD8243FE2A14B40F9156BB8C8A94340A1832EE1D0774B40200C3CF71E324340A1832EE1D0774B40
205	Клинский район	\N	10	36.089816999999996	37.113320999999999	56.595896000000003	56.064273	0103000020E61000000100000005000000FACF9A1F7F0B4240068200193A084C40FACF9A1F7F0B42409BE8F351464C4C409A79724D818E42409BE8F351464C4C409A79724D818E4240068200193A084C40FACF9A1F7F0B4240068200193A084C40
484	Каширский район	\N	10	37.956004	38.581420000000001	54.871848999999997	54.630080999999997	0103000020E610000001000000050000002F6CCD565EFA42405D6A847EA6504B402F6CCD565EFA424070067FBF986F4B40C39E76F86B4A434070067FBF986F4B40C39E76F86B4A43405D6A847EA6504B402F6CCD565EFA42405D6A847EA6504B40
204	Истринский район	\N	10	36.258305	37.178117	56.109526000000002	55.760702000000002	0103000020E6100000010000000500000057B26323102142403B00E2AE5EE14B4057B2632310214240E607AEF2040E4C404AEEB089CC964240E607AEF2040E4C404AEEB089CC9642403B00E2AE5EE14B4057B26323102142403B00E2AE5EE14B40
886	Зарайский район	\N	10	38.532910999999999	39.257384000000002	54.904420999999999	54.592450999999997	0103000020E61000000100000005000000DE567A6D36444340C2BD326FD54B4B40DE567A6D3644434066683C11C4734B40C0417BF5F1A0434066683C11C4734B40C0417BF5F1A04340C2BD326FD54B4B40DE567A6D36444340C2BD326FD54B4B40
81	Егорьевский район	\N	10	38.882058999999998	39.728425000000001	55.531509	54.987126000000004	0103000020E610000001000000050000003C122F4FE770434002840F255A7E4B403C122F4FE7704340CC43A67C08C44B405E4BC8073DDD4340CC43A67C08C44B405E4BC8073DDD434002840F255A7E4B403C122F4FE770434002840F255A7E4B40
7542	Домодедовский район	\N	10	35.144106000000001	40.204334000000003	56.961320000000001	54.256076	0103000020E610000001000000050000002594BE10729241402FA52E19C7204B402594BE1072924140D07EA4880C7B4C40FEBAD39D271A4440D07EA4880C7B4C40FEBAD39D271A44402FA52E19C7204B402594BE10729241402FA52E19C7204B40
749	Дмитровский район	\N	10	36.97428	37.879781999999999	56.696613999999997	56.032881000000003	0103000020E61000000100000005000000CD920035B57C424074D4D17135044C40CD920035B57C4240C6F7C5A52A594C4003CE52B29CF04240C6F7C5A52A594C4003CE52B29CF0424074D4D17135044C40CD920035B57C424074D4D17135044C40
1242	Воскресенский район	\N	10	38.363551000000001	38.930720999999998	55.566837	55.208686999999998	0103000020E61000000100000005000000CCB6D3D6882E4340D80C7041B69A4B40CCB6D3D6882E4340D594641D8EC84B40A759A0DD21774340D594641D8EC84B40A759A0DD21774340D80C7041B69A4B40CCB6D3D6882E4340D80C7041B69A4B40
584	Волоколамский район	\N	10	35.602786000000002	36.349600000000002	56.313903000000003	55.709164999999999	0103000020E610000001000000050000004B3E761728CD4140E23B31EBC5DA4B404B3E761728CD4140E38E37F92D284C403F575BB1BF2C4240E38E37F92D284C403F575BB1BF2C4240E23B31EBC5DA4B404B3E761728CD4140E23B31EBC5DA4B40
1793	Чаплыгинский район	\N	9	39.546677000000003	40.179451	53.587840999999997	52.958095999999998	0103000020E61000000100000005000000DA3C0E83F9C54340D636C5E3A27A4A40DA3C0E83F9C54340BC1FB75F3ECB4A40041E1840F8164440BC1FB75F3ECB4A40041E1840F8164440D636C5E3A27A4A40DA3C0E83F9C54340D636C5E3A27A4A40
1681	Хлевенский район	\N	9	38.801192999999998	39.408498999999999	52.347296	51.983116000000003	0103000020E610000001000000050000005E64027E8D6643405116BEBED6FD49405E64027E8D6643400C040132742C4A406FB9FAB149B443400C040132742C4A406FB9FAB149B443405116BEBED6FD49405E64027E8D6643405116BEBED6FD4940
1726	Усманский район	\N	9	39.348095999999998	40.151494999999997	52.353298000000002	51.919525999999998	0103000020E6100000010000000500000028EFE3688EAC43402DE92807B3F5494028EFE3688EAC434001DF6DDE382D4A40F6402B306413444001DF6DDE382D4A40F6402B30641344402DE92807B3F5494028EFE3688EAC43402DE92807B3F54940
1665	Тербунский район	\N	9	38.006093999999997	38.878196000000003	52.324294999999999	51.966689000000002	0103000020E61000000100000005000000D5592DB0C700434094331477BCFB4940D5592DB0C7004340CFA0A17F82294A4030BDFDB968704340CFA0A17F82294A4030BDFDB96870434094331477BCFB4940D5592DB0C700434094331477BCFB4940
1606	Становлянский район	\N	9	37.834066	38.629192000000003	53.056489999999997	52.641401000000002	0103000020E610000001000000050000004F5AB8ACC2EA4240944F8F6D19524A404F5AB8ACC2EA4240884677103B874A40D2730B5D89504340884677103B874A40D2730B5D89504340944F8F6D19524A404F5AB8ACC2EA4240944F8F6D19524A40
1512	Липецкий район	\N	9	38.981898000000001	39.736393	52.830711000000001	52.285181000000001	0103000020E6100000010000000500000000016BD5AE7D434065389ECF80244A4000016BD5AE7D4340B7B6F0BC546A4A406D00362042DE4340B7B6F0BC546A4A406D00362042DE434065389ECF80244A4000016BD5AE7D434065389ECF80244A40
1442	Лев-Толстовский район	\N	9	39.227497	39.847101000000002	53.434846999999998	53.043098000000001	0103000020E610000001000000050000001478279F1E9D4340F2423A3C84854A401478279F1E9D4340C1E10511A9B74A4057B439CE6DEC4340C1E10511A9B74A4057B439CE6DEC4340F2423A3C84854A401478279F1E9D4340F2423A3C84854A40
1315	Лебедянский район	\N	9	38.646610000000003	39.537497000000002	53.159593999999998	52.741298	0103000020E610000001000000050000001FA2D11DC45243408C4B55DAE25E4A401FA2D11DC4524340A45181936D944A405C59A2B3CCC44340A45181936D944A405C59A2B3CCC443408C4B55DAE25E4A401FA2D11DC45243408C4B55DAE25E4A40
1229	Краснинский район	\N	9	38.500292999999999	39.027495999999999	53.092818000000001	52.697698000000003	0103000020E6100000010000000500000078B5DC9909404340083E062B4E594A4078B5DC9909404340753DD175E18B4A40AA622AFD84834340753DD175E18B4A40AA622AFD84834340083E062B4E594A4078B5DC9909404340083E062B4E594A40
1081	Измалковский район	\N	9	37.722496	38.298397000000001	52.928494999999998	52.389988000000002	0103000020E61000000100000005000000D3BEB9BF7ADC42408EEA7420EB314A40D3BEB9BF7ADC4240F0BF95ECD8764A40BD1C76DF31264340F0BF95ECD8764A40BD1C76DF312643408EEA7420EB314A40D3BEB9BF7ADC42408EEA7420EB314A40
1012	Задонский район	\N	9	38.631698	39.251095999999997	52.794297	52.135596999999997	0103000020E610000001000000050000006C79E57ADB504340C537143E5B114A406C79E57ADB504340CC272B86AB654A400514EAE923A04340CC272B86AB654A400514EAE923A04340C537143E5B114A406C79E57ADB504340C537143E5B114A40
914	Елецкий район	\N	9	38.129091000000003	38.935796000000003	52.785943000000003	52.389899999999997	0103000020E610000001000000050000009E9ACB0D86104340EE5A423EE8314A409E9ACB0D8610434094C2BCC799644A4023DDCF29C877434094C2BCC799644A4023DDCF29C8774340EE5A423EE8314A409E9ACB0D86104340EE5A423EE8314A40
492	Долгоруковский район	\N	9	37.977096000000003	38.720497000000002	52.502101000000003	52.180697000000002	0103000020E61000000100000005000000B686527B11FD42401FBE4C1421174A40B686527B11FD4240FB2477D844404A40DDEEE53E395C4340FB2477D844404A40DDEEE53E395C43401FBE4C1421174A40B686527B11FD42401FBE4C1421174A40
286	Добровский район	\N	9	39.383094	40.125669000000002	53.104199999999999	52.706592999999998	0103000020E610000001000000050000009CA5643909B14340904AB1A3715A4A409CA5643909B14340211FF46C568D4A407E8FFAEB15104440211FF46C568D4A407E8FFAEB15104440904AB1A3715A4A409CA5643909B14340904AB1A3715A4A40
70	Добринский район	\N	9	40.032494999999997	40.763058999999998	52.467063000000003	51.934182999999997	0103000020E610000001000000050000004A24D1CB2804444055BDFC4E93F749404A24D1CB28044440F9156BB8C83B4A4090F5D4EAAB614440F9156BB8C83B4A4090F5D4EAAB61444055BDFC4E93F749404A24D1CB2804444055BDFC4E93F74940
1695	Данковский район	\N	9	38.527017999999998	39.418298999999998	53.579031000000001	53.074995999999999	0103000020E61000000100000005000000A03369537543434058AA0B7899894A40A033695375434340622F14B01DCA4A40897956D28AB54340622F14B01DCA4A40897956D28AB5434058AA0B7899894A40A03369537543434058AA0B7899894A40
1823	Грязинский район	\N	9	39.437344000000003	40.234239000000002	52.721736999999997	52.280304999999998	0103000020E61000000100000005000000098D60E3FAB74340E0F3C308E1234A40098D60E3FAB7434015A8C5E0615C4A405039268BFB1D444015A8C5E0615C4A405039268BFB1D4440E0F3C308E1234A40098D60E3FAB74340E0F3C308E1234A40
1804	Воловский район	\N	9	37.740713	38.281823000000003	52.251925999999997	51.887141999999997	0103000020E610000001000000050000006C5CFFAECFDE42403A747ADE8DF149406C5CFFAECFDE42408C81751C3F204A405C21ACC6122443408C81751C3F204A405C21ACC6122443403A747ADE8DF149406C5CFFAECFDE42403A747ADE8DF14940
859	Пристенский район	\N	8	36.367593999999997	37.15061	51.380493000000001	51.064830999999998	0103000020E61000000100000005000000581AF8510D2F42402C62D8614C884940581AF8510D2F4240B0AD9FFEB3B04940AC39403047934240B0AD9FFEB3B04940AC394030479342402C62D8614C884940581AF8510D2F42402C62D8614C884940
525	Щигровский район	\N	8	36.557290999999999	37.1158	52.177506000000001	51.653494999999999	0103000020E6100000010000000500000075ADBD4F55474240BD8C62B9A5D3494075ADBD4F55474240016C4084B8164A403B70CE88D28E4240016C4084B8164A403B70CE88D28E4240BD8C62B9A5D3494075ADBD4F55474240BD8C62B9A5D34940
304	Черемисиновский район	\N	8	36.970596999999998	37.464095	52.093698000000003	51.719498999999999	0103000020E61000000100000005000000404CC2853C7C42409A40118B18DC4940404CC2853C7C4240AED9CA4BFE0B4A405A9E077767BB4240AED9CA4BFE0B4A405A9E077767BB42409A40118B18DC4940404CC2853C7C42409A40118B18DC4940
77	Хомутовский район	\N	8	34.33229	35.004598000000001	52.070526000000001	51.683396000000002	0103000020E61000000100000005000000D8648D7A882A4140CE1B278579D74940D8648D7A882A414044C2F7FE06094A4042D0D1AA9680414044C2F7FE06094A4042D0D1AA96804140CE1B278579D74940D8648D7A882A4140CE1B278579D74940
1895	Фатежский район	\N	8	35.526797000000002	36.156300999999999	52.300058	51.853799000000002	0103000020E61000000100000005000000C25087156EC34140C32D1F4949ED4940C25087156EC341409B73F04C68264A4082AAD1AB011442409B73F04C68264A4082AAD1AB01144240C32D1F4949ED4940C25087156EC34140C32D1F4949ED4940
876	Тимский район	\N	8	36.789693999999997	37.571694999999998	51.796196999999999	51.501396999999997	0103000020E6100000010000000500000078EC67B11465424000A8E2C62DC0494078EC67B1146542402F1686C8E9E54940B324404D2DC942402F1686C8E9E54940B324404D2DC9424000A8E2C62DC0494078EC67B11465424000A8E2C62DC04940
740	Суджанский район	\N	8	34.973354	35.585600999999997	51.471398000000001	51.027197000000001	0103000020E6100000010000000500000024B726DD967C414050C6F8307B83494024B726DD967C41402DB308C556BC4940A0C03BF9F4CA41402DB308C556BC4940A0C03BF9F4CA414050C6F8307B83494024B726DD967C414050C6F8307B834940
1660	Солнцевский район	\N	8	36.430098000000001	37.015872000000002	51.674996999999998	51.273992999999997	0103000020E610000001000000050000009A0986730D3742409D2ADF3312A349409A0986730D374240F5F23B4D66D649400876FC1708824240F5F23B4D66D649400876FC17088242409D2ADF3312A349409A0986730D3742409D2ADF3312A34940
737	Советский район	\N	8	37.33719	37.909892999999997	52.018079999999998	51.559399999999997	0103000020E61000000100000005000000E544BB0A29AB4240F2B0506B9AC74940E544BB0A29AB4240185B087250024A40FEEDB25F77F44240185B087250024A40FEEDB25F77F44240F2B0506B9AC74940E544BB0A29AB4240F2B0506B9AC74940
720	Рыльский район	\N	8	34.082253000000001	35.057994000000001	51.757596999999997	51.386496999999999	0103000020E61000000100000005000000BB7F2C44870A41404580D3BB78B14940BB7F2C44870A41401B4641F0F8E049409FAEEE586C8741401B4641F0F8E049409FAEEE586C8741404580D3BB78B14940BB7F2C44870A41404580D3BB78B14940
681	Поныровский район	\N	8	35.962786000000001	36.576991	52.379939999999998	52.107793999999998	0103000020E61000000100000005000000F98557923CFB41403E5A9C31CC0D4A40F98557923CFB41409B38B9DFA1304A400D8B51D7DA4942409B38B9DFA1304A400D8B51D7DA4942403E5A9C31CC0D4A40F98557923CFB41403E5A9C31CC0D4A40
1552	Октябрьский район	\N	8	35.687694999999998	36.027149999999999	51.870162000000001	51.504772000000003	0103000020E61000000100000005000000B54FC76306D84140E0F76F5E9CC04940B54FC76306D84140691CEA7761EF49400F0BB5A679034240691CEA7761EF49400F0BB5A679034240E0F76F5E9CC04940B54FC76306D84140E0F76F5E9CC04940
817	Обоянский район	\N	8	35.753694000000003	36.504568999999996	51.405293999999998	51.062488000000002	0103000020E610000001000000050000008198840B79E041403C32569BFF8749408198840B79E04140ECA17DACE0B34940A7C98CB795404240ECA17DACE0B34940A7C98CB7954042403C32569BFF8749408198840B79E041403C32569BFF874940
760	Медвенский район	\N	8	35.698797999999996	36.503095000000002	51.587829999999997	51.304495000000003	0103000020E610000001000000050000004E417E3672D94140D46531B1F9A649404E417E3672D94140C8CD70033ECB4940FCE3BD6A65404240C8CD70033ECB4940FCE3BD6A65404240D46531B1F9A649404E417E3672D94140D46531B1F9A64940
786	Мантуровский район	\N	8	36.930891000000003	37.615200999999999	51.610297000000003	51.261195000000001	0103000020E610000001000000050000000492B06F277742407A7077D66EA149400492B06F2777424068EC4B361ECE4940B6BB07E8BECE424068EC4B361ECE4940B6BB07E8BECE42407A7077D66EA149400492B06F277742407A7077D66EA14940
811	Льговский район	\N	8	34.933802	35.529403000000002	51.812998999999998	51.421697000000002	0103000020E610000001000000050000003E78EDD28677414021E9D32AFAB549403E78EDD2867741402157EA5910E84940C0B33D7AC3C341402157EA5910E84940C0B33D7AC3C3414021E9D32AFAB549403E78EDD28677414021E9D32AFAB54940
770	Курчатовский район	\N	8	35.440396999999997	35.786994	51.910198999999999	51.449697999999998	0103000020E61000000100000005000000D520CCED5EB84140CE893DB48FB94940D520CCED5EB841400BED9C6681F44940F9122A38BCE441400BED9C6681F44940F9122A38BCE44140CE893DB48FB94940D520CCED5EB84140CE893DB48FB94940
7322	Курчатовский	\N	8	35.440396999999997	35.786994	51.910198999999999	51.449697999999998	0103000020E61000000100000005000000D520CCED5EB84140CE893DB48FB94940D520CCED5EB841400BED9C6681F44940F9122A38BCE441400BED9C6681F44940F9122A38BCE44140CE893DB48FB94940D520CCED5EB84140CE893DB48FB94940
395	Курчатов городской округ	\N	8	35.613826000000003	35.664276000000001	51.676794999999998	51.654696000000001	0103000020E610000001000000050000009EB7B1D991CE414038691A14CDD349409EB7B1D991CE4140548CF337A1D6494044C2F7FE06D54140548CF337A1D6494044C2F7FE06D5414038691A14CDD349409EB7B1D991CE414038691A14CDD34940
269	Курский район	\N	8	35.835611	36.654929000000003	51.960202000000002	51.552320999999999	0103000020E61000000100000005000000C4961E4DF5EA41406FF25B74B2C64940C4961E4DF5EA4140E3C62DE6E7FA4940DB19A6B6D4534240E3C62DE6E7FA4940DB19A6B6D45342406FF25B74B2C64940C4961E4DF5EA41406FF25B74B2C64940
752	Кореневский район	\N	8	34.733801	35.253692000000001	51.572400000000002	51.169384999999998	0103000020E61000000100000005000000D462F030ED5D41406BB75D68AE954940D462F030ED5D41407E1D386744C94940E0A0BDFA78A041407E1D386744C94940E0A0BDFA78A041406BB75D68AE954940D462F030ED5D41406BB75D68AE954940
721	Конышевский район	\N	8	34.926955999999997	35.613790000000002	52.083798999999999	51.737696	0103000020E610000001000000050000005D6A847EA6764140EC3191D26CDE49405D6A847EA67641400038F6ECB90A4A40514EB4AB90CE41400038F6ECB90A4A40514EB4AB90CE4140EC3191D26CDE49405D6A847EA6764140EC3191D26CDE4940
231	Касторенский район	\N	8	37.709398	38.517729000000003	51.967677000000002	51.608496000000002	0103000020E6100000010000000500000085ECBC8DCDDA424098DF6932E3CD494085ECBC8DCDDA4240B30B06D7DCFB49406C98A1F144424340B30B06D7DCFB49406C98A1F14442434098DF6932E3CD494085ECBC8DCDDA424098DF6932E3CD4940
302	Золотухинский район	\N	8	36.054997999999998	36.733693000000002	52.221929000000003	51.857999	0103000020E6100000010000000500000036ACA92C0A074240178046E9D2ED494036ACA92C0A0742405A84622B681C4A40EE26F8A6E95D42405A84622B681C4A40EE26F8A6E95D4240178046E9D2ED494036ACA92C0A074240178046E9D2ED4940
84	Железногорский район	\N	8	35.111550999999999	35.708796	52.444803999999998	52.025295999999997	0103000020E61000000100000005000000056B9C4D478E41401C5C3AE63C034A40056B9C4D478E4140A3906456EF384A408FC4CBD3B9DA4140A3906456EF384A408FC4CBD3B9DA41401C5C3AE63C034A40056B9C4D478E41401C5C3AE63C034A40
1902	Дмитриевский район	\N	8	34.666094999999999	35.420599000000003	52.369658999999999	51.907798999999997	0103000020E61000000100000005000000BA83D89942554140B62BF4C132F44940BA83D8994255414006D671FC502F4A407BDD2230D6B5414006D671FC502F4A407BDD2230D6B54140B62BF4C132F44940BA83D89942554140B62BF4C132F44940
688	Горшеченский район	\N	8	37.492795999999998	38.376891000000001	51.670696	51.297590999999997	0103000020E61000000100000005000000C0CC77F013BF4240BE4A3E7617A64940C0CC77F013BF42406DC7D45DD9D549401094DBF63D3043406DC7D45DD9D549401094DBF63D304340BE4A3E7617A64940C0CC77F013BF4240BE4A3E7617A64940
682	Глушковский район	\N	8	34.219048000000001	34.847293999999998	51.484428999999999	51.17109	0103000020E610000001000000050000008A20CEC3091C41401956F146E69549408A20CEC3091C4140F31DFCC401BE49406B0C3A21746C4140F31DFCC401BE49406B0C3A21746C41401956F146E69549408A20CEC3091C41401956F146E6954940
713	Большесолдатский район	\N	8	35.341700000000003	35.823492999999999	51.591394000000001	51.191800000000001	0103000020E6100000010000000500000088855AD3BCAB4140B8AF03E78C98494088855AD3BCAB41407B8670CCB2CB494012BEF73768E941407B8670CCB2CB494012BEF73768E94140B8AF03E78C98494088855AD3BCAB4140B8AF03E78C984940
1772	Беловский район	\N	8	35.32235	36.010998000000001	51.270893999999998	50.903858	0103000020E61000000100000005000000CCEEC9C342A941402E1D739EB1734940CCEEC9C342A94140605793A7ACA249402429E96168014240605793A7ACA249402429E961680142402E1D739EB1734940CCEEC9C342A941402E1D739EB1734940
7281	Шарья городской округ	\N	7	45.473537	45.562730999999999	58.388823000000002	58.341957999999998	0103000020E61000000100000005000000153944DC9CBC4640834D9D47C52B4D40153944DC9CBC46406077BAF3C4314D4002B9C49107C846406077BAF3C4314D4002B9C49107C84640834D9D47C52B4D40153944DC9CBC4640834D9D47C52B4D40
1104	Шарьинский район	\N	7	44.906897999999998	46.265796999999999	58.759500000000003	57.916986000000001	0103000020E610000001000000050000006667D13B15744640E77118CC5FF54C406667D13B15744640F0A7C64B37614D40FD2FD7A205224740F0A7C64B37614D40FD2FD7A205224740E77118CC5FF54C406667D13B15744640E77118CC5FF54C40
494	Чухломский район	\N	7	42.227870000000003	43.732494000000003	59.305621000000002	58.511201	0103000020E61000000100000005000000A9DE1AD82A1D45405C57CC086F414D40A9DE1AD82A1D454044FCC3961EA74D401442075DC2DD454044FCC3961EA74D401442075DC2DD45405C57CC086F414D40A9DE1AD82A1D45405C57CC086F414D40
405	Сусанинский район	\N	7	41.148795999999997	42.027096999999998	58.288400000000003	57.968797000000002	0103000020E6100000010000000500000047E350BF0B93444041BB438A01FC4C4047E350BF0B9344404D158C4AEA244D40EC681CEA770345404D158C4AEA244D40EC681CEA7703454041BB438A01FC4C4047E350BF0B93444041BB438A01FC4C40
247	Судиславский район	\N	7	41.215693000000002	42.200597000000002	58.151097999999998	57.690694000000001	0103000020E61000000100000005000000F27C06D49B9B44408FC536A968D84C40F27C06D49B9B4440D93EE42D57134D407E569929AD194540D93EE42D57134D407E569929AD1945408FC536A968D84C40F27C06D49B9B44408FC536A968D84C40
90	Солигаличский район	\N	7	41.508391000000003	42.874495000000003	59.432158000000001	58.744000999999997	0103000020E61000000100000005000000564ACFF412C144407C98BD6C3B5F4D40564ACFF412C14440365A0EF450B74D40FDC1C073EF6F4540365A0EF450B74D40FDC1C073EF6F45407C98BD6C3B5F4D40564ACFF412C144407C98BD6C3B5F4D40
643	Пыщугский район	\N	7	45.291395000000001	46.144992000000002	59.217475	58.626494999999998	0103000020E61000000100000005000000E59B6D6E4CA54640C30DF8FC30504D40E59B6D6E4CA546404B598638D69B4D4040170D198F1247404B598638D69B4D4040170D198F124740C30DF8FC30504D40E59B6D6E4CA54640C30DF8FC30504D40
805	Поназыревский район	\N	7	45.816989999999997	47.071900999999997	58.753197999999998	58.059193	0103000020E610000001000000050000005B94D92093E846407993DFA293074D405B94D92093E84640D0B4C4CA68604D405CC64D0D34894740D0B4C4CA68604D405CC64D0D348947407993DFA293074D405B94D92093E846407993DFA293074D40
638	Парфеньевский район	\N	7	43.016896000000003	43.987391000000002	58.857097000000003	58.197997999999998	0103000020E6100000010000000500000074B7EBA52982454032569BFF57194D4074B7EBA529824540F73FC05AB56D4D40B0AE0AD462FE4540F73FC05AB56D4D40B0AE0AD462FE454032569BFF57194D4074B7EBA52982454032569BFF57194D40
1877	Павинский район	\N	7	45.734597000000001	46.542496	59.353636000000002	58.880895000000002	0103000020E61000000100000005000000AF5E454607DE4640DF1AD82AC1704D40AF5E454607DE46401958C7F143AD4D40FC1A4982704547401958C7F143AD4D40FC1A498270454740DF1AD82AC1704D40AF5E454607DE4640DF1AD82AC1704D40
1847	Островский район	\N	7	41.765894000000003	42.790593000000001	58.157598999999998	57.555652000000002	0103000020E61000000100000005000000F01989D008E244407FFACF9A1FC74C40F01989D008E24440EF703B342C144D4028B9C32632654540EF703B342C144D4028B9C326326545407FFACF9A1FC74C40F01989D008E244407FFACF9A1FC74C40
630	Октябрьский район	\N	7	46.619292999999999	47.644674999999999	59.368929999999999	58.713196000000003	0103000020E6100000010000000500000024D236FE444F4740ABD1AB014A5B4D4024D236FE444F4740B341261939AF4D403FC6DCB584D24740B341261939AF4D403FC6DCB584D24740ABD1AB014A5B4D4024D236FE444F4740ABD1AB014A5B4D40
7283	Нея городской округ	\N	7	43.833708000000001	43.964205999999997	58.312651000000002	58.264819000000003	0103000020E61000000100000005000000F03499F1B6EA4540022EC896E5214D40F03499F1B6EA4540E607AEF204284D40B14D2A1A6BFB4540E607AEF204284D40B14D2A1A6BFB4540022EC896E5214D40F03499F1B6EA4540022EC896E5214D40
690	Нерехтский район	\N	7	40.392485999999998	41.153385999999998	57.625560999999998	57.273671999999998	0103000020E61000000100000005000000A51133FB3C3244405BEA20AF07A34C40A51133FB3C3244409753026212D04C4006D50627A29344409753026212D04C4006D50627A29344405BEA20AF07A34C40A51133FB3C3244405BEA20AF07A34C40
679	Нейский район	\N	7	43.363700000000001	44.545496999999997	58.755195999999998	57.983199999999997	0103000020E6100000010000000500000011C7BAB88DAE4540AEB6627FD9FD4C4011C7BAB88DAE4540F6083543AA604D4076887FD8D2454640F6083543AA604D4076887FD8D2454640AEB6627FD9FD4C4011C7BAB88DAE4540AEB6627FD9FD4C40
710	Межевской район	\N	7	44.666193999999997	45.371893	59.199762	58.469780999999998	0103000020E610000001000000050000004D6551D8455546401EA4A7C8213C4D404D6551D845554640E57D1CCD91994D40404E98309AAF4640E57D1CCD91994D40404E98309AAF46401EA4A7C8213C4D404D6551D8455546401EA4A7C8213C4D40
605	Мантуровский район	\N	7	44.189593000000002	45.222898000000001	58.613500000000002	57.905597	0103000020E6100000010000000500000078465B9544184640882D3D9AEAF34C4078465B95441846404A0C022B874E4D40022CF2EB879C46404A0C022B874E4D40022CF2EB879C4640882D3D9AEAF34C4078465B9544184640882D3D9AEAF34C40
7280	Мантурово городской округ	\N	7	44.718297	44.819617999999998	58.364958999999999	58.289071999999997	0103000020E610000001000000050000004FE8F527F15B46403B18B14F00254D404FE8F527F15B4640C0B0FCF9B62E4D40419B1C3EE9684640C0B0FCF9B62E4D40419B1C3EE96846403B18B14F00254D404FE8F527F15B46403B18B14F00254D40
1697	Макарьевский район	\N	7	43.202075000000001	44.879292999999997	58.187595999999999	57.410716999999998	0103000020E610000001000000050000006B2BF697DD994540A374E95F92B44C406B2BF697DD994540226E4E2503184D40054D4BAC8C704640226E4E2503184D40054D4BAC8C704640A374E95F92B44C406B2BF697DD994540A374E95F92B44C40
1670	Красносельский район	\N	7	41.064793999999999	41.626007999999999	57.765796000000002	57.400069999999999	0103000020E610000001000000050000000F7D772B4B8844402C0E677E35B34C400F7D772B4B8844402DB4739A05E24C406684B70721D044402DB4739A05E24C406684B70721D044402C0E677E35B34C400F7D772B4B8844402C0E677E35B34C40
197	Костромской район	\N	7	40.603842	41.763979999999997	58.637991	57.536496999999997	0103000020E61000000100000005000000C2F9D4B14A4D444078B306EFABC44C40C2F9D4B14A4D4440381268B0A9514D402766BD18CAE14440381268B0A9514D402766BD18CAE1444078B306EFABC44C40C2F9D4B14A4D444078B306EFABC44C40
1137	Кологривский район	\N	7	43.469889999999999	44.797600000000003	59.266415000000002	58.554098000000003	0103000020E61000000100000005000000D55B035B25BC4540B763EAAEEC464D40D55B035B25BC4540F91400E319A24D4012A5BDC117664640F91400E319A24D4012A5BDC117664640B763EAAEEC464D40D55B035B25BC4540B763EAAEEC464D40
1272	Кадыйский район	\N	7	42.74539	43.563000000000002	58.041699999999999	57.371398999999997	0103000020E61000000100000005000000FA6184F0685F454030629F008AAF4C40FA6184F0685F4540211FF46C56054D40F2D24D6210C84540211FF46C56054D40F2D24D6210C8454030629F008AAF4C40FA6184F0685F454030629F008AAF4C40
444	Галичский район	\N	7	41.682000000000002	42.787790000000001	58.731493	58.0792	0103000020E610000001000000050000009EEFA7C64BD74440EEEBC039230A4D409EEFA7C64BD7444060200890A15D4D40D40E7F4DD664454060200890A15D4D40D40E7F4DD6644540EEEBC039230A4D409EEFA7C64BD74440EEEBC039230A4D40
7282	Галич городской округ	\N	7	42.311737000000001	42.454892000000001	58.404051000000003	58.359493000000001	0103000020E6100000010000000500000001FA7DFFE62745400A12DBDD032E4D4001FA7DFFE6274540437573F1B7334D40249BABE6393A4540437573F1B7334D40249BABE6393A45400A12DBDD032E4D4001FA7DFFE62745400A12DBDD032E4D40
165	Вохомский район	\N	7	46.040796	47.119269000000003	59.625171999999999	58.570296999999997	0103000020E6100000010000000500000060E7A6CD38054740E200FA7DFF484D4060E7A6CD38054740FD2FD7A205D04D409C36E334448F4740FD2FD7A205D04D409C36E334448F4740E200FA7DFF484D4060E7A6CD38054740E200FA7DFF484D40
6909	Вохомский муниципальный район	\N	7	46.040796	47.119269000000003	59.625171999999999	58.570296999999997	0103000020E6100000010000000500000060E7A6CD38054740E200FA7DFF484D4060E7A6CD38054740FD2FD7A205D04D409C36E334448F4740FD2FD7A205D04D409C36E334448F4740E200FA7DFF484D4060E7A6CD38054740E200FA7DFF484D40
956	Буйский район	\N	7	40.929696999999997	42.231895000000002	59.023015999999998	58.241695999999997	0103000020E610000001000000050000003B18B14F0077444079C9FFE4EF1E4D403B18B14F0077444072A43330F2824D408F8D40BCAE1D454072A43330F2824D408F8D40BCAE1D454079C9FFE4EF1E4D403B18B14F0077444079C9FFE4EF1E4D40
813	Антроповский район	\N	7	42.477296000000003	43.531396999999998	58.581501000000003	57.868895000000002	0103000020E610000001000000050000007D410B09183D454037548CF337EF4C407D410B09183D4540B0CBF09F6E4A4D40A41820D104C44540B0CBF09F6E4A4D40A41820D104C4454037548CF337EF4C407D410B09183D454037548CF337EF4C40
7506	район Ульяновский район	\N	6	35.166798	36.085701999999998	53.910494999999997	53.50797	0103000020E61000000100000005000000E48409A359954140B0AC342905C14A40E48409A359954140F415A4198BF44A40D4997B48F80A4240F415A4198BF44A40D4997B48F80A4240B0AC342905C14A40E48409A359954140B0AC342905C14A40
1425	Юхновский район	\N	6	34.868358999999998	35.685099000000001	54.934640000000002	54.510897	0103000020E61000000100000005000000F8174163266F4140F04FA91265414B40F8174163266F414048C49448A2774B40DBC2F352B1D7414048C49448A2774B40DBC2F352B1D74140F04FA91265414B40F8174163266F4140F04FA91265414B40
1649	Хвастовичский район	\N	6	34.656500999999999	35.585664000000001	53.719893999999996	53.276786000000001	0103000020E6100000010000000500000049658A3908544140CEFE40B96DA34A4049658A3908544140164B917C25DC4A40E738B709F7CA4140164B917C25DC4A40E738B709F7CA4140CEFE40B96DA34A4049658A3908544140CEFE40B96DA34A40
1067	Ферзиковский район	\N	6	36.360317000000002	36.972518999999998	54.726740999999997	54.283574999999999	0103000020E61000000100000005000000AF9811DE1E2E42404A7B832F4C244B40AF9811DE1E2E4240C7D45DD9055D4B408BDEA9807B7C4240C7D45DD9055D4B408BDEA9807B7C42404A7B832F4C244B40AF9811DE1E2E42404A7B832F4C244B40
1589	Ульяновский район	\N	6	35.166798	36.085701999999998	53.910494999999997	53.50797	0103000020E61000000100000005000000E48409A359954140B0AC342905C14A40E48409A359954140F415A4198BF44A40D4997B48F80A4240F415A4198BF44A40D4997B48F80A4240B0AC342905C14A40E48409A359954140B0AC342905C14A40
7129	Торжокский район	\N	6	33.443434000000003	37.275906999999997	55.341996999999999	53.276775000000001	0103000020E610000001000000050000009DF7FF71C2B84040DAACFA5C6DA34A409DF7FF71C2B84040412AC58EC6AB4B4065DEAAEB50A34240412AC58EC6AB4B4065DEAAEB50A34240DAACFA5C6DA34A409DF7FF71C2B84040DAACFA5C6DA34A40
1547	Тарусский район	\N	6	36.492387999999998	37.231054	54.852293000000003	54.548775999999997	0103000020E61000000100000005000000AF78EA91063F4240336ABE4A3E464B40AF78EA91063F42400CCEE0EF176D4B4014CE6E2D939D42400CCEE0EF176D4B4014CE6E2D939D4240336ABE4A3E464B40AF78EA91063F4240336ABE4A3E464B40
1456	Сухиничский район	\N	6	34.730890000000002	35.616197999999997	54.331699	53.868000000000002	0103000020E610000001000000050000009A7CB3CD8D5D4140C976BE9F1AEF4A409A7CB3CD8D5D4140D68EE21C752A4B4028EE7893DFCE4140D68EE21C752A4B4028EE7893DFCE4140C976BE9F1AEF4A409A7CB3CD8D5D4140C976BE9F1AEF4A40
1441	Спас-Деменский район	\N	6	33.575980000000001	34.336098	54.584071999999999	54.210796999999999	0103000020E6100000010000000500000036936FB6B9C94040268C6665FB1A4B4036936FB6B9C9404031410DDFC24A4B4021205F42052B414031410DDFC24A4B4021205F42052B4140268C6665FB1A4B4036936FB6B9C94040268C6665FB1A4B40
1412	Перемышльский район	\N	6	35.768434999999997	36.717002000000001	54.450999000000003	54.158166000000001	0103000020E61000000100000005000000060DFD135CE2414069AB92C83E144B40060DFD135CE24140ADC3D155BA394B405395B6B8C65B4240ADC3D155BA394B405395B6B8C65B424069AB92C83E144B40060DFD135CE2414069AB92C83E144B40
7188	Новосокольнический район	\N	6	33.443434000000003	37.275906999999997	55.341996999999999	53.276775000000001	0103000020E610000001000000050000009DF7FF71C2B84040DAACFA5C6DA34A409DF7FF71C2B84040412AC58EC6AB4B4065DEAAEB50A34240412AC58EC6AB4B4065DEAAEB50A34240DAACFA5C6DA34A409DF7FF71C2B84040DAACFA5C6DA34A40
1252	Мосальский район	\N	6	34.435937000000003	35.300997000000002	54.758485	54.353098000000003	0103000020E61000000100000005000000E50E9BC8CC3741403A24B550322D4B40E50E9BC8CC374140D7C0560916614B40D998D71187A64140D7C0560916614B40D998D71187A641403A24B550322D4B40E50E9BC8CC3741403A24B550322D4B40
1215	Мещовский район	\N	6	34.866599000000001	35.724390999999997	54.541494999999998	54.186500000000002	0103000020E6100000010000000500000087DF4DB7EC6E41401D5A643BDF174B4087DF4DB7EC6E414048F949B54F454B40244223D8B8DC414048F949B54F454B40244223D8B8DC41401D5A643BDF174B4087DF4DB7EC6E41401D5A643BDF174B40
1049	Медынский район	\N	6	35.543075000000002	36.090859000000002	55.288075999999997	54.738453	0103000020E610000001000000050000003A234A7B83C541400951BEA0855E4B403A234A7B83C541409961A3ACDFA44B400DC68844A10B42409961A3ACDFA44B400DC68844A10B42400951BEA0855E4B403A234A7B83C541400951BEA0855E4B40
1120	Малоярославецкий район	\N	6	35.970601000000002	36.739820000000002	55.099572000000002	54.692489000000002	0103000020E61000000100000005000000823B50A73CFC41407DEBC37AA3584B40823B50A73CFC414075CC79C6BE8C4B409F76F86BB25E424075CC79C6BE8C4B409F76F86BB25E42407DEBC37AA3584B40823B50A73CFC41407DEBC37AA3584B40
1001	Людиновский район	\N	6	34.107396000000001	34.830692999999997	54.066395999999997	53.722951999999999	0103000020E6100000010000000500000051DCF126BF0D4140F549EEB089DC4A4051DCF126BF0D4140E84A04AA7F084B401002F225546A4140E84A04AA7F084B401002F225546A4140F549EEB089DC4A4051DCF126BF0D4140F549EEB089DC4A40
241	Куйбышевский район	\N	6	33.443443000000002	34.207791999999998	54.336396999999998	53.859057999999997	0103000020E61000000100000005000000F0517FBDC2B84040FFAECF9CF5ED4A40F0517FBDC2B840407BBC900E0F2B4B406A2FA2ED981A41407BBC900E0F2B4B406A2FA2ED981A4140FFAECF9CF5ED4A40F0517FBDC2B84040FFAECF9CF5ED4A40
893	Козельский район	\N	6	35.496093000000002	36.236457999999999	54.292099999999998	53.784592000000004	0103000020E610000001000000050000002463B5F97FBF4140045ABA826DE44A402463B5F97FBF4140AF94658863254B4054707841441E4240AF94658863254B4054707841441E4240045ABA826DE44A402463B5F97FBF4140045ABA826DE44A40
764	Кировский район	\N	6	34.024194000000001	34.854498	54.255597999999999	53.961894999999998	0103000020E610000001000000050000003561FBC918034140CC9717601FFB4A403561FBC91803414025766D6FB7204B40AB3FC230606D414025766D6FB7204B40AB3FC230606D4140CC9717601FFB4A403561FBC918034140CC9717601FFB4A40
508	Калуга городской округ	\N	6	36.023978999999997	36.397776999999998	54.717354999999998	54.377034000000002	0103000020E6100000010000000500000038656EBE1103424073BD6DA642304B4038656EBE11034240A04FE449D25B4B40ED0C535BEA324240A04FE449D25B4B40ED0C535BEA32424073BD6DA642304B4038656EBE1103424073BD6DA642304B40
1892	Износковский район	\N	6	34.982284	35.800676000000003	55.241858000000001	54.719565000000003	0103000020E6100000010000000500000029B16B7BBB7D4140522CB7B41A5C4B4029B16B7BBB7D41405323F433F59E4B409758198D7CE641405323F433F59E4B409758198D7CE64140522CB7B41A5C4B4029B16B7BBB7D4140522CB7B41A5C4B40
1868	Жуковский район	\N	6	36.669580000000003	37.182464000000003	55.234814999999998	54.798499	0103000020E61000000100000005000000210725CCB4554240C171193735664B40210725CCB45542401CCEFC6A0E9E4B404359F8FA5A9742401CCEFC6A0E9E4B404359F8FA5A974240C171193735664B40210725CCB4554240C171193735664B40
1852	Жиздринский район	\N	6	34.409284	35.096091000000001	53.894399999999997	53.381318999999998	0103000020E610000001000000050000005663096B63344140F52B9D0FCFB04A405663096B633441406DC5FEB27BF24A405038BBB54C8C41406DC5FEB27BF24A405038BBB54C8C4140F52B9D0FCFB04A405663096B63344140F52B9D0FCFB04A40
324	Думиничский район	\N	6	34.739496000000003	35.352497	54.157696999999999	53.706598	0103000020E61000000100000005000000ECC20FCEA75E4140A2B5A2CD71DA4A40ECC20FCEA75E4140B2D6506A2F144B401478279F1EAD4140B2D6506A2F144B401478279F1EAD4140A2B5A2CD71DA4A40ECC20FCEA75E4140A2B5A2CD71DA4A40
1701	Дзержинский район	\N	6	35.531424000000001	36.143545000000003	54.906486999999998	54.456871999999997	0103000020E610000001000000050000009E279EB305C44140A33A1DC87A3A4B409E279EB305C44140E49F19C407744B408E40BCAE5F124240E49F19C407744B408E40BCAE5F124240A33A1DC87A3A4B409E279EB305C44140A33A1DC87A3A4B40
1770	Боровский район	\N	6	36.031184000000003	36.668889	55.286270999999999	55.072788000000003	0103000020E6100000010000000500000049145AD6FD03424048C5FF1D51894B4049145AD6FD03424088653387A4A44B40BBD39D279E55424088653387A4A44B40BBD39D279E55424048C5FF1D51894B4049145AD6FD03424048C5FF1D51894B40
514	Барятинский район	\N	6	34.237471999999997	34.879696000000003	54.528441000000001	54.133495000000003	0103000020E610000001000000050000009CDB847B651E4140FB96395D16114B409CDB847B651E4140CA6E66F4A3434B400536E7E099704140CA6E66F4A3434B400536E7E099704140FB96395D16114B409CDB847B651E4140FB96395D16114B40
1269	Бабынинский район	\N	6	35.453494999999997	36.080196000000001	54.573698	54.224800999999999	0103000020E6100000010000000500000023F3C81F0CBA4140D68D7747C61C4B4023F3C81F0CBA4140EBE3A1EF6E494B4090A2CEDC430A4240EBE3A1EF6E494B4090A2CEDC430A4240D68D7747C61C4B4023F3C81F0CBA4140D68D7747C61C4B40
1335	Тейково городской округ	\N	5	40.489693000000003	40.581814999999999	56.878059999999998	56.831369000000002	0103000020E61000000100000005000000420A9E42AE3E444041F4A44C6A6A4C40420A9E42AE3E44407FF6234564704C403FA9F6E9784A44407FF6234564704C403FA9F6E9784A444041F4A44C6A6A4C40420A9E42AE3E444041F4A44C6A6A4C40
7296	Кинешма городской округ	\N	5	42.063963999999999	42.246501000000002	57.480958999999999	57.403241000000001	0103000020E61000000100000005000000880FECF82F08454003B4AD669DB34C40880FECF82F084540C2DB831090BD4C4035B742588D1F4540C2DB831090BD4C4035B742588D1F454003B4AD669DB34C40880FECF82F08454003B4AD669DB34C40
557	Юрьевецкий район	\N	5	42.605494999999998	43.305695999999998	57.601118999999997	57.116799999999998	0103000020E610000001000000050000001D7233DC804D45401E166A4DF38E4C401D7233DC804D45408A00A777F1CC4C404E42E90B21A745408A00A777F1CC4C404E42E90B21A745401E166A4DF38E4C401D7233DC804D45401E166A4DF38E4C40
399	Южский район	\N	5	41.591692000000002	42.468097999999998	56.755797999999999	56.350422000000002	0103000020E6100000010000000500000005A73E90BCCB444043E6CAA0DA2C4C4005A73E90BCCB4440EC3026FDBD604C4058A9A0A2EA3B4540EC3026FDBD604C4058A9A0A2EA3B454043E6CAA0DA2C4C4005A73E90BCCB444043E6CAA0DA2C4C40
1438	Шуя городской округ	\N	5	41.316206000000001	41.440452000000001	56.882810999999997	56.821227999999998	0103000020E6100000010000000500000045662E7079A844409D47C5FF1D694C4045662E7079A8444047C66AF3FF704C4099BA2BBB60B8444047C66AF3FF704C4099BA2BBB60B844409D47C5FF1D694C4045662E7079A844409D47C5FF1D694C40
177	Шуйский район	\N	5	41.109495000000003	41.765399000000002	57.059198000000002	56.651595999999998	0103000020E61000000100000005000000AB09A2EE038E44402A1A6B7F67534C40AB09A2EE038E44408BFED0CC93874C4010B22C98F8E144408BFED0CC93874C4010B22C98F8E144402A1A6B7F67534C40AB09A2EE038E44402A1A6B7F67534C40
1365	Фурмановский район	\N	5	40.649197999999998	41.434595000000002	57.362195999999997	57.086601999999999	0103000020E61000000100000005000000765089EB1853444054E23AC6158B4C40765089EB18534440FA5E43705CAE4C40A80018CFA0B74440FA5E43705CAE4C40A80018CFA0B7444054E23AC6158B4C40765089EB1853444054E23AC6158B4C40
7311	Фрунзенский район	\N	5	40.867938000000002	40.986156000000001	57.02346	56.953045000000003	0103000020E61000000100000005000000537AA697186F4440E44EE960FD794C40537AA697186F4440D061BEBC00834C4089601C5C3A7E4440D061BEBC00834C4089601C5C3A7E4440E44EE960FD794C40537AA697186F4440E44EE960FD794C40
4	Тейковский район	\N	5	40.104190000000003	40.792496999999997	57.034100000000002	56.524675000000002	0103000020E61000000100000005000000FE481119560D4440B003E78C28434C40FE481119560D4440956588635D844C40CC96AC8A70654440956588635D844C40CC96AC8A70654440B003E78C28434C40FE481119560D4440B003E78C28434C40
4490	Сонковский район	\N	5	39.376123	43.324883999999997	57.739004000000001	56.350422000000002	0103000020E61000000100000005000000FF2268CC24B0434043E6CAA0DA2C4C40FF2268CC24B043407DCEDDAE97DE4C40307F85CC95A945407DCEDDAE97DE4C40307F85CC95A9454043E6CAA0DA2C4C40FF2268CC24B0434043E6CAA0DA2C4C40
1916	Савинский район	\N	5	40.820228	41.749194000000003	56.712698000000003	56.471043999999999	0103000020E61000000100000005000000BAA1293BFD6844400F7D772B4B3C4C40BAA1293BFD6844405AF624B0395B4C40022EC896E5DF44405AF624B0395B4C40022EC896E5DF44400F7D772B4B3C4C40BAA1293BFD6844400F7D772B4B3C4C40
1849	Родниковский район	\N	5	41.351995000000002	42.084795	57.280197000000001	56.918300000000002	0103000020E6100000010000000500000082AD122C0EAD44405AF5B9DA8A754C4082AD122C0EAD4440FAB7CB7EDDA34C40A2EE0390DA0A4540FAB7CB7EDDA34C40A2EE0390DA0A45405AF5B9DA8A754C4082AD122C0EAD44405AF5B9DA8A754C40
1857	Пучежский район	\N	5	42.692397999999997	43.281298	57.139297999999997	56.798113000000001	0103000020E610000001000000050000006CE8667FA058454098C1189128664C406CE8667FA0584540F8325184D4914C401137A79201A44540F8325184D4914C401137A79201A4454098C1189128664C406CE8667FA058454098C1189128664C40
1826	Приволжский район	\N	5	41.087224999999997	41.703389000000001	57.480223000000002	57.162694000000002	0103000020E61000000100000005000000613255302A8B4440B2A03028D3944C40613255302A8B4440BDE47FF277BD4C40DEAE97A608DA4440BDE47FF277BD4C40DEAE97A608DA4440B2A03028D3944C40613255302A8B4440B2A03028D3944C40
1816	Пестяковский район	\N	5	42.225794999999998	42.930802	56.807797000000001	56.402197000000001	0103000020E61000000100000005000000D74CBED9E61C454050C6F8307B334C40D74CBED9E61C4540496760E465674C4094861A8524774540496760E465674C4094861A852477454050C6F8307B334C40D74CBED9E61C454050C6F8307B334C40
1810	Палехский район	\N	5	41.627291999999997	42.297597000000003	56.959797999999999	56.700197000000003	0103000020E610000001000000050000006E85B01A4BD04440F0E0270EA0594C406E85B01A4BD0444013622EA9DA7A4C40A13193A81726454013622EA9DA7A4C40A13193A817264540F0E0270EA0594C406E85B01A4BD04440F0E0270EA0594C40
1789	Лухский район	\N	5	42.032594000000003	42.780692999999999	57.185895000000002	56.878895999999997	0103000020E61000000100000005000000DE054A0A2C044540E84A04AA7F704C40DE054A0A2C044540B6BE4868CB974C40AA9B8BBFED634540B6BE4868CB974C40AA9B8BBFED634540E84A04AA7F704C40DE054A0A2C044540E84A04AA7F704C40
1331	Лежневский район	\N	5	40.658298000000002	41.161093999999999	56.969695999999999	56.553897999999997	0103000020E61000000100000005000000D882DE1B43544440EFA83121E6464C40D882DE1B43544440F0879FFF1E7C4C4079CA6ABA9E944440F0879FFF1E7C4C4079CA6ABA9E944440EFA83121E6464C40D882DE1B43544440EFA83121E6464C40
1019	Комсомольский район	\N	5	40.019900999999997	40.741751000000001	57.314058000000003	56.910198000000001	0103000020E610000001000000050000002F14B01D8C0244403B71395E81744C402F14B01D8C0244400A86730D33A84C403D635FB2F15E44400A86730D33A84C403D635FB2F15E44403B71395E81744C402F14B01D8C0244403B71395E81744C40
1639	Кинешемский район	\N	5	41.892699999999998	42.882705999999999	57.691063999999997	57.097399000000003	0103000020E61000000100000005000000D1915CFE43F24440E1D40792778C4C40D1915CFE43F24440B2B8FFC874D84C40D2FD9C82FC704540B2B8FFC874D84C40D2FD9C82FC704540E1D40792778C4C40D1915CFE43F24440E1D40792778C4C40
234	Ильинский район	\N	5	39.376078	40.189897999999999	57.208550000000002	56.74335	0103000020E610000001000000050000005F5FEB5223B04340A5BDC117265F4C405F5FEB5223B0434058CA32C4B19A4C40B4C9E1934E18444058CA32C4B19A4C40B4C9E1934E184440A5BDC117265F4C405F5FEB5223B04340A5BDC117265F4C40
1299	Ивановский район	\N	5	40.618322999999997	41.427318	57.194682999999998	56.813631000000001	0103000020E61000000100000005000000ABAE4335254F44408201840F25684C40ABAE4335254F4440280B5F5FEB984C40FE7E315BB2B64440280B5F5FEB984C40FE7E315BB2B644408201840F25684C40ABAE4335254F44408201840F25684C40
1597	Заволжский район	\N	5	41.563898000000002	42.560093999999999	57.739085000000003	57.407198000000001	0103000020E61000000100000005000000D12346CF2DC84440917F66101FB44C40D12346CF2DC844406AFB57569ADE4C40C9570229B14745406AFB57569ADE4C40C9570229B1474540917F66101FB44C40D12346CF2DC84440917F66101FB44C40
1548	Гаврилово-Посадский район	\N	5	39.822280999999997	40.417988999999999	56.837893000000001	56.435366999999999	0103000020E61000000100000005000000A38FF98040E94340FA60191BBA374C40A38FF98040E943400F46EC13406B4C403B8BDEA9803544400F46EC13406B4C403B8BDEA980354440FA60191BBA374C40A38FF98040E94340FA60191BBA374C40
1515	Вичугский район	\N	5	41.546290999999997	42.366301	57.442196000000003	57.053494999999998	0103000020E61000000100000005000000B08C0DDDECC54440F0BF95ECD8864C40B08C0DDDECC544400536E7E099B84C40FDBE7FF3E22E45400536E7E099B84C40FDBE7FF3E22E4540F0BF95ECD8864C40B08C0DDDECC54440F0BF95ECD8864C40
1183	Вичуга городской округ	\N	5	41.861536999999998	41.964627999999998	57.237343000000003	57.180802	0103000020E61000000100000005000000A0A52BD846EE444094861A8524974C40A0A52BD846EE44409F776341619E4C40276728EE78FB44409F776341619E4C40276728EE78FB444094861A8524974C40A0A52BD846EE444094861A8524974C40
1222	Верхнеландеховский район	\N	5	42.230196999999997	42.891320999999998	56.952097000000002	56.697899	0103000020E6100000010000000500000093516518771D45409F7422C154594C4093516518771D454053CF8250DE794C40779E78CE1672454053CF8250DE794C40779E78CE167245409F7422C154594C4093516518771D45409F7422C154594C40
1280	Эртильский район	\N	4	40.348199000000001	41.157797000000002	51.961683999999998	51.542099999999998	0103000020E61000000100000005000000FDBFEAC8912C4440AF94658863C54940FDBFEAC8912C4440118B187618FB494016342DB132944440118B187618FB494016342DB132944440AF94658863C54940FDBFEAC8912C4440AF94658863C54940
986	Хохольский район	\N	4	38.607120999999999	39.17597	51.677475999999999	51.230365999999997	0103000020E610000001000000050000007FDB1324B64D43401F0E12A27C9D49407FDB1324B64D434096E99788B7D64940DF89592F8696434096E99788B7D64940DF89592F869643401F0E12A27C9D49407FDB1324B64D43401F0E12A27C9D4940
1131	Терновский район	\N	4	41.049801000000002	41.965778	51.803505000000001	51.491495	0103000020E61000000100000005000000702711E15F864440E292E34EE9BE4940702711E15F86444014967840D9E6494020990E9D9EFB444014967840D9E6494020990E9D9EFB4440E292E34EE9BE4940702711E15F864440E292E34EE9BE4940
1006	Таловский район	\N	4	40.389791000000002	41.211596999999998	51.385995999999999	50.936694000000003	0103000020E6100000010000000500000038A3E6ABE4314440022EC896E577494038A3E6ABE43144408331225168B149404277499C159B44408331225168B149404277499C159B4440022EC896E577494038A3E6ABE4314440022EC896E5774940
867	Семилукский район	\N	4	39.157508999999997	39.169313000000002	51.756749999999997	51.751319000000002	0103000020E61000000100000005000000AFE941412994434085EE92382BE04940AFE9414129944340BE9F1A2FDDE04940D2E4620CAC954340BE9F1A2FDDE04940D2E4620CAC95434085EE92382BE04940AFE941412994434085EE92382BE04940
538	Россошанский район	\N	4	39.179445999999999	40.214494000000002	50.381196000000003	49.854396999999999	0103000020E61000000100000005000000F2B22616F8964340776682E15CED4840F2B22616F8964340DAAED007CB3049401898158A741B4440DAAED007CB3049401898158A741B4440776682E15CED4840F2B22616F8964340776682E15CED4840
332	Репьевский район	\N	4	38.378275000000002	38.990898999999999	51.324395000000003	51.001061999999997	0103000020E610000001000000050000007CF2B0506B30434059A2B3CC228049407CF2B0506B30434033FE7DC685A94940CE5147C7D57E434033FE7DC685A94940CE5147C7D57E434059A2B3CC228049407CF2B0506B30434059A2B3CC22804940
17	Рамонский район	\N	4	38.707633000000001	40.088352999999998	52.092751999999997	50.452804	0103000020E610000001000000050000000249D8B7935A4340BEBF417BF53949400249D8B7935A4340BD512B4CDF0B4A4072C0AE264F0B4440BD512B4CDF0B4A4072C0AE264F0B4440BEBF417BF53949400249D8B7935A4340BEBF417BF5394940
4439	Раменский район	\N	4	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
1436	Подгоренский район	\N	4	39.278899000000003	40.098010000000002	50.752096999999999	50.275196999999999	0103000020E610000001000000050000008DF161F6B2A34340897AC1A7392349408DF161F6B2A34340B935E9B6446049402A5778978B0C4440B935E9B6446049402A5778978B0C4440897AC1A7392349408DF161F6B2A34340897AC1A739234940
1294	Поворинский район	\N	4	41.797595000000001	42.947294999999997	51.437184999999999	51.134458000000002	0103000020E61000000100000005000000003ACC9717E64440C15774EB35914940003ACC9717E64440A0A696ADF5B7494008556AF640794540A0A696ADF5B7494008556AF640794540C15774EB35914940003ACC9717E64440C15774EB35914940
1845	Петропавловский район	\N	4	40.650697999999998	41.384791999999997	50.335898999999998	49.804749000000001	0103000020E610000001000000050000004BC972124A5344408E3EE60302E748404BC972124A5344402AE109BDFE2A494097E13FDD40B144402AE109BDFE2A494097E13FDD40B144408E3EE60302E748404BC972124A5344408E3EE60302E74840
1484	Панинский район	\N	4	39.665092999999999	40.539199000000004	51.792197999999999	51.326500000000003	0103000020E6100000010000000500000036E675C421D543406F1283C0CAA9494036E675C421D5434072FA7ABE66E5494099840B790445444072FA7ABE66E5494099840B79044544406F1283C0CAA9494036E675C421D543406F1283C0CAA94940
1757	Павловский район	\N	4	39.771794999999997	40.673999999999999	50.810397999999999	50.215395999999998	0103000020E61000000100000005000000B01BB62DCAE2434038D89B18921B4940B01BB62DCAE24340355F251FBB67494083C0CAA145564440355F251FBB67494083C0CAA14556444038D89B18921B4940B01BB62DCAE2434038D89B18921B4940
887	Острогожский район	\N	4	38.706240999999999	39.350493999999998	51.261994999999999	50.620697999999997	0103000020E61000000100000005000000130CE71A665A4340A7583508734F4940130CE71A665A4340965B5A0D89A14940DCB8C5FCDCAC4340965B5A0D89A14940DCB8C5FCDCAC4340A7583508734F4940130CE71A665A4340A7583508734F4940
1636	Ольховатский район	\N	4	38.983919	39.494297000000003	50.538795	50.089992000000002	0103000020E61000000100000005000000DE74CB0EF17D434069739CDB840B4940DE74CB0EF17D4340C91F0C3CF744494066C1C41F45BF4340C91F0C3CF744494066C1C41F45BF434069739CDB840B4940DE74CB0EF17D434069739CDB840B4940
5817	Оленинский район	\N	4	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
1046	Новохоперский район	\N	4	41.008901000000002	41.876179999999998	51.427802	50.800767	0103000020E610000001000000050000006BF3FFAA23814440A75B76887F6649406BF3FFAA23814440EA944737C2B6494063B48EAA26F04440EA944737C2B6494063B48EAA26F04440A75B76887F6649406BF3FFAA23814440A75B76887F664940
1427	Новоусманский район	\N	4	39.282043000000002	39.903981999999999	51.935381999999997	51.491287999999997	0103000020E610000001000000050000006A882AFC19A4434068757286E2BE49406A882AFC19A443402FA2ED98BAF749401A16A3AEB5F343402FA2ED98BAF749401A16A3AEB5F3434068757286E2BE49406A882AFC19A4434068757286E2BE4940
1307	Нижнедевицкий район	\N	4	38.138415999999999	38.694059000000003	51.721150999999999	51.200650000000003	0103000020E610000001000000050000001F9F909DB7114340A1F831E6AE9949401F9F909DB7114340253D0CAD4EDC49404B3FE1ECD6584340253D0CAD4EDC49404B3FE1ECD6584340A1F831E6AE9949401F9F909DB7114340A1F831E6AE994940
1011	Лискинский район	\N	4	39.144995999999999	39.979692	51.280698000000001	50.769896000000003	0103000020E6100000010000000500000081069B3A8F9243401EA9BEF38B62494081069B3A8F924340BC067DE9EDA349409013268C66FD4340BC067DE9EDA349409013268C66FD43401EA9BEF38B62494081069B3A8F9243401EA9BEF38B624940
7318	Лиски городской округ	\N	4	39.431334	39.605606999999999	51.004072000000001	50.958905000000001	0103000020E6100000010000000500000091D3D7F335B74340467C2766BD7A494091D3D7F335B74340276A696E85804940459DB98784CD4340276A696E85804940459DB98784CD4340467C2766BD7A494091D3D7F335B74340467C2766BD7A4940
1039	Каширский район	\N	4	39.113796999999998	39.797272	51.474426999999999	51.142415	0103000020E6100000010000000500000003B16CE6908E4340DCBA9BA73A92494003B16CE6908E434071AB2006BABC49401D0247020DE6434071AB2006BABC49401D0247020DE64340DCBA9BA73A92494003B16CE6908E4340DCBA9BA73A924940
872	Кантемировский район	\N	4	39.194125	40.372399999999999	50.036600999999997	49.557834	0103000020E61000000100000005000000022B8716D9984340664CC11A67C74840022B8716D99843401D007157AF044940E4839ECDAA2F44401D007157AF044940E4839ECDAA2F4440664CC11A67C74840022B8716D9984340664CC11A67C74840
801	Каменский район	\N	4	39.049253	39.799894999999999	50.835496999999997	50.515895999999998	0103000020E610000001000000050000006D1D1CEC4D864340901150E1084249406D1D1CEC4D864340FB73D190F16A4940F19D98F562E64340FB73D190F16A4940F19D98F562E64340901150E1084249406D1D1CEC4D864340901150E108424940
561	Калачеевский район	\N	4	40.502692000000003	41.537973000000001	50.635987999999998	50.176997	0103000020E61000000100000005000000FDFA213658404440BC3E73D6A7164940FDFA2136584044400053060E68514940C5909C4CDCC444400053060E68514940C5909C4CDCC44440BC3E73D6A7164940FDFA213658404440BC3E73D6A7164940
297	Грибановский район	\N	4	41.127191000000003	42.372633999999998	51.732514000000002	51.245291999999999	0103000020E610000001000000050000003BAC70CB4790444037FC6EBA659F49403BAC70CB479044405BEECC04C3DD494057B08D78B22F45405BEECC04C3DD494057B08D78B22F454037FC6EBA659F49403BAC70CB4790444037FC6EBA659F4940
7319	Воронежская область	\N	4	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
1550	Воробьевский район	\N	4	40.616894000000002	41.418379999999999	50.854993999999998	50.517116000000001	0103000020E61000000100000005000000A08CF161F64E4440821E6ADB30424940A08CF161F64E44405B238271706D494076A6D0798DB544405B238271706D494076A6D0798DB54440821E6ADB30424940A08CF161F64E4440821E6ADB30424940
1102	Верхнехавский район	\N	4	39.377094	40.383898000000002	51.999769999999998	51.670198999999997	0103000020E6100000010000000500000048C2BE9D44B04340EC67B114C9D5494048C2BE9D44B04340CEC29E76F8FF4940FA7FD59123314440CEC29E76F8FF4940FA7FD59123314440EC67B114C9D5494048C2BE9D44B04340EC67B114C9D54940
1430	Верхнемамонский район	\N	4	40.008600000000001	40.712798999999997	50.449793	50.010100000000001	0103000020E61000000100000005000000705F07CE1901444045D8F0F44A014940705F07CE19014440207C28D1923949408DCF64FF3C5B4440207C28D1923949408DCF64FF3C5B444045D8F0F44A014940705F07CE1901444045D8F0F44A014940
1313	Бутурлиновский район	\N	4	40.099697999999997	41.119394	51.007398999999999	50.579996000000001	0103000020E6100000010000000500000001BD70E7C20C4440C9E7154F3D4A494001BD70E7C20C4440F5824F73F280494058AB764D488F4440F5824F73F280494058AB764D488F4440C9E7154F3D4A494001BD70E7C20C4440C9E7154F3D4A4940
1273	Борисоглебский район	\N	4	41.889797999999999	42.791418999999998	51.631211	51.219993000000002	0103000020E61000000100000005000000EA059FE6E4F14440AA2C0ABB289C4940EA059FE6E4F144400FF0A485CBD049406D37C1374D6545400FF0A485CBD049406D37C1374D654540AA2C0ABB289C4940EA059FE6E4F14440AA2C0ABB289C4940
1073	Богучарский район	\N	4	40.188496999999998	41.04663	50.127197000000002	49.578563000000003	0103000020E61000000100000005000000723271AB201844407CD6355A0ECA4840723271AB201844401D93C5FD471049409981CAF8F78544401D93C5FD471049409981CAF8F78544407CD6355A0ECA4840723271AB201844407CD6355A0ECA4840
922	Бобровский район	\N	4	39.694693000000001	40.494095000000002	51.401597000000002	50.727397000000003	0103000020E610000001000000050000004CE141B3EBD84340B11A4B581B5D49404CE141B3EBD84340FB95CE8767B34940FE0E45813E3F4440FB95CE8767B34940FE0E45813E3F4440B11A4B581B5D49404CE141B3EBD84340B11A4B581B5D4940
485	Аннинский район	\N	4	40.064799000000001	41.197997000000001	51.664596000000003	51.252898000000002	0103000020E6100000010000000500000021E868554B084440A69C2FF65EA0494021E868554B084440B686527B11D5494062DA37F757994440B686527B11D5494062DA37F757994440A69C2FF65EA0494021E868554B084440A69C2FF65EA04940
5947	Алексеевский район	\N	4	38.138263000000002	42.947150999999998	52.102777000000003	49.556986000000002	0103000020E61000000100000005000000999F1B9AB2114340392A37514BC74840999F1B9AB2114340F8E3F6CB270D4A40D5AF743E3C794540F8E3F6CB270D4A40D5AF743E3C794540392A37514BC74840999F1B9AB2114340392A37514BC74840
1118	Юрьев-Польский район	\N	3	39.224991000000003	40.242099000000003	56.810758	56.242794000000004	0103000020E610000001000000050000007A724D81CC9C434020D5B0DF131F4C407A724D81CC9C4340357C0BEBC6674C4079B29B19FD1E4440357C0BEBC6674C4079B29B19FD1E444020D5B0DF131F4C407A724D81CC9C434020D5B0DF131F4C40
1017	Суздальский район	\N	3	40.081921000000001	40.778860999999999	56.593913999999998	56.067163000000001	0103000020E6100000010000000500000085ED27637C0A4440294014CC98084C4085ED27637C0A44407A51BB5F054C4C409F909DB7B16344407A51BB5F054C4C409F909DB7B1634440294014CC98084C4085ED27637C0A4440294014CC98084C40
1045	Судогодский район	\N	3	40.274106000000003	41.424489000000001	56.163423999999999	55.584848000000001	0103000020E6100000010000000500000096D1C8E715234440C5909C4CDCCA4B4096D1C8E715234440D5B0DF13EB144C408141D2A755B64440D5B0DF13EB144C408141D2A755B64440C5909C4CDCCA4B4096D1C8E715234440C5909C4CDCCA4B40
858	Собинский район	\N	3	39.637937000000001	40.294103	56.284109000000001	55.74333	0103000020E6100000010000000500000045F46BEBA7D143405E11FC6F25DF4B4045F46BEBA7D14340E8BF07AF5D244C40E753C72AA5254440E8BF07AF5D244C40E753C72AA52544405E11FC6F25DF4B4045F46BEBA7D143405E11FC6F25DF4B40
707	Селивановский район	\N	3	41.263601000000001	42.071993999999997	56.033495000000002	55.587097	0103000020E61000000100000005000000B11875ADBDA14440344A97FE25CB4B40B11875ADBDA144402ECA6C9049044C400DC17119370945402ECA6C9049044C400DC1711937094540344A97FE25CB4B40B11875ADBDA14440344A97FE25CB4B40
1338	Радужный ЗАТО	\N	3	40.316398999999997	40.346995999999997	56.010497999999998	55.995699999999999	0103000020E6100000010000000500000059BE2EC37F2844404850FC1873FF4B4059BE2EC37F28444032569BFF57014C40E1EB6B5D6A2C444032569BFF57014C40E1EB6B5D6A2C44404850FC1873FF4B4059BE2EC37F2844404850FC1873FF4B40
751	Петушинский район	\N	3	38.864792999999999	39.803460999999999	56.516204000000002	55.758493000000001	0103000020E61000000100000005000000A5677A89B16E43405A9F724C16E14B40A5677A89B16E43403E0801F912424C40444E5FCFD7E643403E0801F912424C40444E5FCFD7E643405A9F724C16E14B40A5677A89B16E43405A9F724C16E14B40
190	Муромский район	\N	3	41.700397000000002	42.484994999999998	55.959102000000001	55.467300000000002	0103000020E61000000100000005000000B79BE09BA6D94440DDB5847CD0BB4B40B79BE09BA6D944409CC3B5DAC3FA4B409CDCEF50143E45409CC3B5DAC3FA4B409CDCEF50143E4540DDB5847CD0BB4B40B79BE09BA6D94440DDB5847CD0BB4B40
649	Меленковский район	\N	3	41.064695999999998	42.164386	55.640898999999997	55.104213000000001	0103000020E610000001000000050000004C1762F547884440B66801DA568D4B404C1762F54788444001857AFA08D24B40CBF5B6990A15454001857AFA08D24B40CBF5B6990A154540B66801DA568D4B404C1762F547884440B66801DA568D4B40
5097	Красногорский район	\N	3	38.276963000000002	42.972842999999997	56.810733999999997	55.104182000000002	0103000020E61000000100000005000000DD990986732343407B6AF5D5558D4B40DD99098673234340ACE0B721C6674C403E92921E867C4540ACE0B721C6674C403E92921E867C45407B6AF5D5558D4B40DD990986732343407B6AF5D5558D4B40
539	Кольчугинский район	\N	3	39.118288999999997	39.767797999999999	56.474494	56.094098000000002	0103000020E61000000100000005000000FF3C0D18248F43403C4F3C670B0C4C40FF3C0D18248F4340F9122A38BC3C4C4094F7713447E24340F9122A38BC3C4C4094F7713447E243403C4F3C670B0C4C40FF3C0D18248F43403C4F3C670B0C4C40
1063	Ковровский район	\N	3	41.034297000000002	41.956381	56.527901999999997	55.963697000000003	0103000020E61000000100000005000000EBAC16D8638444406D205D6C5AFB4B40EBAC16D8638444401ABFF04A92434C4005C24EB16AFA44401ABFF04A92434C4005C24EB16AFA44406D205D6C5AFB4B40EBAC16D8638444406D205D6C5AFB4B40
378	Киржачский район	\N	3	38.529515000000004	39.214345999999999	56.495756999999998	55.949758000000003	0103000020E61000000100000005000000E8DEC325C7434340A48E8EAB91F94B40E8DEC325C7434340ACE122F7743F4C40A30392B06F9B4340ACE122F7743F4C40A30392B06F9B4340A48E8EAB91F94B40E8DEC325C7434340A48E8EAB91F94B40
788	Камешковский район	\N	3	40.559491999999999	41.198500000000003	56.528010999999999	56.123297000000001	0103000020E61000000100000005000000D32F116F9D474440F3583332C80F4C40D32F116F9D474440D1764CDD95434C40C520B07268994440D1764CDD95434C40C520B07268994440F3583332C80F4C40D32F116F9D474440F3583332C80F4C40
1145	Гусь-Хрустальный район	\N	3	39.994784000000003	41.342112999999998	55.961959	55.179817	0103000020E61000000100000005000000C34A051555FF4340E621533E04974B40C34A051555FF4340E38BF67821FB4B40AA44D95BCAAB4440E38BF67821FB4B40AA44D95BCAAB4440E621533E04974B40C34A051555FF4340E621533E04974B40
14	Гороховецкий район	\N	3	42.145899	42.972968999999999	56.407178000000002	55.801298000000003	0103000020E6100000010000000500000072C284D1AC124540D42CD0EE90E64B4072C284D1AC1245404AD3A0681E344C40CB82893F8A7C45404AD3A0681E344C40CB82893F8A7C4540D42CD0EE90E64B4072C284D1AC124540D42CD0EE90E64B40
1160	Вязниковский район	\N	3	41.549992000000003	42.594616000000002	56.450741999999998	55.904497999999997	0103000020E61000000100000005000000E4874A2366C6444011A62897C6F34B40E4874A2366C644408177F2E9B1394C40D4D688601C4C45408177F2E9B1394C40D4D688601C4C454011A62897C6F34B40E4874A2366C6444011A62897C6F34B40
12	Александровский район	\N	3	38.277788999999999	39.232616999999998	56.661121000000001	56.203522999999997	0103000020E61000000100000005000000221807978E234340ED7DAA0A0D1A4C40221807978E23434073D9E89C9F544C402FBFD364C69D434073D9E89C9F544C402FBFD364C69D4340ED7DAA0A0D1A4C40221807978E234340ED7DAA0A0D1A4C40
1279	Клинцовский район	\N	2	31.758400999999999	32.546996	52.942297000000003	52.475796000000003	0103000020E61000000100000005000000F240649126C23F40A8C821E2E63C4A40F240649126C23F40390F27309D784A407B8505F703464040390F27309D784A407B8505F703464040A8C821E2E63C4A40F240649126C23F40A8C821E2E63C4A40
7100	Клинцы городской округ	\N	2	32.194226999999998	32.301163000000003	52.780856	52.731734000000003	0103000020E6100000010000000500000006802A6EDC18404086AFAF75A95D4A4006802A6EDC1840405471E316F3634A40F4E159828C2640405471E316F3634A40F4E159828C26404086AFAF75A95D4A4006802A6EDC18404086AFAF75A95D4A40
1139	Унечский район	\N	2	32.426900000000003	33.198894000000003	52.991798000000003	52.660494999999997	0103000020E61000000100000005000000CA54C1A8A4364040F415A4198B544A40CA54C1A8A43640407E1EA33CF37E4A4071AFCC5B759940407E1EA33CF37E4A4071AFCC5B75994040F415A4198B544A40CA54C1A8A4364040F415A4198B544A40
1482	Трубчевский район	\N	2	33.391089000000001	34.161197000000001	52.869100000000003	52.301127000000001	0103000020E61000000100000005000000A56950340FB24040A7785C548B264A40A56950340FB24040107A36AB3E6F4A404E9B711AA2144140107A36AB3E6F4A404E9B711AA2144140A7785C548B264A40A56950340FB24040A7785C548B264A40
1345	Суражский район	\N	2	32.123108000000002	32.783298000000002	53.340058999999997	52.862499999999997	0103000020E6100000010000000500000020F0C000C20F404066666666666E4A4020F0C000C20F4040F0DAA50D87AB4A40D882DE1B43644040F0DAA50D87AB4A40D882DE1B4364404066666666666E4A4020F0C000C20F404066666666666E4A40
1308	Суземский район	\N	2	33.795537000000003	34.452995999999999	52.707597	52.121499	0103000020E6100000010000000500000005E10A28D4E5404094BF7B478D0F4A4005E10A28D4E54040B5DFDA89925A4A40029CDEC5FB394140B5DFDA89925A4A40029CDEC5FB39414094BF7B478D0F4A4005E10A28D4E5404094BF7B478D0F4A40
1182	Стародубский район	\N	2	32.410693999999999	33.188994999999998	52.777096999999998	52.244332999999997	0103000020E61000000100000005000000EB54F99E91344040B22AC24D461F4A40EB54F99E91344040EC681CEA77634A40C30DF8FC30984040EC681CEA77634A40C30DF8FC30984040B22AC24D461F4A40EB54F99E91344040B22AC24D461F4A40
1072	Севский район	\N	2	34.060971000000002	34.744455000000002	52.330294000000002	51.843623000000001	0103000020E610000001000000050000009180D1E5CD074140A393A5D6FBEB49409180D1E5CD0741405308E412472A4A40FE2B2B4D4A5F41405308E412472A4A40FE2B2B4D4A5F4140A393A5D6FBEB49409180D1E5CD074140A393A5D6FBEB4940
1023	Рогнединский район	\N	2	33.245113000000003	33.921697000000002	54.034373000000002	53.672196	0103000020E610000001000000050000008869DFDC5F9F40404240BE840AD64A408869DFDC5F9F4040C66E9F5566044B4021E9D32AFAF54040C66E9F5566044B4021E9D32AFAF540404240BE840AD64A408869DFDC5F9F40404240BE840AD64A40
861	Почепский район	\N	2	33.067200999999997	33.857719000000003	53.197096999999999	52.654300999999997	0103000020E6100000010000000500000016A1D80A9A884040BB5E9A22C0534A4016A1D80A9A884040E29178793A994A40341477BCC9ED4040E29178793A994A40341477BCC9ED4040BB5E9A22C0534A4016A1D80A9A884040BB5E9A22C0534A40
578	Погарский район	\N	2	32.897995000000002	33.513196999999998	52.753596000000002	52.272568	0103000020E610000001000000050000005B7C0A80F1724040D3F71A82E3224A405B7C0A80F1724040BE326FD575604A40E1B37570B0C14040BE326FD575604A40E1B37570B0C14040D3F71A82E3224A405B7C0A80F1724040D3F71A82E3224A40
1218	Новозыбковский район	\N	2	31.496891999999999	32.266596	52.760196000000001	52.412092999999999	0103000020E61000000100000005000000DFA46950347F3F408CF4A276BF344A40DFA46950347F3F4067463F1A4E614A40499F56D11F22404067463F1A4E614A40499F56D11F2240408CF4A276BF344A40DFA46950347F3F408CF4A276BF344A40
7102	Новозыбков городской округ	\N	2	31.898529	31.986384000000001	52.570188999999999	52.499459000000002	0103000020E61000000100000005000000F1811DFF05E63F40B058C345EE3F4A40F1811DFF05E63F40FCC401F4FB484A40344C6DA983FC3F40FCC401F4FB484A40344C6DA983FC3F40B058C345EE3F4A40F1811DFF05E63F40B058C345EE3F4A40
209	Навлинский район	\N	2	33.980392999999999	34.864353000000001	53.139995999999996	52.642094999999998	0103000020E61000000100000005000000191D90847DFD40406AF6402B30524A40191D90847DFD404010C99063EB914A4089997D1EA36E414010C99063EB914A4089997D1EA36E41406AF6402B30524A40191D90847DFD40406AF6402B30524A40
104	Мглинский район	\N	2	32.592298	33.193486	53.330095999999998	52.904397000000003	0103000020E610000001000000050000003CBEBD6BD04B4040DECCE847C3734A403CBEBD6BD04B40402C45F29540AA4A40EF1D3526C49840402C45F29540AA4A40EF1D3526C4984040DECCE847C3734A403CBEBD6BD04B4040DECCE847C3734A40
1899	Краснорский район	\N	2	31.259575000000002	31.817851000000001	53.229781000000003	52.750734000000001	0103000020E61000000100000005000000F5DBD78173423F4065FF3C0D18604A40F5DBD78173423F40001FBC76699D4A403B00E2AE5ED13F40001FBC76699D4A403B00E2AE5ED13F4065FF3C0D18604A40F5DBD78173423F4065FF3C0D18604A40
1855	Комаричский район	\N	2	34.266596	34.959654999999998	52.528998999999999	52.187671000000002	0103000020E61000000100000005000000499F56D11F2241402DB4739A05184A40499F56D11F224140F04E3E3DB6434A40B0389CF9D57A4140F04E3E3DB6434A40B0389CF9D57A41402DB4739A05184A40499F56D11F2241402DB4739A05184A40
1784	Климовский район	\N	2	31.780211999999999	32.577494000000002	52.518698000000001	52.033673999999998	0103000020E610000001000000050000005EF23FF9BBC73F40DD5CFC6D4F044A405EF23FF9BBC73F40144031B264424A4070D1C952EB494040144031B264424A4070D1C952EB494040DD5CFC6D4F044A405EF23FF9BBC73F40DD5CFC6D4F044A40
1746	Клетнянский район	\N	2	32.724952000000002	33.531593999999998	53.641976999999997	53.134999000000001	0103000020E61000000100000005000000BC95253ACB5C404011FFB0A547914A40BC95253ACB5C404060E4654D2CD24A40FA5FAE450BC4404060E4654D2CD24A40FA5FAE450BC4404011FFB0A547914A40BC95253ACB5C404011FFB0A547914A40
1689	Карачевский район	\N	2	34.573594999999997	35.325870999999999	53.376973999999997	52.862896999999997	0103000020E6100000010000000500000016139B8F6B4941408368AD68736E4A4016139B8F6B4941409DB81CAF40B04A407FDB1324B6A941409DB81CAF40B04A407FDB1324B6A941408368AD68736E4A4016139B8F6B4941408368AD68736E4A40
1672	Злынковский район	\N	2	31.533238000000001	32.051898000000001	52.552571999999998	52.184198000000002	0103000020E6100000010000000500000005FC1A4982883F408BFED0CC93174A4005FC1A4982883F40B857E6ADBA464A40295DFA97A4064040B857E6ADBA464A40295DFA97A40640408BFED0CC93174A4005FC1A4982883F408BFED0CC93174A40
1016	Жуковский район	\N	2	33.367400000000004	34.05639	53.770097999999997	53.320796999999999	0103000020E61000000100000005000000744694F606AF4040D4D347E00FA94A40744694F606AF4040855B3E9292E24A4025E99AC937074140855B3E9292E24A4025E99AC937074140D4D347E00FA94A40744694F606AF4040D4D347E00FA94A40
1569	Жирятинский район	\N	2	33.297699999999999	33.962291999999998	53.355997000000002	53.077198000000003	0103000020E6100000010000000500000075029A081BA6404087A8C29FE1894A4075029A081BA64040B03C484F91AD4A40E9995E622CFB4040B03C484F91AD4A40E9995E622CFB404087A8C29FE1894A4075029A081BA6404087A8C29FE1894A40
1458	Дятьковский район	\N	2	33.824193999999999	34.567594	53.919601	53.383699	0103000020E610000001000000050000009BC761307FE940400341800C1DB14A409BC761307FE94040382F4E7CB5F54A40F2B391EBA6484140382F4E7CB5F54A40F2B391EBA64841400341800C1DB14A409BC761307FE940400341800C1DB14A40
1110	Дубровский район	\N	2	33.014093000000003	33.747396999999999	53.832974999999998	53.452298999999996	0103000020E61000000100000005000000200DA7CCCD814040BA8102EFE4B94A40200DA7CCCD8140405BB1BFEC9EEA4A40731074B4AADF40405BB1BFEC9EEA4A40731074B4AADF4040BA8102EFE4B94A40200DA7CCCD814040BA8102EFE4B94A40
1179	Гордеевский район	\N	2	31.679096999999999	32.180995000000003	53.123204000000001	52.698697000000003	0103000020E61000000100000005000000CCCF0D4DD9AD3F401B683EE76E594A40CCCF0D4DD9AD3F40425E0F26C58F4A40A9DE1AD82A174040425E0F26C58F4A40A9DE1AD82A1740401B683EE76E594A40CCCF0D4DD9AD3F401B683EE76E594A40
1297	Выгоничский район	\N	2	33.601097000000003	34.329594999999998	53.235698999999997	52.839697999999999	0103000020E61000000100000005000000A35C1ABFF0CC404020425C397B6B4A40A35C1ABFF0CC4040965984622B9E4A406AF6402B302A4140965984622B9E4A406AF6402B302A414020425C397B6B4A40A35C1ABFF0CC404020425C397B6B4A40
1191	Брянский район	\N	2	33.754862000000003	34.936604000000003	53.532558999999999	53.111010999999998	0103000020E61000000100000005000000207F69519FE04040853FC39B358E4A40207F69519FE040406118B0E42AC44A40C2A6CEA3E27741406118B0E42AC44A40C2A6CEA3E2774140853FC39B358E4A40207F69519FE04040853FC39B358E4A40
1116	Брасовский район	\N	2	34.277492000000002	35.113886999999998	52.815500999999998	52.451199000000003	0103000020E6100000010000000500000069739CDB84234140747E8AE3C0394A4069739CDB842341407A6D365662684A40433866D9938E41407A6D365662684A40433866D9938E4140747E8AE3C0394A4069739CDB84234140747E8AE3C0394A40
7305	Старый Оскол городской округ	\N	1	37.469853000000001	37.481926999999999	50.406187000000003	50.400433999999997	0103000020E61000000100000005000000B876A22424BC42406D1ADB6B41334940B876A22424BC4240BA8784EFFD3349409A07B0C8AFBD4240BA8784EFFD3349409A07B0C8AFBD42406D1ADB6B41334940B876A22424BC42406D1ADB6B41334940
6958	Губкин городской округ	\N	1	37.467948999999997	37.686796999999999	51.321463000000001	51.248044	0103000020E610000001000000050000001399B9C0E5BB424009FCE1E7BF9F49401399B9C0E5BB4240E1EF17B325A94940D6FECEF6E8D74240E1EF17B325A94940D6FECEF6E8D7424009FCE1E7BF9F49401399B9C0E5BB424009FCE1E7BF9F4940
7303	Белгород городской округ	\N	1	36.503490999999997	36.683711000000002	50.661848999999997	50.527819999999998	0103000020E61000000100000005000000486AA164724042405D16139B8F434940486AA16472404240F5F1D077B75449402E7590D783574240F5F1D077B75449402E7590D7835742405D16139B8F434940486AA164724042405D16139B8F434940
7308	Белгород	\N	1	36.519947999999999	36.676372000000001	50.653409000000003	50.547502000000001	0103000020E6100000010000000500000070CFF3A78D4242404F3FA88B1446494070CFF3A78D424240BFF4F6E7A25349400EF7915B93564240BFF4F6E7A25349400EF7915B935642404F3FA88B1446494070CFF3A78D4242404F3FA88B14464940
1588	Белгородский район	\N	1	36.084893999999998	36.878591	50.768397999999998	50.277608999999998	0103000020E6100000010000000500000035D07CCEDD0A4240A20914B18823494035D07CCEDD0A4240E9279CDD5A624940ACC77DAB75704240E9279CDD5A624940ACC77DAB75704240A20914B18823494035D07CCEDD0A4240A20914B188234940
46	Яковлевский район	\N	1	36.045799000000002	36.932796000000003	50.904096000000003	50.555498	0103000020E610000001000000050000004298DBBDDC054240287FF78E1A4749404298DBBDDC054240E338F06AB973494079EBFCDB65774240E338F06AB973494079EBFCDB65774240287FF78E1A4749404298DBBDDC054240287FF78E1A474940
1249	Шебекинский район	\N	1	36.562294000000001	37.577894000000001	50.692495000000001	50.219748000000003	0103000020E61000000100000005000000575EF23FF947424043AED4B3201C4940575EF23FF94742405FD218ADA3584940FE463B6EF8C942405FD218ADA3584940FE463B6EF8C9424043AED4B3201C4940575EF23FF947424043AED4B3201C4940
1807	Чернянский район	\N	1	37.445095999999999	38.322991999999999	51.124294999999996	50.834598999999997	0103000020E610000001000000050000004BCADDE7F8B842401C23D923D46A49404BCADDE7F8B84240350708E6E88F4940506F46CD57294340350708E6E88F4940506F46CD572943401C23D923D46A49404BCADDE7F8B842401C23D923D46A4940
1473	Старооскольский район	\N	1	37.586598000000002	38.527251	51.432057999999998	51.020795	0103000020E6100000010000000500000013F3ACA415CB4240CD751A69A982494013F3ACA415CB4240D2FC31AD4DB7494043E4F4F57C434340D2FC31AD4DB7494043E4F4F57C434340CD751A69A982494013F3ACA415CB4240CD751A69A9824940
474	Ровеньский район	\N	1	38.686836999999997	39.280335999999998	50.304997	49.796672000000001	0103000020E6100000010000000500000064575A46EA574340C8D11C59F9E5484064575A46EA574340663046240A2749401BF2CF0CE2A34340663046240A2749401BF2CF0CE2A34340C8D11C59F9E5484064575A46EA574340C8D11C59F9E54840
1531	Ракитянский район	\N	1	35.542195	36.161897000000003	51.035518000000003	50.650297000000002	0103000020E61000000100000005000000018750A566C54140EDD79DEE3C534940018750A566C54140AD3594DA8B8449400729780AB9144240AD3594DA8B8449400729780AB9144240EDD79DEE3C534940018750A566C54140EDD79DEE3C534940
627	Прохоровский район	\N	1	36.449492999999997	37.202900999999997	51.206361000000001	50.819395999999998	0103000020E61000000100000005000000F56393FC88394240923CD7F7E1684940F56393FC88394240BE1589096A9A4940B0A9F3A8F8994240BE1589096A9A4940B0A9F3A8F8994240923CD7F7E1684940F56393FC88394240923CD7F7E1684940
1288	Новооскольский район	\N	1	37.440694000000001	38.290796999999998	50.943199	50.542700000000004	0103000020E610000001000000050000008FC536A968B8424005C58F31774549408FC536A968B84240594FADBEBA78494030630AD638254340594FADBEBA78494030630AD63825434005C58F31774549408FC536A968B8424005C58F3177454940
2913	Матвеево-Курганский район	\N	1	35.326743	39.280299999999997	51.430688000000004	49.795828999999998	0103000020E610000001000000050000003599F1B6D2A94140AC1A84B9DDE548403599F1B6D2A94140CC63CDC820B74940CE88D2DEE0A34340CC63CDC820B74940CE88D2DEE0A34340AC1A84B9DDE548403599F1B6D2A94140AC1A84B9DDE54840
1134	Краснояружский район	\N	1	35.327120000000001	35.737596000000003	50.975797999999998	50.660592999999999	0103000020E610000001000000050000000BEF7211DFA94140B77BB94F8E5449400BEF7211DFA9414048C0E8F2E67C494089D4B48B69DE414048C0E8F2E67C494089D4B48B69DE4140B77BB94F8E5449400BEF7211DFA94140B77BB94F8E544940
468	Красногвардейский район	\N	1	38.017898000000002	38.609392999999997	50.913201000000001	50.280194000000002	0103000020E61000000100000005000000F8544E7B4A0243408944A165DD234940F8544E7B4A02434056D636C5E3744940A6B4FE96004E434056D636C5E3744940A6B4FE96004E43408944A165DD234940F8544E7B4A0243408944A165DD234940
396	Красненский район	\N	1	38.271698999999998	38.891562999999998	51.105297	50.779094999999998	0103000020E610000001000000050000008EAD6708C722434012BD8C62B96349408EAD6708C7224340F7AE415F7A8D49406DA983BC1E724340F7AE415F7A8D49406DA983BC1E72434012BD8C62B96349408EAD6708C722434012BD8C62B9634940
483	Корочанский район	\N	1	36.696593	37.552992000000003	50.991396999999999	50.617393999999997	0103000020E61000000100000005000000AFCF9CF529594240915F3FC4064F4940AFCF9CF5295942401F2DCE18E67E49408E791D71C8C642401F2DCE18E67E49408E791D71C8C64240915F3FC4064F4940AFCF9CF529594240915F3FC4064F4940
797	Ивнянский район	\N	1	35.920197000000002	36.532398999999998	51.167555	50.874794000000001	0103000020E610000001000000050000004C70EA03C9F54140575EF23FF96F49404C70EA03C9F5414001A436717295494028B682A62544424001A436717295494028B682A625444240575EF23FF96F49404C70EA03C9F54140575EF23FF96F4940
522	Губкинский район	\N	1	37.018836	37.758490999999999	51.392246	50.940032000000002	0103000020E6100000010000000500000065FED13769824240C498F4F75278494065FED1376982424050FEEE1D35B24940B9A7AB3B16E1424050FEEE1D35B24940B9A7AB3B16E14240C498F4F75278494065FED13769824240C498F4F752784940
59	Грайворонский район	\N	1	35.392525999999997	35.912399000000001	50.716597	50.351576000000001	0103000020E61000000100000005000000336ABE4A3EB241407D073F71002D4940336ABE4A3EB24140B3B45373B95B494099F38C7DC9F44140B3B45373B95B494099F38C7DC9F441407D073F71002D4940336ABE4A3EB241407D073F71002D4940
1875	Волоконовский район	\N	1	37.463062000000001	38.158700000000003	50.632697	50.266796999999997	0103000020E610000001000000050000009B02999D45BB4240E0D57267262249409B02999D45BB42407FA31D37FC50494007F01648501443407FA31D37FC50494007F0164850144340E0D57267262249409B02999D45BB4240E0D5726726224940
1836	Вейделевский район	\N	1	38.266793999999997	38.87039	50.413896999999999	49.956218999999997	0103000020E610000001000000050000006F62484E262243402B685A6265FA48406F62484E26224340CD74AF93FA344940FA6184F0686F4340CD74AF93FA344940FA6184F0686F43402B685A6265FA48406F62484E262243402B685A6265FA4840
1112	Валуйский район	\N	1	37.613961000000003	38.416327000000003	50.427498999999997	49.901076000000003	0103000020E610000001000000050000007E02284696CE4240F29A577556F348407E02284696CE42404E098849B83649408DB800344A3543404E098849B83649408DB800344A354340F29A577556F348407E02284696CE4240F29A577556F34840
1727	Борисовский район	\N	1	35.736294000000001	36.215966999999999	50.772801000000001	50.431372000000003	0103000020E61000000100000005000000DA1EBDE13EDE41407F349C3237374940DA1EBDE13EDE414076A8A624EB624940F30181CEA41B424076A8A624EB624940F30181CEA41B42407F349C3237374940DA1EBDE13EDE41407F349C3237374940
7306	Белгородский	\N	1	36.084893999999998	36.878591	50.768397999999998	50.277608999999998	0103000020E6100000010000000500000035D07CCEDD0A4240A20914B18823494035D07CCEDD0A4240E9279CDD5A624940ACC77DAB75704240E9279CDD5A624940ACC77DAB75704240A20914B18823494035D07CCEDD0A4240A20914B188234940
1165	Алексеевский район	\N	1	38.478895000000001	39.126579999999997	50.822702	50.250297000000003	0103000020E61000000100000005000000E59B6D6E4C3D4340BAA46ABB09204940E59B6D6E4C3D4340492D944C4E694940F12900C633904340492D944C4E694940F12900C633904340BAA46ABB09204940E59B6D6E4C3D4340BAA46ABB09204940
3637	Тихвинский район	\N	\N	\N	\N	\N	\N	\N
3877	Ломоносовский район	\N	\N	\N	\N	\N	\N	\N
4266	Можайский район	\N	\N	\N	\N	\N	\N	\N
181	Ямальский район	\N	33	66.417192	73.613892000000007	73.475098000000003	66.464297999999999	0103000020E61000000100000005000000C8091346B39A50404966F50EB79D5040C8091346B39A504048197101685E5240ABD1AB014A67524048197101685E5240ABD1AB014A6752404966F50EB79D5040C8091346B39A50404966F50EB79D5040
49	Шурышкарский район	\N	33	62.001389000000003	69.060897999999995	66.868706000000003	64.023398999999998	0103000020E610000001000000050000007EC9C6832D004F4095F0845E7F0150407EC9C6832D004F40B2F50CE198B750401399B9C0E5435140B2F50CE198B750401399B9C0E543514095F0845E7F0150407EC9C6832D004F4095F0845E7F015040
347	Тазовский район	\N	33	73.005598000000006	82.877993000000004	73.524799999999999	66.321398000000002	0103000020E6100000010000000500000013BBB6B75B405240FDBFEAC89194504013BBB6B75B405240363CBD52966152407C478D0931B85440363CBD52966152407C478D0931B85440FDBFEAC89194504013BBB6B75B405240FDBFEAC891945040
279	Пуровский район	\N	33	73.069800999999998	80.833697000000001	67.705399	62.464699000000003	0103000020E61000000100000005000000990E9D9E77445240F1BDBF417B3B4F40990E9D9E7744524064E8D84125ED50407E71A94A5B35544064E8D84125ED50407E71A94A5B355440F1BDBF417B3B4F40990E9D9E77445240F1BDBF417B3B4F40
295	Приуральский район	\N	33	64.522762	70.747099000000006	69.269897999999998	64.324198999999993	0103000020E61000000100000005000000DC65BFEE74215040569929ADBF145040DC65BFEE742150405FD0420246515140F5F75278D0AF51405FD0420246515140F5F75278D0AF5140569929ADBF145040DC65BFEE74215040569929ADBF145040
276	Надымский район	\N	33	68.566294999999997	77.458393999999998	68.930599999999998	63.195298999999999	0103000020E61000000100000005000000DA38622D3E24514083F8C08EFF984F40DA38622D3E245140166A4DF38E3B5140B0ABC953565D5340166A4DF38E3B5140B0ABC953565D534083F8C08EFF984F40DA38622D3E24514083F8C08EFF984F40
358	Красноселькупский район	\N	33	79.202797000000004	86.014298999999994	66.984296999999998	62.203499999999998	0103000020E6100000010000000500000086AE44A0FACC5340355EBA490C1A4F4086AE44A0FACC53404223D8B8FEBE504064575A46EA8055404223D8B8FEBE504064575A46EA805540355EBA490C1A4F4086AE44A0FACC5340355EBA490C1A4F40
1318	городской округ Миасс	\N	58	59.609102999999998	60.317622	55.428576999999997	54.759872000000001	0103000020E610000001000000050000009F724C16F7CD4D40B492567C43614B409F724C16F7CD4D40AD68739CDBB64B40BC3E73D6A7284E40AD68739CDBB64B40BC3E73D6A7284E40B492567C43614B409F724C16F7CD4D40B492567C43614B40
731	городской округ Южноуральск	\N	58	61.028683999999998	61.312452999999998	54.525525000000002	54.347126000000003	0103000020E6100000010000000500000090F5D4EAAB834E40B0CBF09F6E2C4B4090F5D4EAAB834E407E1D386744434B40BF44BC75FEA74E407E1D386744434B40BF44BC75FEA74E40B0CBF09F6E2C4B4090F5D4EAAB834E40B0CBF09F6E2C4B40
1876	городской округ Усть-Катав	\N	58	58.038955999999999	58.673426999999997	55.170059000000002	54.836528999999999	0103000020E61000000100000005000000D2FD9C82FC044D40EA93DC61136B4B40D2FD9C82FC044D40FBB1497EC4954B40279F1EDB32564D40FBB1497EC4954B40279F1EDB32564D40EA93DC61136B4B40D2FD9C82FC044D40EA93DC61136B4B40
1626	городской округ Пласт	\N	58	60.326946999999997	61.048366000000001	54.569591000000003	54.173400000000001	0103000020E610000001000000050000003D433866D9294E402E90A0F831164B403D433866D9294E40488C9E5BE8484B40821E6ADB30864E40488C9E5BE8484B40821E6ADB30864E402E90A0F831164B403D433866D9294E402E90A0F831164B40
1912	городской округ Кыштым	\N	58	60.074826000000002	60.898401	55.864586000000003	55.564292000000002	0103000020E61000000100000005000000FC71FBE593094E407DB262B83AC84B40FC71FBE593094E402C4A09C1AAEE4B40CBD8D0CDFE724E402C4A09C1AAEE4B40CBD8D0CDFE724E407DB262B83AC84B40FC71FBE593094E407DB262B83AC84B40
6956	городской округ Коркино	\N	58	61.151304000000003	61.483573	54.958689	54.842227000000001	0103000020E6100000010000000500000083E0F1ED5D934E4073672618CE6B4B4083E0F1ED5D934E4079043752B67A4B40431D56B8E5BD4E4079043752B67A4B40431D56B8E5BD4E4073672618CE6B4B4083E0F1ED5D934E4073672618CE6B4B40
1282	городской округ Карабаш	\N	58	59.972695999999999	60.495291000000002	55.711874000000002	55.379879000000003	0103000020E610000001000000050000009A79724D81FC4D40F6B704E09FB04B409A79724D81FC4D40B56FEEAF1EDB4B4067800BB2653F4E40B56FEEAF1EDB4B4067800BB2653F4E40F6B704E09FB04B409A79724D81FC4D40F6B704E09FB04B40
7347	городской округ Златоуст	\N	58	59.093569000000002	60.093528999999997	55.448672999999999	54.613317000000002	0103000020E61000000100000005000000B075A911FA8B4D40598AE42B814E4B40B075A911FA8B4D4092CCEA1D6EB94B40211D1EC2F80B4E4092CCEA1D6EB94B40211D1EC2F80B4E40598AE42B814E4B40B075A911FA8B4D40598AE42B814E4B40
1659	городской округ Еманжелинск	\N	58	61.195303000000003	61.429431000000001	54.816240000000001	54.568823999999999	0103000020E61000000100000005000000C5E74EB0FF984E4007978E39CF484B40C5E74EB0FF984E40F1D7648D7A684B40BD715298F7B64E40F1D7648D7A684B40BD715298F7B64E4007978E39CF484B40C5E74EB0FF984E4007978E39CF484B40
1031	городской округ Верхний Уфалей	\N	58	60.173344	60.291553	56.082908000000003	56.001801	0103000020E610000001000000050000009A7ADD2230164E40D00CE2033B004C409A7ADD2230164E40D449B6BA9C0A4C407D06D49B51254E40D449B6BA9C0A4C407D06D49B51254E40D00CE2033B004C409A7ADD2230164E40D00CE2033B004C40
840	Чесменский район	\N	58	59.98415	61.234774999999999	53.954191999999999	53.371296000000001	0103000020E61000000100000005000000E02D90A0F8FD4D405C9198A086AF4A40E02D90A0F8FD4D406B0DA5F622FA4A408E75711B0D9E4E406B0DA5F622FA4A408E75711B0D9E4E405C9198A086AF4A40E02D90A0F8FD4D405C9198A086AF4A40
7348	Челябинский городской округ	\N	58	61.206910000000001	61.219172	55.024692999999999	55.012852000000002	0103000020E61000000100000005000000919BE1067C9A4E4017D86322A5814B40919BE1067C9A4E4056B8E52329834B407619FED30D9C4E4056B8E52329834B407619FED30D9C4E4017D86322A5814B40919BE1067C9A4E4017D86322A5814B40
812	Чебаркульский район	\N	58	59.879989999999999	60.992877	55.161485999999996	54.510406000000003	0103000020E610000001000000050000004D672783A3F04D4052D7DAFB54414B404D672783A3F04D408461C092AB944B40ADF9F197167F4E408461C092AB944B40ADF9F197167F4E4052D7DAFB54414B404D672783A3F04D4052D7DAFB54414B40
941	Уйский район	\N	58	59.648781999999997	60.619554999999998	54.670889000000003	54.073765999999999	0103000020E61000000100000005000000E21DE0490BD34D4043C70E2A71094B40E21DE0490BD34D40821FD5B0DF554B40618907944D4F4E40821FD5B0DF554B40618907944D4F4E4043C70E2A71094B40E21DE0490BD34D4043C70E2A71094B40
439	Увельский район	\N	58	60.842616	62.139243999999998	54.746727	54.248674999999999	0103000020E610000001000000050000000D8B51D7DA6B4E40992A1895D41F4B400D8B51D7DA6B4E40250516C0945F4B40051555BFD2114F40250516C0945F4B40051555BFD2114F40992A1895D41F4B400D8B51D7DA6B4E40992A1895D41F4B40
135	Троицкий район	\N	58	60.244202999999999	62.341921999999997	54.438099000000001	53.900713000000003	0103000020E61000000100000005000000E44A3D0B421F4E40810A47904AF34A40E44A3D0B421F4E4085B4C6A013384B4036E49F19C42B4F4085B4C6A013384B4036E49F19C42B4F40810A47904AF34A40E44A3D0B421F4E40810A47904AF34A40
56	Сосновский район	\N	58	60.86157	61.566882	55.641756999999998	54.92568	0103000020E610000001000000050000007C9BFEEC476E4E40D847A7AE7C764B407C9BFEEC476E4E40527DE71725D24B407558E1968FC84E40527DE71725D24B407558E1968FC84E40D847A7AE7C764B407C9BFEEC476E4E40D847A7AE7C764B40
1756	Саткинский район	\N	58	58.574683999999998	59.337299999999999	55.327198000000003	54.595841	0103000020E6100000010000000500000069C4CC3E8F494D40D74E9484444C4B4069C4CC3E8F494D4087A8C29FE1A94B406C787AA52CAB4D4087A8C29FE1A94B406C787AA52CAB4D40D74E9484444C4B4069C4CC3E8F494D40D74E9484444C4B40
6905	Саткинский муниципальный район	\N	58	58.574683999999998	59.337299999999999	55.327198000000003	54.595841	0103000020E6100000010000000500000069C4CC3E8F494D40D74E9484444C4B4069C4CC3E8F494D4087A8C29FE1A94B406C787AA52CAB4D4087A8C29FE1A94B406C787AA52CAB4D40D74E9484444C4B4069C4CC3E8F494D40D74E9484444C4B40
6933	Пластовский район	\N	58	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
1494	Октябрьский район	\N	58	62.119858000000001	63.351754	54.728774000000001	53.912919000000002	0103000020E61000000100000005000000FD14C781570F4F40D272A087DAF44A40FD14C781570F4F406A166877485D4B405C1E6B4606AD4F406A166877485D4B405C1E6B4606AD4F40D272A087DAF44A40FD14C781570F4F40D272A087DAF44A40
5668	Озерский район	\N	58	57.132026000000003	63.351762999999998	56.365558	51.990470000000002	0103000020E61000000100000005000000611C5C3AE6904C40A6D590B8C7FE4940611C5C3AE6904C404565C39ACA2E4C40AF78EA9106AD4F404565C39ACA2E4C40AF78EA9106AD4F40A6D590B8C7FE4940611C5C3AE6904C40A6D590B8C7FE4940
921	Нязепетровский район	\N	58	59.019098999999997	60.138292	56.355728999999997	55.580548	0103000020E61000000100000005000000723106D671824D400DE198654FCA4B40723106D671824D40909E2287882D4C4033A6608DB3114E40909E2287882D4C4033A6608DB3114E400DE198654FCA4B40723106D671824D400DE198654FCA4B40
1486	Нагайбакский район	\N	58	59.338538999999997	60.323892999999998	53.921860000000002	53.201666000000003	0103000020E61000000100000005000000D4B5F63E55AB4D408A5B0531D0994A40D4B5F63E55AB4D40CBBE2B82FFF54A40A033695375294E40CBBE2B82FFF54A40A033695375294E408A5B0531D0994A40D4B5F63E55AB4D408A5B0531D0994A40
1686	Кусинский район	\N	58	59.065694000000001	60.030458000000003	55.634664000000001	55.213258000000003	0103000020E610000001000000050000008FC536A968884D4021CEC3094C9B4B408FC536A968884D406AF981AB3CD14B4067F3380CE6034E406AF981AB3CD14B4067F3380CE6034E4021CEC3094C9B4B408FC536A968884D4021CEC3094C9B4B40
161	Кунашакский район	\N	58	60.923679999999997	62.242739	56.239848000000002	55.439450999999998	0103000020E6100000010000000500000011FC6F253B764E40E5982CEE3FB84B4011FC6F253B764E406901DA56B31E4C405C3B5112121F4F406901DA56B31E4C405C3B5112121F4F40E5982CEE3FB84B4011FC6F253B764E40E5982CEE3FB84B40
1449	Красноармейский район	\N	58	61.546024000000003	62.522033999999998	55.832135999999998	55.005181	0103000020E61000000100000005000000626A4B1DE4C54E40C1C760C5A9804B40626A4B1DE4C54E4081E9B46E83EA4B4035B39602D2424F4081E9B46E83EA4B4035B39602D2424F40C1C760C5A9804B40626A4B1DE4C54E40C1C760C5A9804B40
1732	Копейск городской округ	\N	58	61.491649000000002	61.754477999999999	55.258139999999997	54.928251000000003	0103000020E61000000100000005000000390EBC5AEEBE4E405ABDC3EDD0764B40390EBC5AEEBE4E400CE544BB0AA14B4097C62FBC92E04E400CE544BB0AA14B4097C62FBC92E04E405ABDC3EDD0764B40390EBC5AEEBE4E405ABDC3EDD0764B40
835	Кизильский район	\N	58	58.751202999999997	60.046968999999997	53.10866	52.276057000000002	0103000020E610000001000000050000001BD47E6B27604D407B6AF5D555234A401BD47E6B27604D4012312592E88D4A408176871403064E4012312592E88D4A408176871403064E407B6AF5D555234A401BD47E6B27604D407B6AF5D555234A40
954	Катав-Ивановский район	\N	58	57.548197000000002	59.022269999999999	54.992424999999997	54.397219	0103000020E61000000100000005000000F661BD512BC64C40C72C7B12D8324B40F661BD512BC64C40CC5D4BC8077F4B4049D74CBED9824D40CC5D4BC8077F4B4049D74CBED9824D40C72C7B12D8324B40F661BD512BC64C40C72C7B12D8324B40
1255	Каслинский район	\N	58	60.254021999999999	61.804648999999998	56.365558	55.668213999999999	0103000020E61000000100000005000000753BFBCA83204E405B5D4E0988D54B40753BFBCA83204E404565C39ACA2E4C402AE109BDFEE64E404565C39ACA2E4C402AE109BDFEE64E405B5D4E0988D54B40753BFBCA83204E405B5D4E0988D54B40
1235	Карталинский район	\N	58	59.711905999999999	61.070464000000001	53.445884999999997	52.698096999999997	0103000020E61000000100000005000000C0E95DBC1FDB4D40C537143E5B594A40C0E95DBC1FDB4D4073637AC212B94A40CEC5DFF604894E4073637AC212B94A40CEC5DFF604894E40C537143E5B594A40C0E95DBC1FDB4D40C537143E5B594A40
852	Еткульский район	\N	58	60.826410000000003	62.222428000000001	54.988261999999999	54.527484999999999	0103000020E610000001000000050000002F8B89CDC7694E40B610E4A084434B402F8B89CDC7694E4095F0845E7F7E4B407BDB4C85781C4F4095F0845E7F7E4B407BDB4C85781C4F40B610E4A084434B402F8B89CDC7694E40B610E4A084434B40
134	Верхнеуральский район	\N	58	58.814506999999999	60.358648000000002	54.187775000000002	53.515552	0103000020E6100000010000000500000079AEEFC341684D4096B1A19BFDC14A4079AEEFC341684D40D200DE0209184B404E637B2DE82D4E40D200DE0209184B404E637B2DE82D4E4096B1A19BFDC14A4079AEEFC341684D4096B1A19BFDC14A40
834	Варненский район	\N	58	60.563761	62.144534999999998	53.705607000000001	52.950099999999999	0103000020E6100000010000000500000050E1085229484E40FDF675E09C794A4050E1085229484E40126A865451DA4A404D10751F80124F40126A865451DA4A404D10751F80124F40FDF675E09C794A4050E1085229484E40FDF675E09C794A40
1076	Брединский район	\N	58	59.351466000000002	61.066467000000003	52.781281	51.990470000000002	0103000020E61000000100000005000000F6D37FD6FCAC4D40A6D590B8C7FE4940F6D37FD6FCAC4D403BFE0B0401644A40B2A19BFD81884E403BFE0B0401644A40B2A19BFD81884E40A6D590B8C7FE4940F6D37FD6FCAC4D40A6D590B8C7FE4940
946	Ашинский район	\N	58	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
339	Аргаяшский район	\N	58	60.195883000000002	61.314070000000001	55.731023999999998	55.113601000000003	0103000020E61000000100000005000000D36BB3B112194E407EE5417A8A8E4B40D36BB3B112194E40A94BC63192DD4B40CE531D7233A84E40A94BC63192DD4B40CE531D7233A84E407EE5417A8A8E4B40D36BB3B112194E407EE5417A8A8E4B40
935	Агаповский район	\N	58	58.872134000000003	59.791263000000001	53.682746000000002	52.989742999999997	0103000020E6100000010000000500000066DD3F16A26F4D40F3380CE6AF7E4A4066DD3F16A26F4D40C7BC8E3864D74A4076C4211B48E54D40C7BC8E3864D74A4076C4211B48E54D40F3380CE6AF7E4A4066DD3F16A26F4D40F3380CE6AF7E4A40
7349	 Ашинский район	\N	58	57.132026000000003	58.135613999999997	55.337685999999998	54.653896000000003	0103000020E61000000100000005000000611C5C3AE6904C401C7E37DDB2534B40611C5C3AE6904C4095287B4B39AB4B409B70AFCC5B114D4095287B4B39AB4B409B70AFCC5B114D401C7E37DDB2534B40611C5C3AE6904C401C7E37DDB2534B40
7345	городской округ Сургут	\N	59	73.356525000000005	73.489627999999996	61.302334000000002	61.239614000000003	0103000020E6100000010000000500000036CD3B4ED1565240F6D4EAABAB9E4E4036CD3B4ED1565240043C69E1B2A64E402DCDAD10565F5240043C69E1B2A64E402DCDAD10565F5240F6D4EAABAB9E4E4036CD3B4ED1565240F6D4EAABAB9E4E40
7343	Сургут	\N	59	73.194136	73.530788999999999	61.341909000000001	61.226702000000003	0103000020E610000001000000050000007BBE66B96C4C52400AF83592049D4E407BBE66B96C4C5240A29A92ACC3AB4E40E6046D72F8615240A29A92ACC3AB4E40E6046D72F86152400AF83592049D4E407BBE66B96C4C52400AF83592049D4E40
7548	Нягань	\N	59	\N	\N	\N	\N	\N
7530	городской округ Нижневартовск	\N	59	76.473642999999996	76.650638000000001	60.982616999999998	60.906668000000003	0103000020E61000000100000005000000ADBEBA2A501E5340352A70B20D744E40ADBEBA2A501E53402FBFD364C67D4E403BE2900DA42953402FBFD364C67D4E403BE2900DA4295340352A70B20D744E40ADBEBA2A501E5340352A70B20D744E40
7344	городской округ Нефтеюганск	\N	59	72.562072999999998	72.642418000000006	61.131489000000002	61.096054000000002	0103000020E61000000100000005000000BC3D0801F923524033535A7F4B8C4E40BC3D0801F92352405264ADA1D4904E40271763601D2952405264ADA1D4904E40271763601D29524033535A7F4B8C4E40BC3D0801F923524033535A7F4B8C4E40
1032	Ханты-Мансийский район	\N	59	67.998766000000003	71.0274	62.000501999999997	59.842097000000003	0103000020E61000000100000005000000D5963AC8EBFF5040A587A1D5C9EB4D40D5963AC8EBFF504092CA147310004F4044FAEDEBC0C1514092CA147310004F4044FAEDEBC0C15140A587A1D5C9EB4D40D5963AC8EBFF5040A587A1D5C9EB4D40
7549	Ханты-Мансийский автономный округ	\N	59	\N	\N	\N	\N	\N
676	Сургутский район	\N	59	70.221592999999999	76.674398999999994	62.000535999999997	58.664158999999998	0103000020E61000000100000005000000710168942E8E51400A2C802903554D40710168942E8E51403E3C4B9011004F40205D6C5A292B53403E3C4B9011004F40205D6C5A292B53400A2C802903554D40710168942E8E51400A2C802903554D40
7342	Советский район	\N	59	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
5247	Октябрьский район	\N	59	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
306	Нижневартовский район	\N	59	74.478898000000001	77.063674000000006	62.000548000000002	59.630099000000001	0103000020E61000000100000005000000AB07CC43A69E5240041F8315A7D04D40AB07CC43A69E5240030AF5F411004F40C1E61C3C13445340030AF5F411004F40C1E61C3C13445340041F8315A7D04D40AB07CC43A69E5240041F8315A7D04D40
768	Нефтеюганский район	\N	59	70.106195999999997	73.376692000000006	61.250798000000003	59.333699000000003	0103000020E61000000100000005000000D3BD4EEACB8651409DDA19A6B6AA4D40D3BD4EEACB8651407CF31B261AA04E408D2AC3B81B5852407CF31B261AA04E408D2AC3B81B5852409DDA19A6B6AA4D40D3BD4EEACB8651409DDA19A6B6AA4D40
138	Кондинский район	\N	59	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
7529	Кодинский район	\N	59	67.998838000000006	69.602699000000001	60.640999000000001	59.210298999999999	0103000020E61000000100000005000000220038F6ECFF5040D5B0DF13EB9A4D40220038F6ECFF504065E256410C524E403E95D39E9266514065E256410C524E403E95D39E92665140D5B0DF13EB9A4D40220038F6ECFF5040D5B0DF13EB9A4D40
7346	Березовский район	\N	59	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
7550	Березово	\N	59	\N	\N	\N	\N	\N
7524	Белоярский район	\N	59	67.998766000000003	77.072298000000004	62.000548000000002	58.664158999999998	0103000020E61000000100000005000000D5963AC8EBFF50400A2C802903554D40D5963AC8EBFF5040030AF5F411004F403D64CA87A0445340030AF5F411004F403D64CA87A04453400A2C802903554D40D5963AC8EBFF50400A2C802903554D40
1718	Ярковский район	\N	57	66.416697999999997	68.034097000000003	58.188496999999998	57.014595999999997	0103000020E61000000100000005000000C093162EAB9A504082531F48DE814C40C093162EAB9A5040723271AB20184D4012F92EA52E025140723271AB20184D4012F92EA52E02514082531F48DE814C40C093162EAB9A504082531F48DE814C40
1641	Ялуторовский район	\N	57	65.784895000000006	66.954897000000003	57.139995999999996	56.454697000000003	0103000020E61000000100000005000000D0F23CB83B7250406F4BE482333A4C40D0F23CB83B72504010C99063EB914C401B834E081DBD504010C99063EB914C401B834E081DBD50406F4BE482333A4C40D0F23CB83B7250406F4BE482333A4C40
1503	Юргинский район	\N	57	66.874093000000002	68.571190000000001	57.283096999999998	56.613999999999997	0103000020E61000000100000005000000672AC423F1B750403BDF4F8D974E4C40672AC423F1B75040404CC2853CA44C40587380608E245140404CC2853CA44C40587380608E2451403BDF4F8D974E4C40672AC423F1B750403BDF4F8D974E4C40
1508	Упоровский район	\N	57	65.649698000000001	67.073195999999996	56.492795999999998	55.958199999999998	0103000020E61000000100000005000000B491EBA6946950407B832F4CA6FA4B40B491EBA694695040C0CC77F0133F4C40AC8C463EAFC45040C0CC77F0133F4C40AC8C463EAFC450407B832F4CA6FA4B40B491EBA6946950407B832F4CA6FA4B40
1464	Уватский район	\N	57	67.662598000000003	75.195798999999994	59.989877	58.000736000000003	0103000020E610000001000000050000004819710168EA504006F7031E18004D404819710168EA504003081F4AB4FE4D40BA6587F887CC524003081F4AB4FE4D40BA6587F887CC524006F7031E18004D404819710168EA504006F7031E18004D40
624	Тюменский район	\N	57	64.827461	66.519699000000003	57.468797000000002	56.7605	0103000020E61000000100000005000000CA6DFB1EF5345040D34D621058614C40CA6DFB1EF534504041BB438A01BC4C40E43098BF42A1504041BB438A01BC4C40E43098BF42A15040D34D621058614C40CA6DFB1EF5345040D34D621058614C40
54	Тобольский район	\N	57	65.951209000000006	69.164698000000001	59.167698999999999	57.563696	0103000020E610000001000000050000004CAAB69BE07C50406971C63027C84C404CAAB69BE07C504034492C2977954D40DDED7A698A4A514034492C2977954D40DDED7A698A4A51406971C63027C84C404CAAB69BE07C50406971C63027C84C40
1774	Сорокинский район	\N	57	69.255697999999995	70.362395000000006	57.098894999999999	56.447499000000001	0103000020E61000000100000005000000C4E9245B5D50514011FFB0A547394C40C4E9245B5D505140745E6397A88C4C40F94ECC7A31975140745E6397A88C4C40F94ECC7A3197514011FFB0A547394C40C4E9245B5D50514011FFB0A547394C40
1780	Сладковский район	\N	57	69.586699999999993	70.827426000000003	55.969295000000002	55.147190999999999	0103000020E610000001000000050000000B24287E8C655140FDA19927D7924B400B24287E8C6551409296CADB11FC4B400C772E8CF4B451409296CADB11FC4B400C772E8CF4B45140FDA19927D7924B400B24287E8C655140FDA19927D7924B40
1779	Омутинский район	\N	57	67.105795999999998	68.047994000000003	56.776699999999998	56.074297999999999	0103000020E610000001000000050000000C03965CC5C650404014CC9882094C400C03965CC5C65040CF66D5E76A634C40DF196D5512035140CF66D5E76A634C40DF196D55120351404014CC9882094C400C03965CC5C650404014CC9882094C40
854	Нижнетавдинский район	\N	57	64.832617999999997	67.087496999999999	58.112495000000003	57.224097	0103000020E61000000100000005000000E603029D49355040DC10E335AF9C4C40E603029D4935504055FB743C660E4D40E15F048D99C5504055FB743C660E4D40E15F048D99C55040DC10E335AF9C4C40E603029D49355040DC10E335AF9C4C40
1799	Казанский район	\N	57	68.684197999999995	69.786592999999996	55.895197000000003	55.285989000000001	0103000020E61000000100000005000000457F68E6C92B514004029D499BA44B40457F68E6C92B5140193DB7D095F24B40CD902A8A57725140193DB7D095F24B40CD902A8A5772514004029D499BA44B40457F68E6C92B514004029D499BA44B40
657	Ишимский район	\N	57	68.587898999999993	70.068196999999998	56.645198000000001	55.809398000000002	0103000020E6100000010000000500000078962023A025514052B9895A9AE74B4078962023A0255140E9B81AD995524C40DC2BF3565D845140E9B81AD995524C40DC2BF3565D84514052B9895A9AE74B4078962023A025514052B9895A9AE74B40
1650	Исетский район	\N	57	64.928889999999996	66.008396000000005	56.846350999999999	56.272799999999997	0103000020E6100000010000000500000036E50AEF723B5040A52C431CEB224C4036E50AEF723B5040ECF7C43A556C4C40B45A608F89805040ECF7C43A556C4C40B45A608F89805040A52C431CEB224C4036E50AEF723B5040A52C431CEB224C40
1485	Заводоуковский район	\N	57	66.09599	67.314797999999996	56.967198000000003	56.158596000000003	0103000020E610000001000000050000008EAF3DB32486504062A3ACDF4C144C408EAF3DB324865040D960E124CD7B4C4028B682A625D45040D960E124CD7B4C4028B682A625D4504062A3ACDF4C144C408EAF3DB32486504062A3ACDF4C144C40
1435	Голышмановский район	\N	57	67.913991999999993	69.029700000000005	56.879899000000002	56.017195999999998	0103000020E610000001000000050000008F334DD87EFA50409ECF807A33024C408F334DD87EFA50403D64CA87A0704C403D2CD49AE64151403D64CA87A0704C403D2CD49AE64151409ECF807A33024C408F334DD87EFA50409ECF807A33024C40
1342	Викуловский район	\N	57	69.594397999999998	71.676433000000003	57.385063000000002	56.520499000000001	0103000020E61000000100000005000000B3B3E89D0A665140E44C13B69F424C40B3B3E89D0A66514028F38FBE49B14C40DA3BA3AD4AEB514028F38FBE49B14C40DA3BA3AD4AEB5140E44C13B69F424C40B3B3E89D0A665140E44C13B69F424C40
1123	Вагайский район	\N	57	67.777097999999995	70.865594999999999	58.674196000000002	57.062198000000002	0103000020E610000001000000050000005EF23FF9BBF1504035F0A31AF6874C405EF23FF9BBF15040098CF50D4C564D40312592E865B75140098CF50D4C564D40312592E865B7514035F0A31AF6874C405EF23FF9BBF1504035F0A31AF6874C40
1146	Бердюжский район	\N	57	67.996296000000001	69.019396	56.084400000000002	55.356774000000001	0103000020E61000000100000005000000AE484C50C3FF504014083BC5AAAD4B40AE484C50C3FF504026E4839ECD0A4C40166BB8C83D41514026E4839ECD0A4C40166BB8C83D41514014083BC5AAAD4B40AE484C50C3FF504014083BC5AAAD4B40
1065	Аромашевский район	\N	57	68.279794999999993	69.559291999999999	57.216299999999997	56.622399999999999	0103000020E6100000010000000500000065A54929E8115140E4839ECDAA4F4C4065A54929E8115140F90FE9B7AF9B4C40863AAC70CB635140F90FE9B7AF9B4C40863AAC70CB635140E4839ECDAA4F4C4065A54929E8115140E4839ECDAA4F4C40
979	Армизонский район	\N	57	66.987002000000004	68.173694999999995	56.279696999999999	55.655143000000002	0103000020E610000001000000050000008BC56F0A2BBF5040079ACFB9DBD34B408BC56F0A2BBF504008E57D1CCD234C40A31EA2D11D0B514008E57D1CCD234C40A31EA2D11D0B5140079ACFB9DBD34B408BC56F0A2BBF5040079ACFB9DBD34B40
784	Абатский район	\N	57	69.870900000000006	71.261590999999996	56.645138000000003	55.874996000000003	0103000020E6100000010000000500000088855AD3BC775140BF1072DEFFEF4B4088855AD3BC77514014B4C9E193524C40637B2DE8BDD0514014B4C9E193524C40637B2DE8BDD05140BF1072DEFFEF4B4088855AD3BC775140BF1072DEFFEF4B40
1359	городской округ Кушва	\N	56	58.909342000000002	59.955995999999999	58.548937000000002	57.964052000000002	0103000020E610000001000000050000008B70935165744D405BD2510E66FB4C408B70935165744D403D484F9143464D40AC8DB1135EFA4D403D484F9143464D40AC8DB1135EFA4D405BD2510E66FB4C408B70935165744D405BD2510E66FB4C40
383	городской округ Краснотурьинск	\N	56	60.018608999999998	60.459808000000002	59.973478	59.514383000000002	0103000020E61000000100000005000000A4349BC761024E40274F594DD7C14D40A4349BC761024E4010B056ED9AFC4D40373811FDDA3A4E4010B056ED9AFC4D40373811FDDA3A4E40274F594DD7C14D40A4349BC761024E40274F594DD7C14D40
1323	городской округ Кировград	\N	56	59.643383	60.255153	57.660268000000002	57.193868999999999	0103000020E61000000100000005000000B4E6C75F5AD24D40A75A0BB3D0984C40B4E6C75F5AD24D40344C6DA983D44C40F73C7FDAA8204E40344C6DA983D44C40F73C7FDAA8204E40A75A0BB3D0984C40B4E6C75F5AD24D40A75A0BB3D0984C40
6985	городской округ Ирбит	\N	56	63.020887000000002	63.082861000000001	57.687851000000002	57.654625000000003	0103000020E61000000100000005000000AEF4DA6CAC824F406F1283C0CAD34C40AEF4DA6CAC824F40ADC266800BD84C40938E72309B8A4F40ADC266800BD84C40938E72309B8A4F406F1283C0CAD34C40AEF4DA6CAC824F406F1283C0CAD34C40
6986	городской округ Североуральск	\N	56	59.105867000000003	60.272114000000002	60.697763000000002	59.962060999999999	0103000020E61000000100000005000000E25CC30C8D8D4D40E7E099D024FB4D40E25CC30C8D8D4D40EFAD484C50594E405264ADA1D4224E40EFAD484C50594E405264ADA1D4224E40E7E099D024FB4D40E25CC30C8D8D4D40E7E099D024FB4D40
1336	городской округ Ревда	\N	56	59.619622	60.311351999999999	56.875363999999998	56.305469000000002	0103000020E61000000100000005000000E9F010C64FCF4D408E78B29B19274C40E9F010C64FCF4D40410C74ED0B704C40A8C5E061DA274E40410C74ED0B704C40A8C5E061DA274E408E78B29B19274C40E9F010C64FCF4D408E78B29B19274C40
7000	городской округ Полевской	\N	56	59.635899999999999	60.567686000000002	56.676884000000001	56.200293000000002	0103000020E6100000010000000500000061C3D32B65D14D40124F7633A3194C4061C3D32B65D14D40C4978922A4564C40D33252EFA9484E40C4978922A4564C40D33252EFA9484E40124F7633A3194C4061C3D32B65D14D40124F7633A3194C40
6987	городской округ Первоуральск	\N	56	59.227283	60.332427000000003	57.325163000000003	56.740862	0103000020E61000000100000005000000E8F7FD9B179D4D40B16CE690D45E4C40E8F7FD9B179D4D40446FF1F09EA94C4059A7CAF78C2A4E40446FF1F09EA94C4059A7CAF78C2A4E40B16CE690D45E4C40E8F7FD9B179D4D40B16CE690D45E4C40
728	городской округ Нижняя Тура	\N	56	60.094095000000003	60.111314999999998	58.669096000000003	58.661251999999998	0103000020E61000000100000005000000CBDB114E0B0C4E401135D1E7A3544D40CBDB114E0B0C4E4035F10EF0A4554D40F146E6913F0E4E4035F10EF0A4554D40F146E6913F0E4E401135D1E7A3544D40CBDB114E0B0C4E401135D1E7A3544D40
6965	городской округ Красноуфимск	\N	56	57.719909999999999	57.797623000000002	56.641703	56.575166000000003	0103000020E610000001000000050000001C08C90226DC4C40B5E21B0A9F494C401C08C90226DC4C405F5FEB5223524C40CAC4AD8218E64C405F5FEB5223524C40CAC4AD8218E64C40B5E21B0A9F494C401C08C90226DC4C40B5E21B0A9F494C40
6994	городской округ Красноуральск	\N	56	59.855348999999997	60.760150000000003	58.539672000000003	58.108682000000002	0103000020E6100000010000000500000049D576137CED4D40FAD4B14AE90D4D4049D576137CED4D409148DBF813454D40F7065F984C614E409148DBF813454D40F7065F984C614E40FAD4B14AE90D4D4049D576137CED4D40FAD4B14AE90D4D40
7002	городской округ Качканар	\N	56	59.246327000000001	59.650039	58.825755000000001	58.543653999999997	0103000020E61000000100000005000000978FA4A4879F4D40772B4B7496454D40978FA4A4879F4D4016C1FF56B2694D40F10F5B7A34D34D4016C1FF56B2694D40F10F5B7A34D34D40772B4B7496454D40978FA4A4879F4D40772B4B7496454D40
1537	городской округ Карпинск	\N	56	58.366624999999999	60.383451000000001	60.182380999999999	59.207729	0103000020E61000000100000005000000B0726891ED2E4D4024B726DD969A4D40B0726891ED2E4D40B534B74258174E402B4F20EC14314E40B534B74258174E402B4F20EC14314E4024B726DD969A4D40B0726891ED2E4D4024B726DD969A4D40
1596	городской округ Каменск-Уральский	\N	56	61.075018999999998	62.401910999999998	56.686262999999997	56.131089000000003	0103000020E6100000010000000500000010CAFB389A894E40C4EE3B86C7104C4010CAFB389A894E4038BA4A77D7574C408A73D4D171334F4038BA4A77D7574C408A73D4D171334F40C4EE3B86C7104C4010CAFB389A894E40C4EE3B86C7104C40
1444	городской округ Ивдель	\N	56	59.251294999999999	63.155597999999998	61.946418000000001	60.083494999999999	0103000020E61000000100000005000000FC523F6F2AA04D409430D3F6AF0A4E40FC523F6F2AA04D40412C9B3924F94E4058A9A0A2EA934F40412C9B3924F94E4058A9A0A2EA934F409430D3F6AF0A4E40FC523F6F2AA04D409430D3F6AF0A4E40
964	городской округ Екатеринбург	\N	56	60.012222000000001	60.943604000000001	56.962198000000001	56.604092000000001	0103000020E610000001000000050000005725917D90014E403BE3FBE2524D4C405725917D90014E406823D74D297B4C40F92F1004C8784E406823D74D297B4C40F92F1004C8784E403BE3FBE2524D4C405725917D90014E403BE3FBE2524D4C40
312	городской округ Верхняя Пышма	\N	56	60.263364000000003	60.937396999999997	57.326203	56.913789999999999	0103000020E61000000100000005000000CD785BE9B5214E40B7B41A12F7744C40CD785BE9B5214E40B56D1805C1A94C402B2FF99FFC774E40B56D1805C1A94C402B2FF99FFC774E40B7B41A12F7744C40CD785BE9B5214E40B7B41A12F7744C40
136	городской округ Березовский	\N	56	60.663195000000002	61.317492000000001	57.211499000000003	56.826498000000001	0103000020E6100000010000000500000074EFE192E3544E40CE1ABCAFCA694C4074EFE192E3544E4080113466129B4C40EE5EEE93A3A84E4080113466129B4C40EE5EEE93A3A84E40CE1ABCAFCA694C4074EFE192E3544E40CE1ABCAFCA694C40
1393	городской округ Асбест	\N	56	61.258194000000003	61.736097999999998	57.242798000000001	56.897153000000003	0103000020E61000000100000005000000000341800CA14E401041D5E8D5724C40000341800CA14E4061C43E01149F4C405453927538DE4E4061C43E01149F4C405453927538DE4E401041D5E8D5724C40000341800CA14E401041D5E8D5724C40
825	городской округ Алапаевск	\N	56	61.013097999999999	61.889800000000001	57.945298999999999	57.614798	0103000020E610000001000000050000004ED2FC31AD814E40B7D26BB3B1CE4C404ED2FC31AD814E4083F8C08EFFF84C408BFD65F7E4F14E4083F8C08EFFF84C408BFD65F7E4F14E40B7D26BB3B1CE4C404ED2FC31AD814E40B7D26BB3B1CE4C40
457	Шалинский район	\N	56	57.940140999999997	59.742241999999997	57.696134000000001	57.011547999999998	0103000020E610000001000000050000007A50508A56F84C40C72AA5677A814C407A50508A56F84C401CD13DEB1AD94C40DBDB2DC901DF4D401CD13DEB1AD94C40DBDB2DC901DF4D40C72AA5677A814C407A50508A56F84C40C72AA5677A814C40
7043	Шалинский 	\N	56	57.940140999999997	59.742241999999997	57.696134000000001	57.011547999999998	0103000020E610000001000000050000007A50508A56F84C40C72AA5677A814C407A50508A56F84C401CD13DEB1AD94C40DBDB2DC901DF4D401CD13DEB1AD94C40DBDB2DC901DF4D40C72AA5677A814C407A50508A56F84C40C72AA5677A814C40
7041	Шалинский	\N	56	57.940140999999997	59.742241999999997	57.696134000000001	57.011547999999998	0103000020E610000001000000050000007A50508A56F84C40C72AA5677A814C407A50508A56F84C401CD13DEB1AD94C40DBDB2DC901DF4D401CD13DEB1AD94C40DBDB2DC901DF4D40C72AA5677A814C407A50508A56F84C40C72AA5677A814C40
2	Туринский район	\N	56	62.633299000000001	64.565997999999993	58.734399000000003	57.749594999999999	0103000020E6100000010000000500000075CB0EF10F514F40601F9DBAF2DF4C4075CB0EF10F514F40899B53C9005E4D407DE6AC4F39245040899B53C9005E4D407DE6AC4F39245040601F9DBAF2DF4C4075CB0EF10F514F40601F9DBAF2DF4C40
1628	Тугулымский район	\N	56	64.070989999999995	65.237290999999999	57.397596999999998	56.734499	0103000020E61000000100000005000000F415A4198B045040ECF82F10045E4C40F415A4198B0450406DFE5F75E4B24C40A62897C62F4F50406DFE5F75E4B24C40A62897C62F4F5040ECF82F10045E4C40F415A4198B045040ECF82F10045E4C40
7042	Тугулымский р	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
7061	Тугулымский 	\N	56	64.070989999999995	65.237290999999999	57.397596999999998	56.734499	0103000020E61000000100000005000000F415A4198B045040ECF82F10045E4C40F415A4198B0450406DFE5F75E4B24C40A62897C62F4F50406DFE5F75E4B24C40A62897C62F4F5040ECF82F10045E4C40F415A4198B045040ECF82F10045E4C40
1634	Талицкий район	\N	56	62.910393999999997	64.346440999999999	57.328899999999997	56.463898	0103000020E61000000100000005000000C03C64CA87744F4004577902613B4C40C03C64CA87744F40C3D32B6519AA4C40963FDF162C165040C3D32B6519AA4C40963FDF162C16504004577902613B4C40C03C64CA87744F4004577902613B4C40
7060	Талицкий	\N	56	62.910393999999997	64.346440999999999	57.328899999999997	56.463898	0103000020E61000000100000005000000C03C64CA87744F4004577902613B4C40C03C64CA87744F40C3D32B6519AA4C40963FDF162C165040C3D32B6519AA4C40963FDF162C16504004577902613B4C40C03C64CA87744F4004577902613B4C40
1573	Тавдинский район	\N	56	64.565997999999993	66.183136000000005	58.649099	57.668298	0103000020E610000001000000050000007DE6AC4F39245040B9FDF2C98AD54C407DE6AC4F39245040E36E10AD15534D4019AE0E80B88B5040E36E10AD15534D4019AE0E80B88B5040B9FDF2C98AD54C407DE6AC4F39245040B9FDF2C98AD54C40
7049	Тавдинский 	\N	56	64.565997999999993	66.183136000000005	58.649099	57.668298	0103000020E610000001000000050000007DE6AC4F39245040B9FDF2C98AD54C407DE6AC4F39245040E36E10AD15534D4019AE0E80B88B5040E36E10AD15534D4019AE0E80B88B5040B9FDF2C98AD54C407DE6AC4F39245040B9FDF2C98AD54C40
897	Таборинский район	\N	56	63.206901000000002	65.665194	59.378796000000001	58.153396999999998	0103000020E610000001000000050000003E4162BB7B9A4F40FA264D83A2134D403E4162BB7B9A4F4085ED27637CB04D40B5DFDA89926A504085ED27637CB04D40B5DFDA89926A5040FA264D83A2134D403E4162BB7B9A4F40FA264D83A2134D40
611	Сысертский район	\N	56	60.415503000000001	61.183777999999997	56.744504999999997	56.181750000000001	0103000020E61000000100000005000000E831CA332F354E402506819543174C40E831CA332F354E40AF5A99F04B5F4C40B5DC990986974E40AF5A99F04B5F4C40B5DC990986974E402506819543174C40E831CA332F354E402506819543174C40
1189	Сухоложский район	\N	56	61.621886000000003	62.469096	57.217396000000001	56.766105000000003	0103000020E610000001000000050000008EEBDFF599CF4E40AB2688BA0F624C408EEBDFF599CF4E40FF23D3A1D39B4C409B5775560B3C4F40FF23D3A1D39B4C409B5775560B3C4F40AB2688BA0F624C408EEBDFF599CF4E40AB2688BA0F624C40
7022	Сосьвинский район	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
7001	Сосьвинский городской округ	\N	56	59.194682999999998	59.201169	60.182453000000002	60.168508000000003	0103000020E61000000100000005000000280B5F5FEB984D40A48E8EAB91154E40280B5F5FEB984D404F07B29E5A174E4009FCE1E7BF994D404F07B29E5A174E4009FCE1E7BF994D40A48E8EAB91154E40280B5F5FEB984D40A48E8EAB91154E40
1580	Слободо-Туринский район	\N	56	63.871699	64.979698999999997	57.893597	57.316099999999999	0103000020E610000001000000050000005B7A34D593EF4F40FF21FDF675A84C405B7A34D593EF4F40E066F16261F24C40213B6F63B33E5040E066F16261F24C40213B6F63B33E5040FF21FDF675A84C405B7A34D593EF4F40FF21FDF675A84C40
7036	Слободо-Туринский	\N	56	63.871699	64.979698999999997	57.893597	57.316099999999999	0103000020E610000001000000050000005B7A34D593EF4F40FF21FDF675A84C405B7A34D593EF4F40E066F16261F24C40213B6F63B33E5040E066F16261F24C40213B6F63B33E5040FF21FDF675A84C405B7A34D593EF4F40FF21FDF675A84C40
1490	Серовский район	\N	56	60.184187000000001	62.570794999999997	60.235996999999998	58.553196	0103000020E6100000010000000500000097AC8A7093174E4096236420CF464D4097AC8A7093174E40207A5226351E4E4033DC80CF0F494F40207A5226351E4E4033DC80CF0F494F4096236420CF464D4097AC8A7093174E4096236420CF464D40
7046	Серовский	\N	56	60.184187000000001	62.570794999999997	60.235996999999998	58.553196	0103000020E6100000010000000500000097AC8A7093174E4096236420CF464D4097AC8A7093174E40207A5226351E4E4033DC80CF0F494F40207A5226351E4E4033DC80CF0F494F4096236420CF464D4097AC8A7093174E4096236420CF464D40
1347	Режевский район	\N	56	60.603718000000001	61.677796999999998	57.707098999999999	57.166198000000001	0103000020E61000000100000005000000D600A5A1464D4E408F54DFF945954C40D600A5A1464D4E406404543882DA4C40D829560DC2D64E406404543882DA4C40D829560DC2D64E408F54DFF945954C40D600A5A1464D4E408F54DFF945954C40
7058	Реж	\N	56	61.316836000000002	61.494532	57.391733000000002	57.310160000000003	0103000020E61000000100000005000000051901158EA84E408143A852B3A74C40051901158EA84E40CAE1934E24B24C40A96917D34CBF4E40CAE1934E24B24C40A96917D34CBF4E408143A852B3A74C40051901158EA84E408143A852B3A74C40
1142	Пышминский район	\N	56	62.849379999999996	63.525694999999999	57.243198	56.494942000000002	0103000020E6100000010000000500000030F0DC7BB86C4F405BB56B425A3F4C4030F0DC7BB86C4F40EF39B01C219F4C40DA5548F949C34F40EF39B01C219F4C40DA5548F949C34F405BB56B425A3F4C4030F0DC7BB86C4F405BB56B425A3F4C40
340	Пригородный район	\N	56	58.589210000000001	61.237695000000002	58.245139000000002	57.307763000000001	0103000020E61000000100000005000000F33CB83B6B4B4D409DF529C764A74C40F33CB83B6B4B4D40B1FCF9B6601F4D401CB62DCA6C9E4E40B1FCF9B6601F4D401CB62DCA6C9E4E409DF529C764A74C40F33CB83B6B4B4D409DF529C764A74C40
7053	Пригородный 	\N	56	58.589210000000001	61.237695000000002	58.245139000000002	57.307763000000001	0103000020E61000000100000005000000F33CB83B6B4B4D409DF529C764A74C40F33CB83B6B4B4D40B1FCF9B6601F4D401CB62DCA6C9E4E40B1FCF9B6601F4D401CB62DCA6C9E4E409DF529C764A74C40F33CB83B6B4B4D409DF529C764A74C40
7031	Полевской	\N	56	60.14705	60.277341999999997	56.514752999999999	56.416311	0103000020E610000001000000050000003B70CE88D2124E4087FBC8AD49354C403B70CE88D2124E404A42226DE3414C4053E751F17F234E404A42226DE3414C4053E751F17F234E4087FBC8AD49354C403B70CE88D2124E4087FBC8AD49354C40
7016	Первоуральск	\N	56	59.863757	60.054901000000001	56.933847	56.853822999999998	0103000020E610000001000000050000007558E1968FEE4D404BC972124A6D4C407558E1968FEE4D40DE3B6A4C88774C4044C2F7FE06074E40DE3B6A4C88774C4044C2F7FE06074E404BC972124A6D4C407558E1968FEE4D404BC972124A6D4C40
781	Новолялинский район	\N	56	58.998716000000002	61.112217999999999	59.658554000000002	58.800483	0103000020E61000000100000005000000F8FE06EDD57F4D408200193A76664D40F8FE06EDD57F4D4033535A7F4BD44D40E202D0285D8E4E4033535A7F4BD44D40E202D0285D8E4E408200193A76664D40F8FE06EDD57F4D408200193A76664D40
7034	Нижняя Тура	\N	56	59.800210999999997	59.905583	58.642014000000003	58.582036000000002	0103000020E61000000100000005000000217365506DE64D401E8CD827804A4D40217365506DE64D407EC9C6832D524D402368CC24EAF34D407EC9C6832D524D402368CC24EAF34D401E8CD827804A4D40217365506DE64D401E8CD827804A4D40
7531	Нижнетуринский городской округ	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
6988	Нижнетуринский	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
1	Нижнесергинский район	\N	56	58.429561	59.815437000000003	57.098337999999998	56.190666999999998	0103000020E610000001000000050000008B51D7DAFB364D4095B6B8C667184C408B51D7DAFB364D401EFAEE56968C4C406479573D60E84D401EFAEE56968C4C406479573D60E84D4095B6B8C667184C408B51D7DAFB364D4095B6B8C667184C40
7059	Нижнесергинский 	\N	56	58.429561	59.815437000000003	57.098337999999998	56.190666999999998	0103000020E610000001000000050000008B51D7DAFB364D4095B6B8C667184C408B51D7DAFB364D401EFAEE56968C4C406479573D60E84D401EFAEE56968C4C406479573D60E84D4095B6B8C667184C408B51D7DAFB364D4095B6B8C667184C40
1035	Невьянский район	\N	56	59.758637	60.858435	57.708080000000002	56.988782	0103000020E610000001000000050000008D4468041BE14D40CE6F9868907E4C408D4468041BE14D40D1798D5DA2DA4C40F25EB532E16D4E40D1798D5DA2DA4C40F25EB532E16D4E40CE6F9868907E4C408D4468041BE14D40CE6F9868907E4C40
7048	Невьянский 	\N	56	60.157327000000002	60.160615	57.118403000000001	57.116799999999998	0103000020E610000001000000050000008FE3874A23144E401E166A4DF38E4C408FE3874A23144E40C85F5AD4278F4C409F1F46088F144E40C85F5AD4278F4C409F1F46088F144E401E166A4DF38E4C408FE3874A23144E401E166A4DF38E4C40
932	Красноуфимский район	\N	56	57.226942000000001	58.182730999999997	56.956859000000001	56.086565	0103000020E610000001000000050000005F0B7A6F0C9D4C4037FDD98F140B4C405F0B7A6F0C9D4C400FF10F5B7A7A4C40917BBABA63174D400FF10F5B7A7A4C40917BBABA63174D4037FDD98F140B4C405F0B7A6F0C9D4C4037FDD98F140B4C40
7066	Красноуфимский	\N	56	57.226942000000001	58.182730999999997	56.956859000000001	56.086565	0103000020E610000001000000050000005F0B7A6F0C9D4C4037FDD98F140B4C405F0B7A6F0C9D4C400FF10F5B7A7A4C40917BBABA63174D400FF10F5B7A7A4C40917BBABA63174D4037FDD98F140B4C405F0B7A6F0C9D4C4037FDD98F140B4C40
7023	Краснотурьинск	\N	56	60.128337999999999	60.280396000000003	59.794142999999998	59.729830999999997	0103000020E61000000100000005000000C26A2C616D104E40B14D2A1A6BDD4D40C26A2C616D104E4075AC527AA6E54D40F1F62004E4234E4075AC527AA6E54D40F1F62004E4234E40B14D2A1A6BDD4D40C26A2C616D104E40B14D2A1A6BDD4D40
3951	Красногорский район	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
7015	Качканарский городской округ	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
1800	Камышловский район	\N	56	62.301110999999999	63.070734000000002	57.222566999999998	56.491056	0103000020E61000000100000005000000A1BB24CE8A264F4096404AECDA3E4C40A1BB24CE8A264F409C1551137D9C4C408E5BCCCF0D894F409C1551137D9C4C408E5BCCCF0D894F4096404AECDA3E4C40A1BB24CE8A264F4096404AECDA3E4C40
5880	Каменский район	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
1492	Ирбитский район	\N	56	62.141894000000001	63.632496000000003	58.037197999999997	57.134838000000002	0103000020E61000000100000005000000D3BF249529124F400821205F42914C40D3BF249529124F4001BD70E7C2044D40E86C01A1F5D04F4001BD70E7C2044D40E86C01A1F5D04F400821205F42914C40D3BF249529124F400821205F42914C40
7039	Ирбитский 	\N	56	62.141894000000001	63.632496000000003	58.037197999999997	57.134838000000002	0103000020E61000000100000005000000D3BF249529124F400821205F42914C40D3BF249529124F4001BD70E7C2044D40E86C01A1F5D04F4001BD70E7C2044D40E86C01A1F5D04F400821205F42914C40D3BF249529124F400821205F42914C40
7069	Ирбитский	\N	56	62.141894000000001	63.632496000000003	58.037197999999997	57.134838000000002	0103000020E61000000100000005000000D3BF249529124F400821205F42914C40D3BF249529124F4001BD70E7C2044D40E86C01A1F5D04F4001BD70E7C2044D40E86C01A1F5D04F400821205F42914C40D3BF249529124F400821205F42914C40
7014	Екатеринбург	\N	56	60.440745	60.848166999999997	56.945303000000003	56.725827000000002	0103000020E61000000100000005000000117008556A384E40E3C62DE6E75C4C40117008556A384E40C5E74EB0FF784C40F1457BBC906C4E40C5E74EB0FF784C40F1457BBC906C4E40E3C62DE6E75C4C40117008556A384E40E3C62DE6E75C4C40
1483	Гаринский район	\N	56	61.340947	64.063695999999993	60.500276999999997	58.895398999999998	0103000020E61000000100000005000000AC55BB26A4AB4E4080EF366F9C724D40AC55BB26A4AB4E4072F8A41309404E40B43863981304504072F8A41309404E40B43863981304504080EF366F9C724D40AC55BB26A4AB4E4080EF366F9C724D40
1364	Верхотурский район	\N	56	59.965167999999998	62.408774999999999	59.081136999999998	58.369428999999997	0103000020E61000000100000005000000A79201A08AFB4D40D4981073492F4D40A79201A08AFB4D406EBF7CB2628A4D4011363CBD52344F406EBF7CB2628A4D4011363CBD52344F40D4981073492F4D40A79201A08AFB4D40D4981073492F4D40
7024	Верхняя Пышма	\N	56	60.528933000000002	60.626885000000001	56.990312000000003	56.941253000000003	0103000020E6100000010000000500000039639813B4434E40862172FA7A784C4039639813B4434E400E6B2A8BC27E4C402EAD86C43D504E400E6B2A8BC27E4C402EAD86C43D504E40862172FA7A784C4039639813B4434E40862172FA7A784C40
743	Верхнесалдинский район	\N	56	60.328681000000003	61.274427000000003	58.479903	57.855393999999997	0103000020E6100000010000000500000086E81038122A4E40E998F38C7DED4C4086E81038122A4E404B2025766D3D4D40D811876C20A34E404B2025766D3D4D40D811876C20A34E40E998F38C7DED4C4086E81038122A4E40E998F38C7DED4C40
7068	Верхнесалдинский	\N	56	60.328681000000003	61.274427000000003	58.479903	57.855393999999997	0103000020E6100000010000000500000086E81038122A4E40E998F38C7DED4C4086E81038122A4E404B2025766D3D4D40D811876C20A34E404B2025766D3D4D40D811876C20A34E40E998F38C7DED4C4086E81038122A4E40E998F38C7DED4C40
1197	Богдановичский район	\N	56	61.575344999999999	62.587045000000003	56.897153000000003	56.480510000000002	0103000020E610000001000000050000006475ABE7A4C94E4053B3075A813D4C406475ABE7A4C94E401041D5E8D5724C40E223624A244B4F401041D5E8D5724C40E223624A244B4F4053B3075A813D4C406475ABE7A4C94E4053B3075A813D4C40
7038	Богдановичский	\N	56	61.575344999999999	62.587045000000003	56.897153000000003	56.480510000000002	0103000020E610000001000000050000006475ABE7A4C94E4053B3075A813D4C406475ABE7A4C94E401041D5E8D5724C40E223624A244B4F401041D5E8D5724C40E223624A244B4F4053B3075A813D4C406475ABE7A4C94E4053B3075A813D4C40
7021	Березовский	\N	56	60.716726000000001	60.849290000000003	56.944870999999999	56.850091999999997	0103000020E61000000100000005000000B11875ADBD5B4E40AD4B8DD0CF6C4C40B11875ADBD5B4E402BF86D88F1784C40F168E388B56C4E402BF86D88F1784C40F168E388B56C4E40AD4B8DD0CF6C4C40B11875ADBD5B4E40AD4B8DD0CF6C4C40
920	Белоярский район	\N	56	60.858471000000002	61.741982	56.946765999999997	56.455024999999999	0103000020E610000001000000050000003FC8B260E26D4E4063EE5A423E3A4C403FC8B260E26D4E407C7BD7A02F794C403F1C2444F9DE4E407C7BD7A02F794C403F1C2444F9DE4E4063EE5A423E3A4C403FC8B260E26D4E4063EE5A423E3A4C40
836	Байкаловский район	\N	56	62.936193000000003	64.174897999999999	57.801999000000002	57.236296000000003	0103000020E6100000010000000500000040DF162CD5774F407B1684F23E9E4C4040DF162CD5774F405D363AE7A7E64C40B1886187310B50405D363AE7A7E64C40B1886187310B50407B1684F23E9E4C4040DF162CD5774F407B1684F23E9E4C40
734	Ачитский район	\N	56	57.571058999999998	58.565125999999999	57.095027999999999	56.549030999999999	0103000020E61000000100000005000000118B187618C94C40BEBED6A546464C40118B187618C94C40261AA4E0298C4C40450F7C0C56484D40261AA4E0298C4C40450F7C0C56484D40BEBED6A546464C40118B187618C94C40BEBED6A546464C40
7037	Ачитский 	\N	56	57.571058999999998	58.565125999999999	57.095027999999999	56.549030999999999	0103000020E61000000100000005000000118B187618C94C40BEBED6A546464C40118B187618C94C40261AA4E0298C4C40450F7C0C56484D40261AA4E0298C4C40450F7C0C56484D40BEBED6A546464C40118B187618C94C40BEBED6A546464C40
7054	Ачитский	\N	56	57.571058999999998	58.565125999999999	57.095027999999999	56.549030999999999	0103000020E61000000100000005000000118B187618C94C40BEBED6A546464C40118B187618C94C40261AA4E0298C4C40450F7C0C56484D40261AA4E0298C4C40450F7C0C56484D40BEBED6A546464C40118B187618C94C40BEBED6A546464C40
7032	Асбест	\N	56	61.411724999999997	61.540193000000002	57.086181000000003	56.953118000000003	0103000020E6100000010000000500000009F9A067B3B44E404E9D47C5FF794C4009F9A067B3B44E40AF44A0FA078B4C409A43520B25C54E40AF44A0FA078B4C409A43520B25C54E404E9D47C5FF794C4009F9A067B3B44E404E9D47C5FF794C40
446	Артинский район	\N	56	57.987580999999999	59.043111000000003	56.698734999999999	56.052326000000001	0103000020E610000001000000050000005393E00D69FE4C40815D4D9EB2064C405393E00D69FE4C4008C9022670594C40878C47A984854D4008C9022670594C40878C47A984854D40815D4D9EB2064C405393E00D69FE4C40815D4D9EB2064C40
7050	Артинский	\N	56	57.987580999999999	59.043111000000003	56.698734999999999	56.052326000000001	0103000020E610000001000000050000005393E00D69FE4C40815D4D9EB2064C405393E00D69FE4C4008C9022670594C40878C47A984854D4008C9022670594C40878C47A984854D40815D4D9EB2064C405393E00D69FE4C40815D4D9EB2064C40
11	Артемовский район	\N	56	61.518894000000003	62.517093000000003	57.648899	57.158096	0103000020E610000001000000050000009A0B5C1E6BC24E4070D05E7D3C944C409A0B5C1E6BC24E401CB4571F0FD34C40CAFE791A30424F401CB4571F0FD34C40CAFE791A30424F4070D05E7D3C944C409A0B5C1E6BC24E4070D05E7D3C944C40
7020	Артемовский городской округ	\N	56	61.853158000000001	61.946384999999999	57.385629999999999	57.291710999999999	0103000020E610000001000000050000000F29064834ED4E4015713AC956A54C400F29064834ED4E40A12DE7525CB14C406536C82423F94E40A12DE7525CB14C406536C82423F94E4015713AC956A54C400F29064834ED4E4015713AC956A54C40
7067	Артемовский	\N	56	61.842063000000003	61.940052000000001	57.384732999999997	57.288252999999997	0103000020E61000000100000005000000F9156BB8C8EB4E40A8FC6B79E5A44C40F9156BB8C8EB4E40925852EE3EB14C400B45BA9F53F84E40925852EE3EB14C400B45BA9F53F84E40A8FC6B79E5A44C40F9156BB8C8EB4E40A8FC6B79E5A44C40
481	Алапаевский район	\N	56	60.902273000000001	63.221094000000001	59.101098	57.507396999999997	0103000020E610000001000000050000002B8881AE7D734E40548B8862F2C04C402B8881AE7D734E4073D87DC7F08C4D40C1ABE5CE4C9C4F4073D87DC7F08C4D40C1ABE5CE4C9C4F40548B8862F2C04C402B8881AE7D734E40548B8862F2C04C40
7035	Алапаевский 	\N	56	60.902273000000001	63.221094000000001	59.101098	57.507396999999997	0103000020E610000001000000050000002B8881AE7D734E40548B8862F2C04C402B8881AE7D734E4073D87DC7F08C4D40C1ABE5CE4C9C4F4073D87DC7F08C4D40C1ABE5CE4C9C4F40548B8862F2C04C402B8881AE7D734E40548B8862F2C04C40
7071	 Каменский район	\N	56	57.226914999999998	66.185722999999996	61.946506999999997	56.05218	0103000020E6100000010000000500000065FCFB8C0B9D4C40ADC090D5AD064C4065FCFB8C0B9D4C40B037312427F94E405CC7B8E2E28B5040B037312427F94E405CC7B8E2E28B5040ADC090D5AD064C4065FCFB8C0B9D4C40ADC090D5AD064C40
7338	Шадринск	\N	55	63.585675000000002	63.703749999999999	56.123679000000003	56.058568999999999	0103000020E61000000100000005000000DB8AFD65F7CA4F409BC761307F074C40DB8AFD65F7CA4F40DB19A6B6D40F4C40AE47E17A14DA4F40DB19A6B6D40F4C40AE47E17A14DA4F409BC761307F074C40DB8AFD65F7CA4F409BC761307F074C40
1124	Юргамышский район	\N	55	63.969695999999999	64.865899999999996	55.709195999999999	55.040765999999998	0103000020E61000000100000005000000F0879FFF1EFC4F40F564FED137854B40F0879FFF1EFC4F401D3A3DEFC6DA4B40CF66D5E76A3750401D3A3DEFC6DA4B40CF66D5E76A375040F564FED137854B40F0879FFF1EFC4F40F564FED137854B40
1058	Щучанский район	\N	55	62.039189999999998	63.114697999999997	55.823641000000002	55.010049000000002	0103000020E61000000100000005000000452A8C2D04054F40C32D1F4949814B40452A8C2D04054F4087527B116DE94B4053758F6CAE8E4F4087527B116DE94B4053758F6CAE8E4F40C32D1F4949814B40452A8C2D04054F40C32D1F4949814B40
910	Шумихинский район	\N	55	62.725951999999999	63.685245000000002	55.795974999999999	54.991205999999998	0103000020E610000001000000050000009F3BC1FEEB5C4F40ABCC94D6DF7E4B409F3BC1FEEB5C4F4080B74082E2E54B40AF5FB01BB6D74F4080B74082E2E54B40AF5FB01BB6D74F40ABCC94D6DF7E4B409F3BC1FEEB5C4F40ABCC94D6DF7E4B40
228	Шатровский район	\N	55	64.161997999999997	65.247190000000003	56.840497999999997	56.060197000000002	0103000020E610000001000000050000001D01DC2C5E0A50409E280989B4074C401D01DC2C5E0A50403C2D3F70956B4C407D7901F6D14F50403C2D3F70956B4C407D7901F6D14F50409E280989B4074C401D01DC2C5E0A50409E280989B4074C40
436	Шадринский район	\N	55	63.169691999999998	64.399297000000004	56.527599000000002	55.697294999999997	0103000020E610000001000000050000004832AB77B8954F4008556AF640D94B404832AB77B8954F407F33315D88434C40051901158E1950407F33315D88434C40051901158E19504008556AF640D94B404832AB77B8954F4008556AF640D94B40
318	Частоозерский район	\N	55	67.464295000000007	68.493199000000004	55.728696999999997	55.335996000000002	0103000020E61000000100000005000000912C6002B7DD50401DCBBBEA01AB4B40912C6002B7DD5040BED87BF145DD4B40E0DA8992901F5140BED87BF145DD4B40E0DA8992901F51401DCBBBEA01AB4B40912C6002B7DD50401DCBBBEA01AB4B40
80	Целинный район	\N	55	63.096615	64.286693999999997	54.793900000000001	54.187933000000001	0103000020E61000000100000005000000CAA65CE15D8C4F406A6B44300E184B40CAA65CE15D8C4F40AF25E4839E654B40677DCA3159125040AF25E4839E654B40677DCA31591250406A6B44300E184B40CAA65CE15D8C4F406A6B44300E184B40
1874	Сафакулевский район	\N	55	61.963811999999997	62.888412000000002	55.149017999999998	54.625093	0103000020E6100000010000000500000005BF0D315EFB4E40B1FA230C03504B4005BF0D315EFB4E40F641960513934B40DEAF027CB7714F40F641960513934B40DEAF027CB7714F40B1FA230C03504B4005BF0D315EFB4E40B1FA230C03504B40
1838	Притобольный район	\N	55	64.897800000000004	65.696697999999998	55.206097999999997	54.545296999999998	0103000020E610000001000000050000005396218E75395040AFCDC64ACC454B405396218E75395040B0E2546B619A4B40124C35B3966C5040B0E2546B619A4B40124C35B3966C5040AFCDC64ACC454B405396218E75395040AFCDC64ACC454B40
1806	Половинский район	\N	55	65.482395999999994	66.766197000000005	55.135897	54.599096000000003	0103000020E6100000010000000500000028EE7893DF5E50400C957F2DAF4C4B4028EE7893DF5E5040F04FA91265914B40C652245F09B15040F04FA91265914B40C652245F09B150400C957F2DAF4C4B4028EE7893DF5E50400C957F2DAF4C4B40
1293	Петуховский район	\N	55	67.297694000000007	68.725593000000003	55.426498000000002	54.843896000000001	0103000020E61000000100000005000000CA8D226B0DD35040D49CBCC8046C4B40CA8D226B0DD350409BE7887C97B64B40384D9F1D702E51409BE7887C97B64B40384D9F1D702E5140D49CBCC8046C4B40CA8D226B0DD35040D49CBCC8046C4B40
1680	Мокроусовский район	\N	55	66.244392000000005	67.501198000000002	56.044800000000002	55.484597000000001	0103000020E61000000100000005000000DCD9571EA48F5040AF5E454607BE4B40DCD9571EA48F50402F6EA301BC054C4085B4C6A013E050402F6EA301BC054C4085B4C6A013E05040AF5E454607BE4B40DCD9571EA48F5040AF5E454607BE4B40
1349	Мишкинский район	\N	55	63.324167000000003	64.345201000000003	55.854698999999997	54.957500000000003	0103000020E61000000100000005000000A2B8E34D7EA94F40C3F5285C8F7A4B40A2B8E34D7EA94F404276DEC666ED4B40FA62EFC5171650404276DEC666ED4B40FA62EFC517165040C3F5285C8F7A4B40A2B8E34D7EA94F40C3F5285C8F7A4B40
1577	Макушинский район	\N	55	66.686300000000003	67.691092999999995	55.579397999999998	54.749096000000002	0103000020E61000000100000005000000ABCFD556ECAB50403FC8B260E25F4B40ABCFD556ECAB504014AFB2B629CA4B40A65F22DE3AEC504014AFB2B629CA4B40A65F22DE3AEC50403FC8B260E25F4B40ABCFD556ECAB50403FC8B260E25F4B40
1472	Лебяжьевский район	\N	55	66.070496000000006	67.052093999999997	55.614398999999999	54.900596	0103000020E61000000100000005000000ED9FA701838450404774CFBA46734B40ED9FA70183845040F9D85DA0A4CE4B405794128255C35040F9D85DA0A4CE4B405794128255C350404774CFBA46734B40ED9FA701838450404774CFBA46734B40
1305	Куртамышский район	\N	55	63.812859000000003	65.059208999999996	55.150072000000002	54.327798000000001	0103000020E6100000010000000500000030A182C30BE84F40DCD8EC48F5294B4030A182C30BE84F40CD052E8F35934B403FA88B14CA435040CD052E8F35934B403FA88B14CA435040DCD8EC48F5294B4030A182C30BE84F40DCD8EC48F5294B40
1181	Кетовский район	\N	55	64.670597999999998	65.824196000000001	55.773195999999999	55.048043999999997	0103000020E61000000100000005000000D5B0DF13EB2A50406F62484E26864B40D5B0DF13EB2A5040F2B22616F8E24B409E5F94A0BF745040F2B22616F8E24B409E5F94A0BF7450406F62484E26864B40D5B0DF13EB2A50406F62484E26864B40
1038	Катайский район	\N	55	62.061692000000001	62.965577000000003	56.567295999999999	55.760427999999997	0103000020E6100000010000000500000061360186E5074F40397B67B455E14B4061360186E5074F406893C3279D484C408962F206987B4F406893C3279D484C408962F206987B4F40397B67B455E14B4061360186E5074F40397B67B455E14B40
909	Каргапольский район	\N	55	63.937393	65.115497000000005	56.208599999999997	55.601396000000001	0103000020E61000000100000005000000EA3F6B7EFCF74F40FDF84B8BFACC4B40EA3F6B7EFCF74F4009F9A067B31A4C405072874D6447504009F9A067B31A4C405072874D64475040FDF84B8BFACC4B40EA3F6B7EFCF74F40FDF84B8BFACC4B40
839	Звериноголовский район	\N	55	64.338121999999998	65.261697999999996	54.707217999999997	54.325498000000003	0103000020E61000000100000005000000B80375CAA3155040EB7420EBA9294B40B80375CAA31550403E92921E865A4B406EDBF7A8BF5050403E92921E865A4B406EDBF7A8BF505040EB7420EBA9294B40B80375CAA3155040EB7420EBA9294B40
580	Далматовский район	\N	55	62.616554999999998	63.761097999999997	56.612499	55.721594000000003	0103000020E61000000100000005000000B7973446EB4E4F40B37E33315DDC4B40B7973446EB4E4F4096EA025E664E4C408786C5A86BE14F4096EA025E664E4C408786C5A86BE14F40B37E33315DDC4B40B7973446EB4E4F40B37E33315DDC4B40
229	Варгашинский район	\N	55	65.618599000000003	66.517893000000001	56.067298000000001	55.017896	0103000020E61000000100000005000000A795422097675040575D876A4A824B40A795422097675040098B8A389D084C40F374AE2825A15040098B8A389D084C40F374AE2825A15040575D876A4A824B40A795422097675040575D876A4A824B40
92	Белозерский район	\N	55	64.993093000000002	66.066390999999996	56.288995999999997	55.578594000000002	0103000020E61000000100000005000000BD38F1D58E3F5040B7D4415E0FCA4B40BD38F1D58E3F5040605628D2FD244C40EB6F09C03F845040605628D2FD244C40EB6F09C03F845040B7D4415E0FCA4B40BD38F1D58E3F5040B7D4415E0FCA4B40
1880	Альменевский район	\N	55	62.754930999999999	64.022651999999994	55.116768	54.655020999999998	0103000020E6100000010000000500000048DE3994A1604F40BB9866BAD7534B4048DE3994A1604F40139CFA40F28E4B4018CC5F2173015040139CFA40F28E4B4018CC5F2173015040BB9866BAD7534B4048DE3994A1604F40BB9866BAD7534B40
448	Шегарский район	\N	54	83.058698000000007	84.503997999999996	57.085397999999998	56.3735	0103000020E61000000100000005000000CD9541B5C1C354402B8716D9CE2F4C40CD9541B5C1C3544068925852EE8A4C40F6CFD3804120554068925852EE8A4C40F6CFD380412055402B8716D9CE2F4C40CD9541B5C1C354402B8716D9CE2F4C40
146	Чаинский район	\N	54	81.306794999999994	83.579792999999995	58.119697000000002	57.328097999999997	0103000020E61000000100000005000000E2E47E87A253544006F1811DFFA94C40E2E47E87A2535440F436363B520F4D40C85C19541BE55440F436363B520F4D40C85C19541BE5544006F1811DFFA94C40E2E47E87A253544006F1811DFFA94C40
52	Томский район	\N	54	84.033998999999994	86.256099000000006	57.307996000000003	55.985196000000002	0103000020E610000001000000050000003046240A2D02554034130CE71AFE4B403046240A2D02554040A6B5696CA74C4074620FED6390554040A6B5696CA74C4074620FED6390554034130CE71AFE4B403046240A2D02554034130CE71AFE4B40
1384	Тегульдетский район	\N	54	87.000398000000004	89.377098000000004	58.246797000000001	56.683599000000001	0103000020E61000000100000005000000F73E558506C05540064A0A2C80574C40F73E558506C055401EE0490B971F4D40C558A65F225856401EE0490B971F4D40C558A65F22585640064A0A2C80574C40F73E558506C05540064A0A2C80574C40
1813	Первомайский район	\N	54	85.455591999999996	87.910499000000002	58.423896999999997	56.883499	0103000020E610000001000000050000006E14596B285D55403C86C77E16714C406E14596B285D5540AEEFC34142364D409B02999D45FA5540AEEFC34142364D409B02999D45FA55403C86C77E16714C406E14596B285D55403C86C77E16714C40
7205	Парабельский район	\N	54	77.314393999999993	84.065791000000004	59.847096000000001	56.920796000000003	0103000020E61000000100000005000000C00303081F545340D124B1A4DC754C40C00303081F545340454948A46DEC4D40C15774EB35045540454948A46DEC4D40C15774EB35045540D124B1A4DC754C40C00303081F545340D124B1A4DC754C40
807	Молчановский район	\N	54	83.102194999999995	85.577196999999998	58.053598000000001	57.397998999999999	0103000020E6100000010000000500000024B4E55C8AC654409C6B98A1F1B24C4024B4E55C8AC65440C5909C4CDC064D405B96AFCBF0645540C5909C4CDC064D405B96AFCBF06455409C6B98A1F1B24C4024B4E55C8AC654409C6B98A1F1B24C40
765	Кривошеинский район	\N	54	83.114394000000004	84.949597999999995	57.493000000000002	56.990296999999998	0103000020E61000000100000005000000F436363B52C75440D829560DC27E4C40F436363B52C75440C976BE9F1ABF4C403596B036C63C5540C976BE9F1ABF4C403596B036C63C5540D829560DC27E4C40F436363B52C75440D829560DC27E4C40
7144	Колпашевский район	\N	54	80.800998000000007	84.149396999999993	59.311	57.849896000000001	0103000020E61000000100000005000000558A1D8D4333544028806264C9EC4C40558A1D8D433354402B8716D9CEA74D40B6476FB88F0955402B8716D9CEA74D40B6476FB88F09554028806264C9EC4C40558A1D8D4333544028806264C9EC4C40
746	Кожевниковский район	\N	54	83.072595000000007	84.267291999999998	56.496999000000002	55.670996000000002	0103000020E610000001000000050000009AB67F65A5C4544098DF6932E3D54B409AB67F65A5C454408692C9A99D3F4C40E09EE74F1B1155408692C9A99D3F4C40E09EE74F1B11554098DF6932E3D54B409AB67F65A5C4544098DF6932E3D54B40
7151	Каргасокский район	\N	54	75.057592999999997	84.790300000000002	61.034899000000003	57.156998000000002	0103000020E61000000100000005000000A0DE8C9AAFC35240CAC4AD8218944C40A0DE8C9AAFC35240E1D4079277844E40D881734694325540E1D4079277844E40D881734694325540CAC4AD8218944C40A0DE8C9AAFC35240CAC4AD8218944C40
853	Зырянский район	\N	54	86.133595999999997	88.054597999999999	57.100900000000003	56.535899000000001	0103000020E6100000010000000500000017B83CD68C885540C47AA35698444C4017B83CD68C8855404D158C4AEA8C4C40541B9C887E0356404D158C4AEA8C4C40541B9C887E035640C47AA35698444C4017B83CD68C885540C47AA35698444C40
7388	ЗАТО Северск	\N	54	75.057592999999997	89.377098000000004	61.034899000000003	55.664318999999999	0103000020E61000000100000005000000A0DE8C9AAFC35240438EAD6708D54B40A0DE8C9AAFC35240E1D4079277844E40C558A65F22585640E1D4079277844E40C558A65F22585640438EAD6708D54B40A0DE8C9AAFC35240438EAD6708D54B40
7179	Верхнекетский район	\N	54	83.795299	88.815596999999997	59.953696000000001	58.039099	0103000020E61000000100000005000000A8E2C62DE6F2544035272F3201054D40A8E2C62DE6F25440BB29E5B512FA4D40CE6DC2BD32345640BB29E5B512FA4D40CE6DC2BD3234564035272F3201054D40A8E2C62DE6F2544035272F3201054D40
694	Бакчарский район	\N	54	79.593097	83.247191999999998	57.936498999999998	56.242499000000002	0103000020E61000000100000005000000C4961E4DF5E5534007280D350A1F4C40C4961E4DF5E553404CDE0033DFF74C404DF564FED1CF54404CDE0033DFF74C404DF564FED1CF544007280D350A1F4C40C4961E4DF5E5534007280D350A1F4C40
498	Асиновский район	\N	54	84.735699999999994	86.380695000000003	57.891899000000002	56.709896999999998	0103000020E61000000100000005000000B3EA73B5152F5540A643A7E7DD5A4C40B3EA73B5152F5540E52A16BF29F24C400CB08F4E5D985540E52A16BF29F24C400CB08F4E5D985540A643A7E7DD5A4C40B3EA73B5152F5540A643A7E7DD5A4C40
5666	Александровский район	\N	54	75.382441	89.378902999999994	58.000521999999997	55.664318999999999	0103000020E6100000010000000500000092E9D0E979D85240438EAD6708D54B4092E9D0E979D85240D976DA1A11004D40CD565EF23F585640D976DA1A11004D40CD565EF23F585640438EAD6708D54B4092E9D0E979D85240438EAD6708D54B40
1651	Ширинский район	\N	46	88.939097000000004	90.701295000000002	54.940798999999998	53.947631999999999	0103000020E6100000010000000500000064B14D2A1A3C5640505260014CF94A4064B14D2A1A3C5640048E041A6C784B404B766C04E2AC5640048E041A6C784B404B766C04E2AC5640505260014CF94A4064B14D2A1A3C5640505260014CF94A40
1625	Усть-Абаканский район	\N	46	89.165149	91.524699999999996	54.275495999999997	53.378999	0103000020E61000000100000005000000E57D1CCD914A5640BD1B0B0A83B04A40E57D1CCD914A5640E316F37343234B40840D4FAF94E15640E316F37343234B40840D4FAF94E15640BD1B0B0A83B04A40E57D1CCD914A5640BD1B0B0A83B04A40
1669	Таштыпский район	\N	46	87.872195000000005	90.899283999999994	53.148600000000002	51.284770999999999	0103000020E61000000100000005000000062FFA0AD2F75540B3EC496073A44940062FFA0AD2F75540C217265305934A403A747ADE8DB95640C217265305934A403A747ADE8DB95640B3EC496073A44940062FFA0AD2F75540B3EC496073A44940
1627	Орджоникидзевский район	\N	46	88.366187999999994	90.542725000000004	55.434896000000002	54.281205	0103000020E61000000100000005000000020CCB9F6F175640603C8386FE234B40020CCB9F6F175640A39410ACAAB74B402F6EA301BCA25640A39410ACAAB74B402F6EA301BCA25640603C8386FE234B40020CCB9F6F175640603C8386FE234B40
1574	Боградский район	\N	46	90.202091999999993	91.582200999999998	54.916381999999999	53.975898999999998	0103000020E6100000010000000500000020B24813EF8C56407C992842EAFC4A4020B24813EF8C5640505260014C754B40B4ACFBC742E55640505260014C754B40B4ACFBC742E556407C992842EAFC4A4020B24813EF8C56407C992842EAFC4A40
1506	Бейский район	\N	46	90.256297000000004	91.576190999999994	53.389499000000001	52.600819000000001	0103000020E610000001000000050000000744882B6790564060E811A3E74C4A400744882B6790564090696D1ADBB14A40F84F3750E0E4564090696D1ADBB14A40F84F3750E0E4564060E811A3E74C4A400744882B6790564060E811A3E74C4A40
1402	Аскизский район	\N	46	88.756693999999996	90.955995000000001	53.807381999999997	52.790294000000003	0103000020E6100000010000000500000015C5ABAC6D305640CE1C925A28654A4015C5ABAC6D30564085B01A4B58E74A40EE08A7052FBD564085B01A4B58E74A40EE08A7052FBD5640CE1C925A28654A4015C5ABAC6D305640CE1C925A28654A40
1343	Алтайский район	\N	46	90.999392	91.936092000000002	53.735050000000001	53.139223999999999	0103000020E6100000010000000500000094F8DC09F6BF5640BE688F17D2914A4094F8DC09F6BF564060764F1E16DE4A4006836BEEE8FB564060764F1E16DE4A4006836BEEE8FB5640BE688F17D2914A4094F8DC09F6BF5640BE688F17D2914A40
724	Эрзинский район	\N	45	94.524741000000006	97.584196000000006	50.643397	49.744495999999998	0103000020E61000000100000005000000B477465B95A157405C001AA54BDF4840B477465B95A1574019AC38D55A5249400F9D9E776365584019AC38D55A5249400F9D9E77636558405C001AA54BDF4840B477465B95A157405C001AA54BDF4840
7500	Чеди-Хольский кожуун	\N	45	88.791809000000001	99.273622000000003	53.729601000000002	49.743535000000001	0103000020E610000001000000050000006CEBA7FFAC3256403737A6272CDF48406CEBA7FFAC3256408010C99063DD4A40D55DD90583D158408010C99063DD4A40D55DD90583D158403737A6272CDF48406CEBA7FFAC3256403737A6272CDF4840
593	Улуг-Хемский район	\N	45	91.724098999999995	93.624898000000002	51.888798000000001	50.921394999999997	0103000020E610000001000000050000003E0455A357EE564055D97745F07549403E0455A357EE564007600322C4F149407E552E54FE67574007600322C4F149407E552E54FE67574055D97745F07549403E0455A357EE564055D97745F0754940
551	Тоджинский район	\N	45	94.475998000000004	99.269695999999996	53.726095999999998	51.593497999999997	0103000020E6100000010000000500000088BD50C0769E5740E61E12BEF7CB494088BD50C0769E5740D2E0B6B6F0DC4A402BF702B342D15840D2E0B6B6F0DC4A402BF702B342D15840E61E12BEF7CB494088BD50C0769E5740E61E12BEF7CB4940
500	Тес-Хемский район	\N	45	93.115094999999997	95.612493000000001	50.995496000000003	50.143520000000002	0103000020E61000000100000005000000B83B6BB75D475740352905DD5E124940B83B6BB75D47574040A6B5696C7F4940DA01D71533E7574040A6B5696C7F4940DA01D71533E75740352905DD5E124940B83B6BB75D475740352905DD5E124940
7499	Тере-Хольский кожуун	\N	45	88.791809000000001	99.273622000000003	53.729601000000002	49.743535000000001	0103000020E610000001000000050000006CEBA7FFAC3256403737A6272CDF48406CEBA7FFAC3256408010C99063DD4A40D55DD90583D158408010C99063DD4A40D55DD90583D158403737A6272CDF48406CEBA7FFAC3256403737A6272CDF4840
424	Тандинский район	\N	45	93.466992000000005	95.468896999999998	51.592194999999997	50.731695999999999	0103000020E6100000010000000500000098DF6932E35D5740984EEB36A85D494098DF6932E35D574067EDB60BCDCB4940520C906802DE574067EDB60BCDCB4940520C906802DE5740984EEB36A85D494098DF6932E35D5740984EEB36A85D4940
360	Сут-Хольский район	\N	45	90.011677000000006	91.950491999999997	52.203519999999997	51.2592	0103000020E610000001000000050000006347E350BF805640C58F31772DA149406347E350BF8056407C0A80F10C1A4A4004C765DCD4FC56407C0A80F10C1A4A4004C765DCD4FC5640C58F31772DA149406347E350BF805640C58F31772DA14940
263	Пий-Хемский район	\N	45	92.886707999999999	95.072794000000002	52.914459999999998	51.552097000000003	0103000020E610000001000000050000008046E9D2BF385740209C4F1DABC649408046E9D2BF38574005C078060D754A4015562AA8A8C4574005C078060D754A4015562AA8A8C45740209C4F1DABC649408046E9D2BF385740209C4F1DABC64940
196	Овюрский район	\N	45	90.644790999999998	93.384041999999994	51.117097999999999	50.314978000000004	0103000020E610000001000000050000005470784144A95640D17AF832512849405470784144A95640A8363811FD8E49409692E52494585740A8363811FD8E49409692E52494585740D17AF832512849405470784144A95640D17AF83251284940
171	Монгун-Тайгинский район	\N	45	89.310693999999998	90.733500000000006	50.705497000000001	49.912981000000002	0103000020E610000001000000050000000F441669E2535640486FB88FDCF448400F441669E25356408B36C7B94D5A49406DE7FBA9F1AE56408B36C7B94D5A49406DE7FBA9F1AE5640486FB88FDCF448400F441669E2535640486FB88FDCF44840
1924	Кызылский район	\N	45	93.266497000000001	98.328163000000004	52.457197000000001	49.917309000000003	0103000020E61000000100000005000000DBDE6E490E515740CAA99D616AF54840DBDE6E490E515740276A696E853A4A407730629F00955840276A696E853A4A407730629F00955840CAA99D616AF54840DBDE6E490E515740CAA99D616AF54840
1929	Каа-Хемский район	\N	45	94.658795999999995	98.950497999999996	52.290871000000003	50.464995999999999	0103000020E6100000010000000500000014AFB2B629AA5740AA622AFD843B494014AFB2B629AA57406B2DCC423B254A40753A90F5D4BC58406B2DCC423B254A40753A90F5D4BC5840AA622AFD843B494014AFB2B629AA5740AA622AFD843B4940
7496	Каа-Хемский кожуун	\N	45	88.791809000000001	99.273622000000003	53.729601000000002	49.743535000000001	0103000020E610000001000000050000006CEBA7FFAC3256403737A6272CDF48406CEBA7FFAC3256408010C99063DD4A40D55DD90583D158408010C99063DD4A40D55DD90583D158403737A6272CDF48406CEBA7FFAC3256403737A6272CDF4840
7502	Дзун-Хемчикскийй район	\N	45	90.844496000000007	92.316896999999997	51.442698	50.574098999999997	0103000020E610000001000000050000009566F3380CB6564049D576137C4949409566F3380CB656409700FC53AAB84940D5CC5A0A481457409700FC53AAB84940D5CC5A0A4814574049D576137C4949409566F3380CB6564049D576137C494940
1904	Дзун-Хемчикский район	\N	45	90.844496000000007	92.316896999999997	51.442698	50.574098999999997	0103000020E610000001000000050000009566F3380CB6564049D576137C4949409566F3380CB656409700FC53AAB84940D5CC5A0A481457409700FC53AAB84940D5CC5A0A4814574049D576137C4949409566F3380CB6564049D576137C494940
1890	Барун-Хемчикский район	\N	45	89.653993999999997	91.132396999999997	51.811394999999997	50.537295	0103000020E61000000100000005000000EF71A609DB695640F4A62215C6444940EF71A609DB695640A79196CADBE74940AA45443179C85640A79196CADBE74940AA45443179C85640F4A62215C6444940EF71A609DB695640F4A62215C6444940
389	Бай-Тайгинский район	\N	45	88.800693999999993	90.571191999999996	51.657299999999999	50.488900000000001	0103000020E610000001000000050000009E060C923E335640D8817346943E49409E060C923E33564095D4096822D4494028EFE3688EA4564095D4096822D4494028EFE3688EA45640D8817346943E49409E060C923E335640D8817346943E4940
7497	Бай-Тайгинский кожуун	\N	45	88.791809000000001	99.273622000000003	53.729601000000002	49.743535000000001	0103000020E610000001000000050000006CEBA7FFAC3256403737A6272CDF48406CEBA7FFAC3256408010C99063DD4A40D55DD90583D158408010C99063DD4A40D55DD90583D158403737A6272CDF48406CEBA7FFAC3256403737A6272CDF4840
7505	городской округ Улан-Удэ	\N	44	107.51133400000001	107.74473500000001	51.895918000000002	51.778264	0103000020E610000001000000050000004ED53DB2B9E05A40BBD39D279EE349404ED53DB2B9E05A40E9F2E670ADF24940F14BFDBCA9EF5A40E9F2E670ADF24940F14BFDBCA9EF5A40BBD39D279EE349404ED53DB2B9E05A40BBD39D279EE34940
7523	Улан-Удэ	\N	44	107.425985	107.803062	51.912405	51.737639999999999	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
7525	 Улан-Удэ	\N	44	107.425985	107.803062	51.912405	51.737639999999999	0103000020E610000001000000050000008AE5965643DB5A40581CCEFC6ADE49408AE5965643DB5A407BDAE1AFC9F4494043AA285E65F35A407BDAE1AFC9F4494043AA285E65F35A40581CCEFC6ADE49408AE5965643DB5A40581CCEFC6ADE4940
1744	Хоринский район	\N	44	108.378694	110.758798	53.085096	51.808995000000003	0103000020E61000000100000005000000404CC2853C185B4053D0ED258DE74940404CC2853C185B409D82FC6CE48A4A404B917C2590B05B409D82FC6CE48A4A404B917C2590B05B4053D0ED258DE74940404CC2853C185B4053D0ED258DE74940
1671	Тункинский район	\N	44	100.667627	103.809889	51.975898999999998	51.043095999999998	0103000020E610000001000000050000004DBB9866BA2A5940514B732B848549404DBB9866BA2A59407C992842EAFC4940F818AC38D5F359407C992842EAFC4940F818AC38D5F35940514B732B848549404DBB9866BA2A5940514B732B84854940
1632	Тарбагатайский район	\N	44	106.86769099999999	108.15929800000001	51.842498999999997	51.116996	0103000020E610000001000000050000002502D53F88B75A40A4E194B9F98E49402502D53F88B75A40D3F4D901D7EB49405E143DF0310A5B40D3F4D901D7EB49405E143DF0310A5B40A4E194B9F98E49402502D53F88B75A40A4E194B9F98E4940
1551	Селенгинский район	\N	44	105.2717	107.09119200000001	51.5961	50.600594000000001	0103000020E61000000100000005000000AF94658863515A404016A243E04C4940AF94658863515A40A3923A014DCC49400A6AF816D6C55A40A3923A014DCC49400A6AF816D6C55A404016A243E04C4940AF94658863515A404016A243E04C4940
1479	Северобайкальский район	\N	44	108.544253	114.823199	57.129962999999996	54.0122	0103000020E61000000100000005000000FEEF880AD5225B406F8104C58F014B40FEEF880AD5225B405358A9A0A2904C4065C6DB4AAFB45C405358A9A0A2904C4065C6DB4AAFB45C406F8104C58F014B40FEEF880AD5225B406F8104C58F014B40
7504	Северо-Байкальский район	\N	44	108.544253	114.823199	57.129962999999996	54.0122	0103000020E61000000100000005000000FEEF880AD5225B406F8104C58F014B40FEEF880AD5225B405358A9A0A2904C4065C6DB4AAFB45C405358A9A0A2904C4065C6DB4AAFB45C406F8104C58F014B40FEEF880AD5225B406F8104C58F014B40
1140	Прибайкальский район	\N	44	106.95649899999999	110.718994	53.385196999999998	51.905399000000003	0103000020E6100000010000000500000007EA944737BD5A40626A4B1DE4F3494007EA944737BD5A4037C2A2224EB14A404B0169FF03AE5B4037C2A2224EB14A404B0169FF03AE5B40626A4B1DE4F3494007EA944737BD5A40626A4B1DE4F34940
1362	Окинский район	\N	44	98.634299999999996	102.831992	53.374282999999998	51.707144	0103000020E6100000010000000500000094F6065F98A8584004C8D0B183DA494094F6065F98A8584071395E81E8AF4A4027A25F5B3FB5594071395E81E8AF4A4027A25F5B3FB5594004C8D0B183DA494094F6065F98A8584004C8D0B183DA4940
1278	Мухоршибирский район	\N	44	106.947597	108.565939	51.439194999999998	50.771599999999999	0103000020E610000001000000050000006A32E36DA5BC5A40FBCBEEC9C36249406A32E36DA5BC5A408AC8B08A37B84940FB21365838245B408AC8B08A37B84940FB21365838245B40FBCBEEC9C36249406A32E36DA5BC5A40FBCBEEC9C3624940
1267	Муйский район	\N	44	114.337992	116.252876	57.249299999999998	55.197994999999999	0103000020E61000000100000005000000D19332A9A1955C40C1E270E657994B40D19332A9A1955C404772F90FE99F4C405F7CD11E2F105D404772F90FE99F4C405F7CD11E2F105D40C1E270E657994B40D19332A9A1955C40C1E270E657994B40
1152	Кяхтинский район	\N	44	106.05857899999999	107.9318	50.836095	49.960825999999997	0103000020E61000000100000005000000DF4E22C2BF835A40C092AB58FCFA4840DF4E22C2BF835A40B0AC3429056B49406B9A779CA2FB5A40B0AC3429056B49406B9A779CA2FB5A40C092AB58FCFA4840DF4E22C2BF835A40C092AB58FCFA4840
1111	Курумканский район	\N	44	109.942993	112.01459800000001	55.543399000000001	53.922097999999998	0103000020E61000000100000005000000D8D64FFF597C5B407FDAA84E07F64A40D8D64FFF597C5B40EDD632198EC54B409225732CEF005C40EDD632198EC54B409225732CEF005C407FDAA84E07F64A40D8D64FFF597C5B407FDAA84E07F64A40
1022	Кижингинский район	\N	44	109.06849200000001	111.804383	52.185198	51.359200000000001	0103000020E610000001000000050000006902452C62445B40925CFE43FAAD49406902452C62445B406EA46C91B4174A40569DD5027BF35B406EA46C91B4174A40569DD5027BF35B40925CFE43FAAD49406902452C62445B40925CFE43FAAD4940
718	Кабанский район	\N	44	104.587794	107.529292	52.705495999999997	51.054098000000003	0103000020E610000001000000050000003EB2B96A9E255A40B763EAAEEC8649403EB2B96A9E255A40BABA63B14D5A4A4034828DEBDFE15A40BABA63B14D5A4A4034828DEBDFE15A40B763EAAEEC8649403EB2B96A9E255A40B763EAAEEC864940
577	Иволгинский район	\N	44	106.35789800000001	107.961399	52.076597999999997	51.347399000000003	0103000020E61000000100000005000000725303CDE7965A40E1D4079277AC4940725303CDE7965A40317898F6CD094A400EDAAB8F87FD5A40317898F6CD094A400EDAAB8F87FD5A40E1D4079277AC4940725303CDE7965A40E1D4079277AC4940
379	Закаменский район	\N	44	102.148392	104.657099	51.319695000000003	50.131498999999998	0103000020E610000001000000050000003CBF28417F895940753A90F5D41049403CBF28417F895940EDD808C4EBA84940FFCEF6E80D2A5A40EDD808C4EBA84940FFCEF6E80D2A5A40753A90F5D41049403CBF28417F895940753A90F5D4104940
24	Заиграевский район	\N	44	107.644294	109.384996	52.358798	51.399799000000002	0103000020E6100000010000000500000094C0E61C3CE95A409CFC169D2CB3494094C0E61C3CE95A4063EFC517ED2D4A40D04543C6A3585B4063EFC517ED2D4A40D04543C6A3585B409CFC169D2CB3494094C0E61C3CE95A409CFC169D2CB34940
1903	Еравнинский район	\N	44	110.272792	114.369738	53.757697	52.013696000000003	0103000020E6100000010000000500000011A7936C75915B40030B60CAC0014A4011A7936C75915B407FA31D37FCE04A40A98592C9A9975C407FA31D37FCE04A40A98592C9A9975C40030B60CAC0014A4011A7936C75915B40030B60CAC0014A40
1860	Джидинский район	\N	44	104.102794	106.297297	51.299995000000003	50.306798000000001	0103000020E61000000100000005000000670E492D94065A40363D282845274940670E492D94065A4055FB743C66A64940BB0CFFE906935A4055FB743C66A64940BB0CFFE906935A40363D282845274940670E492D94065A40363D282845274940
1820	Бичурский район	\N	44	106.806399	108.689421	50.972900000000003	50.258423999999998	0103000020E61000000100000005000000BC218D0A9CB35A403140A20914214940BC218D0A9CB35A40A323B9FC877C49403D0B42791F2C5B40A323B9FC877C49403D0B42791F2C5B403140A20914214940BC218D0A9CB35A403140A20914214940
1750	Баунтовский район	\N	44	110.37839700000001	116.917495	55.875495999999998	53.040098999999998	0103000020E61000000100000005000000E4F90CA837985B4018CDCAF621854A40E4F90CA837985B40B0E3BF4010F04B4096CFF23CB83A5D40B0E3BF4010F04B4096CFF23CB83A5D4018CDCAF621854A40E4F90CA837985B4018CDCAF621854A40
1768	Баргузинский район	\N	44	108.420699	111.218897	54.154797000000002	53.030394999999999	0103000020E610000001000000050000006F9D7FBBEC1A5B40207BBDFBE3834A406F9D7FBBEC1A5B406C425A63D0134B40520C906802CE5B406C425A63D0134B40520C906802CE5B40207BBDFBE3834A406F9D7FBBEC1A5B40207BBDFBE3834A40
687	Шебалинский район	\N	43	84.881693999999996	86.175995999999998	51.749000000000002	50.951495000000001	0103000020E6100000010000000500000015C5ABAC6D3855405DA79196CA79494015C5ABAC6D3855401D5A643BDFDF4940840EBA84438B55401D5A643BDFDF4940840EBA84438B55405DA79196CA79494015C5ABAC6D3855405DA79196CA794940
280	Чойский район	\N	43	86.164299999999997	87.167295999999993	52.135398000000002	51.148997999999999	0103000020E61000000100000005000000E6AE25E4838A5540AF95D05D12934940E6AE25E4838A5540CFF8BEB854114A401A3048FAB4CA5540CFF8BEB854114A401A3048FAB4CA5540AF95D05D12934940E6AE25E4838A5540AF95D05D12934940
323	Чемальский район	\N	43	85.737590999999995	86.701995999999994	51.711798999999999	50.880994999999999	0103000020E61000000100000005000000BBB4E1B0346F55404278B471C4704940BBB4E1B0346F5540AA29C93A1CDB49400F7BA180EDAC5540AA29C93A1CDB49400F7BA180EDAC55404278B471C4704940BBB4E1B0346F55404278B471C4704940
253	Усть-Коксинский район	\N	43	84.467597999999995	86.723096999999996	50.709895000000003	49.468898000000003	0103000020E61000000100000005000000336B2920ED1D5540759483D904BC4840336B2920ED1D5540064CE0D6DD5A49407CB5A33847AE5540064CE0D6DD5A49407CB5A33847AE5540759483D904BC4840336B2920ED1D5540759483D904BC4840
29	Усть-Канский район	\N	43	83.929497999999995	85.343896000000001	51.512642999999997	50.208697999999998	0103000020E61000000100000005000000A2EC2DE57CFB5440CC5EB69DB61A4940A2EC2DE57CFB5440FCC22B499EC149406A4E5E6402565540FCC22B499EC149406A4E5E6402565540CC5EB69DB61A4940A2EC2DE57CFB5440CC5EB69DB61A4940
1911	Улаганский район	\N	43	87.131192999999996	89.863185000000001	51.555199999999999	50.110297000000003	0103000020E61000000100000005000000B41D537765C8554068EC4B361E0E4940B41D537765C855409E5E29CB10C7494075594C6C3E7756409E5E29CB10C7494075594C6C3E77564068EC4B361E0E4940B41D537765C8554068EC4B361E0E4940
851	Турочакский район	\N	43	86.636796000000004	88.459486999999996	52.655596000000003	51.218497999999997	0103000020E61000000100000005000000508E0244C1A85540E61E12BEF79B4940508E0244C1A85540B8B1D991EA534A40FA7B293C681D5640B8B1D991EA534A40FA7B293C681D5640E61E12BEF79B4940508E0244C1A85540E61E12BEF79B4940
195	Онгудайский район	\N	43	85.239097999999998	87.500597999999997	51.296498	50.192697000000003	0103000020E610000001000000050000007FA2B2614D4F5540C784984BAA1849407FA2B2614D4F55402AAA7EA5F3A549405A9C31CC09E055402AAA7EA5F3A549405A9C31CC09E05540C784984BAA1849407FA2B2614D4F5540C784984BAA184940
863	Майминский район	\N	43	85.693843000000001	86.294393999999997	52.102595000000001	51.633094999999997	0103000020E61000000100000005000000BF6378EC676C55406C21C84109D14940BF6378EC676C5540D7DD3CD5210D4A40DF88EE59D7925540D7DD3CD5210D4A40DF88EE59D79255406C21C84109D14940BF6378EC676C55406C21C84109D14940
841	Кош-Агачский район	\N	43	86.601590999999999	89.719194000000002	50.368195	49.070692999999999	0103000020E6100000010000000500000059A4897780A655402F87DD770C89484059A4897780A655407EC68503212F4940AF5E4546076E56407EC68503212F4940AF5E4546076E56402F87DD770C89484059A4897780A655402F87DD770C894840
335	Исилькульский район	\N	53	70.804293999999999	71.720899000000003	55.303299000000003	54.534595000000003	0103000020E610000001000000050000009E978A8D79B3514075CDE49B6D444B409E978A8D79B351406BF46A80D2A64B40062E8F3523EE51406BF46A80D2A64B40062E8F3523EE514075CDE49B6D444B409E978A8D79B3514075CDE49B6D444B40
245	Шербакульский район	\N	53	71.991292000000001	72.884793000000002	54.780999999999999	54.217699000000003	0103000020E610000001000000050000005532005471FF51409BAF928FDD1B4B405532005471FF51408716D9CEF7634B40B4AED172A03852408716D9CEF7634B40B4AED172A03852409BAF928FDD1B4B405532005471FF51409BAF928FDD1B4B40
1788	Черлакский район	\N	53	74.192397999999997	75.691291000000007	54.664099	53.801400000000001	0103000020E610000001000000050000003674B33F508C5240D881734694E64A403674B33F508C524035272F3201554B403A419B1C3EEC524035272F3201554B403A419B1C3EEC5240D881734694E64A403674B33F508C5240D881734694E64A40
4673	Хангаласский район	\N	53	70.357275000000001	76.305946000000006	58.575800999999998	53.435012999999998	0103000020E610000001000000050000006B2BF697DD965140DC2A8881AEB74A406B2BF697DD9651408600E0D8B3494D40E415889E941353408600E0D8B3494D40E415889E94135340DC2A8881AEB74A406B2BF697DD965140DC2A8881AEB74A40
1443	Усть-Ишимский район	\N	53	70.361181999999999	71.968896999999998	58.532259000000003	57.199969000000003	0103000020E61000000100000005000000D9791B9B1D9751405F9B8D9598994C40D9791B9B1D97514037001B1021444D40520C906802FE514037001B1021444D40520C906802FE51405F9B8D9598994C40D9791B9B1D9751405F9B8D9598994C40
447	Тюкалинский район	\N	53	71.730197000000004	73.276996999999994	56.489198000000002	55.457199000000003	0103000020E61000000100000005000000CAA8328CBBEE5140C861307F85BA4B40CAA8328CBBEE514062A2410A9E3E4C40C405A051BA51524062A2410A9E3E4C40C405A051BA515240C861307F85BA4B40CAA8328CBBEE5140C861307F85BA4B40
1155	Тевризский район	\N	53	71.528093999999996	74.223696000000004	58.154000000000003	57.264794999999999	0103000020E61000000100000005000000AFCDC64ACCE15140799274CDE4A14C40AFCDC64ACCE15140C1CAA145B6134D40BF0F0709518E5240C1CAA145B6134D40BF0F0709518E5240799274CDE4A14C40AFCDC64ACCE15140799274CDE4A14C40
873	Тарский район	\N	53	73.533097999999995	75.847696999999997	58.574581000000002	56.506697000000003	0103000020E6100000010000000500000008E412471E6252409CFD8172DB404C4008E412471E62524095F3C5DE8B494D40B5FAEAAA40F6524095F3C5DE8B494D40B5FAEAAA40F652409CFD8172DB404C4008E412471E6252409CFD8172DB404C40
1527	Таврический район	\N	53	72.881298000000001	74.411794	54.819097999999997	54.228596000000003	0103000020E61000000100000005000000EF01BA2F673852408BFF3BA2421D4B40EF01BA2F67385240081C0934D8684B4019AC38D55A9A5240081C0934D8684B4019AC38D55A9A52408BFF3BA2421D4B40EF01BA2F673852408BFF3BA2421D4B40
2846	Сивинский район	\N	53	70.357275000000001	76.305946000000006	58.575800999999998	53.435012999999998	0103000020E610000001000000050000006B2BF697DD965140DC2A8881AEB74A406B2BF697DD9651408600E0D8B3494D40E415889E941353408600E0D8B3494D40E415889E94135340DC2A8881AEB74A406B2BF697DD965140DC2A8881AEB74A40
1448	Седельниковский район	\N	53	74.816691000000006	76.288652999999996	57.393464000000002	56.696891000000001	0103000020E6100000010000000500000001FC53AA44B4524039F06AB933594C4001FC53AA44B45240A11342075DB24C401BB96E4A79125340A11342075DB24C401BB96E4A7912534039F06AB933594C4001FC53AA44B4524039F06AB933594C40
375	Саргатский район	\N	53	72.765199999999993	74.078194999999994	56.131596000000002	55.349198999999999	0103000020E610000001000000050000008CB96B09F9305240E065868DB2AC4B408CB96B09F930524068244223D8104C407CED99250185524068244223D8104C407CED992501855240E065868DB2AC4B408CB96B09F9305240E065868DB2AC4B40
6900	Саргатский  муниципальный район	\N	53	72.765199999999993	74.078194999999994	56.131596000000002	55.349198999999999	0103000020E610000001000000050000008CB96B09F9305240E065868DB2AC4B408CB96B09F930524068244223D8104C407CED99250185524068244223D8104C407CED992501855240E065868DB2AC4B408CB96B09F9305240E065868DB2AC4B40
1257	Русско-Полянский район	\N	53	73.245492999999996	74.519897	54.047898000000004	53.437196	0103000020E6100000010000000500000067994528B64F524094F8DC09F6B74A4067994528B64F52409CC58B8521064B40771211FE45A152409CC58B8521064B40771211FE45A1524094F8DC09F6B74A4067994528B64F524094F8DC09F6B74A40
7253	Русско-Полянский  район	\N	53	73.245492999999996	74.519897	54.047898000000004	53.437196	0103000020E6100000010000000500000067994528B64F524094F8DC09F6B74A4067994528B64F52409CC58B8521064B40771211FE45A152409CC58B8521064B40771211FE45A1524094F8DC09F6B74A4067994528B64F524094F8DC09F6B74A40
373	Полтавский район	\N	53	71.000108999999995	72.218584000000007	54.685896	54.094582000000003	0103000020E61000000100000005000000DBDB2DC901C05140286552431B0C4B40DBDB2DC901C05140863AAC70CB574B4073DBBE47FD0D5240863AAC70CB574B4073DBBE47FD0D5240286552431B0C4B40DBDB2DC901C05140286552431B0C4B40
1043	Павлоградский район	\N	53	73.122468999999995	74.387692000000001	54.459797999999999	53.939630000000001	0103000020E6100000010000000500000086713788D6475240952BBCCB45F84A4086713788D647524013622EA9DA3A4B40EF3A1BF2CF98524013622EA9DA3A4B40EF3A1BF2CF985240952BBCCB45F84A4086713788D6475240952BBCCB45F84A40
422	Омский район	\N	53	72.907798	74.353296	55.475898000000001	54.533796000000002	0103000020E61000000100000005000000F357C85C193A5240295E656D53444B40F357C85C193A5240AC1DC539EABC4B40B073D3669C965240AC1DC539EABC4B40B073D3669C965240295E656D53444B40F357C85C193A5240295E656D53444B40
636	Оконешниковский район	\N	53	74.584997999999999	75.847239000000002	55.037799	54.458399999999997	0103000020E610000001000000050000006D8E739B70A55240423EE8D9AC3A4B406D8E739B70A552402769FE98D6844B405439ED2939F652402769FE98D6844B405439ED2939F65240423EE8D9AC3A4B406D8E739B70A55240423EE8D9AC3A4B40
527	Одесский район	\N	53	72.309196999999998	73.347694000000004	54.400599999999997	53.904516999999998	0103000020E610000001000000050000005DC136E2C913524088D68A36C7F34A405DC136E2C913524088635DDC46334B40FDC0559E4056524088635DDC46334B40FDC0559E4056524088D68A36C7F34A405DC136E2C913524088D68A36C7F34A40
266	Нововаршавский район	\N	53	74.082795000000004	75.026797999999999	54.402496999999997	53.668995000000002	0103000020E610000001000000050000006E5166834C8552400118CFA0A1D54A406E5166834C8552407ADE8D0585334B404966F50EB7C152407ADE8D0585334B404966F50EB7C152400118CFA0A1D54A406E5166834C8552400118CFA0A1D54A40
95	Нижнеомский район	\N	53	74.377200000000002	75.368527	55.988500000000002	55.186895	0103000020E610000001000000050000004703780B249852409964E42CEC974B404703780B249852404A0C022B87FE4B405A2C45F295D752404A0C022B87FE4B405A2C45F295D752409964E42CEC974B404703780B249852409964E42CEC974B40
625	Называевский район	\N	53	70.444124000000002	72.075993999999994	55.962699999999998	55.164597999999998	0103000020E6100000010000000500000099D711876C9C5140567E198C11954B4099D711876C9C5140FAEDEBC039FB4B404D2CF015DD045240FAEDEBC039FB4B404D2CF015DD045240567E198C11954B4099D711876C9C5140567E198C11954B40
353	Муромцевский район	\N	53	74.620598000000001	76.305946000000006	56.774997999999997	55.853299	0103000020E61000000100000005000000A27DACE0B7A75240D15AD1E638ED4B40A27DACE0B7A75240923B6C2233634C40E415889E94135340923B6C2233634C40E415889E94135340D15AD1E638ED4B40A27DACE0B7A75240D15AD1E638ED4B40
7252	Муромцевский	\N	53	74.620598000000001	76.305946000000006	56.774997999999997	55.853299	0103000020E61000000100000005000000A27DACE0B7A75240D15AD1E638ED4B40A27DACE0B7A75240923B6C2233634C40E415889E94135340923B6C2233634C40E415889E94135340D15AD1E638ED4B40A27DACE0B7A75240D15AD1E638ED4B40
1708	Москаленский район	\N	53	71.535694000000007	72.271997999999996	55.265999000000001	54.506898999999997	0103000020E6100000010000000500000076AA7CCF48E2514003B00111E2404B4076AA7CCF48E2514065E256410CA24B40F4A44C6A6811524065E256410CA24B40F4A44C6A6811524003B00111E2404B4076AA7CCF48E2514003B00111E2404B40
1656	Марьяновский район	\N	53	72.029398999999998	72.969296999999997	55.112000000000002	54.671498	0103000020E610000001000000050000003FE257ACE10152402AAA7EA5F3554B403FE257ACE101524075931804568E4B4019C748F6083E524075931804568E4B4019C748F6083E52402AAA7EA5F3554B403FE257ACE10152402AAA7EA5F3554B40
1507	Любинский район	\N	53	71.946591999999995	73.199400999999995	55.589295	55.019495999999997	0103000020E61000000100000005000000EFA99CF694FC51408F334DD87E824B40EFA99CF694FC51402159C0046ECB4B408A7269FCC24C52402159C0046ECB4B408A7269FCC24C52408F334DD87E824B40EFA99CF694FC51408F334DD87E824B40
1089	Крутинский район	\N	53	70.717292999999998	72.316194999999993	56.690925	55.716797999999997	0103000020E610000001000000050000009529E620E8AD51404AEB6F09C0DB4B409529E620E8AD5140917EFB3A70584C40280AF4893C145240917EFB3A70584C40280AF4893C1452404AEB6F09C0DB4B409529E620E8AD51404AEB6F09C0DB4B40
1075	Кормиловский район	\N	53	73.656598000000002	74.473391000000007	55.224694999999997	54.633896	0103000020E610000001000000050000009E279EB3056A524059880E8123514B409E279EB3056A5240904946CEC29C4B4021CEC3094C9E5240904946CEC29C4B4021CEC3094C9E524059880E8123514B409E279EB3056A524059880E8123514B40
1250	Колосовский район	\N	53	72.748194999999996	74.187494000000001	56.797896000000001	56.046695	0103000020E61000000100000005000000F701486DE22F524080F10C1AFA054C40F701486DE22F5240FBCDC47421664C408F8CD5E6FF8B5240FBCDC47421664C408F8CD5E6FF8B524080F10C1AFA054C40F701486DE22F524080F10C1AFA054C40
495	Калачинский район	\N	53	74.240701000000001	75.407531000000006	55.338197999999998	54.513494999999999	0103000020E6100000010000000500000054C72AA5678F52406BD44334BA414B4054C72AA5678F52404BC972124AAB4B40CC46E7FC14DA52404BC972124AAB4B40CC46E7FC14DA52406BD44334BA414B4054C72AA5678F52406BD44334BA414B40
469	Знаменский район	\N	53	73.109595999999996	74.187494000000001	57.743096000000001	56.743898000000002	0103000020E610000001000000050000006FF1F09E03475240A8C7B60C385F4C406FF1F09E03475240EBE40CC51DDF4C408F8CD5E6FF8B5240EBE40CC51DDF4C408F8CD5E6FF8B5240A8C7B60C385F4C406FF1F09E03475240A8C7B60C385F4C40
4828	Дорогобужский район	\N	53	70.357275000000001	76.305946000000006	58.575800999999998	53.435012999999998	0103000020E610000001000000050000006B2BF697DD965140DC2A8881AEB74A406B2BF697DD9651408600E0D8B3494D40E415889E941353408600E0D8B3494D40E415889E94135340DC2A8881AEB74A406B2BF697DD965140DC2A8881AEB74A40
345	Горьковский район	\N	53	73.386393999999996	74.631997999999996	55.759495999999999	55.163795	0103000020E61000000100000005000000B857E6ADBA585240C91F0C3CF7944B40B857E6ADBA585240AEB8382A37E14B40CB48BDA772A85240AEB8382A37E14B40CB48BDA772A85240C91F0C3CF7944B40B857E6ADBA585240C91F0C3CF7944B40
397	Большеуковский район	\N	53	71.078863999999996	73.383393999999996	57.368599000000003	56.399397999999998	0103000020E610000001000000050000003B35971B0CC551403D0B42791F334C403B35971B0CC551404E2B85402EAF4C40E3DEFC86895852404E2B85402EAF4C40E3DEFC86895852403D0B42791F334C403B35971B0CC551403D0B42791F334C40
103	Большереченский район	\N	53	73.722193000000004	74.920895999999999	56.664895000000001	55.716498000000001	0103000020E610000001000000050000009C19FD68386E524020D3DA34B6DB4B409C19FD68386E5240102384471B554C401AC1C6F5EFBA5240102384471B554C401AC1C6F5EFBA524020D3DA34B6DB4B409C19FD68386E524020D3DA34B6DB4B40
929	Азовский Немецкий Национальный район	\N	53	72.703692000000004	73.500094000000004	54.916195999999999	54.321696000000003	0103000020E610000001000000050000003D9D2B4A092D524084A0A3552D294B403D9D2B4A092D5240EE5C18E945754B4041BB438A01605240EE5C18E945754B4041BB438A0160524084A0A3552D294B403D9D2B4A092D524084A0A3552D294B40
250	Каргатский район	\N	52	79.554890999999998	81.153300000000002	55.644399	54.446596	0103000020E6100000010000000500000010768A5583E353402043C70E2A394B4010768A5583E353409D499BAA7BD24B40849ECDAACF4954409D499BAA7BD24B40849ECDAACF4954402043C70E2A394B4010768A5583E353402043C70E2A394B40
6942	городской округ Обь	\N	52	82.663169999999994	82.749488999999997	55.010958000000002	54.985643000000003	0103000020E610000001000000050000000D6C956071AA54400344C18C297E4B400D6C956071AA544096D05D1267814B408DEDB5A0F7AF544096D05D1267814B408DEDB5A0F7AF54400344C18C297E4B400D6C956071AA54400344C18C297E4B40
6941	городской округ Новосибирск	\N	52	82.739096000000004	83.153794000000005	55.236997000000002	54.810381999999997	0103000020E61000000100000005000000AF264F594DAF54402FA2ED98BA674B40AF264F594DAF54400420EEEA559E4B408C14CAC2D7C954400420EEEA559E4B408C14CAC2D7C954402FA2ED98BA674B40AF264F594DAF54402FA2ED98BA674B40
6896	городской округ Куйбышев	\N	52	78.258227000000005	78.351104000000007	55.467314999999999	55.435805000000002	0103000020E610000001000000050000006EFC89CA8690534076374F75C8B74B406EFC89CA8690534012F758FAD0BB4B40AB5FE97C7896534012F758FAD0BB4B40AB5FE97C7896534076374F75C8B74B406EFC89CA8690534076374F75C8B74B40
1771	городской округ Бердск	\N	52	83.002194000000003	83.167492999999993	54.809598999999999	54.698498999999998	0103000020E61000000100000005000000D68F4DF223C05440F4A44C6A68594B40D68F4DF223C05440E9EFA5F0A0674B40C5538F34B8CA5440E9EFA5F0A0674B40C5538F34B8CA5440F4A44C6A68594B40D68F4DF223C05440F4A44C6A68594B40
6939	городской округ Барабинск	\N	52	78.292587999999995	78.387197999999998	55.367203000000003	55.336872	0103000020E61000000100000005000000EECC04C3B99253401478279F1EAB4B40EECC04C3B99253401EFF058200AF4B40E7C41EDAC79853401EFF058200AF4B40E7C41EDAC79853401478279F1EAB4B40EECC04C3B99253401478279F1EAB4B40
2649	Юсьвинский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
5877	Щекинский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
3985	Чухломский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1423	Чулымский район	\N	52	80.452695000000006	82.140592999999996	55.974896999999999	54.431296000000003	0103000020E61000000100000005000000040473F4F81C5440A47213B534374B40040473F4F81C5440F8FBC56CC9FC4B40FA42C879FF885440F8FBC56CC9FC4B40FA42C879FF885440A47213B534374B40040473F4F81C5440A47213B534374B40
1609	Чистоозерный район	\N	52	75.689396000000002	77.223196999999999	55.061698999999997	54.122996000000001	0103000020E61000000100000005000000917F66101FEC5240F8C43A55BE0F4B40917F66101FEC52401399B9C0E5874B402EE411DC484E53401399B9C0E5874B402EE411DC484E5340F8C43A55BE0F4B40917F66101FEC5240F8C43A55BE0F4B40
4853	Черняховский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
2685	Череповецкий район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1505	Черепановский район	\N	52	82.637793000000002	84.011495999999994	54.481395999999997	53.934466999999998	0103000020E610000001000000050000008927BB99D1A854407A185A9D9CF74A408927BB99D1A854406D3656629E3D4B403A02B859BC0055406D3656629E3D4B403A02B859BC0055407A185A9D9CF74A408927BB99D1A854407A185A9D9CF74A40
467	Чановский район	\N	52	76.202692999999996	77.848091999999994	55.608795000000001	54.722195999999997	0103000020E6100000010000000500000033880FECF80C5340A8A624EB705C4B4033880FECF80C5340F27B9BFEECCD4B40F3FFAA2347765340F27B9BFEECCD4B40F3FFAA2347765340A8A624EB705C4B4033880FECF80C5340A8A624EB705C4B40
1204	Усть-Таркский район	\N	52	75.088431999999997	76.414389999999997	56.165197999999997	55.402898999999998	0103000020E61000000100000005000000DFFAB0DEA8C55240A94BC63192B34B40DFFAB0DEA8C55240ABAE433525154C408672A25D851A5340ABAE433525154C408672A25D851A5340A94BC63192B34B40DFFAB0DEA8C55240A94BC63192B34B40
5442	Увельский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1091	Убинский район	\N	52	78.905390999999995	81.790295	56.537596999999998	54.788699000000001	0103000020E61000000100000005000000EFC517EDF1B95340A7B1BD16F4644B40EFC517EDF1B95340BFB67EFACF444C404FCC7A3194725440BFB67EFACF444C404FCC7A3194725440A7B1BD16F4644B40EFC517EDF1B95340A7B1BD16F4644B40
5368	Тонкинский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
3763	Томаринский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
843	Тогучинский район	\N	52	83.394300000000001	85.087048999999993	55.499499	54.537394999999997	0103000020E61000000100000005000000053411363CD954405704FF5BC9444B40053411363CD954403EB14E95EFBF4B409109F835924555403EB14E95EFBF4B409109F835924555405704FF5BC9444B40053411363CD954405704FF5BC9444B40
315	Татарский район	\N	52	75.095843000000002	76.465198999999998	55.568100000000001	54.672435	0103000020E610000001000000050000003CA3AD4A22C65240C7D79E5912564B403CA3AD4A22C65240C66D3480B7C84B4071C806D2C51D5340C66D3480B7C84B4071C806D2C51D5340C7D79E5912564B403CA3AD4A22C65240C7D79E5912564B40
33	Сузунский район	\N	52	81.714889999999997	83.047469000000007	54.409399000000001	53.494301999999998	0103000020E61000000100000005000000328FFCC1C06D5440772CB64945BF4A40328FFCC1C06D5440EF01BA2F67344B40BAA46ABB09C35440EF01BA2F67344B40BAA46ABB09C35440772CB64945BF4A40328FFCC1C06D5440772CB64945BF4A40
3428	Стародубский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1376	Северный район	\N	52	77.286996000000002	80.555749000000006	57.112099000000001	55.727297999999998	0103000020E610000001000000050000004D8578245E5253401D39D21918DD4B404D8578245E52534008759142598E4C4039F240649123544008759142598E4C4039F24064912354401D39D21918DD4B404D8578245E5253401D39D21918DD4B40
3594	Сафоновский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
4868	Рассказовский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1819	Ордынский район	\N	52	80.950792000000007	82.506791000000007	54.737299	53.905557000000002	0103000020E610000001000000050000001A53B0C6D93C5440FAD4B14AE9F34A401A53B0C6D93C5440CF2F4AD05F5E4B400FBA84436FA05440CF2F4AD05F5E4B400FBA84436FA05440FAD4B14AE9F34A401A53B0C6D93C5440FAD4B14AE9F34A40
6418	Омский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1354	Новосибирский район	\N	52	82.190197999999995	83.505196999999995	55.432597000000001	54.569299000000001	0103000020E61000000100000005000000EF703B342C8C5440A05225CADE484B40EF703B342C8C544082ACA7565FB74B406342CC2555E0544082ACA7565FB74B406342CC2555E05440A05225CADE484B40EF703B342C8C5440A05225CADE484B40
4196	Нижнесергинский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1564	Мошковский район	\N	52	82.966898999999998	84.162493999999995	55.617697999999997	55.088799999999999	0103000020E610000001000000050000003FE257ACE1BD544041F163CC5D8B4B403FE257ACE1BD5440FD6662BA10CF4B40F5F23B4D660A5540FD6662BA10CF4B40F5F23B4D660A554041F163CC5D8B4B403FE257ACE1BD544041F163CC5D8B4B40
3083	Мишкинский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1647	Маслянинский район	\N	52	83.758899	85.115679	54.751097000000001	54.110698999999997	0103000020E61000000100000005000000E57D1CCD91F05440965984622B0E4B40E57D1CCD91F05440D68F4DF223604B406075E44867475540D68F4DF223604B406075E44867475540965984622B0E4B40E57D1CCD91F05440965984622B0E4B40
2859	Мантуровский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
3585	Ленинский район	\N	52	82.751105999999993	82.930419000000001	55.045237999999998	54.942019999999999	0103000020E610000001000000050000001475E61E12B05440C616821C94784B401475E61E12B05440AA44D95BCA854B40EE2422FC8BBB5440AA44D95BCA854B40EE2422FC8BBB5440C616821C94784B401475E61E12B05440C616821C94784B40
1555	Кыштовский район	\N	52	75.839692999999997	78.462970999999996	57.232599	56.207298000000002	0103000020E61000000100000005000000876BB587BDF552405B43A9BD881A4C40876BB587BDF55240890AD5CDC59D4C40C5FF1D51A19D5340890AD5CDC59D4C40C5FF1D51A19D53405B43A9BD881A4C40876BB587BDF552405B43A9BD881A4C40
354	Купинский район	\N	52	76.435815000000005	78.244698999999997	54.883296999999999	53.746963000000001	0103000020E61000000100000005000000CD069964E41B53403929CC7B9CDF4A40CD069964E41B5340D4D347E00F714B404A97FE25A98F5340D4D347E00F714B404A97FE25A98F53403929CC7B9CDF4A40CD069964E41B53403929CC7B9CDF4A40
1260	Куйбышевский район	\N	52	77.400992000000002	79.746700000000004	56.189599999999999	55.304098000000003	0103000020E610000001000000050000004A7D59DAA9595340B763EAAEECA64B404A7D59DAA95953402AA913D044184C4016FBCBEEC9EF53402AA913D044184C4016FBCBEEC9EF5340B763EAAEECA64B404A7D59DAA9595340B763EAAEECA64B40
4882	Красноярский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1105	Краснозерский район	\N	52	78.452892000000006	79.941095000000004	54.360495999999998	53.632601999999999	0103000020E61000000100000005000000AF27BA2EFC9C53402DB1321AF9D04A40AF27BA2EFC9C53405E2BA1BB242E4B4077DB85E63AFC53405E2BA1BB242E4B4077DB85E63AFC53402DB1321AF9D04A40AF27BA2EFC9C53402DB1321AF9D04A40
3058	Красногорский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1054	Кочковский район	\N	52	79.837699000000001	81.036491999999996	54.572498000000003	53.917920000000002	0103000020E61000000100000005000000153944DC9CF55340132C0E677EF54A40153944DC9CF5534041834D9D47494B4033A48AE25542544041834D9D47494B4033A48AE255425440132C0E677EF54A40153944DC9CF55340132C0E677EF54A40
829	Коченевский район	\N	52	81.325291000000007	82.821893000000003	55.513697999999998	54.649197999999998	0103000020E61000000100000005000000B9AB5791D1545440765089EB18534B40B9AB5791D1545440A30227DBC0C14B40EDF318E599B45440A30227DBC0C14B40EDF318E599B45440765089EB18534B40B9AB5791D1545440765089EB18534B40
597	Колыванский район	\N	52	81.580169999999995	83.620199	56.545999000000002	55.167997	0103000020E61000000100000005000000B3075A8121655440BE69FAEC80954B40B3075A81216554400953944BE3454C40C3802557B1E754400953944BE3454C40C3802557B1E75440BE69FAEC80954B40B3075A8121655440BE69FAEC80954B40
3692	Каргапольский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
99	Карасукский район	\N	52	77.166954000000004	78.687163999999996	54.301394999999999	53.292881999999999	0103000020E61000000100000005000000EE7BD45FAF4A534025CB49287DA54A40EE7BD45FAF4A5340C616821C94264B4044BFB67EFAAB5340C616821C94264B4044BFB67EFAAB534025CB49287DA54A40EE7BD45FAF4A534025CB49287DA54A40
7467	Калининский район	\N	52	82.918238000000002	83.005742999999995	55.133915000000002	55.053283999999998	0103000020E6100000010000000500000072FC5069C4BA544035B39602D2864B4072FC5069C4BA5440D0B8702024914B40944BE3175EC05440D0B8702024914B40944BE3175EC0544035B39602D2864B4072FC5069C4BA544035B39602D2864B40
1791	Искитимский район	\N	52	82.374792999999997	84.084395000000001	54.989099000000003	54.252999000000003	0103000020E610000001000000050000004371C79BFC975440DA756F4562204B404371C79BFC975440CFC0C8CB9A7E4B408A3C49BA66055540CFC0C8CB9A7E4B408A3C49BA66055540DA756F4562204B404371C79BFC975440DA756F4562204B40
1399	Здвинский район	\N	52	77.952997999999994	79.582792999999995	55.0383	54.247297000000003	0103000020E61000000100000005000000D1C952EBFD7C534010B3976DA71F4B40D1C952EBFD7C5340E9B7AF03E7844B409DD5027B4CE55340E9B7AF03E7844B409DD5027B4CE5534010B3976DA71F4B40D1C952EBFD7C534010B3976DA71F4B40
1400	Доволенский район	\N	52	78.877499	80.396396999999993	54.887300000000003	54.140394999999998	0103000020E6100000010000000500000074D190F128B85340CEC29E76F8114B4074D190F128B85340D3DEE00B93714B40E1CE85915E195440D3DEE00B93714B40E1CE85915E195440CEC29E76F8114B4074D190F128B85340CEC29E76F8114B40
6065	Городецкий район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
3417	Вологодский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1623	Венгеровский район	\N	52	76.140799000000001	77.885795000000002	56.398800000000001	55.479295999999998	0103000020E61000000100000005000000CF13CFD902095340438D429259BD4B40CF13CFD90209534089D2DEE00B334C4076FD82DDB078534089D2DEE00B334C4076FD82DDB0785340438D429259BD4B40CF13CFD902095340438D429259BD4B40
1554	Болотнинский район	\N	52	83.606491000000005	84.783895000000001	56.055900000000001	55.395200000000003	0103000020E610000001000000050000006094A0BFD0E654408AB0E1E995B24B406094A0BFD0E6544057EC2FBB27074C40DE1FEF552B32554057EC2FBB27074C40DE1FEF552B3255408AB0E1E995B24B406094A0BFD0E654408AB0E1E995B24B40
5168	Беловский район	\N	52	75.088431999999997	85.115983999999997	57.235351000000001	53.290545999999999	0103000020E61000000100000005000000DFFAB0DEA8C55240E7FD7F9C30A54A40DFFAB0DEA8C552405B0A48FB1F9E4C40FEB627486C4755405B0A48FB1F9E4C40FEB627486C475540E7FD7F9C30A54A40DFFAB0DEA8C55240E7FD7F9C30A54A40
1326	Барабинский район	\N	52	77.401899	78.985494000000003	55.429195	54.654494999999997	0103000020E61000000100000005000000E35295B6B8595340A032FE7DC6534B40E35295B6B8595340A94D9CDCEFB64B40DF196D5512BF5340A94D9CDCEFB64B40DF196D5512BF5340A032FE7DC6534B40E35295B6B8595340A032FE7DC6534B40
232	Баганский район	\N	52	77.036033000000003	78.347897000000003	54.323996000000001	53.681604	0103000020E61000000100000005000000EA245B5D4E4253405169C4CC3ED74A40EA245B5D4E425340750470B378294B401958C7F143965340750470B378294B401958C7F1439653405169C4CC3ED74A40EA245B5D4E4253405169C4CC3ED74A40
7126	Северо-Енисейский район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
7119	Эвенкийский район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
994	Шушенский район	\N	49	90.488071000000005	92.500297000000003	53.534395000000004	51.900764000000002	0103000020E6100000010000000500000011C8258E3C9F564003B5183C4CF3494011C8258E3C9F5640AE122C0E67C44A405D52B5DD04205740AE122C0E67C44A405D52B5DD0420574003B5183C4CF3494011C8258E3C9F564003B5183C4CF34940
566	Шарыповский район	\N	49	88.599929000000003	89.837996000000004	56.023797000000002	55.003069000000004	0103000020E6100000010000000500000002BB9A3C65265640D350A39064804B4002BB9A3C65265640185FB4C70B034C40728BF9B9A1755640185FB4C70B034C40728BF9B9A1755640D350A39064804B4002BB9A3C65265640D350A39064804B40
729	Уярский район	\N	49	93.834996000000004	94.762399000000002	56.202295999999997	55.549194999999997	0103000020E610000001000000050000009D12109370755740381092054CC64B409D12109370755740490ED8D5E4194C4033E02C25CBB05740490ED8D5E4194C4033E02C25CBB05740381092054CC64B409D12109370755740381092054CC64B40
476	Ужурский район	\N	49	89.315697999999998	90.779996999999995	55.684797000000003	55.055697000000002	0103000020E61000000100000005000000685A6265345456401FBE4C1421874B40685A62653454564010B3976DA7D74B40997E8978EBB1564010B3976DA7D74B40997E8978EBB156401FBE4C1421874B40685A6265345456401FBE4C1421874B40
336	Тюхтетский район	\N	49	88.502533999999997	90.050196	57.865597000000001	56.353898999999998	0103000020E6100000010000000500000032C85D8429205640268BFB8F4C2D4C4032C85D84292056400342EBE1CBEE4C40F6984869368356400342EBE1CBEE4C40F698486936835640268BFB8F4C2D4C4032C85D8429205640268BFB8F4C2D4C40
7483	Туруханский район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
7492	Тунгусско-Чунский район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
93	Тасеевский район	\N	49	93.744598999999994	96.123992999999999	57.854498	56.876697	0103000020E6100000010000000500000098689082A76F57402BC0779B37704C4098689082A76F5740AB3FC23060ED4C40B5FB5580EF075840AB3FC23060ED4C40B5FB5580EF0758402BC0779B37704C4098689082A76F57402BC0779B37704C40
7120	Таймырский Долгано-Ненцкий район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
7490	Таймырский Долгано-Ненецкий район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
7121	Таймырский Долгано-Ненецкий муниципальный район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
7122	Сухобузимский район  	\N	49	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
1147	Сухобузимский район	\N	49	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
7118	Сухобузимский	\N	49	92.505291999999997	94.716199000000003	56.959097	56.202295999999997	0103000020E610000001000000050000008CBB41B456205740490ED8D5E4194C408CBB41B4562057408A58C4B0C37A4C40639B5434D6AD57408A58C4B0C37A4C40639B5434D6AD5740490ED8D5E4194C408CBB41B456205740490ED8D5E4194C40
252	Саянский район	\N	49	94.144195999999994	95.856098000000003	55.615394999999999	54.233696000000002	0103000020E61000000100000005000000B20DDC813A8957405F9A22C0E91D4B40B20DDC813A8957409B8F6B43C5CE4B40F20A444FCAF657409B8F6B43C5CE4B40F20A444FCAF657405F9A22C0E91D4B40B20DDC813A8957405F9A22C0E91D4B40
1113	Рыбинский район	\N	49	94.071692999999996	95.468492999999995	56.421798000000003	55.511097999999997	0103000020E6100000010000000500000089963C9E968457408786C5A86BC14B4089963C9E9684574055C2137AFD354C40EA5910CAFBDD574055C2137AFD354C40EA5910CAFBDD57408786C5A86BC14B4089963C9E968457408786C5A86BC14B40
1795	Пировский район	\N	49	91.187894999999997	92.762399000000002	58.000660000000003	57.010396	0103000020E610000001000000050000003E05C07806CC56402E01F8A754814C403E05C07806CC56402B357BA015004D4033E02C25CB3057402B357BA015004D4033E02C25CB3057402E01F8A754814C403E05C07806CC56402E01F8A754814C40
1513	Партизанский район	\N	49	93.565897000000007	94.957898999999998	55.619798000000003	54.414496999999997	0103000020E61000000100000005000000E4F90CA83764574022A5D93C0E354B40E4F90CA8376457402810768A55CF4B40C0779B374EBD57402810768A55CF4B40C0779B374EBD574022A5D93C0E354B40E4F90CA83764574022A5D93C0E354B40
1737	Новоселовский район	\N	49	90.498149999999995	91.788094999999998	55.249099000000001	54.627198999999997	0103000020E6100000010000000500000027A089B0E19F5640BD8A8C0E48504B4027A089B0E19F5640B03BDD79E29F4B4008C9022670F25640B03BDD79E29F4B4008C9022670F25640BD8A8C0E48504B4027A089B0E19F5640BD8A8C0E48504B40
1163	Нижнеингашский район	\N	49	96.206098999999995	97.879992999999999	56.826611	55.815398000000002	0103000020E61000000100000005000000402FDCB9300D5840A69C2FF65EE84B40402FDCB9300D5840C6C1A563CE694C405FED28CE51785840C6C1A563CE694C405FED28CE51785840A69C2FF65EE84B40402FDCB9300D5840A69C2FF65EE84B40
79	Назаровский район	\N	49	89.602198000000001	91.107692999999998	56.104998000000002	55.502496999999998	0103000020E61000000100000005000000DDED7A698A66564047AB5AD251C04B40DDED7A698A6656409D121093700D4C4085402E71E4C656409D121093700D4C4085402E71E4C6564047AB5AD251C04B40DDED7A698A66564047AB5AD251C04B40
1541	Мотыгинский район	\N	49	93.244479999999996	95.564684	58.000765000000001	57.726799	0103000020E61000000100000005000000AB21718FA54F5740FCE1E7BF07DD4C40AB21718FA54F5740A0FD481119004D40C4245CC823E45740A0FD481119004D40C4245CC823E45740FCE1E7BF07DD4C40AB21718FA54F5740FCE1E7BF07DD4C40
1439	Минусинский район	\N	49	91.424627999999998	92.644693000000004	54.032997999999999	53.463943999999998	0103000020E61000000100000005000000D13DEB1A2DDB56407496598462BB4A40D13DEB1A2DDB5640AD6A494739044B4073BD6DA642295740AD6A494739044B4073BD6DA6422957407496598462BB4A40D13DEB1A2DDB56407496598462BB4A40
1366	Манский район	\N	49	93.169990999999996	94.165693000000005	56.085298999999999	54.703097999999997	0103000020E610000001000000050000005167EE21E14A574006F1811DFF594B405167EE21E14A5740D5B0DF13EB0A4C40460BD0B69A8A5740D5B0DF13EB0A4C40460BD0B69A8A574006F1811DFF594B405167EE21E14A574006F1811DFF594B40
7127	Ленинский	\N	49	92.938513999999998	93.113523000000001	56.076402999999999	55.973022999999998	0103000020E61000000100000005000000A435069D103C5740BEA085048CFC4B40A435069D103C57407C28D192C7094C400116F9F5434757407C28D192C7094C400116F9F543475740BEA085048CFC4B40A435069D103C5740BEA085048CFC4B40
1068	Курагинский район	\N	49	92.152199999999993	96.685323999999994	54.913696000000002	53.363897000000001	0103000020E61000000100000005000000E09C11A5BD095740670E492D94AE4A40E09C11A5BD095740363E93FDF3744B407DCA3159DC2B5840363E93FDF3744B407DCA3159DC2B5840670E492D94AE4A40E09C11A5BD095740670E492D94AE4A40
1149	Краснотуранский район	\N	49	90.978793999999994	92.261992000000006	54.905999999999999	53.936799000000001	0103000020E6100000010000000500000058E1968FA4BE564077F69507E9F74A4058E1968FA4BE56408716D9CEF7734B4013F4177AC41057408716D9CEF7734B4013F4177AC410574077F69507E9F74A4058E1968FA4BE564077F69507E9F74A40
1080	Козульский район	\N	49	90.901394999999994	91.952198999999993	56.862898000000001	55.633794999999999	0103000020E61000000100000005000000C971A774B0B9564025AFCE3120D14B40C971A774B0B9564054E41071736E4C402B1213D4F0FC564054E41071736E4C402B1213D4F0FC564025AFCE3120D14B40C971A774B0B9564025AFCE3120D14B40
1013	Кежемский район	\N	49	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
936	Каратузский район	\N	49	92.385797999999994	94.711797000000004	53.859000000000002	52.802098999999998	0103000020E610000001000000050000002E3718EAB0185740C093162EAB664A402E3718EAB0185740CBA145B6F3ED4A40051901158EAD5740CBA145B6F3ED4A40051901158EAD5740C093162EAB664A402E3718EAB0185740C093162EAB664A40
723	Канский район	\N	49	94.500198999999995	95.910499999999999	56.630600000000001	55.708998000000001	0103000020E610000001000000050000007B9FAA4203A05740F7764B72C0DA4B407B9FAA4203A05740C66D3480B7504C4083C0CAA145FA5740C66D3480B7504C4083C0CAA145FA5740F7764B72C0DA4B407B9FAA4203A05740F7764B72C0DA4B40
581	Казачинский район	\N	49	92.422899000000001	94.245391999999995	57.979396999999999	57.222498999999999	0103000020E61000000100000005000000B6A0F7C6101B57404432E4D87A9C4C40B6A0F7C6101B5740776682E15CFD4C40CDACA580B48F5740776682E15CFD4C40CDACA580B48F57404432E4D87A9C4C40B6A0F7C6101B57404432E4D87A9C4C40
272	Ирбейский район	\N	49	95.005392999999998	96.938396999999995	55.899698999999998	54.391767000000002	0103000020E6100000010000000500000026A8E15B58C057407653CA6B25324B4026A8E15B58C05740389F3A5629F34B40876A4AB20E3C5840389F3A5629F34B40876A4AB20E3C58407653CA6B25324B4026A8E15B58C057407653CA6B25324B40
7493	Илимпийский район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
83	Иланский район	\N	49	95.711693999999994	96.838584999999995	56.492597000000004	55.568399999999997	0103000020E610000001000000050000009AB0FD648CED5740F085C954C1C84B409AB0FD648CED5740CA8D226B0D3F4C40A27A6B60AB355840CA8D226B0D3F4C40A27A6B60AB355840F085C954C1C84B409AB0FD648CED5740F085C954C1C84B40
1187	Идринский район	\N	49	91.765996000000001	93.304793000000004	54.945898	54.123196	0103000020E610000001000000050000007A37161406F15640BF7FF3E2C40F4B407A37161406F1564008AD872F13794B402FC37FBA8153574008AD872F13794B402FC37FBA81535740BF7FF3E2C40F4B407A37161406F15640BF7FF3E2C40F4B40
1722	Ермаковский район	\N	49	91.095224000000002	94.140090999999998	53.433897000000002	51.772517999999998	0103000020E61000000100000005000000D672672618C6564021C9ACDEE1E24940D672672618C65640906AD8EF89B74A40B1DD3D40F7885740906AD8EF89B74A40B1DD3D40F788574021C9ACDEE1E24940D672672618C6564021C9ACDEE1E24940
1509	Енисейский район	\N	49	88.764634999999998	93.245898999999994	58.000765000000001	57.594496999999997	0103000020E610000001000000050000002098A3C7EF305640F9484A7A18CC4C402098A3C7EF305640A0FD481119004D409FC728CFBC4F5740A0FD481119004D409FC728CFBC4F5740F9484A7A18CC4C402098A3C7EF305640F9484A7A18CC4C40
202	Емельяновский район	\N	49	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
7125	Емельяновский	\N	49	91.596799000000004	93.594894999999994	56.923797999999998	55.675995999999998	0103000020E6100000010000000500000046D26EF431E65640081D740987D64B4046D26EF431E656401B0E4B033F764C4073637AC2126657401B0E4B033F764C4073637AC212665740081D740987D64B4046D26EF431E65640081D740987D64B40
7495	Диксонский район	\N	49	88.501429000000002	99.639540999999994	58.000765000000001	51.772233999999997	0103000020E610000001000000050000000611A96917205640FC6D4F90D8E249400611A96917205640A0FD481119004D40DFDC5F3DEEE85840A0FD481119004D40DFDC5F3DEEE85840FC6D4F90D8E249400611A96917205640FC6D4F90D8E24940
822	Дзержинский район	\N	49	94.333292	95.801597000000001	57.136699	56.542495000000002	0103000020E610000001000000050000002E01F8A7549557402C9FE57970454C402E01F8A754955740AD32535A7F914C4097E4805D4DF35740AD32535A7F914C4097E4805D4DF357402C9FE57970454C402E01F8A7549557402C9FE57970454C40
875	Большеулуйский район	\N	49	89.960499999999996	91.398397000000003	56.880996000000003	56.390698999999998	0103000020E61000000100000005000000B6F3FDD4787D56403ACAC16C02324C40B6F3FDD4787D564013F4177AC4704C40C57421567FD9564013F4177AC4704C40C57421567FD956403ACAC16C02324C40B6F3FDD4787D56403ACAC16C02324C40
1460	Большемуртинский район	\N	49	91.833297999999999	94.175098000000006	57.425297	56.653798000000002	0103000020E610000001000000050000009F7422C154F55640591822A7AF534C409F7422C154F55640200BD12170B64C4015E63DCE348B5740200BD12170B64C4015E63DCE348B5740591822A7AF534C409F7422C154F55640591822A7AF534C40
1558	Богучанский район	\N	49	95.235596000000001	99.510112000000007	58.000765000000001	57.132131999999999	0103000020E6100000010000000500000061C43E0114CF5740A6608DB3E9904C4061C43E0114CF5740A0FD481119004D400553CDACA5E05840A0FD481119004D400553CDACA5E05840A6608DB3E9904C4061C43E0114CF5740A6608DB3E9904C40
1396	Боготольский район	\N	49	88.876897999999997	90.309594000000004	56.550797000000003	55.941400000000002	0103000020E6100000010000000500000061FBC9181F3856402A3A92CB7FF84B4061FBC9181F38564012DE1E8480464C406C425A63D093564012DE1E8480464C406C425A63D09356402A3A92CB7FF84B4061FBC9181F3856402A3A92CB7FF84B40
7494	Боготолькский район	\N	49	88.876897999999997	90.309594000000004	56.550797000000003	55.941400000000002	0103000020E6100000010000000500000061FBC9181F3856402A3A92CB7FF84B4061FBC9181F38564012DE1E8480464C406C425A63D093564012DE1E8480464C406C425A63D09356402A3A92CB7FF84B4061FBC9181F3856402A3A92CB7FF84B40
1352	Бирилюсский район	\N	49	89.608998	91.913392000000002	57.976996999999997	56.554096000000001	0103000020E610000001000000050000001555BFD2F9665640166C239EEC464C401555BFD2F966564022A5D93C0EFD4C40651BB80375FA564022A5D93C0EFD4C40651BB80375FA5640166C239EEC464C401555BFD2F9665640166C239EEC464C40
493	Березовский район	\N	49	92.230892999999995	94.071692999999996	56.374696	55.229897000000001	0103000020E6100000010000000500000005F86EF3C60E57406939D0436D9D4B4005F86EF3C60E574094F8DC09F62F4C4089963C9E9684574094F8DC09F62F4C4089963C9E968457406939D0436D9D4B4005F86EF3C60E57406939D0436D9D4B40
465	Балахтинский район	\N	49	90.607896999999994	93.288595999999998	55.771296999999997	54.763399	0103000020E610000001000000050000008995D1C8E7A656404966F50EB7614B408995D1C8E7A656405F402FDCB9E24B4069705B5B785257405F402FDCB9E24B4069705B5B785257404966F50EB7614B408995D1C8E7A656404966F50EB7614B40
1133	Ачинский район	\N	49	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
7123	Ачинский	\N	49	90.057895000000002	91.314493999999996	56.564498999999998	55.999999000000003	0103000020E6100000010000000500000086E63A8DB483564030849CF7FFFF4B4086E63A8DB4835640F6CFD38041484C40723271AB20D45640F6CFD38041484C40723271AB20D4564030849CF7FFFF4B4086E63A8DB483564030849CF7FFFF4B40
955	Абанский район	\N	49	95.537492	97.672797000000003	57.578499000000001	56.424695	0103000020E610000001000000050000002577D84466E257402AE3DF675C364C402577D84466E2574065E256410CCA4C4034F6251B0F6B584065E256410CCA4C4034F6251B0F6B58402AE3DF675C364C402577D84466E257402AE3DF675C364C40
7124	 Кежемский район	\N	49	98.915760000000006	99.632400000000004	58.000740999999998	57.780588999999999	0103000020E610000001000000050000000ABFD4CF9BBA5840054F2157EAE34C400ABFD4CF9BBA58401762F54718004D40637FD93D79E858401762F54718004D40637FD93D79E85840054F2157EAE34C400ABFD4CF9BBA5840054F2157EAE34C40
7401	городской округ Киселевск	\N	51	86.480399000000006	86.781694000000002	54.083897999999998	53.928800000000003	0103000020E61000000100000005000000FE8172DBBE9E55402D431CEBE2F64A40FE8172DBBE9E554093196F2BBD0A4B40AF5E454607B2554093196F2BBD0A4B40AF5E454607B255402D431CEBE2F64A40FE8172DBBE9E55402D431CEBE2F64A40
890	Беловский район	\N	51	85.866193999999993	87.515995000000004	54.669795000000001	54.107199999999999	0103000020E61000000100000005000000737FF5B86F775540CB10C7BAB80D4B40737FF5B86F7755401D03B2D7BB554B409279E40F06E155401D03B2D7BB554B409279E40F06E15540CB10C7BAB80D4B40737FF5B86F775540CB10C7BAB80D4B40
1434	городской округ Осинники	\N	51	87.2928	87.469992000000005	53.708996999999997	53.583596999999997	0103000020E610000001000000050000003411363CBDD255409885764EB3CA4A403411363CBDD2554026FBE769C0DA4A406D58535914DE554026FBE769C0DA4A406D58535914DE55409885764EB3CA4A403411363CBDD255409885764EB3CA4A40
640	городской округ Мыски	\N	51	87.648892000000004	87.879399000000006	53.763897999999998	53.576898	0103000020E61000000100000005000000B5A84F7287E955405C902DCBD7C94A40B5A84F7287E955406ABDDF68C7E14A40A648BE1248F855406ABDDF68C7E14A40A648BE1248F855405C902DCBD7C94A40B5A84F7287E955405C902DCBD7C94A40
574	Яшкинский район	\N	51	84.888296999999994	86.114192000000003	56.22728	55.603496999999997	0103000020E61000000100000005000000A208A9DBD9385540F71DC3633FCD4B40A208A9DBD93855407784D382171D4C40C05DF6EB4E8755407784D382171D4C40C05DF6EB4E875540F71DC3633FCD4B40A208A9DBD9385540F71DC3633FCD4B40
236	Яйский район	\N	51	85.565653999999995	86.610591999999997	56.633797999999999	55.834598	0103000020E6100000010000000500000080B6D5AC336455404CA7751BD4EA4B4080B6D5AC336455409622F94A20514C40C0CC77F013A755409622F94A20514C40C0CC77F013A755404CA7751BD4EA4B4080B6D5AC336455404CA7751BD4EA4B40
38	Юргинский район	\N	51	84.455848000000003	85.634995000000004	56.162145000000002	55.362997	0103000020E610000001000000050000009CFC169D2C1D5540E7C589AF76AE4B409CFC169D2C1D5540DF1AD82AC1144C40E88711C2A3685540DF1AD82AC1144C40E88711C2A3685540E7C589AF76AE4B409CFC169D2C1D5540E7C589AF76AE4B40
823	Чебулинский район	\N	51	86.832196999999994	88.227497	56.146797999999997	55.420597000000001	0103000020E6100000010000000500000013B534B742B55540DAE55B1FD6B54B4013B534B742B55540218FE046CA124C400ABC934F8F0E5640218FE046CA124C400ABC934F8F0E5640DAE55B1FD6B54B4013B534B742B55540DAE55B1FD6B54B40
1825	Тяжинский район	\N	51	88.139498000000003	89.388892999999996	56.457999999999998	55.702697999999998	0103000020E61000000100000005000000E0F60489ED085640787B1002F2D94B40E0F60489ED085640B4C876BE9F3A4C402C29779FE3585640B4C876BE9F3A4C402C29779FE3585640787B1002F2D94B40E0F60489ED085640787B1002F2D94B40
3787	Тосненский район	\N	51	84.452399	89.402564999999996	56.832393000000003	52.162630999999998	0103000020E610000001000000050000008F6FEF1AF41C55406B28B517D1144A408F6FEF1AF41C5540AD3594DA8B6A4C40E960FD9FC3595640AD3594DA8B6A4C40E960FD9FC35956406B28B517D1144A408F6FEF1AF41C55406B28B517D1144A40
1748	Топкинский район	\N	51	84.825900000000004	86.068899000000002	55.644100000000002	55.068896000000002	0103000020E610000001000000050000000D71AC8BDB345540A1698995D1884B400D71AC8BDB34554043AD69DE71D24B4089EE59D76884554043AD69DE71D24B4089EE59D768845540A1698995D1884B400D71AC8BDB345540A1698995D1884B40
860	Тисульский район	\N	51	86.878793000000002	89.136995999999996	55.969299999999997	54.606596000000003	0103000020E610000001000000050000000ABDFE243EB8554035F10EF0A44D4B400ABDFE243EB85540A301BC0512FC4B40B3EBDE8AC4485640A301BC0512FC4B40B3EBDE8AC448564035F10EF0A44D4B400ABDFE243EB8554035F10EF0A44D4B40
1653	Таштагольский район	\N	51	86.918193000000002	89.239817000000002	53.357798000000003	52.162630999999998	0103000020E61000000100000005000000A29A92ACC3BA55406B28B517D1144A40A29A92ACC3BA554080492A53CCAD4A4097016729594F564080492A53CCAD4A4097016729594F56406B28B517D1144A40A29A92ACC3BA55406B28B517D1144A40
868	Промышленновский район	\N	51	84.840892999999994	86.204993999999999	55.199598999999999	54.576698999999998	0103000020E61000000100000005000000DC9BDF30D13555406551D845D1494B40DC9BDF30D13555403BA8C4758C994B401478279F1E8D55403BA8C4758C994B401478279F1E8D55406551D845D1494B40DC9BDF30D13555406551D845D1494B40
771	Прокопьевский район	\N	51	86.015692000000001	87.459698000000003	54.391599999999997	53.575198	0103000020E61000000100000005000000C4B3041901815540C05C8B16A0C94A40C4B30419018155408A8EE4F21F324B40580229B16BDD55408A8EE4F21F324B40580229B16BDD5540C05C8B16A0C94A40C4B3041901815540C05C8B16A0C94A40
632	Новокузнецкий район	\N	51	86.496191999999994	88.620643999999999	54.833199999999998	52.889898000000002	0103000020E610000001000000050000005B22179CC19F55404E637B2DE8714A405B22179CC19F55407B832F4CA66A4B405A9D9CA1B82756407B832F4CA66A4B405A9D9CA1B82756404E637B2DE8714A405B22179CC19F55404E637B2DE8714A40
285	Междуреченский район	\N	51	87.855298000000005	89.240509000000003	54.416200000000003	53.109195	0103000020E610000001000000050000006495D233BDF6554080F10C1AFA8D4A406495D233BDF65540304CA60A46354B403259DC7F644F5640304CA60A46354B403259DC7F644F564080F10C1AFA8D4A406495D233BDF6554080F10C1AFA8D4A40
815	Мариинский район	\N	51	86.927293000000006	88.735144000000005	56.832393000000003	55.941696999999998	0103000020E61000000100000005000000D333BDC458BB5540E3DEFC8689F84B40D333BDC458BB5540AD3594DA8B6A4C4071766B990C2F5640AD3594DA8B6A4C4071766B990C2F5640E3DEFC8689F84B40D333BDC458BB5540E3DEFC8689F84B40
35	Ленинск-Кузнецкий район	\N	51	85.195098999999999	86.572592999999998	54.973697999999999	54.350096000000001	0103000020E61000000100000005000000DE1E84807C4C5540EF3A1BF2CF2C4B40DE1E84807C4C55401E17D522A27C4B40C93A1C5DA5A455401E17D522A27C4B40C93A1C5DA5A45540EF3A1BF2CF2C4B40DE1E84807C4C5540EF3A1BF2CF2C4B40
613	Крапивинский район	\N	51	86.039991000000001	88.145596999999995	55.437097000000001	54.532699000000001	0103000020E61000000100000005000000994869368F82554053CE177B2F444B40994869368F825540011764CBF2B74B405359147651095640011764CBF2B74B40535914765109564053CE177B2F444B40994869368F82554053CE177B2F444B40
7515	Киселевский городской округ	\N	51	87.123844000000005	87.125703999999999	53.740093999999999	53.737985000000002	0103000020E610000001000000050000009373620FEDC7554023F8DF4A76DE4A409373620FEDC75540A0FB7266BBDE4A407D3ECA880BC85540A0FB7266BBDE4A407D3ECA880BC8554023F8DF4A76DE4A409373620FEDC7554023F8DF4A76DE4A40
384	Кемеровский район	\N	51	85.729478999999998	86.659101000000007	55.866556000000003	55.104754	0103000020E610000001000000050000009A07B0C8AF6E554006103E94688D4B409A07B0C8AF6E55408813984EEBEE4B40B3F0F5B52EAA55408813984EEBEE4B40B3F0F5B52EAA554006103E94688D4B409A07B0C8AF6E554006103E94688D4B40
7521	Калтан	\N	51	87.205331000000001	87.308322000000004	53.577432999999999	53.496384999999997	0103000020E61000000100000005000000B876A22424CD5540CB9C2E8B89BF4A40B876A22424CD5540CA501553E9C94A40CAA8328CBBD35540CA501553E9C94A40CAA8328CBBD35540CB9C2E8B89BF4A40B876A22424CD5540CB9C2E8B89BF4A40
26	Ижморский район	\N	51	86.274891999999994	87.289691000000005	56.637996000000001	55.632595999999999	0103000020E61000000100000005000000A67B9DD4979155404BCADDE7F8D04B40A67B9DD4979155404A7D59DAA9514C4084BC1E4C8AD255404A7D59DAA9514C4084BC1E4C8AD255404BCADDE7F8D04B40A67B9DD4979155404BCADDE7F8D04B40
1192	Гурьевский район	\N	51	84.935198	86.173095000000004	54.653396000000001	54.010184000000002	0103000020E610000001000000050000003752B648DA3B5540A37895B54D014B403752B648DA3B55402AABE97AA2534B4079060DFD138B55402AABE97AA2534B4079060DFD138B5540A37895B54D014B403752B648DA3B5540A37895B54D014B40
7465	городской округ Шелехов	\N	50	104.07950099999999	104.131935	52.229993999999998	52.199066000000002	0103000020E61000000100000005000000F4BF5C8B16055A406EDFA3FE7A194A40F4BF5C8B16055A405B238271701D4A40A88C7F9F71085A405B238271701D4A40A88C7F9F71085A406EDFA3FE7A194A40F4BF5C8B16055A406EDFA3FE7A194A40
7464	городской округ Нижнеудинск	\N	50	99.000434999999996	99.077088000000003	54.933630999999998	54.877935999999998	0103000020E6100000010000000500000085B1852007C0584093FDF33460704B4085B1852007C0584011C4793881774B4080BA8102EFC4584011C4793881774B4080BA8102EFC4584093FDF33460704B4085B1852007C0584093FDF33460704B40
7469	городской округ Зима	\N	50	102.02002299999999	102.083049	53.943271000000003	53.890818000000003	0103000020E61000000100000005000000BD8A8C0E488159401558005306F24A40BD8A8C0E48815940F321A81ABDF84A40CBBDC0AC50855940F321A81ABDF84A40CBBDC0AC508559401558005306F24A40BD8A8C0E488159401558005306F24A40
275	Эхирит-Булагатский район	\N	50	104.317294	105.588095	53.446100000000001	52.381594999999997	0103000020E61000000100000005000000E44D7E8B4E145A4097A8DE1AD8304A40E44D7E8B4E145A40705F07CE19B94A403BFC3559A3655A40705F07CE19B94A403BFC3559A3655A4097A8DE1AD8304A40E44D7E8B4E145A4097A8DE1AD8304A40
1786	Шелеховский район	\N	50	103.470793	104.223294	52.286496999999997	51.801794999999998	0103000020E61000000100000005000000E38BF67821DE5940548CF337A1E64940E38BF67821DE594078B306EFAB244A4027D9EA724A0E5A4078B306EFAB244A4027D9EA724A0E5A40548CF337A1E64940E38BF67821DE5940548CF337A1E64940
294	Чунский район	\N	50	98.629690999999994	100.857495	58.083615999999999	55.560198999999997	0103000020E6100000010000000500000079E57ADB4CA858403E20D099B4C74B4079E57ADB4CA858400FB6D8EDB30A4D40F25EB532E13659400FB6D8EDB30A4D40F25EB532E13659403E20D099B4C74B4079E57ADB4CA858403E20D099B4C74B40
174	Черемховский район	\N	50	101.072318	103.493898	53.314895999999997	52.214100000000002	0103000020E61000000100000005000000603AADDBA04459406C09F9A0671B4A40603AADDBA044594013D21A834EA84A40D4635B069CDF594013D21A834EA84A40D4635B069CDF59406C09F9A0671B4A40603AADDBA04459406C09F9A0671B4A40
212	Усть-Удинский район	\N	50	102.98299900000001	105.078095	56.381500000000003	53.607596000000001	0103000020E610000001000000050000000C40A374E9BE59401897AAB4C5CD4A400C40A374E9BE594046B6F3FDD4304C40CBBE2B82FF445A4046B6F3FDD4304C40CBBE2B82FF445A401897AAB4C5CD4A400C40A374E9BE59401897AAB4C5CD4A40
7466	Усть-Кутский район	\N	50	104.239293	107.328599	58.104075000000002	55.698396000000002	0103000020E610000001000000050000005A4A9693500F5A4020D4450A65D94B405A4A9693500F5A4065AA6054520D4D40E49F19C407D55A4065AA6054520D4D40E49F19C407D55A4020D4450A65D94B405A4A9693500F5A4020D4450A65D94B40
331	Усть-Илимский район	\N	50	100.56989900000001	104.84589800000001	59.315798999999998	56.710500000000003	0103000020E610000001000000050000007BC1A739792459406DE7FBA9F15A4C407BC1A73979245940048E041A6CA84D401E705D3123365A40048E041A6CA84D401E705D3123365A406DE7FBA9F15A4C407BC1A739792459406DE7FBA9F15A4C40
1227	Усольский район	\N	50	102.44779200000001	103.919196	53.015197000000001	51.862098000000003	0103000020E6100000010000000500000045DAC69FA89C594038F92D3A59EE494045DAC69FA89C5940A8FFACF9F1814A404CA7751BD4FA5940A8FFACF9F1814A404CA7751BD4FA594038F92D3A59EE494045DAC69FA89C594038F92D3A59EE4940
307	Тулунский район	\N	50	99.237797	101.103696	55.078797999999999	53.233597000000003	0103000020E610000001000000050000009085E81038CF5840CCB8A981E69D4A409085E81038CF5840BF7E880D168A4B40772E8CF4A2465940BF7E880D168A4B40772E8CF4A2465940CCB8A981E69D4A409085E81038CF5840CCB8A981E69D4A40
139	Тайшетский район	\N	50	96.595096999999996	99.033798000000004	57.831882999999998	54.639496999999999	0103000020E61000000100000005000000A73CBA1116265840EF71A609DB514B40A73CBA1116265840978C63247BEA4C40E52A16BF29C25840978C63247BEA4C40E52A16BF29C25840EF71A609DB514B40A73CBA1116265840EF71A609DB514B40
235	Слюдянский район	\N	50	102.85699200000001	104.827393	51.994895999999997	51.133994999999999	0103000020E61000000100000005000000C13BF9F4D8B65940EC6987BF26914940C13BF9F4D8B65940EA758BC058FF49401EFCC401F4345A40EA758BC058FF49401EFCC401F4345A40EC6987BF26914940C13BF9F4D8B65940EC6987BF26914940
7	Осинский район	\N	50	103.34820000000001	104.755797	54.064895	53.229899000000003	0103000020E61000000100000005000000E71DA7E848D659400A3197546D9D4A40E71DA7E848D659404356B77A4E084B408E5A61FA5E305A404356B77A4E084B408E5A61FA5E305A400A3197546D9D4A40E71DA7E848D659400A3197546D9D4A40
516	Ольхонский район	\N	50	105.32049600000001	108.659193	54.542299999999997	52.485795000000003	0103000020E61000000100000005000000ED9FA70183545A40B9C7D2872E3E4A40ED9FA70183545A40764F1E166A454B402330D637302A5B40764F1E166A454B402330D637302A5B40B9C7D2872E3E4A40ED9FA70183545A40B9C7D2872E3E4A40
155	Нукутский район	\N	50	102.33099300000001	103.377099	54.072498000000003	53.443396999999997	0103000020E610000001000000050000001E8D43FD2E9559407F129F3BC1B84A401E8D43FD2E95594041834D9D47094B40AD16D86322D8594041834D9D47094B40AD16D86322D859407F129F3BC1B84A401E8D43FD2E9559407F129F3BC1B84A40
282	Нижнеудинский район	\N	50	95.655395999999996	100.205399	55.952500000000001	52.970999999999997	0103000020E61000000100000005000000787B1002F2E957403F355EBA497C4A40787B1002F2E9574052B81E85EBF94B4064E8D841250D594052B81E85EBF94B4064E8D841250D59403F355EBA497C4A40787B1002F2E957403F355EBA497C4A40
1713	Нижнеилимский район	\N	50	102.53799100000001	105.050292	57.820898999999997	55.811599000000001	0103000020E61000000100000005000000B6A2CD716EA25940B03BDD79E2E74B40B6A2CD716EA25940D828EB3713E94C4007D0EFFB37435A40D828EB3713E94C4007D0EFFB37435A40B03BDD79E2E74B40B6A2CD716EA25940B03BDD79E2E74B40
7474	Мамско-Чуйский район	\N	50	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
113	Куйтунский район	\N	50	100.592995	102.59249199999999	55.199696000000003	53.720996999999997	0103000020E6100000010000000500000042EC4CA1F3255940CEC133A149DC4A4042EC4CA1F32559402E9276A38F994B4010C99063EBA559402E9276A38F994B4010C99063EBA55940CEC133A149DC4A4042EC4CA1F3255940CEC133A149DC4A40
7470	Киренский район	\N	50	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
905	Качугский район	\N	50	104.395393	108.643598	54.9679	53.217396999999998	0103000020E610000001000000050000004F04711E4E195A40CF9F36AAD39B4A404F04711E4E195A4032E6AE25E47B4B405871AAB530295B4032E6AE25E47B4B405871AAB530295B40CF9F36AAD39B4A404F04711E4E195A40CF9F36AAD39B4A40
7473	Катангский район	\N	50	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
1344	Казачинско-Ленский район	\N	50	106.594891	109.257695	57.140127999999997	54.631618000000003	0103000020E61000000100000005000000D36BB3B112A65A4050C8CEDBD8504B40D36BB3B112A65A407FA0DCB6EF914C40EF552B137E505B407FA0DCB6EF914C40EF552B137E505B4050C8CEDBD8504B40D36BB3B112A65A4050C8CEDBD8504B40
425	Иркутский район	\N	50	103.835994	106.018092	53.049399999999999	51.797199999999997	0103000020E61000000100000005000000BE69FAEC80F55940832F4CA60AE64940BE69FAEC80F5594011363CBD52864A406E14596B28815A4011363CBD52864A406E14596B28815A40832F4CA60AE64940BE69FAEC80F55940832F4CA60AE64940
7471	Иркутская область	\N	50	95.645173	109.26647199999999	59.318250999999997	51.129857000000001	0103000020E61000000100000005000000C8D0B1834AE957400E1478279F904940C8D0B1834AE95740AB75E272BCA84D402E5393E00D515B40AB75E272BCA84D402E5393E00D515B400E1478279F904940C8D0B1834AE957400E1478279F904940
10	Зиминский район	\N	50	100.403496	102.674796	54.497895999999997	53.254897999999997	0103000020E610000001000000050000004704E3E0D21959406CE8667FA0A04A404704E3E0D219594094675E0EBB3F4B402FDE8FDB2FAB594094675E0EBB3F4B402FDE8FDB2FAB59406CE8667FA0A04A404704E3E0D21959406CE8667FA0A04A40
350	Заларинский район	\N	50	100.336733	102.73019499999999	53.816398999999997	52.749039000000003	0103000020E61000000100000005000000F99E91088D155940DB368C82E05F4A40F99E91088D15594059BE2EC37FE84A40F92CCF83BBAE594059BE2EC37FE84A40F92CCF83BBAE5940DB368C82E05F4A40F99E91088D155940DB368C82E05F4A40
426	Жигаловский район	\N	50	103.970894	106.832594	55.872596999999999	53.762998000000003	0103000020E610000001000000050000007D78962023FE5940EB7420EBA9E14A407D78962023FE59403ACB2C42B1EF4B402236583849B55A403ACB2C42B1EF4B402236583849B55A40EB7420EBA9E14A407D78962023FE5940EB7420EBA9E14A40
402	Братский район	\N	50	100.01459699999999	103.507094	56.883896999999997	54.917395999999997	0103000020E61000000100000005000000A9674128EF00594098BD6C3B6D754B40A9674128EF0059402904728923714C40DC7F643A74E059402904728923714C40DC7F643A74E0594098BD6C3B6D754B40A9674128EF00594098BD6C3B6D754B40
441	Боханский район	\N	50	103.351793	104.724599	53.538595999999998	52.678795000000001	0103000020E610000001000000050000008D7DC9C683D659401BD82AC1E2564A408D7DC9C683D65940D2E0B6B6F0C44A40B7ED7BD45F2E5A40D2E0B6B6F0C44A40B7ED7BD45F2E5A401BD82AC1E2564A408D7DC9C683D659401BD82AC1E2564A40
1576	Баяндаевский район	\N	50	105.018294	106.183795	53.628394999999998	52.742894999999997	0103000020E61000000100000005000000A2ED98BA2B415A4053AEF02E175F4A40A2ED98BA2B415A4026FC523F6FD04A40C68A1A4CC38B5A4026FC523F6FD04A40C68A1A4CC38B5A4053AEF02E175F4A40A2ED98BA2B415A4053AEF02E175F4A40
398	Балаганский район	\N	50	102.41659300000001	103.34569399999999	55.447595999999997	53.823697000000003	0103000020E6100000010000000500000086AFAF75A99A59401B683EE76EE94A4086AFAF75A99A594003E962D34AB94B40191BBAD91FD6594003E962D34AB94B40191BBAD91FD659401B683EE76EE94A4086AFAF75A99A59401B683EE76EE94A40
1285	Ангарский район	\N	50	103.199196	104.11049199999999	52.488399999999999	52.164796000000003	0103000020E610000001000000050000009E5F94A0BFCC59407D410B0918154A409E5F94A0BFCC5940E6AE25E4833E4A400E9E094D12075A40E6AE25E4833E4A400E9E094D12075A407D410B0918154A409E5F94A0BFCC59407D410B0918154A40
1177	Аларский район	\N	50	102.126698	103.384699	53.644298999999997	52.992697	0103000020E61000000100000005000000FE9DEDD11B8859402DEBFEB1107F4A40FE9DEDD11B88594039ECBE6378D24A4073F38DE89ED8594039ECBE6378D24A4073F38DE89ED859402DEBFEB1107F4A40FE9DEDD11B8859402DEBFEB1107F4A40
7101	городской округ Чита	\N	48	113.404777	113.54536299999999	52.085343000000002	51.992057000000003	0103000020E61000000100000005000000124BCADDE7595C404A6249B9FBFE4940124BCADDE7595C40A5F8F884EC0A4A40B35C363AE7625C40A5F8F884EC0A4A40B35C363AE7625C404A6249B9FBFE4940124BCADDE7595C404A6249B9FBFE4940
7089	Чита	\N	48	113.184645	113.61933000000001	52.162261000000001	51.964153000000003	0103000020E61000000100000005000000AD174339D14B5C408FAB915D69FB4940AD174339D14B5C404835ECF7C4144A40A1DB4B1AA3675C404835ECF7C4144A40A1DB4B1AA3675C408FAB915D69FB4940AD174339D14B5C408FAB915D69FB4940
178	Шилкинский район	\N	48	114.97969399999999	116.375793	52.326298000000001	51.225898999999998	0103000020E610000001000000050000009885764EB3BE5C407C992842EA9C49409885764EB3BE5C4007600322C4294A40354415FE0C185D4007600322C4294A40354415FE0C185D407C992842EA9C49409885764EB3BE5C407C992842EA9C4940
15	Шелопугинский район	\N	48	117.28089900000001	118.656993	52.137796999999999	51.211795000000002	0103000020E61000000100000005000000AA9ECC3FFA515D40693A3B191C9B4940AA9ECC3FFA515D40533E0455A3114A40DC2C5E2C0CAA5D40533E0455A3114A40DC2C5E2C0CAA5D40693A3B191C9B4940AA9ECC3FFA515D40693A3B191C9B4940
208	Читинский район	\N	48	112.214195	114.647093	53.057198999999997	50.957998000000003	0103000020E61000000100000005000000DFFDF15EB50D5C4014D1AFAD9F7A4940DFFDF15EB50D5C40942EFD4B52874A401D1EC2F869A95C40942EFD4B52874A401D1EC2F869A95C4014D1AFAD9F7A4940DFFDF15EB50D5C4014D1AFAD9F7A4940
1886	Чернышевский район	\N	48	116.24139599999999	118.41399800000001	53.692098999999999	52.103296999999998	0103000020E61000000100000005000000A7583508730F5D4030630AD6380D4A40A7583508730F5D40124C35B396D84A4001A777F17E9A5D40124C35B396D84A4001A777F17E9A5D4030630AD6380D4A40A7583508730F5D4030630AD6380D4A40
809	Хилокский район	\N	48	109.35169500000001	112.427994	52.304859999999998	50.729097000000003	0103000020E61000000100000005000000ACCABE2B82565B404D4EED0C535D4940ACCABE2B82565B40E5ED08A705274A409738F240641B5C40E5ED08A705274A409738F240641B5C404D4EED0C535D4940ACCABE2B82565B404D4EED0C535D4940
214	Улетовский район	\N	48	110.91789900000001	113.284699	51.743395999999997	49.705995999999999	0103000020E61000000100000005000000FE8172DBBEBA5B40AC8DB1135EDA4840FE8172DBBEBA5B4015FDA19927DF49400D8D278238525C4015FDA19927DF49400D8D278238525C40AC8DB1135EDA4840FE8172DBBEBA5B40AC8DB1135EDA4840
614	Тунгокоченский район	\N	48	113.775026	118.23339199999999	56.000698	52.156095000000001	0103000020E610000001000000050000002EE3A6069A715C40D908C4EBFA134A402EE3A6069A715C4018963FDF16004C4079C9FFE4EF8E5D4018963FDF16004C4079C9FFE4EF8E5D40D908C4EBFA134A402EE3A6069A715C40D908C4EBFA134A40
586	Тунгиро-Олекминский район	\N	48	117.265394	122.14396499999999	56.039158	53.729500000000002	0103000020E610000001000000050000007FA31D37FC505D404C37894160DD4A407FA31D37FC505D403AB01C2103054C4031B1F9B836895E403AB01C2103054C4031B1F9B836895E404C37894160DD4A407FA31D37FC505D404C37894160DD4A40
1840	Сретенский район	\N	48	116.896897	119.905292	53.374496999999998	51.900396999999998	0103000020E610000001000000050000005AB8ACC266395D4050357A3540F349405AB8ACC266395D409DB98784EFAF4A402655DB4DF0F95D409DB98784EFAF4A402655DB4DF0F95D4050357A3540F349405AB8ACC266395D4050357A3540F34940
7503	Приаргунский район 	\N	48	117.879797	119.38509500000001	50.801997	49.973232000000003	0103000020E610000001000000050000009C8713984E785D40D9B5BDDD92FC48409C8713984E785D40BC3E73D6A76649409AB67F65A5D85D40BC3E73D6A76649409AB67F65A5D85D40D9B5BDDD92FC48409C8713984E785D40D9B5BDDD92FC4840
1809	Приаргунский район	\N	48	117.879797	119.38509500000001	50.801997	49.973232000000003	0103000020E610000001000000050000009C8713984E785D40D9B5BDDD92FC48409C8713984E785D40BC3E73D6A76649409AB67F65A5D85D40BC3E73D6A76649409AB67F65A5D85D40D9B5BDDD92FC48409C8713984E785D40D9B5BDDD92FC4840
427	Петровск-Забайкальский район	\N	48	108.062343	110.109792	51.517642000000002	50.527906000000002	0103000020E610000001000000050000009C887E6DFD035B405CAE7E6C924349409C887E6DFD035B409D84D21742C24940325706D506875B409D84D21742C24940325706D506875B405CAE7E6C924349409C887E6DFD035B405CAE7E6C92434940
1785	Ононский район	\N	48	113.969691	115.924695	50.652695999999999	49.904651000000001	0103000020E610000001000000050000006F0ED76A0F7E5C4098A59D9ACBF348406F0ED76A0F7E5C40711DE38A8B53494095F1EF332EFB5C40711DE38A8B53494095F1EF332EFB5C4098A59D9ACBF348406F0ED76A0F7E5C4098A59D9ACBF34840
1190	Оловяннинский район	\N	48	115.340098	116.883494	51.392595	50.411594999999998	0103000020E61000000100000005000000D7DB662AC4D55C403B191C25AF344940D7DB662AC4D55C405CC98E8D40B24940950D6B2A8B385D405CC98E8D40B24940950D6B2A8B385D403B191C25AF344940D7DB662AC4D55C403B191C25AF344940
1684	Нерчинско-Заводский район	\N	48	118.83979100000001	120.76719799999999	52.642696000000001	50.914937999999999	0103000020E61000000100000005000000691EC022BFB55D400FEF39B01C754940691EC022BFB55D4090A2CEDC43524A409FE3A3C519315E4090A2CEDC43524A409FE3A3C519315E400FEF39B01C754940691EC022BFB55D400FEF39B01C754940
1663	Нерчинский район	\N	48	115.837998	117.08119499999999	52.906894999999999	51.567495999999998	0103000020E6100000010000000500000042075DC2A1F55C402F4E7CB5A3C8494042075DC2A1F55C40F5F3A62215744A405166834C32455D40F5F3A62215744A405166834C32455D402F4E7CB5A3C8494042075DC2A1F55C402F4E7CB5A3C84940
1622	Могочинский район	\N	48	117.94729700000001	122.09929200000001	54.465198000000001	52.975597999999998	0103000020E6100000010000000500000055A69883A07C5D4081053065E07C4A4055A69883A07C5D401215AA9B8B3B4B404930D5CC5A865E401215AA9B8B3B4B404930D5CC5A865E4081053065E07C4A4055A69883A07C5D4081053065E07C4A40
692	Могойтуйский район	\N	48	114.413899	115.919898	51.689694000000003	50.578698000000003	0103000020E6100000010000000500000037363B527D9A5C405C21ACC6124A494037363B527D9A5C40AC1F9BE447D84940F969DC9BDFFA5C40AC1F9BE447D84940F969DC9BDFFA5C405C21ACC6124A494037363B527D9A5C405C21ACC6124A4940
283	Кыринский район	\N	48	109.36179199999999	113.30949200000001	50.393596000000002	49.154963000000002	0103000020E6100000010000000500000015FDA19927575B40878BDCD3D593484015FDA19927575B4010EB8D5A61324940EA9788B7CE535C4010EB8D5A61324940EA9788B7CE535C40878BDCD3D593484015FDA19927575B40878BDCD3D5934840
34	Красночикойский район	\N	48	107.73453000000001	111.145595	50.796799	49.316797999999999	0103000020E6100000010000000500000094FB1D8A02EF5A4017B83CD68CA8484094FB1D8A02EF5A40253E7782FD65494083DDB06D51C95B40253E7782FD65494083DDB06D51C95B4017B83CD68CA8484094FB1D8A02EF5A4017B83CD68CA84840
1224	Краснокаменский район	\N	48	117.33749299999999	118.911908	50.466796000000002	49.555571999999998	0103000020E6100000010000000500000040683D7C99555D406249B9FB1CC7484040683D7C99555D40AAF3A8F8BF3B49407D3D5FB35CBA5D40AAF3A8F8BF3B49407D3D5FB35CBA5D406249B9FB1CC7484040683D7C99555D406249B9FB1CC74840
1560	Карымский район	\N	48	113.495893	115.232696	52.664199000000004	51.0533	0103000020E610000001000000050000002E54FEB5BC5F5C403B70CE88D28649402E54FEB5BC5F5C4099840B7904554A403E7AC37DE4CE5C4099840B7904554A403E7AC37DE4CE5C403B70CE88D28649402E54FEB5BC5F5C403B70CE88D2864940
1529	Калганский район	\N	48	118.395493	119.53562599999999	51.339995000000002	50.679706000000003	0103000020E610000001000000050000000133DFC14F995D408F72309B005749400133DFC14F995D40DAE6C6F484AB4940C93846B247E25D40DAE6C6F484AB4940C93846B247E25D408F72309B005749400133DFC14F995D408F72309B00574940
1907	Каларский район	\N	48	115.411694	120.529495	58.438696	55.188298000000003	0103000020E61000000100000005000000677DCA3159DA5C407CF31B261A984B40677DCA3159DA5C406971C63027384D405019FF3EE3215E406971C63027384D405019FF3EE3215E407CF31B261A984B40677DCA3159DA5C407CF31B261A984B40
7086	Ингодинский 	\N	48	107.734359	122.14574399999999	58.438729000000002	49.154963000000002	0103000020E610000001000000050000007D21E4BCFFEE5A40878BDCD3D59348407D21E4BCFFEE5A404567994528384D40A565A4DE53895E404567994528384D40A565A4DE53895E40878BDCD3D59348407D21E4BCFFEE5A40878BDCD3D5934840
1453	Забайкальский район	\N	48	116.23561100000001	117.95445599999999	50.245297000000001	49.508014000000003	0103000020E61000000100000005000000FCE42840140F5D4080F44D9A06C14840FCE42840140F5D40496760E4651F4940245E9ECE157D5D40496760E4651F4940245E9ECE157D5D4080F44D9A06C14840FCE42840140F5D4080F44D9A06C14840
631	Дульдургинский район	\N	48	112.338998	114.434893	51.186295999999999	50.404395999999998	0103000020E6100000010000000500000034DAAA24B2155C400D51853FC333494034DAAA24B2155C4014B01D8CD897494099107349D59B5C4014B01D8CD897494099107349D59B5C400D51853FC333494034DAAA24B2155C400D51853FC3334940
1437	Газимуро-Заводский район	\N	48	117.938897	120.494398	53.232999	51.288798999999997	0103000020E61000000100000005000000005471E3167C5D400A0F9A5DF7A44940005471E3167C5D40178046E9D29D4A404D4D8237A41F5E40178046E9D29D4A404D4D8237A41F5E400A0F9A5DF7A44940005471E3167C5D400A0F9A5DF7A44940
1136	Борзинский район	\N	48	115.552334	117.748194	51.085498999999999	49.885083000000002	0103000020E61000000100000005000000029EB47059E35C406F9F55664AF14840029EB47059E35C409C6B98A1F18A49400F441669E26F5D409C6B98A1F18A49400F441669E26F5D406F9F55664AF14840029EB47059E35C406F9F55664AF14840
1099	Балейский район	\N	48	116.024399	117.452594	51.939996000000001	50.983198000000002	0103000020E6100000010000000500000087C3D2C08F015D400EBF9B6ED97D494087C3D2C08F015D40772FF7C951F849406A17D34CF75C5D40772FF7C951F849406A17D34CF75C5D400EBF9B6ED97D494087C3D2C08F015D400EBF9B6ED97D4940
1302	Александрово-Заводский район	\N	48	117.07899399999999	118.756894	51.478594999999999	50.392499000000001	0103000020E6100000010000000500000022A5D93C0E455D403A5B40683D32494022A5D93C0E455D40BA83D89942BD4940792288F370B05D40BA83D89942BD4940792288F370B05D403A5B40683D32494022A5D93C0E455D403A5B40683D324940
1888	Акшинский район	\N	48	112.24459400000001	114.109945	50.651999000000004	49.877094999999997	0103000020E6100000010000000500000010B3976DA70F5C40183E22A644F0484010B3976DA70F5C402A0307B474534940F5D6C05609875C402A0307B474534940F5D6C05609875C40183E22A644F0484010B3976DA70F5C40183E22A644F04840
187	Агинский район	\N	48	113.770696	115.40399499999999	51.427194999999998	50.4587	0103000020E610000001000000050000001DCA501553715C406D567DAEB63A49401DCA501553715C40E2016553AEB64940D72FD80DDBD95C40E2016553AEB64940D72FD80DDBD95C406D567DAEB63A49401DCA501553715C406D567DAEB63A4940
458	Шипуновский район	\N	47	81.526692999999995	83.045492999999993	52.636696000000001	51.742396999999997	0103000020E610000001000000050000000E828E56B561544002D369DD06DF49400E828E56B56154403CBF28417F514A409ACC785BE9C254403CBF28417F514A409ACC785BE9C2544002D369DD06DF49400E828E56B561544002D369DD06DF4940
1700	Шелаболихинский район	\N	47	81.663596999999996	82.683893999999995	53.680399000000001	53.248593999999997	0103000020E61000000100000005000000512E8D5F786A5440ACFD9DEDD19F4A40512E8D5F786A5440959D7E5017D74A408FFB56EBC4AB5440959D7E5017D74A408FFB56EBC4AB5440ACFD9DEDD19F4A40512E8D5F786A5440ACFD9DEDD19F4A40
1664	Чарышский район	\N	47	82.924598000000003	84.588313999999997	51.803899999999999	50.639975999999997	0103000020E610000001000000050000009CFC169D2CBB5440C91CCBBBEA5149409CFC169D2CBB544090A0F831E6E64940DA71C3EFA625554090A0F831E6E64940DA71C3EFA6255540C91CCBBBEA5149409CFC169D2CBB5440C91CCBBBEA514940
1615	Целинный район	\N	47	85.109596999999994	86.402794	53.279795999999997	52.676098000000003	0103000020E6100000010000000500000057AF22A3034755400D7217618A564A4057AF22A3034755409BC6F65AD0A34A409A417C60C79955409BC6F65AD0A34A409A417C60C79955400D7217618A564A4057AF22A3034755400D7217618A564A40
1581	Хабарский район	\N	47	78.744	80.065196999999998	53.831046999999998	53.188600000000001	0103000020E61000000100000005000000560E2DB29DAF53404703780B24984A40560E2DB29DAF53402E3883BF5FEA4A4007B309302C0454402E3883BF5FEA4A4007B309302C0454404703780B24984A40560E2DB29DAF53404703780B24984A40
1523	Усть-Пристанский район	\N	47	83.207801000000003	84.122995000000003	52.668998999999999	51.925097000000001	0103000020E61000000100000005000000DFC4909C4CCD54405950189469F64940DFC4909C4CCD544042075DC2A1554A4094A46B26DF07554042075DC2A1554A4094A46B26DF0755405950189469F64940DFC4909C4CCD54405950189469F64940
1466	Усть-Калманский район	\N	47	82.795096999999998	83.991490999999996	52.258597000000002	51.633397000000002	0103000020E61000000100000005000000740987DEE2B254403831242713D14940740987DEE2B25440FFEBDCB419214A40D0D1AA9674FF5440FFEBDCB419214A40D0D1AA9674FF54403831242713D14940740987DEE2B254403831242713D14940
1411	Угловский район	\N	47	79.539323999999993	80.704393999999994	51.818098999999997	50.737842000000001	0103000020E61000000100000005000000AA7CCF4884E25340C0CE4D9B715E4940AA7CCF4884E25340F5F1D077B7E84940E95F92CA142D5440F5F1D077B7E84940E95F92CA142D5440C0CE4D9B715E4940AA7CCF4884E25340C0CE4D9B715E4940
1360	Тюменцевский район	\N	47	81.035089999999997	82.130297999999996	53.516098	53.007097000000002	0103000020E61000000100000005000000AA9A20EA3E4254402A73F38DE8804A40AA9A20EA3E425440F8C3CF7F0FC24A40FD2E6CCD56885440F8C3CF7F0FC24A40FD2E6CCD568854402A73F38DE8804A40AA9A20EA3E4254402A73F38DE8804A40
1138	Троицкий район	\N	47	83.960893999999996	85.464297000000002	53.226697000000001	52.429096999999999	0103000020E610000001000000050000000C3B8C497FFD5440E6E786A6EC364A400C3B8C497FFD5440F88C4468049D4A4061A8C30AB75D5540F88C4468049D4A4061A8C30AB75D5540E6E786A6EC364A400C3B8C497FFD5440E6E786A6EC364A40
1217	Третьяковский район	\N	47	81.782165000000006	82.748896000000002	51.147998000000001	50.731912999999999	0103000020E61000000100000005000000DBC4C9FD0E72544035423F53AF5D4940DBC4C9FD0E725440CCEF3499F1924940BC067DE9EDAF5440CCEF3499F1924940BC067DE9EDAF544035423F53AF5D4940DBC4C9FD0E72544035423F53AF5D4940
1154	Топчихинский район	\N	47	82.337593999999996	84.194699	53.049795000000003	52.413998999999997	0103000020E61000000100000005000000DA54DD239B955440D1C952EBFD344A40DA54DD239B9554408E40BCAE5F864A401764CBF2750C55408E40BCAE5F864A401764CBF2750C5540D1C952EBFD344A40DA54DD239B955440D1C952EBFD344A40
1119	Тогульский район	\N	47	85.620496000000003	86.623733999999999	53.743698999999999	53.264296999999999	0103000020E6100000010000000500000020D3DA34B667554028B7ED7BD4A14A4020D3DA34B6675540B188618731DF4A40CFD90242EBA75540B188618731DF4A40CFD90242EBA7554028B7ED7BD4A14A4020D3DA34B667554028B7ED7BD4A14A40
975	Тальменский район	\N	47	82.801106000000004	83.979651000000004	54.086342999999999	53.490391000000002	0103000020E6100000010000000500000048A8195245B354405AA0DD21C5BE4A4048A8195245B35440889E94490D0B4B40999F1B9AB2FE5440889E94490D0B4B40999F1B9AB2FE54405AA0DD21C5BE4A4048A8195245B354405AA0DD21C5BE4A40
918	Табунский район	\N	47	78.387395999999995	79.486295999999996	53.088000000000001	52.582295000000002	0103000020E610000001000000050000007AA69718CB985340EACF7EA4884A4A407AA69718CB98534025068195438B4A403D0B42791FDF534025068195438B4A403D0B42791FDF5340EACF7EA4884A4A407AA69718CB985340EACF7EA4884A4A40
900	Суетский район	\N	47	79.631598999999994	80.231493	53.465198000000001	53.106994999999998	0103000020E61000000100000005000000EC4B361E6CE85340F2EA1C03B28D4A40EC4B361E6CE853401215AA9B8BBB4A40301004C8D00E54401215AA9B8BBB4A40301004C8D00E5440F2EA1C03B28D4A40EC4B361E6CE85340F2EA1C03B28D4A40
513	Солтонский район	\N	47	85.999801000000005	87.161294999999996	53.114913999999999	52.492896000000002	0103000020E61000000100000005000000856055BDFC7F5540242A5437173F4A40856055BDFC7F554020ED7F80B58E4A40888043A852CA554020ED7F80B58E4A40888043A852CA5540242A5437173F4A40856055BDFC7F5540242A5437173F4A40
714	Солонешенский район	\N	47	83.898497000000006	84.947523000000004	51.960196000000003	51.267394000000003	0103000020E6100000010000000500000077A38FF980F95440C59272F739A2494077A38FF980F9544001E0D8B3E7FA49404D4D8237A43C554001E0D8B3E7FA49404D4D8237A43C5540C59272F739A2494077A38FF980F95440C59272F739A24940
559	Советский район	\N	47	85.129198000000002	85.920227999999994	52.468297	52.005496999999998	0103000020E610000001000000050000005A2DB0C744485540F19C2D20B4004A405A2DB0C7444855404FE8F527F13B4A404337FB03E57A55404FE8F527F13B4A404337FB03E57A5540F19C2D20B4004A405A2DB0C744485540F19C2D20B4004A40
365	Смоленский район	\N	47	84.440397000000004	85.287094999999994	52.481298000000002	51.774797999999997	0103000020E610000001000000050000006B10E6762F1C5540CB80B3942CE349406B10E6762F1C5540ABD0402C9B3D4A4016F6B4C35F525540ABD0402C9B3D4A4016F6B4C35F525540CB80B3942CE349406B10E6762F1C5540CB80B3942CE34940
1687	Славгородский район	\N	47	78.190996999999996	79.633197999999993	53.377397999999999	52.802497000000002	0103000020E6100000010000000500000095287B4B398C5340AE11C138B8664A4095287B4B398C5340B4C9E1934EB04A402079E75086E85340B4C9E1934EB04A402079E75086E85340AE11C138B8664A4095287B4B398C5340AE11C138B8664A40
160	Рубцовский район	\N	47	80.344097000000005	81.861693000000002	51.916099000000003	51.180069000000003	0103000020E61000000100000005000000B6696CAF05165440000341800C974940B6696CAF05165440FC7266BB42F549404C8C65FA25775440FC7266BB42F549404C8C65FA25775440000341800C974940B6696CAF05165440000341800C974940
43	Романовский район	\N	47	80.669790000000006	81.562994000000003	52.840699000000001	52.339396000000001	0103000020E61000000100000005000000064CE0D6DD2A544055320054712B4A40064CE0D6DD2A5440D4635B069C6B4A400876FC1708645440D4635B069C6B4A400876FC170864544055320054712B4A40064CE0D6DD2A544055320054712B4A40
180	Родинский район	\N	47	79.620495000000005	80.850199000000003	52.857199000000001	52.208995000000002	0103000020E610000001000000050000003815A930B6E7534086032159C01A4A403815A930B6E75340FB9463B2B86D4A40E20511A969365440FB9463B2B86D4A40E20511A96936544086032159C01A4A403815A930B6E7534086032159C01A4A40
118	Ребрихинский район	\N	47	81.837196000000006	82.797297999999998	53.336897999999998	52.695799000000001	0103000020E61000000100000005000000E415889E9475544075CB0EF10F594A40E415889E947554403D0B42791FAB4A40A3CA30EE06B354403D0B42791FAB4A40A3CA30EE06B3544075CB0EF10F594A40E415889E9475544075CB0EF10F594A40
112	Поспелихинский район	\N	47	81.306794999999994	82.396091999999996	52.229796	51.529898000000003	0103000020E61000000100000005000000E2E47E87A2535440A01B9AB2D3C34940E2E47E87A2535440356090F4691D4A40438D429259995440356090F4691D4A40438D429259995440A01B9AB2D3C34940E2E47E87A2535440A01B9AB2D3C34940
1848	Петропавловский район	\N	47	83.747193999999993	84.536192999999997	52.403495999999997	51.916499000000002	0103000020E610000001000000050000001D71C806D2EF54408AE8D7D64FF549401D71C806D2EF54408D08C6C1A5334A4006D671FC502255408D08C6C1A5334A4006D671FC502255408AE8D7D64FF549401D71C806D2EF54408AE8D7D64FF54940
1667	Первомайский район	\N	47	83.705476000000004	84.439858000000001	53.942847	52.909480000000002	0103000020E610000001000000050000003A07CF8426ED5440DC2E34D769744A403A07CF8426ED5440DC10E335AFF84A4093382BA2261C5540DC10E335AFF84A4093382BA2261C5540DC2E34D769744A403A07CF8426ED5440DC2E34D769744A40
381	Панкрушихинский район	\N	47	79.817694000000003	80.737397999999999	54.115169999999999	53.451397999999998	0103000020E61000000100000005000000AB08371955F453406ABDDF68C7B94A40AB08371955F453407BBDFBE3BD0E4B40B1886187312F54407BBDFBE3BD0E4B40B1886187312F54406ABDDF68C7B94A40AB08371955F453406ABDDF68C7B94A40
1693	Павловский район	\N	47	82.515091999999996	83.474492999999995	53.744796000000001	52.983699000000001	0103000020E61000000100000005000000999B6F44F7A05440D00D4DD9E97D4A40999B6F44F7A054408718AF7955DF4A40944BE3175EDE54408718AF7955DF4A40944BE3175EDE5440D00D4DD9E97D4A40999B6F44F7A05440D00D4DD9E97D4A40
1710	Новичихинский район	\N	47	81.004593	81.883792	52.421897999999999	51.837597000000002	0103000020E61000000100000005000000983270404B405440261DE56036EB4940983270404B405440B81FF0C000364A40DA1D520C90785440B81FF0C000364A40DA1D520C90785440261DE56036EB4940983270404B405440261DE56036EB4940
7480	Немецкий район	\N	47	78.557591000000002	79.371195	53.426295000000003	53.128300000000003	0103000020E61000000100000005000000D0622992AFA35340D50968226C904A40D0622992AFA3534063B9A5D590B64A40145CACA8C1D7534063B9A5D590B64A40145CACA8C1D75340D50968226C904A40D0622992AFA35340D50968226C904A40
1685	Немецкий Национальный район	\N	47	78.557591000000002	79.371195	53.426295000000003	53.128300000000003	0103000020E61000000100000005000000D0622992AFA35340D50968226C904A40D0622992AFA3534063B9A5D590B64A40145CACA8C1D7534063B9A5D590B64A40145CACA8C1D75340D50968226C904A40D0622992AFA35340D50968226C904A40
1674	Михайловский район	\N	47	79.158698000000001	80.113400999999996	52.205198000000003	51.458021000000002	0103000020E6100000010000000500000033FCA71B28CA5340CCF09F6EA0BA494033FCA71B28CA5340319A95ED431A4A405B9544F641075440319A95ED431A4A405B9544F641075440CCF09F6EA0BA494033FCA71B28CA5340CCF09F6EA0BA4940
1630	Мамонтовский район	\N	47	81.257998000000001	82.103699000000006	53.079897000000003	52.360399000000001	0103000020E61000000100000005000000BD1B0B0A835054406C41EF8D212E4A40BD1B0B0A8350544036069D103A8A4A4030682101A386544036069D103A8A4A4030682101A38654406C41EF8D212E4A40BD1B0B0A835054406C41EF8D212E4A40
1231	Локтевский район	\N	47	81.064295000000001	81.939299000000005	51.297995999999998	50.746426	0103000020E61000000100000005000000F792C6681D4454402A711DE38A5F4940F792C6681D4454405E2BA1BB24A64940988A8D791D7C54405E2BA1BB24A64940988A8D791D7C54402A711DE38A5F4940F792C6681D4454402A711DE38A5F4940
775	Кытмановский район	\N	47	84.869298000000001	85.924800000000005	53.829999999999998	53.153595000000003	0103000020E610000001000000050000009B1E1494A237554021EA3E00A9934A409B1E1494A23755400AD7A3703DEA4A40D0D556EC2F7B55400AD7A3703DEA4A40D0D556EC2F7B554021EA3E00A9934A409B1E1494A237554021EA3E00A9934A40
1477	Курьинский район	\N	47	81.878598999999994	83.001897999999997	51.794398000000001	51.105896000000001	0103000020E6100000010000000500000017D34CF73A7854407C6308008E8D494017D34CF73A78544000016BD5AEE5494061FBC9181FC0544000016BD5AEE5494061FBC9181FC054407C6308008E8D494017D34CF73A7854407C6308008E8D4940
1416	Кулундинский район	\N	47	78.577803000000003	79.650598000000002	52.789498999999999	52.348534000000001	0103000020E61000000100000005000000F7216FB9FAA45340A4C519C39C2C4A40F7216FB9FAA45340C39CA04D0E654A40F435CB65A3E95340C39CA04D0E654A40F435CB65A3E95340A4C519C39C2C4A40F7216FB9FAA45340A4C519C39C2C4A40
352	Крутихинский район	\N	47	80.490099999999998	81.401737999999995	54.375428999999997	53.729399000000001	0103000020E6100000010000000500000041F163CC5D1F5440185E49F25CDD4A4041F163CC5D1F5440287CB60E0E304B40DEE34C13B6595440287CB60E0E304B40DEE34C13B6595440185E49F25CDD4A4041F163CC5D1F5440185E49F25CDD4A40
316	Краснощековский район	\N	47	82.463493	83.329199000000003	51.881098999999999	51.112597000000001	0103000020E61000000100000005000000323B8BDEA99D544059501894698E4940323B8BDEA99D5440E7C41EDAC7F049400FB8AE9811D55440E7C41EDAC7F049400FB8AE9811D5544059501894698E4940323B8BDEA99D544059501894698E4940
206	Красногорский район	\N	47	85.779793999999995	86.805598000000003	52.630099000000001	52.014899	0103000020E610000001000000050000007DE71725E87155401EDFDE35E8014A407DE71725E8715540041F8315A7504A4046EEE9EA8EB35540041F8315A7504A4046EEE9EA8EB355401EDFDE35E8014A407DE71725E87155401EDFDE35E8014A40
188	Косихинский район	\N	47	84.206097999999997	85.125793999999999	53.557695000000002	53.090795999999997	0103000020E610000001000000050000005871AAB5300D5540C64D0D349F8B4A405871AAB5300D55404512BD8C62C74A401D0247020D4855404512BD8C62C74A401D0247020D485540C64D0D349F8B4A405871AAB5300D5540C64D0D349F8B4A40
1153	Ключевский район	\N	47	78.790038999999993	80.015494000000004	52.565295999999996	51.920020999999998	0103000020E6100000010000000500000021E4BCFF8FB253400D51853FC3F5494021E4BCFF8FB25340A1478C9E5B484A4031D28BDAFD005440A1478C9E5B484A4031D28BDAFD0054400D51853FC3F5494021E4BCFF8FB253400D51853FC3F54940
1085	Каменский район	\N	47	80.570401000000004	82.052396999999999	54.078167000000001	53.372897000000002	0103000020E61000000100000005000000C42632738124544065E3C116BBAF4A40C4263273812454402F505260010A4B40255AF2785A8354402F505260010A4B40255AF2785A83544065E3C116BBAF4A40C42632738124544065E3C116BBAF4A40
1008	Калманский район	\N	47	82.931676999999993	83.653373999999999	53.254385999999997	52.813923000000003	0103000020E61000000100000005000000DD5B9198A0BB54402A3BFDA02E684A40DD5B9198A0BB5440B6476FB88FA04A40A1832EE1D0E95440B6476FB88FA04A40A1832EE1D0E954402A3BFDA02E684A40DD5B9198A0BB54402A3BFDA02E684A40
277	Зональный район	\N	47	84.472700000000003	85.357397000000006	52.9955	52.425099000000003	0103000020E610000001000000050000006E3480B7401E5540FA47DFA469364A406E3480B7401E55408195438B6C7F4A4011ACAA97DF5655408195438B6C7F4A4011ACAA97DF565540FA47DFA469364A406E3480B7401E5540FA47DFA469364A40
48	Змеиногорский район	\N	47	81.561593000000002	83.120844000000005	51.565598000000001	50.884659999999997	0103000020E61000000100000005000000672AC423F1635440280AF4893C714940672AC423F16354406D57E88365C84940BEFA78E8BBC754406D57E88365C84940BEFA78E8BBC75440280AF4893C714940672AC423F1635440280AF4893C714940
730	Заринский район	\N	47	84.203395	86.340091000000001	54.223095000000001	53.472895999999999	0103000020E61000000100000005000000E04A766C040D554061342BDB87BC4A40E04A766C040D5540587380608E1C4B407EAA0A0DC4955540587380608E1C4B407EAA0A0DC495554061342BDB87BC4A40E04A766C040D554061342BDB87BC4A40
598	Залесовский район	\N	47	83.920891999999995	85.386690999999999	54.452229000000003	53.789199000000004	0103000020E6100000010000000500000079C9FFE4EFFA544099840B7904E54A4079C9FFE4EFFA5440C2A6CEA3E2394B4015AA9B8BBF585540C2A6CEA3E2394B4015AA9B8BBF58554099840B7904E54A4079C9FFE4EFFA544099840B7904E54A40
504	Завьяловский район	\N	47	80.434197999999995	81.481993000000003	53.134599000000001	52.584297999999997	0103000020E61000000100000005000000457F68E6C91B5440218FE046CA4A4A40457F68E6C91B544083893F8A3A914A40A9F92AF9D85E544083893F8A3A914A40A9F92AF9D85E5440218FE046CA4A4A40457F68E6C91B5440218FE046CA4A4A40
470	Ельцовский район	\N	47	85.806293999999994	86.931120000000007	53.502872000000004	52.986598999999998	0103000020E61000000100000005000000813D26529A73554016A243E0487E4A40813D26529A7355407D09151C5EC04A40B329577897BB55407D09151C5EC04A40B329577897BB554016A243E0487E4A40813D26529A73554016A243E0487E4A40
385	Егорьевский район	\N	47	80.503899000000004	81.276494999999997	52.102296000000003	51.335498999999999	0103000020E610000001000000050000002D5F97E13F2054409C6B98A1F1AA49402D5F97E13F2054407D410B09180D4A407BA01518B25154407D410B09180D4A407BA01518B25154409C6B98A1F1AA49402D5F97E13F2054409C6B98A1F1AA4940
242	Волчихинский район	\N	47	79.915197000000006	81.136994999999999	52.399298000000002	51.651795999999997	0103000020E610000001000000050000006E19709692FA5340F1D4230D6ED349406E19709692FA5340DAAD65321C334A40CB2DAD86C4485440DAAD65321C334A40CB2DAD86C4485440F1D4230D6ED349406E19709692FA5340F1D4230D6ED34940
142	Быстроистокский район	\N	47	84.092093000000006	84.834397999999993	52.581496000000001	52.064495999999998	0103000020E6100000010000000500000032CC09DAE4055540855CA96741084A4032CC09DAE40555409E60FF756E4A4A404276DEC6663555409E60FF756E4A4A404276DEC666355540855CA96741084A4032CC09DAE4055540855CA96741084A40
111	Бурлинский район	\N	47	77.893394000000001	79.056298999999996	53.651738999999999	52.992296000000003	0103000020E61000000100000005000000541C075E2D795340CFF9298E037F4A40541C075E2D7953408D43FD2E6CD34A400AF31E679AC353408D43FD2E6CD34A400AF31E679AC35340CFF9298E037F4A40541C075E2D795340CFF9298E037F4A40
968	Благовещенский район	\N	47	79.315697	80.707797999999997	53.234195	52.589199999999998	0103000020E61000000100000005000000809C306134D45340CF66D5E76A4B4A40809C306134D4534080F10C1AFA9D4A40268BFB8F4C2D544080F10C1AFA9D4A40268BFB8F4C2D5440CF66D5E76A4B4A40809C306134D45340CF66D5E76A4B4A40
1833	Бийский район	\N	47	85.008195000000001	86.114596000000006	52.884399000000002	52.357599	0103000020E61000000100000005000000683F524486405540890AD5CDC52D4A40683F524486405540BCCE86FC33714A402810768A55875540BCCE86FC33714A402810768A55875540890AD5CDC52D4A40683F524486405540890AD5CDC52D4A40
1839	Баевский район	\N	47	80.113994000000005	81.274797000000007	53.549500000000002	53.050195000000002	0103000020E610000001000000050000002D7C7DAD4B0754401CB62DCA6C864A402D7C7DAD4B0754407593180456C64A407E022846965154407593180456C64A407E022846965154401CB62DCA6C864A402D7C7DAD4B0754401CB62DCA6C864A40
409	Алтайский район	\N	47	84.721093999999994	85.868798999999996	52.166198999999999	51.482993	0103000020E61000000100000005000000E0D57267262E55403599F1B6D2BD4940E0D57267262E55405FD0420246154A400AF31E679A7755405FD0420246154A400AF31E679A7755403599F1B6D2BD4940E0D57267262E55403599F1B6D2BD4940
278	Алейский район	\N	47	82.002296999999999	83.317701	52.789396000000004	52.143197000000001	0103000020E6100000010000000500000040F850A22580544052F17F4754124A4040F850A225805440EFCB99ED0A654A40043A933655D45440EFCB99ED0A654A40043A933655D4544052F17F4754124A4040F850A22580544052F17F4754124A40
972	Шелковской район	\N	80	45.708294000000002	46.658836999999998	44.00902	43.414791999999998	0103000020E61000000100000005000000FDF9B660A9DA46403B527DE717B54540FDF9B660A9DA464045813E9127014640873254C55454474045813E9127014640873254C5545447403B527DE717B54540FDF9B660A9DA46403B527DE717B54540
1728	Шатойский район	\N	80	45.355291999999999	46.036152000000001	43.046494000000003	42.512833000000001	0103000020E61000000100000005000000E54350357AAD4640A0A70183A4414540E54350357AAD4640E9BAF083F3854540AED7F4A0A0044740E9BAF083F3854540AED7F4A0A0044740A0A70183A4414540E54350357AAD4640A0A70183A4414540
7450	Шаройский район	\N	80	44.833398000000003	46.660426999999999	44.009798000000004	42.475405000000002	0103000020E61000000100000005000000A24621C9AC6A46406DAD2F12DA3C4540A24621C9AC6A46407AC8940F410146409C3237DF885447407AC8940F410146409C3237DF885447406DAD2F12DA3C4540A24621C9AC6A46406DAD2F12DA3C4540
1161	Шалинский район	\N	80	45.717699000000003	46.361091000000002	43.352496000000002	42.988295999999998	0103000020E610000001000000050000009BAF928FDDDB46404162BB7B807E45409BAF928FDDDB464044FCC3961EAD4540A2F0D93A382E474044FCC3961EAD4540A2F0D93A382E47404162BB7B807E45409BAF928FDDDB46404162BB7B807E4540
1644	Урус-Мартановский район	\N	80	45.337846999999996	45.711492	43.245260999999999	42.922497999999997	0103000020E610000001000000050000009E060C923EAB46400D501A6A147645409E060C923EAB4640FCFD62B6649F4540CDAE7B2B12DB4640FCFD62B6649F4540CDAE7B2B12DB46400D501A6A147645409E060C923EAB46400D501A6A14764540
1303	Ножай-Юртовский район	\N	80	46.059122000000002	46.532156999999998	43.202007999999999	42.841498000000001	0103000020E61000000100000005000000B03C484F9107474020D3DA34B66B4540B03C484F91074740E3C3EC65DB99454032AB77B81D444740E3C3EC65DB99454032AB77B81D44474020D3DA34B66B4540B03C484F9107474020D3DA34B66B4540
1109	Наурский район	\N	80	45.053314	45.854692	44.009810999999999	43.508899	0103000020E61000000100000005000000A0353FFED2864640CAFB389A23C14540A0353FFED28646400E12A27C410146409013268C66ED46400E12A27C410146409013268C66ED4640CAFB389A23C14540A0353FFED2864640CAFB389A23C14540
1417	Надтеречный район	\N	80	44.833398000000003	45.489096000000004	43.728698000000001	43.446399999999997	0103000020E61000000100000005000000A24621C9AC6A46409A779CA223B94540A24621C9AC6A46408F54DFF945DD45405E4D9EB29ABE46408F54DFF945DD45405E4D9EB29ABE46409A779CA223B94540A24621C9AC6A46409A779CA223B94540
1363	Итум-Калинский район	\N	80	45.092731999999998	45.839053	42.835693999999997	42.475783999999997	0103000020E6100000010000000500000076A565A4DE8B4640E3FA777DE63C454076A565A4DE8B464051BB5F05F86A45402B4EB51666EB464051BB5F05F86A45402B4EB51666EB4640E3FA777DE63C454076A565A4DE8B4640E3FA777DE63C4540
1178	Гудермесский район	\N	80	45.915301999999997	46.422446000000001	43.462898000000003	43.176597000000001	0103000020E6100000010000000500000050FBAD9D28F546402EC901BB9A96454050FBAD9D28F5464021B1DD3D40BB4540BB29E5B51236474021B1DD3D40BB4540BB29E5B5123647402EC901BB9A96454050FBAD9D28F546402EC901BB9A964540
1069	Грозненский район	\N	80	45.095975000000003	46.020395999999998	43.562195000000003	42.966192999999997	0103000020E61000000100000005000000E71DA7E8488C4640E34F5436AC7B4540E71DA7E8488C4640C47C7901F6C745400F7C0C569C024740C47C7901F6C745400F7C0C569C024740E34F5436AC7B4540E71DA7E8488C4640E34F5436AC7B4540
1066	Веденский район	\N	80	45.795197000000002	46.311450000000001	43.090299000000002	42.677799	0103000020E610000001000000050000004C70EA03C9E5464079211D1EC25645404C70EA03C9E5464046EEE9EA8E8B45406B2BF697DD27474046EEE9EA8E8B45406B2BF697DD27474079211D1EC25645404C70EA03C9E5464079211D1EC2564540
990	Ачхой-Мартановский район	\N	80	45.138807	45.546894000000002	43.395398999999998	42.809395000000002	0103000020E610000001000000050000005ABA826DC4914640E1455F419A6745405ABA826DC491464080EF366F9CB245407730629F00C6464080EF366F9CB245407730629F00C64640E1455F419A6745405ABA826DC4914640E1455F419A674540
7448	 Курчалоевский район	\N	80	44.833398000000003	46.660426999999999	44.009798000000004	42.475405000000002	0103000020E61000000100000005000000A24621C9AC6A46406DAD2F12DA3C4540A24621C9AC6A46407AC8940F410146409C3237DF885447407AC8940F410146409C3237DF885447406DAD2F12DA3C4540A24621C9AC6A46406DAD2F12DA3C4540
8	Пригородный район	\N	79	44.313192000000001	44.957554000000002	43.27852	42.697687000000002	0103000020E6100000010000000500000036AFEAAC1628464014ECBFCE4D59454036AFEAAC1628464016A4198BA6A34540B6132521917A464016A4198BA6A34540B6132521917A464014ECBFCE4D59454036AFEAAC1628464014ECBFCE4D594540
1004	Правобережный район	\N	79	44.336297000000002	44.708297999999999	43.419074000000002	43.118898999999999	0103000020E61000000100000005000000185FB4C70B2B464078431A15388F4540185FB4C70B2B46404D4D8237A4B545403EE94482A95A46404D4D8237A4B545403EE94482A95A464078431A15388F4540185FB4C70B2B464078431A15388F4540
1592	Моздокский район	\N	79	44.265366	44.848435000000002	43.836956999999998	43.393098999999999	0103000020E6100000010000000500000034BC5983F72146408F8B6A1151B2454034BC5983F721464042942F6821EB454011E4A084996C464042942F6821EB454011E4A084996C46408F8B6A1151B2454034BC5983F72146408F8B6A1151B24540
1834	Кировский район	\N	79	44.037742000000001	44.490797999999998	43.448827999999999	43.236795000000001	0103000020E61000000100000005000000C3D7D7BAD40446409C6D6E4C4F9E4540C3D7D7BAD4044640B9C3263273B945409A780778D23E4640B9C3263273B945409A780778D23E46409C6D6E4C4F9E4540C3D7D7BAD40446409C6D6E4C4F9E4540
1040	Ирафский район	\N	79	43.397781999999999	44.085594999999998	43.323658999999999	42.759822	0103000020E61000000100000005000000FF774485EAB245400264E8D841614540FF774485EAB245402D077AA86DA94540BED9E6C6F40A46402D077AA86DA94540BED9E6C6F40A46400264E8D841614540FF774485EAB245400264E8D841614540
1061	Дигорский район	\N	79	43.845295999999998	44.239198000000002	43.320793000000002	42.944893999999998	0103000020E6100000010000000500000045B8C9A832EC4540E3175E49F278454045B8C9A832EC454093E4B9BE0FA9454062A2410A9E1E464093E4B9BE0FA9454062A2410A9E1E4640E3175E49F278454045B8C9A832EC4540E3175E49F2784540
628	Владикавказ городской округ	\N	79	44.618825999999999	44.709924000000001	43.113844	42.792838000000003	0103000020E610000001000000050000000EF5BBB0354F4640568330B77B6545400EF5BBB0354F4640446CB070928E4540A05225CADE5A4640446CB070928E4540A05225CADE5A4640568330B77B6545400EF5BBB0354F4640568330B77B654540
1777	Ардонский район	\N	79	44.173791999999999	44.481392999999997	43.279195999999999	43.037896000000003	0103000020E610000001000000050000003927F6D03E1646401A53B0C6D98445403927F6D03E1646404696CCB1BCA34540FCC22B499E3D46404696CCB1BCA34540FCC22B499E3D46401A53B0C6D98445403927F6D03E1646401A53B0C6D9844540
754	Алагирский район	\N	79	43.713467999999999	44.510795000000002	43.148195000000001	42.547130000000003	0103000020E610000001000000050000000B5F5FEB52DB45408B54185B084645400B5F5FEB52DB45402237C30DF8924540ECFA05BB614146402237C30DF8924540ECFA05BB614146408B54185B084645400B5F5FEB52DB45408B54185B08464540
7452	Черкесск городской округ	\N	78	42.026009999999999	42.085909000000001	44.268737000000002	44.175513000000002	0103000020E610000001000000050000003AAFB14B54034540ED82C135771646403AAFB14B54034540D21C59F9652246404EB7EC10FF0A4540D21C59F9652246404EB7EC10FF0A4540ED82C135771646403AAFB14B54034540ED82C13577164640
645	Хабезский район	\N	78	41.585000000000001	41.951998000000003	44.305492000000001	43.904699000000001	0103000020E610000001000000050000007B14AE47E1CA4440A9DC442DCDF345407B14AE47E1CA44404698A25C1A274640C0ED0912DBF944404698A25C1A274640C0ED0912DBF94440A9DC442DCDF345407B14AE47E1CA4440A9DC442DCDF34540
1159	Усть-Джегутинский район	\N	78	41.805993999999998	42.337598999999997	44.165393999999999	43.775295	0103000020E61000000100000005000000D862B7CF2AE744404CE0D6DD3CE34540D862B7CF2AE74440317A6EA12B154640C614AC71362B4540317A6EA12B154640C614AC71362B45404CE0D6DD3CE34540D862B7CF2AE744404CE0D6DD3CE34540
796	Урупский район	\N	78	40.676622999999999	41.395797000000002	44.144911999999998	43.385939	0103000020E61000000100000005000000575C1C959B5644401FA0FB7266B14540575C1C959B5644402366F6798C1246406E6DE179A9B244402366F6798C1246406E6DE179A9B244401FA0FB7266B14540575C1C959B5644401FA0FB7266B14540
656	Прикубанский район	\N	78	41.925991000000003	42.611288999999999	44.368650000000002	44.062018000000002	0103000020E61000000100000005000000F7B182DF86F64440B5E1B034F0074640F7B182DF86F64440D0D556EC2F2F4640C8B3CBB73E4E4540D0D556EC2F2F4640C8B3CBB73E4E4540B5E1B034F0074640F7B182DF86F64440B5E1B034F0074640
7455	Ногайский район	\N	78	40.693035999999999	42.679578999999997	44.496468999999998	43.187358000000003	0103000020E61000000100000005000000AF795567B55844406E52D158FB974540AF795567B5584440293DD34B8C3F46403106D671FC564540293DD34B8C3F46403106D671FC5645406E52D158FB974540AF795567B55844406E52D158FB974540
967	Малокарачаевский район	\N	78	42.200192999999999	42.679578999999997	44.037508000000003	43.438290000000002	0103000020E61000000100000005000000AEF199EC9F194540F91400E319B84540AEF199EC9F19454050ABE80FCD0446403106D671FC56454050ABE80FCD0446403106D671FC564540F91400E319B84540AEF199EC9F194540F91400E319B84540
534	Карачаевский район	\N	78	41.510052999999999	42.436881	43.928179999999998	43.187358000000003	0103000020E61000000100000005000000041DAD6A49C144406E52D158FB974540041DAD6A49C1444090662C9ACEF64540349F73B7EB37454090662C9ACEF64540349F73B7EB3745406E52D158FB974540041DAD6A49C144406E52D158FB974540
612	Карачаевск городской округ	\N	78	41.881875000000001	41.943589000000003	43.862766000000001	43.747396999999999	0103000020E610000001000000050000007B14AE47E1F04440731074B4AADF45407B14AE47E1F04440E50CC51D6FEE4540C4EE3B86C7F84440E50CC51D6FEE4540C4EE3B86C7F84440731074B4AADF45407B14AE47E1F04440731074B4AADF4540
747	Зеленчукский район	\N	78	41.032401	41.823197	44.190438999999998	43.275474000000003	0103000020E61000000100000005000000C9AD49B725844440FC7266BB42A34540C9AD49B72584444004711E4E601846402995F0845EE9444004711E4E601846402995F0845EE94440FC7266BB42A34540C9AD49B725844440FC7266BB42A34540
576	Адыге-Хабльский район	\N	78	41.593218999999998	42.064332	44.499535999999999	44.264598999999997	0103000020E61000000100000005000000D32EA699EECB4440F3C64961DE214640D32EA699EECB44405B96AFCBF03F46400B0BEE073C0845405B96AFCBF03F46400B0BEE073C084540F3C64961DE214640D32EA699EECB4440F3C64961DE214640
7454	Абазинский район	\N	78	40.693035999999999	42.679578999999997	44.496468999999998	43.187358000000003	0103000020E61000000100000005000000AF795567B55844406E52D158FB974540AF795567B5584440293DD34B8C3F46403106D671FC564540293DD34B8C3F46403106D671FC5645406E52D158FB974540AF795567B55844406E52D158FB974540
7453	Нальчик	\N	77	43.558211999999997	43.693651000000003	43.547097000000001	43.438146000000003	0103000020E610000001000000050000000C1EA67D73C74540C66F0A2B15B845400C1EA67D73C74540AF5E454607C645403AEB538EC9D84540AF5E454607C645403AEB538EC9D84540C66F0A2B15B845400C1EA67D73C74540C66F0A2B15B84540
1604	Эльбрусский район	\N	77	42.398083	43.271496999999997	43.662194999999997	43.133940000000003	0103000020E61000000100000005000000FA0B3D62F432454029D027F224914540FA0B3D62F4324540904946CEC2D4454026FBE769C0A24540904946CEC2D4454026FBE769C0A2454029D027F224914540FA0B3D62F432454029D027F224914540
1563	Черекский район	\N	77	43.016483000000001	43.789994999999998	43.506093999999997	42.888725999999998	0103000020E6100000010000000500000051F86C1D1C8245406D8D08C6C171454051F86C1D1C824540D5592DB0C7C045407380608E1EE54540D5592DB0C7C045407380608E1EE545406D8D08C6C171454051F86C1D1C8245406D8D08C6C1714540
1519	Чегемский район	\N	77	42.862313999999998	43.806793999999996	43.647297999999999	43.088396000000003	0103000020E6100000010000000500000004711E4E606E4540728C648F508B454004711E4E606E454013622EA9DAD24540F44D9A0645E7454013622EA9DAD24540F44D9A0645E74540728C648F508B454004711E4E606E4540728C648F508B4540
1461	Урванский район	\N	77	43.584991000000002	44.098010000000002	43.641297000000002	43.075963999999999	0103000020E6100000010000000500000028BA2EFCE0CA454030D63730B989454028BA2EFCE0CA4540EF02250516D245402A5778978B0C4640EF02250516D245402A5778978B0C464030D63730B989454028BA2EFCE0CA454030D63730B9894540
1408	Терский район	\N	77	44.070692000000001	44.475518000000001	43.730696999999999	43.350391999999999	0103000020E610000001000000050000005F0B7A6F0C094640D86322A5D9AC45405F0B7A6F0C0946408524B37A87DD4540655419C6DD3C46408524B37A87DD4540655419C6DD3C4640D86322A5D9AC45405F0B7A6F0C094640D86322A5D9AC4540
669	Прохладненский район	\N	77	43.639195000000001	44.419220000000003	44.019671000000002	43.636096999999999	0103000020E6100000010000000500000024624A24D1D14540B70A62A06BD1454024624A24D1D14540FED64E948402464021EA3E00A9354640FED64E948402464021EA3E00A9354640B70A62A06BD1454024624A24D1D14540B70A62A06BD14540
969	Нальчик городской округ	\N	77	43.468083999999998	43.693651000000003	43.547089999999997	43.421064999999999	0103000020E61000000100000005000000F3E32F2DEABB4540C03E3A75E5B54540F3E32F2DEABB4540FCFB8C0B07C645403AEB538EC9D84540FCFB8C0B07C645403AEB538EC9D84540C03E3A75E5B54540F3E32F2DEABB4540C03E3A75E5B54540
346	Майский район	\N	77	43.875793999999999	44.277223999999997	43.768192999999997	43.380881000000002	0103000020E610000001000000050000003A048E041AF045407A5567B5C0B045403A048E041AF045401002F22554E2454049D576137C2346401002F22554E2454049D576137C2346407A5567B5C0B045403A048E041AF045407A5567B5C0B04540
7451	Лескенский район	\N	77	42.398083	44.475527	44.020572000000001	42.888719000000002	0103000020E61000000100000005000000FA0B3D62F4324540BB2A508BC1714540FA0B3D62F43245404E9B711AA2024640B8AE9811DE3C46404E9B711AA2024640B8AE9811DE3C4640BB2A508BC1714540FA0B3D62F4324540BB2A508BC1714540
774	Зольский район	\N	77	42.404766000000002	43.418999999999997	43.960296	43.345796	0103000020E6100000010000000500000031444E5FCF334540378B170B43AC454031444E5FCF334540643DB5FAEAFA45401283C0CAA1B54540643DB5FAEAFA45401283C0CAA1B54540378B170B43AC454031444E5FCF334540378B170B43AC4540
533	Баксанский район	\N	77	43.147098	43.835800999999996	43.865951000000003	43.524498000000001	0103000020E610000001000000050000004CA7751BD4924540A1681EC022C345404CA7751BD492454021787C7BD7EE4540677BF486FBEA454021787C7BD7EE4540677BF486FBEA4540A1681EC022C345404CA7751BD4924540A1681EC022C34540
719	Сунженский район	\N	76	44.833694000000001	45.277524999999997	43.521791	42.823905000000003	0103000020E610000001000000050000008B6F287CB66A4640650113B8756945408B6F287CB66A46406F2C280CCAC2454044696FF085A346406F2C280CCAC2454044696FF085A34640650113B8756945408B6F287CB66A4640650113B875694540
762	Назрановский район	\N	76	44.568466999999998	45.147627999999997	43.416003000000003	42.614837999999999	0103000020E6100000010000000500000078EDD286C3484640452BF702B34E454078EDD286C3484640DA0418963FB54540A8FC6B79E5924640DA0418963FB54540A8FC6B79E5924640452BF702B34E454078EDD286C3484640452BF702B34E4540
767	Малгобекский район	\N	76	44.477288000000001	44.885590000000001	43.615411000000002	43.323448999999997	0103000020E61000000100000005000000FA62EFC5173D46404276DEC666A94540FA62EFC5173D4640A14CA3C9C5CE454013D55B035B714640A14CA3C9C5CE454013D55B035B7146404276DEC666A94540FA62EFC5173D46404276DEC666A94540
7446	Джейрахский район	\N	76	44.477305000000001	45.293892	43.615417999999998	42.614910999999999	0103000020E61000000100000005000000D09B8A54183D4640AF795567B54E4540D09B8A54183D464053AF5B04C6CE45402C47C8409EA5464053AF5B04C6CE45402C47C8409EA54640AF795567B54E4540D09B8A54183D4640AF795567B54E4540
7293	Хасавюрт городской округ	\N	75	46.548479	46.617280999999998	43.288606999999999	43.218803000000001	0103000020E610000001000000050000007AC5538F3446474023A298BC019C45407AC5538F34464740C632FD12F1A4454099B85510034F4740C632FD12F1A4454099B85510034F474023A298BC019C45407AC5538F3446474023A298BC019C4540
7299	Махачкала	\N	75	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
7292	Дербент городской округ	\N	75	48.275337999999998	48.326828999999996	42.095300999999999	42.023899999999998	0103000020E610000001000000050000004BAC8C463E234840EC2FBB270F0345404BAC8C463E2348405723BBD2320C454033315D88D52948405723BBD2320C454033315D88D5294840EC2FBB270F0345404BAC8C463E234840EC2FBB270F034540
1330	Шамильский район	\N	75	46.267395999999998	46.805999	42.539498000000002	42.191096999999999	0103000020E61000000100000005000000658A39083A2247408EAED2DD75184540658A39083A224740F3203D450E454540EACDA8F92A674740F3203D450E454540EACDA8F92A6747408EAED2DD75184540658A39083A2247408EAED2DD75184540
1208	Чародинский район	\N	75	46.539191000000002	46.981898000000001	42.370193	41.883592999999998	0103000020E6100000010000000500000016A6EF3504454740BDFC4E9319F1444016A6EF3504454740A41AF67B622F454000016BD5AE7D4740A41AF67B622F454000016BD5AE7D4740BDFC4E9319F1444016A6EF3504454740BDFC4E9319F14440
1090	Цунтинский район	\N	75	45.607548000000001	46.266112	42.413297	42.079945000000002	0103000020E6100000010000000500000007600322C4CD4640473D44A33B0A454007600322C4CD4640784485EAE63445405D8940F50F224740784485EAE63445405D8940F50F224740473D44A33B0A454007600322C4CD4640473D44A33B0A4540
894	Цумадинский район	\N	75	45.735548999999999	46.299393999999999	42.618493999999998	42.278995000000002	0103000020E6100000010000000500000081CD397826DE4640AF5FB01BB623454081CD397826DE4640D862B7CF2A4F45402F4FE78A52264740D862B7CF2A4F45402F4FE78A52264740AF5FB01BB623454081CD397826DE4640AF5FB01BB6234540
621	Хунзахский район	\N	75	46.455297000000002	46.916896000000001	42.694094999999997	42.472997999999997	0103000020E61000000100000005000000C47B0E2C473A47406589CE328B3C4540C47B0E2C473A474097A8DE1AD8584540A7EA1ED95C75474097A8DE1AD8584540A7EA1ED95C7547406589CE328B3C4540C47B0E2C473A47406589CE328B3C4540
416	Хивский район	\N	75	47.719693999999997	48.165590000000002	41.904694999999997	41.659799	0103000020E610000001000000050000004F90D8EE1EDC47407D772B4B74D444404F90D8EE1EDC474067EDB60BCDF34440B745990D3215484067EDB60BCDF34440B745990D321548407D772B4B74D444404F90D8EE1EDC47407D772B4B74D44440
22	Хасавюртовский район	\N	75	46.328139999999998	47.011893000000001	43.547195000000002	43.112495000000003	0103000020E610000001000000050000003541D47D002A474055FB743C668E45403541D47D002A474072C45A7C0AC645409206B7B58581474072C45A7C0AC645409206B7B58581474055FB743C668E45403541D47D002A474055FB743C668E4540
1858	Унцукульский район	\N	75	46.631492000000001	47.144395000000003	42.879894	42.572392000000001	0103000020E61000000100000005000000C3D7D7BAD4504740FB3E1C2444494540C3D7D7BAD45047402BF9D85DA07045405C5A0D897B9247402BF9D85DA07045405C5A0D897B924740FB3E1C2444494540C3D7D7BAD4504740FB3E1C2444494540
1782	Тляратинский район	\N	75	46.122695999999998	46.782158000000003	42.359095000000003	41.802576999999999	0103000020E61000000100000005000000CDACA580B40F4740CAC2D7D7BAE64440CDACA580B40F47401D9430D3F62D45400327DBC01D6447401D9430D3F62D45400327DBC01D644740CAC2D7D7BAE64440CDACA580B40F4740CAC2D7D7BAE64440
535	Тарумовский район	\N	75	46.307803	46.974128	44.939400999999997	43.887199000000003	0103000020E610000001000000050000002B4EB516662747409F05A1BC8FF145402B4EB51666274740336ABE4A3E784640170FEF39B07C4740336ABE4A3E784640170FEF39B07C47409F05A1BC8FF145402B4EB516662747409F05A1BC8FF14540
1447	Табасаранский район	\N	75	47.688791999999999	48.347194000000002	42.129593999999997	41.771293999999997	0103000020E610000001000000050000008BDF14562AD84740EECC04C3B9E244408BDF14562AD8474000E143899610454008AF5DDA702C484000E143899610454008AF5DDA702C4840EECC04C3B9E244408BDF14562AD84740EECC04C3B9E24440
782	Сулейман-Стальский район	\N	75	47.830294000000002	48.403626000000003	41.829900000000002	41.541395000000001	0103000020E610000001000000050000005308E41247EA4740E59B6D6E4CC544405308E41247EA4740A779C7293AEA44405CE84A04AA334840A779C7293AEA44405CE84A04AA334840E59B6D6E4CC544405308E41247EA4740E59B6D6E4CC54440
7291	Советский район	\N	75	45.103879999999997	48.591796000000002	44.992620000000002	41.185778999999997	0103000020E61000000100000005000000AF5A99F04B8D46404CA4349BC7974440AF5A99F04B8D464082AD122C0E7F4640AAF3A8F8BF4B484082AD122C0E7F4640AAF3A8F8BF4B48404CA4349BC7974440AF5A99F04B8D46404CA4349BC7974440
1539	Сергокалинский район	\N	75	47.485897999999999	47.851297000000002	42.514501000000003	42.222799999999999	0103000020E610000001000000050000008D98D9E731BE47403FC6DCB5841C45408D98D9E731BE47403161342BDB4145406A17D34CF7EC47403161342BDB4145406A17D34CF7EC47403FC6DCB5841C45408D98D9E731BE47403FC6DCB5841C4540
1410	Рутульский район	\N	75	46.757975000000002	47.560898000000002	41.937897999999997	41.369062999999997	0103000020E61000000100000005000000C217265305614740F294D5743DAF4440C217265305614740ED7DAA0A0DF8444027327381CBC74740ED7DAA0A0DF8444027327381CBC74740F294D5743DAF4440C217265305614740F294D5743DAF4440
1355	Ногайский район	\N	75	45.103907	46.449089999999998	44.993327000000001	43.816614000000001	0103000020E61000000100000005000000A96917D34C8D464056BABBCE86E84540A96917D34C8D4640ED9DD156257F4640F67AF7C77B394740ED9DD156257F4640F67AF7C77B39474056BABBCE86E84540A96917D34C8D464056BABBCE86E84540
1287	Новолакский район	\N	75	46.387250000000002	46.591095000000003	43.261906000000003	43.082996999999999	0103000020E6100000010000000500000021B072689131474043554CA59F8A454021B07268913147402750C42286A1454021EA3E00A94B47402750C42286A1454021EA3E00A94B474043554CA59F8A454021B072689131474043554CA59F8A4540
7294	Махачкала городской округ	\N	75	47.283993000000002	47.887031999999998	44.007153000000002	42.885694000000001	0103000020E610000001000000050000007FA5F3E159A44740B821C66B5E7145407FA5F3E159A44740BE88B663EA004640B340BB438AF14740BE88B663EA004640B340BB438AF14740B821C66B5E7145407FA5F3E159A44740B821C66B5E714540
7301	Махачкала 	\N	75	47.412613999999998	47.556038999999998	43.012613000000002	42.940809000000002	0103000020E6100000010000000500000095EF1989D0B447402864E76D6C78454095EF1989D0B447409240834D9D814540782634492CC747409240834D9D814540782634492CC747402864E76D6C78454095EF1989D0B447402864E76D6C784540
674	Магарамкентский район	\N	75	47.827294000000002	48.590708999999997	41.914203999999998	41.420898999999999	0103000020E61000000100000005000000A91611C5E4E94740A5F5B704E0B54440A91611C5E4E94740AAEFFCA204F54440F7393E5A9C4B4840AAEFFCA204F54440F7393E5A9C4B4840A5F5B704E0B54440A91611C5E4E94740A5F5B704E0B54440
341	Левашинский район	\N	75	47.061193000000003	47.579295999999999	42.616596000000001	42.305599000000001	0103000020E6100000010000000500000040DF162CD58747405C5837DE1D27454040DF162CD5874740166C239EEC4E4540105A0F5F26CA4740166C239EEC4E4540105A0F5F26CA47405C5837DE1D27454040DF162CD58747405C5837DE1D274540
9	Лакский район	\N	75	46.925995999999998	47.274794	42.344996000000002	41.900292999999998	0103000020E61000000100000005000000081D740987764740ABE80FCD3CF34440081D7409877647401BA034D4282C45408A9125732CA347401BA034D4282C45408A9125732CA34740ABE80FCD3CF34440081D740987764740ABE80FCD3CF34440
1648	Курахский район	\N	75	47.466997999999997	48.111494	41.746696	41.482596999999998	0103000020E6100000010000000500000011A62897C6BB4740E8120EBDC5BD444011A62897C6BB4740EA060ABC93DF4440A1D9756F450E4840EA060ABC93DF4440A1D9756F450E4840E8120EBDC5BD444011A62897C6BB4740E8120EBDC5BD4440
650	Кумторкалинский район	\N	75	46.936596000000002	47.508868	43.368797000000001	42.8994	0103000020E610000001000000050000003FC8B260E2774740DE02098A1F7345403FC8B260E277474074EE76BD34AF45408FFD2C9622C1474074EE76BD34AF45408FFD2C9622C14740DE02098A1F7345403FC8B260E2774740DE02098A1F734540
1867	Кулинский район	\N	75	47.058793999999999	47.4054	42.166694999999997	41.804996000000003	0103000020E61000000100000005000000BB99D18F8687474096B4E21B0AE74440BB99D18F868747400FB402435615454032E6AE25E4B347400FB402435615454032E6AE25E4B3474096B4E21B0AE74440BB99D18F8687474096B4E21B0AE74440
7297	Кировский район	\N	75	45.103879999999997	48.591796000000002	44.992620000000002	41.185778999999997	0103000020E61000000100000005000000AF5A99F04B8D46404CA4349BC7974440AF5A99F04B8D464082AD122C0E7F4640AAF3A8F8BF4B484082AD122C0E7F4640AAF3A8F8BF4B48404CA4349BC7974440AF5A99F04B8D46404CA4349BC7974440
677	Кизлярский район	\N	75	46.434033999999997	47.529654999999998	44.397632999999999	43.637095000000002	0103000020E6100000010000000500000010AD156D8E374740FAB836548CD1454010AD156D8E374740BA675DA3E5324640D9942BBCCBC34740BA675DA3E5324640D9942BBCCBC34740FAB836548CD1454010AD156D8E374740FAB836548CD14540
653	Кизилюртовский район	\N	75	46.733792999999999	47.12359	43.415393999999999	43.074252000000001	0103000020E610000001000000050000005184D4EDEC5D4740D0D4EB16818945405184D4EDEC5D4740317A6EA12BB545406B0E10CCD18F4740317A6EA12BB545406B0E10CCD18F4740D0D4EB16818945405184D4EDEC5D4740D0D4EB1681894540
1709	Каякентский район	\N	75	47.697290000000002	48.111727000000002	42.607506000000001	42.221698000000004	0103000020E61000000100000005000000F7E978CC40D9474058CB9D99601C4540F7E978CC40D94740D80FB1C1C24D4540448A01124D0E4840D80FB1C1C24D4540448A01124D0E484058CB9D99601C4540F7E978CC40D9474058CB9D99601C4540
1621	Карабудахкентский район	\N	75	47.256594	47.811599999999999	42.928597000000003	42.445892000000001	0103000020E61000000100000005000000C72C7B12D8A0474026C632FD12394540C72C7B12D8A04740F5143944DC76454080B74082E2E74740F5143944DC76454080B74082E2E7474026C632FD12394540C72C7B12D8A0474026C632FD12394540
1533	Кайтагский район	\N	75	47.622990000000001	48.059894999999997	42.262194999999998	41.929493000000001	0103000020E6100000010000000500000016DEE522BECF4740336E6AA0F9F6444016DEE522BECF47405D16139B8F214540D218ADA3AA0748405D16139B8F214540D218ADA3AA074840336E6AA0F9F6444016DEE522BECF4740336E6AA0F9F64440
1469	Казбековский район	\N	75	46.469642999999998	46.887898999999997	43.148497999999996	42.842799999999997	0103000020E61000000100000005000000CDE506431D3C4740CE88D2DEE06B4540CDE506431D3C4740BDC282FB019345405793A7ACA6714740BDC282FB019345405793A7ACA6714740CE88D2DEE06B4540CDE506431D3C4740CE88D2DEE06B4540
1407	Докузпаринский район	\N	75	47.705806000000003	48.018231	41.480995999999998	41.185778999999997	0103000020E6100000010000000500000009A9DBD957DA47404CA4349BC797444009A9DBD957DA4740DFC0E44691BD4440FE62B66455024840DFC0E44691BD4440FE62B664550248404CA4349BC797444009A9DBD957DA47404CA4349BC7974440
1122	Дербентский район	\N	75	47.983592000000002	48.486198999999999	42.323594	41.814095999999999	0103000020E61000000100000005000000BA4DB857E6FD4740F7E6374C34E84440BA4DB857E6FD4740469737876B294540882CD2C43B3E4840469737876B294540882CD2C43B3E4840F7E6374C34E84440BA4DB857E6FD4740F7E6374C34E84440
1047	Дахадаевский район	\N	75	47.372988999999997	47.782494999999997	42.262796000000002	41.867694999999998	0103000020E610000001000000050000004562821ABEAF47408CF337A110EF44404562821ABEAF474083C2A04CA32145404A24D1CB28E4474083C2A04CA32145404A24D1CB28E447408CF337A110EF44404562821ABEAF47408CF337A110EF4440
870	Гунибский район	\N	75	46.745893000000002	47.117499000000002	42.497798000000003	42.177593999999999	0103000020E610000001000000050000005DA8FC6B795F4740A0FB7266BB1645405DA8FC6B795F4740D20149D8B73F454007280D350A8F4740D20149D8B73F454007280D350A8F4740A0FB7266BB1645405DA8FC6B795F4740A0FB7266BB164540
704	Гумбетовский район	\N	75	46.332496999999996	46.907795999999998	42.943593999999997	42.652797999999997	0103000020E610000001000000050000005182FE428F2A4740757286E28E5345405182FE428F2A4740D5592DB0C778454045B8C9A832744740D5592DB0C778454045B8C9A832744740757286E28E5345405182FE428F2A4740757286E28E534540
609	Гергебильский район	\N	75	46.836793	47.202793999999997	42.621499	42.426096000000001	0103000020E61000000100000005000000C84274081C6B47406C7A50508A364540C84274081C6B474094BF7B478D4F45409AE95E27F599474094BF7B478D4F45409AE95E27F59947406C7A50508A364540C84274081C6B47406C7A50508A364540
223	Буйнакский район	\N	75	46.636297999999996	47.540992000000003	43.128991999999997	42.579098000000002	0103000020E610000001000000050000004E417E3672514740EA961DE21F4A45404E417E36725147400AB952CF82904540E6B2D1393FC547400AB952CF82904540E6B2D1393FC54740EA961DE21F4A45404E417E3672514740EA961DE21F4A4540
21	Ботлихский район	\N	75	46.005645000000001	46.519491000000002	42.910196999999997	42.579596000000002	0103000020E610000001000000050000006631B1F9B80047403B72A433304A45406631B1F9B80047406AF5D555817445407EC85BAE7E4247406AF5D555817445407EC85BAE7E4247403B72A433304A45406631B1F9B80047403B72A433304A4540
1200	Бежтинский Участок район	\N	75	45.911358	46.316687000000002	42.213799000000002	41.986781000000001	0103000020E6100000010000000500000057790261A7F4464037A8FDD64EFE444057790261A7F44640717500C45D1B4540C0081A3389284740717500C45D1B4540C0081A338928474037A8FDD64EFE444057790261A7F4464037A8FDD64EFE4440
256	Бабаюртовский район	\N	75	46.416336999999999	47.669288999999999	43.897106000000001	43.273696000000001	0103000020E61000000100000005000000B08EE3874A354740E485747808A34540B08EE3874A354740CF85915ED4F2454049490F43ABD54740CF85915ED4F2454049490F43ABD54740E485747808A34540B08EE3874A354740E485747808A34540
1817	Ахтынский район	\N	75	47.257689999999997	47.840390999999997	41.608896999999999	41.19838	0103000020E61000000100000005000000CC4065FCFBA047401A170E8464994440CC4065FCFBA04740F6D03E56F0CD4440266DAAEE91EB4740F6D03E56F0CD4440266DAAEE91EB47401A170E8464994440CC4065FCFBA047401A170E8464994440
1796	Ахвахский район	\N	75	46.227995999999997	46.486494999999998	42.648800000000001	42.447496000000001	0103000020E6100000010000000500000035CF11F92E1D4740A08B868C4739454035CF11F92E1D474089D2DEE00B5345407155D977453E474089D2DEE00B5345407155D977453E4740A08B868C4739454035CF11F92E1D4740A08B868C47394540
1736	Акушинский район	\N	75	47.188249999999996	47.559694999999998	42.370292999999997	41.988497000000002	0103000020E610000001000000050000006ABC749318984740D998D71187FE44406ABC7493189847400778D2C2652F45400B5EF415A4C747400778D2C2652F45400B5EF415A4C74740D998D71187FE44406ABC749318984740D998D71187FE4440
1706	Агульский район	\N	75	47.309595000000002	47.813594999999999	42.069805000000002	41.678995999999998	0103000020E61000000100000005000000A80018CFA0A74740B20E4757E9D64440A80018CFA0A74740740CC85EEF084540359886E123E84740740CC85EEF084540359886E123E84740B20E4757E9D64440A80018CFA0A74740B20E4757E9D64440
7288	 Кировский район	\N	75	45.103879999999997	48.591796000000002	44.992620000000002	41.185778999999997	0103000020E61000000100000005000000AF5A99F04B8D46404CA4349BC7974440AF5A99F04B8D464082AD122C0E7F4640AAF3A8F8BF4B484082AD122C0E7F4640AAF3A8F8BF4B48404CA4349BC7974440AF5A99F04B8D46404CA4349BC7974440
7439	Буденновск городской округ	\N	81	44.110559000000002	44.195368999999999	44.825316999999998	44.760359999999999	0103000020E61000000100000005000000A5A31CCC260E4640E197FA7953614640A5A31CCC260E46409AEAC9FCA36946407CD3F4D9011946409AEAC9FCA36946407CD3F4D901194640E197FA7953614640A5A31CCC260E4640E197FA7953614640
1126	Шпаковский район	\N	81	41.409460000000003	42.404398	45.347496999999997	44.740893	0103000020E6100000010000000500000095826E2F69B44440EC6AF294D55E464095826E2F69B44440A33A1DC87AAC4640AE484C50C3334540A33A1DC87AAC4640AE484C50C3334540EC6AF294D55E464095826E2F69B44440EC6AF294D55E4640
100	Туркменский район	\N	81	42.958398000000003	44.280664000000002	45.734293000000001	45.237900000000003	0103000020E61000000100000005000000A24621C9AC7A4540F5DBD781739E4640A24621C9AC7A454043572250FDDD4640109546CCEC23464043572250FDDD4640109546CCEC234640F5DBD781739E4640A24621C9AC7A4540F5DBD781739E4640
874	Труновский район	\N	81	41.727094999999998	42.386899	45.820898999999997	45.345996	0103000020E61000000100000005000000E50AEF7211DD4440FE45D09849AC4640E50AEF7211DD4440D828EB3713E9464074ED0BE885314540D828EB3713E9464074ED0BE885314540FE45D09849AC4640E50AEF7211DD4440FE45D09849AC4640
980	Степновский район	\N	81	44.199995999999999	44.939093	44.510098999999997	44.053499000000002	0103000020E6100000010000000500000058AA0B789919464032AF230ED906464058AA0B7899194640745C8DEC4A41464086730D3334784640745C8DEC4A41464086730D333478464032AF230ED906464058AA0B789919464032AF230ED9064640
857	Советский район	\N	81	43.597090999999999	44.329999999999998	44.618298000000003	44.051698000000002	0103000020E6100000010000000500000033DE567A6DCC454062A2410A9E06464033DE567A6DCC454053978C63244F46400AD7A3703D2A464053978C63244F46400AD7A3703D2A464062A2410A9E06464033DE567A6DCC454062A2410A9E064640
437	Пятигорск городской округ	\N	81	42.953420999999999	43.228485999999997	44.086719000000002	44.000922000000003	0103000020E61000000100000005000000E92807B3097A454068EC4B361E004640E92807B3097A45408E78B29B190B464003CC7C073F9D45408E78B29B190B464003CC7C073F9D454068EC4B361E004640E92807B3097A454068EC4B361E004640
18	Предгорный район	\N	81	42.293142000000003	43.423994999999998	44.311956000000002	43.801326000000003	0103000020E61000000100000005000000C28A53AD852545409EB7B1D991E64540C28A53AD852545403FE5982CEE2746407155D97745B645403FE5982CEE2746407155D97745B645409EB7B1D991E64540C28A53AD852545409EB7B1D991E64540
1295	Петровский район	\N	81	42.378993999999999	43.229194999999997	45.608097000000001	44.953200000000002	0103000020E61000000100000005000000ABB019E0823045400B462575027A4640ABB019E082304540DAE55B1FD6CD46400FB40243569D4540DAE55B1FD6CD46400FB40243569D45400B462575027A4640ABB019E0823045400B462575027A4640
1866	Новоселицкий район	\N	81	43.077694000000001	43.872388999999998	44.958896000000003	44.510098999999997	0103000020E61000000100000005000000378C82E0F1894540745C8DEC4A414640378C82E0F1894540F321A81ABD7A4640F0315871AAEF4540F321A81ABD7A4640F0315871AAEF4540745C8DEC4A414640378C82E0F1894540745C8DEC4A414640
1413	Новоалександровский район	\N	81	40.843556999999997	41.501491999999999	45.760236999999996	45.213498000000001	0103000020E61000000100000005000000EBA7FFACF96B444076E107E7539B4640EBA7FFACF96B4440C51A2E724FE14640529ACDE330C04440C51A2E724FE14640529ACDE330C0444076E107E7539B4640EBA7FFACF96B444076E107E7539B4640
1312	Нефтекумский район	\N	81	44.557794999999999	45.707979000000002	44.992696000000002	44.252707999999998	0103000020E61000000100000005000000A86F99D36547464002B859BC58204640A86F99D3654746405D6F9BA9107F46409DA04D0E9FDA46405D6F9BA9107F46409DA04D0E9FDA464002B859BC58204640A86F99D36547464002B859BC58204640
216	Невинномысск городской округ	\N	81	41.427892999999997	42.338399000000003	45.001607	44.329864999999998	0103000020E61000000100000005000000FA97A432C5B644402A8C2D04392A4640FA97A432C5B64440EB387EA834804640E3FF8EA8502B4540EB387EA834804640E3FF8EA8502B45402A8C2D04392A4640FA97A432C5B644402A8C2D04392A4640
7442	Невинномысск	\N	81	41.889870000000002	42.007252999999999	44.676814	44.586098999999997	0103000020E6100000010000000500000084D89942E7F14440F19BC24A054B464084D89942E7F14440CBBC55D7A156464021E692AAED004540CBBC55D7A156464021E692AAED004540F19BC24A054B464084D89942E7F14440F19BC24A054B4640
1320	Минераловодский район	\N	81	42.655898999999998	43.247897999999999	44.570093	44.094397000000001	0103000020E61000000100000005000000533D997FF453454096EB6D33150C4640533D997FF4534540DA56B3CEF8484640355F251FBB9F4540DA56B3CEF8484640355F251FBB9F454096EB6D33150C4640533D997FF453454096EB6D33150C4640
7443	Лермонтов городской округ	\N	81	42.928879000000002	43.050395000000002	44.125942999999999	44.076500000000003	0103000020E610000001000000050000007978CF81E57645406F1283C0CA0946407978CF81E57645407F1475E61E104640E370E657738645407F1475E61E104640E370E657738645406F1283C0CA0946407978CF81E57645406F1283C0CA094640
1275	Левокумский район	\N	81	44.376792999999999	45.717699000000003	45.424787000000002	44.622095999999999	0103000020E610000001000000050000004D2EC6C03A304640787C7BD7A04F46404D2EC6C03A3046400B62A06B5FB646409BAF928FDDDB46400B62A06B5FB646409BAF928FDDDB4640787C7BD7A04F46404D2EC6C03A304640787C7BD7A04F4640
1268	Курский район	\N	81	44.102097000000001	45.504313000000003	44.285497999999997	43.658569	0103000020E610000001000000050000008602B683110D464068942EFD4BD445408602B683110D46406589CE328B2446404DF910548DC046406589CE328B2446404DF910548DC0464068942EFD4BD445408602B683110D464068942EFD4BD44540
745	Красногвардейский район	\N	81	41.156610999999998	42.084589000000001	46.008347000000001	45.545597999999998	0103000020E61000000100000005000000D09849D40B944440AA61BF27D6C54640D09849D40B9444408602B68311014740F94CF6CFD30A45408602B68311014740F94CF6CFD30A4540AA61BF27D6C54640D09849D40B944440AA61BF27D6C54640
7441	Кочубеевский район	\N	81	40.90025	45.717699000000003	46.236939	43.658569	0103000020E61000000100000005000000AC1C5A643B73444068942EFD4BD44540AC1C5A643B734440CF126404541E47409BAF928FDDDB4640CF126404541E47409BAF928FDDDB464068942EFD4BD44540AC1C5A643B73444068942EFD4BD44540
1221	Кисловодск городской округ	\N	81	42.642747999999997	42.783594999999998	43.947465999999999	43.860166	0103000020E61000000100000005000000E2C8039145524540C99063EB19EE4540E2C80391455245403509DE9046F94540912749D74C6445403509DE9046F94540912749D74C644540C99063EB19EE4540E2C8039145524540C99063EB19EE4540
1087	Кировский район	\N	81	43.239525999999998	44.230395000000001	44.162601000000002	43.805847999999997	0103000020E610000001000000050000005645B8C9A89E454004C6FA0626E745405645B8C9A89E454001A60C1CD0144640BA1457957D1D464001A60C1CD0144640BA1457957D1D464004C6FA0626E745405645B8C9A89E454004C6FA0626E74540
965	Ипатовский район	\N	81	41.944792999999997	43.358696000000002	46.135281999999997	45.523994000000002	0103000020E61000000100000005000000AF3E1EFAEEF844406EA6423C12C34640AF3E1EFAEEF8444065DEAAEB501147405F9A22C0E9AD454065DEAAEB501147405F9A22C0E9AD45406EA6423C12C34640AF3E1EFAEEF844406EA6423C12C34640
744	Изобильненский район	\N	81	41.349227999999997	42.100093999999999	45.656995999999999	45.054633000000003	0103000020E610000001000000050000007A6CCB80B3AC44402524D236FE8646407A6CCB80B3AC444029CDE67118D446404E4354E1CF0C454029CDE67118D446404E4354E1CF0C45402524D236FE8646407A6CCB80B3AC44402524D236FE864640
686	Железноводск городской округ	\N	81	42.983964	43.186894000000002	44.171097000000003	44.058396999999999	0103000020E610000001000000050000007E384888F27D45409E978A8D790746407E384888F27D4540CCB8A981E6154640C9E88024EC974540CCB8A981E6154640C9E88024EC9745409E978A8D790746407E384888F27D45409E978A8D79074640
157	Грачевский район	\N	81	42.139296000000002	42.861199999999997	45.557797999999998	44.888196000000001	0103000020E61000000100000005000000583B8A73D411454011381268B0714640583B8A73D411454019E3C3EC65C7464058A835CD3B6E454019E3C3EC65C7464058A835CD3B6E454011381268B0714640583B8A73D411454011381268B0714640
5	Георгиевский район	\N	81	43.165792000000003	43.790489999999998	44.590297999999997	43.937198000000002	0103000020E610000001000000050000001FF818AC3895454035F0A31AF6F745401FF818AC38954540757286E28E4B464053E8BCC62EE54540757286E28E4B464053E8BCC62EE5454035F0A31AF6F745401FF818AC3895454035F0A31AF6F74540
1382	Буденновский район	\N	81	43.663594000000003	44.603797	45.154099000000002	44.427799	0103000020E6100000010000000500000032E9EFA5F0D4454079211D1EC236464032E9EFA5F0D4454054AC1A84B993464022365838494D464054AC1A84B993464022365838494D464079211D1EC236464032E9EFA5F0D4454079211D1EC2364640
1234	Благодарненский район	\N	81	43.128295999999999	44.046697999999999	45.357897999999999	44.825994999999999	0103000020E61000000100000005000000931ADA006C9045406BD44334BA694640931ADA006C904540E3A6069ACFAD4640F1643733FA054640E3A6069ACFAD4640F1643733FA0546406BD44334BA694640931ADA006C9045406BD44334BA694640
1797	Арзгирский район	\N	81	43.752994000000001	44.845965	45.596595000000001	44.896994999999997	0103000020E61000000100000005000000C80A7E1B62E0454077D66EBBD0724640C80A7E1B62E0454083FA96395DCC4640C347C494486C464083FA96395DCC4640C347C494486C464077D66EBBD0724640C80A7E1B62E0454077D66EBBD0724640
1420	Апанасенковский район	\N	81	42.685597999999999	44.112302	46.236939	45.539400000000001	0103000020E61000000100000005000000FC19DEACC157454030BB270F0BC54640FC19DEACC1574540CF126404541E474040A374E95F0E4640CF126404541E474040A374E95F0E464030BB270F0BC54640FC19DEACC157454030BB270F0BC54640
1374	Андроповский район	\N	81	42.110388	42.790494000000002	44.953499999999998	44.297693000000002	0103000020E6100000010000000500000078EFA831210E4540C39FE1CD1A26464078EFA831210E4540355EBA490C7A464095D74AE82E654540355EBA490C7A464095D74AE82E654540C39FE1CD1A26464078EFA831210E4540C39FE1CD1A264640
1714	Александровский район	\N	81	42.656995000000002	43.388492999999997	44.996495000000003	44.446193999999998	0103000020E610000001000000050000005951836918544540F1D58EE21C394640595183691854454053D0ED258D7F4640CADC7C23BAB1454053D0ED258D7F4640CADC7C23BAB14540F1D58EE21C3946405951836918544540F1D58EE21C394640
7422	Воркута городской округ	\N	25	63.933449000000003	64.105090000000004	67.539413999999994	67.463470000000001	0103000020E61000000100000005000000F1BDBF417BF74F40562B137EA9DD5040F1BDBF417BF74F404A404CC285E25040BF4868CBB90650404A404CC285E25040BF4868CBB9065040562B137EA9DD5040F1BDBF417BF74F40562B137EA9DD5040
1830	Ухтинский район	\N	25	51.861170000000001	55.011561	64.468298000000004	62.604604999999999	0103000020E61000000100000005000000EE258DD13AEE4940C1FF56B2634D4F40EE258DD13AEE494010B22C98F81D50405C74B2D47A814B4010B22C98F81D50405C74B2D47A814B40C1FF56B2634D4F40EE258DD13AEE4940C1FF56B2634D4F40
778	Усть-Цилемский район	\N	25	48.999389000000001	53.786116	67.099691000000007	64.390798000000004	0103000020E61000000100000005000000B77D8FFAEB7F4840E7559DD502195040B77D8FFAEB7F4840282D5C5661C65040616EF7729FE44A40282D5C5661C65040616EF7729FE44A40E7559DD502195040B77D8FFAEB7F4840E7559DD502195040
850	Усть-Куломский район	\N	25	52.542864999999999	56.348632000000002	62.754502000000002	60.831910000000001	0103000020E610000001000000050000004F92AE997C454A40919BE1067C6A4E404F92AE997C454A402062838593604F40672B2FF99F2C4C402062838593604F40672B2FF99F2C4C40919BE1067C6A4E404F92AE997C454A40919BE1067C6A4E40
824	Усть-Вымский район	\N	25	49.039102999999997	50.709583000000002	62.77102	61.618729999999999	0103000020E610000001000000050000007616BD5301854840EC866D8B32CF4E407616BD5301854840ED478AC8B0624F401766A19DD35A4940ED478AC8B0624F401766A19DD35A4940EC866D8B32CF4E407616BD5301854840EC866D8B32CF4E40
7429	Усинский район	\N	25	53.762571000000001	58.849631000000002	67.007075999999998	65.348607000000001	0103000020E6100000010000000500000063F030ED9BE14A40070ABC934F56504063F030ED9BE14A408925E5EE73C050407A5567B5C06C4D408925E5EE73C050407A5567B5C06C4D40070ABC934F56504063F030ED9BE14A40070ABC934F565040
756	Удорский район	\N	25	45.399552	51.057581999999996	64.793091000000004	62.177028	0103000020E6100000010000000500000094861A8524B34640F73C7FDAA8164F4094861A8524B3464020F0C000C23250404C6BD3D85E87494020F0C000C23250404C6BD3D85E874940F73C7FDAA8164F4094861A8524B34640F73C7FDAA8164F40
833	Троицко-Печорский район	\N	25	55.138350000000003	59.634301000000001	63.679521999999999	61.302978000000003	0103000020E6100000010000000500000068B3EA73B5914B4029B4ACFBC7A64E4068B3EA73B5914B40CD74AF93FAD64F40F96871C630D14D40CD74AF93FAD64F40F96871C630D14D4029B4ACFBC7A64E4068B3EA73B5914B4029B4ACFBC7A64E40
7428	Троицко-Печорский	\N	25	55.138350000000003	59.634301000000001	63.679521999999999	61.302978000000003	0103000020E6100000010000000500000068B3EA73B5914B4029B4ACFBC7A64E4068B3EA73B5914B40CD74AF93FAD64F40F96871C630D14D40CD74AF93FAD64F40F96871C630D14D4029B4ACFBC7A64E4068B3EA73B5914B4029B4ACFBC7A64E40
199	Сысольский район	\N	25	48.967740999999997	50.970185000000001	61.538795999999998	60.624499999999998	0103000020E61000000100000005000000C9FFE4EFDE7B48400E2DB29DEF4F4E40C9FFE4EFDE7B4840999B6F44F7C44E40EE08A7052F7C4940999B6F44F7C44E40EE08A7052F7C49400E2DB29DEF4F4E40C9FFE4EFDE7B48400E2DB29DEF4F4E40
86	Сыктывдинский район	\N	25	49.361913000000001	51.577382999999998	62.219696999999996	60.925697	0103000020E61000000100000005000000A67F492A53AE4840AE80423D7D764E40A67F492A53AE4840C00303081F1C4F401822A7AFE7C94940C00303081F1C4F401822A7AFE7C94940AE80423D7D764E40A67F492A53AE4840AE80423D7D764E40
895	Сосногорский район	\N	25	53.374139	56.839840000000002	64.474705999999998	62.591303000000003	0103000020E610000001000000050000003E9468C9E3AF4A406B8313D1AF4B4F403E9468C9E3AF4A40C24D4695611E5040B3EF8AE07F6B4C40C24D4695611E5040B3EF8AE07F6B4C406B8313D1AF4B4F403E9468C9E3AF4A406B8313D1AF4B4F40
7426	Сосногорск городской округ	\N	25	53.826082	53.995288000000002	63.614445000000003	63.535873000000002	0103000020E610000001000000050000003AE8120EBDE94A409BE7887C97C44F403AE8120EBDE94A406A183E22A6CE4F40F60CE19865FF4A406A183E22A6CE4F40F60CE19865FF4A409BE7887C97C44F403AE8120EBDE94A409BE7887C97C44F40
420	Прилузский район	\N	25	48.419769000000002	50.460884999999998	61.136696999999998	59.198729999999998	0103000020E61000000100000005000000F46F97FDBA354840F65D11FC6F994D40F46F97FDBA3548400C3B8C497F914E40C51B9947FE3A49400C3B8C497F914E40C51B9947FE3A4940F65D11FC6F994D40F46F97FDBA354840F65D11FC6F994D40
1277	Печорский район	\N	25	54.521782000000002	60.221367999999998	65.829621000000003	64.203012999999999	0103000020E610000001000000050000001CD2A8C0C9424B406CEA3C2AFE0C50401CD2A8C0C9424B40CAC4AD8218755040C23060C9551C4E40CAC4AD8218755040C23060C9551C4E406CEA3C2AFE0C50401CD2A8C0C9424B406CEA3C2AFE0C5040
7427	Печора городской округ	\N	25	57.116169999999997	57.351655000000001	65.184528	65.103814999999997	0103000020E610000001000000050000005E6397A8DE8E4C406475ABE7A44650405E6397A8DE8E4C40904C874ECF4B5040C93CF20703AD4C40904C874ECF4B5040C93CF20703AD4C406475ABE7A44650405E6397A8DE8E4C406475ABE7A4465040
795	Корткеросский район	\N	25	51.016483999999998	53.570034999999997	62.855901000000003	60.830730000000003	0103000020E610000001000000050000002174D0251C8249402EE7525C556A4E402174D0251C8249408ECEF9298E6D4F40A54929E8F6C84A408ECEF9298E6D4F40A54929E8F6C84A402EE7525C556A4E402174D0251C8249402EE7525C556A4E40
394	Койгородский район	\N	25	49.940283999999998	52.371889000000003	60.984197000000002	59.748517999999997	0103000020E61000000100000005000000DD79E2395BF84840D13B1570CFDF4D40DD79E2395BF8484021E9D32AFA7D4E40FF5E0A0F9A2F4A4021E9D32AFA7D4E40FF5E0A0F9A2F4A40D13B1570CFDF4D40DD79E2395BF84840D13B1570CFDF4D40
901	Княжпогостский район	\N	25	49.752392999999998	53.270141000000002	64.523797999999999	62.180895	0103000020E61000000100000005000000A25EF0694EE0484045813E9127174F40A25EF0694EE0484074ED0BE8852150408527F4FA93A24A4074ED0BE8852150408527F4FA93A24A4045813E9127174F40A25EF0694EE0484045813E9127174F40
1225	Интинский район	\N	25	58.771065	63.052973999999999	67.013163000000006	64.918107000000006	0103000020E610000001000000050000008D0B0742B2624D40A3CEDC43C23A50408D0B0742B2624D401BA19FA9D7C05040E7C41EDAC7864F401BA19FA9D7C05040E7C41EDAC7864F40A3CEDC43C23A50408D0B0742B2624D40A3CEDC43C23A5040
1528	Ижемский район	\N	25	51.943572000000003	55.515605999999998	66.359897000000004	64.291798999999997	0103000020E61000000100000005000000EEB5A0F7C6F849405A80B6D5AC125040EEB5A0F7C6F849406D3B6D8D0897504089CF9D60FFC14B406D3B6D8D0897504089CF9D60FFC14B405A80B6D5AC125040EEB5A0F7C6F849405A80B6D5AC125040
7430	Вуктыльский район	\N	25	55.825678000000003	59.838541999999997	64.654747	63.089013999999999	0103000020E610000001000000050000006B8313D1AFE94B406D718DCF648B4F406B8313D1AFE94B40DD09F65FE72950404529215855EB4D40DD09F65FE72950404529215855EB4D406D718DCF648B4F406B8313D1AFE94B406D718DCF648B4F40
6897	Вуктыл городской округ	\N	25	57.289779000000003	57.334470000000003	63.882655	63.838251999999997	0103000020E61000000100000005000000A708707A17A54C403EE76ED74BEB4F40A708707A17A54C405053CBD6FAF04F401FBFB7E9CFAA4C405053CBD6FAF04F401FBFB7E9CFAA4C403EE76ED74BEB4F40A708707A17A54C403EE76ED74BEB4F40
7423	Воркутинский район	\N	25	61.631444000000002	66.253608999999997	68.423308000000006	66.204678999999999	0103000020E61000000100000005000000B2A03028D3D04E4064CBF275198D5040B2A03028D3D04E40A708707A171B5140293E3E213B905040A708707A171B5140293E3E213B90504064CBF275198D5040B2A03028D3D04E4064CBF275198D5040
1897	Суоярвский район	\N	24	30.785615	33.361398999999999	63.047696000000002	61.603299999999997	0103000020E610000001000000050000003E3F8C101EC93E40A1D634EF38CD4E403E3F8C101EC93E4034130CE71A864F404FE78A5242AE404034130CE71A864F404FE78A5242AE4040A1D634EF38CD4E403E3F8C101EC93E40A1D634EF38CD4E40
7433	Сортавала городской округ	\N	24	30.030526999999999	31.0915	62.248289	61.538068000000003	0103000020E610000001000000050000001EA5129ED0073E4017838769DFC44E401EA5129ED0073E40707A17EFC71F4F408195438B6C173F40707A17EFC71F4F408195438B6C173F4017838769DFC44E401EA5129ED0073E4017838769DFC44E40
400	Сегежский район	\N	24	32.947797000000001	36.256974999999997	64.231694000000005	63.142496000000001	0103000020E610000001000000050000009B1F7F6951794040C9E7154F3D924F409B1F7F69517940407C2B1213D40E5040DE718A8EE42042407C2B1213D40E5040DE718A8EE4204240C9E7154F3D924F409B1F7F6951794040C9E7154F3D924F40
1828	Пудожский район	\N	24	35.674570000000003	37.945987000000002	62.807398999999997	61.403863999999999	0103000020E610000001000000050000006E6E4C4F58D641401004C8D0B1B34E406E6E4C4F58D641405BE9B5D958674F4078B81D1A16F942405BE9B5D958674F4078B81D1A16F942401004C8D0B1B34E406E6E4C4F58D641401004C8D0B1B34E40
550	Пряжинский район	\N	24	31.948295999999999	34.100794	62.178694999999998	61.154837999999998	0103000020E6100000010000000500000078EDD286C3F23F40CA1649BBD1934E4078EDD286C3F23F40B77A4E7ADF164F4007D15AD1E60C4140B77A4E7ADF164F4007D15AD1E60C4140CA1649BBD1934E4078EDD286C3F23F40CA1649BBD1934E40
536	Прионежский район	\N	24	33.701492999999999	35.614195000000002	62.055399999999999	61.139015999999998	0103000020E61000000100000005000000BCAFCA85CAD9404074CFBA46CB914E40BCAFCA85CAD940406519E25817074F40F12E17F19DCE41406519E25817074F40F12E17F19DCE414074CFBA46CB914E40BCAFCA85CAD9404074CFBA46CB914E40
326	Питкярантский район	\N	24	30.722697	32.320791	61.911898000000001	61.213087999999999	0103000020E61000000100000005000000D5EAABAB02B93E40C495B377469B4E40D5EAABAB02B93E40D7A4DB12B9F44E40F2ECF2AD0F294040D7A4DB12B9F44E40F2ECF2AD0F294040C495B377469B4E40D5EAABAB02B93E40C495B377469B4E40
1761	Олонецкий район	\N	24	32.225498000000002	33.920878999999999	61.535395999999999	60.679319999999997	0103000020E610000001000000050000001EA8531EDD1C404065C22FF5F3564E401EA8531EDD1C404061342BDB87C44E405E49F25CDFF5404061342BDB87C44E405E49F25CDFF5404065C22FF5F3564E401EA8531EDD1C404065C22FF5F3564E40
1745	Муезерский район	\N	24	29.997622	33.325699999999998	64.611898999999994	62.899000000000001	0103000020E6100000010000000500000026C5C72764FF3D40508D976E12734F4026C5C72764FF3D40205D6C5A292750405227A089B0A94040205D6C5A292750405227A089B0A94040508D976E12734F4026C5C72764FF3D40508D976E12734F40
1704	Медвежьегорский район	\N	24	32.429693999999998	36.529991000000003	63.811295000000001	61.968437000000002	0103000020E61000000100000005000000CAA4863600374040419E5DBEF5FB4E40CAA48636003740404434BA83D8E74F405116BEBED64342404434BA83D8E74F405116BEBED6434240419E5DBEF5FB4E40CAA4863600374040419E5DBEF5FB4E40
1619	Лоухский район	\N	24	29.361785000000001	34.606589999999997	66.668638000000001	65.430398999999994	0103000020E61000000100000005000000F12E17F19D5C3D40CA4E3FA88B5B5040F12E17F19D5C3D4039B709F7CAAA5040520ABABDA44D414039B709F7CAAA5040520ABABDA44D4140CA4E3FA88B5B5040F12E17F19D5C3D40CA4E3FA88B5B5040
1642	Лахденпохский район	\N	24	29.308191999999998	30.556985000000001	61.761125	61.165092999999999	0103000020E610000001000000050000008AE3C0ABE54E3D4036E675C421954E408AE3C0ABE54E3D408195438B6CE14E40D15CA791968E3E408195438B6CE14E40D15CA791968E3E4036E675C421954E408AE3C0ABE54E3D4036E675C421954E40
19	Кондопожский район	\N	24	33.003096999999997	34.811658000000001	62.824199999999998	61.971874	0103000020E610000001000000050000009CDB847B6580404096EA025E66FC4E409CDB847B658040407DAEB6627F694F40B5C4CA68E46741407DAEB6627F694F40B5C4CA68E467414096EA025E66FC4E409CDB847B6580404096EA025E66FC4E40
430	Кемский район	\N	24	32.411493999999998	34.977728999999997	66.029122999999998	64.753094000000004	0103000020E610000001000000050000000740DCD5AB34404016342DB1323050400740DCD5AB344040EE23B726DD815040E6AC4F39267D4140EE23B726DD815040E6AC4F39267D414016342DB1323050400740DCD5AB34404016342DB132305040
349	Калевальский район	\N	24	29.602236999999999	33.024396000000003	65.678549000000004	64.362797	0103000020E61000000100000005000000EF703B342C9A3D409085E81038175040EF703B342C9A3D40F2EEC8586D6B50409D137B681F834040F2EEC8586D6B50409D137B681F8340409085E81038175040EF703B342C9A3D409085E81038175040
459	Беломорский район	\N	24	32.597301000000002	36.591059000000001	64.864801999999997	63.579906000000001	0103000020E610000001000000050000001E6FF25B744C404089601C5C3ACA4F401E6FF25B744C4040FCE07CEA58375040D48041D2A74B4240FCE07CEA58375040D48041D2A74B424089601C5C3ACA4F401E6FF25B744C404089601C5C3ACA4F40
423	Усвятский район	\N	32	30.398792	31.061865000000001	56.021377000000001	55.589748	0103000020E610000001000000050000000CE8853B17663E40D270CADC7CCB4B400CE8853B17663E407CF1457BBC024C405DC47762D60F3F407CF1457BBC024C405DC47762D60F3F40D270CADC7CCB4B400CE8853B17663E40D270CADC7CCB4B40
1837	Стругокрасненский район	\N	32	28.462698	29.702921	58.563200000000002	57.901899999999998	0103000020E61000000100000005000000B3EC496073763C4096218E7571F34C40B3EC496073763C40B98D06F016484D40EFAB72A1F2B33D40B98D06F016484D40EFAB72A1F2B33D4096218E7571F34C40B3EC496073763C4096218E7571F34C40
72	Себежский район	\N	32	28.125623000000001	29.277892000000001	56.542499999999997	55.954531000000003	0103000020E610000001000000050000001BA034D428203C40540262122EFA4B401BA034D428203C403D0AD7A370454C40EED11BEE23473D403D0AD7A370454C40EED11BEE23473D40540262122EFA4B401BA034D428203C40540262122EFA4B40
735	Пыталовский район	\N	32	27.660295000000001	28.319533	57.353296999999998	56.820295999999999	0103000020E610000001000000050000005BB6D61709A93B4012859675FF684C405BB6D61709A93B4030630AD638AD4C4026FE28EACC513C4030630AD638AD4C4026FE28EACC513C4012859675FF684C405BB6D61709A93B4012859675FF684C40
1618	Пушкиногорский район	\N	32	28.408296	29.105999000000001	57.193294000000002	56.782302000000001	0103000020E610000001000000050000006E162F1686683C4036CCD07822644C406E162F1686683C40AB4198DBBD984C40A1681EC0221B3D40AB4198DBBD984C40A1681EC0221B3D4036CCD07822644C406E162F1686683C4036CCD07822644C40
515	Пустошкинский район	\N	32	28.971395999999999	29.793192000000001	56.654699000000001	56.049897999999999	0103000020E6100000010000000500000018778368ADF83C406211C30E63064C4018778368ADF83C40A9DC442DCD534C40E77283A10ECB3D40A9DC442DCD534C40E77283A10ECB3D406211C30E63064C4018778368ADF83C406211C30E63064C40
1171	Псковский район	\N	32	27.525836000000002	29.252998999999999	58.290297000000002	57.495514999999997	0103000020E61000000100000005000000390F27309D863B40B6D617096DBF4C40390F27309D863B403F90BC7328254D40B3EBDE8AC4403D403F90BC7328254D40B3EBDE8AC4403D40B6D617096DBF4C40390F27309D863B40B6D617096DBF4C40
601	Порховский район	\N	32	28.6861	29.993220000000001	58.113798000000003	57.323695999999998	0103000020E610000001000000050000001DC9E53FA4AF3C404AECDADE6EA94C401DC9E53FA4AF3C40D42CD0EE900E4D40AEBB79AA43FE3D40D42CD0EE900E4D40AEBB79AA43FE3D404AECDADE6EA94C401DC9E53FA4AF3C404AECDADE6EA94C40
1870	Плюсский район	\N	32	28.461493999999998	29.986958999999999	58.868288999999997	58.252229	0103000020E61000000100000005000000DB4C857824763C40280D350A49204D40DB4C857824763C40FF3C0D18246F4D402C7E5358A9FC3D40FF3C0D18246F4D402C7E5358A9FC3D40280D350A49204D40DB4C857824763C40280D350A49204D40
488	Печорский район	\N	32	27.327317000000001	28.058599000000001	58.098866999999998	57.395361000000001	0103000020E61000000100000005000000C26C020CCB533B40938E72309BB24C40C26C020CCB533B40AAD381ACA70C4D400C941458000F3C40AAD381ACA70C4D400C941458000F3C40938E72309BB24C40C26C020CCB533B40938E72309BB24C40
1291	Палкинский район	\N	32	27.646794	28.392952000000001	57.704006999999997	57.319890000000001	0103000020E61000000100000005000000C03FA54A94A53B40A228D027F2A84C40C03FA54A94A53B40D993C0E61CDA4C40D6E5948098643C40D993C0E61CDA4C40D6E5948098643C40A228D027F2A84C40C03FA54A94A53B40A228D027F2A84C40
1421	Островский район	\N	32	28.015992000000001	29.219294999999999	57.571299000000003	57.045495000000003	0103000020E6100000010000000500000065FF3C0D18043C40D690B8C7D2854C4065FF3C0D18043C40679E5C5320C94C40232D95B723383D40679E5C5320C94C40232D95B723383D40D690B8C7D2854C4065FF3C0D18043C40D690B8C7D2854C40
1432	Опочецкий район	\N	32	28.256094000000001	29.389094	56.917195	56.474997000000002	0103000020E61000000100000005000000ABB35A608F413C405C59A2B3CC3C4C40ABB35A608F413C40018750A566754C40E01115AA9B633D40018750A566754C40E01115AA9B633D405C59A2B3CC3C4C40ABB35A608F413C405C59A2B3CC3C4C40
502	Новосокольнический район	\N	32	29.392696000000001	30.383996	56.691097999999997	56.151201	0103000020E6100000010000000500000020459DB987643D40AE0FEB8D5A134C4020459DB987643D405E2A36E675584C4079CBD58F4D623E405E2A36E675584C4079CBD58F4D623E40AE0FEB8D5A134C4020459DB987643D40AE0FEB8D5A134C40
685	Новоржевский район	\N	32	28.864792000000001	29.651797999999999	57.356099	56.831797000000002	0103000020E61000000100000005000000AAD72D0263DD3C4099F4F752786A4C40AAD72D0263DD3C40B491EBA694AD4C402499D53BDCA63D40B491EBA694AD4C402499D53BDCA63D4099F4F752786A4C40AAD72D0263DD3C4099F4F752786A4C40
220	Невельский район	\N	32	29.182769	30.442495000000001	56.291998	55.703341999999999	0103000020E61000000100000005000000FEB8FDF2C92E3D409DF3531C07DA4B40FEB8FDF2C92E3D40AB3FC23060254C40BEA4315A47713E40AB3FC23060254C40BEA4315A47713E409DF3531C07DA4B40FEB8FDF2C92E3D409DF3531C07DA4B40
1747	Локнянский район	\N	32	29.623895999999998	30.985714999999999	57.177187000000004	56.570999999999998	0103000020E61000000100000005000000EF1AF4A5B79F3D400C022B8716494C40EF1AF4A5B79F3D4060234910AE964C40382D78D157FC3E4060234910AE964C40382D78D157FC3E400C022B8716494C40EF1AF4A5B79F3D400C022B8716494C40
1776	Куньинский район	\N	32	30.728096000000001	31.509018999999999	56.519188	55.702641999999997	0103000020E610000001000000050000003259DC7F64BA3E40E4654D2CF0D94B403259DC7F64BA3E40E23C9CC074424C40E90AB6114F823F40E23C9CC074424C40E90AB6114F823F40E4654D2CF0D94B403259DC7F64BA3E40E4654D2CF0D94B40
696	Красногородский район	\N	32	27.903172999999999	28.571825	57.079847000000001	56.508754000000003	0103000020E6100000010000000500000055A1815836E73B40C7DADFD91E414C4055A1815836E73B4084D72E6D388A4C4003098A1F63923C4084D72E6D388A4C4003098A1F63923C40C7DADFD91E414C4055A1815836E73B40C7DADFD91E414C40
880	Дновский район	\N	32	29.727993000000001	30.544461999999999	57.995632999999998	57.657798	0103000020E6100000010000000500000089B7CEBF5DBA3D40E6AF90B932D44C4089B7CEBF5DBA3D40C0E8F2E670FF4C402DEA93DC618B3E40C0E8F2E670FF4C402DEA93DC618B3E40E6AF90B932D44C4089B7CEBF5DBA3D40E6AF90B932D44C40
683	Дедовичский район	\N	32	29.356396	30.683485999999998	57.702323999999997	57.246699	0103000020E61000000100000005000000DB6CACC43C5B3D405B7A34D5939F4C40DB6CACC43C5B3D401399B9C0E5D94C401B4641F0F8AE3E401399B9C0E5D94C401B4641F0F8AE3E405B7A34D5939F4C40DB6CACC43C5B3D405B7A34D5939F4C40
596	Гдовский район	\N	32	27.358281999999999	28.595593999999998	59.021847999999999	58.166397000000003	0103000020E61000000100000005000000D7BE805EB85B3B408693347F4C154D40D7BE805EB85B3B40D3BD4EEACB824D409EB12FD978983C40D3BD4EEACB824D409EB12FD978983C408693347F4C154D40D7BE805EB85B3B408693347F4C154D40
537	Великолукский район	\N	32	30.171994000000002	31.064945999999999	56.779195000000001	55.911396000000003	0103000020E61000000100000005000000B51B7DCC072C3E4045DAC69FA8F44B40B51B7DCC072C3E40761A69A9BC634C408A01124DA0103F40761A69A9BC634C408A01124DA0103F4045DAC69FA8F44B40B51B7DCC072C3E4045DAC69FA8F44B40
543	Бежаницкий район	\N	32	29.240898999999999	30.745450999999999	57.466197999999999	56.633298000000003	0103000020E610000001000000050000009CA38E8EAB3D3D40A54FABE80F514C409CA38E8EAB3D3D40F5BA4560ACBB4C403FC571E0D5BE3E40F5BA4560ACBB4C403FC571E0D5BE3E40A54FABE80F514C409CA38E8EAB3D3D40A54FABE80F514C40
1083	Пестовский район	\N	31	35.143639	36.229216999999998	58.861024999999998	58.406875999999997	0103000020E610000001000000050000000FB743C3629241407EC3448314344D400FB743C362924140EA043411366E4D40F7578FFB561D4240EA043411366E4D40F7578FFB561D42407EC3448314344D400FB743C3629241407EC3448314344D40
371	Шимский район	\N	31	29.618946000000001	31.051696	58.479498	58.022897	0103000020E6100000010000000500000072FDBB3E739E3D409816F549EE024D4072FDBB3E739E3D40AB3FC230603D4D408255F5F23B0D3F40AB3FC230603D4D408255F5F23B0D3F409816F549EE024D4072FDBB3E739E3D409816F549EE024D40
477	Чудовский район	\N	31	31.246504999999999	32.476047000000001	59.434798000000001	58.793196000000002	0103000020E61000000100000005000000EC4CA1F31A3F3F40B5A84F7287654D40EC4CA1F31A3F3F40E02EFB75A7B74D40F12DAC1BEF3C4040E02EFB75A7B74D40F12DAC1BEF3C4040B5A84F7287654D40EC4CA1F31A3F3F40B5A84F7287654D40
445	Холмский район	\N	31	30.627538999999999	31.871597000000001	57.358497	56.90981	0103000020E61000000100000005000000ECF65965A6A03E4071C971A774744C40ECF65965A6A03E40685BCD3AE3AD4C40AE4A22FB20DF3F40685BCD3AE3AD4C40AE4A22FB20DF3F4071C971A774744C40ECF65965A6A03E4071C971A774744C40
938	Хвойнинский район	\N	31	33.750495999999998	35.366197	59.207641000000002	58.651899	0103000020E61000000100000005000000B0E3BF4010E04040C6A52A6D71534D40B0E3BF4010E040408527F4FA939A4D405872158BDFAE41408527F4FA939A4D405872158BDFAE4140C6A52A6D71534D40B0E3BF4010E04040C6A52A6D71534D40
667	Старорусский район	\N	31	30.759392999999999	32.009093999999997	58.229671000000003	57.369598000000003	0103000020E61000000100000005000000B3CF639467C23E406155BDFC4EAF4C40B3CF639467C23E4079EBFCDB651D4D407F4B00FE2901404079EBFCDB651D4D407F4B00FE290140406155BDFC4EAF4C40B3CF639467C23E406155BDFC4EAF4C40
908	Солецкий район	\N	31	29.630327999999999	30.627395	58.251798000000001	57.876213999999997	0103000020E61000000100000005000000CAC0012D5DA13D400F26C5C727F04C40CAC0012D5DA13D405F99B7EA3A204D4086AC6EF59CA03E405F99B7EA3A204D4086AC6EF59CA03E400F26C5C727F04C40CAC0012D5DA13D400F26C5C727F04C40
1107	Поддорский район	\N	31	30.410855999999999	31.694396000000001	57.739998	57.209699999999998	0103000020E61000000100000005000000895DDBDB2D693E4050FC1873D79A4C40895DDBDB2D693E407E8D2441B8DE4C402579AEEFC3B13F407E8D2441B8DE4C402579AEEFC3B13F4050FC1873D79A4C40895DDBDB2D693E4050FC1873D79A4C40
1475	Парфинский район	\N	31	31.509917999999999	32.193994000000004	58.210996000000002	57.716200000000001	0103000020E6100000010000000500000048A46DFC89823F4096B20C71ACDB4C4048A46DFC89823F401DCBBBEA011B4D4064CF9ECBD41840401DCBBBEA011B4D4064CF9ECBD418404096B20C71ACDB4C4048A46DFC89823F4096B20C71ACDB4C40
1409	Окуловский район	\N	31	32.544193	33.732295999999998	58.748497	58.067028999999998	0103000020E6100000010000000500000027DBC01DA84540401971016894084D4027DBC01DA8454040BA13ECBFCE5F4D40ED7E15E0BBDD4040BA13ECBFCE5F4D40ED7E15E0BBDD40401971016894084D4027DBC01DA84540401971016894084D40
51	Новгородский район	\N	31	30.707695000000001	32.12229	59.092039	58.213295000000002	0103000020E61000000100000005000000F08AE07F2BB53E403EB324404D1B4D40F08AE07F2BB53E40707A17EFC78B4D405D50DF32A70F4040707A17EFC78B4D405D50DF32A70F40403EB324404D1B4D40F08AE07F2BB53E403EB324404D1B4D40
257	Мошенской район	\N	31	34.223297000000002	35.325099000000002	58.757599999999996	58.194336999999997	0103000020E61000000100000005000000C02500FF941C41408DB3E908E0184D40C02500FF941C41408CB96B09F9604D402D7B12D89CA941408CB96B09F9604D402D7B12D89CA941408DB3E908E0184D40C02500FF941C41408DB3E908E0184D40
163	Маревский район	\N	31	31.677292000000001	32.669795999999998	57.587898000000003	57.072727999999998	0103000020E61000000100000005000000AAD72D0263AD3F4072C0AE264F894C40AAD72D0263AD3F4021B1DD3D40CB4C40ED7E15E0BB55404021B1DD3D40CB4C40ED7E15E0BB55404072C0AE264F894C40AAD72D0263AD3F4072C0AE264F894C40
149	Маловишерский район	\N	31	31.835898	32.999693000000001	59.135671000000002	58.4754	0103000020E61000000100000005000000B4CA4C69FDD53F405B423EE8D93C4D40B4CA4C69FDD53F400002D6AA5D914D402385B2F0F57F40400002D6AA5D914D402385B2F0F57F40405B423EE8D93C4D40B4CA4C69FDD53F405B423EE8D93C4D40
549	Любытинский район	\N	31	32.614998	34.049894999999999	59.426623999999997	58.571198000000003	0103000020E610000001000000050000007E8D2441B84E404033C51C041D494D407E8D2441B84E404027D87F9D9BB64D40F19D98F56206414027D87F9D9BB64D40F19D98F56206414033C51C041D494D407E8D2441B84E404033C51C041D494D40
528	Крестецкий район	\N	31	31.702902999999999	33.147798000000002	58.548994	58.007995000000001	0103000020E61000000100000005000000A2427573F1B33F4009C4EBFA05014D40A2427573F1B33F40A1D9756F45464D4005357C0BEB924040A1D9756F45464D4005357C0BEB92404009C4EBFA05014D40A2427573F1B33F4009C4EBFA05014D40
773	Демянский район	\N	31	31.957799999999999	33.329203999999997	58.093995999999997	57.390996000000001	0103000020E61000000100000005000000DA1B7C6132F53F40F46E2C280CB24C40DA1B7C6132F53F4037FA980F080C4D402FDB4E5B23AA404037FA980F080C4D402FDB4E5B23AA4040F46E2C280CB24C40DA1B7C6132F53F40F46E2C280CB24C40
702	Волотовский район	\N	31	30.419345	30.975294000000002	58.063701999999999	57.642493000000002	0103000020E61000000100000005000000BABDA4315A6B3E405874EB353DD24C40BABDA4315A6B3E404B581B6327084D402BFC19DEACF93E404B581B6327084D402BFC19DEACF93E405874EB353DD24C40BABDA4315A6B3E405874EB353DD24C40
526	Валдайский район	\N	31	32.441794000000002	33.692239999999998	58.208199	57.651201	0103000020E61000000100000005000000D6C8AEB48C384040AE0FEB8D5AD34C40D6C8AEB48C384040AB07CC43A61A4D40D47D00529BD84040AB07CC43A61A4D40D47D00529BD84040AE0FEB8D5AD34C40D6C8AEB48C384040AE0FEB8D5AD34C40
44	Боровичский район	\N	31	33.466493	34.738821999999999	58.805	58.073802999999998	0103000020E610000001000000050000000E68E90AB6BB404060AC6F6072094D400E68E90AB6BB4040D7A3703D0A674D405CC823B8915E4140D7A3703D0A674D405CC823B8915E414060AC6F6072094D400E68E90AB6BB404060AC6F6072094D40
952	Батецкий район	\N	31	29.980391999999998	31.054193000000001	58.870690000000003	58.383896999999997	0103000020E61000000100000005000000914259F8FAFA3D402904728923314D40914259F8FAFA3D40257A19C5726F4D4011ACAA97DF0D3F40257A19C5726F4D4011ACAA97DF0D3F402904728923314D40914259F8FAFA3D402904728923314D40
3735	Интинский район	\N	60	43.266871000000002	65.672865999999999	69.865477999999996	65.820004999999995	0103000020E610000001000000050000001BA034D428A245409D6340F67A7450401BA034D428A24540145AD6FD63775140C8258E3C106B5040145AD6FD63775140C8258E3C106B50409D6340F67A7450401BA034D428A245409D6340F67A745040
1913	Апатиты городской округ	\N	30	31.734299	33.738394999999997	67.813901000000001	67.075001999999998	0103000020E610000001000000050000004A7CEE04FBBB3F409D4830D5CCC450404A7CEE04FBBB3F40A14B38F416F45040D44334BA83DE4040A14B38F416F45040D44334BA83DE40409D4830D5CCC450404A7CEE04FBBB3F409D4830D5CCC45040
314	Терский район	\N	30	32.982309999999998	40.295099999999998	67.305601999999993	66.056583000000003	0103000020E6100000010000000500000052448655BC7D40409DA04D0E9F83504052448655BC7D4040E6E5B0FB8ED35040598638D6C5254440E6E5B0FB8ED35040598638D6C52544409DA04D0E9F83504052448655BC7D40409DA04D0E9F835040
53	Североморск городской округ	\N	30	33.071899000000002	37.976629000000003	69.315511000000001	68.5244	0103000020E61000000100000005000000BCCE86FC338940406F8104C58F215140BCCE86FC33894040CFA10C5531545140A0A9D72D02FD4240CFA10C5531545140A0A9D72D02FD42406F8104C58F215140BCCE86FC338940406F8104C58F215140
435	Печенгский район	\N	30	28.417045000000002	33.127702999999997	69.951768999999999	68.729297000000003	0103000020E61000000100000005000000D8F50B76C36A3C408A0453CDAC2E5140D8F50B76C36A3C402F1686C8E97C5140F04C6892589040402F1686C8E97C5140F04C6892589040408A0453CDAC2E5140D8F50B76C36A3C408A0453CDAC2E5140
573	Мончегорск городской округ	\N	30	31.413996000000001	33.976996999999997	68.321297000000001	67.622598999999994	0103000020E61000000100000005000000C1AC50A4FB693F406DE179A9D8E75040C1AC50A4FB693F4063D34A219014514022A5D93C0EFD404063D34A219014514022A5D93C0EFD40406DE179A9D8E75040C1AC50A4FB693F406DE179A9D8E75040
524	Ловозерский район	\N	30	33.490594999999999	41.387245	68.865898999999999	66.373358999999994	0103000020E61000000100000005000000624A24D1CBBE4040B4AA251DE5975040624A24D1CBBE4040E7A8A3E36A3751400F45813E91B14440E7A8A3E36A3751400F45813E91B14440B4AA251DE5975040624A24D1CBBE4040B4AA251DE5975040
408	Кольский район	\N	30	28.433969000000001	36.187094999999999	69.588654000000005	67.669399999999996	0103000020E61000000100000005000000537AA697186F3C4050FC1873D7EA5040537AA697186F3C4037AAD381AC655140601F9DBAF217424037AAD381AC655140601F9DBAF217424050FC1873D7EA5040537AA697186F3C4050FC1873D7EA5040
491	Ковдорский район	\N	30	30.034497999999999	32.070394999999998	67.922897000000006	67.137794999999997	0103000020E6100000010000000500000004C765DCD4083E4059A31EA2D1C8504004C765DCD4083E40E62494BE10FB5040A5660FB402094040E62494BE10FB5040A5660FB40209404059A31EA2D1C8504004C765DCD4083E4059A31EA2D1C85040
370	Кировск городской округ	\N	30	33.526688999999998	34.798299999999998	67.919402000000005	67.066597999999999	0103000020E61000000100000005000000DB148F8B6AC34040A8FE412443C45040DB148F8B6AC3404021787C7BD7FA5040CA32C4B12E66414021787C7BD7FA5040CA32C4B12E664140A8FE412443C45040DB148F8B6AC34040A8FE412443C45040
7286	Кандалакшского района	\N	30	28.417090000000002	41.406135999999996	69.953256999999994	66.054203999999999	0103000020E61000000100000005000000187D0569C66A3C40FED30D1478835040187D0569C66A3C40B7EBA529027D514037DDB243FCB34440B7EBA529027D514037DDB243FCB34440FED30D1478835040187D0569C66A3C40FED30D1478835040
7279	Кандалакшский район	\N	30	28.417090000000002	41.406135999999996	69.953256999999994	66.054203999999999	0103000020E61000000100000005000000187D0569C66A3C40FED30D1478835040187D0569C66A3C40B7EBA529027D514037DDB243FCB34440B7EBA529027D514037DDB243FCB34440FED30D1478835040187D0569C66A3C40FED30D1478835040
1741	Кандалакша городской округ	\N	30	29.033891000000001	33.324928	67.673147	66.344375999999997	0103000020E61000000100000005000000F5A0A014AD083D40BF61A2410A965040F5A0A014AD083D40A29927D714EB504000C79E3D97A94040A29927D714EB504000C79E3D97A94040BF61A2410A965040F5A0A014AD083D40BF61A2410A965040
564	Тосненский район	\N	29	30.417432000000002	31.608912	59.736533999999999	58.992505999999999	0103000020E61000000100000005000000CB4DD4D2DC6A3E40B98AC56F0A7F4D40CB4DD4D2DC6A3E402F3201BF46DE4D40572426A8E19B3F402F3201BF46DE4D40572426A8E19B3F40B98AC56F0A7F4D40CB4DD4D2DC6A3E40B98AC56F0A7F4D40
1194	Тихвинский район	\N	29	32.659492	35.216636000000001	60.296610000000001	59.314163999999998	0103000020E61000000100000005000000A0FCDD3B6A5440404FCAA48636A84D40A0FCDD3B6A54404052D50451F7254E4071917BBABA9B414052D50451F7254E4071917BBABA9B41404FCAA48636A84D40A0FCDD3B6A5440404FCAA48636A84D40
1125	Сланцевский район	\N	29	27.734487000000001	29.032733	59.319096000000002	58.823127999999997	0103000020E6100000010000000500000050560C5707BC3B40003620425C694D4050560C5707BC3B4068244223D8A84D40FE7F9C3061083D4068244223D8A84D40FE7F9C3061083D40003620425C694D4050560C5707BC3B40003620425C694D40
97	Приозерский район	\N	29	29.497682999999999	31.899014000000001	61.188707000000001	60.417831999999997	0103000020E6100000010000000500000071C63027687F3D40739CDB847B354E4071C63027687F3D405DC30C8D27984E406AA510C825E63F405DC30C8D27984E406AA510C825E63F40739CDB847B354E4071C63027687F3D40739CDB847B354E40
438	Подпорожский район	\N	29	33.448293	35.967061999999999	61.313352999999999	60.235174999999998	0103000020E610000001000000050000004B033FAA61B940401CEBE2361A1E4E404B033FAA61B940403F8D7BF31BA84E40289A07B0C8FB41403F8D7BF31BA84E40289A07B0C8FB41401CEBE2361A1E4E404B033FAA61B940401CEBE2361A1E4E40
261	Лужский район	\N	29	28.677440000000001	30.989775000000002	59.276232	58.417071999999997	0103000020E61000000100000005000000930035B56CAD3C40E509849D62354D40930035B56CAD3C40E90DF7915BA34D40FE65F7E461FD3E40E90DF7915BA34D40FE65F7E461FD3E40E509849D62354D40930035B56CAD3C40E509849D62354D40
356	Ломоносовский район	\N	29	28.769121999999999	29.406863000000001	60.047784	59.620730000000002	0103000020E6100000010000000500000055A2EC2DE5C43C40B3D2A41474CF4D4055A2EC2DE5C43C40D3A23EC91D064E40D4F36E2C28683D40D3A23EC91D064E40D4F36E2C28683D40B3D2A41474CF4D4055A2EC2DE5C43C40B3D2A41474CF4D40
225	Лодейнопольский район	\N	29	32.825087000000003	34.647077000000003	61.006005999999999	60.138966000000003	0103000020E6100000010000000500000069AD68739C694040C3A04CA3C9114E4069AD68739C69404036CAFACDC4804E40357F4C6BD352414036CAFACDC4804E40357F4C6BD3524140C3A04CA3C9114E4069AD68739C694040C3A04CA3C9114E40
69	Кировский район	\N	29	28.745873	28.766677999999999	60.748280999999999	60.734172999999998	0103000020E610000001000000050000002BF86D88F1BE3C40984D8061F95D4E402BF86D88F1BE3C40ED9BFBABC75F4E400C90680245C43C40ED9BFBABC75F4E400C90680245C43C40984D8061F95D4E402BF86D88F1BE3C40984D8061F95D4E40
1304	Киришский район	\N	29	31.562397000000001	32.971252	59.770471000000001	59.106577999999999	0103000020E61000000100000005000000575EF23FF98F3F408E3C1059A48D4D40575EF23FF98F3F401AC231CB9EE24D4059164CFC517C40401AC231CB9EE24D4059164CFC517C40408E3C1059A48D4D40575EF23FF98F3F408E3C1059A48D4D40
1405	Кингисеппский район	\N	29	26.580233	29.125250000000001	60.388105000000003	59.108288000000002	0103000020E610000001000000050000005A0F5F268A943A404E469561DC8D4D405A0F5F268A943A400135B56CAD314E40F2D24D6210203D400135B56CAD314E40F2D24D6210203D404E469561DC8D4D405A0F5F268A943A404E469561DC8D4D40
120	Гатчинский район	\N	29	29.576591000000001	30.686091000000001	59.622655000000002	59.013782999999997	0103000020E61000000100000005000000FE2AC0779B933D40D11E2FA4C3814D40FE2AC0779B933D406FD8B628B3CF4D407714E7A8A3AF3E406FD8B628B3CF4D407714E7A8A3AF3E40D11E2FA4C3814D40FE2AC0779B933D40D11E2FA4C3814D40
644	Выборгский район	\N	29	28.721439	28.746862	60.734169000000001	60.718738999999999	0103000020E61000000100000005000000170FEF39B0B83C400CAEB9A3FF5B4E40170FEF39B0B83C40575EF23FF95D4E400AA0185932BF3C40575EF23FF95D4E400AA0185932BF3C400CAEB9A3FF5B4E40170FEF39B0B83C400CAEB9A3FF5B4E40
623	Всеволожский район	\N	29	29.937013	31.899014000000001	60.846325	59.801499	0103000020E6100000010000000500000046ED7E15E0EF3D406B63EC8497E64D4046ED7E15E0EF3D40C364AA60546C4E406AA510C825E63F40C364AA60546C4E406AA510C825E63F406B63EC8497E64D4046ED7E15E0EF3D406B63EC8497E64D40
953	Волховский район	\N	29	31.575243	33.734972999999997	60.846325	59.584865000000001	0103000020E61000000100000005000000C040102043933F409BC937DBDCCA4D40C040102043933F40C364AA60546C4E40B438639813DE4040C364AA60546C4E40B438639813DE40409BC937DBDCCA4D40C040102043933F409BC937DBDCCA4D40
1020	Волосовский район	\N	29	28.847760000000001	29.833024000000002	59.683059	59.032055999999997	0103000020E6100000010000000500000062DBA2CC06D93C40FED137691A844D4062DBA2CC06D93C40861E317A6ED74D407AC8940F41D53D40861E317A6ED74D407AC8940F41D53D40FED137691A844D4062DBA2CC06D93C40FED137691A844D40
906	Бокситогорский район	\N	29	33.571947000000002	35.624588000000003	60.189149999999998	59.083360999999996	0103000020E61000000100000005000000CD052E8F35C940408461C092AB8A4D40CD052E8F35C94040EA04341136184E40AEBCE47FF2CF4140EA04341136184E40AEBCE47FF2CF41408461C092AB8A4D40CD052E8F35C940408461C092AB8A4D40
962	Черняховский район	\N	28	21.334745000000002	22.136429	54.867300999999998	54.4773	0103000020E61000000100000005000000E17F2BD9B1553540BE30992A183D4B40E17F2BD9B1553540E0641BB8036F4B40DA39CD02ED223640E0641BB8036F4B40DA39CD02ED223640BE30992A183D4B40E17F2BD9B1553540BE30992A183D4B40
7463	Центральный район	\N	28	20.35887	20.509571000000001	54.778762	54.717047999999998	0103000020E61000000100000005000000F98381E7DE5B3440C3D4963AC85B4B40F98381E7DE5B34400CAF2479AE634B4072FDBB3E738234400CAF2479AE634B4072FDBB3E73823440C3D4963AC85B4B40F98381E7DE5B3440C3D4963AC85B4B40
879	Славский район	\N	28	21.178025000000002	21.847324	55.294401000000001	54.731498000000002	0103000020E61000000100000005000000D3DEE00B932D3540728BF9B9A15D4B40D3DEE00B932D3540717495EEAEA54B40AC1DC539EAD83540717495EEAEA54B40AC1DC539EAD83540728BF9B9A15D4B40D3DEE00B932D3540728BF9B9A15D4B40
865	Светлый городской округ	\N	28	20.059982000000002	20.260262000000001	54.742102000000003	54.650874999999999	0103000020E610000001000000050000004359F8FA5A0F34405A643BDF4F534B404359F8FA5A0F3440EA25C632FD5E4B403D64CA87A0423440EA25C632FD5E4B403D64CA87A04234405A643BDF4F534B404359F8FA5A0F34405A643BDF4F534B40
7096	Светлогорский	\N	28	19.639102999999999	22.887384999999998	55.294432	54.318204000000001	0103000020E6100000010000000500000086C613419CA333406BBA9EE8BA284B4086C613419CA33340AC72A1F2AFA54B4001F6D1A92BE33640AC72A1F2AFA54B4001F6D1A92BE336406BBA9EE8BA284B4086C613419CA333406BBA9EE8BA284B40
6960	Светлогорск городской округ	\N	28	20.054511000000002	20.223790000000001	54.959403000000002	54.918902000000003	0103000020E61000000100000005000000B345D26EF40D3440501DAB949E754B40B345D26EF40D34409757AEB7CD7A4B40FE2B2B4D4A3934409757AEB7CD7A4B40FE2B2B4D4A393440501DAB949E754B40B345D26EF40D3440501DAB949E754B40
680	Правдинский район	\N	28	20.741067000000001	21.643532	54.582996999999999	54.318294000000002	0103000020E6100000010000000500000014252191B6BD3440AB4198DBBD284B4014252191B6BD344043554CA59F4A4B40F2ED5D83BEA4354043554CA59F4A4B40F2ED5D83BEA43540AB4198DBBD284B4014252191B6BD3440AB4198DBBD284B40
451	Полесский район	\N	28	20.873864999999999	21.637442	55.026200000000003	54.684500999999997	0103000020E61000000100000005000000791EDC9DB5DF3440268A90BA9D574B40791EDC9DB5DF3440DE9387855A834B40CA181F662FA33540DE9387855A834B40CA181F662FA33540268A90BA9D574B40791EDC9DB5DF3440268A90BA9D574B40
472	Озерский район	\N	28	21.604140999999998	22.336825000000001	54.572096000000002	54.326286000000003	0103000020E61000000100000005000000382C0DFCA89A3540439259BDC3294B40382C0DFCA89A3540121615713A494B40A779C7293A563640121615713A494B40A779C7293A563640439259BDC3294B40382C0DFCA89A3540439259BDC3294B40
361	Нестеровский район	\N	28	22.261627000000001	22.792998999999998	54.749096000000002	54.340612999999998	0103000020E6100000010000000500000027C0B0FCF9423640D5CBEF34992B4B4027C0B0FCF94236403FC8B260E25F4B40BDC282FB01CB36403FC8B260E25F4B40BDC282FB01CB3640D5CBEF34992B4B4027C0B0FCF9423640D5CBEF34992B4B40
7094	Нестеровский	\N	28	22.261627000000001	22.792998999999998	54.749096000000002	54.340612999999998	0103000020E6100000010000000500000027C0B0FCF9423640D5CBEF34992B4B4027C0B0FCF94236403FC8B260E25F4B40BDC282FB01CB36403FC8B260E25F4B40BDC282FB01CB3640D5CBEF34992B4B4027C0B0FCF9423640D5CBEF34992B4B40
189	Неманский район	\N	28	21.704239999999999	22.309021999999999	55.098640000000003	54.798000999999999	0103000020E61000000100000005000000F888981249B43540709692E524664B40F888981249B43540EA094B3CA08C4B4098BED7101C4F3640EA094B3CA08C4B4098BED7101C4F3640709692E524664B40F888981249B43540709692E524664B40
23	Краснознаменский район	\N	28	22.187328000000001	22.881195000000002	55.070045999999998	54.711399999999998	0103000020E6100000010000000500000006A051BAF42F3640EC2FBB270F5B4B4006A051BAF42F3640999B6F44F7884B401366DAFE95E13640999B6F44F7884B401366DAFE95E13640EC2FBB270F5B4B4006A051BAF42F3640EC2FBB270F5B4B40
991	Калининград городской округ	\N	28	20.293786999999998	20.648288999999998	54.777977999999997	54.630789999999998	0103000020E610000001000000050000006DFDF49F354B344069520ABABD504B406DFDF49F354B3440F58079C894634B40465B9544F6A53440F58079C894634B40465B9544F6A5344069520ABABD504B406DFDF49F354B344069520ABABD504B40
816	Зеленоградский район	\N	28	19.924983000000001	20.996960999999999	55.280534000000003	54.688409999999998	0103000020E61000000100000005000000215B96AFCBEC3340A31EA2D11D584B40215B96AFCBEC334042B5C189E8A34B4030630AD638FF344042B5C189E8A34B4030630AD638FF3440A31EA2D11D584B40215B96AFCBEC3340A31EA2D11D584B40
1115	Гусевский район	\N	28	21.995581999999999	22.391254	54.823594999999997	54.476097000000003	0103000020E610000001000000050000007C7C4276DEFE3540A35C1ABFF03C4B407C7C4276DEFE354016139B8F6B694B40DF6DDE382964364016139B8F6B694B40DF6DDE3829643640A35C1ABFF03C4B407C7C4276DEFE3540A35C1ABFF03C4B40
641	Гурьевский район	\N	28	20.211375	20.941158000000001	54.948649000000003	54.568902000000001	0103000020E61000000100000005000000273108AC1C3634408350DEC7D1484B40273108AC1C3634400A3197546D794B40685E0EBBEFF034400A3197546D794B40685E0EBBEFF034408350DEC7D1484B40273108AC1C3634408350DEC7D1484B40
386	Гвардейский район	\N	28	20.696169000000001	21.489642	54.808264999999999	54.522103000000001	0103000020E61000000100000005000000317DAF2138B234405E126745D4424B40317DAF2138B234402FC03E3A75674B407FBF982D597D35402FC03E3A75674B407FBF982D597D35405E126745D4424B40317DAF2138B234405E126745D4424B40
1103	Багратионовский район	\N	28	19.802793999999999	20.826568000000002	54.618603	54.365442999999999	0103000020E61000000100000005000000CE6C57E883CD3340ACC612D6C62E4B40CE6C57E883CD33408F1A13622E4F4B408EEBDFF599D334408F1A13622E4F4B408EEBDFF599D33440ACC612D6C62E4B40CE6C57E883CD3340ACC612D6C62E4B40
1561	Шекснинский район	\N	27	38.167799000000002	39.262199000000003	59.635899000000002	58.927912999999997	0103000020E6100000010000000500000098A608707A15434041446ADAC5764D4098A608707A1543409147702365D14D409F05A1BC8FA143409147702365D14D409F05A1BC8FA1434041446ADAC5764D4098A608707A15434041446ADAC5764D40
296	Череповецкий район	\N	27	36.933999	39.036614	59.752293999999999	58.507257000000003	0103000020E6100000010000000500000094BF7B478D77424063D520CCED404D4094BF7B478D7742400F7D772B4BE04D40B2497EC4AF8443400F7D772B4BE04D40B2497EC4AF84434063D520CCED404D4094BF7B478D77424063D520CCED404D40
1734	Чагодощенский район	\N	27	34.717047000000001	35.889896	59.306286999999998	58.767321000000003	0103000020E61000000100000005000000F3583332C85B41405B44149337624D40F3583332C85B41405018946934A74D40AD6BB41CE8F141405018946934A74D40AD6BB41CE8F141405B44149337624D40F3583332C85B41405B44149337624D40
499	Харовский район	\N	27	39.384692999999999	41.008290000000002	60.403396000000001	59.721995999999997	0103000020E610000001000000050000000400C79E3DB14340E1EB6B5D6ADC4D400400C79E3DB143402AABE97AA2334E4022718FA50F8144402AABE97AA2334E4022718FA50F814440E1EB6B5D6ADC4D400400C79E3DB14340E1EB6B5D6ADC4D40
489	Устюженский район	\N	27	35.661096000000001	37.120426999999999	59.214393999999999	58.477502999999999	0103000020E610000001000000050000001AC231CB9ED44140F65E7CD11E3D4D401AC231CB9ED44140B43A3943719B4D401747E5266A8F4240B43A3943719B4D401747E5266A8F4240F65E7CD11E3D4D401AC231CB9ED44140F65E7CD11E3D4D40
1616	Усть-Кубинский район	\N	27	38.892893000000001	39.999994000000001	60.2789	59.489396999999997	0103000020E61000000100000005000000E6E95C514A72434058E1968FA4BE4D40E6E95C514A7243405D6DC5FEB2234E401E19ABCDFFFF43405D6DC5FEB2234E401E19ABCDFFFF434058E1968FA4BE4D40E6E95C514A72434058E1968FA4BE4D40
1544	Тотемский район	\N	27	41.740192999999998	43.774994	60.400995999999999	59.160502999999999	0103000020E6100000010000000500000033DDEBA4BEDE444077F4BF5C8B944D4033DDEBA4BEDE4440D5E940D653334E40514CDE0033E34540D5E940D653334E40514CDE0033E3454077F4BF5C8B944D4033DDEBA4BEDE444077F4BF5C8B944D40
274	Тарногский район	\N	27	42.605693000000002	44.487870000000001	61.062302000000003	60.164693999999997	0103000020E6100000010000000500000044352559874D454078EC67B114154E4044352559874D4540DA3C0E83F9874E408A592F86723E4640DA3C0E83F9874E408A592F86723E464078EC67B114154E4044352559874D454078EC67B114154E40
259	Сямженский район	\N	27	40.583297000000002	42.058394	60.390594999999998	59.727898000000003	0103000020E610000001000000050000006E6DE179A94A44407369FCC22BDD4D406E6DE179A94A4440957D5704FF314E402D24607479074540957D5704FF314E402D246074790745407369FCC22BDD4D406E6DE179A94A44407369FCC22BDD4D40
450	Сокольский район	\N	27	39.744900000000001	41.891694000000001	59.813600000000001	59.276099000000002	0103000020E610000001000000050000002C6519E258DF4340AABA473657A34D402C6519E258DF43404703780B24E84D400C056C0723F244404703780B24E84D400C056C0723F24440AABA473657A34D402C6519E258DF4340AABA473657A34D40
298	Нюксенский район	\N	27	43.706524000000002	45.244672999999999	60.943221000000001	59.981397000000001	0103000020E6100000010000000500000068EBE0606FDA45403EB2B96A9EFD4D4068EBE0606FDA454041F33977BB784E406B9BE271519F464041F33977BB784E406B9BE271519F46403EB2B96A9EFD4D4068EBE0606FDA45403EB2B96A9EFD4D40
413	Никольский район	\N	27	44.191938	46.407677	60.040199999999999	59.122686000000002	0103000020E61000000100000005000000096EA46C91184640AAD6C22CB48F4D40096EA46C911846404CA60A4625054E406B2A8BC22E3447404CA60A4625054E406B2A8BC22E344740AAD6C22CB48F4D40096EA46C91184640AAD6C22CB48F4D40
213	Междуреченский район	\N	27	40.202689999999997	42.185397999999999	59.648896999999998	59.021194999999999	0103000020E61000000100000005000000F59CF4BEF11944405BEB8B84B6824D40F59CF4BEF11944407BBC900E0FD34D40355F251FBB1745407BBC900E0FD34D40355F251FBB1745405BEB8B84B6824D40F59CF4BEF11944405BEB8B84B6824D40
233	Кичменгско-Городецкий район	\N	27	44.629094000000002	47.156297000000002	60.436397999999997	59.591948000000002	0103000020E610000001000000050000000F0EF626865046406077BAF3C4CB4D400F0EF626865046401805C1E3DB374E4041BB438A019447401805C1E3DB374E4041BB438A019447406077BAF3C4CB4D400F0EF626865046406077BAF3C4CB4D40
949	Кирилловский район	\N	27	37.992493000000003	39.192489999999999	60.821993999999997	59.436199000000002	0103000020E610000001000000050000002541B8020AFF424022C66B5ED5B74D402541B8020AFF42400DC1711937694E404D672783A39843400DC1711937694E404D672783A398434022C66B5ED5B74D402541B8020AFF424022C66B5ED5B74D40
191	Кадуйский район	\N	27	36.277591000000001	37.531692999999997	59.749198	59.057200000000002	0103000020E61000000100000005000000FC54151A8823424065AA605452874D40FC54151A88234240431D56B8E5DF4D408D4127840EC44240431D56B8E5DF4D408D4127840EC4424065AA605452874D40FC54151A8823424065AA605452874D40
27	Грязовецкий район	\N	27	39.583993999999997	42.077052000000002	59.202398000000002	58.534405999999997	0103000020E61000000100000005000000B587BD50C0CA4340A164726A67444D40B587BD50C0CA43404E637B2DE8994D40B30B06D7DC0945404E637B2DE8994D40B30B06D7DC094540A164726A67444D40B587BD50C0CA4340A164726A67444D40
547	Вытегорский район	\N	27	35.177739000000003	38.413722	61.604447	60.411296999999998	0103000020E61000000100000005000000A41CCC26C0964140B1F84D61A5344E40A41CCC26C09641402995F0845ECD4E405FD1ADD7F43443402995F0845ECD4E405FD1ADD7F4344340B1F84D61A5344E40A41CCC26C0964140B1F84D61A5344E40
587	Вологодский район	\N	27	38.783999000000001	40.326694000000003	59.872801000000003	58.875281000000001	0103000020E61000000100000005000000618C48145A644340B4E7323509704D40618C48145A644340437573F1B7EF4D4054E6E61BD1294440437573F1B7EF4D4054E6E61BD1294440B4E7323509704D40618C48145A644340B4E7323509704D40
309	Вожегодский район	\N	27	38.858396999999997	41.476492	60.784405	60.194794999999999	0103000020E6100000010000000500000004FEF0F3DF6D43405036E50AEF184E4004FEF0F3DF6D4340D1E80E6267644E401F679AB0FDBC4440D1E80E6267644E401F679AB0FDBC44405036E50AEF184E4004FEF0F3DF6D43405036E50AEF184E40
563	Верховажский район	\N	27	41.343595999999998	42.986272999999997	60.917183999999999	60.299601000000003	0103000020E61000000100000005000000A98427F4FAAB4440A96C585359264E40A98427F4FAAB44400D350A4966754E40C2F693313E7E45400D350A4966754E40C2F693313E7E4540A96C585359264E40A98427F4FAAB4440A96C585359264E40
1717	Великоустюгский район	\N	27	45.148392000000001	47.075090000000003	61.195188999999999	60.235371000000001	0103000020E61000000100000005000000787E5182FE924640A2B60DA3201E4E40787E5182FE924640FCC401F4FB984E40DA20938C9C894740FCC401F4FB984E40DA20938C9C894740A2B60DA3201E4E40787E5182FE924640A2B60DA3201E4E40
1690	Вашкинский район	\N	27	37.083694999999999	38.516292	60.715094999999998	60.085594999999998	0103000020E610000001000000050000005BEB8B84B68A4240BED9E6C6F40A4E405BEB8B84B68A42403D44A33B885B4E40DD9733DB154243403D44A33B885B4E40DD9733DB15424340BED9E6C6F40A4E405BEB8B84B68A4240BED9E6C6F40A4E40
540	Белозерский район	\N	27	36.394596999999997	38.156894000000001	60.567698999999998	59.621899999999997	0103000020E61000000100000005000000C30C8D2782324240F2B0506B9ACF4D40C30C8D2782324240677C5F5CAA484E402578431A15144340677C5F5CAA484E402578431A15144340F2B0506B9ACF4D40C30C8D2782324240F2B0506B9ACF4D40
519	Бабушкинский район	\N	27	42.857399999999998	44.8461	60.143701	59.179048000000002	0103000020E6100000010000000500000092CB7F48BF6D454005357C0BEB964D4092CB7F48BF6D454085B35BCB64124E40A3923A014D6C464085B35BCB64124E40A3923A014D6C464005357C0BEB964D4092CB7F48BF6D454005357C0BEB964D40
311	Бабаевский район	\N	27	35.142417000000002	36.720092999999999	60.483696999999999	59.043393999999999	0103000020E610000001000000050000007DB262B83A924140DB6B41EF8D854D407DB262B83A9241402F1686C8E93D4E400D8AE6012C5C42402F1686C8E93D4E400D8AE6012C5C4240DB6B41EF8D854D407DB262B83A924140DB6B41EF8D854D40
7278	Бабаевский 	\N	27	35.142417000000002	36.720092999999999	60.483696999999999	59.043393999999999	0103000020E610000001000000050000007DB262B83A924140DB6B41EF8D854D407DB262B83A9241402F1686C8E93D4E400D8AE6012C5C42402F1686C8E93D4E400D8AE6012C5C4240DB6B41EF8D854D407DB262B83A924140DB6B41EF8D854D40
1595	Шенкурский район	\N	26	41.218899999999998	44.083995999999999	62.704698	61.593997000000002	0103000020E61000000100000005000000158C4AEA049C44400876FC1708CC4E40158C4AEA049C44403FC7478B335A4F40567F8461C00A46403FC7478B335A4F40567F8461C00A46400876FC1708CC4E40158C4AEA049C44400876FC1708CC4E40
1487	Холмогорский район	\N	26	40.638095	43.679296000000001	64.733295999999996	62.888195000000003	0103000020E61000000100000005000000DD5ED218AD51444041BCAE5FB0714F40DD5ED218AD51444068925852EE2E5040DD26DC2BF3D6454068925852EE2E5040DD26DC2BF3D6454041BCAE5FB0714F40DD5ED218AD51444041BCAE5FB0714F40
1387	Устьянский район	\N	26	42.785293000000003	45.362046999999997	61.864997000000002	60.729216000000001	0103000020E610000001000000050000008D63247B8464454027DC2BF3565D4E408D63247B84644540AE11C138B8EE4E40B54E5C8E57AE4640AE11C138B8EE4E40B54E5C8E57AE464027DC2BF3565D4E408D63247B8464454027DC2BF3565D4E40
7432	Соловецкий район	\N	26	35.502201999999997	35.880589999999998	65.172982000000005	64.954785999999999	0103000020E610000001000000050000002EFEB62748C041406F2BBD361B3D50402EFEB62748C04140FD321823124B5040A297512CB7F04140FD321823124B5040A297512CB7F041406F2BBD361B3D50402EFEB62748C041406F2BBD361B3D5040
1176	Приморский район	\N	26	36.437060000000002	42.105195999999999	65.946899000000002	63.864196999999997	0103000020E61000000100000005000000E4310395F13742409126DE019EEE4F40E4310395F13742405E6743FE997C5040C3D50110770D45405E6743FE997C5040C3D50110770D45409126DE019EEE4F40E4310395F13742409126DE019EEE4F40
1059	Плесецкий район	\N	26	37.252749000000001	42.003892999999998	64.135502000000002	61.751499000000003	0103000020E61000000100000005000000618C48145AA0424005FD851E31E04E40618C48145AA04240BAA29410AC08504077D7D9907F004540BAA29410AC08504077D7D9907F00454005FD851E31E04E40618C48145AA0424005FD851E31E04E40
904	Пинежский район	\N	26	41.756793999999999	47.233984	65.274698000000001	63.067297000000003	0103000020E610000001000000050000008EE733A0DEE04440390F27309D884F408EE733A0DEE04440B491EBA694515040C5E40D30F39D4740B491EBA694515040C5E40D30F39D4740390F27309D884F408EE733A0DEE04440390F27309D884F40
715	Онежский район	\N	26	35.895142999999997	40.178094000000002	64.624791000000002	62.648896000000001	0103000020E61000000100000005000000251FBB0B94F24140AB402D060F534F40251FBB0B94F2414073F56393FC27504092CEC0C8CB16444073F56393FC27504092CEC0C8CB164440AB402D060F534F40251FBB0B94F24140AB402D060F534F40
511	Няндомский район	\N	26	39.722298000000002	41.631497000000003	62.551395999999997	61.407395000000001	0103000020E61000000100000005000000ADFBC74274DC4340E7C6F48425B44E40ADFBC74274DC43409692E52494464F40D542C9E4D4D044409692E52494464F40D542C9E4D4D04440E7C6F48425B44E40ADFBC74274DC4340E7C6F48425B44E40
41	Мезенский район	\N	26	40.670434	49.040325000000003	66.514617999999999	65.009094000000005	0103000020E61000000100000005000000301004C8D0554440C02500FF94405040301004C8D0554440B5FB5580EFA05040091B9E5E29854840B5FB5580EFA05040091B9E5E29854840C02500FF94405040301004C8D0554440C02500FF94405040
1566	Лешуконский район	\N	26	44.512394	50.501902000000001	65.436299000000005	64.210796999999999	0103000020E6100000010000000500000054556820964146401346B3B27D0D50405455682096414640C311A452EC5B504004E621533E404940C311A452EC5B504004E621533E4049401346B3B27D0D504054556820964146401346B3B27D0D5040
1854	Ленский район	\N	26	47.640389999999996	49.639555000000001	62.853295000000003	61.379421000000001	0103000020E61000000100000005000000BC57AD4CF8D14740333509DE90B04E40BC57AD4CF8D14740906B43C5386D4F40247F30F0DCD14840906B43C5386D4F40247F30F0DCD14840333509DE90B04E40BC57AD4CF8D14740333509DE90B04E40
1643	Красноборский район	\N	26	44.849594000000003	48.160093000000003	62.337465999999999	61.282601	0103000020E610000001000000050000005D70067FBF6C4640906802452CA44E405D70067FBF6C464087C1FC15322B4F40C6A86BED7D14484087C1FC15322B4F40C6A86BED7D144840906802452CA44E405D70067FBF6C4640906802452CA44E40
1457	Котласский район	\N	26	45.338546999999998	47.843994000000002	61.803297000000001	60.851833999999997	0103000020E610000001000000050000005794128255AB464078CF81E5086D4E405794128255AB4640CAFCA36FD2E64E409702D2FE07EC4740CAFCA36FD2E64E409702D2FE07EC474078CF81E5086D4E405794128255AB464078CF81E5086D4E40
1743	Коношский район	\N	26	38.900897000000001	41.437604	61.489699000000002	60.636370999999997	0103000020E610000001000000050000004208C89750734340B88FDC9A74514E404208C8975073434024F1F274AEBE4E40A54C6A6803B8444024F1F274AEBE4E40A54C6A6803B84440B88FDC9A74514E404208C89750734340B88FDC9A74514E40
1570	Каргопольский район	\N	26	37.759093	39.912894000000001	62.084598	60.709139999999998	0103000020E61000000100000005000000AFCF9CF529E1424089247A19C55A4E40AFCF9CF529E142404CA7751BD40A4F40795BE9B5D9F443404CA7751BD40A4F40795BE9B5D9F4434089247A19C55A4E40AFCF9CF529E1424089247A19C55A4E40
1587	Виноградовский район	\N	26	41.753093	45.257699000000002	63.504697	62.340699000000001	0103000020E610000001000000050000005BECF65965E04440D4635B069C2B4F405BECF65965E04440D5B14AE999C04F40209BE447FCA04640D5B14AE999C04F40209BE447FCA04640D4635B069C2B4F405BECF65965E04440D4635B069C2B4F40
1635	Вилегодский район	\N	26	47.214993	49.409019999999998	61.535798999999997	60.837023000000002	0103000020E6100000010000000500000039EFFFE3849B4740FA7FD591236B4E4039EFFFE3849B4740601DC70F95C44E4078B471C45AB44840601DC70F95C44E4078B471C45AB44840FA7FD591236B4E4039EFFFE3849B4740FA7FD591236B4E40
1579	Верхнетоемский район	\N	26	43.549596999999999	47.567293999999997	63.219352000000001	61.641195000000003	0103000020E61000000100000005000000677DCA3159C64540EBAD81AD12D24E40677DCA3159C64540F627F1B9139C4F40C79BFC169DC84740F627F1B9139C4F40C79BFC169DC84740EBAD81AD12D24E40677DCA3159C64540EBAD81AD12D24E40
1404	Вельский район	\N	26	40.908693999999997	43.621696	61.912897999999998	60.767884000000002	0103000020E610000001000000050000002409C21550744440938FDD054A624E402409C21550744440BA4A77D7D9F44E40EA060ABC93CF4540BA4A77D7D9F44E40EA060ABC93CF4540938FDD054A624E402409C21550744440938FDD054A624E40
1567	Янтиковский район	\N	66	47.579996999999999	48.012490999999997	55.637098000000002	55.334443999999998	0103000020E61000000100000005000000996379573DCA4740F52B9D0FCFAA4B40996379573DCA47406B2C616D8CD14B40463F1A4E990148406B2C616D8CD14B40463F1A4E99014840F52B9D0FCFAA4B40996379573DCA4740F52B9D0FCFAA4B40
708	Яльчикский район	\N	66	47.701484999999998	48.103183999999999	55.323684999999998	54.943468000000003	0103000020E6100000010000000500000039D1AE42CAD947404969368FC3784B4039D1AE42CAD94740569A94826EA94B4038BC2022350D4840569A94826EA94B4038BC2022350D48404969368FC3784B4039D1AE42CAD947404969368FC3784B40
939	Ядринский район	\N	66	46.076495000000001	46.687592000000002	56.129021999999999	55.760297000000001	0103000020E610000001000000050000005DA79196CA0947409B1F7F6951E14B405DA79196CA094740753BFBCA83104C40E17EC00303584740753BFBCA83104C40E17EC003035847409B1F7F6951E14B405DA79196CA0947409B1F7F6951E14B40
115	Шумерлинский район	\N	66	46.207362000000003	46.738194	55.676098000000003	55.268497000000004	0103000020E61000000100000005000000723788D68A1A47407D09151C5EA24B40723788D68A1A47400D7217618AD64B403D0D18247D5E47400D7217618AD64B403D0D18247D5E47407D09151C5EA24B40723788D68A1A47407D09151C5EA24B40
1210	Шемуршинский район	\N	66	47.034889999999997	47.845044999999999	54.992899999999999	54.653542000000002	0103000020E610000001000000050000008D7A884677844740FE47A643A7534B408D7A8846778447406519E258177F4B40FC523F6F2AEC47406519E258177F4B40FC523F6F2AEC4740FE47A643A7534B408D7A884677844740FE47A643A7534B40
1036	Чебоксарский район	\N	66	46.920768000000002	47.597459999999998	56.300085000000003	55.871682999999997	0103000020E61000000100000005000000079ACFB9DB75474055BDFC4E93EF4B40079ACFB9DB75474095826E2F69264C408655BC9179CC474095826E2F69264C408655BC9179CC474055BDFC4E93EF4B40079ACFB9DB75474055BDFC4E93EF4B40
889	Цивильский район	\N	66	47.186695999999998	47.802194999999998	55.977097999999998	55.664700000000003	0103000020E61000000100000005000000A2258FA7E59747405BD3BCE314D54B40A2258FA7E5974740567E198C11FD4B40E2016553AEE64740567E198C11FD4B40E2016553AEE647405BD3BCE314D54B40A2258FA7E59747405BD3BCE314D54B40
546	Урмарский район	\N	66	47.624993000000003	48.149295000000002	55.811396000000002	55.513382	0103000020E610000001000000050000004E9D47C5FFCF4740732D5A80B6C14B404E9D47C5FFCF4740780DFAD2DBE74B40693A3B191C134840780DFAD2DBE74B40693A3B191C134840732D5A80B6C14B404E9D47C5FFCF4740732D5A80B6C14B40
501	Порецкий район	\N	66	46.010720999999997	46.775097000000002	55.379271000000003	54.975434	0103000020E61000000100000005000000B130444E5F01474007B47405DB7C4B40B130444E5F0147401EA9BEF38BB04B40261DE560366347401EA9BEF38BB04B40261DE5603663474007B47405DB7C4B40B130444E5F01474007B47405DB7C4B40
6914	Новочебоксарск городской округ	\N	66	47.440147000000003	47.554889000000003	56.130316999999998	56.058855000000001	0103000020E610000001000000050000005D37A5BC56B84740611A868F88074C405D37A5BC56B84740718E3A3AAE104C4080F44D9A06C74740718E3A3AAE104C4080F44D9A06C74740611A868F88074C405D37A5BC56B84740611A868F88074C40
1445	Моргаушский район	\N	66	46.485391	46.983497	56.231667999999999	55.815295999999996	0103000020E61000000100000005000000E962D34A213E4740A1478C9E5BE84B40E962D34A213E4740CEC3094CA71D4C40685BCD3AE37D4740CEC3094CA71D4C40685BCD3AE37D4740A1478C9E5BE84B40E962D34A213E4740A1478C9E5BE84B40
1654	Мариинско-Посадский район	\N	66	47.503450999999998	48.080869999999997	56.159402999999998	55.837893999999999	0103000020E61000000100000005000000BA11161571C04740DFC14F1C40EB4B40BA11161571C0474030F1475167144C401F9DBAF2590A484030F1475167144C401F9DBAF2590A4840DFC14F1C40EB4B40BA11161571C04740DFC14F1C40EB4B40
1454	Красночетайский район	\N	66	45.911223	46.528384000000003	55.822099000000001	55.517189000000002	0103000020E61000000100000005000000772E8CF4A2F44640EC6CC83F33C24B40772E8CF4A2F4464083893F8A3AE94B4066DD3F16A243474083893F8A3AE94B4066DD3F16A2434740EC6CC83F33C24B40772E8CF4A2F44640EC6CC83F33C24B40
1590	Красноармейский район	\N	66	46.912889999999997	47.390093	55.896498999999999	55.643495000000001	0103000020E61000000100000005000000376C5B94D9744740DC114E0B5ED24B40376C5B94D9744740C7F2AE7AC0F24B4003B34291EEB14740C7F2AE7AC0F24B4003B34291EEB14740DC114E0B5ED24B40376C5B94D9744740DC114E0B5ED24B40
215	Комсомольский район	\N	66	47.222791000000001	47.740794999999999	55.374093999999999	55.097301000000002	0103000020E61000000100000005000000EC6B5D6A849C47401E6FF25B748C4B40EC6B5D6A849C47409ED0EB4FE2AF4B402905DD5ED2DE47409ED0EB4FE2AF4B402905DD5ED2DE47401E6FF25B748C4B40EC6B5D6A849C47401E6FF25B748C4B40
1418	Козловский район	\N	66	47.780698000000001	48.420648999999997	55.944364	55.686684999999997	0103000020E61000000100000005000000BC067DE9EDE34740AED3484BE5D74B40BC067DE9EDE3474087C267EBE0F84B402C0C91D3D735484087C267EBE0F84B402C0C91D3D7354840AED3484BE5D74B40BC067DE9EDE34740AED3484BE5D74B40
1185	Канашский район	\N	66	47.133597000000002	47.707197999999998	55.725199000000003	55.324196999999998	0103000020E61000000100000005000000FFEBDCB4199147400C3B8C497FA94B40FFEBDCB419914740C40B2252D3DC4B40F7E5CC7685DA4740C40B2252D3DC4B40F7E5CC7685DA47400C3B8C497FA94B40FFEBDCB4199147400C3B8C497FA94B40
1106	Ибресинский район	\N	66	46.703600000000002	47.404394000000003	55.430998000000002	55.083091000000003	0103000020E6100000010000000500000099BB96900F5A4740C5CBD3B9A28A4B4099BB96900F5A47401A5245F12AB74B406D59BE2EC3B347401A5245F12AB74B406D59BE2EC3B34740C5CBD3B9A28A4B4099BB96900F5A4740C5CBD3B9A28A4B40
902	Вурнарский район	\N	66	46.638193999999999	47.229995000000002	55.712471999999998	55.350796000000003	0103000020E6100000010000000500000070404B57B0514740A8C821E2E6AC4B4070404B57B051474069A8514832DB4B402C9FE579709D474069A8514832DB4B402C9FE579709D4740A8C821E2E6AC4B4070404B57B0514740A8C821E2E6AC4B40
619	Батыревский район	\N	66	46.977792999999998	47.886394000000003	55.156897999999998	54.929600999999998	0103000020E61000000100000005000000FDA02E52287D474019AA622AFD764B40FDA02E52287D47406667D13B15944B4071AFCC5B75F147406667D13B15944B4071AFCC5B75F1474019AA622AFD764B40FDA02E52287D474019AA622AFD764B40
362	Аликовский район	\N	66	46.430593000000002	47.016492	55.857199999999999	55.642499000000001	0103000020E610000001000000050000007A71E2AB1D3747403A5B40683DD24B407A71E2AB1D374740CB10C7BAB8ED4B40A452EC681C824740CB10C7BAB8ED4B40A452EC681C8247403A5B40683DD24B407A71E2AB1D3747403A5B40683DD24B40
107	Алатырский район	\N	66	46.245342999999998	47.143092000000003	55.097496	54.632212000000003	0103000020E61000000100000005000000B9A64066671F4740C311A452EC504B40B9A64066671F4740D3BEB9BF7A8C4B40DD28B2D650924740D3BEB9BF7A8C4B40DD28B2D650924740C311A452EC504B40B9A64066671F4740C311A452EC504B40
7409	Глазов городской округ	\N	65	52.580370000000002	52.723354999999998	58.166867000000003	58.112704999999998	0103000020E610000001000000050000002ECA6C90494A4A403F8C101E6D0E4D402ECA6C90494A4A400DE4D9E55B154D40F4328AE5965C4A400DE4D9E55B154D40F4328AE5965C4A403F8C101E6D0E4D402ECA6C90494A4A403F8C101E6D0E4D40
1498	Ярский район	\N	65	51.682423	52.431922999999998	58.489387000000001	58.000250000000001	0103000020E61000000100000005000000E48409A359D7494079E9263108004D40E48409A359D74940350BB43BA43E4D40F2B1BB4049374A40350BB43BA43E4D40F2B1BB4049374A4079E9263108004D40E48409A359D7494079E9263108004D40
1401	Якшур-Бодьинский район	\N	65	52.473309	53.508743000000003	57.395560000000003	56.98039	0103000020E6100000010000000500000084F3A963953C4A40A8A9656B7D7D4C4084F3A963953C4A408ACDC7B5A1B24C40D388997D1EC14A408ACDC7B5A1B24C40D388997D1EC14A40A8A9656B7D7D4C4084F3A963953C4A40A8A9656B7D7D4C40
1368	Юкаменский район	\N	65	51.820475999999999	52.584367	58.099200000000003	57.763596999999997	0103000020E610000001000000050000009293895B05E949406F29E78BBDE14C409293895B05E94940B1E1E995B20C4D404AEEB089CC4A4A40B1E1E995B20C4D404AEEB089CC4A4A406F29E78BBDE14C409293895B05E949406F29E78BBDE14C40
1271	Шарканский район	\N	65	53.425649	54.292343000000002	57.536144	57.120103999999998	0103000020E610000001000000050000009D499BAA7BB64A40340F60915F8F4C409D499BAA7BB64A402BF9D85DA0C44C40761BD47E6B254B402BF9D85DA0C44C40761BD47E6B254B40340F60915F8F4C409D499BAA7BB64A40340F60915F8F4C40
7411	Устиновский район	\N	65	53.256073999999998	53.389311999999997	56.912655000000001	56.839433999999997	0103000020E610000001000000050000008EAD6708C7A04A404293C492726B4C408EAD6708C7A04A40F4C308E1D1744C405DF8C1F9D4B14A40F4C308E1D1744C405DF8C1F9D4B14A404293C492726B4C408EAD6708C7A04A404293C492726B4C40
1195	Увинский район	\N	65	51.852178000000002	52.756160999999999	57.307397999999999	56.625698	0103000020E61000000100000005000000732F302B14ED494018963FDF16504C40732F302B14ED49408B6D52D158A74C405DC136E2C9604A408B6D52D158A74C405DC136E2C9604A4018963FDF16504C40732F302B14ED494018963FDF16504C40
1128	Сюмсинский район	\N	65	51.124830000000003	51.919578000000001	57.468119999999999	56.875315000000001	0103000020E61000000100000005000000A4C7EF6DFA8F4940605969520A704C40A4C7EF6DFA8F4940404D2D5BEBBB4C40800F5EBBB4F54940404D2D5BEBBB4C40800F5EBBB4F54940605969520A704C40A4C7EF6DFA8F4940605969520A704C40
176	Селтинский район	\N	65	51.446075999999998	52.569563000000002	57.586995999999999	57.126299000000003	0103000020E61000000100000005000000E7C3B30419B949403E42CD902A904C40E7C3B30419B94940007157AF22CB4C407E01BD70E7484A40007157AF22CB4C407E01BD70E7484A403E42CD902A904C40E7C3B30419B949403E42CD902A904C40
131	Сарапульский район	\N	65	53.315147000000003	54.198829000000003	56.759207000000004	56.170600999999998	0103000020E610000001000000050000005D37A5BC56A84A401BD5E940D6154C405D37A5BC56A84A4078F2E9B12D614C408A3F8A3A73194B4078F2E9B12D614C408A3F8A3A73194B401BD5E940D6154C405D37A5BC56A84A401BD5E940D6154C40
1005	Сарапул городской округ	\N	65	53.677743	54.279820999999998	56.673955999999997	56.418801000000002	0103000020E61000000100000005000000E50B5A48C0D64A401C446B459B354C40E50B5A48C0D64A40B378B13044564C40F4DDAD2CD1234B40B378B13044564C40F4DDAD2CD1234B401C446B459B354C40E50B5A48C0D64A401C446B459B354C40
7412	Октябрьский район	\N	65	53.054034000000001	53.232402999999998	56.987746999999999	56.843895000000003	0103000020E61000000100000005000000A06F0B96EA864A40042159C0046C4C40A06F0B96EA864A406EDC627E6E7E4C40033FAA61BF9D4A406EDC627E6E7E4C40033FAA61BF9D4A40042159C0046C4C40A06F0B96EA864A40042159C0046C4C40
847	Можгинский район	\N	65	51.837077000000001	52.731619000000002	56.717796	56.184094999999999	0103000020E61000000100000005000000ED9DD15625EB4940B62DCA6C90174C40ED9DD15625EB49408D9944BDE05B4C40ED10FFB0A55D4A408D9944BDE05B4C40ED10FFB0A55D4A40B62DCA6C90174C40ED9DD15625EB4940B62DCA6C90174C40
634	Малопургинский район	\N	65	52.546368999999999	53.444845999999998	56.734499	56.359549000000001	0103000020E610000001000000050000002C465D6BEF454A409E279EB3052E4C402C465D6BEF454A40ECF82F10045E4C40D2E0B6B6F0B84A40ECF82F10045E4C40D2E0B6B6F0B84A409E279EB3052E4C402C465D6BEF454A409E279EB3052E4C40
6899	Ленинский район	\N	65	51.124830000000003	54.434052000000001	58.545209	55.856203999999998	0103000020E61000000100000005000000A4C7EF6DFA8F4940295AB91798ED4B40A4C7EF6DFA8F4940103E9468C9454D40B76114048F374B40103E9468C9454D40B76114048F374B40295AB91798ED4B40A4C7EF6DFA8F4940295AB91798ED4B40
510	Красногорский район	\N	65	51.799168000000002	52.880963999999999	57.857199000000001	57.475499999999997	0103000020E610000001000000050000003F0114234BE64940BE9F1A2FDDBC4C403F0114234BE64940FB9463B2B8ED4C40077AA86DC3704A40FB9463B2B8ED4C40077AA86DC3704A40BE9F1A2FDDBC4C403F0114234BE64940BE9F1A2FDDBC4C40
369	Киясовский район	\N	65	52.942804000000002	53.420546000000002	56.488402999999998	56.062936000000001	0103000020E61000000100000005000000DD442DCDAD784A40DBDE6E490E084C40DD442DCDAD784A40572250FD833E4C40583B8A73D4B54A40572250FD833E4C40583B8A73D4B54A40DBDE6E490E084C40DD442DCDAD784A40DBDE6E490E084C40
61	Кизнерский район	\N	65	51.130453000000003	52.017170999999998	56.681308999999999	55.933101000000001	0103000020E61000000100000005000000225514AFB2904940B56E83DA6FF74B40225514AFB290494038BC202235574C4045B8C9A832024A4038BC202235574C4045B8C9A832024A40B56E83DA6FF74B40225514AFB2904940B56E83DA6FF74B40
1658	Кезский район	\N	65	53.301645000000001	54.142181000000001	58.420701000000001	57.729903	0103000020E610000001000000050000003F00A94D9CA64A404B2025766DDD4C403F00A94D9CA64A407F32C687D9354D40698EACFC32124B407F32C687D9354D40698EACFC32124B404B2025766DDD4C403F00A94D9CA64A404B2025766DDD4C40
1629	Каракулинский район	\N	65	53.199497999999998	54.184635	56.231997999999997	55.856203999999998	0103000020E6100000010000000500000007CF842689994A40295AB91798ED4B4007CF842689994A40635E471CB21D4C403659A31EA2174B40635E471CB21D4C403659A31EA2174B40295AB91798ED4B4007CF842689994A40295AB91798ED4B40
1608	Камбарский район	\N	65	53.849527999999999	54.417883000000003	56.496597000000001	56.198951000000001	0103000020E61000000100000005000000A5846055BDEC4A40D540F33977194C40A5846055BDEC4A405725917D903F4C40F646AD307D354B405725917D903F4C40F646AD307D354B40D540F33977194C40A5846055BDEC4A40D540F33977194C40
6901	Индустриальный район	\N	65	51.124830000000003	54.434052000000001	58.545209	55.856203999999998	0103000020E61000000100000005000000A4C7EF6DFA8F4940295AB91798ED4B40A4C7EF6DFA8F4940103E9468C9454D40B76114048F374B40103E9468C9454D40B76114048F374B40295AB91798ED4B40A4C7EF6DFA8F4940295AB91798ED4B40
1321	Игринский район	\N	65	52.334069999999997	53.648834999999998	57.765801000000003	57.292099999999998	0103000020E61000000100000005000000904946CEC22A4A40AF94658863A54C40904946CEC22A4A403F1F65C405E24C4005C078060DD34A403F1F65C405E24C4005C078060DD34A40AF94658863A54C40904946CEC22A4A40AF94658863A54C40
1575	Завьяловский район	\N	65	52.630208000000003	53.795771999999999	57.05254	56.592619999999997	0103000020E61000000100000005000000BBD6DEA7AA504A404E7ADFF8DA4B4C40BBD6DEA7AA504A40ADDD76A1B9864C4048895DDBDBE54A40ADDD76A1B9864C4048895DDBDBE54A404E7ADFF8DA4B4C40BBD6DEA7AA504A404E7ADFF8DA4B4C40
1721	Дебесский район	\N	65	53.465246	54.156185999999998	57.796402	57.443300000000001	0103000020E61000000100000005000000234C512E8DBB4A408D28ED0DBEB84C40234C512E8DBB4A40083C3080F0E54C40E90B21E7FD134B40083C3080F0E54C40E90B21E7FD134B408D28ED0DBEB84C40234C512E8DBB4A408D28ED0DBEB84C40
1562	Граховский район	\N	65	51.541378000000002	52.263058000000001	56.251302000000003	55.887332000000001	0103000020E610000001000000050000000F63D2DF4BC54940DE58501894F14B400F63D2DF4BC54940AFB5F7A92A204C40C07971E2AB214A40AFB5F7A92A204C40C07971E2AB214A40DE58501894F14B400F63D2DF4BC54940DE58501894F14B40
1000	Глазовский район	\N	65	52.290968999999997	53.205454000000003	58.545209	57.840995999999997	0103000020E610000001000000050000002D93E1783E254A408D08C6C1A5EB4C402D93E1783E254A40103E9468C9454D408C6A11514C9A4A40103E9468C9454D408C6A11514C9A4A408D08C6C1A5EB4C402D93E1783E254A408D08C6C1A5EB4C40
1557	Воткинский район	\N	65	53.415847999999997	54.434052000000001	57.317557999999998	56.749895000000002	0103000020E61000000100000005000000B20DDC813AB54A408B37328FFC5F4C40B20DDC813AB54A40A54A94BDA5A84C40B76114048F374B40A54A94BDA5A84C40B76114048F374B408B37328FFC5F4C40B20DDC813AB54A408B37328FFC5F4C40
7410	Воткинск городской округ	\N	65	53.890571999999999	54.031939999999999	57.083525000000002	57.022015000000003	0103000020E61000000100000005000000DD5D6743FEF14A40BF823463D1824C40DD5D6743FEF14A40FFB27BF2B08A4C4095B7239C16044B40FFB27BF2B08A4C4095B7239C16044B40BF823463D1824C40DD5D6743FEF14A40BF823463D1824C40
1535	Вавожский район	\N	65	51.390901999999997	52.276074999999999	57.016801000000001	56.498699000000002	0103000020E6100000010000000500000072F8A41309B2494022C66B5ED53F4C4072F8A41309B2494022C5008926824C40211FF46C56234A4022C5008926824C40211FF46C56234A4022C66B5ED53F4C4072F8A41309B2494022C66B5ED53F4C40
1392	Балезинский район	\N	65	52.705962999999997	53.791865000000001	58.543667999999997	57.693401999999999	0103000020E61000000100000005000000D097DEFE5C5A4A40917D9065C1D84C40D097DEFE5C5A4A40DCF0BBE996454D406CEC12D55BE54A40DCF0BBE996454D406CEC12D55BE54A40917D9065C1D84C40D097DEFE5C5A4A40917D9065C1D84C40
1333	Алнашский район	\N	65	52.189377999999998	52.885356999999999	56.362197000000002	55.983815999999997	0103000020E610000001000000050000007B4ACE893D184A4009A4C4AEEDFD4B407B4ACE893D184A40CBDAA6785C2E4C407024D06053714A40CBDAA6785C2E4C407024D06053714A4009A4C4AEEDFD4B407B4ACE893D184A4009A4C4AEEDFD4B40
7510	высо	\N	64	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
923	Ютазинский район	\N	64	53.029356999999997	53.640867	54.815285000000003	54.479497000000002	0103000020E610000001000000050000004F745DF8C1834A40DBC35E28603D4B404F745DF8C1834A40AEF545425B684B40F60A0BEE07D24A40AEF545425B684B40F60A0BEE07D24A40DBC35E28603D4B404F745DF8C1834A40DBC35E28603D4B40
763	Чистопольский район	\N	64	50.290295	51.245285000000003	55.489998	55.034198000000004	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
6928	Чистопольский муниципальный район	\N	64	50.290295	51.245285000000003	55.489998	55.034198000000004	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
319	Черемшанский район	\N	64	51.009287999999998	51.913874	54.952697999999998	54.555365000000002	0103000020E61000000100000005000000641F645930814940E92B483316474B40641F645930814940787B1002F2794B401555BFD2F9F44940787B1002F2794B401555BFD2F9F44940E92B483316474B40641F645930814940E92B483316474B40
36	Тюлячинский район	\N	64	49.938389000000001	50.604489000000001	56.036000000000001	55.609299	0103000020E610000001000000050000008CF678211DF84840253E7782FDCD4B408CF678211DF84840F853E3A59B044C4058E542E55F4D4940F853E3A59B044C4058E542E55F4D4940253E7782FDCD4B408CF678211DF84840253E7782FDCD4B40
1883	Тукаевский район	\N	64	51.935172999999999	52.909989000000003	55.861206000000003	55.362617999999998	0103000020E61000000100000005000000158DB5BFB3F74940707841446AAE4B40158DB5BFB3F749403B8F8AFF3BEE4B40215C01857A744A403B8F8AFF3BEE4B40215C01857A744A40707841446AAE4B40158DB5BFB3F74940707841446AAE4B40
6936	Тукаевский муниципальный район	\N	64	51.935172999999999	52.909989000000003	55.861206000000003	55.362617999999998	0103000020E61000000100000005000000158DB5BFB3F74940707841446AAE4B40158DB5BFB3F749403B8F8AFF3BEE4B40215C01857A744A403B8F8AFF3BEE4B40215C01857A744A40707841446AAE4B40158DB5BFB3F74940707841446AAE4B40
1815	Тетюшский район	\N	64	48.229388999999998	48.977299000000002	55.161394000000001	54.624144000000001	0103000020E61000000100000005000000F487669E5C1D484050FF59F3E34F4B40F487669E5C1D4840A4E2FF8EA8944B40EEB43522187D4840A4E2FF8EA8944B40EEB43522187D484050FF59F3E34F4B40F487669E5C1D484050FF59F3E34F4B40
1778	Спасский район	\N	64	48.861794000000003	49.837184000000001	55.245998999999998	54.555162000000003	0103000020E61000000100000005000000CCF10A444F6E4840B1FD648C0F474B40CCF10A444F6E4840A2EC2DE57C9F4B40035E66D828EB4840A2EC2DE57C9F4B40035E66D828EB4840B1FD648C0F474B40CCF10A444F6E4840B1FD648C0F474B40
1265	Сармановский район	\N	64	52.334474	52.954661999999999	55.504694999999998	55.004798000000001	0103000020E6100000010000000500000060AE450BD02A4A40098B8A389D804B4060AE450BD02A4A4034BA83D899C04B40F25D4A5D327A4A4034BA83D899C04B40F25D4A5D327A4A40098B8A389D804B4060AE450BD02A4A40098B8A389D804B40
1640	Сабинский район	\N	64	50.079585999999999	50.768791	56.252997000000001	55.777697000000003	0103000020E61000000100000005000000179CC1DF2F0A4940429946938BE34B40179CC1DF2F0A4940397EA83462204C40C53A55BE67624940397EA83462204C40C53A55BE67624940429946938BE34B40179CC1DF2F0A4940429946938BE34B40
1476	Рыбно-Слободский район	\N	64	49.715893999999999	50.869087999999998	55.807896	55.356594999999999	0103000020E6100000010000000500000089B3226AA2DB48406475ABE7A4AD4B4089B3226AA2DB4840DC48D92269E74B404BAC8C463E6F4940DC48D92269E74B404BAC8C463E6F49406475ABE7A4AD4B4089B3226AA2DB48406475ABE7A4AD4B40
1398	Пестречинский район	\N	64	49.323473999999997	50.806736000000001	56.021835000000003	55.508544000000001	0103000020E610000001000000050000009B8D959867A94840DC4944F817C14B409B8D959867A948403F74417DCB024C40C0401020436749403F74417DCB024C40C040102043674940DC4944F817C14B409B8D959867A94840DC4944F817C14B40
1254	Нурлатский район	\N	64	49.985585999999998	51.150610999999998	54.892597000000002	54.323701999999997	0103000020E610000001000000050000009EB29AAE27FE48402CD32F116F294B409EB29AAE27FE4840FDC0559E40724B407CB5A33847934940FDC0559E40724B407CB5A338479349402CD32F116F294B409EB29AAE27FE48402CD32F116F294B40
6927	Нурлатский муниципальный район	\N	64	49.985585999999998	51.150610999999998	54.892597000000002	54.323701999999997	0103000020E610000001000000050000009EB29AAE27FE48402CD32F116F294B409EB29AAE27FE4840FDC0559E40724B407CB5A33847934940FDC0559E40724B407CB5A338479349402CD32F116F294B409EB29AAE27FE48402CD32F116F294B40
1157	Новошешминский район	\N	64	50.82199	51.580877000000001	55.270097	54.854298999999997	0103000020E61000000100000005000000CCD1E3F736694940B4006DAB596D4B40CCD1E3F736694940B5DFDA8992A24B40D2FF722D5ACA4940B5DFDA8992A24B40D2FF722D5ACA4940B4006DAB596D4B40CCD1E3F736694940B4006DAB596D4B40
856	Нижнекамский район	\N	64	51.026482000000001	52.078077	55.729000999999997	55.116298999999998	0103000020E6100000010000000500000062F71DC3638349405CC7B8E2E28E4B4062F71DC3638349402AE09EE74FDD4B40EFC8586DFE094A402AE09EE74FDD4B40EFC8586DFE094A405CC7B8E2E28E4B4062F71DC3638349405CC7B8E2E28E4B40
6926	Нижнекамск городской округ	\N	64	51.780492000000002	51.863630999999998	55.667549000000001	55.596086	0103000020E6100000010000000500000013656F29E7E349403ECDC98B4CCC4B4013656F29E7E349401FBDE13E72D54B40E867EA758BEE49401FBDE13E72D54B40E867EA758BEE49403ECDC98B4CCC4B4013656F29E7E349403ECDC98B4CCC4B40
32	Муслюмовский район	\N	64	52.882365999999998	53.808250000000001	55.504797000000003	55.121679999999998	0103000020E61000000100000005000000198D7C5EF1704A40E449D235938F4B40198D7C5EF1704A40390F27309DC04B40FA7E6ABC74E74A40390F27309DC04B40FA7E6ABC74E74A40E449D235938F4B40198D7C5EF1704A40E449D235938F4B40
1856	Мензелинский район	\N	64	52.626364000000002	53.491943999999997	55.942397999999997	55.388900999999997	0103000020E6100000010000000500000025B20FB22C504A40DB300A82C7B14B4025B20FB22C504A406CE8667FA0F84B4051BB5F05F8BE4A406CE8667FA0F84B4051BB5F05F8BE4A40DB300A82C7B14B4025B20FB22C504A40DB300A82C7B14B40
1814	Менделеевский район	\N	64	52.071879000000003	52.767766999999999	56.098832999999999	55.790098999999998	0103000020E610000001000000050000007522C15433094A4018CDCAF621E54B407522C15433094A40FE614B8FA60C4C4059F9653046624A40FE614B8FA60C4C4059F9653046624A4018CDCAF621E54B407522C15433094A4018CDCAF621E54B40
1755	Мамадышский район	\N	64	50.619185999999999	51.578882999999998	56.072001999999998	55.440697	0103000020E610000001000000050000000E12A27C414F4940003961C268B84B400E12A27C414F4940909F8D5C37094C40ED9A90D618CA4940909F8D5C37094C40ED9A90D618CA4940003961C268B84B400E12A27C414F4940003961C268B84B40
970	Лениногорский район	\N	64	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
6920	Лениногорский муниципальный район	\N	64	51.708644999999997	52.739066000000001	54.846798999999997	54.328612	0103000020E61000000100000005000000A9BC1DE1B4DA49405D8940F50F2A4B40A9BC1DE1B4DA49408BA4DDE8636C4B40F3CAF5B6995E4A408BA4DDE8636C4B40F3CAF5B6995E4A405D8940F50F2A4B40A9BC1DE1B4DA49405D8940F50F2A4B40
971	Лаишевский район	\N	64	49.011946999999999	49.853085	55.658890999999997	55.273117999999997	0103000020E610000001000000050000008524B37A8781484076F9D687F5A24B408524B37A878148407A50508A56D44B40A5DAA7E331ED48407A50508A56D44B40A5DAA7E331ED484076F9D687F5A24B408524B37A8781484076F9D687F5A24B40
6931	Лаишевский муниципальный район	\N	64	49.011946999999999	49.853085	55.658890999999997	55.273117999999997	0103000020E610000001000000050000008524B37A8781484076F9D687F5A24B408524B37A878148407A50508A56D44B40A5DAA7E331ED48407A50508A56D44B40A5DAA7E331ED484076F9D687F5A24B408524B37A8781484076F9D687F5A24B40
289	Кукморский район	\N	64	50.311387000000003	51.647388999999997	56.409951999999997	55.842700999999998	0103000020E6100000010000000500000025B37A87DB2749403BA759A0DDEB4B4025B37A87DB2749400377A04E79344C4023658BA4DDD249400377A04E79344C4023658BA4DDD249403BA759A0DDEB4B4025B37A87DB2749403BA759A0DDEB4B40
6935	Кукморский муниципальный район	\N	64	50.311387000000003	51.647388999999997	56.409951999999997	55.842700999999998	0103000020E6100000010000000500000025B37A87DB2749403BA759A0DDEB4B4025B37A87DB2749400377A04E79344C4023658BA4DDD249400377A04E79344C4023658BA4DDD249403BA759A0DDEB4B4025B37A87DB2749403BA759A0DDEB4B40
1238	Камско-Устьинский район	\N	64	48.712296000000002	49.420492000000003	55.509298999999999	55.043700999999999	0103000020E610000001000000050000002B89EC832C5B4840B8E68EFE97854B402B89EC832C5B48405871AAB530C14B40651D8EAED2B548405871AAB530C14B40651D8EAED2B54840B8E68EFE97854B402B89EC832C5B4840B8E68EFE97854B40
1168	Кайбицкий район	\N	64	47.645583000000002	48.579489000000002	55.541397000000003	55.213911000000003	0103000020E6100000010000000500000042EDB776A2D2474099A0866F619B4B4042EDB776A2D247408693347F4CC54B4025B20FB22C4A48408693347F4CC54B4025B20FB22C4A484099A0866F619B4B4042EDB776A2D2474099A0866F619B4B40
947	Зеленодольский район	\N	64	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
6906	Зеленодольский муниципальный район	\N	64	47.694046999999998	49.047907000000002	56.068182999999998	55.278635999999999	0103000020E6100000010000000500000086713788D6D847407FBE2D58AAA34B4086713788D6D8474053927538BA084C40EF1F0BD12186484053927538BA084C40EF1F0BD1218648407FBE2D58AAA34B4086713788D6D847407FBE2D58AAA34B40
639	Заинский район	\N	64	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
6913	Заинский муниципальный район	\N	64	51.663378999999999	52.466966999999997	55.530296	55.038800000000002	0103000020E6100000010000000500000035ED629AE9D44940DB8AFD65F7844B4035ED629AE9D449408D9944BDE0C34B40D6A71C93C53B4A408D9944BDE0C34B40D6A71C93C53B4A40DB8AFD65F7844B4035ED629AE9D44940DB8AFD65F7844B40
173	Елабужский район	\N	64	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
1949	Елабужский муниципальный район	\N	64	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
376	Дрожжановский район	\N	64	47.257779999999997	48.114691999999998	54.909753000000002	54.496384999999997	0103000020E610000001000000050000000CC85EEFFEA04740CB9C2E8B893F4B400CC85EEFFEA047400D384BC972744B40718E3A3AAE0E48400D384BC972744B40718E3A3AAE0E4840CB9C2E8B893F4B400CC85EEFFEA04740CB9C2E8B893F4B40
13	Высокогорский район	\N	64	48.894348999999998	49.757333000000003	56.340834000000001	55.863227000000002	0103000020E61000000100000005000000EB1A2D077A7248401903EB387EEE4B40EB1A2D077A724840B4AED172A02B4C403E97A949F0E04840B4AED172A02B4C403E97A949F0E048401903EB387EEE4B40EB1A2D077A7248401903EB387EEE4B40
1872	Верхнеуслонский район	\N	64	48.428176999999998	49.03586	55.787432000000003	55.306987999999997	0103000020E610000001000000050000001FF30181CE364840D921FE614BA74B401FF30181CE36484075E95F92CAE44B40069E7B0F9784484075E95F92CAE44B40069E7B0F97844840D921FE614BA74B401FF30181CE364840D921FE614BA74B40
1742	Буинский район	\N	64	47.762264999999999	48.595891999999999	55.229326999999998	54.720179000000002	0103000020E6100000010000000500000056F146E691E147400C2252D32E5C4B4056F146E691E147407E8B4E965A9D4B4059F96530464C48407E8B4E965A9D4B4059F96530464C48400C2252D32E5C4B4056F146E691E147400C2252D32E5C4B40
1683	Бугульминский район	\N	64	52.486764999999998	53.145159	54.804498000000002	54.266773000000001	0103000020E6100000010000000500000031EBC5504E3E4A40583A1F9E25224B4031EBC5504E3E4A4045D95BCAF9664B402BDCF29194924A4045D95BCAF9664B402BDCF29194924A40583A1F9E25224B4031EBC5504E3E4A40583A1F9E25224B40
6902	Бугульминский муниципальный район	\N	64	52.486764999999998	53.145159	54.804498000000002	54.266773000000001	0103000020E6100000010000000500000031EBC5504E3E4A40583A1F9E25224B4031EBC5504E3E4A4045D95BCAF9664B402BDCF29194924A4045D95BCAF9664B402BDCF29194924A40583A1F9E25224B4031EBC5504E3E4A40583A1F9E25224B40
1620	Балтасинский район	\N	64	49.921294000000003	50.595954999999996	56.675643000000001	56.230896999999999	0103000020E61000000100000005000000220038F6ECF548404CDF6B088E1D4C40220038F6ECF54840BB6246787B564C409F71E140484C4940BB6246787B564C409F71E140484C49404CDF6B088E1D4C40220038F6ECF548404CDF6B088E1D4C40
1546	Бавлинский район	\N	64	52.950000000000003	53.504125000000002	54.573400999999997	53.974775999999999	0103000020E610000001000000050000009A99999999794A407D76C075C5FC4A409A99999999794A40313F373465494B404A0C022B87C04A40313F373465494B404A0C022B87C04A407D76C075C5FC4A409A99999999794A407D76C075C5FC4A40
1481	Атнинский район	\N	64	49.105992000000001	49.679692000000003	56.479092999999999	56.087494	0103000020E610000001000000050000009ED15625918D4840514CDE00330B4C409ED15625918D48400B5F5FEB523D4C402AADBF2500D748400B5F5FEB523D4C402AADBF2500D74840514CDE00330B4C409ED15625918D4840514CDE00330B4C40
1263	Арский район	\N	64	49.488287999999997	50.300688000000001	56.537591999999997	55.916899999999998	0103000020E61000000100000005000000BE839F3880BE4840E8D9ACFA5CF54B40BE839F3880BE4840AD4B8DD0CF444C405B26C3F17C264940AD4B8DD0CF444C405B26C3F17C264940E8D9ACFA5CF54B40BE839F3880BE4840E8D9ACFA5CF54B40
950	Апастовский район	\N	64	48.004854999999999	48.852694	55.435395999999997	55.101401000000003	0103000020E610000001000000050000006D1CB1169F0048400F643DB5FA8C4B406D1CB1169F00484094675E0EBBB74B406ABFB513256D484094675E0EBBB74B406ABFB513256D48400F643DB5FA8C4B406D1CB1169F0048400F643DB5FA8C4B40
151	Альметьевский район	\N	64	51.443381000000002	52.769168999999998	55.219098000000002	54.677999999999997	0103000020E610000001000000050000007A5567B5C0B84940105839B4C8564B407A5567B5C0B849403C4F3C670B9C4B406B0C3A2174624A403C4F3C670B9C4B406B0C3A2174624A40105839B4C8564B407A5567B5C0B84940105839B4C8564B40
7477	Альметьевск городской округ	\N	64	52.248362	52.385624	54.921101	54.861719999999998	0103000020E61000000100000005000000DAC87553CA1F4A40912749D74C6E4B40DAC87553CA1F4A400DA837A3E6754B40BF4692205C314A400DA837A3E6754B40BF4692205C314A40912749D74C6E4B40DAC87553CA1F4A40912749D74C6E4B40
310	Алькеевский район	\N	64	49.578892000000003	50.257192000000003	55.056600000000003	54.501153000000002	0103000020E6100000010000000500000041F50F2219CA48406AA510C825404B4041F50F2219CA4840107A36AB3E874B407C65DEAAEB204940107A36AB3E874B407C65DEAAEB2049406AA510C825404B4041F50F2219CA48406AA510C825404B40
6904	Алькеевский муниципальный район	\N	64	49.578892000000003	50.257192000000003	55.056600000000003	54.501153000000002	0103000020E6100000010000000500000041F50F2219CA48406AA510C825404B4041F50F2219CA4840107A36AB3E874B407C65DEAAEB204940107A36AB3E874B407C65DEAAEB2049406AA510C825404B4041F50F2219CA48406AA510C825404B40
20	Алексеевский район	\N	64	49.641891000000001	50.560786	55.414597999999998	54.857698999999997	0103000020E61000000100000005000000624CFA7B29D24840EC67B114C96D4B40624CFA7B29D24840567E198C11B54B40FF06EDD5C7474940567E198C11B54B40FF06EDD5C7474940EC67B114C96D4B40624CFA7B29D24840EC67B114C96D4B40
1851	Актанышский район	\N	64	53.316350999999997	54.268591999999998	55.929020999999999	55.347335999999999	0103000020E61000000100000005000000488787307EA84A409A5C8C8175AC4B40488787307EA84A400B26FE28EAF64B40CEFBFF3861224B400B26FE28EAF64B40CEFBFF3861224B409A5C8C8175AC4B40488787307EA84A409A5C8C8175AC4B40
1802	Аксубаевский район	\N	64	50.456384	51.246685999999997	55.067895999999998	54.633901000000002	0103000020E61000000100000005000000763579CA6A3A49406BF3FFAA23514B40763579CA6A3A4940BDC3EDD0B0884B40C6302768939F4940BDC3EDD0B0884B40C6302768939F49406BF3FFAA23514B40763579CA6A3A49406BF3FFAA23514B40
1309	Азнакаевский район	\N	64	52.685572000000001	53.650452000000001	55.191299999999998	54.650396000000001	0103000020E61000000100000005000000D386C3D2C0574A4080B9162D40534B40D386C3D2C0574A40C6DCB5847C984B4014CFD90242D34A40C6DCB5847C984B4014CFD90242D34A4080B9162D40534B40D386C3D2C0574A4080B9162D40534B40
1646	Агрызский район	\N	64	52.556600000000003	53.578505999999997	56.543840000000003	55.842897999999998	0103000020E61000000100000005000000107A36AB3E474A4091EEE714E4EB4B40107A36AB3E474A40DA20938C9C454C4017450F7C0CCA4A40DA20938C9C454C4017450F7C0CCA4A4091EEE714E4EB4B40107A36AB3E474A4091EEE714E4EB4B40
6930	 Чистопольский муниципальный район	\N	64	50.290295	51.245285000000003	55.489998	55.034198000000004	0103000020E610000001000000050000009E98F5622825494058CB9D9960844B409E98F562282549407E8D2441B8BE4B408599B67F659F49407E8D2441B8BE4B408599B67F659F494058CB9D9960844B409E98F5622825494058CB9D9960844B40
6923	 Елабужский район	\N	64	51.435054000000001	52.317360999999998	55.982078999999999	55.584074999999999	0103000020E610000001000000050000003BFF76D9AFB74940A2B437F8C2CA4B403BFF76D9AFB74940508BC1C3B4FD4B404F0306499F284A40508BC1C3B4FD4B404F0306499F284A40A2B437F8C2CA4B403BFF76D9AFB74940A2B437F8C2CA4B40
1108	Чамзинский район	\N	63	45.474795	46.087094999999998	54.651099000000002	54.214699000000003	0103000020E61000000100000005000000F4A62215C6BC4640F1BDBF417B1B4B40F4A62215C6BC4640AABA473657534B409352D0ED250B4740AABA473657534B409352D0ED250B4740F1BDBF417B1B4B40F4A62215C6BC4640F1BDBF417B1B4B40
838	Торбеевский район	\N	63	42.8673	43.552399999999999	54.396396000000003	53.928111000000001	0103000020E6100000010000000500000010E9B7AF036F454068075C57CCF64A4010E9B7AF036F4540F321A81ABD324B40BB270F0BB5C64540F321A81ABD324B40BB270F0BB5C6454068075C57CCF64A4010E9B7AF036F454068075C57CCF64A40
1711	Теньгушевский район	\N	63	42.389719999999997	43.064290999999997	54.842449999999999	54.493143000000003	0103000020E610000001000000050000006E4C4F58E23145402CA0504F1F3F4B406E4C4F58E2314540F241CF66D56B4B40AC36FFAF3A884540F241CF66D56B4B40AC36FFAF3A8845402CA0504F1F3F4B406E4C4F58E23145402CA0504F1F3F4B40
1600	Темниковский район	\N	63	42.831798999999997	43.658994	54.962059000000004	54.393697000000003	0103000020E6100000010000000500000039ECBE63786A454044C4CDA964324B4039ECBE63786A454047E9D2BF247B4B404F2157EA59D4454047E9D2BF247B4B404F2157EA59D4454044C4CDA964324B4039ECBE63786A454044C4CDA964324B40
1631	Старошайговский район	\N	63	44.207999999999998	44.966392999999997	54.604723	54.143596000000002	0103000020E61000000100000005000000B4C876BE9F1A464010EB8D5A61124B40B4C876BE9F1A4640CB113290674D4B40AA0A0DC4B27B4640CB113290674D4B40AA0A0DC4B27B464010EB8D5A61124B40B4C876BE9F1A464010EB8D5A61124B40
7414	Саранск городской округ	\N	63	45.081961999999997	45.292535999999998	54.237805000000002	54.061692999999998	0103000020E61000000100000005000000E3C116BB7D8A464031B2648EE5074B40E3C116BB7D8A4640A3E9EC64701E4B408A73D4D171A54640A3E9EC64701E4B408A73D4D171A5464031B2648EE5074B40E3C116BB7D8A464031B2648EE5074B40
1514	Рузаевский район	\N	63	44.517954000000003	45.144385	54.262393000000003	53.927802999999997	0103000020E610000001000000050000008C6A11514C424640BA10AB3FC2F64A408C6A11514C42464084D9041896214B4038842A357B92464084D9041896214B4038842A357B924640BA10AB3FC2F64A408C6A11514C424640BA10AB3FC2F64A40
6907	Рузаевский муниципальный район	\N	63	44.517954000000003	45.144385	54.262393000000003	53.927802999999997	0103000020E610000001000000050000008C6A11514C424640BA10AB3FC2F64A408C6A11514C42464084D9041896214B4038842A357B92464084D9041896214B4038842A357B924640BA10AB3FC2F64A408C6A11514C424640BA10AB3FC2F64A40
1380	Ромодановский район	\N	63	45.018199000000003	45.632295999999997	54.591397000000001	54.267898000000002	0103000020E61000000100000005000000F3E8465854824640F8544E7B4A224B40F3E8465854824640ECF99AE5B24B4B4020B24813EFD04640ECF99AE5B24B4B4020B24813EFD04640F8544E7B4A224B40F3E8465854824640F8544E7B4A224B40
1391	Лямбирский район	\N	63	44.870265000000003	45.595599999999997	54.480465000000002	54.12041	0103000020E610000001000000050000003EEDF0D7646F4640410E4A98690F4B403EEDF0D7646F4640B3EF8AE07F3D4B40B1BFEC9E3CCC4640B3EF8AE07F3D4B40B1BFEC9E3CCC4640410E4A98690F4B403EEDF0D7646F4640410E4A98690F4B40
287	Краснослободский район	\N	63	43.404591000000003	44.365501000000002	54.570791	54.235095000000001	0103000020E61000000100000005000000C3A04CA3C9B34540003ACC97171E4B40C3A04CA3C9B34540F2ECF2AD0F494B40E1D39CBCC82E4640F2ECF2AD0F494B40E1D39CBCC82E4640003ACC97171E4B40C3A04CA3C9B34540003ACC97171E4B40
1256	Кочкуровский район	\N	63	45.123024000000001	45.898448999999999	54.167296999999998	53.870213999999997	0103000020E61000000100000005000000C24F1C40BF8F4640BB421F2C63EF4A40C24F1C40BF8F464005DCF3FC69154B40DC0F786000F3464005DCF3FC69154B40DC0F786000F34640BB421F2C63EF4A40C24F1C40BF8F4640BB421F2C63EF4A40
698	Ковылкинский район	\N	63	43.476689999999998	44.344695999999999	54.336995999999999	53.736611000000003	0103000020E61000000100000005000000452A8C2D04BD4540DB6FED4449DE4A40452A8C2D04BD4540007157AF222B4B40F0879FFF1E2C4640007157AF222B4B40F0879FFF1E2C4640DB6FED4449DE4A40452A8C2D04BD4540DB6FED4449DE4A40
963	Кадошкинский район	\N	63	44.137993999999999	44.580199	54.300196999999997	53.932198	0103000020E61000000100000005000000A98592C9A9114640C4B2994352F74A40A98592C9A9114640BCADF4DA6C264B400116F9F5434A4640BCADF4DA6C264B400116F9F5434A4640C4B2994352F74A40A98592C9A9114640C4B2994352F74A40
866	Ичалковский район	\N	63	45.010446999999999	45.7836	54.882975000000002	54.522834000000003	0103000020E61000000100000005000000B0ABC95356814640529E7939EC424B40B0ABC95356814640C217265305714B40A3923A014DE44640C217265305714B40A3923A014DE44640529E7939EC424B40B0ABC95356814640529E7939EC424B40
903	Инсарский район	\N	63	44.038218000000001	44.734188000000003	53.975793000000003	53.644064	0103000020E610000001000000050000002C0FD253E4044640F6436CB070D24A402C0FD253E40446403755F7C8E6FC4A40CE8E54DFF95D46403755F7C8E6FC4A40CE8E54DFF95D4640F6436CB070D24A402C0FD253E4044640F6436CB070D24A40
475	Зубово-Полянский район	\N	63	42.164313999999997	43.181080999999999	54.508974000000002	53.733350999999999	0103000020E610000001000000050000003123BC3D0815454094BE1072DEDD4A403123BC3D08154540D5415E0F26414B40A77686A92D974540D5415E0F26414B40A77686A92D97454094BE1072DEDD4A403123BC3D0815454094BE1072DEDD4A40
466	Ельниковский район	\N	63	43.533400999999998	44.296843000000003	54.857196000000002	54.456499999999998	0103000020E61000000100000005000000AC53E57B46C44540DF4F8D976E3A4B40AC53E57B46C445408A213999B86D4B40F58590F3FE2546408A213999B86D4B40F58590F3FE254640DF4F8D976E3A4B40AC53E57B46C44540DF4F8D976E3A4B40
321	Дубенский район	\N	63	46.030996000000002	46.730441999999996	54.565795999999999	54.190046000000002	0103000020E6100000010000000500000046274BADF7034740295E656D53184B4046274BADF7034740931ADA006C484B40FACF9A1F7F5D4740931ADA006C484B40FACF9A1F7F5D4740295E656D53184B4046274BADF7034740295E656D53184B40
226	Большеигнатовский район	\N	63	45.401294999999998	45.876198000000002	55.190255999999998	54.804597000000001	0103000020E610000001000000050000002F8672A25DB34640D8BAD408FD664B402F8672A25DB3464013EF004F5A984B400A698D4127F0464013EF004F5A984B400A698D4127F04640D8BAD408FD664B402F8672A25DB34640D8BAD408FD664B40
67	Большеберезниковский район	\N	63	45.571489	46.331895000000003	54.378695999999998	54.021098000000002	0103000020E610000001000000050000000A83328D26C946406901DA56B3024B400A83328D26C9464021904B1C79304B405C5A0D897B2A474021904B1C79304B405C5A0D897B2A47406901DA56B3024B400A83328D26C946406901DA56B3024B40
270	Атяшевский район	\N	63	45.668391	46.536298000000002	54.807195999999998	54.459102000000001	0103000020E610000001000000050000006AF816D68DD546409CC3B5DAC33A4B406AF816D68DD5464023BBD23252674B408274B169A544474023BBD23252674B408274B169A54447409CC3B5DAC33A4B406AF816D68DD546409CC3B5DAC33A4B40
1801	Атюрьевский район	\N	63	42.960293999999998	43.606594999999999	54.503799000000001	54.177695	0103000020E61000000100000005000000C345EEE9EA7A4540D4D4B2B5BE164B40C345EEE9EA7A4540F660527C7C404B406475ABE7A4CD4540F660527C7C404B406475ABE7A4CD4540D4D4B2B5BE164B40C345EEE9EA7A4540D4D4B2B5BE164B40
1824	Ардатовский район	\N	63	45.754897999999997	46.454911000000003	55.083910000000003	54.628298000000001	0103000020E610000001000000050000006CE8667FA0E046403412A1116C504B406CE8667FA0E0464058E71890BD8A4B409BCB0D863A3A474058E71890BD8A4B409BCB0D863A3A47403412A1116C504B406CE8667FA0E046403412A1116C504B40
1792	Юринский район	\N	62	45.626528999999998	46.420397000000001	56.904153000000001	56.168861999999997	0103000020E610000001000000050000006F7F2E1A32D04640C1C41F459D154C406F7F2E1A32D0464047CA1649BB734C40132BA391CF35474047CA1649BB734C40132BA391CF354740C1C41F459D154C406F7F2E1A32D04640C1C41F459D154C40
1765	Советский район	\N	62	48.129998999999998	48.809494000000001	56.985996	56.447996000000003	0103000020E61000000100000005000000A0C1A6CEA3104840925ED4EE57394C40A0C1A6CEA310484050FEEE1D357E4C407427D87F9D67484050FEEE1D357E4C407427D87F9D674840925ED4EE57394C40A0C1A6CEA3104840925ED4EE57394C40
1730	Сернурский район	\N	62	48.900286999999999	49.595393999999999	57.343259000000003	56.839995999999999	0103000020E61000000100000005000000C901BB9A3C734840AA622AFD846B4C40C901BB9A3C734840628731E9EFAB4C40081EDFDE35CC4840628731E9EFAB4C40081EDFDE35CC4840AA622AFD846B4C40C901BB9A3C734840AA622AFD846B4C40
1707	Параньгинский район	\N	62	49.180093999999997	49.695690999999997	56.928597000000003	56.535496999999999	0103000020E61000000100000005000000581AF8510D974840950D6B2A8B444C40581AF8510D974840F5143944DC764C408E8F16670CD94840F5143944DC764C408E8F16670CD94840950D6B2A8B444C40581AF8510D974840950D6B2A8B444C40
1677	Оршанский район	\N	62	47.601025999999997	48.384895999999998	57.104101999999997	56.771096999999997	0103000020E61000000100000005000000D905836BEECC47409885764EB3624C40D905836BEECC47405EB9DE36538D4C403C2EAA45443148405EB9DE36538D4C403C2EAA45443148409885764EB3624C40D905836BEECC47409885764EB3624C40
1661	Новоторъяльский район	\N	62	48.221905999999997	48.944195999999998	57.174191	56.867198000000002	0103000020E61000000100000005000000A164726A671C48400C941458006F4C40A164726A671C4840F72004E44B964C40CB811E6ADB784840F72004E44B964C40CB811E6ADB7848400C941458006F4C40A164726A671C48400C941458006F4C40
1583	Моркинский район	\N	62	48.412393999999999	49.577894999999998	56.674000999999997	56.183898999999997	0103000020E6100000010000000500000087889B53C934484030629F008A174C4087889B53C9344840533C2EAA45564C40CEC29E76F8C94840533C2EAA45564C40CEC29E76F8C9484030629F008A174C4087889B53C934484030629F008A174C40
1452	Медведевский район	\N	62	47.184693000000003	48.364593999999997	56.924112000000001	56.319294999999997	0103000020E610000001000000050000006B662D05A49747405E6397A8DE284C406B662D05A4974740ABEB504D49764C40AE282504AB2E4840ABEB504D49764C40AE282504AB2E48405E6397A8DE284C406B662D05A49747405E6397A8DE284C40
1390	Мари-Турекский район	\N	62	49.485494000000003	50.202781000000002	57.077458999999998	56.425621	0103000020E61000000100000005000000BE33DAAA24BE4840D3BEB9BF7A364C40BE33DAAA24BE4840F3E32F2DEA894C4006A051BAF4194940F3E32F2DEA894C4006A051BAF4194940D3BEB9BF7A364C40BE33DAAA24BE4840D3BEB9BF7A364C40
1334	Куженерский район	\N	62	48.681089	49.355589000000002	56.923498000000002	56.592396999999998	0103000020E610000001000000050000002A55A2EC2D574840CF9F36AAD34B4C402A55A2EC2D574840F1F5B52E35764C409FE8BAF083AD4840F1F5B52E35764C409FE8BAF083AD4840CF9F36AAD34B4C402A55A2EC2D574840CF9F36AAD34B4C40
1284	Килемарский район	\N	62	46.272993	47.299092999999999	56.972110000000001	56.193666999999998	0103000020E61000000100000005000000BA84436FF12247403FA88B14CA184C40BA84436FF1224740AA0EB9196E7C4C4034BBEEAD48A64740AA0EB9196E7C4C4034BBEEAD48A647403FA88B14CA184C40BA84436FF12247403FA88B14CA184C40
1520	Йошкар-Ола городской округ	\N	62	47.794801999999997	48.079504999999997	56.683613000000001	56.539949	0103000020E61000000100000005000000CF656A12BCE547400341800C1D454C40CF656A12BCE547406B0F7BA180574C402A6F47382D0A48406B0F7BA180574C402A6F47382D0A48400341800C1D454C40CF656A12BCE547400341800C1D454C40
1199	Звениговский район	\N	62	47.238197	48.609788999999999	56.480896999999999	55.913030999999997	0103000020E61000000100000005000000AE80423D7D9E4740F99D2633DEF44B40AE80423D7D9E47404CDF6B088E3D4C40F33AE2900D4E48404CDF6B088E3D4C40F33AE2900D4E4840F99D2633DEF44B40AE80423D7D9E4740F99D2633DEF44B40
1095	Горномарийский район	\N	62	46.043616999999998	46.813769999999998	56.637298000000001	56.017885	0103000020E610000001000000050000005A46EA3D95054740630B410E4A024C405A46EA3D9505474032E719FB92514C40A33B889D2968474032E719FB92514C40A33B889D29684740630B410E4A024C405A46EA3D95054740630B410E4A024C40
878	Волжский район	\N	62	48.220792000000003	48.996037999999999	56.206296999999999	55.828313999999999	0103000020E61000000100000005000000F69B89E9421C4840D368723106EA4B40F69B89E9421C4840A721AAF0671A4C4060C9552C7E7F4840A721AAF0671A4C4060C9552C7E7F4840D368723106EA4B40F69B89E9421C4840D368723106EA4B40
7458	Сибай городской округ	\N	61	58.633747999999997	58.701571000000001	52.741194	52.679406999999998	0103000020E61000000100000005000000E4F38AA71E514D4034D6FECEF6564A40E4F38AA71E514D40E7FEEA71DF5E4A4038691A14CD594D40E7FEEA71DF5E4A4038691A14CD594D4034D6FECEF6564A40E4F38AA71E514D4034D6FECEF6564A40
1261	Федоровский район	\N	61	54.874972999999997	55.682845	53.355600000000003	52.898806999999998	0103000020E6100000010000000500000006F1811DFF6F4B403B35971B0C734A4006F1811DFF6F4B40933A014D84AD4A405A9E077767D74B40933A014D84AD4A405A9E077767D74B403B35971B0C734A4006F1811DFF6F4B403B35971B0C734A40
1613	Янаульский район	\N	61	54.327314999999999	55.508347999999998	56.533661000000002	55.988700999999999	0103000020E61000000100000005000000C03E3A75E5294B40E1421EC18DFE4B40C03E3A75E5294B404913EF004F444C40567E198C11C14B404913EF004F444C40567E198C11C14B40E1421EC18DFE4B40C03E3A75E5294B40E1421EC18DFE4B40
1348	Шаранский район	\N	61	53.592897000000001	54.396915999999997	55.049698999999997	54.666899999999998	0103000020E61000000100000005000000C172840CE4CB4A40E8D9ACFA5C554B40C172840CE4CB4A406BD26D895C864B402BA1BB24CE324B406BD26D895C864B402BA1BB24CE324B40E8D9ACFA5C554B40C172840CE4CB4A40E8D9ACFA5C554B40
357	Чишминский район	\N	61	54.891421000000001	55.784993	54.828071000000001	54.317405999999998	0103000020E61000000100000005000000DBFB54151A724B40EFC682C2A0284B40DBFB54151A724B400DE2033BFE694B40624B8FA67AE44B400DE2033BFE694B40624B8FA67AE44B40EFC682C2A0284B40DBFB54151A724B40EFC682C2A0284B40
317	Чекмагушевский район	\N	61	54.162123000000001	55.109181	55.352204	54.901600000000002	0103000020E61000000100000005000000F7764B72C0144B406C09F9A067734B40F7764B72C0144B409CC24A0515AD4B401B2C9CA4F98D4B409CC24A0515AD4B401B2C9CA4F98D4B406C09F9A067734B40F7764B72C0144B406C09F9A067734B40
106	Хайбуллинский район	\N	61	57.299686999999999	58.713113999999997	52.379731999999997	51.719147999999997	0103000020E61000000100000005000000A704C4245CA64C40ED7DAA0A0DDC4940A704C4245CA64C40519FE40E9B304A40ED28CE51475B4D40519FE40E9B304A40ED28CE51475B4D40ED7DAA0A0DDC4940A704C4245CA64C40ED7DAA0A0DDC4940
659	Учалинский район	\N	61	58.535786999999999	59.997571000000001	54.907760000000003	53.856014999999999	0103000020E610000001000000050000009C4F1DAB94444D4056F146E691ED4A409C4F1DAB94444D40F94ECC7A31744B4011381268B0FF4D40F94ECC7A31744B4011381268B0FF4D4056F146E691ED4A409C4F1DAB94444D4056F146E691ED4A40
284	Уфимский район	\N	61	54.909962	55.986566000000003	55.055309999999999	54.605620000000002	0103000020E61000000100000005000000274D83A279744B40DAE6C6F4844D4B40274D83A279744B402592E86514874B403BAC70CB47FE4B402592E86514874B403BAC70CB47FE4B40DAE6C6F4844D4B40274D83A279744B40DAE6C6F4844D4B40
308	Туймазинский район	\N	61	53.384163999999998	54.355513000000002	54.797055999999998	54.265000999999998	0103000020E61000000100000005000000782634492CB14A402234828DEB214B40782634492CB14A40508A56EE05664B40C4263273812D4B40508A56EE05664B40C4263273812D4B402234828DEB214B40782634492CB14A402234828DEB214B40
102	Татышлинский район	\N	61	55.324354999999997	56.204982000000001	56.455936000000001	56.069203000000002	0103000020E61000000100000005000000A4A5F27684A94B407EE4D6A4DB084C40A4A5F27684A94B40D788601C5C3A4C406422A5D93C1A4C40D788601C5C3A4C406422A5D93C1A4C407EE4D6A4DB084C40A4A5F27684A94B407EE4D6A4DB084C40
130	Стерлитамакский район	\N	61	55.228873	56.245289999999997	53.950409000000001	53.321604000000001	0103000020E61000000100000005000000FDF7E0B54B9D4B40A321E3512AA94A40FDF7E0B54B9D4B407B698A00A7F94A409604A8A9651F4C407B698A00A7F94A409604A8A9651F4C40A321E3512AA94A40FDF7E0B54B9D4B40A321E3512AA94A40
7457	Стерлитамак городской округ	\N	61	55.887490999999997	56.015715999999998	53.717587000000002	53.586081999999998	0103000020E61000000100000005000000463F1A4E99F14B401B6327BC04CB4A40463F1A4E99F14B4073840CE4D9DB4A4010035DFB02024C4073840CE4D9DB4A4010035DFB02024C401B6327BC04CB4A40463F1A4E99F14B401B6327BC04CB4A40
368	Стерлибашевский район	\N	61	54.549863000000002	55.709139	53.633505	53.182302999999997	0103000020E61000000100000005000000E62329E961464B40397B67B455974A40E62329E961464B401E6D1CB116D14A40B9A81611C5DA4B401E6D1CB116D14A40B9A81611C5DA4B40397B67B455974A40E62329E961464B40397B67B455974A40
787	Салаватский район	\N	61	57.473655000000001	58.826419000000001	55.519626000000002	54.907536999999998	0103000020E610000001000000050000001F4B1FBAA0BC4C407974232C2A744B401F4B1FBAA0BC4C405E13D21A83C24B4082E50819C8694D405E13D21A83C24B4082E50819C8694D407974232C2A744B401F4B1FBAA0BC4C407974232C2A744B40
944	Нуримановский район	\N	61	56.381968000000001	57.484200999999999	55.591019000000003	54.935912000000002	0103000020E610000001000000050000002C0FD253E4304C408CF7E3F6CB774B402C0FD253E4304C404628B682A6CB4B4062D8614CFABD4C404628B682A6CB4B4062D8614CFABD4C408CF7E3F6CB774B402C0FD253E4304C408CF7E3F6CB774B40
271	Миякинский район	\N	61	54.361117999999998	55.346362999999997	53.868901999999999	53.346725999999997	0103000020E610000001000000050000009BFF571D392E4B4021567F8461AC4A409BFF571D392E4B40E9B6442E38EF4A40B0C56E9F55AC4B40E9B6442E38EF4A40B0C56E9F55AC4B4021567F8461AC4A409BFF571D392E4B4021567F8461AC4A40
798	Мишкинский район	\N	61	55.333858999999997	56.331276000000003	55.797108000000001	55.309303999999997	0103000020E61000000100000005000000D53C47E4BBAA4B40D042024697A74B40D53C47E4BBAA4B40A3B08BA207E64B4090F98040672A4C40A3B08BA207E64B4090F98040672A4C40D042024697A74B40D53C47E4BBAA4B40D042024697A74B40
237	Мечетлинский район	\N	61	57.896096999999997	58.831674	56.173006000000001	55.613128000000003	0103000020E610000001000000050000009885764EB3F24C40862172FA7ACE4B409885764EB3F24C408201840F25164C407D772B4B746A4D408201840F25164C407D772B4B746A4D40862172FA7ACE4B409885764EB3F24C40862172FA7ACE4B40
179	Мелеузовский район	\N	61	55.553156000000001	56.902928000000003	53.390208000000001	52.814706000000001	0103000020E6100000010000000500000008CBD8D0CDC64B4070ED444948684A4008CBD8D0CDC64B409C51F355F2B14A4044520B2593734C409C51F355F2B14A4044520B2593734C4070ED444948684A4008CBD8D0CDC64B4070ED444948684A40
531	Куюргазинский район	\N	61	55.105902	56.202907000000003	52.962105000000001	52.346147000000002	0103000020E610000001000000050000005E4A5D328E8D4B40E44D7E8B4E2C4A405E4A5D328E8D4B40B728B341267B4A40939048DBF8194C40B728B341267B4A40939048DBF8194C40E44D7E8B4E2C4A405E4A5D328E8D4B40E44D7E8B4E2C4A40
1041	Кушнаренковский район	\N	61	54.856791000000001	55.935415999999996	55.297302000000002	54.782001999999999	0103000020E61000000100000005000000EA40D653AB6D4B400BB43BA418644B40EA40D653AB6D4B408884EFFD0DA64B40DB1324B6BBF74B408884EFFD0DA64B40DB1324B6BBF74B400BB43BA418644B40EA40D653AB6D4B400BB43BA418644B40
258	Кугарчинский район	\N	61	55.980421	57.182384999999996	53.005113999999999	52.233711999999997	0103000020E61000000100000005000000E3A7716F7EFD4B4064575A46EA1D4A40E3A7716F7EFD4B4039605793A7804A40F623456458974C4039605793A7804A40F623456458974C4064575A46EA1D4A40E3A7716F7EFD4B4064575A46EA1D4A40
482	Краснокамский район	\N	61	53.704566999999997	54.696899000000002	56.247425999999997	55.684102000000003	0103000020E61000000100000005000000A06B5F402FDA4A40699082A790D74B40A06B5F402FDA4A400D17B9A7AB1F4C40BCCE86FC33594B400D17B9A7AB1F4C40BCCE86FC33594B40699082A790D74B40A06B5F402FDA4A40699082A790D74B40
6677	Кировский район	\N	61	55.870835999999997	56.092962	54.753284000000001	54.500791999999997	0103000020E61000000100000005000000F816D68D77EF4B40990CC7F319404B40F816D68D77EF4B40CF4C309C6B604B40A8E2C62DE60B4C40CF4C309C6B604B40A8E2C62DE60B4C40990CC7F319404B40F816D68D77EF4B40990CC7F319404B40
207	Кигинский район	\N	61	58.292926999999999	59.183965999999998	55.666533000000001	55.137929	0103000020E61000000100000005000000C58EC6A17E254D40C21550A8A7914B40C58EC6A17E254D40365A0EF450D54B40B8C9A8328C974D40365A0EF450D54B40B8C9A8328C974D40C21550A8A7914B40C58EC6A17E254D40C21550A8A7914B40
64	Кармаскалинский район	\N	61	55.540129999999998	56.529705	54.517122000000001	54.122267999999998	0103000020E6100000010000000500000053CBD6FA22C54B4075AC527AA60F4B4053CBD6FA22C54B406405BF0D31424B408BC3995FCD434C406405BF0D31424B408BC3995FCD434C4075AC527AA60F4B4053CBD6FA22C54B4075AC527AA60F4B40
518	Караидельский район	\N	61	56.231383999999998	57.705348000000001	56.076117000000004	55.462814000000002	0103000020E61000000100000005000000A968ACFD9D1D4C40C310397D3DBB4B40A968ACFD9D1D4C40B7D5AC33BE094C404626E0D748DA4C40B7D5AC33BE094C404626E0D748DA4C40C310397D3DBB4B40A968ACFD9D1D4C40C310397D3DBB4B40
706	Калтасинский район	\N	61	54.410418	55.422153999999999	56.151300999999997	55.718806000000001	0103000020E6100000010000000500000049D8B79388344B409415C3D501DC4B4049D8B79388344B40116DC7D45D134C4013F06B2409B64B40116DC7D45D134C4013F06B2409B64B409415C3D501DC4B4049D8B79388344B409415C3D501DC4B40
300	Ишимбайский район	\N	61	55.9587	57.206972	53.853110000000001	53.115406	0103000020E610000001000000050000006D567DAEB6FA4B408FE1B19FC58E4A406D567DAEB6FA4B40FEF15EB532ED4A400798F90E7E9A4C40FEF15EB532ED4A400798F90E7E9A4C408FE1B19FC58E4A406D567DAEB6FA4B408FE1B19FC58E4A40
293	Илишевский район	\N	61	53.845934	54.697096999999999	55.829901	55.203400999999999	0103000020E610000001000000050000008849B89047EC4A40A27C410B099A4B408849B89047EC4A4077F52A323AEA4B40E29178793A594B4077F52A323AEA4B40E29178793A594B40A27C410B099A4B408849B89047EC4A40A27C410B099A4B40
877	Иглинский район	\N	61	56.227044999999997	57.621670000000002	55.097403999999997	54.484147	0103000020E6100000010000000500000033DC80CF0F1D4C406FBA6587F83D4B4033DC80CF0F1D4C40F23FF9BB778C4B40C173EFE192CF4C40F23FF9BB778C4B40C173EFE192CF4C406FBA6587F83D4B4033DC80CF0F1D4C406FBA6587F83D4B40
831	Зилаирский район	\N	61	56.884934999999999	58.192810000000001	52.99512	51.965124000000003	0103000020E61000000100000005000000FA0AD28C45714C40D84AE82E89FB4940FA0AD28C45714C403ACC9717607F4A40BF2B82FFAD184D403ACC9717607F4A40BF2B82FFAD184D40D84AE82E89FB4940FA0AD28C45714C40D84AE82E89FB4940
184	Зианчуринский район	\N	61	56.199835	57.401107000000003	52.462915000000002	51.572012999999998	0103000020E610000001000000050000004FCC7A3194194C4084F1D3B837C949404FCC7A3194194C40F7E978CC403B4A402D99637957B34C40F7E978CC403B4A402D99637957B34C4084F1D3B837C949404FCC7A3194194C4084F1D3B837C94940
144	Ермекеевский район	\N	61	53.420349000000002	54.009436999999998	54.328097	53.705078999999998	0103000020E6100000010000000500000002F4FBFECDB54A40560C570740DA4A4002F4FBFECDB54A4036751E15FF294B40A92F4B3B35014B4036751E15FF294B40A92F4B3B35014B40560C570740DA4A4002F4FBFECDB54A40560C570740DA4A40
133	Дюртюлинский район	\N	61	54.490709000000003	55.287461	55.760302000000003	55.249899999999997	0103000020E610000001000000050000002B6D718DCF3E4B409CA223B9FC9F4B402B6D718DCF3E4B40AD8A709351E14B400FF0A485CBA44B40AD8A709351E14B400FF0A485CBA44B409CA223B9FC9F4B402B6D718DCF3E4B409CA223B9FC9F4B40
119	Дуванский район	\N	61	57.282637000000001	58.500869000000002	56.149149999999999	55.373131999999998	0103000020E61000000100000005000000DDD1FF722DA44C40A88B14CAC2AF4B40DDD1FF722DA44C406519E25817134C40454AB3791C404D406519E25817134C40454AB3791C404D40A88B14CAC2AF4B40DDD1FF722DA44C40A88B14CAC2AF4B40
732	Давлекановский район	\N	61	54.385516000000003	55.602150000000002	54.482202000000001	54.022705999999999	0103000020E61000000100000005000000D90A9A9658314B4024B6BB07E8024B40D90A9A9658314B406C088ECBB83D4B40A9A44E4013CD4B406C088ECBB83D4B40A9A44E4013CD4B4024B6BB07E8024B40D90A9A9658314B4024B6BB07E8024B40
57	Гафурийский район	\N	61	56.105206000000003	57.172072999999997	54.320909	53.647010999999999	0103000020E61000000100000005000000E7ABE463770D4C407D93A641D1D24A40E7ABE463770D4C40FCFECD8B13294B4026C3F17C06964C40FCFECD8B13294B4026C3F17C06964C407D93A641D1D24A40E7ABE463770D4C407D93A641D1D24A40
158	Бурзянский район	\N	61	56.838034	58.200482000000001	53.566814000000001	52.863810000000001	0103000020E61000000100000005000000D177B7B2446B4C4098FA7953916E4A40D177B7B2446B4C401D75745C8DC84A40E5B7E864A9194D401D75745C8DC84A40E5B7E864A9194D4098FA7953916E4A40D177B7B2446B4C4098FA7953916E4A40
58	Бураевский район	\N	61	54.85839	55.832622000000001	56.090502000000001	55.538004999999998	0103000020E61000000100000005000000529B38B9DF6D4B40D00A0C59DDC44B40529B38B9DF6D4B407E1CCD91950B4C400EF7915B93EA4B407E1CCD91950B4C400EF7915B93EA4B40D00A0C59DDC44B40529B38B9DF6D4B40D00A0C59DDC44B40
1021	Буздякский район	\N	61	54.182721999999998	54.843693000000002	54.990101000000003	54.306196999999997	0103000020E610000001000000050000003E213B6F63174B4010919A7631274B403E213B6F63174B40535E2BA1BB7E4B409C6ED921FE6B4B40535E2BA1BB7E4B409C6ED921FE6B4B4010919A7631274B403E213B6F63174B4010919A7631274B40
497	Благовещенский район	\N	61	55.741073999999998	57.050961999999998	55.837772999999999	54.939838000000002	0103000020E610000001000000050000003CF54883DBDE4B40DFC4909C4C784B403CF54883DBDE4B40643C4A253CEB4B405CAB3DEC85864C40643C4A253CEB4B405CAB3DEC85864C40DFC4909C4C784B403CF54883DBDE4B40DFC4909C4C784B40
642	Благоварский район	\N	61	54.530611999999998	55.283365000000003	54.965600000000002	54.443004999999999	0103000020E61000000100000005000000BD6E1118EB434B40747B4963B4384B40BD6E1118EB434B404182E2C7987B4B4060EAE74D45A44B404182E2C7987B4B4060EAE74D45A44B40747B4963B4384B40BD6E1118EB434B40747B4963B4384B40
1594	Бирский район	\N	61	55.078378000000001	55.992010000000001	55.587102000000002	55.144902000000002	0103000020E61000000100000005000000EA5C514A088A4B40009013268C924B40EA5C514A088A4B4046B5882826CB4B4009A7052FFAFE4B4046B5882826CB4B4009A7052FFAFE4B40009013268C924B40EA5C514A088A4B40009013268C924B40
1414	Бижбулякский район	\N	61	53.783060999999996	54.633406999999998	53.987399000000003	53.360925000000002	0103000020E61000000100000005000000F3E2C4573BE44A4087A757CA32AE4A40F3E2C4573BE44A40338D261763FE4A405B07077B13514B40338D261763FE4A405B07077B13514B4087A757CA32AE4A40F3E2C4573BE44A4087A757CA32AE4A40
1403	Белорецкий район	\N	61	56.931207000000001	59.049219000000001	54.716678999999999	53.362419000000003	0103000020E6100000010000000500000034677DCA31774C407A39ECBE63AE4A4034677DCA31774C40705D3123BC5B4B40C1ABE5CE4C864D40705D3123BC5B4B40C1ABE5CE4C864D407A39ECBE63AE4A4034677DCA31774C407A39ECBE63AE4A40
1325	Белокатайский район	\N	61	58.439577	59.653030999999999	56.168244999999999	55.433945999999999	0103000020E610000001000000050000007289230F44384D40711DE38A8BB74B407289230F44384D40965B5A0D89154C401823128596D34D40965B5A0D89154C401823128596D34D40711DE38A8BB74B407289230F44384D40711DE38A8BB74B40
1158	Белебеевский район	\N	61	53.782243999999999	54.632212000000003	54.422203000000003	53.911200000000001	0103000020E6100000010000000500000001BF469220E44A40BF0E9C33A2F44A4001BF469220E44A40F5A276BF0A364B40C311A452EC504B40F5A276BF0A364B40C311A452EC504B40BF0E9C33A2F44A4001BF469220E44A40BF0E9C33A2F44A40
607	Балтачевский район	\N	61	55.571463000000001	56.393960999999997	56.172310000000003	55.687106	0103000020E61000000100000005000000E1EF17B325C94B405471E316F3D74B40E1EF17B325C94B400B630B410E164C40217365506D324C400B630B410E164C40217365506D324C405471E316F3D74B40E1EF17B325C94B405471E316F3D74B40
846	Бакалинский район	\N	61	53.157313000000002	54.240223	55.359389	54.879680999999998	0103000020E610000001000000050000002A1E17D522944A40CFF4126399704B402A1E17D522944A4065C5707500AE4B409E5F94A0BF1E4B4065C5707500AE4B409E5F94A0BF1E4B40CFF4126399704B402A1E17D522944A40CFF4126399704B40
322	Баймакский район	\N	61	57.519640000000003	58.952551	53.228923999999999	52.244731000000002	0103000020E61000000100000005000000C3D8429083C24C40A0A86C58531F4A40C3D8429083C24C407FA2B2614D9D4A40D462F030ED794D407FA2B2614D9D4A40D462F030ED794D40A0A86C58531F4A40C3D8429083C24C40A0A86C58531F4A40
55	Аургазинский район	\N	61	55.462561000000001	56.391877000000001	54.291207	53.763508999999999	0103000020E61000000100000005000000D9B3E73235BB4B40D099B4A9BAE14A40D9B3E73235BB4B40E2AE5E4546254B40FD86890629324C40E2AE5E4546254B40FD86890629324C40D099B4A9BAE14A40D9B3E73235BB4B40D099B4A9BAE14A40
998	Аскинский район	\N	61	56.136890000000001	57.596876999999999	56.405748000000003	55.878708000000003	0103000020E6100000010000000500000021938C9C85114C40E65DF58079F04B4021938C9C85114C406E35EB8CEF334C40075E2D7766CC4C406E35EB8CEF334C40075E2D7766CC4C40E65DF58079F04B4021938C9C85114C40E65DF58079F04B40
931	Архангельский район	\N	61	56.469563000000001	57.438395999999997	54.789513999999997	54.214782999999997	0103000020E61000000100000005000000B134F0A31A3C4C404E5E64027E1B4B40B134F0A31A3C4C40F8DD74CB0E654B403E59315C1DB84C40F8DD74CB0E654B403E59315C1DB84C404E5E64027E1B4B40B134F0A31A3C4C404E5E64027E1B4B40
672	Альшеевский район	\N	61	54.345621999999999	55.497954	54.245803000000002	53.702905000000001	0103000020E61000000100000005000000996379573D2C4B40F29881CAF8D94A40996379573D2C4B401D210379761F4B40C974E8F4BCBF4B401D210379761F4B40C974E8F4BCBF4B40F29881CAF8D94A40996379573D2C4B40F29881CAF8D94A40
571	Абзелиловский район	\N	61	57.854460000000003	58.989113000000003	53.877538999999999	52.857525000000003	0103000020E61000000100000005000000BEDEFDF15EED4C404F401361C36D4A40BEDEFDF15EED4C4076FBAC3253F04A40348639419B7E4D4076FBAC3253F04A40348639419B7E4D404F401361C36D4A40BEDEFDF15EED4C404F401361C36D4A40
1666	Чердаклинский район	\N	74	48.536487000000001	49.473923999999997	54.440967999999998	53.947493999999999	0103000020E6100000010000000500000055DD239BAB444840FF93BF7B47F94A4055DD239BAB444840904AB1A371384B400E65A88AA9BC4840904AB1A371384B400E65A88AA9BC4840FF93BF7B47F94A4055DD239BAB444840FF93BF7B47F94A40
1610	Цильнинский район	\N	74	47.515399000000002	48.281337999999998	54.766677000000001	54.339494000000002	0103000020E6100000010000000500000010B22C98F8C147401898158A742B4B4010B22C98F8C1474036CCD07822624B409F8F32E20224484036CCD07822624B409F8F32E2022448401898158A742B4B4010B22C98F8C147401898158A742B4B40
505	Ульяновский район	\N	74	47.820799000000001	48.549529999999997	54.694524000000001	54.053797000000003	0103000020E6100000010000000500000075CB0EF10FE94740BCCFF1D1E2064B4075CB0EF10FE94740C0249529E6584B40DF15C1FF56464840C0249529E6584B40DF15C1FF56464840BCCFF1D1E2064B4075CB0EF10FE94740BCCFF1D1E2064B40
1773	Ульяновск городской округ	\N	74	48.076450999999999	48.413426999999999	54.311076999999997	54.130974000000002	0103000020E610000001000000050000008D5F7825C90948402B508BC1C3104B408D5F7825C9094840D6C4025FD1274B4046240A2DEB344840D6C4025FD1274B4046240A2DEB3448402B508BC1C3104B408D5F7825C90948402B508BC1C3104B40
1471	Тереньгульский район	\N	74	47.912194	48.605271000000002	54.105699999999999	53.426676	0103000020E61000000100000005000000C0CDE2C5C2F447407AFEB4519DB64A40C0CDE2C5C2F44740F697DD93870D4B40CE1B2785794D4840F697DD93870D4B40CE1B2785794D48407AFEB4519DB64A40C0CDE2C5C2F447407AFEB4519DB64A40
1361	Сурский район	\N	74	46.411414000000001	47.399301000000001	54.762858999999999	54.370897999999997	0103000020E61000000100000005000000EB8EC536A93447406E13EE95792F4B40EB8EC536A9344740C93A1C5DA5614B404B21904B1CB34740C93A1C5DA5614B404B21904B1CB347406E13EE95792F4B40EB8EC536A93447406E13EE95792F4B40
1316	Старомайнский район	\N	74	48.599314999999997	49.584327000000002	54.890044000000003	54.351092999999999	0103000020E6100000010000000500000049809A5AB64C4840616D8C9DF02C4B4049809A5AB64C4840220038F6EC714B40BC95253ACBCA4840220038F6EC714B40BC95253ACBCA4840616D8C9DF02C4B4049809A5AB64C4840616D8C9DF02C4B40
1253	Старокулаткинский район	\N	74	47.238295000000001	48.089548000000001	52.961595000000003	52.571601999999999	0103000020E6100000010000000500000071E65773809E4740022A1C412A494A4071E65773809E4740A27F828B157B4A400BB6114F760B4840A27F828B157B4A400BB6114F760B4840022A1C412A494A4071E65773809E4740022A1C412A494A40
1184	Сенгилеевский район	\N	74	48.28689	48.984575	54.124198999999997	53.704546000000001	0103000020E6100000010000000500000054C6BFCFB8244840894336902EDA4A4054C6BFCFB82448401399B9C0E50F4B40C7BAB88D067E48401399B9C0E50F4B40C7BAB88D067E4840894336902EDA4A4054C6BFCFB8244840894336902EDA4A40
1130	Радищевский район	\N	74	47.425494999999998	48.593916	53.069721000000001	52.752397000000002	0103000020E6100000010000000500000046CEC29E76B64740E44D7E8B4E604A4046CEC29E76B64740166C239EEC884A401B498270054C4840166C239EEC884A401B498270054C4840E44D7E8B4E604A4046CEC29E76B64740E44D7E8B4E604A40
1044	Павловский район	\N	74	46.797123999999997	47.536141000000001	52.910099000000002	52.532910000000001	0103000020E61000000100000005000000A86DC328086647400EDB166536444A40A86DC32808664740A88FC01F7E744A40BA85AE44A0C44740A88FC01F7E744A40BA85AE44A0C447400EDB166536444A40A86DC328086647400EDB166536444A40
660	Новоспасский район	\N	74	47.458193999999999	48.215366000000003	53.356976000000003	52.989797000000003	0103000020E61000000100000005000000999CDA19A6BA4740E75608ABB17E4A40999CDA19A6BA47407CBABA63B1AD4A40CE55F31C911B48407CBABA63B1AD4A40CE55F31C911B4840E75608ABB17E4A40999CDA19A6BA4740E75608ABB17E4A40
892	Новомалыклинский район	\N	74	49.762794999999997	50.243626999999996	54.514513999999998	53.968367999999998	0103000020E61000000100000005000000B2463D44A3E14840183F8D7BF3FB4A40B2463D44A3E14840C5AA4198DB414B4017B6662B2F1F4940C5AA4198DB414B4017B6662B2F1F4940183F8D7BF3FB4A40B2463D44A3E14840183F8D7BF3FB4A40
154	Николаевский район	\N	74	46.862502999999997	47.606192	53.388795000000002	52.846398999999998	0103000020E61000000100000005000000D7D9907F666E4740FD2E6CCD566C4A40D7D9907F666E474096ECD808C4B14A40658C0FB397CD474096ECD808C4B14A40658C0FB397CD4740FD2E6CCD566C4A40D7D9907F666E4740FD2E6CCD566C4A40
411	Мелекесский район	\N	74	48.954993999999999	50.050767999999998	54.578232999999997	53.803218000000001	0103000020E6100000010000000500000028F04E3E3D7A48407EC7F0D8CFE64A4028F04E3E3D7A4840E63BF889034A4B4077D7D9907F064940E63BF889034A4B4077D7D9907F0649407EC7F0D8CFE64A4028F04E3E3D7A48407EC7F0D8CFE64A40
50	Майнский район	\N	74	47.253495000000001	48.055098000000001	54.567357000000001	53.764392999999998	0103000020E610000001000000050000008A592F8672A047404A253CA1D7E14A408A592F8672A047400E1478279F484B409A0986730D0748400E1478279F484B409A0986730D0748404A253CA1D7E14A408A592F8672A047404A253CA1D7E14A40
1910	Кузоватовский район	\N	74	47.302390000000003	48.088093000000001	54.023795999999997	53.322502	0103000020E6100000010000000500000098512CB7B4A647408272DBBE47A94A4098512CB7B4A6474047E350BF0B034B40D600A5A1460B484047E350BF0B034B40D600A5A1460B48408272DBBE47A94A4098512CB7B4A647408272DBBE47A94A40
1869	Карсунский район	\N	74	46.430692000000001	47.509695000000001	54.445	54.005898000000002	0103000020E610000001000000050000000D535BEA20374740508E0244C1004B400D535BEA20374740295C8FC2F5384B40A5F78DAF3DC14740295C8FC2F5384B40A5F78DAF3DC14740508E0244C1004B400D535BEA20374740508E0244C1004B40
186	Инзенский район	\N	74	45.796517000000001	46.802791999999997	54.272447	53.580795999999999	0103000020E61000000100000005000000A1DAE044F4E54640E5D2F88557CA4A40A1DAE044F4E546405872158BDF224B40C6BE64E3C16647405872158BDF224B40C6BE64E3C1664740E5D2F88557CA4A40A1DAE044F4E54640E5D2F88557CA4A40
1787	Вешкаймский район	\N	74	46.682993000000003	47.488197999999997	54.219299999999997	53.805594999999997	0103000020E61000000100000005000000CF328B506C5747401A69A9BC1DE74A40CF328B506C574740A301BC05121C4B407EFCA5457DBE4740A301BC05121C4B407EFCA5457DBE47401A69A9BC1DE74A40CF328B506C5747401A69A9BC1DE74A40
162	Барышский район	\N	74	46.689900999999999	47.720799	53.886699999999998	53.320597999999997	0103000020E61000000100000005000000253D0CAD4E584740DD94F25A09A94A40253D0CAD4E5847407DAEB6627FF14A40A8FE412443DC47407DAEB6627FF14A40A8FE412443DC4740DD94F25A09A94A40253D0CAD4E584740DD94F25A09A94A40
1691	Базарносызганский район	\N	74	46.443277000000002	46.993693	53.933799	53.429788000000002	0103000020E61000000100000005000000D508FD4CBD3847404C1B0E4B03B74A40D508FD4CBD384740CD04C3B986F74A40CFA10C55317F4740CD04C3B986F74A40CFA10C55317F47404C1B0E4B03B74A40D508FD4CBD3847404C1B0E4B03B74A40
7272	Хвалынск городской округ	\N	73	48.075355000000002	48.116928999999999	52.520538999999999	52.465795999999997	0103000020E61000000100000005000000884B8E3BA5094840C64D0D349F3B4A40884B8E3BA509484072A59E05A1424A401C7A8B87F70E484072A59E05A1424A401C7A8B87F70E4840C64D0D349F3B4A40884B8E3BA5094840C64D0D349F3B4A40
7271	Энгельсский район 	\N	73	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
288	Энгельсский район	\N	73	45.905070000000002	46.677486000000002	51.670589999999997	50.978185000000003	0103000020E610000001000000050000009D4B7155D9F346400938842A357D49409D4B7155D9F346402783A3E4D5D54940BABF7ADCB75647402783A3E4D5D54940BABF7ADCB75647400938842A357D49409D4B7155D9F346400938842A357D4940
626	Хвалынский район	\N	73	47.492176999999998	48.427987999999999	52.818674000000001	52.230798999999998	0103000020E61000000100000005000000F46BEBA7FFBE4740897956D28A1D4A40F46BEBA7FFBE4740F20A444FCA684A404C8A8F4FC8364840F20A444FCA684A404C8A8F4FC8364840897956D28A1D4A40F46BEBA7FFBE4740897956D28A1D4A40
218	Федоровский район	\N	73	47.089489999999998	48.067494000000003	51.556896999999999	50.919094999999999	0103000020E61000000100000005000000D6A88768748B47406475ABE7A4754940D6A88768748B4740C91EA16648C749408F56B5A4A3084840C91EA16648C749408F56B5A4A30848406475ABE7A4754940D6A88768748B47406475ABE7A4754940
201	Турковский район	\N	73	42.759025999999999	43.418695	52.333596	51.866698	0103000020E61000000100000005000000276893C3276145401AC1C6F5EFEE4940276893C327614540C8091346B32A4A40D6FF39CC97B54540C8091346B32A4A40D6FF39CC97B545401AC1C6F5EFEE4940276893C3276145401AC1C6F5EFEE4940
219	Татищевский район	\N	73	44.908901	46.040562999999999	52.061445999999997	51.544210999999997	0103000020E610000001000000050000009E2633DE56744640CD8FBFB4A8C549409E2633DE56744640293C6876DD074A40BD361B2B31054740293C6876DD074A40BD361B2B31054740CD8FBFB4A8C549409E2633DE56744640CD8FBFB4A8C54940
327	Советский район	\N	73	46.620299000000003	47.193891999999998	51.515698	51.046697999999999	0103000020E61000000100000005000000EA5E27F5654F4740F1643733FA854940EA5E27F5654F47406A4E5E6402C249405F7AFB73D19847406A4E5E6402C249405F7AFB73D1984740F1643733FA854940EA5E27F5654F4740F1643733FA854940
7270	Саратовский район 	\N	73	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
25	Саратовский район	\N	73	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
7267	Саратовский 	\N	73	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
826	Самойловский район	\N	73	43.081898000000002	44.223379000000001	51.488197999999997	50.999464000000003	0103000020E61000000100000005000000CDCD37A27B8A4540C2C3B46FEE7F4940CDCD37A27B8A45407EFCA5457DBE49407DCEDDAE971C46407EFCA5457DBE49407DCEDDAE971C4640C2C3B46FEE7F4940CDCD37A27B8A4540C2C3B46FEE7F4940
1712	Ртищевский район	\N	73	42.894717	44.309482000000003	52.458964000000002	51.962299000000002	0103000020E610000001000000050000006E162F16867245409CFC169D2CFB49406E162F16867245404B051555BF3A4A40B0592E1B9D2746404B051555BF3A4A40B0592E1B9D2746409CFC169D2CFB49406E162F16867245409CFC169D2CFB4940
622	Романовский район	\N	73	42.501936999999998	43.257500999999998	52.021588999999999	51.536228999999999	0103000020E6100000010000000500000080D3BB783F4045405915E126A3C4494080D3BB783F404540077AA86DC3024A40F9D7F2CAF5A04540077AA86DC3024A40F9D7F2CAF5A045405915E126A3C4494080D3BB783F4045405915E126A3C44940
1698	Ровенский район	\N	73	45.837696000000001	46.619590000000002	51.147399	50.526026999999999	0103000020E61000000100000005000000B9FE5D9F39EB464010E84CDA54434940B9FE5D9F39EB4640473B6EF8DD924940DE76A1B94E4F4740473B6EF8DD924940DE76A1B94E4F474010E84CDA54434940B9FE5D9F39EB464010E84CDA54434940
1233	Пугачевский район	\N	73	48.245190000000001	49.789690999999998	52.393098999999999	51.537097000000003	0103000020E6100000010000000500000033A7CB62621F4840CEE33098BFC4494033A7CB62621F48408F8B6A1151324A4007793D9814E548408F8B6A1151324A4007793D9814E54840CEE33098BFC4494033A7CB62621F4840CEE33098BFC44940
7265	Пугачев городской округ	\N	73	48.728475000000003	48.852477999999998	52.048171000000004	51.982500000000002	0103000020E61000000100000005000000107A36AB3E5D4840F6285C8FC2FD4940107A36AB3E5D4840CDCEA2772A064A409D47C5FF1D6D4840CDCEA2772A064A409D47C5FF1D6D4840F6285C8FC2FD4940107A36AB3E5D4840F6285C8FC2FD4940
387	Питерский район	\N	73	46.907266	47.884794999999997	50.991895999999997	50.371308999999997	0103000020E61000000100000005000000E962D34A21744740F0DAA50D872F4940E962D34A217447404084B872F67E494008556AF640F147404084B872F67E494008556AF640F14740F0DAA50D872F4940E962D34A21744740F0DAA50D872F4940
366	Петровский район	\N	73	44.855299000000002	45.856012999999997	52.508257	51.944299000000001	0103000020E6100000010000000500000098A608707A6D4640A05225CADEF8494098A608707A6D4640467BBC900E414A40B5F97FD591ED4640467BBC900E414A40B5F97FD591ED4640A05225CADEF8494098A608707A6D4640A05225CADEF84940
678	Перелюбский район	\N	73	49.442393000000003	50.833129	52.190283000000001	51.546995000000003	0103000020E610000001000000050000005B7D7555A0B84840AB09A2EE03C649405B7D7555A0B848400DFE7E315B184A40B22C98F8A36A49400DFE7E315B184A40B22C98F8A36A4940AB09A2EE03C649405B7D7555A0B84840AB09A2EE03C64940
432	Озинский район	\N	73	49.227696000000002	50.554946999999999	51.708700999999998	50.988011999999998	0103000020E610000001000000050000000BB77C24259D48401C075E2D777E49400BB77C24259D48403DD2E0B6B6DA4940B401D880084749403DD2E0B6B6DA4940B401D880084749401C075E2D777E49400BB77C24259D48401C075E2D777E4940
615	Новоузенский район	\N	73	47.693399999999997	49.163088999999999	50.893098000000002	50.092436999999997	0103000020E61000000100000005000000F085C954C1D847405DF8C1F9D40B4940F085C954C1D84740BF0F0709517249402EABB019E0944840BF0F0709517249402EABB019E09448405DF8C1F9D40B4940F085C954C1D847405DF8C1F9D40B4940
462	Новобурасский район	\N	73	45.586095999999998	46.382992000000002	52.414538	51.811835000000002	0103000020E610000001000000050000008028983105CB4640C45F9335EAE749408028983105CB46408179C8940F354A409850C1E1053147408179C8940F354A409850C1E105314740C45F9335EAE749408028983105CB4640C45F9335EAE74940
1239	Марксовский район	\N	73	46.407291000000001	47.820394999999998	51.965696000000001	51.409598000000003	0103000020E61000000100000005000000427A8A1C22344740E6400FB56DB44940427A8A1C2234474063F030ED9BFB4940A5660FB402E9474063F030ED9BFB4940A5660FB402E94740E6400FB56DB44940427A8A1C22344740E6400FB56DB44940
503	Лысогорский район	\N	73	44.536890999999997	45.458993	51.701495999999999	51.079065	0103000020E61000000100000005000000244223D8B84446400EA14ACD1E8A4940244223D8B84446402D23F59ECAD94940E50B5A48C0BA46402D23F59ECAD94940E50B5A48C0BA46400EA14ACD1E8A4940244223D8B84446400EA14ACD1E8A4940
193	Краснопартизанский район	\N	73	48.145594000000003	49.250287999999998	51.971499000000001	51.431097999999999	0103000020E61000000100000005000000363FFED2A21248407DAF21382EB74940363FFED2A2124840618C48145AFC4940664AEB6F09A04840618C48145AFC4940664AEB6F09A048407DAF21382EB74940363FFED2A21248407DAF21382EB74940
166	Краснокутский район	\N	73	46.519697000000001	47.437497	51.201298999999999	50.522430999999997	0103000020E61000000100000005000000276A696E8542474052B5DD04DF424940276A696E85424740D7DB662AC49949408F8CD5E6FFB74740D7DB662AC49949408F8CD5E6FFB7474052B5DD04DF424940276A696E8542474052B5DD04DF424940
116	Красноармейский район	\N	73	45.082715999999998	46.067494000000003	51.246195	50.550558000000002	0103000020E610000001000000050000008F6D1970968A46408D463EAF784649408F6D1970968A464028B85851839F49408F56B5A4A308474028B85851839F49408F56B5A4A30847408D463EAF784649408F6D1970968A46408D463EAF78464940
727	Калининский район	\N	73	43.729098999999998	44.859907	51.769413999999998	51.121648999999998	0103000020E61000000100000005000000ED45B41D53DD4540A94BC631928F4940ED45B41D53DD4540D28A6F287CE24940FD4CBD6E116E4640D28A6F287CE24940FD4CBD6E116E4640A94BC631928F4940ED45B41D53DD4540A94BC631928F4940
633	Ивантеевский район	\N	73	48.662799	49.791136999999999	52.499377000000003	52.007953000000001	0103000020E610000001000000050000002769FE98D6544840DA73999A04014A402769FE98D6544840F3AFE595EB3F4A40E9D32AFA43E54840F3AFE595EB3F4A40E9D32AFA43E54840DA73999A04014A402769FE98D6544840DA73999A04014A40
267	Ершовский район	\N	73	47.710997999999996	48.780092000000003	51.838799000000002	50.824795999999999	0103000020E61000000100000005000000BDC282FB01DB474091EF52EA92694940BDC282FB01DB4740717500C45DEB494085EFFD0DDA634840717500C45DEB494085EFFD0DDA63484091EF52EA92694940BDC282FB01DB474091EF52EA92694940
28	Екатериновский район	\N	73	44.009588999999998	44.924101	52.531315999999997	51.718198999999998	0103000020E610000001000000050000005FB35C363A0146408C82E0F1EDDB49405FB35C363A014640B7EBA52902444A40B7990AF148764640B7EBA52902444A40B7990AF1487646408C82E0F1EDDB49405FB35C363A0146408C82E0F1EDDB4940
239	Духовницкий район	\N	73	48.087392000000001	48.882095999999997	52.679805000000002	52.107396000000001	0103000020E610000001000000050000004DF73AA92F0B484051DCF126BF0D4A404DF73AA92F0B48402254A9D903574A4059F78F85E87048402254A9D903574A4059F78F85E870484051DCF126BF0D4A404DF73AA92F0B484051DCF126BF0D4A40
844	Дергачевский район	\N	73	48.160694999999997	49.443570000000001	51.552097000000003	50.773592999999998	0103000020E61000000100000005000000BBD05CA7911448400FB56D1805634940BBD05CA791144840209C4F1DABC649404DBED9E6C6B84840209C4F1DABC649404DBED9E6C6B848400FB56D1805634940BBD05CA7911448400FB56D1805634940
742	Воскресенский район	\N	73	46.189898999999997	47.099991000000003	52.119497000000003	51.728397999999999	0103000020E610000001000000050000008445459C4E184740643C4A253CDD49408445459C4E1847402D7C7DAD4B0F4A407A724D81CC8C47402D7C7DAD4B0F4A407A724D81CC8C4740643C4A253CDD49408445459C4E184740643C4A253CDD4940
663	Вольский район	\N	73	46.717398000000003	47.981490000000001	52.638314000000001	51.911794	0103000020E61000000100000005000000A01B9AB2D35B4740325871AAB5F44940A01B9AB2D35B47401B4AED45B4514A40EFACDD76A1FD47401B4AED45B4514A40EFACDD76A1FD4740325871AAB5F44940A01B9AB2D35B4740325871AAB5F44940
1497	Балтайский район	\N	73	46.259473	47.024298999999999	52.725850000000001	52.227997000000002	0103000020E61000000100000005000000F698486936214740064B75012F1D4A40F6984869362147409BE61DA7E85C4A40AA29C93A1C8347409BE61DA7E85C4A40AA29C93A1C834740064B75012F1D4A40F698486936214740064B75012F1D4A40
595	Балашовский район	\N	73	42.595829000000002	43.827392000000003	51.830696000000003	51.147635999999999	0103000020E610000001000000050000001381EA1F444C45402BDB87BCE59249401381EA1F444C454082751C3F54EA49406C7C26FBE7E9454082751C3F54EA49406C7C26FBE7E945402BDB87BCE59249401381EA1F444C45402BDB87BCE5924940
7273	Балашов городской округ	\N	73	43.118963000000001	43.242184999999999	51.565558000000003	51.515070000000001	0103000020E610000001000000050000008F37F92D3A8F45404B9352D0EDC149408F37F92D3A8F4540DFFE5C3464C84940774A07EBFF9E4540DFFE5C3464C84940774A07EBFF9E45404B9352D0EDC149408F37F92D3A8F45404B9352D0EDC14940
588	Балаковский район	\N	73	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
7264	Балаковский  район	\N	73	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
7255	Балаковский	\N	73	47.237693999999998	48.419795999999998	52.290596000000001	51.599395000000001	0103000020E610000001000000050000004B3ACAC16C9E47406631B1F9B8CC49404B3ACAC16C9E4740992CEE3F32254A40ED7E15E0BB354840992CEE3F32254A40ED7E15E0BB3548406631B1F9B8CC49404B3ACAC16C9E47406631B1F9B8CC4940
793	Базарно-Карабулакский район	\N	73	45.931497999999998	46.829391000000001	52.612057999999998	51.923898000000001	0103000020E610000001000000050000000B2593533BF746407F6B274A42F649400B2593533BF74640A9A0A2EA574E4A40624CFA7B296A4740A9A0A2EA574E4A40624CFA7B296A47407F6B274A42F649400B2593533BF746407F6B274A42F64940
819	Аткарский район	\N	73	44.490493000000001	45.539392999999997	52.233297999999998	51.564796999999999	0103000020E610000001000000050000005EF58079C83E464080F0A1444BC849405EF58079C83E4640711C78B5DC1D4A407D586FD40AC54640711C78B5DC1D4A407D586FD40AC5464080F0A1444BC849405EF58079C83E464080F0A1444BC84940
568	Аркадакский район	\N	73	43.141196000000001	44.049194999999997	52.168695999999997	51.608597000000003	0103000020E61000000100000005000000BB29E5B512924540CCB8A981E6CD4940BB29E5B512924540A67B9DD497154A40381092054C064640A67B9DD497154A40381092054C064640CCB8A981E6CD4940BB29E5B512924540CCB8A981E6CD4940
556	Александрово-Гайский район	\N	73	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
7258	Александрово-Гайский	\N	73	48.098512999999997	48.902504999999998	50.527493	49.801195999999997	0103000020E610000001000000050000008C9DF0129C0C4840CFD72C978DE648408C9DF0129C0C484039EFFFE384434940FDBCA9488573484039EFFFE384434940FDBCA94885734840CFD72C978DE648408C9DF0129C0C4840CFD72C978DE64840
7275	 Саратовский райо	\N	73	45.230435	46.235255000000002	51.846127000000003	51.223528999999999	0103000020E61000000100000005000000486DE2E47E9D4640925A28999C9C4940486DE2E47E9D46409DA1B8E34DEC4940399CF9D51C1E47409DA1B8E34DEC4940399CF9D51C1E4740925A28999C9C4940486DE2E47E9D4640925A28999C9C4940
7268	 Пугачевский 	\N	73	48.827415000000002	48.851616	52.040838000000001	52.027208000000002	0103000020E61000000100000005000000249C16BCE869484044183F8D7B034A40249C16BCE86948408F37F92D3A054A400B60CAC0016D48408F37F92D3A054A400B60CAC0016D484044183F8D7B034A40249C16BCE869484044183F8D7B034A40
647	Сызранский район	\N	72	47.926988999999999	49.220391999999997	53.493316	52.939784000000003	0103000020E6100000010000000500000039605793A7F64740ECA694D74A784A4039605793A7F64740F94B8BFA24BF4A40672618CE359C4840F94B8BFA24BF4A40672618CE359C4840ECA694D74A784A4039605793A7F64740ECA694D74A784A40
617	Сызрань городской округ	\N	72	48.348685000000003	48.587052999999997	53.213670999999998	53.055450999999998	0103000020E610000001000000050000008ACDC7B5A12C4840E7C3B30419874A408ACDC7B5A12C4840438D4292599B4A4064027E8D244B4840438D4292599B4A4064027E8D244B4840E7C3B30419874A408ACDC7B5A12C4840E7C3B30419874A40
671	Шигонский район	\N	72	48.37444	49.226007000000003	53.770299999999999	53.296838000000001	0103000020E61000000100000005000000392861A6ED2F4840E31A9FC9FEA54A40392861A6ED2F4840ED0DBE3099E24A4063D520CCED9C4840ED0DBE3099E24A4063D520CCED9C4840E31A9FC9FEA54A40392861A6ED2F4840E31A9FC9FEA54A40
1591	Шенталинский район	\N	72	51.219413000000003	51.951900000000002	54.649656	54.214297999999999	0103000020E610000001000000050000009CA8A5B9159C494092CCEA1D6E1B4B409CA8A5B9159C494039D384ED27534B40FD87F4DBD7F9494039D384ED27534B40FD87F4DBD7F9494092CCEA1D6E1B4B409CA8A5B9159C494092CCEA1D6E1B4B40
959	Челно-Вершинский район	\N	72	50.742883999999997	51.396839	54.675012000000002	54.165900000000001	0103000020E610000001000000050000005F5CAAD2165F4940053411363C154B405F5CAAD2165F49402B3410CB66564B408063CF9ECBB249402B3410CB66564B408063CF9ECBB24940053411363C154B405F5CAAD2165F4940053411363C154B40
1751	Хворостянский район	\N	72	48.501488000000002	49.475693	52.913297999999998	52.407462000000002	0103000020E6100000010000000500000011AB3FC2304048406F2EFEB627344A4011AB3FC23040484048C0E8F2E6744A40D3F71A82E3BC484048C0E8F2E6744A40D3F71A82E3BC48406F2EFEB627344A4011AB3FC2304048406F2EFEB627344A40
248	Ставропольский район	\N	72	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
7382	Ставропольский	\N	72	49.026769000000002	49.930897000000002	53.863025	53.155523000000002	0103000020E61000000100000005000000F8C5A52A6D8348404E637B2DE8934A40F8C5A52A6D834840B1506B9A77EE4A40E67805A227F74840B1506B9A77EE4A40E67805A227F748404E637B2DE8934A40F8C5A52A6D8348404E637B2DE8934A40
583	Сергиевский район	\N	72	50.543286999999999	51.523583000000002	54.311743999999997	53.615651999999997	0103000020E61000000100000005000000C5ABAC6D8A454940C6DB4AAFCDCE4A40C5ABAC6D8A454940B35C363AE7274B40ECDE8AC404C34940B35C363AE7274B40ECDE8AC404C34940C6DB4AAFCDCE4A40C5ABAC6D8A454940C6DB4AAFCDCE4A40
94	Приволжский район	\N	72	48.309320999999997	49.119394999999997	53.238399000000001	52.661664000000002	0103000020E61000000100000005000000A67B9DD4972748406478EC67B1544A40A67B9DD4972748401633C2DB839E4A402827DA55488F48401633C2DB839E4A402827DA55488F48406478EC67B1544A40A67B9DD4972748406478EC67B1544A40
393	Похвистневский район	\N	72	51.508876999999998	52.374979000000003	54.001601000000001	53.403776000000001	0103000020E61000000100000005000000E257ACE122C14940717495EEAEB34A40E257ACE122C149400952297634004B40E9D7D64FFF2F4A400952297634004B40E9D7D64FFF2F4A40717495EEAEB34A40E257ACE122C14940717495EEAEB34A40
194	Пестравский район	\N	72	49.260277000000002	50.318187000000002	52.717494000000002	52.129382999999997	0103000020E610000001000000050000005473B9C150A1484045D4449F8F104A405473B9C150A14840C289E8D7D65B4A409581035ABA284940C289E8D7D65B4A409581035ABA28494045D4449F8F104A405473B9C150A1484045D4449F8F104A40
648	Октябрьск городской округ	\N	72	48.575671	48.898291999999998	53.207555999999997	53.153162999999999	0103000020E61000000100000005000000B8205B96AF49484087FA5DD89A934A40B8205B96AF494840560BEC31919A4A401421753BFB724840560BEC31919A4A401421753BFB72484087FA5DD89A934A40B8205B96AF49484087FA5DD89A934A40
7381	Новокуйбышевский район	\N	72	47.926988999999999	52.567847	54.675012000000002	51.772261999999998	0103000020E6100000010000000500000039605793A7F64740C6F8307BD9E2494039605793A7F647402B3410CB66564B40DC10E335AF484A402B3410CB66564B40DC10E335AF484A40C6F8307BD9E2494039605793A7F64740C6F8307BD9E24940
68	Новокуйбышевск городской округ	\N	72	49.747847	49.985289999999999	53.115876	52.991498999999997	0103000020E61000000100000005000000B3B45373B9DF484023827170E97E4A40B3B45373B9DF484016325706D58E4A40B58993FB1DFE484016325706D58E4A40B58993FB1DFE484023827170E97E4A40B3B45373B9DF484023827170E97E4A40
1496	Нефтегорский район	\N	72	50.553789000000002	51.349085000000002	53.012433999999999	52.645854999999997	0103000020E6100000010000000500000039F1D58EE2464940A27A6B60AB524A4039F1D58EE2464940E2ADF36F97814A40184339D1AEAC4940E2ADF36F97814A40184339D1AEAC4940A27A6B60AB524A4039F1D58EE2464940A27A6B60AB524A40
460	Красноярский район	\N	72	49.826988999999998	51.024084000000002	53.841599000000002	53.318596999999997	0103000020E610000001000000050000006C938AC6DAE9484046CD57C9C7A84A406C938AC6DAE9484054AC1A84B9EB4A40AE2D3C2F1583494054AC1A84B9EB4A40AE2D3C2F1583494046CD57C9C7A84A406C938AC6DAE9484046CD57C9C7A84A40
7380	Красноглинский район	\N	72	50.132083000000002	50.328409999999998	53.396335000000001	53.264254000000001	0103000020E61000000100000005000000C5AD8218E810494029EB3713D3A14A40C5AD8218E81049404DA1F31ABBB24A40F5D6C056092A49404DA1F31ABBB24A40F5D6C056092A494029EB3713D3A14A40C5AD8218E810494029EB3713D3A14A40
455	Красноармейский район	\N	72	49.443992000000001	50.406393000000001	53.000095000000002	52.438898000000002	0103000020E61000000100000005000000C3D7D7BAD4B84840D12346CF2D384A40C3D7D7BAD4B8484052F2EA1C03804A40632992AF0434494052F2EA1C03804A40632992AF04344940D12346CF2D384A40C3D7D7BAD4B84840D12346CF2D384A40
392	Кошкинский район	\N	72	50.094067000000003	50.901184999999998	54.505079000000002	54.011066999999997	0103000020E61000000100000005000000015130630A0C49404C88B9A46A014B40015130630A0C4940BD72BD6DA6404B40A852B3075A734940BD72BD6DA6404B40A852B3075A7349404C88B9A46A014B40015130630A0C49404C88B9A46A014B40
542	Клявлинский район	\N	72	51.709983000000001	52.567847	54.474088000000002	54.096899999999998	0103000020E61000000100000005000000A5DB12B9E0DA4940BF7D1D38670C4B40A5DB12B9E0DA494089B663EAAE3C4B40DC10E335AF484A4089B663EAAE3C4B40DC10E335AF484A40BF7D1D38670C4B40A5DB12B9E0DA4940BF7D1D38670C4B40
364	Кинельский район	\N	72	50.418591999999997	51.256684	53.485301	52.918098000000001	0103000020E61000000100000005000000012F336C94354940F2423A3C84754A40012F336C94354940A9DBD9571EBE4A4007B47405DBA04940A9DBD9571EBE4A4007B47405DBA04940F2423A3C84754A40012F336C94354940F2423A3C84754A40
342	Кинель-Черкасский район	\N	72	50.812188999999996	52.210802999999999	53.724401999999998	53.185200999999999	0103000020E61000000100000005000000E19524CFF5674940DF1797AAB4974A40E19524CFF567494018946934B9DC4A400873BB97FB1A4A4018946934B9DC4A400873BB97FB1A4A40DF1797AAB4974A40E19524CFF5674940DF1797AAB4974A40
7379	Кинель городской округ	\N	72	50.475087000000002	50.675438	53.288457999999999	53.183900000000001	0103000020E610000001000000050000009CE09BA6CF3C494001DE02098A974A409CE09BA6CF3C494081221631ECA44A40E23C9CC07456494081221631ECA44A40E23C9CC07456494001DE02098A974A409CE09BA6CF3C494001DE02098A974A40
960	Камышлинский район	\N	72	51.875579000000002	52.489235999999998	54.21313	53.871552000000001	0103000020E610000001000000050000003E0801F912F04940B76114048FEF4A403E0801F912F04940F3E505D8471B4B404F0306499F3E4A40F3E505D8471B4B404F0306499F3E4A40B76114048FEF4A403E0801F912F04940B76114048FEF4A40
329	Исаклинский район	\N	72	51.212586000000002	51.946176999999999	54.250695	53.723697999999999	0103000020E6100000010000000500000032CB9E04369B49401E17D522A2DC4A4032CB9E04369B4940A72215C616204B401B9DF3531CF94940A72215C616204B401B9DF3531CF949401E17D522A2DC4A4032CB9E04369B49401E17D522A2DC4A40
1725	Елховский район	\N	72	49.926333	50.667884000000001	54.061228	53.760762999999997	0103000020E61000000100000005000000501A6A1492F64840E08096AE60E14A40501A6A1492F64840BCCCB051D6074B40C6C210397D554940BCCCB051D6074B40C6C210397D554940E08096AE60E14A40501A6A1492F64840E08096AE60E14A40
268	Волжский район	\N	72	49.574724000000003	50.663814000000002	53.516638999999998	52.719059000000001	0103000020E61000000100000005000000F81C588E90C948407E7214200A5C4A40F81C588E90C94840486B0C3A21C24A4040506EDBF7544940486B0C3A21C24A4040506EDBF75449407E7214200A5C4A40F81C588E90C948407E7214200A5C4A40
555	Борский район	\N	72	51.407485000000001	52.172283	53.343398000000001	52.646210000000004	0103000020E61000000100000005000000274EEE7728B44940912C6002B7524A40274EEE7728B4494083C13577F4AB4A4011548D5E0D164A4083C13577F4AB4A4011548D5E0D164A40912C6002B7524A40274EEE7728B44940912C6002B7524A40
123	Большечерниговский район	\N	72	50.156346999999997	51.464078000000001	52.364896999999999	51.772261999999998	0103000020E61000000100000005000000F2E9B12D03144940C6F8307BD9E24940F2E9B12D031449404AB4E4F1B42E4A4084656CE866BB49404AB4E4F1B42E4A4084656CE866BB4940C6F8307BD9E24940F2E9B12D03144940C6F8307BD9E24940
766	Большеглушицкий район	\N	72	50.059491000000001	51.409488000000003	52.751099000000004	52.218795	0103000020E6100000010000000500000003B4AD669D074940A0C37C79011C4A4003B4AD669D0749407787140324604A405F0D501A6AB449407787140324604A405F0D501A6AB44940A0C37C79011C4A4003B4AD669D074940A0C37C79011C4A40
726	Богатовский район	\N	72	51.053125999999999	51.523384999999998	53.265999000000001	52.889099000000002	0103000020E610000001000000050000009D4830D5CC86494002F4FBFECD714A409D4830D5CC86494065E256410CA24A40C51B9947FEC2494065E256410CA24A40C51B9947FEC2494002F4FBFECD714A409D4830D5CC86494002F4FBFECD714A40
705	Безенчукский район	\N	72	48.825195999999998	49.778793999999998	53.238399000000001	52.781466000000002	0103000020E610000001000000050000001F65C405A0694840CD77F01307644A401F65C405A06948401633C2DB839E4A4017299485AFE348401633C2DB839E4A4017299485AFE34840CD77F01307644A401F65C405A0694840CD77F01307644A40
664	Алексеевский район	\N	72	50.761892000000003	51.615085000000001	52.940001000000002	52.349497	0103000020E61000000100000005000000C28A53AD856149406A865451BC2C4A40C28A53AD85614940899AE8F351784A404DA1F31ABBCE4940899AE8F351784A404DA1F31ABBCE49406A865451BC2C4A40C28A53AD856149406A865451BC2C4A40
372	Юсьвинский район	\N	71	54.712090000000003	56.255161999999999	59.333602999999997	58.800204000000001	0103000020E6100000010000000500000082E7DEC3255B4B406F10AD156D664D4082E7DEC3255B4B407A6CCB80B3AA4D404A97FE25A9204C407A6CCB80B3AA4D404A97FE25A9204C406F10AD156D664D4082E7DEC3255B4B406F10AD156D664D40
562	Юрлинский район	\N	71	53.220869	55.242851000000002	59.746963000000001	59.119287	0103000020E61000000100000005000000A1D9756F459C4A4042EBE1CB448F4D40A1D9756F459C4A403929CC7B9CDF4D408466D7BD159F4B403929CC7B9CDF4D408466D7BD159F4B4042EBE1CB448F4D40A1D9756F459C4A4042EBE1CB448F4D40
1738	Чусовой городской округ	\N	71	56.649208000000002	58.216794999999998	58.704914000000002	57.972816000000002	0103000020E610000001000000050000009A266C3F19534C404583143C85FC4C409A266C3F19534C400C3F389F3A5A4D40D97745F0BF1B4D400C3F389F3A5A4D40D97745F0BF1B4D404583143C85FC4C409A266C3F19534C404583143C85FC4C40
1652	Чернушинский район	\N	71	55.748629000000001	56.631529	56.771906000000001	56.289935	0103000020E6100000010000000500000029EB3713D3DF4B409E7B0F971C254C4029EB3713D3DF4B4008CBD8D0CD624C40E0BC38F1D5504C4008CBD8D0CD624C40E0BC38F1D5504C409E7B0F971C254C4029EB3713D3DF4B409E7B0F971C254C40
456	Чердынский район	\N	71	54.990586	58.711084	61.525385999999997	59.840206999999999	0103000020E610000001000000050000000FF0A485CB7E4B40656F29E78BEB4D400FF0A485CB7E4B405CE333D93FC34E40BC5AEECC045B4D405CE333D93FC34E40BC5AEECC045B4D40656F29E78BEB4D400FF0A485CB7E4B40656F29E78BEB4D40
1553	Частинский район	\N	71	54.289028000000002	55.185763000000001	57.596001999999999	57.018301000000001	0103000020E610000001000000050000006CD097DEFE244B40F73DEAAF57824C406CD097DEFE244B40E02C25CB49CC4C4047E7FC14C7974B40E02C25CB49CC4C4047E7FC14C7974B40F73DEAAF57824C406CD097DEFE244B40F73DEAAF57824C40
7405	Чайковский район	\N	71	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
716	Чайковский городской округ	\N	71	53.798071999999998	54.942777	56.992213999999997	56.346541000000002	0103000020E6100000010000000500000039ED293927E64A4090DC9A745B2C4C4039ED293927E64A4011514CDE007F4C40E335AFEAAC784B4011514CDE007F4C40E335AFEAAC784B4090DC9A745B2C4C4039ED293927E64A4090DC9A745B2C4C40
572	Усольский район	\N	71	55.380940000000002	57.236103999999997	59.747407000000003	58.991610999999999	0103000020E610000001000000050000007FDE54A4C2B04B404BADF71BED7E4D407FDE54A4C2B04B4097E65608ABDF4D40363AE7A7389E4C4097E65608ABDF4D40363AE7A7389E4C404BADF71BED7E4D407FDE54A4C2B04B404BADF71BED7E4D40
1329	Уинский район	\N	71	56.011493999999999	57.044260000000001	57.068407999999998	56.661512000000002	0103000020E61000000100000005000000D40CA9A278014C40AEF4DA6CAC544C40D40CA9A278014C407364E597C1884C40AF42CA4FAA854C407364E597C1884C40AF42CA4FAA854C40AEF4DA6CAC544C40D40CA9A278014C40AEF4DA6CAC544C40
1264	Суксунский район	\N	71	57.003467999999998	58.125041000000003	57.260613999999997	56.853518000000001	0103000020E61000000100000005000000904AB1A371804C400F46EC13406D4C40904AB1A371804C409B70AFCC5BA14C405FD4EE5701104D409B70AFCC5BA14C405FD4EE5701104D400F46EC13406D4C40904AB1A371804C400F46EC13406D4C40
1832	Соликамский район	\N	71	55.354844	57.919147000000002	60.186706999999998	59.479115999999998	0103000020E61000000100000005000000469737876BAD4B40C37E4FAC53BD4D40469737876BAD4B409677D503E6174E40B79BE09BA6F54C409677D503E6174E40B79BE09BA6F54C40C37E4FAC53BD4D40469737876BAD4B40C37E4FAC53BD4D40
927	Сивинский район	\N	71	53.704071999999996	54.727190999999998	58.765799999999999	58.171205	0103000020E61000000100000005000000C00303081FDA4A40B2F4A10BEA154D40C00303081FDA4A406EA301BC05624D4007793D98145D4B406EA301BC05624D4007793D98145D4B40B2F4A10BEA154D40C00303081FDA4A40B2F4A10BEA154D40
849	Пермский район	\N	71	55.425863999999997	56.831521000000002	58.166168999999996	57.392600999999999	0103000020E61000000100000005000000994528B682B64B403EB0E3BF40B24C40994528B682B64B40F44D9A0645154D40F777B6476F6A4C40F44D9A0645154D40F777B6476F6A4C403EB0E3BF40B24C40994528B682B64B403EB0E3BF40B24C40
1781	Очерский район	\N	71	54.090724999999999	55.106262000000001	58.072502999999998	57.715502999999998	0103000020E61000000100000005000000FDF675E09C0B4B404E98309A95DB4C40FDF675E09C0B4B4052EE3EC747094D405E6743FE998D4B4052EE3EC747094D405E6743FE998D4B404E98309A95DB4C40FDF675E09C0B4B404E98309A95DB4C40
1092	Оханский район	\N	71	54.841186999999998	55.554538999999998	57.928303999999997	57.378104999999998	0103000020E610000001000000050000000169FF03AC6B4B401FBAA0BE65B04C400169FF03AC6B4B407C5F5CAAD2F64C40A3AD4A22FBC64B407C5F5CAAD2F64C40A3AD4A22FBC64B401FBAA0BE65B04C400169FF03AC6B4B401FBAA0BE65B04C40
1406	Осинский район	\N	71	54.977379999999997	55.926099999999998	57.515706999999999	57.053705000000001	0103000020E61000000100000005000000DAE1AFC91A7D4B40DB5031CEDF864C40DAE1AFC91A7D4B40BDA8DDAF02C24C40AD69DE718AF64B40BDA8DDAF02C24C40AD69DE718AF64B40DB5031CEDF864C40DAE1AFC91A7D4B40DB5031CEDF864C40
1057	Ординский район	\N	71	56.256670999999997	57.223438000000002	57.287211999999997	56.843313999999999	0103000020E61000000100000005000000726A6798DA204C40252191B6F16B4C40726A6798DA204C406682E15CC3A44C408257CB9D999C4C406682E15CC3A44C408257CB9D999C4C40252191B6F16B4C40726A6798DA204C40252191B6F16B4C40
1510	Октябрьский район	\N	71	56.370559999999998	57.440238000000001	56.891514000000001	56.105469999999997	0103000020E61000000100000005000000569A94826E2F4C40C45A7C0A800D4C40569A94826E2F4C408CF678211D724C406D3A02B859B84C408CF678211D724C406D3A02B859B84C40C45A7C0A800D4C40569A94826E2F4C40C45A7C0A800D4C40
1009	Нытвенский район	\N	71	54.981279000000001	55.781013000000002	58.417203999999998	57.816401999999997	0103000020E6100000010000000500000034A0DE8C9A7D4B40CA3159DC7FE84C4034A0DE8C9A7D4B4054E1CFF066354D401C60E63BF8E34B4054E1CFF066354D401C60E63BF8E34B40CA3159DC7FE84C4034A0DE8C9A7D4B40CA3159DC7FE84C40
1530	Лысьва городской округ	\N	71	57.192033000000002	58.873553999999999	58.258626	57.561784000000003	0103000020E610000001000000050000005B608F8994984C4042B5C189E8C74C405B608F8994984C4099F221A81A214D401EA5129ED06F4D4099F221A81A214D401EA5129ED06F4D4042B5C189E8C74C405B608F8994984C4042B5C189E8C74C40
2763	Лужский район	\N	71	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
1372	Кунгурский район	\N	71	55.847614	57.273214000000003	58.028315999999997	57.044407999999997	0103000020E61000000100000005000000DDD0949D7EEC4B4023D74D29AF854C40DDD0949D7EEC4B400DFAD2DB9F034D40996725ADF8A24C400DFAD2DB9F034D40996725ADF8A24C4023D74D29AF854C40DDD0949D7EEC4B4023D74D29AF854C40
7404	Кунгур городской округ	\N	71	56.892983999999998	57.020617000000001	57.460403999999997	57.375382999999999	0103000020E61000000100000005000000F6ECB94C4D724C40B83CD68C0CB04C40F6ECB94C4D724C404A79AD84EEBA4C40EE5EEE93A3824C404A79AD84EEBA4C40EE5EEE93A3824C40B83CD68C0CB04C40F6ECB94C4D724C40B83CD68C0CB04C40
1074	Куединский район	\N	71	54.555909	55.895710000000001	56.797201000000001	56.304385000000003	0103000020E61000000100000005000000AA46AF0628474B404D327216F6264C40AA46AF0628474B4054ABAFAE0A664C409F5912A0A6F24B4054ABAFAE0A664C409F5912A0A6F24B404D327216F6264C40AA46AF0628474B404D327216F6264C40
96	Кудымкарский район	\N	71	53.690131000000001	55.585926000000001	59.523808000000002	58.597903000000002	0103000020E61000000100000005000000577A6D3656D84A401497E315884C4D40577A6D3656D84A400CB1FA230CC34D4024F0879FFFCA4B400CB1FA230CC34D4024F0879FFFCA4B401497E315884C4D40577A6D3656D84A401497E315884C4D40
4039	Краснокамский район	\N	71	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
1228	Краснокамск городской округ	\N	71	55.438701000000002	56.208044999999998	58.351872	58.003321	0103000020E610000001000000050000007BDCB75A27B84B40EC3191D26C004D407BDCB75A27B84B40663046240A2D4D40548CF337A11A4C40663046240A2D4D40548CF337A11A4C40EC3191D26C004D407BDCB75A27B84B40EC3191D26C004D40
1028	Красновишерский район	\N	71	56.505118000000003	59.483105000000002	61.661814999999997	59.807726000000002	0103000020E610000001000000050000007B4FE5B4A7404C408010C99063E74D407B4FE5B4A7404C4049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D408010C99063E74D407B4FE5B4A7404C408010C99063E74D40
934	Кочевский район	\N	71	53.631740000000001	55.187955000000002	60.010703999999997	59.465800999999999	0103000020E610000001000000050000009BC937DBDCD04A40D8B8FE5D9FBB4D409BC937DBDCD04A40DBF7A8BF5E014E40520FD1E80E984B40DBF7A8BF5E014E40520FD1E80E984B40D8B8FE5D9FBB4D409BC937DBDCD04A40D8B8FE5D9FBB4D40
913	Косинский район	\N	71	54.416508	55.635316000000003	60.250104999999998	59.444401999999997	0103000020E61000000100000005000000DD42572250354B4074232C2AE2B84D40DD42572250354B4075C8CD7003204E401250E10852D14B4075C8CD7003204E401250E10852D14B4074232C2AE2B84D40DD42572250354B4074232C2AE2B84D40
984	Кишертский район	\N	71	57.117150000000002	58.047255999999997	57.525784999999999	57.147725999999999	0103000020E61000000100000005000000FB5C6DC5FE8E4C406B6281AFE8924C40FB5C6DC5FE8E4C401ADD41EC4CC34C4017450F7C0C064D401ADD41EC4CC34C4017450F7C0C064D406B6281AFE8924C40FB5C6DC5FE8E4C406B6281AFE8924C40
958	Кизел городской округ	\N	71	57.450271999999998	58.753214999999997	59.271929	58.928024000000001	0103000020E61000000100000005000000FA264D83A2B94C4099F38C7DC9764D40FA264D83A2B94C40C0EAC891CEA24D40A6ED5F5969604D40C0EAC891CEA24D40A6ED5F5969604D4099F38C7DC9764D40FA264D83A2B94C4099F38C7DC9764D40
523	Карагайский район	\N	71	54.580002	55.435943000000002	58.824302000000003	58.078904999999999	0103000020E61000000100000005000000ABCE6A813D4A4B40D53E1D8F190A4D40ABCE6A813D4A4B4082035ABA82694D40C7F5EFFACCB74B4082035ABA82694D40C7F5EFFACCB74B40D53E1D8F190A4D40ABCE6A813D4A4B40D53E1D8F190A4D40
717	Ильинский район	\N	71	55.259649000000003	56.275849999999998	58.984003000000001	58.272705000000002	0103000020E6100000010000000500000035B8AD2D3CA14B40543A58FFE7224D4035B8AD2D3CA14B403C1570CFF37D4D40014D840D4F234C403C1570CFF37D4D40014D840D4F234C40543A58FFE7224D4035B8AD2D3CA14B40543A58FFE7224D40
582	Еловский район	\N	71	54.331913999999998	55.309055999999998	57.164202000000003	56.733401999999998	0103000020E61000000100000005000000D28A6F287C2A4B401669E21DE05D4C40D28A6F287C2A4B400AF8359204954C40F850A2258FA74B400AF8359204954C40F850A2258FA74B401669E21DE05D4C40D28A6F287C2A4B401669E21DE05D4C40
404	Добрянка городской округ	\N	71	56.090752000000002	58.457292000000002	59.449516000000003	58.153112	0103000020E61000000100000005000000F705F4C29D0B4C4005508C2C99134D40F705F4C29D0B4C40AE8383BD89B94D40795C548B883A4D40AE8383BD89B94D40795C548B883A4D4005508C2C99134D40F705F4C29D0B4C4005508C2C99134D40
222	Губаха городской округ	\N	71	57.174525000000003	58.246476000000001	59.027517000000003	58.704914000000002	0103000020E61000000100000005000000CEAACFD556964C400C3F389F3A5A4D40CEAACFD556964C40C28A53AD85834D40DC9F8B868C1F4D40C28A53AD85834D40DC9F8B868C1F4D400C3F389F3A5A4D40CEAACFD556964C400C3F389F3A5A4D40
7406	Гремячинск городской округ	\N	71	57.352688000000001	58.542577999999999	59.053632	58.458525999999999	0103000020E6100000010000000500000088D860E124AD4C40CF2EDFFAB03A4D4088D860E124AD4C407102D369DD864D40B9C3263273454D407102D369DD864D40B9C3263273454D40CF2EDFFAB03A4D4088D860E124AD4C40CF2EDFFAB03A4D40
1842	Горнозаводский район	\N	71	57.878076	59.452536000000002	59.247683000000002	57.929537000000003	0103000020E6100000010000000500000085B35BCB64F04C4003B68311FBF64C4085B35BCB64F04C4039639813B49F4D409F211CB3ECB94D4039639813B49F4D409F211CB3ECB94D4003B68311FBF64C4085B35BCB64F04C4003B68311FBF64C40
951	Гайнский район	\N	71	51.771723999999999	55.242545	61.090304000000003	59.970298999999997	0103000020E61000000100000005000000E7C41EDAC7E24940B62BF4C132FC4D40E7C41EDAC7E249405859DB148F8B4E407767EDB60B9F4B405859DB148F8B4E407767EDB60B9F4B40B62BF4C132FC4D40E7C41EDAC7E24940B62BF4C132FC4D40
1129	Верещагинский район	\N	71	53.785235	55.100062999999999	58.310599000000003	57.941200000000002	0103000020E6100000010000000500000058569A9482E44A40637FD93D79F84C4058569A9482E44A40CD9541B5C1274D40134548DDCE8C4B40CD9541B5C1274D40134548DDCE8C4B40637FD93D79F84C4058569A9482E44A40637FD93D79F84C40
1599	Большесосновский район	\N	71	53.985595000000004	54.932276000000002	57.876601000000001	57.209403000000002	0103000020E61000000100000005000000F20C1AFA27FE4A409757AEB7CD9A4C40F20C1AFA27FE4A400952297634F04C40406CE9D154774B400952297634F04C40406CE9D154774B409757AEB7CD9A4C40F20C1AFA27FE4A409757AEB7CD9A4C40
997	Березовский район	\N	71	56.956170999999998	58.132362999999998	57.876817000000003	57.415520999999998	0103000020E610000001000000050000001A31B3CF637A4C408EE6C8CA2FB54C401A31B3CF637A4C40D6C9198A3BF04C40A8195245F1104D40D6C9198A3BF04C40A8195245F1104D408EE6C8CA2FB54C401A31B3CF637A4C408EE6C8CA2FB54C40
982	Березники городской округ	\N	71	56.577306999999998	57.081837	59.548614000000001	59.257652999999998	0103000020E610000001000000050000003D601E32E5494C40AF5B04C6FAA04D403D601E32E5494C405A10CAFB38C64D40274D83A2798A4C405A10CAFB38C64D40274D83A2798A4C40AF5B04C6FAA04D403D601E32E5494C40AF5B04C6FAA04D40
391	Бардымский район	\N	71	55.155768000000002	56.153581000000003	57.207107000000001	56.577902999999999	0103000020E61000000100000005000000B5E1B034F0934B4051A1BAB9F8494C40B5E1B034F0934B40E7E26F7B829A4C40BC24CE8AA8134C40E7E26F7B829A4C40BC24CE8AA8134C4051A1BAB9F8494C40B5E1B034F0934B4051A1BAB9F8494C40
7456	Александровский район	\N	71	51.771723999999999	59.483105000000002	61.661814999999997	56.105469999999997	0103000020E61000000100000005000000E7C41EDAC7E24940C45A7C0A800D4C40E7C41EDAC7E2494049809A5AB6D44E405DC47762D6BD4D4049809A5AB6D44E405DC47762D6BD4D40C45A7C0A800D4C40E7C41EDAC7E24940C45A7C0A800D4C40
1088	Александровск городской округ	\N	71	56.924658999999998	58.690666	59.883029000000001	58.894013000000001	0103000020E61000000100000005000000DD79E2395B764C4074999A046F724D40DD79E2395B764C40B535221807F14D40C53A55BE67584D40B535221807F14D40C53A55BE67584D4074999A046F724D40DD79E2395B764C4074999A046F724D40
1007	Сердобский район	\N	70	43.781812000000002	44.535525	52.840496999999999	52.291775000000001	0103000020E6100000010000000500000068CF656A12E445402C6519E258254A4068CF656A12E445406CB1DB67956B4A405F984C158C4446406CB1DB67956B4A405F984C158C4446402C6519E258254A4068CF656A12E445402C6519E258254A40
7508	Заречный городской округ	\N	70	45.170158000000001	45.213177999999999	53.208385999999997	53.189976000000001	0103000020E610000001000000050000008E93C2BCC79546403083312251984A408E93C2BCC7954640DD787764AC9A4A40041DAD6A499B4640DD787764AC9A4A40041DAD6A499B46403083312251984A408E93C2BCC79546403083312251984A40
1077	Шемышейский район	\N	70	45.070597999999997	45.829296999999997	53.093597000000003	52.598396000000001	0103000020E61000000100000005000000DD94F25A098946405307793D984C4A40DD94F25A098946407A008BFCFA8B4A40E0D5726726EA46407A008BFCFA8B4A40E0D5726726EA46405307793D984C4A40DD94F25A098946405307793D984C4A40
244	Тамалинский район	\N	70	43.025627999999998	43.755797000000001	52.835999000000001	52.352697999999997	0103000020E6100000010000000500000052EE3EC747834540ABAE4335252D4A4052EE3EC7478345408E3EE603026B4A401CB5C2F4BDE045408E3EE603026B4A401CB5C2F4BDE04540ABAE4335252D4A4052EE3EC747834540ABAE4335252D4A40
1096	Сосновоборский район	\N	70	45.834498000000004	46.746063999999997	53.549382000000001	53.106617	0103000020E61000000100000005000000E94999D4D0EA46404C1938A0A58D4A40E94999D4D0EA46406B813D2652C64A40895C70067F5F47406B813D2652C64A40895C70067F5F47404C1938A0A58D4A40E94999D4D0EA46404C1938A0A58D4A40
976	Пензенский район	\N	70	44.341543000000001	45.267750999999997	53.272267999999997	52.909365999999999	0103000020E61000000100000005000000C09657AEB72B4640130CE71A66744A40C09657AEB72B4640A8DF85ADD9A24A40533C2EAA45A24640A8DF85ADD9A24A40533C2EAA45A24640130CE71A66744A40C09657AEB72B4640130CE71A66744A40
1831	Пенза городской округ	\N	70	44.870938000000002	45.213752999999997	53.251567999999999	53.155723000000002	0103000020E61000000100000005000000FD6B79E57A6F4640151E34BBEE934A40FD6B79E57A6F46402D5C566133A04A40003620425C9B46402D5C566133A04A40003620425C9B4640151E34BBEE934A40FD6B79E57A6F4640151E34BBEE934A40
899	Пачелмский район	\N	70	42.955694000000001	43.829396000000003	53.530000999999999	53.119194	0103000020E61000000100000005000000E17D552E547A454091F0BDBF418F4A40E17D552E547A454074ECA012D7C34A4074B7EBA529EA454074ECA012D7C34A4074B7EBA529EA454091F0BDBF418F4A40E17D552E547A454091F0BDBF418F4A40
739	Никольский район	\N	70	45.392895000000003	46.478321000000001	54.029561000000001	53.478597999999998	0103000020E6100000010000000500000087E123624AB246402BF702B342BD4A4087E123624AB24640581EA4A7C8034B40B9FE5D9F393D4740581EA4A7C8034B40B9FE5D9F393D47402BF702B342BD4A4087E123624AB246402BF702B342BD4A40
463	Нижнеломовский район	\N	70	43.282097	44.199294999999999	53.750599999999999	53.319693999999998	0103000020E610000001000000050000005DA626C11BA445401C5DA5BBEBA84A405DA626C11BA4454055302AA913E04A40CFA0A17F8219464055302AA913E04A40CFA0A17F821946401C5DA5BBEBA84A405DA626C11BA445401C5DA5BBEBA84A40
262	Неверкинский район	\N	70	46.290698999999996	46.981171000000003	52.942594999999997	52.612817999999997	0103000020E610000001000000050000006DFDF49F352547403733FAD1704E4A406DFDF49F35254740C22FF5F3A6784A404E64E602977D4740C22FF5F3A6784A404E64E602977D47403733FAD1704E4A406DFDF49F352547403733FAD1704E4A40
74	Наровчатский район	\N	70	43.408318999999999	43.973844999999997	54.014549000000002	53.664396000000004	0103000020E61000000100000005000000EFAA07CC43B44540EFCB99ED0AD54A40EFAA07CC43B445404298DBBDDC014B40C22FF5F3A6FC45404298DBBDDC014B40C22FF5F3A6FC4540EFCB99ED0AD54A40EFAA07CC43B44540EFCB99ED0AD54A40
635	Мокшанский район	\N	70	43.989592000000002	44.940890000000003	53.722712999999999	53.172097000000001	0103000020E610000001000000050000000E315EF3AAFE4540AF5E454607964A400E315EF3AAFE454070B20DDC81DC4A40159161156F78464070B20DDC81DC4A40159161156F784640AF5E454607964A400E315EF3AAFE4540AF5E454607964A40
1603	Малосердобинский район	\N	70	44.718521000000003	45.403801000000001	52.666755000000002	52.307713	0103000020E610000001000000050000009F3E027FF85B4640EBC6BB2363274A409F3E027FF85B4640E5B8533A58554A40CA8B4CC0AFB34640E5B8533A58554A40CA8B4CC0AFB34640EBC6BB2363274A409F3E027FF85B4640EBC6BB2363274A40
1582	Лунинский район	\N	70	44.879095	45.677697000000002	53.926175999999998	53.384799999999998	0103000020E61000000100000005000000DF89592F867046401AC05B2041B14A40DF89592F86704640882B67EF8CF64A4075CC79C6BED64640882B67EF8CF64A4075CC79C6BED646401AC05B2041B14A40DF89592F867046401AC05B2041B14A40
1798	Лопатинский район	\N	70	45.273761	46.182496999999998	52.770297999999997	52.385739999999998	0103000020E61000000100000005000000CBF5B6990AA346402861A6ED5F314A40CBF5B6990AA346404C16F71F99624A401E4FCB0F5C1747404C16F71F99624A401E4FCB0F5C1747402861A6ED5F314A40CBF5B6990AA346402861A6ED5F314A40
1367	Кузнецкий район	\N	70	46.124294999999996	46.973579999999998	53.408644000000002	52.848199000000001	0103000020E61000000100000005000000350708E6E80F4740FDBFEAC8916C4A40350708E6E80F474073DA53724EB44A401405FA449E7C474073DA53724EB44A401405FA449E7C4740FDBFEAC8916C4A40350708E6E80F4740FDBFEAC8916C4A40
1003	Кондольский район	\N	70	44.674593999999999	45.353298000000002	52.962398	52.622599000000001	0103000020E61000000100000005000000F609A01859564640DBC2F352B14F4A40F609A018595646402FDE8FDB2F7B4A4001DF6DDE38AD46402FDE8FDB2F7B4A4001DF6DDE38AD4640DBC2F352B14F4A40F609A01859564640DBC2F352B14F4A40
1379	Колышлейский район	\N	70	44.119892999999998	44.888294000000002	52.977896999999999	52.459677999999997	0103000020E61000000100000005000000790261A7580F464068588CBAD63A4A40790261A7580F4640A2ED98BA2B7D4A40D49D279EB3714640A2ED98BA2B7D4A40D49D279EB371464068588CBAD63A4A40790261A7580F464068588CBAD63A4A40
1369	Камешкирский район	\N	70	45.691594000000002	46.515276999999998	53.013598000000002	52.593358000000002	0103000020E610000001000000050000000F0EF62686D84640F568AA27F34B4A400F0EF62686D8464040A54A94BD814A40C4B0C398F441474040A54A94BD814A40C4B0C398F4414740F568AA27F34B4A400F0EF62686D84640F568AA27F34B4A40
1202	Каменский район	\N	70	43.488897999999999	44.362895999999999	53.404597000000003	52.783797	0103000020E61000000100000005000000378AAC3594BE4540F9D9C87553644A40378AAC3594BE4540A587A1D5C9B34A40B3EC4960732E4640A587A1D5C9B34A40B3EC4960732E4640F9D9C87553644A40378AAC3594BE4540F9D9C87553644A40
1451	Иссинский район	\N	70	44.590646	45.258732000000002	53.972074999999997	53.643301000000001	0103000020E61000000100000005000000B1C1C2499A4B4640F73DEAAF57D24A40B1C1C2499A4B46402D211FF46CFC4A40DF3653211EA146402D211FF46CFC4A40DF3653211EA14640F73DEAAF57D24A40B1C1C2499A4B4640F73DEAAF57D24A40
1468	Земетчинский район	\N	70	42.082307	42.906098	53.853619999999999	53.325498000000003	0103000020E61000000100000005000000AE9D2809890A4540EB7420EBA9A94A40AE9D2809890A4540139B8F6B43ED4A404A7CEE04FB734540139B8F6B43ED4A404A7CEE04FB734540EB7420EBA9A94A40AE9D2809890A4540EB7420EBA9A94A40
1375	Городищенский район	\N	70	45.402695999999999	46.178400000000003	53.560797000000001	52.909399000000001	0103000020E61000000100000005000000711DE38A8BB34640EF01BA2F67744A40711DE38A8BB34640F3583332C8C74A409FCDAACFD5164740F3583332C8C74A409FCDAACFD5164740EF01BA2F67744A40711DE38A8BB34640EF01BA2F67744A40
553	Вадинский район	\N	70	42.734842999999998	43.372593000000002	53.829006	53.480697999999997	0103000020E61000000100000005000000E658DE550F5E454055A0168387BD4A40E658DE550F5E454009185DDE1CEA4A40F9DB9E20B1AF454009185DDE1CEA4A40F9DB9E20B1AF454055A0168387BD4A40E658DE550F5E454055A0168387BD4A40
1055	Бессоновский район	\N	70	44.724333000000001	45.472306000000003	53.606757999999999	53.035533999999998	0103000020E61000000100000005000000F03499F1B65C4640B2F2CB608C844A40F03499F1B65C46400E4B033FAACD4A4030DAE38574BC46400E4B033FAACD4A4030DAE38574BC4640B2F2CB608C844A40F03499F1B65C4640B2F2CB608C844A40
925	Белинский район	\N	70	42.827046000000003	43.875200999999997	53.188195	52.723095000000001	0103000020E61000000100000005000000D124B1A4DC694540587380608E5C4A40D124B1A4DC694540A72215C616984A4097361C9606F04540A72215C616984A4097361C9606F04540587380608E5C4A40D124B1A4DC694540587380608E5C4A40
1086	Бековский район	\N	70	43.341799000000002	43.947093000000002	52.767901000000002	52.377026999999998	0103000020E610000001000000050000001B67D311C0AB4540C05AB56B42304A401B67D311C0AB454069C878944A624A40A1A2EA573AF9454069C878944A624A40A1A2EA573AF94540C05AB56B42304A401B67D311C0AB4540C05AB56B42304A40
945	Беднодемьяновский район	\N	70	43.045571000000002	43.604394999999997	54.025922000000001	53.677599000000001	0103000020E61000000100000005000000B1524145D5854540B2666490BBD64A40B1524145D58545409B1F7F6951034B40D66EBBD05CCD45409B1F7F6951034B40D66EBBD05CCD4540B2666490BBD64A40B1524145D5854540B2666490BBD64A40
999	Башмаковский район	\N	70	42.410119999999999	43.194996000000003	53.523797000000002	52.982830999999997	0103000020E61000000100000005000000BFB7E9CF7E3445405B3FFD67CD7D4A40BFB7E9CF7E344540185FB4C70BC34A40E86C01A1F5984540185FB4C70BC34A40E86C01A1F59845405B3FFD67CD7D4A40BFB7E9CF7E3445405B3FFD67CD7D4A40
7415	 Белинский район	\N	70	42.827046000000003	43.875200999999997	53.188195	52.723095000000001	0103000020E61000000100000005000000D124B1A4DC694540587380608E5C4A40D124B1A4DC694540A72215C616984A4097361C9606F04540A72215C616984A4097361C9606F04540587380608E5C4A40D124B1A4DC694540587380608E5C4A40
7397	Сорочинск городской округ	\N	69	53.123050999999997	53.187631000000003	52.452955000000003	52.400210000000001	0103000020E61000000100000005000000BB5E9A22C08F4A401EC4CE143A334A40BB5E9A22C08F4A40A4C7EF6DFA394A409F5BE84A04984A40A4C7EF6DFA394A409F5BE84A04984A401EC4CE143A334A40BB5E9A22C08F4A401EC4CE143A334A40
7393	Ясный городской округ	\N	69	59.792476000000001	59.927376000000002	51.046041000000002	51.007120999999998	0103000020E61000000100000005000000B56E83DA6FE54D40B20E4757E9804940B56E83DA6FE54D4038A3E6ABE4854940338CBB41B4F64D4038A3E6ABE4854940338CBB41B4F64D40B20E4757E9804940B56E83DA6FE54D40B20E4757E9804940
666	Адамовский район	\N	69	59.126761999999999	61.008606	52.056756	51.177289999999999	0103000020E610000001000000050000001230BABC39904D4034F44F70B19649401230BABC39904D4007EDD5C743074A4052465C001A814E4007EDD5C743074A4052465C001A814E4034F44F70B19649401230BABC39904D4034F44F70B1964940
325	Курманаевский район	\N	69	51.373249999999999	52.328276000000002	52.684697	52.056395999999999	0103000020E61000000100000005000000B29DEFA7C6AF494007D0EFFB37074A40B29DEFA7C6AF4940AC55BB26A4574A40E607AEF2042A4A40AC55BB26A4574A40E607AEF2042A4A4007D0EFFB37074A40B29DEFA7C6AF494007D0EFFB37074A40
7396	Бузулук	\N	69	52.202942999999998	52.292352000000001	52.817689000000001	52.736477999999998	0103000020E61000000100000005000000DFF94509FA194A409B1C3EE9445E4A40DFF94509FA194A4044A67C08AA684A40C97553CA6B254A4044A67C08AA684A40C97553CA6B254A409B1C3EE9445E4A40DFF94509FA194A409B1C3EE9445E4A40
7394	Бузулук городской округ	\N	69	52.203499999999998	52.294319000000002	52.817318999999998	52.735588999999997	0103000020E61000000100000005000000355EBA490C1A4A400F26C5C7275E4A40355EBA490C1A4A4020B3B3E89D684A40B4CBB73EAC254A4020B3B3E89D684A40B4CBB73EAC254A400F26C5C7275E4A40355EBA490C1A4A400F26C5C7275E4A40
1545	Ясненский район	\N	69	59.256343999999999	60.535876999999999	51.351573000000002	50.812868999999999	0103000020E610000001000000050000004E4354E1CFA04D40537765170C6849404E4354E1CFA04D400C94145800AD4940DCD6169E97444E400C94145800AD4940DCD6169E97444E40537765170C6849404E4354E1CFA04D40537765170C684940
1324	Шарлыкский район	\N	69	54.25253	55.426465999999998	53.275740999999996	52.549599000000001	0103000020E6100000010000000500000023A12DE752204B400875914259464A4023A12DE752204B404A95287B4BA34A408F6D197096B64B404A95287B4BA34A408F6D197096B64B400875914259464A4023A12DE752204B400875914259464A40
748	Тюльганский район	\N	69	55.613360999999998	56.492047999999997	52.650165000000001	52.123604999999998	0103000020E6100000010000000500000028D2FD9C82CE4B40A04FE449D20F4A4028D2FD9C82CE4B407E00529B38534A40F607CA6DFB3E4C407E00529B38534A40F607CA6DFB3E4C40A04FE449D20F4A4028D2FD9C82CE4B40A04FE449D20F4A40
1258	Тоцкий район	\N	69	52.037374	52.977964	52.679996000000003	51.944499	0103000020E6100000010000000500000040DCD5ABC8044A40670DDE57E5F8494040DCD5ABC8044A4096B4E21B0A574A402A55A2EC2D7D4A4096B4E21B0A574A402A55A2EC2D7D4A40670DDE57E5F8494040DCD5ABC8044A40670DDE57E5F84940
1156	Ташлинский район	\N	69	52.300176	53.357754	52.162796	51.453328999999997	0103000020E61000000100000005000000A585CB2A6C264A4008AA46AF06BA4940A585CB2A6C264A40B6F5D37FD6144A40B00111E2CAAD4A40B6F5D37FD6144A40B00111E2CAAD4A4008AA46AF06BA4940A585CB2A6C264A4008AA46AF06BA4940
520	Сорочинский район	\N	69	52.782769000000002	53.819344000000001	52.786596000000003	52.087302000000001	0103000020E610000001000000050000004CA94BC631644A400D7041B62C0B4A404CA94BC631644A400C957F2DAF644A404016A243E0E84A400C957F2DAF644A404016A243E0E84A400D7041B62C0B4A404CA94BC631644A400D7041B62C0B4A40
884	Соль-Илецкий район	\N	69	54.003804000000002	55.629665000000003	51.500000999999997	50.527413000000003	0103000020E6100000010000000500000008CC43A67C004B401D3EE9448243494008CC43A67C004B40D07B630800C04940CA37DBDC98D04B40D07B630800C04940CA37DBDC98D04B401D3EE9448243494008CC43A67C004B401D3EE94482434940
473	Северный район	\N	69	52.294535000000003	53.310197000000002	54.364834000000002	53.870798000000001	0103000020E610000001000000050000008143A852B3254A400BB6114F76EF4A408143A852B3254A40043C69E1B22E4B409E280989B4A74A40043C69E1B22E4B409E280989B4A74A400BB6114F76EF4A408143A852B3254A400BB6114F76EF4A40
662	Светлинский район	\N	69	60.161135999999999	61.691226999999998	51.468217000000003	50.597186999999998	0103000020E61000000100000005000000A81ABD1AA0144E40554CA59F704C4940A81ABD1AA0144E403337DF88EEBB49405C8E57207AD84E403337DF88EEBB49405C8E57207AD84E40554CA59F704C4940A81ABD1AA0144E40554CA59F704C4940
337	Саракташский район	\N	69	55.707656999999998	56.780676999999997	52.212074000000001	51.477910999999999	0103000020E610000001000000050000008AE42B8194DA4B4007B309302CBD49408AE42B8194DA4B407C2AA73D251B4A40A4DE5339ED634C407C2AA73D251B4A40A4DE5339ED634C4007B309302CBD49408AE42B8194DA4B4007B309302CBD4940
121	Сакмарский район	\N	69	54.641706999999997	55.935406999999998	53.089627999999998	51.938969	0103000020E61000000100000005000000A04E797423524B409A7ADD2230F84940A04E797423524B40276728EE788B4A4088B9A46ABBF74B40276728EE788B4A4088B9A46ABBF74B409A7ADD2230F84940A04E797423524B409A7ADD2230F84940
334	Пономаревский район	\N	69	53.713845999999997	54.609709000000002	53.464534	52.9694	0103000020E61000000100000005000000B130444E5FDB4A40075F984C157C4A40B130444E5FDB4A40A6F0A0D975BB4A40D789CBF10A4E4B40A6F0A0D975BB4A40D789CBF10A4E4B40075F984C157C4A40B130444E5FDB4A40075F984C157C4A40
1861	Переволоцкий район	\N	69	53.920440999999997	54.707014999999998	52.380105	51.631703000000002	0103000020E61000000100000005000000E272BC02D1F54A407EE4D6A4DBD04940E272BC02D1F54A40E605D847A7304A400664AF777F5A4B40E605D847A7304A400664AF777F5A4B407EE4D6A4DBD04940E272BC02D1F54A407EE4D6A4DBD04940
1655	Первомайский район	\N	69	50.768251999999997	52.391472	52.229695999999997	51.448569999999997	0103000020E61000000100000005000000158BDF1456624940BDFBE3BD6AB94940158BDF1456624940D102B4AD661D4A405DA626C11B324A40D102B4AD661D4A405DA626C11B324A40BDFBE3BD6AB94940158BDF1456624940BDFBE3BD6AB94940
1754	Орск городской округ	\N	69	58.342531999999999	58.883856999999999	51.336134999999999	51.041839000000003	0103000020E61000000100000005000000AFEAAC16D82B4D404359F8FA5A854940AFEAAC16D82B4D403E05C07806AB49409BABE63922714D403E05C07806AB49409BABE63922714D404359F8FA5A854940AFEAAC16D82B4D404359F8FA5A854940
1244	Оренбургский район	\N	69	54.069192999999999	56.048208000000002	52.096277000000001	51.270088000000001	0103000020E610000001000000050000005A0EF450DB084B4062855B3E92A249405A0EF450DB084B40B22D03CE520C4A40EAB303AE2B064C40B22D03CE520C4A40EAB303AE2B064C4062855B3E92A249405A0EF450DB084B4062855B3E92A24940
7402	Оренбургская область	\N	69	50.768251999999997	61.691226999999998	54.364834000000002	50.495192000000003	0103000020E61000000100000005000000158BDF1456624940D49E9273623F4940158BDF1456624940043C69E1B22E4B405C8E57207AD84E40043C69E1B22E4B405C8E57207AD84E40D49E9273623F4940158BDF1456624940D49E9273623F4940
1056	Октябрьский район	\N	69	54.657913000000001	55.892431000000002	52.675196999999997	52.103900000000003	0103000020E610000001000000050000007F4E417E36544B40F7065F984C0D4A407F4E417E36544B40BCADF4DA6C564A40E277D32D3BF24B40BCADF4DA6C564A40E277D32D3BF24B40F7065F984C0D4A407F4E417E36544B40F7065F984C0D4A40
1148	Новотроицк городской округ	\N	69	58.099682000000001	58.430576000000002	51.337530000000001	51.068007000000001	0103000020E61000000100000005000000FCFF3861C20C4D4015731074B4884940FCFF3861C20C4D409EB5DB2E34AB4940A438471D1D374D409EB5DB2E34AB4940A438471D1D374D4015731074B4884940FCFF3861C20C4D4015731074B4884940
891	Новосергиевский район	\N	69	53.131459	54.252825999999999	52.738899000000004	51.705196000000001	0103000020E61000000100000005000000E7E104A6D3904A4090A2CEDC43DA4940E7E104A6D3904A400806103E945E4A400CCA349A5C204B400806103E945E4A400CCA349A5C204B4090A2CEDC43DA4940E7E104A6D3904A4090A2CEDC43DA4940
790	Новоорский район	\N	69	58.661515000000001	59.601610999999998	51.822051999999999	51.009642999999997	0103000020E610000001000000050000001F680586AC544D4052D158FB3B8149401F680586AC544D4042CEFBFF38E94940F9F4D89601CD4D4042CEFBFF38E94940F9F4D89601CD4D4052D158FB3B8149401F680586AC544D4052D158FB3B814940
7543	Медногорск городской округ	\N	69	57.549266000000003	57.737912000000001	51.496721000000001	51.382731	0103000020E61000000100000005000000026729594EC64C402B155454FDB04940026729594EC64C40431EC18D94BF4940B9A981E673DE4C40431EC18D94BF4940B9A981E673DE4C402B155454FDB04940026729594EC64C402B155454FDB04940
552	Матвеевский район	\N	69	53.222054	53.870342000000001	53.658195999999997	53.088799999999999	0103000020E6100000010000000500000016F9F5436C9C4A4041F163CC5D8B4A4016F9F5436C9C4A40D32D3BC43FD44A40E92ADD5D67EF4A40D32D3BC43FD44A40E92ADD5D67EF4A4041F163CC5D8B4A4016F9F5436C9C4A4041F163CC5D8B4A40
2799	Ленинский район	\N	69	55.020463999999997	55.274084999999999	51.836356000000002	51.682088999999998	0103000020E61000000100000005000000675F79909E824B400DFB3DB14ED74940675F79909E824B401DE8A1B60DEB49407EA99F3715A34B401DE8A1B60DEB49407EA99F3715A34B400DFB3DB14ED74940675F79909E824B400DFB3DB14ED74940
63	Кувандыкский район	\N	69	56.731259999999999	58.165906	51.869644999999998	50.877192999999998	0103000020E61000000100000005000000BD6F7CED995D4C40DBA337DC47704940BD6F7CED995D4C40A110018750EF4940E71A66683C154D40A110018750EF4940E71A66683C154D40DBA337DC47704940BD6F7CED995D4C40DBA337DC47704940
791	Красногвардейский район	\N	69	53.068964000000001	54.045630000000003	53.140298000000001	52.526598999999997	0103000020E61000000100000005000000F94CF6CFD3884A409B8D959867434A40F94CF6CFD3884A40DCD8EC48F5914A40B6DB2E34D7054B40DCD8EC48F5914A40B6DB2E34D7054B409B8D959867434A40F94CF6CFD3884A409B8D959867434A40
1733	Кваркенский район	\N	69	58.616734000000001	60.205522000000002	52.486469	51.762742000000003	0103000020E61000000100000005000000672AC423F14E4D4090A4A487A1E14940672AC423F14E4D4048C2BE9D443E4A40E44D7E8B4E1A4E4048C2BE9D443E4A40E44D7E8B4E1A4E4090A4A487A1E14940672AC423F14E4D4090A4A487A1E14940
1351	Илекский район	\N	69	53.022862000000003	54.412923999999997	51.783200000000001	51.162838999999998	0103000020E610000001000000050000001C295B24ED824A40B5C189E8D79449401C295B24ED824A40151DC9E53FE44940E3DD91B1DA344B40151DC9E53FE44940E3DD91B1DA344B40B5C189E8D79449401C295B24ED824A40B5C189E8D7944940
1612	Домбаровский район	\N	69	58.577692999999996	60.039566999999998	51.159748999999998	50.495192000000003	0103000020E6100000010000000500000066101FD8F1494D40D49E9273623F494066101FD8F1494D40CB48BDA7729449401B800D8810054E40CB48BDA7729449401B800D8810054E40D49E9273623F494066101FD8F1494D40D49E9273623F4940
2990	Дзержинский район	\N	69	55.054546000000002	55.388934999999996	51.948718	51.797967999999997	0103000020E610000001000000050000005610035DFB864B4094A0BFD023E649405610035DFB864B40329067976FF9494087A2409FC8B14B40329067976FF9494087A2409FC8B14B4094A0BFD023E649405610035DFB864B4094A0BFD023E64940
1521	Грачевский район	\N	69	52.618467000000003	53.402849000000003	53.230902	52.732301	0103000020E61000000100000005000000DF5339ED294F4A40FFE9060ABC5D4A40DF5339ED294F4A405E4A5D328E9D4A40F81C588E90B34A405E4A5D328E9D4A40F81C588E90B34A40FFE9060ABC5D4A40DF5339ED294F4A40FFE9060ABC5D4A40
618	Гайский район	\N	69	57.747110999999997	58.816951000000003	52.046737	51.080767999999999	0103000020E61000000100000005000000ADBD4F55A1DF4C401B48179B568A4940ADBD4F55A1DF4C40AF415F7AFB054A409EB7B1D991684D40AF415F7AFB054A409EB7B1D991684D401B48179B568A4940ADBD4F55A1DF4C401B48179B568A4940
1489	Бузулукский район	\N	69	51.710377999999999	52.816169000000002	53.323394999999998	52.512098999999999	0103000020E6100000010000000500000021E692AAEDDA49403BA8C4758C414A4021E692AAEDDA49404F58E20165A94A402881CD3978684A404F58E20165A94A402881CD3978684A403BA8C4758C414A4021E692AAEDDA49403BA8C4758C414A40
1214	Бугурусланский район	\N	69	52.078265999999999	53.146254999999996	54.026699000000001	53.254396999999997	0103000020E61000000100000005000000C231CB9E040A4A40AA99B51490A04A40C231CB9E040A4A40FFEA71DF6A034B4030F0DC7BB8924A40FFEA71DF6A034B4030F0DC7BB8924A40AA99B51490A04A40C231CB9E040A4A40AA99B51490A04A40
1237	Беляевский район	\N	69	55.583761000000003	57.006431999999997	51.670506000000003	50.969768999999999	0103000020E6100000010000000500000013D731AEB8CA4B405AD6FD63217C494013D731AEB8CA4B40CAE2FE23D3D54940EDD286C3D2804C40CAE2FE23D3D54940EDD286C3D2804C405AD6FD63217C494013D731AEB8CA4B405AD6FD63217C4940
1172	Асекеевский район	\N	69	52.537672999999998	53.375253000000001	53.785401	53.125998000000003	0103000020E610000001000000050000009A780778D2444A4043AED4B320904A409A780778D2444A40739F1C0588E44A40EA5C514A08B04A40739F1C0588E44A40EA5C514A08B04A4043AED4B320904A409A780778D2444A4043AED4B320904A40
224	Александровский район	\N	69	53.829846000000003	54.972790000000003	53.008701000000002	52.263800000000003	0103000020E61000000100000005000000B45BCB6438EA4A40A857CA32C4214A40B45BCB6438EA4A40A438471D1D814A401CF0F961847C4B40A438471D1D814A401CF0F961847C4B40A857CA32C4214A40B45BCB6438EA4A40A857CA32C4214A40
919	Акбулакский район	\N	69	55.128064000000002	56.546377999999997	51.430509000000001	50.549505000000003	0103000020E61000000100000005000000C1E5B16664904B4087FE092E56464940C1E5B16664904B401CD13DEB1AB749407FA0DCB6EF454C401CD13DEB1AB749407FA0DCB6EF454C4087FE092E56464940C1E5B16664904B4087FE092E56464940
604	Абдулинский район	\N	69	53.122261000000002	54.058394999999997	54.055498999999998	53.433602	0103000020E61000000100000005000000C3499A3FA68F4A4077BD344580B74A40C3499A3FA68F4A40F8FA5A971A074B40FD9FC37C79074B40F8FA5A971A074B40FD9FC37C79074B4077BD344580B74A40C3499A3FA68F4A4077BD344580B74A40
933	Шахунский район	\N	68	46.003894000000003	46.994132999999998	58.064416000000001	57.443499000000003	0103000020E6100000010000000500000048533D997F00474084674293C4B84C4048533D997F00474069AB92C83E084D40EB6F09C03F7F474069AB92C83E084D40EB6F09C03F7F474084674293C4B84C4048533D997F00474084674293C4B84C40
828	Шатковский район	\N	68	43.781300000000002	44.838698000000001	55.386097999999997	55.028925000000001	0103000020E61000000100000005000000B22E6EA301E44540B6847CD0B3834B40B22E6EA301E445408786C5A86BB14B403D9CC0745A6B46408786C5A86BB14B403D9CC0745A6B4640B6847CD0B3834B40B22E6EA301E44540B6847CD0B3834B40
689	Шарангский район	\N	68	46.035899999999998	46.855837999999999	57.352097999999998	56.862907999999997	0103000020E6100000010000000500000094F6065F9804474077BAF3C4736E4C4094F6065F98044740567E198C11AD4C4047567E198C6D4740567E198C11AD4C4047567E198C6D474077BAF3C4736E4C4094F6065F9804474077BAF3C4736E4C40
305	Чкаловский район	\N	68	42.795766999999998	43.330444	56.879904000000003	56.503796000000001	0103000020E61000000100000005000000361E6CB1DB65454085ED27637C404C40361E6CB1DB6545404FCFBBB1A0704C4068942EFD4BAA45404FCFBBB1A0704C4068942EFD4BAA454085ED27637C404C40361E6CB1DB65454085ED27637C404C40
338	Уренский район	\N	68	45.335797999999997	46.300992999999998	57.741396000000002	57.212600999999999	0103000020E61000000100000005000000F607CA6DFBAA4640670C7382369B4C40F607CA6DFBAA46404FB16A10E6DE4C4097A949F0862647404FB16A10E6DE4C4097A949F086264740670C7382369B4C40F607CA6DFBAA4640670C7382369B4C40
126	Тоншаевский район	\N	68	46.706394000000003	47.770995999999997	58.022568	57.487654999999997	0103000020E610000001000000050000009A0B5C1E6B5A47408D5DA27A6BBE4C409A0B5C1E6B5A4740D3F71A82E3024D4064AC36FFAFE24740D3F71A82E3024D4064AC36FFAFE247408D5DA27A6BBE4C409A0B5C1E6B5A47408D5DA27A6BBE4C40
42	Тонкинский район	\N	68	45.853200999999999	46.834511999999997	57.526398	57.145397000000003	0103000020E610000001000000050000000EF5BBB035ED4640E0F76F5E9C924C400EF5BBB035ED46400457790261C34C404D0F0A4AD16A47400457790261C34C404D0F0A4AD16A4740E0F76F5E9C924C400EF5BBB035ED4640E0F76F5E9C924C40
1101	Спасский район	\N	68	45.344493999999997	45.897990999999998	56.023398999999998	55.703595999999997	0103000020E6100000010000000500000088D51F6118AC464057CC086F0FDA4B4088D51F6118AC46402AE109BDFE024C40198D7C5EF1F246402AE109BDFE024C40198D7C5EF1F2464057CC086F0FDA4B4088D51F6118AC464057CC086F0FDA4B40
1050	Сосновский район	\N	68	42.883091999999998	43.622900000000001	55.936599999999999	55.543897999999999	0103000020E61000000100000005000000FBAD9D28097145400E2E1D739EC54B40FBAD9D280971454080B74082E2F74B40D656EC2FBBCF454080B74082E2F74B40D656EC2FBBCF45400E2E1D739EC54B40FBAD9D28097145400E2E1D739EC54B40
1117	Сокольский район	\N	68	43.092193000000002	43.885477000000002	57.605753	56.815024999999999	0103000020E61000000100000005000000C7F5EFFACC8B454011363CBD52684C40C7F5EFFACC8B4540193A765089CD4C401B2E724F57F14540193A765089CD4C401B2E724F57F1454011363CBD52684C40C7F5EFFACC8B454011363CBD52684C40
5773	Советский район	\N	68	43.962435999999997	44.080222999999997	56.320442999999997	56.243634999999998	0103000020E610000001000000050000001C3F541A31FB45409A94826E2F1F4C401C3F541A31FB4540B69DB64604294C4089B14CBF440A4640B69DB64604294C4089B14CBF440A46409A94826E2F1F4C401C3F541A31FB45409A94826E2F1F4C40
1805	Сеченовский район	\N	68	45.578595	46.230260000000001	55.428193999999998	54.992781999999998	0103000020E610000001000000050000008750A5660FCA46405B07077B137F4B408750A5660FCA4640F52B9D0FCFB64B40DAC9E028791D4740F52B9D0FCFB64B40DAC9E028791D47405B07077B137F4B408750A5660FCA46405B07077B137F4B40
1201	Сергачский район	\N	68	45.085796999999999	45.825093000000003	55.800296000000003	55.317501999999998	0103000020E61000000100000005000000268C6665FB8A46401135D1E7A3A84B40268C6665FB8A4640508F6D1970E64B404B94BDA59CE94640508F6D1970E64B404B94BDA59CE946401135D1E7A3A84B40268C6665FB8A46401135D1E7A3A84B40
1084	Семеновский район	\N	68	44.018194999999999	45.193989999999999	57.421798000000003	56.524197999999998	0103000020E61000000100000005000000B1F9B83654024640765089EB18434C40B1F9B8365402464055C2137AFDB54C4022E010AAD498464055C2137AFDB54C4022E010AAD4984640765089EB18434C40B1F9B83654024640765089EB18434C40
1211	Починковский район	\N	68	44.182658000000004	45.222664999999999	54.926000999999999	54.461975000000002	0103000020E61000000100000005000000282D5C5661174640E9482EFF213B4B40282D5C56611746401A88653387764B405F7B6649809C46401A88653387764B405F7B6649809C4640E9482EFF213B4B40282D5C5661174640E9482EFF213B4B40
1209	Пильнинский район	\N	68	45.621093999999999	46.392297999999997	55.925566000000003	55.345697999999999	0103000020E61000000100000005000000F4DE180280CF4640742502D53FAC4B40F4DE180280CF464010255AF278F64B40A22424D23632474010255AF278F64B40A22424D236324740742502D53FAC4B40F4DE180280CF4640742502D53FAC4B40
1465	Перевозский район	\N	68	44.291794000000003	44.735391	55.833596999999997	55.382947999999999	0103000020E61000000100000005000000A3957B8159254640C808A87004B14B40A3957B81592546409885764EB3EA4B40E962D34A215E46409885764EB3EA4B40E962D34A215E4640C808A87004B14B40A3957B8159254640C808A87004B14B40
1230	Первомайский район	\N	68	43.457878999999998	44.185093000000002	55.173200000000001	54.726886	0103000020E61000000100000005000000394371C79BBA4540CBF5B6990A5D4B40394371C79BBA454067D5E76A2B964B40F9DB9E20B117464067D5E76A2B964B40F9DB9E20B1174640CBF5B6990A5D4B40394371C79BBA4540CBF5B6990A5D4B40
981	Павловский район	\N	68	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
1042	Навашинский район	\N	68	42.061169999999997	43.013393000000001	55.785265000000003	55.419395999999999	0103000020E6100000010000000500000087BF266BD40745405F09A4C4AEB54B4087BF266BD4074540C3D8429083E44B40677FA0DCB6814540C3D8429083E44B40677FA0DCB68145405F09A4C4AEB54B4087BF266BD40745405F09A4C4AEB54B40
390	Лысковский район	\N	68	44.706394000000003	45.653891999999999	56.464699000000003	55.855699000000001	0103000020E610000001000000050000009A0B5C1E6B5A4640261C7A8B87ED4B409A0B5C1E6B5A4640F1BDBF417B3B4C40DA8EA9BBB2D34640F1BDBF417B3B4C40DA8EA9BBB2D34640261C7A8B87ED4B409A0B5C1E6B5A4640261C7A8B87ED4B40
1502	Лукояновский район	\N	68	44.046078000000001	45.088897000000003	55.200097	54.626448000000003	0103000020E61000000100000005000000558847E2E50546408352B4722F504B40558847E2E50546408C834BC79C994B4034DB15FA608B46408C834BC79C994B4034DB15FA608B46408352B4722F504B40558847E2E50546408352B4722F504B40
1292	Кулебакский район	\N	68	42.219794	43.078898000000002	55.508293999999999	55.157598	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
7005	Кулебакский	\N	68	42.219794	43.078898000000002	55.508293999999999	55.157598	0103000020E61000000100000005000000B3EDB435221C45401FF5D72B2C944B40B3EDB435221C454063601DC70FC14B4023DC6454198A454063601DC70FC14B4023DC6454198A45401FF5D72B2C944B40B3EDB435221C45401FF5D72B2C944B40
926	Кстовский район	\N	68	43.972551000000003	44.857913000000003	56.238987000000002	55.865206999999998	0103000020E610000001000000050000009758198D7CFC454098A25C1ABFEE4B409758198D7CFC4540A7954220971E4C4019E8DA17D06D4640A7954220971E4C4019E8DA17D06D464098A25C1ABFEE4B409758198D7CFC454098A25C1ABFEE4B40
1499	Краснооктябрьский район	\N	68	45.214499000000004	45.849491	55.479995000000002	55.086233999999997	0103000020E610000001000000050000002A0307B4749B4640D1E638B7098B4B402A0307B4749B46402C9FE57970BD4B40889FFF1EBCEC46402C9FE57970BD4B40889FFF1EBCEC4640D1E638B7098B4B402A0307B4749B4640D1E638B7098B4B40
1450	Краснобаковский район	\N	68	44.689497000000003	45.912697000000001	57.380299000000001	56.904299999999999	0103000020E6100000010000000500000056D80C7041584640EBE2361AC0734C4056D80C7041584640CBD93BA3ADB04C4023145B41D3F44640CBD93BA3ADB04C4023145B41D3F44640EBE2361AC0734C4056D80C7041584640EBE2361AC0734C40
1274	Ковернинский район	\N	68	43.485709	44.511800999999998	57.522357999999997	56.842896000000003	0103000020E61000000100000005000000BA2F67B62BBE4540F1F62004E46B4C40BA2F67B62BBE4540E8667FA0DCC24C40B187F6B182414640E8667FA0DCC24C40B187F6B182414640F1F62004E46B4C40BA2F67B62BBE4540F1F62004E46B4C40
168	Княгининский район	\N	68	44.856493	45.480795999999998	55.925899000000001	55.639898000000002	0103000020E6100000010000000500000060200890A16D46404E637B2DE8D14B4060200890A16D46401633C2DB83F64B4018062CB98ABD46401633C2DB83F64B4018062CB98ABD46404E637B2DE8D14B4060200890A16D46404E637B2DE8D14B40
1300	Дивеевский район	\N	68	42.950195999999998	43.736797000000003	55.275399999999998	54.892668999999998	0103000020E610000001000000050000001F65C405A0794540969350FA42724B401F65C405A0794540C1A8A44E40A34B403D65355D4FDE4540C1A8A44E40A34B403D65355D4FDE4540969350FA42724B401F65C405A0794540969350FA42724B40
7009	Дзержинский городской округ	\N	68	41.776566000000003	47.770995999999997	58.091237	54.461975000000002	0103000020E61000000100000005000000C097C28366E34440E9482EFF213B4B40C097C28366E34440B3976DA7AD0B4D4064AC36FFAFE24740B3976DA7AD0B4D4064AC36FFAFE24740E9482EFF213B4B40C097C28366E34440E9482EFF213B4B40
6977	Дзержинск городской округ	\N	68	43.294018000000001	43.669297999999998	56.324246000000002	56.206901999999999	0103000020E61000000100000005000000B937BF61A2A545400EBDC5C37B1A4C40B937BF61A2A54540EEED96E480294C409CA38E8EABD54540EEED96E480294C409CA38E8EABD545400EBDC5C37B1A4C40B937BF61A2A545400EBDC5C37B1A4C40
985	Дальнеконстантиновский район	\N	68	43.566763999999999	44.452440000000003	56.102030999999997	55.653146999999997	0103000020E610000001000000050000006B4606B98BC84540813D26529AD34B406B4606B98BC84540CE16105A0F0D4C407DB3CD8DE9394640CE16105A0F0D4C407DB3CD8DE9394640813D26529AD34B406B4606B98BC84540813D26529AD34B40
837	Городецкий район	\N	68	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
590	Гагинский район	\N	68	44.615898000000001	45.359594999999999	55.420893	55.057698000000002	0103000020E61000000100000005000000FED5E3BED54E4640B685E7A562874B40FED5E3BED54E4640C30E63D2DFB54B400E677E3507AE4640C30E63D2DFB54B400E677E3507AE4640B685E7A562874B40FED5E3BED54E4640B685E7A562874B40
6955	Выксунский район	\N	68	41.776566000000003	42.802900000000001	55.479596999999998	54.95964	0103000020E61000000100000005000000C097C28366E344407BF7C77BD57A4B40C097C28366E344403E213B6F63BD4B40ADFA5C6DC56645403E213B6F63BD4B40ADFA5C6DC56645407BF7C77BD57A4B40C097C28366E344407BF7C77BD57A4B40
6980	Выкса городской округ	\N	68	42.106687000000001	42.223145000000002	55.365642000000001	55.292442999999999	0103000020E6100000010000000500000045F46BEBA70D4540D978B0C56EA54B4045F46BEBA70D4540A305685BCDAE4B400AA2EE03901C4540A305685BCDAE4B400AA2EE03901C4540D978B0C56EA54B4045F46BEBA70D4540D978B0C56EA54B40
47	Воскресенский район	\N	68	44.898499000000001	46.104595000000003	57.190596999999997	56.446100999999999	0103000020E610000001000000050000008E3EE6030273464040DB6AD619394C408E3EE603027346409CDB847B65984C409E29745E630D47409CDB847B65984C409E29745E630D474040DB6AD619394C408E3EE6030273464040DB6AD619394C40
1540	Воротынский район	\N	68	45.375799999999998	46.183394999999997	56.475797	55.854197999999997	0103000020E610000001000000050000001CEBE2361AB0464080272D5C56ED4B401CEBE2361AB04640784485EAE63C4C40FD9FC37C79174740784485EAE63C4C40FD9FC37C7917474080272D5C56ED4B401CEBE2361AB0464080272D5C56ED4B40
888	Володарский район	\N	68	42.612546999999999	43.391395000000003	56.519998000000001	56.161799000000002	0103000020E61000000100000005000000A721AAF0674E454044C362D4B5144C40A721AAF0674E454022FE614B8F424C40B2683A3B19B2454022FE614B8F424C40B2683A3B19B2454044C362D4B5144C40A721AAF0674E454044C362D4B5144C40
1818	Вознесенский район	\N	68	42.426020999999999	43.231090999999999	55.076895999999998	54.754043000000003	0103000020E6100000010000000500000061342BDB873645408D63247B84604B4061342BDB87364540BB9866BAD7894B4031B3CF63949D4540BB9866BAD7894B4031B3CF63949D45408D63247B84604B4061342BDB873645408D63247B84604B40
1446	Ветлужский район	\N	68	44.799720000000001	46.212294	58.091237	57.555197999999997	0103000020E6100000010000000500000083FA96395D664640FD6662BA10C74C4083FA96395D664640B3976DA7AD0B4D408A9125732C1B4740B3976DA7AD0B4D408A9125732C1B4740FD6662BA10C74C4083FA96395D664640FD6662BA10C74C40
1675	Вачский район	\N	68	42.375239000000001	42.992597000000004	55.983629999999998	55.620691999999998	0103000020E610000001000000050000008597E0D407304540C571E0D572CF4B408597E0D407304540A7AE7C96E7FD4B40CA8D226B0D7F4540A7AE7C96E7FD4B40CA8D226B0D7F4540C571E0D572CF4B408597E0D407304540C571E0D572CF4B40
1010	Варнавинский район	\N	68	44.336117000000002	45.447693000000001	57.832433999999999	57.193098999999997	0103000020E610000001000000050000009850C1E1052B4640F5F1D077B7984C409850C1E1052B46400B0A83328DEA4C40F6D214014EB946400B0A83328DEA4C40F6D214014EB94640F5F1D077B7984C409850C1E1052B4640F5F1D077B7984C40
1703	Вадский район	\N	68	43.976495	44.472796000000002	55.689796000000001	55.326394000000001	0103000020E6100000010000000500000090DAC4C9FDFC454029CE5147C7A94B4090DAC4C9FDFC4540B0743E3C4BD84B40FED64E94843C4640B0743E3C4BD84B40FED64E94843C464029CE5147C7A94B4090DAC4C9FDFC454029CE5147C7A94B40
1536	Бутурлинский район	\N	68	44.485911000000002	45.253898999999997	55.712000000000003	55.318496000000003	0103000020E6100000010000000500000022E2E654323E464013F4177AC4A84B4022E2E654323E46404260E5D022DB4B4059BE2EC37FA046404260E5D022DB4B4059BE2EC37FA0464013F4177AC4A84B4022E2E654323E464013F4177AC4A84B40
983	Борский район	\N	68	43.790453999999997	45.221066	56.896185000000003	56.052326000000001	0103000020E61000000100000005000000067FBF982DE54540815D4D9EB2064C40067FBF982DE545403815A930B6724C40F72004E44B9C46403815A930B6724C40F72004E44B9C4640815D4D9EB2064C40067FBF982DE54540815D4D9EB2064C40
1526	Большемурашкинский район	\N	68	44.464692999999997	44.991995000000003	55.945998000000003	55.630299000000001	0103000020E610000001000000050000000ED76A0F7B3B4640CBD93BA3ADD04B400ED76A0F7B3B46406C0A647616F94B40D46531B1F97E46406C0A647616F94B40D46531B1F97E4640CBD93BA3ADD04B400ED76A0F7B3B4640CBD93BA3ADD04B40
1428	Большеболдинский район	\N	68	44.868791000000002	45.482394999999997	55.193196	54.801644000000003	0103000020E610000001000000050000009207228B346F46406F8445459C664B409207228B346F4640E8DB82A5BA984B4080608E1EBFBD4640E8DB82A5BA984B4080608E1EBFBD46406F8445459C664B409207228B346F46406F8445459C664B40
1389	Богородский район	\N	68	43.205911	43.939017	56.199882000000002	55.823377999999998	0103000020E610000001000000050000007E71A94A5B9A4540791F477364E94B407E71A94A5B9A45409087BEBB95194C40ABB184B531F845409087BEBB95194C40ABB184B531F84540791F477364E94B407E71A94A5B9A4540791F477364E94B40
916	Балахнинский район	\N	68	43.104849999999999	43.717312999999997	56.644509999999997	56.371102	0103000020E61000000100000005000000287E8CB96B8D454077BD3445802F4C40287E8CB96B8D4540F4F8BD4D7F524C4071FF91E9D0DB4540F4F8BD4D7F524C4071FF91E9D0DB454077BD3445802F4C40287E8CB96B8D454077BD3445802F4C40
992	Арзамасский район	\N	68	42.484293999999998	44.395738000000001	55.719186000000001	55.202706999999997	0103000020E6100000010000000500000013D38558FD3D4540CBD58F4DF2994B4013D38558FD3D4540DBDE6E490EDC4B4069E4F38AA7324640DBDE6E490EDC4B4069E4F38AA7324640CBD58F4DF2994B4013D38558FD3D4540CBD58F4DF2994B40
907	Ардатовский район	\N	68	42.733396999999997	43.581091999999998	55.623600000000003	55.058996999999998	0103000020E6100000010000000500000004FEF0F3DF5D4540F3C7B4368D874B4004FEF0F3DF5D45408FE4F21FD2CF4B40CEFBFF3861CA45408FE4F21FD2CF4B40CEFBFF3861CA4540F3C7B4368D874B4004FEF0F3DF5D4540F3C7B4368D874B40
6974	 Павловский район	\N	68	42.671297000000003	43.433399999999999	56.194794000000002	55.829799999999999	0103000020E610000001000000050000009373620FED554540431CEBE236EA4B409373620FED55454080BA8102EF184C400F0BB5A679B7454080BA8102EF184C400F0BB5A679B74540431CEBE236EA4B409373620FED554540431CEBE236EA4B40
6982	 Городецкий район	\N	68	43.081054000000002	43.953749000000002	57.438301000000003	56.442681999999998	0103000020E61000000100000005000000E19A3BFA5F8A45409143C4CDA9384C40E19A3BFA5F8A4540ED66463F1AB84C40DECB7D7214FA4540ED66463F1AB84C40DECB7D7214FA45409143C4CDA9384C40E19A3BFA5F8A45409143C4CDA9384C40
87	Яранский район	\N	67	47.396191999999999	48.555711000000002	57.462997999999999	56.957776000000003	0103000020E61000000100000005000000EA77616BB6B2474065726A67987A4C40EA77616BB6B24740840EBA8443BB4C408483BD8921474840840EBA8443BB4C408483BD892147484065726A67987A4C40EA77616BB6B2474065726A67987A4C40
1882	Юрьянский район	\N	67	48.522894999999998	49.783285999999997	59.291598999999998	58.681499000000002	0103000020E61000000100000005000000F71E2E39EE424840DCA0F65B3B574D40F71E2E39EE424840ED45B41D53A54D4013B534B742E44840ED45B41D53A54D4013B534B742E44840DCA0F65B3B574D40F71E2E39EE424840DCA0F65B3B574D40
1862	Шабалинский район	\N	67	46.318734999999997	47.579493999999997	58.791797000000003	58.003135	0103000020E61000000100000005000000978BF84ECC2847408A3C49BA66004D40978BF84ECC2847401409A69A59654D40361D01DC2CCA47401409A69A59654D40361D01DC2CCA47408A3C49BA66004D40978BF84ECC2847408A3C49BA66004D40
1841	Фаленский район	\N	67	51.111885000000001	52.012571999999999	58.680399999999999	57.837699999999998	0103000020E61000000100000005000000DCF4673F528E4940FAEDEBC039EB4C40DCF4673F528E49406519E25817574D40336C94F59B014A406519E25817574D40336C94F59B014A40FAEDEBC039EB4C40DCF4673F528E4940FAEDEBC039EB4C40
359	Уржумский район	\N	67	49.409630999999997	50.643692000000001	57.406601000000002	56.777996999999999	0103000020E61000000100000005000000C136E2C96EB448406CB1DB6795634C40C136E2C96EB44840ADC266800BB44C403259DC7F64524940ADC266800BB44C403259DC7F645249406CB1DB6795634C40C136E2C96EB448406CB1DB6795634C40
1759	Унинский район	\N	67	50.844582000000003	51.958233	57.885697999999998	57.402999000000001	0103000020E61000000100000005000000286552431B6C49400DA9A27895B34C40286552431B6C4940F910548D5EF14C4057790261A7FA4940F910548D5EF14C4057790261A7FA49400DA9A27895B34C40286552431B6C49400DA9A27895B34C40
592	Тужинский район	\N	67	47.440893000000003	48.357191999999998	57.881511000000003	57.406601000000002	0103000020E6100000010000000500000086048C2E6FB84740ADC266800BB44C4086048C2E6FB847403A083A5AD5F04C404832AB77B82D48403A083A5AD5F04C404832AB77B82D4840ADC266800BB44C4086048C2E6FB84740ADC266800BB44C40
869	Сунский район	\N	67	49.553891999999998	50.477592999999999	58.043796	57.713999000000001	0103000020E610000001000000050000000DC2DCEEE5C648403830B95164DB4C400DC2DCEEE5C648400AD9791B9B054D4036E675C4213D49400AD9791B9B054D4036E675C4213D49403830B95164DB4C400DC2DCEEE5C648403830B95164DB4C40
1676	Советский район	\N	67	48.620398000000002	49.391899000000002	57.876195000000003	57.081440999999998	0103000020E610000001000000050000007D40A033694F4840DAC69FA86C8A4C407D40A033694F484099F5622827F04C40E52A16BF29B2484099F5622827F04C40E52A16BF29B24840DAC69FA86C8A4C407D40A033694F4840DAC69FA86C8A4C40
30	Слободской район	\N	67	49.600774999999999	50.781627999999998	59.394114999999999	58.477404999999997	0103000020E6100000010000000500000090A0F831E6CC484033F9669B1B3D4D4090A0F831E6CC484078EE3D5C72B24D40A6D1E4620C64494078EE3D5C72B24D40A6D1E4620C64494033F9669B1B3D4D4090A0F831E6CC484033F9669B1B3D4D40
132	Свечинский район	\N	67	47.181800000000003	47.908591000000001	58.695900000000002	58.006377999999998	0103000020E61000000100000005000000D734EF3845974740FAB48AFED0004D40D734EF3845974740A9A44E4013594D405038BBB54CF44740A9A44E4013594D405038BBB54CF44740FAB48AFED0004D40D734EF3845974740FAB48AFED0004D40
1500	Санчурский район	\N	67	46.707292000000002	47.705455000000001	57.202168	56.796491000000003	0103000020E61000000100000005000000795C548B885A47407847C66AF3654C40795C548B885A47401C261AA4E0994C405CE674594CDA47401C261AA4E0994C405CE674594CDA47407847C66AF3654C40795C548B885A47407847C66AF3654C40
122	Подосиновский район	\N	67	46.262419999999999	48.304397999999999	60.581499999999998	59.954799999999999	0103000020E610000001000000050000007DE882FA96214740431CEBE236FA4D407DE882FA96214740DF4F8D976E4A4E40E17B7F83F6264840DF4F8D976E4A4E40E17B7F83F6264840431CEBE236FA4D407DE882FA96214740431CEBE236FA4D40
1426	Пижанский район	\N	67	48.198990000000002	48.805388999999998	57.634099999999997	57.150207000000002	0103000020E61000000100000005000000931D1B8178194840AD50A4FB39934C40931D1B8178194840613255302AD14C4071C79BFC16674840613255302AD14C4071C79BFC16674840AD50A4FB39934C40931D1B8178194840AD50A4FB39934C40
789	Орловский район	\N	67	48.331096000000002	49.297790999999997	58.979095999999998	58.429594000000002	0103000020E6100000010000000500000010EB8D5A612A48406747AAEFFC364D4010EB8D5A612A48407CD28904537D4D408505F7031EA648407CD28904537D4D408505F7031EA648406747AAEFFC364D4010EB8D5A612A48406747AAEFFC364D40
1245	Оричевский район	\N	67	48.343394000000004	49.661788000000001	58.616396999999999	58.006998000000003	0103000020E6100000010000000500000042D2A755F42B484097917A4FE5004D4042D2A755F42B48401F2DCE18E64E4D4050711C78B5D448401F2DCE18E64E4D4050711C78B5D4484097917A4FE5004D4042D2A755F42B484097917A4FE5004D40
1240	Опаринский район	\N	67	46.918135999999997	48.536999000000002	60.229899000000003	59.282497999999997	0103000020E61000000100000005000000DFA3FE7A85754740BB97FBE428A44D40DFA3FE7A857547400A3197546D1D4E400B7E1B62BC4448400A3197546D1D4E400B7E1B62BC444840BB97FBE428A44D40DFA3FE7A85754740BB97FBE428A44D40
769	Омутнинский район	\N	67	51.474679000000002	53.077758000000003	59.220298	58.393431	0103000020E610000001000000050000008B8C0E48C2BC4940C51D6FF25B324D408B8C0E48C2BC4940E6AF90B9329C4D404E8061F9F3894A40E6AF90B9329C4D404E8061F9F3894A40C51D6FF25B324D408B8C0E48C2BC4940C51D6FF25B324D40
736	Нолинский район	\N	67	49.322091	50.361593999999997	57.901800000000001	57.262799999999999	0103000020E6100000010000000500000000AB23473AA94840C4B12E6EA3A14C4000AB23473AA9484033C4B12E6EF34C40043752B6482E494033C4B12E6EF34C40043752B6482E4940C4B12E6EA3A14C4000AB23473AA94840C4B12E6EA3A14C40
7390	Нововятский район	\N	67	49.638890000000004	49.770564999999998	58.563124999999999	58.481727999999997	0103000020E61000000100000005000000E8DEC325C7D14840A3C85A43A93D4D40E8DEC325C7D14840AE47E17A14484D409B38B9DFA1E24840AE47E17A14484D409B38B9DFA1E24840A3C85A43A93D4D40E8DEC325C7D14840A3C85A43A93D4D40
733	Немский район	\N	67	50.104191	51.202686999999997	57.857897999999999	57.170496999999997	0103000020E61000000100000005000000CEC47421560D494076887FD8D2954C40CEC47421560D4940E3A6069ACFED4C408429CAA5F1994940E3A6069ACFED4C408429CAA5F199494076887FD8D2954C40CEC47421560D494076887FD8D2954C40
449	Нагорский район	\N	67	49.798943000000001	51.757280000000002	60.043013000000002	59.041200000000003	0103000020E610000001000000050000001F2FA4C343E64840304CA60A46854D401F2FA4C343E64840C426327381054E401BF5108DEEE04940C426327381054E401BF5108DEEE04940304CA60A46854D401F2FA4C343E64840304CA60A46854D40
942	Мурашинский район	\N	67	48.130996000000003	49.573214999999998	59.705844999999997	58.908696999999997	0103000020E6100000010000000500000013F4177AC4104840957CEC2E50744D4013F4177AC4104840C685032159DA4D40CF49EF1B5FC94840C685032159DA4D40CF49EF1B5FC94840957CEC2E50744D4013F4177AC4104840957CEC2E50744D40
808	Малмыжский район	\N	67	50.024608999999998	51.265352999999998	56.832417999999997	56.31926	0103000020E61000000100000005000000F817416326034940E275FD82DD284C40F817416326034940054D4BAC8C6A4C409F724C16F7A14940054D4BAC8C6A4C409F724C16F7A14940E275FD82DD284C40F817416326034940E275FD82DD284C40
412	Лузский район	\N	67	46.960850999999998	48.785356	61.065370999999999	60.163409000000001	0103000020E6100000010000000500000019AA622AFD7A4740A06F0B96EA144E4019AA622AFD7A4740AC8DB1135E884E40D3DB9F8B86644840AC8DB1135E884E40D3DB9F8B86644840A06F0B96EA144E4019AA622AFD7A4740A06F0B96EA144E40
575	Лебяжский район	\N	67	49.139229	49.877788000000002	57.548698000000002	57.007049000000002	0103000020E61000000100000005000000D0D38041D2914840193C4CFBE6804C40D0D38041D2914840B8B06EBC3BC64C401F69705B5BF04840B8B06EBC3BC64C401F69705B5BF04840193C4CFBE6804C40D0D38041D2914840193C4CFBE6804C40
414	Куменский район	\N	67	49.502094999999997	50.836981999999999	58.337797000000002	57.946095999999997	0103000020E61000000100000005000000183E22A644C048402E7079AC19F94C40183E22A644C04840EDD79DEE3C2B4D409BABE639226B4940EDD79DEE3C2B4D409BABE639226B49402E7079AC19F94C40183E22A644C048402E7079AC19F94C40
110	Котельничский район	\N	67	47.409443000000003	48.682893999999997	58.791998	57.815596999999997	0103000020E61000000100000005000000BF49D3A068B447409CDB847B65E84C40BF49D3A068B44740AB3FC23060654D403B51121269574840AB3FC23060654D403B511212695748409CDB847B65E84C40BF49D3A068B447409CDB847B65E84C40
7389	Кировский район	\N	67	46.262419999999999	53.931992999999999	61.065370999999999	56.058951	0103000020E610000001000000050000007DE882FA962147408388D4B48B074C407DE882FA96214740AC8DB1135E884E40EB8CEF8B4BF74A40AC8DB1135E884E40EB8CEF8B4BF74A408388D4B48B074C407DE882FA962147408388D4B48B074C40
1887	Кирово-Чепецкий район	\N	67	49.278458999999998	50.744985999999997	58.567537000000002	58.17747	0103000020E610000001000000050000007023658BA4A34840B4024356B7164D407023658BA4A348408E226B0DA5484D402AFD84B35B5F49408E226B0DA5484D402AFD84B35B5F4940B4024356B7164D407023658BA4A34840B4024356B7164D40
7391	Кирово-Чепецк городской округ	\N	67	49.935603999999998	50.069606	58.568612000000002	58.519398000000002	0103000020E61000000100000005000000DE0033DFC1F74840CDCD37A27B424D40DE0033DFC1F748407C0E2C47C8484D407DCD72D9E80849407C0E2C47C8484D407DCD72D9E8084940CDCD37A27B424D40DE0033DFC1F74840CDCD37A27B424D40
1752	Киров городской округ	\N	67	49.210089000000004	49.848134999999999	58.671959999999999	58.470393000000001	0103000020E61000000100000005000000EB1F4432E49A484038A27BD6353C4D40EB1F4432E49A48402E1C08C902564D40E6CB0BB08FEC48402E1C08C902564D40E6CB0BB08FEC484038A27BD6353C4D40EB1F4432E49A484038A27BD6353C4D40
655	Кильмезский район	\N	67	50.526353999999998	51.558517999999999	57.493498000000002	56.661431999999998	0103000020E61000000100000005000000340F60915F4349409143C4CDA9544C40340F60915F4349401A5245F12ABF4C40191D90847DC749401A5245F12ABF4C40191D90847DC749409143C4CDA9544C40340F60915F4349409143C4CDA9544C40
1556	Кикнурский район	\N	67	46.681061999999997	47.560692000000003	57.561118	57.092896000000003	0103000020E610000001000000050000003046240A2D574740F1F62004E48B4C403046240A2D5747403599F1B6D2C74C407E9065C1C4C747403599F1B6D2C74C407E9065C1C4C74740F1F62004E48B4C403046240A2D574740F1F62004E48B4C40
1328	Зуевский район	\N	67	50.60669	51.523583000000002	58.714995999999999	57.960199000000003	0103000020E61000000100000005000000B6679604A84D4940725303CDE7FA4C40B6679604A84D4940AA622AFD845B4D40ECDE8AC404C34940AA622AFD845B4D40ECDE8AC404C34940725303CDE7FA4C40B6679604A84D4940725303CDE7FA4C40
1053	Даровской район	\N	67	47.203817999999998	48.545192	59.407198000000001	58.632998000000001	0103000020E61000000100000005000000062B4EB5169A47407A37161406514D40062B4EB5169A4740917F66101FB44D403A05F9D9C8454840917F66101FB44D403A05F9D9C84548407A37161406514D40062B4EB5169A47407A37161406514D40
1290	Вятскополянский район	\N	67	50.833632000000001	51.499175999999999	56.444099999999999	56.058951	0103000020E6100000010000000500000015731074B46A49408388D4B48B074C4015731074B46A4940A913D044D8384C405B79C9FFE4BF4940A913D044D8384C405B79C9FFE4BF49408388D4B48B074C4015731074B46A49408388D4B48B074C40
185	Верхошижемский район	\N	67	48.521988	49.681587	58.203001999999998	57.752994999999999	0103000020E61000000100000005000000C573B680D04248409886E12362E04C40C573B680D0424840E48233F8FB194D407B30293E3ED74840E48233F8FB194D407B30293E3ED748409886E12362E04C40C573B680D04248409886E12362E04C40
172	Верхнекамский район	\N	67	51.567196000000003	53.687902999999999	60.308957999999997	59.126998999999998	0103000020E610000001000000050000000536E7E099C84940F6CFD38041904D400536E7E099C8494035EB8CEF8B274E40FFE89B340DD84A4035EB8CEF8B274E40FFE89B340DD84A40F6CFD38041904D400536E7E099C84940F6CFD38041904D40
198	Богородский район	\N	67	50.405386999999997	51.231082000000001	58.042495000000002	57.567495000000001	0103000020E610000001000000050000009D9CA1B8E33349405FD218ADA3C84C409D9CA1B8E33349402C9FE57970054D40DE585018949D49402C9FE57970054D40DE585018949D49405FD218ADA3C84C409D9CA1B8E33349405FD218ADA3C84C40
486	Белохолуницкий район	\N	67	50.392190999999997	52.037778000000003	59.558098000000001	58.591797	0103000020E610000001000000050000008C648F50333249407A6F0C01C04B4D408C648F503332494044FB58C16FC74D401041D5E8D5044A4044FB58C16FC74D401041D5E8D5044A407A6F0C01C04B4D408C648F50333249407A6F0C01C04B4D40
246	Афанасьевский район	\N	67	52.584367	53.931992999999999	59.425502999999999	58.383623999999998	0103000020E610000001000000050000004AEEB089CC4A4A40F8FA5A971A314D404AEEB089CC4A4A40C9ACDEE176B64D40EB8CEF8B4BF74A40C9ACDEE176B64D40EB8CEF8B4BF74A40F8FA5A971A314D404AEEB089CC4A4A40F8FA5A971A314D40
429	Арбажский район	\N	67	47.858393999999997	48.757095	57.996195999999998	57.573895	0103000020E61000000100000005000000938AC6DADFED4740412B306475C94C40938AC6DADFED4740F833BC5983FF4C40897B2C7DE8604840F833BC5983FF4C40897B2C7DE8604840412B306475C94C40938AC6DADFED4740412B306475C94C40
1281	Чукотский район	\N	42	184.39139299999999	190.343693	67.119999000000007	65.167997	0103000020E6100000010000000500000044DC9C4A860C6740DF347D76C04A504044DC9C4A860C674060234910AEC75040A75B7688FFCA674060234910AEC75040A75B7688FFCA6740DF347D76C04A504044DC9C4A860C6740DF347D76C04A5040
1524	Чаунский район	\N	42	167.04129599999999	174.224593	70.127399999999994	67.110997999999995	0103000020E61000000100000005000000942EFD4B52E16440F8FA5A971AC75040942EFD4B52E16440AA6054522788514023BDA8DD2FC76540AA6054522788514023BDA8DD2FC76540F8FA5A971AC75040942EFD4B52E16440F8FA5A971AC75040
1735	Провиденский район	\N	42	182.88489200000001	187.93019799999999	66.922998000000007	64.243699000000007	0103000020E61000000100000005000000BF0F070951DC664059C4B0C3980F5040BF0F070951DC66408011346612BB5040BF99982EC47D67408011346612BB5040BF99982EC47D674059C4B0C3980F5040BF0F070951DC664059C4B0C3980F5040
1719	Иультинский район	\N	42	176.06889699999999	185.40589700000001	68.312197999999995	64.948198000000005	0103000020E610000001000000050000005C397B67340266407D08AA46AF3C50405C397B67340266401AF8510DFB1351406D91B41BFD2C67401AF8510DFB1351406D91B41BFD2C67407D08AA46AF3C50405C397B67340266407D08AA46AF3C5040
1705	Билибинский район	\N	42	157.72459900000001	171.00389000000001	69.756799000000001	64.662195999999994	0103000020E61000000100000005000000DCF63DEA2FB76340B0E2546B612A5040DCF63DEA2FB7634050A912656F70514002D9EBDD1F60654050A912656F70514002D9EBDD1F606540B0E2546B612A5040DCF63DEA2FB76340B0E2546B612A5040
7218	Беринговский район	\N	42	171.36209400000001	179.62779800000001	64.433396999999999	61.808397999999997	0103000020E610000001000000050000007E022846966B65406E13EE9579E74E407E022846966B6540CF4BC5C6BC1B5040D1CFD4EB16746640CF4BC5C6BC1B5040D1CFD4EB167466406E13EE9579E74E407E022846966B65406E13EE9579E74E40
1682	Анадырский район	\N	42	165.305194	179.75699399999999	68.272299000000004	62.253399000000002	0103000020E61000000100000005000000EF1D3526C4A9644068EBE0606F204F40EF1D3526C4A96440F2EEC8586D11514095287B4B39786640F2EEC8586D11514095287B4B3978664068EBE0606F204F40EF1D3526C4A9644068EBE0606F204F40
7534	район имени Лазо 	\N	37	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
7003	имени Лазо	\N	37	135.07719	135.09385399999999	48.509652000000003	48.499546000000002	0103000020E6100000010000000500000081B2295778E260407F6C921FF13F484081B2295778E26040A62BD8463C41484029931ADA00E36040A62BD8463C41484029931ADA00E360407F6C921FF13F484081B2295778E260407F6C921FF13F4840
7082	Центральный район	\N	37	134.89181400000001	135.11669800000001	48.506638000000002	48.434173000000001	0103000020E61000000100000005000000AE8383BD89DC604032E719FB92374840AE8383BD89DC604097749483D940484047B071FDBBE3604097749483D940484047B071FDBBE3604032E719FB92374840AE8383BD89DC604032E719FB92374840
249	Хабаровский район	\N	37	132.760291	136.23359099999999	50.577095999999997	48.075595999999997	0103000020E610000001000000050000002E8ECA4D54986040ADDA3521AD0948402E8ECA4D5498604082531F48DE4949407A34D5937907614082531F48DE4949407A34D59379076140ADDA3521AD0948402E8ECA4D54986040ADDA3521AD094840
65	Ульчский район	\N	37	137.44999999999999	141.18033500000001	53.570599999999999	50.820295000000002	0103000020E6100000010000000500000066666666662E61404209336DFF68494066666666662E61407E8CB96B09C94A4060EAE74DC5A561407E8CB96B09C94A4060EAE74DC5A561404209336DFF68494066666666662E61404209336DFF684940
1919	Тугуро-Чумиканский район	\N	37	130.388092	139.64618300000001	55.333671000000002	52.708596	0103000020E61000000100000005000000DBFAE93F6B4C6040C8091346B35A4A40DBFAE93F6B4C6040D34F38BBB5AA4B406687F887AD746140D34F38BBB5AA4B406687F887AD746140C8091346B35A4A40DBFAE93F6B4C6040C8091346B35A4A40
673	Солнечный район	\N	37	134.21499600000001	138.11319900000001	52.368796000000003	50.373199	0103000020E61000000100000005000000AB984A3FE1C6604030F31DFCC42F4940AB984A3FE1C66040A47213B5342F4A40145E82539F436140A47213B5342F4A40145E82539F43614030F31DFCC42F4940AB984A3FE1C6604030F31DFCC42F4940
652	Советско-Гаванский район	\N	37	138.15909400000001	140.39017699999999	49.099297999999997	47.390687	0103000020E61000000100000005000000ADDF4C4C1745614076FC170802B24740ADDF4C4C174561407347FFCBB58C4840D8D479547C8C61407347FFCBB58C4840D8D479547C8C614076FC170802B24740ADDF4C4C1745614076FC170802B24740
7076	Охотский район	\N	37	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
911	Николаевский район	\N	37	138.73109600000001	141.54502400000001	54.358401999999998	51.755795999999997	0103000020E6100000010000000500000091477023655761404B395FECBDE0494091477023655761401669E21DE02D4B4020F12BD670B161401669E21DE02D4B4020F12BD670B161404B395FECBDE0494091477023655761404B395FECBDE04940
1843	Нанайский район	\N	37	135.13879600000001	138.81359800000001	49.996597999999999	48.199094000000002	0103000020E610000001000000050000001A1A4F0471E46040386A85E97B1948401A1A4F0471E4604027A1F48590FF4840EA42ACFE085A614027A1F48590FF4840EA42ACFE085A6140386A85E97B1948401A1A4F0471E46040386A85E97B194840
7080	Краснофлотский район	\N	37	134.97636299999999	135.18267	48.599291000000001	48.516928	0103000020E61000000100000005000000C8409E5D3EDF60407F315BB22A424840C8409E5D3EDF6040C1E44691B54C4840BB7EC16ED8E56040C1E44691B54C4840BB7EC16ED8E560407F315BB22A424840C8409E5D3EDF60407F315BB22A424840
620	Комсомольский район	\N	37	136.19049899999999	139.418496	51.444999000000003	49.395094999999998	0103000020E6100000010000000500000076DD5B911806614014E8137992B2484076DD5B911806614059E02BBAF5B849403830B951646D614059E02BBAF5B849403830B951646D614014E8137992B2484076DD5B911806614014E8137992B24840
7079	Кировский район	\N	37	134.943296	135.071405	48.524191000000002	48.469448	0103000020E6100000010000000500000053CE177B2FDE604018963FDF163C484053CE177B2FDE6040C4EDD0B018434840AB7823F348E26040C4EDD0B018434840AB7823F348E2604018963FDF163C484053CE177B2FDE604018963FDF163C4840
1885	Имени Полины Осипенко район	\N	37	136.467602	136.515366	52.435225000000003	52.408302999999997	0103000020E610000001000000050000006A317898F60E6140E9EDCF4543344A406A317898F60E614068B3EA73B5374A400D6FD6E07D10614068B3EA73B5374A400D6FD6E07D106140E9EDCF4543344A406A317898F60E6140E9EDCF4543344A40
661	Имени Лазо район	\N	37	134.54383300000001	138.08331200000001	48.948894000000003	46.764037999999999	0103000020E610000001000000050000008AAF761467D160405C7347FFCB6147408AAF761467D1604071AFCC5B75794840A96BED7DAA42614071AFCC5B75794840A96BED7DAA4261405C7347FFCB6147408AAF761467D160405C7347FFCB614740
658	Вяземский район	\N	37	134.14946399999999	135.46209099999999	47.831797999999999	47.130308999999997	0103000020E61000000100000005000000BDFDB968C8C46040EEAF1EF7AD904740BDFDB968C8C4604069705B5B78EA4740D4981073C9EE604069705B5B78EA4740D4981073C9EE6040EEAF1EF7AD904740BDFDB968C8C46040EEAF1EF7AD904740
948	Верхнебуреинский район	\N	37	130.644543	135.08009100000001	52.683720000000001	49.211694000000001	0103000020E61000000100000005000000B43BA418A05460403561FBC9189B4840B43BA418A054604081CF0F2384574A408736001B90E2604081CF0F2384574A408736001B90E260403561FBC9189B4840B43BA418A05460403561FBC9189B4840
654	Ванинский район	\N	37	138.453292	140.68714199999999	51.056097000000001	48.868794999999999	0103000020E610000001000000050000003B71395E814E6140D3F6AFAC346F48403B71395E814E6140AD33BE2F2E874940A8363811FD956140AD33BE2F2E874940A8363811FD956140D3F6AFAC346F48403B71395E814E6140D3F6AFAC346F4840
1283	Бикинский район	\N	37	134.009964	134.86629199999999	47.302995000000003	46.638581000000002	0103000020E6100000010000000500000065C405A051C060406A6CAF05BD51474065C405A051C06040FFEC478AC8A647402A1900AAB8DB6040FFEC478AC8A647402A1900AAB8DB60406A6CAF05BD51474065C405A051C060406A6CAF05BD514740
7081	Аяно-Майский район	\N	37	130.38620499999999	141.54637199999999	55.333671000000002	46.638581000000002	0103000020E61000000100000005000000A79196CA5B4C60406A6CAF05BD514740A79196CA5B4C6040D34F38BBB5AA4B4067EE21E17BB16140D34F38BBB5AA4B4067EE21E17BB161406A6CAF05BD514740A79196CA5B4C60406A6CAF05BD514740
864	Амурский район	\N	37	134.40629200000001	137.42139800000001	50.572198999999998	48.573998000000003	0103000020E610000001000000050000000C94145800CD604016FC36C4784948400C94145800CD6040E6E61BD13D4949403293A8177C2D6140E6E61BD13D4949403293A8177C2D614016FC36C4784948400C94145800CD604016FC36C478494840
7375	городской округ Южно-Сахалинск	\N	40	142.440393	142.88439399999999	47.193600000000004	46.827095	0103000020E61000000100000005000000658C0FB317CE6140B2D7BB3FDE694740658C0FB317CE6140B84082E2C7984740EA58A5F44CDC6140B84082E2C7984740EA58A5F44CDC6140B2D7BB3FDE694740658C0FB317CE6140B2D7BB3FDE694740
7532	Южно-Курильский район	\N	40	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
1749	Холмский район	\N	40	141.94359800000001	142.519193	47.632323	46.818998999999998	0103000020E6100000010000000500000046D26EF431BE6140753A90F5D468474046D26EF431BE61401AC1C6F5EFD04740FD69A33A9DD061401AC1C6F5EFD04740FD69A33A9DD06140753A90F5D468474046D26EF431BE6140753A90F5D4684740
1715	Углегорский район	\N	40	141.847702	142.57529299999999	49.816695000000003	48.573645999999997	0103000020E610000001000000050000001FD8F15F20BB614098BD6C3B6D4948401FD8F15F20BB614043E7357689E84840C493DDCC68D2614043E7357689E84840C493DDCC68D2614098BD6C3B6D4948401FD8F15F20BB614098BD6C3B6D494840
1694	Тымовский район	\N	40	142.23749900000001	143.317993	51.527493999999997	50.295797	0103000020E61000000100000005000000A6BA809799C76140A1A014ADDC254940A6BA809799C76140096B63EC84C349406CEBA7FF2CEA6140096B63EC84C349406CEBA7FF2CEA6140A1A014ADDC254940A6BA809799C76140A1A014ADDC254940
1679	Томаринский район	\N	40	141.94258199999999	142.49039300000001	48.777797999999997	47.494297000000003	0103000020E610000001000000050000008BF9B9A129BE614066C1C41F45BF47408BF9B9A129BE6140757286E28E634840FF25A94CB1CF6140757286E28E634840FF25A94CB1CF614066C1C41F45BF47408BF9B9A129BE614066C1C41F45BF4740
1662	Смирныховский район	\N	40	142.131058	143.997344	50.379496000000003	49.465397000000003	0103000020E6100000010000000500000022FC8BA031C461400954FF2092BB484022FC8BA031C461403E7B2E539330494094DBF63DEAFF61403E7B2E539330494094DBF63DEAFF61400954FF2092BB484022FC8BA031C461400954FF2092BB4840
1617	Поронайский район	\N	40	142.48209299999999	144.74737400000001	49.966197999999999	48.501294999999999	0103000020E610000001000000050000002D944C4E6DCF6140FC523F6F2A4048402D944C4E6DCF6140F5BA4560ACFB48402FFCE07CEA176240F5BA4560ACFB48402FFCE07CEA176240FC523F6F2A4048402D944C4E6DCF6140FC523F6F2A404840
1431	Охинский район	\N	40	141.628828	143.32529600000001	54.424470999999997	51.893394999999998	0103000020E61000000100000005000000E4D9E55B1FB4614078B471C45AF24940E4D9E55B1FB46140DA8CD31055364B40A13028D368EA6140DA8CD31055364B40A13028D368EA614078B471C45AF24940E4D9E55B1FB4614078B471C45AF24940
1511	Ногликский район	\N	40	142.23149900000001	143.91088099999999	52.958232000000002	50.024298000000002	0103000020E61000000100000005000000D141977068C76140DAAD65321C034940D141977068C7614087FD9E58A77A4A408731E9EF25FD614087FD9E58A77A4A408731E9EF25FD6140DAAD65321C034940D141977068C76140DAAD65321C034940
1534	Невельский район	\N	40	141.21089599999999	142.119595	46.84684	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA66140EA78CC40656C47407CB8E4B8D3C36140EA78CC40656C47407CB8E4B8D3C361400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
1516	Макаровский район	\N	40	142.35379499999999	142.98661300000001	48.994798000000003	47.961598000000002	0103000020E61000000100000005000000A04FE44952CB614013F3ACA415FB4740A04FE44952CB61402810768A557F4840DF196D5592DF61402810768A557F4840DF196D5592DF614013F3ACA415FB4740A04FE44952CB614013F3ACA415FB4740
7533	Курильский район	\N	40	141.21089599999999	144.74737400000001	54.424655000000001	45.892699	0103000020E610000001000000050000006EDBF7A8BFA661400116F9F543F246406EDBF7A8BFA661409C8A54185B364B402FFCE07CEA1762409C8A54185B364B402FFCE07CEA1762400116F9F543F246406EDBF7A8BFA661400116F9F543F24640
1440	Корсаковский район	\N	40	142.67359500000001	143.61489499999999	47.147894999999998	46.021090000000001	0103000020E61000000100000005000000F9F719178ED56140E622BE13B3024740F9F719178ED56140F71E2E39EE9247402A6F4738ADF36140F71E2E39EE9247402A6F4738ADF36140E622BE13B3024740F9F719178ED56140E622BE13B3024740
1394	Долинский район	\N	40	142.22589300000001	143.043001	48.005799000000003	47.117187999999999	0103000020E61000000100000005000000A7ECF4833AC76140E8BD3104008F4740A7ECF4833AC76140BDAC8905BE0048404016A24360E16140BDAC8905BE0048404016A24360E16140E8BD3104008F4740A7ECF4833AC76140E8BD3104008F4740
1356	Анивский район	\N	40	142.000497	142.899899	47.202894999999998	45.894136000000003	0103000020E61000000100000005000000E0D7481204C061409016670C73F24640E0D7481204C06140CEC29E76F899474080D6FCF8CBDC6140CEC29E76F899474080D6FCF8CBDC61409016670C73F24640E0D7481204C061409016670C73F24640
1314	Александровск-Сахалинский район	\N	40	141.627894	142.49239600000001	51.979599	50.158797999999997	0103000020E61000000100000005000000596B28B517B46140C9552C7E53144940596B28B517B46140DF18028063FD4940CD9541B5C1CF6140DF18028063FD4940CD9541B5C1CF6140C9552C7E53144940596B28B517B46140C9552C7E53144940
255	Хангаласский район	\N	34	124.434498	130.3169	62.006096999999997	60.552097000000003	0103000020E610000001000000050000005B0BB3D0CE1B5F40209C4F1DAB464E405B0BB3D0CE1B5F4046CD57C9C7004F404703780B244A604046CD57C9C7004F404703780B244A6040209C4F1DAB464E405B0BB3D0CE1B5F40209C4F1DAB464E40
567	городской округ Якутск	\N	34	128.46149299999999	130.06049400000001	62.420799000000002	61.745297999999998	0103000020E61000000100000005000000A7CAF78CC40E604019E3C3EC65DF4E40A7CAF78CC40E60404298DBBDDC354F4056F31C91EF4160404298DBBDDC354F4056F31C91EF41604019E3C3EC65DF4E40A7CAF78CC40E604019E3C3EC65DF4E40
117	городской округ Нерюнгри	\N	34	124.000989	131.00103899999999	58.566597999999999	55.489896000000002	0103000020E61000000100000005000000F8A92A3410005F407A3881E9B4BE4B40F8A92A3410005F4050FD834886484D40A8E0F0820860604050FD834886484D40A8E0F082086060407A3881E9B4BE4B40F8A92A3410005F407A3881E9B4BE4B40
7374	Якутск	\N	34	129.593334	129.81023300000001	62.10642	61.949759999999998	0103000020E610000001000000050000005BB39597FC326040448655BC91F94E405BB39597FC326040F6D1A92B9F0D4F407BA4C16DED396040F6D1A92B9F0D4F407BA4C16DED396040448655BC91F94E405BB39597FC326040448655BC91F94E40
7538	Эвено-Бытантайский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7314	Чурапчинский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7540	Усть-Янский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7334	Усть-Майский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
240	Усть-Алданский район	\N	34	129.981595	131.00099399999999	62.667129000000003	62.376997000000003	0103000020E6100000010000000500000059DDEA39693F604056D80C7041304F4059DDEA39693F60404A9BAA7B64554F40C0AF9124086060404A9BAA7B64554F40C0AF91240860604056D80C7041304F4059DDEA39693F604056D80C7041304F40
7371	Томпонский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7366	Таттинский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7367	Сунтарский район,	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7316	Сунтарский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7537	Среднеколымский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7362	Оленекский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
200	Олекминский район	\N	34	124.006029	127.97049199999999	61.434165999999998	59.560788000000002	0103000020E61000000100000005000000F77475C762005F40A0FEB3E6C7C74D40F77475C762005F407F8461C092B74E40E5417A8A1CFE5F407F8461C092B74E40E5417A8A1CFE5F40A0FEB3E6C7C74D40F77475C762005F40A0FEB3E6C7C74D40
7315	Оймяконский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7368	Нюрбинский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7361	Нижнеколымский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
6894	Нерюнгринский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
1301	Намский район	\N	34	127.924498	130.263666	62.667146000000002	62.297699999999999	0103000020E61000000100000005000000EACDA8F92AFB5F4075029A081B264F40EACDA8F92AFB5F4020D4450A65554F4026E2ADF36F48604020D4450A65554F4026E2ADF36F48604075029A081B264F40EACDA8F92AFB5F4075029A081B264F40
7336	Момский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7352	Мирнинский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
496	Мегино-Кангаласский район	\N	34	129.57499999999999	130.999045	62.456595999999998	60.834598	0103000020E6100000010000000500000066666666663260404CA7751BD46A4E40666666666632604001BEDBBC713A4F406F47382DF85F604001BEDBBC713A4F406F47382DF85F60404CA7751BD46A4E4066666666663260404CA7751BD46A4E40
7329	Ленский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
5322	Ковылкинский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7326	Кобяйский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7317	Жиганский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
1114	Горный район	\N	34	124.001034	128.640896	62.667183000000001	61.194400000000002	0103000020E61000000100000005000000C80BE9F010005F40D42B6519E2984E40C80BE9F010005F403DB9A64066554F4064045438821460403DB9A64066554F406404543882146040D42B6519E2984E40C80BE9F010005F40D42B6519E2984E40
7332	Вилюйский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7327	Верхоянский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7328	Верхнеколымский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7330	Верхневилюйский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7363	Булунский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7539	Анабарский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
299	Амгинский район	\N	34	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
7536	Аллаиховский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
159	Алданский район	\N	34	124.00793299999999	130.998389	61.020598999999997	56.880198999999998	0103000020E61000000100000005000000C9E369F981005F40677C5F5CAA704C40C9E369F981005F4047AAEFFCA2824E40F5F57CCDF25F604047AAEFFCA2824E40F5F57CCDF25F6040677C5F5CAA704C40C9E369F981005F40677C5F5CAA704C40
7333	Абыйский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7364	 Чурапчинский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7331	 Кобяйский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7372	 Амгинский район	\N	34	128.83450099999999	130.99650299999999	61.393825	59.771295000000002	0103000020E6100000010000000500000056EF703BB41A6040BF4868CBB9E24D4056EF703BB41A604071AC8BDB68B24E40B56B425AE35F604071AC8BDB68B24E40B56B425AE35F6040BF4868CBB9E24D4056EF703BB41A6040BF4868CBB9E24D40
7335	 Абыйский район	\N	34	124.000873	131.00129100000001	62.667183000000001	55.486274999999999	0103000020E61000000100000005000000C39CA04D0E005F4063EE5A423EBE4B40C39CA04D0E005F403DB9A64066554F40EF586C930A6060403DB9A64066554F40EF586C930A60604063EE5A423EBE4B40C39CA04D0E005F4063EE5A423EBE4B40
7435	 Уссурийск	\N	36	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
7438	Уссурийск	\N	36	131.87554	132.07607999999999	43.849141000000003	43.755231000000002	0103000020E61000000100000005000000E04A766C047C604073F6CE68ABE04540E04A766C047C6040AC58FCA6B0EC454026FC523F6F826040AC58FCA6B0EC454026FC523F6F82604073F6CE68ABE04540E04A766C047C604073F6CE68ABE04540
7436	 Находка	\N	36	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
7437	Находка	\N	36	132.84098700000001	132.98674700000001	42.858986999999999	42.748972000000002	0103000020E610000001000000050000008FAB915DE99A604053CF8250DE5F45408FAB915DE99A604036583849F36D4540A3CD716E939F604036583849F36D4540A3CD716E939F604053CF8250DE5F45408FAB915DE99A604053CF8250DE5F4540
7355	Лесозаводск	\N	36	133.325987	133.462118	45.510340999999997	45.438733999999997	0103000020E610000001000000050000007AFD497C6EAA604056D28A6F28B846407AFD497C6EAA60406A6798DA52C14640931CB0ABC9AE60406A6798DA52C14640931CB0ABC9AE604056D28A6F28B846407AFD497C6EAA604056D28A6F28B84640
7358	остров Русский	\N	36	131.74581499999999	131.93778499999999	43.062857999999999	42.944636000000003	0103000020E61000000100000005000000B83B6BB7DD776040E84F1BD5E9784540B83B6BB7DD7760405F251FBB0B884540BD35B055027E60405F251FBB0B884540BD35B055027E6040E84F1BD5E9784540B83B6BB7DD776040E84F1BD5E9784540
1203	городской округ Партизанск	\N	36	132.82039700000001	133.294995	43.481295000000003	43.009897000000002	0103000020E61000000100000005000000929735B1409A60400DAA0D4E44814540929735B1409A60403A5D16139BBD454079AF5A9970A960403A5D16139BBD454079AF5A9970A960400DAA0D4E44814540929735B1409A60400DAA0D4E44814540
7357	городской округ Находка	\N	36	132.53489500000001	133.00569300000001	42.998998999999998	42.737496999999998	0103000020E6100000010000000500000068791EDC1D916040F5F23B4D665E454068791EDC1D9160404CDE0033DF7F45401E1A16A32EA060404CDE0033DF7F45401E1A16A32EA06040F5F23B4D665E454068791EDC1D916040F5F23B4D665E4540
7354	городской округ Лесозаводск	\N	36	133.37516099999999	133.46794800000001	45.513890000000004	45.455592000000003	0103000020E610000001000000050000008237A45101AC6040DD28B2D650BA46408237A45101AC6040E8DEC325C7C146405187156EF9AE6040E8DEC325C7C146405187156EF9AE6040DD28B2D650BA46408237A45101AC6040DD28B2D650BA4640
140	Шкотовский район	\N	36	132.273278	133.22214199999999	43.734839999999998	42.773085999999999	0103000020E61000000100000005000000EC1681B1BE8860406B7F677BF4624540EC1681B1BE88604075E5B33C0FDE45402D228AC91BA7604075E5B33C0FDE45402D228AC91BA760406B7F677BF4624540EC1681B1BE8860406B7F677BF4624540
594	Черниговский район	\N	36	132.30109899999999	132.90669800000001	44.566799000000003	43.981892999999999	0103000020E6100000010000000500000077BB5E9AA2896040EE9579ABAEFD454077BB5E9AA2896040E833A0DE8C484640282B86AB039D6040E833A0DE8C484640282B86AB039D6040EE9579ABAEFD454077BB5E9AA2896040EE9579ABAEFD4540
1753	Хорольский район	\N	36	131.75099800000001	132.51599400000001	44.633097999999997	44.069893999999998	0103000020E61000000100000005000000912BF52C08786040E3175E49F2084640912BF52C08786040DD94F25A09514640D55DD90583906040DD94F25A09514640D55DD90583906040E3175E49F2084640912BF52C08786040E3175E49F2084640
1724	Хасанский район	\N	36	130.597049	131.767563	43.429001	42.293455999999999	0103000020E61000000100000005000000812381061B536040516859F78F254540812381061B536040C4793881E9B64540D4D347E08F786040C4793881E9B64540D4D347E08F786040516859F78F254540812381061B536040516859F78F254540
750	Ханкайский район	\N	36	131.47622999999999	132.25408999999999	45.339756000000001	44.536794999999998	0103000020E61000000100000005000000F86BB2463D6F604002D4D4B2B5444640F86BB2463D6F6040554FE61F7DAB4640B3075A8121886040554FE61F7DAB4640B3075A812188604002D4D4B2B5444640F86BB2463D6F604002D4D4B2B5444640
7359	Фрунзенский район,	\N	36	131.84038899999999	131.90227400000001	43.140827999999999	43.072816000000003	0103000020E6100000010000000500000061DD7877E47A60401250E1085289454061DD7877E47A6040382EE3A606924540FF40B96DDF7C6040382EE3A606924540FF40B96DDF7C60401250E1085289454061DD7877E47A60401250E10852894540
1637	Уссурийский район	\N	36	131.19439299999999	132.49319499999999	44.005000000000003	43.455942	0103000020E610000001000000050000004832AB7738666040B96FB54E5CBA45404832AB7738666040713D0AD7A30046409F71E140C88F6040713D0AD7A30046409F71E140C88F6040B96FB54E5CBA45404832AB7738666040B96FB54E5CBA4540
1455	Тернейский район	\N	36	135.806299	139.01091299999999	48.459895000000003	44.528795000000002	0103000020E6100000010000000500000085798F33CDF96040E8A4F78DAF43464085798F33CDF96040064CE0D6DD3A48403D43386659606140064CE0D6DD3A48403D43386659606140E8A4F78DAF43464085798F33CDF96040E8A4F78DAF434640
616	Спасский район	\N	36	132.38709499999999	133.569197	45.151899999999998	44.343494	0103000020E610000001000000050000003EAE0D15638C6040A52F849CF72B46403EAE0D15638C604096218E7571934640677FA0DC36B2604096218E7571934640677FA0DC36B26040A52F849CF72B46403EAE0D15638C6040A52F849CF72B4640
668	Пожарский район	\N	36	133.80609200000001	137.872693	47.307338999999999	46.053598000000001	0103000020E6100000010000000500000027327381CBB96040C5909C4CDC06474027327381CBB9604086E464E256A7474057CEDE19ED3B614086E464E256A7474057CEDE19ED3B6140C5909C4CDC06474027327381CBB96040C5909C4CDC064740
1251	Пограничный район	\N	36	130.95899800000001	131.942294	44.986494	44.218898000000003	0103000020E61000000100000005000000BEDD921CB05E6040759483D9041C4640BEDD921CB05E6040A1D9756F457E4640F226BF45277E6040A1D9756F457E4640F226BF45277E6040759483D9041C4640BEDD921CB05E6040759483D9041C4640
738	Партизанский район	\N	36	132.50149500000001	133.75279499999999	43.821798000000001	42.679794000000001	0103000020E6100000010000000500000071033E3F0C9060402E02637D0357454071033E3F0C90604088F546AD30E94540F4328AE516B8604088F546AD30E94540F4328AE516B860402E02637D0357454071033E3F0C9060402E02637D03574540
1029	Ольгинский район	\N	36	134.12889200000001	135.63139699999999	44.185597999999999	43.202697999999998	0103000020E61000000100000005000000EA961DE21FC46040787B1002F2994540EA961DE21FC46040FC19DEACC11746405C397B6734F46040FC19DEACC11746405C397B6734F46040787B1002F2994540EA961DE21FC46040787B1002F2994540
454	Октябрьский район	\N	36	131.24129400000001	131.8289	44.308394999999997	43.861894999999997	0103000020E6100000010000000500000013D731AEB8676040FFCA4A9352EE454013D731AEB8676040FD9FC37C79274640F1F44A59867A6040FD9FC37C79274640F1F44A59867A6040FFCA4A9352EE454013D731AEB8676040FFCA4A9352EE4540
579	Надеждинский район	\N	36	131.384063	132.06049400000001	43.662703999999998	43.274470000000001	0103000020E6100000010000000500000051137D3E4A6C6040D7DD3CD521A3454051137D3E4A6C6040D576137CD3D4454056F31C91EF816040D576137CD3D4454056F31C91EF816040D7DD3CD521A3454051137D3E4A6C6040D7DD3CD521A34540
410	Михайловский район	\N	36	131.795896	132.87179900000001	44.299298999999998	43.586196999999999	0103000020E610000001000000050000008D60E3FA77796040B401D88008CB45408D60E3FA77796040DD5CFC6D4F264640F03504C7E59B6040DD5CFC6D4F264640F03504C7E59B6040B401D88008CB45408D60E3FA77796040B401D88008CB4540
147	Лесозаводский район	\N	36	133.09159	134.10159300000001	45.824592000000003	45.197698000000003	0103000020E6100000010000000500000080D4264EEEA26040083E062B4E99464080D4264EEEA2604089450C3B8CE946401590F63F40C3604089450C3B8CE946401590F63F40C36040083E062B4E99464080D4264EEEA26040083E062B4E994640
651	Лазовский район	\N	36	133.18859	134.50399300000001	43.644598000000002	42.765799000000001	0103000020E61000000100000005000000494BE5ED08A660409E279EB305624540494BE5ED08A660409488F02F82D24540378DEDB520D060409488F02F82D24540378DEDB520D060409E279EB305624540494BE5ED08A660409E279EB305624540
646	Красноармейский район	\N	36	134.00109800000001	136.76180099999999	46.542893999999997	44.984797999999998	0103000020E61000000100000005000000EA42ACFE08C06040469561DC0D7E4640EA42ACFE08C06040E998F38C7D454740ECA17DAC60186140E998F38C7D454740ECA17DAC60186140469561DC0D7E4640EA42ACFE08C06040469561DC0D7E4640
517	Кировский район	\N	36	133.08749299999999	134.26369399999999	45.276696999999999	44.654800000000002	0103000020E6100000010000000500000020B41EBECCA26040DDB5847CD053464020B41EBECCA260405EF3AACE6AA34640D844662E70C860405EF3AACE6AA34640D844662E70C86040DDB5847CD053464020B41EBECCA26040DDB5847CD0534640
1829	Кавалеровский район	\N	36	134.43719400000001	135.70129399999999	44.684396	43.952294999999999	0103000020E610000001000000050000003D80457EFDCD6040799274CDE4F945403D80457EFDCD6040B1C1C2499A574640315C1D0071F66040B1C1C2499A574640315C1D0071F66040799274CDE4F945403D80457EFDCD6040799274CDE4F94540
71	Дальнереченский район	\N	36	133.459261	135.14499499999999	46.228467000000002	44.961095999999998	0103000020E6100000010000000500000081EA1F44B2AE604080289831057B464081EA1F44B2AE60408D9B1A683E1D4740ACE28DCCA3E460408D9B1A683E1D4740ACE28DCCA3E4604080289831057B464081EA1F44B2AE604080289831057B4640
701	Дальнегорский район	\N	36	134.91379499999999	136.18839700000001	45.162793999999998	44.214995000000002	0103000020E61000000100000005000000F20703CF3DDD6040DAE6C6F4841B4640F20703CF3DDD604015FE0C6FD6944640443525590706614015FE0C6FD69446404435255907066140DAE6C6F4841B4640F20703CF3DDD6040DAE6C6F4841B4640
125	Артем городской округ	\N	36	132.125281	132.38187600000001	43.459947	43.278599	0103000020E61000000100000005000000EDB94C4D0284604062D9CC21A9A34540EDB94C4D028460405872158BDFBA454013640454388C60405872158BDFBA454013640454388C604062D9CC21A9A34540EDB94C4D0284604062D9CC21A9A34540
1169	Анучинский район	\N	36	132.703194	133.435294	44.472693999999997	43.382098999999997	0103000020E61000000100000005000000CA17B49080966040CA6ABA9EE8B04540CA17B49080966040F981AB3C813C4640A4C4AEEDEDAD6040F981AB3C813C4640A4C4AEEDEDAD6040CA6ABA9EE8B04540CA17B49080966040CA6ABA9EE8B04540
1922	Ягоднинский район	\N	39	148.18719400000001	152.37540100000001	63.629600000000003	61.273898000000003	0103000020E610000001000000050000003D80457EFD8562404C38F4160FA34E403D80457EFD856240E3C798BB96D04F40583CF548030C6340E3C798BB96D04F40583CF548030C63404C38F4160FA34E403D80457EFD8562404C38F4160FA34E40
101	Хасынский район	\N	39	150.24689599999999	153.506191	62.089896000000003	59.829096999999997	0103000020E610000001000000050000006CB07092E6C76240191BBAD91FEA4D406CB07092E6C7624047054EB6810B4F40F2D077B73230634047054EB6810B4F40F2D077B732306340191BBAD91FEA4D406CB07092E6C76240191BBAD91FEA4D40
1914	Тенькинский район	\N	39	146.09569200000001	151.218999	62.501299000000003	60.403796	0103000020E61000000100000005000000A54FABE80F436240B8205B96AF334E40A54FABE80F4362403E42CD902A404F406ADB300A02E762403E42CD902A404F406ADB300A02E76240B8205B96AF334E40A54FABE80F436240B8205B96AF334E40
1905	Сусуманский район	\N	39	144.72429700000001	151.76129399999999	64.557900000000004	61.951295999999999	0103000020E61000000100000005000000E9F2E6702D17624066683C11C4F94E40E9F2E6702D1762400F9C33A2B423504083143C855CF862400F9C33A2B423504083143C855CF8624066683C11C4F94E40E9F2E6702D17624066683C11C4F94E40
1900	Среднеканский район	\N	39	150.83099000000001	159.390399	66.340896999999998	61.911098000000003	0103000020E61000000100000005000000B329577897DA6240BBB9F8DB9EF44E40B329577897DA62407D93A641D1955040842C0B267EEC63407D93A641D1955040842C0B267EEC6340BBB9F8DB9EF44E40B329577897DA6240BBB9F8DB9EF44E40
1893	Северо-Эвенский район	\N	39	156.807095	163.483698	65.652496999999997	60.579498000000001	0103000020E610000001000000050000007CB8E4B8D3996340780C8FFD2C4A4E407CB8E4B8D39963403DEFC682C269504080643A747A6F64403DEFC682C269504080643A747A6F6440780C8FFD2C4A4E407CB8E4B8D3996340780C8FFD2C4A4E40
1891	Омсукчанский район	\N	39	153.21739099999999	158.582292	65.036896999999996	60.936897000000002	0103000020E610000001000000050000003B6EF8DDF42663403A5CAB3DEC774E403B6EF8DDF426634083143C855C4250401E17D522A2D2634083143C855C4250401E17D522A2D263403A5CAB3DEC774E403B6EF8DDF42663403A5CAB3DEC774E40
62	Ольский район	\N	39	145.52749800000001	156.048396	61.305396999999999	58.834000000000003	0103000020E6100000010000000500000093567C43E1306240986E1283C06A4D4093567C43E1306240F4A5B73F17A74E403BA8C4758C816340F4A5B73F17A74E403BA8C4758C816340986E1283C06A4D4093567C43E1306240986E1283C06A4D40
1889	Усть-Камчатский район	\N	35	159.09459200000001	163.36289199999999	57.595799999999997	54.980797000000003	0103000020E61000000100000005000000D34ECDE506E36340E9818FC18A7D4B40D34ECDE506E36340787AA52C43CC4C405CFFAECF9C6B6440787AA52C43CC4C405CFFAECF9C6B6440E9818FC18A7D4B40D34ECDE506E36340E9818FC18A7D4B40
1873	Усть-Большерецкий район	\N	35	156.00669600000001	158.09539599999999	53.631497000000003	51.081696000000001	0103000020E6100000010000000500000073A087DA36806340651BB803758A494073A087DA36806340D542C9E4D4D04A406A85E97B0DC36340D542C9E4D4D04A406A85E97B0DC36340651BB803758A494073A087DA36806340651BB803758A4940
1898	Тигильский район	\N	35	155.63810000000001	162.25299699999999	60.055996	55.671900000000001	0103000020E610000001000000050000007CF2B0506B7463405917B7D100D64B407CF2B0506B746340795A7EE02A074E408E1F2A8D18486440795A7EE02A074E408E1F2A8D184864405917B7D100D64B407CF2B0506B7463405917B7D100D64B40
1884	Соболевский район	\N	35	155.54569900000001	157.829791	55.823596000000002	53.521399000000002	0103000020E61000000100000005000000B8CEBF5D767163406495D233BDC24A40B8CEBF5D76716340E78EFE976BE94B407CF0DAA58DBA6340E78EFE976BE94B407CF0DAA58DBA63406495D233BDC24A40B8CEBF5D767163406495D233BDC24A40
1920	Пенжинский район	\N	35	162.16619299999999	170.190699	64.947699999999998	60.522599999999997	0103000020E610000001000000050000005F7AFB7351456440DE718A8EE4424E405F7AFB7351456440D49AE61DA73C5040280CCA341A466540D49AE61DA73C5040280CCA341A466540DE718A8EE4424E405F7AFB7351456440DE718A8EE4424E40
1918	Олюторский район	\N	35	164.08439200000001	174.49339599999999	62.548397999999999	59.590699999999998	0103000020E610000001000000050000006901DA56B3826440A4DFBE0E9CCB4D406901DA56B38264408D98D9E731464F40457F68E6C9CF65408D98D9E731464F40457F68E6C9CF6540A4DFBE0E9CCB4D406901DA56B3826440A4DFBE0E9CCB4D40
1863	Мильковский район	\N	35	157.49579800000001	160.79719600000001	55.844900000000003	53.860497000000002	0103000020E61000000100000005000000836DC493DDAF63402FA704C424EE4A40836DC493DDAF6340F931E6AE25EC4B4011902FA182196440F931E6AE25EC4B4011902FA1821964402FA704C424EE4A40836DC493DDAF63402FA704C424EE4A40
1909	Карагинский район	\N	35	160.40369799999999	165.30489700000001	60.874097999999996	57.318797000000004	0103000020E61000000100000005000000BD6E1118EB0C64400E881057CEA84C40BD6E1118EB0C6440DFBF7971E26F4E40C1745AB7C1A96440DFBF7971E26F4E40C1745AB7C1A964400E881057CEA84C40BD6E1118EB0C64400E881057CEA84C40
1821	Елизовский район	\N	35	156.654597	162.15239500000001	55.177098000000001	50.863999999999997	0103000020E61000000100000005000000E9616875F29463403BDF4F8D976E4940E9616875F2946340F017B325AB964B405EA27A6BE0446440F017B325AB964B405EA27A6BE04464403BDF4F8D976E4940E9616875F29463403BDF4F8D976E4940
1879	Быстринский район	\N	35	156.15190000000001	159.647595	56.822896999999998	54.692396000000002	0103000020E610000001000000050000006688635DDC846340CCF09F6EA0584B406688635DDC846340FE7C5BB054694C40B3412619B9F46340FE7C5BB054694C40B3412619B9F46340CCF09F6EA0584B406688635DDC846340CCF09F6EA0584B40
1896	Алеутский район	\N	35	165.754594	168.109995	55.363697999999999	54.495297000000001	0103000020E6100000010000000500000040F850A225B86440496760E4653F4B4040F850A225B8644070CFF3A78DAE4B4027F73B148503654070CFF3A78DAE4B4027F73B1485036540496760E4653F4B4040F850A225B86440496760E4653F4B40
1601	Смидовичский район	\N	41	133.08859799999999	134.98523800000001	48.959685	48.101295999999998	0103000020E61000000100000005000000B60F79CBD5A26040999B6F44F70C4840B60F79CBD5A260401BBB44F5D67A4840D998D71187DF60401BBB44F5D67A4840D998D71187DF6040999B6F44F70C4840B60F79CBD5A26040999B6F44F70C4840
1645	Октябрьский район	\N	41	130.65350799999999	131.990354	48.646796999999999	47.654294	0103000020E6100000010000000500000094F59B89E954604009FCE1E7BFD3474094F59B89E954604051137D3ECA524840CF2EDFFAB07F604051137D3ECA524840CF2EDFFAB07F604009FCE1E7BFD3474094F59B89E954604009FCE1E7BFD34740
1543	Облученский район	\N	41	130.52173400000001	133.27749600000001	49.493721000000001	48.403897999999998	0103000020E61000000100000005000000C366800BB2506040BC75FEEDB2334840C366800BB2506040992CEE3F32BF4840AB984A3FE1A86040992CEE3F32BF4840AB984A3FE1A86040BC75FEEDB2334840C366800BB2506040BC75FEEDB2334840
1696	Ленинский район	\N	41	131.66949399999999	133.080792	48.557195999999998	47.690195000000003	0103000020E61000000100000005000000C85BAE7E6C7560406E6E4C4F58D84740C85BAE7E6C75604023BBD23252474840E9B81AD995A2604023BBD23252474840E9B81AD995A260406E6E4C4F58D84740C85BAE7E6C7560406E6E4C4F58D84740
1668	Биробиджанский район	\N	41	132.299994	133.34759199999999	48.960963	48.099556999999997	0103000020E61000000100000005000000E15F048D998960403F8BA548BE0C4840E15F048D9989604041D5E8D5007B48403D0B42791FAB604041D5E8D5007B48403D0B42791FAB60403F8BA548BE0C4840E15F048D998960403F8BA548BE0C4840
881	городской округ Райчихинск	\N	38	129.321495	129.70199500000001	49.853997	49.715997999999999	0103000020E610000001000000050000007BDAE1AF492A60402E008DD2A5DB48407BDAE1AF492A6040E9F010C64FED484094DE37BE76366040E9F010C64FED484094DE37BE763660402E008DD2A5DB48407BDAE1AF492A60402E008DD2A5DB4840
6892	городской округ Белогорск	\N	38	128.41360399999999	128.56582299999999	50.929189999999998	50.894581000000002	0103000020E61000000100000005000000D5AF743E3C0D6040BE4F55A181724940D5AF743E3C0D604097E2AAB2EF764940630AD6381B12604097E2AAB2EF764940630AD6381B126040BE4F55A181724940D5AF743E3C0D6040BE4F55A181724940
709	Шимановский район	\N	38	126.292035	128.66969599999999	52.930394999999997	51.243471	0103000020E61000000100000005000000649291B3B0925F402043C70E2A9F4940649291B3B0925F4053AEF02E17774A4062484E266E15604053AEF02E17774A4062484E266E1560402043C70E2A9F4940649291B3B0925F402043C70E2A9F4940
419	Тындинский район	\N	38	119.656153	128.14549299999999	57.053058999999998	53.859296999999998	0103000020E61000000100000005000000070B2769FEE95D408446B071FDED4A40070B2769FEE95D4015E126A3CA864C408099EFE0A704604015E126A3CA864C408099EFE0A70460408446B071FDED4A40070B2769FEE95D408446B071FDED4A40
243	Тамбовский район	\N	38	127.485671	128.53489400000001	50.302995000000003	49.751423000000003	0103000020E610000001000000050000006667D13B15DF5F402A3BFDA02EE048406667D13B15DF5F40FFEC478AC8264940749A05DA1D116040FFEC478AC8264940749A05DA1D1160402A3BFDA02EE048406667D13B15DF5F402A3BFDA02EE04840
37	Сковородинский район	\N	38	121.62669699999999	125.388994	54.541297	53.205095999999998	0103000020E6100000010000000500000015E0BBCD1B685E402C45F295409A4A4015E0BBCD1B685E402236583849454B40C6151747E5585F402236583849454B40C6151747E5585F402C45F295409A4A4015E0BBCD1B685E402C45F295409A4A40
1808	Серышевский район	\N	38	127.85669300000001	129.39259699999999	51.436095999999999	50.877198999999997	0103000020E61000000100000005000000946DE00ED4F65F40BD8A8C0E48704940946DE00ED4F65F404DF564FED1B749403F709527902C60404DF564FED1B749403F709527902C6040BD8A8C0E48704940946DE00ED4F65F40BD8A8C0E48704940
1025	Селемджинский район	\N	38	129.81029599999999	134.91729900000001	53.821097999999999	51.6098	0103000020E610000001000000050000008C82E0F1ED396040E78C28ED0DCE49408C82E0F1ED396040CF6740BD19E94A40EAB46E835ADD6040CF6740BD19E94A40EAB46E835ADD6040E78C28ED0DCE49408C82E0F1ED396040E78C28ED0DCE4940
700	Свободненский район	\N	38	126.892792	128.69869299999999	51.947696999999998	50.887262999999997	0103000020E6100000010000000500000059880E8123B95F40B5F97FD59171494059880E8123B95F4037C2A2224EF94940361E6CB15B16604037C2A2224EF94940361E6CB15B166040B5F97FD59171494059880E8123B95F40B5F97FD591714940
1030	Ромненский район	\N	38	128.488991	131.1953	51.392797000000002	50.355995999999998	0103000020E610000001000000050000003A2174D0A50F6040DFC0E446912D49403A2174D0A50F6040C47B0E2C47B24940151DC9E53F666040C47B0E2C47B24940151DC9E53F666040DFC0E446912D49403A2174D0A50F6040DFC0E446912D4940
978	Октябрьский район	\N	38	128.432298	129.530192	50.591394000000001	49.916699999999999	0103000020E610000001000000050000000A849D62D50D6040211FF46C56F548400A849D62D50D60407B8670CCB24B49403A933655F73060407B8670CCB24B49403A933655F7306040211FF46C56F548400A849D62D50D6040211FF46C56F54840
988	Михайловский район	\N	38	128.319299	129.41969900000001	50.092095999999998	49.351446000000003	0103000020E61000000100000005000000A85489B2370A6040AF27BA2EFCAC4840A85489B2370A6040D40B3ECDC90B49403FE5982C6E2D6040D40B3ECDC90B49403FE5982C6E2D6040AF27BA2EFCAC4840A85489B2370A6040AF27BA2EFCAC4840
1611	Мазановский район	\N	38	128.243697	131.49553499999999	53.379998000000001	51.062894999999997	0103000020E6100000010000000500000044A4A65DCC0760407C0A80F10C88494044A4A65DCC076040D04543C6A3B04A40BF60376CDB6F6040D04543C6A3B04A40BF60376CDB6F60407C0A80F10C88494044A4A65DCC0760407C0A80F10C884940
1578	Магдагачинский район	\N	38	124.578498	127.743694	54.122399999999999	52.300631000000003	0103000020E610000001000000050000004AB3791C06255F40F7949C137B264A404AB3791C06255F40E4839ECDAA0F4B40D00EB8AE98EF5F40E4839ECDAA0F4B40D00EB8AE98EF5F40F7949C137B264A404AB3791C06255F40F7949C137B264A40
810	Константиновский район	\N	38	127.669134	128.498998	49.968099000000002	49.534323999999998	0103000020E6100000010000000500000011A96917D3EA5F40E4BB94BA64C4484011A96917D3EA5F40292504ABEAFB48409F58A7CAF70F6040292504ABEAFB48409F58A7CAF70F6040E4BB94BA64C4484011A96917D3EA5F40E4BB94BA64C44840
1397	Ивановский район	\N	38	127.659998	128.610793	50.812998999999998	50.205694000000001	0103000020E610000001000000050000003A5B40683DEA5F40E17D552E541A49403A5B40683DEA5F402157EA591068494006F4C29D8B1360402157EA591068494006F4C29D8B136040E17D552E541A49403A5B40683DEA5F40E17D552E541A4940
1386	Зейский район	\N	38	125.61329499999999	132.97109900000001	55.783357000000002	52.671697000000002	0103000020E6100000010000000500000038F3AB3940675F4021E9D32AFA554A4038F3AB3940675F40DD0BCC0A45E44B40B5C5353E139F6040DD0BCC0A45E44B40B5C5353E139F604021E9D32AFA554A4038F3AB3940675F4021E9D32AFA554A40
966	Завитинский район	\N	38	129.01259200000001	130.17239699999999	50.628995000000003	49.772098	0103000020E610000001000000050000001F865627672060404CA7751BD4E248401F865627672060407C2C7DE882504940B69DB646844560407C2C7DE882504940B69DB646844560404CA7751BD4E248401F865627672060404CA7751BD4E24840
40	Бурейский район	\N	38	128.97909300000001	131.41859400000001	50.616897000000002	49.407364999999999	0103000020E61000000100000005000000C3D7D7BA541F60407C444C8924B44840C3D7D7BA541F604011001C7BF64E4940A9893E1F656D604011001C7BF64E4940A9893E1F656D60407C444C8924B44840C3D7D7BA541F60407C444C8924B44840
912	Благовещенский район	\N	38	127.15375299999999	127.920393	51.081797999999999	50.012323000000002	0103000020E610000001000000050000005CAAD216D7C95F408BFED0CC930149405CAAD216D7C95F4069705B5B788A4940E99D0AB8E7FA5F4069705B5B788A4940E99D0AB8E7FA5F408BFED0CC930149405CAAD216D7C95F408BFED0CC93014940
600	Белогорский район	\N	38	127.764391	129.17529400000001	51.017696000000001	50.588797999999997	0103000020E61000000100000005000000D5963AC8EBF05F40A0F99CBB5D4B4940D5963AC8EBF05F4090A2CEDC43824940ECA529029C25604090A2CEDC43824940ECA529029C256040A0F99CBB5D4B4940D5963AC8EBF05F40A0F99CBB5D4B4940
428	Архаринский район	\N	38	129.45439200000001	131.515693	50.263595000000002	48.854895999999997	0103000020E610000001000000050000000D7217618A2E604098BD6C3B6D6D48400D7217618A2E6040CF31207BBD214940D6389B8E80706040CF31207BBD214940D6389B8E8070604098BD6C3B6D6D48400D7217618A2E604098BD6C3B6D6D4840
\.


--
-- Data for Name: voting_station; Type: TABLE DATA; Schema: public; Owner: -
--

COPY voting_station (id, location_id, name, address, is_standalone, size) FROM stdin;
7434	38011	242	республика Калмыкия, поселок Яшкуль	f	medium
7216	37803	23	республика Калмыкия, Элиста, МОУ ДОД Дворец детского творчества, Парк культуры и отдыха Дружба	f	large
7195	37781	2	республика Калмыкия, Элиста, МОУ Начальная общеобразовательная школа №24СМП-334	f	small
7222	37810	29	республика Калмыкия, Элиста, микрорайон, 10, МОУ СОШ № 172	f	large
7197	37783	4	республика Калмыкия, Элиста, микрорайон, 1А, МОУ Начальная общеобразовательная школа №251	f	large
7228	37814	35	республика Калмыкия, Элиста, Хрущева, 19, МУП Октябрь	f	large
7227	37814	34	республика Калмыкия, Элиста, Хрущева, 19, МУП Октябрь	f	large
7202	37788	9	республика Калмыкия, Элиста, Хомутникова, 109А, МОУ Этнокультурная гимназия №8 имени Н.Очирова	f	large
7198	37784	5	республика Калмыкия, Элиста, Северный, отделение почтовой связи №15	f	small
7240	37823	47	республика Калмыкия, Элиста, С.Стальского , 6, МОУ Средняя общеобразовательная школа №3	f	large
7194	37780	1	республика Калмыкия, Элиста, Рокчинского, 7, МОУ СОШ №21Г	f	large
7239	37822	46	республика Калмыкия, Элиста, Пушкина, 3, ОУ Элистинский технический лицей	f	large
7224	37812	31	республика Калмыкия, Элиста, Пушкина, 5, ГГКУ Калмконцерт	f	large
7234	37806	41	республика Калмыкия, Элиста, Николаева, 55, МОУ РНГ	f	large
7233	37806	40	республика Калмыкия, Элиста, Николаева, 55, МОУ РНГ	f	large
7242	37825	49	республика Калмыкия, Элиста, Мира, 25, МОУ Начальная общеобразовательная школа №22	f	large
7237	37820	44	республика Калмыкия, Элиста, Лесная, 11, РГУ Элистинское лесничество	f	large
7236	37819	43	республика Калмыкия, Элиста, Ленина , 52, МОУ Средняя общеобразовательная школа №2	f	large
7235	37819	42	республика Калмыкия, Элиста, Ленина , 52, МОУ Средняя общеобразовательная школа №2	f	large
7218	37805	25	республика Калмыкия, Элиста, Ленина, 276, КРО Всероссийское добровольное пожарное общество	f	large
7215	37802	22	республика Калмыкия, Элиста, Ленина, 209, МОУ Калмыцкая национальная гимназия	f	medium
7212	37799	19	республика Калмыкия, Элиста, Ленина, 291, МОУ Калмыцкая национальная гимназия	f	large
7208	37795	15	республика Калмыкия, Элиста, Ленина, 237 А, ГОУ Калмыцкий медицинский колледж им.Т.Хахлыновой	f	large
7203	37789	10	республика Калмыкия, Элиста, Ленина, 10, Калмыцкое дорожное управление	f	large
7223	37811	30	республика Калмыкия, Элиста, Леваневского, 18, МОУ ДОД Детская школа искусств №1	f	large
7207	37794	14	республика Калмыкия, Элиста, Илишкина, 16, МОУ СОШ №4	f	large
7206	37793	13	республика Калмыкия, Элиста, Добровольского, 2, ГСУ СО Элистинский дом-интернат для престарелых и инвалидов	f	small
7211	37798	18	республика Калмыкия, Элиста, Губаревича, 14, МОУ ЦООД РК Элистинский лицей	f	medium
7241	37824	48	республика Калмыкия, Элиста, Гагарина, 34	f	large
7205	37791	12	республика Калмыкия, Элиста, Волгоградская, 59А, МОУ СОШ №23	f	large
7204	37790	11	республика Калмыкия, Элиста, Волгоградская, 59 А, МОУ СОШ №23	f	large
7231	37817	38	республика Калмыкия, Элиста, 8микрорайон, 21а, МОУ Элистинская многопрофильная гимназия	f	large
7230	37816	37	республика Калмыкия, Элиста, 8 микрорайон, 21а, МОУ Элистинская многопрофильная гимназия	f	large
7229	37815	36	республика Калмыкия, Элиста, 8 микрорайон, 19, МОУ Средняя общеобразовательная школа №18	f	large
7232	37792	39	республика Калмыкия, Элиста, 8 микрорайон, 67а, МУ ЦГБ им. А.С. Пушкина	f	large
7201	37787	8	республика Калмыкия, Элиста, 8 Марта, 26, ФГОУ СПО КГТЭК	f	large
7226	37813	33	республика Калмыкия, Элиста, 6 микрорайон, 18, Средняя общеобразовательная школа №20	f	large
7225	37813	32	республика Калмыкия, Элиста, 6 микрорайон, 18, Средняя общеобразовательная школа №20	f	large
7219	37807	26	республика Калмыкия, Элиста, 5 микрорайон, 3	f	large
7221	37809	28	республика Калмыкия, Элиста, 4 микрорайон, 51, МОУ Элистинская классическая гимназия	f	large
7220	37808	27	республика Калмыкия, Элиста, 3 мкр, 8, Вечерняя общеобразовательная школа №25	f	large
134534	94423	21	республика Калмыкия, Элиста, 3 микрорайон, 26, МБОУ СОШ №12	f	large
7200	37786	7	республика Калмыкия, Элиста, 28 Армии, 25, ГУ Государствен. калмыцкий ансамбль песни и танца Тюльпан	f	large
7217	37804	24	республика Калмыкия, Элиста, 2 микрорайон	f	large
155	14915	155	республика Адыгея, Майкоп, Комсомольская, 276	f	large
134533	94422	17	республика Калмыкия, Элиста, 1мкр, 8, МБОУ СОШ №10 им.Бембетова В.А	f	large
7209	37796	16	республика Калмыкия, Элиста, 1мкр, 8, МОУ СОШ №10	f	large
7196	37782	3	республика Калмыкия, Элиста, 1 микрорайон, 1А, МОУ Начальная общеобразовательная школа №25	f	large
7238	37821	45	республика Калмыкия, Элиста, Маяковского , 57, МУ Городская поликлиника	f	large
7302	37884	110	республика Калмыкия, Лагань, микрорайон, 60	f	small
7304	37886	112	республика Калмыкия, Лагань, Свердлова, 124	f	medium
7310	37893	118	республика Калмыкия, Лагань, Пришкольная, 3 а	f	medium
7313	37896	121	республика Калмыкия, Лагань, Колхозная, 44	f	small
7311	37894	119	республика Калмыкия, Лагань, Дружбы, 9	f	medium
7250	37833	58	республика Калмыкия, Городовиковск	f	large
7243	37826	51	республика Калмыкия, Городовиковск	f	large
7440	38017	248	Россия, республика Калмыкия, Яшкульский район, поселок Яшкуль	f	medium
7437	38014	245	республика Калмыкия, Яшкульский район, поселок Яшкуль, Ленина, 6	f	medium
7431	38007	239	республика Калмыкия, Яшкульский район, Яшкуль, Клыкова, 86	f	large
7430	38006	238	республика Калмыкия, Яшкульский район, поселок Яшкуль, Кирова, 16б	f	medium
7433	38010	241	республика Калмыкия, Яшкульский район, поселок городского типа Яшкуль, Лиджиева, 2	f	large
7432	38008	240	республика Калмыкия, Яшкульский район, поселок городского типа Яшкуль, Леджинова, 1	f	large
7445	38022	253	республика Калмыкия, Яшкульский район, село Элвг	f	small
7444	38021	252	республика Калмыкия, Яшкульский район, село Чилгир	f	medium
7443	38020	251	республика Калмыкия, Яшкульский район, село Цаган Усн	f	small
7442	38019	250	республика Калмыкия, Яшкульский район, село Хулхута	f	small
7441	38018	249	республика Калмыкия, Яшкульский район, село Хар Толга, Советская, 26 	f	small
7439	38016	247	республика Калмыкия, Яшкульский район, село Улан Эрге	f	medium
7438	38015	246	республика Калмыкия, Яшкульский район, село Тавн Гашун	f	small
7436	38013	244	республика Калмыкия, Яшкульский район, село Молодежный	f	small
7435	38012	243	республика Калмыкия, Яшкульский район, село Гашун, 60 лет Октября, 27	f	small
7429	38005	237	республика Калмыкия, Яшалтинский район, поселок городского типа Яшалта, переулок Школьный, 2	f	large
7428	38004	236	республика Калмыкия, Яшалтинский район, поселок Яшалта, Ленина, 10	f	large
7427	38003	235	республика Калмыкия, Яшалтинский район, село Эсто-Алтай, имени Карла Маркса, администрация СМО	f	medium
7426	38002	234	республика Калмыкия, Яшалтинский район, село Ульяновское, Школьная, 6	f	large
7425	38001	233	республика Калмыкия, Яшалтинский район, село Соленое, Ленина, 38	f	large
7421	37997	229	Россия, Сахалинская область, Поронайский район, село Матросово	f	small
7423	37999	231	республика Калмыкия, Яшалтинский район, село Манычский, Школьная, 2	f	medium
7422	37998	230	республика Калмыкия, Яшалтинский район, село Красный Партизан, столовая СПК Яшалтинский	f	small
7416	36352	224	республика Калмыкия, Яшалтинский район, село Красный Маныч, Центральная, 60	t	small
7418	37994	226	республика Калмыкия, Яшалтинский район, село Краснополье, Спортивный переулок, 11	f	small
7420	37996	228	республика Калмыкия, Яшалтинский район, село Красномихайловское, Школьная, 3	f	medium
7417	37993	225	республика Калмыкия, Яшалтинский район, село Березовское, Кооперативная, сельский Дом культуры	f	medium
7415	36281	223	республика Калмыкия, Яшалтинский район, село Бага Тугтун, Пионерская, 10	f	small
7408	37986	216	республика Калмыкия, Юстинский район, село Юста, сельский Дом культуры	f	small
7414	37992	222	республика Калмыкия, Юстинский район, село Эрдниевский, сельский Дом культуры	f	medium
7407	37985	215	Россия, республика Калмыкия, Юстинский район, село Чомпот	f	small
7403	37980	211	республика Калмыкия, Юстинский район, поселок Цаган Аман, переулок Мацакова, 5	f	medium
7402	37979	210	республика Калмыкия, Юстинский район, поселок Цаган Аман, Хомутникова, 5	f	medium
7405	37982	213	республика Калмыкия, Юстинский район, поселок Цаган Аман, Советская, 154	f	medium
7400	37977	208	республика Калмыкия, Юстинский район, поселок Цаган Аман, Кирова, 2	f	medium
7404	37981	212	республика Калмыкия, Юстинский район, поселок Цаган Аман, Городовикова, 114	f	medium
149	14910	149	республика Адыгея, Майкоп, Заводская, 116	f	large
7401	37978	209	республика Калмыкия, Юстинский район, поселок городского типа Цаган Аман, переулок Школьный, 6	f	medium
7411	37989	219	республика Калмыкия, Юстинский район, село Харба, сельский Дом культуры	f	small
7406	37984	214	республика Калмыкия, Юстинский район, село Татал, сельский Дом культуры	f	small
7424	38000	232	республика Калмыкия, Юстинский район, село Октябрьский, Центральная, 15	f	medium
7413	37991	221	республика Калмыкия, Юстинский район, Бергин	f	small
7409	37987	217	республика Калмыкия, Юстинский район, село Белоозерный, сельский Дом культуры	t	small
7412	37990	220	Россия, республика Калмыкия, Юстинский район, село Барун	f	small
7199	37785	6	республика Калмыкия, Элиста городской округ, село Салын, Школьная, 2	f	small
7399	37976	207	республика Калмыкия, Черноземельский район, село Сарул, Интернациональная, 2	f	small
7398	37975	206	республика Калмыкия, Черноземельский район, село Прикумский, Комсомольская, 12	t	medium
7397	37974	205	республика Калмыкия, Черноземельский район, село Нарын Худук, Советская, 5/1	f	small
7273	37856	81	Россия, республика Калмыкия, Ики-Бурульский район, село Маныч	f	small
7396	37973	204	республика Калмыкия, Черноземельский район, село Кумской, Ленина, 4	t	small
7394	37971	202	республика Калмыкия, Черноземельский район, Комсомольское сельское муниципальное образование Республики Калмыкия, Ленина, 54	f	medium
7393	37970	201	республика Калмыкия, Черноземельский район, поселок Комсомольский, Некрасова, 60	f	medium
7395	37972	203	республика Калмыкия, Черноземельский район, поселок Комсомольский, Ленина, 38	f	medium
7392	37969	200	республика Калмыкия, Черноземельский район, поселок Комсомольский, Аллея Памяти, 43	f	large
7391	37968	199	республика Калмыкия, Черноземельский район, село Ачинеры, Ленина, 12	t	medium
7388	37965	196	республика Калмыкия, Черноземельский район, село Артезиан, переулок Кооперативный, 10	t	medium
7389	37966	197	республика Калмыкия, Черноземельский район, село Артезиан, Советская, 8	t	medium
7390	37967	198	республика Калмыкия, Черноземельский район, село Артезиан, Д. Адьянова, 20	t	medium
7387	37964	195	республика Калмыкия, Черноземельский район, село Адык, Мира, 2	f	medium
7378	37962	186	Россия, республика Калмыкия, Целинный район, село Ялмта	f	small
7377	37961	185	Россия, республика Калмыкия, Целинный район, село Чагорта	f	small
7375	37959	183	республика Калмыкия, Целинный район, село Хар-Булук	f	medium
7383	35330	191	республика Калмыкия, Целинный район, село Троицкое, СУ-95945	f	large
7386	35596	194	республика Калмыкия, Целинный район, село Троицкое, Чапаева, 43	f	medium
7384	35468	192	республика Калмыкия, Целинный район, село Троицкое, Физкультурная, 5	f	large
7382	35134	190	республика Калмыкия, Целинный район, село Троицкое, Пушкина, 1А	f	large
7380	37881	188	республика Калмыкия, Целинный район, село Троицкое, Октябрьская, 1	f	large
7385	35571	193	республика Калмыкия, Целинный район, село Троицкое, Ленина, 4	f	medium
7381	37921	189	республика Калмыкия, Целинный район, село Троицкое, Колхозная, 25 а	f	medium
7379	37963	187	республика Калмыкия, Целинный район, село Троицкое, Геологическая, 37а	f	large
7374	37958	182	республика Калмыкия, Целинный район, село Овата	f	medium
7373	37957	181	Россия, республика Калмыкия, Целинный район, село Найнтахн	f	small
7372	37956	180	республика Калмыкия, Целинный район, село Ики-Чонос	f	medium
7371	37955	179	Россия, республика Калмыкия, Целинный район, село Вознесеновка	f	large
7370	37954	178	Россия, республика Калмыкия, Целинный район, село Верхняя Яшкуль	f	small
7369	37953	177	Россия, республика Калмыкия, Целинный район, село Бага-Чонос	f	small
7376	37960	184	Россия, республика Калмыкия, Целинный район, село Аршан-Булг	t	small
7358	37942	166	республика Калмыкия, Сарпинский район, село Шарнут	f	small
7357	37941	165	республика Калмыкия, Сарпинский район, село Шарнут, Хомутникова, 11	f	medium
7367	37951	175	республика Калмыкия, Сарпинский район, село Уманцево, Ленина, 1	f	small
7366	37949	174	республика Калмыкия, Сарпинский район, село Салын Тугтун, Школьная, 11	f	small
7365	37949	173	республика Калмыкия, Сарпинский район, село Салын Тугтун, Школьная, 11	f	small
7364	37948	172	республика Калмыкия, Сарпинский район, село Салын Тугтун, Бадмаева, 15	f	small
7356	37940	164	республика Калмыкия, Сарпинский район, село Садовое, Ленина, 120	f	large
7354	37938	162	республика Калмыкия, Сарпинский район, село Садовое, Ленина, 95	f	large
7355	37939	163	республика Калмыкия, Сарпинский район, село Садовое, Дорожная, 10	f	large
7363	37947	171	республика Калмыкия, Сарпинский район, село Обильное, Колхозная, 1	f	medium
7362	37946	170	республика Калмыкия, Сарпинский район, село Коробкин, Школьная, 12	f	small
7361	37945	169	республика Калмыкия, Сарпинский район, село Кировский, Центральная, 49	f	small
7360	37944	168	республика Калмыкия, Сарпинский район, село Кировский, Зеленая, 42	f	small
7359	37943	167	республика Калмыкия, Сарпинский район, село Кануково, Лесная, 2	f	medium
7368	37952	176	республика Калмыкия, Сарпинский район, село Аршань-Зельмень, Дорожная, 1	f	medium
7353	37937	161	республика Калмыкия, Приютненский район, село Ульдючины, Дружбы, 28	f	medium
7350	37934	158	республика Калмыкия, Приютненский район, село Приютное, Московская, 85	f	large
7352	37936	160	республика Калмыкия, Приютненский район, село Приютное, Канукова, 1	f	large
7351	37935	159	республика Калмыкия, Приютненский район, село Приютное, Ильина, 4	f	medium
7349	37933	157	республика Калмыкия, Приютненский район, село Приютное, Гагарина, 75	f	large
7348	37932	156	республика Калмыкия, Приютненский район, село Песчаный, Гагарина, 1 а	f	small
7347	37931	155	республика Калмыкия, Приютненский район, село Первомайский, Советская, 13	f	medium
7410	37988	218	Россия, республика Калмыкия, Яшалтинский район, село Октябрьский	f	small
7346	37930	154	республика Калмыкия, Приютненский район, село Октябрьский, МОУ Октябрьская средняя общеобразовательная школа	f	small
7343	37927	151	республика Калмыкия, Приютненский район, село Нарын, Степная, 10	t	small
7345	37929	153	республика Калмыкия, Приютненский район, село Нарта, Школьная, 16	t	small
7344	37928	152	республика Калмыкия, Приютненский район, село Воробьевка, МОУ Воробьевская средняя общеобразовательная школа	f	medium
7342	37926	150	Россия, республика Калмыкия, Приютненский район, село Бурата	f	small
7340	37924	148	Россия, республика Калмыкия, Октябрьский район, село Цаган Нур	f	medium
7341	37925	149	республика Калмыкия, Октябрьский район, село Хошеут, Октябрьская, 18	f	small
7337	37920	145	республика Калмыкия, Октябрьский район, село Мирный, Советская, 13	f	small
7339	37923	147	республика Калмыкия, Октябрьский район, село Иджил, Северная, 3	f	small
7338	37922	146	республика Калмыкия, Октябрьский район, село Джангар, Квартал, 1	f	small
7336	37919	144	республика Калмыкия, Октябрьский район, село Восход, Советская, 15	f	medium
7333	37916	141	республика Калмыкия, Октябрьский район, село Большой Царын, Советская, 1	f	medium
7332	37915	140	республика Калмыкия, Октябрьский район, село Большой Царын, Матросова, 4	f	large
7335	37918	143	республика Калмыкия, Октябрьский район, село Большой Царын, Ломоносова, 1	f	medium
7334	37917	142	республика Калмыкия, Октябрьский район, село Большой Царын, Горького, 15	f	medium
7331	37914	139	Россия, республика Калмыкия, Малодербетовский район, село Хонч-Нур	t	small
7330	37913	138	республика Калмыкия, Малодербетовский район, село Ханата, Г.Даваева, 4	t	small
7329	37912	137	республика Калмыкия, Малодербетовский район, село Унгун-Терячи, пер.Школьный, 1	t	small
7327	37910	135	республика Калмыкия, Малодербетовский район, село Тундутово, Ленина, 154	f	large
7326	37909	134	республика Калмыкия, Малодербетовский район, село Плодовитое, А.Хадыкина, 31	f	medium
7325	37908	133	республика Калмыкия, Малодербетовский район, село Малые Дербеты, Советская, 8	f	large
7324	37907	132	республика Калмыкия, Малодербетовский район, село Малые Дербеты, Советская, 9	f	large
7323	37906	131	республика Калмыкия, Малодербетовский район, село Малые Дербеты, 40 лет Победы, 7	f	large
7322	37905	130	республика Калмыкия, Малодербетовский район, село Ики-Манлан, Китидова, 2	t	small
7321	37904	129	республика Калмыкия, Малодербетовский район, село Ики-Бухус, Э.Овла, 1	t	small
7328	37911	136	Россия, республика Калмыкия, Малодербетовский район, село Зурган	t	small
7318	37901	126	республика Калмыкия, Лаганский район, поселок Улан Хол, Советская, 24	f	medium
7317	37900	125	республика Калмыкия, Лаганский район, поселок Улан Хол, Орджоникидзе, 26	f	medium
7301	37883	109	республика Калмыкия, Лаганский район, поселок городского типа Улан Хол, Пушкина, 61	f	small
7320	37903	128	республика Калмыкия, Лаганский район, село Северное, Школьная, 30	f	medium
7305	37887	113	республика Калмыкия, Лаганский район, Лагань, переулок Почтовый, 12	f	medium
7299	37880	107	республика Калмыкия, Лаганский район, Лагань, микрорайон, 70	f	medium
7298	37880	106	республика Калмыкия, Лаганский район, Лагань, микрорайон, 70	f	medium
7307	37889	115	республика Калмыкия, Лаганский район, Лагань, Советская, 59	f	large
7306	37888	114	республика Калмыкия, Лаганский район, Лагань, Свердлова, 16А	f	medium
7314	37897	122	республика Калмыкия, Лаганский район, Лагань, Садовая, 58	f	small
7309	37891	117	республика Калмыкия, Лаганский район, Лагань, Рабочая, 44	f	medium
7308	37890	116	республика Калмыкия, Лаганский район, Лагань, Колхозная, 1	f	medium
7303	37885	111	республика Калмыкия, Лаганский район, Лагань, Кирова, 7	f	medium
7300	37882	108	республика Калмыкия, Лаганский район, Лагань, Канукова, 44 а	f	medium
7312	37895	120	республика Калмыкия, Лаганский район, Лагань, Ермолинская, 33	f	medium
7319	37902	127	республика Калмыкия, Лаганский район, село Красинское, Советская, 25	f	medium
7315	37898	123	республика Калмыкия, Лаганский район, село Джалыково, Ленина, 25	f	medium
7316	37899	124	республика Калмыкия, Лаганский район, село Джалыково, Кирова, 14	t	small
7295	37877	103	республика Калмыкия, Кетченеровский район, село Эвдик, Школьная, 1	f	small
7287	37870	95	республика Калмыкия, Кетченеровский район, село Шин Мер, Октябрьская, 8	f	small
7297	37879	105	республика Калмыкия, Кетченеровский район, село Шатта, Октябрьская, 16	f	medium
7294	37876	102	республика Калмыкия, Кетченеровский район, село Чкаловский, Кошевого, 1	f	small
7296	37878	104	республика Калмыкия, Кетченеровский район, село Тугтун, Бадмаева, 15	f	small
7293	37875	101	республика Калмыкия, Кетченеровский район, село Сарпа, Центральная, 11	f	small
7285	37868	93	республика Калмыкия, Кетченеровский район, село Кетченеры, Номто Очирова, 23	f	medium
7286	37869	94	республика Калмыкия, Кетченеровский район, село Кетченеры, Ленина, 79	f	medium
7284	37867	92	республика Калмыкия, Кетченеровский район, село Кетченеры, Ленина, 76	f	medium
7283	37866	91	республика Калмыкия, Кетченеровский район, село Кетченеры, Заречная, 93	f	medium
7282	37865	90	республика Калмыкия, Кетченеровский район, село Кетченеры, А. Мучкаева, 5	f	medium
7292	37874	100	республика Калмыкия, Кетченеровский район, село Кегульта, Центральная, 1	f	medium
7290	37854	98	республика Калмыкия, Кетченеровский район, село Ергенинский, Школьная, 10	f	medium
7291	37873	99	республика Калмыкия, Кетченеровский район, село Годжур, Мира, 7	t	small
7289	37872	97	республика Калмыкия, Кетченеровский район, село Гаршун-Бургуста, Манджиева, 18	f	small
7288	37871	96	республика Калмыкия, Кетченеровский район, село Алцынхута, Чапчаева, 2	f	medium
7280	37863	88	Россия, республика Калмыкия, Городовиковский район, село Южный	f	small
7275	37858	83	республика Калмыкия, Ики-Бурульский район, село Шееринг	t	small
7281	37864	89	Россия, республика Калмыкия, Ики-Бурульский район, село Чолун Хамур	t	small
7279	37862	87	Россия, республика Калмыкия, Ики-Бурульский район, село Хомутников	f	medium
7278	37861	86	республика Калмыкия, Ики-Бурульский район, село Ут-Сала	f	small
7277	37860	85	Россия, республика Калмыкия	t	small
7276	37859	84	Россия, республика Калмыкия, Ики-Бурульский район, село Приманыч	f	medium
7274	37857	82	Россия, республика Калмыкия, Ики-Бурульский район, село Оргакин	f	medium
7272	37855	80	Россия, республика Калмыкия, Ики-Бурульский район, село Манцин Кец	f	small
7213	37800	20	республика Калмыкия, Ики-Бурульский район, село Лола, санаторий Лола	f	small
7271	37853	79	Россия, республика Калмыкия, Ики-Бурульский район, село Кевюды	f	small
7270	37852	78	республика Калмыкия, Ики-Бурульский район, село Ики-Бурул, Здание ГУП Чограй	f	medium
7269	37851	77	республика Калмыкия, Ики-Бурульский район, село Ики-Бурул, молодежный центр	f	large
7268	37850	76	Россия, республика Калмыкия, Ики-Бурульский район, село Зунда Толга	t	small
7265	37847	73	республика Калмыкия, Городовиковский район, село Южный	t	small
7264	37846	72	республика Калмыкия, Городовиковский район, село Южный	f	small
7263	37846	71	республика Калмыкия, Городовиковский район, село Южный	f	small
7262	37845	70	республика Калмыкия, Городовиковский район, село Южный	f	small
7258	37841	66	республика Калмыкия, Городовиковский район, село Пушкинское	t	small
7257	37840	65	Россия, республика Калмыкия, Городовиковский район, село Пушкинское	f	medium
7256	37839	64	республика Калмыкия, Городовиковский район, село Лазаревский, Балковский сельский клуб	t	small
7255	37838	63	республика Калмыкия, Городовиковский район, село Лазаревский, начальная школа СПК Бага-Бурул	t	small
7254	37837	62	республика Калмыкия, Городовиковский район, село Лазаревский, Контора отделения № 3	t	small
7253	37836	61	республика Калмыкия, Городовиковский район, село Лазаревский, Контора отделения №2	f	small
7252	37835	60	республика Калмыкия, Городовиковский район, село Лазаревский	t	small
7251	37834	59	Россия, республика Калмыкия, Городовиковский район, село Лазаревский	f	medium
7261	37844	69	республика Калмыкия, Городовиковский район, село Дружное	f	medium
7249	37832	57	республика Калмыкия, Городовиковский район, Городовиковск	f	large
7248	37831	56	республика Калмыкия, Городовиковский район, Городовиковск	f	large
7246	37829	54	Россия, республика Калмыкия, Городовиковский район, Городовиковск	f	medium
7245	37828	53	республика Калмыкия, Городовиковский район, Городовиковск	f	large
7244	37827	52	республика Калмыкия, Городовиковский район, Городовиковск	f	large
7260	37843	68	республика Калмыкия, Городовиковский район, село Виноградное	f	small
7259	37842	67	республика Калмыкия, Городовиковский район, село Виноградное	f	large
7419	37995	227	республика Калмыкия, Городовиковский район, село Веселое, Школьная, сельский Дом культуры	f	small
7267	37849	75	Россия, республика Калмыкия, Городовиковский район, село Бага-Бурул	f	small
7266	37848	74	республика Калмыкия, Городовиковский, село Розенталь	f	small
169	14927	169	республика Адыгея, Майкоп, квартал 407-е	f	large
134689	95160	167	республика Адыгея, Майкоп, Шоссейная, 10	f	large
170	14928	170	республика Адыгея, Майкоп, Шоссейная, 10	f	large
166	14924	166	республика Адыгея, Майкоп, Шоссейная, 96	f	large
135	14896	135	республика Адыгея, Майкоп, Чкалова, 77	f	large
185	14942	185	республика Адыгея, Майкоп, Хакурате, 640	f	medium
162	14919	162	республика Адыгея, Майкоп, Тульская, 3	f	large
160	14919	160	республика Адыгея, Майкоп, Тульская, 3	f	large
159	14919	159	республика Адыгея, Майкоп, Тульская, 3	f	large
148	14909	148	республика Адыгея, Майкоп, Советская, 108	f	large
147	14908	147	республика Адыгея, Майкоп, Советская, 168	f	large
146	14907	146	республика Адыгея, Майкоп, Советская, 241	f	large
158	14918	158	республика Адыгея, Майкоп, Пушкина, 173	f	large
144	14905	144	республика Адыгея, Майкоп, Пролетарская, 353	f	large
121	14882	121	республика Адыгея, Майкоп, Привокзальная, 106	f	large
118	14879	118	республика Адыгея, Майкоп, Привокзальная, 130	f	large
117	14878	117	республика Адыгея, Майкоп, Привокзальная, 288-А	f	large
164	14922	164	республика Адыгея, Майкоп, Пржевальского, 2	f	medium
165	14923	165	республика Адыгея, Майкоп, Пионерская, 532	f	small
157	14917	157	республика Адыгея, Майкоп, Первомайская, 208	f	large
145	14906	145	республика Адыгея, Майкоп, Первомайская, 268	f	large
179	14936	179	республика Адыгея, Майкоп, Мичурина, 34	f	medium
153	14914	153	республика Адыгея, Майкоп, МОПРа, 65, столовая	f	large
152	14913	152	республика Адыгея, Майкоп, МОПРа, 65	f	large
154	14913	154	республика Адыгея, Майкоп, МОПРа, 65	f	large
175	14932	175	республика Адыгея, Майкоп, Ленина, 40	f	large
119	14880	119	республика Адыгея, Майкоп, Ленина, 139	f	large
132	14893	132	республика Адыгея, Майкоп, Курганная, 1	f	large
131	14892	131	республика Адыгея, Майкоп, Курганная, 172	f	large
126	14887	126	республика Адыгея, Майкоп, Курганная, 331	f	large
122	14883	122	республика Адыгея, Майкоп, Курганная, 710	f	large
124	14839	124	республика Адыгея, Майкоп, Курганная, 644	f	large
128	14889	128	республика Адыгея, Майкоп, Крестьянская, 238	f	large
129	14890	129	республика Адыгея, Майкоп, Краснооктябрьская, 48	f	large
123	14884	123	республика Адыгея, Майкоп, Красногвардейская, 3	f	large
156	14916	156	республика Адыгея, Майкоп, Комсомольская, 201	f	large
163	14921	163	республика Адыгея, Майкоп, Железнодорожная, 162	f	large
136	14897	136	республика Адыгея, Майкоп, Димитрова, 21	f	large
134	14895	134	республика Адыгея, Майкоп, Димитрова, 23	f	large
137	14898	137	республика Адыгея, Майкоп, Депутатская, 10	f	large
130	14891	130	республика Адыгея, Майкоп, Гоголя, 112	f	large
116	14877	116	республика Адыгея, Майкоп, Герцена, 96	f	large
161	14920	161	республика Адыгея, Майкоп, Апшеронская, 4	f	large
125	14886	125	республика Адыгея, Майкоп, 8 Марта, 21	f	large
171	14926	171	республика Адыгея, Майкоп, 7-й переулок, 22	f	large
168	14926	168	республика Адыгея, Майкоп, 7-й переулок, 22	f	large
150	14911	150	республика Адыгея, Майкоп, 2-я Ветеранов, 1	f	large
133	14894	133	республика Адыгея, Майкоп, 2 Ветеранов, 1	f	large
142	14903	142	республика Адыгея, Майкоп, 12 Марта, 65	f	large
141	14902	141	республика Адыгея, Майкоп, 12 Марта, 126	f	large
140	14901	140	республика Адыгея, Майкоп, 12 Марта, 114-а	f	large
139	14900	139	республика Адыгея, Майкоп, 12 Марта, 144А	f	large
138	14899	138	республика Адыгея, Майкоп, 12 Марта, 163	f	large
44	14805	44	республика Адыгея, хутор Игнатьевский, Ленина, 92	f	medium
51	14812	51	республика Адыгея, хутор Дмитриевский, Комсомольская, 20А	f	medium
4	14767	4	республика Адыгея, Адыгейск, Пушкина, 15	f	large
3	14766	3	республика Адыгея, Адыгейск, Ленина, 28	f	large
256	15006	256	республика Адыгея, Шовгеновский район, аул Хакуринохабль, Шовгенова, 12	f	large
249	14999	249	республика Адыгея, Шовгеновский район, Чернышев, Школьная, 5	f	medium
259	15009	259	республика Адыгея, Шовгеновский район, Хатажукай, Мурата Шовгенова, 9	f	medium
255	15005	255	республика Адыгея, Шовгеновский район, Хакуринохабль, Краснооктябрьская, 90	f	large
247	14997	247	республика Адыгея, Шовгеновский район, поселок Тихонов, Советская, 206	f	medium
254	15004	254	республика Адыгея, Шовгеновский район, поселок Семено-Макаровский, Кочубея, 6	t	small
253	15003	253	республика Адыгея, Шовгеновский район, поселок Свободный Труд, Карла Маркса, 1А	f	small
260	15010	260	республика Адыгея, Шовгеновский район, поселок Пшичо, Ленина, 51	f	medium
262	15012	262	республика Адыгея, Шовгеновский район, Пшизов, Школьная, 22	f	medium
251	15001	251	республика Адыгея, Шовгеновский район, поселок Михайлов, Красноармейская, 16	t	small
258	15008	258	республика Адыгея, Шовгеновский район, Мамхег, 50 лет ВЛКСМ, 35	f	large
248	14998	248	республика Адыгея, Шовгеновский район, поселок Мамацев, Школьная, 2	t	small
257	15007	257	республика Адыгея, Шовгеновский район, поселок Киров, Краснооктябрьская, 18	f	small
261	15011	261	республика Адыгея, Шовгеновский район, поселок Кабехабль, Ленина, 35	f	medium
250	15000	250	республика Адыгея, Шовгеновский район, поселок Зарево, Пролетарская, 5	f	medium
246	14996	246	республика Адыгея, Шовгеновский район, поселок Дукмасов, Ушанева, 19	f	small
252	15002	252	республика Адыгея, Шовгеновский район, поселок Джерокай, Краснооктябрьская, 26	f	medium
244	14994	244	республика Адыгея, Теучежский район, поселок Шевченко, Красная, 1	f	small
229	14978	229	республика Адыгея, Теучежский район, поселок Четук, Ленина, 4/1	t	small
227	14976	227	республика Адыгея, Теучежский район, поселок Тугургой, Школьная, 5	f	small
225	14974	225	республика Адыгея, Теучежский район, Тлюстенхабль, Школьная, 1	f	large
226	14975	226	республика Адыгея, Теучежский район, Тлюстенхабль, Ленина, 23	f	large
240	14990	240	республика Адыгея, Теучежский район, поселок Тауйхабль, Пролетарская, 23	t	small
235	14984	235	республика Адыгея, Теучежский район, поселок Пшикуйхабль, Красная, 28	t	small
231	14980	231	республика Адыгея, Теучежский район, поселок Пчегатлукай, Ленина, 45	f	medium
233	14982	233	республика Адыгея, Теучежский район, поселок Понежукай, Октябрьская, 34	f	large
245	14995	245	республика Адыгея, Теучежский район, поселок Петров, Первомайская, 37А	t	small
236	14985	236	республика Адыгея, Теучежский район, Нешукай, Октябрьская, 43	f	medium
234	14983	234	республика Адыгея, Теучежский район, поселок Начерезий, Хакурате, 4А	t	small
238	14987	238	республика Адыгея, Теучежский район, поселок Красное, Шоссейная, 1	t	small
230	14979	230	республика Адыгея, Теучежский район, поселок Красненский, Школьная, 1	t	small
242	14992	242	республика Адыгея, Теучежский район, поселок Кончукохабль, Хакурате, 3	t	small
228	14977	228	республика Адыгея, Теучежский район, поселок Казазов, Красная, 13	t	small
239	14988	239	республика Адыгея, Теучежский район, поселок Джиджихабль, Школьная, 36	f	medium
241	14991	241	республика Адыгея, Теучежский район, поселок Городской, Советов, 16	t	small
243	14993	243	республика Адыгея, Теучежский район, Габукай, Хакурате, 26	f	large
232	14981	232	республика Адыгея, Теучежский район, Вочепший, Школьная, 1	f	large
67830	14986	237	республика Адыгея, Теучежский район, Ассоколай, Ленина, 47	f	large
5	14768	5	республика Адыгея, Теучежский район, Адыгейск, Ленина, 13	f	medium
2	14765	2	республика Адыгея, Теучежский район, город Адыгейск, Ленина, 16	f	large
1	14764	1	республика Адыгея, Теучежский район, Адыгейск, Ленина, 21	f	small
6	14769	6	республика Адыгея, Теучежский район, Адыгейск, А.И. Хуаде, 76	f	large
218	14967	218	республика Адыгея, Тахтамукайский район, аул Новая Адыгея, Братьев Пченушай, 39	f	medium
212	14961	212	республика Адыгея, Тахтамукайский район, Яблоновский, Школьная, 2/1	f	large
211	14960	211	республика Адыгея, Тахтамукайский район, поселок Яблоновский, Пушкина, 26	f	large
213	14962	213	республика Адыгея, Тахтамукайский район, Яблоновский, Ленина, 17	f	large
210	14959	210	республика Адыгея, Тахтамукайский район, поселок Яблоновский, Лаухина, 11	f	large
134950	95199	208	республика Адыгея, Тахтамукайский район, Яблоновский, Космическая, 35	f	large
207	14956	207	республика Адыгея, Тахтамукайский район, поселок Яблоновский, Космическая, 35	f	large
205	14954	205	республика Адыгея, Тахтамукайский район, поселок Яблоновский, Заводская, 7	f	large
86914	14965	216	республика Адыгея, Тахтамукайский район, Яблоновский, Гагарина, 41/1	f	large
209	14958	209	республика Адыгея, Тахтамукайский район, Яблоновский, Гагарина, 41	f	large
206	14955	206	республика Адыгея, Тахтамукайский район, Яблоновский, Андрухаева, 61	f	large
194	14951	194	республика Адыгея, Тахтамукайский район, Энем, Чкалова, 13	f	large
193	14950	193	республика Адыгея, Тахтамукайский район, поселок Энем, Седина, 42	f	large
195	14885	195	республика Адыгея, Тахтамукайский район, Энем, Седина, 36	f	large
196	14719	196	республика Адыгея, Тахтамукайский район, Энем, Седина, 9	f	large
198	14726	198	республика Адыгея, Тахтамукайский район, поселок Энем, Маяковского, 1	f	large
199	14731	199	республика Адыгея, Тахтамукайский район, поселок Энем, Ленина, 60	f	large
192	14949	192	республика Адыгея, Тахтамукайский район, поселок Энем, Красная, 16А	f	large
197	14720	197	республика Адыгея, Тахтамукайский район, поселок Энем, Красная, 23	f	large
186	14943	186	республика Адыгея, Тахтамукайский район, Шенджий, Пушкина, 22	f	large
219	14968	219	республика Адыгея, Тахтамукайский район, поселок Хомуты, Заречная, 10	t	small
223	14972	223	республика Адыгея, Тахтамукайский район, поселок Хаштук, Хакурате, 18/1	t	small
187	14944	187	республика Адыгея, Тахтамукайский район, поселок Тахтамукай, Совмена, 3	f	large
188	14945	188	республика Адыгея, Тахтамукайский район, поселок Тахтамукай, Натухаевская, 6	f	large
201	14735	201	республика Адыгея, Тахтамукайский район, поселок Суповский, Ленина, 86а	t	small
217	14966	217	республика Адыгея, Тахтамукайский район, поселок Старобжегокай, Ленина, 35/1	f	large
222	14971	222	республика Адыгея, Тахтамукайский район, поселок Псейтук, Школьная, 2	f	small
109205	14946	189	республика Адыгея, Тахтамукайский район, Прикубанский, Ленина, 10	f	medium
215	14964	215	республика Адыгея, Тахтамукайский район, поселок Перекатный, кафе На берегу	t	small
221	14970	221	республика Адыгея, Тахтамукайский район, Панахес, Схакумидова, 2	f	large
190	14947	190	республика Адыгея, Тахтамукайский район, поселок Отрадный, Павлова, 10	f	medium
214	14963	214	республика Адыгея, Тахтамукайский район, поселок Новый Сад, Ленина, 1	f	medium
202	14759	202	республика Адыгея, Тахтамукайский район, поселок Новый Сад, Дружбы, 29А	f	medium
203	14952	203	республика Адыгея, Тахтамукайский район, поселок Новобжегокай, Хатита, 17	f	small
191	14948	191	республика Адыгея, Тахтамукайский район, поселок Натухай, Ленина, 33	f	small
69945	76743	2136	Ростовская область, Шахты, Садовая, 33а	f	large
224	14973	224	республика Адыгея, Тахтамукайский район, поселок Кубаньстрой, Заводская, 1	f	small
204	14953	204	республика Адыгея, Тахтамукайский район, Козет, Площадь Памяти, 1	f	large
200	14733	200	республика Адыгея, Тахтамукайский район, поселок Дружный, Рабочая, 14	t	small
220	14969	220	республика Адыгея, Тахтамукайский район, Афипсип, Жане, 5	f	large
115	14876	115	республика Адыгея, Майкопский район, пос. Трехречный, Школьная, 2	f	small
45	14806	45	республика Адыгея, Майкопский район, аул Кошехабль, Промышленная, 35	f	large
79	14836	79	республика Адыгея, Майкопский район, поселок Шунтук, Школьный переулок, 1	f	medium
105	14865	105	республика Адыгея, Майкопский район, поселок Шаумян, Комсомольская, 9	f	medium
81	14838	81	республика Адыгея, Майкопский район, Цветочный, Клубная, 6	f	large
177	14934	177	республика Адыгея, Майкопский район, поселок Ханская, Краснооктябрьская, 25	f	large
176	14933	176	республика Адыгея, Майкопский район, Ханская, Интернациональная, 112	f	large
95	14854	95	республика Адыгея, Майкопский район, поселок Усть-Сахрайский, Советская, 17	t	small
103	14863	103	республика Адыгея, Майкопский район, Удобный, Ленина, 20 б	f	large
75	14832	75	республика Адыгея, Майкопский район, поселок Тульский, Советская, 38	f	large
78	14835	78	республика Адыгея, Майкопский район, поселок Тульский, Первомайская, 222	f	large
77	14834	77	республика Адыгея, Майкопский район, Тульский, Комсомольская, 22	f	large
76	14833	76	республика Адыгея, Майкопский район, поселок Тульский, Комсомольская, 22б	f	large
80	14837	80	республика Адыгея, Майкопский район, поселок Тимирязева, Садовая, 4	f	large
101	14860	101	республика Адыгея, Майкопский район, Табачный, Шоссейная, 29	f	large
104	14864	104	республика Адыгея, Майкопский район, Совхозный, Советская, 49	f	large
46	14807	46	Россия, республика Адыгея, Майкопский район, поселок Советский	f	large
96	14855	96	республика Адыгея, Майкопский район, поселок Советский, Советская, 11	f	medium
47	14808	47	республика Адыгея, Майкопский район, поселок Советский, Советская, 26	f	large
109	14869	109	республика Адыгея, Майкопский район, поселок Советский, Западная, 4	t	small
107	14867	107	республика Адыгея, Майкопский район, поселок Северо-Восточные Сады, Нагорная, 48А	f	large
108	14868	108	республика Адыгея, Майкопский район, Северо-Восточные Сады, Маяковского, 268	f	large
180	14937	180	республика Адыгея, Майкопский район, поселок Северный, Школьная, 12	f	large
86	14844	86	республика Адыгея, Майкопский район, поселок Севастопольская, Советская, 29	f	small
178	14935	178	республика Адыгея, Майкопский район, поселок Родниковый, Ленина, 14	f	medium
110	14870	110	республика Адыгея, Майкопский район, поселок Пролетарский, Комсомольская, 43 а	f	medium
102	14862	102	республика Адыгея, Майкопский район, поселок Победа, Шоссейная, 103 ш	f	medium
92	14851	92	республика Адыгея, Майкопский район, поселок Победа, Дружбы, 42	t	small
85	14843	85	республика Адыгея, Майкопский район, Первомайский, Школьная, 39	f	large
87	14845	87	республика Адыгея, Майкопский район, поселок Новосвободная, Советская, 20	f	medium
94	14853	94	республика Адыгея, Майкопский район, поселок Новопрохладное, Советская, 8	t	small
127	14888	127	республика Адыгея, Майкопский район, город Майкоп, Краснооктябрьская, 51	f	large
120	14881	120	республика Адыгея, Майкопский район, город Майкоп, Краснооктябрьская, 61	f	large
143	14904	143	республика Адыгея, Майкопский район, город Майкоп, Гайдара, 1-А	f	large
151	14912	151	республика Адыгея, Майкопский район, город Майкоп, 12 Марта, 138	f	large
97	14856	97	республика Адыгея, Майкопский район, поселок Курджипская, Кооперативная, 12А	f	large
113	14874	113	республика Адыгея, Майкопский район, Кужорская, Школьная, 25	f	large
114	14875	114	республика Адыгея, Майкопский район, Кужорская, Краснооктябрьская, 18	f	large
99	14858	99	республика Адыгея, Майкопский район, Краснооктябрьский, Шоссейная, 95	f	large
100	14859	100	республика Адыгея, Майкопский район, Краснооктябрьский, Кубанская, 74	f	large
39	14801	39	Россия, республика Адыгея, Майкопский район, поселок Красная Улька	f	large
38	14801	38	Россия, республика Адыгея, Майкопский район, поселок Красная Улька	f	large
112	14873	112	республика Адыгея, Майкопский район, Красная Улька, Октябрьская, 27	f	large
40	14802	40	республика Адыгея, Майкопский район, поселок Красная Улька, Красная, 62	t	small
181	14938	181	республика Адыгея, Майкопский район, поселок Косинов, Гагарина, 17	t	small
89	14847	89	республика Адыгея, Майкопский район, Каменномостский, Мира, 25	f	large
90	14848	90	республика Адыгея, Майкопский район, Каменномостский, Железнодорожная, 21	f	large
91	14849	91	республика Адыгея, Майкопский район, поселок Каменномостский, Дальняя, 11	f	large
88	14846	88	республика Адыгея, Майкопский район, поселок Каменномостский, Гагарина, 38 а	f	large
172	14929	172	республика Адыгея, Майкопский район, Западный, Клубная, 18	f	large
93	14852	93	республика Адыгея, Майкопский район, поселок Даховская, Советская, 20	f	large
98	14857	98	республика Адыгея, Майкопский район, поселок Дагестанская, Ленина, 145	f	small
106	14866	106	республика Адыгея, Майкопский район, поселок Грозный, Школьная, 9	t	small
111	14871	111	республика Адыгея, Майкопский район, поселок Грозный, Пионерская, 47	f	medium
67829	15014	276	республика Адыгея, Майкопский район, поселок Гавердовский, переулок Клубный, 1	f	large
173	14930	173	республика Адыгея, Майкопский район, Гавердовский, переулок Клубный, 1	f	large
174	14931	174	республика Адыгея, Майкопский район, поселок Веселый, Лесная, 4	f	medium
84	14842	84	республика Адыгея, Майкопский район, поселок Абадзехская, Полевая, 4	f	small
83	14841	83	республика Адыгея, Майкопский район, Абадзехская, Клубная, 48	f	large
82	14840	82	республика Адыгея, Майкопский район, поселок Абадзехская, Винника, 52	f	large
73	14830	73	республика Адыгея, Красногвардейский район, поселок Штурбино, Красная, 3	f	small
54	14815	54	республика Адыгея, Красногвардейский район, поселок Хатукай, Школьная, 2	f	large
55	14816	55	республика Адыгея, Красногвардейский район, Хатукай, Мира, 35	f	large
74	14831	74	республика Адыгея, Красногвардейский район, поселок Уляп, Братьев Шекультировых, 1	f	large
70	14721	70	республика Адыгея, Красногвардейский район, поселок Саратовский, Красная, 28	f	small
64	14825	64	республика Адыгея, Красногвардейский район, поселок Садовое, Красная, 14	f	medium
61	14822	61	республика Адыгея, Красногвардейский район, Преображенское, Школьная, 28	f	medium
63	14824	63	республика Адыгея, Красногвардейский район, Новосевастопольское, Чучваги, 4	f	medium
56	14817	56	республика Адыгея, Красногвардейский район, Красногвардейское, Первомайская, 12	f	large
59	14820	59	республика Адыгея, Красногвардейский район, поселок Красногвардейское, Мира, 341	f	large
57	14818	57	республика Адыгея, Красногвардейский район, Красногвардейское, 50 лет Октября, 35	f	large
69	14709	69	республика Адыгея, Красногвардейский район, Еленовское, Юбилейная, 8	f	medium
68	14762	68	республика Адыгея, Красногвардейский район, поселок Еленовское, Молодежная, 2	f	medium
67	14761	67	республика Адыгея, Красногвардейский район, поселок Еленовское, Клубная, 17	f	small
72	14829	72	республика Адыгея, Красногвардейский район, Джамбечи, Центральная, 38	f	medium
66	14827	66	республика Адыгея, Красногвардейский район, поселок Верхненазаровское, Почтовая, 40 А	f	small
71	14828	71	республика Адыгея, Красногвардейский район, поселок Большесидоровское, Советская, 42	f	large
65	14826	65	республика Адыгея, Красногвардейский район, поселок Бжедугхабль, Клубная, 13	f	medium
62	14823	62	республика Адыгея, Красногвардейский район, село Белосельское, Советская, 12	f	large
60	14821	60	республика Адыгея, Красногвардейский район, поселок Адамий, Шоссейная, 36	f	medium
32	14795	32	республика Адыгея, Кошехабльский район, аул Ходзь, Краснооктябрьская, 104	f	large
53	14814	53	республика Адыгея, Кошехабльский район, аул Хачемзий, Ленина, 37	f	medium
48	14809	48	республика Адыгея, Кошехабльский район, аул Егерухай, Школьная, 28А	f	large
34	14797	34	республика Адыгея, Кошехабльский район, хутор Шелковников, Мира, 53	t	small
50	14811	50	республика Адыгея, Кошехабльский район, Поселок Дружба, Промышленная, 3	f	medium
41	14803	41	республика Адыгея, Кошехабльский район, поселок Майский, Заводская, 5	f	large
49	14810	49	республика Адыгея, Кошехабльский район, поселок Комсомольский, поселок Южный, Центральная, 1	t	small
33	14796	33	республика Адыгея, Кошехабльский район, хутор Кармалино-Гидроицкий, Свободного Мира, 75	t	small
37	14800	37	республика Адыгея, Кошехабльский район, хутор Казенно-Кужорский, Ленина, 50	f	medium
36	14799	36	республика Адыгея, Кошехабльский район, село Вольное, Гагарина, 18	f	large
35	14798	35	республика Адыгея, Кошехабльский район, село Вольное, пер. Кооперативный, 6	f	small
27	14790	27	республика Адыгея, Гиагинский район, поселок Тамбовский, Прямая, 1	f	medium
24	14787	24	республика Адыгея, Гиагинский район, поселок Смольчев-Малиновский, Шоссейная, 10	t	small
25	14788	25	республика Адыгея, Гиагинский район, поселок Сергиевское, Почтовая, 7	f	large
17	14780	17	республика Адыгея, Гиагинский район, поселок Садовый, Луговая, 45	t	small
16	14779	16	республика Адыгея, Гиагинский район, поселок Прогресс, Центральная, 2	f	large
14	14777	14	республика Адыгея, Гиагинский район, поселок Новый, переулок Советский, 2	f	large
15	14778	15	Россия, республика Адыгея, Гиагинский район, поселок Ниж. Айрюм	t	small
31	14794	31	республика Адыгея, Гиагинский район, поселок Лесной	t	small
30	14793	30	республика Адыгея, Гиагинский район, поселок Келермесская, Советская, 89	f	large
29	14792	29	республика Адыгея, Гиагинский район, поселок Келермесская, Советская, 116	f	medium
23	14786	23	республика Адыгея, Гиагинский район, поселок Дондуковская, Ленина, 169	f	large
21	14784	21	республика Адыгея, Гиагинский район, поселок Дондуковская, Ленина, 145	f	medium
19	14782	19	республика Адыгея, Гиагинский район, Дондуковская, Элеваторная, 30	f	large
20	14783	20	республика Адыгея, Гиагинский район, Дондуковская, Ленина, 73	f	large
22	14785	22	республика Адыгея, Гиагинский район, Дондуковская, Гагарина, 148	f	medium
28	14791	28	республика Адыгея, Гиагинский район, поселок Днепровский, Крестьянская, 48	f	small
13	14776	13	республика Адыгея, Гиагинский район, поселок Гончарка, Центральная, 11	f	large
10	14773	10	республика Адыгея, Гиагинский район, поселок Гиагинская, Центральная, 36А	f	large
12	14775	12	республика Адыгея, Гиагинский район, Гиагинская, Красноармейская, 220	f	large
11	14774	11	республика Адыгея, Гиагинский район, поселок Гиагинская, Красная, 170	f	large
8	14771	8	республика Адыгея, Гиагинский район, Гиагинская, Красная, 310	f	large
7	14770	7	республика Адыгея, Гиагинский район, Гиагинская, Боевая, 3	f	large
9	14772	9	республика Адыгея, Гиагинский район, поселок Гиагинская, Ленина, 152	f	large
26	14789	26	республика Адыгея, Гиагинский район, поселок Георгиевское, Октябрьская, 4	t	small
18	14781	18	республика Адыгея, Гиагинский район, поселок Вольно-Веселый, Центральная, 27	t	small
69952	77312	2143	Ростовская область, Шахты, пл.Ленина, 1	f	large
69966	77326	2159	Ростовская область, Шахты, бульвар Аллейный, 8	f	large
69991	77350	2185	Ростовская область, Шахты, Энтузиастов, 103	f	large
69949	77308	2140	Ростовская область, Шахты, Шевченко, 94	f	large
69948	77204	2139	Ростовская область, Шахты, Шевченко, 145	f	large
69947	77158	2138	Ростовская область, Шахты, Шевченко, 147	f	large
69944	76944	2135	Ростовская область, Шахты, Шевченко, 116	f	large
70002	77359	2197	Ростовская область, Шахты, Фучика, 8а	f	large
69978	77337	2172	Ростовская область, Шахты, Федосеева, 49	f	large
87099	77311	2142	Ростовская область, Шахты, Тюменский, 97	f	large
70021	77378	2219	Ростовская область, Шахты, Текстильная, 41а	f	large
70020	77377	2218	Ростовская область, Шахты, Текстильная, 19	f	large
69987	77345	2181	Ростовская область, Шахты, Стрельникова, 40	f	large
69955	77314	2146	Ростовская область, Шахты, Спортивный, 2	f	large
70007	77364	2204	Ростовская область, Шахты, Сокольнический, 17а	f	large
69982	77340	2176	Ростовская область, Шахты, Советская, 155	f	large
69980	77339	2174	Ростовская область, Шахты, Советская, 145	f	large
69943	76922	2134	Ростовская область, Шахты, Советская, 279	f	large
69990	77349	2184	Ростовская область, Шахты, Сельская, 42	f	large
69998	77354	2192	Ростовская область, Шахты, Сапрыкина, 5	f	large
69997	77354	2191	Ростовская область, Шахты, Сапрыкина, 5	f	large
69950	77309	2141	Ростовская область, Шахты, Садовая, 10б	f	large
69941	76743	2132	Ростовская область, Шахты, Садовая, 33а	f	large
70000	77356	2194	Ростовская область, Шахты, Рудничный, 1а	t	large
69953	77313	2144	Ростовская область, Шахты, Пролетарская, 135	f	large
69964	77324	2157	Ростовская область, Шахты, Пограничная, 47в	f	large
69975	77324	2169	Ростовская область, Шахты, Пограничная, 47в	f	large
69984	77342	2178	Ростовская область, Шахты, Победы революции, 105	f	large
69976	77335	2170	Ростовская область, Шахты, Победы революции, 11	f	large
69979	77338	2173	Ростовская область, Шахты, Победа Революции, 79	f	large
69960	77319	2151	Ростовская область, Шахты, Победа Революции, 4	f	large
70229	77754	2612	Ростовская область, Шахты, Платова, 220а	f	large
69971	77330	2164	Ростовская область, Шахты, Питерская, 66	f	large
69973	77332	2166	Ростовская область, Шахты, Паустовского, 2а	f	large
69961	77320	2152	Ростовская область, Шахты, Панфилова, 42	f	large
70012	77369	2209	Ростовская область, Шахты, Островского, 26	f	large
114733	77373	2214	Ростовская область, Шахты, Муранова, 1	t	medium
70003	77360	2198	Ростовская область, Шахты, Монгольский, 25	t	large
69996	77353	2190	Ростовская область, Шахты, Михайлова, 23	f	large
114728	77323	2156	Ростовская область, Шахты, Мировая Коммуна, 1а	f	large
69958	77317	2149	Ростовская область, Шахты, Мировая Коммуна, 21	f	large
70004	77361	2200	Ростовская область, Шахты, Милиционная, 10	f	large
114731	77361	2199	Ростовская область, Шахты, Милиционная, 10	f	medium
69946	77134	2137	Ростовская область, Шахты, Маяковского, 88	f	large
69965	77325	2158	Ростовская область, Шахты, Майская, 27а	f	large
69981	77325	2175	Ростовская область, Шахты, Майская, 27а	f	large
70234	76690	2621	Ростовская область, Шахты, Лозовая, 33	f	large
69940	76690	2131	Ростовская область, Шахты, Лозовая, 33	f	large
70013	77370	2210	Ростовская область, Шахты, Ленинского Комсомола, 8	f	large
70010	77367	2207	Ростовская область, Шахты, Ленинского Комсомола, 40	f	large
70015	77371	2212	Ростовская область, Шахты, Лебедева, 2	f	large
69988	77346	2182	Ростовская область, Шахты, Красинская, 42а	f	large
69968	77328	2161	Ростовская область, Шахты, Кошевого, 17	f	large
69969	77328	2162	Ростовская область, Шахты, Кошевого, 17	f	large
69986	77341	2180	Ростовская область, Шахты, Короткий, 2	f	large
69983	77341	2177	Ростовская область, Шахты, Короткий, 2	f	large
70024	77380	2222	Ростовская область, Шахты, Индустриальная, 1-Г	f	large
70018	77375	2216	Ростовская область, Шахты, Есенина, 15	f	large
70017	77374	2215	Ростовская область, Шахты, Еременко, 9	f	large
70006	77363	2203	Ростовская область, Шахты, Дубинина, 2	f	large
70005	77363	2202	Ростовская область, Шахты, Дубинина, 2	f	large
69938	76595	2129	Ростовская область, Шахты, Достоевского, 69	f	large
69939	76595	2130	Ростовская область, Шахты, Достоевского, 69	f	large
69956	77315	2147	Ростовская область, Шахты, Донской, 37	f	large
69967	77327	2160	Ростовская область, Шахты, Депутатская, 16а	f	large
69954	77307	2145	Ростовская область, Шахты, Дачная, 223	f	large
69937	77307	2128	Ростовская область, Шахты, Дачная, 223	f	large
69972	77331	2165	Ростовская область, Шахты, Георгиевская, 27	f	large
69999	77355	2193	Ростовская область, Шахты, Врубовая, 27/29	f	large
70019	77376	2217	Ростовская область, Шахты, Ворошилова, 51	f	large
69994	77352	2188	Ростовская область, Шахты, Волошина, 20	f	large
69995	77352	2189	Ростовская область, Шахты, Волошина, 20	f	large
69942	76825	2133	Ростовская область, Шахты, Веселый, 36а	f	large
69963	77322	2155	Ростовская область, Шахты, Бугроватый, 28	f	large
114727	77322	2154	Ростовская область, Шахты, Бугроватый, 28	f	medium
69962	77321	2153	Ростовская область, Шахты, Безымянная, 6	f	large
87100	77344	2179	Ростовская область, Шахты, Баррикадная, 16	f	large
69970	77329	2163	Ростовская область, Шахты, Базарная, 25	f	large
87101	77347	2183	Ростовская область, Шахты, Азовская, 46	f	large
70001	77358	2196	Ростовская область, Шахты, 60 лет Победы, 50	f	large
69977	77336	2171	Ростовская область, Шахты, 50 лет ВЛКСМ, 25	f	large
69936	77306	2127	Ростовская область, Шахты, 10 лет За индустриализацию, 179	f	large
69957	77316	2148	Ростовская область, Шахты, 1-й Милиционный, 67а	f	large
69159	75994	774	Ростовская область, Цимлянск, Свердлова, 112	f	large
69819	77042	1874	Ростовская область, Таганрог	f	large
69794	77021	1849	Ростовская область, Таганрог	f	large
69763	76995	1818	Ростовская область, Таганрог	f	large
70195	77676	2522	Ростовская область, Таганрог, улица Чехова, 22б	f	large
69817	77040	1872	Ростовская область, Таганрог, улица Сергея Лазо, 7	f	large
69739	76974	1793	Ростовская область, Таганрог, улица Розы Люксембург, 153	f	large
69810	77033	1865	Ростовская область, Таганрог, улица Пальмиро Тольятти, 32	f	large
69809	77032	1864	Ростовская область, Таганрог, улица Пальмиро Тольятти, 26	f	large
69813	77036	1868	Россия, Ростовская область, Таганрог, улица Морозова, 30	f	large
69793	77020	1848	Россия, Ростовская область, Таганрог, улица Менделеева, 14	f	large
70168	77630	2469	Ростовская область, Таганрог, улица Маршала Жукова, 2	f	large
69796	77022	1851	Россия, Ростовская область, Таганрог, улица Ленина, 212	f	large
69795	77022	1850	Россия, Ростовская область, Таганрог, улица Ленина, 212	f	large
69748	76983	1802	Ростовская область, Таганрог, улица Карла Либкнехта, 185	f	large
70167	77515	2468	Россия, Ростовская область, Таганрог, улица Инициативная, 22	f	large
70104	77515	2350	Россия, Ростовская область, Таганрог, улица Инициативная, 22	f	large
69829	77052	1884	Ростовская область, Таганрог, улица Инициативная, 38	f	large
69823	77047	1878	Россия, Ростовская область, Таганрог, улица Инициативная, 70	f	large
69815	77038	1870	Ростовская область, Таганрог, улица Дзержинского, 171	f	large
69807	77031	1862	Ростовская область, Таганрог, улица Дзержинского, 144	f	large
69822	77046	1877	Ростовская область, Таганрог, улица 1-я Линия, 146а	f	large
69750	76985	1804	Ростовская область, Таганрог, переулок Трудовых Резервов, 1	f	large
69728	76966	1782	Ростовская область, Таганрог, Шевченко, 2	f	large
70103	77514	2349	Ростовская область, Таганрог, Шаумяна, 12	f	large
70100	77511	2346	Ростовская область, Таганрог, Шаумяна, 14	f	large
69767	76999	1822	Ростовская область, Таганрог, Чехова, 375	f	large
69740	76975	1794	Ростовская область, Таганрог, Чехова, 104	f	large
69731	76969	1785	Ростовская область, Таганрог, Чехова, 75	f	large
69814	77037	1869	Ростовская область, Таганрог, Черняховского, 7	f	large
69741	76976	1795	Ростовская область, Таганрог, Фрунзе, 40	f	large
69778	77007	1833	Ростовская область, Таганрог, Фадеева, 21	f	large
69733	76839	1787	Ростовская область, Таганрог, Украинский переулок, 8	f	large
69734	76896	1788	Россия, Ростовская область, Таганрог, Тургеневский переулок, 32	f	large
69779	77008	1834	Ростовская область, Таганрог, Транспортная, 1/5	f	large
69755	76989	1809	Ростовская область, Таганрог, Смирновский переулок, 26а	f	large
69737	76972	1791	Ростовская область, Таганрог, Смирновский переулок, 101а	f	large
69782	77012	1837	Ростовская область, Таганрог, Сергея Шило, 162	f	large
69784	77012	1839	Ростовская область, Таганрог, Сергея Шило, 162	f	large
87093	77010	1838	Ростовская область, Таганрог, Сергея Шило, 182-1	f	large
87092	77010	1836	Ростовская область, Таганрог, Сергея Шило, 182-1	f	large
69777	77006	1832	Ростовская область, Таганрог, Сергея Шило, 190	f	large
69776	77005	1831	Ростовская область, Таганрог, Сергея Шило, 196	f	large
69773	77003	1828	Ростовская область, Таганрог, Сергея Шило, 245	f	large
69816	77039	1871	Ростовская область, Таганрог, Сергея Лазо, 1	f	large
69753	76987	1807	Ростовская область, Таганрог, Свободы, 34	f	large
69752	76986	1806	Ростовская область, Таганрог, Свободы, 21	f	large
69751	76986	1805	Ростовская область, Таганрог, Свободы, 21	f	large
69747	76982	1801	Ростовская область, Таганрог, Свободы, 16	f	large
69746	76981	1800	Ростовская область, Таганрог, Свободы, 10	f	large
69808	77002	1863	Ростовская область, Таганрог, С. И. Шило, 202/а	f	large
69772	77002	1827	Ростовская область, Таганрог, С. И. Шило, 202/а	f	large
69760	76992	1814	Ростовская область, Таганрог, Розы Люксембург, 240к2	f	large
69759	76992	1813	Ростовская область, Таганрог, Розы Люксембург, 240к2	f	large
69821	77045	1876	Ростовская область, Таганрог, Поселковая, 58	f	large
69798	77024	1853	Ростовская область, Таганрог, Петровская, 109/А	f	large
69775	77004	1830	Ростовская область, Таганрог, Пархоменко, 21	f	large
69774	77004	1829	Ростовская область, Таганрог, Пархоменко, 21	f	large
69771	77000	1826	Ростовская область, Таганрог, Пархоменко, 5	f	large
69769	77000	1824	Ростовская область, Таганрог, Пархоменко, 5	f	large
69756	76990	1810	Ростовская область, Таганрог, Октябрьская, 44	f	large
83927	57343	3123	Москва, Зеленоград, к621а	f	large
69742	76977	1796	Ростовская область, Таганрог, Октябрьская, 7	f	large
69723	76958	1774	Ростовская область, Таганрог, Октябрьская, 72а	f	large
69729	76967	1783	Ростовская область, Таганрог, Некрасовский переулок, 44	f	large
69727	76965	1781	Ростовская область, Таганрог, Некрасовский переулок, 17	f	large
69811	77034	1866	Ростовская область, Таганрог, Московская, 72	f	large
69832	77054	1887	Ростовская область, Таганрог, Москатова, 1	f	large
70170	77632	2471	Ростовская область, Таганрог, Михайловская, 51/1	f	large
69825	77049	1880	Ростовская область, Таганрог, Маршала Жукова, 146/А	f	large
87095	77043	1875	Ростовская область, Таганрог, Маршала Жукова, 192	f	large
69788	77016	1843	Ростовская область, Таганрог, Ломоносова, 65	f	large
69736	76968	1790	Ростовская область, Таганрог, Ломакина, 2	f	large
69730	76968	1784	Ростовская область, Таганрог, Ломакина, 2	f	large
69743	76978	1797	Ростовская область, Таганрог, Лермонтовский переулок, 2	f	large
114548	76559	1323	Ростовская область, Таганрог, Ленина, 19	f	medium
114285	76206	977	Ростовская область, Таганрог, Ленина, 19а	f	medium
69749	76984	1803	Ростовская область, Таганрог, Красногвардейский переулок, 9	f	large
69764	76996	1819	Ростовская область, Таганрог, Котлостроительная, 21к2	f	large
69800	77025	1855	Ростовская область, Таганрог, Конторская, 76	f	large
69735	76971	1789	Ростовская область, Таганрог, Комсомольский переулок, 86а	f	large
69791	77019	1846	Ростовская область, Таганрог, Комарова, 30	f	large
69831	77053	1886	Ростовская область, Таганрог, Кирова, 2	f	large
69830	77053	1885	Ростовская область, Таганрог, Кирова, 2	f	large
69792	77015	1847	Ростовская область, Таганрог, Калинина, 109	f	large
69787	77015	1842	Ростовская область, Таганрог, Калинина, 109	f	large
69745	76980	1799	Ростовская область, Таганрог, Инструментальная, 25/2	f	large
69824	77048	1879	Ростовская область, Таганрог, Инициативная, 48	f	large
69802	77026	1857	Ростовская область, Таганрог, Заводская, 20/3	f	large
69801	77026	1856	Ростовская область, Таганрог, Заводская, 20/3	f	large
69732	76970	1786	Ростовская область, Таганрог, Добролюбовский переулок, 9	f	large
69806	77030	1861	Ростовская область, Таганрог, Дзержинского, 149	f	large
87094	77030	1867	Ростовская область, Таганрог, Дзержинского, 149	f	large
69803	77027	1858	Ростовская область, Таганрог, Дзержинского, 115	f	large
69799	77023	1854	Ростовская область, Таганрог, Дзержинского, 67	f	large
69797	77023	1852	Ростовская область, Таганрог, Дзержинского, 67	f	large
69726	76964	1780	Ростовская область, Таганрог, Греческая, 37	f	large
69762	76994	1817	Ростовская область, Таганрог, Восточная, 2	f	large
69789	77017	1844	Ростовская область, Таганрог, Вишневая, 21	f	large
70196	77017	2523	Ростовская область, Таганрог, Вишневая, 21	f	large
69761	76993	1815	Ростовская область, Таганрог, Большой проспект, 3	f	large
114590	76993	1816	Ростовская область, Таганрог, Большой проспект, 3	f	medium
69754	76988	1808	Ростовская область, Таганрог, Большой проспект, 48к1	f	large
69744	76979	1798	Россия, Ростовская область, Таганрог, Большой Садовый переулок, 11	f	large
69765	76997	1820	Ростовская область, Таганрог, Большая Бульварная, 12	f	large
70102	77513	2348	Ростовская область, Таганрог, Бабушкина, 43	f	large
70101	77512	2347	Ростовская область, Таганрог, Бабушкина, 2в	f	large
114836	77635	2474	Ростовская область, Таганрог, Афоновых, 2	f	small
69738	76973	1792	Ростовская область, Таганрог, Александровская, 47	f	large
69826	77050	1881	Россия, Ростовская область, Таганрог, 7-й Новый переулок, 75	f	large
69827	77051	1882	Ростовская область, Таганрог, 3-я Линия, 49	f	large
69828	77051	1883	Ростовская область, Таганрог, 3-я Линия, 49	f	large
69804	77028	1859	Ростовская область, Таганрог, 3-й Артиллерийский переулок, 21	f	large
69818	77041	1873	Ростовская область, Таганрог, 17-й Новый переулок, 5	f	large
69805	77029	1860	Россия, Ростовская область, Таганрог, 14-й Артиллерийский переулок, 21	f	large
70169	77631	2470	Россия, Ростовская область, Таганрог, 1-й Новый переулок, 8	f	large
69780	77009	1835	Ростовская область, Таганрог, Чехова, 299к1	f	large
69770	77001	1825	Ростовская область, Таганрог, Чехова, 339/3	f	large
69768	76998	1823	Ростовская область, Таганрог, Чехова, 357/3	f	large
69766	76998	1821	Ростовская область, Таганрог, Чехова, 357/3	f	large
69790	77018	1845	Ростовская область, Таганрог, Театральная, 1	f	large
69786	77014	1841	Ростовская область, Таганрог, Театральная, 6	f	large
69785	77013	1840	Ростовская область, Таганрог, Театральная, 20	f	large
69758	76991	1812	Ростовская область, Таганрог, Площадь Мира, 6	f	large
69757	76991	1811	Ростовская область, Таганрог, Площадь Мира, 6	f	large
69228	76092	868	Ростовская область, Таганрог, Плеханова, 8	f	large
68957	75563	324	Ростовская область, Семикаракорск, Атаманский проспект, 250	f	large
68956	75563	323	Ростовская область, Семикаракорск, Атаманский проспект, 250	f	large
69299	76461	1232	Ростовская область, Семикаракорск, Араканцева, 2	f	large
68955	75503	322	Ростовская область, Семикаракорск, 16-й переулок, 35	f	large
69043	75664	444	Ростовская область, Сальск, Кутузова, 1	f	large
69037	75658	437	Ростовская область, Сальск, Коломийцева, 128	f	large
69429	76661	1442	Ростовская область, Ростов-на-Дону, парк им. В.Черевичкина, спорткомплекс Экспресс 	f	large
69418	76646	1430	Ростовская область, Ростов-на-Дону, 3, Сельмаш	f	large
114353	76297	1067	Россия, Ростовская область, Ростов-на-Дону, улица Школьная, 18	f	small
69333	76574	1341	Ростовская область, Ростов-на-Дону, улица Фурмановская, 82	f	large
69332	76574	1340	Ростовская область, Ростов-на-Дону, улица Фурмановская, 82	f	large
69600	76852	1646	Ростовская область, Ростов-на-Дону, улица Тургеневская, 12	f	large
69598	76850	1644	Ростовская область, Ростов-на-Дону, улица Тургеневская, 48	f	large
69396	76626	1408	Ростовская область, Ростов-на-Дону, улица Туполева, 8	f	large
69658	76902	1705	Ростовская область, Ростов-на-Дону, улица Таганрогская, 137	f	large
114751	77465	2304	Россия, Ростовская область, Ростов-на-Дону, улица Советская, 1	f	medium
69602	76854	1648	Ростовская область, Ростов-на-Дону, улица Серафимовича, 25	f	large
69587	76836	1631	Россия, Ростовская область, Ростов-на-Дону, улица Пушкинская, 190	f	large
69472	76707	1491	Россия, Ростовская область, Ростов-на-Дону, улица Портовая, 166	f	large
69641	76889	1688	Ростовская область, Ростов-на-Дону, улица Погодина, 5а	f	large
69710	76941	1757	Ростовская область, Ростов-на-Дону, улица Пескова, 17к1	t	large
69408	76637	1420	Ростовская область, Ростов-на-Дону, улица Орская, 31А	f	large
114350	76294	1064	Россия, Ростовская область, Ростов-на-Дону, улица Молодежная, 4	f	small
69632	76881	1679	Россия, Ростовская область, Ростов-на-Дону, улица Мечникова, 61	f	large
69414	76640	1426	Россия, Ростовская область, Ростов-на-Дону, улица Металлургическая, 100	f	large
69411	76640	1423	Россия, Ростовская область, Ростов-на-Дону, улица Металлургическая, 100	f	large
69406	76634	1418	Россия, Ростовская область, Ростов-на-Дону, улица Мелитопольская, 22	f	large
69403	76634	1415	Россия, Ростовская область, Ростов-на-Дону, улица Мелитопольская, 22	f	large
69579	76827	1623	Россия, Ростовская область, Ростов-на-Дону, улица Малюгиной, 212	f	large
69230	76094	870	Ростовская область, Ростов-на-Дону, улица Максима Горького, 28	f	large
69544	76792	1587	Ростовская область, Ростов-на-Дону, улица Лесопарковая, 23	t	large
87083	76819	1616	Ростовская область, Ростов-на-Дону, улица Лермонтовская, 161	f	large
69557	76802	1600	Ростовская область, Ростов-на-Дону, улица Кулагина, 19	f	large
69546	76794	1589	Россия, Ростовская область, Ростов-на-Дону, улица Крупской, 43	f	large
69553	76794	1596	Россия, Ростовская область, Ростов-на-Дону, улица Крупской, 43	f	large
69552	76794	1595	Россия, Ростовская область, Ростов-на-Дону, улица Крупской, 43	f	large
69584	76832	1628	Ростовская область, Ростов-на-Дону, улица Красных Зорь, 157	f	large
69607	76859	1653	Россия, Ростовская область, Ростов-на-Дону, улица Красноармейская, 11	f	large
69698	76931	1745	Ростовская область, Ростов-на-Дону, улица Калининградская, 1	f	large
69391	76621	1403	Россия, Ростовская область, Ростов-на-Дону, улица Казахская, 107	f	large
69637	76885	1684	Россия, Ростовская область, Ростов-на-Дону, улица Зоологическая, 3	f	large
69703	76936	1750	Ростовская область, Ростов-на-Дону, улица Еременко, 56	f	large
69349	76587	1358	Ростовская область, Ростов-на-Дону, улица Добровольского, 15	f	large
69413	76642	1425	Ростовская область, Ростов-на-Дону, улица Днепропетровская, 10	f	large
69399	76630	1411	Ростовская область, Ростов-на-Дону, улица Днепропетровская, 14	f	large
69395	76625	1407	Россия, Ростовская область, Ростов-на-Дону, улица Днепропетровская, 44	f	large
69402	76633	1414	Ростовская область, Ростов-на-Дону, улица Глинки, 93	f	large
69614	76865	1660	Ростовская область, Ростов-на-Дону, улица Гайдара, 27	f	large
69613	76865	1659	Ростовская область, Ростов-на-Дону, улица Гайдара, 27	f	large
87050	76659	1441	Ростовская область, Ростов-на-Дону, улица Верхненольная, 15	f	large
87089	76898	1698	Ростовская область, Ростов-на-Дону, улица Вавилова, 1	f	large
69549	76795	1592	Россия, Ростовская область, Ростов-на-Дону, улица Балакирева, 32	f	large
69547	76795	1590	Россия, Ростовская область, Ростов-на-Дону, улица Балакирева, 32	f	large
114555	76702	1486	Россия, Ростовская область, Ростов-на-Дону, улица Аксайская, 22	f	medium
69434	76667	1448	Ростовская область, Ростов-на-Дону, улица 14-я Линия, 50	f	large
69433	76665	1446	Ростовская область, Ростов-на-Дону, улица 14-я Линия, 64	f	large
69431	76663	1444	Ростовская область, Ростов-на-Дону, улица 1-я Линия, 54	f	large
114554	76695	1477	Ростовская область, Ростов-на-Дону, станция Кизитеринка, вокзал	t	large
69639	76887	1686	Ростовская область, Ростов-на-Дону, проспект Ленина, 42а	f	large
70201	76567	2541	Ростовская область, Ростов-на-Дону, проспект Ленина, 105/3	f	large
69325	76567	1330	Ростовская область, Ростов-на-Дону, проспект Ленина, 105/3	f	large
69323	76565	1328	Ростовская область, Ростов-на-Дону, проспект Ленина, 125/1	f	large
69320	76561	1325	Ростовская область, Ростов-на-Дону, проспект Ленина, 92	f	large
69318	76557	1321	Ростовская область, Ростов-на-Дону, проспект Ленина, 217-219	f	large
69618	76869	1664	Ростовская область, Ростов-на-Дону, пер. Саратовский, 40	f	large
69375	76608	1387	Ростовская область, Ростов-на-Дону, Штахановского, 18	t	large
69423	76653	1435	Ростовская область, Ростов-на-Дону, Шолохова проспект, 294	f	large
87048	76651	1434	Ростовская область, Ростов-на-Дону, Шолохова проспект, 262	f	large
69421	76649	1433	Ростовская область, Ростов-на-Дону, Шолохова проспект, 272	f	large
69256	76244	1017	Ростовская область, Ростов-на-Дону, Шолохова проспект, 46	f	large
69440	76675	1456	Ростовская область, Ростов-на-Дону, Ченцова, 95	f	large
69539	76787	1582	Ростовская область, Ростов-на-Дону, Чебанова, 10	f	large
69625	76875	1672	Россия, Ростовская область, Ростов-на-Дону, Халтуринский переулок, 155	f	large
69605	76857	1651	Ростовская область, Ростов-на-Дону, Халтуринский переулок, 65	f	large
69633	76882	1680	Ростовская область, Ростов-на-Дону, Фрунзе, 12	f	large
69424	76654	1436	Ростовская область, Ростов-на-Дону, Фасадная, 99	t	large
69382	76614	1394	Ростовская область, Ростов-на-Дону, Украинская, 26	f	large
69397	76627	1409	Ростовская область, Ростов-на-Дону, Туполева, 4/1	f	large
69660	76904	1707	Ростовская область, Ростов-на-Дону, Тимошенко, 30	f	large
69661	76904	1708	Ростовская область, Ростов-на-Дону, Тимошенко, 30	f	large
69659	76903	1706	Ростовская область, Ростов-на-Дону, Тимошенко, 22	f	large
69590	76840	1634	Ростовская область, Ростов-на-Дону, Текучева, 201	f	large
69426	76656	1439	Ростовская область, Ростов-на-Дону, Театральный проспект, 46	f	large
69425	76655	1438	Ростовская область, Ростов-на-Дону, Театральный проспект, 48	f	large
70191	76905	2512	Ростовская область, Ростов-на-Дону, Таганрогская, 114	f	large
69662	76905	1709	Ростовская область, Ростов-на-Дону, Таганрогская, 114	f	large
69657	76901	1704	Ростовская область, Ростов-на-Дону, Таганрогская, 139/6	f	large
69656	76901	1703	Ростовская область, Ростов-на-Дону, Таганрогская, 139/6	f	large
87084	76835	1630	Ростовская область, Ростов-на-Дону, Суворова, 131	f	large
69410	76639	1422	Ростовская область, Ростов-на-Дону, Студенческая, 4	f	large
69689	76921	1736	Ростовская область, Ростов-на-Дону, Стачки проспект, 200	f	large
69687	76919	1734	Ростовская область, Ростов-на-Дону, Стачки проспект, 195	f	large
69685	76919	1732	Ростовская область, Ростов-на-Дону, Стачки проспект, 195	f	large
69686	76919	1733	Ростовская область, Ростов-на-Дону, Стачки проспект, 195	f	large
69684	76918	1731	Россия, Ростовская область, Ростов-на-Дону, Стачки проспект, 221	f	large
69683	76917	1730	Россия, Ростовская область, Ростов-на-Дону, Стачки проспект, 227	f	large
69682	76917	1729	Россия, Ростовская область, Ростов-на-Дону, Стачки проспект, 227	f	large
69540	76788	1583	Ростовская область, Ростов-на-Дону, Ставского проспект, 33	f	large
69591	76841	1635	Ростовская область, Ростов-на-Дону, Социалистическая, 195	f	large
69580	76828	1624	Ростовская область, Ростов-на-Дону, Социалистическая, 126	f	large
83926	57343	3122	Москва, Зеленоград, к621а	f	large
69457	76692	1474	Ростовская область, Ростов-на-Дону, Солидарности, 184	f	large
69571	76817	1615	Ростовская область, Ростов-на-Дону, Соколова проспект, 58	f	large
69701	76933	1748	Ростовская область, Ростов-на-Дону, Содружества, 43	f	large
69700	76933	1747	Ростовская область, Ростов-на-Дону, Содружества, 43	f	large
70173	76933	2475	Ростовская область, Ростов-на-Дону, Содружества, 43	f	large
70204	77694	2544	Ростовская область, Ростов-на-Дону, Совхозная, 18а	t	large
69446	76682	1463	Ростовская область, Ростов-на-Дону, Советская, 30/1	f	large
114426	76394	1166	Ростовская область, Ростов-на-Дону, Советская, 91	f	medium
69623	76872	1670	Россия, Ростовская область, Ростов-на-Дону, Соборный переулок, 88	f	large
69599	76851	1645	Россия, Ростовская область, Ростов-на-Дону, Соборный переулок, 1	f	large
69412	76641	1424	Ростовская область, Ростов-на-Дону, Сержантова, 10	f	large
69596	76848	1642	Ростовская область, Ростов-на-Дону, Серафимовича, 85	f	large
69627	76877	1674	Россия, Ростовская область, Ростов-на-Дону, Семашко переулок, 132	f	large
69595	76847	1641	Ростовская область, Ростов-на-Дону, Семашко переулок, 48-50	f	large
69417	76645	1429	Ростовская область, Ростов-на-Дону, Селиванова, 64/112	f	large
69438	76671	1452	Ростовская область, Ростов-на-Дону, Свободы площадь, 1	f	large
69452	76688	1469	Ростовская область, Ростов-на-Дону, Сарьяна, 86	f	large
69407	76629	1419	Ростовская область, Ростов-на-Дону, Ректорская, 11	f	large
69398	76629	1410	Ростовская область, Ростов-на-Дону, Ректорская, 11	f	large
69455	76689	1472	Ростовская область, Ростов-на-Дону, Расковой переулок, 28	f	large
69454	76689	1471	Ростовская область, Ростов-на-Дону, Расковой переулок, 28	f	large
87082	76796	1591	Ростовская область, Ростов-на-Дону, Рабочая площадь, 23	f	large
69575	76822	1619	Ростовская область, Ростов-на-Дону, Пушкинская, 128	f	large
69551	76799	1594	Ростовская область, Ростов-на-Дону, Профсоюзная, 45	f	large
69538	76786	1581	Ростовская область, Ростов-на-Дону, Профсоюзная, 29/22	f	large
69565	76809	1608	Россия, Ростовская область, Ростов-на-Дону, Пржевальского переулок, 30	f	large
69564	76808	1607	Ростовская область, Ростов-на-Дону, Портовая, 541а	f	large
70212	76808	2570	Ростовская область, Ростов-на-Дону, Портовая, 541а	f	large
69562	76806	1605	Ростовская область, Ростов-на-Дону, Портовая, 238	f	large
69558	76803	1601	Ростовская область, Ростов-на-Дону, Портовая, 82	f	large
69559	76803	1602	Ростовская область, Ростов-на-Дону, Портовая, 82	f	large
69416	76644	1428	Ростовская область, Ростов-на-Дону, Полторацкого, 10	f	large
69696	76929	1743	Ростовская область, Ростов-на-Дону, Петрозаводская, 137А	f	large
69695	76928	1742	Ростовская область, Ростов-на-Дону, Петрозаводская, 137а	f	large
70182	76928	2492	Ростовская область, Ростов-на-Дону, Петрозаводская, 137а	f	large
69645	76892	1692	Ростовская область, Ростов-на-Дону, Педагогический переулок, 24	f	large
87045	76581	1351	Ростовская область, Ростов-на-Дону, Пацаева, 11	f	large
69624	76874	1671	Ростовская область, Ростов-на-Дону, Островского переулок, 153	f	large
87044	76573	1339	Ростовская область, Ростов-на-Дону, Оренбургский переулок, 22, МБУЗ Городская поликлиника №3 г.Ростова-на-Дону	f	large
69330	76571	1338	Ростовская область, Ростов-на-Дону, Оренбургский, 26/55	f	large
70179	77646	2489	Ростовская область, Ростов-на-Дону, Орбитальная, 86к1	f	large
69367	76601	1376	Ростовская область, Ростов-на-Дону, Орбитальная, 78/1	f	large
69364	76599	1373	Ростовская область, Ростов-на-Дону, Орбитальная, 66к2	f	large
69366	76598	1375	Ростовская область, Ростов-на-Дону, Орбитальная, 50/1	f	large
69363	76598	1372	Ростовская область, Ростов-на-Дону, Орбитальная, 50/1	f	large
69355	76590	1364	Ростовская область, Ростов-на-Дону, Орбитальная, 26к1	f	large
69354	76590	1363	Ростовская область, Ростов-на-Дону, Орбитальная, 26к1	f	large
69322	76564	1327	Россия, Ростовская область, Ростов-на-Дону, Обуховский переулок, 3	f	large
69388	76616	1400	Ростовская область, Ростов-на-Дону, Обский переулок, 7/2	f	large
69385	76616	1397	Ростовская область, Ростов-на-Дону, Обский переулок, 7/2	f	large
69376	76609	1388	Россия, Ростовская область, Ростов-на-Дону, Обский переулок, 122	f	large
69601	76853	1647	Ростовская область, Ростов-на-Дону, Обороны, 24	f	large
69543	76791	1586	Ростовская область, Ростов-на-Дону, Некрасовская, 20	f	large
69642	76890	1689	Ростовская область, Ростов-на-Дону, Неклиновская, 4/1Б	f	large
69646	76893	1693	Россия, Ростовская область, Ростов-на-Дону, Народного Ополчения площадь, 2	f	large
69448	76684	1465	Ростовская область, Ростов-на-Дону, Мясникова, 10	f	large
69597	76849	1643	Ростовская область, Ростов-на-Дону, Московская, 51	f	large
69634	76883	1681	Ростовская область, Ростов-на-Дону, Михаила Нагибина проспект, 17к2	f	large
69329	76570	1337	Ростовская область, Ростов-на-Дону, Михаила Нагибина проспект, 33а	f	large
69328	76570	1336	Ростовская область, Ростов-на-Дону, Михаила Нагибина проспект, 33а	f	large
69327	76569	1334	Россия, Ростовская область, Ростов-на-Дону, Михаила Нагибина проспект, 29	f	large
69394	76624	1406	Ростовская область, Ростов-на-Дону, Миронова, 8а	f	large
69420	76648	1432	Ростовская область, Ростов-на-Дону, Мира площадь, 10	f	large
69419	76647	1431	Ростовская область, Ростов-на-Дону, Мира, 9	f	large
69542	76790	1585	Ростовская область, Ростов-на-Дону, Минераловодская, 128	t	large
69626	76876	1673	Ростовская область, Ростов-на-Дону, Мечникова, 130	f	large
69616	76868	1662	Ростовская область, Ростов-на-Дону, Мечникова, 41	f	large
69617	76867	1663	Ростовская область, Ростов-на-Дону, Мечникова, 17	f	large
87088	76866	1661	Ростовская область, Ростов-на-Дону, Мечникова, 19А	f	large
69622	76871	1669	Ростовская область, Ростов-на-Дону, Малюгиной, 163/72	f	large
69621	76871	1668	Ростовская область, Ростов-на-Дону, Малюгиной, 163/72	f	large
69583	76831	1627	Ростовская область, Ростов-на-Дону, Малюгиной, 233	f	large
70175	76920	2477	Ростовская область, Ростов-на-Дону, Малиновского, 36	f	large
69688	76920	1735	Ростовская область, Ростов-на-Дону, Малиновского, 36	f	large
69606	76858	1652	Ростовская область, Ростов-на-Дону, Максима Горького, 30	f	large
69594	76846	1640	Ростовская область, Ростов-на-Дону, Максима Горького, 115	f	large
69578	76826	1622	Ростовская область, Ростов-на-Дону, Максима Горького, 166	f	large
87091	76932	1746	Ростовская область, Ростов-на-Дону, Мадояна, 205б	f	large
87110	76932	2491	Ростовская область, Ростов-на-Дону, Мадояна, 205б	t	large
69545	76793	1588	Ростовская область, Ростов-на-Дону, Мадояна, 126	f	large
69554	76800	1597	Ростовская область, Ростов-на-Дону, Литвинова, 4	f	large
69447	76683	1464	Ростовская область, Ростов-на-Дону, Листопадова, 42/79	f	large
69588	76837	1632	Ростовская область, Ростов-на-Дону, Лермонтовская, 229	f	large
69631	76880	1678	Ростовская область, Ростов-на-Дону, Лениногорская, 9	f	large
69638	76886	1685	Ростовская область, Ростов-на-Дону, Ленина проспект, 61	f	large
69324	76566	1329	Ростовская область, Ростов-на-Дону, Ленина проспект, 64к2	f	large
87043	76563	1326	Ростовская область, Ростов-на-Дону, Ленина проспект, 113к4	f	large
69319	76560	1324	Ростовская область, Ростов-на-Дону, Ленина проспект, 92/1	f	large
87042	76555	1320	Ростовская область, Ростов-на-Дону, Ленина проспект, 245	f	large
69644	76891	1691	Россия, Ростовская область, Ростов-на-Дону, Ленина проспект, 44	f	large
69636	76884	1683	Ростовская область, Ростов-на-Дону, Ленина проспект, 83а	f	large
69635	76884	1682	Ростовская область, Ростов-на-Дону, Ленина проспект, 83а	f	large
69373	76606	1385	Ростовская область, Ростов-на-Дону, Лелюшенко, 7	f	large
69372	76606	1384	Ростовская область, Ростов-на-Дону, Лелюшенко, 7	f	large
69370	76604	1382	Ростовская область, Ростов-на-Дону, Лелюшенко, 3	f	large
69326	76568	1333	Ростовская область, Ростов-на-Дону, Ларина, 24а	f	large
69405	76636	1417	Ростовская область, Ростов-на-Дону, Курчатова, 2	f	large
114862	77680	2527	Ростовская область, Ростов-на-Дону, Кумженская, 62 А	t	small
69643	76888	1690	Ростовская область, Ростов-на-Дону, Кропоткина, 31	f	large
69640	76888	1687	Ростовская область, Ростов-на-Дону, Кропоткина, 31	f	large
69473	76708	1492	Ростовская область, Ростов-на-Дону, Кривоноса, 9/4	f	large
69664	76708	1711	Ростовская область, Ростов-на-Дону, Кривоноса, 9/4	f	large
69665	76708	1712	Ростовская область, Ростов-на-Дону, Кривоноса, 9/4	f	large
69589	76838	1633	Россия, Ростовская область, Ростов-на-Дону, Крепостной переулок, 139	f	large
69709	76940	1756	Ростовская область, Ростов-на-Дону, Красноярский переулок, 26	f	large
69608	76860	1654	Ростовская область, Ростов-на-Дону, Красноармейская, 5	f	large
69582	76830	1626	Ростовская область, Ростов-на-Дону, Красноармейская, 232	f	large
69468	76703	1487	Ростовская область, Ростов-на-Дону, Краеведческая, 13	f	large
70207	77696	2547	Ростовская область, Ростов-на-Дону, Космонавтов проспект, 24	f	large
70208	77697	2548	Ростовская область, Ростов-на-Дону, Космонавтов площадь, 6к1	f	large
69361	76597	1370	Ростовская область, Ростов-на-Дону, Космонавтов площадь, 36	f	large
69359	76594	1368	Ростовская область, Ростов-на-Дону, Космонавтов, 18/2	f	large
69362	76596	1371	Ростовская область, Ростов-на-Дону, Королева проспект, 25к3	f	large
69360	76596	1369	Ростовская область, Ростов-на-Дону, Королева проспект, 25к3	f	large
69356	76589	1365	Ростовская область, Ростов-на-Дону, Королева проспект, 15	f	large
69353	76589	1362	Ростовская область, Ростов-на-Дону, Королева проспект, 15	f	large
69347	76585	1356	Ростовская область, Ростов-на-Дону, Королева проспект, 12	f	large
69346	76585	1355	Ростовская область, Ростов-на-Дону, Королева проспект, 12	f	large
69453	76687	1470	Ростовская область, Ростов-на-Дону, Комсомольская, 57	f	large
69451	76687	1468	Ростовская область, Ростов-на-Дону, Комсомольская, 57	f	large
69681	76916	1728	Ростовская область, Ростов-на-Дону, Коммунистический проспект, 42	f	large
69680	76916	1727	Ростовская область, Ростов-на-Дону, Коммунистический проспект, 42	f	large
69679	76915	1726	Россия, Ростовская область, Ростов-на-Дону, Коммунистический проспект, 11	f	large
69444	76678	1461	Ростовская область, Ростов-на-Дону, Коммунаров, 34	f	large
69442	76678	1459	Ростовская область, Ростов-на-Дону, Коммунаров, 34	f	large
69712	76588	1759	Ростовская область, Ростов-на-Дону, Комарова бульвар, 6	f	large
69352	76588	1361	Ростовская область, Ростов-на-Дону, Комарова бульвар, 6	f	large
69351	76588	1360	Ростовская область, Ростов-на-Дону, Комарова бульвар, 6	f	large
69350	76586	1359	Ростовская область, Ростов-на-Дону, Комарова бульвар, 18	f	large
69348	76586	1357	Ростовская область, Ростов-на-Дону, Комарова бульвар, 18	f	large
69369	76586	1380	Ростовская область, Ростов-на-Дону, Комарова бульвар, 18	f	large
69345	76584	1354	Ростовская область, Ростов-на-Дону, Комарова бульвар, 28	f	large
69344	76584	1353	Ростовская область, Ростов-на-Дону, Комарова бульвар, 28	f	large
69343	76583	1352	Ростовская область, Ростов-на-Дону, Комарова бульвар, 3	f	large
69340	76579	1349	Ростовская область, Ростов-на-Дону, Комарова бульвар, 7	f	large
69339	76578	1348	Ростовская область, Ростов-на-Дону, Комарова бульвар, 9к5	f	large
69338	76578	1347	Ростовская область, Ростов-на-Дону, Комарова бульвар, 9к5	f	large
69393	76618	1405	Ростовская область, Ростов-на-Дону, Киргизская, 12	f	large
69387	76618	1399	Ростовская область, Ростов-на-Дону, Киргизская, 12	f	large
69386	76617	1398	Ростовская область, Ростов-на-Дону, Киргизская, 41	f	large
69670	76909	1717	Ростовская область, Ростов-на-Дону, Каширская, 20	f	large
69669	76909	1716	Ростовская область, Ростов-на-Дону, Каширская, 20	f	large
69668	76909	1715	Ростовская область, Ростов-на-Дону, Каширская, 20	f	large
69697	76930	1744	Ростовская область, Ростов-на-Дону, Калининградская, 1	f	large
69390	76620	1402	Ростовская область, Ростов-на-Дону, Казахская, 89к4	f	large
69389	76619	1401	Ростовская область, Ростов-на-Дону, Казахская, 80/1	f	large
87115	77759	2617	Ростовская область, Ростов-на-Дону, Зорге, 28	f	large
87090	76926	1741	Ростовская область, Ростов-на-Дону, Зорге, 7	f	large
69400	76631	1412	Ростовская область, Ростов-на-Дону, Зои Космодемьянской, 47	t	large
69577	76824	1621	Ростовская область, Ростов-на-Дону, Журавлева переулок, 24	f	large
69708	76939	1755	Ростовская область, Ростов-на-Дону, Еременко, 87	f	large
69705	76937	1752	Ростовская область, Ростов-на-Дону, Еременко, 60к5	f	large
69704	76935	1751	Ростовская область, Ростов-на-Дону, Еременко, 56к4	f	large
69702	76935	1749	Ростовская область, Ростов-на-Дону, Еременко, 56к4	f	large
69610	76862	1656	Россия, Ростовская область, Ростов-на-Дону, Доломановский переулок, 93	f	large
69383	76615	1395	Ростовская область, Ростов-на-Дону, Днепровский переулок, 103/18	f	large
69378	76611	1390	Ростовская область, Ростов-на-Дону, Днепровский переулок, 116	f	large
69377	76610	1389	Ростовская область, Ростов-на-Дону, Днепровский переулок, 131	f	large
69379	76610	1391	Ростовская область, Ростов-на-Дону, Днепровский переулок, 131	f	large
69443	76680	1460	Ростовская область, Ростов-на-Дону, Дзержинского переулок, 1	f	large
69561	76805	1604	Ростовская область, Ростов-на-Дону, Деревянко переулок, 12	f	large
111564	57342	3121	Москва, Зеленоград, к621а	f	medium
69541	76789	1584	Ростовская область, Ростов-на-Дону, Гусева, 2	f	large
69654	76900	1701	Ростовская область, Ростов-на-Дону, Госпитальный переулок, 3	f	large
69445	76681	1462	Ростовская область, Ростов-на-Дону, Горсоветская, 49	f	large
69456	76691	1473	Ростовская область, Ростов-на-Дону, Герцена, 4	f	large
87085	76861	1655	Ростовская область, Ростов-на-Дону, Гвардейский переулок, 2	f	large
69629	76878	1676	Ростовская область, Ростов-на-Дону, Гагарина площадь, 1	f	large
69628	76878	1675	Ростовская область, Ростов-на-Дону, Гагарина площадь, 1	f	large
69415	76643	1427	Ростовская область, Ростов-на-Дону, Вятская, 112Б	f	large
69384	76613	1396	Ростовская область, Ростов-на-Дону, Вятская, 27	f	large
69381	76613	1393	Ростовская область, Ростов-на-Дону, Вятская, 27	f	large
69380	76612	1392	Ростовская область, Ростов-на-Дону, Вятская, 108	f	large
69566	76810	1609	Ростовская область, Ростов-на-Дону, Всесоюзная, 128	f	large
69574	76821	1618	Россия, Ростовская область, Ростов-на-Дону, Ворошиловский проспект, 29	f	large
69567	76813	1611	Ростовская область, Ростов-на-Дону, Ворошиловский проспект, 2	f	large
87046	76592	1367	Ростовская область, Ростов-на-Дону, Волкова, 41к1	f	large
69357	76591	1366	Ростовская область, Ростов-на-Дону, Волкова, 18	f	large
69337	76577	1346	Ростовская область, Ростов-на-Дону, Волкова, 5	f	large
69334	76575	1342	Ростовская область, Ростов-на-Дону, Волкова, 6к2	f	large
69563	76807	1606	Ростовская область, Ростов-на-Дону, Войкова, 136	f	large
69550	76798	1593	Ростовская область, Ростов-на-Дону, Верещагина, 10	f	large
87087	76864	1658	Ростовская область, Ростов-на-Дону, Варфоломеева, 1а	f	large
87086	76864	1657	Ростовская область, Ростов-на-Дону, Варфоломеева, 1а	f	large
69573	76820	1617	Ростовская область, Ростов-на-Дону, Варфоломеева, 259	f	large
69652	76895	1699	Ростовская область, Ростов-на-Дону, Вавилова, 58	f	large
69650	76895	1697	Ростовская область, Ростов-на-Дону, Вавилова, 58	f	large
87049	76658	1440	Ростовская область, Ростов-на-Дону, В.Нольная, 8	f	large
69432	76664	1445	Ростовская область, Ростов-на-Дону, В.Закруткина, 67	f	large
69693	76925	1740	Ростовская область, Ростов-на-Дону, Быковского, 5	f	large
69692	76925	1739	Ростовская область, Ростов-на-Дону, Быковского, 5	f	large
69441	76676	1457	Ростовская область, Ростов-на-Дону, Буйнакская, 12	f	large
69630	76879	1677	Россия, Ростовская область, Ростов-на-Дону, Буденновский проспект, 100	f	large
69620	76870	1667	Россия, Ростовская область, Ростов-на-Дону, Буденновский проспект, 64	f	large
69619	76870	1666	Россия, Ростовская область, Ростов-на-Дону, Буденновский проспект, 64	f	large
69603	76855	1649	Ростовская область, Ростов-на-Дону, Буденновский проспект, 39-41	f	large
69404	76635	1416	Ростовская область, Ростов-на-Дону, Брестская, 1/79	f	large
69341	76580	1350	Ростовская область, Ростов-на-Дону, Борко, 3к1	f	large
69604	76856	1650	Ростовская область, Ростов-на-Дону, Большая Садовая, 33	f	large
69585	76833	1629	Ростовская область, Ростов-на-Дону, Большая Садовая, 170	f	large
69569	76815	1613	Ростовская область, Ростов-на-Дону, Большая Садовая, 69	f	large
69365	76600	1374	Ростовская область, Ростов-на-Дону, Беляева, 24/1	f	large
87047	76622	1404	Ростовская область, Ростов-на-Дону, Беломорский переулок, 16	f	large
69690	76923	1737	Ростовская область, Ростов-на-Дону, Андрея Сладкова, 85	f	large
69560	76804	1603	Ростовская область, Ростов-на-Дону, Амбулаторная, 95	f	large
69655	76899	1702	Ростовская область, Ростов-на-Дону, Авиамоторный переулок, 13	f	large
69653	76899	1700	Ростовская область, Ростов-на-Дону, Авиамоторный переулок, 13	f	large
69470	76705	1489	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 65к5	f	large
69469	76704	1488	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 312	f	large
69466	76700	1484	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 73	f	large
69465	76700	1483	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 73	f	large
69464	76699	1482	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 65/12	f	large
69463	76698	1481	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 63	f	large
69462	76698	1480	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 63	f	large
69461	76697	1479	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 43б	f	large
69460	76696	1478	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 27а	f	large
69459	76694	1476	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 81	f	large
69458	76693	1475	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 87к4	f	large
69450	76686	1467	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 87к4	f	large
114553	76677	1458	Россия, Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 306	f	medium
69430	76662	1443	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 95	f	large
69467	76662	1485	Ростовская область, Ростов-на-Дону, 40-летия Победы проспект, 95	f	large
70205	77695	2545	Ростовская область, Ростов-на-Дону, 339-й Стрелковой Дивизии, 21/3	f	large
69707	76938	1754	Ростовская область, Ростов-на-Дону, 339-й Стрелковой Дивизии, 15	f	large
69713	76943	1760	Ростовская область, Ростов-на-Дону, 339-й Стрелковой Дивизии, 21/3	f	large
70206	76943	2546	Ростовская область, Ростов-на-Дону, 339-й Стрелковой Дивизии, 21/3	f	large
69439	76672	1453	Ростовская область, Ростов-на-Дону, 31-я Линия, 4	f	large
69436	76669	1450	Ростовская область, Ростов-на-Дону, 28-я линия, 55/56а	f	large
69437	76670	1451	Ростовская область, Ростов-на-Дону, 24-я Линия, 2/5	f	large
69449	76685	1466	Ростовская область, Ростов-на-Дону, 23-я Линия, 43	f	large
69678	76914	1725	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 68А	f	large
69677	76914	1724	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 68А	f	large
69676	76913	1723	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 80/13	f	large
70174	76912	2476	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 82	f	large
69675	76912	1722	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 82	f	large
69674	76912	1721	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 82	f	large
69673	76911	1720	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 94	f	large
69672	76911	1719	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 94	f	large
69671	76910	1718	Ростовская область, Ростов-на-Дону, 2-я Краснодарская, 149к1	f	large
69471	76706	1490	Ростовская область, Ростов-на-Дону, 2-я Володарская, 78	f	large
69556	76706	1599	Ростовская область, Ростов-на-Дону, 2-я Володарская, 78	f	large
69649	76894	1696	Ростовская область, Ростов-на-Дону, 2-й Пятилетки, 10	f	large
69648	76894	1695	Ростовская область, Ростов-на-Дону, 2-й Пятилетки, 10	f	large
69647	76894	1694	Ростовская область, Ростов-на-Дону, 2-й Пятилетки, 10	f	large
69435	76668	1449	Ростовская область, Ростов-на-Дону, 1-я Майская, 34	f	large
69555	76801	1598	Ростовская область, Ростов-на-Дону, 1-я Круговая, 91	f	large
69409	76638	1421	Ростовская область, Ростов-на-Дону, Урожайная, 4/82	f	large
70180	76906	2490	Ростовская область, Ростов-на-Дону, Таганрогская, 118к2	f	large
69663	76906	1710	Ростовская область, Ростов-на-Дону, Таганрогская, 118к2	f	large
69576	76823	1620	Ростовская область, Ростов-на-Дону, Седова, 8	f	large
69374	76607	1386	Ростовская область, Ростов-на-Дону, Миронова, 12	f	large
69570	76816	1614	Ростовская область, Ростов-на-Дону, Максима Горького, 108	f	large
69371	76605	1383	Ростовская область, Ростов-на-Дону, Думенко, 3А	f	large
69336	76576	1345	Ростовская область, Ростов-на-Дону, Волкова, 6к3	f	large
69335	76576	1343	Ростовская область, Ростов-на-Дону, Волкова, 6к3	f	large
69401	76632	1413	Ростовская область, Ростов-на-Дону, Волжская, 19	f	large
69581	76829	1625	Ростовская область, Ростов-на-Дону, Большая Садовая, 105	f	large
69691	76924	1738	Ростовская область, Ростов-на-Дону, 339-й Стрелковой Дивизии, 25к3	f	large
69706	76924	1753	Ростовская область, Ростов-на-Дону, 339-й Стрелковой Дивизии, 25к3	f	large
70233	76924	2618	Ростовская область, Ростов-на-Дону, 339-й Стрелковой Дивизии, 25к3	f	large
69136	75922	704	Ростовская область, Пролетарск, пер.Красный, 31	f	large
69133	75919	701	Ростовская область, Пролетарск, Пионерская, 200	f	large
69135	75921	703	Ростовская область, Пролетарск, Думенко, 139	f	large
69132	75918	700	Ростовская область, Пролетарск, Думенко, 162	f	large
69138	75924	706	Ростовская область, Пролетарск, Дорожная, 5	f	large
70122	77530	2368	Ростовская область, Новошахтинск, Энергетическая, 6	t	large
114786	77550	2388	Ростовская область, Новошахтинск, Энгельса, 8	f	medium
70137	77549	2387	Ростовская область, Новошахтинск, Энгельса, 2	f	large
70139	77556	2394	Ростовская область, Новошахтинск, Щербакова, 21	f	large
70138	77556	2393	Ростовская область, Новошахтинск, Щербакова, 21	f	large
83925	57342	3120	Москва, Зеленоград, к621а	f	large
70110	77520	2356	Ростовская область, Новошахтинск, Школьная, 7	f	large
70120	77528	2366	Ростовская область, Новошахтинск, Харьковская, 84	f	large
70119	77527	2365	Ростовская область, Новошахтинск, Харьковская, 18	f	large
70127	77535	2374	Ростовская область, Новошахтинск, Союзная, 1	f	large
70112	77522	2358	Ростовская область, Новошахтинск, Советской Конституции, 36	f	large
70111	77521	2357	Ростовская область, Новошахтинск, Советской Конституции, 52	f	large
70108	77518	2354	Ростовская область, Новошахтинск, Советская, 1/18б	f	large
70124	77532	2371	Ростовская область, Новошахтинск, Радио, 24	f	large
70123	77532	2370	Ростовская область, Новошахтинск, Радио, 24	f	large
70130	77537	2377	Ростовская область, Новошахтинск, Рабоче-Крестьянская, 19	f	large
70128	77507	2375	Ростовская область, Новошахтинск, Рабочая, 2	f	large
70113	77523	2359	Ростовская область, Новошахтинск, Просвещения, 28	f	large
70147	77568	2405	Ростовская область, Новошахтинск, Пирогова, 26	f	large
114792	77559	2397	Ростовская область, Новошахтинск, Перова, 1а	f	medium
114987	77540	2381	Ростовская область, Новошахтинск, Назаренко, 1Б/14	f	medium
70129	77536	2376	Ростовская область, Новошахтинск, Молодогвардейцев, 6	f	large
70143	77564	2401	Ростовская область, Новошахтинск, Молдавская, 3	t	large
70146	77567	2404	Ростовская область, Новошахтинск, Моисеенко, 2/1а	t	large
70114	77524	2360	Ростовская область, Новошахтинск, Мичурина, 52а/2б	f	large
114784	77542	2382	Ростовская область, Новошахтинск, Маяковского, 58а	f	medium
70118	77526	2364	Ростовская область, Новошахтинск, Малосадовая, 6	f	large
70117	77526	2363	Ростовская область, Новошахтинск, Малосадовая, 6	f	large
70140	77558	2396	Ростовская область, Новошахтинск, Магистральная, 8а	t	large
70126	77534	2373	Ростовская область, Новошахтинск, Ленинградская, 40	f	large
70125	77533	2372	Ростовская область, Новошахтинск, Ленинградская, 28	f	large
70106	77516	2352	Ростовская область, Новошахтинск, Ленина, 54	f	large
70105	77516	2351	Ростовская область, Новошахтинск, Ленина, 54	f	large
70144	77565	2402	Ростовская область, Новошахтинск, Курская, 21б	f	large
87105	77544	2383	Ростовская область, Новошахтинск, Краснофлотская, 22/8	f	large
87107	77562	2400	Ростовская область, Новошахтинск, Котельникова, 7а/20/13	t	large
70145	77566	2403	Ростовская область, Новошахтинск, Королева, 2б	f	large
70131	77538	2378	Ростовская область, Новошахтинск, Киевская, 15	f	large
114788	77553	2390	Ростовская область, Новошахтинск, Казахстанская, 7	f	medium
114988	77552	2389	Ростовская область, Новошахтинск, Грессовская, 21/17/1	f	medium
87106	77545	2384	Ростовская область, Новошахтинск, Грессовсая, 21/17/1	f	large
70121	77529	2367	Ростовская область, Новошахтинск, Горького, 13	t	large
70109	77519	2355	Ростовская область, Новошахтинск, Горняцкая, 24	f	large
70141	77561	2399	Ростовская область, Новошахтинск, Восточная, 8г	t	large
114782	77531	2369	Ростовская область, Новошахтинск, Вокзальная, 2а	f	large
114789	77554	2391	Ростовская область, Новошахтинск, Войкова, 66а	f	medium
70116	77525	2362	Ростовская область, Новошахтинск, 60 лет Октября, 20	f	large
70115	77525	2361	Ростовская область, Новошахтинск, 60 лет Октября, 20	f	large
114793	77560	2398	Ростовская область, Новошахтинск, Поленова, 1	t	small
68854	75315	93	Ростовская область, Новочеркасск, Театральная, 1	f	large
68822	75282	60	Ростовская область, Новочеркасск, Платовский проспект, 37	f	large
87064	75279	56	Ростовская область, Новочеркасск, Платовский пр-т, 37С	f	large
113816	75269	47	Ростовская область, Новочеркасск, Панфилова, 10	f	medium
87066	75294	72	Ростовская область, Новочеркасск, Михайловская, 166, ГОУ СПО НМК	f	large
68861	75324	101	Ростовская область, Новочеркасск, Макаренко, 14	f	large
68860	75324	100	Ростовская область, Новочеркасск, Макаренко, 14	f	large
68813	75274	51	Ростовская область, Новочеркасск, Крылова, 6	f	large
114842	77642	2485	Ростовская область, Новочеркасск, Интернатный пер, 7	f	medium
68817	75277	55	Ростовская область, Новочеркасск, Дубовского, 3	f	large
68827	75286	65	Ростовская область, Новочеркасск, Дворцовая, 12	f	large
68848	75310	87	Ростовская область, Новочеркасск, Гвардейская, 24	f	large
68847	75310	86	Ростовская область, Новочеркасск, Гвардейская, 24	f	large
68815	75275	53	Ростовская область, Новочеркасск, Буденновская, 21	f	large
83924	57341	3119	Москва, Зеленоград, к603а	f	large
68814	75275	52	Ростовская область, Новочеркасск, Буденновская, 21	f	large
70178	77644	2487	Ростовская область, Новочеркасск, Баклановский проспект, 79	f	large
68810	75270	48	Ростовская область, Новочеркасск, Баклановский проспект, 118	f	large
68807	75266	44	Ростовская область, Новочеркасск, Баклановский пр-т, 150	f	large
68806	75265	43	Ростовская область, Новочеркасск, Баклановский пр-т, 166	f	large
87065	75288	66	Ростовская область, Новочеркасск, Б.Хмельницкого, 38, НГОО СВА	f	large
68824	75283	62	Ростовская область, Новочеркасск, Александровская, 62	f	large
68823	75283	61	Ростовская область, Новочеркасск, Александровская, 62	f	large
69265	76315	1084	Ростовская область, Морозовск, Руднева, 98	f	large
87057	76314	1083	Ростовская область, Морозовск, Руднева, 98	f	large
69268	76318	1088	Ростовская область, Морозовск, Ленина, 157	f	large
69276	76326	1096	Ростовская область, Морозовск, Ворошилова, 211	f	large
69233	76097	873	Ростовская область, Миллерово, Черноморская, 52	f	large
68920	75482	247	Ростовская область, Миллерово, 3-го Интернационала, 21	f	large
114747	77448	2288	Ростовская область, Красный Сулин, Коммунистическая, 1а	t	small
70184	77652	2498	Ростовская область, Константиновск, Коммунистическая, 224	f	large
68927	75492	254	Ростовская область, Константиновск, Донская, 1	f	large
68924	75487	251	Ростовская область, Константиновск, 25 Октября, 57	f	large
87053	76051	830	Ростовская область, Каменск-Шахтинский, переулок Придорожный, 83	f	large
87055	76081	857	Ростовская область, Каменск-Шахтинский, пер.Советский, 43, Лесозащитная станция	t	large
87054	76066	844	Ростовская область, Каменск-Шахтинский, Ученическая, 7	f	large
69185	76043	822	Ростовская область, Каменск-Шахтинский, Танкистов, 28	f	large
69211	76073	850	Ростовская область, Каменск-Шахтинский, Строителей, 2	t	large
69214	76076	853	Ростовская область, Каменск-Шахтинский, Советская, 38	t	large
69186	76044	823	Ростовская область, Каменск-Шахтинский, Просторный, 1	t	large
69216	76078	855	Ростовская область, Каменск-Шахтинский, Победы, 7	t	large
69207	76068	845	Ростовская область, Каменск-Шахтинский, Пивоварова, 16	f	large
69286	76396	1168	Ростовская область, Каменск-Шахтинский, Парковая, 14	t	large
87052	76040	820	Ростовская область, Каменск-Шахтинский, Парк Культуры, 8	f	large
69184	76042	821	Ростовская область, Каменск-Шахтинский, Островского, 57	f	large
69203	76063	841	Ростовская область, Каменск-Шахтинский, Освобождения, 46а	f	large
69188	76046	825	Ростовская область, Каменск-Шахтинский, Мусина, 80	f	large
69182	76039	819	Ростовская область, Каменск-Шахтинский, Мира, 20	f	large
69208	76069	846	Ростовская область, Каменск-Шахтинский, Микрорайон 60-лет Октября, 7	f	large
69212	76074	851	Ростовская область, Каменск-Шахтинский, Луначарского, 1	f	large
69189	76047	826	Ростовская область, Каменск-Шахтинский, Ленина, 25	f	large
69199	76059	837	Ростовская область, Каменск-Шахтинский, Крупской, 82	f	large
69196	76056	834	Ростовская область, Каменск-Шахтинский, Крупской, 48	f	large
69204	76064	842	Ростовская область, Каменск-Шахтинский, Красная, 20а	f	large
69209	76070	847	Ростовская область, Каменск-Шахтинский, Котовского, 15	f	large
69191	76049	828	Ростовская область, Каменск-Шахтинский, Коммунистический, 72	f	large
69195	76055	833	Ростовская область, Каменск-Шахтинский, Кирова, 98	f	large
69187	76045	824	Ростовская область, Каменск-Шахтинский, Кирова, 4	f	large
69197	76057	835	Ростовская область, Каменск-Шахтинский, К.Маркса, 58	f	large
114195	76053	831	Ростовская область, Каменск-Шахтинский, К.Маркса, 62	f	medium
69285	76392	1164	Ростовская область, Каменск-Шахтинский, Западная, 2	t	large
69201	76061	839	Ростовская область, Каменск-Шахтинский, Желябова, 107	f	large
114196	76071	848	Ростовская область, Каменск-Шахтинский, Дружбы, 1	f	medium
69220	76083	859	Ростовская область, Каменск-Шахтинский, Героев Пионеров, 81	f	large
69215	76077	854	Ростовская область, Каменск-Шахтинский, Гагарина, 141	t	large
69213	76075	852	Ростовская область, Каменск-Шахтинский, Гагарина, 16	t	large
69202	76062	840	Ростовская область, Каменск-Шахтинский, Гагарина, 93	f	large
87109	77626	2462	Ростовская область, Каменск-Шахтинский, Ворошилова, 143	f	large
69192	76050	829	Ростовская область, Каменск-Шахтинский, Володарского, 74	f	large
70062	77428	2268	Ростовская область, Гуково, Куйбышева, 1а	f	large
69190	76048	827	Ростовская область, Каменск-Шахтинский, Володарского, 43	f	large
69219	76082	858	Ростовская область, Каменск-Шахтинский, Вокзальная, 114	t	large
69210	76072	849	Ростовская область, Каменск-Шахтинский, Больничная, 10	t	large
69200	76060	838	Ростовская область, Каменск-Шахтинский, Башкевича, 106а	f	large
69198	76058	836	Ростовская область, Каменск-Шахтинский, Башкевича, 84	f	large
69194	76054	832	Ростовская область, Каменск-Шахтинский, Астаховский, 96	f	large
68917	75478	243	Ростовская область, Зерноград, Мира, 1	f	large
68912	75470	236	Ростовская область, Зерноград, Колодина, 5	f	large
68910	75468	234	Ростовская область, Зерноград, Калинина, 49	f	large
70031	77389	2232	Ростовская область, Зверево, Школьная, 7	f	large
70027	77386	2228	Ростовская область, Зверево, Строительная, 19	f	large
70177	77384	2482	Ростовская область, Зверево, Советская, 120а	f	large
70025	77384	2226	Ростовская область, Зверево, Советская, 120а	f	large
70034	77392	2235	Ростовская область, Зверево, Рижская, 11	f	large
70032	77390	2233	Ростовская область, Зверево, Рижская, 7	f	large
70029	77388	2230	Ростовская область, Зверево, Осташенко, 10	f	large
70176	77636	2478	Ростовская область, Зверево, Обухова, 7	f	large
70030	77387	2231	Ростовская область, Зверево, Обухова, 45	f	large
70028	77387	2229	Ростовская область, Зверево, Обухова, 45	f	large
70033	77391	2234	Ростовская область, Зверево, Ивановская, 11	f	large
70026	77385	2227	Ростовская область, Зверево, Горького, 65а	f	large
70224	77748	2606	Ростовская область, Донецк, проспект Мира, 35	f	large
69177	76031	811	Ростовская область, Донецк, проспект Мира, 21	f	large
69173	76028	807	Ростовская область, Донецк, проспект Мира, 57	f	large
69174	76013	808	Ростовская область, Донецк, проспект Мира, 41	f	large
114190	76021	800	Ростовская область, Донецк, переулок Октябрьский, 53	f	medium
70226	77750	2608	Ростовская область, Донецк, переулок Молодежный, 14	f	large
69176	76030	810	Ростовская область, Донецк, переулок Гагарина, 70	f	large
69175	76029	809	Ростовская область, Донецк, Экскаваторная, 1	f	large
69178	76033	813	Ростовская область, Донецк, Шевченко, 6	f	large
69180	76036	816	Ростовская область, Донецк, Цветкова, 20а	f	large
70227	77751	2609	Ростовская область, Донецк, Тимирязева, 44	f	large
69166	76019	798	Ростовская область, Донецк, Советская, 51	f	large
69181	76038	818	Ростовская область, Донецк, Пролетарская, 100	f	large
114194	76037	817	Ростовская область, Донецк, Обогатителей, 25	f	medium
69179	76034	814	Ростовская область, Донецк, Некрасова, 27б	f	large
69170	76025	804	Ростовская область, Донецк, Мичурина, 75	f	large
69172	76027	806	Ростовская область, Донецк, Королева, 12	f	large
69171	76026	805	Ростовская область, Донецк, Королева, 19	f	large
114191	76024	803	Ростовская область, Донецк, Второй Аварийный, 10	f	medium
69167	76020	799	Ростовская область, Донецк, Братьев Дорошевых, 23а	f	large
70228	77752	2610	Ростовская область, Донецк, 3 микрорайон, 24	f	large
69169	76023	802	Ростовская область, Донецк, 3 микрорайон, 25	f	large
69168	76022	801	Ростовская область, Донецк, 3 микрорайон, 10	f	large
70225	77749	2607	Ростовская область, городской округ Донецк, 12 квартал, 17/1	f	large
87104	77423	2264	Ростовская область, Гуково, пер. Волжский, 1	f	large
70061	77426	2266	Ростовская область, Гуково, Щорса, 40	f	large
70064	77431	2271	Ростовская область, Гуково, Школьная, 2а	f	large
70050	77409	2252	Ростовская область, Гуково, Шахтерская, 63а	f	large
70063	77429	2269	Ростовская область, Гуково, Чкалова, 32	f	large
87103	77422	2263	Ростовская область, Гуково, Трамвайная, 1а	f	large
87102	77415	2258	Ростовская область, Гуково, Степная, 12	f	large
70067	77437	2277	Ростовская область, Гуково, Российская, 42	f	large
114741	77427	2267	Ростовская область, Гуково, Розы Люксембург, 2-а	f	medium
114740	77425	2265	Ростовская область, Гуково, Пушкина, 79	f	medium
70051	77410	2253	Ростовская область, Гуково, Молодежная, 17	f	large
70042	77401	2244	Ростовская область, Гуково, Мира, 13а	f	large
70041	77400	2243	Ростовская область, Гуково, Мира, 28	f	large
70047	77406	2249	Ростовская область, Гуково, Милицейская, 1	t	large
70036	77394	2237	Ростовская область, Гуково, Льва Толстого, 28	f	large
70058	77420	2262	Ростовская область, Гуково, Ленинградская, 2	f	large
70057	77419	2261	Ростовская область, Гуково, Кутузова, 30	f	large
70037	77395	2238	Ростовская область, Гуково, Крупской, 51	f	large
70048	77407	2250	Ростовская область, Гуково, Криничная, 59	f	large
70054	77414	2257	Ростовская область, Гуково, Кооперативная, 2	f	large
114742	77430	2270	Ростовская область, Гуково, Комсомольская, 46	f	small
114738	77413	2256	Ростовская область, Гуково, Комсомольская, 31	f	medium
70053	77412	2255	Ростовская область, Гуково, Комсомольская, 40а	f	large
70052	77411	2254	Ростовская область, Гуково, Комсомольская, 75	f	large
70046	77405	2248	Ростовская область, Гуково, Колодезная, 61	f	large
114737	77397	2240	Ростовская область, Гуково, Карла Маркса, 89	f	medium
70039	77398	2241	Ростовская область, Гуково, Герцена, 115	f	large
70038	77396	2239	Ростовская область, Гуково, Герцена, 124	f	large
70044	77403	2246	Ростовская область, Гуково, Бургустинская, 17	f	large
70043	77402	2245	Ростовская область, Гуково, Бургустинская, 7	f	large
70040	77399	2242	Ростовская область, Гуково, Болгарский, 4	f	large
70065	77432	2272	Ростовская область, Гуково, Ардинцева, 12а	f	large
69024	75293	424	Ростовская область, Волгодонск, Мира, 47	f	large
69023	75293	423	Ростовская область, Волгодонск, Мира, 47	f	large
69014	75643	414	Ростовская область, Волгодонск, переулок Октябрьский, 13	f	large
69008	75640	408	Ростовская область, Волгодонск, бульвар Великой Победы, 14	f	large
69007	75639	407	Ростовская область, Волгодонск, бульвар Великой Победы, 14	f	large
69006	75638	406	Ростовская область, Волгодонск, бульвар Великой Победы, 6	f	large
69003	75636	403	Ростовская область, Волгодонск, Энтузиастов, 7	f	large
69002	75636	402	Ростовская область, Волгодонск, Энтузиастов, 7	f	large
69013	75642	413	Ростовская область, Волгодонск, Черникова, 6	f	large
69010	75642	410	Ростовская область, Волгодонск, Черникова, 6	f	large
69012	75642	412	Ростовская область, Волгодонск, Черникова, 6	f	large
69011	75642	411	Ростовская область, Волгодонск, Черникова, 6	f	large
69015	75644	415	Ростовская область, Волгодонск, Строителей, 39	f	large
69009	75641	409	Ростовская область, Волгодонск, Строителей, 37	f	large
68999	75633	399	Ростовская область, Волгодонск, Степная, 193	f	large
68998	75633	398	Ростовская область, Волгодонск, Степная, 193	f	large
68989	75626	389	Ростовская область, Волгодонск, Советская, 138	f	large
68981	75621	381	Ростовская область, Волгодонск, Советская, 1	f	large
69018	75646	418	Ростовская область, Волгодонск, Молодежная, 13а	f	large
69017	75646	417	Ростовская область, Волгодонск, Молодежная, 13а	f	large
69005	75637	405	Ростовская область, Волгодонск, Молодежная, 1	f	large
69004	75637	404	Ростовская область, Волгодонск, Молодежная, 1	f	large
69031	75652	431	Ростовская область, Волгодонск, Мира, 16	f	large
69030	75652	430	Ростовская область, Волгодонск, Мира, 16	f	large
69029	75652	429	Ростовская область, Волгодонск, Мира, 16	f	large
69028	75651	428	Ростовская область, Волгодонск, Мира, 75	f	large
69027	75651	427	Ростовская область, Волгодонск, Мира, 75	f	large
69025	75649	425	Ростовская область, Волгодонск, Мира, 69	f	large
69021	75648	421	Ростовская область, Волгодонск, Маршала Кошевого, 20	f	large
68997	75632	397	Ростовская область, Волгодонск, М. Горького, 163	f	large
68996	75632	396	Ростовская область, Волгодонск, М. Горького, 163	f	large
68995	75631	395	Ростовская область, Волгодонск, Ленина, 115	f	large
68992	75629	392	Ростовская область, Волгодонск, Ленина, 94	f	large
68991	75628	391	Ростовская область, Волгодонск, Ленина, 75	f	large
68986	75625	386	Ростовская область, Волгодонск, Ленина, 73/94	f	large
68985	75624	385	Ростовская область, Волгодонск, Ленина, 56	f	large
68984	75624	384	Ростовская область, Волгодонск, Ленина, 56	f	large
68983	75623	383	Ростовская область, Волгодонск, Ленина, 29	f	large
68982	75622	382	Ростовская область, Волгодонск, Ленина, 28	f	large
69016	75645	416	Ростовская область, Волгодонск, Курчатова, 20	f	large
69000	75634	400	Ростовская область, Волгодонск, Кооперативная, 23	f	large
69026	75650	426	Ростовская область, Волгодонск, К. Маркса, 38	f	large
69022	75489	422	Ростовская область, Волгодонск, К. Маркса, 4	f	large
68994	75630	394	Ростовская область, Волгодонск, Горького, 190	f	large
68993	75630	393	Ростовская область, Волгодонск, Горького, 190	f	large
69020	75647	420	Ростовская область, Волгодонск, Гагарина, 29	f	large
69019	75647	419	Ростовская область, Волгодонск, Гагарина, 29	f	large
68988	75307	388	Ростовская область, Волгодонск, 50 Лет ВЛКСМ, 10	f	large
68987	75307	387	Ростовская область, Волгодонск, 50 Лет ВЛКСМ, 10	f	large
113805	75226	8	Ростовская область, Белая Калитва, Зал ожидания железнодорожного вокзала	f	large
68789	75235	16	Ростовская область, Белая Калитва, Энтузиастов, 11а	f	large
68784	75230	11	Ростовская область, Белая Калитва, Энгельса, 17	f	large
113804	75221	3	Ростовская область, Белая Калитва, Щаденко, 12	f	medium
68785	75231	12	Ростовская область, Белая Калитва, Театральная, 1	f	large
68783	75229	10	Ростовская область, Белая Калитва, Строительная, 6	f	large
68875	75355	131	Ростовская область, Белая Калитва, Светлая, 6	f	large
68778	75222	4	Ростовская область, Белая Калитва, Пролетарская, 98	f	large
68788	75234	15	Ростовская область, Белая Калитва, Мичурина, 34	f	large
69666	76907	1713	Ростовская область, Белая Калитва, Машиностроителей, 4/1	f	large
68777	75220	2	Ростовская область, Белая Калитва, Машиностроителей, МОУ СОШ №17	f	large
68781	75225	7	Ростовская область, Белая Калитва, Копаева, 22	f	large
68787	75233	14	Ростовская область, Белая Калитва, Калинина, 21	f	large
68790	75236	17	Ростовская область, Белая Калитва, Горького, 167	f	large
87061	75237	18	Ростовская область, Белая Калитва, Геологическая, 2	f	large
69483	76495	1502	Ростовская область, Батайск, пл. Ленина, 5	f	large
69481	76495	1500	Ростовская область, Батайск, пл. Ленина, 5	f	large
69475	94449	1494	Ростовская область, Батайск, Южная, 5	f	large
69494	76720	1513	Ростовская область, Батайск, Эстакадная, 12	f	large
70159	77618	2452	Ростовская область, Батайск, Энгельса, 347	f	large
69480	76480	1499	Ростовская область, Батайск, Энгельса, 199	f	large
69491	76717	1510	Ростовская область, Батайск, Тельмана, 154	f	large
70166	77629	2466	Ростовская область, Батайск, Ставропольская, 50	f	large
70217	77629	2584	Ростовская область, Батайск, Ставропольская, 50	f	large
69500	76725	1519	Ростовская область, Батайск, Ставропольская, 50б	f	large
69499	76725	1518	Ростовская область, Батайск, Ставропольская, 50б	f	large
70158	77617	2451	Ростовская область, Батайск, Совхозная, 4/2	f	large
70171	77633	2472	Ростовская область, Батайск, Северный массив, 6/2	f	large
70215	77728	2582	Ростовская область, Батайск, Первомайское кольцо, 175	f	large
69501	76679	1520	Ростовская область, Батайск, Октябьская, 110	f	large
69485	76679	1504	Ростовская область, Батайск, Октябьская, 110	f	large
70216	76722	2583	Ростовская область, Батайск, Молдавская, 17	f	large
69496	76722	1515	Ростовская область, Батайск, Молдавская, 17	f	large
69502	76718	1521	Ростовская область, Батайск, Матросова, 2а/155	f	large
69492	76718	1511	Ростовская область, Батайск, Матросова, 2а/155	f	large
69498	76724	1517	Ростовская область, Батайск, М.Горького, 593	f	large
69497	76723	1516	Ростовская область, Батайск, М.Горького, 582а	f	large
69505	76114	1524	Ростовская область, Батайск, Луначарского, 180	f	large
69493	76719	1512	Ростовская область, Батайск, Ленина, 170	f	large
70161	76652	2457	Ростовская область, Батайск, Ленина, 95	f	large
69484	76652	1503	Ростовская область, Батайск, Ленина, 95	f	large
69487	75960	1506	Ростовская область, Батайск, Ленина, 3	f	large
69489	76715	1508	Ростовская область, Батайск, Коммунистическая, 180б	f	large
69486	76701	1505	Ростовская область, Батайск, Коммунистическая, 88	f	large
70222	76701	2604	Ростовская область, Батайск, Коммунистическая, 88	f	large
70223	77747	2605	Ростовская область, Батайск, Комарова, 175	f	large
70220	77745	2602	Ростовская область, Батайск, Коваливского, 74а	f	large
70202	77693	2542	Ростовская область, Батайск, Калинина, 136а	f	large
69488	76714	1507	Ростовская область, Батайск, Железнодорожный тупик, 37	f	large
70221	77746	2603	Ростовская область, Батайск, Гастелло, 2а	f	large
70165	77628	2465	Ростовская область, Батайск, Воровского, 1а	f	large
70162	76721	2460	Ростовская область, Батайск, Белорусская, 83	f	large
69495	76721	1514	Ростовская область, Батайск, Белорусская, 83	f	large
70203	76726	2543	Ростовская область, Батайск, Авиагородок, 19а	f	large
69504	76726	1523	Ростовская область, Батайск, Авиагородок, 19а	f	large
69503	76726	1522	Ростовская область, Батайск, Авиагородок, 19а	f	large
69490	76716	1509	Ростовская область, Батайск, Авиагородок, 34а	f	large
70164	76713	2464	Ростовская область, Батайск, 50 лет Октября, 71	f	large
69479	76713	1498	Ростовская область, Батайск, 50 лет Октября, 71	f	large
69478	76713	1497	Ростовская область, Батайск, 50 лет Октября, 71	f	large
69476	76711	1495	Ростовская область, Батайск, 1-й Пятилетки, 9	f	large
70219	77744	2601	Ростовская область, Батайск, Северный массив, 8	f	large
69508	76728	1527	Ростовская область, Аксай, Шолохова, 4	f	large
69507	76727	1526	Ростовская область, Аксай, Шевченко, 156	f	large
87059	76744	1540	Ростовская область, Аксай, Садовая, 30/5	f	large
70210	77710	2563	Ростовская область, Аксай, Платова, 68	f	large
69518	76739	1537	Ростовская область, Аксай, Крупской, 5	f	large
69886	77171	2012	Ростовская область, Азов, проспект Зои Космодемьянской, 90а	f	large
69892	77192	2018	Ростовская область, Азов, переулок Степана Разина, 3а	f	large
69878	77183	2004	Ростовская область, Азов, переулок Социалистический, 25	f	large
69889	77189	2015	Ростовская область, Азов, переулок Осипенко, 47	f	large
69871	77175	1996	Ростовская область, Азов, Черноморский переулок, 77	f	large
70153	77606	2440	Ростовская область, Азов, Толстого, 99	f	large
114662	77195	2021	Ростовская область, Азов, Соловьиный пер, 9	f	small
69893	77193	2019	Ростовская область, Азов, Пушкина, 110	f	large
69882	77187	2008	Ростовская область, Азов, Пушкина, 29	f	large
69894	77194	2020	Ростовская область, Азов, Победы, 6	f	large
69875	77180	2001	Ростовская область, Азов, Петровский бульвар, 8	f	large
69890	77190	2016	Ростовская область, Азов, Первомайская, 94	f	large
69891	77191	2017	Ростовская область, Азов, Московская, 292	f	large
69888	77188	2014	Ростовская область, Азов, Московская, 118	f	large
69880	77185	2006	Ростовская область, Азов, Московская, 118	f	large
69887	76158	2013	Ростовская область, Азов, Московская, 141	f	large
114861	77678	2525	Ростовская область, Азов, Мира , 19/31	f	medium
69876	77181	2002	Ростовская область, Азов, Мира, 2	f	large
69883	77077	2009	Ростовская область, Азов, Мира, 41	f	large
69872	77176	1997	Ростовская область, Азов, Макаровского, 31а	f	large
69870	77174	1995	Ростовская область, Азов, Макаровского, 37	f	large
69895	77196	2022	Ростовская область, Азов, Ленинградская, 39	f	large
69881	77186	2007	Ростовская область, Азов, Ленинградская, 47	f	large
69592	76842	1636	Ростовская область, Азов, Куйбышева, 63/30	f	large
70154	77607	2441	Ростовская область, Азов, Красногоровская, 16	f	large
69593	76844	1638	Ростовская область, Азов, Красногоровская, 4	f	large
69879	77184	2005	Ростовская область, Азов, Красноармейский переулок, 63	f	large
69884	77088	2010	Ростовская область, Азов, Красноармейский переулок, 90	f	large
70198	77679	2526	Ростовская область, Азов, Кондаурова, 32	f	large
69896	77197	2023	Ростовская область, Азов, Кондаурова, 23	f	large
69874	77179	2000	Ростовская область, Азов, Дзержинского, 14	f	large
69873	77177	1998	Ростовская область, Азов, Григория Мирошниченко, 48	f	large
70197	77677	2524	Ростовская область, Азов, Васильева, 85/87	f	large
69869	76843	1994	Ростовская область, Азов, Андреевская, 102	f	large
114581	76843	1637	Ростовская область, Азов, Андреевская, 102	f	medium
70008	77365	2205	Ростовская область, городской округ Шахты, Шахты	f	large
69993	77351	2187	Ростовская область, городской округ Шахты, Шахты	f	large
69992	77351	2186	Ростовская область, городской округ Шахты, Шахты	f	large
69959	77318	2150	Ростовская область, городской округ Шахты, Шахты, Якутский, 2	f	large
70011	77368	2208	Ростовская область, городской округ Шахты, Шахты, Мичурина, 11	f	large
70014	77362	2211	Ростовская область, городской округ Шахты, Шахты, Милиционная, 20	f	large
114732	77362	2201	Ростовская область, городской округ Шахты, Шахты, Милиционная, 20	f	medium
70009	77366	2206	Ростовская область, городской округ Шахты, Шахты, Ленинского Комсомола, 51	f	large
70016	77372	2213	Ростовская область, городской округ Шахты, Шахты, Калинина, 79	f	large
70023	77379	2221	Ростовская область, городской округ Шахты, Шахты, Ворошилова, 9-А	f	large
70022	77379	2220	Ростовская область, городской округ Шахты, Шахты, Ворошилова, 9-А	f	large
70136	77547	2385	Ростовская область, городской округ Новошахтинск, Новошахтинск, Привокзальная, 132	f	large
70230	77547	2614	Ростовская область, городской округ Новошахтинск, Новошахтинск, Привокзальная, 132	f	large
114790	77555	2392	Ростовская область, городской округ Новошахтинск, Новошахтинск, Перспективная, 2	f	medium
70133	77539	2380	Ростовская область, городской округ Новошахтинск, Новошахтинск, Молодогвардейцев, 13/5	f	large
70132	77539	2379	Ростовская область, городской округ Новошахтинск, Новошахтинск, Молодогвардейцев, 13/5	f	large
114785	77548	2386	Ростовская область, городской округ Новошахтинск, Новошахтинск, Маркса, 15	f	medium
114791	77557	2395	Ростовская область, городской округ Новошахтинск, Новошахтинск, Линейная, 32	t	medium
70107	77517	2353	Ростовская область, городской округ Новошахтинск, Новошахтинск, Ленина, 21/16	f	large
114192	76032	812	Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский, Советская, 18	t	small
69217	76079	856	Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский, Железнодорожников, 12	t	large
69205	76065	843	Ростовская область, городской округ Каменск-Шахтинский, Каменск-Шахтинский, Ворошилова, 155	f	large
114193	76035	815	Ростовская область, городской округ Донецк, Донецк, Юго-Западное шоссе, 1	f	medium
70056	77417	2259	Ростовская область, городской округ Гуково, Гуково, Красная Горка, 80	t	large
70049	77408	2251	Ростовская область, городской округ Гуково, Гуково, Комсомольская, 17	f	large
70045	77404	2247	Ростовская область, городской округ Гуково, Гуково, Карла Маркса, 54	f	large
114739	77418	2260	Ростовская область, городской округ Гуково, Гуково, Железнодорожная, 31-а	f	medium
69001	75635	401	Ростовская область, городской округ Волгодонск, Волгодонск, Центральная, 46	f	large
70160	75653	2456	Ростовская область, городской округ Волгодонск, Октябрьское шоссе, 32	f	large
69032	75653	432	Ростовская область, городской округ Волгодонск, Октябрьское шоссе, 32	f	large
68990	75627	390	Ростовская область, городской округ Волгодонск, Волгодонск, Вокзальный, 21	f	large
68776	75219	1	Ростовская область, городской округ Белая Калитва, Белая Калитва, Машиностроителей, 17б	f	large
68786	75232	13	Ростовская область, городской округ Белая Калитва, Белая Калитва, Калинина, 19	f	large
68779	75223	5	Ростовская область, городской округ Белая Калитва, Белая Калитва, Большая, 11	f	large
69482	76628	1501	Ростовская область, городской округ Батайск, Батайск, переулок Книжный, 2	f	large
69477	76712	1496	Ростовская область, городской округ Батайск, Батайск, Куйбышева, 50	f	large
70172	77634	2473	Ростовская область, городской округ Батайск, Батайск, Авиагородок, 29а	f	large
114661	77178	1999	Ростовская область, городской округ Азов, Азов	f	small
69868	77173	1993	Ростовская область, городской округ Азов, Азов, Севастопольская, 113	f	large
69877	77182	2003	Ростовская область, городской округ Азов, Азов, Макаровского, 29в	f	large
69667	76908	1714	Ростовская область, городской округ Азов, Азов, Макаровского, 35	f	large
70155	77610	2444	Ростовская область, городской округ Азов, Азов, Литейный проезд, 9/22	f	large
69885	77111	2011	Ростовская область, городской округ Азов, Азов, Измайлова, 69	f	large
114539	76545	1310	Ростовская область, Шолоховский район, хутор Чукаринский, пер.Центральный, 5-а	f	small
114538	76543	1308	Ростовская область, Шолоховский район, хутор Черновский, пер.Центральный, 10	f	small
114536	76541	1306	Ростовская область, Шолоховский район, хутор Ушаковский, Центральная, 22	f	small
114545	76552	1317	Ростовская область, Шолоховский район, хутор Терновской, Центральная, 7-в	f	medium
114541	76547	1312	Ростовская область, Шолоховский район, хутор Сингиновский, Степная, 1	f	small
114860	77675	2521	Ростовская область, Шолоховский район, хутор Рубежинский, Береговая, 22	f	small
114546	76553	1318	Ростовская область, Шолоховский район, хутор Поповский, Центральная, 11а	f	small
114534	76539	1304	Ростовская область, Шолоховский район, хутор Плешаковский, Лесная, 42	f	small
114912	77753	2611	Ростовская область, Шолоховский район, хутор Пигаревский, Чехова, 25	f	medium
114533	76538	1303	Ростовская область, Шолоховский район, хутор Нижнекривской, Родниковая, 152	f	small
69315	76548	1313	Ростовская область, Шолоховский район, хутор Меркуловский, переулок Победы, 5	f	large
114540	76546	1311	Ростовская область, Шолоховский район, хутор Максаевский, Южная, 43-а	f	small
114532	76535	1301	Ростовская область, Шолоховский район, хутор Лосевский, Зеленая, 4а	f	small
114525	76528	1294	Ростовская область, Шолоховский район, хутор Лебяженский, Плоткина, 25	f	small
69314	76544	1309	Ростовская область, Шолоховский район, хутор Кружилинский, Школьная, 12	f	large
114535	76540	1305	Ростовская область, Шолоховский район, хутор Колундаевский, переулок Больничный, 12	f	medium
114543	76550	1315	Ростовская область, Шолоховский район, хутор Калиновский, Центральная, 19	f	small
69313	76536	1302	Ростовская область, Шолоховский район, хутор Калининский, Центральная, 15	f	large
114529	76532	1298	Ростовская область, Шолоховский район, хутор Зубковский, Решетовская, 39	f	small
114542	76549	1314	Ростовская область, Шолоховский район, хутор Затонский, Центральная, 68	f	small
114526	76529	1295	Ростовская область, Шолоховский район, станица Еланская, Платова, 13	f	small
114530	76533	1299	Ростовская область, Шолоховский район, хутор Дударевский, Клубная, 4-б	f	medium
114531	76534	1300	Ростовская область, Шолоховский район, хутор Дударевский, Западная, 16-а	f	small
114527	76530	1296	Ростовская область, Шолоховский район, хутор Дубровский, пер.Школьный, 13	f	medium
114521	76521	1287	Ростовская область, Шолоховский район, хутор Громковский, Почтовая, 271	f	medium
114537	76542	1307	Ростовская область, Шолоховский район, хутор Гороховский, Школьная, 1	f	small
114901	77733	2590	Ростовская область, Шолоховский район, хутор Водянский, Подгорная, 5	f	small
69311	76525	1291	Ростовская область, Шолоховский район, станица Вешенская, пер.Красный, 12	f	large
69316	76554	1319	Ростовская область, Шолоховский район, станица Вешенская, Шолохова, 125	f	large
69312	76526	1292	Ростовская область, Шолоховский район, станица Вешенская, Шолохова, 2г	f	large
69310	76524	1290	Ростовская область, Шолоховский район, станица Вешенская, Сосновая, 61	f	large
114523	76523	1289	Ростовская область, Шолоховский район, хутор Верхнетокинский, Молодежная, 11-а	f	small
114544	76551	1316	Ростовская область, Шолоховский район, хутор Варваринский, Горская, 17	f	small
69309	76520	1286	Ростовская область, Шолоховский район, станица Базковская, Ленина, 12	f	large
69308	76520	1285	Ростовская область, Шолоховский район, станица Базковская, Ленина, 12	f	large
114528	76531	1297	Ростовская область, Шолоховский район, хутор Антиповский, Школьная, 35	f	small
114524	76527	1293	Ростовская область, Шолоховский район, хутор Андроповский, Агеева, 19	f	small
114522	76522	1288	Ростовская область, Шолоховский район, хутор Альшанский, Городская, 10-а	f	small
114498	76494	1260	Ростовская область, Чертковский район, село Щедровка, Южная, 79	f	medium
114505	76502	1267	Ростовская область, Чертковский район, село Шептуховка, Центральная, 59	f	medium
114492	76484	1253	Ростовская область, Чертковский район, поселок Чертково, переулок Деповской, 50	f	medium
114489	76477	1248	Ростовская область, Чертковский район, поселок Чертково, Фрунзе, 23	f	medium
69303	76478	1249	Ростовская область, Чертковский район, поселок Чертково, Садовая, 31	f	large
114488	76476	1247	Ростовская область, Чертковский район, поселок Чертково, Пролетарская, 102	f	medium
69301	76473	1244	Ростовская область, Чертковский район, поселок Чертково, Пролетарская, 1	f	large
114491	76483	1252	Ростовская область, Чертковский район, поселок Чертково, Петровского, 152	f	medium
69302	76475	1246	Ростовская область, Чертковский район, Чертково, Петровского, 71	f	large
69304	76482	1251	Ростовская область, Чертковский район, поселок Чертково, Октябрьская, 21а	f	large
114487	76474	1245	Ростовская область, Чертковский район, поселок Чертково, Комсомольская, 21	f	medium
114509	76507	1272	Ростовская область, Чертковский район, село Тихая Журавка, Широкая, 29	f	medium
114972	76487	1255	Ростовская область, Чертковский район, село Тарасово-Меловское, Ленина, 1	f	small
69306	76506	1271	Ростовская область, Чертковский район, село Сохрановка, Социалистическая, 1а	f	large
114515	76514	1279	Ростовская область, Чертковский район, хутор Сетраки, Советская, 23	f	medium
114514	76513	1278	Ростовская область, Чертковский район, слобода Семено-Камышенская, Советская, 18	f	small
114971	76479	1250	Ростовская область, Чертковский район, хутор Полтава, Комарова	f	small
114517	76516	1281	Ростовская область, Чертковский район, хутор Павловка, Партизанская, 13	f	small
69305	76485	1254	Ростовская область, Чертковский район, село Осиково, Российская, 6	f	large
114516	76515	1280	Ростовская область, Чертковский район, село Ольховчик, Молодежная, 37	f	medium
114496	76492	1258	Ростовская область, Чертковский район, хутор Новостепановский, Мира, 27	f	small
114506	76503	1268	Ростовская область, Чертковский район, село Новоселовка, Школьная, 1	f	medium
114510	76508	1273	Ростовская область, Чертковский район, хутор Нагибин, Лесная, 15	f	medium
114829	77619	2453	Ростовская область, Чертковский район, село Михайлово-Александровка, Ленина, 22	f	medium
114507	76504	1269	Ростовская область, Чертковский район, село Михайлово-Александровка, Ленина, 51-а	f	medium
114511	76509	1274	Ростовская область, Чертковский район, хутор Марьяны, Степная, 2	f	small
114500	76497	1262	Ростовская область, Чертковский район, село Маньково-Калитвенское, Юбилейная, 7	f	medium
114501	76498	1263	Ростовская область, Чертковский район, село Маньково-Калитвенское, Октябрьская, 17	f	medium
114503	76500	1265	Ростовская область, Чертковский район, село Маньково-Калитвенское, Кирова, 106	f	medium
114502	76499	1264	Ростовская область, Чертковский район, село Маньково-Калитвенское, Кирова, 35	f	medium
114512	76511	1276	Ростовская область, Чертковский район, хутор Малая Лозовка, Победы, 18	f	medium
114520	76519	1284	Ростовская область, Чертковский район, хутор Лозовой, Центральная, 3	f	small
114508	76505	1270	Ростовская область, Чертковский район, село Кутейниково, Октябрьская, 32	f	medium
114499	76496	1261	Ростовская область, Чертковский район, хутор Кадамов, Лесная, 33	f	small
114504	76501	1266	Ростовская область, Чертковский район, хутор Гусев, Мира, 20	f	small
114513	76512	1277	Ростовская область, Чертковский район, село Греково-Степановка, переулок Тихий, 2	f	medium
114973	76488	1256	Ростовская область, Чертковский район, хутор Галдин	f	small
114519	76518	1283	Ростовская область, Чертковский район, хутор Богуны, Центральная, 15	f	small
114497	76493	1259	Ростовская область, Чертковский район, хутор Бакай, Полетаева, 33	f	small
114518	76517	1282	Ростовская область, Чертковский район, хутор Артамошкин, Центральная, 19	f	medium
114974	76491	1257	Ростовская область, Чертковский район, слобода Анно-Ребриковская	f	small
69307	76510	1275	Ростовская область, Чертковский район, село Алексеево-Лозовское, Лисичкина, 22	f	large
114830	77620	2454	Ростовская область, Чертковский район, село Алексеево-Лозовское, Кирова, 70-а	f	medium
114183	76010	790	Ростовская область, Цимлянский район, хутор Черкасский, Центральная, 49	f	small
69156	75991	771	Ростовская область, Цимлянский район, Цимлянск, Советская, 35	f	large
114898	77730	2587	Ростовская область, Цимлянский район, Цимлянск, Победы, 134	f	large
69163	75999	779	Ростовская область, Цимлянский район, Цимлянск, Победы, 112	f	large
69155	75990	770	Ростовская область, Цимлянский район, Цимлянск, Набережная, 2	f	large
69160	75995	775	Ростовская область, Цимлянский район, Цимлянск, Московская, 63	f	large
114883	77709	2562	Ростовская область, Цимлянский район, Цимлянск, Маяковского, 106	f	medium
69161	75996	776	Ростовская область, Цимлянский район, Цимлянск, Ломоносова, 6а	f	large
69157	75992	772	Ростовская область, Цимлянский район, Цимлянск, Ленина, 44	f	large
69158	75993	773	Ростовская область, Цимлянский район, Цимлянск, Донская, 33	f	large
114930	77780	2647	Ростовская область, Цимлянский район, Цимлянск, Артемова, 2	f	medium
114175	76001	781	Ростовская область, Цимлянский район, станица Хорошевская, Центральная, 20	f	small
114188	76016	795	Ростовская область, Цимлянский район, станица Терновская, Центральная, 50	f	small
114177	76004	784	Ростовская область, Цимлянский район, поселок Сосенки, Центральная, 32	f	medium
114181	76008	788	Ростовская область, Цимлянский район, поселок Синий Курган, Школьная, 4	f	small
69162	75997	777	Ростовская область, Цимлянский район, поселок Саркел, Винзаводская, 3	f	large
114185	76012	792	Ростовская область, Цимлянский район, хутор Паршиков, Мира, 4	f	medium
69165	76018	797	Ростовская область, Цимлянский район, станица Новоцимлянская, Мира, 36	f	large
114182	76009	789	Ростовская область, Цимлянский район, станица Маркинская, Ленина, 5	f	medium
69164	76002	782	Ростовская область, Цимлянский район, хутор Лозной, Советская, 75	f	large
114179	76006	786	Ростовская область, Цимлянский район, станица Лозновская, Центральная, 32	f	small
114186	76014	793	Ростовская область, Цимлянский район, станица Кумшацкая, Молодежная, 38	f	small
21633	46446	4645	Краснодарский край, Сочи, Дагомысская, 17	f	large
114929	77778	2646	Ростовская область, Цимлянский район, станица Красноярская, Победы, 93	f	medium
114173	75998	778	Ростовская область, Цимлянский район, станица Красноярская, Победы, 101	f	large
114180	76007	787	Ростовская область, Цимлянский район, хутор Карпов, Центральная, 25	t	small
114178	76005	785	Ростовская область, Цимлянский район, станица Камышевская, Победы, 11	f	medium
114187	76015	794	Ростовская область, Цимлянский район, станица Калининская, Театральный, 3	f	medium
114184	76011	791	Ростовская область, Цимлянский район, хутор Железнодорожный, Советская, 29	f	small
114176	76003	783	Ростовская область, Цимлянский район, поселок Дубравный, Садовая, 1	f	medium
114189	76017	796	Ростовская область, Цимлянский район, хутор Антонов, Центральная, 17	f	medium
69152	75981	760	Ростовская область, Целинский район, Юловский, Транспортная, 9а	f	large
87113	77726	2580	Ростовская область, Целинский район, поселок Целина, Степная, 13	f	large
69147	75965	747	Ростовская область, Целинский район, поселок Целина, Советская, 10	f	large
87081	75963	746	Ростовская область, Целинский район, поселок Целина, Механизаторов, 38а	f	large
69148	75966	748	Ростовская область, Целинский район, поселок Целина, Западная, 61	f	large
69154	75989	769	Ростовская область, Целинский район, поселок Целина, 3-я линия, 117	f	large
114170	75987	766	Ростовская область, Целинский район, село Хлеборобное, Советская, 17	f	medium
114172	75988	768	Ростовская область, Целинский район, село Хлебодарное, Центральная, 2/а	f	medium
69151	75979	758	Ростовская область, Целинский район, село Степное, Центральная, 50	f	large
114160	75973	753	Ростовская область, Целинский район, хутор Старченский, Октябрьская, 9	f	small
114958	75961	744	Ростовская область, Целинский район, село Средний Егорлык, Школьная, 4	f	medium
114155	75958	743	Ростовская область, Целинский район, село Средний Егорлык, Молодёжная, 16	f	medium
114162	75976	755	Ростовская область, Целинский район, станица Сладкая Балка, Центральная, 62	f	medium
114959	75969	750	Ростовская область, Целинский район, хутор Северный, Мира, 177-Г	f	medium
114960	75971	751	Ростовская область, Целинский район, хутор Свободный, Зеленая, 40А	f	small
114166	75982	761	Ростовская область, Целинский район, хутор Рассвет, Новая, 2/б	f	small
114169	75986	765	Ростовская область, Целинский район, село Плодородное, Гагарина, 83	f	medium
114161	75975	754	Ростовская область, Целинский район, хутор Первомайский, Центральная, 25	f	small
69153	75984	763	Ростовская область, Целинский район, село Ольшанка, Торговая, 4	f	large
114927	77776	2644	Ростовская область, Целинский район, поселок Новая Целина, Макаренко, 2	f	medium
69149	75967	749	Ростовская область, Целинский район, поселок Новая Целина, Ленина, 5	f	large
114167	75983	762	Ростовская область, Целинский район, село Михайловка, Крупской, 14	f	medium
114163	75977	756	Ростовская область, Целинский район, село Лопанка, Молодежная, 2/а	f	medium
114164	75978	757	Ростовская область, Целинский район, село Лопанка, Красная, 1	f	medium
114928	77777	2645	Ростовская область, Целинский район, хутор Красный Юг, Виноградная, 4	f	small
114165	75980	759	Ростовская область, Целинский район, поселок Коренной, Абрикосовая, 5	f	medium
114168	75985	764	Ростовская область, Целинский район, село Журавлевка, Центральная, 80	f	medium
69150	75972	752	Ростовская область, Целинский район, поселок Вороново, Гусева, 15	f	large
114171	75974	767	Ростовская область, Целинский район, хутор Васильевка, пер. Школьный, 2	f	small
113973	75615	375	Ростовская область, Усть-Донецкий район, хутор Черни, Центральная, 26	f	small
68976	75608	369	Ростовская область, Усть-Донецкий район, Усть-Донецкий, переулок Почтовый, 11	f	large
68977	75609	370	Ростовская область, Усть-Донецкий район, ПГТ Усть-Донецкий, Ленина, 10	f	large
68975	75607	368	Ростовская область, Усть-Донецкий район, Усть-Донецкий, Донецкая, 3	f	large
68980	75620	380	Ростовская область, Усть-Донецкий район, станица Усть-Быстрянская, Центральная, 29	f	large
113977	75619	379	Ростовская область, Усть-Донецкий район, хутор Тереховский, Калинина, 3	f	small
68974	75602	363	Ростовская область, Усть-Донецкий район, станица Раздорская, Ленина, 29а	f	large
68973	75601	362	Ростовская область, Усть-Донецкий район, хутор Пухляковский, Центральная, 31	f	large
68953	75560	319	Ростовская область, Октябрьский район, Каменоломни, Ленина, 15	f	large
113968	75604	365	Ростовская область, Усть-Донецкий район, хутор Ольховский, Центральная, 17	f	small
68979	75614	374	Ростовская область, Усть-Донецкий район, станица Нижнекундрюченская, Советская, 5	f	large
113975	75617	377	Ростовская область, Усть-Донецкий район, хутор Мостовой, Донская, 1	f	small
68972	75600	361	Ростовская область, Усть-Донецкий район, станица Мелиховская, Мерзлякова, 39а	f	large
68971	75599	360	Ростовская область, Усть-Донецкий район, станица Мелиховская, Интернациональная, 72а	f	large
113970	75606	367	Ростовская область, Усть-Донецкий район, хутор Крымский, Центральная, 60	f	medium
113967	75603	364	Ростовская область, Усть-Донецкий район, хутор Коныгин, Шубина, 10	f	small
113966	75598	359	Ростовская область, Усть-Донецкий район, поселок Керчикский, Виноградная, 3а	f	medium
113965	75597	358	Ростовская область, Усть-Донецкий район, хутор Исаевский, Центральная, 37	f	small
113971	75610	371	Ростовская область, Усть-Донецкий район, хутор Ещеулов, Гагарина, МУК Культурный центр Крымского	f	small
113976	75618	378	Ростовская область, Усть-Донецкий район, хутор Евсеевский, Школьная, 8	f	small
113969	75605	366	Ростовская область, Усть-Донецкий район, хутор Виноградный, Большая Садовая, 17	f	small
113974	75616	376	Ростовская область, Усть-Донецкий район, станица Верхнекундрюченская, Центральная, 29	f	medium
114942	75613	373	Ростовская область, Усть-Донецкий район, хутор Бронницкий, Толстого, 9	f	small
68978	75611	372	Ростовская область, Усть-Донецкий район, хутор Апаринский, Комсомольская, 3	f	large
114991	77774	2641	Ростовская область, Усть-Донецкий район, хутор Апаринский, Гагарина, 111	f	\N
114892	77721	2575	Ростовская область, Тацинский район, хутор Чумаков, Советская, 29	f	small
69297	76451	1222	Ростовская область, Тацинский район, поселок Углегорский, Школьный переулок, 2	f	large
87041	76442	1213	Ростовская область, Тацинский район, станица Тацинская, площадь Калинина, 52а	f	large
69292	76445	1216	Ростовская область, Тацинский район, станица Тацинская, Соревнования переулок, 9	f	large
69291	76443	1214	Ростовская область, Тацинский район, станица Тацинская, Пионерский переулок, 23	f	large
70157	77616	2450	Ростовская область, Тацинский район, станица Тацинская, Октябрьская, 61	f	large
114466	76440	1212	Ростовская область, Тацинский район, станица Тацинская, Октябрьская, 131	f	medium
114467	76444	1215	Ростовская область, Тацинский район, станица Тацинская, Ленина, 78	f	medium
114475	76459	1230	Ростовская область, Тацинский район, станица Скосырская, Школьная, 5	f	medium
114471	76454	1225	Ростовская область, Тацинский район, хутор Потапов, Школьный переулок, 7	f	small
114481	76466	1237	Ростовская область, Тацинский район, поселок Новосуховый, Административная, 8	f	medium
114484	76469	1240	Ростовская область, Тацинский район, хутор Новороссошанский, Молодежная, 1	f	small
114474	76458	1229	Ростовская область, Тацинский район, хутор Надежевка, Заводская, 43	f	small
69298	76456	1227	Ростовская область, Тацинский район, хутор Михайлов, Ленина, 126	f	large
114472	76455	1226	Ростовская область, Тацинский район, хутор Михайлов, Клубная, 11	f	medium
114469	76452	1223	Ростовская область, Тацинский район, хутор Маслов, Школьная, 12	f	small
114478	76463	1234	Ростовская область, Тацинский район, хутор Луговой, Молодежная, 1	f	small
114473	76457	1228	Ростовская область, Тацинский район, хутор Крюков, Ленина, 3а	f	medium
114480	76465	1236	Ростовская область, Тацинский район, хутор Крылов, Центральная, 6	f	medium
114479	76464	1235	Ростовская область, Тацинский район, хутор Ковылкин, Мира, 33	f	medium
114476	76460	1231	Ростовская область, Тацинский район, хутор Качалин, Харченко, 44	f	medium
114470	76453	1224	Ростовская область, Тацинский район, хутор Карпово-Обрывский, Розы Люксембург, 1а	f	small
114468	76446	1217	Ростовская область, Тацинский район, хутор Исаев, Южный переулок, 8	f	medium
114483	76468	1239	Ростовская область, Тацинский район, хутор Зазерский, Центральная, 61	f	medium
69293	76447	1218	Ростовская область, Тацинский район, поселок Жирнов, П. Морозова, 2	t	large
69295	76449	1220	Ростовская область, Тацинский район, Жирнов, Островского переулок, 5	t	large
69294	76448	1219	Ростовская область, Тацинский район, ПГТ Жирнов, Театральная, 9	t	large
114486	76471	1242	Ростовская область, Тацинский район, станица Ермаковская, Молодежная, 4	f	medium
114477	76462	1233	Ростовская область, Тацинский район, хутор Верхнеобливский, Советская, 55	f	medium
114485	76470	1241	Ростовская область, Тацинский район, хутор Верхнекольцов, Мира, 28	f	small
70193	77670	2515	Ростовская область, Тацинский район, Быстрогорский, Космонавтов, 1	t	large
69296	76450	1221	Ростовская область, Тацинский район, поселок Быстрогорский, Волгодонская, 5а	t	large
114482	76467	1238	Ростовская область, Тацинский район, хутор Араканцев, 70 лет Октября, 48	f	small
114427	76395	1167	Ростовская область, Тарасовский район, слобода Шарпаевка, Ленина, 43а	f	small
114454	76428	1200	Ростовская область, Тарасовский район, хутор Чеботовка, Центральная, 30	f	small
114462	76436	1208	Ростовская область, Тарасовский район, хутор Ушаковка, Заречная, 40	f	small
69287	76408	1180	Ростовская область, Тарасовский район, поселок Тарасовский, Степная, 136	f	large
87040	76411	1182	Ростовская область, Тарасовский район, поселок Тарасовский, Победы, 32	f	large
69288	76409	1181	Ростовская область, Тарасовский район, поселок Тарасовский, Островского, 63	f	large
114439	76413	1184	Ростовская область, Тарасовский район, поселок Тарасовский, Мира, 29	f	medium
114441	76415	1186	Ростовская область, Тарасовский район, поселок Тарасовский, Ленина, 79	f	medium
114440	76414	1185	Ростовская область, Тарасовский район, поселок Тарасовский, Ленина, 100	f	medium
114438	76412	1183	Ростовская область, Тарасовский район, поселок Тарасовский, Грибоедова, 5	f	medium
114425	76393	1165	Ростовская область, Тарасовский район, хутор Сергеевка, Дорожная, 34	f	small
114435	76405	1176	Ростовская область, Тарасовский район, хутор Россошь, Советская, 10	f	small
114461	76435	1207	Ростовская область, Тарасовский район, хутор Прогной, Южная, 68	f	small
114429	76398	1170	Ростовская область, Тарасовский район, хутор Новоалексеевка, Новоалексеевская, 27	f	small
114437	76407	1179	Ростовская область, Тарасовский район, хутор Нижняя Тарасовка, Школьная, 22	f	small
114452	76426	1198	Ростовская область, Тарасовский район, хутор Нижнемитякин, Правобережная, 122	f	small
114451	76425	1197	Ростовская область, Тарасовский район, хутор Нижнемитякин, Правобережная, 65	f	small
114453	76427	1199	Ростовская область, Тарасовский район, хутор Нижнемитякин, Левобережная, 148	f	small
114422	76389	1160	Ростовская область, Тарасовский район, хутор Нижнемакеевский, Садовая, 40	f	small
114464	76438	1210	Ростовская область, Тарасовский район, хутор Можаевка, Центральная, 66	f	medium
114457	76431	1203	Ростовская область, Тарасовский район, станица Митякинская, Менжинского, 70	f	medium
114886	77714	2568	Ростовская область, Тарасовский район, станица Митякинская, Лесхозный, 17	f	medium
114431	76400	1172	Ростовская область, Тарасовский район, хутор Мартыновка, пер. Советский, 14	f	small
114445	76419	1190	Ростовская область, Тарасовский район, поселок Малое Полесье, Центральная, 20	f	small
114430	76399	1171	Ростовская область, Тарасовский район, слобода Курно-Липовка, Молодежная, 2	f	small
114448	76422	1194	Ростовская область, Тарасовский район, хутор Красновка, Героев, 39	f	small
114443	76417	1188	Ростовская область, Тарасовский район, хутор Каюковка, Центральная, 47	f	small
114428	76397	1169	Ростовская область, Тарасовский район, поселок Изумрудный, Южная, 11	f	small
114455	76429	1201	Ростовская область, Тарасовский район, хутор Зеленовка, Центральная, 55	f	medium
114424	76391	1163	Ростовская область, Тарасовский район, слобода Ефремово-Степановка, Новая, 19	f	medium
114433	76402	1174	Ростовская область, Тарасовский район, хутор Ерофеевка, Школьная, 15	f	small
114465	76439	1211	Ростовская область, Тарасовский район, хутор Елань, Круглая, 44	f	small
114432	76401	1173	Ростовская область, Тарасовский район, хутор Егоро-Калитвенский, Ленина, 19	f	small
114444	76418	1189	Ростовская область, Тарасовский район, слобода Дячкино, Мира площадь, 16	f	medium
114458	76432	1204	Ростовская область, Тарасовский район, хутор Дубы, Центральная, 42	f	small
114459	76433	1205	Ростовская область, Тарасовский район, хутор Дубы, Дубовская, 26	f	small
114436	76406	1177	Ростовская область, Тарасовский район, поселок Донская Нива, Центральная, 1 б	f	medium
114463	76437	1209	Ростовская область, Тарасовский район, поселок Деркул, Школьная, 7 а	f	small
114970	76404	1175	Ростовская область, Тарасовский район, хутор Грачи, Степная, 79	f	small
114460	76434	1206	Ростовская область, Тарасовский район, поселок Войково, Интернациональная, 7	f	small
114446	76420	1191	Ростовская область, Тарасовский район, поселок Весенний, 13 Героев, 22	f	small
114450	76424	1196	Ростовская область, Тарасовский район, хутор Верхний Митякин, Центральная, 136	f	small
114449	76423	1195	Ростовская область, Тарасовский район, хутор Верхний Митякин, Центральная, 39	f	small
114456	76430	1202	Ростовская область, Тарасовский район, хутор Верхние Грачики, Лесная, 3	f	small
114447	76421	1192	Ростовская область, Тарасовский район, поселок Верхнетарасовский, Школьная, 10	f	small
114442	76416	1187	Ростовская область, Тарасовский район, хутор Васильевка, Придорожная, 8	f	medium
69284	76388	1159	Ростовская область, Тарасовский район, слобода Большинка, Башмакова И.В, 1а	f	large
114423	76390	1161	Ростовская область, Тарасовский район, слобода Александровка, Молодежная, 4	f	small
114420	76386	1157	Ростовская область, Советский район, село Чистяково, Гагарина, 6	f	small
114417	76383	1154	Ростовская область, Советский район, поселок Чирский, Дорожная, 19	f	medium
114419	76385	1156	Ростовская область, Советский район, хутор Усть-Грязновский, Речная, 11	f	small
113868	75419	186	Ростовская область, Советский район, хутор Ставиднянский, Центральная, 36	f	small
69283	76378	1149	Ростовская область, Советский район, станица Советская, Горева, 7	f	large
113867	75418	185	Ростовская область, Советский район, хутор Русаков, Мартыненко, 20	f	small
114421	76387	1158	Ростовская область, Советский район, хутор Пичугин, Лесная, 23	f	small
114415	76381	1152	Ростовская область, Советский район, слобода Петрово, Любимая, 27	f	small
114413	76379	1150	Ростовская область, Советский район, хутор Парамонов, Молодежная, 22	f	small
114418	76384	1155	Ростовская область, Советский район, хутор Осиновский, Школьная, 4	f	small
114416	76382	1153	Ростовская область, Советский район, хутор Новорябухин, Центральная, 34	f	small
114903	77735	2592	Ростовская область, Советский район, поселок Малые Озера, Озерная, 16	f	small
114414	76380	1151	Ростовская область, Советский район, слобода Калач-Куртлак, Школьная, 2	f	medium
113952	75582	343	Ростовская область, Семикаракорский район, хутор Шаминка, пер. Школьный, 2/1	f	medium
68964	75573	334	Ростовская область, Семикаракорский район, хутор Чебачий, Гагарина, 8/1	f	large
68968	75581	342	Ростовская область, Семикаракорский район, хутор Топилин, переулок Советский, 10/1	f	large
113951	75580	341	Ростовская область, Семикаракорский район, хутор Титов, Пионерская, 36	f	medium
68970	75593	354	Ростовская область, Семикаракорский район, хутор Сусат, Молодежная, 48В	f	large
113953	75583	344	Ростовская область, Семикаракорский район, хутор Страхов, Гагарина, 60	f	medium
113947	75571	332	Ростовская область, Семикаракорский район, хутор Старая Станица, Центральная, 11	f	small
113964	75596	357	Ростовская область, Семикаракорский район, хутор Слободской, Мира, 25	f	medium
68961	75567	328	Ростовская область, Семикаракорский район, Семикаракорск, проспект Закруткина, 25/1	f	large
68960	75566	327	Ростовская область, Семикаракорский район, Семикаракорск, проспект Закруткина, 25	f	large
113945	75568	329	Ростовская область, Семикаракорский район, Семикаракорск, Серегина, 1	f	medium
114885	77713	2567	Ростовская область, Семикаракорский район, Семикаракорск, Ленина, 138	f	medium
68958	75564	325	Ростовская область, Семикаракорский район, Семикаракорск, Ленина, 129	f	large
113944	75562	321	Ростовская область, Семикаракорский район, Семикаракорск, Зеленая, 14	f	small
68959	75565	326	Ростовская область, Семикаракорский район, Семикаракорск, Авилова, 18	f	large
113954	75585	346	Ростовская область, Семикаракорский район, хутор Павлов, Юрия Гагарина, 25	f	small
113963	75595	356	Ростовская область, Семикаракорский район, хутор Новоромановский, Калинина, 23а	f	small
68963	75572	333	Ростовская область, Семикаракорский район, станица Новозолотовская, Октябрьская, 50	f	large
113959	75590	351	Ростовская область, Семикаракорский район, поселок Нижний Саловск, Тоговая, 14	f	medium
68965	75574	335	Ростовская область, Семикаракорский район, хутор Маломечетный, Октябрьская, 18	f	large
113955	75586	347	Ростовская область, Семикаракорский район, хутор Лиманский, Степная, 26	f	small
68908	75466	232	Ростовская область, Зерноградский район, Зерноград, Ленина, 32	f	large
113960	75591	352	Ростовская область, Семикаракорский район, хутор Кузнецовка, Ананченко, 15А	f	medium
113950	75578	339	Ростовская область, Семикаракорский район, поселок Крымский, Ленина, 28	f	medium
68962	75569	330	Ростовская область, Семикаракорский район, станица Кочетовская, Студенческая, 28	f	large
113962	75594	355	Ростовская область, Семикаракорский район, хутор Костылевка, Ленина, 1 В	f	small
113956	75587	348	Ростовская область, Семикаракорский район, хутор Кирсановка, Школьная, 3	f	small
68969	75584	345	Ростовская область, Семикаракорский район, хутор Золотаревка, Степана Здоровцева, 28а	f	large
113948	75576	337	Ростовская область, Семикаракорский район, поселок Зеленая Горка, Пушкина, 3	f	medium
68967	75579	340	Ростовская область, Семикаракорский район, станица Задоно-Кагальницкая, 30 лет Победы, 63а	f	large
113949	75577	338	Ростовская область, Семикаракорский район, хутор Жуков, Центральная, 7	f	medium
68966	75575	336	Ростовская область, Семикаракорский район, хутор Вислый, Школьная, 23/1	f	large
113958	75589	350	Ростовская область, Семикаракорский район, поселок Вершинный, Центральная, 2/1	f	medium
113946	75570	331	Ростовская область, Семикаракорский район, хутор Бугры, Речная, 5	f	small
113961	75592	353	Ростовская область, Семикаракорский район, хутор Балабинка, Центральная, 17в	f	small
113957	75588	349	Ростовская область, Семикаракорский район, хутор Бакланники, Школьная, 28	f	medium
113993	75703	483	Ростовская область, Сальский район, поселок Ясенево, бывшая контора отделения№10 СПК имени Ангельева	f	medium
69053	75675	455	Ростовская область, Сальский район, Юловский, Ленина, 15	f	large
69060	75689	469	Ростовская область, Сальский район, село Шаблиевка, Димитрова, 44	f	large
114878	77704	2556	Ростовская область, Сальский район, поселок Тальники, Ленина, 12	f	small
113989	75695	475	Ростовская область, Сальский район, село Сысоево-Александровское, Молодежная, 28	f	small
113979	75676	456	Ростовская область, Сальский район, поселок Супрун, Центральная, 19	f	medium
113980	75678	458	Ростовская область, Сальский район, поселок Степной Курган, Победы, 23	f	medium
113992	75698	478	Ростовская область, Сальский район, поселок Сеятель Северный, Пришкольная, 11-б	f	medium
113981	75681	461	Ростовская область, Сальский район, село Сандата, Полевая, 9	f	medium
69057	75682	462	Ростовская область, Сальский район, село Сандата, Калинина, 51	f	large
114881	77707	2559	Ростовская область, Сальский район, поселок Сальский Беслан, Крайняя, 8	f	small
69034	75655	434	Ростовская область, Сальский район, Сальск, переулок Морской, 5	f	large
114877	77703	2555	Ростовская область, Сальский район, Сальск, микрорайон Плодопитомник, адм.зд.ЗАО АФ Сальский сад	f	small
69045	75666	446	Ростовская область, Сальский район, Сальск, Юннатов, 4	f	large
69035	75656	435	Ростовская область, Сальский район, Сальск, Школьная площадь, 13	f	large
69052	75673	453	Ростовская область, Сальский район, Сальск, Халтурина, 27	f	large
69048	75669	449	Ростовская область, Сальский район, Сальск, Фрунзе, 39	f	large
69041	75662	442	Ростовская область, Сальский район, Сальск, Свободы, 58	f	large
69051	75672	452	Ростовская область, Сальский район, Сальск, Прямая, 112	f	large
69046	75667	447	Ростовская область, Сальский район, Сальск, Промышленная, 59	f	large
69049	75670	450	Ростовская область, Сальский район, Сальск, Островского, 6	f	large
69042	75663	443	Ростовская область, Сальский район, Сальск, Новостройка, 1	f	large
69044	75665	445	Ростовская область, Сальский район, Сальск, Ленина, 8	f	large
69040	75661	441	Ростовская область, Сальский район, Сальск, Ленина, 37	f	large
69038	75659	438	Ростовская область, Сальский район, Сальск, Ленина, 41	f	large
69033	75654	433	Ростовская область, Сальский район, Сальск, Ковпака, 26	f	large
69039	75660	440	Ростовская область, Сальский район, Сальск, Кирова, 17	f	large
69047	75668	448	Ростовская область, Сальский район, Сальск, Карла Маркса, 21а	f	large
69050	75671	451	Ростовская область, Сальский район, Сальск, Верхняя, 89а	f	large
69036	75657	436	Ростовская область, Сальский район, Сальск, Береговая, 1	f	large
113991	75697	477	Ростовская область, Сальский район, поселок Рыбасово, Московская, 1	f	medium
113982	75683	463	Ростовская область, Сальский район, село Романовка, Чапаева, 9г	f	medium
21087	45910	3409	Краснодарский край, Новороссийск, Шаумяна, 5	f	large
113994	75704	484	Ростовская область, Сальский район, поселок Приречный, Школьная, 16	f	medium
114880	77706	2558	Ростовская область, Сальский район, поселок Поливной, Советская, 1	f	small
113986	75690	470	Ростовская область, Сальский район, село Новый Маныч, Центральная, 24	f	small
69058	75687	467	Ростовская область, Сальский район, село Новый Егорлык, Советская, 17	f	large
113984	75685	465	Ростовская область, Сальский район, село Новый Егорлык, Новостройка, 13	f	medium
113985	75686	466	Ростовская область, Сальский район, село Новый Егорлык, Гагарина, 12-а	f	medium
114879	77705	2557	Ростовская область, Сальский район, поселок Новостепной, Школьная, 5	f	small
113988	75693	473	Ростовская область, Сальский район, хутор Новоселый 1-й, Солнечная, 6	f	medium
113990	75696	476	Ростовская область, Сальский район, хутор Маяк, Центральная, 1	f	medium
113987	75692	472	Ростовская область, Сальский район, поселок Манычстрой, Нефтяников, 6	f	small
69062	75694	474	Ростовская область, Сальский район, село Крученая Балка, Ленина, 20а	f	large
69061	75691	471	Ростовская область, Сальский район, поселок Конезавод им. Буденного, Ленина, 3	f	large
114174	76000	780	Ростовская область, Сальский район, поселок Конезавод им. Буденного, Буденного, 2	f	medium
114882	77708	2560	Ростовская область, Сальский район, поселок Клены, пер. Школьный, 31а	f	medium
69056	75680	460	Ростовская область, Сальский район, село Ивановка, Ленина, 63	f	large
69059	75688	468	Ростовская область, Сальский район, село Екатериновка, Коржова, 14	f	large
69066	75702	482	Ростовская область, Сальский район, поселок Гигант, Учебная, 3	f	large
69063	75699	479	Ростовская область, Сальский район, поселок Гигант, Учебная, 23	f	large
69065	75701	481	Ростовская область, Сальский район, поселок Гигант, Ленина, 83	f	large
69064	75700	480	Ростовская область, Сальский район, поселок Гигант, Крупской, 6	f	large
69055	75679	459	Ростовская область, Сальский район, село Березовка, Юбилейная, 1	f	large
69054	75677	457	Ростовская область, Сальский район, поселок Белозерный, Центральная, 3	f	large
113983	75684	464	Ростовская область, Сальский район, село Бараники, Октябрьская, 2	f	medium
114804	77580	2417	Ростовская область, Родионово-Несветайский район, село Чистополье, Октябрьская, 28	f	small
70149	77588	2424	Ростовская область, Родионово-Несветайский район, слобода Родионово-Несветайская, Пушкинская, 24	f	large
87108	77589	2425	Ростовская область, Родионово-Несветайский район, слобода Родионово-Несветайская, Кирова, 14	f	large
70199	77681	2528	Ростовская область, Родионово-Несветайский район, слобода Родионово-Несветайская, Гвардейцев-Танкистов, 6	f	large
114795	77570	2407	Ростовская область, Родионово-Несветайский район, село Плато-Ивановка, Чапаева, 3	f	small
114801	77576	2413	Ростовская область, Родионово-Несветайский район, хутор Новопрохоровка, Сельский клуб	f	small
114809	77586	2422	Ростовская область, Родионово-Несветайский район, слобода Кутейниково, Булановой, 30	f	medium
114810	77587	2423	Ростовская область, Родионово-Несветайский район, хутор Каменный Брод, Первомайская, 4	f	medium
114803	77578	2415	Ростовская область, Родионово-Несветайский район, хутор Дарьевка, Центральная, 36Б	f	medium
114805	77581	2418	Ростовская область, Родионово-Несветайский район, село Греково-Ульяновка, Волошилова, 32а	f	medium
114914	77756	2615	Ростовская область, Родионово-Несветайский район, хутор Гребцово, Суворова, 25А	f	small
114807	77583	2420	Ростовская область, Родионово-Несветайский район, село Генеральское, Клубная, 6а	f	medium
114806	77582	2419	Ростовская область, Родионово-Несветайский район, хутор Выдел, Первомайская, 13	f	medium
114989	77584	2421	Ростовская область, Родионово-Несветайский район, хутор Волошино, Центральная, 14	f	medium
114799	77574	2411	Ростовская область, Родионово-Несветайский район, хутор Веселый, Ленина, 5В	f	medium
114798	77573	2410	Ростовская область, Родионово-Несветайский район, хутор Бунако-Соколовец, Первомайская, Сельский клуб	f	small
70148	77579	2416	Ростовская область, Родионово-Несветайский район, слобода Большекрепинская, Ленина, 8	f	large
114802	77577	2414	Ростовская область, Родионово-Несветайский район, хутор Болдыревка, Октябрьская, 26	f	medium
114796	77571	2408	Ростовская область, Родионово-Несветайский район, слобода Барило-Крепинская, Красноармейская, 2А	f	medium
114797	77572	2409	Ростовская область, Родионово-Несветайский район, хутор Атамано-Власовка, Чапаева, 2	f	small
114800	77575	2412	Ростовская область, Родионово-Несветайский район, слобода Алексеево-Тузловка, Садовая, 24а	f	medium
114794	77569	2406	Ростовская область, Родионово-Несветайский район, слобода Аграфеновка, Просвещения, Дом культуры	f	medium
114863	77682	2529	Ростовская область, Родионово-Несветайский район, хутор Авилов, Советская, 1	f	medium
114147	75949	734	Ростовская область, Ремонтненский район, поселок Тихий Лиман, Школьная, 6	f	small
69143	75940	726	Ростовская область, Ремонтненский район, село Ремонтное, Первомайская, 20	f	large
69144	75941	727	Ростовская область, Ремонтненский район, село Ремонтное, Октябрьская, 147	f	large
69142	75939	725	Ростовская область, Ремонтненский район, село Ремонтное, Ленинская, 90	f	large
114957	75952	738	Ростовская область, Ремонтненский район, хутор Раздольный, Центральная, 48	f	small
114153	75956	741	Ростовская область, Ремонтненский район, поселок Привольный, Советская, 21	f	medium
114148	75950	735	Ростовская область, Ремонтненский район, село Подгорное, Ленина, 54	f	medium
69145	75947	732	Ростовская область, Ремонтненский район, село Первомайское, Богданова, 78	f	large
114154	75957	742	Ростовская область, Ремонтненский район, поселок Новопривольный, Садовая, 9	f	small
114151	75954	739	Ростовская область, Ремонтненский район, поселок Краснопартизанский, Южная, 11	f	medium
114146	75948	733	Ростовская область, Ремонтненский район, село Кормовое, Ленина, 24	f	medium
114149	75951	737	Ростовская область, Ремонтненский район, село Киевка, Ленинская, 97	f	medium
114152	75955	740	Ростовская область, Ремонтненский район, поселок Денисовский, Ленинская, 16	f	medium
114956	75944	729	Ростовская область, Ремонтненский район, хутор Вольный, Веревкина, 60	f	small
114142	75942	728	Ростовская область, Ремонтненский район, село Валуевка, 40 лет Победы, 84	f	medium
114144	75945	730	Ростовская область, Ремонтненский район, село Большое Ремонтное, Ленина, 27	f	medium
114145	75946	731	Ростовская область, Ремонтненский район, село Богородское, Буденного, 14	f	medium
114137	75933	719	Ростовская область, Пролетарский район, хутор Уютный, Ленина, 31	f	medium
114136	75932	718	Ростовская область, Пролетарский район, хутор Татнинов, Лесная, 21	f	small
69139	75927	709	Ростовская область, Пролетарский район, хутор Сухой, Пионерская, 28	f	large
69131	75917	699	Ростовская область, Пролетарский район, Пролетарск, переулок Красный, 101	f	large
69134	75920	702	Ростовская область, Пролетарский район, Пролетарск, Матвеева, 8/1	f	large
69137	75923	705	Ростовская область, Пролетарский район, Пролетарск, Горького, 9	f	large
114139	75935	721	Ростовская область, Пролетарский район, хутор Привольный, Свободная, 20/1	f	small
69141	75936	722	Ростовская область, Пролетарский район, Опенки, Каштанов, 21	f	large
114132	75926	708	Ростовская область, Пролетарский район, хутор Новомоисеевский, Школьная, 19	f	small
114140	75937	723	Ростовская область, Пролетарский район, хутор Николаевский 2-й, Школьная, 2-а	f	medium
114133	75929	714	Ростовская область, Пролетарский район, хутор Наумовский, Центральная, 35-а	f	medium
114138	75934	720	Ростовская область, Пролетарский район, хутор Мокрая Ельмута, Фермерская, 2	f	medium
114134	75930	715	Ростовская область, Пролетарский район, хутор Коврино, Ленина, 55-а	f	medium
114131	75925	707	Ростовская область, Пролетарский район, хутор Дальний, Целинная, 28	f	medium
114135	75931	717	Ростовская область, Пролетарский район, хутор Ганчуков, Огнева, 10	f	small
69140	75928	712	Ростовская область, Пролетарский район, станица Буденновская, Гремучая, 38	f	large
114124	75901	681	Ростовская область, Песчанокопский район, село Рассыпное, Ленина, 55-а	f	medium
69129	75915	695	Ростовская область, Песчанокопский район, село Развильное, 3, усадьба СХТ	f	large
87080	75913	694	Ростовская область, Песчанокопский район, село Развильное, Ростовская, 23	f	large
69126	75911	692	Ростовская область, Песчанокопский район, село Развильное, Комсомольская, 1б	f	large
69127	75912	693	Ростовская область, Песчанокопский район, село Развильное, Буденного, 3	f	large
69125	75909	690	Ростовская область, Песчанокопский район, село Поливянка, Центральная площадь, 4	f	large
21153	45975	3796	Краснодарский край, Новороссийск, Чайковского, 15	f	\N
69117	75896	676	Ростовская область, Песчанокопский район, село Песчанокопское, площадь им. В.И. Ленина, 1	f	large
69118	75897	677	Ростовская область, Песчанокопский район, село Песчанокопское, Орджоникидзе, 14	f	large
69121	75900	680	Ростовская область, Песчанокопский район, село Песчанокопское, Народная, 104а	f	large
69120	75899	679	Ростовская область, Песчанокопский район, село Песчанокопское, Народная, 2	f	large
69119	75898	678	Ростовская область, Песчанокопский район, село Песчанокопское, Бабина, 1	f	large
114130	75910	691	Ростовская область, Песчанокопский район, село Николаевка, Дружбы, 43	f	medium
69122	75903	683	Ростовская область, Песчанокопский район, село Летник, Ленина, 50/1	f	large
114955	75903	682	Ростовская область, Песчанокопский район, село Летник, Ленина, 50/1	f	small
114127	75906	686	Ростовская область, Песчанокопский район, село Красная Поляна, площадь Школьная, 3	f	medium
114128	75907	688	Ростовская область, Песчанокопский район, село Красная Поляна, Кирова, 7	f	medium
69124	75907	687	Ростовская область, Песчанокопский район, село Красная Поляна, Кирова, 7	f	large
114126	75905	685	Ростовская область, Песчанокопский район, село Жуковское, Московская, 122	f	small
69123	75904	684	Ростовская область, Песчанокопский район, село Жуковское, Ленина, 98а	f	large
114129	75908	689	Ростовская область, Песчанокопский район, поселок Дальнее Поле, Ленина, 3	f	medium
69130	75916	696	Ростовская область, Песчанокопский район, село Богородицкое, переулок Советский, 65	f	large
114113	75875	655	Ростовская область, Орловский район, хутор Широкий, Школьная, 3	f	small
114911	77743	2600	Ростовская область, Орловский район, хутор Черкесский, Транспортная, 34	f	small
114123	75885	665	Ростовская область, Орловский район, хутор Успенский, Молодежная, 28	f	small
114112	75874	654	Ростовская область, Орловский район, хутор Токмацкий, Дорожная, 17	f	small
114110	75870	650	Ростовская область, Орловский район, хутор Таловый, Микояновская, 12	f	small
114103	75863	641	Ростовская область, Орловский район, поселок Стрепетов, Школьная, 1	f	small
114104	75838	642	Ростовская область, Орловский район, поселок Рунный, Южная, 2	f	small
114107	75865	645	Ростовская область, Орловский район, хутор Романовский, Луговая, 45	f	small
114106	75864	644	Ростовская область, Орловский район, хутор Ребричанский, Веселая, 13	f	medium
114111	75873	653	Ростовская область, Орловский район, хутор Раздорский, Транспортная, 20	f	small
114910	77742	2599	Ростовская область, Орловский район, хутор Пролетарский, Школьная, 19	f	medium
114864	77684	2532	Ростовская область, Орловский район, хутор Островянский, Коммунистическая, 34	f	medium
69109	75888	668	Ростовская область, Орловский район, поселок Орловский, переулок Почтовый, 90	f	large
69113	75892	672	Ростовская область, Орловский район, поселок Орловский, переулок П.Ф. Костенко, 52	f	large
69112	75891	671	Ростовская область, Орловский район, поселок Орловский, переулок П.Ф. Костенко, 50	f	large
69114	75893	673	Ростовская область, Орловский район, поселок Орловский, пер. Чапаевский, 146	f	large
69111	75890	670	Ростовская область, Орловский район, поселок Орловский, пер. Октябрьский, 2	f	large
70200	77683	2531	Ростовская область, Орловский район, поселок Орловский, Рябиновая, 5	f	large
69115	75894	674	Ростовская область, Орловский район, поселок Орловский, Пролетарская, 49	f	large
69108	75887	667	Ростовская область, Орловский район, поселок Орловский, Пионерская, 64	f	large
69107	75886	666	Ростовская область, Орловский район, поселок Орловский, Пионерская, 41	f	large
69116	75895	675	Ростовская область, Орловский район, поселок Орловский, Красноармейская, 1	f	large
69110	75889	669	Ростовская область, Орловский район, поселок Орловский, Коммунальная, 158	f	large
114108	75867	647	Ростовская область, Орловский район, хутор Орден Ленина, Степная, 1-а	f	small
114116	75878	658	Ростовская область, Орловский район, хутор Нижнеантоновский, Антоновская, 44/1	f	small
114102	75862	640	Ростовская область, Орловский район, поселок Маныч, Приозерная, 28	f	small
114122	75884	664	Ростовская область, Орловский район, хутор Майорский, Магистральная, 24	f	medium
114119	75881	661	Ростовская область, Орловский район, хутор Луганский, Колхозный переулок, 4	f	medium
114121	75883	663	Ростовская область, Орловский район, хутор Курмоярский, Новоселов, 7	f	small
114115	75877	657	Ростовская область, Орловский район, хутор Курганный, пер. Театральный, 1	f	medium
114120	75882	662	Ростовская область, Орловский район, хутор Кундрюченский, Почтовый переулок, 2	f	small
69105	75871	651	Ростовская область, Орловский район, поселок Красноармейский, переулок Красноармейский, 22	f	large
69106	75872	652	Ростовская область, Орловский район, поселок Красноармейский, Кирова, 45	f	large
69104	75869	649	Ростовская область, Орловский район, хутор Камышевка, Школьная, 63	f	large
69103	75866	646	Ростовская область, Орловский район, хутор Каменная Балка, пер. Центральный, 1	f	large
114105	75850	643	Ростовская область, Орловский район, хутор Гундоровский, Центральная, 19	f	medium
114109	75868	648	Ростовская область, Орловский район, хутор Греков, Солнечная, 20	f	small
114101	75861	639	Ростовская область, Орловский район, поселок Волочаевский, Садовая, 4-а	f	medium
114909	77741	2598	Ростовская область, Орловский район, хутор Веселый, пер. Кооперативный, 6	f	small
114114	75876	656	Ростовская область, Орловский район, хутор Верхнетавричанский, Пушкинская, 1-б	f	small
114865	77685	2533	Ростовская область, Орловский район, хутор Верхнезундов, Колхозная, 11	f	small
114117	75879	659	Ростовская область, Орловский район, хутор Верхневодяной, Запрудная, 12	f	small
114118	75880	660	Ростовская область, Орловский район, хутор Быстрянский, Садовый переулок, 19	f	medium
114908	77740	2597	Ростовская область, Орловский район, хутор Большевик, Победы, 19	f	small
68940	75540	299	Ростовская область, Октябрьский район, хутор Яново-Грушевский, Восточная, 7	f	large
114841	77641	2484	Ростовская область, Октябрьский район, хутор Ягодинка, Центральная, 25-А	f	small
113928	75523	283	Ростовская область, Октябрьский район, поселок Равнинный, Майская, 27	t	small
68948	75553	312	Ростовская область, Октябрьский район, поселок Персиановский, Школьная, 21	f	large
68947	75552	311	Ростовская область, Октябрьский район, поселок Персиановский, Школьная, 8	f	large
68949	75554	313	Ростовская область, Октябрьский район, поселок Персиановский, Московская, 17в	f	large
114932	75321	98	Ростовская область, Октябрьский район, Новочеркасск, Алюминиевая площадка	f	medium
68820	75280	58	Ростовская область, Октябрьский район, Новочеркасск, проспект Ермака, 92	f	large
68832	75291	70	Ростовская область, Октябрьский район, Новочеркасск, Энгельса, 20	f	large
68857	75318	96	Ростовская область, Октябрьский район, Новочеркасск, Чехова, 7	f	large
87067	75300	76	Ростовская область, Октябрьский район, Новочеркасск, Центральная, 1/7	f	large
68837	75298	75	Ростовская область, Октябрьский район, Новочеркасск, Троицкая, 51	f	large
68846	75309	85	Ростовская область, Октябрьский район, Новочеркасск, Свободы, 19	f	large
68830	75289	68	Ростовская область, Октябрьский район, Новочеркасск, Ростовский выезд, 18	f	large
68829	75289	67	Ростовская область, Октябрьский район, Новочеркасск, Ростовский выезд, 18	f	large
68819	75250	57	Ростовская область, Октябрьский район, Новочеркасск, Пушкинская, 111	f	large
114931	75302	77	Ростовская область, Октябрьский район, Новочеркасск, Просторный переулок, 3	f	small
68831	75290	69	Ростовская область, Октябрьский район, Новочеркасск, Просвещения, 132	f	large
68836	75297	74	Ростовская область, Октябрьский район, Новочеркасск, Платовский проспект, 116	f	large
68835	75296	73	Ростовская область, Октябрьский район, Новочеркасск, Платовский проспект, 102	f	large
68821	75281	59	Ростовская область, Октябрьский район, Новочеркасск, Платовский проспект, 94	f	large
68859	75323	99	Ростовская область, Октябрьский район, Новочеркасск, Петрова, 17	f	large
87070	75319	97	Ростовская область, Октябрьский район, Новочеркасск, Петрова, 17, МБОУ СОШ №25	f	large
68833	75292	71	Ростовская область, Октябрьский район, Новочеркасск, Первомайская, 166	f	large
68864	75326	104	Ростовская область, Октябрьский район, Новочеркасск, Парковый проспект, 7а	f	large
68863	75326	103	Ростовская область, Октябрьский район, Новочеркасск, Парковый проспект, 7а	f	large
68862	75325	102	Ростовская область, Октябрьский район, Новочеркасск, Новый городок, 6	f	large
68856	75317	95	Ростовская область, Октябрьский район, Новочеркасск, Молодежная, 57/8	f	large
68866	75327	106	Ростовская область, Октябрьский район, Новочеркасск, Мелиховская, 35	f	large
68865	75327	105	Ростовская область, Октябрьский район, Новочеркасск, Мелиховская, 35	f	large
68855	75316	94	Ростовская область, Октябрьский район, Новочеркасск, Мацоты, 38	f	large
68841	75305	80	Ростовская область, Октябрьский район, Новочеркасск, Клещева, 37	f	large
68842	75304	81	Ростовская область, Октябрьский район, Новочеркасск, Клещева, 39	f	large
87068	75304	79	Ростовская область, Октябрьский район, Новочеркасск, Клещева, 39	f	large
68853	75314	92	Ростовская область, Октябрьский район, Новочеркасск, Калинина, 65а	f	large
68852	75314	91	Ростовская область, Октябрьский район, Новочеркасск, Калинина, 65а	f	large
68850	75313	89	Ростовская область, Октябрьский район, Новочеркасск, Калинина, 53	f	large
68851	75313	90	Ростовская область, Октябрьский район, Новочеркасск, Калинина, 53	f	large
87069	75312	88	Ростовская область, Октябрьский район, Новочеркасск, Калинина, 25	f	large
68839	75303	78	Ростовская область, Октябрьский район, Новочеркасск, Заводская, 3	f	large
68816	75276	54	Ростовская область, Октябрьский район, Новочеркасск, Ермака, 92	f	large
68844	75308	83	Ростовская область, Октябрьский район, Новочеркасск, Гвардейская, 19	f	large
68845	75306	84	Ростовская область, Октябрьский район, Новочеркасск, Высоковольтная, 1	f	large
68843	75306	82	Ростовская область, Октябрьский район, Новочеркасск, Высоковольтная, 1	f	large
68811	75271	49	Ростовская область, Октябрьский район, Новочеркасск, Буденновская, 94	f	large
68809	75268	46	Ростовская область, Октябрьский район, Новочеркасск, Буденновская, 188	f	large
87063	75273	50	Ростовская область, Октябрьский район, Новочеркасск, Баклановский проспект, 102, МУП Центр технической инвентаризации	f	large
68808	75267	45	Ростовская область, Октябрьский район, Новочеркасск, Баклановский проспект, 136	f	large
68805	75264	42	Ростовская область, Октябрьский район, Новочеркасск, Баклановский проспект, 190	f	large
68826	75285	64	Ростовская область, Октябрьский район, Новочеркасск, Александровская, 109	f	large
68825	75284	63	Ростовская область, Октябрьский район, Новочеркасск, Александровская, 72	f	large
68937	75534	293	Ростовская область, Октябрьский район, поселок Новосветловский, Мокроусова, 251	f	large
113936	75539	298	Ростовская область, Октябрьский район, поселок Новоперсиановка, Советская, 12	f	medium
113934	75536	295	Ростовская область, Октябрьский район, хутор Новопавловка, Центральная, 18-А	t	small
68932	75519	279	Ростовская область, Октябрьский район, поселок Новокадамово, Клубная, 7	f	large
113940	75550	309	Ростовская область, Октябрьский район, поселок Новозарянский, Ленина, 33	f	medium
68943	75544	303	Ростовская область, Октябрьский район, поселок Нижнедонской, Ленина, 9	f	large
113939	75549	308	Ростовская область, Октябрьский район, поселок Мокрый Лог, Рослова, 52-А	f	small
113935	75538	297	Ростовская область, Октябрьский район, хутор Марьевка, Вишневая, 6-А	t	small
113941	75551	310	Ростовская область, Октябрьский район, хутор Маркин, Клубная, 1	f	medium
70186	77660	2506	Ростовская область, Октябрьский район, станица Кривянская, Советская, №100	f	large
68945	75547	306	Ростовская область, Октябрьский район, станица Кривянская, Октябрьская, 81	f	large
68946	75548	307	Ростовская область, Октябрьский район, станица Кривянская, Кооперативная, 119	f	large
68944	75546	305	Ростовская область, Октябрьский район, станица Кривянская, Кирпичная, 1	f	large
68941	75541	300	Ростовская область, Октябрьский район, слобода Красюковская, Советская, 24	f	large
68942	75542	301	Ростовская область, Октябрьский район, слобода Красюковская, Горького, 67	f	large
113938	75545	304	Ростовская область, Октябрьский район, хутор Красный Луч, Центральная, 54	f	small
68938	75535	294	Ростовская область, Октябрьский район, хутор Красный Кут, Чистова, 2в	f	large
68935	75530	290	Ростовская область, Октябрьский район, поселок Красногорняцкий, Чапаева, 26а	f	large
113926	75521	281	Ростовская область, Октябрьский район, хутор Костиков, Центральная, 56-В	f	small
113924	75518	278	Ростовская область, Октябрьский район, хутор Киреевка, Ленина, №1	f	medium
113930	75527	287	Ростовская область, Октябрьский район, хутор Керчик-Савров, Советская, 36	t	medium
87111	77661	2507	Ростовская область, Октябрьский район, ПГТ Каменоломни, переулок Шоссейный, 10а	f	large
68951	75558	317	Ростовская область, Октябрьский район, ПГТ Каменоломни, Крупской, 39	f	large
68954	75561	320	Ростовская область, Октябрьский район, ПГТ Каменоломни, 4-й переулок, 1	f	large
68952	75559	318	Ростовская область, Октябрьский район, поселок Каменоломни, Дзержинского, 78б	f	large
114840	77640	2483	Ростовская область, Октябрьский район, хутор Калиновка, Центральная, 32	f	small
113929	75526	286	Ростовская область, Октябрьский район, хутор Калинин, Центральная, 82	t	small
68950	75556	315	Ростовская область, Октябрьский район, поселок Казачьи Лагери, Российская, 4	f	large
113943	75557	316	Ростовская область, Октябрьский район, поселок Казачьи Лагери, им. Петрушко, 1	f	medium
113942	75555	314	Ростовская область, Октябрьский район, поселок Кадамовский, Садовая, 5	f	medium
68939	75537	296	Ростовская область, Октябрьский район, поселок Интернациональный, Железнодорожная, 57	f	large
68931	75517	277	Ростовская область, Октябрьский район, хутор Ильичевка, Победы Революции, 26	f	large
68933	75524	284	Ростовская область, Октябрьский район, станица Заплавская, Ленина, 1	f	large
113933	75531	291	Ростовская область, Октябрьский район, поселок Заозерье, Центральная, 11	t	small
113932	75529	289	Ростовская область, Октябрьский район, поселок Залужный, Школьная, 1	t	small
113931	75528	288	Ростовская область, Октябрьский район, хутор Веселая Бахмутовка, Логвинова, 2	t	small
113927	75522	282	Ростовская область, Октябрьский район, хутор Верхняя Кадамовка, Галенко, 2	t	small
87079	75532	292	Ростовская область, Октябрьский район, поселок Верхнегрушевский, Школьная, 20	f	large
68934	75525	285	Ростовская область, Октябрьский район, станица Бессергеневская, Комарова, 7	f	large
113937	75543	302	Ростовская область, Октябрьский район, хутор Аюта, Заповедная, 2	f	small
113925	75520	280	Ростовская область, Октябрьский район, поселок Атюхта, Центральная, 11-А	t	small
113923	75516	276	Ростовская область, Октябрьский район, село Алексеевка, Ленина, 2	f	medium
114401	76365	1136	Ростовская область, Обливский район, поселок Шаповаловка, Центральная, 7	f	small
114396	76361	1131	Ростовская область, Обливский район, поселок Средний Чир, Первомайская, 1а	f	medium
114412	76376	1147	Ростовская область, Обливский район, поселок Сосновый, Казачья, 1	f	small
114403	76367	1138	Ростовская область, Обливский район, хутор Солонецкий, Ленина, 8	f	medium
114404	76368	1139	Ростовская область, Обливский район, хутор Сиволобов, Школьная, 9	f	small
114402	76366	1137	Ростовская область, Обливский район, поселок Пухов, Дорожная, 5	f	small
69281	76358	1128	Ростовская область, Обливский район, станица Обливская, Лесхозная, 1	f	large
87058	76355	1126	Ростовская область, Обливский район, станица Обливская, Ленина, 47	f	large
69278	76354	1125	Ростовская область, Обливский район, станица Обливская, Коммунистическая, 4	f	large
69280	76357	1127	Ростовская область, Обливский район, станица Обливская, Грызлова, 18а	f	large
114405	76369	1140	Ростовская область, Обливский район, поселок Новополеевский, переулок Торговый, 9	f	small
114398	76363	1133	Ростовская область, Обливский район, хутор Нестеркин, Центральная, 62	f	medium
114409	76373	1144	Ростовская область, Обливский район, хутор Машинский, Центральная, 5	f	small
114395	76360	1130	Ростовская область, Обливский район, хутор Лобачев, Чирская, 38	f	medium
114407	76371	1142	Ростовская область, Обливский район, хутор Леонов, Терешковой, 5	f	small
114399	76279	1134	Ростовская область, Обливский район, хутор Кривов, Центральная, 35	f	small
114394	76359	1129	Ростовская область, Обливский район, хутор Ковыленский, Речная, 36	f	small
114411	76375	1146	Ростовская область, Обливский район, хутор Киреев, Мира, 38	f	small
114400	76364	1135	Ростовская область, Обливский район, поселок Каштановский, Школьная, 4	f	medium
114410	76374	1145	Ростовская область, Обливский район, хутор Караичев, Восточная, 15	f	small
114397	76362	1132	Ростовская область, Обливский район, хутор Дубовой, Сосновая, 9	f	small
114408	76372	1143	Ростовская область, Обливский район, хутор Алексеевский, Ленина, 11	f	small
114406	76370	1141	Ростовская область, Обливский район, хутор Александровский, Школьная, 4	f	small
114640	77139	1961	Ростовская область, Неклиновский район, село Щербаково, Калинина, 30	f	small
114625	77119	1944	Ростовская область, Неклиновский район, хутор Чекилев, Солнечная, 53	f	small
114615	77103	1931	Ростовская область, Неклиновский район, село Христофоровка, Октябрьская, 24а	f	medium
114603	77085	1916	Ростовская область, Неклиновский район, хутор Халыбо-Адабашев, Молодежная, 18б	f	small
69854	77116	1941	Ростовская область, Неклиновский район, село Федоровка, Ленина, 48	f	large
69841	77073	1904	Ростовская область, Неклиновский район, село Троицкое, Ленина, 74	f	large
69840	77072	1903	Ростовская область, Неклиновский район, село Троицкое, Ленина, 120а	f	large
114630	77124	1949	Ростовская область, Неклиновский район, хутор Таврический, Мира, 36а	f	small
114598	77067	1899	Ростовская область, Неклиновский район, поселок Сухосарматка, Садовая, 14	f	medium
114605	77087	1918	Ростовская область, Неклиновский район, слобода Советка, пр. им. Победы, 18	f	medium
69847	77083	1914	Ростовская область, Неклиновский район, село Синявское	f	large
69848	77084	1915	Ростовская область, Неклиновский район, село Синявское, Ленина, 351	f	large
69842	77075	1906	Ростовская область, Неклиновский район, село Самбек, Кооперативная, 27	f	large
114617	77106	1934	Ростовская область, Неклиновский район, хутор Русский Колодец, Дзержинского, 14а	f	medium
114635	77132	1956	Ростовская область, Неклиновский район, хутор Рожок, им. Приходько П.Е, 23а	f	medium
114595	77063	1896	Ростовская область, Неклиновский район, хутор Родионовка, им. Ленина, 51	f	small
114641	77140	1962	Ростовская область, Неклиновский район, хутор Пудовой, Гагарина, 17а	f	small
114610	77093	1923	Ростовская область, Неклиновский район, хутор Приют, Космическая, 49	f	small
69846	77079	1910	Ростовская область, Неклиновский район, село Приморка, Ленина, 239б	f	large
69845	77079	1909	Ростовская область, Неклиновский район, село Приморка, Ленина, 239б	f	large
114980	77133	1957	Ростовская область, Неклиновский район, поселок Приазовский, Луговая, 1А	f	medium
69833	77055	1888	Ростовская область, Неклиновский район, село Покровское, переулок им. Маяковского, 3	f	large
69834	77056	1889	Ростовская область, Неклиновский район, село Покровское, пер. Тургеневский, 12	f	large
69836	77058	1891	Ростовская область, Неклиновский район, село Покровское, Привокзальная, 38	f	large
69835	77057	1890	Ростовская область, Неклиновский район, село Покровское, Ленина, 438	f	large
87097	77094	1924	Ростовская область, Неклиновский район, село Петрушино, Ворошилова, 102	f	large
114623	77117	1942	Ростовская область, Неклиновский район, хутор Петровский, Мичурина, 18	f	small
114594	77062	1895	Ростовская область, Неклиновский район, село Отрадное, Ленина, 13	f	medium
114628	77122	1947	Ростовская область, Неклиновский район, село Носово, Клубная, 34а	f	medium
114624	77118	1943	Ростовская область, Неклиновский район, хутор Новофедоровский	f	small
114607	77090	1920	Ростовская область, Неклиновский район, село Новостроенка, Ленина, 23	f	small
114600	77080	1911	Ростовская область, Неклиновский район, поселок Новоприморский, Центральная, 1	f	medium
114925	77773	2638	Ростовская область, Неклиновский район, хутор Новозолотовка, Транспортная, 29	f	medium
69850	77096	1925	Ростовская область, Неклиновский район, село Новобессергеневка, Коминтерна, 33	f	large
114613	77100	1928	Ростовская область, Неклиновский район, село Никольское, Центральная, 2	f	small
114632	77127	1952	Ростовская область, Неклиновский район, хутор Николаево-Отрадное, им. Ленина, 37а	f	small
114639	77138	1960	Ростовская область, Неклиновский район, хутор Николаево-Козловский, Шолохова, 16	f	small
114638	77137	1959	Ростовская область, Неклиновский район, хутор Николаево-Иловайский, Ленина, 38	f	small
114897	77068	2586	Ростовская область, Неклиновский район, село Николаевка, переулок Школьный, 1	f	medium
114926	77775	2642	Ростовская область, Неклиновский район, село Николаевка, Садовая, 103	f	medium
87096	77069	1900	Ростовская область, Неклиновский район, село Николаевка, Садовая, 39	f	large
69838	77070	1901	Ростовская область, Неклиновский район, село Николаевка, Ленина, 341	f	large
114604	77086	1917	Ростовская область, Неклиновский район, хутор Некрасовка, пер. Молодежный, 11	f	small
69855	77125	1950	Ростовская область, Неклиновский район, село Натальевка, Чехова, 46а	f	large
114602	77082	1913	Ростовская область, Неклиновский район, хутор Морской Чулек, Красногвардейская, 21а	f	medium
21135	45957	3710	Краснодарский край, Новороссийск, Цедрика, 7	f	large
114627	77121	1946	Ростовская область, Неклиновский район, хутор Михайловка, Садовая	f	small
114601	77081	1912	Ростовская область, Неклиновский район, хутор Мержаново, Первомайская, 31	f	medium
114596	77064	1897	Ростовская область, Неклиновский район, село Марьевка, им. Ленина, 100	f	small
114978	77110	1936	Ростовская область, Неклиновский район, село Малофедоровка, Клубная, 8-А	f	small
114979	77130	1955	Ростовская область, Неклиновский район, хутор Максимов, пер. Кольцевой, 2-А	f	small
114608	77091	1921	Ростовская область, Неклиновский район, хутор Любовка, Красносельская, 24	f	small
114631	77126	1951	Ростовская область, Неклиновский район, хутор Ломакин, Набережная, 9	f	small
69853	77112	1937	Ростовская область, Неклиновский район, село Лакедемоновка, Ленина, 50б	f	large
114599	77074	1905	Ростовская область, Неклиновский район, хутор Курлацкий, Кооперативная, 3	f	medium
114614	77102	1930	Ростовская область, Неклиновский район, хутор Красный Десант, Октябрьская, 2	f	medium
114609	77092	1922	Ростовская область, Неклиновский район, хутор Копани, Металлургическая, 32	f	small
69852	77104	1932	Ростовская область, Неклиновский район, хутор Ключникова Балка, Октябрьская, 83	f	large
114629	77123	1948	Ростовская область, Неклиновский район, село Ивановка, Миусская, 29	f	small
114616	77105	1933	Ростовская область, Неклиновский район, поселок Золотая Коса, Октябрьская, 73а	f	medium
114593	77061	1894	Ростовская область, Неклиновский район, хутор Жатва, Полевая, 1а	f	small
114626	77120	1945	Ростовская область, Неклиновский район, село Ефремовка, Транспортная, 1	f	medium
114976	77098	1926	Ростовская область, Неклиновский район, поселок Дмитриадовка, 2-я Степная, 1	f	small
114612	77099	1927	Ростовская область, Неклиновский район, хутор Дарагановка, Центральная, 160	f	small
114606	77089	1919	Ростовская область, Неклиновский район, село Горская Порада, Центральная, 22	f	small
69839	77071	1902	Ростовская область, Неклиновский район, хутор Гаевка, переулок Ореховый, 12	f	large
114977	77108	1935	Ростовская область, Неклиновский район, село Гаевка, им. Ленина, 34А	f	small
69851	77101	1929	Ростовская область, Неклиновский район, хутор Веселый, Ленина, 11	f	large
69856	77129	1954	Ростовская область, Неклиновский район, село Весело-Вознесенка, Октябрьская, 93а	f	large
114637	77136	1958	Ростовская область, Неклиновский район, село Васильево-Ханжоновка, Школьная, 9	f	medium
69843	77076	1907	Ростовская область, Неклиновский район, село Вареновка, Советская, 124	f	large
114591	77059	1892	Ростовская область, Неклиновский район, село Большая Неклиновка, пер. Памятный, 1а	f	medium
114592	77060	1893	Ростовская область, Неклиновский район, село Большая Неклиновка, Школьная, 76а	f	medium
69844	77078	1908	Ростовская область, Неклиновский район, село Бессергеновка, Школьная, 2	t	large
114622	77115	1940	Ростовская область, Неклиновский район, село Беглица, Садовая, 81а	f	small
114620	77113	1938	Ростовская область, Неклиновский район, село Беглица, Октябрьская, 68б, 16-й участок	f	small
114621	77114	1939	Ростовская область, Неклиновский район, село Беглица, Ленина, 30а	f	medium
114597	77066	1898	Ростовская область, Неклиновский район, село Андреево-Мелентьево, им. Победы, 16-а	f	medium
114633	77128	1953	Ростовская область, Неклиновский район, хутор Александрово-Марково, Энгельса, 18	f	small
114858	77673	2518	Ростовская область, Неклиновский район, село Александрова Коса, Цветочная, 1	f	medium
114588	76961	1777	Ростовская область, Мясниковский район, хутор Чкалова, Нижняя	f	small
69717	76948	1764	Ростовская область, Мясниковский район, село Чалтырь, Туманяна, 2	f	large
69474	76709	1493	Ростовская область, Мясниковский район, село Чалтырь, Синявская, 19б	f	large
69715	76946	1762	Ростовская область, Мясниковский район, село Чалтырь, Октябрьская, 36	f	large
69716	76947	1763	Ростовская область, Мясниковский район, село Чалтырь, Мясникяна, 18	f	large
69714	76945	1761	Ростовская область, Мясниковский район, село Чалтырь, Мясникяна, 88	f	large
69718	76949	1765	Ростовская область, Мясниковский район, село Чалтырь, 6-я линия, 86	f	large
114587	76959	1775	Ростовская область, Мясниковский район, хутор Хапры, пер.Макаренко, 9	f	medium
114585	76955	1771	Ростовская область, Мясниковский район, село Султан-Салы, Селиверстова, 2	f	medium
83923	57341	3118	Москва, Зеленоград, к603а	f	large
69725	76962	1778	Ростовская область, Мясниковский район, слобода Петровка, Школьная, 15	f	large
114586	76956	1772	Ростовская область, Мясниковский район, село Несветай, Ворошилова, 1 А	f	small
114884	77712	2566	Ростовская область, Мясниковский район, хутор Мокрый Чалтырь, Ленина, 3	f	small
114583	76953	1769	Ростовская область, Мясниковский район, хутор Ленинакан, Трудовая, 1	f	small
69721	76952	1768	Ростовская область, Мясниковский район, хутор Ленинаван, Ленина, 5	f	large
69711	76942	1758	Ростовская область, Мясниковский район, село Крым, Советская, 3	f	large
69719	76950	1766	Ростовская область, Мясниковский район, село Крым, 8-я линия, 14	f	large
114584	76954	1770	Ростовская область, Мясниковский район, хутор Красный Крым, Туманяна, 51	f	medium
70185	77659	2505	Ростовская область, Мясниковский район, хутор Калинин, Школьная, 136	f	large
69720	76951	1767	Ростовская область, Мясниковский район, хутор Калинин, Школьная, 81	f	large
69724	76960	1776	Ростовская область, Мясниковский район, хутор Веселый, Новая, 5	f	large
69722	76957	1773	Ростовская область, Мясниковский район, село Большие Салы, Советская, 8	f	large
70231	77757	2616	Ростовская область, Мясниковский район, село Большие Салы, Оганяна, 7	f	large
114589	76963	1779	Ростовская область, Мясниковский район, село Александровка 2-я, Центральная, 26	f	medium
114375	76335	1105	Ростовская область, Морозовский район, хутор Широко-Атамановский, Мира, 33	f	small
114386	76346	1117	Ростовская область, Морозовский район, станица Чертковская, Степная, 22	f	small
114379	76339	1109	Ростовская область, Морозовский район, хутор Чекалов, Центральная, 12б	f	small
114393	76353	1124	Ростовская область, Морозовский район, хутор Трофименков, Садовая, 14	f	small
114381	76341	1111	Ростовская область, Морозовский район, поселок Табунный, 17	f	small
114387	76347	1118	Ростовская область, Морозовский район, хутор Старопетровский, Лютиковая, 1	f	small
114389	76349	1120	Ростовская область, Морозовский район, хутор Сибирьки, Степная, 21	f	small
114382	76342	1113	Ростовская область, Морозовский район, поселок Разлатный, Разлатный, 7	f	small
114374	76334	1104	Ростовская область, Морозовский район, хутор Покровский, Покровская, 52	f	small
114385	76345	1116	Ростовская область, Морозовский район, хутор Парамонов, Центральная, 41	f	medium
114369	76328	1098	Ростовская область, Морозовский район, хутор Общий, Энтузиастов, 33	f	small
114392	76352	1123	Ростовская область, Морозовский район, хутор Новопроциков, Школьная, 54	f	small
114383	76343	1114	Ростовская область, Морозовский район, хутор Николаев, Придорожная, 29б	f	medium
69271	76321	1091	Ростовская область, Морозовский район, Морозовск, Филонова, 7	f	large
69272	76322	1092	Ростовская область, Морозовский район, Морозовск, Ляшенко, 96	f	large
69267	76317	1086	Ростовская область, Морозовский район, Морозовск, Луначарского, 122	f	large
69300	76472	1243	Ростовская область, Морозовский район, Морозовск, Ленина, 296	f	large
69282	76377	1148	Ростовская область, Морозовский район, Морозовск, Ленина, 169	f	large
69275	76325	1095	Ростовская область, Морозовский район, Морозовск, Кирова, 152	f	large
69274	76324	1094	Ростовская область, Морозовский район, Морозовск, Кирова, 124	f	large
69266	76316	1085	Ростовская область, Морозовский район, Морозовск, Карла Маркса, 5	f	large
69269	76319	1089	Ростовская область, Морозовский район, Морозовск, Дзержинского, 7	f	large
69273	76323	1093	Ростовская область, Морозовский район, Морозовск, Ворошилова, 264	f	large
69270	76320	1090	Ростовская область, Морозовский район, Морозовск, Ворошилова, 170	f	large
69277	76332	1102	Ростовская область, Морозовский район, хутор Морозов, Дорожная, 34	f	large
114376	76336	1106	Ростовская область, Морозовский район, хутор Малая Хлоповая, Солнечная, 26	f	small
114391	76351	1122	Ростовская область, Морозовский район, хутор Костино-Быстрянский, Котельникова, 74	f	medium
114377	76337	1107	Ростовская область, Морозовский район, поселок Комсомольский, Центральная, 51	f	small
114380	76340	1110	Ростовская область, Морозовский район, поселок Знаменка, Дружбы, 18	f	medium
114373	76333	1103	Ростовская область, Морозовский район, хутор Донской, Школьная, 17	f	small
114372	76331	1101	Ростовская область, Морозовский район, хутор Гурин, Гурина, 17	f	small
22149	46951	5927	Краснодарский край, Новороссийск, Фрунзе, 50	f	large
114368	76327	1097	Ростовская область, Морозовский район, хутор Грузинов, Центральная, 55	f	medium
114388	76348	1119	Ростовская область, Морозовский район, станица Вольно-Донская, Стадионная, 3	f	medium
114370	76329	1099	Ростовская область, Морозовский район, хутор Вознесенский, Центральная, 14	f	medium
114872	77692	2540	Ростовская область, Морозовский район, хутор Владимиров, Молодежная, 26	f	small
114390	76350	1121	Ростовская область, Морозовский район, хутор Вишневка, Центральная, 40	f	small
114371	76330	1100	Ростовская область, Морозовский район, хутор Вербочки, Мира, 37	f	small
114871	77691	2539	Ростовская область, Морозовский район, хутор Быстрый, Быстрая, 30	f	small
114378	76338	1108	Ростовская область, Морозовский район, хутор Беляев, Молодежная, 2а	f	small
114384	76344	1115	Ростовская область, Морозовский район, хутор Александров, Центральная, 13	f	medium
114363	76307	1077	Ростовская область, Милютинский район, хутор Юдин, Заречная, 2/35	f	medium
114831	77621	2455	Ростовская область, Милютинский район, хутор Юдин, Березовый переулок, 1	f	small
114362	76306	1076	Ростовская область, Милютинский район, хутор Широко-Бахолдинский, Школьная, 4	f	small
114890	77719	2573	Ростовская область, Милютинский район, хутор Терновой, Городская, 1	f	small
114366	76311	1081	Ростовская область, Милютинский район, хутор Сулинский, Центральная, 18/2	f	medium
114364	76309	1079	Ростовская область, Милютинский район, хутор Старокузнецов, пер. Культурный, 6	f	medium
114355	76299	1069	Ростовская область, Милютинский район, станица Селивановская, Титова, 21	f	medium
114922	77770	2635	Ростовская область, Милютинский район, станица Селивановская, Песчаная, 48	f	small
114356	76300	1070	Ростовская область, Милютинский район, хутор Севостьянов, Школьная, 23	f	small
114361	76305	1075	Ростовская область, Милютинский район, поселок Светоч, Западная, 2/2	f	small
114354	76298	1068	Ростовская область, Милютинский район, хутор Решетняков, Центральная, 14	f	small
114921	77768	2633	Ростовская область, Милютинский район, хутор Павловка, 3-я Пионерская, 18	f	small
114360	76304	1074	Ростовская область, Милютинский район, хутор Орлов, Центральная, 3	f	small
114365	76310	1080	Ростовская область, Милютинский район, хутор Образцов, Студенческая, 6	f	small
114357	76301	1071	Ростовская область, Милютинский район, хутор Новодмитриевский, Новодмитриевская, 12	f	small
114349	76293	1063	Ростовская область, Милютинский район, хутор Николовка, переулок Школьный, 2	f	medium
114351	76295	1065	Ростовская область, Милютинский район, хутор Нижнепетровский, Ермака, 3	f	small
70237	77769	2634	Ростовская область, Милютинский район, станица Милютинская, Красноармейская, 14	f	large
69263	76308	1078	Ростовская область, Милютинский район, станица Милютинская, Комсомольская, 32	f	large
114352	76296	1066	Ростовская область, Милютинский район, слобода Маньково-Березовская, Проходной, 18	f	medium
114358	76302	1072	Ростовская область, Милютинский район, хутор Кутейников, Центральная, 14	f	small
114359	76303	1073	Ростовская область, Милютинский район, поселок Доброполье, Солнечная, 2	f	small
114923	77771	2636	Ростовская область, Милютинский район, хутор Вячеслав, Вячеслав, 9	f	small
114924	77772	2637	Ростовская область, Милютинский район, хутор Волоцков, Мира, 9	f	small
114920	77767	2632	Ростовская область, Милютинский район, хутор Антоновка, Сельская, 4	f	small
114367	76312	1082	Ростовская область, Милютинский район, поселок Аграрный, Строительная, 18/27	f	small
114205	76105	881	Ростовская область, Миллеровский район, поселок Ярский, Молодежная, 11	f	small
114211	76112	888	Ростовская область, Миллеровский район, хутор Хмызов, Ленина, 7	f	medium
114202	76102	878	Ростовская область, Миллеровский район, хутор Фоминка, Станиславского, 2	f	small
114199	76099	875	Ростовская область, Миллеровский район, хутор Туроверово-Глубокинский, Российская, 48	f	medium
114838	77638	2480	Ростовская область, Миллеровский район, хутор Треневка, пер. Школьный, 3	f	small
114225	76131	905	Ростовская область, Миллеровский район, слобода Титовка, Ленина, 8	f	small
114961	76128	903	Ростовская область, Миллеровский район, хутор Терновой, Школьная, 32	f	medium
114210	76111	887	Ростовская область, Миллеровский район, слобода Терновая, Школьная, 22	f	medium
87076	75464	231	Ростовская область, Зерноградский район, Зерноград, Ленина, 14	f	large
114230	76138	911	Ростовская область, Миллеровский район, хутор Сулин, Северная, 9	f	medium
114228	76135	909	Ростовская область, Миллеровский район, слобода Рогалик, Дружбы, 67	f	small
114215	76120	895	Ростовская область, Миллеровский район, слобода Поповка, Садовая, 3	f	small
114207	76108	884	Ростовская область, Миллеровский район, слобода Позднеевка, Советская, 2-а	f	medium
114209	76110	886	Ростовская область, Миллеровский район, село Ольховый Рог, Вокзальная, 6	f	medium
114876	77702	2553	Ростовская область, Миллеровский район, хутор Новоспасовка, Центральная, 19	f	medium
114219	76124	899	Ростовская область, Миллеровский район, хутор Новая Деревня, Милькевича, 8	f	small
114204	76104	880	Ростовская область, Миллеровский район, слобода Никольская, Школьная, 43	f	medium
114224	76130	904	Ростовская область, Миллеровский район, слобода Нижненагольная, Российская, 1	f	medium
114227	76134	908	Ростовская область, Миллеровский район, слобода Нижнекамышинка, Центральная, 11	f	small
69232	76096	872	Ростовская область, Миллеровский район, Миллерово, квартал имени маршала Ефимова, гимназия №7	f	large
114197	76087	863	Ростовская область, Миллеровский район, Миллерово, квартал ДСХТ, 29	f	medium
69224	76088	864	Ростовская область, Миллеровский район, Миллерово, Энгельса, 26	f	large
69221	76084	860	Ростовская область, Миллеровский район, Миллерово, Осоавиахима, 15	f	large
69229	76093	869	Ростовская область, Миллеровский район, Миллерово, Нахимова, 45	f	large
69222	76085	861	Ростовская область, Миллеровский район, Миллерово, Менделеева, 27	f	large
69227	76091	867	Ростовская область, Миллеровский район, Миллерово, Криничная, 16	f	large
69231	76095	871	Ростовская область, Миллеровский район, Миллерово, Заводская, 15	f	large
69225	76089	865	Ростовская область, Миллеровский район, Миллерово, Жуковского, 60	f	large
69223	76086	862	Ростовская область, Миллеровский район, Миллерово, Донецкая, 2	f	large
69226	76090	866	Ростовская область, Миллеровский район, Миллерово, Артиллерийская, 24	f	large
114226	76132	906	Ростовская область, Миллеровский район, слобода Машлыкино, пер. Школьный, 22	f	small
114222	76127	902	Ростовская область, Миллеровский район, слобода Мальчевско-Полненская, Школьная, 1	f	medium
69237	76119	894	Ростовская область, Миллеровский район, станица Мальчевская, Голдобина, 1а	f	large
114201	76101	877	Ростовская область, Миллеровский район, хутор Малотакмацкий, Мира, 15	f	medium
114214	76118	893	Ростовская область, Миллеровский район, слобода Кудиновка, Победы, 21	f	medium
114208	76109	885	Ростовская область, Миллеровский район, хутор Криничный, Речная, 79	f	small
69234	76106	882	Ростовская область, Миллеровский район, слобода Криворожье, Ленина, 33	f	large
69236	76117	892	Ростовская область, Миллеровский район, слобода Колодези, Советская, 15	f	large
114203	76103	879	Ростовская область, Миллеровский район, хутор Каменка, Почтовая, 2	f	medium
114875	77701	2552	Ростовская область, Миллеровский район, хутор Ивановка, Фабричная, 21	f	small
114216	76121	896	Ростовская область, Миллеровский район, хутор Зеленая Роща, Школьная, 3-а	f	small
113904	75481	246	Ростовская область, Миллеровский район, хутор Жеребковский, Свободы, 7	t	small
114212	76113	889	Ростовская область, Миллеровский район, хутор Еритовка, Центральная, 14	f	small
114206	76107	883	Ростовская область, Миллеровский район, хутор Екатериновка, Юбилейная, 85	f	small
114221	76126	901	Ростовская область, Миллеровский район, поселок Долотинка, Советская, 3-в	f	medium
69235	76115	890	Ростовская область, Миллеровский район, слобода Дегтево, Российская, 34	f	large
114200	76100	876	Ростовская область, Миллеровский район, хутор Греково-Станичный, Станичная, 26	f	small
114220	76125	900	Ростовская область, Миллеровский район, слобода Греково, Центральная, 3	f	medium
114213	76116	891	Ростовская область, Миллеровский район, хутор Грай-Воронец, Московская, 77	f	small
114217	76122	897	Ростовская область, Миллеровский район, хутор Гетманов, Гетмановская, 41	f	small
114874	77700	2551	Ростовская область, Миллеровский район, хутор Гернер, Восточная, 9	f	small
69238	76133	907	Ростовская область, Миллеровский район, слобода Волошино, Ленина, 27	f	large
114198	76098	874	Ростовская область, Миллеровский район, хутор Верхнеталовка, Центральная, 38	f	medium
68919	75480	245	Ростовская область, Зерноградский район, Зерноград, Еремина, 17	f	large
114218	76123	898	Ростовская область, Миллеровский район, хутор Венделеевка, Молодежная, 2	f	medium
114873	77699	2550	Ростовская область, Миллеровский район, хутор Беляевск, Школьная, 3	f	small
114962	76136	910	Ростовская область, Миллеровский район, хутор Ануфриевка, Калинина, 91	f	small
114843	77643	2486	Ростовская область, Матвеево-Курганский район, село Шапошниково, Примиусская, 88	f	small
114826	77613	2447	Ростовская область, Матвеево-Курганский район, поселок Сухореченский, Парковая, 1	f	small
114643	77147	1968	Ростовская область, Матвеево-Курганский район, хутор Староротовка, проспект Дружбы, 68	f	medium
69862	77149	1970	Ростовская область, Матвеево-Курганский район, село Рясное, Таганрогская, 2а	f	large
69861	77148	1969	Ростовская область, Матвеево-Курганский район, село Ряженое, Ленина, 4	f	large
114645	77151	1972	Ростовская область, Матвеево-Курганский район, село Политотдельское, Азарова, 12	f	medium
114654	77161	1982	Ростовская область, Матвеево-Курганский район, село Новониколаевка, Ленина, 69А	f	medium
114647	77153	1974	Ростовская область, Матвеево-Курганский район, село Новоандриановка, 50 лет Победы, 48	f	medium
114650	77156	1977	Ростовская область, Матвеево-Курганский район, поселок Надежда, Первомайская, 38	f	medium
69860	77145	1966	Ростовская область, Матвеево-Курганский район, поселок Матвеев Курган, Славы, 6	f	large
70156	77612	2446	Ростовская область, Матвеево-Курганский район, поселок Матвеев Курган, Донецкая, 1	f	large
69859	77144	1965	Ростовская область, Матвеево-Курганский район, поселок Матвеев Курган, 1-я Пятилетка, 107	f	large
69857	77141	1963	Ростовская область, Матвеево-Курганский район, поселок Матвеев Курган, 1-я Пятилетка, 42	f	large
87098	77142	1964	Ростовская область, Матвеево-Курганский район, поселок Матвеев Курган, 1-я Мая, 18	f	large
114646	77152	1973	Ростовская область, Матвеево-Курганский район, село Марьевка, Парамонова, 39А	f	medium
69864	77163	1984	Ростовская область, Матвеево-Курганский район, село Марфинка, Центральная, 59а	f	large
114659	77169	1990	Ростовская область, Матвеево-Курганский район, село Малокирсановка, Аникиенко, 52	f	medium
114656	77166	1987	Ростовская область, Матвеево-Курганский район, хутор Малоекатериновка, Центральная, 32	f	small
114655	77162	1983	Ростовская область, Матвеево-Курганский район, поселок Ленинский, Центральная, 35	f	medium
69867	77170	1991	Ростовская область, Матвеево-Курганский район, село Латоново, Ленина, 61	f	large
114649	77155	1976	Ростовская область, Матвеево-Курганский район, село Кульбаково, Таганрогская, 56А	f	medium
114653	77159	1980	Ростовская область, Матвеево-Курганский район, поселок Крынка, Светлая, 19	f	medium
114642	77146	1967	Ростовская область, Матвеево-Курганский район, поселок Красный Бумажник, Заречная, 4	f	small
114660	77172	1992	Ростовская область, Матвеево-Курганский район, хутор Красная Горка, Школьная, 2А	f	small
114827	77614	2448	Ростовская область, Матвеево-Курганский район, хутор Колесниково, Таганрогская, 2	f	medium
114644	77150	1971	Ростовская область, Матвеево-Курганский район, село Каменно-Андрианово, Центральная, 66	f	medium
69866	77165	1986	Ростовская область, Матвеево-Курганский район, село Екатериновка, переулок Школьный, 2	f	large
114657	77167	1988	Ростовская область, Матвеево-Курганский район, село Григорьевка, Кирова, 34	f	medium
114658	77168	1989	Ростовская область, Матвеево-Курганский район, село Греково-Тимофеевка, Мира, 57	f	medium
114648	77154	1975	Ростовская область, Матвеево-Курганский район, хутор Большая Кирсановка, Советская, 91Б	f	medium
69865	77164	1985	Ростовская область, Матвеево-Курганский район, село Анастасиевка, Ленина, 49	f	large
114651	77157	1978	Ростовская область, Матвеево-Курганский район, село Алексеевка, Гагарина, 34	f	medium
114652	77065	1979	Ростовская область, Матвеево-Курганский район, село Александровка, Московская, 39А	f	medium
114870	77690	2538	Ростовская область, Матвеево-Курганский район, хутор Авило-Федоровка, Победы, 1	f	small
69863	77160	1981	Ростовская область, Матвеево-Курганский район, село Авило-Успенка, Ленина, 60	f	large
69101	75855	629	Ростовская область, Мартыновский район, поселок Южный, переулок Клубный, 1	f	large
69102	75856	630	Ростовская область, Мартыновский район, поселок Южный, Административный переулок, 4	f	large
114078	75822	598	Ростовская область, Мартыновский район, поселок Черемухи, Ленина, 11	f	medium
114952	75857	631	Ростовская область, Мартыновский район, поселок Центральный, Ленина, 62	f	medium
114098	75826	624	Ростовская область, Мартыновский район, поселок Типчаковый, Краснопартизанская, 2а	f	small
114083	75828	603	Ростовская область, Мартыновский район, поселок Степной Маяк, Широкая, 23	f	small
114085	75833	608	Ростовская область, Мартыновский район, хутор Сальский Кагальник, Центральная, 9	f	medium
114951	75854	628	Ростовская область, Мартыновский район, хутор Пробуждение, Юбилейная, 57	f	small
114095	75847	621	Ростовская область, Мартыновский район, поселок Поречье, Северная, 1/2	f	small
114091	75843	617	Ростовская область, Мартыновский район, хутор Новоселовка, Кировская, 3А	f	medium
69096	75830	605	Ростовская область, Мартыновский район, хутор Новосадковский, Центральная, 2	f	large
114949	75852	626	Ростовская область, Мартыновский район, хутор Новониколаевский, Школьная, 24	t	\N
114097	75849	623	Ростовская область, Мартыновский район, поселок Новомартыновский, Думенко, 14	f	small
114090	75842	616	Ростовская область, Мартыновский район, поселок Новоберезовка, Центральная, 16А	f	medium
114092	75844	618	Ростовская область, Мартыновский район, хутор Несмеяновка, Несмеяновская, 116	f	small
114094	75846	620	Ростовская область, Мартыновский район, хутор Московский, Московская, 79А	f	small
69097	75832	607	Ростовская область, Мартыновский район, хутор Малоорловский, Новая, 25	f	large
114953	75858	632	Ростовская область, Мартыновский район, хутор Малая Мартыновка, Административная, 9	f	medium
114079	75823	599	Ростовская область, Мартыновский район, поселок Малая Горка, Садовая, 11	f	medium
114086	75834	609	Ростовская область, Мартыновский район, хутор Лесной, Центральная, 2	f	medium
114084	75831	606	Ростовская область, Мартыновский район, поселок Крутоярский, Широкая, 1	f	small
114077	75820	596	Ростовская область, Мартыновский район, поселок Крутобережный, Мира, 27	f	medium
114099	75851	625	Ростовская область, Мартыновский район, хутор Кривой Лиман, Молодежная, 29	f	medium
114093	75845	619	Ростовская область, Мартыновский район, хутор Красноармейский, Красноармейская, 71А	f	small
69095	75829	604	Ростовская область, Мартыновский район, хутор Комаров, Никифорова, 37а	f	large
114081	75825	601	Ростовская область, Мартыновский район, хутор Ильинов, пер. Пионерский, 8	f	medium
69094	75821	597	Ростовская область, Мартыновский район, поселок Зеленолугский, Строительный, 10	f	large
114950	75853	627	Ростовская область, Мартыновский район, хутор Засальский, Ленина, 75	f	small
114088	75836	611	Ростовская область, Мартыновский район, хутор Долгий, Школьная, 23	f	medium
114087	75835	610	Ростовская область, Мартыновский район, хутор Денисов, Школьная, 23	f	medium
114089	75841	615	Ростовская область, Мартыновский район, поселок Гром-Гора, Центральная, 15А	f	small
114954	75859	633	Ростовская область, Мартыновский район, поселок Восход, переулок Экскаваторный, 7	f	medium
114082	75827	602	Ростовская область, Мартыновский район, хутор Веселый, Кирова, 21	f	small
69092	75818	594	Ростовская область, Мартыновский район, слобода Большая Орловка, Советская, 25	f	large
69093	75819	595	Ростовская область, Мартыновский район, слобода Большая Орловка, Октябрьская, 88	f	large
69100	75840	614	Ростовская область, Мартыновский район, слобода Большая Мартыновка, переулок Зыгина, 12	f	large
69098	75837	612	Ростовская область, Мартыновский район, слобода Большая Мартыновка, Ленина, 98	f	large
69099	75839	613	Ростовская область, Мартыновский район, слобода Большая Мартыновка, Ковалева, 1а	f	large
114096	75848	622	Ростовская область, Мартыновский район, хутор Арбузов, Школьная, 24	f	medium
114080	75824	600	Ростовская область, Мартыновский район, поселок Абрикосовый, Школьная, 5А	f	small
114777	77503	2339	Ростовская область, Куйбышевский район, хутор Свободный, Победы, 29	f	small
114775	77501	2337	Ростовская область, Куйбышевский район, село Русское, Красноармейская, 8-А	f	small
114780	77508	2343	Ростовская область, Куйбышевский район, хутор Русско-Лютино, Социалистическая, 18-Б	f	small
114866	77686	2534	Ростовская область, Куйбышевский район, хутор Ольховский, Центральная, 5-А	f	small
68911	75469	235	Ростовская область, Зерноградский район, Зерноград, Гагарина, 1	f	large
114868	77688	2536	Ростовская область, Куйбышевский район, село Новоспасовка, Победы, 9в	f	small
114919	77766	2628	Ростовская область, Куйбышевский район, хутор Новобахмутский, Широкая, 89-А	f	small
114776	77502	2338	Ростовская область, Куйбышевский район, село Новиковка, Победы, 30	f	small
70098	77504	2340	Ростовская область, Куйбышевский район, хутор Новая Надежда, Юбилейная, 15	f	large
114778	77505	2341	Ростовская область, Куйбышевский район, село Миллерово, Школьная, 3	f	medium
70099	77509	2344	Ростовская область, Куйбышевский район, село Лысогорка, Кушнарёва, 7	f	large
70097	77500	2336	Ростовская область, Куйбышевский район, село Куйбышево, Театральная, 22	f	large
70096	77499	2335	Ростовская область, Куйбышевский район, село Куйбышево, Пролетарская, 2б	f	large
114781	77510	2345	Ростовская область, Куйбышевский район, хутор Крюково, Молодежная, 30	f	medium
114779	77506	2342	Ростовская область, Куйбышевский район, хутор Кринично-Лугский, Октябрьская, 38-В	f	medium
114867	77687	2535	Ростовская область, Куйбышевский район, хутор Карташево, Калинина, 18-А	f	small
114141	75938	724	Ростовская область, Куйбышевский район, село Каменно-Тузловка, Социалистическая, 18	f	small
114835	77627	2463	Ростовская область, Куйбышевский район, хутор Зайцево, Советская, 39	f	small
114744	77435	2275	Ростовская область, Красносулинский район, станция Замчалово, Пионерская, 1	f	small
114745	77436	2276	Ростовская область, Красносулинский район, хутор Ясный, Гуковская, 1	t	small
114763	77482	2320	Ростовская область, Красносулинский район, хутор Шахтенки, Школьный, 2	f	small
114755	77471	2310	Ростовская область, Красносулинский район, поселок Чичерино, Горького, 1	f	medium
114762	77481	2319	Ростовская область, Красносулинский район, хутор Черников, Советская, 4	f	small
114749	77463	2302	Ростовская область, Красносулинский район, хутор Чернецов, Щаденко, 2	f	small
114869	77689	2537	Ростовская область, Красносулинский район, хутор Чекунов, Мира, 23	f	small
114766	77486	2324	Ростовская область, Красносулинский район, хутор Украинский, Ворошилова, б/н	f	small
114743	77434	2274	Россия, Ростовская область, Красносулинский район, ПГТ Углеродовский	f	medium
70066	77433	2273	Ростовская область, Красносулинский район, ПГТ Углеродовский, Восточная, 73	f	large
70089	77466	2305	Ростовская область, Красносулинский район, поселок Тополевый, Советская, 1а	f	large
114773	77496	2333	Ростовская область, Красносулинский район, село Табунщиково, Ленина, 82	f	medium
70094	77490	2328	Ростовская область, Красносулинский район, хутор Садки, Советская, 17	f	large
114986	77497	2334	Ростовская область, Красносулинский район, поселок Рябиновка, Школьная, 5	f	small
114754	77469	2308	Ростовская область, Красносулинский район, хутор Русско-Прохоровский, Новая, 9	f	small
70090	77470	2309	Ростовская область, Красносулинский район, поселок Розет, Советская, 8а	f	large
114764	77484	2322	Ростовская область, Красносулинский район, село Прохоровка, Центральная, 27	f	small
70093	77483	2321	Ростовская область, Красносулинский район, хутор Пролетарка, Советская, 27	f	large
70095	77494	2331	Ростовская область, Красносулинский район, поселок Пригородный, Ленина, 1а	f	large
70092	77480	2318	Ростовская область, Красносулинский район, хутор Платово, Советская, 46	f	large
114736	77383	2225	Ростовская область, Красносулинский район, поселок Первомайский, Карла Маркса, 25	f	medium
114767	77487	2325	Ростовская область, Красносулинский район, село Павловка, Саломатина, 15	f	small
114750	77464	2303	Ростовская область, Красносулинский район, поселок Октябрьский	f	small
114760	77478	2316	Ростовская область, Красносулинский район, хутор Новоровенецкий, Карьерная, 61	f	medium
114761	77479	2317	Ростовская область, Красносулинский район, хутор Нижняя Ковалевка, Мичурина, 33-а	f	small
114819	77600	2434	Ростовская область, Красносулинский район, поселок Молодежный, Степная, 4	f	small
114984	77474	2313	Ростовская область, Красносулинский район, хутор Молаканский, Придорожная, 1/1	f	small
70035	77393	2236	Ростовская область, Красносулинский район, хутор Михайловка, Ленина, 18	f	large
114759	77477	2315	Ростовская область, Красносулинский район, хутор Марс, Первомайская, 37-а	f	medium
114765	77485	2323	Ростовская область, Красносулинский район, хутор Малая Гнилуша, 1	f	small
70091	77472	2311	Ростовская область, Красносулинский район, хутор Лихой, Ленина, 65	f	large
70081	77454	2293	Ростовская область, Красносулинский район, Красный Сулин, инени Героя Советского Союза Алексеева А.И, 2	f	large
70072	77443	2283	Ростовская область, Красносулинский район, Красный Сулин, Шоссейная, 2а	f	large
70084	77457	2296	Ростовская область, Красносулинский район, Красный Сулин, Чкалова, 19	f	large
70083	77456	2295	Ростовская область, Красносулинский район, Красный Сулин, Чкалова, 13	f	large
70068	77438	2278	Ростовская область, Красносулинский район, Красный Сулин, Центральная, 10	f	large
70070	77440	2280	Ростовская область, Красносулинский район, Красный Сулин, Фондовый, 16	f	large
70069	77439	2279	Ростовская область, Красносулинский район, Красный Сулин, Строителей, 2	f	large
70077	77449	2289	Ростовская область, Красносулинский район, Красный Сулин, Свободы, 1а	f	large
70080	77453	2292	Ростовская область, Красносулинский район, Красный Сулин, Революционный, 1	f	large
70088	77462	2301	Ростовская область, Красносулинский район, Красный Сулин, Первомайская, 3	f	large
70073	77444	2284	Ростовская область, Красносулинский район, Красный Сулин, Московская, 25	f	large
114748	77460	2299	Ростовская область, Красносулинский район, Красный Сулин, Металлургов, 12-а	f	medium
70087	77461	2300	Ростовская область, Красносулинский район, Красный Сулин, Ленина, 8	f	large
70082	77455	2294	Ростовская область, Красносулинский район, Красный Сулин, Культуры, 1	f	large
70075	77446	2286	Ростовская область, Красносулинский район, Красный Сулин, Кронштадтская, 5	f	large
70085	77458	2297	Ростовская область, Красносулинский район, Красный Сулин, Краснопартизанская, 69	f	large
70086	77459	2298	Ростовская область, Красносулинский район, Красный Сулин, Интернациональная, 13	f	large
70079	77452	2291	Ростовская область, Красносулинский район, Красный Сулин, Гагарина, 153	f	large
70078	77451	2290	Ростовская область, Красносулинский район, Красный Сулин, Гагарина, 59	f	large
70074	77445	2285	Ростовская область, Красносулинский район, Красный Сулин, Вокзальная, 68	f	large
114746	77442	2282	Ростовская область, Красносулинский район, Красный Сулин, Вербенская, 60	f	medium
70071	77441	2281	Ростовская область, Красносулинский район, Красный Сулин, Вербенская, 217а	f	large
114769	77489	2327	Ростовская область, Красносулинский район, хутор Коминтерн, Щербатых, 31	f	small
114768	77488	2326	Ростовская область, Красносулинский район, село Киселево, Мичурина, 3	f	medium
114771	77493	2330	Ростовская область, Красносулинский район, хутор Зайцевка, Советская, 12	f	small
114985	77492	2329	Ростовская область, Красносулинский район, хутор Дудкино, Набережная, 1-А	f	small
114756	77473	2312	Ростовская область, Красносулинский район, хутор Долотинка, Малиновского, 2	f	small
114758	77476	2314	Ростовская область, Красносулинский район, хутор Гуково, Краснопартизанская, 1	f	medium
114772	77495	2332	Ростовская область, Красносулинский район, хутор Гривенный, Победы, 19	f	small
70076	77447	2287	Ростовская область, Красносулинский район, ПГТ Горный, Соцтруда, 1а	f	large
114753	77468	2307	Ростовская область, Красносулинский район, станица Владимировская, Ленина, 20	f	medium
114752	77467	2306	Ростовская область, Красносулинский район, хутор Большая Федоровка, Октябрьская, 22	f	medium
113907	75496	258	Ростовская область, Константиновский район, хутор Хрящевский, Сельский дом культуры	t	small
114853	77657	2503	Ростовская область, Константиновский район, поселок Холмистый, Западная, 3	f	small
113914	75504	265	Ростовская область, Константиновский район, хутор Упраздно-Кагальницкий, Спортивная, 6	f	small
114849	77653	2499	Ростовская область, Константиновский район, хутор Трофимов, Степная, 26	f	small
114852	77656	2502	Ростовская область, Константиновский район, хутор Суворов, Центральная, 30	f	small
113920	75512	273	Ростовская область, Константиновский район, поселок Стычновский, Центральная, 3	f	small
114100	75860	638	Ростовская область, Константиновский район, поселок Старая Станица, Школьная, 2	f	small
113919	75511	272	Ростовская область, Константиновский район, хутор Савельев, Фестивальная, 13	f	small
114851	77655	2501	Ростовская область, Константиновский район, хутор Правда, Центральная, 13	f	small
113909	75498	260	Ростовская область, Константиновский район, хутор Почтовый, Центральная, 3	f	small
114059	75793	571	Ростовская область, Константиновский район, хутор Новая Жизнь, Сельский дом культуры	f	small
68930	75506	267	Ростовская область, Константиновский район, станица Николаевская, Центральная, 28	f	large
68929	75505	266	Ростовская область, Константиновский район, станица Николаевская, Центральная, 23	f	large
113910	75499	261	Ростовская область, Константиновский район, хутор Нижнекалинов, Набережная, 20	t	small
113905	75494	256	Ростовская область, Константиновский район, хутор Нижнежуравский, Мира, 15	f	small
113908	75497	259	Ростовская область, Константиновский район, хутор Михайловский, Березовая, 22	f	small
113915	75507	268	Ростовская область, Константиновский район, станица Мариинская, Зеленая, 5	f	medium
113917	75509	270	Ростовская область, Константиновский район, хутор Лисичкин, Центральная, 13	t	small
113911	75500	262	Ростовская область, Константиновский район, хутор Крюков, пер. Клубный, 2	f	small
114850	77654	2500	Ростовская область, Константиновский район, хутор Кременской, Московская, 8	f	small
113906	75495	257	Ростовская область, Константиновский район, хутор Костино-Горский, Казачья, 2	t	small
87077	75484	248	Ростовская область, Константиновский район, Константиновск, 12	f	large
87078	75491	253	Ростовская область, Константиновский район, Константиновск, Рылеева, 59	f	large
68922	75485	249	Ростовская область, Константиновский район, Константиновск, Комсомольская, 61	f	large
68925	75488	252	Ростовская область, Константиновский район, Константиновск, Калинина, 93	f	large
68923	75486	250	Ростовская область, Константиновский район, Константиновск, 25 Октября, 52	f	large
114825	77611	2445	Ростовская область, Константиновский район, хутор Кастырский, Центральная, 10	f	small
113913	75502	264	Ростовская область, Константиновский район, хутор Камышный, Центральная, 40	t	small
114941	75513	274	Ростовская область, Константиновский район, хутор Ермилов, Степная, 58	f	small
113916	75508	269	Ростовская область, Константиновский район, хутор Гапкин, Центральная, 42	f	medium
113922	75515	275	Ростовская область, Константиновский район, хутор Вифлянцев, Октябрьская, 13	f	small
114847	77650	2496	Ростовская область, Константиновский район, хутор Верхнепотапов, Береговая, 1	f	small
68928	75493	255	Ростовская область, Константиновский район, хутор Ведерников, Лесная, 37	f	large
113912	75501	263	Ростовская область, Константиновский район, станица Богоявленская, Парковая, 2	f	medium
113918	75510	271	Ростовская область, Константиновский район, хутор Белянский, Широкая, 22	f	small
114854	77658	2504	Ростовская область, Константиновский район, поселок Белоковыльный, Лазоревая, 16	f	small
114848	77651	2497	Ростовская область, Константиновский район, хутор Базки, Пушкина, 11	f	small
114846	77649	2495	Ростовская область, Константиновский район, хутор Авилов, Молодежная, 17	f	small
114328	76268	1041	Ростовская область, Кашарский район, село Шалаевка, Заречная, 1	f	small
114339	76282	1053	Ростовская область, Кашарский район, хутор Чернигово-Песчаный, Молодежная, 2	f	small
114332	76272	1045	Ростовская область, Кашарский район, село Усть-Мечетка, Центральная, 7	f	small
114348	76292	1062	Ростовская область, Кашарский район, хутор Третий Интернационал, Заветная, 1	f	small
114345	76289	1059	Ростовская область, Кашарский район, поселок Теплые Ключи, Школьная, 22	f	small
114333	76273	1046	Ростовская область, Кашарский район, хутор Талловеров, Центральная, 46	f	medium
114968	76276	1049	Ростовская область, Кашарский район, хутор Сергеевка, Сергеевская, 1	f	small
114337	76278	1050	Ростовская область, Кашарский район, село Сариновка, Школьная, 17	f	small
114969	76285	1055	Россия, Ростовская область, Кашарский район, село Россошь	f	medium
114322	76262	1035	Ростовская область, Кашарский район, хутор Речка, Тихомировская, 29	t	small
114326	76266	1039	Ростовская область, Кашарский район, слобода Поповка, Большая Садовая, 46	f	medium
114346	76290	1060	Ростовская область, Кашарский район, хутор Пономарев, Центральная, 7	f	medium
69262	76280	1051	Ростовская область, Кашарский район, село Первомайское, Мира, 9	f	large
114324	76264	1037	Ростовская область, Кашарский район, хутор Ольховый, Лесная, 126 А	f	small
83922	57341	3117	Москва, Зеленоград, к603а	f	large
114321	76261	1034	Ростовская область, Кашарский район, хутор Новочигириновский, Набережная, 54	f	small
114317	76257	1030	Ростовская область, Кашарский район, село Новопавловка, Октябрьская, 37	f	medium
114330	76270	1043	Ростовская область, Кашарский район, хутор Нижний Астахов, пер. Школьный, 2	f	small
114338	76281	1052	Ростовская область, Кашарский район, хутор Михайловка, Юбилейная, 28	f	small
114318	76258	1031	Ростовская область, Кашарский район, село Лысогорка, Школьная, 34	t	small
114335	76275	1048	Ростовская область, Кашарский район, хутор Ленинский, Песчаная, 1 А	f	small
114347	76291	1061	Ростовская область, Кашарский район, поселок Красный Колос, Пушкинская, 12	f	small
114342	76286	1056	Ростовская область, Кашарский район, хутор Краснояровка, Центральная, 31	f	small
87056	76254	1027	Ростовская область, Кашарский район, слобода Кашары, Ленина, 62	f	large
69259	76252	1026	Ростовская область, Кашарский район, слобода Кашары, Комсомольская, 43	f	large
69261	76255	1028	Ростовская область, Кашарский район, слобода Кашары, Андреевская, 42	f	large
114316	76256	1029	Ростовская область, Кашарский район, слобода Кашары, Адмиральская, 44	f	medium
114327	76267	1040	Ростовская область, Кашарский район, село Каменка, Центральная, 15 В	f	medium
114343	76287	1057	Ростовская область, Кашарский район, хутор Калашников, Подтелковская, 1	f	small
114340	76283	1054	Ростовская область, Кашарский район, поселок Индустриальный, Советская, 9	f	medium
114325	76265	1038	Ростовская область, Кашарский район, поселок Дибровый, Центральная, 12	f	medium
114323	76263	1036	Ростовская область, Кашарский район, хутор Вяжа, Центральная, 6	f	medium
114331	76271	1044	Ростовская область, Кашарский район, хутор Второй Киевский, Победы, 1	f	small
114334	76274	1047	Ростовская область, Кашарский район, хутор Вишневка, Молодежная, 8	f	small
114344	76288	1058	Ростовская область, Кашарский район, село Верхнесвечниково, Ленина, 18	f	medium
114320	76260	1033	Ростовская область, Кашарский район, слобода Верхнемакеевка, Октябрьская, 26	f	medium
114319	76259	1032	Ростовская область, Кашарский район, село Верхнекалиновка, Центральная, 55	f	small
114329	76269	1042	Ростовская область, Кашарский район, село Верхнегреково, Береговая, 5	f	small
114287	76171	980	Ростовская область, Каменский район, станция Репная, Железнодорожная, 14-А	f	small
69245	76208	979	Ростовская область, Каменский район, поселок Чистоозерный, Ленина, 23	f	large
114303	76231	1006	Ростовская область, Каменский район, хутор Филиппенков, Набережная, 45	f	small
114967	76242	1016	Ростовская область, Каменский район, хутор Урывский, Российская, 48	f	medium
114313	76249	1022	Ростовская область, Каменский район, хутор Уляшкин, Лесная, 35	t	small
69258	76246	1019	Ростовская область, Каменский район, хутор Старая Станица, Садовая, 52	f	large
69257	76245	1018	Ростовская область, Каменский район, хутор Старая Станица, Театральная, 65	f	large
114309	76241	1015	Ростовская область, Каменский район, хутор Сибилев, Степная, 1	f	small
114293	76214	987	Ростовская область, Каменский район, хутор Светлый, Центральная, 93	f	small
114297	76223	996	Ростовская область, Каменский район, хутор Самбуров, Колхозная, 3	f	medium
114288	76209	981	Ростовская область, Каменский район, поселок Разъезд Северный Донец, Народная, 1	f	small
114301	76227	1000	Ростовская область, Каменский район, хутор Плешаков, Московская, 20	f	medium
114308	76238	1013	Ростовская область, Каменский район, хутор Нижнеясиновский, Платова, 35	f	small
114300	76226	999	Ростовская область, Каменский район, хутор Нижнеерохин, Молодежная, 3	t	small
114289	76210	982	Ростовская область, Каменский район, хутор Нижнеговейный, Щаденко, 14	f	small
114286	76207	978	Ростовская область, Каменский район, поселок Молодежный, Достоевского, 12	f	small
114304	76234	1009	Ростовская область, Каменский район, хутор Михайловка, Донская, 16А	f	small
69253	76232	1007	Ростовская область, Каменский район, хутор Масаловка, Советская, 62	f	large
69254	76233	1008	Ростовская область, Каменский район, хутор Малая Каменка, Карла Маркса площадь, 23-Б	f	large
114311	76247	1020	Ростовская область, Каменский район, хутор Лесной, Королева, 10	f	medium
114302	76230	1005	Ростовская область, Каменский район, Красновка, Профильная, 15	t	medium
69252	76229	1004	Ростовская область, Каменский район, хутор Красновка, Октябрьская, 146-Б	t	large
114294	76218	991	Ростовская область, Каменский район, хутор Красновка, Матросова, 2	t	medium
114315	76251	1025	Ростовская область, Каменский район, хутор Кочетовка, Победы, 1	f	small
114295	76221	994	Ростовская область, Каменский район, поселок Каменногорье, Спортивная, 41	f	medium
69251	76228	1002	Ростовская область, Каменский район, станица Калитвенская, Калинина, 13	f	large
114312	76248	1021	Ростовская область, Каменский район, хутор Диченский, Левитана переулок, 48-А	f	small
114296	76222	995	Ростовская область, Каменский район, хутор Данилов, Школьный, 2	f	small
114299	76225	998	Ростовская область, Каменский район, хутор Гусев, Центральная, 21	f	medium
114298	76224	997	Ростовская область, Каменский район, хутор Груцинов, Школьная, 3	f	medium
69249	76219	992	Ростовская область, Каменский район, ПГТ Глубокий, Юбилейная, 8/4	f	large
69250	76220	993	Ростовская область, Каменский район, ПГТ Глубокий, Фрунзе, 86	f	large
69247	76216	989	Ростовская область, Каменский район, Глубокий, Ленина, 32	f	large
69246	76215	988	Ростовская область, Каменский район, ПГТ Глубокий, К.Маркса, 50	f	large
69248	76217	990	Ростовская область, Каменский район, ПГТ Глубокий, Вокзальная, 212	f	large
114290	76211	983	Ростовская область, Каменский район, хутор Волченский, Молодежная, 52	f	medium
114305	76235	1010	Ростовская область, Каменский район, хутор Вишневецкий, Набережная, 1	f	medium
69255	76239	1014	Ростовская область, Каменский район, хутор Верхний Пиховкин, Центральная, 31	f	large
114314	76250	1023	Ростовская область, Каменский район, хутор Верхние Грачики, Молодежная, 22	f	small
114306	76236	1011	Ростовская область, Каменский район, хутор Верхнеясиновский, Центральная, 19	f	small
114307	76237	1012	Ростовская область, Каменский район, поселок Васильевский, Школьная, 8	f	small
114291	76212	984	Ростовская область, Каменский район, хутор Белгородцев, Станичная, 78	f	small
114823	77608	2442	Ростовская область, Каменский район, хутор Астахов, Советская, 44а	f	small
114292	76213	985	Ростовская область, Каменский район, хутор Аникин, Мира, 122	f	small
114824	77609	2443	Ростовская область, Каменский район, хутор Абрамовка, Набережная, 1	f	small
114719	77298	2119	Ростовская область, Кагальницкий район, станица Хомутовская, Школьная, 13	f	medium
114714	77288	2109	Ростовская область, Кагальницкий район, хутор Середин, Солнечная, 60	f	small
114711	77284	2105	Ростовская область, Кагальницкий район, поселок Светлый Яр, Парковая, 1Б	f	small
114725	77304	2125	Ростовская область, Кагальницкий район, хутор Родники, Школьная, 25	f	small
114722	77301	2122	Ростовская область, Кагальницкий район, хутор Раково-Таврический, Школьная, 20	f	small
114720	77299	2120	Ростовская область, Кагальницкий район, хутор Первомайский, Степная, 59	t	small
114717	77294	2115	Ростовская область, Кагальницкий район, поселок Новоракитный, Климова, 34	f	small
114893	77722	2576	Ростовская область, Кагальницкий район, поселок Новонатальин, Садовая, 5	f	small
70194	77671	2516	Ростовская область, Кагальницкий район, село Новобатайск, Ленина, 20	f	large
114715	77290	2111	Ростовская область, Кагальницкий район, село Новобатайск, Ленина, 64	f	medium
69931	77289	2110	Ростовская область, Кагальницкий район, село Новобатайск, Ленина, 55	f	large
114857	77672	2517	Ростовская область, Кагальницкий район, село Новобатайск, Красная, 31	f	medium
114894	77723	2577	Ростовская область, Кагальницкий район, хутор Николаевский, Луговая, 127	f	medium
69935	77296	2117	Ростовская область, Кагальницкий район, поселок Мокрый Батай, 40 Лет Победы, 36	f	large
114895	77724	2578	Ростовская область, Кагальницкий район, поселок Малодубравный, Светлая, 13/2	f	small
114707	77280	2101	Ростовская область, Кагальницкий район, поселок Малиновка, Юбилейная, 13	f	small
114726	77305	2126	Ростовская область, Кагальницкий район, хутор Красный Яр, Пионерская, 7	f	small
114710	77283	2104	Ростовская область, Кагальницкий район, поселок Ключевой, Школьная, 23	f	small
114833	77623	2459	Ростовская область, Кагальницкий район, станица Кировская, Школьная, 30	f	medium
69934	77295	2116	Ростовская область, Кагальницкий район, станица Кировская, Школьная, 49	f	large
69933	77292	2113	Ростовская область, Кагальницкий район, станица Кировская, Московская, 37	f	large
114832	77622	2458	Ростовская область, Кагальницкий район, станица Кировская, Ленина, 62	f	medium
69932	77291	2112	Ростовская область, Кагальницкий район, станица Кировская, Гагарина, 110	f	large
114724	77303	2124	Ростовская область, Кагальницкий район, хутор Камышеваха, Казачья, 30	f	small
114708	77281	2102	Ростовская область, Кагальницкий район, хутор Кагальничек, Трудовая, 23	f	small
114705	77278	2099	Ростовская область, Кагальницкий район, станица Кагальницкая, пер. Комсомольский, 1А	f	medium
114706	77279	2100	Ростовская область, Кагальницкий район, станица Кагальницкая, Привокзальная, 1	f	medium
114703	77275	2096	Ростовская область, Кагальницкий район, станица Кагальницкая, Почтовая, 101	f	medium
69929	77276	2097	Ростовская область, Кагальницкий район, станица Кагальницкая, Кольцовский переулок, 57	f	large
69928	77274	2095	Ростовская область, Кагальницкий район, станица Кагальницкая, Калинина, 105	f	large
114704	77277	2098	Ростовская область, Кагальницкий район, станица Кагальницкая, Горького, 34	f	medium
114713	77286	2107	Ростовская область, Кагальницкий район, село Иваново-Шамшево, Красноармейская, 36	f	small
114721	77300	2121	Ростовская область, Кагальницкий район, хутор Зеленая Роща, Школьная, 14	f	small
114723	77302	2123	Ростовская область, Кагальницкий район, хутор Жуково-Татарский, Ленина, 16А	f	medium
114709	77282	2103	Ростовская область, Кагальницкий район, поселок Двуречье, Советская, 30	f	medium
114712	77285	2106	Ростовская область, Кагальницкий район, поселок Двуречье, Первомайская, 37	f	medium
114896	77725	2579	Ростовская область, Кагальницкий район, поселок Глубокий Яр, Кленовая, 10 В	f	small
114718	77297	2118	Ростовская область, Кагальницкий район, поселок Воронцовка, Школьная, 1А	f	medium
69930	77287	2108	Ростовская область, Кагальницкий район, село Васильево-Шамшево, Жукова, 17	f	large
114716	77293	2114	Ростовская область, Кагальницкий район, поселок Березовая Роща, Бирюкова, 8	f	small
114072	75811	588	Ростовская область, Зимовниковский район, хутор Хуторской, Стадионная, 7	f	medium
114067	75804	581	Ростовская область, Зимовниковский район, хутор Харьковский, Клубный переулок, 5	f	small
114948	75817	593	Ростовская область, Зимовниковский район, хутор Савоськин, Кирова, 59	f	medium
114074	75814	591	Ростовская область, Зимовниковский район, хутор Погорелов, Зелёный, 2	f	small
114070	75809	586	Ростовская область, Зимовниковский район, хутор Плотников, Мира, 22	f	medium
114061	75795	573	Ростовская область, Зимовниковский район, хутор Нариманов, Школьная, 17	f	small
114075	75815	592	Ростовская область, Зимовниковский район, поселок Мокрый Гашун, Центральная, 64	f	medium
114063	75798	575	Ростовская область, Зимовниковский район, хутор Марченков, Победы, 20 Б	f	small
114947	75801	577	Ростовская область, Зимовниковский район, хутор Майкопский, Центральный, 18	f	small
114946	75796	574	Ростовская область, Зимовниковский район, хутор Ленинский, Мира, 38	f	small
114060	75794	572	Ростовская область, Зимовниковский район, поселок Лагунный, Макарчука, 58	f	small
69088	75802	578	Ростовская область, Зимовниковский район, станица Кутейниковская, Школьный, 32	f	large
114073	75812	589	Ростовская область, Зимовниковский район, поселок Красностепной, Школьная, 9 В	f	medium
69091	75813	590	Ростовская область, Зимовниковский район, хутор Камышев, Мира, 16	f	large
114064	75799	576	Ростовская область, Зимовниковский район, хутор Ильичев, Лодянова, 19 Б	f	small
69085	75790	567	Ростовская область, Зимовниковский район, поселок Зимовники, Сиреневая, 92	f	large
69084	75789	566	Ростовская область, Зимовниковский район, поселок Зимовники, Пушкина, 8	f	large
69086	75791	568	Ростовская область, Зимовниковский район, поселок Зимовники, Малый, 2	f	large
114066	75803	579	Ростовская область, Зимовниковский район, поселок Зимовники, Магистральная, 23	f	medium
69080	75785	562	Ростовская область, Зимовниковский район, поселок Зимовники, Круглякова, 120	f	large
69083	75788	565	Ростовская область, Зимовниковский район, поселок Зимовники, Игнатовский, 85	f	large
69087	75792	569	Ростовская область, Зимовниковский район, поселок Зимовники, Дружбы, 135	f	large
69082	75787	564	Ростовская область, Зимовниковский район, поселок Зимовники, Дзержинского, 206	f	large
69081	75786	563	Ростовская область, Зимовниковский район, поселок Зимовники, Дзержинского, 179	f	large
21473	46285	4350	Краснодарский край, Сочи, Форелевая, 45	f	medium
114071	75810	587	Ростовская область, Зимовниковский район, хутор Глубокий, Садовая, 23	f	medium
69090	75807	584	Ростовская область, Зимовниковский район, хутор Гашун, Деревенского, 2	f	large
114068	75806	583	Ростовская область, Зимовниковский район, хутор Верхоломов, Школьная, 1 В	f	small
69089	75805	582	Ростовская область, Зимовниковский район, слобода Верхнесеребряковка, Мира, 12	f	large
114069	75808	585	Ростовская область, Зимовниковский район, поселок Байков, Парковая, 15	f	medium
113898	75458	226	Ростовская область, Зерноградский район, поселок Экспериментальный, Шоссейная, 6	f	medium
113900	75460	228	Ростовская область, Зерноградский район, поселок Шоссейный, Пугачева, 12	f	small
68902	75435	204	Ростовская область, Зерноградский район, хутор Чернышевка, Центральная, 14	f	large
113891	75448	217	Ростовская область, Зерноградский район, хутор Средние Хороли, Заречная, 9	f	small
68904	75451	220	Ростовская область, Зерноградский район, поселок Сорговый, Центральная, 9	f	large
113882	75438	207	Ростовская область, Зерноградский район, село Светлоречное, Специалистов, 23	f	medium
113872	75427	194	Ростовская область, Зерноградский район, хутор Революционный, Магистральная, 96	f	small
113903	75477	242	Ростовская область, Зерноградский район, хутор Ракитный, Заречная, 61	f	small
68905	75452	221	Ростовская область, Зерноградский район, хутор Путь Правды, Ленина, 85/5	f	large
113899	75459	227	Ростовская область, Зерноградский район, поселок Прудовой, Платова, 1	f	small
113887	75444	213	Ростовская область, Зерноградский район, хутор Попов, 40 лет Победы, 89 В	f	small
113884	75441	210	Ростовская область, Зерноградский район, хутор Пишванов, Мира площадь, 27а	f	small
113889	75446	215	Ростовская область, Зерноградский район, поселок Осокино, Майская, 11	f	small
113865	75410	178	Ростовская область, Зерноградский район, поселок Новые Постройки, пер. Казачий, 37	f	small
113883	75439	208	Ростовская область, Зерноградский район, село Новокузнецовка, Специалистов, 32	f	small
113874	75360	196	Ростовская область, Зерноградский район, село Новоивановка, Школьная, 24	f	small
113876	75431	199	Ростовская область, Зерноградский район, хутор Новая Поляна, Бородинская, 35	f	small
113875	75429	197	Ростовская область, Зерноградский район, поселок Нижнекугоейский, Мира, 20	f	small
68897	75420	187	Ростовская область, Зерноградский район, станица Мечетинская, Токарева, 93	f	large
68900	75423	190	Ростовская область, Зерноградский район, станица Мечетинская, Победы, 35	f	large
68899	75422	189	Ростовская область, Зерноградский район, станица Мечетинская, Ленина, 23	f	large
68898	75421	188	Ростовская область, Зерноградский район, станица Мечетинская, Ленина, 68	f	large
113888	75445	214	Ростовская область, Зерноградский район, поселок Междупольный, Ростовская, 41	f	small
113890	75447	216	Ростовская область, Зерноградский район, поселок Малый Лог, Молодежная, 25	f	small
113880	75436	205	Ростовская область, Зерноградский район, поселок Лободин, Майская, 14	f	small
113873	75428	195	Ростовская область, Зерноградский район, село Ленинка, Парковая, 3	f	small
113894	75453	222	Ростовская область, Зерноградский район, хутор Краснюков, Молодежная, 42/4	f	small
113885	75442	211	Ростовская область, Зерноградский район, хутор Красноармейский, Заречная, 16А	f	small
114940	75455	224	Ростовская область, Зерноградский район, поселок Комсомольский, Тургенева, 16	f	medium
113879	75434	203	Ростовская область, Зерноградский район, Клюев, Садовая, 10	f	medium
113897	75457	225	Ростовская область, Зерноградский район, поселок Кленовый, Куйбышева, 11а	f	medium
68918	75479	244	Ростовская область, Зерноградский район, Зерноград, Шукшина, 14	f	large
114889	77718	2572	Ростовская область, Зерноградский район, Зерноград, Специалистов, 57	f	medium
87075	75462	230	Ростовская область, Зерноградский район, Зерноград, Социалистическая, 35/42	f	large
68913	75471	237	Ростовская область, Зерноградский район, Зерноград, Советская, 28	f	large
68916	75476	241	Ростовская область, Зерноградский район, Зерноград, Научный Городок, 3	f	large
68915	75473	239	Ростовская область, Зерноградский район, Зерноград, Мира, 22	f	large
68909	75467	233	Ростовская область, Зерноградский район, Зерноград, Мира, 8	f	large
68914	75472	238	Ростовская область, Зерноградский район, Зерноград, Ленина, 17	f	large
113901	75461	229	Ростовская область, Зерноградский район, поселок Зерновой, Разина, 7	f	small
113881	75437	206	Ростовская область, Зерноградский район, хутор Заполосный, Степная, 20	f	medium
114887	77715	2569	Ростовская область, Зерноградский район, поселок Займище, Школьная, 4	f	small
68903	75440	209	Ростовская область, Зерноградский район, хутор Донской, Цветной Бульвар, 29	f	large
68901	75430	198	Ростовская область, Зерноградский район, хутор Гуляй-Борисовка, 50 лет ВЛКСМ, 8/63	f	large
113895	75454	223	Ростовская область, Зерноградский район, хутор Голубовка, Школьная, 5/3	f	small
113892	75449	218	Ростовская область, Зерноградский район, хутор Верхние Хороли, Школьная, 28	f	small
113893	75450	219	Ростовская область, Зерноградский район, хутор Булочкин, Центральная, 63	f	small
113877	75432	200	Ростовская область, Зерноградский район, хутор Большие Эльбуздовские, Родниковая, 2А	f	small
113886	75443	212	Ростовская область, Зерноградский район, хутор Большая Таловая, Ленина, 4А	f	medium
113878	75433	201	Ростовская область, Зерноградский район, хутор Болдиновка, Звездная, 30	f	small
113871	75426	193	Ростовская область, Зерноградский район, хутор 2-й Россошинский, Мира, 27	f	small
113869	75424	191	Ростовская область, Зерноградский район, хутор 1-й Россошинский, Садовая, 5	f	small
113870	75425	192	Ростовская область, Зерноградский район, хутор 1-й Россошинский, Заречная, 92	f	medium
114053	75779	556	Ростовская область, Заветинский район, хутор Шебалин, Гагарина, 1	f	medium
114055	75781	558	Ростовская область, Заветинский район, хутор Фомин, Центральная, 9	f	medium
114058	75784	561	Ростовская область, Заветинский район, село Федосеевка, Центральная, 11А	f	medium
114057	75783	560	Ростовская область, Заветинский район, село Тюльпаны, Школьная, 16А	f	medium
114056	75782	559	Ростовская область, Заветинский район, хутор Савдя, Центральная, 11	f	medium
114821	77604	2438	Ростовская область, Заветинский район, хутор Новобеляевский, Зеленая, 16/2	f	small
114822	77605	2439	Ростовская область, Заветинский район, хутор Никольский, Школьная, 22А	f	small
114054	75780	557	Ростовская область, Заветинский район, хутор Никольский, Школьная, 10А	f	small
114051	75777	554	Ростовская область, Заветинский район, село Кичкино, Школьная, 15А	f	medium
114052	75778	555	Ростовская область, Заветинский район, село Киселевка, Новый, 6	f	medium
69078	75775	552	Ростовская область, Заветинский район, село Заветное, Ломоносова, 39	f	large
69079	75776	553	Ростовская область, Заветинский район, село Заветное, Горького, 52	f	large
114820	77603	2437	Ростовская область, Заветинский район, хутор Андреев, Центральная, 14А	f	small
68893	75413	181	Ростовская область, Егорлыкский район, хутор Шаумяновский, Шаумяна, 21	f	large
113862	75403	172	Ростовская область, Егорлыкский район, хутор Украинский, пер. Школьный, 6	t	small
114939	75404	173	Ростовская область, Егорлыкский район, хутор Таганрогский, Специалистов, 23	f	medium
113859	75392	164	Ростовская область, Егорлыкский район, хутор Тавричанка, Мира, 30а	t	small
68896	75417	184	Ростовская область, Егорлыкский район, поселок Роговский, пер. Победы, 10	f	large
68890	75407	175	Ростовская область, Егорлыкский район, хутор Объединенный, Зеленая, 25	f	large
87074	75415	183	Ростовская область, Егорлыкский район, станица Новороговская, Школьная, 50	f	large
68892	75411	179	Ростовская область, Егорлыкский район, хутор Мирный, Почтовая, 1г	f	large
68891	75409	177	Ростовская область, Егорлыкский район, хутор Кугейский, Октябрьская, 31	f	large
68894	75414	182	Ростовская область, Егорлыкский район, хутор Кавалерский, Ленина, 33	f	large
113864	75408	176	Ростовская область, Егорлыкский район, хутор Ильинский, Парковая, 3/1	t	small
113860	75400	170	Ростовская область, Егорлыкский район, хутор Изобильный, Ростовская, 12	f	medium
87072	75396	167	Ростовская область, Егорлыкский район, станица Егорлыкская, переулок Тергенева, 129	f	large
68889	75406	174	Ростовская область, Егорлыкский район, станица Егорлыкская, переулок Первомайский, 57	f	large
68882	75389	162	Ростовская область, Егорлыкский район, станица Егорлыкская, переулок Первомайский, 1	f	large
68884	75393	165	Ростовская область, Егорлыкский район, станица Егорлыкская, Ростовская, 117	f	large
68887	75397	168	Ростовская область, Егорлыкский район, станица Егорлыкская, Мичурина, 5	f	large
87073	75398	169	Ростовская область, Егорлыкский район, станица Егорлыкская, Малькова, 5	f	large
68883	75391	163	Ростовская область, Егорлыкский район, станица Егорлыкская, Ленина, 62	f	large
68881	75388	161	Ростовская область, Егорлыкский район, станица Егорлыкская, Ленина, 1	f	large
68885	75394	166	Ростовская область, Егорлыкский район, станица Егорлыкская, Грицика, 119	f	large
114938	75401	171	Ростовская область, Егорлыкский район, хутор Войнов, Садовая, 32	f	medium
113866	75412	180	Ростовская область, Егорлыкский район, хутор Балко-Грузский, Школьная, 8	f	medium
114047	75771	548	Ростовская область, Дубовский район, станица Эркетиновская, Молодежная, 13	f	small
114039	75762	539	Ростовская область, Дубовский район, хутор Щеглов, Садовая, 37	f	medium
114044	75768	545	Ростовская область, Дубовский район, хутор Семичный, Ленина, 14	f	medium
114037	75760	537	Ростовская область, Дубовский район, хутор Романов, Молодежная, 24	f	medium
114049	75773	550	Ростовская область, Дубовский район, хутор Присальский, Центральная, 7	f	medium
114041	75764	541	Ростовская область, Дубовский район, станица Подгоренская, пер. Солнечный, 18	t	small
114036	75759	536	Ростовская область, Дубовский район, хутор Новогашунский, Центральная, 74	f	small
114050	75774	551	Ростовская область, Дубовский район, хутор Мирный, Центральная, 7	f	small
114042	75766	543	Ростовская область, Дубовский район, станица Малая Лучка, Приморская, 12	f	small
114048	75772	549	Ростовская область, Дубовский район, хутор Лесной, Лесная, 15 	f	medium
69077	75765	542	Ростовская область, Дубовский район, станица Жуковская, Центральная площадь, 1	f	large
114038	75761	538	Ростовская область, Дубовский район, хутор Ериковский, Школьный, 18	f	medium
69075	75756	533	Ростовская область, Дубовский район, село Дубовское, пл. Павших Борцов 2, 2	f	large
69076	75757	534	Ростовская область, Дубовский район, село Дубовское, переулок Герцена, 31	f	large
70151	77601	2435	Ростовская область, Дубовский район, село Дубовское, Первомайская, 38	f	large
70152	77602	2436	Ростовская область, Дубовский район, село Дубовское, Ленина, 73	f	large
114045	75769	546	Ростовская область, Дубовский район, хутор Гуреев, Школьная, 2	f	medium
114035	75758	535	Ростовская область, Дубовский район, хутор Веселый, Октябрьская, 45	f	medium
114040	75763	540	Ростовская область, Дубовский район, хутор Вербовый Лог, Административная, 1	f	medium
114046	75770	547	Ростовская область, Дубовский район, станица Андреевская, Центральная, 34	f	medium
114043	75767	544	Ростовская область, Дубовский район, хутор Алдабульский, Школьная, 1А	f	small
114018	75735	514	Ростовская область, Волгодонской район, хутор Ясырев, Победы, 24	f	medium
114017	75733	512	Ростовская область, Волгодонской район, хутор Холодный, Центральная, 30-а	f	small
114944	75742	521	Ростовская область, Волгодонской район, поселок Сухая Балка, Центральная, 17	f	small
114019	75736	515	Ростовская область, Волгодонской район, хутор Степной, Комсомольская, 14	f	small
114024	75741	520	Ростовская область, Волгодонской район, поселок Солнечный, Прудовая, 18	f	medium
114855	77667	2511	Ростовская область, Волгодонской район, поселок Сибирьковый, Надежды, 23	f	small
114033	75752	529	Ростовская область, Волгодонской район, хутор Семенкин, Центральная, 16	f	small
114026	75744	522	Ростовская область, Волгодонской район, поселок Саловский, Молодежная, 4	f	small
114021	75738	517	Ростовская область, Волгодонской район, поселок Савельевский, Степная, 4	f	small
114917	75734	2622	Ростовская область, Волгодонской район, хутор Рябичев, Театральная, 49	f	medium
69072	75734	513	Ростовская область, Волгодонской район, хутор Рябичев, Театральная, 49	f	large
87112	77663	2508	Ростовская область, Волгодонской район, станица Романовская, переулок Союзный, 44	f	large
70190	77666	2510	Ростовская область, Волгодонской район, станица Романовская, Юбилейная, 2	f	large
69074	75755	532	Ростовская область, Волгодонской район, станица Романовская, Тюхова, 90	f	large
70189	77665	2509	Ростовская область, Волгодонской район, станица Романовская, Мелиораторов, 8а	f	large
114027	75745	523	Ростовская область, Волгодонской район, поселок Прогресс, Ленина, 11	f	medium
70235	77762	2623	Ростовская область, Волгодонской район, хутор Потапов, Садовая, 67б	f	large
21562	46374	4508	Краснодарский край, Сочи, Учительская, 19	f	large
114020	75737	516	Ростовская область, Волгодонской район, хутор Потапов, Комсомольская, 45	f	medium
114034	75754	531	Ростовская область, Волгодонской район, хутор Погожев, Комсомольская, 1 - а	f	small
114029	75747	525	Ростовская область, Волгодонской район, поселок Победа, Кооперативная, 7	f	medium
114013	75729	508	Ростовская область, Волгодонской район, хутор Пирожок, Центральная, 11 - а	f	medium
114015	75731	510	Ростовская область, Волгодонской район, хутор Морозов, Школьная, 24	f	medium
114023	75740	519	Ростовская область, Волгодонской район, хутор Мокросоленый, Центральная, 27	f	small
114030	75748	526	Ростовская область, Волгодонской район, поселок Мичуринский, Ленина, 12	f	medium
69073	75753	530	Ростовская область, Волгодонской район, хутор Лагутники, переулок Юбилейный, 9а	f	large
114032	75751	528	Ростовская область, Волгодонской район, поселок Краснодонский, Мира, 18	f	medium
114022	75739	518	Ростовская область, Волгодонской район, хутор Калинин, Школьная, 7	f	small
114014	75730	509	Ростовская область, Волгодонской район, станица Дубенцовская, переулок Совхозный, 21	f	medium
114945	75749	527	Ростовская область, Волгодонской район, поселок Донской, Гайдара, 7	f	medium
114028	75746	524	Ростовская область, Волгодонской район, хутор Виноградный, Дружбы, 19, Прогрессовское сельское поселение	f	medium
114016	75732	511	Ростовская область, Волгодонской район, станица Большовская, Школьная, 37 - а	f	medium
114005	75721	500	Ростовская область, Веселовский район, поселок Чаканиха, Школьная, 15	f	medium
114002	75717	496	Ростовская область, Веселовский район, поселок Средний Маныч, Ленина, 4	f	medium
114007	75723	502	Ростовская область, Веселовский район, хутор Спорный, Центральная, 27	f	small
114000	75715	494	Ростовская область, Веселовский район, хутор Свобода, Производственная, 19/2	f	small
114006	75722	501	Ростовская область, Веселовский район, поселок Садковский, Механическая, 4	f	small
113996	75710	490	Ростовская область, Веселовский район, хутор Проциков, Верхняя, 35	f	small
113998	75712	492	Ростовская область, Веселовский район, хутор Позднеевка, Центральная, 22	f	medium
114003	75718	497	Ростовская область, Веселовский район, поселок Новый, Дружбы, 7	f	medium
114004	75720	499	Ростовская область, Веселовский район, хутор Нижнесоленый, Садовая, 27	f	medium
114008	75724	503	Ростовская область, Веселовский район, хутор Маныч-Балабинка, Солнечная, 23а	f	small
114943	75713	493	Ростовская область, Веселовский район, хутор Малая Западенка, 40-летия Победы проспект, 12/3	f	medium
114009	75725	504	Ростовская область, Веселовский район, хутор Ленинский, Вишневая, 51а	f	medium
114011	75727	506	Ростовская область, Веселовский район, хутор Красный Октябрь, Школьная, 59	f	medium
114012	75728	507	Ростовская область, Веселовский район, хутор Красный Маныч, Центральная, 128	f	medium
114001	75716	495	Ростовская область, Веселовский район, хутор Красный Кут, Школьная, 5а	f	small
114859	77674	2519	Ростовская область, Веселовский район, хутор Красное Знамя, Центральная, 24	f	medium
113995	75709	489	Ростовская область, Веселовский район, хутор Каракашев, Старая, 37	f	small
114010	75726	505	Ростовская область, Веселовский район, хутор Казачий, Школьная, 20	f	small
69070	75708	488	Ростовская область, Веселовский район, поселок Веселый, переулок Комсомольский, 50а	f	large
69067	75705	485	Ростовская область, Веселовский район, поселок Веселый, пер. Комсомольский, 50	f	large
69068	75706	486	Ростовская область, Веселовский район, поселок Веселый, Октябрьская, 190	f	large
69069	75707	487	Ростовская область, Веселовский район, поселок Веселый, Думенко, 185	f	large
113997	75711	491	Ростовская область, Веселовский район, хутор Верхний Хомутец, пер. Школьный, 6	f	small
69071	75719	498	Ростовская область, Веселовский район, хутор Верхнесоленый, Центральная, 61	f	large
114282	76203	973	Ростовская область, Верхнедонской район, станица Шумилинская, Ленина, 6	f	medium
114279	76199	970	Ростовская область, Верхнедонской район, хутор Тубянский, Тубянская, 21	f	small
114263	76180	950	Ростовская область, Верхнедонской район, поселок Суходольный, Клубная, 6	f	medium
114275	76195	965	Ростовская область, Верхнедонской район, хутор Суровский, Суровская, 26	f	small
114966	76202	972	Ростовская область, Верхнедонской район, хутор Стоговской, Стоговская, 45	f	small
114277	76197	968	Ростовская область, Верхнедонской район, хутор Солонцовский, Солонцовская, 123	f	small
114283	76204	974	Ростовская область, Верхнедонской район, хутор Свидовский, Свидовская, 3а	f	small
114273	76192	963	Ростовская область, Верхнедонской район, хутор Раскольный, Раскольная, 33	f	small
114270	76189	959	Ростовская область, Верхнедонской район, поселок Придонский, Придонская, 80	t	small
114260	76176	945	Ростовская область, Верхнедонской район, хутор Поповка, Петровского, 52	f	medium
114256	76168	939	Ростовская область, Верхнедонской район, хутор Поздняковский, Лесная, 31	f	small
114284	76205	976	Ростовская область, Верхнедонской район, хутор Песковатская Лопатина, Песковатсколопатинская, 120-А	f	small
114276	76196	966	Ростовская область, Верхнедонской район, хутор Парижский, Парижская, 70	f	small
114255	76167	938	Ростовская область, Верхнедонской район, хутор Павловский, Павловская, 76	f	small
114965	76193	964	Ростовская область, Верхнедонской район, хутор Новониколаевский, Центральная, 4	f	medium
114266	76183	954	Ростовская область, Верхнедонской район, хутор Нижнетиховский, Ермака, 9	f	small
114262	76179	949	Ростовская область, Верхнедонской район, хутор Назаровский, Назаровская, 54, кв.1	f	small
114264	76181	952	Ростовская область, Верхнедонской район, хутор Мрыховский, Мрыховская, 29-А	f	small
114252	76164	935	Ростовская область, Верхнедонской район, хутор Михайловский, Степная, 10	f	small
69244	76186	957	Ростовская область, Верхнедонской район, станица Мигулинская, Карла Маркса, 7	f	large
114265	76182	953	Ростовская область, Верхнедонской район, хутор Мещеряковский, Плешакова, 13а	f	medium
69243	76178	948	Ростовская область, Верхнедонской район, станица Мешковская, Победы, 2	f	large
114261	76177	946	Ростовская область, Верхнедонской район, хутор Меловатский, Меловатская, 40, кв.2	f	small
114251	76163	934	Ростовская область, Верхнедонской район, хутор Макаровский, Макаровская, 5	f	small
114259	76175	944	Ростовская область, Верхнедонской район, хутор Кукуевский, Школьная, 3	f	medium
114964	76188	958	Ростовская область, Верхнедонской район, хутор Коноваловский, Центральная, 28	f	small
114258	76174	943	Ростовская область, Верхнедонской район, хутор Колодезный, Колодезная, 105	f	small
113902	75475	240	Ростовская область, Верхнедонской район, хутор Каменный, Семиренко, 4	f	small
114963	76172	942	Ростовская область, Верхнедонской район, хутор Казанская Лопатина, Лопатинская, 165	f	small
69242	76170	941	Ростовская область, Верхнедонской район, станица Казанская, Матросова, 10	f	large
69241	76169	940	Ростовская область, Верхнедонской район, станица Казанская, Коммунальная, 13	f	large
114278	76198	969	Ростовская область, Верхнедонской район, хутор Заикинский, Заикинская, 126	f	small
114272	76191	962	Ростовская область, Верхнедонской район, хутор Дубровский, Дубровская, 80	f	small
114280	76200	971	Ростовская область, Верхнедонской район, хутор Гормиловский, Гормиловская, 37	f	small
114253	76165	936	Ростовская область, Верхнедонской район, хутор Верхняковский, Мира, 9	f	small
114254	76166	937	Ростовская область, Верхнедонской район, хутор Верхняковский, Административная, 6	f	medium
114271	76190	960	Ростовская область, Верхнедонской район, хутор Быковский, Быковская, 213	f	small
114267	76184	955	Ростовская область, Верхнедонской район, хутор Бирюковский, Бирюковская, 40	f	small
114268	76185	956	Ростовская область, Верхнедонской район, хутор Алексеевский, Центральная, 4кв.2	f	small
114240	76151	923	Ростовская область, Боковский район, поселок Яблоновский, Казачья, 3	f	small
114904	77736	2593	Ростовская область, Боковский район, хутор Свиридов, Луговая, 42	f	small
114245	76156	928	Ростовская область, Боковский район, хутор Попов, Школьная, 26	f	small
114237	76148	920	Ростовская область, Боковский район, село Пономаревка, Школьная, 28	f	small
114236	76147	919	Ростовская область, Боковский район, хутор Малаховский, Центральная, 24А	f	small
114247	76159	930	Ростовская область, Боковский район, хутор Лиховидовский, Школьная, 7	f	small
114242	76153	925	Ростовская область, Боковский район, хутор Латышев, Кривошлыкова, 36	f	small
114231	76139	912	Ростовская область, Боковский район, станица Краснокутская, Лазоревая, 13	f	small
114239	76150	922	Ростовская область, Боковский район, поселок Краснозоринский, Школьная, 1	f	small
114244	76155	927	Ростовская область, Боковский район, хутор Коньков, Коньковская, 34Б	f	small
114243	76154	926	Ростовская область, Боковский район, хутор Климовка, Школьная, 6	f	small
114888	77717	2571	Ростовская область, Боковский район, станица Каргинская, Советская, 35	f	medium
114241	76152	924	Ростовская область, Боковский район, станица Каргинская, Советская, 37	f	medium
114233	76141	914	Ростовская область, Боковский район, хутор Каменка, Песчаная, 77	f	small
114232	76140	913	Ростовская область, Боковский район, хутор Илларионов, Магрицкого, 25	f	small
114238	76149	921	Ростовская область, Боковский район, хутор Земцов, Школьная, 42	f	medium
114235	76144	916	Ростовская область, Боковский район, хутор Дуленков, Песчаная, 29В	f	small
114246	76157	929	Ростовская область, Боковский район, хутор Грушинский, Грушинская, 69	f	small
114248	76160	931	Ростовская область, Боковский район, хутор Грачев, Школьная, 35	f	medium
114906	77738	2595	Ростовская область, Боковский район, хутор Горбатов, Луговая, 15А	f	small
114250	76162	933	Ростовская область, Боковский район, хутор Верхнечирский, Мира, 56	f	small
114905	77737	2594	Ростовская область, Боковский район, село Вербовка, Кристальная, 47/2	f	small
114249	76161	932	Ростовская область, Боковский район, хутор Большенаполовский, Школьная, 73	f	small
69239	76145	917	Ростовская область, Боковский район, станица Боковская, Теличенко переулок, 27	f	large
69240	76146	918	Ростовская область, Боковский район, станица Боковская, Октябрьская, 20а	f	large
114234	76142	915	Ростовская область, Боковский район, хутор Белавин, Центральная, 17А	f	small
113843	75369	142	Ростовская область, Белокалитвинский район, хутор Поцелуев, Старцева, 57	f	medium
87060	75228	9	Ростовская область, Белокалитвинский район, Белая Калитва, Космонавтов, 3	f	large
113809	75245	25	Ростовская область, Белокалитвенский район, поселок Ясногорка, Строителей, 11	f	medium
68802	75260	39	Ростовская область, Белокалитвенский район, ПГТ Шолоховский, Пушкина, 32	t	large
87062	75263	41	Ростовская область, Белокалитвенский район, ПГТ Шолоховский, Октябрьская, 19	t	large
68801	75259	38	Ростовская область, Белокалитвенский район, ПГТ Шолоховский, Максима Горького, 1	t	large
70214	75261	2581	Ростовская область, Белокалитвенский район, ПГТ Шолоховский, Железнодорожная, 4	f	large
68803	75261	40	Ростовская область, Белокалитвенский район, ПГТ Шолоховский, Железнодорожная, 4	t	large
113854	75381	154	Ростовская область, Белокалитвенский район, хутор Чернышев, Центральная, 21	t	small
113857	75386	159	Ростовская область, Белокалитвенский район, хутор Чапаев, пер. Школьный, 2	f	medium
113815	75255	34	Ростовская область, Белокалитвенский район, хутор Усть-Быстрый, Верхняя, 65	f	small
113807	75240	20	Ростовская область, Белокалитвенский район, поселок Углекаменный, Бурденко, 1	f	medium
68878	75373	146	Ростовская область, Белокалитвенский район, поселок Сосны, Пролетарская, 1а	f	large
68792	75242	22	Ростовская область, Белокалитвенский район, поселок Синегорский, микрорайон Юбилейный, 23	t	large
68794	75244	24	Ростовская область, Белокалитвенский район, поселок Синегорский, Маяковского, 6	t	large
68793	75243	23	Ростовская область, Белокалитвенский район, поселок Синегорский, Горького, 15	t	large
113808	75241	21	Ростовская область, Белокалитвенский район, поселок Синегорский, Белинского, 3	f	medium
113810	75246	26	Ростовская область, Белокалитвенский район, поселок Русичи, Почтовая, 5	t	small
113842	75368	141	Ростовская область, Белокалитвенский район, хутор Рудаков, Школьная, 44	f	small
114891	77720	2574	Ростовская область, Белокалитвенский район, поселок Разъезд Васильевский, Вокзальная, 16	f	small
113845	75371	144	Ростовская область, Белокалитвенский район, хутор Погорелов, Ефремовой, 2	f	small
113849	75376	149	Ростовская область, Белокалитвенский район, хутор Нижнесеребряковский, Центральная, 25	t	small
113846	75372	145	Ростовская область, Белокалитвенский район, хутор Нижнепопов, Молодежная, 23	f	medium
113848	75375	148	Ростовская область, Белокалитвенский район, хутор Насонтов, Центральная, 57	f	small
113858	75387	160	Ростовская область, Белокалитвенский район, хутор Мечетный, Шляхтная, 22	t	small
114902	77734	2591	Ростовская область, Белокалитвенский район, поселок Мельничный, Береговая, 24	f	small
114937	75359	133	Ростовская область, Белокалитвенский район, хутор Марьевка, Центральная, 2	f	medium
68876	75366	139	Ростовская область, Белокалитвенский район, село Литвиновка, Школьная, 32	f	large
68877	75367	140	Ростовская область, Белокалитвенский район, хутор Ленина, Ленина, 112	f	large
113844	75370	143	Ростовская область, Белокалитвенский район, хутор Крутинский, Центральная, 40	f	medium
113851	75378	151	Ростовская область, Белокалитвенский район, станица Краснодонецкая, Центральная, 23	f	medium
113841	75365	138	Ростовская область, Белокалитвенский район, хутор Кононов, Центральная, 60	f	medium
68797	75251	30	Ростовская область, Белокалитвенский район, поселок Коксовый, Щаденко, 10	t	large
113814	75254	33	Ростовская область, Белокалитвенский район, поселок Коксовый, Чехов, 22	f	medium
113813	75253	32	Ростовская область, Белокалитвенский район, поселок Коксовый, Тургенева, 20	t	medium
113812	75252	31	Ростовская область, Белокалитвенский район, поселок Коксовый, Отечественная, 16А	t	medium
68795	75248	28	Ростовская область, Белокалитвенский район, поселок Коксовый, К. Маркса, 2	t	large
113811	75247	27	Ростовская область, Белокалитвенский район, поселок Коксовый, Дзержинского, 26	t	small
68796	75249	29	Ростовская область, Белокалитвенский район, Коксовый, Горноспасательная, 6	t	large
113856	75385	158	Ростовская область, Белокалитвенский район, хутор Какичев, Центральная, 44	t	small
113838	75362	135	Ростовская область, Белокалитвенский район, хутор Ильинка, Школьная, 1	f	medium
113852	75379	152	Ростовская область, Белокалитвенский район, хутор Западный, Садовая, 48	t	small
114839	77639	2481	Ростовская область, Белокалитвенский район, хутор Дороговский, Терновой, 4	f	small
113840	75364	137	Ростовская область, Белокалитвенский район, хутор Гусынка, Центральная, 28	f	small
113853	75380	153	Ростовская область, Белокалитвенский район, хутор Грушевка, Центральная, 19а	f	medium
68800	75258	37	Ростовская область, Белокалитвенский район, поселок Горняцкий, Театральная, 1	t	large
68798	75256	35	Ростовская область, Белокалитвенский район, поселок Горняцкий, Майская, 26	f	large
68799	75257	36	Ростовская область, Белокалитвенский район, Горняцкий, Дзержинского, 19а	t	large
113855	75382	155	Ростовская область, Белокалитвенский район, хутор Голубинка, Центральная, 16	f	medium
113839	75363	136	Ростовская область, Белокалитвенский район, село Головка, Школьная, 16	f	small
113806	75239	19	Ростовская область, Белокалитвенский район, поселок Виноградный, Матросова, 26	f	medium
68880	75384	157	Ростовская область, Белокалитвенский район, хутор Богураев, Центральная, 66	f	large
68879	75383	156	Ростовская область, Белокалитвенский район, хутор Богураев, Заречная, 1	f	large
113850	75377	150	Ростовская область, Белокалитвенский район, хутор Богатов, Станкевского, 21	t	small
113847	75374	147	Ростовская область, Белокалитвенский район, хутор Апанасовка, Шоссейная, 29	f	medium
114934	75348	125	Ростовская область, Багаевский район, поселок Ясный, Центральная, 4	f	small
113820	75335	113	Ростовская область, Багаевский район, хутор Федулов, Федуловская СОШ	f	medium
113832	75351	128	Ростовская область, Багаевский район, хутор Усьман, Братская, 50	f	medium
114936	75357	132	Ростовская область, Багаевский район, хутор Тузлуков, Береговая, 9А	f	small
114935	75353	129	Ростовская область, Багаевский район, поселок Садовый, Гагарина, 5	f	medium
113829	75346	124	Ростовская область, Багаевский район, хутор Пустошкин, Ленина, 35	f	small
114933	75341	118	Ростовская область, Багаевский район, поселок Привольный, Школьная, 1	f	medium
113831	75350	127	Ростовская область, Багаевский район, поселок Первомайский, Школьная, 42	f	medium
113834	75354	130	Ростовская область, Багаевский район, поселок Отрадный, Первомайская, 7А	f	medium
113827	75344	121	Ростовская область, Багаевский район, станица Манычская, Почтовая, 14	f	medium
113828	75331	122	Ростовская область, Багаевский район, станица Манычская, Поповкина, 2	f	small
113826	75343	120	Ростовская область, Багаевский район, хутор Кудинов, Школьная, 94	f	medium
68874	75349	126	Ростовская область, Багаевский район, хутор Красный, Центральная, 18	f	large
113824	75339	117	Ростовская область, Багаевский район, хутор Карповка, Зеленая, 13	f	small
113822	75337	115	Ростовская область, Багаевский район, поселок Задонский, Дом культуры	f	small
68872	75342	119	Ростовская область, Багаевский район, хутор Елкин, Советская, 8	f	large
113821	75336	114	Ростовская область, Багаевский район, поселок Дачный, Центральная, 1	f	small
113819	75334	112	Ростовская область, Багаевский район, хутор Белянин, Октябрьская, 24	f	medium
68870	75332	110	Ростовская область, Багаевский район, Багаевская, Фрунзе, 69А	f	large
68871	75333	111	Ростовская область, Багаевский район, станица Багаевская, Спартака, 106	f	large
87071	75329	107	Ростовская область, Багаевский район, станица Багаевская, Красноармейская, 1	f	large
68869	75330	109	Ростовская область, Багаевский район, станица Багаевская, Ермаковский, 83	f	large
68868	75330	108	Ростовская область, Багаевский район, станица Багаевская, Ермаковский, 83	f	large
68873	75345	123	Ростовская область, Багаевский район, хутор Арпачин, Советская, 42	f	large
113823	75338	116	Ростовская область, Багаевский район, хутор Ажинов, Заярного, 6	f	medium
114565	76765	1560	Ростовская область, Аксайский район, поселок Элитный, Центральная, 13	f	small
114975	76762	1557	Ростовская область, Аксайский район, поселок Щепкин, Строителей, 36А	f	medium
114569	76771	1566	Ростовская область, Аксайский район, хутор Черюмкин, Центральная, 67/3	f	medium
114918	77764	2625	Ростовская область, Аксайский район, поселок Темерницкий, Парковый переулок, 18	f	medium
70211	77711	2564	Ростовская область, Аксайский район, поселок Степной, Центральная, 7	f	large
69537	76782	1577	Ростовская область, Аксайский район, станица Старочеркасская, Гагарина, 1	f	large
114571	76773	1568	Ростовская область, Аксайский район, хутор Слава Труда, Славянская, 19	f	small
114578	76784	1579	Ростовская область, Аксайский район, хутор Рыбацкий, Береговая, 29	f	small
114557	76750	1546	Ростовская область, Аксайский район, поселок Российский, Молодежная, 7а	f	medium
69524	76748	1544	Ростовская область, Аксайский район, поселок Реконструктор, Гагарина, 1а	f	large
69529	76757	1553	Ростовская область, Аксайский район, поселок Рассвет, Экспериментальная, 66б	f	large
69528	76756	1552	Ростовская область, Аксайский район, поселок Рассвет, Комсомольская, 47	f	large
114556	76747	1543	Ростовская область, Аксайский район, хутор Пчеловодный, Пионерский, 2а	f	small
114573	76775	1570	Ростовская область, Аксайский район, хутор Островского, Кирова, 21 б	f	medium
114560	76755	1551	Ростовская область, Аксайский район, поселок Опытный, Центральная, 33	f	small
69535	76779	1574	Ростовская область, Аксайский район, станица Ольгинская, Ленина, 78	f	large
69534	76778	1573	Ростовская область, Аксайский район, станица Ольгинская, 5-ый, 1	f	large
69531	76760	1556	Ростовская область, Аксайский район, поселок Октябрьский, Советская, 36	f	large
114576	76780	1575	Ростовская область, Аксайский район, хутор Нижнеподпольный, Центральная, 53	f	medium
70236	77763	2624	Ростовская область, Аксайский район, станица Мишкинская, Просвещения, 30а	f	large
69526	76751	1547	Ростовская область, Аксайский район, станица Мишкинская, Просвещения, 58	f	large
114559	76753	1549	Ростовская область, Аксайский район, хутор Малый Мишкин, Восточная, 13а	f	small
69536	76781	1576	Ростовская область, Аксайский район, хутор Ленина, Онучкина, 22	f	large
114561	76758	1554	Ростовская область, Аксайский район, поселок Красный Колос, Зеленая, 13	f	medium
114563	76763	1558	Ростовская область, Аксайский район, поселок Красный, Толстого, 13а	f	medium
114577	76783	1578	Ростовская область, Аксайский район, хутор Краснодворск, Центральная, 38	f	small
69530	76759	1555	Ростовская область, Аксайский район, поселок Ковалевка, Центральная, 28	f	large
114558	76752	1548	Ростовская область, Аксайский район, хутор Киров, 50-летия Октября, 92а	f	small
114567	76768	1563	Ростовская область, Аксайский район, хутор Камышеваха, Подтелкова, 26	f	small
114574	76776	1571	Ростовская область, Аксайский район, хутор Истомино, Истомина, 67	f	medium
114575	76777	1572	Ростовская область, Аксайский район, поселок Дорожный, Центральная, 25а	f	medium
114572	76774	1569	Ростовская область, Аксайский район, поселок Дивный, Ленина, 14	f	medium
69532	76767	1562	Ростовская область, Аксайский район, станица Грушевская, Школьная, 25	f	large
114730	77357	2195	Ростовская область, Аксайский район, станица Грушевская, Советская, 265 а	f	medium
114568	76769	1564	Ростовская область, Аксайский район, станица Грушевская, Советская, 35	f	medium
114566	76766	1561	Ростовская область, Аксайский район, станица Грушевская, Советская, 191	f	medium
114564	76764	1559	Ростовская область, Аксайский район, поселок Возрожденный, Школьная, 14	f	small
69525	76749	1545	Ростовская область, Аксайский район, поселок Водопадный, Совхозная, 5	f	large
69533	76770	1565	Ростовская область, Аксайский район, хутор Верхнеподпольный, Школьная, 1 	f	large
69523	76746	1542	Ростовская область, Аксайский район, хутор Большой Лог, Советская, 73	f	large
69522	76745	1541	Ростовская область, Аксайский район, хутор Большой Лог, Советская, 36а	f	large
114845	77647	2493	Ростовская область, Аксайский район, Большой Лог, Фадеева, 293 	f	small
114570	76772	1567	Ростовская область, Аксайский район, хутор Алитуб, Луговая, 1	f	small
69527	76754	1550	Ростовская область, Аксайский район, хутор Александровка, Студенческая, 43	f	large
69520	76741	1539	Ростовская область, Аксайский район, Аксай, Чапаева, 299	f	large
69519	76740	1538	Ростовская область, Аксайский район, Аксай, Чапаева, 163	f	large
69514	76735	1533	Ростовская область, Аксайский район, Аксай, Толпинского, 114	f	large
70209	77698	2549	Ростовская область, Аксайский район, Аксай, Садовая, 14а	f	large
70183	77648	2494	Ростовская область, Аксайский район, Аксай, Садовая, 20	f	large
87051	76732	1530	Ростовская область, Аксайский район, Аксай, Мира, 1а	f	large
69510	76730	1529	Ростовская область, Аксайский район, Аксай, Мира, 7	f	large
69513	76734	1532	Ростовская область, Аксайский район, Аксай, Маяковского, 13	f	large
69512	76733	1531	Ростовская область, Аксайский район, Аксай, Ленина, 17	f	large
69509	76729	1528	Ростовская область, Аксайский район, Аксай, Ленина, 39	f	large
69974	77333	2167	Ростовская область, Аксайский район, Аксай, Кирова, 31	f	large
69516	76737	1535	Ростовская область, Аксайский район, Аксай, Гулаева, 129	f	large
69515	76736	1534	Ростовская область, Аксайский район, Аксай, Гулаева, 89	f	large
69506	76143	1525	Ростовская область, Аксайский район, Аксай, Вартанова, 25	f	large
69568	76814	1612	Ростовская область, Аксайский район, Аксай, Буденного, 136	f	large
69517	76738	1536	Ростовская область, Аксайский район, Аксай, Бондарчука, 18	f	large
114674	77215	2038	Ростовская область, Азовский район, поселок Южный, Гагарина, 40	f	small
114687	77246	2067	Ростовская область, Азовский район, хутор Чумбур-Коса, Центральная, 36б	f	small
114981	77205	2030	Ростовская область, Азовский район, хутор Христичево, Школьная, 38	f	small
114684	77237	2058	Ростовская область, Азовский район, хутор Харьковский, Центральная, 85	f	small
114982	77213	2036	Ростовская область, Азовский район, хутор Усть-Койсуг, Степная, 83	f	small
114697	77260	2082	Ростовская область, Азовский район, хутор Узяк, Платова, 90	f	small
114685	77242	2063	Ростовская область, Азовский район, поселок Тимирязевский, Кольцевая, 5	f	small
114701	77271	2092	Ростовская область, Азовский район, поселок Суходольск, Зеленая, 40	f	medium
69908	77232	2054	Ростовская область, Азовский район, село Стефанидинодар, Мира, 45	f	large
114814	77595	2429	Ростовская область, Азовский район, хутор Степнянский, Социалистическая, 19-а	f	small
114815	77596	2430	Ростовская область, Азовский район, поселок Солнечный, Школьная, 5	f	small
114694	77254	2076	Ростовская область, Азовский район, село Советский Дар, пер.Береговой, 1-1	f	small
69927	77272	2093	Ростовская область, Азовский район, село Семибалки, Ленина, 14	f	large
69924	77265	2087	Ростовская область, Азовский район, село Самарское, переулок Промышленный, 9	f	large
69922	77263	2085	Ростовская область, Азовский район, село Самарское, Переездная, 68	f	large
69925	77267	2088	Ростовская область, Азовский район, село Самарское, Московская, 51	f	large
69926	77268	2089	Ростовская область, Азовский район, село Самарское, Мира, 1	f	large
69923	77264	2086	Ростовская область, Азовский район, село Самарское, Ленина, 42	f	large
114698	77262	2084	Ростовская область, Азовский район, хутор Рогожкино, пер.Школьный, 29	f	medium
114688	77247	2068	Ростовская область, Азовский район, поселок Приморский, Центральная, 12	f	small
69916	77248	2069	Ростовская область, Азовский район, село Порт-Катон, Социалистическая, 39	f	large
114683	77236	2057	Ростовская область, Азовский район, хутор Полтава 2-я, Молодежная, 8	f	small
114682	77234	2056	Ростовская область, Азовский район, хутор Полтава 1-я, Южная, 5	f	small
69900	77219	2042	Ростовская область, Азовский район, хутор Победа, Филипченко, 2а	f	large
114691	77251	2073	Ростовская область, Азовский район, село Платоно-Петровка, Калинина, 12-А	f	small
69918	77256	2078	Ростовская область, Азовский район, село Пешково, переулок Октябрьский, 20	f	large
87114	77729	2585	Ростовская область, Азовский район, село Пешково, пер.Октябрьский, 15-А	f	large
114677	77218	2041	Ростовская область, Азовский район, хутор Песчаный, Комсомольская, 4	f	medium
114692	77252	2074	Ростовская область, Азовский район, хутор Павловка, Ростовский переулок, 8	f	medium
114702	77273	2094	Ростовская область, Азовский район, хутор Павло-Очаково, Победы, 36	f	small
114693	77253	2075	Ростовская область, Азовский район, село Отрадовка, Курышко, 20а	f	medium
114695	77255	2077	Ростовская область, Азовский район, село Орловка, Победы, 23	f	medium
69914	77243	2064	Ростовская область, Азовский район, поселок Овощной, переулок Комсомольский, 6а	f	large
69898	77209	2033	Ростовская область, Азовский район, хутор Обуховка, Заводская, 38-В	f	large
69901	77221	2044	Ростовская область, Азовский район, село Новотроицкое, Школьная, 12	f	large
69921	77261	2083	Ростовская область, Азовский район, поселок Новополтавский, переулок Школьный, 21а	f	large
114699	77269	2090	Ростовская область, Азовский район, село Новониколаевка, пер.Школьный, 13	f	medium
69906	77229	2051	Ростовская область, Азовский район, поселок Новомирский, Московская, 5	f	large
114689	77249	2070	Ростовская область, Азовский район, село Новомаргаритово, Ленина, 14	f	small
69917	77250	2071	Ростовская область, Азовский район, хутор Новоалександровка, улица Ленина, 88-А	f	large
114667	77203	2029	Ростовская область, Азовский район, хутор Нижняя Козинка, Мира, 40-А	f	small
114686	77245	2066	Ростовская область, Азовский район, село Маргаритово, Луговая, 8	f	medium
114669	77207	2031	Ростовская область, Азовский район, поселок Ленинский Лесхоз, пл.Домошевского, 5	f	small
114812	77593	2427	Ростовская область, Азовский район, хутор Левобережный, Школьная, 1	f	small
69912	77240	2061	Ростовская область, Азовский район, село Кулешовка, площадь Гагарина, 1	f	large
69913	77241	2062	Ростовская область, Азовский район, село Кулешовка, Первомайская, 30	f	large
70192	77669	2514	Ростовская область, Азовский район, село Кулешовка, Матросова, 16	f	large
69910	77238	2059	Ростовская область, Азовский район, село Кулешовка, Ленина, 299	f	large
69911	77239	2060	Ростовская область, Азовский район, село Кулешовка, Кулагина, 4а	f	large
69909	77233	2055	Ростовская область, Азовский район, село Кугей, Ленина, 50	f	large
69907	77231	2053	Ростовская область, Азовский район, село Круглое, Мира, 79	f	large
69915	77244	2065	Ростовская область, Азовский район, поселок Красный Сад, Заводская, 15	f	large
114700	77270	2091	Ростовская область, Азовский район, хутор Кочеванчик, Луговая, 71	f	medium
114672	77211	2035	Ростовская область, Азовский район, хутор Колузаево, Ленина, 68-А	f	medium
114679	77222	2045	Ростовская область, Азовский район, поселок Каяльский, Ленина, 44	f	medium
114817	77598	2432	Ростовская область, Азовский район, хутор Калиновка, Октябрьская, 39	f	small
69902	77223	2046	Ростовская область, Азовский район, село Кагальник, Тельмана, 4б	f	large
69903	77224	2047	Ростовская область, Азовский район, село Кагальник, Советская, 59	f	large
69904	77225	2048	Ростовская область, Азовский район, село Кагальник, Ленина, 33а	f	large
69905	77226	2049	Ростовская область, Азовский район, село Кагальник, Волгодонская, 9	f	large
114913	77755	2613	Ростовская область, Азовский район, поселок Зеленый, Центральная, 17	f	small
69920	77258	2080	Ростовская область, Азовский район, село Займо-Обрыв, переулок Октябрьский, 12	f	large
114678	77220	2043	Ростовская область, Азовский район, хутор Задонский, Ленина, 28а	f	medium
114676	77217	2040	Ростовская область, Азовский район, хутор Еремеевка, Ворошиловская, 72-А	f	small
114813	77594	2428	Ростовская область, Азовский район, хутор Ельбузд, Юбилейная, 1-Б	f	small
69899	77214	2037	Ростовская область, Азовский район, село Елизаветовка, Дзержинского, 35	f	large
114670	77208	2032	Ростовская область, Азовский район, станица Елизаветинская, пл.Павших Борцов, 1	f	small
114671	77210	2034	Ростовская область, Азовский район, хутор Дугино, Мало-Свердлова, 12	f	small
83921	57341	3116	Москва, Зеленоград, к603а	f	large
114983	77227	2050	Ростовская область, Азовский район, хутор Донской, Бакланова, 79	f	small
114681	77230	2052	Ростовская область, Азовский район, хутор Гусарева Балка, Кирова, 29	f	medium
114818	77599	2433	Ростовская область, Азовский район, хутор Григорьевка, Центральная, 14-А	f	small
69919	77257	2079	Ростовская область, Азовский район, село Головатовка, переулок Октябрьский, 26	f	large
114690	77235	2072	Ростовская область, Азовский район, село Высочино, Горького, 33	f	medium
114675	77216	2039	Ростовская область, Азовский район, село Васильево-Петровское, Азовская, 35	f	small
114811	77591	2426	Ростовская область, Азовский район, поселок Васильево-Петровский, Строителей , 2	f	small
114816	77597	2431	Ростовская область, Азовский район, хутор Бурхановка, Октябрьская, 18-Б	f	small
114696	77259	2081	Ростовская область, Азовский район, хутор Береговой, Ленина, 30	f	small
114665	77201	2027	Ростовская область, Азовский район, село Александровка, переулок Победы, 45	f	small
69897	77199	2025	Ростовская область, Азовский район, село Александровка, Советская, 35	f	large
114664	77200	2026	Ростовская область, Азовский район, село Александровка, Октябрьская, 22	f	medium
114666	77202	2028	Ростовская область, Азовский район, село Александровка, Калинина, 101	f	medium
20126	44958	1605	Краснодарский край, х. Журавлевка, улица Центральная, 102/А	f	small
22065	46867	5646	Краснодарский край, ст. Ладожская, Коншиных, 113, телефон: 70-1-19	f	large
22055	46859	5636	Краснодарский край, ст. Воронежская, Карпенко, 50, телефон: 37-1-45	f	large
21474	46286	4351	Краснодарский край, с.Галицино, Батайская, 43	f	small
21093	45916	3415	Краснодарский край, пос.Грушовая балка, 16	t	small
67932	46648	5105	Краснодарский край, п. Пригородный, Центральная, 27	f	large
19908	44739	1031	Краснодарский край, жилой городок Лесная сказка, здание средней школы №17	f	medium
21081	45904	3403	Краснодарский край, поселок Шесхарис, Сухумийское шоссе, 5, телефон: 60-46-21	f	large
21080	45903	3402	Краснодарский край, поселок Шесхарис, Сухумийское шоссе, 92, телефон: 28-12-58	f	large
21079	45902	3401	Краснодарский край, поселок Шесхарис, Сухумийское шоссе, 11, телефон: 60-34-63	f	large
19904	44735	1027	Краснодарский край, станица Черноморская, Ленина, 25, телефон: 5-87-72	f	medium
21119	45941	3522	Краснодарский край, поселок Цемдолина, улица Школьная, 33	t	large
19560	44389	322	Краснодарский край, Хадыженск, Ленина, 57	f	large
19894	44725	1017	Краснодарский край, село Фанагорийское, Подгорная, 14, телефон: 5-39-4	t	small
22038	46843	5619	Краснодарский край, Усть-Лабинск, Строительная, 11	f	large
22032	46837	5613	Краснодарский край, Усть-Лабинск, Площадь Революции, 15, телефон: 2-36-83	f	large
22078	46880	5659	Краснодарский край, Усть-Лабинск, Пионерская, 251/А	f	large
22036	46841	5617	Краснодарский край, Усть-Лабинск, Коммунистическая, 63	f	large
21253	46070	3942	Краснодарский край, станица Украинская, Школьная, 2	f	medium
20995	45821	3206	Республика Хакасия, Абакан, улица Пушкина, 1	f	small
21982	46789	5416	Краснодарский край, Туапсе, улица Новицкого, 17 А	f	large
21979	46786	5413	Краснодарский край, Туапсе, улица Коммунистическая, 1, Школа искусств	f	medium
21973	46779	5407	Краснодарский край, Туапсе, улица Горького, 40, СОШ 4, корпус 2	f	large
21976	46782	5410	Краснодарский край, Туапсе, площадь Октябрьской Революции, 2, ГДК, 2 этаж	f	large
21975	46781	5409	Краснодарский край, Туапсе, площадь Октябрьской Революции, 2, ГДК, 1 этаж	f	large
21978	46784	5412	Краснодарский край, Туапсе, Шаумяна, 7, Центр детского творчества	f	large
21942	46751	5333	Краснодарский край, Туапсе, Шаумяна, 4	f	small
21970	46776	5404	Краснодарский край, Туапсе, Фрунзе, 67	f	large
21969	46775	5403	Краснодарский край, Туапсе, Фрунзе, 67, СОШ 2, правое крыло	f	large
21971	46777	5405	Краснодарский край, Туапсе, Таманская, 12, ТЮЗ	f	large
21992	46800	5426	Краснодарский край, Туапсе, Сочинская, 45, СОШ 3	f	medium
21986	46793	5420	Краснодарский край, Туапсе, Сочинская, 48, ДКН, 2 этаж	f	large
21985	46792	5419	Краснодарский край, Туапсе, Сочинская, 48, ДКН, 1этаж	f	large
21974	46780	5408	Краснодарский край, Туапсе, Полетаева, 10, СОШ 7	f	large
21977	46783	5411	Краснодарский край, Туапсе, Ленина, 1, СОШ 6	f	large
21980	46787	5414	Краснодарский край, Туапсе, Кондратьева, 5, СОШ 5	f	large
21984	46791	5418	Краснодарский край, Туапсе, Киевская, 1, СОШ 10	f	large
21991	46799	5425	Краснодарский край, Туапсе, Карла Маркса, 17, Кинотеатр Россия	f	large
21981	46788	5415	Краснодарский край, Туапсе, Карла Маркса, 39, Художественная школа	f	large
21941	46750	5332	Краснодарский край, Туапсе, Камо, 1	f	small
21990	46797	5424	Краснодарский край, Туапсе, Калараша, 7а, СОШ 11, правое крыло	f	large
21968	46774	5402	Краснодарский край, Туапсе, Калараша, 7а, СОШ 11, левое крыло	f	large
67937	46801	5427	Краснодарский край, Туапсе, Звездная, 49, МОУ СОШ №8	f	large
21988	46795	5422	Краснодарский край, Туапсе, Звездная, 25, КубГТУ	t	large
21987	46794	5421	Краснодарский край, Туапсе, Звездная, 49, СОШ 8	f	large
67936	46773	5401	Краснодарский край, Туапсе, Дружбы переулок, 68, Социальный дом, (фойе 1 этажа) 	f	large
21972	46778	5406	Краснодарский край, Туапсе, Горького, 40, СОШ 4, корпус 1	f	large
21983	46790	5417	Краснодарский край, Туапсе, Богдана Хмельницкого, 85, филиал РГУПС	f	large
21900	46712	5226	Краснодарский край, Тихорецк, Федосеева, 43	f	small
21894	46706	5220	Краснодарский край, Тихорецк, Парковая, 35	f	large
21889	46701	5215	Краснодарский край, Тихорецк, Красноармейская, 80	f	large
21877	46689	5203	Краснодарский край, Тихорецк, Красноармейская, 32	f	large
21880	46692	5206	Краснодарский край, Тихорецк, Калинина, 128	f	large
21884	46696	5210	Краснодарский край, Тихорецк, Меньшикова, 84	f	large
21775	46589	5005	Краснодарский край, Тимашевск, Степанова, 54, Профессиональное училище № 17	f	large
21825	46610	5055	Краснодарский край, Тимашевск, Рабочая, 36	f	large
21796	46610	5026	Краснодарский край, Тимашевск, Рабочая, 36	f	large
21786	46600	5016	Краснодарский край, Тимашевск, Пионерская, 92	f	large
21780	46594	5010	Краснодарский край, Тимашевск, Ленина, 176	f	large
21783	46597	5013	Краснодарский край, Тимашевск, Колхозная, 74	f	medium
19759	44587	669	Краснодарский край, поселок Терновый, Спортивная, 38	f	small
21732	46547	4916	Краснодарский край, Темрюк, 27 Сентября, 188/1, здание Дома культуры	f	large
19902	44733	1025	Краснодарский край, станица Суздальская, Красная, 30, телефон: 3-28-34	f	medium
20446	45278	2162	Краснодарский край, станица Старокорсунская, Шевченко, 222	f	large
20445	45277	2161	Краснодарский край, станица Старокорсунская, Красная, 60/1	f	large
20444	45276	2160	Краснодарский край, станица Старокорсунская, Красная, 27/1	f	large
20984	45809	3137	Краснодарский край, Станица Ярославская, Энгельса, 106	f	large
111110	46311	4399	Краснодарский край, Сочи, село Эстосадок, Роза-Хутор	t	\N
111107	46309	4397	Краснодарский край, Сочи, Общество с ограниченной ответственностью ТрансКомСтрой	f	\N
111098	46304	4393	Краснодарский край, Сочи, Пикет № 276	t	\N
111091	46300	4389	Краснодарский край, Сочи, Пикет № 59	t	\N
21620	46432	4632	Краснодарский край, Сочи, улица Тимирязева, 21/7	f	medium
21646	46459	4658	Краснодарский край, Большой Сочи Центральный район, Сочи, улица Советская, 26а	f	medium
21461	46273	4338	Краснодарский край, Сочи, улица Ленина, 280а	f	large
21613	46425	4625	Краснодарский край, Большой Сочи Центральный район, Сочи, улица Донская, 15	f	large
21600	46412	4612	Краснодарский край, Большой Сочи Центральный район, Сочи, улица Гагарина, 10а	f	medium
21597	46409	4609	Краснодарский край, Большой Сочи Центральный район, Сочи, улица Виноградная, 45	f	large
21595	46407	4607	Краснодарский край, Большой Сочи Центральный район, Сочи, улица Виноградная, 101	f	large
21565	46377	4511	Краснодарский край, Сочи, Яна Фабрициуса, 2к28	f	large
21580	46392	4526	Краснодарский край, Сочи, Шоссейная, 26	f	small
21610	46422	4622	Краснодарский край, Большой Сочи Центральный район, Сочи, Чехова переулок, 9	f	large
21615	46427	4627	Краснодарский край, Большой Сочи Центральный район, Сочи, Чехова, 25	f	large
21617	46429	4629	Краснодарский край, Сочи, Чехова, 37	f	large
21574	46386	4520	Краснодарский край, Сочи, Чекменева, 45	f	large
21636	46449	4648	Краснодарский край, Сочи, Чебрикова, 5	f	large
21603	46415	4615	Краснодарский край, Сочи, Чайковского, 7	f	large
21599	46411	4611	Краснодарский край, Сочи, Чайковского, 4	f	small
111118	46419	4619	Краснодарский край, Большой Сочи Центральный район, Сочи, Чайковского, 45	f	medium
21606	46418	4618	Краснодарский край, Большой Сочи Центральный район, Сочи, Чайковского, 39	f	large
21605	46417	4617	Краснодарский край, Большой Сочи Центральный район, Сочи, Цветной бульвар, 40	f	large
21647	46460	4659	Краснодарский край, Большой Сочи Центральный район, Сочи, Туапсинская, 11	f	large
21635	46448	4647	Краснодарский край, Большой Сочи Центральный район, Сочи, Туапсинская, 11	f	large
21637	46450	4649	Краснодарский край, Большой Сочи Центральный район, Сочи, Трунова переулок, 3	f	large
21622	46434	4634	Краснодарский край, Сочи, Труда, 29	f	large
21638	46451	4650	Краснодарский край, Сочи, Тоннельная, 27	f	medium
20644	45467	2431	Краснодарский край, Сочи, Тимирязева, 2	f	large
21650	46463	4662	Краснодарский край, Большой Сочи Центральный район, Сочи, Театральная, 2	f	large
21584	46396	4530	Краснодарский край, Сочи, Сухумское шоссе, 11, телефон: 65-43-43	f	medium
67929	46205	4314	Краснодарский край, Сочи, Станиславского, 1	f	large
21641	46454	4653	Краснодарский край, Большой Сочи Центральный район, Сочи, Советская, 57	f	large
21593	46405	4605	Краснодарский край, Сочи, Санаторная, 49	f	large
21587	46399	4533	Краснодарский край, Сочи, Ростовская, 7	f	large
21501	46313	4402	Краснодарский край, Сочи, Ровная, 33	f	small
21594	46406	4606	Краснодарский край, Сочи, Политехническая, 62	f	large
21513	46325	4414	Краснодарский край, Сочи, Победы, 62	f	large
21511	46323	4412	Краснодарский край, Сочи, Победы, 153	f	medium
21592	46404	4604	Краснодарский край, Сочи, Плеханова, 42	f	large
21596	46408	4608	Краснодарский край, Сочи, Пирогова, 3	f	large
21427	46243	4304	Краснодарский край, Сочи, Петропавловская, 1	f	large
21470	46282	4347	Краснодарский край, Сочи, Петрозаводская, 10	f	large
21611	46423	4623	Краснодарский край, Сочи, Пасечная, 18	f	large
21645	46458	4657	Краснодарский край, Сочи, Парковая, 19	f	large
21517	46329	4418	Краснодарский край, Сочи, Павлова переулок, 18	f	large
21649	46462	4661	Краснодарский край, Большой Сочи Центральный район, Сочи, Орджоникидзе, 10	f	large
21579	46391	4525	Краснодарский край, Сочи, Октября, 1/4	f	medium
111086	46299	4387	Краснодарский край, Сочи, Микрорайон Мирный	t	\N
111089	46299	4388	Краснодарский край, Сочи, Микрорайон Мирный	f	\N
21527	46339	4428	Краснодарский край, Сочи, Медицинская, 9	f	medium
21575	46387	4521	Краснодарский край, Большой Сочи Центральный район, Сочи, Мацестинская, 7	f	large
21630	46443	4642	Краснодарский край, Большой Сочи Хостинский район, Сочи, Макаренко, 8/А, телефон: 688470	f	medium
21563	46375	4509	Краснодарский край, Сочи, Лысая Гора, 34	f	large
21434	46250	4311	Краснодарский край, Большой Сочи Хостинский район, Сочи, Лесная, 1, телефон: 638896	f	large
21462	46274	4339	Краснодарский край, Сочи, Ленина, 282	f	medium
21453	46268	4330	Краснодарский край, Сочи, Ленина, 97	f	medium
21457	43010	4334	Краснодарский край, Сочи, Ленина, 147	f	large
21589	46401	4601	Краснодарский край, Сочи, Ландышевая, 12	f	large
21648	46461	4660	Краснодарский край, Центральный район, Сочи, Курортный проспект, 32, телефон: 623399	f	large
21573	46385	4519	Краснодарский край, Сочи, Курортный проспект, 106/А	f	large
21604	46416	4616	Краснодарский край, Большой Сочи Центральный район, Сочи, Красноармейская, 28	f	large
21602	46414	4614	Краснодарский край, Большой Сочи Центральный район, Сочи, Красноармейская, 24	f	large
21601	46413	4613	Краснодарский край, Сочи, Красноармейская, 6, телефон: 547143	f	medium
21644	46457	4656	Краснодарский край, Сочи, Конституции СССР, 26	f	large
21643	46456	4655	Краснодарский край, Большой Сочи Центральный район, Сочи, Конституции СССР, 26, телефон: 645688	f	medium
21483	46296	4360	Краснодарский край, Сочи, Коммунаров	f	large
111120	34289	5054	Краснодарский край, Сочи, Коммунальная, 1 А	f	medium
21578	46390	4524	Краснодарский край, Сочи, Кипарисовая, 6	f	large
21516	46328	4417	Краснодарский край, Сочи, Калараш, 47а	f	large
21560	46372	4506	Краснодарский край, Сочи, Измайловская, 57	f	large
21472	46284	4349	Краснодарский край, Сочи, Ивановская, 54а	f	large
21546	46358	4447	Краснодарский край, Сочи, Золотая, 13	f	large
21577	46389	4523	Краснодарский край, Сочи, Звездная, 14, телефон: 65-92-84	f	large
21616	46428	4628	Краснодарский край, Сочи, Донская, 92	f	large
21614	46426	4626	Краснодарский край, Сочи, Донская, 17	f	large
21609	46421	4621	Краснодарский край, Сочи, Донская, 36	f	large
21618	46430	4630	Краснодарский край, Большой Сочи Центральный район, Сочи, Донская, 108	f	large
21612	46424	4624	Краснодарский край, Большой Сочи Центральный район, Сочи, Донская, 13а	f	large
21564	46376	4510	Краснодарский край, Сочи, Депутатская, 10	f	large
21619	46431	4631	Краснодарский край, Большой Сочи Центральный район, Сочи, Гранатная, 3	f	large
21460	46272	4337	Краснодарский край, Сочи, Голубые Дали, 23	f	large
21608	46420	4620	Краснодарский край, Большой Сочи Центральный район, Сочи, Гагарина, 64	f	large
21642	46455	4654	Краснодарский край, Большой Сочи Центральный район, Сочи, Воровского, 52к54	f	large
21591	46403	4603	Краснодарский край, Сочи, Волжская, 64	f	large
21571	46383	4517	Краснодарский край, Большой Сочи Центральный район, Сочи, Возрождения, 8, телефон: 97-82-14	f	large
21623	46435	4635	Краснодарский край, Сочи, Вишневая, 7	f	large
111116	46410	4610	Краснодарский край, Сочи, Виноградная, 27	f	medium
21567	46379	4513	Краснодарский край, Сочи, Бытха, 25, телефон: 67-20-19	f	large
21440	46255	4317	Краснодарский край, Сочи, Богдана Хмельницкого, 24, телефон: 440172	f	large
21432	46248	4309	Краснодарский край, Сочи, Бакинская, 2, телефон: 411872	f	large
67930	46349	4438	Краснодарский край, Большой Сочи Лазаревский район, Сочи, Астраханская, 7	f	large
21627	46439	4639	Краснодарский край, Сочи, Абрикосовая, 23	f	large
21626	46438	4638	Краснодарский край, Сочи, Абрикосовая, 29	f	medium
21557	46369	4503	Краснодарский край, Сочи, Абовяна, 39	f	large
21628	46440	4640	Краснодарский край, Сочи, 60 Лет ВЛКСМ, 12	f	large
21534	46346	4435	Краснодарский край, Сочи, Лооская, 2/1	f	large
21441	46256	4318	Краснодарский край, Сочи, Кирова, 26	f	medium
21640	46453	4652	Краснодарский край, Сочи, Горького, 48	f	large
21639	46452	4651	Краснодарский край, Большой Сочи Центральный район, Сочи, Горького, 85	f	large
21383	46198	4223	Краснодарский край, Славянск-На-Кубани, Строителей, 49	f	large
21368	46183	4208	Краснодарский край, Славянск-На-Кубани, Пролетарская, 4	f	large
21382	46197	4222	Краснодарский край, Славянск-На-Кубани, Победы, 380	f	large
21379	46194	4219	Краснодарский край, Славянск-На-Кубани, Отдельская, 32	f	large
21376	46191	4216	Краснодарский край, Славянск-На-Кубани, Отдельская, 213	f	large
21372	46187	4212	Краснодарский край, Славянск-На-Кубани, Отдельская, 207	f	large
21369	46184	4209	Краснодарский край, Славянск-На-Кубани, Набережная, 14	f	large
22044	46848	5625	Краснодарский край, Семёновкский, улица Буденного, 1-А	f	small
20767	45591	2717	Краснодарский край, хутор Свобода, клуб, телефон: 7-01-42	f	small
19897	44728	1020	Краснодарский край, станица Саратовская, Школьная, 3 А, телефон: 3-11-28	f	large
19899	44730	1022	Краснодарский край, станица Саратовская, Табачная, 5	f	large
19898	44729	1021	Краснодарский край, станица Саратовская, Ленина, 69 А, телефон: 3-14-53	f	large
21198	46015	3838	Краснодарский край, поселок Передовая, Ленина, 124	f	large
21165	45982	3805	Краснодарский край, поселок Отрадненая, Октябрьская, 210	f	large
21247	46064	3936	Краснодарский край, Октябрьский, Советская, 10	f	large
21357	46172	4167	Краснодарский край, поселок Октябрьский, Пушкина, 46, телефон: 66-2-13	f	large
20044	44877	1312	Краснодарский край, поселок Октябрьский, Мира, 38 Б, телефон: 97236	f	large
20281	45111	1926	Краснодарский край, поселок Октябрьский, Красная, 20/А	f	large
21146	45968	3721	Краснодарский край, Новороссийск, улица набережная Адмирала Серебрякова, 53	f	large
22115	46918	5816	Краснодарский край, Новороссийск, улица Южная, 6	f	large
21136	45958	3711	Краснодарский край, Новороссийск, улица Энгельса, 49	f	large
21095	45918	3417	Краснодарский край, Новороссийск, улица Мефодиевская, 118Б, Детская библиотека филиал №8, телефон: 27-27-58	f	large
21089	45912	3411	Краснодарский край, Новороссийск, улица Мефодиевская, 15, телефон: 27-33-08	f	large
21083	45906	3405	Краснодарский край, Новороссийск, улица Жуковского, 7, телефон: 67-80-48	f	large
21137	45959	3712	Краснодарский край, Новороссийск, улица Грибоедова, 12	f	large
22101	46903	5802	Краснодарский край, Новороссийск, улица Героев Десантников, 29а	f	large
21108	45930	3511	Краснодарский край, Новороссийск, улица Видова, 164	f	large
21105	45927	3508	Краснодарский край, Новороссийск, улица Видова, 109	f	large
21134	45956	3709	Краснодарский край, Новороссийск, набережная Адмирала Серебрякова, 9	f	large
22138	46940	5916	Краснодарский край, Новороссийск, Южная, 10	t	small
22148	46950	5926	Краснодарский край, Новороссийск, Шоссейная, 34	f	large
22147	46949	5925	Краснодарский край, Новороссийск, Шоссейная, 1	f	large
22137	46939	5915	Краснодарский край, Новороссийск, Шоссейная, 53	t	small
83920	57340	3115	Москва, Зеленоград, к529	f	large
22141	46943	5919	Краснодарский край, Новороссийск, Фрунзе, 54	f	large
22140	46942	5918	Краснодарский край, Новороссийск, Фрунзе, 50	f	large
21139	45961	3714	Краснодарский край, Новороссийск, Толстого, 4	f	large
67981	45936	3517	Краснодарский край, Новороссийск, Тобольского , 5 а	f	large
21138	45960	3713	Краснодарский край, Новороссийск, Суворовская, 40	f	large
21115	45937	3518	Краснодарский край, Новороссийск, Спортивная, 1	f	large
21130	45952	3705	Краснодарский край, Новороссийск, Советов, 45	f	large
21127	45949	3702	Краснодарский край, Новороссийск, Советов, 19	f	large
21126	45948	3701	Краснодарский край, Новороссийск, Советов, 9	f	large
21099	45921	3502	Краснодарский край, Новороссийск, Севрюкова, 6	f	large
22129	46931	5907	Краснодарский край, Новороссийск, Садовая, 1а	t	small
21131	45953	3706	Краснодарский край, Новороссийск, Рубина, 27	f	large
21129	45951	3704	Краснодарский край, Новороссийск, Рубина, 5, телефон: 642-271, 611-868	f	medium
21133	45955	3708	Краснодарский край, Новороссийск, Революции 1905 Года, 23	f	large
21149	45971	3724	Краснодарский край, Новороссийск, Прямая, 33	f	large
22124	46926	5902	Краснодарский край, Новороссийск, Промышленная, 12	f	large
21120	45942	3523	Краснодарский край, Новороссийск, Полевая, 8	t	large
22139	46941	5917	Краснодарский край, Новороссийск, Победы, 1а	f	large
21117	45939	3520	Краснодарский край, Новороссийск, Первомайская, 3-а	t	large
21094	45917	3416	Краснодарский край, Новороссийск, Первомайская, 9, телефон: 27-93-53	f	large
21084	45907	3406	Краснодарский край, Новороссийск, Первомайская, 7, телефон: 27-86-41	f	large
21152	45974	3727	Краснодарский край, Новороссийск, Пархоменко, 6	f	small
22120	46923	5821	Краснодарский край, Новороссийск, Мысхакское шоссе, 56	f	large
22116	46919	5817	Краснодарский край, Новороссийск, Мысхакское шоссе, 48	f	large
21142	45964	3717	Краснодарский край, Новороссийск, Мысхакское шоссе, 23	f	large
22132	46934	5910	Краснодарский край, Новороссийск, Мира, 47	f	large
22126	46928	5904	Краснодарский край, Новороссийск, Мира, 27	t	medium
21092	45915	3414	Краснодарский край, Новороссийск, Мефодиевская, 118-б	f	large
21086	45909	3408	Краснодарский край, Новороссийск, Менжинского, 52, телефон: 26-56-54	f	large
21091	45914	3413	Краснодарский край, Новороссийск, Межевая, 4, телефон: 76-86-64	f	large
22113	46916	5814	Краснодарский край, Новороссийск, Малоземельская, 11	f	large
22111	46914	5812	Краснодарский край, Новороссийск, Малоземельская, 15	f	large
21109	45931	3512	Краснодарский край, Новороссийск, Луначарского, 21	f	large
22130	46932	5908	Краснодарский край, Новороссийск, Ленина проспект, 1	f	large
22118	46921	5819	Краснодарский край, Новороссийск, Ленина проспект, 95А	f	large
22117	46920	5818	Краснодарский край, Новороссийск, Ленина проспект, 93	f	large
67989	46902	5801	Краснодарский край, Новороссийск, Ленина проспект, 59	f	large
21147	45969	3722	Краснодарский край, Новороссийск, Ленина проспект, 22	f	large
21118	45940	3521	Краснодарский край, Новороссийск, Ленина, 82	t	large
21141	45963	3716	Краснодарский край, Новороссийск, Лейтенанта Шмидта, 37	f	large
21151	45973	3726	Краснодарский край, Новороссийск, Куникова, 28	f	large
21150	45972	3725	Краснодарский край, Новороссийск, Куникова, 9	f	large
21098	45920	3501	Краснодарский край, Новороссийск, Краснознаменный переулок, 2-а	f	large
21090	45913	3412	Краснодарский край, Новороссийск, Краснодарская, 35	f	large
22143	46945	5921	Краснодарский край, Новороссийск, Красная, 42, телефон: 270244	f	large
21121	45943	3524	Краснодарский край, Новороссийск, Красная, 23	f	medium
21106	45928	3509	Краснодарский край, Новороссийск, Козлова, 76	f	large
22133	46935	5911	Краснодарский край, Новороссийск, Кирова, 19	f	medium
21148	45970	3723	Краснодарский край, Новороссийск, Карамзина, 43	f	large
21140	45962	3715	Краснодарский край, Новороссийск, Исаева, 2	f	large
22114	46917	5815	Краснодарский край, Новороссийск, Золотаревского, 6	f	large
21122	45944	3525	Краснодарский край, Новороссийск, Дружбы, 5	t	large
22121	46924	5822	Краснодарский край, Новороссийск, Дзержинского проспект, 210	f	large
22119	46922	5820	Краснодарский край, Новороссийск, Дзержинского проспект, 197	f	large
22108	46911	5809	Краснодарский край, Новороссийск, Дзержинского проспект, 213	f	large
22122	46909	5823	Краснодарский край, Новороссийск, Дзержинского проспект, 213	f	large
22104	46906	5805	Краснодарский край, Новороссийск, Дзержинского проспект, 162	f	large
21145	45967	3720	Краснодарский край, Новороссийск, Дзержинского проспект, 126	f	large
21116	45938	3519	Краснодарский край, Новороссийск, Горького, 27	f	large
67980	45932	3513	Краснодарский край, Новороссийск, Герцена, 5	f	large
22112	46915	5813	Краснодарский край, Новороссийск, Героев Десантников, 67	f	large
22106	46908	5807	Краснодарский край, Новороссийск, Героев Десантников, 57А	f	large
67990	46907	5806	Краснодарский край, Новороссийск, Героев Десантников, 51a	f	large
22103	46905	5804	Краснодарский край, Новороссийск, Героев Десантников, 13	f	large
22102	46904	5803	Краснодарский край, Новороссийск, Героев Десантников, 13	f	large
22110	46913	5811	Краснодарский край, Новороссийск, Волгоградская, 46	f	large
22109	46912	5810	Краснодарский край, Новороссийск, Волгоградская, 46	f	large
134656	46910	5808	Краснодарский край, Новороссийск, Волгоградская, 44, филиал №18 юношеской библиотеки	f	large
22127	46929	5905	Краснодарский край, Новороссийск, Виноградная, 36	t	small
21123	45945	3526	Краснодарский край, Новороссийск, Видова, 56	f	large
21112	45934	3515	Краснодарский край, Новороссийск, Видова, 184	f	large
21111	45933	3514	Краснодарский край, Новороссийск, Видова, 182	f	large
21107	45929	3510	Краснодарский край, Новороссийск, Видова, 123	f	large
21113	45935	3516	Краснодарский край, Новороссийск, Анапское шоссе, 55-а	f	large
21103	45925	3506	Краснодарский край, Новороссийск, Анапское шоссе, 6	f	large
21102	45924	3505	Краснодарский край, Новороссийск, Анапское шоссе, 17	f	large
21101	45923	3504	Краснодарский край, Новороссийск, Анапское шоссе, 18	f	large
22142	46944	5920	Краснодарский край, Новороссийск, 50 лет Октября, 10-а, телефон: 8-918-16-92-885	t	small
22134	46936	5912	Краснодарский край, Новороссийск, 40 лет Октября, 8, телефон: 27-65-64	f	large
21132	45954	3707	Краснодарский край, Новороссийск, Яковлева, 27	f	large
21104	45926	3507	Краснодарский край, Новороссийск, Чкалова, 48	f	large
21143	45965	3718	Краснодарский край, Новороссийск, Суворовская, 5	f	large
21100	45922	3503	Краснодарский край, Новороссийск, Козлова, 74	f	large
21128	45950	3703	Краснодарский край, Новороссийск, Гладкова, 3	f	large
21013	45838	3224	Краснодарский край, Новокубанск, Чапаева, 63	f	large
21008	45833	3219	Краснодарский край, Новокубанск, Победы, 4	f	large
21017	45842	3228	Краснодарский край, Новокубанск, Первомайская, 132	f	large
21015	45840	3226	Краснодарский край, Новокубанск, Первомайская, 83	f	medium
21007	45832	3218	Краснодарский край, Новокубанск, Красная, 46	f	large
21018	45843	3229	Краснодарский край, Новокубанск, Кооперативная, 64/1	f	large
21011	45836	3222	Краснодарский край, Новокубанск, К.Маркса, 52	f	large
21351	46166	4161	Краснодарский край, поселок Мирный, Здание сельского клуба	t	small
21085	45908	3407	Краснодарский край, поселок Мефодиевка, Сакко и Ванцетти, 23	f	large
21082	45905	3404	Краснодарский край, поселок Мефодиевка, Сакко и Ванцетти, 4, телефон: 60-47-00	f	large
19662	44490	467	Краснодарский край, поселок Маяк, Восточная, 10, телефон: 38240	t	small
19903	44734	1026	Краснодарский край, станица Мартанская, Красная, 36, телефон: 5-33-47	f	medium
20943	45767	3031	Краснодарский край, хутор Ленина, улица Казачья, 2	t	small
20474	45303	2218	Краснодарский край, поселок Лазурный, Октябрьская, 1	f	large
20874	45697	2916	Краснодарский край, Лабинск, Халтурина, 14	f	large
20859	45631	2901	Краснодарский край, Лабинск, Турчанинова, 65	f	large
20867	45690	2909	Краснодарский край, Лабинск, Победы, 268	f	large
20868	45691	2910	Краснодарский край, Лабинск, Константинова, 89, телефон: 26708	f	large
20879	45703	2921	Краснодарский край, Лабинск, Ватутина, 11	f	large
20762	45586	2712	Краснодарский край, Курганинск, Мира, 107	f	large
20765	45589	2715	Краснодарский край, Курганинск, Ленина, 369	f	large
20756	45579	2706	Краснодарский край, Курганинск, Крупской, 1	f	large
19891	44722	1014	Краснодарский край, хутор Кура-Цеце, Октябрьская, 20, телефон: 4-85-62	t	small
19775	44604	712	Краснодарский край, хутор Кубань, Центральная, 14, телефон: 52191	f	small
20701	45523	2616	Краснодарский край, Крымск, Темченко, 18	f	large
20690	45512	2605	Краснодарский край, Крымск, Свердлова, 65	f	large
20695	45517	2610	Краснодарский край, Крымск, Ленина, 31	f	large
20702	45524	2617	Краснодарский край, Крымск, Жукова, 35	f	large
20706	45528	2621	Краснодарский край, Крымск, Авиационная, 2	f	large
20618	45441	2405	Краснодарский край, Кропоткин, Черноморская, 79	f	large
20648	45471	2435	Краснодарский край, Кропоткин, С.Целых, 258	f	large
20622	45445	2409	Краснодарский край, Кропоткин, Пушкина, 79	f	large
20614	45437	2401	Краснодарский край, Кропоткин, Пушкина, 82	f	large
20616	45439	2403	Краснодарский край, Кропоткин, Мира, 146	f	large
20632	45455	2419	Краснодарский край, Кропоткин, Линейная, 13	f	large
20631	45454	2418	Краснодарский край, Кропоткин, Красная, 164	f	large
20629	45452	2416	Краснодарский край, Кропоткин, Красная, 166	f	large
20627	45450	2414	Краснодарский край, Кропоткин, Красная, 234	f	large
20626	45449	2413	Краснодарский край, Кропоткин, Красная, 234	f	large
20452	45283	2168	Краснодарский край, Краснодар, поселок Пригородный, Сербская, 7, телефон: 2607677	f	medium
20356	45190	2036	Краснодарский край, Краснодар, улица космонавта Гагарина, 135к1	f	large
21834	46646	5103	Краснодарский край, Краснодар, улица Энгельса, 96	f	medium
20360	45194	2040	Краснодарский край, Краснодар, улица Энгельса, 57	f	large
20521	45348	2265	Калужская область, Калуга, улица Широкая	f	large
20479	45308	2223	Краснодарский край, Краснодар, улица Центральная, 16/2	f	medium
20348	45182	2028	Краснодарский край, Краснодар, улица Федора Лузана, 1	f	large
20362	45196	2042	Краснодарский край, Краснодар, улица Урицкого, 185	f	large
20439	45271	2155	Краснодарский край, Краснодар, улица Трудовой Славы, 28	f	large
19463	44291	135	Челябинская область, Челябинск, улица Труда	f	small
20471	45300	2215	Краснодарский край, Краснодар, улица Тепличная, 16	f	large
20512	45339	2256	Краснодарский край, Краснодар, улица Темрюкская, 68	f	large
20150	44982	1704	Краснодарский край, Краснодар, улица Таманская, 184	f	large
22043	46847	5624	Краснодарский край, Краснодар, улица Степная, 65, телефон: 75-6-32	f	medium
20561	45388	2312	Краснодарский край, Краснодар, улица Ставропольская, 236	f	large
20385	45219	2101	Краснодарский край, Краснодар, улица Ставропольская, 123г	f	large
20430	45262	2146	Краснодарский край, Краснодар, улица Сормовская, 187	f	large
20429	45261	2145	Краснодарский край, Краснодар, улица Сормовская, 187	f	large
20510	45337	2254	Краснодарский край, Краснодар, улица Славянская, 65	f	large
20990	45816	3201	Ленинградская область, Выборгский район, посёлок Рощино, Садовая улица, 3	t	small
20350	45184	2030	Краснодарский край, Краснодар, улица Рашпилевская, 341	f	large
21515	46327	4416	республика Мордовия, Саранск, улица Пугачева, 15	f	large
20416	45249	2132	Краснодарский край, Краснодар, поселок Знаменский, улица Первомайская, 20	f	large
21042	45867	3253	Ленинградская область, Выборгский район, посёлок Советский, станция Советский	f	large
20328	45160	2008	Краснодарский край, Краснодар, Западный район, улица Октябрьская, 67	f	large
20591	45415	2342	Краснодарский край, Краснодар, улица Московская, 2	f	large
20417	45250	2133	Краснодарский край, Краснодар, улица Молодежная, 37	f	large
20577	45402	2328	Краснодарский край, Краснодар, Центральный район, улица Мира, 52	f	large
22049	46853	5630	республика Коми, Сыктывкар, улица Ленина, 28	f	large
21959	46766	5350	республика Коми, Сыктывкар, улица Ленина, 6	f	small
21302	46119	4112	Саратовская область, Саратов, станция Площадь Ленина	f	large
20254	45084	1856	Ростовская область, Дубовский район, хутор Верхний Жиров	t	small
19859	44690	920	республика Коми, Сыктывкар, улица Ленина, 38	f	large
19956	44788	1142	Краснодарский край, Краснодар, улица Ленина, 36к2, здание клуба	t	medium
21822	46636	5052	Ростовская область, Куйбышевский район, хутор Ленинский	f	large
20517	45344	2261	Краснодарский край, Краснодар, улица Красная, 8	f	large
20477	45306	2221	Краснодарский край, Краснодар, улица Карякина, 8	f	large
20325	45157	2005	Краснодарский край, Краснодар, улица Индустриальная, 68	f	large
20459	45288	2203	Краснодарский край, Краснодар, улица Заречная, 1	t	small
20483	45312	2227	Краснодарский край, Краснодар, улица Дорожная, 1	f	large
20154	44986	1708	Краснодарский край, Краснодар, улица Длинная, 180	f	large
20550	45377	2301	Краснодарский край, Краснодар, улица Воронежская, 47	f	large
20603	45427	2354	Краснодарский край, Краснодар, улица Володарского, 5	f	large
20559	45386	2310	Краснодарский край, Краснодар, улица Бургасская, 29	f	large
83919	57339	3114	Москва, Зеленоград, к509	f	large
20554	45381	2305	Краснодарский край, Краснодар, улица Бургасская, 65	f	large
20507	45334	2251	Краснодарский край, Краснодар, улица Атарбекова, 5	f	large
20453	45284	2169	Краснодарский край, Краснодар, улица Андреевская, 1, телефон: 2609399	f	large
20370	45204	2050	Краснодарский край, Краснодар, улица 70-летия Октября, 30	f	large
20469	45298	2213	Краснодарский край, Краснодар, Прикубанский район, улица 1-го Мая, 298а	f	large
20367	45201	2047	Краснодарский край, Краснодар, им. 70-летия Октября, 28	f	large
20498	45325	2242	Краснодарский край, Краснодар, Яна Полуяна, 40	f	large
20497	45325	2241	Краснодарский край, Краснодар, Яна Полуяна, 40	f	large
20496	45324	2240	Краснодарский край, Краснодар, Яна Полуяна, 40	f	large
22042	45899	5623	Краснодарский край, Краснодар, Южная	f	small
20361	45195	2041	Краснодарский край, Краснодар, Энгельса, 57	f	large
21962	46769	5353	Краснодарский край, Краснодар, Школьная, 10	f	small
20568	45394	2319	Краснодарский край, Краснодар, Шевченко, 2	f	large
20567	45393	2318	Краснодарский край, Краснодар, Шевченко, 56	f	large
20407	45240	2123	Краснодарский край, Краснодар, Шевченко, 56	f	large
20406	45240	2122	Краснодарский край, Краснодар, Шевченко, 56	f	large
20332	45165	2012	Краснодарский край, Краснодар, Чкалова, 75	f	large
20377	45211	2057	Краснодарский край, Краснодар, Чекистов проспект, 18	f	large
20376	45210	2056	Краснодарский край, Краснодар, Чекистов проспект, 31	f	large
20366	45200	2046	Краснодарский край, Краснодар, Чекистов проспект, 18	f	large
20365	45199	2045	Краснодарский край, Краснодар, Чекистов проспект, 18	f	large
20579	45404	2330	Краснодарский край, Краснодар, Чапаева, 85/1	f	large
20586	45410	2337	Краснодарский край, Краснодар, Хакурате, 5	f	large
20585	45410	2336	Краснодарский край, Краснодар, Хакурате, 5	f	large
20515	45342	2259	Краснодарский край, Краснодар, Филатова, здание корпуса КМЦУ ГНУ КНИИСХ Россельхозакадемии, центральная усадьба	f	large
20458	45287	2202	Краснодарский край, Краснодар, Филатова, 17	f	large
20349	45183	2029	Краснодарский край, Краснодар, Федора Лузана, 1	f	large
20455	45244	2171	Краснодарский край, Краснодар, Фадеева, 329	f	large
20411	45244	2127	Краснодарский край, Краснодар, Фадеева, 329	f	large
20540	45367	2284	Краснодарский край, Краснодар, Уссурийская, 2	f	large
20532	45359	2276	Краснодарский край, Краснодар, Уссурийская, 2	f	large
20470	45299	2214	Краснодарский край, Краснодар, Уссурийская, 2	f	large
20450	45282	2166	Краснодарский край, Краснодар, Уральская, 196	f	large
20418	45251	2134	Краснодарский край, Краснодар, Уральская, 121	f	large
20352	45186	2032	Краснодарский край, Краснодар, Тургенева, 140	f	large
20440	45272	2156	Краснодарский край, Краснодар, Трудовой Славы, 28	f	large
20542	45369	2286	Краснодарский край, Краснодар, Тепличная, 11	f	large
20528	45355	2272	Краснодарский край, Краснодар, Тепличная, 11	f	large
20511	45338	2255	Краснодарский край, Краснодар, Темрюкская, 68	f	large
20566	45392	2317	Краснодарский край, Краснодар, Таманская, 137	f	large
20347	45181	2027	Краснодарский край, Краснодар, Строителей бульвар, 29	f	large
20473	45302	2217	Краснодарский край, Краснодар, Степная, 10	f	large
20565	45387	2316	Краснодарский край, Краснодар, Степана Разина, 51	f	large
20560	45387	2311	Краснодарский край, Краснодар, Степана Разина, 51	f	large
20456	45285	2172	Краснодарский край, Краснодар, Стасова, 175	f	large
20399	45233	2115	Краснодарский край, Краснодар, Стасова, 175	f	large
20393	45227	2109	Краснодарский край, Краснодар, Стасова, 167	f	large
20392	45226	2108	Краснодарский край, Краснодар, Старокубанская, 127	f	large
20569	45395	2320	Краснодарский край, Краснодар, Ставропольская, 130	f	large
20389	45223	2105	Краснодарский край, Краснодар, Ставропольская, 149	f	large
20386	45220	2102	Краснодарский край, Краснодар, Ставропольская, 123г	f	large
20449	45281	2165	Краснодарский край, Краснодар, Сормовская, 25	f	large
20432	45264	2148	Краснодарский край, Краснодар, Сормовская, 199	f	large
20431	45263	2147	Краснодарский край, Краснодар, Сормовская, 199	f	large
20425	45257	2141	Краснодарский край, Краснодар, Сормовская, 167	f	large
20424	45256	2140	Краснодарский край, Краснодар, Сормовская, 171	f	large
20423	45255	2139	Краснодарский край, Краснодар, Сормовская, 171	f	large
20420	45253	2136	Краснодарский край, Краснодар, Сормовская, 169	f	large
111563	57339	3113	Москва, Зеленоград, к509	f	medium
20419	45252	2135	Краснодарский край, Краснодар, Сормовская, 169	f	large
20454	45237	2170	Краснодарский край, Краснодар, Сормовская, 107	f	large
20403	45237	2119	Краснодарский край, Краснодар, Сормовская, 107	f	large
20402	45236	2118	Краснодарский край, Краснодар, Сормовская, 25	f	large
20401	45235	2117	Краснодарский край, Краснодар, Сормовская, 12/6	f	large
20400	45234	2116	Краснодарский край, Краснодар, Сормовская, 5к1	f	large
20523	45350	2267	Краснодарский край, Краснодар, Советская, 62	f	large
20522	45349	2266	Краснодарский край, Краснодар, Советская, 26	f	large
20527	45354	2271	Краснодарский край, Краснодар, Славянская, 63	f	large
20509	45336	2253	Краснодарский край, Краснодар, Славянская, 63	f	large
20508	45335	2252	Краснодарский край, Краснодар, Славянская, 28	f	large
20395	45229	2111	Краснодарский край, Краснодар, Селезнева, 4	f	large
20394	45228	2110	Краснодарский край, Краснодар, Селезнева, 86	f	large
20390	45224	2106	Краснодарский край, Краснодар, Селезнева, 242	f	large
20596	45420	2347	Краснодарский край, Краснодар, Северная, 309	f	large
20338	45171	2018	Краснодарский край, Краснодар, Северная, 269	f	large
20336	45169	2016	Краснодарский край, Краснодар, Северная, 255	f	large
20558	45385	2309	Краснодарский край, Краснодар, Свободная, 51	f	large
20555	45382	2306	Краснодарский край, Краснодар, Свободная, 51	f	large
20597	45421	2348	Краснодарский край, Краснодар, Садовая, 112	f	large
20593	45417	2344	Краснодарский край, Краснодар, Садовая, 245	f	large
20404	45238	2120	Краснодарский край, Краснодар, Садовая, 11	f	large
20357	45191	2037	Краснодарский край, Краснодар, Рылеева, 147	f	large
20466	45295	2210	Краснодарский край, Краснодар, Российская, 132	f	large
20464	45293	2208	Краснодарский край, Краснодар, Российская, 10	f	large
20460	45289	2204	Краснодарский край, Краснодар, Российская, 10	f	large
20537	45364	2281	Краснодарский край, Краснодар, Репина проезд, 5	f	large
20351	45185	2031	Краснодарский край, Краснодар, Рашпилевская, 329	f	large
20341	45174	2021	Краснодарский край, Краснодар, Рашпилевская, 134	f	large
21689	46503	4818	Краснодарский край, Краснодар, Псурцева, 20, телефон: 6 91 72	f	large
20371	45205	2051	Краснодарский край, Краснодар, Платановый бульвар, 3	f	large
20369	45203	2049	Краснодарский край, Краснодар, Платановый бульвар, 3	f	large
20563	45390	2314	Краснодарский край, Краснодар, Пионерская, 38	f	large
20324	45156	2004	Краснодарский край, Краснодар, Песчаная, 14	f	large
20321	45153	2001	Краснодарский край, Краснодар, Песчаная, 14	f	large
20600	45424	2351	Краснодарский край, Краснодар, Пашковская, 146	f	large
20326	45158	2006	Краснодарский край, Краснодар, Октябрьская, 25 А	f	large
20323	45155	2003	Краснодарский край, Краснодар, Октябрьская, 1	f	large
20342	45175	2022	Краснодарский край, Краснодар, Одесская, 25	f	large
20397	45231	2113	Краснодарский край, Краснодар, Новгородская, 16	f	large
20396	45230	2112	Краснодарский край, Краснодар, Новгородская, 16	f	large
20592	45416	2343	Краснодарский край, Краснодар, Московская, 2	f	large
20475	45304	2219	Краснодарский край, Краснодар, Московская, 42	f	large
20602	45426	2353	Краснодарский край, Краснодар, Митрофана Седина, 38	f	large
20574	45399	2325	Краснодарский край, Краснодар, Мира, 65	f	large
20933	45757	3021	Краснодарский край, Краснодар, Мира, 13, телефон: 4-56-60	f	large
20282	45112	1927	Краснодарский край, Краснодар, Мира, 15, телефон: 91-3-79	f	large
19889	44720	1012	Краснодарский край, Краснодар, Мира, 34 А, телефон: 4-65-10	t	small
20364	45198	2044	Краснодарский край, Краснодар, Минская, 126	f	large
20363	45197	2043	Краснодарский край, Краснодар, Минская, 126	f	large
20590	45414	2341	Краснодарский край, Краснодар, Механическая, 15/1	f	large
20564	45391	2315	Краснодарский край, Краснодар, Майкопская, 70	f	large
20562	45389	2313	Краснодарский край, Краснодар, Майкопская, 70	f	large
20482	45311	2226	Краснодарский край, Краснодар, Лунная, 1, 2 отд СКЗНИИСиВ	f	large
20524	45351	2268	Краснодарский край, Краснодар, Ленина, 52	f	large
20595	45419	2346	Краснодарский край, Краснодар, Леваневского, 187	f	large
20582	45407	2333	Краснодарский край, Краснодар, Леваневского, 82	f	large
20519	45346	2263	Краснодарский край, Краснодар, Курганная, 136	f	large
20598	45422	2349	Краснодарский край, Краснодар, Кузнечная, 167	f	large
20533	45360	2277	Краснодарский край, Краснодар, Красных Партизан, 135	f	large
20581	45406	2332	Краснодарский край, Краснодар, Красноармейская, 70	f	large
20578	45403	2329	Краснодарский край, Краснодар, Красноармейская, 52	f	large
20587	45411	2338	Краснодарский край, Краснодар, Красная, 186	f	large
20330	45162	2010	Краснодарский край, Краснодар, Красная, 55	f	large
20329	45161	2009	Краснодарский край, Краснодар, Красная, 31	f	large
20354	45188	2034	Краснодарский край, Краснодар, Котовского, 100	f	large
20353	45187	2033	Краснодарский край, Краснодар, Котовского, 100	f	large
20487	45316	2231	Краснодарский край, Краснодар, Кореновская, 35	f	large
20486	45315	2230	Краснодарский край, Краснодар, Кореновская, 33	f	large
20485	45314	2229	Краснодарский край, Краснодар, Кореновская, 3	f	large
20327	45159	2007	Краснодарский край, Краснодар, Комсомольская, 46	f	large
20481	45310	2225	Краснодарский край, Краснодар, Коммунаров, 203, здание конторы МУП совхоз Прогресс	f	large
20594	45418	2345	Краснодарский край, Краснодар, Колхозная, 9	f	large
20589	45413	2340	Краснодарский край, Краснодар, Колхозная, 71	f	large
20588	45412	2339	Краснодарский край, Краснодар, Колхозная, 71	f	large
20359	45193	2039	Краснодарский край, Краснодар, Кожевенная, 42	f	large
20495	45323	2239	Краснодарский край, Краснодар, Ковалева, 6	f	large
20333	45166	2013	Краснодарский край, Краснодар, Кирова, 79	f	large
20331	45164	2011	Краснодарский край, Краснодар, Кирова, 79	f	large
20544	45371	2288	Краснодарский край, Краснодар, Карякина, 8	f	large
20476	45305	2220	Краснодарский край, Краснодар, Карякина, 8	f	large
20530	45357	2274	Краснодарский край, Краснодар, Калинина, 13	f	large
20513	45340	2257	Краснодарский край, Краснодар, Калинина, 13	f	large
20358	45192	2038	Краснодарский край, Краснодар, Калинина, 233	f	large
20599	45423	2350	Краснодарский край, Краснодар, Казачья, 16	f	large
20572	45396	2323	Краснодарский край, Краснодар, КИМ, 17	f	large
20570	45396	2321	Краснодарский край, Краснодар, КИМ, 17	f	large
20436	45268	2152	Краснодарский край, Краснодар, Игнатова, 49	f	large
20435	45267	2151	Краснодарский край, Краснодар, Игнатова, 49	f	large
21361	46176	4201	Краснодарский край, Славянский район, Зеленского, 10	f	large
20538	45365	2282	Краснодарский край, Краснодар, Звездная, 5	f	large
20322	45154	2002	Краснодарский край, Краснодар, Захарова, 7	f	large
20573	45398	2324	Краснодарский край, Краснодар, Железнодорожная, 8	f	large
20478	45307	2222	Краснодарский край, Краснодар, поселок Березовый, Ейское шоссе, 18	f	large
20412	45245	2128	Краснодарский край, Краснодар, Евдокии Бершанской, 372	f	large
20409	45242	2125	Краснодарский край, Краснодар, Евдокии Бершанской, 220	f	large
20405	45239	2121	Краснодарский край, Краснодар, Евдокии Бершанской, 19а	f	large
20372	45206	2052	Краснодарский край, Краснодар, Думенко, 31	f	large
20536	45363	2280	Краснодарский край, Краснодар, Дорожная, 1	f	large
20601	45425	2352	Краснодарский край, Краснодар, Дмитриевская Дамба, 3	f	large
20448	45280	2164	Краснодарский край, Краснодар, Димитрова, 172	f	large
20388	45222	2104	Краснодарский край, Краснодар, Димитрова, 170	f	large
20345	45178	2025	Краснодарский край, Краснодар, Дзержинского, 24	f	large
20343	45176	2023	Краснодарский край, Краснодар, Дзержинского, 24	f	large
20580	45405	2331	Краснодарский край, Краснодар, Горького, 173	f	large
20410	45243	2126	Краснодарский край, Краснодар, Гоголя, 60/2	f	large
20408	45241	2124	Краснодарский край, Краснодар, Гоголя, 17	f	large
20443	45275	2159	Краснодарский край, Краснодар, Гидростроителей, 41	f	large
20451	45275	2167	Краснодарский край, Краснодар, Гидростроителей, 41	f	large
20441	45274	2157	Краснодарский край, Краснодар, Гидростроителей, 20	f	large
20442	45274	2158	Краснодарский край, Краснодар, Гидростроителей, 20	f	large
20489	45318	2233	Краснодарский край, Краснодар, Гастелло, 26	f	large
20488	45317	2232	Краснодарский край, Краснодар, Гастелло, 26	f	large
20504	45331	2248	Краснодарский край, Краснодар, Воровского, 229	f	large
20503	45330	2247	Краснодарский край, Краснодар, Воровского, 229	f	large
20502	45329	2246	Краснодарский край, Краснодар, Воровского, 229	f	large
20500	45327	2244	Краснодарский край, Краснодар, Воровского, 237	f	large
20398	45232	2114	Краснодарский край, Краснодар, Волжская, 39	f	large
20571	45397	2322	Краснодарский край, Краснодар, Вишняковой, 3/5	f	large
20434	45266	2150	Краснодарский край, Краснодар, Василия Мачуги, 80	f	large
20433	45265	2149	Краснодарский край, Краснодар, Василия Мачуги, 78, телефон: 2666434	f	large
20516	45343	2260	Краснодарский край, Краснодар, Вавилова, 21	f	large
20557	45384	2308	Краснодарский край, Краснодар, Бургасская, 29	f	large
20556	45383	2307	Краснодарский край, Краснодар, Бургасская, 65	f	large
20374	45208	2054	Краснодарский край, Краснодар, Бульварное Кольцо, 22	f	large
20447	45279	2163	Краснодарский край, Краснодар, Буковая, 2	f	large
20335	45168	2015	Краснодарский край, Краснодар, Буденного, 107	f	large
20438	45270	2154	Краснодарский край, Краснодар, Благоева, 22	f	large
20437	45269	2153	Краснодарский край, Краснодар, Благоева, 22	f	large
20339	45172	2019	Краснодарский край, Краснодар, Бабушкина, 307	f	large
20506	45333	2250	Краснодарский край, Краснодар, Атарбекова, 26	f	large
20505	45332	2249	Краснодарский край, Краснодар, Атарбекова, 26	f	large
20499	45326	2243	Краснодарский край, Краснодар, Атарбекова, 52	f	large
20378	45212	2058	Краснодарский край, Краснодар, Алма-Атинская, 2	f	large
21500	46312	4401	Краснодарский край, Краснодар, Алексеевская, 20	f	small
20375	45209	2055	Краснодарский край, Краснодар, 70-летия Октября, 28	f	large
20368	45202	2048	Краснодарский край, Краснодар, 70-летия Октября, 30	f	large
20467	45296	2211	Краснодарский край, Краснодар, 40-летия Победы, 33	f	large
20428	45260	2144	Краснодарский край, Краснодар, 30-й Иркутской Дивизии, 1	f	large
20427	45259	2143	Краснодарский край, Краснодар, 30-й Иркутской Дивизии, 1	f	large
20426	45258	2142	Краснодарский край, Краснодар, 30-й Иркутской Дивизии, 1	f	large
20514	45341	2258	Краснодарский край, Краснодар, 2-я Линия, 49	f	large
20552	45379	2303	Краснодарский край, Краснодар, 2-й Стасова проезд, 54	f	large
20551	45378	2302	Краснодарский край, Краснодар, 2-й Стасова проезд, 48	f	large
20387	45221	2103	Краснодарский край, Краснодар, 2-й Пятилетки, 12, телефон: 2337415	f	large
20340	45173	2020	Краснодарский край, Краснодар, 2-й Гаражный проезд, 3	f	large
20535	45362	2279	Краснодарский край, Краснодар, 1-го Мая, 298а	f	large
20472	45301	2216	Краснодарский край, Краснодар, 1-го Мая, 580/3	f	large
20465	45294	2209	Краснодарский край, Краснодар, 1-го Мая, 99	f	large
20463	45292	2207	Краснодарский край, Краснодар, 1-го Мая, 93	f	large
20414	45247	2130	Краснодарский край, Краснодар, 1-го Мая, 65	f	large
20413	45246	2129	Краснодарский край, Краснодар, 1-го Мая, 65	f	large
21961	46768	5352	Краснодарский край, Краснодар, Школьная, 10, телефон: 96015	f	medium
20539	45366	2283	Краснодарский край, Краснодар, Школьная, 15/6	f	large
20531	45358	2275	Краснодарский край, Краснодар, Школьная, 15/6	f	large
20457	45286	2201	Краснодарский край, Краснодар, Школьная, 15к6	f	large
20494	45322	2238	Краснодарский край, Краснодар, Тургенева, 195	f	large
20493	45321	2237	Краснодарский край, Краснодар, Тургенева, 195	f	large
20492	45320	2236	Краснодарский край, Краснодар, Тургенева, 217	f	large
20553	45380	2304	Краснодарский край, Краснодар, Старокубанская, 88к4	f	large
20391	45225	2107	Краснодарский край, Краснодар, Старокубанская, 127	f	large
20422	45254	2138	Краснодарский край, Краснодар, Сормовская, 114	f	large
20421	45254	2137	Краснодарский край, Краснодар, Сормовская, 114	f	large
20583	45408	2334	Краснодарский край, Краснодар, Седина, 168	f	large
20605	45428	2356	Краснодарский край, Краснодар, Северная, 564	f	large
20604	45428	2355	Краснодарский край, Краснодар, Северная, 564	f	large
20337	45170	2017	Краснодарский край, Краснодар, Северная, 269	f	large
20415	45248	2131	Краснодарский край, Краснодар, Рязанская, 12	f	large
20462	45291	2206	Краснодарский край, Краснодар, Ростовская, 14	f	large
20461	45290	2205	Краснодарский край, Краснодар, Ростовская, 14	f	large
20576	45401	2327	Краснодарский край, Краснодар, Красноармейская, 2	f	large
20575	45400	2326	Краснодарский край, Краснодар, Красноармейская, 7	f	large
20334	45167	2014	Краснодарский край, Краснодар, Красная, 87/89	f	large
20355	45189	2035	Краснодарский край, Краснодар, Котовского, 100	f	large
20543	45370	2287	Краснодарский край, Краснодар, Зиповская, 12	f	large
20518	45345	2262	Краснодарский край, Краснодар, Звездная, 10	f	large
20541	45368	2285	Краснодарский край, Краснодар, Восточно-Кругликовская, 49	f	large
20373	45207	2053	Краснодарский край, Краснодар, Бульварное Кольцо, 22	f	large
20584	45409	2335	Краснодарский край, Краснодар, Буденного, 161	f	large
111562	57339	3112	Москва, Зеленоград, к509	f	medium
20344	45177	2024	Краснодарский край, Краснодар, Брянская, 6	f	large
20346	45179	2026	Краснодарский край, Краснодар, Бакинская, 5	f	large
20501	45328	2245	Краснодарский край, Краснодар, Атарбекова, 42	f	large
20468	45297	2212	Краснодарский край, Краснодар, 40-летия Победы, 33	f	large
20201	45033	1803	Краснодарский край, Кореновск, Выселковская, 29А	f	large
20199	45031	1801	Краснодарский край, Кореновск, Матросова, 11, телефон: 4-25-02	f	large
22047	46851	5628	Краснодарский край, хутор Калининский, Школьная, 14	f	small
20529	45356	2273	Краснодарский край, поселок Индустриальный, Степная, 10	f	large
19896	44727	1019	Краснодарский край, станица Имеретинская, Ленина, 18	f	large
20520	45347	2264	Краснодарский край, поселок Елизаветовская, Ленина, 276	f	large
20071	44903	1413	Краснодарский край, Ейск, Рабочая, 2А	f	large
20072	44904	1414	Краснодарский край, Ейск, Одесская, 261	f	large
20091	44923	1433	Краснодарский край, Ейск, Коммунистическая, 67	f	large
20061	44894	1403	Краснодарский край, Ейск, Калинина, 279а	f	large
19927	44758	1113	Краснодарский край, Гулькевичи, Гражданская площадь, 17, здание МОУ СОШ № 4	f	medium
19919	44750	1105	Краснодарский край, Гулькевичи, Братская, 2, здание МАОУ СОШ № 1	f	large
19721	44549	631	Краснодарский край, поселок Грушевый, Речная, 4	f	medium
20781	45605	2731	Краснодарский край, Горячий Ключ, поселок Первомайский, Школьная, 1, телефон: 6-68-48	f	small
21686	46499	4815	Рязанская область, Рязань, поселок Мирный	t	small
19909	44740	1032	Краснодарский край, Горячий Ключ, станица Саратовская, здание сельского клуба военного совхоза, телефон: 3-20-56	f	small
21032	45857	3243	Краснодарский край, Горячий Ключ, поселок Веселый, 11	f	small
19886	44717	1009	Краснодарский край, Горячий Ключ, Ярославского, 109, телефон: 4-31-34	f	large
20284	45115	1929	Краснодарский край, Горячий Ключ, Школьная, 5, телефон: 91-6-18	f	large
134654	94980	1033	Краснодарский край, Горячий Ключ, Хадыженская, 28 Б	f	large
19885	44715	1008	Краснодарский край, Горячий Ключ, Советская, 98, телефон: 3-72-89	f	large
19913	44744	1036	Краснодарский край, Горячий Ключ, Псекупская, 2, телефон: 3-50-33	f	small
19900	44731	1023	Краснодарский край, Горячий Ключ, Парковая, 8	f	medium
19911	44742	1034	Краснодарский край, Горячий Ключ, Ленина, 195, телефон: 3-46-72	f	large
19884	44714	1007	Краснодарский край, Горячий Ключ, Ленина, 203, телефон: 3-81-49	f	large
19883	44713	1006	Краснодарский край, Горячий Ключ, Ленина, 185 А	f	large
19881	44711	1004	Краснодарский край, Горячий Ключ, Ленина, 137, телефон: 3-44-71	f	large
19880	44710	1003	Краснодарский край, Горячий Ключ, Ленина, 35, телефон: 3-40-41	f	large
19879	44709	1002	Краснодарский край, Горячий Ключ, Ленина, 26	f	large
19906	44737	1029	Краснодарский край, Горячий Ключ, Ленина, 27 А, телефон: 5-86-34	f	small
19882	44712	1005	Краснодарский край, Горячий Ключ, Кучерявого, 42, телефон: 4-29-58	f	large
19907	44738	1030	Краснодарский край, Горячий Ключ, Космонавтов, 20, телефон: 5-94-49, хутор Молькин	f	small
19878	44708	1001	Краснодарский край, Горячий Ключ, Кондратьева, 70, телефон: 4-27-19	f	large
19887	44718	1010	Краснодарский край, Горячий Ключ, Заводская, 37, телефон: 4-61-62	f	large
19888	44719	1011	Краснодарский край, Горячий Ключ, Вокзальная, 6, телефон: 4-48-91	f	medium
19848	44679	909	Краснодарский край, Геленджик, улица Кирова, 66	f	large
19845	44676	906	Краснодарский край, Геленджик, улица Калинина, 33а	f	large
19867	44698	928	Краснодарский край, Геленджик, Черноморская, 18	f	small
19855	44686	916	Краснодарский край, Геленджик, Туристическая, 19	f	large
19851	44682	912	Краснодарский край, Геленджик, Толстого, 19	f	large
19857	44688	918	Краснодарский край, Геленджик, Солнечная, 3	f	large
19842	44673	903	Краснодарский край, Геленджик, Полевая, 2	f	large
19872	44702	933	Краснодарский край, Геленджик, Подгорная, 6	f	small
19846	44677	907	Краснодарский край, Геленджик, Первомайская улица, 37	f	large
19847	44678	908	Краснодарский край, Геленджик, Первомайская, 4	f	large
19843	44674	904	Краснодарский край, Геленджик, Парус, 25	f	large
19850	44681	911	Краснодарский край, Геленджик, Островского, 141а	f	large
19849	44680	910	Краснодарский край, Геленджик, Нахимова, 2	f	large
19854	44685	915	Краснодарский край, Геленджик, Маячная, 3	f	large
19852	44683	913	Краснодарский край, Геленджик, Луначарского, 95	f	large
19853	44684	914	Краснодарский край, Геленджик, Ленина, 22	f	large
19873	44703	934	Краснодарский край, Геленджик, Ленина, 33а	f	medium
19844	44675	905	Краснодарский край, Геленджик, Курзальная, 12	f	large
67958	44671	901	Краснодарский край, Геленджик, Крымская улица, 15	f	large
19841	44672	902	Краснодарский край, Геленджик, Красногвардейская, 38	f	large
67959	44689	919	Краснодарский край, Геленджик, Взлетная, 39	f	large
19856	44687	917	Краснодарский край, Геленджик, мкр. Северный, 55, телефон: 26867	f	large
22053	46857	5634	Краснодарский край, поселок Вимовец, Батохина, 4-А, телефон: 34-1-69	f	large
21242	46059	3931	Краснодарский край, поселок Веселая Жизнь, Северная, 26 А, телефон: 4-26-31	t	small
20480	45309	2224	Краснодарский край, поселок Березовый, 19/2, телефон: 274-79-57	f	large
20534	45361	2278	Краснодарский край, поселок Березовый, Целиноградская, 1	f	large
20947	45771	3035	Краснодарский край, Белый, Горького, 234	f	large
19709	44538	619	Краснодарский край, Белореченск, переулок Коммунальный, 2	f	large
19705	44534	615	Краснодарский край, Белореченск, Толстого, 138	f	large
19691	44519	601	Краснодарский край, Белореченск, Мостовая, 75	f	medium
19708	44537	618	Краснодарский край, Белореченск, Мира, 106	f	medium
19702	44531	612	Краснодарский край, Белореченск, Калинина, 260	f	large
19712	44541	622	Краснодарский край, Белореченск, Аэродромная, 15	f	medium
19893	44724	1016	Краснодарский край, поселок Безымянное, Таманская, 80, телефон: 5-35-21	f	medium
19901	44732	1024	Краснодарский край, поселок Бакинская, Горбунова, 1, телефон: 5-89-45	f	large
19661	44489	466	Краснодарский край, Армавир, п.Южный, Мичурина, 6, телефон: 49850	t	small
110994	44444	464	Краснодарский край, Армавир п.ВНИИМК, здание клуба	f	medium
19665	44493	470	Краснодарский край, Армавир, Центральная усадьба совхоза Юбилейный	f	small
19618	44448	423	Краснодарский край, Армавир, пос.Мясокомбинат, 9-а, телефон: 36606	f	large
19596	44425	401	Краснодарский край, Армавир, Шоссейная, 63, телефон: 45865	f	large
19636	44465	441	Краснодарский край, Армавир, Шмидта, 132, телефон: 57419	f	large
19615	44445	420	Краснодарский край, Армавир, Чехова, 46	f	large
19646	44475	451	Краснодарский край, Армавир, Черноморская, 8, телефон: 27257	f	large
19597	44426	402	Краснодарский край, Армавир, Центральная, 1, телефон: 33203	f	large
19666	44494	471	Краснодарский край, Армавир, Урупская, 1, телефон: 58578	f	large
19620	44450	425	Краснодарский край, Армавир, Урицкого, 106а, телефон: 72652	f	large
67951	44483	459	Краснодарский край, Армавир, Ставропольская, 111, п.Старая Станица	f	large
19653	44482	458	Краснодарский край, Армавир, Ставропольская, 41, телефон: 37846	f	large
19651	44480	456	Краснодарский край, Армавир, Совецкая, 45	f	large
19658	44487	463	Краснодарский край, Армавир, Советской Армии, 214, телефон: 73626	f	large
19641	44470	446	Краснодарский край, Армавир, Советской Армии, 9, телефон: 53820	f	large
19667	44495	472	Краснодарский край, Армавир, Свердлова, 92, телефон: 22012	f	large
67948	44459	434	Краснодарский край, Армавир, Свердлова, 174	f	large
19600	44429	405	Краснодарский край, Армавир, Свердлова, 79, телефон: 37784	f	large
19640	44469	445	Краснодарский край, Армавир, С.Армии, 9-а, телефон: 53621	f	large
19622	44452	427	Краснодарский край, Армавир, С.Армии, 210-а, телефон: 73933	f	large
19607	44436	412	Краснодарский край, Армавир, Розы Люксембург, 233, телефон: 33243	f	large
19606	44435	411	Краснодарский край, Армавир, Р.Люксембург, 166	f	large
19598	44427	403	Краснодарский край, Армавир, Р.Люксембург, 11, телефон: 42485	f	large
19663	44491	468	Краснодарский край, Армавир, Пушкина, 27	f	large
67952	44485	461	Краснодарский край, Армавир, Пушкина, 29	f	large
19652	44481	457	Краснодарский край, Армавир, Песчаная, 40/2, телефон: 30041	f	large
19660	44488	465	Краснодарский край, Армавир, Островского, 162-а, телефон: 54352	f	large
19645	44474	450	Краснодарский край, Армавир, Островского, 179, телефон: 75979	f	large
19613	44442	418	Краснодарский край, Армавир, Октябрьская, 143	f	large
19647	44476	452	Краснодарский край, Армавир, Новороссийская, 102, телефон: 78123	f	large
19644	44473	449	Краснодарский край, Армавир, Новороссийская, 147, телефон: 57299	f	large
19642	44471	447	Краснодарский край, Армавир, Новороссийская, 8	f	large
19639	44468	444	Краснодарский край, Армавир, Новороссийская, 104, телефон: 50713	f	large
19638	44467	443	Краснодарский край, Армавир, Новороссийская, 161	f	large
19610	44439	415	Краснодарский край, Армавир, Мира, 48	f	large
19633	44462	438	Краснодарский край, Армавир, Матвеева, 20, телефон: 23492	f	large
19643	44472	448	Краснодарский край, Армавир, Маркова, 36	f	large
19617	44447	422	Краснодарский край, Армавир, Луначарского, 279, телефон: 35354	f	large
19605	44434	410	Краснодарский край, Армавир, Лермонтова, 93	f	large
19655	44484	460	Краснодарский край, Армавир, Ленинградская, 122	f	large
19611	44440	416	Краснодарский край, Армавир, Ленина, 258, телефон: 33010	f	large
19609	44438	414	Краснодарский край, Армавир, Ленина, 96	f	medium
19601	44430	406	Краснодарский край, Армавир, Ленина, 103, телефон: 39036	f	large
19599	44428	404	Краснодарский край, Армавир, Ленина, 28, телефон: 39023	f	large
19619	44449	424	Краснодарский край, Армавир, Лавриненко, 5-а, телефон: 35200	f	large
19616	44446	421	Краснодарский край, Армавир, Лавриненко, 172-а	f	large
19614	44443	419	Краснодарский край, Армавир, Лавриненко, 1	f	large
19631	44460	436	Краснодарский край, Армавир, Кропоткина, 103, телефон: 20041	f	large
19612	44441	417	Краснодарский край, Армавир, Кочубея, 47, телефон: 33566	f	large
19608	44437	413	Краснодарский край, Армавир, Комсомольская, 136, телефон: 33579	f	large
19657	44486	462	Краснодарский край, Армавир, Комсомольская, 14, хутор Первомайский, телефон: 40009	f	medium
19626	44456	431	Краснодарский край, Армавир, Кирова, 57, телефон: 73496	f	large
19624	44454	429	Краснодарский край, Армавир, Кирова, 127, телефон: 73956	f	large
19623	44453	428	Краснодарский край, Армавир, Кирова, 129, телефон: 73765	f	large
67947	44432	408	Краснодарский край, Армавир, Кирова	f	large
19602	44431	407	Краснодарский край, Армавир, Кирова, 43, телефон: 32487	f	large
19634	44463	439	Краснодарский край, Армавир, Калинина, 32, телефон: 53773	f	large
19628	44458	433	Краснодарский край, Армавир, К.Маркса, 156	f	large
19604	44433	409	Краснодарский край, Армавир, К.Либкнехта, 48, телефон: 32450	f	large
19627	44457	432	Краснодарский край, Армавир, Ефремова, 57	f	large
67949	44392	435	Краснодарский край, Армавир, Ефремова, 123	f	large
67950	44479	455	Краснодарский край, Армавир, Донская, 6б, СПК Восток	f	large
19621	44451	426	Краснодарский край, Армавир, Гоголя, 207, телефон: 46022	f	large
19635	44464	440	Краснодарский край, Армавир, Володарского, 2	f	large
19632	44461	437	Краснодарский край, Армавир, Володарского, 68, телефон: 21709	f	large
19625	44455	430	Краснодарский край, Армавир, Володарского, 120, телефон: 71132	f	large
19664	44492	469	Краснодарский край, Армавир, Академическая, телефон: 27143, п.ВИМ	f	small
19649	44478	454	Краснодарский край, Армавир, Азовская, 20, телефон: 51347	f	large
19648	44477	453	Краснодарский край, Армавир, Азовская, 22, телефон: 78123	f	large
19637	44466	442	Краснодарский край, Армавир, 30 лет Победы, 110, телефон: 27858	f	large
19539	44369	301	Краснодарский край, Апшеронск, Репина, 49/б	f	large
19545	44374	307	Краснодарский край, Апшеронск, Лесозаводская, 78	f	large
19553	44382	315	Краснодарский край, город Апшеронск, Ленина, 224	f	large
19493	44322	223	Краснодарский край, Анапская, Кавказская, 90А 	f	large
19484	44313	214	Краснодарский край, Анапа, 12-й микрорайон, 8	f	large
19479	44307	209	Московская область, Люберецкий район, поселок городского типа Малаховка, улица Некрасова	f	large
19481	44309	211	Краснодарский край, Анапа, улица Ленина, МБОУ СОШ №7, телефон: 45686	f	large
19535	44365	265	Краснодарский край, Анапа, Школьная, 4	f	large
19520	44350	250	Краснодарский край, Анапа, Школьная, 1	f	large
19471	44299	201	Краснодарский край, Анапа, Черноморская, 11	f	large
19513	44343	243	Краснодарский край, Анапа, Центральная, 173	t	small
19486	44315	216	Краснодарский край, Анапа, Тургенева, 261	f	large
19476	44304	206	Краснодарский край, Анапа, Терская, 190	f	large
19503	44332	233	Краснодарский край, Анапа, Таманская, 2В	f	large
19537	44367	267	Краснодарский край, Анапа, Спортивная, 8	f	large
19497	44326	227	Краснодарский край, Анапа, Солнечная, 43	t	small
19498	44327	228	Краснодарский край, Анапа, Свободы, 9А	f	small
19496	44325	226	Краснодарский край, Анапа, Свободы, 10	f	large
19472	44300	202	Краснодарский край, Анапа, Самбурова, 19	f	large
19488	44317	218	Краснодарский край, Анапа, Пионерский проспект, 103	f	medium
19482	44310	212	Краснодарский край, Анапа, Парковая, 29	f	large
19536	44366	266	Краснодарский край, Анапа, Омелькова, 32	f	large
19494	44323	224	Краснодарский край, Анапа, Набережная, 148	f	medium
19504	44333	234	Краснодарский край, Анапа, Мира, 5	f	large
19495	44324	225	Краснодарский край, Анапа, Мира, 46	f	large
19491	44320	221	Краснодарский край, Анапа, Мира, 25	f	large
19502	44331	232	Краснодарский край, Анапа, Лиманная, 8	f	large
19501	44330	231	Краснодарский край, Анапа, Лиманная, 8	f	large
19487	44316	217	Краснодарский край, Анапа, Ленинградская, 75	f	large
19519	44349	249	Краснодарский край, Анапа, Ленина, 159	f	large
19473	44301	203	Краснодарский край, Анапа, Ленина, 125	f	large
19485	44314	215	Краснодарский край, Анапа, Крымская, 209	f	large
19477	44305	207	Краснодарский край, Анапа, Крымская, 179	f	large
19475	44303	205	Краснодарский край, Анапа, Крымская, 115	f	large
19474	44302	204	Краснодарский край, Анапа, Крымская, 122	f	large
19480	44308	210	Краснодарский край, Анапа, Крылова, 18а	f	large
19492	44321	222	Краснодарский край, Анапа, Комсомольская, 75 А	f	large
19507	44336	237	Краснодарский край, Анапа, Коммунаров, 41	f	large
19508	44337	238	Краснодарский край, Анапа, Дружбы, 4	f	medium
19506	44335	236	Краснодарский край, Анапа, Дружбы, 50	f	large
19483	44311	213	Краснодарский край, Анапа, Гребенская, 24, МАОУ СОШ №6, телефон: 35446	f	large
19490	44319	220	Саратовская область, Саратов, улица Астраханская, 88	f	large
19478	44306	208	Краснодарский край, Анапа, Астраханская, 62	f	large
19862	44693	923	Краснодарский край, Адербиевка, Октябрьская, 49	f	medium
111104	46307	4396	Краснодарский край, городской округ Сочи, поселок Эстосадок, ГТС	t	\N
21479	46292	4356	Краснодарский край, городской округ Сочи, поселок Эстосадок	f	small
111108	46310	4398	Краснодарский край, городской округ Сочи, поселок Эстосадок, 2-ая бригада	t	\N
21509	46321	4410	Краснодарский край, городской округ Сочи, поселок Наджиго, Зыхы, 18, телефон: 74-71-96	f	small
111096	46303	4392	Краснодарский край, городской округ Сочи, поселок Монастырь, Пикет № 234	t	\N
111100	46305	4394	Краснодарский край, городской округ Сочи, поселок Красная Поляна, Общество с ограниченной ответственностью ЧЗК-Юг Пикет № 391	t	\N
21476	46289	4353	Краснодарский край, городской округ Сочи, поселок Красная Поляна, Турчинского, 29, телефон: 437479	f	large
111103	46306	4395	Краснодарский край, городской округ Сочи, поселок Красная Поляна, Пикет № 397, БТС-Гидрострой Пикет № 397	t	\N
21478	46291	4355	Краснодарский край, городской округ Сочи, поселок Красная Поляна, Защитников Кавказа	f	small
111093	46301	4390	Краснодарский край, городской округ Сочи, поселок Красная Поляна, 12-й км дороги Адлер - Красная Поляна, Пикет № 125	t	\N
21475	46287	4352	Краснодарский край, городской округ Сочи, поселок Кепша	f	small
21467	46279	4344	Краснодарский край, городской округ Сочи, поселок Калиновое Озеро, Центральная, 10	t	large
21502	46314	4403	Краснодарский край, городской округ Сочи, поселок Калеж, Адыгахабль, 62, телефон: 76-92-30	f	medium
21425	46241	4302	Самарская область, Челно-Вершинский район, село Ермоловка	t	small
19530	44360	260	Краснодарский край, городской округ Сочи, поселок Варваровка, Калинина, 60, телефон: 91651, факс: 91651, email: уик260@mail.ru	f	large
111095	46302	4391	Краснодарский край, городской округ Сочи, поселок Ахштырь, Пикет № 131	t	\N
21426	46242	4303	Краснодарский край, городской округ Сочи, поселок Ахштырь, Кропоткинская, 17а, телефон: 431128	f	small
21424	46240	4301	Краснодарский край, городской округ Сочи, поселок Аибга	t	small
19892	44723	1015	Краснодарский край, городской округ Новороссийск, поселок Широкая Балка, Красная, 3, телефон: 4-86-31	t	small
22146	46948	5924	Краснодарский край, городской округ Новороссийск, поселок Раевская, Нижняя, 3, телефон: 8-918-48-48-354	f	large
22144	46946	5922	Краснодарский край, городской округ Новороссийск, поселок Раевская, Ленина, 27	f	large
22145	46947	5923	Краснодарский край, городской округ Новороссийск, поселок Раевская, Красная, 40, телефон: 27-01-38	f	large
111140	46930	5906	Краснодарский край, городской округ Новороссийск, поселок Глебовское, Чехова, 1	f	medium
22131	46933	5909	Краснодарский край, городской округ Новороссийск, поселок Гайдук, Гагарина, 5, телефон: 26-94-47	f	large
22136	46938	5914	Краснодарский край, городской округ Новороссийск, поселок Верхнебаканский, Титан, 22, телефон: 276228	f	large
22135	46937	5913	Краснодарский край, городской округ Новороссийск, поселок Верхнебаканский, Орловская, 11, телефон: 27-65-23	f	large
22125	46927	5903	Краснодарский край, городской округ Новороссийск, поселок Большие Хутора, Солнечная, 19	f	medium
22123	46925	5901	Краснодарский край, городской округ Новороссийск, поселок Абрау-Дюрсо, Островского, 8, телефон: 27-54-24	f	medium
19876	44706	937	Краснодарский край, городской округ Геленджик, поселок Тешебс, Ленина, телефон: 61321	f	small
19870	44700	931	Краснодарский край, городской округ Геленджик, поселок Пшада, Советская, 26а, телефон: 68343	f	large
19868	44668	929	Краснодарский край, городской округ Геленджик, поселок Прасковеевка, Морская, 12, телефон: 62823	f	small
19869	44699	930	Краснодарский край, городской округ Геленджик, поселок Михайловский Перевал, Школьная, 2	f	large
19861	44692	922	Краснодарский край, городской округ Геленджик, поселок Кабардинка, Революционная, 69, телефон: 65493	f	large
19860	44691	921	Краснодарский край, городской округ Геленджик, поселок Кабардинка, Партизанская, 11, телефон: 65251	f	large
19866	44697	927	Краснодарский край, городской округ Геленджик, поселок Дивноморское, Кирова, 17, телефон: 63252	f	large
19865	44696	926	Краснодарский край, городской округ Геленджик, поселок Дивноморское, Горная, 23	f	large
19871	44701	932	Краснодарский край, городской округ Геленджик, поселок Береговое, Мира, 27	f	medium
19875	44705	936	Краснодарский край, городской округ Геленджик, поселок Архипо-Осиповка, Рабочая, 5, телефон: 61890	f	large
19874	44704	935	Краснодарский край, городской округ Геленджик, поселок Архипо-Осиповка, Ленина, 116, телефон: 60248	f	large
19877	44707	938	Краснодарский край, городской округ Геленджик, поселок Архипо-Осиповка, Красных партизан, 2а	f	large
67988	46893	5710	Краснодарский край, Щербиновский район, поселок Щербиновский, К. Маркса, 12	f	large
22092	46894	5711	Краснодарский край, Щербиновский район, поселок Шабельское, Ленина, 20, телефон: 3-56-36	f	large
22083	46885	5702	Краснодарский край, Щербиновский район, поселок Старощербиновская, Шевченко, 195, телефон: 4-18-09	f	large
22082	46884	5701	Краснодарский край, Щербиновский район, поселок Старощербиновская, Шевченко, 226, телефон: 4-14-11	f	large
22088	46890	5707	Краснодарский край, Щербиновский район, поселок Старощербиновская, Тельмана, 183, телефон: 4-21-80	f	large
22085	46887	5704	Краснодарский край, Щербиновский район, поселок Старощербиновская, Ленина, 170	f	large
22087	46889	5706	Краснодарский край, Щербиновский район, поселок Старощербиновская, Красноармейская, 16, телефон: 4-23-47	f	large
22086	46888	5705	Краснодарский край, Щербиновский район, поселок Старощербиновская, Красная, 3, телефон: 4-44-53	f	large
22084	46886	5703	Краснодарский край, Щербиновский район, станица Старощербиновская, Первомайская, 93	f	large
22089	46891	5708	Краснодарский край, Щербиновский район, поселок Новощербиновская, Советов, 7, телефон: 3-05-34	f	large
22090	46892	5709	Краснодарский край, Щербиновский район, поселок Новощербиновская, Мира, 39, телефон: 3-05-47	f	large
22095	46897	5714	Краснодарский край, Щербиновский район, поселок Николаевка, 2-я Пятилетка, 7	f	large
22098	46900	5717	Краснодарский край, Щербиновский район, поселок Любимов, Мира, 2/2, телефон: 3-31-41	f	small
22099	46901	5718	Краснодарский край, Щербиновский район, поселок Красный Дар, переулок Бригадный, 9	t	small
22096	46898	5715	Краснодарский край, Щербиновский район, поселок Екатериновка, пер. Советов, 22, телефон: 3-83-84	f	large
22097	46899	5716	Краснодарский край, Щербиновский район, поселок Екатериновка, Крестьянская, 5/2, телефон: 3-88-76	f	medium
22094	46896	5713	Краснодарский край, Щербиновский район, поселок Ейское Укрепление, Советов, 2	f	large
22093	46895	5712	Краснодарский край, Щербиновский район, поселок Глафировка, Первомайская, 56	f	large
22054	46858	5635	Краснодарский край, Усть-Лабинский район, поселок Южный, Школьная, 20, телефон: 33-7-06	f	medium
20025	44858	1241	Краснодарский край, Усть-Лабинский район, поселок Южный, Советская, 31, телефон: 44-1-82	t	large
21251	46068	3940	Краснодарский край, Усть-Лабинский район, поселок Южный, Кирова, 41, телефон: 3-75-55	t	small
22022	46827	5603	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Энгельса, 71, телефон: 4-56-08	f	large
22029	46834	5610	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Советская, 56, телефон: 2-31-24	f	large
22057	46861	5638	Краснодарский край, Усть-Лабинский район, поселок Воронежская, Заводская, 115	f	large
22021	46826	5602	Краснодарский край, Усть-Лабинский район, город Усть-Лабинск, Рубина, 30, телефон: 2-24-43	f	large
22040	46845	5621	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Пролетарская, 79, телефон: 4-51-56	f	large
22023	46828	5604	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Пролетарская, 104, телефон: 4-51-70	f	large
22033	46838	5614	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Позиционная, 171, телефон: 2-16-32	f	large
22034	46839	5615	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Островского, 13, телефон: 2-24-00	f	large
22031	46836	5612	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Островского, 63, телефон: 5-18-65	f	large
22030	46835	5611	Краснодарский край, Усть-Лабинский район, город Усть-Лабинск, Октябрьская, 117, телефон: 4-18-52	f	large
22024	46829	5605	Краснодарский край, Усть-Лабинский район, город Усть-Лабинск, Ободовского, 153-А, телефон: 4-51-60	f	large
22028	46833	5609	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Ленина, 62, телефон: 2-35-18	f	medium
22027	46832	5608	Краснодарский край, Усть-Лабинский район, город Усть-Лабинск, Куйбышева, 31, телефон: 2-29-14	f	large
22020	46825	5601	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Комсомольская, 212, телефон: 4-18-67	f	large
22025	46830	5606	Краснодарский край, Усть-Лабинский район, город Усть-Лабинск, Кавказская, 28, телефон: 2-24-04	f	large
22035	46840	5616	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Демьяна Бедного, 101, телефон: 2-16-86	f	large
22037	46842	5618	Краснодарский край, Усть-Лабинский район, Усть-Лабинск, Воронежская, 2-А, телефон: 2-20-86	f	large
22026	46831	5607	Краснодарский край, Усть-Лабинский район, город Усть-Лабинск, Вокзальная, 37, телефон: 2-15-29	f	large
22077	46879	5658	Краснодарский край, Усть-Лабинский район, поселок Тенгинская, Мира, 23	f	large
22075	46877	5656	Краснодарский край, Усть-Лабинский район, поселок Суворовское, Чапаева, 61/1, телефон: 57-4-75	f	small
67943	46878	5657	Краснодарский край, Усть-Лабинский район, поселок Суворовское, Ленина, 80	f	large
22046	46850	5627	Краснодарский край, Усть-Лабинский район, поселок Согласный, Советская, 55	t	small
22048	46852	5629	Краснодарский край, Усть-Лабинский район, поселок Саратовский, Мира, 63-А	t	small
22074	46876	5655	Краснодарский край, Усть-Лабинский район, поселок Новолабинская, Красноармейская, 63, телефон: 36-2-56	f	large
22073	46875	5654	Краснодарский край, Усть-Лабинский район, поселок Новолабинская, Калинина, 12, телефон: 36-2-31	f	large
22070	46872	5651	Краснодарский край, Усть-Лабинский район, поселок Некрасовская, Советская, 8	f	large
22069	46871	5650	Краснодарский край, Усть-Лабинский район, поселок Некрасовская, Ленина, 11	f	large
22063	46865	5644	Краснодарский край, Усть-Лабинский район, поселок Ладожская, Школьная, 17	f	large
22081	46883	5662	Краснодарский край, Усть-Лабинский район, поселок Ладожская, Красная, 98/А	f	large
22067	46869	5648	Краснодарский край, Усть-Лабинский район, поселок Ладожская, Коншиных, 98, телефон: 70-4-33	f	large
67942	46868	5647	Краснодарский край, Усть-Лабинский район, поселок Ладожская, Коншиных, 167-Б	f	large
67941	46866	5645	Краснодарский край, Усть-Лабинский район, поселок Ладожская, Комсомольская, 132	f	large
22079	46881	5660	Краснодарский край, Усть-Лабинский район, поселок Кирпильская, Советская, 2	f	medium
67940	46288	5643	Краснодарский край, Усть-Лабинский район, поселок Кирпильская, Советская, 41	f	large
67939	46126	5642	Краснодарский край, Усть-Лабинский район, поселок Кирпильская, Красная, 45	f	large
22060	46864	5641	Краснодарский край, Усть-Лабинский район, поселок Кирпильская, Кирпильская, Административное здание кирпичного завода	f	small
22071	46873	5652	Краснодарский край, Усть-Лабинский район, поселок Кадухин, Степная, 19	f	small
22058	46862	5639	Краснодарский край, Усть-Лабинский район, поселок Железный, Ленина, 37	f	large
22041	46846	5622	Краснодарский край, Усть-Лабинский район, поселок Двубратский, Пионерская, 2, телефон: 48-2-00	f	large
22052	46856	5633	Краснодарский край, Усть-Лабинский район, поселок Восточная, Школьная, 1	f	large
22056	46860	5637	Краснодарский край, Усть-Лабинский район, поселок Воронежская, Ленина, 60	f	large
22080	46882	5661	Краснодарский край, Усть-Лабинский район, поселок Воронежская, Красная, 112	f	large
83918	57338	3111	Москва, Зеленоград, к344а	f	large
22050	46854	5631	Краснодарский край, Усть-Лабинский район, поселок Болгов, Советская, 110	f	medium
22051	46855	5632	Краснодарский край, Усть-Лабинский район, поселок Болгов, Красная, 53	f	large
22068	46870	5649	Краснодарский край, Усть-Лабинский район, поселок Безлесный, Красная, 64	f	large
22045	46849	5626	Краснодарский край, Усть-Лабинский район, поселок Александровский, Красная, 38	f	large
21998	46806	5504	Краснодарский край, Успенский район, поселок Успенское, Молодежная, 1	f	large
67938	46804	5502	Краснодарский край, Успенский район, поселок Успенское, Ленина , 108	f	large
21997	46805	5503	Краснодарский край, Успенский район, поселок Успенское, Калинина, 77	f	large
21995	46803	5501	Краснодарский край, Успенский район, село Успенское, Школьная, 5	f	large
22007	46785	5513	Краснодарский край, Успенский район, поселок Убеженская, Почтовая, 6	f	medium
22014	46820	5520	Краснодарский край, Успенский район, поселок Трехсельское, Мира, 4, телефон: 64334	f	medium
22015	46821	5521	Краснодарский край, Успенский район, поселок Новоурупское, Ленина, 38, телефон: 64349	f	small
22008	46814	5514	Краснодарский край, Успенский район, поселок Новенький, Ленина, 77, телефон: 63791	t	small
22012	46818	5518	Краснодарский край, Успенский район, поселок Николаевская, улица Красная, 34 а	f	large
21999	46807	5505	Краснодарский край, Успенский район, поселок Мичуринский, Ленина, 13, телефон: 66321	f	large
22017	46823	5523	Краснодарский край, Успенский район, поселок Марьино, Центральная, 36 а, телефон: 51344	f	large
22005	46813	5511	Краснодарский край, Успенский район, поселок Маламино, Ленина, 47 б	f	large
22004	46812	5510	Краснодарский край, Успенский район, поселок Коноково, сельский Дом культуры, телефон: 68203	f	large
22003	46811	5509	Краснодарский край, Успенский район, поселок Коноково, Калинина, 22, телефон: 67321	f	large
22002	46810	5508	Краснодарский край, Успенский район, поселок Коноково, Калинина, 51, телефон: 67253	f	large
22001	46809	5507	Краснодарский край, Успенский район, поселок Коноково, Донская, 10, телефон: 67251	f	large
22010	46816	5516	Краснодарский край, Успенский район, поселок Державный, Советская, 4, телефон: 58112	f	small
21937	46746	5328	Краснодарский край, Туапсинский район, поселокПансионат отдыха Южный, здание МОУ НОШ № 21 п/о Южный	f	small
21935	46744	5326	Краснодарский край, Туапсинский район, поселок Шепси, ЗАО Пансионат Шепси, корпус № 16, телефон: 6363	f	small
21934	46743	5325	Краснодарский край, Туапсинский район, поселок Шепси, Сочинская, 6, телефон: 63494	f	medium
21933	46742	5324	Краснодарский край, Туапсинский район, поселок Шепси, Сочинская, 2, телефон: 63615	f	medium
21956	46763	5347	Краснодарский край, Туапсинский район, поселок Шаумян, Шаумяна, 58	f	medium
21966	46772	5357	Краснодарский край, Туапсинский район, поселок Цыпка, Центральная, 2, телефон: 65514	f	medium
21930	46738	5321	Краснодарский край, Туапсинский район, поселок Тюменский, здание КСК, телефон: 68424	f	large
21957	46764	5348	Краснодарский край, Туапсинский район, поселок Терзиян, здание сельского клуба	f	small
21919	46727	5310	Краснодарский край, Туапсинский район, поселок Тенгинка, Шаумяна, 40, телефон: 95394	f	medium
21918	46726	5309	Краснодарский край, Туапсинский район, поселок Тенгинка, Шаумяна, 40, телефон: 95469	f	medium
21927	46735	5318	Краснодарский край, Туапсинский район, поселок Сосновый, ГУ ЦВМиР Сосновый МВД России, здание клуба	t	small
21953	46760	5344	Краснодарский край, Туапсинский район, поселок Садовое, Баграмяна, 11, телефон: 96717	f	small
21924	46732	5315	Краснодарский край, Туапсинский район, Псебе, Мира, 41	f	small
21955	46762	5346	Краснодарский край, Туапсинский район, Поселок Джубга, Новороссийское шоссе, 1/Б	f	medium
21916	46724	5307	Краснодарский край, Туапсинский район, Поселок Джубга, Колхозная, 38	f	medium
21925	46733	5316	Краснодарский край, Туапсинский район, село Пляхо, Дорога Орлят, 1, телефон: 93850	f	medium
21952	46759	5343	Краснодарский край, Туапсинский район, поселок Островская Щель, Центральная, 3/А	f	small
21926	46734	5317	Краснодарский край, Туапсинский район, поселок Ольгинка, переулок Ореховый, 5Б	f	large
21923	46731	5314	Краснодарский край, Туапсинский район, поселок Новомихайловский, Юности, 12, телефон: 92400	f	large
20935	45759	3023	Краснодарский край, Староминский район, поселок Первомайский, Комарова, 8	f	large
21920	46728	5311	Краснодарский край, Туапсинский район, поселок Новомихайловский, 1 Микрорайон, 6, телефон: 91225	f	large
21929	46737	5320	Краснодарский край, Туапсинский район, поселок Небуг, переулок Фонтанный, 2, телефон: 97919	f	large
21928	46736	5319	Краснодарский край, Туапсинский район, поселок Небуг, переулок Фонтанный, 2, телефон: 97991	f	large
21954	46761	5345	Краснодарский край, Туапсинский район, поселок Навагинское, Центральная, 21, телефон: 96677	f	small
21910	46721	5301	Краснодарский край, Туапсинский район, поселок Молдавановка, Центральная, 49, телефон: 95750	f	medium
21965	46771	5356	Краснодарский край, Туапсинский район, поселок Мессажай, Шаумяна, 11, телефон: 65120	f	medium
21964	46771	5355	Краснодарский край, Туапсинский район, поселок Мессажай, Шаумяна, 11, телефон: 65120	f	medium
21947	46756	5338	Краснодарский край, Туапсинский район, поселок Мал. Псеушхо, Тхагушева, здание сельского Дома культуры	f	small
21917	46725	5308	Краснодарский край, Туапсинский район, поселок Лермонтово, Ленина, 19Б, телефон: 74140	f	medium
21944	46753	5335	Краснодарский край, Туапсинский район, поселок Кривенковское, Спорная, 1, телефон: 62420	f	medium
21943	46752	5334	Краснодарский край, Туапсинский район, поселок Кривенковское, Спорная, 1	f	large
21948	45180	5339	Краснодарский край, Туапсинский район, поселок Кирпичное, Майкопская, 28, телефон: 64768	f	medium
21949	45273	5340	Краснодарский край, Туапсинский район, поселок Индюк, Майкопская, 95	f	small
21914	46722	5305	Краснодарский край, Туапсинский район, Джубга, Черноморская, 66	f	medium
21915	46723	5306	Краснодарский край, Туапсинский район, поселок Джубга, Советская, 33, телефон: 94298	f	large
21911	43866	5302	Краснодарский край, Туапсинский район, поселок Дефановка, Школьная, 9, телефон: 95538	f	large
21936	46745	5327	Краснодарский край, Туапсинский район, поселок Дедеркой, Клубная, 2, телефон: 61150	f	small
21958	46765	5349	Краснодарский край, Туапсинский район, Гунайка Четвёртая, Школьная, 13	f	small
21912	44259	5303	Краснодарский край, Туапсинский район, поселок Горское, Центральная, 5 А, телефон: 66760	t	small
21951	46758	5342	Краснодарский край, Туапсинский район, поселок Горный, Глебова, 19	f	medium
21960	46767	5351	Краснодарский край, Туапсинский район, поселок Гойтх, здание МОУ СОШ № 38	f	small
111127	46754	5336	Краснодарский край, Туапсинский район, поселок Георгиевское, Советская, 23	f	medium
21940	46749	5331	Краснодарский край, Туапсинский район, поселок Вольное, представительство РГСУ БАЗА оск Строитель, корпус № 1	f	small
21950	46757	5341	Краснодарский край, Туапсинский район, поселок Большое Псеушхо, Центральная, здание Дома культуры	f	small
21913	44866	5304	Краснодарский край, Туапсинский район, поселок Бжид, Черноморская, 65, телефон: 66599	t	small
21946	46755	5337	Краснодарский край, Туапсинский район, поселок Анастасиевка, Центральная, телефон: 64262	f	small
21932	46741	5323	Краснодарский край, Туапсинский район, поселок Агуй-Шапсуг, Шапсугская, 73	f	large
21931	46739	5322	Краснодарский край, Туапсинский район, поселок Агой, Горная, 12/Б	f	large
21989	46796	5423	Краснодарский край, Туапсинский, Туапсе, Московских Строителей, 1	f	small
21046	45871	3257	Краснодарский край, Тихорецкий район, поселок Южный, Цветочная, 3, телефон: 5-39-68	t	small
21874	46686	5143	Краснодарский край, Тихорецкий район, поселок Юго-Северная, Северная, 67	f	large
20726	45549	2641	Краснодарский край, Тихорецкий район, поселок Школьный, Магистральная, 48а	f	medium
21870	46682	5139	Краснодарский край, Тихорецкий район, поселок Хоперская, Школьная, 3	f	medium
21866	46678	5135	Краснодарский край, Тихорецкий район, станица Фастовецкая, Ленина, 9, телефон: 45-3-56	f	large
21864	46676	5133	Краснодарский край, Тихорецкий район, поселок Фастовецкая, Ленина, 9, телефон: 45-2-26	f	large
21868	46680	5137	Краснодарский край, Тихорецкий район, поселок Фастовецкая, Азина, 4, телефон: 45-5-89	f	large
21867	46679	5136	Краснодарский край, Тихорецкий район, поселок Фастовецкая, Азина, 4, телефон: 45-4-46	f	large
21893	46705	5219	Краснодарский край, Тихорецкий район, Тихорецк, Юго-Восточный бульвар, 1	f	large
21905	46717	5231	Краснодарский край, Тихорецкий район, Тихорецк, Парковая, 3	f	medium
21881	46693	5207	Краснодарский край, Тихорецкий район, Тихорецк, Октябрьская, 93	f	large
83917	57338	3110	Москва, Зеленоград, к344а	f	large
21891	46703	5217	Краснодарский край, Тихорецкий район, Тихорецк, Юго-Восточный бульвар, 2-Б, телефон: 5-56-91	f	large
21908	46720	5234	Краснодарский край, Тихорецкий район, Тихорецк, Энгельса, 91, телефон: 7-11-25	f	large
21886	46698	5212	Краснодарский край, Тихорецкий район, Тихорецк, Энгельса, 220-А, телефон: 4-14-84	f	large
21907	46719	5233	Краснодарский край, Тихорецкий район, Тихорецк, Чапаева, 2/2, телефон: 7-55-48	f	large
21888	46700	5214	Краснодарский край, Тихорецкий район, Тихорецк, Федосеева, 15, телефон: 7-17-20	f	large
21896	46708	5222	Краснодарский край, Тихорецкий район, Тихорецк, Ударников, 12, телефон: 5-80-81	f	large
21906	46718	5232	Краснодарский край, Тихорецкий район, Тихорецк, Подвойского, 42-Б, телефон: 7-11-70	f	medium
21887	46699	5213	Краснодарский край, Тихорецкий район, Тихорецк, Передовая, 326	f	large
21882	46694	5208	Краснодарский край, Тихорецкий район, город Тихорецк, Октябрьская, 106	f	large
21879	46691	5205	Краснодарский край, Тихорецкий район, город Тихорецк, Октябрьская, 96, телефон: 5-39-65	f	large
21898	46710	5224	Краснодарский край, Тихорецкий район, город Тихорецк, Новорождественское шоссе, 3, телефон: 5-83-62	f	medium
21892	46704	5218	Краснодарский край, Тихорецкий район, Тихорецк, Набережная, 20, телефон: 5-50-36	f	large
21901	46713	5227	Краснодарский край, Тихорецкий район, Тихорецк, Меньшикова, 98, телефон: 7-10-52	f	medium
21885	46697	5211	Краснодарский край, Тихорецкий район, город Тихорецк, Ляпидевского, 64, телефон: 7-22-87	f	large
21878	46690	5204	Краснодарский край, Тихорецкий район, Тихорецк, Ленинградская, 135, телефон: 7-47-68	f	large
21895	46707	5221	Краснодарский край, Тихорецкий район, Тихорецк, Ленина, 58, телефон: 5-80-61	f	large
21890	46702	5216	Краснодарский край, Тихорецкий район, Тихорецк, Кирова, 19, телефон: 2-89-39	f	large
21883	46695	5209	Краснодарский край, Тихорецкий район, город Тихорецк, Калинина/Майская, 33/1, телефон: 7-14-47	f	large
21903	46715	5229	Краснодарский край, Тихорецкий район, Тихорецк, Калинина, 112-А, телефон: 7-65-56	f	small
21904	46716	5230	Краснодарский край, Тихорецкий район, город Тихорецк, Гражданская, 89, телефон: 7-09-01	f	medium
67935	46714	5228	Краснодарский край, Тихорецкий район, Тихорецк, Гвардейская, 2	f	large
21876	46688	5202	Краснодарский край, Тихорецкий район, город Тихорецк, Ачкасова, 2, телефон: 7-52-21	f	large
21875	46687	5201	Краснодарский край, Тихорецкий район, город Тихорецк, Ачкасова, 78, телефон: 7-12-80	f	large
21863	46675	5132	Краснодарский край, Тихорецкий район, поселок Терновская, Суворова, 1	f	large
21862	46674	5131	Краснодарский край, Тихорецкий район, поселок Терновская, Суворова, 1	f	large
21861	46673	5130	Краснодарский край, Тихорецкий район, поселок Терновская, Пионерская, 14	f	large
21860	46672	5129	Краснодарский край, Тихорецкий район, поселок Терновская, Малиновского, 5а, телефон: 43-3-05	f	large
21857	46669	5126	Краснодарский край, Тихорецкий район, поселок Садовый, Титова, 2а, телефон: 94-1-27	t	small
20055	44888	1323	Краснодарский край, Тихорецкий район, поселок Садовый, Советская, 8, телефон: 65095	f	medium
21869	46681	5138	Краснодарский край, Тихорецкий район, поселок Привольный, Первомайская, 58	f	small
21858	46670	5127	Краснодарский край, Тихорецкий район, поселок Полевой, Пионерская, 71а	t	small
21856	46668	5125	Краснодарский край, Тихорецкий район, поселок Парковый, Дружбы, 9, телефон: 48-3-78	f	large
67934	46664	5121	Краснодарский край, Тихорецкий район, поселок Парковый, Гагарина , 32	f	large
21853	46665	5122	Краснодарский край, Тихорецкий район, поселок Парковый, Гагарина, 24, 47-2-74	f	large
21851	46663	5120	Краснодарский край, Тихорецкий район, поселок Парковый, Гагарина, 22	f	medium
21850	46662	5119	Краснодарский край, Тихорецкий район, станица Отрадненская, Ленина, 10	f	large
21161	45978	3801	Краснодарский край, Тихорецкий район, поселок Отрадная, Северная, 51	f	large
21163	45980	3803	Краснодарский край, Тихорецкий район, поселок Отрадная, Первомайская, 20	f	large
67982	45981	3804	Краснодарский край, Тихорецкий район, поселок Отрадная, Красная, 86А	f	large
21859	46671	5128	Краснодарский край, Тихорецкий район, поселок Новоромановская, Набережная, 9а	f	small
67933	46659	5116	Краснодарский край, Тихорецкий район, поселок Новорождественская, Красная, 54	f	large
20971	45796	3124	Краснодарский край, Мостовский район, поселок Губская, Мира, 129	f	large
21846	46658	5115	Краснодарский край, Тихорецкий район, поселок Новорождественская, Красная, 54, телефон: 46-1-47	f	large
21848	46660	5117	Краснодарский край, Тихорецкий район, поселок Новорождественская, Кирпичная, 16, телефон: 46-9-18	f	large
21849	46661	5118	Краснодарский край, Тихорецкий район, поселок Новорождественская, Горького, 1	f	large
21844	46656	5113	Краснодарский край, Тихорецкий район, поселок Мирный, Мира, 2а	f	small
21837	46649	5106	Краснодарский край, Тихорецкий район, поселок Малороссийский, Мичурина, 4, телефон: 97-7-45	f	large
21865	46677	5134	Краснодарский край, Тихорецкий район, поселок Ленинское Возрождение, Северная, 118а, телефон: 92-7-49	f	small
21871	46683	5140	Краснодарский край, Тихорецкий район, поселок Ленинский, Советская, 3а	f	small
21854	46666	5123	Краснодарский край, Тихорецкий район, поселок Крутой, Новая, 10, телефон: 7-08-76	f	large
21872	46684	5141	Краснодарский край, Тихорецкий район, поселок Красный, Красная, 28А	t	small
21835	46647	5104	Краснодарский край, Тихорецкий район, поселок Краснооктябрьская, Мира, 5	f	large
21899	46711	5225	Краснодарский край, Тихорецкий район, поселок Каменный, Ленина, 5	f	large
21873	46685	5142	Краснодарский край, Тихорецкий район, поселок Казаче-Борисовский, Октябрьская, 23, телефон: 91-1-42	f	small
21855	46667	5124	Краснодарский край, Тихорецкий район, поселок Зеленый, переулок Степной, 36, телефон: 94-1-13	f	small
22009	46815	5515	Краснодарский край, Тихорецкий район, хутор Западный, улица Центральная, 28	f	small
21845	46657	5114	Краснодарский край, Тихорецкий район, поселок Еремизино-Борисовская, Школьная, 7	f	large
19722	44550	632	Краснодарский край, Тихорецкий район, поселок Восточный, Свободная, 28, телефон: 3-71-75	f	small
21843	46655	5112	Краснодарский край, Тихорецкий район, поселок Братский, Школьная, 20, телефон: 92-6-31	f	large
21838	46650	5107	Краснодарский край, Тихорецкий район, поселок Архангельская, Садовая, 3, телефон: 91-7-47	f	large
21841	46653	5110	Краснодарский край, Тихорецкий район, поселок Архангельская, Первомайская, 75, телефон: 91-4-21	f	large
21840	46652	5109	Краснодарский край, Тихорецкий район, поселок Архангельская, Ленина, 2	f	large
21839	46651	5108	Краснодарский край, Тихорецкий район, поселок Архангельская, Ленина, 6, телефон: 91-3-88	f	large
21842	46654	5111	Краснодарский край, Тихорецкий район, поселок Архангельская, Буденного, 35а	f	large
21833	46645	5102	Краснодарский край, Тихорецкий район, поселок Алексеевская, Ленина, 45, телефон: 94-3-43	f	large
21832	46644	5101	Краснодарский край, Тихорецкий район, поселок Алексеевская, Ленина, 45	f	large
21790	46604	5020	Краснодарский край, Тимашевский район, Тимашевск, мкр.Сахарного завода, 8, здание МДОУ д/с №11, телефон: 5-35-77	f	large
21795	46609	5025	Краснодарский край, Тимашевский район, город Тимашевск, мкр.Индустриальный,, 3, здание МБУДОД ЦРДиЮ, телефон: 5-52-54	f	large
21794	46608	5024	Краснодарский край, Тимашевский район, Тимашевск, мкр.Индустриальный, МОУ СОШ № 5, телефон: 5-54-51	f	large
21789	46603	5019	Краснодарский край, Тимашевский район, город Тимашевск, мкр. Сахарного завода, МОУ СОШ № 4, телефон: 4-04-08	f	large
21772	46586	5002	Краснодарский край, Тимашевский район, Тимашевск, Шереметова, 36, телефон: 4-36-59	f	large
21774	46588	5004	Краснодарский край, Тимашевский район, Тимашевск, Степанова, 170/а	f	large
21773	46587	5003	Краснодарский край, Тимашевский район, Тимашевск, Советская, 105, телефон: 9-03-87	f	large
21771	46585	5001	Краснодарский край, Тимашевский район, город Тимашевск, Профильная, 47, телефон: 4-18-13	f	large
21827	46639	5057	Краснодарский край, Тимашевский район, Тимашевск, Набережная, 30	f	large
21826	46638	5056	Краснодарский край, Тимашевский район, Тимашевск, Ленина, 152, телефон: 4-40-42	f	medium
21779	46593	5009	Краснодарский край, Тимашевский район, Тимашевск, Ленина, 154, телефон: 4-12-31	f	large
21777	46591	5007	Краснодарский край, Тимашевский район, город Тимашевск, Ленина, 120, телефон: 4-21-97	f	large
21776	46590	5006	Краснодарский край, Тимашевский район, Тимашевск, Ленина, 120, телефон: 4-12-52	f	medium
21781	46595	5011	Краснодарский край, Тимашевский район, город Тимашевск, Красная, 179, телефон: 4-00-30	f	large
21778	46592	5008	Краснодарский край, Тимашевский район, город Тимашевск, Красная, 105, телефон: 4-17-73, 4-24-68	f	large
29506	19091	49	Астраханская область, Ахтубинск, пл.Ленина, 1	f	large
21788	46602	5018	Краснодарский край, Тимашевский район, город Тимашевск, Котляра, 2/б, телефон: 4-19-65	f	medium
21787	46601	5017	Краснодарский край, Тимашевский район, город Тимашевск, Котляра, 2/а, телефон: 5-85-75	f	large
21784	46598	5014	Краснодарский край, Тимашевский район, город Тимашевск, Коммунальная, 16, телефон: 4-16-32	f	large
21823	46637	5053	Краснодарский край, Тимашевский район, город Тимашевск, Комарова, 42, телефон: 4-20-67	f	large
21791	46605	5021	Краснодарский край, Тимашевский район, город Тимашевск, Западная, 12, телефон: 5-48-09	f	large
21831	46643	5099	Краснодарский край, Тимашевский район, Тимашевск, Гибридная, 2, телефон: 4-24-89	f	small
21830	46642	5060	Краснодарский край, Тимашевский район, Тимашевск, Выборная, 68а, телефон: 4-24-55	f	small
21793	46607	5023	Краснодарский край, Тимашевский район, город Тимашевск, Братьев Степановых, 2, здание МБОУ СОШ № 19, телефон: 4-06-08	f	large
21792	46606	5022	Краснодарский край, Тимашевский район, Тимашевск, Братьев Степановых, 2, здание спорткомплекса Олимп, телефон: 4-22-89	f	large
21782	46596	5012	Краснодарский край, Тимашевский район, город Тимашевск, 70 лет Октября, 4, здание МОУ СОШ № 18	f	large
21785	46599	5015	Краснодарский край, Тимашевский район, Тимашевск, 50 лет Октября, 100Ж, телефон: 4-19-11	f	large
21806	46620	5036	Краснодарский край, Тимашевский район, поселок Танцура Крамаренко, Школьная, 12/а, здание СОШ № 6, телефон: 3-63-49	f	large
21821	46635	5051	Краснодарский край, Тимашевский район, поселок Стринский, Красная, 91/а, телефон: 3-00-61	f	small
21808	46622	5038	Краснодарский край, Тимашевский район, поселок Советский, Ленина, 19	f	large
20715	45538	2630	Краснодарский край, Тимашевский район, поселок Садовый, Комсомольская, 22, телефон: 6-27-82	f	medium
21814	46628	5044	Краснодарский край, Тимашевский район, поселок Роговская, Свободная, 40	f	medium
21813	46627	5043	Краснодарский край, Тимашевский район, поселок Роговская, Ленина, 74, телефон: 6-62-31	f	large
21817	46631	5047	Краснодарский край, Тимашевский район, поселок Роговская, Коммунаров, 44/а	f	large
21815	46629	5045	Краснодарский край, Тимашевский район, поселок Роговская, Гоголя, 18	f	large
21812	46626	5042	Краснодарский край, Тимашевский район, хутор Ольховский, Степанова, 63/а, телефон: 7-82-04	f	medium
21819	46633	5049	Краснодарский край, Тимашевский район, поселок Новокорсунская, Пионерская, 23, телефон: 3-44-52	f	large
21818	46632	5048	Краснодарский край, Тимашевский район, поселок Новокорсунская, Красная, 2, телефон: 3-44-92	f	large
21820	46634	5050	Краснодарский край, Тимашевский район, поселок Незаймановский, Школьная, 24/а, телефон: 3-08-65	f	large
21801	46615	5031	Краснодарский край, Тимашевский район, поселок Медведовская, Школьная, 34	f	large
21803	46617	5033	Краснодарский край, Тимашевский район, поселок Медведовская, Пушкина, 7, здание СОШ № 10, телефон: 7-15-59	f	large
67931	46616	5032	Краснодарский край, Тимашевский район, поселок Медведовская, Пушкина, 5	f	large
21798	46612	5028	Краснодарский край, Тимашевский район, поселок Медведовская, Мира, 90, телефон: 7-14-06	f	large
21829	46641	5059	Краснодарский край, Тимашевский район, поселок Медведовская, Ленина, 54	f	large
21800	46614	5030	Краснодарский край, Тимашевский район, поселок Медведовская, Ленина, 54, телефон: 7-53-58	f	large
21799	46613	5029	Краснодарский край, Тимашевский район, поселок Медведовская, Ленина, 77	f	large
20315	45147	1960	Краснодарский край, Тимашевский район, поселок Крупской, улица Народная, 59	f	medium
21811	46625	5041	Краснодарский край, Тимашевский район, поселок Калинина, Победы, 6а/2, телефон: 7-93-37	f	large
21810	46624	5040	Краснодарский край, Тимашевский район, поселок Днепровская, Ленина, 68	f	large
21807	46621	5037	Краснодарский край, Тимашевский район, поселок Беднягина, Юбилейный, 5, телефон: 3-13-98	f	large
21765	46579	4949	Краснодарский край, Темрюкский район, поселек Тамань, Карла Маркса, 102, дм. здание рыбколхоза	f	large
21756	46570	4940	Краснодарский край, Темрюкский район, поселок Юбилейный, Ленина, 17, здание МБОУ СОШ №31, телефон: 76-4-31	f	medium
21758	46572	4942	Краснодарский край, Темрюкский район, поселок Фонталовская, Ленина, 27, здание администрации поселения	f	large
21725	46540	4909	Краснодарский край, Темрюкский район, Темрюк, площадь Терлецкого, здание МБОУ СОШ №2, телефон: 4-22-26	f	large
83916	57338	3109	Москва, Зеленоград, к344а	f	large
21717	46531	4901	Краснодарский край, Темрюкский район, Темрюк, пер. имени Дуси Виноградовой, 1, здание Дома культуры, телефон: 94-1-64	f	large
21721	46536	4905	Краснодарский край, Темрюкский район, город Темрюк, Шопена, 70, здание штаба ТРКО, телефон: 5-21-29	f	large
21722	46537	4906	Краснодарский край, Темрюкский район, город Темрюк, Таманская, 69, здание кинотеатра Тамань, телефон: 5-24-77	f	large
21720	46535	4904	Краснодарский край, Темрюкский район, город Темрюк, Свердлова, 1 А, МБДОУ ДС КВ №11, телефон: 5-43-73	f	large
21730	46545	4914	Краснодарский край, Темрюкский район, Темрюк, Полетаева, 2, здание детского сада №13, телефон: 4-27-27	f	large
21724	46539	4908	Краснодарский край, Темрюкский район, город Темрюк, Октябрьская, 109, здание МБОУ ООШ №14, телефон: 5-22-57	f	large
21718	46533	4902	Краснодарский край, Темрюкский район, Темрюк, Морская, 12, здание ООО Владимпекс-транс, телефон: 5-13-17	f	small
21731	46546	4915	Краснодарский край, Темрюкский район, Темрюк, Молодежная, 1, администрат. здание рисосовхоза, телефон: 99-2-24	f	large
21729	46544	4913	Краснодарский край, Темрюкский район, Темрюк, Мира, 152, здание соц.-центра, телефон: 4-28-65	f	large
21727	46542	4911	Краснодарский край, Темрюкский район, город Темрюк, Мира, 73 А, здание МБОУ СОШ №3, телефон: 4-21-55	f	large
21726	46541	4910	Краснодарский край, Темрюкский район, город Темрюк, Мира, 73 А, здание МБОУ СОШ №3, телефон: 4-29-20	f	large
21719	46534	4903	Краснодарский край, Темрюкский район, Темрюк, Ленина, 29, здание Дома культуры, телефон: 5-24-27	f	large
21728	46543	4912	Краснодарский край, Темрюкский район, Темрюк, Карла Маркса, 151, здание библиотеки, телефон: 4-38-03	f	large
21733	46532	4917	Краснодарский край, Темрюкский район, Темрюк, Гагарина, здание МБОУ СОШ №15, телефон: 65-4-21	f	large
21723	46538	4907	Краснодарский край, Темрюкский район, Темрюк, Бувина, 2, здание местного отделения ДОСААФ, телефон: 5-24-35	f	large
21766	46580	4950	Краснодарский край, Темрюкский район, станица Тамань, Некрасова, 5, здание МБОУ СОШ №9	f	large
21764	46578	4948	Краснодарский край, Темрюкский район, поселок Тамань, Карла Маркса, 165, здание Дома культуры	f	large
21768	46582	4952	Краснодарский край, Темрюкский район, поселок Таманский, Ленина, 14, здание Дома культуры, телефон: 36-8-94	f	large
21747	46561	4931	Краснодарский край, Темрюкский район, поселок Стрелка, Ленина, 11, здание Дома культуры, телефон: 92-4-30	f	large
21746	46560	4930	Краснодарский край, Темрюкский район, поселок Стрелка, Ленина, 8 Б, здание администрации поселения, телефон: 92-5-75	f	large
21751	46565	4935	Краснодарский край, Темрюкский район, поселок Старотитаровская, пер. Горького, 2, адмдминистративное здание ПЧ-2	f	large
21749	46563	4933	Краснодарский край, Темрюкский район, поселок Старотитаровская, Садовая, 151, здание МОУ СОШ №27, телефон: 90-5-71	f	large
21752	46566	4936	Краснодарский край, Темрюкский район, поселок Старотитаровская, Переулок Ильича, 46, администр. здание ООО Кубань	f	large
21770	46584	4954	Краснодарский край, Темрюкский район, поселок Старотитаровская, Ленина, 211, здание МБОУ СОШ №6, телефон: 90-1-01	f	large
21750	46564	4934	Краснодарский край, Темрюкский район, поселок Старотитаровская, Ленина, 310, здание Культурно-соц. центра, телефон: 90-6-63	f	large
21744	46558	4928	Краснодарский край, Темрюкский район, поселок Сенной, Мира, 38, здание Дома культуры, телефон: 38-4-08	f	large
21743	46557	4927	Краснодарский край, Темрюкский район, поселок Сенной, Кулакова, 31, здание музыкальной школы, телефон: 39-00-2	f	large
21737	46551	4921	Краснодарский край, Темрюкский район, поселок Светлый Путь Ленина, Широкая, 45, здание Дома культуры	f	large
21745	46559	4929	Краснодарский край, Темрюкский район, поселок Приморский, Ленина, 7, здание Дома культуры	f	large
21269	46086	4014	Краснодарский край, Темрюкский район, поселок Приморский, Красная, 10	f	medium
21741	46555	4925	Краснодарский край, Темрюкский район, поселок Пересыпь, Бондаревой, 94, здание МБОУ СОШ №22, телефон: 79-1-02	f	large
21757	46571	4941	Краснодарский край, Темрюкский район, поселок Кучугуры, Ленина, 41, здание Дома культуры, телефон: 79-2-98	f	large
21734	46548	4918	Краснодарский край, Темрюкский район, поселок Курчанская, Чапаева, 38, телефон: 95-4-07	f	large
21736	46550	4920	Краснодарский край, Темрюкский район, поселок Курчанская, Красная, здание МДОУ №17	f	large
83915	57337	3108	Москва, Зеленоград, к314	f	large
21735	46549	4919	Краснодарский край, Темрюкский район, поселок Курчанская, Красная, 79, здание Дома культуры, телефон: 95-2-69	f	large
21738	46552	4922	Краснодарский край, Темрюкский район, поселок Красный Октябрь, Школьная, 1, здание МБОУ СОШ №20	f	large
21809	46623	5039	Краснодарский край, Темрюкский район, поселок Красноармейский, Постовая, 35, телефон: 6-01-05	f	small
20114	44946	1516	Краснодарский край, Темрюкский район, поселок Красноармейский, Первомайский, 4, телефон: 56-2-74	f	small
21760	46574	4944	Краснодарский край, Темрюкский район, поселок Ильич, Ленина, 36, МБОУ СОШ №17	f	large
21759	46573	4943	Краснодарский край, Темрюкский район, поселок Запорожская, Ленина, 21 А, здание Дома культуры, телефон: 77-4-14	f	large
21739	46553	4923	Краснодарский край, Темрюкский район, поселок Голубицкая, Советская, 116, здание администрации поселения, телефон: 63-1-17	f	large
21740	46554	4924	Краснодарский край, Темрюкский район, поселок Голубицкая, Красная, 108, здание МКУ, Голубицкий КСЦ, телефон: 63-6-89	f	large
21761	46575	4945	Краснодарский край, Темрюкский район, поселок Гаркуша, Ленина, 28, здание конторы отд. №2;Залив, телефон: 77-2-86	f	large
21754	46568	4938	Краснодарский край, Темрюкский район, поселок Вышестеблиевская, Ленина, 63, здание Дома культуры, телефон: 35-5-01	f	large
21753	46567	4937	Краснодарский край, Темрюкский район, поселок Вышестеблиевская, Ленина, 94, здание администрации поселения, телефон: 35-5-25	f	large
21763	46577	4947	Краснодарский край, Темрюкский район, поселок Волна, Приморская, 2, здание МБОУ ООШ №32, телефон: 33-6-48	f	small
21755	46569	4939	Краснодарский край, Темрюкский район, поселок Виноградный, площадь Ленина, 8, здание Дома культуры	f	large
20732	45555	2647	Краснодарский край, Темрюкский район, поселок Виноградный, Молодежная, 17а, телефон: 6-18-35	f	medium
21769	46583	4953	Краснодарский край, Темрюкский район, поселок Веселовка, Гвардейская, 18, здание Дома культуры, телефон: 36-4-33	f	large
21748	46562	4932	Краснодарский край, Темрюкский район, поселок Белый, Садовый переулок, 7, здание Дома культуры	f	large
21762	46576	4946	Краснодарский край, Темрюкский район, поселок Батарейка, Степная, 8, здание Дома культуры, телефон: 3459504	t	small
21742	46556	4926	Краснодарский край, Темрюкский район, поселок Ахтанизовская, переулок Северный, 13, здание Дома культуры	f	large
21697	46511	4826	Краснодарский край, Тбилисский район, поселок Шереметьевское, Колхозная, 106	t	small
21246	46063	3935	Краснодарский край, Тбилисский район, поселок Шевченко, Длинная, 59	f	small
21710	46524	4839	Краснодарский край, Тбилисский район, поселок Чернобабов, Степная, 67, 6 53 15	t	small
21707	46521	4836	Краснодарский край, Тбилисский район, поселок Терско-Каламбетский, Прикубанская, 33, телефон: 6 74 89	f	small
21687	46500	4816	Краснодарский край, Тбилисский район, поселок Терновый, Центральная, 2, телефон: 6 90 66	t	small
21683	46496	4812	Краснодарский край, Тбилисский район, поселок Тбилисская, переулок Средний, 13, телефон: 2 58 14	f	large
21677	46490	4806	Краснодарский край, Тбилисский район, поселок Тбилисская, Элеваторная, 70, телефон: 3 37 45	f	large
21672	46485	4801	Краснодарский край, Тбилисский район, поселок Тбилисская, Толстого, 24, телефон: 3 29 	f	large
21676	46489	4805	Краснодарский край, Тбилисский район, поселок Тбилисская, Первомайская, 77	f	large
21681	46494	4810	Краснодарский край, Тбилисский район, поселок Тбилисская, Октябрьская, 298 А, телефон: 2 36 08	f	large
21675	46488	4804	Краснодарский край, Тбилисский район, поселок Тбилисская, Октябрьская, 133, телефон: 2 46 51	f	large
21673	46486	4802	Краснодарский край, Тбилисский район, поселок Тбилисская, Октябрьская, 2	f	large
21679	46492	4808	Краснодарский край, Тбилисский район, поселок Тбилисская, Новая, 33, 2 38 46	f	large
21684	46497	4813	Краснодарский край, Тбилисский район, поселок Тбилисская, Набережная, 29, телефон: 3 39 53	f	small
21682	46495	4811	Краснодарский край, Тбилисский район, поселок Тбилисская, Красная, 134, телефон: 2 30 53	f	large
21678	46491	4807	Краснодарский край, Тбилисский район, поселок Тбилисская, Красная, 24, телефон: 3 29 72	f	large
21674	46487	4803	Краснодарский край, Тбилисский район, поселок Тбилисская, Водопроводная, 22, телефон: 2 49 68	f	large
21680	46493	4809	Краснодарский край, Тбилисский район, поселок Тбилисская, Базарная, 145, телефон: 3 27 58	f	large
21702	46516	4831	Краснодарский край, Тбилисский район, поселок Средний, Коммунаров, 1, здание ФАП	f	small
21695	46509	4824	Краснодарский край, Тбилисский район, поселок Северокубанский, Якубина, 239, телефон: 6 32 50	f	medium
21694	46508	4823	Краснодарский край, Тбилисский район, поселок Северокубанский, Якубина, 239, телефон: 6 34 51	f	medium
21685	46498	4814	Краснодарский край, Тбилисский район, поселок Северин, Ленина, 9, телефон: 6 67 75	f	large
21712	46526	4841	Краснодарский край, Тбилисский район, поселок Песчаный, Октябрьская, 38, телефон: 6 04 08	f	medium
21693	46507	4822	Краснодарский край, Тбилисский район, поселок Новопеховский-Первый, Волкова, здание сельского клуба, телефон: 6 34 17	t	small
21709	46523	4838	Краснодарский край, Тбилисский район, поселок Нововладимировская, Ленина, 13, телефон: 6 53 33	f	large
21711	46525	4840	Краснодарский край, Тбилисский район, поселок Новобекешевская, Садовая, 79, телефон: 6 51 76	t	small
21705	46519	4834	Краснодарский край, Тбилисский район, поселок Марьинский, Мамеева, 58, телефон: 6 74 42	f	medium
21703	46517	4832	Краснодарский край, Тбилисский район, поселок Ловлинская, переулок Школьный, 9, телефон: 6 42 30	f	large
21704	46518	4833	Краснодарский край, Тбилисский район, поселок Ловлинская, Школьный переулок, 9	f	medium
21691	46505	4820	Краснодарский край, Тбилисский район, поселок Красный Зеленчук, Магазинная, 16, телефон: 6 38 93	t	small
21716	46530	4845	Краснодарский край, Тбилисский район, поселок Зубов, Зеленчукская, 26, телефон: 6 71 37	f	small
21706	46520	4835	Краснодарский край, Тбилисский район, поселок Зиссермановский, Верхняя, 2, телефон: 6 74 24	f	small
21708	46522	4837	Краснодарский край, Тбилисский район, поселок Еремин, Светлая, 90	t	small
21715	46529	4844	Краснодарский край, Тбилисский район, поселок Екатеринославский, Колхозная, 29, телефон: 6 67 24	f	small
21698	46512	4827	Краснодарский край, Тбилисский район, поселок Геймановская, Октябрьская, 72, телефон: 6 12 18	f	large
21669	46482	4719	Краснодарский край, Тбилисский район, поселок Веселый, Административное здание бригады №2 ЗАО ""Красное Знамя""	t	small
21692	46506	4821	Краснодарский край, Тбилисский район, поселок Веселый, Красная, здание ФАП	t	small
21713	46527	4842	Краснодарский край, Тбилисский район, поселок Веревкин, Красная, 25	t	small
21696	46510	4825	Краснодарский край, Тбилисский район, поселок Ванновское, Ленина, 69, телефон: 6 32 76	f	large
21714	46528	4843	Краснодарский край, Тбилисский район, поселок Алексее-Тенгинская, Октябрьская, здание автогаража	f	small
21701	46515	4830	Краснодарский край, Тбилисский район, станица Алексее-Тенгинская, переулок Ушинского, 3, телефон: 6 86 45	f	medium
21665	46478	4715	Краснодарский край, Староминский район, поселок Ясени, Южная, 83, телефон: 4-38-37	f	small
21651	46464	4701	Краснодарский край, Староминский район, поселок Староминская, Трудовая, 121	f	large
21661	46474	4711	Краснодарский край, Староминский район, поселок Староминская, Петренко, 149, телефон: 5-73-21	f	large
21660	46473	4710	Краснодарский край, Староминский район, поселок Староминская, Орджоникидзе, 101, телефон: 5-73-20	f	large
21655	46468	4705	Краснодарский край, Староминский район, поселок Староминская, Новощербиновская, 138, телефон: 5-73-15	f	large
21653	46466	4703	Краснодарский край, Староминский район, поселок Староминская, Ленина, 24-А	f	large
21657	46470	4707	Краснодарский край, Староминский район, поселок Староминская, Краснознаменная, 126, телефон: 5-73-17	f	large
21654	46467	4704	Краснодарский край, Староминский район, поселок Староминская, Красная, 39, телефон: 5-72-28	f	large
21659	46472	4709	Краснодарский край, Староминский район, поселок Староминская, Кольцовская, 52, телефон: 5-77-81	f	large
21652	46465	4702	Краснодарский край, Староминский район, поселок Староминская, Кирова, 33, телефон: 5-73-12	f	large
21656	46469	4706	Краснодарский край, Староминский район, поселок Староминская, Калинина, 2, телефон: 5-76-20	f	large
21662	46475	4712	Краснодарский край, Староминский район, поселок Староминская, Железнодорожная, 23, телефон: 4-23-43	f	large
21658	46471	4708	Краснодарский край, Староминский район, поселок Староминская, Большая Садовая, 113, телефон: 5-73-18	f	large
21666	46479	4716	Краснодарский край, Староминский район, поселок Рассвет, Мира, Сельский Дом культуры, телефон: 5-32-05	f	large
21664	46477	4714	Краснодарский край, Староминский район, поселок Новоясенская, Мира, 6-А, телефон: 5-17-97	f	small
21671	46484	4721	Краснодарский край, Староминский район, поселок Канеловская, Пионерская, 43, телефон: 5-22-69	f	large
21670	46483	4720	Краснодарский край, Староминский район, поселок Канеловская, Пионерская, 39, телефон: 5-22-98	f	large
20280	45110	1925	Краснодарский край, Староминский район, поселок Заря, Красноармейская, 15, телефон: 91-1-36	f	medium
21663	46476	4713	Краснодарский край, Староминский район, поселок Желтые Копани, Северная, 14	t	small
21668	46481	4718	Краснодарский край, Староминский район, поселок Восточный Сосык, Здание МОУ СОШ №6, телефон: 5-36-20	f	large
20896	45720	2938	Краснодарский край, Староминский район, поселок Веселый, Школьная, 4, телефон: 75185	t	small
21400	46216	4240	Краснодарский край, Славянский район, пос. МТФ-2, ОАО Аспект, телефон: 8-918-6688251	t	small
21421	46237	4261	Краснодарский край, Славянский район, поселок Черный Ерик, Мира, 20	f	small
21418	46234	4258	Краснодарский край, Славянский район, поселок Черноерковская, Комсомольская, 2, телефон: 9-51-71	f	large
21417	46233	4257	Краснодарский край, Славянский район, станица Черноерковская, Красная, 31	f	large
21415	46231	4255	Краснодарский край, Славянский район, поселок Целинный, Красная, 1, телефон: 9-62-87	f	large
21389	46204	4229	Краснодарский край, Славянский район, поселок Ханьков, Ленина, 133	f	large
21408	46224	4248	Краснодарский край, Славянский район, поселок Совхозный, Школьная, 607, елефон: 2-61-13	f	large
21381	46196	4221	Краснодарский край, Славянский район, город Славянск-На-Кубани, Ярмарочная, 349, телефон: 2-34-08	f	large
21364	46179	4204	Краснодарский край, Славянский район, город Славянск-На-Кубани, Школьная, 201, телефон: (246) 2-28-78	f	large
21363	46178	4203	Краснодарский край, Славянский район, Славянск-На-Кубани, Стаханова, 16, телефон: (246) 2-35-56	f	large
21380	46195	4220	Краснодарский край, Славянский район, Славянск-На-Кубани, Совхозная, 100, телефон: 4-45-30	f	large
21375	46190	4215	Краснодарский край, Славянский район, город Славянск-На-Кубани, Проточная, 136	f	large
21367	46182	4207	Краснодарский край, Славянский район, Славянск-На-Кубани, Отдельская, 145, телефон: (246) 2-14-51	f	large
21366	46181	4206	Краснодарский край, Славянский район, Славянск-На-Кубани, Отдельская, 29а, телефон: (246) 2-30-60	f	large
21370	46185	4210	Краснодарский край, Славянский район, Славянск-На-Кубани, Крупской, 294, телефон: (246) 2-20-57	f	large
21374	46189	4214	Краснодарский край, Славянский район, Славянск-На-Кубани, Красная, 8, телефон: 2-23-63	f	large
21371	46186	4211	Краснодарский край, Славянский район, Славянск-На-Кубани, Красная, 52, телефон: (246) 2-39-81	f	large
21378	46193	4218	Краснодарский край, Славянский район, город Славянск-На-Кубани, Запорожская, 36-А, телефон: 2-19-49	f	large
21373	46188	4213	Краснодарский край, Славянский район, Славянск-На-Кубани, Западная, 179	f	large
21362	46177	4202	Краснодарский край, Славянский район, Славянск-На-Кубани, Донская, 7, телефон: (246) 3-13-97	f	large
21377	46192	4217	Краснодарский край, Славянский район, Славянск-На-Кубани, Дзержинского, 390, телефон: 2-11-53	f	large
21365	46180	4205	Краснодарский край, Славянский район, город Славянск-На-Кубани, Дзержинского, 76	f	large
21397	46213	4237	Краснодарский край, Славянский район, поселок Сербин, Пионерская, 9	f	medium
21412	46228	4252	Краснодарский край, Славянский район, поселок Семисводный, улица Пионерская, 11	t	medium
21410	46226	4250	Краснодарский край, Славянский район, поселок Садовый, Виноградная, 8	f	large
21414	46230	4254	Краснодарский край, Славянский район, поселок Рисовый, Октябрьская, 20	f	large
21420	46236	4260	Краснодарский край, Славянский район, поселок Прорвенский, Западная, 2	t	small
21029	45854	3240	Краснодарский край, Славянский район, поселок Прикубанский, Школьная, 6	f	large
21399	46215	4239	Краснодарский край, Славянский район, поселок Прикубанский, Победы, 30	f	large
21388	46203	4228	Краснодарский край, Славянский район, поселок Прикубанский, Веселая, 34-А	f	small
21409	46225	4249	Краснодарский край, Славянский район, поселок Прибрежный, Советская, 6, телефон: 2-61-75	f	large
21402	46218	4242	Краснодарский край, Славянский район, станица Петровская, Чапаева, 177-А	f	large
33833	27609	1130	Волгоградская область, Волжский, Машиностроителей, 13	f	large
21401	46217	4241	Краснодарский край, Славянский район, поселок Петровская, Черноерковская, 1, телефон: 9-11-57	f	large
21405	46221	4245	Краснодарский край, Славянский район, поселок Петровская, Мелиораторов, 4, телефон: 9-11-50	f	large
21404	46220	4244	Краснодарский край, Славянский район, поселок Петровская, Красная, 20, телефон: 9-11-43	f	large
21403	46219	4243	Краснодарский край, Славянский район, поселок Петровская, Инкубаторская, 10, телефон: 9-12-40	f	large
21406	46222	4246	Краснодарский край, Славянский район, поселок Петровская, Гагарина, 12	f	medium
21413	46229	4253	Краснодарский край, Славянский район, поселок Нещадимовский, Безымянная, 35	f	large
21398	46214	4238	Краснодарский край, Славянский район, поселок Маевский, Мира, 7	f	medium
21394	46210	4234	Краснодарский край, Славянский район, поселок Красноармейский Городок, Красноармейская, 49	t	small
21396	46212	4236	Краснодарский край, Славянский район, поселок Коржевский, улица Октябрьская, 13	f	large
21395	46211	4235	Краснодарский край, Славянский район, поселок Коржевский, Октябрьская, 24-А	f	large
21390	46206	4230	Краснодарский край, Славянский район, поселок Забойский, Красная, 131	f	large
21391	46207	4231	Краснодарский край, Славянский район, поселок Деревянковка, Школьная, 12	f	small
21416	46232	4256	Краснодарский край, Славянский район, поселок Голубая Нива, Школьная, 1, телефон: 9-61-17	f	large
21392	46208	4232	Краснодарский край, Славянский район, поселок Галицын, Мира, 11	f	large
21407	46223	4247	Краснодарский край, Славянский район, поселок Водный, Кубанская, 1-А	t	small
21419	46235	4259	Краснодарский край, Славянский район, поселок Верхний, Рабочая, 11	f	medium
21393	46209	4233	Краснодарский край, Славянский район, поселок Беликов, пер. Гвардейский, 14, телефон: 9-64-79	t	medium
21411	46227	4251	Краснодарский край, Славянский район, поселок Бараниковский, Советов, 13	f	large
21422	46238	4262	Краснодарский край, Славянский район, поселок Ачуево, Ленина, 43, телефон: 7-55-67,7-55-16	f	small
21387	46202	4227	Краснодарский край, Славянский район, поселок Анастасиевская, Красная, 52, телефон: 5-32-14	f	large
21386	46201	4226	Краснодарский край, Славянский район, поселок Анастасиевская, Красная, 87, телефон: 5-13-18	f	large
21385	46200	4225	Краснодарский край, Славянский район, поселок Анастасиевская, Красная, 181, телефон: 5-20-62	f	large
21384	46199	4224	Краснодарский край, Славянский район, поселок Анастасиевская, Красная, 162, телефон: 5-13-03	f	large
21343	46157	4153	Краснодарский край, Северский район, станция Северская, Ленина, 230, телефон: 2-68-34	f	large
21342	46156	4152	Краснодарский край, Северский район, станция Северская, Казачья, 147	f	large
21341	46155	4151	Краснодарский край, Северский район, ст. Северская, Ленина, 132	f	large
21337	46151	4147	Краснодарский край, Северский район, ст. Северская, Ленина, 19/А	f	large
21359	46174	4169	Краснодарский край, Северский район, поселок Шабановское, Кирова, 48, телефон: 57-3-11	t	small
21353	46168	4163	Краснодарский край, Северский район, поселок Черноморский, Тельмана, 3, телефон: 66-8-81	f	large
21355	46170	4165	Краснодарский край, Северский район, поселок Черноморский, Октябрьская, 2, телефон: 66-9-30	f	large
21304	46121	4114	Краснодарский край, Северский район, Убинская, Центральная, 48	f	small
21360	46175	4170	Краснодарский край, Северский район, поселок Тхамаха, Школьная, 20, телефон: 57-3-21	t	small
21326	46140	4136	Краснодарский край, Северский район, поселок Стефановский, Соболя, 16, телефон: 3-78-90	t	small
21307	46124	4117	Краснодарский край, Северский район, поселок Ставропольская, 50-Лет ВЛКСМ, 50	f	medium
21349	46164	4159	Краснодарский край, Северский район, поселок Смоленская, Почтовая, 23/А	f	large
21348	46163	4158	Краснодарский край, Северский район, поселок Смоленская, Мира, 151	f	large
21347	46162	4157	Краснодарский край, Северский район, поселок Смоленская, Мира, 121	f	large
21346	46161	4156	Краснодарский край, Северский район, поселок Смоленская, Мира, 2	f	large
21305	46122	4115	Краснодарский край, Северский район, поселок Северская, Здание главного корпуса интерната,	f	small
21340	46154	4150	Краснодарский край, Северский район, поселок Северская, Орджоникидзе, 2/1, телефон: 2-60-85	f	large
21336	46150	4146	Краснодарский край, Северский район, поселок Северская, Октябрьская, 7	f	large
21344	46159	4154	Краснодарский край, Северский район, поселок Северская, Ленина, 151, телефон: 2-23-30	f	large
21338	46152	4148	Краснодарский край, Северский район, поселок Северская, Ленина, 61, телефон: 2-15-33	f	large
21335	46149	4145	Краснодарский край, Северский район, поселок Северская, Комсомольская, 43, телефон: 2-12-30	f	large
21334	46148	4144	Краснодарский край, Северский район, поселок Северская, Комсомольская, 43, телефон: 2-22-57	f	large
21339	46153	4149	Краснодарский край, Северский район, Северская, Орджоникидзе, 37/А, телефон: 2-22-25	f	large
21287	46103	4032	Краснодарский край, Северский район, поселок Свободный, Ленина, 22	f	medium
21328	46142	4138	Краснодарский край, Северский район, поселок Новоивановский, Широкова, 1, телефон: 3-72-38	t	small
21332	46146	4142	Краснодарский край, Северский район, поселок Новодмитриевская, Мичурина, 43, телефон: 42-4-99	f	large
21333	46147	4143	Краснодарский край, Северский район, поселок Новодмитриевская, Красная, 69	f	medium
21331	46145	4141	Краснодарский край, Северский район, поселок Новодмитриевская, Красная, 69	f	large
21329	46143	4139	Краснодарский край, Северский район, поселок Михайловское, Кооперативная, 3/А, телефон: 36-3-78	f	large
21323	46137	4133	Краснодарский край, Северский район, поселок Львовское, Советская, 80, телефон: 3-75-60	f	medium
21322	46136	4132	Краснодарский край, Северский район, поселок Львовское, Советская, 66	f	large
21324	46138	4134	Краснодарский край, Северский район, поселок Львовское, Северная, 75, телефон: 3-75-33	t	medium
21325	46139	4135	Краснодарский край, Северский район, поселок Львовское, Октябрьская, 9/Б	f	medium
21327	46141	4137	Краснодарский край, Северский район, поселок Львовское, Ворошилова, 2/А, телефон: 3-75-67	f	medium
21350	46165	4160	Краснодарский край, Северский район, поселок Крепостная, Клубная, 1	t	medium
20895	45719	2937	Краснодарский край, Северский район, поселок Красный, Ленина, 6	f	medium
21297	46114	4107	Краснодарский край, Северский район, поселок Коваленко, Пролетарская, 21	t	medium
21358	46173	4168	Краснодарский край, Северский район, поселок Карский, Восточная, 1/А	t	medium
21321	46135	4131	Краснодарский край, Северский район, поселок Калужская, Красная, 20, телефон: 42-4-06	t	large
21317	46132	4127	Краснодарский край, Северский район, поселок Ильский, Пионерская, 32	f	large
21316	46132	4126	Краснодарский край, Северский район, поселок Ильский, Пионерская, 32	f	large
21314	46130	4124	Краснодарский край, Северский район, поселок Ильский, Первомайская, 116, 68-0-17	f	large
21313	46129	4123	Краснодарский край, Северский район, поселок Ильский, Первомайская, 44/Б, телефон: 68-5-32	f	large
21312	46129	4122	Краснодарский край, Северский район, поселок Ильский, Первомайская, 44/Б, телефон: 68-5-32	f	large
21311	46128	4121	Краснодарский край, Северский район, поселок Ильский, Партизанская, 161, телефон: 69-5-12	f	large
21308	46125	4118	Краснодарский край, Северский район, поселок Ильский, Мира, 24/Б, телефон: 68-5-36	f	large
21315	46131	4125	Краснодарский край, Северский район, поселок Ильский, Длинная, 104, телефон: 68-5-41	f	large
21310	46127	4120	Краснодарский край, Северский район, поселок Ильский, Длинная, 30, телефон: 68-5-92	f	large
21309	46127	4119	Краснодарский край, Северский район, поселок Ильский, Длинная, 30, телефон: 68-5-92	f	large
21319	46133	4129	Краснодарский край, Северский район, поселок Ильский, 50-Лет Октября, 123	t	large
21318	46133	4128	Краснодарский край, Северский район, поселок Ильский, 50-Лет Октября, 123	t	large
21320	46134	4130	Краснодарский край, Северский район, поселок Дербентская, Калинина, 23	t	small
21306	46123	4116	Краснодарский край, Северский район, поселок Григорьевская, Ленина, 6	f	large
20774	45598	2724	Краснодарский край, Северский район, поселок Веселый, Веселая, 3	f	small
21294	46111	4104	Краснодарский край, Северский район, поселок Афипский, Школьная, 43, телефон: 33-3-13	f	large
21298	46115	4108	Краснодарский край, Северский район, поселок Афипский, Пушкина, 57, телефон: 33-6-12	f	large
21292	46109	4102	Краснодарский край, Северский район, поселок Афипский, Привокзальная, 9, телефон: 34-5-5	f	large
21296	46113	4106	Краснодарский край, Северский район, поселок Афипский, Победы, 9, телефон: 33-1-95	f	large
21295	46112	4105	Краснодарский край, Северский район, поселок Афипский, Победы, 2, телефон: 33-4-56	f	large
21291	46108	4101	Краснодарский край, Северский район, поселок Афипский, Ленина, 11, телефон: 33-5-31	t	medium
21299	46116	4109	Краснодарский край, Северский район, поселок Афипский, Комсомольская, 119, телефон: 33-3-23	f	large
21293	46110	4103	Краснодарский край, Северский район, поселок Афипский, Калинина, 44, телефон: 35-3-96	f	large
21300	46117	4110	Краснодарский край, Северский район, поселок Афипский, 50-лет Октября, 26	f	large
21330	46144	4140	Краснодарский край, Северский район, поселок Ананьевский, Центральная, 9	t	small
21303	46120	4113	Краснодарский край, Северский район, поселок Азовская, Советская, 8	f	large
21278	46095	4023	Краснодарский край, Приморско-Ахтарский район, поселок им. Тамаровского, Школьная, 6	f	medium
21289	46105	4034	Краснодарский край, Приморско-Ахтарский район, поселок Степная, Ленина, 25, телефон: 55209	f	large
21345	46160	4155	Краснодарский край, Приморско-Ахтарский район, поселок Свободный, Центральная, 26	f	small
20215	45047	1817	Краснодарский край, Приморско-Ахтарский район, поселок Свободный, Центральная, 10	f	small
21256	46073	4001	Краснодарский край, Приморско-Ахтарский район, поселок Садки, Чапаева, 98	f	medium
21258	46075	4003	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, ул.Ленина, 70, телефон: 31747	f	large
21260	46077	4005	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, ул. Зеленая, 1А	f	large
21261	46078	4006	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Фестивальная, 2/2, телефон: 20309	f	large
21271	46088	4016	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Строителей, 85, телефон: 30682	f	large
21263	46080	4008	Краснодарский край, Приморско-Ахтарский район, Приморско-Ахтарск, Свободная, 113	f	large
21264	46081	4009	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Ростовская, 35/1	f	large
21259	46076	4004	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Московская, 64, телефон: 33518	f	medium
21266	46083	4011	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Мира, 263, телефон: 34091	f	large
67928	46085	4013	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Ленина, 56, Мира 38	f	large
21257	46074	4002	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Ленина, 15, телефон: 30774	f	large
21267	46084	4012	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Космонавтов, 111, телефон: 21241	f	large
21270	46087	4015	Краснодарский край, Приморско-Ахтарский район, поселок Приморско-Ахтарск, Казачья, 59 - 2, телефон: 31105	f	large
21265	46082	4010	Краснодарский край, Приморско-Ахтарский район, Приморско-Ахтарск, 50 лет Октября, 65, телефон: 34409	f	large
21963	46770	5354	Краснодарский край, Приморско-Ахтарский район, поселок Пригородное, Майкопская, 77, телефон: 32600	f	medium
21286	46102	4031	Краснодарский край, Приморско-Ахтарский район, поселок Приазовская, Ленина, 24, телефон: 56082	f	large
21282	46098	4027	Краснодарский край, Приморско-Ахтарский район, поселок Ольгинская, Ленина, 25	f	large
21284	46100	4029	Краснодарский край, Приморско-Ахтарский район, поселок Ольгинская, Ленина, 100, телефон: 53160	f	medium
21283	46099	4028	Краснодарский край, Приморско-Ахтарский район, поселок Ольгинская, Краснодарская, 11	f	large
111075	46101	4030	Краснодарский край, Приморско-Ахтарский район, поселок Октябрьский, Ленина, 10	f	medium
21272	46089	4017	Краснодарский край, Приморско-Ахтарский район, поселок Огородный, Центральная, 6, телефон: 31105	t	small
21281	46097	4026	Краснодарский край, Приморско-Ахтарский район, поселок Новонекрасовский, Степная, 21, телефон: 51138	t	small
21290	46106	4035	Краснодарский край, Приморско-Ахтарский район, поселок Нов. Лиманокирпили, Бригадная, 35	t	small
21275	46092	4020	Краснодарский край, Приморско-Ахтарский район, поселок Морозовский, ул.Пионера - ул.Тельмана, 15/1 - 23/1, телефон: 58627	f	small
111079	46107	4036	Краснодарский край, Приморско-Ахтарский район, поселок Максима Горького, Центральная, 6	t	\N
20106	44938	1508	Краснодарский край, Приморско-Ахтарский район, поселок Максима Горького, Ленина, 53, телефон: 54-5-53	f	large
111078	46104	4033	Краснодарский край, Приморско-Ахтарский район, поселок Курчанский, Красная, 37	f	medium
20112	44944	1514	Краснодарский край, Приморско-Ахтарский район, поселок Возрождение, Школьная, 4 а, телефон: 56-6-32	t	small
21277	46094	4022	Краснодарский край, Приморско-Ахтарский район, поселок Бриньковская, Красная, 134, телефон: 54522	f	large
21276	46093	4021	Краснодарский край, Приморско-Ахтарский район, поселок Бриньковская, Красная, 79, телефон: 54112	f	large
21274	46091	4019	Краснодарский край, Приморско-Ахтарский район, поселок Бородинская, Ленина, 17, телефон: 51498	f	large
21273	46090	4018	Краснодарский край, Приморско-Ахтарский район, поселок Ахтарский, Горького, 13, телефон: 52174	f	large
86115	42531	4024	Краснодарский край, Приморско-Ахтарский район, поселок Аджановка, Гагарина, 1	f	small
111071	46033	3905	Краснодарский край, Павловский район, поселок Упорный, Ленина, 28, 352061	f	medium
21255	46072	3944	Краснодарский край, Павловский район, поселок Старолеушковская, Красная, 10, телефон: 4-54-58	f	large
21254	46071	3943	Краснодарский край, Павловский район, поселок Старолеушковская, Жлобы, 14	f	large
21249	46066	3938	Краснодарский край, Павловский район, поселок Сред. Челбас, Молодежная, 7 А, телефон: 3-02-62	f	medium
21245	46062	3934	Краснодарский край, Павловский район, поселок Пушкина, Южная, 2	f	small
19905	44736	1028	Краснодарский край, Павловский район, поселок Первомайский, Бендуса, 10, телефон: 5-81-82	f	large
21241	46058	3930	Краснодарский край, Павловский район, поселок Павловская, переулок Вокзальный, железнодорожный вокзал, телефон: 5-40-82	f	large
21235	46052	3924	Краснодарский край, Павловский район, поселок Павловская, Шевченко, 47 А, телефон: 3-13-41	f	large
21234	46051	3923	Краснодарский край, Павловский район, поселок Павловская, Шевченко, 36, телефон: 5-32-34	f	large
21233	46050	3922	Краснодарский край, Павловский район, поселок Павловская, Чкалова, 3, телефон: 5-12-50	f	large
21237	46054	3926	Краснодарский край, Павловский район, поселок Павловская, Спартаковская, 3, телефон: 4-17-81	f	large
21240	46057	3929	Краснодарский край, Павловский район, поселок Павловская, Советская, 66	f	medium
21238	46055	3927	Краснодарский край, Павловский район, поселок Павловская, Промышленная, 22	f	large
21227	46044	3916	Краснодарский край, Павловский район, поселок Павловская, Преградная, 2 А	f	medium
21232	46049	3921	Краснодарский край, Павловский район, поселок Павловская, Ленина, 13, телефон: 5-32-45	f	large
21230	46047	3919	Краснодарский край, Павловский район, поселок Павловская, Крупская, 237, телефон: 3-11-52	f	large
21229	46046	3918	Краснодарский край, Павловский район, поселок Павловская, Комсомольская, 17	f	large
21239	46056	3928	Краснодарский край, Павловский район, поселок Павловская, Заводская, 30, телефон: 5-20-79	f	large
21236	46053	3925	Краснодарский край, Павловский район, поселок Павловская, Гражданская, 21, телефон: 4-17-21	f	large
21231	46048	3920	Краснодарский край, Павловский район, поселок Павловская, Горького, 302, телефон: 5-41-86	f	large
21228	46045	3917	Краснодарский край, Павловский район, станица Павловская, Горького, 354	f	large
21224	46041	3913	Краснодарский край, Павловский район, поселок Новый Урал, Заречная, 1, телефон: 5-85-47	t	small
21243	46060	3932	Краснодарский край, Павловский район, поселок Новый, Колхозная, 78 А	f	small
21221	46038	3910	Краснодарский край, Павловский район, поселок Новопластуновская, Кооперативная, 23 А, телефон: 5-85-32	f	large
21226	46043	3915	Краснодарский край, Павловский район, поселок Новопетровская, Ленина, 29, телефон: 3-05-38	f	large
21217	46034	3906	Краснодарский край, Павловский район, поселок Новолеушковская, Ленина, 8, телефон: 4-43-51	f	large
21219	46036	3908	Краснодарский край, Павловский район, поселок Новолеушковская, Красная, 13, телефон: 4-48-30	f	large
21218	46035	3907	Краснодарский край, Павловский район, поселок Новолеушковская, Жлобы, 70, телефон: 4-45-88	f	large
21225	46042	3914	Краснодарский край, Павловский район, поселок Незамаевская, Ленина, 6 Б, телефон: 3-81-57	f	large
21252	46069	3941	Краснодарский край, Павловский район, поселок Набережный, Красноармейская, 18, телефон: 3-75-32	t	small
21222	46039	3911	Краснодарский край, Павловский район, поселок Междуреченский, Ленина, 15 А, телефон: 5-86-67	t	small
21248	46065	3937	Краснодарский край, Павловский район, поселок Ленинодар, Мира, 63, телефон: 3-02-20	t	small
33832	27609	1129	Волгоградская область, Волжский, Машиностроителей, 13	f	large
21244	46061	3933	Краснодарский край, Павловский район, поселок Краснопартизанское, Советская, 64, телефон: 3-65-64	f	medium
21213	46030	3902	Краснодарский край, Павловский район, поселок Веселая, Ленина, 41 Г	f	large
21250	46067	3939	Краснодарский край, Павловский район, поселок Бейсужек, Степная, 5, телефон: 3-01-68	t	small
21223	46040	3912	Краснодарский край, Павловский район, поселок Бальчанский, Школьная, 12 А, телефон: 5-85-74	t	small
21212	46029	3901	Краснодарский край, Павловский район, станица Атаманская, Ленина, 3	f	large
86127	46002	3825	Краснодарский край, Отрадненский район, поселок Чайкин, Советская, 54	t	small
21179	45996	3819	Краснодарский край, Отрадненский район, поселок Хорин, Южная, 12	t	small
86128	46006	3829	Краснодарский край, Отрадненский район, поселок Хлопонин, Полевая, 31	t	small
22013	46819	5519	Краснодарский край, Отрадненский район, поселок Урупский, Шовгенова, 36, телефон: 65679	f	large
67985	46004	3827	Краснодарский край, Отрадненский район, поселок Урупский, Центральная, 5, 352260	f	large
21190	46007	3830	Краснодарский край, Отрадненский район, поселок Удобная, Международная, 82 Б, телефон: 9-82-98	f	medium
21193	46010	3833	Краснодарский край, Отрадненский район, поселок Удобная, Ленина, 54	f	large
67987	46009	3832	Краснодарский край, Отрадненский район, поселок Удобная, Кооперативная, 25 А	f	large
111062	46008	3831	Краснодарский край, Отрадненский район, станица Удобная, Восточная, 42А	f	medium
21173	45990	3813	Краснодарский край, Отрадненский район, поселок Спокойная Синюха, Казачья, 16	t	small
111068	46018	3841	Краснодарский край, Отрадненский район, поселок Спокойная, Тихая, 9	f	medium
21203	46020	3843	Краснодарский край, Отрадненский район, поселок Спокойная, Ленина, 39	f	medium
67927	46019	3842	Краснодарский край, Отрадненский район, поселок Спокойная, Ленина, 35	f	large
21211	46028	3851	Краснодарский край, Отрадненский район, поселок Солдатская Балка, Шоссейная, 81	t	small
19863	44694	924	Краснодарский край, Отрадненский район, поселок Светлый, Садовая, 13, телефон: 67326	f	small
21178	45995	3818	Краснодарский край, Отрадненский район, поселок Рудь, Ленина, 5, телефон: 9-53-41	f	small
86113	46014	3837	Краснодарский край, Отрадненский район, поселок Романчуков, Центральная, 46	f	small
21177	45994	3817	Краснодарский край, Отрадненский район, станица Попутная, Степная, 11	f	large
67984	45993	3816	Краснодарский край, Отрадненский район, станица Попутная, Мащенко, 11Г	f	large
67983	45991	3814	Краснодарский край, Отрадненский район, станица Попутная, Ленина, 75	f	large
21175	45992	3815	Краснодарский край, Отрадненский район, станица Попутная, Кирова, 68, телефон: 9-22-49	f	large
86124	45989	3812	Краснодарский край, Отрадненский район, поселок Подгорная Синюха, Ленина, 15	f	small
21209	46026	3849	Краснодарский край, Отрадненский район, поселок Подгорная, Шаумяна, 41	f	small
21208	46025	3848	Краснодарский край, Отрадненский район, поселок Подгорная, Комсомольская, 82	f	large
86126	45999	3822	Краснодарский край, Отрадненский район, поселок Пискуновское, Красная, 55	t	small
21184	46001	3824	Краснодарский край, Отрадненский район, поселок Петровское, Ленина, 107, телефон: 9-77-17	f	medium
21204	46021	3844	Краснодарский край, Отрадненский район, поселок Отрадо-Тенгинский, улица Буденного, 106	t	small
21170	45987	3810	Краснодарский край, Отрадненский район, поселок Отрадо-Солдатский, Первомайская, Здание сельского клуба	t	small
21168	45985	3808	Краснодарский край, Отрадненский район, поселок Отрадная, Урупская, 68	f	large
21166	45983	3806	Краснодарский край, Отрадненский район, поселок Отрадная, Урупская, 64, телефон: 3-84-31	f	large
21167	45984	3807	Краснодарский край, Отрадненский район, поселок Отрадная, Овражная, 83	f	large
21162	45979	3802	Краснодарский край, Отрадненский район, поселок Отрадная, Кизилова, 80 А, телефон: 3-12-71	f	large
86114	46024	3847	Краснодарский край, Отрадненский район, поселок Надежная, Трактовая, 45Б	f	small
21205	46022	3845	Краснодарский край, Отрадненский район, поселок Надежная, Лесная, 9 А	f	small
21171	45988	3811	Краснодарский край, Отрадненский район, поселок Маяк, Красная, 14	f	small
67986	46005	3828	Краснодарский край, Отрадненский район, поселок Малотенгинская, пер. Советский, 5	f	large
21200	46017	3840	Краснодарский край, Отрадненский район, поселок Ильич, Ленина, 25	t	small
86125	45997	3820	Краснодарский край, Отрадненский район, поселок Изобильное, Ленина, 33	t	small
21196	46013	3836	Краснодарский край, Отрадненский район, поселок Зеленчук Мостовой, Набережная, 71	f	small
21181	45998	3821	Краснодарский край, Отрадненский район, поселок Гусаровское, Красная, 282, телефон: 9-65-23	f	medium
111056	46000	3823	Краснодарский край, Отрадненский район, поселок Благодарное, Октябрьская, 102-А	f	medium
21186	46003	3826	Краснодарский край, Отрадненский район, поселок Благодарное, Коммунаров, 2 А	f	small
21210	46027	3850	Краснодарский край, Отрадненский район, поселок Бесстрашная, Красная, 35, телефон: 9-47-52	f	small
86121	45891	3318	Краснодарский край, Новопокровский район, поселок Хлебороб, Пролетарская, 26	f	small
20056	44889	1324	Краснодарский край, Новопокровский район, поселок Степной, Советов, 8	f	large
20798	45621	2748	Краснодарский край, Новопокровский район, поселок Степной, Мира, 34, телефон: 7-91-87	f	large
21214	46031	3903	Краснодарский край, Новопокровский район, поселок Северный, Юбилейная, 25, телефон: 4-05-10	f	medium
67976	45895	3322	Краснодарский край, Новопокровский район, поселок Плоская, Красная, 26	f	large
21280	46096	4025	Краснодарский край, Новопокровский район, поселок Новопокровский, Центральная, 18	f	medium
67979	45900	3326	Краснодарский край, Новопокровский район, поселок Новопокровский, Ленина, 16	f	large
21056	45882	3307	Краснодарский край, Новопокровский район, поселок Новопокровская, ул. Первенцева, 1, телефон: 7-11-54	f	large
21050	45875	3301	Краснодарский край, Новопокровский район, поселок Новопокровская, Черняховского, 1, телефон: 75-3-98	f	large
21053	45879	3304	Краснодарский край, Новопокровский район, поселок Новопокровская, Почтовая, 32	f	large
21052	45878	3303	Краснодарский край, Новопокровский район, поселок Новопокровская, Первомайская, 203, телефон: 7-18-92	f	large
21054	45880	3305	Краснодарский край, Новопокровский район, поселок Новопокровская, Ленина, 80, телефон: 7-15-65	f	large
21055	45881	3306	Краснодарский край, Новопокровский район, поселок Новопокровская, Калинина, 103, телефон: 7-15-59	f	large
21051	45876	3302	Краснодарский край, Новопокровский район, поселок Новопокровская, Григорьева, 29, телефон: 7-10-64	f	large
86123	45894	3321	Краснодарский край, Новопокровский район, поселок Новоивановская, Красная, 87	f	small
67974	45890	3317	Краснодарский край, Новопокровский район, поселок Незамаевский, Красная, 18	f	large
19753	44581	663	Краснодарский край, Новопокровский район, поселок Мирный, Шоссейная, 2/1	f	small
67972	45886	3311	Краснодарский край, Новопокровский район, поселок Малокубанский, Светлая, 13 	f	large
111026	45885	3310	Краснодарский край, Новопокровский район, поселок Кубанский, Школьная, 1	f	medium
86117	45884	3309	Краснодарский край, Новопокровский район, поселок Кубанский, Советская, 5а	f	small
19758	44586	668	Краснодарский край, Новопокровский район, поселок Кубанский, Молодежная, 9, телефон: 67-4-30	f	large
67973	41942	3314	Краснодарский край, Новопокровский район, поселок Калниболотская, Фрунзе, 28	f	large
86118	45887	3312	Краснодарский край, Новопокровский район, поселок Калниболотская, Красная , 45	f	small
86120	42071	3315	Краснодарский край, Новопокровский район, поселок Калниболотская, Октябрьская, 27	f	small
111043	45897	3324	Краснодарский край, Новопокровский район, поселок Ильинская, Ленина, 46	f	medium
67977	45896	3323	Краснодарский край, Новопокровский район, поселок Ильинская, Крылова, 91	f	large
67978	45898	3325	Краснодарский край, Новопокровский район, поселок Животновод, Центральная, 12	t	large
86122	45893	3320	Краснодарский край, Новопокровский район, поселок Горькая Балка, Советская , 4	f	small
86119	45888	3313	Краснодарский край, Новопокровский район, поселок Балка Грузская, Клубный переулок, 2	f	small
20775	45599	2725	Краснодарский край, Новокубанский район, поселок Южный, Пролетарская, 38	f	medium
20999	45825	3210	Краснодарский край, Новокубанский район, поселок Энгельса, Урожайная, 16	t	small
21026	45851	3237	Краснодарский край, Новокубанский район, поселок Фортштадт, Свободы, 17	f	small
21001	45810	3212	Краснодарский край, Новокубанский район, поселок Федоровский, Широкая, 14/1	f	medium
19724	44552	634	Краснодарский край, Новокубанский район, поселок Степной, Школьная, 11, телефон: 72-1-37	f	small
21037	45862	3248	Краснодарский край, Новокубанский район, поселок Стебницкий, улица Ленина, 15	f	small
21039	45864	3250	Краснодарский край, Новокубанский район, поселок Советская, улица Октябрьская, 356	f	large
21044	45869	3255	Краснодарский край, Новокубанский район, поселок Советская, Энгельса, 34	f	large
21041	45866	3252	Краснодарский край, Новокубанский район, поселок Советская, Ленина, 293	f	large
20998	45824	3209	Краснодарский край, Новокубанский район, поселок Роте-Фане, Садовая, 40	f	medium
21045	45870	3256	Краснодарский край, Новокубанский район, поселок Родниковский, Мира, 18/2	f	medium
19782	44611	719	Краснодарский край, Новокубанский район, поселок Раздольный, Западная, 14, телефон: 43659	f	small
21038	45863	3249	Краснодарский край, Новокубанский район, поселок Радищево, Школьная, 6, телефон: 5-37-48	f	medium
21028	45853	3239	Краснодарский край, Новокубанский район, поселок Прочноокопская, Ленина, 92	f	large
21027	45852	3238	Краснодарский край, Новокубанский район, поселок Прочноокопская, Ленина, 153	f	large
21767	46581	4951	Краснодарский край, Новокубанский район, поселок Прогресс, Ленина, 31, здание Дома культуры, телефон: 36-6-98	f	medium
20993	45819	3204	Краснодарский край, Новокубанский район, поселок Прогресс, Красноармейская,, 2	f	large
21031	45856	3242	Краснодарский край, Новокубанский район, поселок Передовой, Школьная, 13, телефон: 2-29-25	f	small
21035	45860	3246	Краснодарский край, Новокубанский район, поселок Новосельское, Ленина, 100, телефон: 2-56-40	f	medium
21010	45835	3221	Краснодарский край, Новокубанский район, Новокубанск, Ленина, 60, телефон: 3-28-87	f	large
21009	45834	3220	Краснодарский край, Новокубанский район, Новокубанск, Щорса, 78, телефон: 4-55-69	f	large
21021	45846	3232	Краснодарский край, Новокубанский район, Новокубанск, Тимирязева, 25, телефон: 3-10-91, 3-17-47	f	medium
21012	45837	3223	Краснодарский край, Новокубанский район, город Новокубанск, Суворова, 1, телефон: 3-70-50	f	large
21016	45841	3227	Краснодарский край, Новокубанский район, Новокубанск, Пушкина, 28, телефон: 3-40-83	f	large
21020	45845	3231	Краснодарский край, Новокубанский район, город Новокубанск, Первомайская, 182, телефон: 3-04-65	f	large
21014	45839	3225	Краснодарский край, Новокубанский район, Новокубанск, Первомайская, 23, телефон: 3-12-83	f	medium
21023	45848	3234	Краснодарский край, Новокубанский район, Новокубанск, Обороны, 3, телефон: 3-17-06	f	medium
21022	45847	3233	Краснодарский край, Новокубанский район, Новокубанск, Новаторов, 5, телефон: 3-40-39	f	large
21019	45844	3230	Краснодарский край, Новокубанский район, Новокубанск, Лермонтова, 41, телефон: 3-14-09	f	large
21006	45831	3217	Краснодарский край, Новокубанский район, Новокубанск, Красная, 44, телефон: 3-63-31, 4-14-80	f	large
19588	44417	350	Краснодарский край, Новокубанский район, Новокубанск, Красная, 28	f	large
21002	45827	3213	Краснодарский край, Новокубанский район, поселок Марьинский, Мира, 14, телефон: 2-62-94	f	medium
21024	45849	3235	Краснодарский край, Новокубанский район, поселок Ляпино, Школьная, 5	f	large
21034	45859	3245	Краснодарский край, Новокубанский район, поселок Косякинская, Ленина, 18/2, телефон: 2-29-41	t	small
19738	44566	648	Краснодарский край, Новокубанский район, поселок Комсомольский, Школьная, 17	f	small
20792	45615	2742	Краснодарский край, Новокубанский район, поселок Комсомольский, Комсомольская, 1, телефон: 6-61-35	f	small
20994	45820	3205	Краснодарский край, Новокубанский район, поселок Ковалевское, Мичурина, 46, телефон: 2-75-67	f	large
20997	45823	3208	Краснодарский край, Новокубанский район, поселок Кирова, Мира, 26	f	large
21025	45850	3236	Краснодарский край, Новокубанский район, поселок Камышеваха, Коммунаров, 5, телефон: 2-46-36	f	small
21005	45830	3216	Краснодарский край, Новокубанский район, поселок Измайлов, Механизаторов, 17	f	small
21004	45829	3215	Краснодарский край, Новокубанский район, поселок Зорька, Пионерская, 18, телефон: 2-61-37	f	small
21033	45858	3244	Краснодарский край, Новокубанский район, поселок Горькая Балка, Красноармейская, 57	f	small
21036	45861	3247	Краснодарский край, Новокубанский район, поселок Глубокий, Школьная, 11А, телефон: 2-51-80	f	large
111046	45901	3327	Краснодарский край, Новокубанский район, поселок Восход, Зеленая, 1а	t	medium
20980	45805	3133	Краснодарский край, Мостовский район, поселок Костромская, Ленина, 72	f	large
20992	45818	3203	Краснодарский край, Новокубанский район, поселок Восход, Гагарина, 27, телефон: 2-93-23	f	large
21000	45826	3211	Краснодарский край, Новокубанский район, поселок Большевик, Большевистская, 2	f	small
21047	45872	3258	Краснодарский край, Новокубанский район, поселок Бесскорбная, Московская, 70, телефон: 2-34-25	f	large
21048	45873	3259	Краснодарский край, Новокубанский район, поселок Бесскорбная, Ленина, 247, телефон: 2-34-12	f	large
21049	45874	3260	Краснодарский край, Новокубанский район, поселок Бесскорбная, Ленина, 2	f	medium
20985	45811	3138	Краснодарский край, Мостовский район, поселок Ярославская, Школьная, 21	f	large
20986	45812	3139	Краснодарский край, Мостовский район, поселок Ярославская, Первомайская, 80а	f	medium
20970	45795	3123	Краснодарский край, Мостовский район, поселок Шедок, Ленина, 50, телефон: 6-26-59	f	large
20973	45798	3126	Краснодарский край, Мостовский район, поселок Хамкетинская, улица Красная, 46	f	small
20988	45814	3141	Краснодарский край, Мостовский район, поселок Унароково, Ленина, 25	f	large
20976	45801	3129	Краснодарский край, Мостовский район, поселок Узловой, Клубная, 1, телефон: 6-66-13	f	small
20969	45794	3122	Краснодарский край, Мостовский район, поселок Соленое, Калинина, 36 А	f	medium
20989	45815	3142	Краснодарский край, Мостовский район, поселок Славянский, Дубовая, 34	f	medium
20983	45808	3136	Краснодарский край, Мостовский район, поселок Северный, Комарова, 5	f	small
20979	45804	3132	Краснодарский край, Мостовский район, поселок Свободный Мир, Коммунаров, 52	f	small
20966	45791	3119	Краснодарский край, Мостовский район, поселок Псебай, Советская, 87	f	large
20963	45788	3116	Краснодарский край, Мостовский район, поселок Псебай, Советская, 50	f	large
20962	45787	3115	Краснодарский край, Мостовский район, поселок Псебай, Мостовая, 71, телефон: 6-15-80	f	medium
20965	45790	3118	Краснодарский край, Мостовский район, поселок Псебай, Маяковского, 5, телефон: 6-11-23	f	large
20960	45785	3113	Краснодарский край, Мостовский район, поселок Псебай, Ленина, 14	f	large
20964	45789	3117	Краснодарский край, Мостовский район, поселок Псебай, Красный, 7, телефон: 6-13-75	f	medium
20961	45786	3114	Краснодарский край, Мостовский район, поселок Псебай, Главная, 27, телефон: 6-22-66	f	medium
20107	44939	1509	Краснодарский край, Мостовский район, поселок Пролетарский, Школьная, 2	f	medium
20249	45080	1851	Краснодарский край, Мостовский район, поселок Пролетарский, Центральная, 4, телефон: 51-0-38	t	small
20978	45803	3131	Краснодарский край, Мостовский район, поселок Переправная, Красная, 14	f	large
20967	45792	3120	Краснодарский край, Мостовский район, поселок Перевалка, Садовая, 1, телефон: 6-24-50	f	medium
20959	45784	3112	Краснодарский край, Мостовский район, поселок Первомайский, Мостовая, 39	f	medium
21667	46480	4717	Краснодарский край, Мостовский район, поселок Первомайский, Комсомольская, Сельский Дом культуры, телефон: 5-33-73	f	medium
20948	45772	3101	Краснодарский край, Мостовский район, поселок Мостовской, мкр. Энергетиков, СОШ №30, телефон: 5-38-40	f	large
20952	45776	3105	Краснодарский край, Мостовский район, поселок Мостовской, Советская, 12, телефон: 5-10-93	f	large
20950	45774	3103	Краснодарский край, Мостовский район, поселок Мостовской, Садовая, 33, телефон: 5-10-41	f	large
20956	45780	3109	Краснодарский край, Мостовский район, поселок Мостовской, Мичурина, 22, телефон: 5-16-71	f	large
20951	45775	3104	Краснодарский край, Мостовский район, поселок Мостовской, Ленина, 10, телефон: 5-15-42	f	large
20949	45773	3102	Краснодарский край, Мостовский район, поселок Мостовской, Красная, 46, телефон: 5-15-32	f	large
20957	45781	3110	Краснодарский край, Мостовский район, поселок Мостовской, Комарова, 35, телефон: 5-20-01	f	large
20954	45778	3107	Краснодарский край, Мостовский район, поселок Мостовской, Горького, 142	f	large
20953	45777	3106	Краснодарский край, Мостовский район, поселок Мостовской, Горького, 137, телефон: 5-16-00	f	large
20955	45779	3108	Краснодарский край, Мостовский район, поселок Мостовской, Буденного, 177	f	large
20958	45783	3111	Краснодарский край, Мостовский район, поселок Мостовской, Боженко, 1 Г	f	large
20987	45813	3140	Краснодарский край, Мостовский район, поселок Махошевская, Советская, 8	f	large
20982	45807	3135	Краснодарский край, Мостовский район, поселок Красный Кут, Советская, 41 А	f	small
20801	45624	2751	Краснодарский край, Мостовский район, поселок Высокий, Кузнечная, 17	f	large
20981	45806	3134	Краснодарский край, Мостовский район, поселок Восточный, Ленина, 2, телефон: 6-91-19	f	medium
20977	45802	3130	Краснодарский край, Мостовский район, поселок Бесленеевская, Первомайская, 7	f	large
20974	45799	3127	Краснодарский край, Мостовский район, поселок Беноково, Красная, 35, телефон: 6-71-99	f	large
20972	45797	3125	Краснодарский край, Мостовский район, поселок Баракаевская, Школьная, 29	f	small
20975	45800	3128	Краснодарский край, Мостовский район, поселок Баговская, Клубная, 1	f	medium
20968	45793	3121	Краснодарский край, Мостовский район, поселок Андрюки, Советская улица, 79а	f	large
20934	45758	3022	Краснодарский край, Ленинградский район, поселок Уманский, Школьная, 2, телефон: 5-92-48	f	medium
20945	45769	3033	Краснодарский край, Ленинградский район, поселок Образцовый, Школьная, 12, телефон: 5-53-17	f	large
20942	45766	3030	Краснодарский край, Ленинградский район, поселок Новоплатнировская, Советов, 42, телефон: 7-83-88	f	large
20941	45765	3029	Краснодарский край, Ленинградский район, поселок Новоплатнировская, Ленина, 83	f	large
20916	45740	3004	Краснодарский край, Ленинградский район, поселок Ленинградская, улица Западная, 34	f	large
20918	45742	3006	Краснодарский край, Ленинградский район, поселок Ленинградская, Энергетиков, 1	f	large
20927	45751	3015	Краснодарский край, Ленинградский район, поселок Ленинградская, Школьная, 70 Б	f	large
67971	45745	3009	Краснодарский край, Ленинградский район, поселок Ленинградская, Шевченко , 42а	f	large
20922	45746	3010	Краснодарский край, Ленинградский район, поселок Ленинградская, Чернышевского, 181	f	large
20928	45752	3016	Краснодарский край, Ленинградский район, поселок Ленинградская, Терновая, 23	f	large
20925	45749	3013	Краснодарский край, Ленинградский район, поселок Ленинградская, Пролетарская, 33	f	large
20924	45748	3012	Краснодарский край, Ленинградский район, поселок Ленинградская, Красная, 98 А, телефон: 7-21-55	f	large
20923	45747	3011	Краснодарский край, Ленинградский район, поселок Ленинградская, Красная, Дворец культуры, телефон: 3-73-11	f	large
20920	45744	3008	Краснодарский край, Ленинградский район, поселок Ленинградская, Красная, 1, телефон: 3-71-33	f	large
67970	45737	3001	Краснодарский край, Ленинградский район, поселок Ленинградская, Красная, 247	f	large
20915	45739	3003	Краснодарский край, Ленинградский район, поселок Ленинградская, Кооперации, 127, телефон: 7-07-81	f	large
20914	45738	3002	Краснодарский край, Ленинградский район, поселок Ленинградская, Кооперации, 159, телефон: 7-16-31	f	large
20917	45741	3005	Краснодарский край, Ленинградский район, поселок Ленинградская, Заводская, 3	f	large
20919	45743	3007	Краснодарский край, Ленинградский район, поселок Ленинградская, 20-й Горнострелковой Дивизии, 18	f	large
20926	45750	3014	Краснодарский край, Ленинградский район, поселок Ленинградская, Школьная, 14 А	f	large
20946	45770	3034	Краснодарский край, Ленинградский район, поселок Куликовский, Красная, 96	f	large
20650	45473	2502	Краснодарский край, Ленинградский район, поселок Крыловская, Шевченко, 16, здание Крыловского РС РОСТО (ДОСААФ)	f	large
20931	45755	3019	Краснодарский край, Ленинградский район, поселок Краснострелецкий, Дружная, 14	t	small
20940	45764	3028	Краснодарский край, Ленинградский район, поселок Коржи, Ленина, 1	f	medium
20936	45760	3024	Краснодарский край, Ленинградский район, поселок Звезда, Механическая, 2	f	small
21003	45828	3214	Краснодарский край, Ленинградский район, поселок Западный, Центральная, 18, телефон: 2-61-74	t	small
19737	44565	647	Краснодарский край, Ленинградский район, поселок Высотный, Центральная, 12, телефон: 64-6-19	f	small
20930	45754	3018	Краснодарский край, Ленинградский район, поселок Восточный, Юбилейная, 2	t	small
20944	45768	3032	Краснодарский край, Ленинградский район, поселок Бичевой, Красная, 3, телефон: 4-62-45	f	large
21554	46366	4455	Краснодарский край, Лазаревский район, поселок Малый Кичмай, Убыхская, 39, телефон: 76-21-13	f	small
21508	46320	4409	Краснодарский край, Лазаревский район, поселок Аше, Туристская, 3	f	large
20888	45712	2930	Краснодарский край, Лабинский район, станция Владимирская, Телефонная, 73	f	large
29854	18827	390	Астраханская область, Астрахань, Шелгунова, 12	f	large
20886	45710	2928	Краснодарский край, Лабинский район, поселок Чернореченская, Советская, 28	f	small
20900	45724	2942	Краснодарский край, Лабинский район, поселок Чамлыкская, Центральная, 34, телефон: 62172	f	small
111021	45726	2944	Краснодарский край, Лабинский район, поселок Чамлыкская, Ленина, 74	f	medium
20901	45725	2943	Краснодарский край, Лабинский район, поселок Чамлыкская, Кооперативная, 18, телефон: 62126	f	large
20912	45736	2954	Краснодарский край, Лабинский район, поселок Харьковский, Советская, 2	t	small
20910	45734	2952	Краснодарский край, Лабинский район, поселок Упорная, Ленина, 264	f	large
20909	45733	2951	Краснодарский край, Лабинский район, поселок Упорная, Ленина, телефон: 65347	f	small
20911	45735	2953	Краснодарский край, Лабинский район, поселок Упорная, Набережная, 94	t	small
20903	45727	2945	Краснодарский край, Лабинский район, поселок Соколихин, Школьная, 1, телефон: 60626	t	medium
20907	45731	2949	Краснодарский край, Лабинский район, поселок Сладкий, Ленина, 123	f	medium
20908	45732	2950	Краснодарский край, Лабинский район, поселок Розовый, Парковая, 2	f	medium
20241	45073	1843	Краснодарский край, Лабинский район, Поселок Братский, Садовая, 10Е	f	small
20906	45730	2948	Краснодарский край, Лабинский район, поселок Первая Синюха, Мира, 136	f	large
20904	45728	2946	Краснодарский край, Лабинский район, поселок Отважная, Ленина, 4, телефон: 66434	t	small
67975	45892	3319	Краснодарский край, Лабинский район, поселок Новый Мир, Первомайская, 34	f	large
67966	45687	2906	Краснодарский край, Лабинский район, Лабинск, Школьная, 177	f	large
20883	45707	2925	Краснодарский край, Лабинский район, Лабинск, Центральная, 6	f	large
20862	45685	2904	Краснодарский край, Лабинский район, Лабинск, Леонтьева, 91, телефон: 72674	f	large
20881	45705	2923	Краснодарский край, Лабинский район, Лабинск, Калинина, 65, телефон: 31123	f	large
20860	45644	2902	Краснодарский край, Лабинский район, Лабинск, Воровского, 92, телефон: 74176	f	large
20882	45706	2924	Краснодарский край, Лабинский район, Лабинск, Армавирское шоссе, 12	f	large
20870	45693	2912	Краснодарский край, Лабинский район, город Лабинск, Селиверстова, 26, телефон: 31357	f	large
20880	45704	2922	Краснодарский край, Лабинский район, Лабинск, Победы, 177, телефон: 35619	f	large
67967	45699	2918	Краснодарский край, Лабинский район, Лабинск, Мира, 167	f	large
20872	45695	2914	Краснодарский край, Лабинский район, Лабинск, Международная, 31, телефон: 27104	f	medium
20873	45696	2915	Краснодарский край, Лабинский район, город Лабинск, Маркса, 187, телефон: 34688	f	large
20875	45698	2917	Краснодарский край, Лабинский район, город Лабинск, Красная, 102, телефон: 31764	f	large
20871	45694	2913	Краснодарский край, Лабинский район, Лабинск, Красная, 27, телефон: 33464	f	large
20869	45692	2911	Краснодарский край, Лабинский район, город Лабинск, Красная, 14, телефон: 26149	f	large
67968	45702	2920	Краснодарский край, Лабинский район, город Лабинск, Коммунаров, 7/1	f	large
20865	45688	2907	Краснодарский край, Лабинский район, город Лабинск, Делегатская, 9/1, телефон: 32828	f	large
20861	45684	2903	Краснодарский край, Лабинский район, Лабинск, Д.Бедного, 67, телефон: 73830	f	large
20863	45686	2905	Краснодарский край, Лабинский район, Лабинск, Военная, 69, телефон: 74089	f	large
20877	45701	2919	Краснодарский край, Лабинский район, Лабинск, Владимирская, 171, телефон: 69344	f	large
20866	45689	2908	Краснодарский край, Лабинский район, город Лабинск, 40 лет Октября, 121, телефон: 31118	f	large
67969	45723	2941	Краснодарский край, Лабинский район, поселок Каладжинская, Ленина, 69	f	large
20898	45722	2940	Краснодарский край, Лабинский район, поселок Зассовская, Советская, 15, телефон: 78419	f	large
20897	45721	2939	Краснодарский край, Лабинский район, поселок Ереминская, Ленина, 1, телефон: 70013	t	small
20905	45729	2947	Краснодарский край, Лабинский район, поселок Гофицкое, Ленина, 146	f	small
20892	45716	2934	Краснодарский край, Лабинский район, поселок Вознесенская, Мира, 76, телефон: 70131	f	large
20891	45715	2933	Краснодарский край, Лабинский район, поселок Вознесенская, Мира, 186, телефон: 70120	f	small
20893	45717	2935	Краснодарский край, Лабинский район, поселок Вознесенская, Калмыкова, 9, телефон: 70765	f	small
20894	45718	2936	Краснодарский край, Лабинский район, поселок Вознесенская, 50 лет Октября, 26, телефон: 70198	f	medium
20887	45711	2929	Краснодарский край, Лабинский район, поселок Владимирская, Чапаева, 10, телефон: 63528	f	large
20889	45713	2931	Краснодарский край, Лабинский район, поселок Владимирская, Телефонная, 32, телефон: 63557	f	large
20890	45714	2932	Краснодарский край, Лабинский район, поселок Владимирская, Гагарина, 136, телефон: 63439	f	large
22011	46817	5517	Краснодарский край, Лабинский район, поселок Веселый, Почтовая, 12	f	large
20047	44880	1315	Калужская область, Жиздринский район, поселок Братский	t	small
20885	45709	2927	Краснодарский край, Лабинский район, поселок Ахметовская, Краснопартизанская, 13, телефон: 66233	f	large
20857	45682	2848	Краснодарский край, Кущевский район, поселок Шкуринская, Ленина, 26, телефон: 4-53-64	f	large
20856	45681	2847	Краснодарский край, Кущевский район, поселок Шкуринская, Ленина, 54, телефон: 4-51-64	f	large
20855	45680	2846	Краснодарский край, Кущевский район, поселок Тауруп 1-й, Комсомольская, 2, телефон: 4-45-83	f	small
20824	45649	2815	Краснодарский край, Кущевский район, поселок Степное, Школьная, 2/1, телефон: 4-17-95	f	small
20851	45676	2842	Краснодарский край, Кущевский район, поселок Средние Чубурки, Красная, 81	f	small
20850	45675	2841	Краснодарский край, Кущевский район, поселок Средние Чубурки, Красная, 67	f	medium
20852	45677	2843	Краснодарский край, Кущевский район, хутор Средние Чубурки, Октябрьская, 21	f	medium
20823	45648	2814	Краснодарский край, Кущевский район, поселок Северный, Школьная, 1/5	t	small
20825	45650	2816	Краснодарский край, Кущевский район, поселок Садовый, Мира, 65, телефон: 4-26-91	f	small
20829	45654	2820	Краснодарский край, Кущевский район, поселок Ровный, Центральная, 1	t	small
20844	45669	2835	Краснодарский край, Кущевский район, поселок Раздольное, Красная, 63, телефон: 3-41-31	f	large
20235	45067	1837	Краснодарский край, Кущевский район, поселок Пролетарский, Школьная, 10	f	large
20842	45667	2833	Краснодарский край, Кущевский район, поселок Пролетарский, Центральная, 11	f	medium
20843	45668	2834	Краснодарский край, Кущевский район, поселок Полтавченское, Трудовая, 1	f	medium
20840	45665	2831	Краснодарский край, Кущевский район, поселок Первомайский, Советская, 10, телефон: 4-84-86	f	large
19736	44564	646	Краснодарский край, Кущевский район, поселок Первомайский, Советская, 6, телефон: 64-1-83	f	medium
20858	45683	2849	Краснодарский край, Кущевский район, поселок Первомайский, Первомайская, 11	f	medium
20838	45663	2829	Краснодарский край, Кущевский район, поселок Новомихайловское, Школьная, 11, телефон: 4-93-08	f	large
20827	45652	2818	Краснодарский край, Кущевский район, поселок Новоивановское, Парковая, 8, телефон: 4-16-16	f	small
20854	45679	2845	Краснодарский край, Кущевский район, поселок Нововысоченский, Центральная, 24, телефон: 4-41-79	f	small
20826	45651	2817	Краснодарский край, Кущевский район, поселок Мирный, Мира, 9, телефон: 3-20-15	f	small
20820	45645	2811	Краснодарский край, Кущевский район, поселок Кущевская, переулок Школьный, 56	f	large
20819	45643	2810	Краснодарский край, Кущевский район, поселок Кущевская, переулок Школьный, 55, телефон: 4-07-63	f	large
67965	45639	2806	Краснодарский край, Кущевский район, поселок Кущевская, переулок Кавказский, 134	f	large
20810	45634	2801	Краснодарский край, Кущевский район, поселок Кущевская, переулок Б.Е. Москвича, 80, телефон: 5-46-69	f	large
20817	45641	2808	Краснодарский край, Кущевский район, поселок Кущевская, Элеваторная, 42, телефон: 5-47-44	f	large
20814	45638	2805	Краснодарский край, Кущевский район, поселок Кущевская, Ленинградская, 74, телефон: 5-57-65	f	large
20813	45637	2804	Краснодарский край, Кущевский район, поселок Кущевская, Ленина, 89, телефон: 5-40-41	f	large
20812	45636	2803	Краснодарский край, Кущевский район, поселок Кущевская, Ленина, 46, телефон: 5-40-69	f	large
20811	45635	2802	Краснодарский край, Кущевский район, поселок Кущевская, Ленина, 12	f	large
20816	45640	2807	Краснодарский край, Кущевский район, поселок Кущевская, Красногвардейская, 1, телефон: 5-43-22	f	large
20818	45642	2809	Краснодарский край, Кущевский район, поселок Кущевская , 2, здание МБОУ СОШ №30 (микрорайон Кущёвка - 2), телефон: 5-13-19	f	large
20821	45646	2812	Краснодарский край, Кущевский район, станица Кущевская, Ейская, 83	f	small
21215	46032	3904	Краснодарский край, Кущевский район, поселок Красный, Советская, 40, телефон: 4-03-22	f	medium
21816	46630	5046	Краснодарский край, Кущевский район, поселок Красный, Длинная, 34	f	small
20835	45660	2826	Краснодарский край, Кущевский район, поселок Красное, переулок Советов, 13, телефон: 3-51-78	f	large
20836	45661	2827	Краснодарский край, Кущевский район, поселок Красное, Клубный переулок, 3	f	large
20834	45659	2825	Краснодарский край, Кущевский район, поселок Красная Поляна, Мира, 55	f	medium
20841	45666	2832	Краснодарский край, Кущевский район, поселок Комсомольский, Центральная, 16, телефон: 3-81-68	f	large
20839	45664	2830	Краснодарский край, Кущевский район, поселок Коммунар, Мира, 1, телефон: 4-94-43	t	small
20832	45657	2823	Краснодарский край, Кущевский район, поселок Кисляковская, Красная, 45, телефон: 4-31-44	f	large
20831	45656	2822	Краснодарский край, Кущевский район, поселок Кисляковская, Красная, 150, телефон: 4-33-01	f	large
20833	45658	2824	Краснодарский край, Кущевский район, поселок Кисляковка, Восточная, 3	t	small
20853	45678	2844	Краснодарский край, Кущевский район, поселок Исаевский, Садовая, 31	f	small
20830	45655	2821	Краснодарский край, Кущевский район, поселок Ильинское, переулок Школьный, 6, телефон: 3-22-42	f	large
20848	45673	2839	Краснодарский край, Кущевский район, поселок Ивано-Слюсаревское, Нижняя, 11/1, телефон: 4-23-11	f	small
20847	45672	2838	Краснодарский край, Кущевский район, поселок Зеленая Роща, улица Целинная, 16	f	small
20849	45674	2840	Краснодарский край, Кущевский район, поселок Гослесопитомник, Ленина, 60, телефон: 4-24-46	f	small
20828	45653	2819	Краснодарский край, Кущевский район, поселок Глебовка, Братская, 33, телефон: 3-76-75	f	large
20845	45670	2836	Краснодарский край, Кущевский район, поселок Водяная Балка, Красная, 54, телефон: 3-41-31	f	small
20822	45647	2813	Краснодарский край, Кущевский район, поселок Бол. Лопатина, Большелопатинская, 1, телефон: 4-71-80	f	medium
20846	45671	2837	Краснодарский край, Кущевский район, поселок Алексеевское, Школьная, 7, телефон: 3-72-43	f	small
20796	45619	2746	Краснодарский край, Курганинский район, поселок Щебенозаводской, Заводская, 1 А, телефон: 7-98-01	f	small
20799	45622	2749	Краснодарский край, Курганинский район, поселок Урмия, Магистральная, 2	f	medium
20784	45608	2734	Краснодарский край, Курганинский район, поселок Темиргоевская, Школьная, 22, телефон: 7-15-89	f	large
20782	45606	2732	Краснодарский край, Курганинский район, поселок Темиргоевская, Прогонная, 43, телефон: 7-11-84	f	large
20783	45607	2733	Краснодарский край, Курганинский район, поселок Темиргоевская, Мира, 12	f	large
20786	45610	2736	Краснодарский край, Курганинский район, поселок Темиргоевская, Ленина, 62, телефон: 7-12-82	f	large
20788	45612	2738	Краснодарский край, Курганинский район, поселок Сухой Кут, Красная, 44, телефон: 7-51-90	f	small
20794	45617	2744	Краснодарский край, Курганинский район, поселок Светлая Заря, Центральная, 76, телефон: 7-43-68	f	medium
20805	45628	2755	Краснодарский край, Курганинский район, поселок Родниковская, Первомайская, 152, телефон: 6-42-27	f	large
20809	45633	2759	Краснодарский край, Курганинский район, поселок Родниковская, Курганинская, 88	f	large
20804	45627	2754	Краснодарский край, Курганинский район, поселок Родниковская, Курганинская, 88, телефон: 6-41-57	f	large
20806	45629	2756	Краснодарский край, Курганинский район, поселок Родниковская, Кирова, 143, телефон: 6-44-16	f	large
20776	45600	2726	Краснодарский край, Курганинский район, поселок Петропавловская, Энгельса, 3	f	medium
20777	45601	2727	Краснодарский край, Курганинский район, поселок Петропавловская, Пролетарская, 69	f	medium
20780	45604	2730	Краснодарский край, Курганинский район, поселок Петропавловская, Победы, 15	f	medium
20778	45602	2728	Краснодарский край, Курганинский район, поселок Петропавловская, КИМ, 51, телефон: 6-31-01	f	large
20779	45603	2729	Краснодарский край, Курганинский район, поселок Петропавловская, Гагарина, 49, телефон: 6-27-78	f	large
20800	45623	2750	Краснодарский край, Курганинский район, поселок Новоалексеевская, 50 лет ВЛКСМ, 10	f	large
20771	45595	2721	Краснодарский край, Курганинский район, поселок Михайловская, Революционная, 52, телефон: 6-17-98	f	large
20768	45592	2718	Краснодарский край, Курганинский район, поселок Михайловская, Острецова, 247, телефон: 6-12-72	f	large
20770	45594	2720	Краснодарский край, Курганинский район, поселок Михайловская, Октябрьская, 79, телефон: 6-13-72	f	large
20769	45593	2719	Краснодарский край, Курганинский район, поселок Михайловская, Ленина, 148, телефон: 6-14-85	f	large
20791	45580	2741	Краснодарский край, Курганинский район, поселок Мира, Мира, 1, телефон: 6-61-12	f	small
20751	45574	2701	Краснодарский край, Курганинский район, город Курганинск, Чапаева, 1, телефон: 2-99-58	f	large
20807	45630	2757	Краснодарский край, Курганинский район, Курганинск, Серикова, 56, телефон: 2-66-01	f	large
20808	45632	2758	Краснодарский край, Курганинский район, город Курганинск, Розы Люксембург, 293, телефон: 2-25-16	f	large
20752	45575	2702	Краснодарский край, Курганинский район, город Курганинск, Пушкина, 57 А, телефон: 2-10-75	f	large
20753	45576	2703	Краснодарский край, Курганинский район, город Курганинск, Первомайская, 1, телефон: 2-13-80	f	large
20755	45578	2705	Краснодарский край, Курганинский район, Курганинск, Партизанская, 154, телефон: 2-35-28	f	large
20754	45577	2704	Краснодарский край, Курганинский район, Курганинск, Партизанская, 154, телефон: 2-29-47	f	large
20758	45582	2708	Краснодарский край, Курганинский район, Курганинск, Луговая, 3, телефон: 2-02-80	f	large
20764	45588	2714	Краснодарский край, Курганинский район, Курганинск, Ленина, 151, телефон: 2-27-85	f	large
20757	45581	2707	Краснодарский край, Курганинский район, город Курганинск, Коммунистическая, 77, телефон: 2-261-9	f	large
20763	45587	2713	Краснодарский край, Курганинский район, Курганинск, Калинина, 48, телефон: 2-10-17	f	large
20759	45583	2709	Краснодарский край, Курганинский район, город Курганинск, Заводская, 20	f	large
20761	45585	2711	Краснодарский край, Курганинский район, Курганинск, Демьяна Бедного, 213, телефон: 2-23-37	f	large
20760	45584	2710	Краснодарский край, Курганинский район, город Курганинск, Бедного, 313, телефон: 3-13-90	f	large
20772	45596	2722	Краснодарский край, Курганинский район, поселок Красный, Синюхинская, 10, телефон: 6-13-01	f	small
20766	45590	2716	Краснодарский край, Курганинский район, поселок Красное Поле, Кочубея, 109	f	small
20773	45597	2723	Краснодарский край, Курганинский район, поселок Красное Знамя, Коммунаров, 16/1	f	small
20797	45620	2747	Краснодарский край, Курганинский район, поселок Кочергин, Северная, 50, телефон: 7-98-73	f	small
20803	45626	2753	Краснодарский край, Курганинский район, поселок Константиновская, Кирова, 63, телефон: 7-32-53	f	large
20802	45625	2752	Краснодарский край, Курганинский район, поселок Константиновская, Калинина, 100	f	medium
20787	45611	2737	Краснодарский край, Курганинский район, поселок Воздвиженская, Советская, 12 А,, телефон: 7-51-36	f	large
20795	45618	2745	Краснодарский край, Курганинский район, поселок Андрее-Дмитриевский, Элеваторная, 1	f	small
20032	44865	1248	Краснодарский край, Крымский район, поселок Южный, Садовая, 36, телефон: 13-03-04	f	large
20707	45530	2622	Краснодарский край, Крымский район, поселок Экономическое, Почтовая, 12	f	large
21354	46169	4164	Краснодарский край, Крымский район, поселок Черноморский, Суворова, 2, телефон: 66-3-56	f	large
20743	45566	2658	Краснодарский край, Крымский район, поселок Черноморский, Ленина, 7	f	medium
21352	46167	4162	Краснодарский край, Крымский район, поселок Черноморский, Кирова, 30, телефон: 66-3-31	f	large
21356	46171	4166	Краснодарский край, Крымский район, поселок Черноморский, Гоголя, 10, телефон: 67-0-00	f	large
20725	45548	2640	Краснодарский край, Крымский район, поселок Фадеево, Школьная, 2а, телефон: 6-24-24	t	small
20738	45561	2653	Краснодарский край, Крымский район, поселок Троицкая, Советская, 60, телефон: 6-71-95	f	large
20737	45560	2652	Краснодарский край, Крымский район, поселок Троицкая, Пестеля, 58, телефон: 6-73-84	f	large
20733	45556	2648	Краснодарский край, Крымский район, поселок Саукдере, улица Школьная, 6	f	large
20730	45553	2645	Краснодарский край, Крымский район, поселок Русское, Высоцкой, 22а, телефон: 6-90-09	f	small
20884	45708	2926	Краснодарский край, Крымский район, поселок Прохладный, Коммунистическая, 45	f	large
20048	44881	1316	Краснодарский край, Крымский район, поселок Пролетарский, Зеленая, 22А	t	small
20749	45572	2664	Краснодарский край, Крымский район, поселок Плавненский, Широкая, 11в	f	medium
20734	45557	2649	Краснодарский край, Крымский район, поселок Новоукраинский, Комарова, 5, телефон: 7-64-15	f	large
20750	45573	2665	Краснодарский край, Крымский район, поселок Новоукраинский, Кирова, 1в	f	large
20744	45567	2659	Краснодарский край, Крымский район, поселок Новотроицкий, Шоссейная, 61	f	medium
20719	45542	2634	Краснодарский край, Крымский район, поселок Новопокровское, Новопокровская, 5а, телефон: 7-52-32	f	small
21922	46730	5313	Краснодарский край, Крымский район, поселок Новомихайловский, Мира, 67	f	large
20729	45552	2644	Краснодарский край, Крымский район, поселок Новокрымский, Фроловой, 10а, телефон: 6-93-37	f	small
20747	45570	2662	Краснодарский край, Крымский район, станица Нижнебаканская, Горького, 37, телефон: 2-88-92	f	large
20746	45569	2661	Краснодарский край, Крымский район, поселок Нижнебаканская, Октябрьская, 5, телефон: 2-82-24	f	large
20720	45543	2635	Краснодарский край, Крымский район, поселок Непиль, Кубанская, 12а	f	medium
20748	45571	2663	Краснодарский край, Крымский район, поселок Неберджаевская, Ленина, 48, телефон: 6-45-05	f	large
20731	45554	2646	Краснодарский край, Крымский район, поселок Молдаванское, Ленина, 11а, телефон: 6-93-33	f	large
20739	45562	2654	Краснодарский край, Крымский район, поселок Могукоровский, Пролетарская, 46, телефон: 6-71-40	f	small
20736	45559	2651	Краснодарский край, Крымский район, поселок Мерчанское, Мира, 6, телефон: 6-57-67	f	large
19469	44297	141	Краснодарский край, Крымский район, поселок Ленинский, Кирова, 69А	f	medium
20740	45563	2655	Краснодарский край, Крымский район, поселок Кувичинский, Зеленая, 59, телефон: 6-73-33	f	small
20718	45541	2633	Краснодарский край, Крымский район, поселок Кубанская Колонка, Жукова, 51, телефон: 7-52-81	f	small
20694	45516	2609	Краснодарский край, Крымский район, город Крымск, Фурманова, 40а, телефон: 4-05-00	f	large
20700	45522	2615	Краснодарский край, Крымский район, Крымск, Фадеева, 60, телефон: 4-66-12	f	large
20689	45430	2604	Краснодарский край, Крымский район, город Крымск, Свердлова, 5, телефон: 3-63-68	f	large
20686	45509	2601	Краснодарский край, Крымский район, город Крымск, Родниковая, 2, телефон: 5-13-21	f	large
20693	45515	2608	Краснодарский край, Крымский район, город Крымск, Луначарского, 9, телефон: 2-70-96	f	large
20698	45520	2613	Краснодарский край, Крымский район, город Крымск, Ленина, 168, телефон: 4-23-67	f	large
20691	45513	2606	Краснодарский край, Крымский район, Крымск, Энергетиков, 61, телефон: 2-74-10	f	medium
20687	45510	2602	Краснодарский край, Крымский район, Крымск, Привокзальная, 16, телефон: 5-10-63	f	large
20703	45525	2618	Краснодарский край, Крымский район, Крымск, Луначарского, 303, телефон: 4-33-00	f	large
20692	45514	2607	Краснодарский край, Крымский район, Крымск, Луначарского, 116, телефон: 4-02-01	f	large
20704	45526	2619	Краснодарский край, Крымский район, Крымск, Либкнехта, 40, телефон: 4-89-93	f	large
20699	45521	2614	Краснодарский край, Крымский район, Крымск, Ленина, 231, телефон: 4-79-57	f	large
20697	45519	2612	Краснодарский край, Крымский район, Крымск, Крупской, 33	f	large
20688	45511	2603	Краснодарский край, Крымский район, Крымск, Гречко, 10а, телефон: 4-60-23	f	large
20696	45518	2611	Краснодарский край, Крымский район, Крымск, Горная, 13, телефон: 4-34-55	f	large
20705	45527	2620	Краснодарский край, Крымский район, Крымск, 50 лет Октября, 20, телефон: 4-22-01	f	large
20745	45568	2660	Краснодарский край, Крымский район, поселок Красный, Школьная, 3, телефон: 2-29-56	f	medium
20712	45535	2627	Краснодарский край, Крымский район, поселок Красная Батарея, Комсомольская, 47а, телефон: 7-90-73	f	medium
20709	45532	2624	Краснодарский край, Крымский район, поселок Киевское, Красная, 117г	f	large
20710	45533	2625	Краснодарский край, Крымский район, поселок Киевское, Горького, 116, телефон: 6-02-49	f	large
20711	45534	2626	Краснодарский край, Крымский район, поселок Кеслерово, Гастелло, 29, телефон: 7-37-39	f	medium
20932	45756	3020	Краснодарский край, Крымский район, поселок Западный, Светлая, 153 а	f	medium
20742	45565	2657	Краснодарский край, Крымский район, поселок Евсеевский, Школьная, 11	t	small
20728	45551	2643	Краснодарский край, Крымский район, поселок Даманка, Молодежная, 73, телефон: 6-11-66	f	large
20716	45539	2631	Краснодарский край, Крымский район, поселок Гладковская, Центральная, 19, телефон: 6-27-03	f	small
20708	45531	2623	Краснодарский край, Крымский район, поселок Гвардейское, Колобова, 16, телефон: 4-56-05	t	small
20724	45547	2639	Краснодарский край, Крымский район, поселок Варениковская, Пушкина, 250, телефон: 7-14-58	f	large
29949	19488	497	Астраханская область, Астрахань, Луконина, 4а	f	large
20721	45544	2636	Краснодарский край, Крымский район, поселок Варениковская, Красная, 74	f	large
20727	45550	2642	Краснодарский край, Крымский район, поселок Варениковская, Железнодорожная, 2, телефон: 7-13-35	f	large
20722	45545	2637	Краснодарский край, Крымский район, станица Варениковская, Чапаева, 53, телефон: 7-14-50	f	large
20723	45546	2638	Краснодарский край, Крымский район, станица Варениковская, Советская, 41	f	large
20735	45558	2650	Краснодарский край, Крымский район, поселок Армянский, Миронова, 1, телефон: 6-40-27	f	large
20717	45540	2632	Краснодарский край, Крымский район, поселок Адагум, Ленина, 47, телефон: 7-54-22	f	large
20680	45503	2532	Краснодарский край, Крыловский район, отделение N5 совхоза Новосергиеский, Пушкина, 16/2, здание ФП, телефон: 37379	t	small
20676	45499	2528	Краснодарский край, Крыловский район, отделение N1 Совхоза Новосергиевский, Центральная, 1/2, помещение фельдш-го пункта	f	small
20658	45481	2510	Краснодарский край, Крыловский район, поселок Шевченковское, Свердликова, 45, здание МОУ СОШ № 4	f	medium
20666	45489	2518	Краснодарский край, Крыловский район, поселок Темп, переулок Парковый, 7, здание магазина	t	small
20673	45496	2525	Краснодарский край, Крыловский район, поселок Тверской, Первомайская, 30а, телефон: 37820	t	small
20684	45507	2536	Краснодарский край, Крыловский район, поселок Сиротино, Ленина, 65, здание СК Сиротино	f	small
20665	45488	2517	Краснодарский край, Крыловский район, поселок Сборный, Хлеборобная, 60/1, телефон: 38761, помещение для приема по личным вопросам депутата сельского	t	small
20670	45493	2522	Краснодарский край, Крыловский район, поселок Решетиловский, Суворова, 1, здание МОУ НОШ № 18, телефон: 35927	t	small
20938	45762	3026	Краснодарский край, Крыловский район, поселок Октябрьская, Юбилейная, 6	f	large
20654	45477	2506	Краснодарский край, Крыловский район, Октябрьская, Чкалова, 33, здание филиала МУК СДК Крыловский	f	medium
20661	45484	2513	Краснодарский край, Крыловский район, поселок Октябрьская, Центральная, 2, здание филиала МУК СДК Авангард	f	medium
20664	45487	2516	Краснодарский край, Крыловский район, поселок Октябрьская, Трудовая, 347, здание конторы отделения № 2 ОАО Знамя Октябрь	f	small
20685	45508	2537	Краснодарский край, Крыловский район, поселок Октябрьская, Первомайская, 86, телефон: 31634	f	large
20939	45763	3027	Краснодарский край, Крыловский район, поселок Октябрьская, Ленина, 9	f	large
19748	44576	658	Краснодарский край, Крыловский район, поселок Октябрьская, Красная, 8, телефон: 61-6-98	f	small
20653	45476	2505	Краснодарский край, Крыловский район, поселок Октябрьская, Кооперативная, 69, здание ДК Нива, телефон: 31463	f	large
20663	45486	2515	Краснодарский край, Крыловский район, поселок Октябрьская, Кондратюка, 198, здание филиала МУК СДК Октябрь, телефон: 36250	f	large
20662	45485	2514	Краснодарский край, Крыловский район, поселок Октябрьская, Кондратюка, 20, здание МОУ СОШ № 6	f	large
20649	45472	2501	Краснодарский край, Крыловский район, поселок Октябрьская, Комсомольская, 162, здание МОУ СОШ № 3, телефон: 32565	f	large
20651	45474	2503	Краснодарский край, Крыловский район, поселок Октябрьская, Кирова, 1, здание дом детского творчества, телефон: 32247	f	large
20659	45482	2511	Краснодарский край, Крыловский район, поселок Октябрьская, Зеленый переулок, 3, здание МУК СДК Октябрьский	f	large
20667	45490	2519	Краснодарский край, Крыловский район, поселок Обильный, Лермонтова, 18, здание филиала МУК СДК, телефон: 39920	f	small
20675	45498	2527	Краснодарский край, Крыловский район, поселок Новосергиевская, Школьная, 8, телефон: 34245	f	large
20677	45500	2529	Краснодарский край, Крыловский район, поселок Новосергиевская, Красная, 12/2, Центр отделения № 2 ЗАО Новосергиевское, здание ФП	t	small
20671	45494	2523	Краснодарский край, Крыловский район, поселок Новопашковская, Первомайская, 43, здание МОУ СОШ № 8	f	medium
20681	45504	2533	Краснодарский край, Крыловский район, поселок Кугоейская, Ленина, 49а	f	large
20937	45761	3025	Краснодарский край, Крыловский район, станица Крыловская, Энгельса, 138, телефон: 7-70-58	f	large
20657	45480	2509	Краснодарский край, Крыловский район, станица Крыловская, Халтурина, 35, здание офиса врача общей практики	f	medium
20269	45099	1914	Краснодарский край, Красноармейский район, поселок Полтавская, Народная, 3	f	medium
20656	45479	2508	Краснодарский край, Крыловский район, станица Крыловская, Орджоникидзе, 145, здание конторы МУП Водоканал	f	medium
20652	45475	2504	Краснодарский край, Крыловский район, станица Крыловская, Орджоникидзе, 41, здание МОУ СОШ № 2	f	large
20669	45492	2521	Краснодарский край, Крыловский район, поселок Ковалевка, Фермерская, 7, здание МОУ НОШ № 17	t	small
20678	45501	2530	Краснодарский край, Крыловский район, поселок Ключевой, Черемушки, 1, здание сельского клуба	t	small
19591	44420	353	Краснодарский край, Крыловский район, поселок Калинин, пер. Школьный, 1, телефон: 26888	f	medium
20683	45506	2535	Краснодарский край, Крыловский район, поселок Калинин, Калинина, 69а, здание ФП	t	small
20682	45505	2534	Краснодарский край, Крыловский район, поселок Ириновка, Мира, 12, здание сельского клуба	t	small
20668	45491	2520	Краснодарский край, Крыловский район, поселок Запрудный, Советская, 1, телефон: 35819	f	small
20674	45497	2526	Краснодарский край, Крыловский район, поселок Грузское, Трудовая, 13а, здание фельдшерского пункта	t	small
20679	45502	2531	Краснодарский край, Крыловский район, поселок Водораздельный, Центральная, 7/3, здание фельдшерского пункта, телефон: 34311	t	small
20314	45145	1959	Краснодарский край, Красноармейский район, поселок Элитный, Садовая, 5, телефон: 93-5-89	f	medium
20293	45124	1938	Краснодарский край, Красноармейский район, хутор Чигрина, Центральная, 5	t	medium
20307	45138	1952	Краснодарский край, Красноармейский район, поселок Чебургольская, ул.Школьная, 2, телефон: 93-2-44	f	large
20290	45121	1935	Краснодарский край, Красноармейский район, поселок Трудобеликовский, Школьная, 1, телефон: 99-8-44	f	large
20288	45119	1933	Краснодарский край, Красноармейский район, поселок Трудобеликовский, Школьная, 1, телефон: 99-1-82	f	large
20291	45122	1936	Краснодарский край, Красноармейский район, поселок Трудобеликовский, Садовая, 70, телефон: 49-0-36	f	large
20289	45120	1934	Краснодарский край, Красноармейский район, поселок Трудобеликовский, Набережная, 387/3, телефон: 99-8-78	t	large
20292	45123	1937	Краснодарский край, Красноармейский район, поселок Трудобеликовский, Мазуренко, 58	f	large
20294	45125	1939	Краснодарский край, Красноармейский район, поселок Тиховский, Школьная, 25	f	medium
20316	45148	1961	Краснодарский край, Красноармейский район, поселок Старонижестеблиевская, Северная, 30, телефон: 97-7-11	f	large
20320	45152	1965	Краснодарский край, Красноармейский район, поселок Старонижестеблиевская, Мира, 56, телефон: 97-1-89	f	large
20318	45150	1963	Краснодарский край, Красноармейский район, поселок Старонижестеблиевская, Мира, 179, телефон: 97-2-15	f	large
20317	45149	1962	Краснодарский край, Красноармейский район, поселок Старонижестеблиевская, Мира, 174, телефон: 97-3-51	f	large
20319	45151	1964	Краснодарский край, Красноармейский район, поселок Старонижестеблиевская, Батарейная, 4, телефон: 97-4-74	f	large
20309	45140	1954	Краснодарский край, Красноармейский район, поселок Староджерелиевская, Красная, 102/А, телефон: 95-3-37	f	large
20310	45141	1955	Краснодарский край, Красноармейский район, поселок Староджерелиевская, Дружбы, 9	f	medium
20283	45114	1928	Краснодарский край, Красноармейский район, поселок Рисоопытный, Мира, 1, телефон: 92-2-15	f	medium
20308	45139	1953	Краснодарский край, Красноармейский район, поселок Протоцкие, Набережная, 50, телефон: 95-6-30	f	large
20311	45142	1956	Краснодарский край, Красноармейский район, поселок Протичка, Красная, 44, телефон: 93-3-18	f	large
20275	45105	1920	Краснодарский край, Красноармейский район, поселок Прикубанский, Центральная, 46	t	small
20264	45094	1909	Краснодарский край, Красноармейский район, поселок Полтавская, Элеваторная, 60/2	f	medium
20256	45086	1901	Краснодарский край, Красноармейский район, поселок Полтавская, Школьная, 9, телефон: 3-35-23	f	large
20266	45096	1911	Краснодарский край, Красноармейский район, поселок Полтавская, Шевченко, 3, телефон: 3-18-35	f	large
20270	45100	1915	Краснодарский край, Красноармейский район, поселок Полтавская, Центральная, 60	f	medium
20257	45087	1902	Краснодарский край, Красноармейский район, поселок Полтавская, Таманская, 148/А, телефон: 3-15-95	f	large
20261	45091	1906	Краснодарский край, Красноармейский район, поселок Полтавская, Просвещения, 198, телефон: 3-28-31	f	large
29950	19488	498	Астраханская область, Астрахань, Луконина, 4а	f	large
20265	45095	1910	Краснодарский край, Красноармейский район, поселок Полтавская, Народная, 157	f	medium
20262	45092	1907	Краснодарский край, Красноармейский район, поселок Полтавская, Ленина, 247	f	medium
20263	45093	1908	Краснодарский край, Красноармейский район, поселок Полтавская, Красная, 39, телефон: 3-16-65	f	large
20259	45089	1904	Краснодарский край, Красноармейский район, поселок Полтавская, Красная, 194, телефон: 3-37-19	f	large
20258	45088	1903	Краснодарский край, Красноармейский район, поселок Полтавская, Красная, 145, телефон: 3-20-88	f	large
20260	45090	1905	Краснодарский край, Красноармейский район, поселок Полтавская, Комсомольская, 29, телефон: 3-28-21	f	large
20268	45098	1913	Краснодарский край, Красноармейский район, поселок Полтавская, Жлобы, 60/А, телефон: 3-38-33	f	large
20267	45097	1912	Краснодарский край, Красноармейский район, поселок Полтавская, Жлобы, 78, телефон: 3-13-55	f	large
20287	45118	1932	Краснодарский край, Красноармейский район, поселок Подлесный, Кольцевая, 9, телефон: 46-0-64	t	small
21030	45855	3241	Краснодарский край, Красноармейский район, поселок Первомайский, Мира, 15, телефон: 2-21-21	f	small
20789	45613	2739	Краснодарский край, Красноармейский район, поселок Октябрьский, Октябрьская, 7, телефон: 6-62-82	f	large
20273	45103	1918	Краснодарский край, Красноармейский район, поселок Новомышастовская, Красная, 52, телефон: 98-3-70	f	large
20272	45102	1917	Краснодарский край, Красноармейский район, поселок Новомышастовская, Красная, 81, телефон: 98-2-55	f	large
20271	45101	1916	Краснодарский край, Красноармейский район, поселок Новомышастовская, Гагарина, 15, телефон: 98-2-47	f	large
20038	44871	1306	Рязанская область, Рязань, поселок Мирный	t	small
21805	46619	5035	Краснодарский край, Красноармейский район, поселок Мирный, Космонавтов, 16	f	small
20216	45048	1818	Краснодарский край, Красноармейский район, поселок Мирный, Клубная, 6, телефон: 2-66-43	f	small
20306	45137	1951	Краснодарский край, Красноармейский район, поселок Марьянская, Шевченко, 43, телефон: 96-5-62	f	large
20302	45133	1947	Краснодарский край, Красноармейский район, поселок Марьянская, Соболя, 2, телефон: 96-3-75	f	large
20303	45134	1948	Краснодарский край, Красноармейский район, поселок Марьянская, Пионерская, 55, телефон: 96-2-99	f	large
20305	45136	1950	Краснодарский край, Красноармейский район, поселок Марьянская, Ленина, 54, телефон: 96-2-41	f	large
20304	45135	1949	Краснодарский край, Красноармейский район, поселок Марьянская, Красная, 24, телефон: 96-4-12	f	large
20295	45126	1940	Краснодарский край, Красноармейский район, поселок Крикуна, Молодежная, 1/А	f	large
20286	45117	1931	Краснодарский край, Красноармейский район, поселок Красный Лес, Октябрьская, 30, телефон: 91-6-40	t	small
20278	45108	1923	Краснодарский край, Красноармейский район, поселок Краснодарский, Центральная, 7, телефон: 44-1-69	t	small
20285	45116	1930	Краснодарский край, Красноармейский район, поселок Колос, Первомайская, 3, телефон: 46-7-32	f	small
20313	45144	1958	Краснодарский край, Красноармейский район, поселок Казачий Ерик, Рисовая, 9, телефон: 93-4-76	t	small
20301	45132	1946	Краснодарский край, Красноармейский район, станица Ивановская, Пионерская, 12	f	large
20298	45129	1943	Краснодарский край, Красноармейский район, поселок Ивановская, Черноморская, 86, телефон: 94-2-79	f	large
20296	45127	1941	Краснодарский край, Красноармейский район, поселок Ивановская, Советская, 28	f	large
20297	45128	1942	Краснодарский край, Красноармейский район, поселок Ивановская, Ленина, 31, телефон: 94-1-43	f	large
20300	45131	1945	Краснодарский край, Красноармейский район, поселок Ивановская, Красная, 28, телефон: 94-3-01	f	large
20299	45130	1944	Краснодарский край, Красноармейский район, поселок Ивановская, Красная, 84, телефон: 94-2-50	f	large
20312	45143	1957	Краснодарский край, Красноармейский район, поселок Заветное, Кирова, 25, телефон: 93-3-15	t	small
21690	46504	4819	Краснодарский край, Красноармейский район, поселок Восточный, Пролетарская, 17, телефон: 6 91 21	t	small
20790	45614	2740	Краснодарский край, Красноармейский район, поселок Восточный, Матросова, 2, телефон: 6-63-44	f	small
20277	45107	1922	Краснодарский край, Красноармейский район, поселок Водный, Новая, 3, телефон: 44-1-02	f	small
20526	45353	2270	Краснодарский край, Красноармейский район, поселок Белозерный, 14/2, телефон: 229-43-99	f	large
20525	45352	2269	Краснодарский край, Красноармейский район, поселок Белозерный, 17/1, телефон: 229-50-31	f	large
86112	46012	3835	Краснодарский край, Кошехаблинский район, поселок Чехрак, улица Шоссейная, 2а	t	small
20991	45817	3202	Краснодарский край, Кошехаблинский район, поселок Комсомольский, Центральная, 15	t	small
20242	45074	1844	Краснодарский край, Кошехаблинский район, поселок Комсомольский, Центральная, 13	f	large
19950	44782	1136	Краснодарский край, Кошехаблинский район, поселок Комсомольский, Кирова, 2, здание Дома культуры	f	large
20115	44947	1517	Краснодарский край, Кошехаблинский район, поселок Комсомольский, Азовская, 19, телефон: 56-6-70	t	small
22016	46822	5522	Краснодарский край, Кошехаблинский район, поселок Вольное, Школьная, 24, телефон: 69120	f	large
20255	45085	1857	Краснодарский край, Кореновский район, поселок Сергиевская, Красная, 46В	f	medium
20229	45061	1831	Краснодарский край, Кореновский район, поселок Сергиевская, Айвазяна, 48, телефон: 98-6-92	f	large
20220	45052	1822	Краснодарский край, Кореновский район, поселок Раздольная, Фрунзе, 36	f	medium
20219	45051	1821	Краснодарский край, Кореновский район, поселок Раздольная, Фрунзе, 38	f	large
20224	45056	1826	Краснодарский край, Кореновский район, поселок Платнировская, Третьякова, 111, телефон: 71-1-46	f	large
20226	45058	1828	Краснодарский край, Кореновский район, поселок Платнировская, Пролетарская, 36, телефон: 71-7-53	f	large
20225	45057	1827	Краснодарский край, Кореновский район, поселок Платнировская, Пролетарская, 36, телефон: 71-6-82	f	large
20222	45054	1824	Краснодарский край, Кореновский район, поселок Платнировская, Красная, 30, телефон: 7-12-00	f	large
20223	45055	1825	Краснодарский край, Кореновский район, станица Платнировская, Красная, 27	f	large
20239	45071	1841	Краснодарский край, Кореновский район, поселок Новоберезанский, Пионерская, 9, телефон: 51-1-41	f	large
20228	45060	1830	Краснодарский край, Кореновский район, поселок Нижний, Северная, 19	f	medium
19895	44726	1018	Краснодарский край, Кореновский район, поселок Мирный, Партизанская, 26, телефон: 5-32-24	f	large
20227	45059	1829	Краснодарский край, Кореновский район, поселок Левченко, Центральная, 7	t	small
20213	45045	1815	Краснодарский край, Кореновский район, Кореновск, Школьная, 7, телефон: 3-83-28	f	large
20234	45066	1836	Краснодарский край, Кореновский район, город Кореновск, Фрунзе, 180Г, телефон: 4-62-50	f	small
20211	45043	1813	Краснодарский край, Кореновский район, город Кореновск, Маяковского, 8, телефон: 3-60-00	f	large
20252	45083	1854	Краснодарский край, Кореновский район, Кореновск, Матросова, 6Б, телефон: 4-58-88	f	large
20200	45032	1802	Краснодарский край, Кореновский район, город Кореновск, Матросова, 11, телефон: 4-25-03	f	large
20245	45077	1847	Краснодарский край, Кореновский район, город Кореновск, Маркса, 318А, телефон: 3-09-48	f	large
20203	45035	1805	Краснодарский край, Кореновский район, Кореновск, Маркса, 215, телефон: 4-54-76	f	large
20205	45037	1807	Краснодарский край, Кореновский район, город Кореновск, Красная, 29, телефон: 4-54-48	f	large
20206	45038	1808	Краснодарский край, Кореновский район, город Кореновск, Коммунаров, 107	f	large
20210	45042	1812	Краснодарский край, Кореновский район, Кореновск, Заводская, 3, телефон: 4-50-68	f	large
20202	45034	1804	Краснодарский край, Кореновский район, Кореновск, Октябрьская, 1, телефон: 4-02-10	f	large
20207	45039	1809	Краснодарский край, Кореновский район, Кореновск, Лиманский переулок, 19	f	large
20208	45040	1810	Краснодарский край, Кореновский район, Кореновск, Красная, 5, телефон: 4-44-95	f	large
20204	45036	1806	Краснодарский край, Кореновский район, Кореновск, Красная, 126, телефон: 4-50-57	f	large
20212	45044	1814	Краснодарский край, Кореновский район, Кореновск, Клубная, 5, телефон: 3-86-61	f	large
20214	45046	1816	Краснодарский край, Кореновский район, Кореновск, Запорожская, 12, телефон: 3-60-12	f	large
20250	45081	1852	Краснодарский край, Кореновский район, Кореновск, Выселковская, 29А, телефон: 4-14-26	f	large
20655	45478	2507	Краснодарский край, Кореновский район, поселок Казачий, Казачья, 50, здание филиала МУК СК Казачий, телефон: 39424	t	small
20221	45053	1823	Краснодарский край, Кореновский район, Казачий хутор, Золотарева, 26	f	medium
20076	44908	1418	Краснодарский край, Ейский район, город Ейск, Харьковская, телефон: 38468	f	large
20244	45076	1846	Краснодарский край, Кореновский район, поселок Казаче-Малеваный, Лунева, 63, телефон: 26-3-48	f	small
20236	45068	1838	Краснодарский край, Кореновский район, поселок Журавский, Южная, 64	f	medium
20243	45075	1845	Краснодарский край, Кореновский район, поселок Журавская, Северная, 68, телефон: 25-1-68	f	large
20230	45062	1832	Краснодарский край, Кореновский район, станица Дядьковская, Пролетарская, здание конторы АК Кубань-Люкс	f	medium
20231	45063	1833	Краснодарский край, Кореновский район, поселок Дядьковская, Советская, 42, телефон: 66-2-08	f	large
20232	45064	1834	Краснодарский край, Кореновский район, поселок Дядьковская, Ленина, 24, телефон: 66-4-04	f	large
20218	45050	1820	Краснодарский край, Кореновский район, поселок Бураковский, Гагарина, 5	f	large
20237	45069	1839	Краснодарский край, Кореновский район, поселок Братковское, Школьная, 1А	f	small
20238	45070	1840	Краснодарский край, Кореновский район, поселок Братковское, Центральная, 81, телефон: 92-6-40	f	medium
20233	45065	1835	Краснодарский край, Кореновский район, поселок Бабиче-Кореновский, Мира, 109	f	medium
20240	45072	1842	Краснодарский край, Кореновский район, поселок Анапский, Партизанская, 142А, телефон: 55-7-22	f	small
20713	45536	2628	Краснодарский край, Кировский район, хутор Павловский, Новая, 2, телефон: 7-94-12	f	large
21797	46611	5027	Краснодарский край, Карасунский, хутор Ленинский, Центральная, 128	f	small
20192	45024	1746	Краснодарский край, Каневский район, станция Челбасская, Красная, 75, телефон: 6-27-70	f	large
20175	45007	1729	Краснодарский край, Каневский район, ст.Придорожная, Красная, 40, телефон: 3-81-22	f	large
20186	45018	1740	Краснодарский край, Каневский район, поселок Челбасская, переулок Гоголя, 1	f	large
20185	45017	1739	Краснодарский край, Каневский район, поселок Челбасская, Партизанская, 1, телефон: 6-31-25	f	large
20184	45016	1738	Краснодарский край, Каневский район, поселок Челбасская, Красная, 75, телефон: 6-34-14	f	large
20191	45023	1745	Краснодарский край, Каневский район, поселок Ударный, Алтайская, 10 А	f	small
20174	45006	1728	Краснодарский край, Каневский район, поселок Труд, Длинная, 32	f	small
20158	44990	1712	Краснодарский край, Каневский район, поселок Сухие Челбасы, Северная, 38	f	medium
20190	45022	1744	Краснодарский край, Каневский район, поселок Степной, Широкая, 2 А, телефон: 3-99-28	f	small
20179	45011	1733	Краснодарский край, Каневский район, поселок Стародеревянковская, Лиманская, 23	f	large
20198	45030	1752	Краснодарский край, Каневский район, поселок Стародеревянковская, Красная, 126 Б, телефон: 6-87-24	f	large
20177	45009	1731	Краснодарский край, Каневский район, поселок Стародеревянковская, Красная, 82, телефон: 6-40-99	f	large
20178	45010	1732	Краснодарский край, Каневский район, поселок Стародеревянковская, Коммунаров, 30, телефон: 6-42-23	f	large
20180	45012	1734	Краснодарский край, Каневский район, поселок Стародеревянковская, Кирова, 24	f	large
20159	44991	1713	Краснодарский край, Каневский район, Средние Челбасы, Центральная, 18	f	medium
20181	45013	1735	Краснодарский край, Каневский район, поселок Сладкий Лиман, Широкая, 116	f	medium
20246	45078	1848	Краснодарский край, Каневский район, поселок Раздольный, Труда, 1	t	small
20166	44998	1720	Краснодарский край, Каневский район, поселок Раздольный, Светлая, 97	f	small
20165	44997	1719	Краснодарский край, Каневский район, поселок Приютный, Кондруцкого, 64 Г, телефон: 3-87-85	f	small
20172	45004	1726	Краснодарский край, Каневский район, станица Привольная, Мира, 66	f	large
20173	45005	1727	Краснодарский край, Каневский район, поселок Привольная, Мира, 66, телефон: 4-87-88	f	large
20176	45008	1730	Краснодарский край, Каневский район, поселок Партизанский, Красноармейская, 4, телефон: 3-89-57	f	small
20189	45021	1743	Краснодарский край, Каневский район, поселок Орджоникидзе, Светлая, 15	f	small
20168	45000	1722	Краснодарский край, Каневский район, поселок Новоминская, пер. Вольный, 41 А, телефон: 7-62-04	f	large
20197	45029	1751	Краснодарский край, Каневский район, поселок Новоминская, Ленина, 25, телефон: 7-61-05	f	large
20171	45003	1725	Краснодарский край, Каневский район, поселок Новоминская, Ленина, 25	f	large
20170	45002	1724	Краснодарский край, Каневский район, поселок Новоминская, Ленина, 25 А, телефон: 7-65-26	f	large
29966	19499	512	Астраханская область, Астрахань, Бэра, 44	f	large
20169	45001	1723	Краснодарский край, Каневский район, поселок Новоминская, Дружбы, 49, телефон: 7-61-08	f	large
20195	45027	1749	Краснодарский край, Каневский район, поселок Новодеревянковская, Мира, 50	f	medium
20164	44996	1718	Краснодарский край, Каневский район, поселок Новодеревянковская, Мира, 22	f	large
20163	44995	1717	Краснодарский край, Каневский район, поселок Новодеревянковская, Мира, 1, телефон: 4-61-36	f	large
20196	45028	1750	Краснодарский край, Каневский район, поселок Новодеревянковская, Восточная, 4	f	medium
20182	45014	1736	Краснодарский край, Каневский район, поселок Мигуты, Охотничья, 17	f	small
20162	44994	1716	Краснодарский край, Каневский район, поселок Кубанская Степь, Центральная, 75, телефон: 3-71-43	f	large
20160	44992	1714	Краснодарский край, Каневский район, поселок Красногвардеец, Красная, 3, телефон: 3-97-94	f	large
20157	44989	1711	Краснодарский край, Каневский район, Широкая, 109	f	large
20193	45025	1747	Краснодарский край, Каневский район, поселок Каневская, Элеваторная, 8	f	large
20153	44985	1707	Краснодарский край, Каневский район, поселок Каневская, Чипигинская, 125, телефон: 4-50-61	f	large
20147	44979	1701	Краснодарский край, Каневский район, поселок Каневская, Чигиринская, 72, телефон: 7-14-05	f	large
20148	44980	1702	Краснодарский край, Каневский район, поселок Каневская, Таманская, 104	f	large
20187	45019	1741	Краснодарский край, Каневский район, поселок Каневская, Северная, 3, телефон: 7-31-06	f	large
20188	45020	1742	Краснодарский край, Каневский район, поселок Каневская, Октябрьская, 109	f	large
20156	44988	1710	Краснодарский край, Каневский район, поселок Каневская, Октябрьская, 79, телефон: 7-52-82	f	large
20155	44987	1709	Краснодарский край, Каневский район, поселок Каневская, Октябрьская, 1	f	large
20194	45026	1748	Краснодарский край, Каневский район, поселок Каневская, Горького, 64, телефон: 7-92-39	f	large
20152	44984	1706	Краснодарский край, Каневский район, поселок Каневская, Горького, 55, телефон: 4-20-24	f	large
20151	44983	1705	Краснодарский край, Каневский район, поселок Каневская, Герцена, 82, телефон: 7-16-91	f	large
20183	45015	1737	Краснодарский край, Каневский район, поселок Бол. Челбасы, Полтавская, 63	f	small
20161	44993	1715	Краснодарский край, Каневский район, поселок Александровская, Советская, 17А	f	small
20167	44999	1721	Краснодарский край, Каневский район, хутор Албаши, Светлая, 97	f	small
20130	44962	1609	Краснодарский край, Калининский район, поселок Старовеличковская, Школьная, 42, телефон: 26493	f	large
20133	44965	1612	Краснодарский край, Калининский район, поселок Старовеличковская, Северная, 1, телефон: 27776	f	large
20132	44964	1611	Краснодарский край, Калининский район, поселок Старовеличковская, Красная, 202, телефон: 26034	f	large
20131	44963	1610	Краснодарский край, Калининский район, поселок Старовеличковская, Красная, 127, телефон: 26591	f	large
20139	44971	1618	Краснодарский край, Калининский район, поселок Рогачевский, Солнечная, 4, телефон: 42196	f	medium
20135	44967	1614	Краснодарский край, Калининский район, поселок Редант, Центральная, 7	f	small
20146	44978	1625	Краснодарский край, Калининский район, поселок Пригибский, Центральная, 8	f	small
20134	44966	1613	Краснодарский край, Калининский район, Поселок Гришковское, Гайдара, 30/А, телефон: 49183	f	large
20140	44972	1619	Краснодарский край, Калининский район, поселок Новониколаевская, Ленина, 134, телефон: 47105	f	large
20138	44970	1617	Краснодарский край, Калининский район, поселок Могукоровка, Ленина, 84	f	small
20123	44955	1602	Краснодарский край, Калининский район, поселок Калининская, Фадеева, 146, телефон: 21471	f	large
20122	44954	1601	Краснодарский край, Калининский район, поселок Калининская, Ленина, 43, телефон: 21169	f	large
20124	44956	1603	Краснодарский край, Калининский район, поселок Калининская, Коваля, 41, телефон: 21409	f	large
20125	44957	1604	Краснодарский край, Калининский район, поселок Калининская, Заречная, 15/А, телефон: 21183	f	large
20127	44959	1606	Краснодарский край, Калининский район, поселок Джумайловка, Молодежная, 2	f	large
20144	44976	1623	Краснодарский край, Калининский район, поселок Гривенская, Советская, 20, телефон: 57675	f	large
20143	44975	1622	Краснодарский край, Калининский район, поселок Гривенская, Советская, 20	f	medium
29965	19499	511	Астраханская область, Астрахань, Бэра, 44	f	large
20145	44977	1624	Краснодарский край, Калининский район, поселок Гривенская, Мира, 12/Б, телефон: 57398	f	large
20136	44968	1615	Краснодарский край, Калининский район, поселок Гречаная Балка, Советская, 37	f	large
20137	44969	1616	Краснодарский край, Калининский район, поселок Греки, Мира, 23	f	medium
20128	44960	1607	Краснодарский край, Калининский район, поселок Бойкопонура, улица Бойко-Павлова, 1/Б, телефон: 48701	f	large
20129	44961	1608	Краснодарский край, Калининский район, поселок Андреевская, Красная, 23	f	large
20141	44973	1620	Краснодарский край, Калининский район, поселок Ангелинский, Центральная, 18	f	small
20104	44936	1506	Краснодарский край, Кавказский район, поселок Черномуровский, Красноармейская, 51, телефон: 54-4-46	t	small
20103	44935	1505	Краснодарский край, Кавказский район, станица Темижбекская, Вокзальная, 47, телефон: 51-4-44	f	large
20102	44934	1504	Краснодарский край, Кавказский район, поселок Темижбекская, Трактовая, 58, телефон: 51-4-77	f	large
20110	44942	1512	Краснодарский край, Кавказский район, поселок Степной, Ленина, 10, телефон: 55-8-76	f	medium
20116	44948	1518	Краснодарский край, Кавказский район, поселок Расцвет, Школьная, 9	t	small
20105	44937	1507	Краснодарский край, Кавказский район, поселок Озерный, Первомайская, 11, телефон: 54-5-86	t	small
20117	44949	1519	Краснодарский край, Кавказский район, поселок Мирской, Ленина, 85	f	large
20109	44941	1511	Краснодарский край, Кавказский район, поселок Лосево, Мира, 7 а	f	large
20628	45451	2415	Краснодарский край, Кавказский район, Кропоткинское городское поселение, переулок Белинского, 25	f	large
20639	45462	2426	Краснодарский край, Кавказский район, Кропоткинское городское поселение, Целых, 45, телефон: 6-30-73	f	large
20640	45463	2427	Краснодарский край, Кавказский район, Кропоткинское городское поселение, С.Целых, 45, телефон: 6-30-80	f	large
20642	45465	2429	Краснодарский край, Кавказский район, Кропоткинское городское поселение, Микрорайон-1, 11, телефон: 3-47-67	f	large
20619	45442	2406	Краснодарский край, Кавказский район, Кропоткинское городское поселение, Красноармейская, 53	f	large
20615	45438	2402	Краснодарский край, Кавказский район, город Кропоткин, улица Мира, 146	f	large
20647	45470	2434	Краснодарский край, Кавказский район, город Кропоткин, пер.Белинского, 25	f	large
20635	45458	2422	Краснодарский край, Кавказский район, Кропоткин, Шоссейная, 59	f	large
20623	45446	2410	Краснодарский край, Кавказский район, город Кропоткин, Шаумяна, 17 А	f	large
20617	45440	2404	Краснодарский край, Кавказский район, Кропоткин, Черноморская, 79	f	large
20636	45459	2423	Краснодарский край, Кавказский район, город Кропоткин, Целых, 258	f	large
20625	45448	2412	Краснодарский край, Кавказский район, Кропоткин, Пушкина, 211	f	large
20621	45444	2408	Краснодарский край, Кавказский район, город Кропоткин, Пушкина, 69	f	large
20643	45466	2430	Краснодарский край, Кавказский район, Кропоткин, Микрорайон-1, 53, телефон: 3-49-61	f	large
20646	45469	2433	Краснодарский край, Кавказский район, город Кропоткин, Микрорайон №1, 11, телефон: 7-13-21	f	large
20620	45443	2407	Краснодарский край, Кавказский район, Кропоткин, Красноармейская, 53	f	large
20634	45457	2421	Краснодарский край, Кавказский район, Кропоткин, Красная, 11	f	large
20633	45456	2420	Краснодарский край, Кавказский район, Кропоткин, Красная, 64	f	large
20630	45453	2417	Краснодарский край, Кавказский район, Кропоткин, Красная, 164	f	large
20638	45461	2425	Краснодарский край, Кавказский район, Кропоткин, Комсомольская, 206	f	large
20637	45460	2424	Краснодарский край, Кавказский район, Кропоткин, Гоголя, 166	f	large
20645	45468	2432	Краснодарский край, Кавказский район, Кропоткин, 1 проезд, 1	f	large
20996	45822	3207	Краснодарский край, Кавказский район, поселок Красная Звезда, Мира, 11	f	small
20119	44951	1521	Краснодарский край, Кавказский район, поселок Казанская, Ленина, 11	f	large
20120	44952	1522	Краснодарский край, Кавказский район, поселок Казанская, Красная, 307	f	large
20118	44950	1520	Краснодарский край, Кавказский район, станица Казанская, Красная, 221	f	large
20101	44933	1503	Краснодарский край, Кавказский район, станица Кавказская, Ленина, 220	f	large
20121	44953	1523	Краснодарский край, Кавказский район, поселок Кавказская, Первомайский, 18, телефон: 22-3-38	f	large
80685	14073	375	Ярославская область, Рыбинск, Куйбышева, 26	f	large
20100	44932	1502	Краснодарский край, Кавказский район, поселок Кавказская, Ленина, 158, телефон: 22-8-51	f	large
20099	44931	1501	Краснодарский край, Кавказский район, поселок Кавказская, Калинина, 111, телефон: 22-8-01	f	large
20108	44940	1510	Краснодарский край, Кавказский район, поселок Дмитриевская, Фрунзе, 2, телефон: 53-1-69	f	large
20113	44945	1515	Краснодарский край, Кавказский район, поселок Десятихатка, Молодежная, 6	f	medium
19864	44695	925	Краснодарский край, Кавказский район, поселок Возрождение, Таманская, 50, телефон: 67443	f	large
20045	44878	1313	Краснодарский край, Ейский район, поселок им. Николая Островского, Центральная, 64, телефон: 97219	t	small
20052	44885	1320	Краснодарский край, Ейский район, поселок Ясенская Переправа, Кирова, 36, телефон: 65742	f	medium
20051	44884	1319	Краснодарский край, Ейский район, поселок Ясенская, Ленина, 79	f	large
20050	44883	1318	Краснодарский край, Ейский район, поселок Ясенская, Ленина, 80	f	large
20087	44919	1429	Краснодарский край, Ейский район, поселок Широчанка, Косиора, 34, телефон: 79238	f	large
20086	44918	1428	Краснодарский край, Ейский район, поселок Широчанка, Косиора, 36, телефон: 79171	f	large
20042	44875	1310	Краснодарский край, Ейский район, поселок Советский, Ленина, 2, телефон: 61147	f	large
20089	44921	1431	Краснодарский край, Ейский район, поселок Морской, Центральная, 12	f	small
20037	44870	1305	Краснодарский край, Ейский район, поселок Моревка, Шоссейная, 17	f	medium
20276	45106	1921	Краснодарский край, Ейский район, поселок Мирный, Светлая, 12, телефон: 91-4-17	f	medium
20036	44869	1304	Краснодарский край, Ейский район, поселок Кухаривка, Советов, 33А, телефон: 99293	f	large
20088	44920	1430	Краснодарский край, Ейский район, поселок Краснофлотский, Комсомольская, 12,, телефон: 92762	f	large
20053	44886	1321	Краснодарский край, Ейский район, поселок Копанская, Мешкова, 22, телефон: 95475	f	large
20041	44874	1309	Краснодарский край, Ейский район, поселок Комсомолец, Школьная, 23, телефон: 67407	f	large
20058	44891	1326	Краснодарский край, Ейский район, поселок Камышеватская, Победы, 13	f	medium
20039	44872	1307	Краснодарский край, Ейский район, поселок Камышеватская, Азовская, 3А	f	large
20040	44873	1308	Краснодарский край, Ейский район, станица Камышеватская, Советская, 172Б	f	large
20049	44882	1317	Краснодарский край, Ейский район, поселок Заводской, Мира, 39	f	medium
67963	44925	1435	Краснодарский край, Ейский район, Ейск, ЕВВАУЛ им.В.М. Комарова	f	large
20092	44924	1434	Краснодарский край, Ейский район, Ейск, клуб в/ч 37115, телефон: 29947	f	large
67961	44899	1408	Краснодарский край, Ейский район, Ейск, угол ул.К.Маркса и ул.Гоголя	f	large
20059	44892	1401	Краснодарский край, Ейский район, Ейск, Ясенская, 31, телефон: 34422	f	large
20067	44900	1409	Краснодарский край, Ейский район, Ейск, Янышева, 22	f	large
20095	44927	1437	Краснодарский край, Ейский район, Ейск, Юности переулок , 10, телефон: 48211	f	large
20068	44901	1410	Краснодарский край, Ейский район, Ейск, Театральная площадь, 1, телефон: 20376	f	large
20079	44911	1421	Краснодарский край, Ейский район, Ейск, Пушкина, 56, телефон: 20297	f	large
20078	44910	1420	Краснодарский край, Ейский район, Ейск, Пушкина, 73, телефон: 21114	f	large
67962	44906	1416	Краснодарский край, Ейский район, Ейск, Пушкина, 98	f	large
20073	44905	1415	Краснодарский край, Ейский район, Ейск, Пушкина, 120, телефон: 30251	f	large
20065	44898	1407	Краснодарский край, Ейский район, Ейск, Портовая аллея, 6, телефон: 22961	f	large
20062	44895	1404	Краснодарский край, Ейский район, Ейск, Первомайская, 196, телефон: 24506	f	large
20094	44926	1436	Краснодарский край, Ейский район, Ейск, Красная, 74/2, телефон: 47194	f	large
20090	44922	1432	Краснодарский край, Ейский район, Ейск, Красная, 47/6, телефон: 45350	f	large
20085	44917	1427	Краснодарский край, Ейский район, Ейск, Красная, 74/2, телефон: 77145	f	large
20084	44916	1426	Краснодарский край, Ейский район, Ейск, Коммунистическая, 83/3, телефон: 45111	f	large
20096	44928	1438	Краснодарский край, Ейский район, Ейск, Кирпичная, 12, телефон: 75045	f	large
20075	44907	1417	Краснодарский край, Ейский район, Ейск, К. Либкнехта, 1, телефон: 21941	f	large
20097	44929	1439	Краснодарский край, Ейский район, Ейск, Герцена, 44, телефон: 77959	f	large
20080	44912	1422	Краснодарский край, Ейский район, Ейск, Баррикадная, 1, телефон: 45910	f	large
20063	44896	1405	Краснодарский край, Ейский район, город Ейск, Таманская, 23к.1	f	large
20064	44897	1406	Краснодарский край, Ейский район, город Ейск, Свердлова, 19, телефон: 21835	f	large
20077	44909	1419	Краснодарский край, Ейский район, город Ейск, Романа, 275, телефон: 46910	f	large
20060	44893	1402	Краснодарский край, Ейский район, Ейск, Первомайская, 189/2, телефон: 24459	f	large
20083	44915	1425	Краснодарский край, Ейский район, город Ейск, Коммунистическая, 63а, телефон: 48906	f	large
20082	44914	1424	Краснодарский край, Ейский район, город Ейск, Коммунистическая, 49/12, телефон: 46747	f	large
20081	44913	1423	Краснодарский край, Ейский район, Ейск, Коммунистическая, 14, телефон: 72248	f	large
20069	44832	1411	Краснодарский край, Ейский район, город Ейск, Коммунаров, 10, телефон: 23166	f	large
20070	44902	1412	Краснодарский край, Ейский район, город Ейск, Бердянская, 111	f	large
20057	44890	1325	Краснодарский край, Ейский район, поселок Должанская, Октябрьская, 137	f	large
20033	44815	1301	Краснодарский край, Ейский район, поселок Должанская, Ленина, 1	f	large
20034	44867	1302	Краснодарский край, Ейский район, станица Должанская, Октябрьская, 210	f	large
20035	44868	1303	Краснодарский край, Ейский район, поселок Воронцовка, Мира, 63, телефон: 62395	f	large
21804	46618	5034	Краснодарский край, Ейский район, поселок Большевик, здание клуба, телефон: 6-50-74	f	small
20043	44876	1311	Краснодарский край, Ейский район, поселок Большевик, Парковая, 2А	t	small
20054	44887	1322	Краснодарский край, Ейский район, поселок Александровка, Советская, 30Д, телефон: 94236	f	large
21700	46514	4829	Краснодарский край, Дубовский район, хутор Дальний, здание конторы МТФ № 2 ЗАО АФ Дружба, телефон: 6 11 44	f	small
20002	44835	1218	Краснодарский край, Динской район, ст.Васюринская, Западная, 59	f	large
20001	44834	1217	Краснодарский край, Динской район, поселок Янтарный, Садовая, 18	f	medium
22000	46808	5506	Краснодарский край, Динской район, поселок Украинский, Украинская, 26а	f	small
67960	44830	1214	Краснодарский край, Динской район, поселок Украинский, Советов, 4/1	f	large
20014	44847	1230	Краснодарский край, Динской район, поселок Старомышастовская, Советская, 59, телефон: 75-2-98	f	large
20013	44846	1229	Краснодарский край, Динской район, поселок Старомышастовская, Советская, 49, телефон: 75-2-19	f	large
20012	44845	1228	Краснодарский край, Динской район, поселок Старомышастовская, Красная, 34	f	large
20003	44836	1219	Краснодарский край, Динской район, поселок Ст. Васюринская, Луначарского, 94, телефон: 31-2-50	f	large
20022	44855	1238	Краснодарский край, Динской район, поселок Примаки, улица Новотитаровская	t	small
20008	44841	1224	Краснодарский край, Динской район, поселок Пластуновская, Мира, 26-а, телефон: 37-5-03	f	large
20010	44843	1226	Краснодарский край, Динской район, поселок Пластуновская, Красная, 55, телефон: 37-2-17	f	large
20009	44842	1225	Краснодарский край, Динской район, поселок Пластуновская, Красная, 187 А, телефон: 37-2-25	f	large
20007	44840	1223	Краснодарский край, Динской район, поселок Пластуновская, Базарная, 82, телефон: 37-4-19	f	large
20006	44839	1222	Краснодарский край, Динской район, поселок Первореченское, Ленина, 100, телефон: 3-43-82	f	large
20023	44856	1239	Краснодарский край, Динской район, поселок Новотитаровская, Южная, 90\\2	f	medium
20024	44857	1240	Краснодарский край, Динской район, поселок Новотитаровская, Широкая, 2	f	large
20016	44849	1232	Краснодарский край, Динской район, поселок Новотитаровская, Степная, 21\\2	f	large
20019	44852	1235	Краснодарский край, Динской район, поселок Новотитаровская, Советская, 61	f	large
20018	44851	1234	Краснодарский край, Динской район, поселок Новотитаровская, Советская, 116	f	large
20021	44854	1237	Краснодарский край, Динской район, поселок Новотитаровская, Октябрьская, 304	f	large
20017	44850	1233	Краснодарский край, Динской район, поселок Новотитаровская, Новотитаровская, 46	f	large
20020	44853	1236	Краснодарский край, Динской район, поселок Новотитаровская, Луначарского, 169	f	large
20015	44848	1231	Краснодарский край, Динской район, станица Новотитаровская, Крайняя, 2/1 А	f	medium
20028	44861	1244	Краснодарский край, Динской район, поселок Нововеличковская, Свердлова, 24	f	large
20031	44864	1247	Краснодарский край, Динской район, поселок Нововеличковская, Красная, 51	f	large
20027	44860	1243	Краснодарский край, Динской район, поселок Нововеличковская, Красная, 124	f	large
20026	44859	1242	Краснодарский край, Динской район, поселок Нововеличковская, Красная, 42	f	large
20029	44862	1245	Краснодарский край, Динской район, поселок Найдорф, Школьная , 9, телефон: 42-0-47	f	large
20011	44844	1227	Краснодарский край, Динской район, поселок Красносельское, Кирова, 62 А, телефон: 33-3-60	f	large
20000	44833	1216	Краснодарский край, Динской район, поселок Зарождение, Центральная, 22, телефон: 39-3-28	f	large
19997	44829	1213	Краснодарский край, Динской район, поселок Динская, переулокТельмана, 3 А, телефон: 6-34-98	f	large
19995	44827	1211	Краснодарский край, Динской район, поселок Динская, Тельмана, 102, телефон: 6-17-27	f	large
19986	44818	1202	Краснодарский край, Динской район, поселок Динская, Мира, 2	f	large
19990	44822	1206	Краснодарский край, Динской район, поселок Динская, Луначарского, 34, телефон: 5-94-03	f	large
19994	44826	1210	Краснодарский край, Динской район, поселок Динская, Краснодарская, 7, телефон: 5-51-94	f	large
19993	44825	1209	Краснодарский край, Динской район, поселок Динская, Красная, 23, телефон: 6-59-05	f	large
19992	44824	1208	Краснодарский край, Динской район, поселок Динская, Красная, 34, телефон: 6-30-02, 6-31-16	f	large
19989	44821	1205	Краснодарский край, Динской район, поселок Динская, Красная, 111, телефон: 6-41-22	f	large
19996	44828	1212	Краснодарский край, Динской район, поселок Динская, Комарова, 3	f	large
19987	44819	1203	Краснодарский край, Динской район, поселок Динская, Кирова, 95, телефон: 6-32-86	f	large
19991	44823	1207	Краснодарский край, Динской район, поселок Динская, Калинина, 58, телефон: 6-15-43	f	large
19988	44820	1204	Краснодарский край, Динской район, поселок Динская, Гоголя, 108, телефон: 6-14-77	f	large
134655	94981	1249	Краснодарский край, Динской район, поселок Дальний, Центральная, 7	t	small
21301	46118	4111	Краснодарский край, Динской район, поселок Восточный, Здание сельского клуба, телефон: 33-8-53	t	small
20030	44863	1246	Краснодарский край, Динской район, поселок Воронцовская, Красная, 10	f	medium
20004	44837	1220	Краснодарский край, Динской район, поселок Васюринская, Луначарского, 190	f	large
20005	44838	1221	Краснодарский край, Динской район, поселок Васюринская, Интернациональная, 59	f	large
19999	44831	1215	Краснодарский край, Динской район, поселок Агроном, Почтовая, 1, телефон: 78-1-32	f	large
19934	44765	1120	Краснодарский край, Гулькевичский район, поселок Черединовский, Северная, здание сельского клуба	f	small
19982	44813	1168	Краснодарский край, Гулькевичский район, поселок Чаплыгин, Советская, 19, здание правления ООО Маяк Революции	f	medium
19954	44786	1140	Краснодарский край, Гулькевичский район, поселок Урожайный, Ветеранов, 15, здание клуба, телефон: 9-47-38	t	small
19983	44814	1169	Краснодарский край, Гулькевичский район, поселок Тысячный, Красная, 9, здание Дома культуры	f	large
19951	44783	1137	Краснодарский край, Гулькевичский район, поселок Тельман, Шукшина, 26, здание Дома культуры, телефон: 5-83-54	t	medium
19977	44808	1163	Краснодарский край, Гулькевичский район, поселок Соколовское, Ленина , здание Дома культуры, телефон: 3-77-22	f	large
19978	44809	1164	Краснодарский край, Гулькевичский район, поселок Соколовское, Кирова, здание отделения № 1 ООО ПЗ Наша Родина, телефон: 3-77-79	t	small
19953	44785	1139	Краснодарский край, Гулькевичский район, поселок Советский, Садовая, 7, здание МДОУ ДС № 25, телефон: 9-45-31	t	medium
21699	46513	4828	Краснодарский край, Гулькевичский район, поселок Советский, Буденного, 44 Б	f	small
19975	44806	1161	Краснодарский край, Гулькевичский район, поселок Скобелевская, Октябрьская, 28, здание администрации поселения	f	medium
19966	44799	1152	Краснодарский край, Гулькевичский район, поселок Самойлов, Красная, 81, (здание бригадного дома ЗАО КСП ""Дружба""	t	small
19973	44804	1159	Краснодарский край, Гулькевичский район, поселок Пушкинское, Советская, 171, здание Дома культуры	f	large
19972	44803	1158	Краснодарский край, Гулькевичский район, поселок Отрадо-Ольгинское, Красная, 37, здание Дома культуры, телефон: 9-32-43	f	large
111009	44793	1146	Краснодарский край, Гулькевичский район, поселок Отрадо-Кубанское, Ленина, 44а, ДК	f	medium
19959	44792	1145	Краснодарский край, Гулькевичский район, поселок Отрадо-Кубанское, Ленина, 35А, (здание МОУ СОШ № 15), телефон: 9-66-76	f	large
33807	27594	1104	Волгоградская область, Волжский, Комсомольская, 1	f	large
19964	44797	1150	Краснодарский край, Гулькевичский район, поселок Орлов, Октябрьская, здание МДОУ детского сада № 43	t	small
19968	44801	1154	Краснодарский край, Гулькевичский район, поселок Новоукраинское, Красная, 131, МКУК СДК Новоукраинского сельского поселения	f	large
19969	44775	1155	Краснодарский край, Гулькевичский район, поселок Новоукраинское, Красная, 231	f	large
19980	44811	1166	Краснодарский край, Гулькевичский район, поселок Новопавловский, Восточная, 24-а, здание сельского клуба	t	medium
19971	44802	1157	Краснодарский край, Гулькевичский район, поселок Новомихайловское, Октябрьская, 5, здание Дома культуры, телефон: 9-83-41	f	medium
19974	44805	1160	Краснодарский край, Гулькевичский район, поселок Новокрасный, Красная, 59	f	small
19962	44795	1148	Краснодарский край, Гулькевичский район, поселок Николенское, Октябрьская, 86, здание правления ООО Агрофирмы Победа, телефон: 9-95-88	f	medium
19963	44796	1149	Краснодарский край, Гулькевичский район, поселок Николенское, Заречная, здание МОУ СОШ № 18, телефон: 9-92-03	f	medium
19957	44790	1143	Краснодарский край, Гулькевичский район, поселок Мирный, Красная,, 7, здание фельдшерско-акушерского пункта	t	small
19981	44812	1167	Краснодарский край, Гулькевичский район, поселок Машевский, Первомайская, здание сельского клуба	t	small
19932	44763	1118	Краснодарский край, Гулькевичский район, поселок Майкопское, Кирова, 16а, здание МОУ СОШ № 12	f	large
19933	44764	1119	Краснодарский край, Гулькевичский район, поселок Майкопское, Базарная, 1а, здание МУК Дом культуры Майкопский, телефон: 2-54-74	f	large
19949	44781	1135	Краснодарский край, Гулькевичский район, поселок Лесодача, Рабочая, 2, здание сельского клуба, телефон: 2-75-24	f	small
19952	44784	1138	Краснодарский край, Гулькевичский район, поселок Кубань, Школьная, 8, здание Дома культуры, телефон: 9-45-79	f	large
19947	44779	1133	Краснодарский край, Гулькевичский район, поселок Крупский, Мира, 18, здание сельского клуба	f	small
19941	44772	1127	Краснодарский край, Гулькевичский район, поселок Красносельский, Школьная, 72, здание МОУ СОШ № 16	f	large
19940	44771	1126	Краснодарский край, Гулькевичский район, поселок Красносельский, Строителей, 22, (здание Дома культуры), телефон: 3-08-20	f	large
19939	44770	1125	Краснодарский край, Гулькевичский район, поселок Красносельский, Промышленная, 2, административное здание ОАО Блок,телефон: 3-08-82	f	medium
19942	44773	1128	Краснодарский край, Гулькевичский район, поселок Красносельский, Почтовая, 7, телефон: 3-01-92	f	medium
21477	46290	4354	Краснодарский край, Гулькевичский район, поселок Красная Поляна, Турчинского, 42	f	medium
19970	44789	1156	Краснодарский край, Гулькевичский район, поселок Киевка, здание сельского клуба, телефон: 9-89-31	f	small
19976	44807	1162	Краснодарский край, Гулькевичский район, поселок Журавлев, Красная, 8, здание фельдшерско-акушерского пункта	t	small
19948	44780	1134	Краснодарский край, Гулькевичский район, поселок Духовский, Юбилейная, 3, здание библиотеки	f	medium
19955	44787	1141	Краснодарский край, Гулькевичский район, поселок Дальний, Ленина, 9, столовая отделения № 3 ФГУП Племзавод Кубань	t	small
19918	44749	1104	Краснодарский край, Гулькевичский район, Гулькевичи, Энергетиков, 29, здание клуба ОАО АПСКГ, телефон: 5-51-31	f	large
19928	44759	1114	Краснодарский край, Гулькевичский район, Гулькевичи, Чехова, 20, здание столовой ЗАО ""Племзавод ""Гулькевичский"	f	large
19931	44762	1117	Краснодарский край, Гулькевичский район, город Гулькевичи, Тимирязева, 14, телефон: 5-62-45	f	large
19929	44760	1115	Краснодарский край, Гулькевичский район, город Гулькевичи, Советская, 49, ГОУ СПО Гулькевичский строительный техникум, телефон: 3-24-69	f	large
19922	44753	1108	Краснодарский край, Гулькевичский район, Гулькевичи, Советская, 20, здание МАОУ СОШ № 3, телефон: 3-48-37	f	large
19921	44752	1107	Краснодарский край, Гулькевичский район, Гулькевичи, Советская, 14, здание администрации МО Гулькевичский район, телефон: 3-35-54	f	large
19915	44746	1101	Краснодарский край, Гулькевичский район, город Гулькевичи, Пионерская, 96, телефон: 5-32-63	f	large
19930	44761	1116	Краснодарский край, Гулькевичский район, Гулькевичи, Нагорная, 10, здание ДК ЗАО КСП ""Дружба", телефон: 3-48-13	f	medium
19829	44659	830	Краснодарский край, Выселковский район, поселок Ирклиевская, Кооперативная, 11, телефон: 40-1-92	f	large
19920	44751	1106	Краснодарский край, Гулькевичский район, Гулькевичи, Ленина, 88, административное здание ООО Керамика, телефон: 3-32-91	f	large
19925	44756	1111	Краснодарский край, Гулькевичский район, Гулькевичи, Короткова, 155, адм.здание ЗАО Гулькевичский маслозавод,телефон: 3-21-57	f	large
19923	44754	1109	Краснодарский край, Гулькевичский район, Гулькевичи, Комсомольская, 80, (здание МУК КДЦ Лукоморье), телефон: 3-47-63	f	large
19924	44755	1110	Краснодарский край, Гулькевичский район, город Гулькевичи, Кирова, 78, телефон: 3-30-98	f	medium
19926	44757	1112	Краснодарский край, Гулькевичский район, город Гулькевичи, Западный микрорайон, 19, (отделение почтовой связи г. Гулькевичи), телефон: 5-90-65	f	large
19917	44748	1103	Краснодарский край, Гулькевичский район, Гулькевичи, Волго-Донская, 7, (здание МОУ СОШ № 2), телефон: 5-32-94	f	large
19916	44747	1102	Краснодарский край, Гулькевичский район, Гулькевичи, 50 лет ВЛКСМ, 28, Административное здание ЗАО ДСУ-7, телефон: 5-47-30	f	large
19938	44769	1124	Краснодарский край, Гулькевичский район, поселок Гирей, Шевченко, 15а, здание магазина Надежда	t	medium
19937	44768	1123	Краснодарский край, Гулькевичский район, поселок Гирей, Степная, 138, здание магазина Снежана	t	medium
19935	44766	1121	Краснодарский край, Гулькевичский район, поселок Гирей, Почтовая, 5, здание Дома культуры Эльдорадо, телефон: 2-91-42	f	large
19936	44767	1122	Краснодарский край, Гулькевичский район, поселок Гирей, Красная, 6, здание Дома культуры Фламинго	f	large
19984	44816	1170	Краснодарский край, Гулькевичский район, поселок Воздвиженский, Свободный Труд, здание сельского клуба, телефон: 9-61-83	f	small
19944	44776	1130	Краснодарский край, Гулькевичский район, поселок Венцы, Советская , 25, корпус ФГОУ СПО Зооветтехникум Венцы-Заря, телефон: 3-18-54	f	large
19943	44774	1129	Краснодарский край, Гулькевичский район, поселок Венцы, Советская, 10, телефон: 3-16-22	f	large
19965	44798	1151	Краснодарский край, Гулькевичский район, поселок Булгаков, Школьная, 20, здание фельдшерско-акушерского пункта	t	small
111006	44791	1144	Краснодарский край, Гулькевичский район, поселок Ботаника, Центральная, 1а, (ДК)	f	medium
19979	44810	1165	Краснодарский край, Гулькевичский район, поселок Алексеевский, улица Ленина, здание сельского клуба	f	small
19890	44721	1013	Краснодарский край, Горячий Ключ, поселок Кутаис, Ленина, 84, телефон: 4-85-11	f	medium
19839	44670	840	Краснодарский край, Выселковский район, ст. Березанская, Новобазарная, 4	f	large
19823	44653	824	Краснодарский край, Выселковский район, поселок Советский, Красная, 6, телефон: 33-7-59	t	small
19820	44650	821	Краснодарский край, Выселковский район, поселок Первомайское, Комарова, 7, телефон: 37-6-59	f	small
21220	46037	3909	Краснодарский край, Выселковский район, поселок Первомайский, Школьная, 1	f	small
21688	46501	4817	Краснодарский край, Выселковский район, поселок Первомайский, Молодежная, 5,	f	small
19832	44662	833	Краснодарский край, Выселковский район, поселок Первомайский, Дорожная, 1/А, телефон: 35-5-81	t	small
19830	44660	831	Краснодарский край, Выселковский район, поселок Память Ленина, Красная, 28	t	small
19824	44654	825	Краснодарский край, Выселковский район, поселок Октябрьский, Советская, 40, телефон: 33-6-40	t	small
19836	44666	837	Краснодарский край, Выселковский район, поселок Новомалороссийская, Украинская, 1/4	f	large
19835	44665	836	Краснодарский край, Выселковский район, поселок Новомалороссийская, Почтовая, 29	f	large
19837	44667	838	Краснодарский край, Выселковский район, поселок Новомалороссийская, Красная, 58/3	f	large
19803	44632	804	Краснодарский край, Выселковский район, поселок Новодонецкая, Советская, 39/А	f	medium
19804	44633	805	Краснодарский край, Выселковский район, поселок Новодонецкая, Комсомольская, 25/А	f	medium
19838	44669	839	Краснодарский край, Выселковский район, станица Новогражданская, Ленина, 2/А	f	medium
19834	44664	835	Краснодарский край, Выселковский район, поселок Новобейсугская, Ленина, 12, телефон: 46-4-06	f	large
19833	44663	834	Краснодарский край, Выселковский район, поселок Новобейсугская, Горького, 115, телефон: 46-5-43	f	small
19831	44661	832	Краснодарский край, Выселковский район, поселок Крупская, Ленина, 70/А	f	medium
19828	44658	829	Краснодарский край, Выселковский район, поселок Ирклиевская, Красная, 49, телефон: 40-1-95	f	large
19819	44649	820	Краснодарский край, Выселковский район, поселок Иногородне-Малеваный, Южная, 4	t	medium
19808	44637	809	Краснодарский край, Выселковский район, поселок Заря, Школьная, 67, телефон: 44-1-19	f	small
22018	46824	5524	Краснодарский край, Выселковский район, поселок Заречный, Школьная, 33, телефон: 69148	t	medium
19809	44638	810	Краснодарский край, Выселковский район, поселок Заречный, Садовая, 1, телефон: 79-0-60	f	large
19825	44655	826	Краснодарский край, Выселковский район, поселок Гражданский, переулок Школьный, 5	f	medium
19826	44656	827	Краснодарский край, Выселковский район, поселок Гражданский, Мира, 15/Б	f	large
19822	44652	823	Краснодарский край, Выселковский район, поселок Газырь, Шевченко, 1/А	f	large
19814	44644	815	Краснодарский край, Выселковский район, поселок Выселки, станция Выселки	f	large
19817	44647	818	Краснодарский край, Выселковский район, поселок Выселки, переулок Полевой, 6, телефон: 72-9-38	f	large
19812	44642	813	Краснодарский край, Выселковский район, поселок Выселки, пер.Якименко, 9/А, телефон: 73-6-00	f	large
19821	44651	822	Краснодарский край, Выселковский район, поселок Выселки, пер.Первомайский, 15, телефон: 75-0-41	f	large
19818	44648	819	Краснодарский край, Выселковский район, поселок Выселки, Свободы, 97/А	f	large
19816	44646	817	Краснодарский край, Выселковский район, поселок Выселки, Ленина, 94, телефон: 73-0-67	f	large
19815	44645	816	Краснодарский край, Выселковский район, поселок Выселки, Ленина, 130/А	f	large
19813	44643	814	Краснодарский край, Выселковский район, поселок Выселки, Дзержинского, 2, телефон: 73-4-44	f	large
19810	44639	811	Краснодарский край, Выселковский район, поселок Бузиновская, Октябрьская, 38	f	large
19811	44641	812	Краснодарский край, Выселковский район, поселок Бузиновская, Мира, 73, телефон: 45-5-34	f	small
19807	44636	808	Краснодарский край, Выселковский район, поселок Березанская, Красноармейская, 55, телефон: 52-3-99	f	large
19800	44629	801	Краснодарский край, Выселковский район, поселок Бейсуг, Ленина, 2/А, телефон: 31-1-93	f	large
19801	44630	802	Краснодарский край, Выселковский район, поселок Бейсуг, Кочубея, 3/А, телефон: 31-1-33	f	medium
19827	44657	828	Краснодарский край, Выселковский район, поселок Балковская, Красная, 10	f	medium
19802	44631	803	Краснодарский край, Выселковский район, поселок Александроневская, Чапаева, 33/А	f	medium
19805	44634	806	Краснодарский край, Выселковский район, поселок 2-й Бейсужек, Октябрьская, 24	f	large
19781	44610	718	Краснодарский край, Брюховецкий район, поселок Чепигинская, Красная, 44, телефон: 43191	f	large
19779	44608	716	Краснодарский край, Брюховецкий район, поселок Челюскинец, Матросова, 5	f	medium
19790	44619	727	Краснодарский край, Брюховецкий район, поселок Свободное, Ленина, 1, телефон: 54182	f	large
19791	44620	728	Краснодарский край, Брюховецкий район, поселок Свободное, 50 лет Победы, 1А, телефон: 54102	f	medium
19792	44621	729	Краснодарский край, Брюховецкий район, поселок Приречное, Суворова, 25/3, телефон: 45125	f	medium
20111	44943	1513	Краснодарский край, Брюховецкий район, Привольный, улица Мира, 84	f	large
20248	45079	1850	Краснодарский край, Брюховецкий район, поселок Привольный, Партизанская, 16, телефон: 51-0-57	t	small
19797	44626	734	Краснодарский край, Брюховецкий район, поселок Полтавский, Солнечная, 46/1, телефон: 46135	f	small
20279	45109	1924	Краснодарский край, Брюховецкий район, поселок Полтавский, Набережная,, 9, телефон: 92-9-09	f	small
19788	44617	725	Краснодарский край, Брюховецкий район, поселок Переясловская, Толстого, 22	f	large
19789	44618	726	Краснодарский край, Брюховецкий район, поселок Переясловская, Красная, 134, телефон: 61325	f	large
19787	44616	724	Краснодарский край, Брюховецкий район, поселок Переясловская, Красная, 76	f	large
19786	44615	723	Краснодарский край, Брюховецкий район, поселок Переясловская, Красная, 83, телефон: 61368	f	large
19799	44628	736	Краснодарский край, Брюховецкий район, поселок Новое Село, Советская, 131А, телефон: 8-918-1136959	f	medium
19798	44627	735	Краснодарский край, Брюховецкий район, поселок Новое Село, Красная, 75	f	medium
19778	44607	715	Краснодарский край, Брюховецкий район, поселок Новоджерелиевская, Красная, 75, телефон: 65124	f	large
19777	44606	714	Краснодарский край, Брюховецкий район, поселок Новоджерелиевская, Красная, 56, телефон: 65281	f	large
19783	44612	720	Краснодарский край, Брюховецкий район, поселок Лиманский, Красная, 19, телефон: 63571	f	small
19785	44614	722	Краснодарский край, Брюховецкий район, поселок Лебяжий Остров, Гагарина, 6А, телефон: 63197	f	small
19946	44778	1132	Краснодарский край, Брюховецкий район, поселок Красная Поляна, Советская, 7, здание сельского клуба	t	small
19774	44603	711	Краснодарский край, Брюховецкий район, поселок Красная Нива, Длинная, 117	f	large
19784	44613	721	Краснодарский край, Брюховецкий район, поселок Киновия, Гоголя, 7, телефон: 43030	f	small
19945	44777	1131	Краснодарский край, Брюховецкий район, поселок Заря, Восточная, 7, Здание фельдшерско-акушерского пункта телефон: 2-82-37	f	small
19776	44605	713	Краснодарский край, Брюховецкий район, поселок Гарбузовая Балка, Центральная, 19, телефон: 66134	f	medium
19769	44598	706	Краснодарский край, Брюховецкий район, станица Брюховецкая, КДЦ Дом культуры 	f	large
19767	44596	704	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Энгельса, 175, телефон: 20066	f	large
67956	44593	701	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Тимофеева, 2	f	large
19766	44595	703	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Ростовская, 1, телефон: 33041	f	large
19768	44597	705	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Ленина, 55А, телефон: 22480	f	large
67957	44601	709	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Красная, 280	f	large
19765	44594	702	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Красная, 180, телефон: 32113	f	large
19770	44599	707	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Кошевого Олега, 119А, телефон: 31578	f	large
19771	44600	708	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Димитрова, 46, телефон: 32049	f	large
19773	44602	710	Краснодарский край, Брюховецкий район, поселок Брюховецкая, Выгонная, 35, телефон: 34474	f	large
19793	44622	730	Краснодарский край, Брюховецкий район, поселок Большой Бейсуг, Деркача, 1, телефон: 45122	f	large
19794	44623	731	Краснодарский край, Брюховецкий район, поселок Бол. Бейсуг, Деркача, 244, телефон: 45142	f	small
19780	44609	717	Краснодарский край, Брюховецкий район, поселок Бейсугское, Ленина, 71, телефон: 68008	f	small
19796	44625	733	Краснодарский край, Брюховецкий район, поселок Батуринская, Красная, 45	f	large
19795	44624	732	Краснодарский край, Брюховецкий район, поселок Батуринская, Красная, 40, телефон: 46289	f	large
21206	46023	3846	Краснодарский край, Большой Сочи Центральный район, ст. Надежная, улица Кооперативная, 8	f	medium
21588	46400	4534	Краснодарский край, Большой Сочи Центральный район, село Русская Мамайка, Целинная, 119/Г, телефон: 60-00-18	f	small
21556	46368	4502	Краснодарский край, Большой Сочи Центральный район, поселок Пластунка, Леселидзе, 51, телефон: 66-90-34	f	large
21621	46433	4633	Краснодарский край, Большой Сочи Центральный район, село Новая Заря, Труда, 5	f	large
21629	46441	4641	Краснодарский край, Большой Сочи Центральный район, село Новагинка, улица Абрикосовая, 2	f	large
21632	46445	4644	Краснодарский край, Большой Сочи Центральный район, село Новагинка, улица 60 Лет ВЛКСМ, 12	f	large
21590	46402	4602	Краснодарский край, Большой Сочи Центральный район, село Мамайка, Крымская, 22, телефон: 502425	f	medium
21555	46308	4501	Краснодарский край, Большой Сочи Центральный район, село Барановка, Армянская, 9	f	large
21582	46394	4528	Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, улица Ялтинская, 16а, телефон: 65-35-41	f	large
21583	46395	4529	Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, улица Краснополянская, 6, 65-43-66	f	large
21581	46393	4527	Краснодарский край, Большой Сочи Хостинский район, поселок Хоста, Ушинского, 3, телефон: 65-09-69	f	large
21480	46293	4357	Краснодарский край, Большой Сочи Хостинский район, село Хлебороб, улица Центральная, 27	f	small
21558	46370	4504	Краснодарский край, Большой Сочи Хостинский район, поселок Раздольное, Буковая, 14к3	f	large
19961	44794	1147	Краснодарский край, Большой Сочи Хостинский район, поселок Прогресс, улица Карчикяна, 11, здание фельдшерско-акушерского пункта	t	small
21561	46373	4507	Краснодарский край, Большой Сочи Хостинский район, поселок Прогресс, Юбилейная, 46	f	large
34905	28578	4305	Волгоградская область, Камышин, Металлургов, 9	f	large
21631	46444	4643	Краснодарский край, Большой Сочи Хостинский район, село Новагинка, Макаренко, 31, телефон: 640874	f	large
21625	46437	4637	Краснодарский край, Большой Сочи Хостинский район, село Новагинка, Макаренко, 45, телефон: 980917	f	medium
21624	46436	4636	Краснодарский край, Большой Сочи Хостинский район, село Новагинка, Вишневая, 7, телефон: 982295	f	large
21576	46388	4522	Краснодарский край, Большой Сочи Хостинский район, село Малый Ахун, Большой Ахун дорога, 14, телефон: 61-95-38	f	medium
21585	46397	4531	Краснодарский край, Большой Сочи Хостинский район, поселок Кудепста, улица Дарвина, 82	f	large
21586	46398	4532	Краснодарский край, Большой Сочи Хостинский район, поселок Кудепста, Апшеронская, 1	f	large
20714	45537	2629	Краснодарский край, Большой Сочи Хостинский район, Красный Октябрь, улица Шаумяна, 36б	f	small
19985	44817	1201	Краснодарский край, Большой Сочи Хостинский район, село Красная Воля, улица Володи Ульянова, 46к1	f	large
21468	46280	4345	Краснодарский край, Большой Сочи Хостинский район, село Красная Воля, Школьная, 1	t	medium
21559	46371	4505	Краснодарский край, Большой Сочи Хостинский район, поселок Измайловка, Калиновая, 22, телефон: 67-99-18	f	large
21466	46278	4343	Краснодарский край, Большой Сочи Хостинский район, поселок Дубравный, Пробковая, 20, телефон: 472886	f	medium
21568	46380	4514	Краснодарский край, Большой Сочи Хостинский район, село Бытха, улица Ворошиловская, 2/24, телефон: 67-11-89	f	large
21566	46378	4512	Краснодарский край, Большой Сочи Хостинский район, село Бытха, улица Бытха, 1, телефон: 97-40-34	f	large
21433	46249	4310	Краснодарский край, Большой Сочи Хостинский район, село Бытха, Лесная, 1, телефон: 639485	f	large
21572	46384	4518	Краснодарский край, Большой Сочи Хостинский район, село Бытха, Курортный проспект, 100	f	large
21570	46382	4516	Краснодарский край, Большой Сочи Хостинский район, село Бытха, Курортный проспект, 92, телефон: 67-15-69	f	large
21569	46381	4515	Краснодарский край, Большой Сочи Хостинский район, село Бытха, Возрождения, 19, телефон: 67-15-57	f	large
21529	46341	4430	Краснодарский край, Большой Сочи Лазаревский район, микрорайон Якорная Щель, Череповецкая, 12, телефон: 52-69-67	f	medium
21545	46357	4446	Краснодарский край, Большой Сочи Лазаревский район, микрорайон Дагомыс, Батумское шоссе, 20/2, телефон: 52-19-02	f	medium
22006	46798	5512	Краснодарский край, Большой Сочи Лазаревский район, аул Кургоковский, улица Центральная, 16а	f	small
21528	46340	4429	Краснодарский край, Большой Сочи Лазаревский район, поселок Якорная Щель, улица Главная, 66а	f	medium
21526	46338	4427	Московская область, городской округ Лосино-Петровский, деревня Осеево, Центральная улица, 93	f	large
19730	44558	640	Краснодарский край, Большой Сочи Лазаревский район, село Шахе, улица Центральная, 45	t	small
21523	46335	4424	Краснодарский край, Большой Сочи Лазаревский район, поселок Чемитоквадже, Военный санаторий Чемитоквадже, телефон: 74-98-70	t	medium
21551	46363	4452	Краснодарский край, Большой Сочи Лазаревский район, поселок Харциз Первый, Лучевая, 7, телефон: 52-58-86	f	medium
21522	46334	4423	Краснодарский край, Большой Сочи Лазаревский район, поселок Солоники, Солоники, 16	f	large
22059	46863	5640	Иркутская область, Ангарск, Кольцевая улица, 3	t	small
21506	46318	4407	Краснодарский край, Большой Сочи Лазаревский район, поселок Совет-Квадже, Сибирская, 9	f	large
21547	46359	4448	Краснодарский край, Большой Сочи Лазаревский район, село Сергей-Поле, Славы, 124	f	large
111114	46367	4456	Краснодарский край, Большой Сочи Лазаревский район, село Нижняя Беранда, Рязанская, 12	f	\N
21552	46364	4453	Краснодарский край, Большой Сочи Лазаревский район, село Мамедова Щель, улица Верхняя, 10	f	small
21505	46317	4406	Краснодарский край, Большой Сочи Лазаревский район, поселок Макопсе, Свободы, 13, телефон: 74-43-98	f	medium
21504	46316	4405	Краснодарский край, Большой Сочи Лазаревский район, поселок Макопсе, Майкопская, 69а, телефон: 74-44-45	f	medium
21503	46315	4404	Краснодарский край, Большой Сочи Лазаревский район, поселок Магри, Магринская, 8	f	small
21536	46348	4437	Краснодарский край, Большой Сочи Лазаревский район, поселок Лоо, Весенняя, 2/1	f	large
21512	46324	4413	Красноярский край, Лесосибирск, улица Победы	f	large
21521	46333	4422	Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Сочинское шоссе, 6а	f	large
21520	46332	4421	Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Победы, 2, телефон: 70-48-04	f	medium
21518	46330	4419	Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Победы, 28	f	large
21510	46322	4411	Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Победы, 167	f	large
21514	46326	4415	Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Партизанская, 16	f	large
21553	46365	4454	Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Павлова, 89, телефон: 70-71-84	f	medium
21519	46331	4420	Краснодарский край, Большой Сочи Лазаревский район, поселок Лазаревское, Нахимова, 16, телефон: 70-10-39	f	medium
21538	46350	4439	Краснодарский край, Большой Сочи Лазаревский район, поселок Культурное Учдере, улица Чайная, 7а, телефон: 50-73-74	f	medium
21548	46360	4449	Краснодарский край, Большой Сочи Лазаревский район, поселок Культурное Учдере, Образцовая, 2, телефон: 50-73-05	f	small
21524	46336	4425	Краснодарский край, Большой Сочи Лазаревский район, село Каткова Щель, улица Магистральная, 26	t	medium
20142	44974	1621	Орловская область, Орел, улица Фестивальная, 5	f	large
21541	46353	4442	Краснодарский край, Большой Сочи Лазаревский район, поселок Дагомыс, Барановское шоссе, 7	f	large
21543	46355	4444	Краснодарский край, Большой Сочи Лазаревский район, Дагомыс, Армавирская, 116	f	large
21542	46354	4443	Краснодарский край, Большой Сочи Лазаревский район, поселок Дагомыс, Армавирская, 143	f	large
21539	46351	4440	Краснодарский край, Большой Сочи Лазаревский район, поселок Дагомыс, Армавирская, 56, телефон: 52-20-75	f	medium
21544	46356	4445	Краснодарский край, Большой Сочи Лазаревский район, село Грузинская Мамайка, Батумское шоссе, 63	f	large
21540	46352	4441	Краснодарский край, Большой Сочи Лазаревский район, село Грузинская Мамайка, Батумское шоссе, 25	f	large
21507	46319	4408	Краснодарский край, Большой Сочи Лазаревский район, поселок Голубая Дача, улица Авроры, 10	f	small
21550	46362	4451	Краснодарский край, Большой Сочи Лазаревский район, поселок Волковка, улица Космическая, 1, телефон: 50-74-05	f	medium
21549	46361	4450	Краснодарский край, Большой Сочи Лазаревский район, поселок Волковка, Надежная, 28	f	large
21535	46347	4436	Краснодарский край, Большой Сочи Лазаревский район, село Верхнее Буу, улица Октемберянская, 23/Б	f	medium
21533	46345	4434	Краснодарский край, Большой Сочи Лазаревский район, село Верхнеармянское Лоо, улица Краснооктябрьская, 18, телефон: 50-95-79	f	medium
21532	46344	4433	Краснодарский край, Большой Сочи Лазаревский район, поселок Вардане, улица Львовская, 11к12	f	large
21531	46343	4432	Краснодарский край, Большой Сочи Лазаревский район, поселок Вардане, Молодежная, 36	f	large
21525	46337	4426	Краснодарский край, Большой Сочи Лазаревский район, село Большой Кичмай, улица Ачмизова, 8/Б, телефон: 76-21-47	f	medium
21530	46342	4431	Краснодарский край, Большой Сочи Лазаревский район, село Беранда, Араратская, 26/2, телефон: 52-66-68	f	medium
21449	46264	4326	Краснодарский край, Большой Сочи Адлерский район, село Высокое, Пензенская, 3	t	small
21482	46295	4359	Краснодарский край, Большой Сочи Адлерский район, поселок Веселое, Худякова, 15, телефон: 416595	f	large
21430	46246	4307	Краснодарский край, Большой Сочи Адлеровский район, село Черешня, улица Владимировская, 67к1	f	large
21469	46281	4346	Ростовская область, Ростов-на-Дону, улица Петрозаводская, 10	f	large
21921	46729	5312	Краснодарский край, Большой Сочи Адлеровский район, Нововмихайловский, Мира, 73	f	large
21428	46244	4305	Краснодарский край, Большой Сочи Адлеровский район, Нижняя Шиловка, улица Светогорская, телефон: 498159	f	large
21429	46245	4306	Краснодарский край, Большой Сочи Адлеровский район, село Нижняя Шиловка, улица Грушевая, 10, телефон: 498108	f	medium
21481	46294	4358	Краснодарский край, Большой Сочи Адлеровский район, село Нижняя Шиловка, Светогорская, 16а, телефон: 416180	f	large
21436	46252	4313	Краснодарский край, Большой Сочи Адлеровский район, поселок Нижнеимеретинская Бухта, улица Нижнеимеретинская, телефон: 416442 (деж-во), в день голос. сот связь	f	medium
111084	46298	4386	Краснодарский край, Большой Сочи Адлеровский район, поселок Нижнеимеретинская Бухта, микрорайон Мирный	f	\N
80686	14073	376	Ярославская область, Рыбинск, Куйбышева, 26	f	large
21435	46251	4312	Краснодарский край, Большой Сочи Адлеровский район, поселок Нижнеимеретинская Бухта, Полевая, 12	f	large
21471	46283	4348	Краснодарский край, Большой Сочи Адлеровский район, село Молдовка, Пчеловодов, 4	f	large
21199	46016	3839	Ставропольский край, Изобильненский район, станция Передовая	f	large
21431	46247	4308	Краснодарский край, Большой Сочи Адлеровский район, поселок Веселое, Мира переулок, 16а	f	large
21465	46277	4342	Краснодарский край, Большой Сочи Адлеровский район, село Верхнениколаевское, Мостовая, 12а	f	medium
21442	46257	4319	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ульянова, 68, телефон: 401278	f	large
21451	46266	4328	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ромашек, 1, телефон: 404165	f	large
21448	46263	4325	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Революции, 4	f	medium
21464	46276	4341	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ленина, 233, телефон: 902132 (собственная АТС	f	medium
111082	46260	4322	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Ленина, 42	f	medium
21450	46265	4327	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Куйбышева, 32, телефон: 401222	f	large
21455	42682	4332	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, улица Кирпичная, 3, телефон: 464878	f	large
21444	46259	4321	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Ульянова, 55, телефон: 404423	f	large
21446	46261	4323	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Свердлова, 94, телефон: 401685	f	large
21443	46258	4320	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Садовая, 51, телефон: 401313	f	large
21463	46275	4340	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Просвещения, 139, телефон: 473472	f	large
21447	46262	4324	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Молокова, 1, телефон: 403752	f	large
21452	46267	4329	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Котовского, 3, телефон: 404353	f	large
21484	46297	4361	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Костромская, 58а	f	large
21454	46269	4331	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Кирпичная, 1к1, телефон: 462810	f	large
21438	46253	4315	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Демократическая, 43, телефон: 400495	f	medium
21459	46271	4336	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Голубые Дали, 60, телефон: 465157	f	large
21456	42874	4333	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Гастелло, 29, телефон: 466631	f	large
67964	45464	2428	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, 8 Марта, 127 В	f	large
21458	46270	4335	Краснодарский край, Большой Сочи Адлеровский район, поселок Адлер, Голубые Дали, 21, телефон: 462932	f	large
86116	45883	3308	Краснодарский край, Белореченский район, поселок Южный, Шоссейная, 9	t	small
19716	44545	626	Краснодарский край, Белореченский район, поселок Южный, Школьная, 16, телефон: 3-82-78	f	large
20741	45564	2656	Краснодарский край, Белореченский район, поселок Южный, Центральная, 1, телефон: 6-73-33	f	medium
20217	45049	1819	Краснодарский край, Белореченский район, поселок Южный, Краснооктябрьская, 1	f	medium
19725	44553	635	Краснодарский край, Белореченский район, поселок Школьное, Советская, 7, телефон: 75-1-85	f	medium
19750	44578	660	Краснодарский край, Белореченский район, поселок Черниговская, Красная, 44	f	medium
19740	44568	650	Краснодарский край, Белореченский район, поселок Фокин Первый, Школьная, 1, телефон: 71-3-19	f	small
19760	44588	670	Краснодарский край, Белореченский район, поселок Фадеевский, Мира, 52	f	small
20793	45616	2743	Краснодарский край, Белореченский район, поселок Северный, Красная, 4, телефон: 6-61-55	t	small
19723	44551	633	Краснодарский край, Белореченский район, поселок Садовый, Комарова, 31/А, телефон: 2-55-27	f	small
19743	44571	653	Краснодарский край, Белореченский район, поселок Рязанская, Победы, 69/А, телефон: 71-2-01	f	large
19742	44570	652	Краснодарский край, Белореченский район, поселок Рязанская, Первомайская, 108, телефон: 71-1-30	f	large
19741	44569	651	Краснодарский край, Белореченский район, поселок Рязанская, Кубанская, 6	f	large
19720	44548	630	Краснодарский край, Белореченский район, поселок Родники, Центральная, 11/А	f	medium
19719	44547	629	Краснодарский край, Белореченский район, поселок Родники, Норильская, 6, телефон: 3-71-18	f	large
19761	44589	671	Краснодарский край, Белореченский район, поселок Пшехская, Мира, 6	f	large
19762	44590	672	Краснодарский край, Белореченский район, поселок Пшехская, Крестьянская, 4	f	large
19763	44591	673	Краснодарский край, Белореченский район, поселок Пшехская, Заречная, здание магазина Орфей	f	medium
19735	44563	645	Краснодарский край, Белореченский район, поселок Проточный, Мира, 22, телефон: 64-5-42	f	small
111033	45889	3316	Краснодарский край, Белореченский район, Пос.Первомайский, Центральная, 12	t	medium
20660	45483	2512	Краснодарский край, Белореченский район, поселок Октябрьская, Привокзальная, 1, здание МОУ СОШ №30, телефон: 39005	f	large
19749	44577	659	Краснодарский край, Белореченский район, поселок Новогурийский, Школьная, 5	f	small
19726	44554	636	Краснодарский край, Белореченский район, поселок Новоалексеевское, Красная, 19	f	medium
19744	44572	654	Краснодарский край, Белореченский район, поселок Нижневеденеевский, Клубная, 1, телефон: 61-5-40	f	small
19751	44579	661	Краснодарский край, Белореченский район, поселок Молодежный, Ленина, 10, телефон: 65-1-63	f	large
19729	44557	639	Краснодарский край, Белореченский район, поселок Леонтьевское, Клубная, 15, телефон: 75-2-72	f	small
19728	44556	638	Краснодарский край, Белореченский район, поселок Лантратов, Мира, здание клуба, телефон: 75-5-30	f	small
22072	46874	5653	Краснодарский край, Белореченский район, поселок Заречный, Центральная, 21	f	medium
134653	94979	698	Краснодарский край, Белореченский район, поселок Дружный, Химплощадка	f	medium
19754	44582	664	Краснодарский край, Белореченский район, поселок Дружный, Советская, 61, телефон: 73-1-10	f	small
19755	44583	665	Краснодарский край, Белореченский район, поселок Дружный, Заводская, 8/А	f	small
19756	44584	666	Краснодарский край, Белореченский район, поселок Долгогусевский, Луценко, 5/2, телефон: 69-2-82	f	small
19757	44585	667	Краснодарский край, Белореченский район, поселок Долгогусевский, Голенева, 68/Б	f	medium
19752	44580	662	Краснодарский край, Белореченский район, поселок Гурийская, Школьная, 57, телефон: 65-4-16	f	small
19739	44567	649	Краснодарский край, Белореченский район, поселок Ганжинский, Солнечная, 7, телефон: 64-6-34	f	small
19734	44562	644	Краснодарский край, Белореченский район, поселок Верхневеденеевский, Гагарина, 14, телефон: 62-1-43	f	small
19731	44559	641	Краснодарский край, Белореченский район, поселок Великовечное, Советская, 55, телефон: 39-2-25	f	large
19733	44561	643	Краснодарский край, Белореченский район, поселок Великовечное, Почтовая, 59, телефон: 39-1-72	f	large
19732	44560	642	Краснодарский край, Белореченский район, поселок Великовечное, Ленина, 50/Б	f	large
19746	44574	656	Краснодарский край, Белореченский район, поселок Бжедуховская, Красная, 85	f	medium
19747	44575	657	Краснодарский край, Белореченский район, поселок Бжедуховская, Комсомольская, 7	f	medium
19703	44532	613	Краснодарский край, Белореченский район, город Белореченск, Совхозная, 3	f	large
67953	44521	603	Краснодарский край, Белореченский район, город Белореченск, Ленина, 85	f	large
67954	44529	611	Краснодарский край, Белореченский район, Белореченск, Шалимова, 28	f	large
19711	44540	621	Краснодарский край, Белореченский район, Белореченск, Свердлова, 1, телефон: 3-36-01	f	large
19713	44542	623	Краснодарский край, Белореченский район, Белореченск, Пролетарская, 220, телефон: 2-73-09	f	large
19707	44536	617	Краснодарский край, Белореченский район, Белореченск, Победы, 170, телефон: 2-41-26	f	large
19706	44535	616	Краснодарский край, Белореченский район, Белореченск, Победы, 353, телефон: 3-37-12	f	large
67955	44533	614	Краснодарский край, Белореченский район, Белореченск, Победы, 461	f	large
19694	44522	604	Краснодарский край, Белореченский район, Белореченск, Мира, 2, телефон: 2-21-85	f	large
19698	44526	608	Краснодарский край, Белореченский район, Белореченск, Луначарского, 122, телефон: 2-35-23, 2-35-89	f	large
110997	44525	607	Краснодарский край, Белореченский район, Белореченск, Ленина, 119	f	medium
83914	57336	3107	Москва, Зеленоград, к314	f	large
19699	44527	609	Краснодарский край, Белореченский район, Белореченск, Красная, 50, телефон: 2-32-58	f	large
19695	44523	605	Краснодарский край, Белореченский район, Белореченск, Интернациональная, 153	f	large
19692	44520	602	Краснодарский край, Белореченский район, Белореченск, Интернациональная, 1, телефон: 2-49-77	f	large
19714	44543	624	Краснодарский край, Белореченский район, Белореченск, Железнодорожная, 2, телефон: 3-23-44	f	medium
19710	44539	620	Краснодарский край, Белореченский район, Белореченск, Деповская, 68, телефон: 76-9-52	f	large
19696	44524	606	Краснодарский край, Белореченский район, Белореченск, Гоголя, 51, телефон: 2-44-00	f	large
19700	44528	610	Краснодарский край, Белореченский район, Белореченск, 40 лет Октября, 33, телефон: 2-22-65	f	large
19727	44555	637	Краснодарский край, Белореченский район, поселок Архиповское, Первомайская, 8/А, телефон: 75-7-30	f	medium
19681	44509	512	Краснодарский край, Белоглинский район, поселок Центральный, Советская, 3, телефон: 91199	f	medium
19689	44517	520	Краснодарский край, Белоглинский район, поселок Успенская, Советская, 113, телефон: 92714	f	large
19688	44516	519	Краснодарский край, Белоглинский район, поселок Успенская, Краснопартизанская, 151, телефон: 92585	f	large
19690	44518	521	Краснодарский край, Белоглинский район, поселок Туркинский, Алексенко, 88	f	medium
19680	44508	511	Краснодарский край, Белоглинский район, поселок Селекционный, переулок Почтовый, 6, телефон: 91495	f	medium
19682	44510	513	Краснодарский край, Белоглинский район, поселок Садовый, Садовая, 25, телефон: 91716	f	small
19684	44512	515	Краснодарский край, Белоглинский район, поселок Новопавловка, Соболя, 64, телефон: 94208	f	large
19687	44515	518	Краснодарский край, Белоглинский район, поселок Новолокинская, Красная, 1	f	medium
19686	44514	517	Краснодарский край, Белоглинский район, поселок Меклета, 60 лет СССР, 279, телефон: 96166	f	medium
19683	44511	514	Краснодарский край, Белоглинский район, поселок Магистральный, Новая, 14	t	small
19685	44513	516	Краснодарский край, Белоглинский район, поселок Кулешовка, Мира, 153, телефон: 95242	f	large
19679	44507	510	Краснодарский край, Белоглинский район, поселок Западный, Степная, 3, телефон: 91430	f	small
19673	44501	504	Краснодарский край, Белоглинский район, поселок Белая Глина, Толстого, 56, телефон: 72405	f	medium
19677	44505	508	Краснодарский край, Белоглинский район, поселок Белая Глина, Первомайская, 159	f	large
19675	44503	506	Краснодарский край, Белоглинский район, поселок Белая Глина, Первомайская, 282	f	large
19674	44502	505	Краснодарский край, Белоглинский район, поселок Белая Глина, Первомайская, 367	f	large
19670	44498	501	Краснодарский край, Белоглинский район, поселок Белая Глина, Крестьянская, 92, телефон: 75452	f	large
19676	44504	507	Краснодарский край, Белоглинский район, поселок Белая Глина, Красная,, 132	f	large
19671	44499	502	Краснодарский край, Белоглинский район, поселок Белая Глина, Красная, 20, телефон: 74538	f	large
19672	44500	503	Краснодарский край, Белоглинский район, поселок Белая Глина, Колхозная, 104, телефон: 73925	f	large
19678	44506	509	Краснодарский край, Белоглинский район, поселок Белая Глина, Капитана Молчанова, 49, телефон: 72142	f	large
19574	44403	336	Краснодарский край, Апшеронский район, поселок Ширванская, Советская, 14	f	small
19577	44406	339	Краснодарский край, Апшеронский район, поселок Черниговское, Шоссейная, телефон: 34147	f	large
19555	44384	317	Краснодарский край, Апшеронский район, поселок Цуревский, Полевая, 1	t	small
19564	44394	326	Краснодарский край, Апшеронский район, Хадыженск, Промысловая, 24, телефон: 40188	f	large
19556	44385	318	Краснодарский край, Апшеронский район, Хадыженск, Промысловая, 18, телефон: 40146	f	large
19559	44388	321	Краснодарский край, Апшеронский район, город Хадыженск, Первомайская, 128, телефон: 49352	t	large
19558	44387	320	Краснодарский край, Апшеронский район, Хадыженск, Кирова, 144, телефон: 4-91-25	f	large
19557	44386	319	Краснодарский край, Апшеронский район, Хадыженск, Аэродромная, 43/а, телефон: 41797	f	large
19581	44410	343	Краснодарский край, Апшеронский район, поселок Тубы, Клубная, 25, телефон: 4855819	t	small
19562	44391	324	Краснодарский край, Апшеронский район, поселок Травалев, Чкалова, 93	f	small
19593	44422	355	Краснодарский край, Апшеронский район, поселок Тверская, Советская, 5, телефон: 30229	f	large
19587	44416	349	Краснодарский край, Апшеронский район, поселок Станционный, Привокзальная, телефон: 46500	f	small
19541	44371	303	Краснодарский край, Апшеронский район, поселок Спасов, Хадыженское шоссе, 85, телефон: 27388	f	small
19573	44402	335	Краснодарский край, Апшеронский район, поселок Самурская, Ленина, 29	t	small
19582	44411	344	Краснодарский край, Апшеронский район, поселок Режет, Железнодорожная, 9, телефон: 2260610	f	small
19580	44409	342	Краснодарский край, Апшеронский район, поселок Отдаленный, Клубная, 13, телефон: 4858100	t	small
19572	44401	334	Краснодарский край, Апшеронский район, поселок Новые Поляны, Советская, 1а	f	large
19570	44399	332	Краснодарский край, Апшеронский район, поселок Николаенко, Дружбы, 2	f	medium
19575	44404	337	Краснодарский край, Апшеронский район, поселок Нижегородская, Центральная, 45	t	small
19571	44400	333	Краснодарский край, Апшеронский район, поселок Нефтяная, Красная, 132	f	medium
19566	44396	328	Краснодарский край, Апшеронский район, поселок Нефтегорск, Школьная, 8, телефон: 31410	f	large
19565	44395	327	Краснодарский край, Апшеронский район, поселок Нефтегорск, Школьная, 8,1, телефон: 31415	f	medium
19568	44397	330	Краснодарский край, Апшеронский район, поселок Нефтегорск, Советская, 22, телефон: 31408	f	medium
19567	14682	329	Краснодарский край, Апшеронский район, поселок Нефтегорск, Советская, 72	t	medium
19579	44408	341	Краснодарский край, Апшеронский район, поселок Мезмай, Железнодорожная, 6, телефон: 32018	t	small
19592	44421	354	Краснодарский край, Апшеронский район, поселок Малько, Ленина, 33	t	small
19595	44424	357	Краснодарский край, Апшеронский район, поселок Линейная, Школьная, 1	t	small
19594	44423	356	Краснодарский край, Апшеронский район, поселок Лесогорская, Центральная, 5	t	medium
19585	44414	347	Краснодарский край, Апшеронский район, поселок Куринская, Новицкого, 118	f	medium
19586	44415	348	Краснодарский край, Апшеронский район, станица Куринская, Железнодорожная, 16	f	medium
19583	44412	345	Краснодарский край, Апшеронский район, поселок Кабардинская, Ленина, 43	f	medium
19584	44413	346	Краснодарский край, Апшеронский район, поселок Кабардинская, Клубная, 13	t	small
19718	44546	628	Краснодарский край, Апшеронский район, поселок Заречный, Советская, 18	f	large
19554	44383	316	Краснодарский край, Апшеронский район, поселок Зазулин, Угольная	t	small
19589	44418	351	Краснодарский край, Апшеронский район, поселок Ерик, Школьная, 18, телефон: 76181	f	medium
19576	44405	338	Краснодарский край, Апшеронский район, поселок Гуамка, Клубная, 1, телефон: 77138	t	small
19590	44419	352	Краснодарский край, Апшеронский район, поселок Вперед, Кимовская, 80-а, телефон: 26995	t	medium
19546	44375	308	Краснодарский край, Апшеронский район, город Апшеронск, Пролетарская, 62, телефон: 28307	f	large
19551	44380	313	Краснодарский край, Апшеронский район, город Апшеронск, Ленина, 74, телефон 20909	f	large
19549	44378	311	Краснодарский край, Апшеронский район, город Апшеронск, Ленина, 47, телефон: 92648	f	large
19543	44373	305	Краснодарский край, Апшеронский район, город Апшеронск, Краснознаменная, 40	f	large
19540	44370	302	Краснодарский край, Апшеронский район, город Апшеронск, Красноармейская, 2, телефон: 25574	f	large
19548	44377	310	Краснодарский край, Апшеронский район, город Апшеронск, Коммунистическая, 15, телефон: 28485	f	large
19542	44372	304	Краснодарский край, Апшеронский район, город Апшеронск, Исполкомовская, 2, телефон: 26166	f	large
19544	44342	306	Краснодарский край, Апшеронский район, Апшеронск, Пролетарская, 79, телефон: 28464	f	large
19550	44379	312	Краснодарский край, Апшеронский район, Апшеронск, Ленина, 30, телефон: 91605	f	large
19552	44381	314	Краснодарский край, Апшеронский район, Апшеронск, Королева, 122, телефон: 21834	f	large
19547	44376	309	Краснодарский край, Апшеронский район, Апшеронск, Комарова, 76, телефон: 26574	f	large
19511	44340	241	Краснодарский край, Анапский район, ст.Гостагаевская, Советская, 112, телефон: 25272	f	large
19515	44345	245	Краснодарский край, Анапский район, поселок Юровка, Садовая, 202, телефон: 95224	f	medium
19514	44344	244	Краснодарский край, Анапский район, поселок Юровка, Садовая, 91, телефон: 95198	f	large
19521	44351	251	Краснодарский край, Анапский район, поселок Черный, Свободы, 9	t	medium
19489	44318	219	Краснодарский край, Анапский район, поселок Чембурка, отделение связи	f	small
19534	44364	264	Краснодарский край, Анапский район, поселок Цибанобалка, Совхозная, 17, телефон: 23166	f	large
19522	44352	252	Краснодарский край, Анапский район, поселок Цибанобалка, Садовая, 74, телефон: 23110	f	large
19499	44328	229	Краснодарский край, Анапский район, поселок Усатова Балка, Чехова, 33, телефон: 71867	t	medium
19529	44359	259	Краснодарский край, Анапский район, поселок Супсех, Фрунзе, 72, телефон: 29791	f	large
19538	44368	268	Краснодарский край, Анапский район, поселок Супсех, Советская, 42, телефон: 29666	f	large
19528	44358	258	Краснодарский край, Анапский район, поселок Супсех, Парковый проезд, 20	f	large
19531	44361	261	Краснодарский край, Анапский район, поселок Сукко, Советская, 103, телефон: 93154, факс: 93154, email: уик261@mail.ru	f	large
19505	44334	235	Краснодарский край, Анапский район, поселок Суворов-Черкесский, Пушкина, 2	f	medium
19526	44356	256	Краснодарский край, Анапский район, поселок Пятихатки, Солнечная, 7	t	medium
19532	44362	262	Краснодарский край, Анапский район, поселок Просторный, Школьная, 1, телефон: 97333	f	medium
19525	44355	255	Краснодарский край, Анапский район, поселок Ниж. Гостагайка, Гремахова, 4, телефон: 96498	t	medium
19524	44354	254	Краснодарский край, Анапский район, поселок Красный Курган, Свободы, 33А, телефон: 73470	t	medium
19563	44393	325	Краснодарский край, Анапский район, поселок Красная Горка, Красногорская, 29	t	small
19518	44348	248	Краснодарский край, Анапский район, поселок Иванов, Солнечная, 6	t	small
19533	44363	263	Краснодарский край, Анапский район, поселок Джигинка, Центральная, здание администрации с/о, телефон: 76182	f	large
19512	44341	242	Краснодарский край, Анапский район, поселок Джигинка, Октябрьская, 30, телефон: 76294	f	large
19510	44339	240	Краснодарский край, Анапский район, поселок Гостагаевская, Новороссийская, 100, телефон: 25115	f	large
19509	44338	239	Краснодарский край, Анапский район, поселок Гостагаевская, Мира, 45, телефон: 25450	f	large
19527	44357	257	Краснодарский край, Анапский район, поселок Воскресенский, улица Мира, 4А	f	medium
19517	44347	247	Краснодарский край, Анапский район, поселок Вестник, Центральная, 39	t	medium
19516	44346	246	Краснодарский край, Анапский район, поселок Бол. Разнокол, Южная, 1А	f	medium
19500	44329	230	Краснодарский край, Анапский район, поселок Благовещенская, Лобача, 3	f	large
19446	44277	118	Краснодарский край, Абинский район, поселок Эриванская, Ленина, 32	f	small
19443	44274	115	Краснодарский край, Абинский район, поселок Шапсугская, Красная, 19	f	small
19459	44287	131	Краснодарский край, Абинский район, станица Холмская, Каменеческая, 19	f	large
19455	44283	127	Краснодарский край, Абинский район, поселок Холмская, Холмская, 1	f	large
19456	44284	128	Краснодарский край, Абинский район, поселок Холмская, Толстого, 62	f	large
19454	44282	126	Краснодарский край, Абинский район, поселок Холмская, Рудничная, 5Б	f	large
19457	44285	129	Краснодарский край, Абинский район, поселок Холмская, Мира, 151	f	large
19458	44286	130	Краснодарский край, Абинский район, поселок Холмская, Ленина, 181	f	large
19468	44296	140	Краснодарский край, Абинский район, поселок Федоровская, Первомайская, 1	f	medium
19466	44294	138	Краснодарский край, Абинский район, поселок Федоровская, Красная, 3	f	large
19460	44288	132	Краснодарский край, Абинский район, поселок Синегорск, Лесная, 3, телефон: 99-2-50	f	medium
19445	44276	117	Краснодарский край, Абинский район, поселок Светлогорское, Центральная, 1А, телефон: 9-55-44	f	medium
19444	44275	116	Краснодарский край, Абинский район, поселок Пролетарий, здание филиала МАУ Абинский КДЦ	t	small
20046	44879	1314	Краснодарский край, Абинский район, поселок Первомайский, Мира, 33А, телефон: 97182	f	small
19470	44298	142	Краснодарский край, Абинский район, поселок Ольгинский, Первомайская, 17	f	large
19717	44530	627	Краснодарский край, Абинский район, поселок Новый, Есенина, 8, телефон: 3-86-68	f	small
19461	44289	133	Краснодарский край, Абинский район, поселок Новый, Офицерская, 1	f	small
19464	44292	136	Краснодарский край, Абинский район, станица Мингрельская, Советская, 67	f	large
19465	44293	137	Краснодарский край, Абинский район, поселок Мингрельская, Мельничная, 20, телефон: 9-75-41	f	large
21828	46640	5058	Краснодарский край, Абинский район, поселок Ленинский, Красная, 36	f	medium
34924	28594	4324	Волгоградская область, Камышин, Короленко, 24, ДЮСШ№2	f	large
19462	44290	134	Краснодарский край, Абинский район, поселок Краснооктябрьский, Пионерская, 38	f	medium
19467	44295	139	Краснодарский край, Абинский район, поселок Екатериновский, Суворова, 7А	f	large
19447	44245	119	Краснодарский край, Абинский район, поселок Варнавинское, Красная, 75, телефон: 9-42-60	f	medium
19452	44280	124	Краснодарский край, Абинский район, поселок Ахтырский, Школьная, 17	f	large
19448	43979	120	Краснодарский край, Абинский район, поселок Ахтырский, Свободы, 8, телефон: 3-72-27	f	large
19451	44279	123	Краснодарский край, Абинский район, поселок Ахтырский, Мира, 6, телефон: 6-24-43	f	large
19449	47070	121	Краснодарский край, Абинский район, поселок Ахтырский, Красная, 25, телефон: 3-71-95	f	large
19450	44278	122	Краснодарский край, Абинский район, поселок Ахтырский, Красная, 40	f	large
19453	44281	125	Краснодарский край, Абинский район, поселок Ахтырский, Колхозная, 46, телефон: 3-62-24	f	large
19440	44271	112	Краснодарский край, Абинский район, Абинск, Советов, 2А, телефон: 5-12-95	f	large
19437	44268	109	Краснодарский край, Абинский район, город Абинск, Советов, 35, телефон: 5-25-78	f	large
19441	44272	113	Краснодарский край, Абинский район, город Абинск, Набережная, 59А	f	large
19434	44265	106	Краснодарский край, Абинский район, Абинск, Мира, 200А, телефон: 4-42-84	f	large
19432	44263	104	Краснодарский край, Абинский район, Абинск, Интернациональная, 73, телефон: 5-13-54	f	large
19431	44262	103	Краснодарский край, Абинский район, город Абинск, Интернациональная, 32	f	large
19429	44260	101	Краснодарский край, Абинский район, Абинск, Интернациональная, 23, телефон: 5-15-54	f	large
19435	44266	107	Краснодарский край, Абинский район, Абинск, Володарского, 55, телефон: 5-20-36	f	large
19433	44264	105	Краснодарский край, Абинский район, город Абинск, Вокзальная, 16, телефон: 5-18-98	f	large
19442	47069	114	Краснодарский край, Абинский район, Абинск, Тищенко, 84, телефон: 5-27-35	f	large
19438	44269	110	Краснодарский край, Абинский район, Абинск, Советов, 15, телефон: 4-48-81	f	large
19430	44261	102	Краснодарский край, Абинский район, Абинск, Пролетарская, 3, телефон: 5-35-68	f	large
19439	47071	111	Краснодарский край, Абинский район, Абинск, Набережная, 11, телефон: 4-26-48	f	large
19436	44267	108	Краснодарский край, Абинский район, Абинск, Володарского, 1	f	large
34150	27878	1830	Волгоградская область, Хутор Первомайский, Первомайская, 19А, Первомайская НОШ	f	small
34359	28057	2502	Волгоградская область, Хутор Княжеский-1, Левинская, 10, Княженский-1 сельский клуб	f	small
34709	28385	3628	Волгоградская область, Хутор Кепенский, Кепенский сельский клуб	f	small
35009	28677	4608	Волгоградская область, Фролово, Чапаева, 17	f	large
35011	28679	4610	Волгоградская область, Фролово, Фроловская, 6	f	large
35021	28689	4620	Волгоградская область, Фролово, Строителей, 138	f	large
35019	28687	4618	Волгоградская область, Фролово, Строителей, 206	f	large
35012	28680	4611	Волгоградская область, Фролово, Свердлова, 33	f	large
35014	28682	4613	Волгоградская область, Фролово, Революционная, 17	f	large
35010	28678	4609	Волгоградская область, Фролово, Революционная, 13	f	large
35004	28672	4603	Волгоградская область, Фролово, Рабочая, 5а	f	large
35002	28670	4601	Волгоградская область, Фролово, Рабочая, 62	f	large
35018	28686	4617	Волгоградская область, Фролово, Пролетарская, 326	f	large
35023	28691	4622	Волгоградская область, Фролово, Орджоникидзе, 10	f	large
35016	28684	4615	Волгоградская область, Фролово, Народная, 97	f	large
35008	28676	4607	Волгоградская область, Фролово, Народная, 23	f	large
35013	28681	4612	Волгоградская область, Фролово, Московская, 66	f	large
35017	28685	4616	Волгоградская область, Фролово, Красноармейская, 79а	f	large
35006	28674	4605	Волгоградская область, Фролово, Зеленая, 50	f	small
35022	28690	4621	Волгоградская область, Фролово, Заречный квартал, 11а	f	large
35007	28675	4606	Волгоградская область, Фролово, Заречный квартал, 36	f	large
35015	28683	4614	Волгоградская область, Фролово, Донская, 7	f	large
35020	28688	4619	Волгоградская область, Фролово, Гагарина, 23	f	large
34850	28524	4016	Волгоградская область, Урюпинск, пр. Ленина, 64, МП Гостиница Урюпинск	f	large
34838	28472	4004	Волгоградская область, Урюпинск, Чапаева, 16, МОУ Гимназия	f	large
34844	28518	4010	Волгоградская область, Урюпинск, Советская, 150А, МОУ СОШ №4	f	large
83913	57336	3106	Москва, Зеленоград, к314	f	large
34854	28528	4020	Волгоградская область, Урюпинск, Разливаева, 6, ГОУНПО Казачье кадетское ПУ-41	f	large
34843	28517	4009	Волгоградская область, Урюпинск, Пушкина, 111, Урюпинская автошкола РОСТО	f	large
34849	28523	4015	Волгоградская область, Урюпинск, Островского, 20, Очно-заочная вечерняя школа УПЦ	f	large
34841	28515	4007	Волгоградская область, Урюпинск, Октябрьская, 43, ГОУ СПО Медицинский колледж №5 г.Урюпинск	f	large
34840	28514	4006	Волгоградская область, Урюпинск, Октябрьская, 6, МОУ ДОД Детская школа искусств	f	large
34853	28527	4019	Волгоградская область, Урюпинск, Московская, 9, НОУ ВПО ВИБ	f	large
34852	28526	4018	Волгоградская область, Урюпинск, Мичурина, 42, МОУ СОШ №7	f	large
34848	28522	4014	Волгоградская область, Урюпинск, М. Горького, 47, МОУ СОШ №3	f	large
34842	28516	4008	Волгоградская область, Урюпинск, Льва Толстого, 42, МБОУ Лицей	f	large
34835	28510	4001	Волгоградская область, Урюпинск, Красноармейская, 5, МОУДОД Центр детского творчества	f	large
34839	28513	4005	Волгоградская область, Урюпинск, Гагарина, 29, Кинотеатр МИР	f	large
34845	28519	4011	Волгоградская область, Урюпинск, Волгоградская, 1А, МДОУ Детский сад №5 Радуга	f	large
34846	28520	4012	Волгоградская область, Урюпинск, Весенняя, 2, МДОУ Десткий сад №1 Березка	f	large
34851	28525	4017	Волгоградская область, Урюпинск, Большая Мушкетовская, 28, МУ Благоустройство и озеленение	f	large
34837	28512	4003	Волгоградская область, Урюпинск, 50-лет Победы, 5, ГОУ Урюпинская Школа-интернат	f	large
34836	28511	4002	Волгоградская область, Урюпинск, 50-лет Победы, 16, МОУ СОШ №6	f	large
34847	28521	4013	Волгоградская область, Урюпинск, Гастелло, 3, МОУ СОШ №5	f	large
34749	28425	3730	Волгоградская область, поселок Третья Карта, Тракторная, 2/1, ФАП	f	small
34774	28449	3755	Волгоградская область, поселок Третий Решающий, Центральная, 2, Здание школы	f	small
34807	28481	3907	Волгоградская область, Суровикино, Орджоникидзе, 69	f	large
34747	28423	3728	Волгоградская область, хутор Старенький, Центральная, 9, Здание клуба	f	small
34733	28409	3714	Волгоградская область, поселок Средняя Ахтуба, Октябрьская, 91, ЖКО	f	large
34736	28412	3717	Волгоградская область, поселок Средняя Ахтуба, Ленина, 63, КДЦ Юбилейный	f	large
34734	28410	3715	Волгоградская область, поселок Средняя Ахтуба, Гагарина, 114, ДС Дельфиненок	f	medium
34718	28394	3637	Волгоградская область, Серафимович, Пролетарская, 7, СОШ№1	f	large
34687	28363	3606	Волгоградская область, село Рыбный, Рыбинский сельский клуб	f	small
34775	28450	3756	Волгоградская область, поселок Рыбачий, Центральная, 42, Контора рыболовецкого колхоза	f	small
34197	27924	1925	Волгоградская область, Петров Вал, переулок Карла Маркса, 1	f	large
34561	28262	3201	Волгоградская область, Палласовка, Пугачева, 29	f	large
34449	28146	2808	Волгоградская область, Новоаннинский, Ленина, 70	f	large
34742	28418	3723	Волгоградская область, хутор Новенький, Центральная, 16, здание сельского клуба	f	small
34234	27960	2020	Волгоградская область, Михайловка, здание Михайловской школы	f	small
34944	28612	4404	Волгоградская область, Михайловка, площадь Конституции, 1, МУК ГДК	f	large
34964	28632	4424	Волгоградская область, Михайловка, Ясный, 5, МОУ ООШ №8	f	large
34946	28614	4406	Волгоградская область, Михайловка, Южная, 1, общежитие тех. техникума	f	large
34958	28626	4418	Волгоградская область, Михайловка, Энгельса, 19, МОУ СОШ №7	f	large
34942	28610	4402	Волгоградская область, Михайловка, Энгельса, 12, ГОУ ПТУ №23	f	large
34949	28617	4409	Волгоградская область, Михайловка, Стройная, 42, МДОУ Школа-сад №14 Теремок	f	large
34945	28613	4405	Волгоградская область, Михайловка, Смехова, 1, МОУ СОШ №4	f	large
34951	28619	4411	Волгоградская область, Михайловка, Свободы, 21, ГУП ПТП Михайловское	f	large
34960	28628	4420	Волгоградская область, Михайловка, Республиканская, 42, МУК ЦБС гор. детская библиотека	f	large
34957	28625	4417	Волгоградская область, Михайловка, Республиканская, 26, МУК ЦБС центр. гор. библиотека	f	large
34954	28622	4414	Волгоградская область, Михайловка, Пирогова, 2, МОУ ДОД Стация юных юнатов	f	medium
34962	28630	4422	Волгоградская область, Михайловка, Новороссийская, 1, МОУ СОШ №10	f	large
34941	28609	4401	Волгоградская область, Михайловка, Мичурина, 26, МОУ СОШ №3	f	large
33895	27636	1192	Волгоградская область, Волжский, Мира, 159	f	large
34963	28631	4423	Волгоградская область, Михайловка, Мира, 79, МОУ Открытая сменная школа	f	large
34943	28611	4403	Волгоградская область, Михайловка, Магистральная, 2, МУ Мих. спортивный комплекс	f	large
34966	28634	4426	Волгоградская область, Михайловка, Ленина, 185-В, МДОУ Детский сад №21 Родничок	f	large
34956	28624	4416	Волгоградская область, Михайловка, Ленина, 66, МОУ СОШ №1	f	large
34953	28621	4413	Волгоградская область, Михайловка, Кубанский, 2, МУ Клуб Заозерье	f	large
34947	28615	4407	Волгоградская область, Михайловка, Крупской, 99-E, МДОУ Дет.сад №25 	f	large
34965	28633	4425	Волгоградская область, Михайловка, Карельская, 2-В, МУП Водоканал	f	large
34955	28623	4415	Волгоградская область, Михайловка городской округ, Гоголя, 29, ГОУ СПО Михайловский педколледж	f	large
34948	28616	4408	Волгоградская область, Михайловка, Байкальская, 31, МУ Себровский ДК	f	large
34952	28620	4412	Волгоградская область, Михайловка, Александра Невского, 12, Подростковый клуб Одуванчик	f	large
34961	28629	4421	Волгоградская область, Михайловка, 2 Краснознаменская, 18-А, МУ Соц.дос. центр для подрост	f	large
34959	28627	4419	Волгоградская область, Михайловка, 2 Краснознаменская, 55, Городской ЗАГС	f	large
34336	28037	2404	Волгоградская область, Ленинск, Крупской, 7	f	large
34746	28422	3727	Волгоградская область, Лебяжья Поляна, Павших Борцов, 4, Дом культуры	f	medium
34750	28426	3731	Волгоградская область, поселок Красный Буксир, Шоссейная, 2, клуб	f	small
34722	28398	3703	Волгоградская область, Краснослободск, улица Космонавтов, 22, школа № 2	f	large
34727	28403	3708	Волгоградская область, Краснослободск, улица Горького, 1, школа № 3	f	medium
34720	28396	3701	Волгоградская область, Краснослободск, Ленина, 164, школа № 4	f	large
34748	28424	3729	Волгоградская область, поселок Кировец, Ленина, 72а, Сельский клуб	f	medium
34935	28603	4335	Волгоградская область, Камышин, Южный городок, Учреждение ЯР 154/5	f	large
34916	28587	4316	Волгоградская область, Камышин, Феоктистова, 8, Школа №15	f	large
34933	28599	4333	Волгоградская область, Камышин, Титова, 11, МОУСОШ№8	f	large
34930	28599	4330	Волгоградская область, Камышин, Титова, 11, МОУСОШ№8	f	large
34904	28577	4304	Волгоградская область, Камышин, Советская, 40	f	large
34903	28576	4303	Волгоградская область, Камышин, Советская, 36	f	large
34940	28608	4340	Волгоградская область, Камышин, Серафимовича, 67, МОУСОШ№5	f	large
34902	28575	4302	Волгоградская область, Камышин, Республиканская , 25	f	large
34911	28583	4311	Волгоградская область, Камышин, Пролетарская, 6	f	large
34936	28604	4336	Волгоградская область, Камышин, Набережная, 11, МОУСОШ№4	f	large
34918	28589	4318	Волгоградская область, Камышин, Мира, 21, Школа №14	f	large
34919	28590	4319	Волгоградская область, Камышин, Ленина, 5, Камышинский ТИ	f	large
34932	28601	4332	Волгоградская область, Камышин, Кубанская, 96	f	large
34923	28593	4323	Волгоградская область, Камышин, Короленко, 24, ДЮСШ №2	f	large
34926	28595	4326	Волгоградская область, Камышин, Королева, 18, МОУСОШ№16	f	large
34925	28595	4325	Волгоградская область, Камышин, Королева, 18, МОУСОШ№16	f	large
34931	28600	4331	Волгоградская область, Камышин, Казанская улица, 35/а	f	large
34901	28574	4301	Волгоградская область, Камышин, Давыдова, 27	f	large
34939	28607	4339	Волгоградская область, Камышин, Волгоградская, 37/к, АК 1733 Камышинская	f	large
34907	28579	4307	Волгоградская область, Камышин, Воинов интернационалистов, 8	f	large
34937	28605	4337	Волгоградская область, Камышин, Буденного, 16	f	large
34934	28602	4334	Волгоградская область, Камышин, 5 микрорайон, 63а	f	large
34910	28582	4310	Волгоградская область, Камышин, 5 микрорайон, 46, Школа №7	f	large
34908	28580	4308	Волгоградская область, Камышин, 5 микрорайон, 12	f	large
34929	28598	4329	Волгоградская область, Камышин, 4 микрорайон, Политехнический колледж	f	large
34928	28597	4328	Волгоградская область, Камышин, 4 микрорайон, 22, Общежитие Политехнического колледжа	f	large
34938	28606	4338	Волгоградская область, Камышин, 333 Стрелковой дивизии, 32, ПУ№57	f	large
34914	28585	4314	Волгоградская область, Камышин, 3 микрорайон, 24, Школа №18	f	large
34913	28585	4313	Волгоградская область, Камышин, 3 микрорайон, 24, Школа №18	f	large
34906	28578	4306	Волгоградская область, Камышин, Металлургов, 9	f	large
77793	94881	1121	Тульская область, Тула, Рязанская, 40	f	large
34909	28581	4309	Волгоградская область, Камышин, 5 микрорайон, 63а, Центр детского творчества	f	large
34084	27811	1703	Волгоградская область, Иловля, здание районного Дома культуры	f	large
34045	27785	1606	Волгоградская область, Жирновск, Ломоносова, 62	f	large
33967	27708	1401	Волгоградская область, Дубовка, Северная, 15, ООО ПК Техника	f	large
33974	27715	1408	Волгоградская область, Дубовка, Московская, 1, МОУ Детская школа искусств	f	medium
33972	27713	1406	Волгоградская область, Дубовка, Московская, 13, Центр культуры и досуга	f	medium
34773	28448	3754	Волгоградская область, хутор Госпитомник, переулок Школьный, 2, Здание школы	f	medium
33711	27551	839	Волгоградская область, поселок Горьковский, Валентины Терешковой, 52, МОУ СОШ №140	f	large
33820	27603	1117	Волгоградская область, Волжский, улица имени генерала Карбышева, 40	f	large
33821	27603	1118	Волгоградская область, Волжский, улица имени генерала Карбышева, 40	f	large
33857	27619	1154	Волгоградская область, Волжский, улица Пушкина, 124а	f	large
33856	27619	1153	Волгоградская область, Волжский, улица Пушкина, 124а	f	large
33831	27608	1128	Волгоградская область, Волжский, улица Пушкина, 64	f	large
33830	27608	1127	Волгоградская область, Волжский, улица Пушкина, 64	f	large
33896	27637	1193	Волгоградская область, Волжский, улица Мира, 127б	f	large
33864	27621	1161	Волгоградская область, Волжский, улица Дружбы, 36	f	large
33863	27621	1160	Волгоградская область, Волжский, улица Дружбы, 36	f	large
33862	27621	1159	Волгоградская область, Волжский, улица Дружбы, 36	f	large
33845	27613	1142	Волгоградская область, Волжский, улица Дружбы, 9	f	large
33844	27613	1141	Волгоградская область, Волжский, улица Дружбы, 9	f	large
33846	27613	1143	Волгоградская область, Волжский, улица Дружбы, 9	f	large
33809	27595	1106	Волгоградская область, Волжский, улица 19 Партсъезда, 57	f	large
33808	27595	1105	Волгоградская область, Волжский, улица 19 Партсъезда, 57	f	large
33885	27631	1182	Волгоградская область, Волжский, имени генерала Карбышева, 144	f	large
33816	27600	1113	Волгоградская область, Волжский, имени Космонавтов, 19	f	large
33815	27600	1112	Волгоградская область, Волжский, имени Космонавтов, 19	f	large
33813	27598	1110	Волгоградская область, Волжский, имени Карла Маркса, 36	f	large
33805	27593	1102	Волгоградская область, Волжский, имени Карла Маркса, 13	f	large
33804	27593	1101	Волгоградская область, Волжский, имени Карла Маркса, 13	f	large
33803	27593	1100	Волгоградская область, Волжский, имени Карла Маркса, 13	f	large
33814	27599	1111	Волгоградская область, Волжский, имени Аркадия Гайдара, 7	f	large
33900	27640	1197	Волгоградская область, Волжский, Чапаева, 5	f	large
33848	27614	1145	Волгоградская область, Волжский, Химиков , 5	f	large
33847	27614	1144	Волгоградская область, Волжский, Химиков , 5	f	large
33825	27606	1122	Волгоградская область, Волжский, Советская улица, 26	f	large
33826	27606	1123	Волгоградская область, Волжский, Советская улица, 26	f	large
33819	27602	1116	Волгоградская область, Волжский, Советская, 6	f	large
33854	27618	1151	Волгоградская область, Волжский, Пушкина, 124	f	large
33855	27618	1152	Волгоградская область, Волжский, Пушкина, 124	f	large
33812	27597	1109	Волгоградская область, Волжский, Пушкина, 6	f	large
33811	27597	1108	Волгоградская область, Волжский, Пушкина, 6	f	large
33840	27611	1137	Волгоградская область, Волжский, Прибрежная, 91	f	large
33839	27611	1136	Волгоградская область, Волжский, Прибрежная, 91	f	large
33861	27620	1158	Волгоградская область, Волжский, Пионерская, 14	f	large
33860	27620	1157	Волгоградская область, Волжский, Пионерская, 14	f	large
33859	27620	1156	Волгоградская область, Волжский, Пионерская, 14	f	large
33858	27620	1155	Волгоградская область, Волжский, Пионерская, 14	f	large
33851	27615	1148	Волгоградская область, Волжский, Пионерская, 31	f	large
33850	27615	1147	Волгоградская область, Волжский, Пионерская, 31	f	large
33849	27615	1146	Волгоградская область, Волжский, Пионерская, 31	f	large
33843	27612	1140	Волгоградская область, Волжский, Пионерская, 1	f	large
33842	27612	1139	Волгоградская область, Волжский, Пионерская, 1	f	large
33841	27612	1138	Волгоградская область, Волжский, Пионерская, 1	f	large
33818	27601	1115	Волгоградская область, Волжский, Набережная, 12	f	large
33817	27601	1114	Волгоградская область, Волжский, Набережная, 12	f	large
33806	27594	1103	Волгоградская область, Волжский, Комсомольская, 1	f	large
33871	27625	1168	Волгоградская область, Волжский, Клавы Нечаевой, 7	f	large
33870	27625	1167	Волгоградская область, Волжский, Клавы Нечаевой, 7	f	large
33810	27596	1107	Волгоградская область, Волжский, Кирова, 20	f	large
33898	27638	1195	Волгоградская область, Волжский, Зеленый Гидростроевская, 1	f	large
33897	27638	1194	Волгоградская область, Волжский, Зеленый Гидростроевская, 1	f	large
33869	27624	1166	Волгоградская область, Волжский, Дружбы, 65	f	large
33868	27624	1165	Волгоградская область, Волжский, Дружбы, 65	f	large
33867	27624	1164	Волгоградская область, Волжский, Дружбы, 65	f	large
33866	27624	1163	Волгоградская область, Волжский, Дружбы, 65	f	large
33865	27622	1162	Волгоградская область, Волжский, Дружбы, 59	f	large
33838	27610	1135	Волгоградская область, Волжский, Академика Королева, 6	f	large
33837	27610	1134	Волгоградская область, Волжский, Академика Королева, 6	f	large
33836	27610	1133	Волгоградская область, Волжский, Академика Королева, 6	f	large
33835	27610	1132	Волгоградская область, Волжский, Академика Королева, 6	f	large
33834	27610	1131	Волгоградская область, Волжский, Академика Королева, 6	f	large
86269	27278	3	Волгоградская область, Волжский, 7 Автодорога, 6	f	small
33884	27630	1181	Волгоградская область, Волжский, 40 лет Победы, 37	f	large
33882	27630	1179	Волгоградская область, Волжский, 40 лет Победы, 37	f	large
33883	27630	1180	Волгоградская область, Волжский, 40 лет Победы, 37	f	large
33891	27635	1188	Волгоградская область, Волжский, 40 Лет Победы, 80	f	large
33894	27635	1191	Волгоградская область, Волжский, 40 Лет Победы, 80	f	large
33893	27635	1190	Волгоградская область, Волжский, 40 Лет Победы, 80	f	large
33892	27635	1189	Волгоградская область, Волжский, 40 Лет Победы, 80	f	large
33890	27634	1187	Волгоградская область, Волжский, 40 Лет Победы, 58	f	large
33889	27634	1186	Волгоградская область, Волжский, 40 Лет Победы, 58	f	large
33887	27632	1184	Волгоградская область, Волжский, 40 Лет Победы, 11	f	large
33886	27632	1183	Волгоградская область, Волжский, 40 Лет Победы, 11	f	large
33881	27628	1178	Волгоградская область, Волжский, 40 Лет Победы, 59	f	large
33880	27628	1177	Волгоградская область, Волжский, 40 Лет Победы, 59	f	large
33879	27628	1176	Волгоградская область, Волжский, 40 Лет Победы, 59	f	large
33878	27627	1175	Волгоградская область, Волжский, 40 Лет Победы, 79	f	large
33877	27627	1174	Волгоградская область, Волжский, 40 Лет Победы, 79	f	large
33876	27627	1173	Волгоградская область, Волжский, 40 Лет Победы, 79	f	large
33875	27627	1172	Волгоградская область, Волжский, 40 Лет Победы, 79	f	large
33824	27604	1121	Волгоградская область, Волжский, Пушкина, 44	f	large
33823	27604	1120	Волгоградская область, Волжский, Пушкина, 44	f	large
33822	27604	1119	Волгоградская область, Волжский, Пушкина, 44	f	large
33899	27639	1196	Волгоградская область, Волжский, Плеханова, 8	f	large
33853	27617	1150	Волгоградская область, Волжский, Наримана Нариманова, 27, Школа №6	f	large
33852	27617	1149	Волгоградская область, Волжский, Наримана Нариманова, 27, Школа №6	f	large
33874	27626	1171	Волгоградская область, Волжский, Клавы Нечаевой, 10	f	large
33873	27626	1170	Волгоградская область, Волжский, Клавы Нечаевой, 10	f	large
33872	27626	1169	Волгоградская область, Волжский, Клавы Нечаевой, 10	f	large
33888	27633	1185	Волгоградская область, Волжский, 40 Лет Победы, 48	f	large
33717	27557	845	Волгоградская область, Волгоград, контора ФГУП ОПХ Орошаемое	f	medium
33753	27503	936	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33768	27503	951	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33767	27503	950	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33766	27503	949	Волгоградская область, Волгоград, Тракторозаводский район	f	medium
33765	27503	948	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33764	27503	947	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33763	27503	946	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33762	27503	945	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33761	27503	944	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33759	27503	942	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33758	27503	941	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33757	27503	940	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33756	27503	939	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33755	27503	938	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33754	27503	937	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33751	27503	934	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33750	27503	933	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33749	27503	932	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33748	27503	931	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33747	27503	930	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33745	27503	928	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33744	27503	927	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33743	27503	926	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33742	27503	925	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33741	27503	924	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33740	27503	923	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33739	27503	922	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33738	27503	921	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33737	27503	920	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33736	27503	919	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33735	27503	918	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33734	27503	917	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33733	27503	916	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33732	27503	915	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33731	27503	914	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33730	27503	913	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33729	27503	912	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33728	27503	911	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33727	27503	910	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33726	27503	909	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33725	27503	908	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33724	27503	907	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33723	27503	906	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33722	27503	905	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33721	27503	904	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33720	27503	903	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33760	27503	943	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33719	27503	902	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33718	27503	901	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33752	27503	935	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33746	27503	929	Волгоградская область, Волгоград, Тракторозаводский район	f	large
33551	27425	535	Волгоградская область, Волгоград, х. Песчаный, о. Сарпинский, фельдшерский пункт полик.№ 5	t	small
33550	27424	534	Волгоградская область, Волгоград, школа №25	f	small
33512	27396	461	Волгоградская область, Волгоград, МОУ СОШ №73	f	large
34917	28588	4317	Волгоградская область, Камышин городской округ, улица Текстильная, 2	f	large
33655	27508	737	Волгоградская область, Волгоград, улица Таращенцев, 11	f	large
33640	27496	722	Волгоградская область, Волгоград, улица Таращенцев, 27а	f	large
33626	27487	708	Волгоградская область, Волгоград, улица Таращенцев, 51	f	large
33448	27343	330	Волгоградская область, Волгоград, улица Саши Филиппова, 96	f	large
33495	27383	444	Волгоградская область, Волгоград, улица Савкина, 8, Молодежный центр XXI век	f	large
33668	27516	750	Волгоградская область, Волгоград, улица Репина, 78	f	large
33641	27497	723	Волгоградская область, Волгоград, проспект В. И. Ленина, 121	f	large
33545	27419	529	Волгоградская область, Волгоград, улица Писемского, 30а, вечерняя школа №10	f	large
33544	27419	528	Волгоградская область, Волгоград, улица Писемского, 30а, вечерняя школа №10	f	large
33546	27420	530	Волгоградская область, Волгоград, улица Первой Пятилетки, 9, ДК и Т профобразования	f	large
33629	27489	711	Волгоградская область, Волгоград, улица Пельше, 3	f	large
33628	27489	710	Волгоградская область, Волгоград, улица Пельше, 3	f	large
34915	28586	4315	Волгоградская область, Камышин городской округ, улица Некрасова, 13, Школа №3	f	large
33693	27535	821	Волгоградская область, Волгоград, улица Крепильная, 128, ОАО Гипс	f	medium
33481	27371	430	Волгоградская область, Волгоград, улица Константина Симонова, 20/А, МОУ гимназия №11	f	large
33480	27371	429	Волгоградская область, Волгоград, улица Константина Симонова, 20/А, МОУ гимназия №11	f	large
33593	27459	642	Волгоградская область, Волгоград, улица Командира Рудь, 18, МОУ СОШ №71	f	large
33519	27402	503	Волгоградская область, Волгоград, улица Кирова, 141	f	large
33520	27402	504	Волгоградская область, Волгоград, улица Кирова, 141	f	large
33419	27319	301	Волгоградская область, Волгоград, улица КИМ, 14	f	large
33435	27332	317	Волгоградская область, Волгоград, улица Елецкая, 20	f	large
33709	27549	837	Волгоградская область, Волгоград, улица Голубятникова, 134, ДК поселка Горьковский	f	large
33636	27493	718	Волгоградская область, Волгоград, улица Генерала Штеменко, 50	f	large
33635	27493	717	Волгоградская область, Волгоград, улица Генерала Штеменко, 50	f	large
33793	27583	1025	Волгоградская область, Волгоград, улица Гагарина, 14	f	large
33660	27512	742	Волгоградская область, Волгоград, улица Вершинина, 5а	f	large
33659	27512	741	Волгоградская область, Волгоград, улица Вершинина, 5а	f	large
33675	27521	803	Волгоградская область, Волгоград, улака, 1, МОУ СОШ №93	f	large
33674	27521	802	Волгоградская область, Волгоград, улака, 1, МОУ СОШ №93	f	large
33599	27462	648	Волгоградская область, Волгоград, проспект Столетова, 16а, МОУ СОШ №125	f	large
33598	27462	647	Волгоградская область, Волгоград, проспект Столетова, 16а, МОУ СОШ №125	f	large
33597	27461	646	Волгоградская область, Волгоград, проспект Столетова, 50, МОУ СОШ №38	f	large
33596	27461	645	Волгоградская область, Волгоград, проспект Столетова, 50, МОУ СОШ №38	f	large
33473	27364	422	Волгоградская область, Волгоград, проспект Маршала Советского Союза Г. К. Жукова, 153, ЦДТ	f	large
33469	27361	418	Волгоградская область, Волгоград, проспект Маршала Советского Союза Г. К. Жукова, 83, технологический колледж	f	large
33457	27351	406	Волгоградская область, Волгоград, проспект Маршала Советского Союза Г. К. Жукова, 13	f	large
33456	27350	405	Волгоградская область, Волгоград, проспект Маршала Советского Союза Г. К. Жукова, 90, ГОУ Профессиональное училище №11	f	large
33573	27443	622	Волгоградская область, Волгоград, проспект Героев Сталинграда, 33, МОУ СОШ №120	f	large
33572	27443	621	Волгоградская область, Волгоград, проспект Героев Сталинграда, 33, МОУ СОШ №120	f	large
33571	27441	620	Волгоградская область, Волгоград, проспект Героев Сталинграда, 33, МОУ СОШ №120	f	large
33567	27439	616	Волгоградская область, Волгоград, проспект Героев Сталинграда, 43, МОУ гимназия №2	f	large
33799	27589	1031	Волгоградская область, Волгоград, проспект В. И. Ленина, 2б	f	large
33798	27588	1030	Волгоградская область, Волгоград, проспект В. И. Ленина, 4	f	large
33792	27582	1024	Волгоградская область, Волгоград, проспект В. И. Ленина, 28	f	large
33791	27581	1023	Волгоградская область, Волгоград, проспект В. И. Ленина, 31	f	large
33787	27577	1019	Волгоградская область, Волгоград, проспект В. И. Ленина, 59	f	large
33786	27576	1018	Волгоградская область, Волгоград, проспект В. И. Ленина, 51а	f	large
33785	27575	1017	Волгоградская область, Волгоград, проспект В. И. Ленина, 78	f	large
33671	27518	753	Волгоградская область, Волгоград, проспект В. И. Ленина, 69	f	large
33669	27517	751	Волгоградская область, Волгоград, проспект В. И. Ленина, 83	f	large
33670	27517	752	Волгоградская область, Волгоград, проспект В. И. Ленина, 83	f	large
33657	27510	739	Волгоградская область, Волгоград, проспект В. И. Ленина, 97	f	large
33643	27498	725	Волгоградская область, Волгоград, проспект В. И. Ленина, 133	f	large
33642	27497	724	Волгоградская область, Волгоград, проспект В. И. Ленина, 121	f	large
33627	27488	709	Волгоградская область, Волгоград, проспект В. И. Ленина, 151а	f	large
33578	27447	627	Волгоградская область, Волгоград, поселок имени XIX Партсъезда, Волжский уч-к ВЭС- филиал ФБУ	f	small
33549	27423	533	Волгоградская область, Волгоград, поселок Веселая Балка, 62а, школа № 59	f	large
33634	27492	716	Волгоградская область, Волгоград, пос. Сорок домиков, 21а	f	large
33658	27511	740	Волгоградская область, Волгоград, пос. Металлургов, 120	f	large
33797	27587	1029	Волгоградская область, Волгоград, площадь Павших Борцов, 1	f	large
33625	27486	707	Волгоградская область, Волгоград, улица Германа Титова, 1	f	large
33531	27410	515	Волгоградская область, Волгоград, переулок Школьный, 1а, проф.училище №12	f	large
33530	27410	514	Волгоградская область, Волгоград, переулок Школьный, 1а, проф.училище №12	f	large
33563	27435	612	Волгоградская область, Волгоград, переулок Обводный, 1, МОУ СОШ №62	f	large
33564	27436	613	Волгоградская область, Волгоград, переулок Обводной, 1, МОУ СОШ №62	f	large
33714	27554	842	Волгоградская область, Волгоград, переулок Лейтенанта Мостового, 7, общежитие	f	small
33548	27422	532	Волгоградская область, Волгоград, п. имени Саши Чекалина, 10, школа № 108	f	large
33547	27422	531	Волгоградская область, Волгоград, п. имени Саши Чекалина, 10, школа № 108	f	large
33516	27400	465	Волгоградская область, Волгоград, п. Аэропорт, ОАО Международный Аэропорт Волгоград	f	small
33650	27505	732	Волгоградская область, Волгоград, им. Асланова, 39	f	large
33649	27505	731	Волгоградская область, Волгоград, им. Асланова, 39	f	large
33651	27505	733	Волгоградская область, Волгоград, им. Асланова, 39	f	large
33575	27444	624	Волгоградская область, Волгоград, бульвар Энгельса, 33, МОУ гимназия №7	f	large
33574	27444	623	Волгоградская область, Волгоград, бульвар Энгельса, 33, МОУ гимназия №7	f	large
33483	27373	432	Волгоградская область, Волгоград, бульвар 30-летия Победы, 66а	f	large
33482	27372	431	Волгоградская область, Волгоград, бульвар 30-летия Победы, 66а	f	large
33475	27366	424	Волгоградская область, Волгоград, бульвар 30-летия Победы, 29а, ДЮСШ	f	large
33689	27531	817	Волгоградская область, Волгоград, Юрьевская улица, 4	f	large
33613	27476	662	Волгоградская область, Волгоград, Южный, МОУСОШ №22	f	large
33474	27365	423	Волгоградская область, Волгоград, Эльбрусская, 91, МОУ СОШ №85	f	large
33691	27533	819	Волгоградская область, Волгоград, Электролесовская улица, 5	f	large
33705	27545	833	Волгоградская область, Волгоград, Электролесовская, 86, Центр Доверие	f	large
33690	27532	818	Волгоградская область, Волгоград, Электролесовская, 4а, подростковый клуб Надежда	f	medium
33788	27578	1020	Волгоградская область, Волгоград, Школьная, 11	f	large
33508	27393	457	Волгоградская область, Волгоград, Шекснинская, 24, клуб Дзержинец	f	large
33688	27530	816	Волгоградская область, Волгоград, Чебышева, 38, МОУ СОШ №111	f	large
33687	27530	815	Волгоградская область, Волгоград, Чебышева, 38, МОУ СОШ №111	f	large
33472	27363	421	Волгоградская область, Волгоград, Хорошева, 30а, ЦСЗН	f	large
33633	27484	715	Волгоградская область, Волгоград, Хользунова, 33	f	large
33622	27484	704	Волгоградская область, Волгоград, Хользунова, 33	f	large
33621	27484	703	Волгоградская область, Волгоград, Хользунова, 33	f	large
33771	27560	1003	Волгоградская область, Волгоград, Хиросимы, 10	f	large
33770	27559	1002	Волгоградская область, Волгоград, Хиросимы, 11	f	large
33577	27446	626	Волгоградская область, Волгоград, Хабаровская, 10, МОУ СОШ №55	f	large
33450	27345	332	Волгоградская область, Волгоград, Феодосийская, 55	f	large
33692	27534	820	Волгоградская область, Волгоград, Ухтомского, 2, Детско-юношеский центр	f	large
33702	27543	830	Волгоградская область, Волгоград, Университетский проспект, 100, ГОУ ВПО ВолГУ	f	large
33700	27542	828	Волгоградская область, Волгоград, Университетский проспект, 20	f	large
33701	27542	829	Волгоградская область, Волгоград, Университетский проспект, 20	f	large
33704	27541	832	Волгоградская область, Волгоград, Университетский проспект, 88, МОУ СОШ №103	f	large
33699	27541	827	Волгоградская область, Волгоград, Университетский проспект, 88, МОУ СОШ №103	f	large
33698	27540	826	Волгоградская область, Волгоград, Университетский проспект, 64, Дворец бракосочетания	f	large
33713	27553	841	Волгоградская область, Волгоград, Волгоградская, 1, МОУ СОШ №58	f	large
33697	27539	825	Волгоградская область, Волгоград, Университетский проспект, 64, НОУ ВИЭСП	f	large
33695	27537	823	Волгоградская область, Волгоград, Университетский проспект, 71, Колледж газа и нефти	f	large
33686	27529	814	Волгоградская область, Волгоград, Университетский проспект, 26, ВГСХА	f	large
33684	27527	812	Волгоградская область, Волгоград, Университетский проспект, 26, ВГСХА	f	large
33606	27469	655	Волгоградская область, Волгоград, Удмуртская, 1а, ГОУ ПУ №6	f	large
33589	27455	638	Волгоградская область, Волгоград, Удмуртская, 18, МОУ гимназия №8	f	large
33588	27455	637	Волгоградская область, Волгоград, Удмуртская, 18, МОУ гимназия №8	f	large
33584	27452	633	Волгоградская область, Волгоград, Удмурская, 34, МОУ СОШ № 121	f	large
33583	27451	632	Волгоградская область, Волгоград, Удмурская, 34, МОУ СОШ №121	f	large
33677	27472	805	Волгоградская область, Волгоград, Туркменская, 17, МОУ МУК	f	large
33676	27472	804	Волгоградская область, Волгоград, Туркменская, 17, МОУ МУК	f	large
33525	27406	509	Волгоградская область, Волгоград, Турбинная, 182, СОШ №100	f	large
33518	27401	502	Волгоградская область, Волгоград, Турбинная, 261, Волгоградский энергетический колледж	f	large
33517	27401	501	Волгоградская область, Волгоград, Турбинная, 261, Волгоградский энергетический колледж	f	large
33673	27520	801	Волгоградская область, Волгоград, Тулака, 1, МОУ СОШ №93	f	large
33775	27564	1007	Волгоградская область, Волгоград, Ткачева, 7	f	large
33773	27562	1005	Волгоградская область, Волгоград, Ткачева, 10а	f	large
33511	27395	460	Волгоградская область, Волгоград, Строителей, 4а, МОУ СОШ №50	f	large
33510	27395	459	Волгоградская область, Волгоград, Строителей, 4а, МОУ СОШ №50	f	large
33449	27344	331	Волгоградская область, Волгоград, Ставропольская, 70	f	large
33431	27329	313	Волгоградская область, Волгоград, Социалистическая улица, 23	f	large
33430	27329	312	Волгоградская область, Волгоград, Социалистическая улица, 23	f	large
33644	27499	726	Волгоградская область, Волгоград, Созидательская улица, 27	f	large
33829	27607	1126	Волгоградская область, Волгоград, Советская улица, 39	f	large
33828	27607	1125	Волгоградская область, Волгоград, Советская улица, 39	f	large
33827	27607	1124	Волгоградская область, Волгоград, Советская улица, 39	f	large
33795	27585	1027	Волгоградская область, Волгоград, Советская улица, 24	f	large
33796	27586	1028	Волгоградская область, Волгоград, Советская, 18	f	large
33440	27336	322	Волгоградская область, Волгоград, Саши Филиппова, 1	f	large
33451	27336	333	Волгоградская область, Волгоград, Саши Филиппова, 1	f	large
33608	27471	657	Волгоградская область, Волгоград, Саушинская, 13а, ГОУ ПУ№36	f	large
33607	27470	656	Волгоградская область, Волгоград, Саушинская, 13а, ГОУ ПУ №36	f	large
33604	27467	653	Волгоградская область, Волгоград, Саушинская, 30, муниципальное общежитие	f	large
33603	27466	652	Волгоградская область, Волгоград, Саушинская, 22, МОУ СОШ №113	f	large
33433	27331	315	Волгоградская область, Волгоград, Ростовская улица, 4	f	large
33432	27330	314	Волгоградская область, Волгоград, Ростовская улица, 15а	f	large
33434	27330	316	Волгоградская область, Волгоград, Ростовская улица, 15а	f	large
33587	27454	636	Волгоградская область, Волгоград, Российская, 8, МОУ СОШ №118	f	large
33778	27567	1010	Волгоградская область, Волгоград, Рокоссовского, 40	f	large
33774	27563	1006	Волгоградская область, Волгоград, Рокоссовского, 48	f	large
33769	27558	1001	Волгоградская область, Волгоград, Рокоссовского, 60	f	large
33703	27544	831	Волгоградская область, Волгоград, Родниковая, 14, МУ ГМЦ Планета	f	large
33471	27362	420	Волгоградская область, Волгоград, Рионская улица, 14, МОУ СОШ №96	f	large
33470	27362	419	Волгоградская область, Волгоград, Рионская улица, 14, МОУ СОШ №96	f	large
33467	27359	416	Волгоградская область, Волгоград, Римского-Корсакова, 1, МОУ СОШ №36	f	large
33466	27358	415	Волгоградская область, Волгоград, Римского-Корсакова, 1, МОУ СОШ №36	f	large
33501	27387	450	Волгоградская область, Волгоград, Республиканская, 2, МОУ ЦПК	f	large
33500	27386	449	Волгоградская область, Волгоград, Республиканская, 5, МОУ СОШ № 89	f	large
33499	27386	448	Волгоградская область, Волгоград, Республиканская, 5, МОУ СОШ № 89	f	large
33498	27385	447	Волгоградская область, Волгоград, Республиканская, 18, МОУ СОШ № 101	f	large
33497	27385	446	Волгоградская область, Волгоград, Республиканская, 18, МОУ СОШ № 101	f	large
33667	27515	749	Волгоградская область, Волгоград, Репина, 11	f	large
33666	27515	748	Волгоградская область, Волгоград, Репина, 11	f	large
33665	27515	747	Волгоградская область, Волгоград, Репина, 11	f	large
33426	27326	308	Волгоградская область, Волгоград, Рабоче-Крестьянская, 38	f	large
33425	27325	307	Волгоградская область, Волгоград, Рабоче-Крестьянская, 54	f	large
33424	27324	306	Волгоградская область, Волгоград, Рабоче-Крестьянская, 41	f	large
33507	27392	456	Волгоградская область, Волгоград, Пятиизбянская, 5, МОУ СОШ № 97	f	large
33506	27392	455	Волгоградская область, Волгоград, Пятиизбянская, 5, МОУ СОШ № 97	f	large
33800	27590	1032	Волгоградская область, Волгоград, Пушкина, 7	f	large
33570	27440	619	Волгоградская область, Волгоград, Пролетарская, 9, МОУ СОШ №75	f	large
33569	27440	618	Волгоградская область, Волгоград, Пролетарская, 9, МОУ СОШ №75	f	large
33568	27440	617	Волгоградская область, Волгоград, Пролетарская, 9, МОУ СОШ №75	f	large
33802	27592	1034	Волгоградская область, Волгоград, Привокзальная площадь, 1	f	small
33630	27490	712	Волгоградская область, Волгоград, Прибалтийская улица, 1а	f	medium
33646	27501	728	Волгоградская область, Волгоград, Поддубного, 15	f	large
33777	27566	1009	Волгоградская область, Волгоград, Пархоменко, 23	f	large
33452	27346	401	Волгоградская область, Волгоград, Охотская улица, 19, МОУ ОО Школа №41	f	large
33712	27552	840	Волгоградская область, Волгоград, Ольховская, 8, МОУ СОШ №114	f	medium
33602	27465	651	Волгоградская область, Волгоград, Олимпийская, 33, МОУ СОШ №60	f	large
33459	27339	408	Волгоградская область, Волгоград, Новорядская, 124, ОАО Игрушка	f	large
33783	27573	1015	Волгоградская область, Волгоград, Новороссийская улица, 2	f	large
33781	27570	1013	Волгоградская область, Волгоград, Новороссийская, 41	f	large
33454	27348	403	Волгоградская область, Волгоград, Новодвинская, 20, ГОУ СПО Волгоградский КРСиТ	f	large
33620	27483	702	Волгоградская область, Волгоград, Никопольская, 1	f	large
33609	27473	658	Волгоградская область, Волгоград, Николаевская улица, 17, здание нач. школы МОУСОШ №117	f	large
33664	27513	746	Волгоградская область, Волгоград, Нестерова, 1а	f	large
33661	27513	743	Волгоградская область, Волгоград, Нестерова, 1а	f	large
33780	27569	1012	Волгоградская область, Волгоград, Невская, 13	f	large
33794	27584	1026	Волгоградская область, Волгоград, Мира, 17	f	large
33439	27335	321	Волгоградская область, Волгоград, Милиционера Буханцева, 21	f	large
33790	27580	1022	Волгоградская область, Волгоград, Маршала Чуйкова, 53	f	large
33639	27495	721	Волгоградская область, Волгоград, Маршала Еременко, 106	f	large
33638	27494	720	Волгоградская область, Волгоград, Маршала Еременко, 116а	f	large
33637	27494	719	Волгоградская область, Волгоград, Маршала Еременко, 116а	f	large
33623	27482	705	Волгоградская область, Волгоград, Маршала Еременко, 57	f	large
33619	27482	701	Волгоградская область, Волгоград, Маршала Еременко, 57	f	large
33682	27525	810	Волгоградская область, Волгоград, Мамина-Сибиряка, 28, МДОУ ДС №287	f	large
33555	27428	604	Волгоградская область, Волгоград, Лазоревая, 197, МОУСОШ №115	f	large
33554	27428	603	Волгоградская область, Волгоград, Лазоревая, 197, МОУСОШ №115	f	large
33496	27384	445	Волгоградская область, Волгоград, Кутузовская, 5, Педагогический колледж	f	large
33528	27408	512	Волгоградская область, Волгоград, Курчатова, 1, школа-интернат Надежда	f	large
33527	27408	511	Волгоградская область, Волгоград, Курчатова, 1, школа-интернат Надежда	f	large
33672	27519	754	Волгоградская область, Волгоград, Кубинская улица, 26	f	large
33782	27572	1014	Волгоградская область, Волгоград, Кубанская, 20	f	large
33685	27528	813	Волгоградская область, Волгоград, Криворожская улица, 2а, Дом престарелых	f	small
33696	27538	824	Волгоградская область, Волгоград, Криворожская, 1, МОУ СОШ №106	f	large
33503	27389	452	Волгоградская область, Волгоград, Краснополянская, 40а, Межшкольный учеб. комбинат	f	large
33502	27388	451	Волгоградская область, Волгоград, Краснополянская, 11, ПУ № 12	f	large
33678	27522	806	Волгоградская область, Волгоград, Красноволжская улица, 11, ГОУ ПУ №30	f	medium
33488	27377	437	Волгоградская область, Волгоград, Константина Симонова, 29, МОУСОШ №33	f	large
33489	27376	438	Волгоградская область, Волгоград, Константина Симонова, 29, МОУСОШ №33	f	large
33487	27376	436	Волгоградская область, Волгоград, Константина Симонова, 29, МОУСОШ №33	f	large
33789	27579	1021	Волгоградская область, Волгоград, Коммунистическая улица, 60	f	large
34155	27883	1835	Волгоградская область, Волгоград, Коммунистическая, 10а	f	small
33632	27491	714	Волгоградская область, Волгоград, Коммунаров, 23	f	large
33631	27491	713	Волгоградская область, Волгоград, Коммунаров, 23	f	large
33443	27338	325	Волгоградская область, Волгоград, Комитетская, 58	f	large
33442	27338	324	Волгоградская область, Волгоград, Комитетская, 58	f	large
33556	27429	605	Волгоградская область, Волгоград, Колесная, 82а, МДОШ детский сад №388	f	large
33428	27328	310	Волгоградская область, Волгоград, Козловская, 10	f	large
33429	27292	311	Волгоградская область, Волгоград, Козловская, 33	f	large
33427	27327	309	Волгоградская область, Волгоград, Ковровская улица, 4	f	large
33441	27337	323	Волгоградская область, Волгоград, Клубная, 39	f	large
33538	27415	522	Волгоградская область, Волгоград, Кирова, 94б	f	large
33537	27415	521	Волгоградская область, Волгоград, Кирова, 94б	f	large
33536	27415	520	Волгоградская область, Волгоград, Кирова, 94б	f	large
33529	27409	513	Волгоградская область, Волгоград, Кирова, 116, СОШ № 110	f	large
33521	27404	505	Волгоградская область, Волгоград, Кирова, 128а, сред.образоват. школа № 56	f	large
33522	27404	506	Волгоградская область, Волгоград, Кирова, 128а, сред.образоват. школа № 56	f	large
33612	27475	661	Волгоградская область, Волгоград, Кедроградская, 1а, ГОУ школа-интернат №11	f	medium
33455	27349	404	Волгоградская область, Волгоград, Качинцев, 63, НОУВПО Волг. институт бизнеса	f	large
33648	27504	730	Волгоградская область, Волгоград, Качалова, 42а	f	large
33645	27500	727	Волгоградская область, Волгоград, Качалова, 54	f	large
33679	27523	807	Волгоградская область, Волгоград, Казахская улица, 12, ГОУ СПО медицинский колледж	f	large
33681	27524	809	Волгоградская область, Волгоград, Казахская, 20, МОУ СОШ №54	f	large
33680	27524	808	Волгоградская область, Волгоград, Казахская, 20, МОУ СОШ №54	f	large
33420	27320	302	Волгоградская область, Волгоград, КИМ, 5	f	large
33453	27347	402	Волгоградская область, Волгоград, Иртышская, 29а, МОУ МУК	f	large
33423	27323	305	Волгоградская область, Волгоград, Иркутская, 1	f	large
33576	27445	625	Волгоградская область, Волгоград, Изобильная, 16, МОУ гимназия №6	f	large
33464	27357	413	Волгоградская область, Волгоград, Жирновская, 2, Общежитие	f	large
33445	27340	327	Волгоградская область, Волгоград, Ельшанская, 130	f	large
33444	27340	326	Волгоградская область, Волгоград, Ельшанская, 130	f	large
33438	27333	320	Волгоградская область, Волгоград, Елецкая, 9/2	f	large
33436	27333	318	Волгоградская область, Волгоград, Елецкая, 9/2	f	large
33776	27565	1008	Волгоградская область, Волгоград, Двинская, 3	f	large
33694	27536	822	Волгоградская область, Волгоград, Даугавская , 1, Комплекс культуры и отдыха	f	large
33535	27414	519	Волгоградская область, Волгоград, Губкина, 2, СОШ № 57	f	large
33565	27437	614	Волгоградская область, Волгоград, Гражданская улица, 9, МОУ ООШ №24	f	large
33562	27434	611	Волгоградская область, Волгоград, Гражданская улица, 64, МОУ ДО ДШИ №2	f	large
33561	27433	610	Волгоградская область, Волгоград, Героев Малой Земли, 34, ПУ №19	f	large
33560	27432	609	Волгоградская область, Волгоград, Героев Малой Земли, 53, (МОУСОШ №64)	f	large
33559	27432	608	Волгоградская область, Волгоград, Героев Малой Земли, 53, (МОУСОШ №64)	f	large
33552	27426	601	Волгоградская область, Волгоград, Георгиевская улица, 2, МОУСОШ №119	f	large
33553	27427	602	Волгоградская область, Волгоград, Георгиевская, 4, МОУООШ №119	f	large
33654	27507	736	Волгоградская область, Волгоград, Генерала Штеменко, 23	f	large
33505	27391	454	Волгоградская область, Волгоград, Гейне, 7, МОУ СОШ № 128	f	large
33504	27390	453	Волгоградская область, Волгоград, Гейне, 7, МОУ СОШ № 128	f	large
33586	27453	635	Волгоградская область, Волгоград, Вучетича, 17, МОУ СОШ №134 Дарование	f	large
33585	27453	634	Волгоградская область, Волгоград, Вучетича, 17, МОУ СОШ №134 Дарование	f	large
33582	27450	631	Волгоградская область, Волгоград, Вучетича, 30, МОУ СОШ №124	f	large
33710	27550	838	Волгоградская область, Волгоград, Волгоградская улица, 134	f	large
33708	27548	836	Волгоградская область, Волгоград, Волгоградская, 2, МОУ СОШ №15	f	large
33707	27547	835	Волгоградская область, Волгоград, Волгоградская, 156, МОУ СОШ №8	f	large
33801	27591	1033	Волгоградская область, Волгоград, В. И. Ленина, 21	f	large
33566	27438	615	Волгоградская область, Волгоград, Бульвар Энгельса, 30, МОУ СОШ №65	f	large
33595	27460	644	Волгоградская область, Волгоград, Брестская, 15, МОУ лицей №1	f	large
33594	27460	643	Волгоградская область, Волгоград, Брестская, 15, МОУ лицей №1	f	large
33460	27353	409	Волгоградская область, Волгоград, Большая, 17, ГОУ школа-интернат Созвездие	f	large
33656	27509	738	Волгоградская область, Волгоград, Богунская улица, 3	f	large
33653	27506	735	Волгоградская область, Волгоград, Богунская, 18	f	large
33652	27506	734	Волгоградская область, Волгоград, Богунская, 18	f	large
33647	27502	729	Волгоградская область, Волгоград, Богунская, 38	f	large
33591	27457	640	Волгоградская область, Волгоград, Бахтурова, 6, ПУ №33	f	large
33590	27456	639	Волгоградская область, Волгоград, Бахтурова, 25г, Волгоградский филиал МФЮА	f	large
33422	27322	304	Волгоградская область, Волгоград, Баррикадная, 2	f	large
33462	27355	411	Волгоградская область, Волгоград, Ангарская улица, 15	f	large
33465	27356	414	Волгоградская область, Волгоград, Ангарская, 49, МОУ СОШ №82	f	large
33463	27356	412	Волгоградская область, Волгоград, Ангарская, 49, МОУ СОШ №82	f	large
33461	27354	410	Волгоградская область, Волгоград, Ангарская, 15, МОУ СОШ №67	f	large
33542	27417	526	Волгоградская область, Волгоград, Алычевая, 1а, СОШ №112	f	large
33541	27417	525	Волгоградская область, Волгоград, Алычевая, 1а, СОШ №112	f	large
33683	27526	811	Волгоградская область, Волгоград, Алишера Навои, 2, МОУ СОШ №46	f	large
33557	27430	606	Волгоградская область, Волгоград, Алданская, 10, МОУООШ №63	f	large
33421	27321	303	Волгоградская область, Волгоград, Академическая, 1	f	large
33446	27341	328	Волгоградская область, Волгоград, Автотранспортная, 29а	f	large
33540	27416	524	Волгоградская область, Волгоград, Абганеровская, 107, школа № 122	f	large
33539	27416	523	Волгоградская область, Волгоград, Абганеровская, 107, школа № 122	f	large
33478	27369	427	Волгоградская область, Волгоград, 8-й Воздушной Армии улица, 27а, МОУ лицей №8 Олимпия	f	large
33477	27368	426	Волгоградская область, Волгоград, 8-й Воздушной Армии улица, 27/А, МОУ лицей №8 Олимпия	f	large
33490	27378	439	Волгоградская область, Волгоград, 8-й Воздушной Армии, 50, МОУ детский сад № 4	f	large
33486	27375	435	Волгоградская область, Волгоград, 8-й Воздушной Армии, 26а, МОУ Лицей №9	f	large
33485	27374	434	Волгоградская область, Волгоград, 8-й Воздушной Армии, 26а, МОУ лицей №9	f	large
33484	27374	433	Волгоградская область, Волгоград, 8-й Воздушной Армии, 26а, МОУ лицей №9	f	large
33479	27370	428	Волгоградская область, Волгоград, 8-й Воздушной Армии, 35, Библиотека №24 им.В.М.Шукшина	f	large
33476	27367	425	Волгоградская область, Волгоград, 8-й Воздушной Армии, 27а	f	large
33534	27413	518	Волгоградская область, Волгоград, 64-й Армии улица, 73а, Центр детского творчества	f	large
33523	27405	507	Волгоградская область, Волгоград, 64-й Армии улица, 117, проф.училище №26	f	large
33524	27405	508	Волгоградская область, Волгоград, 64-й Армии улица, 117, проф.училище №26	f	large
33533	27412	517	Волгоградская область, Волгоград, 64-й Армии, 63, гимназия № 10	f	large
33532	27411	516	Волгоградская область, Волгоград, 64-й Армии, 63, гимназия №10	f	large
33494	27382	443	Волгоградская область, Волгоград, 51-й Гвардейской Дивизии, 38б, общежитие ЖКХ	f	large
33493	27381	442	Волгоградская область, Волгоград, 51-й Гвардейской Дивизии, 59, МОУ лицей № 7	f	large
33492	27381	441	Волгоградская область, Волгоград, 51-й Гвардейской Дивизии, 59, МОУ лицей № 7	f	large
33491	27380	440	Волгоградская область, Волгоград, 51-й Гвардейской Дивизии, 48, МОУ СОШ №40	f	large
33580	27449	629	Волгоградская область, Волгоград, 50 Лет Октября, 23, МОУ лицей №4	f	large
33581	27449	630	Волгоградская область, Волгоград, 50 Лет Октября, 23, МОУ лицей №4	f	large
33610	27474	659	Волгоградская область, Волгоград, 2-я Штурманская, 2, МОУ СОШ №117	f	large
33611	27474	660	Волгоградская область, Волгоград, 2-я Штурманская, 2, МОУ СОШ №117	f	large
33605	27468	654	Волгоградская область, Волгоград, 2-я Динамовская, 11, ПУ №31	f	large
77657	4241	967	Тульская область, Тула, Рогова, 30	f	large
33468	27360	417	Волгоградская область, Волгоград, Хорошева, 18а, ГОУ ВСКО школа-интернат№2	f	large
33779	27568	1011	Волгоградская область, Волгоград, Рокоссовского, 40г	f	large
33458	27352	407	Волгоградская область, Волгоград, Рокоссовского, 41, ФГУ Управление мелиорации	f	large
33663	27514	745	Волгоградская область, Волгоград, улица Репина, 19	f	large
33662	27514	744	Волгоградская область, Волгоград, улица Репина, 19	f	large
33543	27418	527	Волгоградская область, Волгоград, Писемского, 38, гимгазия № 9	f	large
33624	27485	706	Волгоградская область, Волгоград, Пельше, 15б	f	large
33772	27561	1004	Волгоградская область, Волгоград, Пархоменко, 47а	f	large
33437	27334	319	Волгоградская область, Волгоград, Липецкая, 3	f	large
33526	27407	510	Волгоградская область, Волгоград, Кирова, 121, УПК	f	large
33509	27394	458	Волгоградская область, Волгоград, Землячки, 27б, ЗАО ВМС- Ремонт	f	large
33447	27342	329	Волгоградская область, Волгоград, Елецкая, 142	f	large
33558	27431	607	Волгоградская область, Волгоград, Арсеньева, 32, МОУСОШ №9	f	large
33706	27546	834	Волгоградская область, Волгоград, Академика Королева, 1а, МОУ СОШ №52	f	large
33601	27464	650	Волгоградская область, Волгоград, 40 Лет ВЛКСМ, 31, ДК Царицын	f	large
33600	27463	649	Волгоградская область, Волгоград, 40 Лет ВЛКСМ, 31, ООО ДК Царицын	f	large
33592	27458	641	Волгоградская область, Волгоград, 40 Лет ВЛКСМ, 66, МУП Метроэлектротранс	f	large
34772	28447	3753	Волгоградская область, хутор Бурковский, Школьная, 6, Здание школы	f	medium
34881	28554	4206	Волгоградская область, Чернышковский район, село Ярской, помещение Ярского сельс.клуба	f	small
34879	28552	4204	Волгоградская область, Чернышковский район, поселок Чернышковский, Цимлянская, 64	f	large
34876	28549	4201	Волгоградская область, Чернышковский район, поселок Чернышковский, Советская, 31	f	large
34877	28550	4202	Волгоградская область, Чернышковский район, поселок Чернышковский, Ленина, 56	f	medium
34878	28551	4203	Волгоградская область, Чернышковский район, поселок Чернышковский, 2-я Гвардейская, 16	f	medium
34894	28567	4219	Волгоградская область, Чернышковский район, село Фирсовка, помещение Фирсовского сельск.клуба	f	small
34895	28568	4220	Волгоградская область, Чернышковский район, село Тормосин, Октябрьская, 25	f	large
34891	28564	4216	Волгоградская область, Чернышковский район, село Сизов, Советская, 22	f	medium
34436	28133	2716	Волгоградская область, Чернышковский район, село Раздольный, Гагарина, 28а	f	large
34899	28572	4224	Волгоградская область, Чернышковский район, село Пристеновский, помещ. администрации сел.поселения	f	small
34898	28571	4223	Волгоградская область, Чернышковский район, село Попов, помещение МОУ СОШ	f	small
34880	28553	4205	Волгоградская область, Чернышковский район, село Нижняя Вербовка, помещение Вербовского сельс. клуба	f	small
34892	28565	4217	Волгоградская область, Чернышковский район, хутор Нижнегнутов, Ленина, 23	f	medium
34896	28569	4221	Волгоградская область, Чернышковский район, село Морской, помещение Морсковского сельск.клуба	f	small
34893	28566	4218	Волгоградская область, Чернышковский район, село Лозной, помещение Лозновского сельского клуба	f	small
34885	28558	4210	Волгоградская область, Чернышковский район, село Красный, помещение Красновского МОУ	f	small
34884	28557	4209	Волгоградская область, Чернышковский район, село Красноярский, Советская, 14	f	medium
34897	28570	4222	Волгоградская область, Чернышковский район, село Захаров, помещение МОУ СОШ	f	small
34887	28560	4212	Волгоградская область, Чернышковский район, село Елкино, Школьная, 6	f	small
34882	28555	4207	Волгоградская область, Чернышковский район, село Волоцкий, помещение Дома культуры	f	small
34900	28573	4225	Волгоградская область, Чернышковский район, село Водяновский, помещение МОУ СОШ	f	small
34889	28562	4214	Волгоградская область, Чернышковский район, село Верхнегнутов, Октябрьская, 15	f	medium
34883	28556	4208	Волгоградская область, Чернышковский район, село Большетерновой, Горбункова, 3	f	medium
34886	28559	4211	Волгоградская область, Чернышковский район, село Богомазовка, помещение Богомазовского МОУ	f	small
34890	28563	4215	Волгоградская область, Чернышковский район, село Басакин, пл. Центральная, 5	f	large
83911	57336	3104	Москва, Зеленоград, к314	f	large
34888	28561	4213	Волгоградская область, Чернышковский район, село Алешкин, Октябрьская, 25	f	small
34868	28541	4114	Волгоградская область, Фроловский район, село Шуруповский, здание школы	f	large
34862	28535	4108	Волгоградская область, Фроловский район, село Шляховский, здание клуба	f	small
34858	28531	4104	Волгоградская область, Фроловский район, поселок Школьный, здание клуба	f	small
35005	28673	4604	Волгоградская область, Фроловский район, Фролово, 40 Лет Октября, 7	f	large
34871	28544	4117	Волгоградская область, Фроловский район, село Рубежный, здание клуба	f	small
34865	28538	4111	Волгоградская область, Фроловский район, село Пригородный, здание Зеленовской средней школы	f	large
34864	28537	4110	Волгоградская область, Фроловский район, село Писаревка, Здание Дома культуры	f	medium
34258	27983	2123	Волгоградская область, Фроловский район, село Перелазовский, Центральная, 22	f	medium
34869	28542	4115	Волгоградская область, Фроловский район, село Образцы, здание Дома культуры	f	medium
34859	28532	4105	Волгоградская область, Фроловский район, село Новая Паника, здание начальной школы	f	small
34870	28543	4116	Волгоградская область, Фроловский район, село Манский, здание школы	f	small
34875	28548	4121	Волгоградская область, Фроловский район, село Малодельская, здание кафетерия	f	large
34863	28536	4109	Волгоградская область, Фроловский район, село Лычак, здание Дома культуры	f	medium
34857	28530	4103	Волгоградская область, Фроловский район, село Лесхоз Арчединский, здание школы	f	small
34861	28534	4107	Волгоградская область, Фроловский район, село Красные Липки, здание Дома культуры	f	medium
34232	27958	2018	Волгоградская область, Фроловский район, село Калиновский, Калиновский переулок, здание сельского Дома культуры	f	medium
34874	28547	4120	Волгоградская область, Фроловский район, село Дудаченский, здание администрации сельского посе	f	small
34856	28529	4102	Волгоградская область, Фроловский район, село Гуляевка, Дом культуры	f	small
34855	28486	4101	Волгоградская область, Фроловский район, село Ветютнев, средняя школа	f	medium
34860	28533	4106	Волгоградская область, Фроловский район, село Верхние Липки, здание Дома культуры	f	medium
34873	28546	4119	Волгоградская область, Фроловский район, село Большой Лычак, здание клуба	f	medium
34872	28545	4118	Волгоградская область, Фроловский район, село Арчедино-Чернушинский, здание Дома культуры	f	small
34867	28540	4113	Волгоградская область, Фроловский район, село Амелино, здание Дома культуры	f	medium
35003	28671	4602	Волгоградская область, Фролово городской округ, Фролово, 40 Лет Октября, 132	f	large
34968	28636	4502	Волгоградская область, Урюпинский район, село Тепикинская	f	small
34999	28667	4533	Волгоградская область, Урюпинский район, село Салтынский	f	small
34995	28663	4529	Волгоградская область, Урюпинский район, село Россошинский	f	medium
34981	28649	4515	Волгоградская область, Урюпинский район, село Провоторовский	f	small
34993	28661	4527	Волгоградская область, Урюпинский район, село Попов, Школьная, 37	f	medium
34994	28662	4528	Волгоградская область, Урюпинский район, село Петровский, Ленина, 56	f	large
34997	28665	4531	Волгоградская область, Урюпинский район, село Первомайский	f	medium
34992	28660	4526	Волгоградская область, Урюпинский район, село Ольшанка, Комарова, 45	f	large
34980	28648	4514	Волгоградская область, Урюпинский район, село Ольховский	f	small
34990	28658	4524	Волгоградская область, Урюпинский район, село Окладненский	f	small
35000	28668	4534	Волгоградская область, Урюпинский район, село Моховской	f	small
34989	28657	4523	Волгоградская область, Урюпинский район, село Михайловская, Октябрьская, 15	f	large
34988	28656	4522	Волгоградская область, Урюпинский район, село Лощиновский	f	small
35001	28669	4535	Волгоградская область, Урюпинский район, село Криушинский	f	medium
34987	28655	4521	Волгоградская область, Урюпинский район, село Креповский, Центральная	f	medium
34986	28654	4520	Волгоградская область, Урюпинский район, село Красный	f	medium
34985	28653	4519	Волгоградская область, Урюпинский район, село Котовский	f	medium
34692	28368	3611	Волгоградская область, Урюпинский район, село Котовский, Котовский ФАП	f	small
77696	4276	1019	Тульская область, Тула, Рихарда Зорге, 29	f	large
34984	28652	4518	Волгоградская область, Урюпинский район, село Искра	f	medium
34983	28651	4517	Волгоградская область, Урюпинский район, село Забурдяевский	f	small
34982	28650	4516	Волгоградская область, Урюпинский район, село Дьяконовский 2-й, Юбилейная, 4	f	medium
34979	28647	4513	Волгоградская область, Урюпинский район, село Дубовский	f	medium
34991	28659	4525	Волгоградская область, Урюпинский район, село Долгий	f	small
34977	28645	4511	Волгоградская область, Урюпинский район, село Добринка, Красноармейская	f	large
34978	28646	4512	Волгоградская область, Урюпинский район, село Горский	f	small
34976	28644	4510	Волгоградская область, Урюпинский район, село Вишняковский	f	small
34975	28643	4509	Волгоградская область, Урюпинский район, село Вихлянцевский	f	small
34974	28642	4508	Волгоградская область, Урюпинский район, село Верхнесоинский	f	small
34973	28641	4507	Волгоградская область, Урюпинский район, Верхнебезымянский	f	medium
34996	28664	4530	Волгоградская область, Урюпинский район, село Булековский	f	small
34998	28666	4532	Волгоградская область, Урюпинский район, хутор Бугровский	f	small
34972	28640	4506	Волгоградская область, Урюпинский район, село Бубновский	f	large
34971	28639	4505	Волгоградская область, Урюпинский район, село Большинский	f	medium
34970	28638	4504	Волгоградская область, Урюпинский район, село Бесплемяновский	f	small
34969	28637	4503	Волгоградская область, Урюпинский район, село Беспаловский	f	small
34967	28635	4501	Волгоградская область, Урюпинский район, село Акчернский	f	medium
34824	28499	3924	Волгоградская область, Суровикинский район, село Чувилевский, МОУ Чувилевская НОШ	f	small
34832	28507	3932	Волгоградская область, Суровикинский район, село Сысоевский, МУК Искра	f	medium
34817	28492	3917	Волгоградская область, Суровикинский район, село Сухановский, МОУ Сухановская НОШ	f	small
34808	28482	3908	Волгоградская область, Суровикинский район, Суровикино, Шоссейная, 69	f	large
34805	28479	3905	Волгоградская область, Суровикинский район, Суровикино, Шоссейная, 1	f	large
34802	28476	3902	Волгоградская область, Суровикинский район, Суровикино, Советская, 144А	f	large
34804	28478	3904	Волгоградская область, Суровикинский район, Суровикино, Ленина, 4	f	large
34803	28477	3903	Волгоградская область, Суровикинский район, Суровикино, Ленина, 78	f	large
34801	28475	3901	Волгоградская область, Суровикинский район, Суровикино, Ленина, 296А	f	large
34806	28480	3906	Волгоградская область, Суровикинский район, Суровикино, Звездина, 20	f	large
34829	28504	3929	Волгоградская область, Суровикинский район, село Суворовская, МОУ Суворовская ООШ	f	small
34834	28509	3934	Волгоградская область, Суровикинский район, село Синяпкинский, МУК Искра	f	small
34812	28487	3912	Волгоградская область, Суровикинский район, село Пещеровский, ТОС Пещеровское	f	small
34830	28505	3930	Волгоградская область, Суровикинский район, село Новомаксимовский, МУК Ритм	f	medium
34833	28508	3933	Волгоградская область, Суровикинский район, село Новодербеновский, МУК Искра	f	small
34827	28502	3927	Волгоградская область, Суровикинский район, Нижний Чир, МОУ Нижнечирская ООШ	f	medium
34826	28501	3926	Волгоградская область, Суровикинский район, Нижний Чир, ГОУ Профессиональное училище № 46	f	small
34825	28500	3925	Волгоградская область, Суровикинский район, Нижний Чир, МУК Дом культуры Нижнечирского сельского поселения	f	large
34822	28497	3922	Волгоградская область, Суровикинский район, село Нижнеосиновский, МОУ Нижнеосиновская НОШ	f	medium
34816	28491	3916	Волгоградская область, Суровикинский район, село Майоровский, МОУ Майоровская СОШ	f	small
34820	28495	3920	Волгоградская область, Суровикинский район, село Лысов, МУК Виктория	f	small
34818	28493	3918	Волгоградская область, Суровикинский район, село Лобакин, МУК Дружба	f	medium
34122	27850	1802	Волгоградская область, Суровикинский район, село Кумовка, Центральная, 15, Кумовская НОШ	f	small
34819	28494	3919	Волгоградская область, Суровикинский район, село Киселев, МОУ Киселевская НОШ	f	small
34815	28490	3915	Волгоградская область, Суровикинский район, село Качалин, МОУ Качалинская СОШ	f	medium
34810	28484	3910	Волгоградская область, Суровикинский район, село Жирковский, МОУ Жирковская начальная общеобразовательная школа	f	small
34240	27966	2105	Волгоградская область, Суровикинский район, село Жирковский, Раздольная, 39	f	small
34814	28489	3914	Волгоградская область, Суровикинский район, село Добринка, МУК Добринское	f	medium
34831	28506	3931	Волгоградская область, Суровикинский район, село Верхнечирский, МОУ Новомаксимовская СОШ	f	medium
34811	28485	3911	Волгоградская область, Суровикинский район, село Верхнесолоновский, МОУ Верхнесолоновская СОШ	f	medium
34823	28498	3923	Волгоградская область, Суровикинский район, село Верхнеосиновский, МОУ Ворхнеосиновская НОШ	f	small
34813	28488	3913	Волгоградская область, Суровикинский район, село Верхнеаксеновский, МОУ Верхнеаксеновская НОШ	f	small
34821	28496	3921	Волгоградская область, Суровикинский район, село Бурацкий, МУК Виктория	f	medium
34809	28483	3909	Волгоградская область, Суровикинский район, село Ближнеосиновский, МУК Надежда	f	medium
34828	28503	3928	Волгоградская область, Суровикинский район, село Ближнемельничный, МОУ Ближнемельничная ООШ	f	small
34800	28474	3825	Волгоградская область, Старополтавский район, село Черобаево, Здание культурно-досугового объединения	f	small
34781	28456	3806	Волгоградская область, Старополтавский район, село Цветочное, Здание сельского клуба	f	small
34799	28473	3824	Волгоградская область, Старополтавский район, село Харьковка, Здание культурно-досугового объединения	f	medium
34798	28471	3823	Волгоградская область, Старополтавский район, село Торгун, Здание культурно-досугового объединения	f	medium
34797	28470	3822	Волгоградская область, Старополтавский район, Старая Полтавка, Здание культурно-досугового объединения	f	large
34796	28470	3821	Волгоградская область, Старополтавский район, Старая Полтавка, Здание культурно-досугового объединения	f	large
34795	28469	3820	Волгоградская область, Старополтавский район, село Салтово, Здание культурно-досугового объединения	f	medium
34794	28468	3819	Волгоградская область, Старополтавский район, село Новый Тихонов, Здание культурно-досугового объединения	f	small
34791	28465	3816	Волгоградская область, Старополтавский район, село Новая Полтавка, Здание культурно-досугового объединения	f	medium
34793	28467	3818	Волгоградская область, Старополтавский район, село Новая Квасниковка, Здание культурно-досугового объединения	f	small
34790	28464	3815	Волгоградская область, Старополтавский район, село Лятошинка, Здание культурно-досугового объединения	f	small
34789	28463	3814	Волгоградская область, Старополтавский район, село Курнаевка, Здание культурно-досугового объединения	f	medium
34787	28461	3812	Волгоградская область, Старополтавский район, село Колышкино, Здание школы	f	small
34785	28459	3810	Волгоградская область, Старополтавский район, село Кано, Здание культурно-досугового объединения	f	small
34792	28466	3817	Волгоградская область, Старополтавский район, село Калинино, здание школы	f	small
34783	28457	3808	Волгоградская область, Старополтавский район, село Иловатка, Здание культурно-досугового объединения	f	large
34780	28455	3805	Волгоградская область, Старополтавский район, село Гмелинка, Здание центра досуга	f	medium
34779	28454	3804	Волгоградская область, Старополтавский район, село Гмелинка, Здание администрациии с/п	f	medium
34778	28453	3803	Волгоградская область, Старополтавский район, село Верхняя Водянка, Здание культурно-досугового объединения	f	medium
34786	28460	3811	Волгоградская область, Старополтавский район, село Верхний Еруслан, Здание школы	f	small
34782	14666	3807	Волгоградская область, Старополтавский район, село Вербный, Здание школы	f	small
34777	28452	3802	Волгоградская область, Старополтавский район, село Валуевка, Здание школы	f	medium
34776	28451	3801	Волгоградская область, Старополтавский район, село Беляевка, Здание школы	f	small
34784	28458	3809	Волгоградская область, Старополтавский район, село Белокаменка, Здание школы	f	small
34751	28427	3732	Волгоградская область, Среднеахтубинский район, село Ямы, Базовский переулок, 4, Здание школы	f	small
34770	28445	3751	Волгоградская область, Среднеахтубинский район, село Чапаевец, Придорожная, 31/2, Помещение ТОС	f	small
34752	28428	3733	Волгоградская область, Среднеахтубинский район, село Тумак, Центральная, 32/4, Здание школы	f	small
34769	28444	3750	Волгоградская область, Среднеахтубинский район, село Суходол, Советская, 9, Здание СДК	f	medium
34768	28443	3749	Волгоградская область, Среднеахтубинский район, село Суходол, Молодежная, 12, Здание школы	f	small
34759	28435	3740	Волгоградская область, Среднеахтубинский район, село Стандартный, Совхозная, 11, начальная школа	f	small
34731	28407	3712	Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба, микрорайон, 74, школа № 1	f	large
34730	28406	3711	Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба, микрорайон, 70, ПУ-50	f	large
34737	28413	3718	Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба, Садовая, 22, школа № 3 им Горького	f	large
34732	28408	3713	Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба, Партизанская, 47, школа № 2 им. Ломоносова	f	large
34735	28411	3716	Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба, Гагарина, 114, ДС Дельфиненок	f	medium
34738	28414	3719	Волгоградская область, Среднеахтубинский район, поселок Средняя Ахтуба, Воровкого, 12, школа-интернат	f	large
34755	28431	3736	Волгоградская область, Среднеахтубинский район, село Репино, Новостройка, 21, Школа-сад	f	small
34767	28442	3748	Волгоградская область, Среднеахтубинский район, село Рахинка, Советская, 35а, Здание дома культуры	f	large
34131	27859	1811	Волгоградская область, Среднеахтубинский район, село Приканальный, Приканальная, 33, ФАП	f	small
34754	28430	3735	Волгоградская область, Среднеахтубинский район, село Пламенка, Новая, 1, Здание школы	f	medium
34728	28404	3709	Волгоградская область, Среднеахтубинский район, поселок Песчанка, Солнечная, 22а, Начальная школа	f	small
34762	28438	3743	Волгоградская область, Среднеахтубинский район, село Максима Горького, Школьная, 7, Здание школы	f	small
34764	28439	3745	Волгоградская область, Среднеахтубинский район, село Куйбышев, Турусова, 26а, школа	f	medium
34763	14613	3744	Волгоградская область, Среднеахтубинский район, село Куйбышев, Турусова, 26а, средняя школа	f	large
34756	28432	3737	Волгоградская область, Среднеахтубинский район, село Красный Сад, Школьная, 23, Здание школы	f	medium
34761	28437	3742	Волгоградская область, Среднеахтубинский район, село Красный Октябрь, Рыжовой, 44, Здание дома культуры	f	small
34760	28436	3741	Волгоградская область, Среднеахтубинский район, село Красный Октябрь, Рыжовой, 44, Здание ДК	f	medium
34723	28399	3704	Волгоградская область, Среднеахтубинский район, Краснослободск, Шестакова, 29, ЦД и развлечений Остров	f	large
34725	28401	3706	Волгоградская область, Среднеахтубинский район, Краснослободск, Тимирязева, 65, Центр детского творчества	f	large
34726	28402	3707	Волгоградская область, Среднеахтубинский район, Краснослободск, Свердлова, 51, Здание Опытной станции ВИР	f	large
34721	28397	3702	Волгоградская область, Среднеахтубинский район, Краснослободск, Ленина, 164, МОУ Краснослободская школа№4	f	large
34724	28400	3705	Волгоградская область, Среднеахтубинский район, Краснослободск, В. И. Ленина, 1, гимназия	f	large
34766	28441	3747	Волгоградская область, Среднеахтубинский район, село Кочетково, улица Центральная, 27/5, Здание клуба	f	small
34740	28416	3721	Волгоградская область, Среднеахтубинский район, село Колхозная Ахтуба, Центральная, 35а, начальная школа	f	medium
34739	28415	3720	Волгоградская область, Среднеахтубинский район, село Колхозная Ахтуба, Веселая, 31, сельский дом культуры	f	small
34753	28429	3734	Волгоградская область, Среднеахтубинский район, село Клетский, Советская, 21, дом культуры	f	large
34741	28417	3722	Волгоградская область, Среднеахтубинский район, село Киляковка, Тракторозаводская, 1, ТОС Киляковка	f	small
34757	28433	3738	Волгоградская область, Среднеахтубинский район, село Калинина, Калинина, 34б, Здание клуб	f	small
34745	28421	3726	Волгоградская область, Среднеахтубинский район, село Звездный, Школьная, 1, Здание школы	f	small
34771	28446	3752	Волгоградская область, Среднеахтубинский район, село Закутский, Ленина, 2в, Здание СКДЦ Стимул	f	large
34729	28405	3710	Волгоградская область, Среднеахтубинский район, село Вторая Пятилетка, Молодежная, 21, библиотека	f	small
34466	28164	2825	Волгоградская область, Новоаннинский район, село Мартыновский	f	small
34744	28420	3725	Волгоградская область, Среднеахтубинский район, село Верхнепогромное, Центральная, 32, дом культуры	f	medium
34743	28419	3724	Волгоградская область, Среднеахтубинский район, село Верхнепогромное, Центральная, 32, дом культуры	f	medium
34765	28440	3746	Волгоградская область, Среднеахтубинский район, село Великий Октябрь, Школьная, 24, Здание школы	f	medium
34691	28367	3610	Волгоградская область, Серафимовичский район, село Чеботаревский, Чеботаревский ФАП	f	small
34695	28371	3614	Волгоградская область, Серафимовичский район, село Хохлачев	f	small
34684	28360	3603	Волгоградская область, Серафимовичский район, село Хованский, Хованский ФАП	f	small
34700	28376	3619	Волгоградская область, Серафимовичский район, село Фомихинский, Фомихинский ФАП	f	small
34685	28361	3604	Волгоградская область, Серафимовичский район, село Усть-Хоперская, дом культуры	f	medium
34689	28365	3608	Волгоградская область, Серафимовичский район, село Тюковной, Тюковновский дом культуры	f	small
34708	28384	3627	Волгоградская область, Серафимовичский район, село Трясиновский, Трясиновский дом культуры	f	medium
34710	28386	3629	Волгоградская область, Серафимовичский район, село Теркин, зд.адм.Теркинского с/п	f	medium
34699	28375	3618	Волгоградская область, Серафимовичский район, село Среднецарицынский, зд.адм.Среднецарицынского с/п	f	medium
34716	28392	3635	Волгоградская область, Серафимовичский район, Серафимович, Подтелкова, 63, техникум (СТМСХ)	f	large
34717	28393	3636	Волгоградская область, Серафимовичский район, Серафимович, Октябрьская, 47, центральная библиотека	f	large
34719	28395	3638	Волгоградская область, Серафимовичский район, Серафимович, 68-Гвардейская, 105, ДРСУ	f	large
34694	28370	3613	Волгоградская область, Серафимовичский район, село Пронин, Пронинский дом культуры	f	medium
34705	28381	3624	Волгоградская область, Серафимовичский район, село Подольховский, Подольховский ФАП	f	small
34715	28391	3634	Волгоградская область, Серафимовичский район, село Отрожки, здание администрации	f	small
34711	28387	3630	Волгоградская область, Серафимовичский район, село Орлиновский, Орлиновский медпункт	f	small
34698	28374	3617	Волгоградская область, Серафимовичский район, село Новопавловский, адм.здание ТОСа Новопавловский	f	small
34704	28380	3623	Волгоградская область, Серафимовичский район, село Новоалександровский, Новоалександровский ФАП	f	small
34707	28383	3626	Волгоградская область, Серафимовичский район, село Мостовский, Мостовское ОПС	f	small
34688	28364	3607	Волгоградская область, Серафимовичский район, село Крутовский, Крутовский дом культуры	f	small
34714	28390	3633	Волгоградская область, Серафимовичский район, село Козиновский, зда. бывшей администрации с/с	f	small
34712	28388	3631	Волгоградская область, Серафимовичский район, село Клетско-Почтовский, Клетско-Почтовский дом культуры	f	medium
34247	27973	2112	Волгоградская область, Серафимовичский район, село Калмыковский, Центральная, 10	f	medium
34706	28382	3625	Волгоградская область, Серафимовичский район, село Зимняцкий, Зимняцкий дом культуры	f	large
34682	28358	3601	Волгоградская область, Серафимовичский район, Затонский, Затонский ФАП	f	small
34713	28389	3632	Волгоградская область, Серафимовичский район, село Ендовский, Ендовский сельский клуб	f	small
34693	28369	3612	Волгоградская область, Серафимовичский район, хутор Горбатовский, Горбатовский дом культуры	f	small
34683	28359	3602	Волгоградская область, Серафимовичский район, село Буерак-Поповский, Буерак-Поповский дом культуры	f	small
34365	28063	2508	Волгоградская область, Серафимовичский район, село Большой, Ленина, 25, Большовский сельский ДК	f	large
34702	28378	3621	Волгоградская область, Серафимовичский район, село Бобровский 2-й, Бобровский-2 дом культуры	f	small
34686	28362	3605	Волгоградская область, Серафимовичский район, село Бобровский 1-й, Бобровский-1й дом культуры	f	small
34696	28372	3615	Волгоградская область, Серафимовичский район, село Блиновский	f	small
34703	28379	3622	Волгоградская область, Серафимовичский район, село Березки, Березкинский дом культуры	f	small
34701	28377	3620	Волгоградская область, Серафимовичский район, село Базки, Базковское ОПС	f	small
34675	28351	3524	Волгоградская область, Светлоярский район, село Червленое, Клубная, 7	f	large
34666	14665	3515	Волгоградская область, Светлоярский район, село Цаца, 18 ГМП, 53	f	large
34671	28347	3520	Волгоградская область, Светлоярский район, село Станция Абганерово, Сердюкова, 2	f	medium
34674	28350	3523	Волгоградская область, Светлоярский район, село Северный, Школьная, 5	f	small
34656	28334	3505	Волгоградская область, Светлоярский район, Светлый Яр, Здание МКУ Электроник	f	large
34658	28336	3507	Волгоградская область, Светлоярский район, Светлый Яр, Сидорова, 7	f	large
34652	28330	3501	Волгоградская область, Светлоярский район, Светлый Яр, Сидорова, 3	f	large
34653	28331	3502	Волгоградская область, Светлоярский район, Светлый Яр, Переулок Зеленый, 1	f	large
34654	28332	3503	Волгоградская область, Светлоярский район, Светлый Яр, Мелиоративная, 1	f	large
34657	28335	3506	Волгоградская область, Светлоярский район, Светлый Яр, 1 микрорайон, 23а	f	large
34655	28333	3504	Волгоградская область, Светлоярский район, Светлый Яр, 1 микрорайон, 29	f	large
34661	28339	3510	Волгоградская область, Светлоярский район, село Райгород, Здание МКОУ Райгородская СОШ	f	large
34660	28338	3509	Волгоградская область, Светлоярский район, село Райгород, Советская, 195	f	large
34673	28349	3522	Волгоградская область, Светлоярский район, село Прудовый, Набережная, 35	f	small
34670	28308	3519	Волгоградская область, Светлоярский район, село Привольный, переулок Школьный, 3	f	large
34667	28344	3516	Волгоградская область, Светлоярский район, село Приволжский, Школьная, 291	f	large
34672	28348	3521	Волгоградская область, Светлоярский район, село Нариман, Дружбы, 1	f	large
34664	28342	3513	Волгоградская область, Светлоярский район, село Малые Чапурники, Школьная, 20	f	medium
34668	28345	3517	Волгоградская область, Светлоярский район, село Луговой, Красных Зорь, 23	f	small
34669	28346	3518	Волгоградская область, Светлоярский район, село Краснопартизанский, Чапаева, Здание МОУ Краснопартизанской ООШ	f	small
34678	28354	3527	Волгоградская область, Светлоярский район, село Кирова, Школьная, 2-а	f	large
34679	28355	3528	Волгоградская область, Светлоярский район, поселок Кирова, Кирова, 6А	f	small
34676	28352	3525	Волгоградская область, Светлоярский район, Канальная, Привокзальная, Здание вокзала ж/д	f	small
34681	28357	3530	республика Марий Эл, Советский район, село Ивановка	f	medium
34665	28343	3514	Волгоградская область, Светлоярский район, село Дубовый Овраг, Октябрьская, 62а	f	large
34663	28341	3512	Волгоградская область, Светлоярский район, село Большие Чапурники, Ильина, 46	f	large
34662	28340	3511	Волгоградская область, Светлоярский район, село Большие Чапурники, Ильина, Здание Большечапурниковского СДК	f	large
34646	28324	3415	Волгоградская область, Руднянский район, село Ушинка, Советская, 34, Берёзовский ФАБ МУЗ ЦРБ	f	small
34651	28329	3420	Волгоградская область, Руднянский район, село Сосновка, Мирная, 5, МУ Сосновский СДК	f	small
34637	28315	3406	Волгоградская область, Руднянский район, село Садовый, Новая, 4, МДОУ Плодосовхозный д/сад	f	small
34633	28311	3402	Волгоградская область, Руднянский район, поселок городского типа Рудня, Строителей, 2, МОУ Щелканская СОШ	f	large
34636	28314	3405	Волгоградская область, Руднянский район, поселок городского типа Рудня, Советская, 7, МОУ Руднянская СОШ	f	large
34638	28316	3407	Волгоградская область, Руднянский район, поселок городского типа Рудня, Горная, 131, Русско-Бундевский СДК	f	small
34635	28313	3404	Волгоградская область, Руднянский район, поселок Рудня, Октябрьская , 43, МОУ ДОД Центр детского творчества	f	large
34632	28310	3401	Волгоградская область, Руднянский район, поселок Рудня, Комсомольская, 2, МУ РЦКД Современник	f	large
34634	28312	3403	Волгоградская область, Руднянский район, поселок Рудня, Володарского, 2-в, НОУ Руднянский УСТК ДОСААФ	f	large
34649	28327	3418	Волгоградская область, Руднянский район, село Подкуйково, Полевая, 10, МУ Подкуйковский СДК	f	small
34648	28326	3417	Волгоградская область, Руднянский район, село Осички, Мирная, 25, МБОУ Осичковская СОШ	f	medium
34641	28319	3410	Волгоградская область, Руднянский район, село Новая Кондаль, Пролетарская, 49, МУ Новокондальский ФАП МУЗ ЦРБ	f	small
83912	57336	3105	Москва, Зеленоград, к314	f	large
34647	28325	3416	Волгоградская область, Руднянский район, село Матышево, Московская , 56, Библиотека МУ Матышевский СДК	f	large
34645	28323	3414	Волгоградская область, Руднянский район, село Лопуховка, Молодёжная, 2, Администрация Лопуховского с/пос	f	medium
34644	28322	3413	Волгоградская область, Руднянский район, село Лемешкино, Кирова, 97, МУ Лемешкинский СДК	f	large
34643	28321	3412	Волгоградская область, Руднянский район, село Козловка, Майская, 49, Администрация Козловского с/пос	f	small
34642	28320	3411	Волгоградская область, Руднянский район, село Ильмень, Мира , 1, Администрация Ильменск. с/пос	f	medium
34640	28318	3409	Волгоградская область, Руднянский район, село Громки, Молодежная, 4, МУ Громковский СДК	f	small
34639	28317	3408	Волгоградская область, Руднянский район, село Большое Судачье, Школьная, 18, Администрация Большесудачен. с/пос	f	medium
34650	28328	3419	Волгоградская область, Руднянский район, село Баранниково, Центральная, 23, МУ Баранниковский СДК	f	small
34599	28295	3239	Волгоградская область, Палласовский район, поселок Эльтон, Калинина, 10	f	large
34600	28296	3240	Волгоградская область, Палласовский район, поселок Эльтон, Вокзальная, 24	f	large
34586	28282	3226	Волгоградская область, Палласовский район, село Худушный, Худушнинская МНОШ	f	small
34580	28209	3220	Волгоградская область, Палласовский район, село Старая Иванцовка, Центральная, 28	f	small
34583	28279	3223	Волгоградская область, Палласовский район, село Старая Балка, Школьная, 10	f	small
34571	28271	3211	Волгоградская область, Палласовский район, село Смычка, Береговая, 26	f	small
34577	28277	3217	Волгоградская область, Палласовский район, Село Серогодский, улица Карпенко, 12	f	small
34591	28287	3231	Волгоградская область, Палласовский район, село Сапунков, Сапунсковская МНОШ	f	small
34573	28273	3213	Волгоградская область, Палласовский район, село Савинка, Чапаева, 152	f	large
34574	28274	3214	Волгоградская область, Палласовский район, село Савинка, Гагарина, 4	f	large
34581	28235	3221	Волгоградская область, Палласовский район, село Ромашки, А.Уриха, 55	f	large
34429	28126	2709	Волгоградская область, Палласовский район, село Путь Ильича, Ильичевский СДК	f	large
34592	28288	3232	Волгоградская область, Палласовский район, село Прудентов, Прудентовская, 1	f	medium
34601	28297	3241	Волгоградская область, Палласовский район, село Приозерный, Приозерская МНОШ	f	small
34563	14612	3203	Волгоградская область, Палласовский район, Палласовка, площадь Ленина, 1-а	f	large
34565	28265	3205	Волгоградская область, Палласовский район, Палласовка, Юбилейная, 60	f	medium
34567	28267	3207	Волгоградская область, Палласовский район, Палласовка, Ушакова, 2	f	large
34562	28263	3202	Волгоградская область, Палласовский район, Палласовка, Советская, 28А	f	large
34569	28269	3209	Волгоградская область, Палласовский район, Палласовка, Остравская, 17	f	large
34566	28266	3206	Волгоградская область, Палласовский район, Палласовка, Новая, 52	f	large
34568	28268	3208	Волгоградская область, Палласовский район, Палласовка, Мира, 9	f	large
34564	28264	3204	Волгоградская область, Палласовский район, Палласовка, Красноармейская, 1	f	large
34579	28147	3219	Волгоградская область, Палласовский район, село Новая Иванцовка, Школьная, 6	f	small
34576	28276	3216	Волгоградская область, Палласовский район, село Лиманный, Школьная, 12	f	small
34570	28270	3210	Волгоградская область, Палласовский район, село Кумысолечебница, Центральная, 3	f	small
34572	28272	3212	Волгоградская область, Палласовский район, село Куликов, Школьная, 10	f	small
34582	28259	3222	Волгоградская область, Палласовский район, село Красный Октябрь, Цветочная, 1	f	large
34595	28291	3235	Волгоградская область, Палласовский район, село Комсомольский, Мирная, 3	f	medium
34603	28299	3243	Волгоградская область, Палласовский район, село Калинина, улица Калинина, сельский клуб	f	small
34587	28283	3227	Волгоградская область, Палласовский район, село Калашники, Клашаниковская МНОШ	f	small
34594	28290	3234	Волгоградская область, Палласовский район, село Кайсацкое, Советская, 34	f	large
34588	28284	3228	Волгоградская область, Палласовский район, село Золотари, Комсомольская, 14	f	large
34461	28159	2820	Волгоградская область, Новоаннинский район, село Кузнецовский	f	small
34575	28275	3215	Волгоградская область, Палласовский район, село Заливной, переулок Гоголя, 5	f	small
34584	28280	3224	Волгоградская область, Палласовский район, село Жолобов, Жолобская МНОШ	f	small
34590	28286	3230	Волгоградская область, Палласовский район, село Ерши, Ершовская МНОШ	f	small
34593	28289	3233	Волгоградская область, Палласовский район, село Гормаки, Гормаковуская МНОШ	f	small
34596	28292	3236	Волгоградская область, Палласовский район, село Вишневка, Мира, 19-а	f	medium
34598	28294	3238	Волгоградская область, Палласовский район, село Венгеловка, Ветеринаров, 15	f	small
34602	28298	3242	Волгоградская область, Палласовский район, село Большой Симкин, Большисимкинская МООШ	f	small
34555	28255	3116	Волгоградская область, Ольховский район, село Ягодное, Советская, 3	f	medium
34558	28258	3119	Волгоградская область, Ольховский район, село Солодча, Краснопартизанская, 9	f	medium
34559	28260	3120	Волгоградская область, Ольховский район, село Солодча, Кирова, 2	f	medium
34546	28246	3107	Волгоградская область, Ольховский район, село Рыбинка, Центральная, 52	f	medium
34557	28257	3118	Волгоградская область, Ольховский район, село Романовка, Ценральная, 68	f	small
34550	28250	3111	Волгоградская область, Ольховский район, село Погожья Балка, Новая, 2	f	small
34540	28240	3101	Волгоградская область, Ольховский район, поселок городского типа Ольховка, улица Восточная, 9В	f	large
34541	28241	3102	Волгоградская область, Ольховский район, поселок городского типа Ольховка, Советская, 14	f	large
34542	28242	3103	Волгоградская область, Ольховский район, поселок Ольховка, Базарная, 9А	f	large
34549	28249	3110	Волгоградская область, Ольховский район, село Нежинский, Почтовая, 1	f	small
34556	28256	3117	Волгоградская область, Ольховский район, село Липовка, Ленина, 54	f	medium
34543	28243	3104	Волгоградская область, Ольховский район, село Клиновка, Даниловка, 25	f	small
34547	28247	3108	Волгоградская область, Ольховский район, село Киреево, Кооперативная, 6	f	medium
34551	28251	3112	Волгоградская область, Ольховский район, село Каменный Брод, Верхняя, 5	f	small
34552	28252	3113	Волгоградская область, Ольховский район, село Зензеватка, Элеваторная, 1	f	medium
34553	28253	3114	Волгоградская область, Ольховский район, село Зензеватка, Октябрьская, 1	f	medium
34560	28261	3121	Волгоградская область, Ольховский район, село Захаровка, Московская , 14	f	small
34545	28245	3106	Волгоградская область, Ольховский район, село Забурунный, сельский клуб	f	small
34544	28244	3105	Волгоградская область, Ольховский район, село Гусевка, Почтовая, 62	f	medium
34548	28248	3109	Волгоградская область, Ольховский район, село Гурово, Центральная, 18	f	medium
34537	28237	3027	Волгоградская область, Октябрьский район, село Шелестово, Сердюкова, 27, Шелестовская средняя школа	f	medium
34536	28236	3026	Волгоградская область, Октябрьский район, село Шебалино, Центральная, 7, Администрация сельского поселен	f	medium
34533	28232	3023	Волгоградская область, Октябрьский район, село Советский, Рабочая, 1, Администрация Советского с/п	f	small
34518	28217	3008	Волгоградская область, Октябрьский район, село Самохино, Дуенко, 4/1, Самохинский ФАП	f	small
34532	28231	3022	Волгоградская область, Октябрьский район, село Перегрузное, Центральная, 68, Перегрузненская средняя школа	f	medium
34135	27863	1815	Волгоградская область, Октябрьский район, поселок Октябрьский, ФГУ 61 дом офицеров гарнизонный	f	large
34530	28229	3020	Волгоградская область, Октябрьский район, поселок Октябрьский, Небыкова, 2, МОУ ОСОШ № 1	f	large
34531	28230	3021	Волгоградская область, Октябрьский район, поселок городского типа Октябрьский, переулок Рабочий, 1, ОАО Октябрьская райагротехника	f	large
34528	28227	3018	Волгоградская область, Октябрьский район, поселок городского типа Октябрьский, Октябрьская, 22, Районный Дом Культуры	f	large
34529	28228	3019	Волгоградская область, Октябрьский район, поселок городского типа Октябрьский, Ленина, 51, Кинотеатр Октябрь	f	medium
34527	28226	3017	Волгоградская область, Октябрьский район, село Новоаксайский, Центральная, 2, Сельский Дом культуры	f	medium
34535	28234	3025	Волгоградская область, Октябрьский район, село Нижнекумский, Центральная, 20, Нижнекумский сельский клуб	f	small
83907	57335	3100	Москва, Зеленоград, к429а	f	large
34521	28220	3011	Волгоградская область, Октябрьский район, село Молокановский, Тихий переулок, 4, Молокановская начальная школа	f	small
34526	28225	3016	Волгоградская область, Октябрьский район, село Ковалевка, Продольная, 34, Ковалевская начальная школа	f	small
34525	28224	3015	Волгоградская область, Октябрьский район, село Каменка, Школьная, 5, Каменская начальная школа	f	small
34522	28221	3012	Волгоградская область, Октябрьский район, село Ильмень-Суворовский, Школьная, 13, Дом культуры	f	medium
34516	28215	3006	Волгоградская область, Октябрьский район, село Ивановка, Центральная, 45, Сельский Дом культуры	f	small
34519	28218	3009	Волгоградская область, Октябрьский район, село Заливский, Юбилейная, 8, Сельский Дом культуры	f	large
34517	28216	3007	Волгоградская область, Октябрьский район, село Жутово 2-е, им. Ю.М. Носачева, 9, Жутовская СОШ	f	medium
34524	28223	3014	Волгоградская область, Октябрьский район, село Жутово 1-е, Центральная, 40, Жутовский сельский Дом культуры	f	small
34515	28214	3005	Волгоградская область, Октябрьский район, село Громославка, Административная, 4, Администрация сельского пос	f	medium
34538	28238	3028	Волгоградская область, Октябрьский район, село Гончаровское, Молодежная, 4, Гончаровский сельский клуб	f	small
34520	28219	3010	Волгоградская область, Октябрьский район, село Водянский, улица Дружбы, 12, Водянская начальная школа	f	small
34539	28239	3029	Волгоградская область, Октябрьский район, село Водино, Центральная, 10, Водинский ФАП	f	small
34523	28222	3013	Волгоградская область, Октябрьский район, село Верхнерубежный, Центральная, 44, Верхнерубежная начальная школа	f	small
34534	28233	3024	Волгоградская область, Октябрьский район, село Верхнекумский, Виноградная, 16, Верхнекумская начальная школа	f	small
34514	28213	3004	Волгоградская область, Октябрьский район, село Васильевка, Центральная, 6, сельский Дом культуры	f	small
34513	28212	3003	Волгоградская область, Октябрьский район, село Антонов, Татаренко, 8, Сельский Дом культуры	f	large
34512	28211	3002	Волгоградская область, Октябрьский район, село Аксай, Октябрьская, 1а, Сельский Дом культуры	f	large
34511	28210	3001	Волгоградская область, Октябрьский район, село Абганерово, Гордиенко, 12, Сельский Дом культуры	f	large
34509	28207	2925	Волгоградская область, Новониколаевский район, село Хоперский, Советская, 20, МОУ Хоперская средняя общеобразовательная школа	f	medium
34493	28191	2909	Волгоградская область, Новониколаевский район, село Фоминский, улица Центральная, 88, Сельский клуб	f	small
34507	28205	2923	Волгоградская область, Новониколаевский район, село Серп и Молот, Центральная, 1, дом культуры	f	medium
34492	28190	2908	Волгоградская область, Новониколаевский район, село Орловский, Центральная, 11, сельский Дом культуры	t	small
34486	28184	2902	Волгоградская область, Новониколаевский район, поселок Новониколаевский, районный Дом культуры	f	large
34491	28189	2907	Волгоградская область, Новониколаевский район, поселок Новониколаевский, Усадьба СХ, 4Б	f	large
34490	28188	2906	Волгоградская область, Новониколаевский район, поселок Новониколаевский, Первомайская, 1, МОУ Новониколаевская средняя общеобразовательная школа №2	f	medium
34488	28186	2904	Волгоградская область, Новониколаевский район, поселок Новониколаевский, Народная, 20, Новониколаевская средняя общеобразовательная школа	f	large
34487	28185	2903	Волгоградская область, Новониколаевский район, поселок Новониколаевский, Народная, 128, администрация Новониколаевского городского поселения	f	large
34485	28183	2901	Волгоградская область, Новониколаевский район, поселок Новониколаевский, Народная, 123А, контора Новониколаевского участка ОГУП Волгоградавтодор ДРСУ-4	f	large
34489	28187	2905	Волгоградская область, Новониколаевский район, поселок городского типа Новониколаевский, МОУ Новониколаевская средняя общеобразовательная школа № 3	f	large
34501	28199	2917	Волгоградская область, Новониколаевский район, село Новокардаильский	f	small
34497	28195	2913	Волгоградская область, Новониколаевский район, село Николаевский	f	small
34504	28202	2920	Волгоградская область, Новониколаевский район, село Нижнекардаильский, Центральная, 10А, сельский клуб	f	small
29512	19097	55	Астраханская область, Ахтубинск, Шоссе авиаторов, 5	f	large
34505	28203	2921	Волгоградская область, Новониколаевский район, село Мирный, Народная, 4	f	medium
34506	28204	2922	Волгоградская область, Новониколаевский район, село Купава, Школьная, 11, филиал Муниципального образовательного учреждения Мирная средняя общеобразовательная школа Купавская основная общеобразовательная школа	f	small
34503	28201	2919	Волгоградская область, Новониколаевский район, село Куликовский, Советская, 22А, кафетерий	f	large
34502	28200	2918	Волгоградская область, Новониколаевский район, село Красноармейский, сельский Дом культуры	f	medium
34500	28198	2916	Волгоградская область, Новониколаевский район, село Комсомольский, сельский Дом культуры	f	medium
34510	28208	2926	Волгоградская область, Новониколаевский район, село Киквидзе, Центральная, 24	f	small
34508	28206	2924	Волгоградская область, Новониколаевский район, село Каменка, сельский Дом Культуры	f	small
34499	28197	2915	Волгоградская область, Новониколаевский район, село Дуплятский, сельский Дом культуры	f	medium
34498	28196	2914	Волгоградская область, Новониколаевский район, село Двойновский, сельский Дом культуры	f	medium
34495	28193	2911	Волгоградская область, Новониколаевский район, село Грачи	f	small
34496	28194	2912	Волгоградская область, Новониколаевский район, село Верхнекардаильский, сельский Дом культуры	f	medium
34494	28192	2910	Волгоградская область, Новониколаевский район, село Алексиковский, Центральная, 22, сельский Дом культуры	f	large
34457	28155	2816	Волгоградская область, Новоаннинский район, село Ярыженский	f	small
34484	28182	2843	Волгоградская область, Новоаннинский район, село Черкесовский	f	large
34463	28161	2822	Волгоградская область, Новоаннинский район, село Челышевский	f	small
34481	28179	2840	Волгоградская область, Новоаннинский район, село Филоновская	f	medium
34479	28177	2838	Волгоградская область, Новоаннинский район, село Тростянский	f	medium
34472	28170	2831	Волгоградская область, Новоаннинский район, село Троецкий	f	small
34222	27948	2008	Волгоградская область, Новоаннинский район, село Страховский, здание Страховского сельского клуба	f	small
34475	28173	2834	Волгоградская область, Новоаннинский район, село Староаннинская	f	medium
34483	28181	2842	Волгоградская область, Новоаннинский район, село Соломатин	f	small
34460	28158	2819	Волгоградская область, Новоаннинский район, село Сатаровский	f	small
34482	28180	2841	Волгоградская область, Новоаннинский район, село Рожновский	f	small
34476	28174	2835	Волгоградская область, Новоаннинский район, село Родниковский	f	small
34468	28166	2827	Волгоградская область, Новоаннинский район, село Рог-Измайловский	f	small
34480	28178	2839	Волгоградская область, Новоаннинский район, село Поповский	f	small
34458	28156	2817	Волгоградская область, Новоаннинский район, село Поповский	f	small
34470	28168	2829	Волгоградская область, Новоаннинский район, село Полтавский	t	small
34474	28172	2833	Волгоградская область, Новоаннинский район, село Полевой	f	small
34471	28169	2830	Волгоградская область, Новоаннинский район, село Панфилово	f	large
34473	28171	2832	Волгоградская область, Новоаннинский район, село Новосельский	f	small
34469	28167	2828	Волгоградская область, Новоаннинский район, село Новокиевка	f	medium
34445	28142	2804	Волгоградская область, Новоаннинский район, Новоаннинский, поселок Казачий, 85	f	large
34452	28150	2811	Волгоградская область, Новоаннинский район, Новоаннинский, Советская улица, 41	f	large
34447	28144	2806	Волгоградская область, Новоаннинский район, Новоаннинский, Рабочая, 239	f	large
34444	28141	2803	Волгоградская область, Новоаннинский район, Новоаннинский, Подтелкова, 67	f	large
34443	28140	2802	Волгоградская область, Новоаннинский район, Новоаннинский, Подтелкова, 41 а	f	large
34442	28139	2801	Волгоградская область, Новоаннинский район, Новоаннинский, Пионерская, 38	f	large
34450	28148	2809	Волгоградская область, Новоаннинский район, Новоаннинский, Народная, 11	f	large
34448	28145	2807	Волгоградская область, Новоаннинский район, Новоаннинский, Ленина, 44	f	large
34451	28149	2810	Волгоградская область, Новоаннинский район, Новоаннинский, Калинина, 106	f	large
34446	28143	2805	Волгоградская область, Новоаннинский район, Новоаннинский, Киквидзе, 95	f	large
34467	28165	2826	Волгоградская область, Новоаннинский район, село Краснокоротковский	f	small
34454	28152	2813	Волгоградская область, Новоаннинский район, село Красногорский	f	small
34478	28176	2837	Волгоградская область, Новоаннинский район, село Дурновский	f	small
34464	28162	2823	Волгоградская область, Новоаннинский район, село Деминский	f	medium
34462	28160	2821	Волгоградская область, Новоаннинский район, село Галушкинский	f	medium
34459	28157	2818	Волгоградская область, Новоаннинский район, село Бочаровский	f	small
34477	28175	2836	Волгоградская область, Новоаннинский район, село Борисовский	f	small
34465	28163	2824	Волгоградская область, Новоаннинский район, село Большой Головский	f	small
34456	28154	2815	Волгоградская область, Новоаннинский район, село Березовка 2-я	f	small
34455	28153	2814	Волгоградская область, Новоаннинский район, село Березовка 1-я	f	small
34453	28151	2812	Волгоградская область, Новоаннинский район, село АМО	f	medium
34426	28123	2706	Волгоградская область, Николаевский район, село Торгунский, здание МОУ Торгунская НОШ	f	small
34441	28138	2721	Волгоградская область, Николаевский район, село Степновский, Степновский СДК	f	medium
34438	28135	2718	Волгоградская область, Николаевский район, село Солодушино, Солодушинский СДК	f	large
34440	28137	2720	Волгоградская область, Николаевский район, село Рулевой, Рулевской СК	f	small
34435	28132	2715	Волгоградская область, Николаевский район, село Политотдельское, здание администрации Политотдельского сельского поселения	f	medium
34431	28128	2711	Волгоградская область, Николаевский район, село Пионер, МОУ Пионерская СОШ	f	small
34439	28136	2719	Волгоградская область, Николаевский район, село Очкуровка, Очкуровский СДК	f	medium
34434	28131	2714	Волгоградская область, Николаевский район, село Новый Быт, здание администрации Новобытовского сельского поселения	f	medium
34422	28119	2702	Волгоградская область, Николаевский район, Николаевск, Чайковского, 3	f	large
34421	28118	2701	Волгоградская область, Николаевский район, Николаевск, Свердлова, 30	f	large
34424	28121	2704	Волгоградская область, Николаевский район, Николаевск, Республиканская, 36	f	large
34423	28120	2703	Волгоградская область, Николаевский район, Николаевск, Октябрьская, 4	f	large
34425	28122	2705	Волгоградская область, Николаевский район, Николаевск, Калинина, 28	f	large
34432	28129	2712	Волгоградская область, Николаевский район, село Ленинское, Ленинский СДК	f	large
34430	28127	2710	Волгоградская область, Николаевский район, село Левчуновка, здание МОУ Левчуновская СОШ	f	medium
34437	28134	2717	Волгоградская область, Николаевский район, село Кумысолечебница, здание конторы ОАО Новая Жизнь	f	small
34427	28124	2707	Волгоградская область, Николаевский район, село Красный Мелиоратор, здание МОУ Вербенская СОШ	f	medium
34433	28130	2713	Волгоградская область, Николаевский район, село Комсомолец, здание МОУ Комсомольская СОШ	f	medium
34428	28125	2708	Волгоградская область, Николаевский район, село Бережновка, Бережновский СДК	f	large
34411	28108	2617	Волгоградская область, Нехаевский район, село Хорошенский, здание СДК	f	small
34410	28107	2616	Волгоградская область, Нехаевский район, село Упорниковский, здание ЦКС	f	large
34400	28097	2606	Волгоградская область, Нехаевский район, село Тушкановский, Школа	f	small
34412	28109	2618	Волгоградская область, Нехаевский район, село Тишанская, школа	f	small
34420	28117	2626	Волгоградская область, Нехаевский район, село Солонка, администрация СП	f	medium
34415	28112	2621	Волгоградская область, Нехаевский район, село Соколовский, здание ФАП	f	small
34403	28100	2609	Волгоградская область, Нехаевский район, Село Успенка, администрация СП	f	small
34418	28115	2624	Волгоградская область, Нехаевский район, село Роднички, школа	f	medium
34402	28099	2608	Волгоградская область, Нехаевский район, село Нижнедолговский, здание СДК	f	medium
34395	28092	2601	Волгоградская область, Нехаевский район, поселок Нехаевская, Ленина, 40	f	large
34397	28094	2603	Волгоградская область, Нехаевский район, поселок Нехаевская, Коммунистическая	f	large
34396	28093	2602	Волгоградская область, Нехаевский район, Нехаевская, Лесхоз	f	medium
83906	57335	3099	Москва, Зеленоград, к429а	f	large
34414	28111	2620	Волгоградская область, Нехаевский район, село Мазинский, здание СДК	f	small
34401	28098	2607	Волгоградская область, Нехаевский район, село Луковская, администрация СП	f	small
34407	28104	2613	Волгоградская область, Нехаевский район, хутор Лобачевский, школа	f	small
34419	28116	2625	Волгоградская область, Нехаевский район, село Кулички, администрация СП	f	small
34416	28113	2622	Волгоградская область, Нехаевский район, село Кругловка, здание ЦКД	f	medium
34404	28101	2610	Волгоградская область, Нехаевский район, село Краснополье, школа	f	small
34399	28096	2605	Волгоградская область, Нехаевский район, село Захоперский, школа	f	small
34408	28105	2614	Волгоградская область, Нехаевский район, село Динамо, школа	f	medium
34409	28106	2615	Волгоградская область, Нехаевский район, село Денисовский, здание ЦКС	f	small
34405	28102	2611	Волгоградская область, Нехаевский район, село Верхнереченский, администрация СП	f	medium
34413	28110	2619	Волгоградская область, Нехаевский район, село Артановский, здание ФАП	f	small
34406	28103	2612	Волгоградская область, Нехаевский район, село Авраамовский, школа	f	small
34382	28079	2524	Волгоградская область, Михайловский район, село Черемухов, Советская, 14, Черемуховский сельский ДК	f	small
34393	28090	2535	Волгоградская область, Михайловский район, село Троицкий, Советская, 32, Центр детского творчества	f	large
34380	28078	2523	Волгоградская область, Михайловский район, село Сухов 2-й, Мира, 16, д/с Солнышко	f	medium
34364	28062	2507	Волгоградская область, Михайловский район, село Сухов 1-й, Садовая, 4, Суховский-1 сельский клуб	f	small
34384	28081	2526	Волгоградская область, Михайловский район, село Субботин, Юрия Прищепного, 121, Субботинский сельский клуб	f	small
34391	28088	2533	Волгоградская область, Михайловский район, село Страховский, Школьная, 1, Страховская школа	f	small
34363	28061	2506	Волгоградская область, Михайловский район, село Староселье, Центральная, 24, Старосельская школа	f	medium
34388	28085	2530	Волгоградская область, Михайловский район, село Сидоры, Ленина, 38, Сидорская школа	f	large
34387	28084	2529	Волгоградская область, Михайловский район, село Сидоры, Ленина, 5-А, Сидорский сельский ДК	f	medium
34385	28082	2527	Волгоградская область, Михайловский район, село Сенной, Ленина, 36, Сенновский сельский ДК	f	medium
34372	28070	2515	Волгоградская область, Михайловский район, село Сеничкин, Центральная, 27-А, Сеничкинский сельский клуб	f	small
34377	28075	2520	Волгоградская область, Михайловский район, село Секачи, Первомайский, 4, Секачевский сельский ДК	f	small
34394	28091	2536	Волгоградская область, Михайловский район, село Рогожин, Первомайский, 2, Рогожинская школа	f	small
34390	28087	2532	Волгоградская область, Михайловский район, село Реконструкция, Парковый, 8, Реконструкторский сельский ДК	f	medium
34383	28080	2525	Волгоградская область, Михайловский район, село Раздоры, Мира, 3, Раздорский сельский ДК	f	small
34374	28072	2517	Волгоградская область, Михайловский район, село Плотников 2-й, Школьная, 3, Плотниковская школа	f	medium
34373	28071	2516	Волгоградская область, Михайловский район, село Отруба, Украинская , 10, Отрубской сельский клуб	f	small
34378	28076	2521	Волгоградская область, Михайловский район, село Отрадное, Чекунова, 22, Отрадненская школа	f	large
34386	28083	2528	Волгоградская область, Михайловский район, Орлы, Лесная, 1, Орловский сельский клуб	f	small
34366	28064	2509	Волгоградская область, Михайловский район, село Моховский, Маршала Жукова, 44, Моховский сельский клуб	f	small
34375	28073	2518	Волгоградская область, Михайловский район, село Мишин, Заречная, 4, Мишинский сельский клуб	f	small
34950	28618	4410	Волгоградская область, Михайловский район, Михайловка, Свободы, 142-А, МОУ СОШ №9	f	large
34370	28068	2513	Волгоградская область, Михайловский район, село Крутинский, Центральная, 22	f	small
34371	28069	2514	Волгоградская область, Михайловский район, село Катасонов, Советская, 51, Катасоновский сельский ДК	f	small
34369	28067	2512	Волгоградская область, Михайловский район, село Карагичевский, Центральная, 1, Карагичевский сельский ДК	f	large
34368	28066	2511	Волгоградская область, Михайловский район, село Ильменский 2-й, Центральная, 15/1, льменский-2 сельский клуб	f	small
34360	28058	2503	Волгоградская область, Михайловский район, село Ильменский 1-й, Центральная, 31, Ильменский сельский клуб	f	small
34367	28065	2510	Волгоградская область, Михайловский район, село Етеревская, Красная, 21-А, Етеревская казачья школа	f	medium
34389	28086	2531	Волгоградская область, Михайловский район, село Большой Орешкин, Ольховая, 1, Большеорешкинский сельский клуб	f	small
34690	28366	3609	Волгоградская область, Михайловский район, село Большой, Большовский дом культуры	f	medium
34392	28089	2534	Волгоградская область, Михайловский район, село Большемедведевский, Зеленая, 4, Большемедведевский сельский клуб	f	small
34362	28060	2505	Волгоградская область, Михайловский район, село Безымянка, Центральная, 3, Администрация поселения	f	medium
34361	28059	2504	Волгоградская область, Михайловский район, село Безымянка, Советская улица, 130а, Безымянский сельский ДК	f	medium
34358	28056	2501	Волгоградская область, Михайловский район, село Арчединская, Ленина, 29, Арчединская школа	f	large
34346	28044	2413	Волгоградская область, Ленинский район, село Царев, Бегичева, 14	f	large
34355	28053	2422	Волгоградская область, Ленинский район, село Тракторострой, Ленина, 21	f	small
34353	28051	2420	Волгоградская область, Ленинский район, село Степной, Добровольского, 29	f	medium
34350	28048	2417	Волгоградская область, Ленинский район, село Степана Разина, Центральная, 32	f	small
34347	28045	2414	Волгоградская область, Ленинский район, село Солодовка, Павших борцов, 1-А	f	small
34356	28054	2423	Волгоградская область, Ленинский район, село Рассвет, Школьная, 8	f	medium
34597	28293	3237	Волгоградская область, Ленинский район, село Путь Ильича, Переулок Клубный, 1	f	medium
34354	28052	2421	Волгоградская область, Ленинский район, село Путь Ильича, Барышнева, 46	f	medium
34349	28047	2416	Волгоградская область, Ленинский район, село Покровка, Речная, 27	f	small
34585	28281	3225	Волгоградская область, Ленинский район, село Новостройка, Школьная, 3	f	large
34357	28055	2424	Волгоградская область, Ленинский район, село Маяк Октября, Ленина, 14	f	medium
34343	28042	2410	Волгоградская область, Ленинский район, село Маляевка, Советская, 57	f	medium
34351	28049	2418	Волгоградская область, Ленинский район, село Лещев, Павших Борцов, 15	f	small
34335	28036	2403	Волгоградская область, Ленинский район, Ленинск, Ястребова, 89 А	f	large
34334	28035	2402	Волгоградская область, Ленинский район, Ленинск, Чернышевского, 7	f	large
34337	28038	2405	Волгоградская область, Ленинский район, Ленинск, Ленина, 204 А	f	large
34338	14703	2406	Волгоградская область, Ленинский район, Ленинск, Ленина, 241	f	large
34339	28039	2407	Волгоградская область, Ленинский район, Ленинск, Битюцкого, 30 А	f	large
34333	28034	2401	Волгоградская область, Ленинский район, Ленинск, Ленина, 51	f	large
34342	28041	2409	Волгоградская область, Ленинский район, село Коммунар, Школьная, 12	f	medium
34348	28046	2415	Волгоградская область, Ленинский район, село Колобовка, Гагарина, 4	f	medium
34352	28050	2419	Волгоградская область, Ленинский район, село Каршевитое, Заречная, 7	f	small
34345	28043	2412	Волгоградская область, Ленинский район, село Заплавное, Совхозная, 21	f	large
34344	28043	2411	Волгоградская область, Ленинский район, село Заплавное, Совхозная, 21	f	large
34341	28040	2408	Волгоградская область, Ленинский район, село Бахтияровка, Карла Маркса, 33	f	medium
34630	28307	3327	Волгоградская область, Кумылженский район, село Шакин, Шакинское сельское поселение	f	medium
34616	28301	3313	Волгоградская область, Кумылженский район, село Суляевский	f	small
34615	28301	3312	Волгоградская область, Кумылженский район, село Суляевский	f	small
34614	28301	3311	Волгоградская область, Кумылженский район, село Суляевский	f	medium
34624	28304	3321	Волгоградская область, Кумылженский район, село Слащевская	f	small
34623	28304	3320	Волгоградская область, Кумылженский район, село Слащевская	f	large
34629	28306	3326	Волгоградская область, Кумылженский район, село Попов	f	small
34628	28306	3325	Волгоградская область, Кумылженский район, село Попов	f	medium
34379	28077	2522	Волгоградская область, Кумылженский район, село Поддубный, Центральная, 25, Поддубинский сельский клуб	f	small
34613	28300	3310	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	small
34612	28300	3309	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	small
34611	28300	3308	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	small
34610	28300	3307	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	small
34609	28300	3306	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	large
34608	28300	3305	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	large
34607	28300	3304	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	small
34606	28300	3303	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	medium
34605	28300	3302	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	large
34604	28300	3301	Волгоградская область, Кумылженский район, поселок городского типа Кумылженская	f	large
34619	28303	3316	Волгоградская область, Кумылженский район, село Краснянский	f	small
34622	28303	3319	Волгоградская область, Кумылженский район, село Краснянский	f	small
34621	28303	3318	Волгоградская область, Кумылженский район, село Краснянский	f	small
34620	28303	3317	Волгоградская область, Кумылженский район, село Краснянский	f	small
34618	28302	3315	Волгоградская область, Кумылженский район, село Глазуновская	f	medium
34617	28302	3314	Волгоградская область, Кумылженский район, село Глазуновская	f	medium
34627	28305	3324	Волгоградская область, Кумылженский район, село Букановская	f	small
34626	28305	3323	Волгоградская область, Кумылженский район, село Букановская	f	small
34625	28305	3322	Волгоградская область, Кумылженский район, село Букановская	f	medium
34631	28309	3328	Волгоградская область, Кумылженский район, село Белогорский	f	medium
34315	28017	2311	Волгоградская область, Котовский район, село Тарасово, сельский клуб	f	small
34313	28015	2309	Волгоградская область, Котовский район, село Сосновка, сельский клуб	f	small
34325	28026	2321	Волгоградская область, Котовский район, село Смородино, Смородинская школа	f	small
34316	28018	2312	Волгоградская область, Котовский район, село Слюсарево, Слюсаревская школа	f	small
34318	28019	2314	Волгоградская область, Котовский район, село Романов, сельский клуб	f	small
34317	27991	2313	Волгоградская область, Котовский район, село Попки, Дом культуры	f	medium
34329	28030	2325	Волгоградская область, Котовский район, село Племхоз, здание школы	f	small
34322	28023	2318	Волгоградская область, Котовский район, село Перещепное, сельский Дом культуры	f	small
34328	28029	2324	Волгоградская область, Котовский район, село Новониколаевка, здание школы	f	small
34319	28020	2315	Волгоградская область, Котовский район, село Нижние Коробки, Дом культуры	f	small
34321	28022	2317	Волгоградская область, Котовский район, село Неткачево, сельский клуб	f	small
34323	28024	2319	Волгоградская область, Котовский район, село Мокрая Ольховка, сельский Дом культуры	f	medium
34314	28016	2310	Волгоградская область, Котовский район, село Мирошники, Мирошниковский сельский Дом культуры	f	medium
34324	28025	2320	Волгоградская область, Котовский район, село Лапшинская, Лапшингская школа	f	medium
34326	28027	2322	Волгоградская область, Котовский район, село Купцово, сельский Дом культуры	f	medium
34320	28021	2316	Волгоградская область, Котовский район, село Крячки, Крячковская школа	f	small
34308	28010	2304	Волгоградская область, Котовский район, Котово, Чапаева, 3, ГОУ школа-интернат	f	large
34307	28009	2303	Волгоградская область, Котовский район, Котово, Синельникова, 2, МОУ СОШ №6	f	large
34309	28011	2305	Волгоградская область, Котовский район, Котово, Мира, 128, районный Дом культуры	f	large
34305	28007	2301	Волгоградская область, Котовский район, Котово, Ленина, 89	f	large
34311	28013	2307	Волгоградская область, Котовский район, Котово, Зеленая, 154, школа № 4	f	large
34310	28012	2306	Волгоградская область, Котовский район, Котово, Губкина, 8, МОУ СОШ №2	f	large
34306	28008	2302	Волгоградская область, Котовский район, Котово, Ленина, 89, МОУ СОШ №3	f	large
34330	28031	2326	Волгоградская область, Котовский район, село Коростино, здание администрации	f	medium
83910	57334	3103	Москва, Зеленоград, к429а	f	large
34178	27905	1906	Волгоградская область, Котовский район, село Калиновка, Зеленая, 5	f	small
34332	28033	2328	Волгоградская область, Котовский район, село Ефимовка, Мира, 55/3, офис ТОС Ефимовский	f	small
34312	28014	2308	Волгоградская область, Котовский район, село Бурлук, сельский Дом культуры	f	medium
34327	28028	2323	Волгоградская область, Котовский район, село Авилово, Сельский клуб	f	small
34920	28591	4320	Волгоградская область, Котельниковский район, городской округ город Камышин, село Ленина, ПУ №22	f	large
34279	27992	2214	Волгоградская область, Котельниковский район, село Чилеково	f	small
34278	27992	2213	Волгоградская область, Котельниковский район, село Чилеково	f	small
34277	27992	2212	Волгоградская область, Котельниковский район, село Чилеково	f	medium
34290	27998	2225	Волгоградская область, Котельниковский район, село Семичный	f	medium
34302	28005	2237	Волгоградская область, Котельниковский район, село Пугачевская	f	small
34301	28005	2236	Волгоградская область, Котельниковский район, село Пугачевская	f	small
34283	27994	2218	Волгоградская область, Котельниковский район, село Поперечный	f	small
34282	27994	2217	Волгоградская область, Котельниковский район, село Поперечный	f	small
34285	27995	2220	Волгоградская область, Котельниковский район, село Пимено-Черни	f	small
34284	27995	2219	Волгоградская область, Котельниковский район, село Пимено-Черни	f	medium
34298	28003	2233	Волгоградская область, Котельниковский район, село Нижнеяблочный	f	medium
34297	28003	2232	Волгоградская область, Котельниковский район, село Нижнеяблочный	f	small
34289	27997	2224	Волгоградская область, Котельниковский район, село Нагольный	f	medium
34293	28000	2228	Волгоградская область, Котельниковский район, село Нагавская	f	medium
34292	27999	2227	Волгоградская область, Котельниковский район, село Майоровский	f	small
34291	27999	2226	Волгоградская область, Котельниковский район, село Майоровский	f	small
34300	28004	2235	Волгоградская область, Котельниковский район, село Красноярский	f	small
34299	28004	2234	Волгоградская область, Котельниковский район, село Красноярский	f	medium
34288	27996	2223	Волгоградская область, Котельниковский район, Котельниково	f	medium
34287	27996	2222	Волгоградская область, Котельниковский район, Котельниково	f	small
34286	27996	2221	Волгоградская область, Котельниковский район, Котельниково	f	small
34276	27990	2211	Волгоградская область, Котельниковский район, Котельниково	f	large
34275	27990	2210	Волгоградская область, Котельниковский район, Котельниково	f	large
34274	27990	2209	Волгоградская область, Котельниковский район, Котельниково	f	large
34273	27990	2208	Волгоградская область, Котельниковский район, Котельниково	f	medium
34272	27990	2207	Волгоградская область, Котельниковский район, Котельниково	f	large
34271	27990	2206	Волгоградская область, Котельниковский район, Котельниково	f	medium
34270	27990	2205	Волгоградская область, Котельниковский район, Котельниково	f	large
34269	27990	2204	Волгоградская область, Котельниковский район, Котельниково	f	large
34268	27990	2203	Волгоградская область, Котельниковский район, Котельниково	f	medium
34267	27990	2202	Волгоградская область, Котельниковский район, Котельниково	f	medium
34266	27990	2201	Волгоградская область, Котельниковский район, Котельниково	f	large
34296	28002	2231	Волгоградская область, Котельниковский район, село Захаров	f	small
34295	28002	2230	Волгоградская область, Котельниковский район, село Захаров	f	small
34242	27968	2107	Волгоградская область, Котельниковский район, село Захаров, Центральная, 12	f	medium
34304	28006	2239	Волгоградская область, Котельниковский район, село Генераловский	f	small
34303	28006	2238	Волгоградская область, Котельниковский район, село Генераловский	f	medium
34280	27993	2215	Волгоградская область, Котельниковский район, село Выпасной	t	small
34281	27993	2216	Волгоградская область, Котельниковский район, село Выпасной	f	medium
34294	28001	2229	Волгоградская область, Котельниковский район, село Веселый	f	medium
34376	28074	2519	Волгоградская область, Котельниковский район, село Веселый, Садовая, 2, Веселовский сельский клуб	f	small
34243	27969	2108	Волгоградская область, Клетский район, село Селиванов, Пролетарская, 12	f	small
34246	27972	2111	Волгоградская область, Клетский район, село Селиванов, Придорожная, 6	f	small
34250	27976	2115	Волгоградская область, Клетский район, село Перекопская, Казачья, 26	f	small
34262	27987	2127	Волгоградская область, Клетский район, село Перекопка, Центральная, 29А	f	medium
34264	27989	2129	Волгоградская область, Клетский район, село Орехов, Донская, 14А	f	small
34241	27967	2106	Волгоградская область, Клетский район, село Новоцарицынский, Молодежная, 4	f	small
34254	27980	2119	Волгоградская область, Клетский район, село Мелоклетский, Сухорукова, 69	f	small
34255	27981	2120	Волгоградская область, Клетский район, село Манойлин, Атамана Макарова, 3	f	medium
34260	27985	2125	Волгоградская область, Клетский район, село Малая Донщинка, Центральная, 6	f	small
34261	27986	2126	Волгоградская область, Клетский район, село Максари, Центральная, 33	f	small
34257	27982	2122	Волгоградская область, Клетский район, село Майоровский, Келина, 64	f	small
34263	27988	2128	Волгоградская область, Клетский район, село Логовский, Молодежная, 22	f	small
34259	27984	2124	Волгоградская область, Клетский район, село Липовский, Молодежная, 13	f	small
34249	27975	2114	Волгоградская область, Клетский район, село Кременская, Ленина, 22Б	f	medium
34252	27978	2117	Волгоградская область, Клетский район, поселок Клетская, Ленина, 32	f	large
34251	27977	2116	Волгоградская область, Клетский район, поселок Клетская, Ленина, 63	f	large
34253	27979	2118	Волгоградская область, Клетский район, село Караженский, переулок Школьный, 8	f	small
34245	27971	2110	Волгоградская область, Клетский район, село Казачий, Центральная, 6	f	small
34248	27974	2113	Волгоградская область, Клетский район, село Зотовский, Центральная, 22	t	small
34244	27970	2109	Волгоградская область, Клетский район, село Евстратовский, Московский переулок, 2	f	small
34236	27962	2101	Волгоградская область, Клетский район, село Верхняя Бузиновка, Центральная, 103	f	medium
34238	27964	2103	Волгоградская область, Клетский район, село Верхнечеренский, переулок Больничный, 2	f	small
34239	27965	2104	Волгоградская область, Клетский район, село Верхнечеренский, Центральная, 24Б	f	small
34237	27963	2102	Волгоградская область, Клетский район, село Венцы, Пролетарская, 7	f	small
34256	27922	2121	Волгоградская область, Клетский район, село Борисов, улица Чижова, 45	f	small
34788	28462	3813	Волгоградская область, Старополтавский район, село Красный Яр, Здание культурно-досугового объединения	f	medium
34056	27773	1617	Волгоградская область, Старополтавский район, село Красный Яр, Центральная, 14А	f	large
34217	27943	2003	Волгоградская область, Киквидзенский район, село Ширяевский, Ширяевский проезд, здание Ширяевского сельского клуба	f	small
34228	27954	2014	Волгоградская область, Киквидзенский район, село Чернолагутинский, здание сельского Дома культуры	f	medium
33996	27734	1430	Волгоградская область, Киквидзенский район, село Семеновка, Центральная, 19, Семеновский сельский клуб	f	small
34224	27950	2010	Волгоградская область, Киквидзенский район, село Расстригин, здание Расстригинского сельского клуба	f	small
34218	27944	2004	Волгоградская область, Киквидзенский район, Преображенская, здание Дон-Якушовского сельского клуба	f	small
34216	27942	2002	Волгоградская область, Киквидзенский район, поселок городского типа Преображенская, здание районного Дома культуры	f	large
34215	27941	2001	Волгоградская область, Киквидзенский район, поселок городского типа Преображенская, Здание МУ Социально досуговый центр Ровесник	f	large
34229	27955	2015	Волгоградская область, Киквидзенский район, село Озерки, дание Озерской школы	f	small
34226	27952	2012	Волгоградская область, Киквидзенский район, село Мордвинцево, здание Мордвинцевской общеобразовательной школы	f	small
34231	27957	2017	Волгоградская область, Киквидзенский район, село Мачеха, здание сельского Дома культуры	f	large
34225	27951	2011	Волгоградская область, Киквидзенский район, село Калачевский, Калачевский переулок, здание Калачевского сельского Дома культуры	f	medium
34219	27945	2005	Волгоградская область, Киквидзенский район, село Казарино, здание Казаринского сельского клуба	f	small
34190	27917	1918	Волгоградская область, Камышинский район, село Барановка, Саратовская, 14	f	small
34220	27946	2006	Волгоградская область, Киквидзенский район, село Завязка, здание Завязенского сельского Дома культуры	f	medium
34223	27949	2009	Волгоградская область, Киквидзенский район, село Дубровский, здание Дубровского сельского клуба	f	small
34227	27953	2013	Волгоградская область, Киквидзенский район, село Гришин, здание сельского Дома культуры	f	large
34221	27947	2007	Волгоградская область, Киквидзенский район, село Алонцево, здание Алонцевского сельского клуба	f	small
34182	27909	1910	Волгоградская область, Камышинский район, село Щербатовка, Мира, 28	f	small
34183	27910	1911	Волгоградская область, Камышинский район, село Щербаковка, Центральная, 14	f	small
34202	27929	1930	Волгоградская область, Камышинский район, Чухонастовка, Советская, 14	f	small
34174	27901	1902	Волгоградская область, Камышинский район, село Усть-Грязнуха, Школьная, 22	f	medium
34173	27884	1901	Волгоградская область, Камышинский район, село Умет, 60 лет Октября, 75	f	medium
34866	28539	4112	Волгоградская область, Камышинский район, село Терновка, здание Дома культуры	f	medium
34188	27915	1916	Волгоградская область, Камышинский район, село Терновка, Центральная, 5б	f	medium
34203	27930	1931	Волгоградская область, Камышинский район, село Таловка, Молодежная, 1	f	large
34213	27939	1941	Волгоградская область, Камышинский район, село Средняя Камышинка, Центральная, 8	f	small
34177	27904	1905	Волгоградская область, Камышинский район, село Семеновка, Советская, 6	f	medium
34207	27933	1935	Волгоградская область, Камышинский район, село Саломатино, Советская, 31	f	large
34191	27918	1919	Волгоградская область, Камышинский район, село Петрунино, Школьная, 5	f	medium
34198	27925	1926	Волгоградская область, Камышинский район, Петров Вал, Школьная, 3	f	medium
34200	27927	1928	Волгоградская область, Камышинский район, Петров Вал, Рихарда Зорге, 5	f	large
34194	27921	1922	Волгоградская область, Камышинский район, Петров Вал, Пионерская, 14	f	medium
34195	27921	1923	Волгоградская область, Камышинский район, Петров Вал, Пионерская, 14	f	large
34196	27923	1924	Волгоградская область, Камышинский район, Петров Вал, Ленина, 15	f	large
34192	27919	1920	Волгоградская область, Камышинский район, Петров Вал, Ленина, 61	f	large
34193	27920	1921	Волгоградская область, Камышинский район, Петров Вал, Коммунистическая, 67	f	large
34199	27926	1927	Волгоградская область, Камышинский район, Петров Вал, 30 лет Победы, 2	f	large
34176	27903	1904	Волгоградская область, Камышинский район, село Пановка, Центральная, 5	f	small
34186	27913	1914	Волгоградская область, Камышинский район, село Нижняя Добринка, Ленина, 33б	f	medium
34209	27935	1937	Волгоградская область, Камышинский район, поселок Мичуринский, Совхозная, 5	f	large
34214	27940	1942	Волгоградская область, Камышинский район, село Лебяжье, Советская, 27	f	large
34208	27934	1936	Волгоградская область, Камышинский район, село Костарево, Центральная, 10	f	medium
34212	27938	1940	Волгоградская область, Камышинский район, село Ельшанка, Центральная, 10	f	medium
34187	27914	1915	Волгоградская область, Камышинский район, село Дубовка, Центральная, 31а	f	small
34210	27936	1938	Волгоградская область, Камышинский район, село Дворянское, Советская, 7б	f	small
34211	27937	1939	Волгоградская область, Камышинский район, село Дворянское, Микрорайон, 6а	f	large
34179	27906	1907	Волгоградская область, Камышинский район, село Гуселка, Центральная, 73	f	small
34205	27932	1933	Волгоградская область, Камышинский район, село Госселекстанция, Почтовая, 11	f	medium
34184	27911	1912	Волгоградская область, Камышинский район, село Галка, Цветочный бульвар, 16	f	small
34180	27907	1908	Волгоградская область, Камышинский район, село Воднобуерачное, Советская, 14	f	medium
34204	27931	1932	Волгоградская область, Камышинский район, село Вихлянцево, Мира, 14	f	medium
34189	27916	1917	Волгоградская область, Камышинский район, село Верхняя Липовка, Школьная, 19	f	small
34181	27908	1909	Волгоградская область, Камышинский район, село Верхняя Куланинка, Школьная, 15	f	small
34175	27902	1903	Волгоградская область, Камышинский район, село Верхняя Грязнуха, Песчаная, 8	f	small
34206	14664	1934	Волгоградская область, Камышинский район, село Белогорки, Новая, 10	f	small
83909	57334	3102	Москва, Зеленоград, к429а	f	large
34201	27928	1929	Волгоградская область, Камышинский район, село Антиповка, Дружбы, 58	f	large
34922	28592	4322	Волгоградская область, Камышин городской округ, Камышин, Ленина, 17, ДК Текстильщик	f	large
34921	28592	4321	Волгоградская область, Камышин городской округ, Камышин, Ленина, 17, ДК Текстильщик	f	large
34927	28596	4327	Волгоградская область, Камышин городской округ, Камышин, Краснодонская, 7, МОУСОШ№11	f	large
34143	27871	1823	Волгоградская область, Калачевский район, село Ярки-Рубежный, Пушкина, 14, Клуб	f	small
34138	27866	1818	Волгоградская область, Калачевский район, село Тихоновка, Суворова, 4, Клуб	f	small
34142	27870	1822	Волгоградская область, Калачевский район, село Степаневка, Верхне-Царицынская, 36 А, МОУ Верхне-Царицынская НОШ	f	small
34123	27851	1803	Волгоградская область, Калачевский район, село Светлый Лог, Школьная, 1, Логовская ООШ	f	small
34127	27855	1807	Волгоградская область, Калачевский район, село Рюмино-Красноярский, Центральная, 29, Клуб	f	small
34129	27857	1809	Волгоградская область, Калачевский район, село Пятиморский, Волгоградская, 41, Клуб ДРГСиС	f	large
34121	27849	1801	Волгоградская область, Калачевский район, село Пятиизбянский, Центральная, 33, Администрация ПСП	f	medium
34132	27860	1812	Волгоградская область, Калачевский район, село Прудбой, Молодежная, 4, МОУ Прудбойская СОШ	f	large
34140	27868	1820	Волгоградская область, Калачевский район, село Приморский, Победы, 16, Дом культуры	f	small
34758	28434	3739	Волгоградская область, Калачевский район, село Первомайский, Первомайская, 24а, здание магазина Лесовик	f	small
34159	27888	1839	Волгоградская область, Калачевский район, село Пархоменко, Селский клуб	f	small
34134	27862	1814	Волгоградская область, Калачевский район, село Октябрьский, ФГУ 61 Дом офицеров (гарнизрна)	f	large
34554	28254	3115	Волгоградская область, Калачевский район, село Октябрьский, Школьная, 12	f	medium
34154	27882	1834	Волгоградская область, Калачевский район, село Овражный, Мира, 15 А, Клуб	f	small
34145	27873	1825	Волгоградская область, Калачевский район, село Новоляпичев, Молодежная, 20, Дом культуры	f	small
34130	27858	1810	Волгоградская область, Калачевский район, село Мариновка, Набережная, 17 А, Дом культуры	f	medium
34124	27852	1804	Волгоградская область, Калачевский район, село Малоголубинский, Подгорная, 91, Клуб	f	small
34147	27875	1827	Волгоградская область, Калачевский район, село Ляпичев, 16, Дом культуры	f	medium
34149	27877	1829	Волгоградская область, Калачевский район, село Логовский, 63, МОУ Логовская СОШ	f	large
34153	27881	1833	Волгоградская область, Калачевский район, село Крепинский, Свободная, 31, МОУ Крепинская СОШ	f	medium
34133	27861	1813	Волгоградская область, Калачевский район, село Комсомольский, Шлюзовая, 11, Клуб	f	large
34139	27867	1819	Волгоградская область, Калачевский район, село Колпачки, Клубная, 2, Клуб	f	small
34126	27854	1806	Волгоградская область, Калачевский район, село Камыши, Донская, 28, Клуб	f	small
34161	27890	1841	Волгоградская область, Калачевский район, Калач-на-Дону, пер.Озёрный, 9, МОУ Черкасовская ООШ	f	large
34169	27898	1849	Волгоградская область, Калачевский район, Калач-на-Дону, Советская, 5, МОУ СОШ №2	f	large
34163	27892	1843	Волгоградская область, Калачевский район, Калач-на-Дону, Революционная, 421, МОУ СОШ №4	f	large
34162	27891	1842	Волгоградская область, Калачевский район, Калач-на-Дону, Революционная, 421, МОУ СОШ №4	f	large
34171	27900	1851	Волгоградская область, Калачевский район, Калач-на-Дону, Октябрьская, 94 А, МУК Калачевская ГФ	f	large
34170	27899	1850	Волгоградская область, Калачевский район, Калач-на-Дону, Октябрьская, 73, МОУ СОШ №2	f	large
34166	27895	1846	Волгоградская область, Калачевский район, Калач-на-Дону, Октябрьская, 204, Районный ДК	f	large
34165	27894	1845	Волгоградская область, Калачевский район, Калач-на-Дону, Октябрьская, 271, ГОУ ПУ-13	f	large
34164	27893	1844	Волгоградская область, Калачевский район, Калач-на-Дону, Октябрьская, 283, МОУ СОШ №1	f	large
34168	27897	1848	Волгоградская область, Калачевский район, Калач-на-Дону, Краснознаменская, 103 А, Детский сад №1	f	large
34167	27896	1847	Волгоградская область, Калачевский район, Калач-на-Дону, Дубинец, 18 А, МОУ СОШ №3	f	large
29635	19214	176	Астраханская область, Камызяк, А.П. Гужвина, 1	f	medium
34128	27856	1808	Волгоградская область, Калачевский район, село Ильевка, пер.Советский, 11, Ильевская СОШ	f	large
34160	27889	1840	Волгоградская область, Калачевский район, село Заря, Сельский дом культуры	f	medium
34125	27853	1805	Волгоградская область, Калачевский район, село Голубинская, пер.Клубный, 9, Дом культуры	f	medium
34137	27865	1817	Волгоградская область, Калачевский район, село Волгодонской, Советская, 17/1, Дом культуры	f	large
34144	27872	1824	Волгоградская область, Калачевский район, село Вербовский, Донская, 32, Дом культуры	f	small
34141	27869	1821	Волгоградская область, Калачевский район, село Бузиновка, Центральная, 45, Администрация Бузиновского СП	f	small
34152	27880	1832	Волгоградская область, Калачевский район, село Братский, переулок Мирный, 5, Клуб	f	small
34157	27886	1837	Волгоградская область, Калачевский район, село Береславка, Школьная, 2, Администрация Береславског СП	f	large
34156	27885	1836	Волгоградская область, Калачевский район, село Береславка, Ленина, 23 А, Дом культуры Родина	f	large
34158	27887	1838	Волгоградская область, Калачевский район, село Береславка, Волгоградская, 32 А, Клуб Рокотинский	f	medium
34151	27879	1831	Волгоградская область, Калачевский район, село Белоглинский, Трудовой переулок, 5, Сельский клуб	f	small
34117	27845	1736	Волгоградская область, Иловлинский район, село Шохинский, здание Шохинской начальной школы	f	small
34099	27827	1718	Волгоградская область, Иловлинский район, село Ширяевский, здание Ж-Ширяйского сельского клуба	f	small
34098	27826	1717	Волгоградская область, Иловлинский район, село Ширяевский, здание администрации Ширяевского сельского поселения	f	medium
34102	27830	1721	Волгоградская область, Иловлинский район, село Чернозубовка, здание Чернозубовского сельского клуба	f	small
34114	27842	1733	Волгоградская область, Иловлинский район, село Трехостровская, здание Трехостровского сельского Дома культуры	f	medium
34091	27818	1710	Волгоградская область, Иловлинский район, село Тары, здание Таровского сельского клуба	f	small
34118	27846	1737	Волгоградская область, Иловлинский район, село Сиротинская, здание Камышинского сельского клуба	f	small
34116	27844	1735	Волгоградская область, Иловлинский район, село Сиротинская, здание Сиротинского дома культуры	f	medium
34115	27843	1734	Волгоградская область, Иловлинский район, село Сиротинская, здание Хмелевской начальной школы	f	small
34096	27824	1715	Волгоградская область, Иловлинский район, село Песчанка, административное здание ООО Придонье	f	small
34097	27825	1716	Волгоградская область, Иловлинский район, село Озерки, здание Б-Колдаировского культурно-досугового центра	f	small
34120	27848	1739	Волгоградская область, Иловлинский район, село Новогригорьевская, здание Старогригорьевской сельской библиотеки	f	small
34119	27847	1738	Волгоградская область, Иловлинский район, село Новогригорьевская, здание Новогригорьевского Дома культуры	f	medium
34108	27836	1727	Волгоградская область, Иловлинский район, село Медведев, здание Медведевского сельского Дома культуры	f	large
34094	27822	1713	Волгоградская область, Иловлинский район, поселок Лог, здание МОУ Логовская СОШ	f	large
34095	27823	1714	Волгоградская область, Иловлинский район, поселок городского типа Лог, здание Вилтовского сельского клуба	f	small
34093	27821	1712	Волгоградская область, Иловлинский район, поселок городского типа Лог, здание Логовской музыкальной школы	f	large
34106	27834	1725	Волгоградская область, Иловлинский район, село Красноярский, здание Красноярского сельского клуба	f	small
34107	27835	1726	Волгоградская область, Иловлинский район, село Краснодонский, здание Краснодонского сельского Дома культуры	f	medium
34105	27833	1724	Волгоградская область, Иловлинский район, село Кондраши, здание Кондрашовской средней школы	f	medium
34104	27832	1723	Волгоградская область, Иловлинский район, село Кондраши, здание Писаревской начальной школы	f	small
34103	27831	1722	Волгоградская область, Иловлинский район, село Кондраши, здание Бердиевского клуба	f	small
34089	27816	1708	Волгоградская область, Иловлинский район, село Колоцкий, здание Колоцкого сельского клуба	f	small
29515	19100	58	Астраханская область, Ахтубинск, 4А	f	medium
34111	27839	1730	Волгоградская область, Иловлинский район, село Качалинская, здание Качалинской средней школы №1	f	large
34113	27841	1732	Волгоградская область, Иловлинский район, село Качалино, дание клуба санатория Качалинский	f	small
34112	27840	1731	Волгоградская область, Иловлинский район, село Качалино, здание Качалинской средней школы №2	f	small
34110	27838	1729	Волгоградская область, Иловлинский район, село Качалино, здание Широковского сельского клуба	f	small
34109	27837	1728	Волгоградская область, Иловлинский район, село Качалино, здание Фастовского сельского клуба	f	small
34417	28114	2623	Волгоградская область, Иловлинский район, село Каменский, Каменский проезд, сдание СДК	f	small
34172	27819	1852	Волгоградская область, Иловлинский район, Иловля, 14, Дом отдыха, кв.14. Медпункт	f	small
34088	27815	1707	Волгоградская область, Иловлинский район, Иловля, здание Песчанского сельского клуба	f	small
34087	27814	1706	Волгоградская область, Иловлинский район, Иловля, здание офиса ОАО КХ Егорова А.В.	f	medium
34086	27813	1705	Волгоградская область, Иловлинский район, Иловля, здание Иловлинской средней школы №1	f	large
34085	27812	1704	Волгоградская область, Иловлинский район, Иловля, Здание Иловлинской средней школы №2	f	large
34083	27810	1702	Волгоградская область, Иловлинский район, Иловля, здание Центрального детского творчества	f	large
34082	27809	1701	Волгоградская область, Иловлинский район, Иловля, площадь Ленина, 1	f	large
33907	27647	1205	Волгоградская область, Иловлинский район, поселок Городище, площадь Павших Борцов, 2, МКУ Центр культурного обслуживая	f	large
34101	27829	1720	Волгоградская область, Иловлинский район, село Большая Ивановка, здание Большеивановского сельского Дома культуры	f	medium
34100	27828	1719	Волгоградская область, Иловлинский район, село Александровка, здание Александровского сельского Дома культуры	f	medium
34092	27820	1711	Волгоградская область, Иловлинский район, село Авилов, здание конторы ОАО КХ Егорова А.В.	f	small
34060	14663	1621	Волгоградская область, Жирновский район, село Фоменково, Победы, 2	f	small
34062	27789	1623	Волгоградская область, Жирновский район, село Тетеревятка, Молодежная, 36	f	small
34077	27804	1638	Волгоградская область, Жирновский район, село Тарапатино, Молодежная, 7	f	small
34081	27808	1642	Волгоградская область, Жирновский район, село Романовка, Степная, 10	f	small
34066	27793	1627	Волгоградская область, Жирновский район, село Подчинный, Центральная, 3А	f	small
34069	27796	1630	Волгоградская область, Жирновский район, село Песковка, Эльтонская, 27	f	small
34067	27794	1628	Волгоградская область, Жирновский район, село Новинка, Молодежная, 7	f	small
34075	27802	1636	Волгоградская область, Жирновский район, село Новая Бахметьевка, Зеленая, 42	f	small
34054	27751	1615	Волгоградская область, Жирновский район, село Нижняя Добринка, Центральная, 63	f	large
34059	27787	1620	Волгоградская область, Жирновский район, село Недоступов, улица Центральная, 28	f	small
34331	28032	2327	Волгоградская область, Жирновский район, село Моисеево, Здание школы	f	medium
34053	27723	1614	Волгоградская область, Жирновский район, село Мельзавод, Ленина, 6	f	small
34076	27803	1637	Волгоградская область, Жирновский район, село Меловатка, Центральная, 35	f	small
34052	27629	1613	Волгоградская область, Жирновский район, поселок Медведицкий, Фрунзе, 17	f	medium
34068	27795	1629	Волгоградская область, Жирновский район, село Медведица	f	large
34050	27605	1611	Волгоградская область, Жирновский район, Линево, Нефтяников, 33	f	large
34051	27616	1612	Волгоградская область, Жирновский район, поселок Линево, Ленина, 66	f	large
34049	27571	1610	Волгоградская область, Жирновский район, поселок Линево, Карла Маркса, 70	f	large
34057	27212	1618	Волгоградская область, Жирновский район, поселок городского типа Красный Яр, Новая, 104А	f	large
34055	27762	1616	Волгоградская область, Жирновский район, поселок городского типа Красный Яр, Ленина, 64	f	large
34058	27379	1619	Волгоградская область, Жирновский район, поселок Красный Яр, Камышинская, 2А	f	small
34078	27805	1639	Волгоградская область, Жирновский район, село Кленовка, Продольная, 3	f	medium
34043	27784	1604	Волгоградская область, Жирновский район, Жирновск, Строителей, 12	f	large
34041	27782	1602	Волгоградская область, Жирновский район, Жирновск, Советская, 25	f	medium
34047	27421	1608	Волгоградская область, Жирновский район, Жирновск, Мира, 49	f	large
34040	27781	1601	Волгоградская область, Жирновский район, Жирновск, Матросова, 18	f	large
34046	27786	1607	Волгоградская область, Жирновский район, Жирновск, Ленина, 1А	f	medium
34042	27783	1603	Волгоградская область, Жирновский район, Жирновск, Ленина, 9	f	large
34048	27442	1609	Волгоградская область, Жирновский район, Жирновск, 35 лет Победы, 4А	f	small
34044	27442	1605	Волгоградская область, Жирновский район, Жирновск, 35 лет Победы, 4А	f	large
34080	27807	1641	Волгоградская область, Жирновский район, село Ершовка, Школьная, 18	f	small
34070	27797	1631	Волгоградская область, Жирновский район, село Гречихино, Верхняя, 10/1	f	small
34064	27791	1625	Волгоградская область, Жирновский район, село Вишневое, Мира, 11	f	small
34063	27790	1624	Волгоградская область, Жирновский район, село Верхняя Добринка, Центральная, 74	f	medium
34185	27912	1913	Волгоградская область, Жирновский район, село Верхняя Добринка, Рабочая, 23б	f	large
34079	27806	1640	Волгоградская область, Жирновский район, село Бутырка, Центральная, 2	f	small
34061	27788	1622	Волгоградская область, Жирновский район, село Бородачи, Лиманская, 67	f	small
34074	27801	1635	Волгоградская область, Жирновский район, село Большая Князевка, Мира, 1/2	f	small
34072	27799	1633	Волгоградская область, Жирновский район, село Андреевка, Мира, 4	f	small
34065	27792	1626	Волгоградская область, Жирновский район, село Алешники, Центральная, 3А	f	medium
33404	27304	208	Волгоградская область, Жирновский район, село Александровка, улица Центральная, 3, Сельский Дом культуры	f	medium
34020	27759	1518	Волгоградская область, Еланский район, село Щелоковка, здание МОУ Щелоковская НОШ	f	small
34021	27760	1519	Волгоградская область, Еланский район, село Хвощинка, здание МОУ Хвощинская ООШ	f	small
34033	27774	1531	Волгоградская область, Еланский район, село Тростянка, Советская, 27, здание Тростянского СДК	f	medium
34038	27779	1536	Волгоградская область, Еланский район, село Торяное, Боевая, 20, здание МОУ Торяновская НОШ	f	small
34028	27768	1526	Волгоградская область, Еланский район, село Терса, Красная, 45, здание администрации	f	large
34015	27754	1513	Волгоградская область, Еланский район, село Терновое, Ленина, 6, здание администрации	f	medium
34031	27771	1529	Волгоградская область, Еланский район, село Таловка, Центральная, 13, здание Таловского СДК	f	medium
34039	27780	1537	Волгоградская область, Еланский район, село Родинское, Ленинская, 6, здание администрации	f	small
34146	27874	1826	Волгоградская область, Еланский район, село Новопетровский, Солнечная, 44, сельский клуб	f	small
34019	27758	1517	Волгоградская область, Еланский район, село Новодобринка, здание МОУ Новодобринская НОШ	f	small
34014	27753	1512	Волгоградская область, Еланский район, село Набат, Пролетарская, 21, МОУ Набатская ООШ	f	small
34018	27757	1516	Волгоградская область, Еланский район, село Морец, Московская, 96, здание МОУ Морецкая СОШ	f	medium
34032	27772	1530	Волгоградская область, Еланский район, село Красноталовский, Центральная, 48, здание МОУ Красноталовская	f	small
34024	27764	1522	Волгоградская область, Еланский район, село Краишево, Центральная, 4, здание Краишевского СДК	f	medium
34034	27775	1532	Волгоградская область, Еланский район, село Ивановка, Мира, 59, здание администрации	f	small
34027	27767	1525	Волгоградская область, Еланский район, село Журавка, Новосельская, 90а, здание администрации	f	medium
34073	27800	1634	Волгоградская область, Еланский район, село Журавка, Сорокина, 17/2	f	small
34006	27744	1504	Волгоградская область, Еланский район, поселок Елань, Школьная, 2, здание МОУ СОШ № 2	f	large
34010	27748	1508	Волгоградская область, Еланский район, поселок Елань, Первомайская, 1, здание ГУПВО автоколонны №1727	f	small
34008	27746	1506	Волгоградская область, Еланский район, поселок Елань, Мира, 1А, здание МУЗ Еланская ЦРБ	f	small
34005	27743	1503	Волгоградская область, Еланский район, поселок Елань, Ленинская, 63, МОУ ДОД Еланский детский центр	f	large
34003	27741	1501	Волгоградская область, Еланский район, поселок Елань, Ленинская, 95, здание МУ РДК Юбилейный	f	large
34009	27747	1507	Волгоградская область, Еланский район, поселок Елань, Красная, 134, филФГОУ Жирновский нефтяной техникум	f	large
34004	27742	1502	Волгоградская область, Еланский район, поселок Елань, Гоголя, 15, МОУ ООШ № 2	f	large
34012	27750	1510	Волгоградская область, Еланский район, поселок городского типа Елань, Новоселовская, 13, здание МОУ ДОД 	f	large
34013	27752	1511	Волгоградская область, Еланский район, поселок городского типа Елань, Вокзальная, здание ЖД станции Елань-Камышинская	f	large
34011	27749	1509	Волгоградская область, Еланский район, поселок городского типа Елань, Вокзальная, 2, ГОУ Еланский аграрный колледж	f	large
34007	27745	1505	Волгоградская область, Еланский район, Елань, Большая Казанская, 61, здание МОУ ООШ № 1	f	large
34035	27776	1533	Волгоградская область, Еланский район, село Дубовое, Советская, 5, здание МОУ Дубовская СОШ	f	medium
34025	27765	1523	Волгоградская область, Еланский район, село Вязовка, Усадьба школы, 4, здание МОУ Вязовская СОШ	f	large
34026	27766	1524	Волгоградская область, Еланский район, село Вязовка, Мельничная, 1Б, здание Вязовского СДК	f	large
34036	27777	1534	Волгоградская область, Еланский район, село Волково, Новая, 1, Фельдшерско-акушерский пункт	f	small
34017	27756	1515	Волгоградская область, Еланский район, село Водопьяново, Центральная, 11/2, Фельдшерско-акушерский пункт	f	small
34023	27763	1521	Волгоградская область, Еланский район, село Большой Морец, Советская, 39, здание администрации	f	large
34030	27770	1528	Волгоградская область, Еланский район, село Большевик, Микрорайон-1, 10, здание Большевистского СДК	f	large
34016	27755	1514	Волгоградская область, Еланский район, село Березовка, Молодежная, 45, здание Березовского СДК	f	small
34022	27761	1520	Волгоградская область, Еланский район, село Березовка, Ленина, 187, здание Рассветовского СДК	f	medium
34037	27778	1535	Волгоградская область, Еланский район, село Бабинкино, Веселая, 4, здание МОУ Бабинкинская ООШ	f	small
34029	27769	1527	Волгоградская область, Еланский район, село Алявы, Степная, 42, здание администрации	f	small
34001	27739	1435	Волгоградская область, Дубовский район, село Челюскинец, Центральная, 41, Челюскинский сельский клуб	f	small
33989	27727	1423	Волгоградская область, Дубовский район, село Усть-Погожье, Кленовая, 1, МОУ Усть-Погожинская СОШ	f	medium
33990	27728	1424	Волгоградская область, Дубовский район, село Суводская, 13, Суводской СДК	f	small
33987	27725	1421	Волгоградская область, Дубовский район, село Стрельноширокое, Советская, 34, МОУ Стрельношироковская СОШ	f	medium
34230	27956	2016	Волгоградская область, Дубовский район, село Семеновка, здание Семеновской школы	f	small
33998	27736	1432	Волгоградская область, Дубовский район, село Садки, Центральная, 15 , МОУ Садковская ООШ	f	small
33999	27737	1433	Волгоградская область, Дубовский район, село Родники, Мира, 24, Родниковсий сельский клуб)	f	small
33982	27623	1416	Волгоградская область, Дубовский район, село Прямая Балка, Мира, 36, Прямобалкинская ООШ	f	small
33995	27733	1429	Волгоградская область, Дубовский район, село Полунино, Комсомольская, 41 , МОУ Полунинская ООШ	f	small
33979	27720	1413	Волгоградская область, Дубовский район, село Пичуга, Степная, 29 , Пичужинская МОУ СОШ	f	medium
34002	27740	1436	Волгоградская область, Дубовский район, село Пичуга, Песчанная, 5, ФАП ВЛС	f	small
34000	27738	1434	Волгоградская область, Дубовский район, село Петропавловка, Большая, 28, СК с. Петропавловка	f	small
33980	27721	1414	Волгоградская область, Дубовский район, село Песковатка, Московская, 27 , МОУ Песковатская СОШ	f	medium
33981	27722	1415	Волгоградская область, Дубовский район, село Оленье, Центральная, 13, Оленьевский СДК	f	medium
33985	27403	1419	Волгоградская область, Дубовский район, село Малая Ивановка, Центральная, 25, Малоивановский СДК	f	medium
33984	27705	1418	Волгоградская область, Дубовский район, село Лозное, Гагарина, 2, Лозновский СДК	f	medium
33993	27731	1427	Волгоградская область, Дубовский район, село Караваинка, Центральная, 12, Административное здание	f	small
33970	27711	1404	Волгоградская область, Дубовский район, Дубовка, Юбилейная, 44 , Дубовский Райпотребсоюз	f	large
33968	27709	1402	Волгоградская область, Дубовский район, Дубовка, Юбилейная, 115	f	medium
33978	27719	1412	Волгоградская область, Дубовский район, Дубовка, Шевченко, 2, Межпоселковый СОК	f	medium
33973	27714	1407	Волгоградская область, Дубовский район, Дубовка, Советская, 62 , МОУ Дубовская СОШ №1	f	medium
33976	27717	1410	Волгоградская область, Дубовский район, Дубовка, Пугачева, 17 , Дубовское ХПП	f	small
33977	27718	1411	Волгоградская область, Дубовский район, Дубовка, Почтовая, 52 , Дубовская МОУ СОШ №2	f	large
33969	27710	1403	Волгоградская область, Дубовский район, Дубовка, Магистральная, 10, ФГОУ СПО ДЗВК	f	medium
33975	27716	1409	Волгоградская область, Дубовский район, Дубовка, Гагарина, 143, МОУ ООШ Базовая школа	f	medium
33971	27712	1405	Волгоградская область, Дубовский район, Дубовка, 30 лет Победы,, 81	f	large
33983	27645	1417	Волгоградская область, Дубовский район, село Давыдовка, Школьная, 1 , МОУ Давыдовская СОШ	f	medium
33992	27730	1426	Волгоградская область, Дубовский район, село Горный Балыклей, Пушкина, 18 , МОУ Горнобалыклейская СОШ	f	medium
33991	27729	1425	Волгоградская область, Дубовский район, село Горный Балыклей, Крестьянская, 2, МУК Горнобалыклейский СДК	f	large
33986	27724	1420	Волгоградская область, Дубовский район, село Горноводяное, Школьный переулок, 4, МОУ Горноводяновская СОШ	f	medium
33988	27726	1422	Волгоградская область, Дубовский район, село Горная Пролейка, Школьная, 1, МОУ Горнопролейская СОШ	f	medium
33994	27732	1428	Волгоградская область, Дубовский район, село Варькино, Центральная, 11, клуб с. Варькино	f	small
33997	27735	1431	Волгоградская область, Дубовский район, село Бойкие Дворики, Конторская, 25, Сельский клуб х. Бойкие Дворики	f	small
33953	27693	1312	Волгоградская область, Даниловский район, село Сергиевская, здание ДК	f	medium
33960	27700	1319	Волгоградская область, Даниловский район, село Рогачи, здание селького клуба	f	small
33946	27686	1305	Волгоградская область, Даниловский район, село Профсоюзник, здание МСОШ	f	small
33963	27703	1322	Волгоградская область, Даниловский район, село Попов, здание селького клуба	f	small
33950	27690	1309	Волгоградская область, Даниловский район, село Плотников 1-й, здание средней школы	f	medium
33962	27702	1321	Волгоградская область, Даниловский район, село Островская, здание ДК	f	large
33949	27689	1308	Волгоградская область, Даниловский район, село Орехово, здание ДК	f	small
33944	27684	1303	Волгоградская область, Даниловский район, село Миусово, здание сельского клуба	f	small
33957	27697	1316	Волгоградская область, Даниловский район, село Ловягин	f	small
33947	27687	1306	Волгоградская область, Даниловский район, село Лобойково, здание ДК	f	medium
33961	27701	1320	Волгоградская область, Даниловский район, село Кувшинов, здание селького клуба	f	small
33958	27698	1317	Волгоградская область, Даниловский район, село Красный, здание ДК	f	medium
33964	27704	1323	Волгоградская область, Даниловский район, село Каменный, здание школы	f	small
33948	27688	1307	Волгоградская область, Даниловский район, село Каменночерновский, здание сельского клуба	f	small
33954	27694	1313	Волгоградская область, Даниловский район, село Заполянский, здание сельского клуба	f	small
33952	27692	1311	Волгоградская область, Даниловский район, село Заплавка, здание школы	f	small
33943	27683	1302	Волгоградская область, Даниловский район, Даниловка, Комсомольская, 1	f	large
33942	27682	1301	Волгоградская область, Даниловский район, поселок Даниловка, Федорцова, 28	f	large
33966	27707	1325	Волгоградская область, Даниловский район, село Грязнуха, здание школы	f	small
33955	27695	1314	Волгоградская область, Даниловский район, село Горин, здание сельского клуба	f	small
34589	28285	3229	Волгоградская область, Даниловский район, село Гончары, Гончаровская МНОШ	f	small
33945	27685	1304	Волгоградская область, Даниловский район, село Гончары, здание сельского клуба	f	small
33951	27691	1310	Волгоградская область, Даниловский район, село Бобры, здание школы	f	small
33956	27696	1315	Волгоградская область, Даниловский район, село Березовская, здание ДК	f	large
33965	27706	1324	Волгоградская область, Даниловский район, село Белые Пруды, здание школы	f	medium
33959	27699	1318	Волгоградская область, Даниловский район, село Атамановка, здание ДК	f	medium
83908	57334	3101	Москва, Зеленоград, к429а	f	large
33930	27671	1229	Волгоградская область, Городищенский район, поселок Царицын, Центральная, 13, помещение Дом культуры	f	medium
34136	27864	1816	Волгоградская область, Городищенский район, село Степной, улица Центральная, 64 А, Средне-Царицынская ООШ	f	small
33924	27665	1223	Волгоградская область, Городищенский район, село Степной, Центральная, 5, помещение Дом культуры	f	large
33934	27675	1233	Волгоградская область, Городищенский район, село Самофаловка, Советская, 22А, помещение Дом культуры	f	large
33937	27678	1236	Волгоградская область, Городищенский район, село Сады Придонья, Специалистов, 41, Культурно-развлекательный центр	f	medium
33925	27666	1224	Волгоградская область, Городищенский район, село Россошка, Рабочая, 26, павильон для приезжающих	f	small
33927	27668	1226	Волгоградская область, Городищенский район, поселок Радужный, 2-я Продольная, 132, помещение Правление ТСЖ	f	small
33941	27681	1239	Волгоградская область, Городищенский район, село Песковатка, Спортивная, 14, помещение Дом культуры	f	medium
33938	27679	1237	Волгоградская область, Городищенский район, село Паньшино, переулок Советский, 2, Дом культуры	f	medium
33916	27656	1214	Волгоградская область, Городищенский район, село Орловка, Советская, 1Б, средняя школа Орловская	f	large
33931	27672	1230	Волгоградская область, Городищенский район, село Областная сельскохозяйственная опытная станция, улица Молодежная, 51, помещение Дом культуры	f	large
33922	27663	1221	Волгоградская область, Городищенский район, поселок Новый Рогачик, Озерная, 2, средняя школа	f	large
33921	27662	1220	Волгоградская область, Городищенский район, поселок Новый Рогачик, Озерная, 2, средняя школа (левое крыло)	f	large
33920	27661	1219	Волгоградская область, Городищенский район, поселок Новый Рогачик, Ленина, 54, помещение администрации поселка	f	large
33926	27667	1225	Волгоградская область, Городищенский район, село Новая Надежда, Центральная, 1, средняя школа Новонадеждинская	f	medium
33932	27673	1231	Волгоградская область, Городищенский район, село Кузьмичи, Нефтянников, 1, помещение Дом культуры	f	large
33928	27669	1227	Волгоградская область, Городищенский район, село Красный Пахарь, Новосельская, 18, помещение Дом культуры	f	small
33935	27676	1234	Волгоградская область, Городищенский район, Котлубань, Шлихтера, 17, помещение Дом культуры	f	large
33923	27664	1222	Волгоградская область, Городищенский район, село Карповка, 51 Гвардейской дивизии, 5А, средняя школа Карповская	f	large
33919	27660	1218	Волгоградская область, Городищенский район, село Каменный, Ленина, 6, средняя школа 	f	large
33918	27658	1216	Волгоградская область, Городищенский район, поселок Ерзовка, Школьная, 2, средняя школа Ерзовская	f	large
33917	27657	1215	Волгоградская область, Городищенский район, поселок Ерзовка, Молодежная, 4 квартал, 1	f	large
86270	27659	1217	Волгоградская область, Городищенский район, поселок городского типа Ерзовка, Мелиоративная, 2, помещение Администрации поселка	f	small
34148	27876	1828	Волгоградская область, Городищенский район, село Донской, Центральная, 10, МОУ Донская НОШ	f	medium
33933	27674	1232	Волгоградская область, Городищенский район, село Грачи, Ленина, 35, Дом культуры	f	medium
33913	27653	1211	Волгоградская область, Городищенский район, Городище 2, Баррикадная, 2б, дом культуры Разгуляевка	f	large
33905	27644	1203	Волгоградская область, Городищенский район, поселок Городище, проспект Ленина, 8, помещение музея	f	large
33904	27643	1202	Волгоградская область, Городищенский район, поселок Городище, площадь 40-лет Сталинградской битвы, 3, помещение Школы Исскуств	f	large
33903	27642	1201	Волгоградская область, Городищенский район, поселок Городище, площадь 40 лет Сталинградской битвы, 3, районный Дворец культуры	f	large
33906	27646	1204	Волгоградская область, Городищенский район, поселок Городище, Чуйкова, 6А, помещение Средняя школа №1	f	large
33909	27649	1207	Волгоградская область, Городищенский район, поселок Городище, Центральная, 101, помещение ИП Казарян	f	medium
33908	27648	1206	Волгоградская область, Городищенский район, поселок Городище, Промышленная, 2А, помещение кафе Дворик	f	large
33911	27651	1209	Волгоградская область, Городищенский район, поселок Городище, Пархоменко, 35А, помещение Средняя школа №2	f	large
33910	27650	1208	Волгоградская область, Городищенский район, поселок Городище, Октябрьская, 1а, помещение Казпромволга	f	small
33915	27655	1213	Волгоградская область, Городищенский район, поселок Городище, Новоселовская, 2, помещение Средняя школа №3	f	medium
33912	27652	1210	Волгоградская область, Городищенский район, поселок Городище, Краснознаменская, 54, помещение базы ООО Энергострой	f	large
33914	27654	1212	Волгоградская область, Городищенский район, Городище, Демократическая, 35, продовольственный магазин	f	large
33940	27680	1238	Волгоградская область, Городищенский район, село Вертячий, Мира, 58, помещение Дом культуры	f	large
33936	27677	1235	Волгоградская область, Городищенский район, село Варламов, Центральная, 15, средняя школа Варламовская	f	small
33902	27641	1199	Волгоградская область, Волжский городской округ, поселок Краснооктябрьский, Калинина, 1	f	large
33901	27641	1198	Волгоградская область, Волжский городской округ, поселок Краснооктябрьский, Калинина, 1	f	large
33929	27670	1228	Волгоградская область, Волгоград городской округ, село Студено-Яблоневка, Заречная, 10, помещение Дом культуры	f	small
33579	27448	628	Волгоградская область, Волгоград городской округ, село Соляной, МОУ ООШ №79	f	medium
33716	27556	844	Волгоградская область, Волгоград городской округ, село Майский, Лундышева, 1а, контора ФГУП Горная Поляна	f	small
33715	27555	843	Волгоградская область, Волгоград городской округ, Горный, Семушкина, 1, МОУ СОШ №116	f	medium
34677	28353	3526	Волгоградская область, Быковский район, село Солянка, Центральная, 18	f	small
33417	27317	221	Волгоградская область, Быковский район, село Солдатско-Степное, Мира, 50, Администрация Солдат-Степновского с.п	f	medium
33416	27316	220	Волгоградская область, Быковский район, село Садовое, Садовая, 2, Садовский Дом культуры	f	small
33403	27303	207	Волгоградская область, Быковский район, село Раздолье, Центральная, 25, МОУ Раздольевская ООШ	f	small
33414	27314	218	Волгоградская область, Быковский район, поселок городского типа Приморск, Пионерская, 6, МОУ Приморская СОШ	f	large
33415	27315	219	Волгоградская область, Быковский район, поселок городского типа Приморск, Горького, 18, Приморский Дом культуры	f	large
33413	27313	217	Волгоградская область, Быковский район, село Победа, Центральная, 5, МОУ Побединская СОШ	f	medium
34697	28373	3616	Волгоградская область, Быковский район, село Песчаный, здание администрации Песчановского с/п	f	medium
33412	27312	216	Волгоградская область, Быковский район, село Новоникольское, Шурухина, 44, Сельский Дом культуры	f	large
33411	27311	215	Волгоградская область, Быковский район, село Луговая Пролейка, Советская, 60, Адм-ция Луго-кого сельского пос	f	medium
33410	27310	214	Волгоградская область, Быковский район, село Красноселец, переулок Центральный, 5, Красносельский Дом культуры	f	large
33408	27308	212	Волгоградская область, Быковский район, село Кислово, Советская, 8а, Кисловский сельский Дом культуры	f	large
33409	27309	213	Волгоградская область, Быковский район, село Кислово, Песчаная, 19, Сельский Дом культуры Источник	f	large
33418	27318	222	Волгоградская область, Быковский район, село Катричев, Шмарова, 9, МОУ Урало-Ахтубинская СОШ	f	large
33407	27307	211	Волгоградская область, Быковский район, село Зеленый, Сиреневая, 5, МОУ Быковская СОШ № 2	f	medium
34578	28278	3218	Волгоградская область, Быковский район, село Заволжский, Совхозная, 23	f	large
33406	27306	210	Волгоградская область, Быковский район, село Демидов, Советская, 35, МОУ Демидовская СОШ	f	medium
33405	27305	209	Волгоградская область, Быковский район, село Верхний Балыклей, Советская, 16, Сельский Дом культуры	f	large
33400	27300	204	Волгоградская область, Быковский район, поселок городского типа Быково, переулок Набережный, 9, Дом культуры Строитель	f	large
33402	27302	206	Волгоградская область, Быковский район, Быково, Загодзерновская, 17, ОАО Быковское ХПП	f	small
33399	27299	203	Волгоградская область, Быковский район, поселок городского типа Быково, Дзержинского, 95а, Детский сад Солнышко	f	large
33397	27297	201	Волгоградская область, Быковский район, поселок городского типа Быково, Волжская, 37, Центр культуры и досуга	f	large
33398	27298	202	Волгоградская область, Быковский район, поселок городского типа Быково, Мира, 23а, МОУ Быковская СОШ № 1	f	large
33401	27301	205	Волгоградская область, Быковский район, поселок Быково, Строителей, 11, ФГУ Волгоградмеливодхоз	f	medium
34235	27961	2021	Волгоградская область, Быковский район, село Александровка, здание Александровской школы	f	small
34071	27798	1632	Волгоградская область, Быковский район, село Александровка, Центральная, 49	f	medium
33379	27260	103	Волгоградская область, Алексеевский район, село Яминский, Веселый, 10	f	large
33388	27287	112	Волгоградская область, Алексеевский район, село Шарашенский, МОУ Шарашенская средняя общеобразовательная школа 242	f	medium
33381	27280	105	Волгоградская область, Алексеевский район, село Чечеровский, 73А, здание МОУ Чечеринская начальная общеобразовательная школа	f	small
33390	27289	114	Волгоградская область, Алексеевский район, село Усть-Бузулукская, Хоперская, 35,Б	f	large
33393	27293	117	Волгоградская область, Алексеевский район, село Трехложинский, 60, здание МУК Трехложинский культурно-досуговый комплекс	f	small
33391	27290	115	Волгоградская область, Алексеевский район, село Титовский, 66, здание МУК Титовский культурно-досуговый комплекс	f	small
33382	27281	106	Волгоградская область, Алексеевский район, село Стеженский, 101, Здание МОУ Стеженская средняя общеобразовательная школа	f	medium
33389	27288	113	Волгоградская область, Алексеевский район, село Солонцовский, МОУ Солонцовуская средняя общеобразовательная школа 147	f	small
33383	27282	107	Волгоградская область, Алексеевский район, село Самолшинский, 72, здание МУК Самолшинский культурно-досуговый комплекс	f	medium
33395	27295	119	Волгоградская область, Алексеевский район, село Рябовский, 383, здание МОУ Рябовская средняя общеобразовательная школа	f	medium
33394	27294	118	Волгоградская область, Алексеевский район, село Реченский, 56, здание МУК Реченский культурно-досуговый комплекс	f	small
33384	27283	108	Волгоградская область, Алексеевский район, село Поклоновский, здание МОУ Поклоновская основная общеобразовательная школа, 5	f	small
33380	27279	104	Волгоградская область, Алексеевский район, село Ларинский, 72, здание администрации Ларинского сельского поселения,	f	small
33387	27286	111	Волгоградская область, Алексеевский район, село Красный Октябрь, 73, здание МУК Краснооктябрьский культурно-досуговый компкекс	f	medium
33385	27284	109	Волгоградская область, Алексеевский район, село Исакиевский, 52, здание МУК Исакиевский культурно-досуговый комплекс	f	small
34233	27959	2019	Волгоградская область, Алексеевский район, село Ежовка, здание сельского Дома культуры	f	medium
33396	27296	120	Волгоградская область, Алексеевский район, село Ежовка, 31, здание МОУ Ежовская основная общеобразовательная школа	f	small
33386	27285	110	Волгоградская область, Алексеевский район, село Большой Бабинский, 17/2, здание администрации Большебабинского сельского поселения	f	small
33392	27291	116	Волгоградская область, Алексеевский район, село Аржановская, 116, здание МУК Аржановский культурно-досуговый комплекс	f	medium
33378	27251	102	Волгоградская область, Алексеевский район, поселок Алексеевская, Ленина, 44	f	large
33377	27239	101	Волгоградская область, Алексеевский район, поселок Алексеевская, Ленина, 37	f	large
29819	19395	356	Астраханская область, Харабали, Советская, 151	f	large
29810	19387	347	Астраханская область, Харабали, Перовской, 103	f	large
29816	19392	353	Астраханская область, Харабали, Ленина, 18	f	large
29809	19386	346	Астраханская область, Харабали, Интернациональная, 156	f	large
29817	19393	354	Астраханская область, Харабали, Б.Хмельницкого, 5	f	medium
29744	19323	284	Астраханская область, село Солянка, Советская, 129А 	f	large
29484	19070	27	Астраханская область, село Сокрутовка, Калинина, 37	f	medium
29670	19249	211	Астраханская область, село Образцово-Травино, Восточная, 5	f	medium
29772	19349	309	Астраханская область, Нариманов, Центральная, 3	f	large
29774	19351	311	Астраханская область, Нариманов, Волжская, 6А	f	large
29773	19350	310	Астраханская область, Нариманов, Астраханская, 9	f	large
29627	19205	168	Астраханская область, поселок Мумра, Ленина, 20	f	medium
29682	19261	223	Астраханская область, село Красный Яр, Карла Маркса, 19А	f	medium
29633	19211	174	Астраханская область, Камызяк, Молодежная, 32	f	medium
29636	19215	177	Астраханская область, Камызяк, Горького, 67	f	large
29502	19087	45	Астраханская область, Ахтубинск, Финогенова, 11А	f	large
29518	19103	61	Астраханская область, Ахтубинск, Суворова, 1	f	large
29510	19095	53	Астраханская область, Ахтубинск, Ст.Лаврентьева, 6	f	large
29516	19101	59	Астраханская область, Ахтубинск, П.О.Сухого, 4	f	medium
29501	19086	44	Астраханская область, Ахтубинск, Октябрьская, 81	f	large
29507	19092	50	Астраханская область, Ахтубинск, Нестерова, 5	f	large
29517	19102	60	Астраханская область, Ахтубинск, Мира, 47А	f	large
29504	19089	47	Астраханская область, Ахтубинск, Микрорайон, 19а	f	large
29514	19099	57	Астраханская область, Ахтубинск, Котовского, 9	f	large
29513	19098	56	Астраханская область, Ахтубинск, Котовского, 28	f	large
29511	19096	54	Астраханская область, Ахтубинск, Конструкторская, 1А	f	large
29521	19019	64	Астраханская область, Ахтубинск, К.Маркса, 125	f	medium
29509	19094	52	Астраханская область, Ахтубинск, Иванова, 2	f	large
29508	19093	51	Астраханская область, Ахтубинск, Иванова, 6А	f	large
29519	18763	62	Астраханская область, Ахтубинск, Заводская, 187	f	medium
29503	19088	46	Астраханская область, Ахтубинск, Добролюбова, 5	f	large
29500	19085	43	Астраханская область, Ахтубинск, Волгоградская, 41	f	large
29499	19084	42	Астраханская область, Ахтубинск, Волгоградская, 4	f	large
29520	18937	63	Астраханская область, Ахтубинск, Величко, 10	f	large
29505	19090	48	Астраханская область, Ахтубинск, Андреева, 6А	f	large
29784	19362	321	Россия, Астраханская область, Астрахань, Трусовский район, улица Шоссейная, 15/10к1	f	medium
29860	19196	397	Россия, Астраханская область, Астрахань, улица Челюскинцев, 132	f	large
29896	19452	443	Россия, Астраханская область, Астрахань, улица Туркменская, 30	f	large
29895	19452	442	Россия, Астраханская область, Астрахань, улица Туркменская, 30	f	large
29894	19452	441	Россия, Астраханская область, Астрахань, улица Туркменская, 30	f	large
29921	19468	468	Россия, Астраханская область, Астрахань, улица Татищева, 20а	f	large
29989	19514	538	Россия, Астраханская область, Астрахань, Трусовский район, улица Таганская, 36а	f	large
30008	19540	568	Россия, Астраханская область, Астрахань, улица Староастраханская, 90	f	large
29847	19425	383	Россия, Астраханская область, Астрахань, улица Сен-Симона, 31	f	large
134628	94955	588	Россия, Астраханская область, Астрахань, улица Полякова, 19	f	medium
29792	19370	329	Астраханская область, Астрахань, улица Пионерская, 48	f	large
29987	19512	536	Астраханская область, Астрахань, улица Пионерская, 2А	f	large
29986	19511	532	Россия, Астраханская область, Астрахань, улица Панфилова, 36	f	large
29985	19511	531	Россия, Астраханская область, Астрахань, улица Панфилова, 36	f	large
66234	19528	554	Россия, Астраханская область, Астрахань, улица Лепехинская, 49	f	large
66225	19430	405	Россия, Астраханская область, Астрахань, улица Куликова, 61	f	large
29848	19426	384	Россия, Астраханская область, Астрахань, улица Костина, 2	f	large
29936	19476	484	Россия, Астраханская область, Астрахань, улица Звездная, 59к1	f	large
29934	19476	482	Россия, Астраханская область, Астрахань, улица Звездная, 59к1	f	large
66282	19523	548	Россия, Астраханская область, Астрахань, улица Заводская Площадь, 98	f	medium
29967	19500	513	Россия, Астраханская область, Астрахань, улица Боевая, 59а	f	large
29956	19493	504	Астраханская область, Астрахань, улица Боевая, 65А	f	large
29971	19503	517	Россия, Астраханская область, Астрахань, улица Богдана Хмельницкого, 16к1	f	large
29970	19503	516	Россия, Астраханская область, Астрахань, улица Богдана Хмельницкого, 16к1	f	large
29968	19501	514	Астраханская область, Астрахань, улица Богдана Хмельницкого, 35п.1	f	large
29977	18286	523	Россия, Астраханская область, Астрахань, улица Безжонова, 2	f	large
29957	19494	505	Россия, Астраханская область, Астрахань, улица 3-я Рыбацкая, 5	f	large
29910	19462	457	Астраханская область, Астрахань, Яблочкова, 28	f	large
29889	19450	436	Астраханская область, Астрахань, Энергетическая, 13 п.1	f	large
29903	19456	450	Астраханская область, Астрахань, Щукина, 79	f	large
29902	19456	449	Астраханская область, Астрахань, Щукина, 79	f	large
29743	19322	283	Астраханская область, Астрахань, Школьная, 24	f	small
29785	19363	322	Астраханская область, Астрахань, Школьная, 4	f	small
29768	19343	305	Астраханская область, Астрахань, Школьная, 2	f	large
29851	18805	387	Россия, Астраханская область, Астрахань, Кировский район, Шаумяна площадь, 1а	f	large
29855	18849	392	Астраханская область, Астрахань, Шаумяна, 60	f	large
66232	19521	546	Астраханская область, Астрахань, Чкалова, 80а	f	large
29994	19522	547	Астраханская область, Астрахань, Чкалова, 31	f	large
29975	19506	521	Астраханская область, Астрахань, Чигорина, 14А	f	large
29862	19429	404	Астраханская область, Астрахань, Чалабяна, 17	f	large
66277	19544	573	Астраханская область, Астрахань, Химиков, 7	f	large
30011	19543	572	Астраханская область, Астрахань, Химиков, 5А	f	large
30010	19543	571	Астраханская область, Астрахань, Химиков, 5А	f	large
29955	19492	503	Астраханская область, Астрахань, Фунтовское шоссе, 9а	f	large
30014	19545	576	Астраханская область, Астрахань, Тренева, 11	f	large
30013	19545	575	Астраханская область, Астрахань, Тренева, 11	f	large
30012	19545	574	Астраханская область, Астрахань, Тренева, 11	f	large
30001	19532	558	Астраханская область, Астрахань, Толстого, 26	f	large
29925	19471	472	Астраханская область, Астрахань, Татищева, 8а	f	large
29924	19470	471	Астраханская область, Астрахань, Татищева, 8	f	large
29923	19470	470	Астраханская область, Астрахань, Татищева, 8	f	large
29922	19469	469	Астраханская область, Астрахань, Татищева, 16	f	large
66278	19515	539	Астраханская область, Астрахань, Таганская, 34	f	large
29988	19513	537	Астраханская область, Астрахань, Таганская, 36	f	large
134627	94954	413	Астраханская область, Астрахань, Студенческая, 6/1	f	large
29874	19439	418	Астраханская область, Астрахань, Студенческая, 4А	f	large
29871	19438	415	Астраханская область, Астрахань, Студенческая, 6п.1	f	large
29872	19438	416	Астраханская область, Астрахань, Студенческая, 6п.1	f	large
66271	19533	559	Астраханская область, Астрахань, Спортивный переулок, 2	f	large
29883	19446	428	Астраханская область, Астрахань, Софьи Перовской, 103к25	f	large
29900	19454	447	Астраханская область, Астрахань, Соликамская, 8	f	large
29899	19454	446	Астраханская область, Астрахань, Соликамская, 8	f	large
29766	19341	303	Астраханская область, Астрахань, Советская, 58	f	medium
29802	19380	339	Астраханская область, Астрахань, Советская, 19	f	medium
68044	19428	403	Астраханская область, Астрахань, Советская, 23, ФГБОУ ВПО Астраханская государственная консерватория	f	large
30019	19552	584	Астраханская область, Астрахань, Силикатная, 26	f	large
29930	19474	477	Астраханская область, Астрахань, Селенского, 15а	f	large
29929	19474	476	Астраханская область, Астрахань, Селенского, 15а	f	large
29908	19460	455	Астраханская область, Астрахань, Садовских, 3	f	large
29954	19491	502	Астраханская область, Астрахань, Рождественского, 4	f	large
30000	19531	557	Астраханская область, Астрахань, Пушкина, 2	f	large
66237	19550	582	Астраханская область, Астрахань, Промышленная, 3	f	large
29866	14691	402	Астраханская область, Астрахань, Победы, 52	f	large
29865	14691	401	Астраханская область, Астрахань, Победы, 52	f	large
29999	19530	556	Астраханская область, Астрахань, Пирогова, 39	f	large
29984	19510	530	Астраханская область, Астрахань, Немова, 28п.2	f	large
29983	19510	529	Астраханская область, Астрахань, Немова, 28п.2	f	large
29884	19447	429	Россия, Астраханская область, Астрахань, Началовское шоссе, 5	f	large
30007	19539	567	Астраханская область, Астрахань, Нанайская, 23	f	large
29846	19424	382	Астраханская область, Астрахань, Набережная Приволжского Затона, 36	f	large
29952	19489	500	Астраханская область, Астрахань, Н. Островского, 111	f	large
29951	19489	499	Астраханская область, Астрахань, Н. Островского, 111	f	large
29943	19483	491	Астраханская область, Астрахань, Н. Островского, 127	f	large
29939	19479	487	Астраханская область, Астрахань, Н. Островского, 152к1	f	large
29852	18816	389	Астраханская область, Астрахань, Молодой Гвардии, 3	f	large
29746	19325	286	Россия, Астраханская область, Астрахань, Мирный переулок, 19	f	medium
30002	19534	560	Астраханская область, Астрахань, Минина, 54	f	large
30018	19551	583	Астраханская область, Астрахань, Мелиоративная, 2в	f	large
30017	19548	580	Астраханская область, Астрахань, Магистральная, 1	f	large
29948	19487	496	Астраханская область, Астрахань, М.Луконина, 6А	f	large
29947	19487	495	Астраханская область, Астрахань, М.Луконина, 6А	f	large
29926	19472	473	Астраханская область, Астрахань, Ляхова, 11	f	large
134520	19537	562	Астраханская область, Астрахань, Ленинградский переулок, 55	f	large
66281	19537	565	Астраханская область, Астрахань, Ленинградский переулок, 55	f	large
30005	19536	563	Астраханская область, Астрахань, Ленинградский переулок, 55	f	large
66235	19536	564	Астраханская область, Астрахань, Ленинградский переулок, 55	f	large
29461	19047	2	Россия, Воронежская область, Воронеж, Центральный район, площадь Ленина, 2	f	large
29782	19360	319	Астраханская область, Астрахань, Ленина, 48	f	large
29853	18838	391	Астраханская область, Астрахань, Ленина, 17	f	medium
29801	19379	338	Астраханская область, Астрахань, Ленина, 95	f	large
29762	19340	302	Астраханская область, Астрахань, Ленина, 58	f	large
66227	19435	412	Астраханская область, Астрахань, Курская, 55	f	large
29880	19444	425	Астраханская область, Астрахань, Куликова, 46а	f	large
29876	19432	408	Астраханская область, Астрахань, Куликова, 42	f	large
29877	19431	419	Астраханская область, Астрахань, Куликова, 40	f	large
29875	19431	407	Астраханская область, Астрахань, Куликова, 40	f	large
29870	19431	406	Астраханская область, Астрахань, Куликова, 40	f	large
29953	19490	501	Астраханская область, Астрахань, Краснодарская, 43к1	f	large
66228	19437	414	Астраханская область, Астрахань, Красная набережная, 227 а	f	large
66224	19212	398	Астраханская область, Астрахань, Красная набережная, 11	f	medium
29856	18991	393	Астраханская область, Астрахань, Котовского, 6	f	large
29940	19480	488	Астраханская область, Астрахань, Космонавтов, 10к1	f	large
29907	19459	454	Астраханская область, Астрахань, Космонавта В. Комарова, 154а	f	large
29906	19459	453	Астраханская область, Астрахань, Космонавта В. Комарова, 154а	f	large
29905	19458	452	Астраханская область, Астрахань, Космонавта В. Комарова, 53	f	large
29904	19457	451	Астраханская область, Астрахань, Космонавта В. Комарова, 25	f	large
29928	19473	475	Астраханская область, Астрахань, Комсомольская Набережная, 7а	f	large
29927	19473	474	Астраханская область, Астрахань, Комсомольская Набережная, 7а	f	large
29761	19339	301	Астраханская область, Астрахань, Комсомольская, 99	f	medium
66276	19525	551	Астраханская область, Астрахань, Комсомольская, 142	f	large
29931	19475	478	Астраханская область, Астрахань, Коммунистическая, 48	f	large
29863	19291	399	Астраханская область, Астрахань, Коммунистическая, 35	f	large
29858	19104	395	Астраханская область, Астрахань, Кирова, 47	f	large
66274	19519	544	Астраханская область, Астрахань, Капитана Краснова, 26	f	large
29941	19482	489	Астраханская область, Астрахань, Звездная, 15А	f	large
29942	19481	490	Астраханская область, Астрахань, Звездная, 21а	f	large
29938	19478	486	Астраханская область, Астрахань, Звездная, 41п.4	f	large
29937	19478	485	Астраханская область, Астрахань, Звездная, 41п.4	f	large
29935	19477	483	Астраханская область, Астрахань, Звездная, 59к1	f	large
29996	19524	550	Астраханская область, Астрахань, Заводская Площадь, 12А	f	large
29995	19524	549	Астраханская область, Астрахань, Заводская Площадь, 12А	f	large
29893	19451	440	Астраханская область, Астрахань, Жилая, 15	f	large
29892	19451	439	Астраханская область, Астрахань, Жилая, 15	f	large
29891	19451	438	Астраханская область, Астрахань, Жилая, 15	f	large
29890	19451	437	Астраханская область, Астрахань, Жилая, 15	f	large
29786	19364	323	Астраханская область, Астрахань, Есенина, 1	f	large
29963	19497	509	Астраханская область, Астрахань, Дубровинского, 54	f	large
29990	19516	541	Астраханская область, Астрахань, Докучаева, 1	f	large
66231	19516	540	Астраханская область, Астрахань, Докучаева, 1	f	large
66233	19529	555	Астраханская область, Астрахань, Дзержинского, 44	f	large
29946	19486	494	Астраханская область, Астрахань, Джона Рида, 39	f	large
29998	19527	553	Астраханская область, Астрахань, Депутатский переулок, 2К1	f	large
29901	19455	448	Астраханская область, Астрахань, Дальняя, 91	f	large
30006	19538	566	Астраханская область, Астрахань, Грановский переулок, 54	f	large
30009	19541	569	Астраханская область, Астрахань, Гагарина, 12	f	large
66236	19542	570	Астраханская область, Астрахань, Гагарина, 104	f	large
29944	19484	492	Россия, Астраханская область, Астрахань, Воробьева проезд, 14к1	f	large
29992	19518	543	Астраханская область, Астрахань, Водников, 14а	f	large
29991	19517	542	Астраханская область, Астрахань, Водников, 14а	f	large
30016	19547	579	Россия, Астраханская область, Астрахань, Бумажников проспект, 9а	f	large
30015	19547	578	Россия, Астраханская область, Астрахань, Бумажников проспект, 9а	f	large
66273	19546	577	Россия, Астраханская область, Астрахань, Бумажников проспект, 17а	f	large
29920	19467	467	Астраханская область, Астрахань, Ботвина, 32	f	large
29919	19467	466	Астраханская область, Астрахань, Ботвина, 32	f	large
29918	19466	465	Астраханская область, Астрахань, Ботвина, 12В	f	large
30021	19549	581	Астраханская область, Астрахань, Бориса Алексеева, 7	f	large
29911	19463	458	Астраханская область, Астрахань, Бориса Алексеева, 12	f	large
29913	19463	460	Астраханская область, Астрахань, Бориса Алексеева, 12	f	large
29912	19463	459	Астраханская область, Астрахань, Бориса Алексеева, 12	f	large
66272	19445	427	Астраханская область, Астрахань, Бориса Алексеева, 612	f	large
66279	19445	426	Астраханская область, Астрахань, Бориса Алексеева, 612	f	large
29964	19498	510	Астраханская область, Астрахань, Боевая, 59б	f	large
29960	19496	508	Астраханская область, Астрахань, Боевая, 81к1	f	large
29959	19496	507	Астраханская область, Астрахань, Боевая, 81к1	f	large
29958	19495	506	Астраханская область, Астрахань, Боевая, 71п.1	f	large
29972	19504	518	Астраханская область, Астрахань, Богдана Хмельницкого, 3	f	large
29969	19502	515	Астраханская область, Астрахань, Богдана Хмельницкого, 9п.3А	f	large
29981	19508	527	Астраханская область, Астрахань, Безжонова, 103	f	large
66226	19434	411	Астраханская область, Астрахань, Барсовой, 8А	f	large
29867	19433	410	Астраханская область, Астрахань, Барсовой, 8А	f	large
29868	19433	409	Астраханская область, Астрахань, Барсовой, 8А	f	large
29859	19167	396	Астраханская область, Астрахань, Бакинская, 121	f	large
29857	19006	394	Астраханская область, Астрахань, Бакинская, 83	f	large
29945	19485	493	Астраханская область, Астрахань, Ахшарумова, 90	f	large
29909	19461	456	Астраханская область, Астрахань, Ахтубинская, 6А	f	large
68043	18642	385	Астраханская область, Астрахань, Артема Сергеева площадь, 20	f	large
29974	19505	520	Астраханская область, Астрахань, Артезианская, 27/17	f	large
29973	19505	519	Астраханская область, Астрахань, Артезианская, 27/17	f	large
29993	19520	545	Астраханская область, Астрахань, Анатолия Сергеева, 22А	f	large
29976	18035	522	Астраханская область, Астрахань, Александрова, 3	f	large
29864	19307	400	Астраханская область, Астрахань, Академика Королева, 40	f	large
29850	18774	386	Астраханская область, Астрахань, Адмиралтейская, 21	f	large
29982	19509	528	Астраханская область, Астрахань, Адмирала Нахимова, 62	f	large
29980	19507	526	Астраханская область, Астрахань, Адмирала Нахимова, 58	f	large
29979	18376	525	Астраханская область, Астрахань, Адмирала Нахимова, 44	f	large
29978	18376	524	Астраханская область, Астрахань, Адмирала Нахимова, 44	f	large
29897	19453	444	Астраханская область, Астрахань, Агрономическая, 15/14	f	large
29898	19453	445	Астраханская область, Астрахань, Агрономическая, 15/14	f	large
29914	19464	461	Астраханская область, Астрахань, Авиационная, 14а	f	large
29887	19448	434	Астраханская область, Астрахань, 8-я Железнодорожная, 57а	f	large
29886	19448	433	Астраханская область, Астрахань, 8-я Железнодорожная, 57а	f	large
29997	19526	552	Астраханская область, Астрахань, 5-я Керченская, 12	f	large
68042	19441	424	Астраханская область, Астрахань, 11-й Красной Армии, 3	f	large
66229	19440	422	Астраханская область, Астрахань, 11-й Красной Армии, 11	f	large
29878	17903	420	Астраханская область, Астрахань, 11-й Красной Армии, 3	f	large
66230	17903	423	Астраханская область, Астрахань, 11-й Красной Армии, 3	f	large
29917	19465	464	Астраханская область, Астрахань, 1-я Перевозная, 94	f	large
29916	19465	463	Астраханская область, Астрахань, 1-я Перевозная, 94	f	large
29915	19465	462	Астраханская область, Астрахань, 1-я Перевозная, 94	f	large
29888	19449	435	Астраханская область, Астрахань, 1-я Железнодорожная, 10	f	large
29833	19409	370	Астраханская область, Черноярский район, село Черный Яр, пл.Ленина, 2	f	large
29835	19411	372	Астраханская область, Черноярский район, село Черный Яр, пл. Ленина, 6	f	large
29836	19412	373	Астраханская область, Черноярский район, село Черный Яр, Комиссара Савельева, 2А	f	large
29834	19410	371	Астраханская область, Черноярский район, село Черный Яр, Комиссара Савельева, 27	f	large
29845	19423	381	Астраханская область, Черноярский район, село Ушаковка, Школьная, 9	f	large
29841	19418	377	Астраханская область, Черноярский район, село Ступино, 1-го Мая, 19	f	small
29839	19415	375	Астраханская область, Черноярский район, село Старица, пл. Мира, 2а	f	medium
29844	19421	380	Астраханская область, Черноярский район, село Солодники, пер. Кооперативный, 12	f	large
29832	19408	369	Астраханская область, Черноярский район, село Соленое Займище, Победы, 2А	f	large
29840	19416	376	Астраханская область, Черноярский район, село Поды, 1-го Мая, 8	f	medium
29843	19420	379	Астраханская область, Черноярский район, село Каменный Яр, Советская, 64	f	medium
29837	19413	374	Астраханская область, Черноярский район, село Зубовка, Комсомольская, 4	f	medium
29842	19419	378	Астраханская область, Черноярский район, село Вязовка, Ленина, 45	f	medium
29808	19385	345	Астраханская область, Харабалинский район, село Чапчачи, Железнодорожная, 13	f	small
29827	19404	364	Астраханская область, Харабалинский район, село Хошеутово, Советская, 25	f	large
29814	19389	351	Астраханская область, Харабалинский район, Харабали, Терешковой, 11	f	large
29812	19389	349	Астраханская область, Харабалинский район, Харабали, Терешковой, 11	f	large
29813	19390	350	Астраханская область, Харабалинский район, Харабали, Советская, 13	f	large
29811	19388	348	Астраханская область, Харабалинский район, Харабали, Лесхозная, 71	f	large
29815	19391	352	Астраханская область, Харабалинский район, Харабали, Ленина, 29	f	large
29818	19394	355	Астраханская область, Харабалинский район, Харабали, Гагарина, 118	f	large
29820	19396	357	Астраханская область, Харабалинский район, село Тамбовка, Октябрьская, 38	f	large
29825	19402	362	Астраханская область, Харабалинский район, село Сероглазово, Светлая, 3	f	small
29823	19398	360	Астраханская область, Харабалинский район, село Селитренное, Советская, 53	f	large
29806	19383	343	Астраханская область, Харабалинский район, село Сасыколи, Ленина, 96	f	large
29805	19383	342	Астраханская область, Харабалинский район, село Сасыколи, Ленина, 96	f	large
29830	19407	367	Астраханская область, Харабалинский район, село Речное, Школьная, 1	t	medium
29803	19381	340	Астраханская область, Харабалинский район, село Михайловка, Ленина, 26 Б	f	medium
29828	19405	365	Астраханская область, Харабалинский район, село Лапас, Советская, 8	f	medium
29807	19384	344	Астраханская область, Харабалинский район, село Кочковатка, Почтовая, 70	f	large
29829	19406	366	Астраханская область, Харабалинский район, село Заволжское, Набережная, 23	f	large
29824	19400	361	Астраханская область, Харабалинский район, село Вольное, Советская, 31	f	large
29804	19382	341	Астраханская область, Харабалинский район, село Бугор, Школьная, 8	f	small
29822	18609	359	Астраханская область, Харабалинский район, село Ашулук	f	large
29821	19397	358	Астраханская область, Харабалинский район, село Ашулук, Привокзальная, 50	f	small
29826	19403	363	Астраханская область, Харабалинский район, село Ахтубинка, Школьная, 26	f	small
29780	19357	317	Астраханская область, Приволжский район,, с.Яманцуг, Центральная, 4а	f	small
29800	19378	337	Астраханская область, Приволжский район, с.Растопуловка, 50-летия Победы, 6	f	large
29797	19375	334	Астраханская область, Приволжский район, п.Ассадулаево, Парковая, 9	f	medium
29794	19372	331	Астраханская область, Приволжский район, село Яксатово, Юность, 5	f	large
29793	19371	330	Астраханская область, Приволжский район, село Яксатово, Школьная, 1	f	large
29788	19366	325	Астраханская область, Приволжский район, село Фунтово 1-е, Чехова, 9	f	large
29796	19374	333	Астраханская область, Приволжский район, село Татарская Башмаковка, Ленина, 41	f	large
29798	19376	335	Астраханская область, Приволжский район, Стеклозавода, Ленина, 2	f	medium
29799	19377	336	Астраханская область, Приволжский район, село Пойменный, Советская, 17а	f	large
29779	19356	316	Астраханская область, Приволжский район, село Начало, Советская, 30	f	medium
29783	19361	320	Астраханская область, Приволжский район, село Начало, Ленина, 13	f	large
29787	19365	324	Астраханская область, Приволжский район, село Кирпичный Завод №1, Клубная, 33	f	large
29778	19355	315	Астраханская область, Приволжский район, село Килинчи, Ленина, 12	f	large
77754	4308	1080	Тульская область, Тула, Революции, 14	f	large
29791	19369	328	Астраханская область, Приволжский район, село Евпраксино, Ленина, 25	f	large
29790	19368	327	Астраханская область, Приволжский район, село Водяновка, Молодежная, 20	f	medium
29789	19367	326	Астраханская область, Приволжский район, село Веселая Грива, Садовая, 39	f	small
29781	19358	318	Астраханская область, Приволжский район, село Болдинский, Школьная, 1	f	small
29777	19354	314	Астраханская область, Приволжский район, село Бирюковка, Юбилейная, 14	f	large
29795	19373	332	Астраханская область, Приволжский район, село Атал, Фрунзе, 11	f	medium
29758	19336	298	Астраханская область, Наримановский район, село Янго-Аскер, М.Джалиля, 17	f	small
29760	19338	300	Астраханская область, Наримановский район, село Туркменка, Советская, 47	f	small
29742	19321	282	Астраханская область, Наримановский район, село Тулугановка, Вересаева, 3	f	medium
29752	19330	292	Астраханская область, Наримановский район, село Тинаки, Санаторная, ФГУ ЦСР ФССРФ	f	medium
29751	19329	291	Астраханская область, Наримановский район, Рассвет, Советская, 31	f	medium
29753	19331	293	Астраханская область, Наримановский район, село Разночиновка, Горького, 1	f	large
29770	19346	307	Астраханская область, Наримановский район, село Прикаспийский, Ленина, 47	f	large
29756	19334	296	Астраханская область, Наримановский район, село Петропавловка, Набережная, 9	f	small
29767	19342	304	Астраханская область, Наримановский район, село Новокучергановка, Кирова, 13А	f	small
29775	19352	312	Астраханская область, Наримановский район, село Николаевка, Советская, 62	f	large
29754	19332	294	Астраханская область, Наримановский район, село Нижнелебяжье, Гагарина, 45	f	small
134626	94953	308	Астраханская область, Наримановский район, Нариманов, Школьная, 7	f	large
29759	19337	299	Астраханская область, Наримановский район, село Линейное, Ленина, 103	f	large
29757	19335	297	Астраханская область, Наримановский район, село Курченко, Ленина, 73	f	small
29749	19327	289	Астраханская область, Наримановский район, село Волжское, Почтовая, 23	f	large
29748	19327	288	Астраханская область, Наримановский район, село Волжское, Почтовая, 23	f	large
29750	19328	290	Астраханская область, Наримановский район, село Верхнелебяжье, Школьная, 12	f	small
29769	19345	306	Астраханская область, Наримановский район, село Буруны, Коммунистическая, 1	f	large
29755	19333	295	Астраханская область, Наримановский район, село Барановка, Пионерская, 36	f	medium
29737	19316	277	Астраханская область, Лиманский район, село Яр-Базар, Иванова, 66	f	small
29722	19300	262	Астраханская область, Лиманский район, село Яндыки, Кирова, 113 Б	f	large
29721	19299	261	Астраханская область, Лиманский район, село Яндыки, Кирова, 122А	f	large
29741	19320	281	Астраханская область, Лиманский район, село Судачье, Полевая	f	small
29733	19312	273	Астраханская область, Лиманский район, Село Зензели, Советская, 53В	f	large
29735	19314	275	Астраханская область, Лиманский район, Село Басы, Школьная, 50	f	medium
29727	19305	267	Астраханская область, Лиманский район, село Рынок, Мира, 7	f	small
29739	19318	279	Астраханская область, Лиманский район, село Проточное, Октябрьская, 22	f	medium
29729	19308	269	Астраханская область, Лиманский район, село Промысловка, Ленина, 115	f	large
29720	19298	260	Астраханская область, Лиманский район, село Песчаное, Молодежная, 12/1	f	small
29723	19301	263	Астраханская область, Лиманский район, село Оля, Советская, 4	f	large
29732	19311	272	Астраханская область, Лиманский район, село Михайловка, Кооперативная, 16	f	medium
29716	19294	256	Астраханская область, Лиманский район, поселок Лиман, Победы, 36	f	large
29718	19296	258	Астраханская область, Лиманский район, поселок Лиман, Космонавтов, 49	f	large
29719	19297	259	Астраханская область, Лиманский район, поселок городского типа Лиман, Ленина, 11	f	large
29717	19295	257	Астраханская область, Лиманский район, поселок городского типа Лиман, Ленина, 45	f	large
29724	19302	264	Астраханская область, Лиманский район, село Лесное, Свердлова, 68	f	large
29740	19319	280	Астраханская область, Лиманский район, село Кряжевое, Колхозная, 47	f	medium
29734	19313	274	Астраханская область, Лиманский район, село Караванное, Советская, 1	f	large
29736	19315	276	Астраханская область, Лиманский район, село Камышово, Советская, 152	f	medium
83905	57334	3098	Москва, Зеленоград, к429а	f	large
29738	19317	278	Астраханская область, Лиманский район, село Заречное, Советская, 110	f	large
29726	19304	266	Астраханская область, Лиманский район, село Забурунное, Горького, 21	f	small
29728	19306	268	Астраханская область, Лиманский район, село Вышка, Октябрьская, 21	f	small
29731	19310	271	Астраханская область, Лиманский район, село Воскресеновка, Южная, 22	f	small
29730	19309	270	Астраханская область, Лиманский район, село Бударино, Мира, 2	f	medium
29725	19303	265	Астраханская область, Лиманский район, село Бирючья Коса, Советская, 42	f	medium
29705	19284	246	Астраханская область, Красноярский район, с.Новоурусовка, Ленина, 21	f	medium
29698	19277	239	Астраханская область, Красноярский район, пос.Топал, Набережная, 12	f	small
29713	19292	254	Астраханская область, Красноярский район, село Ясын-Сокан, Набережная, 64	f	small
29711	19290	252	Астраханская область, Красноярский район, село Шмагино, Мира, 12/1	f	small
29701	19280	242	Астраханская область, Красноярский район, село Черемуха, Елизарова, 21Б	f	medium
29706	19285	247	Астраханская область, Красноярский район, село Тальниковый, Школьная, 1	t	small
29692	19271	233	Астраханская область, Красноярский район, село Сеитовка, Юбилейная, 21	f	small
29700	19279	241	Астраханская область, Красноярский район, село Малый Арал, Набережная, 7	f	small
29689	19268	230	Астраханская область, Красноярский район, село Кривой Бузан, Советская, 24	f	medium
29685	19264	226	Астраханская область, Красноярский район, село Красный Яр, Советская, 10	f	large
29684	19263	225	Астраханская область, Красноярский район, село Красный Яр, Мордовцева, 18	f	large
29686	19265	227	Астраханская область, Красноярский район, село Красный Яр, Леонова, 17	f	large
29681	19260	222	Астраханская область, Красноярский район, село Красный Яр, Ленинская, 2	f	large
29687	19266	228	Астраханская область, Красноярский район, село Красный Яр, З.Ананьевой, 51А	f	medium
29680	19259	221	Астраханская область, Красноярский район, село Красный Яр, Братская, 1А	f	medium
29688	19267	229	Астраханская область, Красноярский район, село Красный Яр, Береговая, 25	f	small
29683	19262	224	Астраханская область, Красноярский район, село Красный Яр, Ахтубинская, 1	f	large
29709	19288	250	Астраханская область, Красноярский район, село Кошелевка, Заречная, 17	f	small
29696	19275	237	Астраханская область, Красноярский район, село Комсомольский, Степная, 39А	f	medium
29699	19278	240	Астраханская область, Красноярский район, село Караозек, Центральная, 22	f	small
29714	19293	255	Астраханская область, Красноярский район, село Забузан, Советская, 15Б	f	large
29697	19276	238	Астраханская область, Красноярский район, село Досанг, Привокзальная, 50	f	medium
29712	18598	253	Астраханская область, Красноярский район, село Джанай, Мира, 6	f	medium
29695	19274	236	Астраханская область, Красноярский район, село Вишневый, Центральная, 9	f	small
29710	19289	251	Астраханская область, Красноярский район, село Верхний Бузан, Ленина, 1	f	large
29708	19287	249	Астраханская область, Красноярский район, село Ватажное, Гагарина, 31Б	f	large
29693	19272	234	Астраханская область, Красноярский район, село Бузан-Пристань, Волгоградская, 2	f	medium
29704	19283	245	Астраханская область, Красноярский район, село Бузан, Советская, 7а	f	medium
29694	19273	235	Астраханская область, Красноярский район, село Бахаревский, Заречная, 1	t	small
29690	19269	231	Астраханская область, Красноярский район, село Бакланье, Иришева, 8	t	small
29703	19282	244	Астраханская область, Красноярский район, село Байбек, Советская, 10А	f	medium
29691	19270	232	Астраханская область, Красноярский район, село Алча, Октябрьская, 23	f	medium
29707	19286	248	Астраханская область, Красноярский район, село Аллайский, Школьная, 1	t	small
29702	19281	243	Астраханская область, Красноярский район, село Аксарайский, Набережная, 37	f	medium
29654	19232	195	Астраханская область, Камызякский район, п.Азовский, улица Молодежная, 1	f	small
29658	19236	199	Астраханская область, Камызякский район, село Чапаево, Восточная, 14	f	small
29679	19258	220	Астраханская область, Камызякский район, село Чаган, Школьная, 1	f	large
29664	19242	205	Астраханская область, Камызякский район, село Хмелевка, Ленина, 24	t	small
29678	19257	219	Астраханская область, Камызякский район, село Успех, Дорожная, 11б	t	small
29677	19256	218	Астраханская область, Камызякский район, село Увары, Ксенофонтова, 22	f	medium
29647	19226	188	Астраханская область, Камызякский район, село Тузуклей, Школьная, 27а	f	medium
29648	19227	189	Астраханская область, Камызякский район, село Тузуклей, Ленина, 53	f	medium
29649	19228	190	Астраханская область, Камызякский район, село Трехизбенка, Джамбула, 35	t	small
29645	19224	186	Астраханская область, Камызякский район, село Станья, Советская, 52а	t	small
29651	19229	192	Астраханская область, Камызякский район, село Сизова Грива, Маяковского, 14	t	small
29656	19234	197	Астраханская область, Камызякский район, село Семибугры, Курманова, 10	f	large
29674	19253	215	Астраханская область, Камызякский район, село Самосделка, Советская, 17	f	large
29652	19230	193	Астраханская область, Камызякский район, село Раздор, Степная, 33	f	large
29673	19252	214	Астраханская область, Камызякский район, село Полдневое, Братьев Фоминых, 55	f	medium
29641	19220	182	Астраханская область, Камызякский район, село Парыгино, Джамбула, 16	t	small
29666	19245	207	Астраханская область, Камызякский район, село Октябрьский, Рыбацкая, 32	t	small
29644	19223	185	Астраханская область, Камызякский район, село Обуховский, Садовая, 21а	t	small
29669	19248	210	Астраханская область, Камызякский район, село Образцово-Травино, Хлебникова, 69	f	large
29667	19246	208	Астраханская область, Камызякский район, село Никольское, Мира, 11а	f	medium
29672	19251	213	Астраханская область, Камызякский район, село Нижненикольский, Комсомольская, 82	t	small
29662	19240	203	Астраханская область, Камызякский район, село Нижнекалиновский, Джамбула, 30	t	small
29665	19243	206	Астраханская область, Камызякский район, село Лебяжье, Степная, 95	f	medium
29668	19247	209	Астраханская область, Камызякский район, село Комаровка, Мира, 31	f	small
29646	19225	187	Россия, Астраханская область, Камызякский район, поселок Кировский	f	large
29675	19254	216	Астраханская область, Камызякский район, село Качкаринский, Садовая, 24	t	small
29655	19233	196	Астраханская область, Камызякский район, село Каспий, Придорожная, 1	t	small
29642	19221	183	Астраханская область, Камызякский район, село Караульное, Молодежная, 31	f	medium
29640	19219	181	Астраханская область, Камызякский район, село Каралат, Ленина, 62	f	medium
29632	19210	173	Астраханская область, Камызякский район, Камызяк, Ульянова, 10	f	large
29634	19213	175	Астраханская область, Камызякский район, Камызяк, Тараканова, 4	f	medium
29639	19218	180	Астраханская область, Камызякский район, Камызяк, Пушкина, 90	f	large
29638	19217	179	Астраханская область, Камызякский район, Камызяк, Максима Горького, 89	f	large
29630	19208	171	Астраханская область, Камызякский район, Камызяк, Любича, 16	f	large
29629	19207	170	Астраханская область, Камызякский район, Камызяк, Любича, 9а	f	large
29631	19209	172	Астраханская область, Камызякский район, Камызяк, Курмангазы, 22	f	medium
29637	19216	178	Астраханская область, Камызякский район, Камызяк, Горького, 75	f	large
29663	19241	204	Астраханская область, Камызякский район, село Иванчуг, Васильева, 45	f	large
29643	19222	184	Астраханская область, Камызякский район, село Затон, Абая, 83а	f	medium
29653	19231	194	Астраханская область, Камызякский район, село Застенка, Степная, 9а	f	small
29661	19239	202	Астраханская область, Камызякский район, Жан-Аул, Школьная, 26	f	medium
29650	18576	191	Астраханская область, Камызякский район, село Грушево, Степная, 2	f	small
29671	19250	212	Астраханская область, Камызякский район, село Гандурино, Молодежная, 4	f	small
29660	19238	201	Астраханская область, Камызякский район, поселок Волго-Каспийский, Ленина, 1	f	large
29659	19237	200	Астраханская область, Камызякский район, село Верхнекалиновский, Набережная, 106	f	large
29657	19235	198	Астраханская область, Камызякский район, село Бирючек, Степная, 12	t	small
29676	19255	217	Астраханская область, Камызякский район, село Алексеевка, Набережная, 45	t	small
29608	19186	149	Астраханская область, Икрянинский район, село Ямное, Школьная, 21	f	small
29622	19200	163	Астраханская область, Икрянинский район, село Чулпан, Ленина, 115	f	medium
29615	19193	156	Астраханская область, Икрянинский район, село Хмелевой, Мичурина, 14	f	small
29614	19192	155	Астраханская область, Икрянинский район, село Федоровка, Пионерская, 27	f	medium
29611	19189	152	Астраханская область, Икрянинский район, поселок Трудфронт, Ленина, 6	f	large
29609	19187	150	Астраханская область, Икрянинский район, село Троицкий, Гагарина, 19	f	small
29625	19203	166	Астраханская область, Икрянинский район, село Товарный, Пионерский переулок, 13	f	medium
29623	19201	164	Астраханская область, Икрянинский район, село Староволжское, Пушкина, 46В	f	small
29603	19181	144	Астраханская область, Икрянинский район, село Сергино, Садовая, 15	t	small
29610	19188	151	Астраханская область, Икрянинский район, село Сергиевка, Советская, 38	f	small
29621	19199	162	Астраханская область, Икрянинский район, село Седлистое, Советская, 37	f	medium
29612	19190	153	Астраханская область, Икрянинский район, село Светлое, Колхозная, 1Б	t	small
29619	19197	160	Астраханская область, Икрянинский район, поселок Оранжереи, Первомайская, 102	t	medium
29617	19195	158	Астраханская область, Икрянинский район, поселок Оранжереи, Кирова, 2	f	medium
29618	19195	159	Астраханская область, Икрянинский район, поселок Оранжереи, Кирова, 2	f	large
29616	19194	157	Астраханская область, Икрянинский район, поселок Оранжереи, Кирова, 17	f	medium
29604	19182	145	Астраханская область, Икрянинский район, село Озерное, Степная, 7	f	small
29595	19173	136	Астраханская область, Икрянинский район, село Ново-Булгары, Тукая, 4	f	small
29613	19191	154	Астраханская область, Икрянинский район, село Ниновка, Советская, 56	f	medium
29626	19204	167	Астраханская область, Икрянинский район, поселок Мумра, Крупской, 18	f	large
29607	19185	148	Астраханская область, Икрянинский район, село Маячное, 70 лет Октября, 1	f	medium
29590	19169	131	Астраханская область, Икрянинский район, поселок Красные Баррикады, Мира, 2	f	large
29591	19169	132	Астраханская область, Икрянинский район, поселок Красные Баррикады, Мира, 2	f	large
29605	19183	146	Астраханская область, Икрянинский район, село Карабулак, Зеленая, 11А	t	small
29598	19176	139	Астраханская область, Икрянинский район, село Икряное, Пионерская, 24	f	large
29597	19175	138	Астраханская область, Икрянинский район, село Икряное, О.Кошевого, 28	f	large
29600	19178	141	Астраханская область, Икрянинский район, село Икряное, Молодежная, 1	f	large
29599	19177	140	Астраханская область, Икрянинский район, село Икряное, Гастелло, 40	f	large
29596	19174	137	Астраханская область, Икрянинский район, село Икряное, 1-го Мая, 21	f	large
29628	19206	169	Астраханская область, Икрянинский район, село Зюзино, Советская, 19	f	small
29624	19202	165	Астраханская область, Икрянинский район, село Житное, Пушкина, 20	f	large
29602	19180	143	Астраханская область, Икрянинский район, село Восточное, Школьная, 6	f	medium
29620	19198	161	Астраханская область, Икрянинский район, село Вахромеево, Волжская, 51	t	small
29601	19179	142	Астраханская область, Икрянинский район, село Боркино, Ленина, 10	t	small
29606	19184	147	Астраханская область, Икрянинский район, село Бекетовка, Степная, 8	f	small
29593	19171	134	Астраханская область, Икрянинский район, село Бахтемир, Калинина, 3	f	large
29594	19172	135	Астраханская область, Икрянинский район, село Анатолия Зверева, Садовая, 16	f	small
29592	19170	133	Астраханская область, Икрянинский район, село Алгаза, Победы, 19 А	f	small
29580	19158	121	Астраханская область, Енотаевский район, село Федоровка, Ленина/Садовая, 14/2	f	medium
29572	19150	113	Астраханская область, Енотаевский район, село Табун-Арал, Зеленая, 19	t	small
29570	19148	111	Астраханская область, Енотаевский район, село Сероглазка, Колхозная, 18	f	small
29584	19162	125	Астраханская область, Енотаевский район, село Пришиб, Мира, 33, МУ Пришибинский СДК	f	medium
29568	19146	109	Астраханская область, Енотаевский район, село Новострой, Колхозная, 16	t	small
29586	19164	127	Астраханская область, Енотаевский район, поселок Никольское, Московская, 42	f	large
29585	19163	126	Астраханская область, Енотаевский район, поселок Никольское, Московская, 21, МУК Дом культуры	f	large
29581	19159	122	Астраханская область, Енотаевский район, село Михайловка, Олега Кошевого, 14	f	small
29571	19149	112	Астраханская область, Енотаевский район, село Ленино, Набережная, 17	f	medium
29573	19151	114	Астраханская область, Енотаевский район, село Косика, 1 Мая, 11А	f	small
29582	19160	123	Астраханская область, Енотаевский район, село Копановка, Ленина, 40а	f	medium
29579	19157	120	Астраханская область, Енотаевский район, село Ивановка, Ленина, 53	f	medium
29567	19145	108	Астраханская область, Енотаевский район, село Замьяны, Зверобоева, 12	f	large
29578	19156	119	Астраханская область, Енотаевский район, село Енотаевка, Чернышевского, 30	f	large
29577	19155	118	Астраханская область, Енотаевский район, село Енотаевка, Чернышевского, 19 б	f	large
29576	19154	117	Астраханская область, Енотаевский район, село Енотаевка, Мусаева, 55	f	large
29587	19165	128	Астраханская область, Енотаевский район, село Грачи, Советская, 63, Грачевский СДК	f	medium
29574	19152	115	Астраханская область, Енотаевский район, село Восток, Октябрьская, 10	f	medium
29569	19147	110	Астраханская область, Енотаевский район, село Волжский, Ленина, 11	f	large
29575	19153	116	Астраханская область, Енотаевский район, село Владимировка, А.Кенжиева, 18	f	medium
29583	19161	124	Астраханская область, Енотаевский район, село Ветлянка, Кирова, 20а, администрация	f	small
29557	19135	98	Астраханская область, Володарский район, село Ямное, Новоямнинская, 1	t	small
29566	19144	107	Астраханская область, Володарский район, село Яблонка, Школьная, 54	f	small
29534	19114	75	Астраханская область, Володарский район, село Цветное, Молодежная, 25	f	medium
29554	19132	95	Астраханская область, Володарский район, село Тюрино, Набережная, 19	f	small
29562	19140	103	Астраханская область, Володарский район, село Тумак, Боевая, 1А	f	large
29559	19137	100	Астраханская область, Володарский район, село Тулугановка, Молодежная, 7	f	medium
29550	19128	91	Астраханская область, Володарский район, село Трубный, Комсомольская, 26	f	medium
29561	19139	102	Астраханская область, Володарский район, село Тишково, Советская, 9	f	large
29536	19116	77	Астраханская область, Володарский район, село Сорочье, И.Алтынсарина, 63	f	medium
29563	19141	104	Астраханская область, Володарский район, село Сизый Бугор, Нариманова, 172	f	large
29565	19143	106	Астраханская область, Володарский район, село Сахма, Заречная, 71	t	small
29555	19133	96	Астраханская область, Володарский район, село Самойловский, Заводская, 2а	t	small
29556	19134	97	Астраханская область, Володарский район, село Разбугорье, Д.Нурпеисовой, 36	f	small
29544	19122	85	Астраханская область, Володарский район, село Новый Рычан, Центральная, 9	f	medium
29527	19130	93	Астраханская область, Володарский район, село Новокрасное, Советская, 17	f	small
29530	19125	88	Астраханская область, Володарский район, село Нововасильево, Жукова, 25	f	small
134519	94412	82	Астраханская область, Володарский район, село Новинка, Центральная, 21	f	medium
29560	19138	101	Астраханская область, Володарский район, село Нижняя Султановка, Школьная, 7а	f	small
29528	19123	86	Астраханская область, Володарский район, село Мултаново, Центральная, 10	f	medium
29546	19109	70	Астраханская область, Володарский район, село Марфино, Проходная, 3	f	large
29547	19110	71	Астраханская область, Володарский район, село Марфино, Победы, 41	f	large
29543	19121	84	Астраханская область, Володарский район, село Маково, Мыльникова, 24	f	medium
29549	19127	90	Астраханская область, Володарский район, село Лебяжье, Бакушина, 18а	f	small
29542	18321	83	Астраханская область, Володарский район, село Крутое, Школьная, 22	f	medium
29551	19129	92	Астраханская область, Володарский район, село Костюбе, Набережная, 2	t	small
29540	19120	81	Астраханская область, Володарский район, село Коровье, Юрия Суюнчалиева, 16в	t	small
29552	19131	94	Астраханская область, Володарский район, село Козлово, 30 лет Победы, 2а	f	large
29538	19118	79	Астраханская область, Володарский район, село Камардан, Гагарина, 8	f	small
29548	19126	89	Астраханская область, Володарский район, село Калинино, Ленина, 9а	f	medium
29539	19119	80	Астраханская область, Володарский район, село Казенный Бугор, Школьная, 6	t	small
29588	19166	129	Астраханская область, Володарский район, село Ильинка, Пионерская, 85	f	large
29589	19168	130	Астраханская область, Володарский район, село Ильинка, Ленина, 33	f	large
29533	19113	74	Астраханская область, Володарский район, село Зеленга, Советская, 32	f	large
29526	19108	69	Астраханская область, Володарский район, поселок Володарский, Чехова, 5А	f	large
29523	19105	66	Астраханская область, Володарский район, поселок Володарский, Суворова, 3	f	large
29522	18203	65	Астраханская область, Володарский район, поселок Володарский, Победы, 2	f	large
29525	19107	68	Астраханская область, Володарский район, поселок Володарский, Маяковского, 44	f	large
29524	19106	67	Астраханская область, Володарский район, поселок Володарский, Алешина, 4а	f	large
29558	19136	99	Астраханская область, Володарский район, село Винный, Лати Каримова, 2	f	medium
29531	19111	72	Астраханская область, Володарский район, село Большой Могой, Советская, 48	f	medium
29532	19112	73	Астраханская область, Володарский район, село Болдырево, Молодежный, 12	f	small
29529	19124	87	Астраханская область, Володарский район, село Блиново, Абая, 58	t	small
29564	19142	105	Астраханская область, Володарский район, село Ахтерек, Набережная, 85	t	small
29537	19117	78	Астраханская область, Володарский район, село Алтынжар, Центральная, 26	f	large
29535	19115	76	Астраханская область, Володарский район, село Алексеевка, Г.Жукова, 1	t	small
29480	19065	23	Астраханская область, Ахтубинский район, село Успенка, Школьная, 15	f	medium
29487	19073	30	Астраханская область, Ахтубинский район, село Удачное, пер.Коммунальный, 6	f	medium
29498	19083	41	Астраханская область, Ахтубинский район, село Средний Баскунчак, Космонавтов, 44	f	small
29745	19324	285	Астраханская область, Ахтубинский район, село Солянка, Ленина, 3Б	f	large
29747	19326	287	Астраханская область, Ахтубинский район, село Солянка, Геологическая, 65, кв.15	f	large
29471	19056	14	Астраханская область, Ахтубинский район, Село Садовое, Набережная, 154 А	f	small
29470	19055	13	Астраханская область, Ахтубинский район, Село Садовое, Набережная, 62	f	small
29477	19062	20	Астраханская область, Ахтубинский район, село Пологое Займище, Братская, 5	f	small
29478	19063	21	Астраханская область, Ахтубинский район, село Пологое Займище, 60 лет СССР, 19	f	medium
29479	19064	22	Астраханская область, Ахтубинский район, село Покровка, Почтовая, 14	f	medium
29485	19071	28	Астраханская область, Ахтубинский район, село Пироговка, Ленина, 106	f	medium
29482	19067	25	Астраханская область, Ахтубинский район, село Новониколаевка, Молодежная, 1	f	medium
29497	19082	40	Россия, Астраханская область, Ахтубинский район, поселок Нижний Баскунчак	f	medium
29496	19081	39	Астраханская область, Ахтубинский район, поселок Нижний Баскунчак, М.Горького, 27	f	large
29475	19060	18	Астраханская область, Ахтубинский район, село Капустин Яр, Советская, 134Б	f	medium
29473	19036	16	Астраханская область, Ахтубинский район, село Капустин Яр, Октябрьская, 4	f	medium
29476	19061	19	Астраханская область, Ахтубинский район, село Капустин Яр, Московская, 90	f	medium
29472	19058	15	Астраханская область, Ахтубинский район, село Капустин Яр, Лесная, 37	f	medium
29474	19059	17	Астраханская область, Ахтубинский район, село Капустин Яр, Кирова, 8	f	medium
29486	19072	29	Астраханская область, Ахтубинский район, село Золотуха, Ленина, 42	f	large
29465	19051	6	Астраханская область, Ахтубинский район, Знаменск, улица Волгоградская, 14-А	f	large
29466	19052	7	Астраханская область, Ахтубинский район, Знаменск, проспект 9 Мая, 2Б	f	large
29468	19053	9	Астраханская область, Ахтубинский район, Знаменск, Янгеля, 5	f	large
29467	19053	8	Астраханская область, Ахтубинский район, Знаменск, Янгеля, 5	f	large
29463	19049	4	Астраханская область, Ахтубинский район, Знаменск, Пионерская, 2А	f	large
29462	19048	3	Астраханская область, Ахтубинский район, Знаменск, Ленина, 43	f	large
29464	19050	5	Астраханская область, Ахтубинский район, Знаменск, Волгоградская, 12А	f	large
29460	19046	1	Астраханская область, Ахтубинский район, Знаменск, Ватутина, 16	f	large
29469	19054	10	Астраханская область, Ахтубинский район, Знаменск, Академика Янгеля, 8	f	large
29494	19079	37	Астраханская область, Ахтубинский район, поселок Верхний Баскунчак, Степная, 75	f	large
29493	19078	36	Астраханская область, Ахтубинский район, поселок Верхний Баскунчак, Советская, 36	f	medium
29492	19077	35	Астраханская область, Ахтубинский район, поселок Верхний Баскунчак, Советская, 30	f	medium
29495	19080	38	Астраханская область, Ахтубинский район, поселок Верхний Баскунчак, Рабочая, 2	f	large
29491	19076	34	Астраханская область, Ахтубинский район, поселок Верхний Баскунчак, Джамбула, 18	f	medium
77753	4308	1079	Тульская область, Тула, Революции, 14	f	large
29490	19075	33	Астраханская область, Ахтубинский район, поселок Верхний Баскунчак, Джамбула, 22А	f	medium
29489	19074	32	Астраханская область, Ахтубинский район, поселок Верхний Баскунчак, Абаева, 17	f	medium
29488	18674	31	Астраханская область, Ахтубинский район, село Верблюжий, Школьная, 1	t	small
29483	19069	26	Астраханская область, Ахтубинский район, село Болхуны, Школьная, 20	f	large
29481	19066	24	Астраханская область, Ахтубинский район, село Батаевка, Школьная, 1	f	small
80825	14563	872	Ярославская область, пгт Лесная Поляна, 37, Дом культуры	f	large
131094	14307	611	Ярославская область, д. Заболотье, Школьная, 1, УИК: д. Веретево, ул. Лесная, д.5	f	small
80554	14001	231	Ярославская область, Ярославль, поселок Прибрежный, 18	f	large
80553	14000	230	Ярославская область, Ярославль, поселок Октябрьский, 19	f	large
80531	13977	199	Ярославская область, Ярославль, улица Юности, 15	f	large
80530	13977	198	Ярославская область, Ярославль, улица Юности, 15	f	large
80557	14003	234	Ярославская область, Ярославль, улица Щепкина, 8	f	large
80556	14003	233	Ярославская область, Ярославль, улица Щепкина, 8	f	large
80555	14002	232	Ярославская область, Ярославль, улица Щепкина, 10	f	large
80537	13981	205	Ярославская область, Ярославль, улица Чкалова, 34	f	large
80522	13974	190	Ярославская область, Ярославль, улица Чкалова, 26	f	large
80521	13974	189	Ярославская область, Ярославль, улица Чкалова, 26	f	large
80366	13747	20	Ярославская область, Ярославль, улица Урицкого, 32а	f	large
80365	13747	19	Ярославская область, Ярославль, улица Урицкого, 32а	f	large
80363	13747	17	Ярославская область, Ярославль, улица Урицкого, 32а	f	large
80364	13747	18	Ярославская область, Ярославль, улица Урицкого, 32а	f	large
80516	13971	184	Ярославская область, Ярославль, улица Тургенева, 14	f	large
80382	13885	36	Ярославская область, Ярославль, улица Туманова, 18в	f	large
80381	13885	35	Ярославская область, Ярославль, улица Туманова, 18в	f	large
80380	13885	34	Ярославская область, Ярославль, улица Туманова, 18в	f	large
80408	13893	62	Ярославская область, Ярославль, улица Труфанова, 25а	f	large
80406	13893	60	Ярославская область, Ярославль, улица Труфанова, 25а	f	large
80407	13893	61	Ярославская область, Ярославль, улица Труфанова, 25а	f	large
80369	13880	23	Ярославская область, Ярославль, улица Труфанова, 4	f	large
80368	13880	22	Ярославская область, Ярославль, улица Труфанова, 4	f	large
80367	13880	21	Ярославская область, Ярославль, улица Труфанова, 4	f	large
80504	13961	171	Ярославская область, Ярославль, улица Стачек, 53	f	large
80503	13961	170	Ярославская область, Ярославль, улица Стачек, 53	f	large
80466	13931	130	Ярославская область, Ярославль, улица Собинова, 22	f	large
80575	14015	252	Ярославская область, Ярославль, улица Слепнева, 26	f	large
80515	13970	183	Ярославская область, Ярославль, улица Свердлова, 62	f	large
80429	13909	90	Ярославская область, Ярославль, улица Саукова, 5	f	large
80428	13909	89	Ярославская область, Ярославль, улица Саукова, 5	f	large
80427	13909	88	Ярославская область, Ярославль, улица Саукова, 5	f	large
80426	13908	87	Ярославская область, Ярославль, улица Саукова, 13	f	large
80425	13908	86	Ярославская область, Ярославль, улица Саукова, 13	f	large
80479	13941	143	Ярославская область, Ярославль, улица Салтыкова-Щедрина, 75	f	large
80478	13941	142	Ярославская область, Ярославль, улица Салтыкова-Щедрина, 75	f	large
80489	13951	155	Ярославская область, Ярославль, улица Рыкачева, 1	f	large
80471	13936	135	Ярославская область, Ярославль, улица Победы, 46	f	large
80484	13944	148	Ярославская область, Ярославль, улица Павлика Морозова, 3	f	large
80483	13944	147	Ярославская область, Ярославль, улица Павлика Морозова, 3	f	large
80507	13963	174	Ярославская область, Ярославль, улица Маланова, 14	f	large
80488	13950	154	Ярославская область, Ярославль, улица Курчатова, 5	f	large
80525	13975	193	Ярославская область, Ярославль, улица Кудрявцева, 28	f	large
80524	13975	192	Ярославская область, Ярославль, улица Кудрявцева, 28	f	large
80523	13975	191	Ярославская область, Ярославль, улица Кудрявцева, 28	f	large
80572	14007	249	Ярославская область, Ярославль, улица Кривова, 4	f	large
80571	14007	248	Ярославская область, Ярославль, улица Кривова, 4	f	large
80562	14007	239	Ярославская область, Ярославль, улица Кривова, 4	f	large
80457	13920	118	Ярославская область, Ярославль, улица Комарова, 1а	f	large
80588	14022	265	Ярославская область, Ярославль, улица Калинина, 37а	f	large
80587	14022	264	Ярославская область, Ярославль, улица Калинина, 37а	f	large
80586	14022	263	Ярославская область, Ярославль, улица Калинина, 37а	f	large
80845	14021	266	Ярославская область, Ярославль, улица Калинина, 35а	f	large
80585	14021	262	Ярославская область, Ярославль, улица Калинина, 35а	f	large
80584	14021	261	Ярославская область, Ярославль, улица Калинина, 35а	f	large
80536	13979	204	Ярославская область, Ярославль, улица Жукова, 7а	f	large
80535	13979	203	Ярославская область, Ярославль, улица Жукова, 7а	f	large
80370	13881	24	Ярославская область, Ярославль, улица Елены Колесовой, 70	f	large
80371	13881	25	Ярославская область, Ярославль, улица Елены Колесовой, 70	f	large
80361	13823	15	Ярославская область, Ярославль, улица Елены Колесовой, 38	f	large
80362	13823	16	Ярославская область, Ярославль, улица Елены Колесовой, 38	f	large
80400	13891	54	Ярославская область, Ярославль, улица Громова, 36	f	large
80401	13891	55	Ярославская область, Ярославль, улица Громова, 36	f	large
80402	13891	56	Ярославская область, Ярославль, улица Громова, 36	f	large
80567	14011	244	Ярославская область, Ярославль, улица Гоголя, 7	f	large
80566	14011	243	Ярославская область, Ярославль, улица Гоголя, 7	f	large
80568	14011	245	Ярославская область, Ярославль, улица Гоголя, 7	f	large
80509	13965	176	Ярославская область, Ярославль, улица Бахвалова, 3	f	large
80510	13965	177	Ярославская область, Ярославль, улица Бахвалова, 3	f	large
80350	13874	4	Ярославская область, Ярославль, улица 1905-го года, 6	f	large
80565	14010	242	Ярославская область, Ярославль, проспект Фрунзе, 8	f	large
80552	13999	229	Ярославская область, Ярославль, проспект Фрунзе, 75а	f	large
80551	13999	228	Ярославская область, Ярославль, проспект Фрунзе, 75а	f	large
80518	13972	186	Ярославская область, Ярославль, проспект Ленина, 24а	f	large
80517	13972	185	Ярославская область, Ярославль, проспект Ленина, 24а	f	large
80514	13969	182	Ярославская область, Ярославль, проспект Ленина, 27	f	large
80513	13969	181	Ярославская область, Ярославль, проспект Ленина, 27	f	large
80386	13887	40	Ярославская область, Ярославль, проспект Дзержинского, 21	f	large
80424	13907	85	Ярославская область, Ярославль, проспект Авиаторов, 84	f	large
80423	13907	84	Ярославская область, Ярославль, проспект Авиаторов, 84	f	large
80422	13907	83	Ярославская область, Ярославль, проспект Авиаторов, 84	f	large
80416	13901	75	Ярославская область, Ярославль, проспект Авиаторов, 37	f	large
80581	14019	258	Ярославская область, Ярославль, проезд Ушакова, 11	f	large
80580	14019	257	Ярославская область, Ярославль, проезд Ушакова, 11	f	large
80577	14016	254	Ярославская область, Ярославль, проезд Подвойского, 11	f	large
80576	14016	253	Ярославская область, Ярославль, проезд Подвойского, 11	f	large
80410	13894	64	Ярославская область, Ярославль, проезд Моторостроителей, 10	f	large
80409	13894	63	Ярославская область, Ярославль, проезд Моторостроителей, 10	f	large
80414	13894	68	Ярославская область, Ярославль, проезд Моторостроителей, 10	f	large
80413	13894	67	Ярославская область, Ярославль, проезд Моторостроителей, 10	f	large
80412	13894	66	Ярославская область, Ярославль, проезд Моторостроителей, 10	f	large
80411	13894	65	Ярославская область, Ярославль, проезд Моторостроителей, 10	f	large
80583	14020	260	Ярославская область, Ярославль, проезд Матросова, 9	f	large
80582	14020	259	Ярославская область, Ярославль, проезд Матросова, 9	f	large
80436	13912	97	Ярославская область, Ярославль, проезд Доброхотова, 8	f	large
80437	13912	98	Ярославская область, Ярославль, проезд Доброхотова, 8	f	large
80435	13912	96	Ярославская область, Ярославль, проезд Доброхотова, 8	f	large
80753	14331	639	Ярославская область, Ярославль, Ярославская, 92	f	large
80752	14330	638	Ярославская область, Ярославль, Ярославская, 86	f	large
80448	13915	109	Ярославская область, Ярославль, Школьный проезд, 15	f	large
80447	13915	108	Ярославская область, Ярославль, Школьный проезд, 15	f	large
80446	13915	107	Ярославская область, Ярославль, Школьный проезд, 15	f	large
80445	13914	106	Ярославская область, Ярославль, Школьный проезд, 13	f	large
80444	13914	105	Ярославская область, Ярославль, Школьный проезд, 13	f	large
80443	13914	104	Ярославская область, Ярославль, Школьный проезд, 13	f	large
80442	13914	103	Ярославская область, Ярославль, Школьный проезд, 13	f	large
80463	13929	127	Ярославская область, Ярославль, Чайковского, 55	f	large
131110	14321	629	Московская область, городской округ Лосино-Петровский, деревня Осеево, Центральная улица, 25	f	small
80526	13976	194	Ярославская область, Ярославль, Угличская улица, 60	f	large
80528	13976	196	Ярославская область, Ярославль, Угличская улица, 60	f	large
80529	13976	197	Ярославская область, Ярославль, Угличская улица, 60	f	large
80527	13976	195	Ярославская область, Ярославль, Угличская улица, 60	f	large
80473	13938	137	Ярославская область, Ярославль, Угличская улица, 1/51	f	large
80482	13943	146	Ярославская область, Ярославль, Угличская, 27	f	large
80358	13878	12	Ярославская область, Ярославль, Тутаевское шоссе, 13	f	large
80351	13875	5	Ярославская область, Ярославль, Тутаевское шоссе, 74	f	large
80538	13990	214	Ярославская область, Ярославль, Туговская, 11	f	large
80403	13892	57	Ярославская область, Ярославль, Труфанова, 21а	f	large
80405	13892	59	Ярославская область, Ярославль, Труфанова, 21а	f	large
80404	13892	58	Ярославская область, Ярославль, Труфанова, 21а	f	large
80379	13884	33	Ярославская область, Ярославль, Труфанова, 16	f	large
80378	13884	32	Ярославская область, Ярославль, Труфанова, 16	f	large
80546	13996	223	Ярославская область, Ярославль, Театральная, 21	f	large
80545	13996	222	Ярославская область, Ярославль, Театральная, 21	f	large
80547	13996	224	Ярославская область, Ярославль, Театральная, 21	f	large
80415	13900	74	Ярославская область, Ярославль, Тверицкая набережная, 58а	f	large
80564	14009	241	Ярославская область, Ярославль, Суздальское шоссе, 15	f	large
80563	14008	240	Ярославская область, Ярославль, Суздальское шоссе, 1	f	large
130893	13899	73	Ярославская область, Ярославль, Станция Урочь, 10	f	medium
80548	13997	225	Ярославская область, Ярославль, Спортивная, 4	f	large
80455	13919	116	Ярославская область, Ярославль, Спартаковская улица, 7	f	large
80456	13919	117	Ярославская область, Ярославль, Спартаковская улица, 7	f	large
130895	13904	78	Ярославская область, Ярославль, Союзная, 141	f	small
80461	13927	125	Ярославская область, Ярославль, Советская улица, 14/2	f	large
80512	13968	180	Ярославская область, Ярославль, Советская, 71	f	large
80511	13967	179	Ярославская область, Ярославль, Советская, 68	f	large
80579	14018	256	Ярославская область, Ярославль, Слепнева, 14	f	large
80574	14014	251	Ярославская область, Ярославль, Слепнева, 26	f	large
80475	13939	139	Ярославская область, Ярославль, Свободы, 77	f	large
80474	13939	138	Ярославская область, Ярославль, Свободы, 77	f	large
80470	13935	134	Ярославская область, Ярославль, Свободы, 46	f	large
80550	13998	227	Ярославская область, Ярославль, Светлая улица, 36	f	large
80549	13998	226	Ярославская область, Ярославль, Светлая улица, 36	f	large
131106	14317	625	Ленинградская область, Выборгский район, посёлок Рощино, Садовая улица	f	small
80481	13942	145	Ярославская область, Ярославль, Рыбинская улица, 51	f	large
80480	13942	144	Ярославская область, Ярославль, Рыбинская улица, 51	f	large
80468	13933	132	Ярославская область, Ярославль, Республиканская улица, 108	f	large
80465	13930	129	Ярославская область, Ярославль, Республиканская улица, 42	f	large
80464	13930	128	Ярославская область, Ярославль, Республиканская улица, 42	f	large
80459	13925	123	Ярославская область, Ярославль, Революционная улица, 5	f	large
130899	13945	149	Ярославская область, Ярославль, Привокзальная площадь, 1а	f	small
80452	13917	113	Ярославская область, Ярославль, Панфилова, 9а	f	large
80451	13917	112	Ярославская область, Ярославль, Панфилова, 9а	f	large
80497	13955	163	Ярославская область, Ярославль, Павлова, 6	f	large
80496	13955	162	Ярославская область, Ярославль, Павлова, 6	f	large
80492	13953	158	Ярославская область, Ярославль, Нефтяников, 26	f	large
80493	13953	159	Ярославская область, Ярославль, Нефтяников, 26	f	large
80491	13953	157	Ярославская область, Ярославль, Нефтяников, 26	f	large
80573	14013	250	Ярославская область, Ярославль, Московский проспект, 155	f	large
80570	14012	247	Ярославская область, Ярославль, Московский проспект, 151	f	large
80569	14012	246	Ярославская область, Ярославль, Московский проспект, 151	f	large
80499	13958	166	Ярославская область, Ярославль, Московский проспект, 28	f	large
80498	13956	164	Ярославская область, Ярославль, Московский проспект, 88	f	large
80487	13949	153	Ярославская область, Ярославль, Московский проспект, 92	f	large
80486	13949	152	Ярославская область, Ярославль, Московский проспект, 92	f	large
80744	14288	592	Московская область, Волоколамский район, Волоколамск, Пролетарская улица, 2	f	large
80506	13962	173	Ярославская область, Ярославль, Маланова, 10	f	large
80505	13962	172	Ярославская область, Ярославль, Маланова, 10	f	large
80485	13946	150	Ярославская область, Ярославль, Магистральная, 50	f	large
80502	13960	169	Ярославская область, Ярославль, Лесная улица, 12	f	large
80391	13889	45	Ярославская область, Ярославль, Ленинградский проспект, 68а	f	large
80392	13889	46	Ярославская область, Ярославль, Ленинградский проспект, 68а	f	large
80390	13889	44	Ярославская область, Ярославль, Ленинградский проспект, 68а	f	large
80389	13889	43	Ярославская область, Ярославль, Ленинградский проспект, 68а	f	large
80388	13889	42	Ярославская область, Ярославль, Ленинградский проспект, 68а	f	large
80395	13888	49	Ярославская область, Ярославль, Ленинградский проспект, 64а	f	large
80394	13888	48	Ярославская область, Ярославль, Ленинградский проспект, 64а	f	large
80393	13888	47	Ярославская область, Ярославль, Ленинградский проспект, 64а	f	large
80396	13888	50	Ярославская область, Ярославль, Ленинградский проспект, 64а	f	large
80387	13888	41	Ярославская область, Ярославль, Ленинградский проспект, 64а	f	large
80377	13883	31	Ярославская область, Ярославль, Ленинградский проспект, 87	f	large
80376	13883	30	Ярославская область, Ярославль, Ленинградский проспект, 87	f	large
80348	13872	2	Ярославская область, Ярославль, Красноперевальский переулок, 4	f	large
80347	13872	1	Ярославская область, Ярославль, Красноперевальский переулок, 4	f	large
80458	13921	119	Ярославская область, Ярославль, Колышкина, 47	f	large
80421	13906	82	Ярославская область, Ярославль, Клубная улица, 62	f	large
80420	13906	81	Ярославская область, Ярославль, Клубная улица, 62	f	large
80419	13905	80	Ярославская область, Ярославль, Клубная улица, 19	f	large
80418	13905	79	Ярославская область, Ярославль, Клубная улица, 19	f	large
80558	14004	235	Ярославская область, Ярославль, Индустриальный переулок, 10	f	large
80544	13995	221	Ярославская область, Ярославль, Ильинская, 14	f	large
80543	13995	220	Ярославская область, Ярославль, Ильинская, 14	f	large
80542	13995	219	Ярославская область, Ярославль, Ильинская, 14	f	large
80561	14006	238	Ярославская область, Ярославль, Звездная улица, 11	f	large
80560	14006	237	Ярославская область, Ярославль, Звездная улица, 11	f	large
80360	13879	14	Ярославская область, Ярославль, Елены Колесовой, 26	f	large
80359	13879	13	Ярославская область, Ярославль, Елены Колесовой, 26	f	large
131125	14338	646	Ярославская область, Ярославль, Дачная, 91	f	medium
80375	13882	29	Ярославская область, Ярославль, Громова, 10а	f	large
80374	13882	28	Ярославская область, Ярославль, Громова, 10а	f	large
80373	13882	27	Ярославская область, Ярославль, Громова, 10а	f	large
80372	13882	26	Ярославская область, Ярославль, Громова, 10а	f	large
80460	13926	124	Ярославская область, Ярославль, Волкова, 5	f	large
80780	14452	758	республика Удмуртская, Кезский район, село Каменники	f	large
80540	13993	217	Ярославская область, Ярославль, Верхняя, 5а	f	large
80501	13959	168	Ярославская область, Ярославль, Большая Федоровская улица, 62	f	large
80500	13959	167	Ярославская область, Ярославль, Большая Федоровская улица, 62	f	large
80477	13940	141	Ярославская область, Ярославль, Большая Октябрьская улица, 79	f	large
80476	13940	140	Ярославская область, Ярославль, Большая Октябрьская улица, 79	f	large
80469	13934	133	Ярославская область, Ярославль, Большая Октябрьская улица, 64а	f	large
80349	13873	3	Ярославская область, Ярославль, Большая Любимская улица, 71	f	large
80355	13876	9	Ярославская область, Ярославль, Блюхера, 74	f	large
80354	13876	8	Ярославская область, Ярославль, Блюхера, 74	f	large
80353	13876	7	Ярославская область, Ярославль, Блюхера, 74	f	large
80352	13876	6	Ярославская область, Ярославль, Блюхера, 74	f	large
80398	13890	52	Ярославская область, Ярославль, Архангельский проезд, 13	f	large
77752	4308	1078	Тульская область, Тула, Революции, 14	f	large
80399	13890	53	Ярославская область, Ярославль, Архангельский проезд, 13	f	large
80397	13890	51	Ярославская область, Ярославль, Архангельский проезд, 13	f	large
80450	13916	111	Ярославская область, Ярославль, Алмазная улица, 25	f	large
80449	13916	110	Ярославская область, Ярославль, Алмазная улица, 25	f	large
80534	13978	202	Ярославская область, Ярославль, Автозаводская, 69	f	large
80533	13978	201	Ярославская область, Ярославль, Автозаводская, 69	f	large
80532	13978	200	Ярославская область, Ярославль, Автозаводская, 69	f	large
80541	13994	218	Ярославская область, Ярославль, 2-я Портовая улица, 1	f	large
80539	13992	216	Ярославская область, Ярославль, 2-я Полянская, 25	f	large
80520	13973	188	Ярославская область, Ярославль, Щапова, 14	f	large
80519	13973	187	Ярославская область, Ярославль, Щапова, 14	f	large
80383	13886	37	Ярославская область, Ярославль, Туманова, 10в	f	large
80385	13886	39	Ярославская область, Ярославль, Туманова, 10в	f	large
80384	13886	38	Ярославская область, Ярославль, Туманова, 10в	f	large
80462	13928	126	Ярославская область, Ярославль, Терешковой, 20	f	large
80578	14017	255	Ярославская область, Ярославль, Слепнева, 14б	f	large
80438	13913	99	Ярославская область, Ярославль, Серго Орджоникидзе, 35а	f	large
80441	13913	102	Ярославская область, Ярославль, Серго Орджоникидзе, 35а	f	large
80440	13913	101	Ярославская область, Ярославль, Серго Орджоникидзе, 35а	f	large
80439	13913	100	Ярославская область, Ярославль, Серго Орджоникидзе, 35а	f	large
80467	13932	131	Ярославская область, Ярославль, Свободы, 15	f	large
80472	13937	136	Ярославская область, Ярославль, Салтыкова-Щедрина, 42а	f	large
80559	14005	236	Ярославская область, Ярославль, Пирогова, 12	f	large
80434	13911	95	Ярославская область, Ярославль, Папанина, 10а	f	large
80433	13911	94	Ярославская область, Ярославль, Папанина, 10а	f	large
80432	13911	93	Ярославская область, Ярославль, Папанина, 10а	f	large
80431	13911	92	Ярославская область, Ярославль, Папанина, 10а	f	large
80430	13911	91	Ярославская область, Ярославль, Папанина, 10а	f	large
80495	13954	161	Ярославская область, Ярославль, Павлова, 37	f	large
80494	13954	160	Ярославская область, Ярославль, Павлова, 37	f	large
80417	13902	76	Ярославская область, Ярославль, Маяковского, 54	f	large
80453	13918	114	Ярославская область, Ярославль, Лебедева, 3а	f	large
80454	13918	115	Ярославская область, Ярославль, Лебедева, 3а	f	large
80490	13952	156	Ярославская область, Ярославль, Зелинского, 6	f	large
80357	13877	11	Ярославская область, Ярославль, Блюхера, 32а	f	large
80356	13877	10	Ярославская область, Ярославль, Блюхера, 32а	f	large
80508	13964	175	Ярославская область, Ярославль, Бахвалова, 1г	f	large
131235	14508	814	Ярославская область, деревня Ченцы, Звездная, 2, Школа	f	small
131240	14521	832	Ярославская область, Углич, микрорайон Мирный, 23	f	medium
80817	14439	822	Ярославская область, Углич, микрорайон Мирный, 1	f	large
80816	14411	821	Ярославская область, Углич, Ярославское шоссе, 10а	f	large
80818	14485	823	Ярославская область, Углич, Ярославская, 47	f	large
80819	14499	824	Ярославская область, Углич, Студенческий городок, 2	f	large
80814	14513	819	Ярославская область, Углич, Старостина, 12	f	large
80813	14512	818	Ярославская область, Углич, Рыбинское шоссе, 39	f	large
80820	14514	825	Ярославская область, Углич, Опарина, 2	f	large
80822	14516	827	Ярославская область, Углич, Ленинское шоссе, 1	f	large
80821	14515	826	Ярославская область, Углич, Ленинское шоссе, 1а	f	large
80815	14373	820	Ярославская область, Углич, Красноармейский бульвар, 3	f	large
131239	14520	831	Ярославская область, Углич, Кирова, 83	f	medium
80812	14511	817	Ярославская область, Углич, Зины Золотовой, 31а	f	large
80823	14517	828	Ярославская область, Углич, Волжская, 17а	f	large
131238	14519	830	Ярославская область, Углич, Вокзальная, 20а	f	medium
80824	14518	829	Ярославская область, Углич, 1 линия Камышевского шоссе, 16а	f	large
80610	14033	292	Ярославская область, Рыбинск, проспект Мира, 27	f	large
80609	14033	291	Ярославская область, Рыбинск, проспект Мира, 27	f	large
80608	14033	290	Ярославская область, Рыбинск, проспект Мира, 27	f	large
80631	14038	313	Ярославская область, Рыбинск, проспект Ленина, 181	f	large
80629	14038	311	Ярославская область, Рыбинск, проспект Ленина, 181	f	large
77634	4227	944	Тульская область, Тула, Пушкина, 19	f	large
80601	14029	283	Ярославская область, Рыбинск, проспект 50 лет Октября, 23	f	large
80600	14029	282	Ярославская область, Рыбинск, проспект 50 лет Октября, 23	f	large
80593	14026	275	Ярославская область, Рыбинск, набережная Космонавтов, 19	f	large
80592	14026	274	Ярославская область, Рыбинск, набережная Космонавтов, 19	f	large
80591	13980	273	Ярославская область, Рыбинск, набережная Космонавтов, 39	f	large
80590	13980	272	Ярославская область, Рыбинск, набережная Космонавтов, 39	f	large
80687	14074	377	Ярославская область, Рыбинск, Ярославский тракт, 43	f	large
80671	14062	358	Ярославская область, Рыбинск, Щепкина, 19	f	large
80659	14050	342	Ярославская область, Рыбинск, Чкалова, 89	f	large
80657	14050	340	Ярославская область, Рыбинск, Чкалова, 89	f	large
80655	14050	338	Ярославская область, Рыбинск, Чкалова, 89	f	large
80640	14043	322	Ярославская область, Рыбинск, Чкалова, 93	f	large
80662	14054	345	Ярославская область, Рыбинск, Чехова, 48а	f	large
80597	14027	279	Ярославская область, Рыбинск, Черняховского, 29	f	large
80596	14027	278	Ярославская область, Рыбинск, Черняховского, 29	f	large
80595	14027	277	Ярославская область, Рыбинск, Черняховского, 29	f	large
80594	14027	276	Ярославская область, Рыбинск, Черняховского, 29	f	large
80620	14034	302	Ярославская область, Рыбинск, Черепанова, 15	f	large
80619	14034	301	Ярославская область, Рыбинск, Черепанова, 15	f	large
80617	14034	299	Ярославская область, Рыбинск, Черепанова, 15	f	large
80618	14034	300	Ярославская область, Рыбинск, Черепанова, 15	f	large
130922	14070	371	Ярославская область, Рыбинск, Фроловская, 4	f	small
80663	14056	347	Ярославская область, Рыбинск, Федорова, 7	f	large
130920	14060	355	Ярославская область, Рыбинск, Труда, 61а	f	medium
80630	14036	312	Ярославская область, Рыбинск, Солнечная, 7	f	large
80624	14036	306	Ярославская область, Рыбинск, Солнечная, 7	f	large
80606	14031	288	Ярославская область, Рыбинск, Серова, 21	f	large
80604	14031	286	Ярославская область, Рыбинск, Серова, 21	f	large
80642	14045	325	Ярославская область, Рыбинск, Свободы, 12а	f	large
80641	14045	324	Ярославская область, Рыбинск, Свободы, 12а	f	large
130917	14055	346	Ярославская область, Рыбинск, Свердлова, 26	f	medium
80589	13947	271	Ярославская область, Рыбинск, Рокоссовского, 11	f	large
80680	14069	369	Ярославская область, Рыбинск, Расплетина, 47	f	large
80681	14069	370	Ярославская область, Рыбинск, Расплетина, 47	f	large
80668	14051	354	Ярославская область, Рыбинск, Радищева, 15	f	large
80658	14051	341	Ярославская область, Рыбинск, Радищева, 15	f	large
80664	14057	348	Ярославская область, Рыбинск, Пятилетки, 27	f	large
80666	14057	350	Ярославская область, Рыбинск, Пятилетки, 27	f	large
80665	14057	349	Ярославская область, Рыбинск, Пятилетки, 27	f	large
80667	14049	353	Ярославская область, Рыбинск, Пушкина, 53	f	large
80653	14049	336	Ярославская область, Рыбинск, Пушкина, 53	f	large
80674	14064	361	Ярославская область, Рыбинск, Полиграфская, 5	f	large
80679	14064	367	Ярославская область, Рыбинск, Полиграфская, 5	f	large
80672	14063	359	Ярославская область, Рыбинск, Пархинская, 12	f	large
80673	14063	360	Ярославская область, Рыбинск, Пархинская, 12	f	large
80846	14068	368	Ярославская область, Рыбинск, Ошанина, 14	f	large
80678	14066	365	Ярославская область, Рыбинск, Ошанина, 14	f	large
80677	14066	364	Ярославская область, Рыбинск, Ошанина, 14	f	large
80684	14072	374	Ярославская область, Рыбинск, Моховая, 18	f	large
80650	14047	333	Ярославская область, Рыбинск, Моторостроителей, 15	f	large
80649	14047	332	Ярославская область, Рыбинск, Моторостроителей, 15	f	large
80648	14047	331	Ярославская область, Рыбинск, Моторостроителей, 15	f	large
80647	14047	330	Ярославская область, Рыбинск, Моторостроителей, 15	f	large
80643	14046	326	Ярославская область, Рыбинск, Моторостроителей, 27	f	large
80646	14046	329	Ярославская область, Рыбинск, Моторостроителей, 27	f	large
80645	14046	328	Ярославская область, Рыбинск, Моторостроителей, 27	f	large
80644	14046	327	Ярославская область, Рыбинск, Моторостроителей, 27	f	large
80633	14039	315	Ярославская область, Рыбинск, Молодежная, 32	f	large
80632	14039	314	Ярославская область, Рыбинск, Молодежная, 32	f	large
80689	14076	379	Ярославская область, Рыбинск, Механизации, 7	f	large
80661	14053	344	Ярославская область, Рыбинск, Ломоносова, 14	f	large
80634	14040	316	Ярославская область, Рыбинск, Кораблестроителей, 6	f	large
80636	14040	318	Ярославская область, Рыбинск, Кораблестроителей, 6	f	large
80635	14040	317	Ярославская область, Рыбинск, Кораблестроителей, 6	f	large
80656	14048	339	Ярославская область, Рыбинск, Карякинская, 104	f	large
80654	14048	337	Ярославская область, Рыбинск, Карякинская, 104	f	large
80651	14048	334	Ярославская область, Рыбинск, Карякинская, 104	f	large
80652	14048	335	Ярославская область, Рыбинск, Карякинская, 104	f	large
80603	14030	285	Ярославская область, Рыбинск, Инженерная, 23а	f	large
80602	14030	284	Ярославская область, Рыбинск, Инженерная, 23а	f	large
80599	14028	281	Ярославская область, Рыбинск, Инженерная, 39	f	large
80598	14028	280	Ярославская область, Рыбинск, Инженерная, 39	f	large
130915	13910	270	Ярославская область, Рыбинск, Гончарова, 3	f	medium
80639	14042	321	Ярославская область, Рыбинск, Глеба Успенского, 4	f	large
80638	14042	320	Ярославская область, Рыбинск, Глеба Успенского, 4	f	large
80688	14075	378	Ярославская область, Рыбинск, Гастелло, 5	f	large
80669	14061	356	Ярославская область, Рыбинск, Гагарина, 22	f	large
80670	14061	357	Ярославская область, Рыбинск, Гагарина, 22	f	large
80613	11958	295	Ярославская область, Рыбинск, Ворошилова, 3	f	large
80614	11958	296	Ярославская область, Рыбинск, Ворошилова, 3	f	large
80612	11958	294	Ярославская область, Рыбинск, Ворошилова, 3	f	large
80611	11958	293	Ярославская область, Рыбинск, Ворошилова, 3	f	large
80676	14065	363	Ярославская область, Рыбинск, Волочаевская, 55	f	large
80675	14065	362	Ярославская область, Рыбинск, Волочаевская, 55	f	large
80660	14052	343	Ярославская область, Рыбинск, Волжская Набережная, 173а	f	large
80683	14071	373	Ярославская область, Рыбинск, Вихарева, 3	f	large
80682	14071	372	Ярославская область, Рыбинск, Вихарева, 3	f	large
130919	14059	352	Ярославская область, Рыбинск, Бурлацкая, 8	f	medium
80607	14032	289	Ярославская область, Рыбинск, Бориса Рукавицына, 35	f	large
80605	14032	287	Ярославская область, Рыбинск, Бориса Рукавицына, 35	f	large
80627	14037	309	Ярославская область, Рыбинск, Бабушкина, 11	f	large
80626	14037	308	Ярославская область, Рыбинск, Бабушкина, 11	f	large
80625	14037	307	Ярославская область, Рыбинск, Бабушкина, 11	f	large
130918	14058	351	Ярославская область, Рыбинск, Академика Павлова, 35	f	medium
80637	14041	319	Ярославская область, Рыбинск, Академика Губкина, 21	f	large
80623	14035	305	Ярославская область, Рыбинск, 9 мая, 24	f	large
80622	14035	304	Ярославская область, Рыбинск, 9 мая, 24	f	large
80621	14035	303	Ярославская область, Рыбинск, 9 мая, 24	f	large
80628	13071	310	Ярославская область, Рыбинск, 9 мая, 14	f	large
80616	13071	298	Ярославская область, Рыбинск, 9 мая, 14	f	large
80615	13071	297	Ярославская область, Рыбинск, 9 мая, 14	f	large
80766	14410	717	Ярославская область, Ростов, Октябрьская, 45-47	f	large
80759	14403	710	Ярославская область, Ростов, 1-Й МКР, 27	f	large
130960	14137	441	Ярославская область, Покровское на Сити село, здание МОУ Покрово-Ситской общеобразовательной школы	f	small
80696	14086	389	Ярославская область, Переславль-Залесский, площадь Народная, 8	f	large
80704	14094	397	Ярославская область, Переславль-Залесский, площадь Менделеева, 2	f	large
80700	14090	393	Ярославская область, Переславль-Залесский, переулок Берендеевский, 27	f	large
80691	14081	384	Ярославская область, Переславль-Залесский, микрорайон Чкаловский, гарнизонный офицерский клуб	f	large
80690	14080	383	Ярославская область, Переславль-Залесский, микрорайон Чкаловский, 53	f	large
80705	14093	398	Ярославская область, Переславль-Залесский, Строителей, 33	f	large
80703	14093	396	Ярославская область, Переславль-Залесский, Строителей, 33	f	large
80702	14092	395	Ярославская область, Переславль-Залесский, Строителей, 22	f	large
80694	14084	387	Ярославская область, Переславль-Залесский, Советская, 3	f	large
80699	14089	392	Ярославская область, Переславль-Залесский, Свободы, 61	f	large
80698	14088	391	Ярославская область, Переславль-Залесский, Свободы, 47а	f	large
80695	14085	388	Ярославская область, Переславль-Залесский, Плещеевская, 17	f	large
80701	14091	394	Ярославская область, Переславль-Залесский, Октябрьская, 41	f	large
80709	14097	402	Ярославская область, Переславль-Залесский, Менделеева, 10	f	large
77688	4272	1011	Тульская область, Тула, Замочная, 105	f	large
80707	14095	400	Ярославская область, Переславль-Залесский, Менделеева, 36	f	large
80706	14095	399	Ярославская область, Переславль-Залесский, Менделеева, 36	f	large
80693	14083	386	Ярославская область, Переславль-Залесский, Кардовского, 11	f	large
80692	14082	385	Ярославская область, Переславль-Залесский, Кардовского, 61	f	large
80708	14096	401	Ярославская область, Переславль-Залесский, 50 лет Комсомола, 1	f	large
80697	14087	390	Ярославская область, город Переславль - Залесский, 1	f	large
80835	14577	887	Ярославская область, поселок Нагорный, Школьная, 1 А, КСК	f	large
80829	14571	881	Ярославская область, поселок Карачиха, Школьная, 31, Карачихская СОШ	f	large
80847	14570	880	Ярославская область, поселок Ивняки, Луговая, 1а, Ивняковская СОШ	f	large
80827	14567	877	Ярославская область, поселок Заволжье, 26, Дом культуры	f	large
131279	14565	874	Ярославская область, деревня Григорьевское, Клубная, 15, ИК - ул. Клубная д. 6 ( Григорьевская СОШ)	f	medium
131282	14578	888	Ярославская область, деревня Ананьино, Садовая, 11, (Дом Культуры)	f	small
80836	14579	889	Ярославская область, Ярославский район, поселок Ярославка, 25, Дом культуры	f	large
131289	14590	900	Ярославская область, Ярославский район, поселок Ширинье, Мира, 2, Дом культуры	f	small
80843	14559	868	Ярославская область, Ярославский район, поселок Туношна, Юбилейная, 7, Дом культуры	f	large
80844	14560	869	Ярославская область, Ярославский район, поселок Туношна, Туношна -городок-26, МДОУ Детский сад №5	f	large
131285	14584	894	Ярославская область, Ярославский район, поселок Толбухино, Социалистическая, 11, Администрация с/п	f	small
131278	14564	873	Ярославская область, Ярославский район, поселок Спасс, 18, Дом культуры	f	medium
80828	14569	879	Ярославская область, Ярославский район, поселок Сарафоново, 51, Дом культуры	f	large
131280	14531	875	Ярославская область, Ярославский район, поселок Прусово, Набережная, 13	f	small
131281	14568	878	Ярославская область, Ярославский район, поселок Пестрецово, 8б, Пестрецовская СОШ	f	medium
131290	14591	901	Ярославская область, Ярославский район, поселок Мордвиново, Советская , 7, Дом культуры	f	medium
131207	14448	754	Ярославская область, Ярославский район, поселок Михайловское, 27	f	small
80841	14592	902	Ярославская область, Ярославский район, поселок Михайловский, Школьная, 7, Михайловская СОШ	f	large
131283	14580	890	Ярославская область, Ярославский район, поселок Медягино, 34, Дом культуры	f	medium
80840	14588	898	Ярославская область, Ярославский район, поселок Курба, Школьная, 1, Курбская СОШ	f	large
80838	14582	892	Ярославская область, Ярославский район, поселок Кузнечиха, Центральная, 3, Дом культуры	f	large
80837	14581	891	Ярославская область, Ярославский район, поселок Кузнечиха, Центральная, 34, Кузнечихинская СОШ	f	large
80831	14573	883	Ярославская область, Ярославский район, поселок Красные Ткачи, Пушкина, 8а, ЦДТ "Ступеньки"	f	large
80830	14572	882	Ярославская область, Ярославский район, поселок Красные Ткачи, Пушкина, 8а, ЦДТ "Ступеньки"	f	large
131277	14562	871	Ярославская область, Ярославский район, поселок Красное, Школьная, 49, ( Красносельская ООШ), УИК - Туношна	f	small
80834	14576	886	Ярославская область, Ярославский район, поселок Кормилицыно, Лесная, 41-А, УИК - д. Карабиха, ул. Школьная д. 1Б ( Адм. с/п)	f	large
80839	14587	897	Ярославская область, Ярославский район, поселок Козьмодемьянск, Центральная, 36, Дом культуры	f	large
80833	14575	885	Ярославская область, Ярославский район, поселок Карабиха, Школьная, 1а, Карабихская ООШ	f	large
80779	14447	753	Ярославская область, Ярославский район, поселок Ермаково, 20, УИК: п. Ермаково, д. 19	f	large
80832	14574	884	Ярославская область, Ярославский район, поселок Дубки, Некрасова, 1, (Дом культуры)	f	large
131286	14585	895	Ярославская область, Ярославский район, поселок Глебовское, Олимпийская, 1а, Дом культуры	f	medium
131284	14583	893	Ярославская область, Ярославский район, поселок Андроники, Ярославская, 9, толовая ПСК "Родина"	f	medium
130963	14140	444	Ярославская область, Череповецкий район, поселок Михальково, Центральная, 6	t	small
131241	14522	833	Ярославская область, Угличский район, поселок Шубино	f	small
131270	14553	862	Ярославская область, Угличский район, поселок Шишкино	f	small
131262	14544	854	Ярославская область, Угличский район, поселок Чурьяково	f	medium
131268	14551	860	Ярославская область, Угличский район, поселок Ульянкино	f	small
131259	14541	851	Ярославская область, Угличский район, поселок Улейма	f	medium
131258	14540	850	Ярославская область, Угличский район, поселок Сосновый	f	medium
131272	14555	864	Ярославская область, Угличский район, поселок Прилуки	f	small
131263	14545	855	Ярославская область, Угличский район, поселок Покровское	f	small
131245	14526	837	Ярославская область, Угличский район, поселок Платуново	f	small
131247	14528	839	Ярославская область, Угличский район, поселок Отрадный	f	medium
131244	14525	836	Ярославская область, Угличский район, поселок Ордино	f	small
131264	14546	856	Ярославская область, Угличский район, поселок Овинищи Никольское	f	small
131250	14532	842	Ярославская область, Угличский район, поселок Ново	f	small
131243	14524	835	Ярославская область, Угличский район, поселок Нинорово	f	small
131256	14538	848	Ярославская область, Угличский район, поселок Нефедьево	f	small
131266	14548	858	Ярославская область, Угличский район, поселок Масальское	f	small
131257	14539	849	Ярославская область, Угличский район, поселок Маймеры	f	small
131267	14550	859	Ярославская область, Угличский район, поселок Климатино	f	small
131261	14543	853	Ярославская область, Угличский район, поселок Клементьево	f	small
131252	14534	844	Ярославская область, Угличский район, поселок Каблуково	f	small
131248	14529	840	Ярославская область, Угличский район, поселок Ильинское	f	medium
131260	14542	852	Ярославская область, Угличский район, поселок Зеленая Роща	f	medium
131269	14552	861	Ярославская область, Угличский район, поселок Заречье	f	small
131253	14535	845	Ярославская область, Угличский район, поселок Заозерье	f	medium
131274	14557	866	Ярославская область, Угличский район, поселок Головино	f	small
131254	14536	846	Ярославская область, Угличский район, поселок Вякирево	f	small
131271	14554	863	Ярославская область, Угличский район, поселок Воздвиженское	f	small
131251	14533	843	Ярославская область, Угличский район, поселок Василево	f	small
131265	14547	857	Ярославская область, Угличский район, поселок Варгуново	f	small
131246	14527	838	Ярославская область, Угличский район, поселок Бурмасово	f	medium
131255	14537	847	Ярославская область, Угличский район, поселок Белоусово	f	small
131242	14523	834	Ярославская область, Угличский район, поселок Алтыново	f	small
131232	14505	811	Ярославская область, Тутаевский район, поселок Ясиплево, Школьный переулок, 5, Школа	f	small
131237	14510	816	Ярославская область, Тутаевский район, поселок Чебаково, Школьная, 5, Школа	f	small
80808	14498	805	Ярославская область, Тутаевский район, поселок Фоминское, Школа	f	large
80803	14483	791	Ярославская область, Тутаевский район, Тутаев, проспект 50-летия Победы, 32, кола №3	f	large
80801	14481	789	Ярославская область, Тутаевский район, Тутаев, проспект 50-летия Победы, 32, Средняя школа №3	f	large
80800	14480	788	Ярославская область, Тутаевский район, Тутаев, проспект 50-летия Победы, 16а, Дом природы	f	large
80799	14479	787	Ярославская область, Тутаевский район, Тутаев, проспект 50-летия Победы, 32, Школа №3	f	large
80797	14477	785	Ярославская область, Тутаевский район, Тутаев, проспект 50-летия Победы, 23, Лицей №1	f	large
80795	14475	783	Ярославская область, Тутаевский район, Тутаев, проспект 50-летия Победы, 23, Лицей №1	f	large
80804	14484	792	Ярославская область, Тутаевский район, Тутаев, проспект 50 лет Победы, 32, Школа №3	f	large
80791	14471	779	Ярославская область, Тутаевский район, Тутаев, Ярославская, 93	f	large
80789	14469	777	Ярославская область, Тутаевский район, Тутаев, Ушакова, 48, Средняя школа №5	f	large
80805	14486	793	Ярославская область, Тутаевский район, Тутаев, Розы Люксембург, 57, ПУ-41	f	large
80798	14478	786	Ярославская область, Тутаевский район, Тутаев, Розы Люксембург, 57, ПУ-41	f	large
80790	14470	778	Ярославская область, Тутаевский район, Тутаев, П.Шитова, 25, Д/к ТМЗ	f	large
80796	14476	784	Ярославская область, Тутаевский район, Тутаев, Моторостроителей, 54, Школа №6	f	large
80794	14474	782	Ярославская область, Тутаевский район, Тутаев, Моторостроителей, 54, Школа №6	f	large
80792	14472	780	Ярославская область, Тутаевский район, Тутаев, Моторостроителей, 54, Школа №6	f	large
131201	14436	742	Ярославская область, Ростовский район, поселок Белогостицы, 35	f	medium
80788	14468	776	Ярославская область, Тутаевский район, Тутаев, Ленина, 96, Средняя школа №2	f	large
80807	14488	795	Ярославская область, Тутаевский район, Тутаев, Комсомольская, 117, Школа №7	f	large
80806	14487	794	Ярославская область, Тутаевский район, Тутаев, Комсомольская, 117, Школа №7	f	large
80802	14482	790	Ярославская область, Тутаевский район, Тутаев, Комсомольская, 117, Школа №7	f	large
80793	14473	781	Ярославская область, Тутаевский район, Тутаев, Комсомольская, 78, ДЮСШ "Старт"	f	large
131222	14490	797	Ярославская область, Тутаевский район, поселок Столбищи, Центральная, 6, Школа	f	medium
131231	14504	810	Ярославская область, Тутаевский район, поселок Савинское, Новая, 17	f	small
131093	14306	610	Ярославская область, Тутаевский район, поселок Рождественное, Молодежная, 27	f	small
131234	14507	813	Ярославская область, Тутаевский район, поселок Пшеничище, Школьная, 4, Дом Культуры	f	small
131210	14451	757	Ярославская область, Тутаевский район, поселок Погорелка, Центральная, 19б	f	small
131229	14497	804	Ярославская область, Тутаевский район, поселок Першино, Молодёжная, 14, Школа	f	small
131228	14496	803	Ярославская область, Тутаевский район, поселок Першино, Молодёжная, 14	f	small
131224	14492	799	Ярославская область, Тутаевский район, поселок Павловское, Школьная, 6	f	small
131236	14509	815	Ярославская область, Тутаевский район, поселок Никульское, Центральная, 41, Дом Культуры	f	medium
131223	14491	798	Ярославская область, Тутаевский район, поселок Никольское, Центральная, 49а, Школа	f	small
131099	14314	618	Ярославская область, Тутаевский район, поселок Никольское, Школьная, 11, УИК: с. Никольское, ул. Школьная. д.15	f	small
131212	14454	760	Ярославская область, Тутаевский район, поселок Назарово, Заречная, 1	f	medium
131230	14503	809	Ярославская область, Тутаевский район, поселок Микляиха, Советская, 2, Дом Культуры	f	medium
80811	14502	808	Ярославская область, Тутаевский район, поселок Константиновский, Садовая, 8, Школа	f	large
80810	14501	807	Ярославская область, Тутаевский район, поселок Константиновский, Садовая, 8, Школа	f	large
80809	14500	806	Ярославская область, Тутаевский район, поселок Константиновский, Садовая, 8, Школа	f	large
131288	14589	899	Ярославская область, Тутаевский район, поселок Иванищево, Молодежная, Иванищевская СОШ	f	medium
131221	14489	796	Ярославская область, Тутаевский район, поселок Емишево, Центральная, 20, Школа	f	medium
131233	14506	812	Ярославская область, Тутаевский район, поселок Выползово, Анненская, 7, Дом Культуры	f	small
131225	14493	800	Ярославская область, Тутаевский район, поселок Верещагино, Центральная, 19	f	small
131227	14495	802	Ярославская область, Тутаевский район, поселок Великое Село, Солнечная, 1а	f	small
131226	14494	801	Ярославская область, Тутаевский район, поселок Борисоглеб, Детский сад	f	small
131220	14465	772	Ярославская область, Рыбинский район, поселок Юбилейный, 5	f	medium
80785	14466	773	Ярославская область, Рыбинский район, поселок Тихменево, Тугаринова, 9	f	large
80784	14463	770	Ярославская область, Рыбинский район, поселок Судоверфь, Водников, 9	f	large
131208	14449	755	Ярославская область, Рыбинский район, поселок Сретенье, 60	f	small
131108	14319	627	Ярославская область, Рыбинский район, поселок Семеновское, Центральная, 41	f	small
131219	14464	771	Ярославская область, Рыбинский район, поселок Свингино, 27	f	small
80781	14457	764	Ярославская область, Рыбинский район, поселок Октябрьский, 18а, адрес УИК: п. Октябрьский, д. 18а	f	large
80842	14594	905	Ярославская область, Рыбинский район, поселок Мокеевское, 34, (Дом культуры), УИК - д. 37 (Адм. с/п)	f	large
131292	14594	904	Ярославская область, Рыбинский район, поселок Мокеевское, 34, (Дом культуры), УИК - д. 37 (Адм. с/п)	f	medium
131214	14456	762	Ярославская область, Рыбинский район, поселок Милюшино, Приморская, 13	f	small
131211	14453	759	Ярославская область, Рыбинский район, поселок Майский, 26	f	small
131084	14296	600	Ярославская область, Рыбинский район, поселок Лапино, 52, Осиново-Слободской сельский Дом культуры	f	small
131217	14460	767	Ярославская область, Рыбинский район, поселок Красная Горка, Центральная, 29	f	medium
80783	14461	768	Ярославская область, Рыбинский район, поселок Искра Октября, Молодежная, 35	f	large
80782	14458	765	Ярославская область, Рыбинский район, поселок Дюдьково, 16	f	large
80778	14400	707	Ярославская область, Ростовский район, поселок Шурскол, Квартал В, 7	f	large
131186	14418	724	Ярославская область, Ростовский район, поселок Чепорово, 31	f	small
131195	14428	734	Ярославская область, Ростовский район, поселок Хмельники, Заводская, 40	f	medium
131198	14433	739	Ярославская область, Ростовский район, поселок Угодичи, Прудная, 27	f	medium
131203	14443	748	Ярославская область, Ростовский район, поселок Татищев-Погост, 44а	f	small
131200	14435	741	Ярославская область, Ростовский район, поселок Сулость, 132	f	small
131180	14398	705	Ярославская область, Ростовский район, поселок Судино, 27	f	medium
131182	14414	720	Ярославская область, Ростовский район, поселок Скнятиново, 132	f	small
80774	14441	746	Ярославская область, Ростовский район, поселок Семибратово, Окружная, 5	f	large
80775	14442	747	Ярославская область, Ростовский район, поселок Семибратово, Мира, 6	f	large
80773	14440	745	Ярославская область, Ростовский район, поселок Семибратово, Ленинская, 1	f	large
80768	14413	719	Ярославская область, Ростовский район, Ростов, Спартаковская, 142	f	large
80762	14406	713	Ярославская область, Ростовский район, Ростов, Революции, 12	f	large
80761	14405	712	Ярославская область, Ростовский район, Ростов, Пролетарская, 40	f	large
80760	14404	711	Ярославская область, Ростовский район, Ростов, Пролетарская, 61	f	large
80767	14412	718	Ярославская область, Ростовский район, Ростов, Московская, 49а	f	large
80763	14407	714	Ярославская область, Ростовский район, Ростов, Моравского, 6	f	large
80765	14409	716	Ярославская область, Ростовский район, Ростов, Ленинская, 39	f	large
80764	14408	715	Ярославская область, Ростовский район, Ростов, Каменный мост, 7	f	large
80758	14402	709	Ярославская область, Ростовский район, Ростов, 1-Й МКР, 27	f	large
80757	14401	708	Ярославская область, Ростовский район, Ростов, 1-Й МКР, 27	f	large
131194	14427	733	Ярославская область, Ростовский район, поселок Приозерный, 39	f	small
131114	14325	633	Московская область, Истринский район, деревня Пречистое	f	small
131119	14332	640	Ярославская область, Ростовский район, поселок Пречистое, Советская, 54	f	medium
131120	14333	641	Ярославская область, Ростовский район, поселок Пречистое, Любимская, 12а	f	medium
80776	14444	749	Ярославская область, Ростовский район, поселок Поречье-Рыбное, Центральная, 62	f	large
80771	14430	736	Ярославская область, Ростовский район, поселок Петровское, Советская, 33	f	large
80770	14429	735	Ярославская область, Ростовский район, поселок Петровское, Пролетарская, 49	f	large
131188	14421	727	Ярославская область, Ростовский район, поселок Павлова Гора, 1	f	small
80772	14437	743	Ярославская область, Ростовский район, поселок Новоникольское, Центральная, 8	f	large
131183	14415	721	Ярославская область, Ростовский район, поселок Никольское, 156	f	small
131196	14431	737	Ярославская область, Ростовский район, поселок Мосейцево, Труда, 41	f	small
131181	14399	706	Ярославская область, Ростовский район, поселок Марково, 11а	f	small
131197	14432	738	Ярославская область, Ростовский район, поселок Лазарцево, Центральная, 2	f	small
80769	14420	726	Ярославская область, Ростовский район, поселок Коленово, Заводская, 15	f	large
131204	14445	750	Ярославская область, Ростовский район, поселок Климатино, Нагорная, 1	f	small
131192	14425	731	Ярославская область, Ростовский район, поселок Караш, Сосновая, 9	f	small
80777	14397	704	Ярославская область, Ростовский район, поселок Ишня, Школьная, 4	f	large
131189	14422	728	Ярославская область, Ростовский район, поселок Итларь, Березовая, 2	f	small
131191	14424	730	Ярославская область, Ростовский район, поселок Заозерье, 14	f	small
131193	14426	732	Ярославская область, Ростовский район, поселок Еремейцево, Центральная, 26	f	small
131185	14417	723	Ярославская область, Ростовский район, поселок Дмитриановское, Кузьмина, 39	f	medium
131184	14416	722	Ярославская область, Ростовский район, поселок Деревни, 49а	f	small
131187	14419	725	Ярославская область, Ростовский район, поселок Горный, 39	f	small
131209	14450	756	Ярославская область, Ростовский район, поселок Глебово	f	medium
131202	14438	744	Ярославская область, Ростовский район, поселок Вахрушево, квартал В, 2	f	medium
131199	14434	740	Ярославская область, Ростовский район, поселок Васильково, 29	f	small
77776	4320	1102	Тульская область, Тула, Жуковского, 27	f	large
131190	14423	729	Ярославская область, Ростовский район, поселок Беклемишево, Школьная, 10	t	small
131171	14387	694	Ярославская область, Пошехонский район, поселок Ясная Поляна, Рыбинская, 18, здание сельского Дома Культуры	f	small
131170	14386	693	Ярославская область, Пошехонский район, поселок Яковлевское, Административная, 4, здание сельского Дома Культуры	f	small
131179	14395	702	Ярославская область, Пошехонский район, поселок Юдино, Центральная, 9, здание Юдинской школы	f	small
131178	14394	701	Ярославская область, Пошехонский район, поселок Холм, 23, здание сельского Дома Культуры	f	small
131176	14392	699	Ярославская область, Пошехонский район, поселок Федорково, 41, здание лагеря ДОЦ "Солнышко"	f	small
131165	14381	688	Ярославская область, Пошехонский район, поселок Ракоболь, Калининская, 15, здание администрации Пригородного СП	f	small
131156	14371	679	Ярославская область, Пошехонский район, Пошехонье, Строителей, 14, Детский сад "Матрешка"	f	small
80756	14370	678	Ярославская область, Пошехонский район, Пошехонье, Советская, 25, сельскохозяйственный техникум	f	large
80754	14396	703	Ярославская область, Пошехонский район, Пошехонье, Преображенского, 23, кинотеатр "Юбилейный"	f	large
80755	14369	677	Ярославская область, Пошехонский район, Пошехонье, Преображенского, 1, районный Дом Культуры	f	large
131157	14372	680	Ярославская область, Пошехонский район, Пошехонье, Заречная, 31, здание Согожского лесничества	f	small
131174	14390	697	Ярославская область, Пошехонский район, поселок Покров-Рогули, Мирная, 8, здание Покров-Рогульской школы	f	small
131173	14389	696	Ярославская область, Пошехонский район, поселок Крестцы, 29, здание Крестцовской библиотеки	f	small
131172	14388	695	Ярославская область, Пошехонский район, поселок Кременево, Школьная, 4, здание Кременевской школы	f	medium
131168	14384	691	Ярославская область, Пошехонский район, поселок Красное, 38, здание адм-и Пригородного СП	f	small
131169	14385	692	Ярославская область, Пошехонский район, поселок Колодино, Центральная, 26, здание Колодинской школы	f	small
131167	14383	690	Ярославская область, Пошехонский район, поселок Князево, Ветеранская, 1, здание сельского Дома Культуры	f	small
131166	14382	689	Ярославская область, Пошехонский район, поселок Кладово, Огурцова, 25, здание сельского Дома Культуры	f	small
131177	14393	700	Ярославская область, Пошехонский район, поселок Зубарево, 87, здание сельского Дома Культ	f	small
131164	14380	687	Ярославская область, Пошехонский район, поселок Ермаково, Ильинская, 1, здание администрации Ермаковского СП	f	medium
131175	14391	698	Ярославская область, Пошехонский район, поселок Дубасово, Школьная, 7, здание Дубасовской начальной школы	f	small
131163	14379	686	Ярославская область, Пошехонский район, поселок Гаютино, Молодежная, 6, здание администрации Ермаковского СП	f	medium
131162	14378	685	Ярославская область, Пошехонский район, поселок Вощиково, Школьная, 9, здание Вощиковской школы	f	small
131161	14377	684	Ярославская область, Пошехонский район, поселок Владычное, Пошехонская, 21, здание сельского дома культуры	f	small
131159	14375	682	Ярославская область, Пошехонский район, поселок Васильевское, Солнечная, 1, здание сельского Дома Культуры	f	small
131158	14374	681	Ярославская область, Пошехонский район, поселок Белое, Федоровская, 41, здание администрации Белосельского СП	f	medium
131160	14376	683	Ярославская область, Пошехонский район, поселок Андрюшино, Центральная, 5, здание ФАП	f	small
131143	14357	664	Ярославская область, Переславский район, поселок Фонинское, Мичуринская, 59	f	small
131149	14363	670	Ярославская область, Переславский район, поселок Филимоново, Овражная, 8	f	small
131127	14340	648	Ярославская область, Переславский район, поселок Троицкая-Слобода, Троицкая, 1а	f	medium
131154	14367	675	Ярославская область, Переславский район, поселок Смоленское, Центральная, 7	f	medium
131152	14365	673	Ярославская область, Переславский район, поселок Рязанцево, Республиканская, 13	f	small
131151	14364	672	Ярославская область, Переславский район, поселок Рязанцево, Большая Октябрьская, 30	f	small
131150	14364	671	Ярославская область, Переславский район, поселок Рязанцево, Большая Октябрьская, 30	f	small
131140	14354	661	Ярославская область, Переславский район, поселок Рахманово, Центральная, 91	f	small
131128	14341	649	Ярославская область, Переславский район, поселок Новоселье, Моисеева, 11	f	medium
131142	14356	663	Ярославская область, Переславский район, поселок Нагорье, Адмирала Спиридова, 1б	f	medium
131141	14355	662	Ярославская область, Переславский район, поселок Нагорье, Адмирала Спиридова, 1б	f	medium
131132	14345	653	Ярославская область, Переславский район, поселок Лыченцы, Школьная, 3	f	small
131135	14349	656	Ярославская область, Переславский район, Купанское, Депутатская, 23	f	medium
131134	14348	655	Ярославская область, Переславский район, Купанское, Депутатская, 23	f	medium
131146	14360	667	Ярославская область, Переславский район, Кубринск, Петрова, 21	f	medium
131145	14359	666	Ярославская область, Переславский район, Кубринск, Петрова, 21	f	medium
131129	14342	650	Ярославская область, Переславский район, поселок Красная, Совхозная, 31	f	small
131136	14350	657	Ярославская область, Переславский район, поселок Копнино, Центральная, 47	f	small
131126	14339	647	Ярославская область, Переславский район, поселок Кичибухино, Школьная, 1	f	small
131130	14343	651	Ярославская область, Переславский район, поселок Ивановское, прспект Мира, 9	f	small
131131	14344	652	Ярославская область, Переславский район, поселок Ивановское, проспект Мира, 9	f	small
131137	14351	658	Ярославская область, Переславский район, поселок Загорье, Центральная, 34	f	small
131138	14352	659	Ярославская область, Переславский район, поселок Ефимьево, Октябрьская, 4	f	small
131148	14362	669	Ярославская область, Переславский район, поселок Дубровицы, Крутец, 4а	f	small
131147	14361	668	Ярославская область, Переславский район, поселок Дубки, Клубная, 1а	f	medium
131139	14353	660	Ярославская область, Переславский район, поселок Дмитриевское, Школьная, 13	f	small
131153	14366	674	Ярославская область, Переславский район, поселок Горки, Центральная, 7	f	small
131124	14337	645	Ярославская область, Переславский район, поселок Глебовское, Центральная, 101	f	small
131123	14336	644	Ярославская область, Переславский район, поселок Глебовское, Центральная, 101	f	small
131133	14347	654	Ярославская область, Переславский район, поселок Большая Брембола, Советская, 35а	f	medium
131122	14335	643	Ярославская область, Переславский район, поселок Берендеево, Центральная, 3, УИК - ул. Центральная, 6	f	small
131121	14334	642	Ярославская область, Переславский район, поселок Берендеево, Центральная, 3, УИК - ул.Центральная, 6	f	medium
131155	14368	676	Ярославская область, Переславский район, поселок Бектышево, Центральная, 19	f	small
131144	14358	665	Ярославская область, Переславский район, поселок Андрианово, Садовая, 3	f	small
131116	14327	635	Ярославская область, Первомайский район, поселок Шильпухово, 95	f	small
131118	14329	637	Ярославская область, Первомайский район, Скалино, Первомайская, 11	f	small
131090	14303	607	Ярославская область, Первомайский район, поселок Путятино, Маслова, 1	f	small
131109	14320	628	Ярославская область, Первомайский район, поселок Паршино, Молодежная, 29	f	small
131105	14316	624	Ярославская область, Первомайский район, поселок Николо-Ухтома, Луговая, 5	f	small
131113	14324	632	Ярославская область, Первомайский район, поселок Никола-Гора, 8	f	small
131104	14163	623	Ярославская область, Первомайский район, поселок Малино, 5	f	small
131101	14220	620	Ярославская область, Первомайский район, поселок Кукобой, Школьная, 4	f	small
131102	14272	621	Ярославская область, Первомайский район, поселок Кукобой, Советская, 19	f	small
131112	14323	631	Ярославская область, Первомайский район, поселок Коза, Заречная, 31	f	small
131111	14322	630	Ярославская область, Первомайский район, поселок Игнатцево, Центральная, 2	f	small
131291	14593	903	Ярославская область, Первомайский район, поселок Григорьевское, Мира, 34	f	medium
131107	14318	626	Ярославская область, Первомайский район, поселок Всехсвятское, Центральная, 32	f	small
131103	14286	622	Ярославская область, Первомайский район, поселок Вараково, 9	f	small
131115	14326	634	Ярославская область, Первомайский район, поселок Багряники, 5	f	small
131086	14299	603	Ярославская область, Некрасовский район, поселок Яснища, Комсомольская, 1б	f	small
131085	14297	601	Ярославская область, Некрасовский район, поселок Черная Заводь, Школьная, 1а	f	small
131071	14276	582	Ярославская область, Некоузский район, поселок Волга, Линейная, 3	f	medium
131081	14292	596	Ярославская область, Некрасовский район, поселок Приволжский, 11а, Приволжская сельская библиотека	f	medium
80787	14467	775	Ярославская область, Некрасовский район, поселок Песочное, Заводская, 1б	f	large
80786	14467	774	Ярославская область, Некрасовский район, поселок Песочное, Заводская, 1б	f	large
80747	14291	595	Ярославская область, Некрасовский район, поселок Некрасовское, Строителей, 7	f	large
80746	14290	594	Ярославская область, Некрасовский район, поселок Некрасовское, Строителей, 7	f	large
80745	14289	593	Ярославская область, Некрасовский район, поселок Некрасовское, Пролетарская, 2	f	large
131089	14302	606	Ярославская область, Некрасовский район, деревня Наумиха, 25, административное здание отд. Гребово СП Красный Профинтерн	f	small
131082	14293	597	Ярославская область, Некрасовский район, поселок Малые Соли, 3а, Малосольская сельская библиотека	f	small
131216	14459	766	Ярославская область, Некрасовский район, поселок Лом, Пионерская, 10	f	small
80748	14295	599	Ярославская область, Некрасовский район, поселок Левашово, Молодежная, 13	f	large
131095	14308	612	Ярославская область, Некрасовский район, поселок Красный Профинтерн, Центральная, 5	f	medium
80749	14298	602	Ярославская область, Некрасовский район, поселок Красный Профинтерн, Набережная, 22	f	large
131080	14287	591	Ярославская область, Некрасовский район, поселок Коробиха, 51, Якушевский сельский Дом культуры	f	small
131088	14301	605	Ярославская область, Некрасовский район, поселок Защитный, 12а, ЭЗС-филиал ФГУ "Управления Ярославльмелиоводхоз"	f	small
131092	14305	609	Ярославская область, Некрасовский район, поселок Диево-Городище, Ярославская, 6	f	medium
131079	14285	590	Ярославская область, Некрасовский район, поселок Гашки, Молодежная, 7/2	f	small
131091	14304	608	Ярославская область, Некрасовский район, поселок Вятское, Давыдковская, 25	f	medium
131097	14312	616	Ярославская область, Некрасовский район, поселок Бурмакино, Центральная, 21, УИК: с. Бурмакино, ул. Заречная, д. 31	f	small
131087	14300	604	Ярославская область, Некрасовский район, поселок Бор, 44а, Боровская специальная (коррекционная) общеобразовательная школа-интернат	f	small
131072	14278	583	Ярославская область, Некоузский район, поселок Шестихино, переулок Клубный	f	medium
131059	14263	568	Ярославская область, Некоузский район, поселок Станилово, 7	f	small
131060	14264	569	Ярославская область, Некоузский район, поселок Спас-Ильдь, 16	f	small
131064	14268	573	Ярославская область, Некоузский район, поселок Рожалово	f	small
131058	14262	567	Ярославская область, Некоузский район, поселок Правдино	f	small
131063	14267	572	Ярославская область, Некоузский район, поселок Парфеньево, 2	f	small
131077	14283	588	Ярославская область, Некоузский район, поселок Октябрь, Ленина, 11	f	medium
131076	14282	587	Ярославская область, Некоузский район, поселок Октябрь, Ленина, 11	f	medium
131056	14260	565	Ярославская область, Некоузский район, поселок Новый Некоуз, Советская, 38	f	small
131055	14259	564	Ярославская область, Некоузский район, поселок Новый Некоуз, Советская, 38	f	medium
80741	14258	563	Ярославская область, Некоузский район, поселок Новый Некоуз, Советская, 38	f	large
80740	14257	562	Ярославская область, Некоузский район, поселок Новый Некоуз, Советская, 19	f	large
131062	14266	571	Ярославская область, Некоузский район, поселок Новинское, 74	f	small
131073	14279	584	Ярославская область, Некоузский район, Новая Ура, Центральная, 5	f	small
131218	14462	769	Ярославская область, Некоузский район, поселок Никольское, Мира, 7	f	medium
131057	14261	566	Ярославская область, Некоузский район, поселок Некоуз, Советская, 13	f	small
131078	14284	589	Ярославская область, Некоузский район, село Мокеиха, 3-я Вокзальная, 6/10	f	medium
131068	14274	578	Ярославская область, Некоузский район, поселок Марьино, Центральная, 9	f	small
131066	14271	576	Ярославская область, Некоузский район, поселок Лацкое, Центральная, 36	f	small
131061	14265	570	Ярославская область, Некоузский район, поселок Данилово, 32	f	small
131075	14281	586	Ярославская область, Некоузский район, поселок Воскресенское, Центральная, 37	f	small
131074	14280	585	Ярославская область, Некоузский район, поселок Воскресенское, Центральная, 37	f	small
131070	14277	581	Ярославская область, Некоузский район, поселок Волга, Линейная улица, 3	f	medium
80743	14276	580	Ярославская область, Некоузский район, поселок Волга, Линейная, 3	f	large
131067	14273	577	Ярославская область, Некоузский район, поселок Веретея, 23	f	small
131065	14270	575	Ярославская область, Некоузский район, поселок Борок, 134	f	medium
80742	14269	574	Ярославская область, Некоузский район, поселок Борок, 134	f	large
131069	14275	579	Ярославская область, Некоузский район, поселок Андреевское, 40	f	small
131053	14252	557	Ярославская область, Мышкинский район, с. Флоровское, здание администрации Приволжского сельского поселения	f	small
131054	14253	558	Ярославская область, Мышкинский район, поселок Шипилово, здание общеобразовательной школы, здание Шипиловского Дома культуры	f	small
131042	14241	546	Ярославская область, Мышкинский район, поселок Ступино, здание Ступинской начальной школы	f	small
131051	14250	555	Ярославская область, Мышкинский район, поселок Сера, здание Серского сельского клуба, здание Серской библиотеки	f	small
131052	14251	556	Ярославская область, Мышкинский район, поселок Рождествено, здание Рождественской средней общеобразовательной школы, помещение администрации Приволжского СП	f	small
131098	14313	617	Ярославская область, Мышкинский район, поселок Рождествено, Центральная, 13	f	small
131050	14249	554	Ярославская область, Мышкинский район, поселок Поводнево, здание Дома культуры	f	small
131049	14248	553	Ярославская область, Мышкинский район, поселок Охотино, здание Охотинской начальной школы, здание администрации Охотинского СП	f	medium
80739	14240	545	Ярославская область, Мышкинский район, Мышкин, Угличская улица, 92, Межпоселенческий ДК&quot;	f	large
80737	14255	560	Ярославская область, Мышкинский район, Мышкин, К.Либкнехта, 45, здание Межпоселенческого Дома культуры	f	large
80738	14256	561	Ярославская область, Мышкинский район, Мышкин, Загородная, 93, здание средней общеобразовательной школы	f	large
80736	14254	559	Ярославская область, Мышкинский район, Мышкин, Карла Либкнехта, 35, здание ПУ-34,, г.Мышкин, ул.К.Либкнехта, д. 45, Межпоселенческий ДК"	f	large
131048	14247	552	Ярославская область, Мышкинский район, поселок Мартыново, помещение администрации Приволжского сельского поселения	f	small
131047	14246	551	Ярославская область, Мышкинский район, поселок Крюково, здание администрации Приволжского сельского поселения	f	small
131045	14244	549	Ярославская область, Мышкинский район, поселок Кривец, помещение сельского клуба Кривецкого спец. дома-интерната	f	small
131046	14245	550	Ярославская область, Мышкинский район, поселок Коптево, здание общеобразовательной школы, здание сельского Дома культуры	f	small
130964	14141	445	Ярославская область, Мышкинский район, поселок Горелово, здание Гореловского сельского клуба	f	small
131044	14243	548	Ярославская область, Мышкинский район, поселок Галачевская, здание Галачевского сельского клуба	f	small
131043	14242	547	Ярославская область, Мышкинский район, поселок Богородское, здание Дома культуры	f	small
131213	14455	761	Ярославская область, Любимский район, поселок Шашково, Юбилейная, 32	f	medium
131040	14238	543	Ярославская область, Любимский район, поселок Черново, здание Черновского сельского ДК	f	small
131022	14206	525	Ярославская область, Любимский район, поселок Фрольцево, здание Воскресенской ООШ	f	small
131018	14216	519	Ярославская область, Любимский район, поселок Филиппово, здание Филипповской ООШ	f	small
131041	14239	544	Ярославская область, Любимский район, поселок Троица, здание Троицкого сельского ДК	f	small
131032	14230	535	Ярославская область, Любимский район, поселок Страшево, здание Страшевской ООШ	f	small
131029	14227	532	Ярославская область, Любимский район, поселок Соколиный, Молодежная, 7/2	f	small
131038	14236	541	Ярославская область, Любимский район, поселок Семендяево, здание Семендяевского сельского ДК	f	small
131039	14237	542	Ярославская область, Любимский район, поселок Рузбугино, здание администрации Осецкого сельского поселения	f	small
131037	14235	540	Ярославская область, Любимский район, поселок Раслово-Барское, здание МУК Расловского ЦДК	f	small
131035	14233	538	Ярославская область, Любимский район, поселок Покров, здание Покров-Кулижской ООШ	f	small
131031	14229	534	Ярославская область, Любимский район, поселок Отрадный, здание МУК "ЦДК п.Отрадный"	f	medium
131036	14234	539	Ярославская область, Любимский район, поселок Обнорское, здание отделения администрации Ермаковского с/п	f	small
131023	14221	526	Ярославская область, Любимский район, поселок Минино, здание Мининского сельского ДК	f	small
131030	14228	533	Ярославская область, Любимский район, Любим, Трефолева, 12/2, здание МУК Любимский районный ДК	f	small
80735	14218	522	Ярославская область, Любимский район, Любим, Советская, 19	f	large
131021	14192	524	Ярославская область, Любимский район, Любим, Советская, 119	f	medium
80734	14217	520	Ярославская область, Любимский район, Любим, Октябрьская, 11	f	large
131019	14217	521	Ярославская область, Любимский район, Любим, Октябрьская, 11	f	medium
131020	14219	523	Ярославская область, Любимский район, Любим, Набережная реки Обноры, 14/62	f	medium
131026	14224	529	Ярославская область, Любимский район, поселок Крутик, помещение сельского клуба	f	small
80826	14566	876	Ярославская область, Любимский район, поселок Красный Бор, 1, библиотека	f	large
131027	14225	530	Ярославская область, Любимский район, поселок Кириллово, здание Кирилловского сельского ДК	f	small
131028	14226	531	Ярославская область, Любимский район, поселок Кинтаново, здание Кинтановской ООШ	f	small
131025	14223	528	Ярославская область, Любимский район, поселок Закобякино, здание отделения Закобякино администрации Осецкого с/п	f	small
131024	14222	527	Ярославская область, Любимский район, поселок Ермаково, здание администрации Ермаковского сельского поселения	f	small
131034	14232	537	Ярославская область, Любимский район, поселок Гузыцыно, здание спортивного зала	f	small
131033	14231	536	Ярославская область, Любимский район, поселок Вахромейка, здание МУК "Вахромеевский ЦДК"	f	small
130999	14196	500	Ярославская область, Даниловский район, поселок Шаготь, Нагорная, 20	f	small
131013	14211	514	Ярославская область, Даниловский район, поселок Чурьяково, Старая, 22	f	small
130997	14194	498	Ярославская область, Даниловский район, поселок Хабарово, Школьная, 1	f	small
131016	14214	517	Ярославская область, Даниловский район, поселок Федурино, Покровская, 8	f	small
131011	14209	512	Ярославская область, Даниловский район, деревня Трофимово, Набережная, 10	f	small
131003	14200	504	Ярославская область, Даниловский район, поселок Торопово, Рабочая, 2	f	small
131010	14208	511	Ярославская область, Даниловский район, поселок Телицыно, Мира, 3б	f	small
131001	14198	502	Ярославская область, Даниловский район, поселок Спас, Школьная, 17	f	small
131005	14202	506	Ярославская область, Даниловский район, поселок Скоково, Центральная, 8	f	small
131014	14212	515	Ярославская область, Даниловский район, поселок Середа, Ленина, 33	f	medium
131017	14215	518	Ярославская область, Даниловский район, поселок Семлово, Школьная, 1	f	small
131004	14201	505	Ярославская область, Даниловский район, поселок Рыжиково, Почтовая, 7	f	small
130996	14193	497	Ярославская область, Даниловский район, поселок Рощино, Центральная, 17	f	small
130994	14190	495	Ярославская область, Даниловский район, поселок Покров, Центральная, 4	f	small
131002	14199	503	Ярославская область, Даниловский район, поселок Мишутино, Молодежная, 2	f	small
130993	14189	494	Ярославская область, Даниловский район, поселок Малое Марьино, Молодёжная, 2а	f	small
130995	14191	496	Ярославская область, Даниловский район, поселок Макарово, Вологодская, 17	f	small
131012	14210	513	Ярославская область, Даниловский район, поселок Лыкошино, Центральная, 4а	f	small
131008	14205	509	Ярославская область, Даниловский район, поселок Кузьмино, Ярославская, 18	f	small
131006	14203	507	Ярославская область, Даниловский район, поселок Костюшино, Центральная, 1	f	small
130972	14148	453	Ярославская область, Даниловский район, поселок Косково, Советская, 22	f	small
131015	14213	516	Ярославская область, Даниловский район, поселок Козлово, Южная, 12	f	small
130998	14195	499	Ярославская область, Даниловский район, поселок Ермаково, Молодежная, 1	f	small
131009	14207	510	Ярославская область, Даниловский район, поселок Дмитриевское, Южная, 1	f	medium
80729	14182	487	Ярославская область, Даниловский район, Данилов, площадь Советская, 4	f	large
80730	14183	488	Ярославская область, Даниловский район, Данилов, площадь Соборная, 7	f	large
80732	14185	490	Ярославская область, Даниловский район, Данилов, Ярославская, 52	f	large
80728	14181	486	Ярославская область, Даниловский район, Данилов, Урицкого, 58а	f	large
80727	14180	485	Ярославская область, Даниловский район, Данилов, Урицкого, 46	f	large
80725	14178	483	Ярославская область, Даниловский район, Данилов, Заводская, 5	f	large
80733	14186	491	Ярославская область, Даниловский район, Данилов, Гражданская, 2	f	large
80731	14184	489	Ярославская область, Даниловский район, Данилов, Вятская, 4	f	large
80726	14179	484	Ярославская область, Даниловский район, Данилов, Володарского, 83	f	large
130992	14188	493	Ярославская область, Даниловский район, поселок Горушка, Гагарина, 6	f	medium
131000	14197	501	Ярославская область, Даниловский район, поселок Горинское, Центральная, 32	f	small
131215	14346	763	Ярославская область, Даниловский район, поселок Волково, Лапшина, 10	f	medium
131007	14204	508	Ярославская область, Даниловский район, поселок Бабаево, Лесная, 3	f	small
80724	14175	480	Ярославская область, Гаврилов-Ямский район, поселок Шопша, Центральная, 5	f	large
130989	14176	481	Ярославская область, Гаврилов-Ямский район, поселок Шалаево, Центральная, 6	f	small
130984	14170	475	Ярославская область, Гаврилов-Ямский район, поселок Ульяново, Центральная, 9	f	small
130983	14169	474	Ярославская область, Гаврилов-Ямский район, поселок Стогинское, Центральная, 16	f	small
130986	14172	477	Ярославская область, Гаврилов-Ямский район, поселок Ставотино, Школьная, 11	f	small
130982	14168	473	Ярославская область, Гаврилов-Ямский район, поселок Пружинино, Центральная, 41	f	small
130987	14173	478	Ярославская область, Гаврилов-Ямский район, поселок Прошенино, Школьная, 29	f	small
130977	14162	468	Ярославская область, Гаврилов-Ямский район, поселок Поляна, Клубная, 10	f	medium
130975	14160	466	Ярославская область, Гаврилов-Ямский район, поселок Плотина, Молодежная, 1	f	small
130974	14159	465	Ярославская область, Гаврилов-Ямский район, поселок Плещеево, Центральная, 43	f	small
130980	14166	471	Ярославская область, Гаврилов-Ямский район, поселок Остров, Школьная, 1	t	small
130985	14171	476	Ярославская область, Гаврилов-Ямский район, поселок Осенево, Центральная, 1	f	small
130981	14167	472	Ярославская область, Гаврилов-Ямский район, поселок Митино, Колхозная, 20	f	small
130976	14161	467	Ярославская область, Гаврилов-Ямский район, поселок Лахость, Урицкого, 2	f	small
130990	14177	482	Ярославская область, Гаврилов-Ямский район, поселок Ильинское-Урусово, Тенистая, 1	f	small
130988	14174	479	Ярославская область, Гаврилов-Ямский район, поселок Заячий Холм, Центральная, 16	f	small
80717	14151	457	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Юбилейный проезд, 5	f	large
80716	14151	456	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Юбилейный проезд, 5	f	large
80719	14153	459	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Чернышевского, 3	f	large
80720	14154	460	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Спортивная, 14	f	large
80721	14155	461	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Советская, 2	f	large
80722	14156	462	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Клубная, 1	f	large
80723	14158	464	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Кирова, 13	f	large
130973	14157	463	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Кирова, 13	f	medium
80718	14152	458	Ярославская область, Гаврилов-Ямский район, Гаврилов-Ям, Калинина, 4	f	large
130978	14164	469	Ярославская область, Гаврилов-Ямский район, поселок Великое, Розы Люксембург, 12	f	medium
130979	14165	470	Ярославская область, Гаврилов-Ямский район, поселок Великое, Некрасовская, 1	f	medium
130961	14138	442	Ярославская область, Брейтовский район, поселок Ульяниха, здание администрации Брейтовского сельского поселения	f	small
130970	14118	451	Ярославская область, Брейтовский район, поселок Сутка, Молодёжная, 4	f	small
130968	14145	449	Ярославская область, Брейтовский район, поселок Суминское, 7, здание Суминского сельского клуба	f	small
130966	14143	447	Ярославская область, Брейтовский район, поселок Севастьянцево, здание Гореловского сельского поселения	f	small
130969	14146	450	Ярославская область, Брейтовский район, поселок Себельское, 63, здание Себельского сельского клуба	f	small
130967	14144	448	Ярославская область, Брейтовский район, поселок Прозорово, Михайловская, 8/2	f	small
130965	14142	446	Ярославская область, Брейтовский район, поселок Остряковка, здание Остряковского Дома культуры	f	small
130958	14135	439	Ленинградская область, Киришский район, деревня Новинка	f	small
130959	14136	440	Ярославская область, Брейтовский район, поселок Логинцево, здание Логинцевского сельского клуба	f	small
130971	14147	452	Ярославская область, Брейтовский район, поселок Лискино, 58, здание Лискинского сельского клуба	f	small
130962	14139	443	Ярославская область, Брейтовский район, поселок Коростень, здание Коростеньской начальной школы	f	small
80715	14150	455	Ярославская область, Брейтовский район, поселок Брейтово, Республиканская, 54	f	large
80714	14149	454	Ярославская область, Брейтовский район, поселок Брейтово, Республиканская, 23	f	large
130940	14114	419	Ярославская область, Борисоглебский район, поселок Яковцево, Центральная, 11	f	small
130946	14123	427	Ярославская область, Борисоглебский район, поселок Юркино, Транспортная, 5	f	small
130957	14134	438	Ярославская область, Борисоглебский район, поселок Щурово, Транспортная, 24	f	small
130954	14131	435	Ярославская область, Борисоглебский район, поселок Сущево, Центральная, 26	f	small
130947	14124	428	Ярославская область, Борисоглебский район, поселок Сигарь, Лесная, 2	f	small
130942	14119	423	Ярославская область, Борисоглебский район, поселок Селище, Верхняя, 1а	f	small
130955	14132	436	Ярославская область, Борисоглебский район, поселок Покровское, Клубная, 4	f	small
130945	14122	426	Ярославская область, Борисоглебский район, поселок Неверково, Школьная, 5	f	medium
130941	14117	422	Ярославская область, Борисоглебский район, поселок Красный Октябрь, Советская, 2а	f	medium
130943	14120	424	Ярославская область, Борисоглебский район, поселок Красново, переулок Луговой, 4	f	small
130950	14127	431	Ярославская область, Борисоглебский район, поселок Кондаково, 60	f	small
130949	14126	430	Ярославская область, Борисоглебский район, поселок Козино, Красная, 19	f	small
130953	14130	434	Ярославская область, Борисоглебский район, поселок Инальцыно, Новая, 21	f	small
130938	14112	417	Ярославская область, Борисоглебский район, поселок Зачатье, Центральная, 16а	f	small
130951	14128	432	Ярославская область, Борисоглебский район, поселок Давыдово, 19	f	small
130948	14125	429	Ярославская область, Борисоглебский район, поселок Высоково, Липовая, 3	f	small
130944	14121	425	Ярославская область, Борисоглебский район, поселок Вощажниково, Советская, 8	f	small
80751	14310	614	Ярославская область, Борисоглебский район, поселок Бурмакино, Советская, 8б	f	large
131096	14311	615	Ярославская область, Борисоглебский район, поселок Бурмакино, Заречная, 30, УИК: с. Бурмакино, ул. Заречная, д. 31	f	small
80750	14309	613	Ярославская область, Борисоглебский район, поселок Бурмакино, Ленина, 19	f	large
80712	14115	420	Ярославская область, Борисоглебский район, поселок Борисоглебский, Победы, 1а	f	large
80713	14116	421	Ярославская область, Борисоглебский район, поселок Борисоглебский, Первомайская, 4а	f	large
130956	14133	437	Ярославская область, Борисоглебский район, поселок Березники, Транспортная, 2	f	small
130939	14113	418	Ярославская область, Борисоглебский район, поселок Андреевское, Крестьянская, 26	f	medium
130952	14129	433	Ярославская область, Борисоглебский район, поселок Алешкино, 72	f	small
130926	14098	403	Ярославская область, Большесельский район, поселок Шельшедом, Мира, 10	f	small
130937	14111	416	Ярославская область, Большесельский район, поселок Чудиново, Школьная, 12	f	small
131287	14586	896	Ярославская область, Большесельский район, поселок Устье, Центральная, 48а	f	small
130930	14103	408	Ярославская область, Большесельский район, поселок Новое Гостилово, Зеленая, 4	f	small
130936	14110	415	Ярославская область, Большесельский район, поселок Новое, Октябрьская, 2	f	small
130933	14107	412	Ярославская область, Большесельский район, поселок Миглино, Мира, 1а	f	small
130934	14108	413	Ярославская область, Большесельский район, поселок Иванцево, 13	f	small
130927	14100	405	Ярославская область, Большесельский район, поселок Дунилово, Рабочая, 18	f	small
130935	14109	414	Ярославская область, Большесельский район, поселок Гари, 26	f	small
130931	14105	410	Ярославская область, Большесельский район, поселок Высоково, А.В.Романова, 19	f	small
130928	14101	406	Ярославская область, Большесельский район, поселок Варегово, Мира, 25	f	medium
130929	14102	407	Ярославская область, Большесельский район, поселок Борисовское, Молодежная, 6	f	small
80710	14099	404	Ярославская область, Большесельский район, поселок Большие Починки, Челюскинцев, 3а	f	large
80711	14104	409	Ярославская область, Большесельский район, поселок Большие Починки, Заречная, 8	f	large
130932	14106	411	Ярославская область, Большесельский район, поселок Байково, 10	f	small
131205	14446	751	Ярославская область, Большесельский район, поселок Арефино, Советская, 4	f	medium
131206	14446	752	Ярославская область, Большесельский район, поселок Арефино, Советская, 4	f	small
126053	3460	88	Тульская область, д.Сестрики, Интернациональная улица, 10	f	small
126538	4200	896	Тульская область, Ясногорск, П.Смидовича, 4	f	medium
77593	4204	900	Тульская область, Ясногорск, Машиностроителей, 7	f	large
77565	4138	834	Тульская область, Щекино, Учебная, 7	f	large
77567	4140	836	Тульская область, Щекино, Советская, 40	f	large
77540	4065	761	Тульская область, Узловая, квартал им. 50-летия Октября, 7а	f	large
77544	4068	765	Тульская область, Узловая, Завенягина, 16а	f	large
77805	94884	1134	Тульская область, Тула, поселок Южный	f	large
77804	94884	1133	Тульская область, Тула, поселок Южный	f	large
126558	4336	1130	Тульская область, Тула, поселок Озерный, 1А	f	small
126160	3639	284	Тульская область, Тула, поселок Овсянниково	f	medium
126030	201	64	Тульская область, Тула	t	small
126201	3655	326	Россия, Новосибирская область, Кочковский район, поселок Маяк	f	small
126540	4223	940	Россия, Тульская область, Тула, улица Дрейера, 33	f	medium
126553	4289	1044	Россия, Тульская область, Тула, улица Дачная, 22	f	medium
77626	4209	907	Россия, Тульская область, Тула, улица Галкина, 29	f	large
77627	4209	908	Россия, Тульская область, Тула, улица Галкина, 29	f	large
77625	4209	906	Россия, Тульская область, Тула, улица Галкина, 29	f	large
77624	4209	905	Россия, Тульская область, Тула, улица Галкина, 29	f	large
77807	4338	1136	Тульская область, Тула, микрорайон Скуратовский, 10	f	large
77806	4338	1135	Тульская область, Тула, микрорайон Скуратовский, 10	f	large
77640	4231	950	Тульская область, Тула, генерала Маргелова, 5	f	large
77706	4282	1029	Тульская область, Тула, Юлиуса Фучика, 24к1	f	large
77705	4282	1028	Тульская область, Тула, Юлиуса Фучика, 24к1	f	large
77673	4265	996	Тульская область, Тула, Щегловская Засека, 35	f	large
126552	4264	995	Тульская область, Тула, Щегловская Засека, 13	f	medium
126403	3988	683	Тульская область, Тула, Школьная, 15	f	small
77785	94878	1113	Тульская область, Тула, Шевченко, 21	f	large
77751	4307	1077	Тульская область, Тула, Халтурина, 1	f	large
77749	4306	1075	Тульская область, Тула, Фрунзе, 18	f	large
77750	4306	1076	Тульская область, Тула, Фрунзе, 18	f	large
77748	4306	1074	Тульская область, Тула, Фрунзе, 18	f	large
77779	4324	1106	Тульская область, Тула, Фридриха Энгельса, 89	f	large
77738	4299	1063	Тульская область, Тула, Фридриха Энгельса, 68	f	large
77739	4299	1064	Тульская область, Тула, Фридриха Энгельса, 68	f	large
77784	4328	1112	Тульская область, Тула, Тимирязева, 99	f	large
77648	4233	958	Тульская область, Тула, Сурикова, 5	f	large
77647	4233	957	Тульская область, Тула, Сурикова, 5	f	large
77642	4233	952	Тульская область, Тула, Сурикова, 5	f	large
77775	4319	1101	Тульская область, Тула, Староникитская, 38Б	f	large
77774	4318	1100	Тульская область, Тула, Староникитская, 107	f	large
77773	4318	1099	Тульская область, Тула, Староникитская, 107	f	large
77743	4302	1069	Тульская область, Тула, Софьи Перовской, 40	f	large
77742	4302	1068	Тульская область, Тула, Софьи Перовской, 40	f	large
77765	4314	1091	Тульская область, Тула, Сойфера, 35	f	large
77762	4311	1088	Тульская область, Тула, Сойфера, 8	f	large
77761	4311	1087	Тульская область, Тула, Сойфера, 8	f	large
77653	4237	963	Тульская область, Тула, Серебровская, 32	f	large
77652	4237	962	Тульская область, Тула, Серебровская, 32	f	large
77651	4234	961	Тульская область, Тула, Седова, 35В	f	large
77649	4234	959	Тульская область, Тула, Седова, 35В	f	large
77643	4234	953	Тульская область, Тула, Седова, 35В	f	large
77794	94882	1122	Тульская область, Тула, Рязанская, 40	f	large
83898	57331	3091	Москва, Зеленоград, к222а	f	large
77632	4225	942	Тульская область, Тула, поселок Косая Гора, Пушкина, 24	f	large
77609	4217	926	Тульская область, Тула, Пузакова, 12А	f	large
77608	4217	925	Тульская область, Тула, Пузакова, 12А	f	large
77607	4217	924	Тульская область, Тула, Пузакова, 12А	f	large
77724	4286	1048	Тульская область, Тула, Приупская, 9а	f	large
77725	4286	1049	Тульская область, Тула, Приупская, 9а	f	large
77726	4286	1050	Тульская область, Тула, Приупская, 9а	f	large
77717	4286	1040	Тульская область, Тула, Приупская, 9а	f	large
77691	4274	1014	Тульская область, Тула, Приупская, 1	f	large
77654	4238	964	Тульская область, Тула, поселок Мясново, Привокзальная, 25	f	large
77769	4315	1095	Тульская область, Тула, Перекопская, 2	f	large
77768	4315	1094	Тульская область, Тула, Перекопская, 2	f	large
77767	4315	1093	Тульская область, Тула, Перекопская, 2	f	large
77766	4315	1092	Тульская область, Тула, Перекопская, 2	f	large
77666	4248	978	Тульская область, Тула, Первомайская, 53	f	large
77656	4240	966	Тульская область, Тула, Павшинский мост, 3	f	large
77646	4235	956	Тульская область, Тула, Оружейная, 46а	f	large
77645	4235	955	Тульская область, Тула, Оружейная, 46а	f	large
77644	4235	954	Тульская область, Тула, Оружейная, 46а	f	large
77803	4337	1132	Тульская область, Тула, Октябрьская, 6	f	large
77802	4337	1131	Тульская область, Тула, Октябрьская, 6	f	large
77603	4215	920	Тульская область, Тула, Октябрьская, 199	f	large
77602	4215	919	Тульская область, Тула, Октябрьская, 199	f	large
77601	4215	918	Тульская область, Тула, Октябрьская, 199	f	large
77600	4214	917	Тульская область, Тула, Октябрьская, 201а	f	large
77623	4208	904	Тульская область, Тула, Октябрьская, 41	f	large
77655	4239	965	Тульская область, Тула, поселок Мясново, Одоевское шоссе, 25	f	large
77662	4243	972	Тульская область, Тула, поселок Мясново, Одоевское шоссе, 106	f	large
77661	4243	971	Тульская область, Тула, поселок Мясново, Одоевское шоссе, 106	f	large
77658	4236	968	Россия, Тульская область, Тула, поселок Мясново, Одоевское шоссе, 50	f	large
77650	4236	960	Россия, Тульская область, Тула, поселок Мясново, Одоевское шоссе, 50	f	large
77771	4316	1097	Тульская область, Тула, Новомосковская, 5а	f	large
77770	4316	1096	Тульская область, Тула, Новомосковская, 5а	f	large
77789	4330	1117	Тульская область, Тула, Николая Руднева, 62	f	large
77788	4330	1116	Тульская область, Тула, Николая Руднева, 62	f	large
77787	4329	1115	Тульская область, Тула, Николая Руднева, 51	f	large
77786	4329	1114	Тульская область, Тула, Николая Руднева, 51	f	large
77698	4277	1021	Тульская область, Тула, Немцова, 27	f	large
77697	4277	1020	Тульская область, Тула, Немцова, 27	f	large
126299	3806	478	Тульская область, Тула, Мира, 15	t	small
77729	4292	1053	Тульская область, Тула, Металлургов, 37	f	large
77728	4292	1052	Тульская область, Тула, Металлургов, 37	f	large
77727	4292	1051	Тульская область, Тула, Металлургов, 37	f	large
77721	4290	1045	Тульская область, Тула, Металлургов, 2	f	large
77722	4290	1046	Тульская область, Тула, Металлургов, 2	f	large
77720	4288	1043	Тульская область, Тула, Металлургов, 22	f	large
77712	4285	1035	Тульская область, Тула, Металлургов, 70к2	f	large
77778	4323	1105	Тульская область, Тула, Металлистов, 2А	f	large
77777	4322	1104	Тульская область, Тула, Менделеевская, 5	f	large
126556	4321	1103	Тульская область, Тула, Менделеевская, 5	f	medium
77798	4333	1126	Тульская область, Тула, Маяковского, 1	f	large
77799	94883	1127	Тульская область, Тула, поселок 2-й Западный, Маяковского, 39	f	large
77630	4210	911	Тульская область, Тула, Максимовского, 2	f	large
77629	4210	910	Тульская область, Тула, Максимовского, 2	f	large
77628	4210	909	Тульская область, Тула, Максимовского, 2	f	large
77617	4219	934	Тульская область, Тула, Максима Горького, 20	f	large
77616	4219	933	Тульская область, Тула, Максима Горького, 20	f	large
77615	4218	932	Тульская область, Тула, Максима Горького, 41	f	large
77614	4218	931	Тульская область, Тула, Максима Горького, 41	f	large
77613	4218	930	Тульская область, Тула, Максима Горького, 41	f	large
77612	4218	929	Тульская область, Тула, Максима Горького, 41	f	large
77611	4218	928	Тульская область, Тула, Максима Горького, 41	f	large
77610	4218	927	Тульская область, Тула, Максима Горького, 41	f	large
77637	4228	947	Тульская область, Тула, поселок Косая Гора, Максима Горького, 40	f	large
77636	4228	946	Тульская область, Тула, поселок Косая Гора, Максима Горького, 40	f	large
77597	4212	914	Тульская область, Тула, поселок Горелки, Макаренко, 3	f	large
77596	4212	913	Тульская область, Тула, поселок Горелки, Макаренко, 3	f	large
77704	4281	1027	Тульская область, Тула, Майская, 5	f	large
77710	4279	1033	Тульская область, Тула, Майская, 4	f	large
77709	4279	1032	Тульская область, Тула, Майская, 4	f	large
77708	4279	1031	Тульская область, Тула, Майская, 4	f	large
77700	4279	1023	Тульская область, Тула, Майская, 4	f	large
77730	4291	1054	Тульская область, Тула, М. Мазая, 13	f	large
77723	4291	1047	Тульская область, Тула, М. Мазая, 13	f	large
77621	4222	939	Тульская область, Тула, Луначарского, 67	f	large
77683	4269	1006	Тульская область, Тула, Ложевая, 124	f	large
77682	4269	1005	Тульская область, Тула, Ложевая, 124	f	large
77680	4269	1003	Тульская область, Тула, Ложевая, 124	f	large
77679	4269	1002	Тульская область, Тула, Ложевая, 124	f	large
77853	4221	938	Тульская область, Тула, Литейная, 25	f	large
77620	4220	937	Тульская область, Тула, Литейная, 25	f	large
77619	4220	936	Тульская область, Тула, Литейная, 25	f	large
77618	4220	935	Тульская область, Тула, Литейная, 25	f	large
77790	94879	1118	Россия, Тульская область, Тула, Ленина проспект, 125	f	large
77780	94877	1107	Россия, Тульская область, Тула, Ленина проспект, 46	f	large
77795	4332	1123	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 139а	f	large
77797	4332	1125	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 139а	f	large
77796	4332	1124	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 139а	f	large
77783	4327	1111	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 89	f	large
77782	4327	1110	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 89	f	large
77781	4327	1109	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 89	f	large
77737	4298	1062	Россия, Тульская область, Тула, Ленина проспект, 84	f	large
77736	4298	1061	Россия, Тульская область, Тула, Ленина проспект, 84	f	large
77735	4297	1060	Россия, Тульская область, Тула, Ленина проспект, 90	f	large
77734	4296	1059	Россия, Тульская область, Тула, Ленина проспект, 92	f	large
77801	4335	1129	Тульская область, Тула, поселок Менделеевский, Ленина, 11	f	large
77800	4335	1128	Тульская область, Тула, поселок Менделеевский, Ленина, 11	f	large
77745	4303	1071	Тульская область, Тула, Ленина, 21	f	large
77744	4303	1070	Тульская область, Тула, Ленина, 21	f	large
77404	3749	421	Тульская область, Тула, Ленина, 18	f	large
77719	4287	1042	Тульская область, Тула, Кутузова, 112	f	large
77718	4287	1041	Тульская область, Тула, Кутузова, 112	f	large
77714	4284	1037	Тульская область, Тула, Кутузова, 94	f	large
77713	4284	1036	Тульская область, Тула, Кутузова, 94	f	large
77711	4284	1034	Тульская область, Тула, Кутузова, 94	f	large
77764	4313	1090	Тульская область, Тула, Коминтерна, 22	f	large
77763	4312	1089	Тульская область, Тула, Коминтерна, 21	f	large
77692	4275	1015	Тульская область, Тула, Кирова, 162а	f	large
77694	4263	1017	Тульская область, Тула, Кирова, 171	f	large
77672	4263	994	Тульская область, Тула, Кирова, 171	f	large
77671	4263	993	Тульская область, Тула, Кирова, 171	f	large
77693	4262	1016	Тульская область, Тула, Кирова, 186	f	large
77670	4262	992	Тульская область, Тула, Кирова, 186	f	large
77669	4261	991	Тульская область, Тула, Кирова, 135	f	large
126176	85233	300	Тульская область, Тула, поселок Октябрьский, Киреевская	f	small
77772	4317	1098	Тульская область, Тула, Кауля, 9к4	f	large
77641	4232	951	Тульская область, Тула, Карбышева, 20А	f	large
77639	4230	949	Россия, Тульская область, Тула, Калужское шоссе, 9	f	large
77664	4230	975	Россия, Тульская область, Тула, Калужское шоссе, 9	f	large
77687	4271	1010	Тульская область, Тула, Калинина, 22К5	f	large
77686	4271	1009	Тульская область, Тула, Калинина, 22К5	f	large
77685	4270	1008	Тульская область, Тула, Калинина, 7	f	large
77684	4270	1007	Тульская область, Тула, Калинина, 7	f	large
77681	4270	1004	Тульская область, Тула, Калинина, 7	f	large
77689	4272	1012	Тульская область, Тула, Замочная, 105	f	large
77690	4273	1013	Тульская область, Тула, Епифанская, 189	f	large
77660	4242	970	Тульская область, Тула, поселок Мясново, Дружбы, 32	f	large
77659	4242	969	Тульская область, Тула, поселок Мясново, Дружбы, 32	f	large
77760	4310	1086	Тульская область, Тула, Демонстрации, 6	f	large
77759	4310	1085	Тульская область, Тула, Демонстрации, 6	f	large
77758	4310	1084	Тульская область, Тула, Демонстрации, 6	f	large
77665	4247	977	Тульская область, Тула, Демонстрации, 134	f	large
77854	4246	976	Тульская область, Тула, Демонстрации, 201	f	large
77675	4267	998	Тульская область, Тула, Демидовская Плотина, 37	f	large
77747	4305	1073	Тульская область, Тула, Гоголевская, 92	f	large
77606	4216	923	Тульская область, Тула, Герцена, 50	f	large
77605	4216	922	Тульская область, Тула, Герцена, 50	f	large
77604	4216	921	Тульская область, Тула, Герцена, 50	f	large
77678	4268	1001	Тульская область, Тула, Гармонная, 37	f	large
77677	4268	1000	Тульская область, Тула, Гармонная, 37	f	large
77676	4268	999	Тульская область, Тула, Гармонная, 37	f	large
77622	4207	903	Тульская область, Тула, Галкина, 14	f	large
77638	4229	948	Тульская область, Тула, поселок Косая Гора, Гагарина, 1	f	large
77631	4224	941	Тульская область, Тула, Гагарина, 3	f	large
77792	94880	1120	Тульская область, Тула, Волоховская, 7	f	large
77791	4331	1119	Тульская область, Тула, Волоховская, 7	f	large
77707	4283	1030	Тульская область, Тула, Вильямса, 26а	f	large
77715	4278	1038	Тульская область, Тула, Вильямса, 10	f	large
77701	4278	1024	Тульская область, Тула, Вильямса, 10	f	large
77699	4278	1022	Тульская область, Тула, Вильямса, 10	f	large
77757	4309	1083	Тульская область, Тула, Вересаева, 10	f	large
77756	4309	1082	Тульская область, Тула, Вересаева, 10	f	large
77755	4309	1081	Тульская область, Тула, Вересаева, 10	f	large
77746	4304	1072	Тульская область, Тула, Вересаева, 12	f	large
77741	4301	1067	Тульская область, Тула, Бундурина, 45	f	large
77740	4301	1066	Тульская область, Тула, Бундурина, 45	f	large
77733	4295	1058	Тульская область, Тула, Болдина, 100	f	large
77732	4295	1057	Тульская область, Тула, Болдина, 100	f	large
77731	4293	1055	Тульская область, Тула, Болдина, 47	f	large
77595	4211	912	Тульская область, Тула, поселок Хомяково, Березовская, 2	f	large
77695	4266	1018	Тульская область, Тула, Баженова, 25	f	large
77674	4266	997	Тульская область, Тула, Баженова, 25	f	large
77663	4244	973	Россия, Тульская область, Тула, поселок Мясново, 6-й Полюсный проезд, 16	f	large
77599	4213	916	Тульская область, Тула, 18-й проезд, 2	f	large
77598	4213	915	Тульская область, Тула, 18-й проезд, 2	f	large
77702	4280	1025	Тульская область, Тула, 1-й Металлургов проезд, 7	f	large
77716	4280	1039	Тульская область, Тула, 1-й Металлургов проезд, 7	f	large
77703	4280	1026	Тульская область, Тула, 1-й Металлургов проезд, 7	f	large
126262	3764	436	Тульская область, Тула, Школьная, 28	f	small
126489	4115	812	Тульская область, Тула, Центральная, 8	f	small
77846	3999	694	Тульская область, Суворов, Тульская, 21	f	large
126279	3784	456	Тульская область, поселок Серебряные Ключи, Парковая, 55	f	small
77427	3809	481	Тульская область, поселок Плеханово, Ленина , 45	f	large
77430	3812	485	Тульская область, поселок Плеханово, Заводская, 19	f	large
77429	3812	484	Тульская область, поселок Плеханово, Заводская, 19	f	large
77428	3810	482	Тульская область, поселок Плеханово, Заводская, 16	f	large
77515	3966	661	Тульская область, Плавск, Победы, 22	f	large
77514	3966	660	Тульская область, Плавск, Победы, 22	f	large
77397	3740	411	Тульская область, Киреевск, Чехова, 6а	f	large
77386	3687	360	Тульская область, Кимовск, Островского, 8	f	large
77833	3633	277	Тульская область, Ефремов, Мира, 2а	f	large
77820	3625	263	Тульская область, Ефремов, Дачная, 4	f	large
77362	3598	229	Тульская область, Донской, Школьная, 11, мкр. Комсомольский	f	large
77361	3597	228	Тульская область, Донской, Школьная, 4	f	large
77355	3589	220	Тульская область, Донской, Школьная, 18	f	large
126135	3590	221	Тульская область, Донской, Тургенева, 1	f	medium
126133	3586	217	Тульская область, Донской, Стахановская, 40	f	medium
126131	3584	215	Тульская область, Донской, Советская, 16	f	medium
77363	3599	230	Тульская область, Донской, Свердлова, 2а	f	large
77347	3577	208	Тульская область, Донской, Первомайская, 1	f	large
77353	3583	214	Тульская область, Донской, Октябрьская, 18	f	large
77350	3580	211	Тульская область, Донской, Октябрьская, 55а	f	large
77349	3579	210	Тульская область, Донской, Октябрьская, 46	f	large
77346	3576	207	Тульская область, Донской, Октябрьская, 91, мкр. Центральный	f	large
77345	3575	206	Тульская область, Донской, Октябрьская, 105	f	large
77344	3574	205	Тульская область, Донской, Октябрьская, 96	f	large
77348	3578	209	Тульская область, Донской, Новая, 50	f	large
126136	3596	227	Тульская область, Донской, Ленина, 8а	f	medium
77360	3595	226	Тульская область, Донской, Ленина, 36	f	large
77357	3592	223	Тульская область, Донской, Ленина, 19	f	large
77356	3591	222	Тульская область, Донской, Ленина, 7	f	large
77365	3601	232	Тульская область, Донской, Кирпичная, 7а	f	large
77367	3604	235	Тульская область, Донской, Кирова, 12	f	large
126137	3603	234	Тульская область, Донской, Индустриальная, 1	f	medium
77366	3602	233	Тульская область, Донской, Индустриальная, 7	f	large
77351	3581	212	Тульская область, Донской, Заводская, 22	f	large
77358	3593	224	Тульская область, Донской, Горького, 9, мкр. Северо-Задонск	f	large
77359	3594	225	Тульская область, Донской, Вахрушева, 34, мкр. Северо-Задонск	f	large
77343	3573	204	Тульская область, Донской, 328 Стрелковой дивизии, 10, мкр. Центральный	f	large
77354	3588	219	Тульская область, Донской, 30 лет Победы, 4	f	large
77364	3600	231	Тульская область, Донской, 10 Армии, 1а, мкр. Руднев	f	large
77323	3488	120	Тульская область, Богородицк, Шахтная, 5	f	large
77322	3487	119	Тульская область, Богородицк, Западный МКР, 22	f	large
77352	3582	213	Тульская область, мкр. Центральный, Донской, Заводская, 11а	f	large
126132	3585	216	Тульская область, мкр Центральный,, Донской, Советская, 1	f	medium
77589	4199	895	Тульская область, Ясногорский район, Ясногорск, Южная, 8	f	large
77590	4201	897	Тульская область, Ясногорский район, Ясногорск, Л.Толстого, 1	f	large
77591	4202	898	Тульская область, Ясногорский район, Ясногорск, Комсомольская, 5	f	large
77594	4205	901	Тульская область, Ясногорский район, Ясногорск, Карбышева, 1	f	large
77588	4198	894	Тульская область, Ясногорский район, Ясногорск, Горького, 3	f	large
77592	4203	899	Тульская область, Ясногорский район, Ясногорск, Гайдара, 8	f	large
126175	84611	299	Тульская область, Ясногорский район, поселок Шилово	f	medium
126537	4196	892	Тульская область, Ясногорский район, поселок Хотушь, Школьная, 31	f	small
126525	4184	880	Тульская область, Ясногорский район, поселок Федяшево, Учительская, 6	f	small
126521	4180	876	Тульская область, Ясногорский район, поселок Тормино, Садовая, 14	t	small
126520	4179	875	Тульская область, Ясногорский район, поселок Тормино, Садовая, 14	f	medium
126536	4195	891	Тульская область, Ясногорский район, поселок Теляково, Мира, 5-Б	f	medium
126205	3660	331	Тульская область, Ясногорский район, поселок Страхово, Экспериментальная, 14	f	medium
126535	4194	890	Тульская область, Ясногорский район, колхоз Спицинский, Центральная, 4	f	small
126534	4193	889	Тульская область, Ясногорский район, поселок Санталовский, Зеленая, 5	f	medium
126519	4178	874	Тульская область, Ясногорский район, поселок Ревякино, Центральная, 12	f	medium
77587	4197	893	Тульская область, Ясногорский район, поселок Ревякино, Советская, 12	f	large
126381	3959	652	Тульская область, Ясногорский район, поселок Мызовка, 1а	f	small
126390	3974	669	Тульская область, Ясногорский район, поселок Михайловское, Новая, 4	t	small
126079	3509	140	Тульская область, Ясногорский район, поселок Каменка, 33	f	small
126528	4187	883	Тульская область, Ясногорский район, поселок Есуковский, Центральная, 19	t	small
126373	3951	644	Тульская область, Ясногорский район, поселок Денисово, Центральная, 9	f	small
126524	4183	879	Тульская область, Ясногорский район, поселок Денисово, Советская, 72	f	small
126527	4186	882	Тульская область, Ясногорский район, поселок Григорьевское, Центральная, 3	t	small
126532	4191	887	Тульская область, Ясногорский район, поселок Воловниково, Мира, 20	t	small
134677	95002	886	Тульская область, Ясногорский район, поселок Верхнее Красино, 63	t	small
126523	4182	878	Тульская область, Ясногорский район, поселок Бураково, Молодежная, 18	f	small
126522	4181	877	Тульская область, Ясногорский район, поселок Боровковский, Школьная, 12	f	medium
126526	4185	881	Тульская область, Ясногорский район, поселок Богословское, Студенческая, 3	f	medium
77835	3666	337	Тульская область, Ясногорский район, поселок Архангельское, Тихомирова, 28	f	large
77453	3879	554	Тульская область, Щекинский район, поселок Ясная Поляна, Школьная, 142а	f	large
126028	30	62	Тульская область, Щекинский район, поселок Ясенки	f	small
126342	3880	555	Тульская область, Щекинский район, поселок Юбилейный, 6	f	medium
77557	4129	825	Тульская область, Щекинский район, Щекино, Юбилейная, 1	f	large
77556	4128	824	Тульская область, Щекинский район, Щекино, Юбилейная, 2	f	large
77575	4148	844	Тульская область, Щекинский район, Щекино, Стволовая, 3	f	large
77563	4135	831	Тульская область, Щекинский район, Щекино, Спортивная, 20	f	large
77566	4139	835	Тульская область, Щекинский район, Щекино, Свободы, 10	f	large
77569	4142	838	Тульская область, Щекинский район, Щекино, Пролетарская, 10	f	large
77576	4149	845	Тульская область, Щекинский район, Щекино, Пионерская, 39	f	large
77574	4147	843	Тульская область, Щекинский район, Щекино, Пионерская, 5	f	large
77559	4131	827	Тульская область, Щекинский район, Щекино, Мира, 18	f	large
77558	4130	826	Тульская область, Щекинский район, Щекино, Мира, 14	f	large
77562	4134	830	Тульская область, Щекинский район, Щекино, Лукашина, 2в	f	large
77561	4134	829	Тульская область, Щекинский район, Щекино, Лукашина, 2в	f	large
77573	4146	842	Тульская область, Щекинский район, Щекино, Лизы Шамшиковой, 18	f	large
77572	4145	841	Тульская область, Щекинский район, Щекино, Лизы Шамшиковой, 18а	f	large
77571	4144	840	Тульская область, Щекинский район, Щекино, Ленина, 36	f	large
77570	4143	839	Тульская область, Щекинский район, Щекино, Ленина, 45	f	large
77568	4141	837	Тульская область, Щекинский район, Щекино, Ленина, 58	f	large
77564	4136	832	Тульская область, Щекинский район, Щекино, Комсомольская, 32а	f	large
77560	4133	828	Тульская область, Щекинский район, Щекино, Коммунальная, 7	f	large
126501	4137	833	Тульская область, Щекинский район, Щекино, Болдина, 121	f	small
126346	3884	559	Тульская область, Щекинский район, поселок Шахтерский, Центральная, 20	f	small
126040	791	74	Тульская область, Щекинский район, поселок Центральный	f	small
126415	4010	705	Тульская область, Щекинский район, поселок Центральный, Ленина, 37	f	medium
126513	4170	866	Тульская область, Щекинский район, поселок Царево, 42а	f	small
126282	3787	459	Тульская область, Щекинский район, поселок Стублевка	f	small
126516	4173	869	Тульская область, Щекинский район, поселок Социалистический, Трудовая, 2	f	medium
77580	4154	850	Тульская область, Щекинский район, Советск, Энергетиков, 17а	f	large
77579	4153	849	Тульская область, Щекинский район, Советск, Энергетиков, 60	f	large
77581	4155	851	Тульская область, Щекинский район, Советск, Школьная, 2	f	large
126345	3883	558	Тульская область, Щекинский район, поселок Селиваново, Советская, 15	f	medium
126507	4162	858	Тульская область, Щекинский район, поселок Пришня, А.Н.Козаченко, 2а	f	medium
126512	4169	865	Тульская область, Щекинский район, поселок Пирогово 1-е, 25а	f	small
126503	4157	853	Тульская область, Щекинский район, поселок Огаревка, Шахтёрская, 108	f	medium
77582	4156	852	Тульская область, Щекинский район, поселок Огаревка, Клубная, 14	f	large
126504	4158	854	Тульская область, Щекинский район, поселок Никольское, Речная, 20	f	small
77586	4176	872	Тульская область, Щекинский район, поселок Мясоедово, 22а	f	large
126506	4160	856	Тульская область, Щекинский район, поселок Малынь, 18	f	small
126349	3887	562	Тульская область, Щекинский район, поселок Майский	f	medium
126244	3716	387	Тульская область, Щекинский район, поселок Львово, 88	f	medium
126509	4166	862	Тульская область, Щекинский район, поселок Лукино, Куприянова, 21	f	small
77585	4174	870	Тульская область, Щекинский район, поселок Ломинцевский, Центральная, 6	f	large
126517	4175	871	Тульская область, Щекинский район, поселок Ломинцево, Центральная, 138	f	small
126511	4168	864	Тульская область, Щекинский район, поселок Липово, Школьная, 18	f	small
126508	4165	861	Тульская область, Щекинский район, поселок Лапотково, 12б	f	small
77584	4164	860	Тульская область, Щекинский район, поселок Лазарево, Тульская, 16	f	large
77583	4161	857	Тульская область, Щекинский район, поселок Крапивна, Коммунаров, 31а	f	large
126530	4189	885	Тульская область, Щекинский район, поселок Климовское, Центральная, 31	f	small
77852	4163	859	Тульская область, Щекинский район, поселок Карамышево, Школьная, 1А	f	large
126461	4081	781	Россия, Республика Бурятия, Кабанский район, село Ивановка	f	small
126510	4167	863	Тульская область, Щекинский район, поселок Грецовка, Молодежная, 1б	f	small
126348	3886	561	Тульская область, Щекинский район, поселок Горячкино, Центральная, 17	f	medium
126343	3881	556	Тульская область, Щекинский район, поселок Головеньковский, Шахтерская, 30	f	medium
126344	3882	557	Тульская область, Щекинский район, поселок Большая Тросна, Агрохимиков, 33	f	medium
126518	4177	873	Тульская область, Щекинский район, поселок Архангельское, Бритикова, 4	f	medium
126505	4159	855	Тульская область, Щекинский район, поселок Алимкина, Комсомольская, 2	f	medium
126482	4105	805	Тульская область, Чернский район, поселок Чернь, Производственная, 1	f	small
77555	4094	794	Тульская область, Чернский район, поселок Чернь, Космонавтов, 29, ЧСШ №1	f	large
77554	4093	793	Тульская область, Чернский район, поселок Чернь, К.Маркса, 22, РДК	f	large
126496	4122	819	Тульская область, Чернский район, поселок Тургенево, Школьная, 9	f	small
126492	4118	815	Тульская область, Чернский район, поселок Троицкое-Бочурино, Центральная, 1	f	small
126167	3497	291	Россия, Омская область, Омск, поселок Степной	f	small
126484	4107	807	Тульская область, Чернский район, поселок Степной, Школьная, 17	f	small
77850	4095	795	Тульская область, Чернский район, поселок Станция Скуратово, Перронная, 8	f	large
126498	4124	821	Тульская область, Чернский район, поселок Спартак, Центральная, 12	f	small
126473	4096	796	Тульская область, Чернский район, поселок Скуратовский, А.Скуратова, 27	f	medium
126486	4110	809	Тульская область, Чернский район, поселок Синегубово 1-е, Центральная, 14	f	small
126316	3843	516	Россия, Вологодская область, Сямженский район, село Слободка	f	medium
126497	4123	820	Тульская область, Чернский район, поселок Поповка 1-я, Школьная, 4	f	medium
126495	4121	818	Тульская область, Чернский район, поселок Полтево, Молодежная, 20	f	small
126500	4127	823	Тульская область, Чернский район, поселок Подгорный, Центральная, 12	f	small
126386	3964	657	Тульская область, Чернский район, поселок Петровское, Школьная, 171	f	small
126477	4100	800	Тульская область, Чернский район, поселок Николо-Вяземское, В.С.Усова, 11	f	small
126483	4106	806	Тульская область, Чернский район, поселок Малое Скуратово, Совхозная, 1 а	f	small
77372	85631	302	Россия, Пермский край, Пермский район, село Лобаново	f	large
126487	4112	810	Тульская область, Чернский район, поселок Липицы, Школьная, 14	f	small
77432	3822	496	Россия, Тульская область, Чернский район, поселок Ленинский	f	large
126488	4114	811	Тульская область, Чернский район, поселок Левое Молчаново, Свободная, 6а	f	small
126485	4109	808	Тульская область, Чернский район, поселок Кресты, Центральная, 52	f	small
126490	4116	813	Тульская область, Чернский район, поселок Красный Путь, Центральная, 4	f	small
126240	3712	383	Тульская область, Чернский район, поселок Краснополье, 187	f	small
126481	4104	804	Тульская область, Чернский район, поселок Коженка, Луговая, 1А	f	small
126493	4119	816	Тульская область, Чернский район, поселок Жизнь, Советская, 5а	f	small
126480	4103	803	Тульская область, Чернский район, поселок Ержино, Центральная, 7	f	small
126494	4120	817	Тульская область, Чернский район, поселок Дьяково, Центральная, 4	f	small
126476	4099	799	Тульская область, Чернский район, поселок Долматово, Юбилейная, 2	f	small
126475	4098	798	Тульская область, Чернский район, поселок Воропаевский, Грушелевского, 17	f	small
126499	4125	822	Тульская область, Чернский район, поселок Велье-Никольское, Победы, 48	f	medium
126474	4097	797	Тульская область, Чернский район, поселок Бредихино 1-е, Садовая, 12	f	small
126478	4101	801	Тульская область, Чернский район, поселок Архангельское, Л.Н.Толстого, 21	f	medium
126338	3870	544	Тульская область, Узловский район, поселок Шаховское	f	small
126293	3800	472	Тульская область, Узловский район, поселок Шаховское, Школьная, 5	f	small
126458	4078	775	Тульская область, Узловский район, поселок Хитрово, 53	f	small
77539	4064	760	Тульская область, Узловский район, Узловая, квартал им. 50-летия Октября, 7а	f	large
77546	94876	767	Тульская область, Узловский район, Узловая, Чехова, 13	f	large
77449	3873	547	Тульская область, Узловский район, Узловая, Центральная, 6	f	large
77448	3872	546	Тульская область, Узловский район, Узловая, Тульская, 13	f	large
77535	4061	756	Тульская область, Узловский район, Узловая, Трудовые резервы, 7	f	large
77849	4059	755	Тульская область, Узловский район, Узловая, Трудовые резервы, 13	f	large
77446	3869	543	Тульская область, Узловский район, Узловая, Смоленского, 9а	f	large
77445	3868	542	Тульская область, Узловский район, Узловая, Смоленского, 3	f	large
77534	4058	754	Тульская область, Узловский район, Узловая, Октябрьская, 21	f	large
77542	4066	763	Тульская область, Узловский район, Узловая, Мира, 5а	f	large
77541	4066	762	Тульская область, Узловский район, Узловая, Мира, 5а	f	large
77447	3871	545	Тульская область, Узловский район, Узловая, Мира, 1	f	large
77533	4057	753	Тульская область, Узловский район, Узловая, Кирова, 4	f	large
77538	4063	759	Тульская область, Узловский район, Узловая, Заводская, 1а	f	large
77543	4067	764	Тульская область, Узловский район, Узловая, Завенягина, 32	f	large
77530	4054	750	Тульская область, Узловский район, Узловая, Горняцкая, 1	f	large
77545	4069	766	Тульская область, Узловский район, Узловая, Генерала Васильева, 1	f	large
77528	4052	748	Тульская область, Узловский район, Узловая, Гагарина, 16а	f	large
77531	4055	751	Тульская область, Узловский район, Узловая, Володарского, 5	f	large
77532	4056	752	Тульская область, Узловский район, Узловая, Беклемищева, 48	f	large
77529	4053	749	Тульская область, Узловский район, Узловая, Беклемищева, 83	f	large
77536	4062	757	Тульская область, Узловский район, Узловая, 14 Декабря, 32	f	large
77537	4062	758	Тульская область, Узловский район, Узловая, 14 Декабря, 32	f	large
126457	4077	774	Россия, Тульская область, Веневский район, поселок Торбеевка	f	medium
126463	4083	783	Тульская область, Узловский район, поселок Смородино, 216	f	medium
126462	4082	782	Тульская область, Узловский район, поселок Прилесье, 81	f	small
77551	4075	772	Тульская область, Узловский район, поселок Партизан, Льва Толстого, 16	f	large
77552	4079	776	Тульская область, Узловский район, поселок Майский, переулок Клубный, 1	f	large
126340	3877	551	Тульская область, Узловский район, поселок Люторичи	f	small
77553	4060	778	Тульская область, Узловский район, поселок Каменецкий, Центральная, 4	f	large
126456	4076	773	Тульская область, Узловский район, поселок Ильинка, Центральная, 39	f	medium
126292	3799	471	Тульская область, Узловский район, поселок Ивановка, Советская, 6	f	small
126466	4086	786	Кировская область, Арбажский район, село Дубовое	f	small
77550	4074	771	Тульская область, Узловский район, поселок Дубовка, Театральная, 1	f	large
77548	4072	769	Тульская область, Узловский район, поселок Дубовка, Советская, 20	f	large
77549	4073	770	Тульская область, Узловский район, поселок Дубовка, Пионерская, 30	f	large
77547	4071	768	Тульская область, Узловский район, поселок Дубовка, Комсомольская, 2В	f	large
126464	4084	784	Тульская область, Узловский район, поселок Волково, 59а	t	small
126468	4088	788	Тульская область, Узловский район, поселок Бутырки, 79	f	small
77451	3875	549	Тульская область, Узловский район, поселок Брусянский, Советская, 1	f	large
77450	3874	548	Тульская область, Узловский район, поселок Брусянский, Пугачёва, 53	f	large
126341	87712	552	Тульская область, Узловский район, поселок Бестужевский	f	small
77578	4152	848	Тульская область, Тула городской округ, поселок Первомайский, Школьная, 8	f	large
126440	4036	732	Тульская область, Тепло-Огаревский район, поселок Центральный, Центральная, 11	f	medium
126339	3876	550	Тульская область, Тепло-Огаревский район, поселок Федоровка, Школьная, 1А	f	medium
126479	4102	802	Тульская область, Тепло-Огаревский район, поселок Успенское, Успенская, 19	f	small
126444	4040	736	Тульская область, Тепло-Огаревский район, поселок Троекурово, 55	t	small
126451	4047	743	Тульская область, Тепло-Огаревский район, поселок Теплое, Сельхозтехниковская,, 14 А	f	medium
126443	4039	735	Тульская область, Тепло-Огаревский район, поселок Стрешнево, 16	f	small
126333	3863	537	Тульская область, Тепло-Огаревский район, поселок Северный, Прудная, 7	f	small
76775	2359	961	Тверская область, Тверь, поселок Литвинки	f	large
126448	4044	740	Тульская область, Тепло-Огаревский район, поселок Мосюковка, Центральная, 32	t	small
126330	3860	534	Тульская область, Тепло-Огаревский район, поселок Мичуринский, 30	f	medium
126332	3862	536	Россия, Московская область, Сергиево-Посадский район, поселок Механизаторов	f	medium
126447	4043	739	Тульская область, Тепло-Огаревский район, поселок Малая Огаревка, Школьная, 2 А	f	small
126442	4038	734	Тульская область, Тепло-Огаревский район, поселок Крюковка 1-я, Центральная, 3	f	small
126334	3864	538	Тульская область, Тепло-Огаревский район, поселок Красногвардеец	f	small
126329	3859	533	Тульская область, Тепло-Огаревский район, поселок Кировский, Центральная, 11	f	small
126337	3867	541	Тульская область, Тепло-Огаревский район, поселок Доробино, 70	t	small
126331	3861	535	Тульская область, Тепло-Огаревский район, поселок Горьковский, 70	t	medium
126336	3866	540	Тульская область, Тепло-Огаревский район, поселок Волчья Дубрава, Колоскова, 3	f	small
126449	4045	741	Тульская область, Тепло-Огаревский район, поселок Бродиловка, Молодежная, 19	f	small
126335	3865	539	Тульская область, Тепло-Огаревский район, поселок Большое Огарево, Базарная, 26	f	small
126441	4037	733	Тульская область, Тепло-Огаревский район, поселок Большое Минино, 69 квартира 2	f	small
126426	4021	717	Тульская область, Тепло-Огаревский район, поселок Богданово, 1	t	small
77527	4028	724	Тульская область, Суворовский район, поселок Черепеть, Молодежная, 4	f	large
126412	4006	701	Тульская область, Суворовский район, Чекалин, Чекалина, 1А	f	small
126411	4005	700	Тульская область, Суворовский район, Чекалин, Чекалина, 1А	f	small
77848	4011	706	Тульская область, Суворовский район, поселок Центральный, Машиностроителей, 5А	f	large
126425	4020	716	Тульская область, Суворовский район, поселок Ханино, Молодежная, 3	f	small
126424	4019	715	Тульская область, Суворовский район, поселок Ханино, Заводская, 6	f	medium
77521	3996	691	Тульская область, Суворовский район, Суворов, пл. Победы, 1 А	f	large
77520	3995	690	Тульская область, Суворовский район, Суворов, Суворова, 7	f	large
77522	3997	692	Тульская область, Суворовский район, Суворов, Проспект Мира, 20	f	large
77525	4002	697	Тульская область, Суворовский район, Суворов, Пионерская, 4	f	large
77523	3998	693	Тульская область, Суворовский район, Суворов, Пионерская, 11	f	large
126409	4003	698	Тульская область, Суворовский район, Суворов, Октябрьская, 4	f	small
77524	4001	696	Тульская область, Суворовский район, Суворов, Ленинского Юбилея, 4	f	large
77845	3994	689	Тульская область, Суворовский район, Суворов, Белинского, 18	f	large
77847	4000	695	Тульская область, Суворовский район, Суворов, Тульская, 5	f	large
126423	87774	714	Тульская область, Суворовский район, поселок Селюково, 1	f	small
126437	4033	729	Тульская область, Суворовский район, поселок Северо-Агеевский, 5	f	small
126428	4023	719	Тульская область, Суворовский район, поселок Своино, 18	t	small
126419	4015	710	Тульская область, Суворовский район, поселок Песоченский, Ленина, 12	f	small
126432	4027	723	Тульская область, Суворовский район, поселок Песковатское, 63	f	small
126433	4029	725	Тульская область, Суворовский район, поселок Новая Черепеть, За мир, 1	f	small
126420	4016	711	Тульская область, Суворовский район, поселок Машковичи, 86	f	small
126429	4024	720	Тульская область, Суворовский район, поселок Марково, 56	f	small
126427	4022	718	Тульская область, Суворовский район, поселок Малиновка, 1	t	small
126438	4034	730	Тульская область, Суворовский район, поселок Лужковский, 60 лет СССР, 9	f	small
126435	4031	727	Тульская область, Суворовский район, поселок Курорт Краинка, ДК ООО ""Санаторий (кур-т) ""Краинка"""	f	medium
126418	4014	709	Тульская область, Суворовский район, поселок Кулешово, 40 лет Победы, 31	t	small
126422	4018	713	Тульская область, Суворовский район, поселок Зеленино, 71	f	small
126439	4035	731	Тульская область, Суворовский район, поселок Збродовский, Полевая, 29	f	small
126430	4025	721	Тульская область, Суворовский район, Желоба-1, 21	f	small
126416	4012	707	Тульская область, Суворовский район, поселок Глубоковский, Глубокая, 1А	f	small
126421	4017	712	Тульская область, Суворовский район, поселок Бряньково, 100	t	small
126013	3441	43	Тульская область, Суворовский район, поселок Борисово, Южная	f	small
126259	3739	410	Свердловская область, Березовский, улица Луговая, 5	f	medium
126417	4013	708	Тульская область, Суворовский район, поселок Березово, Романова, 25	t	small
126414	4008	703	Тульская область, Суворовский район, Агеево, улица Комсомольская, 10	f	small
77635	4226	945	Тульская область, Привокзальный, Тула, Гагарина, 2	f	large
77633	4226	943	Тульская область, Привокзальный, Тула, Гагарина, 2	f	large
126408	3993	688	Тульская область, Плавский район, поселок Юсупово, Школьная, 3	f	small
126406	3991	686	Тульская область, Плавский район, поселок Юрьевский, 21	f	small
126400	3985	680	Тульская область, Плавский район, поселок Стройка, Центральная, 36	f	small
126514	4171	867	Тульская область, Плавский район, поселок Сорочинка, Школьная, 29	f	small
126393	3977	672	Тульская область, Плавский район, поселок Сорочинка, Центральная, 25	f	small
126391	3975	670	Тульская область, Плавский район, поселок Советский, Почтовая, 13	f	medium
126398	3983	678	Тульская область, Плавский район, поселок Савватеевка, Центральная, 21	t	small
126434	4030	726	Тульская область, Плавский район, поселок Рождествено 1-е, 247	f	medium
126388	3971	666	Тульская область, Плавский район, Плавск, 19, поселок Белая Гора	f	medium
77517	3970	665	Тульская область, Плавский район, Плавск, Тимофеева, 7А	f	large
77518	3972	667	Тульская область, Плавский район, Плавск, Орлова, 10	f	large
126387	3967	662	Тульская область, Плавский район, Плавск, Ленина, 4	f	medium
77844	3969	664	Тульская область, Плавский район, Плавск, Коммунаров, 25	f	large
77516	3968	663	Тульская область, Плавский район, Плавск, Коммунаров, 25	f	large
77513	3965	659	Тульская область, Плавский район, Плавск, Коммунаров, 68	f	large
77512	3965	658	Тульская область, Плавский район, Плавск, Коммунаров, 68	f	large
126515	4172	868	Тульская область, Плавский район, поселок Новоникольское, 36а	f	small
126401	3986	681	Тульская область, Плавский район, поселок Новое Жуково, Школьная, 26	f	small
77519	3981	676	Тульская область, Плавский район, поселок Молочные Дворы, Парковая, 2	f	large
126394	3978	673	Тульская область, Плавский район, поселок Мещерино, Центральная, 17	f	medium
126404	3989	684	Тульская область, Плавский район, поселок Крекшино, Шоссейная, 75	t	small
126407	3992	687	Тульская область, Плавский район, поселок Красногорье, Центральная, 6	f	small
126392	3976	671	Тульская область, Плавский район, поселок Камынино, Парковая, 1	f	small
126396	3980	675	Тульская область, Плавский район, поселок Ивановское 1-е, Центральная, 14	f	small
126395	3979	674	Тульская область, Плавский район, поселок Диктатура, Школьная, 1	f	small
126402	3987	682	Тульская область, Плавский район, поселок Гремячево, Молодежная, 6	f	small
126389	3973	668	Тульская область, Плавский район, поселок Горбачево, Школьная, 18	f	medium
126399	3984	679	Тульская область, Плавский район, поселок Большие Озерки, Школьная, 2	f	small
126378	3956	649	Тульская область, Одоевский район, поселок Ченцовы Дворы, Школьная, 9	t	small
126385	3963	656	Тульская область, Одоевский район, поселок Стрелецкий, площадь Стрелецкая, 101	f	medium
126379	3957	650	Тульская область, Одоевский район, поселок Стояново, Центральная, 7а	t	small
126383	3961	654	Тульская область, Одоевский район, поселок Сомово, Шарова, 15	f	small
126376	3954	647	Тульская область, Одоевский район, лесничество Северо-Ватцевское, Центральная, 17	f	small
126380	3958	651	Тульская область, Одоевский район, поселок Рылево, Центральная, 28а	f	small
126374	3952	645	Тульская область, Одоевский район, поселок Окороково, 40	f	small
77510	3949	642	Тульская область, Одоевский район, поселок Одоев, Победы, 4	f	large
126372	3948	641	Тульская область, Одоевский район, поселок Одоев, Ленина, 25а	f	medium
77511	3950	643	Тульская область, Одоевский район, поселок Одоев, Карла Маркса, 150	f	large
77509	3947	640	Тульская область, Одоевский район, поселок Одоев, 50 лет Октября, 80а	f	large
126384	3962	655	Тульская область, Одоевский район, поселок Николо-Жупань, Молодежная, 79	f	small
126049	1474	84	Тульская область, Одоевский район, поселок Мишенское, Бунина, 75	t	small
126377	3955	648	Тульская область, Одоевский район, поселок Жемчужниково, Школьная, 32	f	small
77370	3608	239	Тульская область, Одоевский район, поселок Воскресенское, Дружбы, 30	f	large
126382	3960	653	Тульская область, Одоевский район, поселок Ботвиньево, Луговая, 10	f	small
126056	3463	91	Россия, Вологодская область, Кирилловский район, село Березово	f	small
126375	3953	646	Тульская область, Одоевский район, поселок Апухтино, Центральная, 1	f	medium
126363	3938	631	Тульская область, Новомосковский район, поселок Шишлово, Центральная, 32	f	small
77506	3931	624	Тульская область, Новомосковский район, поселок Ширинский, Зеленая, 25	f	large
126364	3939	632	Тульская область, Новомосковский район, поселок Холтобино, Гукова, 37	t	small
126042	856	76	Тульская область, Новомосковский район, Хлопово	f	small
126361	3936	629	Тульская область, Новомосковский район, поселок Савино, Школьная, 3	t	small
126355	3927	620	Тульская область, Новомосковский район, поселок Рига-Васильевка, 62	f	small
126185	86470	310	Россия, Пензенская область, Пенза, улица Пушкари	f	medium
126368	3943	636	Тульская область, Новомосковский район, поселок Правда, Молодежная, 11	f	small
126533	4192	888	Тульская область, Новомосковский район, поселок Первомайский, Советская, 2	f	small
126502	4150	846	Тульская область, Новомосковский район, поселок Первомайский, Пролетарская, 1	f	small
126285	3790	462	Тульская область, Новомосковский район, поселок Орловка, 2	f	small
126359	3933	626	Тульская область, Новомосковский район, поселок Ольховец, Победы, 35	f	small
126360	3934	627	Тульская область, Новомосковский район, поселок Озерки, Центральная, 11	t	small
77471	3903	581	Тульская область, Новомосковский район, Новомосковск, проспект Победы, 7-б	f	large
77470	3903	580	Тульская область, Новомосковский район, Новомосковск, проспект Победы, 7-б	f	large
77469	3902	579	Тульская область, Новомосковский район, Новомосковск, проспект Победы, 4	f	large
77467	3902	577	Тульская область, Новомосковский район, Новомосковск, проспект Победы, 4	f	large
77468	3902	578	Тульская область, Новомосковский район, Новомосковск, проспект Победы, 4	f	large
77481	3909	591	Тульская область, Новомосковский район, Новомосковск, Школьная, 13	f	large
77480	3909	590	Тульская область, Новомосковский район, Новомосковск, Школьная, 13	f	large
77479	3909	589	Тульская область, Новомосковский район, Новомосковск, Школьная, 13	f	large
77478	3908	588	Тульская область, Новомосковский район, Новомосковск, Школьная, 1	f	large
77502	3922	614	Тульская область, Новомосковский район, Новомосковск, Шахтерская, 16, микрорайон Сокольники	f	large
126351	3918	610	Тульская область, Новомосковский район, Новомосковск, Центральная, 27	f	small
77485	3911	595	Тульская область, Новомосковский район, Новомосковск, Трудовые резервы, 73-б	f	large
77484	3911	594	Тульская область, Новомосковский район, Новомосковск, Трудовые резервы, 73-б	f	large
77483	3911	593	Тульская область, Новомосковский район, Новомосковск, Трудовые резервы, 73-б	f	large
77461	3896	571	Тульская область, Новомосковский район, Новомосковск, Трудовые резервы, 21	f	large
77460	3895	570	Тульская область, Новомосковский район, Новомосковск, Солнечная, 8	f	large
77466	3901	576	Тульская область, Новомосковский район, Новомосковск, Свердлова, 32	f	large
77464	3899	574	Тульская область, Новомосковский район, Новомосковск, Свердлова, 22	f	large
77499	3917	609	Тульская область, Новомосковский район, Новомосковск, Рудничная, 6	f	large
77498	3917	608	Тульская область, Новомосковский район, Новомосковск, Рудничная, 6	f	large
77497	3917	607	Тульская область, Новомосковский район, Новомосковск, Рудничная, 6	f	large
77505	3924	617	Тульская область, Новомосковский район, Новомосковск, Пушкина , 9	f	large
77475	3906	585	Тульская область, Новомосковский район, Новомосковск, Присягина, 9	f	large
77474	3906	584	Тульская область, Новомосковский район, Новомосковск, Присягина, 9	f	large
77494	3915	604	Тульская область, Новомосковский район, Новомосковск, Орджоникидзе, 4-а	f	large
77493	3915	603	Тульская область, Новомосковский район, Новомосковск, Орджоникидзе, 4-а	f	large
77462	3897	572	Тульская область, Новомосковский район, Новомосковск, Октябрьская, 21	f	large
77463	3898	573	Тульская область, Новомосковский район, Новомосковск, Московская, 10	f	large
77458	3892	568	Тульская область, Новомосковский район, Новомосковск, Московская, 9	f	large
77492	3914	602	Тульская область, Новомосковский район, Новомосковск, Молодежная, 2-а	f	large
76774	2359	960	Тверская область, Тверь, поселок Литвинки	f	large
77491	3914	601	Тульская область, Новомосковский район, Новомосковск, Молодежная, 2-а	f	large
77490	3914	600	Тульская область, Новомосковский район, Новомосковск, Молодежная, 2-а	f	large
77496	3916	606	Тульская область, Новомосковский район, Новомосковск, Мира, 15-б	f	large
77495	3916	605	Тульская область, Новомосковский район, Новомосковск, Мира, 15-б	f	large
77477	3907	587	Тульская область, Новомосковский район, Новомосковск, Мира, 8-б	f	large
77476	3907	586	Тульская область, Новомосковский район, Новомосковск, Мира, 8-б	f	large
77456	3890	566	Тульская область, Новомосковский район, Новомосковск, Маяковского, 36/1	f	large
77455	3890	565	Тульская область, Новомосковский район, Новомосковск, Маяковского, 36/1	f	large
126352	3920	612	Тульская область, Новомосковский район, Новомосковск, Маклец, 15-а	f	medium
77504	3923	616	Тульская область, Новомосковский район, Новомосковск, Ленина, 23	f	large
77503	3923	615	Тульская область, Новомосковский район, Новомосковск, Ленина, 23	f	large
77501	3921	613	Тульская область, Новомосковский район, Новомосковск, Ленина, 13	f	large
77457	3891	567	Тульская область, Новомосковский район, Новомосковск, Кукунина, 18	f	large
77472	3904	582	Тульская область, Новомосковский район, Новомосковск, Куйбышева, 15-б	f	large
126350	3889	564	Тульская область, Новомосковский район, Новомосковск, Клинский проезд, 7	f	medium
77465	3900	575	Тульская область, Новомосковский район, Новомосковск, Калинина, 24	f	large
77489	3913	599	Тульская область, Новомосковский район, Новомосковск, Дружбы, 8	f	large
77488	3913	598	Тульская область, Новомосковский район, Новомосковск, Дружбы, 8	f	large
77482	3910	592	Тульская область, Новомосковский район, Новомосковск, Донская, 17-а	f	large
77487	3912	597	Тульская область, Новомосковский район, Новомосковск, Демкина, 7	f	large
77486	3912	596	Тульская область, Новомосковский район, Новомосковск, Демкина, 7	f	large
77459	3893	569	Тульская область, Новомосковский район, Новомосковск, Березовая, 7	f	large
77473	3905	583	Тульская область, Новомосковский район, Новомосковск, Бережного, 16	f	large
77454	3888	563	Тульская область, Новомосковский район, Новомосковск, Аварийная, 12	f	large
77500	3919	611	Тульская область, Новомосковский район, Новомосковск, 1-ая Транспортная, 3	f	large
126465	4085	785	Тульская область, Новомосковский район, поселок Никольское, д. 123а	f	small
126357	3929	622	Тульская область, Новомосковский район, поселок Малое Колодезное, 113	f	small
126358	3930	623	Тульская область, Новомосковский район, поселок Малиновский, Толстого, 16	f	small
126163	3642	287	Тульская область, Новомосковский район, поселок Кукуй	f	small
126111	3551	181	Тульская область, Новомосковский район, поселок Кукуй, Центральная, 23	f	medium
126365	3940	633	Тульская область, Новомосковский район, поселок Красный Богатырь, Школьная, 19	f	medium
126356	3928	621	Тульская область, Новомосковский район, поселок Красное Гремячево, Новая, 11-а	f	small
126367	3942	635	Тульская область, Новомосковский район, поселок Коммунаров, Садовая, 4	f	small
126354	3926	619	Тульская область, Новомосковский район, поселок Грицово, Центральная, 44	f	small
77508	3935	628	Тульская область, Новомосковский район, поселок Гремячее, Новики, 14	f	large
126362	3937	630	Россия, республика Башкортостан, деревня Березовка	t	small
126280	3785	457	Тульская область, Ленинский район, ст. Присады, 15а	f	small
126318	3845	518	Тульская область, Ленинский район, поселок Ямны, 1а	f	medium
126312	3834	507	Тульская область, Ленинский район, поселок Южный	f	small
77444	3853	526	Тульская область, Ленинский район, поселок Шатск 2-й, Садовая, 1а	f	large
126323	3854	527	Тульская область, Ленинский район, поселок Шатск 2-й, Ленина, 15	f	medium
126324	3855	528	Тульская область, Ленинский район, поселок Частое, Совхозная, 20	f	medium
77443	3851	524	Тульская область, Ленинский район, село Хрущево, Центральная, 142	f	large
77442	3850	523	Тульская область, Ленинский район, село Хрущево, Совхозная, 1	f	large
77441	3846	519	Тульская область, Ленинский район, поселок Федоровка, 7а	f	large
126315	3840	512	Тульская область, Ленинский район, поселок Торхово, Центральная, 22	f	medium
126452	4048	744	Тульская область, Ленинский район, поселок Теплое, Советское, 40	f	medium
126455	4051	747	Тульская область, Ленинский район, поселок Теплое, Советская, 16	f	medium
126303	3823	497	Тульская область, Ленинский район, деревня Старое Басово, 21А	f	medium
126308	3828	502	Тульская область, Ленинский район, поселок Сергиевский, Центральная	f	medium
77438	3841	513	Тульская область, Ленинский район, поселок Рождественский, Московская, 18	f	large
77439	3841	514	Тульская область, Ленинский район, поселок Рождественский, Московская, 18	f	large
77434	3837	510	Тульская область, Ленинский район, поселок Рассвет, 35	f	large
126314	3836	509	Тульская область, Ленинский район, поселок Рассвет, 38	f	small
126313	3835	508	Тульская область, Ленинский район, поселок Рассвет, 44	f	medium
126304	3824	498	Тульская область, Ленинский район, поселок Осиновая Гора	f	small
77440	3842	515	Тульская область, Ленинский район, поселок Октябрьский, 93	f	large
77843	3820	494	Тульская область, Ленинский район, поселок Обидимо, Школьная, 3	f	large
77842	3820	493	Тульская область, Ленинский район, поселок Обидимо, Школьная, 3	f	large
126326	3856	530	Тульская область, Ленинский район, деревня Морозовка, Центральная, 9	f	medium
126325	3856	529	Тульская область, Ленинский район, деревня Морозовка, Центральная, 9	f	small
77435	3838	511	Тульская область, Ленинский район, поселок Молодежный, Центральная, 10	f	large
126307	3827	501	Тульская область, Ленинский район, поселок Лутовиново, 2	f	small
77425	3818	491	Тульская область, Ленинский район, поселок Ленинский, Центральная, 1а	f	large
126302	3811	483	Тульская область, Ленинский район, поселок Ленинский, Свердлова, 55	f	medium
77436	3813	486	Тульская область, Ленинский район, поселок Ленинский, Механизаторов, 11	f	large
77424	3817	490	Тульская область, Ленинский район, поселок Ленинский, Ленина, 1	f	large
77423	3816	489	Тульская область, Ленинский район, поселок Ленинский, Гагарина , 11	f	large
77841	3815	488	Тульская область, Ленинский район, поселок Ленинский, Гагарина, 9	f	large
126306	3826	500	Тульская область, Ленинский район, поселок Ленинский, Буденого, 7	t	medium
126052	1872	87	Тульская область, Ленинский район, поселок Кураково, Игоревская, 61А	f	small
126305	3825	499	Тульская область, Ленинский район, поселок Крутое, 6а	t	small
126321	3849	522	Тульская область, Ленинский район, поселок Коптево, 75	f	medium
77433	3831	504	Тульская область, Ленинский район, поселок Иншинский, 22	f	large
126309	3830	503	Тульская область, Ленинский район, поселок Иншинский, 34	f	small
77431	3821	495	Тульская область, Ленинский район, поселок Ильинка, Центральная, 19а	f	large
126046	1130	81	Тульская область, Ленинский район, поселок Зайцево, 9	t	small
126310	3832	505	Тульская область, Ленинский район, поселок Зайцево, Школьная, 12	f	medium
126311	3833	506	Тульская область, Ленинский район, поселок Зайцево, Новая, 1	f	small
126177	85353	301	Тульская область, Ленинский район, поселок Восточный	f	medium
77437	3814	487	Тульская область, Ленинский район, поселок Барсуки, Советская, 16а	f	large
77426	3819	492	Тульская область, Ленинский район, поселок Барсуки, Пушкина, 1	f	large
126322	3852	525	Тульская область, Ленинский район, поселок Барсуки, Клубная, 15	f	medium
126317	3844	517	Тульская область, Ленинский район, поселок Архангельское, Центральная, 12	f	medium
126319	3847	520	Тульская область, Ленинский район, поселок Алешня, Центральная, 35	f	medium
126301	3808	480	Тульская область, Куркинский район, поселок Травино, Молодежная, 3	f	small
126242	3714	385	Тульская область, Куркинский район, поселок Софьинка, 2	f	small
126294	3801	473	Тульская область, Куркинский район, поселок Самарский, Центральная, 27	f	medium
126297	3804	476	Тульская область, Куркинский район, поселок Самарский, Запрудная, 19	f	small
126467	4087	787	Тульская область, Куркинский район, поселок Ракитино, 17а	f	small
126287	3792	464	Тульская область, Куркинский район, поселок Птань, Центральная, 2	f	small
126290	3797	469	Тульская область, Куркинский район, поселок Михайловский, Центральная, 4	t	small
126298	3805	477	Тульская область, Куркинский район, поселок Марьинка, Школьная, 8	f	small
77421	3794	466	Тульская область, Куркинский район, поселок Куркино, Школьная, 6а	f	large
77422	3793	465	Тульская область, Куркинский район, поселок Куркино, Парковая, 2	f	large
126296	3803	475	Тульская область, Куркинский район, поселок Куркино, Октябрьская, 41а	f	medium
76704	2225	802	Тверская область, Ржев, Ленинградское шоссе, 5	f	large
126295	3802	474	Тульская область, Куркинский район, поселок Куркино, 1-ая Привокзальная, 2а	f	medium
126291	3798	470	Тульская область, Куркинский район, поселок Кресты, Садовая, 14	f	small
126284	3789	461	Тульская область, Куркинский район, поселок Грибоедова, Центральная, 10	f	small
126289	3796	468	Тульская область, Куркинский район, поселок Грачевка, Дорожная, 9	t	small
126286	3791	463	Тульская область, Куркинский район, поселок Андреевка, Центральная, 48	f	small
126050	1480	85	Тульская область, Кувшиновский район, поселок Богданово, Школьная, 1	f	small
126263	3767	439	Тульская область, Киреевский район, поселок Шварцевский, Советская, 9	f	medium
77416	3766	438	Тульская область, Киреевский район, поселок Шварцевский, Первомайская, 7	f	large
77415	3765	437	Тульская область, Киреевский район, поселок Шварцевский, Ленина, 17	f	large
126413	4007	702	Тульская область, Донской городской округ, поселок Шахтерский	f	medium
126276	3781	453	Тульская область, Киреевский район, поселок Черная Грязь, Молодежная, 37	f	small
126258	3738	409	Тульская область, Киреевский район, поселок Сеченский, Ленина, 7а	f	small
126265	3770	442	Тульская область, Киреевский район, поселок Сергиевское, Центральная, 30а	f	small
126269	3774	446	Тульская область, Киреевский район, поселок Прогресс, Молодежная, 14	f	medium
77393	3736	407	Тульская область, Киреевский район, поселок Приупский, Клубная, 11а	f	large
126266	3771	443	Тульская область, Киреевский район, поселок Подосинки, 80	f	small
77838	3750	422	Тульская область, Киреевский район, поселок Октябрьский, Ленина	f	large
126283	3788	460	Тульская область, Киреевский район, поселок Новоселебное, Комсомольская, 52	f	medium
126281	3786	458	Тульская область, Киреевский район, поселок Новое Село, Центральная, 3	f	small
126300	3807	479	Тульская область, Киреевский район, поселок Моховое, Центральная, 31	f	small
126271	3776	448	Тульская область, Киреевский район, поселок Мостовая, Зеленая, 30	f	small
126272	3777	449	Тульская область, Киреевский район, поселок Майское, Центральная, 5	f	small
77408	3754	426	Тульская область, Киреевский район, Липки, Советская, 17а	f	large
77406	3752	424	Тульская область, Киреевский район, Липки, Советская, 40	f	large
77407	3753	425	Тульская область, Киреевский район, Липки, Лермонтова, 23	f	large
77405	3751	423	Тульская область, Киреевский район, Липки, Комсомольская, 2	f	large
126270	3775	447	Тульская область, Киреевский район, поселок Кузнецово, Центральная, 14	f	small
126273	3778	450	Тульская область, Киреевский район, поселок Криволучье, 2	f	medium
126278	3783	455	Тульская область, Киреевский район, поселок Красный Яр, Школьная	f	small
126277	3782	454	Тульская область, Киреевский район, поселок Красный Яр, Советская, 10	f	medium
126264	3769	441	Тульская область, Киреевский район, поселок Красногвардейский, Красногвардейская, 3	f	small
126261	3755	427	Тульская область, Киреевский район, поселок Комсомольский, Школьная, 2	f	small
77399	3742	413	Тульская область, Киреевский район, Киреевск, Чехова, 15	f	large
77398	3741	412	Тульская область, Киреевский район, Киреевск, Чехова, 13	f	large
77400	3743	414	Тульская область, Киреевский район, Киреевск, Толстого, 24	f	large
77418	3730	401	Тульская область, Киреевский район, Киреевск, Тесакова, 2	f	large
126256	3729	400	Тульская область, Киреевский район, Киреевск, Тесакова, 38	f	medium
77403	3746	417	Тульская область, Киреевский район, Киреевск, Октябрьская, 28	f	large
77402	3745	416	Тульская область, Киреевский район, Киреевск, Октябрьская, 56	f	large
77395	3734	405	Тульская область, Киреевский район, Киреевск, Мира, 10а	f	large
77401	3744	415	Тульская область, Киреевский район, Киреевск, Ленина, 6	f	large
77396	3735	406	Тульская область, Киреевский район, Киреевск, Ленина, 19	f	large
77394	3733	404	Тульская область, Киреевский район, Киреевск, Ленина, 32	f	large
77420	3732	403	Тульская область, Киреевский район, Киреевск, Комарова, 19а	f	large
77419	3731	402	Тульская область, Киреевский район, Киреевск, Комарова, 17	f	large
77836	3747	418	Тульская область, Киреевский район, Киреевск, Торговая	f	large
77837	3747	419	Тульская область, Киреевский район, Киреевск, Торговая	f	large
126267	3772	444	Тульская область, Киреевский район, поселок Долгое	f	small
76713	2235	812	Тверская область, Ржев, Кривощапова, 6	f	large
126274	3779	451	Тульская область, Киреевский район, поселок Дедилово, Советская, 62	f	medium
126275	3780	452	Тульская область, Киреевский район, поселок Дедилово, Грецова, 16	f	medium
126257	3737	408	Тульская область, Киреевский район, поселок Головлинский, Победы, 24а	f	small
126096	3533	164	Россия, Тульская область, Киреевский район, поселок Васильевский	f	small
77413	3762	434	Тульская область, Киреевский район, поселок Бородинский, Пионерская, 8	f	large
77414	3763	435	Тульская область, Киреевский район, поселок Бородинский, Комсомольская, 13	f	large
77417	3768	440	Тульская область, Киреевский район, поселок Большие Калмыки, Центральная, 13	f	large
77409	3758	430	Тульская область, Киреевский район, Болохово, Советская, 16	f	large
77839	3756	428	Тульская область, Киреевский район, Болохово, Первомайская, 4	f	large
77412	3761	433	Тульская область, Киреевский район, Болохово, Мира, 33	f	large
77411	3760	432	Тульская область, Киреевский район, Болохово, Мира, 20	f	large
77410	3759	431	Тульская область, Киреевский район, Болохово, Мира, 6	f	large
77840	3757	429	Тульская область, Киреевский район, Болохово, Мира, 6	f	large
126229	3701	374	Тульская область, Кимовский район, поселок Шахтерский, Шахтная	f	medium
126237	3709	380	Тульская область, Кимовский район, поселок Черемухово, 16а	t	small
126253	3725	396	Тульская область, Кимовский район, поселок Хитровщина, 17	f	small
126241	3713	384	Тульская область, Кимовский район, поселок Федосовка	f	small
126246	3718	389	Тульская область, Кимовский район, поселок Устье, 19а	t	small
126252	3724	395	Тульская область, Кимовский район, поселок Таболо, 16	f	small
126236	3708	379	Тульская область, Кимовский район, поселок Суханово, 67	f	small
126169	84380	293	Тульская область, Кимовский район, поселок Совхозный	f	medium
126226	3694	367	Тульская область, Кимовский район, поселок Пронь, Центральная, 12	f	medium
126255	95189	398	Тульская область, Кимовский район, поселок Новольвовск, Школьная, 6	f	medium
126248	3720	391	Тульская область, Кимовский район, поселок Муравлянка, 46	f	small
126227	3695	368	Тульская область, Кимовский район, поселок Монастырщино	f	small
126247	3719	390	Тульская область, Кимовский район, поселок Молоденки, 56	f	medium
126288	3795	467	Тульская область, Кимовский район, поселок Михайловский, Центральная, 1	f	small
126162	3641	286	Тульская область, Кимовский район, поселок Мирный	f	medium
126222	3690	363	Тульская область, Кимовский район, поселок Мирный, Кимовская, 9	f	medium
126250	3722	393	Тульская область, Кимовский район, поселок Луговое, Молодежная, 3	f	small
126224	3692	365	Тульская область, Кимовский район, поселок Кудашево, 31	f	small
126225	3693	366	Тульская область, Кимовский район, поселок Кропотово, 106	f	small
126232	95188	376	Тульская область, Кимовский район, Кимовск, Сельхозтехника АБЗ	f	medium
126235	3707	378	Тульская область, Кимовский район, Кимовск, поселок Старый	f	small
77389	3698	371	Тульская область, Кимовский район, Кимовск, Шевченко, 3	f	large
77380	3682	353	Тульская область, Кимовский район, Кимовск, Толстого, 21	f	large
77388	3696	369	Тульская область, Кимовский район, Кимовск, Павлова, 19	f	large
77379	3681	352	Тульская область, Кимовский район, Кимовск, Октябрьская, 19	f	large
126219	3679	350	Тульская область, Кимовский район, Кимовск, Октябрьская, 16	f	medium
77378	3680	351	Тульская область, Кимовский район, Кимовск, Маяковского, 37	f	large
77387	3688	361	Тульская область, Кимовский район, Кимовск, Ленина, 35а	f	large
77381	3683	355	Тульская область, Кимовский район, Кимовск, Крылова, 6	f	large
126220	3683	354	Тульская область, Кимовский район, Кимовск, Крылова, 6	f	medium
77384	3686	358	Тульская область, Кимовский район, Кимовск, Коммунистическая, 20а	f	large
77385	3686	359	Тульская область, Кимовский район, Кимовск, Коммунистическая, 20а	f	large
77383	3685	357	Тульская область, Кимовский район, Кимовск, Коммунистическая, 18	f	large
77382	3684	356	Тульская область, Кимовский район, Кимовск, Коммунистическая, 12	f	large
77391	3700	373	Тульская область, Кимовский район, Кимовск, Кирова, 5	f	large
126228	3697	370	Тульская область, Кимовский район, Кимовск, Больничная, 4	f	medium
77390	3699	372	Тульская область, Кимовский район, Кимовск, Бессолова, 65	f	large
126459	87786	777	Тульская область, Кимовский район, поселок Каменка, 300	f	medium
126254	3726	397	Тульская область, Кимовский район, поселок Казановка, Центральная, 1	f	small
126230	3702	375	Тульская область, Кимовский район, поселок Зубовский, 50а	f	small
126249	3721	392	Тульская область, Кимовский район, поселок Зубовка, 50а	t	small
77392	3728	399	Тульская область, Кимовский район, поселок Епифань, 50 лет Октября, 46	f	large
126238	3710	381	Тульская область, Кимовский район, поселок Гранки, 80	f	small
126431	4026	722	Тульская область, Кимовский район, поселок Горки, 51	t	small
126245	3717	388	Тульская область, Кимовский район, поселок Вишневая, 7	f	small
126221	3689	362	Тульская область, Кимовский район, поселок Бучалки, 62	f	small
126353	3925	618	Тульская область, Кимовский район, поселок Богдановка, Центральная, 20	f	small
126026	3458	60	Россия, Московская область, Луховицкий район, деревня Астапово	t	small
126243	3715	386	Тульская область, Кимовский район, поселок Апарки, Больничная, 4	f	small
126208	3668	339	Россия, республика Башкортостан, Благоварский район, село Языково	f	small
126215	3675	346	Тульская область, Каменский район, поселок Яблонево	f	medium
126491	4117	814	Тульская область, Каменский район, поселок Соловьевка, Центральная, 1	f	small
126216	3676	347	Тульская область, Каменский район, поселок Соклаково	f	small
126210	3670	341	Тульская область, Каменский район, поселок Ситово	f	medium
126445	4041	737	Тульская область, Каменский район, поселок Озерки, 100	t	small
126218	3678	349	Тульская область, Каменский район, поселок Новоселки	f	small
126212	3672	343	Костромская область, Шарьинский район, поселок Новопетровский	f	medium
126213	3673	344	Россия, Московская область, Наро-Фоминский район, село Каменское	f	small
126211	3671	342	Тульская область, Каменский район, поселок Кадное	f	medium
126214	3674	345	Тульская область, Каменский район, поселок Закопы	f	small
126207	3667	338	Тульская область, Каменский район, поселок Долгие Лески	f	small
126217	3677	348	Тульская область, Каменский район, поселок Галица	f	small
126234	3706	377	Тульская область, Каменский район, поселок Барановка, 136	t	small
77377	3665	336	Тульская область, Каменский район, поселок Архангельское, Тихомирова, 32	f	large
126011	3439	41	Тульская область, Каменский район, поселок Авангард, Октябрьская, Авангардский СДК	f	medium
126202	3657	328	Тульская область, Заокский район, станция Приокская, служебное помещение	f	small
126194	3647	319	Тульская область, Заокский район, поселок Теряево 1-е, Молодежная, 1А	f	small
77374	3656	327	Тульская область, Заокский район, поселок Сосновый, микрорайон В, 4	f	large
126204	3659	330	Тульская область, Заокский район, поселок Симоново, 238 Стрелковой дивизии, 11	f	medium
126203	3658	329	Тульская область, Заокский район, поселок Русятино, Болотова, 36	f	medium
126460	4080	780	Тульская область, Заокский район, поселок Пашково, 55	f	small
77373	3654	325	Тульская область, Заокский район, поселок Пахомово, .Школьная, 13	f	large
126200	3653	324	Тульская область, Заокский район, поселок Ненашево, Кирова, 11А	f	medium
126251	3723	394	Россия, Тульская область, Заокский район, поселок Молчаново	f	small
126209	3669	340	Россия, Тульская область, Заокский район, поселок Молчаново	f	small
126196	3649	321	Тульская область, Заокский район, поселок Миротинский, Мира, 2	f	small
126199	3652	323	Тульская область, Заокский район, поселок Малахово, Мира, 1	f	medium
126198	3651	322	Тульская область, Заокский район, поселок Ланьшинский Карьер, Школьная, 1	t	small
77375	3662	333	Тульская область, Заокский район, поселок Заокский, Северная, 1	f	large
77834	3663	334	Тульская область, Заокский район, поселок Заокский, Поленова, 17	f	large
77376	3664	335	Тульская область, Заокский район, поселок Заокский, Гагарина, 1	f	large
126195	3648	320	Тульская область, Заокский район, поселок Дмитриевское, Школьная, 1	f	medium
126206	3661	332	Тульская область, Заокский район, поселок Велегож д.о., Дом Культуры	f	small
126193	3646	318	Тульская область, Заокский район, колхоз Бутиково, Новая, 6	f	medium
126165	3644	289	Тульская область, Ефремовский район, поселок Ясеновая	f	medium
126179	85786	304	Ярославская область, поселок Ярославка	f	small
126181	85887	306	Тульская область, Ефремовский район, поселок Яндовка	f	small
126187	86622	312	Тульская область, Ефремовский район, поселок Шкилевка	f	medium
83897	57331	3090	Москва, Зеленоград, к222а	f	large
126159	3637	282	Россия, Московская область, Клинский район, деревня Чернятино	f	medium
126161	3640	285	Россия, Тульская область, Ефремовский район, поселок Тормасово	f	small
126178	85652	303	Тульская область, Ефремовский район, поселок Сретенка	f	small
126183	86235	308	Россия, Тульская область, Ефремовский район, поселок Покровка	f	small
126170	84399	294	Тульская область, Ефремовский район, поселок Пожилино	f	medium
126157	3636	280	Тульская область, Ефремовский район, поселок Павлов Хутор	f	small
126158	14620	281	Тульская область, Ефремовский район, поселок Новокрасивое	f	small
126186	86584	311	Россия, республика Мордовия, Саранск, рабочий поселок Николаевка	f	small
126189	86946	314	Тамбовская область, Петровский район, поселок Мордовка	f	small
126188	86636	313	Тульская область, Ефремовский район, поселок Мечнянка	f	small
126171	84431	295	Тульская область, Ефремовский район, поселок Малая Хмелевская	f	small
126174	84528	298	Тульская область, Ефремовский район, поселок Кытино	f	small
126180	85834	305	Смоленская область, Смоленский район, поселок Круглики	f	medium
126168	84376	292	Тульская область, Ефремовский район, поселок Кременный	f	small
126182	85942	307	Тульская область, Ефремовский район, поселок Красина	f	medium
126164	3643	288	Ивановская область, Палехский район, поселок Кочкино	f	small
126173	84498	297	Тульская область, Ефремовский район, поселок Козьминский	f	small
126172	84452	296	Тульская область, Ефремовский район, поселок Козье	f	small
126184	86313	309	Тульская область, Ефремовский район, поселок Иноземка	f	medium
77815	3618	256	Тульская область, Ефремовский район, Ефремов, Тургенева, 36	f	large
77831	3632	275	Тульская область, Ефремовский район, Ефремов, Тульское шоссе, 14	f	large
77832	3632	276	Тульская область, Ефремовский район, Ефремов, Тульское шоссе, 14	f	large
77830	3631	274	Тульская область, Ефремовский район, Ефремов, Строителей, 57	f	large
77829	3631	273	Тульская область, Ефремовский район, Ефремов, Строителей, 57	f	large
77828	3631	272	Тульская область, Ефремовский район, Ефремов, Строителей, 57	f	large
77814	3616	254	Тульская область, Ефремовский район, Ефремов, Словацкого восстания, 16	f	large
77813	3616	253	Тульская область, Ефремовский район, Ефремов, Словацкого восстания, 16	f	large
126152	3623	261	Тульская область, Ефремовский район, Ефремов, Свердлова, 55 А	f	medium
77821	3627	265	Тульская область, Ефремовский район, Ефремов, Пионерская, 4	f	large
126150	3614	251	Тульская область, Ефремовский район, Ефремов, Московская застава , 17	f	medium
126155	3634	278	Тульская область, Ефремовский район, Ефремов, Молодежная, 1а	f	medium
126154	3626	264	Тульская область, Ефремовский район, Ефремов, Мира, 2 а	f	medium
77812	3615	252	Тульская область, Ефремовский район, Ефремов, Ломоносова, 48	f	large
77822	3628	266	Тульская область, Ефремовский район, Ефремов, Ленинградская, 101	f	large
77817	3620	258	Тульская область, Ефремовский район, Ефремов, Ленина, 38	f	large
77816	3619	257	Тульская область, Ефремовский район, Ефремов, Ленина, 38	f	large
126153	3624	262	Тульская область, Ефремовский район, Ефремов, Красноармейская, 41	f	small
77818	3621	259	Тульская область, Ефремовский район, Ефремов, Красноармейская, 68	f	large
77819	3622	260	Тульская область, Ефремовский район, Ефремов, Комсомольская, 126	f	large
126151	3617	255	Тульская область, Ефремовский район, Ефремов, Карла Маркса, 41	f	medium
77823	3629	267	Тульская область, Ефремовский район, Ефремов, Интернациональная, 4_а	f	large
77824	3629	268	Тульская область, Ефремовский район, Ефремов, Интернациональная, 4_а	f	large
77827	3630	271	Тульская область, Ефремовский район, Ефремов, Дружбы, 7	f	large
77826	3630	270	Тульская область, Ефремовский район, Ефремов, Дружбы, 7	f	large
77825	3630	269	Тульская область, Ефремовский район, Ефремов, Дружбы, 7	f	large
126347	3885	560	Тульская область, Ефремовский район, поселок Двенадцатый Октябрь, 1	f	medium
126156	3635	279	Тульская область, Ефремовский район, поселок Большие Плоты	f	medium
126166	3424	290	Тульская область, Ефремовский район, поселок Большие Медведки	f	small
126141	2461	242	Тульская область, Дубенский район, поселок Скоморошки	f	small
126147	3611	248	Тульская область, Дубенский район, поселок Протасово, Дружбы, 14	f	medium
126143	2606	244	Тульская область, Дубенский район, поселок Поречье, Мира, 1	f	small
126190	87227	315	Россия, Ярославская область, Ярославль, поселок Первомайский	f	small
126032	299	66	Тульская область, Дубенский район, поселок Первомайский	f	small
77452	3878	553	Тульская область, Дубенский район, поселок Первомайский, проспект Улитина, 16А	f	large
126366	3941	634	Тульская область, Дубенский район, поселок Первомайский, Школьная, 5	f	medium
77577	4151	847	Тульская область, Дубенский район, поселок Первомайский, Улитина, 23/2	f	large
126142	2475	243	Тульская область, Дубенский район, поселок Опочня	f	small
126148	3612	249	Тульская область, Дубенский район, поселок Новое Павшино, Центральная, 11	f	small
126145	2899	246	Тульская область, Дубенский район, поселок Надеждино, Дружбы, 21	f	small
126139	3609	240	Тульская область, Дубенский район, поселок Лужное, Чирикова А.И, 1	t	medium
126146	3253	247	Тульская область, Дубенский район, поселок Лобжа, Центральная, 40/2	t	small
126118	3558	189	Тульская область, Дубенский район, поселок Красавка, 72	f	small
77368	3605	236	Тульская область, Дубенский район, поселок Дубна, Фрунзе, 2а	f	large
126138	3607	238	Тульская область, Дубенский район, поселок Дубна, Красноармейская, 85	f	small
126140	3610	241	Тульская область, Дубенский район, поселок Гвардейский, Молодежная, 12	f	medium
126268	3773	445	Тульская область, Дубенский район, поселок Гвардейский, Ленина, 5	f	small
126144	2830	245	Тульская область, Дубенский район, поселок Бабошино, Дружбы, 6	t	small
126115	3555	185	Тульская область, Воловский район, поселок Ялта, Школьная, 99	f	small
126129	3571	202	Тульская область, Воловский район, поселок Турдей, Центральная, 10	f	medium
126124	3566	197	Тульская область, Воловский район, поселок Турдей, Железнодорожная, 13	f	small
126120	3560	191	Тульская область, Воловский район, Сухие Плоты, 69	f	small
126116	1928	186	Тульская область, Воловский район, поселок Становая, 100	f	small
77340	3556	187	Тульская область, Воловский район, поселок Садовый, Садовская, 31	f	large
126122	3562	193	Тульская область, Воловский район, поселок Победа, Центральная, 14	f	small
126113	3553	183	Тульская область, Воловский район, поселок Панарино, Административная, 1	f	small
126125	3567	198	Тульская область, Воловский район, поселок Никитское, Антонова, 16	f	small
126126	3568	199	Тульская область, Воловский район, поселок Непрядва, Главная, 152 а	f	small
126127	3569	200	Тульская область, Воловский район, поселок Красный Холм, Центральная, 10	f	small
126130	3572	203	Тульская область, Воловский район, поселок Красная Дубровка, Школьная, 5	f	small
126128	3570	201	Тульская область, Воловский район, поселок Казачка, Молодежная, 8	f	medium
126114	3554	184	Тульская область, Воловский район, поселок Истленьево, Школьная, 14	t	small
126119	3559	190	Тульская область, Воловский район, поселок Горный, Весенняя, 6	f	medium
77341	3563	194	Тульская область, Воловский район, поселок Волово, имени Хрунова, 4	f	large
77342	3564	195	Тульская область, Воловский район, поселок Волово, Ленина, 50	f	large
126121	3561	192	Тульская область, Воловский район, поселок Верхоупье, Школьная, 25	f	small
126117	3557	188	Тульская область, Воловский район, поселок Борятино, 31	f	small
126029	133	63	Тульская область, Воловский район, поселок Белый Колодезь	f	small
126112	3552	182	Тульская область, Воловский район, поселок Баскаково, Школьная, 9	f	small
126446	4042	738	Тульская область, Воловский район, поселок Алексеевка, 4	f	small
126099	3537	168	Тульская область, Веневский район, Тулубьево, Молодежная, 1а	t	small
126453	4049	745	Тульская область, Веневский район, поселок Теплое, Школьная, 45	f	medium
126450	4046	742	Тульская область, Веневский район, поселок Теплое, Привокзальная, 13	f	medium
126454	4050	746	Тульская область, Веневский район, поселок Теплое, Комсомольская, 28	f	medium
126098	3536	167	Тульская область, Веневский район, поселок Студенец, Центральная, 10	f	small
126104	3543	174	Тульская область, Веневский район, поселок Сетка, Библиотечная, 24	f	small
126097	3535	166	Тульская область, Веневский район, поселок Рассвет, Центральная, 5	f	small
126108	3547	178	Тульская область, Веневский район, поселок Прудищи, Молодежная, 47	f	small
126107	3546	177	Тульская область, Веневский район, поселок Поветкино, Центральная, 54	t	small
126109	3548	179	Тульская область, Веневский район, поселок Островки, Клубная, 20а	f	small
126103	3542	173	Тульская область, Веневский район, колхоз Оленьковский, Дорожная, 19	f	medium
126106	3545	176	Тульская область, Веневский район, слобода Озеренская, Новая, 11	f	medium
77811	3541	172	Тульская область, Веневский район, поселок Мордвес, Советская, 11	f	large
77339	3534	165	Тульская область, Веневский район, поселок Метростроевский, Горная, 7	f	large
126102	3540	171	Тульская область, Веневский район, поселок Козловка, Липовая, 2	t	small
126101	3539	170	Тульская область, Веневский район, поселок Дьяконово, Барская слобода, 2	f	small
77337	3529	160	Тульская область, Веневский район, поселок Грицовский, Школьная, 4а, Грицовский дом культуры	f	large
77338	3530	161	Тульская область, Веневский район, поселок Грицовский, Первомайская, 21, Грицовская средняя школа	f	large
126105	3544	175	Тульская область, Веневский район, поселок Гати, Воронковка, 15	f	small
77333	3524	155	Тульская область, Веневский район, Венев, 25, Веневская средняя школа №2	f	large
77334	3525	156	Тульская область, Веневский район, Венев, микрорайон Южный, 19	f	large
77332	3523	154	Тульская область, Веневский район, Венев, микрорайон Южный, 44, клуб школьника "Родничок"	f	large
77336	3527	158	Тульская область, Веневский район, Венев, Л. Толстого, 16, МУК МКДЦ	f	large
77335	3526	157	Тульская область, Веневский район, Венев, Бундурина, 13, Веневская средняя школа №1	f	large
126110	3549	180	Тульская область, Веневский район, поселок Бельковский, Дружбы, 2	f	small
126095	3532	163	Тульская область, Веневский район, поселок Анишино, Новая, 14	f	medium
126100	3538	169	Тульская область, Веневский район, поселок Аксиньино, Центральная, 6	f	small
126080	3510	141	Тульская область, Богородицкий район, поселок Шахтерский, Шахтерский переулок, 26	f	small
126086	3516	147	Тульская область, Богородицкий район, поселок Черняевка, 130	f	small
126084	3514	145	Тульская область, Богородицкий район, поселок Упертовка, Липки, 5	f	small
77809	3498	129	Тульская область, Богородицкий район, поселок Товарковский, Трудовая	f	large
77329	3500	131	Тульская область, Богородицкий район, поселок Товарковский, Советская, 6	f	large
77330	3501	132	Тульская область, Богородицкий район, поселок Товарковский, Кирова, 3	f	large
77810	3499	130	Тульская область, Богородицкий район, Товарковский, Воровского	f	large
126089	3519	150	Тульская область, Богородицкий район, поселок Товарково, слоб.1-ое общество, 73	f	medium
77507	3932	625	Тульская область, Богородицкий район, поселок Спасское, Центральная, 5В	f	large
126082	3512	143	Тульская область, Богородицкий район, поселок Романцевский, Школьная, 6	f	small
126405	3990	685	Тульская область, Богородицкий район, поселок Пригородный, Садовая, 1	f	small
126077	3506	137	Тульская область, Богородицкий район, поселок Папоротка, Центральная, 57	f	small
126087	3517	148	Тульская область, Богородицкий район, поселок Новопокровское, Восточная, 1А	f	medium
126076	3505	136	Тульская область, Богородицкий район, поселок Малевка, слоб.Бригада 3, 123	f	small
126092	3522	153	Тульская область, Богородицкий район, поселок Ломовка, слобода Церковенка, 22, слобода Церковенка	f	small
126090	3520	151	Тульская область, Богородицкий район, поселок Левинка, 169	f	small
126091	3521	152	Россия, Липецкая область, Грязинский район, поселок Кузовка	f	medium
126081	3511	142	Тульская область, Богородицкий район, поселок Колодези, 2а	f	small
126083	3513	144	Тульская область, Богородицкий район, поселок Кобловский, 8а	f	small
126074	3503	134	Тульская область, Богородицкий район, поселок Кичевский, Лесная, 6	f	small
126085	3515	146	Тульская область, Богородицкий район, поселок Иевлево, слоб.Бодаево, 181	f	medium
126436	4032	728	Тульская область, Богородицкий район, поселок Доброе, 1	f	small
126075	3504	135	Тульская область, Богородицкий район, поселок Гагарино, Школьная, 6а	f	small
77315	3479	110	Тульская область, Богородицкий район, Богородицк, Совхоз-техникум, уч.корп.№2	f	large
77808	3495	127	Тульская область, Богородицкий район, Богородицк, переулок Школьный, 2а	f	large
126072	3491	123	Тульская область, Богородицкий район, Богородицк, Центральная, 63	f	medium
126070	3485	116	Тульская область, Богородицкий район, Богородицк, Ф.Энгельса, 36	f	medium
77319	3483	114	Тульская область, Богородицкий район, Богородицк, Урицкого, 60	f	large
77317	3481	112	Тульская область, Богородицкий район, Богородицк, Пролетарская, 68	f	large
77326	3493	125	Тульская область, Богородицкий район, Богородицк, Макаренко, 16	f	large
126069	3484	115	Тульская область, Богородицкий район, Богородицк, МКР Лесной, 47	f	medium
77318	3482	113	Тульская область, Богородицкий район, Богородицк, Ленина, 26а	f	large
77325	3492	124	Тульская область, Богородицкий район, Богородицк, Л.Толстого, 5	f	large
77316	3480	111	Тульская область, Богородицкий район, Богородицк, Коммунаров, 91	f	large
77851	3478	109	Тульская область, Богородицкий район, Богородицк, Коммунаров, 157	f	large
77328	3496	128	Тульская область, Богородицкий район, Богородицк, Клубная, 7	f	large
77324	3489	121	Тульская область, Богородицкий район, Богородицк, Кирпичная, 14	f	large
77321	3486	118	Тульская область, Богородицкий район, Богородицк, Западный МКР, 4а	f	large
77320	3486	117	Тульская область, Богородицкий район, Богородицк, Западный МКР, 4а	f	large
126071	3490	122	Тульская область, Богородицкий район, Богородицк, Воронежская, 3	f	small
77327	3494	126	Тульская область, Богородицкий район, Богородицк, Вересаева, 4	f	large
77331	3507	138	Тульская область, Богородицкий район, поселок Бегичевский, Победы, 4	f	large
126078	3508	139	Тульская область, Богородицкий район, поселок Бегичевский, Луговая, 2, МКР Красницкий	f	small
126073	3502	133	Тульская область, Богородицкий район, поселок Бахметьево, Центральная, 2	f	small
126088	3518	149	Тульская область, Богородицкий район, поселок Александринский	t	small
126048	1422	83	Тульская область, Белевский район, поселок Фединское, Ленина, 6	t	small
126047	1143	82	Тульская область, Белевский район, поселок Таратухино, Центральная, 29	t	small
126055	3462	90	Тульская область, Белевский район, поселок Слобода, Садовая, 1А	t	small
126054	3461	89	Тульская область, Белевский район, поселок Ровно, Школьный переулок, 1	f	small
126044	941	79	Тульская область, Белевский район, поселок Новые Дольцы	f	small
126061	3468	96	Тульская область, Белевский район, поселок Кожурово, Центральная, 4	f	small
126239	3711	382	Тульская область, Белевский район, поселок Иваньково, 84	f	small
126529	4188	884	Тульская область, Белевский район, поселок Иваньково, Центральная, 82	f	medium
126058	3465	93	Тульская область, Белевский район, поселок Иваново, 100	f	small
126059	3466	94	Тульская область, Белевский район, поселок Жуково, Школьный переулок, 3	f	medium
77369	3606	237	Тульская область, Белевский район, поселок Дубна, Первомайская, 89а	f	large
126057	3464	92	Тульская область, Белевский район, поселок Давыдово	f	small
126063	3470	98	Тульская область, Белевский район, поселок Будоговищи, Центральная, 129	f	small
126051	1629	86	Тульская область, Белевский район, поселок Болото, Рабочая, 1	f	small
126045	1104	80	Тульская область, Белевский район, поселок Бобрики, Садовая, 33	f	medium
126062	94875	97	Тульская область, Белевский район, поселок Беляево, Садовая, 54	t	small
126064	3471	99	Тульская область, Белевский район, Белев, Фрунзе, 37	f	medium
77314	3477	108	Тульская область, Белевский район, Белев, Советская, 91А	f	large
77312	3477	106	Тульская область, Белевский район, Белев, Советская, 91А	f	large
77313	3477	107	Тульская область, Белевский район, Белев, Советская, 91А	f	large
77311	3474	102	Тульская область, Белевский район, Белев, Советская, 32	f	large
77310	3473	101	Тульская область, Белевский район, Белев, Советская, 43	f	large
126068	3476	105	Тульская область, Белевский район, Белев, Пушкина, 25	f	medium
126067	3476	104	Тульская область, Белевский район, Белев, Пушкина, 25	f	medium
126066	3475	103	Тульская область, Белевский район, Белев, Карла Маркса, 84	f	medium
126065	3472	100	Тульская область, Белевский район, Белев, Карла Маркса, 108	f	medium
126060	3467	95	Тульская область, Белевский район, поселок Астафьево, 60А	f	small
126192	3645	317	Тульская область, Белевский район, поселок Александровка, Школьная, 8	f	small
77526	4009	704	Тульская область, Арсеньевский район, поселок Центральный, Ленина, 29А	f	large
77309	929	78	Тульская область, Арсеньевский район, поселок Славный	f	large
126027	3459	61	Тульская область, Арсеньевский район, поселок Рахлеево	t	small
126031	239	65	Тульская область, Арсеньевский район, поселок Мокрое	t	small
76724	2241	823	Тверская область, Ржев, Краностроителей, 15	f	large
126037	667	71	Тульская область, Арсеньевский район, поселок Меркулово	f	small
126039	701	73	Тульская область, Арсеньевский район, Манаенки	f	small
126038	680	72	Тульская область, Арсеньевский район, поселок Кузьменки	f	small
126036	615	70	Тульская область, Арсеньевский район, поселок Иста	f	small
126034	479	68	Тульская область, Арсеньевский район, поселок Варварино	f	small
126035	602	69	Тульская область, Арсеньевский район, поселок Буревестник	f	small
126041	833	75	Тульская область, Арсеньевский район, поселок Большие Голубочки	f	small
126033	310	67	Тульская область, Арсеньевский район, поселок Боброво	t	small
126123	3565	196	Тульская область, Арсеньевский район, поселок Белый Колодезь, Школьная, 12	f	small
77308	3457	59	Тульская область, Арсеньевский район, поселок Арсеньево, Халтурина, 11	f	large
77307	3456	58	Тульская область, Арсеньевский район, поселок Арсеньево, Папанина, 5	f	large
126043	891	77	Тульская область, Арсеньевский район, поселок Араны	f	small
126019	3447	49	Тульская область, Алексинский район, поселок Хотманово, Дорожная, 6	f	small
126024	3452	54	Тульская область, Алексинский район, поселок Суходол, Садовая, 25 А	f	small
126191	87246	316	Россия, Московская область, Ступинский район, Ступино	f	small
126023	3451	53	Тульская область, Алексинский район, поселок Спас-Конино, Юбилейная, 2 А	f	small
126021	3449	51	Тульская область, Алексинский район, поселок Солопенки, СДК	f	medium
126012	3440	42	Тульская область, Алексинский район, поселок Сенево, Садовая	f	small
126014	3442	44	Тульская область, Алексинский район, поселок Поповка, Победы	f	medium
126015	3443	45	Тульская область, Алексинский район, поселок Пластово, СДК	t	small
77306	3455	57	Тульская область, Алексинский район, поселок Новогуровский, Школьная, 19	f	large
77305	3454	56	Тульская область, Алексинский район, поселок Новогуровский, Школьная, 12	f	large
126020	3448	50	Тульская область, Алексинский район, поселок Мичурина, Центральная, 2	f	medium
126397	3982	677	Россия, Московская область, Домодедово, улица Заречье	f	small
77371	3638	283	Россия, Московская область, Домодедово, улица Заречье	f	large
126017	3445	47	Тульская область, Алексинский район, поселок Егнышевка, Библиотека	f	small
126016	3444	46	Тульская область, Алексинский район, поселок Бунырево, Приокская	f	small
126018	3446	48	Тульская область, Алексинский район, поселок Ботня, Центральная, 5	f	small
126022	3450	52	Тульская область, Алексинский район, поселок Большое Шелепино, Новая, 6	f	medium
126320	3848	521	Тульская область, Алексинский район, поселок Берники, 1, военный городок Берники, квартира 1	f	small
77293	3435	27	Тульская область, Алексинский район, Алексин, площадь Победы, 12	f	large
77299	93660	34	Тульская область, Алексинский район, Алексин, Южная, 11	f	large
77300	93660	35	Тульская область, Алексинский район, Алексин, Южная, 11	f	large
77272	3422	4	Тульская область, Алексинский район, Алексин, Энгельса, 1	f	large
77297	3437	31	Тульская область, Алексинский район, Алексин, Школьная, 4	f	large
77296	3437	30	Тульская область, Алексинский район, Алексин, Школьная, 4	f	large
77304	94285	40	Тульская область, Алексинский район, Алексин, Центральная, 5	f	large
77289	3431	23	Тульская область, Алексинский район, Алексин, Трудовые резервы, 35	f	large
77303	93896	39	Тульская область, Алексинский район, Алексин, Сосновая, 1	f	large
77302	93896	38	Тульская область, Алексинский район, Алексин, Сосновая, 1	f	large
77301	93896	37	Тульская область, Алексинский район, Алексин, Сосновая, 1	f	large
77277	93138	9	Тульская область, Алексинский район, Алексин, Советская, 38	f	large
77276	93138	8	Тульская область, Алексинский район, Алексин, Советская, 38	f	large
77298	3438	33	Тульская область, Алексинский район, Алексин, Серафимовича, 3	f	large
126009	3438	32	Тульская область, Алексинский район, Алексин, Серафимовича, 3	f	medium
77288	3430	22	Тульская область, Алексинский район, Алексин, Северная, 23	f	large
77287	3429	21	Тульская область, Алексинский район, Алексин, Северная, 23	f	large
77290	3432	24	Тульская область, Алексинский район, Алексин, Октябрьская, 1 А	f	large
126010	93708	36	Тульская область, Алексинский район, Алексин, Некрасова, 60	f	medium
126008	3428	20	Тульская область, Алексинский район, Алексин, Мира, 19	f	medium
126007	3427	19	Тульская область, Алексинский район, Алексин, Мира, 19	f	medium
77295	3436	29	Тульская область, Алексинский район, Алексин, Металлистов, 4	f	large
77294	3436	28	Тульская область, Алексинский район, Алексин, Металлистов, 4	f	large
77292	3434	26	Тульская область, Алексинский район, Алексин, Ленина, 20	f	large
77291	3433	25	Тульская область, Алексинский район, Алексин, Ленина, 20	f	large
77275	3423	7	Тульская область, Алексинский район, Алексин, Дубравная, 32	f	large
77273	3423	5	Тульская область, Алексинский район, Алексин, Дубравная, 32	f	large
77274	3423	6	Тульская область, Алексинский район, Алексин, Дубравная, 32	f	large
77271	3421	3	Тульская область, Алексинский район, Алексин, Дубравная, 23 кор.2-Б	f	large
77270	3420	2	Тульская область, Алексинский район, Алексин, Болотова, 6	f	large
77269	3420	1	Тульская область, Алексинский район, Алексин, Болотова, 6	f	large
77286	3426	18	Тульская область, Алексинский район, Алексин, Баумана, 6	f	large
77285	3426	17	Тульская область, Алексинский район, Алексин, Баумана, 6	f	large
77284	3425	16	Тульская область, Алексинский район, Алексин, 50 лет Октября, 10	f	large
77283	3425	15	Тульская область, Алексинский район, Алексин, 50 лет Октября, 10	f	large
77282	3425	14	Тульская область, Алексинский район, Алексин, 50 лет Октября, 10	f	large
77281	3362	13	Тульская область, Алексинский район, Алексин, 50 лет ВЛКСМ, 5	f	large
77279	3362	11	Тульская область, Алексинский район, Алексин, 50 лет ВЛКСМ, 5	f	large
77280	3362	12	Тульская область, Алексинский район, Алексин, 50 лет ВЛКСМ, 5	f	large
77278	3207	10	Тульская область, Алексинский район, Алексин, 50 лет ВЛКСМ, 2	f	large
126025	3453	55	Тульская область, Алексинский район, поселок Александровка, Полякова, 2 А	f	small
77668	4260	990	Тульская область, Пролетарский, Тула, Ступинская, 2	f	large
76758	2355	944	Тверская область, Черкассы, помещение ОАО ДЭП-74	f	large
76943	2576	1220	Тверская область, Удомля, проспект Энергетиков, 9	f	large
76946	2579	1223	Тверская область, Удомля, проспект Курчатова, 17	f	large
76945	2578	1222	Тверская область, Удомля, проспект Курчатова, 9	f	large
76941	2575	1218	Тверская область, Удомля, проспект Курчатова, 3Б	f	large
76942	2575	1219	Тверская область, Удомля, проспект Курчатова, 3Б	f	large
76940	2574	1217	Тверская область, Удомля, проспект Курчатова, 8	f	large
76937	2571	1214	Тверская область, Удомля, проспект Курчатова, 12а	f	large
76939	2573	1216	Тверская область, Удомля, переулок Автодорожный, 1а	f	large
76935	2569	1212	Тверская область, Удомля, Пионерская, 24	f	large
76944	2577	1221	Тверская область, Удомля, Левитана, 5	f	large
76938	2572	1215	Тверская область, Удомля, Автодорожный переулок, 1а	f	large
76936	2570	1213	Тверская область, Удомля, Автодорожный переулок, 1б	f	large
76947	2580	1224	Тверская область, Удомля, 1-й Красноармейский переулок, 1	f	large
125190	2534	1177	Тверская область, Торжок	f	medium
76929	2533	1176	Тверская область, Торжок	f	large
76927	2531	1174	Тверская область, Торжок	f	large
76926	2530	1173	Тверская область, Торжок	f	large
125189	2529	1172	Тверская область, Торжок	f	medium
76925	2528	1171	Тверская область, Торжок	f	large
76924	2527	1170	Тверская область, Торжок	f	large
76923	2526	1169	Тверская область, Торжок	f	large
76919	2522	1165	Тверская область, Торжок	f	large
76918	2521	1164	Тверская область, Торжок	f	large
76917	2520	1163	Тверская область, Торжок	f	large
76916	2519	1162	Тверская область, Торжок	f	large
76915	2518	1161	Тверская область, Торжок	f	large
76914	2517	1160	Тверская область, Торжок	f	large
76913	2516	1159	Тверская область, Торжок	f	large
76912	2515	1158	Тверская область, Торжок	f	large
76911	2514	1157	Тверская область, Торжок	f	large
76920	2523	1166	Тверская область, Торжок, Мира, 30А	f	large
76910	2513	1156	Тверская область, Торжок, Ленинградское шоссе, 63	f	large
76909	2512	1155	Тверская область, Торжок, Ленинградское шоссе, 44	f	large
76922	2525	1168	Тверская область, Торжок, Калининское шоссе, 29	f	large
76921	2524	1167	Тверская область, Торжок, Калининское шоссе, 16Г	f	large
76928	2532	1175	Тверская область, Торжок, Гоголя, 2А	f	large
76807	2386	998	Тверская область, Тверь, здание нового корпуса МОУ СОШ №37	f	large
76801	2376	987	Россия, Тверская область, Тверь	f	large
125143	2443	1085	Тверская область, Тверь, улица маршала Конева, 73	f	small
76867	2429	1065	Тверская область, Тверь, улица Ткача, 18	f	large
76832	2401	1025	Тверская область, Тверь, улица Склизкова, 52а	f	large
76904	2464	1109	Тверская область, Тверь, проспект Чайковского, 19	f	large
76829	2399	1022	Тверская область, Тверь, проспект Победы, 49/21	f	large
76815	1943	1007	Тверская область, Тверь, проспект Победы, 37	f	large
76837	2405	1030	Тверская область, Тверь, проспект Октябрьский, 71а	f	large
76869	2430	1067	Тверская область, Тверь, проспект Ленина, 16	f	large
76868	2430	1066	Тверская область, Тверь, проспект Ленина, 16	f	large
76792	1913	978	Тверская область, Тверь, проспект Комсомольский, 6	f	large
76793	1913	979	Тверская область, Тверь, проспект Комсомольский, 6	f	large
76852	2419	1050	Тверская область, Тверь, проспект Калинина, 20	f	large
76851	2419	1049	Тверская область, Тверь, проспект Калинина, 20	f	large
76850	2418	1048	Тверская область, Тверь, проспект Калинина, 10	f	large
76896	2457	1101	Тверская область, Тверь, проспект Волоколамский, 20	f	large
76873	2433	1071	Тверская область, Тверь, проспект 50 лет Октября, 46	f	large
76872	2432	1070	Тверская область, Тверь, проспект 50 лет Октября, 20б	f	large
76871	2432	1069	Тверская область, Тверь, проспект 50 лет Октября, 20б	f	large
76870	2431	1068	Тверская область, Тверь, проспект 50 лет Октября, 3	f	large
76906	2465	1111	Тверская область, Тверь, проезд Дарвина, 3	f	large
76806	2385	997	Тверская область, Тверь, поселок Химинститута, 1, здание МДК "Синтетик"	f	large
76805	2385	996	Тверская область, Тверь, поселок Химинститута, 1, здание МДК "Синтетик"	f	large
76808	2387	999	Тверская область, Тверь, площадь Гагарина, 1	f	large
76892	2453	1097	Тверская область, Тверь, пл.Славы, 3	f	large
76755	2354	941	Тверская область, Тверь, бульвар Молодежный, 10	f	large
76757	2354	943	Тверская область, Тверь, бульвар Молодежный, 10	f	large
76756	2354	942	Тверская область, Тверь, бульвар Молодежный, 10	f	large
76839	2406	1032	Тверская область, Тверь, бульвар Гусева, 11	f	large
76838	2406	1031	Тверская область, Тверь, бульвар Гусева, 11	f	large
76789	2369	975	Тверская область, Тверь, Шмидта бульвар, 15/13	f	large
76788	2369	974	Тверская область, Тверь, Шмидта бульвар, 15/13	f	large
76783	2364	969	Тверская область, Тверь, Шмидта бульвар, 13/16	f	large
76907	2466	1112	Тверская область, Тверь, Чайковского проспект, 5	f	large
76901	2462	1106	Тверская область, Тверь, Чайковского проспект, 70	f	large
76804	2384	995	Тверская область, Тверь, Центральная, 7	f	large
76833	2402	1026	Тверская область, Тверь, Цанова бульвар, 1	f	large
125140	2417	1047	Тверская область, Тверь, Фадеева, 39	f	small
76818	2390	1010	Тверская область, Тверь, Фадеева, 42	f	large
76817	2390	1009	Тверская область, Тверь, Фадеева, 42	f	large
76887	2447	1091	Тверская область, Тверь, Учительская, 6	f	large
76886	2447	1090	Тверская область, Тверь, Учительская, 6	f	large
76795	654	981	Тверская область, Тверь, Третьяковский переулок, 17	f	large
76880	2437	1078	Тверская область, Тверь, Тракторная, 8а	f	large
125135	2393	1013	Тверская область, Тверь, Терещенко, 5/25	f	medium
76820	2392	1012	Тверская область, Тверь, Тамары Ильиной, 1	f	large
76894	2455	1099	Тверская область, Тверь, Студенческий переулок, 13	f	large
76890	2451	1095	Тверская область, Тверь, Студенческий переулок, 33	f	large
76900	2460	1105	Тверская область, Тверь, Спортивный переулок, 12	f	large
76899	2460	1104	Тверская область, Тверь, Спортивный переулок, 12	f	large
76898	2459	1103	Тверская область, Тверь, Спортивный переулок, 11	f	large
76857	2422	1055	Тверская область, Тверь, Спартака, 39	f	large
76856	2422	1054	Тверская область, Тверь, Спартака, 39	f	large
76780	2361	966	Тверская область, Тверь, Соминка, 65	f	large
76779	2361	965	Тверская область, Тверь, Соминка, 65	f	large
76778	2361	964	Тверская область, Тверь, Соминка, 65	f	large
125071	2280	864	Тверская область, Тверь, Солнечная, 2	f	small
76891	2452	1096	Тверская область, Тверь, Советская, 42	f	large
125147	2449	1093	Тверская область, Тверь, Советская, 4	f	medium
76745	2325	908	Тверская область, Тверь, Советская, 8, здание Старицкого ПУ	f	large
76831	2400	1024	Тверская область, Тверь, Склизкова, 95	f	large
76830	2400	1023	Тверская область, Тверь, Склизкова, 95	f	large
83896	57331	3089	Москва, Зеленоград, к222а	f	large
76889	2450	1094	Тверская область, Тверь, Свободный переулок, 28	f	large
76800	2375	986	Тверская область, Тверь, Сахаровское шоссе, 12	f	large
76797	2372	983	Тверская область, Тверь, Розы Люксембург, 116	f	large
76859	2424	1057	Тверская область, Тверь, Ржевская, 12	f	large
76861	2426	1059	Тверская область, Тверь, Ремесленный проезд, 5	f	large
76834	2403	1027	Тверская область, Тверь, Победы проспект, 57	f	large
76768	94132	954	Тверская область, Тверь, Петербургское шоссе, 42	f	large
76766	93323	952	Тверская область, Тверь, Петербургское шоссе, 39	f	large
76760	2357	946	Тверская область, Тверь, Петербургское шоссе, 95	f	large
76759	2356	945	Тверская область, Тверь, Петербургское шоссе, 105к1	f	large
76765	2309	951	Тверская область, Тверь, Петербургское шоссе, 51к5	f	large
76770	43	956	Тверская область, Тверь, Петербургское шоссе, 8	f	large
76769	43	955	Тверская область, Тверь, Петербургское шоссе, 8	f	large
76763	2358	949	Тверская область, Тверь, Паши Савельевой, 4	f	large
76762	2358	948	Тверская область, Тверь, Паши Савельевой, 4	f	large
76761	2358	947	Тверская область, Тверь, Паши Савельевой, 4	f	large
76764	2358	950	Тверская область, Тверь, Паши Савельевой, 4	f	large
76827	2397	1020	Тверская область, Тверь, Орджоникидзе, 50	f	large
76823	2395	1016	Тверская область, Тверь, Орджоникидзе, 53К3	f	large
76824	2395	1017	Тверская область, Тверь, Орджоникидзе, 53К3	f	large
76822	2394	1015	Тверская область, Тверь, Орджоникидзе, 49, корп.Д	f	large
76821	2394	1014	Тверская область, Тверь, Орджоникидзе, 49, корп.Д	f	large
76816	2389	1008	Тверская область, Тверь, Орджоникидзе, 39	f	large
76809	2388	1000	Тверская область, Тверь, Орджоникидзе, 25	f	large
125134	1117	1003	Тверская область, Тверь, Орджоникидзе, 32	f	medium
76811	1117	1002	Тверская область, Тверь, Орджоникидзе, 32	f	large
76836	2404	1029	Тверская область, Тверь, Октябрьский проспект, 57	f	large
76835	2404	1028	Тверская область, Тверь, Октябрьский проспект, 57	f	large
76814	761	1006	Тверская область, Тверь, Озерная, 12	f	large
76810	761	1001	Тверская область, Тверь, Озерная, 12	f	large
76796	740	982	Тверская область, Тверь, Новая Заря, 23	f	large
76736	2290	874	Тверская область, Тверь, Новая, 50	f	large
76771	459	957	Тверская область, Тверь, Никитина переулок, 12	f	large
76772	459	958	Тверская область, Тверь, Никитина переулок, 12	f	large
76787	2368	973	Тверская область, Тверь, Мусоргского, 5	f	large
125133	2383	994	Тверская область, Тверь, Московское шоссе, 83, здание РЭУ Московского района	f	\N
76754	2353	940	Тверская область, Тверь, Молодежный бульвар, 10/2	f	large
76753	2353	939	Тверская область, Тверь, Молодежный бульвар, 10/2	f	large
76752	2353	938	Тверская область, Тверь, Молодежный бульвар, 10/2	f	large
76849	2412	1042	Тверская область, Тверь, Можайского, 82	f	large
76848	2412	1041	Тверская область, Тверь, Можайского, 82	f	large
76843	2409	1036	Тверская область, Тверь, Можайского, 63	f	large
76862	2423	1060	Тверская область, Тверь, Маршала Конева, 1	f	large
76858	2423	1056	Тверская область, Тверь, Маршала Конева, 1	f	large
76812	1570	1004	Тверская область, Тверь, Линейная, 81	f	large
76860	2425	1058	Тверская область, Тверь, Ленина проспект, 25	f	large
76842	2408	1035	Тверская область, Тверь, Левитана, 30	f	large
76841	2408	1034	Тверская область, Тверь, Левитана, 30	f	large
76840	2407	1033	Тверская область, Тверь, Левитана, 28	f	large
76782	2363	968	Тверская область, Тверь, Красина, 40	f	large
125146	2446	1089	Тверская область, Тверь, Коробкова, 15	f	small
76879	2436	1077	Тверская область, Тверь, Константина Заслонова, 4а	f	large
76878	2436	1076	Тверская область, Тверь, Константина Заслонова, 4а	f	large
76794	2295	980	Тверская область, Тверь, Комсомольский проспект, 17/56	f	large
76881	2438	1079	Тверская область, Тверь, Карбышева, 1	f	large
76826	2396	1019	Тверская область, Тверь, Ипподромная, 26	f	large
76825	2396	1018	Тверская область, Тверь, Ипподромная, 26	f	large
76885	2441	1083	Тверская область, Тверь, Ильи Касьянова, 7	f	large
76790	2370	976	Тверская область, Тверь, Зинаиды Коноплянниковой, 22а	f	large
76893	2454	1098	Тверская область, Тверь, Желябова, 22	f	large
76883	2439	1081	Тверская область, Тверь, Железнодорожников, 53	f	large
76882	2439	1080	Тверская область, Тверь, Железнодорожников, 53	f	large
76791	2371	977	Тверская область, Тверь, Екатерины Фарафоновой, 36	f	large
76888	2448	1092	Тверская область, Тверь, Достоевского, 10а	f	large
76777	2360	963	Тверская область, Тверь, Дачная, 73	f	large
76776	2360	962	Тверская область, Тверь, Дачная, 73	f	large
76845	2411	1038	Тверская область, Тверь, Гусева бульвар, 47к1	f	large
76847	2410	1040	Тверская область, Тверь, Гусева бульвар, 42	f	large
76846	2410	1039	Тверская область, Тверь, Гусева бульвар, 42	f	large
76844	2410	1037	Тверская область, Тверь, Гусева бульвар, 42	f	large
76877	2435	1075	Тверская область, Тверь, Громова, 1	f	large
76876	2435	1074	Тверская область, Тверь, Громова, 1	f	large
76875	2435	1073	Тверская область, Тверь, Громова, 1	f	large
76781	2362	967	Тверская область, Тверь, Грибоедова, 20/1	f	large
76785	2366	971	Тверская область, Тверь, Горького, 126	f	large
76784	2365	970	Тверская область, Тверь, Горького, 97	f	large
76884	2440	1082	Тверская область, Тверь, Георгиевская, 12	f	large
76905	2456	1110	Тверская область, Тверь, Волоколамский проспект, 10	f	large
76895	2456	1100	Тверская область, Тверь, Волоколамский проспект, 10	f	large
76828	2398	1021	Тверская область, Тверь, Волоколамский проспект, 7/1	f	large
76743	2323	906	Тверская область, Тверь, Володарского, 4, здание РДК	f	large
76742	2323	905	Тверская область, Тверь, Володарского, 4, здание РДК	f	large
76854	2420	1052	Тверская область, Тверь, Виноградова, 4	f	large
76853	2420	1051	Тверская область, Тверь, Виноградова, 4	f	large
76767	94093	953	Тверская область, Тверь, Веселова, 33	f	large
76803	2382	993	Тверская область, Тверь, Вагжанова, 14	f	large
76802	2381	992	Тверская область, Тверь, Вагжанова, 2	f	large
76813	1684	1005	Тверская область, Тверь, Бурашевское шоссе, 5/21	f	large
125141	2442	1084	Тверская область, Тверь, Борихино Поле, 2	f	small
76866	2428	1064	Тверская область, Тверь, Бориса Полевого, 15	f	large
76865	2428	1063	Тверская область, Тверь, Бориса Полевого, 15	f	large
76786	2367	972	Тверская область, Тверь, Благоева, 2А	f	large
76855	2421	1053	Тверская область, Тверь, Баррикадная, 5	f	large
76897	2458	1102	Тверская область, Тверь, Александра Завидова, 24	f	large
76864	2427	1062	Тверская область, Тверь, Академическая, 18	f	large
76863	2427	1061	Тверская область, Тверь, Академическая, 18	f	large
76799	2374	985	Тверская область, Тверь, Академика Туполева, 118	f	large
76798	2373	984	Тверская область, Тверь, Академика Туполева, 105	f	large
76874	2434	1072	Тверская область, Тверь, 50 Лет Октября проспект, 40а	f	large
76819	2391	1011	Тверская область, Тверь, 15 лет Октября, 51/18	f	large
76903	2463	1108	Тверская область, Тверь, 1-я Суворова, 19	f	large
76902	2463	1107	Тверская область, Тверь, 1-я Суворова, 19	f	large
76749	2352	935	Тверская область, Тверь, 1-й Вагонников переулок, 5	f	large
76751	2352	937	Тверская область, Тверь, 1-й Вагонников переулок, 5	f	large
76750	2352	936	Тверская область, Тверь, 1-й Вагонников переулок, 5	f	large
76773	991	959	Тверская область, Тверь, 1-й Вагонников переулок, 1-а	f	large
76715	2237	814	Тверская область, Ржев, Чернышевского, 1	f	large
76729	2246	829	Тверская область, Ржев, Челюскинцев, Дом офицеров	f	large
76721	93246	820	Тверская область, Ржев, Чайковского, 2	f	large
76720	93246	819	Тверская область, Ржев, Чайковского, 2	f	large
76726	2243	825	Тверская область, Ржев, Центральная, 17	f	large
76707	2228	805	Тверская область, Ржев, Урицкого, 93	f	large
76706	2227	804	Тверская область, Ржев, Трудовая, 4	f	large
76714	2236	813	Тверская область, Ржев, Торопецкий тракт, 48а	f	large
76730	2247	830	Тверская область, Ржев, Тертия Филиппова, 65а	f	large
76728	2244	827	Тверская область, Ржев, Селижаровский проезд, 4а	f	large
76727	2244	826	Тверская область, Ржев, Селижаровский проезд, 4а	f	large
76722	94068	821	Тверская область, Ржев, Пионерская, 40	f	large
76710	2232	809	Тверская область, Ржев, Партизанская, 9/7	f	large
125042	2245	828	Тверская область, Ржев, Никиты Головни, 31	f	medium
76725	2242	824	Тверская область, Ржев, Никиты Головни, 24	f	large
76718	2238	817	Тверская область, Ржев, Московское шоссе, 6а	f	large
76716	2238	815	Тверская область, Ржев, Московское шоссе, 6а	f	large
76712	2234	811	Тверская область, Ржев, Марата, 25	f	large
76705	2226	803	Тверская область, Ржев, Ленинградское шоссе, 42	f	large
76709	2231	808	Тверская область, Ржев, Карла Маркса, 41	f	large
125041	2230	807	Тверская область, Ржев, Карла Маркса, 46	f	medium
76719	2239	818	Тверская область, Ржев, Зубцовское шоссе, 3/58	f	large
76717	2239	816	Тверская область, Ржев, Зубцовское шоссе, 3/58	f	large
76708	2229	806	Тверская область, Ржев, Волосковская Горка, 2	f	large
76723	2240	822	Тверская область, Ржев, Валентина Степанченко, 27	f	large
125044	2233	832	Тверская область, Ржев, Большая Спасская, 15а	f	small
76711	2233	810	Тверская область, Ржев, Большая Спасская, 15а	f	large
124925	2083	650	Тверская область, Нелидово	f	small
124924	2082	649	Тверская область, Нелидово	f	small
124926	2087	654	Тверская область, Нелидово, пр. Ленина, 12	f	\N
124923	2080	647	Тверская область, Нелидово, Чайковского, 13	f	small
124939	2103	670	Тверская область, Нелидово, Торопецкий тракт, 6	f	small
124922	2078	645	Тверская область, Нелидово, Советская, 40	f	medium
124934	2097	664	Тверская область, Нелидово, Пушкина, 2	f	small
76677	2086	653	Тверская область, Нелидово, Правды, 17	f	large
76679	2096	663	Тверская область, Нелидово, Пионерская, 5	f	large
76676	2085	652	Тверская область, Нелидово, Мира, 8	f	large
76673	2079	646	Тверская область, Нелидово, Мира, 18	f	large
76674	2081	648	Тверская область, Нелидово, Матросова, 42	f	large
124933	2095	662	Тверская область, Нелидово, Лесная, 13	f	small
124932	2094	661	Тверская область, Нелидово, Лесная, 10б	f	medium
124931	2093	660	Тверская область, Нелидово, Лесная, 5	f	small
76675	2084	651	Тверская область, Нелидово, Ленина, 2	f	large
76678	2090	657	Тверская область, Нелидово, Кирова, 10	f	large
124928	2089	656	Тверская область, Нелидово, Кирова, 8	f	medium
76680	2098	665	Тверская область, Нелидово, Карбышева, 14а	f	large
124927	2088	655	Тверская область, Нелидово, Казанская, 5	f	medium
124930	2092	659	Тверская область, Нелидово, Заводская, 7	f	medium
124929	2091	658	Тверская область, Нелидово, Больничная, 6	f	medium
124921	2076	643	Тверская область, Нелидово, А. Невского, 1	f	small
76655	1968	534	Тверская область, Кувшиново, Горячева, 64	f	large
76618	1905	473	Тверская область, Конаково, проспект Ленина, 11	f	large
76614	1903	469	Тверская область, Конаково, проспект Ленина, 28	f	large
76616	1903	471	Тверская область, Конаково, проспект Ленина, 28	f	large
76617	1904	472	Тверская область, Конаково, Энергетиков, 38	f	large
76615	1904	470	Тверская область, Конаково, Энергетиков, 38	f	large
76613	1902	468	Тверская область, Конаково, Энергетиков, 12	f	large
76608	1894	460	Тверская область, Конаково, Строителей, 15	f	large
76609	1895	461	Тверская область, Конаково, Свободы, 162	f	large
124805	1899	465	Тверская область, Конаково, Первомайская, 18	f	small
76610	1898	464	Тверская область, Конаково, Первомайская, 60	f	large
76619	1906	474	Тверская область, Конаково, Набережная Волги, ДК Современник	f	large
76607	1893	459	Тверская область, Конаково, Маяковского, 7	f	large
76606	1892	458	Тверская область, Конаково, Маяковского, 16	f	large
76605	1891	457	Тверская область, Конаково, Комсомольская, 9	f	large
76623	1910	478	Тверская область, Конаково, Горького, 3	f	large
76624	1909	479	Тверская область, Конаково, Горького, 13	f	large
76622	1909	477	Тверская область, Конаково, Горького, 13	f	large
76612	1901	467	Тверская область, Конаково, Гагарина, 31	f	large
76611	1900	466	Тверская область, Конаково, Гагарина, 23	f	large
76621	1908	476	Тверская область, Конаково, Баскакова, 11	f	large
76620	1907	475	Тверская область, Конаково, Баскакова, 3	f	large
76584	1874	434	Тверская область, Кимры, проезд Титова, 12	f	large
76586	1874	436	Тверская область, Кимры, проезд Титова, 12	f	large
76585	1874	435	Тверская область, Кимры, проезд Титова, 12	f	large
76598	1883	448	Тверская область, Кимры, проезд Савеловский, 1	f	large
76597	1883	447	Тверская область, Кимры, проезд Савеловский, 1	f	large
76596	1883	446	Тверская область, Кимры, проезд Савеловский, 1	f	large
76594	1881	444	Тверская область, Кимры, Южная, 5	f	large
76587	1875	437	Тверская область, Кимры, Шевченко, 73	f	large
76593	1880	443	Тверская область, Кимры, Троицкая, 99	f	large
76592	1880	442	Тверская область, Кимры, Троицкая, 99	f	large
76595	1882	445	Тверская область, Кимры, Русакова, 14	f	large
76590	1878	440	Тверская область, Кимры, Ленина, 12а	f	large
76589	1877	439	Тверская область, Кимры, Ленина, 11	f	large
124801	1889	455	Тверская область, Кимры, Кропоткина, 22	f	small
76600	1885	450	Тверская область, Кимры, Коммунистическая, 8	f	large
76599	1884	449	Тверская область, Кимры, Коммунистическая, 8	f	large
76602	1886	452	Тверская область, Кимры, Кириллова, 20	f	large
76601	1886	451	Тверская область, Кимры, Кириллова, 20	f	large
76591	1879	441	Тверская область, Кимры, Звиргздыня, 55	f	large
76588	1876	438	Тверская область, Кимры, Володарского, 102	f	large
76604	1888	454	Тверская область, Кимры, 60 лет Октября, 2	f	large
76603	1887	453	Тверская область, Кимры, 60 лет Октября, 2	f	large
76573	1812	369	Тверская область, Кашин, Чистопрудная, 28	f	large
76577	514	373	Тверская область, Кашин, Республиканская, 20	f	large
76572	1811	368	Тверская область, Кашин, Максима Горького, 1а	f	large
76569	1808	365	Тверская область, Кашин, Льва Толстого, 18	f	large
76574	1813	370	Тверская область, Кашин, Ленина, 30/5	f	large
76575	21	371	Тверская область, Кашин, Кашинская, 17а	f	large
76576	398	372	Тверская область, Кашин, Карла Маркса, 69	f	large
76571	1810	367	Тверская область, Кашин, Инны Константиновой, 1	f	large
76570	1809	366	Тверская область, Кашин, Гражданская, 26	f	large
124746	1807	364	Тверская область, Кашин, Анатолия Луначарского, 2	f	medium
76578	589	374	Тверская область, Кашин, 25 Октября, 20	f	large
76536	966	199	Тверская область, Вышний Волочек, Ямская, 259А	f	large
76520	1622	173	Тверская область, Вышний Волочек, Шмидта, 194	f	large
76518	1620	171	Тверская область, Вышний Волочек, Шмидта, 21	f	large
76519	1621	172	Тверская область, Вышний Волочек, Узкоколейная, 1	f	large
76521	1623	174	Тверская область, Вышний Волочек, Советская, 5	f	large
76528	1632	182	Тверская область, Вышний Волочек, Сиверсова, 75	f	large
76533	1644	194	Тверская область, Вышний Волочек, Северная, 7	f	large
124613	807	196	Тверская область, Вышний Волочек, Северная, 5/49	f	medium
76530	1639	189	Тверская область, Вышний Волочек, Ржевский тракт, 24	f	large
124610	1640	190	Тверская область, Вышний Волочек, Осташковская, 3/7	f	medium
124609	1638	188	Тверская область, Вышний Волочек, Московское шоссе, 107А	f	medium
76534	816	197	Тверская область, Вышний Волочек, Мира, 70Б	f	large
76535	816	198	Тверская область, Вышний Волочек, Мира, 70Б	f	large
76524	1627	178	Тверская область, Вышний Волочек, Марины Расковой, 73	f	large
124611	1643	193	Тверская область, Вышний Волочек, Магистральная, 19/24	f	medium
124614	1646	200	Тверская область, Вышний Волочек, Льва Толстого, 105А	f	small
124612	1645	195	Тверская область, Вышний Волочек, Ленинградское шоссе, 57	f	medium
124605	1633	183	Тверская область, Вышний Волочек, Красный Городок, 239	f	medium
76532	1642	192	Тверская область, Вышний Волочек, Коммунаров, 1/2	f	large
124606	1634	184	Тверская область, Вышний Волочек, Карла Маркса, 99	f	small
76527	1631	181	Тверская область, Вышний Волочек, Казанский проспект, 51/2	f	large
124604	1625	176	Тверская область, Вышний Волочек, Казанский проспект, 86А	f	medium
76522	1624	175	Тверская область, Вышний Волочек, Казанский проспект, 98-100	f	large
124607	1635	185	Тверская область, Вышний Волочек, Екатерининская, 22	f	medium
76525	1628	179	Тверская область, Вышний Волочек, Демьяна Бедного, 72/64	f	large
124608	1636	186	Тверская область, Вышний Волочек, Венецианова, 1	f	medium
76523	1626	177	Тверская область, Вышний Волочек, Вагжанова, 30	f	large
76526	1630	180	Тверская область, Вышний Волочек, Большая Садовая, 31/17	f	large
76531	1641	191	Тверская область, Вышний Волочек, Бейшлотская набережная, 129А	f	large
76529	1637	187	Тверская область, Вышний Волочек, 3-я Пролетарская, 50/26	f	large
76486	93377	39	Тверская область, Бежецк, переулок Первомайский, 35/7А	f	large
76481	1503	33	Тверская область, Бежецк, переулок Молодежный, 9	f	large
76484	1507	37	Тверская область, Бежецк, Школьная, 24	f	large
76485	93309	38	Тверская область, Бежецк, Чудова, 71/5	f	large
76492	93695	45	Тверская область, Бежецк, Чехова, 13	f	large
76491	93599	44	Тверская область, Бежецк, Чехова, 2/15	f	large
76488	93506	41	Тверская область, Бежецк, Спасская, 6/17	f	large
76490	93574	43	Тверская область, Бежецк, Советская, 1	f	large
76483	1506	36	Тверская область, Бежецк, М.И. Кузнецова, 7/4	f	large
76487	93482	40	Тверская область, Бежецк, Красноармейская, 2	f	large
124502	1502	32	Тверская область, Бежецк, Клубная, 1	f	medium
76489	93517	42	Тверская область, Бежецк, Кашинская, 102	f	large
124503	1505	35	Тверская область, Бежецк, Большая, 29	f	medium
76482	1504	34	Тверская область, Бежецк, Большая, 2	f	large
76547	1723	278	Тверская область, поселок Аввакумово, 5, админ. Аввакумовского с/п	f	large
125252	2616	1259	Тверская область, Фировский район, поселок Ходуново, Сельский Дом культуры	f	small
125251	2615	1258	Тверская область, Фировский район, поселок Фирово, Советская, 21	f	small
76948	2603	1247	Тверская область, Фировский район, поселок Фирово, Советская, 25	f	large
125247	2611	1254	Тверская область, Фировский район, поселок Труд, Толстова, 2	f	small
125245	2609	1252	Тверская область, Фировский район, поселок Трестино, Сельский клуб	f	small
125242	2605	1249	Тверская область, Фировский район, поселок Сосновка, Школьная, 100	f	medium
125246	2610	1253	Тверская область, Фировский район, поселок Рождество, Юбилейная, 25	f	medium
125248	2612	1255	Тверская область, Фировский район, поселок Лесной, Сельский клуб	f	small
125249	2613	1256	Тверская область, Фировский район, поселок Комсомольский, Центральная, Сельский Дом культуры	f	small
125243	2607	1250	Тверская область, Фировский район, поселок Жуково, Новая, Сельский Дом культуры	f	medium
125244	2608	1251	Тверская область, Фировский район, поселок Дубровка, Сельский Дом культуры	f	small
76949	2604	1248	Тверская область, Фировский район, поселок Великооктябрьский, Профсоюзная, 5	f	large
125236	2597	1241	Тверская область, Удомельский район, поселок Ряд, Рядская основная школа	f	medium
125241	2602	1246	Тверская область, Удомельский район, поселок Ряд, Городок монтажников , 8	f	\N
125233	2594	1238	Тверская область, Удомельский район, поселок Порожки, Порожкинский сельский Дом Культуры	f	small
125222	2583	1227	Тверская область, Удомельский район, поселок Попово, Зареченская общеобразовательная школа	f	small
125232	2593	1237	Тверская область, Удомельский район, поселок Озера, Центральная, 30	f	small
125231	2592	1236	Тверская область, Удомельский район, Мста, Почтовая, 17, здание администрации	f	medium
125229	2590	1234	Тверская область, Удомельский район, поселок Молдино, Молдинская средняя школа	f	medium
125235	2596	1240	Тверская область, Удомельский район, поселок Мишнево, Мишневский сельский Дом Культуры	f	medium
125230	2591	1235	Тверская область, Удомельский район, поселок Михайлово, 47а	t	\N
125226	2587	1231	Тверская область, Удомельский район, поселок Маслово, Маслово, 35, Дом Культуры	f	small
125227	2588	1232	Тверская область, Удомельский район, поселок Липны, Липенская библиотека	t	small
125239	2600	1244	Тверская область, Удомельский район, поселок Лайково-Попово, Администрация Удомельского сельского поселения	f	small
125228	2589	1233	Тверская область, Удомельский район, поселок Курово, Администрация Куровского сельского поселения	f	small
125225	2586	1230	Тверская область, Удомельский район, поселок Кузьминское, 54, здание библиотеки	f	small
125224	2585	1229	Тверская область, Удомельский район, поселок Котлован, Администрация Котлованского сельского поселения	f	small
125223	2584	1228	Тверская область, Удомельский район, поселок Копачево, Копачевская общеобразовательная школа	f	small
125234	2595	1239	Тверская область, Удомельский район, поселок Касково, Сиговская средняя школа	f	small
125221	2582	1226	Тверская область, Удомельский район, поселок Еремково, Еремковская школа	f	medium
125238	2599	1243	Тверская область, Удомельский район, поселок Дерягино, Дерягинский сельский Дом Культуры	f	small
125237	2598	1242	Тверская область, Удомельский район, поселок Выскодня, Дом Культуры	f	medium
125220	2581	1225	Тверская область, Удомельский район, поселок Брусово, Администрация Брусовского сельского поселения	f	medium
125206	2555	1198	Тверская область, Торопецкий район, поселок Уварово, помещение администрации Уваровского сельского поселения	f	small
76934	2546	1189	Тверская область, Торопецкий район, Торопец	f	large
125197	2545	1188	Тверская область, Торопецкий район, Торопец	f	medium
125196	2544	1187	Тверская область, Торопецкий район, Торопец	f	medium
125195	2543	1186	Тверская область, Торопецкий район, Торопец	f	small
83895	57331	3088	Москва, Зеленоград, к222а	f	large
76933	2541	1184	Тверская область, Торопецкий район, Торопец	f	large
76932	2540	1183	Тверская область, Торопецкий район, Торопец	f	large
125193	2539	1182	Тверская область, Торопецкий район, Торопец	f	medium
125192	2538	1181	Тверская область, Торопецкий район, Торопец	f	medium
76931	2537	1180	Тверская область, Торопецкий район, Торопец	f	large
76930	2536	1179	Тверская область, Торопецкий район, Торопец	f	large
125217	2566	1209	Тверская область, Торопецкий район, поселок Талица, помещение Дома культуры	t	small
125211	2560	1203	Тверская область, Торопецкий район, поселок Скворцово, помещение Центрального сельского Дома культуры	f	small
125213	2562	1205	Тверская область, Торопецкий район, поселок Речане, здание администрации Речанского сельского поселения	f	medium
125212	2561	1204	Тверская область, Торопецкий район, поселок Пятницкое, помещение Дома культуры	f	small
125216	2565	1208	Тверская область, Торопецкий район, поселок Понизовье, помещение Дома культуры	f	small
125200	2549	1192	Тверская область, Торопецкий район, поселок Пожня, помещение Дома культуры	t	small
125198	2547	1190	Тверская область, Торопецкий район, поселок Подгороднее	f	medium
125202	2551	1194	Тверская область, Торопецкий район, поселок Плоскошь, помещение администрации Плоскошского сельского поселения	f	medium
125205	2554	1197	Тверская область, Торопецкий район, поселок Пестряково, помещение Дома культуры	t	small
125209	2558	1201	Тверская область, Торопецкий район, поселок Озерец, помещение Дома культуры	f	small
125199	2548	1191	Тверская область, Торопецкий район, поселок Нишевицы	f	small
125174	2496	1140	Тверская область, Торопецкий район, поселок Никольское	f	small
125201	2550	1193	Тверская область, Торопецкий район, поселок Наговье, помещение администрации Шешуринского сельского поселения	t	small
125203	2552	1195	Тверская область, Торопецкий район, поселок Красноселье, помещение Дома культуры	t	small
125208	2557	1200	Тверская область, Торопецкий район, поселок Кочута, помещение Кочутского Дома культуры	f	small
125204	2553	1196	Тверская область, Торопецкий район, поселок Захоломье, помещение Дома культуры	f	small
125214	2563	1206	Тверская область, Торопецкий район, поселок Грядцы, бывшее здание администрации Грядецкого сельского округа	f	small
125210	2559	1202	Тверская область, Торопецкий район, поселок Выдры, бывшее здание администрации Лужницкого сельского округа	f	small
125207	2556	1199	Тверская область, Торопецкий район, поселок Волок, здание администрации Волокского сельского поселения	f	small
125158	2478	1123	Тверская область, Торжокский район, дер.Митино, 11 , Здание ООО Санаторий Митино	f	small
125187	2510	1153	Тверская область, Торжокский район, поселок Яконово	f	small
125171	2492	1136	Тверская область, Торжокский район, поселок Тупиково, Центральная, 2	f	small
125186	2509	1152	Тверская область, Торжокский район, поселок Тредубье	t	small
125185	2508	1151	Тверская область, Торжокский район, поселок Тверецкий	f	medium
125179	2501	1145	Тверская область, Торжокский район, поселок Таложня	f	small
125183	2506	1149	Тверская область, Торжокский район, поселок Сукромля	f	medium
125180	2502	1146	Тверская область, Торжокский район, поселок Страшевичи	f	small
76740	2307	890	Тверская область, Торжокский район, поселок Спирово	f	large
125157	2477	1122	Тверская область, Торжокский район, поселок Славный	f	medium
125170	2491	1135	Тверская область, Торжокский район, поселок Селихово, Совхозная, 10	f	small
125182	2505	1148	Тверская область, Торжокский район, поселок Русино	f	small
125178	2500	1144	Тверская область, Торжокский район, поселок Рудниково	f	small
125176	2498	1142	Тверская область, Торжокский район, поселок Пирогово	f	small
125175	2497	1141	Тверская область, Торжокский район, поселок Осташково, Молодежная, 9	t	small
125172	2493	1137	Тверская область, Торжокский район, поселок Мошки, 82, Здание администрации с/п	f	medium
76908	2495	1139	Тверская область, Торжокский район, поселок Мирный, Советская, 7а	f	large
125169	2490	1134	Тверская область, Торжокский район, поселок Маслово, Черемушки, 3	f	small
125167	2487	1132	Тверская область, Торжокский район, поселок Марьино, 73, Здание администрации с/п	f	medium
125181	2503	1147	Тверская область, Торжокский район, поселок Лужково	t	small
125165	2485	1130	Тверская область, Торжокский район, поселок Ладьино, 14а, здание библиотеки	f	small
125151	2470	1116	Тверская область, Торжокский район, поселок Климово	f	small
125177	2499	1143	Тверская область, Торжокский район, поселок Ильино	f	small
125168	2488	1133	Тверская область, Торжокский район, поселок Зеленый, 26, административное здание с/п	f	medium
125166	2486	1131	Тверская область, Торжокский район, поселок Дудорово, 35а, административное здание с/п	f	small
125155	2474	1120	Тверская область, Торжокский район, поселок Дубровка	f	medium
125163	2483	1128	Тверская область, Торжокский район, поселок Грузины, Центральная, 7	f	medium
125162	2482	1127	Тверская область, Торжокский район, поселок Глухово, 15, здание школы	f	small
125161	2481	1126	Тверская область, Торжокский район, поселок Высокое	f	\N
125160	2480	1125	Тверская область, Торжокский район, поселок Воропуни	t	small
125153	2472	1118	Тверская область, Торжокский район, поселок Быльцыно, Центральная, 14а	t	small
125173	2494	1138	Тверская область, Торжокский район, поселок Булатниково, 11, Здание администрации с/п	f	small
125156	2476	1121	Тверская область, Торжокский район, поселок Будово	f	medium
125154	2473	1119	Тверская область, Торжокский район, поселок Борисцево	f	medium
125152	2471	1117	Тверская область, Торжокский район, поселок Большое Святцово	f	small
125150	2469	1115	Тверская область, Торжокский район, поселок Большое Петрово	f	small
125188	2511	1154	Тверская область, Торжокский район, поселок Большое Вишенье	f	small
125159	2479	1124	Тверская область, Торжокский район, поселок Богатьково, 85, здание администрации сельского поселения	f	small
125184	2507	1150	Тверская область, Торжокский район, поселок Альфимово	f	small
125107	2327	910	Тверская область, Старицкий район, дер.Юрьевское Архангельского С/П, административное здание сельского поселения	f	small
125128	2351	934	Тверская область, Старицкий район, поселок Степурино	f	medium
76748	2347	930	Тверская область, Старицкий район, Старица, здание администрации сельского поселения	f	large
76744	2324	907	Тверская область, Старицкий район, Старица, Иваноцва, 1а, здание Старицкой СОШ	f	large
125116	2338	921	Тверская область, Старицкий район, поселок Рясня	f	small
125119	2341	924	Тверская область, Старицкий район, поселок Родня	f	small
125125	2348	931	Тверская область, Старицкий район, поселок Покровское	f	small
125124	2346	929	Тверская область, Старицкий район, поселок Паньково	f	small
125118	2340	923	Тверская область, Старицкий район, поселок Орлово	f	small
125121	2343	926	Тверская область, Старицкий район, поселок Орешки	f	small
125123	2345	928	Тверская область, Старицкий район, поселок Новое, административное здание сельского поселения	f	small
125112	2332	915	Тверская область, Старицкий район, поселок Нестерово	f	small
76747	2337	920	Тверская область, Старицкий район, поселок Луковниково	f	large
125114	2335	918	Тверская область, Старицкий район, поселок Красное	f	small
125122	2344	927	Тверская область, Старицкий район, поселок Коньково	f	small
76746	2333	916	Тверская область, Старицкий район, поселок Емельяново	f	large
125109	2329	912	Тверская область, Старицкий район, поселок Дарьино, административное здание сельского поселения	f	small
125127	2350	933	Тверская область, Старицкий район, поселок Гурьево	f	small
125111	2331	914	Тверская область, Старицкий район, поселок Васильевское	f	small
125110	2330	913	Тверская область, Старицкий район, поселок Броды	f	small
125115	2336	919	Тверская область, Старицкий район, поселок Братково	f	small
125108	2328	911	Тверская область, Старицкий район, поселок Берново, здание администрации сельского поселения	f	medium
125126	2349	932	Тверская область, Старицкий район, поселок Бабынино	f	small
125120	2342	925	Тверская область, Старицкий район, поселок Бабино	f	small
125106	2326	909	Тверская область, Старицкий район, поселок Архангельское, здание администрации сельского поселения	f	small
125092	2306	889	Тверская область, Спировский район, поселок Спирово	f	medium
125104	2321	903	Тверская область, Спировский район, поселок Пеньково, Центральная, 29	f	medium
125103	2320	902	Тверская область, Спировский район, поселок Пеньково, Советов, 7	f	small
125098	2315	897	Тверская область, Спировский район, поселок Ососье, 17	f	small
125105	2322	904	Тверская область, Спировский район, поселок Новое Ободово, Лесная, 9А	f	small
125095	2312	894	Тверская область, Спировский район, поселок Никулино, Центральная, 29	f	small
125099	2316	898	Тверская область, Спировский район, поселок Матвеево, Климово, 29	f	small
125100	2317	899	Тверская область, Спировский район, поселок Красное Знамя, Советская, 1А	f	small
125097	2314	896	Тверская область, Спировский район, поселок Козлово, Культурная, 2	f	small
125094	2311	893	Тверская область, Спировский район, поселок Заболотье, Новая, 20	f	small
125096	2313	895	Тверская область, Спировский район, поселок Еремеевка, 40	f	small
125102	2319	901	Тверская область, Спировский район, поселок Городок, Центральная, 6	f	small
125093	2310	892	Тверская область, Спировский район, поселок Выдропужск, Новая, 4	f	medium
125101	2318	900	Тверская область, Спировский район, поселок Бирючево, Центральная, 54А	f	small
76737	2291	875	Тверская область, Сонковский район, поселок Сонково, Широкая, 21	f	large
76738	2292	876	Тверская область, Сонковский район, поселок Сонково, Новопромышленная, 5а	f	large
125090	2303	886	Тверская область, Сонковский район, поселок Сергеевское, здание правления колхоза Советская Россия	f	small
125082	2294	878	Тверская область, Сонковский район, поселок Пригорки, помещение фельдшерско-акушерского пункта	f	small
125091	2304	887	Тверская область, Сонковский район, поселок Пищалкино, здание администрации сельского поселения	f	small
125089	2302	885	Тверская область, Сонковский район, поселок Петровское, здание администрации сельского поселения	f	small
125086	2299	882	Тверская область, Сонковский район, поселок Новые Горицы, помещение сельской библиотеки	f	small
125087	2300	883	Тверская область, Сонковский район, поселок Кой, здание администрации сельского поселения	f	small
125085	2298	881	Тверская область, Сонковский район, поселок Григорково, здание администрации сельского поселения	f	small
125084	2297	880	Тверская область, Сонковский район, поселок Горка, здание администрации сельского поселения	f	medium
125083	2296	879	Тверская область, Сонковский район, поселок Гладышево, здание МОУ Гладышевская основная общеобразовательная школа	f	small
125088	2301	884	Тверская область, Сонковский район, поселок Вепрь, МОУ Вепревская основная общеобразовательная школа	f	small
125081	2293	877	Тверская область, Сонковский район, поселок Беляницы, здание администрации сельского поселения	f	medium
125080	2289	873	Тверская область, Селижаровский район, поселок Шуваево, Новая, 8А	f	small
125078	2287	871	Тверская область, Селижаровский район, поселок Хотошино, Центральная, 2	f	small
125066	2275	859	Тверская область, Селижаровский район, поселок Филистово, Центральная, 5	f	small
125076	2285	869	Тверская область, Селижаровский район, поселок Селище, Почтовая, 22	f	medium
125059	2268	852	Тверская область, Селижаровский район, поселок Селижарово, Энгельса, 103	f	medium
76734	2266	849	Тверская область, Селижаровский район, поселок Селижарово, Пушкина, 58	f	large
76735	2267	851	Тверская область, Селижаровский район, поселок Селижарово, Победы, 15	f	large
125060	2269	853	Тверская область, Селижаровский район, поселок Селижарово, Микрорайон, 7	f	medium
76733	2265	848	Тверская область, Селижаровский район, поселок Селижарово, Ленина, 3 А	f	large
125058	2253	850	Тверская область, Селижаровский район, поселок Селижарово, Зеленая, 1	f	medium
125079	2288	872	Тверская область, Селижаровский район, поселок Подсосонье, Дружная, 6	f	small
125075	2284	868	Тверская область, Селижаровский район, поселок Ольхово, Центральная, 9	f	small
125072	2281	865	Тверская область, Селижаровский район, поселок Оковцы, Советская, 3	f	small
125074	2283	867	Тверская область, Селижаровский район, поселок Малое Ананкино, Центральная, 9	t	small
125070	2279	863	Тверская область, Селижаровский район, поселок Максимково, Новая, 11	f	small
125063	2272	856	Тверская область, Селижаровский район, поселок Киселево, Центральная, 26	f	small
125068	2277	861	Тверская область, Селижаровский район, поселок Захарово, Молодежная, 1	f	small
125067	2276	860	Тверская область, Селижаровский район, поселок Ельцы, Школьный, 8	f	small
125077	2286	870	Тверская область, Селижаровский район, поселок Дубровки, Северная, 3	f	small
125073	2282	866	Тверская область, Селижаровский район, поселок Дружная Горка, Школьная, 5	f	small
125065	2274	858	Тверская область, Селижаровский район, поселок Дмитрово, администрация Дмитровского сельского поселения	f	small
125064	2273	857	Тверская область, Селижаровский район, поселок Гора, Зеленая, 6	t	small
125069	2278	862	Тверская область, Селижаровский район, поселок Большое Кашино, администрация Максимковского сельского поселения	t	small
125062	2271	855	Тверская область, Селижаровский район, поселок Большая Коша, Центральная, 11	f	small
125054	2261	844	Тверская область, Сандовский район, станция Торопово, Здание администрации Топоровского сельского поселения	f	small
125052	2259	842	Тверская область, Сандовский район, поселок Тухани, Здание конторы Крестьянско-фермерского хозяйства Козлов А	f	small
125051	2258	841	Тверская область, Сандовский район, поселок Топалки, Здание МОУ Топалковская НОШ	f	small
125046	2252	836	Тверская область, Сандовский район, поселок Сушигорицы, Здание Сушигорицкого Дома Досуга	f	small
124767	1834	395	Тверская область, Сандовский район, поселок Стулово, 26	f	medium
125053	2260	843	Тверская область, Сандовский район, поселок Старое Сандово, Здание администрации Старосандовского сельского	f	small
125045	2251	835	Тверская область, Сандовский район, поселок Соболины, Здание администрации Соболинского сельского поселения	f	small
76732	2250	834	Тверская область, Сандовский район, поселок Сандово, Школьная, 1	f	large
76731	2249	833	Тверская область, Сандовский район, поселок Сандово, Советская, 13а	f	large
124712	1764	319	Тверская область, Сандовский район, поселок Садовая, 29	f	medium
125048	2255	838	Тверская область, Сандовский район, поселок Пнево, Здание конторы колхоза Заря	f	small
125049	2256	839	Тверская область, Сандовский район, поселок Лукино, Здание администрации Лукинского сельского поселения	f	small
125055	2262	845	Тверская область, Сандовский район, поселок Ладожское, Здание Ладожского Дома Досуга	f	small
125050	2257	840	Тверская область, Сандовский район, поселок Кресты, Здание Свердловского Дома культуры	f	small
125057	2264	847	Тверская область, Сандовский район, поселок Вокшино, Здание Ростороповской библиотеки	f	small
125047	2254	837	Тверская область, Сандовский район, поселок Большое Малинское, Здание МОУ Большемалинская СОШ	f	small
125056	2263	846	Тверская область, Сандовский район, поселок Березье, Здание МОУ Березская НОШ	f	small
125020	2203	779	Тверская область, Ржевский район, поселок Шолохово, 13, здание ДОУ	f	small
125038	2222	799	Тверская область, Ржевский район, поселок Чертолино, Школьная, 16	f	small
76702	2212	789	Тверская область, Ржевский район, поселок Хорошево, 5а, здание администрации	f	large
125027	2112	786	Тверская область, Ржевский район, поселок Успенское, 9, здание СДК	f	small
125018	2201	777	Тверская область, Ржевский район, поселок Трубино, Центральная, здание школы	f	small
125022	2205	781	Тверская область, Ржевский район, поселок Раменское, здание библиотеки	f	small
125036	2220	797	Тверская область, Ржевский район, поселок Пятницкое, 6, здание администрации	f	small
125015	2198	774	Тверская область, Ржевский район, поселок Победа, Школьная, 12а	f	\N
125028	2210	787	Тверская область, Ржевский район, поселок Плешки, 80, здание ДОУ	f	small
125017	2200	776	Тверская область, Ржевский район, поселок Парихино, Новая, здание школы	f	small
125035	2219	796	Тверская область, Ржевский район, поселок Осуга, Привокзальная, 1а	f	small
125029	2211	788	Тверская область, Ржевский район, поселок Орехово, Центральная, 25	f	small
125025	2208	784	Тверская область, Ржевский район, поселок Озерютино, 21, здание библиотеки	f	small
125012	2197	773	Тверская область, Ржевский район, поселок Образцово, 24, здание ДОУ	f	small
125019	2202	778	Тверская область, Ржевский район, поселок Михалево, 4, здание школы	f	small
125033	2217	794	Тверская область, Ржевский район, поселок Медведево, 23	f	small
125034	2218	795	Тверская область, Ржевский район, поселок Курьяново, 52, здание школы	f	small
125023	2206	782	Тверская область, Ржевский район, поселок Кривцово, 61, здание ООО АПК	f	small
125031	2214	791	Тверская область, Ржевский район, поселок Кокошкино, Банная, 10	f	small
125024	2207	783	Тверская область, Ржевский район, поселок Итомля, Центральная, 10	f	small
125040	2224	801	Тверская область, Ржевский район, поселок Ильченко, 33, здание школы	f	small
125037	2221	798	Тверская область, Ржевский район, поселок Звягино, Центральная, 28	f	small
125030	2213	790	Тверская область, Ржевский район, поселок Заволжский, Заводское шоссе, 3	f	small
125032	2215	792	Тверская область, Ржевский район, поселок Домашино, 113, здание библиотеки	f	small
125021	2204	780	Тверская область, Ржевский район, поселок Дмитрово, 46а, здание администрации	f	small
125026	2209	785	Тверская область, Ржевский район, поселок Глебово, Молодежная, 1	f	small
125016	2199	775	Тверская область, Ржевский район, поселок Бахмутово, Приволжская, 3	f	small
125039	2223	800	Тверская область, Ржевский район, поселок Азарово, 48, здание администрации	f	small
76701	2196	772	Тверская область, Рамешковский район, поселок Рамешки, Советская, 47	f	large
125014	2195	771	Тверская область, Рамешковский район, поселок Рамешки, Советская, 47	f	\N
76700	2193	769	Тверская область, Рамешковский район, поселок Рамешки, Советская, 18	f	large
125013	2194	770	Тверская область, Рамешковский район, поселок Рамешки, Пионерская, 1	f	\N
125011	2192	768	Тверская область, Рамешковский район, поселок Никольское, Центральная, 8	f	small
125010	2191	767	Тверская область, Рамешковский район, поселок Некрасово, 2а, здание Некрасовского СДК	f	medium
76699	2189	765	Тверская область, Рамешковский район, поселок Кушалино, Пушкина, 30а	f	large
125009	2190	766	Тверская область, Рамешковский район, поселок Кушалино, Колхозная, 33	f	\N
125008	2188	764	Тверская область, Рамешковский район, поселок Киверичи, Комсомольская, 21	f	medium
125007	2187	763	Тверская область, Рамешковский район, поселок Ильгощи, здание администрации с/п Ильгощи	f	medium
125006	2186	762	Тверская область, Рамешковский район, поселок Застолбье, Школьная, 8	f	medium
125004	2185	761	Тверская область, Рамешковский район, поселок Заклинье, 15а	f	medium
125005	2184	760	Тверская область, Рамешковский район, поселок Высоково, Центральная, 9	f	medium
125003	2183	759	Тверская область, Рамешковский район, поселок Ведное, Советская, 30	f	medium
125002	2182	758	Тверская область, Рамешковский район, поселок Алешино, 22, здание администрации с/п Алешино	f	medium
124998	2179	754	Тверская область, Пеновский район, поселок Соблаго, Первомайская, 12	f	small
124999	2180	755	Тверская область, Пеновский район, поселок Слаутино, Советская, 9	f	small
124993	2172	747	Тверская область, Пеновский район, поселок Пено, Лесная, 15	f	\N
76697	2173	748	Тверская область, Пеновский район, поселок Пено, Восточная, 2	f	large
76698	2174	749	Тверская область, Пеновский район, поселок Пено, 249-й Стрелковой Дивизии, 14	f	large
124997	2178	753	Тверская область, Пеновский район, поселок Охват, Советская, 35	f	small
124996	2177	752	Тверская область, Пеновский район, поселок Мошары, Центральная, 10	f	small
124995	2176	751	Тверская область, Пеновский район, поселок Заево, Центральная, 34а	f	small
125001	2067	757	Тверская область, Пеновский район, поселок Забелино, Центральная, 8	f	small
125000	2181	756	Тверская область, Пеновский район, поселок Жукопа, Набережная, 13а	f	small
124994	2175	750	Тверская область, Пеновский район, поселок Ворошилово, Здание администрации Ворошиловского сельского поселения	f	small
124983	2162	737	Тверская область, Осташковский район, турбаза Сокол , помещение Зареченской начальной школы	f	small
124982	2161	736	Тверская область, Осташковский район, поселок Щучье, помещение администрации Щучьенского сельского поселения	f	small
124985	2164	739	Тверская область, Осташковский район, поселок Хитино, помещение администрации Хитинского сельского поселения	f	small
124991	2170	745	Тверская область, Осташковский район, поселок Сосница, помещение администрации Залучьенского сельского поселения	f	small
124978	2157	732	Тверская область, Осташковский район, поселок Сорога, помещение администрации Сорожского сельского поселения	f	medium
124974	2153	728	Тверская область, Осташковский район, поселок Сиговка, помещение средней школы	f	small
124979	2158	733	Тверская область, Осташковский район, поселок Святое, помещение администрации Святосельского сельского поселения	f	small
124989	2168	743	Тверская область, Осташковский район, поселок Свапуще, помещение администрации Свапущенского сельского поселения	f	small
124975	2154	729	Тверская область, Осташковский район, поселок Рогожа, помещение клуба	f	small
76691	2146	721	Тверская область, Осташковский район, Осташков, переулок Литвиенко, 61а	f	large
124973	2148	723	Тверская область, Осташковский район, Осташков, Шевчука, 7	f	\N
76692	2147	722	Тверская область, Осташковский район, Осташков, Осташковский переулок, 4	f	large
76693	2149	724	Тверская область, Осташковский район, Осташков, Микрорайон, 20	f	large
76694	2150	725	Тверская область, Осташковский район, Осташков, Заслонова, 3а	f	large
76696	2152	727	Тверская область, Осташковский район, Осташков, Загородная, 24	f	large
76695	2151	726	Тверская область, Осташковский район, Осташков, Загородная, 22	f	large
76689	2143	718	Тверская область, Осташковский район, Осташков, Горького, 32	f	large
124972	2145	720	Тверская область, Осташковский район, Осташков, Володарского, 56	f	medium
76690	2144	719	Тверская область, Осташковский район, Осташков, Володарского, 13	f	large
124984	2163	738	Тверская область, Осташковский район, поселок Новые Ельцы, помещение начальной школы	f	small
124980	2159	734	Тверская область, Осташковский район, поселок Мошенка, помещение администрации Мошенского сельского поселения	f	small
125250	2614	1257	Тверская область, Осташковский район, поселок Мартюшино, Сельский клуб	f	small
124976	2155	730	Тверская область, Осташковский район, поселок Зехново, помещение начальной школы	f	small
124988	2167	742	Тверская область, Осташковский район, поселок Занепречье, административное здание Замошского сельского поселения	f	small
124987	2166	741	Тверская область, Осташковский район, поселок Замошье, помещение администрации Замошского сельского помещения	f	small
124981	2160	735	Тверская область, Осташковский район, поселок Задубье, административное здание Мошенского сельского поселения	f	small
124977	2156	731	Тверская область, Осташковский район, поселок Жданово, помещение администрации Ждановского сельского поселения	f	small
124960	2131	706	Тверская область, Оленинский район, поселок Холмина, Здание школы	f	small
124968	2139	714	Тверская область, Оленинский район, поселок Холмец, Советская, 2	f	small
124962	2133	708	Тверская область, Оленинский район, поселок Хлебники, Здание Хлебниковского территориального отдела	f	small
124957	2128	703	Тверская область, Оленинский район, поселок Толокново, Здание школы	f	small
124964	2135	710	Тверская область, Оленинский район, поселок Татево, Школьная, 1	f	small
124965	2136	711	Тверская область, Оленинский район, поселок Тархово, Центральная, 28	f	small
124955	2126	701	Тверская область, Оленинский район, поселок Сады, Здание Садовского территориального отдела	f	small
124971	2142	717	Тверская область, Оленинский район, поселок Отрадное	f	\N
76687	2120	694	Тверская область, Оленинский район, поселок Оленино, Чехова, 12	f	large
76686	2119	693	Тверская область, Оленинский район, поселок Оленино, Октябрьская, 5	f	large
124956	2127	702	Тверская область, Оленинский район, поселок Никулино, Здание школы	f	small
124950	2121	695	Тверская область, Оленинский район, поселок Молодой Туд, Здание школы	f	medium
76688	2122	696	Тверская область, Оленинский район, поселок Мирный, Юбилейная, 12	f	large
124952	2124	698	Тверская область, Оленинский район, поселок Козлы, Центральная, 6а	f	small
124969	2140	715	Тверская область, Оленинский район, поселок Ильенки, Здание Первомайского территориального отдела	f	small
124951	2123	697	Тверская область, Оленинский район, поселок Знаменское, Здание школы	f	small
124961	2132	707	Тверская область, Оленинский район, поселок Завидово, Здание Завидовского территориального отдела	f	small
124963	2134	709	Тверская область, Оленинский район, поселок Гусево, Здание школы	f	small
124958	2129	704	Тверская область, Оленинский район, поселок Гришино, Здание школы	f	small
124967	2138	713	Тверская область, Оленинский район, поселок Городок, Здание Городковского территориального отдела	f	small
124953	2125	699	Тверская область, Оленинский район, поселок Глазки, Центральная, 5	f	small
124966	2137	712	Тверская область, Оленинский район, поселок Воротьково, Советская, 29	f	small
124959	2130	705	Тверская область, Оленинский район, поселок Воронино, Здание Воронинского территориального отдела	f	small
83894	57330	3087	Москва, Зеленоград, к163	f	large
124970	2141	716	Тверская область, Оленинский район, поселок Большая Каденка, Центральная, 5	f	small
124954	2042	700	Тверская область, Оленинский район, поселок Бобровка, Здание школы	f	small
124942	2107	675	Тверская область, Нелидовский район, пос.Заповедный, Помещение Дома досуга	t	small
124986	2165	740	Тверская область, Нелидовский район, поселок Южный, помещение Дома культуры	f	small
124937	2101	668	Тверская область, Нелидовский район, поселок Южный, Помещение Дома досуга	f	medium
124935	2099	666	Тверская область, Нелидовский район, поселок Южный, Бельское шоссе, 2-й км, помещение ДРСУ	f	medium
124456	2104	671	Тверская область, Нелидовский район, поселок Старое Кутьево, Помещение ФАП НМУ ЦРБ	f	small
124943	2108	676	Тверская область, Нелидовский район, поселок Селы, Помещение администрации с/п	f	small
124940	2105	673	Тверская область, Нелидовский район, поселок Пустое Подлесье, Помещение школы	f	small
124465	2109	677	Тверская область, Нелидовский район, поселок Паникля, Помещение Нелидовского психоневрологического интерната	f	small
124945	2111	680	Тверская область, Нелидовский район, поселок Новоселки, Помещение администрации с/п	f	small
76672	2077	644	Тверская область, Нелидовский район, Нелидово, Советская, 33	f	large
124468	2619	682	Тверская область, Нелидовский район, поселок Монино, Административное здание ФБУ-ИК-9	f	small
124938	2102	669	Тверская область, Нелидовский район, поселок Межа, Помещение Дома досуга	f	medium
124469	2630	683	Тверская область, Нелидовский район, поселок Кривцово, Помещение ФАП НМУ ЦРБ	f	small
124467	2629	681	Тверская область, Нелидовский район, поселок Копейки, Помещение ФАП НМУ ЦРБ	f	small
124949	2116	687	Тверская область, Нелидовский район, поселок Земцы, Помещение ИП Степанова	f	small
124948	2115	686	Тверская область, Нелидовский район, поселок Земцы, Помещение администрации с/п	f	small
124947	2114	685	Тверская область, Нелидовский район, поселок Земцы, Помещение школы	f	small
124936	2100	667	Тверская область, Нелидовский район, поселок Загородный, 1а, Помещение Нелидовского психоневрологического интерната	f	small
124946	2113	684	Тверская область, Нелидовский район, поселок Горки, Помещение ФАП НМУ ЦРБ	f	small
124941	2106	674	Тверская область, Нелидовский район, поселок Высокое, Помещение администрации с/п	f	small
124466	2618	679	Тверская область, Нелидовский район, поселок Верхнее Заборье, Помещение ФАП НМУ ЦРБ	f	small
124455	2617	672	Тверская область, Нелидовский район, поселок Арбузово, Помещение администрации с/п	f	small
124920	2075	642	Тверская область, Молоковский район, поселок Черкасово, здание Черкасовской начальной общеобразовательной школы	f	small
124913	2068	635	Тверская область, Молоковский район, поселок Тушитово, здание Тушитовской начальной общеобразовательной школы	f	small
124915	2070	637	Тверская область, Молоковский район, поселок Рамешки	t	small
124909	2063	631	Тверская область, Молоковский район, поселок Покров, здание Покровской сельской библиотеки	f	small
124918	2073	640	Тверская область, Молоковский район, поселок Подертово, здание Суборьской сельской библиотеки	f	small
124916	2071	638	Тверская область, Молоковский район, поселок Обросово, здание Обросовской основной общеобразовательной школы	f	small
76671	2061	629	Тверская область, Молоковский район, поселок Молоково, пл.Корнилова, .4	f	large
124914	2069	636	Тверская область, Молоковский район, поселок Молоково, Ленина, 19	f	small
124907	2060	628	Тверская область, Молоковский район, поселок Молоково, Ленина, 22	f	medium
124917	2072	639	Тверская область, Молоковский район, поселок Карельский Городок, здание Каргородковской начальной общеобразовательной школы	t	small
124910	2064	632	Тверская область, Молоковский район, поселок Деледино, здание Делединской основной общеобразовательной школы	f	small
124911	2065	633	Тверская область, Молоковский район, поселок Биколово, здание отделения почтовой связи	t	small
124908	2062	630	Тверская область, Молоковский район, поселок Ахматово, Здание Ахматовской основной общеобразовательной школы	f	small
124919	2074	641	Тверская область, Молоковский район, поселок Антоновское, здание Антоновской основной общеобразовательной школы	f	small
124865	2007	573	Тверская область, Лихославльский район, поселок Назарово, 83	t	small
124912	2066	634	Тверская область, Молоковский район, поселок Андрейцево, здание Андрейцевской основной общеобразовательной школы	f	small
124901	2054	622	Тверская область, Максатихинский район, поселок Фабрика, Помещение сельского Дома культуры	f	medium
124905	2058	626	Тверская область, Максатихинский район, поселок Труженик, Помещение Труженицкого сельского Дома культуры	f	small
124904	2057	625	Тверская область, Максатихинский район, поселок Трестна, Помещение администрации Трестенского сельского поселения	f	small
124887	2039	608	Тверская область, Максатихинский район, поселок Сидорково, Помещение Сидорковского сельского Дома культуры	f	small
124902	2055	623	Тверская область, Максатихинский район, поселок Сельцы, Помещение администрации Селецкого сельского поселения	f	small
124900	2053	621	Тверская область, Максатихинский район, поселок Рыбинское Заручье, Помещение администрации Рыбинского сельского поселения	f	small
124898	2051	619	Тверская область, Максатихинский район, поселок Ручки, Помещение администрации Ручковского сельского поселения	f	small
124896	2049	617	Тверская область, Максатихинский район, поселок Ривицкий, Помещение администрации Ривицкого сельского поселения	t	medium
124892	2045	613	Тверская область, Максатихинский район, поселок Раевское, Помещение сельской библиотеки	f	small
124894	2047	615	Тверская область, Максатихинский район, поселок Пальчиха, Помещение администрации Пальчихинского сельского поселения	f	small
124906	2059	627	Тверская область, Максатихинский район, поселок Новое Пхово, Помещение сельского Дома культуры	f	small
124890	2043	611	Тверская область, Максатихинский район, поселок Малышево, Помещение администрации Малышевского сельского поселения	f	medium
76670	2035	604	Тверская область, Максатихинский район, поселок Максатиха, Пролетарская, 1	f	large
76667	2032	601	Тверская область, Максатихинский район, поселок Максатиха, Парковская, 50	f	large
76668	2033	602	Тверская область, Максатихинский район, поселок Максатиха, Красноармейская, 58	f	large
76669	2034	603	Тверская область, Максатихинский район, поселок Максатиха, Кранослободская, 7	f	large
124889	2041	610	Тверская область, Максатихинский район, поселок Кострецы, Помещение администрации Кострецкого сельского поселения	f	medium
124895	2048	616	Тверская область, Максатихинский район, поселок Ключевая, Помещение администрации Пальчихинского сельского поселения	f	small
124891	2044	612	Тверская область, Максатихинский район, поселок Кистутово, Помещение Кистутовской средней школы	f	small
124888	2040	609	Тверская область, Максатихинский район, поселок Каменка, Помещение администрации Каменского сельского поселения	f	medium
124893	2046	614	Тверская область, Максатихинский район, поселок Засека, Помещение конторы СПК Засека	f	small
124886	2038	607	Тверская область, Максатихинский район, поселок Заречье, Помещение Зареченского сельского Дома культуры	f	small
124903	2056	624	Тверская область, Максатихинский район, поселок Дымцево, Помещение администрации Селецкого сельского поселения	f	small
124885	2037	606	Тверская область, Максатихинский район, поселок Дубищи, Помещение Дубищенской основной общеобразовательной школы	f	small
124899	2052	620	Тверская область, Максатихинский район, поселок Горка, Помещение сельского Дома культуры	f	small
124884	2036	605	Тверская область, Максатихинский район, поселок Буденовка, Помещение администрации Буденовского сельского	f	small
124897	2050	618	Тверская область, Максатихинский район, поселок Большая Воздвиженка, Помещение фельдшерско-акушерского пункта	f	small
124862	2004	570	Тверская область, Лихославльский район, поселок Язвиха, 53	f	small
124867	2009	575	Тверская область, Лихославльский район, поселок Толмачи, 1-я Больничная, 2	f	medium
124861	2003	569	Тверская область, Лихославльский район, поселок Стан, 33	f	medium
124882	2030	599	Тверская область, Лихославльский район, поселок Сосновицы, 113	f	small
124866	2008	574	Тверская область, Лихославльский район, поселок Прудово, 62	t	small
124878	2026	595	Тверская область, Лихославльский район, поселок Первитино, Севастьянова, 11	f	small
124874	2022	591	Тверская область, Лихославльский район, поселок Осиновая Гряда, 1А	f	medium
76329	92660	754	Тамбовская область, Тамбов, Рылеева, 69	f	large
124883	2031	600	Тверская область, Лихославльский район, поселок Михайлова Гора, 53	f	small
124880	2028	597	Тверская область, Лихославльский район, поселок Микшино, 116	f	small
76662	2014	581	Тверская область, Лихославльский район, Лихославль, Первомайская, 13	f	large
76658	2010	576	Тверская область, Лихославльский район, Лихославль, Лихославская, 30Б	f	large
76659	2010	577	Тверская область, Лихославльский район, Лихославль, Лихославская, 30Б	f	large
124869	2016	584	Тверская область, Лихославльский район, Лихославль, Комсомольская, 66	f	medium
76664	2015	583	Тверская область, Лихославльский район, Лихославль, Комсомольская, 51	f	large
76663	2015	582	Тверская область, Лихославльский район, Лихославль, Комсомольская, 51	f	large
124868	2012	579	Тверская область, Лихославльский район, Лихославль, Гагарина, 51	f	medium
76660	2011	578	Тверская область, Лихославльский район, Лихославль, Бежецкая, 24	f	large
76661	2013	580	Тверская область, Лихославльский район, Лихославль, Афанасьева, 2	f	large
124877	2025	594	Тверская область, Лихославльский район, поселок Кузовино, 105	f	small
124875	2023	592	Тверская область, Лихославльский район, поселок Крючково, Комсомольская, 18	f	medium
124870	2018	586	Тверская область, Лихославльский район, поселок Калашниково, Ленина, 51	f	medium
76665	2017	585	Тверская область, Лихославльский район, поселок Калашниково, Ленина, 45	f	large
76666	2017	587	Тверская область, Лихославльский район, поселок Калашниково, Ленина, 45	f	large
124876	2024	593	Тверская область, Лихославльский район, поселок Кава, 40	f	medium
124872	2020	589	Тверская область, Лихославльский район, поселок Ильинское, Молодежная, 21	f	medium
124881	2029	598	Тверская область, Лихославльский район, поселок Залазино, 47А	f	small
124863	2005	571	Тверская область, Лихославльский район, поселок Гнездово, 94	f	small
124879	2027	596	Тверская область, Лихославльский район, поселок Вышково, 25	f	small
124873	2021	590	Тверская область, Лихославльский район, поселок Вески, Центральная, 14А	f	medium
124864	2006	572	Тверская область, Лихославльский район, поселок Березовка, 39А	f	small
124871	2019	588	Тверская область, Лихославльский район, поселок Барановка, 6	f	medium
124860	2002	568	Тверская область, Лихославльский район, поселок Анцифарово, 8	f	small
124858	1999	566	Тверская область, Лесной район, поселок Телятники, Центральная, 86	f	small
76741	2308	891	Тверская область, Лесной район, поселок Спирово	f	large
76739	2305	888	Тверская область, Лесной район, поселок Спирово	f	large
124856	1997	564	Тверская область, Лесной район, поселок Никольское, Центральная, 22	f	small
124855	1996	563	Тверская область, Лесной район, поселок Мотыли, Речная, 10	f	small
124854	1995	562	Тверская область, Лесной район, поселок Михайловское, Советская, 26	f	small
124853	1994	561	Тверская область, Лесной район, поселок Медведково, Новая, 21	f	small
76657	1993	560	Тверская область, Лесной район, поселок Лесное, Советская, 3	f	large
124857	1998	565	Тверская область, Лесной район, поселок Лесное, Речная, 23	f	small
124852	1992	559	Тверская область, Лесной район, поселок Кожина Гора, Ленина, 28	f	small
124851	1991	558	Тверская область, Лесной район, поселок Застровье, Речная, 16	f	small
124850	1990	557	Тверская область, Лесной район, поселок Городок, Центральная, 52	f	small
124848	1988	555	Тверская область, Лесной район, поселок Борисовское, Береговая, 4	f	small
124849	1989	556	Тверская область, Лесной район, поселок Бор-Пруды, Центральная, 25	f	small
124859	2001	567	Тверская область, Лесной район, поселок Алексейково, Центральная, 42	f	small
124847	1986	553	Тверская область, Кувшиновский район, поселок Тысяцкое, здание администрации сельского поселения	f	medium
124840	1979	546	Тверская область, Кувшиновский район, поселок Сокольники, здание администрации сельского поселения	f	small
124839	1978	545	Тверская область, Кувшиновский район, поселок Ранцево, Трудовая, 4	f	small
124846	1985	552	Тверская область, Кувшиновский район, поселок Прямухино, здание Прямухинской средней школы	f	small
124845	1984	551	Тверская область, Кувшиновский район, поселок Пречисто Каменка, здание администрации сельского поселения	t	small
124844	1983	550	Тверская область, Кувшиновский район, поселок Пень, здание администрации сельского поселения	f	small
124838	1977	544	Тверская область, Кувшиновский район, поселок Могилевка, здание администрации сельского поселения	f	small
124833	1972	539	Тверская область, Кувшиновский район, Кувшиново, административное здание ООО Баховка	f	medium
124832	1957	538	Тверская область, Кувшиновский район, Кувшиново, Степана Разина, 55	f	medium
76653	1966	532	Тверская область, Кувшиновский район, Кувшиново, Советская, 55	f	large
124830	1969	535	Тверская область, Кувшиновский район, Кувшиново, Пионерский бульвар, 9	f	medium
76652	1987	554	Тверская область, Кувшиновский район, Кувшиново, Октябрьская, 16	f	large
76654	1967	533	Тверская область, Кувшиновский район, Кувшиново, Карла Маркса, 1	f	large
76656	1971	537	Тверская область, Кувшиновский район, Кувшиново, Бумажников, 14	f	large
124831	1970	536	Тверская область, Кувшиновский район, Кувшиново, 8 Марта, 5	f	medium
124837	1976	543	Тверская область, Кувшиновский район, поселок Красный Городок, здание Красногородской школы	f	small
124836	1975	542	Тверская область, Кувшиновский район, поселок Заовражье, здание Заовражской ООШ	f	small
124835	1974	541	Тверская область, Кувшиновский район, поселок Васильково, здание администрации сельского поселения	f	small
124842	1981	548	Тверская область, Кувшиновский район, поселок Борзыни, здание Борзынской ООШ	f	small
124843	1982	549	Тверская область, Кувшиновский район, поселок Большой Борок, здание администрации сельского поселения	f	small
124841	1980	547	Тверская область, Кувшиновский район, поселок Большое Кузнечково, здание сельского Дома Культуры	f	small
124815	1950	517	Тверская область, Краснохолмский район, поселок Юрово, Здание администрации Большерагозинского сельского поселения	f	medium
124820	1955	522	Тверская область, Краснохолмский район, поселок Хабоцкое, Здание МОУ Хабоцкая СОШ	f	small
124829	1965	531	Тверская область, Краснохолмский район, поселок Ульянино, Здание администрации Ульянинского сельского поселения	f	small
124828	1964	530	Тверская область, Краснохолмский район, поселок Толстиково, Здание администрации Утеховского сельского поселения	t	small
124817	1952	519	Тверская область, Краснохолмский район, поселок Скоросово, Здание Скоросовского СДК	f	small
124826	1962	528	Тверская область, Краснохолмский район, поселок Рачево, Здание МОУ Рачевская начальная школ-детский сад	f	small
124564	1574	124	Тверская область, Краснохолмский район, поселок Овинищи, Здание библиотеки	f	small
124825	1961	527	Тверская область, Краснохолмский район, поселок Нивы, Здание администрации Нивского сельского поселения	f	small
124822	1958	524	Тверская область, Краснохолмский район, поселок Мартыново, Здание администрации Мартыновского сельского поселения	f	small
76651	1947	514	Тверская область, Краснохолмский район, Красный Холм, Пионерская, 2	f	large
76648	1944	511	Тверская область, Краснохолмский район, Красный Холм, Октябрьская, 1/13	f	large
76650	1946	513	Тверская область, Краснохолмский район, Красный Холм, Мясникова, 34	f	large
76649	1945	512	Тверская область, Краснохолмский район, Красный Холм, Калинина, 37	f	large
124819	1954	521	Тверская область, Краснохолмский район, поселок Ивакино, Здание Ивакинского СДК	f	small
124821	1956	523	Тверская область, Краснохолмский район, поселок Дмитровка, Здание МОУ Дмитровская ООШ	t	small
124814	1949	516	Тверская область, Краснохолмский район, поселок Грудино, 31, Здание библиотеки	f	small
124818	1953	520	Тверская область, Краснохолмский район, поселок Глебени, Здание администрации Глебенского сельского поселения	f	small
124816	1951	518	Тверская область, Краснохолмский район, поселок Высокуша, Здание администрации Высокушинского сельского 	f	small
124823	1959	525	Тверская область, Краснохолмский район, поселок Васильки, Здание медпункта	f	small
124824	1960	526	Тверская область, Краснохолмский район, поселок Братское	f	\N
124827	1963	529	Тверская область, Краснохолмский район, поселок Бекрень, Здание Бекренской сельской библиотеки	f	small
124813	1948	515	Тверская область, Краснохолмский район, поселок Барбино, Здание администрации Барбинского сельского поселения	f	medium
124807	1924	493	Тверская область, Конаковский район, поселок Юрьево-Девичье, Центральная, 16а	f	medium
124803	1896	462	Тверская область, Конаковский район, поселок Энергетик, База отдыха Энергетик	t	small
76639	1929	497	Тверская область, Конаковский район, поселок Старое Мелково, Парковая, 1	f	large
76634	1922	491	Тверская область, Конаковский район, поселок Селихово, Новая, 12	f	large
76644	1936	504	Тверская область, Конаковский район, поселок Редкино, проспект Химиков, 42	f	large
76640	1931	499	Тверская область, Конаковский район, поселок Редкино, Фадеева, 3	f	large
76642	1933	501	Тверская область, Конаковский район, поселок Редкино, Правды, 8	f	large
124809	1934	502	Тверская область, Конаковский район, поселок Редкино, Погрузочная, 2а	f	medium
76641	1932	500	Тверская область, Конаковский район, поселок Редкино, Калинина, 4а	f	large
76643	1935	503	Тверская область, Конаковский район, поселок Редкино, Диева, 33а	f	large
76625	1911	481	Тверская область, Конаковский район, поселок Радченко, здание ДК	f	large
76635	1923	492	Тверская область, Конаковский район, поселок Поповское, Школьная, 4	f	large
76646	1938	506	Тверская область, Конаковский район, поселок Озерки, Школьная, 1	f	large
76627	1914	483	Тверская область, Конаковский район, поселок Новозавидовский, Фабричная, 7а	f	large
76630	1917	486	Тверская область, Конаковский район, поселок Новозавидовский, Советская, 8а	f	large
76629	1916	485	Тверская область, Конаковский район, поселок Новозавидовский, Парковая, 7	f	large
76626	1912	482	Тверская область, Конаковский район, поселок Новозавидовский, Моховая, 1	f	large
76628	1915	484	Тверская область, Конаковский район, поселок Новозавидовский, Ленинская, 17	f	large
76638	1927	496	Тверская область, Конаковский район, поселок Мокшино, Школьная, 4	f	large
124806	1921	490	Тверская область, Конаковский район, поселок Мал. Ручьи, Гаранина, 12	f	medium
124811	1941	509	Тверская область, Конаковский район, поселок Кошелево, Здание библиотеки	f	small
76631	1918	487	Тверская область, Конаковский район, поселок Козлово, Дм. Обушева, 16	f	large
76632	1919	488	Тверская область, Конаковский район, поселок Козлово, Дачный переулок, 6	f	large
124804	1897	463	Тверская область, Конаковский район, поселок Карачарово, ЗАО СОЦ Карачарово ДК	f	medium
76645	1937	505	Тверская область, Конаковский район, поселок Изоплит, Пионерская, 1а	f	large
124810	1940	508	Тверская область, Конаковский район, поселок Игуменка, Главный корпус пансионата Игуменка	f	small
124812	1942	510	Тверская область, Конаковский район, поселок Заполок, Административное здание	f	small
76637	1926	495	Тверская область, Конаковский район, поселок Завидово, Школьная, 1а	f	large
76633	1920	489	Тверская область, Конаковский район, поселок Дмитрова Гора, Центральная, 3б	f	large
76647	1939	507	Тверская область, Конаковский район, поселок Городня, Советская, 18	f	large
124808	1930	498	Тверская область, Конаковский район, поселок Гаврилково, Советская, 8	f	small
76636	1925	494	Тверская область, Конаковский район, поселок Вахонино, Большая, 59	f	large
76583	1873	433	Тверская область, Кимрский район, пос.Центральный, пр-д Абрамовский, 11	f	large
124800	1871	432	Тверская область, Кимрский район, поселок Федоровка, Центральная, 26	f	medium
124799	1870	431	Тверская область, Кимрский район, поселок Устиново, Солнечная, 4	f	small
124798	1869	430	Тверская область, Кимрский район, поселок Титово, Центральная, 2а	f	medium
124797	1868	429	Тверская область, Кимрский район, поселок Стоянцы, Школьная, 2	f	small
124787	1857	418	Тверская область, Кимрский район, поселок Радомино, 47	f	small
124796	1867	428	Тверская область, Кимрский район, поселок Приволжский, Заводская, 1	f	medium
124794	1865	426	Тверская область, Кимрский район, поселок Печетово, 31	f	small
124795	1866	427	Тверская область, Кимрский район, поселок Паскино, Володарского, 1	f	small
124793	1864	425	Тверская область, Кимрский район, поселок Неклюдово, 58а	f	small
124792	1863	424	Тверская область, Кимрский район, поселок Малое Василево, Советская, 3	f	medium
124790	1861	422	Тверская область, Кимрский район, поселок Кучино, Молодежная, 3	f	small
124791	1862	423	Тверская область, Кимрский район, поселок Красное, Лесная, 2	f	small
124788	1859	420	Тверская область, Кимрский район, поселок Кошкино, Школьная, 12	f	small
124789	1860	421	Тверская область, Кимрский район, поселок Ильинское, Центральная, 13	f	medium
76582	1858	419	Тверская область, Кимрский район, поселок Горицы, Садовый переулок, 5	f	large
76581	1856	417	Тверская область, Кимрский район, поселок Белый Городок, Заводская, 1	f	large
124786	1855	416	Тверская область, Кесовогорский район, поселок Фенево, здание администрации Феневского сельского поселения	f	small
124785	1854	415	Тверская область, Кесовогорский район, поселок Федцово, здание Федцовского Дома культуры	f	small
124774	1843	404	Тверская область, Кесовогорский район, поселок Стрелиха, здание МОУ Стрелихинская средняя общеобразовательная школа	f	small
124780	1849	410	Тверская область, Кесовогорский район, поселок Страхиново, здание Страхиновской сельской библиотеки	t	small
124778	1847	408	Тверская область, Кесовогорский район, поселок Петровское, здание Петровского филиала МОУ Кесовогорская СОШ	f	small
124784	1853	414	Тверская область, Кесовогорский район, поселок Никольское, здание МОУ Николо-Поточинская начальная общеобразов. школа	f	small
124775	1844	405	Тверская область, Кесовогорский район, поселок Никольское, здание Никольского сельского дома культуры	f	small
124783	1852	413	Тверская область, Кесовогорский район, поселок Матвеевское, здание Матвеевского филиала МОГУ Кесовогорская СОШ	f	small
124782	1851	412	Тверская область, Кесовогорский район, поселок Лисково, здание администрации Лисковского сельского поселения	f	medium
124777	1846	407	Тверская область, Кесовогорский район, поселок Кесова Гора, Советская, 15	f	small
76580	1840	401	Тверская область, Кесовогорский район, поселок Кесова Гора, Советская, 86	f	large
124772	1841	402	Тверская область, Кесовогорский район, поселок Кесова Гора, Ленинградская, 2	f	medium
76579	1839	400	Тверская область, Кесовогорский район, поселок Кесова Гора, Кооперативная, 14	f	large
124781	1850	411	Тверская область, Кесовогорский район, поселок Завидовская Горка, здание Завгорского детского сада	t	small
124779	1848	409	Тверская область, Кесовогорский район, поселок Елисеево, здание администрации Елисеевского сельского поселения	f	small
124776	1845	406	Тверская область, Кесовогорский район, поселок Горка-Ширятская, здание Горкоширятского филиала МОУ Кесовогорская СОШ	f	small
124773	1842	403	Тверская область, Кесовогорский район, поселок Борисовское, здание Борисовского Дома культуры	t	small
124769	1836	397	Тверская область, Кашинский район, поселок Шепели, 77	f	small
124768	1835	396	Тверская область, Кашинский район, поселок Филипищево, 25	f	small
124766	1833	394	Тверская область, Кашинский район, поселок Фарафоновка, 88	f	small
124764	1831	392	Тверская область, Кашинский район, поселок Уницы, Центральная, 4	t	medium
124748	1815	376	Тверская область, Кашинский район, поселок Тиволино, 44	f	small
124753	1820	381	Тверская область, Кашинский район, поселок Тетьково, Клуб ГУП Тетьково	f	medium
124763	1830	391	Тверская область, Кашинский район, поселок Спасское, 84	t	small
124762	1829	390	Тверская область, Кашинский район, поселок Славково, 8	f	small
124765	1832	393	Тверская область, Кашинский район, поселок Савцыно, 10	f	small
124761	1828	389	Тверская область, Кашинский район, поселок Путилово, 109	f	medium
124759	1826	387	Тверская область, Кашинский район, поселок Письяковка, 1	f	small
124757	1824	385	Тверская область, Кашинский район, поселок Пестриково, 41а	f	small
124760	1827	388	Тверская область, Кашинский район, поселок Никольское, 43	f	small
124755	1822	383	Тверская область, Кашинский район, поселок Лобково, 24	f	small
124751	1818	379	Тверская область, Кашинский район, поселок Леушино, 38	f	small
124749	1816	377	Тверская область, Кашинский район, поселок Коробово, Центральная, 12	f	small
124770	1837	398	Тверская область, Кашинский район, поселок Козьмодемьяновское, 73	f	small
124756	1823	384	Тверская область, Кашинский район, поселок Карабузино, 20	f	small
124771	1838	399	Тверская область, Кашинский район, поселок Данильцево, 67	f	small
124754	1821	382	Тверская область, Кашинский район, поселок Давыдово, 18	f	small
124752	1819	380	Тверская область, Кашинский район, поселок Верхняя Троица, Молодежная, 1	f	medium
124750	1817	378	Тверская область, Кашинский район, поселок Булатово, 94	f	medium
124758	1825	386	Тверская область, Кашинский район, поселок Бузыково, 23	f	small
124747	1814	375	Тверская область, Кашинский район, поселок Барыково, Слободка, 5	f	small
76508	1565	116	Тверская область, Весьегонский район, Весьегонск, Тихонова, 4	f	large
124733	1794	351	Тверская область, Калязинский район, поселок Яринское, Центральная, 33	f	small
124726	1787	344	Тверская область, Калязинский район, поселок Чигирево, Чигиревская, 46	f	small
124743	1804	361	Тверская область, Калязинский район, поселок Тимирязево, Молодежная, 10	t	small
124742	1803	360	Тверская область, Калязинский район, поселок Старобислово, Широкая, 14	t	small
124725	1786	343	Тверская область, Калязинский район, поселок Спасское, Центральная, 16	f	small
124736	1797	354	Тверская область, Калязинский район, поселок Семендяево, Речная, 27	f	small
124732	1793	350	Тверская область, Калязинский район, поселок Поречье, Школьная, 9	f	small
124741	1802	359	Тверская область, Калязинский район, поселок Плоховка, Школьная, 22	f	small
124740	1801	358	Тверская область, Калязинский район, поселок Пенье, Школьная, 1	f	small
76557	1759	314	Тверская область, Калязинский район, поселок Никольское, 13а	f	large
124731	1792	349	Тверская область, Калязинский район, поселок Нерль, Ленинская, 49	f	medium
124735	1796	353	Тверская область, Калязинский район, поселок Малахово, Новая, 4	f	small
124739	1800	357	Тверская область, Калязинский район, поселок Липовка, Центральная, 1	f	small
124730	1791	348	Тверская область, Калязинский район, поселок Крюково, 34	f	small
124729	1790	347	Тверская область, Калязинский район, поселок Капшино, Советская, 38	f	small
76568	94248	339	Тверская область, Калязинский район, Калязин	f	large
76565	1781	336	Тверская область, Калязинский район, Калязин, улица Коминтерна, 81	f	large
76564	1780	335	Тверская область, Калязинский район, Калязин, Тверская, 19	f	large
76566	1782	337	Тверская область, Калязинский район, Калязин, Студенческая, 27	f	large
76563	1779	334	Тверская область, Калязинский район, Калязин, Коминтерна, 101	f	large
76567	1554	338	Тверская область, Калязинский район, Калязин, К. Маркса, 22/20	f	large
124738	1799	356	Тверская область, Калязинский район, поселок Исаково, Школьная, 24	f	small
124724	1785	342	Тверская область, Калязинский район, поселок Дымово, Молодежная, 33	f	small
124728	1789	346	Тверская область, Калязинский район, поселок Воронцово, Центральная, 11	f	small
124723	1784	341	Тверская область, Калязинский район, поселок Василево, Советская, 23	f	small
124727	1788	345	Тверская область, Калязинский район, поселок Бителево, 44	t	small
124734	1795	352	Тверская область, Калязинский район, поселок Баринцево, Цветочная, 5	f	small
124737	1798	355	Тверская область, Калязинский район, поселок Апухтино, Центральная, 1	t	small
125164	2484	1129	Тверская область, Калязинский район, поселок Андрианово	f	small
124722	1783	340	Тверская область, Калязинский район, поселок Алферово, Центральная, 27	f	small
124720	1775	330	Тверская область, Калининский район, поселок Эммаус, Эммаусская школа-интернат, здание музея	f	medium
76560	1774	329	Тверская область, Калининский район, поселок Эммаус, 29, (малый зал)	f	large
76559	1773	328	Тверская область, Калининский район, поселок Эммаус, 29 (артистическая)	f	large
76558	1771	326	Тверская область, Калининский район, поселок Чуприяновка, 3-я Мира, здание ОАО Автотранс	f	large
124717	1769	324	Тверская область, Калининский район, поселок Черногубово, 28а	f	medium
124716	1768	323	Тверская область, Калининский район, поселок Черногубово, 22, санаторий Черногубово	f	small
124715	1767	322	Тверская область, Калининский район, поселок Черногубово, 15, госпиталь ИОВ	f	small
124713	1765	320	Тверская область, Калининский район, поселок Тургиново, Кирова, 22	f	medium
124721	1778	333	Тверская область, Калининский район, поселок Суховерково, проспект Калинина, 2	f	medium
124718	1770	325	Тверская область, Калининский район, поселок Старый Погост, 23б	f	small
124704	1753	308	Тверская область, Калининский район, поселок Старые Мермерины, Центральная, здание конторы ООО Меха	f	medium
124710	1762	317	Тверская область, Калининский район, поселок Славное, здание МОУ Славновская ООШ	f	medium
124694	1740	295	Тверская область, Калининский район, поселок Савино, Слободская, 58	f	small
124696	1743	298	Тверская область, Калининский район, поселок Савватьево, 33а	f	medium
76550	1736	291	Тверская область, Калининский район, поселок Рязаново, 21	f	large
124705	1754	309	Тверская область, Калининский район, поселок Романово, 71, кафе РАЙПО	f	small
83893	57330	3086	Москва, Зеленоград, к163	f	large
76552	1742	297	Тверская область, Калининский район, поселок Рождествено, Советская, 61	f	large
124691	1735	290	Тверская область, Калининский район, поселок Пушкино, 65, здание дома культуры	f	small
124690	1734	289	Тверская область, Калининский район, поселок Полубратово, Беговая, 11	f	small
124689	1733	288	Тверская область, Калининский район, поселок Петровское, Егорова, 15а	f	small
124698	1746	301	Тверская область, Калининский район, поселок Первомайские Горки, Береговая, 4а	f	small
76562	1777	332	Тверская область, Калининский район, поселок Орша, Привокзальная, 7	f	large
76556	1758	313	Тверская область, Калининский район, поселок Никулино, Школьная, 3	f	large
124688	1732	287	Тверская область, Калининский район, поселок Нестерово, Молодежная, 11	f	small
124697	1745	300	Тверская область, Калининский район, поселок Мухино, здание Мухинская сельская библиотека	f	small
76555	1756	311	Тверская область, Калининский район, поселок Михайловское, Центральная, 44ж	f	large
124687	1731	286	Тверская область, Калининский район, поселок Митенево, Центральная, 16	f	small
124703	1752	307	Тверская область, Калининский район, поселок Медное, Тверская, 7	f	medium
76554	1751	306	Тверская область, Калининский район, поселок Медное, Советская, 126	f	large
124702	1750	305	Тверская область, Калининский район, поселок Кумордино, Школьная, 5	f	medium
76553	1744	299	Тверская область, Калининский район, поселок Кулицкая, Титова, 1а	f	large
124719	1772	327	Тверская область, Калининский район, поселок Кузьминское, 1а	f	small
124699	1747	302	Тверская область, Калининский район, поселок Красная Гора, Зеленая, 10	f	medium
124700	1748	303	Тверская область, Калининский район, поселок Колталово, Зеленая, 12	f	medium
76549	1730	285	Тверская область, Калининский район, поселок Квакшино, 54, здание МУКДЦ Квакшинский	f	large
124695	1741	296	Тверская область, Калининский район, поселок Каблуково, Школьная, 8а	f	medium
124686	1729	284	Тверская область, Калининский район, поселок Ильинское, 14, здание адм. Бурашевского с/п	f	medium
124706	1755	310	Тверская область, Калининский район, поселок Загородный, 20, Загородный д/сад	f	medium
76551	1738	293	Тверская область, Калининский район, поселок Заволжский, 7	f	large
124685	1728	283	Тверская область, Калининский район, поселок Езвино, 26, здание адм. Бурашевского с/п	f	small
124714	1766	321	Тверская область, Калининский район, поселок Дубровки, 47	f	small
124701	1749	304	Тверская область, Калининский район, поселок Дмитровское, 119	f	small
124693	1739	294	Тверская область, Калининский район, поселок Дмитрово-Черкасский, Заводская, 26а	f	medium
124707	1757	312	Тверская область, Калининский район, поселок Даниловское, 64в	f	medium
124709	1761	316	Тверская область, Калининский район, поселок Восток, здание МОУ Оршинская ООШ	f	small
124673	1713	268	Тверская область, Калининский район, поселок Вахново, Здание библиотеки	f	small
76561	1776	331	Тверская область, Калининский район, поселок Васильевский Мох, Парковая, 19/8	f	large
124682	1725	280	Тверская область, Калининский район, поселок Бурашево, здание администрации (зд. конт) ГУЗ ОКПБ №1 им. М.П.Литвинова	f	small
76548	1724	279	Тверская область, Калининский район, поселок Бурашево, здание администрации (акт. зал) ГУЗ ОКПБ №1 им М.П. Литвинова	f	large
124711	1763	318	Тверская область, Калининский район, поселок Большие Горки, 31а	f	small
124692	1737	292	Тверская область, Калининский район, поселок Большие Борки, переулок Административный, 1а	f	medium
124684	1727	282	Тверская область, Калининский район, поселок Березино, Центральная, 8	f	medium
124708	1760	315	Тверская область, Калининский район, поселок Беле-Кушальское, 29	f	small
124683	1726	281	Тверская область, Калининский район, деревня Андрейково, 1д	f	medium
124668	1708	263	Тверская область, Зубцовский район, Щеколдино, Здание Дома культуры	f	small
124659	1696	251	Тверская область, Зубцовский район, поселок Ульяново, Здание администрации Ульяновского сельского поселения	f	small
124656	1693	248	Тверская область, Зубцовский район, поселок Столипино, Здание администрации Столипинского сельского поселения	f	small
124658	1695	250	Тверская область, Зубцовский район, поселок Старые Горки, Здание администрации Старогорского тер. подразделения	f	small
76333	92662	758	Тамбовская область, Тамбов, Рылеева, 84	f	large
124677	1717	272	Тверская область, Зубцовский район, поселок Старое Устиново, Здание Дома культуры	f	small
124674	1714	269	Тверская область, Зубцовский район, Старое, Здание правления СХПК Колос	f	small
124657	1694	249	Тверская область, Зубцовский район, поселок Салино, Здание администрации Салинского тер. подразделения	f	small
124671	1711	266	Тверская область, Зубцовский район, поселок Рыльцово, Здание школы	f	small
124675	1715	270	Тверская область, Зубцовский район, поселок Раково, Здание администрации Раковского тер. подразделения	f	small
76546	1719	274	Тверская область, Зубцовский район, Погорелое-Городище, Здание Дома культуры	f	large
124655	1692	247	Тверская область, Зубцовский район, поселок Ошурково, Здание администрации Ошурковского тер. подразделения	f	small
124676	1716	271	Тверская область, Зубцовский район, поселок Орловка, Здание правления СХПК Орловка	f	small
124678	1718	273	Тверская область, Зубцовский район, поселок Новое, Здание правления СХПК Рассвет	f	small
124670	1710	265	Тверская область, Зубцовский район, поселок Никольское, Здание администрации Никольского тер. подразделения	f	small
124681	1722	277	Тверская область, Зубцовский район, поселок Николо-Пустынь, Здание администрации Николо-Пустыньского тер. подразделения	f	small
124680	1721	276	Тверская область, Зубцовский район, поселок Мерейкино, Здание администрации Благининского тер. подразделения	f	small
124669	1709	264	Тверская область, Зубцовский район, поселок Малое Коробино, Здание детского сада	f	small
124679	1720	275	Тверская область, Зубцовский район, поселок Княжьи Горы, Здание администрации Княжьегорского сельского правления	f	medium
124672	1712	267	Тверская область, Зубцовский район, Карамзино, Здание администрации Карамзинского тер. подразделения	f	small
124667	1707	262	Тверская область, Зубцовский район, поселок Игнатово, Здание Дома культуры	f	small
124665	1705	260	Тверская область, Зубцовский район, поселок Зуево, Здание администрации Зуевского тер. подразделения	f	medium
76545	1700	255	Тверская область, Зубцовский район, Зубцов, Советская, 24	f	large
76543	1698	253	Тверская область, Зубцовский район, Зубцов, Советская, 1а	f	large
76544	1699	254	Тверская область, Зубцовский район, Зубцов, Ржевская, 44	f	large
124662	1702	257	Тверская область, Зубцовский район, Зубцов, Октябрьская, 2	f	medium
124661	1701	256	Тверская область, Зубцовский район, Зубцов, Декабристов, 27	f	medium
124654	1691	246	Тверская область, Зубцовский район, поселок Дорожаево, Здание администрации Дорожаевского сельского поселения	f	small
124663	1703	258	Тверская область, Зубцовский район, поселок Брычево, Здание администрации Брычевского тер. подразделения	f	small
124664	1704	259	Тверская область, Зубцовский район, поселок Борки, Здание администрации Борковского тер. подразделения	f	small
124666	1706	261	Тверская область, Зубцовский район, Большое Пищалино, Здание администрации Пищалинского тер. подразделения	f	small
124660	1697	252	Тверская область, Зубцовский район, поселок Белавино, Здание администрации Белавинского тер. подразделения	f	small
124651	1688	243	Тверская область, Западнодвинский район, поселок Шарапово, Здание Шараповского офиса врача общей практики	t	small
124641	1677	233	Тверская область, Западнодвинский район, Фофаново, Здание Фофановского сельского дома культуры	f	small
124636	1672	228	Тверская область, Западнодвинский район, поселок Улин, Здание сельского дома культуры	f	small
76542	1669	225	Тверская область, Западнодвинский район, поселок Старая Торопа, Кирова, 16	f	large
124650	1687	242	Тверская область, Западнодвинский район, поселок Селяны, Здание МОУ Селянская НОШ	t	small
124652	1689	244	Тверская область, Западнодвинский район, поселок Севостьяново, Здание Севостьяновского сельского дома культуры	t	small
124648	1685	240	Тверская область, Западнодвинский район, поселок Пятиусово, Здание МОУ Пятиусовская НОШ	f	small
124635	1671	227	Тверская область, Западнодвинский район, поселок Первомайский, Здание МОУ Первомайская общеобразовательная школа	f	small
124647	1683	239	Тверская область, Западнодвинский район, поселок Макеево, Здание МОУ Макеевская ООШ	f	small
124643	1679	235	Тверская область, Западнодвинский район, поселок Козино, Здание конторы СПК Западный	t	small
124642	1678	234	Тверская область, Западнодвинский район, поселок Ильино, Здание администрации Ильинского сельского поселения	f	medium
76541	1666	222	Тверская область, Западнодвинский район, Западная Двина, Школьная, 41	f	large
124630	1664	219	Тверская область, Западнодвинский район, Западная Двина, Первомайская, 3	f	medium
124629	1664	218	Тверская область, Западнодвинский район, Западная Двина, Первомайская, 3	f	medium
76539	1663	217	Тверская область, Западнодвинский район, Западная Двина, Молодежная, 38	f	large
124632	1667	223	Тверская область, Западнодвинский район, Западная Двина, Мира, Здание Западнодвинский агрострой	f	medium
124633	1668	224	Тверская область, Западнодвинский район, Западная Двина, Льнозаводская, Здание ООО Веста-СП	f	medium
124631	1665	221	Тверская область, Западнодвинский район, Западная Двина, Кирова, 16	f	medium
76540	1665	220	Тверская область, Западнодвинский район, Западная Двина, Кирова, 16	f	large
124639	1675	231	Тверская область, Западнодвинский район, поселок Дуброво, Здание Дубровской сельской библиотеки	f	small
124645	1681	237	Тверская область, Западнодвинский район, поселок Глазомичи, Здание Глазомичской сельской библиотеки	t	small
124637	1673	229	Тверская область, Западнодвинский район, поселок Велеса, Здание МОУ Велесовской начальной школы	f	small
124646	1682	238	Тверская область, Западнодвинский район, поселок Васьково, Здание Васьковской сельской библиотеки	t	small
124638	1674	230	Тверская область, Западнодвинский район, поселок Бибирево, Здание Бибиревского сельского дома культуры	f	small
124634	1670	226	Тверская область, Западнодвинский район, поселок Бенцы, Здание сельского дома культуры	f	small
124640	1676	232	Тверская область, Западнодвинский район, поселок Баево, Здание столовой Баевской школы	f	small
124649	1686	241	Тверская область, Западнодвинский район, поселок Антоново, Здание МОУ Антоновская НОШ	f	small
124644	1680	236	Тверская область, Западнодвинский район, поселок Аксентьево, Здание Аксентьевского сельского дома культуры	t	small
124628	1662	216	Тверская область, Жарковский район, поселок Щучье, Здание администрации Щучейского сельского поселения	f	small
124626	1660	214	Тверская область, Жарковский район, поселок Троицкое, Здание администрации Троицкого сельского поселения	f	small
124624	1658	212	Тверская область, Жарковский район, поселок Полоска, Сельский Дом культуры	f	small
124620	1654	208	Тверская область, Жарковский район, поселок Новоселки, Здание администрации Новоселковского сельского поселения	f	small
124622	1656	210	Тверская область, Жарковский район, поселок Кривая Лука, Сельский клуб	f	small
124617	1651	205	Тверская область, Жарковский район, поселок Кривая, Октябрьская, Клуб	f	small
124623	1657	211	Тверская область, Жарковский район, поселок Королевщина, Здание администрации Сычевского сельского поселения	f	small
124619	1653	207	Тверская область, Жарковский район, поселок Кащенки, Сельский клуб	f	small
124618	1652	206	Тверская область, Жарковский район, поселок Зеленьково, Здание администрации Жарковского сельского поселения	f	small
124616	1650	204	Тверская область, Жарковский район, поселок Жарковский, Октябрьский, 1	f	medium
76538	1649	203	Тверская область, Жарковский район, поселок Жарковский, Советская, 55	f	large
76537	1648	202	Тверская область, Жарковский район, поселок Жарковский, Советская, 37	f	large
124621	1655	209	Тверская область, Жарковский район, поселок Дубоцкое, Сельский Дом культуры	f	small
124627	1661	215	Тверская область, Жарковский район, поселок Гороватка, Здание администрации Щучейского сельского поселения	f	small
124625	1659	213	Тверская область, Жарковский район, поселок Вороны, Сельский Дом культуры	f	small
124588	770	149	Тверская область, Вышневолоцкий район, дер.Заречье, 61А	f	small
124603	1615	166	Тверская область, Вышневолоцкий район, поселок Трудовой, 19	f	small
124601	1613	164	Тверская область, Вышневолоцкий район, поселок Терелесовский, Рабочая, 7	f	medium
124600	1612	163	Тверская область, Вышневолоцкий район, поселок Старое, 82	f	small
124599	1610	161	Тверская область, Вышневолоцкий район, поселок Сороки, Бежецкая, 21	f	small
124597	1608	159	Тверская область, Вышневолоцкий район, поселок Солнечный, Центральная, 12	f	small
83892	57330	3085	Москва, Зеленоград, к163	f	large
76512	1607	158	Тверская область, Вышневолоцкий район, поселок Солнечный, Центральная, 9	f	large
124596	1606	157	Тверская область, Вышневолоцкий район, поселок Садовый, Центральная, 53	f	medium
124598	1609	160	Тверская область, Вышневолоцкий район, поселок Подол, 19А	f	small
124579	1589	139	Тверская область, Вышневолоцкий район, поселок Осечно, Почтовая, 29	f	small
124602	1614	165	Тверская область, Вышневолоцкий район, поселок Осеченка, Карла Маркса, 15	f	small
124594	1604	155	Тверская область, Вышневолоцкий район, поселок Овсище, Заводская, 2	f	small
124591	1601	152	Тверская область, Вышневолоцкий район, поселок Лужниково, Солнечная, 8	f	small
124595	1605	156	Тверская область, Вышневолоцкий район, поселок Кузнецово, 75	f	small
76517	1619	170	Тверская область, Вышневолоцкий район, поселок Красномайский, Кирова, 33	f	large
76516	1618	169	Тверская область, Вышневолоцкий район, поселок Красномайский, Боровая, 1А	f	large
76515	1617	168	Тверская область, Вышневолоцкий район, поселок Красномайский, 1 Мая, 2	f	large
124592	1602	153	Тверская область, Вышневолоцкий район, поселок Красная Заря, Школьная , 4А	f	small
124586	1597	147	Тверская область, Вышневолоцкий район, поселок Коломно, 112А	f	small
124583	1594	144	Тверская область, Вышневолоцкий район, поселок Княщины, 13	f	small
124584	1595	145	Тверская область, Вышневолоцкий район, поселок Ильинское, 35А	f	small
76511	1593	143	Тверская область, Вышневолоцкий район, поселок Зеленогорский, Микробиологов, 31	f	large
124593	1603	154	Тверская область, Вышневолоцкий район, поселок Жилотково, 10Б	f	small
124581	1591	141	Тверская область, Вышневолоцкий район, поселок Есеновичи, Первомайская, 2	f	medium
124580	1590	140	Тверская область, Вышневолоцкий район, поселок Дятлово, Школьная, 3	f	small
124590	1600	151	Тверская область, Вышневолоцкий район, поселок Дорки, Некрасовский переулок, 1Б	f	small
124578	1588	138	Тверская область, Вышневолоцкий район, поселок Горняк, Центральная, 6А	f	medium
124582	1592	142	Тверская область, Вышневолоцкий район, поселок Бухолово, Советская, 8	f	small
124585	1596	146	Тверская область, Вышневолоцкий район, поселок Боровно, 78	f	small
124576	1586	136	Тверская область, Вышневолоцкий район, поселок Борисовский, Октябрьская, 17А	f	medium
124589	1599	150	Тверская область, Вышневолоцкий район, поселок Бельский, Фабричная, 6А	f	small
124577	1587	137	Тверская область, Вышневолоцкий район, поселок Белый Омут, Советская, 10	f	small
76514	1616	167	Тверская область, Вышневолоцкий район, поселок Афимьино, Мира, 8	f	large
124587	1598	148	Тверская область, Вышневолоцкий район, поселок Академический, Октябрьская, 19А	f	medium
124573	1583	133	Тверская область, Весьегонский район, поселок Чистая Дуброва, Здание Дома культуры	f	small
124574	1584	134	Тверская область, Весьегонский район, поселок Чамерово, Здание средней школы	f	small
124565	1575	125	Тверская область, Весьегонский район, поселок Тимошкино, Здание библиотеки	f	small
124575	1585	135	Тверская область, Весьегонский район, поселок Телятово, Здание медпункта	f	small
124570	1580	130	Тверская область, Весьегонский район, поселок Столбищи, Здание Дома культуры	f	small
124571	1581	131	Тверская область, Весьегонский район, поселок Романовское, Здание администрации Романовского сельского поселения	f	small
124569	1579	129	Тверская область, Весьегонский район, поселок Пронино, Здание администрации Пронинского сельского поселения	f	small
124567	1577	127	Тверская область, Весьегонский район, поселок Любегощи, Здание администрации Любегощинского сельского поселения	f	small
124566	1576	126	Тверская область, Весьегонский район, поселок Кесьма, Здание администрации Кесемского сельского поселения	f	medium
124562	1572	122	Тверская область, Весьегонский район, поселок Иваново, Здание администрации Ивановского сельского поселения	f	medium
124560	1569	120	Тверская область, Весьегонский район, поселок Егна, здание администрации Егонского сельского поселения	f	small
124572	1582	132	Тверская область, Весьегонский район, поселок Дюдиково, Здание Дома культуры	f	small
124559	1568	119	Тверская область, Весьегонский район, поселок Гора, Здание медпункта	f	small
76510	1567	118	Тверская область, Весьегонский район, Весьегонск, Южная, 24А	f	large
76331	92661	756	Тамбовская область, Тамбов, Рылеева, 77	f	large
76509	1566	117	Тверская область, Весьегонский район, Весьегонск, Панфилова, 17	f	large
124561	1571	121	Тверская область, Весьегонский район, поселок Большое Овсянниково, здание Большеовсянниковской средней школы	f	small
124563	1573	123	Тверская область, Весьегонский район, поселок Бараново, Здание администрации Ивановского сельского поселения	f	small
124568	1578	128	Тверская область, Весьегонский район, поселок Алферово, Здание библиотеки	f	small
76501	86	87	Тверская область, Бологое городской округ, Бологое, м/р-н Заозерный, 1	f	large
124552	1558	109	Тверская область, Бологовский район, поселок Хотилово, Центральная, 121	f	small
124549	1555	106	Тверская область, Бологовский район, поселок Тимково, Центральная, 55	f	small
124550	1556	107	Тверская область, Бологовский район, поселок Тимково, Озерная, 16	f	small
124542	1547	98	Тверская область, Бологовский район, поселок Михайловское, Дом культуры ЛИУ-З	t	small
124540	1545	96	Тверская область, Бологовский район, поселок Лыкошино, Первомайская, 9	f	medium
124544	1550	101	Тверская область, Бологовский район, поселок Куженкино, Советская, 1	f	small
124553	1559	110	Тверская область, Бологовский район, поселок Куженкино, Полевая, 13	f	small
124541	1546	97	Тверская область, Бологовский район, поселок Корыхново, Советская, 7	f	medium
124548	527	105	Тверская область, Бологовский район, поселок Кемцы, Центральная, 22	f	small
124551	1557	108	Тверская область, Бологовский район, поселок Кафтино, Ленина, 34	f	small
124543	1549	100	Тверская область, Бологовский район, поселок Ильятино, Зеленая, 6	f	small
124554	1560	111	Тверская область, Бологовский район, поселок Заборки, Лесная, 2а	f	small
124539	1544	95	Тверская область, Бологовский район, поселок Гузятино, Новая, 2	f	small
76507	1548	99	Тверская область, Бологовский район, поселок Выползово, Октябрьская, 60а	f	large
124555	1561	112	Тверская область, Бологовский район, Бологое, База отдыха Озерный	t	small
76500	94179	86	Тверская область, Бологовский район, Бологое, Школьный переулок, 9	f	large
76504	1540	91	Тверская область, Бологовский район, Бологое, Студенческая, учебный корпус аграрного колледжа	f	large
76503	214	89	Тверская область, Бологовский район, Бологое, Олега Кошевого, 1а	f	large
124538	1541	92	Тверская область, Бологовский район, Бологое, Народная, 12	f	medium
76499	1539	85	Тверская область, Бологовский район, Бологое, Мира, 28а	f	large
124557	1563	114	Тверская область, Бологовский район, Бологое, Линейная, 9	f	small
124536	1536	82	Тверская область, Бологовский район, Бологое, Кирова, 35	f	medium
76495	1534	80	Тверская область, Бологовский район, Бологое, Кирова, 39	f	large
124535	1533	79	Тверская область, Бологовский район, Бологое, Кирова, 18а	f	medium
76502	123	88	Тверская область, Бологовский район, Бологое, Заозерный м/р-н, 9	f	large
76496	1535	81	Тверская область, Бологовский район, Бологое, Заводской микрорайон, 10	f	large
76497	1537	83	Тверская область, Бологовский район, Бологое, Дзержинского, 11	f	large
124537	274	90	Тверская область, Бологовский район, Бологое, Главная, 10	t	medium
76498	1538	84	Тверская область, Бологовский район, Бологое, Гагарина, 5	f	large
124990	2169	744	Тверская область, Бологовский район, поселок Березовский Рядок, помещение администрации Залучьенского сельского поселения	f	small
124547	1553	104	Тверская область, Бологовский район, поселок Березовский Рядок, Новая, 1а	f	small
76505	1542	93	Тверская область, Бологовский район, поселок Березайка, Победы, 30	f	large
76506	1543	94	Тверская область, Бологовский район, поселок Березайка, Крестьянская, 8	f	large
124532	1530	76	Тверская область, Бельский район, поселок Шайтровщина, Центральная, 36	f	small
124528	1526	72	Тверская область, Бельский район, поселок Чичата, Школьная, 1	t	small
124534	1532	78	Тверская область, Бельский район, поселок Нестерово, Зеленая, 5	f	small
124531	1529	75	Тверская область, Бельский район, поселок Комары, Советская, 32	f	small
124530	1528	74	Тверская область, Бельский район, поселок Кавельщино, Центральная, 76	f	small
124527	1525	71	Тверская область, Бельский район, поселок Демяхи, Центральная, 33	f	small
124526	1524	70	Тверская область, Бельский район, поселок Грибаново, Зеленая, 4	f	small
124525	1523	69	Тверская область, Бельский район, поселок Верховье, Центральная, 8	t	small
124529	1527	73	Тверская область, Бельский район, поселок Будино, Школьная, 4	f	small
76493	1521	67	Тверская область, Бельский район, Белый, Ленина, 21	f	large
76494	1522	68	Тверская область, Бельский район, Белый, Кирова, 47	f	large
124533	1531	77	Тверская область, Бельский район, Белый, 1 Мая, 3	f	small
124516	1512	58	Тверская область, Бежецкий район, поселок Шульгино, Центральная, 11	f	small
124524	1520	66	Тверская область, Бежецкий район, Шишкова-Дубрава, 12	f	small
124520	1516	62	Тверская область, Бежецкий район, поселок Хозницы, 37	f	small
124522	1518	64	Тверская область, Бежецкий район, поселок Фралево, 95	f	medium
124521	1517	63	Тверская область, Бежецкий район, Филиппково, Большая, 44	f	medium
124513	1509	55	Тверская область, Бежецкий район, поселок Сырцевка, Косарева, 15	f	small
124519	1515	61	Тверская область, Бежецкий район, поселок Сукромны, 151	f	small
124523	1519	65	Тверская область, Бежецкий район, поселок Потесы, Молодежная, 7	f	small
124517	1513	59	Тверская область, Бежецкий район, Поречье, 120	f	small
124509	916	51	Тверская область, Бежецкий район, поселок Подобино, Центральная, 6	f	small
124518	1514	60	Тверская область, Бежецкий район, поселок Плотники, Челябинская, 19	f	small
124505	93821	47	Тверская область, Бежецкий район, поселок Морозово, 61	f	small
124515	1511	57	Тверская область, Бежецкий район, поселок Моркины Горы, Восточная, 6	f	small
124514	1510	56	Тверская область, Бежецкий район, поселок Михайлова Гора, 18	f	small
124512	1508	54	Тверская область, Бежецкий район, поселок Лаптиха, Молодежная, 3В	f	small
124511	1493	53	Тверская область, Бежецкий район, поселок Зобы, Солнечная, 3	f	medium
124510	1013	52	Тверская область, Бежецкий район, поселок Житищи, Школьная, 3	f	medium
124506	93932	48	Тверская область, Бежецкий район, поселок Градницы, 32	f	small
124508	754	50	Тверская область, Бежецкий район, поселок Городищи, Центральная, 6	f	medium
124507	721	49	Тверская область, Бежецкий район, поселок Васюково, Центральная, 50	f	medium
124504	93793	46	Тверская область, Бежецкий район, поселок Борок-Сулежский, 34	f	small
124500	1500	30	Тверская область, Андреапольский район, поселок Хотилицы, помещение сельского Дома культуры	f	small
124497	1497	27	Тверская область, Андреапольский район, поселок Торопаца, помещение администрации Торопацкого сельского поселения	f	small
124496	1496	26	Тверская область, Андреапольский район, поселок Студеница, помещение администрации Торопацкого сельского поселения	f	small
124499	1499	29	Тверская область, Андреапольский район, поселок Спиридово, помещение конторы СПК им.Кирова	f	small
124489	1488	19	Тверская область, Андреапольский район, поселок Рогово, помещение Дома культуры КФХ Андреапольское	f	medium
124483	1482	13	Тверская область, Андреапольский район, поселок Мякишево, контора колхоза К Новой жизни	t	small
124493	1492	23	Тверская область, Андреапольский район, поселок Любино, помещение администрации Волокского сельского поселения	f	small
124495	1495	25	Тверская область, Андреапольский район, поселок Луги, помещение администрации Луговского сельского поселения	f	small
124484	1483	14	Тверская область, Андреапольский район, поселок Крючково, здание СПК Колос	t	small
124486	1485	16	Тверская область, Андреапольский район, поселок Костюшино, штаб ФГУ ЛИУ №8 УФСИН МЮ РФ по Тверской области	t	small
124485	1484	15	Тверская область, Андреапольский район, поселок Козлово, помещение сельского Дома культуры	f	small
124494	1494	24	Тверская область, Андреапольский район, поселок Горка, помещение администрации Луговского сельского поселения	f	small
124492	1491	22	Тверская область, Андреапольский район, поселок Горицы, помещение Горицкого сельского филиала Андреапольской ЦБС	f	small
124498	1498	28	Тверская область, Андреапольский район, поселок Воскресенское, помещение Воскресенского филиала Андреапольской ЦБС	f	small
124491	1490	21	Тверская область, Андреапольский район, поселок Волок, помещение администрации Волокского сельского поселения	f	small
124490	1489	20	Тверская область, Андреапольский район, поселок Бологово, помещение администрации Бологовского сельского поселения	f	medium
124488	1487	18	Тверская область, Андреапольский район, поселок Бобровец, помещение сельского клуба	f	small
124472	1476	2	Тверская область, Андреапольский район, Андреаполь, Парковая, 2	f	medium
124471	1475	1	Тверская область, Андреапольский район, Андреаполь, Парковая, 11	f	medium
124480	93259	10	Тверская область, Андреапольский район, Андреаполь, Октябрьская, 20	f	medium
124481	93302	11	Тверская область, Андреапольский район, Андреаполь, Новгородская, 13	f	medium
124479	93166	9	Тверская область, Андреапольский район, Андреаполь, Кленовая, помещение ЦСРНД	f	medium
124478	93126	8	Тверская область, Андреапольский район, Андреаполь, Авиаторов, 54	f	medium
124477	93126	7	Тверская область, Андреапольский район, Андреаполь, Авиаторов, 54	f	medium
124476	1479	6	Тверская область, Андреапольский район, Андреаполь, 8 Марта, 37	f	medium
124475	1479	5	Тверская область, Андреапольский район, Андреаполь, 8 Марта, 37	f	medium
124487	1486	17	Тверская область, Андреапольский район, Андреаполь, 50 лет Октября, 9	f	small
124474	1478	4	Тверская область, Андреапольский район, Андреаполь, 50 лет Октября, 9	f	small
124473	1477	3	Тверская область, Андреапольский район, Андреаполь, 1-ый Измайловский переулок, 1А	f	small
124482	1481	12	Тверская область, Андреапольский район, Аксеново, администрация сельского поселения	t	small
76405	92809	924	Тамбовская область, Уварово, Южная, 40а	f	large
76311	92644	727	Тамбовская область, Тамбов, площадь Комсомольская, 5	f	large
76303	92635	717	Тамбовская область, Тамбов, пл.Л.Толстого, 4а	f	large
76302	92635	716	Тамбовская область, Тамбов, пл.Л.Толстого, 4а	f	large
124356	92615	689	Тамбовская область, Тамбов, им. маршала Малиновского, 12	f	small
76328	92659	753	Тамбовская область, Тамбов, бульвар Энтузиастов, 2	f	large
76432	92672	777	Тамбовская область, Тамбов, Южная, 116	f	large
76315	92648	731	Тамбовская область, Тамбов, Широкая, 8	f	large
76308	92641	724	Тамбовская область, Тамбов, Чичканова, 125	f	large
76335	92663	762	Тамбовская область, Тамбов, Чичерина, 30а	f	large
76334	92663	761	Тамбовская область, Тамбов, Чичерина, 30а	f	large
76429	92663	763	Тамбовская область, Тамбов, Чичерина, 30а	f	large
76428	92663	760	Тамбовская область, Тамбов, Чичерина, 30а	f	large
76427	92663	759	Тамбовская область, Тамбов, Чичерина, 30а	f	large
76336	92664	764	Тамбовская область, Тамбов, Цветочная/М.Н.Мордасовой, 6/20	f	large
76468	92623	700	Тамбовская область, Тамбов, Фридриха Энгельса, 73	f	large
76362	92687	800	Тамбовская область, Тамбов, Ударная, 2	f	large
76361	92687	799	Тамбовская область, Тамбов, Ударная, 2	f	large
76300	92631	710	Тамбовская область, Тамбов, Студенецкая набережная, 23	f	large
76299	92630	709	Тамбовская область, Тамбов, Степана Разина, 7	f	large
76327	92658	752	Тамбовская область, Тамбов, Социалистическая, 5	f	large
76330	92658	755	Тамбовская область, Тамбов, Социалистическая, 5	f	large
124105	92291	364	Тамбовская область, Тамбов, Солнечная, 16/48	f	medium
76377	92707	821	Тамбовская область, Тамбов, Совхозная, 166А	f	large
76314	92647	730	Тамбовская область, Тамбовский район, Тамбов, Советская, 193	f	large
76417	92638	721	Тамбовская область, Тамбов, Советская, 159	f	large
76297	92628	706	Тамбовская область, Тамбов, Советская, 89	f	large
76296	92627	705	Тамбовская область, Тамбов, Советская, 110	f	large
76294	92625	703	Тамбовская область, Тамбов, Советская, 93	f	large
76288	92618	694	Тамбовская область, Тамбов, Советская, 6	f	large
76287	92618	693	Тамбовская область, Тамбов, Советская, 6	f	large
76431	92667	772	Тамбовская область, Тамбов, Серпуховская, 15	f	large
76430	92667	770	Тамбовская область, Тамбов, Серпуховская, 15	f	large
76346	92671	776	Тамбовская область, Тамбов, Сергея Лазо, 18	f	large
76345	92671	775	Тамбовская область, Тамбов, Сергея Лазо, 18	f	large
76414	92624	702	Тамбовская область, Тамбов, Сергеева-Ценского, 4	f	large
76469	92624	701	Тамбовская область, Тамбов, Сергеева-Ценского, 4	f	large
76340	92665	768	Тамбовская область, Тамбов, Сенько, 10	f	large
76339	92665	767	Тамбовская область, Тамбов, Сенько, 10	f	large
76338	92665	766	Тамбовская область, Тамбов, Сенько, 10	f	large
76337	92665	765	Тамбовская область, Тамбов, Сенько, 10	f	large
76289	92619	695	Тамбовская область, Тамбов, Самарская, 9	f	large
76325	92656	750	Тамбовская область, Тамбовский район, Тамбов, Рылеева, 52	f	large
76324	92656	749	Тамбовская область, Тамбовский район, Тамбов, Рылеева, 52	f	large
76332	92662	757	Тамбовская область, Тамбов, Рылеева, 84	f	large
76326	92657	751	Тамбовская область, Тамбов, Рылеева, 67	f	large
76312	92645	728	Тамбовская область, Тамбов, Пролетарская, 252/2	f	large
76310	92643	726	Тамбовская область, Тамбов, Проезд Энергетиков, 7	f	large
76360	92686	798	Тамбовская область, Тамбов, Полынковская, 47	f	large
76359	92686	797	Тамбовская область, Тамбов, Полынковская, 47	f	large
76358	92686	796	Тамбовская область, Тамбов, Полынковская, 47	f	large
76286	92617	692	Тамбовская область, Тамбов, Пионерская, 11	f	large
76344	92670	774	Тамбовская область, Тамбов, Петропавловская, 3	f	large
76301	92634	715	Тамбовская область, Тамбов, Пензенская, 62	f	large
76416	92634	714	Тамбовская область, Тамбов, Пензенская, 62	f	large
76341	92666	769	Тамбовская область, Тамбов, Ново-рубежный переулок, 28	f	large
76354	92682	791	Тамбовская область, Тамбов, Новикова-Прибоя, 53 корп. 1	f	large
76353	92680	789	Тамбовская область, Тамбов, Нагорная, 14	f	large
76352	92680	788	Тамбовская область, Тамбов, Нагорная, 14	f	large
76426	92655	747	Тамбовская область, Тамбов, Н.Вирты, 120	f	large
76425	92655	746	Тамбовская область, Тамбов, Н.Вирты, 120	f	large
76424	92655	745	Тамбовская область, Тамбов, Н.Вирты, 120	f	large
76322	92654	742	Тамбовская область, Тамбов, Н.Вирты, 96	f	large
76423	92654	744	Тамбовская область, Тамбов, Н.Вирты, 96	f	large
76422	92654	743	Тамбовская область, Тамбов, Н.Вирты, 96	f	large
76415	92632	711	Тамбовская область, Тамбов, Московская, 23а	f	large
76298	92629	708	Тамбовская область, Тамбов, Московская, 46	f	large
76309	92642	725	Тамбовская область, Тамбов, Моршанское шоссе, 17	f	large
76421	92653	741	Тамбовская область, Тамбов, Мичуринская, 112б	f	large
76420	92653	740	Тамбовская область, Тамбов, Мичуринская, 112б	f	large
76419	92653	739	Тамбовская область, Тамбов, Мичуринская, 112б	f	large
124358	92652	737	Тамбовская область, Тамбов, Мичуринская, 129	f	medium
76321	92652	738	Тамбовская область, Тамбов, Мичуринская, 129	f	large
76319	92651	735	Тамбовская область, Тамбов, Мичуринская, 110	f	large
76317	92649	733	Тамбовская область, Тамбов, Мичуринская, 93	f	large
76316	92649	732	Тамбовская область, Тамбов, Мичуринская, 93	f	large
76242	92342	415	Тамбовская область, Тамбов, Мира, 41в	f	large
76343	92669	773	Тамбовская область, Тамбов, Мастерских, 1	f	large
76355	92683	792	Тамбовская область, Тамбов, Майская, 35	f	large
76363	92688	801	Тамбовская область, Тамбов, Лесная, 25	f	large
76292	92621	698	Тамбовская область, Тамбов, Лермонтовская, 1А	f	large
76306	92637	720	Тамбовская область, Тамбов, Куйбышева, 1	f	large
76305	92637	719	Тамбовская область, Тамбов, Куйбышева, 1	f	large
76291	92620	697	Тамбовская область, Тамбов, Кронштадтская, 83	f	large
76290	92620	696	Тамбовская область, Тамбов, Кронштадтская, 83	f	large
76436	92678	785	Тамбовская область, Тамбов, Карла Маркса, 167	f	large
76351	92678	786	Тамбовская область, Тамбов, Карла Маркса, 167	f	large
76313	92646	729	Тамбовская область, Тамбов, Карла Маркса, 259	f	large
76320	92646	736	Тамбовская область, Тамбов, Карла Маркса, 259	f	large
76295	92626	704	Тамбовская область, Тамбов, Карла Маркса, 153	f	large
76356	92684	793	Тамбовская область, Тамбов, Кавалерийская, 7А	f	large
76365	92689	803	Тамбовская область, Тамбов, Интернациональная, 118	f	large
76364	92689	802	Тамбовская область, Тамбов, Интернациональная, 118	f	large
76342	92668	771	Тамбовская область, Тамбов, Ивана Франко, 6	f	large
76323	92650	748	Тамбовская область, Тамбов, Защитная, 1а	f	large
76318	92650	734	Тамбовская область, Тамбов, Защитная, 1а	f	large
76433	92674	779	Тамбовская область, Тамбов, Железнодорожная, 51а	f	large
76347	92673	778	Тамбовская область, Тамбов, Железнодорожная, 10	f	large
76437	92679	787	Тамбовская область, Тамбов, Делегатская, 20В	f	large
76285	92616	690	Тамбовская область, Тамбов, Гоголя, 1	f	large
76357	92685	795	Тамбовская область, Тамбов, Гастелло, 38	f	large
76439	92685	794	Тамбовская область, Тамбов, Гастелло, 38	f	large
76304	92636	718	Тамбовская область, Тамбов, Володарского, 7	f	large
76438	92681	790	Тамбовская область, Тамбов, Бастионная, 19	f	large
76350	92677	784	Тамбовская область, Тамбов, Астраханская, 159	f	large
76349	92677	783	Тамбовская область, Тамбов, Астраханская, 159	f	large
76348	92676	782	Тамбовская область, Тамбов, Астраханская, 182	f	large
76435	92675	781	Тамбовская область, Тамбов, Астраханская, 181а	f	large
76434	92675	780	Тамбовская область, Тамбов, Астраханская, 181а	f	large
76293	92622	699	Тамбовская область, Тамбов, А.Бебеля, 108	f	large
76307	92639	722	Тамбовская область, Тамбов, 1-я Полковая, 25	f	large
76463	92496	568	Тамбовская область, Рассказово, Тимирязева, 3	f	large
76266	92487	559	Тамбовская область, Рассказово, Тамбовская, 122	f	large
76273	92495	567	Тамбовская область, Рассказово, Спортивная, 75	f	large
76264	92485	557	Тамбовская область, Рассказово, Советская, 1	f	large
76263	92483	555	Тамбовская область, Рассказово, Советская, 2	f	large
76261	92481	553	Тамбовская область, Рассказово, Советская, 83	f	large
76267	92489	561	Тамбовская область, Рассказово, Пушкина, 103	f	large
76269	92491	563	Тамбовская область, Рассказово, Пролетарская, 23А	f	large
76272	92494	566	Тамбовская область, Рассказово, Победы, 9	f	large
76460	92479	551	Тамбовская область, Рассказово, Некрасова, 4	f	large
76260	92478	550	Тамбовская область, Рассказово, Некрасова, 4	f	large
76461	92484	556	Тамбовская область, Рассказово, Маяковского, 6	f	large
76262	92482	554	Тамбовская область, Рассказово, Комсомольская, 115А	f	large
76271	92493	565	Тамбовская область, Рассказово, Гоголя, 5А	f	large
76265	92486	558	Тамбовская область, Рассказово, Аптекарская, 16	f	large
76268	92490	562	Тамбовская область, Рассказово, Академика Маркова, 27	f	large
76462	92488	560	Тамбовская область, Рассказово, 60 лет, 7	f	large
124111	92311	385	Тамбовская область, Моршанск, Здание ООО ГазпромТрансгазМосква	f	medium
76456	92317	391	Тамбовская область, Моршанск, Южная, 55	f	large
76233	92309	383	Тамбовская область, Моршанск, Фрунзе, 35	f	large
76234	92310	384	Тамбовская область, Моршанск, Пролетарская, 4	f	large
76237	92315	389	Тамбовская область, Моршанск, Пионерская, 38	f	large
76231	92307	381	Тамбовская область, Моршанск, Октябрьская площадь, 41	f	large
124110	92306	380	Тамбовская область, Моршанск, Октябрьская площадь, 12	f	medium
76236	92313	387	Тамбовская область, Моршанск, Лотикова, 90	f	large
76235	92312	386	Тамбовская область, Моршанск, Лотикова, 52	f	large
124109	92305	379	Тамбовская область, Моршанск, Ленина, СПТУ №9	f	medium
76229	92302	376	Тамбовская область, Моршанск, Крупской, 13	f	large
76230	92304	378	Тамбовская область, Моршанск, Красноармейская, 112	f	large
124112	92314	388	Тамбовская область, Моршанск, Красная, 2	f	medium
76225	92298	372	Тамбовская область, Моршанск, Кирова, 69 А	f	large
76455	92303	377	Тамбовская область, Моршанск, Интернациональная, 89	f	large
76224	92297	371	Тамбовская область, Моршанск, Зеленая, 16	f	large
76223	92297	370	Тамбовская область, Моршанск, Зеленая, 16	f	large
76227	92300	374	Тамбовская область, Моршанск, Дзержинского, 22	f	large
76238	92316	390	Тамбовская область, Моршанск, Горького, 1	f	large
76232	92308	382	Тамбовская область, Моршанск, Гибнера, 13	f	large
76228	92301	375	Тамбовская область, Моршанск, 7-й городок, 24	f	large
76210	92206	278	Тамбовская область, Мичуринск, Федеративная, 48	f	large
76208	92203	275	Тамбовская область, Мичуринск, Турбинная, 3	f	large
76207	92203	274	Тамбовская область, Мичуринск, Турбинная, 3	f	large
76188	92188	250	Тамбовская область, Мичуринск, Тамбовская, 270	f	large
124035	92191	256	Тамбовская область, Мичуринск, Средняя, 30-а	f	medium
124034	92191	255	Тамбовская область, Мичуринск, Средняя, 30-а	f	medium
123584	92211	284	Тамбовская область, Мичуринск, Социалистическая, 2	f	large
123583	92210	283	Тамбовская область, Мичуринск, Социалистическая, 2	f	large
76184	92184	246	Тамбовская область, Мичуринск, Советская, 351	f	large
76182	92182	244	Тамбовская область, Мичуринск, Советская, 262	f	large
76183	92183	245	Тамбовская область, Мичуринск, Революционная, 94-а	f	large
76190	92190	253	Тамбовская область, Мичуринск, Новая, 13-а	f	large
76191	92190	254	Тамбовская область, Мичуринск, Новая, 13-а	f	large
76198	92196	263	Тамбовская область, Мичуринск, Мичурина, 1-Б	f	large
76193	92193	258	Тамбовская область, Мичуринск, Мира, 12-а	f	large
76204	92200	269	Тамбовская область, Мичуринск, Мартовская, 3	f	large
76202	92198	267	Тамбовская область, Мичуринск, Липецкое шоссе, 240	f	large
76201	92197	266	Тамбовская область, Мичуринск, Липецкое шоссе, 66	f	large
76200	92197	265	Тамбовская область, Мичуринск, Липецкое шоссе, 66	f	large
76199	92197	264	Тамбовская область, Мичуринск, Липецкое шоссе, 66	f	large
124036	92201	271	Тамбовская область, Мичуринск, Лермонтова, 1	f	medium
76205	92201	270	Тамбовская область, Мичуринск, Лермонтова, 1	f	large
124033	92189	252	Тамбовская область, Мичуринск, Лаврова, 98	f	medium
76189	92189	251	Тамбовская область, Мичуринск, Лаврова, 98	f	large
76476	92205	277	Тамбовская область, Мичуринск, Красная, 72	f	large
76180	92180	242	Тамбовская область, Мичуринск, Кооперативная, 71	f	large
76179	92180	241	Тамбовская область, Мичуринск, Кооперативная, 71	f	large
76203	92199	268	Тамбовская область, Мичуринск, Киевская, 2	f	large
76187	92187	249	Тамбовская область, Мичуринск городской округ, Интернациональная, 94-а	f	large
76226	92299	373	Тамбовская область, Мичуринск, Дзержинского, 22	f	large
76196	92194	261	Тамбовская область, Мичуринск, Автозаводская, 3-а	f	large
76195	92194	260	Тамбовская область, Мичуринск, Автозаводская, 3-а	f	large
76216	92214	287	Тамбовская область, Мичуринск, 7 Ноября, 11	f	large
76479	92214	288	Тамбовская область, Мичуринск, 7 Ноября, 11	f	large
76215	92213	286	Тамбовская область, Мичуринск, 7 Ноября, 7-д	f	large
76214	92212	285	Тамбовская область, Мичуринск, 7 Ноября, 1	f	large
76212	92208	281	Тамбовская область, Мичуринск, ЦГЛ	f	large
124037	92202	273	Тамбовская область, Мичуринск, Энгельса, 2	f	medium
76206	92202	272	Тамбовская область, Мичуринск, Энгельса, 2	f	large
76186	92186	248	Тамбовская область, Мичуринск, Тамбовская, 146	f	large
76213	92209	282	Тамбовская область, Мичуринск, Советская, 274	f	large
76209	92204	276	Тамбовская область, Мичуринск, Советская, 240	f	large
124039	92215	289	Тамбовская область, Мичуринск, Привокзальная площадь, 1	f	small
124038	92207	279	Тамбовская область, Мичуринск, Полтавская, 159	f	medium
76211	92207	280	Тамбовская область, Мичуринск, Полтавская, 159	f	large
76192	92192	257	Тамбовская область, Мичуринск, Мира, 12-а	f	large
76194	92192	259	Тамбовская область, Мичуринск, Мира, 12-а	f	large
76181	92181	243	Тамбовская область, Мичуринск, Красная, 134	f	large
76197	92195	262	Тамбовская область, Мичуринск, Дубровского, 2	f	large
76185	92185	247	Тамбовская область, Мичуринск, Герасимова, 132-а	f	large
76170	92134	190	Тамбовская область, Котовск, Свободы, 8	f	large
76173	92137	193	Тамбовская область, Котовск, Посконкина, 34	f	large
76172	92136	192	Тамбовская область, Котовск, Посконкина, 1	f	large
76169	92133	189	Тамбовская область, Котовск, Октябрьская, 13	f	large
76167	92130	187	Тамбовская область, Котовск, Октябрьская, 38	f	large
76473	92127	184	Тамбовская область, Котовск, Октябрьская, 75	f	large
76168	92131	188	Тамбовская область, Котовск, Набережная, 3	f	large
76164	92125	182	Тамбовская область, Котовск, Лесхозная, 8а	f	large
76165	92126	183	Тамбовская область, Котовск, Красногвардейская, 1	f	large
76166	92128	185	Тамбовская область, Котовск, Котовского, 37	f	large
76474	92129	186	Тамбовская область, Котовск, Кирова, 10	f	large
76171	92135	191	Тамбовская область, Котовск, 9-й Пятилетки, 5а	f	large
123987	92116	173	Тамбовская область, Кирсанов, Железнодорожный район, Спортивная, 32, здание МБОУ ДОД д/с Улыбка	f	medium
76368	92694	808	Тамбовская область, село Бокино, переулок Березовый, 1	f	large
76367	92693	807	Тамбовская область, село Бокино, Советская, 52	f	large
76412	92838	953	Тамбовская область, Уметский район, поселок Умет, Транспортная, 14, здание Липовского сельского клуба	f	large
76413	92839	954	Тамбовская область, Уметский район, поселок Умет, Советская, 85, здание РДК	f	large
124452	92837	952	Тамбовская область, Уметский район, поселок Совхоз Сулакский, Школьная, 5, здание Сулакского филиала МОУ Уметской средней общеобразоват	f	medium
124440	92825	940	Тамбовская область, Уметский район, поселок Совхоз Глуховский, Центральная, 2а, здание Глуховского филиала МОУ Уметской средней общеобразовательной школы	f	small
124451	92836	951	Тамбовская область, Уметский район, поселок Скачиха, Ленина, 3а, МУК Скачихинский Дом культуры	f	small
124122	92331	404	Тамбовская область, Уметский район, поселок Сергиевка, Коммунальная, 43	f	small
124447	92832	947	Тамбовская область, Уметский район, поселок Сергиевка, Заречная, 54, здание Сергиевского Дома культуры	f	small
124233	92460	536	Тамбовская область, Уметский район, поселок Осиновка, Центральная, 3	f	small
124415	92786	901	Тамбовская область, Уваровский район, поселок Моисеево-Алабушка, Молодежная, 4	f	small
124443	92828	943	Тамбовская область, Уметский район, поселок Оржевка, Молодежная, 19, здание Оржевского филиала МОУ Уметской средней общеобразоват	f	small
124439	92824	939	Тамбовская область, Уметский район, поселок Нововоздвиженка, Центральная, 9а, здание Ново-Воздвиженского Дома культуры	f	small
124445	92830	945	Тамбовская область, Уметский район, поселок Нижние Пески, Парковая, 3, здание Нижне-Песковского филиала МОУ Уметской СОШ	f	small
124444	92829	944	Тамбовская область, Уметский район, поселок Масловка, Быковская, 26, здание администрации Оржевского сельсовета	f	small
124442	92827	942	Тамбовская область, Уметский район, поселок Красный Октябрь, Центральная, 62, здание Краснооктябрьского филиала МОУ Уметской средней общео	f	small
124448	92833	948	Тамбовская область, Уметский район, поселок Ильинка, Луговая, 2, здание администрации Сергиевского сельсовета	f	small
124044	92221	294	Тамбовская область, Уметский район, поселок Ивановка, 78, здание администрации Ивановского сельсовета	f	small
124441	92826	941	Тамбовская область, Уметский район, поселок Ивановка, Верхняя, 25, здание Ивановского филиала МОУ Уметской средней общеобразовательной школы	f	small
124086	92267	339	Тамбовская область, Уметский район, поселок Екатериновка, 4, администрация Екатериновского сельсовета	f	small
124446	92831	946	Тамбовская область, Уметский район, поселок Васильевка, Начальная, 31/1, здание Васильевской библиотеки	f	small
124450	92835	950	Тамбовская область, Уметский район, поселок Варваринка, Центральная, 16, здание МУК Софьинскисельский Дом культуры	f	small
124438	92823	938	Тамбовская область, Уметский район, поселок Бибиково, Центральная, 10, здание администрации Бибиковского сельсовета	f	small
124138	92351	424	Тамбовская область, Уметский район, поселок Бибиково, Мира, 8	f	small
124436	92821	936	Россия, Красноярский край, поселок Березовка, улица Садовая, 2	f	small
124437	92822	937	Тамбовская область, Уметский район, поселок 14-й, Молодежная, 1, здание Березовского филиала МОУ Уметской СОШ	f	small
124421	92792	907	Тамбовская область, Уваровский район, поселок Энгуразово, Школьная, 38	f	small
124416	92787	902	Тамбовская область, Уваровский район, поселок Чуево-Подгорное, Школьная, 1	f	small
124432	92803	918	Тамбовская область, Уваровский район, поселок Чуево-Алабушка, Попова, 40а	f	small
123973	92100	156	Тамбовская область, Уваровский район, поселок Ульяновка, Центральная, 13, здание клуба	f	small
124413	92784	899	Тамбовская область, Уваровский район, поселок Ульяновка, Молодежная, 11	f	small
76409	92815	930	Тамбовская область, Уваровский район, Уварово, переулок Первомайский, 4	f	large
76407	92811	926	Тамбовская область, Уваровский район, Уварово, Шоссейная, 39	f	large
76406	92810	925	Тамбовская область, Уваровский район, Уварово, Шоссейная, 71Г	f	large
76404	92808	923	Тамбовская область, Уваровский район, Уварово, Центральная, 22	f	large
76400	92804	919	Тамбовская область, Уваровский район, Уварово, Микрорайон Молодежный, 13	f	large
124435	92820	935	Тамбовская область, Уваровский район, Уварово, Дачная, 1	f	small
76408	92813	928	Тамбовская область, Уваровский район, Уварово, Гагарина, 1	f	large
76410	92816	931	Тамбовская область, Уваровский район, Уварово, Большая Садовая, 83	f	large
76446	92812	927	Тамбовская область, Уваровский район, Уварово, 4 микрорайон, 1	f	large
76447	92814	929	Тамбовская область, Уваровский район, Уварово, 2 микрорайон, 4а	f	large
76403	92807	922	Тамбовская область, Уваровский район, Уварово, 1 микрорайон, 25а	f	large
76402	92806	921	Тамбовская область, Уваровский район, Уварово, 1 микрорайон, здание МУК УГДК Дружба	f	large
76401	92805	920	Тамбовская область, Уваровский район, Уварово, 1 микрорайон, 17 а	f	large
124412	92783	898	Тамбовская область, Уваровский район, поселок Репное, Молодежная, 4	f	small
123892	92011	67	Тамбовская область, Уваровский район, поселок Павлодар, Юбилейная, 35	f	small
124422	92793	908	Тамбовская область, Уваровский район, поселок Павлодар, Центральная, 106д	f	small
124425	92796	911	Тамбовская область, Уваровский район, поселок Нижний Шибряй, Центральная, 16	f	medium
124426	92797	912	Тамбовская область, Уваровский район, поселок Нижний Шибряй, Кировская, 3	f	small
124414	92785	900	Тамбовская область, Уваровский район, поселок Моисеево-Алабушка, Советская, 131	f	small
124417	92788	903	Тамбовская область, Уваровский район, поселок Моисеево, Центральная, 51а	f	small
124420	92791	906	Тамбовская область, Уваровский район, поселок Луч, Школьная, 8	f	small
124428	92799	914	Тамбовская область, Уваровский район, поселок Лебяжье, 4-я Лопатинская, 3а	f	small
124427	92798	913	Тамбовская область, Уваровский район, поселок Канино, Молодежная, 26	f	small
124424	92795	910	Тамбовская область, Уваровский район, поселок Григорьевка 2-я, Григорьевская, 52б	f	small
124419	92790	905	Тамбовская область, Уваровский район, поселок Вольная Вершина, Центральная, 125	f	small
124430	92801	916	Тамбовская область, Уваровский район, поселок Верхний Шибряй, Куракинский, 16	f	medium
124418	92789	904	Тамбовская область, Уваровский район, поселок Верхнее Чуево, Советская, 28	f	small
124410	92781	896	Тамбовская область, Уваровский район, поселок Березовка, Советская, 23	f	medium
124429	92800	915	Тамбовская область, Уваровский район, поселок Алаторка, Алаторская, 26	f	small
76411	92817	932	Тамбовская область, Уварово городской округ, Уварово, переулок Большой Садовый, 57	f	large
124396	92767	882	Тамбовская область, Токаревский район, поселок Ястребовка, Школьная, 10, Здание филиала МБОУ ТСОШ №2	f	medium
124409	92780	895	Тамбовская область, Токаревский район, поселок Чичерино, Полевая, 28, Административное здание ООО Агро-Вилион	f	medium
124408	92779	894	Тамбовская область, Токаревский район, поселок Троицкий Росляй, Центральная, 13, Здание администрации Троицкоросляского сельсовета	f	medium
76397	92752	868	Тамбовская область, Токаревский район, поселок Токаревка, проспект Революции, 2	f	large
76398	92753	869	Тамбовская область, Токаревский район, поселок Токаревка, Чичканова, 25	f	large
76396	92751	867	Тамбовская область, Токаревский район, поселок Токаревка, Проспект Революции, 72	f	large
76399	92754	870	Тамбовская область, Токаревский район, поселок Токаревка, 40 лет Октября, 46	f	large
124385	92755	871	Тамбовская область, Токаревский район, поселок Старогрязное, Школьная, 14	f	small
124406	92777	892	Тамбовская область, Токаревский район, поселок Сергиевка, Центральная, 10, Здание филиала МБОУ ТСОШ №1 в с. Сергиевка	f	medium
123739	92758	874	Тамбовская область, Токаревский район, поселок Розановка, Здание филиала МБОУ ТСОШ №2 в д. Розановка	f	small
124404	92775	890	Тамбовская область, Токаревский район, поселок Полетаево, Центральная, 71, Здание администрации Полетаевского сельсовета	f	medium
124407	92778	893	Тамбовская область, Токаревский район, поселок Новоникольское, Дружбы, 42, Здание филиала МБОУ ТСОШ №1 в с. Новоникольское	f	small
124369	92715	829	Тамбовская область, Токаревский район, поселок Малиновка, Энтузиастов, 1	f	medium
124392	92763	878	Тамбовская область, Токаревский район, поселок Малая Зверяевка, Молодежная, 33, Административное здание Александровского сельсовета	f	small
124397	92768	883	Тамбовская область, Токаревский район, поселок Малая Даниловка, Центральная, 4, Здание администрации Даниловского сельсовета	f	small
124405	92776	891	Тамбовская область, Токаревский район, поселок Кулешовка, Новая, 5, Здание филиала МБОУ ТСОШ №1 в д. Кулешовка	f	small
124118	92327	400	Тамбовская область, Токаревский район, поселок Красный Куст, Парковая, 2а	f	medium
124401	92772	887	Тамбовская область, Токаревский район, поселок Карловка, Речная, 52, Здание филиала МБОУ ТСОШ №1	f	small
124386	92756	872	Тамбовская область, Токаревский район, поселок Ивано-Лебедянь, Центральная, 19, Здание администрации Абакумовского сельсовета	f	medium
124399	92770	885	Тамбовская область, Токаревский район, поселок Знаменка, Каменка, 17, Административное здание ООО Знаменское	f	small
124394	92765	880	Тамбовская область, Токаревский район, поселок Васильевка, Новая, 9, Здание администрации Васильевского сельсовета	f	small
124387	92757	873	Тамбовская область, Токаревский район, поселок Березовка, Кавказская , 21, дание филиала МБОУ ТСОШ №2 в с. Березовка	f	small
124393	92764	879	Тамбовская область, Токаревский район, поселок Безукладовка, Здание конторы СХПК Заря	f	medium
124262	92511	582	Тамбовская область, Токаревский район, поселок Александровка, Школьная, 15	f	small
123901	92019	76	Тамбовская область, Токаревский район, поселок Александровка, Молодежная, 30	f	medium
76374	92704	818	Тамбовская область, Тамбовский район, поселок Донское, Советская, 218	f	large
124391	92762	877	Тамбовская область, Токаревский район, поселок Александровка, Александровская, 76, Здание администрации Александровского сельсовета	f	small
124372	92721	835	Тамбовская область, Тамбовский район, поселок Шестой километр, детский сад Земляничка	f	medium
76395	92749	863	Тамбовская область, Тамбовский район, поселок Черняное, Ленина, 178	f	large
124052	92230	302	Тамбовская область, Тамбовский район, поселок Черняевка, Совхозная, 2, здание Черняевского филиала МБОУ Оборонинская СОШ	f	small
124326	92581	654	Тамбовская область, Тамбовский район, поселок Федоровка, Школьная, 1	f	small
124362	92697	811	Тамбовская область, Тамбовский район, поселок Учебное хозяйство Авангард, 30, контора ОАО Тамбовагропромхолдинг	f	small
76388	92736	850	Тамбовская область, Тамбовский район, поселок Тулиновка, Советская, 66	f	large
124370	92716	830	Тамбовская область, Тамбовский район, поселок Троицкая Дубрава, Большая, 1	f	small
76389	92739	853	Тамбовская область, Тамбовский район, поселок Татаново, Совхозная, 7	f	large
124380	92734	848	Тамбовская область, Тамбовский район, поселок Сурава, переулок Школьный, 2	f	medium
76443	92746	860	Тамбовская область, Тамбовский район, поселок Строитель, мкр.Центральный, 21	f	large
76442	92744	858	Тамбовская область, Тамбовский район, поселок Строитель, мкр.Центральный, 16	f	large
76441	92742	856	Тамбовская область, Тамбовский район, поселок Строитель, мкр. Северный, 19	f	large
76393	92747	861	Тамбовская область, Тамбовский район, поселок Строитель, Центральный, 21	f	large
76392	92745	859	Тамбовская область, Тамбовский район, поселок Строитель, Центральный, 16	f	large
76391	92743	857	Тамбовская область, Тамбовский район, поселок Строитель, Северный, 19	f	large
76386	92730	844	Тамбовская область, Тамбовский район, поселок Стрельцы, Филимонова, 10Б	f	large
76387	92733	847	Тамбовская область, Тамбовский район, поселок Столовое, Чапаева, 23Б	f	large
124384	92741	855	Тамбовская область, Тамбовский район, поселок Солдатская Духовка, Школьная, 1	f	medium
76394	92748	862	Тамбовская область, Тамбовский район, поселок Селезни, Центральная, 22	f	large
76385	92729	843	Тамбовская область, Тамбовский район, поселок Селезневский, 2-я Школьная улица, 11	f	large
76444	92750	864	Тамбовская область, Тамбовский район, поселок Селезневский, 2-я Школьная, 11	f	large
123778	92713	827	Тамбовская область, Тамбовский район, поселок Роща, 17	f	small
124378	92731	845	Тамбовская область, Тамбовский район, поселок Пушкари, 50 лет Октября, 80А	f	medium
124383	92738	852	Тамбовская область, Тамбовский район, поселок Пригородное Лесничество, Дорожная, 1	f	small
76383	92726	840	Тамбовская область, Тамбовский район, поселок Покрово-Пригородное, Советская, 122	f	large
76384	92727	841	Тамбовская область, Тамбовский район, поселок Покрово-Пригородное, Садовая, 50А	f	large
124373	92722	836	Тамбовская область, Тамбовский район, поселок Новосельцево, Центральная, 26	f	medium
76382	92719	833	Тамбовская область, Тамбовский район, поселок Новая Ляда, Советская, 169В	f	large
76381	92717	831	Тамбовская область, Тамбовский район, поселок Новая Ляда, Советская, 80	f	large
124371	92718	832	Тамбовская область, Тамбовский район, поселок Новая Ляда, Малоталинская, 2А	f	small
124368	92714	828	Тамбовская область, Тамбовский район, поселок Лысые Горы, Советская, 21	f	medium
76390	92740	854	Тамбовская область, Тамбовский район, поселок Куксово, Интернациональная, 1	f	large
76378	92708	822	Тамбовская область, Тамбовский район, поселок Кузьмино-Гать, Колхозная, 43А	f	large
76379	92710	824	Тамбовская область, Тамбовский район, поселок Красносвободное, Центральная, 5	f	large
124363	92700	814	Тамбовская область, Тамбовский район, поселок Красная-Криуша, Школьная, 2А	f	medium
76380	92712	826	Тамбовская область, Тамбовский район, поселок Комсомолец, Ново-Южная, 28	f	large
123861	91971	27	Тамбовская область, Тамбовский район, поселок Козьмодемьяновка, Молодежная, 7а	f	medium
124381	92735	849	Тамбовская область, Тамбовский район, поселок Иноземная Духовка, Школьная, 1	f	small
124360	92692	806	Тамбовская область, Тамбовский район, поселок Иванково, 134А	f	medium
124359	92691	805	Тамбовская область, Тамбовский район, поселок Дубровка, Центральная, 15	f	small
76375	92705	819	Тамбовская область, Тамбовский район, поселок Донское, Школьная, 5А	f	large
124382	92737	851	Тамбовская область, Тамбовский район, поселок Горельский лесхоз, Интернациональная, 1А	f	small
76373	92703	817	Тамбовская область, Тамбовский район, поселок Горелое, переулок Школьный, 1	f	large
76372	92702	816	Тамбовская область, Тамбовский район, поселок Горелое, Ленина, 45Д	f	large
76440	92720	834	Тамбовская область, Тамбовский район, поселок Георгиевский, Аграрно-технологический техникум	f	large
124366	92711	825	Тамбовская область, Тамбовский район, поселок Борщевка, Центральная , 13	f	small
124379	92732	846	Тамбовская область, Тамбовский район, поселок Большая Талинка, 2-я Советская, 55	f	small
76370	92698	812	Тамбовская область, Тамбовский район, поселок Большая Липовица, Советская, 54	f	large
76371	92699	813	Тамбовская область, Тамбовский район, поселок Беломестная-Криуша, Школьная, 2А	f	large
76369	92696	810	Тамбовская область, Тамбовский район, поселок Беломестная Двойня, Центральная, 48	f	large
76366	92690	804	Тамбовская область, Тамбовский район, поселок Авдеевка, Молодежная, 4	f	large
76376	92706	820	Тамбовская область, Тамбов городской округ, поселок Красненькая, переулок Совхозный, 19	f	large
124352	92609	683	Тамбовская область, Староюрьевский район, поселок Троицко-Ивановское, Молодежная, 8	f	small
124355	92614	688	Тамбовская область, Староюрьевский район, поселок Староюрьево, Элеваторная, 15	f	medium
76284	92612	686	Тамбовская область, Староюрьевский район, поселок Староюрьево, Советская, 98	f	large
124353	92610	684	Тамбовская область, Староюрьевский район, поселок Староюрьево, Московская, 15-б	f	small
76283	92611	685	Тамбовская область, Староюрьевский район, поселок Староюрьево, Ломоносова, 4	f	large
124354	92613	687	Тамбовская область, Староюрьевский район, поселок Староюрьево, Заречная, 31	f	medium
124343	92599	673	Тамбовская область, Староюрьевский район, поселок Старая Александровка, Центральная, 4	f	small
124350	92607	681	Тамбовская область, Староюрьевский район, поселок Спасское, Уваркина, 1	f	small
124351	92608	682	Тамбовская область, Староюрьевский район, поселок Скобелевка, Центральная, 25	f	small
124196	92420	494	Тамбовская область, Староюрьевский район, поселок Рахманино, Школьная, 1	f	small
124349	92606	680	Тамбовская область, Староюрьевский район, поселок Поповка, Пажа, 236	f	small
124346	92603	677	Тамбовская область, Староюрьевский район, поселок Подгорное, Центральная, 6	f	small
124345	92602	676	Тамбовская область, Староюрьевский район, поселок Подгорное, Рабочая, 9	f	small
124344	92600	674	Тамбовская область, Староюрьевский район, поселок Новоюрьево, Советская, 112	f	small
76282	92601	675	Тамбовская область, Староюрьевский район, поселок Новоюрьево, Бутырская, 64-а	f	large
124341	92597	671	Тамбовская область, Староюрьевский район, поселок Новиково, Центральная, 97	f	small
124347	92604	678	Тамбовская область, Староюрьевский район, поселок Надеждина, Школьная, 6	f	small
124340	92596	670	Тамбовская область, Староюрьевский район, поселок Мезинец, Кончанка, 5	f	small
124348	92605	679	Тамбовская область, Староюрьевский район, поселок Крутовское, школьная, 166	f	small
124337	92593	667	Тамбовская область, Староюрьевский район, поселок Заворонежское, Школьная, 112	f	small
124338	92594	668	Тамбовская область, Староюрьевский район, поселок Вишневое, Центр, 51	f	medium
124339	92595	669	Тамбовская область, Староюрьевский район, поселок Вишневое, Племзавод, 42	f	medium
124336	92592	665	Тамбовская область, Староюрьевский район, поселок Большая Дорога, Совхозная, 2	f	small
124342	92598	672	Тамбовская область, Староюрьевский район, поселок Боголюбово, Сельскохозяйственная, 10	f	small
124318	92573	646	Тамбовская область, Сосновский район, поселок Челнаво-Рождественская, Центральная, 39	f	medium
124317	92572	645	Тамбовская область, Сосновский район, поселок Чекмари, Октябрьская, 28	f	small
124324	92579	652	Тамбовская область, Сосновский район, поселок Христофоровка, Молодежная, 1а	f	small
124332	92587	660	Тамбовская область, Сосновский район, поселок Троицкие Росляи, Московская, 6	f	small
124310	92566	637	Тамбовская область, Сосновский район, поселок Троицкая Вихляйка, Полевая, 11	f	small
124307	92563	634	Тамбовская область, Сосновский район, поселок Третьи Левые Ламки, Интернациональная, 47б	f	medium
76120	90546	772	Смоленская область, Ярцево, Гагарина, 5	f	large
124313	92569	640	Тамбовская область, Сосновский район, поселок Стежки, Советская, 114	f	small
124314	92549	641	Тамбовская область, Сосновский район, поселок Стежки, Советская, 60	f	small
124334	92589	662	Тамбовская область, Сосновский район, поселок Старое Грязное, Ленина, 97	f	small
124064	92244	316	Тамбовская область, Сосновский район, поселок Сосновка, Прогресс, 7, здание Сосновского филиала МБОУ Новопокровская СОШ	f	small
124297	92553	624	Тамбовская область, Сосновский район, поселок Сосновка, Набережная, 5	f	medium
76276	92548	620	Тамбовская область, Сосновский район, поселок Сосновка, Мичурина, 128	f	large
76279	92552	623	Тамбовская область, Сосновский район, поселок Сосновка, Красноармейская, 2	f	large
76277	92550	621	Тамбовская область, Сосновский район, поселок Сосновка, Котовского, 12	f	large
76278	92551	622	Тамбовская область, Сосновский район, поселок Сосновка, Интернациональная, 207	f	large
124298	92554	625	Тамбовская область, Сосновский район, поселок Сосновка, Высотная, 4	f	small
124315	84239	642	Тамбовская область, Сосновский район, поселок Советское, Мира, 2	f	medium
124302	92558	629	Тамбовская область, Сосновский район, поселок Семикино, Колхозная, 120а	f	medium
124333	92588	661	Тамбовская область, Сосновский район, поселок Савинские Карпели, Интернациональная, 13	f	small
124301	92557	628	Тамбовская область, Сосновский район, поселок Рабочий, 22	f	medium
124308	92564	635	Тамбовская область, Сосновский район, поселок Правые Ламки, Центральная, 85	f	medium
124374	92723	837	Тамбовская область, Сосновский район, поселок Поповка, Клубная, 8	f	small
124329	92584	657	Тамбовская область, Сосновский район, поселок Покрово-Васильевка, Пролетарская, 41	f	small
76280	92570	643	Тамбовская область, Сосновский район, поселок Подлесное, Советская бригада №2, 27	f	large
124305	92561	632	Тамбовская область, Сосновский район, поселок Перкинский лесокомбинат, здание конторы ТОГАУ Цнинский лесхоз	f	medium
124304	92560	631	Тамбовская область, Сосновский район, поселок Перкино, Центральная, 315	f	medium
124306	92562	633	Тамбовская область, Сосновский район, поселок Первые Левые Ламки, Пролетарская, 37	f	small
76281	92591	664	Тамбовская область, Сосновский район, поселок Отъяссы, Захарова, 70а	f	large
124331	92586	659	Тамбовская область, Сосновский район, поселок Ольхи, Советская, 1	f	medium
124328	92583	656	Тамбовская область, Сосновский район, поселок Новочеркасовка, Слободская, 5а	f	small
124335	92590	663	Тамбовская область, Сосновский район, поселок Новое Грязное, Молодежная, 1	f	small
124316	92571	644	Тамбовская область, Сосновский район, поселок Новая Слобода, Ленинская, 2	f	small
124323	92578	651	Тамбовская область, Сосновский район, поселок Новая Поповка, Молодежная, 8	f	small
124322	92577	650	Тамбовская область, Сосновский район, поселок Новая Павловка, Молодежная, 4б	f	small
124320	92575	648	Тамбовская область, Сосновский район, поселок Нижняя Ярославка, Половинкина, 126	f	small
124303	92559	630	Тамбовская область, Сосновский район, поселок Красный Хутор, Бахмут, 17а	f	small
124299	92555	626	Тамбовская область, Сосновский район, поселок Космачевка, Интернациональная, 52	f	small
124312	92568	639	Тамбовская область, Сосновский район, поселок Каменный Брод, Центральная, 70	f	small
124321	92576	649	Тамбовская область, Сосновский район, поселок Зеленое, Центральная, 20	f	small
124211	92434	509	Тамбовская область, Сосновский район, поселок Заречье, Новая, 17	f	medium
124330	92585	658	Тамбовская область, Сосновский район, поселок Дельная Дубрава, Советская, 81а	f	small
124311	92567	638	Тамбовская область, Сосновский район, поселок Дегтянка, Ленинская, 95	f	medium
124319	92574	647	Тамбовская область, Сосновский район, поселок Вторые Левые Ламки, Больничная, 35	f	medium
124300	92556	627	Тамбовская область, Сосновский район, поселок Вирятино, Тамбовская, 4	f	small
124327	92582	655	Тамбовская область, Сосновский район, поселок Верхняя Ярославка, Школьная, 3а	f	medium
124309	92565	636	Тамбовская область, Сосновский район, поселок Атаманов Угол, Школьная, 13	f	medium
124282	92531	603	Тамбовская область, Сампурский район, поселок Текино, Советская, 79	f	small
124283	92532	604	Тамбовская область, Сампурский район, поселок Совхоз Россия, Ленина, 12	f	medium
124291	92541	613	Тамбовская область, Сампурский район, поселок Серединовка, Школьная, 17	f	small
76467	92544	616	Тамбовская область, Сампурский район, поселок Сатинка, Олимпийская, 1А	f	large
76466	92530	602	Тамбовская область, Сампурский район, поселок Сампур, Советская, 1	f	large
124292	92542	614	Тамбовская область, Сампурский район, поселок Понзари, Придорожная, 104а	f	small
124295	92546	618	Тамбовская область, Сампурский район, поселок Петровка, Школьная, 15	f	small
124377	92728	842	Тамбовская область, Сампурский район, поселок Перикса, Центральная, 1А	f	medium
124294	92545	617	Тамбовская область, Сампурский район, поселок Перикса, Рабочая, 9	f	medium
124285	92534	606	Тамбовская область, Сампурский район, поселок Первомайское, 20	f	small
124289	92539	611	Тамбовская область, Сампурский район, поселок Пановы Кусты, Театральная, 87а	f	small
124296	92547	619	Тамбовская область, Сампурский район, поселок Осино-Лазовка, Центральная, 19	f	small
124293	92543	615	Тамбовская область, Сампурский район, поселок Медное, Центральная, 35, Медненский сельсовет	f	small
124284	92533	605	Тамбовская область, Сампурский район, поселок Марьевка, Садовая, 25	f	small
124286	92536	608	Тамбовская область, Сампурский район, поселок Марьевка, Кооперативная, 98а	f	small
76275	92535	607	Тамбовская область, Сампурский район, поселок Ивановка, Олимпийская, 1в	f	large
123858	91970	23	Тамбовская область, Сампурский район, поселок Ивановка, Гагарина, 14	f	small
124290	92540	612	Тамбовская область, Сампурский район, поселок Верхоценье, Центральная, 25	f	small
124287	92537	609	Тамбовская область, Сампурский район, поселок Бахарево, Школьная, 104а	f	small
124264	92513	584	Тамбовская область, Сампурский район, поселок Андреевка, Парковая, 32	f	small
124288	92538	610	Тамбовская область, Сампурский район, поселок Александровские Верхи, Школьная, 124а	f	small
124277	92525	597	Тамбовская область, Ржаксинский район, поселок Чакино, Зеленая, 18	f	medium
124268	92517	588	Тамбовская область, Ржаксинский район, поселок Траковка, Мичуринская, 13	f	small
124278	92526	598	Тамбовская область, Ржаксинский район, поселок Тимофеевка, Основная, 19	f	small
124274	92522	594	Тамбовская область, Ржаксинский район, поселок Степановка, Школьная, 12	f	medium
124267	92516	587	Тамбовская область, Ржаксинский район, поселок Серебряное, Садовая, 48	f	small
124253	92502	573	Тамбовская область, Ржаксинский район, поселок Ржакса, Школьная, 36	f	medium
76464	92500	571	Тамбовская область, Ржаксинский район, поселок Ржакса, Советская, 8	f	large
76274	92499	570	Тамбовская область, Ржаксинский район, поселок Ржакса, Первомайская, 36	f	large
76465	92501	572	Тамбовская область, Ржаксинский район, поселок Ржакса, Комсомольская, 51	f	large
124261	92510	581	Тамбовская область, Ржаксинский район, поселок Ракитино, Школьная, 1	f	small
124270	92518	590	Тамбовская область, Ржаксинский район, поселок Протасово, Юбилейная, 47	f	medium
124259	92508	579	Тамбовская область, Ржаксинский район, поселок Перевоз, Центральная, 35	f	small
124254	92503	574	Тамбовская область, Ржаксинский район, поселок Пахарь, Молодежная, 6	f	small
124276	92524	596	Тамбовская область, Ржаксинский район, поселок Отхожее, Школьная, 17	f	small
124255	92504	575	Тамбовская область, Ржаксинский район, поселок Николаевский, Зеленая, 48	f	small
123681	92523	595	Тамбовская область, Ржаксинский район, поселок Недобровка, Школьная, 5	f	small
124271	92519	591	Тамбовская область, Ржаксинский район, поселок Лукино, Проезжая, 4	f	medium
124269	92497	589	Тамбовская область, Ржаксинский район, поселок Каменка, Советская, 2а	f	medium
123887	92005	61	Тамбовская область, Ржаксинский район, поселок Ивановка, Мира, 11	f	small
124266	92515	586	Тамбовская область, Ржаксинский район, поселок Золотовка, Школьная, 14	f	small
124279	92527	599	Тамбовская область, Ржаксинский район, поселок Жемчужный, Школьная, 1	f	medium
124263	92512	583	Тамбовская область, Ржаксинский район, поселок Гавриловка, Новая,  6	f	small
124273	92521	593	Тамбовская область, Ржаксинский район, поселок Вишневка, Вишневая, 18	f	small
124257	92506	577	Тамбовская область, Ржаксинский район, поселок Большая Ржакса, Центральная, 8	f	small
124256	92505	576	Тамбовская область, Ржаксинский район, поселок Богданово, Центральная, 82	f	small
124272	92520	592	Тамбовская область, Ржаксинский район, поселок Афанасьевка, Молодежная, 2	f	small
75976	90285	501	Смоленская область, Смоленск, Витебское шоссе, 42, МБОУ МУК №1	f	large
124265	92514	585	Тамбовская область, Ржаксинский район, поселок Алкаладка, Центральная, 76	f	small
123894	92012	69	Тамбовская область, Ржаксинский район, поселок Александровка 2-я, Центральная, 1	f	small
124238	92465	541	Тамбовская область, Рассказовский район, поселок Хитрово, Центральная, 60	f	medium
124361	92695	809	Тамбовская область, Рассказовский район, поселок Тригуляй, здание филиала МОУ Цнинская СОЩ №2 в п.Тригуляй	f	small
124224	92449	525	Тамбовская область, Рассказовский район, поселок Телешовка, здание Телешовского филиала МОУ Платоновской СОШ	f	small
124221	92446	522	Тамбовская область, Рассказовский район, поселок Татарщино, Школьная, 5	f	small
76257	92445	521	Тамбовская область, Рассказовский район, поселок Саюкино, Октябрьская, 18	f	large
124223	92448	524	Тамбовская область, Рассказовский район, поселок Рождественское, Школьная, 63	f	small
124227	92452	528	Тамбовская область, Рассказовский район, Поселок Каменные Озерки, здание конторы 3-го отделения ОАО ППЗ Арженка	f	small
124244	92470	546	Тамбовская область, Рассказовский район, поселок Подоскляй, здание Подоскляйского филиала имени Героя Советского Союза А.Н.Московского МОУ 	f	small
76258	92455	531	Тамбовская область, Рассказовский район, поселок Платоновка, Советская, 35	f	large
76259	92456	532	Тамбовская область, Рассказовский район, поселок Платоновка, Киевская, 32а	f	large
124231	92458	534	Тамбовская область, Рассказовский район, поселок Пичер, Советская, 56а	f	small
124226	92451	527	Тамбовская область, Рассказовский район, поселок Новогородовка, здание Новгородовского филиала МОУ Платоновской СОШ	f	small
124225	92450	526	Тамбовская область, Рассказовский район, поселок Никольское, здание Никольского филиала имени Героя Советского Союза З.А.Космодемьянской МОУ Платоновской СОШ	f	medium
124169	92389	463	Тамбовская область, Рассказовский район, поселок Никольское, Школьная, 2	f	small
123915	90804	91	Тамбовская область, Рассказовский район, поселок Никольское, Школьная, 14	f	medium
124242	92469	545	Тамбовская область, Рассказовский район, поселок Нижнеспасское, Коммунальная, 2	f	medium
124241	92468	544	Тамбовская область, Рассказовский район, поселок Нижнеспасское, Коммунальная, 21	f	medium
124251	92480	552	Тамбовская область, Рассказовский район, поселок Меховая Фабрика, 34, Меховой фабрики поселок	f	medium
124281	92529	601	Тамбовская область, Рассказовский район, поселок Маяк, Школьная, 12	f	small
124230	92457	533	Тамбовская область, Рассказовский район, поселок Маяк, Центральная, 32	f	small
124212	92435	510	Тамбовская область, Рассказовский район, поселок Липовка, Молодёжная, 3	f	medium
124249	92476	549	Тамбовская область, Рассказовский район, поселок Котовское, здание Котовского филиала МОУ Верхнеспасской СОШ	f	small
124248	92474	548	Тамбовская область, Рассказовский район, поселок Коптево, Молодежная, 23	f	small
124222	92447	523	Тамбовская область, Рассказовский район, поселок Керша, Молодежная, 7	f	small
124234	92461	537	Тамбовская область, Рассказовский район, поселок Имени 2-й Пятилетки, Больничный проезд, 6	f	medium
124411	92782	897	Тамбовская область, Рассказовский район, поселок Ивановка, Проезжая, 1	f	medium
124229	92454	530	Тамбовская область, Рассказовский район, поселок Зеленый, Центральная, 7	f	medium
124228	92453	529	Тамбовская область, Рассказовский район, поселок Дмитриевщина, Советская, 35а	f	medium
124236	92463	539	Тамбовская область, Рассказовский район, поселок Верхнеспасское, Центральная, 84а	f	medium
124237	92464	540	Тамбовская область, Рассказовский район, поселок Верхнеспасское, Больничная, 24	f	medium
124364	92701	815	Тамбовская область, Рассказовский район, поселок Богословка, Советская, 1	f	medium
124235	92462	538	Тамбовская область, Рассказовский район, поселок Богословка, Новое село, 42	f	small
124246	92473	547	Тамбовская область, Рассказовский район, поселок Ахтырка, Красная, 15а	f	small
123911	92030	87	Тамбовская область, Рассказовский район, поселок Алексеевка, Центральная, 46	f	small
124040	92216	290	Тамбовская область, Рассказовский район, поселок Александровка, 160, здание администрации Александровского сельсовета	f	small
76270	92492	564	Тамбовская область, Рассказово городской округ, Рассказово, Ремесленная, 2	f	large
124218	84225	517	Тамбовская область, Пичаевский район, поселок Таракса, Красная, 19	f	small
76256	92444	520	Тамбовская область, Пичаевский район, поселок Рудовка, Садовая, 11	f	large
124219	92442	518	Тамбовская область, Пичаевский район, поселок Покрово-Васильево, Рубцовка, 2 А	f	small
124217	92441	516	Тамбовская область, Пичаевский район, поселок Подъем, Заречная, 13 А	f	small
76255	92438	513	Тамбовская область, Пичаевский район, поселок Пичаево, Пролетарская, 17	f	large
124213	92436	511	Тамбовская область, Пичаевский район, поселок Питим, Молодёжная, 12	f	small
124216	92440	515	Тамбовская область, Пичаевский район, поселок Отделение N3 совхоза Подъем, Школьная, 17	f	medium
124203	92427	501	Тамбовская область, Пичаевский район, поселок Октябрьский, Новая, 16 А	f	small
124239	92466	542	Тамбовская область, Пичаевский район, поселок Липовка, Молодежная, 28	f	small
124205	92429	503	Тамбовская область, Пичаевский район, поселок Коршуновка, Центральная, 65	f	small
124210	92433	508	Тамбовская область, Пичаевский район, поселок Егоровка, Центральная, 50 В	f	small
124208	92431	506	Тамбовская область, Пичаевский район, поселок Вышенка, Новая, 7	f	small
124202	92426	500	Тамбовская область, Пичаевский район, поселок Волхонщина, Садовая, 9 Б	f	small
124220	92443	519	Тамбовская область, Пичаевский район, поселок Васильево, Новая, 2	f	small
124204	92428	502	Тамбовская область, Пичаевский район, поселок Большой Ломовис, Центральная, 47	f	small
124207	92430	505	Тамбовская область, Пичаевский район, поселок Большое Шереметьево, Центральная, 2	f	medium
124201	92425	499	Тамбовская область, Пичаевский район, поселок Байловка 2-я, Школьная, 22 А	f	medium
124214	92437	512	Тамбовская область, Пичаевский район, поселок Бадин Угол, Центральная, 6	f	small
124206	14610	504	Тамбовская область, Пичаевский район, поселок 2-е, 6 А	f	small
124190	92414	488	Тамбовская область, Петровский район, поселок Яблоновец, Советская, 72	f	medium
124187	92411	485	Тамбовская область, Петровский район, поселок Шехмань, Первомайская, 63, Шехманский сельсовет	f	medium
124180	92404	478	Тамбовская область, Петровский район, поселок Чибизовка, Молодежная, 1	f	small
124232	92459	535	Тамбовская область, Петровский район, поселок Центральное отделение совхоза Плавица, Центральная, 1	f	medium
124191	92415	489	Тамбовская область, Петровский район, поселок Хренное, Колхозная, 18	f	small
124198	92422	496	Тамбовская область, Петровский район, поселок Федоровка, здание администрации Первомайского сельсовета	f	small
124182	92406	480	Тамбовская область, Петровский район, поселок Успеновка, Центральная, 60	f	small
124176	92400	474	Тамбовская область, Петровский район, поселок Тынково, Центральная, 5	f	small
124181	92405	479	Тамбовская область, Петровский район, поселок Сестренка, Центральная, 26	f	small
124002	92097	209	Тамбовская область, Петровский район, поселок Сестренка, Центральная, 9	f	small
124390	92761	876	Тамбовская область, Петровский район, поселок Семеновка, Школьная, 5, Здание филиала МБОУ ТСОШ №2 в с. Семеновка	f	small
124192	92416	490	Тамбовская область, Петровский район, поселок Свинино, Молодежная, 9	f	medium
124171	92395	469	Тамбовская область, Петровский район, поселок Покровское, Советская, 14	f	small
124179	92403	477	Тамбовская область, Петровский район, поселок Покрово-Чичерино, Кооперативная, 72	f	small
124395	92766	881	Тамбовская область, Петровский район, поселок Петровское, Советская, 2, Здание филиала МБОУ ТСОШ №2	f	small
124119	92328	401	Тамбовская область, Петровский район, поселок Петровское, Приозерная, 27	f	small
76253	92393	467	Тамбовская область, Петровский район, поселок Петровское, Первомайская, 1Б	f	large
76254	92394	468	Тамбовская область, Петровский район, поселок Петровское, Моторина, 14	f	large
124400	92771	886	Тамбовская область, Петровский район, поселок Петровское, Молодежная, 47, Здание филиала МБОУ ТСОШ №2 в д. Петровское	f	small
76252	92392	466	Тамбовская область, Петровский район, поселок Петровское, Кооперативная, 7	f	large
124197	92421	495	Тамбовская область, Петровский район, поселок Песчаное, Центральная, 1А	f	small
124174	92398	472	Саратовская область, Ртищевский район, село Песковатка	f	small
124188	92412	486	Тамбовская область, Петровский район, поселок Озерки, Советская, 22	f	small
124185	92409	483	Тамбовская область, Петровский район, поселок Новоситовка, Садовая, 1	f	small
134049	90146	355	Смоленская область, Рославль, К.Маркса, 47-а	f	medium
124183	92407	481	Тамбовская область, Петровский район, поселок Новое Гаритово, Гагарина, 36	f	small
124184	95185	482	Тамбовская область, Петровский район, поселок Нарышкино, здание Успеновского сельского совета Петровского района	f	small
124200	92424	498	Тамбовская область, Петровский район, поселок Найденовка, здание Найденовского сельского филиала МБУК Петровского района Досуговый центр	f	small
124186	92410	484	Тамбовская область, Петровский район, поселок Малый Самовец, Школьная, 25	f	small
124173	92397	471	Тамбовская область, Петровский район, поселок Крутое, Советская, 18А	f	small
124199	92423	497	Тамбовская область, Петровский район, поселок Красный, Центральная, 18А	f	small
124175	92399	473	Тамбовская область, Петровский район, поселок Красиловка, Молодежная, 14	f	small
124403	92774	889	Тамбовская область, Петровский район, поселок Калиновка, Школьная, 15, Здание филиала МБОУ ТСОШ №1 в с. Калиновка	f	small
124195	92419	493	Республика Хакасия, Боградский район, село Знаменка	f	small
124132	92345	418	Тамбовская область, Петровский район, поселок Знаменка, Советская, 19	f	small
76153	92033	93	Тамбовская область, Петровский район, поселок Знаменка, Советская, 1	f	large
76450	92032	92	Тамбовская область, Петровский район, поселок Знаменка, Красная площадь, 6	f	large
124172	92396	470	Тамбовская область, Петровский район, поселок Дубовое, Центральная, 11	f	medium
124193	92417	491	Тамбовская область, Петровский район, поселок Волчки, Советская, 17	f	medium
124189	92413	487	Тамбовская область, Петровский район, поселок Большой Избердей, Пионерская, 44	f	small
124178	92402	476	Тамбовская область, Петровский район, поселок Большая Алексеевка, Колхозная, 10А	f	small
124194	92418	492	Тамбовская область, Петровский район, поселок Барановка, Полевая, 33	f	small
124159	92379	451	Тамбовская область, Первомайский район, поселок Чернышевка, Новая, 2	f	small
124015	92164	223	Тамбовская область, Первомайский район, Хоботово, здание школы	f	small
76250	92361	455	Тамбовская область, Первомайский район, поселок Хоботово, Лесная, 1	f	large
124170	92390	464	Тамбовская область, Первомайский район, поселок Хоботец-Васильевское, Школьная, 32	f	small
124165	92385	459	Тамбовская область, Первомайский район, поселок Хобот-Богоявленское, Интернациональная, 12	f	medium
124160	92380	452	Тамбовская область, Первомайский район, поселок Фонвизино, Школьная, 2а	f	small
76251	92391	465	Тамбовская область, Первомайский район, поселок Старосеславино, Советская, 111а	f	large
124166	92386	460	Тамбовская область, Первомайский район, поселок Старокозьмодемьяновское, Школьная, 18	f	medium
124156	92376	448	Тамбовская область, Первомайский район, поселок Старокленское, Пионерская, 41	f	medium
76244	92368	440	Тамбовская область, Первомайский район, поселок Первомайский, переулок Школьный, 3	f	large
76245	92369	441	Тамбовская область, Первомайский район, поселок Первомайский, Э.Тельмана, 5	f	large
123855	91966	19	Тамбовская область, Первомайский район, поселок Первомайский, Советская, 10	f	small
76247	92371	443	Тамбовская область, Первомайский район, поселок Первомайский, Дружбы, 6	f	large
76246	92370	442	Тамбовская область, Первомайский район, поселок Первомайский, Дружбы, 1а	f	large
124154	92374	446	Тамбовская область, Первомайский район, поселок Парижская Коммуна, Колхозная, 4а	f	small
124144	92358	431	Тамбовская область, Первомайский район, поселок Озерки, Центральная, 53	f	medium
124161	92381	453	Тамбовская область, Первомайский район, поселок Новоспасское, Набережная, 65	f	medium
124168	92388	462	Тамбовская область, Первомайский район, поселок Новосеславино, Школьная, 1	f	medium
124167	92387	461	Тамбовская область, Первомайский район, поселок Новокозьмодемьяновское, Школьная, 63	f	small
124155	92375	447	Тамбовская область, Первомайский район, поселок Новокленское, Советская, 51д	f	medium
124153	92373	445	Тамбовская область, Первомайский район, поселок Новоархангельское, Ленина, 1б	f	medium
124157	92377	449	Тамбовская область, Первомайский район, поселок Малый Снежеток, Центральная Усадьба, 31	f	medium
124164	92384	458	Тамбовская область, Первомайский район, поселок Иловай-Рождественское, Заречная, 30	f	medium
76248	92372	444	Тамбовская область, Первомайский район, поселок Иловай-Дмитриевское, Школьная, 1	f	large
83891	57330	3084	Москва, Зеленоград, к163	f	large
124163	92383	457	Тамбовская область, Первомайский район, поселок Иванжитово, Школьная, 1а	f	small
124158	92378	450	Тамбовская область, Первомайский район, поселок Змеевка, Совхозная, 20 б	f	small
76249	92320	454	Тамбовская область, Первомайский район, поселок Заводской, Заводская, 2	f	large
76241	92341	414	Тамбовская область, Никифоровский район, рп.Дмитриевка, Площадь Ленина, 6	f	large
124280	92528	600	Тамбовская область, Никифоровский район, поселок Ярославка, Центральная, 5	f	small
124134	92347	420	Тамбовская область, Никифоровский район, поселок Ярославка, Криворотченко, 153	f	medium
124148	92363	435	Тамбовская область, Никифоровский район, поселок Юрловка, площадь Советов, 18	f	medium
124143	92357	430	Тамбовская область, Никифоровский район, поселок Чебоксары, Молодежная, 37а	f	small
124150	92365	437	Тамбовская область, Никифоровский район, поселок Туровка, Тамбовская, 11	f	small
124133	92346	419	Тамбовская область, Никифоровский район, поселок Сычевка, Школьная, 1	f	small
124136	92349	422	Тамбовская область, Никифоровский район, поселок Степановка, Новая, 20	f	small
124141	92354	427	Тамбовская область, Никифоровский район, поселок Старое Сабурово, Зеленая, 19	f	small
76243	92356	429	Тамбовская область, Никифоровский район, поселок Свобода, Пушкина, 2	f	large
124142	92355	428	Тамбовская область, Никифоровский район, поселок Сабуро-Покровское, Красная, 51а	f	medium
124146	92360	433	Тамбовская область, Никифоровский район, поселок Машково-Сурена, Молодежная, 12	f	small
124149	92364	436	Тамбовская область, Никифоровский район, поселок Любезная, Редькино, 4	f	small
124135	92348	421	Тамбовская область, Никифоровский район, поселок Екатеринино, Советская, 47	f	medium
124152	92367	439	Тамбовская область, Никифоровский район, поселок Дмитриевка, Центральная, 13	f	small
123869	91980	35	Тамбовская область, Никифоровский район, поселок Дмитриевка, Центральная, 1	f	small
76240	92340	413	Тамбовская область, Никифоровский район, поселок Дмитриевка, Победы, 10	f	large
76459	92344	417	Тамбовская область, Никифоровский район, поселок Дмитриевка, Коммунальная, 14	f	large
124131	92343	416	Тамбовская область, Никифоровский район, ПГТ Дмитриевка, Заводская, 10	f	medium
124139	92352	425	Тамбовская область, Никифоровский район, поселок Гомзяки, Центральная, 3	f	small
124151	92366	438	Тамбовская область, Никифоровский район, поселок Голицыно, Молодежная, 37а	f	small
124137	92350	423	Тамбовская область, Никифоровский район, поселок Вырубово, Молодежная, 11а	f	small
124145	92359	432	Тамбовская область, Никифоровский район, поселок Восточная Старинка, Школьная, 2	f	small
124140	92353	426	Тамбовская область, Никифоровский район, поселок Богородицкое, Центральная, 1а	f	small
124130	92339	412	Тамбовская область, Мучкапский район, поселок Шапкино, переулок Коммунульный, 6	f	medium
124129	92338	411	Тамбовская область, Мучкапский район, поселок Шапкино, Интернациональная, 91	f	medium
124114	92323	396	Тамбовская область, Мучкапский район, поселок Чащино, Молодежная, 101	f	medium
124124	92333	406	Тамбовская область, Мучкапский район, поселок Троицкое, Центральная, 54	f	small
124162	92382	456	Тамбовская область, Мучкапский район, поселок Степанищево, Советская, 77	f	small
124115	92324	397	Тамбовская область, Мучкапский район, поселок Прудки, Октябрьская, 22	f	small
124125	92334	407	республика Башкортостан, Куюргазинский район, село Покровка	f	small
124117	92326	399	Тамбовская область, Мучкапский район, поселок Новосельцы, Центральная, 19	f	small
124120	92329	402	Тамбовская область, Мучкапский район, поселок Нижнее Чуево, Советская, 111	f	small
76458	92321	394	Тамбовская область, Мучкапский район, поселок Мучкапский, Свердлова, 15	f	large
76457	92318	392	Тамбовская область, Мучкапский район, поселок Мучкапский, Красная, 13	f	large
76239	92319	393	Тамбовская область, Мучкапский район, поселок Мучкапский, Заводская, 63	f	large
124127	92336	409	Тамбовская область, Мучкапский район, поселок Кулябовка, Советская, 9	f	medium
124113	92322	395	Тамбовская область, Мучкапский район, поселок Коростелево, Первомайская, 26	f	small
124123	92332	405	Тамбовская область, Мучкапский район, поселок Владимировка, Садовая, 24а	f	small
124128	92337	410	Тамбовская область, Мучкапский район, поселок Варварино, Клубная, 2	f	small
83890	57329	3083	Москва, Зеленоград, к142	f	large
124126	92335	408	Тамбовская область, Мучкапский район, поселок Березовка 1-я, Красная, 53а	f	small
124121	92330	403	Тамбовская область, Мучкапский район, поселок Арбеньевка, Малиновская, 4а	f	small
124116	92325	398	Тамбовская область, Мучкапский район, поселок Андриановка, Набережная, 2	f	medium
124325	92580	653	Тамбовская область, Мучкапский район, поселок Андреевка, Центральная, 50	f	small
76220	92276	348	Тамбовская область, Моршанский район, поселок Центральный, Школьная, 8а	f	large
124098	92282	355	Тамбовская область, Моршанский район, поселок Хлыстово, 97, Хлыстовский филиал МОУ Большекуликовской СОШ	f	small
76453	92289	362	Тамбовская область, Моршанский район, поселок Устьи, Центральная, 12	f	large
76454	92292	365	Тамбовская область, Моршанский район, поселок Устьи, Рабочая, 175а	f	large
76222	92293	366	Тамбовская область, Моршанский район, поселок Устьи, Октяборьская, 1а	f	large
76221	92290	363	Тамбовская область, Моршанский район, поселок Устьи, МСО, 4А	f	large
124103	92287	360	Тамбовская область, Моршанский район, поселок Старотомниково, Центральная, 111	f	small
124096	92281	353	Тамбовская область, Моршанский район, поселок Совхоз Базевский, Привокзальная, 15	f	small
124102	92286	359	Тамбовская область, Моршанский район, поселок Серповое, Центральная, 36	f	medium
124075	92256	328	Тамбовская область, Моршанский район, поселок Рысли, Центральная, 32а	f	small
124071	92252	324	Тамбовская область, Моршанский район, поселок Рыбное, Интернациональная, 4	f	small
124097	84195	354	Тамбовская область, Моршанский район, поселок Ракша, Центральная, 140	f	medium
124104	92288	361	Тамбовская область, Моршанский район, поселок Раево, Хлебная, 7	f	small
76452	92273	345	Тамбовская область, Моршанский район, поселок Пригородный, Новая, 1в	f	large
124074	92255	327	Тамбовская область, Моршанский район, поселок Погореловка, Молодежная, 17	f	small
124089	92270	342	Тамбовская область, Моршанский район, поселок Питерское, Молодежная, 15	f	small
124087	92268	340	Тамбовская область, Моршанский район, поселок Петровка, 39, отдел организации досуга населения	f	small
124101	92285	358	Тамбовская область, Моршанский район, поселок Пеньки, Центральная, 75	f	small
124082	92263	335	Тамбовская область, Моршанский район, поселок Парский Угол, Мира, 6б	f	small
124095	92280	352	Тамбовская область, Моршанский район, поселок Носины, Центральная, 125б	f	small
124094	92279	351	Тамбовская область, Моршанский район, поселок Новотомниково, Школьная, 21б	f	medium
124081	92262	334	Тамбовская область, Моршанский район, поселок Новоалександровка, 1-ая Заводская, 2	f	medium
124078	92259	331	Тамбовская область, Моршанский район, поселок Мутасьево, Лоскутовка, 32а	f	small
124072	92253	325	Тамбовская область, Моршанский район, Молодежный, 1, МУК ДК пос. Молодежный	f	small
124108	92296	369	Тамбовская область, Моршанский район, поселок Марусино, Марусинский филиал МОУ Устьинская СОШ	f	small
124091	92275	347	Тамбовская область, Моршанский район, поселок Малые Кулики, Ольховка, 37	f	small
124084	92265	337	Тамбовская область, Моршанский район, поселок Маломоршевка, Школьная, 14	f	small
124093	92278	350	Тамбовская область, Моршанский район, поселок Левино, Центральная, 74	f	small
76219	92272	344	Тамбовская область, Моршанский район, поселок Крюково, 60 лет СССР, 9	f	large
124106	92294	367	Тамбовская область, Моршанский район, поселок Коршуновка, здание Коршуновского ФАП МУЗ Карельская больница	f	small
123913	90611	89	Тамбовская область, Моршанский район, поселок Княжево, Центральная, 96	f	small
124092	92277	349	Тамбовская область, Моршанский район, поселок Кершинские Борки, Тамбовская, 18б	f	small
76218	92271	343	Тамбовская область, Моршанский район, поселок Карели, Новая, 4в	f	large
124088	92269	341	Тамбовская область, Моршанский район, поселок Ивенье, Ламзина, 15	f	medium
124107	92295	368	Тамбовская область, Моршанский район, поселок Зеленый Луг, клуб Моршанского Психоневрологического интерната	f	small
124100	92284	357	Тамбовская область, Моршанский район, поселок Зеленый Бор, Колхозна, 1	f	small
124073	92254	326	Тамбовская область, Моршанский район, поселок Дьячи, Зеленая, 4а	f	small
124099	92283	356	Тамбовская область, Моршанский район, поселок Давыдово, 1-ая Лимасово, 9	f	small
124083	92264	336	Тамбовская область, Моршанский район, поселок Вяжли, Школьная, 18а	f	medium
124209	92432	507	Тамбовская область, Моршанский район, поселок Вяжли, Центральная, 5	f	small
124080	92261	333	Тамбовская область, Моршанский район, поселок Веселое, Школьная, 1	f	medium
124079	92260	332	Тамбовская область, Моршанский район, поселок Ваново, Советская, 10	f	medium
124090	92274	346	Тамбовская область, Моршанский район, поселок Быковка, Заря, 37	f	small
124077	92258	330	Тамбовская область, Моршанский район, поселок Алкужинские Борки, Центральная, 119а	f	small
124076	92257	329	Тамбовская область, Моршанский район, поселок Алкужи, Новая, 17	f	small
124070	92251	323	Тамбовская область, Моршанский район, поселок Алгасово, Ильинка, 24	f	medium
76217	92250	322	Тамбовская область, Моршанский район, поселок Алгасово, Гоголя, 6а	f	large
124069	92249	321	Тамбовская область, Мордовский район, поселок Шульгино, 24, здание Шульгинского Дома культуры	f	medium
124065	92245	317	Тамбовская область, Мордовский район, поселок Шмаровка, Центральная, 23, здание Шмаровского филиала МБОУ Оборонинская СОШ	f	small
124050	92228	300	Тамбовская область, Мордовский район, поселок Центральное отделение совхоза имени Ленина, Луговая , 1а, здание Ленинского филиала МБОУ Новопокровская СОШ	f	medium
124068	92248	320	Тамбовская область, Мордовский район, поселок Хоперка, 41, здание Хоперского филиала МБОУ Новопокровская СОШ	f	small
124045	92222	295	Тамбовская область, Мордовский район, поселок Плоское, 3, здание Плоскинского филиала МБОУ Новопокровская СОШ	f	small
124041	92217	291	Тамбовская область, Мордовский район, поселок Отрада, 126, бывшее здание Отрадовского филиала МОУ Оборонинская СОШ	f	small
124063	92243	315	Тамбовская область, Мордовский район, поселок Новопокровка, Школьная, 14, здание МБОУ Новопокровская СОШ	f	medium
124060	92240	312	Тамбовская область, Мордовский район, поселок Новопокровка, Техническая, 11, здание Калининского филиала МБОУ Новопокровская СОШ	f	small
124061	92241	313	Тамбовская область, Мордовский район, поселок Новопокровка, Революционная, 3, здание администрации Новопокровского поссовета	f	small
124062	92242	314	Тамбовская область, Мордовский район, поселок Новопокровка, Кирпичная, 1А, административное здание ООО Строма-5	f	medium
123663	92219	292	Тамбовская область, Мордовский район, поселок Николо-Сергеевка, здание Николо-Сергиевского дома досуга	f	small
124053	92232	304	Тамбовская область, Мордовский район, поселок Мордово, Школьная, 8, здание №1 МБОУ «Оборонинская СОШ» (ул.Школьная, 8)	f	medium
76480	92231	303	Тамбовская область, Мордовский район, поселок Мордово, Техническая, 40, здание МБДОУ Детский сад Солнышко	f	large
124054	92233	305	Тамбовская область, Мордовский район, поселок Мордово, Пятилетка, 53, Административное здание ТОГУ Мордовская районная станция по борьбе с болезнями животных	f	medium
124057	92237	309	Тамбовская область, Мордовский район, поселок Мордово, Интернациональная, 4б, здание №2 МБОУ Оборонинская СОШ	f	medium
124056	92236	308	Тамбовская область, Мордовский район, поселок Мордово, 70 лет Октября, 6а, бывшее административное здание СХПК Дружба	f	small
76451	92235	307	Тамбовская область, Мордовский район, поселок Мордово, 2-я Революционная, 77, здание администрации Мордовского поссовета	f	large
124055	92234	306	Тамбовская область, Мордовский район, поселок Мордово, 1-я Революционная, 18, здание МБОУДОД Районный Дом детского творчества	f	medium
124049	92227	299	Тамбовская область, Мордовский район, поселок Лаврово, Здание администрации Лавровского сельсовета	f	medium
124067	92247	319	Тамбовская область, Мордовский район, поселок Лавровка, Здание Лавровского СДК	f	small
124066	92246	318	Тамбовская область, Мордовский район, поселок Кужное, Школьная, 2а, здание Кужновского филиала МБОУ Оборонинская СОШ	f	medium
124047	92224	297	Тамбовская область, Мордовский район, поселок Карпели, Центральная, 22, здание администрации Карпельского сельсовета	f	small
123668	92226	298	Тамбовская область, Мордовский район, поселок Борисовка, Бывшее здание Борисовского филиала МОУ Оборонинская СОШ	f	small
124043	92220	293	Тамбовская область, Мордовский район, поселок Большая Даниловка, 16, здание администрации Большеданиловского сельсовета	f	small
124058	92238	310	Тамбовская область, Мордовский район, поселок Ахматово, 5, здание Ахматовского Дома досуга	f	small
124006	92155	214	Тамбовская область, Мичуринский район, поселок Ярок, Советская, 40	f	small
124029	92176	237	Тамбовская область, Мичуринский район, поселок Центральное отделение совхоза имени Мичурина, Горького, 6а	f	small
124000	92149	205	Тамбовская область, Мичуринский район, поселок Устье, Советская, 184	f	medium
124028	92175	236	Тамбовская область, Мичуринский район, поселок Турмасово, Исакова, 123	f	medium
123996	92145	201	Тамбовская область, Мичуринский район, поселок Терское, Поперечная, 9	f	medium
124013	92162	221	Тамбовская область, Мичуринский район, поселок Терновое, Советская, 2	f	small
123998	92147	203	Тамбовская область, Мичуринский район, поселок Старое Хмелевое, Белаховой, 78	f	medium
124004	92153	212	Тамбовская область, Мичуринский район, поселок Старое Тарбеево, Советская, 3	f	small
124007	92156	215	Тамбовская область, Мичуринский район, поселок Старая Казинка, Рахманинова, 16	f	medium
76178	90928	211	Тамбовская область, Мичуринский район, поселок Стаево, Красноармейская, 7	f	large
124009	92158	217	Тамбовская область, Мичуринский район, поселок Совхоз Зеленый Гай, Центральная, 10	f	medium
124024	92173	232	Тамбовская область, Мичуринский район, поселок Совхоз Глазковский, Центральная, 8	f	small
124011	92160	219	Тамбовская область, Мичуринский район, поселок Ранино, Революционная, 26а	f	small
123992	92138	194	Тамбовская область, Мичуринский район, поселок Панское, Луговая, 28	f	medium
124030	92177	238	Тамбовская область, Мичуринский район, поселок Отделение Садострой, Спортивная, 1	f	small
124032	92179	240	Тамбовская область, Мичуринский район, поселок Отделение Коммунар	f	small
124014	92163	222	Тамбовская область, Мичуринский район, поселок Остролучье, Коммунистическая, 41	f	small
76475	92152	208	Тамбовская область, Мичуринский район, поселок Новоникольское, Советская, 23	f	large
76177	92151	207	Тамбовская область, Мичуринский район, поселок Новоникольское, Максима Горького, 1а	f	large
123999	92148	204	Тамбовская область, Мичуринский район, поселок Новое Хмелевое, Замостье, 58	f	small
124008	92157	216	Тамбовская область, Мичуринский район, поселок Новое Тарбеево, Центральная, 100	f	small
124012	92161	220	Тамбовская область, Мичуринский район, поселок Мичуринский лесоучасток, Лесная, 17	f	small
124005	92154	213	Тамбовская область, Мичуринский район, поселок Липовка, Липовская, 26	f	small
123997	92146	202	Тамбовская область, Мичуринский район, поселок Крюковка, Леонова, 4	f	small
124026	84017	234	Тамбовская область, Мичуринский район, поселок Круглое, Центральная, 57а	f	medium
124021	92170	229	Тамбовская область, Мичуринский район, поселок Красивое, Коммунальная, 51	f	medium
124398	92769	884	Тамбовская область, Мичуринский район, поселок Кочетовка, Центральная, 5, Здание филиала МБОУ ТСОШ №1 в с. Кочетовка	f	small
124019	92168	227	Тамбовская область, Мичуринский район, поселок Кочетовка, Центральная, 20	f	small
124018	92167	226	Тамбовская область, Мичуринский район, поселок Кочетовка, Центральная, 19	f	small
124177	92401	475	Тамбовская область, Мичуринский район, поселок Кочетовка, Мира, 48	f	small
123993	92139	195	Тамбовская область, Мичуринский район, поселок Коминтерн, Парковая, 8	f	medium
124365	92709	823	Тамбовская область, Мичуринский район, поселок Имени Калинина, микрорайон Южный, 2Б	f	medium
123995	92144	200	Тамбовская область, Мичуринский район, поселок Имени Калинина, Школьная, 2	f	medium
124031	92178	239	Тамбовская область, Мичуринский район, поселок Изосимово, Ворошилова, 47	f	medium
123994	92143	199	Тамбовская область, Мичуринский район, поселок Заворонежское, Строителей, 25	f	medium
76176	92142	198	Тамбовская область, Мичуринский район, поселок Заворонежское, Советская, 136	f	large
76175	92141	197	Тамбовская область, Мичуринский район, поселок Заворонежское, Советская, 121	f	large
76174	92140	196	Тамбовская область, Мичуринский район, поселок Заворонежское, Советская, 89	f	large
124010	92159	218	Тамбовская область, Мичуринский район, поселок Жидиловка, Советская, 13	f	small
124017	92166	225	Тамбовская область, Мичуринский район, поселок Гостеевка, Заречная, 16а	f	small
124025	91924	233	Тамбовская область, Мичуринский район, поселок Гололобовка, Школьная, 7	f	medium
124023	92172	231	Тамбовская область, Мичуринский район, поселок Глазок, Пушкина, 7	f	medium
124022	92171	230	Тамбовская область, Мичуринский район, поселок Глазок, Пушкина, 1	f	medium
83889	57329	3082	Москва, Зеленоград, к142	f	large
124001	92150	206	Тамбовская область, Мичуринский район, поселок Борщевое, Центральная, 110	f	medium
124003	92132	210	Тамбовская область, Мичуринский район, поселок Большая Сосновка, Ленина, 37	f	small
124147	92362	434	Тамбовская область, Мичуринский район, поселок Александровка, Советская, 1а	f	small
124016	92165	224	Тамбовская область, Мичуринский район, поселок 2-я Пятилетка, Молодежная, 1	f	small
124027	92174	235	Тамбовская область, Котовск городской округ, поселок Лесная Опушка, Лесная, 14а	f	small
76159	92085	144	Тамбовская область, Кирсановский район, поселок Шиновка, здание филиала МБОУ Уваровщинской СОШ в селе Шиновка	f	large
123970	92096	153	Тамбовская область, Кирсановский район, поселок Чутановка, Октябрьская, 67, здание Дома культуры	f	small
124389	92760	875	Тамбовская область, Кирсановский район, поселок Федоровка, Центральная, 2, Здание филиала МБОУ ТСОШ №2 в д. Федоровка	f	small
123979	92108	164	Тамбовская область, Кирсановский район, поселок Тоновка, Кирова, 1в, здание Дома культуры	f	medium
123964	92088	147	Тамбовская область, Кирсановский район, поселок Сурки, Заброд, 28, здание библиотеки	f	small
123976	92103	159	Тамбовская область, Кирсановский район, поселок Соколово, Центральная, 5, здание Соколовского дома культуры	f	small
123631	92092	150	Тамбовская область, Кирсановский район, поселок Свищевка, здание Свищевского фельдшерско-акушерского пункта	f	small
123978	92105	161	Тамбовская область, Кирсановский район, поселок Садовый, Зеленая, 54, дание филиала МБОУ Уваровщинской СОШ п.Садовый	f	small
123972	92099	155	Нижегородская область, Сергачский район, село Рамза	f	small
76160	92109	165	Тамбовская область, Кирсановский район, поселок Прямица, Строителей, 5	f	large
123977	92104	160	Тамбовская область, Кирсановский район, поселок Полевой, Набережная, 3, здание дома культуры	f	small
123974	92101	157	Тамбовская область, Кирсановский район, поселок Подвигаловка, Советская, 22, здание Дома культуры	f	small
123899	92017	74	Тамбовская область, Кирсановский район, поселок Петровка, Юбилейная, 9	f	small
124375	92724	838	Тамбовская область, Кирсановский район, поселок Орловка, Полякова, 1А	f	medium
123975	92102	158	Тамбовская область, Кирсановский район, село Ольшановка, Садовая , 2, здание Березовского сельского клуба	f	small
123704	92095	152	Тамбовская область, Кирсановский район, поселок Овсяновка, здание Екатериновского дома культуры	f	small
123962	92086	145	Тамбовская область, Кирсановский район, поселок Молоканщина, Рабочая, 6, передвижное помещение, установленное напротив домовладения 	f	medium
124059	92239	311	Тамбовская область, Кирсановский район, поселок Михайловка, 140, здание Михайловского филиала МБОУ «Новопокровская СОШ»	f	small
123879	91997	53	Тамбовская область, Кирсановский район, поселок Михайловка, Центральная, 51	f	small
123966	92090	149	Тамбовская область, Кирсановский район, поселок Мирный, Мирная, 1, здание клуба закрытого акционерного общества Ковыльское	f	small
123971	92098	154	Тамбовская область, Кирсановский район, поселок Марьинка, Дорожная, 67, административное здание Марьинского сельсовета	f	small
123968	92093	151	Тамбовская область, Кирсановский район, поселок Ленинское, Новая, 15в, здание дома культуры	f	medium
123965	92089	148	Тамбовская область, Кирсановский район, поселок Краснослободский, Железнодорожная, 12, здание Дома культуры	f	medium
76470	92106	162	Тамбовская область, Кирсановский район, поселок Компрессорная, Газопроводская, 27, здание клуба	f	large
123963	92087	146	Тамбовская область, Кирсановский район, поселок Кобяки, Гордеевка, 36, здание Дома культуры	f	small
123991	92122	179	Тамбовская область, Кирсановский район, Кирсанов, колледж ГА	f	medium
76163	92124	181	Тамбовская область, Кирсановский район, Кирсанов, Школьная, 21	f	large
123988	92117	174	Тамбовская область, Кирсановский район, Кирсанов, Спортивная, 13	f	medium
123983	92113	169	Тамбовская область, Кирсановский район, Кирсанов, Советская, 25	f	medium
123980	92110	166	Тамбовская область, Кирсановский район, Кирсанов, Советская, 3	f	medium
123985	92114	171	Тамбовская область, Кирсановский район, Кирсанов, Рабоче-Крестьянская, 50	f	medium
123981	92111	167	Тамбовская область, Кирсановский район, Кирсанов, Рабоче-Крестьянская, 35	f	medium
123989	92118	175	Тамбовская область, Кирсановский район, Кирсанов, Пушкинская, 29	f	medium
123986	92115	172	Тамбовская область, Кирсановский район, Кирсанов, Пушкинская, 56	f	medium
76472	92120	177	Тамбовская область, Кирсановский район, Кирсанов, Моршанский тракт, 17	f	large
76162	92123	180	Тамбовская область, Кирсановский район, Кирсанов, Микрорайон №1, 15	f	large
123990	92119	176	Тамбовская область, Кирсановский район, Кирсанов, Интернациональная, 15	f	medium
76161	92121	178	Тамбовская область, Кирсановский район, Кирсанов, Заводской, 1 Б	f	large
123982	92112	168	Тамбовская область, Кирсановский район, Кирсанов, 50 лет Победы, 23	f	medium
123984	92082	170	Тамбовская область, Кирсановский район, Кирсанов, 50 лет Победы, 27	f	medium
123961	92084	143	Тамбовская область, Кирсановский район, поселок Калаис, административное здание Калаисского сельсовета	f	medium
123960	92083	142	Тамбовская область, Кирсановский район, поселок Калаис, Подвячка, 1а, здание филиала МБОУ Уваровщинской СОШ в с.Калаис	f	small
123958	92080	140	Тамбовская область, Кирсановский район, поселок Иноковка 2-я, Верхняя Луговка, 14а, здание Дома культуры	f	small
123957	92079	139	Тамбовская область, Кирсановский район, поселок Иноковка 1-я, Площадь, 1б, здание Дома культуры	f	small
76158	92077	137	Тамбовская область, Кирсановский район, поселок Голынщина, 79 А, здание Поселенческого центра досуга Голынщинского сельсовета	f	large
123956	92078	138	Тамбовская область, Кирсановский район, поселок Голынщина, Приовражная, 21	f	medium
123959	92081	141	Тамбовская область, Кирсановский район, поселок Вячка, Городок, 67, здание филиала МБОУ Уваровщинской СОШ в с.Вячка	f	small
76471	92107	163	Тамбовская область, Кирсановский район, поселок Большая Уваровщина, 1а, здание МОУ Уваровщинской СОШ	f	large
123948	92069	129	Тамбовская область, Инжавинский район, поселок Юбилейный, Центральная, 35	f	small
123941	92062	122	Тамбовская область, Инжавинский район, поселок Чернавка, Чапаевская, 22	f	small
123938	92059	119	Тамбовская область, Инжавинский район, поселок Хорошавка, Набережная, 269	f	small
123944	92065	125	Тамбовская область, Инжавинский район, поселок Филатовский, Молодежная, 4, Марьевский сельсовет	f	small
123933	92053	113	Тамбовская область, Инжавинский район, поселок Соболевка, Соболевка, 34, Калугинский сельсовет	f	small
124258	92507	578	Тамбовская область, Инжавинский район, поселок Семеновка, Центральная, 12	f	small
123922	92043	103	Тамбовская область, Инжавинский район, поселок Семеновка, Центральная, 45	f	small
123942	92063	123	Тамбовская область, Инжавинский район, поселок Сатино, Центральная, 5	f	small
123937	92058	118	Тамбовская область, Инжавинский район, поселок Плодопитомник, Садовая, 9	f	medium
123925	92046	106	Тамбовская область, Инжавинский район, поселок Паревка, Центральная, 41	f	small
123953	92074	134	Тамбовская область, Инжавинский район, поселок Павловка, Центральная, 66	f	small
123781	92045	105	Тамбовская область, Инжавинский район, поселок Ольховка, Краснофлотская, 23	f	small
124376	92725	839	Тамбовская область, Инжавинский район, поселок Новая Жизнь, Молодежная, 22	f	small
123946	92067	127	Тамбовская область, Инжавинский район, поселок Николино, Школьная, 1	f	small
123923	92044	104	Тамбовская область, Инжавинский район, поселок Никитино, Молодежная, 2, Никитинский сельсовет	f	small
123954	92075	135	Тамбовская область, Инжавинский район, поселок Михайловка, Петровка, 39	f	small
123934	92054	114	Тамбовская область, Инжавинский район, поселок Лопатино, Богачевская, 7	f	small
123943	92064	124	Тамбовская область, Инжавинский район, поселок Ломовка, Центральная, 46	f	small
123955	92076	136	Тамбовская область, Инжавинский район, поселок Леонтьевка, Калиновка, 16	f	small
123931	92051	111	Тамбовская область, Инжавинский район, поселок Лебедевка, Якова Синева, 56	f	small
123767	92049	109	Тамбовская область, Инжавинский район, поселок Курдюки, Курдюковская, 29	f	small
123945	92066	126	Тамбовская область, Инжавинский район, поселок Кулевча, Кирова, 95	f	small
76157	92057	117	Тамбовская область, Инжавинский район, поселок Красивка, Советская, 18, Красивский сельсовет	f	large
123935	92055	115	Тамбовская область, Инжавинский район, поселок Кишкино, Поселковая, 6а	f	small
123940	92061	121	Тамбовская область, Инжавинский район, поселок Караул, Садовая, 56	f	small
123936	92056	116	Тамбовская область, Инжавинский район, поселок Карандеевка, Карандеевская, 92	f	small
123951	92072	132	Тамбовская область, Инжавинский район, поселок Карай-Салтыково, пер. Школьный, 2, Карай- Салтыковский сельсовет	f	medium
123950	92071	131	Тамбовская область, Инжавинский район, поселок Карай-Салтыково, Высотная, 4, Карай- Салтыковский сельсовет	f	small
123952	92073	133	Тамбовская область, Инжавинский район, поселок Карай-Пущино, Центральная, 97а, Карай-Салтыковский сельсовет	f	small
123930	92050	110	Тамбовская область, Инжавинский район, поселок Караваино, Школьная, 8, Караваинский сельсовет	f	small
123932	92052	112	Тамбовская область, Инжавинский район, поселок Калугино, Школьная, 15	f	small
123920	92041	101	Тамбовская область, Инжавинский район, поселок Инжавино, Техническая, 4, Инжавинский поссовет	f	medium
123918	92038	98	Тамбовская область, Инжавинский район, поселок Инжавино, Советская, 15, Инжавинский поссовет	f	medium
123917	92037	97	Тамбовская область, Инжавинский район, поселок Инжавино, Советская, 19	f	medium
76155	92036	96	Тамбовская область, Инжавинский район, поселок Инжавино, Советская, 56, Инжавинский поссовет	f	large
123916	92035	95	Тамбовская область, Инжавинский район, поселок Инжавино, Рылеева, 6	f	medium
76156	92039	99	Тамбовская область, Инжавинский район, поселок Инжавино, Лунина, 2	f	large
123921	92042	102	Тамбовская область, Инжавинский район, поселок Инжавино, Карла Маркса, 4	f	medium
123919	92040	100	Тамбовская область, Инжавинский район, поселок Инжавино, Белинского, 21	f	medium
123927	92048	108	Тамбовская область, Инжавинский район, поселок Ивановка, Молодежная, 1	f	small
123926	92047	107	Тамбовская область, Инжавинский район, поселок Землянский, Школьная, 15, Землянский сельсовет	f	medium
123947	92068	128	Тамбовская область, Инжавинский район, поселок Екатеринополье, Школьная, 31, Балыклейский сельсовет	f	small
123939	92060	120	Тамбовская область, Инжавинский район, поселок Грушевка, Центральная, 25, Караульский сельсовет	f	small
123949	92070	130	Тамбовская область, Инжавинский район, поселок Балыклей, Центральная, 4	f	medium
124240	92467	543	Тамбовская область, Инжавинский район, поселок Алексеевка, Школьная, 8	f	small
124085	92266	338	Тамбовская область, Инжавинский район, поселок Алексеевка, Школьная, 133	f	small
123885	92003	59	Тамбовская область, Инжавинский район, поселок Алексеевка, Советская, 10	f	medium
123914	90728	90	Тамбовская область, Знаменский район, поселок Сухотинка, Суренка	f	small
123912	92031	88	Тамбовская область, Знаменский район, поселок Сухотинка, Молодежная, 14	f	medium
123907	92026	83	Тамбовская область, Знаменский район, поселок Совхоз Кузьминский, Школьная, 29	f	small
123909	92028	85	Тамбовская область, Знаменский район, поселок Покрово-Марфино, Дзержинского, 1	f	medium
76152	92023	80	Тамбовская область, Знаменский район, поселок Первомайское, Школьная, 1а	f	large
123910	92029	86	Тамбовская область, Знаменский район, поселок Новознаменка, Центральная, 128	f	medium
123908	92027	84	Тамбовская область, Знаменский район, поселок Михайловка, Центральная, 18	f	small
123906	92025	82	Тамбовская область, Знаменский район, поселок Кариан, Московская, 30	f	small
123902	92020	77	Тамбовская область, Знаменский район, поселок Измайловка, Победы, 15	f	small
76154	92034	94	Тамбовская область, Знаменский район, поселок Знаменка, Гагарина, 8 А	f	large
123905	92024	81	Тамбовская область, Знаменский район, поселок Дуплятово-Маслово, Гагарина, 29	f	medium
123904	92022	79	Тамбовская область, Знаменский район, поселок Даниловка, Школьная, 84 А	f	small
123903	92021	78	Тамбовская область, Знаменский район, поселок Воронцовка, Сергеева, 24	f	medium
124020	92169	228	Тамбовская область, Знаменский район, поселок Александровка, Зеленая, 49	f	small
123893	90501	68	Тамбовская область, Жердевский район, поселок Шпикулово, Школьная, 12	f	medium
123890	92009	65	Тамбовская область, Жердевский район, поселок Чикаревка, Центральная, 33	f	small
123881	91999	55	Тамбовская область, Жердевский район, поселок Цветовка, Центральная, 7	f	small
76151	92006	62	Тамбовская область, Жердевский район, поселок Туголуково, Фиолетова, 21	f	large
123886	92004	60	Тамбовская область, Жердевский район, поселок Сукмановка, Международная, 1	f	medium
123898	92016	73	Тамбовская область, Жердевский район, поселок Степной, Трудовая, 96	f	small
134048	90143	352	Смоленская область, Рославль, Заслонова, 2	f	large
124046	92223	296	Тамбовская область, Жердевский район, поселок Степной, Школьная, .12, здание Степновского филиала МБОУ «Новопокровская СОШ»	f	medium
123882	92000	56	Тамбовская область, Жердевский район, поселок Садовый, Вишневая, 7	f	small
123878	91996	52	Тамбовская область, Жердевский район, поселок Рымарево, Трудовая, 14а	f	small
123883	92001	57	Тамбовская область, Жердевский район, поселок Пичаево, Центральная, 19	f	medium
124215	92439	514	Тамбовская область, Жердевский район, поселок Пичаево, Ленинская, 1	f	medium
123884	92002	58	Тамбовская область, Жердевский район, поселок Питим, Кировская, 6	f	medium
123888	92007	63	Тамбовская область, Жердевский район, поселок Петровское, Кропоткина, 60	f	small
124423	92794	909	Тамбовская область, Жердевский район, поселок Павлодар, Центральная, 106з	f	small
123896	92014	71	Тамбовская область, Жердевский район, поселок Новый Свет 1-й, Луговая, 34	f	small
123880	91998	54	Тамбовская область, Жердевский район, поселок Новорусаново, Центральная, 63	f	medium
123895	92013	70	Тамбовская область, Жердевский район, поселок Максим Горький, Мира, 238	f	small
123889	92008	64	Тамбовская область, Жердевский район, поселок Искра, Зеленая, 27	f	small
123875	91993	49	Тамбовская область, Жердевский район, Жердевка, Энгельса, 43	f	small
76149	90486	46	Тамбовская область, Жердевский район, Жердевка, Чкалова, 19а	f	large
123873	91988	43	Тамбовская область, Жердевский район, Жердевка, Тухачевского, 5	f	small
76148	91990	45	Тамбовская область, Жердевский район, Жердевка, Серова, 1	f	large
76145	91986	41	Тамбовская область, Жердевский район, Жердевка, Семашко, 7а	f	large
76143	91984	39	Тамбовская область, Жердевский район, Жердевка, Первомайская, 124	f	large
76144	91985	40	Тамбовская область, Жердевский район, Жердевка, Нагорная	f	large
76146	91987	42	Тамбовская область, Жердевский район, Жердевка, Кировская, 44	f	large
123874	91992	48	Тамбовская область, Жердевский район, Жердевка, Интернациональная, 3	f	medium
76150	91991	47	Тамбовская область, Жердевский район, Жердевка, Интернациональная, 8	f	large
76147	91989	44	Тамбовская область, Жердевский район, Жердевка, Заводская, 28	f	large
123897	92015	72	Тамбовская область, Жердевский район, поселок Демьян Бедный, Мира, 25	f	medium
123900	92018	75	Тамбовская область, Жердевский район, поселок Григорьевка, Северный микрарайон, 10	f	small
123891	92010	66	Тамбовская область, Жердевский район, поселок Вязовое, Жукова, 57	f	small
123876	91994	50	Тамбовская область, Жердевский район, поселок Бурнак, Свободы, 27а	f	medium
123877	91995	51	Тамбовская область, Жердевский район, поселок Бурнак, Колхозная, 21в	f	medium
123862	91972	28	Тамбовская область, Жердевский район, поселок Булгаково, Торговая, 2	f	small
123730	91973	29	Тамбовская область, Гавриловский район, д.Синявка-1, 1а, Здание ФАП	f	small
123865	91976	31	Тамбовская область, Гавриловский район, поселок Чуповка, Заречная, 16	f	small
123872	91983	38	Тамбовская область, Гавриловский район, поселок Станция Рожковка, Центральная, 2	f	small
123860	91950	26	Тамбовская область, Гавриловский район, поселок Пересыпкино 2-е, Поповка, 8	f	medium
76449	91908	25	Тамбовская область, Гавриловский район, поселок Пересыпкино 1-е, Гагарина, 12	f	large
123868	91979	34	Тамбовская область, Гавриловский район, поселок Осино-Гай, Центральная, 3	f	small
124431	92802	917	Саратовская область, Аркадакский район, село Ольшанка	f	small
123866	91977	32	Тамбовская область, Гавриловский район, поселок Ольшанка, Новая, 240а	f	small
123867	91978	33	Тамбовская область, Гавриловский район, поселок Кондаурово, Бурчановка, 80г	f	small
123864	91975	30	Тамбовская область, Гавриловский район, поселок Гусевка, Прудная, 4	f	small
123871	91982	37	Тамбовская область, Гавриловский район, поселок Глуховка, Молодежная, 7	f	small
76448	91969	22	Тамбовская область, Гавриловский район, поселок Гавриловка 2-я, Школьная, 3	f	large
123859	91848	24	Тамбовская область, Гавриловский район, поселок Гавриловка 1-я, Гагарина, 28	f	medium
123870	91981	36	Тамбовская область, Гавриловский район, поселок Анненка, Новая, 32, здание Анненского филиала МБОУ 2-Гавриловской СОШ	f	small
123848	91960	12	Тамбовская область, Бондарский район, поселок Шача Молоканская, Школьная , 3	f	small
123840	91952	4	Тамбовская область, Бондарский район, поселок Строительный, Молодежная, 2	f	small
123839	91951	3	Тамбовская область, Бондарский район, поселок Совхоз Бондарский, Совхозная, 33	f	medium
123857	91968	21	Тамбовская область, Бондарский район, поселок Прибытки, Центральная, 73	f	small
123854	91965	18	Тамбовская область, Бондарский район, поселок Пахотный Угол, Октябрьская, 2	f	medium
123853	91965	17	Тамбовская область, Бондарский район, поселок Пахотный Угол, Октябрьская, 2	f	small
124402	92773	888	Тамбовская область, Бондарский район, поселок Павловка, Молодежная, 35, Здание филиала МБОУ ТСОШ №1 в с. Павловка	f	small
124051	92229	301	Тамбовская область, Бондарский район, поселок Павловка, Ильменовка, 42, здание Павловского филиала МБОУ «Новопокровская СОШ»	f	small
123852	91964	16	Тамбовская область, Бондарский район, поселок Озерный, Совхозная, 2	f	small
123849	91961	13	Тамбовская область, Бондарский район, поселок Митрополье, Школьная, 17	f	small
123847	91959	11	Тамбовская область, Бондарский район, поселок Малое Гагарино, Молодежная, 8	f	small
123846	91958	10	Тамбовская область, Бондарский район, поселок Максимовка, Максимовка, 40а	f	small
123845	91957	9	Тамбовская область, Бондарский район, поселок Куровщина, Центральная, 40	f	small
123843	91955	7	Тамбовская область, Бондарский район, поселок Кривополянье, Советская, 51	f	small
123850	91962	14	Тамбовская область, Бондарский район, поселок Коровино, Центральная, 99	f	small
123842	91954	6	Тамбовская область, Бондарский район, поселок Керша, Школьная, 2	f	medium
123841	91953	5	Тамбовская область, Бондарский район, поселок Граждановка, Центральная, 8	f	medium
123844	91956	8	Тамбовская область, Бондарский район, поселок Городище, Набережная, 72	f	small
124260	92509	580	Тамбовская область, Бондарский район, поселок Волхонщино, Советская, 25	f	small
123851	91963	15	Тамбовская область, Бондарский район, Верхнее Нащекино, Кольцевая, 14	f	medium
123856	91967	20	Тамбовская область, Бондарский район, поселок Вердеревщино, Центральная, 146	f	medium
76445	91949	2	Тамбовская область, Бондарский район, поселок Бондари, Советская, 4	f	large
76142	91948	1	Тамбовская область, Бондарский район, поселок Бондари, Октябрьская, 9	f	large
124449	92834	949	Тамбовская область, Бондарский район, поселок 1-й участок Пахотно-Угловского лесничества, Совхозная, 29, административное здание СПК &quot;&quot;&quot;&quot;Софьинский&quot;&quot;&quot;&quot;&quot;&quot;&quot;	f	small
76128	90553	780	Смоленская область, Ярцево, пр-кт Металлургов, 25, средняя общеобраз.школа №7	f	large
76132	90559	786	Смоленская область, Ярцево, Энтузиастов, 33, Центр досуга Современник	f	large
123396	90564	791	Смоленская область, Ярцево, Энгельса, 1, основная общеобраз.школа №5	f	medium
123395	90563	790	Смоленская область, Ярцево, Шоссейная, 21	f	medium
76137	90567	794	Смоленская область, Ярцево, Школьный переулок, 8, Центр детского творчества	f	large
76136	90566	793	Смоленская область, Ярцево, Школьная, 11, средняя общеобраз.школа №1	f	large
123398	90571	798	Смоленская область, Ярцево, Центральная, 14, Фил.МУК ЯРЦКИ-клуб п.Пологи	f	small
123393	90555	782	Смоленская область, Ярцево, Тургенева, 33	f	small
76126	90551	778	Смоленская область, Ярцево, Старозавопье, 15, средняя общеобраз.школа №10	f	large
76125	90551	777	Смоленская область, Ярцево, Старозавопье, 15, средняя общеобраз.школа №10	f	large
76121	90547	773	Смоленская область, Ярцево, Советская, 26а, Центр по библиот.раб.с детьми	f	large
76117	90543	769	Смоленская область, Ярцево, Пугачева, 3, Ярцевск.индустриальн. техникум	f	large
76134	90561	788	Смоленская область, Ярцево, Победы, 1	f	large
76131	90558	785	Смоленская область, Ярцево, Ольховская, 1а, Центр досуга Современник	f	large
76138	90568	795	Смоленская область, Ярцево, Октябрьская, 8, НОУ Ярцевская АШ ДОСААФ России	f	large
76127	90552	779	Смоленская область, Ярцево, Металлургов проспект, 19а, средняя общеобраз.школа №8	f	large
123394	90562	789	Смоленская область, Ярцево, Макаренко, 3, школа-интернат для детей-сирот	f	medium
76124	90550	776	Смоленская область, Ярцево, Лесная, 1а	f	large
123397	90570	797	Смоленская область, Ярцево, Кузнецова, 56	f	medium
76119	90545	771	Смоленская область, Ярцево, Интернациональная, 5, средняя обшеобраз.школа №4	f	large
123392	90554	781	Смоленская область, Ярцево, Дачная, 20, Ярцевский геронтологич. центр	f	medium
76123	90549	775	Смоленская область, Ярцево, Гагарина, 52, средняя общеобраз.школа №2	f	large
76130	90557	784	Смоленская область, Ярцево, Автозаводская, 18, средняя общеобраз.школа №9	f	large
76129	90556	783	Смоленская область, Ярцево, Автозаводская, 32, Детская музыкальная школа	f	large
76133	90560	787	Смоленская область, Ярцево, 30 лет Победы, 21, Детская художественная школа	f	large
76139	90569	796	Смоленская область, Ярцево, 1-я Рабочая, 20, средняя общеобраз.школа №6	f	large
76105	90457	685	Смоленская область, Сычевка, Станционное шоссе, 15а	f	large
76103	90455	683	Смоленская область, Сычевка, Проспект Коммунистов, 5	f	large
76104	90456	684	Смоленская область, Сычевка, Большая Пролетарская, 16	f	large
123287	90410	638	Смоленская область, деревня Станички, 43	f	small
123278	90349	567	Смоленская область, Смоленск, Дом культуры	f	medium
76019	90331	550	Смоленская область, Смоленск, Ленинский район	f	large
76018	90330	549	Смоленская область, Смоленск, СОГУ Геронтологический центр Вишенки, корп. 2, каб. №1, 1-й этаж	f	large
123271	90282	496	Смоленская область, Смоленск, 13, СОГБОУ ДОД Детско-юношеский центр туризма краеведения и спорта	f	small
123270	90282	495	Смоленская область, Смоленск, 13, СОГБОУ ДОД Детско-юношеский центр туризма краеведения и спорта	f	medium
75972	90281	494	Смоленская область, Смоленск, НУ Санаторий Красный Бор, клуб санатория	f	large
76050	90364	582	Смоленская область, Смоленск, улица Соболева, 24, СОШ №1	f	large
76081	90393	613	Смоленская область, Смоленск, улица Румянцева, 7а	f	large
75970	90279	492	Смоленская область, Смоленск, улица Белинского, 6а, Заднепровский район, ОАО Смоленский ДОК	f	large
76016	90328	547	Смоленская область, Смоленск, проспект Гагарина, 22, филиал ГБОУ ВПО - Всероссийского заочного финансово-экономического института в г.Смоленске, приемная, 2-й этаж	f	large
76049	90363	581	Смоленская область, Смоленск, мкр. Южный, 31А, СОШ №38, 2 эт., каб.29	f	large
76048	90362	580	Смоленская область, Смоленск, мкр. Южный, 31А, Промышленный район,СОШ №38, 2 эт., каб.27 	f	large
76042	90304	574	Смоленская область, Смоленск, маршала Жукова, 17, МБОУ СОШ №6	f	large
123273	90290	507	Смоленская область, Смоленск, генерала Городнянского, 6, МБОУ СОШ №32 им. С.А. Лавочкина	f	small
75981	90290	506	Смоленская область, Смоленск, генерала Городнянского, 6, МБОУ СОШ №32 им. С.А. Лавочкина	f	large
75980	90289	505	Смоленская область, Смоленск, генерала Городнянского, 6, МБОУ СОШ №32 им. С.А.Лавочкина	f	large
75978	90287	503	Смоленская область, Смоленск, генерала Городнянского, 4, МБОУ СОШ №36 им. генерала А.М. Городнянского	f	large
75979	90286	504	Смоленская область, Смоленск, генерала Городнянского, 4, МБОУ СОШ №36 им. генерала А.М.Городнянского	f	large
75977	90286	502	Смоленская область, Смоленск, генерала Городнянского, 4, МБОУ СОШ №36 им. генерала А.М.Городнянского	f	large
76012	90323	543	Смоленская область, Смоленск, Энергетический проезд, 1, 1-й этаж, каб. №105 ФГБОУ ВПО Национальный исследовательский университет МЭИ в г.Смоленске, 	f	large
76013	90324	544	Смоленская область, Смоленск, Энергетический проезд, 1, ФГБОУ ВПО Национальный исследовательский университет МЭИ	f	large
75968	90277	490	Смоленская область, Смоленск, Щорса, 8, детская бибилиотека №3 филиала МУК ЦБС	f	large
76053	90367	585	Смоленская область, Смоленск, Шевченко, 91, Смол. машиностр.колледж, 2 эт	f	large
75987	90294	513	Смоленская область, Смоленск, Чкалова, 6а, МБОУ ДОД Детская школа искусств №2	f	large
75998	90302	524	Смоленская область, Смоленск, Центральная, 10, МБОУ СОШ №23	f	large
76002	90308	530	Смоленская область, Смоленск, Фрунзе, 12, МБОУ СОШ №22	f	large
75986	90293	512	Смоленская область, Смоленск, Фрунзе, 62а, МБОУ СОШ №3	f	large
75985	90293	511	Смоленская область, Смоленск, Фрунзе, 62а, МБОУ СОШ №3	f	large
123272	90284	500	Смоленская область, Смоленск, Ударников, 3, филиал ГОУ ВПО Саратовская государственная академия права	f	medium
76055	90356	587	Смоленская область, Смоленск, Твардовского, 14, СОШ №27, 1 эт., канцелярия	f	large
76054	90356	586	Смоленская область, Смоленск, Твардовского, 14, СОШ №27, 1 эт., канцелярия	f	large
76071	90384	603	Смоленская область, Смоленск, Строителей проспект, 9, СОШ №11	f	large
76070	90383	602	Смоленская область, Смоленск, Строителей проспект, 9, СОШ №11, каб.3	f	large
76069	90382	601	Смоленская область, Смоленск, Строителей проспект, 24, Библиотека, каб.зам. директора	f	large
83888	57329	3081	Москва, Зеленоград, к142	f	large
76078	90389	610	Смоленская область, Смоленск, Соколовского, 7б, СОШ №29, каб.зам.дир.по АХР	f	large
76077	90388	609	Смоленская область, Смоленск, Соколовского, 7Б, СОШ №29, кабинет вожатых	f	large
76052	90366	584	Смоленская область, Смоленск, Соболева, 24, СОШ №1, каб. зам. дир	f	large
76051	90365	583	Смоленская область, Смоленск, Соболева, 24, СОШ №1, каб. зам. директ. 3 эт	f	large
75999	90303	525	Смоленская область, Смоленск, Седова, 1, МБУК Дом культуры Сортировка	f	large
76082	90394	614	Смоленская область, Смоленск, Румянцева, 7а, СОШ №12, учительская, 2 эт	f	large
76080	90392	612	Смоленская область, Смоленск, Румянцева, 7А, СОШ №12	f	large
76047	90361	579	Смоленская область, Смоленск, Румянцева, 8, СГИИ, 1 эт., каб., 105	f	large
123274	90305	527	Смоленская область, Смоленск, Революционная, 8, МБОУ СОШ №13 им. Э.Д. Балтина	f	medium
76000	90305	526	Смоленская область, Смоленск, Революционная, 8, МБОУ СОШ №13 им. Э.Д. Балтина	f	large
76058	90371	590	Смоленская область, Смоленск, Раевского, 2, Смол. пед.кол-дж, каб.17, 1 этаж	f	large
75969	90278	491	Смоленская область, Смоленск, Рабочая, 4, МБОУ СОШ №18	f	large
123269	90275	488	Смоленская область, Смоленск, Рабочая, 10, МБУК Дом культуры микрорайона Гнездово	f	medium
76004	90314	535	Смоленская область, Смоленск, Пржевальского, 4, ФГБОУ ВПО Смоленский государственный университет	f	large
76090	90399	622	Смоленская область, Смоленск, Попова, 108, СОШ №37, каб.завуча, 1эт	f	large
76089	90398	621	Смоленская область, Смоленск, Попова, 108, СОШ №37	f	large
76088	90397	620	Смоленская область, Смоленск, Попова, 108, СОШ №37, каб. зам. дир	f	large
76087	90397	619	Смоленская область, Смоленск, Попова, 108, СОШ №37, каб. зам. дир	f	large
76086	90396	618	Смоленская область, Смоленск, Попова, 108, СОШ №37, каб.завуча, 1 эт	f	large
76076	90387	608	Смоленская область, Смоленск, Попова, 10а, СОШ №16	f	large
76075	90387	607	Смоленская область, Смоленск, Попова, 10а, СОШ №16	f	large
76074	90386	606	Смоленская область, Смоленск, Попова, 62, СОШ №34, каб.5	f	large
76073	90386	605	Смоленская область, Смоленск, Попова, 62, СОШ №34, каб.5	f	large
76072	90385	604	Смоленская область, Смоленск, Попова, 62, СОШ №34, каб.5	f	large
76068	90381	600	Смоленская область, Смоленск, Попова, 36а, СОШ №31	f	large
76067	90380	599	Смоленская область, Смоленск, Попова, 36А, СОШ №31, каб.14, 2 эт	f	large
76066	90379	598	Смоленская область, Смоленск, Попова, 36а, СОШ 31, приемн. директ., 2 эт	f	large
76065	90378	597	Смоленская область, Смоленск, Попова, 36а, СОШ №31	f	large
76064	90377	596	Смоленская область, Смоленск, Петра Алексеева, 20, СОШ №35, каб. зам. дир. по АХР	f	large
76063	90376	595	Смоленская область, Смоленск, Петра Алексеева, 20, СОШ №35	f	large
76062	90375	594	Смоленская область, Смоленск, Петра Алексеева, 20, СОШ №35, каб.соц.педагога, 2эт	f	large
76023	90335	554	Смоленская область, Смоленск, Парковая, 20, СОГОУ Педагогический лицей-интернат им. Кирилла и Мефодия, каб. №15, 1-й этаж	f	large
75990	90288	516	Смоленская область, Смоленск, Островского, 3, МБОУ СОШ №30	f	large
75989	90288	515	Смоленская область, Смоленск, Островского, 3, МБОУ СОШ №30	f	large
76011	90322	542	Смоленская область, Смоленск, Октябрьской Революции, 7а, МБОУ СОШ №14	f	large
76008	90319	539	Смоленская область, Смоленск, Октябрьской Революции, 20а, ГАУ ДОПС Смоленский областной институт развития образования	f	large
76007	90318	538	Смоленская область, Смоленск, Октябрьской Революции, 7а, МБОУ СОШ №14	f	large
76028	90340	559	Смоленская область, Смоленск, Нормандия-Неман, 21, ФГОУ СПО Смоленский торгово-экономический техникум	f	large
123276	90311	532	Смоленская область, Смоленск, Новомосковская, 2/8, МБОУ ООШ №1	f	medium
76029	90341	560	Смоленская область, Смоленск, Новокраснофлотская, 6, МБОУ ДОД Детская школа искусств №3, каб. №1, 1-й этаж	f	large
76038	90352	570	Смоленская область, Смоленск, Николаева, 49а, МБОУ СОШ №26 им. А.С. Пушкина	f	large
76020	90332	551	Смоленская область, Смоленск, Николаева, 49а, МБОУ СОШ №26	f	large
76010	90321	541	Смоленская область, Смоленск, Неверовского, 11, МБОУ СОШ №2	f	large
76009	90320	540	Смоленская область, Смоленск, Неверовского, 11, МБОУ СОШ №2	f	large
76036	90350	568	Смоленская область, Смоленск, Нахимова, 17, Дом культуры Шарм города Смоленска, каб. №4, 1-й этаж	f	large
76027	90339	558	Смоленская область, Смоленск, Нахимова, 35, МБОУ СОШ №39, каб. №308, 3-й этаж	f	large
76026	90338	557	Смоленская область, Смоленск, Нахимова, 17, МБУК Дом культуры Шарм	f	large
76021	90333	552	Смоленская область, Смоленск, Нахимова, 9, МБОУ СОШ №8, каб. псих. разгр. 1 этаж	f	large
76024	90336	555	Смоленская область, Смоленск, Нарвская, 5, Специализированная детско-юношеская спортивная школа олимпийского резерва №1	f	large
123275	90306	528	Смоленская область, Смоленск, Московский Большак, 12, МБОУ ДОД Детская школа искусств №7 г. Смоленска	f	medium
75967	90276	489	Смоленская область, Смоленск, Минская, 21, Заднепровский район, филиал МБУК Дом культуры микрорайона Гнездово.Дом творчества	f	large
76079	90390	611	Смоленская область, Смоленск, Маршала Соколовского, 7Б, СОШ №29	f	large
76041	90355	573	Смоленская область, Смоленск, Марины Расковой, 6, МБОУ СОШ №21 им. Н.И. Рыленкова	f	large
76037	90351	569	Смоленская область, Смоленск, Марины Расковой, 6, МБОУ СОШ №21 им. Н.И. Рыленкова	f	large
76034	90347	565	Смоленская область, Смоленск, Марины Расковой, 6, МБОУ СОШ №21 им. Н.И. Рыленкова, каб. №1, 1-й этаж	f	large
76033	90346	564	Смоленская область, Смоленск, Марины Расковой, 11а, СОГУ СПО Колледж профессиональных технологий и спорта, каб. соц. раб., 1-й этаж	f	large
76043	90357	575	Смоленская область, Смоленск, Ленина, 37, Смол. политех. колледж, каб.106	f	large
123277	90313	534	Смоленская область, Смоленск, Ленина, 4, МБОУ гимназия №1 им. Н.М. Пржевальского	f	medium
76003	90312	533	Смоленская область, Смоленск, Ленина, 13а, Смоленское областное объединение организации профессиональных союзов	f	large
76060	90373	592	Смоленская область, Смоленск, Крупской, 28, СГМА, зал Учен. Совета, 2 этажа	f	large
76059	90372	591	Смоленская область, Смоленск, Крупской, 28, СГМА, каб.319, 3 этаж	f	large
76056	90369	588	Смоленская область, Смоленск, Крупской, 37, МУК №2, каб. директора, 2 этаж	f	large
76046	90360	578	Смоленская область, Смоленск, Крупской, 67/1, Дом культуры ВОС	f	large
76045	90359	577	Смоленская область, Смоленск, Крупской, 67, Дом культуры ВОС, 1 эт	f	large
76044	90358	576	Смоленская область, Смоленск, Коммунистическая, 21, Смол. кол-дж телекоммун	f	large
76057	90370	589	Смоленская область, Смоленск, Коммунальная, 5, СОШ №25, учительская, 2 этаж	f	large
76031	90343	562	Смоленская область, Смоленск, Кловская, 13, Смоленский филиал ФГБОУ ВПО Российская академия народного хозяйства и государственной службы при Президенте Российский Федерации, ауд. №12, 1-й этаж	f	large
76040	90354	572	Смоленская область, Смоленск, Кирова, 22а, МБОУ СОШ №33, каб. вожатых, 1-й этаж	f	large
76035	90348	566	Смоленская область, Смоленск, Кирова, 22а, МБОУ СОШ №33, учительская, 2-й этаж	f	large
76015	90327	546	Смоленская область, Смоленск, Кирова, 22а, МБОУ СОШ №33	f	large
76014	90326	545	Смоленская область, Смоленск, Кирова, 22б, Региональное отделение ДОСААФ России Смоленской области	f	large
76006	90317	537	Смоленская область, Смоленск, Дзержинского, 18, Смоленское областное объединение физкультурно-оздоровительных и спортивных организаций профсоюзов, ком. №15, 2-й этаж	f	large
75993	90298	519	Смоленская область, Смоленск, Губенко, 26, филиал ФГБОУ ВПО Московский государственный университет технологий и управления им. К.Г. Разумовского	f	large
75992	90297	518	Смоленская область, Смоленск, Губенко, 26, филиаил ФГБОУ ВПО Московский государственный университет технологий и управления им. К.Г. Разумовского	f	large
75988	90295	514	Смоленская область, Смоленск, Губенко, 5, МБУК Культурный центр	f	large
75995	90299	521	Смоленская область, Смоленск, Генерала Лукина, 1, МБОУ СОШ №19 им. Героя России Панова	f	large
75994	90299	520	Смоленская область, Смоленск, Генерала Лукина, 1, МБОУ СОШ №19 им. Героя России Панова	f	large
75996	90300	522	Смоленская область, Смоленск, Гастелло, 8, МБОУ СОШ №10	f	large
76032	90344	563	Смоленская область, Смоленск, Гарабурды, 17, СОГБОУ СПО Смоленский монтажный техникум, каб. №107, 1-й этаж	f	large
76030	90342	561	Смоленская область, Смоленск, Гарабурды, 13, ФГОУ СПО Смоленский автотранспортный колледж им. Е.Г. Трубицина	f	large
76039	90353	571	Смоленская область, Смоленск, Гагарина проспект, 52, МБОУ СОШ №9	f	large
76017	90329	548	Смоленская область, Смоленск, Гагарина проспект, 56, ФГОУ СПО Смоленский промышленно-экономический колледж	f	large
76061	90374	593	Смоленская область, Смоленск, Гагарина проспект, 23, СГАФКСТ, каб. 109, 1 этаж	f	large
75984	90292	510	Смоленская область, Смоленск, Валентины Гризодубовой, 6, МБОУ СОШ № 40	f	large
75983	90291	509	Смоленская область, Смоленск, Валентины Гризодубовой, 6, МБОУ СОШ №40	f	large
75982	90291	508	Смоленская область, Смоленск, Валентины Гризодубовой, 6, МБОУ СОШ №40	f	large
76005	90316	536	Смоленская область, Смоленск, Бакунина, 14, МБОУ СОШ №28	f	large
76022	90334	553	Смоленская область, Смоленск, Багратиона, 57, МБОУ лицей №1 им. академика Б.Н. Петрова	f	large
76025	90337	556	Смоленская область, Смоленск, Академика Петрова, 5а, МБОУ СОШ №17, каб. №2, 1-й этаж	f	large
75991	90296	517	Смоленская область, Смоленск, Автозаводская, 31, филиал МБОУ СОШ №30	f	large
76085	90395	617	Смоленская область, Смоленск, 25 Сентября, 28а, МБОУ гимназия №4, учительская	f	large
76084	90395	616	Смоленская область, Смоленск, 25 Сентября, 28а, МБОУ гимназия №4, учительская	f	large
76083	90395	615	Смоленская область, Смоленск, 25 Сентября, 28а, МБОУ гимназия №4, учительская	f	large
134052	90310	531	Смоленская область, Смоленск, 12 Лет Октября, 9, МБОУ СОШ № 7	f	large
76001	90307	529	Смоленская область, Смоленск, 12 Лет Октября, 9, МБОУ СОШ №7	f	large
75975	90283	499	Смоленская область, Смоленск, Радищева, 6, МБОУ СОШ №15	f	large
75974	90283	498	Смоленская область, Смоленск, Радищева, 6, МБОУ СОШ №15	f	large
75973	90283	497	Смоленская область, Смоленск, Радищева, 6, МБОУ СОШ №15	f	large
75997	90301	523	Смоленская область, Смоленск, Папанина, 1, МБОУ СОШ №24	f	large
75956	90240	453	Смоленская область, Сафоново, микрорайон-2, 23	f	large
75961	90245	458	Смоленская область, Сафоново, микрорайон-1, 7-а	f	large
75959	90243	456	Смоленская область, Сафоново, микрорайон-1, 11А	f	large
75958	90242	455	Смоленская область, Сафоново, микрорайон-1, 14-а	f	large
75953	90236	449	Смоленская область, Сафоново, Энгельса, 6	f	large
75951	90234	447	Смоленская область, Сафоново, Строителей, 22	f	large
75955	90238	451	Смоленская область, Сафоново, Советская, 29	f	large
75954	90237	450	Смоленская область, Сафоново, Советская, 52	f	large
123246	90248	461	Смоленская область, Сафоново, Районная подстанция, 3-а	f	medium
123245	90247	460	Смоленская область, Сафоново, Пушкина, 14	f	medium
75960	90244	457	Смоленская область, Сафоново, Октябрьская, 37	f	large
75948	90230	443	Смоленская область, Сафоново, Ленина, 4-а	f	large
75957	90241	454	Смоленская область, Сафоново, Кутузова, 1	f	large
75964	90252	465	Смоленская область, Сафоново, Куйбышева, 2	f	large
75949	90231	444	Смоленская область, Сафоново, Красногвардейская, 34	f	large
75952	90235	448	Смоленская область, Сафоново, Комсомольская, 1	f	large
123244	90233	446	Смоленская область, Сафоново, Коммунистическая, 4	f	medium
75962	90246	459	Смоленская область, Сафоново, Ковалева, 4	f	large
123247	90249	462	Смоленская область, Сафоново, Горняцкая, 1	f	small
75950	90232	445	Смоленская область, Сафоново, Вахрушева, 11	f	large
75965	90253	466	Смоленская область, Сафоново, 40 лет Октября, 3	f	large
75946	90197	409	Смоленская область, Рудня, Молкомбината	f	large
123211	90196	408	Смоленская область, Рудня, Мелиораторов, 35	f	medium
75942	89631	404	Смоленская область, Рудня, Красноярская, 44	f	large
75943	89631	405	Смоленская область, Рудня, Красноярская, 44	f	large
75945	90181	407	Смоленская область, Рудня, Киреева, 80	f	large
75944	90181	406	Смоленская область, Рудня, Киреева, 80	f	large
75947	90198	410	Смоленская область, Рудня, Западная, 22	f	large
75917	90145	354	Смоленская область, Рославль, площадь Бернандоса, 3	f	large
75929	90158	367	Смоленская область, Рославль, пер.1-й Братский, 15	f	large
75919	90148	357	Смоленская область, Рославль, Энергетиков, 18	f	large
75921	90150	359	Смоленская область, Рославль, Советская, 63	f	large
75930	90159	368	Смоленская область, Рославль, Пушкина, 4	f	large
75927	90156	365	Смоленская область, Рославль, Пролетарская, 66	f	large
75926	90155	364	Смоленская область, Рославль, Пролетарская, 65	f	large
75916	90144	353	Смоленская область, Рославль, Пролетарская, 93	f	large
75924	90153	362	Смоленская область, Рославль, Мичурина, 175	f	large
75918	90147	356	Смоленская область, Рославль, Ленина, 57, средняя школа №6	f	large
75920	90149	358	Смоленская область, Рославль, Красноармейская, 9	f	large
75922	90151	360	Смоленская область, Рославль, Красина, 12	f	large
75931	90160	369	Смоленская область, Рославль, Каляева, 4 А	f	large
75925	90154	363	Смоленская область, Рославль, Горького, 42А	f	large
75937	90166	375	Смоленская область, Рославль, 34 микрорайон, 11	f	large
75928	90157	366	Смоленская область, Рославль, 2-я Дачная 	f	large
75935	90164	373	Смоленская область, Рославль, 17 микрорайон, 16	f	large
75933	90162	371	Смоленская область, Рославль, 17 микрорайон, 2/1	f	large
75932	90161	370	Смоленская область, Рославль, 17 микрорайон, 23	f	large
75936	90165	374	Смоленская область, Рославль, 16 микрорайон, 39	f	large
75934	90163	372	Смоленская область, Рославль, 15 микрорайон, 33	f	large
75912	90104	313	Смоленская область, Починок, Толстого, 30	f	large
123151	90103	312	Смоленская область, Починок, Красноармейская, 78	f	medium
75911	90102	311	Смоленская область, Починок, Красноармейская, 11	f	large
75910	90101	310	Смоленская область, Починок, Кирова, 1	f	large
76100	90421	649	Смоленская область, деревня Новые Батеки, Северная, 20а	f	large
76099	90419	647	Смоленская область, деревня Михновка, Молодёжная, 4	f	large
75971	90280	493	Смоленская область, поселок Красный Бор, Станционный переулок, 5, МБОУ СОШ №5	f	large
122942	89801	3	Россия	f	small
122973	89872	77	Смоленская область, Ельня, Ельнинский Дом культуры	f	small
75901	89984	195	Смоленская область, Ельня, микрорайон Кутузовский, 22	f	large
75900	89983	194	Смоленская область, Ельня, Смоленский большак, 8	f	large
75897	89980	191	Смоленская область, Ельня, Пролетарская, 46	f	large
75899	89982	193	Смоленская область, Ельня, Ленина, 46	f	large
75898	89981	192	Смоленская область, Ельня, Кировская, 1	f	large
75894	89960	171	Смоленская область, Духовщина, Смоленская, 60	f	large
75883	89133	160	Смоленская область, Дорогобуж, Седова, 4	f	large
75881	89953	158	Смоленская область, Дорогобуж, Пушкина, 9	f	large
75886	89597	163	Смоленская область, Дорогобуж, Путенкова, 9	f	large
75885	89597	162	Смоленская область, Дорогобуж, Путенкова, 9	f	large
75884	89521	161	Смоленская область, Дорогобуж, Путенкова, 7	f	large
75880	89936	141	Смоленская область, Десногорск, 4 микрорайон	f	large
75879	89935	140	Смоленская область, Десногорск, 4 микрорайон	f	large
75876	89931	136	Смоленская область, Десногорск, 4 микрорайон	f	large
75877	89932	137	Смоленская область, Десногорск, 3 микрорайон	f	large
75875	89930	135	Смоленская область, Десногорск, 2 микрорайон	f	large
75871	89926	131	Смоленская область, Десногорск, 1 микрорайон, Десногорский энергетический колледж	f	large
75872	89927	132	Смоленская область, Десногорск, 1 микрорайон	f	large
75867	89906	111	Смоленская область, Демидов, Суворовский проезд, 7 , здание Демидовского ДК	f	large
75868	89907	112	Смоленская область, Демидов, Советская, 25 А, здание техникума	f	large
75869	89908	113	Смоленская область, Демидов, Октябрьская, 9, здание МБОУ СОШ	f	large
75866	89905	110	Смоленская область, Демидов, Вакарина, 10, здание МОУ СОШ №1	f	large
76094	90404	632	Смоленская область, Гедеоновка, административный корпус ОГОУЗ областной клинической, психиатрической больницы	f	large
75860	89867	72	Смоленская область, Гагарин, Строителей, 50	f	large
75854	89860	65	Смоленская область, Гагарин, Советская, 5	f	large
75859	89865	70	Смоленская область, Гагарин, Первомайский проезд, 1	f	large
75858	89864	69	Смоленская область, Гагарин, П.Алексеева, 2	f	large
122971	89868	73	Смоленская область, Гагарин, Молодежная, 1	f	medium
75853	89859	64	Смоленская область, Гагарин, Ленина, 73	f	large
75852	89858	63	Смоленская область, Гагарин, Ленина, 14	f	large
75861	89869	74	Смоленская область, Гагарин, Гагарина, 87	f	large
75857	89863	68	Смоленская область, Гагарин, Гагарина, 8	f	large
75855	89861	66	Смоленская область, Гагарин, Гагарина, 62	f	large
75856	89862	67	Смоленская область, Гагарин, Бахтина, 8	f	large
75838	89822	27	Смоленская область, Вязьма, Юбилейная	f	large
75837	89821	26	Смоленская область, Вязьма, Юбилейная	f	large
75842	89826	31	Смоленская область, Вязьма, Строителей, 18	f	large
75832	89816	20	Смоленская область, Вязьма, Пушкина, 25	f	large
75844	89828	33	Смоленская область, Вязьма, Ползунова, 9	f	large
75831	89643	19	Смоленская область, Вязьма, Покровского, 2	f	large
75843	89827	32	Смоленская область, Вязьма, Плотникова, 11	f	large
75827	89813	15	Смоленская область, Вязьма, Плотникова, 10	f	large
75836	89820	25	Смоленская область, Вязьма, Московская, 14А	f	large
75835	89819	24	Смоленская область, Вязьма, Московская, 6а	f	large
75834	89818	23	Смоленская область, Вязьма, Московская, 6	f	large
75845	89830	35	Смоленская область, Вязьма, Ленина, 67а	f	large
75840	89824	29	Смоленская область, Вязьма, Ленина, 77	f	large
75833	89817	22	Смоленская область, Вязьма, Ленина, 9	f	large
75830	89695	18	Смоленская область, Вязьма, Ленина, 47	f	large
75828	89814	16	Смоленская область, Вязьма, Заслонова, 8	f	large
75825	89811	13	Смоленская область, Вязьма, Загородный переулок, 23	f	large
75829	89815	17	Смоленская область, Вязьма, Докучаева, 2	f	large
75826	89812	14	Смоленская область, Вязьма, 25 Октября, 21	f	large
75824	89810	12	Смоленская область, Вязьма, 25 Октября, 3А	f	large
122948	89829	34	Смоленская область, Вязьма, Ленина, 75	f	small
75821	89807	9	Смоленская область, Велиж, Советская, 11 А	f	large
75823	89809	11	Смоленская область, Велиж, Недоговорова, 15	f	large
123018	89937	142	Смоленская область, деревня Алексино, Здание администрации Алексинского с/п	f	medium
76122	90548	774	Смоленская область, Ярцевский район, Ярцево, Чайковского, 11, Ярцевский спортивный комплекс	f	large
76135	90565	792	Смоленская область, Ярцевский район, Ярцево, Советская, 24А, МБОУДОД Ярцевская ДЮСШ	f	large
76118	90544	770	Смоленская область, Ярцевский район, Ярцево, Ленинская, 15, Детская школа искусств	f	large
123407	90583	810	Смоленская область, Ярцевский район, поселок Суетово, Магистральная, 4, Администрация сельского поселения	f	medium
122976	89876	81	Смоленская область, Ярцевский район, поселок Самуйлово	f	small
123406	90582	809	Смоленская область, Ярцевский район, поселок Репино, Центральный переулок, 3, Администрация сельс.поселения	f	small
122980	89881	86	Смоленская область, Ярцевский район, поселок Потапово, Потаповский Дом культуры	f	small
123405	90581	808	Смоленская область, Ярцевский район, поселок Подроща, переулок Центральный, 3, Администрация сельс.поселения	f	medium
123403	90579	806	Смоленская область, Ярцевский район, поселок Петрово, Парковая, 2, Администрация сельс.поселения	f	medium
123404	90580	807	Смоленская область, Ярцевский район, поселок Ольхово, Школьная, 2, Ольховский фил.Засижьевск.СОШ	f	small
123402	90578	805	Смоленская область, Ярцевский район, поселок Мушковичи, Школьная, 8, Мушковичск.основная общеобр.шк	f	medium
76141	90577	804	Смоленская область, Ярцевский район, поселок Михейково, Советская, 2	f	large
123401	90576	803	Смоленская область, Ярцевский район, поселок Мирополье, Победы, 3	f	small
134060	90575	802	Смоленская область, Ярцевский район, поселок Львово, Школьная, 40, Марковский сельский клуб	f	\N
123400	90574	801	Смоленская область, Ярцевский район, поселок Кротово, Школьная, 12, Администрация сельс.поселения	f	small
76140	90573	800	Смоленская область, Ярцевский район, поселок Капыревщина, Школьная, 4, Капыревщинск. общеобраз.ср.шк	f	large
123257	90263	476	Смоленская область, Сафоновский район, поселок Вышегор	f	medium
123178	90133	342	Смоленская область, Шумячский район, поселок Яново, 69, Здание филиала начальных классов рябцевской школы	f	small
76115	90530	754	Смоленская область, Шумячский район, поселок Шумячи, Советская, 109	f	large
76114	90529	753	Смоленская область, Шумячский район, поселок Шумячи, Советская, 75	f	large
123388	90539	765	Смоленская область, Шумячский район, поселок Студенец, 136	f	small
123383	90533	759	Смоленская область, Шумячский район, поселок Снегиревка, Молодежная, 1	f	small
123386	90537	763	Смоленская область, Шумячский район, поселок Русское, 186	f	small
123380	90531	755	Смоленская область, Шумячский район, поселок Руссковский, Руссковская, 24	f	medium
123385	90535	761	Смоленская область, Шумячский район, поселок Починичи, 13	f	small
123389	90540	766	Смоленская область, Шумячский район, поселок Понятовка, Первомайская, 6	f	medium
123387	90538	764	Смоленская область, Шумячский район, поселок Петровичи, 90	f	small
123384	90534	760	Смоленская область, Шумячский район, поселок Новое Заселье, 2	f	small
123390	90541	767	Смоленская область, Шумячский район, поселок Надейковичи, 77	f	small
123160	90113	322	Смоленская область, Шумячский район, поселок Лысовка, 45, Здание администрации поселения	f	small
123381	90516	757	Смоленская область, Шумячский район, поселок Криволес, 8 	f	small
123391	90542	768	Смоленская область, Шумячский район, поселок Зимонино, 43	f	small
123260	90266	479	Смоленская область, Шумячский район, поселок Зимницы, здание Зимницкого сельского дома культуры	f	small
134051	90309	756	Смоленская область, Шумячский район, поселок Гневково, 28, помещение Гневковского сельского Дома культуры	f	\N
123382	90532	758	Смоленская область, Шумячский район, поселок Балахоновка, 66	f	small
123062	89996	207	Россия	f	small
122969	89857	62	Смоленская область, Холм-Жирковский район, поселок Юшково, Школьная, 3	f	small
76111	90526	750	Смоленская область, Холм-Жирковский район, поселок Холм-Жирковский, Старшины Сорокина, 21	f	large
76113	90528	752	Смоленская область, Холм-Жирковский район, поселок Холм-Жирковский, Советская, 13А	f	large
76112	90527	751	Смоленская область, Холм-Жирковский район, поселок Холм-Жирковский, Нахимовская, 2	f	large
123377	90523	747	Смоленская область, Холм-Жирковский район, поселок Стешино, Центральная, 33	f	small
123376	90522	746	Смоленская область, Холм-Жирковский район, поселок Пигулино, Грибоедова, 98А	f	small
123375	90521	745	Смоленская область, Холм-Жирковский район, поселок Печатники, Школьная, 9	f	small
123057	89991	202	Смоленская область, Холм-Жирковский район, поселок Новоспасское, помещение Новоспасского сельского Дома культуры	f	small
123374	90520	744	Смоленская область, Холм-Жирковский район, поселок Никитинка, Базарная, 24	f	small
123373	90519	743	Ленинградская область, Выборгский район, посёлок Нахимовское	f	small
123372	90518	742	Смоленская область, Холм-Жирковский район, поселок Лехмино, Центральный переулок, 2	f	small
123313	90443	671	Смоленская область, Холм-Жирковский район, поселок Караваево, помещение Дома культуры	f	small
123139	90085	296	Смоленская область, Холм-Жирковский район, поселок Караваево, МОУ Караваевская начальная школа - детский сад	f	small
123371	90517	741	Смоленская область, Холм-Жирковский район, поселок Канютино, Железнодорожная, 15	f	small
76110	90515	740	Смоленская область, Холм-Жирковский район, поселок Игоревская, Южная, 4	f	large
122987	89888	93	Смоленская область, Холм-Жирковский район, поселок Ивашково, Ивашковский Дом культуры	f	small
123399	90572	799	Смоленская область, Холм-Жирковский район, поселок Зайцево, Центральная, 19, здание Зайцевского СДК	f	small
123379	90525	749	Смоленская область, Холм-Жирковский район, Владимирский Тупик, Железнодорожная, 29	f	medium
123378	90524	748	Смоленская область, Холм-Жирковский район, поселок Верховье, Новая, 7, здание Дома культуры	f	small
123370	90514	739	Смоленская область, Холм-Жирковский район, поселок Болышево	f	small
123369	90513	738	Смоленская область, Холм-Жирковский район, поселок Боголюбово, Центральная, 3	f	medium
123368	90512	737	Смоленская область, Холм-Жирковский район, поселок Батурино, Лесная, 1, здание администрации с/п	f	small
123367	90511	736	Смоленская область, Холм-Жирковский район, поселок Агибалово, Черемушки, 5	f	small
123365	90509	734	Смоленская область, Хиславичский район, поселок Черепово	f	small
76108	90490	716	Смоленская область, Хиславичский район, поселок Хиславичи, Советская, 32	f	large
123350	90493	719	Смоленская область, Хиславичский район, поселок Хиславичи, Северная, 3	f	small
76109	90491	717	Смоленская область, Хиславичский район, поселок Хиславичи, Пушкина переулок, 15	f	large
123349	90492	718	Смоленская область, Хиславичский район, поселок Хиславичи, Берестнева	f	small
123364	90508	733	Смоленская область, Хиславичский район, поселок Упино	f	small
123363	90507	732	Смоленская область, Хиславичский район, поселок Соино	f	small
123360	90504	729	Смоленская область, Хиславичский район, поселок Печерская Буда	f	small
76092	90345	629	Смоленская область, Хиславичский район, поселок Печерск, Школьная, 1а	f	large
123361	90505	730	Смоленская область, Хиславичский район, поселок Петрополье	f	small
123366	90510	735	Смоленская область, Хиславичский район, поселок Новая Рудня	f	small
123113	90053	264	Смоленская область, Хиславичский район, поселок Николаевка, Октябрьская, 12	f	small
123359	90503	728	Смоленская область, Хиславичский район, поселок Микшино	f	small
123155	90108	317	Смоленская область, Хиславичский район, поселок Красиловка, 26, Здание красиловского ФАПа	f	small
123358	90502	727	Смоленская область, Хиславичский район, поселок Корзово	f	medium
123362	90506	731	Смоленская область, Хиславичский район, поселок Козловка	f	small
123356	90499	725	Смоленская область, Хиславичский район, поселок Клюкино	f	small
123354	90497	723	Смоленская область, Хиславичский район, поселок Йозефовка	f	small
123353	90496	722	Смоленская область, Хиславичский район, поселок Жанвиль	f	small
123352	90495	721	Смоленская область, Хиславичский район, поселок Городище	f	small
123351	90494	720	Смоленская область, Хиславичский район, поселок Владимировка	f	small
123355	90498	724	Смоленская область, Хиславичский район, поселок Братковая	f	small
123357	90500	726	Смоленская область, Хиславичский район, поселок Большая Хутора	f	small
123221	90207	420	Россия, Московская область, Лотошинский район, деревня Шилово	f	small
123348	90487	713	Смоленская область, Угранский район, поселок Холмы, помещение администрации Холмовского сельского поселения	f	small
76107	90489	715	Смоленская область, Угранский район, поселок Угра, Советская, 28	f	large
76106	90488	714	Смоленская область, Угранский район, поселок Угра, Мира, 32	f	large
123347	90485	712	Смоленская область, Угранский район, поселок Слободка	f	small
123345	90483	710	Россия	f	small
123344	90482	709	Россия	f	small
123341	90479	706	Смоленская область, Угранский район, поселок Новомилятино	f	small
123343	90481	708	Смоленская область, Угранский район, поселок Мытыщино	f	small
123342	90480	707	Смоленская область, Угранский район, поселок Михали	f	small
123339	90477	704	Россия, Республика Хакасия, Боградский район, село Знаменка	f	small
123337	90475	702	Россия	f	small
123336	90474	701	Россия	f	small
123335	90473	700	Вологодская область, Шекснинский район, село Всходы	f	medium
123334	90472	699	Смоленская область, Угранский район, поселок Вешки, помещение администрации Вешковского сельского поселения	f	small
123333	90471	698	Россия	f	small
123338	90476	703	Смоленская область, Угранский район, поселок Большое Захарьевское	f	small
123340	90478	705	Смоленская область, Угранский район, поселок Баскаковка	f	small
123332	90470	697	Россия	f	small
123321	90451	679	Россия	f	small
134057	90463	696	Смоленская область, Темкинский район, поселок Темкино, помещение Администрации Темкинского сельского поселения	f	\N
123330	90468	695	Смоленская область, Темкинский район, поселок Селенки, Центральная, 20	f	small
123265	90271	484	Смоленская область, Темкинский район, поселок Прудки	f	medium
123171	90126	335	Смоленская область, Темкинский район, поселок Прудки, Центральная, 18	f	medium
123236	90222	435	Смоленская область, Темкинский район, поселок Понизовье, Здание администрации с/п	f	medium
123326	90459	687	Смоленская область, Темкинский район, поселок Нарытка, Возрождения, 13	f	small
134059	90465	692	Смоленская область, Темкинский район, поселок Кикино, помещение Администрации Кикинского сельского поселения	f	\N
134056	90462	690	Смоленская область, Темкинский район, поселок Замыцкое, помещение Администрации Вязищенского сельского поселения	f	\N
134058	90464	691	Смоленская область, Темкинский район, поселок Горки, помещение Администрации Долматовского сельского поселения	f	\N
123328	90466	693	Смоленская область, Темкинский район, поселок Власово, Центральная, 7	f	small
123256	90262	475	Смоленская область, Темкинский район, поселок Васильевское, здание Администрации Васильевского сельского поселения	f	small
123327	90461	689	Смоленская область, Темкинский район, поселок Васильевское, Молодежная, 19	f	small
123039	89968	179	Московская область, Луховицкий район, деревня Булгаково	f	small
123329	90467	694	Смоленская область, Темкинский район, поселок Булгаково, Липовая Аллея, 8	f	medium
134055	90460	688	Смоленская область, Темкинский район, поселок Бекрино, помещение Администрации Батюшковского сельского поселения	f	\N
123322	90452	680	Россия	f	small
123324	90454	682	Россия	f	small
123323	90453	681	Смоленская область, Сычевский район, поселок Софьино, помещение клуба	f	small
123319	90449	677	Смоленская область, Сычевский район, поселок Середа	f	small
123114	90054	265	Смоленская область, Сычевский район, поселок Павлово, Здание администрации с/п	f	small
123314	90444	672	Смоленская область, Сычевский район, поселок Никитье	f	small
123316	90446	674	Курганская область, Шадринский район, село Мальцево	f	medium
123315	90445	673	Россия	f	small
123317	90447	675	Россия	f	small
123312	90442	670	Смоленская область, Сычевский район, поселок Дугино	f	medium
123258	90264	477	Смоленская область, Сычевский район, поселок Дроздово, здание Дроздовского сельского дома культуры	f	small
123311	90441	669	Смоленская область, Сычевский район, поселок Вараксино, помещение администрации Вараксинского с/п	f	small
123310	90440	668	Россия	f	small
123309	90439	667	Россия	f	small
123320	90450	678	Россия	f	small
123001	89904	109	республика Мордовия, Ромодановский район, поселок Ромоданово	f	small
123294	90420	648	Смоленская область, Смоленский район, поселок Чекулино, Смоленская, 2	f	small
123292	90417	645	Смоленская область, Смоленский район, поселок Хохлово, Мира, 12	f	medium
76098	90414	642	Смоленская область, Смоленский район, поселок Талашкино, Ленина, 7	f	large
123299	90428	656	Смоленская область, Смоленский район, поселок Сметанино, Озерная, 1а	f	medium
123291	90416	644	Смоленская область, Смоленский район, поселок Санники, Центральная, 23а	f	small
123297	90424	652	Смоленская область, Смоленский район, Санаторий Борок	f	medium
123290	90415	643	Смоленская область, Смоленский район, поселок Русилово, Центральная, 2	f	medium
123285	90406	634	Смоленская область, Смоленский район, поселок Рогачево, Центральная, 10	f	small
76096	90409	637	Смоленская область, Смоленский район, поселок Пригорское, Спортивная, 2	f	large
123300	90429	657	Смоленская область, Смоленский район, поселок Почаево, Витебское шоссе, 7Б	f	small
76093	90402	630	Смоленская область, Смоленский район, поселок Печерск, Автодорожная, 1	f	large
123282	90315	627	Смоленская область, Смоленский район, поселок Ольша, Садовый переулок, 1а	f	medium
123025	89944	149	Смоленская область, Смоленский район, поселок Озерище, Здание Озерищенской средней общеобразовательной школы	f	small
123304	90433	661	Смоленская область, Смоленский район, поселок Новосельский, 70	f	medium
123209	90194	402	Смоленская область, Смоленский район, поселок Новоселки, здание администрации Сырокоренского сельского поселения	f	small
123295	90422	650	Смоленская область, Смоленский район, поселок Новое Куприно, Парковая, 13	f	small
123296	90423	651	Смоленская область, Смоленский район, поселок Нивищи, Мира, 10а	f	medium
123281	90391	626	Смоленская область, Смоленский район, поселок Мощинки, Лесная, 9	f	medium
123289	90413	641	Смоленская область, Смоленский район, поселок Моготово, Школьная, 8	f	small
123280	90401	624	Смоленская область, Смоленский район, поселок Мазальцево, Мира, 3	f	small
134053	90405	633	Смоленская область, Смоленский район, поселок Магалинщина, Садовая, 49	f	large
123293	90418	646	Смоленская область, Смоленский район, поселок Лубня, Садовая, 2	f	medium
123307	90437	665	Смоленская область, Смоленский район, поселок Лойно, Колхозный переулок, 1	f	small
123022	89941	146	Свердловская область, городской округ Первоуральск, поселок Кузино	f	small
76097	90412	640	Смоленская область, Смоленский район, поселок Кощино, Дружбы, 27	f	large
76101	90425	653	Смоленская область, Смоленский район, поселок Катынь, Витебское шоссе, 10А	f	large
134054	90434	662	Смоленская область, Смоленский район, поселок Каспля, Советская, 15, здание администрации сельского поселения	f	\N
123306	90436	664	Смоленская область, Смоленский район, поселок Замощье, Молодёжная, 123	f	small
76091	90368	625	Смоленская область, Смоленский район, поселок Жуково, Мира, 48	f	large
123288	90411	639	Смоленская область, Смоленский район, поселок Дрюцк, дом-интернат, корпус №3	f	small
123283	90325	628	Смоленская область, Смоленский район, поселок Дивасы, Мичурина, 23	f	medium
123185	90140	349	Смоленская область, Смоленский район, поселок Горяны, Здание Дома культуры	f	small
123302	90431	659	Смоленская область, Смоленский район, поселок Вязгино, Мира, 20	f	small
123298	90427	655	Смоленская область, Смоленский район, поселок Высокий Холм, 16	f	small
123305	90435	663	Смоленская область, Смоленский район, поселок Волоковая, Центральная, 9	f	small
123303	90432	660	Смоленская область, Смоленский район, поселок Верховье, .Речная, .2	f	small
123286	90408	636	Смоленская область, Смоленский район, поселок Бубново, Почтовая, 28	f	small
123308	90438	666	Смоленская область, Смоленский район, поселок Бабны, Молодежная, 20	f	small
123301	90430	658	Смоленская область, Смоленский район, поселок Аполье, Ефимова, 1	f	small
76102	90426	654	Смоленская область, Смоленский район, поселок Авторемзавод, 19	f	large
123014	89922	127	Смоленская область, Сафоновский район, поселок Холм, Центральная, 11	f	small
123055	89989	200	Смоленская область, Сафоновский район, поселок Уварово, помещение Уваровского сельского Дома культуры	f	small
123146	90095	306	Новосибирская область, Черепановский район, поселок Татарка	f	small
123268	90274	487	Смоленская область, Сафоновский район, поселок Старое Село, здание Администрации Старосельского сельского поселения	f	small
123284	90403	631	Смоленская область, Сафоновский район, поселок Синьково, Ковалева, 7	f	small
123252	90258	471	Смоленская область, Сафоновский район, Сафоново	f	small
134050	90239	452	Смоленская область, Сафоновский район, Сафоново	f	large
123248	90250	463	Смоленская область, Сафоновский район, Сафоново, Калинина, 49	f	medium
75963	90251	464	Смоленская область, Сафоновский район, Сафоново, микрорайон ГМП, 18	f	large
123267	90273	486	Смоленская область, Сафоновский район, поселок Рыбки	f	medium
122952	89837	42	Смоленская область, Сафоновский район, поселок Путьково, здание школы	f	small
123264	90270	483	Смоленская область, Сафоновский район, поселок Николо-Погорелое	f	small
75909	90078	289	Смоленская область, Сафоновский район, поселок Монастырщина, Революционная, 36	f	large
75908	90077	288	Смоленская область, Сафоновский район, поселок Монастырщина, 1-я Краснинская, 11	f	large
123251	90257	470	Ярославская область, Большесельский район, поселок Мишенино	f	small
122990	89891	96	Смоленская область, Сафоновский район, поселок Мальцево, администрация сельского поселения	f	small
123255	90261	474	Смоленская область, Сафоновский район, поселок Лесное, здание Ново-Тимошинского филиала МОУ Вадинской средней школы	f	small
123263	90269	482	Смоленская область, Сафоновский район, поселок Казулино	f	medium
75966	90254	467	Смоленская область, Сафоновский район, поселок Издешково	f	large
123262	90268	481	Смоленская область, Сафоновский район, поселок Игнатково, Административное здание МУСХП Исток	f	small
123259	90265	478	Россия, Смоленская область, Сафоновский район, поселок Дурово	f	small
134042	90081	292	Смоленская область, Сафоновский район, поселок Высокое, Высоковская СОШ	f	\N
123064	89998	209	Смоленская область, Сафоновский район, поселок Высокое, помещение МБОУ Высоковской основной школы	f	small
123254	90260	473	Смоленская область, Сафоновский район, поселок Вадино	f	medium
123253	90259	472	Псковская область, Гдовский район, село Богдановщина	f	small
123250	90256	469	Смоленская область, Сафоновский район, поселок Беленино	f	small
123261	90267	480	Смоленская область, Сафоновский район, поселок Алферово, здание Администрации Зимницкого сельского поселения	f	small
123224	90210	423	Смоленская область, Руднянский район, поселок Шубки	f	small
123234	90220	433	Смоленская область, Руднянский район, поселок Чистик	f	medium
123240	90226	439	Московская область, Домодедово, улица Горки, 1	f	small
123218	90204	417	Смоленская область, Руднянский район, поселок Суфляново	f	small
123217	90203	416	Смоленская область, Руднянский район, поселок Сташки	f	small
123229	90215	428	Калужская область, Спас-Деменский район, поселок Стаи	f	small
123219	90205	418	Смоленская область, Руднянский район, поселок Смолиговка	f	medium
123220	90206	419	Орловская область, Кромский район, поселок Приволье	f	small
123230	90216	429	Смоленская область, Руднянский район, поселок Переволочье	f	small
123237	90223	436	Смоленская область, Руднянский район, поселок Никонцы	f	small
123227	90213	426	Смоленская область, Руднянский район, поселок Могильно	f	small
123135	90075	286	Смоленская область, Руднянский район, поселок Любавичи, помещение администрации Любавичского сельского поселения	f	small
123235	90221	434	Смоленская область, Руднянский район, поселок Лешно	f	small
123228	90214	427	Смоленская область, Руднянский район, поселок Кругловка	f	small
123231	90217	430	Россия	f	medium
123242	90228	441	Смоленская область, Руднянский район, поселок Кляриново	f	small
123232	90218	431	Смоленская область, Руднянский район, поселок Карташевичи	f	small
123225	90211	424	Смоленская область, Руднянский район, поселок Казимирово	f	small
123015	89923	128	Смоленская область, Руднянский район, поселок Заборье, Молодежная, 40, здание Администрации	f	small
122950	89835	40	Смоленская область, Руднянский район, поселок Ефремово, Школьная, 16	f	small
123216	90202	415	Смоленская область, Руднянский район, поселок Гранки	f	small
123214	90201	413	Смоленская область, Руднянский район, поселок Голынки, Ленина	f	medium
123215	90200	414	Смоленская область, Руднянский район, поселок Голынки, Ленина	f	medium
123213	90200	412	Смоленская область, Руднянский район, поселок Голынки, Ленина	f	small
123212	90199	411	Смоленская область, Руднянский район, поселок Голынки, Ленина	f	medium
123095	90034	245	Смоленская область, Руднянский район, поселок Волково, Гореленкова, 14	f	small
123239	90225	438	Смоленская область, Руднянский район, поселок Верхнии Кошевичи	f	small
123243	90229	442	Смоленская область, Руднянский район, поселок Братышки	f	small
123241	90227	440	Смоленская область, Руднянский район, поселок Боярщина, Здание школы	f	small
123004	89911	116	Смоленская область, Руднянский район, поселок Боярщина	f	small
123202	90185	393	Смоленская область, Рославльский район, поселок Чижовка	f	medium
123210	90195	403	Московская область, Волоколамский район, деревня Хорошово	f	medium
123125	90065	276	Смоленская область, Рославльский район, поселок Слобода	f	small
123208	90193	401	Смоленская область, Рославльский район, поселок Савеево	f	small
75915	90142	351	Смоленская область, Рославльский район, Рославль, переулок Димитрова, 3А, здание средней школы №2	f	large
75923	90152	361	Смоленская область, Рославльский район, Рославль, Первомайская, 21А, здание средней школы №5	f	large
123204	90189	397	Смоленская область, Рославльский район, поселок Пригоры	f	medium
123203	90188	396	Смоленская область, Рославльский район, поселок Перенка	f	medium
75940	90186	394	Смоленская область, Рославльский район, поселок Остер, Советская, 11	f	large
75939	90176	385	Смоленская область, Рославльский район, поселок Малые Кириллы, Совхозная, 2	f	large
123199	90182	390	Самарская область, Хворостянский район, село Липовка	f	medium
123200	90183	391	Смоленская область, Рославльский район, поселок Лесники	f	small
123205	90190	398	Смоленская область, Рославльский район, поселок Лахи	f	small
75906	90032	243	Смоленская область, Рославльский район, поселок Красный, Советская, 17, 1 этаж	f	large
75905	90031	242	Смоленская область, Рославльский район, поселок Красный, Советская, 17, 2 этаж	f	large
123197	90179	388	Смоленская область, Рославльский район, поселок Крапивна, здание администрации Крапивенского сельского поселения	f	small
123206	90191	399	Смоленская область, Рославльский район, поселок Крапивенский 1-й	f	medium
123198	90180	389	Смоленская область, Рославльский район, поселок Коханы	f	small
123195	90177	386	Смоленская область, Рославльский район, поселок Костыри	f	small
123201	90184	392	Смоленская область, Рославльский район, поселок Коски	f	small
75941	90187	395	Смоленская область, Рославльский район, поселок Козловка, Мира, 44	f	large
123192	90173	382	Смоленская область, Рославльский район, поселок Жарынь	f	medium
123191	90172	381	Смоленская область, Рославльский район, поселок Епишево	f	small
75938	90171	380	Смоленская область, Рославльский район, поселок Екимовичи, Комсомольская, 14 А	f	large
123207	90192	400	Смоленская область, Рославльский район, поселок Доротовка	f	small
134040	89934	139	Смоленская область, Рославльский район, Десногорск, здание МБОУ ДОД Детская музыкальная школа	f	large
75878	89933	138	Смоленская область, Рославльский район, Десногорск	f	large
75874	89929	134	Смоленская область, Рославльский район, Десногорск, 2 микрорайон	f	large
75873	89928	133	Смоленская область, Рославльский район, Десногорск, 1 микрорайон	f	large
123190	90170	379	Смоленская область, Рославльский район, поселок Грязенять	f	small
123193	90174	383	Смоленская область, Рославльский район, поселок Волконщина	f	small
123189	90169	378	Смоленская область, Рославльский район, поселок Волковичи	f	small
123188	90168	377	Смоленская область, Рославльский район, поселок Богданово, им.колхоза Быстрые волны, 8	f	small
123196	90178	387	Смоленская область, Рославльский район, поселок Барсуки, здание Красниковской средней школы	f	small
123187	90167	376	Смоленская область, Рославльский район, поселок Астапковичи	f	medium
123157	90110	319	Смоленская область, Починковский район, поселок Шмаково, 56	f	small
75914	90122	331	Смоленская область, Починковский район, поселок Шаталово	f	large
123167	90121	330	Смоленская область, Починковский район, поселок Шаталово, 238	f	medium
123164	90118	327	Смоленская область, Починковский район, поселок Шанталово	f	medium
123154	90107	316	Смоленская область, Починковский район, поселок Стригино, 86	f	small
123163	90117	326	Смоленская область, Починковский район, поселок Стодолище, Ленина, 21-а	f	medium
75913	90116	325	Смоленская область, Починковский район, поселок Стодолище, Ленина, 16	f	large
123176	90131	340	Смоленская область, Починковский район, поселок Старинки, 59, Здание Дома культуры	f	small
123179	90134	343	Смоленская область, Починковский район, поселок Рябцево, 68	f	medium
123186	90141	350	Смоленская область, Починковский район, поселок Прилепово, 1	f	small
123173	90128	337	Россия, Московская область, Шаховской район, деревня Плоское	f	medium
123180	90135	344	Смоленская область, Починковский район, поселок Пересна, 90	f	medium
123159	90112	321	Смоленская область, Починковский район, поселок Новые Головачи, 29 	f	small
123174	90129	338	Смоленская область, Починковский район, поселок Мурыгино, Центральная, 71	f	medium
123168	90123	332	Смоленская область, Починковский район, поселок Мачулы, 96	f	medium
123175	90130	339	Московская область, Клинский район, деревня Макшеево	f	small
123152	90105	314	Смоленская область, Починковский район, поселок Лучеса, имени С.И.Бизунова, 6	f	medium
123177	90132	341	Смоленская область, Починковский район, поселок Лосня, 1	f	medium
123182	90137	346	Смоленская область, Починковский район, поселок Ламоново, 14	f	small
123162	90115	324	Смоленская область, Починковский район, поселок Красное Знамя, 11	f	small
123184	90139	348	Смоленская область, Починковский район, поселок Княжое 1-е, 131	f	small
123156	90109	318	Смоленская область, Починковский район, поселок Климщина, 52	f	small
123183	90138	347	Смоленская область, Починковский район, поселок Клемятино, 1, Здание СПК Клемятино	f	small
123133	90073	284	Смоленская область, Починковский район, поселок Доброселье, помещение МОУ Добросельская ООШ	f	small
123161	90114	323	Смоленская область, Починковский район, поселок Деребуж 1-й, 30	f	small
123169	90124	333	Смоленская область, Починковский район, поселок Даньково, 94	f	medium
123165	90119	328	Смоленская область, Починковский район, поселок Ворошилово, 76	f	small
123166	90120	329	Смоленская область, Починковский район, поселок Васьково, 5	f	medium
123172	90127	336	Смоленская область, Починковский район, поселок Бояды 1-е	f	small
123158	90111	320	Смоленская область, Починковский район, поселок Белик, 26	f	small
123153	90106	315	Смоленская область, Починковский район, поселок Бабыново	f	small
134047	90099	308	Смоленская область, Новодугинский район, поселок Хвощеватое, здание МКОУ Хвощеватовская ООШ	f	\N
134046	90096	307	Московская область, Сергиево-Посадский район, садовое товарищество Торбеево	f	medium
122933	90094	305	Смоленская область, Новодугинский район, поселок Тесово, МОУ Тесовская основная общеобразовательная школа	f	medium
122925	90093	304	Смоленская область, Новодугинский район, поселок Селище, здание МОУ Селищенская основная общеобразовательная школа	f	small
123035	89964	175	Смоленская область, Новодугинский район, поселок Савино, Центральная, 7, здание медпункта	f	small
123145	90092	303	Калужская область, Калуга городской округ, поселок Рябинки	f	small
123144	90091	302	Смоленская область, Новодугинский район, поселок Печеничено	f	small
123149	90100	309	Смоленская область, Новодугинский район, поселок Новодугино, 1	f	small
123143	90090	301	Смоленская область, Новодугинский район, поселок Новодугино, Чкалова, 27	f	medium
123141	90088	299	Смоленская область, Новодугинский район, поселок Новодугино, Советская, 1	f	medium
123142	90089	300	Смоленская область, Новодугинский район, поселок Новодугино, Горького, 4	f	medium
75864	89892	97	Смоленская область, Новодугинский район, поселок Никольское, Никольский Дом культуры	f	large
123107	90047	258	Московская область, Каширский район, деревня Малеево	f	small
134045	90087	298	Смоленская область, Новодугинский район, поселок Липецы, здание МКОУ Липецкая ООШ	f	\N
134044	90084	295	Смоленская область, Новодугинский район, поселок Извеково, здание МКОУ Извековская ООШ	f	\N
134043	90083	294	Смоленская область, Новодугинский район, поселок Днепровское	f	medium
83887	57329	3080	Москва, Зеленоград, к142	f	large
123138	90082	293	Рязанская область, Кораблинский район, поселок Григорьевское	f	small
123137	90080	291	Смоленская область, Новодугинский район, поселок Бурцево, здание МОУ Бурцевская начальная школа - детский сад	f	small
134041	90079	290	Смоленская область, Новодугинский район, поселок Болшево, здание МКОУ Печениченская ООШ	f	\N
123249	90255	468	Смоленская область, Новодугинский район, поселок Бараново, здание Администрации Барановского сельского поселения	f	medium
123132	90072	283	Россия	f	medium
123120	90060	271	Россия	f	small
123119	90059	270	Смоленская область, Монастырщинский район, поселок Соболево	f	small
123134	90074	285	Смоленская область, Монастырщинский район, поселок Раевка	f	small
123118	90058	269	Смоленская область, Монастырщинский район, поселок Октябрьское	f	small
123116	90056	267	Россия	f	small
123023	89942	147	Московская область, Подольский район, деревня Новомихайловское	f	small
75850	89844	49	Смоленская область, Монастырщинский район, поселок Новое Село, Центральная, 61	f	large
123126	90066	277	Смоленская область, Монастырщинский район, поселок Михайловка, помещение администрации Новомихайловского сельского поселения	f	medium
123223	90209	422	Смоленская область, Монастырщинский район, поселок Любавичи, Здание администрации с/п	f	small
123128	90068	279	Россия	f	small
123136	90076	287	Смоленская область, Монастырщинский район, поселок Кадино	f	small
123129	90069	280	Смоленская область, Монастырщинский район, поселок Железняк	f	small
123117	90057	268	Россия	f	small
123122	90062	273	Россия	f	small
123121	90061	272	Россия	f	small
123130	90070	281	Смоленская область, Монастырщинский район, поселок Гоголевка	f	small
123124	90064	275	Смоленская область, Монастырщинский район, поселок Барсуки, помещение администрации Барсуковского сельского поселения	f	small
123123	90063	274	Смоленская область, Монастырщинский район, поселок Барсуки, помещение администрации	f	small
123131	90071	282	Россия	f	small
123233	90219	432	Смоленская область, Краснинский район, поселок Шеровичи, Здание школы	f	small
123109	90049	260	Смоленская область, Краснинский район, поселок Сырокоренье	f	small
123096	90035	246	Смоленская область, Краснинский район, поселок Рогайлово, Центральная, 9	f	small
123100	90039	250	Смоленская область, Краснинский район, поселок Миганово	f	small
123110	90050	261	Смоленская область, Краснинский район, поселок Мерлино, Парковая, 12	f	medium
123108	90048	259	Московская область, Сергиево-Посадский район, деревня Маньково	f	medium
123105	90045	256	Смоленская область, Краснинский район, поселок Лонница	f	medium
123106	90046	257	Смоленская область, Краснинский район, поселок Красное	f	small
123103	90043	254	Смоленская область, Краснинский район, поселок Комиссарово, Здание сельского Дома культуры	f	small
123115	90055	266	Смоленская область, Краснинский район, поселок Зверовичи	f	small
123099	90038	249	Смоленская область, Краснинский район, поселок Двуполяны, Мира, 24, каб. №2	f	small
123098	90037	248	Смоленская область, Краснинский район, поселок Двуполяны, Мира, 24, каб. №3	f	small
123101	90041	252	Смоленская область, Краснинский район, поселок Гусино, Советская, 15	f	medium
75907	90040	251	Смоленская область, Краснинский район, поселок Гусино, Советская, 17	f	large
123102	90042	253	Смоленская область, Краснинский район, поселок Гусино, Молодежная, 1, кв.77	f	medium
123111	90051	262	Смоленская область, Краснинский район, поселок Гребени	f	small
123094	90033	244	Смоленская область, Краснинский район, поселок Викторово	f	small
122994	89896	101	Вологодская область, Вологодский район, село Болтутино	f	small
123226	90212	425	Смоленская область, Краснинский район, поселок Березино	f	medium
123104	90044	255	Смоленская область, Краснинский район, поселок Белеи	f	small
123097	90036	247	Псковская область, Пустошкинский район, село Алушково	f	small
123091	90028	239	Смоленская область, Кардымовский район, поселок Шутовка, Молодежная, 10	f	small
123092	90029	240	Смоленская область, Кардымовский район, поселок Шокино, Молодежнвя, 16	f	small
123093	90030	241	Смоленская область, Кардымовский район, поселок Шестаково, Школьная, 1	f	small
123090	90027	238	Смоленская область, Кардымовский район, поселок Тюшино, Приозёрная, 75	f	medium
70422	78553	634	Рязанская область, Скопин, Ленина, 183	f	large
123088	90025	236	Смоленская область, Кардымовский район, поселок Титково, Центральная, 15	f	small
123083	90020	231	Смоленская область, Кардымовский район, поселок Тверицы, Зеленая, 1	f	small
123089	90026	237	Смоленская область, Кардымовский район, поселок Соловьево, Школьная, 4	f	small
123346	90484	711	Смоленская область, Кардымовский район, поселок Русаново, помещение администрации Русановского сельского поселения	f	small
123082	90019	230	Смоленская область, Кардымовский район, поселок Пищулино, Школа-интернат, 17, актовый зал школы-интернат	f	medium
123086	90023	234	Смоленская область, Кардымовский район, поселок Нетризово, Школьная, 4	f	small
123085	90022	233	Смоленская область, Кардымовский район, поселок Мольково, Административная, 7	f	medium
75903	90016	227	Смоленская область, Кардымовский район, поселок Кардымово, Школьная, 4, актовый зал Кардымовской школы	f	large
75904	90017	228	Смоленская область, Кардымовский район, поселок Кардымово, Ленина, 18, актовый зал Центра культуры	f	large
123084	90021	232	Смоленская область, Кардымовский район, поселок Каменка, Центральная, 13, здание Администрации с/п	f	medium
123087	90024	235	Смоленская область, Кардымовский район, поселок Вачково	f	small
123081	90018	229	Смоленская область, Кардымовский район, поселок Варваровщина, Центральная, 20 	f	small
122993	89895	100	Смоленская область, Кардымовский район, поселок Березкино, здание Администрации сельского поселения	f	small
123071	90006	217	Тверская область, Торжокский район, поселок Сукромля	f	small
123077	90012	223	Смоленская область, Ершичский район, поселок Рухань	f	small
123076	90011	222	Смоленская область, Ершичский район, деревня Поселки	f	small
76116	90536	762	Смоленская область, Ершичский район, поселок Первомайский, Никольская, 38	f	large
123075	90010	221	Смоленская область, Ершичский район, поселок Малая Язовка	f	small
123080	90015	226	Архангельская область, Няндомский район, село Лужная	f	small
123073	90008	219	Воронежская область, Острогожский район, поселок Литвиновка	f	small
123074	90009	220	Волгоградская область, Городищенский район, село Кузьмичи	f	small
123079	90014	225	Смоленская область, Ершичский район, поселок Корсики	f	small
123078	90013	224	Смоленская область, Ершичский район, поселок Карды	f	small
75902	90003	214	Смоленская область, Ершичский район, поселок Ершичи, Понятовская, 11	f	large
123070	90005	216	Смоленская область, Ершичский район, поселок Егоровка	f	small
123072	90007	218	Смоленская область, Ершичский район, поселок Ворга, Ленина, 3	f	medium
123069	90004	215	Смоленская область, Ершичский район, поселок Блинные Кучи	f	small
123058	89992	203	Смоленская область, Ельнинский район, поселок Шарапово, помещение Администрации Леонидовского сельского поселения	f	small
123066	90000	211	Смоленская область, Ельнинский район, поселок Фенино	f	small
123068	90002	213	Московская область, Павлово-Посадский район, деревня Теренино	f	small
123067	90001	212	Смоленская область, Ельнинский район, поселок Старое Устиново	f	small
123063	89997	208	Россия	f	small
123065	89999	210	Смоленская область, Ельнинский район, поселок Пронино	f	small
123061	89995	206	Смоленская область, Ельнинский район, поселок Мазово	f	small
123059	89993	204	Смоленская область, Ельнинский район, поселок Леоново, помещение МБОУ Леоновской основной школы	f	small
123056	89990	201	Смоленская область, Ельнинский район, поселок Лапино	f	small
123054	89988	199	Смоленская область, Ельнинский район, поселок Коробец	f	small
123053	89987	198	Россия	f	small
123060	89994	205	Россия	f	small
123052	89986	197	Россия	f	small
123222	90208	421	Смоленская область, Ельнинский район, поселок Волково, Здание ФАП	f	small
123051	89985	196	Смоленская область, Ельнинский район, поселок Богородицкое, помещение Администрации Бобровичского сельского поселения	f	small
76095	90407	635	Смоленская область, Ельнинский район, поселок Богородицкое, Викторова, 23	f	large
123047	89976	187	Смоленская область, Духовщинский район, поселок Шиловичи, 52	f	small
123048	89977	188	Смоленская область, Духовщинский район, поселок Третьяково, Московская, 18	f	small
123050	89979	190	Смоленская область, Духовщинский район, поселок Спас-Углы, Центральная, 5	f	small
122974	89874	79	Смоленская область, Духовщинский район, поселок Пречистое, администрация сельского поселения	f	medium
123045	89974	185	Смоленская область, Духовщинский район, поселок Пречистое, Б. Советская, 24 	f	medium
123036	89965	176	Смоленская область, Духовщинский район, поселок Петрищево, Центральная, 17, здание Администрации СП	f	small
75895	89961	172	Смоленская область, Духовщинский район, поселок Озерный, Парковая, 5	f	large
75896	89962	173	Смоленская область, Духовщинский район, поселок Озерный, Строителей, 22	f	large
123038	89967	178	Смоленская область, Духовщинский район, поселок Митяево, Центральная, 1	f	small
123170	90125	334	Смоленская область, Духовщинский район, поселок Липки, 42, Здание школы	f	small
123041	89970	181	Смоленская область, Духовщинский район, поселок Зимец, Центральная, 25	f	small
123040	89969	180	Смоленская область, Духовщинский район, поселок Ерыши, Центральная, 6	f	small
75893	89959	170	Смоленская область, Духовщинский район, Духовщина, Бугаева, 44/47А	f	large
123043	89972	183	Смоленская область, Духовщинский район, поселок Добрино, Школьная, 1, здание школы	f	small
123044	89973	184	Смоленская область, Духовщинский район, поселок Воронцово, Школьная, 4	f	small
123046	89975	186	Смоленская область, Духовщинский район, поселок Верешковичи 1-е, 8	f	small
123042	89971	182	Смоленская область, Духовщинский район, поселок Велисто, Центральная, 12	f	small
123037	89966	177	Смоленская область, Духовщинский район, поселок Большое Береснево, Лесная, 3	f	small
123034	89963	174	Смоленская область, Духовщинский район, поселок Бабино, Солнечная, 4	f	small
123112	90052	263	Россия, Смоленская область, Дорогобужский район, нежилой населенный пункт Марково	f	small
123024	89943	148	Ленинградская область, Лужский район, деревня Шаломино	f	small
123030	89949	154	Курская область, деревня Ушаково	f	small
123029	89948	153	Смоленская область, Дорогобужский район, поселок Усвятье	f	small
123028	89947	152	Смоленская область, Дорогобужский район, поселок Слоиково	f	small
123032	89951	156	Смоленская область, Дорогобужский район, поселок Садовая	f	medium
123027	89946	151	Тверская область, Торопецкий район, поселок Полибино	f	small
123031	89950	155	Смоленская область, Дорогобужский район, поселок Мархоткино	f	small
123021	89940	145	Ярославская область, Первомайский район, поселок Княщина	f	small
123026	89945	150	Ленинградская область, Волосовский район, деревня Каськово	f	small
122997	89900	105	Смоленская область, Дорогобужский район, поселок Ивонино, здание Дома культуры	f	small
75882	88986	159	Смоленская область, Дорогобужский район, Дорогобуж, Лермонтова, 18	f	large
123033	89952	157	Смоленская область, Дорогобужский район, Дорогобуж, Карла Маркса , 176А	f	medium
75892	89958	169	Смоленская область, Дорогобужский район, поселок Верхнеднепровский, Советская, 1	f	large
75891	89957	168	Смоленская область, Дорогобужский район, поселок Верхнеднепровский, Молодежная, 5	f	large
75890	89956	167	Смоленская область, Дорогобужский район, поселок Верхнеднепровский, Молодежная, 19	f	large
75888	89955	165	Смоленская область, Дорогобужский район, поселок Верхнеднепровский, Комсомольская, 20	f	large
75887	89954	164	Смоленская область, Дорогобужский район, поселок Верхнеднепровский, Комсомольская, 18	f	large
75889	89954	166	Смоленская область, Дорогобужский район, поселок Верхнеднепровский, Комсомольская, 18	f	large
123020	89939	144	Смоленская область, Дорогобужский район, поселок Васино, Здание Администрации Васинского с/п	f	small
123019	89938	143	Смоленская область, Дорогобужский район, поселок Быково, Здание Администрации Балакиревского с/п	f	small
123009	89916	121	Смоленская область, Демидовский район, поселок Шапы, Боровая, 15, здание МБОУ Шаповская ООШ	f	small
123008	89915	120	Смоленская область, Демидовский район, поселок Центральная Усадьба, Дорожная, 11, здание Администрации	f	small
123049	89978	189	Смоленская область, Демидовский район, поселок Троицкое, Школьная, 9 , здание школы	f	small
123007	89914	119	Смоленская область, Демидовский район, поселок Титовщина, Центральная, 18, здание Титовщинского СДК	f	small
75870	89917	122	Смоленская область, Демидовский район, поселок Пржевальское, Советская, 23, здание Администрации	f	large
123010	89918	123	Смоленская область, Демидовский район, поселок Пржевальское, Курортная, 1, здание санатория	f	small
122959	89846	51	Смоленская область, Вяземский район, поселок Черное, Окружная, 5, кв.1	f	small
123011	89919	124	Смоленская область, Демидовский район, поселок Пржевальское, 1 Мая, 2, здание Администрации	f	small
123017	89925	130	Смоленская область, Демидовский район, поселок Подосинки, Лесная, 8, здание Администрации	f	small
123012	89920	125	Смоленская область, Демидовский район, поселок Корево, Ямская, 2 здание Администрации	f	small
123016	89924	129	Смоленская область, Демидовский район, поселок Закрутье, Центральная, 19, здание МБОУ Бурлыгинская ООШ	f	small
123127	90067	278	Смоленская область, Демидовский район, поселок Жуково, помещение Жуковского сельского клуба	f	small
123006	89913	118	Смоленская область, Демидовский район, поселок Жичицы, Егорова, 28, здание Жичицкого СДК	f	small
123005	89912	117	Смоленская область, Демидовский район, поселок Дубровка, Парковая, 19 , 19 здание Дубровского СДК	f	small
123002	89909	114	Смоленская область, Демидовский район, поселок Верхнии Моховичи, Парковая, 2, здание Администрации	f	small
123003	89910	115	Смоленская область, Демидовский район, поселок Борода, Верхняя, 10 , здание Администрации	f	small
123238	90224	437	Смоленская область, Демидовский район, поселок Борки, Здание дома культуры	f	small
123013	89921	126	Смоленская область, Демидовский район, поселок Бакланово, Центральная, 54, здание Администрации	f	small
122999	89902	107	Смоленская область, Глинковский район, поселок Ханино, здание Новоханинской школы	f	small
123000	89903	108	Республика Бурятия, Бичурский район, село Петропавловка	f	small
122998	89901	106	Смоленская область, Глинковский район, поселок Новобрыкино	f	small
122996	89899	104	Смоленская область, Глинковский район, поселок Дубосище	f	small
122995	89898	103	Смоленская область, Глинковский район, поселок Добромино	f	small
75865	89897	102	Смоленская область, Глинковский район, поселок Глинка, Ленина, 5Б	f	large
122992	89894	99	Смоленская область, Глинковский район, поселок Белый Холм, здание Администрации сельского поселения	f	small
122972	89871	76	Смоленская область, Гагаринский район, поселок Черногубцево, Черногубцевская сельская библиотека	f	small
122985	89886	91	Смоленская область, Гагаринский район, поселок Токарево, администрация сельского поселения	f	medium
122984	89885	90	Смоленская область, Гагаринский район, поселок Серго-Ивановское, администрация сельского поселения	f	medium
122982	89883	88	Смоленская область, Гагаринский район, поселок Родоманово, Родомановский Дом культуры	f	medium
122988	89889	94	Смоленская область, Гагаринский район, поселок Пышково, Пышковская основная школа	f	small
134039	89879	84	Смоленская область, Гагаринский район, поселок Покров, Центральная, 11, помещение СПК Мишино	f	\N
122977	89877	82	Владимирская область, Петушинский район, Петушки	f	small
123318	90448	676	Смоленская область, Гагаринский район, поселок Никольское, помещение администрации Никольского с/п	f	small
122979	89880	85	Смоленская область, Гагаринский район, поселок Молоченево, Молоченевская сельская библиотека	f	small
122975	89875	80	Смоленская область, Гагаринский район, поселок Липцы, Липецкий клуб	f	small
122991	89893	98	Смоленская область, Гагаринский район, поселок Колокольня, Колокольнинская основная школа	f	small
122989	89890	95	Смоленская область, Гагаринский район, поселок Клушино, Клушинский Дом культуры	f	medium
75863	89873	78	Смоленская область, Гагаринский район, поселок Карманово, МУК Кармановский КДЦ	f	large
122983	89884	89	Смоленская область, Гагаринский район, поселок Ивино, Ивинская основная школа	f	small
123194	90175	384	Смоленская область, Гагаринский район, поселок Ивановское, здание администрации Ивановского сельского поселения	f	small
122970	89866	71	Смоленская область, Гагаринский район, Гагарин, микрорайон Лесной, адм.здание Гагаринского лесхоза	f	medium
122978	89878	83	Смоленская область, Гагаринский район, поселок Баскаково, Баскаковская средняя школа	f	medium
75862	89870	75	Смоленская область, Гагаринский район, поселок Ашково, Ашковская средняя школа	f	large
122981	89882	87	Смоленская область, Гагаринский район, поселок Астахово, Астаховская основная школа	f	small
122986	89887	92	Смоленская область, Гагаринский район, поселок Акатово, Акатовский Дом культуры	f	small
122968	89856	61	Смоленская область, Вяземский район, поселок Шуйское, Новоселов, 21	f	small
122961	89848	53	Смоленская область, Вяземский район, поселок Черемушки, Школьная, 15	f	medium
122967	89855	60	Смоленская область, Вяземский район, поселок Царево-Займище	f	small
122966	89854	59	Смоленская область, Вяземский район, поселок Хмелита, Центральная, 11	f	small
122951	89836	41	Смоленская область, Вяземский район, поселок Хватов Завод	f	small
122949	89834	39	Смоленская область, Вяземский район, поселок Успенское, Успенская, 3	f	medium
75851	89853	58	Смоленская область, Вяземский район, поселок Туманово, Почтовая, 6	f	large
122962	89849	54	Смоленская область, Вяземский район, поселок Семлево, Советская, 12	f	medium
122963	89850	55	Смоленская область, Вяземский район, поселок Семлево, Ленина, 50	f	medium
123266	90272	485	Смоленская область, Вяземский район, поселок Пушкино, здание Администрации Пушкинского сельского поселения	f	small
122960	89847	52	Смоленская область, Вяземский район, поселок Поляново, Гагарина, 1	f	small
122958	89845	50	Смоленская область, Вяземский район, поселок Относово, Школьная, 7	f	medium
122964	89851	56	Смоленская область, Вяземский район, поселок Новый, Рабочая	f	medium
122965	89852	57	Смоленская область, Вяземский район, поселок Новоникольское, здание Ново-Никольского дома-интерната	f	small
122954	89840	45	Смоленская область, Вяземский район, поселок Малая Калпита, Молодёжная, 11	f	small
122943	89802	4	Смоленская область, Вяземский район, поселок Крутое, Помещение МБОУ Крутовская ООШ	f	small
122955	89841	46	Смоленская область, Вяземский район, поселок Касня, Ленина	f	medium
123140	90086	297	Смоленская область, Вяземский район, поселок Капустино, Здание Администрации	f	small
75849	89839	44	Смоленская область, Вяземский район, поселок Кайдаково, Парковая, 17	f	large
122953	89838	43	Смоленская область, Вяземский район, поселок Исаково, Школьная, 8	f	medium
122957	89843	48	Смоленская область, Вяземский район, поселок Дмитровка, здание Администрации Мещерского с/п	f	small
123181	90136	345	Смоленская область, Вяземский район, поселок Денисово, 5, Здание администрации поселения	f	medium
75848	89833	38	Смоленская область, Вяземский район, поселок Вязьма Брянская, Авиационная, 1а	f	large
75847	89832	37	Смоленская область, Вяземский район, поселок Вязьма Брянская, 50 лет Победы	f	large
75841	89825	30	Смоленская область, Вяземский район, Вязьма, Песочная, 2	f	large
75839	89823	28	Смоленская область, Вяземский район, Вязьма, Кашена, 15	f	large
122956	89842	47	Смоленская область, Вяземский район, поселок Богородицкое, 62, здание Администрации Масловского с/п	f	small
75846	89831	36	Смоленская область, Вяземский район, поселок Андрейково, Ленина, 10	f	large
122947	89806	8	Смоленская область, Велижский район, поселок Ситьково	f	medium
122946	89805	7	Россия	f	medium
122945	89804	6	Россия	f	small
122944	89803	5	Россия	f	small
75822	89808	10	Смоленская область, Велижский район, Велиж, Володарского, 11	f	large
122941	89800	2	Смоленская область, Велижский район, поселок Будница	f	small
122940	89799	1	Смоленская область, Велижский район, поселок Беляево, Помещение Администрации Беляевского сп	f	small
70458	78762	804	Рязанская область, Шацк, Цюрупы	f	large
116424	78368	482	Рязанская область, Рязанский район, деревня Хирино	f	medium
70389	78365	479	Рязанская область, поселок Турлатово	f	large
116550	78578	657	Рязанская область, Спасск-Рязанский, Набережная, 30	f	medium
70445	78574	653	Рязанская область, Спасск-Рязанский, Ломоносова, 34	f	large
70442	78567	648	Рязанская область, Скопин, мкр.Октябрьский	f	large
116546	78568	649	Рязанская область, Скопин, мкр.Комсомольский	f	small
116547	78571	650	Рязанская область, Скопин, мкр.Коготково	f	medium
70443	78572	651	Рязанская область, Скопин, мкр.Заречный	f	large
116544	78555	636	Рязанская область, Скопин, Пушкина, 84	f	medium
70435	78560	641	Рязанская область, Скопин, Поташная, 3а	f	large
70434	78559	640	Рязанская область, Скопин, Площадь Ленина, 1	f	large
70423	78554	635	Рязанская область, Скопин, Орджоникидзе, 139	f	large
116545	78558	639	Рязанская область, Скопин, Октябрьская, 26	f	medium
70441	78566	647	Рязанская область, Скопин, Мира, 12	f	large
70440	78565	646	Рязанская область, Скопин, Мира, 4	f	large
70433	78556	638	Рязанская область, Скопин, Ленина, 19	f	large
70432	78556	637	Рязанская область, Скопин, Ленина, 19	f	large
70438	78563	644	Рязанская область, Скопин, Карла Маркса, 259	f	large
70436	78561	642	Рязанская область, Скопин, Карла Маркса, 162а	f	large
70439	78564	645	Рязанская область, Скопин, Автозаводской микрорайон, 6	f	large
70437	78562	643	Рязанская область, Скопин, Автозаводской микрорайон, 22	f	large
116416	78350	468	Рязанская область, Секиотово	f	medium
116500	78465	562	Рязанская область, Сасово, администрация сельского поселения	f	small
70414	78506	595	Рязанская область, Сасово, микрорайон Южный, 38 , детский сад	f	large
70413	78505	594	Рязанская область, Сасово, микрорайон Южный, 36, детский сад	f	large
70412	78504	593	Рязанская область, Сасово, микрорайон Южный, 35, детский сад	f	large
70407	78501	588	Рязанская область, Сасово, микрорайон Южный, 44а, поликлинника	f	large
70405	78499	586	Рязанская область, Сасово, микрорайон Южный, 57, школа	f	large
70411	78503	592	Рязанская область, Сасово, микрорайон Северный, 57, ДК	f	large
70410	78503	591	Рязанская область, Сасово, микрорайон Северный, 57, ДК	f	large
70409	78502	590	Рязанская область, Сасово, микрорайон Северный, 40, школа	f	large
70408	78502	589	Рязанская область, Сасово, микрорайон Северный, 40, школа	f	large
70401	78495	582	Рязанская область, Сасово, Типанова, 2, Управление образования	f	large
70400	78494	581	Рязанская область, Сасово, Свободы проспект, 19а, кафе Цна	f	large
70402	78496	583	Рязанская область, Сасово, Пушкина, 106 школа	f	large
70404	78498	585	Рязанская область, Сасово, Островитянова, 133, Распределительные сети	f	large
70398	78492	579	Рязанская область, Сасово, Ново-Елатомская, 31, школа	f	large
70397	78491	578	Рязанская область, Сасово, Ново-Елатомская, 31, школа	f	large
70399	78493	580	Рязанская область, Сасово, Ленина, 34 , школа	f	large
70396	78490	577	Рязанская область, Сасово, Ленина, 42, техникум	f	large
70406	78500	587	Рязанская область, Сасово, Киевская, 6 , детский сад	f	large
70403	78497	584	Рязанская область, Сасово, Вокзальная, 18, ДК	f	large
70554	78862	897	Рязанская область, Рязань, 25	f	large
70553	78862	896	Рязанская область, Рязань, 25	f	large
70555	78862	898	Рязанская область, Рязань, 25	f	large
70252	78933	1019	Рязанская область, Рязань, поселок Черезово-Песочня, улица Новоселов, 58	f	large
70275	78947	1042	Рязанская область, Рязань, проезд Щедрина, 14	f	large
70274	78947	1041	Рязанская область, Рязань, проезд Щедрина, 14	f	large
70598	78889	944	Рязанская область, Рязань, поселок Приокский, проезд Шабулина, 20	f	large
70481	78845	872	Рязанская область, Рязань, проезд Гоголя, 5	f	large
70480	78845	871	Рязанская область, Рязань, проезд Гоголя, 5	f	large
70504	78893	951	Рязанская область, Рязань, Юбилейная , 24	f	large
70505	78893	952	Рязанская область, Рязань, Юбилейная , 24	f	large
70261	78938	1028	Рязанская область, Рязань, Электрозаводская, 56	f	large
70260	78938	1027	Рязанская область, Рязань, Электрозаводская, 56	f	large
70478	78843	869	Рязанская область, Рязань, Щорса, 38/11	f	large
70476	78841	867	Рязанская область, Рязань, Черновицкая, 23а	f	large
70475	78841	866	Рязанская область, Рязань, Черновицкая, 23а	f	large
70474	78840	865	Рязанская область, Рязань, Черновицкая, 23а	f	large
70531	78914	982	Рязанская область, Рязань, Трудовая, 6/6	f	large
70530	78914	981	Рязанская область, Рязань, Трудовая, 6/6	f	large
116726	78914	980	Рязанская область, Рязань, Трудовая, 6/6	f	medium
70472	78839	863	Рязанская область, Рязань, Толстого, 5	f	large
70473	78838	864	Рязанская область, Рязань, Толстого, 5	f	large
70471	78838	862	Рязанская область, Рязань, Толстого, 5	f	large
70540	78920	992	Рязанская область, Рязань, Тимуровцев, 4	f	large
70539	78920	991	Рязанская область, Рязань, Тимуровцев, 4	f	large
70246	78930	1013	Рязанская область, Рязань, Тимакова, 7	f	large
70245	78930	1012	Рязанская область, Рязань, Тимакова, 7	f	large
70244	78930	1011	Рязанская область, Рязань, Тимакова, 7	f	large
70243	78929	1010	Рязанская область, Рязань, Тимакова, 9	f	large
70242	78929	1009	Рязанская область, Рязань, Тимакова, 9	f	large
70484	78847	876	Рязанская область, Рязань, Стройкова, 86	f	large
70483	78847	875	Рязанская область, Рязань, Стройкова, 86	f	large
70281	78884	1049	Рязанская область, Рязань, Солнечная, 6	f	large
70543	78922	995	Рязанская область, Рязань, Советской Армии, 24к1	f	large
70546	78923	998	Рязанская область, Рязань, Советской Армии, 15а	f	large
70545	78923	997	Рязанская область, Рязань, Советской Армии, 15а	f	large
70544	78923	996	Рязанская область, Рязань, Советской Армии, 15а	f	large
70604	78960	1057	Рязанская область, Рязань, Соборная площадь, 15	f	large
70603	78959	1056	Рязанская область, Рязань, Семинарская, 6	f	large
70280	78952	1048	Рязанская область, Рязань, Семинарская, 44/3	f	large
70526	78909	974	Рязанская область, Рязань, Семашко, 18	f	large
70569	78870	914	Рязанская область, Рязань, Сельских Строителей, 4а	f	large
70568	78870	913	Рязанская область, Рязань, Сельских Строителей, 4а	f	large
70567	78870	912	Рязанская область, Рязань, Сельских Строителей, 4а	f	large
70256	78935	1023	Рязанская область, Рязань, Связи, 17а	f	large
70258	78936	1025	Рязанская область, Рязань, Связи, 17а	f	large
70257	78936	1024	Рязанская область, Рязань, Связи, 17а	f	large
70277	78949	1044	Рязанская область, Рязань, Свободы, 46	f	large
70529	78913	979	Рязанская область, Рязань, Предзаводская, 17	f	large
70528	78913	978	Рязанская область, Рязань, Предзаводская, 17	f	large
70525	78908	973	Рязанская область, Рязань, Полетаева, 30к1	f	large
70566	78869	911	Рязанская область, Рязань, Полетаева, 14	f	large
70286	78956	1053	Рязанская область, Рязань, Полевая, 38	f	large
70283	78954	1051	Рязанская область, Рязань, Первомайский проспект, 17	f	large
70282	78953	1050	Рязанская область, Рязань, Первомайский проспект, 17	f	large
70565	78868	908	Рязанская область, Рязань, Первомайский проспект, 62к1	f	large
70564	78868	907	Рязанская область, Рязань, Первомайский проспект, 62к1	f	large
70563	78867	906	Рязанская область, Рязань, Первомайский проспект, 68	f	large
70562	78867	905	Рязанская область, Рязань, Первомайский проспект, 68	f	large
70561	78866	904	Рязанская область, Рязань, Первомайский проспект, 61	f	large
70482	78846	873	Рязанская область, Рязань, Островского, 44	f	large
70470	78837	861	Рязанская область, Рязань, Островского, 33к1	f	large
70469	78836	860	Рязанская область, Рязань, Островского, 24	f	large
70550	78860	893	Рязанская область, Рязань, Октябрьский Городок, 39а	f	large
70590	78882	936	Рязанская область, Рязань, поселок Приокский, Октябрьская улица, 5	f	large
70589	78882	935	Рязанская область, Рязань, поселок Приокский, Октябрьская улица, 5	f	large
70593	78886	939	Рязанская область, Рязань, Октябрьская , 37	f	large
70596	78887	942	Рязанская область, Рязань, Октябрьская, 56а	f	large
70595	78887	941	Рязанская область, Рязань, Октябрьская, 56а	f	large
70594	78887	940	Рязанская область, Рязань, Октябрьская, 56а	f	large
70238	78926	1005	Рязанская область, Рязань, Новоселов, 30б	f	large
70607	78926	1004	Рязанская область, Рязань, Новоселов, 30б	f	large
70541	78921	993	Рязанская область, Рязань, Новоселов, 6а	f	large
70542	78921	994	Рязанская область, Рязань, Новоселов, 6а	f	large
70509	78895	956	Рязанская область, Рязань, Новаторов, 21а	f	large
70508	78895	955	Рязанская область, Рязань, Новаторов, 21а	f	large
70507	78894	954	Рязанская область, Рязань, Новаторов, 21	f	large
70506	78894	953	Рязанская область, Рязань, Новаторов, 21	f	large
70602	78958	1055	Рязанская область, Рязань, Николодворянская , 19/40	f	large
70479	78844	870	Рязанская область, Рязань, Нахимова, 1	f	large
70477	78842	868	Рязанская область, Рязань, Нахимова, 13	f	large
70513	78899	961	Рязанская область, Рязань, Московское шоссе, 18	f	large
70556	78863	899	Рязанская область, Рязань, Михайловское шоссе, 63 , Рязаньагроснаб	f	large
70276	78948	1043	Рязанская область, Рязань, Лесопарковая, 52	f	large
70265	78940	1032	Рязанская область, Рязань, Лермонтова, 2	f	large
70263	78940	1030	Рязанская область, Рязань, Лермонтова, 2	f	large
70264	78940	1031	Рязанская область, Рязань, Лермонтова, 2	f	large
70262	78939	1029	Рязанская область, Рязань, Лермонтова, 22	f	large
70495	78855	887	Рязанская область, Рязань, Ленинского Комсомола, 13	f	large
70494	78855	886	Рязанская область, Рязань, Ленинского Комсомола, 13	f	large
70492	78853	884	Рязанская область, Рязань, Ленинского Комсомола, 7	f	large
70601	78957	1054	Рязанская область, Рязань, Ленина, 29	f	large
70285	78950	1045	Рязанская область, Рязань, Ленина, 28	f	large
70271	78945	1038	Рязанская область, Рязань, Ленина, 1/70	f	large
70534	78916	985	Рязанская область, Рязань, Куйбышевское шоссе, 2/1	f	large
70533	78916	984	Рязанская область, Рязань, Куйбышевское шоссе, 2/1	f	large
83886	57328	3078	Москва, Зеленоград, к2031	f	large
70532	78915	983	Рязанская область, Рязань, Куйбышевское шоссе, 9	f	large
70284	78955	1052	Рязанская область, Рязань, Кудрявцева, 36	f	large
70512	78898	960	Рязанская область, Рязань, Крупской, 17	f	large
70503	78892	950	Рязанская область, Рязань, Крупской, 7	f	large
70502	78892	949	Рязанская область, Рязань, Крупской, 7	f	large
70591	78883	937	Рязанская область, Рязань, Космонавтов, 13	f	large
70551	78861	894	Рязанская область, Рязань, Керамзавода, 8а	f	large
70552	78861	895	Рязанская область, Рязань, Керамзавода, 8а	f	large
70548	78924	1000	Рязанская область, Рязань, Касимовское шоссе, 38б	f	large
70547	78924	999	Рязанская область, Рязань, Касимовское шоссе, 38б	f	large
70266	78852	1033	Рязанская область, Рязань, Касимовское шоссе, 9	f	large
70267	78852	1034	Рязанская область, Рязань, Касимовское шоссе, 9	f	large
70251	78932	1018	Рязанская область, Рязань, Зубковой, 28а	f	large
70250	78932	1017	Рязанская область, Рязань, Зубковой, 28а	f	large
70249	78932	1016	Рязанская область, Рязань, Зубковой, 28а	f	large
70247	78931	1014	Рязанская область, Рязань, Зубковой, 27	f	large
70248	78931	1015	Рязанская область, Рязань, Зубковой, 27	f	large
70240	78927	1007	Рязанская область, Рязань, Зубковой, 22а	f	large
70239	78927	1006	Рязанская область, Рязань, Зубковой, 22а	f	large
70253	78832	1020	Рязанская область, Рязань, Зубковой, 30к2	f	large
70523	78906	971	Рязанская область, Рязань, Забайкальская	f	large
70522	78906	970	Рязанская область, Рязань, Забайкальская	f	large
70537	78918	988	Рязанская область, Рязань, Есенина, 57	f	large
70536	78918	987	Рязанская область, Рязань, Есенина, 57	f	large
70272	78937	1039	Рязанская область, Рязань, Есенина, 46	f	large
70259	78937	1026	Рязанская область, Рязань, Есенина, 46	f	large
70489	78850	881	Рязанская область, Рязань, Дзержинского, 78	f	large
70488	78850	880	Рязанская область, Рязань, Дзержинского, 78	f	large
70493	78854	885	Рязанская область, Рязань, Дзержинского, 42	f	large
70491	78851	883	Рязанская область, Рязань, Дзержинского, 71	f	large
70490	78851	882	Рязанская область, Рязань, Дзержинского, 71	f	large
70592	78885	938	Рязанская область, Рязань, Дачная, 2а	f	large
70270	78944	1037	Рязанская область, Рязань, Горького, 49	f	large
70273	78946	1040	Рязанская область, Рязань, Вознесенская, 44	f	large
70515	78900	963	Рязанская область, Рязань, Вишневая, 35	f	large
70514	78900	962	Рязанская область, Рязань, Вишневая, 35	f	large
70557	78864	900	Рязанская область, Рязань, Весенняя, 14	f	large
70501	78891	948	Рязанская область, Рязань, Великанова, 9	f	large
70500	78891	947	Рязанская область, Рязань, Великанова, 9	f	large
70600	78891	946	Рязанская область, Рязань, Великанова, 9	f	large
70269	78943	1036	Рязанская область, Рязань, Введенская, 131	f	large
70582	78879	928	Рязанская область, Рязань, Бирюзова, 25а	f	large
70581	78879	927	Рязанская область, Рязань, Бирюзова, 25а	f	large
70580	78878	926	Рязанская область, Рязань, Бирюзова, 23а	f	large
70578	78876	924	Рязанская область, Рязань, Бирюзова, 19а	f	large
70576	78875	922	Рязанская область, Рязань, Бирюзова, 13а	f	large
70577	78875	923	Рязанская область, Рязань, Бирюзова, 13а	f	large
70571	78871	916	Рязанская область, Рязань, Бирюзова, 2	f	large
70570	78871	915	Рязанская область, Рязань, Бирюзова, 2	f	large
70521	78905	969	Рязанская область, Рязань, Белякова, 7а	f	large
70520	78904	968	Рязанская область, Рязань, Белякова, 1	f	large
70519	78904	967	Рязанская область, Рязань, Белякова, 1	f	large
70516	78901	964	Рязанская область, Рязань, Бахмачевская, 34	f	large
70527	78910	976	Рязанская область, Рязань, Баженова, 36к1	f	large
70518	78902	966	Рязанская область, Рязань, Аллейная, 52	f	large
70517	78902	965	Рязанская область, Рязань, Аллейная, 52	f	large
70498	78858	890	Рязанская область, Рязань, 9-я линия, 18	f	large
70279	78951	1047	Рязанская область, Рязань, 9-й район	f	large
70278	78951	1046	Рязанская область, Рязань, 9-й район	f	large
70485	78848	877	Рязанская область, Рязань, 50-летия Октября площадь, МАУК Дворец молодежи города Рязани	f	large
70497	78857	889	Рязанская область, Рязань, 2-я линия, 25а	f	large
70496	78856	888	Рязанская область, Рязань, 2-я Линия, 25	f	large
70549	78859	892	Рязанская область, Рязань, 12-я линия, 1г	f	large
70499	78859	891	Рязанская область, Рязань, 12-я линия, 1г	f	large
111561	57328	3079	Москва, Зеленоград, к2031	f	medium
70255	78934	1022	Рязанская область, Рязань, 1-я Механизаторов, 25а	f	large
70254	78934	1021	Рязанская область, Рязань, 1-я Механизаторов, 25а	f	large
70599	78890	945	Рязанская область, Рязань, 1-я Красная, 22	f	large
134936	95165	1058	Рязанская область, Рязань, Южный промузел, 8, ЗАО РНПК	f	medium
70560	78865	903	Рязанская область, Рязань, Чкалова, 9а	f	large
70559	78865	902	Рязанская область, Рязань, Чкалова, 9а	f	large
70558	78865	901	Рязанская область, Рязань, Чкалова, 9а	f	large
70535	78917	986	Рязанская область, Рязань, Циолковского, 22	f	large
70538	78919	990	Рязанская область, Рязань, Урицкого, 2а	f	large
70524	78907	972	Рязанская область, Рязань, Сельских Строителей, 4а, Средняя общеобразовательная школа №70	f	large
70597	78888	943	Рязанская область, Рязань, Пирогова, 11	f	large
70606	78925	1002	Рязанская область, Рязань, Новоселов, 17к1	f	large
70605	78925	1001	Рязанская область, Рязань, Новоселов, 17к1	f	large
70241	78928	1008	Рязанская область, Рязань, Новоселов, 28	f	large
70511	78897	959	Рязанская область, Рязань, Костычева, 1	f	large
70510	78897	958	Рязанская область, Рязань, Костычева, 1	f	large
70588	78881	934	Рязанская область, Рязань, Карла Маркса, 4 к1	f	large
70587	78881	933	Рязанская область, Рязань, Карла Маркса, 4 к1	f	large
70575	78874	921	Рязанская область, Рязань, Интернациональная, 5д, Детский центр	f	large
70586	78880	932	Рязанская область, Рязань, Интернациональная, 27	f	large
70584	78880	930	Рязанская область, Рязань, Интернациональная, 27	f	large
70583	78880	929	Рязанская область, Рязань, Интернациональная, 27	f	large
70585	78880	931	Рязанская область, Рязань, Интернациональная, 27	f	large
70574	78872	919	Рязанская область, Рязань, Интернациональная, 6	f	large
70573	78872	918	Рязанская область, Рязань, Интернациональная, 6	f	large
70572	78872	917	Рязанская область, Рязань, Интернациональная, 6	f	large
70487	78849	879	Рязанская область, Рязань, Гагарина, 158	f	large
70486	78849	878	Рязанская область, Рязань, Гагарина, 158	f	large
70579	78877	925	Рязанская область, Рязань, Бирюзова, 19а	f	large
70379	78274	407	Рязанская область, Ряжск, Строителей, 17, детский сад №8	f	large
116374	78285	418	Рязанская область, Ряжск, Пожалостина, 15	f	small
116373	78284	417	Рязанская область, Ряжск, Новоряжская, 31, школа №4	f	medium
70384	78279	412	Рязанская область, Ряжск, Мичуринская, 122, клуб	f	large
70388	78283	416	Рязанская область, Ряжск, Лермонтова, 2, дом детства	f	large
70387	78282	415	Рязанская область, Ряжск, Кольцова, 28А, детский сад №1	f	large
70383	78278	411	Рязанская область, Ряжск, Горького, 115, техникум	f	large
70381	78276	409	Рязанская область, Ряжск, Гагарина, 11, Библиотека	f	large
70378	78239	406	Рязанская область, Ряжск, Волгоградская, детский сад №6	f	large
70368	78263	395	Рязанская область, Рыбное, Набережный переулок, 2, школа № 1	f	large
70371	78267	399	Рязанская область, Рыбное, Мира, 18, МОУ Лицей г.Рыбное	f	large
116372	78265	397	Рязанская область, Рыбное, Куйбышева, 96, школа №5	f	medium
116401	78325	450	Рязанская область, Новоселки	f	medium
70321	78058	222	Рязанская область, Михайлов, Воеводина, 9-а , ПУ 25	f	large
70337	77981	165	Рязанская область, Кораблино, Коминтерна, 36	f	large
116140	77931	114	Рязанская область, Касимов, академика В.Ф. Уткина, 5 , ДК	f	medium
116139	77930	113	Рязанская область, Касимов, Широкая, 11, Детский сад	f	medium
70316	77941	125	Рязанская область, Касимов, Татарская, 7	f	large
70311	77937	120	Рязанская область, Касимов, Советская, 226, МП Городская управляющая компания	f	large
70310	77936	119	Рязанская область, Касимов, Советская, 199	f	large
70309	77935	118	Рязанская область, Касимов, Советская, 195В	f	large
70306	77932	115	Рязанская область, Касимов, Советская, 18	f	large
70302	77925	109	Рязанская область, Касимов, Северная, 1	f	large
70301	77925	108	Рязанская область, Касимов, Северная, 1	f	large
70300	77924	107	Рязанская область, Касимов, Приоский, 6	f	large
70299	77923	106	Рязанская область, Касимов, Приокский, 6	f	large
70305	77929	112	Рязанская область, Касимов, Московская, 1	f	large
70303	77926	110	Рязанская область, Касимов, Московская, 67	f	large
70315	77939	124	Рязанская область, Касимов, Ленина, 25	f	large
70308	77934	117	Рязанская область, Касимов, К. Либкнехта, 6, библиотека	f	large
70304	77927	111	Рязанская область, Касимов, Затонная, 9Б	f	large
70314	77938	123	Рязанская область, Касимов, Гагарина, 1	f	large
70313	77938	122	Рязанская область, Касимов, Гагарина, 1	f	large
70312	77938	121	Рязанская область, Касимов, Гагарина, 1	f	large
70324	77942	127	Рязанская область, Касимов, Большакова, 51	f	large
70323	77942	126	Рязанская область, Касимов, Большакова, 51	f	large
70307	77933	116	Рязанская область, Касимов, 50 лет ВЛКСМ, 26Б, школа	f	large
70358	78324	449	Рязанская область, село Дядьково	f	large
116712	78811	839	Рязанская область, Шиловский район, поселок Юшта	f	small
70468	78835	859	Рязанская область, Шиловский район, поселок Шилово	f	large
70467	78834	858	Рязанская область, Шиловский район, поселок Шилово	f	large
116722	78833	857	Рязанская область, Шиловский район, поселок Шилово	f	small
70466	78828	854	Рязанская область, Шиловский район, поселок Шилово	f	large
70465	78827	853	Рязанская область, Шиловский район, поселок Шилово	f	large
70464	78826	852	Рязанская область, Шиловский район, поселок Шилово	f	large
116719	78825	851	Рязанская область, Шиловский район, поселок Шилово	f	medium
70463	78824	850	Рязанская область, Шиловский район, поселок Шилово	f	large
70462	78823	849	Рязанская область, Шиловский район, поселок Шилово	f	large
116709	78807	836	Рязанская область, Шиловский район	f	small
116717	78817	844	Рязанская область, Шиловский район, поселок Тырново	t	medium
116715	78815	842	Рязанская область, Шиловский район, поселок Тимошкино	f	small
116713	78812	840	Рязанская область, Шиловский район, поселок Терехово	f	small
116703	78798	830	Рязанская область, Шиловский район, поселок Сельцо-Сергиевка	f	small
116683	78769	810	Рязанская область, Шиловский район, поселок Свинчус	f	small
116701	78796	828	Рязанская область, Шиловский район, поселок Саськино	f	medium
116700	78795	827	Рязанская область, Шиловский район, поселок Саськино	f	small
116711	78809	838	Рязанская область, Шиловский район, поселок Санское	f	small
116691	78780	818	Рязанская область, Шиловский район, поселок Сановка	f	small
116694	78785	821	Рязанская область, Шиловский район, поселок Пустополье	f	small
116720	78829	855	Рязанская область, Шиловский район, поселок Прибрежный	f	medium
116688	78776	815	Рязанская область, Шиловский район, поселок Нармушадь	f	small
116710	78808	837	Рязанская область, Шиловский район, поселок Муратово	f	small
116707	78803	834	Рязанская область, Шиловский район, поселок Мосолово	f	medium
116705	78801	832	Рязанская область, Шиловский район, поселок Мосолово	f	medium
70461	78822	848	Рязанская область, Шиловский район, поселок Лесной	f	large
70460	78821	847	Рязанская область, Шиловский район, поселок Лесной	f	large
70459	78820	846	Рязанская область, Шиловский район, поселок Лесной	f	large
116687	78775	814	Рязанская область, Шиловский район	f	small
116686	78773	813	Рязанская область, Шиловский район, поселок Куземкино	f	small
116704	78800	831	Рязанская область, Шиловский район, поселок Красный Холм	f	small
116706	78802	833	Рязанская область, Шиловский район, поселок Красногвардейский	f	small
116695	78787	822	Рязанская область, Шиловский район, поселок Константиново	f	small
116714	78814	841	Рязанская область, Шиловский район, поселок Ирицы	f	small
116702	78797	829	Рязанская область, Шиловский район, поселок Инякино, детский сад 	f	medium
116699	78794	826	Рязанская область, Шиловский район	f	small
116708	78805	835	Рязанская область, Шиловский район, поселок Заполье, ФАП	f	small
116697	78790	824	Рязанская область, Шиловский район, поселок Занино-Починки	f	small
116696	78789	823	Рязанская область, Шиловский район, поселок Занино-Починки	f	small
116693	78784	820	Рязанская область, Шиловский район, поселок Задубровье	f	small
116689	78777	816	Рязанская область, Шиловский район, поселок Желудево	f	medium
116685	78771	812	Рязанская область, Шиловский район, поселок Ерахтур	f	medium
116718	78818	845	Рязанская область, Шиловский район, поселок Дубровка	f	small
116721	78830	856	Рязанская область, Шиловский район, поселок Борок	f	small
116684	78770	811	Рязанская область, Шиловский район, поселок Боровое	f	small
116682	78768	809	Рязанская область, Шиловский район, поселок Борки	f	medium
116698	78792	825	Рязанская область, Шиловский район, поселок Большые Пекселы	f	small
116716	78816	843	Рязанская область, Шиловский район, поселок Березово	t	small
116681	78767	808	Рязанская область, Шиловский район, поселок Аделино	f	small
116680	78766	807	Рязанская область, Шиловский район, поселок Аделино	f	small
116692	78782	819	Рязанская область, Шиловский район	f	small
116690	78779	817	Рязанская область, Шиловский район	f	small
116678	78763	805	Рязанская область, Шацкий район, поселок Ямбирно, Центральная	f	medium
116677	78755	798	Рязанская область, Шацкий район, поселок Шевырляй, Центральная	f	small
70457	78761	803	Рязанская область, Шацкий район, Шацк, Энгельса	f	large
70456	78760	802	Рязанская область, Шацкий район, Шацк, Тараскина	f	large
70455	78759	801	Рязанская область, Шацкий район, Шацк, Республиканская площадь, здание СДК	f	large
116649	78718	770	Рязанская область, Шацкий район, поселок Шарик, Центральная	f	small
70454	78757	800	Рязанская область, Шацкий район, поселок Черная Слобода, Морина	f	large
70453	78756	799	Рязанская область, Шацкий район, поселок Черная Слобода, Базарная	f	large
116641	78707	760	Рязанская область, Шацкий район, поселок Федяево, Центральная	f	small
116668	78744	789	Рязанская область, Шацкий район, поселок Федосово, Центральная	f	small
116655	78726	776	Рязанская область, Шацкий район, поселок Темешево, Центральная	f	small
116674	78751	795	Рязанская область, Шацкий район, поселок Тарадей, Центральная	f	small
116665	78739	786	Рязанская область, Шацкий район, поселок Сявель, Центральная	f	small
116664	78738	785	Рязанская область, Шацкий район, поселок Старочернеево, Центральная	f	small
116656	78728	777	Рязанская область, Шацкий район, поселок Сново-Здорово, Центральная	f	small
116662	78734	783	Рязанская область, Шацкий район, Свеженькая, Центральная	f	small
116661	78733	782	Рязанская область, Шацкий район, поселок Садовый, Центральная	f	small
116671	78747	792	Рязанская область, Шацкий район, поселок Польное Ялтуново, Центральная	f	small
116672	78748	793	Рязанская область, Шацкий район, поселок Польное Ялтуново, Набережная	f	small
116658	78730	779	Рязанская область, Шацкий район, поселок Польное Конобеево, Центральная	f	medium
116669	78745	790	Рязанская область, Шацкий район, поселок Печины, Центральная	f	small
116666	78742	787	Рязанская область, Шацкий район, поселок Парсаты, Центральная	f	small
116667	78743	788	Рязанская область, Шацкий район, поселок Ольхи, Центральная	f	small
116663	78736	784	Рязанская область, Шацкий район, поселок Новочернеево, Центральная	f	small
116644	78710	763	Рязанская область, Шацкий район, поселок Новософьино, Центральная	f	small
116652	78723	773	Рязанская область, Шацкий район, поселок Новоселки, Центральная	f	small
116657	78729	778	Рязанская область, Шацкий район, поселок Лесное-Конобеево, Центральная	f	small
116673	78750	794	Рязанская область, Шацкий район, поселок Лесное Ялтуново, Центральная	f	small
116659	78731	780	Рязанская область, Шацкий район, поселок Лесная Поляна, Центральная	f	small
116654	78725	775	Рязанская область, Шацкий район, поселок Кучасьево, Центральная	f	small
116653	78724	774	Рязанская область, Шацкий район, поселок Купля, Центральная	f	small
116675	78752	796	Рязанская область, Шацкий район, поселок Кулики, Центральная	f	small
116639	78705	758	Рязанская область, Шацкий район, поселок Кривая Лука, Центральная	f	small
116679	78765	806	Рязанская область, Шацкий район, поселок Красный Холм, Центральная	f	small
116648	78717	769	Рязанская область, Шацкий район, поселок Кермись, Центральная	f	small
116642	78708	761	Рязанская область, Шацкий район, поселок Карнаухово, Центральная	f	small
70451	78715	767	Рязанская область, Шацкий район, поселок Казачья-Слобода, Центральная	f	large
70452	78716	768	Рязанская область, Шацкий район, поселок Казачья-Слобода, Ленина	f	large
116676	78754	797	Рязанская область, Шацкий район, поселок Казачий Дюк, Центральная	f	small
116647	78714	766	Рязанская область, Шацкий район, поселок Каверино, Центральная	f	medium
116645	78712	764	Рязанская область, Шацкий район, поселок Завидное, Центральная	f	small
116646	78713	765	Рязанская область, Шацкий район, поселок Желанное, Плетнева, школа	f	small
116650	78721	771	Рязанская область, Шацкий район, поселок Выша, Центральная, ДК	f	small
116670	78746	791	Рязанская область, Шацкий район, поселок Высокое, Центральная	f	small
116660	78704	781	Рязанская область, Шацкий район, поселок Вачкас, Центральная	f	small
116651	78722	772	Рязанская область, Шацкий район, поселок Важная, Центральная, школа	f	small
116643	78709	762	Рязанская область, Шацкий район, поселок Борки, Центральная	f	small
116640	78706	759	Рязанская область, Шацкий район, поселок Большое Агишево, Центральная	f	small
116638	78701	757	Рязанская область, Шацкий район, поселок Апушка, Центральная	f	small
116637	78700	756	Рязанская область, Чучковский район, поселок Шеметово	f	small
70450	78698	754	Рязанская область, Чучковский район, поселок Чучково	f	large
70449	78697	753	Рязанская область, Чучковский район, поселок Чучково	f	large
116636	78699	755	Рязанская область, Чучковский район, поселок Чучково, Сосновая, Культурно-досуговый центр Русь	f	small
116635	78696	752	Рязанская область, Чучковский район, поселок Церлево	f	small
116634	78695	751	Рязанская область, Чучковский район, поселок Протасьев Угол	f	small
116633	78694	750	Рязанская область, Чучковский район, поселок Пертово, Дом культуры	f	medium
116632	78693	749	Рязанская область, Чучковский район, поселок Остро-Пластиково	f	small
116631	78692	748	Рязанская область, Чучковский район, поселок Назаровка, медпункт	f	small
116630	78691	747	Рязанская область, Чучковский район, поселок Мелехово	f	small
116628	78688	745	Рязанская область, Чучковский район, поселок Красное Озеро	f	small
116627	78686	744	Рязанская область, Чучковский район, поселок Кистенево, Дом культуры 	f	small
116626	78686	743	Рязанская область, Чучковский район, поселок Кистенево, Дом культуры 	f	small
116625	78685	742	Рязанская область, Чучковский район, поселок Завидово, Дом культуры	f	small
116624	78684	741	Рязанская область, Чучковский район, поселок Дудкино	f	small
116623	78683	740	Рязанская область, Чучковский район, поселок Дубровка, Дом культуры	f	small
116622	78681	739	Рязанская область, Чучковский район, поселок Алеево	f	small
116621	78680	738	Рязанская область, Чучковский район, поселок Аладьино	f	medium
116620	78679	737	Рязанская область, Чучковский район, поселок Авангард, Дом культуры	f	small
116618	78674	733	Рязанская область, Ухоловский район, поселок Ясенок, Однодворцы, 1, школа	f	small
116617	78673	732	Рязанская область, Ухоловский район, поселок Чуриловка, Молодежная, 11, ФАП 	f	small
70430	78677	735	Рязанская область, Ухоловский район, поселок Ухолово, Совхозная, 20 А , СПК Маяк	f	large
70431	78678	736	Рязанская область, Ухоловский район, поселок Ухолово, Советская, 15, ДК	f	large
116619	78675	734	Рязанская область, Ухоловский район, поселок Ухолово, Гагарина, 15, ДК	f	small
116616	78670	731	Рязанская область, Ухоловский район, поселок Соловачево, Юбилейная, 10, ФАП	f	small
116615	78669	730	Рязанская область, Ухоловский район, поселок Смолеевка, Молодежная, 14, ДК	f	small
116614	78668	729	Рязанская область, Ухоловский район, поселок Покровское, Центральная, 18, ДК	f	small
116610	78661	725	Рязанская область, Ухоловский район, поселок Погореловка, Правобережная, 11, КФХ Зоринское	f	small
116613	78665	728	Рязанская область, Ухоловский район, поселок Ольхи, Центральная, 46, ДК	f	small
116607	78656	722	Рязанская область, Ухоловский район, поселок Мостье, Школьная, 9, школа	f	small
116612	78664	727	Рязанская область, Ухоловский район, поселок Лубянки, Центральная, 17, школа	f	small
116606	78654	721	Рязанская область, Ухоловский район, поселок Красный, Центральная, 8, администрация	f	small
116608	78658	723	Рязанская область, Ухоловский район, поселок Коноплино, Школьный переулок, 5, школа	f	small
116611	78663	726	Рязанская область, Ухоловский район, поселок Кобылино, Центральная, 26 , школа	f	small
116609	78659	724	Рязанская область, Ухоловский район, поселок Кензино, Аничкова, 39 , ДК	f	small
116605	78653	720	Рязанская область, Ухоловский район, поселок Калинин, Новоселов, 2, ДК	f	small
116604	78652	719	Рязанская область, Ухоловский район, поселок Дегтяные Борки, Центральная, 3 , ДК	f	small
116603	78651	718	Рязанская область, Ухоловский район, поселок Волынщино, Центральная, 35, ФАП	f	small
116602	78650	717	Рязанская область, Ухоловский район, поселок Богородицкое, Солнечная, 14, детский сад	f	small
116596	78638	708	Рязанская область, Старожиловский район, поселок Чернобаево, Колхозная, 59, администрация	f	small
70426	78632	702	Рязанская область, Старожиловский район, поселок Старожилово, Школьная, 14, ДК	f	large
62093	69819	100	Орловская область, Орел, Октябрьская, 44	f	large
70424	78630	700	Рязанская область, Старожиловский район, поселок Старожилово, Советская, 5, ДК	f	large
70425	78631	701	Рязанская область, Старожиловский район, поселок Старожилово, Денисова, 16, школа	f	large
116593	78635	705	Рязанская область, Старожиловский район, поселок Соха, Новая, 1А , школа	f	small
70429	78641	711	Рязанская область, Старожиловский район, поселок Совхоз Имени Ленина, Советская, 8, администрация	f	large
70427	78639	709	Рязанская область, Старожиловский район, поселок Рязанские Сады, Весенняя, 4, администрация	f	large
116591	78633	703	Рязанская область, Старожиловский район, поселок Панинская Слобода, Молодежная, 2 , администрация	f	small
116599	78645	714	Рязанская область, Старожиловский район, поселок Мелекшино, Речная, 2Б, администрация	f	medium
116592	78634	704	Рязанская область, Старожиловский район, поселок Киселево, 39, Здание администрации поселения	f	small
70428	78640	710	Рязанская область, Старожиловский район, поселок Истье, Центральная, 20, ДК	f	large
116594	78636	706	Рязанская область, Старожиловский район, поселок Ивановское, 72, Дом культуры	f	small
116600	78646	715	Рязанская область, Старожиловский район, поселок Ершово, Молодежная, 20 , ДК	t	medium
116595	78637	707	Рязанская область, Старожиловский район, поселок Гребнево, 70А , Дом культуры	f	medium
116597	78642	712	Рязанская область, Старожиловский район, поселок Большие Поляны, Колхозная, 3 , администрация	f	small
116598	78644	713	Рязанская область, Старожиловский район, поселок Аристово, Центральная, 1, администрация	t	small
116590	78629	699	Рязанская область, Спасский район, поселок Федотьево, Школьная, 11	f	small
116573	78606	682	Рязанская область, Спасский район, поселок Фатьяновка, 100	f	small
116556	78587	665	Рязанская область, Спасский район, поселок Ухорское, Школьная, 1	f	small
116572	78605	681	Рязанская область, Спасский район, поселок Устрань, Кооперативная, 1	f	small
116587	78625	696	Рязанская область, Спасский район, поселок Троица, Школьная, 2а, школа	f	medium
116567	78600	676	Рязанская область, Спасский район, поселок Сушки, Административная, 1	f	medium
116570	78603	679	Рязанская область, Спасский район, поселок Старый Киструсс, Школьная, 52	f	small
116578	78613	687	Рязанская область, Спасский район, поселок Старое Тонино, Федина, 10	f	small
116555	78586	664	Рязанская область, Спасский район, поселок Спиртзаводской	f	small
70447	78579	658	Рязанская область, Спасский район, Спасск-Рязанский, Советская, 96	f	large
70446	78575	654	Рязанская область, Спасский район, Спасск-Рязанский, Рязанское шоссе, 5а , администрация	f	large
116549	78577	656	Рязанская область, Спасский район, Спасск-Рязанский, Луначарского, 25	f	medium
116548	78576	655	Рязанская область, Спасский район, Спасск-Рязанский, Ленина, 50	f	medium
70444	78573	652	Рязанская область, Спасский район, Спасск-Рязанский, Войкова, 68	f	large
116585	78622	694	Рязанская область, Спасский район, поселок Собчаково, Центральная, 27	f	medium
116566	78598	675	Рязанская область, Спасский район, поселок Разбердеево, Почтовая, 34	f	small
116584	78621	693	Рязанская область, Спасский район, поселок Половское, Назина, 34	f	small
116582	78618	691	Рязанская область, Спасский район, поселок Перкино, Школьная, 21, школа	f	small
116580	78615	689	Рязанская область, Спасский район, поселок Панино, Рязанская, 2 , школа	f	medium
116581	78616	690	Рязанская область, Спасский район, поселок Огородниково, Мартынова, 1	f	medium
116569	78602	678	Рязанская область, Спасский район, поселок Новый Киструсс, Центральная, 66	f	medium
116579	78614	688	Рязанская область, Спасский район, поселок Новики, Школьная, 66	f	small
116577	78611	686	Рязанская область, Спасский район, поселок Михали, Центральная, 38	f	small
116574	78608	683	Рязанская область, Спасский район, поселок Лакаш, Молодежная, 2	t	medium
116571	78604	680	Рязанская область, Спасский район, поселок Кутуково, Центральная, 48 , ДК	f	medium
116586	78624	695	Рязанская область, Спасский район, поселок Красильниково, Центральная, 29	f	small
116564	78595	673	Рязанская область, Спасский район, поселок Кирицы, Интернатская, 5/1	f	medium
116563	78594	672	Рязанская область, Спасский район, поселок Кирицы, Интернатская, 5/2	f	small
116562	78593	671	Рязанская область, Спасский район, поселок Исады, Василия Игонина, 46	f	small
116559	78590	668	Рязанская область, Спасский район, поселок Ижевское	t	medium
116560	78591	669	Рязанская область, Спасский район, поселок Ижевское, Советская, 12	t	medium
116558	78589	667	Рязанская область, Спасский район, поселок Ижевское, Красная, 94	t	medium
116557	78588	666	Рязанская область, Спасский район, поселок Ижевское, Банникова, 17	t	medium
116553	78582	661	Рязанская область, Спасский район, поселок Иванково, Молодежная, 2а	f	small
116554	78585	663	Рязанская область, Спасский район, поселок Заречье, Дачная, 40	f	small
116576	78610	685	Рязанская область, Спасский район, поселок Жолобова-Слобода, Магистральная, 80	f	small
116583	78619	692	Рязанская область, Спасский район, поселок Дубовичье, Молодежная, 1а	f	small
116568	78601	677	Рязанская область, Спасский район, поселок Деревенское, Перышкина, 2	t	small
116552	78581	660	Рязанская область, Спасский район, поселок Дегтяное, Школьная, 12	f	small
70448	78584	662	Рязанская область, Спасский район, поселок Гавриловское, Центральная, 119	f	large
116551	78580	659	Рязанская область, Спасский район, поселок Выжелес, Школьная, 6	t	small
116589	78628	698	Рязанская область, Спасский район, поселок Веретье, Масловка, 6	f	small
116575	78609	684	Рязанская область, Спасский район, поселок Брыкин Бор	t	small
116588	78626	697	Рязанская область, Спасский район, поселок Бельское	f	small
116561	78592	670	Рязанская область, Спасский район, поселок Аргамаково, Центральная, 19а	f	small
116539	78546	628	Рязанская область, Скопинский район, поселок Шелемишево, Октябрьская, 24, школа	f	small
70418	78516	603	Рязанская область, Скопинский район, поселок Чулково, Большак, 12, школа	f	large
116537	78543	626	Рязанская область, Скопинский район, поселок Совхоз Желтухинский, Школьная, 19А, администрация	f	medium
116536	78540	625	Рязанская область, Скопинский район, поселок Совхоз Желтухинский, Гагарина, 3, ДК В/ч, 86741	f	medium
70421	78547	629	Рязанская область, Скопинский район, Скопин, Мичурина, 2В, ДК	f	large
70417	78515	602	Рязанская область, Скопинский район, поселок Секирино, Школьная, 25, школа	f	large
116535	78539	624	Рязанская область, Скопинский район, поселок Свинушки, Клубная, 11А, ДК	f	medium
116525	78528	613	Рязанская область, Скопинский район, поселок Рудинка, Школьная, 39, детский сад	f	small
116543	78551	633	Рязанская область, Скопинский район, поселок Рождествено, Карла Маркса, 43, ДК	f	small
116529	78533	618	Рязанская область, Скопинский район, поселок Пупки, Первомайская, 4, ФАП	f	small
116533	78537	622	Рязанская область, Скопинский район, поселок Поляны, 40 лет Победы, 11, школа	f	small
70416	78513	600	Рязанская область, Скопинский район, поселок Побединка, Горняцкая, 10, ДК	f	large
116531	78535	620	Рязанская область, Скопинский район, поселок Петрушино, Набережная, 32, ДК	f	small
116515	78511	598	Рязанская область, Скопинский район, поселок Павелец, Центральная, 15, администрация	f	small
70415	78512	599	Рязанская область, Скопинский район, поселок Павелец, Первомайская, 41, ДК	f	large
116532	78536	621	Рязанская область, Скопинский район, поселок Новые Кельцы, Центральная, 2, ДК	f	small
116518	78519	606	Рязанская область, Скопинский район, поселок Новое, Рабочая, 13, администрация	f	small
116524	78527	612	Рязанская область, Скопинский район, поселок Нагиши, Молодежная, 6, школа	f	small
116542	78550	632	Рязанская область, Скопинский район, поселок Моховое, Советская, 57, администрация	f	small
116541	78549	631	Рязанская область, Скопинский район, поселок Лопатино, Советская, 1В, ДК	f	medium
116514	78510	597	Рязанская область, Скопинский район, поселок Кремлево, Молодежная, 20, библиотека	f	small
70420	78532	617	Рязанская область, Скопинский район, поселок Корневое, Мира, 1, ДК	f	large
116530	78534	619	Рязанская область, Скопинский район, поселок Князево, Центральная, 13, администрация	f	small
116523	78526	611	Рязанская область, Скопинский район, поселок Клекотки, Школьная, 31, школа	f	medium
116522	78524	610	Рязанская область, Скопинский район, поселок Катино, Советская, 14, администрация	f	small
116527	78530	615	Рязанская область, Скопинский район, поселок Казинка, Школьная, 2Б, администрация	f	small
116526	78529	614	Рязанская область, Скопинский район, поселок Ильинка, Попова, 2, школа	f	medium
116521	78523	609	Рязанская область, Скопинский район, поселок Затворное, Казинка, 5, администрация	f	small
116534	78538	623	Рязанская область, Скопинский район, поселок Ермолово, Церковная, 41, администрация	t	medium
116513	78507	596	Рязанская область, Скопинский район, поселок Делехово, Советская, 4	f	small
116540	78548	630	Рязанская область, Скопинский район, поселок Гремячка, Молодежна, 34, школа	f	small
116538	78544	627	Рязанская область, Скопинский район, поселок Городецкое, Гагарина, 4, ФАП	f	small
116520	78522	608	Рязанская область, Скопинский район, поселок Горлово, Базарная, 2А, ДК	f	medium
70419	78517	604	Рязанская область, Скопинский район, поселок Вослебово, Школьная, 73А, ДК	f	large
116517	78518	605	Рязанская область, Скопинский район, поселок Вердерево, Центральная	f	medium
116519	78520	607	Рязанская область, Скопинский район, поселок Богослово, Запрудная, 2, школа	f	small
116528	78531	616	Рязанская область, Скопинский район, поселок Березняги, Ленина, 119, администрация	f	small
116501	78466	563	Рязанская область, Сасовский район, поселок Чубарово, администрация	f	small
116489	78452	551	Рязанская область, Сасовский район, поселок Фроловское, школа	t	small
116494	78458	556	Рязанская область, Сасовский район, поселок Устье	f	small
116480	78440	542	Рязанская область, Сасовский район, поселок Усады	f	small
116512	78489	576	Рязанская область, Сасовский район, поселок Трудолюбовка, администрация сельского поселения	f	small
116493	78457	555	Рязанская область, Сасовский район, поселок Темгенево	f	medium
70394	78485	574	Рязанская область, Сасовский район, поселок Сотницыно, клуб	f	large
70395	78487	575	Рязанская область, Сасовский район, поселок Сотницыно, Больничная, участковая больница	f	large
116510	78480	572	Рязанская область, Сасовский район, поселок Салтыково	f	small
116482	78443	544	Рязанская область, Сасовский район, поселок Саблино, кафе Кучеренко	f	small
116509	78478	571	Рязанская область, Сасовский район, поселок Придорожный, школа	f	small
116508	78476	570	Рязанская область, Сасовский район, поселок Пичкиряево	f	small
116492	78456	554	Рязанская область, Сасовский район, поселок Огарево-Почково	f	small
116505	78471	567	Рязанская область, Сасовский район, поселок Новое Березово, начальная школа	f	medium
116504	78470	566	Рязанская область, Сасовский район, поселок Нижнее Мальцево, школа 	f	medium
116491	78455	553	Рязанская область, Сасовский район, поселок Мыс Доброй Надежды, школа	f	small
116499	78464	561	Рязанская область, Сасовский район, поселок Мокрое, администрация сельского поселения 	f	small
116507	78474	569	Рязанская область, Сасовский район, поселок Матвеевское	f	small
116503	78469	565	Рязанская область, Сасовский район, поселок Малый Студенец	f	medium
116488	78451	550	Рязанская область, Сасовский район, поселок Любовниково	f	small
116502	78468	564	Рязанская область, Сасовский район, поселок Кустаревка, Дом культуры	f	medium
116497	78462	559	Рязанская область, Сасовский район, поселок Кошибеево, Дом культуры	f	small
116485	78447	547	Рязанская область, Сасовский район, поселок Ключи, медпункт	f	small
116498	78463	560	Рязанская область, Сасовский район, поселок Каргашино, Дом культуры	f	small
116496	78460	558	Рязанская область, Сасовский район, поселок Демушкино, Дом культуры	f	medium
116490	78453	552	Рязанская область, Сасовский район, поселок Глядково, администрация сельского поселения	f	small
116487	78450	549	Рязанская область, Сасовский район, поселок Гавриловское	f	small
116484	78446	546	Рязанская область, Сасовский район, поселок Вялсы, медпункт	f	small
116511	78483	573	Рязанская область, Сасовский район, поселок Верхнее Мальцево, библиотека	f	small
116506	78472	568	Рязанская область, Сасовский район, поселок Боковой Майдан, медпункт	f	small
116486	78449	548	Рязанская область, Сасовский район, поселок Берестянки	f	medium
116483	78444	545	Рязанская область, Сасовский район, поселок Батьки, школа	f	medium
116495	78459	557	Рязанская область, Сасовский район, поселок Бастаново, школа	f	small
116481	78442	543	Рязанская область, Сасовский район, поселок Алешино, администрация сельского поселения 	f	medium
116479	78439	541	Рязанская область, Сасовский район, поселок Агломазово, медпункт	f	medium
116475	78432	535	Рязанская область, Сараевский район, поселок Ягодное	f	small
116447	78397	507	Рязанская область, Сараевский район, поселок Троицкое	f	small
116472	78427	532	Рязанская область, Сараевский район, поселок Телятники	f	small
116455	78408	515	Рязанская область, Сараевский район, поселок Таптыково	f	small
116470	78425	530	Рязанская область, Сараевский район, поселок Сысои	f	medium
116452	78403	512	Рязанская область, Сараевский район, поселок Старобокино	f	small
70392	78435	538	Рязанская область, Сараевский район, поселок Сараи, Ленина, 153	f	large
116477	78434	537	Рязанская область, Сараевский район, поселок Сараи, Ленина, 122 , административное здание	f	medium
70393	78436	539	Рязанская область, Сараевский район, поселок Сараи, Казинка, 3	f	large
116478	78438	540	Рязанская область, Сараевский район, поселок Сараи, 1 Мая, 23	f	medium
116467	78421	527	Рязанская область, Сараевский район, поселок Ремизово 1-е, администрация	f	small
116471	78426	531	Рязанская область, Сараевский район, поселок Паники	f	small
116565	78596	674	Рязанская область, Сараевский район, поселок Павловка, Курская, 6 , Детский сад	f	medium
116457	78410	517	Рязанская область, Сараевский район, поселок Островка, ДК	f	small
116451	78402	511	Рязанская область, Сараевский район, поселок Озерки	f	small
116468	78422	528	Рязанская область, Сараевский район, поселок Новобокино	f	small
116469	78423	529	Рязанская область, Сараевский район, поселок Низовка	f	small
116466	78419	526	Рязанская область, Сараевский район, поселок Напольное	f	medium
116453	78405	513	Рязанская область, Сараевский район, поселок Назарьево	f	small
116464	78417	524	Рязанская область, Сараевский район, поселок Муравлянка	f	medium
116476	78433	536	Рязанская область, Сараевский район, поселок Мордово, ДК	f	small
116462	78415	522	Рязанская область, Сараевский район, поселок Меньшие Можары	f	medium
116473	78428	533	Рязанская область, Сараевский район, поселок Малая Витуша	f	small
116465	78418	525	Рязанская область, Сараевский район, поселок Максы	f	small
116460	78413	520	Рязанская область, Сараевский район, поселок Кривское	f	medium
116459	78412	519	Рязанская область, Сараевский район, поселок Красная Вершина	f	small
116446	78396	506	Рязанская область, Сараевский район, поселок Калиновка	f	small
116474	78430	534	Рязанская область, Сараевский район, поселок Ивановка	f	small
116449	78400	509	Рязанская область, Сараевский район, поселок Зеркальные Пруды	t	small
116458	78411	518	Рязанская область, Сараевский район, поселок Желобово	f	medium
116454	78406	514	Рязанская область, Сараевский район, поселок Высокое	f	small
116463	78416	523	Рязанская область, Сараевский район, поселок Веселый	f	small
116450	78401	510	Рязанская область, Сараевский район, поселок Бычки	f	small
116448	78399	508	Рязанская область, Сараевский район, поселок Борец	f	small
116461	78414	521	Рязанская область, Сараевский район, поселок Большие Можары, школа	f	medium
116456	78409	516	Рязанская область, Сараевский район, поселок Белоречье	f	small
116445	78395	505	Рязанская область, Сараевский район, поселок Алексеевка	f	small
116431	78377	491	Рязанская область, Сапожковский район, поселок Черная Речка	f	small
116444	78394	504	Рязанская область, Сапожковский район, поселок Собчаково	f	small
70391	78376	490	Рязанская область, Сапожковский район, поселок Сапожок, 15 магазин ООО Феникс 	f	large
116426	78371	485	Рязанская область, Сапожковский район, поселок Сапожок, Советская, 19 , школа искуств	f	medium
70390	78370	484	Рязанская область, Сапожковский район, поселок Сапожок, Советская, 15 , здание КСК «Надежда»	f	large
116427	78372	486	Рязанская область, Сапожковский район, поселок Сапожок, Свободы, 13 , школа	f	medium
116430	78375	489	Рязанская область, Сапожковский район, поселок Сапожок, Пролетарская, 48 , Техникум	f	medium
116428	78373	487	Рязанская область, Сапожковский район, поселок Сапожок, Гусева, 24, школа	f	small
116429	78374	488	Рязанская область, Сапожковский район, поселок Сапожок, Большая Дорога, 55 , ДРСУ	f	medium
116437	78384	497	Рязанская область, Сапожковский район, поселок Парышка	f	small
116436	78383	496	Рязанская область, Сапожковский район, поселок Новокрасное	f	small
116443	78393	503	Рязанская область, Сапожковский район, поселок Морозовы-Борки	f	medium
116439	78387	499	Рязанская область, Сапожковский район, поселок Михей	f	small
116438	78385	498	Рязанская область, Сапожковский район, поселок Малый Сапожок	f	small
116442	78391	502	Рязанская область, Сапожковский район, поселок Лукмос, ФАП	f	small
116434	78380	494	Рязанская область, Сапожковский район, поселок Красный Угол	f	small
116433	78379	493	Рязанская область, Сапожковский район, поселок Красное	f	small
116441	78390	501	Рязанская область, Сапожковский район, поселок Коровка	f	small
116435	78382	495	Рязанская область, Сапожковский район, поселок Канино	f	small
116440	78388	500	Рязанская область, Сапожковский район, поселок Васильевка	f	small
116432	78378	492	Рязанская область, Сапожковский район, поселок Березники	t	small
116601	78647	716	Рязанская область, Сапожковский район, поселок Александровка, Центральная, 38, ДК	f	small
116418	78357	474	Рязанская область, Рязанский район, поселок Шумашь	f	medium
116419	78361	476	Рязанская область, Рязанский район, поселок Шевцово	f	small
116423	78367	481	Рязанская область, Рязанский район, поселок Тюшево	f	medium
116421	78363	478	Рязанская область, Рязанский район, поселок Стенькино	f	small
116394	78312	441	Рязанская область, Рязанский район, поселок Стенькино	f	medium
70268	78942	1035	Рязанская область, Рязанский район, поселок Солотча	f	large
116398	78317	445	Рязанская область, Рязанский район, поселок Сажнево	f	small
116403	78327	452	Рязанская область, Рязанский район, поселок Рожок	f	small
116420	78362	477	Рязанская область, Рязанский район, поселок Ровное	f	medium
116422	78366	480	Рязанская область, Рязанский район, поселок Реткино	f	medium
116405	78330	455	Рязанская область, Рязанский район, поселок Приозерный, контора МУП ЖКХ	f	small
70365	78356	473	Рязанская область, Рязанский район, поселок Поляны	f	large
70364	78355	472	Рязанская область, Рязанский район, поселок Поляны	f	large
116409	78338	459	Рязанская область, Рязанский район, поселок Полково	f	medium
70363	78352	470	Рязанская область, Рязанский район, поселок Подвязье	f	large
70362	78351	469	Рязанская область, Рязанский район, поселок Окский	f	large
116414	78347	465	Рязанская область, Рязанский район, поселок Наумово	f	small
116417	78354	471	Рязанская область, Рязанский район, поселок Насурово	f	medium
116425	78369	483	Рязанская область, Рязанский район, поселок Мушковатово	f	medium
70355	78305	436	Рязанская область, Рязанский район, поселок Мурмино	f	large
70354	78304	435	Рязанская область, Рязанский район, поселок Мурмино, Лесная, 15, детский сад	f	large
70361	78348	466	Рязанская область, Рязанский район, поселок Льгово	f	large
70360	78343	462	Рязанская область, Рязанский район, поселок Листвянка	f	large
116404	78329	454	Рязанская область, Рязанский район, поселок Ласково	f	small
116411	78342	461	Рязанская область, Рязанский район, поселок Коростово	f	small
116391	78306	437	Рязанская область, Рязанский район, поселок Казарь	f	small
70366	78359	475	Рязанская область, Рязанский район, поселок Искра	f	large
116410	78339	460	Рязанская область, Рязанский район, поселок Заокское	f	medium
70359	78328	453	Рязанская область, Рязанский район, поселок Заборье	f	large
116402	78326	451	Рязанская область, Рязанский район, поселок Екимовка	f	medium
70357	78320	447	Рязанская область, Рязанский район, поселок Дубровичи	f	large
116392	78308	438	Рязанская область, Рязанский район, поселок Долгинино	f	medium
116408	78336	458	Рязанская область, Рязанский район, поселок Деулино	f	small
116399	78319	446	Рязанская область, Рязанский район, поселок Дашки 2-е	f	medium
116396	78314	443	Рязанская область, Рязанский район, поселок Гавердово, администрация 	f	small
116397	78316	444	Рязанская область, Рязанский район, поселок Вышетравино	f	medium
116395	78313	442	Рязанская область, Рязанский район, поселок Вышгород	f	medium
116393	78311	440	Рязанская область, Рязанский район, поселок Высокое	f	medium
70356	78310	439	Рязанская область, Рязанский район, деревня Варские	f	large
116407	78334	457	Рязанская область, Рязанский район, поселок Борисково	f	small
116413	78346	464	Рязанская область, Рязанский район, поселок Болошнево	f	medium
116412	78344	463	Рязанская область, Рязанский район, поселок Александрово	f	medium
116400	78323	448	Рязанская область, Рязанский район, поселок Алеканово, Центральная, приемная администрации	f	small
116406	78332	456	Рязанская область, Рязанский район, поселок Агро-Пустынь	f	small
116381	78294	425	Рязанская область, Ряжский район, поселок Шереметьево, Центральная, 100, СДК	f	small
116390	78303	434	Рязанская область, Ряжский район, поселок Чирково, Есенина, 32, школа №3	f	small
111560	57327	3077	Москва, Зеленоград, к2011	f	medium
116378	78289	422	Рязанская область, Ряжский район, поселок Турово, Совхозная, 13, СДК	f	small
116379	78291	423	Рязанская область, Ряжский район, поселок Свет, Дорожная, 6, СДК	f	small
116386	78299	430	Рязанская область, Ряжский район, поселок Салтыки, Поповка, 16, СДК	f	small
70376	78272	404	Рязанская область, Ряжский район, Ряжск, площадь Свободы, 12 , центр внешкольной работы	f	large
70377	78273	405	Рязанская область, Ряжский район, Ряжск, Совхозная, 2, здание культуры и спорта	f	large
70385	78280	413	Рязанская область, Ряжский район, Ряжск, Свободы, 48, школа №6	f	large
70382	78277	410	Рязанская область, Ряжский район, Ряжск, Максима Горького, 79, школа №3	f	large
70386	78281	414	Рязанская область, Ряжский район, Ряжск, Лермонтова, 13, музыкал. школа	f	large
70380	78275	408	Рязанская область, Ряжский район, Ряжск, Ленина, 7, музык.школа	f	large
70375	78271	403	Рязанская область, Ряжский район, Ряжск, Красной Армии, 43, НПО ПЛ№36	f	large
116377	78288	421	Рязанская область, Ряжский район, поселок Ратманово, Центральная, 102, библиотека	f	small
116388	78301	432	Рязанская область, Ряжский район, поселок Поплевино, Большая Дорога, 62, школа №3	f	small
116389	78302	433	Рязанская область, Ряжский район, поселок Подвислово, Новая, 18, школа	t	small
116387	78300	431	Рязанская область, Ряжский район, поселок Петрово, Новая, 17, школа №4	f	medium
116383	78296	427	Рязанская область, Ряжский район, поселок Новое Еголдаево, Школьная, 3, школа №4	f	medium
116385	78298	429	Рязанская область, Ряжский район, поселок Марчуки 2-е, 76, СДК	f	small
116376	78287	420	Рязанская область, Ряжский район, поселок Марчуки 1-е, Новая, 6, клуб	t	small
116384	78297	428	Рязанская область, Ряжский район, поселок Журавинка, Центральная, 61, администация	f	small
116382	78295	426	Рязанская область, Ряжский район, поселок Дегтяное, Советской Армии, 1а, администрация	f	medium
116380	78292	424	Рязанская область, Ряжский район, поселок Введеновка, Солнечная, 99, СДК	f	small
116375	78286	419	Рязанская область, Ряжский район, поселок Большая Алешня, Гагарина, 21, администрация	f	small
116371	78261	393	Рязанская область, Рыбновский район, поселок Шехмино, здание администрации	f	\N
116370	78260	392	Рязанская область, Рыбновский район, поселок Чурилково, здание школы	f	\N
116368	78258	390	Рязанская область, Рыбновский район, поселок Ходынино, здание администрации	f	\N
116365	78255	387	Рязанская область, Рыбновский район, поселок Федякино, школа	f	\N
116364	78253	386	Рязанская область, Рыбновский район, поселок Сельцы, здание администрации	f	\N
70369	78264	396	Рязанская область, Рыбновский район, Рыбное, Электротяговая, 16, академия пчеловодства	f	large
70370	78266	398	Рязанская область, Рыбновский район, Рыбное, Театральная, 1, социально-культурный центр	f	large
70367	78262	394	Рязанская область, Рыбновский район, Рыбное, Почтовая, 22	f	large
70372	78268	400	Рязанская область, Рыбновский район, Рыбное, Новосельская, 17, школа № 3	f	large
70374	78270	402	Рязанская область, Рыбновский район, Рыбное, Макаренко, 13, школа №, 2	f	large
70373	78269	401	Рязанская область, Рыбновский район, Рыбное, Заготовительная, 7, здание ОАО Рыбновская МС	f	large
116363	78252	385	Рязанская область, Рыбновский район, поселок Пощупово, здание администрации	f	\N
116369	78259	391	Рязанская область, Рыбновский район, Поселок завода Ветзоотехника, здание завода	f	\N
116361	78250	383	Рязанская область, Рыбновский район, поселок Пионерский, здание основной общеобраз.школы	f	\N
116367	78257	389	Рязанская область, Рыбновский район, поселок Перекаль, здание школы	f	\N
116360	78249	382	Рязанская область, Рыбновский район, поселок Пальные, адмистрация	f	\N
116344	78230	366	Рязанская область, Рыбновский район, поселок Ногино, здание начальной школы	f	\N
116359	78247	381	Рязанская область, Рыбновский район, поселок Новоселки, здание администрации	f	\N
116347	78234	369	Рязанская область, Рыбновский район, Новое Батурино, здание школы	f	\N
116358	78246	380	Рязанская область, Рыбновский район, поселок Марково, здание администрации	f	\N
116346	78232	368	Рязанская область, Рыбновский район, поселок Мантурово, здание дома культуры	f	\N
116353	78241	375	Рязанская область, Рыбновский район, поселок Летово, здание начальной школы	f	\N
116357	78245	379	Рязанская область, Рыбновский район, поселок Кузьминское, здание СПК колхоза Есенинский	f	\N
116362	78251	384	Рязанская область, Рыбновский район, поселок Костино, здание средней школы	f	\N
116356	78244	378	Рязанская область, Рыбновский район, поселок Константиново, здание музея им.С.Есенина	f	\N
116355	78243	377	Рязанская область, Рыбновский район, поселок Комсомольский, здание администрации	f	\N
116352	78240	374	Рязанская область, Рыбновский район, поселок Истобники, здание начальной школы	f	\N
116354	78242	376	Рязанская область, Рыбновский район, поселок Житово, здание сельского дома культуры	f	\N
116366	78256	388	Рязанская область, Рыбновский район, поселок Глебово-Городище, здание сельского дома культуры	f	\N
116348	78235	370	Рязанская область, Рыбновский район, поселок Высокое, здание сельского дома культуры	f	\N
116350	78237	372	Рязанская область, Рыбновский район, поселок Вакино, здание правления СПК Вакинское	f	\N
116349	78236	371	Рязанская область, Рыбновский район, поселок Большое Жоково, здание дома культуры	f	\N
116345	78231	367	Рязанская область, Рыбновский район, поселок Баграмово	f	\N
116343	78229	365	Рязанская область, Рыбновский район, поселок Алешня, Дом культуры	f	\N
116351	78238	373	Рязанская область, Рыбновский, поселок Глебково	f	\N
116342	78228	364	Рязанская область, Путятинский район, поселок Унгор, Молодежная, 6	f	small
116332	78209	352	Рязанская область, Путятинский район, поселок Строевское, Новая, 4, клуб	f	small
116341	78227	363	Рязанская область, Путятинский район, поселок Романовы Дарки, Сельская, 27	f	small
70352	78220	359	Рязанская область, Путятинский район, поселок Путятино, Ленинский проспект, 59ак2, здание ГУ	f	large
70353	78221	360	Рязанская область, Путятинский район, поселок Путятино, Ворошилова, 41, школа	f	large
116337	78218	357	Рязанская область, Путятинский район, поселок Поляки, 67	f	small
116338	78219	358	Рязанская область, Путятинский район, поселок Песочня, Революции, 4	f	medium
116328	78203	348	Рязанская область, Путятинский район, поселок Отрада, Поселковая, 18	f	small
116330	78207	350	Рязанская область, Путятинский район, поселок Новая Деревня, Черемушки, 1	f	small
116335	78213	355	Рязанская область, Путятинский район, поселок Макеево, Центральная, 30	f	small
116336	78215	356	Рязанская область, Путятинский район, поселок Летники, Школьная, 18	f	small
116340	78223	362	Рязанская область, Путятинский район, поселок Караулово, Центральная, 55	f	small
116334	78212	354	Рязанская область, Путятинский район, поселок Карабухино, Луговая, 8	f	small
116333	78211	353	Рязанская область, Путятинский район, поселок Екатериновка, Солнечный переулок, 13	f	small
116339	78222	361	Рязанская область, Путятинский район, поселок Глебово, Молодежная	f	small
116331	78208	351	Рязанская область, Путятинский район, поселок Воршево, Центральная	f	small
116329	78205	349	Рязанская область, Путятинский район, поселок Большая Екатериновка, Центальная, 87	f	small
116327	78202	347	Рязанская область, Путятинский район, поселок Береговое, Центральная, 104	f	small
116308	78172	317	Рязанская область, Пронский район, поселок Тырново	f	medium
116313	78178	322	Рязанская область, Пронский район, поселок Совхоз Орловский, Центральная, 38	f	small
116319	78184	328	Рязанская область, Пронский район, поселок Совхоз .Погореловский, Садовая, 29	f	small
116318	78183	327	Рязанская область, Пронский район, поселок Синь, Центральная, 10	f	small
116315	78180	324	Рязанская область, Пронский район, поселок Семенск, Степановка, 24	f	small
70341	78191	335	Рязанская область, Пронский район, поселок Пронск, Первомайская, 30	f	large
70342	78190	336	Рязанская область, Пронский район, поселок Пронск, Первомайская, 32	f	large
116325	78190	334	Рязанская область, Пронский район, поселок Пронск, Первомайская, 32	f	medium
116326	78192	337	Рязанская область, Пронский район, поселок Пронск, Верхне-Архангельская, 30	f	medium
116314	78179	323	Рязанская область, Пронский район, поселок Октябрьское, Большая, 76	f	medium
70350	78201	345	Рязанская область, Пронский район, Новомичуринск, 21 Д	f	large
70351	78200	346	Рязанская область, Пронский район, Новомичуринск, 26 Д	f	large
70349	78200	344	Рязанская область, Пронский район, Новомичуринск, 26 Д	f	large
70345	78195	340	Рязанская область, Пронский район, Новомичуринск, проспект Энергетиков , 20	f	large
70343	78193	338	Рязанская область, Пронский район, Новомичуринск, пр. Энергетиков, 28	f	large
70344	78194	339	Рязанская область, Пронский район, Новомичуринск, пр. Смирягина, 18	f	large
70347	78198	342	Рязанская область, Пронский район, Новомичуринск, Строителей, 16	f	large
70346	78196	341	Рязанская область, Пронский район, Новомичуринск, Строителей, 18	f	large
70348	78199	343	Рязанская область, Пронский район, Новомичуринск, Комсомольская, 6	f	large
116317	78182	326	Рязанская область, Пронский район, поселок Мамоново	f	medium
116306	78169	315	Рязанская область, Пронский район, поселок Малинищи, Школьная, 73	f	medium
116321	78186	330	Рязанская область, Пронский район, поселок Маклаково	f	medium
116322	78187	331	Рязанская область, Пронский район, поселок Кисьва	f	small
116311	78175	320	Рязанская область, Пронский район, поселок Елшино, Октябрьская, 27	f	small
116323	78188	332	Рязанская область, Пронский район, поселок Денисово	f	small
116307	78171	316	Рязанская область, Пронский район, поселок Гремяки	f	small
116316	78181	325	Рязанская область, Пронский район, поселок Восточный, Молодежная, 30	f	small
116324	78189	333	Рязанская область, Пронский район, поселок Большое Село	f	small
116312	78177	321	Рязанская область, Пронский район, поселок Березово, Советская, 11	f	small
116320	78185	329	Рязанская область, Пронский район, поселок Береговая Погореловка	f	medium
116310	78174	319	Рязанская область, Пронский район, поселок Альютово, Почтовая, 6 , здание школы	f	small
116309	78173	318	Рязанская область, Пронский район, поселок Абакумово	f	small
116297	78160	306	Рязанская область, Пителинский район, поселок Юрьево, им. Дмитрия Кокорева, 29	f	small
116296	78159	305	Рязанская область, Пителинский район, поселок Темирево, Школьная, 43	f	small
116300	78163	309	Рязанская область, Пителинский район, поселок Потапьево, Первомайская, 64	f	small
116298	78161	307	Рязанская область, Пителинский район, поселок Подболотье, Школьная, 6	t	small
116305	78168	314	Рязанская область, Пителинский район, поселок Пителино, Павлова, 10	f	medium
116303	78166	312	Рязанская область, Пителинский район, поселок Пителино, Красная, 27	f	medium
116304	78167	313	Рязанская область, Пителинский район, поселок Пителино, Горького, 56	f	medium
116301	78164	310	Рязанская область, Пителинский район, поселок Пет, Николаевка, 16	t	small
116299	78162	308	Рязанская область, Пителинский район, поселок Пеньки, Заречная, 6/2	f	small
116294	78157	303	Рязанская область, Пителинский район, поселок Новый Ункор, Молодежная, 4А	f	small
116293	78156	302	Рязанская область, Пителинский район, поселок Нестерово, Молодежная, 1	f	medium
116291	78154	300	Рязанская область, Пителинский район, поселок Краснопартизанский, Есенина, 1а	f	small
116292	78155	301	Рязанская область, Пителинский район, поселок Ермо-Николаевка, Николаевка, 25	f	small
116295	78158	304	Рязанская область, Пителинский район, поселок Гридино, Крупской, 2	t	small
116290	78153	299	Рязанская область, Пителинский район, поселок Высокие Поляны, Центральная, 45, школа	f	small
116302	78165	311	Рязанская область, Пителинский район, поселок Веряево, Колхозная, 91	f	small
116276	78134	285	Рязанская область, Новодеревенский район, поселок Чернышевка, 67 , ФАП	f	small
116273	78131	282	Рязанская область, Новодеревенский район, поселок Студенки, Молодежная, 10а , ДК	f	small
116288	78150	297	Рязанская область, Новодеревенский район, поселок Спешнево, Центральная, 33 , школа	f	small
116281	78141	290	Рязанская область, Новодеревенский район, поселок Сергиевский-Боровок, Центральная, 119, библиотека	f	small
116287	78149	296	Рязанская область, Новодеревенский район, поселок Просечье	f	small
116274	78132	283	Рязанская область, Новодеревенский район, поселок Павловка, Центральная, 46, школа	f	small
116271	78127	280	Рязанская область, Новодеревенский район, поселок Ольховка, Крутякова, 24 , ДК	f	small
116284	78144	293	Рязанская область, Новодеревенский район, поселок Новотишевое, Вишневая, 17, ФАП	f	small
116280	78140	289	Рязанская область, Новодеревенский район, поселок Новосергиевка, 39 , ДК	f	small
116283	78143	292	Рязанская область, Новодеревенский район, поселок Нижний Якимец, Молодежная, 20, детский сад	f	small
116289	78152	298	Рязанская область, Новодеревенский район, поселок Михалково, Центральная, 17, школа	f	small
116629	78689	746	Рязанская область, Новодеревенский район, поселок Луговой, сельский клуб	f	small
111559	57327	3076	Москва, Зеленоград, к2011	f	medium
116282	78142	291	Рязанская область, Новодеревенский район, поселок Ленино, Центральная, 43, ДК	f	medium
116285	78146	294	Рязанская область, Новодеревенский район, поселок Красное Знамя, Почтовая, 30	f	small
116279	78138	288	Рязанская область, Новодеревенский район, поселок Каширин	f	medium
116286	78148	295	Рязанская область, Новодеревенский район, поселок Калинино, Молодежная, 1а , школа	f	small
116277	78136	286	Рязанская область, Новодеревенский район, поселок Зимарово, Заречная, 50 , ДК	f	small
116278	78137	287	Рязанская область, Новодеревенский район, поселок Бурминка, Молодежная, 6Б, Школа	f	small
116275	78133	284	Рязанская область, Новодеревенский район, поселок Борисовка, Зеленая, 1а, школа	f	small
116270	78126	279	Рязанская область, Новодеревенский район, поселок Благие, Центральная, 28 , школа	f	small
116272	78129	281	Рязанская область, Новодеревенский район, поселок Бахметьево, Мичурина, 45 , ФАП	f	small
116268	78123	277	Рязанская область, Новодеревенский район, поселок Александро-Невский, Советская, 27, ДК	f	medium
116269	78124	278	Рязанская область, Новодеревенский район, поселок Александро-Невский, Весенняя , 15 , Детский сад	f	medium
70340	78118	273	Рязанская область, Михайловский район, поселок Щетиновка, администрация муниципального образования	f	large
116244	78095	252	Рязанская область, Михайловский район, поселок Щеголево, 39, Администрация муниципального образования	f	small
116262	78115	270	Рязанская область, Михайловский район, поселок Чурики, Верховка, 1-а, Администрация муниципального образования	f	small
116259	77940	267	Рязанская область, Михайловский район, поселок Фирюлевка, медпункт	t	small
116263	78116	271	Рязанская область, Михайловский район, поселок Трепольский, администрация муниципального 	f	small
116252	78104	260	Рязанская область, Михайловский район, поселок Стубле, Кадушная, клуб	f	small
116261	78114	269	Рязанская область, Михайловский район, поселок Стрелецкие Выселки, 135, администрация муниципального образования	f	medium
116246	78097	254	Рязанская область, Михайловский район, поселок Совхоз им. Ильича, Центральная, 13-а, Администрация муниципального образования	f	small
116264	78117	272	Рязанская область, Михайловский район, поселок Совхоз Фрунзенский	f	small
116257	78110	265	Рязанская область, Михайловский район, поселок Слободка, администрация муниципального образования	f	small
116240	78090	248	Рязанская область, Михайловский район, поселок Садовый Поселок	f	small
116256	78109	264	Рязанская область, Михайловский район, поселок Рачатники, 1 , администрация муниципального образования	f	small
116267	78122	276	Рязанская область, Михайловский район, поселок Пушкари, администрация ООО Пушкари	f	small
116265	78120	274	Рязанская область, Михайловский район, поселок Прудские Выселки	f	small
116254	78107	262	Рязанская область, Михайловский район, поселок Поярково, Поярковская , ООШ	f	small
116222	78067	230	Рязанская область, Михайловский район, поселок Помозово	f	small
116253	78106	261	Рязанская область, Михайловский район, поселок Печерники	f	small
116223	78069	231	Рязанская область, Михайловский район, поселок Первомайский, Почтовая, 2	f	medium
116236	78084	244	Рязанская область, Михайловский район, поселок Павелково, Лесная, 52	f	small
116237	78086	245	Рязанская область, Михайловский район, поселок Отделение совхоза Возрождение, Луговая, 2	f	small
116233	78080	241	Рязанская область, Михайловский район, поселок Октябрьский, Цементников, 4	f	medium
116230	78076	238	Рязанская область, Михайловский район, поселок Октябрьский, Кочубина, 15-а	f	medium
116229	78076	237	Рязанская область, Михайловский район, поселок Октябрьский, Кочубина, 15-а	f	medium
116226	78072	234	Рязанская область, Михайловский район, поселок Октябрьский, Клубная, 10	f	medium
116227	78073	235	Рязанская область, Михайловский район, поселок Октябрьский, Больничная, 1-а	f	small
116232	78079	240	Рязанская область, Михайловский район, поселок Октябрьский, 3-й Строительный переулок, 5	f	medium
116251	78103	259	Рязанская область, Михайловский район, поселок Новопанское, Слобода, дом культуры	f	small
116260	78112	268	Рязанская область, Михайловский район, поселок Некрасово, Новая, 6	f	small
116258	78111	266	Рязанская область, Михайловский район, поселок Мишино, п.центрального отделения с-за Мишино	f	small
83880	57323	3070	Москва, Зеленоград, к1816	f	large
70338	78062	226	Рязанская область, Михайловский район, Михайлов, ст. Михайлов, 21-б	f	large
70322	78059	223	Рязанская область, Михайловский район, Михайлов, Школьная, 2	f	large
116219	78061	225	Рязанская область, Михайловский район, Михайлов, Октябрьская, 7	f	medium
116221	78065	229	Рязанская область, Михайловский район, Михайлов, Новая, 7	f	small
70339	78064	228	Рязанская область, Михайловский район, Михайлов, Новая, 5	f	large
70320	78057	221	Рязанская область, Михайловский район, Михайлов, Нагорная, 25-а	f	large
116218	78060	224	Рязанская область, Михайловский район, Михайлов, Карла Маркса, 11	f	medium
116266	78121	275	Рязанская область, Михайловский район, Михайлов, Зеленая, 20 , контора МУП Михайловсое МСО	f	small
116220	78063	227	Рязанская область, Михайловский район, Михайлов, 23 Партсъезда, 1, контора ООО Управление жилыми домами	f	medium
116238	78088	246	Рязанская область, Михайловский район, поселок Малинки, Кулькова, клуб	f	small
116250	78102	258	Рязанская область, Михайловский район, поселок Красное, администрация муниципального образования 	f	small
116247	78098	255	Рязанская область, Михайловский район, поселок Коровинский спирт. завод, Центральная, 4	f	small
116225	78071	233	Рязанская область, Михайловский район, поселок Козловка	f	medium
116224	78070	232	Рязанская область, Михайловский район, поселок Козловка, Лещенка, 142	f	medium
116248	78100	256	Рязанская область, Михайловский район, поселок Каморино	f	small
116255	78108	263	Рязанская область, Михайловский район, поселок Ижеславль, Дом культуры	f	small
116242	78092	250	Рязанская область, Михайловский район, поселок Иваньково, сельский клуб	f	small
116231	78077	239	Рязанская область, Михайловский район, поселок Змеинка, здание клуба	f	small
116239	78089	247	Рязанская область, Михайловский район, поселок Заря, Центральная, 4	f	medium
116249	78101	257	Рязанская область, Михайловский район, поселок Завидовка, 41, медпункт	f	small
116245	78096	253	Рязанская область, Михайловский район, поселок Жмурово, Администрация муниципального образования	f	small
116243	78094	251	Рязанская область, Михайловский район, поселок Грязное, Центральная, 74	f	medium
116228	78075	236	Рязанская область, Михайловский район, поселок Горенка, Школьная	f	small
116235	78083	243	Рязанская область, Михайловский район, поселок Голдино, Школьная, 1	f	medium
116234	78081	242	Рязанская область, Михайловский район, поселок Виленка	f	medium
116241	78091	249	Рязанская область, Михайловский район, поселок Бычки	f	small
116207	78042	208	Рязанская область, Милославский район, поселок Южный, Центральная, 5, администрация	f	small
116214	78051	215	Рязанская область, Милославский район, поселок Чернава, Ленина, 34, администрация	f	medium
116217	78056	220	Рязанская область, Милославский район, поселок Центральный, Мира, 6а, администрация	f	medium
116211	78046	212	Рязанская область, Милославский район, поселок Топилы, Центральная, 13а	f	small
116192	78021	193	Рязанская область, Милославский район, поселок Спасское, Новая, 30, администрация	f	small
116210	78045	211	Рязанская область, Милославский район, поселок Совхоз Большевик, Центральная, 2, школа	f	small
116200	78033	201	Рязанская область, Милославский район, поселок Роговое, Луговая, 1, медпункт	f	small
116209	78044	210	Рязанская область, Милославский район, поселок Пролетарский, Новоселов, 2, администрация	f	small
116215	78052	216	Рязанская область, Милославский район, поселок Потапово, Центральная, 4, администрация	f	small
116516	78514	601	Рязанская область, Милославский район, поселок Поплевинский, Центральная, 20, ЖЭУ	f	medium
116213	78049	214	Рязанская область, Милославский район, поселок Новоалександрово, Центральная, 38, школа	f	small
116208	78043	209	Рязанская область, Милославский район, поселок Мураевня	f	small
116201	78034	202	Рязанская область, Милославский район, поселок Молодежный, Центральная, 4, администрация	t	small
70318	78054	218	Рязанская область, Милославский район, поселок Милославское	f	large
70319	78055	219	Рязанская область, Милославский район, поселок Милославское, Центральная, 14а	f	large
116205	78039	206	Рязанская область, Милославский район, поселок Липяги, Поповка, 6, администрация	f	small
116202	78035	203	Рязанская область, Милославский район, поселок Кочуры, Зеленая, 1, администрация	f	small
116198	78029	199	Рязанская область, Милославский район, поселок Казначеевка, Московская, 11, контора	f	small
116216	78053	217	Рязанская область, Милославский район, поселок Змеевка, Центральная, 3, школа	t	small
116199	78031	200	Рязанская область, Милославский район, поселок Зеленый, Вишневая, 22, администрация	t	small
116195	78025	196	Рязанская область, Милославский район, поселок Дегтярка, Центральная, 15, школа	t	small
116196	78026	197	Рязанская область, Милославский район, поселок Горняк, Ленина, 1, администрация	f	small
116193	78022	194	Рязанская область, Милославский район, поселок Воскресенское 1-е, Центральная, 36, медпункт	f	small
116203	78036	204	Рязанская область, Милославский район, поселок Воейково, Центральная, 39, администрация	f	small
116206	78041	207	Рязанская область, Милославский район, поселок Бугровка, Молодежная, 44, дом культуры	f	small
116212	78048	213	Рязанская область, Милославский район, поселок Боршевое, Центральная, 6, администрация	f	small
116194	78024	195	Рязанская область, Милославский район, поселок Большое Подовечье, Центральная, 4, администрация	f	small
116191	78019	192	Рязанская область, Милославский район, поселок Богородицкое, Школьная, 3, администрация 	f	small
116197	78028	198	Рязанская область, Милославский район, поселок Арцыбашевский, Центральная, 28, клуб	f	small
116204	78038	205	Рязанская область, Милославский район, поселок Архангельское, Ерзикова, 20, дом культуры	f	small
116190	78018	191	Рязанская область, Кораблинский район, поселок Яблонево, Молодежная, 2	f	small
116188	78014	189	Рязанская область, Кораблинский район, поселок Юраково, Новая, 26	f	small
116187	78012	188	Рязанская область, Кораблинский район, поселок Чижово, Верхняя, 4	f	small
116177	77997	177	Рязанская область, Кораблинский район, поселок Совхоз Быковская Степь, Центральная, 27	f	small
116185	78009	186	Рязанская область, Кораблинский район, поселок Семион, Набережная, 3	f	small
116184	78008	185	Рязанская область, Кораблинский район, поселок Пустотино, Школьная, 2	f	medium
70317	78005	183	Рязанская область, Кораблинский район, поселок Пехлец, Центральная, 76	f	large
116181	78003	181	Рязанская область, Кораблинский район, поселок Никитино, Новая, 10	f	small
116180	78002	180	Рязанская область, Кораблинский район, поселок Незнаново, Молодежная, 30	f	medium
116179	78000	179	Рязанская область, Кораблинский район, поселок Моловка, Новая , 19 кв.2	f	small
116182	78004	182	Рязанская область, Кораблинский район, поселок Молвина Слобода, Кукуевская, 13	f	small
116186	78011	187	Рязанская область, Кораблинский район, поселок Лесуново, Лесная, 2	f	small
116178	77999	178	Рязанская область, Кораблинский район, поселок Курбатово, Цветочная, 1	f	small
116415	78349	467	Рязанская область, Кораблинский район, Кораблино	f	medium
70336	77980	164	Рязанская область, Кораблинский район, Кораблино, Школьная, 18	f	large
70335	77978	163	Рязанская область, Кораблинский район, Кораблино, Школьная, 20	f	large
70334	77977	162	Рязанская область, Кораблинский район, Кораблино, Шахтерская, 21	f	large
70333	77976	161	Рязанская область, Кораблинский район, Кораблино, Маяковского, 29, детская музыкальная школа	f	large
70332	77975	160	Рязанская область, Кораблинский район, Кораблино, Маяковского, 30, дом культуры	f	large
116166	77982	166	Рязанская область, Кораблинский район, Кораблино, Заводская, 3, бывшее помещение магазина ООО Кораблинский завод модульных конструкций	f	medium
116172	77979	172	Рязанская область, Кораблинский район, поселок Ковалинка, Луговая, 8	f	small
116175	77994	175	Рязанская область, Кораблинский район, поселок Княжое, микрорайон Каменный карьер, 8	f	small
116176	77996	176	Рязанская область, Кораблинский район, поселок Ключ, Школьная, 39	f	medium
116173	77991	173	Рязанская область, Кораблинский район, поселок Кипчаково, Школьная, 26	f	medium
116174	77993	174	Рязанская область, Кораблинский район, поселок Ибердский, Центральный переулок, 2 а	f	small
116170	77988	170	Рязанская область, Кораблинский район, поселок Ерлино, 3, Административный центр	f	small
116183	78006	184	Рязанская область, Кораблинский район, поселок Газопровода, Центральная, 14, здание СДК	f	small
116169	77986	169	Рязанская область, Кораблинский район, поселок Великая Лука, Центральная, 39	f	small
116168	77985	168	Рязанская область, Кораблинский район, поселок Бобровинки, Братьев Лукьяновых, 43	f	medium
116189	78016	190	Рязанская область, Кораблинский район, поселок Бестужево, Полевая, 4	f	small
116167	77984	167	Рязанская область, Кораблинский район, поселок Аманово, Новая, 23	f	small
116171	77989	171	Рязанская область, Кораблинский район, поселок 1-е отделение совхоза Красное (Проницы), Школьная, 10	f	small
116162	77971	156	Рязанская область, Клепиковский район, поселок Шопино, 45 , ФАП	f	small
116156	77965	150	Рязанская область, Клепиковский район, поселок Уткино, 1, Здание администрации с/п	t	medium
116145	77953	138	Рязанская область, Клепиковский район, поселок Тюково, 7, Здание администрации с/п	f	small
116142	77948	133	Рязанская область, Клепиковский район, поселок Тума, Советская, 76 а	f	medium
70329	77950	135	Рязанская область, Клепиковский район, поселок Тума, Ленина, 18	f	large
116143	77949	134	Рязанская область, Клепиковский район, поселок Тума, Ленина, 133	f	medium
70328	77947	132	Рязанская область, Клепиковский район, поселок Тума, Ленина, 141	f	large
116157	77966	151	Рязанская область, Клепиковский район, поселок Спирино, 1 , Здание администрации с/п	t	small
70325	77943	128	Рязанская область, Клепиковский район, Спас-Клепики, Московская, 33	f	large
70326	77944	129	Рязанская область, Клепиковский район, Спас-Клепики, Ленина, 88	f	large
116141	77946	131	Рязанская область, Клепиковский район, Спас-Клепики, Интернациональная, 26	f	medium
70327	77945	130	Рязанская область, Клепиковский район, Спас-Клепики, Есенина, 8	f	large
116148	77956	141	Рязанская область, Клепиковский район, поселок Прудки, 43, Прудковское лесничество Национальный парк Мещерский	t	small
116150	77958	143	Рязанская область, Клепиковский район, поселок Первушкино, 13 , Детский сад	f	medium
116154	77963	148	Рязанская область, Клепиковский район, поселок Оськино, 54, здание Дома культуры	f	medium
116160	77969	154	Рязанская область, Клепиковский район, поселок Норино, 2 , Здание медпункта	f	small
116147	77955	140	Рязанская область, Клепиковский район, поселок Ненашкино, 2 , Здание администрации с/п	f	small
116164	77973	158	Рязанская область, Клепиковский район, поселок Мягково, 30 , Здание администрации с/п	f	small
116161	77970	155	Рязанская область, Клепиковский район, поселок Молькино, 9 Дружбы	f	small
116158	77967	152	Рязанская область, Клепиковский район, поселок Малахово, 122, Здание администрации с/п	f	small
116144	77951	136	Рязанская область, Клепиковский район, поселок Криуша, 1 Мая, 1 А	f	medium
116146	77954	139	Рязанская область, Клепиковский район, поселок Колычево, 38, Здание администрации с/п	t	small
116159	77968	153	Рязанская область, Клепиковский район, поселок Колесниково, 63, здание администрации	f	small
116149	77957	142	Рязанская область, Клепиковский район, поселок Калдево, 55, Здание сельского Дома культуры	t	small
116151	77959	144	Рязанская область, Клепиковский район, поселок Заднепилево, улица Центральная, 45, администрация	t	small
70331	77960	145	Рязанская область, Клепиковский район, поселок Екшур, Красный Октябрь, 1А, школа	f	large
116165	77974	159	Рязанская область, Клепиковский район, поселок Давыдово, 85 , Здание сельского дома культуры	t	small
116155	77964	149	Рязанская область, Клепиковский район, поселок Гуреево, 13, здание МОУ Гуреевская начальная школа	f	small
116153	77962	147	Рязанская область, Клепиковский район, поселок Гришино, 49, Здание администрации с/п	f	small
116152	77961	146	Рязанская область, Клепиковский район, поселок Бусаево, 139, Здание МОУ Бусаевская начальная школа-детский сад	f	small
70330	77952	137	Рязанская область, Клепиковский район, поселок Болонь, Школьная, 5	f	large
116163	77972	157	Рязанская область, Клепиковский район, поселок Алексеево, 53, здание администрации с/п	f	small
116124	77900	85	Рязанская область, Касимовский район, поселок Щербатовка	t	small
116135	77913	97	Рязанская область, Касимовский район, поселок Шостье	f	small
116137	77916	100	Рязанская область, Касимовский район, поселок Чаур	t	small
116133	77911	95	Рязанская область, Касимовский район, поселок Торбаево	f	small
116130	77908	92	Рязанская область, Касимовский район, поселок Токарево	f	small
116125	77903	87	Рязанская область, Касимовский район, поселок Ташенка	f	medium
70298	77922	105	Рязанская область, Касимовский район, поселок Сынтул, Советская, 8, дом культуры	f	large
116123	77899	84	Рязанская область, Касимовский район, поселок Сосновка	t	small
116134	77912	96	Рязанская область, Касимовский район, поселок Сиверка	t	small
70288	77901	86	Рязанская область, Касимовский район, поселок Селизово	f	large
116121	77897	82	Рязанская область, Касимовский район, поселок Самылово	f	small
116129	77907	91	Рязанская область, Касимовский район, поселок Савостьяново	t	small
116108	77881	68	Рязанская область, Касимовский район, поселок Пустынь	f	medium
116100	77873	60	Рязанская область, Касимовский район, поселок Поповка	t	small
116132	77910	94	Рязанская область, Касимовский район, поселок Подлипки	f	medium
116127	77905	89	Рязанская область, Касимовский район, поселок Погост	t	medium
116126	77904	88	Рязанская область, Касимовский район, поселок Перво	f	medium
116104	77877	64	Рязанская область, Касимовский район, поселок Озерный	t	small
116122	77898	83	Рязанская область, Касимовский район, поселок Новая Деревня	f	medium
116128	77906	90	Рязанская область, Касимовский район, поселок Мишуково	f	small
116119	77894	80	Рязанская область, Касимовский район, поселок Малеево	f	small
116116	77889	76	Рязанская область, Касимовский район, поселок Любовниково	f	small
116114	77887	74	Рязанская область, Касимовский район, поселок Лубяники	t	small
116120	77896	81	Рязанская область, Касимовский район, поселок Лощинино	f	medium
70297	77921	104	Рязанская область, Касимовский район, поселок Лашма, Академика Уткина, 23, школа	f	large
116118	77891	78	Рязанская область, Касимовский район, поселок Крюково	f	small
70287	77893	79	Рязанская область, Касимовский район, поселок Крутоярский	f	large
116113	77886	73	Рязанская область, Касимовский район, поселок Кочемары	t	small
116117	77890	77	Рязанская область, Касимовский район, поселок Которово	f	small
116131	77909	93	Рязанская область, Касимовский район, поселок Кольдюки	t	small
116115	77888	75	Рязанская область, Касимовский район, поселок Клетино	f	medium
116112	77885	72	Рязанская область, Касимовский район, поселок Китово	t	small
116110	77883	70	Рязанская область, Касимовский район, поселок Квасьево	f	small
116111	77884	71	Рязанская область, Касимовский район, поселок Ибердус	f	small
116109	77882	69	Рязанская область, Касимовский район, поселок Ермолово	f	small
70296	77918	102	Рязанская область, Касимовский район, поселок Елатьма, Янина, 3, дом культуры	f	large
70295	77917	101	Рязанская область, Касимовский район, поселок Елатьма, Луначарского, 48, школа	f	large
116106	77879	66	Рязанская область, Касимовский район, поселок Дмитриево	f	medium
116107	77880	67	Рязанская область, Касимовский район, поселок Данево	f	small
116136	77915	99	Рязанская область, Касимовский район, поселок Гусь-Железный, Центральная	f	medium
70294	77914	98	Рязанская область, Касимовский район, поселок Гусь-Железный, Первомайская	f	large
116105	77878	65	Рязанская область, Касимовский район, поселок Гиблицы	f	medium
116103	77876	63	Рязанская область, Касимовский район, поселок Булгаково	f	small
116101	77874	61	Рязанская область, Касимовский район, поселок Балушево-Починки	f	small
116099	77872	59	Рязанская область, Касимовский район, поселок Ахматово	f	medium
116098	77871	58	Рязанская область, Касимовский район, поселок Ардабьево	f	small
116102	77875	62	Рязанская область, Касимовский район, поселок Алешино	t	small
116082	77853	42	Рязанская область, Кадомский район, поселок Четово, Центральная, 10, дом культуры	f	small
116084	77855	44	Рязанская область, Кадомский район, поселок Чермные, Школьная, 2, ФАП	f	small
116088	77859	48	Рязанская область, Кадомский район, поселок Сумерки, клуб	t	small
116083	77854	43	Рязанская область, Кадомский район, поселок Старый Кадом, дом культуры	t	small
116079	77850	39	Рязанская область, Кадомский район, поселок Новоселки, Почтовая, 4, школа	f	small
116080	77851	40	Рязанская область, Кадомский район, поселок Никиткино, Молодежная, 31, сельский дом культуры	f	small
116087	77858	47	Рязанская область, Кадомский район, Кущапино, Базарная, 4, администация	t	small
116090	77861	50	Рязанская область, Кадомский район, поселок Кочемирово, Центральная, 21, клуб	t	small
116085	77856	45	Рязанская область, Кадомский район, поселок Котелино, Школьная, 6, администрация	t	small
116096	77867	56	Рязанская область, Кадомский район, Кадом, Центральная, 31, дом культуры	f	medium
62092	69818	99	Орловская область, Орел, Октябрьская, 35	f	large
116092	77863	52	Рязанская область, Кадомский район, Кадом, Первомайская, 2 Б, общежитие технологического техникума	f	medium
116097	77869	57	Рязанская область, Кадомский район, Кадом, Московская, 31, школа	f	small
116095	77866	55	Рязанская область, Кадомский район, Кадом, Ленина, 8	f	medium
116094	77865	54	Рязанская область, Кадомский район, Кадом, Ленина, 32 А, школа искусств	f	medium
116093	77864	53	Рязанская область, Кадомский район, Кадом, Ленина, 34, дом культуры	f	medium
116091	77862	51	Рязанская область, Кадомский район, Кадом, Касимовская, 4, дом детского творчества	f	medium
116089	77860	49	Рязанская область, Кадомский район, поселок Заулки, Школьная, 4, клуб	t	small
116081	77852	41	Рязанская область, Кадомский район, поселок Енкаево, Центральная, 2, администация	f	small
116086	77857	46	Рязанская область, Кадомский район, поселок Дарьино, Почтовая, 1/3, дом культуры	f	small
116078	77849	38	Рязанская область, Кадомский район, поселок Восход, Почтовая, 1, сельский дом культуры	f	small
116062	77829	20	Рязанская область, Захаровский район, поселок Федоровское	f	medium
116069	77836	27	Рязанская область, Захаровский район, поселок Субботино	f	small
116074	77844	34	Рязанская область, Захаровский район, поселок Старое Зимино	t	small
116076	77847	36	Рязанская область, Захаровский район, поселок Совхоз Смена	f	medium
116073	77843	33	Рязанская область, Захаровский район, поселок Пупкино	f	small
116066	77833	24	Рязанская область, Захаровский район, поселок Поливаново, библиотека	t	small
116072	77842	32	Рязанская область, Захаровский район, поселок Плахино	f	medium
116068	77835	26	Рязанская область, Захаровский район, поселок Остроухово	f	small
116064	77831	22	Рязанская область, Захаровский район, поселок Осово	f	small
116065	77832	23	Рязанская область, Захаровский район, поселок Окуньково	f	small
116071	77840	31	Рязанская область, Захаровский район, поселок Катагоща, ДК	f	small
70292	77838	29	Рязанская область, Захаровский район, поселок Захарово, Школьная, 1 школа	f	large
70293	77839	30	Рязанская область, Захаровский район, поселок Захарово, Центральная, 190, ДК	f	large
116077	77848	37	Рязанская область, Захаровский район, поселок Жонино, административное здание сельского поселения	f	small
116070	77837	28	Рязанская область, Захаровский район, поселок Елино	f	medium
116067	77834	25	Рязанская область, Захаровский район, поселок Добрые Пчелы	f	small
116063	77830	21	Рязанская область, Захаровский район, поселок Большое Коровино	f	small
116061	77828	19	Рязанская область, Захаровский район, поселок Безлычное 3-е	f	medium
116075	77845	35	Рязанская область, Захаровский район, поселок Альяшево	f	small
116060	77827	18	Рязанская область, Ермишинский район, поселок Царево, Центральная, 20	f	small
116059	77826	17	Рязанская область, Ермишинский район, поселок Турмадеево, Центральная, 62	f	small
116058	77825	16	Рязанская область, Ермишинский район, поселок Торопово, Центральная, 24	f	small
116057	77824	15	Рязанская область, Ермишинский район, поселок Спас-Раменье, Моложежная, 20	f	small
116056	77823	14	Рязанская область, Ермишинский район, поселок Свестур, Свестурская, 30	f	small
116055	77822	13	Рязанская область, Ермишинский район, поселок Савватьма, Центральная, 114	f	small
116054	77821	12	Рязанская область, Ермишинский район, поселок Нарма, Центральная, 13	f	small
116053	77820	11	Рязанская область, Ермишинский район, поселок Надежка, Центральная, 79	f	small
116052	77819	10	Рязанская область, Ермишинский район, поселок Мердушь, Поляна, 1	t	small
116051	77818	9	Рязанская область, Ермишинский район, поселок Кафтейка, Зеленая, 66	t	small
116050	77817	8	Рязанская область, Ермишинский район, поселок Игошино, Школьная, 15	f	small
70289	77814	5	Рязанская область, Ермишинский район, поселок Ермишь, пл.Ленина, 62	f	large
70291	77816	7	Рязанская область, Ермишинский район, поселок Ермишь, Садовая, 40	f	large
70290	77815	6	Рязанская область, Ермишинский район, поселок Ермишь, Московская, 63	f	large
116049	77813	4	Рязанская область, Ермишинский район, поселок Гремячий Ключ, Центральная, 4	t	small
116048	77812	3	Рязанская область, Ермишинский район, поселок Власово, Солнечная, 4	f	small
116047	77811	2	Рязанская область, Ермишинский район, поселок Большое Ляхово, Молодежная, 1	f	small
62089	69815	96	Орловская область, Орел, Октябрьская, 12	f	large
116046	77810	1	Рязанская область, Ермишинский район, поселок Азеево, Советская, 14	f	medium
62473	70187	504	Орловская область, с.Отрадинское, 4	f	large
62573	70289	607	Орловская область, железнодорожная станция Стальной Конь	f	medium
62565	70281	599	Орловская область, поселок Хардикова	f	large
62566	70282	600	Красноярский край, деревня Старцево	f	large
62109	69832	116	Орловская область, Орел, улица Цветаева, 42	f	large
62090	69816	97	Орловская область, Орел, улица Тургенева, 44	f	large
62024	69767	31	Орловская область, Орел, улица Силикатная, 12	f	large
62100	69824	107	Орловская область, Орел, улица Пожарная, 52	f	large
62099	69824	106	Орловская область, Орел, улица Пожарная, 52	f	large
62108	69831	115	Орловская область, Орел, улица Матвеева, 12	f	large
62098	69823	105	Орловская область, Орел, улица Максима Горького, 93	f	large
62097	69823	104	Орловская область, Орел, улица Максима Горького, 93	f	large
62065	69796	72	Орловская область, Орел, улица Латышских Стрелков, 103	f	large
62728	69776	788	Орловская область, Орел, улица Дмитрия Блынского, 6	f	large
62041	69776	48	Орловская область, Орел, улица Дмитрия Блынского, 6	f	large
62040	69776	47	Орловская область, Орел, улица Дмитрия Блынского, 6	f	large
62044	69778	51	Орловская область, Орел, улица Гагарина, 35А	f	large
62016	69760	22	Орловская область, Орел, переулок Южный, 26	f	large
62015	69759	21	Орловская область, Орел, переулок Южный, 26	f	large
62059	69791	66	Орловская область, Орел, переулок Циолковского, 6	f	large
62053	69786	60	Орловская область, Орел, переулок Соляной, 2	f	large
62726	70436	786	Орловская область, Орел, переулок Артельный, 3а	f	large
62002	69749	8	Орловская область, Орел, набережная Дубровинского, 40	f	large
62745	70451	820	Орловская область, Орел, генерала Родина, 69	f	large
62047	69781	54	Орловская область, Орел, Черкасская, 81	f	large
62046	69780	53	Орловская область, Орел, Черкасская, 74	f	large
62060	69792	67	Орловская область, Орел, Фридриха Энгельса, 90	f	medium
62084	69810	91	Орловская область, Орел, Узловая улица, 3	f	large
62083	69810	90	Орловская область, Орел, Узловая улица, 3	f	large
62018	69762	24	Орловская область, Орел, Тульская, 63	f	large
62743	70450	818	Орловская область, Орел, Трудовых резервов, 32	f	large
62114	69837	121	Орловская область, Орел, Трудовых Резервов, 32	f	large
62007	69752	13	Орловская область, Орел, Студенческая, 2	f	large
62010	69755	16	Орловская область, Орел, Старо-Привокзальная, 2	f	large
62541	70258	575	Оренбургская область, Оренбург, улица Советская, 21	f	large
61995	69743	1	Орловская область, Орел, Советская, 29	f	large
62023	69766	30	Орловская область, Орел, Силикатная, 22	f	large
62096	69822	103	Орловская область, Орел, Салтыкова-Щедрина, 41	f	large
62088	69814	95	Орловская область, Орел, Салтыкова-Щедрина, 31	f	large
62033	69774	40	Орловская область, Орел, Рощинская улица, 11а	f	large
62031	69772	38	Орловская область, Орел, Рощинская, 33	f	large
62036	69772	43	Орловская область, Орел, Рощинская, 33	f	large
62028	69770	35	Орловская область, Орел, Рощинская, 3	f	large
61997	69745	3	Орловская область, Орел, Революции, 4	f	large
62001	69748	7	Орловская область, Орел, Пушкина, 80	f	large
62000	69748	6	Орловская область, Орел, Пушкина, 80	f	large
62087	69813	94	Орловская область, Орел, Пролетарская гора, 7	f	large
62011	69756	17	Орловская область, Орел, Привокзальная площадь, 8	f	large
62091	69817	98	Орловская область, Орел, Полесская, 53	f	large
61998	69746	4	Орловская область, Орел, Покровская, 8	f	large
62078	69806	85	Орловская область, Орел, Планерная, 55	f	large
62077	69806	84	Орловская область, Орел, Планерная, 55	f	large
62747	69806	823	Орловская область, Орел, Планерная, 55	f	large
62075	69805	82	Орловская область, Орел, Планерная, 35	f	large
62094	69820	101	Орловская область, Орел, Пионерская, 8	f	large
62017	69761	23	Орловская область, Орел, Паровозная, Красный уголок локомотивного депо	f	large
62051	69785	58	Орловская область, Орел, Панчука, 85, МУП совхоз комунальник	f	medium
62052	69782	59	Орловская область, Орел, Панчука, 1	f	large
62048	69782	55	Орловская область, Орел, Панчука, 1	f	large
62014	69693	20	Орловская область, Орел, Орджоникидзе, 3	f	large
62107	69830	114	Орловская область, Орел, Октябрьская, 65	f	large
62104	69828	111	Орловская область, Орел, Октябрьская, 209	f	large
62113	69836	120	Орловская область, Орел, Наугорское шоссе, 29	f	large
62110	69833	117	Орловская область, Орел, Наугорское шоссе, 17	f	large
62739	70446	800	Орловская область, Орел, Московское шоссе, 137	f	large
62727	70437	787	Орловская область, Орел, Московское шоссе, 1А	f	medium
62012	69757	18	Орловская область, Орел, Московская, 34	f	large
61999	69747	5	Орловская область, Орел, Московская, 26	f	large
133607	70478	36	Орловская область, Орел, Металлургов, 3а	f	\N
62037	69773	44	Орловская область, Орел, Металлургов, 42	f	large
62032	69773	39	Орловская область, Орел, Металлургов, 42	f	large
62038	69768	45	Орловская область, Орел, Металлургов, 17	f	large
62025	69768	32	Орловская область, Орел, Металлургов, 17	f	large
62045	69779	52	Орловская область, Орел, Маяковского, 55	f	large
62074	69804	81	Орловская область, Орел, Машкарина, 12	f	large
62111	69834	118	Орловская область, Орел, Матросова, 3	f	large
62069	69799	76	Орловская область, Орел, Маслозаводской переулок, 2	f	large
62732	69775	793	Орловская область, Орел, Маринченко, 25	f	large
62039	69775	46	Орловская область, Орел, Маринченко, 25	f	large
62035	69775	42	Орловская область, Орел, Маринченко, 25	f	large
62729	69771	789	Орловская область, Орел, Маринченко, 9	f	large
62034	69771	41	Орловская область, Орел, Маринченко, 9	f	large
62030	69771	37	Орловская область, Орел, Маринченко, 9	f	large
62027	69769	34	Орловская область, Орел, Маринченко, 10	f	large
62026	69769	33	Орловская область, Орел, Маринченко, 10	f	large
62103	69827	110	Орловская область, Орел, Максима Горького, 117	f	large
62102	69826	109	Орловская область, Орел, Максима Горького, 115	f	large
62086	69812	93	Орловская область, Орел, Максима Горького, 25	f	large
62056	69789	63	Орловская область, Орел, МОПРа, 42	f	large
62055	69788	62	Орловская область, Орел, МОПРа, 24	f	large
62021	69764	27	Орловская область, Орел, Льва Толстого, 6	f	large
62022	69765	29	Орловская область, Орел, Ливенская, 25	f	large
62008	69753	14	Орловская область, Орел, Лесная, 9	f	large
62112	69835	119	Орловская область, Орел, Лескова, 15	f	large
62071	69801	78	Орловская область, Орел, Латышских Стрелков, 105	f	large
62064	69795	71	Орловская область, Орел, Латышских Стрелков, 98	f	large
62080	69807	87	Орловская область, Орел, Кромское шоссе, 29	f	medium
62095	69821	102	Орловская область, Орел, Красноармейская, 17	f	large
62733	70440	794	Орловская область, Орел, Комсомольская, 320	f	large
62079	69803	86	Орловская область, Орел, Комсомольская, 374	f	large
62073	69803	80	Орловская область, Орел, Комсомольская, 374	f	large
62076	69802	83	Орловская область, Орел, Комсомольская, 261А	f	large
62072	69802	79	Орловская область, Орел, Комсомольская, 261А	f	large
62066	69797	73	Орловская область, Орел, Комсомольская, 182	f	large
62067	69797	74	Орловская область, Орел, Комсомольская, 182	f	large
62058	69790	65	Орловская область, Орел, Комсомольская, 170	f	large
62057	69790	64	Орловская область, Орел, Комсомольская, 170	f	large
62744	69787	819	Орловская область, Орел, Комсомольская, 95	f	large
62054	69787	61	Орловская область, Орел, Комсомольская, 95	f	large
62049	69783	56	Орловская область, Орел, Комсомольская, 39	f	large
62746	70452	821	Орловская область, Орел, Картукова, 8	f	large
62063	69794	70	Орловская область, Орел, Карачевское шоссе, 86	f	large
62068	69798	75	Орловская область, Орел, Карачевский переулок, 6	f	large
62050	69784	57	Орловская область, Орел, Карачевская, 29	f	medium
62106	69829	113	Орловская область, Орел, Игнатова, 9	f	large
62105	69829	112	Орловская область, Орел, Игнатова, 9	f	large
62013	69758	19	Орловская область, Орел, Емельяна Пугачева, 2а	f	large
62020	69763	26	Орловская область, Орел, Деповская, 6	f	large
62019	69763	25	Орловская область, Орел, Деповская, 6	f	large
62009	69754	15	Орловская область, Орел, Грузовая, 1	f	large
62082	69809	89	Орловская область, Орел, Городская, 64А, Б	f	large
61996	69744	2	Орловская область, Орел, Герцена, 19	f	large
62043	69777	50	Орловская область, Орел, Воскресенский переулок, 7	f	medium
62042	69777	49	Орловская область, Орел, Воскресенский переулок, 7	f	large
62115	69838	122	Орловская область, Орел, Веселая, 28	f	large
62061	69793	68	Орловская область, Орел, Васильевская, 151	f	large
62062	69793	69	Орловская область, Орел, Васильевская, 151	f	large
62081	69808	88	Орловская область, Орел, Бетонный переулок, 5	f	large
62070	69800	77	Орловская область, Орел, Автовокзальная, 34	f	large
62005	69751	11	Орловская область, Орел, Абрамова-Соколова, 76	f	large
62006	69751	12	Орловская область, Орел, Абрамова-Соколова, 76	f	large
62085	69811	92	Орловская область, Орел, 6-й Орловской дивизии, 25	f	large
62101	69825	108	Орловская область, Орел, Полярная, 11	f	large
62673	70389	722	Орловская область, Орел, Молодежная, 7	f	small
62003	69750	9	Орловская область, Орел, 5 Августа, 25	f	large
62004	69750	10	Орловская область, Орел, 5 Августа, 25	f	large
62533	70249	567	Орловская область, деревня Нижняя Лужна	f	medium
62542	70261	578	республика Башкортостан, село Нижегородка, улица Школьная, 8	f	large
62544	70259	576	республика Башкортостан, село Нижегородка, улица Школьная, 8	f	large
62386	70106	410	Орловская область, поселок Нагорный, 20	f	medium
62167	69889	174	Орловская область, Мценск, Автомагистраль, Отделение скорой медицинской помощ	f	large
62162	69885	169	Орловская область, Мценск, Микрорайон Коммаш, школа №8	f	large
62161	69884	168	Орловская область, Мценск, Тургенева, 32	f	large
62155	69879	162	Орловская область, Мценск, Тургенева, 196	f	large
62160	69878	167	Орловская область, Мценск, Тургенева, 96	f	large
62154	69878	161	Орловская область, Мценск, Тургенева, 96	f	large
62158	69882	165	Орловская область, Мценск, Рева, 32	f	medium
62152	69876	159	Орловская область, Мценск, Мира, 21	f	large
62150	69874	157	Орловская область, Мценск, Мира, 35	f	large
62741	70448	813	Орловская область, Мценск, Микрорайон Коммаш, Клуб ОАО Коммаш	f	large
62159	69883	166	Орловская область, Мценск, Микрорайон 1, 1	f	large
62166	69888	173	Орловская область, Мценск, Машиностроителей, 2	f	large
62156	69880	163	Орловская область, Мценск, Ленина, 194	f	large
62165	69887	172	Орловская область, Мценск, Кузьмина, 1/1	f	large
62164	69886	171	Орловская область, Мценск, Кузьмина, 18	f	large
62163	69886	170	Орловская область, Мценск, Кузьмина, 18	f	large
62168	69890	175	Орловская область, Мценск, Катукова, 1	f	large
62153	69877	160	Орловская область, Мценск, Карла Маркса, 45	f	large
62151	69875	158	Орловская область, Мценск, Карла Маркса, 73	f	large
62157	69881	164	Орловская область, Мценск, Болховская, 60	f	large
62439	70160	470	Орловская область, Малоархангельск, Советская, 25	f	large
62438	70159	469	Орловская область, Малоархангельск, Ленина, 57	f	large
62149	69873	156	Орловская область, Ливны, Энергетиков, 1А	f	small
62125	69848	132	Орловская область, Ливны, Элеваторная, 1	f	large
62126	69849	133	Орловская область, Ливны, Фрунзе, 11	f	large
62748	69851	826	Орловская область, Ливны, Селитренникова, 5	f	large
62128	69851	135	Орловская область, Ливны, Селитренникова, 5	f	large
62134	69857	141	Орловская область, Ливны, Пушкина, 3	f	large
62136	69859	143	Орловская область, Ливны, Октябрьская пл., 5	f	large
62143	69866	150	Орловская область, Ливны, Октябрьская, 39	f	large
62135	69858	142	Орловская область, Ливны, Октябрьская, 7А	f	large
62738	70445	799	Орловская область, Ливны, Московская, 111	f	large
62123	69846	130	Орловская область, Ливны, Московская, 106 Б	f	large
62147	69871	154	Орловская область, Ливны, Мира, 207А	f	large
62145	69868	152	Орловская область, Ливны, Мира, 180А	f	large
62142	69865	149	Орловская область, Ливны, Мира, 152 А	f	large
62130	69853	137	Орловская область, Ливны, Горького, 18	f	large
62131	69854	138	Орловская область, Ливны, Ленина, 24	f	large
62127	69850	134	Орловская область, Ливны, Кирова, 71	f	large
62124	69847	131	Орловская область, Ливны, Кирова, 22	f	large
62132	69855	139	Орловская область, Ливны, Карла Маркса, 120	f	large
62129	69852	136	Орловская область, Ливны, Дзержинского, 112	f	large
62144	69867	151	Орловская область, Ливны, Денисова, 30А	f	large
62138	69861	145	Орловская область, Ливны, Гайдара, 5	f	large
62137	69860	144	Орловская область, Ливны, Пухова, 28	f	large
62148	69872	155	Орловская область, Ливны, Мира, 223А	f	large
62146	69870	153	Орловская область, Ливны, Мира, 186	f	large
62140	69863	147	Орловская область, Ливны, Мира, 138	f	large
62133	69856	140	Орловская область, Ливны, Елецкая, 16 А	f	large
62141	69864	148	Орловская область, Ливны, Гайдара, 8	f	large
62139	69862	146	Орловская область, Ливны, Гайдара, 1	f	large
62556	70272	590	Орловская область, поселок Куликовский	f	large
62576	70292	610	Орловская область, деревня Жилина	f	large
62575	70291	609	Орловская область, деревня Жилина, Строительная, 17, общественное помещение дома	t	large
62535	70251	569	Орловская область, поселок Биофабрика, поселок Биофабрика, Здание культурно-спортивного центра	f	large
62216	69936	223	Курская область, Щигровский район, поселок Капитановка	f	small
62695	70405	749	Орловская область, Шаблыкинский район, поселок Шаблыкино, Советская, 20	f	large
62697	70407	751	Орловская область, Шаблыкинский район, поселок Шаблыкино, Ленина, 2а	f	medium
62696	70406	750	Орловская область, Шаблыкинский район, поселок Шаблыкино, Ленина, 19	f	large
62705	70415	760	Орловская область, Шаблыкинский район, поселок Хотьково, Тургенева, 7	f	medium
62709	70418	764	Орловская область, Шаблыкинский район, поселок Титово, Центральная, 1	f	small
62633	70350	674	Орловская область, Шаблыкинский район, поселок Сомово	f	medium
62700	70410	754	Орловская область, Шаблыкинский район, поселок Сомово, Комсомольская, 2	f	medium
62704	70414	759	Орловская область, Шаблыкинский район, поселок Сельстрой, Советская, 5	f	small
62701	70411	755	Орловская область, Шаблыкинский район, поселок Рядовичи, 78а	f	small
62708	70417	763	Орловская область, Шаблыкинский район, поселок Робье, пер. Почтовый, 1	f	small
62703	70413	758	Орловская область, Шаблыкинский район, поселок Навля	f	small
62706	70416	761	Орловская область, Шаблыкинский район, поселок Молодовое, Садовая, 4	f	small
62699	70409	753	Орловская область, Шаблыкинский район, поселок Косуличи, Школьный переулок, 3	f	small
62710	70419	765	Орловская область, Шаблыкинский район, поселок Герасимово, Медведевка, 1а	f	small
62698	70408	752	Орловская область, Шаблыкинский район, поселок Высокое, пер. Школьный, 1	f	small
62681	70397	730	Орловская область, Хотынецкий район, поселок Хотынец, им. Пушкина, 25	f	large
62683	70399	732	Орловская область, Хотынецкий район, поселок Хотынец, Школьная, 1	f	medium
62682	70398	731	Орловская область, Хотынецкий район, поселок Хотынец, Батова, 47	f	medium
62679	70395	728	Орловская область, Хотынецкий район, поселок Хотимль Кузьменово, Школьная, 9	f	medium
62669	70365	718	Орловская область, Хотынецкий район, поселок Мощеное, Школьная, 6	t	small
62675	70391	724	Орловская область, Хотынецкий район, поселок Льгов, Льговский сельский клуб	f	small
62678	70394	727	Орловская область, Хотынецкий район, поселок Кукуевка, им. Ефимова, 3	f	small
62676	70392	725	Орловская область, Хотынецкий район, поселок Красные Рябинки, Школьная, 9	f	medium
62524	70240	558	Орловская область, Хотынецкий район, поселок Клейменово, Здание сельского дома культуры	f	small
62677	70393	726	Орловская область, Хотынецкий район, поселок Звезда, им. Алдобаева, 7	f	small
62680	70396	729	Орловская область, Хотынецкий район, поселок Жудерский, Школьная, 6	f	small
62668	70385	717	Орловская область, Хотынецкий район, поселок Воейково, Молодежная, 1	f	medium
62193	69912	200	Орловская область, Хотынецкий район, поселок Верховье, Привокзальная, 3	f	large
62671	70387	720	Орловская область, Хотынецкий район, поселок Большое Юрьево, МОУ - Юрьевская средняя общеобразовательная школа	f	small
62672	70388	721	Ростовская область, Песчанокопский район, село Богородицкое	f	medium
62670	70386	719	Орловская область, Хотынецкий район, поселок Алехино, Алехинский сельский Дом культуры	f	small
62662	70379	710	Орловская область, Урицкий район, поселок Ясная Поляна, Центральная, 12	f	small
62702	70412	757	Орловская область, Урицкий район, поселок Юшково, помещение конторы ООО &quot;&quot;Агротех-Юшково&quot;&quot;&quot;	f	small
62649	70366	697	Орловская область, Урицкий район, поселок Юшино, Первомайская, 6	f	small
62183	69905	190	Россия, Орловская область, Урицкий район, поселок Черногрязка	f	medium
62648	70348	696	Орловская область, Урицкий район, поселок Совхозный, Советская, 10	f	medium
62663	70380	711	Орловская область, Урицкий район, поселок Себякино, Молодежная, 19	f	small
62423	70144	453	Орловская область, Урицкий район, поселок Прогресс, Здание Дома культуры	f	medium
62664	70381	712	Орловская область, Урицкий район, поселок Подзавалово, Школьная, 2	f	medium
62655	70372	703	Орловская область, Урицкий район, поселок Парамоново, Д.Давыдова, 23	f	small
62657	70374	705	Орловская область, Урицкий район, поселок Муравлево, Микрорайон Школьный, 5	f	small
83876	57320	3066	Москва, Зеленоград, к1642	f	large
62661	70378	709	Орловская область, Урицкий район, поселок Максимовский, Школьная, 6	f	small
62653	70370	701	Орловская область, Урицкий район, поселок Лески, Школьная, 2	f	small
62660	70377	708	Орловская область, Урицкий район, поселок Ледно, Молодежная, 24а	f	medium
62613	70327	651	Орловская область, Урицкий район, поселок Кошелево, Здание Кошелевской основной школы	f	small
62656	70373	704	Орловская область, Урицкий район, поселок Городище, Центральная, 47	f	medium
62650	70367	698	Орловская область, Урицкий район, поселок Бунинский, Центральная, 4	f	small
62654	70371	702	Орловская область, Урицкий район, поселок Бунино, Державина, 15	f	small
62659	70376	707	Орловская область, Урицкий район, поселок Большое Сотниково, Победы, 13	f	small
62640	70357	681	Орловская область, Троснянский район, поселок Чермошное, здание Чермошновского СДК	f	small
62642	70359	683	Московская область, Наро-Фоминский район, деревня Турейка	t	small
62631	70347	672	Орловская область, Троснянский район, поселок Тросна, Московская, 31	f	large
112586	70351	675	Россия, Орловская область, Троснянский район, поселок Нижнее Муханово	f	\N
112588	70358	682	Россия, Орловская область, Троснянский район, поселок Муравль	f	\N
112587	70353	677	Россия, Орловская область, Троснянский район, поселок Ломовец	f	\N
62632	70349	673	Орловская область, Троснянский район, поселок Ладарево	f	small
62639	70356	680	Ростовская область, Орловский район, поселок Красноармейский	f	small
62644	70361	685	Орловская область, Троснянский район, поселок Красавка	t	small
62638	70355	679	Орловская область, Троснянский район, поселок Колычевский	f	small
112589	70364	688	Россия, Орловская область, Троснянский район, поселок Каменец	f	\N
62635	70352	676	Орловская область, Троснянский район, поселок Жизло-Павлово	t	small
62645	70362	686	Орловская область, Троснянский район, поселок Гнилец	f	small
62646	70363	687	Кировская область, Немский район, село Воронец	f	small
62482	70196	513	Орловская область, Троснянский район, поселок Бобрик, здание Погореловского клуба	t	small
62715	70425	772	Орловская область, Сосковский район, поселок Хмелевая, Здание Чмелевского СК МУКТТ Алпеевское КДО	f	small
62723	70433	780	Орловская область, Сосковский район, поселок Сосково, Советская, 26	f	small
62722	70432	779	Орловская область, Сосковский район, поселок Сосково, Советская, 29	f	large
62721	70431	778	Орловская область, Сосковский район, поселок Сосково, Ленина, 18	f	small
62712	70421	769	Орловская область, Сосковский район, поселок Сковородовка, 46	f	small
62718	70428	775	Орловская область, Сосковский район, поселок Новогнездилово	f	small
62724	70434	781	Орловская область, Сосковский район, поселок Мыцкое	f	small
62716	70426	773	Орловская область, Сосковский район, поселок Мураевка	f	medium
62717	70427	774	Орловская область, Сосковский район, поселок Кирово	f	small
62714	70423	771	Орловская область, Сосковский район, поселок Гнилое Болото	f	small
62719	70429	776	Калужская область, Хвастовичский район, поселок Волчьи Ямы	f	small
62711	70420	768	Саратовская область, Балашовский район, село Алмазово	f	small
62621	70337	661	Орловская область, Свердловский район, поселок Хотетово, Здание Хотетовской основной школы	f	small
62562	70278	596	Орловская область, Свердловский район, поселок Троицкое, Здание сельского дома культуры	f	small
62592	70307	628	Орловская область, Свердловский район, поселок Столбецкое, Школьная, 23	t	small
62628	70344	668	Орловская область, Свердловский район, поселок Степановка, Здание Степановской сельской библиотеки	t	small
62737	70444	798	Россия, Орловская область, Свердловский район, поселок Разбегаевка	f	medium
62623	70339	663	Оренбургская область, Матвеевский район, село Новопетровка	f	small
62643	70360	684	Орловская область, Свердловский район, поселок Никольское, здание Никольского СДК	f	medium
62617	70332	655	Орловская область, Свердловский район, поселок Никольское, Здание Никольской средней школы	f	medium
62612	70326	650	Орловская область, Свердловский район, поселок Нахлестово	f	medium
62362	70082	383	Орловская область, Свердловский район, поселок Морозовский, здание Федотовского социального центра	f	small
62480	70194	511	Орловская область, Свердловский район, поселок Михайловка, здание Мансуровской школы	f	small
111558	57319	3065	Москва, Зеленоград, к1632	f	medium
62630	70346	670	Тверская область, Бельский район, поселок Куракинский	f	medium
62615	70329	653	Орловская область, Свердловский район, поселок Красная Рыбница	f	small
62611	70325	649	Орловская область, Свердловский район, поселок Котовка, Здание Котовского сельского Дома культуры	f	medium
62614	70328	652	Орловская область, Свердловский район, поселок Козьминское	f	small
62181	69903	188	Московская область, Каширский район, деревня Знаменское	f	small
112585	70334	658	Орловская область, Свердловский район, поселок Змиево, Кимовский СК	t	\N
62736	70443	797	Орловская область, Свердловский район, поселок Змиевка, Школьная, 5	f	large
62610	70324	648	Орловская область, Свердловский район, поселок Змиевка, Чкалова, 12	f	large
62609	70323	647	Орловская область, Свердловский район, поселок Змиевка, Садовая, 45	f	large
62608	70322	646	Орловская область, Свердловский район, поселок Змиевка, Ленина, 25	f	large
62620	70336	660	Орловская область, Свердловский район, поселок Еропкино-Большак	f	small
62622	70338	662	Орловская область, Свердловский район, поселок Гостиново	f	small
62629	70345	669	Орловская область, Свердловский район, поселок Борисоглебское	f	small
62627	70343	667	Орловская область, Свердловский район, поселок Богодухово	f	medium
62600	70314	637	Орловская область, Покровский район, поселок Шалимовка, Центральная, 24	f	small
62585	70300	621	Орловская область, Покровский район, поселок Хаустово, Центральная, 12	f	small
62591	70306	627	Орловская область, Покровский район, поселок Федоровка, Центральная, 16	f	small
62590	70305	626	Орловская область, Покровский район, поселок Успенское, Овалова, 10	f	small
62398	70118	426	Орловская область, Покровский район, поселок Успенское, Мира, 8а	f	large
62210	69930	217	Орловская область, Покровский район, поселок Троицкое, Троицкая средняя общеобразовательная школа	f	small
62605	70319	642	Орловская область, Покровский район, поселок Топки, Центральная, 5	f	small
62593	70308	629	Орловская область, Покровский район, поселок Тимирязево, Школьная, 6	f	small
62584	70299	620	Орловская область, Покровский район, поселок Тетерье, Центральная, 22	f	small
62606	70320	643	Орловская область, Покровский район, поселок Смирные, Центральная, 6	f	small
62598	70312	635	Орловская область, Покровский район, поселок Сетенева, Центральная, 42	f	small
62589	70304	625	Орловская область, Покровский район, поселок Протасово, Заречная, 14	t	small
62579	70295	615	Орловская область, Покровский район, поселок Покровское, Советская, 14	f	large
62578	70294	614	Орловская область, Покровский район, поселок Покровское, 50 лет Октября, 4	f	large
62595	70310	632	Орловская область, Покровский район, поселок Озерное, Центральная, 5	f	small
62588	70303	624	Орловская область, Покровский район, поселок Нижний Туровец, Советская, 1	f	small
62582	70297	618	Орловская область, Покровский район, поселок Малая Казинка, Центральная, 23	f	small
62731	70439	791	Орловская область, Покровский район, поселок Дубки, Рабочая, 10	f	small
62597	70201	634	Орловская область, Покровский район, поселок Дросково, Советская, 69	f	large
62583	70298	619	Орловская область, Покровский район, поселок Даниловка, Административная, 2	f	small
62599	70313	636	Орловская область, Покровский район, поселок Внуково, Школьная, 13	f	small
62607	70321	644	Орловская область, Покровский район, поселок Верхососенье Средина 1-я, Алферьева, 24	f	small
62601	70315	638	Орловская область, Покровский район, поселок Вепринец, Цветочная, 22	f	small
62594	70309	630	Орловская область, Покровский район, поселок Алексеевка, Центральная, 28	f	small
62179	69901	186	Россия, Псковская область, Новоржевский район, село Щербово	f	small
62536	70253	570	Россия, Алтайский край, Калманский район, поселок Шиловский	f	medium
62571	70287	605	Орловская область, Орловский район, поселок Шепино	f	small
62540	70257	574	Орловская область, Орловский район, поселок Усть-Рыбница	f	medium
62528	70244	562	Нижегородская область, Борский район, село Тайное	f	small
62558	70274	592	Орловская область, Орловский район, поселок Ступишено	f	small
62530	70246	564	Тульская область, Одоевский район, поселок Стрелецкий	f	large
62551	70268	585	Орловская область, Орловский район, поселок Становой Колодезь	f	medium
62550	70267	584	Орловская область, Орловский район, поселок Становой Колодезь	f	large
62549	70266	583	Орловская область, Орловский район, поселок Путимец	f	small
62560	70276	594	Орловская область, Орловский район, деревня Пугачевка	f	medium
62522	70238	556	Орловская область, Орловский район, поселок Полозовские Дворы	f	small
62574	70290	608	Новгородская область, Демянский район, село Плещеево	f	large
62526	70242	560	Орловская область, Орловский район, поселок Паюсово	f	small
62261	69980	273	Орловская область, Орловский район, поселок Новотроицкое	t	small
62577	70293	611	Московская область, Воскресенский район, деревня Новоселово	f	small
62552	70269	586	Орловская область, Орловский район, поселок Новодмитровка	f	small
62568	70284	602	Орловская область, Орловский район, поселок Нижняя Калиновка	f	medium
62534	70250	568	Орловская область, Орловский район, поселок Некрасовка	f	medium
62525	70241	559	Орловская область, Орловский район, поселок Моховица	f	medium
62555	70252	589	Орловская область, Орловский район, поселок Михайловка, Здание детского сада	f	medium
62559	70275	593	Орловская область, Орловский район, поселок Малое Рябцево	f	small
62554	70271	588	Вологодская область, Череповецкий район, село Лаврово	f	large
62561	70277	595	Орловская область, Орловский район, поселок Красная Звезда, Здание столовой ОПХ Красная Звезда	f	medium
62563	70279	597	Архангельская область, Плесецкий район, село Карпова	f	small
62532	70248	566	Московская область, Сергиево-Посадский район, деревня Истомино	f	small
62570	70286	604	Московская область, Серпуховский район, деревня Ивановское	f	medium
62616	70330	654	Орловская область, Орловский район, поселок Знаменское, Здание Знаменского сельского Дома Культуры	t	small
112584	70260	577	Россия, Орловская область, Орловский район, поселок Знаменка	f	\N
62538	70255	572	Орловская область, Орловский район, поселок Звягинки	f	large
62427	70148	457	Нижегородская область, Воскресенский район, село Дубовик	f	small
62523	70239	557	Московская область, Раменский район, поселок Дубовая Роща	f	small
62625	70341	665	Орловская область, Орловский район, поселок Домнино, Здание Первомайской основной школы	f	small
62548	70265	582	Орловская область, Орловский район, поселок Добрый	f	medium
62547	70264	581	Орловская область, Орловский район, поселок Добрый	f	small
62603	70317	640	Орловская область, Орловский район, поселок Грачевка, переулок Школьный, 5	f	small
62287	70007	300	Орловская область, Орловский район, поселок Грачевка, Луговая, 4	f	medium
62567	70283	601	Орловская область, Орловский район, поселок Вязки	t	small
62557	70273	591	Орловская область, Орловский район, поселок Большая Куликовка	f	medium
62531	70247	565	Орловская область, Орловский район, поселок Болотовские Дворы	f	medium
62572	70288	606	Орловская область, Орловский район, поселок Белоберезовский	f	medium
62529	70245	563	Вологодская область, Кичменгско-Городецкий район, село Бакланово	f	medium
62546	70263	580	Орловская область, Орловский район, поселок Альшань	f	small
62502	70217	533	Орловская область, Новосильский район, поселок Чулково, Раздольная, 38	f	small
62506	70221	537	Орловская область, Новосильский район, поселок Хутор (деревня Михалево), Центральная, 5	f	small
62510	70225	543	Орловская область, Новосильский район, поселок Хворостянка, Центральная, 26	t	small
62511	70226	544	Орловская область, Новосильский район, поселок Селезнево, Школьная, 8	f	small
62504	70219	535	Орловская область, Новосильский район, поселок Ржавка, Садовая, 3	t	small
62501	70216	532	Орловская область, Новосильский район, поселок Одинок, Школьная, 13	f	small
62498	70213	529	Орловская область, Новосильский район, Новосиль, Карла Маркса, 86	f	large
62497	70212	528	Орловская область, Новосильский район, Новосиль, Карла Маркса, 37	f	large
62508	70223	540	Орловская область, Новосильский район, поселок Мужиково, Победы, 101	f	small
62527	70243	561	Вологодская область, Череповецкий район, село Маслово	f	medium
62505	70220	536	Орловская область, Новосильский район, поселок Заречье, Центральная, 28	f	medium
62500	70215	531	Орловская область, Новосильский район, поселок Задушное, Центральная, 21	f	small
112583	70218	534	Орловская область, Новосильский район, поселок Голунь, Центральная, 15/3	f	\N
62499	70214	530	Орловская область, Новосильский район, поселок Вяжи-Заверх, Лесная, 37	f	small
62509	70224	541	Орловская область, Новосильский район, поселок Воротынцево, Образцовая, 2	f	small
62507	70222	539	Орловская область, Новосильский район, поселок Большие Пруды, Центральная, 17	f	small
62486	70200	517	Орловская область, Новодеревеньковский район, поселок Шатилово, здание Шатиловского лицея	f	small
112580	70189	506	Орловская область, Новодеревеньковский район, поселок Хомутово, Победы, 1а	f	\N
62476	70190	507	Орловская область, Новодеревеньковский район, поселок Хомутово, Комсомольская, 22	f	large
62484	70198	515	Орловская область, Новодеревеньковский район, поселок Суры, здание Суровской начальной школы	f	small
62488	70203	519	Орловская область, Новодеревеньковский район, поселок Судбищи	f	small
62494	70209	525	Воронежская область, Грибановский район, поселок Старогольское	t	small
62618	70333	657	Орловская область, Новодеревеньковский район, поселок Плоское, Здание Плосковской основной школы	f	small
62495	70210	526	Тверская область, Спировский район, поселок Пасынки	t	small
62491	70206	522	Орловская область, Новодеревеньковский район, поселок Паньково, здание Паньковской школы	f	medium
62477	70191	508	Орловская область, Новодеревеньковский район, поселок Новая Заря, здание МДОУ Новозоренский детский сад	t	small
62478	70192	509	Орловская область, Новодеревеньковский район, поселок Никольское, здание МОУ Никольская нач. школа	f	small
62413	70133	443	Орловская область, Новодеревеньковский район, поселок Никольское, Колхозная, 1а	f	small
112581	70195	512	Орловская область, Новодеревеньковский район, поселок Муравьевка, Школьная, 3	f	\N
112582	70202	518	Россия, Орловская область, Новодеревеньковский район, поселок Моховое	f	\N
62483	70197	514	Орловская область, Новодеревеньковский район, поселок Лазавка	f	small
62485	70199	516	Орловская область, Новодеревеньковский район, поселок Кулеши	f	small
62479	70193	510	Калужская область, деревня Косарево	f	small
62493	70208	524	Орловская область, Новодеревеньковский район, поселок Кологривово	f	small
62489	70204	520	Тульская область, Тула, улица Дементьева, 10	f	small
62496	70211	527	Московская область, Дмитровский район, деревня Благодать	t	small
62446	70166	477	Орловская область, Мценский район, поселок Ядрино, 54	f	small
62459	70176	490	Орловская область, Мценский район, поселок Шашкино, Школьная, 4	f	small
62443	70163	474	Орловская область, Мценский район, поселок Черемошны, Садовая, 2	f	medium
62451	70170	482	Орловская область, Мценский район, поселок Чахино, Мичурина, 44	t	small
62457	70174	488	Орловская область, Мценский район, поселок Фроловка, Центральная, 2	t	small
62463	70180	494	Орловская область, Мценский район, поселок Фарафоново, Школьная, 5	f	small
62460	70177	491	Орловская область, Мценский район, поселок Тельчье, Ленина, 1	f	medium
62466	55525	497	Орловская область, Мценский район, поселок Сычи, Центральная, 1	t	small
62455	70172	486	Орловская область, Мценский район, поселок Спасское-Лутовиново, Никольская, 19	f	medium
62185	69907	192	Россия, Псковская область, Новоржевский район, село Руднево	f	small
62464	70181	495	Орловская область, Мценский район, поселок Протасово, Полянская, 27	f	small
62445	70165	476	Орловская область, Мценский район, поселок Подберезово, 24	f	small
62450	70169	481	Орловская область, Мценский район, поселок Подбелевец, Школьная, 1	f	small
62412	70132	442	Орловская область, Мценский район, поселок Петровка, Центральная, 4	f	small
112579	70188	505	Орловская область, Мценский район, поселок Отрадинский, Совхозная, 3	f	\N
62469	70184	500	Орловская область, Мценский район, поселок Нововолковский, Центральная, 18	f	medium
62604	70318	641	Орловская область, Мценский район, поселок Никольское, Центральная, 1	f	small
62456	70173	487	Орловская область, Мценский район, поселок Нижняя Зароща, Мира, 28а	f	small
62667	70384	715	Орловская область, Мценский район, поселок Нарышкино, Чапаева, 26	f	large
62666	70383	714	Орловская область, Мценский район, поселок Нарышкино, Чапаева, 6	f	large
62665	70382	713	Орловская область, Мценский район, поселок Нарышкино, Ленина, 95	f	large
62447	70167	478	Орловская область, Мценский район, поселок Мелынь, Квартальная, 7	f	small
62444	70164	475	Орловская область, Мценский район, поселок Жилино, Минаева, 7	f	medium
52590	59936	2965	Московская область, Троицк, микрорайон В, 26	f	large
62465	70182	496	Орловская область, Мценский район, поселок Добрая Вода, Школьный переулок, 3	t	small
62626	70342	666	Орловская область, Мценский район, поселок Городище, Здание Городищенского сельского Дома культуры	t	small
62458	70175	489	Орловская область, Мценский район, поселок Глазуново, Школьная, 4	f	medium
62442	70162	473	Орловская область, Мценский район, поселок Гладкое, Школьная, 8	f	small
62448	70168	479	Орловская область, Мценский район, поселок Высокое, Школьная, 1	f	small
62470	70185	501	Орловская область, Мценский район, поселок Волково, Центральная, 2	f	small
62468	70183	498	Орловская область, Мценский район, поселок Воин 1-й, Тюленина, 1	f	medium
62441	70142	472	Орловская область, Мценский район, поселок Верхнее Алябьево, пл.Центральная, 2	f	medium
62461	70178	492	Орловская область, Мценский район, поселок Брагино, Молодежная, 36	f	medium
112578	70171	483	Орловская область, Мценский район, поселок Большая Каменка, 4	f	\N
62472	70186	503	Орловская область, Мценский район, поселок Башкатово, Школьная, 4	t	small
62361	70080	382	Орловская область, Мценский район, поселок Апальково, здание администрации Апальковского сельского поселения	f	small
62462	70179	493	Орловская область, Мценский район, поселок Аниканово, Центральная, 13	f	small
62430	70151	460	Орловская область, Малоархангельский район, поселок Хитрово, Здание Дома культуры	f	small
62433	70154	464	Орловская область, Малоархангельский район, поселок Рогатый	f	small
62437	70158	468	Орловская область, Малоархангельский район, поселок Подгородняя 2-я	f	medium
62432	70153	462	Орловская область, Малоархангельский район, поселок Плещеевский Завод	f	small
62394	70114	420	Орловская область, Малоархангельский район, поселок Остров, Центральная, 10	f	medium
62421	70141	451	Орловская область, Малоархангельский район, поселок Новая Стройка	f	medium
62422	70143	452	Орловская область, Малоархангельский район, поселок Малоархангельск	f	medium
62440	70161	471	Орловская область, Малоархангельский район, Малоархангельск, К.Либкнехта, 64	f	large
62431	70152	461	Псковская область, Бежаницкий район, село Луковец	f	medium
62434	70155	465	Орловская область, Малоархангельский район, поселок Легостаево 1-е	t	small
62424	70145	454	Московская область, Королев, микрорайон Костино	f	small
62429	70150	459	Орловская область, Малоархангельский район, поселок Ивань 1-я	f	small
62436	70157	467	Псковская область, Новоржевский район, село Губкино	f	small
62335	70056	354	Орловская область, Малоархангельский район, поселок Гриневка, Садовая, 51а	f	small
62435	70156	466	Орловская область, Малоархангельский район, поселок Гнилая Плота	t	small
62428	70149	458	Костромская область, Чухломский район, поселок Архарово	f	small
62401	70121	429	Орловская область, Ливны городской округ, поселок Беломестное, Воронежская, 17	f	large
62402	70122	430	Орловская область, Ливенский район, поселок Троицкое, Садовая, 4	f	small
62381	70101	405	Орловская область, Ливенский район, поселок Теличье, Дружбы Народов, 33	f	small
112577	70099	403	Орловская область, Ливенский район, поселок Сосновка, Центральная, 2	f	\N
62395	70115	421	Орловская область, Ливенский район, поселок Совхозный, Центральная, 8	f	medium
62410	70130	440	Орловская область, Ливенский район, поселок Сергиевское, Пентюхова, 15	f	medium
62390	70110	415	Орловская область, Ливенский район, поселок Семенихино, Школьная, 1а	f	medium
62417	70137	447	Орловская область, Ливенский район, поселок Свободная Дубрава, Центральная, 21	f	small
62387	70107	411	Орловская область, Ливенский район, поселок Сахзаводской, Комсомольская, 34	f	large
62407	70127	436	Орловская область, Ливенский район, поселок Росстани, Ассовиахим, 41	f	medium
62380	70100	404	Орловская область, Ливенский район, поселок Речица, Центральная, 58	f	medium
62382	70102	406	Орловская область, Ливенский район, поселок Покровка 1-я, Молодежная, 18	f	medium
62690	55934	744	Орловская область, Ливенский район, поселок Пешково, Советская, 20	t	small
62391	70111	416	Орловская область, Ливенский район, поселок Орлово, Орловская, 96	f	small
62564	70280	598	Московская область, Солнечногорский район, деревня Овсянниково	f	large
62416	70136	446	Орловская область, Ливенский район, поселок Норовка, Фрунзе, 17	f	small
62370	70090	392	Орловская область, Кромский район, поселок Кутафино	f	small
62418	70138	448	Орловская область, Ливенский район, поселок Навесное, Центральная, 23	f	small
62385	70105	409	Орловская область, Ливенский район, поселок Набережный, Школьная, 35	f	medium
62384	70104	408	Орловская область, Ливенский район, поселок Моногарово, Октябрьская, 2	f	small
62586	70301	622	Орловская область, Ливенский район, поселок Липовец, Центральная, 34	f	small
62396	70116	422	Орловская область, Ливенский район, поселок Липовец, Н.А. Кузьмина, 36	f	medium
62226	69945	238	Орловская область, Ливенский район, поселок Кунач	f	medium
62399	70119	427	Орловская область, Ливенский район, поселок Кунач, Церковная, 28	f	small
62383	70103	407	Орловская область, Ливенский район, поселок Крутое, Комсомольская, 1	f	large
62420	70140	450	Орловская область, Ливенский район, поселок Круглое, Круглянская, 36	t	small
62405	70125	433	Орловская область, Ливенский район, поселок Коротыш, Молодежная, 7	f	large
62397	70117	424	Орловская область, Ливенский район, поселок Козьминка, Центральная, 28	f	medium
62553	70270	587	Россия, Вологодская область, Верховажский район, село Калинино	f	medium
62415	70135	445	Орловская область, Ливенский район, поселок Казанское, М. Горького, 25	f	small
62388	70108	412	Орловская область, Ливенский район, поселок Зубцово, Вишневая, 13	f	small
62389	70109	413	Орловская область, Ливенский район, поселок Здоровецкие Выселки, Центральная, 75	f	medium
62658	70375	706	Россия, Волгоградская область, Волгоград, поселок Заречный	f	medium
62537	70254	571	Липецкая область, Чаплыгинский район, поселок Зареченский	f	large
62411	70131	441	Орловская область, Ливенский район, поселок Жерино, Воронежская, 2	f	small
62414	70134	444	Орловская область, Ливенский район, поселок Екатериновка, Центральная, 3	f	small
62392	70112	418	Орловская область, Ливенский район, поселок Гремячий Колодезь, Центральная, 5а	f	medium
62404	70124	432	Орловская область, Ливенский район, поселок Горностаевка, площадь Центральная, 5	t	small
62419	70139	449	Орловская область, Ливенский район, поселок Вязовая Дубрава, Центральная, 13	t	small
62393	70113	419	Орловская область, Ливенский район, поселок Воротынск, Школьная, 5а	t	small
62400	70120	428	Орловская область, Ливенский район, поселок Викторовка, Центральная, 44	f	small
62408	70128	438	Орловская область, Ливенский район, поселок Введенское, Ливенская, 38	f	small
62406	70126	434	Орловская область, Ливенский район, поселок Вахново, Центральная, 44	t	small
62378	70098	402	Орловская область, Ливенский район, поселок Важжова, Полевая, 2	t	small
62403	70123	431	Орловская область, Ливенский район, поселок Барково, Карла Маркса, 41	t	small
62409	70129	439	Орловская область, Ливенский район, поселок Бараново, Войнова, 5	f	small
62619	70335	659	Россия, Московская область, Химки, квартал Яковлево, 10	f	medium
62373	70093	396	Орловская область, Кромский район, поселок Шоссе	f	small
62347	70066	368	Орловская область, Кромский район, поселок Шахово, Победы, здание Шаховского сельского клуба	t	small
62351	70070	372	Орловская область, Кромский район, поселок Черкасская	f	large
62349	70068	370	Орловская область, Кромский район, поселок Стрелецкая	f	small
62360	70079	381	Московская область, Одинцовский район, деревня Семенково	f	small
62720	70430	777	Орловская область, Кромский район, поселок Рыжково, Здание Рыжковского СК МУККТ Рыжковское КДО	f	medium
62358	70077	379	Ленинградская область, Сланцевский район, деревня Родина	f	small
62372	70092	395	Орловская область, Кромский район, поселок Ржава, 56	t	small
62359	70078	380	Орловская область, Кромский район, поселок Ретяжи	f	small
62350	70069	371	Орловская область, Кромский район, деревня Рассыльная, филиал структурного подразделения МОУ Черкасская школа	f	medium
62375	70095	398	Орловская область, Кромский район, поселок Рассоховец	f	small
62352	70071	373	Орловская область, Кромский район, поселок Пушкарная	f	medium
62374	70094	397	Орловская область, Кромский район, поселок Моховое, здание Моховского сельского дома культуры	f	small
62596	70311	633	Орловская область, Кромский район, поселок Моховое, Лесная, 3	f	small
62368	70088	389	Орловская область, Кромский район, поселок Малая Драгунская, здание магазина ИП Пясецкого В.Ф.	f	small
62377	70097	401	Московская область, Ступинский район, деревня Макеево	f	small
83875	57319	3064	Москва, Зеленоград, к1632	f	large
62730	70438	790	Орловская область, Кромский район, поселок Кромы, красный уголок отделения Орловской дистанции пути ПЧ-25	f	small
62365	70085	386	Орловская область, Кромский район, поселок Кромы, пер.Бобкова, корпус ПУ-19	f	large
62364	70084	385	Орловская область, Кромский район, поселок Кромы, Советская, 1 , районный дом культуры	f	large
62366	70086	387	Орловская область, Кромский район, поселок Кромы, Заводской пер., 6, кр. уг. треста Кромымежрайгаз	f	medium
62367	70087	388	Орловская область, Кромский район, поселок Кромы, Карла Маркса	f	large
62353	70072	374	Орловская область, Кромский район, поселок Кромской	f	small
62355	70074	376	Орловская область, Кромский район, поселок Кромский Мост	f	small
62356	70075	377	Орловская область, Кромский район, поселок Кривчиково	f	small
62492	70207	523	Орловская область, Кромский район, поселок Красный Октябрь, здание Краснооктябрьской школы	f	small
62691	56192	745	Орловская область, Кромский район, поселок Красниково, Майская, 21	f	small
62376	70096	400	Московская область, Ступинский район, село Короськово	f	small
62363	70083	384	Орловская область, Кромский район, поселок Коровье Болото	f	small
62369	70089	390	Орловская область, Кромский район, поселок Глинки, здание МОУ Глинская средняя общеобразовательная школа	f	small
62371	70091	394	Орловская область, Кромский район, поселок Бельдяжки	f	small
62354	70073	375	Орловская область, Кромский район, поселок Атяевка	f	medium
62357	70076	378	Московская область, Дмитровский район, деревня Арбузово	f	small
62337	70058	356	Орловская область, Краснозоренский район, поселок Шатилово, Школьная, 3	f	small
62334	70055	353	Орловская область, Краснозоренский район, поселок Россошенский, Ленина, 18	f	medium
62344	70046	363	Орловская область, Краснозоренский район, поселок Протасово, Центральная, 2	f	small
62339	70060	358	Орловская область, Краснозоренский район, поселок Пол-Успенье, Центральная, 33	f	small
62343	70064	362	Орловская область, Краснозоренский район, поселок Покровское, Ленина, 4	f	small
62332	70053	351	Орловская область, Краснозоренский район, поселок Орево, Школьная, 3	f	small
62345	55492	364	Орловская область, Краснозоренский район, поселок Медвежье, Толстовка, 31	f	small
62341	70062	360	Орловская область, Краснозоренский район, поселок Малиново, Центральная, 2	f	small
62331	70052	350	Орловская область, Краснозоренский район, поселок Красная Заря, Ленина, 9	f	large
62340	70061	359	Орловская область, Краснозоренский район, поселок Зверево-Бакулино, Молодежная, 6	f	small
62333	70054	352	Орловская область, Краснозоренский район, поселок Верхняя Любовша, Набережная, 10	f	small
62338	70059	357	Орловская область, Краснозоренский район, поселок Большая Чернава, Школьная, 18	f	small
62336	70057	355	Орловская область, Краснозоренский район, поселок Бегичево, 8 Марта, 5	t	small
62513	70228	546	Орловская область, Корсаковский район, поселок Страховка, 36	f	small
62515	70230	548	Орловская область, Корсаковский район, поселок Спешнево	f	small
62624	70340	664	Кировская область, Яранский район, село Петрово	f	small
62519	70235	552	Орловская область, Корсаковский район, поселок Парамоново, 52	f	small
62539	70256	573	Орловская область, Корсаковский район, поселок Образцово, Здание сельского дома культуры	f	medium
62514	70229	547	Орловская область, Корсаковский район, поселок Новомихайловка, 100	f	small
62520	70236	553	Орловская область, Корсаковский район, поселок Новомалиново	f	small
62521	70237	554	Орловская область, Корсаковский район, поселок Нечаево, 53	f	medium
62517	70232	550	Орловская область, Корсаковский район, поселок Мельничная Слобода, 36	f	small
62516	70231	549	Орловская область, Корсаковский район, поселок Малое Теплое, 34	f	small
62518	70233	551	Орловская область, Корсаковский район, поселок Корсаково, Советская, 7	f	large
62684	70400	737	Орловская область, Корсаковский район, поселок Глотово, Школьная, 8	f	small
62651	70368	699	Орловская область, Корсаковский район, поселок Гагаринский Хутор, Центральная, 5	f	medium
62512	70227	545	Орловская область, Корсаковский район, поселок Большие Озерки, 23/2	f	small
62327	70048	346	Орловская область, Колпнянский район, поселок Ярище	f	medium
62314	70034	332	Орловская область, Колпнянский район, поселок Яковка	f	small
80893	55362	46	Москва, улица Бахрушина, 24с1	f	large
62324	70044	343	Орловская область, Колпнянский район, поселок Хутор Лимовое	f	small
62329	70050	348	Орловская область, Колпнянский район, поселок Фошня	t	small
62325	70045	344	Орловская область, Колпнянский район, поселок Ушаково	f	small
62346	70065	367	Орловская область, Колпнянский район, поселок Ульяновка, здание администрации Шаховского сельского поселения	f	medium
62323	70043	342	Орловская область, Колпнянский район, поселок Тимирязево	f	small
62186	69869	193	Россия, Псковская область, Порховский район, село Струково	f	small
62330	70051	349	Орловская область, Колпнянский район, поселок Остров	f	small
62321	70041	340	Орловская область, Колпнянский район, поселок Нетрубеж	t	small
62298	70018	313	Орловская область, Колпнянский район, поселок Моховое, Первомайская, 6	f	large
62319	70039	338	Орловская область, Колпнянский район, поселок Мисайлово	f	small
62326	70047	345	Орловская область, Колпнянский район, поселок Маркино	f	small
62320	70040	339	Орловская область, Колпнянский район, поселок Крутое	f	medium
62318	70038	337	Орловская область, Колпнянский район, поселок Красное	f	small
62310	70030	327	Орловская область, Колпнянский район, поселок Колпны, Терешковой, 2	f	large
62306	70026	323	Орловская область, Колпнянский район, поселок Колпны, Советская улица, 11	f	medium
62305	70025	322	Орловская область, Колпнянский район, поселок Колпны, Пионерская, 2	f	large
62307	70027	324	Орловская область, Колпнянский район, поселок Колпны, Комсомольская улица, 3	f	large
112576	70029	326	Орловская область, Колпнянский район, поселок Колпны, Карла Маркса, 32	f	\N
62308	70028	325	Орловская область, Колпнянский район, поселок Колпны, Железнодорожная, 5	f	large
62317	70037	336	Орловская область, Колпнянский район, поселок Колпны, 1-й Октябрьский переулок, 6	f	medium
62316	70036	335	Орловская область, Колпнянский район, поселок Клевцово	f	medium
62315	70035	333	Орловская область, Колпнянский район, поселок Знаменское	f	small
62322	70042	341	Орловская область, Колпнянский район, поселок Дровосечное	f	small
62328	70049	347	Орловская область, Колпнянский район, поселок Городецкое	t	small
62312	70032	329	Орловская область, Колпнянский район, поселок Вороново	f	small
62587	70302	623	Орловская область, Колпнянский район, поселок Березовка, Лесная, 3	f	medium
62313	70033	330	Орловская область, Колпнянский район, поселок Белый Колодезь 1-й	f	medium
62311	70031	328	Орловская область, Колпнянский район, поселок Ахтырка	f	small
62426	70147	456	Орловская область, Колпнянский район, поселок Александровка, Здание Дома культуры	f	small
62637	70354	678	республика Башкортостан, поселок Рождественский	f	medium
62694	56885	748	Орловская область, Знаменский район, поселок Узкое, Садовая, 2а	f	small
62692	56379	746	Московская область, Сергиево-Посадский район, деревня Селихово	f	small
62713	70422	770	Орловская область, Знаменский район, поселок Прилепы, Здание Прилепской средней шкоолы	f	small
62693	56550	747	Орловская область, Знаменский район, поселок Мымрино, Школьная, 1а	f	small
62688	70404	741	Орловская область, Знаменский район, поселок Локно, 1-я Русская, 1А	f	small
62689	55925	742	Орловская область, Знаменский район, поселок Коптево, Центральная, 2	t	small
62687	70403	740	Орловская область, Знаменский район, поселок Знаменское, Совхозная, 3а	f	large
62685	70401	738	Орловская область, Знаменский район, поселок Ждимир, Никольская, 8	f	small
62175	69897	182	Ивановская область, Шуйский район, поселок Гнездилово	f	small
62178	69900	185	Орловская область, Знаменский район, поселок Вязовая	f	small
62686	70402	739	Орловская область, Знаменский район, поселок Ворошилово, Молодежная, 2	t	small
62652	70369	700	Орловская область, Залегощенский район, хут.Сеина, Лесная, 10	f	small
62569	70285	603	Московская область, Раменский район, деревня Становое	f	medium
62297	69999	312	Орловская область, Залегощенский район, поселок Слобода, Малая Выгонская, 14	f	small
62289	70009	303	Орловская область, Залегощенский район, поселок Сетуха, Паршина, 2	f	small
62299	70019	314	Орловская область, Залегощенский район, поселок Ржаное, Школьная, 5	f	small
62302	70022	318	Орловская область, Залегощенский район, поселок Ржавец, Школьная, 8	f	small
62303	70023	319	Орловская область, Залегощенский район, поселок Победное, Центральная, 1	f	small
62294	70014	309	Орловская область, Залегощенский район, поселок Ольховец, Молодежная, 5	f	small
62301	70021	317	Орловская область, Залегощенский район, поселок Ломовое, Почтовый переулок, 1	f	medium
62292	70012	306	Орловская область, Залегощенский район, поселок Красное, Центральная, 21	f	small
62291	70011	305	Орловская область, Залегощенский район, поселок Котлы, Советская, 14	f	small
62296	70016	311	Орловская область, Залегощенский район, поселок Казарь, Октябрьская, 7	f	medium
62304	70024	320	Орловская область, Залегощенский район, поселок Золотарево, Привокзальная, 9	f	medium
62286	70006	299	Орловская область, Залегощенский район, поселок Залегощь, М. Горького, 10	f	large
62283	70003	296	Орловская область, Залегощенский район, поселок Залегощь, Ленина, 17	f	medium
62285	70005	298	Орловская область, Залегощенский район, поселок Залегощь, Гагарина, 34	f	small
62284	70004	297	Орловская область, Залегощенский район, поселок Залегощь, М.Горького, 26	f	large
62293	70013	308	Орловская область, Залегощенский район, поселок Верхнее Скворчее, Центральная, 6	f	small
62295	70015	310	Орловская область, Залегощенский район, поселок Васильевка, Мира, 17	f	medium
62253	69972	265	Орловская область, Залегощенский район, поселок Бычки, Здание СДК	f	small
62290	70010	304	Орловская область, Залегощенский район, поселок Березовец, Школьная, 2	f	small
62288	70008	302	Орловская область, Залегощенский район, поселок Архангельское, Привокзальная, 3	f	small
62173	69895	180	Курская область, Железногорский район, поселок Козюлькина	f	small
62279	69998	292	Орловская область, Должанский район, поселок Урынок	f	small
62259	69978	271	Орловская область, Должанский район, поселок Тим	f	small
62264	69983	276	Орловская область, Должанский район, поселок Студеное	f	small
62268	69987	280	Орловская область, Должанский район, поселок Рогатик	f	small
62281	70001	294	Орловская область, Должанский район	f	small
62262	69981	274	Орловская область, Должанский район, поселок Никольское	f	medium
62267	69986	279	Орловская область, Должанский район, поселок Нижнее Ольшаное	f	small
62263	69982	275	Орловская область, Должанский район, поселок Кривцово-Плота	f	small
62270	69989	283	Орловская область, Должанский район, поселок Козьма-Демьяновское	t	small
62271	69990	284	Орловская область, Должанский район	f	small
62269	69988	282	Орловская область, Должанский район, поселок Знаменское	f	small
62260	69979	272	Орловская область, Должанский район	f	small
62490	70205	521	Орловская область, Должанский район, поселок Дубровка, здание Дубровской школы	f	small
62258	69977	270	Орловская область, Должанский район	f	small
62272	69991	285	Орловская область, Должанский район, поселок Долгое, Луговая	f	small
112575	69993	287	Орловская область, Должанский район, поселок Долгое, Ленина, 24	f	\N
62273	69992	286	Орловская область, Должанский район, поселок Долгое, Ленина	f	large
62277	69996	290	Орловская область, Должанский район	f	small
62282	70002	295	Орловская область, Должанский район, поселок Вышняя Замарайка 1-я	f	small
62266	69985	278	Орловская область, Должанский район	f	small
62278	69997	291	Орловская область, Должанский район, поселок Вышнее Долгое, помещение Вышне-Должанской основной общеобразовательной школы	f	small
62275	69994	288	Орловская область, Должанский район	f	small
62280	70000	293	Орловская область, Должанский район, поселок Быстра, помещение Быстринской основной общеобразовательной школы 	f	small
62265	69984	277	Орловская область, Должанский район, поселок Баранчик	f	small
62276	69995	289	Орловская область, Должанский район	f	small
62236	69955	248	Орловская область, Дмитровский район, пос.Занеруссовский, дом досуга	t	small
62251	69970	263	Орловская область, Дмитровский район, поселок Хальзево	t	small
62238	69957	250	Брянская область, Выгоничский район, поселок Упорой	f	small
62244	69963	256	Орловская область, Дмитровский район, поселок Труд, Долбенкинский СДК	f	small
62242	69961	254	Орловская область, Дмитровский район, поселок Сторожище	f	small
62240	69959	252	Орловская область, Дмитровский район, поселок Рублино	t	small
62255	69974	267	Орловская область, Дмитровский район, поселок Работьково, Административное здание	f	small
62209	69929	216	Новгородская область, Старорусский район, село Коньшино	f	small
62250	69969	262	Орловская область, Дмитровский район, поселок Плоское, Административное здание	t	small
62245	69964	257	Орловская область, Дмитровский район, поселок Малое Боброво	f	small
62247	69966	259	Архангельская область, Холмогорский район, село Лубянки	f	medium
62248	69967	260	Орловская область, Дмитровский район, поселок Крупышино	t	small
62254	69973	266	Орловская область, Дмитровский район, поселок Красное Знамя, Здание СДК	f	small
62252	69971	264	Орловская область, Дмитровский район, поселок Дружно	f	small
62246	69965	258	Орловская область, Дмитровский район, поселок Домаха	f	medium
62256	69975	268	Орловская область, Дмитровский район, Дмитровск-Орловский, Социалистическая, 63	f	large
62257	69976	269	Орловская область, Дмитровский район, Дмитровск-Орловский, Советская, 152 А	f	large
62237	69956	249	Орловская область, Дмитровский район, поселок Девятино	f	small
62241	69960	253	Курская область, Солнцевский район, поселок Горбуновка	f	small
62249	69968	261	Орловская область, Дмитровский район, поселок Брусовец	f	small
62239	69958	251	Тюменская область, Викуловский район, село Бородино	f	small
62235	69954	247	Калужская область, Сухиничский район, поселок Алешинка	f	small
62220	69940	232	Орловская область, Глазуновский район, поселок Техникумовский	f	small
62234	69953	246	Орловская область, Глазуновский район, поселок Тагинский	f	small
62233	69952	245	Орловская область, Глазуновский район, поселок Тагино	f	medium
62232	69951	244	Орловская область, Глазуновский район, поселок Степная	f	small
62231	69950	243	Орловская область, Глазуновский район, поселок Сеньково	f	small
62545	70262	579	Орловская область, Глазуновский район, поселок Сабурово, Здание школы	t	small
62228	69947	240	Орловская область, Глазуновский район, поселок Отрада, помещение Отрадинской сельской администрации	f	small
62227	69946	239	Россия	f	medium
62230	69949	242	Орловская область, Глазуновский район, поселок Никольское, помещение Очкинской основной школы	f	small
62225	69944	237	Россия	f	small
62223	69925	235	Орловская область, Глазуновский район, поселок Красная Слободка	f	small
62674	70390	723	Орловская область, Глазуновский район, поселок Ильинское, Школьная, 17	f	medium
62602	70316	639	Орловская область, Глазуновский район, поселок Ивановка, Школьная, 18	f	small
62224	69943	236	Орловская область, Глазуновский район, поселок Гремячево	f	small
62222	69942	234	Орловская область, Глазуновский район, поселок Гнилуша	f	small
62217	69937	229	Орловская область, Глазуновский район, поселок Глазуновка, Советская, 4	f	medium
62219	69939	231	Орловская область, Глазуновский район, поселок Глазуновка, Привокзальная, 4	f	medium
62735	70442	796	Орловская область, Глазуновский район, поселок Глазуновка, Ленина, 17	f	medium
62734	70441	795	Орловская область, Глазуновский район, поселок Глазуновка, Ленина, 67	f	medium
62218	69938	230	Орловская область, Глазуновский район, поселок Глазуновка, Ленина, 174	f	medium
62221	69941	233	республика Татарстан, Пестречинский район, село Богородское	f	small
62581	70296	617	Орловская область, Верховский район, поселок Юдинка, 4	f	small
62196	69915	203	Костромская область, Солигаличский район, поселок Туровка	f	small
62211	69931	218	Орловская область, Верховский район, поселок Теляжье	f	small
62199	69918	206	Орловская область, Верховский район, поселок Сухотиновка	t	small
62200	69919	207	Орловская область, Верховский район, Суровцев	f	medium
62206	69926	213	Орловская область, Верховский район, поселок Скорятино	f	small
62205	69924	212	Тульская область, Плавский район, поселок Скородное	f	small
62212	69932	219	Орловская область, Верховский район, поселок Русский Брод, Кооперативная, 41	f	medium
62213	69933	220	Орловская область, Верховский район, поселок Русский Брод, Гайтеровой, 40	f	large
62214	69934	221	Орловская область, Верховский район, поселок Прусынок, Центральная, 21А	f	small
62198	69917	205	Нижегородская область, Богородский район, село Песочное	f	small
62215	69935	222	Орловская область, Верховский район, поселок Пеньшино, Молодежная, 5	f	small
62243	69962	255	Орловская область, Верховский район, поселок Круглое, Административное здание	f	small
62203	69922	210	Орловская область, Верховский район, поселок Корсунь	f	small
62342	70063	361	Орловская область, Верховский район, поселок Ключики, Школьная, 4	f	medium
62202	69921	209	Оренбургская область, Акбулакский район, село Карповка	f	small
62201	69920	208	Орловская область, Верховский район, поселок Долгое, Славянская, 6	f	medium
62194	69913	201	Орловская область, Верховский район, поселок Верховье, Ленина, 2	f	large
62195	69914	202	Орловская область, Верховский район, поселок Верховье, Коминтерна, 29	f	large
62204	69923	211	Орловская область, Верховский район, поселок Верхняя Залегощь	f	small
62208	69928	215	Орловская область, Верховский район, поселок Большой Синковец	f	small
62348	70067	369	Орловская область, Болховский район, поселок Ямские Выселки, здание Лысовского сельского клуба	f	small
62171	69893	178	Орловская область, Болховский район, поселок Фатнево	f	medium
62187	31838	194	Орловская область, Болховский район, поселок Середичи	t	small
62180	69902	187	Орловская область, Болховский район, поселок Репнино	f	small
62170	69892	177	Орловская область, Болховский район, поселок Пальчикова	t	small
62184	69906	191	Орловская область, Болховский район, поселок Однолуки	f	small
62182	69904	189	Орловская область, Болховский район, поселок Новый Синец	f	small
62188	31907	195	Орловская область, Болховский район, поселок Кривчее	f	small
62425	70146	455	Орловская область, Болховский район, поселок Каменка, Здание Дома Культуры	f	small
62197	69916	204	Орловская область, Болховский район, поселок Каменка, здание Каменского сельского клуба	f	small
62177	69899	184	Орловская область, Болховский район, поселок Злынь	f	small
62174	69896	181	Иркутская область, Черемховский район, поселок Герасимова	t	small
62207	69927	214	Орловская область, Болховский район, поселок Васильевский, здание МОУ &quot;&quot;Васильевская основная общеобразовательная школа&quot;&quot;&quot;	f	small
62229	69948	241	Орловская область, Болховский район, поселок Васильевка, помещение Васильевского дома культуры	f	small
62172	69894	179	Вологодская область, Вологодский район, село Борилово	f	small
62176	69898	183	Орловская область, Болховский район, поселок Большая Чернь	f	small
62192	69911	199	Орловская область, Болховский район, Болхов, переулок Земляной, 9	f	large
62191	69910	198	Орловская область, Болховский район, Болхов, Ленина, 165	f	large
62189	69908	196	Орловская область, Болховский район, Болхов, Ленина, 22	f	large
62190	69909	197	Орловская область, Болховский район, Болхов, Василия Ермакова, 19	f	large
62300	70020	316	Орловская область, Болховский район, поселок Алешня, переулок Школьный, 7	f	medium
49899	57824	272	Московская область, Яхрома, Бусалова, 8, помещение красного уголка общежития	f	medium
50813	58557	1187	Московская область, Яковлево, Школьная, 33	t	medium
52993	60261	3370	Россия, Московская область, Юбилейный, Школьный проезд, 2	f	large
52990	60259	3367	Московская область, Юбилейный, Тихонравова, 24/1	f	large
52986	60257	3363	Московская область, Юбилейный, М.К.Тихонравова, 19	f	large
52991	60260	3368	Россия, Московская область, Юбилейный, Лесная улица, 22	f	large
52992	60260	3369	Россия, Московская область, Юбилейный, Лесная улица, 22	f	large
52995	60262	3372	Московская область, Юбилейный, Комитетская, 31	f	large
52994	60262	3371	Московская область, Юбилейный, Комитетская, 31	f	large
52987	60258	3364	Московская область, Юбилейный, АМ.К.Тихонравова, 19	f	large
52989	60183	3366	Московская область, Юбилейный, А.И.Соколова, 3	f	large
52988	60183	3365	Московская область, Юбилейный, А.И.Соколова, 3	f	large
51420	58967	1772	Московская область, Электроугли, Маяковского, 34, МОУ СОШ № 30 новое здание	f	large
51417	58967	1769	Московская область, Электроугли, Маяковского, 34, МОУ СОШ № 30 новое здание	f	large
52949	60234	3326	Россия, Московская область, Электросталь, улица Ялагина, 22а	f	large
52948	60234	3325	Россия, Московская область, Электросталь, улица Ялагина, 22а	f	large
52964	60242	3341	Россия, Московская область, Электросталь, улица Тевосяна, 23	f	large
52963	60242	3340	Россия, Московская область, Электросталь, улица Тевосяна, 23	f	large
52980	60254	3357	Россия, Московская область, Электросталь, улица Сталеваров, 19	f	large
52965	60243	3342	Россия, Московская область, Электросталь, улица Корешкова, 16	f	large
52979	60253	3356	Россия, Московская область, Электросталь, проспект Ленина, 2к4	f	large
52967	60245	3344	Россия, Московская область, Электросталь, проспект Ленина, 32а	f	large
111657	60247	3346	Московская область, Электросталь, проезд Чернышевского, 22	f	\N
52982	60235	3359	Московская область, Электросталь, Ялагина, 14	f	large
52951	60235	3328	Московская область, Электросталь, Ялагина, 14	f	large
52950	60235	3327	Московская область, Электросталь, Ялагина, 14	f	large
52947	60233	3324	Московская область, Электросталь, Южный проспект, 7	f	large
52946	60233	3323	Московская область, Электросталь, Южный проспект, 7	f	large
52945	60233	3322	Московская область, Электросталь, Южный проспект, 7	f	large
52966	60244	3343	Московская область, Электросталь, Советская улица, 3	f	large
52962	60241	3339	Московская область, Электросталь, Радио, 36	f	large
52978	60252	3355	Московская область, Электросталь, Пушкина, 23а	f	large
52977	60252	3354	Московская область, Электросталь, Пушкина, 23а	f	large
52983	60251	3360	Московская область, Электросталь, Пушкина, 30	f	large
52976	60251	3353	Московская область, Электросталь, Пушкина, 30	f	large
52975	60251	3352	Московская область, Электросталь, Пушкина, 30	f	large
52974	60250	3351	Московская область, Электросталь, Пушкина, 6	f	large
52943	60232	3320	Московская область, Электросталь, Победы, 12к3	f	large
52944	60232	3321	Московская область, Электросталь, Победы, 12к3	f	large
52970	60248	3347	Московская область, Электросталь, Первомайская, 7	f	large
52957	60238	3334	Московская область, Электросталь, Мира, 24В	f	large
52956	60238	3333	Московская область, Электросталь, Мира, 24В	f	large
52955	60238	3332	Московская область, Электросталь, Мира, 24В	f	large
52954	60238	3331	Московская область, Электросталь, Мира, 24В	f	large
111656	60246	3345	Московская область, Электросталь, Корешкова, 16	f	\N
52937	60227	3314	Московская область, Электросталь, Комсомольская, 4	f	large
52936	60227	3313	Московская область, Электросталь, Комсомольская, 4	f	large
52942	60231	3319	Московская область, Электросталь, Карла Маркса, 9	f	large
52941	60230	3318	Московская область, Электросталь, Карла Маркса, 23	f	large
52952	60236	3329	Московская область, Электросталь, Западная, 1а	f	large
52981	60229	3358	Московская область, Электросталь, Загонова, 16	f	large
52940	60229	3317	Московская область, Электросталь, Загонова, 16	f	large
52953	60237	3330	Московская область, Электросталь, Журавлева, 5	f	large
52961	60240	3338	Московская область, Электросталь, 1-я Поселковая, 20	f	large
52933	60225	3310	Московская область, Электрогорск, Советская улица, 36а	f	large
52929	60222	3306	Московская область, Электрогорск, Советская, 47	f	large
52932	60222	3309	Московская область, Электрогорск, Советская, 47	f	large
52928	60221	3305	Московская область, Электрогорск, Ленина, 34	f	large
52927	60221	3304	Московская область, Электрогорск, Ленина, 34	f	large
52931	60224	3308	Московская область, Электрогорск, Кржижановского, 13	f	large
52930	60223	3307	Московская область, Электрогорск, Горького, 5	f	large
52922	60206	3299	Московская область, Щербинка, Театральная, 1а	f	large
52924	60218	3301	Московская область, Щербинка, Новостроевская, 4	t	large
52925	60219	3302	Московская область, Щербинка, Молодежная, 1	t	large
52926	60220	3303	Московская область, Щербинка, Авиаторов, 9	t	large
52920	60215	3297	Московская область, Щербинка, 40 Лет Октября, 8	f	large
52919	60215	3296	Московская область, Щербинка, 40 Лет Октября, 8	f	large
52918	60215	3295	Московская область, Щербинка, 40 Лет Октября, 8	f	large
52917	60214	3294	Московская область, Щербинка, 40 Лет Октября, 5/1	f	large
52916	60214	3293	Московская область, Щербинка, 40 Лет Октября, 5/1	f	large
111652	60124	3189	Московская область, Щелково, проспект 60 лет Октября, 10	f	\N
52831	60141	3209	Московская область, Щелково, площадь Ленина, 5, ООО Агростройпроект	f	large
52838	60146	3216	Московская область, Щелково, Центральная, 23, Средняя школа №4	f	large
52836	60146	3214	Московская область, Щелково, Центральная, 23, Средняя школа №4	f	large
52823	60133	3201	Московская область, Щелково, Талсинская, 1, Дом Быта "Подмосковье"	f	large
52840	60149	3218	Московская область, Щелково, Советская, 3, городская библиотека №3	f	large
52835	60145	3213	Московская область, Щелково, Пушкина, 22, районный культурный комплекс	f	large
52826	60136	3204	Московская область, Щелково, Пролетарский проспект, 11, Клуб Заречный	f	large
52830	60140	3208	Московская область, Щелково, Парковая, 3б, Средняя школа №16	f	large
52845	60154	3223	Московская область, Щелково, Московская, 68 А, Жегаловская библиотека №14	f	large
52843	60152	3221	Московская область, Щелково, Краснознаменская, 4 А, Помещение ЖРЭУ-1	f	large
52824	60134	3202	Московская область, Щелково, Комсомольская, 8а, Средняя школа №2	f	large
52857	60165	3235	Московская область, Щелково, Институтская, 18, Средняя школа №14	f	large
52848	60157	3226	Московская область, Щелково, микрорайон Щелково-3, Институтская, 11, Средняя школа №11	f	large
52849	60158	3227	Московская область, Щелково, микрорайон Щелково-3, Гагарина, 17, Средняя школа №12	f	small
52844	60153	3222	Московская область, Щелково, 8 Марта, 11, ООО Эко-Солид	f	large
52841	60150	3219	Московская область, Щелково, 1-й Советский переулок, 32	f	large
52832	60142	3210	Московская область, Щелково, 1-й Советский переулок, 17, Политехнический колледж	f	large
52761	60076	3138	Московская область, Шатура, проспект Маршала Борзова, 13	f	large
52754	60070	3131	Московская область, Шатура, проспект Ильича, 25	f	large
52753	60069	3130	Московская область, Шатура, проспект Ильича, 24	f	large
52765	60080	3142	Московская область, Шатура, микрорайон Керва, Первомайская, 1	f	large
52763	60078	3140	Московская область, Шатура, Вокзальная, 76	f	medium
52703	60030	3080	Московская область, Чехов, Чехова, 27, Центр развития творчества	f	large
52700	60027	3077	Московская область, Чехов, Чехова, 10, Гимназия № 2	f	large
52704	60031	3081	Московская область, Чехов, Солнышевская, 2а, Лицей №4	f	large
111651	60038	3093	Московская область, Чехов, Полиграфистов, 11, здание лицея № 56	f	\N
52722	94661	3099	Московская область, Чехов, Гагарина, 112, помещение СОШ №9спортивный зал	f	large
52721	94661	3098	Московская область, Чехов, Гагарина, 112, помещение СОШ №9спортивный зал	f	large
52718	60039	3095	Московская область, Чехов, Гагарина, 86а, Средняя общеобразовательная школа №8	f	large
52717	60039	3094	Московская область, Чехов, Гагарина, 86а, Средняя общеобразовательная школа №8	f	large
52690	60017	3067	Московская область, Черноголовка, село Макарово, клуб села Макарово	t	small
52694	60021	3071	Россия, Московская область, Черноголовка, проспект Академика Семенова, 1	f	large
52693	60020	3070	Московская область, Черноголовка, проезд Строителей, 3, спортзал	f	large
52692	60019	3069	Московская область, Черноголовка, проезд Строителей, 3, фойе	f	large
52697	60024	3074	Московская область, Черноголовка, Школьный бульвар, 1	f	large
52698	60025	3075	Московская область, Черноголовка, Центральная, 1	f	large
52696	60023	3073	Россия, Московская область, Черноголовка, Институтский проспект, 8	f	large
52695	60022	3072	Россия, Московская область, Черноголовка, Институтский проспект, 7	f	large
52689	60016	3066	Московская область, Химки, Аэропорт Шереметьево, Терминал D	f	medium
52688	60015	3065	Московская область, Химки, Аэропорт ШереметьевоТерминал С	f	small
52672	60001	3049	Московская область, Химки, микрорайон Сходня, улица Чапаева, 11	f	large
52620	59960	2996	Московская область, Химки, улица Маяковского, 23а	f	large
52619	59960	2995	Московская область, Химки, улица Маяковского, 23а	f	large
52684	60011	3061	Россия, Московская область, Химки, микрорайон Фирсановка, улица Маяковского, 3	f	medium
52645	59979	3021	Московская область, Химки, улица Машенцева, 6	f	large
52676	60005	3053	Россия, Московская область, Химки, микрорайон Сходня, улица Горького, 7	f	large
52631	59968	3007	Московская область, Химки, улица Глинки, 9	f	large
52633	59970	3009	Московская область, Химки, проспект Мира, 22/7	f	large
52656	59988	3033	Россия, Московская область, Химки, проспект Мельникова, 2а	f	large
52655	59988	3032	Россия, Московская область, Химки, проспект Мельникова, 2а	f	large
52683	60010	3060	Московская область, Химки, микрорайон Планерная, мкр. Планерная	t	large
52668	59998	3045	Московская область, Химки, мкр. Новогорск, 15а, Помещение НОУ Школа современного образования	f	medium
52649	94657	3025	Россия, Московская область, Химки, Юбилейный проспект, 20	f	large
52650	59985	3027	Россия, Московская область, Химки, Юбилейный проспект, 59	f	large
52671	60000	3048	Московская область, Химки, микрорайон Сходня, Тюкова, 8	f	large
52670	60000	3047	Московская область, Химки, микрорайон Сходня, Тюкова, 8	f	large
52686	60013	3063	Московская область, Химки, садовое товарищество Октябрьский, Спортивная, 34	f	small
52669	94659	3046	Московская область, Химки, Соколовская, 11, кв. 2	f	large
52664	59994	3041	Московская область, Химки, Пожарского, 14	f	large
52677	60006	3054	Московская область, Химки, Первомайская, 33	f	large
52654	59987	3031	Московская область, Химки, Парковая, 10	f	large
52653	59987	3030	Московская область, Химки, Парковая, 10	f	large
52638	59973	3014	Московская область, Химки, Панфилова, 14	f	large
52675	60004	3052	Московская область, Химки, микрорайон Сходня, Октябрьская, 30	f	medium
52666	59996	3043	Московская область, Химки, Нахимова, 2	f	large
52618	59959	2994	Московская область, Химки, Московская, 38	f	large
52661	59992	3038	Московская область, Химки, Молодежный проезд, 4	t	large
52660	59992	3037	Московская область, Химки, Молодежный проезд, 4	f	large
52644	59978	3020	Московская область, Химки, Молодежная, 44	f	large
52643	59978	3019	Московская область, Химки, Молодежная, 44	f	large
52639	59974	3015	Московская область, Химки, Молодежная, 1	f	large
52659	59991	3036	Московская область, Химки, Марии Рубцовой, 4	f	large
52658	59991	3035	Московская область, Химки, Марии Рубцовой, 4	f	large
52632	59969	3008	Россия, Московская область, Химки, Ленинский проспект, 2	f	large
52627	59965	3003	Россия, Московская область, Химки, Ленинский проспект, 7	f	large
52621	59961	2997	Московская область, Химки, Ленинградская, 18а	f	large
52647	94655	3023	Московская область, Химки, Лавочкина, 12	f	large
52646	59980	3022	Московская область, Химки, Лавочкина, 12	f	large
52641	59975	3017	Московская область, Химки, Куркинское шоссе, 18	f	large
52640	59975	3016	Московская область, Химки, Куркинское шоссе, 18	f	large
52637	59972	3013	Московская область, Химки, район Куркино, Куркинское шоссе, 18а	f	large
52636	59972	3012	Московская область, Химки, район Куркино, Куркинское шоссе, 18а	f	large
52625	59964	3001	Московская область, Химки, Кирова, 11а	f	large
52687	94660	3064	Московская область, Химки, Квартал Свистуха, 11	f	medium
52665	59995	3042	Московская область, Химки, Зеленая улица, 22, здание гимназии	f	large
111647	59984	3026	Московская область, Химки, Горшина, 7	t	\N
52678	60007	3055	Московская область, Химки, Горная, 21	f	small
52626	59958	3002	Московская область, Химки, Ватутина, 2	f	large
52617	59958	2993	Московская область, Химки, Ватутина, 2	f	large
52630	59967	3006	Московская область, Химки, Бурденко, 5	f	large
52629	59967	3005	Московская область, Химки, Бурденко, 5	f	large
52662	59993	3039	Россия, Московская область, Химки, Библиотечная улица, 7	f	large
52663	59993	3040	Россия, Московская область, Химки, Библиотечная улица, 7	f	large
52667	94658	3044	Московская область, Химки, Библиотечная, 13	f	large
52628	59966	3004	Московская область, Химки, Березовая Аллея, 1	f	large
52635	59971	3011	Московская область, Химки, Бабакина, 1а	f	large
52634	59971	3010	Московская область, Химки, Бабакина, 1а	f	large
52648	94656	3024	Московская область, Химки, 9 Мая, 3а	f	large
111648	59990	3034	Московская область, Химки, 9 Мая, 19	f	\N
52674	60003	3051	Россия, Московская область, Химки, микрорайон Сходня, 2-й Чапаевский переулок, 3	f	large
111649	60002	3050	Россия, Московская область, Химки, микрорайон Сходня, 2-й Чапаевский переулок, 3	f	\N
52614	59955	2990	Московская область, Фрязино, проспект Мира, 18б	f	large
52613	59955	2989	Московская область, Фрязино, проспект Мира, 18б	f	large
52612	59955	2988	Московская область, Фрязино, проспект Мира, 18б	f	large
52605	59950	2981	Московская область, Фрязино, проспект Мира, 23	f	large
52604	59949	2980	Московская область, Фрязино, Школьная, 10	f	large
52603	59949	2979	Московская область, Фрязино, Школьная, 10	f	large
134578	94437	1354	Московская область, Фрязино, Попова, 39, Петростат	f	\N
52615	59956	2991	Московская область, Фрязино, Полевая, 29	f	large
52611	59954	2987	Московская область, Фрязино, Полевая, 3	f	large
52599	59945	2975	Московская область, Фрязино, Нахимова, 23а	f	large
52607	59951	2983	Московская область, Фрязино, Луговая, 31	f	large
52606	59951	2982	Московская область, Фрязино, Луговая, 31	f	large
52602	59948	2978	Московская область, Фрязино, Комсомольская, 17	f	large
52601	59947	2977	Московская область, Фрязино, Комсомольская, 19	f	large
52183	59589	2556	Московская область, поселок городского типа Тучково, Новая, 15	f	large
52591	94652	2966	Московская область, Троицк, микрорайон В, 26	f	large
52594	59940	2970	Московская область, Троицк, Школьная, 10	f	large
52593	59939	2969	Московская область, Троицк, Школьная, 10а	f	large
52596	59942	2972	Россия, Московская область, Троицк, Сиреневый бульвар, 1	f	large
52595	59941	2971	Россия, Московская область, Троицк, Сиреневый бульвар, 2	f	large
52592	94654	2968	Московская область, Троицк, Площадь Верещагина, 1, здание торгового центра	f	large
52586	94653	2967	Московская область, Троицк, Октябрьский проспект, 16Б	f	large
52598	59944	2974	Московская область, Троицк, Октябрьский проспект, 9	f	large
52597	59943	2973	Московская область, Троицк, Октябрьский проспект, 6	f	large
52589	94651	2964	Московская область, Троицк, Микрорайон В, 6А	f	large
52588	94650	2963	Московская область, Троицк, Микрорайон В, 53	f	large
52587	59934	2962	Московская область, Троицк, микрорайон В, Микрорайон В, 53	f	large
52585	59933	2961	Московская область, Троицк, Комсомольский проезд, 3	f	large
52561	59907	2936	Московская область, Талдом, Шишунова, 5, МУ Дом Культуры Колос	f	large
111645	59906	2935	Московская область, Талдом, Шишунова, 5, МУ Дом культуры Колос кабинет хариографии	f	\N
52560	59905	2934	Московская область, Талдом, Победы, 10, МУ Районный Дом культуры	f	large
52559	59904	2933	Московская область, Талдом, Орлова, 5, МОУ ТСОШ №1	f	medium
52520	94647	2894	Московская область, Ступино, Чайковского, 54, лицей №1	f	large
52530	59874	2904	Московская область, Ступино, Чайковского, 3/10	f	large
52521	59851	2895	Московская область, Ступино, Чайковского, 54	f	large
52519	59865	2893	Московская область, Ступино, Тургенева, 14/19	f	large
52509	59857	2883	Московская область, Ступино, Пушкина, 101	f	large
52510	59858	2884	Московская область, Ступино, Куйбышева, 63	f	large
52505	59853	2879	Московская область, Ступино, Колхозная , 173	f	large
52506	59854	2880	Московская область, Ступино, Есенина, 2	f	large
52518	59864	2892	Московская область, Ступино, Горького, 21	f	large
52516	59862	2890	Московская область, Ступино, Горького, 18	f	large
52507	59855	2881	Московская область, Ступино, Городищенская, 8	f	large
52512	59859	2886	Московская область, Ступино,  Тимирязева, 58	f	large
52511	59859	2885	Московская область, Ступино,  Тимирязева, 58	f	large
51431	58977	1783	Московская область, Старая Купавна, Большая Московская, 3а	f	large
51426	58974	1778	Московская область, Старая Купавна, Большая Московская, 116, ДК "Акрихин"	f	large
51425	58974	1777	Московская область, Старая Купавна, Большая Московская, 116, ДК "Акрихин"	f	large
52023	59507	2442	Московская область, поселок Спартак	f	large
52469	59825	2845	Московская область, Солнечногорск, Обуховская, 2/96	f	large
52452	59811	2828	Московская область, Солнечногорск, Вертлинская, 17	f	large
52457	59815	2833	Московская область, Солнечногорск, Банковская, 6а	f	large
50846	94555	1220	Московская область, Серпухов, улица Чехова, 5 , Выставочный зал Управления Культуры	f	medium
52357	59734	2733	Россия, Московская область, Серпухов, улица Чехова, 56	f	large
52377	59748	2753	Россия, Московская область, Серпухов, улица Ворошилова, 148/2	f	large
52371	59736	2735	Россия, Московская область, Серпухов, проезд Мишина, 12б	f	large
52359	59736	2747	Россия, Московская область, Серпухов, проезд Мишина, 12б	f	large
52366	59741	2742	Московская область, Серпухов, Юбилейная, 14	f	large
52365	59741	2741	Московская область, Серпухов, Юбилейная, 14	f	large
52347	59725	2723	Московская область, Серпухов, Чернышевского, 42а	f	large
52346	59725	2722	Московская область, Серпухов, Чернышевского, 42а	f	large
52356	59733	2732	Московская область, Серпухов, Центральная улица, 79А	f	large
52354	59731	2730	Московская область, Серпухов, Центральная улица, 97А	f	large
52383	59752	2759	Московская область, Серпухов, Центральная, 154	f	large
52362	59739	2738	Московская область, Серпухов, Химиков, 6	f	large
52385	59747	2761	Московская область, Серпухов, Фирсова, 9	f	large
52376	59747	2752	Московская область, Серпухов, Фирсова, 9	f	large
52387	59744	2763	Московская область, Серпухов, Тяговая , 8	f	large
52386	59744	2762	Московская область, Серпухов, Тяговая , 8	f	large
52370	59744	2746	Московская область, Серпухов, Тяговая , 8	f	large
52389	59756	2765	Московская область, Серпухов, Текстильная, 2	f	large
52375	59743	2751	Московская область, Серпухов, Советская улица, 90	f	large
52374	59743	2750	Московская область, Серпухов, Советская улица, 90	f	large
52369	59743	2745	Московская область, Серпухов, Советская улица, 90	f	large
52379	59749	2755	Московская область, Серпухов, Советская, 83	f	large
52378	59749	2754	Московская область, Серпухов, Советская, 83	f	large
52373	59746	2749	Московская область, Серпухов, Советская, 45	f	large
52372	59746	2748	Московская область, Серпухов, Советская, 45	f	large
52358	59735	2734	Московская область, Серпухов, Свердлова, 33/4	f	large
52364	59740	2740	Московская область, Серпухов, Пушкина, 40а	f	large
52363	59740	2739	Московская область, Серпухов, Пушкина, 40а	f	large
52348	59726	2724	Московская область, Серпухов, Пролетарская, 78	f	large
52384	59753	2760	Московская область, Серпухов, Осенняя, 7д	f	large
52353	59730	2729	Московская область, Серпухов, Новослободская , 2	f	large
52367	59737	2743	Московская область, Серпухов, Московское шоссе, 64	f	large
52360	59737	2736	Московская область, Серпухов, Московское шоссе, 64	f	large
52345	59723	2721	Московская область, Серпухов, Красный Текстильщик, 6а	f	large
52342	59723	2718	Московская область, Серпухов, Красный Текстильщик, 6а	f	large
52351	59728	2727	Московская область, Серпухов, Космонавтов, 17	f	large
52350	59728	2726	Московская область, Серпухов, Космонавтов, 17	f	large
52349	59727	2725	Московская область, Серпухов, Клубный переулок, 1/2	f	large
52388	59755	2764	Московская область, Серпухов, Дзержинского, 2а	f	large
52382	59732	2758	Московская область, Серпухов, Джона Рида, 6	f	large
52355	59732	2731	Московская область, Серпухов, Джона Рида, 6	f	large
52368	59742	2744	Московская область, Серпухов, Горького, 32	f	large
52391	59757	2767	Московская область, Серпухов, Войкова, 11	f	large
52392	59757	2768	Московская область, Серпухов, Войкова, 11	f	large
52390	59757	2766	Московская область, Серпухов, Войкова, 11	f	large
52381	94629	2757	Московская область, Серпухов, Водонапорная, 6, здание школы №6	f	large
52352	59729	2728	Московская область, Серпухов, Большой Ударный переулок, 1	f	large
52393	59729	2769	Московская область, Серпухов, Большой Ударный переулок, 1	f	large
52344	59724	2720	Московская область, Серпухов, 1905 года, 15	f	large
52343	59724	2719	Московская область, Серпухов, 1905 года, 15	f	large
52361	59738	2737	Московская область, Серпухов, 1-я Московская, 42/8	f	large
52231	59633	2604	Московская область, Сергиев Посад, проспект Красной Армии, 212а	f	large
52206	59613	2579	Московская область, Сергиев Посад, Хотьковский проезд, 18а	f	large
52247	59647	2620	Московская область, Сергиев Посад, Птицеградская, 2	f	large
52246	59646	2619	Московская область, Сергиев Посад, городок Сергиев Посад-7, Молодежная, 4	f	large
52245	59646	2618	Московская область, Сергиев Посад, городок Сергиев Посад-7, Молодежная, 4	f	large
52209	59616	2582	Московская область, Сергиев Посад, Куликова, 16	f	large
52208	59616	2581	Московская область, Сергиев Посад, Куликова, 16	f	large
52210	59617	2583	Московская область, Сергиев Посад, Кирова, 8	f	large
52223	59625	2596	Московская область, Сергиев Посад, Дружбы, 5а	f	large
52222	59625	2595	Московская область, Сергиев Посад, Дружбы, 5а	f	large
52221	59624	2594	Московская область, Сергиев Посад, Дружбы, 5	f	large
52220	59624	2593	Московская область, Сергиев Посад, Дружбы, 5	f	large
52219	59624	2592	Московская область, Сергиев Посад, Дружбы, 5	f	large
52238	59640	2611	Московская область, Сергиев Посад, Валовая, 5	f	large
52173	59578	2546	Московская область, Руза, Ульяновская, 22	f	large
52169	59574	2542	Московская область, Руза, Волоколамское шоссе, 2	f	large
52163	59569	2536	Московская область, Рошаль, улица Энгельса, 4/2	f	large
52162	59568	2535	Московская область, Рошаль, Энгельса, 12	f	large
52160	59566	2533	Московская область, Рошаль, Фридриха Энгельса, 28а	f	large
52164	59570	2537	Московская область, Рошаль, Советская улица, 36	f	large
52167	59572	2540	Московская область, Рошаль, Свердлова, 48	f	large
52161	59567	2534	Московская область, Рошаль, Октябрьской Революции, 24	f	large
52166	59571	2539	Московская область, Рошаль, Карла Маркса, 1	f	large
52165	59571	2538	Московская область, Рошаль, Карла Маркса, 1	f	large
52147	59560	2520	Московская область, Реутов, улица Победы, 4	f	large
52146	59560	2519	Московская область, Реутов, улица Победы, 4	f	large
52142	59560	2515	Московская область, Реутов, улица Победы, 4	f	large
52140	59560	2513	Московская область, Реутов, улица Победы, 4	f	large
52123	59555	2496	Московская область, городской округ Реутов, Котовского, 13	f	large
52122	59555	2495	Московская область, городской округ Реутов, Котовского, 13	f	large
52125	59556	2498	Московская область, Реутов, Южная, 17	f	large
52124	59556	2497	Московская область, Реутов, Южная, 17	f	large
52130	59503	2503	Московская область, Реутов, Южная, 8	f	large
52129	59503	2502	Московская область, Реутов, Южная, 8	f	large
52127	59503	2500	Московская область, Реутов, Южная, 8	f	large
52126	59503	2499	Московская область, Реутов, Южная, 8	f	large
52134	59557	2507	Московская область, Реутов, Юбилейный проспект, 15	f	large
52133	59557	2506	Московская область, Реутов, Юбилейный проспект, 15	f	large
52132	59557	2505	Московская область, Реутов, Юбилейный проспект, 15	f	large
52131	59557	2504	Московская область, Реутов, Юбилейный проспект, 15	f	large
52128	59557	2501	Московская область, Реутов, Юбилейный проспект, 15	f	large
52121	59554	2494	Московская область, Реутов, Юбилейный проспект, 38	f	large
52120	59554	2493	Московская область, Реутов, Юбилейный проспект, 38	f	large
52159	59564	2532	Московская область, Реутов, Советская, 27	f	large
52158	59564	2531	Московская область, Реутов, Советская, 27	f	large
52153	59564	2526	Московская область, Реутов, Советская, 27	f	large
52152	59562	2525	Московская область, Реутов, Советская, 6а	f	large
52150	59562	2523	Московская область, Реутов, Советская, 6а	f	large
52149	59562	2522	Московская область, Реутов, Советская, 6а	f	large
52148	59562	2521	Московская область, Реутов, Советская, 6а	f	large
52154	59565	2527	Московская область, Реутов, Победы, 32	f	large
52151	59563	2524	Московская область, Реутов, Победы, 2	f	large
52141	59559	2514	Московская область, Реутов, Новая, 16	f	large
52138	59559	2511	Московская область, Реутов, Новая, 16	f	large
52145	59561	2518	Московская область, Реутов, Лесная, 12	f	large
52144	59561	2517	Московская область, Реутов, Лесная, 12	f	large
52143	59558	2516	Московская область, Реутов, Комсомольская улица, 15	f	large
52139	59558	2512	Московская область, Реутов, Комсомольская улица, 15	f	large
52135	59558	2508	Московская область, Реутов, Комсомольская улица, 15	f	large
52102	59471	2399	Московская область, Раменское, Михалевича, 29	f	large
52101	59471	2398	Московская область, Раменское, Михалевича, 29	f	large
52111	59478	2408	Московская область, Раменское, Красноармейская, 27	f	large
52089	59463	2386	Московская область, Раменское, Космонавтов, 19	f	large
52087	59463	2384	Московская область, Раменское, Космонавтов, 19	f	large
52086	59463	2383	Московская область, Раменское, Космонавтов, 19	f	large
52088	59463	2385	Московская область, Раменское, Космонавтов, 19	f	medium
52085	59462	2382	Московская область, Раменское, Космонавтов, 1	f	large
52084	59462	2381	Московская область, Раменское, Космонавтов, 1	f	large
52083	59462	2380	Московская область, Раменское, Космонавтов, 1	f	large
52082	59462	2379	Московская область, Раменское, Космонавтов, 1	f	large
52105	59475	2402	Московская область, Раменское, Карла Маркса, 1	f	large
52117	59472	2414	Московская область, Раменское, Гурьева, 1	f	large
52116	59472	2411	Московская область, Раменское, Гурьева, 1	f	large
52114	59472	2413	Московская область, Раменское, Гурьева, 1	f	large
52098	59469	2395	Московская область, Раменское, 100-й Свирской Дивизии, 11	f	large
51996	59459	2375	Московская область, Пущино, микрорайон АБ, 4А	f	large
51999	59458	2372	Московская область, Пущино, 23а	f	large
51998	59457	2371	Московская область, Пущино, микрорайон В, 6А	f	large
52002	59409	2374	Московская область, Пущино, микрорайон Д, 2А	f	large
52000	59383	2373	Россия, Московская область, Пущино, микрорайон АБ, проспект Науки, 2	f	large
51997	59456	2370	Московская область, Пущино, микрорайон В, бульвар Иерусалимского, 32б	f	large
51944	59402	2318	Московская область, Пушкино, мкр. Дзержинец, 10а	f	large
51943	59402	2317	Московская область, Пушкино, мкр. Дзержинец, 10а	f	large
51942	59402	2316	Московская область, Пушкино, мкр. Дзержинец, 10а	f	large
51987	59447	2361	Московская область, Пушкино, микрорайон Новая Деревня, Центральная, 5	f	medium
51925	59391	2299	Московская область, Пушкино, Тургенева, 3	f	large
51940	59400	2314	Московская область, Пушкино, микрорайон Серебрянка, Серебрянка, СОШ №6	f	large
51835	59315	2209	Московская область, Подольск, Народная, 4	f	large
51941	59400	2315	Московская область, Пушкино, микрорайон Серебрянка, Серебрянка, СОШ №6	f	large
51939	59400	2313	Московская область, Пушкино, микрорайон Серебрянка, Серебрянка, СОШ №6	f	large
51955	59414	2329	Московская область, Пушкино, Кольцовская, 2	f	medium
51945	59403	2319	Московская область, Пушкино, Институтская, 15	f	large
51930	59394	2304	Московская область, Пушкино, Горького, 20	f	large
51948	59406	2322	Московская область, Пушкино, Вокзальная, 14	f	large
51905	59376	2279	Московская область, Протвино, Школьная, 12	f	large
51914	59381	2288	Россия, Московская область, Протвино, Северный проезд, 9	f	large
51913	59381	2287	Россия, Московская область, Протвино, Северный проезд, 9	f	large
51912	59380	2286	Россия, Московская область, Протвино, Лесной бульвар, 1	f	large
51911	59380	2285	Россия, Московская область, Протвино, Лесной бульвар, 1	f	large
51907	59377	2281	Московская область, Протвино, Ленина, 8	f	large
51906	59377	2280	Московская область, Протвино, Ленина, 8	f	large
51908	59378	2282	Московская область, Протвино, Дружбы, 20	f	large
51916	59382	2290	Московская область, Протвино, Архитектора Корина, 6	f	large
51915	59382	2289	Московская область, Протвино, Архитектора Корина, 6	f	large
51806	59297	2180	Россия, Московская область, Подольск, улица Ульяновых, 27	f	large
51801	59292	2175	Россия, Московская область, Подольск, улица Павлика Морозова, 30	f	medium
51837	59316	2211	Московская область, Подольск, улица Гайдара, 10	f	large
51838	59316	2212	Московская область, Подольск, улица Гайдара, 10	f	large
51789	59266	2163	Россия, Московская область, Подольск, проспект Юных Ленинцев, 90	f	large
51798	59289	2172	Россия, Московская область, Подольск, проезд Авиаторов, 4	f	medium
51825	59307	2199	Московская область, Подольск, Юбилейная, 19	f	large
51823	59307	2197	Московская область, Подольск, Юбилейная, 19	f	large
51830	59311	2204	Московская область, Подольск, Юбилейная, 5	f	large
51822	59306	2196	Московская область, Подольск, Юбилейная, 19	f	large
51849	59326	2223	Московская область, Подольск, Халатова, 3	f	medium
51859	59333	2233	Московская область, Подольск, Филиппова, 6б	f	large
51857	59333	2231	Московская область, Подольск, Филиппова, 6б	f	large
51805	59296	2179	Россия, Московская область, Подольск, Февральская улица, 65	f	large
51813	59301	2187	Московская область, Подольск, Февральская, 30	f	large
51812	59301	2186	Московская область, Подольск, Февральская, 30	f	large
51810	59299	2184	Московская область, Подольск, Ульяновых, 1	f	large
51865	59337	2239	Московская область, Подольск, Сосновая , 10	f	large
51864	59337	2238	Московская область, Подольск, Сосновая , 10	f	large
51853	59329	2227	Московская область, Подольск, Северная, 9	f	large
51839	59317	2213	Московская область, Подольск, Свердлова, 48а	f	large
51814	59302	2188	Россия, Московская область, Подольск, Революционный проспект, 25/12	f	large
51792	59287	2166	Московская область, Подольск, Профсоюзная, 6	f	large
51794	59287	2168	Московская область, Подольск, Профсоюзная, 6	f	large
51793	59287	2167	Московская область, Подольск, Профсоюзная, 6	f	large
51861	59334	2235	Московская область, Подольск, Правды, 21	f	large
51860	59334	2234	Московская область, Подольск, Правды, 21	f	large
51854	59330	2228	Московская область, Подольск, Правды, 4а	f	large
51842	59320	2216	Московская область, Подольск, Победы, 2	f	large
51797	59288	2171	Московская область, Подольск, Плещеевская, 48а	f	medium
51796	59288	2170	Московская область, Подольск, Плещеевская, 48а	f	large
51820	59305	2194	Россия, Московская область, Подольск, Пахринский проезд, 8	f	large
51824	59305	2198	Россия, Московская область, Подольск, Пахринский проезд, 8	f	large
51821	59305	2195	Россия, Московская область, Подольск, Пахринский проезд, 8	f	large
51819	59305	2193	Россия, Московская область, Подольск, Пахринский проезд, 8	f	large
51818	59304	2192	Московская область, Подольск, Парковая , 18	f	large
51817	59304	2191	Московская область, Подольск, Парковая , 18	f	large
51800	59291	2174	Московская область, Подольск, Павлика Морозова, 69	f	large
51829	59310	2203	Московская область, Подольск, Октябрьский проспект, 7	f	large
51828	59309	2202	Московская область, Подольск, Октябрьский проспект, 7	f	large
51827	59309	2201	Московская область, Подольск, Октябрьский проспект, 7	f	large
51836	59315	2210	Московская область, Подольск, Народная, 4	f	large
51809	59298	2183	Россия, Московская область, Подольск, Мраморная улица, 5	f	large
51808	59298	2182	Россия, Московская область, Подольск, Мраморная улица, 5	f	large
51807	59298	2181	Россия, Московская область, Подольск, Мраморная улица, 5	f	large
51856	59332	2230	Московская область, Подольск, Молодежная, 9	f	large
51852	59328	2226	Московская область, Подольск, Мира, 4	f	large
51816	59303	2190	Московская область, Подольск, Маштакова, 7	f	large
51815	59303	2189	Московская область, Подольск, Маштакова, 7	f	large
51858	59331	2232	Московская область, Подольск, Машиностроителей, 9	f	large
51855	59331	2229	Московская область, Подольск, Машиностроителей, 9	f	large
51843	59321	2217	Московская область, Подольск, Литейная, 27	f	large
51848	59325	2222	Московская область, Подольск, Лапшенкова, 5	f	large
51811	59300	2185	Московская область, Подольск, Красная, 20	f	large
50636	58449	1008	Россия, Московская область, Подольск, Кооперативный проезд, 3	f	large
50640	58449	1012	Россия, Московская область, Подольск, Кооперативный проезд, 3	f	large
50639	58449	1011	Россия, Московская область, Подольск, Кооперативный проезд, 3	f	large
51803	59294	2177	Московская область, Подольск, Комсомольская, 84	f	large
51841	59319	2215	Московская область, Подольск, Высотная, 17	f	large
51840	59318	2214	Московская область, Подольск, Высотная, 5/12	f	large
51847	59324	2221	Московская область, Подольск, Володи Дубинина, 3	f	large
51844	59322	2218	Московская область, Подольск, Володи Дубинина, 6/29	f	large
51846	59323	2220	Московская область, Подольск, Ватутина, 34	f	large
51845	59323	2219	Московская область, Подольск, Ватутина, 34	f	large
51795	59286	2169	Московская область, Подольск, Быковская, 9	f	large
51791	59286	2165	Московская область, Подольск, Быковская, 9	f	large
111633	59336	2237	Московская область, Подольск, Бородинская, 20, Средняя общеобразовательная школа № 13	f	\N
51862	59335	2236	Московская область, Подольск, Бородинская, 20	f	large
51832	59312	2206	Московская область, Подольск, Большая Серпуховская улица, 4	f	large
51831	59312	2205	Московская область, Подольск, Большая Серпуховская улица, 4	f	large
51834	59314	2208	Московская область, Подольск, Большая Серпуховская , 20/1	f	large
51804	59295	2178	Московская область, Подольск, Большая Зеленовская , 54/82	f	large
51802	59293	2176	Московская область, Подольск, Большая Зеленовская, 50	f	large
51850	59327	2224	Московская область, Подольск, Батырева, 2/7	f	large
51851	59327	2225	Московская область, Подольск, Батырева, 2/7	f	large
52267	59660	2636	Московская область, Пересвет, Пионерская, 1	f	large
52262	59660	2635	Московская область, Пересвет, Пионерская, 1	f	large
52266	59662	2639	Московская область, Пересвет, Мира, 13	f	large
52264	59662	2638	Московская область, Пересвет, Мира, 13	f	large
51754	59263	2128	Московская область, Павловский Посад, Школьная, 14	f	large
51760	59267	2134	Московская область, Павловский Посад, Тимирязева, 13	f	large
51759	59267	2133	Московская область, Павловский Посад, Тимирязева, 13	f	large
51764	59267	2138	Московская область, Павловский Посад, Тимирязева, 13	f	large
51747	59256	2121	Московская область, Павловский Посад, Кирова, 87	f	large
52652	59986	3029	Московская область, Павловский Посад, Дружбы, 3	f	large
52651	59986	3028	Московская область, Павловский Посад, Дружбы, 3	f	large
51750	59260	2124	Московская область, Павловский Посад, Выставкина, 1	f	large
51770	59270	2144	Московская область, Павловский Посад, Большая Покровская, 37	f	large
51769	59270	2143	Московская область, Павловский Посад, Большая Покровская, 37	f	large
51768	59270	2142	Московская область, Павловский Посад, Большая Покровская, 37	f	large
51767	59270	2141	Московская область, Павловский Посад, Большая Покровская, 37	f	large
52895	60192	3272	Московская область, деревня Осеево, Центральная, 22, Сельский ДК деревни Осеево	t	medium
51615	59143	1989	Московская область, Орехово-Зуево, улица Володарского, 6	f	large
51624	59143	1998	Московская область, Орехово-Зуево, улица Володарского, 6	f	large
51623	59143	1997	Московская область, Орехово-Зуево, улица Володарского, 6	f	large
51652	59171	2026	Россия, Московская область, Орехово-Зуево, улица Бугрова, 5	f	large
51625	59146	1999	Россия, Московская область, Орехово-Зуево, улица Бирюкова, 25	f	large
51621	59146	1995	Россия, Московская область, Орехово-Зуево, улица Бирюкова, 25	f	large
51618	59146	1992	Россия, Московская область, Орехово-Зуево, улица Бирюкова, 25	f	large
51640	59159	2014	Россия, Московская область, Орехово-Зуево, проезд Беляцкого, 17	f	large
51638	59159	2012	Россия, Московская область, Орехово-Зуево, проезд Беляцкого, 17	f	large
51635	59159	2009	Россия, Московская область, Орехово-Зуево, проезд Беляцкого, 17	f	large
51632	59156	2006	Московская область, Орехово-Зуево, площадь Пушкина, 6	f	large
51649	59168	2023	Московская область, Орехово-Зуево, Торфобрикетная, 18	f	medium
51626	59149	2000	Московская область, Орехово-Зуево, Пушкина, 3а	f	large
51612	59140	1986	Московская область, Орехово-Зуево, Правды, 7	f	large
51611	59140	1985	Московская область, Орехово-Зуево, Правды, 7	f	large
51639	59161	2013	Московская область, Орехово-Зуево, Парковская, 57	f	large
51642	59162	2016	Московская область, Орехово-Зуево, Набережная , 3	f	large
51641	59162	2015	Московская область, Орехово-Зуево, Набережная , 3	f	large
51647	59166	2021	Московская область, Орехово-Зуево, Мира, 12	f	large
51658	59175	2032	Московская область, Орехово-Зуево, Мадонская, 4	f	large
51657	59175	2031	Московская область, Орехово-Зуево, Мадонская, 4	f	large
51637	59160	2011	Московская область, Орехово-Зуево, Лопатина, 17	f	large
51636	59160	2010	Московская область, Орехово-Зуево, Лопатина, 17	f	large
51661	59177	2035	Московская область, Орехово-Зуево, Ленина, 93	f	large
51659	59176	2033	Московская область, Орехово-Зуево, Ленина, 55	f	large
51650	59169	2024	Московская область, Орехово-Зуево, Красина, 1	f	large
51628	59151	2002	Московская область, Орехово-Зуево, Козлова, 5	f	large
51627	59150	2001	Московская область, Орехово-Зуево, Козлова, 5	f	large
51646	59165	2020	Московская область, Орехово-Зуево, Клязьменский проезд, 8	f	large
51622	59147	1996	Московская область, Орехово-Зуево, Иванова, 11	f	large
51619	59147	1993	Московская область, Орехово-Зуево, Иванова, 11	f	large
51617	59145	1991	Московская область, Орехово-Зуево, Иванова, 4	f	large
51653	59172	2027	Московская область, Орехово-Зуево, Зеленая, 26	f	large
51656	59174	2030	Московская область, Орехово-Зуево, Егорьевская, 2	f	large
51655	59173	2029	Московская область, Орехово-Зуево, Горького, 11	f	large
51634	59158	2008	Московская область, Орехово-Зуево, Галочкина, 24	f	large
51614	59142	1988	Московская область, Орехово-Зуево, Гагарина, 8	f	large
51613	59141	1987	Московская область, Орехово-Зуево, Гагарина, 21	f	large
51648	59167	2022	Московская область, Орехово-Зуево, Волкова, 29	f	large
51654	59170	2028	Московская область, Орехово-Зуево, Бугрова, 7	f	large
51651	59170	2025	Московская область, Орехово-Зуево, Бугрова, 7	f	large
51609	59138	1983	Московская область, Орехово-Зуево, Бондаренко, 15	f	large
51608	59137	1982	Московская область, Орехово-Зуево, Бондаренко, 15	f	large
51620	59148	1994	Россия, Московская область, Орехово-Зуево, 4-й проезд Козлова, 1	f	large
51596	59126	1970	Московская область, Озеры, площадь Советская, 1	f	medium
51595	59126	1969	Московская область, Озеры, площадь Советская, 1	f	medium
111629	59115	1958	Московская область, Озеры, микрорайон им. Маршала Катукова, Помещение гимназии №4	f	\N
111609	55997	745	Московская область, Ожерелье, Советская, 20	f	\N
51481	59034	1855	Московская область, Одинцово, Чистяковой, 10	f	large
51503	59034	1877	Московская область, Одинцово, Чистяковой, 10	f	large
51476	59032	1851	Московская область, Одинцово, Чикина, 13	f	large
51477	59032	1850	Московская область, Одинцово, Чикина, 13	f	large
51487	59039	1861	Московская область, Одинцово, поселок Баковка, Трудовая, 36	f	small
52622	59962	2998	Московская область, Одинцово, Союзная, 1	f	large
51461	59021	1835	Московская область, Одинцово, Северная, 20	f	large
51460	59021	1834	Московская область, Одинцово, Северная, 20	f	large
51475	59030	1849	Московская область, Одинцово, Ново-Спортивная, 14	f	large
51472	59030	1846	Московская область, Одинцово, Ново-Спортивная, 14	f	large
51453	94491	1827	Московская область, Одинцово, Молодежная, 16В	f	large
51456	94491	1830	Московская область, Одинцово, Молодежная, 16В	f	large
51455	94491	1829	Московская область, Одинцово, Молодежная, 16В	f	large
51458	58621	1832	Московская область, Одинцово, Молодежная, 3а	f	large
51457	58621	1831	Московская область, Одинцово, Молодежная, 3а	f	large
51488	59040	1862	Московская область, Одинцово, Можайское шоссе, 149	f	large
83619	57154	2802	Москва, улица Барышиха, 32	f	large
51498	59045	1872	Московская область, Одинцово, Комсомольская, 9	f	large
51494	59045	1868	Московская область, Одинцово, Комсомольская, 9	f	large
51485	59038	1859	Московская область, Одинцово, Вокзальная, 5	f	large
51501	59038	1875	Московская область, Одинцово, Вокзальная, 5	f	large
51486	59038	1860	Московская область, Одинцово, Вокзальная, 5	f	large
51497	59043	1871	Московская область, Одинцово, Верхнепролетарская, 14	f	large
51492	59043	1866	Московская область, Одинцово, Верхнепролетарская, 14	f	large
51496	59043	1870	Московская область, Одинцово, Верхнепролетарская, 14	f	large
51389	58951	1737	Московская область, Ногинск, Юбилейная, 3	f	large
51388	58951	1736	Московская область, Ногинск, Юбилейная, 3	f	large
51378	58809	1728	Московская область, Ногинск, Третьего Интернационала, 117	f	large
51352	58955	1748	Московская область, Ногинск, Советской Конституции, 16	f	large
51356	58955	1741	Московская область, Ногинск, Советской Конституции, 16	f	large
51377	58702	1727	Московская область, Ногинск, Советская, 101	f	large
51363	58937	1715	Московская область, Ногинск, Октябрьская, 83	f	large
51361	58937	1713	Московская область, Ногинск, Октябрьская, 83	f	large
51340	58960	1754	Московская область, Ногинск, Набережная 60-летия октября, 2	f	large
111623	58944	1722	Московская область, Ногинск, Краснослободская, 2	f	\N
51354	58944	1739	Московская область, Ногинск, Краснослободская, 2	f	large
51364	58939	1716	Московская область, Ногинск, Комсомольская, 3	f	large
51372	58939	1723	Московская область, Ногинск, Комсомольская, 3	f	large
51371	58939	1720	Московская область, Ногинск, Комсомольская, 3	f	large
51360	58957	1745	Московская область, Ногинск, Кирова, 3	f	large
51359	58957	1744	Московская область, Ногинск, Кирова, 3	f	large
51358	58957	1743	Московская область, Ногинск, Кирова, 3	f	large
51342	58961	1756	Московская область, Ногинск, Зенитчиков, 1	f	large
51344	58963	1758	Московская область, Ногинск, Декабристов, 79б	f	large
51384	58950	1732	Московская область, Ногинск, Бабушкина, 3	f	large
50741	58514	1113	Московская область, поселок Нахабино, Институтская, 1	f	large
50733	58509	1105	Московская область, Нахабино, Нахабинский учебный центр	f	large
50737	58512	1109	Московская область, Нахабино, 11 Саперов, 6	f	large
51244	58862	1619	Московская область, Наро-Фоминск, Школьная, 6	f	large
51264	58872	1639	Московская область, Наро-Фоминск, Шибанкова, 28	f	large
51260	58872	1635	Московская область, Наро-Фоминск, Шибанкова, 28	f	large
51252	58865	1627	Московская область, Наро-Фоминск, Погодина, 93а	f	large
51258	58870	1633	Московская область, Наро-Фоминск, Парк Воровского, 14	f	large
51253	58866	1628	Московская область, Наро-Фоминск, Московская, 9	f	medium
51248	58864	1623	Московская область, Наро-Фоминск, Ленина, 23	f	large
51250	58667	1625	Московская область, Наро-Фоминск, Ленина, 5	f	large
51195	58818	1568	Московская область, Мытищи, Щербакова, 1А	f	large
51189	58818	1562	Московская область, Мытищи, Щербакова, 1А	f	large
51149	58788	1522	Московская область, Мытищи, Фрунзе, 11	f	large
51163	58695	1536	Московская область, Мытищи, Силикатная, 33	f	large
51188	58817	1561	Московская область, Мытищи, Семашко, 2	f	large
51147	58857	1614	Московская область, Мытищи, Октябрьская, 4а, в помещении МОУ средняя	f	large
51205	58826	1578	Московская область, Мытищи, Новомытищинский проспект, 88к5	f	large
51198	58822	1571	Московская область, Мытищи, Новомытищинский проспект, 82к10	f	large
51202	58822	1575	Московская область, Мытищи, Новомытищинский проспект, 82к10	f	large
51194	58820	1567	Московская область, Мытищи, Новомытищинский проспект, 74	f	large
51193	58820	1566	Московская область, Мытищи, Новомытищинский проспект, 74	f	large
51192	58820	1565	Московская область, Мытищи, Новомытищинский проспект, 74	f	large
51179	58810	1552	Московская область, Мытищи, Новомытищинский проспект, 38	f	large
51190	58810	1563	Московская область, Мытищи, Новомытищинский проспект, 38	f	large
51182	58812	1555	Московская область, Мытищи, Колпакова, 34	f	large
51181	58812	1554	Московская область, Мытищи, Колпакова, 34	f	large
51168	58803	1541	Московская область, Мытищи, Индустриальная, 7к2	f	large
51167	58803	1540	Московская область, Мытищи, Индустриальная, 7к2	f	large
51166	58803	1539	Московская область, Мытищи, Индустриальная, 7к2	f	large
51213	58829	1586	Московская область, Мытищи, Веры Волошиной, 12	f	large
51210	58829	1583	Московская область, Мытищи, Веры Волошиной, 12	f	large
51209	58829	1582	Московская область, Мытищи, Веры Волошиной, 12	f	large
51183	58813	1556	Московская область, Мытищи, Борисовка, 4	f	large
51172	58805	1545	Московская область, Мытищи, Белобородова, 5	f	large
51171	58805	1544	Московская область, Мытищи, Белобородова, 5	f	large
51170	58805	1543	Московская область, Мытищи, Белобородова, 5	f	large
51152	58792	1525	Московская область, Мытищи, Академика Каргина, 36к2	f	large
51154	58792	1527	Московская область, Мытищи, Академика Каргина, 36к2	f	large
51146	58856	1613	Московская область, Мытищи, 4-я Парковая, 20, в помещении библиотек	f	large
51214	58831	1587	Московская область, Мытищи, 3-я Крестьянская, 17	f	large
52879	60177	3256	Московская область, Монино, Авиационная, 25, Дом офицеров гарнизона	f	large
52878	60177	3255	Московская область, Монино, Авиационная, 25, Дом офицеров гарнизона	f	large
52876	60177	3253	Московская область, Монино, Авиационная, 25, Дом офицеров гарнизона	f	large
51093	58738	1468	Московская область, Можайск, Полосухина, 7, Филиал МГУПИ	f	large
51089	58734	1464	Московская область, Можайск, Московская, 48, Средняя школа №1	f	large
51084	58729	1459	Московская область, Можайск, Московская, 9, РКДЦ	f	large
51098	58742	1473	Московская область, Можайск, Мира, 93, ПУ №70	f	large
51660	59155	2034	Московская область, Можайск, Красноармейская, 10	f	large
51631	59155	2005	Московская область, Можайск, Красноармейская, 10	f	large
51977	59437	2351	Московская область, деревня Митрополье, Совхозная, 27	t	medium
52445	59804	2821	Московская область, Менделеево, Куйбышево, 11	f	large
51075	58723	1450	Московская область, Люберецкий район, Малаховка, поселок МЭЗ, Быковское шоссе, 52А	f	large
51074	58723	1449	Московская область, Люберецкий район, Малаховка, поселок МЭЗ, Быковское шоссе, 52А	f	large
50977	58666	1352	Московская область, Люберцы, микрорайон поселок Калинина, 55к1, школа № 10	f	large
50976	58666	1351	Московская область, Люберцы, микрорайон поселок Калинина, 55к1, школа № 10	f	large
50975	58666	1350	Московская область, Люберцы, микрорайон поселок Калинина, 55к1, школа № 10	f	large
50974	58666	1349	Московская область, Люберцы, микрорайон поселок Калинина, 55к1, школа № 10	f	large
50973	58666	1348	Московская область, Люберцы, микрорайон поселок Калинина, 55к1, школа № 10	f	large
51005	58688	1388	Московская область, Люберцы, Электрификации, 30, средняя школа № 2	f	large
51004	58688	1387	Московская область, Люберцы, Электрификации, 30, средняя школа № 2	f	large
51008	58681	1378	Московская область, Люберцы, Октябрьский проспект, 348, (гимназия № 5)	f	large
51007	58681	1377	Московская область, Люберцы, Октябрьский проспект, 348, (гимназия № 5)	f	large
50984	58673	1359	Московская область, Люберцы, Октябрьский проспект, 178, гимназия № 1	f	large
50980	58670	1355	Московская область, Люберцы, Октябрьский проспект, 136, училище им. Ю.А.Гагарина	f	large
50972	58665	1347	Московская область, Люберцы, Октябрьский проспект, 114, Областной техникум	f	large
50971	58665	1346	Московская область, Люберцы, Октябрьский проспект, 114, Областной техникум	f	large
51030	58697	1405	Московская область, Люберцы, Красногорская, 3, гимназия № 24	f	large
51029	58697	1404	Московская область, Люберцы, Красногорская, 3, гимназия № 24	f	large
51037	58700	1412	Московская область, Люберцы, Инициативная, 5, УПП "ВОС"	f	large
50954	58652	1329	Московская область, Лыткарино, 1-й квартал, 21	f	large
50955	58652	1330	Московская область, Лыткарино, 1-й квартал, 21	f	large
50963	58658	1338	Московская область, Лыткарино, 7-й квартал, проезд Шестакова, стр.2	f	large
50957	58653	1332	Московская область, Лыткарино, Спортивная , 24	f	large
50958	58654	1333	Московская область, Лыткарино, Спортивная, 24	f	large
50966	58661	1341	Московская область, Лыткарино, Сафонова, 2а	f	large
50968	58662	1343	Московская область, Лыткарино, Пионерская, 6	f	large
50967	58662	1342	Московская область, Лыткарино, Пионерская, 6	f	large
50959	58655	1334	Московская область, Лыткарино, 3-й квартал, Парковая улица, 11	f	large
50965	58660	1340	Московская область, Лыткарино, Парковая, 16	f	large
50964	58659	1339	Московская область, Лыткарино, Парковая, 16	f	large
50962	58657	1337	Московская область, Лыткарино, Ленина, 2а	f	large
50961	58656	1336	Московская область, Лыткарино, Ленина, 2а	f	large
50960	58656	1335	Московская область, Лыткарино, Ленина, 2а	f	large
50956	58651	1331	Московская область, Лыткарино, Комсомольская, 34	f	large
50953	58651	1328	Московская область, Лыткарино, Комсомольская, 34	f	large
50952	58650	1327	Московская область, Лыткарино, 6-й микрорайон, 6 микрорайон, 26	f	large
50905	58606	1279	Московская область, Луховицы, Пушкина, 178	f	medium
50902	58604	1276	Московская область, Луховицы, Пушкина, 132	f	large
50901	58603	1275	Московская область, Луховицы, Первомайская, 18а	f	large
50900	58603	1274	Московская область, Луховицы, Первомайская, 18а	f	large
50907	58608	1281	Московская область, Луховицы, Мира, 16	f	large
50906	58607	1280	Московская область, Луховицы, Мира, 12	f	large
50881	58586	1255	Московская область, Лосино-Петровский, площадь Революции, 24	f	large
50880	58585	1254	Московская область, Московская область, Лосино-Петровский, Чехова, 8	f	large
50875	58580	1249	Московская область, Лосино-Петровский, Строителей, 2	f	large
50874	58579	1248	Московская область, Лосино-Петровский, Строителей, 2	f	large
51790	59271	2164	Россия, Московская область, Лосино-Петровский, Почтовая улица, 2	f	large
50876	58581	1250	Московская область, Лосино-Петровский, Октябрьская, 12	f	large
50878	58583	1252	Московская область, Лосино-Петровский, Ленина, 1	f	large
50882	58582	1256	Московская область, Лосино-Петровский, Ленина, 6	f	large
50877	58582	1251	Московская область, Лосино-Петровский, Ленина, 6	f	large
50879	58584	1253	Московская область, Лосино-Петровский,  Чехова, 10	f	large
50853	94557	1227	Московская область, Лобня, улица Победы, 18, ЦДТ	f	large
50863	94551	1237	Московская область, Лобня, проезд Шадунца, 1, школа № 9	f	large
50841	94551	1215	Московская область, Лобня, проезд Шадунца, 1, школа № 9	f	large
50845	94554	1219	Московская область, Лобня, Чехова, 13, школа № 8	f	large
50844	94554	1218	Московская область, Лобня, Чехова, 13, школа № 8	f	large
50852	94556	1226	Московская область, Лобня, Фестивальная, 2, школа № 2	f	large
50850	94507	1224	Россия, Московская область, Лобня, Первая улица, 3	f	large
50842	94552	1216	Московская область, Лобня, Павлика Морозова, 1, школа № 1	f	large
50872	94572	1246	Московская область, Лобня, Научный городок, 4, ДК Луговая	f	large
50857	94560	1231	Московская область, Лобня, Мирная, 24а, школа № 3	f	large
50856	94560	1230	Московская область, Лобня, Мирная, 24а, школа № 3	f	large
50858	94561	1232	Московская область, Лобня, Ленина, 65, ДС «Лобня»	f	large
50855	94559	1229	Московская область, Лобня, Ленина, 29, МОУ лицей	f	large
50849	94501	1223	Московская область, Лобня, Ленина, 15а, школа искусств	f	large
50868	94568	1242	Московская область, Лобня, Краснополянская улица, 31, спорткомплекс школы № 6	f	large
50843	94553	1217	Московская область, Лобня, Комиссара Агапова, 8а, Досуговый центр Восточный	f	large
50854	94558	1228	Московская область, Лобня, Дружбы, 3, КДЦ Чайка	f	large
50866	94566	1240	Московская область, Лобня, Деповская, 18, Досуговый центр	f	large
50871	94571	1245	Московская область, Лобня, Булычева, 7, филиал ЦДТ	f	large
50862	94564	1236	Россия, Московская область	f	large
50861	94564	1235	Россия, Московская область	f	large
111620	58578	1247	Московская область, Лобня, Большая, 2, Луговская средняя школа	f	\N
50870	94570	1244	Московская область, Лобня, Аэропортовская улица, 1, школа № 6	f	large
50869	94569	1243	Московская область, Лобня, Аэропортовская, 1, школа № 6	f	large
50860	94563	1234	Московская область, Лобня, Авиационная, 1, школа № 5	f	large
50859	94562	1233	Московская область, Лобня,  Авиационная, 1, школа № 5	f	large
51681	59194	2055	Московская область, Ликино-Дулево, Октябрьская, 40	f	large
51555	59092	1929	Московская область, Ликино-Дулево, Новая, 9	f	large
51679	59192	2053	Московская область, Ликино-Дулево, Коммунистическая, 38	f	large
51668	59182	2042	Московская область, Куровское, Совхозная, 2	f	medium
51674	59188	2048	Московская область, Куровское, Лесная, 50	f	large
52042	59485	2421	Московская область, поселок городского типа Кратово, Чурилина, 27	f	medium
50765	58525	1138	Московская область, Краснознаменск, проспект Мира, 8	f	large
50762	58535	1135	Московская область, Краснознаменск, Молодежная, 6	f	large
50764	58492	1137	Московская область, Краснознаменск, Молодежная, 2	f	large
50763	58536	1136	Московская область, Краснознаменск, Комсомольский бульвар, 2	f	large
50761	58534	1134	Московская область, Краснознаменск, Генерала Шлыкова, 3	f	large
52269	59665	2642	Московская область, Краснозаводск, Строителей, 17	f	large
50726	58502	1098	Московская область, Красногорск, Южный бульвар, 3	f	large
50725	58502	1097	Московская область, Красногорск, Южный бульвар, 3	f	large
50724	58502	1096	Московская область, Красногорск, Южный бульвар, 3	f	large
50723	58502	1095	Московская область, Красногорск, Южный бульвар, 3	f	large
50685	58481	1057	Московская область, Красногорск, микрорайон Опалиха, Чапаева, 59	f	medium
50687	94546	1059	Московская область, Красногорск, Ткацкой фабрики, 18, Новоникольская амбулатория	f	large
50715	58497	1087	Московская область, Красногорск, Речная, 8/1	f	large
50711	94547	1083	Московская область, Красногорск, Пионерская, 4, ГПУ № 4	f	large
50719	58499	1091	Московская область, Красногорск, Ильинское шоссе, 6	f	large
50722	58501	1094	Московская область, Красногорск, Вокзальная, 11а	f	medium
50680	58476	1052	Россия, Московская область, Красноармейск, микрорайон Северный, 24	f	large
50682	58478	1054	Россия, Московская область, Красноармейск, улица Академика Янгеля, 31	f	large
50677	58473	1049	Московская область, Красноармейск, Спортивная улица, 9	f	large
50679	58475	1051	Московская область, Красноармейск, Комсомольская, 3	f	large
50678	58474	1050	Московская область, Красноармейск, Комсомольская, 5а	f	large
50676	58472	1048	Московская область, Красноармейск, Горького, 4	f	large
50683	94545	1055	Московская область, Красноармейск, Академика Янгеля, 33	f	large
50681	58477	1053	Московская область, Красноармейск,  Новая Жизнь, 1а	f	large
50669	94544	1041	Московская область, Котельники, микрорайон Силикат, 32, ДК Силикат	f	large
50668	94544	1040	Московская область, Котельники, микрорайон Силикат, 32, ДК Силикат	f	large
50672	58470	1044	Россия, Московская область, Котельники, микрорайон Ковровый, 39	t	large
50670	58470	1042	Россия, Московская область, Котельники, микрорайон Ковровый, 39	t	large
50671	58470	1043	Россия, Московская область, Котельники, микрорайон Ковровый, 39	t	large
50766	58538	1139	Россия, Московская область, Котельники, Парковая улица, 4	f	large
49977	57902	350	Россия, Московская область, Котельники, Парковая улица, 10	f	medium
50667	58468	1039	Московская область, Котельники, Малая Колхозная, 1 а	f	small
50618	58435	990	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 28	f	large
50616	58435	988	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 28	f	large
50615	58435	987	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 28	f	large
50614	58434	986	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 12а	f	large
50613	58434	985	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 12а	f	large
50612	58434	984	Россия, Московская область, Королев, микрорайон Костино, улица Сакко и Ванцетти, 12а	f	large
52156	94622	2529	Россия, Московская область, Королев, микрорайон Валентиновка, улица Победы, 34	f	large
50625	58441	997	Московская область, Королев, улица Дзержинского, 20а	f	large
50624	58441	996	Московская область, Королев, улица Дзержинского, 20а	f	large
50648	58452	1020	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 37б	f	large
50647	58452	1019	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 37б	f	large
50646	58452	1018	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 37б	f	large
50645	58452	1017	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 37б	f	large
50641	58451	1013	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 18	f	large
50644	58450	1016	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 5а	f	large
50638	58450	1010	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 5а	f	large
50637	58450	1009	Россия, Московская область, Королев, микрорайон Костино, проспект Космонавтов, 5а	f	large
50623	58440	995	Россия, Московская область, Королев, микрорайон Костино, проспект Королева, 6а	f	large
50621	58438	993	Россия, Московская область, Королев, микрорайон Костино, проспект Королева, 14а	f	large
50655	58457	1027	Московская область, Королев, Школьная, 19	f	large
50654	58457	1026	Московская область, Королев, Школьная, 19	f	large
50649	58453	1021	Московская область, Королев, Торфопредприятие, 1	f	small
50608	58431	980	Московская область, Королев, Терешковой, 3	f	large
50605	58427	977	Московская область, Королев, Терешковой, 1	f	large
50602	58427	974	Московская область, Королев, Терешковой, 1	f	large
50619	58436	991	Московская область, Королев, Суворова, 16	f	large
50643	58447	1015	Московская область, Королев, микрорайон Костино, Стадионная, 4а	f	large
50642	58447	1014	Московская область, Королев, микрорайон Костино, Стадионная, 4а	f	large
50634	58447	1006	Московская область, Королев, микрорайон Костино, Стадионная, 4а	f	large
50656	58458	1028	Россия, Московская область, Королев, микрорайон Болшево, Спартаковская улица, 5	f	medium
50661	58463	1033	Московская область, Королев, микрорайон Первомайский, Солнечная, 35/25	f	large
50658	58460	1030	Московская область, Королев, Советская , 18	f	large
50660	58462	1032	Московская область, Королев, Советская, 5	f	large
50665	58466	1037	Московская область, Королев, Советская, 8	f	large
50664	58466	1036	Московская область, Королев, Советская, 8	f	large
50659	58461	1031	Московская область, Королев, микрорайон Первомайский, Советская, 71	f	large
50617	94543	989	Московская область, Королев, микрорайон Костино, Сакко и Ванцетти, 28, УИК	f	large
52157	94623	2530	Московская область, Королев, микрорайон Валентиновка, Победы, 35	f	large
52155	94621	2528	Московская область, Королев, микрорайон Валентиновка, Победы, 33	f	large
50611	58433	983	Московская область, Королев, Пионерская, 8	f	large
50610	58433	982	Московская область, Королев, Пионерская, 8	f	large
50595	58420	967	Московская область, Королев, Первомайская улица, 7Акорп. 2	f	large
50657	58459	1029	Московская область, Королев, микрорайон Болшево, Пашенной, 17а	f	small
50622	58439	994	Россия, Московская область, Королев, микрорайон Костино, Октябрьский бульвар, 33	f	large
50606	58425	978	Московская область, Королев, Октябрьская улица, 10	f	large
50600	58425	972	Московская область, Королев, Октябрьская улица, 10	f	large
50603	58428	975	Московская область, Королев, Октябрьская , 23	f	large
50666	58467	1038	Россия, Московская область, Королев, микрорайон Текстильщик, Молодежная улица, 7	f	large
50633	58446	1005	Московская область, Королев, Мичурина, 25	f	large
50632	58446	1004	Московская область, Королев, Мичурина, 25	f	large
50599	58424	971	Московская область, Королев, микрорайон Первомайский, Ленина, 2	f	large
50662	58464	1034	Московская область, Королев, Краснооктябрьская, 40	f	small
50598	58423	970	Московская область, Королев, Комсомольская, 12	f	large
50652	58456	1024	Московская область, Королев, Комитетский лес, 14	f	large
50653	58456	1025	Московская область, Королев, Комитетский лес, 14	f	large
50626	58442	998	Россия, Московская область, Королев, Калининградская улица, 12	f	large
50635	58448	1007	Московская область, Королев, Исаева, 2/30	f	large
50629	58444	1001	Московская область, Королев, микрорайон Костино, Дзержинского, 24/2	f	large
50627	58443	999	Московская область, Королев, микрорайон Костино, Дзержинского, 5	f	large
50628	58443	1000	Московская область, Королев, микрорайон Костино, Дзержинского, 5	f	large
50631	58445	1003	Московская область, Королев, микрорайон Костино, Дзержинского, 26	f	large
50630	58445	1002	Московская область, Королев, микрорайон Костино, Дзержинского, 26	f	large
50597	58422	969	Московская область, Королев, Грабина, 2а	f	large
50609	58432	981	Московская область, Королев, Гагарина, 42	f	large
50604	58429	976	Московская область, Королев, Гагарина, 5	f	large
50596	58421	968	Россия, Московская область, Королев, Болшевское шоссе, 2	f	large
50620	58437	992	Московская область, Королев, микрорайон Костино,  50 Лет ВЛКСМ, 5/16	f	large
50536	58308	908	Россия, Московская область, городской округ Коломна	f	large
50525	58363	897	Россия, Московская область, Коломна, район Старая Коломна, улица Набережная реки Коломенки, 7	f	large
50524	58362	896	Московская область, Коломна, район Запруды, улица Менделеева, 18, школа №1	f	large
50548	58382	920	Россия, Московская область, Коломна, район Центральный, улица Малышева, 19а	f	large
50584	58409	956	Московская область, Коломна, район Ларцевы Поляны, улица Ларцевы Поляны, 11, школа № 28	f	large
50544	58379	916	Россия, Московская область, Коломна, район Центральный, улица Дзержинского, 11	f	large
50563	58395	935	Московская область, Коломна, проспект Кирова, 28, Шахматный клуб	f	large
50559	58391	931	Московская область, Коломна, проспект Кирова, 3, Мособлэлектротранс	f	large
50533	58371	905	Московская область, Коломна, проспект Кирова, 4, Спортивная школа	f	large
50566	58397	938	Московская область, Коломна, проспект Кирова, 49, Детская художественная школа	f	large
50571	58398	943	Московская область, Коломна, район Колычево, бульвар 800-летия Коломны, 9, школа № 15	f	large
50570	58398	942	Московская область, Коломна, район Колычево, бульвар 800-летия Коломны, 9, школа № 15	f	large
50568	58398	940	Московская область, Коломна, район Колычево, бульвар 800-летия Коломны, 9, школа № 15	f	large
50580	58405	952	Московская область, Коломна, Южная, 7, школа № 18	f	large
50579	58405	951	Московская область, Коломна, Южная, 7, школа № 18	f	large
50532	94542	904	Московская область, Коломна, район Репинский, Шилова, 5, здание школы № 14	f	large
50561	58393	933	Московская область, Коломна, Шилова, 5, школа № 14	f	large
50560	58392	932	Московская область, Коломна, Шилова, 5, школа № 14	f	large
50540	58376	913	Московская область, Коломна, Шавырина, 5, школа № 20	f	large
50541	58376	912	Московская область, Коломна, Шавырина, 5, школа № 20	f	large
50588	58412	960	Московская область, Коломна, район Ларцевы Поляны, Цементников, 9, школа № 30	f	large
50585	58410	957	Московская область, Коломна, район Ларцевы Поляны, Цементников, 17, школа № 30	f	large
50601	58426	973	Московская область, Коломна, Фрунзе, 19	f	large
50578	58404	950	Московская область, Коломна, район Колычево, Спирина, 8, школа № 17	f	large
50576	58402	948	Московская область, Коломна, Спирина, 8, школа № 17	f	large
50586	58411	958	Московская область, Коломна, Советская, 60а, Дворец культуры Цементник	f	large
50587	58411	959	Московская область, Коломна, Советская, 60а, Дворец культуры Цементник	f	large
50060	57933	432	Московская область, Коломна, Свободы, 20	f	large
50539	58375	911	Московская область, Коломна, район Запруды, Октябрьской революции, 324, ДК Тепловозостроитель	f	large
50538	58375	910	Московская область, Коломна, район Запруды, Октябрьской революции, 324, ДК Тепловозостроитель	f	large
50542	58377	914	Московская область, Коломна, район Запруды, Октябрьской революции, 408, институт МГОУ	f	medium
50537	58374	909	Московская область, Коломна, район Запруды, Октябрьской Революции, 322а, гимназия № 9	f	large
50534	58372	906	Московская область, Коломна, район Запруды, Октябрьской Революции, 277, школа Надежда	f	large
50530	58368	902	Московская область, Запруды, Коломна, район Запруды, Октябрьской Революции, 222, центр Выбор	f	large
50526	58364	898	Московская область, Коломна, район Запруды, Октябрьской Революции, 232, Дом учителя	f	large
50522	58360	894	Московская область, Коломна, район Запруды, Октябрьской Революции, 128, автоколонна 1417	f	large
50583	58408	955	Московская область, Коломна, район Дубовая Роща, Октябрьская, 107	f	large
50546	58380	918	Московская область, Коломна, Окский проспект, 17, Дворец культуры Коломна	f	large
50545	58378	917	Московская область, Коломна, Окский проспект, 17, Дворец культуры Коломна	f	large
50543	58378	915	Московская область, Коломна, Окский проспект, 17, Дворец культуры Коломна	f	large
50531	94541	903	Московская область, Коломна, район Подлипки, Озерское шоссе, здание РЭУ Коломенский	f	large
50523	58361	895	Россия, Московская область, Коломна, район Запруды, Малинское шоссе, 36	f	large
50581	58406	953	Московская область, Коломна, район Дубовая Роща, Лесная, 13а, бывший клуб КСД	f	large
50562	58394	934	Московская область, Коломна, район Репинский, Леваневского, 8, гимназия № 8	f	large
50528	58366	900	Московская область, Коломна, Красногвардейская, 36, Коломенские электросети	f	large
50529	58367	901	Московская область, Коломна, Коломна, Комсомольская, 12а, Тепло Коломны	f	large
50569	58399	941	Московская область, Коломна, Кирова, 163, Культурный центр	f	medium
50549	58383	921	Московская область, Коломна, район Центральный, Калинина, 14, гимназия № 2	f	large
50552	58385	924	Московская область, Коломна, район Центральный, Зеленая, 30, Пединститут	f	large
50551	58385	923	Московская область, Коломна, район Центральный, Зеленая, 30, Пединститут	f	large
50567	58396	939	Московская область, Коломна, Зеленая, 3, школа № 12	f	large
50565	58396	937	Московская область, Коломна, Зеленая, 3, школа № 12	f	large
50527	58365	899	Московская область, Коломна, Зайцева, 11, школа № 7	f	large
50558	58390	930	Московская область, Коломна, район Центральный, Добролюбова, 2а, лицей № 4	f	large
50557	58390	929	Московская область, Коломна, район Центральный, Добролюбова, 2а, лицей № 4	f	large
50556	58389	928	Московская область, Коломна, Добролюбова, 4, Мособлстрой-3	f	large
50564	58386	936	Московская область, Коломна, Дзержинского, 90, школа № 10	f	large
50553	58386	925	Московская область, Коломна, Дзержинского, 90, школа № 10	f	large
50550	58384	922	Московская область, Коломна, Дзержинского, 27, школа № 11	f	large
50555	58388	927	Московская область, Коломна, Дзержинского, 80, Центр занятости	f	large
50575	58401	947	Московская область, Коломна, район Колычево, Девичье Поле, 9, школа № 16	f	large
50574	58401	946	Московская область, Коломна, район Колычево, Девичье Поле, 9, школа № 16	f	large
50573	58401	945	Московская область, Коломна, район Колычево, Девичье Поле, 9, школа № 16	f	large
50572	58400	944	Московская область, Коломна, район Колычево, Астахова, 23, центр Русь	f	large
50426	58271	798	Московская область, Клин, Самодеятельная, 11а	f	large
50425	58271	797	Московская область, Клин, Самодеятельная, 11а	f	large
111610	58267	792	Московская область, Клин, Папивина, 1/20	f	\N
50433	58275	805	Московская область, Клин, Карла Маркса, 99	f	large
50435	58277	807	Московская область, Клин, 50 лет Октября, 13а	f	large
50436	58277	808	Московская область, Клин, 50 лет Октября, 13а	f	large
50405	58254	777	Россия, Московская область, Климовск, проспект 50 лет Октября, 18	f	large
50409	58259	781	Московская область, Климовск, проезд Юности, 1	f	large
50394	58246	766	Московская область, Климовск, Школьная, 10	f	large
50406	58255	778	Московская область, Климовск, Театральная, 6	f	large
50407	58257	779	Московская область, Климовск, Симферопольская, 5А	f	large
50401	58251	773	Московская область, Климовск, Серпуховская, 1б	f	large
50397	58247	769	Московская область, Климовск, Рощинская, 17а	f	large
50396	58247	768	Московская область, Климовск, Рощинская, 17а	f	large
50395	58247	767	Московская область, Климовск, Рощинская, 17а	f	large
50399	58249	771	Московская область, Климовск, Рожкова, 6	f	large
50402	58252	774	Московская область, Климовск, Революции, 4	f	large
50404	58253	776	Московская область, Климовск, Первомайская, 3А	f	large
50403	58253	775	Московская область, Климовск, Первомайская, 3А	f	large
50410	58260	782	Московская область, Климовск, Молодежная, 2А	f	large
50400	58250	772	Московская область, Климовск, Ленина, 23	f	large
50398	58248	770	Московская область, Климовск, Ленина, 20	f	large
50393	58245	765	Московская область, Климовск, Ленина, 2А	f	large
50408	58258	780	Московская область, Климовск, Заводская, 3	f	large
50361	58192	734	Московская область, Кашира, Металлистов, 6	f	large
50362	58192	735	Московская область, Кашира, Металлистов, 6	f	large
50369	55589	742	Московская область, Кашира, Гвардейская, 6	f	large
50368	55589	741	Московская область, Кашира, Гвардейская, 6	f	large
50296	94511	668	Московская область, Истра, Юбилейная, 11а, Истр.ср.школа №2	f	large
50295	58163	667	Московская область, Истра, Ленина, 6, здание Агитпункта	f	large
50301	58168	673	Московская область, Истра, 9 Гвардейской Дивизии, 33а, здание Педагогического колледжа	f	large
49912	57826	285	Московская область, Икша, поселок опытного хозяйства &amp;quot;Ермолино&amp;quot;, Сельский дом, ДК ц.у. ОПХ Ермолино	f	large
50281	58156	653	Россия, Московская область, Ивантеевка, Центральный проезд, 3	f	large
50290	58160	662	Московская область, Ивантеевка, Хлебозаводская, 18	f	large
50288	58160	660	Московская область, Ивантеевка, Хлебозаводская, 18	f	large
50287	58160	659	Московская область, Ивантеевка, Хлебозаводская, 18	f	large
50286	58159	658	Московская область, Ивантеевка, Трубниковская, 27	f	large
50285	58159	657	Московская область, Ивантеевка, Трубниковская, 27	f	large
50280	58155	652	Московская область, Ивантеевка, Советский проспект, 12/8	f	large
50283	58157	655	Московская область, Ивантеевка, Смурякова, 10	f	large
50282	58157	654	Московская область, Ивантеевка, Смурякова, 10	f	large
50293	58153	665	Московская область, Ивантеевка, Первомайская улица, 35	f	large
50275	58153	647	Московская область, Ивантеевка, Первомайская улица, 35	f	large
50274	58152	646	Московская область, Ивантеевка, Первомайская, 37	f	large
50279	58140	651	Московская область, Ивантеевка, Задорожная, 18	f	large
50278	58140	650	Московская область, Ивантеевка, Задорожная, 18	f	large
50276	58140	648	Московская область, Ивантеевка, Задорожная, 18	f	large
50284	58158	656	Московская область, Ивантеевка,  Дзержинского, 1а	f	large
50277	58154	649	Московская область, Ивантеевка,  Дзержинского, 7	f	large
52474	59830	2850	Московская область, Звенигород, поселок Санаторий	f	large
50266	58145	638	Московская область, Звенигород, Военный санаторий МО РФ клуб	t	medium
50263	58142	635	Московская область, Звенигород, 8	f	large
111608	94509	642	Московская область, Звенигород, улица Кирова, магазин Продукты	f	\N
50267	58146	639	Московская область, Звенигород, Спортивная, 4	f	medium
50265	58144	637	Московская область, Звенигород, Советская улица, 4	f	large
50264	58143	636	Московская область, Звенигород, Некрасова, 8	f	large
50269	58148	641	Московская область, Звенигород, квартал Маяковского, Нахабинское шоссе, 15	f	large
111607	94489	640	Московская область, Звенигород, квартал Маяковского, Маяковского, 4	f	\N
50204	58094	577	Московская область, Звенигород, квартал Маяковского, Маяковского, 15	f	large
50261	58139	633	Московская область, Звенигород, Звенигородское шоссе, 7	f	medium
50260	58138	632	Московская область, Звенигород, Верхнепосадкое шоссе, 1	f	large
50273	58151	645	Московская область, поселок Звездный городок, 7а, МБУК Дом космонавтов	f	large
50272	58151	644	Московская область, поселок Звездный городок, 7а, МБУК Дом космонавтов	f	large
50271	58151	643	Московская область, поселок Звездный городок, 7а, МБУК Дом космонавтов	f	large
50244	57900	616	Московская область, Зарайск, 1-й микрорайон, 30	f	large
50232	58114	604	Московская область, Зарайск, Московская, 1	f	medium
50230	58112	602	Московская область, Зарайск, Московская, 110, Здание ПУ №85	f	medium
50243	58124	615	Московская область, Зарайск, 1-й микрорайон, Микрорайон-1, 34, МОУ гимназия № 2	f	large
50242	58124	614	Московская область, Зарайск, 1-й микрорайон, Микрорайон-1, 34, МОУ гимназия № 2	f	large
50241	58123	613	Московская область, Зарайск, Микрорайон-1, 35	f	large
50219	58105	592	Россия, Московская область, Жуковский, улица Дугина, 16	f	large
50218	58105	591	Россия, Московская область, Жуковский, улица Дугина, 16	f	large
50217	58102	590	Россия, Московская область, Жуковский, улица Дугина, 19	f	large
50214	58102	587	Россия, Московская область, Жуковский, улица Дугина, 19	f	large
50208	58096	581	Московская область, Жуковский, Фрунзе, 28	f	large
50207	58095	580	Московская область, Жуковский, Фрунзе, 8	f	large
50206	58095	579	Московская область, Жуковский, Фрунзе, 8	f	large
50205	58095	578	Московская область, Жуковский, Фрунзе, 8	f	large
50226	58110	599	Московская область, Жуковский, Федотова, 19	f	large
50225	58110	598	Московская область, Жуковский, Федотова, 19	f	large
50202	58092	575	Московская область, Жуковский, Пушкина, 3	f	large
50200	58090	573	Московская область, Жуковский, Осипенко, 7	f	large
50199	58090	572	Московская область, Жуковский, Осипенко, 7	f	large
50222	58107	595	Московская область, Жуковский, Молодежная, 9	f	large
50221	58107	594	Московская область, Жуковский, Молодежная, 9	f	large
50220	58106	593	Московская область, Жуковский, Молодежная, 10	f	large
50224	58087	597	Московская область, Жуковский, Молодежная, 25	f	large
50210	58099	583	Московская область, Жуковский, Менделеева, 12	f	large
50209	58098	582	Московская область, Жуковский, Менделеева, 9	f	large
50198	58089	571	Московская область, Жуковский, Лесная, 7	f	large
50196	94508	569	Московская область, Жуковский, Левченко, 3	f	large
50201	58091	574	Московская область, Жуковский, Комсомольская, 3а	f	large
50203	58093	576	Московская область, Жуковский, Дзержинского, 18	f	large
50215	58103	588	Московская область, Жуковский, Гудкова, 7А	f	large
50216	58104	589	Московская область, Жуковский, Гризодубовой, 12	f	large
50223	58108	596	Московская область, Жуковский, Гагарина, 56	f	large
50213	58101	586	Московская область, Жуковский, Гагарина, 16	f	large
50228	58111	601	Московская область, Жуковский, Баженова, 12	f	large
50227	58111	600	Московская область, Жуковский, Баженова, 12	f	large
50193	58083	565	Россия, Московская область, Железнодорожный	f	large
50192	58082	564	Россия, Московская область, Железнодорожный	f	large
50148	58051	520	Россия, Московская область, Железнодорожный, улица Юннатов, 8	f	large
50147	58051	519	Россия, Московская область, Железнодорожный, улица Юннатов, 8	f	large
50145	58049	517	Россия, Московская область, Железнодорожный, улица Смельчак, 9	f	large
50153	58055	525	Россия, Московская область, Железнодорожный, улица Свободы, 4	f	large
50152	58055	524	Россия, Московская область, Железнодорожный, улица Свободы, 4	f	large
50178	57795	550	Россия, Московская область, Железнодорожный, улица Новая, 17	f	large
50177	57795	549	Россия, Московская область, Железнодорожный, улица Новая, 17	f	large
50190	58080	562	Россия, Московская область, Железнодорожный, улица 1 Мая, 11	f	large
50189	58080	561	Россия, Московская область, Железнодорожный, улица 1 Мая, 11	f	large
50159	58058	531	Московская область, Железнодорожный, микр. Павлино, 12/1	f	large
50158	58058	530	Московская область, Железнодорожный, микр. Павлино, 12/1	f	large
50157	58058	529	Московская область, Железнодорожный, микр. Павлино, 12/1	f	large
50156	58057	528	Московская область, Железнодорожный, микрорайон Павлино, микр. Павлино, 3/1	f	large
50155	58057	527	Московская область, Железнодорожный, микрорайон Павлино, микр. Павлино, 3/1	f	large
50188	58079	560	Московская область, Железнодорожный, Юбилейная, 16а	f	large
50175	58069	547	Московская область, Железнодорожный, Школьная, 3	f	large
50174	58069	546	Московская область, Железнодорожный, Школьная, 3	f	large
50149	58052	521	Московская область, Железнодорожный, Центральная, 11	f	large
50146	58050	518	Московская область, Железнодорожный, Смельчак, 7	f	large
50176	58068	548	Московская область, Железнодорожный, Пролетарская, 8	f	large
50173	58068	545	Московская область, Железнодорожный, Пролетарская, 8	f	large
50194	58084	566	Московская область, Железнодорожный, Победы, 2А	f	large
50185	58076	557	Московская область, Железнодорожный, Пионерская, 26	f	large
50184	58075	556	Московская область, Железнодорожный, Пионерская, 26	f	large
50168	58066	540	Россия, Московская область, Железнодорожный, Октябрьская улица, 11	f	large
50171	58065	543	Россия, Московская область, Железнодорожный, Октябрьская улица, 7	f	large
50170	58065	542	Россия, Московская область, Железнодорожный, Октябрьская улица, 7	f	large
50169	58065	541	Россия, Московская область, Железнодорожный, Октябрьская улица, 7	f	large
50167	58065	539	Россия, Московская область, Железнодорожный, Октябрьская улица, 7	f	large
50151	58054	523	Московская область, Железнодорожный, Носовихинское шоссе, 13	f	large
50150	58053	522	Россия, Московская область, Железнодорожный, Носовихинское шоссе, 13	f	large
50183	58074	555	Московская область, Железнодорожный, Новая, 55	f	large
50166	58064	538	Московская область, Железнодорожный, Некрасова, 4 стр 1	f	large
50182	94506	554	Московская область, Железнодорожный, Колхозная, 9	f	large
50181	58072	553	Московская область, Железнодорожный, Колхозная, 9	f	large
50179	58070	551	Московская область, Железнодорожный, Колхозная, 9	f	large
50186	58078	559	Московская область, Железнодорожный, Калинина, 7	f	large
50187	58077	558	Московская область, Железнодорожный, Калинина, 7	f	large
50154	58056	526	Московская область, Железнодорожный, Заводская, 8	f	large
50165	58063	537	Московская область, Железнодорожный, Жилгородок, 4а	f	large
50164	58062	536	Московская область, Железнодорожный, Жилгородок, 35а	f	large
50161	58060	533	Россия, Московская область, Железнодорожный, Граничная улица, 22	f	large
50163	58061	535	Московская область, Железнодорожный, Граничная, 6	f	large
50162	58061	534	Московская область, Железнодорожный, Граничная, 6	f	large
50144	58034	516	Московская область, Железнодорожный, Гидрогородок	f	small
50191	58081	563	Московская область, Железнодорожный, 1 Мая, 11	f	large
50104	94502	476	Московская область, Егорьевск, 1-й микрорайон, 69, 1-й микрорайон (школа №4)	f	large
50098	58001	470	Московская область, Егорьевск, Софьи Перовской, 101А	f	large
50096	57999	468	Московская область, Егорьевск, Советская, 174	f	large
50086	57989	458	Московская область, Егорьевск, Советская, 2	f	large
50094	57997	466	Московская область, Егорьевск, Горшкова, 32	f	large
83618	57154	2801	Москва, улица Барышиха, 32	f	large
50103	58006	475	Московская область, Егорьевск, 1-й микрорайон, 46	f	large
50095	57998	467	Московская область, Егорьевск, 1 Мая, 77	f	medium
50077	57980	449	Россия, Московская область, Дубна, улица Сахарова, 17	f	large
50075	57978	447	Россия, Московская область, Дубна, улица Понтекорво, 16	f	large
50074	57978	446	Россия, Московская область, Дубна, улица Понтекорво, 16	f	large
50062	94497	434	Московская область, Дубна, площадь Космонавтов, 1, здание ДК Октябрь	f	large
50061	94497	433	Московская область, Дубна, площадь Космонавтов, 1, здание ДК Октябрь	f	large
50056	57968	428	Московская область, Дубна, Центральная, 23/6	f	large
50057	57968	429	Московская область, Дубна, Центральная, 23/6	f	large
50079	57982	451	Московская область, Дубна, Флерова, 8	f	large
50083	57986	455	Московская область, Дубна, Университетская, 19	f	medium
50059	57969	431	Московская область, Дубна, Тверская, 12а	f	large
50058	57969	430	Московская область, Дубна, Тверская, 12а	f	large
50073	57977	445	Московская область, Дубна, Попова, 9	f	large
50072	57977	444	Московская область, Дубна, Попова, 9	f	large
50071	57977	443	Московская область, Дубна, Попова, 9	f	large
50064	57972	436	Московская область, Дубна, Ленина, 39А	f	large
50063	57971	435	Московская область, Дубна, Карла Маркса, 9а	f	large
50076	94498	448	Московская область, Дубна, Дачный проезд, 5, здание городской библиотеки семейного чтения	f	large
50081	57984	453	Московская область, Дубна, Векслера, 23	f	large
50080	57983	452	Московская область, Дубна, Блохинцева, 3	f	large
50078	57981	450	Московская область, Дубна, Алея Высоцкого, 1	f	large
50082	57985	454	Московская область, Дубна, Академика Балдина, 2	f	large
50053	57966	426	Московская область, Домодедово, аэропорт Домодедово, здание аэропорта	f	medium
50042	57957	415	Московская область, Домодедово, тер.ГУ ЦВМиР "Зеленая Роща", Клуб ГУ ЦВМиР "Зеленая Роща"	t	medium
50032	57948	405	Россия, Московская область, Домодедово, микрорайон Белые Столбы	f	large
50021	57937	394	Россия, Московская область, Домодедово, микрорайон Белые Столбы	f	large
50004	57924	377	Россия, Московская область, Домодедово, улица Текстильщиков, 13а	f	large
49990	57914	363	Россия, Московская область, Домодедово, улица Гагарина, 13	f	large
50038	57953	411	Московская область, Домодедово, пос.ГПЗ Константиново, Константиновский СДК	f	large
50014	57930	387	Московская область, Домодедово, микрорайон Авиационный, пл.Гагарина, 5	f	large
50015	57928	388	Московская область, Домодедово, микрорайон Авиационный, пл.Гагарина, 1	f	large
50012	57928	385	Московская область, Домодедово, микрорайон Авиационный, пл.Гагарина, 1	f	large
50010	57928	383	Московская область, Домодедово, микрорайон Авиационный, пл.Гагарина, 1	f	large
50018	57934	391	Московская область, Домодедово, микрорайон Барыбино, Южная, клуб	t	medium
50002	57922	375	Московская область, Домодедово, Ю.Корнеева, 39	f	large
50001	57922	374	Московская область, Домодедово, Ю.Корнеева, 39	f	large
50016	57931	389	Московская область, Домодедово, микрорайон Барыбино, Чкалова, 1	f	large
50047	94496	420	Россия, Московская область, Домодедово, Центральная улица, 7	f	large
50009	57927	382	Московская область, Домодедово, Талалихина, 6	f	large
50007	57927	380	Московская область, Домодедово, Талалихина, 6	f	large
50006	57927	379	Московская область, Домодедово, Талалихина, 6	f	large
49992	57916	365	Россия, Московская область, Домодедово, Советская улица, 32	f	large
50005	57926	378	Московская область, Домодедово, Советская, 19к1	f	large
49986	57911	359	Московская область, Домодедово, Советская, 70	f	large
49987	57911	360	Московская область, Домодедово, Советская, 70	f	large
49994	57918	367	Московская область, Домодедово, Рабочая, 25	f	large
49996	57918	369	Московская область, Домодедово, Рабочая, 25	f	large
49995	57918	368	Московская область, Домодедово, Рабочая, 25	f	large
50024	57940	397	Московская область, Домодедово, Парковая, 1	f	large
111603	58071	552	Московская область, Домодедово, Новая , 38	f	\N
50023	57939	396	Московская область, Домодедово, поселок Востряково, Луговая, 1А	f	large
49985	57910	358	Московская область, Домодедово, Ломоносова, 12/1	f	large
50003	57923	376	Московская область, Домодедово, Корнеева, 42	f	large
49999	57920	372	Московская область, Домодедово, Коломийца, 4	f	large
81434	55813	596	Москва, Яблочкова, 35г	f	large
49998	57920	371	Московская область, Домодедово, Коломийца, 4	f	large
50008	57921	381	Россия, Московская область, Домодедово, Каширское шоссе, 100а	f	large
50000	57921	373	Россия, Московская область, Домодедово, Каширское шоссе, 100а	f	large
49993	57917	366	Московская область, Домодедово, Каширское шоссе, 14	f	large
50041	57956	414	Московская область, Домодедово, поселок Востряково, Заборье, 58	f	large
50013	57929	386	Московская область, Домодедово, Жуковского, 15	f	large
50011	57929	384	Московская область, Домодедово, Жуковского, 15	f	large
49997	94495	370	Московская область, Домодедово, Горького, 8, МУ «Молодежный комплексный центр «Победа»	f	large
52182	59588	2555	Россия, Московская область, Домодедово, Восточная улица, 6	f	large
50917	58614	1291	Россия, Ленинградская область, Гатчинский район, деревня Химози, Восточная улица, 1	f	large
50017	57932	390	Московская область, Домодедово, Агрохимиков, 4б	f	medium
50019	57935	392	Московская область, Домодедово, микрорайон Белые Столбы, Авенариуса, 1А	f	large
49991	57915	364	Россия, Московская область, Домодедово, 3-й Московский проезд, 7	f	large
49988	57912	361	Московская область, Домодедово, 2-я Коммунистическая улица, 2	f	large
50020	57936	393	Московская область, Домодедово, мкр.Белые Столбы, 2-ая Московская, 56	f	large
49989	57913	362	Россия, Московская область, Домодедово, 1-я Коммунистическая улица, 33	f	large
50022	57938	395	Московская область, Домодедово, 1-й Московский проезд, 6	f	medium
49975	57899	348	Московская область, Долгопрудный, проспект Пацаева, 16	f	large
49950	57875	323	Московская область, Долгопрудный, площадь Собина, 3	f	large
49948	57873	321	Московская область, Долгопрудный, площадь Собина, 1	f	large
49981	94492	354	Россия, Московская область, Долгопрудный, микрорайон Шереметьевский, Южная улица, 1а	f	medium
49953	57878	326	Московская область, Долгопрудный, Циолковского, 32	f	large
49951	57876	324	Московская область, Долгопрудный, Циолковского, 10	f	large
49978	57903	351	Московская область, Долгопрудный, Флотская , 1	f	large
49966	57890	339	Московская область, Долгопрудный, Спортивная , 9	f	large
49964	57888	337	Московская область, Долгопрудный, Спортивная , 3а	f	large
49967	57891	340	Московская область, Долгопрудный, Спортивная, 7а	f	large
49965	57889	338	Московская область, Долгопрудный, Спортивная, 3	f	large
49949	57874	322	Московская область, Долгопрудный, Советская, 6	f	large
49952	57877	325	Московская область, Долгопрудный, Первомайская, 50/4	f	large
49956	57881	329	Московская область, Долгопрудный, Октябрьская, 24а	f	large
49968	57892	341	Московская область, Долгопрудный, Новый бульвар, 21к.3	f	large
49958	57882	331	Россия, Московская область, Долгопрудный, Московское шоссе, 53а	f	large
49957	57882	330	Россия, Московская область, Долгопрудный, Московское шоссе, 53а	f	large
49971	57895	344	Московская область, Долгопрудный, Молодежная улица, 10а	f	large
49970	57894	343	Московская область, Долгопрудный, Молодежная улица, 13	f	large
49976	57901	349	Россия, Московская область, Долгопрудный, Лихачевское шоссе, 24	f	large
49974	57898	347	Россия, Московская область, Долгопрудный, Лихачевское шоссе, 27	f	large
49969	57893	342	Россия, Московская область, Долгопрудный, Лихачевское шоссе, 1	f	large
49982	94493	355	Россия, Московская область, Долгопрудный, микрорайон Хлебниково, Ленинградская улица, 10а	f	medium
49946	94490	319	Московская область, Долгопрудный, Институтский переулок, 9с3	f	large
49947	57872	320	Россия, Московская область, Долгопрудный, Институтский переулок, 1	f	medium
49960	57884	333	Московская область, Долгопрудный, Дирижабельная, 17	f	large
49959	57883	332	Московская область, Долгопрудный, Дирижабельная, 21	f	large
49973	57897	346	Московская область, Долгопрудный, Гранитная, 7	f	large
49972	57896	345	Московская область, Долгопрудный, Гранитная, 6	f	large
49961	57886	334	Московская область, Долгопрудный, Академика Лаврентьева, 29	f	large
49983	94494	356	Московская область, Долгопрудный, 25 -го съезда, 1	f	medium
49856	57782	229	Московская область, Дмитров, микрорайон Махалина, 21, здание Еврохимчистки	f	medium
49850	57776	223	Московская область, Дмитров, Старо-Рогачевская , 34, Дмитровская Автошкола	f	medium
49863	57788	236	Московская область, Дмитров, Профессиональная, административное здание Роспотребнадзора	f	large
49862	57787	235	Московская область, Дмитров, Больничная, административный корпус ДТМО	f	small
49842	57769	215	Россия, Московская область, Дзержинский, улица Лермонтова, 1а	f	large
49839	57766	212	Россия, Московская область, Дзержинский, проезд Пушкина, 2	f	large
49837	57766	210	Россия, Московская область, Дзержинский, проезд Пушкина, 2	f	large
49838	57767	211	Московская область, Дзержинский, Школьная, 5а	f	large
49843	57770	216	Московская область, Дзержинский, Угрешская, 32	f	large
49846	57773	219	Московская область, Дзержинский, Томилинская, 9	f	large
49845	57772	218	Московская область, Дзержинский, Томилинская, 23а	f	large
49844	57771	217	Московская область, Дзержинский, Томилинская, 11а	f	large
49849	57775	222	Московская область, Дзержинский, Спортивная, 1а	f	large
49848	57775	221	Московская область, Дзержинский, Спортивная, 1а	f	large
49841	57768	214	Московская область, Дзержинский, Лесная, 3	f	large
49840	57768	213	Московская область, Дзержинский, Лесная, 3	f	large
49847	57774	220	Московская область, Дзержинский, Лермонтова, 42	f	large
50308	94517	680	Московская область, Дедовск, Ленина, 4, помещение МОУ Дедовская ср.общеоб.школа №4 центральный вход	f	large
50310	58177	682	Московская область, Дедовск, Гагарина, 14, здание Дома культуры	f	large
50926	58624	1300	Московская область, деревня Городна, Центральная, 92А	f	medium
49760	57700	133	Московская область, Воскресенск, микрорайон Центральный, площадь Ленина, 1	f	large
49788	57722	161	Московская область, Воскресенск, Чапаева, 1	f	large
49747	94471	120	Московская область, Воскресенск, Цесиса, 17, МУ Молодежный центр Олимпиец	f	large
49757	57697	130	Московская область, Воскресенск, микрорайон Центральный, Менделеева, 11	f	large
49772	57711	145	Московская область, Воскресенск, микрорайон Лопатинский, Маркина, 3	f	large
49773	57711	146	Московская область, Воскресенск, микрорайон Лопатинский, Маркина, 3	f	large
49790	57724	163	Московская область, Воскресенск, Карла Маркса, 12	f	large
49789	57723	162	Московская область, Воскресенск, Карла Маркса, 12А	f	large
49750	57693	125	Московская область, Воскресенск, Кагана, 22	f	large
49752	57693	123	Московская область, Воскресенск, Кагана, 22	f	large
49749	57692	122	Московская область, Воскресенск, Кагана, 21	f	large
49748	57692	121	Московская область, Воскресенск, Кагана, 21	f	large
49719	57675	92	Московская область, Волоколамск, Катукова, 32	f	large
49727	57683	100	Московская область, Волоколамск, микрорайон Привокзальный, Волоколамская, 59	f	large
49835	57764	208	Московская область, поселок городского типа Власиха, Спортивная, 98	f	large
49834	57764	207	Московская область, поселок городского типа Власиха, Спортивная, 98	f	large
49836	94487	209	Московская область, поселок городского типа Власиха, Лесная, 37	f	large
49830	57698	203	Московская область, Власиха, мкр. Школьный, 10	f	large
49833	57751	206	Московская область, Власиха, Маршала Жукова, 9	f	large
49832	57751	205	Московская область, Власиха, Маршала Жукова, 9	f	large
50778	58547	1152	Московская область, Видное, Ольховая , 5	f	large
51282	58889	1657	Московская область, Верея, Советская площадь, 2	f	large
49715	57671	88	Россия, Московская область, Бронницы, поселок Горка, 17	f	large
49709	57665	82	Московская область, Бронницы, площадь Тимофеева	f	large
49712	57668	85	Московская область, Бронницы, Строительная, 17	f	large
52177	59583	2550	Россия, Московская область, Бронницы, Советская улица, 17	f	large
49710	57666	83	Московская область, Бронницы, Московская, 120	f	large
49711	57667	84	Московская область, Бронницы, Москворецкая, 44	f	large
49714	57670	87	Московская область, Бронницы, Льва Толстого, 8	f	large
49713	57669	86	Московская область, Бронницы, Льва Толстого, 11	f	large
49708	57664	81	Россия, Московская область, Бронницы, Комсомольский переулок, 60	f	large
51610	59139	1984	Россия, Московская область, Балашиха, микрорайон имени Гагарина	f	large
49704	57662	77	Московская область, Балашиха, микрорайон 1 Мая, 33	t	large
49676	57641	49	Россия, Московская область, Балашиха, микрорайон ВНИИПО	f	large
49646	57622	19	Московская область, Балашиха, микрорайон имени Гагарина, 14а	f	large
49645	57622	18	Московская область, Балашиха, микрорайон имени Гагарина, 14а	f	large
49667	57636	40	Московская область, Балашиха, шоссе Энтузиастов, 56	f	large
49663	57634	36	Московская область, Балашиха, шоссе Энтузиастов, 53	f	large
49628	57613	1	Московская область, Балашиха, шоссе Энтузиастов, 38	f	large
49665	57635	38	Московская область, Балашиха, проспект Ленина, 55	f	large
49664	57635	37	Московская область, Балашиха, проспект Ленина, 55	f	large
49637	57617	9	Московская область, Балашиха, проспект Ленина, 20	f	large
49636	57617	10	Московская область, Балашиха, проспект Ленина, 20	f	large
49683	57648	56	Московская область, Балашиха, микрорайон ЦОВБ, 14	f	large
49678	57643	51	Московская область, Балашиха, микрорайон Северный, микрорайон Северный, 63	f	large
49705	57649	78	Московская область, Балашиха, микрорайон Дзержинского, 50	f	large
49686	57649	59	Московская область, Балашиха, микрорайон Дзержинского, 50	f	large
49685	57649	58	Московская область, Балашиха, микрорайон Дзержинского, 50	f	large
49684	57649	57	Московская область, Балашиха, микрорайон Дзержинского, 50	f	large
49689	94469	62	Московская область, Балашиха, микрорайон 1 Мая, микрорайон 1 Мая, 12	f	large
49690	57653	63	Московская область, Балашиха, квартал Абрамцово, 103а	f	medium
49669	57147	42	Московская область, Балашиха, Юлиуса Фучика, 5	f	large
49668	57147	41	Московская область, Балашиха, Юлиуса Фучика, 5	f	large
49666	57147	39	Московская область, Балашиха, Юлиуса Фучика, 5	f	large
49647	57623	20	Московская область, Балашиха, Щелковское шоссе, 102	f	large
49674	57639	47	Московская область, Балашиха, Фадеева, 8	f	large
49673	57639	46	Московская область, Балашиха, Фадеева, 8	f	large
49672	57638	45	Московская область, Балашиха, Фадеева, 8а	f	large
49671	57638	44	Московская область, Балашиха, Фадеева, 8а	f	large
49675	57640	48	Московская область, Балашиха, Твардовского, 19	f	large
49670	57637	43	Московская область, Балашиха, Твардовского, 3	f	large
49657	57629	30	Московская область, Балашиха, Спортивная, 17	f	large
49679	57644	52	Московская область, Балашиха, Сосновый бор, 2	f	large
49644	57621	17	Московская область, Балашиха, Солнечная, 10	f	large
49643	57621	16	Московская область, Балашиха, Солнечная, 10	f	large
49642	57621	15	Московская область, Балашиха, Солнечная, 10	f	large
49641	57621	14	Московская область, Балашиха, Солнечная, 10	f	large
49634	56805	7	Московская область, Балашиха, Советская улица, 4	f	large
49697	57658	70	Московская область, Балашиха, Советская, 11	f	large
49633	57616	6	Московская область, Балашиха, Советская, 17	f	large
49632	57616	5	Московская область, Балашиха, Советская, 17	f	large
49648	57624	21	Московская область, Балашиха, Свердлова, 43	f	large
49693	57655	66	Московская область, Балашиха, микрорайон Заря, Садовая , 10	f	large
49692	57655	65	Московская область, Балашиха, микрорайон Заря, Садовая , 10	f	large
68185	57645	53	Россия, Московская область, Балашиха, микрорайон Салтыковка, Разинское шоссе, 31	f	large
49629	57614	2	Московская область, Балашиха, Разина, 5	f	large
49682	57647	55	Россия, Московская область, Балашиха, микрорайон Салтыковка, Носовихинское шоссе, 230	f	large
49677	57642	50	Московская область, Балашиха, микрорайон Салтыковка, Новая, 6	f	large
49661	57632	34	Московская область, Балашиха, Московский проезд, 9	f	large
49660	57632	33	Московская область, Балашиха, Московский проезд, 9	f	large
49681	57646	54	Московская область, Балашиха, Московская, 18	f	large
49703	94470	76	Московская область, Балашиха, Мирской проезд, 12	t	large
49638	57618	11	Московская область, Балашиха, Мирской проезд, 8	t	large
50172	58067	544	Московская область, Балашиха, Лесопарковая улица, 19	f	medium
49654	57628	27	Московская область, Балашиха, Кудаковского, 7	f	large
49656	57628	29	Московская область, Балашиха, Кудаковского, 7	f	large
49653	57628	26	Московская область, Балашиха, Кудаковского, 7	f	large
49655	57627	28	Московская область, Балашиха, Кудаковского, 1	f	large
49652	57627	25	Московская область, Балашиха, Кудаковского, 1	f	large
49635	56969	8	Московская область, Балашиха, Крупской, 16	f	large
49659	57631	32	Московская область, Балашиха, Крупешина, 9	f	large
49639	57619	12	Московская область, Балашиха, микрорайон Салтыковка, Зеленая, 18	f	large
49658	57630	31	Московская область, Балашиха, Заречная, 3	f	large
49695	57656	68	Московская область, Балашиха, микрорайон имени Гагарина, Гагарина, 2	f	large
52794	60110	3171	Московская область, Шатурский район, деревня Шеино, 53	t	small
49694	57656	67	Московская область, Балашиха, микрорайон имени Гагарина, Гагарина, 2	f	large
49688	57651	61	Россия, Московская область, Балашиха, микрорайон Никольско-Архангельский, Вишняковское шоссе, 9	f	large
49662	57633	35	Московская область, Балашиха, Белякова, 10	f	large
49691	57654	64	Московская область, Балашиха, Акуловский проезд, 1	t	medium
49687	57650	60	Московская область, Балашиха, 9-я Линия, 60	f	large
49706	57663	79	Московская область, Балашиха, 40 лет Победы, 23	f	large
51959	59418	2333	Московская область, поселок Ашукино, Кольцова, 11	f	large
51274	58881	1649	Московская область, Апрелевка, Февральская, 65	f	medium
51273	58881	1648	Московская область, Апрелевка, Февральская, 65	f	large
51276	58883	1651	Московская область, Апрелевка, Ленина, 9	f	large
52691	60018	3068	Московская область, городской округ Черноголовка, деревня Ботово, клуб	t	small
52418	59781	2794	Московская область, городской округ Серпухов, поселок Мирный, помещение Дома культуры	f	medium
51879	94602	2253	Московская область, городской округ Подольск, поселок Кузнечики, 8, Молодежном центре Максимум	f	large
51876	59347	2250	Россия, Московская область, городской округ Подольск, поселок Кузнечики	f	large
111617	58540	1142	Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск, Краснознаменная улица, 8, помещение ДЮСШ	f	\N
50760	58533	1133	Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск, Генерала Шлыкова, 10	f	large
50759	58533	1132	Московская область, городской округ Краснознаменск (ЗАТО), Краснознаменск, Генерала Шлыкова, 10	f	large
50516	58354	888	Россия, Московская область, городской округ Коломна, поселок Радужный	f	large
50515	58353	887	Россия, Московская область, городской округ Коломна, поселок Радужный	f	large
51888	59360	2262	Московская область, городской округ Климовск, поселок Подольской машинно-испытательной станции, 25, здание МУК СДК Надежда	f	large
50048	57962	421	Московская область, городской округ Домодедово, село Ям, Связистов, 5А	t	large
50028	57944	401	Московская область, городской округ Домодедово, поселок Чурилково, ДК Пахра	f	large
51575	59105	1949	Московская область, городской округ Домодедово, садовое товарищество Сосны, 30	f	large
50040	57955	413	Россия, Московская область, городской округ Домодедово, поселок Санатория Подмосковье	f	large
50044	57958	417	Московская область, городской округ Домодедово, село Растуново, Заря, 33	f	large
50043	57958	416	Московская область, городской округ Домодедово, село Растуново, Заря, 33	f	large
50026	57942	399	Московская область, городской округ Домодедово, деревня Повадино, Актовый зал конторы племзавода Повадино	f	small
50046	57960	419	Московская область, городской округ Домодедово, деревня Павловское, Павловский СДК	f	large
50039	57954	412	Московская область, городской округ Домодедово, ОПК БОР, Клуб ОПК Бор	f	large
50031	57947	404	Московская область, городской округ Домодедово, деревня Лямцино, Лямцинская сельская библиотека	t	small
50034	57950	407	Московская область, городской округ Домодедово, деревня Лобаново, Лобановская основная общеобразовательная школа	t	small
50029	57945	402	Россия, Московская область, городской округ Домодедово, село Красный Путь	f	large
50036	57951	409	Россия, Московская область, городской округ Домодедово, село Ильинское	f	medium
51550	59087	1924	Московская область, городской округ Домодедово, деревня Ивановка, 43	f	small
50037	57952	410	Московская область, городской округ Домодедово, деревня Заболотье, Заболотьевский СДК	t	small
50030	57946	403	Московская область, городской округ Домодедово, деревня Житнево, ЦФКС Горизонт	f	large
50045	57959	418	Московская область, городской округ Домодедово, село Добрыниха, Добрыниховский СДК	t	medium
50027	57943	400	Московская область, городской округ Домодедово, деревня Голубино, Голубинский ДК	t	small
50035	57949	408	Московская область, городской округ Домодедово, деревня Гальчино, СДК Барыбино	f	small
50033	57949	406	Московская область, городской округ Домодедово, деревня Гальчино, СДК Барыбино	f	large
50025	57941	398	Московская область, городской округ Домодедово, поселок Вельяминово, Повадинский сельский дом культуры	f	large
52829	60139	3207	Московская область, Щелковский район, Щелково, Малопролетарская, ГПТУ-38	f	large
49707	57657	80	Московская область, городской округ Балашиха, деревня Черное, микрорайон Заря, Ленина, 6	f	large
49696	57657	69	Московская область, городской округ Балашиха, деревня Черное, микрорайон Заря, Ленина, 6	f	large
111600	57403	74	Московская область, городской округ Балашиха, деревня Черное, Агрогородок, 1А	f	medium
68186	57403	72	Московская область, городской округ Балашиха, деревня Черное, Агрогородок, 1А	f	large
49698	57659	71	Московская область, городской округ Балашиха, деревня Федурново, улица Авиарембаза, 7	f	large
49700	57660	73	Московская область, городской округ Балашиха, деревня Соболиха, Новослободская, 15	f	large
49702	57661	75	Московская область, городской округ Балашиха, село Новый Милет, Парковая, 6	f	medium
51145	94576	1520	Московская область, городской округ Молодежный (ЗАТО), поселок Молодежный, МОУ СОШ пос.Молодежный	f	large
52881	60179	3258	Московская область, Щелковский район, поселение Монино, Баранова, 1А, Средняя школа №1	f	large
52880	60179	3257	Московская область, Щелковский район, поселение Монино, Баранова, 1А, Средняя школа №1	f	large
52890	60187	3267	Россия, Московская область, Щелковский район, поселок Юность	f	large
52851	60161	3229	Московская область, Щелковский район, Щелково, микрорайон Щелково-3, улица Супруна, 2, ДОЦ Лесная сказка	f	large
52867	60170	3245	Россия, Московская область, Щелковский район, Щелково, улица Свердлова, 10	f	small
52866	60170	3244	Россия, Московская область, Щелковский район, Щелково, улица Свердлова, 10	f	medium
51833	59313	2207	Россия, Московская область, Щелковский район, Щелково, улица Свердлова, 38	f	large
68184	57625	24	Московская область, Щелковский район, Щелково, улица Свердлова, 51	f	large
68183	57625	23	Московская область, Щелковский район, Щелково, улица Свердлова, 51	f	large
68182	57625	22	Московская область, Щелковский район, Щелково, улица Свердлова, 51	f	large
52813	60125	3191	Россия, Московская область, Щелковский район, Щелково, улица Неделина, 8	f	large
52812	60125	3190	Россия, Московская область, Щелковский район, Щелково, улица Неделина, 8	f	large
49810	57744	183	Россия, Московская область, Щелковский район, Щелково, проспект 60 лет Октября, 8	f	large
49809	57744	182	Россия, Московская область, Щелковский район, Щелково, проспект 60 лет Октября, 8	f	large
52908	60205	3285	Россия, Московская область, Щелковский район, Щелково, площадь Ленина, 8	f	large
52815	60127	3193	Московская область, Щелковский район, Щелково, Школьная, 1, Средняя школа №1	f	large
52834	60144	3212	Московская область, Щелковский район, Щелково, Центральная, 55, Средняя школа №8	f	large
52825	60135	3203	Россия, Московская область, Щелковский район, Щелково, Фряновское шоссе, 70	f	medium
50851	94540	1225	Московская область, Щелковский район, Щелково, Фестивальная, 4, школа № 2	f	large
111653	94678	3220	Московская область, Щелковский район, Щелково, Фабричная, 2	f	\N
52863	60160	3241	Московская область, Щелковский район, Щелково, Урожайная, 37	f	small
52822	60132	3200	Московская область, Щелковский район, Щелково, Талсинская , 10	f	large
52816	60128	3194	Московская область, Щелковский район, Щелково, Талсинская, 60, ЗАО Щёлковская ШТФ	f	large
111654	60167	3240	Московская область, Щелковский район, Щелково, Супруна, 2	f	\N
52852	94679	3230	Московская область, Щелковский район, Щелково, Супруна, Дом офицеров (1-й этаж)	f	large
52853	94680	3231	Московская область, Щелковский район, Щелково, микрорайон Щелково-3, Супруна, 2, Дом офицеров (2-й этаж)	f	large
52850	60159	3228	Московская область, Щелковский район, Щелково, микрорайон Щелково-3, Супруна, Дом офицеров	f	large
52839	60148	3217	Россия, Московская область, Щелковский район, Щелково, Пролетарский проспект, 6	f	large
52827	60137	3205	Московская область, Щелковский район, Щелково, Пролетарский проспект, 14, Клуб Ровесник	f	large
52821	60131	3199	Московская область, Щелковский район, Щелково, Полевая, 12б, Помещение ЖЭУ-4	f	large
52833	60143	3211	Московская область, Щелковский район, Щелково, Пионерская, 19, НОУ &quot;&quot;Колледж экономики и прав&quot;&quot;	f	large
52837	60147	3215	Московская область, Щелковский район, Щелково, Парковая, 18, Щелковский лицей	f	large
52814	60126	3192	Московская область, Щелковский район, Щелково, Неделина, 18 А, ГДК Спутник	f	large
81428	55809	590	Москва, Яблочкова, 10	f	large
52818	60130	3196	Московская область, Щелковский район, Щелково, Комсомольская , 3а, ЗАО "Новые Технологии"	f	large
52820	60129	3198	Московская область, Щелковский район, Щелково, Комсомольская, 5а, Средняя школа №3	f	large
52819	60129	3197	Московская область, Щелковский район, Щелково, Комсомольская, 5а, Средняя школа №3	f	large
52817	60129	3195	Московская область, Щелковский район, Щелково, Комсомольская, 5а, Средняя школа №3	f	large
52854	60162	3232	Московская область, Щелковский район, Щелково, микрорайон Щелково-3, Институтская, средняя школа №11 	f	large
52828	60138	3206	Московская область, Щелковский район, Щелково, Заречная, 82, Республиканский политех.колледж	f	small
52856	60164	3234	Московская область, Щелковский район, Щелково, Гагарина, 1а	f	large
52855	60163	3233	Московская область, Щелковский район, Щелково, микрорайон Щелково-3, Гагарина, Средняя школа №12	f	large
52861	60166	3239	Московская область, Щелковский район, Щелково, Беляева, 14, Средняя школа №13	t	large
52860	60166	3238	Московская область, Щелковский район, Щелково, Беляева, 14, Средняя школа №13	f	large
52859	60166	3237	Московская область, Щелковский район, Щелково, Беляева, 14, Средняя школа №13	f	large
52858	60166	3236	Московская область, Щелковский район, Щелково, Беляева, 14, Средняя школа №13	f	large
52912	60210	3289	Московская область, Щелковский район, поселок Фряново, Механизаторов, 12, Средняя школа №1	f	large
52911	60209	3288	Московская область, Щелковский район, поселок городского типа Фряново, Текстильщиков, 3	f	large
52909	60207	3286	Московская область, Щелковский район, поселок городского типа Фряново, Первомайская, 12, Средняя школа №2	f	large
52905	60202	3282	Московская область, Щелковский район, село Трубино, Сельский дом культуры села Трубино	f	medium
52846	60155	3224	Московская область, Щелковский район, деревня Серково, Средняя школа деревни Серково	t	small
52894	60191	3271	Московская область, Щелковский район, поселок Свердловский, Набережная, 5, школа	f	large
52893	60190	3270	Россия, Московская область, Щелковский район, поселок городского типа Свердловский, улица Дзержинского, 1	f	large
52847	60156	3225	Россия, Московская область, Щелковский район, поселок городского типа Свердловский, Советская улица, 1	f	medium
52904	60201	3281	Россия, Московская область, Щелковский район, село Петровское	f	medium
52899	60196	3276	Московская область, Щелковский район, деревня Первая Алексеевка, ООО АРСУ, Дом отдыха Алексеевка, здание столовой	t	small
52902	60199	3279	Московская область, Щелковский район, деревня Огуднево, Сельский дом культуры деревни Огуднево	f	large
52872	60174	3249	Московская область, Щелковский район, деревня Оболдино, 60, Оболдинский СДК Загорянского культурно-досугового центра	t	small
52616	59957	2992	Россия, Московская область, Щелковский район, деревня Новофрязино, Окружной проезд, 2а	f	medium
52886	60182	3263	Московская область, Щелковский район, деревня Никифорово, Сельский дом культуры	t	medium
52875	60176	3252	Московская область, Щелковский район, поселок Монино, 1-я Дачная, 2, Средняя школа №2	f	large
52907	60204	3284	Московская область, Щелковский район, деревня Мишнево, Сельский дом культуры	t	small
52891	60188	3268	Московская область, Щелковский район, деревня Мизиново, Сельский дом культуры деревни Мизиново	t	medium
52892	60189	3269	Московская область, Щелковский район, поселок Медное-Власово, Административное здание детской психиатрической больницы №11	t	small
52883	60181	3260	Московская область, Щелковский район, деревня Медвежьи Озера, Юбилейная, 5, ДК МУ Медвежье-Озерская ЦКС	f	large
52885	60181	3262	Московская область, Щелковский район, деревня Медвежьи Озера, Юбилейная, 5, ДК МУ Медвежье-Озерская ЦКС	f	large
52884	60181	3261	Московская область, Щелковский район, деревня Медвежьи Озера, Юбилейная, 5, ДК МУ Медвежье-Озерская ЦКС	f	large
51799	59290	2173	Россия, Московская область, Щелковский район, деревня Медвежьи Озера, Садовая улица, 2	f	large
52906	60203	3283	Россия, Московская область, Щелковский район, деревня Литвиново	f	large
52864	60168	3242	Россия, Московская область, Щелковский район, поселок Краснознаменский	t	large
52896	60193	3273	Московская область, Щелковский район, деревня Корпуса, Помещение библиотеки санатория Монино	f	medium
52865	60169	3243	Московская область, Щелковский район, поселок Загорянский, Школьная, 27, Средняя школа №1	f	medium
52868	60171	3246	Московская область, Щелковский район, поселок Загорянский, Сергея Лазо, 7	t	large
52137	94620	2510	Московская область, Щелковский район, поселок Загорянский, Комсомольская, 17	f	large
52136	94619	2509	Московская область, Щелковский район, поселок Загорянский, Комсомольская, 16	f	large
52871	60173	3248	Московская область, Щелковский район, поселок Загорянский, Димитрова, 47, Помещение домоуправления	f	large
52910	60208	3287	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, улица Текстильщиков, 4	f	large
111655	94681	3254	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, улица Сергея Лазо, 7	f	\N
52874	60175	3251	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, Комсомольская улица, 10	f	large
52873	60175	3250	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, Комсомольская улица, 10	f	large
52600	59946	2976	Россия, Московская область, Щелковский район, поселок городского типа Загорянский, Комсомольская улица, 19	f	large
52870	60172	3247	Московская область, Щелковский район, поселок городского типа Загорянский, Димитрова, 31, Детская музыкальная школа	f	medium
52914	60212	3291	Московская область, Щелковский район, деревня Еремино, Сельский дом культуры деревни Ерёмино	f	small
52903	60200	3280	Московская область, Щелковский район, село Душоново, Сельский дом культуры села Душоново	t	small
52882	60180	3259	Московская область, Щелковский район, деревня Долгое Ледово, Московский областной с/х колледж	t	medium
52913	60211	3290	Московская область, Щелковский район, деревня Головино, Сельский дом культуры деревни Головино	t	small
52901	94682	3278	Московская область, Щелковский район, деревня Воря-Богородское, Административное здание дома отдыха Щелково	t	small
52915	60213	3292	Московская область, Щелковский район, деревня Булаково, Сельский дом культуры деревни Булаково	t	small
52898	60195	3275	Московская область, Щелковский район, деревня Богослово, Сельский дом культуры деревни Богослово	f	medium
52889	60186	3266	Россия, Московская область, Щелковский район, поселок Биокомбината	f	large
52888	60185	3265	Россия, Московская область, Щелковский район, поселок Биокомбината	f	large
52887	60184	3264	Московская область, Щелковский район, село Анискино, Центральная, 19, Сельский ДК села Анискино	f	medium
49738	57472	111	Московская область, Шаховской район, деревня Шестаково, 7	f	medium
52801	94670	3178	Московская область, Шаховской район, поселок Шаховская, Лесная, 23	f	medium
52798	94667	3175	Московская область, Шаховской район, поселок Шаховская, 1-я Советская улица, 21	f	large
52799	94668	3176	Московская область, Шаховской район, поселок Шаховская, 1-й Советский переулок, 11	f	large
52802	94671	3179	Московская область, Шаховской район, поселок городского типа Шаховская, Южная, 32	f	medium
52797	94666	3174	Московская область, Шаховской район, поселок городского типа Шаховская, Комсомольская улица, 10Б	f	large
52800	94669	3177	Московская область, Шаховской район, поселок городского типа Шаховская, 1-я Советская улица, 61	f	large
52807	94674	3184	Московская область, Шаховской район, деревня Степаньково, Промышленная, 36, микрорайон18А	f	large
52809	94675	3186	Московская область, Шаховской район, село Середа, Школьная, 13, ул. Льнозаводскаядом 12	f	large
52803	94672	3180	Московская область, Шаховской район, село Раменье, Центральная, 1А	f	large
52805	60116	3182	Россия, Московская область, Шаховской район, деревня Новоникольское	f	medium
52808	60120	3185	Московская область, Шаховской район, деревня Муриково, Микрорайон, 19	f	large
52804	60115	3181	Московская область, Шаховской район, деревня Ивашково, Новая, 14	f	large
52810	94676	3187	Московская область, Шаховской район, деревня Дубранивка, Школьная, 3, Школьная, 9	f	medium
52811	94677	3188	Московская область, Шаховской район, деревня Дор, Микрорайон, 14	f	medium
52806	94673	3183	Московская область, Шаховской район, село Белая Колпь, Центральная, 14, Центральная, дом 12	f	medium
52795	60111	3172	Московская область, Шатурский район, пос. санатория Озеро Белое, 8	f	large
83593	57140	2776	Москва, Юровская , 97	f	large
52768	60083	3145	Россия, Московская область, Шатурский район, поселок Шатурторф	f	large
52769	60084	3146	Московская область, Шатурский район, поселок Шатурторф, Интернациональная, 24	f	large
50675	58471	1047	Россия, Московская область, Шатурский район, Шатура, улица Дача Винтера, 3	f	large
50674	58471	1046	Россия, Московская область, Шатурский район, Шатура, улица Дача Винтера, 3	f	large
50673	58471	1045	Россия, Московская область, Шатурский район, Шатура, улица Дача Винтера, 3	f	large
52759	60074	3136	Россия, Московская область, Шатурский район, Шатура, проспект Маршала Борзова, 4/34	f	large
52755	60071	3132	Россия, Московская область, Шатурский район, Шатура, проспект Ильича, 39/1	f	large
52751	60067	3128	Россия, Московская область, Шатурский район, Шатура, площадь Ленина, 1	f	large
52760	60075	3137	Московская область, Шатурский район, Шатура, Спортивная, 3	f	large
52758	60073	3135	Московская область, Шатурский район, Шатура, Спортивная, 9А	f	large
52764	60079	3141	Московская область, Шатурский район, Шатура, Новый Тупик, в помещении общежития ПУ-66	f	small
52752	60068	3129	Россия, Московская область, Шатурский район, Шатура, Московская улица, 10	f	large
52762	60077	3139	Россия, Московская область, Шатурский район, Шатура, Конный проезд, 4	f	large
52757	60072	3134	Московская область, Шатурский район, Шатура, Жарова, 16	f	large
52756	60072	3133	Московская область, Шатурский район, Шатура, Жарова, 16	f	large
52791	60106	3168	Московская область, Шатурский район, село Шарапово, Центральная, 9	f	medium
52777	60092	3154	Московская область, Шатурский район, поселок Черусти, Вокзальная, 1	f	small
52776	60091	3153	Московская область, Шатурский район, поселок городского типа Черусти, Вокзальная, 14	f	large
52781	60096	3158	Московская область, Шатурский район, поселок Центральной усадьбы совхоза "Мир", 6А	f	large
52784	60099	3161	Московская область, Шатурский район, поселок Туголесский Бор, Горького, 11	f	large
52787	60102	3164	Московская область, Шатурский район, село Середниково, 265	f	medium
52766	60081	3143	Московская область, Шатурский район, поселок Северная Грива, 34	f	small
52796	60112	3173	Московская область, Шатурский район, поселок Радовицкий, Клубная, 2	f	large
52793	60109	3170	Московская область, Шатурский район, село Пышлицы, 38	f	medium
52792	60108	3169	Московская область, Шатурский район, село Пышлицы, д.55А	f	medium
52778	60093	3155	Московская область, Шатурский район, поселок Пустоши, Школьная, 1	f	medium
52779	60094	3156	Московская область, Шатурский район, село Пустоша, Парковая, 2	f	small
52786	60101	3163	Московская область, Шатурский район, деревня Пестовская, 69	f	small
52783	60098	3160	Московская область, Шатурский район, поселок Осаново-Дубовое, Клубная, 1	f	medium
52767	60082	3144	Московская область, Шатурский район, деревня Новосидориха, 3	f	small
52772	60087	3149	Московская область, Шатурский район, поселок городского типа Мишеронский, Советская, 13А	f	large
52771	60086	3148	Московская область, Шатурский район, поселок городского типа Мишеронский, Луначарского, 1	f	large
52782	60097	3159	Московская область, Шатурский район, деревня Лузгарино, 39Б	t	small
52770	60085	3147	Московская область, Шатурский район, деревня Левошево, 37А	f	large
52780	60095	3157	Московская область, Шатурский район, село Кривандино, Центральная, 19	f	medium
52788	60103	3165	Московская область, Шатурский район, деревня Дубровка, 35	f	small
52785	60100	3162	Московская область, Шатурский район, село Дмитровский Погост, Пролетарская, 1	f	large
52790	60105	3167	Московская область, Шатурский район, деревня Дерзсковская, 23	f	small
52789	60104	3166	Московская область, Шатурский район, деревня Губино, 24А	f	small
52775	60090	3152	Московская область, Шатурский район, село Власово, 19А	f	small
52774	60089	3151	Московская область, Шатурский район, деревня Бордуки, 94	t	small
52773	60088	3150	Россия, Московская область, Шатурский район, поселок Бакшеево	f	large
52746	94665	3123	Россия, Московская область, Чеховский район, село Шарапово	f	large
52715	60037	3092	Россия, Московская область, Чеховский район, Чехов, улица Полиграфистов, с30	f	large
52714	60037	3091	Россия, Московская область, Чеховский район, Чехов, улица Полиграфистов, с30	f	large
52723	60043	3100	Московская область, Чеховский район, Чехов, улица Гарнаева, 7, Школа №6	t	medium
52720	60041	3097	Россия, Московская область, Чеховский район, Чехов, улица Гагарина, 112	f	large
52719	60040	3096	Россия, Московская область, Чеховский район, Чехов, улица Гагарина, 34	f	large
50847	94475	1221	Московская область, Чеховский район, Чехов, Чехова, 3а, ДЮСШ	f	large
50848	94475	1222	Московская область, Чеховский район, Чехов, Чехова, 3а, ДЮСШ	f	large
52702	60029	3079	Московская область, Чеховский район, Чехов, Чехова, 27, Центр развития творчества	f	large
52701	60028	3078	Московская область, Чеховский район, Чехов, Чехова, 8А,  Гимназия №2	f	large
111650	60035	3089	Россия, Московская область, Чеховский район, Чехов, Московская улица, 104	f	\N
52711	60034	3087	Россия, Московская область, Чеховский район, Чехов, Молодежная улица, 6	f	large
52712	60034	3088	Россия, Московская область, Чеховский район, Чехов, Молодежная улица, 6	f	large
52708	60033	3085	Московская область, Чеховский район, Чехов, Мира, 9, Гимназия №7	f	large
52709	60033	3086	Московская область, Чеховский район, Чехов, Мира, 9, Гимназия №7	f	large
52707	60032	3084	Московская область, Чеховский район, Чехов, Лопасненская, 1/1, Средняя общеобразовательная школа №3	f	large
52706	60032	3083	Московская область, Чеховский район, Чехов, Лопасненская, 1/1, Средняя общеобразовательная школа №3	f	large
52705	60032	3082	Московская область, Чеховский район, Чехов, Лопасненская, 1/1, Средняя общеобразовательная школа №3	f	large
52713	60036	3090	Россия, Московская область, Чеховский район, Чехов, Земская улица, 2	f	large
52741	60056	3118	Московская область, Чеховский район, деревня Чепелево, Вокзальная, 14, ДК Заря	f	large
52736	60054	3113	Московская область, Чеховский район, село Талалихино, ДК Фортуна	f	medium
52745	60060	3122	Московская область, Чеховский район, село Стремилово, Платонова, 42, Основная общеобразовательная школа	f	medium
52725	94663	3102	Россия, Московская область, Чеховский район, поселок городского типа Столбовая	f	large
52724	94662	3101	Россия, Московская область, Чеховский район, поселок городского типа Столбовая	f	large
52728	60048	3105	Московская область, Чеховский район, село Новый Быт, Новая, 8А, ДК Меридиан	f	large
52735	94664	3112	Московская область, Чеховский район, село Молоди, 5, адрес помещения для голосования: (здание школы с. Молоди), адрес УИК: (здание ДК Радуга с. Молоди)	f	medium
52730	60050	3107	Московская область, Чеховский район, поселок Мещерское, 15, Администрация сельского поселения Любучанское	f	large
52743	60058	3120	Московская область, Чеховский район, деревня Манушкино, 28, ДК Русь	f	large
52734	60052	3111	Московская область, Чеховский район, поселок Любучаны, Заводская, 17, Средняя общеобразовательная школа	f	large
52733	60052	3110	Московская область, Чеховский район, поселок Любучаны, Заводская, 17, Средняя общеобразовательная школа	f	large
52744	60059	3121	Московская область, Чеховский район, село Дубна, 30, ДК Мечта	f	large
52742	60057	3119	Московская область, Чеховский район, деревня Гришенки, Русское поле, 8, Администрация сельского поселения Стремиловское	f	medium
52727	60047	3104	Московская область, Чеховский район, поселок Васькино, 4, ДК Каскад	f	large
52583	59931	2959	Московская область, Талдомский район, село Темпы, Шоссейная, 6, администрация сп Темповое	f	small
52557	59902	2931	Россия, Московская область, Талдомский район, Талдом, улица Зины Голицыной	f	large
52556	59901	2930	Московская область, Талдомский район, Талдом, микрорайон Юбилейный	f	large
52558	59903	2932	Московская область, Талдомский район, Талдом, микрорайон ПМК-21, 1	f	large
52555	59900	2929	Московская область, Талдомский район, Талдом, Микрорайон Юбилейный, 47, МОУ ТСОШ № 2	f	large
52573	59919	2947	Московская область, Талдомский район, поселок городского типа Северный, Клубная, 2, МУ Центральный Дом культуры Северный	f	large
52577	59924	2952	Московская область, Талдомский район, деревня Павловичи, 32, МОУ Павловическая средняя общеобразовательная школа	f	medium
52575	59922	2950	Московская область, Талдомский район, деревня Новоникольское, 10а, МУ Новоникольский центральный Дом культуры	f	medium
52576	59923	2951	Московская область, Талдомский район, село Новогуслево, Садовая, 2, администрация сп Гуслевское	f	medium
52540	59885	2914	Россия, Московская область, Ступинский район, поселок городского типа Михнево	f	large
52578	59925	2953	Московская область, Талдомский район, село Николо-Кропотки, 98, МОУ Николо-кропоткинская средняя общеобразовательная школа	f	medium
52581	59929	2957	Московская область, Талдомский район, деревня Кошелево, 66, центральный Дом культуры	f	medium
52580	59928	2956	Московская область, Талдомский район, село Квашенки, 90, МОУ Квашёнковская средняя общеобразовательная школа	f	medium
52566	59914	2942	Россия, Смоленская область, Гагаринский район, поселок Запрудня	f	large
52569	59916	2944	Московская область, Талдомский район, поселок городского типа Запрудня, Пролетарский переулок, 28А	f	large
52565	59912	2940	Московская область, Талдомский район, поселок городского типа Запрудня, МУ Дворец культуры "Прогресс", 29	f	large
52567	59913	2941	Московская область, Талдомский район, поселок городского типа Запрудня, Ленина, 19	f	large
52570	59915	2943	Московская область, Талдомский район, поселок городского типа Запрудня, Карла Маркса, 4, МОУ ЗСОШ №2	f	large
52568	94649	2945	Московская область, Талдомский район, поселок городского типа Запрудня, К.Маркса, 14, Гос. обр уч нач. проф. Обр. ПУ № 48 МО, актовый зал	f	large
52571	59918	2946	Московская область, Талдомский район, поселок Запрудня, 47, МОУ Запрудненская школа-интернат 3-8 вида	f	small
111646	59927	2955	Московская область, Талдомский район, деревня Ермолино, 20а, МУ Ермолинский центральный Дом культуры 2-ой этаж	f	\N
52579	59911	2954	Московская область, Талдомский район, деревня Ермолино, 20А, МУ Ермолинский центральный Дом культуры	f	medium
52563	59909	2938	Россия, Московская область, Талдомский район, поселок городского типа Вербилки	f	large
52564	59908	2937	Московская область, Талдомский район, поселок городского типа Вербилки, Советская, 11	f	large
52562	59910	2939	Московская область, Талдомский район, поселок городского типа Вербилки, Рубцова, 2	f	large
52582	59930	2958	Московская область, Талдомский район, деревня Великий Двор, 59А, Великодворский сельский Дом культуры	f	small
52536	59880	2910	Московская область, Ступинский район, село Шугарово, Совхозная, 15	f	large
52554	59899	2928	Московская область, Ступинский район, село Хатунь, Школьная, 2а	f	medium
52544	59889	2918	Московская область, Ступинский район, поселок Усады, Пролетарская, 12	f	large
52545	59890	2919	Московская область, Ступинский район, село Татариново, Ленина, 4	f	large
50865	94565	1239	Россия, Московская область, Ступинский район, Ступино, улица Чайковского, 2/11	f	large
50864	94565	1238	Россия, Московская область, Ступинский район, Ступино, улица Чайковского, 2/11	f	large
52528	59872	2902	Россия, Московская область, Ступинский район, Ступино, улица Калинина, 1	f	large
52526	59870	2900	Россия, Московская область, Ступинский район, Ступино, улица Андропова, 32	f	large
52525	94648	2899	Московская область, Ступинский район, Ступино, проспект Победы, 18/43, Дворец культуры	f	large
52527	59871	2901	Россия, Московская область, Ступинский район, Ступино, проспект Победы, 25	f	large
52523	59867	2897	Московская область, Ступинский район, Ступино, Чайковского, 42	f	large
52522	59867	2896	Московская область, Ступинский район, Ступино, Чайковского, 42	f	large
52514	59860	2888	Московская область, Ступинский район, Ступино, Тимирязева, 50	f	large
52513	59860	2887	Московская область, Ступинский район, Ступино, Тимирязева, 50	f	large
52529	59873	2903	Московская область, Ступинский район, Ступино, Службина, 8	f	large
52517	94646	2891	Московская область, Ступинский район, Ступино, Куйбышева, 55, авиационно-металлургический техникум	f	large
52515	59861	2889	Московская область, Ступинский район, Ступино, Куйбышева, 61	f	large
52524	59868	2898	Московская область, Ступинский район, Ступино, Андропова, 61/11	f	large
52508	59856	2882	Московская область, Ступинский район, Ступино, Авиаторов, 10	f	large
52533	59877	2907	Московская область, Ступинский район, село Старая Ситня, Центральная, 11А	f	large
52534	59878	2908	Московская область, Ступинский район, село Ситне-Щелканово, Дружбы, 4	f	large
52553	59898	2927	Московская область, Ступинский район, село Семеновское, 40 лет Победы, 37	f	large
52543	59888	2917	Россия, Московская область, Ступинский район, поселок городского типа Михнево	f	large
52542	59887	2916	Россия, Московская область, Ступинский район, поселок городского типа Михнево	f	large
52541	59886	2915	Московская область, Ступинский район, поселок городского типа Михнево, Московская, 26	f	large
52548	59893	2922	Московская область, Ступинский район, село Мещерино, Новая, 1а	f	medium
52537	59881	2911	Московская область, Ступинский район, поселок Малино, Промышленная, 1	f	large
52532	59876	2906	Россия, Московская область, Ступинский район, село Лужники	f	large
52551	59896	2925	Московская область, Ступинский район, деревня Леонтьево, Центральная, 19	f	large
52552	59897	2926	Московская область, Ступинский район, село Ивановское, Школьная, 11	f	medium
52535	59879	2909	Московская область, Ступинский район, поселок городского типа Жилево, Комсомольская, 3А	f	large
52539	59884	2913	Московская область, Ступинский район, деревня Дубнево, Новые дома, 18	f	large
52531	59875	2905	Россия, Московская область, Ступинский район, деревня Городище	f	large
52538	59883	2912	Россия, Московская область, Ступинский район, село Березнецово	f	large
52550	59895	2924	Московская область, Ступинский район, деревня Алфимово, Новоселов, 3	f	large
52546	59891	2920	Московская область, Ступинский район, село Аксиньино, Шоссейная, 12	f	medium
52480	59835	2856	Московская область, Солнечногорский район, сельское поселение Кривцовское, деревня Кривцово	f	large
52487	94632	2863	Россия, Московская область, Солнечногорский район, деревня Черная Грязь	f	large
52496	94639	2870	Московская область, Солнечногорский район, деревня Чашниково, микрорайон Новые дома, помещение актового зала административного корпуса Закрытого акционерного общества Агроплеменная фирма «Искра»,	f	large
111643	59828	2848	Московская область, Солнечногорский район, деревня Тимоново, МОУ Тимоновская средняя общеобразовательная школа	f	\N
52476	59831	2852	Московская область, Солнечногорский район, Солнечногорск-7, Здание 139 Дома культуры РА	f	large
52475	59831	2851	Московская область, Солнечногорский район, Солнечногорск-7, Здание 139 Дома культуры РА	f	large
52477	59832	2853	Московская область, Солнечногорский район, Солнечногорск	f	large
52462	59818	2838	Россия, Московская область, Солнечногорский район, Солнечногорск, микрорайон Рекинцо-1	f	large
52461	59818	2837	Россия, Московская область, Солнечногорский район, Солнечногорск, микрорайон Рекинцо-1	f	large
52460	59817	2836	Московская область, Солнечногорский район, Солнечногорск	f	large
52459	59817	2835	Московская область, Солнечногорский район, Солнечногорск	f	large
52547	59892	2921	Московская область, Солнечногорский район, Солнечногорск, Школьная улица, 6	f	large
52470	59826	2846	Россия, Московская область, Солнечногорский район, Солнечногорск, Школьная улица, 1	f	large
52467	59823	2843	Московская область, Солнечногорский район, Солнечногорск, Стеклозаводская, Здание спортпавильона ОАО Солстек	f	medium
52465	59821	2841	Московская область, Солнечногорский район, Солнечногорск, Советская, 3	f	large
52466	59822	2842	Московская область, Солнечногорский район, Солнечногорск, Почтовая, 9	f	large
52464	59820	2840	Московская область, Солнечногорский район, Солнечногорск, Почтовая, 33	f	large
52468	59824	2844	Россия, Московская область, Солнечногорский район, Солнечногорск, Обуховская улица, 9а	f	large
52463	59819	2839	Московская область, Солнечногорский район, Солнечногорск, Мкр. Рекинцо, Здание МУП СГХ	f	large
52455	59813	2831	Московская область, Солнечногорский район, Солнечногорск, Красная, 113	f	large
52454	59813	2830	Московская область, Солнечногорский район, Солнечногорск, Красная, 113	f	large
52453	59812	2829	Московская область, Солнечногорский район, Солнечногорск, Красная, 176	f	large
52458	59816	2834	Московская область, Солнечногорский район, Солнечногорск, Дзержинского, 21/19	f	large
52456	59814	2832	Московская область, Солнечногорский район, Солнечногорск, Дзержинского, 5	f	large
52500	59848	2874	Московская область, Солнечногорский район, деревня Соколово, ДК	f	small
52497	94640	2871	Московская область, Солнечногорский район, поселок Смирновка, помещение администрации сельского поселения Смирновское	f	large
111644	59839	2860	Московская область, Солнечногорский район, деревня Середниково, в здании Манежа усадьбы Середниково	t	\N
52450	59809	2826	Московская область, Солнечногорский район, поселок Ржавки, здание школы	f	large
52451	59810	2827	Московская область, Солнечногорский район, поселок городского типа Ржавки	f	large
52493	94637	2868	Московская область, Солнечногорский район, деревня Радумля, микрорайон Механического завода № 1, 16, здание администрации сельского поселения Пешковское	f	large
52488	94633	2864	Московская область, Солнечногорский район, деревня Поярково, в помещении муниципального образовательного учреждения Поярковская начальная школа	t	large
52448	59807	2824	Россия, Московская область, Солнечногорский район, поселок городского типа Поварово	f	large
52449	94630	2825	Московская область, Солнечногорский район, поселок городского типа Поварово, микрорайон Поваровка, помещение Дома культуры «Геофизик»	f	large
52447	59806	2823	Московская область, Солнечногорский район, Поварово, МКР№2	f	large
52446	59805	2822	Московская область, Солнечногорский район, поселок городского типа Поварово, МЕХЛЕСХОЗА, 1	f	large
52501	94643	2875	Московская область, Солнечногорский район, деревня Новая, в помещении муниципального общеобразовательного учреждения средняя общеобразовательная школа Лесные озера	f	medium
52187	59593	2560	Московская область, Солнечногорский район, садовое товарищество Никольское, 5	f	medium
52444	59803	2820	Московская область, Солнечногорский район, Менделеево, улица Куйбышева, 11	f	large
52442	59801	2818	Россия, Московская область, Солнечногорский район, поселок городского типа Менделеево, улица Куйбышева	f	large
50473	58313	845	Московская область, Солнечногорский район, Малеевка, Центральная усадьба, 17	f	large
52494	94638	2869	Россия, Московская область, Солнечногорский район, поселок Майдарово	f	large
52443	59802	2819	Московская область, Солнечногорский район, деревня Льялово, здание дома спорта и творчества	f	medium
52499	94642	2873	Россия, Московская область, Солнечногорский район, деревня Лыткино	t	medium
52486	59841	2862	Московская область, Солнечногорский район, поселок Лунево	t	large
52491	94636	2867	Московская область, Солнечногорский район, деревня Ложки, в помещении Центрального сельского Дома культуры	f	large
52479	59834	2855	Московская область, Солнечногорский район, деревня Кривцово	f	large
52481	59836	2857	Московская область, Солнечногорский район, деревня Замятино, сельское поселение Кривцовское, Здание Дома культуры	t	medium
52490	94635	2866	Московская область, Солнечногорский район, деревня Жуково, Сельский дом культуры	f	medium
52441	59800	2817	Московская область, Солнечногорский район, деревня Голубое, Здание больницы	f	large
52482	59837	2858	Московская область, Солнечногорский район, деревня Брехово, Здание школы д. Брехово	t	medium
52484	94631	2859	Московская область, Солнечногорский район, деревня Благовещенка, Липовая Аллея, 1, в помещении магазина «М 5» (собственник Общество с ограниченной ответственностью «Де-Флорес»)	t	medium
52440	59799	2816	Московская область, Солнечногорский район, поселок Андреевка, 1, здание Дома Культуры	f	large
52439	59798	2815	Московская область, Солнечногорский район, поселок Андреевка, 1, здание школы	t	large
52437	59798	2813	Московская область, Солнечногорский район, поселок Андреевка, 1, здание школы	t	large
52438	59798	2814	Московская область, Солнечногорский район, поселок Андреевка, 1, здание школы	f	large
52436	59797	2812	Московская область, Солнечногорский район, село Алабушево, здание школы	t	large
52971	60249	3348	Россия, Московская область, Солнечногорский район, село Алабушево, Первомайская улица, 16	f	large
52973	60249	3350	Россия, Московская область, Солнечногорский район, село Алабушево, Первомайская улица, 16	f	large
52972	60249	3349	Россия, Московская область, Солнечногорский район, село Алабушево, Первомайская улица, 16	f	large
52624	59963	3000	Московская область, Солнечногорский район, село Алабушево, Первомайская, 6	f	large
52623	59963	2999	Московская область, Солнечногорский район, село Алабушево, Первомайская, 6	f	large
49945	57848	318	Московская область, Солнечногорский район, село Алабушево, Первомайская, 3	f	small
52407	59770	2783	Московская область, Серпуховский район, сельское поселение Данковское, ц\\у Совхоза Серпуховский, МОУ Начальная школа-детский сад Улыбка	f	medium
52339	59720	2716	Россия, Орловская область, Знаменский район, поселок Успенский	f	large
52427	59788	2803	Московская область, Серпуховский район, поселок кирпичного завода, сельское поселение Липицкое, ДК Юность	f	medium
52397	59760	2773	Московская область, Серпуховский район, поселок дома отдыха Авангард, сельское поселение Васильевское, помещение Центра Досуга	f	medium
52400	59763	2776	Московская область, Серпуховский район, деревня Шарапова Охота, МОУ Шарапово-Охотская средняя общеобразовательная школа	f	medium
52403	59766	2779	Московская область, Серпуховский район, деревня Фенино, помещение библиотеки	f	small
52405	59768	2781	Московская область, Серпуховский район, деревня Турово, помещение администрации Туровского с/о	f	medium
52412	59775	2788	Московская область, Серпуховский район, деревня Съяново-2, СДК Ровесник	f	small
52402	59765	2778	Московская область, Серпуховский район, деревня Старые Кузьменки, помещение библиотеки	f	small
51891	59363	2265	Московская область, Серпуховский район, деревня Рогово, 1а, здание МУК СДК Юбилейный	f	large
52411	59774	2787	Московская область, Серпуховский район, деревня Райсеменовское, МОУ Райсеменовская средняя общеобразовательная школа	f	medium
52415	59778	2791	Московская область, Серпуховский район, деревня Пущино, помещение ФАПа	t	small
52423	59785	2799	Московская область, Серпуховский район, деревня Прончищево, помещение клуба	t	small
52433	59794	2809	Московская область, Серпуховский район, поселок городского типа Пролетарский, Администрация городского поселения Пролетарский	f	large
52432	59793	2808	Московская область, Серпуховский район, поселок городского типа Пролетарский, помещение администрации городского поселения Пролетарский	f	large
52428	59789	2804	Московская область, Серпуховский район, деревня Подмоклово, помещение СДК	f	small
111642	59792	2807	Московская область, Серпуховский район, поселок городского типа Оболенск, ДК Оболенск	f	\N
52430	59791	2806	Россия, Московская область, Серпуховский район, поселок городского типа Оболенск	f	large
52398	59761	2774	Московская область, Серпуховский район, деревня Нефедово, помещение ФАПа	t	small
52429	59790	2805	Московская область, Серпуховский район, деревня Лукьяново, МОУ Липицкая средняя общеобразовательная школа	f	small
52425	59786	2801	Россия, Московская область, Серпуховский район, село Липицы	f	large
52424	59786	2800	Россия, Московская область, Серпуховский район, село Липицы	f	medium
52417	59780	2793	Московская область, Серпуховский район, деревня Калиново, помещение библиотеки	f	small
52399	59762	2775	Московская область, Серпуховский район, деревня Ивановское, помещение ФАПа	f	small
52416	59779	2792	Московская область, Серпуховский район, деревня Дракино, МУК Дракинский центр досуга	f	small
52409	59772	2785	Московская область, Серпуховский район, местечко Данки, помещение администрации Данковского с/п	f	medium
52406	59769	2782	Московская область, Серпуховский район, местечко Данки, МОУ Данковская средняя общеобразовательная школа	f	medium
52413	59776	2789	Московская область, Серпуховский район, деревня Глазово, помещение библиотеки	f	medium
52414	59777	2790	Московская область, Серпуховский район, деревня Гавшино, помещение СДК	f	small
52401	59764	2777	Московская область, Серпуховский район, деревня Васильевское, помещение администрации Васильевского сельского поселения	f	large
52408	59771	2784	Московская область, Серпуховский район, деревня Бутурлино, сельское поселение Данковское, помещение администрации Данковского сельского поселения	f	small
52421	59783	2797	Россия, Московская область, Серпуховский район	f	large
52420	59782	2796	Россия, Московская область, Серпуховский район, поселок Большевик, улица Ленина, 36	f	large
52419	59782	2795	Россия, Московская область, Серпуховский район, поселок Большевик, улица Ленина, 36	f	large
50547	58381	919	Россия, Московская область, Серпуховский район, поселок Большевик, улица Ленина, 1б	f	medium
52426	59787	2802	Московская область, Серпуховский район, деревня Большая Городня, помещение разновозрастного отряда	t	small
52422	59784	2798	Московская область, Серпуховский район, деревня Балково, помещение СДК	t	small
52404	59767	2780	Московская область, Серпуховский район, деревня Арнеево, помещение администрации Арнеевского с/о	f	small
52338	59257	2714	Московская область, Серебряно-Прудский район, поселок Успенский, Запрудная, 17	f	medium
52329	59639	2704	Московская область, Серебряно-Прудский район, село Узуново, 12, м-н Северный	t	large
52330	59657	2705	Московская область, Серебряно-Прудский район, село Узуново, Советская, 7А	f	large
52323	59714	2698	Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды, Школьная, 1	f	large
52321	59711	2695	Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды, Центральный, 1	f	large
52320	59710	2694	Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды, И.Садофьева, 13	f	large
111640	59713	2697	Московская область, Серебряно-Прудский район, поселок городского типа Серебряные Пруды, Большая Луговая, 8	f	\N
52325	59716	2700	Московская область, Серебряно-Прудский район, поселок Серебряные Пруды, микрорайон Западный, 10	f	large
52324	94627	2699	Московская область, Серебряно-Прудский район, поселок Серебряные Пруды, Привокзальная, 7	f	small
52322	59712	2696	Московская область, Серебряно-Прудский район, поселок Серебряные Пруды, Первомайская, 12	f	large
52336	59614	2712	Московская область, Серебряно-Прудский район, село Подхожее, микрорайон Юбилейный, 10	f	medium
111641	59401	2711	Московская область, Серебряно-Прудский район, село Подхожее, м-он Юбилейный, 12	f	\N
52332	59703	2707	Московская область, Серебряно-Прудский район, село Петрово, 9	f	medium
52327	59718	2702	Россия, Московская область, Серебряно-Прудский район, поселок Новоклемово	f	large
52331	59691	2706	Московская область, Серебряно-Прудский район, село Мягкое, 1а	t	small
52337	42893	2713	Московская область, Серебряно-Прудский район, село Мочилы, Школьная, 9	f	medium
52334	30499	2709	Московская область, Серебряно-Прудский район, село Крутое, 13	f	medium
52326	59717	2701	Московская область, Серебряно-Прудский район, село Дудино, 38а	f	small
52340	94628	2715	Московская область, Серебряно-Прудский район, поселок Дмитриевский, 5а	f	medium
52333	30266	2708	Московская область, Серебряно-Прудский район, село Глубокое, 40а	f	medium
52313	59701	2686	Московская область, Сергиево-Посадский район, село Шеметово, мкр. Новый, 34	f	large
52314	59702	2687	Московская область, Сергиево-Посадский район, село Шеметово, Центральная, 36	f	large
52319	59708	2692	Московская область, Сергиево-Посадский район, деревня Шабурново, 47, Дом культуры	t	large
52281	59671	2651	Московская область, Сергиево-Посадский район, Хотьково, Седина, 30	f	large
52280	59671	2650	Московская область, Сергиево-Посадский район, Хотьково, Седина, 30	f	large
52276	59671	2649	Московская область, Сергиево-Посадский район, Хотьково, Седина, 30	f	large
52277	59673	2653	Московская область, Сергиево-Посадский район, Хотьково, Пушкина, 11	f	large
52275	59670	2648	Московская область, Сергиево-Посадский район, Хотьково, Октябрьская, 1	f	large
52285	59674	2655	Московская область, Сергиево-Посадский район, Хотьково, Майолик, 5	f	large
52286	59674	2656	Московская область, Сергиево-Посадский район, Хотьково, Майолик, 5	f	large
52278	59674	2654	Московская область, Сергиево-Посадский район, Хотьково, Майолик, 5	f	large
52282	59672	2652	Московская область, Сергиево-Посадский район, Хотьково,  Михеенко, 12б	f	large
52312	59700	2685	Московская область, Сергиево-Посадский район, деревня Федорцово, 15а, Дом культуры	f	medium
52259	59629	2632	Московская область, Сергиево-Посадский район, деревня Тураково, 102, Клуб	f	small
52311	59699	2684	Московская область, Сергиево-Посадский район, деревня Торгашино, 5, Клуб	f	medium
49736	57424	109	Московская область, Сергиево-Посадский район, деревня Судниково, Школьная, 12	f	medium
52295	59684	2668	Московская область, Сергиево-Посадский район, поселок городского типа Скоропусковский, 31, Школа №15	f	large
52294	59684	2667	Московская область, Сергиево-Посадский район, поселок городского типа Скоропусковский, 31, Школа №15	f	large
52236	59637	2609	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица Леонида Булавина, 6	f	large
52235	59637	2608	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица Леонида Булавина, 6	f	large
52229	59631	2602	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, улица 40 лет Октября, 2	f	large
52230	59632	2603	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 212а	f	large
52227	59628	2600	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 192/2	f	large
52226	59627	2599	Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 185/27	f	large
52225	59627	2598	Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 185/27	f	large
52211	59618	2584	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, проспект Красной Армии, 111	f	medium
52243	59644	2616	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, городок Сергиев Посад-7, бульвар Свободы, 5	f	large
52244	59645	2617	Московская область, Сергиево-Посадский район, Сергиев Посад, бульвар Свободы, 2	f	large
52242	59643	2615	Московская область, Сергиево-Посадский район, Сергиев Посад, Ясная, 4	f	large
52233	59635	2606	Московская область, Сергиево-Посадский район, Сергиев Посад, Ярославское шоссе, 13	f	large
52207	59615	2580	Московская область, Сергиево-Посадский район, Сергиев Посад, Школьная, 2	f	large
52215	59622	2589	Московская область, Сергиево-Посадский район, Сергиев Посад, Хотьковский проезд, 16	f	large
52214	59622	2588	Московская область, Сергиево-Посадский район, Сергиев Посад, Хотьковский проезд, 16	f	large
52253	94626	2626	Московская область, Сергиево-Посадский район, Сергиев Посад, Советская, 1	f	large
52250	59650	2623	Московская область, Сергиево-Посадский район, Сергиев Посад, Скобяное шоссе, ОДЦ Октябрь	f	large
52254	59654	2627	Московская область, Сергиево-Посадский район, Сергиев Посад, дачный поселок Семхоз, Парковая, 16	f	large
52252	59652	2625	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Московское шоссе, 22а	f	medium
52251	59651	2624	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Московское шоссе, 12	f	large
52228	59630	2601	Московская область, Сергиево-Посадский район, Сергиев Посад, Матросова, 2	f	large
52249	59649	2622	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Клубная улица, 9	f	large
52248	59649	2621	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Клубная улица, 9	f	large
52237	59638	2610	Московская область, Сергиево-Посадский район, Сергиев Посад, Карла Либкнехта, 9	f	large
52241	59642	2614	Московская область, Сергиево-Посадский район, Сергиев Посад, Институтская, 10	f	large
52240	59642	2613	Московская область, Сергиево-Посадский район, Сергиев Посад, Институтская, 10	f	large
52239	59641	2612	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Железнодорожная улица, 29	f	large
52232	59634	2605	Московская область, Сергиево-Посадский район, Сергиев Посад, Глинки, 2	f	large
52212	59619	2585	Россия, Московская область, Сергиево-Посадский район, Сергиев Посад, Вознесенская улица, 81	f	large
111639	59620	2586	Московская область, Сергиево-Посадский район, Сергиев Посад, Вознесенская, 81, Школа № 7	f	\N
52217	59623	2590	Московская область, Сергиево-Посадский район, Сергиев Посад, 1-й Ударной Армии, 93	f	large
52218	59623	2591	Московская область, Сергиево-Посадский район, Сергиев Посад, 1-й Ударной Армии, 93	f	large
52274	59669	2647	Россия, Московская область, Сергиево-Посадский район, деревня Семенково	f	large
52301	59688	2674	Московская область, Сергиево-Посадский район, деревня Сватково, 91, Школа	f	large
52317	59706	2690	Московская область, Сергиево-Посадский район, деревня Самотовино, 5, Административное здание	f	medium
52284	59676	2658	Московская область, Сергиево-Посадский район, деревня Репихово, 3, Школа-сад №8	f	small
52296	59685	2671	Московская область, Сергиево-Посадский район, поселок Реммаш, Институтская, 8	f	large
52297	59685	2670	Московская область, Сергиево-Посадский район, поселок Реммаш, Институтская, 8	f	large
52298	59685	2669	Московская область, Сергиево-Посадский район, поселок Реммаш, Институтская, 8	f	large
52572	59920	2948	Московская область, Сергиево-Посадский район, садовое товарищество Поселок Северный, 8 Марта, 14	f	large
52265	59663	2640	Московская область, Сергиево-Посадский район, Пересвет, Строителей, 12в	f	large
52200	59607	2573	Московская область, Рузский район, деревня Старая Руза	f	large
52263	59661	2637	Московская область, Сергиево-Посадский район, Пересвет, Советская улица, 1/3	f	large
52287	59679	2661	Московская область, Сергиево-Посадский район, поселок ОРГРЭС, Центр инжиниринга воздушных электролиний (ДОЛ ОРГРЭС)	f	medium
52261	59659	2634	Московская область, Сергиево-Посадский район, поселок НИИРП, Конференцзал ОАО НИИРП	f	medium
52290	59682	2665	Московская область, Сергиево-Посадский район, село Муханово, 1/3, Дом культуры	f	medium
52309	59697	2682	Россия, Московская область, Сергиево-Посадский район, село Мостовик	f	large
52279	59677	2659	Московская область, Сергиево-Посадский район, деревня Морозово, 34, ФАП (фельдшерско-амбулаторный пункт)	f	small
52258	59648	2631	Московская область, Сергиево-Посадский район, село Мишутино, Мишутинская средняя школа	f	large
52318	59707	2691	Московская область, Сергиево-Посадский район, деревня Марьино, 12, Дом культуры	f	medium
52304	59692	2677	Московская область, Сергиево-Посадский район, поселок Лоза, 4б, Дом культуры	f	large
52303	59690	2676	Московская область, Сергиево-Посадский район, поселок Лоза, 4д, Библиотека	f	large
52234	59636	2607	Россия, Московская область, Сергиево-Посадский район, поселок Лесхоз	f	large
52316	59705	2689	Московская область, Сергиево-Посадский район, деревня Кузьмино, 11, Школа	f	medium
52299	59686	2672	Московская область, Сергиево-Посадский район, Краснозаводск, п. Зеленая Дубрава, 3, Клуб НИЛИЛ с клиникой	f	small
52273	59668	2646	Россия, Московская область, Сергиево-Посадский район, Краснозаводск, улица 1 Мая, 28	f	large
52272	59668	2645	Россия, Московская область, Сергиево-Посадский район, Краснозаводск, улица 1 Мая, 28	f	large
52271	59667	2644	Московская область, Сергиево-Посадский район, Краснозаводск, Трудовые Резервы, 4	f	large
52270	59666	2643	Московская область, Сергиево-Посадский район, Краснозаводск, Новая, 2а	f	large
52268	59664	2641	Московская область, Сергиево-Посадский район, Краснозаводск, Горького, 4	f	large
52315	59704	2688	Московская область, Сергиево-Посадский район, село Константиново, Октябрьская, 12	f	medium
52306	59694	2679	Московская область, Сергиево-Посадский район, деревня Зубцово, 49, Дом культуры	f	small
51448	59003	1809	Московская область, Сергиево-Посадский район, деревня Зубцово, 16 б, библиотека	f	small
52305	59693	2678	Московская область, Сергиево-Посадский район, поселок Заречный, 19, Дом культуры	f	medium
52288	59675	2657	Россия, Московская область, Сергиево-Посадский район, деревня Жучки	f	large
52260	59658	2633	Московская область, Сергиево-Посадский район, село Глинково, 77, Российский центр сельскохозяйственного консультирования	f	medium
52308	59696	2681	Московская область, Сергиево-Посадский район, село Васильевское, 21А	f	large
52300	59687	2673	Московская область, Сергиево-Посадский район, Бужаниново, Полевая, 3	f	large
49730	57686	103	Московская область, Сергиево-Посадский район, деревня Ботово, микрорайон, 12	f	medium
52292	59681	2664	Московская область, Сергиево-Посадский район, поселок городского типа Богородское, 35, Школа №28	f	large
52291	59681	2663	Московская область, Сергиево-Посадский район, поселок городского типа Богородское, 35, Школа №28	f	large
52289	59680	2662	Московская область, Сергиево-Посадский район, Богородское, Школа №179	f	large
52302	59689	2675	Московская область, Сергиево-Посадский район, деревня Березняки, 120, Дом культуры	f	large
51568	59099	1942	Московская область, Рузский район, поселок санатория "имени Герцена", Дом культуры	t	large
52178	59584	2551	Московская область, Рузский район, поселок городского типа Тучково, Студенческая, 1	f	medium
111636	59587	2554	Московская область, Рузский район, поселок городского типа Тучково, Привокзальная, Здание железнодорожного вокзала	f	\N
52180	59586	2553	Московская область, Рузский район, поселок городского типа Тучково, Восточный микрорайон, 15	f	large
52179	59585	2552	Московская область, Рузский район, поселок городского типа Тучково, Восточный микрорайон, 24А	f	large
49745	54671	118	Московская область, Рузский район, поселок городского типа Сычево, Нерудная, 6	f	large
52202	94625	2575	Московская область, Рузский район, деревня Сытьково, Здание МОУ Сытьковская СОШ	f	large
52197	59604	2570	Россия, Московская область, Рузский район, деревня Старониколаево	f	large
111638	59606	2572	Московская область, Рузский район, деревня Старая Руза, Санаторий Дорохово, здание клуба	f	\N
111635	59582	2549	Московская область, Рузский район, Руза, ул. Федеративная, д. 17, Здание автовокзала	f	\N
52174	59580	2547	Московская область, Рузский район, Руза, Щербакова, 33	f	small
52172	59577	2545	Московская область, Рузский район, Руза, Социалистическая, 63	f	large
52170	59575	2543	Московская область, Рузский район, Руза, Микрорайон, 19	f	large
52168	59573	2541	Московская область, Рузский район, Руза, Волоколамское шоссе, 4	f	large
52204	59611	2577	Московская область, Рузский район, деревня Орешки, 90	f	medium
52184	94624	2557	Россия, Московская область, Рузский район, деревня Нововолково	f	large
52196	59603	2569	Московская область, Рузский район, деревня Лыщиково, 200	t	small
52193	59600	2566	Московская область, Рузский район, поселок Космодемьянский, 17	f	large
52203	59610	2576	Московская область, Рузский район, поселок Колюбакино, Красная Горка, 1	f	large
52186	59592	2559	Московская область, Рузский район, деревня Ивойлово, 8А	t	small
52195	94598	2568	Россия, Московская область, Рузский район, поселок Дорохово	f	large
111637	59605	2571	Московская область, Рузский район, поселок Дорохово, Невкипелого, 1 	f	\N
52194	59601	2567	Московская область, Рузский район, поселок Дорохово, Невкипелого, 49	f	large
52201	59608	2574	Московская область, Рузский район, деревня Воробьево, 22	f	large
52188	59594	2561	Московская область, Рузский район, поселок Брикет, Центральная, 1	f	medium
52190	59597	2563	Московская область, Рузский район, поселок Беляная Гора, 4	f	large
52064	59541	2480	Московская область, Раменский район, деревня Юрово, Мира	f	large
52057	59551	2490	Россия, Московская область, Раменский район, поселок Электроизолятор	f	large
52056	59550	2489	Московская область, Раменский район, поселок Электроизолятор, 55	f	large
52040	59483	2419	Московская область, Раменский район, деревня Хрипань, Школьная, Помещение основной школы	f	small
52049	59543	2482	Московская область, Раменский район, деревня Фенино, Помещение Дома культуры	t	small
52004	59526	2462	Россия, Московская область, Раменский район, село Ульянино	f	large
52026	94618	2430	Московская область, Раменский район, поселок Удельная, Солнцева, 35, в помещении дворца культуры Победа	f	large
52029	59498	2433	Московская область, Раменский район, поселок Удельная, Первомайская, 15	f	large
52028	59497	2432	Московская область, Раменский район, поселок Удельная, Октябрьская , 1	f	large
52027	59496	2440	Московская область, Раменский район, поселок Удельная, Горячева, 38	f	large
52025	59496	2431	Московская область, Раменский район, поселок Удельная, Горячева, 38	f	large
52014	59516	2453	Московская область, Раменский район, деревня Тимонино, Помещение бывшей администрации Тимонинского сельского округа	f	medium
52017	59513	2450	Россия, Московская область, Раменский район, поселок Тельмана	f	large
52016	59513	2449	Россия, Московская область, Раменский район, поселок Тельмана	f	large
52047	59493	2428	Россия, Московская область, Раменский район, село Строкино	f	large
52013	59515	2452	Россия, Московская область, Раменский район, село Софьино	f	large
52073	59536	2474	Московская область, Раменский район, поселок Совхоза Раменское, Помещение дома культуры ОАО "Раменское"	f	large
52008	59521	2458	Московская область, Раменский район, поселок Рылеево, Помещение Ганусовской общеобразовательной средней школы	f	large
52068	59529	2465	Московская область, Раменский район, деревня Рыболово, Помещение Дома культуры	f	medium
52074	59537	2475	Московская область, Раменский район, деревня Рыбаки, Садовая, 1А	t	small
52046	59492	2427	Московская область, Раменский район, поселок городского типа Родники, Трудовая, 3	f	large
52045	59491	2426	Московская область, Раменский район, поселок Родники, Центральная, 3	f	large
52055	59549	2488	Россия, Московская область, Раменский район, село Речицы	f	large
52054	59548	2487	Московская область, Раменский район, село Речицы, Центральная, Помещение администрации	f	large
52107	59476	2404	Россия, Московская область, Раменский район, Раменское, улица Гурьева, 23	f	large
52108	59476	2405	Россия, Московская область, Раменский район, Раменское, улица Гурьева, 23	f	large
50938	58636	1312	Московская область, Раменский район, деревня Аксеново, 227	f	small
52106	59476	2403	Россия, Московская область, Раменский район, Раменское, улица Гурьева, 23	f	large
52095	59467	2392	Московская область, Раменский район, Раменское, поселок Красный Октябрь, 43	f	large
52090	59464	2389	Московская область, Раменский район, Раменское, Чугунова, 10а	f	large
52092	59464	2387	Московская область, Раменский район, Раменское, Чугунова, 10а	f	large
52097	59468	2394	Московская область, Раменский район, Раменское, Серова, 18	f	large
52096	59468	2393	Московская область, Раменский район, Раменское, Серова, 18	f	large
52104	59474	2401	Московская область, Раменский район, Раменское, Михалевича, 2	f	large
52100	59470	2397	Московская область, Раменский район, Раменское, Михалевича, 58	f	large
52099	59470	2396	Московская область, Раменский район, Раменское, Михалевича, 58	f	large
52115	59477	2412	Московская область, Раменский район, Раменское, Красноармейская, 22	f	large
52110	59477	2407	Московская область, Раменский район, Раменское, Красноармейская, 22	f	large
52109	59477	2406	Московская область, Раменский район, Раменское, Красноармейская, 22	f	large
52080	59461	2377	Россия, Московская область, Раменский район, Раменское, Коммунистическая улица, 30	f	medium
52081	59460	2378	Московская область, Раменский район, Раменское, Коммунистическая, 30/1	f	large
52079	59460	2376	Московская область, Раменский район, Раменское, Коммунистическая, 30/1	f	large
52103	59473	2400	Московская область, Раменский район, Раменское, Коминтерна, 9, Красный уголок ОАО РПЗ	f	large
52113	59479	2410	Московская область, Раменский район, Раменское, Интернациональная , 20	f	large
52112	59479	2409	Московская область, Раменский район, Раменское, Интернациональная , 20	f	large
52094	59466	2391	Московская область, Раменский район, Раменское, Воровского, 4	f	large
52093	59466	2390	Московская область, Раменский район, Раменское, Воровского, 4	f	large
52012	59514	2451	Московская область, Раменский район, поселок РАОС, Помещение Дома культуры	t	medium
51436	59014	1820	Московская область, Раменский район, деревня Починки, Советская, 20, Библиотека	t	small
52065	59542	2481	Московская область, Раменский район, деревня Пласкинино, Центральная, Помещение ФАПа	t	small
50796	56701	1170	Россия, Ярославская область, Ростовский район, поселок Петровское	t	large
52007	59520	2457	Московская область, Раменский район, деревня Панино, Дом культуры Лель	f	medium
52019	59510	2445	Россия, Московская область, Раменский район, деревня Островцы, Центральная улица, 24	f	medium
52021	59511	2447	Московская область, Раменский район, деревня Островцы, Подмосковная улица, Помещение средней школы	f	large
52020	59511	2446	Московская область, Раменский район, деревня Островцы, Подмосковная улица, Помещение средней школы	f	large
52024	59508	2443	Московская область, Раменский район, поселок Опытное поле, 8, Помещение клуба	f	medium
52070	59534	2471	Московская область, Раменский район, село Новое, Ленинская, Помещение основной школы	f	large
52069	59530	2466	Московская область, Раменский район, деревня Никулино, Помещение Никулинской  школы	f	small
52005	59522	2459	Московская область, Раменский район, село Никоновское, Центральная, 74	f	medium
52003	59525	2461	Московская область, Раменский район, село Никитское, помещение общеобразовательной средней школы	f	large
52015	59512	2448	Московская область, Раменский район, деревня Нижнее Мячково, Помещение Дома культуры	f	medium
52067	59528	2464	Московская область, Раменский район, деревня Морозово, Помещение Рыболовской средней школы	f	large
52051	59545	2484	Московская область, Раменский район, деревня Минино, Помещение Мининского ФАПа	t	medium
52058	59552	2491	Россия, Московская область, Раменский район, поселок Кузяевского фарфорового завода	f	large
52061	59532	2468	Московская область, Раменский район, деревня Кузнецово, Центральная	f	large
52041	59484	2420	Московская область, Раменский район, поселок городского типа Кратово, Мира, Помещение дома культуры	f	large
52043	59486	2422	Московская область, Раменский район, поселок городского типа Кратово, Карла Маркса, 21	f	medium
52044	59505	2439	Московская область, Раменский район, поселок Кратово, Центральная, 5	f	large
52010	59518	2455	Московская область, Раменский район, поселок Константиново	f	large
52009	59517	2454	Московская область, Раменский район, поселок Константиново, Помещение дома культуры Константиновский	f	large
52072	59524	2473	Московская область, Раменский район, деревня Клишева, Школьная, 90	f	large
52037	59489	2425	Московская область, Раменский район, поселок Ильинский, Первомайская, 15	f	large
52036	59488	2424	Московская область, Раменский район, поселок Ильинский, Октябрьская, 60	f	large
52034	59504	2438	Россия, Московская область, Раменский район, поселок городского типа Ильинский, улица Опаленной Юности, 23	f	medium
52035	59487	2423	Московская область, Раменский район, поселок городского типа Ильинский, Ленинская, 38	f	large
111634	59482	2418	Московская область, Раменский район, деревня Захарово, помещение Дома культуры	f	\N
52006	59523	2460	Россия, Московская область, Раменский район, село Заворово	f	large
52071	59535	2472	Россия, Московская область, Раменский район, деревня Заболотье	f	large
50197	58088	570	Московская область, Раменский район, поселок Жуковский, Кирова, 4	f	large
52076	59538	2477	Россия, Московская область, Раменский район, поселок Дубовая Роща	f	large
52075	59538	2476	Россия, Московская область, Раменский район, поселок Дубовая Роща	f	large
52078	59540	2479	Московская область, Раменский район, поселок Дубовая Роща, Спортивная , 1а	f	medium
52063	59533	2470	Московская область, Раменский район, поселок Дружба, Ленина	f	large
52062	59533	2469	Московская область, Раменский район, поселок Дружба, Ленина	f	large
52118	59480	2415	Московская область, Раменский район, деревня Дергаево, Октябрьская, Помещение средней школы №23	f	large
52119	59480	2416	Московская область, Раменский район, деревня Дергаево, Октябрьская, Помещение средней школы №23	f	large
52011	59519	2456	Московская область, Раменский район, поселок Денежниково, Помещение Ильинской общеобразовательной школы №17	f	medium
52038	59481	2417	Россия, Московская область, Раменский район, деревня Дементьево	f	large
52053	59547	2486	Московская область, Раменский район, поселок Гжельского кирпичного завода, 1, Помещение Дома культуры Строитель	f	medium
52052	59546	2485	Московская область, Раменский район, поселок Гжельского кирпичного завода, 7, Помещение ОАО "Гжельская УК"	f	large
52050	59544	2483	Россия, Московская область, Раменский район, поселок Гжель	f	large
52077	59539	2478	Россия, Московская область, Раменский район, поселок Гжелка	f	large
52048	59494	2429	Московская область, Раменский район, деревня Вялки, Кооперативная, 52	f	large
52066	59527	2463	Московская область, Раменский район, деревня Вохринка, Помещение Вохринского Дома культуры	f	medium
52018	59509	2444	Московская область, Раменский район, село Верхнее Мячково, Центральная, помещение ФАП-а	t	small
52682	60009	3059	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 2	f	large
52681	60009	3058	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 2	f	large
51899	59353	2273	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 9	f	large
50212	58100	585	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 6	f	large
50211	58100	584	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 6	f	large
50066	57973	438	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 3	f	large
50065	57973	437	Россия, Московская область, Раменский район, поселок городского типа Быково, Школьная улица, 3	f	large
52030	59499	2434	Московская область, Раменский район, поселок городского типа Быково, Чапаева, 4	f	large
52031	59500	2435	Московская область, Раменский район, поселок городского типа Быково, Станционная, 9	f	large
52033	59502	2437	Московская область, Раменский район, поселок Быково, Чкалова, 2	f	large
52032	59501	2436	Московская область, Раменский район, поселок Быково, Советская, 21	f	large
52022	59506	2441	Московская область, Раменский район, село Быково, Колхозная	f	large
52060	59531	2467	Московская область, Раменский район, деревня Бояркино, Центральная, Помещение ФАПа	f	small
52059	59553	2492	Московская область, Раменский район, деревня Антоново, Помещение Карповской общеобразовательной школы	f	medium
51982	59441	2356	Московская область, Пушкинский район, поселение Черкизово, Главная, 99	f	large
51973	59432	2347	Московская область, Пушкинский район, поселение Софрино, Школьная, 3	f	large
51966	59425	2340	Московская область, Пушкинский район, городское поселение Правдинский, Степаньковское шоссе, 31а	f	large
51981	59440	2355	Московская область, Пушкинский район, поселок городского типа Черкизово, Школьная , 6/6	f	medium
52685	60012	3062	Россия, Московская область, Пушкинский район, поселок городского типа Черкизово, Речная улица, 20	f	large
51958	59417	2332	Россия, Московская область, Пушкинский район, поселок городского типа Черкизово, Речная улица, 16	f	large
51993	94615	2367	Московская область, Пушкинский район, село Царево, 1Б, Школа	f	large
51984	59443	2358	Московская область, Пушкинский район, село Тишково, 7	f	medium
51989	94612	2363	Московская область, Пушкинский район, село Тарасовка, Учебный центр, в/ч 43431	f	medium
51990	94613	2364	Московская область, Пушкинский район, село Тарасовка, Большая Тарасовская, 108, РИАМА	f	large
51988	59448	2362	Московская область, Пушкинский район, село Тарасовка, Большая Тарасовская, 26	f	medium
51985	59444	2359	Московская область, Пушкинский район, деревня Степаньково, ДК	f	small
51980	94610	2354	Московская область, Пушкинский район, поселок городского типа Софрино-1, Майская школа	f	large
51979	94610	2353	Московская область, Пушкинский район, поселок городского типа Софрино-1, Майская школа	f	large
51978	94610	2352	Московская область, Пушкинский район, поселок городского типа Софрино-1, Майская школа	f	large
51974	59434	2348	Московская область, Пушкинский район, поселок городского типа Софрино, Тютчева, 18	f	large
51971	59430	2345	Московская область, Пушкинский район, поселок городского типа Софрино, Крайняя, 2	f	large
51975	59435	2349	Московская область, Пушкинский район, поселок Софрино, Талицы, 23	f	small
51972	59431	2346	Московская область, Пушкинский район, поселок Софрино, Полевая, 5	f	large
51976	59436	2350	Московская область, Пушкинский район, поселок Софрино, Дальняя, клуб Дальний	f	small
51616	59144	1990	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, улица Коминтерна, 39	f	medium
50292	58161	664	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, улица Коминтерна, 2	f	large
50291	58161	663	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, улица Коминтерна, 2	f	large
50289	58161	661	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, улица Коминтерна, 2	f	large
51934	59397	2308	Россия, Московская область, Пушкинский район, Пушкино, улица Инессы Арманд, 13	f	large
51936	59397	2310	Россия, Московская область, Пушкинский район, Пушкино, улица Инессы Арманд, 13	f	large
51935	59397	2309	Россия, Московская область, Пушкинский район, Пушкино, улица Инессы Арманд, 13	f	large
51946	59404	2320	Московская область, Пушкинский район, Пушкино, пр.Дзержинского, 2	f	medium
51938	59399	2312	Московская область, Пушкинский район, Пушкино, Ярославское шоссе, 170а	f	large
51949	59407	2323	Московская область, Пушкинский район, Пушкино, микрорайон Мамонтовка, Школьная, 5	f	large
51929	59393	2303	Московская область, Пушкинский район, Пушкино, Чехова, 8	f	large
51928	59393	2302	Московская область, Пушкинский район, Пушкино, Чехова, 8	f	large
51927	59393	2301	Московская область, Пушкинский район, Пушкино, Чехова, 8	f	large
51937	59398	2311	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Клязьма, Фабричная улица, 7	f	large
51953	59412	2327	Московская область, Пушкинский район, Пушкино, микрорайон Клязьма, Сологубовская, 3	f	large
51956	59415	2330	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Звягино, Советская улица, 25	f	large
51968	59427	2342	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Заветы Ильича, Советская улица, 1	f	large
51952	59411	2326	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Мамонтовка, Рабочая улица, 1	f	large
51926	59392	2300	Россия, Московская область, Пушкинский район, Пушкино, Писаревский проезд, 5	f	large
51950	59408	2324	Московская область, Пушкинский район, Пушкино, Октябрьская, 23	f	medium
83592	57140	2775	Москва, Юровская , 97	f	large
51924	59390	2298	Московская область, Пушкинский район, Пушкино, Некрасова, 3	f	large
51954	59413	2328	Россия, Московская область, Пушкинский район, Пушкино, микрорайон Клязьма, Лермонтовская улица, 25	f	medium
51951	59410	2325	Московская область, Пушкинский район, Пушкино, микрорайон Мамонтовка, Кузнецкий Мост, 1	f	large
51947	59405	2321	Московская область, Пушкинский район, Пушкино, Коминтерна, 16	f	medium
51920	59387	2294	Московская область, Пушкинский район, Пушкино, Железнодорожная, 14	f	large
51918	59385	2292	Московская область, Пушкинский район, Пушкино, Боголюбская, 3, ГУ УПФ РФ № 16 по г. Москве и МО	f	large
51921	59388	2295	Россия, Московская область, Пушкинский район, Пушкино, Авиационная улица, 35	f	large
51917	59384	2291	Россия, Московская область, Пушкинский район, Пушкино, 2-я Домбровская улица, 26	f	large
51931	59395	2305	Россия, Московская область, Пушкинский район, Пушкино, 2-й Надсоновский проезд, 14	f	large
51932	59395	2306	Россия, Московская область, Пушкинский район, Пушкино, 2-й Надсоновский проезд, 14	f	large
51933	94607	2307	Московская область, Пушкинский район, Пушкино, 1-й Фабричный проезд, 6, Центр соц. обслуживания 51 а	f	large
51919	59386	2293	Московская область, Пушкинский район, Пушкино, 1-й Добролюбовский проезд, 30	f	large
51967	59426	2341	Московская область, Пушкинский район, Правдинский, Ленина, 15/1	f	large
51969	59428	2343	Московская область, Пушкинский район, Правдинский, Зеленый городок, 5	t	medium
51965	59424	2339	Московская область, Пушкинский район, поселок Правдинский, Лесная, 60	f	large
51957	59416	2331	Московская область, Пушкинский район, деревня Мураново, городское поселение Ашукино, 90	f	small
51885	59357	2259	Московская область, Пушкинский район, поселок Лесные Поляны, Новая, 1, здание ФГУЗ ЦКБВЛ ФМБА и Р Лесные поляны, корп. 1	f	medium
51991	59451	2365	Московская область, Пушкинский район, поселок Лесные Поляны, Ленина, 22а, ДК Современник	f	large
51964	94609	2338	Московская область, Пушкинский район, поселок городского типа Лесной, Титова, 11, школа УИК: г.п.Лесной, Гагарина (Администрация), 1	f	large
51962	59422	2336	Московская область, Пушкинский район, поселок городского типа Лесной, Гагарина, 1	f	large
51963	59423	2337	Московская область, Пушкинский район, поселок Лесной, Титова, 11	f	large
51995	94617	2369	Московская область, Пушкинский район, село Левково, 20-а, ДК	f	small
51961	59420	2335	Московская область, Пушкинский район, поселок городского типа Зеленоградский, Школьная, 1	f	large
51992	94614	2366	Московская область, Пушкинский район, поселок Зверосовхоза, Школьная , 6а, здание старой школы	f	large
51983	94611	2357	Московская область, Пушкинский район, село Ельдигино, Дом культуры, Адрес УИК: Администрация с.п.Ельдигинское, 1	f	large
51970	59429	2344	Московская область, Пушкинский район, село Братовщина, Огородная, 17а	f	medium
51994	94616	2368	Московская область, Пушкинский район, село Барково, 64а, Православный центр, Адрес УИК: Барково13а (ФГУП МО Орловское)	f	small
51960	94608	2334	Московская область, Пушкинский район, поселок Ашукино, Племсадпитомник, контора 4 отделения	f	medium
51986	59446	2360	Московская область, Пушкинский район, деревня Алешино, Парковая, 1	f	small
51923	59389	2297	Московская область, Пушкинский, Пушкино, 2-й Некрасовский проезд, 4	f	large
51922	59389	2296	Московская область, Пушкинский, Пушкино, 2-й Некрасовский проезд, 4	f	large
51892	59364	2266	Московская область, Подольский район, поселок фабрики имени 1 Мая, 37, МУК СДК Десна	f	large
51878	59349	2252	Московская область, Подольский район, поселок санатория Родина, здание МАУ Центр Родина	t	medium
51886	59358	2260	Московская область, Подольский район, поселок радиоцентра Романцево, здание СДК, МУК СДК Романцево	f	medium
51883	94604	2257	Московская область, Подольский район, п.Молодёжный, 30	f	large
51873	59345	2247	Московская область, Подольский район, п. дома отдыха Вороново, 31стр.1	f	large
51872	59344	2246	Московская область, Подольский район, п. Львовский, Строителей, 4	f	large
51870	59342	2244	Московская область, Подольский район, п. Львовский, Московская, 1	f	large
51903	59374	2277	Московская область, Подольский район, поселок Щапово, 23	f	large
51902	59373	2276	Московская область, Подольский район, поселок Щапово, 23, МУК СДК Солнечный	f	large
82167	56257	1333	Москва, Юных Ленинцев, 40к4	f	large
51890	59362	2264	Московская область, Подольский район, поселок Шишкин Лес, 28	f	large
51889	59361	2263	Московская область, Подольский район, поселок Шишкин Лес, 28, здание МОУ Михайловская СОШ	f	large
52731	60051	3108	Московская область, Подольский район, деревня Троицкое, 50, Средняя общеобразовательная школа	f	large
52732	60051	3109	Московская область, Подольский район, деревня Троицкое, 50, Средняя общеобразовательная школа	f	large
51887	59359	2261	Московская область, Подольский район, село Сынково, 24	t	large
52185	59591	2558	Московская область, Подольский район, село Покровское, Мира, 1А	f	large
51893	59365	2267	Московская область, Подольский район, поселок Остафьево, здание МОУ Остафьево прогимназия	f	large
51871	59343	2245	Московская область, Подольский район, поселок городского типа Львовский, Горького, 6	f	large
51869	59341	2243	Московская область, Подольский район, поселок городского типа Львовский, Горького, 5	f	large
51875	59346	2249	Россия, Московская область, Подольский район, поселок ЛМС	f	large
51874	59346	2248	Россия, Московская область, Подольский район, поселок ЛМС	f	large
51904	59375	2278	Московская область, Подольский район, поселок Курилово, Центральная, 32	f	large
51882	94603	2256	Московская область, Подольский район, поселок Красная Пахра, 20, помещение МУК СДК «Звездный»	f	large
52503	94645	2877	Московская область, Подольский район, Климовск, Новая улица, Дом культуры	f	small
51880	59351	2254	Московская область, Подольский район, деревня Кленово, Центральная, стр.1	f	large
51895	94606	2269	Московская область, Подольский район, поселок Знамя Октября, 31к3, МУ спортивный клуб «Десна»	f	large
51898	59370	2272	Россия, Московская область, Подольский район, поселок Знамя Октября, 11	f	large
51896	59368	2270	Россия, Московская область, Подольский район, поселок Знамя Октября, 40	f	large
51894	59366	2268	Московская область, Подольский район, поселок Знамя Октября, 40, здание МОУ СОШ	f	large
51884	94605	2258	Московская область, Подольский район, поселок Железнодорожный, Большая Серпуховская, 202А, помещении конференц-зала ОАО Сынково	f	large
51897	59369	2271	Россия, Московская область, Подольский район, поселок Ерино, Высокая улица, 3	f	large
51877	59348	2251	Россия, Московская область, Подольский район, поселок Дубровицы	f	large
51881	59352	2255	Московская область, Подольский район, село Былово, 8а, здание МУК СДК Юбилейный	f	medium
52192	59599	2565	Московская область, Подольский район, садовое товарищество Богородское, Центральная, 4	t	medium
51901	59372	2275	Московская область, Подольский район, поселок Александровка, Центральная, 41	t	small
51774	59274	2148	Московская область, Павлово-Посадский район, деревня Семеново, 18/А	f	small
51787	59164	2161	Московская область, Павлово-Посадский район, деревня Саурово, 29	f	small
51781	59281	2155	Россия, Московская область, Павлово-Посадский район, село Рахманово	f	large
51910	59379	2284	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица Гагарина, 7	f	large
51909	59379	2283	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица Гагарина, 7	f	large
51741	59251	2115	Россия, Московская область, Павлово-Посадский район, Павловский Посад, улица 1 Мая, 66а	f	large
51745	59254	2119	Московская область, Павлово-Посадский район, Павловский Посад, площадь Революции, 13, 15	f	large
51751	94600	2125	Московская область, Павлово-Посадский район, Павловский Посад, переулок Герцена, 19/14, МОУ ДОД ДЭБЦ	f	large
51766	59269	2140	Московская область, Павлово-Посадский район, Павловский Посад, Южная, 14	f	large
51765	59269	2139	Московская область, Павлово-Посадский район, Павловский Посад, Южная, 14	f	large
51771	59253	2145	Московская область, Павлово-Посадский район, Павловский Посад, Сенная, 42	f	large
51744	59253	2118	Московская область, Павлово-Посадский район, Павловский Посад, Сенная, 42	f	medium
51743	59250	2117	Московская область, Павлово-Посадский район, Павловский Посад, Мира, 1	f	medium
51740	59250	2114	Московская область, Павлово-Посадский район, Павловский Посад, Мира, 1	f	large
51763	94601	2137	Московская область, Павлово-Посадский район, Павловский Посад, Кузьмина, 53	f	large
51762	94601	2136	Московская область, Павлово-Посадский район, Павловский Посад, Кузьмина, 53	f	large
51761	94601	2135	Московская область, Павлово-Посадский район, Павловский Посад, Кузьмина, 53	f	large
51758	59265	2132	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Корнево-Юдинский переулок, 12	f	large
51757	59265	2131	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Корнево-Юдинский переулок, 12	f	large
51756	59265	2130	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Корнево-Юдинский переулок, 12	f	large
51746	59255	2120	Московская область, Павлово-Посадский район, Павловский Посад, Кирова, 83	f	large
51748	59258	2122	Московская область, Павлово-Посадский район, Павловский Посад, Каляева, 2	f	large
51752	59259	2126	Московская область, Павлово-Посадский район, Павловский Посад, Герцена, 15	f	large
51749	59259	2123	Московская область, Павлово-Посадский район, Павловский Посад, Герцена, 15	f	large
51755	59264	2129	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Большая Покровская улица, 33	f	large
51753	59262	2127	Московская область, Павлово-Посадский район, Павловский Посад, Белинского, 7	f	large
51742	59252	2116	Россия, Московская область, Павлово-Посадский район, Павловский Посад, 1-й переулок 1 Мая, 1	f	large
51777	59277	2151	Московская область, Павлово-Посадский район, деревня Ново-Загарье, 106/Б	f	small
51784	59284	2158	Московская область, Павлово-Посадский район, деревня Логиново, 22/А	f	small
51779	59279	2153	Московская область, Павлово-Посадский район, деревня Кузнецы, Новая, 1/1	f	large
51778	59278	2152	Московская область, Павлово-Посадский район, деревня Крупино, Школьная, 11А	f	medium
51782	59282	2156	Московская область, Павлово-Посадский район, село Казанское, 42	f	medium
51785	59285	2159	Московская область, Павлово-Посадский район, деревня Ефимово, 69/г	f	medium
51783	59283	2157	Московская область, Павлово-Посадский район, деревня Евсеево, 13/А	f	large
51780	59280	2154	Московская область, Павлово-Посадский район, деревня Васютино, 72/1	f	small
51772	59272	2146	Россия, Московская область, Павлово-Посадский район, поселок городского типа Большие дворы	f	large
51773	59273	2147	Московская область, Павлово-Посадский район, поселок городского типа Большие дворы, Спортивная, 12	f	large
51775	59275	2149	Россия, Тверская область, Сонковский район, поселок Алферово	f	medium
51688	59201	2062	Московская область, Орехово-Зуевский район, деревня Яковлево, 2а	f	small
52574	59921	2949	Московская область, Орехово-Зуевский район, деревня Юркино, 12а, Юркинский сельский Дом культуры	f	medium
51700	59213	2074	Московская область, Орехово-Зуевский район, деревня Юркино, 98в	f	small
51725	59235	2099	Московская область, Орехово-Зуевский район, деревня Цаплино, 141	f	small
51736	59246	2110	Московская область, Орехово-Зуевский район, село Хотеичи, 263 а	f	medium
51712	59222	2086	Московская область, Орехово-Зуевский район, деревня Федорово, 137а	f	small
51724	59234	2098	Московская область, Орехово-Зуевский район, деревня Степановка, 109а	t	small
51737	59247	2111	Московская область, Орехово-Зуевский район, деревня Соболево, 7А	f	large
51697	59210	2071	Московская область, Орехово-Зуевский район, поселок Снопок Новый, Центральная, 15	f	medium
51732	59242	2106	Московская область, Орехово-Зуевский район, деревня Смолево, 93а	f	small
51727	59237	2101	Московская область, Орехово-Зуевский район, деревня Слободище, Советская, 55 б	f	small
51699	59212	2073	Московская область, Орехово-Зуевский район, деревня Савостьяново, Слободка, 7а	f	small
51687	59200	2061	Московская область, Орехово-Зуевский район, деревня Савинская, 30А	f	large
51715	59224	2089	Московская область, Орехово-Зуевский район, деревня Понарино, 75 а	f	medium
51722	59231	2096	Московская область, Орехово-Зуевский район, деревня Петрушино, 121б	f	small
51696	59209	2070	Московская область, Орехово-Зуевский район, поселок Озерецкий, 32а	f	medium
51731	59241	2105	Московская область, Орехово-Зуевский район, деревня Новое, Дружбы, 1а	f	medium
51730	59240	2104	Московская область, Орехово-Зуевский район, деревня Новое, Дружбы, 1а	f	medium
51734	59244	2108	Московская область, Орехово-Зуевский район, поселок Мисцево, 28	f	medium
51721	94599	2095	Московская область, Орехово-Зуевский район, деревня Мисцево, 178	f	small
51738	59248	2112	Московская область, Орехово-Зуевский район, деревня Минино, 179а	f	small
51729	59239	2103	Московская область, Орехово-Зуевский район, деревня Малая Дубна, 15 а	f	large
51680	59193	2054	Россия, Московская область, Орехово-Зуевский район, Ликино-Дулево, улица Степана Морозкина, 14	f	large
51686	59199	2060	Россия, Московская область, Орехово-Зуевский район, Ликино-Дулево, улица Калинина, 14	f	large
51682	59195	2056	Россия, Московская область, Орехово-Зуевский район, Ликино-Дулево, Советская улица, 34	f	large
51678	59190	2052	Московская область, Орехово-Зуевский район, Ликино-Дулево, Ленина, 1	f	large
51676	59190	2050	Московская область, Орехово-Зуевский район, Ликино-Дулево, Ленина, 1	f	large
51677	59191	2051	Московская область, Орехово-Зуевский район, Ликино-Дулево, Кирова, 73	f	large
51685	59198	2059	Московская область, Орехово-Зуевский район, Ликино-Дулево, Калинина, 12	f	large
51684	59197	2058	Московская область, Орехово-Зуевский район, Ликино-Дулево, Калинина, 2в	f	large
51683	59196	2057	Московская область, Орехово-Зуевский район, Ликино-Дулево, Калинина, 3	f	large
51671	59185	2045	Московская область, Орехово-Зуевский район, Куровское, Школьная, 1	f	large
51673	59187	2047	Россия, Московская область, Орехово-Зуевский район, Куровское, Советская улица, 1а	f	medium
51672	59186	2046	Московская область, Орехово-Зуевский район, Куровское, Советская, 4	f	large
51667	59181	2041	Россия, Московская область, Орехово-Зуевский район, Куровское, Новинское шоссе, 12	f	large
51666	59181	2040	Россия, Московская область, Орехово-Зуевский район, Куровское, Новинское шоссе, 12	f	large
51645	59163	2019	Россия, Московская область, Орехово-Зуевский район, Куровское, Набережная улица, 15	f	large
51643	59163	2017	Россия, Московская область, Орехово-Зуевский район, Куровское, Набережная улица, 15	f	large
51644	59163	2018	Россия, Московская область, Орехово-Зуевский район, Куровское, Набережная улица, 15	f	large
51675	59189	2049	Россия, Московская область, Орехово-Зуевский район, Куровское, Коммунистическая улица, 2	f	large
51669	59183	2043	Россия, Московская область, Орехово-Зуевский район, Куровское, Вокзальная улица, 5	f	large
51670	59184	2044	Московская область, Орехово-Зуевский район, Куровское, Вокзальная , 7	f	large
51711	59221	2085	Московская область, Орехово-Зуевский район, деревня Красная Дубрава, 57а	f	small
111632	59215	2077	Россия, Московская область, Орехово-Зуевский район, деревня Кабаново	f	\N
111631	59215	2076	Россия, Московская область, Орехово-Зуевский район, деревня Кабаново	f	\N
51728	59238	2102	Московская область, Орехово-Зуевский район, село Ильинский Погост, Совхозная, 10	f	large
51720	59229	2094	Московская область, Орехово-Зуевский район, деревня Запутное, 58	f	small
51718	59227	2092	Московская область, Орехово-Зуевский район, деревня Заполицы, 35а	f	small
51735	59245	2109	Московская область, Орехово-Зуевский район, деревня Заволенье, Школьная, 89	f	medium
51733	59243	2107	Московская область, Орехово-Зуевский район, деревня Дуброво, 90	f	small
51693	59206	2067	Московская область, Орехово-Зуевский район, деревня Дровосеки, 21а	f	small
51663	59179	2037	Россия, Московская область, Орехово-Зуевский район, Дрезна, Центральная улица, 20	f	large
51665	59179	2039	Россия, Московская область, Орехово-Зуевский район, Дрезна, Центральная улица, 20	f	large
51698	59211	2072	Московская область, Орехово-Зуевский район, Дрезна, Советская, 17	f	small
51664	59180	2038	Московская область, Орехово-Зуевский район, Дрезна, Коммунистическая, 12	f	large
51662	59178	2036	Московская область, Орехово-Зуевский район, Дрезна, Зимина, 2	f	large
51710	59220	2084	Московская область, Орехово-Зуевский район, деревня Демихово, Заводская , 8	f	large
51709	59220	2083	Московская область, Орехово-Зуевский район, деревня Демихово, Заводская , 8	f	large
51704	59216	2078	Россия, Московская область, Орехово-Зуевский район, деревня Давыдово	f	large
51707	59218	2081	Московская область, Орехово-Зуевский район, деревня Давыдово, 2-й микрорайон, 11	f	large
51705	59217	2079	Московская область, Орехово-Зуевский район, деревня Давыдово, 2-й микрорайон, 31	f	large
51706	59217	2080	Московская область, Орехово-Зуевский район, деревня Давыдово, 2-й микрорайон, 31	f	large
51691	59204	2065	Россия, Московская область, Орехово-Зуевский район, деревня Губино	f	large
48704	53147	64	Липецкая область, Липецк, проезд Сиреневый, 9	f	large
51690	59203	2064	Московская область, Орехово-Зуевский район, деревня Губино, Ленинская-2, 95А	f	large
51701	59214	2075	Московская область, Орехово-Зуевский район, деревня Гора, 51а	f	small
51695	59208	2069	Московская область, Орехово-Зуевский район, деревня Войново-Гора, Новая, 138а	f	small
51692	59205	2066	Московская область, Орехово-Зуевский район, поселок Верея, Школьная, 6	f	large
51719	59228	2093	Московская область, Орехово-Зуевский район, деревня Велино, 83	f	small
51717	59226	2091	Московская область, Орехово-Зуевский район, село Богородское, 183а	f	small
51689	59202	2063	Московская область, Орехово-Зуевский район, деревня Белавино, 72	f	small
51726	59236	2100	Московская область, Орехово-Зуевский район, деревня Беззубово, 80а	f	medium
51708	59219	2082	Россия, Московская область, Орехово-Зуевский район, деревня Анциферово	f	medium
51716	59225	2090	Московская область, Орехово-Зуевский район, поселок Авсюнино, 177Б	f	small
51713	59223	2088	Россия, Московская область, Орехово-Зуевский район, поселок Авсюнино	f	large
51714	59223	2087	Россия, Московская область, Орехово-Зуевский район, поселок Авсюнино	f	large
51723	59232	2097	Московская область, Орехово-Зуевский район, деревня Абрамовка, 102б	f	small
51601	59114	1975	Московская область, Озерский район, с. Горы, Багратиона, 28б	f	medium
51580	94594	1954	Московская область, Озерский район, деревня Тарбушево, Набережная, 34	f	medium
111630	59132	1977	Московская область, Озерский район, село Сосновка, Помещение Сосновского фельдшерско-акушерского пункта	f	\N
51604	59133	1978	Московская область, Озерский район, село Сосновка, Советская, 136	f	small
51607	59134	1979	Московская область, Озерский район, село Редькино, 21, Фабрика Ока	f	medium
51599	59129	1973	Московская область, Озерский район, Озеры, Помещение сельского клуба	f	large
51598	59128	1972	Россия, Московская область, Озерский район, Озеры	f	large
51585	59116	1959	Россия, Московская область, Озерский район, Озеры	f	large
51593	59124	1967	Московская область, Озерский район, Озеры, площадь Карла Маркса, 57	f	medium
51597	59127	1971	Московская область, Озерский район, Озеры, пл. Карла Маркса, 55	f	medium
51587	94595	1961	Московская область, Озерский район, Озеры, микрорайон 1, Помещение средней школы №1	f	large
51586	59117	1960	Московская область, Озерский район, Озеры, микрорайон 1, 7	f	large
51582	59112	1956	Московская область, Озерский район, Озеры, Микр.им.маршала Катукова, Гимназия №4	f	large
51583	59113	1957	Московская область, Озерский район, Озеры, Микр. им.Маршала Катукова, Гимназия №4	f	small
51592	59123	1966	Московская область, Озерский район, Озеры, Ленина, 20	f	large
51591	59122	1965	Московская область, Озерский район, Озеры, Ленина, 63	f	large
51589	59120	1963	Московская область, Озерский район, Озеры, Ленина, 102	f	large
51588	59119	1962	Московская область, Озерский район, Озеры, Ленина, 71	f	large
51581	59111	1955	Московская область, Озерский район, Озеры, Ленина, 216	f	medium
51594	59125	1968	Московская область, Озерский район, Озеры, Болотный переулок, 4	f	large
51590	94596	1964	Московская область, Озерский район, Озеры, 2-я Высокополянская, 63	f	medium
51606	59135	1980	Московская область, Озерский район, деревня Емельяновка, Помещение сельского клуба	f	medium
51600	59130	1974	Московская область, Озерский район, село Бояркино, Школьная, 34	f	large
51602	94597	1976	Московская область, Озерский район, село Белые Колодези, Помещение Белоколодезской сельской библиотеки	f	small
51483	59036	1857	Московская область, Одинцовский район, коттеджный поселок Ромашково, Советская, 8	f	medium
51558	59095	1932	Московская область, Одинцовский район, село Юдино, 1-е Успенское шоссе, 2А	f	large
51579	59109	1953	Московская область, Одинцовский район, деревня Часцы, Часцовская школа	f	medium
51576	59106	1950	Московская область, Одинцовский район, деревня Часцы, Культурно спортивный центр	t	large
51560	59097	1934	Московская область, Одинцовский район, деревня Хлюпино, Заводская , 2А	f	large
51574	59104	1948	Московская область, Одинцовский район, село Успенское, Успенский дом культуры	f	large
51546	59083	1920	Московская область, Одинцовский район, село Усово, дом отдыха ОгаревоУсовская начальная школа	f	large
51435	59013	1819	Московская область, Ногинский район, село Ямкино, Центральная усадьба, 43	f	large
51570	94592	1944	Московская область, Одинцовский район, поселок Старый Городок, Школьная улица, 28, Старогородковская средняя общеобразовательная школа - 143079	f	large
51569	94592	1943	Московская область, Одинцовский район, поселок Старый Городок, Школьная улица, 28, Старогородковская средняя общеобразовательная школа - 143079	f	large
51552	59089	1926	Московская область, Одинцовский район, село Саввинская Слобода, Юбилейная, 80А	f	large
51578	59108	1952	Московская область, Одинцовский район, поселок Покровское, филиал Часцовской школы	f	large
51557	59094	1931	Московская область, Одинцовский район, село Перхушково, 2Б	f	large
51489	59041	1863	Россия, Московская область, Одинцовский район, Одинцово, поселок БЗРИ	f	large
51500	58790	1874	Россия, Московская область, Одинцовский район, Одинцово, микрорайон Одинцово-1	f	large
51499	58778	1873	Россия, Московская область, Одинцовский район, Одинцово, 3	f	medium
51469	59027	1843	Россия, Московская область, Одинцовский район, Одинцово, улица Маршала Жукова, 38	f	large
51538	59075	1912	Россия, Московская область, Одинцовский район, Одинцово, поселок ВНИИССОК, улица Дениса Давыдова, 1	f	medium
51484	59037	1858	Россия, Московская область, Одинцовский район, Одинцово, бульвар Маршала Крылова, 20	f	large
51480	59033	1854	Россия, Московская область, Одинцовский район, Одинцово, бульвар Маршала Крылова, 5	f	large
51479	59033	1853	Россия, Московская область, Одинцовский район, Одинцово, бульвар Маршала Крылова, 5	f	large
51478	59033	1852	Россия, Московская область, Одинцовский район, Одинцово, бульвар Маршала Крылова, 5	f	large
51466	59025	1840	Россия, Московская область, Одинцовский район, Одинцово, бульвар Любы Новоселовой, 7	f	large
51465	59025	1839	Россия, Московская область, Одинцовский район, Одинцово, бульвар Любы Новоселовой, 7	f	large
51464	59024	1838	Россия, Московская область, Одинцовский район, Одинцово, бульвар Любы Новоселовой, 8	f	large
51495	59044	1869	Московская область, Одинцовский район, Одинцово, Солнечная, 14	f	large
51493	59044	1867	Московская область, Одинцовский район, Одинцово, Солнечная, 14	f	large
51467	59026	1841	Россия, Московская область, Одинцовский район, Одинцово, Северная улица, 60к1	f	large
51471	59029	1845	Московская область, Одинцовский район, Одинцово, Ново-Спортивная, 3	f	large
51454	58008	1828	Россия, Московская область, Одинцовский район, Одинцово, Молодежная улица, 14	f	large
51473	59031	1847	Россия, Московская область, Одинцовский район, Одинцово, Можайское шоссе, 109	f	large
51474	59031	1848	Россия, Московская область, Одинцовский район, Одинцово, Можайское шоссе, 109	f	large
51470	59028	1844	Московская область, Одинцовский район, Одинцово, Маршала Жукова, 38	f	large
51468	59020	1842	Московская область, Одинцовский район, Одинцово, Маршала Жукова, 26	f	large
51459	59020	1833	Московская область, Одинцовский район, Одинцово, Маршала Жукова, 26	f	large
51535	59072	1909	Московская область, Одинцовский район, Одинцово, Липовая , 1	f	large
51504	59047	1878	Московская область, Одинцовский район, Одинцово, Комсомольская, 1	f	small
51537	59073	1910	Московская область, Одинцовский район, Одинцово, поселок ВНИИССОК, Дружбы, 11	f	large
51490	59042	1864	Московская область, Одинцовский район, Одинцово, Вокзальная, 35	f	large
51491	59042	1865	Московская область, Одинцовский район, Одинцово, Вокзальная, 35	f	large
51567	59098	1941	Московская область, Одинцовский район, поселок Новый Городок, школа	f	large
51566	59098	1940	Московская область, Одинцовский район, поселок Новый Городок, школа	f	large
51539	59076	1913	Московская область, Одинцовский район, поселок Новоивановское, Агрохимиков, 1	f	large
51540	59077	1914	Московская область, Одинцовский район, Новоивановское, Агрохимиков, 2	f	large
51482	59035	1856	Россия, Московская область, Одинцовский район, село Немчиновка, Советский проспект, 4	f	large
51563	59001	1937	Московская область, Одинцовский район, поселок Назарьево, микрорайон Фирсановка, стр.39	f	large
111626	59049	1881	Московская область, Одинцовский район, деревня Малые Вяземы, Петровское шоссе, 3, Тренажерный зал дома № 3 – 143050	f	\N
51559	59096	1933	Московская область, Одинцовский район, поселок Летний Отдых, Зеленая, 9А	f	large
51434	59012	1818	Московская область, Ногинский район, село Ямкино, Московская, 12	f	medium
51534	59071	1908	Россия, Московская область, Одинцовский район, поселок городского типа Лесной городок, Фасадная улица, 10	f	large
51533	59070	1907	Московская область, Одинцовский район, поселок Лесной городок, Фасадная, 7	f	large
51556	59093	1930	Московская область, Одинцовский район, поселок Лесной городок, Осоргино, административное здание пасионата	f	small
51525	59063	1899	Московская область, Одинцовский район, Кубинка, Клуб города Кубинка	f	small
51523	59061	1897	Московская область, Одинцовский район, Кубинка, Кубинка-8, ГДО №140	f	large
51522	59061	1896	Московская область, Одинцовский район, Кубинка, Кубинка-8, ГДО №140	f	large
51521	59060	1895	Московская область, Одинцовский район, Кубинка, Кубинка-8, ГДО №140	f	large
51551	59088	1925	Московская область, Одинцовский район, село Каринское, 10Б	f	large
51541	59078	1915	Московская область, Одинцовский район, поселок Заречье, Лучистая, 4, главный корпус МУ	f	large
51520	59058	1894	Московская область, Одинцовский район, поселок Заречье, Заречная, 2	f	large
51519	59058	1893	Московская область, Одинцовский район, поселок Заречье, Заречная, 2	f	large
51542	59079	1916	Московская область, Одинцовский район, деревня Жуковка, Дом культуры	f	medium
51553	59090	1927	Московская область, Одинцовский район, село Жаворонки, Лесная улица, 9	f	medium
51554	59091	1928	Московская область, Одинцовский район, село Жаворонки, 30 Лет Октября, 11	f	large
51548	59085	1922	Московская область, Одинцовский район, село Ершово, 3А	f	large
51532	59069	1906	Московская область, Одинцовский район, поселок Дубки, 9	f	small
51547	59084	1921	Московская область, Одинцовский район, поселок Горки-23	f	large
51572	94593	1946	Московская область, Одинцовский район, поселок Горки-10, 6А, МУККТ Горковский муниципальный сельский дом культуры	f	large
51573	59103	1947	Московская область, Одинцовский район, поселок Горки-10, школа	f	large
51562	58852	1936	Московская область, Одинцовский район, поселок Горбольницы № 45, 3	t	medium
52380	59750	2756	Россия, Московская область, Одинцовский район, Голицыно, проспект Луначарского, 33	f	large
51515	59054	1889	Россия, Московская область, Одинцовский район, Голицыно, проспект Керамиков, 98	f	large
51513	59052	1887	Россия, Московская область, Одинцовский район, Голицыно, Советская улица, 56к1	f	large
51516	59055	1890	Россия, Московская область, Одинцовский район, Голицыно, Пролетарский проспект, 27	f	large
51514	59053	1888	Россия, Московская область, Одинцовский район, Голицыно, Пролетарский проспект, 50	f	large
51510	59051	1884	Россия, Московская область, Одинцовский район, Голицыно, Молодежный проезд, 1	f	large
51512	59051	1886	Россия, Московская область, Одинцовский район, Голицыно, Молодежный проезд, 1	f	large
51511	59051	1885	Россия, Московская область, Одинцовский район, Голицыно, Молодежный проезд, 1	f	large
51517	59056	1891	Московская область, Одинцовский район, Голицыно, Минское шоссе, 45км	f	large
51565	94590	1939	Московская область, Одинцовский район, деревня Гигирево, 1, квартира 3	t	medium
51577	59107	1951	Россия, Московская область, Одинцовский район, поселок Гарь-Покровское	f	large
51561	58824	1935	Московская область, Одинцовский район, деревня Введенское, 156А	f	medium
111628	59074	1911	Московская область, Одинцовский район, поселок ВНИИССОК, улица Дружбы, 11, Детский сад № 6	f	\N
51506	59048	1879	Россия, Омская область, Омск, военный городок 17-й, 17-й Военный городок	f	large
51507	59048	1880	Россия, Омская область, Омск, военный городок 17-й, 17-й Военный городок	f	large
51509	59050	1883	Московская область, Одинцовский район, поселок городского типа Большие Вяземы, Можайское шоссе, 49	f	large
51508	59050	1882	Московская область, Одинцовский район, поселок городского типа Большие Вяземы, Можайское шоссе, 49	f	large
51543	94591	1917	Московская область, Одинцовский район, поселок Барвиха, 39	f	large
51545	59082	1919	Московская область, Одинцовский район, поселок Барвиха, 40	f	large
51544	59081	1918	Россия, Московская область, Одинцовский район, поселок Барвиха	f	large
51402	58985	1792	Россия, Московская область, Ногинский район, поселок городского типа имени Воровского, улица Сергеева	f	large
51401	58985	1791	Россия, Московская область, Ногинский район, поселок городского типа имени Воровского, улица Сергеева	f	large
82166	56257	1332	Москва, Юных Ленинцев, 40к4	f	large
51424	58973	1776	Московская область, Ногинский район, Электроугли, микрорайон Светлый, 27, Библиотека	t	large
51418	58968	1770	Московская область, Ногинский район, Электроугли, Школьная, 57, КДЦ Квант	f	large
51422	58971	1774	Россия, Московская область, Ногинский район, Электроугли, Советская улица, 11	f	large
51419	58969	1771	Московская область, Ногинский район, Электроугли, Парковая улица, 20 б, МОУ СОШ № 33	f	large
51421	58970	1773	Московская область, Ногинский район, Электроугли, Октябрьская, 4, здание колледжа	f	large
51416	58966	1768	Московская область, Ногинский район, Электроугли, Маяковского, 12, МОУ СОШ № 30 старое здание	f	large
51415	58966	1767	Московская область, Ногинский район, Электроугли, Маяковского, 12, МОУ СОШ № 30 старое здание	f	large
52610	59952	2986	Московская область, Ногинский район, Фрязино, Полевая, 18А	f	large
52609	59952	2985	Московская область, Ногинский район, Фрязино, Полевая, 18А	f	large
52608	59952	2984	Московская область, Ногинский район, Фрязино, Полевая, 18А	f	large
51409	59006	1812	Московская область, Ногинский район, поселок Фрязево, МОУ СОШ № 41	f	small
51412	59009	1815	Московская область, Ногинский район, поселок Фрязево, Железнодорожная, 1	f	medium
51395	58988	1795	Московская область, Ногинский район, деревня Тимохово, Совхозная, 19, СДК "Тимоховский"	f	medium
51445	58998	1805	Московская область, Ногинский район, деревня Тимково, Школьная, МОУ ТООШ № 59	f	small
51449	59004	1810	Московская область, Ногинский район, село Стромынь, Большая Стромынка, МОУ СОШ № 54	t	small
51396	58989	1796	Московская область, Ногинский район, деревня Старые Псарьки, МОУ СОШ № 67	f	medium
51427	58975	1779	Россия, Московская область, Ногинский район, Старая Купавна, Школьный проезд, 2	f	large
49955	57880	328	Россия, Московская область, Ногинский район, Старая Купавна, Октябрьская улица, 33	f	large
51430	94587	1782	Московская область, Ногинский район, Старая Купавна, Большая Московская, 22, МОУ СОШ №22	f	large
51432	58978	1784	Московская область, Ногинский район, Старая Купавна, Большая Московская, МОУ СОШ № 22	f	large
51429	58976	1781	Московская область, Ногинский район, Старая Купавна, Большая Московская, 190	f	large
51428	58976	1780	Московская область, Ногинский район, Старая Купавна, Большая Московская, 190	f	large
51399	58992	1799	Московская область, Ногинский район, поселок Радиоцентра, здание ЖКО	t	small
51438	94589	1822	Московская область, Ногинский район, деревня Пятково, Береговая, 1/1, МОУ ООШ №78	f	medium
51439	59017	1823	Московская область, Ногинский район, деревня Пятково, Береговая, 2/1, здание администрации	f	small
50582	58407	954	Московская область, Ногинский район, деревня Пешково, Лесная, 15, РЭУ Заречный	f	medium
50554	58387	926	Россия, Московская область, Ногинский район, поселок городского типа Обухово, улица Калинина, 24	f	large
51406	58983	1789	Россия, Московская область, Ногинский район, поселок городского типа Обухово, Советская улица, 25	f	large
51407	58980	1786	Россия, Московская область, Ногинский район, поселок городского типа Обухово, Советская улица, 25	f	large
51403	58984	1790	Московская область, Ногинский район, поселок городского типа Обухово, Советская, 25, правое фойе	f	large
51404	58981	1787	Московская область, Ногинский район, поселок городского типа Обухово, Московская, 4, МОУ СОШ № 24	f	large
51405	58982	1788	Россия, Московская область, Ногинский район, поселок городского типа Обухово, Кудиновское шоссе, 6	f	medium
51414	59011	1817	Московская область, Ногинский район, Ногинск, МОУ СОШ № 42	f	large
50070	57976	442	Россия, Московская область, Ногинский район, Ногинск, шоссе Энтузиастов, 9	f	large
50069	57976	441	Россия, Московская область, Ногинский район, Ногинск, шоссе Энтузиастов, 9	f	large
50067	57974	439	Россия, Московская область, Ногинский район, Ногинск, шоссе Энтузиастов, 21	f	large
51373	58946	1725	Россия, Московская область, Ногинский район, Ногинск, улица Третьего Интернационала, 59	f	large
51348	58959	1749	Россия, Московская область, Ногинский район, Ногинск, улица Текстилей, 17	f	large
51336	56730	1750	Россия, Московская область, Ногинский район, Ногинск, улица 28 Июня 1906 Года, 5	f	large
51387	58949	1735	Московская область, Ногинский район, Ногинск, Юбилейная, 13	f	large
51386	58949	1734	Московская область, Ногинский район, Ногинск, Юбилейная, 13	f	large
51385	58949	1733	Московская область, Ногинский район, Ногинск, Юбилейная, 13	f	large
51383	58949	1731	Московская область, Ногинский район, Ногинск, Юбилейная, 13	f	large
51390	58952	1738	Московская область, Ногинский район, Ногинск, Электростальское шоссе, 14	f	medium
51367	94584	1710	Московская область, Ногинский район, Ногинск, Центральная, 8	t	large
51381	58948	1730	Московская область, Ногинский район, Ногинск, Третьего Интернационала, 117а	f	large
51380	58948	1729	Московская область, Ногинский район, Ногинск, Третьего Интернационала, 117а	f	large
51382	58943	1721	Московская область, Ногинский район, Ногинск, Третьего Интернационала, 139	f	large
51349	58958	1747	Московская область, Ногинский район, Ногинск, Советской Конституции, 58	f	large
51351	58958	1762	Московская область, Ногинский район, Ногинск, Советской Конституции, 58	f	large
51350	58958	1761	Московская область, Ногинский район, Ногинск, Советской Конституции, 58	f	large
51374	58947	1726	Московская область, Ногинский район, Ногинск, Советская, 57	f	large
51357	58956	1742	Россия, Московская область, Ногинский район, Ногинск, Ремесленная улица, 15	f	large
51343	58962	1757	Московская область, Ногинский район, Ногинск, Новая , 1	f	large
51365	58936	1712	Московская область, Ногинский район, Ногинск, Нижегородская улица, 30	f	medium
111624	58945	1724	Московская область, Ногинский район, Ногинск, Комсомольская улица, 3, МОУ СОШ № 14	f	\N
51369	94585	1718	Московская область, Ногинский район, Ногинск, Климова, 35, Дом художника	f	large
51370	58942	1719	Московская область, Ногинский район, Ногинск, Климова, 30а	f	medium
51337	56739	1751	Московская область, Ногинский район, Ногинск, Белякова, 21А	f	large
51338	56739	1752	Московская область, Ногинский район, Ногинск, Белякова, 21А	f	large
51341	56739	1755	Московская область, Ногинский район, Ногинск, Белякова, 21А	f	large
51339	56739	1753	Московская область, Ногинский район, Ногинск, Белякова, 21А	f	large
51366	58935	1711	Московская область, Ногинский район, Ногинск, Аэроклубная, 4	f	large
51362	58938	1714	Россия, Московская область, Ногинский район, Ногинск, Автобазовая улица, 4	f	large
51345	58954	1740	Московская область, Ногинский район, Ногинск,  Текстилей, 31	f	large
51347	58954	1760	Московская область, Ногинский район, Ногинск,  Текстилей, 31	f	large
51346	58954	1759	Московская область, Ногинский район, Ногинск,  Текстилей, 31	f	large
51355	58954	1746	Московская область, Ногинский район, Ногинск,  Текстилей, 31	f	large
51368	58940	1717	Московская область, Ногинский район, Ногинск,  Климова, 48	f	large
51411	59008	1814	Московская область, Ногинский район, поселок Новые Дома, 6	f	large
51443	58997	1804	Московская область, Ногинский район, поселок Новостройка, 3а, СДК	f	large
51391	58964	1763	Московская область, Ногинский район, деревня Молзино, Советская, 61а	f	large
51446	58999	1806	Россия, Московская область, Ногинский район, село Мамонтово	t	medium
111625	59000	1807	Московская область, Ногинский район, село Мамонтово, Горького, адм. здание ООО Эллота	f	\N
51394	58987	1794	Московская область, Ногинский район, село Кудиново, Центральная, 17	f	large
51393	58986	1793	Московская область, Ногинский район, село Кудиново, Напрудная, 5, СДК Кудиновский	f	medium
51397	58990	1797	Московская область, Ногинский район, деревня Колонтаево, Административное здание д/о Колонтаево	f	small
51440	58994	1801	Московская область, Ногинский район, деревня Караваево, Спортивная, 3/4, клуб	f	large
51413	59010	1816	Московская область, Ногинский район, деревня Иванисово, Ценральная усадьба, адм. здание ЗАО Электростальское	f	medium
51433	58979	1785	Московская область, Ногинский район, поселок Зеленый, 4	t	large
51408	59005	1811	Московская область, Ногинский район, деревня Есино, 36, фельдшерско-акушерский пункт	t	small
51398	94588	1798	Московская область, Ногинский район, деревня Ельня, Библиотека	t	small
51410	59007	1813	Московская область, Ногинский район, поселок Елизаветино, Центральная, 29 а	f	medium
51400	58993	1800	Московская область, Ногинский район, поселок Горбуша, здание бывшего клуба	t	small
51423	94586	1775	Московская область, Ногинский район, деревня Вишняково, Школьная, 1, МОУ НОШ №29	f	medium
51447	59002	1808	Московская область, Ногинский район, деревня Боровково, Поселок Фабрики, здание бывшего д/с	t	small
51441	58995	1802	Московская область, Ногинский район, деревня Большое Буньково, мкр.Фабрики, 37А	f	large
51442	58996	1803	Московская область, Ногинский район, деревня Большое Буньково, Демонстрационная, 24	f	medium
51320	58921	1695	Московская область, Наро-Фоминский район, поселок совхоза Архангельский	f	large
52502	94644	2876	Московская область, Наро-Фоминский район, коттеджный поселок Лесное озеро, Садовая	f	medium
51326	58925	1701	Россия, Московская область, Наро-Фоминский район, деревня Яковлевское	f	large
51325	58925	1700	Россия, Московская область, Наро-Фоминский район, деревня Яковлевское	f	large
51317	58918	1692	Московская область, Наро-Фоминский район, деревня Шустиково, Здание Шустиковского д/с	f	medium
51571	59101	1945	Московская область, Наро-Фоминский район, деревня Шарапово, школа	f	large
51319	58920	1694	Московская область, Наро-Фоминский район, деревня Устье, Здание ЗАО Татищево	f	medium
51331	58930	1706	Московская область, Наро-Фоминский район, деревня Таширово, Центральная, 5	f	large
51309	58910	1684	Московская область, Наро-Фоминский район, деревня Софьино, Здание Софьинской СШ	f	large
51323	58923	1698	Россия, Московская область, Наро-Фоминский район, поселок Совхоза Крекшино	f	large
51284	58891	1659	Московская область, Наро-Фоминский район, деревня Симбухово, Нарская, стр.12	f	small
51305	58907	1680	Московская область, Наро-Фоминский район, поселок Селятино, Здание спорткомбината Строитель	f	large
51306	58908	1681	Россия, Московская область, Наро-Фоминский район, поселок городского типа Селятино	f	large
51304	58906	1679	Россия, Московская область, Наро-Фоминский район, поселок городского типа Селятино	f	large
51307	58906	1682	Россия, Московская область, Наро-Фоминский район, поселок городского типа Селятино	f	large
51285	58892	1660	Московская область, Наро-Фоминский район, деревня Рождествено, Школьная, 16	f	small
51324	58924	1699	Московская область, Наро-Фоминский район, поселок Рассудово, Майская, 25	f	small
51329	58928	1704	Россия, Московская область, Наро-Фоминский район, поселок Птичное	f	large
51328	58927	1703	Московская область, Наро-Фоминский район, поселок Птичное, Здание ДКиС Десна	f	large
51286	58893	1661	Московская область, Наро-Фоминский район, поселок Пионерский, Центральная	f	small
51327	58926	1702	Московская область, Наро-Фоминский район, поселок Первомайское, Центральная	f	large
51313	58914	1688	Московская область, Наро-Фоминский район, деревня Новая Ольховка, Школьная, 2/1	f	large
51265	58875	1640	Московская область, Наро-Фоминский район, Наро-Фоминск, Шибанкова, 13	f	large
51263	58874	1638	Московская область, Наро-Фоминский район, Наро-Фоминск, Шибанкова, 44	f	large
111622	94579	1615	Московская область, Наро-Фоминский район, Наро-Фоминск, Чехова, 1а	f	\N
51246	58841	1621	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, Профсоюзная улица, 9а	f	large
51245	58841	1620	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, Профсоюзная улица, 9а	f	large
51249	58841	1624	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, Профсоюзная улица, 9а	f	large
51243	58861	1618	Московская область, Наро-Фоминский район, Наро-Фоминск, Маршала Жукова, 10	f	large
51247	58863	1622	Московская область, Наро-Фоминский район, Наро-Фоминск, Ленина, 23	f	large
51251	58678	1626	Московская область, Наро-Фоминский район, Наро-Фоминск, Ленина, 17	f	large
51242	58860	1617	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, Комсомольская улица, 9	f	large
51256	58868	1631	Московская область, Наро-Фоминский район, Наро-Фоминск, Генерала Ефремова, 11	f	large
51255	58868	1630	Московская область, Наро-Фоминский район, Наро-Фоминск, Генерала Ефремова, 11	f	large
51257	58869	1632	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, 2-й Володарский переулок, 4	f	large
51241	94580	1616	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, 1-й Колхозный переулок, 1	f	medium
51786	59154	2160	Московская область, Наро-Фоминский район, деревня Назарьево, 160	f	small
51322	58922	1697	Московская область, Наро-Фоминский район, садовое товарищество Марушкино,  Липовая аллея, 6	f	large
51321	58922	1696	Московская область, Наро-Фоминский район, садовое товарищество Марушкино,  Липовая аллея, 6	f	large
51281	58888	1656	Московская область, Наро-Фоминский район, деревня Мартемьяново, 104а	f	medium
51333	58932	1708	Россия, Московская область, Наро-Фоминский район, деревня Любаново	f	medium
52726	60046	3103	Московская область, Наро-Фоминский район, деревня Крюково, 17, Средняя общеобразовательная школа	f	large
51303	58905	1678	Московская область, Наро-Фоминский район, поселок городского типа Кокошкино, Ленина, 2	f	large
51302	58904	1677	Московская область, Наро-Фоминский район, поселок Кокошкино, Дачная, 3	f	large
51301	58904	1676	Московская область, Наро-Фоминский район, поселок Кокошкино, Дачная, 3	f	large
51300	58904	1675	Московская область, Наро-Фоминский район, поселок Кокошкино, Дачная, 3	f	large
51788	59233	2162	Московская область, Наро-Фоминский район, деревня Ковригино, 156	f	small
51299	58903	1674	Россия, Московская область, Наро-Фоминский район, поселок городского типа Киевский	f	large
51298	58902	1673	Россия, Московская область, Наро-Фоминский район, поселок городского типа Киевский	f	large
51297	58901	1672	Россия, Московская область, Наро-Фоминский район, поселок городского типа Киевский	f	large
51314	58915	1689	Россия, Московская область, Наро-Фоминский район, село Каменское	f	large
51294	94583	1669	Московская область, Наро-Фоминский район, поселок Калининец, 233/1, СДЦ Калининец спортивный зал	f	large
51296	58900	1671	Россия, Московская область, Наро-Фоминский район, поселок Калининец, село Петровское	f	large
51293	58897	1668	Россия, Московская область, Наро-Фоминский район, поселок Калининец	f	large
51292	58896	1667	Россия, Московская область, Наро-Фоминский район, поселок Калининец	f	large
51287	58894	1662	Московская область, Наро-Фоминский район, поселок Калининец, мкрн Тарасково	f	large
51290	58894	1665	Московская область, Наро-Фоминский район, поселок Калининец, мкрн Тарасково	f	large
51289	58894	1664	Московская область, Наро-Фоминский район, поселок Калининец, мкрн Тарасково	f	large
51288	58894	1663	Московская область, Наро-Фоминский район, поселок Калининец, мкрн Тарасково	f	large
51291	58895	1666	Московская область, Наро-Фоминский район, поселок Калининец, мкрн КЭЧ, 245	f	large
51295	58899	1670	Московская область, Наро-Фоминский район, поселок Калининец, Фабричная, 1	f	large
51330	58929	1705	Московская область, Наро-Фоминский район, хутор Ильичёвка, 5	t	large
51254	58867	1629	Московская область, Наро-Фоминский район, деревня Ивановка, Здание библиотеки (читальный зал)	f	small
50814	58558	1188	Московская область, Наро-Фоминский район, садовое товарищество Десна, Административная, 9а	f	small
51334	58933	1709	Россия, Московская область, Наро-Фоминский район, деревня Головково	f	large
51332	58931	1707	Московская область, Наро-Фоминский район, садовое товарищество Восток (Наро-Фоминск-10), Здание гарнизонного офицерского клуба	f	large
51318	58919	1693	Московская область, Наро-Фоминский район, деревня Волченки, Здание ООО Агрофирма Ковригино	f	medium
51316	58917	1691	Россия, Московская область, Наро-Фоминский район, деревня Веселево	f	large
51283	58890	1658	Московская область, Наро-Фоминский район, Верея, Первомайская улица, 8/1	f	large
51259	58871	1634	Московская область, Наро-Фоминский район, поселок Бекасово, Здание Бекасовской СОШ	f	medium
49640	57620	13	Московская область, Наро-Фоминский район, Балашиха, Орджоникидзе, 14	f	large
51311	58912	1686	Россия, Московская область, Наро-Фоминский район, село Атепцево	f	medium
51312	58913	1687	Московская область, Наро-Фоминский район, село Атепцево, Речная, 1а	f	large
51279	58886	1654	Московская область, Наро-Фоминский район, Апрелевка, Школьная, 4	f	large
50867	94567	1241	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 4	f	large
52935	60226	3312	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 12	f	large
52934	60226	3311	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 12	f	large
49963	57887	336	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 2	f	medium
49962	57887	335	Россия, Московская область, Наро-Фоминский район, Апрелевка, Спортивная улица, 2	f	large
51278	58885	1653	Московская область, Наро-Фоминский район, Апрелевка, Самохина, 9	f	large
82165	56256	1331	Москва, Юных Ленинцев, 45к2	f	large
51277	58884	1652	Россия, Московская область, Наро-Фоминский район, Апрелевка, Парковая улица, 6/3	f	large
51270	94581	1645	Московская область, Наро-Фоминский район, Апрелевка, Куйбышева, Апрелевская СОШ № 2	f	medium
51272	58880	1647	Россия, Московская область, Наро-Фоминский район, Апрелевка, Комсомольская улица, 15а	f	large
51271	58880	1646	Россия, Московская область, Наро-Фоминский район, Апрелевка, Комсомольская улица, 15а	f	large
51275	58882	1650	Московская область, Наро-Фоминский район, Апрелевка, Горького, 2	f	large
51280	94582	1655	Московская область, Наро-Фоминский район, Апрелевка, Апрелевская , 65, здание ЦНИИЭПсельстрой	f	large
51308	58909	1683	Московская область, Наро-Фоминский район, деревня Алабино, Здание ПУ №71	f	medium
52584	59932	2960	Московская область, Мытищинский район, деревня Юдино, 16, Юдинский сельский Дом культуры	t	small
51233	58848	1606	Московская область, Мытищинский район, село Федоскино, в помещении административного здания	f	medium
51230	58845	1603	Московская область, Мытищинский район, поселок Туристический пансионат Клязьменское водохранилище, СОШ № 22	f	large
51220	58836	1593	Московская область, Мытищинский район, село Троицкое, в помещении санатория «Дружба»	f	small
51236	58851	1609	Московская область, Мытищинский район, деревня Сухарево, 56	f	medium
51221	58837	1594	Московская область, Мытищинский район, поселок Поведники, Поведниковская школа	f	large
51226	58840	1599	Московская область, Мытищинский район, поселок городского типа Пироговский, Пионерская, 4	f	large
51225	58840	1598	Московская область, Мытищинский район, поселок городского типа Пироговский, Пионерская, 4	f	large
51224	58840	1597	Московская область, Мытищинский район, поселок городского типа Пироговский, Пионерская, 4	f	large
51227	58842	1600	Россия, Московская область, Мытищинский район, деревня Пирогово	f	medium
51187	58816	1560	Россия, Московская область, Мытищинский район, Мытищи, улица Щербакова, 1а	f	large
51186	58811	1559	Россия, Московская область, Мытищинский район, Мытищи, улица Мира, 22	f	large
51180	58811	1553	Россия, Московская область, Мытищинский район, Мытищи, улица Мира, 22	f	large
51173	58806	1546	Россия, Московская область, Мытищинский район, Мытищи, улица Комарова, 5	f	large
51174	58807	1547	Московская область, Мытищинский район, Мытищи, улица Колпакова, 22	f	large
51216	58832	1589	Россия, Московская область, Мытищинский район, Мытищи, улица Веры Волошиной, 56	t	medium
51169	58804	1542	Россия, Московская область, Мытищинский район, Мытищи, улица Белобородова, 2к3	f	large
51215	58825	1588	Россия, Московская область, Мытищинский район, Мытищи, Юбилейная улица, 42к2	f	large
51204	58825	1577	Россия, Московская область, Мытищинский район, Мытищи, Юбилейная улица, 42к2	f	large
51203	58825	1576	Россия, Московская область, Мытищинский район, Мытищи, Юбилейная улица, 42к2	f	large
51184	94577	1557	Московская область, Мытищинский район, Мытищи, Юбилейная, 13к2, МОУ средняя общеобразовательная школа №26	f	large
51191	58819	1564	Московская область, Мытищинский район, Мытищи, Юбилейная, 13к2	f	large
51148	58787	1521	Россия, Московская область, Мытищинский район, Мытищи, Школьный переулок, 3	f	large
51178	58808	1551	Московская область, Мытищинский район, Мытищи, Шараповская, 6к2	f	large
51177	58808	1550	Московская область, Мытищинский район, Мытищи, Шараповская, 6к2	f	large
51176	58808	1549	Московская область, Мытищинский район, Мытищи, Шараповская, 6к2	f	large
51175	58808	1548	Московская область, Мытищинский район, Мытищи, Шараповская, 6к2	f	large
51160	58798	1533	Московская область, Мытищинский район, Мытищи, Чапаева, помещение санатория Подлипки	f	large
51164	58801	1537	Россия, Московская область, Мытищинский район, Мытищи, Силикатная улица, 12	f	medium
51162	58800	1535	Россия, Московская область, Мытищинский район, Мытищи, Силикатная улица, 36	f	large
51165	58802	1538	Московская область, Мытищинский район, Мытищи, Силикатная, 1/9	f	large
51206	58827	1579	Россия, Московская область, Мытищинский район, Мытищи, Новомытищинский проспект, 88к5	f	large
51197	58821	1570	Россия, Московская область, Мытищинский район, Мытищи, Новомытищинский проспект, 39к3	f	large
51207	58821	1580	Россия, Московская область, Мытищинский район, Мытищи, Новомытищинский проспект, 39к3	f	large
51196	58821	1569	Россия, Московская область, Мытищинский район, Мытищи, Новомытищинский проспект, 39к3	f	large
51201	58823	1574	Россия, Московская область, Мытищинский район, Мытищи, Летная улица, 30к2	f	large
51200	58823	1573	Россия, Московская область, Мытищинский район, Мытищи, Летная улица, 30к2	f	large
51199	58823	1572	Россия, Московская область, Мытищинский район, Мытищи, Летная улица, 30к2	f	large
51185	94578	1558	Московская область, Мытищинский район, Мытищи, Летная, 14к1, в помещении центральной библиотеки ЦБС Мытищинского района	f	large
51150	58789	1523	Московская область, Мытищинский район, Мытищи, Карла Маркса, 4, в помещении администра	f	large
51208	58828	1581	Московская область, Мытищинский район, Мытищи, Веры Волошиной, 24	f	large
51156	58795	1529	Московская область, Мытищинский район, Мытищи, Академика Каргина, 38к4	f	large
51153	58793	1526	Московская область, Мытищинский район, Мытищи, Академика Каргина, 36к2	f	large
51161	58799	1534	Россия, Московская область, Мытищинский район, Мытищи, 2-я Новая улица, 30	f	large
51159	58797	1532	Московская область, Мытищинский район, Мытищи, 2-я Институтская улица, 20, общежитие №5 	f	large
51151	58791	1524	Россия, Московская область, Мытищинский район, Мытищи, 2-й Первомайский проезд, 1	f	large
51212	58830	1585	Россия, Московская область, Мытищинский район, Мытищи, 1-я Крестьянская улица, 14	f	large
51211	58830	1584	Россия, Московская область, Мытищинский район, Мытищи, 1-я Крестьянская улица, 14	f	large
51158	58796	1531	Московская область, Мытищинский район, Мытищи, 1-й Щелковский проезд, 9	f	large
51157	58796	1530	Московская область, Мытищинский район, Мытищи, 1-й Щелковский проезд, 9	f	large
51155	58794	1528	Московская область, Мытищинский район, Мытищи, 1-й Щелковский проезд, 9, помещение МОУ лиц	f	large
51235	58850	1608	Московская область, Мытищинский район, село Марфино, Марфинская средняя школа	f	large
51237	58853	1610	Московская область, Мытищинский район, село Марфино, Усадебная, 21А	f	large
51231	58846	1604	Московская область, Мытищинский район, деревня Манюхино, ДК Манюхинск	f	small
51232	58847	1605	Московская область, Мытищинский район, деревня Красная Горка, Светлая, 16	f	medium
51228	58843	1601	Московская область, Мытищинский район, поселок Здравница, Дубки, 1	f	medium
51229	58844	1602	Россия, Московская область, Мытищинский район, поселок Жостово	f	large
51219	58835	1592	Московская область, Мытищинский район, село Виноградово, 36-Г	f	small
51218	58834	1591	Московская область, Мытищинский район, поселок Вешки, Заводская, 5	f	medium
51217	58833	1590	Московская область, Мытищинский район, деревня Бородино, администрация городского поселения	f	medium
51238	58854	1611	Московская область, Мытищинский район, деревня Большое Ивановское, 113	f	small
51222	58838	1595	Московская область, Мытищинский район, деревня Болтино, помещение клуба	f	small
51223	58839	1596	Московская область, Мытищинский район, деревня Беляниново, общеобразовательная школа № 29	f	large
51234	58849	1607	Московская область, Мытищинский район, деревня Аксаково, в помещении пансионата «Русь»	f	medium
50535	58373	907	Московская область, Московская область, Коломна, Октябрьской Революции, 318, ЦРБ	f	large
51134	58774	1509	Московская область, Можайский район, сельское поселение Порецкое, поселок ц/у с-за "Синичино", 30	f	medium
51108	58751	1483	Московская область, Можайский район, поселок имени Дзержинского, Центр культуры и искусств	f	large
51101	58744	1476	Московская область, Можайский район, деревня Ямская, 47, Отдел УФМС	f	small
51113	58754	1488	Московская область, Можайский район, деревня Шохово, детский сад №22	f	medium
51136	58776	1511	Московская область, Можайский район, поселок Шаликово, сельское поселение Спутник, Сельский клуб 	f	small
51125	58766	1500	Московская область, Можайский район, поселок Цветковский, КДЦ Цветковский	f	medium
51112	58753	1487	Московская область, Можайский район, поселок городского типа Уваровка, Урицкого, 32, Средняя школа	f	medium
51111	58753	1486	Московская область, Можайский район, поселок городского типа Уваровка, Урицкого, 32, Средняя школа	f	medium
51123	58764	1498	Московская область, Можайский район, деревня Горетово, КДЦ Горетово	f	large
50927	58625	1301	Московская область, Луховицкий район, село Матыра, Школьная, 8	f	medium
51110	94575	1485	Московская область, Можайский район, поселок городского типа Уваровка, Партизанская , в помещении муниципального учреждения культуры «Уваровский культурно-досуговый центр» (фойе)	f	medium
51109	94574	1484	Московская область, Можайский район, поселок городского типа Уваровка, Партизанская, в помещении муниципального учреждения культуры «Уваровский культурно-досуговый центр» (танцевальный зал)	f	medium
51140	58781	1515	Россия, Московская область, Можайский район, деревня Тропарево	f	small
51139	58780	1514	Московская область, Можайский район, деревня Тропарево, Советская, 14, администрация С/П	f	small
51122	58763	1497	Московская область, Можайский район, деревня Троица, Троицкий клуб, Сельский КДЦ Горки	f	small
51107	58750	1482	Московская область, Можайский район, поселок Строитель, Актовый зал ЗАО 198 КЖИ	f	large
51106	58749	1481	Московская область, Можайский район, поселок Строитель, Профессиональное училище №97	f	medium
51135	58775	1510	Россия, Московская область, Можайский район, поселок Спутник	f	large
51142	58783	1517	Московская область, Можайский район, село Сокольниково, Школьная, 1, Средняя школа	f	medium
51141	58782	1516	Московская область, Можайский район, село Сокольниково, Школьная, 1, Средняя школа	f	small
51127	58768	1502	Московская область, Можайский район, деревня Семеновское, ДК КДЦ Замошинское	f	medium
51132	58772	1507	Московская область, Можайский район, село Поречье, КДЦ Поречье	f	large
51131	58771	1506	Россия, Московская область, Можайский район, деревня Павлищево	f	large
51129	58769	1504	Московская область, Можайский район, деревня Мокрое, Пионерская, 26, КДЦ Замошинское	f	medium
51128	58769	1503	Московская область, Можайский район, деревня Мокрое, Пионерская, 26, КДЦ Замошинское	f	small
51105	58748	1480	Московская область, Можайский район, Можайск, поселок Медико-Инструментального Завода, Сельский дом культуры пос.МИЗ	f	large
51104	58747	1479	Московская область, Можайский район, Можайск, поселок Гидроузел, Гидроузловский сельский дом культуры	f	medium
51085	58730	1460	Россия, Московская область, Можайский район, Можайск	f	large
51088	58733	1463	Московская область, Можайский район, Можайск, Московская, 48, Средняя школа №1	f	large
51094	58739	1469	Московская область, Можайский район, Можайск, Мира, 15, Дворец спорта Багратион	f	large
51092	58737	1467	Московская область, Можайский район, Можайск, Мира, 1	f	large
51630	59153	2004	Россия, Московская область, Можайский район, Можайск, Красноармейская улица, 11	f	large
51097	58741	1472	Московская область, Можайский район, Можайск, Восточная , 19, Гимназия №4	f	large
51096	58740	1471	Московская область, Можайский район, Можайск, Восточная, 19, Гимназия №4	f	large
51095	58740	1470	Московская область, Можайский район, Можайск, Восточная, 19, Гимназия №4	f	large
51100	58743	1475	Московская область, Можайский район, Можайск, Ватутина, 9, Центр культуры и искусств	f	large
51099	58743	1474	Московская область, Можайский район, Можайск, Ватутина, 9, Центр культуры и искусств	f	large
51087	58732	1462	Московская область, Можайский район, Можайск, Бородинская, 33, ЗАО Дорожник	f	large
51091	58736	1466	Московская область, Можайский район, Можайск, 20 Января, 19, Средняя школа №2	f	large
51090	58735	1465	Московская область, Можайский район, Можайск, 20 Января, 19, Средняя школа №2	f	large
52960	60239	3337	Россия, Московская область, Можайский район, поселок Мира	f	large
52959	60239	3336	Россия, Московская область, Можайский район, поселок Мира	f	large
52958	60239	3335	Россия, Московская область, Можайский район, поселок Мира	f	large
51103	58746	1478	Московская область, Можайский район, деревня Красный Балтиец, 24, Средняя школа	f	medium
51102	58745	1477	Московская область, Можайский район, поселок Колычево, 33	f	large
51130	58770	1505	Россия, Московская область, Можайский район, деревня Клементьево	f	large
51086	58731	1461	Московская область, Можайский район, деревня Исавицы, административное здание ЗАО Рассвет	f	medium
51138	58779	1513	Московская область, Можайский район, деревня Ивакино, 5 , квартира 9	f	medium
51126	58767	1501	Московская область, Можайский район, деревня Дровнино, КДЦ Цветковский	f	medium
51119	58760	1494	Московская область, Можайский район, деревня Горки, 1а, Ворошиловская средняя школа	f	small
51124	58765	1499	Московская область, Можайский район, деревня Горетово, Центральная, 4, Филиал почтампта	f	small
51118	58759	1493	Московская область, Можайский район, поселок Бородинское Поле, Детский сад №26	f	medium
51120	58761	1495	Московская область, Можайский район, деревня Бородино, Сельский КДЦ Горки	f	small
51116	58757	1491	Московская область, Можайский район, село Борисово, Администрация сельского поселения Борисовское	f	small
51115	58756	1490	Московская область, Можайский район, село Борисово, Средняя школа	f	small
51114	58755	1489	Московская область, Можайский район, село Борисово, КДЦ Борисово	f	medium
51137	58777	1512	Московская область, Можайский район, деревня Большое Тесово, Сельский клуб Тесово	f	small
52923	60117	3300	Россия, Московская область, Можайский район, деревня Барыши	t	large
51133	58773	1508	Московская область, Можайский район, деревня Астафьево, Астафьевский ФАП	t	small
51117	58758	1492	Московская область, Можайский район, деревня Андреевское, Клуб КДЦ Борисово	f	small
51121	58762	1496	Московская область, Можайский район, деревня Александрово, Александровский СДК Сельский КДЦ Горки	f	medium
51063	58716	1438	Московская область, Люберецкий район, поселение Малаховка, Большое Кореневское шоссе, 25, детский санаторий	f	medium
51050	58707	1425	Московская область, Люберецкий район, поселок Томилино, микрорайон Птицефабрики, 12/1, Средняя школа №19	f	large
51049	58707	1424	Московская область, Люберецкий район, поселок Томилино, микрорайон Птицефабрики, 12/1, Средняя школа №19	f	large
51047	58705	1422	Московская область, Люберецкий район, поселок Томилино, село Жилино, 128, школа № 23	t	small
51066	58717	1441	Россия, Московская область, Люберецкий район, поселок Томилино, улица Грибоедова, 1	f	small
51065	58717	1440	Россия, Московская область, Люберецкий район, поселок Томилино, улица Грибоедова, 1	f	medium
51064	58717	1439	Россия, Московская область, Люберецкий район, поселок Томилино, улица Грибоедова, 1	f	medium
51056	58712	1431	Россия, Московская область, Люберецкий район, поселок Томилино, улица Гаршина, 9ак8	f	large
51053	58709	1428	Московская область, Люберецкий район, поселок Томилино, Чехова, 2, школа № 17	f	medium
51052	58709	1427	Московская область, Люберецкий район, поселок Томилино, Чехова, 2, школа № 17	f	medium
51048	58706	1423	Московская область, Люберецкий район, поселок Томилино, микрорайон Птицефабрики, Птицефабрика микрорайон, ЛИТ Б	f	large
51061	58714	1436	Московская область, Люберецкий район, поселок Томилино, Пионерская, 1, гимназия № 18	f	large
51060	58714	1435	Московская область, Люберецкий район, поселок Томилино, Пионерская, 1, гимназия № 18	f	large
51059	58714	1434	Московская область, Люберецкий район, поселок Томилино, Пионерская, 1, гимназия № 18	f	large
51058	58714	1433	Московская область, Люберецкий район, поселок Томилино, Пионерская, 1, гимназия № 18	f	large
51046	58704	1421	Московская область, Люберецкий район, поселок Томилино, Октябрьская, 172, школа № 22	f	medium
51055	58711	1430	Московская область, Люберецкий район, поселок Томилино, Гоголя, 19, помещение Совета депутатов	f	large
51057	58713	1432	Московская область, Люберецкий район, поселок Томилино, Гаршина, 9ак5, Дом детск. творчества	f	large
51054	58710	1429	Россия, Московская область, Люберецкий район, поселок городского типа Октябрьский, улица Гоголя, 2	f	large
51045	58703	1420	Московская область, Люберецкий район, Октябрьский, Первомайская, 22, средняя школа № 53	f	large
51044	58703	1419	Московская область, Люберецкий район, Октябрьский, Первомайская, 22, средняя школа № 53	f	large
51043	58703	1418	Московская область, Люберецкий район, Октябрьский, Первомайская, 22, средняя школа № 53	f	large
51041	58703	1416	Московская область, Люберецкий район, Октябрьский, Первомайская, 22, средняя школа № 53	f	large
51040	58703	1415	Московская область, Люберецкий район, Октябрьский, Первомайская, 22, средняя школа № 53	f	large
51042	58703	1417	Московская область, Люберецкий район, Октябрьский, Первомайская, 22, средняя школа № 53	f	large
51051	58708	1426	Московская область, Люберецкий район, поселок Октябрьский, Пушкина, 14, Центр культуры и досуга	f	medium
51083	58728	1458	Московская область, Люберецкий район, деревня Марусино, Заречная, 26 , школа-интернат	t	medium
51073	58722	1448	Россия, Московская область, Люберецкий район, поселок городского типа Малаховка, поселок МЭЗ	f	large
51072	58722	1447	Россия, Московская область, Люберецкий район, поселок городского типа Малаховка, поселок МЭЗ	f	large
51070	58720	1445	Московская область, Люберецкий район, поселок городского типа Малаховка, Шоссейная, 40, клуб "Шахтер"	f	large
51067	58718	1442	Московская область, Люберецкий район, поселок городского типа Малаховка, Новая улица, 23, школа № 50	f	small
51062	58715	1437	Россия, Московская область, Люберецкий район, поселок городского типа Малаховка, Большое Кореневское шоссе, 1	f	medium
51071	58721	1446	Московская область, Люберецкий район, поселок Малаховка, Шоссейная, 33, Академия физкультуры	f	large
51069	58719	1444	Московская область, Люберецкий район, поселок Малаховка, 1-я Комсомольская, 4, средняя школа № 48	f	large
51068	58719	1443	Московская область, Люберецкий район, поселок Малаховка, 1-я Комсомольская, 4, средняя школа № 48	f	large
51015	58690	1390	Московская область, Люберецкий район, Люберцы, 9а , средняя школа № 8	f	large
50997	58679	1372	Московская область, Люберецкий район, Люберцы, Люберцы-350	f	large
51000	58679	1375	Московская область, Люберецкий район, Люберцы, Люберцы-350	f	large
50999	58679	1374	Московская область, Люберецкий район, Люберцы, Люберцы-350	f	large
50998	58679	1373	Московская область, Люберецкий район, Люберцы, Люберцы-350	f	large
51020	58692	1395	Россия, Московская область, Люберецкий район, Люберцы, улица Урицкого, 10	f	large
51019	58692	1394	Россия, Московская область, Люберецкий район, Люберцы, улица Урицкого, 10	f	large
51018	58692	1393	Россия, Московская область, Люберецкий район, Люберцы, улица Урицкого, 10	f	large
51017	58692	1392	Россия, Московская область, Люберецкий район, Люберцы, улица Урицкого, 10	f	large
51034	58699	1409	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 28	f	large
51036	58699	1411	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 28	f	large
51035	58699	1410	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 28	f	large
51033	58698	1408	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 19	f	large
51032	58698	1407	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 19	f	large
51031	58698	1406	Россия, Московская область, Люберецкий район, Люберцы, улица Побратимов, 19	f	large
50981	58671	1356	Россия, Московская область, Люберецкий район, Люберцы, улица Кирова, 47	f	large
51039	58701	1414	Россия, Московская область, Люберецкий район, Люберцы, проспект Победы, 13	f	large
51038	58701	1413	Россия, Московская область, Люберецкий район, Люберцы, проспект Победы, 13	f	medium
51013	58683	1383	Московская область, Люберецкий район, Люберцы, Южная улица, 20, гимназия № 20	f	large
51012	58683	1382	Московская область, Люберецкий район, Люберцы, Южная улица, 20, гимназия № 20	f	large
51011	58683	1381	Московская область, Люберецкий район, Люберцы, Южная улица, 20, гимназия № 20	f	large
51028	58696	1403	Московская область, Люберецкий район, Люберцы, Попова, 14/1, институт коммунального хоз	f	large
51826	59308	2200	Россия, Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 11	f	large
51014	58689	1389	Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 403, комбинат ВИНИТИ	f	large
51003	58687	1386	Россия, Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 341	f	large
51002	58686	1385	Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 349А, ДЮСШ	f	medium
51001	58685	1384	Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 259, Университет Сервиса	f	large
50985	58674	1360	Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 200а, Дворец культуры	f	large
50979	58669	1354	Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 118, школа № 6	f	medium
50978	58668	1353	Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 123, ОАО ЛГЖТ	f	large
50970	58664	1345	Россия, Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 24а	f	large
50969	58663	1344	Московская область, Люберецкий район, Люберцы, Октябрьский проспект, 24а, гимназия № 43	f	large
51006	58680	1376	Московская область, Люберецкий район, Люберцы, Котельническая, 12, учебный центр "Мособлгаз"	f	large
51010	58682	1380	Московская область, Люберецкий район, Люберцы, Космонавтов, 7, средняя школа № 9	f	large
51009	58682	1379	Московская область, Люберецкий район, Люберцы, Космонавтов, 7, средняя школа № 9	f	large
50983	58672	1358	Московская область, Люберецкий район, Люберцы, Калараш, 3, гимназия № 44	f	large
50982	58672	1357	Московская область, Люберецкий район, Люберцы, Калараш, 3, гимназия № 44	f	large
51022	58693	1397	Московская область, Люберецкий район, Люберцы, Гоголя, 21	f	large
51023	58693	1398	Московская область, Люберецкий район, Люберцы, Гоголя, 21	f	large
51021	58693	1396	Московская область, Люберецкий район, Люберцы, Гоголя, 21	f	large
51024	58694	1399	Московская область, Люберецкий район, Люберцы, Воинов-Интернационалистов, 7 , средняя школа № 25	f	large
51025	58694	1400	Московская область, Люберецкий район, Люберцы, Воинов-Интернационалистов, 7 , средняя школа № 25	f	large
51027	58694	1402	Московская область, Люберецкий район, Люберцы, Воинов-Интернационалистов, 7 , средняя школа № 25	f	large
51026	58694	1401	Московская область, Люберецкий район, Люберцы, Воинов-Интернационалистов, 7 , средняя школа № 25	f	large
50991	58676	1366	Московская область, Люберецкий район, Люберцы, Авиаторов, 10, гимназия № 41	f	large
50990	58676	1365	Московская область, Люберецкий район, Люберцы, Авиаторов, 10, гимназия № 41	f	large
50989	58676	1364	Московская область, Люберецкий район, Люберцы, Авиаторов, 10, гимназия № 41	f	large
50988	58675	1363	Московская область, Люберецкий район, Люберцы, Авиаторов, 3, лицей № 42	f	large
50987	58675	1362	Московская область, Люберецкий район, Люберцы, Авиаторов, 3, лицей № 42	f	large
50986	58675	1361	Московская область, Люберецкий район, Люберцы, Авиаторов, 3, лицей № 42	f	large
50996	58677	1371	Московская область, Люберецкий район, Люберцы, 3-е Почтовое отделение, 30, Гарнизонный Дом офицеров	f	large
50995	58677	1370	Московская область, Люберецкий район, Люберцы, 3-е Почтовое отделение, 30, Гарнизонный Дом офицеров	f	large
50994	58677	1369	Московская область, Люберецкий район, Люберцы, 3-е Почтовое отделение, 30, Гарнизонный Дом офицеров	f	large
50993	58677	1368	Московская область, Люберецкий район, Люберцы, 3-е Почтовое отделение, 30, Гарнизонный Дом офицеров	f	large
50992	58677	1367	Московская область, Люберецкий район, Люберцы, 3-е Почтовое отделение, 30, Гарнизонный Дом офицеров	f	large
51082	58727	1457	Московская область, Люберецкий район, Красково, Чехова, 11, школа № 59	f	large
51081	58727	1456	Московская область, Люберецкий район, Красково, Чехова, 11, школа № 59	f	large
51078	58725	1453	Московская область, Люберецкий район, поселок городского типа Красково, Федянина, 16, школа № 55	f	large
51077	58724	1452	Московская область, Люберецкий район, поселок городского типа Красково, 2-я Заводская, 28, гимназия № 56	f	large
51076	58724	1451	Московская область, Люберецкий район, поселок городского типа Красково, 2-я Заводская, 28, гимназия № 56	f	large
51080	58726	1455	Московская область, Люберецкий район, поселок Красково, Карла Маркса, 117, ВНИИСТРОМ	f	large
51079	58726	1454	Московская область, Люберецкий район, поселок Красково, Карла Маркса, 117, ВНИИСТРОМ	f	large
51016	58691	1391	Московская область, Люберецкий район, поселок Красково, Железнодорожная улица, 4а, заводоуправление завода	f	small
50925	58623	1299	Московская область, Луховицкий район, поселок совхоза Астапово, Садовая, 37А	f	large
111621	58648	1325	Московская область, Луховицкий район, поселок Фруктовая, Вокзальная, 1А	f	\N
50950	58648	1324	Московская область, Луховицкий район, поселок Фруктовая, Вокзальная, 1А	f	large
50937	94466	1311	Московская область, Луховицкий район, поселок Сельхозтехника, микрорайон Сельхозтехника, 24	f	medium
51605	59136	1981	Московская область, Луховицкий район, деревня Протасово, Победы, 9	f	small
50939	58637	1313	Московская область, Луховицкий район, деревня Подлесная Слобода, 152А	t	small
50928	58626	1302	Московская область, Луховицкий район, поселок Орешково, Парковая, 2	f	medium
50949	58647	1323	Московская область, Луховицкий район, деревня Озерицы, Озерная, 27А	f	small
50934	58632	1308	Московская область, Луховицкий район, деревня Нижне-Маслово, 134А	f	medium
50932	58630	1306	Московская область, Луховицкий район, деревня Марьина Гора, Молодежная, 7	f	small
50944	58641	1318	Московская область, Луховицкий район, село Любичи, Советская, 68	f	small
50899	58601	1273	Россия, Московская область, Луховицкий район, Луховицы	f	large
50897	58601	1271	Россия, Московская область, Луховицкий район, Луховицы	f	large
50913	58612	1287	Россия, Московская область, Луховицкий район, Луховицы, улица Островского, 8	f	large
50914	58612	1288	Россия, Московская область, Луховицкий район, Луховицы, улица Островского, 8	f	large
50912	58611	1286	Россия, Московская область, Луховицкий район, Луховицы, улица Жуковского, 28/2	f	large
50910	58610	1284	Россия, Московская область, Луховицкий район, Луховицы, улица Жуковского, 18	f	large
50911	58610	1285	Россия, Московская область, Луховицкий район, Луховицы, улица Жуковского, 18	f	large
50909	58609	1283	Россия, Московская область, Луховицкий район, Луховицы, улица Гайдара, 2	f	large
50908	58609	1282	Россия, Московская область, Луховицкий район, Луховицы, улица Гайдара, 2	f	large
50904	58605	1278	Россия, Московская область, Луховицкий район, Луховицы, улица 40 лет Октября, 26	f	large
51629	59152	2003	Московская область, Луховицкий район, Луховицы, Пушкина, 4	f	large
50903	14681	1277	Московская область, Луховицкий район, Луховицы, Пушкина, 341А	f	medium
50898	58602	1272	Московская область, Луховицкий район, Луховицы, Озерная, 4	f	small
50916	58613	1290	Московская область, Луховицкий район, Луховицы, Мира, 35	f	large
50915	58613	1289	Московская область, Луховицкий район, Луховицы, Мира, 35	f	large
50946	58644	1320	Московская область, Луховицкий район, село Ловцы, Садовая, 7	f	medium
50945	58643	1319	Московская область, Луховицкий район, село Ловцы, Октябрьской революции, 18	f	small
50943	58640	1317	Московская область, Луховицкий район, деревня Лисьи Норы, Околопрудная, 20А	f	small
50947	58645	1321	Московская область, Луховицкий район, поселок Красная Пойма, Школьная, 6	f	large
50948	58646	1322	Московская область, Луховицкий район, поселок Красная Пойма, Лесная, 4	f	large
50941	58638	1315	Московская область, Луховицкий район, село Дединово, Совхозная, 9	f	medium
50940	58638	1314	Московская область, Луховицкий район, село Дединово, Совхозная, 9	f	medium
50942	58639	1316	Московская область, Луховицкий район, село Дединово, Набережная, 4	f	small
50931	58629	1305	Московская область, Луховицкий район, село Григорьевское, Центральная, 25	f	medium
50935	58633	1309	Московская область, Луховицкий район, деревня Головачево, Мира, 102, здание администрации	f	large
50930	58628	1304	Московская область, Луховицкий район, поселок Газопроводск, Центральная, 17	f	large
50936	58634	1310	Московская область, Луховицкий район, деревня Выкопанка, Советская, 75	f	medium
50951	58649	1326	Московская область, Луховицкий район, поселок Врачово-Горки, Клубная, 11	f	medium
50924	58622	1298	Московская область, Луховицкий район, поселок городского типа Белоомут, Советская площадь, 20	f	small
50918	58615	1292	Московская область, Луховицкий район, поселок городского типа Белоомут, Советская площадь, 1	f	large
50922	58619	1296	Московская область, Луховицкий район, поселок городского типа Белоомут, Малая Огаревская, 113	f	medium
50921	58618	1295	Московская область, Луховицкий район, поселок городского типа Белоомут, Большая Огаревская, 20	f	medium
50919	58616	1293	Московская область, Луховицкий район, поселок Белоомут, Советская площадь, 15	f	small
50923	58620	1297	Московская область, Луховицкий район, поселок Белоомут, Гагарина, Здание клуба	f	medium
50920	58617	1294	Московская область, Луховицкий район, поселок Белоомут, Большая Огаревская, 26	f	medium
50929	58627	1303	Московская область, Луховицкий район, деревня Алпатьево, 20Б	f	small
50887	58591	1261	Московская область, Лотошинский район, п. Новолотошино, 18	f	large
50884	58588	1258	Московская область, Лотошинский район, п. Лотошино, Центральная, 14	f	large
50894	58598	1268	Россия, Московская область, Лотошинский район, деревня Ушаково	f	large
50893	58597	1267	Московская область, Лотошинский район, деревня Савостино, Школьная, 22	f	medium
52489	94634	2865	Московская область, Лотошинский район, деревня Пешки, в помещении сельского Дома культуры	f	large
48814	53216	174	Липецкая область, Липецк, проезд Ударников, 21	f	large
50888	58592	1262	Московская область, Лотошинский район, деревня Монасеино, Школа № 4	f	medium
50890	58594	1264	Московская область, Лотошинский район, деревня Михалево, Микрорайон, 28	f	small
50891	58595	1265	Московская область, Лотошинский район, село Микулино, Микрорайон, 15	f	large
52171	59576	2544	Россия, Московская область, Лотошинский район, поселок городского типа Лотошино, улица Микрорайон, 4	f	large
50883	94573	1257	Московская область, Лотошинский район, поселок городского типа Лотошино, Микрорайон, 8	f	large
50885	58589	1259	Московская область, Лотошинский район, поселок Лотошино, Центральная, 22	f	large
50889	58593	1263	Московская область, Лотошинский район, деревня Кульпино, Микрорайон, 20	f	small
50886	58590	1260	Московская область, Лотошинский район, поселок Кировский, Волоколамское шоссе, 2	f	large
50895	58599	1269	Московская область, Лотошинский район, деревня Доры, 5, Здание СДК	f	medium
50892	58596	1266	Московская область, Лотошинский район, деревня Введенское, Микрорайон, 14	f	medium
50896	58600	1270	Московская область, Лотошинский район, поселок Большая Сестра, 25, Здание СДК	f	small
50812	58556	1186	Московская область, Ленинский район, поселок подсобного хозяйства Воскресенское, 28а	f	large
50811	58555	1185	Московская область, Ленинский район, поселок подсобного хозяйства Воскресенское, МУ Дом культуры	f	large
50832	58570	1206	Московская область, Ленинский район, поселок Совхоза им.Ленина, Каширское шоссе, 7А, ДК поселка Совхоза имени Ленина	f	large
50828	94548	1202	Московская область, Ленинский район, поселок Развилка, МОУДОД ЦДТ Гармония	f	medium
50831	58569	1205	Московская область, Ленинский район, поселок Развилка, МОУ Развилковская средняя школа	f	large
50830	58569	1204	Московская область, Ленинский район, поселок Развилка, МОУ Развилковская средняя школа	f	large
50829	58568	1203	Московская область, Ленинский район, поселок Развилка, Центр Вера	f	medium
50820	58563	1194	Московская область, Ленинский район, село Остров, Животноводческий комплекс	t	small
50806	58550	1180	Россия, Московская область, Ленинский район, поселок Новодрожжино	f	large
50804	57368	1178	Россия, Московская область, Ленинский район, Московский, 3-й микрорайон, 8	f	large
50803	57156	1177	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 19а	f	medium
50802	57121	1176	Московская область, Ленинский район, Московский, поселок Института Полиомиелита, 4	f	large
50801	57094	1175	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 22а	f	large
50800	57069	1174	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 49	f	large
50799	56933	1173	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 19а	f	large
50797	56839	1171	Россия, Московская область, Ленинский район, Московский, 1-й микрорайон, 46	f	large
50798	56867	1172	Московская область, Ленинский район, Московский, микрорайон №1, 47	f	large
50819	58562	1193	Московская область, Ленинский район, село Молоково, Революционная, 161к1	f	large
50838	94550	1212	Россия, Московская область, Ленинский район, поселок Марьино	f	large
50834	58571	1208	Россия, Московская область, Ленинский район, поселок Коммунарка, 14а	f	large
50833	58571	1207	Россия, Московская область, Ленинский район, поселок Коммунарка, 14а	f	large
50795	56648	1169	Россия, Свердловская область, Екатеринбург, Калиновка поселок	f	medium
50805	58415	1179	Московская область, Ленинский район, поселок Измайлово, МОУ Измайловская средняя школа	f	large
111618	58566	1197	Московская область, Ленинский район, поселок Завода Мосрентген, помещение МОУ Теплостанская СОШ	f	\N
50822	58565	1196	Московская область, Ленинский район, поселок Завода Мосрентген, 37	f	large
50827	57393	1201	Московская область, Ленинский район, деревня Дроздово, Центр досуга ""Дроздово""	f	large
50808	58552	1182	Московская область, Ленинский район, поселок ДСК Мичуринец, Погодина, 4	f	small
50821	58564	1195	Московская область, Ленинский район, поселок городского типа Горки Ленинские, ГУ Реабилитационный центр Детство	f	small
50793	56599	1167	Московская область, Ленинский район, поселок городского типа Горки Ленинские,  ГУ ГИМЗ Горки Ленинские	f	medium
50794	56622	1168	Московская область, Ленинский район, деревня Горки, Полковникова, 2	f	medium
50835	94549	1209	Россия, Московская область, Ленинский район, поселок Газопровод, 15	f	large
111619	58573	1210	Россия, Московская область, Ленинский район, поселок Газопровод, 17	f	\N
51502	59046	1876	Московская область, Ленинский район, деревня Вырубово, 22А	f	large
50810	58554	1184	Московская область, Ленинский район, поселок Володарского, Текстильная, 16	f	large
50809	58553	1183	Московская область, Ленинский район, поселок Володарского, Текстильная, 16	f	large
50807	58551	1181	Московская область, Ленинский район, поселок Внуково, 50	f	large
50782	58549	1156	Россия, Московская область, Ленинский район, Видное, проспект Ленинского Комсомола, 23к3	f	large
50777	58546	1151	Россия, Московская область, Ленинский район, Видное, проспект Ленинского Комсомола, 1	f	large
50790	56417	1164	Московская область, Ленинский район, Видное, площадь Вокзальная, депо ПАТП	f	medium
50788	56289	1162	Россия, Московская область, Ленинский район, Видное, Школьная улица, 77	f	large
50787	56247	1161	Россия, Московская область, Ленинский район, Видное, Школьная улица, 40	f	large
50772	56247	1146	Россия, Московская область, Ленинский район, Видное, Школьная улица, 40	f	large
50770	58542	1144	Московская область, Ленинский район, Видное, Школьная, 11	f	large
50789	56309	1163	Московская область, Ленинский район, Видное, Школьная, 78	f	large
50775	58545	1149	Россия, Московская область, Ленинский район, Видное, Советская улица, 17а	f	large
50773	56111	1147	Россия, Московская область, Ленинский район, Видное, Советская улица, 5	f	large
50785	56111	1159	Россия, Московская область, Ленинский район, Видное, Советская улица, 5	f	large
50776	56111	1150	Россия, Московская область, Ленинский район, Видное, Советская улица, 5	f	large
50774	58544	1148	Московская область, Ленинский район, Видное, Советская , 20	f	large
50783	55719	1157	Московская область, Ленинский район, Видное, Советская, 24	f	large
50786	55719	1160	Московская область, Ленинский район, Видное, Советская, 24	f	large
50784	55719	1158	Московская область, Ленинский район, Видное, Советская, 24	f	large
50792	56522	1166	Россия, Московская область, Ленинский район, Видное, микрорайон Расторгуево, Петровский проезд, 12	f	large
50791	56454	1165	Московская область, Ленинский район, Видное, Ольгинская, 51	f	large
50771	58543	1145	Московская область, Ленинский район, Видное, Клубный переулок, 1	f	large
50780	58548	1154	Россия, Московская область, Ленинский район, Видное, Жуковский проезд, 10	f	large
50779	58548	1153	Россия, Московская область, Ленинский район, Видное, Жуковский проезд, 10	f	large
50781	58548	1155	Россия, Московская область, Ленинский район, Видное, Жуковский проезд, 10	f	large
50818	58561	1192	Россия, Московская область, Ленинский район, поселок Ватутинки	f	large
50817	58560	1191	Московская область, Ленинский район, поселок Ватутинки, МБУ Дом культуры Ватутинки	f	large
50816	58560	1190	Московская область, Ленинский район, поселок Ватутинки, МБУ Дом культуры Ватутинки	f	large
50815	58559	1189	Россия, Московская область, Ленинский район, поселок Ватутинки	f	large
50837	58574	1211	Московская область, Ленинский район, деревня Валуево, КС Главмосстроя	f	large
50757	58530	1129	Московская область, Красногорский район, поселок Светлые Горы, сельское поселение Отрадненское, помещение библиотеки	f	medium
50758	58532	1131	Россия, Московская область, Красногорский район, деревня Путилково	f	large
50752	58524	1124	Россия, Московская область, Красногорский район, село Петрово-Дальнее	t	large
50751	58523	1123	Россия, Московская область, Красногорский район, село Петрово-Дальнее	t	large
111616	58531	1130	Московская область, Красногорский район, поселок Отрадное, 1, в помещении администрации с/п Отрадненское	f	\N
50756	58529	1128	Россия, Московская область, Красногорский район, поселок Отрадное	f	large
50748	58520	1120	Россия, Московская область, Красногорский район, поселок Новый, 9	t	large
50749	58521	1121	Россия, Московская область, Красногорский район, село Николо-Урюпино	t	large
50702	58489	1074	Россия, Московская область, Красногорский район, поселок городского типа Нахабино, улица Кирова	f	large
50701	58489	1073	Россия, Московская область, Красногорский район, поселок городского типа Нахабино, улица Кирова	f	large
82154	56250	1320	Москва, Юных Ленинцев, 79к2	f	large
50740	58513	1112	Московская область, Красногорский район, поселок городского типа Нахабино, Школьная, 6	f	large
50739	58513	1111	Московская область, Красногорский район, поселок городского типа Нахабино, Школьная, 6	f	large
50738	58513	1110	Московская область, Красногорский район, поселок городского типа Нахабино, Школьная, 6	f	large
50736	58511	1108	Россия, Московская область, Красногорский район, поселок городского типа Нахабино, Советская улица, 30	f	large
50735	58510	1107	Московская область, Красногорский район, поселок городского типа Нахабино, Красноармейская , 56	f	large
50734	58510	1106	Московская область, Красногорский район, поселок городского типа Нахабино, Красноармейская , 56	f	large
50744	58516	1116	Московская область, Красногорский район, поселок городского типа Нахабино, Институтская, 21а	f	large
50743	58516	1115	Московская область, Красногорский район, поселок городского типа Нахабино, Институтская, 21а	f	large
50742	58515	1114	Московская область, Красногорский район, Нахабино, Институтская, 10б	f	large
50704	58490	1076	Россия, Московская область, Красногорский район, Красногорск, улица Ленина, 9	f	large
50703	58490	1075	Россия, Московская область, Красногорский район, Красногорск, улица Ленина, 9	f	large
50684	58480	1056	Россия, Московская область, Красногорский район, Красногорск, микрорайон Опалиха, улица Геологов, 3	f	large
50718	58498	1090	Московская область, Красногорский район, Красногорск, Чайковского, 12а	f	large
50717	58498	1089	Московская область, Красногорский район, Красногорск, Чайковского, 12а	f	large
50716	58498	1088	Московская область, Красногорский район, Красногорск, Чайковского, 12а	f	large
50697	58487	1069	Московская область, Красногорский район, Красногорск, Успенская , 20	f	large
50696	58487	1068	Московская область, Красногорский район, Красногорск, Успенская , 20	f	large
50714	58496	1086	Московская область, Красногорский район, Красногорск, Пионерская, 11	f	large
50713	58496	1085	Московская область, Красногорский район, Красногорск, Пионерская, 11	f	large
50712	58495	1084	Московская область, Красногорский район, Красногорск, Первомайская, 13	f	large
50686	58482	1058	Московская область, Красногорский район, Красногорск, Мира, 15	f	large
50695	58486	1067	Московская область, Красногорский район, Красногорск, Ленина, 32	f	large
50694	58486	1066	Московская область, Красногорский район, Красногорск, Ленина, 32	f	large
50693	58486	1065	Московская область, Красногорский район, Красногорск, Ленина, 32	f	large
50692	58486	1064	Московская область, Красногорский район, Красногорск, Ленина, 32	f	large
111615	58484	1060	Московская область, Красногорский район, Красногорск, Ленина, 62, ОАО Водоканал	f	\N
50710	58493	1082	Московская область, Красногорский район, Красногорск, Комсомольская, 7а	f	large
50709	58493	1081	Московская область, Красногорский район, Красногорск, Комсомольская, 7а	f	large
50708	58491	1080	Московская область, Красногорский район, Красногорск, Комсомольская, 41	f	large
50707	58491	1079	Московская область, Красногорский район, Красногорск, Комсомольская, 41	f	large
50706	58491	1078	Московская область, Красногорский район, Красногорск, Комсомольская, 41	f	large
50705	58491	1077	Московская область, Красногорский район, Красногорск, Комсомольская, 41	f	large
50700	58488	1072	Московская область, Красногорский район, Красногорск, Карбышева, 5	f	large
50699	58488	1071	Московская область, Красногорский район, Красногорск, Карбышева, 5	f	large
50698	58488	1070	Московская область, Красногорский район, Красногорск, Карбышева, 5	f	large
50691	58485	1063	Московская область, Красногорский район, Красногорск, Карбышева, 21	f	large
50690	58485	1062	Московская область, Красногорский район, Красногорск, Карбышева, 21	f	large
50689	58485	1061	Московская область, Красногорский район, Красногорск, Карбышева, 21	f	large
50729	58505	1101	Московская область, Красногорский район, Красногорск, микрорайон Павшинская пойма, Игната Титова, 5	f	large
50728	58504	1100	Московская область, Красногорский район, Красногорск, мкр.Павшинская пойма, Игната Титова, 5	f	large
50721	58500	1093	Московская область, Красногорский район, Красногорск, Вокзальная, 19	f	large
50720	58500	1092	Московская область, Красногорский район, Красногорск, Вокзальная, 19	f	large
50732	58508	1104	Московская область, Красногорский район, деревня Козино, Центральная, помещение детского сада	f	small
50754	58527	1126	Россия, Московская область, Красногорский район, поселок Истра	t	large
50750	58522	1122	Московская область, Красногорский район, село Ильинское	f	large
50745	58517	1117	Московская область, Красногорский район, поселок Ильинка, Помещение красного уголка дачного хозяйства Архангельское	t	large
50753	58526	1125	Московская область, Красногорский район, село Дмитровское, Центральная, фельдшерско-акушерский пункт	t	medium
50727	58503	1099	Московская область, Красногорский район, деревня Гольево, Центральная, 1	f	small
50747	58519	1119	Россия, Московская область, Красногорский район, поселок Архангельское	f	large
50746	58518	1118	Россия, Московская область, Красногорский район, поселок Архангельское	f	large
50755	58528	1127	Московская область, Красногорский район, село Ангелово, сельское поселение Отрадненское, Ангеловская школа	f	medium
50505	58343	877	Московская область, Коломенский район, село Шеметово, Здание сельского дома культуры	f	medium
52335	31256	2710	Московская область, Коломенский район, село Шеметово, 10	f	medium
50517	58355	889	Московская область, Коломенский район, село Черкизово, Здание районного дома культуры 	f	large
50521	58359	893	Московская область, Коломенский район, село Чанки, Здание начальной школы - детского сада	f	medium
50501	58339	873	Московская область, Коломенский район, Сосновый Бор, Здание средней школы	f	large
50510	58348	882	Московская область, Коломенский район, село Сергиевское, Здание сельской библиотеки	f	small
50509	58347	881	Московская область, Коломенский район, Сергиевский поселок, здание сельской библиотеки	f	medium
50508	58346	880	Россия, Московская область, Коломенский район, Сергиевский поселок	f	large
50497	58335	869	Россия, Московская область, Коломенский район, деревня Сельниково	f	large
50513	58351	885	Московская область, Коломенский район, поселок Проводник, Здание средней школы	f	medium
50500	58338	872	Россия, Московская область, Коломенский район, село Пирочи	f	large
50511	58349	883	Московская область, Коломенский район, село Пестриково, Здание сельского дома культуры	f	medium
50489	58327	861	Россия, Московская область, Коломенский район, поселок городского типа Пески	f	large
50488	58326	860	Россия, Московская область, Коломенский район, поселок городского типа Пески	f	large
50495	58333	867	Московская область, Коломенский район, поселок Первомайский	f	large
50507	58345	879	Московская область, Коломенский район, село Парфентьево, Здание сельской библиотеки	f	medium
50499	58337	871	Московская область, Коломенский район, село Октябрьское, Здание сельской библиотеки	f	medium
50519	58357	891	Московская область, Коломенский район, деревня Новая, Здание клуба	f	small
50520	58358	892	Россия, Московская область, Коломенский район, село Нижнее Хорошово	f	large
50503	58341	875	Московская область, Коломенский район, село Непецино, Здание сельского дома культуры	f	large
50502	58340	874	Московская область, Коломенский район, село Непецино, Здание Администрации сельского поселения Непецинское	f	large
50496	58334	868	Московская область, Коломенский район, деревня Малое Карасево, Здание клуба	f	small
50512	58350	884	Московская область, Коломенский район, деревня Лукерьино, Здание сельского дома культуры	f	medium
50494	58332	866	Московская область, Коломенский район, поселок Лесной, Здание сельского дома культуры	f	large
50504	58342	876	Московская область, Коломенский район, деревня Индустрия, Здание администрации сельского поселения Непецинское	f	large
50498	58336	870	Московская область, Коломенский район, деревня Зарудня, Здание средней школы	f	large
50491	58329	863	Московская область, Коломенский район, поселок Заречный, Здание начальной школы-детского сада	f	medium
50518	58356	890	Московская область, Коломенский район, деревня Губастово, Здание сельской библиотеки	f	medium
50506	58344	878	Россия, Московская область, Коломенский район, поселок Возрождение	f	medium
50514	58352	886	Московская область, Коломенский район, деревня Богдановка, Здание клуба	t	small
50492	58330	864	Россия, Московская область, Коломенский район, поселок Биорки	f	large
81804	56023	967	Москва, Хабаровская, 8а	f	large
50490	58328	862	Россия, Московская область, Коломенский район, село Акатьево	f	large
50455	58294	827	Московская область, Клинский район, поселок Ямуга, 55А	f	small
50470	58310	842	Россия, Московская область, Клинский район, поселок Шевляково	f	large
111613	58300	833	Московская область, Клинский район, поселок Чайковского, 22	f	\N
50471	58311	843	Россия, Московская область, Клинский район, деревня Струбково	f	large
50458	58297	830	Московская область, Клинский район, деревня Стреглово, 96	f	small
50452	58291	824	Россия, Московская область, Клинский район, село Спас-Заулок	f	large
50469	58309	841	Московская область, Клинский район, деревня Слобода, Центральная, 11	f	large
50463	58302	835	Московская область, Клинский район, село Селинское, 111	f	small
50462	58301	834	Московская область, Клинский район, деревня Решоткино, 57	f	medium
50467	58306	839	Россия, Московская область, Клинский район, поселок городского типа Решетниково	f	large
50466	58305	838	Московская область, Клинский район, поселок городского типа Решетниково, Лесная, 3	f	large
50457	58296	829	Московская область, Клинский район, деревня Покровка, Покровская, 2а	f	small
50479	58319	851	Московская область, Клинский район, деревня Петровское, Центральная, 6	f	large
50464	58303	836	Московская область, Клинский район, деревня Першутино, 1	f	medium
50456	58295	828	Московская область, Клинский район, деревня Папивино, 6а	f	small
50475	58315	847	Московская область, Клинский район, поселок Нудоль, Кинотеатр ЦСГ Чайковский	f	medium
50476	58316	848	Московская область, Клинский район, поселок Нудоль, Советская, 8	f	large
50472	58312	844	Московская область, Клинский район, деревня Новощапово, Центральная, 60	f	large
50477	58317	849	Московская область, Клинский район, поселок Нарынка, Королева, 10А	f	large
50459	58298	831	Московская область, Клинский район, деревня Мисирево, 76а	f	small
50480	58320	852	Московская область, Клинский район, деревня Масюгино, 15	f	small
50465	58304	837	Московская область, Клинский район, поселок Марков Лес, 10	f	small
50474	58314	846	Московская область, Клинский район, деревня Кузнецово, 12	f	medium
50432	58274	804	Россия, Московская область, Клинский район, Клин	f	large
50414	58263	786	Московская область, Клинский район, Клин, поселок Майданово, 86	f	large
50607	58430	979	Россия, Московская область, Клинский район, Клин, улица Терешковой, 7	f	large
50412	58261	784	Россия, Московская область, Клинский район, Клин, улица Мичурина, 1	f	large
50411	58261	783	Россия, Московская область, Клинский район, Клин, улица Мичурина, 1	f	large
52680	60008	3057	Россия, Московская область, Клинский район, Клин, улица Мира, 6	f	large
52679	60008	3056	Россия, Московская область, Клинский район, Клин, улица Мира, 6	f	large
50440	58280	812	Россия, Московская область, Клинский район, Клин, улица Мира, 5	f	large
50416	58256	789	Россия, Московская область, Клинский район, Клин, улица Ленина, 18	f	large
50417	58256	788	Россия, Московская область, Клинский район, Клин, улица Ленина, 18	f	large
50415	58256	787	Россия, Московская область, Клинский район, Клин, улица Ленина, 18	f	large
111611	58286	818	Московская область, Клинский район, Клин, улица Карла Маркса, 18/20	f	\N
50444	58284	816	Россия, Московская область, Клинский район, Клин, улица Карла Маркса, 76а	f	large
50443	58283	815	Россия, Московская область, Клинский район, Клин, улица Гагарина, 39	f	large
50431	58273	803	Россия, Московская область, Клинский район, Клин, улица 60 лет Комсомола, 5а	f	large
50430	58273	802	Россия, Московская область, Клинский район, Клин, улица 60 лет Комсомола, 5а	f	large
50429	58273	801	Россия, Московская область, Клинский район, Клин, улица 60 лет Комсомола, 5а	f	large
50428	58273	800	Россия, Московская область, Клинский район, Клин, улица 60 лет Комсомола, 5а	f	large
50422	58269	794	Московская область, Клинский район, Клин, Чайковского, 14	f	large
50423	58270	795	Россия, Московская область, Клинский район, Клин, Талицкий проезд, 49	f	large
50424	58270	796	Россия, Московская область, Клинский район, Клин, Талицкий проезд, 49	f	medium
50427	58272	799	Московская область, Клинский район, Клин, Спортивная, 3а	f	large
50421	58268	793	Московская область, Клинский район, Клин, Сестрорецкая, 43а	f	medium
50419	58265	791	Россия, Московская область, Клинский район, Клин, Пролетарский проезд, 4	f	large
50447	58287	819	Московская область, Клинский район, Клин, Московская улица, 4	f	large
50413	58262	785	Московская область, Клинский район, Клин, Мичурина, 1	f	large
50441	58281	813	Московская область, Клинский район, Клин, Захватаева, 9а	f	large
50445	58285	817	Московская область, Клинский район, Клин, Загородная, 3/29	f	large
50442	58282	814	Московская область, Клинский район, Клин, Гагарина, 39/2	f	large
50448	58288	820	Россия, Московская область, Клинский район, Клин, Волоколамское шоссе, 20/1	f	large
50439	58279	811	Россия, Московская область, Клинский район, Клин, Бородинский проезд, 28	f	large
50438	58278	810	Россия, Московская область, Клинский район, Клин, Бородинский проезд, 23	f	large
50437	58278	809	Россия, Московская область, Клинский район, Клин, Бородинский проезд, 23	f	large
50434	58276	806	Московская область, Клинский район, Клин, 50 лет Октября, 90а	f	large
50418	58264	790	Московская область, Клинский район, Клин,  Дзержинского, 2	f	large
50453	58292	825	Московская область, Клинский район, деревня Захарово, 41б	f	small
50478	58318	850	Московская область, Клинский район, деревня Елгозино, 46	f	medium
111612	58299	832	Московская область, Клинский район, деревня Давыдково, 24а	f	\N
50485	58323	857	Россия, Московская область, Клинский район, Высоковск, Текстильная улица, 4а	f	large
50484	58323	856	Россия, Московская область, Клинский район, Высоковск, Текстильная улица, 4а	f	large
50487	58321	853	Россия, Московская область, Клинский район, Высоковск, Первомайская улица, 2а	f	large
111614	58325	859	Московская область, Клинский район, Высоковск, Первомайская, 2а	f	\N
50483	58322	855	Московская область, Клинский район, Высоковск, Ленина, 11	f	large
50482	58322	854	Московская область, Клинский район, Высоковск, Ленина, 11	f	large
50486	58324	858	Московская область, Клинский район, Высоковск, Курятникова, 97	f	medium
50468	58307	840	Россия, Московская область, Клинский район, село Воздвиженское	f	large
50454	58293	826	Московская область, Клинский район, деревня Бирево, 70а	f	small
50387	58240	760	Московская область, Каширский район, деревня Яковское, Клубная, 1а	f	small
50389	58242	762	Московская область, Каширский район, деревня Топканово, Новая, 16	f	medium
50382	58235	755	Московская область, Каширский район, деревня Тарасково, Комсомольская, 28	f	large
50373	56062	746	Россия, Московская область, Каширский район, Ожерелье, Строительная улица, 15	f	large
50370	55891	743	Московская область, Каширский район, Ожерелье, Советская, 10	f	large
50371	55891	744	Московская область, Каширский район, Ожерелье, Советская, 10	f	large
50374	94467	747	Россия, Московская область, Каширский район, Ожерелье, Заводская улица, 1	f	medium
50375	56105	748	Московская область, Каширский район, Ожерелье, 1 Мая, 29	f	medium
50376	94536	749	Московская область, Каширский район, поселок Новоселки, Центральная, 32	f	large
50390	58243	763	Московская область, Каширский район, поселок Маслово, Фабричная, 5а	t	small
50383	58236	756	Московская область, Каширский район, деревня Лиды, Иваньковское шоссе, 6	t	small
50386	58239	759	Московская область, Каширский район, деревня Ледово, Стадионная, 1	f	large
50381	58234	754	Московская область, Каширский район, деревня Корыстово, Центральная, 13	f	small
50379	94539	752	Московская область, Каширский район, деревня Кокино, Садовая, 33, Здание Кокинской основной общеобразовательной школы	f	medium
50358	58226	731	Россия, Московская область, Каширский район, Кашира, улица Победы, 7к1	f	large
50357	58226	730	Россия, Московская область, Каширский район, Кашира, улица Победы, 7к1	f	large
50356	58226	729	Россия, Московская область, Каширский район, Кашира, улица Победы, 7к1	f	large
50352	58222	725	Россия, Московская область, Каширский район, Кашира, улица Моргунова, 15	f	medium
50354	58224	727	Московская область, Каширский район, Кашира, Школьная, 11	f	medium
50365	55302	738	Россия, Московская область, Каширский район, Кашира, Центральная улица, 17	f	large
50349	58219	722	Россия, Московская область, Каширский район, Кашира, Стрелецкая улица, 65	f	large
50350	58220	723	Московская область, Каширский район, Кашира, Советская, 38	f	large
50367	55317	740	Россия, Московская область, Каширский район, Кашира, Садовая улица, 27	f	large
50366	55317	739	Россия, Московская область, Каширский район, Кашира, Садовая улица, 27	f	large
50355	58225	728	Московская область, Каширский район, Кашира, Победы, 7	f	large
50364	55271	737	Московская область, Каширский район, Кашира, Новокаширская, 4	f	large
50363	58214	736	Московская область, Каширский район, Кашира, Металлистов, 8	f	large
50351	58221	724	Московская область, Каширский район, Кашира, Маршала Астахова, 1	f	large
50360	58228	733	Московская область, Каширский район, Кашира, Клубная, 2	f	large
50353	58223	726	Московская область, Каширский район, Кашира, Ильича, 69а	f	large
50378	94538	751	Московская область, Каширский район, поселок Зендиково, Октябрьская, 5, Здание Зендиковской средней общеобразовательной школы	f	large
50377	94537	750	Московская область, Каширский район, поселок Большое Руново, Южная, 8, Здание Руновской основной общеобразовательной школы	f	large
50388	58241	761	Московская область, Каширский район, поселок Богатищево, Новая, 16	f	large
50380	58233	753	Россия, Калужская область, Балабаново, улица Ленина	f	large
50329	94524	701	Московская область, Истринский район, поселок станции Манихино, Железнодорожная, 22, помещение МОУ Манихинская основная общеоб.школа	f	medium
52205	59612	2578	Московская область, Истринский район, дачный поселок Поречье, 32	t	large
50318	58185	690	Московская область, Истринский район, поселок Снегири, Станционная, 22, здание Дома культуры (фойе)	f	medium
50317	58184	689	Московская область, Истринский район, поселок Снегири, Станционная, 22, здание Снегиревского Дома культуры, актовый зал	f	large
50320	58187	692	Московская область, Истринский район, поселок городского типа Снегири, 90	f	small
50335	58203	707	Московская область, Истринский район, поселок Северный, здание Клуба	f	medium
50348	94535	720	Московская область, Истринский район, деревня Савельево, 56, МУК Ядроминская сельская центр.библиотечная система	f	small
50338	94530	710	Россия, Московская область, Истринский район, поселок Румянцево	f	large
50346	94534	718	Московская область, Истринский район, село Рождествено, Южная, 19, помещение МОУ "Рождественская сред.общеобр.школа"	f	large
50339	94531	711	Московская область, Истринский район, деревня Пречистое, сельское поселение Новопетровское, д.38/3,  здание Дома культуры	f	small
50341	94532	713	Россия, Московская область, Истринский район, деревня Покровское	f	large
50333	94526	705	Московская область, Истринский район, поселок Первомайский, 33, здание Клуба	f	large
50328	94523	700	Россия, Московская область, Истринский район, деревня Павловское	f	large
50933	58631	1307	Московская область, Истринский район, деревня Павловское, Молодежная, 6А	f	medium
50345	58213	717	Московская область, Истринский район, село Павловская Слобода	f	large
50344	58212	716	Московская область, Истринский район, село Павловская Слобода, Комсомольская, 5а	f	large
50343	58211	715	Московская область, Истринский район, село Павловская Слобода, Дзержинского, 4, здание Красного уголка	f	large
50342	94533	714	Московская область, Истринский район, село Онуфриево, Центральная, 1, здание Дома культуры	f	medium
50337	94529	709	Московская область, Истринский район, село Новопетровское, Северная, 49, помещение Дома культуры	f	large
50336	94528	708	Московская область, Истринский район, село Новопетровское, Полевая, 7, помещение МОУ Новопетровская СОШ	f	large
51564	59019	1938	Московская область, Истринский район, деревня Новодарьино, 15	f	medium
50332	58200	704	Московская область, Истринский район, село Лучинское, Здание Административного корпуса санатория Истра	f	medium
50334	94527	706	Московская область, Истринский район, село Лучинское, Железнодорожная, 72, МОУ Лучинская сред.общеобр.школа	f	small
50347	58216	719	Россия, Московская область, Истринский район, поселок Курсаково	f	large
50331	58199	703	Московская область, Истринский район, деревня Котово, здание Клуба	f	medium
50330	94525	702	Московская область, Истринский район, деревня Кострово, Центральная, 17, здание Дома Культуры	f	large
49729	57685	102	Московская область, Истринский район, деревня Кашино, Ленина, 94	f	large
50305	58172	677	Московская область, Истринский район, Истра, Здание Клуба войсковой части	f	large
50302	58169	674	Россия, Московская область, Истринский район, Истра, улица Кирова, 61	f	large
50299	94514	671	Московская область, Истринский район, Истра, Юбилейная, 11а, помещение МОУ Сред. школа №2	f	large
50303	94515	675	Россия, Московская область, Истринский район, Истра, Советская улица, 10а/1	f	large
50294	94510	666	Московская область, Истринский район, Истра, Первомайская , 3, помещение ДК	f	large
50297	94512	669	Московская область, Истринский район, Истра, Ленина, 12, помещение Центра досуга Мир	f	large
50319	58186	691	Московская область, Истринский район, Истра, Кирова, 10а, здание Снегиревской средней школы (фойе)	f	medium
50298	94513	670	Московская область, Истринский район, Истра, Босова, 17а, помещение МОУ Лицей г.Истра	f	large
50300	58167	672	Московская область, Истринский район, Истра, 9 Гвардейской Дивизии, 49, Здание Истринской гор. библиотеки	f	large
50340	58208	712	Московская область, Истринский район, деревня Деньково, 80, Дом культуры	f	small
50315	58182	687	Московская область, Истринский район, Дедовск	f	large
50304	58171	676	Россия, Московская область, Истринский район, Дедовск, улица Панфилова, 1	f	medium
50311	58178	683	Россия, Московская область, Истринский район, Дедовск, улица Гагарина, 6	f	large
50068	57975	440	Россия, Московская область, Истринский район, Дедовск, улица 9 Мая, 3	f	large
50316	94519	688	Московская область, Истринский район, Дедовск, Энергетиков, 15, помещение МОУ Лицей г.Дедовска	f	large
50313	58180	685	Московская область, Истринский район, Дедовск, Победы, 2, здание Детской общеобразовательной школы	f	large
50312	58179	684	Московская область, Истринский район, Дедовск, Победы, 2, здание Дедовской общеобр. школы	f	large
50314	94518	686	Московская область, Истринский район, Дедовск, Осипенко, 1а, помещение МОУ Дедовская сред.общеобр.школа №3	f	large
50307	94516	679	Московская область, Истринский район, Дедовск, Ленина, 4, школа №4	f	large
50309	58176	681	Московская область, Истринский район, Дедовск, Гагарина, 16,  здание филиала Московского Гос.соц. университета	f	large
50306	58173	678	Московская область, Истринский район, Дедовск, Гагарина, 2, здание Дедовской средней школы №1	f	large
50326	94522	698	Россия, Московская область, Истринский район, поселок Глебовский	f	large
50325	94521	697	Россия, Московская область, Истринский район, поселок Глебовский	f	large
50324	94521	696	Россия, Московская область, Истринский район, поселок Глебовский	f	large
50323	94520	695	Московская область, Истринский район, поселок Глебовский, Октябрьская, 58А	f	large
49829	57763	202	Московская область, Истринский район, поселок городского типа Восход, 12	f	large
50322	58189	694	Московская область, Истринский район, Бужарово, Здание Клуба Гидроузла имени Куйбышева	f	large
50321	58188	693	Россия, Московская область, Истринский район, деревня Бужарово	f	large
50327	58195	699	Московская область, Истринский район, поселок Агрогородок, 23	f	large
50259	58137	631	Московская область, Зарайский район, поселок центральной усадьбы совхоза "40 лет Октября", Садовая, Здание Октябрьской средней школы	f	medium
50250	58128	622	Московская область, Зарайский район, село Чулки-Соколово, Здание МУК Чулковский сельский Дом культуры	f	large
50258	58136	630	Московская область, Зарайский район, село Протекино, Здание сельского Дома культуры	f	medium
50254	58132	626	Московская область, Зарайский район, деревня Новоселки, Здание МОУ Новоселковская начальная школа-детский сад	f	medium
50257	58135	629	Россия, Московская область, Зарайский район, деревня Мендюкино	f	large
50256	58134	628	Московская область, Зарайский район, поселок Масловский, МОУ Масловская средняя общеобразовательная школа	f	large
50249	58127	621	Московская область, Зарайский район, село Макеево, Центральная, 15	f	large
111606	58126	620	Московская область, Зарайский район, деревня Летуново, Центральная, 14, здание Летуновского СДК	f	\N
111605	58125	619	Московская область, Зарайский район, поселок Зарайский, 1, здание СДК ц/о АО Зарайское	f	\N
50239	58121	611	Россия, Московская область, Зарайский район, Зарайск, 2-й микрорайон	f	large
50231	58113	603	Московская область, Зарайский район, Зарайск, поселок Текстильщиков, 30	f	medium
50238	58120	610	Московская область, Зарайский район, Зарайск, Школьная, 3	f	large
50233	58115	605	Московская область, Зарайский район, Зарайск, Рабочая Слободка, Здание МОУ ДЮСШ	f	large
50245	57925	617	Московская область, Зарайский район, Зарайск, квартал Южный, Пионерская, 22	f	large
81803	56023	966	Москва, Хабаровская, 8а	f	large
50236	58118	608	Московская область, Зарайский район, Зарайск, Красноармейская, 51	f	large
50234	58116	606	Московская область, Зарайский район, Зарайск, Красноармейская, 31	f	large
50235	58117	607	Московская область, Зарайский район, Зарайск, Карла Маркса, 36	f	large
50237	58119	609	Московская область, Зарайский район, Зарайск, Благоева, 40	f	large
50240	58122	612	Московская область, Зарайский район, Зарайск,  2-й микрорайон, 35	f	large
50252	58130	624	Московская область, Зарайский район, деревня Журавна, 64, Здание Журавенского участка МУП 	f	medium
50255	58133	627	Московская область, Зарайский район, деревня Ерново, Здание МОУ Ерновская средняя общеобразовательная школа	f	medium
50253	58131	625	Московская область, Зарайский район, деревня Гололобово, 64	f	large
50251	58129	623	Московская область, Зарайский район, деревня Алферьево, Микрорайон, 8А	f	medium
111604	55576	618	Московская область, Зарайский район, деревня Авдеево, 22, Здание Авдеевского СДК	f	\N
50130	58033	502	Россия, Московская область, Егорьевский район, деревня Юрцово	f	large
50120	58023	492	Московская область, Егорьевский район, село Шувое, Ленинская, 159	f	large
50119	94504	491	Московская область, Егорьевский район, деревня Челохово, 1, кв.11	t	small
50137	58041	509	Московская область, Егорьевский район, деревня Старое, учебный корпус ГПЛ-96	f	medium
52642	59977	3018	Московская область, Егорьевский район, деревня Селиваниха, улица Юбилейная, 20	f	large
50124	58027	496	Московская область, Егорьевский район, деревня Селиваниха,  Юбилейная, 16	f	large
111602	58028	497	Московская область, Егорьевский район, Саввино, Восточный микрорайн, 8а, школа им.Калабалина	f	\N
50141	58045	513	Московская область, Егорьевский район, поселок Рязановский, Ленина, 2	f	large
50136	58040	508	Россия, Московская область, Егорьевский район, село Раменки	f	large
50142	58046	514	Московская область, Егорьевский район, село Радовицы, Советская, 33	t	small
50131	58035	503	Россия, Московская область, Егорьевский район, деревня Починки	f	large
50139	58043	511	Россия, Московская область, Егорьевский район, деревня Поповская	f	large
50132	58036	504	Московская область, Егорьевский район, деревня Полбино, Молодежная, 9	f	medium
50118	58021	490	Московская область, Егорьевский район, поселок Новый, 52	f	large
50138	58042	510	Московская область, Егорьевский район, село Никиткино, 255	f	small
50134	58038	506	Московская область, Егорьевский район, деревня Михали, Гагарина, 6	f	large
50140	58044	512	Московская область, Егорьевский район, село Лелечи, 44	f	small
50121	58024	493	Московская область, Егорьевский район, деревня Костылево, 1В	f	small
50135	58039	507	Московская область, Егорьевский район, деревня Колычево, З.Самсоновой, 36	f	medium
50128	58031	500	Московская область, Егорьевский район, деревня Клеменово, Фабричная, 2	t	small
50129	94505	501	Московская область, Егорьевский район, деревня Иваново, 62, Иншинская школа	f	medium
50123	58026	495	Московская область, Егорьевский район, деревня Захарово, 1Д	f	small
50110	58013	482	Московская область, Егорьевский район, Егорьевск, 3-й микрорайон, 30	f	large
50109	58012	481	Россия, Московская область, Егорьевский район, Егорьевск, 2-й микрорайон, 45	f	large
50108	58012	480	Россия, Московская область, Егорьевский район, Егорьевск, 2-й микрорайон, 45	f	large
50107	58011	479	Россия, Московская область, Егорьевский район, Егорьевск, 2-й микрорайон, 25	f	large
50102	58005	474	Россия, Московская область, Егорьевский район, Егорьевск, 1-й микрорайон, 61	f	large
50100	58003	472	Россия, Московская область, Егорьевский район, Егорьевск, 6-й микрорайон, 14а	f	large
50099	58002	471	Россия, Московская область, Егорьевский район, Егорьевск, 6-й микрорайон, 9а	f	large
50091	94500	463	Московская область, Егорьевский район, Егорьевск, улица Парижской Коммуны, 14/91, гимназия №10	f	large
49631	57615	4	Россия, Московская область, Егорьевский район, Егорьевск, улица Крупской, 4	f	large
49630	57615	3	Россия, Московская область, Егорьевский район, Егорьевск, улица Крупской, 4	f	large
52939	60228	3316	Россия, Московская область, Егорьевский район, Егорьевск, улица Карла Маркса, 44	f	large
52938	60228	3315	Россия, Московская область, Егорьевский район, Егорьевск, улица Карла Маркса, 44	f	large
50106	58010	478	Россия, Московская область, Егорьевский район, Егорьевск, улица Горького, 13	f	large
50093	57996	465	Россия, Московская область, Егорьевский район, Егорьевск, улица 9 Января, 69	f	large
50101	58004	473	Россия, Московская область, Егорьевский район, Егорьевск, проспект Ленина, 3	f	large
50117	94503	489	Московская область, Егорьевский район, Егорьевск, Совхозная улица, 45, ДК Лад	f	medium
50097	58000	469	Московская область, Егорьевский район, Егорьевск, Советская, 193	f	large
50092	57995	464	Московская область, Егорьевский район, Егорьевск, Рязанская , 9	f	large
50085	57988	457	Московская область, Егорьевский район, Егорьевск, Профсоюзная, 24	f	medium
50087	57990	459	Московская область, Егорьевский район, Егорьевск, Парижской Коммуны, 1б	f	large
50090	57993	462	Московская область, Егорьевский район, Егорьевск, Нечаевская, 24/59	f	large
50114	58016	486	Московская область, Егорьевский район, Егорьевск, Касимовское шоссе, 4	f	medium
50089	57992	461	Московская область, Егорьевский район, Егорьевск, Владимирская, 2	f	large
50088	57991	460	Московская область, Егорьевский район, Егорьевск, Владимирская, 15а	f	large
50084	94499	456	Московская область, Егорьевский район, Егорьевск, 50 лет ВЛКСМ, 3А, ДК Факел	f	large
50113	58015	485	Московская область, Егорьевский район, Егорьевск, 4-й микрорайон, 22	f	large
50112	58015	484	Московская область, Егорьевский район, Егорьевск, 4-й микрорайон, 22	f	large
50111	58014	483	Московская область, Егорьевский район, Егорьевск, 3-й микрорайон, 30	f	large
50105	58009	477	Московская область, Егорьевский район, Егорьевск, 1-й микрорайон, 1-й микрорайон, 67	f	large
50133	58037	505	Московская область, Егорьевский район, деревня Дмитровка, Дом Культуры	f	small
51776	59276	2150	Московская область, Егорьевский район, деревня Данилово, 65	f	small
50126	58029	498	Московская область, Егорьевский район, деревня Верейка, Советская, 12	f	medium
50127	58030	499	Московская область, Егорьевский район, деревня Большое Гридино, 203	f	medium
50122	58025	494	Московская область, Егорьевский район, деревня Бережки, 76	f	small
50143	58047	515	Московская область, Егорьевский район, деревня Алферово, Горького, 79	f	small
49925	57851	298	Московская область, Дмитровский район, поселок совхоза Останкино, Останкинская школа	f	large
49942	57868	315	Московская область, Дмитровский район, поселок совхоза Буденновец, Транспортная, Буденновский СДК	f	medium
49927	57853	300	Московская область, Дмитровский район, сельское поселение Габовское, поселок дома отдыха "Горки", Дом Офицеров Флота	f	large
49887	57812	260	Московская область, Дмитровский район, п. Горшково, ДК п. Горшково	f	large
49886	57812	259	Московская область, Дмитровский район, п. Горшково, ДК п. Горшково	f	large
49869	57794	242	Московская область, Дмитровский район, г. Дмитров, Подъячево, 60	f	large
49902	57828	275	Россия, Московская область, Дмитровский район, Яхрома	f	medium
49898	57823	271	Россия, Московская область, Дмитровский район, Яхрома, микрорайон Левобережье	f	large
49879	57804	252	Московская область, Дмитровский район, Яхрома, спортивно-развлекательный парк Яхрома	f	small
49894	57819	267	Московская область, Дмитровский район, Яхрома, улица Кирьянова, 32, помещение изостудии	f	medium
49901	57827	274	Московская область, Дмитровский район, Яхрома, микрорайон Левобережье, Ленина, 42, здание проход. ЗАО Яхромский автобусный завод	f	medium
49897	57822	270	Московская область, Дмитровский район, Яхрома, Конярова, 9, красный уголок ЯТМК	f	medium
49896	57821	269	Московская область, Дмитровский район, Яхрома, Конярова, 31	f	large
49893	57818	266	Московская область, Дмитровский район, Яхрома, Кирьянова, 12, школа № 2	f	small
49895	57820	268	Московская область, Дмитровский район, Яхрома, Заречная, 2, ДК г Яхромы	f	large
49900	57825	273	Московская область, Дмитровский район, Яхрома, Большевистская, 16, Яхромская техшкола	f	large
49944	57870	317	Московская область, Дмитровский район, село Якоть, административное здание ВНИИПРХ	f	large
49943	57869	316	Московская область, Дмитровский район, село Якоть, сельское поселение Якотское, Якотский СДК	f	small
49885	57811	258	Московская область, Дмитровский район, деревня Целеево, администрация Кузяевского территориального отдела	f	medium
52328	59719	2703	Московская область, Дмитровский район, деревня Тютьково, 14б	t	small
49890	57815	263	Московская область, Дмитровский район, деревня Татищево, клуб дер.Татищево	t	small
49922	57847	295	Московская область, Дмитровский район, деревня Синьково, мкр. Дуброво, 2, кв. 76	f	large
49923	57849	296	Московская область, Дмитровский район, деревня Семеновское, Молодежный Центр с. Семеновское	t	large
49931	57857	304	Россия, Московская область, Дмитровский район, село Рогачево	f	large
49929	57855	302	Московская область, Дмитровский район, село Рогачево, пл. Осипова, здание Дома Культуры	f	medium
49930	57856	303	Московская область, Дмитровский район, село Рогачево, Ракетчиков, здание магазина	f	small
51694	59207	2068	Московская область, Дмитровский район, садовое товарищество Приозерье, 2-й проезд строителей, 2	t	small
49932	57858	305	Московская область, Дмитровский район, село Покровское, ДК с. Покровское	f	small
49904	57830	277	Московская область, Дмитровский район, деревня Подъячево, школа с. Подъячево	t	medium
49883	57809	256	Московская область, Дмитровский район, поселок Подосинки, ДК пос. Подосинки	f	large
49889	57814	262	Московская область, Дмитровский район, село Орудьево, Фабричная, Орудьевская средняя школа	f	large
49892	57817	265	Московская область, Дмитровский район, поселок Орево, ДК поселка Орево	f	medium
49941	57867	314	Московская область, Дмитровский район, деревня Ольявидово, Центральная, Дом культуры	f	large
49905	57831	278	Московская область, Дмитровский район, село Ольгово, библиотека с. Ольгово	t	small
49920	57845	293	Россия, Московская область, Дмитровский район, поселок Новосиньково	f	large
49919	57844	292	Московская область, Дмитровский район, поселок Новосиньково, ДК пос. Новосиньково	f	large
49918	57843	291	Московская область, Дмитровский район, поселок Новосиньково, Синьковская школа №2	f	large
49938	57864	311	Московская область, Дмитровский район, деревня Новое Гришино, Гришинская средняя общеобразовательная школа	t	medium
50384	58237	757	Московская область, Дмитровский район, деревня Никулино, Новая, 12	f	medium
49914	57839	287	Россия, Московская область, Дмитровский район, поселок городского типа Некрасовский	f	large
49916	57841	289	Московская область, Дмитровский район, поселок городского типа Некрасовский, микрорайон Строителей, ДК Строитель	f	medium
49915	57840	288	Московская область, Дмитровский район, поселок городского типа Некрасовский, Ушакова, 20, помещение Некрасовской поликлиники	f	large
49917	57842	290	Московская область, Дмитровский район, поселок городского типа Некрасовский, Городок-1, Дом офицеров	f	large
49913	57838	286	Московская область, Дмитровский район, поселок Некрасовский, Краснофлотская, 10	f	large
49888	57813	261	Московская область, Дмитровский район, деревня Настасьино, ФАП д.Настасьино	t	small
49933	57859	306	Московская область, Дмитровский район, деревня Насадкино, сельское поселение Куликовское, Насадкино, 9, здание администрации	f	medium
49881	57807	254	Московская область, Дмитровский район, деревня Митькино, КДЦ Романтик	f	medium
49937	57863	310	Московская область, Дмитровский район, поселок Мельчевка, ДК поселка	f	medium
49936	57862	309	Московская область, Дмитровский район, поселок Луговой, Куликовское, Клуб пос. Луговой	f	medium
49934	57860	307	Московская область, Дмитровский район, деревня Липино, 14, административное здание больницы	f	small
49940	57866	313	Московская область, Дмитровский район, село Костино, СДК Костино	f	medium
49891	57816	264	Московская область, Дмитровский район, деревня Княжево, здание СДК д. Княжево	f	medium
49926	57852	299	Московская область, Дмитровский район, деревня Каменка, школа N 1	f	medium
50385	58238	758	Московская область, Дмитровский район, деревня Каменка, Центральная, 8	f	medium
49882	57808	255	Московская область, Дмитровский район, село Ильинское, Центр активного отдыха X-LAND - здание боулинга	f	small
49911	57837	284	Московская область, Дмитровский район, поселок городского типа Икша, Комсомольская, Дом культуры	f	large
49884	57810	257	Московская область, Дмитровский район, деревня Дубровки, Триумфальная, казарма №1	t	small
49864	57789	237	Россия, Московская область, Дмитровский район, Дмитров, микрорайон имени А.М. Маркова	f	large
49861	57786	234	Московская область, Дмитровский район, Дмитров, микрорайон Аверьянова, школа №10	f	large
49859	57784	232	Россия, Московская область, Дмитровский район, Дмитров, микрорайон Махалина	f	large
49858	57784	231	Россия, Московская область, Дмитровский район, Дмитров, микрорайон Махалина	f	large
49855	57781	228	Московская область, Дмитровский район, Дмитров, микрорайон Внуковский, 20, Внуковская школа	f	large
49853	57779	226	Россия, Московская область, Дмитровский район, Дмитров, микрорайон ДЗФС	f	large
49852	57778	225	Московская область, Дмитровский район, Дмитров, микрорайон ДЗФС, 24, средняя школа №3	f	large
49851	57777	224	Россия, Московская область, Дмитровский район, Дмитров, микрорайон ДЗФС	f	large
49860	57785	233	Московская область, Дмитровский район, Дмитров, мкр. Аверьянова, школа № 10	f	large
49873	57799	246	Московская область, Дмитровский район, Дмитров, Школьная, 11, средняя школа 1 	f	large
49872	57798	245	Московская область, Дмитровский район, Дмитров, Школьная, 14, начальная школа 5 	f	large
49857	94488	230	Московская область, Дмитровский район, Дмитров, Профессиональная, 21, Центр детского творчества	f	large
49870	57796	243	Московская область, Дмитровский район, Дмитров, Почтовая, городская библиотека	f	large
49865	57790	238	Московская область, Дмитровский район, Дмитров, Маркова, 6, школа № 9	f	large
49877	57802	250	Московская область, Дмитровский район, Дмитров, Космонавтов, 11, средняя школа №8	f	large
49876	57802	249	Московская область, Дмитровский район, Дмитров, Космонавтов, 11, средняя школа №8	f	large
49875	57801	248	Московская область, Дмитровский район, Дмитров, Космонавтов, 33, политехнический колледж 	f	large
49868	57793	241	Московская область, Дмитровский район, Дмитров, Комсомольская, средняя школа № 2	f	large
49867	57792	240	Московская область, Дмитровский район, Дмитров, Инженерная, 24а, гимназия Дмитров 	f	large
49980	57905	353	Россия, Московская область, Дмитровский район, Дмитров, Загорская улица, 30	f	large
49866	57791	239	Московская область, Дмитровский район, Дмитров, Загорская, 64, Дворец Культуры	f	large
49871	57797	244	Московская область, Дмитровский район, Дмитров, Волгостроевская, 2, школа № 7	f	large
49854	57780	227	Московская область, Дмитровский район, Дмитров, Внуковская, строение 40, здание ООО Дмитров - Кабель	f	large
49878	57803	251	Московская область, Дмитровский район, Дмитров, Веретенникова, 13а, помещение красного уголка АО СМПК-73	f	large
49874	57800	247	Московская область, Дмитровский район, Дмитров, Большевистская улица, 14, ДК Современник	f	large
49910	57836	283	Московская область, Дмитровский район, поселок городского типа Деденево, Горнолыжный клуб Л.Тягачева	t	small
49909	57835	282	Россия, Московская область, Дмитровский район, поселок городского типа Деденево	f	large
49908	57834	281	Московская область, Дмитровский район, поселок городского типа Деденево, Советская, здание ФОКа	f	large
49906	57832	279	Московская область, Дмитровский район, поселок городского типа Деденево, Заречная, здание детского сада № 42	f	large
49907	57833	280	Московская область, Дмитровский район, поселок Деденево, клуб Комсомольский	f	large
49939	57865	312	Московская область, Дмитровский район, деревня Гришино, 95, помещение администрации	t	small
49928	57854	301	Московская область, Дмитровский район, деревня Горки, Каменская средняя школа №2	f	medium
49880	57806	253	Московская область, Дмитровский район, село Внуково, Дмитров, 60, здание Внуковского территориального отдела	f	medium
49924	57850	297	Россия, Московская область, Дмитровский район, деревня Бунятино	f	medium
49903	57829	276	Московская область, Дмитровский район, деревня Астрецово, ОАО Гамма	f	small
49921	57846	294	Московская область, Дмитровский район, поселок Автополигон, сельское поселение Синьковское, клуб Испытатель	f	medium
49825	57759	198	Московская область, Воскресенский район, поселение им. Цюрупы, Зайцева, 22	f	large
49821	57755	194	Московская область, Воскресенский район, поселок городского типа имени Цюрупы, Октябрьская, 75	f	large
49822	94484	195	Московская область, Воскресенский район, городское поселение им. Цюрупы, Новомалинная, 5-а, МОУ СОШ №13	f	large
49765	57704	138	Московская область, Воскресенский район, деревня Чемодурово, Центральная, 12	f	large
49826	57760	199	Московская область, Воскресенский район, поселок городского типа Хорлово, Советская, 4	f	large
49824	57758	197	Московская область, Воскресенский район, поселок городского типа Хорлово, Зайцева, 22	f	large
49813	57747	186	Московская область, Воскресенский район, село Федино	f	large
49820	57754	193	Россия, Московская область, Воскресенский район, деревня Степанщино	f	medium
49802	57736	175	Московская область, Воскресенский район, деревня Старая, сельский клуб	t	medium
49819	57753	192	Московская область, Воскресенский район, деревня Ратчино, Некрасова, 11А	f	large
49816	57749	189	Московская область, Воскресенский район, деревня Невское, здание фельдшерско-акушерского пункта	t	small
49759	57699	132	Московская область, Воскресенский район, деревня Маришкино, 1А	t	small
52191	59598	2564	Московская область, Воскресенский район, деревня Лидино, 13	f	large
49818	94483	191	Московская область, Воскресенский район, деревня Косяково, 73-б, Дом культуры	f	medium
49803	94480	176	Московская область, Воскресенский район, село Конобеево, Центральная, 123-а, Сельский клуб	f	small
111601	57735	174	Московская область, Воскресенский район, село Конобеево, Центральная, 123 а, Сельский клуб	f	medium
49800	57734	173	Московская область, Воскресенский район, село Конобеево, Новые дома, 13А	f	large
49792	94478	165	Московская область, Воскресенский район, деревня Золотово, Моховая, 1, МОУ Золотовская СОШ	f	large
49828	57762	201	Московская область, Воскресенский район, деревня Елкино, Советская, 84	t	small
49823	94485	196	Московская область, Воскресенский район, деревня Дворниково, 71А, Библиотека-филиал № 14 Воскресенской ЦБС	f	small
49796	94479	169	Московская область, Воскресенский район, деревня Губино, Лесная, 1-б, Сельский клуб	t	medium
49815	57748	188	Московская область, Воскресенский район, деревня Городище, Мира, 9/1	t	small
49758	94474	131	Московская область, Воскресенский район, Воскресенск, микрорайон Центральный, улица Менделеева, 11, МОУ Лицей № 22	f	large
49756	57696	129	Россия, Московская область, Воскресенский район, Воскресенск, улица Зелинского, 5д	f	large
49755	57696	128	Россия, Московская область, Воскресенский район, Воскресенск, улица Зелинского, 5д	f	large
49775	94476	148	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Лопатинский, улица Андреса	f	large
49774	94476	147	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Лопатинский, улица Андреса	f	large
49827	94486	200	Московская область, Воскресенский район, Воскресенск, площадь Ленина, 3, ДК	f	large
49776	57713	149	Россия, Московская область, Воскресенский район, Воскресенск, Юбилейная улица, 24/1	t	medium
49777	57714	150	Московская область, Воскресенский район, Воскресенск, Толстого, 1	f	large
49768	57707	141	Московская область, Воскресенский район, Воскресенск, Советская, 1а	f	large
49779	94477	152	Московская область, Воскресенский район, Воскресенск, Рабочая, 105, 105/МОУ ДОД ДШИ № 5	f	large
49761	57701	134	Московская область, Воскресенский район, Воскресенск, Победы, 25	f	large
49766	57705	139	Московская область, Воскресенский район, Воскресенск, Пионерская, 8	f	large
49767	57706	140	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Центральный, Октябрьская улица, 9	f	large
49764	57703	137	Московская область, Воскресенский район, Воскресенск, Октябрьская, 21	f	medium
49763	57703	136	Московская область, Воскресенский район, Воскресенск, Октябрьская, 21	f	large
49782	57718	155	Московская область, Воскресенский район, Воскресенск, Некрасова, 17	f	medium
49784	57719	157	Московская область, Воскресенский район, Воскресенск, Московская, 23	f	large
49783	57719	156	Московская область, Воскресенский район, Воскресенск, Московская, 23	f	large
68188	57717	158	Московская область, Воскресенский район, Воскресенск, Ломоносова, 117, ГОУ НПО ПУ 44	f	large
68187	57717	153	Московская область, Воскресенский район, Воскресенск, Ломоносова, 117, ГОУ НПО ПУ 44	f	large
49781	57715	154	Московская область, Воскресенский район, Воскресенск, Ломоносова, 100	f	large
49778	57715	151	Московская область, Воскресенский район, Воскресенск, Ломоносова, 100	f	large
49791	57725	164	Московская область, Воскресенский район, Воскресенск, микрорайон Цемгигант, Ленинская, 1А	f	large
49807	57742	180	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Лопатинский, Комсомольская улица, 1	f	large
49814	94482	187	Московская область, Воскресенский район, Воскресенск, Кагана, 22, здание МОУ Гимназия № 1 МОУ ДОД ДШИ Элегия	f	small
49751	94472	124	Московская область, Воскресенский район, Воскресенск, Кагана, 22, гимназия №1 	f	large
49754	94473	127	Московская область, Воскресенский район, Воскресенск, Зелинского, 5 Д, МОУ СОШ № 3	f	large
49753	94473	126	Московская область, Воскресенский район, Воскресенск, Зелинского, 5 Д, МОУ СОШ № 3	f	large
49771	57709	144	Московская область, Воскресенский район, Воскресенск, Зеленый переулок, 3	f	large
49770	57709	143	Московская область, Воскресенский район, Воскресенск, Зеленый переулок, 3	f	large
52921	60216	3298	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Центральный, Железнодорожная улица, 41	f	large
49786	57720	159	Россия, Московская область, Воскресенский район, Воскресенск, микрорайон Цемгигант, Гражданская улица, 27	f	large
49769	57708	142	Московская область, Воскресенский район, Воскресенск, Быковского, 23	f	large
49793	57727	166	Московская область, Воскресенский район, поселок Виноградово, Коммунистическая, здание школы	f	medium
49794	57728	167	Московская область, Воскресенский район, поселок Виноградово, Зеленая, здание конторы Лесхоза	f	medium
49811	57745	184	Московская область, Воскресенский район, Белоозерский, проспект 60 лет Октября, 18	f	large
49812	94481	185	Московская область, Воскресенский район, поселок Белоозерский, Молодежная, 34А, агитцентр	f	large
49808	57743	181	Московская область, Воскресенский район, поселок городского типа Белоозерский, Молодежная, 39	f	large
49804	57738	177	Московская область, Воскресенский район, село Барановское, Центральная, 1А	f	large
49806	57740	179	Московская область, Воскресенский район, село Ашитково, здание станции кабинет начальника станции	f	small
49799	57733	172	Московская область, Воскресенский район, село Ашитково, Школьная, 1А	f	medium
49798	57732	171	Московская область, Воскресенский район, село Ашитково, Центральная, 57	f	small
49797	57731	170	Московская область, Воскресенский район, село Ашитково, Парковая, 1	f	large
49805	57739	178	Московская область, Воскресенский район, село Ашитково, Королькова, 103, село Усадище	f	medium
49795	57729	168	Московская область, Воскресенский район, село Ашитково, Заводская, 2а	f	medium
49817	57750	190	Московская область, Воскресенский район, село Ачкасово, 76, здание школы	f	small
49744	54307	117	Россия, Московская область, Волоколамский район, село Ярополец	f	large
49720	57676	93	Московская область, Волоколамский район, деревня Ченцы, Советская, 5А	f	small
51900	59371	2274	Россия, Московская область, Волоколамский район, деревня Федюково	f	large
49741	57626	114	Московская область, Волоколамский район, деревня Тимонино, Парковая, 2	f	medium
49737	57440	110	Московская область, Волоколамский район, село Теряево, Теряевская, 92А	f	large
49734	57690	107	Московская область, Волоколамский район, село Спасс, Центральная, 47	f	medium
49732	57688	105	Московская область, Волоколамский район, село Осташево, микрорайон, 1	f	large
49739	57573	112	Московская область, Волоколамский район, деревня Нелидово, Крестьянская, 18	f	large
49742	53948	115	Московская область, Волоколамский район, деревня Курьяново, Центральная, 60	f	medium
49735	57419	108	Московская область, Волоколамский район, деревня Клишино, Центральная, 6	f	large
49731	57687	104	Московская область, Волоколамский район, деревня Калистово, Центральная, 21	f	small
49743	54042	116	Московская область, Волоколамский район, село Ильинское, Центральная, 16	f	medium
49740	57588	113	Московская область, Волоколамский район, деревня Гряды, 5 А	f	large
49716	57672	89	Московская область, Волоколамский район, Волоколамск, деревня Щекино, 57	f	medium
49724	57680	97	Московская область, Волоколамский район, Волоколамск, Школьная, 12	f	large
49718	57674	91	Московская область, Волоколамский район, Волоколамск, Тихая, 4	f	large
49728	57684	101	Московская область, Волоколамский район, Волоколамск, микрорайон Привокзальный, Терешковой, 18	f	large
49717	57673	90	Московская область, Волоколамский район, Волоколамск, Текстильщиков, 15	f	large
49721	57677	94	Россия, Московская область, Волоколамский район, Волоколамск, Советская улица, 11	f	medium
49722	57678	95	Московская область, Волоколамский район, Волоколамск, Советская, 2	f	large
49726	57682	99	Московская область, Волоколамский район, Волоколамск, Прохоровская улица, 3	f	large
52341	59722	2717	Россия, Московская область, Волоколамский район, Волоколамск, Пролетарская улица	f	large
49723	57679	96	Московская область, Волоколамский район, Волоколамск, Панфилова, 42/3	f	large
49725	57681	98	Россия, Московская область, Волоколамский район, Волоколамск, Ново-Солдатский переулок, 1	f	large
49733	57689	106	Московская область, Волоколамский район, село Болычево, Новая, 1	f	medium
49482	53901	841	Липецкая область, Чаплыгин, Советская, 74	f	large
49484	53903	843	Липецкая область, Чаплыгин, Московский переулок, 7	f	large
49483	53902	842	Липецкая область, Чаплыгин, Ленина, 3	f	large
49423	53842	782	Липецкая область, Усмань, улица Новоселов, 4А	f	large
49419	53838	778	Липецкая область, Усмань, Шмидта, 25	f	large
49417	53836	776	Липецкая область, Усмань, Чернышевского, 118	f	large
49421	53840	780	Липецкая область, Усмань, Радищева, 50	f	large
49418	53837	777	Липецкая область, Усмань, Радищева, 122	f	large
49450	53867	807	Липецкая область, Усмань, Первомайская, 1а	f	large
49422	53841	781	Липецкая область, Усмань, Ленина, 2	f	large
49420	53839	779	Липецкая область, Усмань, Ленина, 89	f	large
49354	53763	713	Липецкая область, село Подгорное, Центральная, 76А	f	large
49410	53827	769	Липецкая область, поселок Молодежный, 8	f	medium
48762	53184	122	Липецкая область, Липецк, гарнизонный Дом офицеров	f	large
48761	53184	121	Липецкая область, Липецк, гарнизонный Дом офицеров	f	large
48715	53152	77	Липецкая область, Липецк, 5/2	f	large
48714	53152	76	Липецкая область, Липецк, 5/2	f	large
48713	53152	75	Липецкая область, Липецк, 5/2	f	large
48690	53137	48	Липецкая область, Липецк, улица Хорошавина, 9	f	large
48689	52400	47	Липецкая область, Липецк, улица Хорошавина, 14	f	large
48688	52400	46	Липецкая область, Липецк, улица Хорошавина, 14	f	large
48687	52400	45	Липецкая область, Липецк, улица Хорошавина, 14	f	large
48743	53170	103	Липецкая область, Липецк, улица Фрунзе, 91	f	large
48717	53154	79	Липецкая область, Липецк, улица Студенческий Городок, 10	f	large
48694	53139	52	Липецкая область, Липецк, улица Стаханова, 28б	f	large
48645	53110	5	Липецкая область, Липецк, улица Писарева, 37	f	large
48646	53110	6	Липецкая область, Липецк, улица Писарева, 37	f	large
48661	50074	21	Липецкая область, Липецк, улица Парковая, 5	f	large
48662	50074	22	Липецкая область, Липецк, улица Парковая, 5	f	large
48725	53162	87	Липецкая область, Липецк, улица Папина, 3а	f	large
48723	53160	85	Липецкая область, Липецк, улица Папина, 4а	f	large
86449	53815	759	Липецкая область, Липецк, улица Молодежная	f	small
49391	53803	750	Липецкая область, Липецк, улица Молодежная, 2	f	small
48833	53231	193	Липецкая область, Липецк, село Сселки, улица Ленина, 42	f	large
48786	53199	146	Липецкая область, Липецк, Советский район, улица Космонавтов, 82/4	f	large
48785	53199	145	Липецкая область, Липецк, Советский район, улица Космонавтов, 82/4	f	large
48784	53199	144	Липецкая область, Липецк, Советский район, улица Космонавтов, 82/4	f	large
48783	53192	143	Липецкая область, Липецк, Советский район, улица Космонавтов, 54а	f	large
48774	53192	134	Липецкая область, Липецк, Советский район, улица Космонавтов, 54а	f	large
48767	53188	127	Липецкая область, Липецк, Советский район, улица Космонавтов, 36/3	f	large
48768	53188	128	Липецкая область, Липецк, Советский район, улица Космонавтов, 36/3	f	large
48672	53127	32	Липецкая область, Липецк, улица Ильича, 18	f	large
48678	53132	38	Липецкая область, Липецк, улица Ибаррури, 1	f	large
48677	53132	37	Липецкая область, Липецк, улица Ибаррури, 1	f	large
48745	53172	105	Липецкая область, Липецк, улица 50 лет НЛМК, 19	f	large
48733	53166	93	Липецкая область, Липецк, проспект Победы, 51/2	f	large
48730	53164	90	Липецкая область, Липецк, проспект Победы, 69а	f	large
48724	53161	86	Липецкая область, Липецк, проспект Победы, 96	f	large
48682	53146	61	Липецкая область, Липецк, проспект Победы, 122	f	large
48681	53145	60	Липецкая область, Липецк, проспект Победы, 122	f	large
48701	53144	59	Липецкая область, Липецк, проспект Победы, 130	f	large
48700	53144	58	Липецкая область, Липецк, проспект Победы, 130	f	large
48660	53124	20	Липецкая область, Липецк, проспект Мира, 10	f	large
48659	53124	19	Липецкая область, Липецк, проспект Мира, 10	f	large
48654	53118	14	Липецкая область, Липецк, проспект Мира, 7	f	large
81802	56022	965	Москва, Хабаровская, 18к2	f	large
48703	53147	63	Липецкая область, Липецк, проезд Сиреневый, 9	f	large
48702	53147	62	Липецкая область, Липецк, проезд Сиреневый, 9	f	large
48808	53211	168	Липецкая область, Липецк, проезд Кувшинова, 5, Гимназия №59	f	large
48807	53211	167	Липецкая область, Липецк, проезд Кувшинова, 5, Гимназия №59	f	large
48669	53125	29	Липецкая область, Липецк, проезд Ильича, 1	f	large
48819	53220	179	Липецкая область, Липецк, проезд Боевой, 24а	f	large
48818	53220	178	Липецкая область, Липецк, проезд Боевой, 24а	f	large
48805	53210	165	Липецкая область, Липецк, пр. Сержанта Кувшинова, 3	f	large
48806	53210	166	Липецкая область, Липецк, пр. Сержанта Кувшинова, 3	f	large
48804	53210	164	Липецкая область, Липецк, пр. Сержанта Кувшинова, 3	f	large
48754	53179	114	Липецкая область, Липецк, площадь Торговая, 14А	f	large
48753	53179	113	Липецкая область, Липецк, площадь Торговая, 14А	f	large
48652	53116	12	Липецкая область, Липецк, площадь Мира, 1	f	large
48846	53243	206	Липецкая область, Липецк, площадь Константиновой, 3	f	large
48845	53242	205	Липецкая область, Липецк, площадь Константиновой, 3	f	large
48840	53237	200	Липецкая область, Липецк, площадь Константиновой, 2	f	large
48685	53135	43	Липецкая область, Липецк, переулок Учебный, 1	f	large
48684	53135	42	Липецкая область, Липецк, переулок Учебный, 1	f	large
48683	53135	41	Липецкая область, Липецк, переулок Учебный, 1	f	large
48695	53140	53	Липецкая область, Липецк, бульвар Шубина, 7	f	large
48693	53138	51	Липецкая область, Липецк, бульвар Шубина, 15	f	large
48692	53138	50	Липецкая область, Липецк, бульвар Шубина, 15	f	large
48691	53138	49	Липецкая область, Липецк, бульвар Шубина, 15	f	large
48699	53142	57	Липецкая область, Липецк, бульвар Есенина, 7а	f	large
48698	53142	56	Липецкая область, Липецк, бульвар Есенина, 7а	f	large
68174	53142	55	Липецкая область, Липецк, бульвар Есенина, 7а	f	large
48735	53168	95	Липецкая область, Липецк, Юных Натуралистов, 12а	f	large
48737	53168	97	Липецкая область, Липецк, Юных Натуралистов, 12а	f	large
48736	53168	96	Липецкая область, Липецк, Юных Натуралистов, 12а	f	large
48734	53167	94	Липецкая область, Липецк, Юных Натуралистов, 12	f	large
48812	53214	172	Липецкая область, Липецк, Юношеская, 23а	f	large
48644	53100	4	Липецкая область, Липецк, Энергостроителей, 21	f	large
48643	53090	3	Липецкая область, Липецк, Энергостроителей, 5а	f	large
86549	53829	771	Липецкая область, Липецк, Школьная, 3	f	small
49393	53805	752	Липецкая область, Липецк, Школьная, 10	f	medium
48686	53136	44	Липецкая область, Липецк, Шерстобитова, 8	f	large
48779	53195	139	Липецкая область, Липецк, Циолковского, 34/4	f	large
48778	53194	138	Липецкая область, Липецк, Циолковского, 31	f	large
48777	53194	137	Липецкая область, Липецк, Циолковского, 31	f	large
49396	53808	755	Липецкая область, Липецк, Центральная, 19	f	medium
49395	53807	754	Липецкая область, Липецк, Центральная, 52	f	small
49392	53804	751	Липецкая область, Липецк, Центральная, 20	f	small
49390	53802	749	Липецкая область, Липецк, Центральная, 20	f	small
111304	53800	748	Липецкая область, Липецк, Центральная, 19	f	medium
49387	53798	746	Липецкая область, Липецк, Центральная, 12	f	small
48651	53115	11	Липецкая область, Липецк, Фурманова, 27	f	medium
48798	53206	158	Липецкая область, Липецк, Филипченко, 8/1	f	large
48794	53204	154	Липецкая область, Липецк, Филипченко, 7/4	f	large
48843	53240	203	Липецкая область, Липецк, Ушинского, 14	f	large
48842	53239	202	Липецкая область, Липецк, Ушинского, 19	f	large
48841	53238	201	Липецкая область, Липецк, Ушинского, 5	f	large
48813	53215	173	Липецкая область, Липецк, Ударников, 13	f	large
48719	53156	81	Липецкая область, Липецк, Студенческий городок, 2	f	large
48716	53153	78	Липецкая область, Липецк, Студенческий городок, 24	f	large
48720	53158	82	Липецкая область, Липецк, Студенческий Городок, 1	f	large
48834	53232	194	Липецкая область, Липецк, Студеновская , 4А	f	large
48712	53151	74	Липецкая область, Липецк, Стаханова, 6	f	large
48711	53151	73	Липецкая область, Липецк, Стаханова, 6	f	large
48710	53150	72	Липецкая область, Липецк, Стаханова, 17	f	large
48709	53150	71	Липецкая область, Липецк, Стаханова, 17	f	large
48708	53150	70	Липецкая область, Липецк, Стаханова, 17	f	large
48707	53149	69	Липецкая область, Липецк, Стаханова, 15	f	large
81801	56022	964	Москва, Хабаровская, 18к2	f	large
48706	53149	68	Липецкая область, Липецк, Стаханова, 15	f	large
48705	53149	67	Липецкая область, Липецк, Стаханова, 15	f	large
48696	53141	54	Липецкая область, Липецк, Стаханова, 39а	f	large
49408	53823	767	Липецкая область, Липецк, Совхозная, 9	t	small
68179	53825	768	Липецкая область, Липецк, Советская , 35	f	large
48649	53113	9	Липецкая область, Липецк, Силикатная, 19	f	large
48760	53183	120	Липецкая область, Липецк, Семашко, 68	f	large
48759	53183	119	Липецкая область, Липецк, Семашко, 68	f	large
48758	53182	118	Липецкая область, Липецк, Семашко, 5	f	large
48757	53182	117	Липецкая область, Липецк, Семашко, 5	f	large
48815	53217	175	Липецкая область, Липецк, Северный рудник, 27	f	medium
48851	53246	211	Липецкая область, Липецк, Ракитная, 2	f	large
48850	53246	210	Липецкая область, Липецк, Ракитная, 2	f	large
68173	53123	18	Липецкая область, Липецк, Прокатная, 10	f	large
48648	53112	8	Липецкая область, Липецк, Пришкольная, 21	f	large
48647	53111	7	Липецкая область, Липецк, Привокзальная, 101	f	large
49388	53799	747	Липецкая область, Липецк, Почтовая, 56	f	medium
48809	53212	169	Липецкая область, Липецк, Политехническая , 9А	f	large
48666	50994	26	Липецкая область, Липецк, Полины Осипенко, 18	f	large
48664	50194	24	Липецкая область, Липецк, Полины Осипенко, 12	f	medium
48828	53226	188	Липецкая область, Липецк, Плеханова, 51а	f	large
48827	53226	187	Липецкая область, Липецк, Плеханова, 51а	f	large
48755	53180	115	Липецкая область, Липецк, Первомайская, 59	f	large
48751	53177	111	Липецкая область, Липецк, Первомайская, 58	f	large
48722	53159	84	Липецкая область, Липецк, Папина, 4	f	large
48721	53159	83	Липецкая область, Липецк, Папина, 4	f	large
48718	53155	80	Липецкая область, Липецк, Папина, 3	f	large
48752	53178	112	Липецкая область, Липецк, Октябрьская, 88а	f	large
48816	53218	176	Липецкая область, Липецк, Одоевского, 10	f	medium
48656	53120	16	Липецкая область, Липецк, Невского, 2	f	large
48787	53200	147	Липецкая область, Липецк, Московская, 51а	f	large
48789	53200	149	Липецкая область, Липецк, Московская, 51а	f	large
48788	53200	148	Липецкая область, Липецк, Московская, 51а	f	large
48642	53108	2	Липецкая область, Липецк, Моршанская, 10	f	large
48641	53108	1	Липецкая область, Липецк, Моршанская, 10	f	large
86568	53817	761	Липецкая область, Липецк, Молодежная, 3	f	small
49399	53813	758	Липецкая область, Липецк, Молодежная, 5	f	small
86547	53811	757	Липецкая область, Липецк, Молодежная, 8	f	small
49406	53821	765	Липецкая область, Липецк, Мичурина, 26б	f	large
48739	53169	99	Липецкая область, Липецк, Мичурина, 30	f	large
48738	53169	98	Липецкая область, Липецк, Мичурина, 30	f	large
48740	53157	100	Липецкая область, Липецк, Мичурина, 22	f	large
48742	53157	102	Липецкая область, Липецк, Мичурина, 22	f	large
48741	53157	101	Липецкая область, Липецк, Мичурина, 22	f	large
48729	53163	89	Липецкая область, Липецк, Механизаторов, 21	f	small
48728	53134	88	Липецкая область, Липецк, Механизаторов, 10	f	large
48680	53134	40	Липецкая область, Липецк, Механизаторов, 10	f	large
48727	53148	66	Липецкая область, Липецк, Меркулова, 11а	f	large
48726	53148	65	Липецкая область, Липецк, Меркулова, 11а	f	large
48750	53176	110	Липецкая область, Липецк, Максима Горького, 10	f	large
49413	53831	772	Липецкая область, Липецк, Луговая, 21	f	small
48747	53174	107	Липецкая область, Липецк, Л. Толстого, 23а	f	large
48679	53133	39	Липецкая область, Липецк, Краснознаменная, 4	f	large
48676	53131	36	Липецкая область, Липецк, Краснозаводская, 8	f	large
48852	53248	212	Липецкая область, Липецк, Космонавтов, 1	f	medium
48793	53203	153	Липецкая область, Липецк, Космонавтов, 90	f	large
48792	53202	152	Липецкая область, Липецк, Космонавтов, 108	f	large
48776	53193	136	Липецкая область, Липецк, Космонавтов, 11б	f	large
48775	53193	135	Липецкая область, Липецк, Космонавтов, 11б	f	large
48765	53186	125	Липецкая область, Липецк, Космонавтов, 16а	f	large
48764	53186	124	Липецкая область, Липецк, Космонавтов, 16а	f	large
48675	53130	35	Липецкая область, Липецк, Коммунистическая, 17	f	large
48673	53128	33	Липецкая область, Липецк, Коммунистическая, 20	f	large
48826	53225	186	Липецкая область, Липецк, Интернациональная, 53а	f	large
48756	53181	116	Липецкая область, Липецк, Интернациональная, 5а	f	large
48668	51045	28	Липецкая область, Липецк, Ильича, 31	f	large
48667	51045	27	Липецкая область, Липецк, Ильича, 31	f	large
48825	53224	185	Липецкая область, Липецк, И.В. Шкатова, 25	f	large
48824	53224	184	Липецкая область, Липецк, И.В. Шкатова, 25	f	large
48650	53114	10	Липецкая область, Липецк, Зои Космодемьянской, 178	f	large
48829	53227	189	Липецкая область, Липецк, Зегеля, 6	f	large
48800	53207	160	Липецкая область, Липецк, Звездная, 12	f	large
48799	53207	159	Липецкая область, Липецк, Звездная, 12	f	large
48797	53205	157	Липецкая область, Липецк, Звездная, 6	f	large
48796	53205	156	Липецкая область, Липецк, Звездная, 6	f	large
48795	53205	155	Липецкая область, Липецк, Звездная, 6	f	large
48820	53221	180	Липецкая область, Липецк, Железнякова, 8	f	large
48835	53233	195	Липецкая область, Липецк, Елецкая, 63	f	large
48836	53233	196	Липецкая область, Липецк, Елецкая, 63	f	large
48839	53236	199	Липецкая область, Липецк, Дружбы, 32	f	large
48655	53119	15	Липецкая область, Липецк, Дзержинского, 27	f	large
48811	53213	171	Липецкая область, Липецк, Детская, 2в	f	large
48810	53213	170	Липецкая область, Липецк, Детская, 2в	f	large
48732	53165	92	Липецкая область, Липецк, Депутатская , 55б	f	large
48731	53165	91	Липецкая область, Липецк, Депутатская , 55б	f	large
48837	53234	197	Липецкая область, Липецк, Гражданская, 1а	f	large
48773	53191	133	Липецкая область, Липецк, Германа Титова, 8	f	large
48772	53191	132	Липецкая область, Липецк, Германа Титова, 8	f	large
48771	53190	131	Липецкая область, Липецк, Гагарина, 129	f	large
48823	53223	183	Липецкая область, Липецк, Гагарина, 24	f	large
48822	53222	182	Липецкая область, Липецк, Гагарина, 84	f	large
48821	53222	181	Липецкая область, Липецк, Гагарина, 84	f	large
48770	53189	130	Липецкая область, Липецк, Гагарина, 123/3	f	large
48769	53189	129	Липецкая область, Липецк, Гагарина, 123/3	f	large
48766	53187	126	Липецкая область, Липецк, Гагарина, 73а	f	large
86542	53249	213	Липецкая область, Липецк, Гагарина, 106	f	small
48671	53126	31	Липецкая область, Липецк, Волгоградская, 4	f	large
48670	53126	30	Липецкая область, Липецк, Волгоградская, 4	f	large
48803	53209	163	Липецкая область, Липецк, Вермишева, 23б	f	large
48802	53208	162	Липецкая область, Липецк, Вермишева, 16	f	large
48801	53208	161	Липецкая область, Липецк, Вермишева, 16	f	large
48763	53185	123	Липецкая область, Липецк, В. Терешковой, 13	f	large
48849	53245	209	Липецкая область, Липецк, Баумана, 262	f	large
48847	53244	207	Липецкая область, Липецк, Арсеньева, 38а	f	large
48848	53244	208	Липецкая область, Липецк, Арсеньева, 38а	f	large
48653	53117	13	Липецкая область, Липецк, Адмирала Макарова, 4	f	large
48791	53201	151	Липецкая область, Липецк, 9 микрорайон, 42а	f	large
48790	53201	150	Липецкая область, Липецк, 9 микрорайон, 42а	f	large
48749	53175	109	Липецкая область, Липецк, 8 Марта, 22/4	f	large
48748	53175	108	Липецкая область, Липецк, 8 Марта, 22/4	f	large
48746	53173	106	Липецкая область, Липецк, 8 Марта, 20а	f	large
48744	53171	104	Липецкая область, Липецк, 50 лет НЛМК, 9	f	large
48831	53229	191	Липецкая область, Липецк, Ленина, 28	f	large
49342	53751	700	Липецкая область, село Ленино, Гурьева, 205а	f	large
49341	53751	699	Липецкая область, село Ленино, Гурьева, 205а	f	large
49254	53661	612	Липецкая область, Лебедянь, Шоссейный проезд, 10	f	large
49253	53660	611	Липецкая область, Лебедянь, Школьная, 17	f	large
49247	53653	605	Липецкая область, Лебедянь, Шахрая, 40	f	large
49256	53663	614	Липецкая область, Лебедянь, Тургенева, 32	f	medium
49248	53654	606	Липецкая область, Лебедянь, Студенческая, 12	f	large
49251	53658	609	Липецкая область, Лебедянь, Привокзальная, 1	f	medium
49252	53659	610	Липецкая область, Лебедянь, Первомайская, 13	f	large
49246	53652	604	Липецкая область, Лебедянь, Антонова, 14	f	large
49144	53543	504	Липецкая область, Задонск, Степанищева, 21	f	large
49146	53545	506	Липецкая область, Задонск, Крупской, 56	f	large
49143	53542	503	Липецкая область, Задонск, Коммуны, 17	f	large
49063	53465	424	Липецкая область, Елец, микрорайон Александровский, 15	f	large
49103	53502	463	Липецкая область, Елец, Юбилейная, 7а	f	large
49105	53502	465	Липецкая область, Елец, Юбилейная, 7а	f	large
49108	53506	468	Липецкая область, Елец, Электриков, 2-а	f	large
49067	53470	428	Липецкая область, Елец, Спутников, 9-а	f	large
49066	53469	427	Липецкая область, Елец, Спутников, 9	f	large
49065	53468	426	Липецкая область, Елец, Спутников, 15	f	large
49057	53459	418	Липецкая область, Елец, Советская, 121	f	medium
49069	53472	430	Липецкая область, Елец, Свердлова, 137	f	large
49084	53485	445	Липецкая область, Елец, Рязано-Уральская, 43	f	large
49104	53500	464	Липецкая область, Елец, Радиотехническая, 3	f	large
49100	53500	460	Липецкая область, Елец, Радиотехническая, 3	f	large
49101	53474	461	Липецкая область, Елец, Радиотехническая, 6а	f	large
49072	53474	433	Липецкая область, Елец, Радиотехническая, 6а	f	large
49096	53496	456	Липецкая область, Елец, Пушкина, 54	f	large
49092	53493	453	Липецкая область, Елец, Профинтерна, 2-а	f	large
49093	53494	454	Липецкая область, Елец, Проспект Мира, 83	f	large
49068	53447	429	Липецкая область, Елец, Пригородная, 55-а	f	small
49106	53504	466	Липецкая область, Елец, Плеханова, 1а	f	large
49080	53481	441	Липецкая область, Елец, Орджоникидзе, 9а	f	large
49097	53497	457	Липецкая область, Елец, Октябрьская, 22	f	large
49087	53488	448	Липецкая область, Елец, Новолипецкая, 1б	f	large
49076	53478	437	Липецкая область, Елец, Мира, 84	f	large
49075	53477	436	Липецкая область, Елец, Мира, 94	f	large
49058	53460	419	Липецкая область, Елец, Маяковского, 64	f	large
49094	53495	455	Липецкая область, Елец, Лермонтова, 3	f	large
49059	53461	420	Липецкая область, Елец, Ленина, 91	f	large
49088	53489	449	Липецкая область, Елец, Кротевича, 25	f	large
49079	53479	440	Липецкая область, Елец, Красноармейская, 45	f	large
49077	53479	438	Липецкая область, Елец, Красноармейская, 45	f	large
49102	53501	462	Липецкая область, Елец, Костенко, 57	f	large
49060	53462	421	Липецкая область, Елец, Комсомольская, 83	f	large
49062	53464	423	Липецкая область, Елец, Коммунаров, 48	f	large
49061	53463	422	Липецкая область, Елец, Коммунаров, 30	f	large
49081	53482	442	Липецкая область, Елец, Клубная, 10	f	large
49086	53487	447	Липецкая область, Елец, Известковая, 77	f	large
49085	53486	446	Липецкая область, Елец, Задонское шоссе, 2	f	large
49090	53491	451	Липецкая область, Елец, Задонская, 47	f	large
49098	53498	458	Липецкая область, Елец, Ефремовская, 1	f	large
49071	53473	432	Липецкая область, Елец, Гагарина, 20а	f	large
49070	53473	431	Липецкая область, Елец, Гагарина, 20а	f	large
49089	53490	450	Липецкая область, Елец, Верхняя, 17	f	large
49083	53484	444	Липецкая область, Елец, Вермишева, 1	f	large
49082	53483	443	Липецкая область, Елец, Вермишева, 12	f	large
49099	53499	459	Липецкая область, Елец, Барковского, 3	f	large
49107	53505	467	Липецкая область, Елец, Ани Гайтеровой, 1а	f	large
68169	53466	425	Липецкая область, Елец, Александровский микрорайон, 15	f	large
49078	53480	439	Липецкая область, Елец, А. Оборотова, 4	f	large
49056	53458	417	Липецкая область, Елец, 3-й Ламской переулок, 43-а	f	large
49055	53458	416	Липецкая область, Елец, 3-й Ламской переулок, 43-а	f	large
49109	53507	469	Липецкая область, Елец, 1-я Речная, 34	f	large
48931	53293	292	Липецкая область, Данковский район, Данков, Энгельса, 7	f	large
48929	53332	290	Липецкая область, Данковский район, Данков, Чапаева, 13/1	f	large
48924	53327	285	Липецкая область, Данковский район, Данков, Свердлова, 1б	f	medium
48934	53334	295	Липецкая область, Данковский район, Данков, Пионерская, 11	f	large
48932	53319	293	Липецкая область, Данковский район, Данков, Островского, 30	f	small
48926	53329	287	Липецкая область, Данковский район, Данков, Моложедная, 2	f	large
48928	53331	289	Липецкая область, Данковский район, Данков, Мичурина, 7/1	f	large
48927	53330	288	Липецкая область, Данковский район, Данков, Мичурина, 8	f	large
48930	53256	291	Липецкая область, Данковский район, Данков, Мира, 40	f	large
48925	53328	286	Липецкая область, Данковский район, Данков, Ленина, 18	f	large
48935	53335	296	Липецкая область, Данков, Коммунальная, 21	f	medium
48923	53326	284	Липецкая область, Данковский район, Данков, Зеленая, 4	f	medium
48933	53333	294	Липецкая область, Данковский район, Данков, Володарского, 44	f	large
48878	53276	239	Липецкая область, Грязи, Шкатова, 1	f	large
48874	53272	235	Липецкая область, Грязи, Станционная, 1	f	large
48883	53282	244	Липецкая область, Грязи, Советская, 92	f	medium
48889	53288	250	Липецкая область, Грязи, Правды, 26	f	large
48887	53286	248	Липецкая область, Грязи, Правды, 58	f	large
48888	53287	249	Липецкая область, Грязи, Первомайская, 31	f	large
48880	53278	241	Липецкая область, Грязи, Осовиахима, 1	f	large
48875	53273	236	Липецкая область, Грязи, Орджоникидзе, 80а	f	large
68168	53290	251	Липецкая область, Грязи, Некрасова, 1	f	large
48896	53297	257	Липецкая область, Грязи, Марины Расковой, 33	f	large
48894	53295	255	Липецкая область, Грязи, М. Расковой, 30	f	large
48885	53284	246	Липецкая область, Грязи, Крылова, 4	f	large
48886	53285	247	Липецкая область, Грязи, Красная Площадь, 37	f	large
48884	53283	245	Липецкая область, Грязи, Коммунальная, 5	f	large
48891	53291	252	Липецкая область, Грязи, Гастелло, 5	f	large
48895	53296	256	Липецкая область, Грязи, Гагарина, 1а	f	large
48876	53274	237	Липецкая область, Грязи, 18 Партсъезд, 81а	f	large
49515	53934	874	Липецкая область, Чаплыгинский район, поселок Юсово, Советская, 9	f	medium
49513	53932	872	Липецкая область, Чаплыгинский район, поселок Шишкино	f	small
49495	53914	854	Липецкая область, Чаплыгинский район, поселок Чечеры, Зеленая, 61	f	small
49481	53900	840	Липецкая область, Чаплыгинский район, Чаплыгин, Советская, 10 А	f	large
49512	53931	871	Липецкая область, Чаплыгинский район, поселок Урусово, Центральная, 8	f	small
49511	53930	870	Липецкая область, Чаплыгинский район, поселок Троекурово, Советская, 4	f	medium
49504	53923	863	Липецкая область, Чаплыгинский район, поселок Топтыково, Центральная, 78	f	small
49509	53928	868	Липецкая область, Чаплыгинский район, поселок Соловое, Центральная, 7	f	small
49510	53929	869	Липецкая область, Чаплыгинский район, поселок Солнцево, Школьная, 7	f	small
49514	53933	873	Липецкая область, Чаплыгинский район, поселок Рощинский, Школьная, 12	f	medium
49508	53927	867	Липецкая область, Чаплыгинский район, поселок Пиково, Красиловка, 2	f	small
49506	53925	865	Липецкая область, Чаплыгинский район, поселок Новополянье, Школьная, 4	f	medium
49507	53926	866	Липецкая область, Чаплыгинский район, поселок Новое Петелино, Молодежная, 17	f	small
49503	53922	862	Липецкая область, Чаплыгинский район, поселок Ломовое, Советская, 24	f	small
49502	53921	861	Липецкая область, Чаплыгинский район, поселок Лозовка, Центральная	f	small
49500	53919	859	Липецкая область, Чаплыгинский район, поселок Кривополянье, им.Радина, 2 А	f	large
49499	53918	858	Липецкая область, Чаплыгинский район, поселок Кривополянье, Пролетарская, 2 Б	f	large
49498	53917	857	Липецкая область, Чаплыгинский район, поселок Кривополянье, Дзержинского, 35	f	large
49497	53916	856	Липецкая область, Чаплыгинский район, поселок Конюшки, Центральная, 133	f	small
49501	53920	860	Липецкая область, Чаплыгинский район, поселок Колыбельское, Революционная, 52	f	medium
49496	53915	855	Липецкая область, Чаплыгинский район, поселок Истобное, Ленинская, 1	f	small
49494	53913	853	Липецкая область, Чаплыгинский район, поселок Зенкино, Советская, 4	f	small
49493	53912	852	Липецкая область, Чаплыгинский район, поселок Жабино, Спортивная, 4	t	small
49505	53924	864	Липецкая область, Чаплыгинский район, поселок Дуровщино, Богдановка, 38	f	small
49491	53910	850	Липецкая область, Чаплыгинский район, поселок Дубовое, Театральная, 33	f	medium
49492	53911	851	Липецкая область, Чаплыгинский район, поселок Дубовое, Авиационная	f	medium
86577	53909	849	Липецкая область, Чаплыгинский район, поселок Демкино, Махоново, 103	t	small
49489	53908	848	Липецкая область, Чаплыгинский район, поселок Выселки	f	small
49486	53905	845	Липецкая область, Чаплыгинский район, поселок Воскресенское, Центральная, 1	f	small
49488	53907	847	Липецкая область, Чаплыгинский район, поселок Ведное, Центральная, 7 А	f	small
49487	53906	846	Липецкая область, Чаплыгинский район, поселок Буховое, Красноармейская, 1	f	small
49485	53904	844	Липецкая область, Чаплыгинский район, поселок Братовка, Свинушки, 1	f	small
49516	53935	875	Липецкая область, Чаплыгинский район, поселок Большой Снежеток	f	small
68180	53897	838	Липецкая область, Хлевенский район, поселок Хлевное, Юбилейная, 2	f	large
49478	53896	837	Липецкая область, Хлевенский район, поселок Хлевное, Свободы, 54	f	large
49480	53899	839	Липецкая область, Хлевенский район, поселок Хлевное, Пугачева, 5	f	medium
49477	53895	836	Липецкая область, Хлевенский район, поселок Фомина-Негачевка, Центральная, 20	f	medium
49467	53886	826	Липецкая область, Хлевенский район, поселок Старо Дубовое, Школьная, 13	f	small
49475	53893	834	Липецкая область, Хлевенский район, поселок Синдякино, Центральная, 25	f	small
49476	53894	835	Липецкая область, Хлевенский район, поселок Подгорное, Молодежная, 15	f	small
49474	53892	833	Липецкая область, Хлевенский район, поселок Отскочное, Центральная, 2	f	medium
49473	53891	832	Липецкая область, Хлевенский район, поселок Новое Дубовое, Советская, 105	f	large
49472	53890	831	Липецкая область, Хлевенский район, поселок Нижняя Колыбелька, Центральная, 50	f	medium
49465	53884	824	Липецкая область, Хлевенский район, поселок Муравьевка, Школьная, 1	f	small
49471	53889	830	Липецкая область, Хлевенский район, поселок Малый Мечек, Центральная, 21	f	small
49470	53812	829	Липецкая область, Хлевенский район, поселок Малинино, Мирная, 37	f	small
49469	53888	828	Липецкая область, Хлевенский район, поселок Конь-Колодезь, Ленина, 155	f	large
49466	53885	825	Липецкая область, Хлевенский район, поселок Елецко-Маланинский, Дорожная, 5	f	medium
49468	53887	827	Липецкая область, Хлевенский район, поселок Елецкая Лозовка, Выгонская-Буторина, 20	f	medium
49464	53883	823	Липецкая область, Хлевенский район, поселок Дмитряшевка, Ленина, 38	f	large
49463	53882	822	Липецкая область, Хлевенский район, поселок Воронежская Лозовка, Дорожная, 40	f	small
49462	53881	821	Липецкая область, Хлевенский район, поселок Воробьевка, Мира, 4	f	medium
49461	53880	820	Липецкая область, Хлевенский район, поселок Верхняя Колыбелька, Мира, 15	f	medium
49460	53879	819	Липецкая область, Хлевенский район, поселок Введенка, Центральная, 15	f	medium
49438	53851	791	Липецкая область, Усманский район, станция Дрязги, Центральная, 9-а	f	large
49455	53873	813	Липецкая область, Усманский район, поселок совхоза Ударник, Молодежная, 19а	f	small
49416	53835	775	Липецкая область, Усманский район, Усмань, Карла Маркса, 30	f	large
49458	53877	817	Липецкая область, Усманский район, поселок Студенки, Первомайская, 52	f	small
49451	53870	810	Липецкая область, Усманский район, село Стрелецкие Хутора, Г.Телегина, 187-А	f	medium
49457	53875	815	Липецкая область, Усманский район, поселок Сторожевские Хутора, Центральная, 72	f	medium
49454	53872	812	Липецкая область, Усманский район, поселок Сторожевое, Школьная, 54	f	large
49452	53866	806	Липецкая область, Усманский район, поселок Поддубровка	f	large
49435	53865	805	Липецкая область, Усманский район, поселок Пластинка, Центральная, 14	f	medium
49434	53864	804	Липецкая область, Усманский район, поселок Пашково, Заречная, 34	f	small
49446	53862	802	Липецкая область, Усманский район, поселок Октябрьское, Проспект Революции, 77	f	medium
49447	53863	803	Липецкая область, Усманский район, поселок Октябрьское, Базарная, 1	f	medium
49429	53849	789	Липецкая область, Усманский район, поселок Новоуглянка, Дзержинского, 25	f	large
49445	53861	801	Липецкая область, Усманский район, поселок Никольское	f	medium
49444	53860	800	Липецкая область, Усманский район, поселок Никольское, Ленина, 117	f	medium
49436	53876	816	Липецкая область, Усманский район, поселок Никольские Выселки, Центральная, 60	f	small
49439	53852	792	Липецкая область, Усманский район, поселок Московка, Центральная, 21-а	f	small
49449	53869	809	Липецкая область, Усманский район, поселок Медовка, Молодежная, 12-а	f	small
49453	53871	811	Липецкая область, Усманский район, поселок Куриловка, Б.Котова, 28	f	small
49442	53859	799	Липецкая область, Усманский район, поселок Куликово, Лесная, 10	f	small
49443	53858	798	Липецкая область, Усманский район, поселок Куликово, Ленина, 96	f	medium
49433	53857	797	Липецкая область, Усманский район, поселок Крутченская Байгора, Центральная, 27	f	medium
49441	53856	796	Липецкая область, Усманский район, поселок Кривка, Садовая, 1	f	medium
49456	53874	814	Липецкая область, Усманский район, поселок Красное, 60 лет Победы, 104	f	small
49440	53855	795	Липецкая область, Усманский район, поселок Излегоще, Центральная, 73	f	small
49432	53854	794	Липецкая область, Усманский район, поселок Завальное, Пионерская, 37	f	small
49431	53853	793	Липецкая область, Усманский район, поселок Завальное, Ленина, 119	f	medium
49430	53850	790	Липецкая область, Усманский район, поселок Дмитриевка, Центральная, 10	f	small
49428	53848	788	Липецкая область, Усманский район, поселок Девица, Советская, 5-а	f	large
49427	53847	787	Липецкая область, Усманский район, поселок Грачевка, Ленина, 4	f	medium
49426	53846	786	Липецкая область, Усманский район, поселок Верхняя Мосоловка, Попова, 1	f	small
49425	53845	785	Липецкая область, Усманский район, поселок Бреславка	f	medium
49448	53868	808	Липецкая область, Усманский район, поселок Бочиновка, Заречная, 33	f	small
49437	53844	784	Липецкая область, Усманский район, поселок Боровое, Новая, 12	f	small
49424	53843	783	Липецкая область, Усманский район, поселок Березняговка, Ворошилова, 95-а	f	medium
49459	53878	818	Липецкая область, Усманский район, поселок Беляево, Лесная, 1	f	small
49411	53828	770	Липецкая область, Тербунский район, поселок Яковлево, переулок Почтовый, 6	f	small
111306	53833	773	Липецкая область, Тербунский район, поселок Урицкое, Пятая Сотня, 34	f	medium
49404	53819	763	Липецкая область, Тербунский район, поселок Тербуны, Октябрьская, 39А	f	large
49405	53820	764	Липецкая область, Тербунский район, поселок Тербуны, Ленина, 45	f	large
49403	53818	762	Липецкая область, Тербунский район, поселок Тербуны, Красноармейская, 4	f	large
49401	53816	760	Липецкая область, Тербунский район, поселок Солдатское, Сельская, 34	f	large
49397	53809	756	Липецкая область, Тербунский район, поселок Петропавловка, Высота, 1	f	small
49394	53806	753	Липецкая область, Тербунский район, поселок Михайловка, Садовая, 34	f	small
111302	53796	745	Липецкая область, Тербунский район, поселок Березовка, Центральная, 21	f	medium
49415	53834	774	Липецкая область, Тербунский район, поселок Барышниково, Лесная, 11	f	small
49385	53795	744	Липецкая область, Становлянский район, поселок Яркино, Московская, 14	f	small
49383	53793	742	Липецкая область, Становлянский район, поселок Чернолес, Лесная, 15	f	small
86546	53782	731	Липецкая область, Становлянский район, поселок Чемоданово, Центральная, 6	f	small
49384	53794	743	Липецкая область, Становлянский район, поселок Успенское, Соборная, 29	f	small
49381	53791	740	Липецкая область, Становлянский район, поселок Тростное, Центральная, 9	f	medium
49369	53778	728	Липецкая область, Становлянский район, поселок Толстая Дубрава, Центральная, 28	f	medium
49382	53792	741	Липецкая область, Становлянский район, поселок Телегино, Механизаторов, 58	f	small
49360	53769	719	Липецкая область, Становлянский район, поселок Становая, Новая, 2	f	small
49359	53768	718	Липецкая область, Становлянский район, поселок Становая, Московская, 62	f	large
49358	53767	717	Липецкая область, Становлянский район, поселок Становая, Ленина, 7	f	large
49380	53790	739	Липецкая область, Становлянский район, поселок Соловьево, Садовая, 24	f	medium
49370	53779	729	Липецкая область, Становлянский район, поселок Семенек, Поволяева, 2	f	small
49367	53776	726	Липецкая область, Становлянский район, поселок Плоты, Советская, 50	f	small
49376	53786	735	Липецкая область, Становлянский район, поселок Пальна-Михайловка, 9 мая, 5	f	medium
49379	53789	738	Липецкая область, Становлянский район, поселок Паленка, Ленина, 2	f	medium
49365	53774	724	Липецкая область, Становлянский район, поселок Озерки, А.И.Бунина, 5	f	small
49368	53777	727	Липецкая область, Становлянский район, поселок Лукьяновка, Центральная, 17	f	medium
49371	53780	730	Липецкая область, Становлянский район, поселок Ламское, Победы, 4	f	medium
49378	53788	737	Липецкая область, Становлянский район, поселок Красная Пальна, Фермерская, 12	f	small
49375	53785	734	Липецкая область, Становлянский район, поселок Кличено, Центральная, 40	f	small
49362	53771	721	Липецкая область, Становлянский район, поселок Кириллово, Центральная, 7	f	medium
49363	53772	722	Липецкая область, Становлянский район, поселок Злобино, Центральная, 2	f	small
49361	53770	720	Липецкая область, Становлянский район, поселок Дружба, 2в	f	medium
49364	53773	723	Липецкая область, Становлянский район, поселок Дмитриевка, Центральная, 10	f	medium
49366	53775	725	Липецкая область, Становлянский район, поселок Грунин Воргол, Советская, 13	f	small
49377	53787	736	Липецкая область, Становлянский район, поселок Бродки, Солнечная, 26	f	small
49373	53783	732	Липецкая область, Становлянский район, поселок Березовка, Ю.Тарасова, 18	f	medium
49374	53784	733	Липецкая область, Становлянский район, поселок Барсуково, Ленина, 8	f	small
49357	53766	716	Липецкая область, Липецкий район, поселок Частая Дубрава, Московская, 13	f	large
49355	53764	714	Липецкая область, Липецкий район, село Хрущевка, Титова, 79	f	large
49338	53749	696	Липецкая область, Липецкий район, поселок Тюшевка, Центральная, 18	f	medium
49340	53750	698	Липецкая область, Липецкий район, поселок Троицкое, Гагарина, 70	f	large
49339	53750	697	Липецкая область, Липецкий район, поселок Троицкое, Гагарина, 70	f	large
49356	53765	715	Липецкая область, Липецкий район, поселок Тележенка, Фрунзе, 4	f	medium
49353	53762	712	Липецкая область, Липецкий район, село Сырское, Советская, 139б	f	large
49352	53761	711	Липецкая область, Липецкий район, село Сырское, Ленина, 7	f	large
49343	53752	701	Липецкая область, Липецкий район, поселок Сухая Лубна, Ксении Константиновой, 1в	f	large
49334	53743	692	Липецкая область, Липецкий район, поселок Студеные Хутора, Терешковой, 2а	f	small
111295	53746	695	Липецкая область, Липецкий район, поселок Студеные Выселки, Комсомольская, 20	f	medium
111299	53729	710	Липецкая область, Липецкий район, поселок Стебаево, Шумная, 8	f	medium
49351	53759	709	Липецкая область, Липецкий район, поселок Стебаево, Садовая, 1	f	medium
49327	53736	685	Липецкая область, Липецкий район, село Ситовка, Парковая, 15	f	large
49350	53758	708	Липецкая область, Липецкий район, поселок Сенцово, 8 Марта, 157	f	large
49349	53757	707	Липецкая область, Липецкий район, поселок Пружинки, 50 лет октября , 201А 	f	medium
49347	53747	705	Липецкая область, Липецкий район, село Пады, Юбилейная, 41	f	small
49346	53755	704	Липецкая область, Липецкий район, поселок Новодмитриевка, Кирова, 14	f	large
49344	53753	702	Липецкая область, Липецкий район, поселок Новая Деревня, Советская, 2в	f	large
49336	53745	694	Липецкая область, Липецкий район, поселок Кузьминские Отвержки, Молодежная, 1	f	large
49333	53742	691	Липецкая область, Липецкий район, поселок Крутые Хутора, Школьная, 1	f	medium
49348	53756	706	Липецкая область, Липецкий район, поселок Крутогорье, Свободы, 11	f	small
49331	53740	689	Липецкая область, Липецкий район, село Косырёвка, Советская, 73а	f	large
49335	53744	693	Липецкая область, Липецкий район, поселок Копцевы Хутора, Котовского, 6а	f	large
49325	53734	683	Липецкая область, Липецкий район, поселок Ильино, Административная, 3	f	large
49330	53739	688	Липецкая область, Липецкий район, поселок Ивово, Советская, 48б	f	small
49329	53738	687	Липецкая область, Липецкий район, поселок Грязное, Ленинская, 15	f	medium
49345	53754	703	Липецкая область, Липецкий район, поселок Вешаловка, 8 Марта, 72	f	medium
49328	53737	686	Липецкая область, Липецкий район, поселок Вербилово, Ленина, 2	t	medium
49324	53733	682	Липецкая область, Липецкий район, поселок Васильевка, Центральная, 51	f	medium
49332	53741	690	Липецкая область, Липецкий район, поселок Бруслановка, Ленина, 5	f	small
49321	53730	679	Липецкая область, Липецкий район, поселок Боринское, Советская, 9	f	large
49320	53728	678	Липецкая область, Липецкий район, поселок Боринское, Салтыкова-Щедрина, 31а	f	large
49322	53731	680	Липецкая область, Липецкий район, поселок Боринское, Дзержинского, 2	f	large
49323	53732	681	Липецкая область, Липецкий район, поселок Большая Кузьминка, Московская, 1	f	medium
49314	53722	672	Липецкая область, Лев-Толстовский район, совхоз имени Льва Толстого, Центрльная, 19	f	medium
49318	53726	676	Липецкая область, Лев-Толстовский район, поселок Троицкое, Новая, 4	f	small
49306	53714	664	Липецкая область, Лев-Толстовский район, поселок Топки, Советская, 6	f	small
49300	53708	658	Липецкая область, Лев-Толстовский район, поселок Свищевка, Новая, 1	f	small
49316	53724	674	Липецкая область, Лев-Толстовский район, поселок Первомайское, Центральная, 22	f	small
49303	53711	661	Липецкая область, Лев-Толстовский район, поселок Острый Камень, Графская, 17	f	small
49298	53706	656	Липецкая область, Лев-Толстовский район, поселок Орловка, Центральная, 10А	f	small
49312	53720	670	Липецкая область, Лев-Толстовский район, поселок Новочемоданово, Механизаторов, 9	f	small
49313	53721	671	Липецкая область, Лев-Толстовский район, поселок Митягино, Горбатовка, 4	f	small
49295	53703	653	Липецкая область, Лев-Толстовский район, поселок Лев Толстой, переулок Советский, 1	f	large
49293	53701	651	Липецкая область, Лев-Толстовский район, поселок Лев Толстой, Слонского, 1	f	large
49294	53702	652	Липецкая область, Лев-Толстовский район, поселок Лев Толстой, Коммунистическая, 16	f	large
49163	53563	523	Липецкая область, Задонский район, поселок Донское, Мира, 19	f	large
49292	53700	650	Липецкая область, Лев-Толстовский район, поселок Лев Толстой, Володарского, 24	f	large
49296	53704	654	Липецкая область, Лев-Толстовский район, поселок Лев Толстой, 1-ая Садовая, 1А	f	large
49317	53725	675	Липецкая область, Лев-Толстовский район, поселок Кузовлево, Школьная, 7	f	small
49305	53713	663	Липецкая область, Лев-Толстовский район, поселок Круглое, Поповка, 5	f	small
49301	53709	659	Липецкая область, Лев-Толстовский район, поселок Красный, Центральная, 2	f	small
49302	53710	660	Липецкая область, Лев-Толстовский район, поселок Котовка, Центральная, 7	f	small
49311	53719	669	Липецкая область, Лев-Толстовский район, поселок Ильинка, Школьная, 2	f	small
49304	53712	662	Липецкая область, Лев-Толстовский район, поселок Золотуха, Школьная, 8	f	medium
49299	53707	657	Липецкая область, Лев-Толстовский район, поселок Знаменское, Промстроевская, 5	f	small
49308	53716	666	Липецкая область, Лев-Толстовский район, поселок Загрядчино, Молодёжная, 15	f	small
49297	53705	655	Липецкая область, Лев-Толстовский район, поселок Домачи, Молодёжная, 37	f	small
49319	53727	677	Липецкая область, Лев-Толстовский район, поселок Головинщино, Вязинская, 10	f	small
49307	53715	665	Липецкая область, Лев-Толстовский район, поселок Гагино, Центральная, 36	f	small
49309	53717	667	Липецкая область, Лев-Толстовский район, поселок Гагарино, Новая, 20	f	small
49310	53718	668	Липецкая область, Лев-Толстовский район, поселок Бычки, Полевая, 16А	f	small
49315	53723	673	Липецкая область, Лев-Толстовский район, поселок Астапово, Центральная, 12	f	small
49290	53698	648	Липецкая область, Лебедянский район, поселок Яблонево, Школьная, 6	f	small
49287	53695	645	Липецкая область, Лебедянский район, поселок Шовское, Бутырки, 2	f	small
49266	53673	624	Липецкая область, Лебедянский район, поселок Черепянь, Школьная, 17	f	small
49271	53678	629	Липецкая область, Лебедянский район, поселок Хорошовка, Большой Порядок, 91	f	small
49285	53693	643	Липецкая область, Лебедянский район, поселок Троекурово, Ленина, 12	f	large
49264	53671	622	Липецкая область, Лебедянский район, поселок Теплое, Кривка, 37	f	small
49268	53675	626	Липецкая область, Лебедянский район, поселок Сурки, Новая, 44	f	small
49284	53692	642	Липецкая область, Лебедянский район, поселок Старо Копыл, Садовая, 84	f	small
49283	53691	641	Липецкая область, Лебедянский район, поселок Слободка, Школьная, 98	f	small
49263	53670	621	Липецкая область, Лебедянский район, поселок Сахарного Завода, Октябрьская, 56	f	medium
49277	53684	635	Липецкая область, Лебедянский район, поселок Романово, Ермаковка, 164б	f	small
49282	53690	640	Липецкая область, Лебедянский район, поселок Покрово-Казацкая, Серединка, 59 а	f	large
49281	53689	639	Липецкая область, Лебедянский район, поселок Покрово-Казацкая, Воронежская, 35	f	large
49279	53687	637	Липецкая область, Лебедянский район, поселок Павловское, Почтовая, 75	f	small
49273	53680	631	Липецкая область, Лебедянский район, поселок Павелка	f	small
49276	53683	634	Липецкая область, Лебедянский район, поселок Ольховец, Школьная, 108а	f	medium
49278	53685	636	Липецкая область, Лебедянский район, поселок Новое Ракитино, Школьная, 220 а	f	small
49261	53668	619	Липецкая область, Лебедянский район, поселок Мокрое	f	medium
49260	53667	618	Липецкая область, Лебедянский район, поселок Михайловка, Центральная, 21	f	small
49255	53662	613	Липецкая область, Лебедянский район, Лебедянь, Школьная, 10	f	large
68178	53651	603	Липецкая область, Лебедянский район, Лебедянь, Мира, 1	f	large
49249	53655	607	Липецкая область, Лебедянский район, Лебедянь, Ленина, 44	f	large
49250	53656	608	Липецкая область, Лебедянский район, Лебедянь, Карла Маркса, 57	f	large
49286	53694	644	Липецкая область, Лебедянский район, поселок Курапово	f	small
49288	53696	646	Липецкая область, Лебедянский район, поселок Культура, Садовая, 1	f	small
49274	53681	632	Липецкая область, Лебедянский район, поселок Куликовка 2-я, Центральная, 10А	f	small
49272	53679	630	Липецкая область, Лебедянский район, поселок Куймань, Центральная, 22 б	f	medium
49270	53677	628	Липецкая область, Лебедянский район, поселок Каменная Лубна, Школьная, 13	f	small
49289	53697	647	Липецкая область, Лебедянский район, поселок Инициатор, Трудовая, 22	f	small
49275	53682	633	Липецкая область, Лебедянский район, поселок Донские Избищи, Центральная, 2а	f	small
49269	53676	627	Липецкая область, Лебедянский район, поселок Докторово, Ленина, 2 а	f	small
49280	53688	638	Липецкая область, Лебедянский район, поселок Грязновка, Центральная, 153	f	small
49267	53674	625	Липецкая область, Лебедянский район, поселок Вязово, Центральная, 86	f	small
49265	53672	623	Липецкая область, Лебедянский район, поселок Волотово, Центральная, 19	f	medium
49291	53699	649	Липецкая область, Лебедянский район, поселок Большой Верх, Центральная, 16	f	small
49262	53669	620	Липецкая область, Лебедянский район, поселок Большое Попово, Центральная, 25	f	medium
49259	53666	617	Липецкая область, Лебедянский район, поселок Большие Избищи, Большак, 220	f	small
49258	53665	616	Липецкая область, Лебедянский район, колхоз Агроном, Октябрьская, 14	f	medium
49257	53664	615	Липецкая область, Лебедянский район, поселок Агроном, Советская, 22	f	large
49243	53648	601	Липецкая область, Краснинский район, поселок Яблоново, Советская, 23	f	small
49240	53644	598	Липецкая область, Краснинский район, поселок Щербаково, Центральная, 14	f	small
49242	53647	600	Липецкая область, Краснинский район, поселок Суходол, Торговая, 9	f	small
49238	53642	596	Липецкая область, Краснинский район, поселок Сотниково, Парковая, 1	f	small
49232	53636	590	Липецкая область, Краснинский район, поселок Сергиевское, Новая, 14	f	small
86545	53646	599	Липецкая область, Краснинский район, поселок Решетово-Дуброво, Центральная, 11	f	small
111291	53621	575	Липецкая область, Краснинский район, поселок Пятницкое, Клубная, 2	f	medium
49239	53643	597	Липецкая область, Краснинский район, поселок Половнево, Центральная, 2	f	small
49226	53631	585	Липецкая область, Краснинский район, поселок Морево, Клубная, 36	f	small
49244	53649	602	Липецкая область, Краснинский район, поселок Лески, Мира, 4	f	medium
49225	53630	584	Липецкая область, Краснинский район, поселок Лаухино, Цветочная, 3а	f	small
49233	53637	591	Липецкая область, Краснинский район, поселок Красное, Первомайская, 20	f	large
49235	53639	593	Липецкая область, Краснинский район, поселок Красное, Октябрьская, 73	f	medium
49234	53638	592	Липецкая область, Краснинский район, поселок Красное, Красноармейская, 6	f	large
49222	53627	581	Липецкая область, Краснинский район, Краснинский, Парковая, 15А	f	large
49228	53633	587	Липецкая область, Краснинский район, поселок Корытное, Клубная, 51	f	small
49230	53634	588	Липецкая область, Краснинский район, поселок Ищеино, Школьная, 22	f	small
49223	53628	582	Липецкая область, Краснинский район, поселок Знаменка, 63	f	small
49237	53641	595	Липецкая область, Краснинский район, поселок Епанчино, 45	f	small
49236	53640	594	Липецкая область, Краснинский район, поселок Дегтевая, Центральная, 24	f	medium
49231	53635	589	Липецкая область, Краснинский район, поселок Верхнее Брусланово, Школьная, 24	f	small
49227	53632	586	Липецкая область, Краснинский район, поселок Верхнедрезгалово, Парковая, 26	f	medium
49224	53629	583	Липецкая область, Краснинский район, поселок Бредихино, 19	f	small
49213	53611	568	Липецкая область, Измалковский район, поселок Ясенок, Советская, 6	f	small
49216	53614	571	Липецкая область, Измалковский район, поселок Черник, Центральная, 4	f	small
49202	53626	580	Липецкая область, Измалковский район, поселок Чернава, Первомайская, 260	f	large
49201	53625	579	Липецкая область, Измалковский район, поселок Чернава, Первомайская, 124	f	large
49221	53624	578	Липецкая область, Измалковский район, поселок Чермошное, 39	f	small
49204	53602	560	Липецкая область, Измалковский район, поселок Сухой Семенек, Школьная, 69	f	small
49220	53623	577	Липецкая область, Измалковский район, поселок Слобода, Маяковского, 24	f	small
49200	53622	576	Липецкая область, Измалковский район, поселок Ровенка, Московская, 21	f	small
111290	53617	572	Липецкая область, Измалковский район, поселок Преображение, Ленина, 8	f	medium
49210	53608	565	Липецкая область, Измалковский район, поселок Предтечево, имени Белякова, 16	f	small
49212	53610	567	Липецкая область, Измалковский район, поселок Полевые Локотцы, 13	f	small
49214	53612	569	Липецкая область, Измалковский район, поселок Панкратовка, Школьная, 18	f	medium
49215	53613	570	Липецкая область, Измалковский район, поселок Недоходовка, Центральная, 54	f	small
49205	53603	561	Липецкая область, Измалковский район, поселок Мягкое, Молодежная, 16	f	small
49209	53607	564	Липецкая область, Измалковский район, поселок Мульгино, Центральная, 13	f	small
49211	53609	566	Липецкая область, Измалковский район, поселок Лебяжье, Луговая, 16	f	small
68177	53605	563	Липецкая область, Измалковский район, поселок Измалково, Советская, 53А	f	large
49207	53604	562	Липецкая область, Измалковский район, поселок Измалково, Ленина, 38	f	large
49198	53600	558	Липецкая область, Измалковский район, поселок Иваницкое-Троицкое, Центральная, 4	f	small
49197	53599	557	Липецкая область, Измалковский район, поселок Денисово, Поселковая, 1	f	small
49219	53619	574	Липецкая область, Измалковский район, поселок Гниловоды, 22	f	small
49196	53598	556	Липецкая область, Измалковский район, поселок Власово, Центральная, 20	f	small
49203	53601	559	Липецкая область, Измалковский район, поселок Васильевка, Центральная, 88	f	small
49218	53618	573	Липецкая область, Измалковский район, поселок Быково, Центральная, 53	f	small
49194	53596	554	Липецкая область, Измалковский район, поселок Афанасьево, переулок Школьный, 1	f	small
49195	53597	555	Липецкая область, Измалковский район, поселок Афанасьево, Елецкая, 145	f	medium
49192	53594	552	Липецкая область, Задонский район, поселок Яблоново, Центральная, 4	f	small
49193	53595	553	Липецкая область, Задонский район, поселок Юрьево, Советская, 25	f	small
49182	53582	542	Липецкая область, Задонский район, поселок Черниговка, Молодежная, 49	t	small
49190	53591	550	Липецкая область, Задонский район, поселок Хмелинец, Степанищева, 68	f	small
49189	53590	549	Липецкая область, Задонский район, поселок Хмелинец, Степанищева, 79	f	medium
49153	53552	513	Липецкая область, Задонский район, поселок Уткино, Центральная, 107а	f	medium
49168	53568	528	Липецкая область, Задонский район, поселок Успеновка, 3, кв.3	f	small
49155	53554	515	Липецкая область, Задонский район, поселок Тюнино, Карла-Маркса, 2ж	f	small
49185	53585	545	Липецкая область, Задонский район, поселок Тростяное, Школьная, 5	f	small
49186	53586	546	Липецкая область, Задонский район, поселок Тимирязев, Дорожная, 1	f	small
49154	53553	514	Липецкая область, Задонский район, поселок Тешевка, Задонская, 120	f	small
49179	53579	539	Липецкая область, Задонский район, поселок Сцепное, Клубная, 1	f	small
49159	53559	519	Липецкая область, Задонский район, поселок Старо Воскресеновка, Сосновая, 94	f	small
49183	53583	543	Липецкая область, Задонский район, поселок Скорняково, Советская, 16	f	small
49181	53581	541	Липецкая область, Задонский район, поселок Рогожино, Школьная, 23	f	small
49172	53572	532	Липецкая область, Задонский район, поселок Репец, Покровская, 2	f	small
49169	53569	529	Липецкая область, Задонский район, поселок Паниковец, Запрудная, 2	f	medium
49177	53577	537	Липецкая область, Задонский район, поселок Освобождение, Заводская, 18	f	medium
49152	53551	512	Липецкая область, Задонский район, поселок Нижняя Казачье, Центральная, 52	f	small
49174	53574	534	Липецкая область, Задонский район, село Мирное, Кленовая, 3	f	small
49149	53548	509	Липецкая область, Задонский район, поселок Ливенская, Молодежная, 14	f	small
49175	53575	535	Липецкая область, Задонский район, поселок Ксизово, Центральная, 71	f	medium
49188	53588	548	Липецкая область, Задонский район, поселок Колодезная, Солнечная, 4а	t	small
49148	53547	508	Липецкая область, Задонский район, поселок Колодезная, Мира, 19	f	small
49191	53593	551	Липецкая область, Задонский район, поселок Колесово 1-е, Молодежная, 1	f	small
49173	53573	533	Липецкая область, Задонский район, поселок Кашары, Донская, 24	f	small
49171	53571	531	Липецкая область, Задонский район, поселок Камышевка, Центральная, 83	f	small
49167	53567	527	Липецкая область, Задонский район, поселок Каменка, Центральная, 1	f	small
49166	53566	526	Липецкая область, Задонский район, поселок Калабино, Весенняя, 21	f	medium
49157	53557	517	Липецкая область, Задонский район, поселок Казино, Центральная, 75	f	small
49145	53544	505	Липецкая область, Задонский район, Задонск, Советская, 109А	f	large
49142	53541	502	Липецкая область, Задонский район, Задонск, Свободы, 57а	f	large
49165	53565	525	Липецкая область, Задонский район, поселок Донской Рудник, Первомайская, 16	f	small
49164	53564	524	Липецкая область, Задонский район, поселок Донское, Свердлова, 201а	f	small
49162	53562	522	Липецкая область, Задонский район, поселок Донское, Октябрьская, 38	f	medium
49161	53561	521	Липецкая область, Задонский район, поселок Донское, Новая, 1	f	small
49178	53578	538	Липецкая область, Задонский район, поселок Дегтевое, Ерисова, 27	f	small
49158	53558	518	Липецкая область, Задонский район, поселок Гнилуша, Ленина, 69	f	large
49160	53560	520	Липецкая область, Задонский район, поселок Галичья Гора, Рабочая, 74	f	small
49184	53584	544	Липецкая область, Задонский район, поселок Гагарино, Молодежная, 1	f	small
49156	53555	516	Липецкая область, Задонский район, поселок Верхний Студенец, Центральная, 90	f	medium
49151	53550	511	Липецкая область, Задонский район, поселок Верхние Казачье, Молодежная, 31а	f	small
49150	53549	510	Липецкая область, Задонский район, поселок Бутырки, Центральная, 2	f	small
49147	53546	507	Липецкая область, Задонский район, поселок Болховское, Центральная, 3	f	medium
49170	53570	530	Липецкая область, Задонский район, поселок Болальшое Панарино, 83, кв 2 	f	small
49176	53576	536	Липецкая область, Задонский район, поселок Балахна, Центральная, 47	f	small
49180	53580	540	Липецкая область, Задонский район, поселок Алексеевка, 1	t	small
49119	53518	479	Липецкая область, Елецкий район, поселок Чернышевка, Клубная, 31	f	small
49140	53539	500	Липецкая область, Елецкий район, поселок Черкассы, Советская, 6	f	medium
49135	53534	495	Липецкая область, Елецкий район, поселок Хмелинец, Совхозная	f	large
49187	53587	547	Липецкая область, Елецкий район, поселок Улусарка, Садовая, 13 а	f	small
49123	53522	483	Липецкая область, Елецкий район, поселок Трубицино, Центральная, 77	f	small
49127	53526	487	Липецкая область, Елецкий район, поселок Талица, Советская, 26	f	large
49111	53509	471	Липецкая область, Елецкий район, поселок Солидарность, Первомайская, 2	f	large
49137	53536	497	Липецкая область, Елецкий район, поселок Соколье, Лорха, 12	f	large
49120	53519	480	Липецкая область, Елецкий район, поселок Паниковец, Клубная, 31	f	small
49133	53532	493	Липецкая область, Елецкий район, поселок Ольховец, Школьная	f	medium
49134	53533	494	Липецкая область, Елецкий район, поселок Нижний Воргол, Клубная	f	medium
111288	53513	475	Липецкая область, Елецкий район, поселок Маяк, Школьная, 8	f	medium
49131	53530	491	Липецкая область, Елецкий район, поселок Малая Боевка, Мира, 35	f	medium
49130	53529	490	Липецкая область, Елецкий район, поселок Лавы, Северная, 3а	f	large
49117	53516	477	Липецкая область, Елецкий район, поселок Крутое, Транспортная, 10	t	small
49136	53535	496	Липецкая область, Елецкий район, поселок Капани, жд ст.Телегино	f	small
49138	53537	498	Липецкая область, Елецкий район, поселок Каменское, Октябрьская, 4	f	large
49129	53528	489	Липецкая область, Елецкий район, поселок Казинка, Клубная, 2	f	large
49125	53524	485	Липецкая область, Елецкий район, поселок Казаки, Мира, 55	f	large
49126	53525	486	Липецкая область, Елецкий район, поселок Казаки, Заводская, 96	f	large
49128	53527	488	Липецкая область, Елецкий район, поселок Ивановка, Центральная, 4	f	small
49139	53538	499	Липецкая область, Елецкий район, поселок Ивановка, Рабочая, 45	f	small
49141	53540	501	Липецкая область, Елецкий район, поселок Ериловка, 40 лет Победы	f	small
49122	53521	482	Липецкая область, Елецкий район, поселок Елецкий, 50 лет Октября, 2	f	medium
49114	53512	474	Липецкая область, Елецкий район, поселок Екатериновка, Клубная, 30	f	small
49121	53520	481	Липецкая область, Елецкий район, поселок Голиково, Центральная, 23	f	small
49132	53531	492	Липецкая область, Елецкий район, поселок Газопровод, Советская	f	large
49118	53517	478	Липецкая область, Елецкий район, поселок Воронец, Клубная, 17	f	large
49116	53515	476	Липецкая область, Елецкий район, поселок Волчье, Придорожная, 14	f	small
49113	53511	473	Липецкая область, Елецкий район, поселок Большие Извалы, Советская, 5	f	small
49112	53510	472	Липецкая область, Елецкий район, поселок Архангельское, Клубная, 16	f	small
49124	53523	484	Липецкая область, Елецкий район, поселок Аргамач-Пальна, Библиотечная, 11	f	small
49026	53432	392	Липецкая область, Долгоруковский район, поселок Тимирязевский, Фруктовая	f	small
49054	53442	401	Липецкая область, Долгоруковский район, поселок Тепленькая 1-я, Тепленькая, 41	f	small
49043	53454	412	Липецкая область, Долгоруковский район, поселок Стрелец, Архангельская, 20	f	small
49050	53457	415	Липецкая область, Долгоруковский район, поселок Стегаловка, Центральная, 24	f	large
49044	53438	397	Липецкая область, Долгоруковский район, поселок Слепуха, Центральная, 15	f	small
49039	53456	414	Липецкая область, Долгоруковский район, поселок Свишни, Соборная, 6	f	small
49027	53436	395	Липецкая область, Долгоруковский район, поселок Пашинино	f	small
49036	53444	403	Липецкая область, Долгоруковский район, поселок Нижний Ломовец, Речная, 60	f	small
49037	53445	404	Липецкая область, Долгоруковский район, поселок Меньшой Колодезь, Дорожная, 21	f	small
49048	53449	407	Липецкая область, Долгоруковский район, поселок Красотыновка, Школьная, 22	f	small
49030	53435	394	Липецкая область, Долгоруковский район, поселок Красное	f	small
49046	53440	399	Липецкая область, Долгоруковский район, поселок Карташевка, Нижняя, 13	f	small
86562	53452	410	Липецкая область, Долгоруковский район, поселок Казинка Войсковая, Центральная, 11	f	small
49053	53441	400	Липецкая область, Долгоруковский район, поселок Жерновое, Центральная, 30	f	medium
49031	53434	393	Липецкая область, Долгоруковский район, поселок Екатериновка, Школьная	f	medium
49047	53448	406	Липецкая область, Долгоруковский район, поселок Дубовец, Центральная, 3	f	medium
49045	53439	398	Липецкая область, Долгоруковский район, поселок Долгуша, Центральная, 1	f	small
49034	53427	387	Липецкая область, Долгоруковский район, поселок Долгоруково, Тимирязева, 3	f	large
49033	53429	389	Липецкая область, Долгоруковский район, поселок Долгоруково, Терешковой, 19	f	medium
49029	53428	388	Липецкая область, Долгоруковский район, поселок Долгоруково, Советская, 32	f	large
49032	53430	390	Липецкая область, Долгоруковский район, поселок Долгоруково, Мира	f	medium
49041	53453	411	Липецкая область, Долгоруковский район, поселок Грызлово, Рягузова, 1	f	small
49051	53451	409	Липецкая область, Долгоруковский район, поселок Вязовое, Молодежная, 17	f	small
49040	53450	408	Липецкая область, Долгоруковский район, поселок Веселая, Молодежная, 22	f	medium
49035	53443	402	Липецкая область, Долгоруковский район, поселок Верхний Ломовец, Центральная, 99	f	medium
49028	53431	391	Липецкая область, Долгоруковский район, поселок Братовщина, Власова	f	medium
49038	53446	405	Липецкая область, Долгоруковский район, поселок Большой Колодезь, Центральная, 7	f	small
49052	53437	396	Липецкая область, Долгоруковский район, поселок Большая Боевка, Школьная, 12	f	medium
49042	53455	413	Липецкая область, Долгоруковский район, поселок 2-я Набережная	f	small
49000	53400	361	Липецкая область, Добровский район, поселок Чечеры, Романовская, 1	t	small
49009	53410	370	Липецкая область, Добровский район, поселок Трубетчино, Почтовая, 23	f	large
49018	53419	379	Липецкая область, Добровский район, поселок Ратчино, Ленина, 2	f	medium
49019	53420	380	Липецкая область, Добровский район, поселок Путятино, Костикова, 20	f	medium
48997	53397	358	Липецкая область, Добровский район, поселок Преображеновка, Центральная, 6	f	small
49010	53411	371	Липецкая область, Добровский район, поселок Порой, Сельская, 31	f	medium
49006	53407	367	Липецкая область, Добровский район, поселок Панино, Ленина, 36	f	medium
49005	53406	366	Липецкая область, Добровский район, поселок Панино, Ленина, 56	f	medium
49007	53408	368	Липецкая область, Добровский район, поселок Махоново	f	medium
49001	53401	362	Липецкая область, Добровский район, поселок Лебяжье, Центральная, 86	f	small
49017	53417	378	Липецкая область, Добровский район, поселок Крутое, Комсомольская, 19	f	medium
48998	53398	359	Липецкая область, Добровский район, поселок Кривец, Новая, 2	f	medium
49003	53403	364	Липецкая область, Добровский район, поселок Кореневщина	f	medium
49016	53414	377	Липецкая область, Добровский район, поселок Каликино, пл.Ленина, 14	f	large
49013	53414	374	Липецкая область, Добровский район, поселок Каликино, пл.Ленина, 14	f	medium
49015	53416	376	Липецкая область, Добровский район, поселок Каликино, Советская, 100	f	medium
49020	53421	381	Липецкая область, Добровский район, поселок Зарницы, Здание клуба	f	small
49008	53409	369	Липецкая область, Добровский район, поселок Замартынье, Центральная, 86	f	medium
49011	53412	372	Липецкая область, Добровский район, поселок Екатериновка, Черемушки, 1	f	small
49021	53422	382	Липецкая область, Добровский район, поселок Доброе, площадь Октябрьская, 10	f	medium
81800	56022	963	Москва, Хабаровская, 18к2	f	large
49023	53424	384	Липецкая область, Добровский район, поселок Доброе, переулок Ленина, 5	f	medium
49025	53426	386	Липецкая область, Добровский район, поселок Доброе, Школьная, 57	f	large
49024	53425	385	Липецкая область, Добровский район, поселок Доброе, Победы, 13	f	medium
49022	53423	383	Липецкая область, Добровский район, поселок Доброе, Ленина, 39	f	medium
49014	53415	375	Липецкая область, Добровский район, поселок Гудово, Чкалова, 54	f	small
49004	53404	365	Липецкая область, Добровский район, поселок Горицы, Центральная, 93	t	small
49012	53413	373	Липецкая область, Добровский район, поселок Волчье, Центральная, 37	f	medium
48999	53399	360	Липецкая область, Добровский район, поселок Борисовка, Новая, 1/2	f	large
49002	53402	363	Липецкая область, Добровский район, поселок Большой Хомутец, Советская, 41	f	medium
48979	53380	340	Липецкая область, Добринский район, поселок имени Ильича, Центральная, 46	f	small
48909	53312	283	Липецкая область, Добринский район, поселок Ярлуково, Молодежная, 4б	f	large
48972	53373	333	Липецкая область, Добринский район, поселок Чалмык-Никольское, Школьная, 12	f	medium
48996	53396	357	Липецкая область, Добринский район, поселок Хворостянка, Школьная, 17	f	medium
48985	53386	346	Липецкая область, Добринский район, поселок Хворостянка, Первомайская, 1	f	medium
48982	53383	343	Липецкая область, Добринский район, поселок Тихвинка, Садовая, 63	f	small
48971	53372	332	Липецкая область, Добринский район, поселок Талицкий Чамлык, Советская, 1	f	large
48984	53385	345	Липецкая область, Добринский район, поселок Средняя Матренка, Центральная, 14	f	medium
48986	53387	347	Липецкая область, Добринский район, поселок Салтычки, Молодежная, 108	f	small
48970	53371	331	Липецкая область, Добринский район, поселок Ровенка, Чиркова, 11б	f	small
48987	53388	348	Липецкая область, Добринский район, поселок Пушкино, Мира, 33а	f	large
48990	53390	351	Липецкая область, Добринский район, Плавица, Школьная, 1	f	large
48989	53390	350	Липецкая область, Добринский район, Плавица, Школьная, 1	f	medium
48975	53376	336	Липецкая область, Добринский район, колхоз Петровский, Победы, 3	f	large
48969	53370	330	Липецкая область, Добринский район, поселок Паршиновка, Победы, 1	f	medium
48978	53379	339	Липецкая область, Добринский район, поселок Павловка, Центральная, 64	f	medium
48992	53392	353	Липецкая область, Добринский район, поселок Отскочное, Васильевская, 26	f	small
48994	53394	355	Липецкая область, Добринский район, поселок Ольховка, Дружбы, 24	f	small
48980	53381	341	Липецкая область, Добринский район, поселок Новочеркутино, Школьная, 6	f	small
48977	53378	338	Липецкая область, Добринский район, поселок Новопетровка, Школьная, 4	f	small
48976	53377	337	Липецкая область, Добринский район, поселок Николаевка, Молодёжная, 4	f	small
48993	53393	354	Липецкая область, Добринский район, поселок Нижняя Матренка, Центральная, 8	f	medium
48968	53369	329	Липецкая область, Добринский район, поселок Матвеевка, Центральная, 1	f	small
48973	53374	334	Липецкая область, Добринский район, поселок Мазейка, Центральная, 14	f	small
48967	53368	328	Липецкая область, Добринский район, поселок Лебедянка, Школьная, 49	f	small
48963	53364	324	Липецкая область, Добринский район, поселок Кооператор, 60 лет Победы, 7	f	medium
48974	53375	335	Липецкая область, Добринский район, поселок Заря, Заречная, 18	f	small
48991	53391	352	Липецкая область, Добринский район, поселок Дурово, Центральная, 9	f	small
48995	53395	356	Липецкая область, Добринский район, поселок Дубовое, Лермонтова, 2а	f	large
48962	53363	323	Липецкая область, Добринский район, поселок Добринка, Терпигорева, 1	f	small
48959	53360	320	Липецкая область, Добринский район, поселок Добринка, Октябрьская, 79	f	large
48961	53362	322	Липецкая область, Добринский район, поселок Добринка, Народная, 21	f	medium
48958	53359	319	Липецкая область, Добринский район, поселок Добринка, Ленинская, 4	f	large
48960	53361	321	Липецкая область, Добринский район, поселок Добринка, Кирова, 4	f	large
48964	53365	325	Липецкая область, Добринский район, поселок Демшинка, Центральная, 62	f	medium
49326	53735	684	Липецкая область, Добринский район, поселок Воскресеновка, Звонная, 9	f	medium
48965	53366	326	Липецкая область, Добринский район, поселок Верхняя Матренка, Центральная, 32	f	large
81916	56101	1080	Москва, Фрязевская улица, 5	f	large
48983	53384	344	Липецкая область, Добринский район, поселок Большая Плавица, Центральная, 220	f	small
48988	53389	349	Липецкая область, Добринский район, поселок Богородицкое, Богородицкая, 51	f	small
48966	53367	327	Липецкая область, Добринский район, поселок Березнеговатка, Центральная, 37	f	medium
48981	53382	342	Липецкая область, Добринский район, поселок Александровка, Интернациональная, 22	f	small
48947	53347	308	Липецкая область, Данковский район, поселок Ярославы, Центральная, 19	f	small
48957	53358	318	Липецкая область, Данковский район, поселок Ягодное, Советская, 3	f	medium
48956	53357	317	Липецкая область, Данковский район, поселок Хрущево-Подлесное, Деминская, 5	f	small
48955	53356	316	Липецкая область, Данковский район, поселок Требунки, Центральная, 163	f	small
48954	53355	315	Липецкая область, Данковский район, поселок Теплое, Советская, 3	f	medium
48953	53354	314	Липецкая область, Данковский район, поселок Телепнево, Советская, 1	f	small
48952	53353	313	Липецкая область, Данковский район, поселок Спешнево-Ивановское, Центральная, 22	f	medium
48945	53345	306	Липецкая область, Данковский район, поселок Политово, Спортивная, 1а	f	medium
48951	53352	312	Липецкая область, Данковский район, поселок Полибино, Школьная, 1	f	small
48950	53351	311	Липецкая область, Данковский район, поселок Плахово, Центральная, 10	f	small
48949	53350	310	Липецкая область, Данковский район, поселок Перехваль, Школьная, 1	f	small
48946	53346	307	Липецкая область, Данковский район, поселок Новоникольское, Центральная, 8	f	medium
48944	53344	305	Липецкая область, Данковский район, поселок Кудрявщино, Зеленая, 21	f	medium
49407	53822	766	Липецкая область, Данковский район, поселок Красный Луч, 42	f	medium
48943	53343	304	Липецкая область, Данковский район, поселок Ивановка, Фролова, 4	f	small
48942	53342	303	Липецкая область, Данковский район, поселок Долгое, Советская, 68	f	medium
48948	53349	309	Липецкая область, Данковский район, поселок Воскресенское, Мира, 6/1	f	medium
48941	53341	302	Липецкая область, Данковский район, поселок Воскресенское, Гагарина, 1	f	medium
48940	53340	301	Липецкая область, Данковский район, поселок Бигильдино, Центральная, 60	f	large
48939	53339	300	Липецкая область, Данковский район, поселок Березовка, Парковая, 1	f	medium
48938	53338	299	Липецкая область, Данковский район, поселок Барятино, Центральная, 107	f	medium
48937	53337	298	Липецкая область, Данковский район, поселок Баловнево, Ново-Советская, 14	f	medium
48936	53336	297	Липецкая область, Данковский район, поселок Авдулово, 63	f	small
48922	53325	281	Липецкая область, Грязинский район, поселок совхоза Красная Дубрава, Лесная, 12	f	small
86555	53306	265	Липецкая область, Грязинский район, поселок Ямань, Казанская, 2	f	small
48908	53311	282	Липецкая область, Грязинский район, поселок Фащевка, Советская, 5	f	large
48920	53323	279	Липецкая область, Грязинский район, поселок Сошки, Мира, 37	f	small
48919	53322	278	Липецкая область, Грязинский район, поселок Сошки, Ленина, 129	f	large
48917	53320	270	Липецкая область, Грязинский район, поселок Синявка, Центральная, 5	f	large
48918	53321	271	Липецкая область, Грязинский район, поселок Светлая Поляна, Авиационная, 2	f	small
48921	53324	280	Липецкая область, Грязинский район, колхоз Прибытковский, 19 съезд ВЛКСМ, 1а	f	medium
48906	53308	276	Липецкая область, Грязинский район, поселок Плеханово, Плеханова, 45в	f	large
48902	53303	272	Липецкая область, Грязинский район, поселок Петровка, Асфальтная, 1	f	medium
48899	53300	261	Липецкая область, Грязинский район, колхоз Песковатский, Школьная, 6а	f	medium
86556	53310	269	Липецкая область, Грязинский район, поселок Падворки, Советская, 14	f	small
48914	53317	267	Липецкая область, Грязинский район, поселок Кубань, Лесная, 17	f	medium
48915	53318	268	Липецкая область, Грязинский район, поселок Коробовка, 26 Партсъезд, 42	f	small
48913	53315	266	Липецкая область, Грязинский район, поселок Княжая Байгора, Советская, 1	f	medium
48911	53314	264	Липецкая область, Грязинский район, поселок Карамышево, Центральная площадь, 3	f	medium
48901	53302	263	Липецкая область, Грязинский район, Казинка, Гагарина	f	large
111285	53309	277	Липецкая область, Грязинский район, поселок Гудаловка, ОКУ ЛОПНБ, клуб	f	medium
48892	53292	253	Липецкая область, Грязинский район, Грязи, Чернышевского, 7	f	large
48900	53301	262	Липецкая область, Грязинский район, Грязи, Тимирязева	f	large
48881	53279	242	Липецкая область, Грязинский район, Грязи, Песковатская, 17	f	large
48879	53277	240	Липецкая область, Грязинский район, Грязи, Партизанская, 2	f	large
48882	53280	243	Липецкая область, Грязинский район, Грязи, Лихачева, 11	f	large
48893	53294	254	Липецкая область, Грязинский район, Грязи, Авиационная, 39	f	large
48877	53275	238	Липецкая область, Грязинский район, Грязи, 2-я Чапаева, 56	f	medium
86554	53307	275	Липецкая область, Грязинский район, поселок Головщино, Школьная, 41	f	small
134453	94353	260	Липецкая область, Грязинский район, поселок Верхний Телелюй, Некрасова, 55	f	medium
48898	53299	259	Липецкая область, Грязинский район, поселок Бутырки, Ленинская, 5	f	medium
48897	53298	258	Липецкая область, Грязинский район, поселок Большой Самовец, Советская, 135а	f	large
48904	53316	274	Липецкая область, Грязинский район, поселок Аннино, Социалистическая, контора ЗАО СХП Липецкрыбхоз	f	medium
48903	53304	273	Липецкая область, Грязинский район, поселок Аннино, Набережная, дом Культуры	f	medium
48873	53271	234	Липецкая область, Воловский район, поселок Юрское, Центральная, 25	f	small
48862	53260	223	Липецкая область, Воловский район, поселок Пикалово, Луговая, 2	t	small
48867	53265	228	Липецкая область, Воловский район, поселок Новопавловка, Центральная, 4	f	medium
48855	53252	216	Липецкая область, Воловский район, поселок Нижнее Большое, Молодёжная, 1	f	medium
48869	53267	230	Липецкая область, Воловский район, поселок Набережное, Совхозная, 1	f	medium
48868	53266	229	Липецкая область, Воловский район, поселок Мишино, Центральная, 4	f	small
48870	53268	231	Липецкая область, Воловский район, поселок Княжная, Школьная, 7	f	small
48872	53270	233	Липецкая область, Воловский район, поселок Казаково, Новая, 8	f	medium
48871	53269	232	Липецкая область, Воловский район, поселок Ивановка, Центральная, 32	f	medium
48864	53262	225	Липецкая область, Воловский район, поселок Захаровка, Сельская, 30	f	medium
48863	53261	224	Липецкая область, Воловский район, поселок Замарайка, Центральная, 2	f	small
48861	53259	222	Липецкая область, Воловский район, поселок Гатище, Центральная, 3	f	small
48854	53251	215	Липецкая область, Воловский район, поселок Вышнее Большое, Центральная, 7	f	medium
48860	53258	221	Липецкая область, Воловский район, поселок Воловчик, Центральная, 28	f	small
48859	53257	220	Липецкая область, Воловский район, поселок Волово, Первомайская, 1	f	large
48858	53255	219	Липецкая область, Воловский район, поселок Волово, Ленина, 5	f	large
48857	53254	218	Липецкая область, Воловский район, поселок Верхнее Чесночное, В.Чернова, 24	f	medium
48856	53253	217	Липецкая область, Воловский район, поселок Васильевка, Парковая, 10	f	medium
48853	53250	214	Липецкая область, Воловский район, поселок Большая Ивановка, Школьная, 3	f	small
48865	53263	226	Липецкая область, Воловский район, поселок Алексеевка, Центральная, 10	f	small
48866	53264	227	Липецкая область, Воловский район, поселок Александровка, Родниковая, 30	f	small
47107	50908	583	Курская область, п.Маршала Жукова, средняя общеобразовательная школа	f	large
47145	50946	621	Курская область, поселок Юбилейный, детский сад №8 п.Юбилейный	t	large
47649	51365	1125	Курская область, Щигры, Черняховского, 7	f	large
47652	51453	1128	Курская область, Щигры, Плеханова, 15	f	medium
47647	51183	1123	Курская область, Щигры, Октябрьская, 42	f	large
47650	51451	1126	Курская область, Щигры, Мичурина, 2	f	medium
47651	51452	1127	Курская область, Щигры, Лермонтова, 15	f	large
47643	51449	1119	Курская область, Щигры, Лазарева, 2	f	large
47644	51449	1120	Курская область, Щигры, Лазарева, 2	f	large
47645	51450	1121	Курская область, Щигры, Красная, 52	f	large
47646	51430	1122	Курская область, Щигры, Красная, 44	f	large
47648	51257	1124	Курская область, Щигры, Красная, 29	f	large
47142	50943	618	Курская область, деревня Щетинка	f	medium
47125	50926	601	Курская область, деревня Цветово 1-е, Советская улица, Новопоселеновская средняя школа	f	large
68161	51301	975	Курская область, Суджа, Советская площадь, 18	f	large
47391	51190	867	Курская область, Рыльск, Маяковского, 41, здание МБОУ Рыльская средняя общеобразовательная школа №5	f	large
47385	51184	861	Курская область, Рыльск, Луначарского, 17	f	large
47387	51186	863	Курская область, Рыльск, Ленина, 42	f	large
47392	51191	868	Курская область, Рыльск, Кирова, 102	f	large
47311	51106	787	Курская область, Обоянь, Курская, 95	f	large
47224	50486	700	Курская область, Льгов, Энгельса, 138/82	f	large
47215	51018	691	Курская область, Льгов, Куйбышева, 20	f	large
47222	50982	698	Курская область, Льгов, Красная, 27	f	large
47218	50847	694	Курская область, Льгов, К. Маркса, 49/43	f	large
47216	51019	692	Курская область, Льгов, К. Либкнехта, 4	f	large
47217	50681	693	Курская область, Льгов, К. Либкнехта, 4	f	large
46781	50580	257	Курская область, Курчатов, Энергетиков, 16	f	large
46780	50580	256	Курская область, Курчатов, Энергетиков, 16	f	large
46779	50580	255	Курская область, Курчатов, Энергетиков, 16	f	large
46778	50580	254	Курская область, Курчатов, Энергетиков, 16	f	large
46777	50579	253	Курская область, Курчатов, Строителей, 10	f	large
46776	50579	252	Курская область, Курчатов, Строителей, 10	f	large
46775	50579	251	Курская область, Курчатов, Строителей, 10	f	large
46782	50581	258	Курская область, Курчатов, Садовая , 9а	f	large
46786	50585	262	Курская область, Курчатов, Набережная, 9А	f	large
46788	50582	264	Курская область, Курчатов, Набережная, 9а	f	large
46787	50582	263	Курская область, Курчатов, Набережная, 9а	f	large
46783	50582	259	Курская область, Курчатов, Набережная, 9а	f	large
46773	50577	249	Курская область, Курчатов, Молодежная, 14	f	large
46772	50577	248	Курская область, Курчатов, Молодежная, 14	f	large
46769	50575	245	Курская область, Курчатов, Молодежная, 13	f	large
46770	50576	246	Курская область, Курчатов, Ленинградская, 25	f	large
46771	50576	247	Курская область, Курчатов, Ленинградская, 25	f	large
46774	50578	250	Курская область, Курчатов, Космонавтов, 34	f	large
46785	50584	261	Курская область, Курчатов, Набережная, 4	f	large
46784	50583	260	Курская область, Курчатов, Набережная, 15	f	large
46632	50472	108	Курская область, город Курск, улица Чернышевского, 95	f	large
46631	50472	107	Курская область, город Курск, улица Чернышевского, 95	f	large
46550	50400	26	Курская область, город Курск, улица Полевая, 19а	f	large
46548	50400	24	Курская область, город Курск, улица Полевая, 19а	f	large
46633	50473	109	Курская область, город Курск, улица Пирогова, 3	f	large
46582	50432	58	Курская область, город Курск, улица Парковая, 14Б	f	large
46636	50475	112	Курская область, город Курск, улица Павлуновского, 99	f	large
46635	50475	111	Курская область, город Курск, улица Павлуновского, 99	f	medium
46611	50457	87	Курская область, город Курск, улица Менделеева, 20	f	large
46614	50458	90	Курская область, город Курск, улица Крюкова, 5	f	large
46613	50458	89	Курская область, город Курск, улица Крюкова, 5	f	large
46612	50458	88	Курская область, город Курск, улица Крюкова, 5	f	large
46690	50517	166	Курская область, город Курск, улица Карла Маркса, 70б	f	large
46698	50525	174	Курская область, город Курск, улица Блинова, 3	f	large
46640	50478	116	Курская область, город Курск, улица 50-летия Октября, 94	f	large
68157	50478	115	Курская область, город Курск, улица 50-летия Октября, 94	f	large
46606	50452	82	Курская область, Курск, проспект Ленинского Комсомола, 61, здание общежития Управляющей компании	f	large
46712	50537	188	Курская область, Курск, проспект Вячеслава Клыкова, 1А	f	large
46710	50535	186	Курская область, Курск, проезд Сергеева, 14	f	large
46607	50453	83	Курская область, город Курск, Широкая улица, 2	f	large
46564	50414	40	Курская область, Курск, Тракторная, 8, здание Профессиональное училище № 41	f	large
46569	50420	45	Курская область, Курск, Сумская улица, 8/9	f	large
46540	50394	16	Курская область, Курск, Социалистическая, 10	f	large
46539	50393	15	Курская область, Курск, Социалистическая, 10	f	large
46541	50395	17	Курская область, город Курск, Республиканская улица, 46а	f	large
47108	50909	584	Курская область, Курск, Парижской Коммуны, Гарнизонный Дом офицеров	f	large
46601	50446	77	Курская область, город Курск, Магистральный проезд, 11	f	large
46557	50407	33	Курская область, Курск, Литовская, 12	f	large
46580	50429	56	Курская область, город Курск, Краснополянская улица, 2а	f	large
46579	50429	55	Курская область, город Курск, Краснополянская улица, 2а	f	large
46566	50416	42	Курская область, город Курск, Конорева, 8	f	large
46596	50442	72	Курская область, Курск, Гагарина, 27	f	large
46659	50490	135	Курская область, Курск, Воробьева, 13	f	large
46660	50490	136	Курская область, Курск, Воробьева, 13	f	large
46638	50477	114	Курская область, Курск, Бойцов 9 Дивизии	f	large
46549	50401	25	Курская область, город Курск, Антокольского, 1	f	large
46617	50460	93	Курская область, Курск, 7-й Промышленный переулок, 9	f	large
46554	50405	30	Курская область, Курск, Вокзал ст. Курск	f	small
46707	50533	183	Курская область, Курск, проспект Хрущева, 4а	f	large
46706	50533	182	Курская область, Курск, проспект Хрущева, 4а	f	large
46656	50488	132	Курская область, Курск, проспект Дружбы, 18	f	large
46649	50485	125	Курская область, Курск, проспект Дружбы, 14	f	large
46650	50485	126	Курская область, Курск, проспект Дружбы, 14	f	large
46651	50485	127	Курская область, Курск, проспект Дружбы, 14	f	large
68156	50383	4	Курская область, Курск, проезд Театральный, 1	f	large
46655	50487	131	Курская область, Курск, проезд Сергеева, 14	f	large
46654	50487	130	Курская область, Курск, проезд Сергеева, 14	f	large
46653	50487	129	Курская область, Курск, проезд Сергеева, 14	f	large
46652	50487	128	Курская область, Курск, проезд Сергеева, 14	f	large
46702	50528	178	Курская область, Курск, проезд Светлый, 15	f	large
46701	50528	177	Курская область, Курск, проезд Светлый, 15	f	large
46684	50512	160	Курская область, Курск, Южный переулок, 16	f	large
46574	50425	50	Курская область, Курск, Энгельса, 171В	f	large
46689	50516	165	Курская область, Курск, Школьная, 1а	f	large
46686	50513	162	Курская область, Курск, Школьная, 3б	f	large
46685	50513	161	Курская область, Курск, Школьная, 3б	f	large
46605	50451	81	Курская область, Курск, Широкая, 8	f	large
46618	50450	94	Курская область, Курск, Широкая, 8	f	large
46604	50450	80	Курская область, Курск, Широкая, 8	f	large
46578	50428	54	Курская область, Курск, Черняховского, 4а	f	large
46577	50427	53	Курская область, Курск, Черняховского, 32	f	large
46576	50427	52	Курская область, Курск, Черняховского, 32	f	large
46626	50467	102	Курская область, Курск, Чернышевского, 7	f	large
46625	50467	101	Курская область, Курск, Чернышевского, 7	f	large
46699	50526	175	Курская область, Курск, Челюскинцев, 19а	f	large
46551	50402	27	Курская область, Курск, Чайковского, 49 в	f	medium
46565	50415	41	Курская область, Курск, Сумская, 41	f	large
46563	50413	39	Курская область, Курск, Сумская, 29	f	large
46560	50410	36	Курская область, Курск, Сумская, 5	f	large
46559	50409	35	Курская область, Курск, Сумская, 5	f	large
46533	50387	9	Курская область, Курск, Станционная, 8	f	large
46532	50387	8	Курская область, Курск, Станционная, 8	f	large
46531	50386	7	Курская область, Курск, Станционная, 14	f	large
46544	50397	20	Курская область, Курск, Союзная, 67к1	f	large
46543	50397	19	Курская область, Курск, Союзная, 67к1	f	large
46628	50469	104	Курская область, Курск, Советская, 25	f	large
46627	50468	103	Курская область, Курск, Советская, 40а	f	large
46624	50466	100	Курская область, Курск, Советская, 14	f	large
46595	50441	71	Курская область, Курск, Серегина, 16а	f	large
46592	50440	68	Курская область, Курск, Серегина, 12	f	large
46593	50440	69	Курская область, Курск, Серегина, 12	f	large
46590	50438	66	Курская область, Курск, Серегина, 17	f	large
46589	50438	65	Курская область, Курск, Серегина, 17	f	large
46594	50436	70	Курская область, Курск, Серегина, 41	f	large
46587	50436	63	Курская область, Курск, Серегина, 41	f	large
46586	50436	62	Курская область, Курск, Серегина, 41	f	large
46671	50499	147	Курская область, Курск, Серафима Соровского, 12	f	medium
46677	50505	153	Курская область, Курск, Семеновская, 78	f	large
46680	50508	156	Курская область, Курск, Садовая, 19	f	large
46678	50506	154	Курская область, Курск, Садовая, 31	f	large
46555	50403	31	Курская область, Курск, Республиканская, 50б	f	large
46552	50403	28	Курская область, Курск, Республиканская, 50б	f	large
46542	50396	18	Курская область, Курск, Республиканская, 46а	f	large
46581	50431	57	Курская область, Курск, Резиновая, 14	f	large
46683	50511	159	Курская область, Курск, Радищева, 116	f	medium
46676	50504	152	Курская область, Курск, Радищева, 35	f	large
46675	50503	151	Курская область, Курск, Радищева, 33	f	large
46703	50529	179	Курская область, Курск, Пучковка, 82	f	small
46665	50493	141	Курская область, Курск, Пучковка, 13	f	large
46664	50492	140	Курская область, Курск, Пучковка, 35	f	large
46674	50502	150	Курская область, Курск, Почтовая, 18а	f	large
46637	50476	113	Курская область, Курск, Понизовка, 52	f	medium
46705	50531	181	Курская область, Курск, Пионеров, 84	f	large
46561	50411	37	Курская область, Курск, Пигорева, 7	f	large
46634	50474	110	Курская область, Курск, Павлуновского, 65	f	large
46526	50381	2	Курская область, Курск, Островского, 10а	f	large
46525	50381	1	Курская область, Курск, Островского, 10а	f	large
46567	50417	43	Курская область, Курск, Ольшанского, 27	f	large
46562	50412	38	Курская область, Курск, Ольшанского, 27	f	large
46584	50434	60	Курская область, Курск, Обоянская, 26	f	large
46585	50435	61	Курская область, Курск, Народная, 8	f	large
46709	50491	185	Курская область, Курск, Мыльникова, 8	f	large
46663	50491	139	Курская область, Курск, Мыльникова, 8	f	large
46662	50491	138	Курская область, Курск, Мыльникова, 8	f	large
46661	50491	137	Курская область, Курск, Мыльникова, 8	f	large
46673	50501	149	Курская область, Курск, Мирная, 5	f	large
46616	50459	92	Курская область, Курск, Менделеева, 59, здание МУ Городской культурный центр Лира	f	large
46615	50459	91	Курская область, Курск, Менделеева, 59, здание МУ Городской культурный центр Лира	f	large
46609	50455	85	Курская область, Курск, Менделеева, 19	f	large
46608	50454	84	Курская область, Курск, Менделеева, 19	f	large
46527	50382	3	Курская область, Курск, Маяковского, 85	f	large
46603	50449	79	Курская область, Курск, Магистральный проезд, 17	f	medium
46602	50448	78	Курская область, Курск, Магистральный проезд, 17	f	large
46600	50445	76	Курская область, Курск, Магистральный проезд, 22В	f	large
46599	50445	75	Курская область, Курск, Магистральный проезд, 22В	f	large
46598	50444	74	Курская область, Курск, Магистральный проезд, 20	f	large
46630	50471	106	Курская область, Курск, Ломоносова, 3	f	large
46672	50500	148	Курская область, Курск, Ленина, 43	f	large
46629	50470	105	Курская область, Курск, Красной Армии, 23	f	large
46538	50392	14	Курская область, Курск, Краснознаменная, 13	f	large
46537	50391	13	Курская область, Курск, Краснознаменная, 13	f	large
46658	50489	134	Курская область, Курск, Косухина, 25	f	large
46657	50489	133	Курская область, Курск, Косухина, 25	f	large
46571	50422	47	Курская область, Курск, Комарова, 3	f	large
46570	50421	46	Курская область, Курск, Комарова, 3	f	large
46568	50418	44	Курская область, Курск, Комарова, 27	f	large
46669	50497	145	Курская область, Курск, Кирова, 22	f	large
46553	50404	29	Курская область, Курск, Каширцева, 5	f	large
46536	50390	12	Курская область, Курск, Каширцева, 54	f	large
46535	50389	11	Курская область, Курск, Каширцева, 54	f	large
46711	50536	187	Курская область, Курск, Карла Маркса, 76	f	large
46700	50527	176	Курская область, Курск, Карла Маркса, 101	f	large
46697	50524	173	Курская область, Курск, Карла Маркса, 23	f	medium
46696	50523	172	Курская область, Курск, Карла Маркса, 63	f	large
46695	50522	171	Курская область, Курск, Карла Маркса, 51а	f	large
46694	50521	170	Курская область, Курск, Карла Маркса, 69	f	large
46693	50519	169	Курская область, Курск, Карла Маркса, 70	f	large
46692	50519	168	Курская область, Курск, Карла Маркса, 70	f	large
46691	50518	167	Курская область, Курск, Карла Маркса, 70/1	f	large
46688	50515	164	Курская область, Курск, Карла Маркса, 27/31	f	large
46682	50510	158	Курская область, Курск, Карла Маркса, 3а	f	large
46681	50509	157	Курская область, Курск, Карла Маркса, 2	f	large
46534	50388	10	Курская область, Курск, Ильича, 31	f	large
46642	50480	118	Курская область, Курск, Запольная, 45	f	large
46573	50424	49	Курская область, Курск, Заводская, 81	f	large
46623	50465	99	Курская область, Курск, Добролюбова, 4	f	medium
46679	50507	155	Курская область, Курск, Димитрова, 101	f	large
46668	50496	144	Курская область, Курск, Дзержинского, 50	f	medium
46572	50423	48	Курская область, Курск, Дейнеки, 36	f	large
46591	50439	67	Курская область, Курск, Гагарина, 4	f	large
46588	50437	64	Курская область, Курск, Гагарина, 4	f	large
46670	50498	146	Курская область, Курск, Володарского, 44	f	large
46648	50482	124	Курская область, Курск, Веспремская, 1а	f	large
46647	50482	123	Курская область, Курск, Веспремская, 1а	f	large
46644	50482	120	Курская область, Курск, Веспремская, 1а	f	large
46667	50495	143	Курская область, Курск, Верхняя Луговая, 241	f	large
46666	50494	142	Курская область, Курск, Верхняя Казацкая, 196	f	large
46529	50384	5	Курская область, Курск, ВЧК, 47	f	large
46583	50433	59	Курская область, Курск, Белгородская, 21	f	large
46641	50479	117	Курская область, Курск, Аэродромная, 18	f	large
46704	50530	180	Курская область, Курск, Антокольского, 1а	f	large
46645	50483	121	Курская область, Курск, 50-летия Октября, 165	f	medium
46643	50481	119	Курская область, Курск, 50-летия Октября, 163	f	large
46575	50426	51	Курская область, Курск, 3-я Песковская, 23	f	medium
46558	50408	34	Курская область, Курск, 3-я Песковская, 23	f	large
46610	50456	86	Курская область, Курск, 3-й Промышленный переулок, 4а	f	large
46597	50443	73	Курская область, Курск, 2-я Энергетиков, 22	f	large
46547	50399	23	Курская область, Курск, 2-я Стрелецкая, 46	f	large
46546	50399	22	Курская область, Курск, 2-я Стрелецкая, 46	f	large
46545	50398	21	Курская область, Курск, 2-я Рабочая, 18б	f	large
46687	50514	163	Курская область, Курск, 1-я Офицерская, 29	f	large
46530	50385	6	Курская область, Курск, Профсоюзная, 11	f	large
46646	50484	122	Курская область, Курск, 50-летия Октября, 102	f	large
46729	50555	205	Курская область, Железногорск, Ленина, 11	f	large
46726	50552	202	Курская область, Железногорск, проезд Ветеранов, 10	f	small
46757	50570	233	Курская область, Железногорск, Энтузиастов, 6	f	large
46761	50570	237	Курская область, Железногорск, Энтузиастов, 6	f	large
46760	50570	236	Курская область, Железногорск, Энтузиастов, 6	f	large
46759	50570	235	Курская область, Железногорск, Энтузиастов, 6	f	large
111268	50571	234	Курская область, Железногорск, Привокзальная, 7	f	medium
46734	50558	210	Курская область, Железногорск, Первомайская, 8	f	large
46733	50558	209	Курская область, Железногорск, Первомайская, 8	f	large
46738	50560	214	Курская область, Железногорск, Парковая, 10	f	large
46737	50560	213	Курская область, Железногорск, Парковая, 10	f	large
46755	50569	231	Курская область, Железногорск, Мира, 47	f	large
46756	50569	232	Курская область, Железногорск, Мира, 47	f	large
46754	50569	230	Курская область, Железногорск, Мира, 47	f	large
46768	50574	244	Курская область, Железногорск, Маршала Жукова, 12	f	large
46767	50573	243	Курская область, Железногорск, Ленина, 84/2	f	large
46730	50556	206	Курская область, Железногорск, Ленина, 15	f	large
46728	50554	204	Курская область, Железногорск, Лени Голенькова, 15	f	large
46727	50553	203	Курская область, Железногорск, Лени Голенькова, 2а	f	large
46753	50568	229	Курская область, Железногорск, Курская, 43	f	large
46752	50568	228	Курская область, Железногорск, Курская, 43	f	large
46751	50568	227	Курская область, Железногорск, Курская, 43	f	large
46745	50565	221	Курская область, Железногорск, Курская, 21	f	large
46742	50562	218	Курская область, Железногорск, Курская, 68	f	large
46741	50562	217	Курская область, Железногорск, Курская, 68	f	large
46740	50561	216	Курская область, Железногорск, Курская, 21	f	large
46739	50561	215	Курская область, Железногорск, Курская, 21	f	large
46736	50559	212	Курская область, Железногорск, Курская, 7	f	large
46735	50559	211	Курская область, Железногорск, Курская, 7	f	large
46732	50557	208	Курская область, Железногорск, Комсомольская, 2	f	large
46731	50557	207	Курская область, Железногорск, Комсомольская, 2	f	large
46748	50566	224	Курская область, Железногорск, Дружбы, 14	f	large
46747	50566	223	Курская область, Железногорск, Дружбы, 14	f	large
46746	50566	222	Курская область, Железногорск, Дружбы, 14	f	large
46750	50567	226	Курская область, Железногорск, Детский переулок, 18	f	large
46749	50567	225	Курская область, Железногорск, Детский переулок, 18	f	large
46744	50564	220	Курская область, Железногорск, Гагарина, 14	f	large
46762	50572	238	Курская область, Железногорск, Воинов Интернационалистов, 1	f	large
46766	50572	242	Курская область, Железногорск, Воинов Интернационалистов, 1	f	large
46765	50572	241	Курская область, Железногорск, Воинов Интернационалистов, 1	f	large
46764	50572	240	Курская область, Железногорск, Воинов Интернационалистов, 1	f	large
46763	50572	239	Курская область, Железногорск, Воинов Интернационалистов, 1	f	large
47118	50919	594	Курская область, деревня Духовец, Духовецкий сельский клуб	t	small
47117	50918	593	Курская область, деревня Гремячка, Гремяченская начальная школа	f	small
81915	56101	1079	Москва, Фрязевская улица, 5	f	large
46898	50700	374	Курская область, деревня Голубицкое, улица Центральная	f	small
47372	51169	848	Курская область, Пристенский район, Центральная, 6	f	small
47116	50917	592	Курская область, деревня 1-я Моква, Моковская средняя школа	f	large
47674	51476	1150	Курская область, Щигровский район, поселок Хитровка	f	small
47656	51457	1132	Курская область, Щигровский район, поселок Сидоровка	f	small
47659	51460	1135	Курская область, Щигровский район, поселок Сергеевка	f	small
47672	51474	1148	Курская область, Щигровский район, поселок Семеновка 1-я	f	medium
47675	51477	1151	Курская область, Щигровский район, поселок Пригородняя	f	medium
47663	51464	1139	Курская область, Щигровский район, поселок Пожидаевка	f	small
47670	51471	1146	Курская область, Щигровский район, поселок Плодовый	f	small
47655	51456	1131	Курская область, Щигровский район, поселок Новосергиевка	f	small
47653	51454	1129	Курская область, Щигровский район, поселок Нижний Теребуж	f	small
47676	51478	1152	Курская область, Щигровский район, поселок Куликовка	f	small
47667	51468	1143	Курская область, Щигровский район, поселок Крутое	f	small
47666	51467	1142	Курская область, Щигровский район, поселок Кривцовка	f	small
47665	51466	1141	Курская область, Щигровский район, поселок Косоржа	f	medium
47677	51479	1153	Курская область, Щигровский район, поселок Козловка	t	small
47664	51465	1140	Курская область, Щигровский район, поселок Касиновка	f	small
47673	51475	1149	Курская область, Щигровский район, поселок Зеленая Роща	f	medium
47662	51463	1138	Курская область, Щигровский район, поселок Защитное	f	small
47669	51470	1145	Курская область, Щигровский район, поселок Длинная	f	small
47661	51462	1137	Курская область, Щигровский район, поселок Вязовое	f	small
47658	51459	1134	Курская область, Щигровский район, поселок Вишневка	f	small
47671	51473	1147	Курская область, Щигровский район, поселок Верхняя Гремячка	f	medium
47657	51458	1133	Курская область, Щигровский район, поселок Большой Змеинец	f	small
47654	51455	1130	Курская область, Щигровский район, поселок Басово	f	small
47660	51461	1136	Курская область, Щигровский район, поселок Апухтина	t	small
47668	51469	1144	Курская область, Щигровский район, поселок 2-е Мелехино	f	small
47639	51445	1115	Курская область, Черемисиновский район, поселок Юдинка	f	small
47620	51424	1096	Курская область, Черемисиновский район, поселок Черемисиново, Советская, 27	f	large
47619	51423	1095	Курская область, Черемисиновский район, поселок Черемисиново, Кооперативная, 2	f	large
47621	51425	1097	Курская область, Черемисиновский район, поселок Хмелевская	f	small
47641	51447	1117	Курская область, Черемисиновский район, поселок Удерево, здание Удеревского филиала МКОУ Стакановская средняя общеобразовательная школа имени лейтенанта А.С. Сергеева	f	small
47628	51433	1104	Курская область, Черемисиновский район, поселок Толстый Колодезь, здание Толстоколодезского сельского дома культуры-, филиала МКУК Михайловский сельский дом культуры	f	small
47629	51434	1105	Курская область, Черемисиновский район, поселок Теплое	f	small
47626	51431	1102	Курская область, Черемисиновский район, поселок Старые Савины	f	small
47638	51444	1114	Курская область, Черемисиновский район, поселок Стаканово	f	small
47624	51428	1100	Курская область, Черемисиновский район, поселок Серединка	f	small
47633	51438	1109	Курская область, Черемисиновский район, поселок Сельский Рогачик	f	small
47635	51440	1111	Курская область, Черемисиновский район, поселок Русаново	f	small
47632	51437	1108	Курская область, Черемисиновский район, поселок Петрово-Хутарь	f	small
47634	51439	1110	Курская область, Черемисиновский район, поселок Огневка	f	small
47636	51442	1112	Курская область, Черемисиновский район, поселок Никитское, здание Никитского сельского клуба - филиал МКУК Русановский сельский дом культуры 	f	small
47637	51443	1113	Курская область, Черемисиновский район, поселок Нижнеольховатое, здание Нижнеольховатского филиала МКОУ Русановская средняя общеобразовательная школа имени В.С. Шатохина 	f	small
47631	51436	1107	Курская область, Черемисиновский район, поселок Ниженка	t	small
47627	51432	1103	Курская область, Черемисиновский район, поселок Михайловка	f	small
47430	51234	906	Курская область, Рыльский район, поселок Щекино, 53	f	small
47642	51448	1118	Курская область, Черемисиновский район, поселок Крюково, здание Крюковского сельского клуба - филиала МКУК Удеревский сельский дом культуры	t	small
47623	51427	1099	Курская область, Черемисиновский район, поселок Карасевка	f	small
47640	51446	1116	Курская область, Черемисиновский район, поселок Исаково, здание Исаковского филиала МКОУ Стакановская средняя общеобразовательная, школа имени лейтенанта А.С. Сергеева	f	small
47625	51429	1101	Курская область, Черемисиновский район, поселок Исаково	f	small
47622	51426	1098	Курская область, Черемисиновский район, поселок Ефремовка	f	small
47615	51419	1091	Курская область, Хомутовский район, поселок Ярославка	t	small
47589	51393	1065	Курская область, Хомутовский район, поселок Хомутовка, Советская, 11	f	large
47590	51394	1066	Курская область, Хомутовский район, поселок Хомутовка, Кирова, 5	f	large
47593	51397	1069	Курская область, Хомутовский район, поселок Стрекалово	f	small
47611	51415	1087	Курская область, Хомутовский район, поселок Старшее, здание Старшенского филиала МКОУ Хомутовская СОШ	f	small
47616	51420	1092	Курская область, Хомутовский район, поселок Сковороднево, здание МКОУ Сковородневская СОШ 	f	small
47613	51417	1089	Курская область, Хомутовский район, поселок Сальное, здание МУК Сальновский СДК	f	small
47609	51413	1085	Курская область, Хомутовский район, поселок Романово	f	small
47599	51403	1075	Курская область, Хомутовский район, поселок Приходьково	f	small
47614	51418	1090	Курская область, Хомутовский район, поселок Прилепы, здание МУК Прилеповский центральный СДК 	f	small
47607	51411	1083	Курская область, Хомутовский район, поселок Поды, здание МКОУ Подовская СОШ	f	small
47605	51409	1081	Курская область, Хомутовский район, поселок Петровское	f	small
47606	51410	1082	Курская область, Хомутовский район, поселок Переступлено	f	small
47600	51404	1076	Курская область, Хомутовский район, поселок Ольховка, Школьная, 6	f	small
47602	51406	1078	Курская область, Хомутовский район, поселок Нижняя Туранка	f	small
47604	51408	1080	Курская область, Хомутовский район, поселок Нижнее Чупахино	t	small
47603	51407	1079	Курская область, Хомутовский район, поселок Надейка	f	small
47617	51421	1093	Курская область, Хомутовский район, поселок Меньшиково	t	small
47592	51396	1068	Курская область, Хомутовский район, поселок Малеевка	f	small
47608	51412	1084	Курская область, Хомутовский район, поселок Луговое	f	small
47601	51405	1077	Курская область, Хомутовский район, поселок Красная Поляна, Ольховская, 12	t	small
47598	51402	1074	Курская область, Хомутовский район, поселок Клевень	f	small
47595	51399	1071	Курская область, Хомутовский район, поселок Калиновка, Пионерская, 1	f	large
47618	51422	1094	Курская область, Хомутовский район, поселок Звенячка	t	small
47596	51400	1072	Курская область, Хомутовский район, поселок Жеденовка	f	small
47594	51376	1070	Курская область, Хомутовский район, поселок Дубовица	f	small
47612	51416	1088	Курская область, Хомутовский район, поселок Деменино	f	small
47591	51395	1067	Курская область, Хомутовский район, поселок Гламаздино	f	small
47610	51414	1086	Курская область, Хомутовский район, поселок Веть	f	small
47597	51401	1073	Курская область, Хомутовский район, поселок Амонь, каб. Администрации Калиновского с/с	f	small
47573	51377	1049	Курская область, Фатежский район, поселок Ясенок	t	small
47579	51383	1055	Курская область, Фатежский район, поселок Хмелевое	f	small
47559	51361	1035	Курская область, Фатежский район, Фатеж, Тихая, 33	f	large
47558	51360	1034	Курская область, Фатежский район, Фатеж, Карла Маркса, 32	f	large
47581	51385	1057	Курская область, Фатежский район, поселок Сухочево, здание МКОУ Сухочевская основная общеобразовательная школа	f	small
47565	51368	1041	Курская область, Фатежский район, поселок Сотниково	f	small
47584	51388	1060	Курская область, Фатежский район, поселок Солдатское	f	medium
47580	51384	1056	Курская область, Фатежский район, поселок Русановка	f	medium
47564	51367	1040	Курская область, Фатежский район, поселок Ржава	f	small
47586	51390	1062	Курская область, Фатежский район, поселок Репринка, здание МКОУ Любимовская начальная общеобразовательная школ 	t	small
47588	51392	1064	Курская область, Фатежский район, поселок Поздняково	f	small
47583	51387	1059	Курская область, Фатежский район, поселок Нижний Реут, здание МКОУ Нижнереутская средняя общеобразовательная школа	f	small
47587	51391	1063	Курская область, Фатежский район, поселок Нижние Халчи	f	small
47578	51382	1054	Курская область, Фатежский район, поселок Молотычи	f	small
47575	51379	1051	Курская область, Фатежский район, поселок Миролюбово	f	small
47577	51381	1053	Курская область, Фатежский район, поселок Миленино	f	medium
47569	51372	1045	Курская область, Фатежский район, поселок Мелешинка	f	small
47568	51371	1044	Курская область, Фатежский район, поселок Кукуевка, здание МКОУ Колычевская основная общеобразовательная школа	f	small
47572	51375	1048	Курская область, Фатежский район, поселок Игино	f	small
47576	51380	1052	Курская область, Фатежский район, поселок Зыковка	f	medium
47563	51366	1039	Курская область, Фатежский район, поселок Жердево	t	small
47562	51364	1038	Курская область, Фатежский район, поселок Горки	f	small
47574	51378	1050	Курская область, Фатежский район, поселок Верхняя Хотемль	f	small
47571	51374	1047	Курская область, Фатежский район, поселок Верхний Любаж	f	small
47570	51373	1046	Курская область, Фатежский район, поселок Верхний Любаж	f	large
47561	51363	1037	Курская область, Фатежский район, поселок Бычки	f	small
47567	51370	1043	Курская область, Фатежский район, поселок Большое Жирово	f	medium
47566	51369	1042	Курская область, Фатежский район, поселок Большое Анненково	f	medium
47582	51386	1058	Курская область, Фатежский район, деревня Басовка	f	small
47585	51389	1061	Курская область, Фатежский район, поселок Алисово-Покровское	f	small
47121	50922	597	Курская область, Фатежский район, поселок 1-е Шемякино, Шемякинская основная школа	t	small
47560	51362	1036	Курская область, Фатежский район, поселок 1-е Банино	t	small
47553	51355	1029	Курская область, Тимский район, поселок Шабановка, Шабаново, 49	t	small
47554	51356	1030	Курская область, Тимский район, поселок Успенка, Школьная, 2	f	small
68163	51336	1009	Курская область, Тимский район, поселок Тим, Красноармейская	f	large
47532	51335	1008	Курская область, Тимский район, поселок Тим, Кирова, 25А	f	large
47547	51349	1023	Курская область, Тимский район, поселок Становое, Бахаровская, 41	f	small
47537	51305	1013	Курская область, Тимский район, поселок Соколье, Школьная, 23	f	small
47535	51338	1011	Курская область, Тимский район, поселок Рождественка, Центральная, 11	f	small
47539	51341	1015	Курская область, Тимский район, поселок Рогозцы, Школьная, 29	f	small
47544	51346	1020	Курская область, Тимский район, поселок Рогозецкий Колодезь, Мирная, 8	t	small
47543	51345	1019	Курская область, Тимский район, поселок Постояновка	f	small
47545	51347	1021	Курская область, Тимский район, поселок Погожее, Садовая, 51А	f	small
47536	51339	1012	Курская область, Тимский район, поселок Пахонок, Новая, 10	t	small
47546	51348	1022	Курская область, Тимский район, поселок Лисий Колодезь, Репьевская, 1А	f	small
47557	51359	1033	Курская область, Тимский район, поселок Леженьки, Школьная, 12	f	small
47541	51343	1017	Курская область, Тимский район, поселок Кировка, Центральная, 9	t	small
47556	51358	1032	Курская область, Тимский район, поселок Канищево, Школьная, 1	f	small
47555	51357	1031	Курская область, Тимский район, поселок Заречье, Молодежный переулок, 1	f	small
47548	51350	1024	Курская область, Тимский район, поселок Гнилуши, Камышенская, 22А	f	small
47549	51351	1025	Курская область, Тимский район, поселок Гнилое, Ниженка, 1	f	small
47550	51352	1026	Курская область, Тимский район, поселок Выгорное 3-е, Запрудная, 67	f	small
47540	51342	1016	Курская область, Тимский район, поселок Выгорное 2-е, Придорожная, 22	f	small
47551	51353	1027	Курская область, Тимский район, поселок Выгорное 1-е, Мичурина, 8	f	medium
47542	51344	1018	Курская область, Тимский район, поселок Волобуевка, Придорожная, 40	f	small
47552	51354	1028	Курская область, Тимский район, поселок Введенка, Хуторская, 13	f	small
47538	51340	1014	Курская область, Тимский район, поселок Быстрецы, Новая, 22	f	small
47534	51337	1010	Курская область, Тимский район, поселок Барковка, Школьная, 5	f	small
47503	51306	979	Курская область, Суджанский район, поселок Черный Олех, Советская, 1	f	small
47512	51315	988	Курская область, Суджанский район, поселок Черкасское-Поречное, Выгонок 2, 11	f	medium
47505	51308	981	Курская область, Суджанский район, поселок Уланок, Центральная, 29	f	small
47525	51328	1001	Курская область, Суджанский район, поселок Толстый Луг, 105	f	small
47498	51300	974	Курская область, Суджанский район, Суджа, Щепкина, 18	f	large
47500	51302	976	Курская область, Суджанский район, Суджа, Октябрьская, 12	f	large
68162	51303	977	Курская область, Суджанский район, Суджа, Заводской переулок, 21 А	f	large
47511	51314	987	Курская область, Суджанский район, поселок Спальное, 109	t	small
47521	51324	997	Курская область, Суджанский район, поселок Свердликово, Село, 69	f	small
47513	51316	989	Курская область, Суджанский район, поселок Русское-Поречное, Гора, 10	f	small
47508	51311	984	Курская область, Суджанский район, поселок Русская-Конопелька, Центральная	t	small
46821	50620	297	Курская область, Суджанский район, поселок Розгребли	f	medium
47531	51334	1007	Курская область, Суджанский район, поселок Пушкарное, 35	f	small
47528	51331	1004	Курская область, Суджанский район, поселок Погребки, Село, 14	f	small
47509	51312	985	Курская область, Суджанский район, поселок Плехово, Новая, 2	f	medium
47524	51327	1000	Курская область, Суджанский район, поселок Новоивановка, 87	f	small
86444	51307	980	Курская область, Суджанский район, поселок Нижнемахово, Мира, 30 А	f	small
47507	51310	983	Курская область, Суджанский район, поселок Махновка, Школьная	f	medium
47506	51309	982	Курская область, Суджанский район, поселок Мартыновка, Центр, 10	f	medium
47527	51330	1003	Курская область, Суджанский район, поселок Малая Локня, Молодежная, 7, здание МКОУ Малолокнянская СОШ	f	medium
47523	51326	999	Курская область, Суджанский район, поселок Лебедевка, Церковщина, 8	f	small
47514	51317	990	Курская область, Суджанский район, поселок Киреевка	f	small
47526	51329	1002	Курская область, Суджанский район, поселок Казачья Локня, Новоселовка, 24	f	medium
47529	51332	1005	Курская область, Суджанский район, поселок Ивница, 23	f	small
47519	51322	995	Курская область, Суджанский район, поселок Заолешенка, Школьная, 2	f	large
47518	51321	994	Курская область, Суджанский район, поселок Заолешенка, Новоселовка, 6	f	large
47530	51333	1006	Курская область, Суджанский район, село Замостье, Ленина	f	large
47522	51325	998	Курская область, Суджанский район, поселок Дарьино, Большая, 33	f	small
47515	51318	991	Курская область, Суджанский район, поселок Гуево, Шлях, 9	f	medium
47517	51320	993	Курская область, Суджанский район, поселок Гончаровка, пер. Гагарина 2й, 8	f	large
47516	51319	992	Курская область, Суджанский район, поселок Гончаровка, Мира	f	large
47520	51323	996	Курская область, Суджанский район, поселок Гоголевка, Центральная, 32	f	small
47502	51304	978	Курская область, Суджанский район, поселок Воробжа, Центральная, 7	f	small
86445	51313	986	Курская область, Суджанский район, поселок Борки, Королевка, 36	t	small
47497	51299	973	Курская область, Солнцевский район, поселок Шумаково, Садовая, 4	f	medium
47487	51289	963	Курская область, Солнцевский район, поселок Шлях, Центральная, 4	t	small
47486	51288	962	Курская область, Солнцевский район, поселок Чермошное, Центральная, 14	f	small
47475	51268	951	Курская область, Солнцевский район, поселок Хахилево, Садовая, 9	f	small
47473	51278	949	Курская область, Солнцевский район, поселок Толмачевка, Толмачевская, 1	f	small
47491	51293	967	Курская область, Солнцевский район, поселок Субботино, переулок Школьный, 4	f	medium
47471	51276	947	Курская область, Солнцевский район, поселок Солнцево, Первомайская, 31	f	large
47470	51276	946	Курская область, Солнцевский район, поселок Солнцево, Первомайская, 31	f	large
47492	51294	968	Курская область, Солнцевский район, поселок Сеймица, Сеймская, 3	f	small
47480	51282	956	Курская область, Солнцевский район, поселок Сараевка, Школьная, 3	f	small
47482	51284	958	Курская область, Солнцевский район, поселок Ржаво-Плота, Припрудная, 2	f	small
47496	51298	972	Курская область, Солнцевский район, поселок Плоское, Центральная, 3	f	medium
47493	51295	969	Курская область, Солнцевский район, поселок Орлянка, Молодежная, 1	f	medium
47495	51297	971	Курская область, Солнцевский район, поселок Малиновка, Можайская, 3	f	small
47483	51285	959	Курская область, Солнцевский район, поселок Княжая, Школьная, 6	f	small
47484	51286	960	Курская область, Солнцевский район, поселок Ивановка, Жуковка, 11	f	large
47481	51283	957	Курская область, Солнцевский район, поселок Зуевка, Центральная, 4	f	medium
47489	51291	965	Курская область, Солнцевский район, поселок Ефросимовка, Набережная, 2	f	small
47485	51287	961	Курская область, Солнцевский район, поселок Дорохо-Доренское, Веселая, 1а	f	small
47476	51159	952	Курская область, Солнцевский район, поселок Доброе, Победы, 22	f	small
47479	51281	955	Курская область, Солнцевский район, поселок Дежевка, переулок Школьный, 1	f	small
47478	51280	954	Курская область, Солнцевский район, поселок Гридасово, Марии Овсянниковой, 22	f	small
47488	51290	964	Курская область, Солнцевский район, поселок Гололобовка, Школьная, 1	f	small
47477	51194	953	Курская область, Солнцевский район, поселок Выползово, Гвардейская, 17	f	small
47494	51296	970	Курская область, Солнцевский район, поселок Воробьевка, Центральная, 10	t	small
47474	51246	950	Курская область, Солнцевский район, поселок Бунино, Центральная, 35	f	small
47490	51292	966	Курская область, Солнцевский район, поселок Большая Козьмодемьяновка, Молодежная, 4	f	small
47472	51277	948	Курская область, Солнцевский район, поселок Афанасьевка, Школьная, 13	f	small
47449	51253	925	Курская область, Советский район, поселок имени Пушкина	t	small
47463	51269	939	Курская область, Советский район, поселок Садовый	t	small
47457	51262	933	Курская область, Советский район, поселок Расховецкий	f	small
47456	51261	932	Курская область, Советский район, поселок Расховец	f	small
47438	51241	914	Курская область, Советский район, поселок Подгородище 1-е	f	small
47469	51275	945	Курская область, Советский район, поселок Петрово-Карцево	f	small
47453	51258	929	Курская область, Советский район, поселок Перцевка	f	small
47455	51260	931	Курская область, Советский район, поселок Переволочное	f	small
47450	51254	926	Курская область, Советский район, поселок Октябрьское	f	small
47466	51272	942	Курская область, Советский район, поселок Нижняя Грайворонка	t	small
47447	51251	923	Курская область, Советский район, поселок Нижнее Гурово	f	small
47464	51270	940	Курская область, Советский район, поселок Натальино	f	small
47444	51248	920	Курская область, Советский район, поселок Моздовка	t	small
47461	51266	937	Курская область, Советский район, поселок Михайло-Анненка	f	small
47446	51250	922	Курская область, Советский район, поселок Мелехово	f	small
47459	51264	935	Курская область, Советский район, поселок Мансурово	f	small
47445	51249	921	Курская область, Советский район, поселок Липовчик	t	small
47452	51256	928	Курская область, Советский район, поселок Ледовское	f	small
47434	51237	910	Курская область, Советский район, поселок Кшенский, Свердлова, 3 а	f	large
68159	51215	908	Курская область, Советский район, поселок Кшенский, Пролетарская, 52	f	large
47431	51235	907	Курская область, Советский район, поселок Кшенский, Ленина, 13	f	large
68160	51236	909	Курская область, Советский район, поселок Кшенский, Заводская, 2	f	large
47460	51265	936	Курская область, Советский район, поселок Крестище	f	small
47448	51252	924	Курская область, Советский район, поселок Красная Долина	f	small
47468	51274	944	Курская область, Советский район, поселок Коммунар	f	medium
47462	51267	938	Курская область, Советский район, поселок Кирилловка	t	small
47439	51242	915	Курская область, Советский район, поселок Каменогорка	f	small
47454	51259	930	Курская область, Советский район, поселок Имени Ленина	f	medium
86443	51243	916	Курская область, Советский район, поселок Ефросимовка	f	small
47467	51273	943	Курская область, Советский район, поселок Дицево	f	small
47436	51239	912	Курская область, Советский район, поселок Грязное	f	small
47437	51240	913	Курская область, Советский район, поселок Городище	f	small
47443	51247	919	Курская область, Советский район, поселок Голощаповка	t	small
47442	51245	918	Курская область, Советский район, поселок Волжанец	f	medium
47441	51244	917	Курская область, Советский район, поселок Верхние Апочки	f	medium
47465	51271	941	Курская область, Советский район, поселок Васильевка 2-я	t	medium
47458	51263	934	Курская область, Советский район, поселок Бородаевка	f	small
47451	51255	927	Курская область, Советский район, поселок Березовчик	f	small
47435	51238	911	Курская область, Советский район, поселок Александровка	f	small
111272	51202	878	Курская область, Рыльский район, поселок Учительский, 7А, здание Марьинского филиала №2, МБОУ Ивановская средняя общеобразовательная школа	f	\N
47414	51218	890	Курская область, Рыльский район, поселок Сухая, 127	f	small
47427	51231	903	Курская область, Рыльский район, поселок Студенок, 107	f	small
47423	51227	899	Курская область, Рыльский район, поселок Степановка, 157	f	small
111277	51219	891	Курская область, Рыльский район, поселок Семеново, 43	t	medium
47408	51212	885	Курская область, Рыльский район, поселок Свобода, 80	f	small
47386	51185	862	Курская область, Рыльский район, Рыльск, Розы Люксембург, 50, Здание МБОУ, Рыльская средняя общеобразовательная школа №4	f	large
47389	51188	865	Курская область, Рыльский район, Рыльск, Советская площадь, 15	f	large
47425	51229	901	Курская область, Рыльский район, Рыльск, Советская, 7 А	f	medium
47393	51193	870	Курская область, Рыльский район, Рыльск, Розы Люксембург, 77	f	large
111271	51192	869	Курская область, Рыльский район, город Рыльск, Кирова, 2, здание МБОУ ДОД Рыльская, детско-юношеская спортивная школа	f	\N
47390	51189	866	Курская область, Рыльский район, Рыльск, Дзержинского, 18	f	large
47388	51187	864	Курская область, Рыльский район, Рыльск, Дзержинского, 53	f	large
47405	51207	882	Курская область, Рыльский район, поселок Рыжевка, 185	t	medium
47421	51225	897	Курская область, Рыльский район, поселок Поповка, 37	t	small
47422	51226	898	Курская область, Рыльский район, поселок Октябрьское, 103	t	small
47416	51220	892	Курская область, Рыльский район, поселок Нехаевка, Центральная, 56	f	small
47411	51214	887	Курская область, Рыльский район, поселок Михайловка, 160	f	small
47418	51222	894	Курская область, Рыльский район, поселок Макеево, 83	t	small
47424	51228	900	Курская область, Рыльский район, поселок Мазеповка, 127	f	small
47404	51206	881	Курская область, Рыльский район, поселок Локоть, 278	f	small
47397	51198	874	Курская область, Рыльский район, поселок Кулига, Бобровского, 60, здание филиала МБОУ Рыльская средняя общеобразовательная школа №5	f	small
47395	51196	872	Курская область, Рыльский район, поселок Кострова, 80	f	small
47403	51205	880	Курская область, Рыльский район, поселок Козино, 183	t	medium
47396	51197	873	Курская область, Рыльский район, поселок Капыстичи, 103	f	small
47410	51213	886	Курская область, Рыльский район, поселок Имени Куйбышева, Лесная, 9 А	f	large
47400	51201	877	Курская область, Рыльский район, Ивановское , Комаровка, 37	f	small
47399	51200	876	Курская область, Рыльский район, поселок Ивановское, Ананьева, 1 А	f	large
47398	51199	875	Курская область, Рыльский район, поселок Дурово, 85	f	small
111275	51210	884	Курская область, Рыльский район, поселок Воронок, 131, помещение МКУК, Воронокская поселенческая библиотека	f	\N
111274	51208	883	Курская область, Рыльский район, поселок Воронок, 131, здание МКУК Воронокская поселенческая библиотека	f	\N
47413	51217	889	Курская область, Рыльский район, поселок Большенизовцево, 113	f	small
47420	51224	896	Курская область, Рыльский район, поселок Большегнеушево, 146	t	small
47394	51195	871	Курская область, Рыльский район, поселок Березники, 72	f	small
47417	51221	893	Курская область, Рыльский район, поселок Бегоща, Дубовка, 60	t	small
47412	51216	888	Курская область, Рыльский район, поселок Артюшково, 33	f	small
47429	51233	905	Курская область, Рыльский район, поселок Анатольевка, 74	f	small
47426	51230	902	Курская область, Рыльский район, поселок Александровка, 103	f	small
47428	51232	904	Курская область, Рыльский район, поселок Акимовка, 129	f	small
47419	51223	895	Курская область, Рыльский район, поселок 1-е Яньково, 40	f	small
47377	51175	853	Курская область, Пристенский район, поселок Ярыгино, Центральная, 32	f	small
47371	51168	847	Курская область, Пристенский район, поселок Черновец, 1	f	small
47358	51155	834	Курская область, Пристенский район, поселок Троицкое, Клубная, 40	f	small
47376	51174	852	Курская область, Пристенский район, поселок Средняя Ольшанка, Школьная, 51	f	small
47360	51157	836	Курская область, Пристенский район, поселок Сазановка, Школьная, 6	f	medium
47359	51156	835	Курская область, Пристенский район, поселок Ракитинка, 19	f	small
47367	51164	843	Курская область, Пристенский район, поселок Пселец, 88	f	small
47384	51182	860	Курская область, Пристенский район, поселок Пристень, Советская, 53	f	large
47383	51181	859	Курская область, Пристенский район, поселок Пристень, Советская, 49	f	large
47382	51180	858	Курская область, Пристенский район, поселок Пристень, Почтовая, 56	f	large
47362	51148	838	Курская область, Пристенский район, поселок Пристенное, Центральная, 30	f	small
47374	51172	850	Курская область, Пристенский район, поселок Прилепы, Пигоревых, 8-А	f	small
47369	51166	845	Курская область, Пристенский район, поселок Нагольное, Центральная, 17	f	small
47370	51167	846	Курская область, Пристенский район, поселок Луг, 7	t	small
47366	51163	842	Курская область, Пристенский район, поселок Красниково, Кирова, 21	f	small
47365	51162	841	Курская область, Пристенский район, поселок Котово, Центральная, 11-А	f	small
47364	51161	840	Курская область, Пристенский район, поселок Колбасовка, Центральная, 128	f	small
47380	51178	856	Курская область, Пристенский район, поселок Кировский, Ломоносова, 16	f	large
47381	51179	857	Курская область, Пристенский район, поселок Кировский, Дзержинского, 40	f	medium
47361	51158	837	Курская область, Пристенский район, поселок Ильинка, Центральная, 6-А	f	small
86442	51154	833	Курская область, Пристенский район, поселок Еринка, Центральная, 76	t	small
47373	51170	849	Курская область, Пристенский район, поселок Владимировка, Владимировская, 1	t	small
47379	51177	855	Курская область, Пристенский район, поселок Вихровский, Ватутина, 14	f	small
47378	51176	854	Курская область, Пристенский район, поселок Вихровка, Молодежная, 27	f	small
47375	51173	851	Курская область, Пристенский район, поселок Верхняя Ольшанка	f	small
47363	51160	839	Курская область, Пристенский район, поселок Большие Сети, Садовая, 9	t	small
47368	51165	844	Курская область, Пристенский район, поселок Большие Крюки, 41	f	small
47356	51153	832	Курская область, Пристенский район, поселок Бобрышево, Плант, 131/1	f	medium
47351	51147	827	Курская область, Поныровский район, поселок Становое	t	small
47341	51136	817	Курская область, Поныровский район, поселок Поныри, Октябрьская, 119	f	large
47339	51134	815	Курская область, Поныровский район, поселок Поныри, Ленина, 12	f	large
47340	51135	816	Курская область, Поныровский район, поселок Поныри, Веселая, 14	f	large
47342	51137	818	Курская область, Поныровский район, поселок Первомайское	t	small
47350	51146	826	Курская область, Поныровский район, поселок Ольховатка, помещение МКОУ Ольховатская средняя общеобразовательная школа 	f	small
47349	51145	825	Курская область, Поныровский район, поселок Нижнесмородино	f	small
47352	51149	828	Курская область, Поныровский район, поселок Игишево	f	small
47344	51140	820	Курская область, Поныровский район, поселок Горяйново	f	small
47346	51142	822	Курская область, Поныровский район, поселок Возы, Комсомольская	f	medium
47348	51144	824	Курская область, Поныровский район, поселок Верхнесмородино, помещение МКУК Верхнесмородинский сельский Дом культуры	t	small
47347	51143	823	Курская область, Поныровский район, поселок Брусовое, помещение МКУК Брусовской сельский Дом культуры) 	f	small
47345	51141	821	Курская область, Поныровский район, поселок Бобровка	f	small
47343	51139	819	Курская область, Поныровский район, поселок Березовец	f	small
47353	51150	829	Курская область, Поныровский район, поселок 2-е Поныри, Писаревка	f	medium
47354	51151	830	Курская область, Поныровский район, поселок 1-е Поныри, Майоровка	f	small
47355	51152	831	Курская область, Поныровский район, поселок 1-е Поныри, Бугровка , помещение МКОУ 1-Поныровская начальная общеобразовательная школа	f	small
47317	51112	793	Курская область, Октябрьский район, поселок Черницыно	f	large
47319	51114	795	Курская область, Октябрьский район, поселок Черницыно, Центральная	f	medium
47335	51130	811	Курская область, Октябрьский район, поселок Старково	f	small
47320	51115	796	Курская область, Октябрьский район, поселок Прямицыно, Сеймская	f	medium
47313	51108	789	Курская область, Октябрьский район, поселок Прямицыно, Первомайская	f	large
47314	51109	790	Курская область, Октябрьский район, поселок Прямицыно, Октябрьская	f	large
47315	51110	791	Курская область, Октябрьский район, поселок Прямицыно, Коммунистическая, 73	f	large
47337	51132	813	Курская область, Октябрьский район, поселок Провоторова	f	small
47326	51121	802	Курская область, Октябрьский район, поселок Плотава	f	small
47333	51128	809	Курская область, Октябрьский район, поселок Нижняя Горбулина	f	small
47318	51113	794	Курская область, Октябрьский район, поселок Нижняя Ворожба	f	small
47328	51123	804	Курская область, Октябрьский район, поселок Митрофанова	f	large
47332	51127	808	Курская область, Октябрьский район, поселок Липина	f	small
47324	51119	800	Курская область, Октябрьский район, поселок Журавлино	f	medium
47336	51131	812	Курская область, Октябрьский район, поселок Дюмина	f	small
47323	51118	799	Курская область, Октябрьский район, поселок Дьяконово, Школьная	f	large
47321	51116	797	Курская область, Октябрьский район, поселок Дьяконово, Победы	f	large
47322	51117	798	Курская область, Октябрьский район, поселок Дьяконово, Красной Звезды	f	small
47334	51129	810	Курская область, Октябрьский район, поселок Волобуево	f	small
47327	51122	803	Курская область, Октябрьский район, поселок Верхние Постоялые Дворы	f	small
47331	51126	807	Курская область, Октябрьский район, поселок Ванина	f	small
47330	51125	806	Курская область, Октябрьский район, поселок Большое Долженково	f	small
47325	51120	801	Курская область, Октябрьский район, поселок Артюховка	f	small
47316	51111	792	Курская область, Октябрьский район, деревня Анахина	f	large
47338	51133	814	Курская область, Октябрьский район, поселок Алябьева	f	small
47329	51124	805	Курская область, Октябрьский район, поселок Авдеева	f	small
47284	51078	760	Курская область, Обоянский район, поселок Шипы, Садовая, 51	t	small
47304	51098	780	Курская область, Обоянский район, поселок Шевелево, Молодежная, 17	f	small
47281	51075	757	Курская область, Обоянский район, поселок Чекмаревка, Выгон, 7	f	small
47300	51094	776	Курская область, Обоянский район, поселок Филатово, План, 43	f	small
47301	51095	777	Курская область, Обоянский район, поселок Усланка, Центральная, 9А	f	medium
47303	51097	779	Курская область, Обоянский район, поселок Трубеж, Центральная, 9А	f	medium
47296	51090	772	Курская область, Обоянский район, поселок Стрелецкое, Ленина, 189	f	medium
47298	51092	774	Курская область, Обоянский район, поселок Рыбинские Буды, Карачёвка, 32	f	medium
47295	51089	771	Курская область, Обоянский район, поселок Рудавский, Лесная, 17	f	medium
47294	51088	770	Курская область, Обоянский район, поселок Рудавец, Выгон, 33	f	small
47297	51091	773	Курская область, Обоянский район, поселок Пушкарное, Верхняя Поповка, 45	f	small
47283	51077	759	Курская область, Обоянский район, поселок Пригородный, Центральная, 3	f	medium
47293	51087	769	Курская область, Обоянский район, поселок Потопахино, Молодежная, 6	t	small
47285	51079	761	Курская область, Обоянский район, поселок Пересыпь, Тополевая, 54	f	small
47279	51073	755	Курская область, Обоянский район, поселок Пасечный, Садовая, 23	t	small
47302	51096	778	Курская область, Обоянский район, поселок Павловка, Садовая, 3	f	medium
47309	51103	785	Курская область, Обоянский район, Обоянь, Мирная, 17	f	large
47307	51101	783	Курская область, Обоянский район, Обоянь, Луначарского, 28	f	large
47310	51105	786	Курская область, Обоянский район, Обоянь, Ленина, 23	f	large
47308	51102	784	Курская область, Обоянский район, Обоянь, Ленина, 30	f	large
47306	51100	782	Курская область, Обоянский район, Обоянь, Ленина, 77	f	large
47305	51099	781	Курская область, Обоянский район, Обоянь, Ленина, 90	f	large
47271	51064	747	Курская область, Обоянский район, поселок Нижнее Солотино, Выгон, 22А	f	small
47274	51068	750	Курская область, Обоянский район, поселок Нижнее Бабино, Выгон	f	small
47292	51086	768	Курская область, Обоянский район, поселок Малые Крюки, Молодежная, 18	f	small
47290	51083	766	Курская область, Обоянский район, поселок Котельниково, Центральна, 18	f	small
46708	50534	184	Курская область, Обоянский район, поселок Косиново, Косиновская школа	f	medium
47277	51071	753	Курская область, Обоянский район, поселок Косиново, Выгон, 26	f	small
47272	51065	748	Курская область, Обоянский район, поселок Камынино, Молодежная, 22	f	small
47286	51080	762	Курская область, Обоянский район, поселок Каменка, Молодежная, 16А	f	small
47282	51066	758	Курская область, Обоянский район, поселок Зорино, Октябрьская, 106	f	large
47273	51067	749	Курская область, Обоянский район, поселок Знобиловка, Верхняя Знобиловка, 74	f	small
47291	51084	767	Курская область, Обоянский район, поселок Дрозды, Центральная, 55	f	small
47299	51093	775	Курская область, Обоянский район, поселок Долженково, Выгон, 40	f	small
47280	51074	756	Курская область, Обоянский район, поселок Гридасово, Выгон, 24	t	small
47278	51072	754	Курская область, Обоянский район, поселок Быканово, Молодежная, 15	f	small
47289	51081	765	Курская область, Обоянский район, поселок Бушмено, Выгон, 13	f	small
47287	51081	763	Курская область, Обоянский район, поселок Бушмено, Выгон, 13	f	small
47288	51082	764	Курская область, Обоянский район, поселок Бегичево, Кузьминова, 25	f	small
47276	51070	752	Курская область, Обоянский район, поселок Башкатово, Лугачевка, 2	f	small
47270	51063	746	Курская область, Обоянский район, поселок Афанасьево, Центральная, 36А	f	small
47269	51062	745	Курская область, Обоянский район, поселок Афанасьево, Центральная, 36А	f	medium
47268	51061	744	Курская область, Медвенский район, поселок Чермошное	f	medium
47254	51048	730	Курская область, Медвенский район, поселок Тарасово	f	small
47251	51044	727	Курская область, Медвенский район, поселок Спасское	f	medium
47263	51056	739	Курская область, Медвенский район, поселок Паники	f	large
47261	51055	737	Курская область, Медвенский район, поселок Нижний Реутец	f	medium
47267	51060	743	Курская область, Медвенский район, поселок Нижний Дубовец	t	small
47262	51041	738	Курская область, Медвенский район, поселок Медвенка, Советская, 30	f	small
47248	51041	724	Курская область, Медвенский район, поселок Медвенка, Советская, 30	f	large
47247	51040	723	Курская область, Медвенский район, поселок Медвенка, Промышленная, 56	f	large
86440	51050	732	Курская область, Медвенский район, поселок Любицкое	f	small
47259	51053	735	Курская область, Медвенский район, поселок Любач	f	medium
47255	51049	731	Курская область, Медвенский район, поселок Денисовка	t	small
47258	51052	734	Курская область, Медвенский район, поселок Губановка	f	small
47266	51059	742	Курская область, Медвенский район, поселок Вышний Дубовец	t	small
47265	51058	741	Курская область, Медвенский район, поселок Высоконские Дворы	f	medium
47250	51043	726	Курская область, Медвенский район, поселок Высокое	f	medium
47252	51046	728	Курская область, Медвенский район, поселок Верхний Реутец	f	medium
47249	51042	725	Курская область, Медвенский район, поселок Амосовка	f	medium
86441	51051	733	Курская область, Медвенский район, поселок 2-я Китаевка	f	small
47264	51057	740	Курская область, Медвенский район, поселок 2-е Панино	f	medium
47253	51047	729	Курская область, Медвенский район, поселок 1-я Гостомля	f	medium
47260	51054	736	Курская область, Медвенский район, поселок 1-й Липовец	f	small
47246	51039	722	Курская область, Мантуровский район, поселок Ястребовка, Мира, 95	f	medium
86439	51038	721	Курская область, Мантуровский район, поселок Стужень, Центральная, 53	f	small
47244	51038	720	Курская область, Мантуровский район, поселок Стужень, Центральная, 53	f	small
47243	51037	719	Курская область, Мантуровский район, поселок Сейм, Мира, 7а	f	large
47242	51036	718	Курская область, Мантуровский район, поселок Свинец, Центральная, 28	f	small
47241	51035	717	Курская область, Мантуровский район, поселок Роговое, Центральная, 24	f	small
47238	51032	714	Курская область, Мантуровский район, поселок Репецкая Плата, Центральная, 25	f	small
47237	51031	713	Курская область, Мантуровский район, поселок Пузачи	f	small
47236	51030	712	Курская область, Мантуровский район, поселок Останино, Центральная, 96	f	small
47235	51029	711	Курская область, Мантуровский район, поселок Мяснянка, Центральная, 37	f	small
47234	51028	710	Курская область, Мантуровский район, поселок Мантурово, Маяковского, 2а	f	large
47233	51027	709	Курская область, Мантуровский район, поселок Куськино, Центральная, 58	f	small
47232	51026	708	Курская область, Мантуровский район, поселок Крутые Верхи, Школьная, 76	f	small
47231	51025	707	Курская область, Мантуровский район, поселок Кривец, Школьная, 1	f	medium
47230	51024	706	Курская область, Мантуровский район, поселок Засеймье 2-е, Центральная, 63а	f	small
47229	51023	705	Курская область, Мантуровский район, поселок Засеймье 1-е, Школьная, 52	f	small
47228	51022	704	Курская область, Мантуровский район, поселок Заречное, Центральная, 88	f	small
47239	51033	715	Курская область, Мантуровский район, поселок Заосколье, Центральная, 39	t	small
47227	51021	703	Курская область, Мантуровский район, поселок Гущино, Школьная, 8	f	small
47226	51020	702	Курская область, Мантуровский район, поселок Большие Бутырки, Центральная, 6	f	small
47240	51034	716	Курская область, Мантуровский район, поселок Безлепкино, Садовая, 6	t	small
47177	50978	653	Курская область, Льговский район, поселок Эммануиловка	t	small
47214	51017	690	Курская область, Льговский район, поселок Шерекино	f	medium
47182	50984	658	Курская область, Льговский район, поселок Черемошки	f	small
47183	50985	659	Курская область, Льговский район, поселок Цуканово Бобрик	f	small
47213	51016	689	Курская область, Льговский район, поселок Фитиж	f	small
47204	51007	680	Курская область, Льговский район, поселок Телятниково	f	small
47179	50980	655	Курская область, Льговский район, поселок Сугрово	f	small
47184	50986	660	Курская область, Льговский район, поселок Стремоухово-Бобрик	f	small
47199	51002	675	Курская область, Льговский район, поселок Стремоуховка	t	small
47207	51010	683	Курская область, Льговский район, поселок Сергеевка	t	small
47212	51015	688	Курская область, Льговский район, поселок Селекционный	f	medium
47193	50996	669	Курская область, Льговский район, поселок Речица	t	small
47192	50995	668	Курская область, Льговский район, поселок Пригородная Слобода	f	medium
47203	51006	679	Курская область, Льговский район, поселок Полячково	f	small
47195	50998	671	Курская область, Льговский район, поселок Погореловка	f	small
47205	51008	681	Курская область, Льговский район, поселок Ольшанка	t	small
47178	50979	654	Курская область, Льговский район, поселок Нижние Деревеньки	f	medium
47209	51012	685	Курская область, Льговский район, поселок Марица	f	medium
47176	50977	652	Курская область, Льговский район, поселок Малые Угоны	t	small
47190	50992	666	Курская область, Льговский район, поселок Малеевка	f	small
47219	50857	695	Курская область, Льговский район, Льгов, Советская, 2	f	large
47223	50430	699	Курская область, Льговский район, Льгов, Свердлова, 8	f	large
47221	50970	697	Курская область, Льговский район, Льгов, М.Горького, 9	f	large
47225	50544	701	Курская область, Льговский район, Льгов, Литейная, 15	f	large
47220	50947	696	Курская область, Льговский район, Льгов, Гагарина, 14	f	large
47189	50991	665	Курская область, Льговский район, поселок Левшинка	f	small
47187	50989	663	Курская область, Льговский район, поселок Левшинка	f	small
47206	51009	682	Курская область, Льговский район, поселок Кудинцево	f	small
86438	50988	662	Курская область, Льговский район, поселок Кромские Быки	f	small
47210	51013	686	Курская область, Льговский район, поселок Красная Дубрава	f	small
47198	51001	674	Курская область, Льговский район, поселок Колонтаевка	f	small
47175	50976	651	Курская область, Льговский район, поселок Клишино	t	small
47197	51000	673	Курская область, Льговский район, поселок Износково	f	small
47202	51005	678	Курская область, Льговский район, поселок Иванчиково	t	small
47185	50987	661	Курская область, Льговский район, Деревеньки	f	small
47196	50999	672	Курская область, Льговский район, поселок Густомой, здание Густомойского ФАП	f	small
47191	50993	667	Курская область, Льговский район, поселок Городенск	f	small
47211	51014	687	Курская область, Льговский район, поселок Глиница	f	small
47180	50981	656	Курская область, Льговский район, поселок Вышние Деревеньки	f	small
47208	51011	684	Курская область, Льговский район, поселок Воронино	t	small
47194	50997	670	Курская область, Льговский район, поселок Борисовка	f	small
47174	50975	650	Курская область, Льговский район, поселок Большие Угоны	f	small
47173	50974	649	Курская область, Льговский район, поселок Большие Угоны	f	medium
86437	50983	657	Курская область, Льговский район, поселок Большая Орловка	t	small
47201	51004	677	Курская область, Льговский район, поселок Банищи	t	small
47200	51003	676	Курская область, Льговский район, поселок Банищи	f	small
47188	50990	664	Курская область, Льговский район, поселок Арсеньевка	f	small
47171	50972	647	Курская область, Курчатовский район, поселок Чапли	f	medium
47160	50960	636	Курская область, Курчатовский район, поселок Сопеловка	t	small
47161	50961	637	Курская область, Курчатовский район, поселок Новосергеевка	f	small
81917	56102	1081	Москва, Фрязевская, 7	f	large
47162	50962	638	Курская область, Курчатовский район, поселок Никольский	f	small
47163	50963	639	Курская область, Курчатовский район, поселок Николаевка	f	small
47167	50967	643	Курская область, Курчатовский район, поселок Нижнее Сосково	f	small
47170	50971	646	Курская область, Курчатовский район, поселок Мосолово	f	small
47165	50965	641	Курская область, Курчатовский район, поселок Мармыжи	f	small
86435	50968	644	Курская область, Курчатовский район, поселок Макаровка	f	small
47159	50959	635	Курская область, Курчатовский район, поселок Любицкое	f	small
47164	50964	640	Курская область, Курчатовский район, поселок Костельцево	f	small
47153	50953	629	Курская область, Курчатовский район, поселок Имени Карла Либкнехта, Свободы, 166	f	medium
47151	50951	627	Курская область, Курчатовский район, поселок Имени Карла Либкнехта, Пушкина, 6	f	large
47152	50952	628	Курская область, Курчатовский район, поселок Имени Карла Либкнехта, Красная Площадь, 44	f	medium
47148	50948	624	Курская область, Курчатовский район, поселок Имени Карла Либкнехта, Кирова, 26 А	f	medium
47147	50948	623	Курская область, Курчатовский район, поселок Имени Карла Либкнехта, Кирова, 26 А	f	large
47150	50950	626	Курская область, Курчатовский район, поселок Имени Карла Либкнехта, Захара Суворова, 4	f	medium
47155	50955	631	Курская область, Курчатовский район, поселок Иванино, площадь Антипова, 1	f	medium
47154	50954	630	Курская область, Курчатовский район, поселок Иванино, Октябрьская, 33	f	medium
47166	50966	642	Курская область, Курчатовский район, поселок Жмакино	f	small
47158	50958	634	Курская область, Курчатовский район, поселок Дружная	f	small
86436	50969	645	Курская область, Курчатовский район, поселок Дроняево	f	small
47157	50957	633	Курская область, Курчатовский район, поселок Дичня	f	large
111269	50956	632	Курская область, Курчатовский район, поселок Дичня	f	medium
47172	50973	648	Курская область, Курчатовский район, поселок Быки	f	small
47149	50949	625	Курская область, Курчатовский, поселок Имени Карла Либкнехта, Кирова, 15	f	medium
47630	51435	1106	Курская область, Курчатов городской округ, поселок Мяснянкино	t	small
47093	50895	569	Курская область, Курский район, поселок Шумаков, Брежневский сельский клуб	f	small
47090	50892	566	Курская область, Курский район, поселок Шеховцово, Шеховцовский СДК	t	small
47114	50915	590	Курская область, Курский район, поселок Черемушки, Черемушинский СДК	f	medium
47143	50944	619	Курская область, Курский район, деревня Ушаково, 36, клуб ОБОУ НПО ПУ	f	large
47092	50894	568	Курская область, Курский район, село Троица, здание Троицкой школы	f	small
47124	50925	600	Курская область, Курский район, поселок Селиховы Дворы, Селиховская средняя школа	f	medium
47109	50910	585	Курская область, Курский район, поселок Сахаровка, Клюквинская средняя школа	f	medium
47128	50929	604	Курская область, Курский район, Сапогово, Сапоговская средняя школа	f	medium
68158	50939	614	Курская область, Курский район, поселок Рышково, детская школа искусств	f	large
47094	50896	570	Курская область, Курский район, поселок Разиньково, Гнездиловская школа	f	small
47135	50936	611	Курская область, Курский район, поселок Полянское, Полянская средняя школа	f	large
47134	50935	610	Курская область, Курский район, поселок Полевая	t	large
47106	50815	582	Курская область, Курский район, поселок Подлесный, , СХПК Подлесное	f	small
47091	50893	567	Курская область, Курский район, поселок Петровское, КФХ Дружба	f	small
47115	50916	591	Курская область, Курский район, поселок Петрин, Петринский детский сад	f	medium
47122	50923	598	Курская область, Курский район, поселок Ноздрачево, Ноздрачевская школа	f	small
47146	50635	622	Курская область, Курский район, деревня Михайлово, Михайловский ФАП	f	small
47098	50900	574	Курская область, Курский район, поселок Малиновый, Отрешковская школа	f	small
47129	50930	605	Курская область, Курский район, поселок Лисово, Лисовская основная школа	f	small
47113	50914	589	Курская область, Курский район, село Лебяжье, Лебяженский сельский клуб	f	small
47133	50934	609	Курская область, Курский район, поселок Колодное, Колодненская начальная школа	f	medium
47105	50907	581	Курская область, Курский район, поселок Клюква, Клюквинский Дом культуры	f	large
82093	56215	1258	Москва, Ташкентская, 23к4с2	f	large
47132	50933	608	Курская область, Курский район, поселок Кизилово, магазин ПО Бесединское	t	small
47120	50921	596	Курская область, Курский район, поселок Касиновский, Косиновская средняя школа	f	medium
47104	50906	580	Курская область, Курский район, поселок Камыши, Камышинский районный Дом культуры	f	large
47144	50945	620	Курская область, Курский район, поселок Искра, Сапоговская средняя школа	f	large
47139	50940	615	Курская область, Курский район, деревня Зорино, Зоринский СДК	f	large
47137	50938	613	Курская область, Курский район, поселок Жеребцово, Жеребцовский Дом досуга	t	small
47096	50898	572	Курская область, Курский район, поселок Дроняево, Нижнекасиновский ФАП	t	small
46957	50760	433	Россия, Курская область, Курский район, поселок Гнездилово	f	small
47126	50927	602	Курская область, Курский район, поселок Глебово, Глебовская средняя школа	f	small
47101	50903	577	Курская область, Курский район, Ворошнево, кабинет главврача амбулатории	f	large
47100	50902	576	Курская область, Курский район, поселок Ворошнево	f	medium
47099	50901	575	Курская область, Курский район, поселок Ворошнево, Ворошневская амбулатория	f	large
47103	50905	579	Курская область, Курский район, поселок Волобуево, бывшая Волобуевская школа	t	small
47110	50911	586	Курская область, Курский район, Военный городок, 26, Дом культуры	f	large
47123	50924	599	Курская область, Курский район, поселок Виногробль, Виногробльский Дом досуга	f	small
47119	50920	595	Курская область, Курский район, поселок Верхняя Медведица	f	medium
47095	50897	571	Курская область, Курский район, поселок Верхнекасиново, Верхнекасиновская библиотека	f	small
47131	50932	607	Курская область, Курский район, поселок Верхнее Гуторово, Верхнегуторовский дом досуга	f	small
47141	50942	617	Курская область, Курский район, поселок Введенское, Коноревская основная школа	f	medium
47089	50891	565	Курская область, Курский район, поселок Букреево	t	small
47112	50913	588	Курская область, Курский район, поселок Букреевка, Лебяженская школа	t	small
47102	50904	578	Курская область, Курский район, поселок Букреевка, Букреевская школа	f	medium
47140	50941	616	Курская область, Курский район, поселок Большое Шумаково, Шумаковский СДК 	f	medium
86434	50937	612	Курская область, Курский район, поселок Большое Лукино, Полянская средняя школа	t	small
47088	50890	564	Курская область, Курский район, поселок Беседино	f	large
47111	50912	587	Курская область, Курский район, поселок Безлесное 2-е, Безлесенский сельский клуб	t	small
47130	50931	606	Курская область, Курский район, поселок Барышниково, Барышниковский СДК	f	small
47087	50889	563	Курская область, Курский район, поселок Алябьево	t	small
47127	50928	603	Курская область, Курский район, поселок 1-е Курасово, Курасовская основная школа	f	small
47097	50899	573	Курская область, Курский район, поселок 1-е Винниково, Винниковский СДК	t	medium
47086	50888	562	Курская область, Кореневский район, поселок Шептуховка	f	medium
47065	50868	541	Курская область, Кореневский район, поселок Троицкое	f	small
47082	50884	558	Курская область, Кореневский район, поселок Толпино	f	medium
47078	50881	554	Курская область, Кореневский район, поселок Снагость	f	small
47085	50887	561	Курская область, Кореневский район, поселок Сафоновка	t	small
47077	50880	553	Курская область, Кореневский район, поселок Пушкарное	f	medium
47075	50878	551	Курская область, Кореневский район, поселок Ольговка	f	medium
47072	50875	548	Курская область, Кореневский район, поселок Обуховка	t	small
47081	50883	557	Курская область, Кореневский район, поселок Нижняя Груня	f	small
47071	50874	547	Курская область, Кореневский район, поселок Любимовка	f	small
47073	50876	549	Курская область, Кореневский район, поселок Кремяное	f	medium
47079	50669	555	Курская область, Кореневский район, поселок Краснооктябрьское	f	small
46850	50650	326	Курская область, Кореневский район, поселок Краснооктябрьское, 27	t	small
47069	50872	545	Курская область, Кореневский район, поселок Коренево	f	medium
47068	50871	544	Курская область, Кореневский район, поселок Коренево	f	medium
86433	50873	546	Курская область, Кореневский район, поселок Коренево, Юбилейная, 24	t	small
47060	50863	536	Курская область, Кореневский район, поселок Коренево, Октябрьская, 49	f	large
47062	50865	538	Курская область, Кореневский район, поселок Коренево, Ленина, 50	f	large
47061	50864	537	Курская область, Кореневский район, поселок Коренево, 70 лет Октября, 12	f	large
47066	50869	542	Курская область, Кореневский район, поселок Комаровка	f	small
47084	50886	560	Курская область, Кореневский район, поселок Каучук	f	small
47074	50877	550	Курская область, Кореневский район, поселок Журавли	f	small
47064	50867	540	Курская область, Кореневский район, поселок Гордеевка	t	small
47063	50866	539	Курская область, Кореневский район, поселок Внезапное	f	small
47080	50882	556	Курская область, Кореневский район, поселок Верхняя Груня	f	small
47076	50879	552	Курская область, Кореневский район, поселок Благодатное	f	small
47067	50870	543	Курская область, Кореневский район, поселок Апанасовка	f	small
47083	50885	559	Курская область, Кореневский район, поселок Александровка	t	small
47044	50845	520	Курская область, Конышевский район, поселок Яцено	f	small
47045	50846	521	Курская область, Конышевский район, поселок Яндовище	f	small
47054	50856	530	Курская область, Конышевский район, поселок Шустово	f	small
47057	50860	533	Курская область, Конышевский район, поселок Ширково	f	small
47034	50835	510	Курская область, Конышевский район, поселок Черничено	f	small
47056	50859	532	Курская область, Конышевский район, поселок Толкачевка, здание МКОУ Толкачевская основная общеобразовательная школа, классная комната	f	small
47058	50861	534	Курская область, Конышевский район, поселок Старая Белица	t	small
47040	50841	516	Курская область, Конышевский район, поселок Севенки	f	small
47036	50837	512	Курская область, Конышевский район, поселок Рыжково	f	small
47055	50858	531	Курская область, Конышевский район, поселок Прилепы	f	small
47052	50854	528	Курская область, Конышевский район, поселок Платава	t	small
47033	50834	509	Курская область, Конышевский район, поселок Нижнее Песочное	f	small
47047	50849	523	Курская область, Конышевский район, поселок Наумовка	f	small
47043	50844	519	Курская область, Конышевский район, поселок Машкино	f	small
47046	50848	522	Курская область, Конышевский район, поселок Мармыжи	f	small
47041	50842	517	Курская область, Конышевский район, поселок Малое Городьково	f	small
47032	50833	508	Курская область, Конышевский район, поселок Малахово	f	small
47050	50852	526	Курская область, Конышевский район, поселок Макарово-Петровское	f	small
47030	50831	506	Курская область, Конышевский район, поселок Конышевка, 50 лет Советской власти, 6	f	large
47029	50830	505	Курская область, Конышевский район, Конышевка, 50 лет Советской власти, 7	f	large
47051	50853	527	Курская область, Конышевский район, поселок Кашара	t	small
47038	50839	514	Курская область, Конышевский район, поселок Захарково, кабинет	f	small
47037	50838	513	Курская область, Конышевский район, поселок Жигаево	f	small
47039	50840	515	Курская область, Конышевский район, поселок Дремово-Черемошки	f	small
47053	50855	529	Курская область, Конышевский район, поселок Гряды	t	small
47042	50843	518	Курская область, Конышевский район, поселок Глазово	f	small
47049	50851	525	Курская область, Конышевский район, поселок Верхняя Соковинка	f	small
47048	50850	524	Курская область, Конышевский район, поселок Васильевка	f	small
47035	50836	511	Курская область, Конышевский район, поселок Вабля	f	small
47031	50832	507	Курская область, Конышевский район, поселок Беляево	f	small
47059	50862	535	Курская область, Конышевский район, поселок Арбузово	t	small
47020	50820	496	Курская область, Касторенский район, поселок Успено-Раевка, 58	t	small
47028	50829	504	Курская область, Касторенский район, поселок Успенка, 8	f	medium
47018	50818	494	Курская область, Касторенский район, поселок Суковкино, Училищный переулок, 2	f	small
47006	50805	482	Курская область, Касторенский район, поселок Семеновский, Заречная, 22	t	small
47025	50825	501	Курская область, Касторенский район, поселок Семеновка, 3	f	small
47003	50756	479	Курская область, Касторенский район, поселок Раздолье, Центральная, 78	t	small
47012	50811	488	Курская область, Касторенский район, поселок Погожево	t	small
47023	50823	499	Курская область, Касторенский район, поселок Орехово, Центральная, 47	f	medium
47000	50801	476	Курская область, Касторенский район, поселок Олымский, Садовая, 37	f	large
47001	50802	477	Курская область, Касторенский район, поселок Олымский, 20 лет Победы, 4	f	large
47017	50817	493	Курская область, Касторенский район, поселок Олым, 16	f	small
46998	50799	474	Курская область, Касторенский район, поселок Новокасторное, Сварочный пер., 7	t	medium
46999	50800	475	Курская область, Касторенский район, поселок Новокасторное, Железнодорожная, 42, здание культурного центра досуга Эдельвейс	f	large
47016	50816	492	Курская область, Касторенский район, поселок Новодворский, Школьная, 31	f	small
47022	50822	498	Курская область, Касторенский район, поселок Никольско-Ключевская, 8	t	small
47027	50828	503	Курская область, Касторенский район, поселок Мелавка, Молодежная, 1	t	small
111273	51204	879	Курская область, Касторенский район, поселок Марьино, Кооперативная, 2, здание Марьинского, Дома культуры	f	\N
47021	50821	497	Курская область, Касторенский район, поселок Ленинский, 44	f	small
47019	50819	495	Курская область, Касторенский район, поселок Лачиново, 17	f	small
47014	50813	490	Курская область, Касторенский район, поселок Красная Долина, 23	f	small
47011	50810	487	Курская область, Касторенский район, поселок Котовка, 15	t	medium
46995	50796	471	Курская область, Касторенский район, поселок Касторное, Ленина, 138	f	medium
46997	50798	473	Курская область, Касторенский район, поселок Касторное, Буденного, 36	f	medium
46996	50797	472	Курская область, Касторенский район, поселок Касторное, 50 лет Октября, 4	f	large
47010	50809	486	Курская область, Касторенский район, поселок Жерновец, 8	f	small
47008	50807	484	Курская область, Касторенский район, поселок Егорьевка, Заречная, 6	f	small
47024	50824	500	Курская область, Касторенский район, поселок Горяиново, Центральная, 30	t	small
47009	50808	485	Курская область, Касторенский район, поселок Вознесеновка, Центральная, 20	f	small
47026	50826	502	Курская область, Касторенский район, поселок Верхотопье, Центральная, 2	t	small
47007	50806	483	Курская область, Касторенский район, поселок Верхняя Грайворонка	t	small
47015	50814	491	Курская область, Касторенский район, поселок Бычок, Школьная, 4	t	small
47013	50812	489	Курская область, Касторенский район, поселок Белогорье	f	small
47004	50792	480	Курская область, Касторенский район, поселок Андреевка, 73	t	small
47005	50804	481	Курская область, Касторенский район, поселок Андреевка, Центральная, 25А	t	small
47002	50803	478	Курская область, Касторенский район, поселок Александровский, 15	f	medium
46980	50782	456	Курская область, Золотухинский район, поселок Фентисово, 61	f	small
46993	50794	469	Курская область, Золотухинский район, поселок Тазово, Мирная, 79	f	small
46990	50790	466	Курская область, Золотухинский район, Солнечный, 3	f	large
46991	50791	467	Курская область, Золотухинский район, поселок Солнечный, Молодежная, 3	f	medium
46974	50776	450	Курская область, Золотухинский район, поселок Сергеевское	f	small
46962	50765	438	Курская область, Золотухинский район, поселок Сергеевка, Луговая, 12	f	small
46964	50767	440	Курская область, Золотухинский район, поселок Седмиховка, Шевелева С.Н., 4	f	small
46987	50787	463	Курская область, Золотухинский район, местечко Свобода, Советская, 42	f	medium
46988	50788	464	Курская область, Золотухинский район, поселок Свобода, 2	f	large
46979	50781	455	Курская область, Золотухинский район, поселок Революционное, 45	f	small
46989	50789	465	Курская область, Золотухинский район, поселок Никулино, 182	f	small
46994	50795	470	Курская область, Золотухинский район, поселок Никольское, 77а 	f	small
46968	50770	444	Курская область, Золотухинский район, поселок Кузьминка, 25	t	small
46975	50777	451	Курская область, Золотухинский район, поселок Конево 2-е	f	small
46960	50763	436	Курская область, Золотухинский район, поселок Казанка 2-я, Школьная, 19	f	small
46984	50784	460	Курская область, Золотухинский район, поселок Золотухино, Ленина, 15	f	large
46983	50784	459	Курская область, Золотухинский район, поселок Золотухино, Ленина, 15	f	medium
46982	50783	458	Курская область, Золотухинский район, поселок Золотухино, Ленина, 14	f	medium
46981	50779	457	Курская область, Золотухинский район, поселок Золотухино, Железнодорожная, 68	f	large
46977	50779	453	Курская область, Золотухинский район, поселок Золотухино, Железнодорожная, 68	f	small
44919	42896	226	Костромская область, Кострома, Линейная, 11	f	large
46973	50775	449	Курская область, Золотухинский район, поселок Зиборово, Садовая, 21	f	small
46992	50793	468	Курская область, Золотухинский район, поселок Жерновец, 49	f	medium
46978	50780	454	Курская область, Золотухинский район, поселок Донское, 47	t	small
46972	50774	448	Курская область, Золотухинский район, поселок Дмитриевка, 69	f	small
46986	50786	462	Курская область, Золотухинский район, поселок Дерлово	t	small
46971	50773	447	Курская область, Золотухинский район, поселок Демякино, 49	f	small
46970	50772	446	Курская область, Золотухинский район, поселок Гремячка, 11	t	small
46969	50771	445	Курская область, Золотухинский район, поселок Воробьевка 1-я	f	small
46963	50766	439	Курская область, Золотухинский район, поселок Верентиново 1-е, 2	t	small
46967	50769	443	Курская область, Золотухинский район, поселок Будановка, Советская, 21	f	medium
46966	50769	442	Курская область, Золотухинский район, поселок Будановка, Советская, 21	f	medium
46976	50778	452	Курская область, Золотухинский район, поселок Боево, 92	t	medium
46961	50764	437	Курская область, Золотухинский район, поселок Белый Колодезь	t	small
46965	50768	441	Курская область, Золотухинский район, поселок Апальково, 115	f	small
46985	50785	461	Курская область, Золотухинский район, поселок 1-е Новоспасское, Молодежная, 2	t	medium
46953	50714	429	Курская область, Железногорский район, поселок Фоминка	t	small
46959	50762	435	Курская область, Железногорский район, поселок Трояново	t	small
46956	50759	432	Курская область, Железногорский район, поселок Троицкое	f	small
46950	50753	426	Курская область, Железногорский район, Тепличный	f	medium
46955	50758	431	Курская область, Железногорский район, поселок Студенок	f	large
46958	50761	434	Курская область, Железногорский район, поселок Старый Бузец	f	small
86432	50757	430	Курская область, Железногорский район, поселок Снецкое	f	small
46952	50755	428	Курская область, Железногорский район, поселок Рышково	f	small
46949	50752	425	Курская область, Железногорский район, поселок Разветье	f	small
46939	50743	415	Курская область, Железногорский район, поселок Пасерково, МК-76	t	small
46935	50739	411	Курская область, Железногорский район, поселок Остапово	t	small
46948	50751	424	Курская область, Железногорский район, Новоандросово	f	medium
46947	50750	423	Курская область, Железногорский район, поселок Нижнее Жданово	f	small
46946	50749	422	Курская область, Железногорский район	f	large
46945	50749	421	Курская область, Железногорский район	f	large
46933	50737	409	Курская область, Железногорский район, поселок Магнитный	f	large
46944	50748	420	Курская область, Железногорский район, поселок Линец	f	medium
46943	50747	419	Курская область, Железногорский район, поселок Копенки	f	small
46951	50754	427	Курская область, Железногорский район, поселок Клишино	f	small
46941	50745	417	Курская область, Железногорский район, поселок Карманово	f	medium
46942	50746	418	Курская область, Железногорский район, поселок Злобино	f	small
46743	50563	219	Курская область, Железногорский район, Железногорск, Мира, 50	f	large
46940	50744	416	Курская область, Железногорский район, поселок Городное	t	small
46938	50742	414	Курская область, Железногорский район, поселок Волково	f	small
46937	50741	413	Курская область, Железногорский район, поселок Веретенино	f	medium
46936	50740	412	Курская область, Железногорский район, поселок Басово Заречье	f	small
46934	50738	410	Курская область, Железногорский район, поселок Андросово	t	small
46922	50725	398	Курская область, Дмитриевский район, поселок Черневка	f	small
46932	50736	408	Курская область, Дмитриевский район, поселок Харасея	f	small
46912	50715	388	Курская область, Дмитриевский район, поселок Фокино	f	small
46929	50732	405	Курская область, Дмитриевский район, поселок Фатеевка	f	small
46930	50733	406	Курская область, Дмитриевский район, поселок Старый Город	f	medium
46917	50720	393	Курская область, Дмитриевский район, поселок Снижа	f	small
46928	50731	404	Курская область, Дмитриевский район, поселок Селино	f	small
46927	50730	403	Курская область, Дмитриевский район, поселок Почепное	f	small
46923	50726	399	Курская область, Дмитриевский район, поселок Поповкино	f	small
46926	50729	402	Курская область, Дмитриевский район, поселок Погодино	f	small
46916	50719	392	Курская область, Дмитриевский район, поселок Петраковка	t	small
46919	50722	395	Курская область, Дмитриевский район, поселок Первоавгустовский, Рабочая, 11	f	medium
46918	50721	394	Курская область, Дмитриевский район, поселок Первоавгустовский, Комсомольская, 38	f	medium
46910	50712	386	Курская область, Дмитриевский район, поселок Пальцево	f	small
46921	50724	397	Курская область, Дмитриевский район, поселок Неварь	f	small
46909	50711	385	Курская область, Дмитриевский район, поселок Моршнево	t	small
46925	50728	401	Курская область, Дмитриевский район, поселок Меловое	f	small
46913	50716	389	Курская область, Дмитриевский район, поселок Куток	f	small
46911	50713	387	Курская область, Дмитриевский район, поселок Крупец	t	large
46915	50718	391	Курская область, Дмитриевский район, поселок Красная Дубрава	f	small
46924	50727	400	Курская область, Дмитриевский район, поселок Коробкино	f	small
46907	50709	383	Курская область, Дмитриевский район, Дмитриев-Льговский, Промышленная, 2	f	large
46906	50708	382	Курская область, Дмитриевский район, Дмитриев-Льговский, Ленина , 64, (здание МБУК Дмитриевский районный Дом культуры	f	large
46905	50707	381	Курская область, Дмитриевский район, Дмитриев-Льговский, Володарского , 37, здание МБОУ Средняя общеобразовательная, школа №2	f	large
46904	50706	380	Курская область, Дмитриевский район, Дмитриев, просп. Советских Космонавтов, здание МБОУ Средняя, общеобразовательная школа №1, 2	f	large
46908	50710	384	Курская область, Дмитриевский район, поселок Дерюгино	f	small
46914	50717	390	Курская область, Дмитриевский район, поселок Генеральшино	f	small
46920	50723	396	Курская область, Дмитриевский район, поселок Бычки	t	small
46931	50734	407	Курская область, Дмитриевский район, поселок Береза	t	small
46902	50704	378	Курская область, Горшеченский район, поселок Ясенки, 128	f	medium
46900	50702	376	Курская область, Горшеченский район, поселок Улобное, Новая, 6	f	small
46887	50689	363	Курская область, Горшеченский район, поселок Старомеловое, Колхозная, 151	f	small
46896	50698	372	Курская область, Горшеченский район, поселок Средние Апочки, Советская, 6а	f	small
86431	50696	370	Курская область, Горшеченский район, поселок Среднедорожное, Центральная	f	small
46888	50690	364	Курская область, Горшеченский район, поселок Сосновка, переулок Школьный, 14	f	medium
46890	50692	366	Курская область, Горшеченский район, поселок Солдатское, Парковый переулок 	f	small
46880	50682	356	Курская область, Горшеченский район, поселок Ржавец, Первомайская, 2	t	small
46889	50691	365	Курская область, Горшеченский район, поселок Петровка, Школьный переулок, 1	t	small
46875	50676	351	Курская область, Горшеченский район, поселок Отрада, Комсомольская	t	small
46886	50688	362	Курская область, Горшеченский район, поселок Новомеловое, Центральная, 61	f	medium
46885	50687	361	Курская область, Горшеченский район, поселок Никольское, Школьная, здание Администрации	f	small
46881	50683	357	Курская область, Горшеченский район, поселок Нижние Борки	f	small
46882	50684	358	Курская область, Горшеченский район, поселок Мокрец, Школьная, 15	t	small
46892	50694	368	Курская область, Горшеченский район, поселок Максимовка, Молодежная	f	small
46878	50679	354	Курская область, Горшеченский район, поселок Кунье, Советская, 51	t	small
46903	50705	379	Курская область, Горшеченский район, поселок Кулевка, Школьная, 34	f	small
46877	50678	353	Курская область, Горшеченский район, поселок Ключ, Центральная, 17б	f	small
46901	50703	377	Курская область, Горшеченский район, поселок Ивановка, Юбилейная, 103	t	small
46876	50677	352	Курская область, Горшеченский район, поселок Знаменка, Полевая, 19	f	small
46899	50701	375	Курская область, Горшеченский район, поселок Залесье, Центральная	f	small
46871	50672	347	Курская область, Горшеченский район, поселок Горшечное, переулок Больничный, 3	f	large
46869	50670	345	Курская область, Горшеченский район, поселок Горшечное, Центральная, 24	f	large
46870	50671	346	Курская область, Горшеченский район, поселок Горшечное, Октябрьская, 9	f	large
46868	50668	344	Курская область, Горшеченский район, поселок Горшечное, Кирова, 7	f	large
46895	50697	371	Курская область, Горшеченский район, поселок Головище, Почтовая, 1а	f	small
82092	56215	1257	Москва, Ташкентская, 23к4с2	f	large
46884	50686	360	Курская область, Горшеченский район, поселок Вислое, Светлая, 2	f	small
46874	50675	350	Курская область, Горшеченский район, поселок Быково, Школьная, 33	f	small
46893	50695	369	Курская область, Горшеченский район, поселок Боровка, Советская	t	small
46883	50685	359	Курская область, Горшеченский район, поселок Болото, Раздольная, 1	f	small
46872	50673	348	Курская область, Горшеченский район, поселок Богородицкое, Маяковского, 1	f	small
46873	50674	349	Курская область, Горшеченский район, поселок Богатырево	f	small
46897	50699	373	Курская область, Горшеченский район, поселок Белгородка, Полевая	f	small
46891	50693	367	Курская область, Горшеченский район, поселок Бекетовский, Заводская	t	small
46879	50680	355	Курская область, Горшеченский район, поселок Бараново, Лихачева, 32	f	small
46867	50667	343	Курская область, Глушковский район, поселок Ходяковка, бывший Ходяковский филиал МОУ Сухиновская СОШ 	f	small
46846	50647	322	Курская область, Глушковский район, поселок Теткино, Урицкого, 114	f	large
46847	50623	323	Курская область, Глушковский район, поселок Теткино, Ленина, 112	f	large
46845	50646	321	Курская область, Глушковский район, поселок Теткино, Коммунальная, 3	f	large
46866	50666	342	Курская область, Глушковский район, поселок Сухиновка, Советская, 2	f	medium
86430	50663	339	Курская область, Глушковский район, поселок Ржава, Первомайская, 17г	t	small
46865	50665	341	Курская область, Глушковский район, поселок Попово-Лежачи, Осипенко, 137	t	medium
46857	50657	333	Курская область, Глушковский район, поселок Политотдельский, 1, Политотдельский филиал №2 МКОУ Кульбакинская СОШ	t	small
46862	50662	338	Курская область, Глушковский район, поселок Нижний Мордок, 42а, Кекинская сельская библиотека	t	small
46861	50661	337	Курская область, Глушковский район, поселок Нижний Мордок, Школьный переулок, 2	f	small
46859	50659	335	Курская область, Глушковский район, поселок Марково, Школьная, 22	f	medium
46852	50652	328	Курская область, Глушковский район, поселок Лещиновка, Школьная, Лещиновская СОШ	f	small
46856	50656	332	Курская область, Глушковский район, поселок Кульбаки, 339, МКОУ Кульбакинская СОШ	f	large
46855	50655	331	Курская область, Глушковский район, поселок Коровяковка, Ленина, 58	f	medium
46854	50654	330	Курская область, Глушковский район, поселок Кобылки, Средняя, 39	f	medium
46853	50653	329	Курская область, Глушковский район, поселок Карыж, Сеймовая, 39	f	medium
46851	50651	327	Курская область, Глушковский район, поселок Званное, Центральная, 71а	f	large
46858	50658	334	Курская область, Глушковский район, поселок Елизаветовка, 80, Елизаветовский филиал №1 МКОУ Кульбакинская СОШ	f	small
46860	50660	336	Курская область, Глушковский район, поселок Дроновка, 29б, Дроновский филиал МКОУ Марковская СОШ	f	small
46844	50645	320	Курская область, Глушковский район, поселок Глушково, Советская, 59	f	large
46842	50643	318	Курская область, Глушковский район, поселок Глушково, М.Горького, 11	f	large
46843	50644	319	Курская область, Глушковский район, поселок Глушково, Ленина, 88	f	large
46864	50664	340	Курская область, Глушковский район, поселок Высокое, 59а, филиал МКОУ Нижнемордокская СОШ	t	small
46849	50649	325	Курская область, Глушковский район, поселок Веселое, Советская, 2	f	medium
86429	50648	324	Курская область, Глушковский район, поселок Алексеевка, Ленина, 82	f	small
46824	50624	300	Курская область, Большесолдатский район, поселок Шербачевка	t	small
46841	50642	317	Курская область, Большесолдатский район, поселок Шелеповка	t	small
46839	50640	315	Курская область, Большесолдатский район, поселок Сторожевое	f	small
46833	50633	309	Курская область, Большесолдатский район, поселок Скородное	f	small
46836	50637	312	Курская область, Большесолдатский район, поселок Саморядово	f	small
86428	50622	299	Курская область, Большесолдатский район, поселок Первомайская, Первомайская	f	small
46834	50634	310	Курская область, Большесолдатский район, поселок Нижнее Гридино	f	medium
46820	50619	296	Курская область, Большесолдатский район, поселок Махов Колодезь	t	small
46840	50641	316	Курская область, Большесолдатский район, поселок Малый Каменец	f	small
46831	50631	307	Курская область, Большесолдатский район, поселок Любостань, Мира, 9	f	small
44930	43845	237	Костромская область, Кострома, Ленина, 149	f	large
46828	50628	304	Курская область, Большесолдатский район, поселок Любимовка	f	large
46832	50632	308	Курская область, Большесолдатский район, поселок Леоновка	t	small
46835	50636	311	Курская область, Большесолдатский район, поселок Извеково, МКОУ Извековская основная ОШ	f	small
46830	50630	306	Курская область, Большесолдатский район, поселок Долгий	t	small
47275	51069	751	Курская область, Большесолдатский район, поселок Вышнее Бабино, Бугряновка, 21	f	small
46825	50625	301	Курская область, Большесолдатский район, поселок Волоконск	f	medium
46838	50639	314	Курская область, Большесолдатский район, поселок Будище	f	small
46826	50626	302	Курская область, Большесолдатский район, поселок Борщень	f	small
46827	50627	303	Курская область, Большесолдатский район, поселок Борщень, Школьная, 1	f	small
46818	50617	294	Курская область, Большесолдатский район, поселок Большое Солдатское, Советская, 49	f	large
46819	50618	295	Курская область, Большесолдатский район, поселок Большое Солдатское, Кооперативная, 136	f	medium
46822	50621	298	Курская область, Большесолдатский район, Большесолдатский сельсовет, деревня Ржава, Здание МКОУ Ржавская основная ОШ	f	small
46837	50638	313	Курская область, Большесолдатский район, поселок Бирюковка	t	small
46829	50629	305	Курская область, Большесолдатский район, поселок 1-я Касторная	f	small
46817	50616	293	Курская область, Беловский район, поселок Щеголек, Щеголянский дом культуры	f	small
46793	50591	269	Курская область, Беловский район, поселок Суходол, Суходольский дом досуга	f	small
46813	50612	289	Курская область, Беловский район, поселок Слободка-Корочка	t	small
46805	50603	281	Курская область, Беловский район, поселок Петровы Буды, Петровобудский сельский дом культуры 	t	small
46816	50615	292	Курская область, Беловский район, поселок Песчаное, Песчанский сельский дом культуры	f	medium
46815	50614	291	Курская область, Беловский район, поселок Пены, Пенский сельский дом культуры	f	medium
46791	50589	267	Курская область, Беловский район, поселок Пенский, Октябрьский сельский дом культуры	f	small
46809	50607	285	Курская область, Беловский район, поселок Озерки	t	small
46803	50601	279	Курская область, Беловский район, поселок Мокрушино, Мокрушанская средняя общеобразовательная школа	f	medium
46814	50613	290	Курская область, Беловский район, поселок Малое Солдатское, Малосолдатский сельский дом культуры	f	medium
46790	50588	266	Курская область, Беловский район, поселок Лошаковка, Лошаковский дом досуга	f	small
46808	50606	284	Курская область, Беловский район, хутор Кучеров, Учебный корпус Кучеровского сельскохозяйственного техникума	f	small
46799	50597	275	Курская область, Беловский район, поселок Крупец, Крупецкая неполная средняя школа	f	small
46801	50599	277	Курская область, Беловский район, поселок Кривицкие Буды, Кривицко-Будская основная общеобразовательная школа	t	small
46811	50609	287	Курская область, Беловский район, поселок Корочка, Корочанский сельский дом культуры	f	small
46806	50604	282	Курская область, Беловский район, поселок Кондратовка, Кондратовский дом культуры 	f	small
46804	50602	280	Курская область, Беловский район, поселок Коммунар, Коммунаровский сельский дом культуры	f	large
46798	50596	274	Курская область, Беловский район, поселок Камышное, Камышанский сельский дом культуры	f	small
46802	50600	278	Курская область, Беловский район, поселок Илек, Ильковская средняя общеобразовательная школа	f	small
46810	50608	286	Курская область, Беловский район, поселок Забужевка, Забужанский дом досуга	t	small
46812	50610	288	Курская область, Беловский район, поселок Долгий Колодезь, Долго-Колодезьская начальная школа	t	small
46800	50598	276	Курская область, Беловский район, поселок Долгие Буды, Долгобудский дом культуры	f	medium
46795	50593	271	Курская область, Беловский район, поселок Гочево, Гочевский дом досуга	t	small
46807	50605	283	Курская область, Беловский район, поселок Гоптаровка, Гоптаровская основная общеобразовательная школа	t	small
46797	50595	273	Курская область, Беловский район, поселок Гирьи, Гирьянская средняя общеобразовательная школа	f	large
46796	50594	272	Курская область, Беловский район, поселок Вишнево, Вишневский дом культуры 	f	medium
82088	56212	1253	Москва, Ташкентская, 26к2с1	f	large
46794	50592	270	Курская область, Беловский район, поселок Бобрава, Бобравский сельский дом культуры	f	medium
46792	50590	268	Курская область, Беловский район, поселок Белица, Беличанский сельский дом культуры	f	medium
46789	50586	265	Курская область, Беловский район, поселок Белая, площадь Советская, Беловский центр культуры и досуга	f	large
45249	44142	556	Костромская область, Шарья, имени хирурга Крылова, 9	f	large
45248	44141	555	Костромская область, Шарья, имени хирурга Крылова, 5	f	large
45254	44147	561	Костромская область, Шарья, Фурманова, 64	f	large
45240	44133	547	Костромская область, Шарья, Сергея Громова, 44	f	large
45244	44137	551	Костромская область, Шарья, Полярников, 4	f	large
45242	44135	549	Костромская область, Шарья, П. Морозова, 15	f	large
45243	44136	550	Костромская область, Шарья, Октябрьская, 17	f	large
45239	44132	546	Костромская область, Шарья, Куйбышева, 43	f	large
45238	44132	545	Костромская область, Шарья, Куйбышева, 43	f	large
45245	44138	552	Костромская область, Шарья, Ивана Шатрова, 10	f	large
45241	44134	548	Костромская область, Шарья городской округ, Адмирала Виноградова, 21Б	f	large
45247	44140	554	Костромская область, Шарья, 50 лет Советской власти, 9	f	large
45124	44020	432	Костромская область, Нея, П. Морозова, 1	f	small
45142	44037	449	Костромская область, Нерехта, площадь 30-лет Победы, 5 , ДК фойе	f	large
45135	44030	442	Костромская область, Нерехта, Школьная, 1	f	large
45137	44032	444	Костромская область, Нерехта, Чкалова, 12	f	large
45131	44053	465	Костромская область, Нерехта, ПМК-1, 10	f	small
45140	44035	447	Костромская область, Нерехта, Октябрьская, 2А	f	large
45134	44029	441	Костромская область, Нерехта, Ленина, 28А	f	large
45136	44031	443	Костромская область, Нерехта, Красноармейская, 101	f	large
45138	44033	445	Костромская область, Нерехта, К. Маркса,, 5	f	large
45143	44022	450	Костромская область, Нерехта, Дружбы, 13а	f	large
45141	44036	448	Костромская область, Нерехта, 30-лет Победы, 5, ДК конференцзал	f	large
45139	44034	446	Костромская область, Нерехта, К. Либкнехта, 2	f	large
45082	43980	389	Костромская область, Мантурово , Гвардейская, 5	f	large
134450	94351	633	Костромская область, Мантурово, Юбилейная , 16А, Центр детского творчества	f	large
45092	43989	398	Костромская область, Мантурово, Советская, 141	f	large
45088	43982	391	Костромская область, Мантурово, Советская, 9	f	large
45083	43981	390	Костромская область, Мантурово, Советская, 100	f	large
45087	43985	394	Костромская область, Мантурово, Нагорная, 18	f	large
45086	43984	393	Костромская область, Мантурово, Ленина, 2Б	f	medium
45090	43988	397	Костромская область, Мантурово, Вокзальная, 100	f	large
45045	43942	352	Костромская область, Макарьев, пер. Полевой, 14 а	f	large
45153	44048	460	Костромская область, Лаврово, Школьная, 2	f	medium
44907	43830	214	Костромская область, Кострома, улица Юных Пионеров, 4	f	large
44956	43868	263	Костромская область, Кострома, улица Шагова, 201	f	large
45350	44166	480	Костромская область, Кострома, улица Совхозная, 27	f	small
44928	43843	235	Костромская область, Кострома, улица Ленина, 161	f	large
44925	43839	232	Костромская область, Кострома, улица Ленина, 84	f	large
44922	43839	229	Костромская область, Кострома, улица Ленина, 84	f	large
44845	43767	152	Костромская область, Кострома, улица Клубная, 1Б	f	small
44924	43840	231	Костромская область, Кострома, улица Задорина, 57	f	large
44923	43840	230	Костромская область, Кострома, улица Задорина, 57	f	large
45010	43908	317	Костромская область, Кострома, улица Голубкова, 15	f	large
44913	43588	220	Костромская область, Кострома, улица Борьбы, 50	f	large
44915	43588	222	Костромская область, Кострома, улица Борьбы, 50	f	large
44937	42954	244	Костромская область, Кострома, улица Беговая, 4а	f	medium
44909	43832	216	Костромская область, Кострома, проспект Текстильщиков, 73	f	large
45013	43910	320	Костромская область, Кострома, проезд Библиотечный, 17	f	large
45000	43902	307	Костромская область, Кострома, проезд Березовый, 2	f	large
44933	43847	240	Костромская область, Кострома, мкр Новый, 9	f	large
45008	43903	315	Костромская область, Кострома, микрорайон Паново, 9	f	large
45002	43903	309	Костромская область, Кострома, микрорайон Паново, 9	f	large
44926	43841	233	Костромская область, Кострома, м/н Якиманиха, 19	f	large
44981	43885	288	Костромская область, Кострома, м/н Юбилейный, 24а	f	large
44979	43883	286	Костромская область, Кострома, м/н Юбилейный, 12	f	large
44984	43887	291	Костромская область, Кострома, м/н Черноречье, 23	f	large
44983	43887	290	Костромская область, Кострома, м/н Черноречье, 23	f	large
44988	43886	295	Костромская область, Кострома, м/н Черноречье, 2	f	large
44982	43886	289	Костромская область, Кострома, м/н Черноречье, 2	f	large
45006	43905	313	Костромская область, Кострома, м/н Паново, 12	f	large
45005	43905	312	Костромская область, Кострома, м/н Паново, 12	f	large
45004	43905	311	Костромская область, Кострома, м/н Паново, 12	f	large
44974	43879	281	Костромская область, Кострома, м/н Давыдовский-2, 19	f	large
44973	43879	280	Костромская область, Кострома, м/н Давыдовский-2, 19	f	large
44977	43882	284	Костромская область, Кострома, м/н Давыдовский-1, 32	f	large
44978	43882	285	Костромская область, Кострома, м/н Давыдовский-1, 32	f	large
44980	43884	287	Костромская область, Кострома, м-н Юбилейный, 10	f	large
44921	43838	228	Костромская область, Кострома, квартал 3, 27	f	medium
45016	43913	323	Костромская область, Кострома, Юрия Беленогова, 23а	f	large
44986	43889	293	Костромская область, Кострома, Юношеская, 35	f	large
44950	43861	257	Костромская область, Кострома, Шагова, 201	f	large
44948	43861	255	Костромская область, Кострома, Шагова, 201	f	large
44942	43855	249	Костромская область, Кострома, Шагова, 61а	f	large
44940	43853	247	Костромская область, Кострома, Шагова, 9	f	large
44939	43852	246	Костромская область, Кострома, Шагова, 61	f	large
44965	43873	272	Костромская область, Кострома, Центральная, 50	f	large
44963	43873	270	Костромская область, Кострома, Центральная, 50	f	large
44724	43650	29	Костромская область, Кострома, Центральная, 2, д. Большой Дор,	f	small
45007	43906	314	Костромская область, Кострома, Фрунзе, 5	f	large
44955	43867	262	Костромская область, Кострома, Фестивальная, 31	f	large
45001	43900	308	Костромская область, Кострома, Суслова, 6	f	large
44998	43900	305	Костромская область, Кострома, Суслова, 6	f	large
45015	43912	322	Костромская область, Кострома, Строительная, 8а	f	large
44906	43829	213	Костромская область, Кострома, Спасокукоцкого, 40	f	large
44929	43844	236	Костромская область, Кострома, Совхозная, 21	f	large
44996	43898	303	Костромская область, Кострома, Советская улица, 55а	f	large
44994	43896	301	Костромская область, Кострома, Советская, 52	f	large
44991	43893	298	Костромская область, Кострома, Советская, 111в	f	large
44990	43892	297	Костромская область, Кострома, Советская, 115	f	large
44987	43890	294	Костромская область, Кострома, Советская, 118Б	f	large
44995	43897	302	Костромская область, Кострома, Смоленская, 28а	f	large
44947	43860	254	Костромская область, Кострома, Свердлова, 120	f	large
45014	43911	321	Костромская область, Кострома, Садовая, 7	f	medium
44920	43837	227	Костромская область, Кострома, Речной проспект, 72	f	large
44935	43849	242	Костромская область, Кострома, Пушкина, 2а	f	large
44971	43877	278	Костромская область, Кострома, Профсоюзная, 36	f	large
44969	43876	276	Костромская область, Кострома, Профсоюзная, 20	f	large
44970	43876	277	Костромская область, Кострома, Профсоюзная, 20	f	large
44911	43834	218	Костромская область, Кострома, Просвещения, 22	f	large
44910	43833	217	Костромская область, Кострома, Просвещения, 24	f	large
44932	43846	239	Костромская область, Кострома, Партизанская, 37	f	large
44931	43846	238	Костромская область, Кострома, Партизанская, 37	f	large
44968	43871	275	Костромская область, Кострома, Новоселов, 11	f	large
44967	43871	274	Костромская область, Кострома, Новоселов, 11	f	large
44960	43871	267	Костромская область, Кострома, Новоселов, 11	f	large
44992	43894	299	Костромская область, Кострома, Никитская, 70	f	large
44989	43891	296	Костромская область, Кострома, Никитская, 106б	f	large
44952	43863	259	Костромская область, Кострома, Никитская, 106б	f	medium
44951	43862	258	Костромская область, Кострома, Никитская, 70	f	large
44949	43862	256	Костромская область, Кострома, Никитская, 70	f	large
45003	43904	310	Костромская область, Кострома, Малышковская , 4	f	large
44997	43899	304	Костромская область, Кострома, Малышковская , 55	f	small
44999	43901	306	Костромская область, Кострома, Малышковская, 4	f	large
81879	56076	1042	Москва, Татьяны Макаровой, 2	f	large
44927	43842	234	Костромская область, Кострома, Ленина, 149	f	large
44972	43878	279	Костромская область, Кострома, Кинешемское шоссе, 86	f	medium
44966	43875	273	Костромская область, Кострома, Кинешемское шоссе, 45	f	large
44964	43874	271	Костромская область, Кострома, Кинешемское шоссе, 4	f	large
44962	43872	269	Костромская область, Кострома, Кинешемское шоссе, 23	f	large
44961	43869	268	Костромская область, Кострома, Кинешемское шоссе, 25	f	large
44957	43869	264	Костромская область, Кострома, Кинешемское шоссе, 25	f	large
44954	43865	261	Костромская область, Кострома, Кинешемское шоссе, 15	f	medium
44946	43859	253	Костромская область, Кострома, Ивана Сусанина, 52	f	large
44945	43858	252	Костромская область, Кострома, Ивана Сусанина, 31а	f	large
44916	43593	223	Костромская область, Кострома, Запрудня, 10	f	large
44993	43895	300	Костромская область, Кострома, Долматова, 25	f	large
44985	43888	292	Костромская область, Кострома, Дзержинского, 17	f	large
44914	43836	221	Костромская область, Кострома, Депутатская, 47	f	large
44912	43835	219	Костромская область, Кострома, Депутатская, 47	f	large
44938	43851	245	Костромская область, Кострома, Горького, 7	f	medium
45011	43909	318	Костромская область, Кострома, Голубкова, 12	f	large
44943	43856	250	Костромская область, Кострома, Галичская, 47А	f	large
44941	43854	248	Костромская область, Кострома, Галичская, 47а	f	large
44944	43857	251	Костромская область, Кострома, Войкова, 23	f	large
44976	43881	283	Костромская область, Кострома, Бульварная, 21	f	large
44918	43764	225	Костромская область, Кострома, Боровая, 6	f	large
44917	43720	224	Костромская область, Кострома, Боровая, 2	f	large
44934	43848	241	Костромская область, Кострома, Боевая, 64	f	large
44936	43850	243	Костромская область, Кострома, Беговая, 4а	f	large
44959	43870	266	Костромская область, Кострома, 2-я Глазковская улица, 27А	f	large
44958	43870	265	Костромская область, Кострома, 2-я Глазковская улица, 27А	f	large
134439	94340	282	Костромская область, Кострома, 2-й Давыдовский проезд, 21, Муниципальное общеобразовательное учреждение лицей № 17	f	large
44905	43828	212	Костромская область, Кострома, 1 Мая, 14	f	large
44953	43864	260	Костромская область, Кострома, Юрия Смирнова, 47	f	large
45009	43907	316	Костромская область, Кострома, Машиностроителей, 3	f	large
45012	43907	319	Костромская область, Кострома, Машиностроителей, 3	f	large
44908	43831	215	Костромская область, Кострома, Ленина, 3	f	large
44867	43790	174	Костромская область, Кологрив, Центральная, 13	f	medium
45236	44130	543	Костромская область, Волгореченск, Парковая, 31	f	large
45232	44127	539	Костромская область, Волгореченск, Набережная, 20	f	large
45237	44131	544	Костромская область, Волгореченск, Имени 50-летия Ленинского Комсомола, 19	f	large
45234	44129	541	Костромская область, поселок Волгореченск, Имени 50-летия Ленинского Комсомола, 43	f	large
45233	44128	540	Костромская область, Волгореченск, Имени 50-летия Ленинского Комсомола, 21	f	large
45235	44092	542	Костромская область, поселок Волгореченск, Зеленова, 4	f	large
44741	43665	45	Костромская область, Буй, площадь Хазова, 1	f	large
44743	43666	46	Костромская область, Буй, Республиканская, 4	f	large
44744	43666	47	Костромская область, Буй, Республиканская, 4	f	large
44748	43669	50	Костромская область, Буй, Октябрьской революции, 130	f	large
44749	43670	51	Костромская область, Буй, Овражная, 19	f	large
44752	43672	53	Костромская область, Буй, Лизы Чайкиной, 25-А	f	large
44754	43663	43	Костромская область, Буй, Клубная, 16	f	medium
44740	43664	44	Костромская область, Буй, Карла Маркса, 5	f	large
44746	43668	49	Костромская область, Буй, Ивана Сусанина, 7	f	large
44745	43667	48	Костромская область, Буй, Заря революции, 28	f	large
44750	43671	52	Костромская область, Буй, 3 Интернационала , 10	f	large
45246	44139	553	Костромская область, Шарья городской округ, Шарья, 1-й микрорайон, 7	f	large
45334	43998	406	Костромская область, Шарьинский район, поселок Шекшема, Вокзальная, 7, здание администрации	f	large
45348	44006	414	Костромская область, Шарьинский район, поселок Троицкое, Советская, 26, здание администрации	f	small
45347	44002	410	Костромская область, Шарьинский район, поселок Сергеево, Центральная, 6, здание школы	f	small
45269	44160	574	Костромская область, Солигаличский район, поселок Калинино, 15 	f	small
45342	43999	407	Костромская область, Шарьинский район, поселок Рождественское, Коммунальная, 4, здание администрации	f	large
45340	43991	400	Костромская область, Шарьинский район, Пищевка, Центральная, 27	f	small
45338	44005	413	Костромская область, Шарьинский район, поселок Печенкино, Школьная, 5, здание школы	f	small
45343	44008	415	Костромская область, Шарьинский район, поселок Одоевское, Советская, 11, здание администрации	f	small
45336	43990	399	Костромская область, Шарьинский район, поселок Николо-Шанга, Юрия Смирнова, 19, здание администрации	f	large
45078	43975	385	Волгоградская область, Жирновский район, село Медведица	f	small
45349	44001	409	Костромская область, Шарьинский район, поселок Майтиха, Центральная, 7, здание администрации	f	small
45341	43992	401	Костромская область, Шарьинский район, поселок Кривячка, Школьный переулок, 1, административное здание	f	small
45344	44009	416	Костромская область, Шарьинский район, поселок Конево, Школьная, 1, здание администрации	f	small
45337	44004	412	Костромская область, Шарьинский район, поселок Катунино, Центральная, 17, здание СПОК Победа АГРО	f	small
45333	43996	404	Костромская область, Шарьинский район, поселок Зебляки, Октябрьская, 74, здание администрации 	f	large
45332	43995	403	Костромская область, Шарьинский район, поселок Заболотье, Молодежная, 1А, здание администрации	f	small
45339	43993	402	Костромская область, Шарьинский район, поселок Головино, Центральная, 16, здание школы	f	small
45253	44146	560	Костромская область, Шарьинский район, поселок Ветлужский, Чайковского, 3	f	large
45251	44144	558	Костромская область, Шарьинский район, поселок Ветлужский, Центральная, 26	f	large
45250	44143	557	Костромская область, Шарьинский район, поселок Ветлужский, Центральная, 18	f	large
45252	44145	559	Костромская область, Шарьинский район, поселок Ветлужский, Рабочая, 46	f	large
45335	43997	405	Костромская область, Шарьинский район, поселок Варакинский, Центральная, 1, здание детского сада	f	small
45345	44003	411	Костромская область, Шарьинский район, поселок Быниха, Молодежная, 2, здание школы	f	small
44761	43680	66	Костромская область, Шарьинский район, поселок Боровской, Свободы, 5	f	small
45346	44000	408	Костромская область, Шарьинский район, поселок Берзиха, Центральная, 28-А, здание школы	f	small
45319	44208	625	Костромская область, Чухломский район, поселок Якша, Зеленая, 18	f	small
45330	44215	631	Костромская область, Чухломский район, поселок Шартаново, Береговая, 1	f	small
45311	44201	618	Костромская область, Чухломский район, Чухлома, Советская, 6	f	large
45312	44202	619	Костромская область, Чухломский район, Чухлома, Октября, 6	f	large
45314	44204	621	Костромская область, Чухломский район, поселок Федоровское, пер. Ветеранов, 5	f	small
45329	43675	61	Костромская область, Чухломский район, поселок Тимофеевское, Центральная, 1	f	small
45323	44212	628	Костромская область, Чухломский район, поселок Судай, Советская, 29	f	medium
45324	44213	629	Костромская область, Чухломский район, поселок Судай, Пионерская, 1	f	medium
45085	43983	392	Костромская область, Чухломский район, поселок Сенная, Сенная, 1А	f	medium
45321	44209	626	Костромская область, Чухломский район, поселок Повалихино, Центральная, 18	f	small
45315	44205	622	Костромская область, Чухломский район, поселок Панкратово, Центральная, 7	f	small
45313	44203	620	Костромская область, Чухломский район, поселок Ножкино, Приозерная, 25	f	small
44872	43795	179	Костромская область, Чухломский район, поселок Некрасово, Школьная, 5	f	small
45325	44214	630	Костромская область, Чухломский район, поселок Куливертово, Школьная, 38	f	small
45317	44206	623	Костромская область, Чухломский район, поселок Коровье, Центральная, 11	f	small
45322	44210	627	Костромская область, Чухломский район, поселок Георгий, Кооперативная, 12	f	small
45331	44216	632	Костромская область, Чухломский район, поселок Вига, Школьная, 15А	f	small
45318	44207	624	Костромская область, Чухломский район, поселок Введенское, Сельская, 14	f	small
45326	43673	59	Костромская область, Чухломский район, поселок Белово, Молодежная, 7	f	small
45328	43674	60	Костромская область, Чухломский район, поселок Анфимово, Центральная, 7В	f	small
45300	44190	607	Костромская область, Сусанинский район, поселок Ченцово, Центральная, 9	f	small
45297	44187	604	Костромская область, Сусанинский район, поселок Сусанино, Леонова, 11	f	large
45298	44188	605	Костромская область, Сусанинский район, поселок Сусанино, Крупской, 15	f	large
45299	44189	606	Костромская область, Сусанинский район, поселок Сумароково, Новая, 3	f	small
45310	44200	617	Костромская область, Сусанинский район, поселок Сокирино, Южная, 13	f	small
45308	44198	615	Костромская область, Сусанинский район, поселок Попадьино, Школьная, 11	f	small
45307	44197	614	Костромская область, Сусанинский район, поселок Меленки, Молодежная, 10	f	small
45306	44196	613	Костромская область, Сусанинский район, поселок Медведки, Садовая, 2	f	small
44706	43631	11	Костромская область, Сусанинский район, поселок Малинино, Октябрьская, 2	f	small
45305	44195	612	Костромская область, Сусанинский район, поселок Ломышки, Центральная, 22	f	small
45309	44199	616	Костромская область, Сусанинский район, поселок Запрудня, Дорожная, 2	f	small
45304	44194	611	Костромская область, Сусанинский район, Григорово, Свободы, 2	f	small
45303	44193	610	Костромская область, Сусанинский район, поселок Головинское, Северная, 3, Северная, 2	f	small
45302	44192	609	Костромская область, Сусанинский район, поселок Буяково, Правды, 23	f	small
45301	44191	608	Костромская область, Сусанинский район, поселок Андреевское, Советская, 9	f	small
45351	44126	538	Костромская область, Судиславский район, поселок Шахово, Корякова, 1	f	small
45296	44186	603	Костромская область, Судиславский район, поселок Фадеево, Зелёная, 2	f	small
45277	44167	584	Костромская область, Судиславский район, поселок Судиславль, Юрьева, 2а	f	large
45279	44169	586	Костромская область, Судиславский район, поселок Судиславль, Шаховское шоссе, 3	f	large
45278	44168	585	Костромская область, Судиславский район, поселок Судиславль, Октябрьская, 23	f	medium
45295	44185	602	Костромская область, Судиславский район, поселок Сорож, Новая, 5	f	small
45283	44173	590	Костромская область, Судиславский район, поселок Свозово, Центральная, 17	f	small
45288	44178	595	Костромская область, Судиславский район, поселок Раслово, площадь Октября, 1	f	medium
45282	44172	589	Костромская область, Судиславский район, поселок Первушино, Центральная, 7	f	small
45287	44177	594	Костромская область, Судиславский район, поселок Михайловское, Центральная, 1	f	small
45294	44184	601	Костромская область, Судиславский район, поселок Мирный, Заводская, 2, кв.1	f	small
45285	44175	592	Костромская область, Судиславский район, поселок Кобякино, Королёва, 2	f	small
45286	44176	593	Костромская область, Судиславский район, поселок Калинки, Центральная, 43	f	small
45293	44183	600	Костромская область, Судиславский район, поселок Западный, Молодежная,, 1	f	medium
45281	44171	588	Костромская область, Судиславский район, поселок Завражье, Центральная, 28	f	small
45292	44182	599	Костромская область, Судиславский район, поселок Жвалово, Кашинцева, 15	f	small
45291	44181	598	Костромская область, Судиславский район, поселок Дружба, Цветочная, 4	f	large
45284	44174	591	Костромская область, Судиславский район, поселок Грудки, Центральная, 21	f	small
45290	44180	597	Костромская область, Судиславский район, поселок Глебово, Школьная	f	medium
45280	44170	587	Костромская область, Судиславский район, поселок Воронье, Полевая, 3	f	small
45289	44179	596	Костромская область, Судиславский район, поселок Березовая Роща	f	medium
45258	44150	564	Костромская область, Солигаличский район, д. Великово, 66, адрес УИК: д. Прокошево, 15	f	small
45274	44164	578	Костромская область, Солигаличский район, Солигалич, Серогодского, 10	f	large
134562	44163	577	Костромская область, Солигаличский район, Солигалич, Красноармейская, 7а, МОУ Солигаличская вечерняя общеобразовательная школа	f	large
45275	44165	579	Костромская область, Солигаличский район, Солигалич, В.Серогодского, 10	f	large
45264	44155	569	Костромская область, Солигаличский район, поселок Песлиново, 15 	f	small
45266	44157	571	Костромская область, Солигаличский район, поселок Лосево, 90	f	small
45260	44152	566	Костромская область, Солигаличский район, поселок Куземино, 61	f	small
45262	44154	568	Костромская область, Солигаличский район, поселок Корцово, Центральная, 50, УИК: Центральная, 25	f	small
45267	44158	572	Костромская область, Солигаличский район, поселок Коровново, 85 , д. Коровново, 81	f	small
45271	44162	576	Костромская область, Солигаличский район, поселок Заяцкое, 1А	f	small
45259	44151	565	Костромская область, Солигаличский район, поселок Зашугомье, 10	f	small
45265	44156	570	Костромская область, Солигаличский район, поселок Жилино, 21 	f	small
45270	44161	575	Костромская область, Солигаличский район, поселок Гнездниково, Новая, 1Б	f	small
45256	44149	563	Костромская область, Солигаличский район, поселок Высоковский, Школьная, 2	f	small
45255	44148	562	Костромская область, Солигаличский район, поселок Бурдуково, Ветеранов, 17, ул. Ветеранов, 17	f	small
45261	44153	567	Костромская область, Солигаличский район, поселок Большой Починок, 48	f	small
44758	43678	64	Костромская область, Пыщугский район, поселок Сергеевица, Новая, 9	f	small
132994	43676	62	Костромская область, Пыщугский район, поселок Пыщуг, Чапаева, 5	f	large
44757	43677	63	Костромская область, Пыщугский район, поселок Пыщуг, Советская, 22	f	large
44764	43685	71	Костромская область, Пыщугский район, поселок Носково, Октябрьская, 3	f	small
44759	43679	65	Костромская область, Пыщугский район, поселок Михайловица, Гагарина, 26	f	small
44763	43684	70	Костромская область, Пыщугский район, поселок Крутая, Победы, 1а	f	small
132995	43682	68	Костромская область, Пыщугский район, поселок Колпашница, Советская, 10, Колпашницкий сельский клубный филиал РЦКиД	f	small
44760	43681	67	Костромская область, Пыщугский район, поселок Головино, Шистерова, 23	f	small
44762	43683	69	Костромская область, Пыщугский район, поселок Верхнеспасское, Первомайская, 12	f	small
45229	44125	536	Костромская область, Поназыревский район, поселок Якшанга, Ленина, 38	f	large
45222	44118	529	Костромская область, Поназыревский район, поселок Хмелевка, Строителей, 1	f	small
45226	44122	533	Костромская область, Поназыревский район, поселок Поназырево, площадь 50 лет ВЛКСМ, 6	f	large
45227	44123	534	Костромская область, Поназыревский район, поселок Поназырево, Пушкина, 38	f	large
132999	44121	532	Костромская область, Поназыревский район, поселок Поназырево, Пушкина, 38, МБОУ Поназыревская средняя общеобразовательная школа	f	medium
45230	43745	537	Костромская область, Поназыревский район, поселок Полдневица, Ленина, 19	f	small
45231	43745	129	Костромская область, Поназыревский район, поселок Полдневица, Ленина, 19	f	small
45224	44120	531	Костромская область, Поназыревский район, поселок Клюкино, Центральная, 5	f	small
45228	44124	535	Костромская область, Поназыревский район, поселок Гудково, Северная, 15	f	small
45223	44119	530	Костромская область, Поназыревский район, поселок Горлово	f	small
45210	44106	517	Костромская область, Парфеньевский район, поселок Успенье, Центральная, 1	f	small
45116	44011	423	Костромская область, Парфеньевский район, поселок Тотомица, Ленина, 22	f	medium
45212	44108	519	Костромская область, Парфеньевский район, поселок Савино, 52, помещение МОУ Савинская основная общеобразовательная школа	f	small
45211	44107	518	Костромская область, Парфеньевский район, поселок Потрусово, 35, помещение администрации Потрусовского сельского поселения	f	small
45221	44117	528	Костромская область, Парфеньевский район, поселок Парфеньево, Песочная, 21	f	medium
45220	44116	527	Костромская область, Парфеньевский район, поселок Парфеньево, Ленина, 41	f	large
45213	44109	520	Костромская область, Парфеньевский район, поселок Николо-Ширь, помещение Ширской сельской библиотеки, дом 41	f	small
45215	44111	522	Костромская область, Парфеньевский район, поселок Николо-Полома, 18, помещение Задоринской сельской библиотеки	f	small
132998	44112	523	Костромская область, Парфеньевский район, поселок Николо-Полома, Полевая, 34, Николо-Поломская сельский Дом культуры	f	large
45219	44115	526	Костромская область, Парфеньевский район, поселок Матвеево, 125 А, помещение администрации Матвеевского сельского поселения	f	small
45218	44114	525	Костромская область, Парфеньевский район, поселок Вохтома, Школьная, 16	f	small
45217	44113	524	Костромская область, Парфеньевский район, поселок Бор, Набережная, 2	f	small
45214	44110	521	Костромская область, Парфеньевский район, поселок Аносово, 74, помещение Аносовского сельского Дома культуры	f	small
45206	44102	513	Костромская область, Павинский район, поселок Шумково, 52	f	small
41286	38424	474	Калужская область, Малоярославец, пл.Жукова, 3	f	large
45201	44097	508	Костромская область, Павинский район, поселок Фурово, Чапаева, 15	f	small
45205	44101	512	Костромская область, Павинский район, поселок Павино, Октябрьская, 55	f	large
45204	44100	511	Костромская область, Павинский район, поселок Павино, Октябрьская, 14	f	large
45200	44096	507	Костромская область, Павинский район, поселок Павино, Больничная, 7	f	small
45208	44104	515	Костромская область, Павинский район, поселок Медведица, 32	f	small
45209	44105	516	Костромская область, Павинский район, поселок Леденгск, Советская, 19	f	small
45203	44099	510	Костромская область, Павинский район, поселок Карпово, 6	f	small
45207	44103	514	Костромская область, Павинский район, поселок Доброумово, Дзержинского, 11	f	small
45202	44098	509	Костромская область, Павинский район, поселок Березовка, 30	f	small
45198	44094	505	Костромская область, Островский район, поселок Юрьево, 24	f	small
45181	44076	488	Костромская область, Островский район, поселок Щелыково, 30 	f	small
45196	44091	503	Костромская область, Островский район, поселок Хомутово, 1 	f	small
45194	44089	501	Костромская область, Островский район, поселок Парфеньево, ОАО Островскоеавтотранс	f	small
45175	44070	482	Костромская область, Островский район, поселок Островское, пер. Школьный, 3	f	large
45193	44088	500	Костромская область, Островский район, поселок Островское, Советская, 97	f	small
45177	44072	484	Костромская область, Островский район, поселок Островское, Советская, 51А	f	medium
45176	44071	483	Костромская область, Островский район, поселок Островское, Сахарова, 3, УИК: ул. Советская, 97	f	large
45178	44073	485	Костромская область, Островский район, поселок Островское, Заречная, 8	f	medium
45180	44075	487	Костромская область, Островский район, поселок Марково, Марковский селшьский Дом культуры	f	small
45185	44080	492	Костромская область, Островский район, поселок Малое Березово, Малоберезовский сельский клуб, адрес УИК: д. Ивашево, 70	f	small
45192	44087	499	Костромская область, Островский район, поселок Ломки, Школьная, 1	f	small
45174	44069	481	Костромская область, Островский район, поселок Красная Поляна, Луговая, 15	f	small
45191	44086	498	Костромская область, Островский район, поселок Козловка, Колхозная, 24, ГУ Островский психоневрологический интернат	f	small
45197	44093	504	Костромская область, Островский район, поселок Климово, Школьная, 5	f	small
45189	44084	496	Костромская область, Островский район, Клеванцово, Колхозная, 13	f	small
45186	44081	493	Костромская область, Островский район, поселок Игодово, Пушкина, 16	f	small
45184	44079	491	Костромская область, Островский район, поселок Ивашево, 70	f	small
45182	44077	489	Костромская область, Островский район, поселок Заборье, Совхозная, 20	f	small
45188	44083	495	Костромская область, Островский район, поселок Дымница, Школьная, 1	f	small
45187	44082	494	Костромская область, Островский район, поселок Дубяны, Лесная, 3, с. Игодово, ул. Пушкина, 16	f	small
45195	44090	502	Костромская область, Островский район, поселок Гуляевка, улица Транспортная, 2	f	small
45190	44085	497	Костромская область, Островский район, поселок Воскресенское, Заовражная, 23, адрес УИК: д. Клеванцово, Колхозная, 24	f	small
45183	44078	490	Костромская область, Островский район, поселок Александровское, Советская, 16	f	medium
45179	44074	486	Костромская область, Островский район, поселок Адищево, Комарова, 50	f	medium
45167	44062	474	Костромская область, Октябрьский район, поселок Соловецкое, Центральная, 7	f	small
45164	44059	471	Костромская область, Октябрьский район, поселок Луптюг, Советская, 58	f	small
134449	94350	472	Костромская область, Октябрьский район, поселок Лебеди	f	small
45166	44061	473	Костромская область, Октябрьский район, поселок Кузьмины, Молодёжная, 1	f	small
45173	44065	477	Костромская область, Октябрьский район, поселок Ильинское, Школьная, 2	f	small
45172	44067	479	Костромская область, Октябрьский район, поселок Забегаево, 84	f	small
45171	44066	478	Костромская область, Октябрьский район, поселок Веденье, Интернатовский, 6	f	small
45169	44064	476	Костромская область, Октябрьский район, поселок Боговарово, Победы, 44	f	large
45168	44063	475	Костромская область, Октябрьский район, поселок Андреево, Молодёжная, 3	f	small
45130	44025	437	Костромская область, Нея городской округ, Нея, Махотина, 23	f	large
45128	44023	435	Костромская область, Нея городской округ, Нея, Матросова, 7А	f	large
45127	44007	434	Костромская область, Нея городской округ, Любимова, 45	f	large
45126	44021	433	Костромская область, Нея городской округ, Нея, Кирова, 62	f	large
45129	44024	436	Костромская область, Нея городской округ, Нея, Больничная, 8	f	large
45161	44056	468	Костромская область, Нерехтский район, поселок Якушовка, Мира, 19а	f	medium
45162	44057	469	Костромская область, Нерехтский район, поселок Хомутово, Победы, 1	f	small
45159	44054	466	Костромская область, Нерехтский район, поселок Федоровское, пл. Мира, 3	f	medium
45160	44055	467	Костромская область, Нерехтский район, поселок Тетеринское, Мира, 6	f	medium
45157	44052	464	Костромская область, Нерехтский район, поселок Татарское, Маршала Новикова, 13	f	medium
45147	44042	454	Костромская область, Нерехтский район, поселок Спас, Школьная, 1	f	small
45163	44058	470	Костромская область, Нерехтский район, поселок Рудино, Школьная, 1	f	small
45156	44051	463	Костромская область, Нерехтский район, поселок Марьинское, 91	f	small
134448	94349	462	Костромская область, Нерехтский район, поселок Лужки, Молодежная, 18а, МОУ Ёмсненская СОШ	f	small
45152	44047	459	Костромская область, Нерехтский район, поселок Лаврово, Советская, 1б	f	medium
45133	44028	440	Костромская область, Нерехтский район, поселок Космынино, Техническая, 18	f	medium
45132	44027	439	Костромская область, Нерехтский район, поселок Космынино, Ленина, 31	f	medium
45151	44046	458	Костромская область, Нерехтский район, поселок Клементьево, Октябрьская, 12	f	small
45154	44049	461	Костромская область, Нерехтский район, поселок Иголкино, 94	f	small
45150	44045	457	Костромская область, Нерехтский район, поселок Емсна, Центральная, 60	f	small
45149	44044	456	Костромская область, Нерехтский район, поселок Григорцево, Школьная, 12	f	medium
45146	44041	453	Костромская область, Нерехтский район, поселок Владычное, Фролова, 6	f	small
45148	44043	455	Костромская область, Нерехтский район, поселок Бабаево, Полевая, 20	f	medium
45145	44040	452	Костромская область, Нерехтский район, поселок Арменки, Школьная, 8	f	small
45112	44018	430	Костромская область, Нейский район, поселок Солтаново, Центральная, 2	f	small
45121	44016	428	Костромская область, Нейский район, поселок Номжа, Молодежная, 9	f	medium
45120	44015	427	Костромская область, Нейский район, поселок Михали, Советская, 7	f	small
45118	44013	425	Костромская область, Нейский район, поселок Кужбал, Советская, 33А	f	medium
45114	44019	431	Костромская область, Нейский район, поселок Коткишево, Центральная, 14	f	small
45115	44010	422	Костромская область, Нейский район, поселок Еленский, Советская, 22	f	medium
45122	44017	429	Костромская область, Нейский район, поселок Дьяконово, Советская, 2	f	small
45111	44012	424	Костромская область, Нейский район, поселок Вожерово, Центральная, 1	f	small
45119	44014	426	Костромская область, Нейский район, поселок Абросимово, Вокзальная, 16	f	small
45105	43691	77	Костромская область, Межевской район, поселок Центральный, Заречная, 8	f	small
45107	43692	78	Костромская область, Межевской район, поселок Средняя, Центральная, 1	f	small
45104	43690	76	Костромская область, Межевской район, поселок Петушиха, Советская, 3	f	small
45102	43689	75	Костромская область, Межевской район, поселок Первомайский, Марьинская, 13	f	small
134425	94326	74	Костромская область, Межевской район, поселок Никола, Новая , 1а, МОУ Никольская средняя общеобразовательная школа	f	small
134424	94325	73	Костромская область, Межевской район, поселок Козлиха, 56 , Козлихинский филиал МУК Георгиевский КДК 	f	small
45098	43686	72	Костромская область, Межевской район, поселок Георгиевское, Октябрьская, 43	f	large
45072	43969	379	Костромская область, Мантуровский район, поселок Угоры	f	small
45080	43977	387	Костромская область, Мантуровский район, поселок Самылово	f	small
45071	43968	378	Костромская область, Мантуровский район, поселок Рогово	f	small
45075	43972	382	Костромская область, Мантуровский район, поселок Подвигалиха	f	small
134445	94346	377	Костромская область, Мантуровский район, поселок Октябрьский, Горького, 14, здание МОУ Октябрьская СОШ	f	medium
134446	94347	381	Костромская область, Мантуровский район, Лесобазы, Заречная, здание МОУ Лесобазовская НОШ	f	small
82177	56267	1344	Москва, Танковый проезд, 6	f	large
45069	43966	376	Костромская область, Мантуровский район, поселок Леонтьево	f	small
45081	43978	388	Костромская область, Мантуровский район, поселок Карьково	f	small
45073	43970	380	Костромская область, Мантуровский район, поселок Знаменка	f	small
45079	43976	386	Костромская область, Мантуровский район, поселок Ефимово	f	small
134447	94348	384	Костромская область, Мантуровский район, поселок Елизарово, здание МОУ Елизаровская ООШ	f	small
45076	43973	383	Костромская область, Мантуровский район, поселок Гусево	f	small
45089	43987	396	Костромская область, Мантурово городской округ, Мантурово, Советская, 57	f	medium
45094	43986	395	Костромская область, Мантурово городской округ, Мантурово, Больничная, 2	f	medium
45058	43955	365	Костромская область, Макарьевский район, поселок Якимово, 52	f	small
45062	43959	369	Костромская область, Макарьевский район, поселок Юрово, 227	f	medium
45060	43957	367	Костромская область, Макарьевский район, поселок Юркино, 158	f	small
45051	43948	358	Костромская область, Макарьевский район, поселок Шемятино, 95	f	small
45052	43949	359	Костромская область, Макарьевский район, поселок Унжа, Советская, 8	f	small
45053	43950	360	Костромская область, Макарьевский район, поселок Тимошино, 79	f	small
45056	43953	363	Костромская область, Макарьевский район, поселок Стариково, 3	f	small
45067	43964	374	Костромская область, Макарьевский район, поселок Соловатово, 59 а	f	small
45064	43961	371	Костромская область, Макарьевский район, поселок Первомайка, Ленина, 2	f	medium
45050	43947	357	Костромская область, Макарьевский район, поселок Никулино, 30	f	small
45065	43962	372	Костромская область, Макарьевский район, поселок Николо-Макарово, Коммунистическая, 1	f	small
45068	43965	375	Костромская область, Макарьевский район, поселок Нежитино, Центральная, 65	f	small
45046	43943	353	Костромская область, Макарьевский район, Макарьев, площадь Революции, 13	f	medium
45044	43941	351	Костромская область, Макарьевский район, Макарьев, Юрьевецкая, 25	f	large
45048	43945	355	Костромская область, Макарьевский район, Макарьев, М. Советская, 9	f	large
45043	43940	350	Костромская область, Макарьевский район, Макарьев, Дорожная, 1	f	large
45042	43939	349	Костромская область, Макарьевский район, Макарьев, Ветлужская, 34	f	large
45057	43954	364	Костромская область, Макарьевский район, поселок Лопаты	f	small
45055	43952	362	Костромская область, Макарьевский район, Лопалово, 1	f	small
45047	43944	354	Костромская область, Макарьевский район, Комсомолка	f	small
45054	43951	361	Костромская область, Макарьевский район, поселок Ильинское, 38	f	small
45059	43956	366	Костромская область, Макарьевский район, Заречье, 21	f	small
134443	94344	368	Костромская область, Макарьевский район, поселок Ефино, Культурный центр, 5 , МУ Ефинский культурно-досуговый центр	f	small
45066	43963	373	Костромская область, Макарьевский район, поселок Дорогиня, Горького, 1 а	f	medium
134444	94345	370	Костромская область, Макарьевский район, поселок Горчуха, 20 Партсъезда, 9, МОУ Горчухинская средняя общеобразовательная школа	f	large
45049	43946	356	Костромская область, Макарьевский район, поселок Выгорки, 43	f	small
45023	43921	330	Костромская область, Красносельский район, поселок Шолохово, Центральная, 1, Зеленая, 11	f	large
45028	43926	335	Костромская область, Красносельский район, поселок Ченцы, Молодежная, 5	f	small
134442	94343	332	Костромская область, Красносельский район, поселок Харитоново, 44, Харитоновская начальная школа	f	small
45041	43938	348	Костромская область, Красносельский район, поселок Халипино	f	small
45034	43918	341	Костромская область, Красносельский район, поселок Сухара, 31	f	small
45024	43922	331	Костромская область, Красносельский район, Сопырево, Речная, 2	f	small
45030	43928	337	Костромская область, Красносельский район, поселок Синцово, Центральная, 11 а	f	small
45039	43936	346	Костромская область, Красносельский район, поселок Сидоровское, площадь Сыромятникова, 13	f	medium
45038	43935	345	Костромская область, Красносельский район, поселок Светочева Гора, 56	f	small
45036	43933	343	Костромская область, Красносельский район, поселок Подольское, Центральная, 29	f	medium
134441	94342	328	Костромская область, Красносельский район, поселок Красное-на-Волге, Советская, 45, помещение Детской Художественной Школы	f	large
132996	44026	438	Костромская область, Красносельский район, поселок Красное-на-Волге, Луначарского, 4	f	large
134440	94341	327	Костромская область, Красносельский район, поселок Красное-на-Волге, Ленина, 9, Молодежный Центр Волга	f	large
45022	43920	329	Костромская область, Красносельский район, поселок Красное-на-Волге, Ленина, 44а	f	large
45029	43927	336	Костромская область, Красносельский район, поселок Имени Чапаева, Советская, 13	f	medium
45037	43934	344	Костромская область, Красносельский район, поселок Здемирово, 117	f	medium
45031	43929	338	Костромская область, Красносельский район, поселок Захарово, 73	f	small
45040	43937	347	Костромская область, Красносельский район, поселок Густомесово, 166	f	small
45027	43925	334	Костромская область, Красносельский район, поселок Гридино, Центральная, 9	f	medium
45035	43932	342	Костромская область, Красносельский район, поселок Гравкарьера, Нагорная, 3	f	medium
45033	43931	340	Костромская область, Красносельский район, поселок Веселово, Центральная, 13	f	small
45026	43924	333	Костромская область, Красносельский район, поселок Боровиково, Центральная, 64	f	medium
45032	43930	339	Костромская область, Красносельский район, поселок Афанасово, 92	f	small
44875	43798	182	Костромская область, Костромской район, п.Паточного завода, 27	f	medium
44871	43794	178	Костромская область, Костромской район, поселок Яковлевское, Просвещения, 27	f	medium
44890	43812	197	Костромская область, Костромской район, поселок Щетниково, ФСК Ника	f	medium
44903	43826	210	Костромская область, Костромской район, поселок Шунга, Юбилейная, 10А	f	large
44893	43815	200	Костромская область, Костромской район, поселок Шувалово, Победы, 63	f	large
44889	43811	196	Костромская область, Костромской район, поселок Фанерник, Геофизиков, 24А	f	large
44897	43819	204	Костромская область, Костромской район, поселок Тихий Уголок, Клуб санотория Волга	f	small
134437	94338	198	Костромская область, Костромской район, поселок Сущево, Советская, 18Б, МОУ Сущевская средняя школа	f	large
44901	43824	208	Костромская область, Костромской район, поселок Сухоногово, Советская, 4	f	large
44898	43821	205	Костромская область, Костромской район, поселок Середняя, Кузьмина, 13	f	large
44902	43825	209	Костромская область, Костромской район, поселок Саметь, Малининой, 6	f	medium
44894	43816	201	Костромская область, Костромской район, поселок Прибрежный, Набережная, 5	f	small
44886	43808	193	Костромская область, Костромской район, поселок Петрилово, 35	f	medium
44896	43818	203	Костромская область, Костромской район, поселок Обломихино, Нерехтская, 7	f	small
44888	43810	195	Костромская область, Костромской район, поселок Никольское, Школьная, 2	f	large
134422	94323	194	Костромская область, Костромской район, поселок Никольское, Зеленая, 1	f	large
134438	94339	207	Костромская область, Костромской район, поселок Мисково, Некрасова, 13а, Дом культуры	f	medium
44884	43806	191	Костромская область, Костромской район, поселок Минское, Куколевского, 16	f	large
134436	94337	190	Костромская область, Костромской район, поселок Кузьмищи, Зеленая, 14, МОУ Кузьмищенская СОШ	f	medium
44881	43504	188	Костромская область, Костромской район, поселок Кузнецово, 47	f	small
44892	43814	199	Костромская область, Костромской район, поселок Крутик, Новая, 41	f	small
44873	43796	180	Костромская область, Костромской район, поселок Коряково, 11	f	large
44877	43800	184	Костромская область, Костромской район, поселок Караваево, Штеймана, 58А	f	large
44876	43799	183	Костромская область, Костромской район, поселок Караваево, Штеймана, 1А	f	large
44878	43801	185	Костромская область, Костромской район, поселок Караваево, Учебный городок, 34	f	large
44895	43817	202	Костромская область, Костромской район, поселок Ильинское, Почтовая, 1	f	medium
44874	43797	181	Костромская область, Костромской район, поселок Зарубино, Центральная, 2	f	large
44885	43807	192	Костромская область, Костромской район, поселок Губачево, Новая, 27	f	medium
44879	43802	186	Костромская область, Костромской район, поселок Василево, переулок Школьный, 11	f	medium
44880	43803	187	Костромская область, Костромской район, поселок Бычиха, 68	f	small
44899	43822	206	Костромская область, Костромской район, поселок Большая Сандогора, Центральная, 4	f	medium
82734	56597	1910	Москва, Тамбовская, 10	f	large
44869	43792	176	Костромская область, Костромской район, поселок Аферово, 1 Мая, 19	f	small
44870	43793	177	Костромская область, Костромской район, поселок Апраксино, Молодежная, 4	f	large
134435	94336	171	Костромская область, Кологривский район, поселок Ужуга, Дорожная, 8б, Администрация Ужугского сельского поселения	f	small
134434	94335	170	Костромская область, Кологривский район, поселок Суховерхово, 60 лет Октября, 8, администрация Суховерховского сельского поселения	f	small
44853	43775	160	Костромская область, Кологривский район, поселок Судилово, Судиловский сельский клуб	f	small
134426	94327	79	Костромская область, Кологривский район, поселок Советский, Набережная, 6 , МОУ Советская основная общеобразовательная школа	f	small
44868	43791	175	Костромская область, Кологривский район, поселок Октябрьский	f	small
44859	43781	166	Костромская область, Кологривский район, поселок Овсянниково, МОУ Илешевская средняя общеобразовательная школа	f	small
134433	94334	168	Костромская область, Кологривский район, поселок Маракино, Центральная, 1, Маракинский сельский клуб	f	small
134432	94333	167	Костромская область, Кологривский район, Лисицино, 33, Филиал МУ «Суховерховский дом культуры» 	f	small
134431	94332	165	Костромская область, Кологривский район, поселок Колохта, Набережная, 14а, МОУ Колохтская основная общеобразовательная школа	f	small
44852	43774	159	Костромская область, Кологривский район, Кологрив, Набережная речки Киченки, 11	f	large
44865	43787	172	Костромская область, Кологривский район, Кологрив, Набережная реки Унжи, 10, УИК: улица Центральная, д. 13	f	medium
134430	94331	164	Костромская область, Кологривский район, поселок Ильинское, 99 , МОУ Ильинская средняя общеобразовательная школа	f	small
44862	43784	169	Костромская область, Кологривский район, поселок Даравка, бывшая администрация Понговского сельского поселения	f	small
44856	43778	163	Костромская область, Кологривский район, поселок Высоково-Полома, Высоковский клуб-библиотека	f	small
44855	43777	162	Костромская область, Кологривский район, поселок Воймас, Воймасский сельский клуб	f	small
44866	43789	173	Костромская область, Кологривский район, поселок Верхняя Унжа, филиал Костромского строительного техникума № 6	f	small
44854	43776	161	Костромская область, Кологривский район, поселок Варзенга, Варзенгский сельский клуб-библиотека	f	small
134429	94330	158	Костромская область, Кологривский район, поселок Большая Чежма, филиал МУ Суховерховский дом культуры Чёжемский клуб-библиотека	f	small
44844	43766	151	Костромская область, Кадыйский район, поселок Чернышево, Советская, 11	f	small
44843	43765	150	Костромская область, Кадыйский район, поселок Текун, Клубная, 12	f	small
44849	43771	156	Костромская область, Кадыйский район, поселок Столпино, Набережная, 1	f	small
44839	43760	146	Костромская область, Кадыйский район, поселок Селище, Советская, 25	f	small
44842	43763	149	Костромская область, Кадыйский район, поселок Паньково, Садиковская, 4А	f	small
44850	43772	157	Костромская область, Кадыйский район, поселок Новый Курдюм, Советская, 16	f	small
44834	43755	141	Костромская область, Кадыйский район, поселок Низкусь, Школьная, 1	f	small
44840	43761	147	Костромская область, Кадыйский район, поселок Марьино, Лесная, 4А	f	small
44846	43768	153	Костромская область, Кадыйский район, поселок Лубяны, 26	f	small
44836	43757	143	Костромская область, Кадыйский район, поселок Котлово, Советская, 10А	f	small
44838	43759	145	Костромская область, Кадыйский район, поселок Кадый, Центральная, 17	f	large
44832	43753	139	Костромская область, Кадыйский район, поселок Кадый, Центральная, 5	f	large
44835	43756	142	Костромская область, Кадыйский район, поселок Иваньково, 64, б/у	f	small
44847	43769	154	Костромская область, Кадыйский район, поселок Завражье, Школьная, 8	f	small
44837	43758	144	Костромская область, Кадыйский район, поселок Екатеринкино, Центральная, 8	f	small
44841	43762	148	Костромская область, Кадыйский район, поселок Дубки, Полевая, 21	f	small
44833	43754	140	Костромская область, Кадыйский район, поселок Вешка, Островская, 1А	f	medium
44831	43752	138	Костромская область, Кадыйский район, поселок Ведрово, б/у, б/н	f	small
44848	43770	155	Костромская область, Кадыйский район, поселок Борисоглебское, 45А, б/у	f	small
82733	56597	1909	Москва, Тамбовская, 10	f	large
44804	43729	113	Костромская область, Галичский район, поселок Челсма, Центральная, 27а	f	medium
44812	43736	120	Костромская область, Галичский район, поселок Унорож, Центральная, 16	f	small
44802	43728	112	Костромская область, Галичский район, поселок Углево, Школьная, 12	f	small
44816	43740	124	Костромская область, Галичский район, поселок Толтуново, 10, помещение административного здания Степановского с/п	f	small
44813	43737	121	Костромская область, Галичский район, поселок Степаново, Советская, 3	f	medium
44809	43734	118	Костромская область, Галичский район, поселок Россолово, Кооперативная, 9	f	small
44808	43733	117	Костромская область, Галичский район, поселок Россолово, Зеленая, 27	f	medium
44800	43726	110	Костромская область, Галичский район, поселок Пронино, Центральная, 19а	f	small
44807	43732	116	Костромская область, Галичский район, поселок Орехово, 1-го Мая, 32	f	medium
44817	43741	125	Костромская область, Галичский район, поселок Олешь, 21, помещение Олешского ФАП	f	small
44805	43730	114	Костромская область, Галичский район, поселок Нагатино, Молодежная, 7	f	small
44796	43723	107	Костромская область, Галичский район, поселок Михайловское, Центральная, 9	f	small
44801	43727	111	Костромская область, Галичский район, поселок Митино, Молодежная, 1	f	small
44814	43738	122	Костромская область, Галичский район, поселок Мелешино, 17, помещение МУК Мелёшинского сельского клуба	f	small
44795	43722	106	Костромская область, Галичский район, поселок Малышево, Школьная, 10	f	small
44806	43731	115	Костромская область, Галичский район, поселок Лопарево, Совхозная, 8	f	medium
44792	43719	104	Костромская область, Галичский район, поселок Ладыгино, Ленина, 1-а	f	small
44815	43739	123	Костромская область, Галичский район, поселок Курьяново, Комсомольская, 6	f	small
44797	43724	108	Костромская область, Галичский район, поселок Красильниково, Школьная, 21	f	small
44811	43735	119	Костромская область, Галичский район, поселок Костома, Молодежная, 18	f	small
44799	43725	109	Костромская область, Галичский район, село Кабаново, Центральная улица, 12	f	small
44794	43721	105	Костромская область, Галичский район, поселок Дмитриевское, Центральная, 14	f	medium
44824	43747	131	Костромская область, Галичский район, Галич	f	medium
44821	43744	128	Костромская область, Галичский район, Галич, Пушкина, 6	f	large
44830	43751	137	Костромская область, Галичский район, Галич, Лисья Гора, 1	f	medium
44825	43748	132	Костромская область, Галичский район, Галич, Лермонтова, 39	f	large
44819	43742	126	Костромская область, Галичский район, Галич, Заводская Набережная, 2	f	large
44820	43743	127	Костромская область, Галичский район, Галич, Гладышева, 71	f	medium
44823	43746	130	Костромская область, Галичский район, Галич, Гагарина, 57а	f	medium
44791	43718	103	Костромская область, Галичский район, поселок Березовец, Советская, 11	f	small
44826	43705	133	Костромская область, Галич городской округ, Галич, Школьная, 7	f	large
44827	43337	134	Костромская область, Галич городской округ, Галич, Советская, 1	f	medium
44829	43750	136	Костромская область, Галич городской округ, Галич, Свободы, 59А	f	large
44828	43749	135	Костромская область, Галич городской округ, Галич, Долматова, 13	f	large
45199	44095	506	Костромская область, Вохомский район, поселок Шайменский, Советская, 7	f	small
44779	43708	93	Костромская область, Вохомский район, поселок Троица, Набережная, 22	f	small
44787	43717	102	Костромская область, Вохомский район, поселок Тихон, Больничная, 20	f	small
44790	43715	100	Костромская область, Вохомский район, поселок Талица, Строительная, 40	f	small
44783	43712	97	Костромская область, Вохомский район, поселок Спас, Школьная, 7	f	small
44777	43706	91	Костромская область, Вохомский район, поселок Согра, 14к2	f	small
44780	43709	94	Костромская область, Вохомский район, поселок Поспехово, Школьная, 2	f	small
44782	43710	95	Костромская область, Вохомский район, поселок Покров, Молодежная, 1	f	small
44789	43716	101	Костромская область, Вохомский район, поселок Песочный, Центральная, 2	f	small
44775	43703	89	Костромская область, Вохомский район, поселок Осипино, 23	f	small
45268	44159	573	Костромская область, Вохомский район, поселок Оглоблино, Молодежная, 2	f	small
44770	43698	84	Костромская область, Вохомский район, поселок Никола, Школьная, 1	f	small
44773	43701	87	Костромская область, Вохомский район, поселок Марково, 40	f	small
44771	43699	85	Костромская область, Вохомский район, поселок Малое Раменье, Школьная, 3	f	small
44786	43707	92	Костромская область, Вохомский район, поселок Макарята, 51	f	small
44769	43697	83	Костромская область, Вохомский район, поселок Латышово, Чичерина, 6, сельский клуб	f	small
44785	43713	98	Костромская область, Вохомский район, поселок Лажборовица, Центральная, 17	f	small
44774	43702	88	Костромская область, Вохомский район, поселок Конница, Новая, 1	f	small
134428	94329	86	Костромская область, Вохомский район, поселок Заветлужье, Центральная, 32, отделение временного проживания	f	small
44766	43695	81	Костромская область, Вохомский район, поселок Вохма, Советская, 72	f	large
44765	43694	80	Костромская область, Вохомский район, поселок Вохма, Советская, 37	f	large
44784	43714	99	Костромская область, Вохомский район, поселок Воробьевица, Школьная, 17	f	medium
134427	94328	82	Костромская область, Вохомский район, поселок Бережок, Заводская, 15, детский сад	f	small
44778	43704	90	Костромская область, Вохомский район, поселок Андрианово, 13	f	small
44781	43711	96	Костромская область, Вохомский муниципальный район, поселок Лапшино, 22	f	small
44736	43647	41	Костромская область, Буйский район, поселок Шушкодом, Центральная, 3	f	small
44715	43640	20	Костромская область, Буйский район, Чистые Боры, б-р Строителей, 2	f	large
44714	43639	19	Костромская область, Буйский район, Чистые Боры, б-р Строителей, 20	f	large
44712	43637	17	Костромская область, Буйский район, поселок Талица, Советская, 20	f	small
44737	43662	42	Костромская область, Буйский район, поселок Романцево, 52, кв. 8	f	small
44718	43643	23	Костромская область, Буйский район, поселок Махрово, Железнодорожная, 24	f	small
44735	43661	40	Костромская область, Буйский район, поселок Лужок, Молодежная, 10а	f	small
44734	43660	39	Костромская область, Буйский район, поселок Ликурга, Троицкая, 17	f	small
44733	43659	38	Костромская область, Буйский район, поселок Курилово, 10	f	small
134423	94324	34	Костромская область, Буйский район, поселок Куребрино, Клубная, 1, Куребринский сельский клуб	f	small
44732	43658	37	Костромская область, Буйский район, поселок Кренево, Почтовая, 9	f	small
44731	43657	36	Костромская область, Буйский район, поселок Корега, Сплавная, 25	f	medium
44730	43656	35	Костромская область, Буйский район, поселок Контеево, Верхняя, 7	f	small
44720	43645	25	Костромская область, Буйский район, поселок Ильино, 47	f	small
44722	43648	27	Костромская область, Буйский район, поселок Игумново, Черемушки, 19, кв. 2	f	small
44728	43654	33	Костромская область, Буйский район, поселок Елегино, Задняя, 11	f	small
44727	43653	32	Костромская область, Буйский район, поселок Дьяконово, Дъяконовский, 2	f	small
44726	43652	31	Костромская область, Буйский район, поселок Дор, 21	f	small
44723	43649	28	Костромская область, Буйский район, поселок Добрецово, Новая, 7	f	small
44725	43651	30	Костромская область, Буйский район, поселок Гагарино, Советская, 7	f	small
44721	43646	26	Костромская область, Буйский район, поселок Воскресенье, Центральная, 5	f	small
44719	43644	24	Костромская область, Буйский район, поселок Борок, Молодежная, 7	f	small
44716	43641	21	Костромская область, Буйский район, поселок Бараново, Главная, 4а	f	small
44717	43642	22	Костромская область, Буйский район, поселок Афонино, Гагаринская, 29	f	small
44704	43629	9	Костромская область, Антроповский район, поселок Трифон, 1а, здание Трифоновской основной школы	f	small
44698	43623	3	Костромская область, Антроповский район, поселок Словинка, Садовая, 16	f	small
44711	43625	5	Костромская область, Антроповский район, поселок Просек, Центральная, 1а	f	small
44710	43636	15	Костромская область, Антроповский район, поселок Понизье, 2, здание Понизовской основной школы	f	small
44708	43633	13	Костромская область, Антроповский район, поселок Помчище, 2, здание Помчищской начальной школы-детского сада	f	small
44709	43635	14	Костромская область, Антроповский район, поселок Пеньки, 29, административное здание Котельниковского сельского поселения	f	small
44707	43632	12	Костромская область, Антроповский район, поселок Палкино, Советская, 31	f	medium
41297	38434	485	Калужская область, Малоярославец, Школьная, 3	f	large
44703	43628	8	Костромская область, Антроповский район, село Михайловское, 4, административное здание Котельниковского сельского поселения	f	small
44699	43624	4	Костромская область, Антроповский район, поселок Курново, 26, здание Курновского сельского дома культуры	f	small
44705	43630	10	Костромская область, Антроповский район, поселок Курилово, Школьная, 5, улица Школьная, дом 7	f	small
44702	43627	7	Костромская область, Антроповский район, поселок Котельниково, 32, здание Котельниковской основной школы	f	small
44713	43638	18	Костромская область, Антроповский район, поселок Иваньково, 1	f	small
44701	43626	6	Костромская область, Антроповский район, поселок Бедрино, 87, здание Бедринской начальной школы	f	small
44697	43622	2	Костромская область, Антроповский район, поселок Антропово, Лебедева, 6, УИК: улица Октябрьская, дом 12	f	large
44696	43621	1	Костромская область, Антроповский район, поселок Антропово, Кирова, 8А	f	large
41527	38647	721	Калужская область, Юхнов, Билибина, 40	f	large
41065	38246	249	Калужская область, деревня Шопино, Центральная, 2	f	large
40869	38071	53	Калужская область, деревня Тимашово, Мира, 2	f	small
41460	38587	649	Калужская область, Таруса, Пушкина, 1	f	medium
41463	38590	652	Калужская область, Таруса, Луначарского, 33а	f	large
41306	38443	494	Калужская область, село Спас-Загорье	f	medium
41428	38556	616	Калужская область, Спас-Деменск, пер.Пионерский, 3	f	large
41427	38555	615	Калужская область, Спас-Деменск, Советская, 107	f	large
41394	38521	582	Калужская область, Обнинск, улица Энгельса, 2а	f	large
41382	38509	570	Калужская область, Обнинск, улица Энгельса, 13	f	large
41437	38565	626	Россия, Калужская область, Обнинск, улица Победы, 21	f	small
41390	38517	578	Калужская область, Обнинск, улица Курчатова, 33	f	large
41378	38506	566	Калужская область, Обнинск, улица Гагарина, 12	f	large
41380	38507	568	Калужская область, Обнинск, проспект Маркса, 56	f	large
41398	38525	586	Калужская область, Обнинск, проспект Ленина, 36	f	large
41397	38524	585	Калужская область, Обнинск, проспект Ленина, 15	f	large
41374	38503	562	Калужская область, Обнинск, проспект Ленина, 194	f	large
41372	38501	560	Калужская область, Обнинск, проспект Ленина, 192	f	large
41368	38497	556	Калужская область, Обнинск, проспект Ленина, 126	f	large
41362	38492	550	Калужская область, Обнинск, проспект Ленина, 71	f	large
41387	38514	575	Калужская область, Обнинск, квартал Студенческий городок, 1	f	medium
41388	38515	576	Калужская область, Обнинск, Энгельса, 2а	f	large
41384	38511	572	Калужская область, Обнинск, Энгельса, 14	f	large
41383	38510	571	Калужская область, Обнинск, Энгельса, 22	f	large
41364	38494	552	Калужская область, Обнинск, Треугольная площадь, 1	f	large
41363	38493	551	Калужская область, Обнинск, Треугольная площадь, 1	f	large
41396	38523	584	Калужская область, Обнинск, Пионерский проезд, 23	f	medium
41392	38519	580	Калужская область, Обнинск, Мира, 14	f	large
41391	38518	579	Калужская область, Обнинск, Мира, 14	f	large
41369	38498	557	Калужская область, Обнинск, Любого, 10	f	large
41393	38520	581	Калужская область, Обнинск, Курчатова, 16	f	large
41389	38516	577	Калужская область, Обнинск, Курчатова, 39	f	large
41361	38491	549	Калужская область, Обнинск, Кончаловского, 3	f	large
41371	38500	559	Калужская область, Обнинск, Комарова, 10	f	large
41370	38499	558	Калужская область, Обнинск, Комарова, 8	f	large
41386	38513	574	Калужская область, Обнинск, Калужская улица, 11	f	large
41385	38512	573	Калужская область, Обнинск, Калужская улица, 5	f	large
41381	38508	569	Калужская область, Обнинск, Звездная улица, 3	f	large
41367	38496	555	Калужская область, Обнинск, Гурьянова, 15	f	large
41366	38495	554	Калужская область, Обнинск, Гурьянова, 13	f	large
41395	38522	583	Калужская область, Обнинск, Гастелло, 17	f	large
41379	38505	567	Калужская область, Обнинск, Гагарина, 20	f	large
41377	38505	565	Калужская область, Обнинск, Гагарина, 20	f	large
41376	38505	564	Калужская область, Обнинск, Гагарина, 20	f	large
41375	38504	563	Калужская область, Обнинск, Гагарина, 47	f	large
41373	38502	561	Калужская область, Обнинск, Гагарина, 53	f	large
41305	38442	493	Калужская область, деревня Митинка, Помещение Фельдшерско-акушерского пункта	t	small
41298	38435	486	Калужская область, Малоярославец, площадь Жукова	f	large
40903	38082	87	Калужская область, Малоярославец, Школьная, 6	f	small
40851	38053	35	Калужская область, Малоярославец, Школьная, 6	f	small
41295	38432	483	Калужская область, Малоярославец, Российских Газовиков, 25	f	large
41294	38431	482	Калужская область, Малоярославец, Российских Газовиков, 1	f	large
41289	38426	477	Калужская область, Малоярославец, Радищева, 2	f	large
41288	38426	476	Калужская область, Малоярославец, Радищева, 2	f	large
41293	38430	481	Калужская область, Малоярославец, Московская, 60	f	large
41292	38429	480	Калужская область, Малоярославец, Московская, 42	f	large
41291	38428	479	Калужская область, Малоярославец, Кутузова, 76	f	large
41287	38425	475	Калужская область, Малоярославец, Кирова, 26	f	large
41285	38423	473	Калужская область, Малоярославец, Аузина, 1	f	large
41290	38427	478	Калужская область, Малоярославец, Радищева, 12	f	large
41273	38412	461	Калужская область, село Маклино, Администрация сельского поселения Село Маклино	f	large
41255	38394	442	Калужская область, Людиново, Щербакова, 1-б	f	large
41244	38383	431	Калужская область, Людиново, Соколова, 2	f	large
41254	38393	441	Калужская область, Людиново, Салтыкова-Щедрина, 9-а	f	large
41250	38389	437	Калужская область, Людиново, Карла Маркса, 48	f	large
41253	38392	440	Калужская область, Людиново, Дзержинского, 1	f	medium
40871	38073	55	Калужская область, деревня Коряково, Армейская, 32, кв2	f	small
40913	38109	97	Калужская область, Кондрово, Орджоникидзе, 20	f	large
41271	38410	459	Калужская область, село Коллонтай	t	medium
41203	38355	387	Калужская область, Козельск, Чкалова, ДКРА	f	large
41202	38355	386	Калужская область, Козельск, Чкалова, ДКРА	f	large
41195	38348	379	Калужская область, Козельск, Суворова, 22, МБОУ ООШ №4	f	medium
41187	38341	371	Калужская область, Киров, Пролетарская, 174	f	large
41182	38336	366	Калужская область, Киров, Ленина, 17	f	large
41322	38452	510	Калужская область, Картышово, Центральная, 13	f	medium
41159	38313	343	Калужская область, деревня Канищево, Канищевский СКДЦ	f	large
41112	38275	296	Калужская область, Калуга, Московский округ	f	medium
41064	38245	248	Калужская область, Калуга, деревня Тинино	f	small
41321	38451	509	Россия, Московская область, Одинцовский район, поселок городского типа Лесной городок, Центральная улица, 9	f	small
41156	38311	340	Калужская область, Калуга, Октябрьский округ, улица Центральная, 13а	f	large
41135	38297	319	Калужская область, Калуга, улица Хрустальная, 66	f	large
41093	38264	277	Калужская область, Калуга, улица Телевизионная, 5	f	large
41092	38264	276	Калужская область, Калуга, улица Телевизионная, 5	f	large
41091	38264	275	Калужская область, Калуга, улица Телевизионная, 5	f	large
41039	38221	223	Калужская область, Калуга, улица Суворова, 179	f	large
41108	38270	292	Калужская область, Калуга, улица Рылеева, 18	f	large
41106	38270	290	Калужская область, Калуга, улица Рылеева, 18	f	large
41105	38270	289	Калужская область, Калуга, улица Рылеева, 18	f	large
40951	38142	135	Калужская область, Калуга, улица Новослободская, 31	f	large
41071	38248	255	Калужская область, Калуга, улица Кибальчича, 19	f	large
41070	38248	254	Калужская область, Калуга, улица Кибальчича, 19	f	large
41068	38247	252	Калужская область, Калуга, улица Звездная, 19а	f	medium
41069	38247	253	Калужская область, Калуга, улица Звездная, 19а	f	large
134420	94322	330	Калужская область, Калуга, улица Дубрава, 3	f	large
41155	38310	339	Калужская область, Калуга, улица Дорожная, 17	f	large
41154	38310	338	Калужская область, Калуга, улица Дорожная, 17	f	large
41079	38255	263	Калужская область, Калуга, улица Гурьянова, 8к1	f	large
41126	38288	310	Калужская область, Калуга, улица Веры Андриановой, 3	f	large
41125	38288	309	Калужская область, Калуга, улица Веры Андриановой, 3	f	medium
41122	38285	306	Калужская область, Калуга, улица Билибина, 33	f	large
40952	38677	136	Калужская область, Калуга, площадь Вокзальная, 3	f	small
41119	38283	303	Калужская область, Калуга, переулок Малинники, 20	f	large
41115	38278	299	Калужская область, Калуга, переулок Дорожный, 5	f	large
41114	38277	298	Калужская область, Калуга, переулок Дорожный, 5	f	large
41133	38295	317	Калужская область, Калуга, маршала Жукова, 53	f	large
41132	38294	316	Калужская область, Калуга, маршала Жукова, 51	f	large
82027	56149	1192	Москва, Сиреневый бульвар, 3	f	large
41131	38293	315	Калужская область, Калуга, маршала Жукова, 35	f	large
41030	38213	214	Калужская область, Калуга, вилонов, 11	f	large
41075	38252	259	Калужская область, Калуга, бульвар Моторостроителей, 16	f	large
41077	38252	261	Калужская область, Калуга, бульвар Моторостроителей, 16	f	large
41076	38252	260	Калужская область, Калуга, бульвар Моторостроителей, 16	f	large
41058	38239	242	Калужская область, Калуга, Школьная, 3А	f	large
41094	38258	278	Калужская область, Калуга, Широкая, 51	f	large
41127	38289	311	Калужская область, Калуга, Чижевского, 17	f	large
41158	38312	342	Калужская область, Калуга, Центральная, 12а	f	small
41157	38312	341	Калужская область, Калуга, Центральная, 12а	f	large
41134	38296	318	Калужская область, Калуга, Хрустальная, 2	f	large
41130	38292	314	Калужская область, Калуга, Фридриха Энгельса, 14	f	large
41129	38291	313	Калужская область, Калуга, Фридриха Энгельса, 12	f	large
41044	38226	228	Калужская область, Калуга, Фридриха Энгельса, 119	f	large
41042	38224	226	Калужская область, Калуга, Фридриха Энгельса, 110	f	large
41150	38307	334	Калужская область, Калуга, Турынинская, 10а	f	large
41041	38223	225	Калужская область, Калуга, Тульская улица, 78а	f	large
41048	38229	232	Калужская область, Калуга, Тульская, 102	f	large
41148	38305	332	Калужская область, Калуга, Трудовая, 12	f	medium
41147	38305	331	Калужская область, Калуга, Трудовая, 12	f	large
41117	38280	301	Калужская область, Калуга, Тарутинская улица, 70/1	f	large
41118	38281	302	Калужская область, Калуга, Тарутинская, 70/1	f	large
41128	38290	312	Калужская область, Калуга, Суворова, 143	f	large
41026	38209	210	Калужская область, Калуга, Суворова, 118	f	large
41037	38219	221	Калужская область, Калуга, Степана Разина, 26	f	large
41061	38242	245	Калужская область, Калуга, Секиотовская, 13	f	medium
41032	38215	216	Калужская область, Калуга, Салтыкова-Щедрина, 10	f	large
41035	38217	219	Калужская область, Калуга, С-Щедрина,, 66А	f	large
41034	38217	218	Калужская область, Калуга, С-Щедрина,, 66А	f	large
41043	38225	227	Калужская область, Калуга, С-Щедрина, 66	f	large
41019	38202	203	Калужская область, Калуга, Рылеева, 39	f	large
41060	38241	244	Калужская область, Калуга, Ромодановские Дворики, 61	f	large
41103	38269	287	Калужская область, Калуга, Пухова, 54	f	large
41101	38268	285	Калужская область, Калуга, Пухова, 52	f	large
41102	38268	286	Калужская область, Калуга, Пухова, 52	f	large
41100	38268	284	Калужская область, Калуга, Пухова, 52	f	large
41107	38271	291	Калужская область, Калуга, Пролетарская улица, 40	f	large
41057	38238	241	Калужская область, Калуга, Привокзальная, 11А	f	large
41085	38259	269	Калужская область, Калуга, Поселковая, 4	f	large
41109	38272	293	Калужская область, Калуга, Плеханова, 2	f	large
41090	38263	274	Калужская область, Калуга, Окружная, 4к3	f	medium
41116	38279	300	Калужская область, Калуга, Новослободская, 25	f	large
41036	38218	220	Калужская область, Калуга, Николо-Козинская улица, 68	f	large
41051	38232	235	Калужская область, Калуга, Никитина, 121	f	large
41049	38230	233	Калужская область, Калуга, Никитина, 74	f	large
41153	38309	337	Калужская область, Калуга, Московская, 311	f	large
41104	38267	288	Калужская область, Калуга, Московская, 79	f	large
41099	38267	283	Калужская область, Калуга, Московская, 79	f	large
41098	38267	282	Калужская область, Калуга, Московская, 79	f	large
41097	38266	281	Калужская область, Калуга, Московская, 165	f	large
41096	38266	280	Калужская область, Калуга, Московская, 165	f	large
41089	38262	273	Калужская область, Калуга, Московская, 212	f	large
41088	38262	272	Калужская область, Калуга, Московская, 212	f	large
41087	38261	271	Калужская область, Калуга, Московская, 221а	f	large
41438	38566	627	Калужская область, Калуга, Молодежная, 1	f	small
41141	38302	325	Калужская область, Калуга, Молодежная, 19/14	f	large
41140	38301	324	Калужская область, Калуга, Молодежная, 5	f	large
41139	38301	323	Калужская область, Калуга, Молодежная, 5	f	large
41047	38228	231	Калужская область, Калуга, Мичурина, 45	f	large
41046	38228	230	Калужская область, Калуга, Мичурина, 45	f	large
41138	38300	322	Калужская область, Калуга, Маяковского, 35	f	small
41137	38299	321	Калужская область, Калуга, Маяковского, 55	f	large
41040	38222	224	Калужская область, Калуга, М.Жукова, 12	f	large
82004	56149	1169	Москва, Сиреневый бульвар, 3	f	large
41152	38308	336	Калужская область, Калуга, Льва Толстого, 51	f	large
41151	38308	335	Калужская область, Калуга, Льва Толстого, 51	f	large
41029	38212	213	Калужская область, Калуга, Луначарского, 16	f	large
41120	38284	304	Калужская область, Калуга, Луговая, 43	f	large
41121	38284	305	Калужская область, Калуга, Луговая, 43	f	large
41059	38240	243	Калужская область, Калуга, Лесная, 24, к.1	f	large
41123	38286	307	Калужская область, Калуга, Ленина, 14	f	large
41028	38211	212	Калужская область, Калуга, Ленина, 83	f	large
41027	38210	211	Калужская область, Калуга, Ленина, 74	f	large
41023	38206	207	Калужская область, Калуга, Ленина, 103	f	large
41022	38205	206	Калужская область, Калуга, Кутузова, 22	f	medium
41074	38251	258	Калужская область, Калуга, Кубяка, 8	f	large
41073	38250	257	Калужская область, Калуга, Кубяка, 1к1	f	large
41072	38249	256	Калужская область, Калуга, Кубяка, 4	f	large
41017	38200	201	Калужская область, Калуга, Королева, 39стр.1	f	large
41038	38220	222	Калужская область, Калуга, Кирова, 31	f	large
41095	38265	279	Калужская область, Калуга, Карла Либкнехта, 1	f	large
110352	38234	237	Калужская область, Калуга, Заречная, 72	f	\N
41024	38207	208	Калужская область, Калуга, Дзержинского, 49	f	large
41113	38276	297	Калужская область, Калуга, Гурьянова, 67	f	small
41082	38257	266	Калужская область, Калуга, Гурьянова, 65	f	large
41083	38257	267	Калужская область, Калуга, Гурьянова, 65	f	large
41080	38256	264	Калужская область, Калуга, Гурьянова, 35	f	large
41081	38256	265	Калужская область, Калуга, Гурьянова, 35	f	large
41144	38303	328	Калужская область, Калуга, Грабцевское шоссе, 126	f	large
41143	38303	327	Калужская область, Калуга, Грабцевское шоссе, 126	f	large
41142	38303	326	Калужская область, Калуга, Грабцевское шоссе, 126	f	large
41136	38298	320	Калужская область, Калуга, Грабцевское шоссе, 22а	f	large
41086	38260	270	Калужская область, Калуга, Глаголева, 10а	f	large
41025	38208	209	Калужская область, Калуга, Герцена, 34	f	large
41054	38235	238	Калужская область, Калуга, Генерала Попова, 17	t	large
41018	38201	202	Калужская область, Калуга, Гагарина, 3	f	large
41056	38237	240	Калужская область, Калуга, Вишневского, 27	f	large
41055	38236	239	Калужская область, Калуга, Вишневского, 5	f	large
41031	38214	215	Калужская область, Калуга, Вилонова, 16	f	large
41124	38287	308	Калужская область, Калуга, Веры Андриановой, 68	f	large
41050	38231	234	Калужская область, Калуга, Болдина, 15	f	large
41045	38227	229	Калужская область, Калуга, Болдина, 18	f	large
41033	38216	217	Калужская область, Калуга, Беляева, 2	f	large
41020	38203	204	Калужская область, Калуга, Баумана, 29	f	large
41021	38204	205	Калужская область, Калуга, Баженова, 2	f	large
40893	38096	77	Калужская область, Калуга, Архангельская, 1	f	small
41052	38233	236	Калужская область, Калуга, Академическая улица, 6	f	large
41016	38199	200	Калужская область, Калуга, Академика Королева, 14/25	f	large
41078	38254	262	Калужская область, Калуга, Азаровская улица, 21	f	large
41149	38306	333	Калужская область, Калуга, 5-я линия, 1к2	f	large
41145	38304	329	Калужская область, Калуга, Дубрава, 1	f	large
40972	38160	156	Калужская область, садовое товарищество Истья, Совхозная, 15, Администрация МО СП с.Истье	f	small
41302	38439	490	Калужская область, деревня Захарово, Помещение администрации сельского поселения	f	small
40999	38185	183	Калужская область, Жуков, Ленина, 12	f	large
40998	38184	182	Калужская область, Жуков, Ленина, 32, Жуковская детская школа искусств №2	f	large
40997	38183	181	Калужская область, Жуков, Ленина, 2, ГДК КНИРТИ 	f	large
41001	38186	185	Калужская область, Жуков, Гурьянова, 4, Администрация ГП г.Жуков	f	large
41000	38186	184	Калужская область, Жуков, Гурьянова, 4, Администрация ГП г.Жуков	f	large
40884	38087	68	Калужская область, Ермолино, Русиново, 143	f	large
40885	38088	69	Калужская область, Ермолино, Московское Большое кольцо, ФГУП Ермолино Россельхозакадемии	f	small
40882	38085	66	Калужская область, Ермолино, К. Маркса, 1	f	large
40886	38089	70	Калужская область, Ермолино, 1 Мая, 1	f	small
40883	38086	67	Калужская область, Ермолино, 1 Мая, 3	f	large
40947	38138	131	Калужская область, деревня Дубровка, Центральная, 108	f	small
41491	38619	683	Калужская область, поселок Грабцево, Советская, 2	f	medium
40872	38074	56	Калужская область, село Ворсино, школьная, 11	f	large
40860	38062	44	Калужская область, Боровск, адм. здание ВНИИФБиП с/х животных	f	medium
40856	38058	40	Калужская область, Боровск, улица Ленина, 19	f	large
40861	38063	45	Калужская область, Боровск, калинина, 1	f	large
40855	38057	39	Калужская область, Боровск, Ленина, 47	f	large
40858	38060	42	Калужская область, Боровск, Коммунистическая, 69	f	medium
40859	38061	43	Калужская область, Боровск, Большая, 38	f	small
40857	38059	41	Калужская область, Боровск, Берникова, 114	f	large
40862	38064	46	Калужская область, Боровск, 1 Мая, 51	f	medium
40986	38173	170	Калужская область, Белоусово, московская, 53, Белоусовская школа №1 актовый зал	f	large
40988	38175	172	Калужская область, Белоусово, Московская, 95, КДЦ Созвездие 2 этаж банкетный зал	f	large
40987	38174	171	Калужская область, Белоусово, Мирная, 11, Администрация ГП г.Белоусово	f	large
40989	38176	173	Калужская область, Белоусово, Гурьянова, 33, Белоусовская школа №2, актовый зал	f	large
40879	38081	63	Калужская область, Балабаново, улица Гагарина, 13	f	large
40878	38080	62	Калужская область, Балабаново, Московская, 5А	f	large
40874	38076	58	Калужская область, Балабаново, Мичурина, 19	f	medium
40873	38075	57	Калужская область, Балабаново, Коммунальная, 12	f	small
40875	38077	59	Калужская область, Балабаново, Кап. Королева, 1	f	large
40881	38084	65	Калужская область, Балабаново, Дзержинского, МОУ Средняя школа №2	f	large
40880	38083	64	Калужская область, Балабаново, Дзержинского, клуб в/ч, 42335	f	large
40877	38079	61	Калужская область, Балабаново, Гагарина, 12	f	large
40876	38078	60	Калужская область, Балабаново, Боровская улица, 2А	f	large
41508	38629	700	Калужская область, деревня Аристово, 17	f	small
41478	38605	667	Калужская область, район Ульяновский район, поселок Заречье, Здание Озеренского ФАП	f	small
41528	38648	722	Калужская область, Юхновский район, Юхнов, Карла Маркса, 6	f	large
41540	38660	734	Калужская область, Юхновский район, поселок Щелканово, Молодежная, 22	f	small
41539	38659	733	Калужская область, Юхновский район, поселок Чемоданово, Центральная, 20	t	small
41538	38658	732	Калужская область, Юхновский район, поселок Упрямово, Цветочная, 2	f	small
41537	38657	731	Калужская область, Юхновский район, поселок Рыляки, Новые Черемушки, 15	f	medium
41536	38656	730	Калужская область, Юхновский район, поселок Порослицы, Зеленая, 20	f	small
41408	38535	596	Калужская область, Юхновский район, поселок Погореловка, 55	f	small
41532	38652	726	Калужская область, Юхновский район, поселок Погореловка, Цветочная, 2	t	small
41535	38655	729	Калужская область, Юхновский район, поселок Плоское, калужская, 2	t	small
41534	38654	728	Калужская область, Юхновский район, поселок Озеро, Молодежная, 6	f	small
41533	38653	727	Калужская область, Юхновский район, поселок Куркино, Школьная, 2	f	small
41304	38441	492	Калужская область, Юхновский район, поселок Кудиново, Помещение администрации сельского поселения Село Кудиново	f	large
41531	38651	725	Калужская область, Юхновский район, поселок Колыхманово, центральная, 16	f	small
41530	38650	724	Калужская область, Юхновский район, поселок Климов Завод, Генерала М.Г. Ефремова, 45	f	small
41541	38661	735	Калужская область, Юхновский район, поселок Зубово, Шоссейная, 6	t	small
41543	38663	737	Калужская область, Юхновский район, поселок Емельяновка, Центральная, 15	t	small
41162	38316	346	Калужская область, Юхновский район, поселок Выползово, сельский дом культуры	t	small
41529	38649	723	Калужская область, Юхновский район, поселок Беляево, Центральная, 11	f	small
41523	38644	716	Калужская область, Хвастовичский район, поселок Хвастовичи, ленина, 28	f	large
41524	38645	717	Калужская область, Хвастовичский район, поселок Хвастовичи, Павлова, 7	f	large
41454	38581	643	Калужская область, Хвастовичский район, поселок Фролово, 10	f	small
41515	38636	708	Калужская область, Хвастовичский район, поселок Теребень, Советская, 7	f	small
41425	38553	613	Калужская область, Хвастовичский район, поселок Стайки, Школьная, 1	f	small
41520	38641	713	Калужская область, Хвастовичский район, поселок Подбужье, Молодежная, 4	f	small
41519	38640	712	Калужская область, Хвастовичский район, поселок Пеневичи, декабристов, 2	f	small
41518	38639	711	Калужская область, Хвастовичский район, поселок Нехочи, Центральная, 1	f	small
82003	56149	1168	Москва, Сиреневый бульвар, 3	f	large
41240	37983	424	Калужская область, Хвастовичский район, поселок Милеево, 77	t	small
41517	38638	710	Калужская область, Хвастовичский район, поселок Милеево, Гривская, 1	t	small
41516	38637	709	Калужская область, Хвастовичский район, поселок Ловать, Волостная, 20	t	small
41514	38635	707	Калужская область, Хвастовичский район, поселок Кудрявец, советская, 7	f	small
41513	38634	706	Калужская область, Хвастовичский район, поселок Красное, Комсомольская, 107	f	small
41512	38633	705	Калужская область, Хвастовичский район, поселок Колодяссы, Новостройка, 14	f	small
41525	38646	718	Калужская область, Хвастовичский район, поселок Еленский, Партизанский проспект 	f	large
41511	38632	704	Калужская область, Хвастовичский район, поселок Воткино, Советская, 4	t	small
41165	38319	349	Калужская область, Хвастовичский район, поселок Буда, сельский дом культуры	f	small
41510	38631	703	Калужская область, Хвастовичский район, поселок Бояновичи, коммунарская, 27/А	f	small
41542	38662	736	Калужская область, Хвастовичский район, поселок Барановка, 46	t	small
41509	38630	702	Калужская область, Хвастовичский район, поселок Авдеевка, пер.Березовый, 1	t	small
41504	34242	696	Калужская область, Ферзиковский район, поселок Ястребовка, 4	f	small
41499	34028	691	Калужская область, Ферзиковский район, поселок Ферзиково, 46	f	medium
41506	38627	698	Калужская область, Ферзиковский район, поселок Ферзиково, красноцветова, 1	f	large
41505	38626	697	Калужская область, Ферзиковский район, поселок Ферзиково, Карпова, 20	f	large
41498	33786	690	Калужская область, Ферзиковский район, поселок Сугоново, 51	f	small
41497	38625	689	Калужская область, Ферзиковский район, поселок Сашкино, 27	f	medium
41409	38536	597	Калужская область, Ферзиковский район, поселок Покровское, 65	f	small
41221	38373	405	Калужская область, Ферзиковский район, поселок Плюсково, МБОУ <<Средняя общеобразовательная школа>>	t	small
40928	38124	112	Калужская область, Ферзиковский район, поселок Плюсково, Центральная, 42	t	small
41502	38611	694	Калужская область, Ферзиковский район, поселок Октябрьский, 4 г	f	medium
41496	38624	688	Россия, Брянская область, Краснорский район, поселок Красный Городок	f	small
41495	38623	687	Калужская область, Ферзиковский район, поселок Кольцово, Колхозная, 3	f	small
41494	38622	686	Калужская область, Ферзиковский район, поселок Зудна, Лесная, 10	t	small
41503	38612	695	Калужская область, Ферзиковский район, поселок Желябужский, школьная, 12	t	small
41493	38621	685	Калужская область, Ферзиковский район, поселок Дугна, Больничная, 11	f	medium
41507	38628	699	Калужская область, Ферзиковский район, поселок Бронцы, центральная, 6	f	medium
41492	38620	684	Калужская область, Ферзиковский район, поселок Богданино, 88	f	small
41501	38547	693	Калужская область, Ферзиковский район, поселок Бебелево, Центральная, 30	f	medium
41500	34050	692	Калужская область, Ферзиковский район, поселок Авчурино, Центральная, 23 а	f	medium
41488	38617	677	Калужская область, Ульяновский район, поселок Ульяново	t	small
41490	38618	679	Калужская область, Ульяновский район, поселок Ульяново, Большая Советская, 88	f	large
41489	38618	678	Калужская область, Ульяновский район, поселок Ульяново, Большая Советская, 88	f	medium
41487	38616	676	Калужская область, Ульяновский район, поселок Поздняково	f	small
41486	38615	675	Калужская область, Ульяновский район, поселок Поздняково	t	small
41485	38614	674	Калужская область, Ульяновский район, поселок Поздняково	f	small
41484	38613	673	Калужская область, Ульяновский район, поселок Поздняково	f	small
40945	38136	129	Калужская область, Ульяновский район, поселок Новый Свет, 125	f	medium
41483	38610	672	Калужская область, Ульяновский район, поселок Мелехово	f	small
41482	38609	671	Калужская область, Ульяновский район, поселок Мелехово	f	small
41479	38606	668	Калужская область, Ульяновский район, поселок Заречье	f	small
41475	38602	664	Калужская область, Ульяновский район, поселок Дудоровский	f	medium
41342	38472	530	Калужская область, Ульяновский район, поселок Долгое, Ани Морозовой, 7	f	small
40824	38030	6	Калужская область, Ульяновский район, поселок Вязовна	f	small
41477	38604	666	Калужская область, Ульяновский район, поселок Волосово-Дудино	f	small
41476	38603	665	Калужская область, Ульяновский район, поселок Волосово-Дудино	f	small
41296	38433	484	Новгородская область, Мошенской район, село Чуриково	f	large
41461	38588	650	Калужская область, Тарусский район, Таруса, Шевякова, 10	f	large
41459	38586	648	Калужская область, Тарусский район, Таруса, Марины Цветаевой, 1	f	large
41462	38589	651	Калужская область, Тарусский район, Таруса, Ленина, 74	f	large
41467	38594	656	Калужская область, Тарусский район, поселок Роща, Центральная, 15	t	small
41474	38601	663	Калужская область, Тарусский район, поселок Похвиснево, Центральная, 3	t	small
41468	38595	657	Калужская область, Тарусский район, поселок Петрищево, переулок Садовый, 1	f	small
41466	38593	655	Калужская область, Тарусский район, поселок Некрасово, Тарусская, 23/1	f	small
41405	38532	593	Калужская область, Тарусский район, поселок Макарово, 11	f	small
41473	38600	662	Калужская область, Тарусский район, поселок Лопатино, Центральная, 4б	f	medium
41464	38591	653	Калужская область, Тарусский район, поселок Кузьмищево, Центральная, 10	f	medium
41465	38592	654	Калужская область, Тарусский район, поселок Кузьмищево, Вишневая, 17	f	small
40937	38133	121	Калужская область, Тарусский район, поселок Кочуково, 15	f	small
41471	38598	660	Калужская область, Тарусский район, поселок Волковское, Полевая, 62	f	small
41472	38599	661	Калужская область, Тарусский район, поселок Вознесение, Центральная, 4	f	small
41470	38597	659	Калужская область, Тарусский район, поселок Барятино, Советская, 15	f	small
41469	38596	658	Калужская область, Тарусский район, поселок Алекино, Садовая, 1	t	small
41455	38582	644	Калужская область, Сухиничский район, поселок Юрьево, 34	f	small
41452	38579	641	Калужская область, Сухиничский район, поселок Шлипово, 68	f	medium
41444	38571	633	Калужская область, Сухиничский район, поселок Хотень, 76	f	small
41451	38578	640	Калужская область, Сухиничский район, поселок Уруга, 21	t	small
41449	38576	638	Калужская область, Сухиничский район, поселок Татаринцы, речная, 15	f	small
41432	38560	621	Калужская область, Сухиничский район, Сухиничи, чкалова, 55	f	large
41456	38583	645	Калужская область, Сухиничский район, Сухиничи, ленина, 56	f	large
41458	38585	647	Калужская область, Сухиничский район, Сухиничи, Марченко, 53	f	large
41431	38559	620	Калужская область, Сухиничский район, Сухиничи, Ленина,, 49	f	large
41457	38584	646	Калужская область, Сухиничский район, Сухиничи, Ленина, 92	f	large
41433	38561	622	Калужская область, Сухиничский район, Сухиничи, Дзержинского, 11	f	large
41448	38575	637	Калужская область, Сухиничский район, поселок Субботники, 64	f	small
41447	38574	636	Калужская область, Сухиничский район, поселок Соболевка, 42	f	small
41434	38562	623	Калужская область, Сухиничский район, поселок Середейский, Комсомольская, 11	f	large
41446	38573	635	Калужская область, Сухиничский район, поселок Радождево, 75а	t	small
41442	33276	631	Калужская область, Сухиничский район, поселок Ермолово, 39	t	small
41441	38569	630	Калужская область, Сухиничский район, поселок Дабужа, 123	f	small
41439	38567	628	Калужская область, Сухиничский район, поселок Глазково, 46	t	small
41450	38577	639	Калужская область, Сухиничский район, поселок Володино, 44	f	small
41445	38572	634	Калужская область, Сухиничский район, поселок Брынь, 102а	f	small
40935	38131	119	Калужская область, Сухиничский район, поселок Брынь, им. Т.П. Полянской, 16	f	medium
41436	38564	625	Калужская область, Сухиничский район, поселок Бордуково, 59	f	small
41443	38570	632	Калужская область, Сухиничский район, поселок Богданово-Колодези, 77	f	small
41435	38563	624	Калужская область, Сухиничский район, поселок Алнеры, 1	f	small
41430	38558	618	Калужская область, Спас-Деменский район, поселок Чипляево, Центральная, 7	f	medium
41329	38459	517	Калужская область, Спас-Деменский район, поселок Терпилово, Мира, 1	f	small
41424	38552	612	Калужская область, Спас-Деменский район, поселок Теплово, Центральная, 5	t	small
41522	38643	715	Калужская область, Спас-Деменский район, поселок Стайки, Молодежная, 19	f	small
41426	38554	614	Калужская область, Спас-Деменский район, поселок Снопот, Снопотская, 1	t	small
41421	38549	609	Калужская область, Спас-Деменский район, поселок Понизовье, приозерная, 2	t	small
41423	38551	611	Калужская область, Спас-Деменский район, поселок Павлиново, Центральная, 10	f	small
37972	34544	287	Ивановская область, Тейково, Октябрьская, 3	f	large
41419	38546	607	Калужская область, Спас-Деменский район, поселок Новоалександровский, Школьный переулок, 5	f	small
41420	38548	608	Калужская область, Спас-Деменский район, поселок Нестеры, Бориса Кривельского, 8	t	small
41417	38544	605	Калужская область, Спас-Деменский район, поселок Любунь, переулок школьный, 6	f	small
41429	38557	617	Калужская область, Спас-Деменский район, поселок Буднянский, Школьная, 16	t	small
41416	38543	604	Калужская область, Спас-Деменский район, поселок Болва, Центральная, 11	f	small
41411	38538	599	Калужская область, Перемышльский район, поселок Сильково, 110	f	small
41407	38534	595	Калужская область, Перемышльский район, поселок Перемышль, ленина, 54	f	large
41404	38531	592	Калужская область, Перемышльский район, поселок Корекозево, Центральная, 55	f	medium
41399	38526	587	Калужская область, Перемышльский район, поселок Калужской опытной сельскохозяйственой станции, Центральная	f	large
41415	38542	603	Калужская область, Перемышльский район, поселок Григоровское, 57	t	small
41401	38528	589	Калужская область, Перемышльский район, поселок Гремячево, 191 А	t	small
41414	38541	602	Калужская область, Перемышльский район, поселок Борищево, 90	f	small
41403	38530	591	Калужская область, Перемышльский район, поселок Большие Козлы, 17 Б	f	medium
41413	38540	601	Калужская область, Перемышльский район, поселок Ахлебинино, Центральная, 64	f	medium
41014	38198	198	Калужская область, Новосокольнический район, село Михали, 48	t	small
41341	38471	529	Калужская область, Мосальский район, колхоз Шаховский, центральная, 10	f	small
41360	38490	548	Калужская область, Мосальский район, поселок Устоша, широкая, 8	t	small
41351	38481	539	Калужская область, Мосальский район, поселок Тарасково, Молодежная, 16	t	small
41347	38477	535	Калужская область, Мосальский район, колхоз Раменский, Центральная, 10	t	small
41352	38482	540	Калужская область, Мосальский район, поселок Рамено, Садовая, 14	f	small
41348	38478	536	Калужская область, Мосальский район, поселок Путогино, Дружбы, 1	f	small
41345	38475	533	Калужская область, Мосальский район, поселок Посконь, Центральная, 1	t	small
41346	38476	534	Калужская область, Мосальский район, поселок Передовик, школьная, 1Б	t	small
41355	38485	543	Калужская область, Мосальский район, Мосальск, кирова, 44	f	large
41354	38484	542	Калужская область, Мосальский район, Мосальск, Революции, 10	f	large
41344	38474	532	Калужская область, Мосальский район, поселок Людково, Шоссейная, 11	f	small
41216	38368	400	Россия	f	medium
41343	38473	531	Калужская область, Мосальский район, поселок Калуговский, Школьная, 7	f	small
41359	38489	547	Калужская область, Мосальский район, поселок Дашино, сельская, 30	t	small
41358	38488	546	Россия, Брянская область, Жирятинский район, поселок Горбачи	f	small
41357	38487	545	Калужская область, Мосальский район, поселок Гачки, центральная, 32	f	small
40940	35456	124	Россия, Московская область, Шаховской район, деревня Высокое	f	small
41353	38483	541	Калужская область, Мосальский район, поселок Боровенск, центральная, 1	t	small
41327	38457	515	Калужская область, Мещовский район, поселок Торкотино, центральная, 8	f	small
41328	38458	516	Калужская область, Мещовский район, поселок Серпейск, пушкина, 7	f	medium
41337	38467	525	Калужская область, Мещовский район, поселок Серебряно, Центральная, 3	f	small
41335	38465	523	Калужская область, Мещовский район, поселок Растворово, садовая, 9	f	small
41323	38453	511	Калужская область, Мещовский район, поселок Поповка, Козельская, 4	f	medium
41340	38470	528	Калужская область, Мещовский район, поселок Подкопаево, лесная, 4	f	small
41336	38466	524	Калужская область, Мещовский район, поселок Нестеровка, Коммунарская, 16	t	small
41324	38454	512	Калужская область, Мещовский район, поселок Мошонки, старая, 28	f	small
41333	38463	521	Калужская область, Мещовский район, Мещовск, проспект Революции, 28	f	large
41334	38464	522	Калужская область, Мещовский район, Мещовск, площадь Ленина, 3	f	large
41326	38456	514	Калужская область, Мещовский район, поселок Мармыжи, Школьная, 5	f	small
41330	38460	518	Россия, Смоленская область, Угранский район, поселок Казаковка	t	small
41339	38469	527	Калужская область, Мещовский район, поселок Гаврики, Молодежная, 5	f	small
37986	34556	301	Ивановская область, Тейково, Молодежная, 24	f	large
41338	38468	526	Калужская область, Мещовский район, поселок Большое Алешино, Новая, 1	f	small
41013	38197	197	Калужская область, Медынский район, поселок Хвощи, Мира, 2	f	small
41310	33090	498	Калужская область, Медынский район, поселок Романово, 23	f	medium
40894	38097	78	Калужская область, Медынский район, поселок Редькино, 15	f	medium
41308	32422	496	Калужская область, Медынский район, поселок Передел, 85	f	small
40901	36896	85	Калужская область, Медынский район, поселок Обухово, 2а	f	small
41307	32321	495	Калужская область, Медынский район, поселок Никитское, 122	f	small
41320	38450	508	Калужская область, Медынский район, поселок Михальчуково, 3	f	medium
41316	38446	504	Калужская область, Медынский район, Медынь, проспект Ленина, 2	f	large
41317	38447	505	Калужская область, Медынский район, Медынь, Володарского, 63	f	large
41319	38449	507	Калужская область, Медынский район, поселок Кременское, 181	f	small
41315	38445	503	Калужская область, Медынский район, поселок Гусево, 1	f	small
41314	38444	502	Калужская область, Медынский район, поселок Глухово, 36	t	small
41318	38448	506	Калужская область, Медынский район, поселок Варваровка, 56	f	small
41309	32516	497	Калужская область, Медынский район, поселок Брюхово, 50	t	small
41313	33122	501	Калужская область, Медынский район, поселок Адуево, 115	f	small
41279	38418	467	Курская область, поселок Юбилейный	f	large
41280	38419	468	Калужская область, Малоярославецкий район, поселок Шумятино	t	small
41272	38411	460	Калужская область, Малоярославецкий район, Село Головтеево, Помещение администрации	f	large
41278	38417	466	Калужская область, Малоярославецкий район, поселок Рябцево	f	small
41276	38415	464	Псковская область, Дедовичский район, село Поречье	f	small
41281	38420	469	Калужская область, Малоярославецкий район, поселок Панское	f	small
41275	38414	463	Калужская область, Малоярославецкий район, поселок Недельное	t	medium
41274	38413	462	Московская область, городской округ Домодедово, деревня Михеево	t	small
41312	33106	500	Калужская область, Малоярославецкий район, поселок Михеево, 137	f	small
41301	38438	489	Ярославская область, Ярославский район, поселок Ерденево	t	medium
41284	38422	472	Калужская область, Малоярославецкий район, поселок Детчино	f	large
41283	38422	471	Калужская область, Малоярославецкий район, поселок Детчино	f	large
41300	38437	488	Калужская область, Малоярославецкий район, санаторий Воробьево	f	medium
41299	38436	487	Московская область, Рузский район, деревня Воробьево	f	medium
41350	38480	538	Калужская область, Людиновский район, поселок Савино, Центральная, 2	f	small
41267	38406	454	Калужская область, Людиновский район, поселок Манино, Горчакова, 38	f	small
41245	38384	432	Калужская область, Людиновский район, Людиново, энгельса, 48	f	large
41249	38388	436	Калужская область, Людиновский район, Людиново, фокина, 55	f	large
41252	38391	439	Калужская область, Людиновский район, Людиново, сестер хотеевых, 5	f	large
41247	38386	434	Калужская область, Людиновский район, Людиново, попова, 33	f	large
41258	38397	445	Калужская область, Людиновский район, Людиново, герцена, 24	f	large
41257	38396	444	Калужская область, Людиновский район, Людиново, Щербакова, 1	f	large
41256	38395	443	Калужская область, Людиновский район, Людиново, Щербакова, 3	f	large
41248	38387	435	Калужская область, Людиновский район, Людиново, Чугунова, 4	f	large
41260	38399	447	Калужская область, Людиновский район, Людиново, Черняховского, 17-б	f	large
41251	38390	438	Калужская область, Людиновский район, Людиново, Московская, 17	f	large
41259	38398	446	Калужская область, Людиновский район, Людиново, Маяковского, 250а	f	large
41242	38381	429	Калужская область, Людиновский район, Людиново, Ленина, 3-а	f	large
41246	38385	433	Калужская область, Людиновский район, Людиново, Крупской, 66	f	large
41243	38382	430	Калужская область, Людиновский район, Людиново, Кропоткина, 1	f	large
41265	38404	452	Калужская область, Людиновский район, поселок Куява, Сельский клуб	f	small
41262	38401	449	Калужская область, Людиновский район, поселок Космачово, переулок Школьный, 8	f	small
41266	38405	453	Калужская область, Людиновский район, поселок Колчино, Новая, 1/2	t	small
41261	38400	448	Калужская область, Людиновский район, поселок Игнатовка, Центральная, 20	f	small
41270	38409	457	Калужская область, Людиновский район, поселок Заболотье, Центральная, 4	f	small
41269	38408	456	Калужская область, Людиновский район, поселок Войлово, Центральная, 1	f	small
41264	38403	451	Калужская область, Людиновский район, поселок Вербежичи, ФАП д.Вербежичи	f	small
41268	38407	455	Калужская область, Людиновский район, поселок Букань, Сельский Дом Культуры с.Букань 	f	small
41237	37818	421	Калужская область, Куйбышевский район, поселок Суборово, 8	t	small
41453	38580	642	Калужская область, Куйбышевский район, поселок Новосельский, 8	f	small
41232	36825	416	Калужская область, Куйбышевский район, поселок Новодяглево, 14 А	t	small
41235	37583	419	Калужская область, Куйбышевский район, поселок Мокрое, центральная, 40	f	small
41229	38282	413	Калужская область, Куйбышевский район, поселок Лужница, 121	f	small
41233	36843	417	Калужская область, Куйбышевский район, поселок Кузьминичи, центральная, 3	f	small
41228	38380	412	Калужская область, Куйбышевский район, поселок Зимницы, 78	t	small
41238	37892	422	Калужская область, Куйбышевский район, поселок Закрутое, 23	f	small
41230	38362	414	Калужская область, Куйбышевский район, поселок Жерелево, 52А	f	small
41231	30184	415	Калужская область, Куйбышевский район, поселок Желны, 54	t	small
41241	32305	425	Калужская область, Куйбышевский район, поселок Емельяновичи, 32	f	small
40845	32071	29	Россия, Калужская область, Куйбышевский район, поселок Дегонка	f	small
41239	37950	423	Россия, Краснодарский край, Большой Сочи Адлеровский район, село Высокое	f	small
41227	38379	411	Калужская область, Куйбышевский район, поселок Ветмица, 91	t	small
41226	38378	410	Калужская область, Куйбышевский район, поселок Бутчино, центральная, 47	f	small
41225	38377	409	Калужская область, Куйбышевский район, поселок Бетлица, Ленина, 3А	f	medium
41224	38376	408	Калужская область, Куйбышевский район, поселок Бетлица, Калинина, 2	f	large
41194	38347	378	Калужская область, Козельский район, поселок Чернышено, администрация СП Село Чернышено	t	small
41210	38361	394	Калужская область, Козельский район, Сосенский, МДОУ д/с Колокольчик	f	large
41209	38360	393	Калужская область, Козельский район, Сосенский, МБУК Сосенское городское КДО, ДК Горняк	f	large
41208	38359	392	Калужская область, Козельский район, Сосенский, Средняя общеобразовательная школа №1	f	large
41207	38358	391	Калужская область, Козельский район, Сосенский, Средняя общеобразовательная школа №2	f	large
41206	38357	390	Калужская область, Козельский район, Сосенский, МБУК Сосенское городское КДО ДК Прометей	f	large
41205	38356	389	Калужская область, Козельский район, Сосенский, МДОУ д/с Рябинка	f	large
41193	38346	377	Калужская область, Козельский район, поселок Сенино 1-е, администрация СП Деревня Сенино-Первое	t	small
41192	38345	376	Калужская область, Козельский район, поселок Попелево	f	medium
41223	38375	407	Калужская область, Козельский район, поселок Покровск, МБОУ Основная общеобразовательная школа	t	small
41222	38374	406	Калужская область, Козельский район, поселок Подборки, МБОУ Основная общеобразовательная школа	f	medium
41220	38372	404	Калужская область, Козельский район, поселок Нижние Прыски, МБОУ Основная общеобразовательная школа	f	medium
40939	32260	123	Калужская область, Козельский район, поселок Маслово, 52	t	small
41219	38371	403	Калужская область, Козельский район, поселок Лавровск, администрация СП Деревня Лавровск	t	small
41204	38672	388	Калужская область, Козельский район, Козельск, домоуправление	t	large
41200	38353	384	Калужская область, Козельский район, Козельск, городской Дом Культуры №2	f	medium
41198	38351	382	Калужская область, Козельский район, Козельск, Чкалова, 27	f	large
41201	38354	385	Калужская область, Козельский район, Козельск, Заводская, МБОУ ООШ №2	f	large
41199	38352	383	Калужская область, Козельский район, Козельск, Генерала Бурмака, МБОУ <<СОШ №3>>	f	large
41197	38350	381	Калужская область, Козельский район, Козельск, Большая Советская, 47а	f	large
41196	38349	380	Калужская область, Козельский район, Козельск, Большая Советская, 25	f	medium
41218	38370	402	Калужская область, Козельский район, поселок Киреевское 1-е, Слаговищенский сельский клуб	f	small
41160	38314	344	Калужская область, Калуга городской округ, поселок Ильинка, Центральная, 39	f	small
41217	38369	401	Калужская область, Козельский район, поселок Киреевское 1-е, МБОУ Средняя общеобразовательная школа	f	small
41402	38529	590	Калужская область, Козельский район, поселок Ильинское, 28	t	small
41303	38440	491	Кировская область, Фаленский район, село Ильинское	f	medium
41481	38608	670	Калужская область, Козельский район, поселок Заречье	f	medium
41480	38607	669	Калужская область, Козельский район, поселок Заречье	f	small
41214	38366	398	Калужская область, Козельский район, поселок Дешовки, МБОУ Основная общеобразовательная школа	f	medium
41213	38365	397	Калужская область, Козельский район, поселок Волконское, МБОУ Основная общеобразовательная школа	f	small
41212	38364	396	республика Татарстан, Апастовский район, село Бурнашево	f	small
41215	38367	399	Калужская область, Козельский район, поселок Березичи, Березичский сельский клуб	f	small
41211	38363	395	Калужская область, Козельский район, поселок Березический стеклозавод, МБОУ Основная общеобразовательная школа	f	large
41173	38327	357	Калужская область, Кировский район, поселок Якимово, сельский дом культуры	f	small
41164	38318	348	Калужская область, Кировский район, поселок Шайковка, дом офицеров 	f	large
41163	38317	347	Калужская область, Кировский район, поселок Шайковка, МКОУ Шайковская СОШ №, 1 	f	large
41169	38323	353	Калужская область, Кировский район, поселок Фоминичи, сельский дом культуры	f	small
41161	38315	345	Калужская область, Кировский район, поселок Тягаево, сельский дом культуры	t	small
41277	38416	465	Калужская область, Кировский район, поселок Прудки, Помещение администрации сельского поселения 	f	small
41178	38332	362	Калужская область, Кировский район, поселок Малые Савки, сельский дом культуры	f	small
41170	38324	354	Калужская область, Кировский район, поселок Малые Зимницы	f	small
41176	38330	360	Калужская область, Кировский район, поселок Малая Песочня, сельский дом культуры	f	small
41418	38545	606	Калужская область, Кировский район, поселок Лазинки, Центральная, 5	f	small
41189	38343	373	Калужская область, Кировский район, Киров, строительная, 20	f	large
41188	38342	372	Калужская область, Кировский район, Киров, пролетарская, 259	f	large
41186	38340	370	Калужская область, Кировский район, Киров, пролетарская, 48	f	large
41184	38338	368	Калужская область, Кировский район, Киров, Челюскина, 13-А	f	medium
41180	38334	364	Калужская область, Кировский район, Киров, Урицкого, 12	f	large
41191	38253	375	Калужская область, Кировский район, Киров, Пушкина, 28	f	large
41183	38337	367	Калужская область, Кировский район, Киров, Плеханова, 42а	f	large
41181	38335	365	Калужская область, Кировский район, Киров, Ленина, 14	f	large
41185	38339	369	Калужская область, Кировский район, Киров, Кирова, 2	f	large
41190	38344	374	Калужская область, Кировский район, Киров, Болдина, 7	f	large
41179	38333	363	Калужская область, Кировский район, Киров, пер. Куракина, 6	f	large
41172	38326	356	Калужская область, Кировский район, поселок Дуброво, сельский дом культуры	f	small
41171	38325	355	Калужская область, Кировский район, поселок Гавриловка, администрация сельского поселения	f	small
41166	38320	350	Калужская область, Кировский район, поселок Воскресенск, МКОУ Воскресенская СОШ им. М.В. Угарова	f	medium
41168	38322	352	Калужская область, Кировский район, поселок Волое, администрация сельского поселения	f	small
41174	38328	358	Калужская область, Кировский район, поселок Верхняя Песочня, сельский дом культуры	f	small
41177	38331	361	Калужская область, Кировский район, поселок Большие Савки, сельский дом культуры	f	small
41167	38321	351	Калужская область, Кировский район, поселок Бережки, сельский дом культуры	f	small
41175	38329	359	Калужская область, Кировский район, поселок Анновка, сельский дом культуры	t	small
41110	38273	294	Калужская область, Калуга городской округ, поселок Росва	f	large
41111	38274	295	Калужская область, Калуга городской округ, поселок Мирный	f	large
40852	38054	36	Калужская область, Калуга городской округ, поселок Мирный, Центральная, 6	t	small
41325	38455	513	Калужская область, Калуга городской округ, поселок Лихун, Юбилейная, 3	f	medium
40950	38141	134	Калужская область, Калуга городской округ, поселок Лихун, Успенская, 49	f	small
41063	38244	247	Калужская область, Калуга городской округ, поселок Колюпаново	f	medium
41062	38243	246	Калужская область, Калуга городской округ, поселок Андреевское	f	small
41006	38191	190	Калужская область, Износковский район, поселок Шанский Завод, Центральная, 7	f	small
41004	38189	188	Калужская область, Износковский район, поселок Ореховня, новая, 1	t	small
41007	38179	191	Калужская область, Износковский район, поселок Мятлево, Интернациональная, 61	f	large
41011	38195	195	Калужская область, Износковский район, поселок Льнозавод, центральная, 8	t	small
41012	38196	196	Калужская область, Износковский район, поселок Износки, 40 лет октября, 9	f	large
41010	38194	194	Калужская область, Износковский район, поселок Извольск, Окружная, 5	f	small
41005	38190	189	Калужская область, Износковский район, поселок Ивановское, 8, помещение администрации МО СП д.Ивановское	f	small
41008	38192	192	Калужская область, Износковский район, поселок Алексеевка, помещение администрации МО СП д. Алексеевка	t	small
40976	38164	160	Калужская область, Жуковский район, поселок Чубарово, 36, Администрация СП д.Чубарово	f	small
40985	38172	169	Калужская область, Жуковский район, поселок Чаусово, 10, Чаусовская школа	f	medium
40981	38168	165	Калужская область, Жуковский район, поселок Трубино, 2, Администрация СП с.Трубино	f	medium
40984	38171	168	Калужская область, Жуковский район, поселок Тростье, 7, Администрация СП д.Тростье 	f	small
41234	37016	418	Калужская область, Жуковский район, поселок Троицкое, 100 А	f	small
40974	38162	158	Калужская область, Жуковский район, поселок Тарутино, 13, Администрация СП с.Тарутино	f	small
40973	38161	157	Калужская область, Жуковский район, село Совхоз Победа, 15, Администрация СП с.Совхоз Победа	f	medium
40975	38163	159	Калужская область, Жуковский район, поселок Курилово, 92, Куриловский СДК	f	small
40992	38178	176	Калужская область, Жуковский район, поселок Кременки, ленина, 5, Кременковская средняя школа им.Е.Р.Дашковой, холл 2 этажа	f	large
40996	38182	180	Калужская область, Жуковский район, поселок Кременки, Школьная, 9, Кременковская школа №2, холл 2 этажа	f	large
40995	38182	179	Калужская область, Жуковский район, поселок Кременки, Школьная, 9, Кременковская школа №2, холл 2 этажа	f	large
40994	38181	178	Калужская область, Жуковский район, поселок Кременки, Мира, 11, Кременковский ГДК, каб.№1	f	large
40993	38180	177	Калужская область, Жуковский район, поселок Кременки, Ленина, 5, Кременковская средняя школа им.Е.Р.Дашковой, холл 2 этажа	f	large
40977	38165	161	Калужская область, Жуковский район, поселок Корсаково, 69, Администрация СП д.Корсаково	f	small
41236	37638	420	Калужская область, Жуковский район, поселок Грибовка, 19	t	small
40970	38158	154	Калужская область, Жуковский район, поселок Грачевка, Дачная, 74, Административное здание ООО СберСтройИнвест	f	small
40980	38167	164	Калужская область, Жуковский район, поселок Высокиничи, 1, Администрация СП с.Высокиничи	f	small
40979	38167	163	Калужская область, Жуковский район, поселок Высокиничи, 1, Администрация СП с.Высокиничи	f	small
40978	38166	162	Калужская область, Жуковский район, поселок Высокиничи, Администрация МО СП с.Высокиничи 	f	large
40969	38157	153	Калужская область, Жуковский район, поселок Восход, 15, Восходовский СДК	f	large
40971	38159	155	Калужская область, Жуковский район, поселок Воробьи, Московская, 9, Воробьевский медпункт	t	small
41002	38187	186	Калужская область, Жуковский район, деревня Верховье, 99, Администрация СП д.Верховье	f	large
41003	38188	187	Калужская область, Жуковский район, поселок Величково, Величковский медпункт	t	small
40991	38177	175	Калужская область, Жуковский район, Белоусово, мирная, 11, Администрация ГП г.Белоусово	f	medium
40990	38177	174	Калужская область, Жуковский район, Белоусово, мирная, 11, Администрация ГП г.Белоусово	f	large
40889	38092	73	Калужская область, Жуковский район, поселок Барсуки, Центральная, 45	f	small
41331	38461	519	Калужская область, Жуковский район, поселок Баранцево, Полевая, 5	f	small
40956	38146	140	Калужская область, Жиздринский район, поселок Яровщина, Центральная, 52	t	small
40955	38145	139	Калужская область, Жиздринский район, поселок Улемец, Центральная, 7	t	small
40965	35690	149	Калужская область, Жиздринский район, поселок Студенец, школьная, 9	t	small
40957	38147	141	Калужская область, Жиздринский район, поселок Разъезд Березовский, Пристанционная, 28	f	small
41410	38537	598	Калужская область, Жиздринский район, поселок Поляна, 33	f	medium
40964	38154	148	Калужская область, Жиздринский район, поселок Полюдово, Молодежная, 2	f	small
41406	38533	594	Калужская область, Жиздринский район, поселок Песочня, 54	f	small
40958	38148	142	Калужская область, Жиздринский район, поселок Огорь, центральная, 3	f	small
40954	38144	138	Калужская область, Жиздринский район, поселок Овсорок, Центральная, 12	f	small
40963	38153	147	Калужская область, Жиздринский район, поселок Мужитино, Молодежная, 21	t	small
40953	38143	137	Калужская область, Жиздринский район, поселок Младенск, Центральная, 42	f	small
40968	38156	152	Калужская область, Жиздринский район, поселок Коренево, заречная, 12	f	small
40967	38155	151	Калужская область, Жиздринский район, колхоз Коллективизатор, Центральная, 13а	f	small
40966	35748	150	Калужская область, Жиздринский район, поселок Зикеево, Школьная, 3	f	small
40960	38150	144	Калужская область, Жиздринский район, Жиздра, пл. Коммуны, 1	f	large
40959	38149	143	Калужская область, Жиздринский район, Жиздра, коммунистическая, 20/2	f	large
40961	38151	145	Калужская область, Жиздринский район, Жиздра, Брянская,, 11	f	medium
40962	38152	146	Калужская область, Жиздринский район, поселок Верхняя Акимовка, Центральная, 10	f	small
41282	38421	470	Калужская область, Жиздринский район, поселок Березовка, Помещение администрации сельского поселения	f	small
40949	38140	133	Калужская область, Думиничский район, поселок Чернышено, Ленина, 7	f	medium
40948	38139	132	Калужская область, Думиничский район, поселок Хотьково, Центральная, 54	f	small
41412	38539	600	Калужская область, Думиничский район, поселок Хотисино, 73	f	small
40941	35609	125	Калужская область, Думиничский район, поселок Пыренка, 60	t	small
40944	38135	128	Калужская область, Думиничский район, поселок Палики, 44, Паликский кирпичный завод	f	small
40942	35657	126	Калужская область, Думиничский район, поселок Новослободск, 16 А 	f	large
40943	35673	127	Калужская область, Думиничский район, поселок Маклаки, 91	t	small
40938	38134	122	Калужская область, Думиничский район, поселок Которь, центральная, 2	f	small
40934	38130	118	Калужская область, Думиничский район, поселок Думиничи, Центральная, 51	f	small
40932	38128	116	Калужская область, Думиничский район, поселок Думиничи, Ленина, 20	f	large
40931	38127	115	Калужская область, Думиничский район, поселок Думиничи, Ленина, 3	f	large
40933	38129	117	Калужская область, Думиничский район, поселок Думиничи, Белинского, 6, жд станция Думиничи	f	medium
40936	38132	120	Калужская область, Думиничский район, поселок Верхнее Гульцево, 82	t	small
40946	38137	130	Калужская область, Думиничский район, поселок Вертное, 1	f	small
40982	38169	166	Калужская область, Дзержинский район, колхоз имени Ленина, 164, Правление к-за им.Ленина	t	medium
40904	38009	88	Калужская область, Дзержинский район, поселок Якшуново, Школьная, 2	f	small
40923	38119	107	Калужская область, Дзержинский район, Товарково, Школьная, 1	f	large
40919	38115	103	Калужская область, Дзержинский район, Товарково, Туркестанская, 1	f	large
40921	38117	105	Калужская область, Дзержинский район, Товарково, Ленина, 32	f	large
40918	38114	102	Калужская область, Дзержинский район, Товарково, Ленина, 22	f	large
40917	38113	101	Калужская область, Дзержинский район, Товарково, Ленина, 2а	f	medium
40922	38118	106	Калужская область, Дзержинский район, Товарково, Дзержинского, 14	f	large
40895	38098	79	Калужская область, Дзержинский район, поселок Старки, 65	t	small
40983	38170	167	Калужская область, Дзержинский район, село Совхоз им. Ленина, 44, Диспетчерская к-за им.Ленина	t	small
40905	38101	89	Калужская область, Дзержинский район, поселок Совхоз им. Ленина, Ленина, 8	f	medium
40890	38093	74	Калужская область, Дзержинский район, поселок Рудня, 52	f	small
40930	38126	114	Калужская область, Дзержинский район, поселок Пятовский, ленина, 12	f	large
40920	38116	104	Калужская область, Дзержинский район, Поселок Товарково, Советская, 4	f	large
40916	38112	100	Калужская область, Дзержинский район, Полотняный Завод, Школьная, 1	f	large
40915	38111	99	Калужская область, Дзержинский район, Полотняный Завод, Ленина, 4	f	large
41332	38462	520	Калужская область, Дзержинский район, поселок Покров, Новая, 5	f	small
37973	34545	288	Ивановская область, Тейково, Чапаева, 24	f	large
40926	38122	110	Калужская область, Дзержинский район, поселок Острожное, Заводская, 2	f	small
40925	38121	109	Калужская область, Дзержинский район, поселок Маковцы, Центральная, 6/1	t	small
40898	36467	82	Калужская область, Дзержинский район, поселок Льва Толстого, советская, 27	f	large
40899	36858	83	Калужская область, Дзержинский район, поселок Льва Толстого, Полевая, 10	f	large
40891	38094	75	Калужская область, Дзержинский район, поселок Лужное, Центральная, 1	f	small
40929	38125	113	Калужская область, Дзержинский район, поселок Куровской, Мира, 6а	f	large
40911	38107	95	Калужская область, Дзержинский район, Кондрово, маяковского, 1	f	medium
40912	38108	96	Калужская область, Дзержинский район, Кондрово, Южная, 10	f	large
40907	38103	91	Калужская область, Дзержинский район, Кондрово, Советская, 13	f	large
40910	38106	94	Калужская область, Дзержинский район, Кондрово, Ленина, 37	f	large
40908	38104	92	Калужская область, Дзержинский район, Кондрово, Кооперативная, 9	f	large
40914	38110	98	Калужская область, Дзержинский район, Кондрово, Интернациональная, 6	f	large
40909	38105	93	Калужская область, Дзержинский район, Кондрово, Интернациональная, 30	f	large
40902	37098	86	Калужская область, Дзержинский район, поселок Кожухово, центральная, 13	f	small
40897	38100	81	Калужская область, Дзержинский район, поселок Карцово, Центральная, 3	f	medium
40927	38123	111	Калужская область, Дзержинский район, поселок Звизжи, Речная, 4	f	small
40906	38102	90	Калужская область, Дзержинский район, поселок Жилетово, Садовая, 2	f	large
40892	38095	76	Калужская область, Дзержинский район, поселок Дубинино, переулок светлый, 4	t	small
40900	36865	84	Калужская область, Дзержинский район, поселок Дворцы, Федорова, 14	f	large
41400	38527	588	Калужская область, Дзержинский район, поселок Горки, Кузнецова, 11	f	medium
40896	38099	80	Калужская область, Дзержинский район, поселок Бели, 75	f	small
40887	38090	71	Калужская область, Боровский район, поселок Совьяки, Центральная, 17	f	medium
40870	38072	54	Калужская область, Боровский район, село Совхоз Боровской, Центральная, 3	f	large
40864	38066	48	Калужская область, Боровский район, поселок Серединское, центральная, 8	f	small
40888	38091	72	Калужская область, Боровский район, поселок Митяево, 24, Сельский Дом культуры	t	small
40867	38069	51	Калужская область, Боровский район, деревня Кривское, Мигунова, 3	f	large
40865	38067	49	Калужская область, Боровский район, поселок Коростелево, 63, МОУ Основная общеобразовательная школа д.Коростелево	f	small
40868	38070	52	Калужская область, Боровский район, деревня Комлево, Центральная, 1	f	small
40866	38068	50	Калужская область, Боровский район, поселок Борисово, Центральная, 3	f	small
40863	38065	47	Калужская область, Боровский район, поселок Асеньевское, Центральная, 5	f	medium
40854	38056	38	Калужская область, Барятинский район, поселок Шершнево, Озерная, 11	f	small
40853	38055	37	Калужская область, Барятинский район, поселок Цветовка, Центральная, 22	t	small
40850	38052	34	Калужская область, Барятинский район, поселок Плетни, Молодежная, 23	f	small
40849	38051	33	Калужская область, Барятинский район, поселок Перенежье, центральная, 36	t	small
40848	38050	32	Калужская область, Барятинский район, поселок Милотичи, 41, Администрация СП с. Милотичи,	f	small
40847	38049	31	Калужская область, Барятинский район, поселок Крисаново-Пятница, центральная, 13	f	small
41263	38402	450	Калужская область, Барятинский район, поселок Заречный, Школьная, 3	f	small
41422	38550	610	Калужская область, Барятинский район, поселок Жданово, Центральная, 1	f	small
40846	32115	30	Калужская область, Барятинский район, поселок Добрая, советская, 4	t	small
41440	38568	629	Калужская область, Барятинский район, поселок Глазово, Глазово, 48а	f	small
40844	38034	28	Калужская область, Барятинский район, поселок Бахмутово, Центральная, 29	f	small
40842	38024	26	Калужская область, Барятинский район, поселок Барятино, 40 лет Победы, 18а	f	large
40843	38024	27	Калужская область, Барятинский район, поселок Барятино, 40 лет Победы, 18а	f	large
40841	38048	25	Калужская область, Барятинский район, поселок Асмолово, Мира, 13	f	small
40834	38041	16	Калужская область, Бабынинский район, поселок Утешево	f	small
132863	34546	289	Ивановская область, Тейково, Октябрьская, 34	f	large
41521	38642	714	Московская область, Истринский район, село Павловская Слобода, Молодежная улица	t	small
40832	38039	14	Калужская область, Бабынинский район, поселок Садовый	t	small
40831	38038	13	Калужская область, Бабынинский район, поселок Сабуровщина	f	small
40830	38037	12	Калужская область, Бабынинский район, поселок Пятницкое, 79 	f	small
40835	38042	17	Калужская область, Бабынинский район, поселок Поповские Хутора	f	small
40829	38036	11	Калужская область, Бабынинский район, поселок Никольское, 11а	t	small
40924	38120	108	Калужская область, Бабынинский район, поселок Никольское, Центральная, 20а	f	medium
40828	38035	10	Калужская область, Бабынинский район, поселок Муромцево	f	medium
41349	38479	537	Калужская область, Бабынинский район, поселок Ленское, Дачная, 2	t	small
40827	38033	9	Калужская область, Бабынинский район, поселок Лапино, 40	f	small
40826	38032	8	Калужская область, Бабынинский район, поселок Куракино	f	small
40836	38043	18	Калужская область, Бабынинский район, поселок Кумовское	t	small
40825	38031	7	Калужская область, Бабынинский район, поселок Газопровода	f	medium
40838	38045	20	Калужская область, Бабынинский район, поселок Воротынск, школьная, 21	f	large
40837	38044	19	Калужская область, Бабынинский район, поселок Воротынск, центральная, 10	f	large
40840	38047	22	Калужская область, Бабынинский район, поселок Воротынск, Школьная, 13	f	large
40839	38046	21	Калужская область, Бабынинский район, поселок Воротынск, 50-лет Победы, 10	f	large
40823	38029	5	Калужская область, Бабынинский район, поселок Воронино	t	small
41356	38486	544	Калужская область, Бабынинский район, поселок Воронино, Центральная, 12	f	small
40833	38040	15	Калужская область, Бабынинский район, Бабынинское отделение	t	small
40821	38027	3	Калужская область, Бабынинский район, поселок Бабынино, моторная, 4	f	medium
40822	38028	4	Калужская область, Бабынинский район, поселок Бабынино, Центральная, 38	f	small
40820	38026	2	Калужская область, Бабынинский район, поселок Бабынино, Новая, 2	f	large
40819	38025	1	Калужская область, Бабынинский район, поселок Антопьево, Центральная, 17	f	small
38334	34896	725	Ивановская область, с. Пригородное, Вичугский проезд, 31	f	small
38418	34986	828	Ивановская область, Юрьевец, Тарковского, 1а	f	medium
132870	34588	344	Ивановская область, Шуя, площадь Сехская, 2	f	large
132874	34594	348	Ивановская область, Шуя, переулок Фабричный, 15	f	large
38017	34585	341	Ивановская область, Шуя, Ярославская, 73	f	large
132880	34601	354	Ивановская область, Шуя, Советская, 46	f	large
132879	34600	353	Ивановская область, Шуя, Советская, 40	f	large
132877	34597	351	Ивановская область, Шуя, Советская, 24	f	large
132888	34608	362	Ивановская область, Шуя, Свердлова, 127А	f	large
134521	94413	364	Ивановская область, Шуя, Кооперативная, 24	f	large
132889	34609	363	Ивановская область, Шуя, Кооперативная, 57	f	large
132887	34607	361	Ивановская область, Шуя, Кооперативная, 39	f	large
132881	34602	355	Ивановская область, Шуя, Зинаиды Касаткиной, 10	f	large
134522	34612	365	Ивановская область, Шуя, Дуниловская, 33/2	f	large
132884	34604	358	Ивановская область, Шуя, Вихрева, 65	f	large
132883	34604	357	Ивановская область, Шуя, Вихрева, 65	f	large
132882	34603	356	Ивановская область, Шуя, Вихрева, 81	f	large
38018	34586	342	Ивановская область, Шуя, Аникина, 21	f	large
132885	34605	359	Ивановская область, Шуя, 2-я Первомайская, 20	f	large
132872	34591	346	Ивановская область, Шуя, 2-я Мичуринская, 2а	f	medium
132878	34599	352	Ивановская область, Шуя, 2-я Металлистов, 10	f	large
132873	34593	347	Ивановская область, Шуя, 11-я Мичуринская, 6	f	large
132871	34589	345	Ивановская область, Шуя, 1-я Текстильная, 2 В	f	medium
38019	34587	343	Ивановская область, Шуя, 1-я Нагорная, 14	f	large
132875	34595	349	Ивановская область, Шуя, 1-я Московская, 38	f	large
38003	34571	322	Ивановская область, Фурманов, Колосова, 25	f	large
38004	34571	323	Ивановская область, Фурманов, Колосова, 25	f	large
38005	34572	324	Ивановская область, Фурманов, Демьяна бедного, 71	f	small
37979	34551	294	Ивановская область, Тейково, пр. Красноармейский, 2	f	large
37971	34543	286	Ивановская область, Тейково, пл.Ленина, 2	f	large
37977	34549	292	Ивановская область, Тейково, Шестагинская, 78	f	large
37976	34548	291	Ивановская область, Тейково, Шестагинская, 85	f	large
81938	56112	1103	Москва, Салтыковская, 13б	f	large
37985	34556	300	Ивановская область, Тейково, Молодежная, 24	f	large
37984	34555	299	Ивановская область, Тейково, Молодежная, 10	f	large
37981	34553	296	Ивановская область, Тейково, Ленинская, 3	f	large
37980	34552	295	Ивановская область, Тейково, Ленинская, 3а	f	large
37975	34547	290	Ивановская область, Тейково городской округ, Лежневская, 19	f	large
37983	34554	298	Ивановская область, Тейково, Гвардейская, 14	f	large
37982	34554	297	Ивановская область, Тейково, Гвардейская, 14	f	large
38312	34877	703	Ивановская область, Родники, площадь Ленина, 10	f	large
38314	34879	705	Ивановская область, Родники, мкр. Гагарина, 22	f	large
38289	34852	673	Ивановская область, Пучеж, Радищева, 42	f	medium
38291	34854	675	Ивановская область, Пучеж, Калинина, 2	f	medium
132929	34829	637	Ивановская область, Приволжск, Социалистическая, 4	f	large
132930	34827	638	Ивановская область, Приволжск, Социалистическая, 4	f	large
132928	34827	636	Ивановская область, Приволжск, Социалистическая, 4	f	large
38274	34836	649	Ивановская область, Плес, Корнилова, 20	f	medium
38187	34751	539	Ивановская область, Наволоки, Энгельса, 65	f	large
37960	34538	271	Ивановская область, Кохма, переулок Ивановский, 13	f	large
37959	34538	270	Ивановская область, Кохма, переулок Ивановский, 13	f	large
37963	34538	274	Ивановская область, Кохма, переулок Ивановский, 13	f	large
37962	34538	273	Ивановская область, Кохма, переулок Ивановский, 13	f	large
37961	34538	272	Ивановская область, Кохма, переулок Ивановский, 13	f	large
37965	34540	276	Ивановская область, Кохма, Советская, 30	f	large
37956	34535	267	Ивановская область, Кохма, Октябрьская, 38	f	large
37955	34534	266	Ивановская область, Кохма, Октябрьская, 64	f	large
37968	34542	279	Ивановская область, Кохма, Кочетовой, 36	f	large
37970	34542	281	Ивановская область, Кохма, Кочетовой, 36	f	medium
37969	34542	280	Ивановская область, Кохма, Кочетовой, 36	f	large
37964	34539	275	Ивановская область, Кохма, Ивановская, 32	f	large
37957	34536	268	Ивановская область, Кохма, 8 Марта, 1	f	large
132916	34755	546	Ивановская область, Комсомольск, Советская , 5	f	large
38123	34685	467	Ивановская область, поселок Коляново, Школьная, 81	f	large
38124	34685	468	Ивановская область, поселок Коляново, Школьная, 81	f	large
132842	34084	239	Ивановская область, Кинешма, им. Юрия Горохова, 6А	f	large
132841	33798	238	Ивановская область, Кинешма, им. Юрия Горохова, 8	f	large
132840	33798	237	Ивановская область, Кинешма, им. Юрия Горохова, 8	f	large
134400	34400	235	Ивановская область, Кинешма, им. 50 лет Комсомола, 27	f	large
132858	34530	255	Ивановская область, Кинешма, Юрьевецкая, 50/1	f	large
132856	34524	253	Ивановская область, Кинешма, Юрьевецкая, 46	f	large
132844	34151	241	Ивановская область, Кинешма, Щорса, 32	f	large
132843	34151	240	Ивановская область, Кинешма, Щорса, 32	f	large
37923	34510	228	Ивановская область, Кинешма, Фабричный двор, 12	f	large
37922	34510	227	Ивановская область, Кинешма, Фабричный двор, 12	f	large
132855	34525	252	Ивановская область, Кинешма, Спортиваная, 21	f	large
37919	34508	224	Ивановская область, Кинешма, Социалистическая, 16	f	large
37918	34507	223	Ивановская область, Кинешма, Социалистическая, 27а	f	large
37929	95176	234	Ивановская область, Кинешма, Правды, 4	f	large
132839	34516	236	Ивановская область, Кинешма, Правды, 4	f	large
37917	34506	222	Ивановская область, Кинешма, Наволокская, 18	f	large
132857	34528	254	Ивановская область, Кинешма, Межевая, 18	f	large
132861	34531	259	Ивановская область, Кинешма, Ломоносова, 21-б	f	large
132860	34531	258	Ивановская область, Кинешма, Ломоносова, 21-б	f	large
132859	34529	257	Ивановская область, Кинешма, Ломоносова, 20	f	large
37951	34529	256	Ивановская область, Кинешма, Ломоносова, 20	f	large
132851	34519	248	Ивановская область, Кинешма, Ленина, 42	f	large
132853	34522	250	Ивановская область, Кинешма, Котовского, 19	f	large
132854	34521	251	Ивановская область, Кинешма, Котовского, 19	f	large
37916	34505	221	Ивановская область, Кинешма, Королева, 10	f	large
132848	34426	245	Ивановская область, Кинешма, Ивана Виноградова, 16	f	large
132847	34377	244	Ивановская область, Кинешма, Ивана Виноградова, 18	f	large
132852	34520	249	Ивановская область, Кинешма, Волжский бульвар, 4	f	large
37925	34512	230	Ивановская область, Кинешма, Воеводы Боборыкина, 18а	f	large
37743	34386	10	Ивановская область, Иваново, Смирнова, 103	f	large
37924	34511	229	Ивановская область, Кинешма, Воеводы Боборыкина, 18а	f	large
37921	34509	226	Ивановская область, Кинешма, Воеводы Боборыкина, 53	f	large
37920	34509	225	Ивановская область, Кинешма, Воеводы Боборыкина, 53	f	large
132846	34376	243	Ивановская область, Кинешма, Вичугская , 146	f	large
132849	34394	246	Ивановская область, Кинешма, Вичугская, 104 А	f	large
132845	34219	242	Ивановская область, Кинешма, Вичугская, 176А	f	large
132862	34533	260	Ивановская область, Кинешма, Веснина, 7А	f	large
37927	34514	232	Ивановская область, Кинешма городской округ, 50-летия Комсомола, 22	f	large
37926	34513	231	Ивановская область, Кинешма, 50-летия Комсомола, 24	f	large
132850	34517	247	Ивановская область, Кинешма, 3 Трудовой пер, 4	f	large
37747	33742	14	Ивановская область, Иваново, станция Иваново	f	large
37857	34454	147	Ивановская область, Иваново, улица Ташкентская, 81	f	large
37856	34454	146	Ивановская область, Иваново, улица Ташкентская, 81	f	large
37863	34458	153	Ивановская область, Иваново, улица Нефедова, 10	f	large
37884	34473	174	Ивановская область, Иваново, улица Ленинградская, 13	f	large
37795	34414	71	Ивановская область, Иваново, улица 9 Января, 39	f	large
37794	34414	70	Ивановская область, Иваново, улица 9 Января, 39	f	large
37890	34478	180	Ивановская область, Иваново, улица 1-я Талицкая, 4	f	large
37836	34441	117	Ивановская область, Иваново, маршала Жаворонкова, 5	f	large
37835	34441	116	Ивановская область, Иваново, маршала Жаворонкова, 5	f	large
37834	34441	115	Ивановская область, Иваново, маршала Жаворонкова, 5	f	large
37767	34399	34	Ивановская область, Иваново, маршала Василевского, 6	f	large
37756	34391	23	Ивановская область, Иваново, генерала Хлебникова, 32	f	large
37755	34391	22	Ивановская область, Иваново, генерала Хлебникова, 32	f	large
37754	34391	21	Ивановская область, Иваново, генерала Хлебникова, 32	f	large
132837	34420	77	Ивановская область, Иваново, академика Мальцева, 36	f	large
132838	34420	78	Ивановская область, Иваново, академика Мальцева, 36	f	large
37849	34449	130	Ивановская область, Иваново, Шувандиной, 84	f	large
37848	34448	129	Ивановская область, Иваново, Шувандиной, 95	f	large
37842	34444	123	Ивановская область, Иваново, Шошина, 15б	f	large
37841	34444	122	Ивановская область, Иваново, Шошина, 15б	f	large
37840	34444	121	Ивановская область, Иваново, Шошина, 15б	f	large
37844	34445	125	Ивановская область, Иваново, Чайковского, 38	f	large
37843	34445	124	Ивановская область, Иваново, Чайковского, 38	f	large
37850	34450	131	Ивановская область, Иваново, Хвойная, 2	f	large
37812	34427	88	Ивановская область, Иваново, Фрунзе, 15/25	f	large
37811	34427	87	Ивановская область, Иваново, Фрунзе, 15/25	f	large
37736	34380	3	Ивановская область, Иваново, Фридриха Энгельса проспект, 21	f	large
37735	34379	2	Ивановская область, Иваново, Фридриха Энгельса проспект, 10	f	large
37734	34378	1	Ивановская область, Иваново, Фридриха Энгельса проспект, 8	f	large
134398	34387	12	Ивановская область, Иваново, Типографская, 25/55	f	large
37744	34387	11	Ивановская область, Иваново, Типографская, 25/55	f	large
37859	34456	149	Ивановская область, Иваново, Ташкентская, 15	f	large
37861	34456	151	Ивановская область, Иваново, Ташкентская, 15	f	large
37860	34456	150	Ивановская область, Иваново, Ташкентская, 15	f	large
37871	34455	161	Ивановская область, Иваново, Танкиста Белороссова, 15	f	large
37870	34455	160	Ивановская область, Иваново, Танкиста Белороссова, 15	f	large
37858	34455	148	Ивановская область, Иваново, Танкиста Белороссова, 15	f	large
37740	34384	7	Ивановская область, Иваново, Суворова, 72	f	large
37771	34402	38	Ивановская область, Иваново, Строителей проспект, 94а	f	large
37770	34402	37	Ивановская область, Иваново, Строителей проспект, 94а	f	large
37769	34402	36	Ивановская область, Иваново, Строителей проспект, 94а	f	large
37768	34401	35	Ивановская область, Иваново, Строителей проспект, 124	f	large
37765	34397	32	Ивановская область, Иваново, Строителей проспект, 4а	f	large
37764	34396	31	Ивановская область, Иваново, Строителей проспект, 31	f	large
37763	34395	30	Ивановская область, Иваново, Строителей проспект, 63	f	large
37762	34395	29	Ивановская область, Иваново, Строителей проспект, 63	f	large
37873	34464	163	Ивановская область, Иваново, Степанова, 9	f	large
37742	34386	9	Ивановская область, Иваново, Смирнова, 103	f	large
37845	34446	126	Ивановская область, Иваново, Свободы, 1	f	large
38369	34932	764	Ивановская область, Иваново, Светлая, 7	f	medium
37738	34382	5	Ивановская область, Иваново, Сакко, 45	f	large
37891	34479	181	Ивановская область, Иваново, Рабфаковская, 14	f	large
37887	34475	177	Ивановская область, Иваново, Рабфаковская, 34	f	large
37885	34474	175	Ивановская область, Иваново, Рабфаковская, 2	f	large
37886	34474	176	Ивановская область, Иваново, Рабфаковская, 2	f	large
37774	34404	41	Ивановская область, Иваново, Профессиональная, 39	f	large
37875	34466	165	Ивановская область, Иваново, Почтовая, 3	f	large
38336	34898	727	Ивановская область, Иваново, Почтова, 29	f	small
37820	34430	96	Ивановская область, Иваново, Полка Нормандия-Неман, 80	f	large
37819	34430	95	Ивановская область, Иваново, Полка Нормандия-Неман, 80	f	large
37818	34430	94	Ивановская область, Иваново, Полка Нормандия-Неман, 80	f	large
37753	34390	20	Ивановская область, Иваново, Полевой проезд, 4	f	large
37752	34390	19	Ивановская область, Иваново, Полевой проезд, 4	f	large
37889	34477	179	Ивановская область, Иваново, Парижской Коммуны, 60	f	large
37888	34477	178	Ивановская область, Иваново, Парижской Коммуны, 60	f	large
37877	34467	167	Ивановская область, Иваново, Парижской Коммуны, 44	f	large
37876	34467	166	Ивановская область, Иваново, Парижской Коммуны, 44	f	large
37761	34393	28	Ивановская область, Иваново, Панина, 21	f	large
37760	34393	27	Ивановская область, Иваново, Панина, 21	f	large
37827	34437	108	Ивановская область, Иваново, Окуловой, 59	f	large
37826	34436	107	Ивановская область, Иваново, Окуловой, 1	f	large
37822	34431	98	Ивановская область, Иваново, Носова, 49	f	large
37821	34431	97	Ивановская область, Иваново, Носова, 49	f	large
37778	34406	45	Ивановская область, Иваново, Новосельская, 4-А	f	large
37777	34406	44	Ивановская область, Иваново, Новосельская, 4-А	f	large
37865	34459	155	Ивановская область, Иваново, Некрасова, 51	f	large
37864	34459	154	Ивановская область, Иваново, Некрасова, 51	f	large
37862	34457	152	Ивановская область, Иваново, Некрасова, 61	f	large
37872	34463	162	Ивановская область, Иваново, Московская, 48	f	large
37810	34425	86	Ивановская область, Иваново, Минская, 53	f	large
37809	34425	85	Ивановская область, Иваново, Минская, 53	f	large
37804	34422	80	Ивановская область, Иваново, Минская, 5	f	large
37839	34443	120	Ивановская область, Иваново, Микрорайон ТЭЦ № 3, 14	f	large
37838	34443	119	Ивановская область, Иваново, Микрорайон ТЭЦ № 3, 14	f	large
37773	34403	40	Ивановская область, Иваново, Маршала Василевского, 7	f	large
37772	34403	39	Ивановская область, Иваново, Маршала Василевского, 7	f	large
37766	34398	33	Ивановская область, Иваново, Маршала Василевского, 6-А	f	large
37879	34469	169	Ивановская область, Иваново, Мархлевского, 34/45	f	large
37783	34408	50	Ивановская область, Иваново, Любимова, 20а	f	large
37782	34408	49	Ивановская область, Иваново, Любимова, 20а	f	large
37781	34407	48	Ивановская область, Иваново, Любимова, 16-А	f	large
37780	34407	47	Ивановская область, Иваново, Любимова, 16-А	f	large
37779	34407	46	Ивановская область, Иваново, Любимова, 16-А	f	large
37882	34471	172	Ивановская область, Иваново, Линия 19 , 1а	f	large
37748	34196	15	Ивановская область, Иваново, Летчика Лазарева, 1/2	f	large
37750	34196	17	Ивановская область, Иваново, Летчика Лазарева, 1/2	f	large
37749	34196	16	Ивановская область, Иваново, Летчика Лазарева, 1/2	f	large
37911	34499	212	Ивановская область, Иваново, Ленинградская, 48, здание школы №17	f	large
37798	34417	74	Ивановская область, Иваново, Ленина проспект, 53	f	large
37797	34416	73	Ивановская область, Иваново, Ленина проспект, 114	f	large
37793	34413	69	Ивановская область, Иваново, Ленина проспект, 41	f	large
132876	34596	350	Ивановская область, Иваново, Ленина площадь, 15	f	large
37788	34410	55	Ивановская область, Иваново, Лежневская, 203	f	large
37853	34452	143	Ивановская область, Иваново, Куликова, 19	f	large
37852	34451	142	Ивановская область, Иваново, Куликова, 27	f	large
37851	34451	141	Ивановская область, Иваново, Куликова, 27	f	large
37894	34482	184	Ивановская область, Иваново, Кузнецова, 116	f	large
37751	34389	18	Ивановская область, Иваново, Кудряшова, 82	f	large
37787	34409	54	Ивановская область, Иваново, Кохомское шоссе, 29	f	large
37786	34409	53	Ивановская область, Иваново, Кохомское шоссе, 29	f	large
37785	34409	52	Ивановская область, Иваново, Кохомское шоссе, 29	f	large
37784	34409	51	Ивановская область, Иваново, Кохомское шоссе, 29	f	large
38370	34933	765	Ивановская область, Иваново, Комсомольская, 14	f	large
37790	34411	66	Ивановская область, Иваново, Комсомольская, 52	f	large
37789	34411	65	Ивановская область, Иваново, Комсомольская, 52	f	large
37739	34383	6	Ивановская область, Иваново, Колотилова, 43	f	large
37746	33730	13	Ивановская область, Иваново, Колесанова, 11	f	large
37796	34415	72	Ивановская область, Иваново, Карла Маркса, 62/107	f	large
134399	34419	76	Ивановская область, Иваново, Ермака, 41	f	large
37799	34418	75	Ивановская область, Иваново, Ермака, 37/7	f	large
37792	34412	68	Ивановская область, Иваново, Дунаева, 13	f	large
37791	34412	67	Ивановская область, Иваново, Дунаева, 13	f	large
37893	34481	183	Ивановская область, Иваново, Героя Советского Союза Сахарова П.И, 56	f	large
37892	34480	182	Ивановская область, Иваново, Героя Советского Союза Сахарова, 56	f	large
37855	34453	145	Ивановская область, Иваново, Воронина, 8	f	large
37854	34453	144	Ивановская область, Иваново, Воронина, 8	f	large
37866	34460	156	Ивановская область, Иваново, Володиной, 9	f	large
37869	34462	159	Ивановская область, Иваново, Большая Воробьевская, 80	f	large
37868	34462	158	Ивановская область, Иваново, Большая Воробьевская, 80	f	large
37883	34472	173	Ивановская область, Иваново, Бакинский проезд, 55а	f	large
37874	33764	164	Ивановская область, Иваново, Багаева, 38/17	f	large
37737	34381	4	Ивановская область, Иваново, Арсения, 33/16	f	large
37808	34424	84	Ивановская область, Иваново, Апрельская, 5	f	large
37807	34424	83	Ивановская область, Иваново, Апрельская, 5	f	large
37846	34447	127	Ивановская область, Иваново, Академическая, 5	f	large
37847	34447	128	Ивановская область, Иваново, Академическая, 5	f	large
37881	34470	171	Ивановская область, Иваново, 9-я линия, 1/26	f	large
37880	34470	170	Ивановская область, Иваново, 9-я линия, 1/26	f	large
37776	34405	43	Ивановская область, Иваново, 5-я Коляновская, 72	f	large
37775	34405	42	Ивановская область, Иваново, 5-я Коляновская, 72	f	large
37825	34435	106	Ивановская область, Иваново, 4-я Сосневская, 57/15	f	large
37817	34429	93	Ивановская область, Иваново, 4-я Деревенская, 27	f	large
37816	34429	92	Ивановская область, Иваново, 4-я Деревенская, 27	f	large
37815	34429	91	Ивановская область, Иваново, 4-я Деревенская, 27	f	large
37814	34429	90	Ивановская область, Иваново, 4-я Деревенская, 27	f	large
37824	34434	105	Ивановская область, Иваново, 4-й Котельницкий переулок, 1-Б	f	large
37757	34392	24	Ивановская область, Иваново, 30 микрорайон, 17	f	large
37759	34392	26	Ивановская область, Иваново, 30 микрорайон, 17	f	large
37758	34392	25	Ивановская область, Иваново, 30 микрорайон, 17	f	large
37833	34440	114	Ивановская область, Иваново, 3-я Сосневская, 139	f	large
37832	34440	113	Ивановская область, Иваново, 3-я Сосневская, 139	f	large
37837	34442	118	Ивановская область, Иваново, 2-я Ягодная, 31	f	large
37806	34423	82	Ивановская область, Иваново, 2-я Ключевая, 20	f	large
37805	34423	81	Ивановская область, Иваново, 2-я Ключевая, 20	f	large
37867	34461	157	Ивановская область, Иваново, 13-я Березниковская, 1	f	large
37829	34438	110	Ивановская область, Иваново, 10-й проезд, 24/2	f	large
37828	34438	109	Ивановская область, Иваново, 10-й проезд, 24/2	f	large
37741	34385	8	Ивановская область, Иваново, 10 Августа, 85	f	large
37813	34428	89	Ивановская область, Иваново, 1-я Минеевская, 25/2	f	large
37831	34439	112	Ивановская область, Иваново, 1-я Меланжевая, 5	f	large
37830	34439	111	Ивановская область, Иваново, 1-я Меланжевая, 5	f	large
37803	34421	79	Ивановская область, Иваново, 1-й Северный переулок, 21	f	large
132891	34656	432	Ивановская область, Заволжск, переулок Парковский, 6	f	large
38094	34658	434	Ивановская область, Заволжск, Почтовая, 2	f	medium
132907	34711	493	Ивановская область, поселок Железнодорожный, Садовая, 19	f	small
37901	34489	202	Ивановская область, Вичуга, Ульяновская, 9, здание Детской школы искусств	f	large
37898	34486	199	Ивановская область, Вичуга, Ульяновская, 11, здание школы № 10	f	large
37905	34493	206	Ивановская область, Вичуга, Покровская, 6, здание филиала ИГТА	f	large
37904	34492	205	Ивановская область, Вичуга, Парковая, 8, здание школы №11	f	large
37902	34490	203	Ивановская область, Вичуга, Парковая, 1, здание Центра детского творчества	f	large
37900	34488	201	Ивановская область, Вичуга, Н.П. Куликовой, 13, здание школы № 9	f	large
37896	34484	197	Ивановская область, Вичуга, Металлистов, 9, здание Дома культуры Машиностроитель	f	large
37914	34503	215	Ивановская область, Вичуга, Ленинская, 26, здание клуба имени Шагова	f	large
37910	34498	211	Ивановская область, Вичуга, Ленинградская, 72, здание Социального приюта для детей	f	large
37909	34497	210	Ивановская область, Вичуга, Ленинградская, 107, здание клуба им.Фрунзе	f	large
37908	34496	209	Ивановская область, Вичуга, Ленинградская, 86, здание спорткомплекса Текстильщик	f	large
37913	34501	214	Ивановская область, Вичуга, Желябова, 6, здание школы №6	f	large
37907	34495	208	Ивановская область, Вичуга, Дачная, 1/16, здание школы №12	f	large
37895	34483	196	Ивановская область, Вичуга, Володарского, 14, здание школы №13	f	large
37903	34491	204	Ивановская область, Вичуга, Б.Хмельницкого, 52, здание Межшкольного учебного комбината	f	large
37899	34487	200	Ивановская область, Вичуга, Б-Пролетарская, 1, здание Культурного центра	f	large
37906	34494	207	Ивановская область, Вичуга, Абрамовой, 18, здание Комбината детского питания	f	large
37897	34485	198	Ивановская область, Вичуга, 50-лет Октября, 16, здание филиала школы №13	f	large
37912	34500	213	Ивановская область, Вичуга, 1-Ломоносова, 28, здание Вичугской школы VIII вида	f	large
132962	35000	841	Ивановская область, Юрьевецкий район, поселок Ямская, Молодежная, 28	f	small
38416	34984	826	Ивановская область, Юрьевецкий район, Юрьевец, Школьная, 3	f	large
38419	34987	829	Ивановская область, Юрьевецкий район, Юрьевец, Чкалова, 4а	f	medium
38423	34991	833	Ивановская область, Юрьевецкий район, Юрьевец, Титова, 4	f	large
38422	34990	832	Ивановская область, Юрьевецкий район, Юрьевец, Титова, 2	f	large
38421	34989	831	Ивановская область, Юрьевецкий район, Юрьевец, Советская, 143	f	large
38420	34988	830	Ивановская область, Юрьевецкий район, Юрьевец, Советская, 97	f	medium
38417	34985	827	Ивановская область, Юрьевецкий район, Юрьевец, Промышленная, 10а	f	medium
134528	94417	843	Ивановская область, Юрьевецкий район, поселок Щекотиха, Школьная, 2а	f	small
132960	34992	834	Ивановская область, Юрьевецкий район, поселок Тихон-Воля, Школьная, 1	f	small
134527	94416	842	Ивановская область, Юрьевецкий район, поселок Соболево, Молодежная, 5, здание школы	f	small
38426	34994	836	Ивановская область, Юрьевецкий район, поселок Пелевино, Cоветская, 8	f	small
134530	94419	845	Ивановская область, Юрьевецкий район, поселок Обжериха, Реформатовского, 24, здание школы	f	small
134531	94420	846	Ивановская область, Юрьевецкий район, поселок Новленское, Нагорная , 6, здание Дома культуры	f	small
38429	34997	839	Ивановская область, Юрьевецкий район, поселок Михайлово, Советская, 14-а	f	medium
38425	34993	835	Ивановская область, Юрьевецкий район, поселок Лобаны, Волжская, 2а	f	small
134529	94418	844	Ивановская область, Юрьевецкий район, поселок Костяево-Большое, Набережная, 1	f	small
132963	35005	847	Ивановская область, Юрьевецкий район, поселок Жуковка, Сиреневая, 6	f	small
38428	34996	838	Ивановская область, Юрьевецкий район, поселок Елнать, Сиротина, 6	f	medium
38427	34995	837	Ивановская область, Юрьевецкий район, поселок Дорки, Школьная, 1	f	small
132961	34999	840	Ивановская область, Юрьевецкий район, поселок Ваньково, Солнечеая, 22	f	small
38397	34961	802	Ивановская область, Южский район, Южа	f	large
38401	34965	806	Ивановская область, Южский район, Южа, Советская, 20	f	large
38400	34964	805	Ивановская область, Южский район, Южа, Советская, 9	f	large
38398	34962	803	Ивановская область, Южский район, Южа, Речная, 1	f	large
38396	34960	801	Ивановская область, Южский район, Южа, Пушкина, 2	f	large
38402	34966	807	Ивановская область, Южский район, Южа, Новая, 3а	f	large
38399	34963	804	Ивановская область, Южский район, Южа, Глушицкий проезд, 4а	f	large
132959	34982	820	Ивановская область, Южский район, поселок Хотимль, Юбилейная, 10	f	small
132957	34976	815	Ивановская область, Южский район, Холуй, Полевая, 1а	f	medium
38406	34970	811	Ивановская область, Южский район, поселок Талицы, Ленина, 12	f	large
132958	34977	816	Ивановская область, Южский район, поселок Селищи, 98	f	small
37241	30792	2701	Воронежская область, Павловск, К.Готвальда, 25	f	large
38414	34981	819	Ивановская область, Южский район, поселок Преображенское, Преображенская, 67	f	small
38409	34974	814	Ивановская область, Южский район, поселок Новоклязьминское, Придорожная, 3	f	small
132954	34967	808	Ивановская область, Южский район, поселок Нефедово, Центральная, 43	f	small
38407	34971	812	Ивановская область, Южский район, поселок Мугреевский, Школьная, 7а	f	medium
38405	34969	810	Ивановская область, Южский район, поселок Мугреево-Никольское, Центральная, 40	f	small
132956	34973	813	Ивановская область, Южский район, поселок Моста, Восточная, 5	f	small
38412	34979	817	Ивановская область, Южский район, поселок Мордовское, 38а	f	small
38413	34980	818	Ивановская область, Южский район, поселок Изотино, Центральная, 24а	f	small
132955	34968	809	Ивановская область, Южский район, поселок Груздево, Центральная, 12	f	small
132886	34606	360	Ивановская область, Шуя городской округ, Шуя, Горелова, 12	f	large
38381	34944	781	Ивановская область, Шуйский район, поселок Чижово, Арсения, 9	f	small
38379	34942	779	Ивановская область, Шуйский район, поселок Чечкино-Богородское	f	small
38121	34682	465	Ивановская область, Шуйский район, поселок Чечкино-Богородское, 5-я Клинцевская, 26	f	large
38118	34678	462	Ивановская область, Шуйский район, поселок Чечкино-Богородское, Большая Клинцевская, 4 А	f	medium
38384	34947	784	Ивановская область, Шуйский район, поселок Чернцы, Школьная, 11	f	small
38372	34935	772	Ивановская область, Шуйский район, поселок Центральный, Дом культуры Юбилейный	f	small
38390	34953	790	Ивановская область, Шуйский район, поселок Харитоново	f	small
38393	34957	793	Ивановская область, Шуйский район, поселок Филино, Набережная, 9	f	large
38388	34951	788	Ивановская область, Шуйский район, поселок Сергеево, ФГОУ СПО Сельскохозяйственный техникум	f	medium
38395	34959	795	Ивановская область, Шуйский район, поселок Семейкино, Колхозная, 16	f	small
38374	34937	774	Ивановская область, Шуйский район, поселок Пустошь, Квартал 2, 1	f	small
38391	34954	791	Ивановская область, Шуйский район, поселок Прилив, Центральная, 12	f	medium
38386	34949	786	Ивановская область, Шуйский район, поселок Остапово, Зеленая, 72	f	medium
38377	34940	777	Ивановская область, Шуйский район, поселок Никитское, 44, Клуб	f	small
38380	34943	780	Ивановская область, Шуйский район, поселок Михалково, Центральная, 7	f	small
38378	34941	778	Ивановская область, Шуйский район, поселок Михалево	f	small
38394	34958	794	Ивановская область, Шуйский район, поселок Михалево, Зеленая	f	small
38387	34950	787	Ивановская область, Шуйский район, поселок Милюковка, Милюковская МСОШ 	f	small
38371	34934	771	Ивановская область, Шуйский район, поселок Колобово, Садовая, 2, Колобовская МСОШ	f	large
38389	34952	789	Ивановская область, Шуйский район, поселок Клочково, Дом культуры	f	medium
38385	34948	785	Ивановская область, Шуйский район, Китово, Центральная, 94	f	large
38392	34956	792	Ивановская область, Шуйский район, поселок Качалово, Северная, 8	f	small
132894	34676	455	Ивановская область, Шуйский район, поселок Иванцево, Ивановская, 20	f	medium
132926	34801	602	Ивановская область, Шуйский район, поселок Запрудново, Половинская, 2	f	medium
38383	34946	783	Ивановская область, Шуйский район, поселок Дунилово, Советская, 19	f	medium
38382	34945	782	Ивановская область, Шуйский район, поселок Введенье, Мира, 28	f	small
38376	34939	776	Ивановская область, Шуйский район, поселок Васильевское, Советская, 1	f	medium
38373	34936	773	Ивановская область, Шуйский район, поселок Афанасьевское, 20А, Дом культуры	f	small
38375	34938	775	Ивановская область, Шуйский район, поселок Арефино, Дом культуры 	f	small
132869	34583	334	Ивановская область, Фурмановский район, поселок Широково, 40	f	medium
132868	34579	332	Ивановская область, Фурмановский район, поселок Хромцово, 9 А	f	medium
132867	34570	320	Ивановская область, Фурмановский район, Фурманов, Тимирязева, 32	f	large
38002	34570	321	Ивановская область, Фурмановский район, Фурманов, Тимирязева, 32	f	large
132866	34569	319	Ивановская область, Фурмановский район, Фурманов, Тимирязева, 10	f	large
37999	34567	318	Ивановская область, Фурмановский район, Фурманов, Тимирязева, 10	f	large
37998	34566	317	Ивановская область, Фурмановский район, Фурманов, Тимирязева, 43	f	large
37997	34565	316	Ивановская область, Фурмановский район, Фурманов, Тимирязева, 42	f	large
37992	34560	311	Ивановская область, Фурмановский район, Фурманов, Социалистическая, 15	f	large
37991	34560	310	Ивановская область, Фурмановский район, Фурманов, Социалистическая, 15	f	large
37990	34559	309	Ивановская область, Фурмановский район, Фурманов, Советская, 7	f	large
37989	34559	308	Ивановская область, Фурмановский район, Фурманов, Советская, 7	f	large
37994	34561	313	Ивановская область, Фурмановский район, Фурманов, Пролетарская, 7	f	large
132864	34561	312	Ивановская область, Фурмановский район, Фурманов, Пролетарская, 7	f	large
37988	34558	307	Ивановская область, Фурмановский район, Фурманов, Нижний Двор, 72	f	large
37987	34557	306	Ивановская область, Фурмановский район, Фурманов, Наримановская, 18	f	large
132865	34563	314	Ивановская область, Фурмановский район, Фурманов, Карла Либкнехта, 76	f	large
37996	34564	315	Ивановская область, Фурмановский район, Фурманов, Возрождения, 40	f	large
38010	34577	329	Ивановская область, Фурмановский район, поселок Снетиново, 53	f	small
38009	34576	328	Ивановская область, Фурмановский район, село Погост, 64	f	small
38012	34578	331	Ивановская область, Фурмановский район, поселок Панино, 74	f	small
38011	34578	330	Ивановская область, Фурмановский район, поселок Панино, 74	f	medium
38325	34889	716	Московская область, Коломенский район, село Никульское	f	small
38327	34891	718	Ивановская область, Фурмановский район, поселок Михайловское, 60	f	medium
38014	34581	333	Ивановская область, Фурмановский район, поселок Марьинское, 17	f	small
132923	34798	599	Ивановская область, Фурмановский район, поселок Котово, Школьная, 17	f	small
132915	34724	508	Ивановская область, Фурмановский район, поселок Игрищи, 124	f	small
38008	34575	327	Ивановская область, Фурмановский район, поселок Иванково, 54	f	medium
38016	34584	335	Ивановская область, Фурмановский район, поселок Земляничный, 20	f	small
38117	30277	461	Ивановская область, Фурмановский район, поселок Захарьино, 22	f	small
38007	34574	326	Ивановская область, Фурмановский район, поселок Дуляпино, Текстильная, 10б	f	small
38006	34573	325	Ивановская область, Фурмановский район, поселок Дуляпино, Советская, 12	f	medium
37878	34468	168	Ивановская область, Фрунзенский район, Иваново, Строительная, 5	f	large
38166	34731	514	Ивановская область, Тейковский район, поселок Хлебницы, Центральная, 29	f	small
38359	34921	754	Ивановская область, Тейковский район, поселок Харино, школа	f	medium
38367	34930	762	Ивановская область, Тейковский район, поселок Сокатово, Зеленая, 1/2	f	small
38363	34926	758	Ивановская область, Тейковский район, поселок Сахтыш, Постышева, 28	f	small
38368	34931	763	Ивановская область, Тейковский район, поселок Новое Леушино, площадь Ленина, 12	f	large
38358	34920	753	Ивановская область, Тейковский район, поселок Нерль, Пограничная, 11А	f	medium
38357	34919	752	Ивановская область, Тейковский район, поселок Нерль, Ленина, 4	f	medium
38356	34918	751	Ивановская область, Тейковский район, поселок Москвино, 81	f	small
38365	34928	760	Ивановская область, Тейковский район, поселок Морозово, Школьная, 16А	f	medium
38364	34927	759	Ивановская область, Тейковский район, поселок Морозово, Молодежная, 1А	f	medium
38077	34639	413	Ивановская область, Тейковский район, поселок Морозово, Гусева, 2	f	small
38362	34925	757	Ивановская область, Тейковский район, поселок Крапивново, Центральная, 38	f	medium
38366	34929	761	Ивановская область, Тейковский район, поселок Елховка, Школьная, 2А	f	small
37978	34550	293	Ивановская область, Тейковский район, поселок Грозилово, ОГБОУ ПЛ №19	f	large
134414	94320	595	Ивановская область, Тейковский район, поселок Быково, Речная, 5	f	small
132953	34923	756	Ивановская область, Тейковский район, поселок Большое Клочково, Центральная, 53 А	f	medium
38360	34922	755	Ивановская область, Тейковский район, поселок Большое Клочково, Центральная, 50	f	medium
38110	34675	454	Ивановская область, Сонковский район, поселок Беляницы, 29 В	f	medium
38352	34914	746	Ивановская область, Савинский район, поселок Шестуниха, Молодежная, 12	f	small
38354	34916	748	Ивановская область, Савинский район, поселок Савино, Полевая, 1Б	f	small
38341	34903	735	Ивановская область, Савинский район, поселок Савино, Первомайская, 39	f	medium
38340	34902	734	Ивановская область, Савинский район, поселок Савино, Первомайская, 9	f	large
38339	34901	733	Ивановская область, Савинский район, поселок Савино, Первомайская, 24	f	small
38347	34909	741	Ивановская область, Савинский район, поселок Польки, Центральная, 23	f	small
38353	34915	747	Ивановская область, Савинский район, поселок Полома, Советская, 46	f	small
38349	34911	743	Ивановская область, Савинский район, поселок Покровское, Фабричная, 6	f	small
38355	34917	749	Ивановская область, Савинский район, поселок Панфилово, Первомайская, 1А	f	small
132900	34702	486	Ивановская область, Савинский район, поселок Михалево, 25	f	small
38086	34648	422	Ивановская область, Савинский район, поселок Лычево, Административное здание сельского поселения	f	small
38350	34912	744	Ивановская область, Савинский район, поселок Горячево, Бреховская, 5	f	small
132952	34906	739	Ивановская область, Савинский район, поселок Вознесенье, Центральная, 52	f	small
38344	34905	738	Ивановская область, Савинский район, поселок Архиповка, 1-я Кооперативная, 6	f	large
38346	34908	740	Ивановская область, Савинский район, поселок Агрофенино, Центральная, 4	f	medium
38324	34888	715	Ивановская область, Родниковский район, поселок Тайманиха, Молодежный, 21	f	small
132951	34895	721	Ивановская область, Родниковский район, поселок Сосновец, Центральная, 13	f	small
38326	34890	717	Московская область, Лосино-Петровский, улица Ситьково	f	small
38321	34885	712	Ивановская область, Родниковский район, Родники, пр Северный, 1	f	large
38320	34885	711	Ивановская область, Родниковский район, Родники, пр Северный, 1	f	large
38310	34876	701	Ивановская область, Родниковский район, Родники, площадь Ленина, 10/6	f	large
38318	34881	709	Ивановская область, Родниковский район, Родники, мкр. Южный, 22	f	large
38316	34881	707	Ивановская область, Родниковский район, Родники, мкр. Южный, 22	f	large
38319	34884	710	Ивановская область, Родниковский район, Родники, микрорайон Машиностроитель, 7	f	large
38311	34843	702	Ивановская область, Родниковский район, Родники, Советская, 2	f	large
38315	34880	706	Ивановская область, Родниковский район, Родники, Народная, 7	f	large
132950	34882	708	Ивановская область, Родниковский район, Родники, 60 лет Октября, 6	f	large
38313	34878	704	Ивановская область, Родниковский район, Родники, 3-я Куликовская, 49	f	large
38335	34897	726	Ивановская область, Родниковский район, поселок Постнинский, Школьная, 24	f	medium
38328	34892	719	Ивановская область, Родниковский район, поселок Парское, Светлая, 8	f	medium
38323	34887	714	Ивановская область, Родниковский район, поселок Острецово, Центральная, 6	f	medium
38337	34899	728	Ивановская область, Родниковский район, поселок Куделино	f	small
38329	34893	720	Ивановская область, Родниковский район, поселок Котиха, Молодежная, 7	f	small
38322	34886	713	Ивановская область, Родниковский район, поселок Каминский, Каминского, 13	f	large
38331	34857	722	Ивановская область, Родниковский район, поселок Болотново	f	small
132946	34872	690	Ивановская область, Пучежский район, поселок Сеготь, Советская, 32	f	small
38288	34851	672	Ивановская область, Пучежский район, Пучеж, Ленина, 41	f	large
38287	34850	671	Ивановская область, Пучежский район, Пучеж, Ленина, 48	f	large
38292	34855	676	Ивановская область, Пучежский район, Пучеж, Кирова, 1/2	f	large
132933	34858	677	Ивановская область, Пучежский район, Пучеж, Заводская, 8/1	f	large
38290	34853	674	Ивановская область, Пучежский район, Пучеж, 60 лет Октября, 20	f	large
132941	34867	685	Ивановская область, Пучежский район, поселок Привалово, Центральная, 7	f	small
132947	34873	691	Ивановская область, Пучежский район, поселок Петрово, Центральная, 30	f	small
132943	34869	687	Ивановская область, Пучежский район, поселок Мортки, Школьная, 9	f	small
132948	34874	692	Ивановская область, Пучежский район, поселок Марищи, Школьная, 5	f	small
132936	34861	680	Ивановская область, Пучежский район, поселок Лужинки, Школьная, 7	f	small
132945	34871	689	Ивановская область, Пучежский район, поселок Летнево, Школьная, 20	f	small
132940	34866	684	Ивановская область, Пучежский район, поселок Кораблево, Садовая, 3-1	f	small
132942	34868	686	Ивановская область, Пучежский район, поселок Кандаурово, центральная, 18	f	small
132937	34862	681	Ивановская область, Пучежский район, поселок Илья-Высоково, Школьная, 3	f	medium
132934	34859	678	Ивановская область, Пучежский район, поселок Затеиха, Школьная, 8	f	medium
132935	34860	679	Ивановская область, Пучежский район, поселок Зарайское, Клубная, 3	f	small
132938	34863	682	Ивановская область, Пучежский район, поселок Дубново, Советская, 1	f	medium
132949	34875	693	Ивановская область, Пучежский район, поселок Дроздиха, Садовая, 23	f	small
132939	34864	683	Ивановская область, Пучежский район, поселок Губинская, 29	f	small
132944	34870	688	Ивановская область, Пучежский район, поселок Большое Дмитриево, Центральная, 3	f	small
38333	31317	724	Ивановская область, Приволжский район, поселок Филисово, Школьная, 1	f	small
38276	34838	651	Ивановская область, Приволжский район, поселок Филисово, Зеленая, 2	f	small
38286	34849	661	Ивановская область, Приволжский район, поселок Федорище, 88	f	small
38277	34839	652	Ивановская область, Приволжский район, поселок Утес, 26	f	small
38279	34841	654	Ивановская область, Приволжский район, поселок Толпыгино, Центральная, 8	f	medium
38275	34837	650	Ивановская область, Приволжский район, поселок Северцево, Гагарина, 6	f	medium
38285	34848	660	Ивановская область, Приволжский район, поселок Рождествено, Центральная, 27	f	small
38269	34833	644	Ивановская область, Приволжский район, Приволжск, Коминтерновская, 32	f	large
38268	34833	643	Ивановская область, Приволжский район, Приволжск, Коминтерновская, 32	f	large
38267	34832	642	Ивановская область, Приволжский район, Приволжск, Коминтерновская, 36	f	large
38266	34832	641	Ивановская область, Приволжский район, Приволжск, Коминтерновская, 36	f	large
132932	34830	640	Ивановская область, Приволжский район, Приволжск, Дружбы, 5	f	medium
132931	34830	639	Ивановская область, Приволжский район, Приволжск, Дружбы, 5	f	large
38272	34834	647	Ивановская область, Приволжский район, Приволжск, 1 Мая, 10	f	large
38271	34834	646	Ивановская область, Приволжский район, Приволжск, 1 Мая, 10	f	large
38270	34834	645	Ивановская область, Приволжский район, Приволжск, 1 Мая, 10	f	medium
38273	34835	648	Ивановская область, Приволжский район, Плес, Советская, 37	f	medium
134418	34846	658	Ивановская область, Приволжский район, поселок Парушево, 38	f	small
38282	34845	657	Ивановская область, Приволжский район, поселок Новое, Советская, 24	f	medium
38280	34842	655	Ивановская область, Приволжский район, поселок Кунестино, 72	f	small
38281	34844	656	Ивановская область, Приволжский район, поселок Красинское, 108	f	medium
38278	34840	653	Ивановская область, Приволжский район, поселок Ингарь, Спортивная, 15	f	large
38284	34847	659	Ивановская область, Приволжский район, поселок Горки-Чириковы, 6	f	small
38258	34823	630	Ивановская область, Пестяковский район, поселок Шалаево, Центральная, 5	f	small
38257	34822	629	Ивановская область, Пестяковский район, поселок Филята, Центральная, 57	f	small
38259	34824	631	Ивановская область, Пестяковский район, поселок Пестяки, Социалистическая, 15	f	large
38260	34825	632	Ивановская область, Пестяковский район, поселок Пестяки, Гагарина, 27	f	large
38254	34819	626	Ивановская область, Пестяковский район, поселок Нижний Ландех, Советская, 24	f	medium
38252	34817	624	Ивановская область, Пестяковский район, поселок Неверово-Слобода, Зелёная, 5	f	small
38255	34820	627	Ивановская область, Пестяковский район, поселок Галашово, Галашовская, 7	f	small
38256	34821	628	Ивановская область, Пестяковский район, поселок Вербино, Школьная, 12	f	small
38251	34816	623	Ивановская область, Пестяковский район, поселок Беклемищи, Молодежная, 21	f	small
38249	34813	621	Ивановская область, Пестяковский район, поселок Алехино, Центральная, 54	f	small
38243	34807	611	Ивановская область, Палехский район, поселок Тименка, 16, здание библиотеки	f	small
134416	94321	606	Ивановская область, Палехский район, поселок Сакулино, 2Б	f	small
38241	34805	609	Ивановская область, Палехский район, поселок Подолино, 16 а, здание сельского клуба	f	small
134417	34803	607	Ивановская область, Палехский район, поселок Пеньки, 40 лет Победы, 48	f	medium
38240	34804	608	Ивановская область, Палехский район, поселок Паново, Центральная, 21	f	small
38248	34812	616	Ивановская область, Палехский район, поселок Палех, Ленина, 1	f	large
38247	34811	615	Ивановская область, Палехский район, поселок Палех, Баканова, 19	f	large
38246	34810	614	Ивановская область, Палехский район, поселок Майдаково, Северная, 21	f	large
37190	30741	2604	Воронежская область, Острогожск, Энгельса, 60	f	large
38242	34806	610	Ивановская область, Палехский район, поселок Клетино, Центральная, 8	f	small
132924	34800	600	Ивановская область, Лухский район, поселок Худынское, Набережная, 56	f	small
132925	30708	601	Ивановская область, Лухский район, поселок Тимирязево, Центральная, 62	f	small
134413	94319	594	Ивановская область, Лухский район, поселок Слободки, Центральная, 1	f	small
132922	34796	598	Ивановская область, Лухский район, поселок Рябово, Школьная, 21	f	small
38231	34794	597	Ивановская область, Лухский район, поселок Порздни, Советская, 17	f	small
132921	34788	591	Ивановская область, Лухский район, поселок Лух, Красноармейская, 4А	f	large
38230	34793	596	Ивановская область, Лухский район, поселок Воскресенское-Новое, 9	f	small
134411	94317	592	Ивановская область, Лухский район, поселок Благовещенье, Центральная, 43	f	small
38223	34785	583	Ивановская область, Лежневский район, поселок Шилыково, 38, Клуб	f	medium
134410	34786	584	Ивановская область, Лежневский район, поселок Шилыково, Зеленая, 31	f	medium
38222	34784	582	Ивановская область, Лежневский район, поселок Чернцы, Центральная, 27	f	medium
38221	34783	581	Ивановская область, Лежневский район, поселок Хозниково, Лежневска, 25	f	medium
38215	34777	575	Ивановская область, Лежневский район, село Ухтохма, с. Ухтохма, Московская, 7	f	medium
38216	34778	576	Ивановская область, Лежневский район, поселок Телегино, Клуб	f	small
38220	34782	580	Ивановская область, Лежневский район, поселок Сабиново, Мичурина, 1А	f	medium
38217	34779	577	Ивановская область, Лежневский район, поселок Новые Горки, Советская, 11	f	medium
38218	34780	578	Ивановская область, Лежневский район, поселок Новые Горки, Московская, 8	f	medium
38219	34781	579	Ивановская область, Лежневский район, поселок Новые Горки, Большая Шуйская, 13Б	f	medium
38213	34775	573	Ивановская область, Лежневский район, поселок Малое Растилково, ДОУ Ивушка	f	small
38208	34771	568	Ивановская область, Лежневский район, поселок Лежнево, Советская, 15	f	medium
38207	34770	567	Ивановская область, Лежневский район, поселок Лежнево, Советская, 8	f	medium
38212	34774	572	Ивановская область, Лежневский район, поселок Лежнево, Островского, 17	f	medium
38211	34774	571	Ивановская область, Лежневский район, поселок Лежнево, Островского, 17	f	medium
38210	34773	570	Ивановская область, Лежневский район, поселок Лежнево, Ивановская, 30	f	medium
38209	34772	569	Ивановская область, Лежневский район, поселок Лежнево, 1-я Луначарского, 9	f	medium
38206	34769	566	Ивановская область, Лежневский район, поселок Лежнево, 1-я Комсомольская, 6	f	medium
38214	34776	574	Ивановская область, Лежневский район, поселок Воскресенское, Молодежная, 6	f	medium
132918	34766	556	Ивановская область, Комсомольский район, поселок Седельницы, 57	f	medium
38197	30479	551	Ивановская область, Комсомольский район, поселок Светиково, 7а	f	medium
38343	34904	737	Ивановская область, Комсомольский район, поселок Савино, Советская, 13	f	large
132920	34768	558	Ивановская область, Комсомольский район, поселок Подозерский, Ленина, 22а	f	small
132917	34763	555	Ивановская область, Комсомольский район, поселок Писцово, Советская , 4А	f	large
38200	34762	554	Ивановская область, Комсомольский район, поселок Писцово, Советская, 43	f	large
38199	34761	553	Ивановская область, Комсомольский район, поселок Октябрьский, Техническая, 5	f	medium
38195	34759	549	Ивановская область, Комсомольский район, поселок Новая Усадьба, Зои Космодемьянской, 6	f	small
38253	34818	625	Ивановская область, Комсомольский район, поселок Никулино, Центральная, 6	f	small
132919	34767	557	Ивановская область, Комсомольский район, поселок Михеево, 15	f	medium
38194	34758	548	Ивановская область, Комсомольский район, поселок Марково, Центральная, 10	f	large
38193	34757	547	Ивановская область, Комсомольский район, Комсомольск, Первомайская, 15	f	large
38191	34754	545	Ивановская область, Комсомольский район, Комсомольск, Колганова, 19	f	large
37928	95175	233	Ивановская область, Кинешма городской округ, Кинешма, 50 летия Комсомола, 27	f	large
38172	34737	524	Ивановская область, Кинешемский район, поселок Шумовская, Новая, 1	f	small
38173	34738	525	Ивановская область, Кинешемский район, поселок Шилекша, Центральная, 37	f	small
38177	34742	529	Ивановская область, Кинешемский район, поселок Стиберское, 15-А	f	small
134409	34673	542	Ивановская область, Кинешемский район, поселок Станко	f	small
38179	34744	531	Ивановская область, Кинешемский район, поселок Решма, Ленина, 12	f	medium
38182	34747	534	Ивановская область, Кинешемский район, поселок Первомайский, Садовая, 4	f	large
38183	34748	535	Ивановская область, Кинешемский район, Наволоки, Юбилейная, 18	f	large
134408	34672	541	Ивановская область, Кинешемский район, Наволоки, Энгельса, 25	f	large
38186	34750	538	Ивановская область, Кинешемский район, Наволоки, Ульянова, 6-А	f	large
38185	34749	537	Ивановская область, Кинешемский район, Наволоки, Ульянова, 6	f	large
38184	34749	536	Ивановская область, Кинешемский район, Наволоки, Ульянова, 6	f	medium
38188	34752	540	Ивановская область, Кинешемский район, Наволоки, Спортивная, 23	f	large
38178	34743	530	Ивановская область, Кинешемский район, поселок Луговое, Школьная, 15	f	large
38170	34735	522	Ивановская область, Кинешемский район, поселок Лагуниха, Торговая, 8	f	small
38176	34741	528	Ивановская область, Кинешемский район, поселок Красногорский, Красногорская, 12	f	small
38175	34740	527	Ивановская область, Кинешемский район, поселок Ильинское, школьная, 2	f	small
38174	34739	526	Ивановская область, Кинешемский район, поселок Зобнино, Совхозная, 10	f	small
38169	34734	521	Ивановская область, Кинешемский район, поселок Закусихино, Фабричная, 5	f	small
38181	34746	533	Ивановская область, Кинешемский район, поселок Журихино, Урожайная, 7	f	small
38180	34745	532	Ивановская область, Кинешемский район, поселок Дьячево, микрорайон санатория Решма, 11	f	large
38171	34736	523	Ивановская область, Кинешемский район, поселок Горки, Завражная, 52	f	medium
38168	34733	520	Ивановская область, Кинешемский район, поселок Большие Горки, Большегорковская, 4	f	small
38167	34732	519	Ивановская область, Кинешемский район, поселок Батманы, Центральная, 4	f	small
38165	34730	513	Ивановская область, Ильинский район, поселок Щенниково, Советская, 2	f	small
38342	14672	736	Ивановская область, Ильинский район, поселок Савино, Малиновского, 20	f	medium
38087	34649	423	Ивановская область, Ильинский район, поселок Новоселка, здвние Дома культуры	f	small
38196	34760	550	Ивановская область, Ильинский район, поселок Никольское, 184	f	small
38164	34729	512	Ивановская область, Ильинский район, поселок Нажерово, Советская, 22	f	small
38162	34727	510	Ивановская область, Ильинский район, поселок Кулачево, Школьная, 21	f	small
132914	34722	507	Ивановская область, Ильинский район, поселок Коварчино, Советская, 24	f	small
38161	34726	509	Ивановская область, Ильинский район, поселок Исаевское, Советская, 26	f	small
38155	34718	503	Ивановская область, Ильинский район, поселок Ильинское-Хованское, Школьная, 10	f	small
38153	34716	501	Ивановская область, Ильинский район, поселок Ильинское-Хованское, Советская, 44	f	large
134406	94315	502	Ивановская область, Ильинский район, поселок Ильинское-Хованское, Революционная, 7	f	large
38348	34910	742	Ивановская область, Ильинский район, поселок Воскресенское, Советская, 16	f	medium
38157	34720	505	Ивановская область, Ильинский район, поселок Аньково, Строительная, 3	f	medium
134407	94316	506	Ивановская область, Ильинский район, поселок Аньково, Полевая, 23А	f	medium
132895	34681	464	Ивановская область, Ивановский район, с. Богородское , Парковская, 58	f	large
37958	34537	269	Ивановская область, Ивановский район, городской округ Кохма, Ивановская, 19	f	large
132913	34715	499	Ивановская область, Ивановский район, поселок Чернореченский, Победы, 1 А	f	medium
132912	34715	498	Ивановская область, Ивановский район, поселок Чернореченский, Победы, 1 А	f	medium
132911	34715	497	Ивановская область, Ивановский район, поселок Чернореченский, Победы, 1 А	f	medium
38245	34809	613	Ивановская область, Ивановский район, поселок Теплово, Зеленая, 45	f	small
38114	34635	458	Ивановская область, Ивановский район, поселок Стромихино, 36 кв6	f	small
38119	34679	463	Ивановская область, Ивановский район, поселок Светлый Луч, 20, кв. 7	f	medium
132906	34708	492	Ивановская область, Ивановский район, поселок Подвязновский, 25	f	small
132905	34708	491	Ивановская область, Ивановский район, поселок Подвязновский, 25	f	small
38126	34688	470	Ивановская область, Ивановский район, поселок Панеево, 52	f	medium
132902	34705	488	Ивановская область, Ивановский район, поселок Озерный, Школьная , 8	f	medium
132903	34705	489	Ивановская область, Ивановский район, поселок Озерный, Школьная , 8	f	medium
38137	34697	481	Ивановская область, Ивановский район, поселок Новоталицы, Школьная, 20	f	large
38136	34697	480	Ивановская область, Ивановский район, поселок Новоталицы, Школьная, 20	f	large
132899	34697	485	Ивановская область, Ивановский район, поселок Новоталицы, Школьная, 20	f	small
132898	34693	476	Ивановская область, Ивановский район, поселок Новоталицы, Радужная, 5	f	large
38133	34695	477	Ивановская область, Ивановский район, поселок Новоталицы, Радужная, 5	f	large
38135	34696	479	Ивановская область, Ивановский район, поселок Новоталицы, Новинская, 2	f	large
38134	34696	478	Ивановская область, Ивановский район, поселок Новоталицы, Новинская, 2	f	large
132901	34704	487	Ивановская область, Ивановский район, поселок Новоталицы, 2 Шиймановская, 6	f	small
38139	34699	483	Ивановская область, Ивановский район, поселок Новоталицы, 1-я Яковлевская улица, 20	f	small
38140	34700	484	Ивановская область, Ивановский район, поселок Михалево, 25	f	large
38128	34689	472	Ивановская область, Ивановский район, поселок Куликово, 60	f	small
38127	34689	471	Ивановская область, Ивановский район, поселок Куликово, 60	f	medium
38113	34677	457	Ивановская область, Ивановский район, поселок Кочорский, Спортивная, 13	f	medium
38130	34691	474	Ивановская область, Ивановский район, поселок Котцыно, Школьная, 18	f	small
132910	34714	496	Ивановская область, Ивановский район, поселок Колбацкое, Троицкая, 26а	f	small
38129	34690	473	Тверская область, Торжокский район, поселок Кожевниково	f	small
38131	34692	475	Ивановская область, Ивановский район, поселок Калачево, 41	f	small
38138	34698	482	Ивановская область, Ивановский район, поселок Залесье, Запрудная, 10	f	small
132909	34713	495	Ивановская область, Ивановский район, поселок Ермолино, Колхозная, 30	f	medium
132908	34713	494	Ивановская область, Ивановский район, поселок Ермолино, Колхозная, 30	f	medium
132897	34686	469	Ивановская область, Ивановский район, поселок Дегтярево, 64	f	medium
132896	34684	466	Ивановская область, Ивановский район, поселок Бяково, Озерная, 6А	f	small
38109	34674	453	Ивановская область, Ивановский район, поселок Буньково, Лесная, 16	f	small
38112	30212	456	Ивановская область, Ивановский район, поселок Богданиха, 93	f	small
38115	30212	459	Ивановская область, Ивановский район, поселок Богданиха, 93	f	medium
38116	30212	460	Ивановская область, Ивановский район, поселок Богданиха, 93	f	medium
132904	34703	490	Ивановская область, Ивановский район, поселок Бибирево, Садовая, 4	f	medium
38108	34671	452	Ивановская область, Ивановский район, поселок Балахонки, Центральная, 41	f	small
38107	34671	451	Ивановская область, Ивановский район, поселок Балахонки, Центральная, 41	f	small
38098	34662	438	Ивановская область, Заволжский район, поселок Новлянское, Центральная, 27	f	small
38100	34664	440	Ивановская область, Заволжский район, поселок Коротиха, Центральная, 6	f	small
38099	34663	439	Ивановская область, Заволжский район, поселок Коротиха, Центральная, 3	f	medium
134524	34668	443	Ивановская область, Заволжский район, поселок Корнилово, Зеленая, 14	f	small
38102	34666	442	Ивановская область, Заволжский район, поселок Колшево, школьная, 12	f	small
38101	34665	441	Ивановская область, Заволжский район, поселок Заречный, Фабричная, 18	f	medium
38093	34657	433	Ивановская область, Заволжский район, Заволжск, Школьная, 1	f	large
132890	34653	431	Ивановская область, Заволжский район, Заволжск, Мира, 20	f	large
38090	34652	430	Ивановская область, Заволжский район, Заволжск, Мира, 5	f	large
134525	94414	444	Ивановская область, Заволжский район, поселок Жажлево, Школьная, 10	f	small
38096	34660	436	Ивановская область, Заволжский район, поселок Есиплево, Административная, 1	f	medium
134526	94415	445	Ивановская область, Заволжский район, поселок Долматовский, здание начальной школы	f	medium
38097	34661	437	Ивановская область, Заволжский район, поселок Гольцовка, Центральная, 19	f	small
38095	34659	435	Ивановская область, Заволжский район, поселок Воздвиженье, Центральная, 13	f	medium
38079	34641	415	Ивановская область, Гаврилово-Посадский район, поселок Шекшово, Конец, 7	f	small
38084	34646	420	Ивановская область, Гаврилово-Посадский район, поселок Скомово	f	small
37189	30741	2603	Воронежская область, Острогожск, Энгельса, 60	f	large
38082	34644	418	Ивановская область, Гаврилово-Посадский район, поселок Ратницкое	f	small
134404	94313	412	Ивановская область, Гаврилово-Посадский район, поселок Петровский, Чкалова, 2	f	large
38083	34645	419	Ивановская область, Гаврилово-Посадский район, поселок Осановец, Здание администрации сельского поселения	f	medium
38080	34642	416	Ивановская область, Гаврилово-Посадский район, поселок Непотягово, Старая, 22А	f	small
38078	34640	414	Ивановская область, Гаврилово-Посадский район, поселок Лобцово	f	small
38075	34637	411	Ивановская область, Гаврилово-Посадский район, село Липовая Роща, пл. 70 лет Октября, 7	f	medium
38089	34651	425	Калужская область, Хвастовичский район, поселок Иваньковский	f	small
38085	34647	421	Новгородская область, Валдайский район, село Загорье	f	small
38073	34634	409	Ивановская область, Гаврилово-Посадский район, Гаврилов Посад, пос. 9 Января, 23	f	large
38072	34633	408	Ивановская область, Гаврилово-Посадский район, Гаврилов Посад, пл. Советская, 9	f	large
38074	34636	410	Ивановская область, Гаврилово-Посадский район, Гаврилов Посад, Советская, 16	f	large
38081	34643	417	Тюменская область, Викуловский район, село Бородино	f	small
38088	34650	424	Новгородская область, Хвойнинский район, село Бережок	f	small
38068	34630	400	Ивановская область, Вичугский район, поселок Чертовищи, Парковая, 2	f	large
38069	34630	401	Ивановская область, Вичугский район, поселок Чертовищи, Парковая, 2	f	medium
38061	34623	393	Ивановская область, Вичугский район, поселок Старая Вичуга, Школьная, 2	f	large
38060	34622	392	Ивановская область, Вичугский район, поселок Старая Вичуга, Советская, 6	f	large
38059	34621	391	Ивановская область, Вичугский район, поселок Старая Вичуга, Клшубная, 7	f	large
38065	34627	397	Ивановская область, Вичугский район, поселок Сошники, 1 Школьная, 4	f	medium
134412	94318	593	Ивановская область, Вичугский район, поселок Сорокино, Центральная,  3	f	small
38071	34632	403	Ивановская область, Вичугский район, поселок Семигорье, 109	f	small
38070	34631	402	Ивановская область, Вичугский район, поселок Семигорье, 111	f	small
38066	34628	398	Ивановская область, Вичугский район, поселок Семеновское, 44	f	small
38244	34808	612	Владимирская область, Вязниковский район, поселок Раменье	f	small
38067	34629	399	Ивановская область, Вичугский район, поселок Раздолье, 9	f	small
38351	34913	745	Ивановская область, Вичугский район, поселок Панино, Центральная, 22	f	small
38058	34620	390	Ивановская область, Вичугский район, поселок Новописцово, пер.Почтовый, 5	f	large
38057	34619	389	Ивановская область, Вичугский район, поселок Новописцово, Аптечная, 11	f	large
38332	30725	723	Ивановская область, Вичугский район, поселок Малышево, Центральная, 11	f	small
38064	34626	396	Ивановская область, Вичугский район, поселок Красный Октябрь, 7	f	medium
38056	34618	388	Ивановская область, Вичугский район, поселок Каменка, Николаева, 4	f	large
38055	34617	387	Ивановская область, Вичугский район, поселок Каменка, 1 Мая, 11	f	large
38163	34728	511	Ивановская область, Вичугский район, поселок Ивашево, Совхозная, 2	f	medium
38062	34624	394	Ивановская область, Вичугский район, поселок Золотилово, 66	f	small
132927	34815	622	Ивановская область, Вичугский район, поселок Демидово, Клубная, 12	f	small
38156	34719	504	Ивановская область, Вичугский район, поселок Гари, Школьная, 13	f	small
38063	34625	395	Ивановская область, Вичугский район, поселок Гаврилково, 108	f	medium
134403	94312	384	Ивановская область, Верхнеландеховский район, поселок Симаково, Советская, 24	f	small
38052	34062	383	Ивановская область, Верхнеландеховский район, поселок Мыт, Торговая, 9	f	small
38051	33845	382	Ивановская область, Верхнеландеховский район, поселок Мыт, Восточная, 42	f	small
38050	33845	381	Ивановская область, Верхнеландеховский район, поселок Мыт, Восточная, 42	f	small
38048	34465	379	Ивановская область, Верхнеландеховский район, поселок Кромы, Черемушки, 15	f	small
38198	30562	552	Ивановская область, Верхнеландеховский район, поселок Иваньково, 46	f	medium
38054	34616	385	Ивановская область, Верхнеландеховский район, поселок Засека, Школьная, 33	f	small
134402	34614	378	Ивановская область, Верхнеландеховский район, поселок Верхний Ландех, пер.Школьный, 1	f	medium
37194	30745	2608	Воронежская область, Острогожск, Комсомольская, 71	f	large
134401	34614	377	Ивановская область, Верхнеландеховский район, поселок Верхний Ландех, пер.Школьный, 1	f	medium
38045	34614	376	Ивановская область, Верхнеландеховский район, поселок Верхний Ландех, пер.Школьный, 1	f	medium
38049	34598	380	Ивановская область, Верхнеландеховский район, поселок Бараново, Колхозная, 13	f	small
37677	31220	3823	Воронежская область, с.Новогремяченское, Чапаева, 12	f	large
37720	31264	3932	Воронежская область, Эртиль, площадь Ленина, 8	f	medium
68116	31266	3934	Воронежская область, Эртиль, Труда, 7	f	large
68115	31263	3931	Воронежская область, Эртиль, Советская, 2	f	large
109490	31273	3941	Воронежская область, Эртиль, Лермонтова, 20	f	medium
68117	31276	3943	Воронежская область, Эртиль, Горная, 12	f	large
37534	31082	3507	Воронежская область, Семилуки, переулок Гагарина, 27	f	large
37535	31083	3508	Воронежская область, Семилуки, Чапаева, 62	f	large
37528	31076	3501	Воронежская область, Семилуки, Чайковского, 3	f	large
37550	31084	3523	Воронежская область, Семилуки, Транспортная, 16	f	large
37536	31084	3509	Воронежская область, Семилуки, Транспортная, 16	f	large
37532	31080	3505	Воронежская область, Семилуки, Крупской переулок, 3	f	large
37533	31081	3506	Воронежская область, Семилуки, Дзержинского, 10	f	large
37530	31078	3503	Воронежская область, Семилуки, Башкирцева переулок, 8	f	medium
37567	31114	3540	Воронежская область, Семилуки, 8 Марта, 34	f	large
37538	31086	3511	Воронежская область, Семилуки, 25 лет Октября, 132а	f	large
37531	31079	3504	Воронежская область, Семилуки, 25 лет Октября, 26	f	large
37470	31018	3414	Воронежская область, Россошь, проспект Труда, 14	f	large
37469	31017	3413	Воронежская область, Россошь, проспект Труда, 20	f	large
37463	31011	3407	Воронежская область, Россошь, пролетарская, 67	f	large
37527	31075	3471	Воронежская область, Россошь, площадь Танкистов, 5С	f	small
37466	31014	3410	Воронежская область, Россошь, переулок Школьный, 3	f	large
37474	31021	3418	Воронежская область, Россошь, луговая, 1	f	large
37473	31021	3417	Воронежская область, Россошь, луговая, 1	f	large
37476	31023	3420	Воронежская область, Россошь, Элеваторная, 2	f	large
37442	30993	3305	Воронежская область, Россошь, Центральная, 31	f	medium
68096	31016	3412	Воронежская область, Россошь, Фурманова, 6А/1	f	large
37459	31007	3403	Воронежская область, Россошь, Урицкого, 14	f	large
37483	31031	3427	Воронежская область, Россошь, Толбухина, 43	f	large
37478	31025	3422	Воронежская область, Россошь, Свердлова, 47	f	large
37484	31032	3428	Воронежская область, Россошь, Розы Люксембург, 151	f	large
37467	31015	3411	Воронежская область, Россошь, Простеева, 5	f	large
37475	31022	3419	Воронежская область, Россошь, Пролетарская, 146	f	large
68097	31019	3415	Воронежская область, Россошь, Пролетарская, 113	f	large
37465	31013	3409	Воронежская область, Россошь, Пролетарская, 87А	f	large
37464	31012	3408	Воронежская область, Россошь, Пролетарская, 73	f	large
37462	31010	3406	Воронежская область, Россошь, Пролетарская, 61	f	large
37461	31009	3405	Воронежская область, Россошь, Пролетарская, 13	f	large
37458	31006	3402	Воронежская область, Россошь, Пески, 2	f	large
37457	31005	3401	Воронежская область, Россошь, Октябрьская, 152	f	large
37480	31028	3424	Воронежская область, Россошь, Маршака, 61	f	large
37460	31008	3404	Воронежская область, Россошь, Ленина, 2	f	large
37477	31024	3421	Воронежская область, Россошь, Крупской, 66	f	large
37481	31029	3425	Воронежская область, Россошь, Заводская, 19	f	large
68098	31026	3423	Воронежская область, Россошь, Дзержинского, 66	f	large
68099	31030	3426	Воронежская область, Россошь, Деповская, 10	f	large
37472	31020	3416	Воронежская область, Россошь, Белинского, 20	f	large
37354	30905	3003	Воронежская область, Поворино, Советская, 33	f	large
37356	30907	3005	Воронежская область, Поворино, Садовая, 14	f	large
37358	30908	3007	Воронежская область, Поворино, Народная, 64	f	large
37357	30908	3006	Воронежская область, Поворино, Народная, 64	f	large
37355	30906	3004	Воронежская область, Поворино, Линейная, 23	f	large
37247	30798	2707	Воронежская область, Павловск, проспект Революции, 102	f	large
37248	30799	2708	Воронежская область, Павловск, микрорайон Гранитный, 9	f	large
37246	30797	2706	Воронежская область, Павловск, Ю.Фучика, 13	f	large
37242	30793	2702	Воронежская область, Павловск, Покровская, 9	f	large
37196	30747	2610	Воронежская область, Острогожск, Карла Маркса, 67	f	large
37192	30743	2606	Воронежская область, Острогожск, Карла Маркса, 31	f	large
68092	30753	2616	Воронежская область, Острогожск, 50 лет Октября, 153	f	large
37201	30752	2615	Воронежская область, Острогожск, 50 лет Октября, 103	f	large
37120	30671	2402	Воронежская область, Новохоперск, Советская, 142	f	large
37121	30672	2403	Воронежская область, Новохоперск, Плотникова, 1	f	large
37122	30673	2404	Воронежская область, Новохоперск, Ленина, 42	f	large
37071	30622	2210	Воронежская область, Нововоронеж, Победы, 3 А	f	large
37072	30623	2211	Воронежская область, Нововоронеж, Первомайская, 1	f	large
37063	30616	2202	Воронежская область, Нововоронеж, Октябрьская, 9	f	large
37067	30619	2206	Воронежская область, Нововоронеж, Набережная, 14	f	large
37066	30619	2205	Воронежская область, Нововоронеж, Набережная, 14	f	large
37068	30620	2207	Воронежская область, Нововоронеж, Космонавтов, 20	f	large
37005	30561	2061	Воронежская область, поселок Лиски, Советская, 100А, сельский клуб	f	large
36976	30532	2032	Воронежская область, Лиски, проспект Ленина, 47	f	large
36968	30527	2024	Воронежская область, Лиски, площадь Революции, 10	f	large
36965	30525	2021	Воронежская область, Лиски, Энтузиастов, 9	f	large
36966	30517	2022	Воронежская область, Лиски, Чернышевского, 19	f	large
36956	30517	2012	Воронежская область, Лиски, Чернышевского, 19	f	large
36947	30508	2003	Воронежская область, Лиски, Советская, 29	f	large
36946	30508	2002	Воронежская область, Лиски, Советская, 29	f	large
36974	30518	2030	Воронежская область, Лиски, Первомайская, 46	f	large
36957	30518	2013	Воронежская область, Лиски, Первомайская, 46	f	large
36952	30513	2008	Воронежская область, Лиски, Ломоносова, 44	f	large
36971	30528	2027	Воронежская область, Лиски, 40 лет Победы, 6	f	large
36959	30520	2015	Воронежская область, Лиски, 40 лет Победы, 62	f	large
36962	30523	2018	Воронежская область, Лиски, 40 лет Октября, 43а	f	large
36972	30529	2028	Воронежская область, Лиски, 19 Партсъезда, 5	f	large
36810	30377	1606	Воронежская область, Калач, Пугачева, 11	f	large
36811	30378	1607	Воронежская область, Калач, Комсомольская, 49	f	large
36804	30371	1539	Воронежская область, поселок Грибановский, Советская, 295	f	large
36767	30334	1502	Воронежская область, поселок Грибановский, Мебельная, 3	f	large
36409	30076	946	Воронежская область, Воронеж, федора тютчева, 6	f	large
68084	30316	1422	Воронежская область, Воронеж, улица Шишкова, 105	f	large
36671	30264	1326	Воронежская область, Воронеж, улица Шендрикова, 4	f	large
36670	30264	1325	Воронежская область, Воронеж, улица Шендрикова, 4	f	large
36669	30264	1324	Воронежская область, Воронеж, улица Шендрикова, 4	f	large
36667	30264	1322	Воронежская область, Воронеж, улица Шендрикова, 4	f	large
36713	30293	1368	Воронежская область, Воронеж, Шилово микрорайон, улица Теплоэнергетиков, 8	f	large
36538	30166	1120	Воронежская область, Воронеж, улица Танеева, 4	f	large
36533	30166	1115	Воронежская область, Воронеж, улица Танеева, 4	f	large
36615	30223	1217	Воронежская область, Воронеж, улица Матросова, 2а	f	large
36643	30247	1245	Воронежская область, Воронеж, улица Ворошилова, 1/А	f	large
36642	30246	1244	Воронежская область, Воронеж, улица Ворошилова, 14	f	large
36400	30069	937	Воронежская область, Воронеж, улица Богдана Хмельницкого, 34	f	large
36399	30069	936	Воронежская область, Воронеж, улица Богдана Хмельницкого, 34	f	large
36446	30105	1027	Воронежская область, Воронеж, улица Беговая, 96	f	large
36639	30244	1241	Воронежская область, Воронеж, улица III Интернационала, 33	f	large
68070	30087	1002	Воронежская область, Воронеж, улица 60 лет ВЛКСМ, 27	f	large
68072	30087	1063	Воронежская область, Воронеж, улица 60 лет ВЛКСМ, 27	f	large
36423	30089	1004	Воронежская область, Воронеж, проспект Труда, 70	f	large
36744	30315	1421	Воронежская область, Воронеж, проспект Революции, 29	f	large
36739	30311	1416	Воронежская область, Воронеж, проспект Революции, 19	f	large
36738	30310	1415	Воронежская область, Воронеж, проспект Революции, 18	f	large
36719	30296	1374	Воронежская область, Воронеж, проспект Патриотов, 53	f	large
36699	30283	1354	Воронежская область, Воронеж, проспект Патриотов, 1	f	large
36692	30279	1347	Воронежская область, Воронеж, проспект Патриотов, 8	f	large
80891	55396	44	Москва, Садовническая, 68	f	large
36517	30153	1098	Воронежская область, Воронеж, площадь Советов, 28/А	f	large
36731	30304	1408	Воронежская область, Воронеж, Центральный район, площадь Ленина, 10	f	large
36632	30237	1234	Воронежская область, Воронеж, площадь Ленина, 2	f	large
36590	30208	1172	Воронежская область, Воронеж, переулок Звездный, 2	f	large
36556	30182	1138	Воронежская область, Воронеж, набережная Авиастроителей, 30а	f	large
36555	30182	1137	Воронежская область, Воронеж, набережная Авиастроителей, 30а	f	large
36501	30142	1082	Воронежская область, Воронеж, генерала Лизюкова, 2	f	large
36498	30141	1079	Воронежская область, Воронеж, генерала Лизюкова, 26	f	large
36500	30141	1081	Воронежская область, Воронеж, генерала Лизюкова, 26	f	large
36499	30141	1080	Воронежская область, Воронеж, генерала Лизюкова, 26	f	large
36494	30138	1075	Воронежская область, Воронеж, генерала Лизюкова, 52а	f	large
36493	30138	1074	Воронежская область, Воронеж, генерала Лизюкова, 52а	f	large
36487	30135	1068	Воронежская область, Воронеж, генерала Лизюкова, 81	f	large
36506	30145	1087	Воронежская область, Воронеж, бульвар Победы, 32	f	large
36657	30258	1312	Воронежская область, Воронеж, бульвар Пионеров, 14	f	large
68083	30258	1311	Воронежская область, Воронеж, бульвар Пионеров, 14	f	large
36702	30285	1357	Воронежская область, Воронеж, Юлюса Янониса, 10/2	f	large
36701	30284	1356	Воронежская область, Воронеж, Юлюса Янониса, 6	f	large
36700	30284	1355	Воронежская область, Воронеж, Юлюса Янониса, 6	f	large
36698	30282	1353	Воронежская область, Воронеж, Юлюса Янониса, 4	f	large
36697	30282	1352	Воронежская область, Воронеж, Юлюса Янониса, 4	f	large
36696	30282	1351	Воронежская область, Воронеж, Юлюса Янониса, 4	f	large
36679	30271	1334	Воронежская область, Воронеж, Южно-Моравская, 18	f	large
36681	30271	1336	Воронежская область, Воронеж, Южно-Моравская, 18	f	large
36680	30271	1335	Воронежская область, Воронеж, Южно-Моравская, 18	f	large
36678	30271	1333	Воронежская область, Воронеж, Южно-Моравская, 18	f	large
36677	30270	1332	Воронежская область, Воронеж, Южно-Моравская, 3	f	large
36668	30265	1323	Воронежская область, Воронеж, Южно-Моравская, 74	f	large
36672	30265	1327	Воронежская область, Воронеж, Южно-Моравская, 74	f	large
36449	30108	1030	Воронежская область, Воронеж, Электросигнальная, 1	f	large
36407	30074	944	Воронежская область, Воронеж, Электровозная, 12	f	large
36406	30074	943	Воронежская область, Воронеж, Электровозная, 12	f	large
36465	30119	1046	Воронежская область, Воронеж, Шишкова, 60	f	large
36675	30268	1330	Воронежская область, Воронеж, Шендрикова, 7	f	large
36674	30268	1329	Воронежская область, Воронеж, Шендрикова, 7	f	large
36605	30216	1207	Воронежская область, Воронеж, Черняховского, 2	f	large
36604	30216	1206	Воронежская область, Воронеж, Черняховского, 2	f	large
36603	30216	1205	Воронежская область, Воронеж, Черняховского, 2	f	large
36581	30200	1163	Воронежская область, Воронеж, Черепанова, 18	f	large
36580	30200	1162	Воронежская область, Воронеж, Черепанова, 18	f	large
36623	30230	1225	Воронежская область, Воронеж, Челюскинцев, 84	f	large
36527	30161	1109	Воронежская область, Воронеж, Чебышева, 2б	f	large
36617	30225	1219	Воронежская область, Воронеж, Чапаева, 115	f	large
36588	30206	1170	Воронежская область, Воронеж, Циолковского, 129а	f	large
36545	30175	1127	Воронежская область, Воронеж, Циолковского, 20	f	large
36548	30174	1130	Воронежская область, Воронеж, Циолковского, 12а	f	large
68074	30174	1126	Воронежская область, Воронеж, Циолковского, 12а	f	large
36543	30173	1125	Воронежская область, Воронеж, Циолковского, 28	f	large
36552	30171	1134	Воронежская область, Воронеж, Циолковского, 5	f	large
36541	30171	1123	Воронежская область, Воронеж, Циолковского, 5	f	large
36534	30156	1116	Воронежская область, Воронеж, Цимлянский переулок, 2	f	large
36521	30156	1103	Воронежская область, Воронеж, Цимлянский переулок, 2	f	large
36535	30167	1117	Воронежская область, Воронеж, Цимлянская, 6	f	large
36714	30291	1369	Воронежская область, Воронеж, Центральная, 44	f	large
36711	30291	1366	Воронежская область, Воронеж, Центральная, 44	f	large
86343	31250	3919	Воронежская область, Воронеж, Центральная, 64	f	small
36485	30133	1066	Воронежская область, Воронеж, Хользунова, 78	f	large
36484	30133	1065	Воронежская область, Воронеж, Хользунова, 78	f	large
36483	30133	1064	Воронежская область, Воронеж, Хользунова, 78	f	large
36481	30132	1062	Воронежская область, Воронеж, Хользунова, 70	f	large
36480	30131	1061	Воронежская область, Воронеж, Хользунова, 70	f	large
36479	30130	1060	Воронежская область, Воронеж, Хользунова, 68	f	large
36478	30129	1059	Воронежская область, Воронеж, Хользунова, 64	f	large
36474	30126	1055	Воронежская область, Воронеж, Хользунова, 40а	f	large
36473	30126	1054	Воронежская область, Воронеж, Хользунова, 40а	f	large
36472	30125	1053	Воронежская область, Воронеж, Хользунова, 44	f	large
36471	30124	1052	Воронежская область, Воронеж, Хользунова, 38	f	large
36468	30121	1049	Воронежская область, Воронеж, Хользунова, 40	f	large
36443	30103	1024	Воронежская область, Воронеж, Хользунова, 106	f	large
36733	30306	1410	Воронежская область, Воронеж, Фридриха Энгельса, 23	f	large
36730	30303	1407	Воронежская область, Воронеж, Фридриха Энгельса, 56	f	large
36630	30235	1232	Воронежская область, Воронеж, Фридриха Энгельса, 76	f	large
36629	30235	1231	Воронежская область, Воронеж, Фридриха Энгельса, 76	f	large
36469	30122	1050	Воронежская область, Воронеж, Ученический переулок, 1	f	large
36457	30113	1038	Воронежская область, Воронеж, Урицкого, 66	f	large
36456	30112	1037	Воронежская область, Воронеж, Урицкого, 86	f	large
36455	30112	1036	Воронежская область, Воронеж, Урицкого, 86	f	large
36420	30086	1001	Воронежская область, Воронеж, Урицкого, 75а	f	large
36740	30312	1417	Воронежская область, Воронеж, Центральный район, Университетская площадь, 1	f	large
36608	30218	1210	Воронежская область, Воронеж, Туркменский переулок, 14а	f	large
36607	30218	1209	Воронежская область, Воронеж, Туркменский переулок, 14а	f	large
68078	30218	1211	Воронежская область, Воронеж, Туркменский переулок, 14а	f	large
36587	30205	1169	Воронежская область, Воронеж, Туполева, 25	f	large
36585	30203	1167	Воронежская область, Воронеж, Туполева, 13а	f	large
36584	30203	1166	Воронежская область, Воронеж, Туполева, 13а	f	large
36582	30201	1164	Воронежская область, Воронеж, Туполева, 15в	f	large
36579	30199	1161	Воронежская область, Воронеж, Туполева, 18	f	large
36578	30199	1160	Воронежская область, Воронеж, Туполева, 18	f	large
36577	30197	1159	Воронежская область, Воронеж, Туполева, 40	f	large
36576	30197	1158	Воронежская область, Воронеж, Туполева, 40	f	large
36459	30115	1040	Воронежская область, Воронеж, Транспортная, 51	f	large
36458	30114	1039	Воронежская область, Воронеж, Транспортная, 49	f	large
36759	30326	1436	Воронежская область, Воронеж, Тимирязева, 8	f	large
36758	30326	1435	Воронежская область, Воронеж, Тимирязева, 8	f	large
36709	30289	1364	Воронежская область, Воронеж, Теплоэнергетиков, 15а	f	large
36720	30287	1375	Воронежская область, Воронеж, Тепличная, 20б	f	large
36707	30287	1362	Воронежская область, Воронеж, Тепличная, 20б	f	large
36706	30287	1361	Воронежская область, Воронеж, Тепличная, 20б	f	large
36592	30209	1174	Воронежская область, Воронеж, Тавровская, 57	f	medium
36411	30078	948	Воронежская область, Воронеж, Сухумская, 1	f	large
36737	30309	1414	Воронежская область, Воронеж, Студенческая, 10	f	large
36736	30309	1413	Воронежская область, Воронеж, Студенческая, 10	f	large
36735	30308	1412	Воронежская область, Воронеж, Студенческая, 18	f	large
36734	30307	1411	Воронежская область, Воронеж, Студенческая, 29	f	large
36593	30210	1175	Воронежская область, Воронеж, Степная, 2в	f	medium
36751	30322	1428	Воронежская область, Воронеж, Советский переулок, 2	f	large
36747	30318	1424	Воронежская область, Воронеж, Смоленская улица, 33	f	large
36646	30249	1301	Воронежская область, Воронеж, Силикатная, 14	f	large
36562	30188	1144	Воронежская область, Воронеж, Серова, 4	f	large
36641	30245	1243	Воронежская область, Воронеж, Свободы, 77	f	large
36640	30245	1242	Воронежская область, Воронеж, Свободы, 77	f	large
36634	30239	1236	Воронежская область, Воронеж, Свободы, 59	f	large
36746	30317	1423	Воронежская область, Воронеж, Сакко и Ванцетти, 80	f	large
36539	30169	1121	Воронежская область, Воронеж, Саврасова, 16	f	large
36537	30169	1119	Воронежская область, Воронеж, Саврасова, 16	f	large
36536	30168	1118	Воронежская область, Воронеж, Саврасова, 2а	f	large
36532	30165	1114	Воронежская область, Воронеж, Ростовская, 61	f	large
36531	30164	1113	Воронежская область, Воронеж, Ростовская, 55	f	large
36598	30160	1180	Воронежская область, Воронеж, Ростовская, 48/4	f	large
36526	30160	1108	Воронежская область, Воронеж, Ростовская, 48/4	f	large
36525	30159	1107	Воронежская область, Воронеж, Ростовская, 36	f	large
36523	30158	1105	Воронежская область, Воронеж, Ростовская, 39	f	large
36524	30158	1106	Воронежская область, Воронеж, Ростовская, 39	f	large
36569	30192	1151	Воронежская область, Воронеж, Рижская, 8а	f	large
36570	30192	1152	Воронежская область, Воронеж, Рижская, 8а	f	large
36377	30053	914	Воронежская область, Воронеж, Репненская, 82	f	large
36742	30314	1419	Воронежская область, Воронеж, Пятницкого, 67	f	large
36743	30314	1420	Воронежская область, Воронеж, Пятницкого, 67	f	large
36628	30234	1230	Воронежская область, Воронеж, Пушкинская, 39	f	large
36450	30109	1031	Воронежская область, Воронеж, Политехнический переулок, 16	f	large
36451	30109	1032	Воронежская область, Воронеж, Политехнический переулок, 16	f	large
36549	30178	1131	Воронежская область, Воронеж, Полины Осипенко, 4	f	large
36637	30242	1239	Воронежская область, Воронеж, Плехановская, 39	f	large
68082	30236	1233	Воронежская область, Воронеж, Платонова, 25	f	large
36693	30280	1348	Воронежская область, Воронеж, Пеше-Стрелецкая, 90	f	large
36655	30257	1310	Воронежская область, Воронеж, Пеше-Стрелецкая, 95	f	large
36388	30061	925	Воронежская область, Воронеж, Переверткина, 49	f	large
36385	30059	922	Воронежская область, Воронеж, Переверткина, 42б	f	large
36383	30057	920	Воронежская область, Воронеж, Переверткина, 25	f	large
36382	30057	919	Воронежская область, Воронеж, Переверткина, 25	f	large
36381	30056	918	Воронежская область, Воронеж, Переверткина, 19	f	large
36380	30055	917	Воронежская область, Воронеж, Переверткина, 34	f	large
36379	30055	916	Воронежская область, Воронеж, Переверткина, 34	f	large
36376	30052	913	Воронежская область, Воронеж, Переверткина, 5	f	large
36374	30050	911	Воронежская область, Воронеж, Переверткина, 16	f	large
36373	30050	910	Воронежская область, Воронеж, Переверткина, 16	f	large
36372	30050	909	Воронежская область, Воронеж, Переверткина, 16	f	large
36802	30369	1537	Воронежская область, Воронеж, Первомайская , 12	f	small
36405	30073	942	Воронежская область, Воронеж, Паровозная, 62	f	large
36384	30058	921	Воронежская область, Воронеж, Остужева, 1	f	large
36368	30048	905	Воронежская область, Воронеж, Остужева, 26	f	large
68080	30221	1215	Воронежская область, Воронеж, Острогожский переулок, 1а	f	large
36614	30222	1216	Воронежская область, Воронеж, Острогожская, 83	f	large
36683	30273	1338	Воронежская область, Воронеж, Олеко Дундича, 25	f	large
36710	30290	1365	Воронежская область, Воронеж, Октябрьская, 236	f	large
36572	30193	1154	Воронежская область, Воронеж, Окружная, 3	f	large
36571	30193	1153	Воронежская область, Воронеж, Окружная, 3	f	large
36530	30163	1112	Воронежская область, Воронеж, Новосибирская, 67	f	large
36529	30163	1111	Воронежская область, Воронеж, Новосибирская, 67	f	large
36528	30162	1110	Воронежская область, Воронеж, Новосибирская, 31а	f	large
36729	30302	1406	Воронежская область, Воронеж, Никитинская, 1	f	large
36728	30301	1405	Воронежская область, Воронеж, Никитинская, 26	f	large
36727	30300	1404	Воронежская область, Воронеж, Никитинская, 32	f	large
36417	30083	954	Воронежская область, Воронеж, Никитина, 149	f	large
36365	30045	902	Воронежская область, Воронеж, Набережная, 15	f	large
36518	30154	1099	Воронежская область, Воронеж, Московский проспект, 129	f	large
36514	30150	1095	Воронежская область, Воронеж, Московский проспект, 179	f	large
37731	30148	4002	Воронежская область, Воронеж, Московский проспект, 131	f	large
36511	30148	1092	Воронежская область, Воронеж, Московский проспект, 131	f	large
36504	30144	1085	Воронежская область, Воронеж, Московский проспект, 121	f	large
36505	30144	1086	Воронежская область, Воронеж, Московский проспект, 121	f	large
36470	30123	1051	Воронежская область, Воронеж, Московский проспект, 74	f	large
36461	30116	1042	Воронежская область, Воронеж, Московский проспект, 38	f	large
36460	30116	1041	Воронежская область, Воронеж, Московский проспект, 38	f	large
36452	30110	1033	Воронежская область, Воронеж, Московский проспект, 14	f	large
36690	30278	1345	Воронежская область, Воронеж, Молодогвардейцев, 7	f	large
36721	30276	1376	Воронежская область, Воронеж, Молодогвардейцев, 17	f	large
80890	55395	43	Москва, Садовническая, 33с1	f	large
36691	30276	1346	Воронежская область, Воронеж, Молодогвардейцев, 17	f	large
36689	30276	1344	Воронежская область, Воронеж, Молодогвардейцев, 17	f	large
36687	30274	1342	Воронежская область, Воронеж, Молодогвардейцев, 18	f	large
36686	30274	1341	Воронежская область, Воронеж, Молодогвардейцев, 18	f	large
36685	30274	1340	Воронежская область, Воронеж, Молодогвардейцев, 18	f	large
36684	30274	1339	Воронежская область, Воронеж, Молодогвардейцев, 18	f	large
36757	30325	1434	Воронежская область, Воронеж, Мичурина, 1	f	large
36756	30325	1433	Воронежская область, Воронеж, Мичурина, 1	f	large
36181	29863	330	Воронежская область, Воронеж, Мира, 21	f	large
36419	30084	956	Воронежская область, Воронеж, Минская, 69а	f	large
36418	30084	955	Воронежская область, Воронеж, Минская, 69а	f	large
36378	30054	915	Воронежская область, Воронеж, Минская, 14	f	large
36371	30049	908	Воронежская область, Воронеж, Минская, 23	f	large
36370	30049	907	Воронежская область, Воронеж, Минская, 23	f	large
36369	30049	906	Воронежская область, Воронеж, Минская, 23	f	large
36367	30047	904	Воронежская область, Воронеж, Минская, 17/2	f	large
36520	30155	1102	Воронежская область, Воронеж, Менделеева, 38	f	large
36519	30155	1101	Воронежская область, Воронеж, Менделеева, 38	f	large
36654	30256	1309	Воронежская область, Воронеж, Машиностроителей, 88	f	large
36428	30092	1009	Воронежская область, Воронеж, Машиностроителей, 13/Б	f	large
36394	30065	931	Воронежская область, Воронеж, Маршала Одинцова, 17	f	large
36503	30143	1084	Воронежская область, Воронеж, Маршала Жукова, 6/А	f	large
36502	30143	1083	Воронежская область, Воронеж, Маршала Жукова, 6/А	f	large
36475	30127	1056	Воронежская область, Воронеж, Маршала Жукова, 2	f	large
36476	30127	1057	Воронежская область, Воронеж, Маршала Жукова, 2	f	large
36748	30319	1425	Воронежская область, Воронеж, Мало-Терновая, 9	f	large
36673	30267	1328	Воронежская область, Воронеж, Любы Шевцовой, 3	f	large
36765	30332	1442	Воронежская область, Воронеж, Ломоносова, 114а	f	large
36761	30328	1438	Воронежская область, Воронеж, Ломоносова, 114а	f	large
36760	30327	1437	Воронежская область, Воронеж, Ломоносова, 105	f	large
36414	30080	951	Воронежская область, Воронеж, Липецкая, 2	f	large
36413	30080	950	Воронежская область, Воронеж, Липецкая, 2	f	large
36454	30111	1035	Воронежская область, Воронеж, Лидии Рябцевой, 51	f	large
36453	30111	1034	Воронежская область, Воронеж, Лидии Рябцевой, 51	f	large
36762	30329	1439	Воронежская область, Воронеж, Лесной поселок, 1	f	small
37182	30734	2523	Воронежская область, Воронеж, Лесная, 2ж, контора маслоцеха	f	small
36567	30191	1149	Воронежская область, Воронеж, Ленинский проспект, 116/2	f	large
36566	30190	1148	Воронежская область, Воронеж, Ленинский проспект, 109	f	large
36565	30190	1147	Воронежская область, Воронеж, Ленинский проспект, 109	f	large
68075	30189	1150	Воронежская область, Воронеж, Ленинский проспект, 115а	f	large
36564	30189	1146	Воронежская область, Воронеж, Ленинский проспект, 115а	f	large
36563	30189	1145	Воронежская область, Воронеж, Ленинский проспект, 115а	f	large
36561	30187	1143	Воронежская область, Воронеж, Ленинский проспект, 102	f	large
36559	30185	1141	Воронежская область, Воронеж, Ленинский проспект, 91	f	large
36554	30181	1136	Воронежская область, Воронеж, Ленинский проспект, 47	f	large
36553	30181	1135	Воронежская область, Воронеж, Ленинский проспект, 47	f	large
36547	30177	1129	Воронежская область, Воронеж, Ленинский проспект, 14	f	large
36546	30176	1128	Воронежская область, Воронеж, Ленинский проспект, 9к4	f	large
36392	30063	929	Воронежская область, Воронеж, Ленинский проспект, 207	f	large
36390	30062	927	Воронежская область, Воронеж, Ленинский проспект, 197а	f	large
36389	30062	926	Воронежская область, Воронеж, Ленинский проспект, 197а	f	large
36391	30062	928	Воронежская область, Воронеж, Ленинский проспект, 197а	f	large
36375	30051	912	Воронежская область, Воронеж, Ленинский проспект, 119а	f	large
36560	30186	1142	Воронежская область, Воронеж, Ленинградская, 26а	f	large
36550	30179	1132	Воронежская область, Воронеж, Ленинградская, 33	f	large
36366	30046	903	Воронежская область, Воронеж, Ленинградская, 1	f	large
37056	30610	2129	Воронежская область, Воронеж, Ленина, 4	f	small
36750	30321	1427	Воронежская область, Воронеж, Ленина, 88	f	large
36749	30320	1426	Воронежская область, Воронеж, Ленина, 86	f	large
36540	30170	1122	Воронежская область, Воронеж, Лебедева, 2	f	large
36708	30288	1363	Воронежская область, Воронеж, Курчатова, 12	f	large
36542	30172	1124	Воронежская область, Воронеж, Кулибина, 4	f	large
36404	30072	941	Воронежская область, Воронеж, Куйбышева, 23А	f	large
36403	30071	940	Воронежская область, Воронеж, Куйбышева, 23	f	large
36402	30071	939	Воронежская область, Воронеж, Куйбышева, 23	f	large
36612	30220	1214	Воронежская область, Воронеж, Кривошеина, 13	f	large
36611	30220	1213	Воронежская область, Воронеж, Кривошеина, 13	f	large
36644	30248	1246	Воронежская область, Воронеж, Краснознаменная, 14	f	large
36645	30248	1247	Воронежская область, Воронеж, Краснознаменная, 14	f	large
36606	30217	1208	Воронежская область, Воронеж, Краснознаменная, 105	f	large
36600	30214	1202	Воронежская область, Воронеж, Краснознаменная, 74	f	large
36599	30214	1201	Воронежская область, Воронеж, Краснознаменная, 74	f	large
36676	30269	1331	Воронежская область, Воронеж, Краснозвездная, 2	f	large
36665	30262	1320	Воронежская область, Воронеж, Космонавтов, 46	f	large
36664	30262	1319	Воронежская область, Воронеж, Космонавтов, 46	f	large
36663	30261	1318	Воронежская область, Воронеж, Космонавтов, 36	f	large
36662	30261	1317	Воронежская область, Воронеж, Космонавтов, 36	f	large
36661	30260	1316	Воронежская область, Воронеж, Космонавтов, 34	f	large
36660	30260	1315	Воронежская область, Воронеж, Космонавтов, 34	f	large
36658	30259	1313	Воронежская область, Воронеж, Космонавтов, 23	f	large
36659	30259	1314	Воронежская область, Воронеж, Космонавтов, 23	f	large
36636	30241	1238	Воронежская область, Воронеж, Кольцовская, 56/2	f	large
36723	30252	1378	Воронежская область, Воронеж, Киселева, 2	f	large
36650	30252	1305	Воронежская область, Воронеж, Киселева, 2	f	large
36649	30252	1304	Воронежская область, Воронеж, Киселева, 2	f	large
36732	30305	1409	Воронежская область, Воронеж, Карла Маркса, 57	f	large
36726	30299	1403	Воронежская область, Воронеж, Карла Маркса, 116	f	large
36725	30298	1402	Воронежская область, Воронеж, Карла Маркса, 69	f	large
36724	30298	1401	Воронежская область, Воронеж, Карла Маркса, 69	f	large
36602	30215	1204	Воронежская область, Воронеж, Карла Либкнехта, 50	f	large
36601	30215	1203	Воронежская область, Воронеж, Карла Либкнехта, 50	f	large
36408	30075	945	Воронежская область, Воронеж, Калининградская, 110	f	large
36597	30196	1179	Воронежская область, Воронеж, Иркутская, 25	f	large
36575	30196	1157	Воронежская область, Воронеж, Иркутская, 25	f	large
36647	30250	1302	Воронежская область, Воронеж, Защитников Родины, 2	f	large
36718	30251	1373	Воронежская область, Воронеж, Заполярная, 1	f	large
36648	30251	1303	Воронежская область, Воронеж, Заполярная, 1	f	large
36427	30091	1008	Воронежская область, Воронеж, Загородная, 66	f	large
36426	30091	1007	Воронежская область, Воронеж, Загородная, 66	f	large
36412	30079	949	Воронежская область, Воронеж, Дубовая, 12	f	large
37317	30866	2828	Воронежская область, Воронеж, Дорожная, 2	t	small
36682	30272	1337	Воронежская область, Воронеж, Дорожная, 15а	f	medium
36638	30243	1240	Воронежская область, Воронеж, Донбасская, 15	f	large
36516	30152	1097	Воронежская область, Воронеж, Дмитрия Горина, 2Б	f	large
36515	30151	1096	Воронежская область, Воронеж, Дмитрия Горина, 61	f	large
68076	30194	1155	Воронежская область, Воронеж, Димитрова, 128	f	large
36364	30044	901	Воронежская область, Воронеж, Димитрова, 81	f	large
36620	30227	1222	Воронежская область, Воронеж, Державина, 65	f	large
36619	30227	1221	Воронежская область, Воронеж, Державина, 65	f	large
36393	30064	930	Воронежская область, Воронеж, Грибоедова, 5	f	large
36616	30224	1218	Воронежская область, Воронеж, Грамши, 73/А	f	large
36596	29795	1178	Воронежская область, Воронеж, Глинки, 19	f	large
36595	29795	1177	Воронежская область, Воронеж, Глинки, 19	f	large
36695	30281	1350	Воронежская область, Воронеж, Героев Сибиряков, 5	f	large
36694	30281	1349	Воронежская область, Воронеж, Героев Сибиряков, 5	f	large
36410	30077	947	Воронежская область, Воронеж, Героев России, 1	f	large
36415	30081	952	Воронежская область, Воронеж, Генерала Лохматикова, 43	f	large
36497	30140	1078	Воронежская область, Воронеж, Генерала Лизюкова, 42	f	large
36496	30139	1077	Воронежская область, Воронеж, Генерала Лизюкова, 52	f	large
36495	30139	1076	Воронежская область, Воронеж, Генерала Лизюкова, 52	f	large
36490	30136	1071	Воронежская область, Воронеж, Генерала Лизюкова, 87	f	large
36489	30136	1070	Воронежская область, Воронеж, Генерала Лизюкова, 87	f	large
36488	30136	1069	Воронежская область, Воронеж, Генерала Лизюкова, 87	f	large
36486	30134	1067	Воронежская область, Воронеж, Генерала Лизюкова, 81	f	large
36477	30128	1058	Воронежская область, Воронеж, Генерала Лизюкова, 24	f	large
36551	30180	1133	Воронежская область, Воронеж, Гвардейский переулок, 50	f	large
36429	30093	1010	Воронежская область, Воронеж, Газовая, 24	f	large
36705	30286	1360	Воронежская область, Воронеж, Ворошилова, 19	f	large
36704	30286	1359	Воронежская область, Воронеж, Ворошилова, 19	f	large
36703	30286	1358	Воронежская область, Воронеж, Ворошилова, 19	f	large
36741	30313	1418	Воронежская область, Воронеж, Володарского, 60	f	large
36522	30157	1104	Воронежская область, Воронеж, Волгодонская, 26	f	large
36574	30195	1156	Воронежская область, Воронеж, Волгоградская, 28	f	large
36513	30149	1094	Воронежская область, Воронеж, Владимира Невского, 75	f	large
36512	30149	1093	Воронежская область, Воронеж, Владимира Невского, 75	f	large
36510	30147	1091	Воронежская область, Воронеж, Владимира Невского, 65б	f	large
68073	30146	1088	Воронежская область, Воронеж, Владимира Невского, 42	f	large
36492	30137	1073	Воронежская область, Воронеж, Владимира Невского, 17а	f	large
36491	30137	1072	Воронежская область, Воронеж, Владимира Невского, 17а	f	large
36509	14623	1090	Воронежская область, Воронеж, Владимира Невского, 42	f	large
36508	14623	1089	Воронежская область, Воронеж, Владимира Невского, 42	f	large
36624	30231	1226	Воронежская область, Воронеж, Веры Фигнер, 77	f	large
68079	30219	1212	Воронежская область, Воронеж, Броневая, 12	f	large
36594	30211	1176	Воронежская область, Воронеж, Большая Советская, 35б	f	medium
36401	30070	938	Воронежская область, Воронеж, Богдана Хмельницкого, 34	f	large
36398	30068	935	Воронежская область, Воронеж, Богдана Хмельницкого, 35	f	large
36396	30066	933	Воронежская область, Воронеж, Богдана Хмельницкого, 58	f	large
36395	30066	932	Воронежская область, Воронеж, Богдана Хмельницкого, 58	f	large
36755	30324	1432	Воронежская область, Воронеж, Березовая Роща, 54	f	large
36754	30324	1431	Воронежская область, Воронеж, Березовая Роща, 54	f	large
36752	30323	1429	Воронежская область, Воронеж, Березовая Роща, 32	f	large
36753	30323	1430	Воронежская область, Воронеж, Березовая Роща, 32	f	large
36466	30120	1047	Воронежская область, Воронеж, Беговая, 2	f	large
36467	30117	1048	Воронежская область, Воронеж, Беговая, 2	f	large
36462	30117	1043	Воронежская область, Воронеж, Беговая, 2	f	large
36447	30106	1028	Воронежская область, Воронеж, Беговая, 96	f	large
36445	30104	1026	Воронежская область, Воронеж, Беговая, 120	f	large
36444	30104	1025	Воронежская область, Воронеж, Беговая, 120	f	large
36440	30101	1021	Воронежская область, Воронеж, Беговая, 146	f	large
36439	30100	1020	Воронежская область, Воронеж, Беговая, 146	f	large
36438	30099	1019	Воронежская область, Воронеж, Беговая, 176	f	large
36437	30099	1018	Воронежская область, Воронеж, Беговая, 176	f	large
36586	30204	1168	Воронежская область, Воронеж, Баррикадная, 9а	f	large
36583	30202	1165	Воронежская область, Воронеж, Баррикадная, 43а	f	large
36397	30067	934	Воронежская область, Воронеж, Артамонова, 38	f	large
36558	30183	1140	Воронежская область, Воронеж, Арзамасская, 4	f	large
36557	30183	1139	Воронежская область, Воронеж, Арзамасская, 4	f	large
36712	30292	1367	Воронежская область, Воронеж, Арбатская, 66	f	large
37380	30930	3108	Воронежская область, Воронеж, III Интернационала, 83	f	medium
37732	31278	4003	Воронежская область, Воронеж, 9 Января, 290	f	large
36722	30297	1377	Воронежская область, Воронеж, 9 Января, 221д	f	large
36653	30255	1308	Воронежская область, Воронеж, 9 Января, 103	f	large
36652	30254	1307	Воронежская область, Воронеж, 9 Января, 161	f	large
36651	30253	1306	Воронежская область, Воронеж, 9 Января, 205	f	large
36635	30240	1237	Воронежская область, Воронеж, 9 Января, 46	f	large
36633	30238	1235	Воронежская область, Воронеж, 9 Января, 36	f	large
36434	30096	1015	Воронежская область, Воронеж, 9 Января, 296	f	large
36433	30095	1014	Воронежская область, Воронеж, 9 Января, 270	f	large
36432	30095	1013	Воронежская область, Воронеж, 9 Января, 270	f	large
36431	30094	1012	Воронежская область, Воронеж, 9 Января, 220/А	f	large
36430	30094	1011	Воронежская область, Воронеж, 9 Января, 220/А	f	large
36425	30090	1006	Воронежская область, Воронеж, 9 Января, 134	f	large
36424	30090	1005	Воронежская область, Воронеж, 9 Января, 134	f	large
36422	30088	1003	Воронежская область, Воронеж, 9 Января, 108	f	large
68118	31277	4001	Воронежская область, Воронеж, 60-летия ВЛКСМ, 27	f	large
68071	30118	1044	Воронежская область, Воронеж, 45 Стрелковой Дивизии, 102	f	large
36464	30118	1045	Воронежская область, Воронеж, 45 Стрелковой Дивизии, 102	f	large
36436	30098	1017	Воронежская область, Воронеж, 45 Стрелковой Дивизии, 230а	f	large
36435	30097	1016	Воронежская область, Воронеж, 45 Стрелковой Дивизии, 275А	f	large
36932	30493	1913	Воронежская область, Воронеж, 40 лет Октября, 10а	f	large
36448	30107	1029	Воронежская область, Воронеж, 303 стрелковой дивизии, 2/А	f	large
36387	30060	924	Воронежская область, Воронеж, 25 Января, 40	f	large
36386	30060	923	Воронежская область, Воронеж, 25 Января, 40	f	large
36591	30207	1173	Воронежская область, Воронеж, 206 Стрелковой Дивизии, 308	f	large
68077	30207	1171	Воронежская область, Воронеж, 206 Стрелковой Дивизии, 308	f	large
36627	30233	1229	Воронежская область, Воронеж, 20 лет Октября, 84/А	f	large
36626	30233	1228	Воронежская область, Воронеж, 20 лет Октября, 84/А	f	large
68081	30232	1227	Воронежская область, Воронеж, 20 лет Октября, 38/в	f	large
36622	30229	1224	Воронежская область, Воронеж, 20 лет Октября, 93	f	large
36621	30228	1223	Воронежская область, Воронеж, 20 лет Октября, 95	f	large
36441	30102	1022	Воронежская область, Воронеж, Хользунова, 106	f	large
36442	30102	1023	Воронежская область, Воронеж, Хользунова, 106	f	large
36259	29937	512	Воронежская область, Бутурлиновка, Маяковского, 73	f	large
36256	29934	509	Воронежская область, Бутурлиновка, Ленина, 254	f	large
36255	29933	508	Воронежская область, Бутурлиновка, Ленина, 153	f	large
36254	29932	507	Воронежская область, Бутурлиновка, Ленина, 28	f	large
36249	29927	502	Воронежская область, Бутурлиновка, Ленина, 12	f	large
36260	29938	513	Воронежская область, Бутурлиновка, Заводская, 54	f	large
36261	29939	514	Воронежская область, Бутурлиновка, Дорожная, 14	f	large
36214	29894	417	Воронежская область, Борисоглебск, чкалова, 55	f	large
36231	29910	434	Воронежская область, Борисоглебск, рубежная, 24	f	large
36229	29908	432	Воронежская область, Борисоглебск, пос.Водострой, 10	f	medium
36201	29882	404	Воронежская область, Борисоглебск, переулок Сенной, 30	f	large
36200	29882	403	Воронежская область, Борисоглебск, переулок Сенной, 30	f	large
36226	29905	429	Воронежская область, Борисоглебск, переулок Куйбышева, 1	f	large
36222	29901	425	Воронежская область, Борисоглебск, переулок Гражданский, 9	f	large
36208	29888	411	Воронежская область, Борисоглебск, пер.Суровикина, 1/48	f	medium
36210	29890	413	Воронежская область, Борисоглебск, народная, 43	f	large
36198	29880	401	Воронежская область, Борисоглебск, бланская, 117	f	large
36228	29907	431	Воронежская область, Борисоглебск, Юго-восточный микрорайон, 19	f	medium
36227	29906	430	Воронежская область, Борисоглебск, Юго-восточный микрорайон	f	large
36218	29898	421	Воронежская область, Борисоглебск, Чкалова, 3	f	large
36215	29895	418	Воронежская область, Борисоглебск, Третьяковская, 14	f	large
36219	29899	422	Воронежская область, Борисоглебск, Советская, 123	f	medium
36221	29899	424	Воронежская область, Борисоглебск, Советская, 123	f	large
36213	29893	416	Воронежская область, Борисоглебск, Советская, 58	f	medium
36212	29892	415	Воронежская область, Борисоглебск, Советская, 47	f	large
36211	29891	414	Воронежская область, Борисоглебск, Советская, 13	f	large
36209	29889	412	Воронежская область, Борисоглебск, Советская, 15	f	large
36205	29886	408	Воронежская область, Борисоглебск, Северный микрорайон, 10	f	large
36206	29881	409	Воронежская область, Борисоглебск, Северный микрорайон, 30	f	large
36199	29881	402	Воронежская область, Борисоглебск, Северный микрорайон, 30	f	large
36204	29885	407	Воронежская область, Борисоглебск, Северный м/р-н, 41	f	large
36225	29904	428	Воронежская область, Борисоглебск, Проходная, 4а	f	large
36217	29897	420	Воронежская область, Борисоглебск, Первомайская, 65	f	medium
36223	29902	426	Воронежская область, Борисоглебск, Металлистов, 4	f	large
36203	29884	406	Воронежская область, Борисоглебск, Матросовская, 115а	f	large
36202	29883	405	Воронежская область, Борисоглебск, Матросовская, 117	f	small
36773	30340	1508	Воронежская область, Борисоглебск, Корнаковского, 9	f	small
36207	29887	410	Воронежская область, Борисоглебск, Дубровинская, 127	f	large
36216	29896	419	Воронежская область, Борисоглебск, Бланская, 54	f	medium
36220	29900	423	Воронежская область, Борисоглебск, Аэродромная, 15а	f	large
36232	29911	435	Воронежская область, Борисоглебск, 40 лет Октября, 309	f	large
68068	29903	427	Воронежская область, Борисоглебск, 40 лет Октября, 27а	f	large
36154	29836	303	Воронежская область, Богучар, Дзержинского, 174	f	medium
37087	30638	2312	Воронежская область, село Бобяково, Советская, 5	f	large
36114	29796	209	Воронежская область, Бобров, Революционная, 149	f	large
36113	29794	208	Воронежская область, Бобров, 60 лет Октября, 20	f	large
86348	31257	3925	Воронежская область, Эртильский район, поселок Ячейка, Ф.Усова, 1А	f	small
109487	31267	3935	Воронежская область, Эртильский район, Эртиль, степная, 1	f	medium
109486	31265	3933	Воронежская область, Эртильский район, Эртиль, площадь Ленина, 2	f	medium
86354	31275	3942	Воронежская область, Эртильский район, Эртиль, Пионерская, 117	f	small
109484	31261	3929	Воронежская область, Эртильский район, Эртиль, Первомайская, 19	f	medium
109483	31260	3928	Воронежская область, Эртильский район, Эртиль, Первомайская, 19	f	medium
86351	31268	3936	Воронежская область, Эртильский район, Эртиль, Лесная, 1б	f	small
109489	31274	3940	Воронежская область, Эртильский район, Эртиль, Комарова, 19	f	medium
109485	31262	3930	Воронежская область, Эртильский район, Эртиль, 9 Мая, 48	f	medium
68114	31248	3917	Воронежская область, Эртильский район, поселок Щучье, Ленина, 38	f	large
109480	31246	3915	Воронежская область, Эртильский район, поселок Щученские Пески, Советская, 68А	f	medium
37403	30952	3130	Приморский край, Партизанский район, село Сергеевка	f	medium
86311	31235	3904	Воронежская область, Эртильский район, поселок Ростоши, Ленинская, 126	f	small
37691	31234	3903	Воронежская область, Эртильский район, поселок Ростоши, Ленинская, 5	f	large
86334	31238	3906	Воронежская область, Эртильский район, поселок Первоэртиль, Центральная, 35	f	small
86352	31269	3937	Воронежская область, Эртильский район, поселок Мичуринский, Докучаева, 12	f	small
86349	31258	3926	Воронежская область, Эртильский район, поселок Марьевка, Советская, 21	f	small
86353	31272	3939	Воронежская область, Эртильский район, поселок МТФ	f	small
109488	31270	3938	Воронежская область, Эртильский район, поселок Красноармейский, Гагарина, 10	f	medium
37690	31233	3902	Воронежская область, Эртильский район, поселок Копыл, Ленина, 31	f	small
36276	29954	529	Воронежская область, Эртильский район, поселок Колодеевка, Советская, 118	f	small
86337	31240	3909	Воронежская область, Эртильский район, поселок Дмитриевка, Фрунзе, 56	f	small
86336	31239	3908	Воронежская область, Эртильский район, поселок Дзержинский, Школьная	f	small
86347	31255	3924	Воронежская область, Эртильский район, поселок Грязцы, Рабочая, 9	f	small
86346	31253	3922	Воронежская область, Эртильский район, поселок Вязковка, Советская, 48	f	small
37595	31140	3614	Воронежская область, Эртильский район, поселок Вознесеновка, Центральная, 44	f	small
36987	30542	2043	Воронежская область, Эртильский район, поселок Владимировка, Молодежная-1, 19, Владимирский сельский клуб	f	small
86335	31237	3907	Воронежская область, Эртильский район, поселок Введенка, Восточная, 34 А	f	small
86333	31236	3905	Воронежская область, Эртильский район, поселок Буравцовка, Молодежная, 14	f	small
109481	31247	3916	Воронежская область, Эртильский район, поселок Борщевские Пески, Центральная, 74	f	medium
109482	31254	3923	Воронежская область, Эртильский район, поселок Большой Самовец, Школьная, 15	f	medium
86350	31259	3927	Воронежская область, Эртильский район, поселок Большая Добринка, Центральная, 42	f	small
86344	31252	3920	Воронежская область, Эртильский район, поселок Битюг-Матреновка, Центральная, 8	f	small
37689	31232	3901	Воронежская область, Эртильский район, поселок Александровка, Центральная, 31	f	small
36309	29988	701	Воронежская область, Эртильский район, поселок Александровка, Ленина, 40а	f	small
37683	31226	3829	Воронежская область, Хохольский район, поселок Яблочное, пер. Школьный, 5	f	medium
37657	31202	3803	Воронежская область, Хохольский район, поселок Хохольский, мира, 26	f	medium
37655	31200	3801	Воронежская область, Хохольский район, поселок Хохольский, Ленина, 6	f	large
37656	31201	3802	Воронежская область, Хохольский район, поселок Хохольский, Заводская, 88	f	large
37659	31203	3805	Воронежская область, Хохольский район, поселок Хохольский, Дружбы, 30	f	small
37658	31203	3804	Воронежская область, Хохольский район, поселок Хохольский, Дружбы, 30	f	large
37663	31207	3809	Воронежская область, Хохольский район, поселок Хохол	f	medium
68106	31204	3806	Воронежская область, Хохольский район, поселок Хохол, пер.Советский, 3	f	large
37664	31208	3810	Воронежская область, Хохольский район, поселок Хохол, Сосновый переулок, 3	f	medium
37661	31205	3807	Воронежская область, Хохольский район, поселок Хохол, Красноармейская, 37	f	small
37662	31206	3808	Воронежская область, Хохольский район, поселок Хохол, Верхняя Слобода, 4	f	large
37670	31214	3816	Воронежская область, Хохольский район, поселок Староникольское, Веры Чуркиной, 3	f	small
37669	31213	3815	Воронежская область, Хохольский район, поселок Староникольское, Веры Чуркиной, 63	f	small
37668	31212	3814	Воронежская область, Хохольский район, поселок Староникольское, Веры Чуркиной, 115а	f	medium
37673	31216	3819	Воронежская область, Хохольский район, поселок Семидесятное, Бабенко, 18	f	small
37672	31216	3818	Воронежская область, Хохольский район, поселок Семидесятное, Бабенко, 18	f	small
37681	31224	3827	Воронежская область, Хохольский район, поселок Рудкино, Школьная, 1А	f	medium
109478	31218	3821	Воронежская область, Хохольский район, село Петино, Советская, 1А	f	medium
37684	31227	3830	Воронежская область, Хохольский район, поселок Оськино, Советская, 79	f	medium
37688	31231	3834	Воронежская область, Хохольский район, поселок Опытная станция ВНИИК, Чаянова, 13	f	medium
37667	31211	3813	Воронежская область, Хохольский район, поселок Никольское-на-Еманче, Центральная, 170а	f	small
37671	31215	3817	Воронежская область, Хохольский район, поселок Кочетовка, Центральная, 100	t	small
37682	31225	3828	Воронежская область, Хохольский район, поселок Костенки, Набережная, 136	f	large
37666	31210	3812	Воронежская область, Хохольский район, поселок Еманча 1-я, Центральная, 18	f	small
37680	31223	3826	Воронежская область, Хохольский район, поселок Дмитриевка, Советская, 25	t	small
37679	31222	3825	Воронежская область, Хохольский район, поселок Гремячье, Чехова, 9а	f	large
37678	31221	3824	Воронежская область, Хохольский район, поселок Гремячье, Ленина, 59	f	medium
86318	31209	3811	Воронежская область, Хохольский район, поселок Верхненикольское, Свердлова, 41б	t	small
37685	31228	3831	Воронежская область, Хохольский район, поселок Борщево, Архипова, 35	t	small
37299	30848	2810	Воронежская область, Хохольский район, поселок Борщево, Гагарина, 11	f	small
86306	31126	3553	Воронежская область, Хохольский район, поселок Бахчеево, переулок Школьный, 3	f	small
37686	31229	3832	Воронежская область, Хохольский район, поселок Архангельское, Центральная, 2	f	small
37630	31175	3707	Воронежская область, Терновский район, поселок Чубровка	f	small
37649	31194	3726	Воронежская область, Терновский район, поселок Терновка, Советская, 51	f	large
68104	31195	3727	Воронежская область, Терновский район, поселок Терновка, Первомайская, 110	f	large
68105	31199	3731	Воронежская область, Терновский район, поселок Терновка, Октябрьская, 22	f	large
109476	31196	3728	Воронежская область, Терновский район, поселок Терновка, Звездная, 15	f	medium
37648	31193	3725	Воронежская область, Терновский район, поселок Тамбовка, Школьная, 3	f	small
37645	31190	3722	Воронежская область, Терновский район, поселок Русаново, Советская, 7	f	medium
86314	31191	3723	Воронежская область, Терновский район, поселок Русаново, Проезжая, 110	f	small
86313	31187	3719	Воронежская область, Терновский район, поселок Ржавец, Проезжая, 7, здание медицинского пункта	f	small
86315	31192	3724	Воронежская область, Терновский район, поселок Поляна, Школьная, 8	f	small
37643	31188	3720	Воронежская область, Терновский район, поселок Новотроицкое, Паринского, 55	f	medium
86312	31186	3718	Воронежская область, Терновский район, поселок Новокирсановка, Центральная, 65	f	small
82615	56520	1789	Москва, Садовники, 13	f	large
37640	31185	3717	Воронежская область, Терновский район, поселок Николаевка, Октябрьская, 164	f	small
37626	31171	3703	Воронежская область, Терновский район, поселок Никитская, Центральная, 1б	f	small
109475	31183	3715	Воронежская область, Терновский район, поселок Народное, Центральная, 42	f	medium
86310	31178	3710	Воронежская область, Терновский район, поселок Луначаровка, 4 а	f	small
37639	31184	3716	Воронежская область, Терновский район, поселок Липяги, Набережная, 43	f	medium
37636	31181	3713	Воронежская область, Терновский район, поселок Костино-Отделец, Лениская, 11	f	large
37634	31179	3711	Воронежская область, Терновский район, поселок Козловка, Советская, 71	f	large
109474	31180	3712	Воронежская область, Терновский район, поселок Козловка, Горького, 62	f	medium
86309	31177	3709	Воронежская область, Терновский район, поселок Кисельное, Советская, 172, здание школы	f	small
68103	31174	3706	Воронежская область, Терновский район, поселок Есипово, Молодежная, 11	f	large
36088	29769	139	Воронежская область, Терновский район, поселок Дубровка, Солнечная, 26а	f	small
109473	31176	3708	Воронежская область, Терновский район, поселок Дубровка, Лесная, 7, здание школы	f	medium
86317	31198	3730	Воронежская область, Терновский район, поселок Долина, Садовая	f	small
109472	31173	3705	Воронежская область, Терновский район, поселок Братки, Ленинская, 3 а	f	medium
86316	31197	3729	Воронежская область, Терновский район, поселок Бабино, Комарова	f	small
37627	31172	3704	Воронежская область, Терновский район, поселок Алешки, Фруктовая, 14	f	small
37625	31170	3702	Воронежская область, Терновский район, поселок Алешки, Советская, 1	f	medium
37624	31169	3701	Воронежская область, Терновский район, поселок Александровка, Свободы, 1	f	medium
86308	31155	3629	Воронежская область, Таловский район, поселок Участок N4, Центральная , 26	f	small
37611	31156	3630	Воронежская область, Таловский район, поселок Участок N26, Проезжая, 3	f	medium
37591	31136	3610	Воронежская область, Таловский район, поселок Участок N2 сельскохозяйственного НИИ имени Докучаева, 4 квартал, 78	f	large
37609	31154	3628	Воронежская область, Таловский район, поселок Участок N12, Мира, 2а	f	small
86307	31153	3627	Воронежская область, Таловский район, поселок Утиновка, Свободы, 57	f	small
37606	31151	3625	Воронежская область, Таловский район, поселок Терехово, Центральная, 33	f	medium
37616	31161	3635	Тюменская область, Аромашевский район, село Таловая	f	large
37585	31130	3604	Воронежская область, Таловский район, поселок Таловая, проезд Свободы, 23	f	large
37622	31167	3641	Воронежская область, Таловский район, поселок Таловая, Советская, 6	f	large
37586	31131	3605	Воронежская область, Таловский район, поселок Таловая, Советская, 182	f	large
37584	31129	3603	Воронежская область, Таловский район, поселок Таловая, Советская, 134	f	large
37582	31127	3601	Воронежская область, Таловский район, поселок Таловая, Советская, 147	f	large
37583	31128	3602	Воронежская область, Таловский район, поселок Таловая, Садовая, 39	f	large
37623	31168	3642	Воронежская область, Таловский район, поселок Таловая, Пролетарская, 180	f	large
37618	31163	3637	Воронежская область, Таловский район, поселок Синявка, Советская, 6	f	medium
109477	31217	3820	Воронежская область, Центральная, 16, Здание МОУ Орловская СОШ	f	medium
37592	31137	3611	Воронежская область, Таловский район, поселок Орловка, Центральная, 133	f	small
37593	31138	3612	Воронежская область, Таловский район, поселок Орловка, Заречная, 114	f	small
37603	31148	3622	Воронежская область, Таловский район, поселок Новотроицкий, Центральная, 1а	f	medium
37587	31132	3606	Воронежская область, Таловский район, поселок Новенький, Солнечная, 25	f	small
37597	31142	3616	Воронежская область, Таловский район, поселок Новая Чигла, ленинская, 66	f	large
109469	31141	3615	Воронежская область, Таловский район, поселок Новая Чигла, Садовая, 20	f	medium
37594	31139	3613	Воронежская область, Таловский район, поселок Никольское, просп.Революции, 92а	f	medium
37607	31152	3626	Воронежская область, Таловский район, поселок Нижняя Каменка, Центральная, 62	f	medium
37604	31149	3623	Воронежская область, Таловский район, поселок Михинский, Центральная, 88	f	small
37316	30865	2827	Воронежская область, Таловский район, поселок Михайловский, пер.Цветочный, 5	f	medium
37588	31133	3607	Воронежская область, Таловский район, поселок Коминтерн, Молодежная, 4	f	small
37621	31166	3640	Воронежская область, Таловский район, поселок Козловский, Набережная, 11	f	medium
37612	31157	3631	Воронежская область, Таловский район, поселок Казанка, Центральная, 37	f	medium
37615	31160	3634	Воронежская область, Таловский район, поселок Еланка, Мира, 17	f	medium
37619	31164	3638	Воронежская область, Таловский район, поселок Вязовка, Центральная, 119	f	small
37590	31135	3609	Воронежская область, Таловский район, поселок Высокий, Гагарина, 23а	f	large
37589	31134	3608	Воронежская область, Таловский район, поселок Вознесенский, Дужнова, 36	f	medium
109470	31143	3617	Воронежская область, Таловский район, поселок Верхняя Тишанка, Школьная, 34	f	medium
109471	31144	3618	Воронежская область, Таловский район, поселок Верхняя Тишанка, Чеснокова, 82	f	medium
37600	31145	3619	Воронежская область, Таловский район, поселок Верхняя Тишанка, Гагарина, 2а	f	medium
37605	31150	3624	Воронежская область, Таловский район, поселок Верхнеозерский, Мичурина, 3	f	small
37601	31146	3620	Воронежская область, Таловский район, поселок Бирюч, Колхозная, 78	f	small
36066	29746	117	Воронежская область, Таловский район, поселок Березовка, Комсомольская, 7	f	small
37620	31165	3639	Воронежская область, Таловский район, поселок Анохинка, Центральная, 31	f	small
37602	31147	3621	Воронежская область, Таловский район, поселок Александровка, Пятницкого, 41	f	large
37614	31159	3633	Воронежская область, Таловский район, поселок Абрамовка, Ломоносова, 112а	f	large
37617	31162	3636	Воронежская область, Таловский район, поселок Абрамовка, Ленина, 83а	f	small
37613	31158	3632	Воронежская область, Таловский район, поселок Абрамовка, Ленина, 14а	f	large
37676	31219	3822	Воронежская область, Семилукский район, поселок Устье, Ленина, 19	f	medium
37393	30942	3120	Белгородская область, Шебекинский район, поселок Терновое	f	small
86303	31100	3526	Воронежская область, Семилукский район, поселок Стрелица, Победы, 18, МУК Стрелицкий городской Дом культуры	f	small
37571	31118	3544	Воронежская область, Семилукский район, поселок Стрелица, Центральная, 1	f	large
37574	31121	3547	Воронежская область, Семилукский район, поселок Старая Ольшанка, Ольшанская, 4	f	small
37573	31120	3546	Воронежская область, Семилукский район, поселок Старая Ведуга, Победы, 132	f	small
37572	31119	3545	Воронежская область, Семилукский район, поселок Старая Ведуга, Ленина, 13	f	medium
37570	31117	3543	Воронежская область, Семилукский район, поселок Стадница, Новая, 1	f	small
37549	31097	3522	Воронежская область, Семилукский район, поселок Серебрянка, Школьная, 27	f	small
37542	31090	3515	Воронежская область, Семилукский район, поселок Раздолье, Школьная, 9	f	small
37565	31112	3538	Воронежская область, Семилукский район, поселок Перлевка, Центральная, 54	f	small
37566	31113	3539	Воронежская область, Семилукский район, поселок Перлевка, Транспортная, 11	f	medium
86304	31105	3531	Воронежская область, Семилукский район, поселок Перекоповка, Мира, 40Е	t	small
37546	31094	3519	Воронежская область, Семилукский район, поселок Орлов Лог, переулок Школьный, 1	f	medium
109468	31111	3537	Воронежская область, Семилукский район, поселок Новосильское, Струковская, 6	f	medium
36324	30003	716	Воронежская область, Семилукский район, поселок Никольское, Станиславского, 18	f	small
37563	31110	3536	Воронежская область, Семилукский район, поселок Нижняя Ведуга, Ленина, 68	f	medium
37562	31109	3535	Воронежская область, Семилукский район, поселок Нижняя Ведуга, Ленина, 18	f	medium
37561	31108	3534	Воронежская область, Семилукский район, поселок Меловатка, Центральная, 29	f	small
37560	31107	3533	Воронежская область, Семилукский район, поселок Медвежье, Центральная, 64	f	small
37557	31104	3530	Воронежская область, Семилукский район, поселок Малая Покровка, Набережная, 58Е	f	small
37274	30825	2734	Нижегородская область, Городецкий район, село Лосево	f	medium
37555	31102	3528	Воронежская область, Семилукский район, поселок Лосево, Школьная, 6	f	small
37276	30827	2736	Воронежская область, Семилукский район, поселок Лосево, Кахиповка, 29	f	small
37552	31099	3525	Воронежская область, Семилукский район, поселок Латное, Октябрьская, 53/1	f	large
82612	56520	1785	Москва, Садовники, 13	f	large
37579	31125	3552	Воронежская область, Семилукский район, поселок Латная, переулок заводской, 1а	f	large
37578	31124	3551	Воронежская область, Семилукский район, поселок Латная, Школьная, 18	f	large
37577	31123	3550	Воронежская область, Семилукский район, поселок Латная, Школьная, 16	f	large
37569	31116	3542	Воронежская область, Семилукский район, поселок Кондрашевка, Садовая, 17	f	small
37551	31098	3524	Воронежская область, Семилукский район, поселок Казинка, Молодежная, 23	f	small
86338	31242	3911	Воронежская область, Семилукский район, поселок Ивановка, Центральная, 26	f	small
37548	31096	3521	Воронежская область, Семилукский район, поселок Землянск	f	large
37547	31095	3520	Воронежская область, Семилукский район, поселок Землянск, Садовая, 11	f	large
37568	31115	3541	Воронежская область, Семилукский район, поселок Ендовище, Калинина, 16а	f	large
36788	30355	1523	Воронежская область, Семилукский район, поселок Дмитриевка, Центральная, 20	f	small
37544	31092	3517	Липецкая область, Усманский район, поселок Девица	f	large
68101	31093	3518	Воронежская область, Семилукский район, поселок Девица, Танкистов, 108	f	large
37541	30998	3514	Воронежская область, Семилукский район, поселок Губарево, Вислевского, 47	f	medium
37554	31101	3527	Воронежская область, Семилукский район, поселок Гремячий Колодезь, Школьная, 1а	f	medium
37540	31088	3513	Воронежская область, Семилукский район, поселок Голосновка, Молодежная, 1	f	small
37539	31087	3512	Воронежская область, Семилукский район, поселок Гнилуша, Центральная, 7	f	small
86345	31251	3921	Воронежская область, Семилукский район, поселок Гнилуша, Луговая, 18	f	small
37576	14670	3549	Воронежская область, Семилукский район, поселок Березовка, Ольшанка, 79	t	small
37516	31064	3460	Воронежская область, Россошанский район, п. Опытной Плодово-ягодной станции, 14	f	small
37525	31073	3469	Воронежская область, Россошанский район, поселок Шрамовка, Советская, 1	f	small
37524	31072	3468	Воронежская область, Россошанский район, поселок Шекаловка, Центральная, 21	t	medium
37500	31047	3444	Воронежская область, Россошанский район, поселок Чернышовка, Зеленая, 141	f	small
37501	31048	3445	Воронежская область, Россошанский район, поселок Чагары, Мира, 8В	f	small
37510	31058	3454	Воронежская область, Россошанский район, поселок Цапково, Центральная, 11	t	small
37486	31034	3430	Воронежская область, Россошанский район, поселок Украинский, Садовая, 1	f	small
37522	31070	3466	Воронежская область, Россошанский район, поселок Терновка, Школьная, 9	f	small
37509	31057	3453	Воронежская область, Россошанский район, поселок Стеценково, Мира, 10	t	small
37521	31069	3465	Воронежская область, Россошанский район, поселок Старая Калитва, Школьная, 32	f	medium
37520	31068	3464	Воронежская область, Россошанский район, поселок Старая Калитва, Центральная, 1	f	medium
37490	31038	3434	Воронежская область, Россошанский район, поселок Совхоз Россошанский, Молодежная, 18	f	small
37400	30949	3127	Воронежская область, Подгоренский район, поселок Сагуны	f	medium
37518	31066	3462	Воронежская область, Россошанский район, поселок Поповка, Ленина, 53А	f	large
37493	31041	3437	Воронежская область, Россошанский район, поселок Поддубное, Молодежная, 8	f	small
37517	31065	3461	Воронежская область, Россошанский район, поселок Подгорное, Луначарского, 2А	f	large
37379	30929	3107	Воронежская область, Россошанский район, поселок Подгорное, Ленина, 128	f	large
37378	30928	3106	Воронежская область, Россошанский район, поселок Подгорное, Вокзальная, 188	f	large
37498	31045	3442	Воронежская область, Россошанский район, поселок Первомайское, Центральная, 39	t	small
37514	31062	3458	Воронежская область, Россошанский район, поселок Новопостояловка, Ленинская, 31	f	small
37506	31053	3450	Воронежская область, Россошанский район, поселок Новая Калитва, переулок Советский, 2	f	large
37487	31035	3431	Воронежская область, Россошанский район, поселок Нижний Карабут, Центральная, 26	f	small
68100	31059	3455	Воронежская область, Россошанский район, поселок Начало, Рябцева, 1	f	large
37503	31050	3447	Воронежская область, Россошанский район, поселок Морозовка, Дзержинского, 2	f	large
37515	31063	3459	Воронежская область, Россошанский район, поселок Молодежный, Юбилейная, 2	f	small
37523	31071	3467	Воронежская область, Россошанский район, поселок Лощина, Школьная, 14	f	small
37499	31046	3443	Воронежская область, Россошанский район, поселок Лизиновка, Ленина, 163	f	medium
37505	31052	3449	Воронежская область, Россошанский район, поселок Лебедь-Сергеевка, Лебедь-Сергеевка, 3	f	small
37497	31044	3441	Воронежская область, Россошанский район, поселок Криничное, Центральная, 39	f	medium
37496	31043	3440	Воронежская область, Россошанский район, поселок Кривоносово, Мира, 36	f	medium
37494	31042	3438	Воронежская область, Россошанский район, поселок Копенкина, Веселова, 3	f	small
37513	31061	3457	Воронежская область, Россошанский район, поселок Копанки, Озерная, 3	f	small
37519	31067	3463	Воронежская область, Россошанский район, поселок Комаровка, Центральная, 65	f	small
37512	31060	3456	Воронежская область, Россошанский район, поселок Кокаревка, Гагарина, 43	f	small
37508	31056	3452	Воронежская область, Россошанский район, поселок Ивановка, площадь Имени 172-ой Стрелковой дивизии, 1	t	small
37492	31040	3436	Воронежская область, Россошанский район, поселок Жилино, центральная, 11	f	medium
37526	31074	3470	Воронежская область, Россошанский район, поселок Еленовка, Центральная, 21	t	small
37502	31049	3446	Воронежская область, Россошанский район, поселок Екатериновка, Победы, 77	t	small
37491	31039	3435	Воронежская область, Россошанский район, поселок Евстратовка, Пролетарская, 1	f	large
86302	31054	3451	Воронежская область, Россошанский район, поселок Голубая Криница, Мира, 6а	f	small
37495	31027	3439	Воронежская область, Россошанский район, поселок Ворошиловский, Верхняя, 4	f	small
37489	31037	3433	Воронежская область, Россошанский район, поселок Архиповка, октябрьская, 42б	f	large
37504	31051	3448	Воронежская область, Россошанский район, поселок Анцеловича, Кутузова, 2	f	medium
37488	31036	3432	Воронежская область, Россошанский район, поселок Александровка, Ленина, 48	f	medium
37485	31033	3429	Воронежская область, Россошанский район, поселок Алейниково, Кирова, 48	f	small
86301	31002	3313	Воронежская область, Репьевский район, поселок Фабрицкое, Трушова, 3	f	small
86300	31001	3312	Воронежская область, Репьевский район, поселок Усть-Муравлянка, Первомайская, 53	f	small
86299	31000	3311	Воронежская область, Репьевский район, поселок Россошки, Школьная, 1	f	small
86298	30991	3303	Воронежская область, Репьевский район, поселок Репьевка, Спортивная, 11	f	small
37439	30990	3302	Воронежская область, Репьевский район, поселок Репьевка, Октябрьская, 49	f	large
37438	30989	3301	Воронежская область, Репьевский район, поселок Репьевка, Воронежская, 24	f	large
109467	31004	3315	Воронежская область, Репьевский район, поселок Платава, Советская, 56Г	f	medium
37443	30994	3306	Воронежская область, Репьевский район, поселок Одинцовка, Школьная, 3	f	small
109465	30999	3310	Воронежская область, Репьевский район, поселок Новосолдатка, Воронежская, 2	f	medium
68095	30997	3309	Воронежская область, Репьевский район, поселок Краснолипье, площадь ленина, 2	f	large
109466	31003	3314	Воронежская область, Репьевский район, поселок Колбино, Советская, 17	f	medium
109464	30996	3308	Воронежская область, Репьевский район, поселок Истобное, Терешковой, 34	f	medium
86281	31182	3714	Воронежская область, Репьевский район, поселок Заречье, 58а 	f	small
109463	30992	3304	Воронежская область, Репьевский район, поселок Бутырки, Школьный переулок, 2	f	medium
37436	30986	3228	Воронежская область, Рамонский район, село Ямное, Советская площадь, 2а	f	large
37435	30985	3227	Воронежская область, Рамонский район, поселок Чистая Поляна, Школьная, 6	f	small
68094	30965	3208	Воронежская область, Рамонский район, село Чертовицы, Школьная, 79	f	large
37434	30984	3226	Воронежская область, Рамонский район, поселок Ступино, Зубарева, 10	f	medium
37433	30983	3225	Воронежская область, Рамонский район, поселок Сомово, Мира, 30	f	small
86274	29853	319	Воронежская область, Рамонский район, поселок Солнце Дубрава, Центральная, 4	f	small
109462	30982	3224	Воронежская область, Рамонский район, поселок Скляево, Центральная, 1	f	medium
37431	30981	3223	Воронежская область, Рамонский район, поселок Русская Гвоздевка, Ленина, 45	f	medium
37410	30959	3202	Воронежская область, Рамонский район, поселок Рамонь	f	large
86297	30988	3230	Воронежская область, Рамонский район, поселок Рамонь, Школьная, 1	f	small
37411	30960	3203	Воронежская область, Рамонский район, поселок Рамонь, Советская, 40	f	large
37409	30958	3201	Воронежская область, Рамонский район, поселок Рамонь, Мосина, 9	f	large
86291	30961	3204	Воронежская область, Рамонский район, поселок Рамонь, Лесная, 1а	f	small
37428	30979	3220	Воронежская область, Рамонский район, поселок Новоживотинное, Дом культуры	f	large
37556	31103	3529	Воронежская область, Рамонский район, поселок Малая Верейка, Колхозная, 1	f	small
86292	30967	3210	Воронежская область, Рамонский район, поселок Лопатки, Садовая, 20	t	small
37427	30978	3219	Воронежская область, Рамонский район, поселок Ломово, Центральная, 1	f	small
37404	30953	3131	Ростовская область, Азовский район, село Кулешовка	f	small
37422	30972	3214	Воронежская область, Рамонский район, поселок Кривоборье, Песчаная, 14а	f	small
37425	30976	3217	Воронежская область, Рамонский район, поселок Комсомольский, Центральная, 1а	f	medium
86295	30977	3218	Воронежская область, Рамонский район, поселок Князево, Школьная, 54	f	small
86293	30973	3215	Воронежская область, Рамонский район, поселок Карачун, Солнечная, 74	f	small
37559	31106	3532	Воронежская область, Рамонский район, поселок Каверье, Транспортная, 29а	t	small
37429	30918	3221	Воронежская область, Рамонский район, поселок Гремячье, Центральная, 19	f	small
37421	30971	3213	Воронежская область, Рамонский район, поселок Горожанка, Центральная, 12	f	small
86294	30975	3216	Воронежская область, Рамонский район, поселок Глушицы, Центральная, 10	t	small
37415	30964	3207	Воронежская область, Рамонский район, Вниисс	f	large
37413	30962	3205	Воронежская область, Рамонский район, поселок Бор, Пристанционная, 26	f	medium
37419	30969	3211	Воронежская область, Рамонский район, поселок Большая Верейка, Советская, 3	f	medium
37420	30970	3212	Воронежская область, Рамонский район, поселок Богданово, Почтовая, 15	f	medium
37417	30966	3209	Воронежская область, Рамонский район, поселок Березово, Ленина, 95	f	large
37385	30935	3113	Воронежская область, Рамонский район, поселок Березово, Центральная, 61	f	small
36062	29742	113	Воронежская область, Рамонский район, поселок Архангельское, Мира, 37	f	medium
37414	30963	3206	Воронежская область, Рамонский район, поселок Айдарово, Центральная, 85	f	large
37437	30987	3229	Воронежская область, Раменский район, Солнечный, ТРК Град	f	medium
37407	30956	3134	Красноярский край, Ирбейский район, поселок Юдино	f	small
37543	31091	3516	Воронежская область, Подгоренский район, поселок Терновое, Терновская, 2	f	small
37397	94925	3124	Воронежская область, Подгоренский район, поселок Суд-Николаевка, Зеленая, 1-а	f	medium
37398	95197	3125	Воронежская область, Подгоренский район, поселок Совхоз Пробуждение, Центральная, 11-а	f	small
37392	30941	3119	Воронежская область, Подгоренский район, поселок Совхоз Опыт	f	medium
37326	30875	2837	Воронежская область, Подгоренский район, поселок Сергеевка, Советская, 30	f	small
37402	30951	3129	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Семейка	f	small
37390	30939	3117	Воронежская область, Подгоренский район, поселок Саприно, Школьная, 30	f	small
68093	30924	3102	Воронежская область, Подгоренский район, поселок Подгоренский, калинина, 18	f	large
37375	30925	3103	Воронежская область, Подгоренский район, поселок Подгоренский, Цемзавода, 14	f	large
37381	30931	3109	Воронежская область, Подгоренский район, поселок Подгоренский, Северная, 1	f	small
37373	30923	3101	Воронежская область, Подгоренский район, поселок Подгоренский, Первомайская, 205	f	large
37376	30926	3104	Воронежская область, Подгоренский район, поселок Подгоренский, Ленина, 19в	f	medium
37399	30948	3126	Воронежская область, Подгоренский район, поселок Перевальная, Школьная, 13	t	small
37395	30944	3122	Воронежская область, Подгоренский район, поселок Лыково, Центральная, 3	f	small
37388	30937	3115	Воронежская область, Подгоренский район, поселок Красюковский, Центральная, 75г	f	small
37387	30936	3114	Воронежская область, Подгоренский район, поселок Красный Восход, Челябинская, 29	f	medium
37408	30957	3135	Воронежская область, Подгоренский район, поселок Костомарово, Донская, 107	t	small
82616	56514	1790	Москва, Садовники, 12	f	large
37394	30943	3121	Воронежская область, Подгоренский район, поселок Колодежное	f	small
37391	30940	3118	Воронежская область, Подгоренский район, поселок Гончаровка	f	medium
37389	30938	3116	Воронежская область, Подгоренский район, поселок Витебск, Центральная, 4	t	small
37384	30934	3112	Воронежская область, Подгоренский район, поселок Верхний Карабут	t	small
37405	30954	3132	Воронежская область, Подгоренский район, поселок Большой Скорорыб	f	small
37401	30950	3128	Воронежская область, Подгоренский район, поселок Большая Хвощеватка	f	small
37279	30830	2739	Воронежская область, Подгоренский район, поселок Березово, Богучарская, 23	f	small
37383	30933	3111	Воронежская область, Подгоренский район, поселок Белогорье	f	medium
37382	30932	3110	Воронежская область, Подгоренский район, поселок Белогорье	f	medium
37396	30945	3123	Самарская область, Кошкинский район, село Андреевка	f	small
37037	30591	2110	Воронежская область, Подгоренский район, поселок Андреевка, пл.им.Н Зацепина, 1	f	small
37361	30911	3010	Воронежская область, Поворинский район, поселок Самодуровка, Молодежная, 2	f	medium
37360	30910	3009	Воронежская область, Поворинский район, поселок Рождественское, 18 Партсъезда, 48	f	large
37352	30903	3001	Воронежская область, Поворинский район, Поворино, Центральная, 2	f	small
37353	30904	3002	Воронежская область, Поворинский район, Поворино, Советская, 1А	f	large
37362	30912	3011	Воронежская область, Поворинский район, поселок Пески, площадь Свободы, 18	f	large
37363	30913	3012	Воронежская область, Поворинский район, поселок Пески, площадь Революции, 3А	f	large
37364	30914	3013	Воронежская область, Поворинский район, поселок Пески, Советская, 2	f	large
37359	30909	3008	Воронежская область, Поворинский район, поселок Октябрьское, Ленинская, 21	f	medium
37371	30921	3020	Воронежская область, Поворинский район, поселок Октябрьский, Садовая, 27	f	small
86340	31244	3913	Воронежская область, Поворинский район, поселок Октябрьский, Молодежная, 5	f	small
37366	30916	3015	Воронежская область, Поворинский район, поселок Мазурка, площадь Революции, 25	f	small
37368	30899	3017	Воронежская область, Поворинский район, поселок Кардаиловка, Горская, 5	f	small
37367	30917	3016	Воронежская область, Поворинский район, поселок Ильмень, Садовая, 24А	f	medium
37372	30922	3021	Воронежская область, Поворинский район, поселок Вихляевка, Советская, 48	f	small
37369	30919	3018	Воронежская область, Поворинский район, поселок Байчурово, Октябрьская, 19	f	large
37344	30894	2914	Воронежская область, Петропавловский район, поселок Фоменково, Советская, 47	f	small
37332	30882	2902	Воронежская область, Петропавловский район, поселок Старомеловая, Первомайская, 22	f	medium
37331	30881	2901	Воронежская область, Петропавловский район, поселок Старомеловая, Мира, 32	f	medium
37351	30902	2921	Воронежская область, Петропавловский район, поселок Старая Криуша, Садовая, 34б	f	medium
37349	30900	2919	Воронежская область, Петропавловский район, поселок Старая Криуша, Молодежная, 32б	f	medium
37350	30901	2920	Воронежская область, Петропавловский район, поселок Старая Криуша, Ленина, 26	f	small
37337	30887	2907	Воронежская область, Петропавловский район, поселок Петропавловка, Победы, 30	f	large
37334	30884	2904	Воронежская область, Петропавловский район, поселок Пески, Центральная, 76	f	large
37365	30915	3014	Воронежская область, Петропавловский район, поселок Пески, Международная, 1	f	large
37348	30898	2918	Воронежская область, Петропавловский район, поселок Огарев, Октября, 7а, Здание ЗАО Маяк 	f	small
37340	30890	2910	Воронежская область, Петропавловский район, поселок Новый Лиман, Советская, 76	f	medium
37343	30893	2913	Воронежская область, Петропавловский район, поселок Новотроицкое, Степная, 26а	f	medium
37342	30892	2912	Воронежская область, Петропавловский район, поселок Новобогородицкое, Ленина, 41	f	medium
37346	30896	2916	Воронежская область, Петропавловский район, поселок Краснофлотское, Ленина, 55б	f	medium
37347	30897	2917	Воронежская область, Петропавловский район, поселок Краснофлотское, Космонавтов, 82б	f	small
37335	30885	2905	Воронежская область, Петропавловский район, поселок Красноселовка, Ленина, 28	f	large
37064	30617	2203	Воронежская область, Каширский район, Нововоронеж, Ленина, 10 А	f	large
37333	30883	2903	Воронежская область, Петропавловский район, поселок Индычий, Школьная, 27а	f	small
37338	30888	2908	Воронежская область, Петропавловский район, поселок Замостье, Пионерская, 10	f	small
37341	30891	2911	Воронежская область, Петропавловский район, поселок Глубокое, Шестакова, 22	f	medium
37339	30889	2909	Воронежская область, Петропавловский район, поселок Бычок, Ленина, 26б	f	medium
37309	30858	2820	Воронежская область, Панинский район, поселок Щербачевка, Колхозная, 1	f	small
37328	30877	2839	Воронежская область, Панинский район, поселок Чернавка, Пролетарская, 3А	f	small
36281	29960	534	Воронежская область, Панинский район, поселок Чернавка, Народная, 80	f	small
37325	30874	2836	Воронежская область, Панинский район, поселок Тойда, Школьная, 14	f	medium
86289	30876	2838	Воронежская область, Панинский район, поселок Тойда, Заводская, 24	f	small
36069	29749	120	Воронежская область, Панинский район, поселок Софьинка, Придача, 15	t	small
86339	31243	3912	Воронежская область, Панинский район, поселок Сергеевка, Тверская, 29	f	small
37295	30844	2806	Воронежская область, Панинский район, поселок Перелешинский, брянская, 17	f	large
86290	30880	2842	Воронежская область, Панинский район, поселок Перелешинский, Майская, 33	f	small
37296	30845	2807	Воронежская область, Панинский район, поселок Перелешинский, Ленина, 5	f	large
37297	30846	2808	Воронежская область, Панинский район, поселок Перелешинский, Брянская, 17	f	small
37306	30855	2817	Воронежская область, Панинский район, поселок Перелешино, 50 лет Октября, 5Б	f	large
37330	30879	2841	Воронежская область, Панинский район, поселок Панино, советская, 17	f	large
37290	30839	2801	Воронежская область, Панинский район, поселок Панино, Красная площадь, 13	f	large
37293	30842	2804	Воронежская область, Панинский район, поселок Панино, Железнодорожная, 2	f	medium
37292	30841	2803	Воронежская область, Панинский район, поселок Панино, Железнодорожная, 52	f	medium
37291	30840	2802	Воронежская область, Панинский район, поселок Панино, 9-е Января, 6А	f	large
37294	30843	2805	Воронежская область, Панинский район, поселок Панино, 9-Января, 91	f	medium
37300	95196	2811	Воронежская область, Панинский район, поселок Пады, Верхняя, 47	f	small
37311	30860	2822	Воронежская область, Панинский район, поселок Павловка, Школьная, 6А	f	small
37329	30878	2840	Воронежская область, Панинский район, поселок Отдел Первомайского завода N11, Кольцевая, 39	f	small
37318	30867	2829	Воронежская область, Панинский район, поселок Октябрьский, 50 лет Октября, 136	f	medium
37320	30869	2831	Воронежская область, Панинский район, поселок Новохреновое, Школьная, 51	f	small
37319	30868	2830	Воронежская область, Панинский район, поселок Новохреновое, Совхозная, 76	t	small
37301	30850	2812	Воронежская область, Панинский район, поселок Михайловка 2-я, Школьная, 1	f	small
37321	30870	2832	Воронежская область, Панинский район, поселок Михайловка 1-я, Центральная, 2	f	medium
37322	30871	2833	Воронежская область, Панинский район, поселок Марьевка, Мира, 48	f	small
37313	30862	2824	Воронежская область, Панинский район, поселок Криуша, Молодежная, 47	f	medium
37310	30859	2821	Воронежская область, Панинский район, поселок Красный Лиман, Советская, 50	f	medium
37312	30861	2823	Воронежская область, Панинский район, поселок Красный Лиман, Партизанская, 122	f	medium
37305	30854	2816	Воронежская область, Панинский район, поселок Красные Холмы, Пролетарская, 1	f	small
37308	30857	2819	Воронежская область, Панинский район, поселок Красное, Ломоносова, 70А	f	small
37303	30852	2814	Воронежская область, Панинский район, поселок Ивановка 1-я, Проспект революции, 1	f	small
37302	30851	2813	Воронежская область, Панинский район, поселок Дмитриевка, Бевз, 11	f	small
37304	30853	2815	Воронежская область, Панинский район, поселок Верхняя Катуховка, Дзержинского, 63	f	small
37314	30863	2825	Воронежская область, Панинский район, поселок Большой Мартын, Советская, 2	f	medium
37345	30895	2915	Воронежская область, Панинский район, поселок Березняги, Центральная, 68а	f	medium
37323	30872	2834	Воронежская область, Панинский район, поселок Алое Поле, Школьная, 31	f	medium
37324	30873	2835	Воронежская область, Панинский район, поселок Алое Поле, Центральная, 57	f	small
82614	56514	1788	Москва, Садовники, 12	f	large
36781	30348	1516	Воронежская область, Панинский район, поселок Алексеевка, Центральная, 52	f	small
37277	30828	2737	Воронежская область, Павловский район, с.Лосево, Герино, 340А	f	small
37270	30821	2730	Воронежская область, Павловский район, поселок Шувалов, Молодежная, 14	f	medium
37286	30837	2746	Воронежская область, Павловский район, поселок Шкурлат, Мира, 13	f	small
37284	30835	2744	Воронежская область, Павловский район, поселок Черкасское, Мира, 52	f	small
109461	30838	2747	Воронежская область, Павловский район, поселок Русская Буйловка, Советская, 1	f	medium
37285	30836	2745	Воронежская область, Павловский район, поселок Русская Буйловка, Советская, 5	f	large
37283	30834	2743	Воронежская область, Павловский район, поселок Покровка, Советская, 63	f	medium
37280	30831	2740	Воронежская область, Павловский район, поселок Петровка, проспект Революции, 108А 	f	large
37278	30829	2738	Воронежская область, Павловский район, поселок Пески, Скрынникова, 20	f	medium
37269	30820	2729	Воронежская область, Павловский район, поселок Переездной, Новоселов, 25	f	small
37245	30796	2705	Воронежская область, Павловский район, Павловск, проспект Революции, 102А	f	large
37244	30795	2704	Воронежская область, Павловский район, Павловск, проспект Революции, 15	f	medium
37288	30800	2748	Воронежская область, Павловский район, Павловск, микрорайон гранитный, 25	f	medium
37249	30800	2709	Воронежская область, Павловский район, Павловск, микрорайон гранитный, 25	f	large
37251	30802	2711	Воронежская область, Павловский район, Павловск, микрорайон Черемушки, 1	f	large
37253	30804	2713	Воронежская область, Павловский район, Павловск, восточная, 4	f	large
37243	30794	2703	Воронежская область, Павловский район, Павловск, Советская, 1	f	large
37250	30801	2710	Воронежская область, Павловский район, Павловск, Садовая, 31	f	small
37252	30803	2712	Воронежская область, Павловский район, Павловск, Гагарина, 41	f	large
37266	30817	2726	Воронежская область, Павловский район, поселок Николаевка, Победы, 2	f	medium
37268	30819	2728	Воронежская область, Павловский район, поселок Момотов, Мира, 1	f	small
37281	30832	2741	Воронежская область, Павловский район, поселок Михайловка, 60 лет Октября, 1Б	f	small
37275	30826	2735	Воронежская область, Павловский район, поселок Лосево, пл.Первомайская, 1	f	medium
37273	30824	2733	Воронежская область, Павловский район, поселок Лосево, Буденного, 46	f	medium
37272	30823	2732	Воронежская область, Павловский район, поселок Ливенка, Ленина, 2	f	medium
37263	30814	2723	Воронежская область, Павловский район, поселок Каменск, Центральная, 19	f	small
37265	30816	2725	Воронежская область, Павловский район, поселок Ерышевка, Революции проспект, 1А	f	medium
37264	30815	2724	Воронежская область, Павловский район, поселок Елизаветовка, проспект Революции, 67	f	large
37271	30822	2731	Воронежская область, Павловский район, поселок Данило, Центральная, 32	f	medium
37282	30833	2742	Воронежская область, Павловский район, поселок Грань, Первомайская, 107	f	small
37262	30813	2722	Воронежская область, Павловский район, поселок Гаврильск, Советская, 148	f	medium
37258	30809	2718	Воронежская область, Павловский район, поселок Воронцовка, пролетарская, 49А	f	large
37261	30812	2721	Воронежская область, Павловский район, поселок Воронцовка, Советская, 85	f	large
37260	30811	2720	Воронежская область, Павловский район, поселок Воронцовка, Почтовая, 6	f	medium
37259	30810	2719	Воронежская область, Павловский район, поселок Воронцовка, Мостовая, 50А	f	medium
37267	30818	2727	Воронежская область, Павловский район, поселок Большая Казинка, Почтовая, 8	f	large
37256	30807	2716	Воронежская область, Павловский район, поселок Березки, Центральная, 14Б	f	small
37255	30806	2715	Воронежская область, Павловский район, поселок Бабка, Центральная, 44	f	medium
37254	30805	2714	Воронежская область, Павловский район, поселок Александровка-Донская, Садовая, 115А	f	large
37210	30761	2624	Воронежская область, Острогожский район, поселок Шубное, Мира, 11	f	medium
37214	30765	2628	Воронежская область, Острогожский район, поселок Шинкин, Заречная, 6	f	small
37207	30758	2621	Воронежская область, Острогожский район, поселок Хохол-Тростянка, пер. Мира, 7Б	f	small
36050	29702	101	Воронежская область, Аннинский район, поселок Анна, К.Маркса, 11	f	large
37239	30790	2653	Воронежская область, Острогожский район, поселок Урыв-Покровка, центральная, 91	f	large
109459	30783	2646	Воронежская область, Острогожский район, поселок Терновое, Советская, 51А	f	medium
37240	30791	2654	Воронежская область, Острогожский район, поселок Сторожевое, Советская, 96	f	medium
109460	30785	2648	Воронежская область, Острогожский район, поселок Солдатское, Ленина, 24А	f	medium
37218	30769	2632	Воронежская область, Острогожский район, поселок Сельхозтехника, Советская, 14	f	medium
37225	30776	2639	Воронежская область, Острогожский район, поселок Рыбное, Школьный переулок, 2	f	small
37208	30759	2622	Воронежская область, Острогожский район, поселок Русская Тростянка, Победы, 13	f	small
37228	30779	2642	Воронежская область, Острогожский район, поселок Петропавловка, Молодежная, 6	f	medium
37223	30774	2637	Воронежская область, Острогожский район, поселок Петренково, Мира, 39	f	small
37217	30768	2631	Воронежская область, Острогожский район, поселок Отдел N1 совхоза Острогожский, Школьная, 4	f	medium
37209	30760	2623	Воронежская область, Острогожский район, поселок Острогожский, Садовая, 29	f	medium
37199	30750	2613	Воронежская область, Острогожский район, Острогожск, федосеенко, 67	f	large
37198	30749	2612	Воронежская область, Острогожский район, Острогожск, комсомольская, 16	f	large
37193	30744	2607	Воронежская область, Острогожский район, Острогожск, Нарского, 24	f	large
37197	30748	2611	Воронежская область, Острогожский район, Острогожск, Милицейская, 52	f	large
37191	30742	2605	Воронежская область, Острогожский район, Острогожск, Ленина, 8	f	large
68091	30746	2609	Воронежская область, Острогожский район, Острогожск, Комсомольская, 60	f	large
37188	30740	2602	Воронежская область, Острогожский район, Острогожск, Вокзальная, 12	f	small
37200	30751	2614	Воронежская область, Острогожский район, Острогожск, 50 лет Октября, 51	f	large
37238	30789	2652	Воронежская область, Острогожский район, поселок Новоуспенка, Воронежская, 105	f	small
37205	30756	2619	Воронежская область, Острогожский район, поселок Новая Осиновка, Подгорная, 39	f	small
37204	30755	2618	Воронежская область, Острогожский район, поселок Новая Мельница, 60 лет Октября, 36	f	small
37213	30764	2627	Воронежская область, Острогожский район, поселок Нижний Ольшан, Почтовая, 32	f	medium
37237	30788	2651	Воронежская область, Острогожский район, поселок Мастюгино, Куркина, 31А	f	medium
37227	30778	2641	Воронежская область, Острогожский район, поселок Луки, Садовая, 1	f	medium
37226	30777	2640	Воронежская область, Острогожский район, поселок Криница, пер.Рабочий, 1А	f	small
86275	29870	337	Воронежская область, Острогожский район, поселок Криница, Мира, 4	f	small
37221	30772	2635	Воронежская область, Острогожский район, поселок Кривая Поляна, Школьная, 3	f	small
37229	30780	2643	Воронежская область, Острогожский район, поселок Коротояк, Свободы, 51	f	large
37233	30784	2647	Воронежская область, Острогожский район, поселок Ездочное, Верхняя, 31А	f	small
37224	30775	2638	Воронежская область, Острогожский район, поселок Должик, Центральная, 14	f	small
37235	30786	2649	Воронежская область, Острогожский район, поселок Девица, Ленина, 11Б	f	medium
37219	30770	2633	Воронежская область, Острогожский район, поселок Дальняя Полубянка, Молодежная, 14А	f	small
37211	30762	2625	Воронежская область, Острогожский район, поселок Грушевая Поляна, Садовая, 3	f	small
37215	30766	2629	Воронежская область, Острогожский район, поселок Гнилое, Ленина, 18	f	medium
37203	30754	2617	Воронежская область, Острогожский район, поселок Волошино, Октябрьской революции, 1В	f	small
37220	30771	2634	Воронежская область, Острогожский район, поселок Владимировка, переулок Южный, 1	f	small
109458	30757	2620	Воронежская область, Острогожский район, поселок Веретье, Центральная, 66	f	medium
37236	30787	2650	Воронежская область, Острогожский район, поселок Болдыревка, Мостовая, 1	f	medium
37216	30767	2630	Воронежская область, Острогожский район, поселок Ближняя Стояново, Луговая, 2	f	medium
37222	30773	2636	Воронежская область, Острогожский район, поселок Ближняя Полубянка, Центральная, 5	f	small
37231	30782	2645	Воронежская область, Острогожский район, поселок Березово, Клубная, 1	f	small
82613	56514	1787	Москва, Садовники, 12	f	large
37175	30727	2516	Воронежская область, Ольховатский район, поселок Юрасовка, площадь Победы, 1	f	medium
37167	30718	2508	Воронежская область, Ольховатский район, поселок Шапошниковка, Шевченко, 1в	f	large
37181	30733	2522	Воронежская область, Ольховатский район, поселок Постоялый, Денисова, 11	t	small
37184	30736	2525	Воронежская область, Ольховатский район, поселок Ольховатка, Степана Разина, 1а	f	medium
37160	30711	2501	Воронежская область, Ольховатский район, поселок Ольховатка, Пролетарская, 2	f	medium
37183	30735	2524	Воронежская область, Ольховатский район, поселок Ольховатка, Октябрьская, 56	f	medium
37161	30712	2502	Воронежская область, Ольховатский район, поселок Ольховатка, 50 лет ВЛКСМ, 1	f	large
37178	30730	2519	Воронежская область, Ольховатский район, поселок Новохарьковка, Октябрьская, 162а	f	medium
37179	30731	2520	Воронежская область, Ольховатский район, поселок Новокулишовка, 8б	f	small
37177	30729	2518	Воронежская область, Ольховатский район, поселок Новокараяшник, Асфальтная, 44	f	small
37169	30720	2510	Воронежская область, Ольховатский район, поселок Неровновка, Тополиная, 2	t	small
109457	30723	2513	Воронежская область, Ольховатский район, поселок Назаровка, Гагарина, 171	f	medium
37171	30722	2512	Воронежская область, Ольховатский район, поселок Марьевка, Школьная, 211	f	medium
36335	30015	727	Воронежская область, Ольховатский район, поселок Марьевка, Трудовая, 46б	f	small
37170	30721	2511	Воронежская область, Ольховатский район, поселок Марченковка, Мичурина, 43	f	small
37166	30717	2507	Воронежская область, Ольховатский район, поселок Малые Базы, Юбилейная, 3	f	large
37173	30724	2514	Воронежская область, Ольховатский район, поселок Лимарев, Школьная, 104а	f	small
37168	30719	2509	Воронежская область, Ольховатский район, поселок Костово, 38 Стрелковой Дивизии, 5	f	medium
37174	30726	2515	Воронежская область, Ольховатский район, поселок Копаная 1-я, Молодежная, 112а	f	medium
37176	30728	2517	Воронежская область, Ольховатский район, поселок Караяшник, Школьная, 18	f	medium
37163	30714	2504	Воронежская область, Ольховатский район, поселок Заболотовка, Зеленая, 15	f	large
37162	30713	2503	Воронежская область, Ольховатский район, поселок Заболотовка, Зеленая, 15	f	large
37180	30732	2521	Воронежская область, Ольховатский район, поселок Дроздово, Ленина, 7	f	small
37186	30738	2527	Воронежская область, Ольховатский район, поселок Гвоздовка, Молодежная, 169в	f	small
37164	30715	2505	Воронежская область, Ольховатский район, поселок Бугаевка, Победы, 38	f	large
37185	30737	2526	Воронежская область, Ольховатский район, поселок Болшие Базы, Школьная, 11	f	large
37165	30716	2506	Воронежская область, Ольховатский район, поселок Болшие Базы, Школьная, 9	f	medium
36816	30382	1611	Воронежская область, Оленинский район, поселок Заброды, Дерезовская, 94	f	large
37144	14669	2426	Воронежская область, Новохоперский район, поселок Ярки, Свобода, 53	f	medium
109456	30680	2411	Воронежская область, Новохоперский район, поселок Централь, Советская, 26	f	medium
37158	30709	2440	Воронежская область, Новохоперский район, поселок Тулучеевка, Лесная, 7	f	small
37137	30688	2419	Воронежская область, Новохоперский район, поселок Троицкое, Советская, 12	f	medium
37136	30687	2418	Воронежская область, Новохоперский район, поселок Троицкое, Советская, 22	f	medium
86305	31122	3548	Воронежская область, Новохоперский район, поселок Троицкое, Сельская, 64	f	small
37157	30707	2439	Воронежская область, Новохоперский район, поселок Терновский, Центральная, 1	f	medium
37154	30704	2436	Воронежская область, Новохоперский район, поселок Совхоз имени ХХII Партсъезда, Административная, 5	f	small
37128	30679	2410	Воронежская область, Новохоперский район, поселок Русаново, Верхняя, 53	f	small
37130	30681	2412	Воронежская область, Новохоперский район, поселок Пыховка, Советская, 136	f	medium
37134	30685	2416	Воронежская область, Новохоперский район, поселок Половцево, Приозерный переулок, 31	f	medium
37153	30703	2435	Воронежская область, Новохоперский район, поселок Полежаевский	f	small
37145	30695	2427	Воронежская область, Новохоперский район, поселок Подосиновка, Центральная, 5	f	small
36839	30395	1624	Воронежская область, Новохоперский район, поселок Подгорное, Школьная, 12	f	large
37143	30694	2425	Воронежская область, Новохоперский район, поселок Подгорное, Октябрьская, 40	f	medium
37132	30683	2414	Воронежская область, Новохоперский район, поселок Озерный, Проезжая, 17	f	small
37124	30675	2406	Воронежская область, Новохоперский район, поселок Новохоперск, переулок Пушкина, 21	f	large
37126	30677	2408	Воронежская область, Новохоперский район, поселок Новохоперск, железнодорожная, 8	f	large
37127	30678	2409	Воронежская область, Новохоперский район, поселок Новохоперск, Шолохова, 59	f	large
37159	30710	2441	Воронежская область, Новохоперский район, поселок Новохоперск, Клиническая, 2	f	medium
37125	30676	2407	Воронежская область, Новохоперский район, поселок Новохоперск, Железнодорожная, 27	f	large
68090	30670	2401	Воронежская область, Новохоперский район, поселок Новохоперск, 25 Октября, 32	f	large
37140	30691	2422	Воронежская область, Новохоперский район, поселок Новопокровский, Калинина, 1	f	small
37139	30690	2421	Воронежская область, Новохоперский район, поселок Некрылово, Курортная, 2б	f	medium
37141	30692	2423	Воронежская область, Новохоперский район, поселок Ленинский, Центральная, 44	f	small
37138	30689	2420	Воронежская область, Новохоперский район, поселок Красное, Советская, 36а	f	large
37131	30682	2413	Воронежская область, Новохоперский район, поселок Камено-Садовка, Онысюка, 4	f	medium
37123	30674	2405	Воронежская область, Новохоперский район, поселок Замельничный	f	small
37155	30705	2437	Воронежская область, Новохоперский район, поселок Елань-Коленовский, проспект Кольцова, 10	f	medium
37156	30706	2438	Воронежская область, Новохоперский район, поселок Елань-Коленовский, Центральная, 4	f	large
37146	30696	2428	Воронежская область, Новохоперский район, поселок Елань-Колено, проспект Революции, 10	f	medium
37147	30697	2429	Воронежская область, Новохоперский район, поселок Елань-Колено, крейзера, 9	f	large
37148	30698	2430	Воронежская область, Новохоперский район, поселок Елань-Колено, Мостовая, 130	f	medium
37149	30699	2431	Воронежская область, Новохоперский район, поселок Димитровский	f	small
37133	30684	2415	Воронежская область, Новохоперский район, поселок Варварино, Лесная, 59	f	small
37151	30701	2433	Воронежская область, Новохоперский район, поселок Бурляевка, Школьный переулок, 10	f	small
37142	30693	2424	Воронежская область, Новохоперский район, поселок Бороздиновский, Спортивная, 7	f	small
37150	30700	2432	Воронежская область, Новохоперский район, поселок Березовка, Центральная, 7	f	small
37135	30686	2417	Воронежская область, Новохоперский район, поселок Алферовка, Центральная, 134	f	medium
37114	30665	2339	Воронежская область, Новоусманский район, поселок Шуберское, Подлесная, 19	f	medium
37113	30664	2338	Воронежская область, Новоусманский район, поселок Шуберское, Подлесная, 20	f	medium
37111	30662	2336	Воронежская область, Новоусманский район, поселок Хреновое, Молодежная, 16А	f	medium
37110	30661	2335	Воронежская область, Новоусманский район, поселок Хлебное, Буденного, 4	f	medium
37109	30660	2334	Воронежская область, Новоусманский район, поселок Трудовое, Центральная, 1А	f	medium
37106	30657	2331	Воронежская область, Новоусманский район, поселок Тимирязево, Тимирязева, 14	f	medium
37104	30655	2329	Воронежская область, Новоусманский район, поселок Совхоз Лекраспром, 47	f	small
37105	30656	2330	Воронежская область, Новоусманский район, поселок Совхоз Воронежский, Воронежская, 1	f	large
37112	30663	2337	Воронежская область, Новоусманский район, поселок Рыкань, Центральная, 23	f	medium
37100	30651	2325	Воронежская область, Новоусманский район, поселок Рождественская Хава, Советская, 35	f	medium
37101	30652	2326	Воронежская область, Новоусманский район, поселок Рождественская Хава, Механизаторов, 18	f	medium
37099	30650	2324	Воронежская область, Новоусманский район, поселок Рождественская Хава, Карла Маркса, 82	f	medium
37102	30653	2327	Воронежская область, Новоусманский район, поселок Рогачевка, Ворошилова, 8	f	medium
37084	30635	2309	Воронежская область, Новоусманский район, поселок Парусное, Центральная, 1	f	medium
37093	30644	2318	Воронежская область, Новоусманский район, поселок Отдел N2 совхоза Масловский, Молодежная, 25	t	small
32143	25255	869	Брянская область, Сельцо, Брянская, 2	f	large
37089	30640	2314	Воронежская область, Новоусманский район, поселок Отдел N1 совхоза Новоусманский, Ленина, 1	f	large
37092	30643	2317	Воронежская область, Новоусманский район, поселок Отдел N1 совхоза Масловский, Ленина, 43	f	large
37096	30647	2321	Воронежская область, Новоусманский район, поселок Орлово, Свободы, 68	f	large
37095	94924	2320	Воронежская область, Новоусманский район, поселок Орлово, Мира, 14-а	f	large
37097	30648	2322	Воронежская область, Новоусманский район, поселок Орлово, Анатолия Гуцало, 60	f	small
37082	30633	2307	Воронежская область, Новоусманский район, поселок Новая Усмань, Школьная, 1	f	large
37078	30629	2303	Воронежская область, Новоусманский район, поселок Новая Усмань, Советская, 1	f	large
37086	30637	2311	Воронежская область, Новоусманский район, поселок Новая Усмань, Полевая, 1А к1	f	large
37085	30636	2310	Воронежская область, Новоусманский район, поселок Новая Усмань, Полевая, 1П	f	large
37080	30631	2305	Воронежская область, Новоусманский район, поселок Новая Усмань, Песоцкая, 69	f	large
37118	30669	2343	Воронежская область, Новоусманский район, поселок Новая Усмань, Ленина, 310	f	large
37083	30634	2308	Воронежская область, Новоусманский район, поселок Новая Усмань, Ленина, 141	f	large
37081	30632	2306	Воронежская область, Новоусманский район, поселок Новая Усмань, Ленина, 60В	f	large
37076	30627	2301	Воронежская область, Новоусманский район, поселок Новая Усмань, Ленина, 301	f	large
37079	30630	2304	Воронежская область, Новоусманский район, поселок Новая Усмань, Заречная, 1	f	large
37094	30645	2319	Воронежская область, Новоусманский район, поселок Нижняя Катуховка, Ленина, 116	f	medium
37098	30649	2323	Воронежская область, Новоусманский район, поселок Макарье, Буденного, 21А	f	small
37108	30659	2333	Воронежская область, Новоусманский район, поселок Крыловка, Центральная, 2	f	medium
37107	30658	2332	Воронежская область, Новоусманский район, поселок Горенские Выселки, 70 Лет Октября, 18	f	small
37117	30668	2342	Воронежская область, Новоусманский район, поселок Воля, Школьная, 2А	f	large
37116	30667	2341	Воронежская область, Новоусманский район, поселок Воля, Садовая, 61А	f	large
37115	30666	2340	Воронежская область, Новоусманский район, поселок Воля, Студенческая, 86А	f	large
37051	30605	2124	Воронежская область, Нижнедевицкий район, поселок Сычевка, Полевая, 2	f	small
109454	30604	2123	Воронежская область, Нижнедевицкий район, поселок Совхоз Кучугуровский, Садовая, 10	f	medium
37057	30611	2130	Воронежская область, Нижнедевицкий район, поселок Скупая Потудань, Ленина, 37	f	small
37053	30607	2126	Воронежская область, Нижнедевицкий район, поселок Синие Липяги, Школьный переулок, 10а	f	medium
37052	30606	2125	Воронежская область, Нижнедевицкий район, поселок Синие Липяги, Первомайская, 5в	f	small
37054	30608	2127	Воронежская область, Нижнедевицкий район, поселок Синие Липяги, Автоматчиков, 31а	f	small
86330	30600	2119	Воронежская область, Нижнедевицкий район, поселок Першино, Меркулова, 10	f	small
37045	30599	2118	Воронежская область, Нижнедевицкий район, поселок Першино, Меркулова, 10	f	medium
37055	30609	2128	Воронежская область, Нижнедевицкий район, поселок Острянка, Центральная, 40	f	small
37039	30593	2112	Воронежская область, Нижнедевицкий район, поселок Новая Ольшанка, Советская, 1	f	small
37048	30602	2121	Воронежская область, Нижнедевицкий район, поселок Нижнее Турово, Чапаева, 21	f	small
37047	30601	2120	Воронежская область, Нижнедевицкий район, поселок Нижнее Турово, Проспект Труда, 31	f	small
37044	30598	2117	Воронежская область, Нижнедевицкий район, поселок Нижнедевицкий, Чагадаева, 16	f	small
109453	30597	2116	Воронежская область, Нижнедевицкий район, поселок Нижнедевицкий, Мира, 17	f	medium
37030	30584	2103	Воронежская область, Нижнедевицкий район, Нижнедевицк, площадь Ленина, 1а	f	medium
37028	30582	2101	Воронежская область, Нижнедевицкий район, поселок Нижнедевицк, площадь Ленина, 3	f	large
86331	30612	2131	Воронежская область, Нижнедевицкий район, поселок Нижнедевицк, Центральная, 22	f	small
86329	30592	2111	Воронежская область, Нижнедевицкий район, поселок Нижнедевицк, Центральная, 22	f	small
37029	30583	2102	Воронежская область, Нижнедевицкий район, поселок Нижнедевицк, Луговая, 1	f	large
86332	30614	2134	Воронежская область, Нижнедевицкий район, поселок Нижнедевицк, Заводская, 27	f	small
37049	30603	2122	Воронежская область, Нижнедевицкий район, поселок Михнево, Садовая, 31	f	small
86296	30980	3222	Воронежская область, Нижнедевицкий район, поселок Лебяжье, Чапаева, 80	f	small
37042	30596	2115	Воронежская область, Нижнедевицкий район, поселок Кучугуры, Заречная, 45	f	small
37059	30613	2132	Воронежская область, Нижнедевицкий район, поселок Курбатово, Школьная, 114	f	medium
37060	30613	2133	Воронежская область, Нижнедевицкий район, поселок Курбатово, Школьная, 114	f	medium
37036	30590	2109	Воронежская область, Нижнедевицкий район, поселок Курбатово, Гагарина, 29	f	medium
37041	30595	2114	Воронежская область, Нижнедевицкий район, поселок Глазово, Октября, 36	f	small
37040	30594	2113	Воронежская область, Нижнедевицкий район, поселок Глазово, Мира, 98	f	small
37031	30585	2104	Воронежская область, Нижнедевицкий район, поселок Вязноватовка, Мира, 112	f	small
37032	30586	2105	Воронежская область, Нижнедевицкий район, поселок Вязноватовка, Загорского, 2	f	small
37035	30589	2108	Воронежская область, Нижнедевицкий район, поселок Верхнетурово, Молодежная, 17	f	small
37033	30587	2106	Воронежская область, Нижнедевицкий район, поселок Верхнетурово, Мира, 106	f	small
37034	30588	2107	Воронежская область, Нижнедевицкий район, поселок Верхнетурово, Кирова, 10	f	small
36990	30546	2046	Воронежская область, Лискинский район, поселок Щучье, Советская, 74а	f	medium
37014	30568	2070	Воронежская область, Лискинский район, поселок Троицкое, Буденного, 118б, ДК	f	medium
109450	30577	2078	Воронежская область, Лискинский район, поселок Тресоруково, Советская, 31а	f	medium
37001	30557	2057	Воронежская область, Лискинский район, поселок Сторожевое 2-е, Центральная, 2б, Дом культуры	f	small
37015	30569	2071	Воронежская область, Лискинский район, поселок Старая Хворостань, переулок Советский, 3	f	medium
37000	30556	2056	Воронежская область, Лискинский район, поселок Средний Икорец, санаторий им Цюрупы	f	medium
36997	30553	2053	Воронежская область, Лискинский район, поселок Средний Икорец, площадь Кирова, 9, Дом культуры	f	large
36998	30554	2054	Воронежская область, Лискинский район, поселок Средний Икорец, Площадь Революции, 78	f	large
36999	30555	2055	Воронежская область, Лискинский район, поселок Средний Икорец, Зеленая, 60а	f	large
36944	30506	1925	Воронежская область, Лискинский район, поселок Солонцы, Путь Ленина, 70	f	small
86327	30572	2073	Воронежская область, Лискинский район, поселок Селявное, площадь Победы, 27а	f	small
36983	30538	2039	Воронежская область, Лискинский район, поселок Селявное, 9 мая, 23	f	medium
36996	30552	2052	Воронежская область, Лискинский район, поселок Пухово, Центральная, 43, сельский клуб	f	small
36988	30543	2044	Воронежская область, Лискинский район, поселок Прияр, Мичурина, 62, Приярский сельский клуб	f	small
37021	30576	2077	Воронежская область, Лискинский район, поселок Почепское, Садовая, 6	f	medium
37336	30886	2906	Республика Бурятия, Бичурский район, село Петропавловка	f	large
36986	30541	2042	Воронежская область, Лискинский район, поселок Петропавловка, Административная, 4, Петропавловский Дом культуры	f	small
36980	30535	2036	Воронежская область, Лискинский район, поселок Петровское, 40 лет Октября, 20а	f	medium
36991	30547	2047	Воронежская область, Лискинский район, поселок Переезжее, Коммунистическая, 23, сельский клуб	f	small
86328	30573	2074	Воронежская область, Лискинский район, поселок Новозадонский, Центральная, 16а, сельский клуб	f	small
37004	30560	2060	Воронежская область, Лискинский район, поселок Никольский, Кирова, 138а	f	medium
36985	30540	2041	Воронежская область, Лискинский район, поселок Нижний Икорец, Победы, 59, Нижнеикорецкий Дом культуры	f	large
109452	30579	2080	Воронежская область, Лискинский район, поселок Нижнемарьино, Школьная, 2а, МОУ Нижнемарьинская СОШ	f	medium
36963	30524	2019	Воронежская область, Лискинский район, Лиски, клуб досуга хутор Калач	f	small
36955	30516	2011	Воронежская область, Лискинский район, Лиски, красный уголок ПТО вагонного депо	f	large
36975	30531	2031	Воронежская область, Лиски городской округ, Титова, 16	f	large
36948	30509	2004	Воронежская область, Лискинский район, Лиски, советская, 116	f	large
36953	30514	2009	Воронежская область, Лискинский район, Лиски, проспект Ленина, 32а	f	large
36945	30507	2001	Воронежская область, Лискинский район, Лиски, площадь Революции, 10-а	f	large
36978	30515	2034	Воронежская область, Лискинский район, Лиски, лысенко, 1	f	large
36954	30515	2010	Воронежская область, Лискинский район, Лиски, лысенко, 1	f	medium
36977	30533	2033	Воронежская область, Лискинский район, Лиски, Трудовые резервы, 62	f	large
36950	30511	2006	Воронежская область, Лискинский район, Лиски, Трудовые Резервы, 60, здание школы №10	f	large
36964	30510	2020	Воронежская область, Лискинский район, Лиски, Трудовые Резервы, 62	f	large
36949	30510	2005	Воронежская область, Лискинский район, Лиски, Трудовые Резервы, 62	f	medium
36967	30526	2023	Воронежская область, Лискинский район, Лиски, Свердлова, 66	f	large
36969	30512	2025	Воронежская область, Лискинский район, Лиски, Маршала Жукова, 3	f	large
36951	30512	2007	Воронежская область, Лискинский район, Лиски, Маршала Жукова, 3	f	large
36979	30534	2035	Воронежская область, Лискинский район, Лиски, Громовой, 37	f	large
68111	95192	2064	Воронежская область, Лискинский район, Лиски, 40 лет Победы, 10, дом культуры	f	large
36973	30530	2029	Воронежская область, Лискинский район, Лиски, 40 лет Октября, 64	f	large
36960	30521	2016	Воронежская область, Лискинский район, Лиски, 40 лет Октября, 62	f	large
36970	30519	2026	Воронежская область, Лискинский район, Лиски, 40 лет Октября, 78	f	large
36958	30519	2014	Воронежская область, Лискинский район, Лиски, 40 лет Октября, 78	f	large
36961	30522	2017	Воронежская область, Лискинский район, Лиски, 19 Партсъезда, 5	f	large
36994	30550	2050	Воронежская область, Лискинский район, поселок Копанище, Советская, 1	f	medium
36989	30545	2045	Воронежская область, Лискинский район, поселок Колыбелка, Садовая, 63	f	large
37007	30563	2063	Воронежская область, Лискинский район, поселок Коломыцево, Солнечная, 4, Дом культуры	f	medium
36995	30551	2051	Воронежская область, Лискинский район, поселок Ковалево, Юбилейная, 25, дом культуры	f	large
37003	30559	2059	Воронежская область, Лискинский район, поселок Залужное, Школьная, 27а	f	large
109449	30575	2076	Воронежская область, Лискинский район, поселок Ермоловка, Колхозная, 22	f	medium
36981	30536	2037	Воронежская область, Лискинский район, поселок Дракино, Молодежная, 9, МОУ Дракинская СОШ	f	large
36982	30537	2038	Воронежская область, Лискинский район, поселок Дракино, Ленина, 110а	f	large
109451	30578	2079	Воронежская область, Лискинский район, поселок Добрино, Придорожная, 7, МОУ Добринская СОШ	f	medium
36984	30539	2040	Воронежская область, Лискинский район, поселок Дивногорье, Центральная, 11, начальная школа х.Дивногорье	f	small
68112	95193	2065	Воронежская область, Лискинский район, поселок Давыдовка, ленина, 32	f	large
109447	95194	2066	Воронежская область, Лискинский район, поселок Давыдовка, Филипченко, 29	f	medium
68113	95195	2068	Воронежская область, Лискинский район, поселок Давыдовка, Октябрьская, 16, дом культуры	f	large
37013	30567	2069	Воронежская область, Лискинский район, поселок Давыдовка, Ленина, 34а, культурно-досуговый Центр	f	large
109448	30566	2067	Воронежская область, Лискинский район, поселок Давыдовка, Заводская, 10, МОУ Вознесеновская СОШ	f	medium
37019	30574	2075	Воронежская область, Лискинский район, поселок Бодеевка, Советская, 40	f	medium
37016	30571	2072	Воронежская область, Лискинский район, поселок Аношкино, Центральная, 58	f	small
37006	30544	2062	Воронежская область, Лиски городской округ, село Лиски, Советская, 304, МОУ Лисянская СОШ	f	medium
36943	30505	1924	Воронежская область, Каширский район, поселок Старина, Пришкольная, 9	f	small
86326	30504	1923	Омская область, Омск, поселок Степной	f	small
36933	30494	1914	Воронежская область, Каширский район, поселок Олень-Колодезь, Проспект Революции, 30	f	medium
37065	30618	2204	Воронежская область, Каширский район, Нововоронеж, площадь имени Ленина, 1	f	large
37074	30625	2213	Воронежская область, Каширский район, Нововоронеж, коммунальная, 5	f	large
37070	30621	2209	Воронежская область, Каширский район, Нововоронеж, Первомайская, 9 В	f	large
37069	30621	2208	Воронежская область, Каширский район, Нововоронеж, Первомайская, 9 В	f	large
37062	30615	2201	Воронежская область, Каширский район, Нововоронеж, Октябрьская, 1	f	large
37073	30624	2212	Воронежская область, Каширский район, Нововоронеж, Космонавтов, 27А	f	large
37075	30626	2214	Воронежская область, Каширский район, Нововоронеж, Воронежское шоссе, 13	f	large
36939	30501	1920	Воронежская область, Каширский район, поселок Мосальское, Советская, 37а	f	small
36940	30502	1921	Воронежская область, Каширский район, поселок Можайское, Ленина, 17	f	medium
37152	30702	2434	Нижегородская область, Воскресенский район, поселок Михайловский	f	small
109446	30500	1919	Воронежская область, Каширский район, поселок Левая Россошь, Пролетарская, 6	f	medium
36937	30498	1918	Воронежская область, Каширский район, поселок Круглое, Карла Маркса, 52	f	medium
36936	30497	1917	Воронежская область, Каширский район, поселок Красный Лог, Степная, 3	f	large
36934	30495	1915	Воронежская область, Каширский район, поселок Кондрашкино, Молодежная, 2	f	medium
36935	30496	1916	Воронежская область, Каширский район, поселок Коломенское, Первомайская, 61	f	small
36931	30492	1912	Воронежская область, Каширский район, поселок Колодезный, Ленина, 42а	f	large
36930	30491	1911	Воронежская область, Каширский район, поселок Колодезная, Центральная, 18а	f	large
36920	30481	1901	Воронежская область, Каширский район, поселок Каширское, Олимпийская, 3	f	large
36921	30482	1902	Воронежская область, Каширский район, поселок Каширское, Мира, 1	f	large
36922	30483	1903	Воронежская область, Каширский район, поселок Каширское, 3 Интернационала, 92	f	medium
36929	30490	1910	Воронежская область, Каширский район, поселок Камено-Верховка, Мира, 15	f	small
36927	30488	1908	Воронежская область, Каширский район, поселок Имени Дзержинского, Школьная, 60	f	large
36941	30503	1922	Воронежская область, Каширский район, поселок Ильича, Новая, 8	f	small
36928	30489	1909	Воронежская область, Каширский район, поселок Запрудское, Ленина, 19а	f	medium
36925	30486	1906	Воронежская область, Каширский район, поселок Данково, Мира, 23	f	medium
36926	30487	1907	Воронежская область, Каширский район, поселок Данково, Кольцовская, 1а	f	medium
36924	30485	1905	Воронежская область, Каширский район, поселок Боево, Школьная, 9	f	large
36923	30484	1904	Воронежская область, Каширский район, поселок Бирюченское, Пушкинская, 48	t	small
86323	30470	1836	Воронежская область, Кантемировский район, поселок Шевченково, Советская, 47	t	small
36916	30477	1844	Воронежская область, Кантемировский район, поселок Фисенково, Советская, 69а	t	small
36914	30475	1842	Воронежская область, Кантемировский район, поселок Титаревка, Победы, 51	f	medium
68109	30473	1840	Воронежская область, Кантемировский район, поселок Талы, Центральная, 163	f	large
36897	14667	1825	Воронежская область, Кантемировский район, поселок Софиевка, Луговая, 45	f	small
86322	30469	1835	Воронежская область, Кантемировский район, поселок Соленый, Школьная, 60	t	small
109445	30471	1838	Воронежская область, Кантемировский район, поселок Смаглеевка, 50 лет Октября, 16	t	medium
36911	30472	1839	Воронежская область, Кантемировский район, поселок Скнаровка, Широкая, 2	t	small
36915	30476	1843	Воронежская область, Кантемировский район, поселок Рудаевка, Центральная, 17	t	small
36909	14668	1837	Воронежская область, Кантемировский район, поселок Писаревка, Ленина, 8 б	f	large
36887	30451	1815	Воронежская область, Кантемировский район, поселок Пасюковка, Колхозная, 26	f	small
36906	30468	1834	Воронежская область, Кантемировский район, поселок Пасеково, Мира, 55	f	small
36885	30449	1813	Воронежская область, Кантемировский район, поселок Охровый Завод, Школьная, 13	f	medium
86321	30466	1832	Воронежская область, Кантемировский район, поселок Осиковка, Центральная, 18	f	small
36891	30455	1819	Воронежская область, Кантемировский район, поселок Новопавловка, Мира, 29	t	small
36900	30462	1828	Воронежская область, Кантемировский район, поселок Новопавловка, Луговая, 11	f	small
68108	30465	1831	Воронежская область, Кантемировский район, поселок Новомарковка, Советская, 14	f	large
68107	30464	1830	Воронежская область, Кантемировский район, поселок Новобелая, Советская, 27	t	large
36899	30461	1827	Воронежская область, Кантемировский район, поселок Михайловка, Юбилейная, 19	f	medium
36892	30456	1820	Воронежская область, Кантемировский район, поселок Митрофановка, пр-кт Строителей, 16	f	medium
36896	30459	1824	Воронежская область, Кантемировский район, поселок Митрофановка, Элеваторская, 5	f	large
36894	29842	1822	Воронежская область, Кантемировский район, поселок Митрофановка, Ленина, 105	f	medium
36895	30458	1823	Воронежская область, Кантемировский район, поселок Митрофановка, Большевик, 32	f	medium
86320	30463	1829	Воронежская область, Кантемировский район, поселок Куликовка, Центральная, 28	f	small
36905	30467	1833	Воронежская область, Кантемировский район, поселок Кузнецовский, Центральная, 40	t	small
86287	30448	1812	Воронежская область, Кантемировский район, поселок Колещатовка, Ленина, 26	t	small
36888	30452	1816	Воронежская область, Кантемировский район, поселок Касьяновка, Театральная, 14	f	medium
36875	30438	1803	Воронежская область, Кантемировский район, поселок Кантемировка, победы, 30	f	large
36873	30436	1801	Воронежская область, Кантемировский район, поселок Кантемировка, первомайская, 14	f	large
36879	30442	1807	Воронежская область, Кантемировский район, поселок Кантемировка, Шевченко, 96	f	large
36876	30439	1804	Воронежская область, Кантемировский район, поселок Кантемировка, Строителей, 1а	f	medium
36874	30437	1802	Воронежская область, Кантемировский район, поселок Кантемировка, Победы, 11	f	large
36877	30440	1805	Воронежская область, Кантемировский район, поселок Кантемировка, Кирпичная, 3	f	medium
109443	30441	1806	Воронежская область, Кантемировский район, поселок Кантемировка, Дунай, 16а	f	medium
86288	30453	1817	Воронежская область, Кантемировский район, поселок Зайцевка, Центральная, 42	f	small
36898	30460	1826	Воронежская область, Кантемировский район, поселок Евдокиевка, Центральная, 25	f	small
86285	30443	1808	Воронежская область, Кантемировский район, поселок Гартмашевка, Вокзальная, 14	f	small
86319	30454	1818	Воронежская область, Кантемировский район, поселок Гармашевка, Победы, 18	t	small
86286	30446	1810	Воронежская область, Кантемировский район, поселок Волоконовка, Школьная, 1 а	f	small
86325	30478	1845	Воронежская область, Кантемировский район, поселок Валентиновка, Победы, 15а	t	small
86324	30474	1841	Воронежская область, Кантемировский район, поселок Бугаевка, Советская, 54	t	small
36883	30447	1811	Воронежская область, Кантемировский район, поселок Бугаевка, Лесная, 50	f	medium
109444	30445	1809	Воронежская область, Кантемировский район, поселок Бондарево, Базарная, 2а	f	medium
86284	30429	1717	Воронежская область, Каменский район, поселок Ярки, Школьная, 72/1	f	small
86282	30417	1705	Воронежская область, Каменский район, поселок Щербаково, Молодежная, 12	f	small
36865	30428	1716	Воронежская область, Каменский район, поселок Тхоревка, Центральная, 29	f	small
36863	30426	1714	Воронежская область, Каменский район, поселок Трехстенки, Центральная, 23	f	small
36867	30430	1718	Воронежская область, Каменский район, поселок Тимирязево, Центральная, 26	f	medium
36862	30425	1713	Воронежская область, Каменский район, поселок Татарино, Центральная, 27	f	medium
36860	30423	1711	Воронежская область, Каменский район, поселок Сончино, Ленина, 10	f	medium
36864	30427	1715	Воронежская область, Каменский район, поселок Пилипы, Механизаторов, 26	f	small
36856	30419	1707	Воронежская область, Каменский район, поселок Ольхов Лог, Центральная, 47	f	small
36861	30424	1712	Воронежская область, Каменский район, поселок Новиковское, Новая, 9	f	small
36858	30421	1709	Воронежская область, Каменский район, поселок Марки, Центральная, 1	f	medium
36851	30414	1702	Воронежская область, Каменский район, поселок Крутец, Железнодорожная, 38а	f	small
36857	30420	1708	Воронежская область, Каменский район, поселок Коденцово, Красная, 42	f	medium
109442	30418	1706	Воронежская область, Каменский район, поселок Карпенково, Дружбы, 35	f	medium
36869	30432	1720	Воронежская область, Каменский район, поселок Каменка, Солнечная, 1	f	large
36870	30433	1721	Воронежская область, Каменский район, поселок Каменка, Советская, 31	f	large
68087	30431	1719	Воронежская область, Каменский район, поселок Каменка, Привокзальная, 3	f	large
36871	30434	1722	Воронежская область, Каменский район, поселок Каменка, Полевая, 30	f	large
37370	30920	3019	Воронежская область, Каменский район, поселок Каменка, Народная, 23Б	f	small
32142	25255	868	Брянская область, Сельцо, Брянская, 2	f	large
68088	30435	1723	Воронежская область, Каменский район, поселок Каменка, Гагарина, 18 Б	f	large
36853	30416	1704	Воронежская область, Каменский район, поселок Евдаково, Садовая, 3	f	small
109441	30415	1703	Воронежская область, Каменский район, поселок Дегтярное, Мира, 20	f	medium
36850	30413	1701	Воронежская область, Каменский район, поселок Волчанское, Центральная, 26	f	small
86283	30422	1710	Воронежская область, Каменский район, поселок Верхние Марки, Новая Жизнь, 116	f	small
36828	30411	1640	Воронежская область, Калачеевский район, поселок Ясеновка, Центральная, 54	f	medium
36827	30393	1622	Воронежская область, Калачеевский район, поселок Юнаково, Комсомольская, 51	f	small
36836	30410	1639	Воронежская область, Калачеевский район, поселок Ширяево, Ленина площадь, 1	f	medium
36835	30409	1638	Воронежская область, Калачеевский район, поселок Ширяево, Ленина, 37	f	large
36849	30408	1637	Воронежская область, Калачеевский район, поселок Четвериково, Кирова, 37	f	small
36846	30405	1634	Воронежская область, Калачеевский район, поселок Хрещатое, Восточная, 11	f	medium
36829	30412	1641	Воронежская область, Калачеевский район, поселок Хвощеватое, переулок Гагарина, 48	f	small
36844	30404	1633	Воронежская область, Калачеевский район, поселок Советское, Советская, 47	f	small
36845	30403	1632	Воронежская область, Калачеевский район, поселок Скрипниково, Ленина, 39	f	small
36329	30009	721	Воронежская область, Калачеевский район, поселок Семеновка, Свердлова, 28	f	small
36821	30401	1630	Воронежская область, Калачеевский район, поселок Семеновка, Ленина, 45	f	medium
36832	30388	1617	Воронежская область, Калачеевский район, поселок Пришиб, Щербакова, 16	f	large
36824	30398	1627	Воронежская область, Калачеевский район, поселок Пригородный, Космонавтов, 24	f	large
36833	30397	1626	Воронежская область, Калачеевский район, поселок Пригородный, Космонавтов, 46	f	large
36826	30392	1621	Воронежская область, Калачеевский район, поселок Попасное, Октябрьская, 82	f	small
36822	30402	1631	Воронежская область, Калачеевский район, поселок Пирогово, Красный Флот, 18	f	small
36848	30407	1636	Воронежская область, Калачеевский район, поселок Перевалочное, Первомайская, 2	f	small
36818	30384	1613	Воронежская область, Калачеевский район, поселок Отдел N1 совозах Забродненский, Кирова, 63	f	large
36815	30381	1610	Воронежская область, Калачеевский район, поселок Отдел N1 совозах Забродненский, Заброденская, 46	f	large
36825	30391	1620	Воронежская область, Калачеевский район, поселок Новомеловатка, Ленина, 31 А	f	large
36843	30394	1623	Воронежская область, Калачеевский район, поселок Новая Криуша, советская, 76	f	large
36830	30400	1629	Воронежская область, Калачеевский район, поселок Медвежье, Победы, 19	f	small
36838	30390	1619	Воронежская область, Калачеевский район, поселок Манино, Щербинина площадь, 2	f	medium
36837	30389	1618	Воронежская область, Калачеевский район, поселок Манино, Федота Щербинина, 22	f	large
36847	30406	1635	Воронежская область, Калачеевский район, поселок Лесково, Садовая, 3	f	medium
36842	30387	1616	Воронежская область, Калачеевский район, поселок Коренное, Школьная, 3	f	medium
36819	30385	1614	Воронежская область, Калачеевский район, поселок Калачеевский, Ленина, 21	f	medium
36812	30379	1608	Воронежская область, Калачеевский район, Калач, Селянская, 55	f	large
68086	30375	1604	Воронежская область, Калачеевский район, Калач, Северная, 52	f	large
68085	30373	1602	Воронежская область, Калачеевский район, Калач, Луначарского, 6	f	large
36805	30372	1601	Воронежская область, Калачеевский район, Калач, Ленина площадь, 1	f	large
36807	30374	1603	Воронежская область, Калачеевский район, Калач, Коммунистическая, 11	f	large
36809	30376	1605	Воронежская область, Калачеевский район, Калач, 1 Мая, 86	f	large
36840	95191	1625	Воронежская область, Калачеевский район, поселок Ильинка, Первомайская, 47	f	small
36813	30380	1609	Воронежская область, Калачеевский район, поселок Залесный, Центральная, 17 А	f	small
36817	30383	1612	Воронежская область, Калачеевский район, село Заброды, Магистральная, 1	f	large
36801	30368	1536	Воронежская область, Грибановский район, поселок Хомутовка, Садовая, 3	f	small
36796	30363	1531	Воронежская область, Грибановский район, поселок Тихвинка, Степная, 9	f	small
36790	30357	1525	Воронежская область, Грибановский район, поселок Старогольское, Центральная, 17	f	small
36784	30351	1519	Воронежская область, Грибановский район, поселок Средний Карачан, Мира, 12	f	medium
36787	30354	1522	Воронежская область, Грибановский район, поселок Савельевский, Центральная, 46	f	small
36780	30347	1515	Воронежская область, Грибановский район, поселок Посевкино, Максима Горького, 1	f	small
36794	30361	1529	Воронежская область, Грибановский район, село Поляна, Школьная, 60	f	small
36799	30366	1534	Воронежская область, Грибановский район, поселок Новомакарово, Советская, 56	f	medium
36789	30356	1524	Воронежская область, Грибановский район, поселок Новогольско, Советская, 69	f	small
36800	30367	1535	Воронежская область, Грибановский район, поселок Новоголь-Елань, Октябрьская, 39а	f	medium
36087	29768	138	Воронежская область, Грибановский район, поселок Новая Жизнь, Центральная, 17а	f	small
36785	30352	1520	Воронежская область, Грибановский район, поселок Нижний Карачан, Ленинская, 2	f	large
36776	30343	1511	Воронежская область, Грибановский район, поселок Малые Алабухи 2-е, Свободы, 2	f	small
36775	30342	1510	Воронежская область, Грибановский район, поселок Малые Алабухи 1-е, Первомайская, 1	f	medium
36774	30341	1509	Воронежская область, Грибановский район, поселок Малая Грибановка, Советская, 6	f	medium
36791	30358	1526	Воронежская область, Грибановский район, поселок Листопадовка, Пионерская, 2	f	large
36793	30360	1528	Воронежская область, Грибановский район, поселок Листопадовка, Глотова, 13	f	medium
36795	30362	1530	Воронежская область, Грибановский район, поселок Лавровка, Центральная, 16	f	small
36797	30364	1532	Воронежская область, Грибановский район, поселок Кутки, Административная, 7	f	small
36792	30359	1527	Воронежская область, Грибановский район, поселок Красовка, Заречная, 98	f	small
36798	30365	1533	Воронежская область, Грибановский район, поселок Краснореченка, Ленинская, 3	f	small
36782	30349	1517	Воронежская область, Грибановский район, поселок Кирсановка, Свободы, 2	f	medium
36766	30333	1501	Воронежская область, Грибановский район, поселок Грибановский, машзаводская, 8	f	large
36772	30339	1507	Воронежская область, Грибановский район, поселок Грибановский, Совхозная, 13	f	medium
36771	30338	1506	Воронежская область, Грибановский район, поселок Грибановский, Советская, 55	f	large
36769	30336	1504	Воронежская область, Грибановский район, поселок Грибановский, Сахзаводская, 18	f	large
36770	30337	1505	Воронежская область, Грибановский район, поселок Грибановский, Ленинская, 78	f	large
36768	30335	1503	Воронежская область, Грибановский район, поселок Грибановский, Красная Поляна, 24	f	large
86279	30345	1513	Воронежская область, Грибановский район, поселок Власовка, Пролетарская, 61	f	small
36783	30350	1518	Воронежская область, Грибановский район, поселок Верхний Карачан, площадь революции, 1	f	large
36777	30344	1512	Воронежская область, Грибановский район, поселок Болшие Алабухи, площадь Революции, 10/2	f	medium
37529	31077	3502	Воронежская область, Воронежская область, Семилуки, 25 лет Октября, 24	f	large
36361	30041	822	Воронежская область, Воробьевский район, поселок Солонцы, Садовая, 41	f	medium
36351	30031	812	Воронежская область, Воробьевский район, поселок Совхоз Краснопольский, Садовая, 1	f	medium
36347	30027	808	Воронежская область, Воробьевский район, поселок Совхоз Воробьевский, Садовая, 14 А	f	medium
36358	30038	819	Воронежская область, Воробьевский район, поселок Рудня, 40 лет Октября, 66	f	medium
37307	30856	2818	Воронежская область, Воробьевский район, поселок Первомайский, Центральная, 2А	f	small
36349	30029	810	Воронежская область, Воробьевский район, поселок Первомайский, Первомайская, 19	f	small
109479	31241	3910	Воронежская область, Воробьевский район, поселок Первомайский, Памяти, 6	f	medium
36359	30039	820	Воронежская область, Воробьевский район, поселок Новотулучеево, Пролетарская, 57	f	medium
36357	30037	818	Воронежская область, Воробьевский район, поселок Никольское, Школьная площадь, 3	f	small
36356	30036	817	Воронежская область, Воробьевский район, поселок Никольское, Советская, 27	f	small
36355	30035	816	Воронежская область, Воробьевский район, поселок Никольское, Борцов Революции площадь, 3	f	small
36344	30024	805	Воронежская область, Воробьевский район, поселок Нижний Бык, Горького, 15	f	small
36353	30033	814	Воронежская область, Воробьевский район, поселок Мужичье, Школьный второй переулок, 4	f	medium
36352	30032	813	Воронежская область, Воробьевский район, поселок Лещаное, Первомайская, 35	f	medium
36350	30030	811	Воронежская область, Воробьевский район, поселок Краснополье, 50 лет Октября, 6	f	medium
36348	30028	809	Воронежская область, Воробьевский район, поселок Квашино, Калинина, 2А	f	small
36362	30042	823	Воронежская область, Воробьевский район, поселок Каменка, комсомольская, 10	t	small
36360	30040	821	Воронежская область, Воробьевский район, поселок Затон, Кирова, 121	f	medium
36342	30022	803	Воронежская область, Воробьевский район, поселок Елизаветовка, Октябрьская, 18	f	small
36363	30043	824	Воронежская область, Воробьевский район, поселок Гринев, Кирова, 36	t	small
36993	30548	2048	Воронежская область, Воробьевский район, поселок Высокое, Советская, 33	f	medium
36992	30549	2049	Воронежская область, Воробьевский район, поселок Высокое, Полевая, 2б	f	medium
36346	30026	807	Воронежская область, Воробьевский район, поселок Воробьевка, Чкалова, 3А	f	large
36345	30025	806	Воронежская область, Воробьевский район, поселок Воробьевка, Калинина, 24 Б	f	large
36343	30023	804	Воронежская область, Воробьевский район, поселок Верхний Бык, Ленина, 5	f	small
36341	30021	802	Воронежская область, Воробьевский район, поселок Верхнетолучеево, Свободы, 47	f	small
36340	30020	801	Воронежская область, Воробьевский район, поселок Березовка, Центральная, 11	f	large
36354	30034	815	Воронежская область, Воробьевский район, поселок Банное, Ленина, 26	f	small
36336	30016	728	Воронежская область, Верхнехавский район, поселок Шукавка, Мира, 49	f	medium
36339	30019	731	Воронежская область, Верхнехавский район, поселок Углянец, ломоносова, 167г	f	large
36337	30017	729	Воронежская область, Верхнехавский район, поселок Углянец, ломоносова, 167в	f	large
36334	94923	726	Воронежская область, Верхнехавский район, поселок Сухие Гаи, Ленина, 5г, здание МКОУ Сухогаевская СОШ	f	small
36332	30012	724	Воронежская область, Верхнехавский район, поселок Правая Хава, Леваневского, 23	f	medium
37230	30781	2644	Воронежская область, Верхнехавский район, поселок Покровка, Молодежная, 37	f	large
36338	30018	730	Воронежская область, Верхнехавский район, поселок Подлесный, Школьная, 1а	f	large
36313	29992	705	Воронежская область, Верхнехавский район, поселок Подлесный, Школьная, 1а	f	large
36328	30008	720	Воронежская область, Верхнехавский район, поселок Плясоватка, Заречная, 35	f	small
109440	30006	718	Воронежская область, Верхнехавский район, поселок Парижская Коммуна, Совхозная, 42	f	medium
36327	30007	719	Воронежская область, Верхнехавский район, поселок Никоново, Некрасова, 82	f	small
36315	29994	707	Воронежская область, Верхнехавский район, поселок Нижняя Маза, Комсомольская, 3а	f	small
36310	29989	702	Воронежская область, Верхнехавский район, поселок Нижняя Байгора, Московская, 28б	f	small
86278	30005	717	Воронежская область, Верхнехавский район, поселок Малый Самовец, Ленина, 41	f	small
36323	30002	715	Воронежская область, Верхнехавский район, поселок Малая Приваловка, Ленина, 41	f	small
36416	30082	953	Воронежская область, Верхнехавский район, поселок Краснолесный, Генерала Лохматикова, 13	f	large
36333	30013	725	Воронежская область, Верхнехавский район, поселок Вишневка, Комарова, 61	f	large
36320	29999	712	Воронежская область, Верхнехавский район, поселок Верхняя Хава, Школьная, 1	f	large
36319	29998	711	Воронежская область, Верхнехавский район, поселок Верхняя Хава, Октябрьская, 22	f	large
36330	30010	722	Воронежская область, Верхнехавский район, поселок Верхняя Хава, Ленина, 13	f	large
36317	29996	709	Воронежская область, Верхнехавский район, поселок Верхняя Хава, Ленина, 13	f	large
36318	29997	710	Воронежская область, Верхнехавский район, поселок Верхняя Хава, 50 лет Октября, 14	f	large
36316	29995	708	Воронежская область, Верхнехавский район, поселок Верхняя Плавица, Ленина, 56	f	small
36314	29993	706	Воронежская область, Верхнехавский район, поселок Верхняя Маза, 50 лет Октября, 25а	f	small
36331	30011	723	Воронежская область, Верхнехавский район, поселок Верхняя Луговатка, Харина, 30а	f	small
36311	29990	703	Воронежская область, Верхнехавский район, поселок Верхняя Байгора, 50 лет Октября, 74	f	small
36322	30001	714	Воронежская область, Верхнехавский район, поселок Васильевка 1-я, Кольцова, 43б	f	small
36312	29991	704	Воронежская область, Верхнехавский район, поселок Большая Приваловка, Гагарина, 1	f	medium
36321	30000	713	Воронежская область, Верхнехавский район, поселок Богословка, Гагарина, 5	f	small
36307	29986	618	Воронежская область, Верхнемамонский район, поселок Русская Журавка, Центральная, 165/1	f	large
36303	29982	614	Воронежская область, Верхнемамонский район, поселок Приречное, Ленина, 81	f	medium
36296	29975	607	Воронежская область, Верхнемамонский район, поселок Осетровка, Алпеева, 23	f	medium
36298	29977	609	Воронежская область, Верхнемамонский район, поселок Оробинский, Школьная, 1	t	small
36300	29979	611	Воронежская область, Верхнемамонский район, поселок Ольховатка, Дьячкова, 17	f	medium
36305	29984	616	Воронежская область, Верхнемамонский район, поселок Нижний Мамон, Ленина, 19	f	medium
36306	29985	617	Воронежская область, Верхнемамонский район, поселок Нижний Мамон, 50 лет Победы, 1А	f	medium
36304	29983	615	Воронежская область, Верхнемамонский район, поселок Нижний Мамон, 40 лет Победы, 7	f	large
36308	29987	619	Воронежская область, Верхнемамонский район, поселок Мамоновка, Первомайская, 1/1	f	small
36301	29980	612	Воронежская область, Верхнемамонский район, поселок Лозовое, Октябрьская, 69	f	medium
36302	29981	613	Воронежская область, Верхнемамонский район, поселок Лозовое, Авдеева, 6	f	medium
36297	29976	608	Воронежская область, Верхнемамонский район, поселок Дерезовка, Центральная, 111	f	medium
86342	31249	3918	Воронежская область, Верхнемамонский район, поселок Гороховка, Центральная, 5	f	small
36299	29978	610	Воронежская область, Верхнемамонский район, поселок Гороховка, Советская, 170	f	large
36295	29974	606	Воронежская область, Верхнемамонский район, поселок Верхний Мамон, Прогресс, 1	f	medium
36293	29972	604	Воронежская область, Верхнемамонский район, поселок Верхний Мамон, Правды, 21	f	medium
36290	29969	601	Воронежская область, Верхнемамонский район, поселок Верхний Мамон, Первомайская, 3/1	f	medium
36291	29970	602	Воронежская область, Верхнемамонский район, поселок Верхний Мамон, Братская Площадь, 2	f	large
36294	29973	605	Воронежская область, Верхнемамонский район, поселок Верхний Мамон, 60 лет октября, 11/1	f	large
36292	29971	603	Воронежская область, Верхнемамонский район, поселок Верхний Мамон, 22-го Партсъезда, 83	f	large
37406	30955	3133	Воронежская область, Бутурлиновский район, хут.Петропавловка	f	small
37377	30927	3105	Воронежская область, Бутурлиновский район, хут.Луговой	f	small
36166	29849	315	Воронежская область, Бутурлиновский район, х.Варваровка, 1-е Мая, 13	f	small
36834	30399	1628	Воронежская область, Бутурлиновский район, пос.Черноземный, Молодежная площадь, 2	f	small
36820	30386	1615	Воронежская область, Бутурлиновский район, пос.Колос, 40 лет Победы, 2	f	small
36288	29967	541	Воронежская область, Бутурлиновский район, поселок Чулок, Советская, 1	f	small
36284	29963	537	Воронежская область, Бутурлиновский район, поселок Филиппенково, Комарова, 14	f	medium
36289	29968	542	Воронежская область, Бутурлиновский район, поселок Совхоз Ударник, Ленина, 31а	f	small
36282	29961	535	Воронежская область, Бутурлиновский район, поселок Сериково, Советская, 51	f	small
36279	29958	532	Воронежская область, Бутурлиновский район, поселок Пузево, Пески, 99а	f	medium
36280	29959	533	Воронежская область, Бутурлиновский район, поселок Пузево, Ленина, 103	f	large
36285	29964	538	Воронежская область, Бутурлиновский район, поселок Патокино, Школьная, 34	f	small
37091	30642	2316	Воронежская область, Бутурлиновский район, поселок Отрадное, Советская, 41Д	f	large
37090	30641	2315	Воронежская область, Бутурлиновский район, поселок Отрадное, 50 Лет Октября, 26	f	large
109439	29956	531	Воронежская область, Бутурлиновский район, поселок Озерки, Октябрьская, 5	f	medium
36269	29947	522	Воронежская область, Бутурлиновский район, поселок Нижний Кисляй, Советская, 6	f	large
36270	29948	523	Воронежская область, Бутурлиновский район, поселок Нижний Кисляй, Заводская, 22	f	large
36283	29962	536	Воронежская область, Бутурлиновский район, поселок Макогоново, Зеленая, 2б	f	small
36277	29955	530	Воронежская область, Бутурлиновский район, поселок Кучеряевка, Ленина, 93	f	medium
86341	31245	3914	Воронежская область, Бутурлиновский район, поселок Комсомольский, Дальняя, 12	f	small
36274	29952	527	Воронежская область, Бутурлиновский район, поселок Козловка, Октябрьская, 21	f	large
36275	29953	528	Воронежская область, Бутурлиновский район, поселок Козловка, Дзержинского, 28	f	large
36272	29950	525	Воронежская область, Бутурлиновский район, поселок Клеповка, Советская, 80	f	medium
36273	29951	526	Воронежская область, Бутурлиновский район, поселок Клеповка, Ленинская, 100а	f	medium
109438	29949	524	Воронежская область, Бутурлиновский район, поселок Карайчевка, 50 лет Октября, 4	f	medium
36263	29941	516	Воронежская область, Бутурлиновский район, поселок Зеленый Гай, Набережная, 50	f	small
36264	29942	517	Воронежская область, Бутурлиновский район, поселок Зеленый, Ленина, 10	f	medium
36286	29965	539	Воронежская область, Бутурлиновский район, поселок Елизаветино, Советская, 62	f	small
36262	29940	515	Воронежская область, Бутурлиновский район, поселок Дмитриевка, Пролетарская, 17	f	small
36267	29945	520	Воронежская область, Бутурлиновский район, поселок Гвазда, Ленина, 79	f	medium
68069	29946	521	Воронежская область, Бутурлиновский район, поселок Гвазда, Ивана Бочарникова, 41	f	large
109437	29943	518	Воронежская область, Бутурлиновский район, поселок Великоархангельское, Октябрьская, 63	f	medium
36266	29944	519	Воронежская область, Бутурлиновский район, поселок Великоархангельское, Ленина, 48	f	small
36786	30353	1521	Воронежская область, Бутурлиновский район, поселок Васильевка, Советская, 2	f	small
36287	29966	540	Воронежская область, Бутурлиновский район, поселок Васильевка, Ленина, 46	f	medium
36250	29928	503	Воронежская область, Бутурлиновский район, Бутурлиновка, площадь Воли, 21	f	medium
36252	29930	505	Воронежская область, Бутурлиновский район, Бутурлиновка, пер. Связистов, 4	f	large
36257	29935	510	Воронежская область, Бутурлиновский район, Бутурлиновка, Чехова, 16	f	large
36258	29936	511	Воронежская область, Бутурлиновский район, Бутурлиновка, Победы, 76	f	large
36251	29929	504	Воронежская область, Бутурлиновский район, Бутурлиновка, Красная, 216	f	large
36248	29926	501	Воронежская область, Бутурлиновский район, Бутурлиновка, Кирова, 11	f	large
36253	29931	506	Воронежская область, Бутурлиновский район, Бутурлиновка, Блинова, 2	f	large
36234	29913	437	Воронежская область, Борисоглебский район, поселок Чигорак, Переулок Первомайский, 7	f	large
36235	29914	438	Воронежская область, Борисоглебский район, поселок Чигорак, Красная, 106	f	medium
36236	29915	439	Воронежская область, Борисоглебский район, поселок Ульяновка, Ворошилова, 36	f	medium
36245	29923	448	Воронежская область, Борисоглебский район, поселок Тюковка, Молодежная, 10	f	small
36243	29921	446	Воронежская область, Борисоглебский район, поселок Третьяки, Народная, 44	f	medium
36247	29925	450	Воронежская область, Борисоглебский район, поселок Танцырей, Московская, 4	f	medium
36244	29922	447	Воронежская область, Борисоглебский район, поселок Старая Воскресеновка, Борисоглебская, 3	f	small
36246	29924	449	Воронежская область, Борисоглебский район, поселок Петровское, Первомайская, 2	f	medium
36238	29916	441	Воронежская область, Борисоглебский район, поселок Миролюбие, Свободы, 7	f	medium
36239	29917	442	Воронежская область, Борисоглебский район, поселок Махровка, Свободы, 1	f	small
36241	29919	444	Воронежская область, Борисоглебский район, поселок Макашевка, Коммуны, 3	f	medium
36240	29918	443	Воронежская область, Борисоглебский район, поселок Губари, Советская, 128	f	medium
36242	29920	445	Воронежская область, Борисоглебский район, поселок Горелка, Советская, 87	f	small
36237	29593	440	Воронежская область, Борисоглебский район, поселок Богана, Советская, 259	f	medium
36167	29850	316	Воронежская область, Богучарский район, поселок Шуриновка, Октябрьская, 31	f	small
36197	29879	346	Воронежская область, Богучарский район, поселок Филоново, Молодёжная, 38	f	small
86276	29872	339	Воронежская область, Богучарский район, поселок Травкино, Парковая, 7	f	small
86273	29843	310	Воронежская область, Богучарский район, поселок Терешково, Ленина, 16а	f	small
32852	26728	492	Владимирская область, Владимир, микрорайон Оргтруд, школа № 47	f	\N
36194	29876	343	Воронежская область, Богучарский район, поселок Твердохлебовка, Калинина, 62	f	medium
36192	29874	341	Воронежская область, Богучарский район, поселок Сухой Донец, Советская, 1	f	medium
36182	29864	331	Воронежская область, Богучарский район, поселок Старотолучеево, Героя Бондарева, 21	f	small
36171	29854	320	Воронежская область, Богучарский район, поселок Совхоз Южный, Садовая, 19	f	small
36196	29878	345	Воронежская область, Богучарский район, поселок Свобода, Центральная, 21а	t	small
109436	29871	338	Воронежская область, Богучарский район, поселок Радченское, Воробьева, 65	f	medium
36186	29868	335	Воронежская область, Богучарский район, поселок Поповка, Калинина, 67а	f	small
37644	31189	3721	Воронежская область, Богучарский район, поселок Поповка, Крупской, 25	f	small
36160	29841	309	Воронежская область, Богучарский район, поселок Полтавка, Мира, 60	f	small
36179	29862	328	Воронежская область, Богучарский район, поселок Плесновка, Советская, 14	f	small
36195	29877	344	Воронежская область, Богучарский район, поселок Перещепное, Садовая, 15а	f	small
36193	29875	342	Воронежская область, Богучарский район, поселок Отдел N1 совхоза Вишневый, Школьная, 10	f	small
36177	29860	326	Воронежская область, Богучарский район, поселок Новоникольск, Кирова, д.5а	t	small
36175	29858	324	Воронежская область, Богучарский район, поселок Монастырщина, Центральная, 22	f	medium
36174	29857	323	Воронежская область, Богучарский район, поселок Медово, Низовая, 2а	t	small
36173	29856	322	Воронежская область, Богучарский район, поселок Малеваный, Российская, 3	f	small
36168	29851	317	Воронежская область, Богучарский район, поселок Луговое, Мира, 18	f	medium
36185	29867	334	Воронежская область, Богучарский район, поселок Лофицкое, Ленина, 65	f	medium
36165	29848	314	Воронежская область, Богучарский район, поселок Липчанка, Кирова, 62	f	medium
36178	29861	327	Воронежская область, Богучарский район, поселок Лебединка, Первомайская, 10	f	medium
36184	29866	333	Воронежская область, Богучарский район, поселок Купянка, Октябрьская, 1а	f	medium
86272	29840	308	Воронежская область, Богучарский район, поселок Красногоровка, Западная, 11	f	small
36172	29855	321	Воронежская область, Богучарский район, поселок Каразеево	t	small
36164	29847	313	Воронежская область, Богучарский район, поселок Залиман, Малаховского, 51б	f	large
36886	30450	1814	Воронежская область, Богучарский район, поселок Журавка, Пролетарская, 29	f	small
36180	29535	329	Воронежская область, Богучарский район, поселок Журавка, Ленина, 15	f	small
36187	29869	336	Воронежская область, Богучарский район, поселок Дядин, переулок Рабочий, 15	f	small
68067	29839	307	Воронежская область, Богучарский район, поселок Дьяченково, Школьная, 33	f	large
109435	29852	318	Воронежская область, Богучарский район, поселок Данцевка, Центральная, 14Б	f	medium
36163	29846	312	Воронежская область, Богучарский район, поселок Грушовое, Центральная, 3а	f	small
36162	29845	311	Воронежская область, Богучарский район, поселок Галиевка, 1-е Мая, 11	f	small
36183	29865	332	Воронежская область, Богучарский район, поселок Вервековка, Пролетарская, 174	f	small
36176	29859	325	Воронежская область, Богучарский район, поселок Ботовка, Авиаторов, 11/2	t	small
36152	29834	301	Воронежская область, Богучарский район, Богучар, урицкого, 1	f	large
68066	29838	306	Воронежская область, Богучарский район, Богучар, военный городок, 60	f	large
68065	29838	305	Воронежская область, Богучарский район, Богучар, военный городок, 60	f	large
36155	29837	304	Воронежская область, Богучарский район, Богучар, Советская, 56	f	large
36153	29835	302	Воронежская область, Богучарский район, Богучар, Карла Маркса, 2	f	large
86277	29873	340	Воронежская область, Богучарский район, поселок Белая Горка 1-я, Коммунаров, 3	f	small
36144	29826	239	Воронежская область, Бобровский район, поселок Ясенки, Свободы, 1б	f	large
36148	29830	243	Воронежская область, Бобровский район, поселок Ясенки, Микрорайон Юбилейный, 1а	f	medium
36132	29814	227	Воронежская область, Бобровский район, поселок Юдановка, Советская, 2	f	medium
36139	29821	234	Воронежская область, Бобровский район, поселок Шишовка, Большая Советская, 163	f	medium
36120	29802	215	Воронежская область, Бобровский район, поселок Шестаково, Чибисовка, 14	f	medium
109434	29801	214	Воронежская область, Бобровский район, поселок Шестаково, Советская, 42	f	medium
36138	29820	233	Воронежская область, Бобровский район, поселок Чесменка, Советская, 66	f	medium
36134	29816	229	Воронежская область, Бобровский район, поселок Хреновое, пушкина, 147	f	large
36137	29819	232	Воронежская область, Бобровский район, поселок Хреновое, Сахарного завода, 9	f	medium
36135	29817	230	Воронежская область, Бобровский район, поселок Хреновое, Базарная площадь, 13а	f	large
36136	29818	231	Воронежская область, Бобровский район, поселок Хреновое, 40 лет Октября, 55а	f	medium
36127	29809	222	Воронежская область, Бобровский район, поселок Тройня, Гагарина, 123	f	small
36131	29813	226	Воронежская область, Бобровский район, поселок Сухая Березовка, карла маркса, 65	f	medium
36129	29811	224	Воронежская область, Бобровский район, поселок Слобода, Рубежная, 10	f	large
36149	29831	244	Воронежская область, Бобровский район, поселок Слобода, Ленина, 36	f	medium
36128	29810	223	Воронежская область, Бобровский район, поселок Слобода, Большая, 44	f	large
36126	29808	221	Воронежская область, Бобровский район, поселок Семено-Александровка, Проспект Революции, 126б	f	large
37002	30558	2058	Воронежская область, Бобровский район, поселок Пятилетка 2-я, Центральная, 7, Дом культуры	f	medium
36117	29799	212	Воронежская область, Бобровский район, поселок Пчелиновка, Школьная, 1	f	medium
36133	29815	228	Воронежская область, Бобровский район, поселок Песковатка, Центральная, 40	f	small
86280	30346	1514	Воронежская область, Бобровский район, поселок Павловка, Строительная, 2 А	f	small
36125	29807	220	Воронежская область, Бобровский район, поселок Новый Буравль, 51	t	small
36143	29825	238	Воронежская область, Бобровский район, поселок Никольское 2-е, Школьная, 1а	f	medium
36118	29800	213	Воронежская область, Бобровский район, поселок Николо-Варваринка, Микрорайон, 7	f	medium
36141	29823	236	Воронежская область, Бобровский район, поселок Нескучный, 29	f	small
36893	30457	1821	Томская область, Асиновский район, село Митрофановка	f	large
36122	29804	217	Воронежская область, Бобровский район, поселок Митрофановка, Молодежная, 51а	t	small
36123	29805	218	Воронежская область, Бобровский район, поселок Мечетка, Ленинская, 75	f	medium
36116	29798	211	Воронежская область, Бобровский район, поселок Липовка, Мира, 6	f	medium
36124	29806	219	Воронежская область, Бобровский район, поселок Красный, Центральная, 72	f	small
36130	29812	225	Воронежская область, Бобровский район, поселок Коршево, советская, 142а	f	large
36140	29822	235	Воронежская область, Бобровский район, поселок Верхний Икорец, Центральная, 7	f	medium
36142	29824	237	Воронежская область, Бобровский район, поселок Верхний Икорец, Ранняя Весна, 44/2	f	small
36108	29789	203	Воронежская область, Бобровский район, Бобров, Центральная, 4	f	medium
36109	29790	204	Воронежская область, Бобровский район, Бобров, Красная печать, 22	f	large
36106	29787	201	Воронежская область, Бобровский район, Бобров, Комсомольская, 1	f	large
36107	29788	202	Воронежская область, Бобровский район, Бобров, Кирова, 57	f	large
36147	29829	242	Воронежская область, Бобровский район, Бобров, Калинина, 268	f	large
36112	29793	207	Воронежская область, Бобровский район, Бобров, Зои Космодемьянской, 150	f	large
68064	29797	210	Воронежская область, Бобровский район, Бобров, Гоголя, 49	f	large
36145	29827	240	Воронежская область, Бобровский район, Бобров, 3 Интернационала, 25	f	large
36146	29828	241	Воронежская область, Бобровский район, Бобров, 22 января, 17	f	large
36110	29791	205	Воронежская область, Бобровский район, Бобров, 22 января, 17	f	large
36111	29792	206	Воронежская область, Бобровский район, Бобров, 22 Января, 136	f	large
36121	29803	216	Воронежская область, Бобровский район, поселок Анновка, Советская, 95б	f	small
36105	29786	156	Воронежская область, Аннинский район, поселок Хлебородное, Советская, 3	f	medium
36092	29773	143	Воронежская область, Аннинский район, поселок Суровский, Лесная, 98	f	small
36079	29760	130	Воронежская область, Аннинский район, поселок Студеное, Советская, 14	f	small
36085	29766	136	Воронежская область, Аннинский район, поселок Старый Курлак, Ленина, 4	f	small
36104	29785	155	Воронежская область, Аннинский район, поселок Старая Чигла, Труда, 121	f	small
81443	55818	605	Москва, Псковская, 12к3	f	large
36103	29784	154	Воронежская область, Аннинский район, поселок Старая Чигла, Ленина, 1	f	small
36102	29783	153	Воронежская область, Аннинский район, поселок Старая Тойда, Октябрьская, 13а	f	medium
36101	29782	152	Воронежская область, Аннинский район, поселок Садовое, Мира, 81	f	medium
36099	29780	150	Воронежская область, Аннинский район, поселок Садовое, Малая Советская, 39	f	large
36100	29781	151	Воронежская область, Аннинский район, поселок Садовое, Красная Площадь, 47	f	medium
36098	29779	149	Воронежская область, Аннинский район, поселок Садовое, Красная Площадь, 41	f	medium
36076	29757	127	Воронежская область, Аннинский район, поселок Сабуровка, Молодежная, 40	t	small
36096	29777	147	Воронежская область, Аннинский район, поселок Рубашевка, Советская, 24	f	medium
36080	29761	131	Воронежская область, Аннинский район, поселок Романовка, Школьная, 2	t	small
36095	29776	146	Воронежская область, Аннинский район, поселок Рамонье, Центральная, 24	f	medium
36094	29775	145	Воронежская область, Аннинский район, поселок Пугачевский, паркова, 2	f	medium
36090	29771	141	Омская область, Исилькульский район, поселок Петровка	t	small
36091	29772	142	Воронежская область, Аннинский район, поселок Островки, Ленинская, 47Б	f	medium
36084	29765	135	Воронежская область, Аннинский район, поселок Новый Курлак, Ленина, 23	f	small
36070	29750	121	Воронежская область, Аннинский район, поселок Новонадеждинский, Плошадь Мира, 10	f	medium
36083	29764	134	Воронежская область, Аннинский район, поселок Никольское, 50 лет Октября, 59	f	medium
36081	29762	132	Воронежская область, Аннинский район, поселок Николаевка, Юбилейная, 31	f	medium
36078	29759	129	Воронежская область, Аннинский район, поселок Нащекино, Школьная, 2	f	small
36086	29767	137	Воронежская область, Аннинский район, поселок Моховое, Советская, 21	f	small
36075	29755	126	Воронежская область, Аннинский район, поселок Мосоловка, Центральная, 1а	f	small
36072	29752	123	Воронежская область, Аннинский район, поселок Левашевка, Школьная, Здание правления СХА Левашевка	f	small
36082	29763	133	Воронежская область, Аннинский район, поселок Круглоподпольное, Школьная, 23	f	small
36093	29774	144	Воронежская область, Аннинский район, поселок Кругловский, Школьная, 67а	f	small
36074	29754	125	Воронежская область, Аннинский район, поселок Красный Лог, Коммунальная, 19	f	small
86271	29758	128	Воронежская область, Аннинский район, поселок Желанное, Коммунистическая, 86	f	small
36073	29753	124	Воронежская область, Аннинский район, поселок Дерябкино, Центральная площадь, 1	f	small
36089	29770	140	Воронежская область, Аннинский район, поселок Гусевка, Центральная, 10	f	small
109433	29751	122	Воронежская область, Аннинский район, поселок Верхняя Тойда, Ленина, 19а	f	medium
36068	29748	119	Воронежская область, Аннинский район, поселок Васильевка, Молодежная, 13	f	small
36067	29747	118	Воронежская область, Аннинский район, поселок Бродовое, школьная, 12	f	large
36063	29743	114	Воронежская область, Аннинский район, поселок Большая Алексеевка, Центральная, 1	t	small
37298	30847	2809	Воронежская область, Аннинский район, поселок Болшие Ясырки, Садовая, 42	f	small
36097	29778	148	Воронежская область, Аннинский район, поселок Болшие Ясырки, Жданова, 11	f	medium
37088	30639	2313	Воронежская область, Аннинский район, поселок Бобяково, Совхозная, 72	f	medium
36065	29745	116	Воронежская область, Аннинский район, поселок Березовка, Советская, 9	f	medium
36061	29741	112	Воронежская область, Аннинский район, поселок Архангельское, Мира, 10а	f	large
36064	29744	115	Воронежская область, Аннинский район, поселок Артюшкино, Свободы, 19	f	small
36060	29740	111	Воронежская область, Аннинский район, поселок Анна, Чехова, 1А	f	large
36058	29738	109	Воронежская область, Аннинский район, поселок Анна, Фридриха Энгельса, 1А	f	large
36054	29631	105	Воронежская область, Аннинский район, поселок Анна, Советская, 17	f	large
68062	29737	108	Воронежская область, Аннинский район, поселок Анна, М.Горького, 40	f	large
36056	29487	107	Воронежская область, Аннинский район, поселок Анна, Ленина, 24	f	large
36052	29465	103	Воронежская область, Аннинский район, поселок Анна, Красноармейская, 199	f	large
36055	29645	106	Воронежская область, Аннинский район, поселок Анна, Коммунальная, 104	f	large
81662	55942	824	Москва, Проходчиков, 9	f	large
68063	29739	110	Воронежская область, Аннинский район, поселок Анна, Гнездилова, 18	f	large
68061	29545	104	Воронежская область, Аннинский район, поселок Анна, Ватутина, 186	f	large
36051	29352	102	Воронежская область, Аннинский район, поселок Анна, Ватутина, 37	f	large
37315	30864	2826	Воронежская область, Аннинский район, поселок Александровка, Школьная, 21	f	small
37257	30808	2717	Воронежская область, Аннинский район, поселок Александровка, Первомайская, 3	f	large
37212	30763	2626	Воронежская область, Алексеевский район, поселок Верхний Ольшан, Ольшанская, 18	f	small
32556	26481	176	Владимирская область, п. Сушнево-2, Административное здание	f	small
32964	26825	614	Владимирская область, поселок имени Воровского, Воровского, 24	f	large
32630	26554	257	Владимирская область, Юрьев-Польский, Шибанкова, 46	f	large
32632	26556	259	Владимирская область, Юрьев-Польский, Авангардский переулок, 1	f	large
32705	26625	338	Владимирская область, Суздаль, Ленина, 50	f	large
32456	26387	58	Владимирская область, Струнино, Клубный переулок, 1	f	large
32618	26544	241	Владимирская область, Собинка, Чайковского, 3а	f	large
32617	26544	240	Владимирская область, Собинка, Чайковского, 3а	f	large
32623	26548	246	Владимирская область, Собинка, Центральная площадь, 6	f	large
32613	26540	236	Владимирская область, Собинка, Ленина, 5	f	large
32616	26543	239	Владимирская область, Собинка, Димитрова, 24а	f	large
32615	26542	238	Владимирская область, Собинка, Димитрова, 7	f	large
32678	26600	311	Владимирская область, село Сновицы, Школьная, 1	f	large
32597	26524	219	Владимирская область, село Рукав, 2а, Здание администрации	f	small
32860	26733	500	Владимирская область, Радужный ЗАТО, 3 квартал, 36	f	large
32859	26732	499	Владимирская область, Радужный ЗАТО, 1 квартал, 56	f	large
32861	26641	501	Владимирская область, Радужный ЗАТО, 1 квартал, 41	f	large
32858	26641	498	Владимирская область, Радужный ЗАТО, 1 квартал, 41	f	large
32857	26730	497	Владимирская область, Радужный, 1 квартал, 51	f	large
32651	26575	278	Владимирская область, Пригородный, 44	f	small
32569	26494	189	Владимирская область, Покров, Пролетарская, 1А	f	large
32531	26453	151	Владимирская область, Петушки, Советская площадь, 3	f	large
131617	26457	155	Владимирская область, Петушки, Полевой проезд, 4	f	large
32534	26456	154	Владимирская область, Петушки, Ленина, 96	f	medium
32540	26463	160	Владимирская область, Петушки, Клязьменская, 2	f	medium
33360	27182	1045	Владимирская область, Муром, Тихомирова, 15	f	large
33362	27184	1047	Владимирская область, Муром, Привокзальная площадь им. Гастелло, 5, Ж/Д вокзал	f	\N
33359	27181	1044	Владимирская область, Муром, Московская, 110, МОУ СО Школа № 20	f	\N
33198	27036	862	Владимирская область, Муром, Мичуринская, 2	f	large
33247	27075	911	Владимирская область, Муром, Ленинградская, 13	f	large
33249	27075	913	Владимирская область, Муром, Ленинградская, 13	f	large
33244	27073	908	Владимирская область, Муром, Ленинградская, 28	f	large
33251	27038	915	Владимирская область, Муром, Красногвардейская, 40А	f	large
33200	27038	864	Владимирская область, Муром, Красногвардейская, 40А	f	large
33207	27044	871	Владимирская область, Муром, Комсомольская, 55	f	large
33210	27047	874	Владимирская область, Муром, Воровского, 103	f	large
33305	27129	974	Владимирская область, Меленки, Королева, 2А	f	large
33310	27134	979	Владимирская область, Меленки, Дзержинского, 28	f	large
32506	26435	120	Владимирская область, Кольчугино, Шмелева, 3	f	large
32510	26437	124	Владимирская область, Кольчугино, Мира, 4	f	large
32508	26437	122	Владимирская область, Кольчугино, Мира, 4	f	large
32502	26432	116	Владимирская область, Кольчугино, Ленина, 17	f	large
32500	26431	114	Владимирская область, Кольчугино, Дружбы, 14	f	large
32499	26414	113	Владимирская область, Кольчугино, Дружбы, 13	f	large
33062	26918	714	Владимирская область, Ковров, чернышевского, 8	f	large
33063	26918	715	Владимирская область, Ковров, чернышевского, 8	f	large
33049	26910	701	Владимирская область, Ковров, свердлова, 13	f	large
33064	26919	716	Владимирская область, Ковров, проспект Ленина, 59	f	large
33058	26916	710	Владимирская область, Ковров, подлесная, 1	f	large
68059	26923	724	Владимирская область, Ковров, моховая, 1/2, школа №8	f	large
68058	26923	723	Владимирская область, Ковров, моховая, 1/2, школа №8	f	large
33048	26909	700	Владимирская область, Ковров, микрорайон Заречная Слободка, Школа № 12	f	medium
33043	26904	695	Владимирская область, Ковров, Элеваторная, 1	f	medium
33095	26942	747	Владимирская область, Ковров, Шмидта, 48	f	large
33093	26940	745	Владимирская область, Ковров, Циолковского, 26	f	large
33051	26843	703	Владимирская область, Ковров, Труда, 6	f	large
33077	26926	729	Владимирская область, Ковров, Строителей, 20к.1	f	large
33057	26914	709	Владимирская область, Ковров, Сосновая, 13, корп. А	f	large
33054	26914	706	Владимирская область, Ковров, Сосновая, 13, корп. А	f	large
33056	26915	708	Владимирская область, Ковров, Пионерская, 8	f	large
33055	26915	707	Владимирская область, Ковров, Пионерская, 8	f	large
33052	26912	704	Владимирская область, Ковров, Первомайская, 32	f	large
33102	26949	754	Владимирская область, Ковров, Октябрьская, 10 , железнодорожный вокзал г. Коврова	f	\N
33053	26913	705	Владимирская область, Ковров, Муромская, 5	f	large
33081	26929	733	Владимирская область, Ковров, Московская, 10	f	large
33097	26944	749	Владимирская область, Ковров, Малеева, 2, КМКТС	f	medium
33096	26943	748	Владимирская область, Ковров, Лопатина, 4	f	large
33094	26941	746	Владимирская область, Ковров, Лопатина, 44, к А	f	large
33092	26939	744	Владимирская область, Ковров, Лопатина, 55	f	large
33070	26922	722	Владимирская область, Ковров, Кошевого, 1 к4	f	large
33061	26917	713	Владимирская область, Ковров, Колхозная, 30	f	large
33060	26917	712	Владимирская область, Ковров, Колхозная, 30	f	large
33059	26917	711	Владимирская область, Ковров, Колхозная, 30	f	large
33042	26903	694	Владимирская область, Ковров, Ковров-8, Гарнизонный Дом Офицеров	f	large
33041	26903	693	Владимирская область, Ковров, Ковров-8, Гарнизонный Дом Офицеров	f	large
33040	26902	692	Владимирская область, Ковров, Клязьминская, 14	f	large
33073	26924	725	Владимирская область, Ковров, Зои Космодемьянской, 2/1	f	large
33075	26924	727	Владимирская область, Ковров, Зои Космодемьянской, 2/1	f	large
33074	26924	726	Владимирская область, Ковров, Зои Космодемьянской, 2/1	f	large
33086	26934	738	Владимирская область, Ковров, Запольная, 7	f	large
33085	26933	737	Владимирская область, Ковров, Запольная, 37	f	large
33084	26932	736	Владимирская область, Ковров, Жуковского, 5	f	large
33080	26928	732	Владимирская область, Ковров, Еловая, 5	f	large
33076	26925	728	Владимирская область, Ковров, Еловая, 19	f	small
33046	26907	698	Владимирская область, Ковров, Дегтярева, 65	f	large
33045	26906	697	Владимирская область, Ковров, Дегтярева, 192	f	large
33044	26905	696	Владимирская область, Ковров, Дегтярева, 192	f	large
33069	26921	721	Владимирская область, Ковров, Грибоедова, 76	f	large
33066	26920	718	Владимирская область, Ковров, Грибоедова, 9В	f	large
33065	26920	717	Владимирская область, Ковров, Грибоедова, 9В	f	large
33067	26896	719	Владимирская область, Ковров, Грибоедова, 24	f	large
33068	26896	720	Владимирская область, Ковров, Грибоедова, 24	f	large
33091	26938	743	Владимирская область, Ковров, Волго-Донская, 9А	f	large
33090	26937	742	Владимирская область, Ковров, Волго-Донская, 1Б	f	large
33089	26936	741	Владимирская область, Ковров, Волго-Донская, 1 А	f	large
33088	26936	740	Владимирская область, Ковров, Волго-Донская, 1 А	f	large
33083	26930	735	Владимирская область, Ковров, Владимирская, 53 А	f	large
33082	26930	734	Владимирская область, Ковров, Владимирская, 53 А	f	large
33039	26901	691	Владимирская область, Ковров, Белинского, 4А	f	large
33050	26911	702	Владимирская область, Ковров, Абельмана, 15	f	large
33047	26908	699	Владимирская область, Ковров, Абельмана, 75	f	large
33087	26935	739	Владимирская область, Ковров, 19 Партсъезда, 8	f	large
33079	26927	731	Владимирская область, Ковров, Строителей, 7	f	large
33078	26927	730	Владимирская область, Ковров, Строителей, 7	f	large
68048	26423	104	Владимирская область, Киржач, Пушкина, 27, средняя школа № 6, 1й этаж, холл	f	large
32459	26391	72	Владимирская область, Киржач, Гагарина, 25	f	small
32467	26347	80	Владимирская область, Киржач, 50 лет октября, 14	f	large
32451	26360	53	Владимирская область, Карабаново, Мира, 11	f	large
32450	26382	52	Владимирская область, Карабаново, Лермонтова, 15	f	large
32449	26382	51	Владимирская область, Карабаново, Лермонтова, 15	f	large
33367	27186	1091	Владимирская область, Камешково, Ленина, 1, Муниципальное учреждение культуры районный Дом культуры 13 Октябрь	f	\N
32977	26838	628	Владимирская область, Камешково, Ленина, 2	f	large
32976	26837	627	Владимирская область, Камешково, Ленина, 1	f	large
32803	26698	443	Владимирская область, поселок Заклязьменский, Центральная, 11а	f	large
32913	26775	560	Владимирская область, Гусь-Хрустальный, торфяная, 9	f	large
32912	26775	559	Владимирская область, Гусь-Хрустальный, торфяная, 9	f	large
32910	26773	557	Владимирская область, Гусь-Хрустальный, проспект 50-летия Советской власти, 13	f	large
32915	26778	563	Владимирская область, Гусь-Хрустальный, писарева, 17	f	medium
68045	26776	561	Владимирская область, Гусь-Хрустальный, Торфяная, 9, средняя школа №4	f	large
32934	26793	581	Владимирская область, Гусь-Хрустальный, Рылеева, 3, средняя школа № 3	f	\N
32909	26772	556	Владимирская область, Гусь-Хрустальный, Мира, 2	f	large
32908	26772	555	Владимирская область, Гусь-Хрустальный, Мира, 2	f	large
32907	26772	554	Владимирская область, Гусь-Хрустальный, Мира, 2	f	large
68049	26789	578	Владимирская область, Гусь-Хрустальный, Микрорайон, 53, средняя школа № 2	f	large
32927	26788	577	Владимирская область, Гусь-Хрустальный, Микрорайон, 53	f	large
32926	26788	576	Владимирская область, Гусь-Хрустальный, Микрорайон, 53	f	large
32914	26777	562	Владимирская область, Гусь-Хрустальный, Менжинского, 2	f	large
32933	26791	580	Владимирская область, Гусь-Хрустальный, Менделеева, 20, средняя школа № 1	f	\N
32928	26790	579	Владимирская область, Гусь-Хрустальный, Менделеева, 20	f	large
32911	26774	558	Владимирская область, Гусь-Хрустальный, Лесная, 18	f	large
32917	26780	565	Владимирская область, Гусь-Хрустальный, Курская, 18а	f	large
32916	26779	564	Владимирская область, Гусь-Хрустальный, Кирова, 4	f	large
32925	26787	575	Владимирская область, Гусь-Хрустальный, Интернациональная, 49	f	large
32924	26787	574	Владимирская область, Гусь-Хрустальный, Интернациональная, 49	f	large
32922	26784	571	Владимирская область, Гусь-Хрустальный, Интернациональная, 11	f	large
68047	26786	573	Владимирская область, Гусь-Хрустальный, Димитрова, 17, школа № 9	f	large
32923	26785	572	Владимирская область, Гусь-Хрустальный, Димитрова, 38	f	large
32918	26781	567	Владимирская область, Гусь-Хрустальный, Александра Невского, 39а	f	large
32919	26781	566	Владимирская область, Гусь-Хрустальный, Александра Невского, 39а	f	large
32920	26782	569	Владимирская область, Гусь-Хрустальный, 2-я Народная, 5	f	large
32921	26782	568	Владимирская область, Гусь-Хрустальный, 2-я Народная, 5	f	large
68046	26783	570	Владимирская область, Гусь-Хрустальный, 2-ая Народная, 5, школа №7	f	large
33173	27012	830	Владимирская область, Гороховец, Ленина, 64, здание МОУ СОШ № 1	f	\N
33179	27018	836	Владимирская область, Гороховец, Гагарина, 30	f	large
33120	26963	772	Владимирская область, Вязники, Физкультурная, 12	f	large
33111	26954	763	Владимирская область, Вязники, Советский переулок, 6/9	f	large
33119	26962	771	Владимирская область, Вязники, Ленина, 48	f	large
33122	26965	774	Владимирская область, Вязники, Железнодорожная, 11	f	large
33107	26950	759	Владимирская область, Вязники, Горького, 102	f	large
32851	26727	491	Владимирская область, Владимир, помещение территориального сектора мкр. Лесной	f	\N
32806	26700	446	Владимирская область, Владимир, Дом культуры	f	small
32755	26634	392	Владимирская область, Владимир, Ленинский район, улица Завадского, 7	f	large
32718	26634	355	Владимирская область, Владимир, Ленинский район, улица Завадского, 7	f	large
32717	26634	354	Владимирская область, Владимир, Ленинский район, улица Завадского, 7	f	large
32818	26708	458	Россия, Владимирская область, Владимир, Фрунзенский район, улица Добросельская, 194а	f	\N
33261	27086	925	Ярославская область, Гаврилов-Ямский район, поселок Петроково	f	small
32778	26680	418	Владимирская область, Владимир, Октябрьский район, улица Горького, 83	f	large
32807	26701	447	Россия, Владимирская область, Владимир, Октябрьский район, улица Вокзальная, 12а	f	\N
32768	26671	407	Владимирская область, Владимир, проспект Строителей, 44в	f	large
32767	26671	406	Владимирская область, Владимир, проспект Строителей, 44в	f	large
32853	26728	493	Владимирская область, Владимир, микрорайон Оргтруд, школа № 47	f	\N
32831	26716	471	Владимирская область, Владимир, Юбилейная, 56, СДЮСШОР № 2 по шахматам	f	\N
32824	26712	464	Владимирская область, Владимир, Юбилейная, 11, химико-механический колледж	f	\N
32743	26655	380	Владимирская область, Владимир, Энергетиков, 1	f	large
32742	26655	379	Владимирская область, Владимир, Энергетиков, 1	f	large
32802	26697	442	Владимирская область, Владимир, Школьная, 1	f	large
32801	26697	441	Владимирская область, Владимир, Школьная, 1	f	large
32746	26657	383	Владимирская область, Владимир, Школьная, 10	f	small
32770	26673	409	Владимирская область, Владимир, Чернышевского, 76	f	large
32713	26631	350	Владимирская область, Владимир, Чайковского, 25	f	large
32750	26660	387	Владимирская область, Владимир, Центральная, 40	f	small
32791	26691	431	Владимирская область, Владимир, Усти-На-Лабе, 28	f	large
32753	26662	390	Владимирская область, Владимир, Университетская, 1	f	large
32776	26678	416	Владимирская область, Владимир, Тракторная, 1а	f	large
32761	26667	398	Владимирская область, Владимир, Тихонравова, 1, ВЗФЭИ	f	\N
32759	26666	396	Владимирская область, Владимир, Тихонравова, 1	f	large
32825	26713	465	Владимирская область, Владимир, Суздальский проспект , 11, детская школа искусств № 3	f	\N
32780	26682	420	Владимирская область, Владимир, Студенческая, 10а	f	large
32773	26675	413	Владимирская область, Владимир, Ленинский район, Строителей проспект, 2б	f	large
32772	26674	411	Владимирская область, Владимир, Ленинский район, Строителей проспект, 10а	f	large
32771	26674	410	Владимирская область, Владимир, Ленинский район, Строителей проспект, 10а	f	large
32710	26629	347	Владимирская область, Владимир, Ленинский район, Строителей проспект, 11	f	large
32842	26722	482	Владимирская область, Владимир, Соколова-Соколенка, 18а, школа № 10	f	\N
32841	26722	481	Владимирская область, Владимир, Соколова-Соколенка, 18а, школа № 10	f	\N
32840	26722	480	Владимирская область, Владимир, Соколова-Соколенка, 18а, школа № 10	f	\N
32821	26711	461	Владимирская область, Владимир, Соколова-Соколенка, 7Б, школа 38	f	\N
32822	26711	462	Владимирская область, Владимир, Соколова-Соколенка, 7Б, школа 38	f	\N
32823	26711	463	Владимирская область, Владимир, Соколова-Соколенка, 7Б, школа 38	f	\N
32816	26706	456	Владимирская область, Владимир, Северная, 2а, АНО Центр организации культурного досуга Артдворец	f	\N
32817	26707	457	Владимирская область, Владимир, Северная, 2А, АНО Центр организации культурного досуга Артдворец	f	\N
32835	26718	475	Владимирская область, Владимир, Растопчина, 31А, школа № 5	f	\N
32834	26718	474	Владимирская область, Владимир, Растопчина, 31А, школа № 5	f	\N
32731	26644	368	Владимирская область, Владимир, Разина, 2а	f	large
32790	26690	430	Владимирская область, Владимир, Полины Осипенко, 33а	f	large
32793	26689	433	Владимирская область, Владимир, Полины Осипенко, 6	f	large
32789	26689	429	Владимирская область, Владимир, Полины Осипенко, 6	f	large
32788	26688	428	Владимирская область, Владимир, Полины Осипенко, 13	f	large
32757	26665	394	Владимирская область, Владимир, Парижской Коммуны, 45а	f	large
32728	26642	365	Владимирская область, Владимир, Парижской Коммуны, 45б	f	large
32729	26642	366	Владимирская область, Владимир, Парижской Коммуны, 45б	f	large
32727	26640	364	Владимирская область, Владимир, Парижской Коммуны, 45а	f	large
32737	26649	374	Владимирская область, Владимир, Октябрьский проспект, 11	f	large
32741	26653	378	Владимирская область, Владимир, Ноябрьская, 3	f	large
32726	26639	363	Владимирская область, Владимир, Нижняя Дуброва, 28а	f	large
32725	26639	362	Владимирская область, Владимир, Нижняя Дуброва, 28а	f	large
32724	26638	361	Владимирская область, Владимир, Нижняя Дуброва, 28а, школа № 39	f	\N
32605	26532	228	Владимирская область, Владимир, Молодежная, 15	f	large
32595	26521	217	Владимирская область, Владимир, Молодежная, 19	f	large
32815	26705	455	Владимирская область, Владимир, Мира, 55, Дом культуры молодежи	f	\N
32814	26704	454	Владимирская область, Владимир, Мира, 55, Дом культуры молодежи	f	\N
32785	26686	425	Владимирская область, Владимир, Мира, 31	f	large
32747	26658	384	Владимирская область, Владимир, Мира, 8	f	large
32805	26699	445	Владимирская область, Владимир, Луневская, 1а	f	small
32786	26687	426	Владимирская область, Владимир, Луначарского, 15	f	large
32784	26685	424	Владимирская область, Владимир, Луначарского, 1	f	large
32735	26646	372	Владимирская область, Владимир, Ленинский район, Ленина проспект, 8	f	large
32733	26646	370	Владимирская область, Владимир, Ленинский район, Ленина проспект, 8	f	large
32760	26646	397	Владимирская область, Владимир, Ленинский район, Ленина проспект, 8	f	large
32716	26633	353	Владимирская область, Владимир, Ленинский район, Ленина проспект, 53	f	large
32769	26672	408	Владимирская область, Владимир, Лакина, 139	f	large
32766	26670	405	Владимирская область, Владимир, Лакина, 183	f	large
32765	26670	404	Владимирская область, Владимир, Лакина, 183	f	large
32850	26726	490	Владимирская область, Владимир, Куйбышева, 56, школа №20	f	\N
32849	26726	489	Владимирская область, Владимир, Куйбышева, 56, школа №20	f	\N
32848	26726	488	Владимирская область, Владимир, Куйбышева, 56, школа №20	f	\N
32847	26726	487	Владимирская область, Владимир, Куйбышева, 56, школа №20	f	\N
32712	26630	349	Владимирская область, Владимир, Красноармейская, 40	f	large
32711	26630	348	Владимирская область, Владимир, Красноармейская, 40	f	large
32837	26720	477	Владимирская область, Владимир, Комиссарова, 39, гимназия № 35	f	\N
32836	26719	476	Владимирская область, Владимир, Комиссарова, 39, гимназия № 35	f	\N
32839	26721	479	Владимирская область, Владимир, Комиссарова, 27, школа № 34	f	\N
32838	26721	478	Владимирская область, Владимир, Комиссарова, 27, школа № 34	f	\N
32621	26547	244	Владимирская область, Владимир, Кирова, 2	f	large
32622	26547	245	Владимирская область, Владимир, Кирова, 2	f	large
32783	26684	423	Владимирская область, Владимир, Кирова, 15	f	large
68054	26692	432	Владимирская область, Владимир, Каманина, 16, школа №29	f	large
32745	26652	382	Владимирская область, Владимир, Юрьевец поселок, Институтский городок, 20	f	large
32740	26652	377	Владимирская область, Владимир, Юрьевец поселок, Институтский городок, 20	f	large
32739	26651	376	Владимирская область, Владимир, Юрьевец поселок, Институтский городок, 7	f	large
32752	26661	389	Владимирская область, Владимир, Институтский городок, 7, школа № 44	f	\N
32820	26710	460	Владимирская область, Владимир, Жуковского, 14, школа № 13	f	\N
32819	26709	459	Владимирская область, Владимир, Жуковского, 14, школа 13 	f	\N
32832	26717	472	Владимирская область, Владимир, Добросельская, 205А, школа № 28	f	\N
32833	26717	473	Владимирская область, Владимир, Добросельская, 205А, школа № 28	f	\N
32828	26715	468	Владимирская область, Владимир, Добросельская, 179А, школа № 36	f	\N
32830	26715	470	Владимирская область, Владимир, Добросельская, 179А, школа № 36	f	\N
32829	26715	469	Владимирская область, Владимир, Добросельская, 179А, школа № 36	f	\N
32827	26715	467	Владимирская область, Владимир, Добросельская, 179А, школа № 36	f	\N
32730	26643	367	Владимирская область, Владимир, Диктора Левитана, 37а, школа № 43	f	large
32748	26659	385	Владимирская область, Владимир, Диктора Левитана, 37а, школа № 43	f	large
32732	26645	369	Владимирская область, Владимир, Диктора Левитана, 4	f	large
32762	26668	399	Владимирская область, Владимир, Дворянская, 1, школа № 1	f	\N
32736	26648	373	Владимирская область, Владимир, Дворянская, 1	f	large
32734	26647	371	Владимирская область, Владимир, Дворянская, 27, Владимирский авиамеханический колледж	f	\N
32782	26683	422	Владимирская область, Владимир, Горького, 54	f	large
32781	26683	421	Владимирская область, Владимир, Горького, 54	f	large
32779	26681	419	Владимирская область, Владимир, Горького, 77б	f	large
32777	26679	417	Владимирская область, Владимир, Горького, 97	f	large
32775	26677	415	Владимирская область, Владимир, Горького, 7а	f	large
32774	26676	414	Владимирская область, Владимир, Горького, 107а	f	large
32794	26693	434	Владимирская область, Владимир, Герцена, 35	f	large
68055	26695	438	Владимирская область, Владимир, Герцена, 35, школа №14	f	large
32756	26664	393	Владимирская область, Владимир, Верхняя Дуброва, 2а, школа № 32	f	\N
32744	26656	381	Владимирская область, Владимир, Верхняя Дуброва, 32б	f	large
32758	26656	395	Владимирская область, Владимир, Верхняя Дуброва, 32б	f	large
32723	26637	360	Владимирская область, Владимир, Верхняя Дуброва, 32б	f	large
32721	26635	358	Владимирская область, Владимир, Верхняя Дуброва, 2а	f	large
32720	26635	357	Владимирская область, Владимир, Верхняя Дуброва, 2а	f	large
32719	26635	356	Владимирская область, Владимир, Верхняя Дуброва, 2а	f	large
32722	26636	359	Владимирская область, Владимир, Василисина, 22б	f	large
32751	26636	388	Владимирская область, Владимир, Василисина, 22б	f	large
32796	26694	436	Владимирская область, Владимир, Большая Московская улица, 33	f	large
32845	26725	485	Владимирская область, Владимир, Безыменского, 14б, школа № 40	f	\N
32846	26725	486	Владимирская область, Владимир, Безыменского, 14б, школа № 40	f	\N
32844	26724	484	Владимирская область, Владимир, Безыменского, 14б, школа № 40	f	\N
32843	26723	483	Владимирская область, Владимир, Безыменского, 14б, школа № 40	f	\N
32764	26669	403	Владимирская область, Владимир, Балакирева, 41	f	large
32763	26669	402	Владимирская область, Владимир, Балакирева, 41	f	large
32754	26663	391	Владимирская область, Владимир, Балакирева, 32	f	large
32749	26632	386	Владимирская область, Владимир, Балакирева, 21	f	large
32715	26632	352	Владимирская область, Владимир, Балакирева, 21	f	large
32714	26632	351	Владимирская область, Владимир, Балакирева, 21	f	large
32826	26714	466	Владимирская область, Владимир, Соколова-Соколенка, 6г, детская школа искусств № 6	f	\N
32404	26337	6	Владимирская область, Александров, Советская, 3, муниципальное бюджетное учреждение культуры Социально-культурный центр	f	large
32420	26352	22	Владимирская область, Александров, Маяковского, 50	f	large
32415	26348	17	Владимирская область, Александров, Ленина, 24	f	large
32408	26340	10	Владимирская область, Александров, Королева, 6	f	large
32636	26560	263	Владимирская область, Юрьев-Польский район, Юрьев-Польский, перфильева, 69	f	medium
32633	26557	260	Владимирская область, Юрьев-Польский район, Юрьев-Польский, набережная, 20	f	large
32638	26562	265	Владимирская область, Юрьев-Польский район, Юрьев-Польский, Чехова, 15/Б	f	medium
32635	26559	262	Владимирская область, Юрьев-Польский район, Юрьев-Польский, Набережная, 80	f	large
32637	26561	264	Владимирская область, Юрьев-Польский район, Юрьев-Польский, Железнодорожная, 23	f	small
32629	26553	256	Владимирская область, Юрьев-Польский район, Юрьев-Польский, Горького, 5	f	large
32634	26558	261	Владимирская область, Юрьев-Польский район, Юрьев-Польский, Артиллерийская, 30	f	large
32631	26555	258	Владимирская область, Юрьев-Польский район, Юрьев-Польский, Авангардский переулок, 31	f	large
32628	26552	255	Владимирская область, Юрьев-Польский район, Юрьев-Польский, 1 Мая, 74	f	large
32645	26569	272	Владимирская область, Юрьев-Польский район, поселок Энтузиаст, жевлаковича, 9/А	f	medium
32659	26583	286	Владимирская область, Юрьев-Польский район, поселок Шихобалово, 79	f	medium
32650	26574	277	Владимирская область, Юрьев-Польский район, поселок Шипилово, 24	f	small
32660	26584	287	Владимирская область, Юрьев-Польский район, поселок Чеково, VII, 4	f	small
32648	26572	275	Владимирская область, Юрьев-Польский район, поселок Сосновый Бор, улица Школьная, 1	f	medium
32639	26563	266	Владимирская область, Юрьев-Польский район, поселок Сима, Советская, 47	f	large
32644	26568	271	Владимирская область, Юрьев-Польский район, поселок Сима, Богомолова, 41	f	small
32658	26582	285	Владимирская область, Юрьев-Польский район, поселок Семьинское, 13/А 	f	small
32646	26570	273	Владимирская область, Юрьев-Польский район, поселок Подолец, Школьная, 7	f	small
32684	26606	317	Владимирская область, Юрьев-Польский район, поселок Павловское, Школьная, 16	f	large
32653	26577	280	Владимирская область, Юрьев-Польский район, поселок Ополье, 41	f	medium
32661	26585	288	Владимирская область, Юрьев-Польский район, поселок Небылое, Первомайская, 2	f	large
32640	26564	267	Владимирская область, Юрьев-Польский район, поселок Матвейщево, Школьный переулок, 3	f	small
32642	26566	269	Владимирская область, Юрьев-Польский район, поселок Лучки, 45	f	small
32649	26573	276	Владимирская область, Юрьев-Польский район, поселок Кузьмадино	f	small
32665	26588	292	Владимирская область, Юрьев-Польский район, поселок Красное Заречье, 78/А	f	small
32700	26620	333	Владимирская область, Юрьев-Польский район, поселок Красное, Центральная, 58	f	small
32655	26579	282	Владимирская область, Юрьев-Польский район, поселок Косинское, Школьная, 1/А	f	medium
32668	26591	301	Владимирская область, Юрьев-Польский район, поселок Добрынское, Огурцова, 27	f	medium
32652	26576	279	Владимирская область, Юрьев-Польский район, поселок Городище, Школьная, 6	f	small
32656	26580	283	Владимирская область, Юрьев-Польский район, поселок Горки, Механическая, 11	f	medium
32643	26567	270	Владимирская область, Юрьев-Польский район, поселок Веска, 2	f	small
32701	26621	334	Владимирская область, Суздальский район, поселок Черниж, Центральная, 44	f	small
32683	26605	316	Владимирская область, Суздальский район, поселок Цибеево, центральная, 2	f	small
32663	26587	290	Владимирская область, Суздальский район, поселок Федоровское, 104	f	medium
32664	26587	291	Владимирская область, Суздальский район, поселок Федоровское, 104	f	small
32703	26623	336	Владимирская область, Суздальский район, поселок Туртино, совхозная, 1	f	small
109425	26622	335	Владимирская область, Суздальский район, поселок Торчино, Центральная, 47, школа	f	medium
32691	26612	324	Владимирская область, Суздальский район, поселок Суходол, Александрова, 33	f	small
32673	26595	306	Владимирская область, Суздальский район, поселок Суромна, Школьная, 11А	f	small
32704	26624	337	Владимирская область, Суздальский район, Суздаль, колхозная, 1	f	medium
32709	26628	342	Владимирская область, Суздальский район, Суздаль, Промышленная, 3	f	large
32706	26626	339	Владимирская область, Суздальский район, Суздаль, Лоунская, 7А	f	large
32707	26627	340	Владимирская область, Суздальский район, Суздаль, Красная площадь,, 5	f	large
32708	14662	341	Владимирская область, Суздальский район, Суздаль, Гоголя, 37	f	large
32682	26604	315	Владимирская область, Суздальский район, поселок Старый Двор, красная, 3	f	medium
32685	26607	318	Владимирская область, Суздальский район, поселок Спасское-Городище, Школьная, 24Б	f	small
32641	26565	268	Владимирская область, Суздальский район, поселок Спасское, Центральная, 29/А	f	small
32671	26539	304	Ярославская область, Ярославль, поселок Сокол, 1	f	large
32681	26603	314	Владимирская область, Суздальский район, поселок Содышка, Прибольничная, 10	f	medium
32689	26611	322	Владимирская область, Суздальский район, поселок Садовый, Центральная, 1а	f	large
32670	26593	303	Владимирская область, Суздальский район, поселок Раменье, Западная, 1Б	f	small
32686	26608	319	Владимирская область, Суздальский район, поселок Порецкое, Молодежная, 6	f	medium
32674	26596	307	Владимирская область, Суздальский район, поселок Ославское, Центральная, 24А	f	small
32697	26617	330	Владимирская область, Суздальский район, поселок Омутское, Молодежная, 3	f	small
32698	26618	331	Владимирская область, Суздальский район, поселок Новое Село, Центральная, 3	f	large
32672	26594	305	Владимирская область, Суздальский район, поселок Новое Село, Молодежная, 4А	f	large
32676	26598	309	Владимирская область, Суздальский район, поселок Новоалександрово, Школьная, 8	f	medium
32688	26610	321	Владимирская область, Суздальский район, поселок Мордыш, Центральная, 13	f	medium
32694	26615	327	Владимирская область, Суздальский район, поселок Ляховицы, центральная, 37	f	small
32669	26592	302	Владимирская область, Суздальский район, поселок Лемешки, Вокзальная, 1	f	small
32677	26599	310	Владимирская область, Суздальский район, поселок Кутуково, садовая, 9	f	small
32654	26578	281	Владимирская область, Суздальский район, поселок Красное, 72	f	medium
32693	26614	326	Владимирская область, Суздальский район, поселок Красногвардейский, Октябрьская, 1	f	large
32675	26597	308	Владимирская область, Суздальский район, поселок Клементьево, Новая, 1	f	medium
32680	26602	313	Владимирская область, Суздальский район, поселок Зелени, Полевая, 1, кв.2	f	small
32954	26815	604	Владимирская область, Суздальский район, поселок Гридино, Молодежная, 13	f	medium
32699	26619	332	Владимирская область, Суздальский район, поселок Глебовское, Западная, 1	f	small
32692	26613	325	Владимирская область, Суздальский район, поселок Гавриловское, Школьная, 32	f	medium
32696	26616	329	Владимирская область, Суздальский район, поселок Весь, Набережная, 5	f	medium
32687	26609	320	Владимирская область, Суздальский район, поселок Борисовское, большая дорога, 47	f	medium
32679	26601	312	Владимирская область, Суздальский район, поселок Богослово, Совхозная, 3	f	small
32666	26589	299	Владимирская область, Суздальский район, поселок Боголюбово, ленина, 26	f	large
32667	26590	300	Владимирская область, Суздальский район, поселок Боголюбово, Ленина, 48	f	large
32963	26824	613	Владимирская область, Судогодский район, поселок Чамерево, Судогодская, 14	f	medium
32955	26816	605	Владимирская область, Судогодский район, поселок Улыбышево, Школьная, 4	f	small
109428	26806	595	Владимирская область, Судогодский район, поселок Тюрмеровка, Муромская	f	medium
32942	26803	592	Владимирская область, Судогодский район, Судогда, Чапаева, 31	f	large
32941	26802	591	Владимирская область, Судогодский район, Судогда, Химиков, 2	f	large
32938	26799	588	Владимирская область, Судогодский район, Судогда, Ошмарина, 1	f	large
32937	26798	587	Владимирская область, Судогодский район, Судогда, Ленина, 44	f	large
32940	26801	590	Владимирская область, Судогодский район, Судогда, Коммунистическая, 1	f	large
32939	26800	589	Владимирская область, Судогодский район, Судогда, Халтурина, 66	f	large
109431	26977	788	Владимирская область, Судогодский район, поселок Станки, Рябиновая, 4, Станковская основная общеобразовательная школа	f	medium
32960	26821	610	Владимирская область, Судогодский район, поселок Сойма, Лесная, 33	f	small
32972	26833	622	Владимирская область, Судогодский район, поселок Передел, Северная, 22	f	small
32524	26448	138	Владимирская область, Судогодский район, поселок Павловка, Вторая, 9	f	small
32961	26822	611	Владимирская область, Судогодский район, поселок Овцино, Центральная, 13	f	small
32958	26819	608	Московская область, Солнечногорский район, деревня Овсянниково	f	small
32951	26812	601	Владимирская область, Судогодский район, поселок Новопетрово, Школьная, 2	f	small
32971	26832	621	Владимирская область, Судогодский район, поселок Муромцево, Шкурина, 17	f	large
32970	26831	620	Владимирская область, Судогодский район, поселок Муромцево, Школьная, 15	f	large
32965	26826	615	Владимирская область, Судогодский район, поселок Мошок, Заводская, 4	f	large
32967	26828	617	Владимирская область, Судогодский район, поселок Красный Куст, советская, 24	f	small
32946	26807	596	Владимирская область, Судогодский район, поселок Красный Богатырь, парковая, 22	f	medium
32966	26827	616	Владимирская область, Судогодский район, поселок Кондряево, Колхозная, 19	f	small
32948	26809	598	Владимирская область, Судогодский район, поселок Картмазово, Полевая, 1А	f	small
32883	26753	524	Владимирская область, Судогодский район, поселок Ильино, Школьная, 5	f	medium
32973	26834	623	Владимирская область, Судогодский район, поселок Дворишнево, 18А	f	small
32968	26829	618	Владимирская область, Судогодский район, поселок Гонобилово, Центральная, 29	f	small
68056	26818	607	Владимирская область, Судогодский район, поселок Головино, Юбилейная, 1а	f	large
32956	26817	606	Владимирская область, Судогодский район, поселок Головино, Советская, 54А	f	large
32952	26813	602	Владимирская область, Судогодский район, поселок Вяткино, Докучаева	f	large
32975	26836	625	Владимирская область, Судогодский район, поселок Вольная Артемовка	f	small
32969	26830	619	Владимирская область, Судогодский район, поселок Вежки, 6	f	small
32974	26835	624	Владимирская область, Судогодский район, поселок Бег, Спортивная, 21	f	medium
32953	26814	603	Владимирская область, Судогодский район, поселок Бараки, красноармейская, 1	f	medium
32944	26805	594	Владимирская область, Судогодский район, поселок Андреево, Первомайская, 15А	f	large
32943	26804	593	Владимирская область, Судогодский район, поселок Андреево, Красная Слобода, 15А	f	large
32609	26536	232	Владимирская область, Собинский район, поселок Черкутино, Первомайская, 40	f	medium
32611	26538	234	Владимирская область, Собинский район, поселок Фетинино, Суворова, 26	f	small
33264	27089	928	Владимирская область, Собинский район, поселок Степаньково, Школьная, 2А	f	small
32604	26531	226	Владимирская область, Собинский район, поселок Ставрово, Школьная,, 6	f	large
32602	26529	224	Владимирская область, Собинский район, поселок Ставрово, Советская, 22	f	large
32612	26473	235	Владимирская область, Собинский район, Собинка, Ленина, 32	f	large
32619	26545	242	Владимирская область, Собинский район, Собинка, Красная звезда, 16	f	large
32614	26541	237	Владимирская область, Собинский район, Собинка, Димитрова, 8	f	large
32607	26534	230	Владимирская область, Собинский район, поселок Рождествено, Порошина, 10	f	medium
33214	27050	878	Владимирская область, Муромский район, Муром, Ленина, 18	f	large
32880	26731	521	Владимирская область, Собинский район, поселок Никулино, Зеленая, 8	f	small
32624	26549	247	Владимирская область, Собинский район, Лакинск, Центральная площадь, 6, городской Дом культуры	f	large
32620	26546	243	Владимирская область, Собинский район, Лакинск, Карла Маркса, 5	f	large
32599	26526	221	Владимирская область, Собинский район, поселок Курилово, Юбилейная, 40	f	medium
32593	26519	214	Владимирская область, Собинский район, поселок Копнино, Молодежная, 18	f	small
131620	26523	218	Владимирская область, Собинский район, поселок Колокша, Советская, 20 а	f	medium
32610	26537	233	Владимирская область, Собинский район, поселок Кишлеево, Строителей, 19а	f	small
32594	26520	215	Владимирская область, Собинский район, поселок Заречное, Парковая, 14	f	large
32608	26535	231	Владимирская область, Собинский район, поселок Ельтесуново, Первомайская, 4	f	small
32866	26738	507	Владимирская область, Собинский район, поселок Демидово, Зелёная, 46	f	medium
32601	26528	223	Владимирская область, Собинский район, поселок Глухово, Новая, 7	f	small
32592	26518	213	Владимирская область, Собинский район, поселок Вышманово, Сысоевская, 2	f	small
32606	26533	229	Владимирская область, Собинский район, поселок Волосово, Мичуринская, 9а	f	small
32600	26527	222	Владимирская область, Собинский район, поселок Васильевка, Механизаторов, 19	f	medium
32590	26516	211	Владимирская область, Собинский район, поселок Березники, Владимирская, 1а	f	medium
32598	26525	220	Владимирская область, Собинский район, поселок Бабаево, Полевая, 10а	f	medium
32591	26517	212	Владимирская область, Собинский район, поселок Асерхово, Лесной проспект, 3А	f	medium
33297	27122	962	Владимирская область, Селивановский район, поселок Чертково, Советская, 47-а	f	small
33283	27107	948	Владимирская область, Селивановский район, поселок Переложниково, Свободы, 17, МОУ детский сад №19	f	small
33290	27115	955	Владимирская область, Селивановский район, поселок Первомайский, Школьная, 9	f	small
33293	27118	958	Владимирская область, Селивановский район, поселок Новый Быт, Молодежная, 1	f	large
68050	27105	946	Владимирская область, Селивановский район, поселок Новлянка, совхозная, 16	f	large
33282	27106	947	Владимирская область, Селивановский район, поселок Новлянка, Совхозная, 16	f	medium
32890	26760	531	Владимирская область, Селивановский район, поселок Неклюдово, Школьная, 2	f	small
33296	27121	961	Владимирская область, Селивановский район, поселок Надеждино, школьная, 7	f	small
33284	27108	949	Владимирская область, Селивановский район, поселок Малышево, ленина, 2	f	medium
33286	27110	951	Владимирская область, Селивановский район, поселок Красная Ушна, заводская, 10	f	medium
33300	27125	965	Владимирская область, Селивановский район, поселок Красная Горбатка, красноармейская, 21	f	large
33302	27127	967	Владимирская область, Селивановский район, поселок Красная Горбатка, Школьная, 41	f	large
33299	27124	964	Владимирская область, Селивановский район, поселок Красная Горбатка, Пролетарская, 4	f	large
33298	27123	963	Владимирская область, Селивановский район, поселок Красная Горбатка, Пролетарская, 3	f	large
33301	27126	966	Владимирская область, Селивановский район, поселок Красная Горбатка, Механизаторов, 24	f	large
33289	27114	954	Владимирская область, Селивановский район, поселок Кочергино, Центральная, 68	f	small
33285	27109	950	Владимирская область, Селивановский район, поселок Костенец	f	small
33292	27117	957	Владимирская область, Селивановский район, поселок Копнино, молодежная, 12	f	small
33294	27119	959	Владимирская область, Селивановский район, поселок Ильинское, 2	f	small
33291	27116	956	Владимирская область, Селивановский район, поселок Ивановское, Центральная, 96	f	small
33287	27111	952	Владимирская область, Селивановский район, поселок Драчево, кирпичная, 2	f	medium
33288	27113	953	Владимирская область, Селивановский район, поселок Губино, Школьная, 1	f	medium
33280	27104	945	Владимирская область, Селивановский район, поселок Высоково, Зеленая, 1	f	medium
33295	27120	960	Владимирская область, Селивановский район, поселок Вощиха, 34	f	small
32856	26729	496	Владимирская область, Радужный ЗАТО, ЗАТО город Радужный, 1 квартал, 40	f	large
32555	26480	175	Владимирская область, Петушинский район, п. Сушнево-1, Здание детского сада	f	small
32551	26476	171	Владимирская область, Петушинский район, поселок Труд, профсоюзная, 3	f	medium
32542	26466	162	Владимирская область, Петушинский район, поселок Старые Петушки, Шоссейная, 156А	f	medium
32544	26468	164	Владимирская область, Петушинский район, поселок Старые Омутищи, Артельная, 4А	f	small
131619	26506	201	Владимирская область, Петушинский район, поселок Старое Перепечино, Вокзальная, 1	f	small
32585	26511	206	Владимирская область, Петушинский район, поселок Санинского ДОКа, клубная, 4	f	medium
32570	26495	190	Владимирская область, Петушинский район, Покров, советская, 40	f	large
32572	26497	192	Владимирская область, Петушинский район, Покров, Советская, 21А	f	large
32567	26492	187	Владимирская область, Петушинский район, Покров, Ленина, 107	f	large
32568	26493	188	Владимирская область, Петушинский район, Покров, Больничный проезд, 2	f	large
32573	26498	193	Владимирская область, Петушинский район, Покров, 3 Интернационала, 52	f	large
32571	26496	191	Владимирская область, Петушинский район, Покров, 3 Интернационала, 39	f	large
32545	26469	165	Владимирская область, Петушинский район, Петушки, поселок Березка, б/н, Клуб	f	small
32538	26461	158	Владимирская область, Петушинский район, Петушки, пушкина, 2	f	medium
32539	26462	159	Владимирская область, Петушинский район, Петушки, покровка, 2	f	medium
131618	26464	161	Владимирская область, Петушинский район, Петушки, ленина, 4А	f	small
32530	26452	150	Владимирская область, Петушинский район, Петушки, Школьная, 2	f	large
32537	26460	157	Владимирская область, Петушинский район, Петушки, Чкалова, 12	f	large
32533	26455	153	Владимирская область, Петушинский район, Петушки, Профсоюзная, 6	f	small
32536	26459	156	Владимирская область, Петушинский район, Петушки, Московская, 22А	f	large
32532	26454	152	Владимирская область, Петушинский район, Петушки, Кирова, 2	f	medium
32588	26514	209	Владимирская область, Петушинский район, Петушки, Вокзальная, 42, Железнодорожный вокзал г. Петушки	f	\N
32552	26477	172	Владимирская область, Петушинский район, поселок Пекша, центральная, 8	f	medium
32558	26483	178	Владимирская область, Петушинский район, поселок Пахомово, Начальная школа, 50	f	small
32584	26510	205	Владимирская область, Петушинский район, поселок Панфилово, Верхняя, 4	f	small
32546	26470	166	Владимирская область, Петушинский район, поселок Новое Аннино, центральная, 14	f	medium
32950	26811	600	Владимирская область, Петушинский район, поселок Новая, Муромская, здание ФАП	f	small
32554	26479	174	Владимирская область, Петушинский район, поселок Метенино, Центральная, 15	f	small
32582	26508	202	Владимирская область, Петушинский район, поселок Марково, Советская, 25	f	small
32550	26475	170	Владимирская область, Петушинский район, поселок Липна, Сельский Дом культуры, 127А	f	medium
86264	26482	177	Владимирская область, Петушинский район, поселок Ларионово, Совхозная, 2, СДК	f	small
32548	26472	168	Владимирская область, Петушинский район, поселок Крутово, 61, Библиотека	f	small
32547	26471	167	Владимирская область, Петушинский район, поселок Костино, Спортивная, 6	f	medium
32566	26491	186	Владимирская область, Петушинский район, Костерево-1, Средняя школа № 3	f	large
32564	26489	184	Владимирская область, Петушинский район, поселок Костерево, южная, 8	f	large
32561	26486	181	Владимирская область, Петушинский район, поселок Костерево, писцова, 26	f	large
32563	26488	183	Владимирская область, Петушинский район, поселок Костерево, пионерская, 7	f	large
32562	26487	182	Владимирская область, Петушинский район, поселок Костерево, Заречная, Контора лесозаготовительного участка	f	medium
32565	26490	185	Владимирская область, Петушинский район, поселок Костерево, Горького, 2	f	large
32543	26467	163	Владимирская область, Петушинский район, поселок Кибирево, им. Н.К. Погодина, 55А	f	small
32560	26485	180	Владимирская область, Петушинский район, поселок Караваево, Каргополова, 28	f	small
32586	26512	207	Владимирская область, Петушинский район, поселок Городищи, Ленина, 4	f	large
32587	26513	208	Владимирская область, Петушинский район, поселок Городищи, К. Соловьева, 4	f	large
32583	26509	204	Владимирская область, Петушинский район, поселок Головино, 1, Сельский Дом культуры	f	small
32579	26504	199	Владимирская область, Петушинский район, поселок Глубоково, Школьная, 20	f	small
32549	26474	169	Владимирская область, Петушинский район, поселок Воспушка, круглова, 1А	f	medium
32576	26501	196	Владимирская область, Петушинский район, поселок Вольгинский, старовская, 23	f	large
32575	26500	195	Владимирская область, Петушинский район, поселок Вольгинский, Старовская, 9	f	large
32574	26499	194	Владимирская область, Петушинский район, поселок Введенский, Детский сад № 6	f	small
32553	26478	173	Владимирская область, Петушинский район, поселок Болдино, Лесхозная, 6	f	small
32559	26484	179	Владимирская область, Петушинский район, поселок Анкудиново, Арханинская, 48	f	small
33219	27054	883	Владимирская область, Муромский район, поселок Якиманская Слобода, Клубная, 1	f	large
33263	27088	927	Владимирская область, Муромский район, поселок Чаадаево, муромская, 43А	f	medium
33255	27080	919	Владимирская область, Муромский район, поселок Татарово, Мира, 40	f	small
33257	27082	921	Владимирская область, Муромский район, поселок Талызино, сельская, 6	f	small
33274	27098	938	Владимирская область, Муромский район, поселок Стригино, Первая, 54	f	small
33277	27101	941	Владимирская область, Муромский район, поселок Старое Ратово, совхозная, 68А	f	small
33270	27076	934	Владимирская область, Муромский район, поселок Саксино, Заречная, 35	f	small
33259	27084	923	Владимирская область, Муромский район, поселок Прудищи, Молодежная, 2	f	small
33254	27079	918	Владимирская область, Муромский район, поселок Польцо, Юбилейная, 2	f	small
33272	27096	936	Владимирская область, Муромский район, поселок Пестенькино, центральная, 50	f	medium
33222	27057	886	Владимирская область, Муромский район, поселок Орлово, Дом Культуры 	f	medium
33223	27058	887	Владимирская область, Муромский район, поселок Муромский, Центральная, 37	f	medium
33199	27037	863	Владимирская область, Муромский район, Муром	f	large
33237	27068	901	Владимирская область, Муромский район, Муром, пионеров, 2	f	large
33195	27033	859	Владимирская область, Муромский район, Муром, орловская, 23/А	f	large
33241	27069	905	Владимирская область, Муромский район, Муром, московская, 126	f	large
33239	27069	903	Владимирская область, Муромский район, Муром, московская, 126	f	large
33238	27069	902	Владимирская область, Муромский район, Муром, московская, 126	f	large
33357	27180	1042	Владимирская область, Муромский район, Муром, лакина, 65	f	large
33230	27064	894	Владимирская область, Муромский район, Муром, куйбышева, 24/а	f	large
33226	27061	890	Владимирская область, Муромский район, Муром, Филатова, 8	f	large
33225	27060	889	Владимирская область, Муромский район, Муром, Привокзальная, 4	f	large
33201	27039	865	Владимирская область, Муромский район, Муром, Первомайская, 36	f	large
33197	27035	861	Владимирская область, Муромский район, Муром, Орловская, 16	f	large
33194	27032	858	Владимирская область, Муромский район, Муром, Орловская, 23	f	large
33245	27074	909	Владимирская область, Муромский район, Муром, Муромская, 15/А	f	large
33248	27074	912	Владимирская область, Муромский район, Муром, Муромская, 15/А	f	large
33246	27074	910	Владимирская область, Муромский район, Муром, Муромская, 15/А	f	large
33243	27072	907	Владимирская область, Муромский район, Муром, Муромская, 15А, МОУ СО Школа № 2	f	\N
33240	27070	904	Владимирская область, Муромский район, Муром, Московская, 126, МОУ СО Школа № 1	f	\N
33231	27063	895	Владимирская область, Муромский район, Муром, Московская, 110	f	large
33229	27063	893	Владимирская область, Муромский район, Муром, Московская, 110	f	large
33235	27062	899	Владимирская область, Муромский район, Муром, Московская, 91	f	large
33228	27062	892	Владимирская область, Муромский район, Муром, Московская, 91	f	large
33206	27043	870	Владимирская область, Муромский район, Муром, Мечникова, 20	f	large
33213	27049	877	Владимирская область, Муромский район, Муром, Льва Толстого, 23	f	large
33212	27049	876	Владимирская область, Муромский район, Муром, Льва Толстого, 23	f	large
33209	27046	873	Владимирская область, Муромский район, Муром, Льва Толстого, 40	f	large
33361	27183	1046	Владимирская область, Муромский район, Муром, Ленинградская, 6	f	large
33250	27077	914	Владимирская область, Муромский район, Муром, Ленинградская, 13, ДК «Вербовский»	f	\N
33215	27050	879	Владимирская область, Муромский район, Муром, Ленина, 18	f	large
81660	55940	822	Москва, Проходчиков, 12	f	large
33252	27040	916	Владимирская область, Муромский район, Муром, Ленина, 95	f	large
33202	27040	866	Владимирская область, Муромский район, Муром, Ленина, 95	f	large
33205	27042	869	Владимирская область, Муромский район, Муром, Лакина, 69	f	large
33190	27029	854	Владимирская область, Муромский район, Муром, Красина, 1	f	large
33233	27066	897	Владимирская область, Муромский район, Муром, Кооперативная, 7А, МОУ СО Школа № 8	f	\N
33234	27065	898	Владимирская область, Муромский район, Муром, Кооперативная, 7/А	f	large
33232	27065	896	Владимирская область, Муромский район, Муром, Кооперативная, 7/А	f	large
33204	27041	868	Владимирская область, Муромский район, Муром, Комсомольская, 60	f	large
33203	27041	867	Владимирская область, Муромский район, Муром, Комсомольская, 60	f	large
33218	27053	882	Владимирская область, Муромский район, Муром, Колхозная, 15	f	large
33358	27051	1043	Владимирская область, Муромский район, Муром, Колхозная, 35	f	large
33216	27051	880	Владимирская область, Муромский район, Муром, Колхозная, 35	f	large
33217	27052	881	Владимирская область, Муромский район, Муром, Ковровская, 18	f	large
33192	27031	856	Владимирская область, Муромский район, Муром, Кирова, 13, МОУ СО Школа № 10	f	\N
33191	27030	855	Владимирская область, Муромский район, Муром, Кирова, 13	f	large
33193	27030	857	Владимирская область, Муромский район, Муром, Кирова, 13	f	large
33211	27048	875	Владимирская область, Муромский район, Муром, Карла Маркса, 23	f	large
33196	27034	860	Владимирская область, Муромский район, Муром, Карачаровское шоссе, 9	f	large
33236	27067	900	Владимирская область, Муромский район, Муром, Гоголева, 1	f	large
33208	27045	872	Владимирская область, Муромский район, Муром, Артема, 39	f	large
33227	27059	891	Владимирская область, Муромский район, Муром, Амосова, 41	f	large
33224	27059	888	Владимирская область, Муромский район, Муром, Амосова, 41	f	large
33258	27083	922	Владимирская область, Муромский район, поселок Молотицы, гагарина, 24	f	medium
33278	27102	942	Владимирская область, Муромский район, поселок Мишино, Комсомольская, 71Б	f	small
33269	27094	933	Владимирская область, Муромский район, поселок Михалево, Кооперативная, 18	f	small
33265	27090	929	Владимирская область, Муромский район, поселок Межищи, Полевая, 45	f	small
33273	27097	937	Владимирская область, Муромский район, поселок Макаровка, Центральная, 10	f	small
32888	26758	529	Владимирская область, Муромский район, поселок Лесниково, Центральная, 43	f	small
33276	27100	940	Владимирская область, Муромский район, поселок Лазарево, Школьная, 9А	f	small
33256	27081	920	Владимирская область, Муромский район, поселок Кондраково, муромская, 13	f	small
33271	27095	935	Владимирская область, Муромский район, поселок Ковардицы, Школьная, 9	f	large
33221	27056	885	Владимирская область, Муромский район, поселок Имени Войкова, дом культуры	f	large
33275	27099	939	Владимирская область, Муромский район, поселок Иваньково, Школьная, 132	f	small
32889	26759	530	Владимирская область, Муромский район, поселок Иванищи, Молодёжная, 1	f	large
33220	27055	884	Владимирская область, Муромский район, поселок Дмитриева Слобода, Средняя школа	f	large
33266	27091	930	Владимирская область, Муромский район, поселок Булатниково, Мира, 1	f	medium
33253	27078	917	Владимирская область, Муромский район, поселок Боровицы, Приокская, 15	f	small
33260	27085	924	Владимирская область, Муромский район, поселок Борисоглеб, Коминтерна, 16	f	medium
33242	27071	906	Владимирская область, Муромский район, поселок Александровка, Библиотека	f	small
33351	27175	1020	Владимирская область, Меленковский район, поселок Усад, Центральная, 26	f	small
86263	27174	1019	Владимирская область, Меленковский район, поселок Урваново, Центральная, 76	f	small
33355	27179	1024	Владимирская область, Меленковский район, поселок Тургенево, Совхозная, 9	f	small
33326	27150	995	Владимирская область, Меленковский район, поселок Софроново, Молодежная, 1	f	medium
33319	27143	988	Владимирская область, Меленковский район, поселок Скрипино, новая, 1	f	small
33325	27149	994	Владимирская область, Меленковский район, поселок Синжаны, Комсомольская, 5	f	small
33353	27177	1022	Владимирская область, Меленковский район, поселок Селино, Советская, 44А	f	small
33268	27093	932	Владимирская область, Меленковский район, поселок Савково, Советская, 2	f	small
33330	27154	999	Владимирская область, Меленковский район, поселок Прудня, Зеленая, 28А	f	small
33329	27153	998	Владимирская область, Меленковский район, поселок Папулино, советская, 1	f	medium
33348	27172	1017	Владимирская область, Меленковский район, поселок Паново, Центральная, 67	f	small
33342	27166	1011	Владимирская область, Меленковский район, поселок Осинки, Лесничества	f	small
33335	27159	1004	Владимирская область, Меленковский район, поселок Окшово, Центральная, 72А	f	small
33318	27142	987	Владимирская область, Меленковский район, поселок Новониколаевское, Центральная, 12	f	small
33308	27132	977	Владимирская область, Меленковский район, Меленки, комсомольская, 189	f	large
33324	27148	993	Владимирская область, Меленковский район, Меленки, Свердлова, 70А	f	small
33309	27133	978	Владимирская область, Меленковский район, Меленки, Пушкина, 6А	f	medium
33312	27136	981	Владимирская область, Меленковский район, Меленки, Мичурина, 46	f	medium
33306	27130	975	Владимирская область, Меленковский район, Меленки, Ленина, 41	f	medium
33307	27131	976	Владимирская область, Меленковский район, Меленки, Комсомольская, 108	f	large
33303	27112	972	Владимирская область, Меленковский район, Меленки, Комсомольская, 40	f	medium
33311	27135	980	Владимирская область, Меленковский район, Меленки, Дзержинского, 29	f	large
33304	27128	973	Владимирская область, Меленковский район, Меленки, 1 Мая, 27	f	medium
33334	27158	1003	Владимирская область, Меленковский район, поселок Малый Санчур, центральная, 52А	f	small
33323	27147	992	Владимирская область, Меленковский район, поселок Малый Приклон, Центральная	f	small
33317	27141	986	Владимирская область, Меленковский район, поселок Максимово, Каманина, 1Б	f	small
33346	27170	1015	Владимирская область, Меленковский район, поселок Ляхи, советская, 114	f	medium
33347	27171	1016	Владимирская область, Меленковский район, поселок Ляхи, горького, 2	f	medium
33341	27165	1010	Владимирская область, Меленковский район, поселок Лехтово, Центральная, 124А	f	small
33328	27152	997	Владимирская область, Меленковский район, поселок Левино, Школьная, 19А	f	medium
86262	27169	1014	Владимирская область, Меленковский район, поселок Левенда, Новая, 11	f	small
33340	27164	1009	Владимирская область, Меленковский район, поселок Кулаки, Центральная, 103	f	small
33339	27163	1008	Владимирская область, Меленковский район, поселок Крутцы, новая, 116А	f	small
33322	27146	991	Владимирская область, Меленковский район, поселок Коровино, Зелёная, здание Дома культуры	f	small
33333	27157	1002	Владимирская область, Меленковский район, поселок Кононово, клубная, 16	f	small
33338	27162	1007	Владимирская область, Меленковский район, поселок Илькино, Центральная, 167	f	medium
33321	27145	990	Владимирская область, Меленковский район, поселок Иватино, Центральная, 80А	f	small
33316	27140	985	Владимирская область, Меленковский район, поселок Злобино, Центральная, 34А	f	small
33344	27168	1013	Владимирская область, Меленковский район, поселок Елино, Новая, 5	f	small
33332	27156	1001	Владимирская область, Меленковский район, поселок Дмитриевы Горы, Первомайская, 67А	f	medium
32863	26735	504	Владимирская область, Меленковский район, поселок Дмитриево, Дмитриевский сельский клуб	f	small
33327	27151	996	Владимирская область, Меленковский район, поселок Денятино, Советская, 89	f	medium
33337	27161	1006	Владимирская область, Меленковский район, поселок Двойново, Школьная, 2А	f	small
33343	27167	1012	Владимирская область, Меленковский район, поселок Высоково, Центральная, 57	f	medium
33331	27155	1000	Владимирская область, Меленковский район, поселок Воютино, Центральная, 108А	f	small
33336	27160	1005	Владимирская область, Меленковский район, поселок Войново, Центральная, 41А	f	small
33315	27139	984	Владимирская область, Меленковский район, поселок Верхоунжа, Центральная, 114	f	small
68051	27138	983	Владимирская область, Меленковский район, поселок Бутылицы, Садовая, 2 а	f	large
33320	27144	989	Владимирская область, Меленковский район, поселок Большой Приклон, Центральная, 69	f	small
33313	27137	982	Владимирская область, Меленковский район, поселок Архангел, Центральная, 44А	f	medium
33352	27176	1021	Владимирская область, Меленковский район, поселок Адино, Центральная	f	small
82324	56356	1492	Москва, Подъемная, 15	f	large
32647	26571	274	Владимирская область, Красногорский район, Красногорск, Успенская, 26	f	small
32518	26110	132	Владимирская область, Кольчугинский район, поселок Раздолье, Первомайская, 1	f	small
32519	26110	133	Владимирская область, Кольчугинский район, поселок Раздолье, Первомайская, 1	f	medium
32526	26450	140	Владимирская область, Кольчугинский район, поселок Новобусино, Четвертая, 1, Дом культуры	f	small
32527	26451	141	Владимирская область, Кольчугинский район, поселок Металлист, Школьная, 1	f	medium
32512	26440	126	Владимирская область, Кольчугинский район, поселок Литвиново, 158а	f	small
32962	26823	612	Владимирская область, Кольчугинский район, поселок Лаврово, Молодежная, 4	f	medium
32505	26434	119	Владимирская область, Кольчугинский район, Кольчугино, шмелева, 7	f	large
68052	26424	106	Владимирская область, Кольчугинский район, Кольчугино, темкина, 6	f	large
32496	26428	110	Владимирская область, Кольчугинский район, Кольчугино, луговая, 1-а	f	large
32507	26436	121	Владимирская область, Кольчугинский район, Кольчугино, алексеева, 1	f	large
32504	26433	118	Владимирская область, Кольчугинский район, Кольчугино, Садовая, 46	f	large
32503	26433	117	Владимирская область, Кольчугинский район, Кольчугино, Садовая, 46	f	large
32497	26429	111	Владимирская область, Кольчугинский район, Кольчугино, Молодежная, 2	f	large
32509	26438	123	Владимирская область, Кольчугинский район, Кольчугино, Мира, 4	f	large
32495	26427	109	Владимирская область, Кольчугинский район, Кольчугино, Интернационала, 57/7	f	large
32501	26430	115	Владимирская область, Кольчугинский район, Кольчугино, Гагарина, 8	f	large
32498	26430	112	Владимирская область, Кольчугинский район, Кольчугино, Гагарина, 8	f	large
32494	26426	108	Владимирская область, Кольчугинский район, Кольчугино, 50 лет СССР, 3	f	large
32493	26425	107	Владимирская область, Кольчугинский район, Кольчугино, 3 Интернационала, 73	f	large
32516	26444	130	Владимирская область, Кольчугинский район, поселок Ильинское, Первая , 6	f	small
32517	26445	131	Владимирская область, Кольчугинский район, поселок Золотуха, Тринадцатая, 2	f	small
32525	26449	139	Владимирская область, Кольчугинский район, поселок Есиплево, Коллективная, 2	f	small
32523	26447	137	Владимирская область, Кольчугинский район, поселок Ельцино, Школьная, 13	f	small
32521	26331	135	Владимирская область, Кольчугинский район, поселок Вишневый, Первая, 13	f	small
32522	26446	136	Владимирская область, Кольчугинский район, поселок Ваулово, первая, 3	f	small
32514	26442	128	Владимирская область, Кольчугинский район, поселок Большое Кузьминское, Молодежная, 1в	f	medium
32515	26443	129	Владимирская область, Кольчугинский район, поселок Большевик, Спортивная, 12	f	small
32520	26153	134	Владимирская область, Кольчугинский район, поселок Беречино, 107	f	small
68053	26439	125	Владимирская область, Кольчугинский район, поселок Белая Речка, улица Школьная, 1	f	large
32513	26441	127	Владимирская область, Кольчугинский район, поселок Бавлены, пл. Мира, 1а	f	large
32657	26581	284	Владимирская область, Кольчугинский район, поселок Авдотьино, 23/А	f	small
33011	26872	662	Владимирская область, Ковровский район, поселок Юдиха, 57	f	small
33033	26895	684	Владимирская область, Ковровский район, поселок Шевинская, Советская, 33	f	small
86267	26879	669	Владимирская область, Ковровский район, поселок Филино, 12	f	small
33014	26875	665	Владимирская область, Ковровский район, поселок Старая, совхозная, 31	f	small
33029	26891	680	Владимирская область, Ковровский район, поселок Смолино, Дорожная, 3	f	small
33160	27001	812	Владимирская область, Ковровский район, поселок Серково, Старое Серково, 25 А	f	medium
33012	26873	663	Владимирская область, Ковровский район, поселок Санниково, Центральная, 35	f	small
33008	26869	659	Владимирская область, Ковровский район, поселок Ручей, Центральная, 8-Б	f	large
33022	26884	673	Владимирская область, Ковровский район, поселок Первомайский, 20	f	large
33010	26871	661	Владимирская область, Ковровский район, поселок Пантелеево, Подгородица, 5	f	small
33009	26870	660	Владимирская область, Ковровский район, поселок Пакино, Школьная, 20-Г	f	large
33026	26888	677	Владимирская область, Ковровский район, поселок Павловское, Советская, 9	f	small
32138	25252	864	Брянская область, Сельцо, Куйбышева, 19	f	large
33020	26881	671	Владимирская область, Ковровский район, поселок Новый, Школьная, 3	f	medium
33024	26886	675	Владимирская область, Ковровский район, поселок Нерехта, Школьная, 2	f	small
33035	26898	686	Владимирская область, Ковровский район, поселок Мелехово, школьный переулок, 25-А	f	large
33034	26897	685	Владимирская область, Ковровский район, поселок Мелехово, Первомайская, 48	f	large
33036	26899	687	Владимирская область, Ковровский район, поселок Мелехово, Парковая, 2-а	f	large
33007	26868	658	Владимирская область, Ковровский район, поселок Малыгино, Школьная, 62	f	large
33025	26887	676	Владимирская область, Ковровский район, поселок Крутово, Танеева, 2	f	medium
33019	26880	670	Владимирская область, Ковровский район, поселок Крестниково, Школьная, 9	f	small
109429	26892	681	Владимирская область, Ковровский район, поселок Красный Октябрь, комсомольская, 2а	f	medium
33031	26893	682	Владимирская область, Ковровский район, поселок Красный Маяк, маяковского, 2	f	medium
33013	26874	664	Владимирская область, Ковровский район, поселок Клязьминский Городок, Фабричный поселок, 35	f	medium
33006	26867	657	Владимирская область, Ковровский район, поселок Ильино, Центральная, 29	f	small
32959	26820	609	Владимирская область, Ковровский район, поселок Ильино, Молодежная, 8	f	small
33028	26890	679	Владимирская область, Ковровский район, поселок Иваново, Коммунистическая, 24	f	large
33027	26889	678	Владимирская область, Ковровский район, поселок Иваново, Гагарина, 9-А	f	medium
33017	26878	668	Владимирская область, Ковровский район, поселок Достижение, Фабричная, 40	f	large
86266	26876	666	Владимирская область, Ковровский район, поселок Глебово, Школьная, 22	f	small
33004	26865	655	Владимирская область, Ковровский район, поселок Гигант, Юбилейная, 66	f	medium
33032	26894	683	Владимирская область, Ковровский район, поселок Восход, советская, 51-А	f	small
33023	26885	674	Владимирская область, Ковровский район, поселок Великово, 79	f	small
32947	26808	597	Владимирская область, Ковровский район, поселок Болотский, Школьная, 11	f	small
33005	26866	656	Владимирская область, Ковровский район, поселок Бол. Всегодичи, центральная, 61-А	f	small
33021	26882	672	Владимирская область, Ковровский район, поселок Бельково, 105-А	f	small
32488	26420	101	Владимирская область, Киржачский район, поселок Филипповское, Сельская Новь, 24	f	medium
32484	26416	97	Владимирская область, Киржачский район, поселок Федоровское, Советская, 6а	f	medium
32489	26421	102	Владимирская область, Киржачский район, поселок Песьяне, Советская, 27а	f	small
32486	26418	99	Владимирская область, Киржачский район, поселок Першино, Школьная, 4а	f	large
32483	26415	96	Владимирская область, Киржачский район, поселок Новоселово, школьная, 6	f	medium
32476	26407	89	Владимирская область, Киржачский район, Киржач, пионерская, 1	f	medium
32466	26398	79	Владимирская область, Киржачский район, Киржач, набережная, 9	f	large
32463	26395	76	Владимирская область, Киржачский район, Киржач, закодская, 14а	f	large
32462	26394	75	Владимирская область, Киржачский район, Киржач, гастелло, 9	f	large
32468	26399	81	Владимирская область, Киржачский район, Киржач, вокзальная, 26	f	large
32469	26400	82	Владимирская область, Киржачский район, Киржач, Шелковиков, 10	f	medium
32465	26397	78	Владимирская область, Киржачский район, Киржач, Чехова, 10а	f	large
32460	26392	73	Владимирская область, Киржачский район, Киржач, Фрунзе, 2а	f	medium
32464	26396	77	Владимирская область, Киржачский район, Киржач, Серёгина, 24	f	large
32472	26403	85	Владимирская область, Киржачский район, Киржач, Садовая, 51	f	large
32474	26405	87	Владимирская область, Киржачский район, Киржач, Пушкина, 27	f	large
32473	26404	86	Владимирская область, Киржачский район, Киржач, Пушкина, 29	f	large
32475	26406	88	Владимирская область, Киржачский район, Киржач, Октябрьская, 14	f	large
32461	26393	74	Владимирская область, Киржачский район, Киржач, Ленинградская, 55	f	large
32471	26402	84	Владимирская область, Киржачский район, Киржач, 40 лет Октября, 17	f	large
32470	26401	83	Владимирская область, Киржачский район, Киржач, 40 Лет Октября, 25а	f	large
32481	26412	94	Владимирская область, Киржачский район, поселок Кипрево, Центральная, 8д	f	medium
32479	26410	92	Владимирская область, Киржачский район, поселок Илькино, Центральная, 40	f	small
32490	26422	103	Владимирская область, Киржачский район, поселок Заречье, Центральная, 17	f	small
32480	26411	93	Владимирская область, Киржачский район, поселок Ефремово, Восточная, 9	f	medium
32477	26408	90	Владимирская область, Киржачский район, поселок Ельцы, Молодежная, 15	f	small
32478	26409	91	Владимирская область, Киржачский район, поселок Горка, Школьный переулок, 3	f	medium
32482	26413	95	Владимирская область, Киржачский район, поселок Афанасово, центральная, 19	f	small
32487	26419	100	Владимирская область, Киржачский район, поселок Аленино, Центральная, 73	f	medium
32995	26857	646	Владимирская область, Камешковский район, поселок Сергеиха, Центральная, 1, Администрация муниципального образования Сергеихинское	f	\N
32993	26855	644	Владимирская область, Камешковский район, поселок Сергеиха, Карла Либкнехта, 91	f	medium
33001	26863	652	Владимирская область, Камешковский район, поселок Пенкино, Лесная, 1	f	small
68057	26844	633	Владимирская область, Камешковский район, поселок Новки, ильича, 14	f	large
32983	26845	634	Владимирская область, Камешковский район, поселок Новки, Фрунзе, 17	f	large
32997	26859	648	Владимирская область, Камешковский район, поселок Мирный, Школьная, 8	f	medium
32994	26856	645	Владимирская область, Камешковский район, поселок Лубенцы, 45	f	medium
32990	26852	641	Владимирская область, Камешковский район, поселок Краснознаменский, Шоссейная, Муниципальное учреждение культуры Дом культуры поселка Краснознаменский	f	\N
32992	26854	643	Владимирская область, Камешковский район, поселок Коверино, Садовая, 18	f	medium
32980	26841	631	Владимирская область, Камешковский район, Камешково, гоголя, 4	f	large
33003	26840	654	Владимирская область, Камешковский район, Камешково, Школьная,, 3	f	medium
32979	26840	630	Владимирская область, Камешковский район, Камешково, Школьная,, 3	f	large
33368	27187	1092	Владимирская область, Камешковский район, Камешково, Гоголя, 5А, МОУ средняя общеобразовательная школа №, 1	f	\N
32981	26842	632	Владимирская область, Камешковский район, Камешково, Гоголя, 5А	f	large
32978	26839	629	Владимирская область, Камешковский район, Камешково, Герцена, 10	f	medium
32989	26851	640	Владимирская область, Камешковский район, поселок Имени Красина, рабочая, 1	f	medium
32986	26848	637	Владимирская область, Камешковский район, поселок Имени Кирова	f	small
32984	26846	635	Владимирская область, Камешковский район, поселок Имени Карла Маркса, Шоссейная, 14	f	large
32985	26847	636	Владимирская область, Камешковский район, поселок Имени Карла Маркса, Карла Маркса, 9, МОУ Брызгаловская общеобразовательная школа	f	\N
32988	26850	639	Владимирская область, Камешковский район, поселок Имени Горького, Морозова, 2	f	medium
32987	26849	638	Владимирская область, Камешковский район, поселок Имени Горького, Морозова, 2-а	f	large
32991	26853	642	Владимирская область, Камешковский район, поселок Имени Артема, Центральная, 15, Здание администрации МО Сергеихинское	f	\N
33000	26862	651	Владимирская область, Камешковский район, поселок Давыдово, 53	f	medium
32999	26861	650	Владимирская область, Камешковский район, поселок Горки, 20а	f	small
33002	26864	653	Владимирская область, Камешковский район, поселок Гатиха, Новая, 2	f	medium
32996	26858	647	Владимирская область, Камешковский район, поселок Второво, советская, 28а	f	medium
33369	27188	1093	Владимирская область, Камешковский район, поселок Второво, Советская, 22А, Администрация муниципального образования Второвское	f	\N
32998	26860	649	Владимирская область, Камешковский район, поселок Волковойно, 39	f	medium
32901	26769	542	Владимирская область, Гусь-Хрустальный район, поселок Уршельский, Театральная, 1	f	large
32900	26768	541	Владимирская область, Гусь-Хрустальный район, поселок Уршельский, Весёлкина, 36	f	large
32876	26748	517	Владимирская область, Гусь-Хрустальный район, поселок Уляхино, Колхозная, 127	f	medium
33349	27173	1018	Владимирская область, Гусь-Хрустальный район, поселок Толстиково, Центральная, 21	f	small
86265	26744	513	Владимирская область, Гусь-Хрустальный район, поселок Тащилово, центральная, 3	f	small
32902	26770	543	Владимирская область, Гусь-Хрустальный район, поселок Тасинский Бор, Центральная, 8	f	small
32903	26771	544	Владимирская область, Гусь-Хрустальный район, поселок Тасинский, Новая, 1	f	medium
32874	26746	515	Владимирская область, Гусь-Хрустальный район, поселок Таланово, Центральная, 156	f	small
32865	26737	506	Владимирская область, Гусь-Хрустальный район, поселок Разъезд Вековка, Вековская СОШ	f	medium
33132	26973	784	Владимирская область, Гусь-Хрустальный район, поселок Перово, Школьная, 6 А	f	small
32867	26739	508	Владимирская область, Гусь-Хрустальный район, поселок Перово, Школьная, 2	f	small
32877	26749	518	Владимирская область, Гусь-Хрустальный район, поселок Парахино 1-е, Парахинский сельский дом культуры	f	small
33279	27103	943	Владимирская область, Гусь-Хрустальный район, поселок Панфилово, Октябрьская, 4	f	large
32875	26747	516	Владимирская область, Гусь-Хрустальный район, поселок Новодурово, Новодуровский СДК	f	small
32898	26766	539	Владимирская область, Гусь-Хрустальный район, поселок Нечаевская, Стрельцова, 28а	f	medium
32577	26502	197	Владимирская область, Гусь-Хрустальный район, поселок Нагорный Поселок, Владимирская, 1А	f	medium
32868	26740	509	Московская область, Серпуховский район, деревня Мокрое	f	medium
32897	26765	538	Владимирская область, Гусь-Хрустальный район, поселок Мезиновский, строительная, 14	f	large
32896	26764	537	Владимирская область, Гусь-Хрустальный район, поселок Курлово, советская, 1а	f	large
32895	26764	536	Владимирская область, Гусь-Хрустальный район, поселок Курлово, советская, 1а	f	large
32894	26764	535	Владимирская область, Гусь-Хрустальный район, поселок Курлово, советская, 1а	f	large
32871	26743	512	Владимирская область, Гусь-Хрустальный район, поселок Купреево, школьная, 5	f	medium
32870	26742	511	Владимирская область, Гусь-Хрустальный район, поселок Красный Октябрь, Октябрьская, 11	f	medium
32891	26761	532	Владимирская область, Гусь-Хрустальный район, поселок Красное Эхо, Почтовая, 1	f	large
32873	26745	514	Владимирская область, Гусь-Хрустальный район, поселок Колпь, центральная, 6	f	medium
32887	26757	528	Владимирская область, Гусь-Хрустальный район, поселок Икшево	f	medium
32886	26756	527	Владимирская область, Гусь-Хрустальный район, поселок Золотковский, Дачная, 22	f	small
32885	26755	526	Владимирская область, Гусь-Хрустальный район, поселок Золотково, Социалистическая, 29	f	large
32884	26754	525	Владимирская область, Гусь-Хрустальный район, поселок Золотково, Гагарина, 19	f	large
32864	26736	505	Владимирская область, Гусь-Хрустальный район, поселок Заколпье, Молодёжная, 21	f	small
32893	26763	534	Владимирская область, Гусь-Хрустальный район, поселок Дубасово, Дубасовский сельский клуб	f	small
32882	26752	523	Владимирская область, Гусь-Хрустальный район, поселок Добрятино, 60 лет Октября, 5	f	large
32936	26797	583	Владимирская область, Гусь-Хрустальный район, поселок Гусевский, Мира, 10 , клуб Центрального поселка	f	\N
32935	26794	582	Владимирская область, Гусь-Хрустальный район, поселок Гусевский, Мира, 12, средняя школа № 14	f	\N
32862	26734	503	Владимирская область, Гусь-Хрустальный район, поселок Григорьево, Черёмушки, 3	f	medium
32881	26751	522	Владимирская область, Гусь-Хрустальный район, поселок Великодворский, Ленина, 3	f	large
109426	26654	520	Владимирская область, Гусь-Хрустальный район, поселок Вашутино, центральная, 2а	f	medium
33262	27087	926	Владимирская область, Гусь-Хрустальный район, поселок Борисово, Куйбышева, 73	f	small
32878	26750	519	Владимирская область, Гусь-Хрустальный район, поселок Анопино, Мира, 6	f	large
32899	26767	540	Владимирская область, Гусь-Хрустальный район, поселок Аббакумово, МОУ Аббакумовская ООШ 	f	small
109432	27028	847	Владимирская область, Гороховецкий район, поселок Чулково, центральная, 14	f	medium
33188	27027	846	Владимирская область, Гороховецкий район, поселок Фоминки, Советская, 2	f	large
109427	26762	533	Владимирская область, Гороховецкий район, поселок Семеновка, Сельская Новь, 44	f	medium
33184	27023	842	Владимирская область, Гороховецкий район, поселок Пролетарский, Советская, 16	f	large
33143	26984	795	Владимирская область, Гороховецкий район, поселок Осинки, Шоссейная, 13	f	small
86261	27024	843	Владимирская область, Гороховецкий район, поселок Крутово, Колхозная, 8, ФАП ГБУЗ ВО	f	small
33267	27092	931	Владимирская область, Гороховецкий район, поселок Зименки, Кооперативная, 21	f	medium
32135	25250	861	Брянская область, Сельцо, Куйбышева, 30	f	large
86268	27022	841	Владимирская область, Гороховецкий район, поселок Гришино, Ленина, 33, Дом культуры	f	small
33177	27016	834	Владимирская область, Гороховецкий район, Гороховец, революции, 1	f	large
33176	27015	833	Владимирская область, Гороховецкий район, Гороховец, Революции, 1, здание МОУ СОШ № 3	f	\N
33170	27009	827	Владимирская область, Гороховецкий район, Гороховец, Парковая, 60	f	large
33178	27017	835	Владимирская область, Гороховецкий район, Гороховец, Московская, 43	f	medium
33175	27014	832	Владимирская область, Гороховецкий район, Гороховец, Мира, 15	f	large
33174	27013	831	Владимирская область, Гороховецкий район, Гороховец, Ленина, 48	f	large
33171	27010	828	Владимирская область, Гороховецкий район, Гороховец, Кутузова, 7	f	large
33172	27011	829	Владимирская область, Гороховецкий район, Гороховец, Комсомольская, 23	f	medium
33182	27021	840	Владимирская область, Гороховецкий район, поселок Галицы, Железнодорожная, 1	f	medium
33186	27025	844	Владимирская область, Гороховецкий район, поселок Выезд, Полевая, 15	f	medium
33181	27020	838	Владимирская область, Гороховецкий район, поселок Великово, школьная, 47	f	medium
33187	27026	845	Владимирская область, Гороховецкий район, поселок Быкасово, Садовая, 16	f	small
33180	27019	837	Владимирская область, Гороховецкий район, поселок Арефино, Центральная, 4	f	medium
33144	26985	796	Владимирская область, Вязниковский район, поселок станции Сарыево, Шоссейная, 12	f	small
33148	26989	800	Владимирская область, Вязниковский район, поселок Эдон, Советская, 12	f	medium
33151	26992	803	Владимирская область, Вязниковский район, поселок Шатнево, заречная, 11	f	medium
33126	26967	778	Владимирская область, Вязниковский район, поселок Чудиново, Центральная, 11	f	large
33167	27008	819	Владимирская область, Вязниковский район, поселок Центральный, Главная, 19	f	medium
33147	26988	799	Владимирская область, Вязниковский район, поселок Степанцево, Совхозная, сельский клуб	f	small
33146	26987	798	Владимирская область, Вязниковский район, поселок Степанцево, Первомайская, 16-А	f	large
33162	27003	814	Владимирская область, Вязниковский район, поселок Сергиевы-Горки, Муромская, 90	f	medium
33166	27007	818	Владимирская область, Вязниковский район, поселок Сергеево, Центральная, 2 А	f	small
33145	26986	797	Владимирская область, Вязниковский район, поселок Сарыево, Советская, 22Г	f	small
33153	26994	805	Владимирская область, Вязниковский район, поселок Приозерный, Советская, 74	f	medium
109430	26974	785	Владимирская область, Вязниковский район, поселок Пировы Городищи, центральная, 5, Пирово-Городищенская основная общеобразовательная школа	f	medium
33131	26972	783	Владимирская область, Вязниковский район, поселок Пески, Новая, 15	f	medium
33164	27005	816	Владимирская область, Вязниковский район, поселок Паустово, Центральная, 56 А	f	medium
33161	27002	813	Владимирская область, Вязниковский район, поселок Октябрьский, Советская, 1	f	large
32603	26530	225	Владимирская область, Вязниковский район, поселок Октябрьская, 118в	f	large
33163	27004	815	Владимирская область, Вязниковский район, поселок Октябрьская, Советская, 34	f	large
33156	26997	808	Владимирская область, Вязниковский район, поселок Никологоры, Пушкинский переулок, 10	f	large
33155	26996	807	Владимирская область, Вязниковский район, поселок Никологоры, Базарная, 23	f	large
33154	26995	806	Владимирская область, Вязниковский район, поселок Никологоры, 2 Пролетарская, 57	f	large
33139	26980	791	Владимирская область, Вязниковский район, поселок Мстера, площадь Ленина, 9	f	large
33142	26983	794	Владимирская область, Вязниковский район, поселок Мстера, Шоссейная, 12 А	f	large
33140	26981	792	Владимирская область, Вязниковский район, поселок Мстера, Школьная, 4	f	large
33141	26982	793	Владимирская область, Вязниковский район, поселок Мстера, Дзержинского, 8	f	medium
33134	26975	786	Владимирская область, Вязниковский район, поселок Малые Удолы, 67	f	small
33152	26993	804	Владимирская область, Вязниковский район, поселок Маловская, Заречная, 1 А	f	small
33157	26998	809	Владимирская область, Вязниковский район, поселок Лукново, советская, 2А	f	large
33158	26999	810	Владимирская область, Вязниковский район, поселок Лукново, Центральная, 27	f	medium
32140	25253	866	Брянская область, Сельцо, Горького, 14	f	large
33125	26966	777	Владимирская область, Вязниковский район, поселок Коурково, Школьная, 18	f	small
33135	26976	787	Владимирская область, Вязниковский район, поселок Козлово, 61	f	medium
33137	26978	789	Владимирская область, Вязниковский район, поселок Заречный, 41	f	medium
33150	26991	802	Владимирская область, Вязниковский район, поселок Галкино, Советская, 1	f	small
33128	26969	780	Владимирская область, Вязниковский район, Вязники, южная, 13	f	medium
33116	26959	768	Владимирская область, Вязниковский район, Вязники, стахановская, 23	f	large
33110	26953	762	Владимирская область, Вязниковский район, Вязники, сенькова, 1/2	f	large
33118	26961	770	Владимирская область, Вязниковский район, Вязники, мк-н Ефимьево, 2 А	f	small
33130	26971	782	Владимирская область, Вязниковский район, Вязники, механизаторов, 90	f	large
33124	26883	776	Владимирская область, Вязниковский район, Вязники, железнодорожная, 33	f	medium
33117	26960	769	Владимирская область, Вязниковский район, Вязники, Южная, 41	f	large
33108	26951	760	Владимирская область, Вязниковский район, Вязники, Чапаевская, 14	f	large
33127	26968	779	Владимирская область, Вязниковский район, Вязники, Текстильная, 4	f	large
33113	26956	765	Владимирская область, Вязниковский район, Вязники, Свердлова, 15	f	large
33121	26964	773	Владимирская область, Вязниковский район, Вязники, Металлистов, 18	f	large
33115	26958	767	Владимирская область, Вязниковский район, Вязники, Комсомольская, 4 А	f	large
33109	26952	761	Владимирская область, Вязниковский район, Вязники, Киселева, 87	f	large
33123	26931	775	Владимирская область, Вязниковский район, Вязники, Ефимьево, 1	f	large
33114	26957	766	Владимирская область, Вязниковский район, Вязники, Владимирская, 5	f	large
33112	26955	764	Владимирская область, Вязниковский район, Вязники, Благовещенская, 16	f	large
33129	26970	781	Владимирская область, Вязниковский район, Вязники, 1 шоссейная, 1А	f	large
33165	27006	817	Владимирская область, Вязниковский район, поселок Воробьевка, Главная, 8	f	small
33149	26990	801	Владимирская область, Вязниковский район, поселок Буторлино, Фабричный переулок, 9 А	f	medium
33159	27000	811	Владимирская область, Вязниковский район, поселок Большевысоково, Центральная, 32	f	small
33138	26979	790	Владимирская область, Вязниковский район, поселок Барское Татарово, Шибанова, 122	f	large
32869	26741	510	Владимирская область, Вязниковский район, поселок Аксеново, Школьная	f	medium
33354	27178	1023	Владимирская область, Александровский район, поселок Тургенево, Школьная, 9	f	medium
32455	26386	57	Владимирская область, Александровский район, Струнино, шувалова, 14а	f	large
32458	26389	60	Владимирская область, Александровский район, Струнино, заречная, 9	f	large
32457	26388	59	Владимирская область, Александровский район, Струнино, воронина, 3, МУ « Дом спорта», 1-й этаж	f	large
32454	26385	56	Владимирская область, Александровский район, Струнино, Фрунзе, 1	f	large
32428	26361	30	Владимирская область, Александровский район, поселок Следнево, Октябрьский квартал, 8	f	medium
32438	26371	40	Владимирская область, Александровский район, поселок Светлый, сельский клуб	f	medium
32434	26367	36	Владимирская область, Александровский район, поселок Обашево	f	small
32426	26358	28	Владимирская область, Александровский район, поселок Мошнино, Владимирская, 31	f	small
32442	26375	44	Владимирская область, Александровский район, поселок Маяк, Лесная, 1	f	small
32446	26379	48	Владимирская область, Александровский район, поселок Махра, Монастырская, 11а	f	small
32437	26370	39	Владимирская область, Александровский район, поселок Майский, Первомайская, 16	f	medium
32432	26365	34	Владимирская область, Александровский район, поселок Лобково, Кирпичная, 5	f	small
32430	26363	32	Владимирская область, Александровский район, поселок Лисавы	f	small
32447	26380	49	Владимирская область, Александровский район, поселок Лизуново, Мусатова, 54	f	medium
32440	26373	42	Владимирская область, Александровский район, поселок Легково, Весенняя, 3	f	medium
32431	26364	33	Владимирская область, Александровский район, поселок Красное Пламя, Клубная, 74	f	medium
32452	26383	54	Владимирская область, Александровский район, Карабаново, вокзальная, 11	f	large
32448	26381	50	Владимирская область, Александровский район, Карабаново, Торговая площадь, 3	f	large
32453	26384	55	Владимирская область, Александровский район, Карабаново, Победы, 7	f	large
32433	26366	35	Владимирская область, Александровский район, поселок Искра, Кооперативная, 1	f	small
32445	26378	47	Владимирская область, Александровский район, поселок Зеленцино, фельдшерско-акушерский пункт	f	small
32439	26372	41	Владимирская область, Александровский район, поселок Елькино	f	small
32435	26368	37	Владимирская область, Александровский район, поселок Долгополье	f	small
32436	26369	38	Владимирская область, Александровский район, поселок Годуново, Новлянская, 19	f	medium
32444	26377	46	Владимирская область, Александровский район, поселок Большое Каринское, Деревенская, 56	f	medium
32425	26357	27	Владимирская область, Александровский район, поселок Балакирево, Юго-Западный квартал, 1а	f	large
32424	26356	26	Владимирская область, Александровский район, поселок Балакирево, Октябрьская, 2	f	large
32423	26355	25	Владимирская область, Александровский район, поселок Балакирево, Вокзальная, 15	f	large
32427	26359	29	Владимирская область, Александровский район, поселок Бакшеево, Центральная, 12	f	medium
32443	26376	45	Владимирская область, Александровский район, поселок Бакино, центральная, 10	f	small
32429	26362	31	Владимирская область, Александровский район, поселок Арсаки, 110	f	large
32441	26374	43	Владимирская область, Александровский район, поселок Андреевское, советская, 13	f	medium
32662	26586	289	Владимирская область, Александровский район, поселок Андреевское, Хивинская, 24	f	medium
32422	26354	24	Владимирская область, Александровский район, Александров, советская, 25а	f	large
32402	26335	4	Владимирская область, Александровский район, Александров, парковая, 1	f	medium
131616	26345	16	Владимирская область, Александровский район, Александров, ленина, 24	f	large
32407	26339	9	Владимирская область, Александровский район, Александров, кубасова, 10	f	large
32406	26339	8	Владимирская область, Александровский район, Александров, кубасова, 10	f	large
32412	26343	14	Владимирская область, Александровский район, Александров, Ческа-Липа, 5	f	large
32411	26343	13	Владимирская область, Александровский район, Александров, Ческа-Липа, 5	f	large
32409	26341	11	Владимирская область, Александровский район, Александров, Терешковой, 5	f	large
32403	26336	5	Владимирская область, Александровский район, Александров, Стрелецкая набережная, 1	f	large
32418	26350	20	Владимирская область, Александровский район, Александров, Перфильева, 3а	f	large
32417	26349	19	Владимирская область, Александровский район, Александров, Первомайская, 89	f	large
32421	26353	23	Владимирская область, Александровский район, Александров, Маяковского, 30	f	large
32419	26351	21	Владимирская область, Александровский район, Александров, Ленина, 5	f	large
32413	26344	15	Владимирская область, Александровский район, Александров, Красный переулок, 8	f	large
32400	26333	2	Владимирская область, Александровский район, Александров, Двориковское шоссе, 1	f	large
32399	26332	1	Владимирская область, Александровский район, Александров, Геологов, 1	f	large
32410	26342	12	Владимирская область, Александровский район, Александров, Гагарина, 19	f	large
32416	26334	18	Владимирская область, Александровский район, Александров, Восстания 1905 года, 3	f	large
32401	26334	3	Владимирская область, Александровский район, Александров, Восстания 1905 года, 3	f	medium
33370	26390	61	Владимирская область, Александровский район, Александров, Вокзальная, 10, железнодорожный вокзал г. Александров	f	\N
32405	26338	7	Владимирская область, Александровский район, Александров, Базунова, стадион Рекорд	f	large
31493	24621	219	Брянская область, село Супонево, Чувиной, 35	f	large
31495	24624	221	Брянская область, село Супонево, Советская, 10а	f	large
32144	25256	870	Брянская область, Сельцо, Школьная, 25	f	large
32141	25254	867	Брянская область, Сельцо, Мейпариани, 15	f	large
32137	25251	863	Брянская область, Сельцо, Мейпариани, 17	f	large
32136	25251	862	Брянская область, Сельцо, Мейпариани, 17	f	medium
32134	25249	860	Брянская область, Сельцо, Мейпариани, 2	f	large
31614	24736	340	Брянская область, Сельцо, Ленина, 6, здание Дома культуры	f	medium
32139	25252	865	Брянская область, Сельцо, Куйбышева, 19	f	large
32040	25158	766	Брянская область, Почеп, Мира, 62	f	large
31482	24610	208	Брянская область, поселок Новые дарковичи, Новодарковичская средняя школа	f	small
32396	25507	1122	Брянская область, Новозыбков, (48343)91-5-10	f	small
31981	25099	707	Брянская область, Новозыбков, Синицына, 67	f	large
31973	25091	699	Брянская область, Новозыбков, Садовая, 58	f	large
31970	25088	696	Брянская область, Новозыбков, Садовая, 30	f	large
31978	25096	704	Брянская область, Новозыбков, Рошаля, 25	f	large
31980	25098	706	Брянская область, Новозыбков, Наримановская, 136	f	large
31965	25083	691	Брянская область, Новозыбков, Мичурина, 59	f	large
31966	25084	692	Брянская область, Новозыбков, Ломоносова, 39-А	f	large
31971	25089	697	Брянская область, Новозыбков, Ленина, 13	f	large
31969	25087	695	Брянская область, Новозыбков, Ленина, 59	f	large
31979	25097	705	Брянская область, Новозыбков, Красногвардейская, 70	f	large
31976	25094	702	Брянская область, Новозыбков, Красная, 136-А	f	large
31972	25090	698	Брянская область, Новозыбков, Красная, 2	f	large
31974	25092	700	Брянская область, Новозыбков, Коммунистическая, 20	f	large
31967	25085	693	Брянская область, Новозыбков, Голодеда, 22	f	large
31975	25093	701	Брянская область, Новозыбков, Воровского, 16	f	large
31968	25086	694	Брянская область, Новозыбков, Вокзальная, 24-А	f	large
31982	25100	708	Брянская область, Новозыбков, 114 квартал, здание филиала НГЦБС № 3	f	large
31931	25049	657	Брянская область, Мглин, площадь Советская, 4	f	large
31831	24950	557	Брянская область, Клинцы, проспект Ленина, 70	f	large
31820	24945	546	Брянская область, Клинцы, проспект Ленина, 29	f	large
31818	24943	544	Брянская область, Клинцы, проспект Ленина, 23	f	large
31845	24963	571	Брянская область, Клинцовский район, Станционная, 3	f	large
31828	24923	554	Брянская область, Клинцы, Свердлова, 152	f	large
31829	24923	555	Брянская область, Клинцы, Свердлова, 152	f	large
31821	24946	547	Брянская область, Клинцы городской округ, Пушкина, 24	f	large
31825	24828	551	Брянская область, Клинцы, Площадь Свободы, 26	f	large
31824	24828	550	Брянская область, Клинцы, Площадь Свободы, 26	f	large
31827	24887	553	Брянская область, Клинцы, Первомайская, 57	f	large
31823	24948	549	Брянская область, Клинцы, Октябрьская, 66	f	large
31822	24947	548	Брянская область, Клинцы, Октябрьская, 29	f	large
31819	24944	545	Брянская область, Клинцы, Октябрьская, 27	f	large
31836	24955	562	Брянская область, Клинцы, Мира, 95	f	large
31835	24954	561	Брянская область, Клинцы, Мира, 111	f	large
31839	24957	565	Брянская область, Клинцы, Калинина, 155	f	large
31838	24957	564	Брянская область, Клинцы, Калинина, 155	f	large
31832	24951	558	Брянская область, Клинцы, Калинина, 139	f	large
31830	24949	556	Брянская область, Клинцы, Калинина, 137	f	large
31826	24874	552	Брянская область, Клинцы, Декабристов, 20а	f	large
31837	24956	563	Брянская область, Клинцы, Ворошилова, 3	f	large
31833	24952	559	Брянская область, Клинцы, Ворошилова, 44а	f	large
31701	24823	427	Брянская область, Карачев, Советская, 45	f	large
31364	24505	90	Брянская область, Брянск, поселок Снежка, Центр детского и юношеского туризма и экскурсий	f	medium
31305	24453	31	Брянская область, Брянск, улица ХХII Съезда КПСС, 98	f	large
31408	24540	134	Брянская область, Брянск, улица Фрунзе, 80а	f	large
31357	24498	83	Брянская область, Брянск, улица Фосфоритная, 9	f	large
31378	24518	104	Брянская область, Брянск, улица Фокина, 56	f	large
31329	24472	55	Брянская область, Брянск, улица Федюнинского, 15	f	large
31303	24451	29	Брянская область, Брянск, улица Ульянова, 118	f	large
31360	24501	86	Брянская область, Брянск, улица Тельмана, 109в	f	large
31342	24484	68	Брянская область, Брянск, улица Пушкина, 59	f	large
31418	24549	144	Брянская область, Брянск, улица Полесская, 83	f	large
31301	24449	27	Брянская область, Брянск, улица Отрадная, 23	f	large
31325	24468	51	Брянская область, Брянск, улица Орловская, 26А	f	large
31414	24546	140	Брянская область, Брянск, улица Олега Кошевого, 30	f	large
32235	25348	961	Брянская область, Брянск, улица Молодежная, 10	f	small
31315	24459	41	Брянская область, Брянск, улица Ленинградская, 24	f	large
31314	24459	40	Брянская область, Брянск, улица Ленинградская, 24	f	large
31313	24459	39	Брянская область, Брянск, улица Ленинградская, 24	f	large
31302	24450	28	Брянская область, Брянск, улица Кромская, 48а	f	large
31338	24480	64	Брянская область, Брянск, улица Королева, 1а	f	large
31288	24442	14	Брянская область, Брянск, улица Коммунистическая, 134	f	large
31290	24443	16	Брянская область, Брянск, улица Клинцовская, 61	f	large
31289	24443	15	Брянская область, Брянск, улица Клинцовская, 61	f	large
31410	24542	136	Брянская область, Брянск, улица Карачижская, 2б	f	large
31317	24461	43	Брянская область, Брянск, улица Институтская, 16	f	large
31370	24510	96	Брянская область, Брянск, улица Дуки, 2	f	large
31425	24555	151	Брянская область, Брянск, улица Дзержинского, 47	f	large
31427	24555	153	Брянская область, Брянск, улица Дзержинского, 47	f	large
31331	24474	57	Брянская область, Брянск, улица Делегатская, 74	f	large
31335	24448	61	Брянская область, Брянск, улица Вокзальная, 162	f	large
31300	24448	26	Брянская область, Брянск, улица Вокзальная, 162	f	large
31365	24506	91	Брянская область, Брянск, улица Бежицкая, 14	f	large
31366	24506	92	Брянская область, Брянск, улица Бежицкая, 14	f	large
31337	24479	63	Брянская область, Брянск, улица Афанасьева, 26	f	large
31373	24513	99	Брянская область, Брянск, Ямская, 21	f	medium
31326	24469	52	Брянская область, Брянск, Шоссейная, 63	f	large
31355	24496	81	Брянская область, Брянск, Чернышевского, 23	f	large
31431	24560	157	Брянская область, Брянск, Челюскинцев, 2	f	large
32285	25398	1011	Брянская область, Брянск, поселок Большое Полпино, Центральная, 69	f	medium
31362	24503	88	Брянская область, Брянск, Центральная, 72	f	large
31320	24463	46	Брянская область, Брянск, ХХII Съезда КПСС, 6	f	large
31312	24458	38	Брянская область, Брянск, ХХII Съезда КПСС, 25	f	large
31311	24458	37	Брянская область, Брянск, ХХII Съезда КПСС, 25	f	large
31375	24515	101	Брянская область, Брянск, Фокина, 108а	f	large
31330	24473	56	Брянская область, Брянск, Федюнинского, 1	f	large
31424	24554	150	Брянская область, Брянск, Трофименко проезд, 12	f	large
31359	24500	85	Брянская область, Брянск, Тельмана, 78	f	large
31356	24497	82	Брянская область, Брянск, Тельмана, 109в	f	large
31352	24493	78	Брянская область, Брянск, Суворова, 2б	f	large
31407	24539	133	Брянская область, Брянск, Станке Димитрова проспект, 73	f	large
31406	24538	132	Брянская область, Брянск, Станке Димитрова проспект, 39	f	large
31391	24532	117	Брянская область, Брянск, Станке Димитрова проспект, 3	f	large
31409	24541	135	Брянская область, Брянск, Спартаковская, 112	f	large
31377	24517	103	Брянская область, Брянск, Советская, 2А	f	large
31376	24516	102	Брянская область, Брянск, Советская, 35	f	large
31374	24514	100	Брянская область, Брянск, Советская, 79	f	large
31296	24444	22	Брянская область, Брянск, Северный переулок, 58	f	large
31295	24444	21	Брянская область, Брянск, Северный переулок, 58	f	large
31347	24488	73	Брянская область, Брянск, Пушкина, 23	f	large
31346	24488	72	Брянская область, Брянск, Пушкина, 23	f	large
31340	24482	66	Брянская область, Брянск, Пушкина, 74	f	large
31343	24485	69	Брянская область, Брянск, Профсоюзов, 24	f	large
31321	24464	47	Брянская область, Брянск, Протасова, 1	f	large
31334	24477	60	Брянская область, Брянск, Почтовая, 110	f	large
31282	24437	8	Брянская область, Брянск, Почтовая, 4	f	large
31281	24436	7	Брянская область, Брянск, Почтовая, 26	f	large
31278	24434	4	Брянская область, Брянск, Почтовая, 100	f	large
31277	24433	3	Брянская область, Брянск, Почтовая, 67	f	large
31276	24432	2	Брянская область, Брянск, Почтовая, 71	f	large
31426	24556	152	Брянская область, Брянск, Победы, 5	f	large
31368	24508	94	Брянская область, Брянск, Петрова, 4	f	large
31388	24529	114	Брянская область, Брянск, Пересвета, 3	f	large
31387	24528	113	Брянская область, Брянск, Партизан площадь, 4	f	large
31389	24530	115	Брянская область, Брянск, Осоавиахима переулок, 3а	f	large
31361	24502	87	Брянская область, Брянск, Орджоникидзе, 2А	f	large
31423	24553	149	Брянская область, Брянск, Олега Кошевого, 69	f	large
31422	24553	148	Брянская область, Брянск, Олега Кошевого, 69	f	large
31385	24526	111	Брянская область, Брянск, Октябрьская, 14	f	large
31371	24511	97	Брянская область, Брянск, Октябрьская, 135	f	large
31284	24439	10	Брянская область, Брянск, Окружная, 13	f	large
31439	24567	165	Брянская область, Брянск, Новозыбковская, 20	f	large
31437	24565	163	Брянская область, Брянск, Новозыбковская, 7Б	f	large
82323	56356	1491	Москва, Подъемная, 15	f	large
31286	24440	12	Брянская область, Брянск, Ново-Советская, 82	f	large
31285	24440	11	Брянская область, Брянск, Ново-Советская, 82	f	large
31280	24435	6	Брянская область, Брянск, Ново-Советская, 48	f	large
31279	24435	5	Брянская область, Брянск, Ново-Советская, 48	f	large
31350	24491	76	Брянская область, Брянск, Никитина, 19	f	large
31299	24447	25	Брянская область, Брянск, Нахимова, 124	f	large
31440	24568	166	Брянская область, Брянск, Московский проспект, 103	f	large
31436	24564	162	Брянская область, Брянск, Московский проспект, 88А	f	medium
31435	24564	161	Брянская область, Брянск, Московский проспект, 88А	f	large
31433	24562	159	Брянская область, Брянск, Московский проспект, 64	f	large
31421	24552	147	Брянская область, Брянск, Московский проспект, 46А	f	medium
31415	24547	141	Брянская область, Брянск, Московский проспект, 3	f	large
31322	24465	48	Брянская область, Брянск, Московский м/район, 56	f	large
31336	24478	62	Брянская область, Брянск, Московский м/р-н, 56	f	large
31294	24409	20	Брянская область, Брянск, Молодой Гвардии, 73А	f	large
31293	24409	19	Брянская область, Брянск, Молодой Гвардии, 73А	f	large
31348	24489	74	Брянская область, Брянск, Мичурина, 27А	f	large
31434	24563	160	Брянская область, Брянск, Менжинского, 6	f	large
31432	24561	158	Брянская область, Брянск, Менжинского, 6	f	large
31309	24456	35	Брянская область, Брянск, Медведева, 20	f	large
31298	24446	24	Брянская область, Брянск, Марии Ульяновой, 1	f	large
31319	24462	45	Брянская область, Брянск, Майской Стачки, 6	f	large
31318	24462	44	Брянская область, Брянск, Майской Стачки, 6	f	large
31333	24476	59	Брянская область, Брянск, Магистральный переулок, 1	f	large
31275	24431	1	Брянская область, Брянск, Магистральный переулок	f	large
31386	24527	112	Брянская область, Брянск, Луначарского, 7	f	large
31381	24521	107	Брянская область, Брянск, Луначарского, 41	f	large
31297	24445	23	Брянская область, Брянск, Литейная, 29	f	large
31384	24524	110	Брянская область, Брянск, Ленина проспект, 7	f	large
31372	24512	98	Брянская область, Брянск, Ленина проспект, 72	f	large
31308	24455	34	Брянская область, Брянск, Куйбышева, 101А	f	large
31307	24455	33	Брянская область, Брянск, Куйбышева, 101А	f	large
31429	24558	155	Брянская область, Брянск, Красных Партизан, 35	f	large
31390	24531	116	Брянская область, Брянск, Красноармейская, 79	f	large
31383	24523	109	Брянская область, Брянск, Красноармейская, 13	f	large
31401	24536	127	Брянская область, Брянск, Костычева, 57	f	large
31400	24536	126	Брянская область, Брянск, Костычева, 57	f	large
31399	24536	125	Брянская область, Брянск, Костычева, 57	f	large
31324	24467	50	Брянская область, Брянск, Комсомольская, 2	f	large
31283	24438	9	Брянская область, Брянск, Клубная, 5	f	large
31291	24379	17	Брянская область, Брянск, Клинцовская, 60	f	large
31292	24379	18	Брянская область, Брянск, Клинцовская, 60	f	large
31287	24441	13	Брянская область, Брянск, Кирова, 118А	f	large
31420	24551	146	Брянская область, Брянск, Киевская, 20	f	large
31419	24550	145	Брянская область, Брянск, Киевская, 38	f	large
31382	24522	108	Брянская область, Брянск, Калинина, 66	f	large
31306	24454	32	Брянская область, Брянск, Институтская, 141	f	large
31363	24504	89	Брянская область, Брянск, Инженерная, 12	f	medium
31332	24475	58	Брянская область, Брянск, Ильича, 4	f	large
31354	24495	80	Брянская область, Брянск, Есенина, 20	f	large
31353	24494	79	Брянская область, Брянск, Есенина, 20	f	large
31417	24548	143	Брянская область, Брянск, Ермакова, 30	f	large
31416	24548	142	Брянская область, Брянск, Ермакова, 30	f	large
31367	24507	93	Брянская область, Брянск, Дуки, 74	f	large
31351	24492	77	Брянская область, Брянск, Димитрова, 46	f	large
31344	24486	70	Брянская область, Брянск, Димитрова, 112	f	large
31430	24559	156	Брянская область, Брянск, Дзержинского, 2А	f	large
31428	24557	154	Брянская область, Брянск, Дзержинского, 32	f	large
31380	24520	106	Брянская область, Брянск, Горького, 20	f	large
31323	24466	49	Брянская область, Брянск, Гончарова переулок, 19	f	large
31379	24519	105	Брянская область, Брянск, Гагарина бульвар, 18	f	large
31316	24460	42	Брянская область, Брянск, Брянской Пролетарской Дивизии, 13	f	large
31405	24537	131	Брянская область, Брянск, Брянского Фронта, 16	f	large
31404	24537	130	Брянская область, Брянск, Брянского Фронта, 16	f	large
31403	24537	129	Брянская область, Брянск, Брянского Фронта, 16	f	large
31402	24537	128	Брянская область, Брянск, Брянского Фронта, 16	f	large
31304	24452	30	Брянская область, Брянск, Болховская, 59	f	large
31438	24566	164	Брянская область, Брянск, Богдана Хмельницкого, 81А	f	large
31328	24471	54	Брянская область, Брянск, Бежицкая, 187	f	large
31339	24481	65	Брянская область, Брянск, Афанасьева, 26	f	large
31341	24483	67	Брянская область, Брянск, Академика Королева, 7	f	large
31398	24535	124	Брянская область, Брянск, Авиационная, 24	f	large
31397	24535	123	Брянская область, Брянск, Авиационная, 24	f	large
31396	24535	122	Брянская область, Брянск, Авиационная, 24	f	large
31345	24487	71	Брянская область, Брянск, Абашева, 3а	f	large
31310	24457	36	Брянская область, Брянск, 50 Лет Октября бульвар, 4	f	large
31349	24490	75	Брянская область, Брянск, 2-я Мичурина, 1	f	large
31395	24534	121	Брянская область, Брянск, 2-й Станке Димитрова проезд, 2	f	large
31394	24534	120	Брянская область, Брянск, 2-й Станке Димитрова проезд, 2	f	large
31393	24534	119	Брянская область, Брянск, 2-й Станке Димитрова проезд, 2	f	large
31392	24533	118	Брянская область, Брянск, 1-й Станке Димитрова проезд, 2	f	large
31358	24499	84	Брянская область, Брянск, Тельмана, 78	f	large
31369	24509	95	Брянская область, Брянск, Калинина, 223	f	large
32342	25454	1068	Брянская область, Унечский район, поселок Шулаковка, Советская, 36	t	small
32315	25428	1041	Брянская область, Унечский район, Унеча, Чапаева, 46	f	large
32312	25425	1038	Брянская область, Унечский район, Унеча, Совхозная, 1	f	large
32314	25427	1040	Брянская область, Унечский район, Унеча, Попова, 8	f	large
32313	25426	1039	Брянская область, Унечский район, Унеча, Первомайская, 22	f	large
32317	25430	1043	Брянская область, Унечский район, Унеча, Октябрьская, 26	f	large
32318	25431	1044	Брянская область, Унечский район, Унеча, Луначарского, 38	f	large
32316	25429	1042	Брянская область, Унечский район, Унеча, Ленина, 98Б	f	large
32311	25424	1037	Брянская область, Унечский район, Унеча, Комсомольская, 18	f	large
32310	25423	1036	Брянская область, Унечский район, Унеча, Комсомольская, 3	f	large
32309	25422	1035	Брянская область, Унечский район, Унеча, Комсомольская, 10	f	large
32319	25371	1045	Брянская область, Унечский район, Унеча, Иванова, 26	f	large
32321	25433	1047	Брянская область, Унечский район, Унеча, Гомельская, 10	f	small
32320	25432	1046	Брянская область, Унечский район, Унеча, Володарского, 113	f	large
32346	25458	1072	Брянская область, Унечский район, поселок Староселье, Новоселов, 2	f	medium
32343	25455	1069	Брянская область, Унечский район, поселок Старая Гута, Садовая, 7	f	medium
32322	25434	1048	Брянская область, Унечский район, поселок Слобода-Селецкая, Октябрьская, 19	f	small
32325	25437	1051	Брянская область, Унечский район, поселок Рюхово, Октябрьская, 58	f	medium
32327	25439	1053	Брянская область, Унечский район, поселок Рохманово, Центральная, 2	f	small
32344	25456	1070	Брянская область, Унечский район, поселок Робчик, Щорса, 21	t	small
32348	25460	1074	Брянская область, Унечский район, поселок Пучковка, Луговая, 5	f	small
32332	25444	1058	Брянская область, Унечский район, поселок Писаревка, Школьная, 24	f	medium
32329	25441	1055	Брянская область, Унечский район, поселок Новые Ивайтенки, Зеленая, 4А	f	medium
32334	25446	1060	Брянская область, Унечский район, поселок Найтоповичи, Октябрьская, 18	f	medium
32336	25448	1062	Брянская область, Унечский район, Лыщичи, Щорса, 9	f	small
32347	25459	1073	Брянская область, Унечский район, поселок Лизогубовка, Советская, 11	f	small
32331	25443	1057	Брянская область, Унечский район, поселок Красновичи, Школьная, 2	f	medium
32339	25451	1065	Брянская область, Унечский район, поселок Коробоничи, Центральная, 29Б	f	small
32340	25452	1066	Брянская область, Унечский район, поселок Коробоничи, Сосновый переулок, 1А	f	small
31842	24960	568	Брянская область, Унечский район, поселок Займище, Школьная, 2	f	large
31844	24962	570	Брянская область, Унечский район, поселок Займище, Буденного, 72а	f	medium
32330	25442	1056	Брянская область, Унечский район, поселок Задубенье, Школьная, 63	f	small
31457	24584	183	Брянская область, Унечский район, поселок Добрик, Здание сельской администрации	f	small
32333	25445	1059	Брянская область, Унечский район, поселок Добрик, Центральная, 61	f	small
31905	25023	631	Брянская область, Унечский район, поселок Высокое, Цветочная, 33	f	small
32335	25447	1061	Брянская область, Унечский район, поселок Брянкустичи, Первомайская, 1А	f	medium
32269	25383	995	Брянская область, Унечский район, поселок Бородинка, Лесная , 14, СДК	t	small
32341	25453	1067	Брянская область, Унечский район, поселок Белогорщ, Мглинская, 49	f	small
32324	25436	1050	Брянская область, Унечский район, поселок Аленовка, Переулок Совхозный, 4А	f	small
32274	25388	1000	Брянская область, Трубчевский район, поселок Юрово, Центральная, 6, СДК	f	small
32294	25407	1020	Брянская область, Трубчевский район, поселок Хотьяновка, СДК	f	small
32286	25399	1012	Брянская область, Трубчевский район, поселок Филипповичи, Новая, 1	f	small
32299	25412	1025	Брянская область, Трубчевский район, поселок Усох, СДК	f	medium
32262	25376	988	Брянская область, Трубчевский район, Трубчевск, Советская, 56	f	large
32264	25378	990	Брянская область, Трубчевский район, Трубчевск, Луначарского, 60	f	large
32267	25381	993	Брянская область, Трубчевский район, Трубчевск, Ленина, 79	f	large
32263	25377	989	Брянская область, Трубчевский район, Трубчевск, Ленина, 85	f	large
32268	25382	994	Брянская область, Трубчевский район, Трубчевск, Комсомольская, 2	f	large
32266	25380	992	Брянская область, Трубчевский район, Трубчевск, Володарского, 3	f	medium
32265	25379	991	Брянская область, Трубчевский район, Трубчевск, Володарского, 4	f	large
32283	25396	1009	Брянская область, Трубчевский район, поселок Телец, Трубчевская , 25, здание администрации	f	medium
32304	25417	1030	Брянская область, Трубчевский район, поселок Семячки, здание администрвации	f	small
32289	25402	1015	Брянская область, Трубчевский район, поселок Селец, Селецкая СОШ	f	medium
32291	25404	1017	Брянская область, Трубчевский район, поселок Сагутьево, здание магазина	f	small
32282	25395	1008	Брянская область, Трубчевский район, поселок Рябчевск, Строительная , 2, здание администрации	f	small
32302	25415	1028	Брянская область, Трубчевский район, поселок Радутино, СДК	f	small
32301	25414	1027	Брянская область, Трубчевский район, поселок Радинская, здание ФАП	t	small
32278	25391	1004	Брянская область, Трубчевский район, поселок Плюсково, Молодежная , 20, Плюсковская СОШ	f	small
32276	25285	1002	Брянская область, Трубчевский район, поселок Острая Лука, Октябрьская , 33, здание магазина	t	small
32307	25420	1033	Брянская область, Трубчевский район, поселок Молчаново, СДК	t	small
32280	25393	1006	Брянская область, Трубчевский район, поселок Манцурово, Молодежная, 15, СДК	f	small
32287	25400	1013	Брянская область, Трубчевский район, поселок Макарзно, СДК	f	small
32277	25390	1003	Брянская область, Трубчевский район, поселок Любожичи, Центральная , 4, Любожичский СДК	f	small
32290	25403	1016	Брянская область, Трубчевский район, поселок Любец, СДК	t	small
32279	25392	1005	Брянская область, Трубчевский район, поселок Ложки, Ложковская, 18, контора ООО Арсеналец	f	small
32288	25401	1014	Брянская область, Трубчевский район, поселок Кветунь, СДК	f	small
32298	25411	1024	Тверская область, Кувшиновский район, поселок Городцы	f	medium
32297	25410	1023	Брянская область, Трубчевский район, поселок Городцы, здание администрации	f	medium
32296	25409	1022	Брянская область, Трубчевский район, поселок Городцы, СДК	f	medium
32281	25394	1007	Брянская область, Трубчевский район, поселок Голубичи, Деснянская, 62, СДК	f	small
32275	25389	1001	Брянская область, Трубчевский район, поселок Гнилево, Центральная, 6, СДК	f	small
32293	25406	1019	Брянская область, Трубчевский район, поселок Глыбочка, Глыбоченская ООШ	f	small
32308	25421	1034	Брянская область, Трубчевский район, поселок Бобовня, здание конторы МУП Бобовня	f	small
32271	25385	997	Брянская область, Трубчевский район, поселок Белая Березка, Ленина, 6А, кинотеатр	f	large
32270	25384	996	Брянская область, Трубчевский район, поселок Белая Березка, Ленина, 12, Центр ДТ Юность	f	large
32272	25386	998	Брянская область, Трубчевский район, поселок Белая Березка, Дзержинского, 4, здание поселковой администрации	f	large
32273	25387	999	Брянская область, Трубчевский район, поселок Белая Березка, Калинина, 11, СДК	f	large
32292	25405	1018	Брянская область, Трубчевский район, поселок Алешенка, Алешенская СОШ	f	small
32305	25418	1031	Брянская область, Трубчевский район, поселок Аладьино, здание ООО "Молочное"	f	small
32231	25344	957	Брянская область, Суражский район, Сураж, Октябрьская, 81	f	large
32230	25343	956	Брянская область, Суражский район, Сураж, Ленина, 52	f	large
32223	25336	949	Брянская область, Суражский район, Сураж, Ленина, 84	f	large
32224	25337	950	Брянская область, Суражский район, Сураж, Комсомольская, 46	f	large
32225	25338	951	Брянская область, Суражский район, Сураж, Ворошилова, 76	f	medium
32229	25342	955	Брянская область, Суражский район, Сураж, Белорусская, 60	f	medium
32228	25341	954	Брянская область, Суражский район, Сураж, Белорусская, 66	f	medium
32226	25339	952	Брянская область, Суражский район, Сураж, Белорусская, 150а	f	large
32227	25340	953	Брянская область, Суражский район, Сураж, 29 квартал, здание детского сада Солнышко	f	small
32243	25356	969	Брянская область, Суражский район, поселок Струженка, Новая, 8	f	small
32258	25372	984	Брянская область, Суражский район, поселок Старая Кашовка, здание начальной общеобразовательной школы	f	small
32242	25324	968	Брянская область, Суражский район, поселок Слище, Советская, 71а	f	small
32166	25279	892	Брянская область, Суражский район, поселок Селище, Клинцовская, 12-А	f	small
32236	25349	962	Брянская область, Суражский район, поселок Октябрьское, Ковалевка, 1	f	small
32256	25369	982	Брянская область, Суражский район, поселок Овчинец, Молодежная, 1а	f	small
32255	25368	981	Брянская область, Суражский район, поселок Новый Дроков, пер.Молодежный, 10	f	small
32253	25366	979	Брянская область, Суражский район, поселок Нивное, Ленина , 57	f	medium
32252	25365	978	Брянская область, Суражский район, поселок Ляличи, Мичурина, 10	f	medium
32250	25363	976	Брянская область, Суражский район, поселок Лопазна, Дубиновка, 61	f	small
32246	25359	972	Брянская область, Суражский район, поселок Лесной, Школьная, 6	f	small
32244	25357	970	Брянская область, Суражский район, поселок Кулаги, Октябрьская, 23	f	medium
32247	25360	973	Брянская область, Суражский район, поселок Красный Завод, здание МАУ Детский санаторий Ипуть	f	small
32233	25346	959	Брянская область, Суражский район, поселок Красная Слобода, Гагарина, 8а	f	small
32251	25364	977	Брянская область, Суражский район, поселок Костеничи, Заречье, 17а	f	small
32248	25361	974	Брянская область, Суражский район, поселок Каменск, .Новая, 1а	f	small
32257	25370	983	Брянская область, Суражский район, поселок Калинки, Садовая, 2	f	medium
32245	25358	971	Брянская область, Суражский район, поселок Жемердеевка, здание сельского клуба	f	small
32238	25351	964	Брянская область, Суражский район, поселок Жастково, Центральная, 26	f	small
32259	25373	985	Брянская область, Суражский район, поселок Душатино, Школьная, 1	f	small
32240	25354	966	Брянская область, Суражский район, поселок Дубровка, Центральная, 3	f	small
32237	25350	963	Брянская область, Суражский район, поселок Дегтяревка, пер.Садовый, 4	f	small
32241	25355	967	Брянская область, Суражский район, поселок Далисичи, Октябрьская, 5	f	small
32260	25374	986	Брянская область, Суражский район, поселок Гудовка, здание основной общеобразовательной школы	f	small
32249	25362	975	Брянская область, Суражский район, поселок Глуховка, Садовая, 28	f	small
32239	25353	965	Брянская область, Суражский район, поселок Вьюково, пер.Сентябрьский, 1	f	small
32254	25367	980	Брянская область, Суражский район, поселок Высокоселище, Молодежная, 1	f	small
32232	25345	958	Брянская область, Суражский район, поселок Влазовичи, Ленина, 24	f	medium
31869	24987	595	Брянская область, Суражский район, поселок Владимировка, здание Владимировского сельского клуба	f	small
31908	25026	634	Брянская область, Суражский район, поселок Беловодка, 60 лет Октября, 39	f	medium
32234	25347	960	Брянская область, Суражский район, поселок Андреевка, Октябрьская, 16	t	small
32219	25332	945	Брянская область, Суземский район, поселок Ямное, Заречная, 22	f	small
32213	25326	939	Брянская область, Суземский район, поселок Щепетлево, Молодёжная, 1	f	small
32221	25334	947	Брянская область, Суземский район, поселок Холмечи, Будённого, 77	f	medium
32201	25313	927	Брянская область, Суземский район, поселок Суземка, пер. 1-й Трубчевский, 14	f	medium
32199	25311	925	Брянская область, Суземский район, поселок Суземка, Площадь Ленина, 6	f	large
32200	25312	926	Брянская область, Суземский район, поселок Суземка, Переулок Интернациональный, 5	f	large
32202	25314	928	Брянская область, Суземский район, поселок Суземка, Первомайская, 59	f	large
32212	25325	938	Брянская область, Суземский район, поселок Страчово, им. Мореева, 19	f	small
32216	25329	942	Брянская область, Суземский район, поселок Семеновск, Центральная, 1	f	small
32220	25333	946	Брянская область, Суземский район, поселок Селичня, Школьная, 6	f	medium
32211	25323	937	Брянская область, Суземский район, поселок Полевые Новоселки, Молодёжная, 6	f	small
32210	25322	936	Брянская область, Суземский район, поселок Павловичи, Молодёжная, 24	f	small
32218	25331	944	Брянская область, Суземский район, поселок Новенькое, Школьная, 2	f	small
32217	25330	943	Брянская область, Суземский район, поселок Новая Погощь, Центральная, 11	f	small
32222	25335	948	Брянская область, Суземский район, Нерусса, станция Лесная, 24	f	small
32206	25318	932	Брянская область, Суземский район, поселок Нерусса, Центральная, 21	f	small
32215	25328	941	Брянская область, Суземский район, поселок Негино, Центральная, 83	f	small
32214	25327	940	Брянская область, Суземский район, поселок Невдольск, Центральная, 68	f	small
32205	25317	931	Брянская область, Суземский район, поселок Красная Слобода, Школьная, 12	f	small
32207	25319	933	Брянская область, Суземский район, поселок Кокоревка, Гагарина, 1	f	large
32209	25321	935	Брянская область, Суземский район, поселок Зерново, Молодёжная, 15	f	small
32204	25316	930	Брянская область, Суземский район, поселок Денисовка, пер. Речной, 1	f	small
32203	25315	929	Брянская область, Суземский район, поселок Горожанка, Лесная, 1	t	small
32208	25320	934	Брянская область, Суземский район, поселок Алешковичи, пер. Советский, 1	f	small
32182	25296	908	Брянская область, Стародубский район, поселок Шкрябино, Садовая, 3	f	medium
32168	25281	894	Брянская область, Стародубский район, поселок Чубковичи, Зеленая Дубрава, 48	f	small
32176	25290	902	Брянская область, Стародубский район, поселок Тарасовка, Новая, 25	f	small
32194	25309	920	Брянская область, Стародубский район, Стародуб, Урицкого, 24-А	f	large
32195	25309	921	Брянская область, Стародубский район, Стародуб, Урицкого, 24-А	f	large
32189	25304	915	Брянская область, Стародубский район, Стародуб, Совхозная, 49	f	large
32192	25307	918	Брянская область, Стародубский район, Стародуб, Семашко, 11	f	large
32196	25310	922	Брянская область, Стародубский район, Стародуб, Ленина, 2	f	large
32197	25273	923	Брянская область, Стародубский район, Стародуб, Ленина, 14	f	large
32198	25297	924	Брянская область, Стародубский район, Стародуб, Красных Партизан, 21-а	f	large
32193	25308	919	Брянская область, Стародубский район, Стародуб, Краснооктябрьская, 79-А	f	large
32191	25306	917	Брянская область, Стародубский район, Стародуб, Краснооктябрьская, 12	f	large
32190	25305	916	Брянская область, Стародубский район, Стародуб, Краснооктябрьская, 9	f	large
32151	25263	877	Брянская область, Стародубский район, поселок Солова, Пролетарская, 64-А	t	small
32178	25292	904	Брянская область, Стародубский район, поселок Случок, пер. Коммунистический, 5	t	small
32183	25298	909	Брянская область, Стародубский район, поселок Пятовск, Стародубская, 16	f	small
32161	25274	887	Брянская область, Стародубский район, поселок Пролетарское, Молодежная, 1	f	small
32185	25300	911	Брянская область, Стародубский район, поселок Понуровка, Бриггена, 76-А	f	small
32154	25266	880	Брянская область, Стародубский район, поселок Пестриково, Центральная, 26	t	small
32160	25272	886	Брянская область, Стародубский район, поселок Пантусово, Школьная, 7-А	f	small
32181	25295	907	Брянская область, Стародубский район, поселок Остроглядово, Мацкевича, 12-А	f	small
31920	25038	646	Брянская область, Стародубский район, поселок Осколково, Советская, 10	f	small
32184	25299	910	Брянская область, Стародубский район, поселок Новополье, Садовая, 1-А	t	small
32164	25277	890	Брянская область, Стародубский район, поселок Новомлынка, переулок Школьный, 1	f	small
32173	25287	899	Брянская область, Стародубский район, поселок Новое Село, Озерная, 20	f	small
32171	25284	897	Брянская область, Стародубский район, поселок Нижнее, Школьная, 24	f	small
32179	25293	905	Брянская область, Стародубский район, поселок Мохоновка, Пролетарская, 46	t	small
32175	25289	901	Брянская область, Стародубский район, поселок Мишковка, Центральная, 11-Г	t	medium
32156	25268	882	Брянская область, Стародубский район, поселок Михайловск, Садовая, 11-А	f	small
32159	25271	885	Брянская область, Стародубский район, поселок Мереневка, Первомайская, 97-А	t	small
32172	25286	898	Брянская область, Стародубский район, поселок Меленск, Комсомольская, 1	f	large
32174	25288	900	Брянская область, Стародубский район, поселок Меженики, Садовая, 29	f	small
32146	25258	872	Брянская область, Стародубский район, поселок Лужки, Советская, 11	t	small
32149	25261	875	Брянская область, Стародубский район, поселок Ломаковка, Семеновская, 24-а	f	small
32170	25283	896	Брянская область, Стародубский район, поселок Логоватое, Трудовая, 82	f	small
32157	25269	883	Брянская область, Стародубский район, поселок Левенки, Садовая, 26	f	small
32188	25303	914	Брянская область, Стародубский район, поселок Курковичи, Луговая, 1	f	small
32169	25282	895	Брянская область, Стародубский район, поселок Крюков, Советская, 14	t	small
32148	25260	874	Брянская область, Стародубский район, поселок Крутая Буда, Набережная, 33	f	small
32162	25275	888	Брянская область, Стародубский район, поселок Красный, Культуры, 5	f	medium
32155	25267	881	Брянская область, Стародубский район, поселок Ковалево, Новая, 11	f	small
32163	25276	889	Брянская область, Стародубский район, поселок Картушино, Советская, 63	f	small
32167	25280	893	Брянская область, Стародубский район, поселок Камень, Центральная, 62	f	small
32153	25265	879	Брянская область, Стародубский район, поселок Ильбово, Центральная, 84	f	small
32165	25278	891	Брянская область, Стародубский район, поселок Запольские Халеевичи, Комсомольская, 10	f	medium
32150	25262	876	Брянская область, Стародубский район, поселок Елионка, Магистральная, 2	f	small
32177	25291	903	Брянская область, Стародубский район, поселок Дохновичи, Магистральная, 24	f	medium
32158	25270	884	Брянская область, Стародубский район, поселок Десятуха, площадь Ленина, 7	f	large
32187	25302	913	Брянская область, Стародубский район, поселок Демьянки, Садовая, 1-А	t	small
32180	25294	906	Брянская область, Стародубский район, поселок Дареевичи, Садовая, 10	t	small
32152	25264	878	Брянская область, Стародубский район, поселок Гарцево, Школьная, 4	f	small
32145	25257	871	Брянская область, Стародубский район, поселок Воронок, Площадь 1 Мая, 2	t	medium
32147	25259	873	Брянская область, Стародубский район, поселок Алейниково, Центральная, 9-А	f	small
32186	25301	912	Брянская область, Стародубский район, поселок Азаровка, Комсомольская, 8	f	small
32120	25235	846	Брянская область, Севский район, поселок Шведчики, Центральная, 76	f	small
32116	25231	842	Брянская область, Севский район, поселок Чемлыж, Лушникова, 30	f	small
32110	25225	836	Брянская область, Севский район, поселок Хинель, Парковая, 17	f	small
32124	25239	850	Брянская область, Севский район, поселок Треобортное, Новая, 5	f	small
32128	25243	854	Брянская область, Севский район, поселок Сенное, Молодежная, 32	f	small
32132	25247	858	Брянская область, Севский район, Севск, Советская, 6	f	large
32131	25246	857	Брянская область, Севский район, Севск, С.Щедрина, 23	f	large
32130	25245	856	Брянская область, Севский район, Севск, Ленина, 49	f	large
32109	25224	835	Брянская область, Севский район, поселок Рабочий, Садовая, 10	f	small
32112	25227	838	Брянская область, Севский район, поселок Поздняшовка, Центральная, 14	f	small
32106	25221	832	Брянская область, Севский район, поселок Подывотье, Молодежная, 32	f	small
32107	25222	833	Брянская область, Севский район, поселок Подлесные Новоселки, Центральная, 22	f	small
31456	24583	182	Брянская область, Севский район, поселок Погребы, Здание Дома культуры	f	large
32108	25223	834	Брянская область, Севский район, поселок Первомайское, 65-й Армии, 4а	f	small
32056	25174	782	Брянская область, Севский район, поселок Первомайский, Школьная, 9 А	f	medium
32119	25234	845	Брянская область, Севский район, поселок Новоямское, Молодежная, 17	f	small
32123	25238	849	Брянская область, Севский район, поселок Некислица, 8 Марта, 58	f	small
32115	25230	841	Брянская область, Севский район, поселок Марицкий Хутор, Тихая Долина, 3	f	small
32125	25240	851	Брянская область, Севский район, поселок Лемешовка, Центральная, 4	f	small
32122	25237	848	Брянская область, Севский район, поселок Кривцово, Провинциальная, 1а	f	small
32111	25226	837	Брянская область, Севский район, поселок Косицы, Школьный переулок, 3	f	small
32118	25233	844	Брянская область, Севский район, поселок Заулье, Копылова, 1	f	small
32129	25244	855	Брянская область, Севский район, поселок Заречный, Молодежная, 6	f	small
32133	25248	859	Брянская область, Севский район, поселок Дубрава, Миловидова, 27	f	small
32126	25241	852	Брянская область, Севский район, поселок Доброводье, Ульянова, 63	f	small
32121	25236	847	Брянская область, Севский район, поселок Голышино, Центральная, 22	f	small
32127	25242	853	Брянская область, Севский район, поселок Гапоново, Центральная, 69	f	small
32099	25215	825	Брянская область, Рогнединский район, поселок Шаровичи, Центральная, 28	f	small
32105	25220	831	Брянская область, Рогнединский район, поселок Хариново, Школьная, 8	f	small
32104	25219	830	Брянская область, Рогнединский район, поселок Тюнино, Специалистов, 11	f	small
32098	25214	824	Брянская область, Рогнединский район, поселок Старое Хотмирово, Школьная, 1	f	small
32097	25213	823	Брянская область, Рогнединский район, поселок Снопот, Центральная, 2	f	small
32091	25208	817	Брянская область, Рогнединский район, поселок Рогнедино, Ленина, 40	f	large
32092	14697	818	Брянская область, Рогнединский район, поселок Пацынь, Молодежная, 11	f	small
32103	25218	829	Брянская область, Рогнединский район, поселок Осовик, Школьная, 19	f	small
32095	25211	821	Брянская область, Рогнединский район, поселок Лутовиновка, Набережная, 36	t	small
31675	24795	400	Брянская область, Рогнединский район, поселок Летошники, Здание поселенческого Дома культуры	f	medium
32117	25232	843	Брянская область, Рогнединский район, поселок Княгинино, Молодежная, 22	f	small
32102	25217	828	Брянская область, Рогнединский район, поселок Гобики, Советская, 3	f	small
32101	25217	827	Брянская область, Рогнединский район, поселок Гобики, Советская, 3	f	small
32093	25209	819	Брянская область, Рогнединский район, поселок Вороново, имени Старостина, 15	t	small
32064	25182	790	Брянская область, Почепский район, поселок Шуморово, Тупицина, 1	f	small
32086	25203	812	Брянская область, Почепский район, поселок Чопово, Школьная, 3	t	small
32069	14695	795	Брянская область, Почепский район, поселок Тубольцы, Лесная, 5	f	small
32062	25180	788	Брянская область, Почепский район, поселок Третьяки, Клубная, 8	t	small
32073	25190	799	Брянская область, Почепский район, поселок Супрягино, Молодежная, 5	f	small
32088	25205	814	Брянская область, Почепский район, поселок Старопочелье, Центральная, 10 А	f	small
32083	25200	809	Брянская область, Почепский район, поселок Старокрасная Слобода, Школьный переулок, 14 Б	f	medium
32057	25175	783	Брянская область, Почепский район, поселок Сотниково, Колхозная, 13	f	small
32082	25199	808	Брянская область, Почепский район, поселок Семцы, Щемелинина, 34	f	medium
32079	25196	805	Брянская область, Почепский район, поселок Светолово, улица Советская, 11	f	small
32085	25202	811	Брянская область, Почепский район, поселок Рогово, Центральная, 32	f	small
32046	25164	772	Брянская область, Почепский район, поселок Рамасуха, Почепская, 1	f	small
32284	25397	1010	Брянская область, Почепский район, поселок Прогресс, Володарского , 2, здание Трубчевской метеостанции	f	small
32045	25163	771	Брянская область, Почепский район, Почеп, Усиевича, 8	f	large
32043	25161	769	Брянская область, Почепский район, Почеп, Стародубская, 82	f	large
32042	25160	768	Брянская область, Почепский район, Почеп, Октябрьская площадь, 1	f	large
32038	25156	764	Брянская область, Почепский район, Почеп, Октябрьская площадь, 2 А	f	large
32044	25162	770	Брянская область, Почепский район, Почеп, Ново-Полянская, 1	f	large
32041	25159	767	Брянская область, Почепский район, Почеп, Ново-Затинская, 48	f	medium
32039	25157	765	Брянская область, Почепский район, Почеп, Колхозная, 5	f	large
32071	25188	797	Брянская область, Почепский район, поселок Польники, Польниковская, 42	f	small
32058	25176	784	Брянская область, Почепский район, поселок Подбелово, Школьная, 5	f	small
32070	25187	796	Брянская область, Почепский район, поселок Первомайское, Советская, 2	f	medium
32060	25178	786	Брянская область, Почепский район, поселок Папсуевка, Центральная, 24	t	small
83601	57145	2784	Москва, Пенягинская, 14	f	large
32050	25168	776	Брянская область, Почепский район, поселок Октябрьский, Школьная, 1	t	small
32067	25185	793	Брянская область, Почепский район, поселок Милечь, Центральная, 58 Г	f	small
32065	25183	791	Брянская область, Почепский район, поселок Красный Рог, 2-й переулок Толстого, 7 А	f	large
32303	25416	1029	Брянская область, Почепский район, поселок Котляково, здание администрации	f	small
32048	25166	774	Брянская область, Почепский район, поселок Котляково, Гагарина, 17А	f	small
32076	25193	802	Брянская область, Почепский район, поселок Козорезовка, Набережная, 42	f	small
32049	25167	775	Брянская область, Почепский район, поселок Кожемяки, Школьная, 8	f	small
32054	25172	780	Брянская область, Почепский район, поселок Калачево, Набережная , 2-а	f	small
32089	25206	815	Брянская область, Почепский район, поселок Житня, Школьная, 6	f	small
32061	25179	787	Брянская область, Почепский район, поселок Доманичи, улица Почепская, 1 А	t	medium
32059	25177	785	Брянская область, Почепский район, поселок Дмитрово, Дмитировская, 55	f	small
32080	25197	806	Брянская область, Почепский район, поселок Громыки, Клубный, 1 В	f	small
32074	25191	800	Брянская область, Почепский район, поселок Глазово, Центральная, 45	f	small
31921	25039	647	Брянская область, Почепский район, поселок Вормино, им. Новикова, 3	f	small
32081	25198	807	Брянская область, Почепский район, поселок Воложино, Громышева, 4	f	small
32055	25173	781	Брянская область, Почепский район, поселок Витовка, Почепская, 94 А	f	medium
32075	25192	801	Брянская область, Почепский район, поселок Верхняя Злобинка, Советская, 14	f	small
32087	25204	813	Брянская область, Почепский район, поселок Васьковичи, Садовая, 10 А	f	small
32053	25171	779	Брянская область, Почепский район, поселок Валуец, Клубная, 12	f	medium
32051	25169	777	Брянская область, Почепский район, поселок Бельково, Центральная, 52	f	small
32052	25170	778	Брянская область, Почепский район, поселок Балыки, Мира, 41	f	small
32047	25165	773	Брянская область, Почепский район, поселок Баклань, Ленина, 14	f	medium
32063	25181	789	Брянская область, Почепский район, поселок Алексеевск, Заречная, 42	f	small
32034	25152	760	Брянская область, Погарский район, поселок Юдиново, Бойня, 1	f	medium
32027	25145	753	Брянская область, Погарский район, поселок Чеховка, Советская, 53-а	f	medium
32032	25150	758	Брянская область, Погарский район, поселок Чаусы, Кооперативная, 11	t	small
32001	25119	727	Брянская область, Погарский район, поселок Чайкино, Светлая	f	medium
32029	25147	755	Брянская область, Погарский район, поселок Суворово, Первомайская, 35-а	f	medium
32023	25141	749	Брянская область, Погарский район, поселок Стечна, Новая, 3-а	f	small
32033	25151	759	Брянская область, Погарский район, поселок Сопычи, Садовя, 3	t	small
32002	25120	728	Брянская область, Погарский район, поселок Синицкий, Козина, 11	f	small
32010	25128	736	Брянская область, Погарский район, поселок Савостьяны, Воробьевка, 1-а	f	small
32026	25144	752	Брянская область, Погарский район, поселок Романовка, Заречная, 34	f	small
32328	25440	1054	Брянская область, Погарский район, поселок Рассуха, пер. Брянский, 2	f	small
32338	25450	1064	Брянская область, Погарский район, поселок Рассуха, Линейная, 39	f	small
32020	25138	746	Брянская область, Погарский район, поселок Прирубки, Новая, 6	f	small
32018	25136	744	Брянская область, Погарский район, поселок Посудичи	f	medium
31987	25105	713	Брянская область, Погарский район, поселок Погар, улица Фрунзе, 24	f	medium
31989	25107	715	Брянская область, Погарский район, поселок Погар, улица Урицкого, 90	f	medium
31984	25102	710	Брянская область, Погарский район, поселок Погар, площадь Советская, 1	f	large
31985	25103	711	Брянская область, Погарский район, поселок Погар, Чехова, 9	f	large
31988	25106	714	Брянская область, Погарский район, поселок Погар, Октябрьская, 112	f	small
31986	25104	712	Брянская область, Погарский район, поселок Погар, Ленина, 115	f	medium
31983	25101	709	Брянская область, Погарский район, поселок Погар, Гагарина, 26	f	large
31992	25110	718	Брянская область, Погарский район, поселок Песчанки, Кизеевская, 45	f	small
32004	25122	730	Брянская область, Погарский район, поселок Перегон, Пушкина, 113	f	small
32012	25130	738	Брянская область, Погарский район, поселок Михновка, Советская, 26-а	f	small
30574	23752	553	Белгородская область, Губкин, 9 Января, 2	f	medium
32019	25137	745	Брянская область, Погарский район, поселок Мадеевка, Полевая, 1	f	medium
32006	25124	732	Брянская область, Погарский район, поселок Лукин, Центральная, 20-б	f	small
31991	25109	717	Брянская область, Погарский район, поселок Лобки, Пушкина, 22	f	small
32030	25148	756	Брянская область, Погарский район, поселок Курово, Первомайская, 25-б	f	medium
31999	25117	725	Брянская область, Погарский район, поселок Красный Угол, Мичурина, 6	f	small
32014	25132	740	Брянская область, Погарский район, поселок Кистер, Центральная, 11	f	small
32013	25131	739	Брянская область, Погарский район, поселок Кистер, Центральная, 43	f	small
32028	25146	754	Брянская область, Погарский район, поселок Карбовка, Партизанская, 50	f	small
32037	25155	763	Брянская область, Погарский район, поселок Казиловка, Зеленая, 15	t	small
31998	25116	724	Брянская область, Погарский район, поселок Исаевка, Первомайская, 19	t	small
32035	25153	761	Брянская область, Погарский район, поселок Заречное, Центральная, 67-б	f	small
31996	25114	722	Брянская область, Погарский район, поселок Запесонье, Центральная, 14-а	f	small
32022	25140	748	Брянская область, Погарский район, поселок Жигалки, Луговая, 22	f	small
31995	25113	721	Брянская область, Погарский район, поселок Евдоколье, Советская, 41	t	small
32009	25127	735	Брянская область, Погарский район, поселок Долботово, Новая, 19-а	f	small
32005	25123	731	Брянская область, Погарский район, поселок Дареевск, Ленина, 27	f	small
32015	25133	741	Брянская область, Погарский район, поселок Гудовка, Центральная, 12	f	small
32024	25142	750	Брянская область, Погарский район, поселок Грязивец, Центральная, 37	f	small
32007	25125	733	Брянская область, Погарский район, поселок Гринево, Новая, 7-а	f	medium
32003	25121	729	Брянская область, Погарский район, поселок Городище, Чапаева, 2	f	medium
32000	25118	726	Брянская область, Погарский район, поселок Гетуновка, Центральная, 18	f	medium
31994	25112	720	Брянская область, Погарский район, поселок Витемля, Школьная, 8	f	small
31997	25115	723	Брянская область, Погарский район, поселок Василевка, Советская, 7	f	small
31993	25111	719	Брянская область, Погарский район, поселок Вадьковка, Советская, 3	f	medium
32025	25143	751	Брянская область, Погарский район, поселок Бугаевка, Светлая, 32	f	small
32008	25126	734	Брянская область, Погарский район, поселок Бобрик, Школьная, 5	f	small
32036	25154	762	Брянская область, Погарский район, поселок Березовка, Новая, 1-а	f	small
32031	25149	757	Брянская область, Погарский район, поселок Белевица, Советская, 55-а	f	small
32021	25139	747	Брянская область, Погарский район, поселок Балыкино, Центральная, 11	f	small
32017	25135	743	Брянская область, Погарский район, поселок Андрейковичи, Слободская, 20	f	small
32016	25134	742	Брянская область, Погарский район, поселок Андрейковичи, Зеленая, 4	f	small
32011	25129	737	Брянская область, Погарский район, поселок Абарники, Хуторская, 11	f	small
32397	25508	1123	Брянская область, Новозыбковский район, поселок Шеломы, Центральная, 91-А	f	medium
32395	25506	1121	Брянская область, Новозыбковский район, село Халеевичи, Набережная, 21	f	small
32392	25503	1118	Брянская область, Новозыбковский район, поселок Тростань, Хутор Сибирский, 30	t	medium
32390	25501	1116	Брянская область, Новозыбковский район, поселок Старый Кривец, Школьная, 1-А	f	small
32389	25500	1115	Брянская область, Новозыбковский район, поселок Старый Вышков, 1 Мая, 2	f	small
32387	25498	1113	Брянская область, Новозыбковский район, поселок Старые Бобовичи, Ленина, 29	f	medium
32394	25505	1120	Брянская область, Новозыбковский район, поселок Сновское, Новая, 28-Б	f	medium
32386	25497	1112	Брянская область, Новозыбковский район, поселок Синий Колодец, Центральный переулок, 3	f	small
31488	24616	214	Брянская область, Новозыбковский район, поселок Отрадное, Советская, 2	f	large
32381	25492	1107	Брянская область, Новозыбковский район, поселок Опытная станция, 1д	f	small
32388	25499	1114	Брянская область, Новозыбковский район, поселок Новые Бобовичи, Советская, 48	f	small
32398	25509	1124	Брянская область, Новозыбковский район, поселок Новое Место, Луговая, 25	f	small
32385	25496	1111	Брянская область, Новозыбковский район, поселок Манюки, Первомайская, 52	t	small
32393	25504	1119	Брянская область, Новозыбковский район, поселок Мамай, Молодежная, 5/2	f	small
32383	25494	1109	Брянская область, Новозыбковский район, поселок Лесная Поляна, Лесная, 6	t	small
32384	25495	1110	Брянская область, Новозыбковский район, поселок Крутоберезка, Восточная, 1	t	small
32379	25490	1105	Брянская область, Новозыбковский район, поселок Катичи, Ленина, 106	f	small
32391	25502	1117	Брянская область, Новозыбковский район, поселок Каташин, Молодежная, 14	f	small
32382	25493	1108	Брянская область, Новозыбковский район, поселок Замишево, Манюковская, 23	f	medium
31453	24580	179	Брянская область, Новозыбковский район, поселок Дубровка, Здание школы	f	small
32380	25491	1106	Брянская область, Новозыбковский район, поселок Деменка, Гагарина, 2а	f	small
32378	25489	1104	Брянская область, Новозыбковский район, поселок Верещаки, Коммунистическая, 64	f	medium
31964	25058	690	Брянская область, Новозыбков городской округ, Новозыбков, РОС, 5	f	large
31977	25095	703	Брянская область, Новозыбков городской округ, Новозыбков, Красногвардейская, 25	f	large
31963	25082	689	Брянская область, Навлинский район, поселок Щегловка, Школьная, 1	f	small
31954	25073	680	Брянская область, Навлинский район, поселок Чичково, Л. Мирошина, 14/2	f	medium
31961	25080	687	Брянская область, Навлинский район, поселок Соколово, Северная, 5	f	small
31960	25079	686	Брянская область, Навлинский район, поселок Синезерки, Школьная, 13	f	medium
31946	25065	672	Брянская область, Навлинский район, поселок Селище, Центральная, 6	f	small
31959	25078	685	Брянская область, Навлинский район, поселок Салтановка, Школьная, 1А	f	small
31958	25077	684	Брянская область, Навлинский район, поселок Салтановка, Молодежная, 35	f	small
31956	25075	682	Брянская область, Навлинский район, поселок Ревны, Центральная, 34	f	small
31955	25074	681	Брянская область, Навлинский район, поселок Пролысово, Центральная, 100	f	small
31944	25063	670	Брянская область, Навлинский район, поселок Прилепы, Центральная, 8	f	small
31953	25072	679	Брянская область, Навлинский район, поселок Приволье, Полевая, 49/1	f	small
31962	25081	688	Брянская область, Навлинский район, поселок Пластовое, Слободская, 2	f	small
31939	25057	665	Брянская область, Навлинский район, поселок Навля, Филиппа Стрельца, 47	f	large
31936	25054	662	Брянская область, Навлинский район, поселок Навля, Леонардо Гарсиа, 12	f	large
31938	25056	664	Брянская область, Навлинский район, поселок Навля, Ленина, 15	f	large
31935	25053	661	Брянская область, Навлинский район, поселок Навля, Ленина, 56	f	large
31937	25055	663	Брянская область, Навлинский район, поселок Навля, Красных Партизан, 23	f	large
31951	25070	677	Брянская область, Навлинский район, поселок Литовня, микрорайон Молодежный, 35	f	small
31950	25069	676	Брянская область, Навлинский район, поселок Лески, Молодежная, 23	f	small
31949	25068	675	Брянская область, Навлинский район, поселок Клюковники, Школьная, 8	f	medium
31957	25076	683	Брянская область, Навлинский район, поселок Зубовка, Советская, 4	f	small
31948	25067	674	Брянская область, Навлинский район, поселок Гремячее, Молодежная, 9	f	small
31559	14694	285	Брянская область, Навлинский район, поселок Глинное, Зеленая, 10	t	small
31947	25066	673	Брянская область, Навлинский район, поселок Вздружное, Центральная, 19	f	small
31945	25064	671	Брянская область, Навлинский район, поселок Бяково, Клубная, 6	f	small
31943	25062	669	Брянская область, Навлинский район, поселок Бутре, Садовая, 19	f	small
31952	25071	678	Брянская область, Навлинский район, поселок Борщево, Центральная, 45	t	small
31990	25108	716	Брянская область, Навлинский район, поселок Борщево, Александра Яковца, 42	f	medium
31940	25059	666	Брянская область, Навлинский район, поселок Алтухово, Вяльцевой, 1А	f	large
31942	25061	668	Брянская область, Навлинский район, поселок Алешинка, Лесная, 28	f	medium
31941	25060	667	Брянская область, Навлинский район, поселок Алексеевка, переулок Дорожный, 1	f	small
31918	25036	644	Брянская область, Мглинский район, поселок Шумарово, пер. Афанасьева, 5	f	medium
31906	25024	632	Брянская область, Мглинский район, поселок Шеверды, Центральная, 3	t	small
31917	25035	643	Брянская область, Мглинский район, поселок Черновица, Советская, 11	f	small
31915	25033	641	Брянская область, Мглинский район, поселок Цинка, Суворова, 14	f	small
31928	25046	654	Брянская область, Мглинский район, поселок Старая Романовка, Молодёжная, 3	f	small
31903	25021	629	Брянская область, Мглинский район, поселок Соколовка, Партизан, 16	f	small
31904	25022	630	Брянская область, Мглинский район, поселок Симонтовка, Цветочная, 1	f	medium
31926	25044	652	Брянская область, Мглинский район, поселок Семки, Колхозная, 24	f	small
31927	25045	653	Брянская область, Мглинский район, поселок Попелевка, Молодёжная, 2	f	small
31912	25030	638	Брянская область, Мглинский район, поселок Новые Чешуйки, Молодёжная, 7А	f	small
31925	25043	651	Брянская область, Мглинский район, поселок Новая Романовка, Школьная, 3	f	medium
31909	25027	635	Брянская область, Мглинский район, поселок Нетяговка, Школьная, 8	f	small
31916	25034	642	Брянская область, Мглинский район, поселок Молодьково, Молодёжная, 14	f	small
31932	25050	658	Брянская область, Мглинский район, Мглин, площадь Советская, 6А	f	large
31933	25051	659	Брянская область, Мглинский район, Мглин, Первомайская, 57	f	large
31934	25052	660	Брянская область, Мглинский район, Мглин, Октябрьская, 148	f	large
31929	25047	655	Брянская область, Мглинский район, Мглин, Кирова, 13	f	large
31930	25048	656	Брянская область, Мглинский район, Мглин, Будённого, 7	f	large
31910	25028	636	Брянская область, Мглинский район, поселок Луговец, Прудная, 10	f	medium
31911	25029	637	Брянская область, Мглинский район, поселок Красные Косары, Садовая, 12	f	small
31914	25032	640	Брянская область, Мглинский район, поселок Католино, Ипутьская, 56	f	small
31924	25042	650	Брянская область, Мглинский район, поселок Дивовка, Молодёжная, 2	f	small
31923	25041	649	Брянская область, Мглинский район, поселок Деремна, Советская, 1	f	small
31919	25037	645	Брянская область, Мглинский район, поселок Ветлевка, Октябрьская, 33	f	medium
31922	25040	648	Брянская область, Мглинский район, поселок Вельжичи, Пролетарская, 5	f	small
31907	25025	633	Брянская область, Мглинский район, поселок Великая Дуброва, Советская, 12	f	small
31913	25031	639	Брянская область, Мглинский район, поселок Быковка, Советская, 2А	f	small
31902	25020	628	Брянская область, Мглинский район, поселок Бурчак, Лесная, 25	t	small
31899	25017	625	Брянская область, Краснорский район, поселок Яловка, Луговая, 7	f	small
31888	25006	614	Брянская область, Краснорский район, поселок Фошное, Центральная, 1	f	small
31900	25018	626	Брянская область, Краснорский район, поселок Увелье, Советская, 54	f	small
31885	25003	611	Брянская область, Краснорский район, поселок Селец, Советская, 52	f	small
31897	25015	623	Брянская область, Краснорский район, поселок Перелазы, Советская, 39	f	medium
31895	25013	621	Брянская область, Краснорский район, поселок Палужская Рудня, Центральная, 1	f	small
31896	25014	622	Брянская область, Краснорский район, поселок Медведи, Центральная, 8	f	small
31894	25012	620	Брянская область, Краснорский район, поселок Макаричи, Центральная, 14	f	small
31892	25010	618	Брянская область, Краснорский район, поселок Любовша, Советская, 2	t	medium
31889	25007	615	Брянская область, Краснорский район, поселок Лотаки, Центральная, 8	f	small
31898	25016	624	Брянская область, Краснорский район, поселок Летяхи, Коммунистическая, 8	f	small
31891	25009	617	Брянская область, Краснорский район, поселок Ларневск, Центральная, 31	f	small
31887	25005	613	Брянская область, Краснорский район, поселок Кургановка, Центральная, 94	f	small
31454	24581	180	Брянская область, Краснорский район, поселок Красное, Здание Дома культуры	f	small
31882	25000	608	Брянская область, Краснорский район, поселок Красная Гора, переулок Московский, 24	f	medium
31881	24999	607	Брянская область, Краснорский район, поселок Красная Гора, Центральная, 1	f	medium
31880	24998	606	Брянская область, Краснорский район, поселок Красная Гора, Куйбышева, 123	f	medium
31879	24997	605	Брянская область, Краснорский район, поселок Красная Гора, Буйневича, 66	f	medium
31877	24995	603	Брянская область, Краснорский район, поселок Красная Гора, Буйневича, 44	f	medium
31876	24994	602	Брянская область, Краснорский район, поселок Красная Гора, Буйневича, 14	f	medium
31878	24996	604	Брянская область, Краснорский район, поселок Красная Гора, Больничная, 55	f	small
31886	25004	612	Брянская область, Краснорский район, поселок Колюды, Центральная, 10	f	small
31890	25008	616	Брянская область, Краснорский район, поселок Кибирщина, Центральная, 2	f	small
82433	56427	1602	Москва, Педагогическая, 3	f	large
31884	25002	610	Брянская область, Краснорский район, поселок Дубенец, Центральная, 31	f	small
31901	25019	627	Брянская область, Краснорский район, поселок Городечня, Совхозная, 28	f	small
31893	25011	619	Брянская область, Краснорский район, поселок Верхличи, Молодежная, 8	f	small
31883	25001	609	Брянская область, Унечский район, поселок Батуровка	f	small
31860	24978	586	Брянская область, Комаричский район, поселок Шарово, здание МОУ Шаровская основная общеобразовательная школа	f	small
31868	24986	594	Брянская область, Комаричский район, поселок Хлебтово, здание Хлебтовского сельского клуба	f	small
31872	24990	598	Брянская область, Комаричский район, поселок Усожа, здание Усожской сельской администрации	f	small
31874	24992	600	Брянская область, Комаричский район, поселок Угревище, здание МОУ Угревищская основная общеобразовательная школа	f	small
31875	24993	601	Брянская область, Комаричский район, поселок Тростенчик, здание МОУ Лукинская средняя общеобразовательная школа	f	small
31854	24972	580	Брянская область, Комаричский район, поселок Радогощь, здание МОУ Радогощская средняя общеобразовательная школа	f	small
31871	24989	597	Брянская область, Комаричский район, Марьинка, здание сельского Дома культуры	t	medium
31853	24971	579	Брянская область, Комаричский район, поселок Лопандино, Горького, 12	f	large
31866	24984	592	Брянская область, Комаричский район, поселок Литиж, здание Литижской сельской библиотеки	f	small
31864	24982	590	Брянская область, Комаричский район, поселок Лагеревка, здание МОУ "Лагерёвская начальная общеобразовательная школа"	f	small
31851	24969	577	Брянская область, Комаричский район, поселок Комаричи, Советская, 91	f	medium
31847	24965	573	Брянская область, Комаричский район, поселок Комаричи, Советская, 17	f	medium
31846	24964	572	Брянская область, Комаричский район, поселок Комаричи, Советская, 28	f	large
31852	24970	578	Брянская область, Комаричский район, поселок Комаричи, Рабочая, 28	f	medium
31850	24968	576	Брянская область, Комаричский район, поселок Комаричи, Переулок Кирова, 7	f	medium
31848	24966	574	Брянская область, Комаричский район, поселок Комаричи, Ленина, 37	f	medium
31849	24967	575	Брянская область, Комаричский район, поселок Комаричи, Комсомольская, 55-В	f	large
31873	24991	599	Брянская область, Комаричский район, поселок Избичня, здание Избичёнского сельского клуба	f	small
31862	24980	588	Брянская область, Комаричский район, поселок Игрицкое, здание МОУ Луганская средняя общеобразовательная школа	f	medium
31867	24985	593	Брянская область, Комаричский район, поселок Евдокимовка, здание МОУ Евдокимовская средняя общеобразовательная школа	f	small
31857	24975	583	Брянская область, Комаричский район, поселок Добровольская, здание МОУ "Лубошевская основная общеобразовательная школа"	f	small
31870	24988	596	Брянская область, Комаричский район, поселок Дерюгино, здание МОУ "Дерюгинская основная общеобразовательная школа"	f	small
31858	24976	584	Брянская область, Комаричский район, поселок Быхово, здание МОУ Быховская основная общеобразовательная школа	f	small
31865	24983	591	Брянская область, Комаричский район, поселок Бобрик, здание МОУ Бобриковская средняя общеобразовательная школа	f	small
31863	24981	589	Брянская область, Комаричский район, поселок Асовицы, здание МОУ Асовицкая основная общеобразовательная школа	f	small
31856	24974	582	Брянская область, Комаричский район, поселок Аркино, здание Аркинской сельской администрации	f	small
31861	24979	587	Брянская область, Комаричский район, поселок Апажа, МОУ "Апажская основная общеобразовательная школа"	f	small
31840	24958	566	Брянская область, Клинцы городской округ, Клинцы, Школьная, 19	f	large
31834	24953	560	Брянская область, Клинцы городской округ, Клинцы, Ворошилова, 39	f	large
32376	25487	1102	Брянская область, Клинцовский район, поселок Чемерна, Школьная, 4	f	large
32374	25485	1100	Брянская область, Клинцовский район, поселок Ущерпье, Школьная, 17	f	medium
32352	25464	1078	Брянская область, Клинцовский район, поселок Туросна, Центральная, 11	f	small
32295	25408	1021	Брянская область, Клинцовский район, поселок Сосновка, Сосновская ООШ	f	small
32363	25474	1089	Брянская область, Клинцовский район, поселок Сосновка, Школьная, 3	f	small
30094	23289	73	Белгородская область, Белгород, Конева, 11	f	large
32365	25476	1091	Брянская область, Клинцовский район, поселок Смотрова Буда, Советская, 73	f	medium
32375	25486	1101	Брянская область, Клинцовский район, поселок Смолевичи, Ленина, 4	f	medium
32370	25481	1096	Брянская область, Клинцовский район, поселок Рудня-Голубовка, Клинцовская, 10	f	small
32372	25483	1098	Брянская область, Клинцовский район, поселок Рожны, Зеленая, 42	f	medium
32345	25457	1071	Брянская область, Клинцовский район, поселок Песчанка, Мира, 69	f	small
32377	25488	1103	Брянская область, Клинцовский район, поселок Песчанка, Зеленая, 14	f	small
32368	25479	1094	Брянская область, Клинцовский район, поселок Первое Мая, Центральная, 1	f	medium
32367	25478	1093	Брянская область, Клинцовский район, поселок Павличи, Центральная, 8	f	medium
32369	25480	1095	Брянская область, Клинцовский район, поселок Ольховка, Молодежная, 7	f	medium
32358	25470	1084	Брянская область, Клинцовский район, поселок Оболешево, Октябрьская, 2	f	small
32355	25467	1081	Брянская область, Клинцовский район, поселок Медведово, Центральная, 82	f	medium
32366	25477	1092	Брянская область, Клинцовский район, поселок Мартьяновка, Центральная, 94	f	medium
32350	25462	1076	Брянская область, Клинцовский район, поселок Малая Топаль, Школьная, 8а	f	small
32353	25465	1079	Брянская область, Клинцовский район, поселок Лопатни, Совхозная, 3	f	medium
32361	25472	1087	Брянская область, Клинцовский район, поселок Коржово-Голубовка, Советская, 7	f	medium
32360	25472	1086	Брянская область, Клинцовский район, поселок Коржово-Голубовка, Советская, 7	f	medium
32357	25469	1083	Брянская область, Клинцовский район, поселок Киваи, Буденного, 56	f	small
32371	25482	1097	Брянская область, Клинцовский район, поселок Ивановщина, Займищенская, 25	f	small
32364	25475	1090	Брянская область, Клинцовский район, поселок Затишье, клуб	f	small
31843	24961	569	Брянская область, Клинцовский район, поселок Займище, Клинцовская, 99	f	large
32356	25468	1082	Брянская область, Клинцовский район, поселок Душкино, Центральная, 33	f	small
32354	25466	1080	Брянская область, Клинцовский район, поселок Гута Корецкая, Свердлова, 50	f	small
32351	25463	1077	Брянская область, Клинцовский район, поселок Гулевка, Заводская, 7	f	medium
32362	25473	1088	Брянская область, Клинцовский район, поселок Вьюнка, пер.1 Центральный, 5	f	small
32373	25484	1099	Брянская область, Клинцовский район, поселок Веприно, Песчаная, 29	f	small
32349	25461	1075	Брянская область, Клинцовский район, поселок Великая Топаль, Октябрьская, 14а	f	medium
32359	25471	1085	Брянская область, Клинцовский район, поселок Бутовск, Ленина, медпункт	f	small
31841	24959	567	Брянская область, Клинцовский район, поселок Ардонь, Зеленая, 21	f	large
31810	24935	536	Брянская область, Климовский район, поселок Шумиловка, Октябрьская, 50	f	small
31814	24939	540	Брянская область, Климовский район, поселок Чуровичи, Советская, 1	f	medium
31815	24940	541	Брянская область, Климовский район, поселок Чуровичи, Ленинская, 106	f	medium
31805	24930	531	Брянская область, Климовский район, поселок Чолхов, Набережная, 90	f	small
31791	24916	517	Брянская область, Климовский район, поселок Чернооково, Молодежная, 1-а	f	small
31782	24907	508	Брянская область, Климовский район, поселок Хохловка, Школьная, 1	f	medium
31813	24938	539	Брянская область, Климовский район, поселок Хоромное, Октябрьская, 149	f	medium
31804	24929	530	Брянская область, Климовский район, поселок Фоевичи, Советская, 19	f	small
31784	24909	510	Брянская область, Климовский район, поселок Сытая Буда, Школьная, 11	f	small
31799	24924	525	Брянская область, Климовский район, поселок Сушаны, Октябрьская, 37	f	small
31798	24922	524	Брянская область, Климовский район, поселок Старый Ропск, Ленина, 64	f	small
31816	24941	542	Брянская область, Климовский район, поселок Старые Юрковичи, Пролетарская, 7	f	small
31809	24934	535	Брянская область, Климовский район, поселок Соловьевка, Мичурина, 34	f	small
31800	24925	526	Брянская область, Климовский район, поселок Сачковичи, Ленина, 34	f	medium
31785	24910	511	Брянская область, Климовский район, поселок Рубежное, Мира, 1	f	small
31789	24914	515	Брянская область, Климовский район, поселок Пруска, 84-а, здание сельского клуба	f	small
31786	24911	512	Брянская область, Климовский район, поселок Плавна, Центральная площадь, 8	f	small
31797	24921	523	Брянская область, Климовский район, поселок Новый Ропск, Ленина, 148	f	medium
31796	24921	522	Брянская область, Климовский район, поселок Новый Ропск, Ленина, 148	f	small
31817	24942	543	Брянская область, Климовский район, поселок Новые Юрковичи, Советская, .41	f	medium
31793	24918	519	Брянская область, Климовский район, поселок Могилевцы, Школьная, 21	f	small
31781	24906	507	Брянская область, Климовский район, поселок Митьковка, Школьная, 2	f	small
31795	24920	521	Брянская область, Климовский район, поселок Любечане, Коммунистическая, 48	f	small
31792	24917	518	Брянская область, Климовский район, поселок Лобановка, Садовая, 14	f	small
31783	24908	509	Брянская область, Климовский район, поселок Лакомая Буда, Заречная, 19-б	f	small
31806	24931	532	Брянская область, Климовский район, поселок Куршановичи, Советская, 5	f	small
31787	24912	513	Брянская область, Климовский район, поселок Курозново, Гагарина, 2-а	f	small
31665	24786	391	Брянская область, Климовский район, поселок Красный Бор, Здание начальной общеобразовательной школы	f	small
31802	24927	528	Брянская область, Климовский район, поселок Крапивна, Заречная, 5	f	small
31774	24899	500	Брянская область, Климовский район, поселок Климово, площадь Ленина, 1-а	f	large
31775	24900	501	Брянская область, Климовский район, поселок Климово, Советская, 61	f	large
31776	24901	502	Брянская область, Климовский район, поселок Климово, Полевая, 39	f	large
31780	24905	506	Брянская область, Климовский район, поселок Климово, Октябрьская, 70	f	large
31779	24904	505	Брянская область, Климовский район, поселок Климово, Лесная, 30	f	large
31777	24902	503	Брянская область, Климовский район, поселок Климово, Коммунистическая, 37	f	large
31778	24903	504	Брянская область, Климовский район, поселок Климово, Брянская, 45	f	small
31811	24936	537	Брянская область, Климовский район, поселок Кирилловка, Советская, 40	f	small
31808	24933	534	Брянская область, Климовский район, поселок Каменский Хутор, Ленина, 99	f	medium
31788	24913	514	Брянская область, Климовский район, поселок Каменка, 75-а, здание ФАП	t	small
31473	24601	199	Брянская область, Климовский район, поселок Каменка, Административное здание ФКУ ИК-4	f	small
31790	24915	516	Брянская область, Климовский район, поселок Истопки, Октябрьская, 25-а	f	small
31807	24932	533	Брянская область, Климовский район, поселок Забрама, Набережная, 76	f	small
31803	24928	529	Брянская область, Климовский район, поселок Гетманская Буда, Первомайская, 83	f	small
31801	24926	527	Брянская область, Климовский район, поселок Воробьёвка, Озерная, 13	f	small
31812	24937	538	Брянская область, Климовский район, поселок Вишнёвый, Комсомольская, 34	f	small
31794	24919	520	Брянская область, Климовский район, поселок Брахлов, Цветная, 2	f	small
31759	24883	485	Брянская область, Клетнянский район, поселок Ширковка	f	small
31765	24890	491	Брянская область, Клетнянский район, поселок Харитоновка	f	small
31753	24877	479	Брянская область, Клетнянский район, поселок Строительная Слобода	f	small
31757	24881	483	Брянская область, Клетнянский район, поселок Старая Мармазовка	f	small
31771	24896	497	Брянская область, Клетнянский район, поселок Синицкое	f	small
31760	24884	486	Брянская область, Клетнянский район, поселок Семиричи	f	small
32113	25228	839	Брянская область, Клетнянский район, поселок Пушкино, Понизовка, 4	f	small
31772	24897	498	Брянская область, Клетнянский район, поселок Павлинки	f	small
31769	24894	495	Брянская область, Клетнянский район, поселок Новотроицкое	f	small
31773	24898	499	Брянская область, Клетнянский район, поселок Новая Осиновка	t	small
31770	24895	496	Брянская область, Клетнянский район, поселок Николаевка	f	small
31768	24893	494	Брянская область, Клетнянский район, поселок Неделька	f	small
31767	24892	493	Брянская область, Клетнянский район, поселок Мужиново	t	small
31756	24880	482	Брянская область, Клетнянский район, поселок Лутна	f	medium
31755	24879	481	Брянская область, Клетнянский район, поселок Коршево	f	small
31450	24525	176	Брянская область, Клетнянский район, поселок Коммуна, Здание медпункта	f	small
31747	24870	473	Брянская область, Клетнянский район, поселок Клетня, улица Лесная, 71	f	medium
31752	24876	478	Брянская область, Клетнянский район, поселок Клетня, Первомайская	f	medium
82432	56427	1601	Москва, Педагогическая, 3	f	large
31745	24868	471	Брянская область, Клетнянский район, поселок Клетня, Орджоникидзе	f	large
31749	24872	475	Брянская область, Клетнянский район, поселок Клетня, Медведева, 8	f	medium
31744	24867	470	Брянская область, Клетнянский район, поселок Клетня, Ленина, 84	f	large
31742	24865	468	Брянская область, Клетнянский район, поселок Клетня, Ленина, 128а	f	large
31748	24871	474	Брянская область, Клетнянский район, поселок Клетня, Красных Партизан, 14	f	large
31751	24875	477	Брянская область, Клетнянский район, поселок Клетня, Кирова, 40	f	medium
31750	24873	476	Брянская область, Клетнянский район, поселок Клетня, Карла Маркса	f	large
31746	24869	472	Брянская область, Клетнянский район, поселок Клетня, Гоголя, 14а	f	medium
31743	24866	469	Брянская область, Клетнянский район, поселок Клетня, Вокзальная	f	large
31741	24864	467	Брянская область, Клетнянский район, поселок Клетня, Вокзальная, 26	f	medium
31762	24886	488	Брянская область, Клетнянский район, поселок Добрая Корна	f	small
31763	24888	489	Брянская область, Клетнянский район, поселок Быстрянка	t	small
31761	24885	487	Брянская область, Клетнянский район, поселок Болотня	f	small
31766	24891	492	Брянская область, Клетнянский район, поселок Алень	f	small
31758	24882	484	Брянская область, Клетнянский район, поселок Алексеевка	f	small
31754	24878	480	Брянская область, Клетнянский район, поселок Акуличи	f	small
31723	24846	449	Брянская область, Карачевский район, поселок Юрасово, здание библиотеки	f	small
31717	24840	443	Брянская область, Карачевский район, поселок Трыковка, зд-е нач. школы с.Рясники	f	medium
31716	24839	442	Брянская область, Карачевский район, поселок Трыковка, Адм. зд-е Карачевской гор. адм. № 5	f	small
31730	24853	456	Брянская область, Карачевский район, поселок Теплое, здание Клуба	f	small
31719	24842	445	Брянская область, Карачевский район, поселок Согласие, зд-е сельского клуба	t	medium
32096	25212	822	Брянская область, Карачевский район, поселок Семеновка, Молодежная, 17	f	small
31740	24863	466	Брянская область, Карачевский район, поселок Ружное, зд-е Ревенской с/а	f	small
31736	24859	462	Брянская область, Карачевский район, поселок Песочня, здание Песоченской с/а	f	medium
31737	24860	463	Брянская область, Карачевский район, поселок Новгородский, зд-е Новгородской с/а	t	small
31735	24858	461	Брянская область, Карачевский район, поселок Мылинка, здание сельской библиотеки	t	small
32068	25186	794	Брянская область, Карачевский район, поселок Московский, Школьная, 2 А	f	medium
31715	24838	441	Брянская область, Карачевский район, поселок Масловка, Адм. зд-е Карачевской гор. адм. № 2	f	large
31714	24837	440	Брянская область, Карачевский район, поселок Масловка, зд-е Первомайской школы	f	large
31722	24845	448	Брянская область, Карачевский район, поселок Мальтино, Адм. зд-е Карачевской гор. адм. № 4	t	medium
31720	24843	446	Брянская область, Карачевский район, поселок Мазнево, зд-е средней школы	f	small
31738	24861	464	Брянская область, Карачевский район, поселок Лужецкая, зд-е Ревенской с/а	f	small
31739	24862	465	Брянская область, Карачевский район, поселок Куприно, зд-е к-ры СПК Восход	f	small
31718	24841	444	Брянская область, Карачевский район, поселок Коптилово, ТНВ Авангард	f	small
31713	24836	439	Брянская область, Карачевский район, Карачев	f	large
31712	24835	438	Брянская область, Карачевский район, Карачев, Федюнинского, 82	f	medium
31709	24832	435	Брянская область, Карачевский район, Карачев, Советская, 66-А	f	large
31708	24831	434	Брянская область, Карачевский район, Карачев, Свердлова, 2	f	medium
31721	24844	447	Брянская область, Карачевский район, Карачев, Первомайская, 45	f	medium
31711	24834	437	Брянская область, Карачевский район, Карачев, Первомайская, 26	f	medium
31705	24827	431	Брянская область, Карачевский район, Карачев, Первомайская, 227	f	large
31702	24824	428	Брянская область, Карачевский район, Карачев, Кольцова, 36-А	f	medium
31710	24833	436	Брянская область, Карачевский район, Карачев, К.Либкнехта, 34	f	large
31703	24825	429	Брянская область, Карачевский район, Карачев, Заводская, 2	f	large
31707	24830	433	Брянская область, Карачевский район, Карачев, Дзержинского, 28	f	large
31704	24826	430	Брянская область, Карачевский район, Карачев, Горького, 1	f	large
30096	23289	75	Белгородская область, Белгород, Конева, 11	f	large
31706	24829	432	Брянская область, Карачевский район, Карачев, Володарского, 80-А	f	large
31733	24856	459	Брянская область, Карачевский район, поселок Дунаевский, зд-ние школы	f	small
31732	24855	458	Брянская область, Карачевский район, поселок Дроново, зд-ние клуба	t	small
31729	24852	455	Брянская область, Карачевский район, поселок Гощь, СХП Железнодорожник	t	small
31728	24851	454	Брянская область, Карачевский район, поселок Верхополье, зд-е Библиотеки	f	small
31727	24850	453	Брянская область, Карачевский район, поселок Вельяминово, зд-е сельсовета	f	medium
31726	24849	452	Брянская область, Карачевский район, поселок Вельяминово, д\\сад	f	large
31724	24847	450	Брянская область, Карачевский район, поселок Бошино, зд-е средней школы	f	small
31734	24857	460	Брянская область, Карачевский район, поселок Березовка, зд-е СДК ""Березовсий"""	f	medium
31731	24854	457	Брянская область, Карачевский район, поселок Алымово, здание клуба	f	small
31725	24848	451	Брянская область, Карачевский район, поселок Алексеевка, здание Библиотеки	f	small
31694	24816	420	Брянская область, Злынковский район, поселок Спиридонова Буда, Ленина, 4	f	small
31700	24822	426	Брянская область, Злынковский район, поселок Софиевка, Ленина, 34	f	small
31699	24821	425	Брянская область, Злынковский район, поселок Рогов, Ленина, 2	f	small
31696	24818	422	Брянская область, Злынковский район, поселок Петрятинка, Первомайская, 10	t	small
31697	24819	423	Брянская область, Злынковский район, поселок Малые Щербиничи, Молодежная, 16	f	small
31691	24813	417	Брянская область, Злынковский район, поселок Лысые, Молодежная, 11	f	small
31695	24817	421	Брянская область, Злынковский район, поселок Кожановка, Школьная, 12	f	small
31693	24815	419	Брянская область, Злынковский район, Карпиловка, Молодежная, 11	f	small
31688	24810	414	Брянская область, Злынковский район, Злынка, площадь Свободы, 30	f	large
31690	24812	416	Брянская область, Злынковский район, Злынка, Республиканская, 134 А	f	large
31689	24811	415	Брянская область, Злынковский район, Злынка, Коммунальная, 17	f	large
31685	24807	411	Брянская область, Злынковский район, поселок Добродеевка, Школьная, 1	f	small
31692	24814	418	Брянская область, Злынковский район, поселок Денисковичи, Злынковская, 1	f	small
31687	24809	413	Брянская область, Злынковский район, поселок Вышков, Школьная, 5	f	medium
31686	24808	412	Брянская область, Злынковский район, поселок Вышков, Клубная площадь, 5	f	large
31698	24820	424	Брянская область, Злынковский район, поселок Большие Щербиничи, Центральная, 9	f	small
31670	24790	395	Брянская область, Жуковский район, поселок Шамордино, Здание поселенческого Дома культуры	f	medium
31678	24798	403	Брянская область, Жуковский район, поселок Тросна, Здание поселенческого Дома культуры	f	large
32084	25201	810	Брянская область, Жуковский район, поселок Титовка, Школьная, 5А	f	small
31664	24785	390	Брянская область, Жуковский район, поселок Ржаница, Здание Ржаницкой средней школы	f	large
31667	24788	393	Брянская область, Жуковский район, поселок Речица, Здание сельского Дома культуры	f	small
32078	25195	804	Брянская область, Жуковский район, поселок Речица, 70 лет Октября, 12	f	medium
32077	25194	803	Брянская область, Жуковский район, поселок Речица, 70 лет Октября, 9	f	large
31679	24799	404	Брянская область, Жуковский район, поселок Поляковка, Здание бывшей школы	f	small
31683	24803	408	Брянская область, Жуковский район, поселок Петуховка, Здание поселенческого Дома культуры	f	medium
31681	24801	406	Брянская область, Жуковский район, поселок Олсуфьево, Здание сельского Дома культуры	f	medium
31666	24787	392	Брянская область, Жуковский район, поселок Овстуг, Здание поселенческого Дома культуры	f	medium
31677	24797	402	Брянская область, Жуковский район, поселок Никольская Слобода, Здание центр "Юнеско"	f	medium
31673	24793	398	Брянская область, Жуковский район, поселок Леденево, Здание сельского клуба	f	small
31663	24784	389	Брянская область, Жуковский район, поселок Латыши, Здание сельского Дома культуры	f	medium
31671	24791	396	Брянская область, Жуковский район, поселок Крыжино, Здание поселенческого Дома культуры	f	small
31682	24802	407	Брянская область, Жуковский район, поселок Касилово, Здание сельского Дома культуры	f	small
83933	57349	3132	Москва, Зеленоград, к1115	f	large
31669	24789	394	Брянская область, Жуковский район, поселок Задубравье, Здание сельского клуба	f	small
31662	24783	388	Брянская область, Жуковский район, Жуковка, Дом интернат для престарелых и инвалидов	f	small
31657	24778	383	Брянская область, Жуковский район, Жуковка, переулок Школьный, 1	f	large
31659	24780	385	Брянская область, Жуковский район, Жуковка, пер. Первомайский, 19	f	large
31658	24779	384	Брянская область, Жуковский район, Жуковка, Смоленская, 4А	f	large
31654	24775	380	Брянская область, Жуковский район, Жуковка, Переулок Первомайский, 43	f	medium
31651	24773	377	Брянская область, Жуковский район, Жуковка, Ленина, 44А	f	medium
31661	24782	387	Брянская область, Жуковский район, Жуковка, Краснофокинская, 106Г	f	medium
31656	24777	382	Брянская область, Жуковский район, Жуковка, Карла Маркса, 78А	f	large
31655	24776	381	Брянская область, Жуковский район, Жуковка, Карла Маркса, 80	f	large
31653	24774	379	Брянская область, Жуковский район, Жуковка, Карла Либкнехта, 2	f	large
31649	14661	375	Брянская область, Жуковский район, Жуковка, Калинина, 1	f	large
31650	24772	376	Брянская область, Жуковский район, Жуковка, Калина, 38	f	large
31660	24781	386	Брянская область, Жуковский район, Жуковка, Заречная, 2А	f	large
31652	24760	378	Брянская область, Жуковский район, Жуковка, Дзержинского, 2	f	large
31680	24800	405	Брянская область, Жуковский район, деревня Гришина Слобода, Здание поселенческого дома культуры	f	medium
31676	24796	401	Брянская область, Жуковский район, поселок Гостиловка, здание сельского клуба	f	medium
31672	24792	397	Брянская область, Жуковский район, поселок Быковичи, здание сельского Дома культуры	f	small
31674	24794	399	Брянская область, Жуковский район, поселок Белоголовль, здание сельского клуба	f	small
32066	25184	792	Брянская область, Жирятинский район, поселок Усошки, Молодежная, 3	f	medium
31634	24756	360	Брянская область, Жирятинский район, поселок Страшевичи, Школьная, 22	f	medium
31642	24765	368	Брянская область, Жирятинский район, поселок Савлуково, Юбилейная, 1а	f	small
31646	24769	372	Брянская область, Жирятинский район, поселок Норино, Набережная, 56	f	small
31639	24762	365	Брянская область, Жирятинский район, поселок Морачево, Пролетарская, 10	f	small
31647	24770	373	Брянская область, Жирятинский район, поселок Кульнево, Клубная, 19	f	small
32300	25413	1026	Брянская область, Жирятинский район, поселок Комягино, СДК	f	small
31635	24757	361	Брянская область, Жирятинский район, поселок Комягино, Полевая, 3	f	small
31643	24766	369	Брянская область, Жирятинский район, поселок Колодня, Центральная, 19	f	small
31638	24761	364	Брянская область, Жирятинский район, поселок Княвичи, Пришкольная, 16	f	small
31859	24977	585	Брянская область, Жирятинский район, поселок Заречная, здание МОУ Зареченская основная общеобразовательная школа	f	small
31641	24764	367	Брянская область, Жирятинский район, поселок Жирятино, Молодежная, 25	f	small
31636	24758	362	Брянская область, Жирятинский район, поселок Жирятино, Мира, 10	f	medium
31637	24759	363	Брянская область, Жирятинский район, поселок Жирятино, Ленина, 55	f	large
31640	24763	366	Брянская область, Жирятинский район, поселок Высокое, Центральная, 6а	f	small
32326	25438	1052	Брянская область, Жирятинский район, поселок Высокое, Дружбы, 10А	f	medium
31644	24767	370	Брянская область, Жирятинский район, поселок Воробейня, Центральная, 2	f	small
31645	24768	371	Брянская область, Жирятинский район, поселок Буда, Молодежная, 12	f	small
31627	24749	353	Брянская область, Дятьковский район, поселок Чернятичи, переулок Мира, 1а , здание сельской библиотеки	f	small
31629	24751	355	Брянская область, Дятьковский район, Фокино, площадь Ленина, 2, здание МУК Культурно-досуговый	f	large
31633	24755	359	Брянская область, Дятьковский район, Фокино, К.Маркса, 3а, СОШ №2	f	large
31632	24754	358	Брянская область, Дятьковский район, Фокино, К.Маркса, 13, ФИТ	f	large
31631	24753	357	Брянская область, Дятьковский район, Фокино, К.Маркса, 42а , здание СОШ №3	f	large
31630	24752	356	Брянская область, Дятьковский район, Фокино, К.Маркса, 17а , профессиональный лицей №13	f	large
31628	24750	354	Брянская область, Дятьковский район, Фокино, Гайдара, 7, Центр детского творчества	f	large
31588	24710	314	Брянская область, Дубровский район, поселок Радичи, Центральная, 3а	t	small
31618	24740	344	Брянская область, Дятьковский район, поселок Старь, Ленина, 5, здание поселковой администрации	f	large
31617	24739	343	Брянская область, Дятьковский район, поселок Старь, площадь 30 лет Победы, 11, Здание Дома культуры	f	large
31648	24771	374	Брянская область, Дятьковский район, поселок Старая Рубча, Пролетарская, 15	f	small
31621	24743	347	Брянская область, Дятьковский район, поселок Сосновка, Советская, 14, здание сельского клуба	f	small
31626	24748	352	Брянская область, Дятьковский район, поселок Слободище, 16, здание Дома культуры	f	large
31620	24742	346	Брянская область, Дятьковский район, поселок Пупково, Советская, 1, здание магазина №29, РАЙПО	f	small
31607	24729	333	Брянская область, Дятьковский район, поселок Псурь, здание сельского клуба	f	small
31625	24747	351	Брянская область, Дятьковский район, поселок Немеричи, Школьная, 8, здание ОШ	f	medium
31622	24744	348	Брянская область, Дятьковский район, поселок Неверь, Озерная, 24б , здание сельского клуба	f	small
31615	24737	341	Брянская область, Дятьковский район, поселок Любохна, Пушкина, 10, здание Дома культуры "Литейщик"	f	large
31616	24738	342	Брянская область, Дятьковский район, поселок Любохна, Брянская, 1, здание администрации поселка	f	large
31612	24734	338	Брянская область, Дятьковский район, поселок Ивот, Пролетарская, 9, здание ДК	f	large
31611	24733	337	Брянская область, Дятьковский район, поселок Ивот, Горохова, 17, здание СОШ	f	large
31598	24721	324	Брянская область, Дятьковский район, Дятьково, площадь Ленина, 1, ДК МУК МКЦД	f	large
31595	24718	321	Брянская область, Дятьковский район, Дятьково, Орджоникидзе, 2а , здание ДЮСШ Электрон	f	large
31602	24725	328	Брянская область, Дятьковский район, Дятьково, Ленина, 176 , здание МОО	f	medium
31601	24724	327	Брянская область, Дятьковский район, Дятьково, Ленина, 170	f	large
31597	24720	323	Брянская область, Дятьковский район, Дятьково, Ленина, 161, МУК Дятьковский Дом Культуры	f	large
31592	24715	318	Брянская область, Дятьковский район, Дятьково, Ленина, 224, ПУ №14	f	large
31593	24716	319	Брянская область, Дятьковский район, Дятьково, Крупской, 5, здание ДСОШ №2	f	large
31603	24726	329	Брянская область, Дятьковский район, Дятьково, Краснофлотская, 2, здание ДСОШ №5	f	large
31596	24719	322	Брянская область, Дятьковский район, Дятьково, Красина, 22, здание ДСОШ №3	f	large
31594	24717	320	Брянская область, Дятьковский район, Дятьково, Киевская, 36а , здание нач. школы-детского сада	f	large
31599	24722	325	Брянская область, Дятьковский район, Дятьково, Карла Маркса, 7а, здание ДИТ	f	large
31600	24723	326	Брянская область, Дятьковский район, Дятьково, В.Рябка, 2а, здание МУП г. Дятьково ВКХ	f	medium
31606	24728	332	Брянская область, Дятьковский район, Дятьково, 13 микрорайон, 2а, здание ДСОШ №4 г. Дятьково	f	large
31605	24711	331	Брянская область, Дятьковский район, Дятьково, 13 микрорайон, 2а, здание ДСОШ №4 г. Дятьково	f	large
31604	24727	330	Брянская область, Дятьковский район, Дятьково, 12 микрорайон, 2, общ. ООО ЖЭУ №1	f	large
31623	24745	349	Брянская область, Дятьковский район, поселок Дружба, Октябрьская, 9, здание СОШ	f	large
31624	24746	350	Брянская область, Дятьковский район, поселок Верхи, Рябка, 2а , здание ОШ	f	small
31608	24730	334	Брянская область, Дятьковский район, поселок Бытошь, Ленина, 61, здание СОШ	f	large
31609	24731	335	Брянская область, Дятьковский район, поселок Бытошь, Алексеева, 1а	f	large
31610	24732	336	Брянская область, Дятьковский район, поселок Будочка, Центральная, 9, здание СОШ	f	small
31619	24741	345	Брянская область, Дятьковский район, поселок Березино, Керамическая, 11, здание конторы СПК Фокинский	f	large
31613	24735	339	Брянская область, Дятьковский район, поселок Бацкино, Приозерная, 33 , здание отделения связи	f	small
31589	24712	315	Брянская область, Дубровский район, поселок Старое Колышкино, Центральная, 27	f	small
31586	24708	312	Брянская область, Дубровский район, поселок Сеща, Центральная, 1	f	large
31585	24707	311	Брянская область, Дубровский район, поселок Сеща, Центральная, 14	f	large
31584	24706	310	Брянская область, Дубровский район, поселок Серпеевский, Центральная, 14	t	small
31583	24705	309	Брянская область, Дубровский район, поселок Рябчи, Центральная, 39	f	medium
31581	24703	307	Брянская область, Дубровский район, поселок Рековичи, Журавлева, 19	f	small
31579	24701	305	Брянская область, Дубровский район, поселок Пеклино, Калинина, 32	f	medium
31580	24702	306	Брянская область, Дубровский район, поселок Новая Салынь, Центральная, 29	t	small
31576	24698	302	Брянская область, Дубровский район, поселок Немерь, переулок Садовый, 7	t	medium
31578	24700	304	Брянская область, Дубровский район, поселок Мареевка, Клубная, 1	t	small
31582	24704	308	Брянская область, Дубровский район, поселок Зимницкая Слобода, Совхозная, 6	f	medium
31574	24696	300	Брянская область, Дубровский район, поселок Дубровка, переулок Матросова, 8	f	medium
31573	24695	299	Брянская область, Дубровский район, поселок Дубровка, Ленина, 84	f	large
31572	24694	298	Брянская область, Дубровский район, поселок Дубровка, 60 лет Октября, 16-а	f	large
31571	24693	297	Брянская область, Дубровский район, поселок Дубровка, 1-ый Микрорайон, школа №2	f	large
31575	24697	301	Брянская область, Дубровский район, поселок Давыдчичи, Центральная, 21	f	medium
31587	24709	313	Брянская область, Дубровский район, поселок Большая Островня, Центральная, 11	f	medium
32114	25229	840	Брянская область, Дубровский район, поселок Бересток, Центральная, 20	f	small
31591	24714	317	Брянская область, Дубровский район, поселок Афонино, Школьная, 5	t	small
31577	24699	303	Брянская область, Дубровский район, поселок Алешня, Административная, 7	f	small
31590	24713	316	Брянская область, Дубровский район, поселок Алешинка, Лесная, 3а	t	small
31569	24691	295	Брянская область, Гордеевский район, поселок Ямное, Центральная, 4	t	small
31557	24622	283	Брянская область, Гордеевский район, Ширяевка, Дорожная, 15/2	f	small
31552	24681	278	Брянская область, Гордеевский район, поселок Черный-Ручей, Совхозная, 10	f	small
31568	24690	294	Брянская область, Гордеевский район, поселок Хаминка, Центральная, 34, помещение медпункта	t	small
31567	24689	293	Брянская область, Гордеевский район, поселок Уношево, Красногорская, 15	f	small
31551	24680	277	Брянская область, Гордеевский район, поселок Творишино, Школьная, 1	f	medium
31558	24657	284	Брянская область, Гордеевский район, Струговская Буда, Юбилейная, 7	f	small
31560	24130	286	Брянская область, Гордеевский район, поселок Струговка, Цветочная, 27/1	f	small
31556	24597	282	Брянская область, Гордеевский район, поселок Староновицкая, Школьная, 1	f	small
31555	24684	281	Брянская область, Гордеевский район, поселок Старая Полона, Школьная, 8	f	small
31566	24688	292	Брянская область, Гордеевский район, поселок Смяльч, Советская, 59 В	f	small
31553	24682	279	Брянская область, Гордеевский район, поселок Рудня-Воробьевка, Центральная, 28	f	small
31554	24683	280	Брянская область, Гордеевский район, поселок Поповка, Первомайская, 48	f	small
31550	24679	276	Брянская область, Гордеевский район, поселок Поконь, Красноармейская, 12	f	small
31563	24685	289	Брянская область, Гордеевский район, поселок Петрова Буда, Красногорская, 27, помещение сел. админ	f	\N
31564	24686	290	Брянская область, Гордеевский район, поселок Перетин, Гордеевская, 17	t	small
31561	24196	287	Брянская область, Гордеевский район, поселок Мирный, Ленина, 10	f	large
31565	24687	291	Брянская область, Гордеевский район, поселок Малоудебное, Школьная, 2/1	f	small
31570	24692	296	Брянская область, Гордеевский район, поселок Кузнецы, Недоливко, 3	t	small
32306	25419	1032	Брянская область, Гордеевский район, поселок Кожаны, СДК	f	small
31562	24353	288	Брянская область, Гордеевский район, поселок Кожаны, Садовая, 14	t	small
31549	24678	275	Брянская область, Гордеевский район, поселок Заводокорецкий, улица Школьная, 7	f	small
31548	24677	274	Брянская область, Гордеевский район, поселок Гордеевка, Ленина, 46	f	large
32323	25435	1049	Брянская область, Гордеевский район, поселок Березина, Буденного, 29А	f	small
31547	24676	273	Брянская область, Выгоничский район, поселок Хутор Бор, Луговая, 1-б	f	small
31546	24675	272	Брянская область, Выгоничский район, поселок Хмелево, Молодежная, 40	f	small
31541	24670	267	Брянская область, Выгоничский район, поселок Уручье, Центральная, 69	f	small
31545	24674	271	Брянская область, Выгоничский район, поселок Сосновое Болото, Партизанская, 6	f	small
31540	24669	266	Брянская область, Выгоничский район, поселок Сосновка, Салова, 4	f	small
31526	24654	252	Брянская область, Выгоничский район, поселок Скуратово, Ольховая, 27	f	medium
31538	24667	264	Брянская область, Выгоничский район, поселок Скрябино, Школьная, 1-а	f	medium
31537	24666	263	Брянская область, Выгоничский район, поселок Полужье, Школьная, 7	f	small
31528	24656	254	Брянская область, Выгоничский район, поселок Пильшино, Садовая, 2	t	medium
32337	25449	1063	Брянская область, Выгоничский район, поселок Павловка, Школьная, 1	f	medium
31536	24665	262	Брянская область, Выгоничский район, поселок Орменка, Парковая, 3	f	small
31531	24660	257	Брянская область, Выгоничский район, поселок Мякишево, Молодежная, 14	f	small
31535	24664	261	Брянская область, Выгоничский район, поселок Малфа, Больничная, 6	t	small
31530	24659	256	Брянская область, Выгоничский район, поселок Лопушь, Деснянская, 6	f	large
31544	24673	270	Брянская область, Выгоничский район, поселок Красный Рог, Переулок Заводской, 3-а	f	small
31527	24655	253	Брянская область, Выгоничский район, поселок Красное, Школьная, 4	f	small
31855	24973	581	Брянская область, Выгоничский район, поселок Кокино, здание МОУ Кокинская средняя общеобразовательная школа	f	small
31525	24653	251	Брянская область, Выгоничский район, поселок Кокино, Советская, 6-а	f	large
31524	24652	250	Брянская область, Выгоничский район, поселок Кокино, Советская, 2-а	f	large
31533	24662	259	Брянская область, Выгоничский район, поселок Евтиховский, Соловьиная, 10	f	small
31542	24671	268	Брянская область, Выгоничский район, поселок Деснянский, Школьная, 3	f	medium
31539	24668	265	Брянская область, Выгоничский район, поселок Десна, Заречная, 5-а	f	small
31523	24651	249	Брянская область, Выгоничский район, поселок Городец, Центральная , 15, здание МОУ Городетская ООШ	f	medium
31522	24650	248	Брянская область, Выгоничский район, поселок Выгоничи, Свердлова, 10	f	medium
31521	24649	247	Брянская область, Выгоничский район, поселок Выгоничи, Ленина, 27	f	large
31520	24648	246	Брянская область, Выгоничский район, поселок Выгоничи, Ленина, 25	f	large
31532	24661	258	Брянская область, Выгоничский район, поселок Большой Крупец, Школьная, 30	f	small
31543	24672	269	Брянская область, Выгоничский район, поселок Алексеевский, Молодежная, 2	f	small
31505	24634	231	Брянская область, Брянский район, п.Путевка, Центральная, 14	f	large
31487	24615	213	Брянская область, Брянский район, поселок Хотылево, Школьная, 2	f	small
31506	24635	232	Брянская область, Брянский район, поселок Толмачево, Трудовая, 6а	f	large
31517	24645	243	Брянская область, Брянский район, поселок Толвинка, Толвинская, 49 а	f	small
31485	24613	211	Брянская область, Брянский район, поселок Титовка, пл.им.К.Маркса, 8	f	medium
31512	24640	238	Брянская область, Брянский район, поселок Тиганово, Садовая, 54 а	f	small
31513	24641	239	Брянская область, Брянский район, поселок Теменичи, Светлая, 8а	t	medium
31494	24623	220	Брянская область, Брянский район, село Супонево, Свенская, 10	f	large
31502	24631	228	Брянская область, Брянский район, поселок Стяжное, Киевская, 30	t	small
31474	24602	200	Брянская область, Брянский район, поселок Стеклянная Радица, Комсомольская, 58	f	large
31489	24617	215	Брянская область, Брянский район, поселок Староселье, Центральная, здание Старосельского клуба	f	small
31500	24629	226	Брянская область, Брянский район, Свень-Транспортная, 12, 2	f	medium
31503	24632	229	Брянская область, Брянский район, поселок Свень, санаторий Снежка	f	small
31499	24628	225	Брянская область, Брянский район, поселок Свень, Клубная, 6	f	medium
31501	24630	227	Брянская область, Брянский район, поселок Пятилетка, Школьная, 1	f	medium
31504	24633	230	Брянская область, Брянский район, Путевка, поселок Большое Полпино, Центральная, 14	f	large
31519	24647	245	Брянская область, Брянский район, поселок Пальцо, Ленина, здание Пальцовского ПКЦ	f	medium
31481	24609	207	Брянская область, Брянский район, Новые Дарковичи, 2, здание Новодарковичского СДК	f	large
31497	24626	223	Брянская область, Брянский район, поселок Новоселки, Резцова, 13, здание Новосельской средней школы	t	large
31515	24643	241	Брянская область, Брянский район, поселок Нетьинка, Школьная, 28 а	f	medium
31514	24642	240	Брянская область, Брянский район, поселок Нетьинка, Мира, 30	f	large
31498	24627	224	Брянская область, Брянский район, поселок Молотино, Школьная, 34	t	small
31507	24636	233	Брянская область, Брянский район, поселок Мичуринский, Березовая, 7, Мичуринская средняя школа	f	large
31764	24889	490	Брянская область, Брянский район, поселок Мирный	f	medium
31479	24607	205	Брянская область, Брянский район, поселок Мирный, Школьная, 16а	f	small
31509	24638	235	Брянская область, Брянский район, поселок Меркульево, Воинская, 7	f	small
31478	24606	204	Брянская область, Брянский район, поселок Малое Полпино, Молодежная, 8	f	medium
31508	24637	234	Брянская область, Брянский район, поселок Колтово, Тамбовская, 11	f	medium
31476	24604	202	Брянская область, Брянский район, поселок Козелкино, Лесная, 49 а	t	small
31486	24614	212	Брянская область, Брянский район, поселок Кабаличи, Советская, 8	f	medium
31477	24605	203	Брянская область, Брянский район, поселок Журиничи, Песочная, 1 а	t	small
31518	24646	244	Брянская область, Брянский район, поселок Домашово, Советская, 20	f	medium
31511	24639	237	Брянская область, Брянский район, поселок Добрунь, Юбилейная, 31	f	large
31510	24639	236	Брянская область, Брянский район, поселок Добрунь, Юбилейная, 31	f	large
31492	24620	218	Брянская область, Брянский район, поселок Госома, Сельская, 58	t	small
31491	24619	217	Брянская область, Брянский район, поселок Городец, Школьная, 6	f	small
31483	24611	209	Брянская область, Брянский район, поселок Глинищево, П.М.Яшенина, 39	f	large
31484	24612	210	Брянская область, Брянский район, поселок Глинищево, Клубная, 1	f	large
31516	24644	242	Брянская область, Брянский район, поселок Глаженка, Набережная, 2 а	f	medium
31490	24618	216	Брянская область, Брянский район, поселок Бетово, Молодежная, 49	f	medium
31442	24570	168	Брянская область, Брянский район, поселок Белые Берега, улица Ленина, 1	f	large
31441	24569	167	Брянская область, Брянский район, поселок Белые Берега, Ромашина, 7	f	large
31443	24571	169	Брянская область, Брянский район, поселок Белые Берега, Коминтерна, 34	f	large
31444	24572	170	Брянская область, Брянский район, поселок Белые Берега, Карла Маркса, 6	f	large
31480	24608	206	Брянская область, Брянский район, поселок Белобережская, Центральная, здание почты	t	small
31475	24603	201	Брянская область, Брянский район, поселок Батагово, Центральная, 1а	f	small
31496	24625	222	Брянская область, Брянский район, поселок Антоновка, переулок Школьный, 6 &quot;&quot;а&quot;&quot;&quot	f	medium
31464	24591	190	Брянская область, Брасовский район, поселок Чаянка, Здание школы	f	small
31458	24585	184	Брянская область, Брасовский район, село Хотеева, Здание школы	f	small
31459	24586	185	Брянская область, Брасовский район, поселок Столбово, Здание сельской администрации	f	small
31451	24578	177	Брянская область, Брасовский район, поселок Сныткино, Здание сельской администрации	f	small
31452	24579	178	Брянская область, Брасовский район, поселок Осотское, Здание школы	f	small
31461	24588	187	Брянская область, Брасовский район, поселок Новое, Здание школы	f	small
31472	24600	198	Брянская область, Брасовский район, поселок Локоть, Здание ОАО Брасовское ХПП	f	medium
31471	24599	197	Брянская область, Брасовский район, поселок Локоть, Здание десткого сада Гномик	f	medium
31470	24598	196	Брянская область, Брасовский район, поселок Локоть, Здание Локотской средней школы №2	f	medium
31469	24596	195	Брянская область, Брасовский район, поселок Локоть, Здание Локотской средней школы №3	f	large
31468	24595	194	Брянская область, Брасовский район, поселок Локоть, Здание Брасовского техникума	f	large
31467	24594	193	Брянская область, Брасовский район, поселок Локоть, Здание Локотского Дома культуры	f	large
31466	24593	192	Брянская область, Брасовский район, поселок Локоть	f	medium
31465	24592	191	Брянская область, Брасовский район, поселок Локоть, Административное здание СПК Столбовский им. Столярова	f	medium
31460	24587	186	Брянская область, Брасовский район, поселок Летча, Здание сельской администрации	f	small
31449	24577	175	Брянская область, Брасовский район, поселок Крупец, Здание сельской администрации	f	medium
31447	24575	173	Брянская область, Брасовский район, поселок Красный Колодец, Здание Дома культуры	f	small
31455	24582	181	Брянская область, Брасовский район, поселок Калошичье, Здание магазина РАЙПО	f	small
31448	24576	174	Брянская область, Брасовский район, поселок Городище 1-е, Здание медпункта	t	small
31462	24589	188	Брянская область, Брасовский район, поселок Глоднево, Здание Дома культуры	f	medium
31446	24574	172	Брянская область, Брасовский район, поселок Воронов Лог, Здание сельской администрации	f	small
31463	24590	189	Брянская область, Брасовский район, поселок Веребское, Здание Дома культуры	f	small
31445	24573	171	Брянская область, Брасовский район, поселок Брасово, Здание Брасовской средней школы	f	large
31161	24314	1140	Белгородская область, Шебекино, Чкалова, 40	f	large
31165	24318	1144	Белгородская область, Шебекино, Харьковская, 51	f	large
31159	24312	1138	Белгородская область, Шебекино, Фрунзе, 8	f	large
31166	24319	1145	Белгородская область, Шебекино, Садовая, 7	f	medium
31169	24321	1148	Белгородская область, Шебекино, Ржевское шоссе, 233	f	large
31168	24321	1147	Белгородская область, Шебекино, Ржевское шоссе, 233	f	large
31167	24320	1146	Белгородская область, Шебекино, Ржевское шоссе, 13	f	medium
31150	24303	1129	Белгородская область, Шебекино, Октябрьская, 17	f	large
31149	24302	1128	Белгородская область, Шебекино, Октябрьская, 3	f	large
31148	24301	1127	Белгородская область, Шебекино, Октябрьская, 13	f	large
31164	24317	1143	Белгородская область, Шебекино, Нежегольдское шоссе, 13	f	large
31160	24313	1139	Белгородская область, Шебекино, Мочалина, 7	f	large
31151	24304	1130	Белгородская область, Шебекино, Московская, 19	f	large
31157	24310	1136	Белгородская область, Шебекино, Мичурина, 2А	f	large
31156	24309	1135	Белгородская область, Шебекино, Мичурина, 2	f	large
31158	24311	1137	Белгородская область, Шебекино, Ленина, 70	f	large
31155	24308	1134	Белгородская область, Шебекино, Ленина, 58	f	large
31153	24306	1132	Белгородская область, Шебекино, Ленина, 1	f	large
31152	24305	1131	Белгородская область, Шебекино, Ленина, 19	f	large
31163	24316	1142	Белгородская область, Шебекино, Дзержинского, 18	f	large
31162	24315	1141	Белгородская область, Шебекино, Дзержинского, 13	f	large
31170	24322	1149	Белгородская область, Шебекино, Дачная, 2	f	small
31147	24300	1126	Белгородская область, Шебекино, Белгородская, 8	f	large
30975	24147	954	Белгородская область, Старый Оскол, м-н Юность, 9, СОШ №21	f	large
30976	24147	955	Белгородская область, Старый Оскол, м-н Юность, 9, СОШ №21	f	large
31035	24197	1014	Белгородская область, Старый Оскол городской округ, м-н Юбилейный, 10, СОШ №33	f	large
31032	24195	1011	Белгородская область, Старый Оскол, м-н Юбилейный, 10, СОШ №33	f	large
31034	24195	1013	Белгородская область, Старый Оскол, м-н Юбилейный, 10, СОШ №33	f	large
31033	24195	1012	Белгородская область, Старый Оскол, м-н Юбилейный, 10, СОШ №33	f	large
31009	24175	988	Белгородская область, Старый Оскол, м-н Углы, 17, школа №2	f	large
31008	24175	987	Белгородская область, Старый Оскол, м-н Углы, 17, школа №2	f	large
31007	24175	986	Белгородская область, Старый Оскол, м-н Углы, 17, школа №2	f	large
30991	24159	970	Белгородская область, Старый Оскол городской округ, м-н Студенческий, 4, техникум технологий и дизайна	f	large
30990	24158	969	Белгородская область, Старый Оскол, м-н Студенческий, 5а, техникум строительства,транспорта	f	large
31042	24204	1021	Белгородская область, Старый Оскол, м-н Солнечный, 19, школа №26	f	large
31041	24203	1020	Белгородская область, Старый Оскол, м-н Солнечный, 18, педагогический колледж	f	large
31036	24198	1015	Белгородская область, Старый Оскол, м-н Северный, 7а, ЗАО Витязь	f	large
30984	24154	963	Белгородская область, Старый Оскол, м-н Рудничный, 22, СОШ №19	f	large
30983	24153	962	Белгородская область, Старый Оскол, м-н Рудничный, 1а, библиотека - филиал №11 ЦБС	f	large
30974	24146	953	Белгородская область, Старый Оскол городской округ, м-н Приборостроитель, 16, СОШ №14	f	large
30973	24145	952	Белгородская область, Старый Оскол городской округ, м-н Приборостроитель, 16, СОШ №14	f	large
30972	24145	951	Белгородская область, Старый Оскол городской округ, м-н Приборостроитель, 16, СОШ №14	f	large
30971	24144	950	Белгородская область, Старый Оскол, м-н Приборостроитель, 30, юношеская библиотека-филиал №1 ЦБС	f	large
30992	24160	971	Белгородская область, Старый Оскол, м-н Парковый, 27а, СОШ №13	f	large
31028	24192	1007	Белгородская область, Старый Оскол, м-н Ольминского, 12	f	large
31064	24219	1043	Белгородская область, Старый Оскол, м-н Олимпийский, 18, детская школа искусств №2	f	large
31063	24218	1042	Белгородская область, Старый Оскол, м-н Олимпийский, 49а, спортклуб Невский ОАО ОЭМК	f	large
31062	24217	1041	Белгородская область, Старый Оскол, м-н Олимпийский, 54, школа №20	f	large
31061	24216	1040	Белгородская область, Старый Оскол, м-н Олимпийский, 34, школа №22	f	large
31060	24216	1039	Белгородская область, Старый Оскол, м-н Олимпийский, 34, школа №22	f	large
31059	24215	1038	Белгородская область, Старый Оскол, м-н Олимпийский, 8, гимназия №18	f	large
30977	24148	956	Белгородская область, Старый Оскол, м-н Молодогвардеец, 15, СОШ №15	f	large
31040	24202	1019	Белгородская область, Старый Оскол, м-н Макаренко, 36а, СОШ №28	f	large
31039	24201	1018	Белгородская область, Старый Оскол, м-н Макаренко, 39, ПУ №9	f	large
31038	24200	1017	Белгородская область, Старый Оскол, м-н Макаренко, 3а, индустриальный техникум	f	large
31037	24199	1016	Белгородская область, Старый Оскол, м-н Макаренко, 7а, Д/К Молодежный	f	large
30986	24156	965	Белгородская область, Старый Оскол, м-н Лебединец, 28, СОШ №12	f	large
30985	24155	964	Белгородская область, Старый Оскол, м-н Лебединец, 28, СОШ № 12	f	large
31065	24221	1044	Белгородская область, Старый Оскол, м-н Космос, 6, Детский санаторий Надежда	f	large
31045	24206	1024	Белгородская область, Старый Оскол городской округ, м-н Королева, 16, СОШ №34	f	large
31044	24206	1023	Белгородская область, Старый Оскол городской округ, м-н Королева, 16, СОШ №34	f	large
31027	24191	1006	Белгородская область, Старый Оскол, м-н Конева, 15а, СОШ №24	f	large
31026	24191	1005	Белгородская область, Старый Оскол, м-н Конева, 15а, СОШ №24	f	large
30994	24162	973	Белгородская область, Старый Оскол городской округ, м-н Интернациональный, 1, лицей №3	f	large
30993	24161	972	Белгородская область, Старый Оскол, м-н Интернациональный, 23, СОШ №11	f	large
31031	24194	1010	Белгородская область, Старый Оскол, м-н Зеленый Лог, 5	f	large
30970	24143	949	Белгородская область, Старый Оскол, м-н Звездный, 13, ФОК	f	large
30969	24143	948	Белгородская область, Старый Оскол, м-н Звездный, 13, ФОК	f	large
31058	24214	1037	Белгородская область, Старый Оскол, м-н Жукова, 24а, пункт охраны общественного порядка	f	large
31057	24213	1036	Белгородская область, Старый Оскол, м-н Жукова, 54, школа №16	f	large
31055	24211	1034	Белгородская область, Старый Оскол, м-н Жукова, 57, школа №17	f	large
31054	24211	1033	Белгородская область, Старый Оскол, м-н Жукова, 57, школа №17	f	large
31053	24210	1032	Белгородская область, Старый Оскол, м-н Жукова, 37, центр развития творчества детей	f	large
31052	24209	1031	Белгородская область, Старый Оскол, м-н Жукова, 36, школа №6	f	large
31043	24205	1022	Белгородская область, Старый Оскол, м-н Жукова, 30б, детская музыкальная школа №5	f	large
31067	24222	1046	Белгородская область, Старый Оскол, м-н Дубрава, 5	f	large
31066	24222	1045	Белгородская область, Старый Оскол, м-н Дубрава, 5	f	large
30997	24164	976	Белгородская область, Старый Оскол, м-н Горняк, 7, Центр культуры и искусств	f	large
30996	24163	975	Белгородская область, Старый Оскол, м-н Горняк, 35, СОШ №1	f	large
30995	24163	974	Белгородская область, Старый Оскол, м-н Горняк, 35, СОШ №1	f	large
31050	24208	1029	Белгородская область, Старый Оскол, м-н Восточный, 51, СОШ №40	f	large
31049	24208	1028	Белгородская область, Старый Оскол, м-н Восточный, 51, СОШ №40	f	large
31051	24208	1030	Белгородская область, Старый Оскол, м-н Восточный, 51, СОШ №40	f	large
30981	24151	960	Белгородская область, Старый Оскол, м-н Весенний, 11, АПК Стойленская Нива	f	large
31030	24193	1009	Белгородская область, Старый Оскол, м-н Буденного, 2, школа №25	f	large
31029	24193	1008	Белгородская область, Старый Оскол, м-н Буденного, 2, школа №25	f	large
30988	24157	967	Белгородская область, Старый Оскол городской округ, бульвар Дружбы, 1, ДК Комсомолец	f	large
30989	24157	968	Белгородская область, Старый Оскол городской округ, бульвар Дружбы, 1, ДК Комсомолец	f	large
30987	24157	966	Белгородская область, Старый Оскол городской округ, бульвар Дружбы, 1, ДК Комсомолец	f	large
31016	24182	995	Белгородская область, Старый Оскол, Южная, 68	f	medium
31024	24189	1003	Белгородская область, Старый Оскол, Стадионная, 13, городской д/к Железнодорожник	f	medium
31023	24188	1002	Белгородская область, Старый Оскол городской округ, Стадионная, 14, школа № 36	f	large
31025	24190	1004	Белгородская область, Старый Оскол, Советская, 11а, межшкольный учкомбинат	f	large
30998	24165	977	Белгородская область, Старый Оскол, Свердлова, ЦТП №12	f	large
31018	24183	997	Белгородская область, Старый Оскол, Революционная, 15, театр для детей и молодежи	f	large
31019	24184	998	Белгородская область, Старый Оскол, Пролетарская, 72а, СОШ №8	f	large
31010	24176	989	Белгородская область, Старый Оскол, Пролетарская, 108, медицинский колледж	f	medium
31006	24174	985	Белгородская область, Старый Оскол, Первой Конной Армии, 26а, школа №9	f	large
31017	24168	996	Белгородская область, Старый Оскол, Октябрьская, 10, СОШ №5	f	large
31013	24179	992	Белгородская область, Старый Оскол, Мира, 22, бывшая школа №10	f	large
31012	24178	991	Белгородская область, Старый Оскол, Мира, 4, автошкола РОСТО (ДОСААФ) 	f	large
31003	24171	982	Белгородская область, Старый Оскол, Ленина, 17, спорт зал техникума ГРТ	f	large
31005	24173	984	Белгородская область, Старый Оскол, Комсомольская, 33/36, школа №35	f	small
31002	24170	981	Белгородская область, Старый Оскол, Зои Космодемьянской, 42, СОШ №7	f	large
31021	24186	1000	Белгородская область, Старый Оскол, Заречная, 32, бывшая школа № 37	f	medium
31020	24185	999	Белгородская область, Старый Оскол, Заречная, 32, бывшая школа №37	f	medium
31056	24212	1035	Белгородская область, Старый Оскол, Жукова, 54, СОШ №16	f	large
30999	24166	978	Белгородская область, Старый Оскол, Ватутина, 27а, МУП Водоканал	f	large
31015	24181	994	Белгородская область, Старый Оскол городской округ, Большевистская, 14, библиотека филиал №2 ЦБС	f	medium
31022	24187	1001	Белгородская область, Старый Оскол, 19 Партсъезда, 45, Красный уголок ЮЖВД	f	large
30591	23768	570	Белгородская область, Губкин, проспект Горняков, 1	f	large
30558	23742	537	Белгородская область, Губкин, Школьная, 21а	f	large
30559	23454	538	Белгородская область, Губкин, Чайковского, 18	f	large
30566	23744	545	Белгородская область, Губкин, Фрунзе, 6А	f	medium
30594	23771	573	Белгородская область, Губкин, Ударников, 12	f	large
30572	23750	551	Белгородская область, Губкин, Спортивный проезд, 3	f	large
30564	23678	543	Белгородская область, Губкин, Советская, 27	f	medium
30561	23517	540	Белгородская область, Губкин, Советская, 29	f	large
30553	23737	532	Белгородская область, Губкин, Революционная, 8	f	small
30571	23749	550	Белгородская область, Губкин, Раевского, 15а	f	large
30570	23748	549	Белгородская область, Губкин, Раевского, 9	f	large
30568	23746	547	Белгородская область, Губкин, Раевского, 3а	f	large
30584	23761	563	Белгородская область, Губкин, Преображенская, 6г	f	large
30555	23739	534	Белгородская область, Губкин, Победы, 24	f	medium
30554	23738	533	Белгородская область, Губкин, Победы, 1	f	large
30593	23770	572	Белгородская область, Губкин, Павлика Морозова, 8	f	large
30578	23756	557	Белгородская область, Губкин, Осколецкая, 21	f	large
30590	23767	569	Белгородская область, Губкин, Народня, 4А	f	medium
30589	23766	568	Белгородская область, Губкин, Народная, 2А	f	medium
30575	23753	554	Белгородская область, Губкин, Мичурина, 21	f	large
30563	23642	542	Белгородская область, Губкин, Мира, 22	f	large
30562	23546	541	Белгородская область, Губкин, Мира, 18	f	large
30573	23751	552	Белгородская область, Губкин, Лазарева, 23/92	f	medium
30569	23747	548	Белгородская область, Губкин, Лазарева, 17а	f	large
30567	23745	546	Белгородская область, Губкин, Лазарева, 15	f	large
30565	23743	544	Белгородская область, Губкин городской округ, Лазарева, 13	f	large
30586	23763	565	Белгородская область, Губкин, Королева, 30	f	large
30583	23760	562	Белгородская область, Губкин, Королева, 12а	f	large
30582	23760	561	Белгородская область, Губкин, Королева, 12а	f	large
30581	23759	560	Белгородская область, Губкин, Королева, 3а	f	large
30557	23741	536	Белгородская область, Губкин, Комсомольская, 16	f	large
30579	23757	558	Белгородская область, Губкин, Карла Маркса, 21а	f	large
30587	23764	566	Белгородская область, Губкин, Добролюбова, 13А	f	medium
30576	23754	555	Белгородская область, Губкин, Дзержинского, 17	f	large
30588	23765	567	Белгородская область, Губкин, Гастелло, 14	f	large
30580	23758	559	Белгородская область, Губкин, Воинов-интернационалистов, 1	f	large
30596	23773	575	Белгородская область, Губкин, Белгородская, 349	f	large
30595	23772	574	Белгородская область, Губкин, Белгородская, 97	f	medium
30556	23740	535	Белгородская область, Губкин, Артема, 18/3	f	medium
30585	23762	564	Белгородская область, Губкин, Агошкова, 1а	f	large
111567	57348	3130	Москва, Зеленоград, к1017	f	medium
30577	23755	556	Белгородская область, Губкин, 2-я Академическая, 34	f	large
30237	23424	216	Белгородская область, Белгород городской округ, бульвар Первого Салюта, 8	f	large
30118	23338	97	Белгородская область, Белгород, Юности бульвар, 14	f	large
30119	23338	98	Белгородская область, Белгород, Юности бульвар, 14	f	large
30117	23338	96	Белгородская область, Белгород, Юности бульвар, 14	f	large
30103	23330	82	Белгородская область, Белгород, Юности бульвар, 4	f	large
30128	23344	107	Белгородская область, Белгород, Щорса, 18	f	large
30127	23343	106	Белгородская область, Белгород, Щорса, 14	f	large
30126	23342	105	Белгородская область, Белгород, Щорса, 11	f	large
30125	23342	104	Белгородская область, Белгород, Щорса, 11	f	large
30124	23342	103	Белгородская область, Белгород, Щорса, 11	f	large
30122	23340	101	Белгородская область, Белгород, Щорса, 46	f	large
30104	23331	83	Белгородская область, Белгород, Щорса, 8	f	medium
30102	23329	81	Белгородская область, Белгород, Щорса, 55В	f	large
30101	23328	80	Белгородская область, Белгород, Щорса, 43	f	large
30100	23328	79	Белгородская область, Белгород, Щорса, 43	f	large
30246	23429	225	Белгородская область, Белгород, Шумилова, 12А	f	medium
30218	23411	197	Белгородская область, Белгород, Широкая, 1	f	medium
30171	23376	150	Белгородская область, Белгород, Шершнева, 26	f	large
30170	23376	149	Белгородская область, Белгород, Шершнева, 26	f	large
30130	23346	109	Белгородская область, Белгород городской округ, Шаландина, 5	f	large
30131	23346	110	Белгородская область, Белгород городской округ, Шаландина, 5	f	large
30132	23327	111	Белгородская область, Белгород городской округ, Белгород, Шаландина, 13	f	large
30099	23327	78	Белгородская область, Белгород городской округ, Белгород, Шаландина, 13	f	large
30211	23404	190	Белгородская область, Белгород, Чумичева, 51	f	large
30210	23403	189	Белгородская область, Белгород, Чумичева, 53А	f	large
30160	23366	139	Белгородская область, Белгород, Чапаева, 22	f	large
30159	23366	138	Белгородская область, Белгород, Чапаева, 22	f	large
30147	23356	126	Белгородская область, Белгород, Чапаева, 14	f	large
30146	23356	125	Белгородская область, Белгород, Чапаева, 14	f	large
30145	23356	124	Белгородская область, Белгород, Чапаева, 14	f	large
30196	23395	175	Белгородская область, Белгород, Хихлушки, 4	f	large
30204	23395	183	Белгородская область, Белгород, Хихлушки, 4	f	large
30157	23364	136	Белгородская область, Белгород, Сумская, 378	f	large
30156	23363	135	Белгородская область, Белгород, Сумская, 72	f	large
30154	23361	133	Белгородская область, Белгород, Сумская, 64	f	large
30189	23391	168	Белгородская область, Белгород, Студенческая, 14	f	large
30172	23377	151	Белгородская область, Белгород, Студенческая, 17А	f	large
30113	23318	92	Белгородская область, Белгород, Спортивная, 6А	f	large
30114	23318	93	Белгородская область, Белгород, Спортивная, 6А	f	large
30080	23318	59	Белгородская область, Белгород, Спортивная, 6А	f	large
30143	23354	122	Белгородская область, Белгород, Славы пр, 69	f	large
30193	23394	172	Белгородская область, Белгород, Садовая, 116А	f	large
30192	23394	171	Белгородская область, Белгород, Садовая, 116А	f	large
30194	23373	173	Белгородская область, Белгород, Садовая, 3	f	large
30195	23373	174	Белгородская область, Белгород, Садовая, 3	f	large
30167	23373	146	Белгородская область, Белгород, Садовая, 3	f	large
30191	23393	170	Белгородская область, Белгород городской округ, Белгород, Садовая, 116А	f	large
30202	23398	181	Белгородская область, Белгород городской округ, Белгород, Репина, 3	f	large
30201	23398	180	Белгородская область, Белгород городской округ, Белгород, Репина, 3	f	large
30200	23398	179	Белгородская область, Белгород городской округ, Белгород, Репина, 3	f	large
30235	23422	214	Белгородская область, Белгород, Пугачева, 5	f	large
30174	23378	153	Белгородская область, Белгород, Привольная, 16	f	large
30173	23378	152	Белгородская область, Белгород, Привольная, 16	f	large
30165	23371	144	Белгородская область, Белгород, Привольная, 2	f	large
30227	23417	206	Белгородская область, Белгород, Преображенская, 19	f	large
30228	23409	207	Белгородская область, Белгород, Преображенская, 14	f	large
30216	23409	195	Белгородская область, Белгород, Преображенская, 14	f	large
30152	23359	131	Белгородская область, Белгород, Преображенская, 98	f	large
30151	23358	130	Белгородская область, Белгород, Преображенская, 78	f	large
30225	23415	204	Белгородская область, Белгород, Попова, 26/45	f	large
30203	23399	182	Белгородская область, Белгород, Попова, 98	f	large
30234	23421	213	Белгородская область, Белгород, Победы, 40А	f	large
30149	23357	128	Белгородская область, Белгород, Победы, 78	f	large
30150	23353	129	Белгородская область, Белгород, Победы, 85А	f	large
30142	23353	121	Белгородская область, Белгород, Победы, 85А	f	large
30214	23407	193	Белгородская область, Белгород, Первомайская, 2А	f	large
30241	23426	220	Белгородская область, Белгород, Первого салюта бульвар, 6	f	large
30240	23426	219	Белгородская область, Белгород, Первого салюта бульвар, 6	f	large
30239	23425	218	Белгородская область, Белгород, Первого салюта бульвар, 8	f	large
30238	23425	217	Белгородская область, Белгород, Первого салюта бульвар, 8	f	large
30213	23406	192	Белгородская область, Белгород, Октябрьская, 59А	f	large
30208	23402	187	Белгородская область, Белгород, Октябрьская, 26А	f	large
30207	23402	186	Белгородская область, Белгород, Октябрьская, 26А	f	medium
30209	23402	188	Белгородская область, Белгород, Октябрьская, 26А	f	medium
30206	23401	185	Белгородская область, Белгород, Октябрьская, 58	f	large
30144	23355	123	Белгородская область, Белгород, Озембловского, 34	f	large
30188	23390	167	Белгородская область, Белгород городской округ, Белгород, Некрасова, 38А	f	large
30190	23392	169	Белгородская область, Белгород, Некрасова, 19	f	large
30186	23389	165	Белгородская область, Белгород, Некрасова, 20	f	large
30187	23389	166	Белгородская область, Белгород, Некрасова, 20	f	large
30185	23388	164	Белгородская область, Белгород, Некрасова, 17Б	f	large
30169	23375	148	Белгородская область, Белгород, Некрасова, 5Б/8	f	large
30224	23414	203	Белгородская область, Белгород, Народный бульвар, 55	f	large
30212	23405	191	Белгородская область, Белгород, Народный бульвар, 74	f	large
30162	23368	141	Белгородская область, Белгород, Народный бульвар, 118	f	large
30161	23367	140	Белгородская область, Белгород, Народный бульвар, 118	f	large
30081	23319	60	Белгородская область, Белгород городской округ, Белгород, Молодежная, 2А	f	large
30097	23325	76	Белгородская область, Белгород городской округ, Белгород, Мокроусова, 3А	f	large
30168	23374	147	Белгородская область, Белгород, Мичурина, 39	f	large
30163	23369	142	Белгородская область, Белгород, Мичурина, 43	f	large
30182	23385	161	Белгородская область, Белгород, Менделеева, 14	f	large
30179	23383	158	Белгородская область, Белгород, Менделеева, 4	f	large
30181	23384	160	Белгородская область, Белгород, Менделеев, 6	f	large
30180	23384	159	Белгородская область, Белгород, Менделеев, 6	f	large
30221	23412	200	Белгородская область, Белгород, Макаренко, 3	f	large
30219	23412	198	Белгородская область, Белгород, Макаренко, 3	f	large
30220	23412	199	Белгородская область, Белгород, Макаренко, 3	f	large
30178	23382	157	Белгородская область, Белгород, Кутузова, 19	f	large
30164	23370	143	Белгородская область, Белгород, Курская, 8	f	large
30175	23379	154	Белгородская область, Белгород, Куйбышева, 33А	f	large
30176	23380	155	Белгородская область, Белгород, Крупской, 9	f	medium
30098	23326	77	Белгородская область, Белгород, Костюкова, 11А	f	large
30233	23420	212	Белгородская область, Белгород, Костюкова, 46	f	large
30232	23420	211	Белгородская область, Белгород, Костюкова, 46	f	large
30141	23352	120	Белгородская область, Белгород, Костюкова, 13	f	large
30140	23351	119	Белгородская область, Белгород, Костюкова, 20	f	large
30139	23351	118	Белгородская область, Белгород, Костюкова, 20	f	large
30199	23397	178	Белгородская область, Белгород, Корочанская, 318	f	large
30198	23397	177	Белгородская область, Белгород, Корочанская, 318	f	large
30242	23427	221	Белгородская область, Белгород городской округ, Белгород, Королепа, 22	f	large
30245	23428	224	Белгородская область, Белгород, Королева, 22	f	large
30244	23428	223	Белгородская область, Белгород, Королева, 22	f	large
30243	23428	222	Белгородская область, Белгород, Королева, 22	f	large
30135	23349	114	Белгородская область, Белгород, Королева, 7	f	large
30134	23348	113	Белгородская область, Белгород, Королева, 5	f	large
30133	23347	112	Белгородская область, Белгород, Королева, 8	f	large
30093	23289	72	Белгородская область, Белгород, Конева, 11	f	large
30092	23289	71	Белгородская область, Белгород, Конева, 11	f	large
30095	23289	74	Белгородская область, Белгород, Конева, 11	f	large
30197	23396	176	Белгородская область, Белгород, Индустриальная, 85	f	small
30184	23387	163	Белгородская область, Белгород, Железнякова, 2	f	large
30183	23386	162	Белгородская область, Белгород, Железнякова, 4	f	large
30091	23324	70	Белгородская область, Белгородский район, Есенина, 48Б	f	large
30090	23323	69	Белгородская область, Белгород, Есенина, 40А	f	large
30089	23323	68	Белгородская область, Белгород, Есенина, 40А	f	large
30088	23323	67	Белгородская область, Белгород, Есенина, 40А	f	large
30087	23322	66	Белгородская область, Белгород, Есенина, 38А	f	large
30231	23419	210	Белгородская область, Белгород, Донецкая, 84	f	large
30137	23350	116	Белгородская область, Белгород, Дегтярева, 1	f	large
30148	23350	127	Белгородская область, Белгород, Дегтярева, 1	f	large
30136	23350	115	Белгородская область, Белгород, Дегтярева, 1	f	large
30138	23350	117	Белгородская область, Белгород, Дегтярева, 1	f	large
30116	23337	95	Белгородская область, Белгород, Губкина, 27	f	large
30115	23336	94	Белгородская область, Белгород, Губкина, 48	f	small
30236	23423	215	Белгородская область, Белгород, Гражданский проспект, 33	f	large
30226	23416	205	Белгородская область, Белгород, Гражданский проспект, 50	f	large
30230	23418	209	Белгородская область, Белгород, Гражданский пр, 55	f	large
30129	23345	108	Белгородская область, Белгород, Горького, 71	f	large
30107	23333	86	Белгородская область, Белгород, Горького, 26А	f	large
30108	23333	87	Белгородская область, Белгород, Горького, 26А	f	large
30217	23410	196	Белгородская область, Белгород, Волчанская, 22	f	medium
30155	23362	134	Белгородская область, Белгород, Везельская, 95	f	small
30247	23430	226	Белгородская область, Белгород, Ватутина пр, 23	f	large
30223	23413	202	Белгородская область, Белгород, Ватутина, 2А	f	large
30222	23413	201	Белгородская область, Белгород, Ватутина, 2А	f	large
30121	23339	100	Белгородская область, Белгород, Буденного, 1	f	large
30120	23339	99	Белгородская область, Белгород, Буденного, 1	f	large
30086	23321	65	Белгородская область, Белгород, Буденного, 4	f	large
30085	23321	64	Белгородская область, Белгород, Буденного, 4	f	large
30229	23408	208	Белгородская область, Белгород, Белгородского полка, 56А	f	large
30215	23408	194	Белгородская область, Белгород, Белгородского полка, 56А	f	large
30153	23360	132	Белгородская область, Белгород, Белгородский пр, 116	f	large
30166	23372	145	Белгородская область, Белгород, Б.Хмельницкого, 58	f	large
30106	23332	85	Белгородская область, Белгород, Апанасенко, 51А	f	large
30105	23332	84	Белгородская область, Белгород, Апанасенко, 51А	f	large
30110	23334	89	Белгородская область, Белгород, 8 марта, 172	f	large
30109	23334	88	Белгородская область, Белгород, 8 марта, 172	f	large
30079	23317	58	Белгородская область, Белгород, 60 лет Октября, 4	f	large
30078	23317	57	Белгородская область, Белгород, 60 лет Октября, 4	f	large
30077	23317	56	Белгородская область, Белгород, 60 лет Октября, 4	f	large
30112	23316	91	Белгородская область, Белгород, 60 лет Октября, 7	f	large
30076	23316	55	Белгородская область, Белгород, 60 лет Октября, 7	f	large
30084	23316	63	Белгородская область, Белгород, 60 лет Октября, 7	f	medium
30083	23316	62	Белгородская область, Белгород, 60 лет Октября, 7	f	large
30123	23341	102	Белгородская область, Белгород, 5 Августа, 2	f	large
30205	23400	184	Белгородская область, Белгород, 2 Карьерный пр, 10	f	large
30158	23365	137	Белгородская область, Белгород, 2 Декабристов переулок, 8	f	large
30177	23381	156	Белгородская область, Белгород, 1 Центральная, 20	f	large
30022	23261	1	Белгородская область, Алексеевка, площадь 3 Интернационала, 5	f	large
30029	23268	8	Белгородская область, Алексеевка, Чкалова, 62	f	large
30027	23266	6	Белгородская область, Алексеевка, Фрунзе, 2	f	large
30023	23262	2	Белгородская область, Алексеевка, Ф.Энгельса, 6	f	large
30026	23265	5	Белгородская область, Алексеевка, Урицкого, 91	f	large
30033	23272	12	Белгородская область, Алексеевка, Тимирязева, 10	f	large
30036	23275	15	Белгородская область, Алексеевка, Спортивная, 54	f	large
30030	23269	9	Белгородская область, Алексеевка, Свердлова, 10Г	f	large
30031	23270	10	Белгородская область, Алексеевка, Привокзальная, 5	f	large
30024	23263	3	Белгородская область, Алексеевка, Ленина, 119	f	large
30025	23264	4	Белгородская область, Алексеевка, Л.Толстого, 8	f	large
30032	23271	11	Белгородская область, Алексеевка, Комсомольская, 51	f	large
30034	23273	13	Белгородская область, Алексеевка, Кирова, 6	f	large
30028	23267	7	Белгородская область, Алексеевка, В.Собины, 10	f	large
31236	24388	1215	Белгородская область, Яковлевский район, поселок Яковлево, Шаландина, 80б	f	large
31235	24387	1214	Белгородская область, Яковлевский район, поселок Яковлево, Октябрьская, 11	f	large
31274	24427	1253	Белгородская область, Яковлевский район, поселок Шопино, Школьный переулок, 5	f	medium
31246	24398	1225	Белгородская область, Яковлевский район, поселок Черкасское, Озерная, 1А	f	small
31256	24408	1235	Белгородская область, Яковлевский район, поселок Триречное, Школьная, 3	f	small
31241	24393	1220	Белгородская область, Яковлевский район, поселок Томаровка, Ватутина, 5	f	large
31239	24391	1218	Белгородская область, Яковлевский район, поселок Томаровка, Ватутина, 3	f	large
31238	24390	1217	Белгородская область, Яковлевский район, поселок Томаровка, Ватутина, 1	f	large
31242	24394	1221	Белгородская область, Яковлевский район, поселок Томаровка, 32-го Гвардейского Корпуса, 15А	f	large
31273	24426	1252	Белгородская область, Яковлевский район, поселок Терновка, Центральная, 5	f	large
31232	24385	1211	Белгородская область, Яковлевский район, Строитель, Юбилейная, 1	f	large
31233	24384	1212	Белгородская область, Яковлевский район, Строитель, Победы, 7	f	large
31231	24384	1210	Белгородская область, Яковлевский район, Строитель, Победы, 7	f	large
31228	24381	1207	Белгородская область, Яковлевский район, Строитель, Октябрьская, 2	f	large
31230	24383	1209	Белгородская область, Яковлевский район, Строитель, Ленина, здание столовой ПУ № 16	f	large
31229	24382	1208	Белгородская область, Яковлевский район, Строитель, Ленина, 24	f	large
31227	24380	1206	Белгородская область, Яковлевский район, Строитель, Ленина, 9	f	large
31225	24377	1204	Белгородская область, Яковлевский район, Строитель, Ленина, 14	f	large
31226	24378	1205	Белгородская область, Яковлевский район, Строитель, 5-Августа, 10	f	large
31234	24386	1213	Белгородская область, Яковлевский район, Строитель , Магистральная, 2	f	large
31271	24424	1250	Белгородская область, Яковлевский район, поселок Стрелецкое, Школьная, 3А	f	medium
31237	24389	1216	Белгородская область, Яковлевский район, поселок Смородино, Советская, 41	f	medium
31263	24416	1242	Белгородская область, Яковлевский район, поселок Серетено, Калинина, 110	f	medium
31261	24414	1240	Белгородская область, Яковлевский район, поселок Сажное, Центральная, 20	f	small
31250	24402	1229	Белгородская область, Яковлевский район, поселок Сажное, Центральная, 14	f	medium
31259	24412	1238	Белгородская область, Яковлевский район, поселок Сабынино, Центральная, 13	f	small
31269	24422	1248	Белгородская область, Яковлевский район, поселок Пушкарное, Школьный переулок, 3А	f	small
31254	24406	1233	Белгородская область, Яковлевский район, поселок Подымовка, Центральная, 41	f	small
31260	24413	1239	Белгородская область, Яковлевский район, поселок Озерово, Центральная, 32	f	small
31265	24418	1244	Белгородская область, Яковлевский район, поселок Новая Глинка, Центральная, 48	f	small
31267	24420	1246	Белгородская область, Яковлевский район, поселок Мощеное, Садовая, 2А	f	small
31270	24423	1249	Белгородская область, Яковлевский район, поселок Мощеное, Набережная, 23	t	small
31244	24396	1223	Белгородская область, Яковлевский район, поселок Луханино, Новая, 18	f	small
31266	24419	1245	Белгородская область, Яковлевский район, поселок Локня, Лесная, 17	t	small
31264	24417	1243	Белгородская область, Яковлевский район, поселок Кустовое, Проворова, 41	f	large
31249	24401	1228	Белгородская область, Яковлевский район, поселок Крюково, здание сельского клуба	f	small
31257	24410	1236	Белгородская область, Яковлевский район, поселок Кривцово, Центральная, 18	f	medium
31240	24392	1219	Белгородская область, Яковлевский район, поселок Красная Поляна, Малиновского, 35	f	medium
31262	24415	1241	Белгородская область, Яковлевский район, поселок Калинино	t	small
31255	24407	1234	Белгородская область, Яковлевский район, поселок Казацкое	f	medium
31253	24405	1232	Белгородская область, Яковлевский район, поселок Завидовка, Школьная, 1	f	medium
31268	24421	1247	Белгородская область, Яковлевский район, поселок Драгунское, Центральная, 67	f	small
31252	24404	1231	Белгородская область, Яковлевский район, поселок Дмитриевка, Центральная, 59	f	medium
31251	24403	1230	Белгородская область, Яковлевский район, поселок Гостищево, Советская, 5	f	large
31248	24400	1227	Белгородская область, Яковлевский район, поселок Гостищево, Советская, 15	f	medium
31272	24425	1251	Белгородская область, Яковлевский район, поселок Вислое, Школьная, 13	f	small
31258	24411	1237	Белгородская область, Яковлевский район, поселок Верхний Ольшанец, Школьная, 1	t	small
31247	24399	1226	Белгородская область, Яковлевский район, поселок Быковка, Центральная, 64	f	large
31245	24397	1224	Белгородская область, Яковлевский район, поселок Бутово, Речная, 3	f	medium
31243	24395	1222	Белгородская область, Яковлевский район, поселок Алексеевка, Центральная, 36	f	medium
31224	24376	1203	Белгородская область, Шебекинский район, поселок Шебекинский, Подлесная, 1	f	small
31219	24371	1198	Белгородская область, Шебекинский район, поселок Чураево, Гагарина, сельский дом культуры	f	medium
31202	24355	1181	Белгородская область, Шебекинский район, поселок Червона Дибровка, Центральная, здание общежития БГК	f	small
31217	24369	1196	Белгородская область, Шебекинский район, поселок Цепляево 1-е, Ленин, сельский дом культуры	f	medium
31218	24370	1197	Белгородская область, Шебекинский район, поселок Сурково, Фрунзе, сельский дом культуры	f	medium
31184	24336	1163	Белгородская область, Шебекинский район, поселок Стрелица 2-я, Больничная, 19, амбулатория	f	small
31174	24326	1153	Белгородская область, Шебекинский район, поселок Стрелица 1-я, Октябрьская, сельский клуб	f	small
31185	24337	1164	Белгородская область, Шебекинский район, поселок Стариково, Ленина, сельский клуб	f	medium
31211	24364	1190	Белгородская область, Шебекинский район, поселок Середа, Октябрьская, школа	f	small
31192	24344	1171	Белгородская область, Шебекинский район, поселок Ржевка, Пионерская, 49, здание школы	f	medium
31193	24345	1172	Белгородская область, Шебекинский район, поселок Ржевка, Ленина, 1А, дом культуры	f	large
31199	24351	1178	Белгородская область, Шебекинский район, поселок Репное, 1 Мая, здание сельской библиотеки	f	small
31181	24333	1160	Белгородская область, Шебекинский район, поселок Поповка, Центральная, сельский дом культуры	f	small
31207	24360	1186	Белгородская область, Шебекинский район, поселок Поляна, Центральная, 16	f	small
31213	24365	1192	Белгородская область, Шебекинский район, поселок Новая Таволжанка, Харьковская, 22	f	large
31212	24365	1191	Белгородская область, Шебекинский район, поселок Новая Таволжанка, Харьковская, 22	f	large
31215	24367	1194	Белгородская область, Шебекинский район, поселок Новая Таволжанка, Колхозная, 13	f	medium
31214	24366	1193	Белгородская область, Шебекинский район, поселок Новая Таволжанка, Кирова, 1Г	f	large
31222	24374	1201	Белгородская область, Шебекинский район, поселок Никольское, Ленина, здание школы	f	small
31176	24328	1155	Белгородская область, Шебекинский район, поселок Нижнее Березово 2-е, Октябрьская, сельский клуб	f	small
31223	24375	1202	Белгородская область, Шебекинский район, поселок Неклюдово, Советская, здание ФАП	f	small
31191	24343	1170	Белгородская область, Шебекинский район, поселок Нежеголь, Ленина, сельский дом культуры	f	medium
31209	24362	1188	Белгородская область, Шебекинский район, поселок Муром, Гагарина, здание школы	f	medium
31203	24356	1182	Белгородская область, Шебекинский район, поселок Мешковое, Молодежная, здание школы	f	medium
31204	24357	1183	Белгородская область, Шебекинский район, поселок Маслова Пристань, Шумилова, 1	f	large
31206	24359	1185	Белгородская область, Шебекинский район, поселок Маслова Пристань, 1 Мая, 4	f	large
31205	24358	1184	Белгородская область, Шебекинский район, поселок Маслова Пристань, 1 Мая, 156	f	large
31189	24341	1168	Белгородская область, Шебекинский район, поселок Маломихайловка, ул. Садовая, сельский дом культуры	f	medium
83932	57347	3131	Москва, Зеленоград, к1017	f	large
31201	24354	1180	Белгородская область, Шебекинский район, поселок Максимовка, Коммунистическая, здание сельского дома 	f	medium
31196	24348	1175	Белгородская область, Шебекинский район, поселок Купино, Ленина, 61	f	large
31190	24342	1169	Белгородская область, Шебекинский район, поселок Красное, Школьная, 10	f	medium
31198	24350	1177	Белгородская область, Шебекинский район, поселок Красная Поляна, Гагарина, здание школы	f	medium
31221	24373	1200	Белгородская область, Шебекинский район, поселок Крапивное, Победы, сельский дом культуры	f	medium
31220	24372	1199	Белгородская область, Шебекинский район, поселок Кошлаково, Молодежная, здание школы	f	medium
31178	24330	1157	Белгородская область, Шебекинский район, поселок Козьмодемьяновка, Прилужная, сельский клуб	f	medium
31172	24324	1151	Белгородская область, Шебекинский район, поселок Караичное, Гагарина, сельский клуб	t	small
30601	23777	580	Белгородская область, Шебекинский район, поселок Ивановка, Центральная, 7А	f	small
31200	24352	1179	Белгородская область, Шебекинский район, поселок Зимовное, Серпа и молота, здание сельского клуба	f	small
31177	24329	1156	Белгородская область, Шебекинский район, поселок Зимовенька, Базарная, сельский клуб	f	small
31210	24363	1189	Белгородская область, Шебекинский район, поселок Зиборовка, Зеленая, здание сельского дома культуры	f	small
31197	24349	1176	Белгородская область, Шебекинский район, поселок Дмитриевка, Победы, 38	f	medium
31194	24346	1173	Белгородская область, Шебекинский район, поселок Графовка, Центральная, 1А	f	large
30799	23972	778	Белгородская область, Шебекинский район, поселок Графовка, Центральная, 1	f	medium
31188	24340	1167	Белгородская область, Шебекинский район, поселок Вознесеновка, Административная, здание администрации 	f	large
31187	24339	1166	Белгородская область, Шебекинский район, поселок Верхнеберезово, Кооперативная, здание школы	f	medium
31182	24334	1161	Белгородская область, Шебекинский район, поселок Булановка, Ленина, здание школы	f	medium
31183	24335	1162	Белгородская область, Шебекинский район, поселок Большое Городище, Советская, здание администрации	f	medium
31186	24338	1165	Белгородская область, Шебекинский район, поселок Большетроицкое, пер. Чапаева, Дом культуры	f	large
31179	24331	1158	Белгородская область, Шебекинский район, поселок Бершаково, Калинина, адм.здание АО Восход	f	medium
31175	24327	1154	Белгородская область, Шебекинский район, поселок Белянка, Школьная, дом культуры	f	large
30445	23629	424	Белгородская область, Шебекинский район, поселок Белый Колодезь, помещение сельского Дома культуры	f	large
31171	24323	1150	Белгородская область, Шебекинский район, поселок Белый Колодезь, Кирова, ДК	f	small
31195	24347	1174	Белгородская область, Шебекинский район, поселок Безлюдовка, Садовый, 19	f	medium
31208	24361	1187	Белгородская область, Шебекинский район, поселок Батрацкая Дача, Центральная, Здание сельского клуба	f	small
31216	24368	1195	Белгородская область, Шебекинский район, поселок Архангельское, Ушакова, сельский дом культуры	f	medium
31173	24325	1152	Белгородская область, Шебекинский район, поселок Артельное, Пролетарская, администрация	f	small
31113	24266	1092	Белгородская область, Шебекинский район, поселок Андреевка, Центральная, 36	f	small
31180	24332	1159	Белгородская область, Шебекинский район, поселок Александровка, Степная, здание школы	f	small
30441	23625	420	Белгородская область, Чернянский район, Яблоново, здание Яблоновского сельского Дома культуры	f	small
31110	24263	1089	Белгородская область, Чернянский район, поселок Чернянка, пл. Октябрьская, 4	f	large
31104	24257	1083	Белгородская область, Чернянский район, поселок Чернянка, пл. Октябрьская, 12	f	large
31112	24265	1091	Белгородская область, Чернянский район, поселок Чернянка, переулок Оскольский, 1	f	medium
31108	24261	1087	Белгородская область, Чернянский район, поселок Чернянка, Строительная, 14	f	large
31106	24259	1085	Белгородская область, Чернянский район, поселок Чернянка, Советская, 59	f	large
31105	24258	1084	Белгородская область, Чернянский район, поселок Чернянка, Революции, 22	f	large
31111	24264	1090	Белгородская область, Чернянский район, поселок Чернянка, Первомайская, 154	f	large
31109	24262	1088	Белгородская область, Чернянский район, поселок Чернянка, Крупская, 12	f	large
31107	24260	1086	Белгородская область, Чернянский район, поселок Чернянка, Кольцова, 38	f	large
31124	24277	1103	Белгородская область, Чернянский район, поселок Холки, Школьная, 10	f	small
31130	24283	1109	Белгородская область, Чернянский район, поселок Хитрово, Центральная, 24	t	small
31129	24282	1108	Белгородская область, Чернянский район, поселок Славянка, Центральная, 71	t	small
31145	24298	1124	Белгородская область, Чернянский район, поселок Русская Халань, Пятый Центральный переулок, 8	f	medium
31141	24294	1120	Белгородская область, Чернянский район, поселок Прилепы, им. Ивлева Д.Д, 5	f	small
31138	24291	1117	Белгородская область, Чернянский район, поселок Орлик, Центральная, 8	f	medium
31136	24289	1115	Белгородская область, Чернянский район, поселок Ольшанка, Школьная, 2	f	medium
31120	24273	1099	Белгородская область, Чернянский район, поселок Окуни, Центральная, 24	f	small
31134	24287	1113	Белгородская область, Чернянский район, поселок Огибное, Центральная, 76	f	small
31132	24285	1111	Белгородская область, Чернянский район, поселок Новоречье, Центральная, 61	f	small
31123	24276	1102	Белгородская область, Чернянский район, поселок Новая Масловка, Парковая, 14	f	small
31117	24270	1096	Белгородская область, Чернянский район, поселок Малый, Молодёжная, 2	t	small
31128	24281	1107	Белгородская область, Чернянский район, поселок Малотроицкое, Садовая, 16	f	medium
30513	23699	492	Белгородская область, Чернянский район, поселок Малиново, Здание сельского клуба	t	small
31127	24280	1106	Белгородская область, Чернянский район, поселок Лубяное 1-е, Школьная, 3	f	small
31126	24279	1105	Белгородская область, Чернянский район, поселок Лозное, Магистральная, 7	f	small
31133	24286	1112	Белгородская область, Чернянский район, поселок Ларисовка, Зеленая, 25	t	small
31146	24299	1125	Белгородская область, Чернянский район, поселок Красный Остров, Воровского, 45	f	medium
31125	24278	1104	Белгородская область, Чернянский район, поселок Кочегуры, Центральная, 37	f	medium
31139	24292	1118	Белгородская область, Чернянский район, поселок Комаревцево, Новая, 2	t	small
31142	24295	1121	Белгородская область, Чернянский район, поселок Ковылино, Центральная, 2	f	small
31137	24290	1116	Белгородская область, Чернянский район, поселок Захарово, Покровская, 2	f	small
31119	24272	1098	Белгородская область, Чернянский район, поселок Завалищено, Садовая, 1	f	small
31122	24275	1101	Белгородская область, Чернянский район, поселок Ездочное, Центральная, 16	f	large
31140	24293	1119	Белгородская область, Чернянский район, поселок Воскресеновка, Полевая, 4	t	small
31121	24274	1100	Белгородская область, Чернянский район, поселок Волотово, Центральная, 41	f	medium
31118	24271	1097	Белгородская область, Чернянский район, поселок Волоконовка, Покровская, 2	f	medium
30481	23666	460	Белгородская область, Чернянский район, поселок Волоконовка, Курочкина, 30	f	large
30483	23668	462	Белгородская область, Чернянский район, поселок Волоконовка, Коммунистическая, 2	f	large
31135	24288	1114	Белгородская область, Чернянский район, поселок Волково, Хуторская, 3	f	small
31144	24297	1123	Белгородская область, Чернянский район, поселок Водяное, Дачная, 25	t	small
31143	24296	1122	Белгородская область, Чернянский район, поселок Верхнее Кузькино, Центральная, 1	f	small
31116	24269	1095	Белгородская область, Чернянский район, поселок Бородин, Верхняя, 30	t	small
31115	24268	1094	Белгородская область, Чернянский район, поселок Большое, Красовка, 3	t	small
31131	24284	1110	Белгородская область, Чернянский район, поселок Баклановка, Центральная, 32	t	small
31114	24267	1093	Белгородская область, Чернянский район, поселок Александровка, Школьная, 5	t	small
31011	24177	990	Белгородская область, Старый Оскол городской округ, Старый Оскол, Ленина, 82, кооперативный техникум	f	medium
31001	24169	980	Белгородская область, Старый Оскол городской округ, Старый Оскол, Ватутина, 54, спорткомплекс ЗАО СОАТЭ	f	large
31076	24231	1055	Белгородская область, Старооскольский район, с.Верхнечуфичево, Центральная, 8, сельский клуб	f	small
31048	24207	1027	Белгородская область, Старооскольский район, микрорайон Королева, м-н Королева, 17, СОШ №30	f	large
31047	24207	1026	Белгородская область, Старооскольский район, микрорайон Королева, м-н Королева, 17, СОШ №30	f	large
31046	24207	1025	Белгородская область, Старооскольский район, микрорайон Королева, м-н Королева, 17, СОШ №30	f	large
31078	24233	1057	Белгородская область, Старооскольский район, поселок Шмарное, Центральная, 4, сельский клуб	f	small
31103	24256	1082	Белгородская область, Старооскольский район, поселок Шаталовка, Центральная, 38, сельский дом культуры	f	large
31089	24242	1068	Белгородская область, Старооскольский район, поселок Черниково, Мельничная, 44, сельский клуб	f	small
31090	24243	1069	Белгородская область, Старооскольский район, поселок Хорошилово, Центральная, 74	f	small
31101	24254	1080	Белгородская область, Старооскольский район, поселок Федосеевка, Натальи Лихачевой, 48, детская школа искусств	f	large
31100	24253	1079	Белгородская область, Старооскольский район, поселок Федосеевка, Натальи Лихачевой, 17, управление сельской территории	f	large
31083	24220	1062	Белгородская область, Старооскольский район, поселок Терехово, Парковая, 1, ДК	f	small
30982	24152	961	Белгородская область, Старооскольский район, Старый Оскол, Губкина, 103, СГА	f	small
31095	24248	1074	Белгородская область, Старооскольский район, поселок Роговатое, Ленина, 1, школа	f	medium
31096	24249	1075	Белгородская область, Старооскольский район, поселок Роговатое, Владимира Ленина, 1, школа	f	medium
31094	24247	1073	Белгородская область, Старооскольский район, поселок Роговатое, Владимира Ленина, 7, управление сельской территории	f	medium
31097	24250	1076	Белгородская область, Старооскольский район, поселок Преображенка, Центральная, 43, сельский клуб	t	small
31093	24246	1072	Белгородская область, Старооскольский район, поселок Потудань, Центральная, 6, дом культуры	f	small
31092	24245	1071	Белгородская область, Старооскольский район, поселок Песчанка, Заводская, 10, завод сухих кормовых дрожжей	f	medium
31088	24241	1067	Белгородская область, Старооскольский район, поселок Озерки, Парковая, 8, управление сельской территории	f	medium
31087	24240	1066	Белгородская область, Старооскольский район, поселок Обуховка, пер. Школьный, 2, школа	f	large
31085	24238	1064	Белгородская область, Старооскольский район, поселок Новокладовое, Городок, 47	f	small
30840	24013	819	Белгородская область, Старооскольский район, поселок Николаевка, сельский Дом культуры	f	medium
30472	23657	451	Белгородская область, Старооскольский район, поселок Николаевка, помещение средней школы	f	small
30471	23656	450	Белгородская область, Старооскольский район, поселок Николаевка, помещение сельского Дома культуры	f	medium
31086	24239	1065	Белгородская область, Старооскольский район, поселок Незнамово, Центральная, 3, дом культуры	f	large
31077	24232	1056	Белгородская область, Старооскольский район, поселок Монаково, Южная, 4, сельский дом культуры	f	large
31084	24056	1063	Белгородская область, Старооскольский район, поселок Лапыгино, Центральная, 101, школа	f	large
31073	24228	1052	Белгородская область, Старооскольский район, поселок Крутое, Центральная, 12, администрация	f	medium
31082	24237	1061	Белгородская область, Старооскольский район, поселок Котово, Котовская, 11, школа	f	medium
31102	24255	1081	Белгородская область, Старооскольский район, поселок Каплино, Московская, сельский клуб	f	medium
31080	24235	1059	Белгородская область, Старооскольский район, поселок Казачок, Центральная, 64, ДК	f	small
31081	24236	1060	Белгородская область, Старооскольский район, поселок Ивановка, Молодежная, 9, школа	f	medium
31079	24234	1058	Белгородская область, Старооскольский район, поселок Знаменка, Центральная, 27, дом культуры	f	medium
31075	24230	1054	Белгородская область, Старооскольский район, поселок Долгая Поляна, Центральная, 6, управление сельской территории	f	medium
31074	24229	1053	Белгородская область, Старооскольский район, поселок Дмитриевка, Садовая, 84, управление сельской территории	f	medium
31071	24226	1050	Белгородская область, Старооскольский район, поселок Городище, Гагарина, 3, дом культуры	f	large
30488	23673	467	Белгородская область, Волоконовский район, поселок Голофеевка	f	small
31069	24224	1048	Белгородская область, Старооскольский район, поселок Архангельское, Центральная, 35	f	medium
30607	23782	586	Белгородская область, Старооскольский район, поселок Архангельское, Центральная, 6	f	medium
30962	24136	941	Белгородская область, Ровеньский район, поселок Шияны	f	small
30967	24141	946	Белгородская область, Ровеньский район, поселок Харьковское, здание Харьковского Дома культуры	f	small
30966	24140	945	Белгородская область, Ровеньский район, поселок Свистовка, здание Свистовского Дома культуры	f	medium
30464	23649	443	Белгородская область, Ровеньский район, поселок Саловка, Помещение сельского клуба	f	small
30954	24127	933	Белгородская область, Ровеньский район, поселок Ровеньки, Шевченко, 8	f	large
30958	24132	937	Белгородская область, Ровеньский район, поселок Ровеньки, Чапаева, 13	f	medium
30959	24133	938	Белгородская область, Ровеньский район, поселок Ровеньки, Пролетарская, 41	f	large
30957	24131	936	Белгородская область, Ровеньский район, поселок Ровеньки, Московская, 29	f	large
30953	24126	932	Белгородская область, Ровеньский район, поселок Ровеньки, Ленина, 61	f	large
30956	24129	935	Белгородская область, Ровеньский район, поселок Ровеньки, Докучаева, 112	f	large
30955	24128	934	Белгородская область, Ровеньский район, поселок Ровеньки, Горького, 29 А	f	large
30963	24137	942	Белгородская область, Ровеньский район, поселок Ржевка, здание Администрации Ржевского сельского поселения	f	small
30938	24111	917	Белгородская область, Ровеньский район, поселок Пристень, здание Пристеньского Дома культуры	f	small
30444	23628	423	Белгородская область, Ровеньский район, поселок Пристень, здание Пристенского сельского Дома культуры	f	small
30951	24124	930	Белгородская область, Ровеньский район, поселок Новоалександровка, здание правления колхоза Советская Россия	f	medium
30940	24113	919	Белгородская область, Ровеньский район, поселок Нижняя Серебрянка, здание Нижнесеребрянского Дома культуры	f	small
30947	24120	926	Белгородская область, Ровеньский район, поселок Нагорье, здание Нагорьевской средней школы	f	medium
30945	24118	924	Белгородская область, Ровеньский район, поселок Нагольное, здание Наголенского Дома культуры	f	medium
30968	24142	947	Белгородская область, Ровеньский район, поселок Масловка	f	small
30965	24139	944	Белгородская область, Ровеньский район, поселок Мартынцы	f	small
30942	24115	921	Белгородская область, Ровеньский район, поселок Лозовое, здание Администрации Лозовского сельского поселения	f	small
30941	24114	920	Белгородская область, Ровеньский район, поселок Лозная, здание администрации Лознянского сельского поселения	f	medium
30960	24134	939	Белгородская область, Ровеньский район, поселок Лихолобов, здание Лихолобовской начальной школы	f	small
30943	24116	922	Белгородская область, Ровеньский район, поселок Ладомировка, здание Ладомировского Дома культуры	f	medium
30964	24138	943	Белгородская область, Ровеньский район, поселок Копанки, здание Копанского сельского клуба	f	small
30946	24119	925	Белгородская область, Ровеньский район, поселок Клименково	f	small
30952	24125	931	Белгородская область, Ровеньский район, поселок Калиниченково, здание Калиниченковсой начальной школы	f	small
30961	24135	940	Белгородская область, Ровеньский район, поселок Ивановка	f	small
30944	24117	923	Белгородская область, Ровеньский район, поселок Жабское, здание Жабского Дома культуры	f	small
30948	24121	927	Белгородская область, Ровеньский район, поселок Еремовка, здание Еремовского сельского клуба	f	small
30949	24122	928	Белгородская область, Ровеньский район, поселок Всесвятка, здание Всесвятского сельского клуба	f	small
30939	24112	918	Белгородская область, Ровеньский район, поселок Верхняя Серебрянка, Здание администрации Верхнесеребрянского сельского поселения	f	medium
30950	24123	929	Белгородская область, Ровеньский район, поселок Барсучье	f	small
30937	24110	916	Белгородская область, Ровеньский район, поселок Айдар, здание Айдарского Дома культуры	f	large
30936	24109	915	Белгородская область, Ракитянский район, Центральное, Совхозное, 5	f	medium
30925	24098	904	Белгородская область, Ракитянский район, поселок Трефиловка, Почтовая, 3	f	small
31098	24251	1077	Белгородская область, Ракитянский район, поселок Солдатское, Центральная, 12, управление сельской территории	f	large
83931	57347	3129	Москва, Зеленоград, к1017	f	large
30923	24096	902	Белгородская область, Ракитянский район, поселок Солдатское, Третьяковка, 23	f	medium
30919	24092	898	Белгородская область, Ракитянский район, поселок Святославка	t	small
30922	24095	901	Белгородская область, Ракитянский район, поселок Русская Березовка, Новостороевка, 13	f	small
30934	24107	913	Белгородская область, Ракитянский район, поселок Ракитное, Федутенко, 2	f	large
30932	24105	911	Белгородская область, Ракитянский район, поселок Ракитное, Пролетарская, 20Б	f	large
30933	24106	912	Белгородская область, Ракитянский район, поселок Ракитное, Новосадовая, 31	f	large
30931	24104	910	Белгородская область, Ракитянский район, поселок Ракитное, Коммунаров, 30А	f	large
30912	24085	891	Белгородская область, Ракитянский район, поселок Псковское, Центральная, 6А	f	small
30929	24102	908	Белгородская область, Ракитянский район, поселок Пролетарский, Пролетарская, 32	f	large
30928	24101	907	Белгородская область, Ракитянский район, поселок Пролетарский, Почтовый, 4А	f	large
30927	24100	906	Белгородская область, Ракитянский район, поселок Пролетарский, Ватутина, 2А	f	large
30920	24093	899	Белгородская область, Ракитянский район, поселок Нижние Пены	f	medium
30913	24086	892	Белгородская область, Ракитянский район, поселок Меловое, Центральная, 20	t	small
30926	24099	905	Белгородская область, Ракитянский район, поселок Лаптевка, Центральная, 131	t	small
30930	24103	909	Белгородская область, Ракитянский район, поселок Криничное, здание администрации производства	t	medium
30918	24091	897	Белгородская область, Ракитянский район, поселок Илек-Кошары, Советская, 25	f	medium
30917	24090	896	Белгородская область, Ракитянский район, поселок Зинаидино	f	medium
30916	24089	895	Белгородская область, Ракитянский район, поселок Дмитриевка, Шатилова, 9	f	small
30915	24088	894	Белгородская область, Ракитянский район, поселок Дмитриевка, Выгон, 78	f	medium
30921	24094	900	Белгородская область, Ракитянский район, поселок Вышние Пены, Центральная, 13	f	medium
30911	24084	890	Белгородская область, Ракитянский район, поселок Венгеровка, Центральная, 47А	f	medium
30924	24097	903	Белгородская область, Ракитянский район, поселок Введенская Готня, Гордеевка, 2	f	small
30935	24108	914	Белгородская область, Ракитянский район, поселок Васильевка, Ленина, 1В	f	small
30909	24082	888	Белгородская область, Ракитянский район, поселок Борисполье, Молодёжная, 2	f	small
30910	24083	889	Белгородская область, Ракитянский район, поселок Бобрава	f	large
30914	24087	893	Белгородская область, Ракитянский район, поселок Александровка, Центральная, 32	t	small
30908	24081	887	Белгородская область, Прохоровский район, поселок Шахово, Здание СДК	f	small
30907	24080	886	Белгородская область, Прохоровский район, поселок Холодное, Здание СДК	f	medium
30862	24034	841	Белгородская область, Прохоровский район, поселок Тетеревино	f	small
30865	95183	844	Белгородская область, Прохоровский район, поселок Средняя Ольшанка, помещение ФАПа	t	small
30805	23978	784	Белгородская область, Прохоровский район, поселок Сергиевка, Центральная, 2	f	medium
30618	23793	597	Белгородская область, Прохоровский район, поселок Сергиевка, Белгородская, 129	f	medium
30870	24042	849	Белгородская область, Прохоровский район, поселок Сеймица	t	small
30888	24061	867	Белгородская область, Прохоровский район, поселок Сагайдачное, Здание СДК	f	small
30904	24077	883	Белгородская область, Прохоровский район, поселок Ржавец, Здание СДК	f	small
30902	24075	881	Белгородская область, Прохоровский район, поселок Радьковка	f	medium
30901	24074	880	Белгородская область, Прохоровский район, поселок Радьковка, Здание конторы ИП Маматов	f	small
30893	24066	872	Белгородская область, Прохоровский район, поселок Прохоровка, переулок 1-й Советский, 1	f	large
30898	24071	877	Белгородская область, Прохоровский район, поселок Прохоровка, Советская, 256А	f	large
30897	24070	876	Белгородская область, Прохоровский район, поселок Прохоровка, Советская, 178	f	large
30894	24067	873	Белгородская область, Прохоровский район, поселок Прохоровка, Советская, 130	f	large
30896	24069	875	Белгородская область, Прохоровский район, поселок Прохоровка, Первомайская, 1	f	large
30899	24072	878	Белгородская область, Прохоровский район, поселок Прохоровка, Парковая, 48	f	large
30895	24068	874	Белгородская область, Прохоровский район, поселок Прохоровка, Мичурина, 38	f	large
30892	24065	871	Белгородская область, Прохоровский район, поселок Призначное, Здание СДК 	f	medium
30886	24059	865	Белгородская область, Прохоровский район, поселок Прелестное, Здание СДК	f	medium
30866	24038	845	Белгородская область, Прохоровский район, поселок Политотдельский, Здание Досугового центра	f	small
30299	23482	278	Белгородская область, Прохоровский район, поселок Политотдельский, Центральная, 1А	f	medium
30884	24057	863	Белгородская область, Прохоровский район, поселок Подольхи, Здание СДК	f	medium
30906	24079	885	Белгородская область, Прохоровский район, поселок Плющины, Здание Плющинского ФАПа	t	small
30881	24053	860	Белгородская область, Прохоровский район, поселок Плота, Здание СДК	f	small
30879	24051	858	Белгородская область, Прохоровский район, поселок Петровка, Здание СДК	t	small
30900	24073	879	Белгородская область, Прохоровский район, поселок Нижняя Гусынка, Здание магазина райпо	t	small
30876	24048	855	Белгородская область, Прохоровский район, поселок Масловка, Здание сельского клуба	f	small
30878	24050	857	Белгородская область, Прохоровский район, поселок Малые Маяки, Здание СДК	f	small
30880	24052	859	Белгородская область, Прохоровский район, поселок Малояблоново, Здание медпункта	f	small
30877	24049	856	Белгородская область, Прохоровский район, поселок Лучки	f	small
30874	24046	853	Белгородская область, Прохоровский район, поселок Кривые Балки, Здание сельского клуба	t	small
30875	24047	854	Белгородская область, Прохоровский район, поселок Кривошеевка, Здание СДК	f	small
30891	24064	870	Белгородская область, Прохоровский район, поселок Красное, Здание медпункта	t	small
30873	24045	852	Белгородская область, Прохоровский район, поселок Кондровка	f	small
30290	23473	269	Белгородская область, Прохоровский район, поселок Комсомольский, Гайдара, 1	f	large
30872	24044	851	Белгородская область, Прохоровский район, поселок Коломыцево	f	small
30887	24060	866	Белгородская область, Прохоровский район, поселок Карташевка, Здание СДК	f	small
30863	24035	842	Белгородская область, Прохоровский район, поселок Калинин, Здание медпункта	t	small
30903	24076	882	Белгородская область, Прохоровский район, село Казачье, Здание сельского клуба	t	small
30869	24041	848	Белгородская область, Прохоровский район, поселок Журавка 1-я, Здание Журавского СДК	f	medium
30871	24043	850	Белгородская область, Прохоровский район, поселок Донец, Здание Донецкого СДК	t	small
30890	24063	869	Белгородская область, Прохоровский район, поселок Гусек-Погореловка, Здание библиотеки	f	small
30883	24055	862	Белгородская область, Прохоровский район, поселок Гнездиловка, Здание СДК	t	small
30867	24039	846	Белгородская область, Прохоровский район, Вязовое, Здание Вязовского СДК	f	medium
30885	24058	864	Белгородская область, Прохоровский район, поселок Веселый, Здание сельского клуба	t	small
30868	24040	847	Белгородская область, Прохоровский район, поселок Верхняя Гусынка	t	small
30882	24054	861	Белгородская область, Прохоровский район, поселок Большой, Здание СДК	t	small
30889	24062	868	Белгородская область, Прохоровский район, поселок Бехтеевка	f	small
30864	24036	843	Белгородская область, Прохоровский район, поселок Береговое 1-е, Здание администрации с/п	f	medium
30861	24033	840	Белгородская область, Прохоровский район, поселок Беленихино	f	medium
30905	24078	884	Белгородская область, Прохоровский район, поселок Андреевка, Здание Андреевской ООШ	t	small
30857	24029	836	Белгородская область, Новооскольский район, поселок Ярское, сельский Дом культуры 	f	medium
30855	24027	834	Белгородская область, Новооскольский район, поселок Яковлевка, сельский Дом культуры	f	medium
30854	24026	833	Белгородская область, Новооскольский район, поселок Шараповка	f	medium
30853	24025	832	Белгородская область, Новооскольский район, поселок Тростенец, сельский Дом культуры	f	medium
30852	24024	831	Белгородская область, Новооскольский район, поселок Старая Безгинка, сельский Дом культуры	f	medium
30850	24022	829	Белгородская область, Новооскольский район, поселок Солонец Поляна	f	small
30825	23997	804	Белгородская область, Новооскольский район, поселок Слоновка, сельский Дом культуры	f	small
30832	24005	811	Белгородская область, Новооскольский район, поселок Скрынников, сельский клуб	t	small
30842	24014	821	Белгородская область, Новооскольский район, поселок Серебрянка, сельский клуб	t	small
30839	24012	818	Белгородская область, Новооскольский район, поселок Севальный, сельский клуб	f	small
30844	24016	823	Белгородская область, Новооскольский район, поселок Прибрежный, сельский Дом культуры	f	large
30827	24000	806	Белгородская область, Новооскольский район, поселок Полевой, сельский клуб	t	small
30836	24009	815	Белгородская область, Новооскольский район, поселок Покрово-Михайловка, адм. здание мехотряда ООО Михайловское	f	medium
30837	24010	816	Белгородская область, Новооскольский район, поселок Подвислое, медицинский пунк	f	small
30492	23677	471	Белгородская область, Новооскольский район, поселок Погромец, Здание сельского Дома культуры	f	medium
30845	24017	824	Белгородская область, Новооскольский район, поселок Песчанка, сельский клуб	t	small
30859	24031	838	Белгородская область, Новооскольский район, поселок Остаповка, сельская библиотека	f	small
30848	24020	827	Белгородская область, Новооскольский район, поселок Оскольское, сельский Дом культуры 	f	medium
30824	23996	803	Белгородская область, Новооскольский район, поселок Ольховатка, сельский Дом культуры	f	medium
30634	23809	613	Белгородская область, Новооскольский район, поселок Ольховатка, Александра Адонина, 10	f	small
30815	23987	794	Белгородская область, Новооскольский район, Новый Оскол, площадь Центральная, 6	f	large
30819	23991	798	Белгородская область, Новооскольский район, Новый Оскол, Сушкова, 28	f	large
30816	23988	795	Белгородская область, Новооскольский район, Новый Оскол, Оскольская, 7	f	large
30822	23994	801	Белгородская область, Новооскольский район, Новый Оскол, Ливенская, 94	f	large
30820	23992	799	Белгородская область, Новооскольский район, Новый Оскол, Ливенская, 132А	f	large
30817	23989	796	Белгородская область, Новооскольский район, Новый Оскол, Кооперативная, 12	f	large
30821	23993	800	Белгородская область, Новооскольский район, Новый Оскол, Дорожная, 1/1	f	large
30818	23990	797	Белгородская область, Новооскольский район, Новый Оскол, Авиационная, 1	f	large
30847	24019	826	Белгородская область, Новооскольский район, поселок Новая Безгинка, сельский Дом культуры	f	medium
30843	24015	822	Белгородская область, Новооскольский район, поселок Ниновка, сельский клуб	f	medium
30831	24004	810	Белгородская область, Новооскольский район, поселок Немцев, сельский Дом культуры	t	small
30834	24007	813	Белгородская область, Новооскольский район, поселок Малое Городище, сельский клуб	t	small
30841	23998	820	Белгородская область, Новооскольский район, поселок Макешкино, сельский Дом культуры	f	small
30411	23595	390	Курская область, Щигровский район, поселок Леоновка	f	small
30856	24028	835	Белгородская область, Новооскольский район, поселок Крюк	t	small
30846	24018	825	Белгородская область, Новооскольский район, поселок Косицыно, сельский клуб	f	small
30851	24023	830	Белгородская область, Новооскольский район, поселок Киселевка	t	small
30830	24003	809	Белгородская область, Новооскольский район, село Гринево, сельский Дом культуры	t	small
30849	24021	828	Белгородская область, Новооскольский район, поселок Голубино, сельский Дом культуры	f	medium
30838	24011	817	Белгородская область, Новооскольский район, поселок Глинное, сельский Дом культуры	f	small
30835	24008	814	Белгородская область, Новооскольский район, поселок Великомихайловка, сельский Дом культуры	f	large
30833	24006	812	Белгородская область, Новооскольский район, поселок Васильев Дол, сельский Дом культуры	f	medium
30860	24032	839	Белгородская область, Новооскольский район, поселок Борсук, сельский Дом культуры	f	small
30829	24002	808	Белгородская область, Новооскольский район, поселок Боровое, СДК	t	small
30828	24001	807	Белгородская область, Новооскольский район, поселок Большая Ивановка, сельский Дом культуры	f	medium
30826	23999	805	Белгородская область, Новооскольский район, поселок Богородское, сельский Дом культуры	f	medium
30858	24030	837	Белгородская область, Новооскольский район, поселок Богдановка	f	small
30468	23653	447	Ростовская область, Матвеево-Курганский район, хутор Колесников	f	small
30807	23980	786	Белгородская область, Краснояружский район, поселок Теребрено, Новостроевка, 38	f	small
30808	23981	787	Белгородская область, Краснояружский район, поселок Староселье, Подлесье, 4	t	small
30804	23977	783	Белгородская область, Краснояружский район, поселок Репяховка, Садовая, 1	f	medium
30806	23979	785	Белгородская область, Краснояружский район, поселок Отрадовский, здание сельского клуба досуга	t	small
30812	23984	791	Белгородская область, Краснояружский район, поселок Красная Яруга, Центральная, 79А	f	medium
30813	23985	792	Белгородская область, Краснояружский район, поселок Красная Яруга, Театральная, 1	f	large
30810	23982	789	Белгородская область, Краснояружский район, поселок Красная Яруга, Мира, 1	f	medium
30809	23922	788	Белгородская область, Краснояружский район, поселок Красная Яруга, Мира, 31	f	large
30814	23986	793	Белгородская область, Краснояружский район, поселок Красная Яруга, Крыловка, 8	f	medium
30811	23983	790	Белгородская область, Краснояружский район, поселок Красная Яруга, Парковая, 36	f	large
30802	23975	781	Белгородская область, Краснояружский район, поселок Колотиловка, Центральная, 36	f	small
30801	23974	780	Белгородская область, Краснояружский район, поселок Илек-Пеньковка, здание культурно-досугового центра	f	medium
30800	23973	779	Белгородская область, Краснояружский район, поселок Демидовка, Школьная, 1	f	small
30803	23976	782	Белгородская область, Краснояружский район, поселок Вязовское, здание Хуторского СДК	t	small
30798	23971	777	Кировская область, Юрьянский район, село Вязовое	f	medium
30761	23936	740	Белгородская область, Красногвардейский район, поселок Хуторцы, Горького, 9	f	small
30794	23967	773	Белгородская область, Красногвардейский район, поселок Уточка, Советская, 13	f	small
30797	23970	776	Белгородская область, Красногвардейский район, поселок Ураково, Садовая, 1	t	small
30789	23963	768	Белгородская область, Красногвардейский район, поселок Стрелецкое, Победы, 16	f	medium
30750	23925	729	Белгородская область, Красногвардейский район, поселок Сорокино, пер. Первомайский, 1	f	medium
31099	24252	1078	Белгородская область, Красногвардейский район, поселок Сорокино, Центральная, 8	f	medium
30781	23955	760	Белгородская область, Красногвардейский район, поселок Самарино, Октябрьская, 58	f	medium
30743	23917	722	Белгородская область, Красногвардейский район, поселок Садки, Лесная, 25	f	small
30792	23965	771	Белгородская область, Красногвардейский район, поселок Репенка, Подлесная, 10	f	small
30759	23934	738	Белгородская область, Красногвардейский район, поселок Раздорное, Школьная, 7 А	f	medium
30748	23923	727	Белгородская область, Красногвардейский район, поселок Прудки, Коммунистичесая, 1В	f	small
30793	23966	772	Белгородская область, Красногвардейский район, поселок Прилепы, Мира, 1	f	small
30768	23943	747	Белгородская область, Красногвардейский район, поселок Попасное, Гагарина, 23 А	t	small
30796	23969	775	Белгородская область, Красногвардейский район, поселок Плюхино, Заречная, 12	f	small
30747	23921	726	Белгородская область, Красногвардейский район, поселок Петров, Цветочная, 36Б	t	small
30785	23959	764	Белгородская область, Красногвардейский район, поселок Палатово, Набережная, 4	f	medium
30769	23944	748	Белгородская область, Красногвардейский район, поселок Палатовка 2-я, Чапаева, 54	t	small
30753	23928	732	Белгородская область, Красногвардейский район, поселок Остроухово, Октябрьская, 6А	t	small
30783	23957	762	Белгородская область, Красногвардейский район, поселок Новохуторное, Молодежная, 69 Г	f	small
30757	23932	736	Белгородская область, Красногвардейский район, поселок Николаевский, Народная, 34	f	small
30780	23954	759	Белгородская область, Красногвардейский район, поселок Никитовка, Калинина, 23	f	medium
30779	23953	758	Белгородская область, Красногвардейский район, поселок Никитовка, 1 Мая, 15А	f	large
30749	23924	728	Белгородская область, Красногвардейский район, село Нижняя Покровка, Мирная, 93Б	f	small
30791	23964	770	Белгородская область, Красногвардейский район, поселок Марьевка, Моледежная, 2	f	small
30788	23962	767	Белгородская область, Красногвардейский район, поселок Малобыково, Пушкарная, 7	t	medium
30777	23951	756	Белгородская область, Красногвардейский район, поселок Ливенка, Учительская, 1	f	medium
30775	23949	754	Белгородская область, Красногвардейский район, поселок Ливенка, Транспортная, 9	f	large
30778	23952	757	Белгородская область, Красногвардейский район, поселок Ливенка, Советская, 62	f	medium
30776	23950	755	Белгородская область, Красногвардейский район, поселок Ливенка, Советская, 15	f	medium
30786	23960	765	Белгородская область, Красногвардейский район, поселок Лазареново, Московская, 2	t	small
30745	23919	724	Белгородская область, Красногвардейский район, поселок Кулешовка, Молодежная, 83	t	small
30758	23933	737	Белгородская область, Красногвардейский район, поселок Красное, Пролетарская, 79	t	small
30770	23945	749	Белгородская область, Красногвардейский район, поселок Коломыцево, Советская, 7	f	small
30774	23948	753	Белгородская область, Красногвардейский район, поселок Ковалев, Пушкина, 4	f	small
30767	23942	746	Белгородская область, Красногвардейский район, поселок Калиново, Мира, 49А	f	small
30787	23961	766	Белгородская область, Красногвардейский район, поселок Казацкое, Ленина, 31	f	large
30765	23940	744	Белгородская область, Красногвардейский район, поселок Засосна, имени Чапаева, 67	f	medium
30762	23937	741	Белгородская область, Красногвардейский район, поселок Засосна, Пролетарская, 53 Б	f	medium
30763	23938	742	Белгородская область, Красногвардейский район, поселок Засосна, Ленина, 111 А/1	f	medium
30764	23939	743	Белгородская область, Красногвардейский район, поселок Засосна, 60 лет Октября, 2А	f	large
30752	23927	731	Белгородская область, Красногвардейский район, поселок Завальское, Садовая, 99	t	small
30766	23941	745	Белгородская область, Красногвардейский район, поселок Ендовицкое, Народная, 47 В	f	small
30760	23935	739	Белгородская область, Красногвардейский район, поселок Гредякино, Трудовая, 105А	f	small
30784	23958	763	Белгородская область, Красногвардейский район, поселок Горовое, Мира, 31В	f	small
30754	23929	733	Белгородская область, Красногвардейский район, поселок Веселое, Свободы, 102А	t	medium
30755	23930	734	Белгородская область, Красногвардейский район, поселок Веселое, Мира, 186А	f	medium
30756	23931	735	Белгородская область, Красногвардейский район, поселок Веселое, Куйбышева, 118 А	f	small
30751	23926	730	Белгородская область, Красногвардейский район, поселок Верхососна, Центральная, 17	f	medium
30746	23920	725	Белгородская область, Красногвардейский район, поселок Верхняя Покровка, Советская, 148А	f	medium
30744	23918	723	Белгородская область, Красногвардейский район, поселок Валуйчик, Черняховского, 6	f	medium
30773	23947	752	Белгородская область, Красногвардейский район, поселок Валуй, Железнодорожная, 4	t	small
30795	23968	774	Белгородская область, Красногвардейский район, поселок Большое Быково, Центральная, 36	f	medium
30742	23916	721	Белгородская область, Красногвардейский район, поселок Бирюч	f	medium
30398	23582	377	Белгородская область, Красногвардейский район, поселок Бирюч, здание Бирючанского сельского Дома культуры	f	small
30740	23914	719	Белгородская область, Красногвардейский район, поселок Бирюч, имени Ольминского, 24	f	large
30741	23915	720	Белгородская область, Красногвардейский район, поселок Бирюч, Ямская, 154	f	medium
30737	23911	716	Белгородская область, Красногвардейский район, поселок Бирюч, Соборная площадь, 3	f	large
30772	23946	751	Белгородская область, Красногвардейский район, поселок Бирюч, Привокзальная, 8	f	small
30782	23956	761	Белгородская область, Красногвардейский район, поселок Арнаутово, Заречная, 56	f	small
30732	23906	711	Белгородская область, Красненский район, поселок Широкое, помещение дома культуры	t	small
30735	23909	714	Белгородская область, Красненский район, поселок Черемухово, помещение Дома досуга	t	small
30734	23908	713	Белгородская область, Красненский район, поселок Хмелевое, помещение Дома культуры	f	small
30731	23905	710	Белгородская область, Красненский район, поселок Флюговка, помещение сельского клуба	t	small
30720	23894	699	Белгородская область, Красненский район, поселок Ураково, помещение Дома культуры	f	small
30730	23904	709	Белгородская область, Красненский район, поселок Староуколово, помещение Дома досуга	t	small
30736	23910	715	Белгородская область, Красненский район, поселок Сетище, помещение Дома культуры	f	medium
83930	57347	3128	Москва, Зеленоград, к1017	f	large
30723	23897	702	Белгородская область, Красненский район, поселок Свистовка, помещение сельского клуба	t	small
30733	23907	712	Белгородская область, Красненский район, поселок Расховец	f	medium
30722	23896	701	Белгородская область, Красненский район, поселок Польниково, помещение сельского клуба	t	small
30728	23902	707	Белгородская область, Красненский район, поселок Новоуколово, помещение Дома культуры	f	large
30726	23900	705	Белгородская область, Красненский район, поселок Новосолдатка, помещение Дома досуга	t	small
30727	23901	706	Белгородская область, Красненский район, поселок Лесное-Уколово, помещение Дома культуры	f	medium
30724	23898	703	Белгородская область, Красненский район, поселок Круглое, помещение Дома культуры	f	medium
30721	23895	700	Белгородская область, Красненский район, поселок Красное, помещение районного Дворца культуры 	f	large
30718	23892	697	Белгородская область, Красненский район, поселок Камышенка, помещение Дома досуга	t	small
30719	23893	698	Белгородская область, Красненский район, поселок Камызино, помещение Дома культуры	f	medium
30729	23903	708	Белгородская область, Красненский район, поселок Каменка, помещение сельского клуба	t	small
30725	23899	704	Белгородская область, Красненский район, поселок Заломное, помещение Дома досуга	f	small
30717	23891	696	Белгородская область, Красненский район, поселок Готовье, помещение администрации готовского с/п	f	medium
30715	23889	694	Белгородская область, Красненский район, поселок Горки, помещение Дома культуры	f	medium
30714	23888	693	Белгородская область, Красненский район, поселок Большое, помещение Дома культуры	f	small
30716	23890	695	Белгородская область, Красненский район, поселок Богословка, помещение сельского клуба	t	small
30712	23886	691	Белгородская область, Корочанский район, поселок Яблоново, Центральная, 36	f	large
30711	23885	690	Белгородская область, Корочанский район, поселок Шляхово, Административная, 35	f	small
30709	23883	688	Белгородская область, Корочанский район, поселок Шеино, Школьная, 29	f	medium
30686	23861	665	Белгородская область, Корочанский район, поселок Хмелевое, Интернациональная, 8	f	small
30708	23882	687	Белгородская область, Корочанский район, поселок Фощеватое, Центральная, 13	f	small
30707	23881	686	Белгородская область, Корочанский район, поселок Соколовка, Зеленая, 2	f	medium
30680	23855	659	Белгородская область, Корочанский район, поселок Сетное, Центральная, 20	f	small
30696	23871	675	Белгородская область, Корочанский район, поселок Самойловка, Самойловская, 27	f	small
30705	23879	684	Белгородская область, Корочанский район, поселок Проходное, Центральная, 90	f	medium
30703	23877	682	Белгородская область, Корочанский район, поселок Поповка, Бельгия, 2	f	large
30702	23876	681	Белгородская область, Корочанский район, поселок Погореловка, Шевченко, 40	f	large
30701	23875	680	Белгородская область, Корочанский район, поселок Погореловка, Центральная, 16/А	f	large
30700	23874	679	Белгородская область, Корочанский район, поселок Плотавец, Центральная, 5	f	small
30697	23872	676	Белгородская область, Корочанский район, поселок Плоское, Центральная, 80	f	small
30691	23866	670	Белгородская область, Корочанский район, поселок Пестуново, Садовая, 3	f	small
30695	23870	674	Белгородская область, Корочанский район, поселок Новая Слободка, Сытник, 28	f	medium
30679	23854	658	Белгородская область, Корочанский район, поселок Нечаево, Центральная, 16	f	small
30694	23869	673	Белгородская область, Корочанский район, поселок Мелихово, Центральная, 6	f	medium
30677	23852	656	Белгородская область, Корочанский район, поселок Мальцевка, Центральная, 14	f	small
30710	23884	689	Белгородская область, Корочанский район, поселок Мазикино, Лисовенька, 6	f	small
30692	23867	671	Белгородская область, Корочанский район, поселок Ломово, Мозгового, 8	f	large
30690	23865	669	Белгородская область, Корочанский район, поселок Кощеево, Центральная, 17	f	medium
30673	23848	652	Белгородская область, Корочанский район, Короча, площадь Васильева, 30	f	medium
30671	23846	650	Белгородская область, Корочанский район, Короча, Советская, 18	f	large
30672	23847	651	Белгородская область, Корочанский район, Короча, Пролетарская, 26	f	large
30670	23845	649	Белгородская область, Корочанский район, Короча, Пролетарская, 39	f	large
30689	23864	668	Белгородская область, Корочанский район, поселок Короткое, Центральная, 3	f	medium
30683	23858	662	Белгородская область, Корочанский район, поселок Клиновец, Кожанова, 27	f	small
30706	23880	685	Белгородская область, Корочанский район, поселок Ивица, Центральная, 42	f	small
30688	23863	667	Белгородская область, Корочанский район, поселок Заячье, Выгон, 56	f	medium
30687	23862	666	Белгородская область, Корочанский район, поселок Жигайловка, Базарная, 42	f	medium
30693	23868	672	Белгородская область, Корочанский район, село Дальняя Игуменка, Центральная, 78	t	medium
30704	23878	683	Белгородская область, Корочанский район, поселок Городище, Вершина, 71	t	small
30685	23860	664	Белгородская область, Корочанский район, поселок Бубново, Маркашовой А.И, 17	f	small
30713	23887	692	Белгородская область, Корочанский район, поселок Большое Песчаное, Песчаная, 20	f	small
30684	23859	663	Белгородская область, Корочанский район, поселок Большая Халань, Базарная, 39	f	medium
30682	23857	661	Белгородская область, Корочанский район, поселок Бехтеевка, Ленина, 130/1	f	large
30681	23856	660	Белгородская область, Корочанский район, поселок Бехтеевка, Ленина, 126	f	large
30699	23873	678	Белгородская область, Корочанский район, поселок Белый Колодец, Выгон, 5	t	small
30678	23853	657	Белгородская область, Корочанский район, поселок Афанасово, Центральная, 1	f	medium
30676	23851	655	Белгородская область, Корочанский район, поселок Анновка, Центральная, 2	f	medium
30675	23850	654	Белгородская область, Корочанский район, поселок Алексеевка, Мирошникова, 1/в	f	small
30674	23849	653	Белгородская область, Корочанский район, поселок Алексеевка, Богомазова, 1/А	f	large
30663	23838	642	Белгородская область, Ивнянский район, поселок Череново	f	small
30669	23844	648	Белгородская область, Ивнянский район, поселок Хомутцы, здание сельского Дома культуры	f	medium
30658	23833	637	Белгородская область, Ивнянский район, поселок Федчевка, здание сельского Дома культуры	f	small
30667	23842	646	Белгородская область, Ивнянский район, поселок Сырцево	f	small
30666	23841	645	Белгородская область, Ивнянский район, поселок Сухосолотино, здание сельского Дома культуры	f	small
30665	23840	644	Белгородская область, Ивнянский район, поселок Сафоновка, здание фельдшерско-акушерского пункта	f	medium
30664	23839	643	Белгородская область, Ивнянский район, поселок Покровка, здание культурно-спортивного комплекса	f	medium
30495	23681	474	Белгородская область, Ивнянский район, поселок Покровка, Здание сельского Дома культуры	f	large
30662	23837	641	Белгородская область, Ивнянский район, поселок Песчаное, здание сельского Дома культуры	f	medium
30661	23836	640	Белгородская область, Ивнянский район, поселок Новенькое, здание сельского Дома культуры	f	large
30660	23835	639	Белгородская область, Ивнянский район, поселок Курасовка	f	large
30659	23834	638	Белгородская область, Ивнянский район, поселок Кочетовка, здание сельского Дома культуры	f	medium
30657	23832	636	Белгородская область, Ивнянский район, поселок Кировский, здание сельского клуба	t	small
30654	23829	633	Белгородская область, Ивнянский район, поселок Ивня, Советская, 42	f	large
30656	23831	635	Белгородская область, Ивнянский район, поселок Ивня, Садовая, 5А	f	large
30653	23828	632	Белгородская область, Ивнянский район, поселок Ивня, Ленина, 20	f	large
30655	23830	634	Белгородская область, Ивнянский район, поселок Ивня, Заречная, 17А	f	large
30652	23827	631	Белгородская область, Ивнянский район, поселок Драгунка	f	small
30651	23826	630	Белгородская область, Ивнянский район, поселок Вознесеновка, здание школы	f	medium
30650	23825	629	Белгородская область, Ивнянский район, поселок Владимировка, здание школы	f	medium
30649	23824	628	Белгородская область, Ивнянский район, поселок Верхопенье	f	medium
30648	23823	627	Белгородская область, Ивнянский район, поселок Верхопенье, здание сельского Дома культуры	f	large
30647	23822	626	Белгородская область, Ивнянский район, поселок Богатое, здание сельского клуба	f	medium
30668	23843	647	Белгородская область, Ивнянский район, поселок Березовка, здание сельского клуба	f	small
30626	23801	605	Белгородская область, Губкинский район, поселок Юшково, Троицкая, 57	f	small
111566	57346	3127	Москва, Зеленоград, к1016	f	medium
30646	23821	625	Белгородская область, Губкинский район, поселок Юрьевка, Мира, 6	f	small
30632	23807	611	Белгородская область, Губкинский район, поселок Чуево, Центральная, 41	f	medium
30612	23787	591	Белгородская область, Губкинский район, поселок Чапкино, Садовая, 4	f	small
30619	23794	598	Самарская область, Хворостянский район, село Хворостянка	f	medium
30497	23683	476	Белгородская область, Губкинский район, поселок Успенка, Здание сельского Дома культуры	t	small
30621	23796	600	Белгородская область, Губкинский район, поселок Успенка, Заречная, 32	f	small
30631	23806	610	Белгородская область, Губкинский район, поселок Уколово, Центральная, 13	f	small
30598	23775	577	Белгородская область, Губкинский район, поселок Троицкий, Центральная, 9	f	large
30597	23774	576	Белгородская область, Губкинский район, поселок Троицкий, Центральная, 11	f	large
30599	23774	578	Белгородская область, Губкинский район, поселок Троицкий, Центральная, 11	f	medium
30640	23815	619	Белгородская область, Губкинский район, поселок Толстое, Центральная, 46	f	medium
30602	23778	581	Белгородская область, Губкинский район, поселок Теплый Колодезь, Центральная, 4	f	medium
30638	23813	617	Белгородская область, Губкинский район, поселок Телешовка, Григория Найдина, 68	f	small
30611	23786	590	Белгородская область, Губкинский район, поселок Строкино, Ракитная, 1	f	small
30645	23820	624	Белгородская область, Губкинский район, поселок Степное, Народная, 1	f	small
30625	23800	604	Белгородская область, Губкинский район, поселок Солнцево, Медовая, 1	f	small
30635	23810	614	Белгородская область, Губкинский район, поселок Скородное, Красноармейская, 1	f	medium
30637	23812	616	Белгородская область, Губкинский район, поселок Скородное, 1 Мая, 39	f	medium
30636	23811	615	Белгородская область, Губкинский район, поселок Скородное, 1 Мая, 26	f	large
30620	23795	599	Белгородская область, Губкинский район, поселок Сапрыкино, Центральная, 49	f	medium
30617	23792	596	Белгородская область, Губкинский район, поселок Присынки, Светлая, 13	f	small
30615	23790	594	Белгородская область, Губкинский район, поселок Петровки, Юбилейная, 8	f	small
30606	23781	585	Белгородская область, Губкинский район, поселок Осколец, Центральная, 9	f	small
30633	23808	612	Белгородская область, Губкинский район, поселок Новоселовка, Производственный участок №1 ЗАЧуевское поле, зал заседаний	f	small
30628	23803	607	Белгородская область, Губкинский район, поселок Никаноровка, Владимира Уколова, 3	f	medium
30630	23805	609	Белгородская область, Губкинский район, поселок Морозово, Сиреневая, 8	f	small
30627	23802	606	Белгородская область, Губкинский район, поселок Мелавое, Школьная, 6	f	small
30639	23814	618	Белгородская область, Губкинский район, поселок Корочка, Троицкая, 77	f	small
30644	23819	623	Белгородская область, Губкинский район, поселок Коньшино, Тихая, 2	f	medium
30624	23799	603	Белгородская область, Губкинский район, поселок Кладовое, Народная, 10	f	small
30629	23804	608	Белгородская область, Губкинский район, поселок Калинин, Мира, 1а	f	small
30600	23776	579	Белгородская область, Губкинский район, поселок Казацкая Степь, Школьная, 2	f	small
30642	23817	621	Белгородская область, Губкинский район, поселок Истобное, Центральная, 1	f	medium
30643	23818	622	Белгородская область, Губкинский район, поселок Истобное, Солнечная, 3	f	small
30616	23791	595	Белгородская область, Губкинский район, поселок Заповедный, Центральная, 14	f	small
30614	23789	593	Белгородская область, Губкинский район, поселок Заломное, Урожайная, 27	f	small
30458	23643	437	Архангельская область, Приморский район, село Долгое	f	medium
30416	23600	395	Псковская область, Бежаницкий район, село Долгое	f	small
30609	23784	588	Белгородская область, Губкинский район, поселок Гущино, Железнодорожная, 34	f	small
30610	23785	589	Белгородская область, Губкинский район, поселок Вислая Дубрава, Каштановая, 3	f	small
30623	23798	602	Белгородская область, Губкинский район, поселок Богородицкое, Центральная, 5	f	small
30622	23797	601	Белгородская область, Губкинский район, поселок Бобровы Дворы, Белгородская, 91	f	medium
30608	23783	587	Белгородская область, Губкинский район, поселок Архангельское, Мичурина, 3	f	small
30603	23779	582	Белгородская область, Губкинский район, поселок Аверино, Центральная, 27	f	medium
30604	23779	583	Белгородская область, Губкинский район, поселок Аверино, Центральная, 27	f	small
30592	23769	571	Белгородская область, Губкин городской округ, поселок Лебеди, Павлика Морозова, 2	f	medium
30605	23780	584	Белгородская область, Губкин городской округ, поселок Зареченка, Заречная , 40А	f	small
30527	23712	506	Белгородская область, Грайворонский район, поселок Хотмыжск, ООО Хотмыжское ХПП	f	small
30536	23721	515	Белгородская область, Грайворонский район, поселок Санково, Санковский сельский клуб	f	small
30424	23608	403	Белгородская область, Грайворонский район, поселок Подгорное, здание Подгоренского сельского Дома культуры	f	medium
30548	23733	527	Белгородская область, Грайворонский район, поселок Новостроевка 1-я, Ремесленно промысловый двор	f	small
30538	23723	517	Белгородская область, Грайворонский район, поселок Мощеное, Мощенская начальная школа	f	small
30546	23731	525	Белгородская область, Грайворонский район, поселок Мокрая Орловка, М-Орловская средняя школа	f	small
30545	23730	524	Белгородская область, Грайворонский район, поселок Мокрая Орловка, М-Орловский СМДК	f	small
30520	23705	499	Белгородская область, Грайворонский район, поселок Луговка	f	small
30541	23726	520	Белгородская область, Грайворонский район, поселок Ломное, Ломненский сельский клуб	t	small
30543	23728	522	Белгородская область, Грайворонский район, поселок Косилово, Косиловский сельский ДК	f	medium
30544	23729	523	Белгородская область, Грайворонский район, поселок Козинка, Козинский СМДК	f	large
30542	23727	521	Белгородская область, Грайворонский район, поселок Казачья Лисица, Казачье Лисичанский сельский клуб	f	small
30540	23725	519	Белгородская область, Грайворонский район, поселок Ивановская Лисица, И-Лисичанскай сельский ДК	f	medium
30537	23722	516	Белгородская область, Грайворонский район, поселок Дунайка, Дунайский СМДК	f	small
30550	23735	529	Белгородская область, Грайворонский район, поселок Дроновка, Дроновский сельский клуб	t	small
30535	23720	514	Белгородская область, Грайворонский район, поселок Дорогощь, Дорогощанский СМДК	f	medium
30534	23719	513	Белгородская область, Грайворонский район, поселок Добро-Ивановка, Замостянская ОШ	f	medium
30533	23718	512	Белгородская область, Грайворонский район, поселок Добро-Ивановка, Добросельский СМДК	f	medium
30532	23717	511	Белгородская область, Грайворонский район, поселок Добро-Ивановка, Доброивановский сельский клуб	f	small
30530	23715	509	Белгородская область, Грайворонский район, Грайворон, Гора Подольская средняя школа	f	large
30518	23704	497	Белгородская область, Грайворонский район, Грайворон, Средняя школа им.Шухова	f	large
30519	23704	498	Белгородская область, Грайворонский район, Грайворон, Средняя школа им.Шухова	f	large
30517	23703	496	Белгородская область, Грайворонский район, Грайворон, ОГУЗ Детский санаторий г.Грайворон	f	large
30516	23702	495	Белгородская область, Грайворонский район, Грайворон, Грайворонская средняя школа с УИОП	f	large
30529	23714	508	Белгородская область, Грайворонский район, Горьковское сельское поселение, Чапаевская начальная школа	f	small
30528	23713	507	Белгородская область, Грайворонский район, поселок Горьковский, Горьковская средняя школа	f	small
30531	23716	510	Белгородская область, Грайворонский район, Гора-Подольское сельское поселение, Глотовский сельский клуб	f	medium
30526	23711	505	Белгородская область, Грайворонский район, поселок Головчино, Головчинская начальная школа	f	large
30525	23710	504	Белгородская область, Грайворонский район, поселок Головчино, Головчинская школа с УИОП	f	medium
30524	23709	503	Белгородская область, Грайворонский район, поселок Головчино, Головчинская библиотека	f	medium
30522	23707	501	Белгородская область, Грайворонский район, поселок Головчино, Антоновский СМДК	f	large
30521	23706	500	Белгородская область, Грайворонский район, поселок Безымено, Безыменский СМДК	f	medium
30552	23708	531	Белгородская область, Грайворонский район, поселок Антоновка, Антоновская ОШ	f	large
30523	23708	502	Белгородская область, Грайворонский район, поселок Антоновка, Антоновская ОШ	f	large
30511	23697	490	Белгородская область, Волоконовский район, поселок Ютановка, Здание сельского Дома культуры	f	medium
30510	23696	489	Белгородская область, Волоконовский район, поселок Шидловка, Здание сельского Дома культуры	f	medium
30501	23687	480	Белгородская область, Волоконовский район, поселок Шеншиновка, Здание сельского клуба	t	small
30507	23693	486	Брянская область, Рогнединский район, поселок Шаховка	f	small
30512	23698	491	Белгородская область, Волоконовский район, поселок Чапельное	t	small
30509	23695	488	Белгородская область, Волоконовский район, поселок Фощеватово, Здание сельского клуба	f	small
30508	23694	487	Белгородская область, Волоконовский район, поселок Фощеватово, Здание администрации сельского поселения	f	medium
30506	23692	485	Белгородская область, Волоконовский район, поселок Тишанка, Здание сельского Дома культуры	f	medium
30502	23688	481	Белгородская область, Волоконовский район, поселок Староивановка, Здание администрации сельского поселения	f	medium
30500	23686	479	Белгородская область, Волоконовский район, поселок Репьевка, Здание сельского Дома культуры	f	small
30499	23685	478	Белгородская область, Волоконовский район, поселок Пятницкое, проспект Маресевой, 16	f	large
30498	23684	477	Белгородская область, Волоконовский район, поселок Пятницкое, проспект Маресевой, 14	f	large
30491	23676	470	Белгородская область, Волоконовский район, поселок Осколище, Здание сельского клуба	f	medium
30503	23689	482	Белгородская область, Волоконовский район, поселок Новорождественка	f	small
30515	23701	494	Белгородская область, Волоконовский район, поселок Нижние Лубянки, Здание сельского клуба	f	medium
30496	23682	475	Белгородская область, Волоконовский район, поселок Лазурное, Здание сельского клуба	t	small
30504	23690	483	Белгородская область, Волоконовский район, поселок Коровино, Здание сельского клуба	f	small
30494	23680	473	Белгородская область, Волоконовский район, поселок Коновалово, Здание сельского клуба 	f	small
30493	23679	472	Белгородская область, Волоконовский район, поселок Давыдкин, Здание фельдшерско-акушерского пункта 	t	small
30490	23675	469	Калининградская область, Правдинский район, село Грушевка	f	medium
30487	23672	466	Белгородская область, Волоконовский район, поселок Волчья Александровка, Здание бывшего селького библиотечного филиала	f	small
30486	23671	465	Белгородская область, Волоконовский район, поселок Волчья Александровка, Здание администрации сельского поселения	f	medium
30485	23670	464	Белгородская область, Волоконовский район, поселок Волоконовка, Чехова, 1	f	large
30479	23664	458	Белгородская область, Волоконовский район, поселок Волоконовка, Пионерская, 20	f	large
30480	23665	459	Белгородская область, Волоконовский район, поселок Волоконовка, Ленина, 18 А	f	large
30484	23669	463	Белгородская область, Волоконовский район, поселок Волоконовка, Гагарина, 55	f	large
30482	23667	461	Белгородская область, Волоконовский район, поселок Волоконовка, 60 лет Октября, 147	f	large
31070	24225	1049	Белгородская область, Волоконовский район, поселок Владимировка, Школьная, 19, дом культуры	f	medium
30489	23674	468	Белгородская область, Волоконовский район, поселок Ветчининово	t	small
30514	23700	493	Белгородская область, Волоконовский район, поселок Верхние Лубянки	t	small
30505	23691	484	Белгородская область, Волоконовский район, поселок Афоньевка, Здание сельского Дома культуры	t	small
30476	23661	455	Республика Бурятия, Иволгинский район, село Солонцы	f	small
30459	23644	438	Белгородская область, Вейделевский район, поселок Ромахово	f	small
30475	23660	454	Белгородская область, Вейделевский район, поселок Ровны, помещение основной школы	f	small
30477	23662	456	Белгородская область, Вейделевский район, поселок Попов, помещение сельского клуба	t	small
30474	23659	453	Белгородская область, Вейделевский район, поселок Попасный, помещение сельского клуба	t	small
30457	23641	436	Белгородская область, Вейделевский район, поселок Опытный, помещение сельского клуба	t	small
30456	23640	435	Белгородская область, Вейделевский район, поселок Олейники, помещение сельского клуба	t	small
30473	23658	452	Белгородская область, Вейделевский район, поселок Ногин, помещение сельского клуба	f	small
30469	23654	448	Белгородская область, Вейделевский район, поселок Малакеево	f	medium
83929	57345	3126	Москва, Зеленоград, к1016	f	large
30466	23651	445	Белгородская область, Вейделевский район, поселок Кубраки	f	small
30465	23650	444	Белгородская область, Вейделевский район, поселок Клименки, помещение сельского Дома культуры	f	medium
30463	23648	442	Белгородская область, Вейделевский район, поселок Зенино, Здание сельского Дома культуры	f	medium
30461	23646	440	Белгородская область, Вейделевский район, поселок Закутское, Здание Дома культуры	f	medium
30470	23655	449	Белгородская область, Вейделевский район, поселок Дегтярное, помещение сельского Дома культуры	f	medium
30455	23639	434	Белгородская область, Вейделевский район, поселок Викторополь, помещение сельского Дома культуры	f	medium
30451	23635	430	Белгородская область, Вейделевский район, поселок Вейделевка, Центральная, 30	f	medium
30452	23636	431	Белгородская область, Вейделевский район, поселок Вейделевка, Пролетарская, 32а	f	medium
30453	23637	432	Белгородская область, Вейделевский район, поселок Вейделевка, Октябрьская, 34	f	small
30447	23631	426	Белгородская область, Вейделевский район, поселок Вейделевка, Мира, 83	f	medium
30450	23634	429	Белгородская область, Вейделевский район, поселок Вейделевка, Комсомольская, 17	f	medium
30449	23633	428	Белгородская область, Вейделевский район, поселок Вейделевка, Гайдара, 22А	f	large
30448	23632	427	Белгородская область, Вейделевский район, поселок Вейделевка, Гайдара, 1	f	medium
30462	23647	441	Белгородская область, Вейделевский район, поселок Брянские Липяги, помещение сельского клуба	t	small
30446	23630	425	Белгородская область, Вейделевский район, поселок Большие Липяги, помещение сельского Дома культуры	f	medium
30460	23645	439	Белгородская область, Вейделевский район, поселок Белый Плес	t	small
30467	23652	446	Белгородская область, Вейделевский район, поселок Банкино	t	small
30432	23616	411	Белгородская область, Валуйский район, поселок Шушпаново, здание Шушпановского сельского Дома культуры	t	small
30438	23622	417	Белгородская область, Валуйский район, поселок Шелаево, здание Шелаевского сельского Дома культуры	f	large
30443	23627	422	Рязанская область, Рязань, поселок Храпово	f	small
30427	23611	406	Белгородская область, Белгородский район, поселок Хохлово	t	small
30437	23621	416	Белгородская область, Валуйский район, поселок Хмелевец, здание Хмелевского сельского Дома культуры	t	small
30433	23617	412	Белгородская область, Валуйский район, поселок Филиппово, здание бывшей начальной школы	t	small
30393	23577	372	Белгородская область, Валуйский район, поселок Уразово, Рабочая, 37	f	medium
30394	23578	373	Белгородская область, Валуйский район, поселок Уразово, Ленина, 7Б	f	large
30395	23579	374	Белгородская область, Валуйский район, поселок Уразово, Калинина, 45	f	large
30392	23576	371	Белгородская область, Валуйский район, поселок Уразово, 2-я Пролетарская, 17	f	large
30440	23624	419	Белгородская область, Валуйский район, поселок Ураево, здание Ураевского сельского Дома культуры	f	small
30426	23610	405	Белгородская область, Валуйский район, поселок Углово, здание Угловского сельского клуба	t	small
30419	23603	398	Белгородская область, Валуйский район, поселок Тулянка, здание МОУ Тулянская основная общеобразовательная школа	f	small
30434	23618	413	Московская область, Солнечногорский район, деревня Тимоново	f	small
30402	23586	381	Белгородская область, Валуйский район, поселок Сухарево, здание Сухаревского сельского клуба	f	small
30399	23583	378	Белгородская область, Валуйский район, поселок Старый Хутор, здание Старохуторского сельского клуба	f	small
30436	23620	415	Белгородская область, Валуйский район, поселок Солоти, здание Солотянского сельского Дома культуры	f	medium
30397	23581	376	Белгородская область, Валуйский район, поселок Соболевка, здание Соболевского сельского Дома культуры 	f	medium
30431	23615	410	Вологодская область, Череповецкий район, село Селиваново	f	small
30412	23596	391	Белгородская область, Валуйский район, поселок Рябики, здание конторы участка №1 ООО Русагро-Валуйки	f	small
30423	23607	402	Белгородская область, Валуйский район, поселок Рощино, здание Рощинского сельского клуба	f	small
30428	23612	407	Белгородская область, Валуйский район, поселок Рождествено, здание Рождественского сельского Дома культуры	f	large
83928	57344	3125	Москва, Зеленоград, к1016	f	large
30430	23614	409	Белгородская область, Валуйский район, поселок Ровное, здание МДОУ Детский сад	t	small
30425	23609	404	Белгородская область, Валуйский район, поселок Принцевка, здание Принцевского сельского Дома культуры	f	medium
30420	23604	399	Белгородская область, Валуйский район, поселок Посохово, здание Посоховского сельского клуба	f	small
31091	24244	1070	Белгородская область, Валуйский район, поселок Песчанка, Центральная, 22, дом культуры	f	large
30442	23626	421	Белгородская область, Валуйский район, поселок Орехово, здание Ореховского сельского клуба	t	small
30403	23587	382	Оренбургская область, Матвеевский район, село Новопетровка	f	small
30429	23613	408	Белгородская область, Валуйский район, поселок Новоказацкое	f	small
30422	23606	401	Белгородская область, Валуйский район, поселок Насоново, здание Насоновского сельского Дома культуры	f	large
30421	23605	400	Белгородская область, Валуйский район, поселок Мандрово, здание Мандровского сельского Дома культуры	f	medium
30407	23591	386	Оренбургская область, Тоцкий район, село Логачевка	f	small
30418	23602	397	Брянская область, Унечский район, поселок Лавы	f	small
30415	23599	394	Псковская область, Печорский район, село Кукуевка	f	small
30413	23597	392	Белгородская область, Валуйский район, поселок Конопляновка, здание Конопляновского сельского Дома культуры	f	small
30439	23623	418	Белгородская область, Валуйский район, поселок Колыхалино	f	medium
30417	23601	396	Белгородская область, Валуйский район, поселок Колосково, здание Колосковского сельского Дома культуры	f	medium
30404	23588	383	Псковская область, Невельский район, село Карабаново	f	small
30410	23594	389	Орловская область, Покровский район, поселок Казначеевка	f	small
30409	23593	388	Белгородская область, Валуйский район, поселок Казинка, здание Казинского сельского Дома культуры	f	medium
30396	23580	375	Белгородская область, Валуйский район, поселок Знаменка, здание Знаменского сельского Дома культуры	t	small
30613	23788	592	Белгородская область, Валуйский район, поселок Долгое, Центральная, 48	f	small
30406	23590	385	Белгородская область, Валуйский район, поселок Двулучное, здание Двулученского сельского Дома культуры	f	large
30408	23592	387	Алтайский край, Ребрихинский район, поселок Дальний	f	small
30405	23589	384	Белгородская область, Валуйский район, поселок Герасимовка, здание Герасимовского сельского Дома культуры	f	medium
30391	23575	370	Белгородская область, Валуйский район, Валуйки, Фурманова, 22	f	large
30387	23571	366	Белгородская область, Валуйский район, Валуйки, Суржикова, 78	f	large
30386	23570	365	Белгородская область, Валуйский район, Валуйки, Суржикова, 30	f	large
30378	23562	357	Белгородская область, Валуйский район, Валуйки, Ст. Разина, 10	f	large
30390	23574	369	Белгородская область, Валуйский район, Валуйки, Соколова, 48	f	large
30381	23565	360	Белгородская область, Валуйский район, Валуйки, Свердлова, 91	f	large
30373	23557	352	Белгородская область, Валуйский район, Валуйки, Речная, 2	f	small
30385	23569	364	Белгородская область, Валуйский район, Валуйки, Привокзальная площадь, 4	f	large
30384	23568	363	Белгородская область, Валуйский район, Валуйки, Никольская , 191	f	large
30382	23566	361	Белгородская область, Валуйский район, Валуйки, Никольская, 1	f	large
30389	23573	368	Белгородская область, Валуйский район, Валуйки, Курячего, 3	f	large
30388	23572	367	Белгородская область, Валуйский район, Валуйки, Котовского, 16	f	large
30383	23567	362	Белгородская область, Валуйский район, Валуйки, Комсомольская, 28	f	large
30375	23559	354	Белгородская область, Валуйский район, Валуйки, Горького, 86	f	large
30374	23558	353	Белгородская область, Валуйский район, Валуйки, Горького, 41	f	large
30377	23561	356	Белгородская область, Валуйский район, Валуйки, 9 Января, 1	f	large
30376	23560	355	Белгородская область, Валуйский район, Валуйки, 9 Января, 43	f	large
30380	23564	359	Белгородская область, Валуйский район, Валуйки, 1 Мая, 51	f	large
30400	23584	379	Белгородская область, Валуйский район, поселок Бутырки, здание МОУ Бутырская основная общеобразовательная школа	f	small
30401	23585	380	Белгородская область, Валуйский район, поселок Борки, здание Борчанского сельского Дома культуры 	f	medium
111565	57344	3124	Москва, Зеленоград, к1016	f	medium
30739	23913	718	Белгородская область, Валуйский район, поселок Бирюч, Красная, 22	f	medium
30738	23912	717	Белгородская область, Валуйский район, поселок Бирюч, Красная, 2	f	large
30435	23619	414	Белгородская область, Валуйский район, поселок Басово, здание Басовского сельского клуба	t	small
30414	23598	393	республика Татарстан, Пестречинский район, село Аркатово	f	small
30365	23549	344	Белгородская область, Борисовский район, поселок Чуланово, Мирная, 142	f	small
30372	23556	351	Белгородская область, Борисовский район, поселок Хотмыжск, Данкова, 10	f	large
30369	23553	348	Белгородская область, Борисовский район, поселок Стригуны 1-е, Набережная, 50А	f	medium
30370	23554	349	Белгородская область, Борисовский район, поселок Стригуны 1-е, Комсомольская, 8а	f	large
30367	23551	346	Белгородская область, Борисовский район, поселок Октябрьская Готня, Советская, 70	f	small
30371	23555	350	Белгородская область, Борисовский район, поселок Ново-Александровка, Новоалександровская, здание сельского клуба	t	small
30348	23531	327	Белгородская область, Борисовский район, поселок Никитское, Подлесовка, 13	t	small
30364	23548	343	Белгородская область, Борисовский район, поселок Крюково, Ленина, 55	f	medium
30368	23552	347	Белгородская область, Борисовский район, поселок Красный Куток, Середенко, 6	t	small
30366	23550	345	Белгородская область, Борисовский район, поселок Зыбино, Центральная, 2	t	small
30350	23533	329	Белгородская область, Борисовский район, поселок Зозули, Колхозная, 41а	f	medium
30362	23545	341	Белгородская область, Борисовский район, поселок Грузское, Центральная, 22	f	medium
30478	23663	457	Белгородская область, Борисовский район, поселок Борисовка, Здание ООО Русагро-Инвест Филиал Белогорье	f	medium
30360	23543	339	Белгородская область, Борисовский район, поселок Борисовка, пл. Ушакова, 5а	f	large
30358	23541	337	Белгородская область, Борисовский район, поселок Борисовка, переулок Дегтярева, 1	f	large
30361	23544	340	Белгородская область, Борисовский район, поселок Борисовка, Совхозная, 11	f	large
30356	23539	335	Белгородская область, Борисовский район, поселок Борисовка, Советская, 98	f	medium
30355	23538	334	Белгородская область, Борисовский район, поселок Борисовка, Советская, 67	f	large
30353	23536	332	Белгородская область, Борисовский район, поселок Борисовка, Республиканская, 40	f	medium
30359	23542	338	Белгородская область, Борисовский район, поселок Борисовка, Первомайская, 13	f	large
30357	23540	336	Белгородская область, Борисовский район, поселок Борисовка, Грайворонская, 221а	f	large
30354	23537	333	Белгородская область, Борисовский район, поселок Борисовка, Белгородская, 35	f	large
30351	23534	330	Белгородская область, Борисовский район, поселок Березовка, Садовая, 14	f	medium
30352	23535	331	Белгородская область, Борисовский район, поселок Березовка, Колхозная, 28	f	medium
30349	23532	328	Белгородская область, Борисовский район, поселок Беленькое, Первомайская, 66а	f	large
30363	23547	342	Белгородская область, Борисовский район, поселок Байцуры, Молодежная, 67	f	small
30347	23530	326	Белгородская область, Борисовский район, поселок Акулиновка, Центральная, 32	f	small
30265	23447	244	Белгородская область, Белгородский район, поселок Ястребово, Кидалова, 41	f	small
30321	23505	300	Белгородская область, Белгородский район, поселок Ясные Зори, Кирова, 31	f	large
30320	23504	299	Белгородская область, Белгородский район, поселок Щетиновка, Молодежная, 1	f	medium
30322	23506	301	Белгородская область, Белгородский район, поселок Черемошное, Мира, 6	f	small
30318	23502	297	Белгородская область, Белгородский район, поселок Хохлово, Центральная, 17	f	medium
30326	23510	305	Белгородская область, Белгородский район, поселок Устинка, Центральная, 1	t	small
30316	23499	295	Белгородская область, Белгородский район, поселок Таврово, Садовая, 41А	f	large
30317	23500	296	Белгородская область, Белгородский район, поселок Таврово, Комсомольская, 26Б	f	large
30315	23498	294	Белгородская область, Белгородский район, поселок Таврово, Комсомольская, 3	f	large
30313	23496	292	Белгородская область, Белгородский район, поселок Стрелецкое, Чапаева, 88	f	large
30314	23497	293	Белгородская область, Белгородский район, поселок Стрелецкое, Краснооктябрьская, 148	f	large
30312	23495	291	Белгородская область, Белгородский район, поселок Стрелецкое, Королева, 36	f	large
30275	23458	254	Белгородская область, Белгородский район, поселок Солохи, Школьная, 1А	f	small
30343	23527	322	Белгородская область, Белгородский район, поселок Северный, Школьная, 52	f	large
30346	23529	325	Белгородская область, Белгородский район, поселок Северный, Олимпийская, 14	f	large
30345	23529	324	Белгородская область, Белгородский район, поселок Северный, Олимпийская, 14	f	large
30344	23528	323	Белгородская область, Белгородский район, поселок Северный, Олимпийская, 12	f	large
30286	23469	265	Белгородская область, Белгородский район, поселок Репное	t	small
30337	23521	316	Белгородская область, Белгородский район, поселок Разумное, Школьная, 1	f	large
30338	23522	317	Белгородская область, Белгородский район, поселок Разумное, Чехова, 1	f	large
30340	23524	319	Белгородская область, Белгородский район, поселок Разумное, Филиппова, 5	f	large
30336	23520	315	Белгородская область, Белгородский район, поселок Разумное, Филиппова, 2	f	large
30341	23525	320	Белгородская область, Белгородский район, поселок Разумное, Станционная, ПМС-59	f	medium
30335	23519	314	Белгородская область, Белгородский район, поселок Разумное, Сиреневый бульвар, 1	f	large
30334	23519	313	Белгородская область, Белгородский район, поселок Разумное, Сиреневый бульвар, 1	f	large
30339	23523	318	Белгородская область, Белгородский район, поселок Разумное, Ленина, 141	f	large
30332	23516	311	Белгородская область, Белгородский район, поселок Разумное, Железнодорожная, 17	f	large
30333	23518	312	Белгородская область, Белгородский район, поселок Разумное, Бельгина, 14	f	large
30309	23492	288	Белгородская область, Белгородский район, поселок Пушкарное, Центральная, 11	f	large
30310	23493	289	Белгородская область, Белгородский район, поселок Пушкарное, Пушкарская, 140А	f	large
30268	23450	247	Белгородская область, Белгородский район, поселок Петропавловка, Гагарина, 51	f	small
30304	23487	283	Белгородская область, Белгородский район, поселок Петровка, Трудовая, 23	f	small
30274	23457	253	Белгородская область, Белгородский район, поселок Орловка, переулок Лесной, 9А	t	small
30327	23511	306	Белгородская область, Белгородский район, поселок Октябрьский, Чернышевского, 2	f	large
30329	23513	308	Белгородская область, Белгородский район, поселок Октябрьский, Привокзальная, 5	f	large
30330	23514	309	Белгородская область, Белгородский район, поселок Октябрьский, Матросова, 2	f	large
30331	23515	310	Белгородская область, Белгородский район, поселок Октябрьский, Кутузова, 4А	f	medium
30328	23512	307	Белгородская область, Белгородский район, Коммунистическая, 1	f	large
30307	23490	286	Белгородская область, Белгородский район, поселок Новосадовый, Лейтенанта Павлова, 1	f	large
30280	23463	259	Белгородская область, Белгородский район, поселок Новая Нелидовка, Зеленая, 93	t	small
30306	23489	285	Белгородская область, Белгородский район, поселок Никольское, Школьная, 3	f	large
30305	23488	284	Белгородская область, Белгородский район, поселок Никольское, Советская, 26Б	f	large
30273	23456	252	Белгородская область, Белгородский район, поселок Николаевка, Николаевка, 57	t	small
30295	23478	274	Белгородская область, Белгородский район, поселок Нижний Ольшанец, Придорожная, 8	f	small
30324	23508	303	Белгородская область, Белгородский район, поселок Нечаевка, Мира, 61	t	small
30289	23472	268	Белгородская область, Белгородский район, поселок Нехотеевка, Зелёная, 35	f	small
30264	23446	243	Белгородская область, Белгородский район, поселок Мясоедово, Трунова, 86	f	medium
30303	23486	282	Белгородская область, Белгородский район, поселок Малиновский, Мирная, 9	f	large
30300	23483	279	Белгородская область, Белгородский район, поселок Майский, Садовая, 12Б	f	large
30301	23484	280	Белгородская область, Белгородский район, поселок Майский, Пионерская, 2	f	medium
30302	23485	281	Белгородская область, Белгородский район, поселок Майский, Кирова, 6	f	large
30297	23480	276	Белгородская область, Белгородский район, поселок Майский, Кирова, 16А	f	large
30298	23481	277	Белгородская область, Белгородский район, поселок Майский, Вавилова, 16	f	large
30296	23479	275	Белгородская область, Белгородский район, поселок Майский, Вавилова, 1	f	large
30294	23477	273	Белгородская область, Белгородский район, поселок Крутой Лог, Октябрьская, 21	f	large
30293	23476	272	Белгородская область, Белгородский район, поселок Красный Хутор, Калинина, 3	f	medium
30291	23474	270	Белгородская область, Белгородский район, поселок Красный Октябрь, Победы, 3	f	medium
30292	23475	271	Белгородская область, Белгородский район, поселок Красный Октябрь, Гагарина, 2А	f	large
30082	23320	61	Белгородская область, Белгородский район, поселок Красное, Ворошилова, 2Б	f	large
30319	23503	298	Белгородская область, Белгородский район, поселок Киселево, Центральная, 14А	f	small
30267	23449	246	Белгородская область, Белгородский район, поселок Зеленая Поляна, Донецкая, 3	f	medium
30288	23471	267	Белгородская область, Белгородский район, поселок Журавлевка, Коммунистическая, 7	f	medium
30287	23470	266	Белгородская область, Белгородский район, поселок Ерик, Советская, 2А	t	medium
30285	23468	264	Белгородская область, Белгородский район, колхоз Дубовое, Ягодная, 3А	f	large
30283	23466	262	Белгородская область, Белгородский район, колхоз Дубовое, Лесная, 2	f	large
30282	23465	261	Белгородская область, Белгородский район, колхоз Дубовое, Лесная, 2	f	large
30311	23494	290	Белгородская область, Белгородский район, поселок Драгунское, Драгунская, 193А	f	medium
30278	23461	257	Белгородская область, Белгородский район, поселок Долбино, Школьная, 21А	t	small
30279	23462	258	Белгородская область, Белгородский район, поселок Головино, Катульского, 47	f	medium
30325	23509	304	Белгородская область, Белгородский район, поселок Вёргилевка, Центральная, 24	t	small
30276	23459	255	Белгородская область, Белгородский район, поселок Веселая Лопань, Заводская, 1А	f	medium
30277	23460	256	Белгородская область, Белгородский район, поселок Веселая Лопань, Гагарина, 7Б	f	large
30281	23464	260	Белгородская область, Белгородский район, поселок Варваровка, Зелёная, 55	t	small
30323	23507	302	Белгородская область, Белгородский район, поселок Бочковка, Советская, 69	t	small
30308	23491	287	Белгородская область, Белгородский район, поселок Ближняя Игуменка, Центральная, 10	f	medium
30272	23455	251	Белгородская область, Белгородский район, поселок Ближний, Луговой переулок, 9а	t	small
30270	23452	249	Белгородская область, Белгородский район, поселок Бессоновка	f	large
30271	23453	250	Белгородская область, Белгородский район, поселок Бессоновка, Партизанская, 4А	f	large
30823	23995	802	Белгородская область, Белгородский район, поселок Беломестное, сельский Дом культуры	f	large
30269	23451	248	Белгородская область, Белгородский район, поселок Беломестное, Центральная, 64	f	small
30266	23448	245	Белгородская область, Белгородский район, поселок Беломестное, Центральная, 13	f	large
30263	23445	242	Белгородская область, Белгородский район, поселок Беловское, Центральная, 1Б	f	large
30342	23526	321	Белгородская область, Белгородский, поселок Северный, Школьная,, 35	f	large
30057	23297	36	Белгородская область, Алексеевский район, поселок Щербаково, Здание дома культуры	f	large
30075	23315	54	Белгородская область, Алексеевский район, поселок Хрещатый, Здание дома культуры	f	small
30073	23313	52	Белгородская область, Алексеевский район, поселок Хлевище	f	medium
30049	23288	28	Белгородская область, Алексеевский район, поселок Тютюнниково, Здание администрации сельского поселения	f	small
30056	23296	35	Белгородская область, Алексеевский район, поселок Теплинка, Здание школы	f	small
30070	23310	49	Белгородская область, Алексеевский район, поселок Студеный Колодец, Здание клуба	f	small
30072	23312	51	Белгородская область, Алексеевский район, поселок Советское, Здание дома культуры	f	large
30038	23277	17	Белгородская область, Алексеевский район, поселок Славгородское	t	small
30053	23293	32	Белгородская область, Алексеевский район, поселок Сидоркин	t	small
30069	23309	48	Белгородская область, Алексеевский район, поселок Репенка, Здание дома культуры	f	small
30068	23308	47	Белгородская область, Алексеевский район, поселок Подсереднее, Здание администрации сельского поселения	f	large
30048	23287	27	Белгородская область, Алексеевский район, поселок Пирогово, Здание клуба	t	small
30067	23307	46	Белгородская область, Алексеевский район, поселок Мухоудеровка, Здание дома культуры	f	large
30064	23304	43	Белгородская область, Алексеевский район, поселок Меняйлово, Здание дома культуры	f	small
30062	23302	41	Белгородская область, Алексеевский район, поселок Матрено-Гезово, Здание дома культуры	f	medium
30059	23299	38	Белгородская область, Алексеевский район, поселок Луценково, Здание школы	f	medium
30055	23295	34	Белгородская область, Алексеевский район, поселок Красное, Здание клуба	f	small
30054	23294	33	Белгородская область, Алексеевский район, поселок Красное, Здание дома культуры	f	small
30058	23298	37	Белгородская область, Алексеевский район, поселок Копанец, Здание клуба	t	small
30066	23306	45	Белгородская область, Алексеевский район, поселок Колтуновка, Здание клуба	t	small
30043	23282	22	Белгородская область, Алексеевский район, поселок Ковалево, Здание дома культуры	f	small
30074	23314	53	Белгородская область, Алексеевский район, поселок Камышеватое	f	small
30041	23280	20	Белгородская область, Алексеевский район, поселок Калитва, Здание дома культуры	f	medium
30052	23292	31	Белгородская область, Алексеевский район, поселок Ильинка, Здание дома культуры	f	large
30051	23291	30	Белгородская область, Алексеевский район, поселок Иловка, Здание администрации	f	large
30050	23290	29	Белгородская область, Алексеевский район, поселок Иловка, Здание дома культуры	f	large
30047	23286	26	Белгородская область, Алексеевский район, поселок Иващенково, Здание дома культуры	f	small
30071	23311	50	Белгородская область, Алексеевский район, поселок Запольное, Здание ФАП	f	small
30046	23285	25	Белгородская область, Алексеевский район, поселок Жуково, Здание дома культуры	f	small
31072	24227	1051	Белгородская область, Алексеевский район, поселок Городище, Революционная, 52, Петровский дом культуры	f	large
30044	23283	23	Белгородская область, Алексеевский район, поселок Глуховка, Здание школы 	f	medium
30042	23281	21	Белгородская область, Алексеевский район, поселок Гарбузово, Здание дома культуры	f	medium
30061	23301	40	Белгородская область, Алексеевский район, поселок Воробьево, Здание клуба	t	small
30040	23279	19	Белгородская область, Алексеевский район, поселок Варваровка, Здание дома культуры 	f	medium
30045	23284	24	Белгородская область, Алексеевский район, поселок Бубликово, Здание клуба	f	small
30060	23300	39	Белгородская область, Алексеевский район, поселок Божково	f	small
30065	23305	44	Белгородская область, Алексеевский район, поселок Ближнее Чесночное, Здание клуба 	f	small
30039	23278	18	Белгородская область, Алексеевский район, поселок Афанасьевка, здание дома культуры	f	medium
30063	23303	42	Белгородская область, Алексеевский район, поселок Алексеенково	f	small
30035	23274	14	Белгородская область, Алексеевский район, Алексеевка, поселок Опытная станция	f	small
30037	23276	16	Белгородская область, Алексеевский район, поселок Алейниково, СДК	f	small
111599	57402	4008	Москва, площадь Киевского Вокзала, 1	f	medium
83962	57369	3161	Москва, Зеленоград, к818	f	large
83960	57367	3159	Москва, Зеленоград, к912	f	large
83959	57366	3158	Москва, Зеленоград, к844	f	large
83958	57365	3157	Москва, Зеленоград, к921а	f	large
83963	57364	3162	Москва, Зеленоград, к921а	f	large
83956	57364	3155	Москва, Зеленоград, к921а	f	large
83965	57363	3164	Москва, Зеленоград, к913а	f	large
83953	57363	3152	Москва, Зеленоград, к913а	f	large
83954	57362	3153	Москва, Зеленоград, к913а	f	large
83952	57362	3151	Москва, Зеленоград, к913а	f	large
83951	57361	3150	Москва, Зеленоград, к844	f	large
83957	57360	3156	Москва, Зеленоград, к818	f	large
83955	57360	3154	Москва, Зеленоград, к818	f	large
83950	57360	3149	Москва, Зеленоград, к818	f	large
83949	57359	3148	Москва, Зеленоград, к1214	f	large
83948	57358	3147	Москва, Зеленоград, к1214	f	large
83947	57358	3146	Москва, Зеленоград, к1214	f	large
83946	57358	3145	Москва, Зеленоград, к1214	f	large
83945	57358	3144	Москва, Зеленоград, к1214	f	large
83943	57357	3142	Москва, Зеленоград, к1140	f	large
83941	57355	3140	Москва, Зеленоград, к1128	f	large
83940	57354	3139	Москва, Зеленоград, к1128	f	large
83939	57353	3138	Москва, Зеленоград, к1128	f	large
83938	57353	3137	Москва, Зеленоград, к1128	f	large
83937	57352	3136	Москва, Зеленоград, к1115	f	large
83936	57352	3135	Москва, Зеленоград, к1115	f	large
83935	57351	3134	Москва, Зеленоград, к1115	f	large
83934	57350	3133	Москва, Зеленоград, к1115	f	large
83874	57318	3063	Москва, Зеленоград, к1632, адрес УИК: Зеленоград, корпус 1604	f	large
83873	57318	3062	Москва, Зеленоград, к1632, адрес УИК: Зеленоград, корпус 1604	f	large
83872	57317	3061	Москва, Зеленоград, к1609	f	large
83871	57316	3060	Москва, Зеленоград, к1609	f	large
83869	57315	3058	Москва, Зеленоград, к1609	f	large
83870	57315	3059	Москва, Зеленоград, к1609	f	large
83868	57314	3057	Москва, Зеленоград, к1530	f	large
83867	57314	3056	Москва, Зеленоград, к1530	f	large
83866	57313	3055	Москва, Зеленоград, к1555	f	large
83865	57312	3054	Москва, Зеленоград, к1555	f	large
83864	57311	3053	Москва, Зеленоград, к1530	f	large
83863	57310	3052	Москва, Зеленоград, к1530	f	large
83862	57309	3051	Москва, Зеленоград, к1555	f	large
83861	57308	3050	Москва, Зеленоград, к1555	f	large
83860	57307	3049	Москва, Зеленоград, к1556	f	large
83859	57306	3048	Москва, Зеленоград, к1556	f	large
83858	57305	3047	Москва, Зеленоград, к1556	f	large
83857	57304	3046	Зеленоград, к1556	f	large
83879	57303	3069	Зеленоград, к1816	f	large
83856	57303	3045	Зеленоград, к1816	f	large
83855	57302	3044	Москва, Зеленоград, к1816	f	large
111557	57301	3043	Москва, Зеленоград, к1464	f	medium
83854	57300	3042	Москва, Зеленоград, к1464	f	large
111556	57299	3041	Москва, Зеленоград, к1464	f	medium
83852	57299	3039	Москва, Зеленоград, к1464	f	large
83853	57298	3040	Москва, Зеленоград, к1464	f	large
83851	57298	3038	Москва, Зеленоград, к1464	f	large
83964	57297	3163	Москва, Зеленоград, к828	f	large
83961	57297	3160	Москва, Зеленоград, к828	f	large
83848	57296	3035	Москва, Зеленоград, к1469	f	large
83846	57295	3033	Москва, Зеленоград, к1469	f	large
83847	57294	3034	Москва, Зеленоград, к1469	f	large
83845	57294	3032	Москва, Зеленоград, к1469	f	large
83844	57293	3031	Москва, Зеленоград, к1468	f	large
83850	57292	3037	Москва, Зеленоград, к1468, корпус 1444	f	large
83842	57292	3029	Москва, Зеленоград, к1468, корпус 1444	f	large
83636	57163	2819	Москва, Северо-Западный административный округ	f	large
83552	57113	2734	Москва, район Филевский парк, Новозаводская улица, 19	f	large
83551	57113	2733	Москва, район Филевский парк, Новозаводская улица, 19	f	large
83506	57083	2688	Москва, Западный административный округ	f	large
83505	57083	2687	Москва, Западный административный округ	f	large
83457	57050	2639	Москва, 1, адрес УИК: Ленинские горы, дом 1, корп. Ж	f	large
83456	57049	2638	Москва, район Раменки, улица Дружбы, 8	f	large
83246	56912	2427	Москва, поселок Внуково, Интернациональная улица, 10	f	large
83245	56912	2426	Москва, поселок Внуково, Интернациональная улица, 10	f	large
82861	56660	2039	Москва, микрорайон Северное Чертаново	f	large
82860	56660	2038	Москва, микрорайон Северное Чертаново	f	large
82859	56660	2037	Москва, микрорайон Северное Чертаново	f	large
82802	56625	1979	Москва, к810	f	large
82801	56625	1978	Москва, к810	f	large
82800	56625	1977	Москва, к810	f	large
82799	56624	1976	Москва, к809	f	large
82798	56624	1975	Москва, к809	f	large
82128	56233	1293	Москва, Капотня 3-й квартал, 24	f	large
82127	56232	1292	Москва, Капотня 2-й квартал, 20А	f	large
82126	56232	1291	Москва, Капотня 2-й квартал, 20А	f	large
82125	56232	1290	Москва, Капотня 2-й квартал, 20А	f	large
82043	56181	1208	Москва, 8-я улица Соколиной Горы, 5	f	large
82042	56180	1207	Москва, 9-я улица Соколиной Горы, 17	f	large
82022	56161	1187	Москва, 15-я Парковая улица, 52а	f	large
82020	56161	1185	Москва, 15-я Парковая улица, 52а	f	large
81763	56003	926	Москва, поселок Восточный, Главная улица, 13	f	large
81762	56002	925	Москва, поселок Восточный, Главная улица, 9а	f	large
81758	56000	921	Москва, стадион Измайлово	f	large
81759	55999	922	Москва, район Измайлово, Первомайская улица, 111	f	large
81757	55999	920	Москва, район Измайлово, Первомайская улица, 111	f	large
81755	55995	918	Москва, стадион Измайлово	f	large
81754	55995	917	Москва, стадион Измайлово	f	large
81752	55995	915	Москва, стадион Измайлово	f	large
81575	55889	737	Москва, район Отрадное, Березовая аллея, 15б	f	large
81573	55889	735	Москва, район Отрадное, Березовая аллея, 15б	f	large
81289	55715	450	Москва, Левобережный район, Флотская улица, 11	f	large
81286	55715	447	Москва, Левобережный район, Флотская улица, 11	f	large
81274	55706	435	Москва, дрес УИК: Дмитровское шоссе, дом 57, корп. 1, 1-й Нижне-Лихоборский проезд, 15, адрес УИК: Дмитровское шоссе, дом 57, корп. 1	f	large
82431	56427	1600	Москва, Педагогическая, 3	f	large
81224	55662	384	Москва, Левобережный район, Ленинградское шоссе, 94а	f	large
81150	55615	310	Москва, Левобережный район, Флотская улица, 25	f	large
81143	55610	303	Москва, Левобережный район, Флотская улица, 60	f	large
81142	55610	302	Москва, Левобережный район, Флотская улица, 60	f	large
81092	55575	252	Москва, Левобережный район, Ленинградское шоссе, 54	f	large
82172	56262	1339	Москва, шоссе Энтузиастов, 12	f	large
82168	56258	1334	Москва, шоссе Энтузиастов, 16	f	large
81965	56126	1130	Москва, шоссе Энтузиастов, 72	f	large
81812	56027	975	Москва, шоссе Энтузиастов, 100а	f	large
81811	56027	974	Москва, шоссе Энтузиастов, 100а	f	large
81813	56027	976	Москва, шоссе Энтузиастов, 100а	f	large
81810	56026	973	Москва, шоссе Энтузиастов, 96г	f	large
81809	56026	972	Москва, шоссе Энтузиастов, 96г	f	large
111570	57372	3167	Москва, улица Яблочкова, 35г	f	\N
81427	55808	589	Москва, улица Яблочкова, 3	f	large
82158	56252	1324	Москва, улица Юных Ленинцев, 68К2	f	large
82157	56252	1323	Москва, улица Юных Ленинцев, 68К2	f	large
83488	57071	2670	Москва, улица Щорса, 5к1	f	large
83487	57071	2669	Москва, улица Щорса, 5к1	f	large
83486	57071	2668	Москва, улица Щорса, 5к1	f	large
80917	55417	71	Москва, улица Щепкина, 68	f	large
82138	56241	1304	Москва, улица Шумилова, 9	f	large
82144	56241	1310	Москва, улица Шумилова, 9	f	large
83393	57008	2574	Москва, улица Шолохова, 20	f	large
111540	56486	1710	Москва, улица Шаболовка, 39	f	small
82538	56486	1709	Москва, улица Шаболовка, 39	f	large
82091	56214	1256	Москва, улица Чугунные Ворота, 11	f	large
82090	56214	1255	Москва, улица Чугунные Ворота, 11	f	large
82397	56399	1565	Москва, улица Чистова, 15/15	f	large
83119	56838	2298	Москва, улица Цюрупы, 10	f	large
81521	55864	683	Москва, улица Цандера, 7к2	f	large
83681	57193	2865	Москва, улица Фомичевой, 5	f	large
81047	55535	206	Москва, улица Усиевича, 31а	f	large
81630	55913	792	Москва, улица Тихомирова, 10	f	large
81608	55913	770	Москва, улица Тихомирова, 10	f	large
81607	55913	769	Москва, улица Тихомирова, 10	f	large
83478	57064	2660	Москва, улица Столетова, 3	f	large
82539	56485	1711	Москва, улица Стасовой, 8	f	large
82537	56485	1708	Москва, улица Стасовой, 8	f	large
82063	56198	1228	Москва, улица Сокольнический Вал, 28	f	large
82062	56198	1227	Москва, улица Сокольнический Вал, 28	f	large
83815	57273	3002	Москва, улица Свободы, 26	f	large
83814	57273	3001	Москва, улица Свободы, 26	f	large
81252	55685	413	Москва, улица Сальвадора Альенде, 6	f	large
83218	56898	2398	Москва, улица Рокотова, 5	f	large
81307	55730	468	Москва, улица Розанова, 8с1	f	large
83849	57291	3036	Москва, улица Радио, к1468	f	large
83843	57291	3030	Москва, улица Радио, к1468	f	large
83841	57291	3028	Москва, улица Радио, к1468	f	large
83449	57045	2631	Москва, улица Пудовкина, 4а	f	large
81007	55496	166	Москва, улица Пречистенка, 22/2	f	large
83160	56865	2339	Москва, улица Поляны, 31а	f	large
83159	56865	2338	Москва, улица Поляны, 31а	f	large
81011	55500	170	Москва, улица Плющиха, 39	f	large
81945	56116	1110	Москва, улица Плющева, 11а	f	large
81963	56125	1128	Москва, улица Плеханова, 5б	f	large
81560	55880	722	Москва, улица Пестеля, 8г	f	large
81557	55880	719	Москва, улица Пестеля, 8г	f	large
81555	55880	717	Москва, улица Пестеля, 8г	f	large
82265	56319	1432	Москва, улица Перерва, 44	f	large
82264	56319	1431	Москва, улица Перерва, 44	f	large
82262	56319	1429	Москва, улица Перерва, 44	f	large
82263	56318	1430	Москва, улица Перерва, 36	f	large
82261	56318	1428	Москва, улица Перерва, 36	f	large
82260	56318	1427	Москва, улица Перерва, 36	f	large
83778	57248	2964	Москва, улица Паршина, 8	f	large
83020	56773	2199	Москва, улица Панферова, 8к1	f	large
81330	55750	492	Москва, улица Павла Корчагина, 13	f	large
82990	56752	2169	Москва, улица Островитянова, 19/22	f	large
83045	56792	2224	Москва, улица Обручева, 28а	f	large
83044	56792	2223	Москва, улица Обручева, 28а	f	large
80850	55356	3	Москва, улица Новый Арбат, 36/9	f	large
83043	56791	2222	Москва, улица Новаторов, 34к2	f	large
83041	56787	2220	Москва, улица Новаторов, 34к1	f	large
83039	56787	2218	Москва, улица Новаторов, 34к1	f	large
83788	95181	2975	Москва, улица Народного Ополчения, 38к2, Российский заочный институт текстильной и легкой промышленности	f	large
83765	57238	2951	Москва, улица Народного Ополчения, 31	f	large
81818	56031	981	Москва, улица Молостовых, 10б	f	large
81731	55983	894	Москва, улица Молдагуловой, 3к1	f	large
83748	57227	2934	Москва, улица Мневники, 4	f	large
83046	56793	2225	Москва, улица Миклухо-Маклая, 21а	f	large
81886	56082	1049	Москва, улица Медведева, 6	f	large
83779	57249	2965	Москва, улица Маршала Тухачевского, 58к2	f	large
83784	57253	2971	Москва, улица Маршала Соколовского, 10	f	large
83786	57254	2973	Москва, улица Маршала Конева, 11	f	large
83785	57254	2972	Москва, улица Маршала Конева, 11	f	large
83794	57240	2981	Москва, улица Маршала Конева, 10	f	large
83793	57240	2980	Москва, улица Маршала Конева, 10	f	large
83014	56768	2193	Москва, улица Марии Ульяновой, 5а	f	large
82349	56369	1517	Москва, улица Маевок, 4	f	large
83430	57033	2612	Москва, улица Лобачевского, 54	f	large
82535	56483	1705	Москва, улица Лобанова, 3	f	large
82534	56483	1704	Москва, улица Лобанова, 3	f	large
81317	55740	479	Москва, улица Куусинена, 13	f	large
81314	55737	476	Москва, улица Куусинена, 6к6	f	large
111588	57390	3185	Москва, улица Кулакова, 17к2, СОШ №129	f	\N
83721	57213	2906	Москва, улица Кулакова, 12к2	f	large
83720	57213	2905	Москва, улица Кулакова, 12к2	f	large
83719	57213	2904	Москва, улица Кулакова, 12к2	f	large
83697	57203	2882	Москва, улица Кулакова, 2к2	f	large
83696	57203	2881	Москва, улица Кулакова, 2к2	f	large
83695	57203	2880	Москва, улица Кулакова, 2к2	f	large
83010	56764	2189	Москва, улица Крупской, 12	f	large
80930	55429	87	Москва, улица Красина, 20с1	f	large
80928	55429	85	Москва, улица Красина, 20с1	f	large
81198	55643	358	Москва, улица Космонавта Волкова, 20	f	large
81390	55788	552	Москва, улица Корнейчука, 52а	f	large
81389	55788	551	Москва, улица Корнейчука, 52а	f	large
81357	55769	519	Москва, улица Коминтерна, 8	f	large
82924	56707	2103	Москва, улица Каховка, 12к2	f	large
81341	55758	503	Москва, улица Касаткина, 13с5	f	large
83303	56950	2484	Москва, улица Ивана Франко, 28к1	f	large
82892	56682	2071	Москва, улица Ивана Бабушкина, 15к5	f	large
82891	56682	2070	Москва, улица Ивана Бабушкина, 15к5	f	large
83302	56949	2483	Москва, улица Екатерины Будановой, 18	f	large
83452	57046	2634	Москва, улица Довженко, 10	f	large
83451	57046	2633	Москва, улица Довженко, 10	f	large
81027	55516	186	Москва, улица Доватора, 5/9	f	large
82883	56675	2062	Москва, улица Дмитрия Ульянова, 26ас1	f	large
81570	55887	732	Москва, улица Декабристов, 40	f	large
81504	55851	666	Москва, улица Двинцев, 10	f	large
81503	55851	665	Москва, улица Двинцев, 10	f	large
82342	56365	1510	Москва, улица Гурьянова, 71	f	large
82339	56365	1507	Москва, улица Гурьянова, 71	f	large
82338	56365	1506	Москва, улица Гурьянова, 71	f	large
83072	56806	2251	Москва, улица Грина, 18к3с1	f	large
83071	56806	2250	Москва, улица Грина, 18к3с1	f	large
83070	56806	2249	Москва, улица Грина, 18к3с1	f	large
83483	95179	2665	Москва, улица Главмосстроя, 28	f	large
83662	57181	2846	Москва, улица Героев Панфиловцев, 35к2	f	large
83770	57243	2956	Москва, улица Генерала Глаголева, 10к2	f	large
81258	55691	419	Москва, улица Врубеля, 6	f	large
80865	55370	18	Москва, улица Воронцово Поле, 5а	f	large
111553	57202	2879	Москва, улица Вилиса Лациса, 2к1	f	small
82235	56305	1402	Москва, улица Верхние Поля, 47к1	f	large
82234	56305	1401	Москва, улица Верхние Поля, 47к1	f	large
82978	56743	2157	Москва, улица Введенского, 32а	f	large
82977	56743	2156	Москва, улица Введенского, 32а	f	large
82976	56742	2155	Москва, улица Введенского, 28	f	large
82975	56742	2154	Москва, улица Введенского, 28	f	large
83582	57134	2765	Москва, улица Ватутина, 8	f	large
83581	57134	2764	Москва, улица Ватутина, 8	f	large
83023	56776	2202	Москва, улица Вавилова, 91	f	large
82967	56736	2146	Москва, улица Бутлерова, 38а	f	large
82961	56729	2140	Москва, улица Бутлерова, 24а	f	large
82958	56729	2137	Москва, улица Бутлерова, 24а	f	large
81195	55640	355	Москва, улица Бусиновская Горка, 7к2	f	large
81194	55640	354	Москва, улица Бусиновская Горка, 7к2	f	large
81193	55640	353	Москва, улица Бусиновская Горка, 7к2	f	large
82047	56185	1212	Москва, улица Бориса Жигуленкова, 27	f	large
82774	56612	1950	Москва, улица Бехтерева, 17а	f	large
82773	56612	1949	Москва, улица Бехтерева, 17а	f	large
82772	56612	1948	Москва, улица Бехтерева, 17а	f	large
82771	56612	1947	Москва, улица Бехтерева, 17а	f	large
82765	56609	1941	Москва, улица Бехтерева, 51	f	large
82764	56609	1940	Москва, улица Бехтерева, 51	f	large
83547	57109	2729	Москва, улица Барклая, 15к1, Адрес УИК: Филёвская Б. ул, дом 31	f	large
80948	55446	107	Москва, улица Антонова-Овсеенко, 6с1	f	large
81590	55900	752	Москва, улица Амундсена, 2с1	f	large
83030	56781	2209	Москва, улица Академика Пилюгина, 16, адрес УИК: Пилюгина академика ул, дом 16, корп. 1	f	large
83029	56781	2208	Москва, улица Академика Пилюгина, 16, адрес УИК: Пилюгина академика ул, дом 16, корп. 1	f	large
83028	56780	2207	Москва, улица Академика Пилюгина, 14а	f	large
83188	56881	2367	Москва, улица Адмирала Лазарева, 68к3	f	large
83187	56881	2366	Москва, улица Адмирала Лазарева, 68к3	f	large
83500	57080	2682	Москва, улица Авиаторов, 8к2	f	large
83499	57080	2681	Москва, улица Авиаторов, 8к2	f	large
83496	57077	2678	Москва, улица Авиаторов, 28	f	large
82124	56231	1289	Москва, улица Авиаконструктора Миля, 18к2	f	large
82123	56231	1288	Москва, улица Авиаконструктора Миля, 18к2	f	large
83489	95180	2671	Москва, улица 50 лет Октября, 6	f	large
83883	57325	3073	Москва, Зеленоград, улица 2-я Пятилетка, 18а, Средняя общеобразовательная школа №229	f	large
83882	57325	3072	Москва, Зеленоград, улица 2-я Пятилетка, 18а, Средняя общеобразовательная школа №229	f	large
83881	57324	3071	Москва, Зеленоград, улица 2-я Пятилетка, 18а	f	large
83878	57322	3068	Москва, Зеленоград, улица 2-я Пятилетка, 18а	f	large
83944	57356	3143	Москва, Зеленоград, район Силино, к1137	f	large
83942	57356	3141	Москва, Зеленоград, район Силино, к1137	f	large
83877	57321	3067	Москва, Зеленоград, район Крюково, к1642	f	large
81516	55860	678	Москва, проспект Мира, 105, УИК: Ольминского пр, дом 3	f	large
81515	55859	677	Москва, проспект Мира, 101а	f	large
81513	55857	675	Москва, проспект Мира, 87	f	large
83745	57225	2931	Москва, проспект Маршала Жукова, 37к2	f	large
111555	57225	2970	Москва, проспект Маршала Жукова, 37к2	f	small
83531	57098	2713	Москва, проспект Вернадского, 88	f	large
83530	57098	2712	Москва, проспект Вернадского, 88	f	large
83528	57096	2710	Москва, проспект Вернадского, 127к2	f	large
83520	57090	2702	Москва, проспект Вернадского, 101к5	f	large
83519	57090	2701	Москва, проспект Вернадского, 101к5	f	large
83518	57090	2700	Москва, проспект Вернадского, 101к5	f	large
83522	57089	2704	Москва, проспект Вернадского, 101к6	f	large
83517	57089	2699	Москва, проспект Вернадского, 101к6	f	large
83442	57041	2624	Москва, проспект Вернадского, 57	f	large
83441	57041	2623	Москва, проспект Вернадского, 57	f	large
83436	57038	2618	Москва, проспект Вернадского, 55	f	large
83435	57038	2617	Москва, проспект Вернадского, 55	f	large
83434	57037	2616	Москва, проспект Вернадского, 37к2	f	large
83432	57035	2614	Москва, проспект Вернадского, 62а	f	large
83012	56766	2191	Москва, проспект Вернадского, 29а	f	large
82052	56190	1217	Москва, проспект Буденного, 32	f	large
82049	56187	1214	Москва, проспект Буденного, 32	f	large
82046	56184	1211	Москва, проспект Буденного, 35	f	large
82044	56182	1209	Москва, проспект Буденного, 31	f	large
82041	56179	1206	Москва, проспект Буденного, 21	f	large
82628	56532	1802	Москва, проспект Андропова, 17к3	f	large
82627	56531	1801	Москва, проспект Андропова, 17к3	f	large
82625	56529	1799	Москва, проспект Андропова, 17к5	f	large
82624	56528	1798	Москва, проспект Андропова, 17К5	f	large
82051	56189	1216	Москва, проезд Энтузиастов, 19а	f	large
81651	55935	813	Москва, проезд Шокальского, 7к2	f	large
81650	55933	812	Москва, проезд Шокальского, 11	f	large
81649	55933	811	Москва, проезд Шокальского, 11	f	large
81648	55932	810	Москва, проезд Шокальского, 11/3	f	large
81627	55921	789	Москва, проезд Шокальского, 63а	f	large
81626	55921	788	Москва, проезд Шокальского, 63а	f	large
81625	55921	787	Москва, проезд Шокальского, 63а	f	large
81206	55650	366	Москва, проезд Черепановых, 44	f	large
81203	55647	363	Москва, проезд Черепановых, 22	f	large
83653	57176	2837	Москва, проезд Стратонавтов, 15	f	large
83654	57176	2838	Москва, проезд Стратонавтов, 15	f	large
83244	56910	2424	Москва, проезд Карамзина, 13к3	f	large
83243	56910	2423	Москва, проезд Карамзина, 13к3	f	large
83242	56910	2422	Москва, проезд Карамзина, 13к3	f	large
83239	56908	2419	Москва, проезд Карамзина, 9к3	f	large
83238	56908	2418	Москва, проезд Карамзина, 9к3	f	large
81008	55497	167	Москва, проезд Девичьего Поля, 2	f	large
81318	55741	480	Москва, проезд Аэропорта, 10	f	large
82430	56427	1599	Москва, Педагогическая, 3	f	large
81764	56004	927	Москва, поселок Акуловского гидроузла, 25	f	large
111597	57400	4006	Москва, площадь Тверская Застава, 7с1	f	small
81016	55505	175	Москва, переулок Хользунова, 8, УИК: Толстого Льва ул, дом 7	f	large
80860	55366	13	Москва, переулок Огородная Слобода, 6с1	f	large
80855	55361	8	Москва, переулок Каменная Слобода, 4	f	large
111590	57392	3187	Москва, набережная Новикова-Прибоя, 6к4, РЭУ 18 ОАО «АПРЭО»	f	\N
83836	57288	3023	Москва, бульвар Яна Райниса, 43к2	f	large
83835	57288	3022	Москва, бульвар Яна Райниса, 43к2	f	large
83834	57288	3021	Москва, бульвар Яна Райниса, 43к2	f	large
83679	57191	2863	Москва, бульвар Яна Райниса, 4к2, УИК: Героев Панфиловцев ул, дом 1, корп. 5	f	large
83678	57190	2862	Москва, бульвар Яна Райниса, 4к2	f	large
83677	57190	2861	Москва, бульвар Яна Райниса, 4к2	f	large
81217	55657	377	Москва, бульвар Матроса Железняка, 22к1	f	large
81218	55646	378	Москва, бульвар Матроса Железняка, 12	f	large
81202	55646	362	Москва, бульвар Матроса Железняка, 12	f	large
81689	55960	852	Москва, бульвар Маршала Рокоссовского, 34	f	large
81688	55960	851	Москва, бульвар Маршала Рокоссовского, 34	f	large
81687	55960	850	Москва, бульвар Маршала Рокоссовского, 34	f	large
83061	56800	2240	Москва, бульвар Дмитрия Донского, 14а	f	large
83060	56800	2239	Москва, бульвар Дмитрия Донского, 14а	f	large
83059	56800	2238	Москва, бульвар Дмитрия Донского, 14а	f	large
83062	56800	2241	Москва, бульвар Дмитрия Донского, 14а	f	large
83058	56799	2237	Москва, бульвар Дмитрия Донского, 6к1	f	large
83057	56799	2236	Москва, бульвар Дмитрия Донского, 6к1	f	large
83056	56798	2235	Москва, бульвар Дмитрия Донского, 6	f	large
83055	56798	2234	Москва, бульвар Дмитрия Донского, 6	f	large
83772	57244	2958	Москва, бульвар Генерала Карбышева, 15к3	f	large
83771	57242	2957	Москва, бульвар Генерала Карбышева, 9к2	f	large
83769	57242	2955	Москва, бульвар Генерала Карбышева, 9к2	f	large
83762	57236	2948	Москва, бульвар Генерала Карбышева, 10к4	f	large
83761	57236	2947	Москва, бульвар Генерала Карбышева, 10к4	f	large
81718	55976	881	Москва, аллея Жемчуговой, 7	f	large
81717	55976	880	Москва, аллея Жемчуговой, 7	f	large
83178	56875	2357	Москва, аллея Витте, 2с1	f	large
83177	56875	2356	Москва, аллея Витте, 2с1	f	large
83176	56875	2355	Москва, аллея Витте, 2с1	f	large
111532	55956	845	Москва, Яузская аллея, 2ас1	f	small
81647	55931	809	Москва, Ясный проезд, 10а	f	large
81646	55931	808	Москва, Ясный проезд, 10а	f	large
81645	55931	807	Москва, Ясный проезд, 10а	f	large
81644	55930	806	Москва, Ясный проезд, 10к3	f	large
81643	55930	805	Москва, Ясный проезд, 10к3	f	large
81642	55929	804	Москва, Ясный проезд, 24а	f	large
81641	55929	803	Москва, Ясный проезд, 24а	f	large
81640	55928	802	Москва, Ясный проезд, 21	f	large
81639	55928	801	Москва, Ясный проезд, 21	f	large
82730	56595	1906	Москва, Ясеневая улица, 35к2	f	large
82725	56592	1901	Москва, Ясеневая , 21к3	f	large
82724	56592	1900	Москва, Ясеневая , 21к3	f	large
82723	56592	1899	Москва, Ясеневая , 21к3	f	large
82729	56594	1905	Москва, Ясеневая, 35к2, Ясеневая ул, дом 41, корп. 1	f	large
82713	56586	1889	Москва, Ясеневая, 8к2	f	large
82712	56586	1888	Москва, Ясеневая, 8к2	f	large
82710	56586	1886	Москва, Ясеневая, 8к2	f	large
83328	56966	2509	Москва, Ярцевская улица, 36к2	f	large
81670	55948	832	Москва, Ярославское шоссе, 8к7	f	large
81669	55947	831	Москва, Ярославское шоссе, 8к7	f	large
81668	55946	830	Москва, Ярославское шоссе, 8к6	f	large
81667	55945	829	Москва, Ярославское шоссе, 26	f	large
81666	55945	828	Москва, Ярославское шоссе, 26	f	large
81665	55945	827	Москва, Ярославское шоссе, 26	f	large
81664	55944	826	Москва, Ярославское шоссе, 116к1	f	large
81663	55943	825	Москва, Ярославское шоссе, 126а	f	large
81680	55939	842	Москва, Ярославское шоссе, 147	f	large
81659	55939	821	Москва, Ярославское шоссе, 147	f	large
81339	55757	501	Москва, Ярославская улица, 27	f	large
81338	55756	500	Москва, Ярославская, 17	f	large
81469	55830	631	Москва, Янтарный проезд, 2	f	large
81468	55830	630	Москва, Янтарный проезд, 2	f	large
82629	56533	1803	Москва, Якорная, 6, УИК: Судостроительная ул, дом 27, корп. 2	f	large
111571	57373	3168	Москва, Яблочкова, 43, Библиотека № 82	f	\N
81438	55814	600	Москва, Яблочкова, 43	f	large
81437	55813	599	Москва, Яблочкова, 35г	f	large
81436	55813	598	Москва, Яблочкова, 35г	f	large
81435	55813	597	Москва, Яблочкова, 35г	f	large
83175	56874	2354	Москва, Южнобутовская улица, 76к1	f	large
83174	56873	2353	Москва, Южнобутовская, 135а	f	large
83173	56873	2352	Москва, Южнобутовская, 135а	f	large
83172	56873	2351	Москва, Южнобутовская, 135а	f	large
83168	56871	2347	Москва, Южнобутовская, 52к2	f	large
82180	56270	1347	Москва, Энергетический проезд, 3	f	large
82183	56273	1350	Москва, Энергетическая, 5	f	large
82424	56423	1593	Москва, Элеваторная улица, 4к2	f	large
82423	56423	1592	Москва, Элеваторная улица, 4к2	f	large
82425	56423	1594	Москва, Элеваторная улица, 4к2	f	large
83809	57260	2996	Москва, Щукинская, 5с1	f	large
83498	57078	2680	Москва, Щорса, 6к1	f	large
83497	57078	2679	Москва, Щорса, 6к1	f	large
82036	56174	1201	Москва, Щербаковская, 36а	f	large
82035	56173	1200	Москва, Щербаковская, 38	f	large
82019	56160	1184	Москва, Щелковское шоссе, 82б	f	large
82013	56156	1178	Москва, Щелковское шоссе, 58А	f	large
82006	56151	1171	Москва, Щелковское шоссе, 26а	f	large
81780	56013	943	Москва, Щелковское шоссе, 79а	f	large
81779	56013	942	Москва, Щелковское шоссе, 79а	f	large
81777	56012	940	Москва, Щелковское шоссе, 77	f	large
81778	56011	941	Москва, Щелковское шоссе, 77	f	large
81776	56011	939	Москва, Щелковское шоссе, 77	f	large
81767	56006	930	Москва, Щелковское шоссе, 29	f	large
81766	56006	929	Москва, Щелковское шоссе, 29	f	large
80848	55354	1	Москва, Шубинский переулок, 6с1	f	large
83821	57278	3008	Москва, Штурвальная улица, 7к2	f	large
82328	56359	1496	Москва, Шоссейная, 7	f	large
82327	56359	1495	Москва, Шоссейная, 7	f	large
83392	57007	2573	Москва, Шолохова, 20, УИК: Чоботовская ул., дом 3, корп. 1	f	large
83391	57005	2572	Москва, Шолохова, 20	f	large
83373	56992	2554	Москва, Шолохова, 9	f	large
83372	56992	2553	Москва, Шолохова, 9	f	large
83371	56992	2552	Москва, Шолохова, 9	f	large
83369	56991	2550	Москва, Шолохова, 19	f	large
83370	56991	2551	Москва, Шолохова, 19	f	large
80951	55445	110	Москва, Шмитовский проезд, 26	f	large
80947	55445	106	Москва, Шмитовский проезд, 26	f	large
111537	56402	1569	Москва, Шкулева, 13/25с2	f	medium
81621	55918	783	Москва, Широкая , 21а	f	large
81620	55918	782	Москва, Широкая , 21а	f	large
81617	55918	779	Москва, Широкая , 21а	f	large
111580	57382	3177	Москва, Широкая, 1а, гимназия № 1506	f	\N
81612	55916	774	Москва, Широкая, 1а	f	large
82711	56587	1887	Москва, Шипиловский проезд, 73	f	large
82706	56583	1882	Москва, Шипиловский проезд, 57	f	large
82705	56581	1880	Москва, Шипиловский проезд, 37К2	f	large
82704	56581	1879	Москва, Шипиловский проезд, 37К2	f	large
82703	56581	1878	Москва, Шипиловский проезд, 37К2	f	large
82699	56578	1874	Москва, Шипиловская улица, 18к2	f	large
82698	56578	1873	Москва, Шипиловская улица, 18к2	f	large
82559	56496	1732	Москва, Шипиловская улица, 46к3	f	large
82558	56496	1731	Москва, Шипиловская улица, 46к3	f	large
82688	56573	1863	Москва, Шипиловская, 27к2	f	large
82687	56573	1862	Москва, Шипиловская, 27к2	f	large
82171	56261	1338	Москва, Шепелюгинская, 21/13с1	f	large
81420	55802	582	Москва, Шенкурский проезд, 15	f	large
81419	55801	581	Москва, Шенкурский проезд, 15	f	large
81414	55799	576	Москва, Шенкурский проезд, 8	f	large
81415	55799	577	Москва, Шенкурский проезд, 8	f	large
81413	55798	575	Москва, Шенкурский проезд, 4а	f	large
81412	55798	574	Москва, Шенкурский проезд, 4а	f	large
81411	55798	573	Москва, Шенкурский проезд, 4а	f	large
82874	56668	2053	Москва, Шверника, 19к2	f	large
82873	56667	2052	Москва, Шверника, 17к2	f	large
82876	56666	2055	Москва, Шверника, 10а	f	large
82872	56666	2051	Москва, Шверника, 10а	f	large
82348	56368	1516	Москва, Шатурская, 1	f	large
82665	56562	1840	Москва, Чонгарский бульвар, 12	f	large
82664	56562	1839	Москва, Чонгарский бульвар, 12	f	large
83394	57009	2575	Москва, Чоботовская улица, 3к1	f	large
83368	56990	2549	Москва, Чоботовская улица, 19	f	large
83396	57011	2577	Москва, Чоботовская, 17	f	large
83395	57010	2576	Москва, Чоботовская, 19, УИК: Мухиной скульптора ул., дом 2	f	large
81836	56040	999	Москва, Чечулина, 28	f	large
81835	56040	998	Москва, Чечулина, 28	f	large
81832	56038	995	Москва, Чечулина, 3к1	f	large
83171	56872	2350	Москва, Чечерский проезд, 80	f	large
83170	56872	2349	Москва, Чечерский проезд, 80	f	large
83169	56872	2348	Москва, Чечерский проезд, 80	f	large
83167	56870	2346	Москва, Чечерский проезд, 42	f	large
83166	56870	2345	Москва, Чечерский проезд, 42	f	large
83165	56869	2344	Москва, Чечерский проезд, 22к1	f	large
83164	56869	2343	Москва, Чечерский проезд, 22к1	f	large
83163	56868	2342	Москва, Чечерский проезд, 6	f	large
82836	56650	2014	Москва, Чертановская улица, 60A	f	large
82835	56650	2013	Москва, Чертановская улица, 60A	f	large
82814	56634	1992	Москва, Чертановская улица, 44а	f	large
82834	56649	2012	Москва, Чертановская, 62а	f	large
82833	56649	2011	Москва, Чертановская, 62а	f	large
82832	56649	2010	Москва, Чертановская, 62а	f	large
82823	56637	2001	Москва, Чертановская, 27	f	large
82817	56637	1995	Москва, Чертановская, 27	f	large
82816	56636	1994	Москва, Чертановская, 27	f	large
82812	56633	1990	Москва, Чертановская, 44а	f	large
82811	56633	1989	Москва, Чертановская, 44а	f	large
82792	56620	1969	Москва, Чертановская, 9А	f	large
82791	56620	1968	Москва, Чертановская, 9А	f	large
82790	56620	1967	Москва, Чертановская, 9А	f	large
82780	56615	1957	Москва, Чертановская, 1ак3	f	large
82776	56615	1953	Москва, Чертановская, 1ак3	f	large
82775	56614	1952	Москва, Чертановская, 1ак3	f	large
82672	56565	1847	Москва, Черноморский бульвар, 8	f	large
82670	56565	1845	Москва, Черноморский бульвар, 8	f	large
81463	55828	625	Москва, Череповецкая, 10а	f	large
81464	55828	626	Москва, Череповецкая, 10а	f	large
81840	56042	1003	Москва, Челябинская улица, 20	f	large
81839	56042	1002	Москва, Челябинская улица, 20	f	large
81834	56039	997	Москва, Челябинская, 9	f	large
81833	56039	996	Москва, Челябинская, 9	f	large
81632	55923	794	Москва, Челобитьевское шоссе, 2к1	f	large
81631	55923	793	Москва, Челобитьевское шоссе, 2к1	f	large
81049	55537	208	Москва, Часовая улица, 22/2с1	f	large
80862	55367	15	Москва, Чаплыгина, 9с3, УИК: Фурманный пер, дом 13, стр. 8	f	large
80861	55367	14	Москва, Чаплыгина, 9с3, УИК: Фурманный пер, дом 13, стр. 8	f	large
81261	55694	422	Москва, Чапаевский переулок, 6/1	f	large
83126	56843	2305	Москва, Цюрупы, 10к1, УИК: Цюрупы ул, дом 3	f	large
83118	56837	2297	Москва, Цюрупы, 14б, УИК: Новочеремушкинская ул, дом 49	f	large
83117	56836	2296	Москва, Цюрупы, 14б	f	large
83120	56819	2299	Москва, Цюрупы, 14а	f	large
83127	56819	2306	Москва, Цюрупы, 14а	f	large
83247	56913	2428	Москва, Центральная, 15а	f	large
81313	55736	475	Москва, Хорошевское шоссе, 82к7	f	large
81312	55735	474	Москва, Хорошевское шоссе, 64ас2, УИК: Хорошевское шоссе, дом 66	f	large
81311	55734	473	Москва, Хорошевское шоссе, 64ас2	f	large
81310	55733	472	Москва, Хорошевское шоссе, 52к2	f	large
81306	55729	467	Москва, Хорошевское шоссе, 3, УИК: Магистральная 5-я ул, дом 8	f	large
81322	55745	484	Москва, Ходынский бульвар, 21а	f	large
81321	55744	483	Москва, Ходынский бульвар, 7, УИК: Полины Осипенко ул, дом 18, корп. 2	f	large
81320	55743	482	Москва, Ходынский бульвар, 7	f	large
82072	56203	1237	Москва, Хлобыстова, 14к3	f	large
82071	56203	1236	Москва, Хлобыстова, 14к3	f	large
82070	56203	1235	Москва, Хлобыстова, 14к3	f	large
111582	57384	3179	Москва, Хибинский проезд, 10, ГОУ СПО Строительный колледж № 12	f	\N
83134	56849	2313	Москва, Херсонская улица, 27а	f	large
83133	56847	2312	Москва, Херсонская улица, 30к3	f	large
83132	56847	2311	Москва, Херсонская улица, 30к3	f	large
83135	56850	2314	Москва, Херсонская, 27а, адрес УИК: Обручева ул, дом 55А	f	large
82110	56223	1275	Москва, Хвалынский бульвар, 4к4	f	large
82109	56223	1274	Москва, Хвалынский бульвар, 4к4	f	large
82467	56447	1637	Москва, Харьковский проезд, 9б	f	large
82466	56446	1636	Москва, Харьковский проезд, 9а, УИК: Медынская ул, дом 1, корп. 3	f	large
82464	56444	1634	Москва, Харьковский проезд, 9а	f	large
82463	56444	1633	Москва, Харьковский проезд, 9а	f	large
82462	56444	1632	Москва, Харьковский проезд, 9а	f	large
81026	55515	185	Москва, Хамовнический Вал, 26, адрес УИК: Хамовнический Вал ул, дом 24	f	large
81025	55514	184	Москва, Хамовнический Вал, 26, адрес УИК: Доватора ул, дом 3	f	large
81998	56143	1163	Москва, Халтуринская улица, 16	f	large
81995	56143	1160	Москва, Халтуринская улица, 16	f	large
81994	56143	1159	Москва, Халтуринская улица, 16	f	large
81996	56144	1161	Москва, Халтуринская, 18	f	large
82515	56469	1685	Москва, Хавская улица, 15с2	f	large
82514	56469	1684	Москва, Хавская улица, 15с2	f	large
82516	56470	1686	Москва, Хавская, 5, УИК: Лестева ул, дом 21, корп. 1	f	large
81806	56024	969	Москва, Хабаровская, 4а	f	large
81805	56024	968	Москва, Хабаровская, 4а	f	large
81019	55508	178	Москва, Фрунзенская набережная, 30, Фрунзенская наб, дом 24/1	f	large
81018	55507	177	Москва, Фрунзенская набережная, 30с	f	large
82662	56145	1836	Москва, Фруктовая улица, 9	f	large
82661	56145	1835	Москва, Фруктовая улица, 9	f	large
82902	56691	2081	Москва, Фотиевой, 14к1	f	large
83684	57195	2868	Москва, Фомичевой, 1к1	f	large
83683	57195	2867	Москва, Фомичевой, 1к1	f	large
83682	57194	2866	Москва, Фомичевой, 5	f	large
83680	57192	2864	Москва, Фомичевой, 5к1, адрес УИК: Героев Панфиловцев ул, дом 8, корп. 1	f	large
81145	55611	305	Москва, Флотская , 64	f	large
81144	55611	304	Москва, Флотская , 64	f	large
81285	55714	446	Москва, Флотская, 15к1	f	large
83561	57120	2743	Москва, Филевский бульвар, 11а	f	large
83560	57119	2742	Москва, Филевский бульвар, 13к1	f	large
83559	57119	2741	Москва, Филевский бульвар, 13к1	f	large
83558	57118	2740	Москва, Филевский бульвар, 3	f	large
83557	57118	2739	Москва, Филевский бульвар, 3	f	large
81287	55716	448	Москва, Фестивальная улица, 16	f	large
81296	55722	457	Москва, Фестивальная, 67	f	large
81291	55720	452	Москва, Фестивальная, 51, адрес УИК: Лавочкина ул, дом 46, корп. 1	f	large
81292	55720	453	Москва, Фестивальная, 51, адрес УИК: Лавочкина ул, дом 46, корп. 1	f	large
81290	55718	451	Москва, Фестивальная, 69	f	large
81295	55718	456	Москва, Фестивальная, 69	f	large
81288	55717	449	Москва, Фестивальная, 16, УИК: Фестивальная ул, дом 14	f	large
81233	55669	394	Москва, Фестивальная, 4к2	f	large
81151	55616	311	Москва, Фестивальная, 42	f	large
82104	56220	1269	Москва, Ферганский проезд, 5к2	f	large
82102	56220	1267	Москва, Ферганский проезд, 5к2	f	large
82103	56220	1268	Москва, Ферганский проезд, 5к2	f	large
82101	56219	1266	Москва, Ферганский проезд, 10к4	f	large
82100	56219	1265	Москва, Ферганский проезд, 10к4	f	large
82099	56218	1264	Москва, Ферганский проезд, 10к5	f	large
82098	56218	1263	Москва, Ферганский проезд, 10к5	f	large
82097	56218	1262	Москва, Ферганский проезд, 10к5	f	large
82078	56206	1243	Москва, Ферганская, 7	f	large
82077	56206	1242	Москва, Ферганская, 7	f	large
82076	56206	1241	Москва, Ферганская, 7	f	large
83074	56807	2253	Москва, Феодосийская, 11а	f	large
83073	56807	2252	Москва, Феодосийская, 11а	f	large
83376	56995	2557	Москва, Федосьино, 16к3	f	large
83375	56994	2556	Москва, Федосьино, 4к2	f	large
83374	56993	2555	Москва, Федосьино, 4к2, УИК: Боровское шоссе, дом 48, корп. 1	f	large
81676	55952	838	Москва, Федоскинская , 4	f	large
81675	55952	837	Москва, Федоскинская , 4	f	large
82142	56244	1308	Москва, Федора Полетаева, 2к8	f	large
81978	56133	1143	Москва, Федеративный проспект, 11	f	large
81977	56132	1142	Москва, Федеративный проспект, 1а	f	large
81976	56132	1141	Москва, Федеративный проспект, 1а	f	large
81913	56100	1077	Москва, Федеративный проспект, 27	f	large
81914	56099	1078	Москва, Федеративный проспект, 29а	f	large
81912	56099	1076	Москва, Федеративный проспект, 29а	f	large
81831	56037	994	Москва, Федеративный проспект, 37а	f	large
81830	56037	993	Москва, Федеративный проспект, 37а	f	large
80989	55477	148	Москва, Фадеева, 4, УИК: Долгоруковская ул, дом 5	f	large
83826	57281	3013	Москва, Фабрициуса, 21	f	large
83825	57281	3012	Москва, Фабрициуса, 21	f	large
83823	57279	3010	Москва, Фабрициуса, 26, УИК: Лодочная ул, дом 3	f	large
83820	57277	3007	Москва, Фабрициуса, 6к2	f	large
83819	57277	3006	Москва, Фабрициуса, 6к2	f	large
83822	57276	3009	Москва, Фабрициуса, 10к1	f	large
83818	57276	3005	Москва, Фабрициуса, 10к1	f	large
81173	55630	333	Москва, Учинская улица, 10	f	large
81172	55630	332	Москва, Учинская улица, 10	f	large
82188	56277	1355	Москва, Ухтомская, 21	f	large
81902	56093	1066	Москва, Утренняя, 12	f	large
81791	56018	954	Москва, Уссурийская улица, 12	f	large
81790	56018	953	Москва, Уссурийская улица, 12	f	large
81051	55540	210	Москва, Усиевича, 6, УИК: Усиевича ул, дом 12/14	f	large
81046	55534	205	Москва, Усиевича, 31К3	f	large
81028	55517	187	Москва, Усачева улица, 66а	f	large
81030	55519	189	Москва, Усачева, 50	f	large
81773	56009	936	Москва, Уральская, 19	f	large
81772	56009	935	Москва, Уральская, 19	f	large
82905	56694	2084	Москва, Университетский проспект, 7	f	large
82906	56693	2085	Москва, Университетский проспект, 3	f	large
82904	56693	2083	Москва, Университетский проспект, 3	f	large
83735	57218	2920	Москва, Таллинская улица, 16к4	f	large
82903	56692	2082	Москва, Университетский проспект, 4а, УИК: Университетский просп, дом 4	f	large
83269	56929	2450	Москва, Украинский бульвар, 9	f	large
83268	56929	2449	Москва, Украинский бульвар, 9	f	large
83472	57061	2654	Москва, Удальцова, 87к1	f	large
83473	57060	2655	Москва, Удальцова, 87к1	f	large
83471	57060	2653	Москва, Удальцова, 87к1	f	large
83443	57042	2625	Москва, Удальцова, 40	f	large
83438	57039	2620	Москва, Удальцова, 21	f	large
83437	57039	2619	Москва, Удальцова, 21	f	large
83429	57032	2611	Москва, Удальцова, 67	f	large
81446	55819	608	Москва, Угличская , 17	f	large
81445	55819	607	Москва, Угличская , 17	f	large
81462	55827	624	Москва, Угличская, 6а	f	large
81461	55827	623	Москва, Угличская, 6а	f	large
83596	57142	2779	Москва, Уваровский переулок, 8	f	large
83595	57142	2778	Москва, Уваровский переулок, 8	f	large
83652	57174	2836	Москва, Тушинская улица, 2	f	large
83651	57174	2834	Москва, Тушинская улица, 2	f	large
83650	57171	2833	Москва, Тушинская, 7, адрес УИК: Свободы ул, дом 5/5	f	large
83647	57171	2830	Москва, Тушинская, 7, адрес УИК: Свободы ул, дом 5/5	f	large
83831	57285	3018	Москва, Туристская улица, 11к2	f	large
83832	57286	3019	Москва, Туристская , 11к2	f	large
83676	57189	2860	Москва, Туристская, 16к2	f	large
83675	57189	2859	Москва, Туристская, 16к2	f	large
83661	57180	2845	Москва, Туристская, 31к1	f	large
83660	57178	2844	Москва, Туристская, 19к5	f	large
83657	57178	2841	Москва, Туристская, 19к5	f	large
82420	56420	1589	Москва, Трофимова, 15а	f	large
82419	56419	1588	Москва, Трофимова, 15а, УИК: Трофимова ул, дом 11	f	large
82416	56415	1585	Москва, Трофимова, 27к2	f	large
82412	56412	1581	Москва, Трофимова, 13а	f	large
82411	56411	1580	Москва, Трофимова, 13а	f	large
80919	55419	73	Москва, Трифоновская, 57а	f	large
83352	56978	2533	Москва, Толбухина, 10к4	f	large
83351	56977	2532	Москва, Толбухина, 7к3	f	large
83348	56977	2529	Москва, Толбухина, 7к3	f	large
80870	55376	23	Москва, Токмаков переулок, 8	f	large
80958	55453	117	Москва, Товарищеский переулок, 21, УИК: Рогожский Б. пер, дом 10, корп. 2	f	large
82030	56168	1195	Москва, Ткацкая улица, 28/14	f	large
82031	56169	1196	Москва, Ткацкая, 47	f	large
82212	56291	1379	Москва, Тихорецкий бульвар, 8а	f	large
82211	56291	1378	Москва, Тихорецкий бульвар, 8а	f	large
82208	56288	1375	Москва, Тихорецкий бульвар, 10	f	large
82207	56288	1374	Москва, Тихорецкий бульвар, 10	f	large
81610	55914	772	Москва, Тихомирова, 6	f	large
81609	55914	771	Москва, Тихомирова, 6	f	large
81002	55490	161	Москва, Тихвинский переулок, 3, УИК: Тихвинский пер, дом 7, стр. 2	f	large
82191	56279	1358	Москва, Тихая улица, 23	f	large
83143	56855	2322	Москва, Типографская, 10с1	f	large
81017	55506	176	Москва, Тимура Фрунзе, 3с1, УИК: Фрунзенская наб, дом 10а	f	large
81015	55504	174	Москва, Тимура Фрунзе, 3с1, УИК: Зубовский пр, дом 2, стр. 1	f	large
81271	55703	432	Москва, Тимирязевская улица, 28	f	large
81284	55702	445	Москва, Тимирязевская, 14а	f	large
81270	55702	431	Москва, Тимирязевская, 14а	f	large
83105	56825	2284	Москва, Теплый Стан, 3к1	f	large
83099	56821	2278	Москва, Теплый Стан, 25А	f	large
83098	56821	2277	Москва, Теплый Стан, 25А	f	large
83097	56821	2276	Москва, Теплый Стан, 25А	f	large
83096	56820	2275	Москва, Теплый Стан, 25а, УИК: Варги академика ул, дом 3	f	large
83093	56816	2272	Москва, Теплый Стан, 13к3	f	large
83092	56816	2271	Москва, Теплый Стан, 13к3	f	large
83089	56815	2268	Москва, Теплый Стан, 13к4	f	large
83091	56815	2270	Москва, Теплый Стан, 13к4	f	large
83090	56815	2269	Москва, Теплый Стан, 13к4	f	large
83083	56812	2262	Москва, Теплый Стан, 4	f	large
81600	55909	762	Москва, Тенистый проезд, 8	f	large
81599	55909	761	Москва, Тенистый проезд, 8	f	large
111589	57391	3186	Москва, Твардовского, 20, СОШ № 1295	f	\N
83729	57216	2914	Москва, Твардовского, 20	f	large
83728	57216	2913	Москва, Твардовского, 20	f	large
82085	56210	1250	Москва, Ташкентский переулок, 7к3	f	large
82084	56210	1249	Москва, Ташкентский переулок, 7к3	f	large
82081	56207	1246	Москва, Ташкентская улица, 6	f	large
82080	56207	1245	Москва, Ташкентская улица, 6	f	large
82079	56207	1244	Москва, Ташкентская улица, 6	f	large
82087	56211	1252	Москва, Ташкентская , 18к3	f	large
82086	56211	1251	Москва, Ташкентская , 18к3	f	large
82095	56216	1260	Москва, Ташкентская, 21к2	f	large
82094	56216	1259	Москва, Ташкентская, 21к2	f	large
83734	57218	2919	Москва, Таллинская улица, 16к4	f	large
83733	57218	2918	Москва, Таллинская улица, 16к4	f	large
83738	57219	2923	Москва, Таллинская, 20к4	f	large
83737	57219	2922	Москва, Таллинская, 20к4	f	large
83736	57219	2921	Москва, Таллинская, 20к4	f	large
83732	57217	2917	Москва, Таллинская, 12к4	f	large
83731	57217	2916	Москва, Таллинская, 12к4	f	large
83730	57217	2915	Москва, Таллинская, 12к4	f	large
81184	55636	344	Москва, Талдомская , 13а	f	large
81183	55636	343	Москва, Талдомская , 13а	f	large
80973	55463	132	Москва, Талалихина, 20с1	f	large
80972	55463	131	Москва, Талалихина, 20с1	f	large
80971	55462	130	Москва, Талалихина, 33С1, УИК: Талалихина ул, дом 39	f	large
81478	55834	640	Москва, Тайнинская, 15к3	f	large
111574	57376	3171	Москва, Таймырская , 3	f	\N
81481	55836	643	Москва, Таймырская , 3	f	large
81484	55838	646	Москва, Таймырская, 4	f	large
81483	55838	645	Москва, Таймырская, 4	f	large
81482	55837	644	Москва, Таймырская, 5	f	large
83824	57280	3011	Москва, Сходненская улица, 15	f	large
83829	57283	3016	Москва, Сходненская , 35	f	large
83828	57283	3015	Москва, Сходненская , 35	f	large
81654	55936	816	Москва, Сухонская улица, 3	f	large
81653	55936	815	Москва, Сухонская улица, 3	f	large
81652	55936	814	Москва, Сухонская улица, 3	f	large
81605	55912	767	Москва, Сухонская улица, 13	f	large
81604	55912	766	Москва, Сухонская улица, 13	f	large
82797	56623	1974	Москва, Сумской проезд, 19а	f	large
82796	56623	1973	Москва, Сумской проезд, 19а	f	large
82779	56616	1956	Москва, Сумской проезд, 12к6	f	large
82778	56616	1955	Москва, Сумской проезд, 12к6	f	large
82777	56616	1954	Москва, Сумской проезд, 12к6	f	large
81927	56107	1092	Москва, Суздальская улица, 24б	f	large
81926	56107	1091	Москва, Суздальская улица, 24б	f	large
81925	56106	1090	Москва, Суздальская улица, 22б	f	large
81924	56106	1089	Москва, Суздальская улица, 22б	f	large
81923	56106	1088	Москва, Суздальская улица, 22б	f	large
81922	56104	1087	Москва, Суздальская, 12	f	large
81921	56104	1086	Москва, Суздальская, 12	f	large
82651	56553	1825	Москва, Судостроительная улица, 10к1	f	large
82642	56545	1816	Москва, Судостроительная улица, 32к3	f	large
82641	56544	1815	Москва, Судостроительная улица, 32к3	f	large
82640	56543	1814	Москва, Судостроительная улица, 46к2	f	large
82650	56552	1824	Москва, Судостроительная, 10к1	f	large
82639	56542	1813	Москва, Судостроительная, 44, Речников ул, дом 18, корп. 2	f	large
82636	56540	1810	Москва, Судостроительная, 43к2	f	large
82631	56535	1805	Москва, Судостроительная, 31к2, УИК: Судостроительная ул, дом 27, корп. 2	f	large
82630	56534	1804	Москва, Судостроительная, 31к2, УИК: Кленовый бульв, дом 7	f	large
82231	56303	1398	Москва, Судакова, 18а	f	large
82220	56296	1387	Москва, Судакова, 25	f	large
82219	56295	1386	Москва, Судакова, 29	f	large
83257	56919	2438	Москва, Студенческая , 29	f	large
83255	56919	2436	Москва, Студенческая , 29	f	large
83256	56920	2437	Москва, Студенческая, 29, УИК: Студенческая ул, дом 25	f	large
83253	56917	2434	Москва, Студенческая, 24	f	large
83252	56917	2433	Москва, Студенческая, 24	f	large
82068	56202	1233	Москва, Стромынка, 17	f	large
82069	56202	1234	Москва, Стромынка, 17	f	large
83009	56763	2188	Москва, Строителей, 15	f	large
83725	57215	2910	Москва, Строгинский бульвар, 14к5	f	large
83726	57215	2911	Москва, Строгинский бульвар, 14к5	f	large
83727	57215	2912	Москва, Строгинский бульвар, 14к5	f	large
83713	57210	2898	Москва, Строгинский бульвар, 7К3	f	large
80897	55401	51	Москва, Стремянный переулок, 28	f	large
82189	56278	1356	Москва, Сторожевая, 22к1	f	large
80938	55437	96	Москва, Столярный переулок, 16с1	f	large
80925	55426	79	Москва, Столовый переулок, 10/2с1	f	large
82241	56308	1408	Москва, Степана Шутова, 8к3	f	large
82240	56308	1407	Москва, Степана Шутова, 8к3	f	large
81480	55835	642	Москва, Стартовая, 27к3	f	large
81479	55835	641	Москва, Стартовая, 27к3	f	large
82058	56195	1223	Москва, Старослободская, 8	f	large
80995	55483	154	Москва, Старопименовский переулок, 5	f	large
81510	55854	672	Москва, Старомарьинское шоссе, 5	f	large
81509	55854	671	Москва, Старомарьинское шоссе, 5	f	large
81508	55854	670	Москва, Старомарьинское шоссе, 5	f	large
82621	56525	1795	Москва, Старокаширское шоссе, 2к11	f	large
82620	56525	1794	Москва, Старокаширское шоссе, 2к11	f	large
83066	56803	2245	Москва, Старокачаловская, 22	f	large
81381	55782	543	Москва, Староватутинский проезд, 8к1	f	large
81377	55780	539	Москва, Староватутинский проезд, 6с2	f	large
81334	55753	496	Москва, Староалексеевская, 3	f	large
80869	55375	22	Москва, Старая Басманная, 35, УИК: Басманный 1-й пер, дом 12	f	large
81347	55763	509	Москва, Стандартная улица, 2	f	large
81348	55764	510	Москва, Стандартная, 4а	f	large
81828	56035	991	Москва, Сталеваров, 20а	f	large
81827	56035	990	Москва, Сталеваров, 20а	f	large
81826	56035	989	Москва, Сталеваров, 20а	f	large
81825	56034	988	Москва, Сталеваров, 16а	f	large
81824	56034	987	Москва, Сталеваров, 16а	f	large
81823	56034	986	Москва, Сталеваров, 16а	f	large
81821	56032	984	Москва, Сталеваров, 10а	f	large
81820	56032	983	Москва, Сталеваров, 10а	f	large
81819	56032	982	Москва, Сталеваров, 10а	f	large
82193	56281	1360	Москва, Ставропольская , 16	f	large
82202	56281	1369	Москва, Ставропольская , 16	f	large
82210	56290	1377	Москва, Ставропольская, 54к3	f	large
82209	56290	1376	Москва, Ставропольская, 54к3	f	large
82204	56286	1371	Москва, Ставропольская, 20	f	large
82203	56286	1370	Москва, Ставропольская, 20	f	large
80900	55403	54	Москва, Сретенка, 20	f	large
81871	56068	1034	Москва, Средняя Первомайская, 8	f	large
81870	56068	1033	Москва, Средняя Первомайская, 8	f	large
80970	55461	129	Москва, Средняя Калитниковская, 22с3	f	large
80969	55461	128	Москва, Средняя Калитниковская, 22с3	f	large
80933	55433	91	Москва, Средний Тишинский переулок, 5/7с1	f	large
82198	56283	1365	Москва, Спортивный проезд, 3с2	f	large
82197	56283	1364	Москва, Спортивный проезд, 3с2	f	large
82196	56283	1363	Москва, Спортивный проезд, 3с2	f	large
81909	56095	1073	Москва, Союзный проспект, 2	f	large
81908	56095	1072	Москва, Союзный проспект, 2	f	large
81905	56095	1069	Москва, Союзный проспект, 2	f	large
81175	55631	335	Москва, Софьи Ковалевской, 8а	f	large
81174	55631	334	Москва, Софьи Ковалевской, 8а	f	large
81170	55628	330	Москва, Софьи Ковалевской, 18а	f	large
83228	56903	2408	Москва, Соловьиный проезд, 16к2	f	large
83215	56896	2395	Москва, Соловьиный проезд, 4к3	f	large
83214	56895	2394	Москва, Соловьиный проезд, 4к2	f	large
83213	56895	2393	Москва, Соловьиный проезд, 4к2	f	large
83495	57076	2677	Москва, Солнцевский проспект, 7а	f	large
83494	57076	2676	Москва, Солнцевский проспект, 7а	f	large
83492	57074	2674	Москва, Солнцевский проспект, 16А	f	large
83490	57073	2672	Москва, Солнцевский проспект, 12а	f	large
83491	57073	2673	Москва, Солнцевский проспект, 12а	f	large
81149	55614	309	Москва, Солнечногорский проезд, 7а	f	large
81154	55619	314	Москва, Солнечногорская, 4с1	f	large
82184	56274	1351	Москва, Солдатская, 14	f	large
82060	56196	1225	Москва, Сокольническая площадь, 7	f	large
83594	57141	2777	Москва, Соколово-Мещерская улица, 27к1	f	large
82227	56300	1394	Москва, Совхозная улица, 2а	f	large
81496	55846	658	Москва, Советской Армии, 9	f	large
81495	55846	657	Москва, Советской Армии, 9	f	large
83298	56946	2479	Москва, Советская, 11а	f	large
111549	56911	2425	Москва, Советская, 1с1	f	medium
81204	55648	364	Москва, Соболевский проезд, 17а	f	large
81594	55904	756	Москва, Снежная, 4	f	large
81737	55986	900	Москва, Снайперская улица, 4а	f	large
81736	55986	899	Москва, Снайперская улица, 4а	f	large
81735	55985	898	Москва, Снайперская, 11а	f	large
81734	55985	897	Москва, Снайперская, 11а	f	large
81141	55609	301	Москва, Смольная улица, 10	f	large
81231	55667	391	Москва, Смольная , 37а	f	large
81140	55608	300	Москва, Смольная , 25	f	large
81232	55668	393	Москва, Смольная, 37а, адрес УИК: Смольная ул, дом 39	f	large
83577	57131	2760	Москва, Славянский бульвар, 11к3	f	large
83576	57131	2759	Москва, Славянский бульвар, 11к3	f	large
80902	55405	56	Москва, Скорняжный переулок, 3с1	f	large
80903	55405	57	Москва, Скорняжный переулок, 3с1	f	large
83158	56864	2337	Москва, Скобелевская, 30	f	large
83157	56864	2336	Москва, Скобелевская, 30	f	large
83156	56863	2335	Москва, Скобелевская, 28	f	large
81060	55549	220	Москва, Скаковая улица, 20с1	f	large
81059	55548	219	Москва, Скаковая, 20с1, УИК: Скаковая ул, дом 17	f	large
82025	56163	1190	Москва, Сиреневый бульвар, 73к3	f	large
82024	56163	1189	Москва, Сиреневый бульвар, 73к3	f	large
82018	56159	1183	Москва, Сиреневый бульвар, 55	f	large
82017	56159	1182	Москва, Сиреневый бульвар, 55	f	large
82005	56150	1170	Москва, Сиреневый бульвар, 9	f	large
81866	56065	1029	Москва, Сиреневый бульвар, 30с1	f	large
81864	56063	1027	Москва, Сиреневый бульвар, 20	f	large
81843	56044	1006	Москва, Сиреневый бульвар, 4г	f	large
81842	56044	1005	Москва, Сиреневый бульвар, 4г	f	large
81841	56043	1004	Москва, Сиреневый бульвар, 4	f	large
81751	55994	914	Москва, Сиреневый бульвар, 68	f	large
81750	55994	913	Москва, Сиреневый бульвар, 68	f	large
81749	55993	912	Москва, Сиреневый бульвар, 58а	f	large
81748	55993	911	Москва, Сиреневый бульвар, 58а	f	large
81747	55993	910	Москва, Сиреневый бульвар, 58а	f	large
82671	56563	1846	Москва, Симферопольский бульвар, 23а	f	large
82667	56563	1842	Москва, Симферопольский бульвар, 23а	f	large
82526	56477	1696	Москва, Симоновский Вал, 18а	f	large
82527	56477	1697	Москва, Симоновский Вал, 18а	f	large
82939	56717	2118	Москва, Сивашская, 2к1	f	large
82940	56716	2119	Москва, Сивашская, 2к1, Адрес УИК: Фруктовая ул, дом 18	f	large
82938	56716	2117	Москва, Сивашская, 2к1, Адрес УИК: Фруктовая ул, дом 18	f	large
81032	55521	191	Москва, Серафимовича, 2	f	large
80881	55386	34	Москва, Семеновская набережная, 3/1к5	f	large
111579	57381	3176	Москва, Сельскохозяйственная, 15к1, Гостиница «Байкал»	f	\N
81579	55892	741	Москва, Сельскохозяйственная, 20к1	f	large
81577	55892	739	Москва, Сельскохозяйственная, 20к1	f	large
81597	55907	759	Москва, Седова, 4К1	f	large
81596	55906	758	Москва, Седова, 12	f	large
81593	55903	755	Москва, Седова, 4к1	f	large
82795	56621	1972	Москва, Северный бульвар, 21а	f	large
82794	56621	1971	Москва, Северный бульвар, 21а	f	large
82793	56621	1970	Москва, Северный бульвар, 21а	f	large
81564	55884	726	Москва, Северный бульвар, 4а	f	large
81562	55884	724	Москва, Северный бульвар, 4а	f	large
81551	55878	713	Москва, Северный бульвар, 11	f	large
81549	55878	711	Москва, Северный бульвар, 11	f	large
81547	55874	709	Москва, Северный бульвар, 1а	f	large
81541	55874	703	Москва, Северный бульвар, 1а	f	large
83008	56762	2187	Москва, Севастопольский проспект, 51к5	f	large
83007	56761	2186	Москва, Севастопольский проспект, 43а	f	large
82997	56756	2176	Москва, Севастопольский проспект, 11а	f	large
82996	56755	2175	Москва, Севастопольский проспект, 20а	f	large
82547	56490	1720	Москва, Севастопольский проспект, 5а	f	large
82546	56490	1719	Москва, Севастопольский проспект, 5а	f	large
82767	56610	1943	Москва, Севанская улица, 13к2	f	large
82766	56610	1942	Москва, Севанская улица, 13к2	f	large
82763	56608	1939	Москва, Севанская, 6	f	large
82762	56608	1938	Москва, Севанская, 6	f	large
82761	56608	1937	Москва, Севанская, 6	f	large
82760	56608	1936	Москва, Севанская, 6	f	large
81882	56079	1045	Москва, Святоозерская, 17	f	large
83817	57275	3004	Москва, Свободы, 45с1	f	large
83816	57274	3003	Москва, Свободы, 42к2	f	large
83813	57272	3000	Москва, Свободы, 37	f	large
83694	57201	2878	Москва, Свободы, 91	f	large
83693	57201	2877	Москва, Свободы, 91	f	large
83692	57200	2876	Москва, Свободы, 81к1, УИК: Свободы ул, дом 81, корп. 2	f	large
83690	57199	2874	Москва, Свободы, 81к6	f	large
83691	57199	2875	Москва, Свободы, 81к6	f	large
83686	57196	2870	Москва, Свободы, 81к1	f	large
83685	57196	2869	Москва, Свободы, 81к1	f	large
81255	55688	416	Москва, Светлый проезд, 2а	f	large
83838	57289	3025	Москва, Светлогорский проезд, 7	f	large
83837	57289	3024	Москва, Светлогорский проезд, 7	f	large
81808	56025	971	Москва, Саянская улица, 3а	f	large
81807	56025	970	Москва, Саянская улица, 3а	f	large
81815	56029	978	Москва, Саянская, 6б	f	large
82383	56390	1551	Москва, Саратовская улица, 16	f	large
82384	56391	1552	Москва, Саратовская, 21ас1	f	large
82381	56388	1549	Москва, Саратовская, 1к2	f	large
81533	55870	695	Москва, Санникова, 3к3	f	large
81532	55870	694	Москва, Санникова, 3к3	f	large
83048	56794	2227	Москва, Саморы Машела, 6к3	f	large
83047	56794	2226	Москва, Саморы Машела, 6к3	f	large
82096	56217	1261	Москва, Самаркандский бульвар, 28к2	f	large
81251	55684	412	Москва, Сальвадора Альенде, 6, УИК: Алабяна ул, дом 15	f	large
81250	55683	411	Москва, Сальвадора Альенде, 9, УИК: Новопесчаная ул, дом 24	f	large
81943	56114	1108	Москва, Салтыковская улица, 5а	f	large
81942	56114	1107	Москва, Салтыковская улица, 5а	f	large
81941	56113	1106	Москва, Салтыковская, 13а	f	large
81940	56113	1105	Москва, Салтыковская, 13а	f	large
81939	56113	1104	Москва, Салтыковская, 13а	f	large
81937	56112	1102	Москва, Салтыковская, 13б	f	large
80911	55412	65	Москва, Садовая-Сухаревская, 12а	f	large
80901	55404	55	Москва, Садовая-Спасская улица, 8с1	f	large
82351	56370	1519	Москва, Рязанский проспект, 39с4	f	large
82350	56370	1518	Москва, Рязанский проспект, 39с4	f	large
82083	56208	1248	Москва, Рязанский проспект, 82к4	f	large
82082	56208	1247	Москва, Рязанский проспект, 82к4	f	large
82075	56205	1240	Москва, Рязанский проспект, 68к2	f	large
82074	56205	1239	Москва, Рязанский проспект, 68к2	f	large
82073	56204	1238	Москва, Рязанский проспект, 99	f	large
82437	56429	1606	Москва, Ряжская, 13к2	f	large
82436	56429	1605	Москва, Ряжская, 13к2	f	large
83334	56970	2515	Москва, Рябиновая, 8к2	f	large
81426	55807	588	Москва, Руставели, 2	f	large
80906	55407	60	Москва, Русаковская улица, 10с1	f	large
81366	55774	528	Москва, Рудневой, 10	f	large
81881	56078	1044	Москва, Рудневка, 10	f	large
80879	55384	32	Москва, Рубцов переулок, 10/14	f	large
83301	56948	2482	Москва, Рублевское шоссе, 24к4	f	large
83300	56942	2481	Москва, Рублевское шоссе, 24к3	f	large
83292	56942	2473	Москва, Рублевское шоссе, 24к3	f	large
81661	55941	823	Москва, Ротерта, 5	f	large
81583	55896	745	Москва, Ростокинская, 7	f	large
81584	55895	746	Москва, Ростокинская, 3	f	large
81582	55895	744	Москва, Ростокинская, 3	f	large
82855	56657	2033	Москва, Россошанский проезд, 3а	f	large
82854	56657	2032	Москва, Россошанский проезд, 3а	f	large
83502	57081	2684	Москва, Родниковая, 20к1	f	large
83501	57081	2683	Москва, Родниковая, 20к1	f	large
83591	57139	2774	Москва, Родионовская улица, 8	f	large
83590	57079	2773	Москва, Родионовская, 6/7	f	large
83800	57265	2987	Москва, Рогова, 1	f	large
83801	57265	2988	Москва, Рогова, 1	f	large
81721	55977	884	Москва, Реутовская, 16а	f	large
81720	55977	883	Москва, Реутовская, 16а	f	large
81719	55977	882	Москва, Реутовская, 16а	f	large
81714	55974	877	Москва, Реутовская, 2а	f	large
81713	55974	876	Москва, Реутовская, 2а	f	large
81712	55974	875	Москва, Реутовская, 2а	f	large
83003	56758	2182	Москва, Ремизова, 12	f	large
83001	56758	2180	Москва, Ремизова, 12	f	large
83254	56918	2435	Москва, Резервный проезд, 10, УИК: Студенческая ул, дом 25	f	large
83365	56987	2546	Москва, Ращупкина, 3	f	large
83364	56987	2545	Москва, Ращупкина, 3	f	large
83363	56987	2544	Москва, Ращупкина, 3	f	large
83065	56802	2244	Москва, Ратная улица, 6а	f	large
83064	56802	2243	Москва, Ратная улица, 6а	f	large
83052	56796	2231	Москва, Ратная улица, 14а	f	large
83050	56796	2229	Москва, Ратная улица, 14а	f	large
83063	56801	2242	Москва, Ратная, 6б	f	large
83051	56797	2230	Москва, Ратная, 14а, УИК: Ратная ул, дом 8В	f	large
81064	55552	224	Москва, Расковой, 14	f	large
81063	55539	223	Москва, Расковой, 4	f	large
83469	57059	2651	Москва, Раменки, 15к1	f	large
83468	57059	2650	Москва, Раменки, 15к1	f	large
83470	57058	2652	Москва, Раменки, 15к2	f	large
83466	57058	2648	Москва, Раменки, 15к2	f	large
83467	57058	2649	Москва, Раменки, 15к2	f	large
83465	57057	2647	Москва, Раменки, 4	f	large
81362	55770	524	Москва, Радужная улица, 7	f	large
81360	55770	522	Москва, Радужная улица, 7	f	large
81359	55770	521	Москва, Радужная улица, 7	f	large
81358	55770	520	Москва, Радужная улица, 7	f	large
81361	55771	523	Москва, Радужная, 13	f	large
80866	55372	19	Москва, Радио, 6/4с1, УИК: Сыромятнический 4-й пер, дом 3/5, стр.4	f	large
80963	55457	122	Москва, Рабочая, 12с1	f	large
111585	57387	3182	Москва, Пятницкое шоссе, 18	f	\N
83638	57164	2821	Москва, Пятницкое шоссе, 16к5	f	large
83637	57164	2820	Москва, Пятницкое шоссе, 16к5	f	large
83635	57162	2818	Москва, Пятницкое шоссе, 25к3	f	large
83634	57162	2817	Москва, Пятницкое шоссе, 25к3	f	large
83633	57162	2816	Москва, Пятницкое шоссе, 25к3	f	large
83626	57159	2809	Москва, Пятницкое шоссе, 42к2	f	large
83627	57159	2810	Москва, Пятницкое шоссе, 42к2	f	large
83625	57158	2808	Москва, Пятницкое шоссе, 45к2	f	large
83624	57158	2807	Москва, Пятницкое шоссе, 45к2	f	large
80888	55393	41	Москва, Пятницкая, 46с3	f	large
83450	57044	2632	Москва, Пырьева, 11	f	large
83448	57044	2630	Москва, Пырьева, 11	f	large
83447	57044	2629	Москва, Пырьева, 11	f	large
81345	55761	507	Москва, Путевой проезд, 10а	f	large
81344	55760	506	Москва, Путевой проезд, 10а	f	large
81343	55760	505	Москва, Путевой проезд, 10а	f	large
81135	55605	295	Москва, Пулковская улица, 6ас3	f	large
81442	55817	604	Москва, Псковская , 11	f	large
81444	55818	606	Москва, Псковская, 12к3	f	large
83088	56814	2267	Москва, Профсоюзная улица, 156к6	f	large
83087	56814	2266	Москва, Профсоюзная улица, 156к6	f	large
83086	56814	2265	Москва, Профсоюзная улица, 156к6	f	large
82954	56727	2133	Москва, Профсоюзная , 98а, УИК: Профсоюзная ул, дом 98, корп. 1	f	large
111548	56894	2392	Москва, Профсоюзная, 123ас1	f	small
83115	56834	2294	Москва, Профсоюзная, 25к4	f	large
83111	56830	2290	Москва, Профсоюзная, 40к2	f	large
83110	56830	2289	Москва, Профсоюзная, 40к2	f	large
83082	56811	2261	Москва, Профсоюзная, 142к5	f	large
83081	56811	2260	Москва, Профсоюзная, 142к5	f	large
83079	56810	2258	Москва, Профсоюзная, 132к9	f	large
83080	56809	2259	Москва, Профсоюзная, 132к9	f	large
83078	56809	2257	Москва, Профсоюзная, 132к9	f	large
83033	56783	2212	Москва, Профсоюзная, 62	f	large
83032	56783	2211	Москва, Профсоюзная, 62	f	large
82992	56751	2171	Москва, Профсоюзная, 118б	f	large
82991	56751	2170	Москва, Профсоюзная, 118б	f	large
82989	56751	2168	Москва, Профсоюзная, 118б	f	large
82979	56744	2158	Москва, Профсоюзная, 115к1	f	large
82973	56740	2152	Москва, Профсоюзная, 97к1, адрес УИК: Введенского ул, дом 30, корпус 1	f	large
82965	56734	2144	Москва, Профсоюзная, 83б, УИК: Профсоюзная ул, дом 83, корп. 3	f	large
82956	56728	2135	Москва, Профсоюзная, 98а	f	large
82955	56728	2134	Москва, Профсоюзная, 98а	f	large
82953	56726	2132	Москва, Профсоюзная, 96б	f	large
82952	56726	2131	Москва, Профсоюзная, 96б	f	large
82889	56680	2068	Москва, Профсоюзная, 24к1	f	large
82888	56679	2067	Москва, Профсоюзная, 15а	f	large
82886	56677	2065	Москва, Профсоюзная, 9а	f	large
82885	56677	2064	Москва, Профсоюзная, 9а	f	large
80915	55415	69	Москва, Протопоповский переулок, 5	f	large
82106	56221	1271	Москва, Пронская , 4к1	f	large
82105	56221	1270	Москва, Пронская , 4к1	f	large
82582	56506	1755	Москва, Пролетарский проспект, 6к3	f	large
82583	56506	1756	Москва, Пролетарский проспект, 6к3	f	large
83504	57082	2686	Москва, Производственная улица, 3к2	f	large
83503	57082	2685	Москва, Производственная улица, 3к2	f	large
80954	55449	113	Москва, Причальный проезд, 7с1	f	large
80953	55449	112	Москва, Причальный проезд, 7с1	f	large
83380	56997	2561	Москва, Приречная , 3	f	large
83379	56997	2560	Москва, Приречная , 3	f	large
83378	56997	2559	Москва, Приречная , 3	f	large
83383	56998	2564	Москва, Приречная, 1	f	large
83382	56998	2563	Москва, Приречная, 1	f	large
83381	56998	2562	Москва, Приречная, 1	f	large
82118	56228	1283	Москва, Привольная улица, 45	f	large
82117	56227	1282	Москва, Привольная улица, 41	f	large
82114	56225	1279	Москва, Привольная улица, 37	f	large
82113	56225	1278	Москва, Привольная улица, 37	f	large
82108	56222	1273	Москва, Привольная, 17к1	f	large
82107	56222	1272	Москва, Привольная, 17к1	f	large
111598	57401	4007	Москва, Привокзальная площадь, с2, штаб строительства ОАО &quot;Трансстрой&quot;	f	medium
81228	55665	388	Москва, Прибрежный проезд, 12	f	large
81227	55665	387	Москва, Прибрежный проезд, 12	f	large
81005	55494	164	Москва, Пречистенка, 16	f	large
81067	55555	227	Москва, Правды, 1А	f	large
81066	55554	226	Москва, Правды, 21с1	f	large
81065	55553	225	Москва, Правды, 1а, адрес УИК: Ленинградский просп, дом 26	f	large
83833	57287	3020	Москва, Походный проезд, 23, УИК: Донелайтиса пр, дом 12, корп. 2	f	large
80859	55365	12	Москва, Потаповский переулок, 16с3, Чистопрудный бульв, дом 12/7	f	large
83162	56866	2341	Москва, Поляны, 53	f	large
83161	56866	2340	Москва, Поляны, 53	f	large
81248	55681	409	Москва, Полтавская, 3	f	large
83306	56951	2487	Москва, Полоцкая, 21	f	large
83304	56951	2485	Москва, Полоцкая, 21	f	large
81904	56094	1068	Москва, Полимерная , 7А	f	large
81903	56094	1067	Москва, Полимерная , 7А	f	large
81308	55731	470	Москва, Поликарпова, 3а	f	large
82345	56366	1513	Москва, Полбина, 68с1	f	large
82344	56366	1512	Москва, Полбина, 68с1	f	large
82343	56366	1511	Москва, Полбина, 68с1	f	large
82341	56364	1509	Москва, Полбина, 44	f	large
82340	56364	1508	Москва, Полбина, 44	f	large
82337	56364	1505	Москва, Полбина, 44	f	large
82336	56363	1504	Москва, Полбина, 38	f	large
82335	56363	1503	Москва, Полбина, 38	f	large
82332	56360	1500	Москва, Полбина, 18	f	large
82331	56360	1499	Москва, Полбина, 18	f	large
83260	56922	2441	Москва, Поклонная улица, 16	f	large
83259	56921	2440	Москва, Поклонная, 2, УИК: Кутузовский просп, дом 43	f	large
83258	56921	2439	Москва, Поклонная, 2, УИК: Кутузовский просп, дом 43	f	large
82853	56656	2031	Москва, Подольских Курсантов, 16ак1	f	large
82852	56656	2030	Москва, Подольских Курсантов, 16ак1	f	large
82851	56656	2029	Москва, Подольских Курсантов, 16ак1	f	large
82847	56654	2025	Москва, Подольских Курсантов, 18б	f	large
82846	56654	2024	Москва, Подольских Курсантов, 18б	f	large
82245	56310	1412	Москва, Подольская, 15	f	large
82243	56310	1410	Москва, Подольская, 15	f	large
82242	56310	1409	Москва, Подольская, 15	f	large
80950	55447	109	Москва, Подвойского, 2	f	large
80949	55447	108	Москва, Подвойского, 2	f	large
81948	56118	1113	Москва, Плющева, 11а	f	large
81949	56117	1114	Москва, Плющева, 13а	f	large
81947	56117	1112	Москва, Плющева, 13а	f	large
81946	56115	1111	Москва, Плющева, 14А	f	large
81944	56115	1109	Москва, Плющева, 14А	f	large
81395	55791	557	Москва, Плещеева, 26а	f	large
81394	55791	556	Москва, Плещеева, 26а	f	large
81056	55545	216	Москва, Планетная, 23, адрес УИК: Планетная ул, дом 11	f	large
111587	57389	3184	Москва, Планерная улица, 5	f	\N
83689	57198	2873	Москва, Планерная улица, 12к2	f	large
83688	57198	2872	Москва, Планерная улица, 12к2	f	large
83687	57197	2871	Москва, Планерная, 12к2	f	large
83671	57186	2855	Москва, Планерная, 5к2	f	large
83670	57186	2854	Москва, Планерная, 5к2	f	large
81246	55679	407	Москва, Писцовая, 7а	f	large
81243	55674	404	Москва, Писцовая, 14а, УИК: Полтавская ул, дом 18	f	large
81238	55674	399	Москва, Писцовая, 14а, УИК: Полтавская ул, дом 18	f	large
81368	55773	530	Москва, Печорская, 18	f	large
81367	55773	529	Москва, Печорская, 18	f	large
81364	55773	526	Москва, Печорская, 18	f	large
81294	55721	455	Москва, Петрозаводская, 19а	f	large
81293	55721	454	Москва, Петрозаводская, 19а	f	large
81249	55682	410	Москва, Петровско-Разумовский проезд, 9	f	large
81239	55672	400	Москва, Петровско-Разумовский проезд, 27	f	large
81236	55672	397	Москва, Петровско-Разумовский проезд, 27	f	large
81040	55529	199	Москва, Петровско-Разумовская аллея, 12ас1	f	large
80994	55482	153	Москва, Петровка, 23/10с21	f	large
82414	56414	1583	Москва, Петра Романова, 6	f	large
81259	55692	420	Москва, Песчаный переулок, 6, адрес УИК: Песчаная ул, дом 12	f	large
81260	55693	421	Москва, Песчаная, 5	f	large
81563	55883	725	Москва, Пестеля, 5	f	large
81561	55883	723	Москва, Пестеля, 5	f	large
82315	56349	1483	Москва, Перовское шоссе, 8	f	large
82314	56349	1482	Москва, Перовское шоссе, 8	f	large
81955	56120	1120	Москва, Перовская, 37	f	large
81954	56120	1119	Москва, Перовская, 37	f	large
81953	56120	1118	Москва, Перовская, 37	f	large
81952	56119	1117	Москва, Перовская, 24а	f	large
81950	56119	1115	Москва, Перовская, 24а	f	large
81951	56119	1116	Москва, Перовская, 24а	f	large
81901	56092	1065	Москва, Перовская, 57а	f	large
81900	56092	1064	Москва, Перовская, 57а	f	large
81899	56091	1063	Москва, Перовская, 44б	f	large
81898	56091	1062	Москва, Перовская, 44б	f	large
82306	56339	1473	Москва, Перервинский бульвар, 5к3	f	large
82299	56339	1466	Москва, Перервинский бульвар, 5к3	f	large
82296	56337	1463	Москва, Перервинский бульвар, 10к1	f	large
82295	56337	1462	Москва, Перервинский бульвар, 10к1	f	large
82294	56336	1461	Москва, Перервинский бульвар, 10к2	f	large
82293	56335	1460	Москва, Перервинский бульвар, 16к1	f	large
82292	56335	1459	Москва, Перервинский бульвар, 16к1	f	large
82291	56334	1458	Москва, Перервинский бульвар, 20к1	f	large
82283	56329	1450	Москва, Перерва, 41к2	f	large
82282	56329	1449	Москва, Перерва, 41к2	f	large
83131	56846	2310	Москва, Перекопская, 21, адрес УИК: Севастопольский просп, дом 30	f	large
83130	56845	2309	Москва, Перекопская, 21, УИК: Севастопольский просп, дом 30	f	large
83129	56844	2308	Москва, Перекопская, 28	f	large
83128	56844	2307	Москва, Перекопская, 28	f	large
82926	56709	2105	Москва, Перекопская, 7к3	f	large
82925	56708	2104	Москва, Перекопская, 7к3, УИК: Севастопольский просп, дом 71	f	large
80876	55382	29	Москва, Переведеновский переулок, 11, УИК: Бакунинская ул, дом 55	f	large
81859	56058	1022	Москва, Первомайская улица, 59	f	large
81869	56067	1032	Москва, Первомайская, 65	f	large
81850	56050	1013	Москва, Первомайская, 3К1	f	large
81849	56049	1012	Москва, Первомайская, 27а	f	large
81848	56049	1011	Москва, Первомайская, 27а	f	large
81760	55988	923	Москва, Первомайская, 78	f	large
81741	55988	904	Москва, Первомайская, 78	f	large
83602	57145	2785	Москва, Пенягинская, 14	f	large
83237	56907	2417	Москва, Паустовского, 5К2	f	large
83236	56907	2416	Москва, Паустовского, 5К2	f	large
83235	56907	2415	Москва, Паустовского, 5К2	f	large
83234	56906	2414	Москва, Паустовского, 5к3	f	large
83231	56904	2411	Москва, Паустовского, 6к2	f	large
83230	56904	2410	Москва, Паустовского, 6к2	f	large
83229	56904	2409	Москва, Паустовского, 6к2	f	large
83783	57252	2969	Москва, Паршина, 39	f	large
83777	57247	2963	Москва, Паршина, 4	f	large
83316	56959	2497	Москва, Партизанская улица, 30к2с2	f	large
83310	56955	2491	Москва, Партизанская улица, 7к3	f	large
83311	56953	2492	Москва, Партизанская , 11	f	large
83308	56953	2489	Москва, Партизанская , 11	f	large
83319	56961	2500	Москва, Партизанская, 45	f	large
83318	56960	2499	Москва, Партизанская, 39	f	large
83317	56960	2498	Москва, Партизанская, 39	f	large
83315	56958	2496	Москва, Партизанская, 30к2	f	large
83313	56956	2494	Москва, Партизанская, 30к2с2	f	large
83312	56956	2493	Москва, Партизанская, 30к2с2	f	large
82504	56465	1674	Москва, Паромная улица, 5к3	f	large
82503	56465	1673	Москва, Паромная улица, 5к3	f	large
82502	56465	1672	Москва, Паромная улица, 5к3	f	large
81253	55686	414	Москва, Панфилова, 6, адрес УИК: Панфилова ул, дом 4, корп.3	f	large
81678	55953	840	Москва, Палехская улица, 137	f	large
81677	55953	839	Москва, Палехская улица, 137	f	large
81673	55950	835	Москва, Палехская улица, 10	f	large
81674	55951	836	Москва, Палехская , 10	f	large
81672	55949	834	Москва, Палехская, 8	f	large
81671	55949	833	Москва, Палехская, 8	f	large
82519	56472	1689	Москва, Павловская, 8а	f	large
82518	56472	1688	Москва, Павловская, 8а	f	large
81331	55751	493	Москва, Павла Корчагина, 1а	f	large
81332	55751	494	Москва, Павла Корчагина, 1а	f	large
81328	55748	490	Москва, Павла Корчагина, 22ак2	f	large
81327	55748	489	Москва, Павла Корчагина, 22ак2	f	large
81326	55747	488	Москва, Павла Корчагина, 2	f	large
81325	55747	487	Москва, Павла Корчагина, 2	f	large
81324	55747	486	Москва, Павла Корчагина, 2	f	large
111593	57396	4002	Москва, Павелецкая площадь, 1ас2	f	medium
83415	57024	2596	Москва, Очаковское шоссе, 10к1	f	large
83414	57024	2595	Москва, Очаковское шоссе, 10к1	f	large
83413	57022	2594	Москва, Очаковское шоссе, 10к1	f	large
81568	55885	730	Москва, Отрадная улица, 1а	f	large
81567	55885	729	Москва, Отрадная улица, 1а	f	large
81566	55885	728	Москва, Отрадная улица, 1а	f	large
81565	55885	727	Москва, Отрадная улица, 1а	f	large
81572	55888	734	Москва, Отрадная, 11б	f	large
81571	55886	733	Москва, Отрадная, 11а	f	large
81569	55886	731	Москва, Отрадная, 11а	f	large
81897	56089	1060	Москва, Открытое шоссе, 24к35	f	large
81895	56088	1058	Москва, Открытое шоссе, 29а	f	large
81894	56087	1057	Москва, Открытое шоссе, 25	f	large
81893	56087	1056	Москва, Открытое шоссе, 25	f	large
81892	56086	1055	Москва, Открытое шоссе, 23а	f	large
81896	56086	1059	Москва, Открытое шоссе, 23а	f	large
81891	56085	1054	Москва, Открытое шоссе, 24к7	f	large
81890	56085	1053	Москва, Открытое шоссе, 24к7	f	large
81889	56084	1052	Москва, Открытое шоссе, 24к27	f	large
81888	56084	1051	Москва, Открытое шоссе, 24к27	f	large
81696	55966	859	Москва, Открытое шоссе, 6к12	f	large
81319	55742	481	Москва, Острякова, 15а, адрес УИК: Ленинградский просп, дом 57	f	large
83077	56808	2256	Москва, Островитянова, 18к5	f	large
83076	56808	2255	Москва, Островитянова, 18к5	f	large
83075	56808	2254	Москва, Островитянова, 18к5	f	large
82970	56737	2149	Москва, Островитянова, 53к4	f	large
82969	56737	2148	Москва, Островитянова, 53к4	f	large
81378	55781	540	Москва, Осташковская улица, 7к6	f	large
81622	55920	784	Москва, Осташковская, 30к2	f	large
81624	55920	786	Москва, Осташковская, 30к2	f	large
81623	55920	785	Москва, Осташковская, 30к2	f	large
83286	56939	2467	Москва, Осенняя улица, 8к1	f	large
83285	56939	2466	Москва, Осенняя улица, 8к1	f	large
83284	56939	2465	Москва, Осенняя улица, 8к1	f	large
83280	56936	2461	Москва, Осенний бульвар, 10к3	f	large
83279	56936	2460	Москва, Осенний бульвар, 10к3	f	large
83325	56965	2506	Москва, Оршанская улица, 10к2	f	large
83326	56964	2507	Москва, Оршанская , 10к1	f	large
83324	56964	2505	Москва, Оршанская , 10к1	f	large
82561	56481	1734	Москва, Ореховый проезд, 17к2	f	large
82560	56481	1733	Москва, Ореховый проезд, 17к2	f	large
82702	56579	1877	Москва, Ореховый бульвар, 3	f	large
82701	56579	1876	Москва, Ореховый бульвар, 3	f	large
82700	56579	1875	Москва, Ореховый бульвар, 3	f	large
82697	56577	1872	Москва, Ореховый бульвар, 11к3	f	large
82696	56577	1871	Москва, Ореховый бульвар, 11к3	f	large
82695	56577	1870	Москва, Ореховый бульвар, 11к3	f	large
82694	56576	1869	Москва, Ореховый бульвар, 21к2	f	large
82693	56576	1868	Москва, Ореховый бульвар, 21к2	f	large
82557	56495	1730	Москва, Ореховый бульвар, 35к3	f	large
82556	56495	1729	Москва, Ореховый бульвар, 35к3	f	large
82555	56495	1728	Москва, Ореховый бульвар, 35к3	f	large
82552	56493	1725	Москва, Ореховый бульвар, 37к4	f	large
82551	56493	1724	Москва, Ореховый бульвар, 37к4	f	large
82317	56350	1485	Москва, Орехово-Зуевский проезд, 4	f	large
82316	56350	1484	Москва, Орехово-Зуевский проезд, 4	f	large
81875	56072	1038	Москва, Оренбургская, 15	f	large
82540	56487	1712	Москва, Орджоникидзе, 15	f	large
81147	55601	307	Москва, Онежская улица, 3	f	large
81130	55601	290	Москва, Онежская улица, 3	f	large
81129	55600	289	Москва, Онежская , 2	f	large
81148	55613	308	Москва, Онежская, 24с1	f	large
81380	55779	542	Москва, Олонецкий проезд, 6	f	large
81379	55779	541	Москва, Олонецкий проезд, 6	f	large
81376	55779	538	Москва, Олонецкий проезд, 6	f	large
81576	55890	738	Москва, Олонецкая, 13	f	large
81574	55890	736	Москва, Олонецкая, 13	f	large
80918	55418	72	Москва, Олимпийский проспект, 11с2	f	large
83513	57086	2695	Москва, Олимпийская деревня, 24	f	large
83512	57086	2694	Москва, Олимпийская деревня, 24	f	large
82067	56201	1232	Москва, Олений Вал, 22	f	large
83542	57104	2724	Москва, Олеко Дундича, 23, Адрес УИК: Кастанаевская ул, дом 7	f	large
81497	55847	659	Москва, Октябрьский переулок, 11	f	large
81507	55853	669	Москва, Октябрьская , 81	f	large
81506	55853	668	Москва, Октябрьская , 81	f	large
82133	56235	1298	Москва, Окская, 16к3	f	large
82132	56235	1297	Москва, Окская, 16к3	f	large
83423	57028	2604	Москва, Озерная улица, 27к2	f	large
83424	57028	2605	Москва, Озерная улица, 27к2	f	large
111554	57220	2924	Москва, Одинцовская, 24	f	small
82936	56714	2115	Москва, Одесская, 13	f	large
82935	56714	2114	Москва, Одесская, 13	f	large
80892	55397	45	Москва, Овчинниковская набережная, 22/24с1	f	large
83042	56790	2221	Москва, Обручева, 11с1	f	large
111575	57377	3172	Москва, Норильская, 4, СОШ № 762	f	\N
81474	55832	636	Москва, Норильская, 4	f	large
81473	55832	635	Москва, Норильская, 4	f	large
81057	55546	217	Москва, Новый Зыковский проезд, 4, адрес УИК: Планетная ул, дом 11	f	large
83204	56891	2383	Москва, Новоясеневский проспект, 24к3	f	large
83206	56891	2385	Москва, Новоясеневский проспект, 24к3	f	large
83205	56891	2384	Москва, Новоясеневский проспект, 24к3	f	large
82250	56313	1417	Москва, Новочеркасский бульвар, 19	f	large
82249	56313	1416	Москва, Новочеркасский бульвар, 19	f	large
82248	56311	1415	Москва, Новочеркасский бульвар, 17	f	large
82244	56311	1411	Москва, Новочеркасский бульвар, 17	f	large
83123	56840	2302	Москва, Новочеремушкинская улица, 62к2	f	large
83114	56833	2293	Москва, Новочеремушкинская улица, 48	f	large
82877	56670	2056	Москва, Новочеремушкинская улица, 3	f	large
83125	56842	2304	Москва, Новочеремушкинская, 64к4	f	large
83124	56841	2303	Москва, Новочеремушкинская, 64к2	f	large
83116	56835	2295	Москва, Новочеремушкинская, 56к1	f	large
83121	56828	2300	Москва, Новочеремушкинская, 62к2	f	large
83122	56828	2301	Москва, Новочеремушкинская, 62к2	f	large
82878	56671	2057	Москва, Новочеремушкинская, 11а	f	large
83753	57231	2939	Москва, Новохорошевский проезд, 12	f	large
83752	57230	2938	Москва, Новохорошевский проезд, 26	f	large
83751	57229	2937	Москва, Новохорошевский проезд, 1	f	large
83642	57166	2825	Москва, Новотушинский проезд, 8	f	large
83641	57166	2824	Москва, Новотушинский проезд, 8	f	large
83640	57165	2823	Москва, Новотушинский проезд, 8к2	f	large
83639	57165	2822	Москва, Новотушинский проезд, 8к2	f	large
81498	55848	660	Москва, Новосущевская, 7	f	large
81499	55848	661	Москва, Новосущевская, 7	f	large
81001	55489	160	Москва, Новослободская улица, 38с1, УИК: Новослободская ул, дом 14/19, корп. 8	f	large
80985	55473	144	Москва, Новослободская улица, 57/65	f	large
80986	55474	145	Москва, Новослободская , 41, адрес УИК: Лесная ул, дом 61, стр.1	f	large
81784	56014	947	Москва, Новосибирская улица, 3а	f	large
81783	56014	946	Москва, Новосибирская улица, 3а	f	large
81781	56014	944	Москва, Новосибирская улица, 3а	f	large
81786	56016	949	Москва, Новосибирская, 8а	f	large
81785	56016	948	Москва, Новосибирская, 8а	f	large
83299	56947	2480	Москва, Новорублевская, 1, адрес УИК: Советская ул, дом 11А	f	large
82233	56304	1400	Москва, Новороссийская, 36	f	large
82232	56304	1399	Москва, Новороссийская, 36	f	large
80968	55460	127	Москва, Новорогожская улица, 18	f	large
80967	55460	126	Москва, Новорогожская улица, 18	f	large
80965	55458	124	Москва, Новорогожская, 9	f	large
80964	55458	123	Москва, Новорогожская, 9	f	large
81201	55645	361	Москва, Новопетровская, 1а	f	large
81200	55645	360	Москва, Новопетровская, 1а	f	large
81262	55695	423	Москва, Новопесчаная, 15	f	large
83386	57001	2567	Москва, Новопеределкинская , 9к1	f	large
83389	57003	2570	Москва, Новопеределкинская, 13к1	f	large
83388	57003	2569	Москва, Новопеределкинская, 13к1	f	large
83387	57002	2568	Москва, Новопеределкинская, 9	f	large
83385	57000	2566	Москва, Новопеределкинская, 9к1	f	large
82406	56407	1575	Москва, Новоостаповская, 10	f	large
81518	55862	680	Москва, Новомосковская улица, 10	f	large
82278	56325	1445	Москва, Новомарьинская, 7к2	f	large
82277	56325	1444	Москва, Новомарьинская, 7к2	f	large
81936	56110	1101	Москва, Новокосинская улица, 40а	f	large
81935	56110	1100	Москва, Новокосинская улица, 40а	f	large
81931	56108	1096	Москва, Новокосинская улица, 41	f	large
81929	56108	1094	Москва, Новокосинская улица, 41	f	large
81928	56108	1093	Москва, Новокосинская улица, 41	f	large
81930	56108	1095	Москва, Новокосинская улица, 41	f	large
81920	56103	1084	Москва, Новокосинская улица, 13а	f	large
81919	56103	1083	Москва, Новокосинская улица, 13а	f	large
81918	56103	1082	Москва, Новокосинская улица, 13а	f	large
81934	56109	1099	Москва, Новокосинская , 42а	f	large
81933	56109	1098	Москва, Новокосинская , 42а	f	large
81932	56109	1097	Москва, Новокосинская , 42а	f	large
83555	57116	2737	Москва, Новозаводская, 2к5	f	large
81973	56130	1138	Москва, Новогиреевская улица, 22а	f	large
81972	56130	1137	Москва, Новогиреевская улица, 22а	f	large
81333	55752	495	Москва, Новоалексеевская, 6	f	large
80851	55357	4	Москва, Новинский бульвар, 20с1, Трубниковский пер, дом 2	f	large
80849	55355	2	Москва, Новинский бульвар, 3с1	f	large
82654	56556	1828	Москва, Новинки, 8, УИК: Андропова просп, дом 29, корп. 2	f	large
82653	56555	1827	Москва, Новинки, 8	f	large
82652	56554	1826	Москва, Новинки, 21к2	f	large
81460	55826	622	Москва, Новгородская улица, 6	f	large
81459	55826	621	Москва, Новгородская улица, 6	f	large
81458	55825	620	Москва, Новгородская улица, 8	f	large
81457	55825	619	Москва, Новгородская улица, 8	f	large
81456	55824	618	Москва, Новгородская , 7а	f	large
81455	55823	617	Москва, Новгородская, 12	f	large
81454	55823	616	Москва, Новгородская, 12	f	large
81453	55822	615	Москва, Новгородская, 24к1	f	large
81452	55822	614	Москва, Новгородская, 24к1	f	large
81449	55820	611	Москва, Новгородская, 21а	f	large
81448	55820	610	Москва, Новгородская, 21а	f	large
81447	55820	609	Москва, Новгородская, 21а	f	large
80868	55374	21	Москва, Новая Басманная, 4-6с4, УИК: Садовая-Черногрязская ул, дом 11/2	f	large
81188	55638	348	Москва, Новая, 2	f	large
81187	55638	347	Москва, Новая, 2	f	large
83040	56789	2219	Москва, Новаторов, 4к8, адрес УИК: Новаторов ул, дом 16, корп. 2	f	large
83536	57100	2718	Москва, Никулинская, 10	f	large
83509	57084	2691	Москва, Никулинская, 5	f	large
83508	57084	2690	Москва, Никулинская, 5	f	large
83507	57084	2689	Москва, Никулинская, 5	f	large
80956	55451	115	Москва, Николоямская, 33с1, УИК: Мартыновский пер, дом 8	f	large
80940	55439	98	Москва, Николаева, 5	f	large
80993	55481	152	Москва, Никитский переулок, 7с1, адрес УИК: Тверская ул, дом 6, стр. 6	f	large
81846	56047	1009	Москва, Никитинская , 7	f	large
81847	56048	1010	Москва, Никитинская, 4а	f	large
81873	56070	1036	Москва, Нижняя Первомайская, 14	f	large
81872	56069	1035	Москва, Нижняя Первомайская, 9	f	large
81743	55990	906	Москва, Нижняя Первомайская, 51	f	large
81742	55989	905	Москва, Нижняя Первомайская, 51	f	large
81247	55680	408	Москва, Нижняя Масловка, 16	f	large
81245	55678	406	Москва, Нижняя Масловка, 8	f	large
82319	56352	1487	Москва, Нижегородская улица, 67	f	large
80966	55459	125	Москва, Нижегородская улица, 3бс1	f	large
82321	56354	1489	Москва, Нижегородская , 70к1	f	large
82320	56353	1488	Москва, Нижегородская , 98	f	large
82322	56355	1490	Москва, Нижегородская, 64	f	large
81282	55712	443	Москва, Немчинова, 8	f	large
81281	55711	442	Москва, Немчинова, 8	f	large
83827	57282	3014	Москва, Нелидовская улица, 21к1	f	large
111550	57029	2607	Москва, Нежинская, 2	f	medium
83399	57014	2580	Москва, Нежинская, 7к2, УИК: Веерная ул, дом 32, корп. 1	f	large
83398	57013	2579	Москва, Нежинская, 7к2	f	large
83006	56760	2185	Москва, Нахимовский проспект, 10	f	large
83005	56760	2184	Москва, Нахимовский проспект, 10	f	large
82658	56558	1832	Москва, Нахимовский проспект, 4а	f	large
83760	57235	2946	Москва, Народного Ополчения, 27к2	f	large
83759	57234	2945	Москва, Народного Ополчения, 32	f	large
83758	57234	2944	Москва, Народного Ополчения, 32	f	large
83755	57232	2941	Москва, Народного Ополчения, 22к4	f	large
83754	57232	2940	Москва, Народного Ополчения, 22к4	f	large
83741	57222	2927	Москва, Народного Ополчения, 16к4	f	large
80982	55470	141	Москва, Народная, 11/2	f	large
80981	55469	140	Москва, Народная, 11/2	f	large
81094	55578	254	Москва, Нарвская, 12, УИК: Нарвская ул, дом 9А	f	large
81829	56036	992	Москва, Напольный проезд, 7	f	large
81822	56033	985	Москва, Напольный проезд, 9	f	large
82998	56757	2177	Москва, Нагорная улица, 11к1	f	large
83000	56580	2179	Москва, Нагорная улица, 16к1	f	large
83004	56759	2183	Москва, Нагорная, 32к3	f	large
83002	56759	2181	Москва, Нагорная, 32к3	f	large
82999	56748	2178	Москва, Нагорная, 22к1	f	large
82638	56541	1812	Москва, Нагатинская набережная, 56, адрес УИК: Судостроительная ул, дом 44	f	large
82609	56518	1782	Москва, Нагатинская набережная, 24	f	large
82608	56518	1781	Москва, Нагатинская набережная, 24	f	large
82607	56518	1780	Москва, Нагатинская набережная, 24	f	large
82606	56517	1779	Москва, Нагатинская набережная, 12к1	f	large
82605	56517	1778	Москва, Нагатинская набережная, 12к1	f	large
82604	56517	1777	Москва, Нагатинская набережная, 12к1	f	large
82637	56503	1811	Москва, Нагатинская набережная, 56	f	large
82602	56515	1775	Москва, Нагатинская , 4к2	f	large
82290	56333	1457	Москва, Мячковский бульвар, 25	f	large
82289	56333	1456	Москва, Мячковский бульвар, 25	f	large
82288	56332	1455	Москва, Мячковский бульвар, 21	f	large
82287	56332	1454	Москва, Мячковский бульвар, 21	f	large
82286	56331	1453	Москва, Мячковский бульвар, 7к2	f	large
82285	56331	1452	Москва, Мячковский бульвар, 7к2	f	large
82281	56328	1448	Москва, Мячковский бульвар, 7к1	f	large
82280	56327	1447	Москва, Мячковский бульвар, 10к2	f	large
82279	56326	1446	Москва, Мячковский бульвар, 10к2	f	large
82275	56323	1442	Москва, Мячковский бульвар, 14к3	f	large
82274	56323	1441	Москва, Мячковский бульвар, 14к3	f	large
82273	56322	1440	Москва, Мячковский бульвар, 18к3	f	large
82272	56322	1439	Москва, Мячковский бульвар, 18к3	f	large
82517	56471	1687	Москва, Мытная улица, 50, УИК: Шухова ул, дом 4	f	large
82575	56502	1748	Москва, Мусы Джалиля, 29к2	f	large
82574	56502	1747	Москва, Мусы Джалиля, 29к2	f	large
82570	56500	1743	Москва, Мусы Джалиля, 17к3	f	large
82569	56500	1742	Москва, Мусы Джалиля, 17к3	f	large
82568	56500	1741	Москва, Мусы Джалиля, 17к3	f	large
82567	56499	1740	Москва, Мусы Джалиля, 7к5	f	large
82566	56499	1739	Москва, Мусы Джалиля, 7к5	f	large
82564	56498	1737	Москва, Мусы Джалиля, 6к3	f	large
82565	56498	1738	Москва, Мусы Джалиля, 6к3	f	large
82562	56497	1735	Москва, Мусы Джалиля, 12к2	f	large
82563	56497	1736	Москва, Мусы Джалиля, 12к2	f	large
82554	56494	1727	Москва, Мусы Джалиля, 36к2	f	large
82553	56494	1726	Москва, Мусы Джалиля, 36к2	f	large
81559	55882	721	Москва, Мусоргского, 3	f	large
81558	55882	720	Москва, Мусоргского, 3	f	large
81556	55881	718	Москва, Мусоргского, 11	f	large
81874	95178	1037	Москва, Муромская улица, 1а	f	large
81876	56073	1039	Москва, Муромская , 1а	f	large
81511	55855	673	Москва, Мурманский проезд, 12	f	large
81410	55797	572	Москва, Мурановская улица, 10вс2	f	large
81409	55797	571	Москва, Мурановская улица, 10вс2	f	large
81408	55796	570	Москва, Мурановская, 8б	f	large
81407	55796	569	Москва, Мурановская, 8б	f	large
81406	55795	568	Москва, Мурановская, 4а	f	large
81405	55795	567	Москва, Мурановская, 4а	f	large
81404	55795	566	Москва, Мурановская, 4а	f	large
80952	55448	111	Москва, Мукомольный проезд, 3с1	f	large
83455	57048	2637	Москва, Мосфильмовская, 21	f	large
83454	57048	2636	Москва, Мосфильмовская, 21	f	large
81817	56030	980	Москва, Молостовых, 6а	f	large
81816	56030	979	Москва, Молостовых, 6а	f	large
81814	56028	977	Москва, Молостовых, 10а	f	large
81606	55911	768	Москва, Молодцова, 4а	f	large
81603	55911	765	Москва, Молодцова, 4а	f	large
81602	55911	764	Москва, Молодцова, 4а	f	large
83309	56954	2490	Москва, Молодогвардейская улица, 47	f	large
83307	56952	2488	Москва, Молодогвардейская, 19к2	f	large
83305	56952	2486	Москва, Молодогвардейская, 19к2	f	large
81732	55984	895	Москва, Молдагуловой, 20А	f	large
81733	55984	896	Москва, Молдагуловой, 20А	f	large
83296	56944	2477	Москва, Молдавская, 6к2	f	large
83295	56944	2476	Москва, Молдавская, 6к2	f	large
83361	56985	2542	Москва, Можайское шоссе, 18к2	f	large
83356	56981	2537	Москва, Можайское шоссе, 38к7	f	large
83353	56979	2534	Москва, Можайское шоссе, 50	f	large
83750	57228	2936	Москва, Мневники, 14к1	f	large
83749	57228	2935	Москва, Мневники, 14к1	f	large
83740	57221	2926	Москва, Мневники, 7к5	f	large
83739	57221	2925	Москва, Мневники, 7к5	f	large
83511	57085	2693	Москва, Мичуринский проспект, 23	f	large
83510	57085	2692	Москва, Мичуринский проспект, 23	f	large
83477	57063	2659	Москва, Мичуринский проспект, 42	f	large
83476	57063	2658	Москва, Мичуринский проспект, 42	f	large
83475	57063	2657	Москва, Мичуринский проспект, 42	f	large
83474	57062	2656	Москва, Мичуринский проспект, 54к3	f	large
83464	57056	2646	Москва, Мичуринский проспект, 23	f	large
83463	57056	2645	Москва, Мичуринский проспект, 23	f	large
83462	57055	2644	Москва, Мичуринский проспект, 23, адрес УИК: Мичуринский просп, дом 25, корп.5	f	large
83461	57054	2643	Москва, Мичуринский проспект, 15к1	f	large
83460	57053	2642	Москва, Мичуринский проспект, 15к1	f	large
83459	57052	2641	Москва, Мичуринский проспект, 9б	f	large
83458	57051	2640	Москва, Мичуринский проспект, 5к1	f	large
81214	55654	374	Москва, Михалковская улица, 14	f	large
81213	55654	373	Москва, Михалковская улица, 14	f	large
81205	55649	365	Москва, Михалковская , 13а	f	large
81215	55655	375	Москва, Михалковская, 3	f	large
82358	56375	1526	Москва, Михайлова, 24к3	f	large
82357	56375	1525	Москва, Михайлова, 24к3	f	large
83630	57160	2813	Москва, Митинская , 46к2	f	large
83629	57160	2812	Москва, Митинская , 46к2	f	large
83628	57160	2811	Москва, Митинская , 46к2	f	large
83632	57161	2815	Москва, Митинская, 48к2	f	large
83631	57161	2814	Москва, Митинская, 48к2	f	large
83617	57153	2800	Москва, Митинская, 45к3	f	large
83616	57153	2799	Москва, Митинская, 45к3	f	large
81237	55673	398	Москва, Мирской переулок, 5к2	f	large
81683	55955	846	Москва, Миллионная, 5	f	large
81682	55955	844	Москва, Миллионная, 5	f	large
81681	55955	843	Москва, Миллионная, 5	f	large
111572	57374	3169	Москва, Милашенкова, 10б, СОШ № 968	f	\N
81441	55815	603	Москва, Милашенкова, 9б	f	large
81439	55815	601	Москва, Милашенкова, 9б	f	large
81433	55812	595	Москва, Милашенкова, 10	f	large
81373	55777	535	Москва, Менжинского, 30	f	large
82473	56449	1643	Москва, Медынская улица, 9а, адрес УИК: Харьковская ул, дом 1, корп. 3	f	large
82472	56449	1642	Москва, Медынская улица, 9а, адрес УИК: Харьковская ул, дом 1, корп. 3	f	large
82471	56449	1641	Москва, Медынская улица, 9а, адрес УИК: Харьковская ул, дом 1, корп. 3	f	large
82470	56449	1640	Москва, Медынская улица, 9а, адрес УИК: Харьковская ул, дом 1, корп. 3	f	large
82465	56445	1635	Москва, Медынская , 6а	f	large
82469	56448	1639	Москва, Медынская, 7а	f	large
82468	56448	1638	Москва, Медынская, 7а	f	large
83480	57066	2662	Москва, Матросова, 31	f	large
83411	57020	2592	Москва, Матвеевская улица, 34к2	f	large
83410	57019	2591	Москва, Матвеевская, 34к2	f	large
83409	57019	2590	Москва, Матвеевская, 34к2	f	large
83408	57018	2589	Москва, Матвеевская, 20к2, УИК: Нежинская ул, дом 21	f	large
83407	57018	2588	Москва, Матвеевская, 20к2, УИК: Нежинская ул, дом 21	f	large
82239	56307	1406	Москва, Марьинский Парк, 43	f	large
82238	56307	1405	Москва, Марьинский Парк, 43	f	large
82160	56253	1326	Москва, Маршала Чуйкова, 26к1	f	large
82159	56253	1325	Москва, Маршала Чуйкова, 26к1	f	large
83776	57241	2962	Москва, Маршала Тухачевского, 46	f	large
83768	57241	2954	Москва, Маршала Тухачевского, 46	f	large
83764	57237	2950	Москва, Маршала Тухачевского, 20к1	f	large
83763	57237	2949	Москва, Маршала Тухачевского, 20к1	f	large
83757	57233	2943	Москва, Маршала Тухачевского, 17к3	f	large
83756	57233	2942	Москва, Маршала Тухачевского, 17к3	f	large
83323	56963	2504	Москва, Маршала Тимошенко, 36к2	f	large
83322	56963	2503	Москва, Маршала Тимошенко, 36к2	f	large
83142	56854	2321	Москва, Маршала Савицкого, 26к4	f	large
83141	56854	2320	Москва, Маршала Савицкого, 26к4	f	large
83138	56851	2317	Москва, Маршала Савицкого, 6к4	f	large
83137	56851	2316	Москва, Маршала Савицкого, 6к4	f	large
83136	56851	2315	Москва, Маршала Савицкого, 6к4	f	large
83796	57262	2983	Москва, Маршала Рыбалко, 14	f	large
82122	56230	1287	Москва, Маршала Полубоярова, 22	f	large
82121	56230	1286	Москва, Маршала Полубоярова, 22	f	large
82116	56226	1281	Москва, Маршала Полубоярова, 12	f	large
82115	56226	1280	Москва, Маршала Полубоярова, 12	f	large
83804	57267	2991	Москва, Маршала Новикова, 13	f	large
83716	57211	2901	Москва, Маршала Катукова, 12к3	f	large
83715	57211	2900	Москва, Маршала Катукова, 12к3	f	large
83714	57211	2899	Москва, Маршала Катукова, 12к3	f	large
83709	57208	2894	Москва, Маршала Катукова, 21к2	f	large
83708	57208	2893	Москва, Маршала Катукова, 21к2	f	large
83707	57208	2892	Москва, Маршала Катукова, 21к2	f	large
82682	56570	1857	Москва, Маршала Захарова, 8к1	f	large
82681	56570	1856	Москва, Маршала Захарова, 8к1	f	large
82680	56569	1855	Москва, Маршала Захарова, 25к2	f	large
82679	56569	1854	Москва, Маршала Захарова, 25к2	f	large
82678	56569	1853	Москва, Маршала Захарова, 25к2	f	large
82257	56316	1424	Москва, Маршала Голованова, 9	f	large
83805	57268	2992	Москва, Маршала Василевского, 11к2, УИК: Новикова маршала ул, дом 13	f	large
83803	57266	2990	Москва, Маршала Василевского, 9к1	f	large
83802	57263	2989	Москва, Маршала Василевского, 3к2	f	large
83797	57263	2984	Москва, Маршала Василевского, 3к2	f	large
83789	95182	2976	Москва, Маршала Бирюзова, 5, ДМТ Домисолька	f	large
83791	57258	2978	Москва, Маршала Бирюзова, 6	f	large
83790	57257	2977	Москва, Маршала Бирюзова, 5	f	large
80977	55466	136	Москва, Марксистский переулок, 3	f	large
80974	55464	133	Москва, Марксистская улица, 9к2	f	large
80976	95177	135	Москва, Марксистская, 9, ГОУ СОШ №622	f	large
82224	56299	1391	Москва, Мариупольская, 3	f	large
83015	56769	2194	Москва, Марии Ульяновой, 5а, УИК: Ленинский просп, дом 88, корп. 2	f	large
80910	55411	64	Москва, Малый Сухаревский переулок, 6	f	large
81031	55520	190	Москва, Малый Саввинский переулок, 8	f	large
80992	55480	151	Москва, Малый Палашевский переулок, 3	f	large
81052	55541	211	Москва, Малый Коптевский проезд, 3, адрес УИК: Коптевский м. пр, дом 4/6	f	large
80924	55425	78	Москва, Малый Кисловский переулок, 12/8с1	f	large
81336	55754	498	Москва, Маломосковская, 7	f	large
81335	55754	497	Москва, Маломосковская, 7	f	large
82059	56194	1224	Москва, Маленковская, 17	f	large
82057	56194	1222	Москва, Маленковская, 17	f	large
82934	56713	2113	Москва, Малая Юшуньская, 4	f	large
82933	56712	2112	Москва, Малая Юшуньская, 4, УИК: Одесская ул, дом 27/14	f	large
82932	56712	2111	Москва, Малая Юшуньская, 4, УИК: Одесская ул, дом 27/14	f	large
83564	57123	2747	Москва, Малая Филевская , 26к1	f	large
83563	57123	2746	Москва, Малая Филевская , 26к1	f	large
83562	57111	2744	Москва, Малая Филевская, 50	f	large
82511	56467	1681	Москва, Малая Тульская, 15	f	large
82510	56467	1680	Москва, Малая Тульская, 15	f	large
80923	55424	77	Москва, Малая Переяславская, 6/8	f	large
80927	55428	84	Москва, Малая Бронная, 5-7с1	f	large
81492	55843	654	Москва, Малая Ботаническая , 24Б	f	large
81587	55898	749	Москва, Малахитовая улица, 18	f	large
81585	55897	747	Москва, Малахитовая улица, 15	f	large
81586	55897	748	Москва, Малахитовая улица, 15	f	large
82028	56166	1193	Москва, Мажоров переулок, 8	f	large
81837	56041	1000	Москва, Магнитогорская, 15	f	large
81838	56041	1001	Москва, Магнитогорская, 15	f	large
80864	55369	17	Москва, Лялин переулок, 12с1	f	large
80899	55402	53	Москва, Люсиновская улица, 31с1	f	large
80898	55402	52	Москва, Люсиновская улица, 31с1	f	large
82276	56324	1443	Москва, Люблинская улица, 167	f	large
82270	56321	1437	Москва, Люблинская улица, 173	f	large
82269	56321	1436	Москва, Люблинская улица, 173	f	large
82271	56321	1438	Москва, Люблинская улица, 173	f	large
82400	56401	1568	Москва, Люблинская, 45	f	large
82399	56401	1567	Москва, Люблинская, 45	f	large
82382	56389	1550	Москва, Люблинская, 11	f	large
82199	56284	1366	Москва, Люблинская, 56/2с1	f	large
82226	56209	1393	Москва, Люблинская, 125ас1	f	large
82225	56209	1392	Москва, Люблинская, 125ас1	f	large
81887	56083	1050	Москва, Лухмановская, 13б	f	large
81885	56081	1048	Москва, Лухмановская, 26а	f	large
81884	56081	1047	Москва, Лухмановская, 26а	f	large
81883	56080	1046	Москва, Лухмановская, 10а	f	large
83397	57012	2578	Москва, Лукинская, 12к1	f	large
83377	56996	2558	Москва, Лукинская, 9к1	f	large
83366	56988	2547	Москва, Лукинская, 1к1	f	large
111533	56090	1061	Москва, Лосиноостровская, 24с1	f	medium
81679	55954	841	Москва, Лосевская, 9	f	large
82187	56276	1354	Москва, Лонгиновская улица, 6	f	large
82186	56276	1353	Москва, Лонгиновская улица, 6	f	large
83479	57065	2661	Москва, Ломоносовский проспект, 31к2	f	large
82916	56700	2095	Москва, Ломоносовский проспект, 4к4	f	large
82915	56700	2094	Москва, Ломоносовский проспект, 4к4	f	large
82914	56699	2093	Москва, Ломоносовский проспект, 3а	f	large
82913	56699	2092	Москва, Ломоносовский проспект, 3а	f	large
82912	56698	2091	Москва, Ломоносовский проспект, 13	f	large
82911	56697	2090	Москва, Ломоносовский проспект, 21	f	large
82910	56697	2089	Москва, Ломоносовский проспект, 21	f	large
82909	56696	2088	Москва, Ломоносовский проспект, 18	f	large
82908	56695	2087	Москва, Ломоносовский проспект, 12	f	large
82907	56695	2086	Москва, Ломоносовский проспект, 12	f	large
111591	57394	3188	Москва, Лодочная, 3с1	f	\N
83433	57036	2615	Москва, Лобачевского, 66б	f	large
83431	57034	2613	Москва, Лобачевского, 54, УИК: Вернадского просп, дом 62А	f	large
83444	57031	2626	Москва, Лобачевского, 92	f	large
83427	57031	2609	Москва, Лобачевского, 92	f	large
83426	57030	2608	Москва, Лобачевского, 90, Адрес УИК: Вернадского просп, дом 62А	f	large
83428	57030	2610	Москва, Лобачевского, 90, Адрес УИК: Вернадского просп, дом 62А	f	large
83227	56902	2407	Москва, Литовский бульвар, 17к4	f	large
83226	56902	2406	Москва, Литовский бульвар, 17к4	f	large
83225	56901	2405	Москва, Литовский бульвар, 17к3	f	large
83224	56901	2404	Москва, Литовский бульвар, 17к3	f	large
83223	56901	2403	Москва, Литовский бульвар, 17к3	f	large
83222	56900	2402	Москва, Литовский бульвар, 44к2	f	large
83221	56900	2401	Москва, Литовский бульвар, 44к2	f	large
83220	56899	2400	Москва, Литовский бульвар, 42к2	f	large
83219	56899	2399	Москва, Литовский бульвар, 42к2	f	large
83217	56897	2397	Москва, Литовский бульвар, 11к6	f	large
83216	56897	2396	Москва, Литовский бульвар, 11к6	f	large
83212	56893	2391	Москва, Литовский бульвар, 3к3	f	large
83211	56893	2390	Москва, Литовский бульвар, 3к3	f	large
83210	56893	2389	Москва, Литовский бульвар, 3к3	f	large
83207	56892	2386	Москва, Литовский бульвар, 6к2	f	large
83209	56892	2388	Москва, Литовский бульвар, 6к2	f	large
83208	56892	2387	Москва, Литовский бульвар, 6к2	f	large
81273	55705	434	Москва, Лиственничная аллея, 12	f	large
82459	56441	1628	Москва, Липецкая, 15к2	f	large
82460	56441	1629	Москва, Липецкая, 15к2	f	large
82458	56440	1627	Москва, Липецкая, 15к2, УИК: Липецкая ул, дом 17, корп. 1	f	large
82457	56440	1626	Москва, Липецкая, 15к2, УИК: Липецкая ул, дом 17, корп. 1	f	large
82451	56437	1620	Москва, Липецкая, 44	f	large
82450	56437	1619	Москва, Липецкая, 44	f	large
81278	55709	439	Москва, Линейный проезд, 11	f	large
81277	55709	438	Москва, Линейный проезд, 11	f	large
81276	55708	437	Москва, Линейный проезд, 9	f	large
82032	56170	1197	Москва, Лечебная, 20	f	large
80872	55378	25	Москва, Лефортовский переулок, 8с7	f	large
82179	56269	1346	Москва, Лефортовский Вал, 14	f	large
80987	55475	146	Москва, Лесная улица, 18/5с3	f	large
81422	55804	584	Москва, Лескова, 3к3	f	large
81421	55803	583	Москва, Лескова, 7	f	large
81416	55800	578	Москва, Лескова, 8а	f	large
81418	55800	580	Москва, Лескова, 8а	f	large
81417	55800	579	Москва, Лескова, 8а	f	large
81388	55787	550	Москва, Лескова, 25А	f	large
81387	55786	549	Москва, Лескова, 25а, адрес УИК: Белозерская ул, дом 13	f	large
82112	56224	1277	Москва, Лермонтовский проспект, 14к2	f	large
82111	56224	1276	Москва, Лермонтовский проспект, 14к2	f	large
81371	55776	533	Москва, Ленская, 24	f	large
81370	55776	532	Москва, Ленская, 24	f	large
81369	55775	531	Москва, Ленская, 24, УИК: Ленская ул, дом 23	f	large
81365	55772	527	Москва, Ленская, 6	f	large
81363	55772	525	Москва, Ленская, 6	f	large
81372	55772	534	Москва, Ленская, 6	f	large
83527	57095	2709	Москва, Ленинский проспект, 158	f	large
83521	57091	2703	Москва, Ленинский проспект, 146	f	large
83440	57040	2622	Москва, Ленинский проспект, 132	f	large
83439	57040	2621	Москва, Ленинский проспект, 132	f	large
83108	56827	2287	Москва, Ленинский проспект, 125к4, УИК: Ленинский просп, дом 123, корп. 2	f	large
83107	56827	2286	Москва, Ленинский проспект, 125к4, УИК: Ленинский просп, дом 123, корп. 2	f	large
83106	56826	2285	Москва, Ленинский проспект, 125к4	f	large
83104	56824	2283	Москва, Ленинский проспект, 131к4	f	large
83103	56824	2282	Москва, Ленинский проспект, 131к4	f	large
83049	56795	2228	Москва, Ленинский проспект, 119к1	f	large
83038	56786	2217	Москва, Ленинский проспект, 97к2	f	large
83037	56785	2216	Москва, Ленинский проспект, 97к1, УИК: Новаторов ул, дом 16, корп. 2	f	large
83025	56778	2204	Москва, Ленинский проспект, 93б	f	large
83024	56777	2203	Москва, Ленинский проспект, 93б	f	large
83021	56774	2200	Москва, Ленинский проспект, 83а	f	large
83018	56771	2197	Москва, Ленинский проспект, 76а	f	large
83017	56771	2196	Москва, Ленинский проспект, 76а	f	large
82919	56704	2098	Москва, Ленинский проспект, 43а	f	large
82917	56702	2096	Москва, Ленинский проспект, 65к1	f	large
82901	56690	2080	Москва, Ленинский проспект, 42к5	f	large
82900	56689	2079	Москва, Ленинский проспект, 32а	f	large
82899	56688	2078	Москва, Ленинский проспект, 34а	f	large
82898	56687	2077	Москва, Ленинский проспект, 39а	f	large
82536	56484	1707	Москва, Ленинский проспект, 18а	f	large
81039	55528	198	Москва, Ленинский проспект, 13а	f	large
111584	57386	3181	Москва, Ленинские горы, 1к3с33	f	\N
81234	55670	395	Москва, Ленинградское шоссе, 95, Новоселки 4-я ул, дом 2	f	large
81223	55661	383	Москва, Ленинградское шоссе, 94а, адрес УИК: Фестивальная ул, дом 9	f	large
81222	55660	382	Москва, Ленинградское шоссе, 59	f	large
81095	55579	255	Москва, Ленинградское шоссе, 30, УИК: Макарова адмирала ул, дом 37, корп. 2	f	large
81093	55577	253	Москва, Ленинградское шоссе, 54, УИК: Макарова адмирала ул, дом 37, корп. 2	f	large
81091	55574	251	Москва, Ленинградское шоссе, 30	f	large
81087	55570	247	Москва, Ленинградское шоссе, 13А	f	large
81058	55547	218	Москва, Ленинградский проспект, 5с1	f	large
81045	55533	204	Москва, Ленинградский проспект, 64	f	large
81042	55530	201	Москва, Ленинградский проспект, 46	f	large
81041	55530	200	Москва, Ленинградский проспект, 46	f	large
82456	56439	1625	Москва, Лебедянская улица, 26к4	f	large
82455	56439	1624	Москва, Лебедянская улица, 26к4	f	large
82439	56430	1608	Москва, Лебедянская улица, 9	f	large
82438	56430	1607	Москва, Лебедянская улица, 9	f	large
82449	56436	1618	Москва, Лебедянская , 14к3	f	large
82447	56436	1616	Москва, Лебедянская , 14к3	f	large
82448	56435	1617	Москва, Лебедянская, 16	f	large
82446	56435	1615	Москва, Лебедянская, 16	f	large
83589	57138	2772	Москва, Ландышевая, 8	f	large
83588	57138	2771	Москва, Ландышевая, 8	f	large
80878	55371	31	Москва, Ладожская улица, 4/6с3	f	large
80980	55468	139	Москва, Лавров переулок, 9	f	large
81323	55746	485	Москва, Кучин переулок, 14	f	large
83575	57130	2758	Москва, Кутузовский проспект, 80	f	large
83266	56927	2447	Москва, Кутузовский проспект, 6	f	large
83265	56926	2446	Москва, Кутузовский проспект, 24	f	large
83264	56926	2445	Москва, Кутузовский проспект, 24	f	large
83263	56925	2444	Москва, Кутузовский проспект, 28, адрес УИК: Кутузовский просп, дом 30/32	f	large
83262	56924	2443	Москва, Кутузовский проспект, 10, адрес УИК: Давыдова Дениса ул, дом 7	f	large
83358	56982	2539	Москва, Кутузова, 20	f	large
83357	56982	2538	Москва, Кутузова, 20	f	large
82573	56501	1746	Москва, Кустанайская, 10к2	f	large
82572	56501	1745	Москва, Кустанайская, 10к2	f	large
82571	56501	1744	Москва, Кустанайская, 10к2	f	large
83053	56788	2232	Москва, Куликовская, 3б	f	large
83054	56788	2233	Москва, Куликовская, 3б	f	large
83724	57214	2909	Москва, Кулакова, 25к2	f	large
83723	57214	2908	Москва, Кулакова, 25к2	f	large
83722	57214	2907	Москва, Кулакова, 25к2	f	large
83717	57212	2902	Москва, Кулакова, 17к2	f	large
83718	57212	2903	Москва, Кулакова, 17к2	f	large
83701	57205	2886	Москва, Кулакова, 3к1	f	large
83700	57205	2885	Москва, Кулакова, 3к1	f	large
83699	57205	2884	Москва, Кулакова, 3к1	f	large
83698	57204	2883	Москва, Кулакова, 2к2	f	large
83355	56980	2536	Москва, Кубинка, 20к1	f	large
83354	56980	2535	Москва, Кубинка, 20к1	f	large
82192	56280	1359	Москва, Кубанская, 27	f	large
81035	55524	194	Москва, Крымский Вал, 8к2, адрес УИК: Крымский вал ул, дом 8	f	large
83291	56941	2472	Москва, Крылатские Холмы, 13	f	large
83290	56941	2471	Москва, Крылатские Холмы, 13	f	large
83289	56941	2470	Москва, Крылатские Холмы, 13	f	large
83288	56940	2469	Москва, Крылатские Холмы, 15к1	f	large
83287	56940	2468	Москва, Крылатские Холмы, 15к1	f	large
83283	56938	2464	Москва, Крылатские Холмы, 23	f	large
83282	56938	2463	Москва, Крылатские Холмы, 23	f	large
83281	56937	2462	Москва, Крылатские Холмы, 23, адрес УИК: Крылатские холмы, дом 27, корп. 3	f	large
83278	56935	2459	Москва, Крылатские Холмы, 45к2	f	large
83277	56935	2458	Москва, Крылатские Холмы, 45к2	f	large
83276	56934	2457	Москва, Крылатские Холмы, 45к1	f	large
83275	56934	2456	Москва, Крылатские Холмы, 45к1	f	large
83274	56932	2455	Москва, Крылатские Холмы, 28к1	f	large
83273	56932	2454	Москва, Крылатские Холмы, 28к1	f	large
83272	56931	2453	Москва, Крылатская, 25, адрес УИК: Крылатская ул, дом 30, корп. 3	f	large
83271	56930	2452	Москва, Крылатская, 25	f	large
83270	56930	2451	Москва, Крылатская, 25	f	large
82402	56403	1571	Москва, Крутицкий вал, 3	f	large
82403	56404	1572	Москва, Крутицкий Вал, 3	f	large
83019	56772	2198	Москва, Крупской, 9, УИК: Ульяновой Марии ул, дом 8	f	large
83011	56765	2190	Москва, Крупской, 17	f	large
81146	55612	306	Москва, Кронштадтский бульвар, 43а	f	large
81133	55603	293	Москва, Кронштадтский бульвар, 33	f	large
82657	56557	1831	Москва, Криворожская улица, 27а	f	large
82656	56557	1830	Москва, Криворожская улица, 27а	f	large
82890	56681	2069	Москва, Кржижановского, 4а	f	large
82887	56678	2066	Москва, Кржижановского, 30	f	large
83587	57137	2770	Москва, Кременчугская улица, 46	f	large
83362	56986	2543	Москва, Красных Зорь, 61	f	large
81740	55987	903	Москва, Красный Казанец, 3а	f	large
81739	55987	902	Москва, Красный Казанец, 3а	f	large
81738	55987	901	Москва, Красный Казанец, 3а	f	large
82178	56268	1345	Москва, Красноказарменная , 3к1	f	large
82173	56263	1340	Москва, Красноказарменная , 21	f	large
82174	56264	1341	Москва, Красноказарменная, 11	f	large
82228	56301	1395	Москва, Краснодонская улица, 40	f	large
82195	56282	1362	Москва, Краснодонская улица, 2к4	f	large
82194	56282	1361	Москва, Краснодонская улица, 2к4	f	large
82223	56298	1390	Москва, Краснодарская, 11	f	large
82206	56287	1374	Москва, Краснодарская, 45/11	f	large
82205	56287	1372	Москва, Краснодарская, 45/11	f	large
82201	56285	1368	Москва, Краснодарская, 9	f	large
82200	56285	1367	Москва, Краснодарская, 9	f	large
82827	56644	2005	Москва, Красного Маяка, 3г	f	large
82825	56644	2003	Москва, Красного Маяка, 3г	f	large
82815	56635	1993	Москва, Красного Маяка, 13а	f	large
81685	55958	848	Москва, Краснобогатырская улица, 21а	f	large
81686	55959	849	Москва, Краснобогатырская, 38	f	large
80929	55430	86	Москва, Красина, 27	f	large
83016	56770	2195	Москва, Кравченко, 14, адрес УИК: Ленинский просп, дом 88, корп. 2	f	large
83013	56767	2192	Москва, Кравченко, 14к1	f	large
111531	55543	213	Москва, Кочновский проезд, 4к1	f	medium
80984	55472	143	Москва, Котельническая набережная, 1/15кб	f	large
81356	55768	518	Москва, Костромская , 14гс1	f	large
81355	55767	517	Москва, Костромская, 14к1	f	large
81354	55767	516	Москва, Костромская, 14к1	f	large
81340	55749	502	Москва, Космонавтов, 5	f	large
81329	55749	491	Москва, Космонавтов, 5	f	large
81100	55584	260	Москва, Космонавта Волкова, 23	f	large
81728	55981	891	Москва, Косинская улица, 24а	f	large
81727	55981	890	Москва, Косинская улица, 24а	f	large
81730	55982	893	Москва, Косинская, 28а	f	large
81729	55982	892	Москва, Косинская, 28а	f	large
81723	55978	886	Москва, Косинская, 10а	f	large
81722	55978	885	Москва, Косинская, 10а	f	large
81176	55632	336	Москва, Коровинское шоссе, 14а, УИК: 800-летия Москвы ул, дом 2, корп. 1	f	large
81159	55622	319	Москва, Коровинское шоссе, 28	f	large
81156	55620	316	Москва, Коровинское шоссе, 24А	f	large
81155	55620	315	Москва, Коровинское шоссе, 24А	f	large
81393	55790	555	Москва, Корнейчука, 55а	f	large
81392	55789	554	Москва, Корнейчука, 37а	f	large
81391	55789	553	Москва, Корнейчука, 37а	f	large
81403	55794	565	Москва, Коненкова, 10а	f	large
81402	55794	564	Москва, Коненкова, 10а	f	large
81401	55794	563	Москва, Коненкова, 10а	f	large
81400	55793	562	Москва, Коненкова, 8а	f	large
81399	55793	561	Москва, Коненкова, 8а	f	large
81398	55792	560	Москва, Коненкова, 4а	f	large
81397	55792	559	Москва, Коненкова, 4а	f	large
81396	55792	558	Москва, Коненкова, 4а	f	large
81523	55865	685	Москва, Кондратюка, 5	f	large
81522	55865	684	Москва, Кондратюка, 5	f	large
81137	55606	297	Москва, Конаковский проезд, 5	f	large
81136	55606	296	Москва, Конаковский проезд, 5	f	large
81024	55512	183	Москва, Комсомольский проспект, 43с1, адрес УИК: Хамовнический Вал ул, дом 16	f	large
111596	57399	4005	Москва, Комсомольская площадь, 5	f	small
111595	57398	4004	Москва, Комсомольская площадь, 3	f	medium
111594	57397	4003	Москва, Комсомольская площадь, 2	f	small
80905	55406	59	Москва, Комсомольская площадь, 4с1, адрес УИК: Красносельская Верх. ул, дом 34	f	large
80904	55406	58	Москва, Комсомольская площадь, 4с1, адрес УИК: Красносельская Верх. ул, дом 34	f	large
81472	55831	634	Москва, Коминтерна, 52	f	large
81471	55831	633	Москва, Коминтерна, 52	f	large
81470	55831	632	Москва, Коминтерна, 52	f	large
81601	55910	763	Москва, Кольская, 1	f	large
82619	56524	1793	Москва, Коломенский проезд, 16	f	large
82618	56524	1792	Москва, Коломенский проезд, 16	f	large
82649	56551	1823	Москва, Коломенская набережная, 8	f	large
82648	56551	1822	Москва, Коломенская набережная, 8	f	large
82647	56549	1821	Москва, Коломенская набережная, 8, УИК: Коломенская ул, дом 5, корп. 3	f	large
82655	56548	1829	Москва, Коломенская набережная, 16	f	large
82646	56548	1820	Москва, Коломенская набережная, 16	f	large
82645	56547	1819	Москва, Коломенская набережная, 20	f	large
82644	56547	1818	Москва, Коломенская набережная, 20	f	large
81158	55621	318	Москва, Клязьминская улица, 8а	f	large
81157	55621	317	Москва, Клязьминская улица, 8а	f	large
81163	55623	323	Москва, Клязьминская, 7к4	f	large
81161	55623	321	Москва, Клязьминская, 7к4	f	large
81160	55623	320	Москва, Клязьминская, 7к4	f	large
82493	56461	1663	Москва, Ключевая , 6К2	f	large
82492	56461	1662	Москва, Ключевая , 6К2	f	large
81305	55728	466	Москва, Клинская, 20а	f	large
81304	55727	465	Москва, Клинская, 22	f	large
81302	55726	463	Москва, Клинская, 16а	f	large
81301	55726	462	Москва, Клинская, 16а	f	large
81303	55725	464	Москва, Клинская, 24	f	large
81300	55725	461	Москва, Клинская, 24	f	large
81299	55724	460	Москва, Клинская, 22	f	large
81298	55723	459	Москва, Клинская, 20	f	large
81297	55723	458	Москва, Клинская, 20	f	large
80936	55434	94	Москва, Климашкина, 13бс1	f	large
80934	55434	92	Москва, Климашкина, 13бс1	f	large
111583	57385	3180	Москва, Кленовый бульвар, 7к2, Частная школа «Самсон»	f	\N
82635	56539	1809	Москва, Кленовый бульвар, 21, адрес УИК: Коломенская ул, дом 27	f	large
82634	56538	1808	Москва, Кленовый бульвар, 21, УИК: Кленовый бульв, дом 23, копр. 2	f	large
82632	56536	1806	Москва, Кленовый бульвар, 21, УИК: Судостроительная ул, дом 20/2, корп. 1	f	large
82626	56530	1800	Москва, Кленовый бульвар, 7к2, адрес УИК: Кленовый бульв, дом 7	f	large
81099	55583	259	Москва, Клары Цеткин, 23	f	large
81098	55582	258	Москва, Клары Цеткин, 27	f	large
81097	55581	257	Москва, Клары Цеткин, 27	f	large
82842	56652	2020	Москва, Кировоградская улица, 42к2	f	large
82841	56652	2019	Москва, Кировоградская улица, 42к2	f	large
82840	56652	2018	Москва, Кировоградская улица, 42к2	f	large
82839	56651	2017	Москва, Кировоградская улица, 42Б	f	large
82838	56651	2016	Москва, Кировоградская улица, 42Б	f	large
82837	56651	2015	Москва, Кировоградская улица, 42Б	f	large
82831	56645	2009	Москва, Кировоградская улица, 21	f	large
82830	56645	2008	Москва, Кировоградская улица, 21	f	large
82826	56645	2004	Москва, Кировоградская улица, 21	f	large
82788	56618	1965	Москва, Кировоградская улица, 6б	f	large
82787	56618	1964	Москва, Кировоградская улица, 6б	f	large
82786	56618	1963	Москва, Кировоградская улица, 6б	f	large
82785	56618	1962	Москва, Кировоградская улица, 6б	f	large
82821	56641	1999	Москва, Кировоградская , 22а	f	large
82829	56647	2007	Москва, Кировоградская, 30а, Красного Маяка ул, дом 5, корп. 1	f	large
82828	56646	2006	Москва, Кировоградская, 30а	f	large
82824	56643	2002	Москва, Кировоградская, 22а	f	large
82822	56642	2000	Москва, Кировоградская, 22а	f	large
82820	56640	1998	Москва, Кировоградская, 18к4, адрес УИК: Кировоградская ул, дом 16, корп. 3	f	large
82819	56639	1997	Москва, Кировоградская, 18к4	f	large
82818	56638	1996	Москва, Кировоградская, 18к4	f	large
82789	56619	1966	Москва, Кировоградская, 8г	f	large
82784	56613	1961	Москва, Кировоградская, 8г	f	large
111545	56613	1951	Москва, Кировоградская, 8г	f	small
81337	55755	499	Москва, Кибальчича, 1	f	large
81711	55973	874	Москва, Кетчерская улица, 10а	f	large
81710	55973	873	Москва, Кетчерская улица, 10а	f	large
81709	55972	872	Москва, Кетчерская, 8а	f	large
81707	55972	870	Москва, Кетчерская, 8а	f	large
81708	55972	871	Москва, Кетчерская, 8а	f	large
81118	55595	278	Москва, Керамический проезд, 55к3	f	large
81117	55595	277	Москва, Керамический проезд, 55к3	f	large
81116	55595	276	Москва, Керамический проезд, 55к3	f	large
81115	55594	275	Москва, Керамический проезд, 47а	f	large
81114	55594	274	Москва, Керамический проезд, 47а	f	large
81113	55594	273	Москва, Керамический проезд, 47а	f	large
82894	56683	2073	Москва, Кедрова, 5к1	f	large
82893	56683	2072	Москва, Кедрова, 5к1	f	large
82884	56676	2063	Москва, Кедрова, 11	f	large
82718	56589	1894	Москва, Каширское шоссе, 116к3	f	large
82717	56589	1893	Москва, Каширское шоссе, 116к3	f	large
82716	56589	1892	Москва, Каширское шоссе, 116к3	f	large
82623	56527	1797	Москва, Каширское шоссе, 15	f	large
82622	56526	1796	Москва, Каширское шоссе, 6к2	f	large
82599	56512	1772	Москва, Каширское шоссе, 55к7	f	large
82598	56512	1771	Москва, Каширское шоссе, 55к7	f	large
82597	56512	1770	Москва, Каширское шоссе, 55к7	f	large
82596	56512	1769	Москва, Каширское шоссе, 55к7	f	large
82586	56507	1759	Москва, Каширское шоссе, 52	f	large
82585	56507	1758	Москва, Каширское шоссе, 52	f	large
82584	56507	1757	Москва, Каширское шоссе, 52	f	large
82944	56720	2123	Москва, Каховка, 11к2	f	large
82930	56711	2109	Москва, Каховка, 19к3	f	large
82929	56711	2108	Москва, Каховка, 19к3	f	large
82928	56711	2107	Москва, Каховка, 19к3	f	large
82931	56710	2110	Москва, Каховка, 19к2	f	large
82927	56710	2106	Москва, Каховка, 19к2	f	large
83574	57129	2757	Москва, Кастанаевская улица, 59к1	f	large
83573	57129	2756	Москва, Кастанаевская улица, 59к1	f	large
83572	57128	2755	Москва, Кастанаевская улица, 45к1	f	large
83545	57107	2727	Москва, Кастанаевская улица, 10	f	large
83544	57106	2726	Москва, Кастанаевская улица, 10	f	large
83543	57105	2725	Москва, Кастанаевская , 7	f	large
83571	57127	2754	Москва, Кастанаевская, 43	f	large
83570	57127	2753	Москва, Кастанаевская, 43	f	large
83568	57125	2751	Москва, Кастанаевская, 29к1	f	large
83567	57125	2750	Москва, Кастанаевская, 29к1	f	large
83539	57102	2721	Москва, Кастанаевская, 9а, Адрес УИК: Минская ул, дом 8, корп. 1	f	large
83538	57102	2720	Москва, Кастанаевская, 9а, Адрес УИК: Минская ул, дом 8, корп. 1	f	large
81342	55759	504	Москва, Касаткина, 15	f	large
81168	55627	328	Москва, Карельский бульвар, 20	f	large
81167	55627	327	Москва, Карельский бульвар, 20	f	large
81164	55625	324	Москва, Карельский бульвар, 5	f	large
81540	55873	702	Москва, Каргопольская, 13к2	f	large
81539	55873	701	Москва, Каргопольская, 13к2	f	large
83747	57226	2933	Москва, Карамышевская набережная, 54к2	f	large
83746	57226	2932	Москва, Карамышевская набережная, 54к2	f	large
83744	57224	2930	Москва, Карамышевская набережная, 38	f	large
83743	57223	2929	Москва, Карамышевская набережная, 22к2	f	large
83742	57223	2928	Москва, Карамышевская набережная, 22к2	f	large
82590	56509	1763	Москва, Кантемировская улица, 22к6	f	large
82589	56508	1762	Москва, Кантемировская улица, 22к4	f	large
82588	56508	1761	Москва, Кантемировская улица, 22к4	f	large
82587	56508	1760	Москва, Кантемировская улица, 22к4	f	large
82749	56604	1925	Москва, Кантемировская, 1а	f	large
82748	56604	1924	Москва, Кантемировская, 1а	f	large
82747	56604	1923	Москва, Кантемировская, 1а	f	large
82592	56510	1765	Москва, Кантемировская, 22к5	f	large
82591	56510	1764	Москва, Кантемировская, 22к5	f	large
81794	56019	957	Москва, Камчатская улица, 6	f	large
81793	56019	956	Москва, Камчатская улица, 6	f	large
81792	56019	955	Москва, Камчатская улица, 6	f	large
81799	56021	962	Москва, Камчатская, 10	f	large
81797	56021	960	Москва, Камчатская, 10	f	large
81798	56020	961	Москва, Камчатская, 8	f	large
81796	56020	959	Москва, Камчатская, 8	f	large
81795	56020	958	Москва, Камчатская, 8	f	large
81037	55526	196	Москва, Калужская площадь, 1к1	f	large
83189	56882	2368	Москва, Кадырова, 10	f	large
82770	56611	1946	Москва, Кавказский бульвар, 37к2	f	large
82769	56611	1945	Москва, Кавказский бульвар, 37к2	f	large
82768	56611	1944	Москва, Кавказский бульвар, 37к2	f	large
82746	56603	1922	Москва, Кавказский бульвар, 12к3	f	large
82745	56603	1921	Москва, Кавказский бульвар, 12к3	f	large
82742	56602	1918	Москва, Кавказский бульвар, 16к2	f	large
82744	56602	1920	Москва, Кавказский бульвар, 16к2	f	large
82743	56602	1919	Москва, Кавказский бульвар, 16к2	f	large
83712	57209	2897	Москва, Исаковского, 29к1	f	large
83711	57209	2896	Москва, Исаковского, 29к1	f	large
83710	57209	2895	Москва, Исаковского, 29к1	f	large
83706	57207	2891	Москва, Исаковского, 22к3	f	large
83705	57207	2890	Москва, Исаковского, 22к3	f	large
83704	57207	2889	Москва, Исаковского, 22к3	f	large
83703	57206	2888	Москва, Исаковского, 14к3	f	large
83702	57206	2887	Москва, Исаковского, 14к3	f	large
83586	57136	2769	Москва, Инициативная, 1	f	large
83585	57136	2768	Москва, Инициативная, 1	f	large
81349	55762	511	Москва, Инженерная, 16	f	large
81346	55762	508	Москва, Инженерная, 16	f	large
81171	55629	331	Москва, Икшинская, 12	f	large
83155	56862	2334	Москва, Изюмская улица, 38	f	large
83154	56861	2333	Москва, Изюмская, 34к3	f	large
83153	56861	2332	Москва, Изюмская, 34к3	f	large
83152	56861	2331	Москва, Изюмская, 34к3	f	large
83151	56860	2330	Москва, Изюмская, 28К3	f	large
83150	56859	2329	Москва, Изюмская, 35а	f	large
83149	56859	2328	Москва, Изюмская, 35а	f	large
83148	56859	2327	Москва, Изюмская, 35а	f	large
81467	55829	629	Москва, Изумрудная, 13к3	f	large
81466	55829	628	Москва, Изумрудная, 13к3	f	large
81465	55829	627	Москва, Изумрудная, 13к3	f	large
82039	56177	1204	Москва, Измайловское шоссе, 24к3	f	large
82038	56176	1203	Москва, Измайловское шоссе, 60	f	large
82037	56175	1202	Москва, Измайловское шоссе, 57	f	large
81853	56052	1016	Москва, Измайловский проспект, 53	f	large
81852	56052	1015	Москва, Измайловский проспект, 53	f	large
81746	55992	909	Москва, Измайловский проспект, 115	f	large
81745	55992	908	Москва, Измайловский проспект, 115	f	large
81744	55991	907	Москва, Измайловский проспект, 87	f	large
81845	56046	1008	Москва, Измайловский проезд, 12	f	large
81856	56055	1019	Москва, Измайловский бульвар, 19	f	large
81855	56054	1018	Москва, Измайловский бульвар, 7	f	large
81756	55998	919	Москва, Измайловский бульвар, 52	f	large
81598	55908	760	Москва, Ивовая, 1к1, адрес УИК: Тенистый пр, дом 8А	f	large
81698	55965	861	Москва, Ивантеевская, 32а	f	large
81695	55965	858	Москва, Ивантеевская, 32а	f	large
82029	56167	1194	Москва, Ибрагимова, 12	f	large
81315	55738	477	Москва, Зорге, 4, адрес УИК: Куусинена ул, дом 4, корп. 2	f	large
81219	55658	379	Москва, Зои и Александра Космодемьянских, 33	f	large
81199	55644	359	Москва, Зои и Александра Космодемьянских, 33, УИК: Космодемьянских З. и А. ул, дом 42	f	large
81104	55588	264	Москва, Зои и Александра Космодемьянских, 4а	f	large
81103	55587	263	Москва, Зои и Александра Космодемьянских, 6а	f	large
81096	55580	256	Москва, Зои и Александра Космодемьянских, 3/2	f	large
82002	56148	1167	Москва, Знаменская, 6	f	large
82001	56148	1166	Москва, Знаменская, 6	f	large
82000	56147	1165	Москва, Знаменская, 12/4	f	large
81999	56147	1164	Москва, Знаменская, 12/4	f	large
81877	56074	1040	Москва, Златоустовская, 3с3	f	large
111592	57395	4001	Москва, Земляной Вал, 29	f	small
80955	55450	114	Москва, Земляной Вал, 44ас1	f	large
81010	55499	169	Москва, Земледельческий переулок, 20а	f	large
81997	56146	1162	Москва, Зельев переулок, 11, адрес УИК: Знаменская ул, дом 23	f	large
81980	56134	1145	Москва, Зеленый проспект, 59	f	large
81979	56134	1144	Москва, Зеленый проспект, 59	f	large
81957	56121	1122	Москва, Зеленый проспект, 14	f	large
81956	56121	1121	Москва, Зеленый проспект, 14	f	large
81907	56096	1071	Москва, Зеленый проспект, 75	f	large
81906	56096	1070	Москва, Зеленый проспект, 75	f	large
82153	56249	1319	Москва, Зеленодольская улица, 41к3	f	large
82371	56382	1539	Москва, Зеленодольская, 7к4	f	large
82370	56382	1538	Москва, Зеленодольская, 7к4	f	large
82139	56242	1305	Москва, Зеленодольская, 32к6	f	large
82137	56240	1303	Москва, Зеленодольская, 33к2	f	large
82143	56239	1309	Москва, Зеленодольская, 33к3	f	large
111534	56239	1302	Москва, Зеленодольская, 33к3	f	medium
81153	55618	313	Москва, Зеленоградская улица, 9	f	large
81152	55617	312	Москва, Зеленоградская , 11	f	large
82033	56171	1198	Москва, Зверинецкая улица, 25	f	large
82643	56546	1817	Москва, Затонная улица, 7к3	f	large
82633	56537	1807	Москва, Затонная, 7к3, адрес УИК: Судостроительная ул, дом 20/2, корп. 1	f	large
82356	56374	1524	Москва, Зарайская, 55	f	large
82355	56374	1523	Москва, Зарайская, 55	f	large
81658	55938	820	Москва, Заповедная, 12	f	large
81657	55938	819	Москва, Заповедная, 12	f	large
81656	55937	818	Москва, Заповедная, 22	f	large
81655	55937	817	Москва, Заповедная, 22	f	large
81761	56001	924	Москва, Западная, 1	f	large
82580	56505	1753	Москва, Задонский проезд, 34к2	f	large
82579	56505	1752	Москва, Задонский проезд, 34к2	f	large
82578	56505	1751	Москва, Задонский проезд, 34к2	f	large
82581	56504	1754	Москва, Задонский проезд, 34к3	f	large
82577	56504	1750	Москва, Задонский проезд, 34к3	f	large
82576	56504	1749	Москва, Задонский проезд, 34к3	f	large
82454	56438	1623	Москва, Загорьевский проезд, 13	f	large
82453	56438	1622	Москва, Загорьевский проезд, 13	f	large
82452	56438	1621	Москва, Загорьевский проезд, 13	f	large
82445	56434	1614	Москва, Загорьевский проезд, 7к3	f	large
82444	56434	1613	Москва, Загорьевский проезд, 7к3	f	large
82461	56442	1630	Москва, Загорьевская улица, 29	f	large
82544	56474	1717	Москва, Загородное шоссе, 8кб	f	large
82543	56474	1716	Москва, Загородное шоссе, 8кб	f	large
82545	56474	1718	Москва, Загородное шоссе, 8кб	f	large
83885	57326	3075	Москва, Зеленоград, Заводской переулок, к2011	f	large
83884	57326	3074	Москва, Зеленоград, Заводской переулок, к2011	f	large
82120	56229	1285	Москва, Жулебинский бульвар, 38	f	large
82119	56229	1284	Москва, Жулебинский бульвар, 38	f	large
81036	55513	195	Москва, Житная улица, 6	f	large
83780	57250	2966	Москва, Живописная улица, 11к1	f	large
83799	57264	2986	Москва, Живописная, 32к1	f	large
83798	57264	2985	Москва, Живописная, 32к1	f	large
83782	57251	2968	Москва, Живописная, 11к2	f	large
83781	57251	2967	Москва, Живописная, 11к2	f	large
83774	57245	2960	Москва, Живописная, 2к2	f	large
83773	57245	2959	Москва, Живописная, 2к2	f	large
82053	56191	1218	Москва, Жебрунова, 6с1	f	large
82156	56251	1322	Москва, Есенинский бульвар, 14к2	f	large
82155	56251	1321	Москва, Есенинский бульвар, 14к2	f	large
82150	56237	1316	Москва, Есенинский бульвар, 9к2	f	large
82149	56237	1315	Москва, Есенинский бульвар, 9к2	f	large
82752	56605	1928	Москва, Ереванская улица, 21	f	large
82751	56605	1927	Москва, Ереванская улица, 21	f	large
82750	56605	1926	Москва, Ереванская улица, 21	f	large
82757	56606	1933	Москва, Ереванская, 20К2	f	large
82756	56606	1932	Москва, Ереванская, 20К2	f	large
82755	56606	1931	Москва, Ереванская, 20К2	f	large
82754	56606	1930	Москва, Ереванская, 20К2	f	large
82753	56606	1929	Москва, Ереванская, 20К2	f	large
81375	55778	537	Москва, Енисейская, 32к3	f	large
81374	55778	536	Москва, Енисейская, 32к3	f	large
83327	56957	2508	Москва, Ельнинская, 24	f	large
83314	56957	2495	Москва, Ельнинская, 24	f	large
83329	56943	2510	Москва, Ельнинская, 10	f	large
83294	56943	2475	Москва, Ельнинская, 10	f	large
83293	56943	2474	Москва, Ельнинская, 10	f	large
80874	55380	27	Москва, Елоховский проезд, 1с5	f	large
82732	56596	1908	Москва, Елецкая, 31к2	f	large
82731	56596	1907	Москва, Елецкая, 31к2	f	large
82722	56591	1898	Москва, Елецкая, 12к3	f	large
82721	56591	1897	Москва, Елецкая, 12к3	f	large
82065	56199	1230	Москва, Егерская улица, 4	f	large
82064	56199	1229	Москва, Егерская улица, 4	f	large
83607	57148	2790	Москва, Дубравная, 41к4	f	large
83606	57148	2789	Москва, Дубравная, 41к4	f	large
83605	57146	2788	Москва, Дубравная, 41к3	f	large
83604	57146	2787	Москва, Дубравная, 41к3	f	large
83603	57146	2786	Москва, Дубравная, 41к3	f	large
81257	55690	418	Москва, Дубосековская, 4ас1	f	large
81256	55689	417	Москва, Дубосековская, 3	f	large
81122	55597	282	Москва, Дубнинская улица, 73к5с2	f	large
81121	55597	281	Москва, Дубнинская улица, 73к5с2	f	large
81120	55597	280	Москва, Дубнинская улица, 73к5с2	f	large
81112	55593	272	Москва, Дубнинская улица, 18б	f	large
81111	55593	271	Москва, Дубнинская улица, 18б	f	large
81106	55590	266	Москва, Дубнинская улица, 8а	f	large
81105	55590	265	Москва, Дубнинская улица, 8а	f	large
81082	55566	242	Москва, Дубнинская улица, 59	f	large
81081	55566	241	Москва, Дубнинская улица, 59	f	large
81086	55556	246	Москва, Дубнинская улица, 7	f	large
81068	55556	228	Москва, Дубнинская улица, 7	f	large
81126	55598	286	Москва, Дубнинская , 36а	f	large
81124	55598	284	Москва, Дубнинская , 36а	f	large
81125	55598	285	Москва, Дубнинская , 36а	f	large
81128	55599	288	Москва, Дубнинская, 46к2	f	large
81127	55599	287	Москва, Дубнинская, 46к2	f	large
81110	55592	270	Москва, Дубнинская, 18а	f	large
81109	55592	269	Москва, Дубнинская, 18а	f	large
81107	55591	267	Москва, Дубнинская, 21	f	large
81108	55591	268	Москва, Дубнинская, 21	f	large
81084	55568	244	Москва, Дубнинская, 41, УИК: Дубнинская ул, дом 31	f	large
81083	55567	243	Москва, Дубнинская, 41	f	large
80895	55399	49	Москва, Дубининская, 42	f	large
111530	55398	47	Москва, Дубининская, 25с1	f	medium
80894	55398	48	Москва, Дубининская, 25с1	f	large
81000	55488	159	Москва, Достоевского, 25с1	f	large
82850	56655	2028	Москва, Дорожная, 20а	f	large
82849	56655	2027	Москва, Дорожная, 20а	f	large
82848	56655	2026	Москва, Дорожная, 20а	f	large
83336	56971	2517	Москва, Дорогобужская, 13	f	large
83335	56971	2516	Москва, Дорогобужская, 13	f	large
81038	55527	197	Москва, Донская, 21	f	large
82246	56312	1413	Москва, Донецкая , 14	f	large
82247	56312	1414	Москва, Донецкая , 14	f	large
82715	56588	1891	Москва, Домодедовская, 35к2	f	large
82714	56588	1890	Москва, Домодедовская, 35к2	f	large
82709	56585	1885	Москва, Домодедовская, 44к2	f	large
82708	56584	1884	Москва, Домодедовская, 24к7	f	large
82707	56584	1883	Москва, Домодедовская, 24к7	f	large
80997	55485	156	Москва, Долгоруковская, 26с2	f	large
83649	57173	2832	Москва, Долгова, 12	f	large
81581	55894	743	Москва, Докукина, 5	f	large
81580	55894	742	Москва, Докукина, 5	f	large
81029	55518	188	Москва, Доватора, 5/9	f	large
81432	55811	594	Москва, Добролюбова, 14	f	large
81431	55811	593	Москва, Добролюбова, 14	f	large
82808	56630	1986	Москва, Днепропетровская улица, 33а	f	large
82807	56629	1985	Москва, Днепропетровская улица, 33а	f	large
82806	56628	1984	Москва, Днепропетровская улица, 25а	f	large
82804	56628	1982	Москва, Днепропетровская улица, 25а	f	large
82805	56627	1983	Москва, Днепропетровская улица, 25а	f	large
82803	56627	1981	Москва, Днепропетровская улица, 25а	f	large
82809	56631	1987	Москва, Днепропетровская, 33а	f	large
111581	57383	3178	Москва, Дмитровское шоссе, 165ек1, школа №2044	f	\N
81634	55924	796	Москва, Дмитровское шоссе, 165е к8	f	large
81633	55924	795	Москва, Дмитровское шоссе, 165е к8	f	large
81283	55713	444	Москва, Дмитровское шоссе, 11	f	large
81280	55710	441	Москва, Дмитровское шоссе, 45к1	f	large
81279	55710	440	Москва, Дмитровское шоссе, 45к1	f	large
81272	55704	433	Москва, Дмитровское шоссе, 45к1	f	large
81169	55624	329	Москва, Дмитровское шоссе, 137а	f	large
81162	55624	322	Москва, Дмитровское шоссе, 137а	f	large
81069	55557	229	Москва, Дмитровское шоссе, 66	f	large
81264	55697	425	Москва, Дмитровский проезд, 10с1	f	large
82896	56685	2075	Москва, Дмитрия Ульянова, 15к1	f	large
82879	56672	2058	Москва, Дмитрия Ульянова, 35с1	f	large
81880	56077	1043	Москва, Дмитриевского, 13	f	large
81878	56075	1041	Москва, Дмитриевского, 5	f	large
83145	56856	2324	Москва, Джанкойская , 7	f	large
83144	56856	2323	Москва, Джанкойская , 7	f	large
82523	56475	1693	Москва, Дербеневская, 13	f	large
82522	56475	1692	Москва, Дербеневская, 13	f	large
83261	56923	2442	Москва, Дениса Давыдова, 5, УИК: Давыдова Дениса ул, дом 7	f	large
80998	55486	157	Москва, Делегатская, 3с1	f	large
81536	55871	698	Москва, Декабристов, 8к4	f	large
81535	55871	697	Москва, Декабристов, 8к4	f	large
81534	55871	696	Москва, Декабристов, 8к4	f	large
81182	55635	342	Москва, Дегунинская, 17а	f	large
81181	55635	341	Москва, Дегунинская, 17а	f	large
81180	55634	340	Москва, Дегунинская, 18ас1	f	large
81179	55634	339	Москва, Дегунинская, 18ас1	f	large
81178	55633	338	Москва, Дегунинская, 2	f	large
81177	55633	337	Москва, Дегунинская, 2	f	large
81985	56137	1150	Москва, Девятая Рота, 4	f	large
81984	56136	1149	Москва, Девятая Рота, 14а, адрес УИК: Буженинова ул, дом 22	f	large
81983	56136	1148	Москва, Девятая Рота, 14а, адрес УИК: Буженинова ул, дом 22	f	large
82525	56476	1695	Москва, Даниловская набережная, 6	f	large
82524	56476	1694	Москва, Даниловская набережная, 6	f	large
83579	57132	2762	Москва, Давыдковская улица, 2к6	f	large
83578	57132	2761	Москва, Давыдковская улица, 2к6	f	large
83580	57133	2763	Москва, Давыдковская, 14к1	f	large
82334	56362	1502	Москва, Гурьянова, 33	f	large
82333	56362	1501	Москва, Гурьянова, 33	f	large
82330	56358	1498	Москва, Гурьянова, 15	f	large
82329	56358	1497	Москва, Гурьянова, 15	f	large
82326	56358	1494	Москва, Гурьянова, 15	f	large
82325	56357	1493	Москва, Гурьянова, 2к6	f	large
83333	56968	2514	Москва, Гродненская улица, 5	f	large
83332	56968	2513	Москва, Гродненская улица, 5	f	large
83359	56983	2540	Москва, Гришина, 8к3	f	large
83069	56804	2248	Москва, Грина, 18б	f	large
83068	56804	2247	Москва, Грина, 18б	f	large
83067	56804	2246	Москва, Грина, 18б	f	large
82880	56673	2059	Москва, Гримау, 11ас1	f	large
82875	56669	2054	Москва, Гримау, 8	f	large
81629	55922	791	Москва, Грекова, 3К1	f	large
81628	55922	790	Москва, Грекова, 3К1	f	large
81619	55919	781	Москва, Грекова, 20	f	large
81618	55919	780	Москва, Грекова, 20	f	large
81616	55917	778	Москва, Грекова, 11а	f	large
81615	55917	777	Москва, Грекова, 11а	f	large
81613	55917	775	Москва, Грекова, 11а	f	large
81614	55915	776	Москва, Грекова, 11б	f	large
81611	55915	773	Москва, Грекова, 11б	f	large
82377	56385	1545	Москва, Грайвороново квартал 90А, к12	f	large
82376	56385	1544	Москва, Грайвороново квартал 90А, к12	f	large
111576	57378	3173	Москва, Гостиничная улица, 8к1, в помещении школы №278	f	\N
81494	55845	656	Москва, Гостиничная , 8	f	large
80883	55388	36	Москва, Госпитальный Вал, 5к18	f	large
80882	55387	35	Москва, Госпитальный Вал, 5с19	f	large
80884	55389	37	Москва, Госпитальная набережная, 4с2	f	large
83181	56877	2360	Москва, Горчакова, 9к1	f	large
80867	55373	20	Москва, Гороховский переулок, 4	f	large
83346	56975	2527	Москва, Горбунова, 10с3	f	large
81430	55810	592	Москва, Гончарова, 15б	f	large
81429	55810	591	Москва, Гончарова, 15б	f	large
83203	56890	2382	Москва, Голубинская , 21к3	f	large
83202	56890	2381	Москва, Голубинская , 21к3	f	large
83198	56888	2377	Москва, Голубинская , 5к3	f	large
83197	56888	2376	Москва, Голубинская , 5к3	f	large
83196	56888	2375	Москва, Голубинская , 5к3	f	large
83241	56909	2421	Москва, Голубинская, 28к2	f	large
83240	56909	2420	Москва, Голубинская, 28к2	f	large
83233	56905	2413	Москва, Голубинская, 23к3	f	large
83232	56905	2412	Москва, Голубинская, 23к3	f	large
83201	56889	2380	Москва, Голубинская, 5к2	f	large
83200	56889	2379	Москва, Голубинская, 5к2	f	large
83199	56889	2378	Москва, Голубинская, 5к2	f	large
83195	56887	2374	Москва, Голубинская, 5к4	f	large
83194	56887	2373	Москва, Голубинская, 5к4	f	large
81514	55858	676	Москва, Годовикова, 16а	f	large
81512	55856	674	Москва, Годовикова, 4с1	f	large
83349	56848	2530	Москва, Говорова, 7	f	large
83350	56848	2531	Москва, Говорова, 7	f	large
80922	55423	76	Москва, Глинистый переулок, 7с1	f	large
81703	55964	866	Москва, Глебовская улица, 10	f	large
81694	55964	857	Москва, Глебовская улица, 10	f	large
80914	55414	68	Москва, Гиляровского, 21	f	large
80913	55414	67	Москва, Гиляровского, 21	f	large
83331	56967	2512	Москва, Гжатская, 6	f	large
83330	56967	2511	Москва, Гжатская, 6	f	large
83674	57188	2858	Москва, Героев Панфиловцев, 13к2	f	large
83673	57188	2857	Москва, Героев Панфиловцев, 13к2	f	large
83672	57187	2856	Москва, Героев Панфиловцев, 15	f	large
83659	57179	2843	Москва, Героев Панфиловцев, 45к3	f	large
83658	57179	2842	Москва, Героев Панфиловцев, 45к3	f	large
83569	57126	2752	Москва, Герасима Курина, 10	f	large
83095	56818	2274	Москва, Генерала Тюленева, 19	f	large
83094	56817	2273	Москва, Генерала Тюленева, 19	f	large
83775	57246	2961	Москва, Генерала Глаголева, 9к2	f	large
83600	57144	2783	Москва, Генерала Белобородова, 22	f	large
83599	57144	2782	Москва, Генерала Белобородова, 22	f	large
82964	56733	2143	Москва, Генерала Антонова, 4а	f	large
82963	56733	2142	Москва, Генерала Антонова, 4а	f	large
82962	56733	2141	Москва, Генерала Антонова, 4а	f	large
82960	56732	2139	Москва, Генерала Антонова, 5а, адрес УИК: Антонова генерала ул, дом 5, корп. 3, кв. 75	f	large
82959	56731	2138	Москва, Генерала Антонова, 5А	f	large
83360	56984	2541	Москва, Гвардейская, 15к2	f	large
82056	56193	1221	Москва, Гастелло, 3	f	large
82055	56193	1220	Москва, Гастелло, 3	f	large
83113	56832	2292	Москва, Гарибальди, 19, УИК: Власова архитектора ул, дом 25, корп. 2	f	large
83031	56782	2210	Москва, Гарибальди, 28к3	f	large
83027	56779	2206	Москва, Гарибальди, 8к1	f	large
83026	56779	2205	Москва, Гарибальди, 8к1	f	large
83807	57269	2994	Москва, Гамалеи, 17	f	large
83806	57269	2993	Москва, Гамалеи, 17	f	large
82862	56661	2040	Москва, Газопровод, 9а	f	large
83645	57169	2828	Москва, Габричевского, 8	f	large
81244	55677	405	Москва, Вятская улица, 29	f	large
83338	56972	2519	Москва, Вяземская, 7	f	large
83337	56972	2518	Москва, Вяземская, 7	f	large
82611	56519	1784	Москва, Высокая, 6	f	large
82610	56519	1783	Москва, Высокая, 6	f	large
81268	55699	429	Москва, Вучетича, 6	f	large
81266	55699	427	Москва, Вучетича, 6	f	large
81265	55698	426	Москва, Вучетича, 3/1	f	large
81254	55687	415	Москва, Врубеля, 12	f	large
83646	57170	2829	Москва, Врачебный проезд, 12	f	large
83644	57168	2827	Москва, Врачебный проезд, 12	f	large
83643	57167	2826	Москва, Врачебный проезд, 12, УИК: Полесский пр, дом 4, корп. 2	f	large
82483	56457	1653	Москва, Востряковский проезд, 5б, адрес УИК: Востряковский пр, дом 3А	f	large
82482	56456	1652	Москва, Востряковский проезд, 5б	f	large
82481	56455	1651	Москва, Востряковский проезд, 5б, адрес УИК: Востряковский пр, дом 5, корп. 1	f	large
82480	56453	1650	Москва, Востряковский проезд, 13а	f	large
82479	56453	1649	Москва, Востряковский проезд, 13а	f	large
82478	56452	1648	Москва, Востряковский проезд, 13а	f	large
82530	56479	1700	Москва, Восточная, 4, УИК: Ленинская слобода ул, дом 4	f	large
111539	56479	1706	Москва, Восточная, 4, УИК: Ленинская слобода ул, дом 4	f	medium
82529	56478	1699	Москва, Восточная, 4, УИК: Восточная ул, дом 7	f	large
82528	56478	1698	Москва, Восточная, 4, УИК: Восточная ул, дом 7	f	large
82738	56601	1914	Москва, Воронежская, 46к3	f	large
82737	56601	1913	Москва, Воронежская, 46к3	f	large
82739	56601	1915	Москва, Воронежская, 46к3	f	large
82741	56600	1917	Москва, Воронежская, 46к2	f	large
82740	56600	1916	Москва, Воронежская, 46к2	f	large
82736	56600	1912	Москва, Воронежская, 46к2	f	large
82735	56598	1911	Москва, Воронежская, 44к2	f	large
82728	56593	1904	Москва, Воронежская, 26К4	f	large
82727	56593	1903	Москва, Воронежская, 26К4	f	large
82726	56593	1902	Москва, Воронежская, 26К4	f	large
82720	56590	1896	Москва, Воронежская, 7к2	f	large
82719	56590	1895	Москва, Воронежская, 7к2	f	large
82176	56266	1343	Москва, Волочаевская , 14а	f	large
83598	57143	2781	Москва, Волоцкой переулок, 15к2	f	large
83597	57143	2780	Москва, Волоцкой переулок, 15к2	f	large
82386	56392	1554	Москва, Волжский бульвар, 16к2	f	large
82385	56392	1553	Москва, Волжский бульвар, 16к2	f	large
82380	56387	1548	Москва, Волжский бульвар, 6к3	f	large
82379	56387	1547	Москва, Волжский бульвар, 6к3	f	large
82378	56386	1546	Москва, Волжский бульвар, 6к4	f	large
82164	56255	1330	Москва, Волгоградский проспект, 74к4	f	large
82163	56255	1329	Москва, Волгоградский проспект, 74к4	f	large
82162	56254	1328	Москва, Волгоградский проспект, 58к4	f	large
82161	56254	1327	Москва, Волгоградский проспект, 58к4	f	large
82148	56246	1314	Москва, Волгоградский проспект, 157к3	f	large
82147	56246	1313	Москва, Волгоградский проспект, 157к3	f	large
82146	56245	1312	Москва, Волгоградский проспект, 157к4	f	large
82145	56245	1311	Москва, Волгоградский проспект, 157к4	f	large
82136	56238	1301	Москва, Волгоградский проспект, 109к6	f	large
82135	56236	1300	Москва, Волгоградский проспект, 103к6	f	large
82134	56236	1299	Москва, Волгоградский проспект, 103к6	f	large
83648	57172	2831	Москва, Вишневая, 7	f	large
82994	56753	2173	Москва, Винокурова, 19	f	large
82993	56753	2172	Москва, Винокурова, 19	f	large
83193	56886	2372	Москва, Вильнюсская, 14	f	large
83192	56886	2371	Москва, Вильнюсская, 14	f	large
83191	56884	2370	Москва, Вильнюсская, 12	f	large
111586	57388	3183	Москва, Вилиса Лациса, 31к2, школа № 1399	f	\N
83669	57185	2853	Москва, Вилиса Лациса, 11к2	f	large
83668	57185	2852	Москва, Вилиса Лациса, 11к2	f	large
83667	57184	2851	Москва, Вилиса Лациса, 23К3	f	large
83666	57184	2850	Москва, Вилиса Лациса, 23К3	f	large
83665	57183	2849	Москва, Вилиса Лациса, 21	f	large
83664	57182	2848	Москва, Вилиса Лациса, 33к2	f	large
83663	57182	2847	Москва, Вилиса Лациса, 33к2	f	large
81724	55979	887	Москва, Вешняковская, 29д	f	large
81716	55975	879	Москва, Вешняковская, 2а	f	large
81715	55975	878	Москва, Вешняковская, 2а	f	large
82759	56607	1935	Москва, Веселая, 12	f	large
82758	56607	1934	Москва, Веселая, 12	f	large
81868	56066	1031	Москва, Верхняя Первомайская улица, 32	f	large
82284	56330	1451	Москва, Братиславская, 8к1	f	large
81867	56066	1030	Москва, Верхняя Первомайская улица, 32	f	large
81865	56064	1028	Москва, Верхняя Первомайская, 47	f	large
81854	56053	1017	Москва, Верхняя Первомайская, 23а	f	large
81844	56045	1007	Москва, Верхняя Первомайская, 7	f	large
81235	55671	396	Москва, Верхняя Масловка, 26	f	large
80907	55408	61	Москва, Верхняя Красносельская улица, 14а	f	large
80908	55409	62	Москва, Верхняя Красносельская, 7ас1	f	large
82175	56265	1342	Москва, Верхний Золоторожский переулок, 2	f	large
82305	56343	1472	Москва, Верхние Поля, 40к2	f	large
82298	56338	1465	Москва, Верхние Поля, 30	f	large
82297	56338	1464	Москва, Верхние Поля, 30	f	large
82230	56302	1397	Москва, Верхние Поля, 15к2	f	large
82229	56302	1396	Москва, Верхние Поля, 15к2	f	large
83406	57017	2587	Москва, Веерная улица, 5к3	f	large
83405	57017	2586	Москва, Веерная улица, 5к3	f	large
83404	57016	2585	Москва, Веерная, 5к3, УИК: Веерная ул, дом 3, корп.2	f	large
83401	57015	2582	Москва, Веерная, 38к2	f	large
83400	57015	2581	Москва, Веерная, 38к2	f	large
83402	57006	2583	Москва, Веерная, 5	f	large
83403	57006	2584	Москва, Веерная, 5	f	large
82974	56741	2153	Москва, Введенского, 28	f	large
82972	56738	2151	Москва, Введенского, 27а	f	large
82971	56738	2150	Москва, Введенского, 27а	f	large
82352	56371	1520	Москва, Васильцовский переулок, 1	f	large
82354	56373	1522	Москва, Васильцовский Стан, 4	f	large
82353	56372	1521	Москва, Васильцовский Стан, 6	f	large
80931	55431	88	Москва, Васильевская, 13, адрес УИК: Васильевская ул, дом 2, стр. 6	f	large
83840	57290	3027	Москва, Василия Петушкова, 23к1	f	large
83839	57290	3026	Москва, Василия Петушкова, 23к1	f	large
83297	56945	2478	Москва, Василия Ботылева, 31, УИК: Советская ул, дом 11А	f	large
82868	56663	2046	Москва, Варшавское шоссе, 156б	f	large
82867	56663	2045	Москва, Варшавское шоссе, 156б	f	large
82866	56663	2044	Москва, Варшавское шоссе, 156б	f	large
82865	56662	2043	Москва, Варшавское шоссе, 143к6	f	large
82864	56662	2042	Москва, Варшавское шоссе, 143к6	f	large
82863	56662	2041	Москва, Варшавское шоссе, 143к6	f	large
82845	56653	2023	Москва, Варшавское шоссе, 152к10	f	large
82844	56653	2022	Москва, Варшавское шоссе, 152к10	f	large
82843	56653	2021	Москва, Варшавское шоссе, 152к10	f	large
82783	56617	1960	Москва, Варшавское шоссе, 126а	f	large
82782	56617	1959	Москва, Варшавское шоссе, 126а	f	large
82781	56617	1958	Москва, Варшавское шоссе, 126а	f	large
111543	56561	1838	Москва, Варшавское шоссе, 81к2	f	small
82663	56561	1837	Москва, Варшавское шоссе, 81к2	f	large
82659	56559	1833	Москва, Варшавское шоссе, 70к1	f	large
82550	56492	1723	Москва, Варшавское шоссе, 12	f	large
82549	56492	1722	Москва, Варшавское шоссе, 12	f	large
81226	55664	386	Москва, Валдайский проезд, 14, УИК: Валдайский пр, дом 10, корп. 1	f	large
81229	55664	389	Москва, Валдайский проезд, 14, УИК: Валдайский пр, дом 10, корп. 1	f	large
81225	55663	385	Москва, Валдайский проезд, 8	f	large
81003	55491	162	Москва, Вадковский переулок, 3	f	large
81166	55626	326	Москва, Вагоноремонтная улица, 15а	f	large
81165	55626	325	Москва, Вагоноремонтная улица, 15а	f	large
83022	56775	2201	Москва, Вавилова, 84к2, адрес УИК: Панферова ул, дом 20	f	large
82918	56703	2097	Москва, Вавилова, 44к2	f	large
82897	56686	2076	Москва, Вавилова, 25к1, УИК: Вавилова ул, дом 37а	f	large
82895	56684	2074	Москва, Вавилова, 25к1, адрес УИК: Вавилова ул, дом 51	f	large
111547	56665	2050	Москва, Вавилова, 17	f	medium
111541	56488	1713	Москва, Вавилова, 5	f	medium
82968	56735	2147	Москва, Бутлерова, 38а, УИК: Бутлерова ул, дом 40, корп. 1	f	large
82966	56735	2145	Москва, Бутлерова, 38а, УИК: Бутлерова ул, дом 40, корп. 1	f	large
82950	56724	2129	Москва, Бутлерова, 3	f	large
81197	55642	357	Москва, Бусиновская Горка, 7к1	f	large
81196	55641	356	Москва, Бусиновская Горка, 7ас2	f	large
82476	56451	1646	Москва, Булатниковская улица, 1а	f	large
82475	56451	1645	Москва, Булатниковская улица, 1а	f	large
82477	56450	1647	Москва, Булатниковская, 1а	f	large
82474	56450	1644	Москва, Булатниковская, 1а	f	large
82040	56178	1205	Москва, Буденного просп, 15А	f	large
83251	56916	2432	Москва, Брянская, 10	f	large
83140	56853	2319	Москва, Брусилова, 29к1	f	large
83139	56852	2318	Москва, Брусилова, 29к1	f	large
80975	55465	134	Москва, Брошевский переулок, 23с3	f	large
81034	55523	193	Москва, Бродников переулок, 3, УИК: Якиманка Б. ул, дом 25-27	f	large
82500	56463	1670	Москва, Братеевская улица, 18	f	large
82499	56463	1669	Москва, Братеевская улица, 18	f	large
82498	56463	1668	Москва, Братеевская улица, 18	f	large
82490	56460	1660	Москва, Братеевская улица, 23к4	f	large
82495	56460	1665	Москва, Братеевская улица, 23к4	f	large
82494	56460	1664	Москва, Братеевская улица, 23к4	f	large
82497	56462	1667	Москва, Братеевская, 8к2	f	large
82496	56462	1666	Москва, Братеевская, 8к2	f	large
81488	55840	650	Москва, Ботаническая улица, 9а	f	large
81487	55840	649	Москва, Ботаническая улица, 9а	f	large
81493	55844	655	Москва, Ботаническая, 4	f	large
83390	57004	2571	Москва, Боровское шоссе, 18к4	f	large
83384	56999	2565	Москва, Боровское шоссе, 35к1	f	large
82692	56575	1867	Москва, Борисовский проезд, 40к2	f	large
82691	56575	1866	Москва, Борисовский проезд, 40к2	f	large
82690	56574	1865	Москва, Борисовский проезд, 40к3	f	large
82689	56574	1864	Москва, Борисовский проезд, 40к3	f	large
82686	56572	1861	Москва, Борисовский проезд, 10к2	f	large
82685	56572	1860	Москва, Борисовский проезд, 10к2	f	large
82684	56571	1859	Москва, Борисовский проезд, 13	f	large
82683	56571	1858	Москва, Борисовский проезд, 13	f	large
82505	56464	1675	Москва, Борисовские Пруды, 36к2	f	large
82501	56464	1671	Москва, Борисовские Пруды, 36к2	f	large
82491	56459	1661	Москва, Борисовские Пруды, 20к3	f	large
82488	56459	1658	Москва, Борисовские Пруды, 20к3	f	large
82489	56459	1659	Москва, Борисовские Пруды, 20к3	f	large
82487	56458	1657	Москва, Борисовские Пруды, 12к2	f	large
82486	56458	1656	Москва, Борисовские Пруды, 12к2	f	large
82485	56458	1655	Москва, Борисовские Пруды, 12к2	f	large
82484	56458	1654	Москва, Борисовские Пруды, 12к2	f	large
80962	55456	121	Москва, Большой Факельный переулок, 3	f	large
80961	55455	120	Москва, Большой Факельный переулок, 23	f	large
80858	55364	11	Москва, Большой Трехсвятительский переулок, 4, УИК: Старосадский пер, дом 10, стр. 1	f	large
80942	55440	100	Москва, Большой Трехгорный переулок, 3	f	large
80941	55440	99	Москва, Большой Трехгорный переулок, 3	f	large
81006	55495	165	Москва, Большой Могильцевский переулок, 4-6	f	large
80932	55432	90	Москва, Большой Кондратьевский переулок, 3	f	large
80926	55427	83	Москва, Большой Козихинский переулок, 5	f	large
80996	55484	155	Москва, Большой Каретный переулок, 22с1	f	large
80863	55368	16	Москва, Большой Казенный переулок, 9	f	large
80856	55359	9	Москва, Большой Афанасьевский переулок, 27с1	f	large
80853	55359	6	Москва, Большой Афанасьевский переулок, 27с1	f	large
82945	56721	2124	Москва, Большая Юшуньская, 14	f	large
81992	56142	1157	Москва, Большая Черкизовская, 26	f	large
81991	56142	1156	Москва, Большая Черкизовская, 26	f	large
81993	56142	1158	Москва, Большая Черкизовская, 26	f	large
81986	56138	1151	Москва, Большая Черкизовская, 4к1, УИК: Черкизовская Б. ул, дом 10, корп. 1	f	large
82995	56754	2174	Москва, Большая Черемушкинская, 17а	f	large
82882	56674	2061	Москва, Большая Черемушкинская, 38	f	large
82881	56674	2060	Москва, Большая Черемушкинская, 38	f	large
83566	57124	2749	Москва, Большая Филевская, 39	f	large
83565	57124	2748	Москва, Большая Филевская, 39	f	large
83550	57112	2732	Москва, Большая Филевская, 15, УИК: Физкультурный пр, дом 5	f	large
83549	57112	2731	Москва, Большая Филевская, 15, УИК: Физкультурный пр, дом 5	f	large
83546	57108	2728	Москва, Большая Филевская, 29, Адрес УИК: Филёвская Б. ул, дом 31	f	large
80887	55392	40	Москва, Большая Татарская, 32	f	large
80880	55385	33	Москва, Большая Почтовая, 35с1	f	large
80877	55383	30	Москва, Большая Почтовая, 18/20к18	f	large
80920	55420	74	Москва, Большая Переяславская улица, 1	f	large
80921	55421	75	Москва, Большая Переяславская, 15	f	large
83422	57027	2603	Москва, Большая Очаковская улица, 39к2	f	large
83421	57027	2602	Москва, Большая Очаковская улица, 39к2	f	large
83420	57026	2601	Москва, Большая Очаковская, 25	f	large
83417	57026	2598	Москва, Большая Очаковская, 25	f	large
83419	57025	2600	Москва, Большая Очаковская, 18	f	large
83418	57025	2599	Москва, Большая Очаковская, 18	f	large
83416	57025	2597	Москва, Большая Очаковская, 18	f	large
83425	57023	2606	Москва, Большая Очаковская, 42к2	f	large
82066	56200	1231	Москва, Большая Остроумовская, 12к1	f	large
80889	55394	42	Москва, Большая Ордынка, 15	f	large
81425	55806	587	Москва, Большая Новодмитровская, 63	f	large
111552	57175	2835	Москва, Большая Набережная улица, 15	f	small
80852	55358	5	Москва, Большая Молчановка, 26-28	f	large
81491	55842	653	Москва, Большая Марфинская улица, 7	f	large
81490	55842	652	Москва, Большая Марфинская улица, 7	f	large
81489	55841	651	Москва, Большая Марфинская, 1	f	large
83267	56928	2448	Москва, Большая Дорогомиловская, 10к2	f	large
80937	55436	95	Москва, Большая Грузинская, 13с1	f	large
83249	56914	2430	Москва, Большая Внуковская, 6	f	large
83248	56914	2429	Москва, Большая Внуковская, 6	f	large
83146	56857	2325	Москва, Большая Бутовская , 9	f	large
83147	56858	2326	Москва, Большая Бутовская, 9	f	large
81211	55653	371	Москва, Большая Академическая улица, 77ас1	f	large
81210	55653	370	Москва, Большая Академическая улица, 77ас1	f	large
81209	55652	369	Москва, Большая Академическая улица, 77ас1	f	large
81208	55652	368	Москва, Большая Академическая улица, 77ас1	f	large
81221	55659	381	Москва, Большая Академическая, 22а	f	large
81220	55659	380	Москва, Большая Академическая, 22а	f	large
80916	55416	70	Москва, Больничный переулок, 4	f	large
82923	56706	2102	Москва, Болотниковская, 47к2	f	large
82922	56706	2101	Москва, Болотниковская, 47к2	f	large
82921	56705	2100	Москва, Болотниковская, 52к3	f	large
82920	56705	2099	Москва, Болотниковская, 52к3	f	large
82666	56560	1841	Москва, Болотниковская, 6	f	large
82660	56560	1834	Москва, Болотниковская, 6	f	large
81702	55969	865	Москва, Бойцовая улица, 6к8а	f	large
81701	55969	864	Москва, Бойцовая улица, 6к8а	f	large
81700	55968	863	Москва, Бойцовая, 6к8б	f	large
81699	55967	862	Москва, Бойцовая, 20	f	large
83493	57075	2675	Москва, Богданова, 50	f	large
82034	56172	1199	Москва, Благуша, 6	f	large
82441	56432	1610	Москва, Бирюлевская улица, 50	f	large
82429	56426	1598	Москва, Бирюлевская улица, 7а	f	large
82443	56433	1612	Москва, Бирюлевская, 50	f	large
82442	56433	1611	Москва, Бирюлевская, 50	f	large
82440	56431	1609	Москва, Бирюлевская, 50, УИК: Бирюлевская ул, дом 52, корп. 1	f	large
82435	56428	1604	Москва, Бирюлевская, 23к1	f	large
82434	56428	1603	Москва, Бирюлевская, 23к1	f	large
82428	56425	1597	Москва, Бирюлевская, 28, адрес УИК: Бирюлевская ул, дом 21, корп. 1	f	large
82427	56424	1596	Москва, Бирюлевская, 28	f	large
82426	56424	1595	Москва, Бирюлевская, 28	f	large
80960	55454	119	Москва, Библиотечная , 29, УИК: Библиотечная ул, дом 6	f	large
80959	55454	118	Москва, Библиотечная , 29, УИК: Библиотечная ул, дом 6	f	large
111568	57370	3165	Москва, Бибиревская улица, 6г	f	\N
81351	55765	513	Москва, Бибиревская, 5	f	large
81350	55765	512	Москва, Бибиревская, 5	f	large
81554	55879	716	Москва, Бестужевых, 25б	f	large
81553	55879	715	Москва, Бестужевых, 25б	f	large
81552	55879	714	Москва, Бестужевых, 25б	f	large
81550	55877	712	Москва, Бестужевых, 23	f	large
81548	55877	710	Москва, Бестужевых, 23	f	large
81546	55875	708	Москва, Бестужевых, 1	f	large
81545	55875	707	Москва, Бестужевых, 1	f	large
81542	55875	704	Москва, Бестужевых, 1	f	large
81080	55565	240	Москва, Бескудниковский проезд, 4б	f	large
81079	55564	239	Москва, Бескудниковский проезд, 4а	f	large
81070	55558	230	Москва, Бескудниковский переулок, 4а	f	large
81085	55569	245	Москва, Бескудниковский бульвар, 12	f	large
81078	55563	238	Москва, Бескудниковский бульвар, 50б	f	large
81077	55563	237	Москва, Бескудниковский бульвар, 50б	f	large
81076	55562	236	Москва, Бескудниковский бульвар, 50а	f	large
81075	55561	235	Москва, Бескудниковский бульвар, 53	f	large
81074	55561	234	Москва, Бескудниковский бульвар, 53	f	large
81073	55560	233	Москва, Бескудниковский бульвар, 29	f	large
81072	55560	232	Москва, Бескудниковский бульвар, 29	f	large
81071	55559	231	Москва, Бескудниковский бульвар, 53а	f	large
80957	55452	116	Москва, Берниковская набережная, 12с1	f	large
83787	57255	2974	Москва, Берзарина, 26	f	large
83767	57239	2953	Москва, Берзарина, 19к2	f	large
83766	57239	2952	Москва, Берзарина, 19к2	f	large
83903	57333	3096	Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	f	large
83902	57333	3095	Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	f	large
83904	57332	3097	Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	f	large
83901	57332	3094	Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	f	large
83900	57332	3093	Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	f	large
83899	57332	3092	Москва, Зеленоград, 4-й микрорайон, Березовая аллея, 7а	f	large
83250	56915	2431	Москва, Бережковская набережная, 6, адрес УИК: Бережковская наб, дом 12	f	large
83553	57114	2735	Москва, Береговой проезд, 8, УИК: Новозаводская ул, дом 25, корп. 1	f	large
82304	56342	1471	Москва, Белореченская улица, 45к2	f	large
82303	56342	1470	Москва, Белореченская улица, 45к2	f	large
82302	56341	1469	Москва, Белореченская улица, 36к1	f	large
82218	56294	1385	Москва, Белореченская улица, 8	f	large
82217	56294	1384	Москва, Белореченская улица, 8	f	large
82216	56293	1383	Москва, Белореченская улица, 23а	f	large
82215	56293	1382	Москва, Белореченская улица, 23а	f	large
82301	56340	1468	Москва, Белореченская, 36к2	f	large
82300	56340	1467	Москва, Белореченская, 36к2	f	large
82214	56292	1381	Москва, Белореченская, 11	f	large
82213	56292	1380	Москва, Белореченская, 11	f	large
81230	55666	390	Москва, Беломорская, 19/38	f	large
81384	55784	546	Москва, Белозерская улица, 13	f	large
81385	55785	547	Москва, Белозерская, 15	f	large
81386	55785	548	Москва, Белозерская, 15	f	large
81383	55783	545	Москва, Белозерская, 7	f	large
81382	55783	544	Москва, Белозерская, 7	f	large
83344	56974	2525	Москва, Беловежская , 67	f	large
83343	56974	2524	Москва, Беловежская , 67	f	large
83342	56974	2523	Москва, Беловежская , 67	f	large
83345	56974	2526	Москва, Беловежская , 67	f	large
83341	56973	2522	Москва, Беловежская, 7	f	large
83340	56973	2521	Москва, Беловежская, 7	f	large
83339	56973	2520	Москва, Беловежская, 7	f	large
81061	55550	221	Москва, Беговая, 19, УИК: Ленинградский просп, дом 33, корп. 6	f	large
81242	55676	403	Москва, Башиловская, 24	f	large
80873	55379	26	Москва, Бауманская, 40, адрес УИК: Бауманская ул, дом 39	f	large
82268	56320	1435	Москва, Батайский проезд, 47	f	large
82267	56320	1434	Москва, Батайский проезд, 47	f	large
82266	56320	1433	Москва, Батайский проезд, 47	f	large
82259	56317	1426	Москва, Батайский проезд, 45	f	large
82258	56317	1425	Москва, Батайский проезд, 45	f	large
82256	56315	1423	Москва, Батайский проезд, 23	f	large
82255	56315	1422	Москва, Батайский проезд, 23	f	large
82254	56315	1421	Москва, Батайский проезд, 23	f	large
82253	56314	1420	Москва, Батайский проезд, 21	f	large
82252	56314	1419	Москва, Батайский проезд, 21	f	large
82251	56314	1418	Москва, Батайский проезд, 21	f	large
82313	56348	1481	Москва, Басовская улица, 12с2	f	large
83623	57157	2806	Москва, Барышиха, 42к2	f	large
83622	57157	2805	Москва, Барышиха, 42к2	f	large
83609	57149	2792	Москва, Барышиха, 17к1	f	large
83608	57149	2791	Москва, Барышиха, 17к1	f	large
83184	56878	2363	Москва, Бартеневская, 49к4	f	large
83183	56878	2362	Москва, Бартеневская, 49к4	f	large
83182	56878	2361	Москва, Бартеневская, 49к4	f	large
83180	56876	2359	Москва, Бартеневская, 27	f	large
83179	56876	2358	Москва, Бартеневская, 27	f	large
80939	55438	97	Москва, Баррикадная, 2/1, УИК: Кудринская пл, дом 1	f	large
83548	57110	2730	Москва, Барклая, 15к1	f	large
83541	57103	2723	Москва, Барклая, 5с6	f	large
83540	57103	2722	Москва, Барклая, 5с6	f	large
83347	56976	2528	Москва, Барвихинская улица, 16к1	f	large
82054	56164	1219	Москва, Барболина, 1	f	large
82943	56719	2122	Москва, Балаклавский проспект, 32а	f	large
82942	56719	2121	Москва, Балаклавский проспект, 32а	f	large
82941	56718	2120	Москва, Балаклавский проспект, 32к4	f	large
82675	56567	1850	Москва, Балаклавский проспект, 6а	f	large
82674	56566	1849	Москва, Балаклавский проспект, 6	f	large
82673	56566	1848	Москва, Балаклавский проспект, 6	f	large
80875	55381	28	Москва, Бакунинская улица, 7с1, УИК: Красносельская Нижн, дом 42	f	large
81782	56015	945	Москва, Байкальская , 44	f	large
81192	55639	352	Москва, Базовская, 20а	f	large
81191	55639	351	Москва, Базовская, 20а	f	large
81189	55639	349	Москва, Базовская, 20а	f	large
81190	55639	350	Москва, Базовская, 20а	f	large
83556	57117	2738	Москва, Багратионовский проезд, 7	f	large
83554	57115	2736	Москва, Багратионовский проезд, 10	f	large
83830	57284	3017	Москва, Аэродромная, 9	f	large
81269	55701	430	Москва, Астрадамский проезд, 5	f	large
81267	55700	428	Москва, Астрадамский проезд, 5	f	large
83112	56831	2291	Москва, Архитектора Власова, 19а, адрес УИК: Гарибальди ул, дом 19, корп. 1	f	large
83109	56829	2288	Москва, Архитектора Власова, 19А, УИК: Профсоюзная ул, дом 30, корп. 3	f	large
82396	56398	1564	Москва, Артюхиной, 17	f	large
82395	56398	1563	Москва, Артюхиной, 17	f	large
82669	56564	1844	Москва, Артековская улица, 3	f	large
82668	56564	1843	Москва, Артековская улица, 3	f	large
83584	57135	2767	Москва, Артамонова, 2	f	large
83583	57135	2766	Москва, Артамонова, 2	f	large
80857	55363	10	Москва, Армянский переулок, 4	f	large
82222	56297	1389	Москва, Армавирская, 4	f	large
82221	56297	1388	Москва, Армавирская, 4	f	large
81520	55863	682	Москва, Аргуновская , 12к2с1	f	large
81519	55863	681	Москва, Аргуновская , 12к2с1	f	large
80854	55360	7	Москва, Арбат, 35	f	large
80871	55377	24	Москва, Аптекарский переулок, 8/2	f	large
111577	57379	3174	Москва, Анненский проезд, 1с1, ЗАО «Оливеста»	f	\N
81693	55963	856	Москва, Андреево-Забелинская , 28	f	large
81692	55963	855	Москва, Андреево-Забелинская , 28	f	large
81186	55637	346	Москва, Ангарская, 22а	f	large
81185	55637	345	Москва, Ангарская, 22а	f	large
81486	55839	648	Москва, Анадырский проезд, 51	f	large
81485	55839	647	Москва, Анадырский проезд, 51	f	large
81771	56008	934	Москва, Амурская улица, 25а	f	large
81770	56008	933	Москва, Амурская улица, 25а	f	large
81769	56007	932	Москва, Амурская улица, 60	f	large
81768	56007	931	Москва, Амурская улица, 60	f	large
81765	56005	928	Москва, Амурская, 6	f	large
81592	55902	754	Москва, Амундсена, 11К3	f	large
81591	55901	753	Москва, Амундсена, 5к2	f	large
81589	55899	751	Москва, Амундсена, 10А	f	large
81588	55899	750	Москва, Амундсена, 10А	f	large
83412	57021	2593	Москва, Аминьевское шоссе, 5	f	large
81706	55971	869	Москва, Алымов переулок, 15	f	large
111578	57380	3175	Москва, Алтуфьевское шоссе, 12вс2, центр образования №14860	f	\N
111569	57371	3166	Москва, Алтуфьевское шоссе, 94	f	\N
81544	55876	706	Москва, Алтуфьевское шоссе, 42б	f	large
81543	55876	705	Москва, Алтуфьевское шоссе, 42б	f	large
81538	55872	700	Москва, Алтуфьевское шоссе, 30а	f	large
81537	55872	699	Москва, Алтуфьевское шоссе, 30а	f	large
81531	55869	693	Москва, Алтуфьевское шоссе, 24а	f	large
81530	55869	692	Москва, Алтуфьевское шоссе, 24а	f	large
81529	55868	691	Москва, Алтуфьевское шоссе, 12вс2	f	large
81528	55867	690	Москва, Алтуфьевское шоссе, 13к2	f	large
81527	55867	689	Москва, Алтуфьевское шоссе, 13к2	f	large
81451	55821	613	Москва, Алтуфьевское шоссе, 97к3	f	large
81450	55821	612	Москва, Алтуфьевское шоссе, 97к3	f	large
81424	55805	586	Москва, Алтуфьевское шоссе, 94	f	large
81423	55805	585	Москва, Алтуфьевское шоссе, 94	f	large
81353	55766	515	Москва, Алтуфьевское шоссе, 60б	f	large
81352	55766	514	Москва, Алтуфьевское шоссе, 60б	f	large
81787	56017	950	Москва, Алтайская , 26а	f	large
81788	56017	951	Москва, Алтайская , 26а	f	large
81789	56010	952	Москва, Алтайская, 10а	f	large
81775	56010	938	Москва, Алтайская, 10а	f	large
81774	56010	937	Москва, Алтайская, 10а	f	large
82509	56466	1679	Москва, Алма-Атинская, 9к3	f	large
82508	56466	1678	Москва, Алма-Атинская, 9к3	f	large
82507	56466	1677	Москва, Алма-Атинская, 9к3	f	large
82506	56466	1676	Москва, Алма-Атинская, 9к3	f	large
81910	56098	1074	Москва, Алексея Дикого, 18а	f	large
81911	56098	1075	Москва, Алексея Дикого, 18а	f	large
80990	55478	149	Москва, Александра Невского, 4	f	large
83036	56784	2215	Москва, Академика Челомея, 6а	f	large
83035	56784	2214	Москва, Академика Челомея, 6а	f	large
83034	56784	2213	Москва, Академика Челомея, 6а	f	large
82152	56248	1318	Москва, Академика Скрябина, 36к3	f	large
82151	56248	1317	Москва, Академика Скрябина, 36к3	f	large
82089	56213	1254	Москва, Академика Скрябина, 23с1	f	large
83190	56883	2369	Москва, Академика Понтрягина, 17к1	f	large
83321	56962	2502	Москва, Академика Павлова, 9к2	f	large
83320	56962	2501	Москва, Академика Павлова, 9к2	f	large
82617	56523	1791	Москва, Академика Миллионщикова, 20	f	large
82983	56746	2162	Москва, Академика Капицы, 14а	f	large
82982	56746	2161	Москва, Академика Капицы, 14а	f	large
82981	56745	2160	Москва, Академика Капицы, 12	f	large
82980	56745	2159	Москва, Академика Капицы, 12	f	large
81055	55544	215	Москва, Академика Ильюшина, 8	f	large
81054	55544	214	Москва, Академика Ильюшина, 8	f	large
82984	56747	2163	Москва, Академика Волгина, 41	f	large
82957	56725	2136	Москва, Академика Волгина, 11	f	large
82951	56725	2130	Москва, Академика Волгина, 11	f	large
64849	63936	2929	Пермский край, Пермь, Мира, 39	f	large
83085	56813	2264	Москва, Академика Виноградова, 7, УИК: Теплый стан ул, дом 4	f	large
83084	56813	2263	Москва, Академика Виноградова, 7, УИК: Теплый стан ул, дом 4	f	large
83102	56823	2281	Москва, Академика Варги, 32	f	large
83101	56822	2280	Москва, Академика Варги, 34	f	large
83100	56822	2279	Москва, Академика Варги, 34	f	large
82988	56750	2167	Москва, Академика Арцимовича, 7	f	large
82987	56750	2166	Москва, Академика Арцимовича, 7	f	large
82986	56749	2165	Москва, Академика Арцимовича, 7, УИК: Миклухо-Маклая ул, дом 20	f	large
82985	56749	2164	Москва, Академика Арцимовича, 7, УИК: Миклухо-Маклая ул, дом 20	f	large
83537	57101	2719	Москва, Академика Анохина, 2к5	f	large
83529	57097	2711	Москва, Академика Анохина, 48	f	large
83516	57088	2698	Москва, Академика Анохина, 32	f	large
83515	57088	2697	Москва, Академика Анохина, 32	f	large
83514	57087	2696	Москва, Академика Анохина, 4К5	f	large
82949	56723	2128	Москва, Азовская улица, 41	f	large
82948	56723	2127	Москва, Азовская улица, 41	f	large
82937	56715	2116	Москва, Азовская улица, 2к2	f	large
82947	56722	2126	Москва, Азовская, 31	f	large
82946	56722	2125	Москва, Азовская, 31	f	large
83186	56880	2365	Москва, Адмирала Руднева, 16к1	f	large
83185	56879	2364	Москва, Адмирала Руднева, 16к1	f	large
81043	55531	202	Москва, Авиационный переулок, 6	f	large
83812	57271	2999	Москва, Авиационная, 71к3	f	large
83811	57271	2998	Москва, Авиационная, 71к3	f	large
83810	57271	2997	Москва, Авиационная, 71к3	f	large
82170	56260	1337	Москва, Авиамоторная улица, 42	f	large
82185	56275	1352	Москва, Авиамоторная , 1	f	large
82181	56271	1348	Москва, Авиамоторная , 8А	f	large
82190	56272	1357	Москва, Авиамоторная, 7	f	large
82182	56272	1349	Москва, Авиамоторная, 7	f	large
111535	56259	1336	Москва, Авиамоторная, 51б	f	medium
82169	56259	1335	Москва, Авиамоторная, 51б	f	large
81139	55607	299	Москва, Авангардная улица, 11а	f	large
81138	55607	298	Москва, Авангардная улица, 11а	f	large
81134	55604	294	Москва, Авангардная улица, 5	f	large
111573	57375	3170	Москва, Абрамцевская, 1, ГУП ДЭЗ района Лианозово	f	\N
81638	55927	800	Москва, 9-я Северная линия, 1к2	f	large
81637	55927	799	Москва, 9-я Северная линия, 1к2	f	large
81636	55927	798	Москва, 9-я Северная линия, 1к2	f	large
81123	55596	283	Москва, 800-летия Москвы, 7а	f	large
81119	55596	279	Москва, 800-летия Москвы, 7а	f	large
82391	56396	1559	Москва, 8-я Текстильщиков, 14	f	large
81053	55542	212	Москва, 8 Марта, 17	f	large
82401	56400	1570	Москва, 7-я улица Текстильщиков, 9	f	large
82398	56400	1566	Москва, 7-я улица Текстильщиков, 9	f	large
83367	56989	2548	Москва, 7-я улица Лазенки, 12с3	f	large
81863	56060	1026	Москва, 7-я Парковая, 1а	f	large
81861	56060	1024	Москва, 7-я Парковая, 1а	f	large
81862	56061	1025	Москва, 6-я Парковая, 19	f	large
82410	56410	1579	Москва, 6-я Кожуховская, 8	f	large
83485	57070	2667	Москва, 50 лет Октября, 13а	f	large
83484	57070	2666	Москва, 50 лет Октября, 13а	f	large
83482	57067	2664	Москва, 50 лет Октября, 14А	f	large
83481	57067	2663	Москва, 50 лет Октября, 14А	f	large
82050	56188	1215	Москва, 5-я улица Соколиной Горы, 14	f	large
82048	56186	1213	Москва, 5-я улица Соколиной Горы, 25A	f	large
82045	56183	1210	Москва, 5-я улица Соколиной Горы, 5	f	large
82011	56155	1176	Москва, 5-я Парковая улица, 62	f	large
82008	56152	1173	Москва, 5-я Парковая улица, 49	f	large
82007	56152	1172	Москва, 5-я Парковая улица, 49	f	large
81858	56057	1021	Москва, 5-я Парковая улица, 21	f	large
82012	56154	1177	Москва, 5-я Парковая, 60	f	large
82010	56154	1175	Москва, 5-я Парковая, 60	f	large
82009	56153	1174	Москва, 5-я Парковая, 58	f	large
82533	56482	1703	Москва, 5-я Кожуховская улица, 8, адрес УИК: Сайкина ул, дом 6/5	f	large
82418	56418	1587	Москва, 5-я Кожуховская , 15	f	large
81697	55961	860	Москва, 5-й проезд Подбельского, 2с2	f	large
81690	55961	853	Москва, 5-й проезд Подбельского, 2с2	f	large
81502	55850	664	Москва, 5-й проезд Марьиной Рощи, 15а	f	large
82131	56234	1296	Москва, 5-й квартал Капотня, 28	f	large
82130	56234	1295	Москва, 5-й квартал Капотня, 28	f	large
82129	56234	1294	Москва, 5-й квартал Капотня, 28	f	large
82513	56468	1683	Москва, 5-й Рощинский проезд, 4	f	large
82512	56468	1682	Москва, 5-й Рощинский проезд, 4	f	large
80885	55390	38	Москва, 5-й Монетчиковский переулок, 7	f	large
80983	55471	142	Москва, 5-й Котельнический переулок, 8	f	large
81860	56059	1023	Москва, 4-я Парковая, 12к1	f	large
82373	56383	1541	Москва, 4-я Новокузьминская, 3	f	large
82372	56383	1540	Москва, 4-я Новокузьминская, 3	f	large
81212	55651	372	Москва, 4-й Новомихалковский проезд, 9а	f	large
81207	55651	367	Москва, 4-й Новомихалковский проезд, 9а	f	large
82364	56378	1532	Москва, 4-й Вешняковский проезд, 1к1	f	large
82363	56378	1531	Москва, 4-й Вешняковский проезд, 1к1	f	large
82362	56378	1530	Москва, 4-й Вешняковский проезд, 1к1	f	large
81022	55510	181	Москва, 3-я Фрунзенская, 5, УИК: Фрунзенская наб, дом 42	f	large
81635	55926	797	Москва, 3-я Северная линия, 17	f	large
82061	56197	1226	Москва, 3-я Рыбинская улица, 18с1	f	large
111538	56443	1631	Москва, 3-я Радиальная, 8	f	medium
81857	56056	1020	Москва, 3-я Парковая , 22а	f	large
81517	55861	679	Москва, 3-я Новоостанкинская улица, 17	f	large
81969	56128	1134	Москва, 3-я Владимирская , 26а	f	large
81968	56128	1133	Москва, 3-я Владимирская , 26а	f	large
81975	56131	1140	Москва, 3-я Владимирская, 5	f	large
81974	56131	1139	Москва, 3-я Владимирская, 5	f	large
81971	56129	1136	Москва, 3-я Владимирская, 30а	f	large
81970	56129	1135	Москва, 3-я Владимирская, 30а	f	large
81967	56127	1132	Москва, 3-я Владимирская, 12а	f	large
81966	56127	1131	Москва, 3-я Владимирская, 12а	f	large
81505	55852	667	Москва, 3-й проезд Марьиной Рощи, 41	f	large
80999	55487	158	Москва, 3-й Самотечный переулок, 14	f	large
82521	56473	1691	Москва, 3-й Павловский переулок, 14	f	large
82520	56473	1690	Москва, 3-й Павловский переулок, 14	f	large
81102	55586	262	Москва, 3-й Новоподмосковный переулок, 7	f	large
81101	55585	261	Москва, 3-й Новоподмосковный переулок, 7	f	large
81275	55707	436	Москва, 3-й Нижнелихоборский проезд, 1с16	f	large
81216	55656	376	Москва, 3-й Михалковский переулок, 16	f	large
83615	57152	2798	Москва, 3-й Митинский проезд, 12	f	large
83614	57152	2797	Москва, 3-й Митинский проезд, 12	f	large
83613	57151	2796	Москва, 3-й Митинский проезд, 12к1	f	large
83612	57151	2795	Москва, 3-й Митинский проезд, 12к1	f	large
81132	55602	292	Москва, 3-й Лихачевский переулок, 2а	f	large
81131	55602	291	Москва, 3-й Лихачевский переулок, 2а	f	large
82415	56413	1584	Москва, 3-й Кожуховский проезд, 3а	f	large
82413	56413	1582	Москва, 3-й Кожуховский проезд, 3а	f	large
81033	55522	192	Москва, 3-й Кадашевский переулок, 9	f	large
82858	56658	2036	Москва, 3-й Дорожный проезд, 6а	f	large
82857	56658	2035	Москва, 3-й Дорожный проезд, 6а	f	large
82856	56658	2034	Москва, 3-й Дорожный проезд, 6а	f	large
83524	57093	2706	Москва, 26-ти Бакинских Комиссаров, 3К4	f	large
83525	57093	2707	Москва, 26-ти Бакинских Комиссаров, 3К4	f	large
83526	57092	2708	Москва, 26-ти Бакинских Комиссаров, 3к5	f	large
83523	57092	2705	Москва, 26-ти Бакинских Комиссаров, 3к5	f	large
80945	55443	104	Москва, 2-я Черногрязская, 7с1	f	large
81241	55675	402	Москва, 2-я Хуторская улица, 15	f	large
81240	55675	401	Москва, 2-я Хуторская улица, 15	f	large
81021	55509	180	Москва, 2-я Фрунзенская, 7а, адрес УИК: Фрунзенская 2-я ул, дом 7	f	large
81020	55509	179	Москва, 2-я Фрунзенская, 7а, адрес УИК: Фрунзенская 2-я ул, дом 7	f	large
80991	55479	150	Москва, 2-я Тверская-Ямская, 46	f	large
81088	55571	248	Москва, 2-я Радиаторская , 9	f	large
81090	55573	250	Москва, 2-я Радиаторская, 9, УИК: Войковский 4-й пр, дом 9	f	large
81089	55572	249	Москва, 2-я Радиаторская, 9	f	large
81988	56139	1153	Москва, 2-я Пугачевская , 10	f	large
81987	56139	1152	Москва, 2-я Пугачевская , 10	f	large
81990	56141	1155	Москва, 2-я Пугачевская, 7	f	large
81989	56140	1154	Москва, 2-я Пугачевская, 6а	f	large
81263	55696	424	Москва, 2-я Песчаная улица, 4а	f	large
81477	55833	639	Москва, 2-я Напрудная, 17	f	large
81476	55833	638	Москва, 2-я Напрудная, 17	f	large
81475	55833	637	Москва, 2-я Напрудная, 17	f	large
82359	56376	1527	Москва, 2-я Институтская, 6с	f	large
80946	55444	105	Москва, 2-я Звенигородская улица, 13с41	f	large
80944	55442	103	Москва, 2-я Звенигородская , 8, УИК: 1905 года ул, дом 5	f	large
80943	55441	102	Москва, 2-я Звенигородская, 8, УИК: 1905 года ул, дом 5	f	large
80979	55467	138	Москва, 2-я Дубровская, 3, УИК: Дубровская 1-я ул, дом 5А	f	large
80978	55467	137	Москва, 2-я Дубровская, 3, УИК: Дубровская 1-я ул, дом 5А	f	large
81691	55962	854	Москва, 2-я Гражданская улица, 8	f	large
111536	56345	1477	Москва, 2-я Вольская, 7к2	f	small
82309	56345	1476	Москва, 2-я Вольская, 7к2	f	large
81961	56123	1126	Москва, 2-я Владимирская, 22а	f	large
82422	56422	1591	Москва, 2-й Южнопортовый проезд, 11с1	f	large
82421	56421	1590	Москва, 2-й Южнопортовый проезд, 11с1	f	large
82548	56491	1721	Москва, 2-й Тульский переулок, 4, адрес УИК: Варшавское шоссе, дом 2	f	large
80912	55413	66	Москва, 2-й Троицкий переулок, 6	f	large
83446	57043	2628	Москва, 2-й Сетуньский проезд, 9	f	large
83445	57043	2627	Москва, 2-й Сетуньский проезд, 9	f	large
81578	55893	740	Москва, 2-й Сельскохозяйственный проезд, 4	f	large
81004	55493	163	Москва, 2-й Обыденский переулок, 9	f	large
80909	55410	63	Москва, 2-й Красносельский переулок, 18	f	large
82318	56351	1486	Москва, 2-й Карачаровский проезд, 1	f	large
82542	56489	1715	Москва, 2-й Верхний Михайловский проезд, 9а	f	large
82541	56489	1714	Москва, 2-й Верхний Михайловский проезд, 9а	f	large
81048	55536	207	Москва, 2-й Балтийский переулок, 3	f	large
82026	56165	1191	Москва, 16-я Парковая, 20	f	large
82023	56162	1188	Москва, 15-я Парковая улица, 46а	f	large
82021	56162	1186	Москва, 15-я Парковая улица, 46а	f	large
82016	56158	1181	Москва, 13-я Парковая улица, 33	f	large
82369	56381	1537	Москва, 12-я Новокузьминская, 6к2	f	large
82368	56381	1536	Москва, 12-я Новокузьминская, 6к2	f	large
82367	56381	1535	Москва, 12-я Новокузьминская, 6к2	f	large
82390	56393	1558	Москва, 11-я Текстильщиков, 6	f	large
82387	56393	1555	Москва, 11-я Текстильщиков, 6	f	large
82015	56157	1180	Москва, 11-я Парковая улица, 50	f	large
82014	56157	1179	Москва, 11-я Парковая улица, 50	f	large
81753	55996	916	Москва, 11-я Парковая, 36	f	large
82392	56394	1560	Москва, 1-я улица Текстильщиков, 5/8	f	large
82388	56394	1556	Москва, 1-я улица Текстильщиков, 5/8	f	large
82409	56409	1578	Москва, 1-я улица Машиностроения, 12к2	f	large
82408	56409	1577	Москва, 1-я улица Машиностроения, 12к2	f	large
82407	56408	1576	Москва, 1-я улица Машиностроения, 3/5а	f	large
82389	56395	1557	Москва, 1-я Текстильщиков, 16	f	large
82393	56395	1561	Москва, 1-я Текстильщиков, 16	f	large
81851	56051	1014	Москва, 1-я Парковая, 12	f	large
81526	55866	688	Москва, 1-я Останкинская, 29	f	large
81525	55866	687	Москва, 1-я Останкинская, 29	f	large
81524	55866	686	Москва, 1-я Останкинская, 29	f	large
82366	56380	1534	Москва, 1-я Новокузьминская улица, 21	f	large
82365	56380	1533	Москва, 1-я Новокузьминская улица, 21	f	large
82375	56384	1543	Москва, 1-я Новокузьминская, 20к4	f	large
82374	56384	1542	Москва, 1-я Новокузьминская, 20к4	f	large
81684	55957	847	Москва, 1-я Мясниковская, 16	f	large
80988	55476	147	Москва, 1-я Миусская улица, 4	f	large
82404	56405	1573	Москва, 1-я Дубровская улица, 16	f	large
82405	56406	1574	Москва, 1-я Дубровская, 16, УИК: Симоновский вал ул, дом 11/31	f	large
81705	55970	868	Москва, 1-я Гражданская, 96	f	large
81704	55970	867	Москва, 1-я Гражданская, 96	f	large
82311	56346	1479	Москва, 1-я Вольская, 9к3	f	large
82310	56346	1478	Москва, 1-я Вольская, 9к3	f	large
82308	56344	1475	Москва, 1-я Вольская, 5	f	large
82307	56344	1474	Москва, 1-я Вольская, 5	f	large
81960	56122	1125	Москва, 1-я Владимирская улица, 20	f	large
81959	56122	1124	Москва, 1-я Владимирская улица, 20	f	large
81958	56122	1123	Москва, 1-я Владимирская улица, 20	f	large
81964	56124	1129	Москва, 1-я Владимирская, 11/13	f	large
81962	56124	1127	Москва, 1-я Владимирская, 11/13	f	large
81044	55532	203	Москва, 1-я Аэропортовская, 1	f	large
81501	55849	663	Москва, 1-й проезд Марьиной Рощи, 3а	f	large
81500	55849	662	Москва, 1-й проезд Марьиной Рощи, 3а	f	large
81013	55502	172	Москва, 1-й переулок Тружеников, 18	f	large
80896	55400	50	Москва, 1-й Щипковский переулок, 23	f	large
81309	55732	471	Москва, 1-й Хорошевский проезд, 8с1, УИК: Хорошевский 1-й пр, дом 2/17	f	large
83656	57177	2840	Москва, 1-й Тушинский проезд, 13	f	large
83655	57177	2839	Москва, 1-й Тушинский проезд, 13	f	large
80886	55391	39	Москва, 1-й Новокузнецкий переулок, 12	f	large
81009	55498	168	Москва, 1-й Неопалимовский переулок, 10, адрес УИК: Смоленский бульв, дом 15	f	large
82603	56516	1776	Москва, 1-й Нагатинский проезд, 16	f	large
82347	56367	1515	Москва, 1-й Курьяновский проезд, 14	f	large
82346	56367	1514	Москва, 1-й Курьяновский проезд, 14	f	large
82532	56480	1702	Москва, 1-й Кожуховский, 17, адрес УИК: Кожуховский 1-й пр, дом 19, корп. 1	f	large
82531	56480	1701	Москва, 1-й Кожуховский, 17, адрес УИК: Кожуховский 1-й пр, дом 19, корп. 1	f	large
81982	56135	1147	Москва, 1-й Зборовский переулок, 3	f	large
81981	56135	1146	Москва, 1-й Зборовский переулок, 3	f	large
81012	55501	171	Москва, 1-й Вражский переулок, 4, УИК: Плющиха ул, дом 30	f	large
83795	57261	2982	Москва, 1-й Волоколамский проезд, 9к1	f	large
82361	56377	1529	Москва, 1-й Вешняковский проезд, 6/10	f	large
82360	56377	1528	Москва, 1-й Вешняковский проезд, 6/10	f	large
81062	55551	222	Москва, 1-й Боткинский проезд, 31а	f	large
81595	55905	757	Москва, 1-й Ботанический проезд, 2	f	large
81050	55538	209	Москва, 1-й Амбулаторный проезд, 8с1	f	large
82312	56347	1480	Москва, 1-ая Вольская, 22к2	f	large
82394	56397	1562	Москва, Юных Ленинцев, 35к2	f	large
81023	55511	182	Москва, Хамовнический Вал, 6, УИК: Фрунзенская 3-я ул, дом 3	f	large
82141	56243	1307	Москва, Федора Полетаева, 2к7	f	large
82140	56243	1306	Москва, Федора Полетаева, 2к7	f	large
81014	55503	173	Москва, Тимура Фрунзе, 28, УИК: Зубовский пр, дом 2, стр. 2	f	large
82417	56416	1586	Москва, Петра Романова, 16	f	large
81726	55980	889	Москва, Молдагуловой, 13а	f	large
81725	55980	888	Москва, Молдагуловой, 13а	f	large
81440	55816	602	Москва, Милашенкова, 7а	f	large
82237	56306	1404	Москва, Марьинский Парк, 37	f	large
82236	56306	1403	Москва, Марьинский Парк, 37	f	large
83792	57259	2979	Москва, Маршала Рыбалко, 1	f	large
82677	56568	1852	Москва, Маршала Захарова, 25	f	large
82676	56568	1851	Москва, Маршала Захарова, 25	f	large
81316	55739	478	Москва, Куусинена, 13, УИК: Куусинена ул, дом 9, корп. 1	f	large
82813	56632	1991	Москва, Красного Маяка, 13а	f	large
82810	56632	1988	Москва, Красного Маяка, 13а	f	large
82595	56511	1768	Москва, Кошкина, 13к2	f	large
82594	56511	1767	Москва, Кошкина, 13к2	f	large
82593	56511	1766	Москва, Кошкина, 13к2	f	large
82871	56664	2049	Москва, Газопровод, 5а	f	large
82870	56664	2048	Москва, Газопровод, 5а	f	large
82869	56664	2047	Москва, Газопровод, 5а	f	large
82601	56513	1774	Москва, Борисовские Пруды, 11к1	f	large
82600	56513	1773	Москва, Борисовские Пруды, 11к1	f	large
83621	57155	2804	Москва, Барышиха, 42к1	f	large
83620	57155	2803	Москва, Барышиха, 42к1	f	large
83611	57150	2794	Москва, Барышиха, 29к1	f	large
83610	57150	2793	Москва, Барышиха, 29к1	f	large
83808	57270	2995	Москва, Академика Бочвара, 2к2	f	large
83535	57099	2717	Москва, Академика Анохина, 36	f	large
83534	57099	2716	Москва, Академика Анохина, 36	f	large
83533	57099	2715	Москва, Академика Анохина, 36	f	large
83532	57099	2714	Москва, Академика Анохина, 36	f	large
80935	55435	93	Москва, 1905 Года, 8	f	large
85976	13806	161	Ямало-Ненецкий автономный округ, Тарко-Сале	f	large
85974	13804	159	Ямало-Ненецкий автономный округ, Тарко-Сале, Ленина, 16	f	large
85977	13807	162	Ямало-Ненецкий автономный округ, Тарко-Сале, Губкина, 9	f	large
85994	13825	181	Ямало-Ненецкий автономный округ, Салехард, Чкалова, 14	f	large
85996	13827	183	Ямало-Ненецкий автономный округ, Салехард, Титова, 19	f	large
130874	13854	210	Ямало-Ненецкий автономный округ, Салехард, Республики, 54	f	\N
85990	13822	177	Ямало-Ненецкий автономный округ, Салехард, Республики, 123	f	large
85986	13819	173	Ямало-Ненецкий автономный округ, Салехард, Республики, 50	f	large
85985	13818	172	Ямало-Ненецкий автономный округ, Салехард, Республики, 36а	f	large
85987	13799	174	Ямало-Ненецкий автономный округ, Салехард, Республики, 74	f	large
85991	13799	178	Ямало-Ненецкий автономный округ, Салехард, Республики, 74	f	large
85993	13824	180	Ямало-Ненецкий автономный округ, Салехард, Маяковского, 36	f	large
85992	13811	179	Ямало-Ненецкий автономный округ, Салехард, Маяковского, 22	f	large
85988	13820	175	Ямало-Ненецкий автономный округ, Салехард, Матросова, 33	f	large
85995	13826	182	Ямало-Ненецкий автономный округ, Салехард, Кооперативная, 22а	f	large
130875	13855	211	Ямало-Ненецкий автономный округ, Салехард, Комсомольская, 17	f	\N
85989	13821	176	Ямало-Ненецкий автономный округ, Салехард, Артеева, 17	f	large
85961	13786	141	Ямало-Ненецкий автономный округ, Ноябрьск, МОУ СОШ №10	f	large
85960	13785	140	Ямало-Ненецкий автономный округ, Ноябрьск, МОУ СОШ №10	f	large
85962	13738	142	Ямало-Ненецкий автономный округ, Ноябрьск, СМП329	f	large
85948	13773	128	Ямало-Ненецкий автономный округ, Ноябрьск, Холмогорская, 66а	f	large
85947	13772	127	Ямало-Ненецкий автономный округ, Ноябрьск, Холмогорская, 29	f	large
85946	13772	126	Ямало-Ненецкий автономный округ, Ноябрьск, Холмогорская, 29	f	large
85945	13771	125	Ямало-Ненецкий автономный округ, Ноябрьск, Холмогорская, 29	f	large
85964	13788	144	Ямало-Ненецкий автономный округ, Ноябрьск, Транспортная, 38	f	large
85963	13787	143	Ямало-Ненецкий автономный округ, Ноябрьск, Транспортная, 38	f	large
85955	13780	135	Ямало-Ненецкий автономный округ, Ноябрьск, Советская, 19а	f	large
85953	13778	133	Ямало-Ненецкий автономный округ, Ноябрьск, Советская, 51	f	large
85935	13761	115	Ямало-Ненецкий автономный округ, Ноябрьск, Советская, 79	f	large
85934	13760	114	Ямало-Ненецкий автономный округ, Ноябрьск, Советская, 82	f	large
85937	13763	117	Ямало-Ненецкий автономный округ, Ноябрьск, Магистральная, 71	f	large
85936	13762	116	Ямало-Ненецкий автономный округ, Ноябрьск, Магистральная, 71	f	large
85957	13782	137	Ямало-Ненецкий автономный округ, Ноябрьск, Лиственная, 28	f	large
85956	13781	136	Ямало-Ненецкий автономный округ, Ноябрьск, Лиственная, 28	f	large
85958	13783	138	Ямало-Ненецкий автономный округ, Ноябрьск, Ленина, 29	f	large
85952	13777	132	Ямало-Ненецкий автономный округ, Ноябрьск, Ленина, 12	f	large
85951	13776	131	Ямало-Ненецкий автономный округ, Ноябрьск, Ленина, 25	f	large
85942	13768	122	Ямало-Ненецкий автономный округ, Ноябрьск, Ленина, 41	f	large
85932	13759	112	Ямало-Ненецкий автономный округ, Ноябрьск, Ленина, 67а	f	large
85933	13708	113	Ямало-Ненецкий автономный округ, Ноябрьск, Ленина, 67а	f	large
85950	13775	130	Ямало-Ненецкий автономный округ, Ноябрьск, Космонавтов, 22а	f	large
85949	13774	129	Ямало-Ненецкий автономный округ, Ноябрьск, Космонавтов, 22а	f	large
85944	13770	124	Ямало-Ненецкий автономный округ, Ноябрьск, Изыскателей, 47	f	large
85959	13784	139	Ямало-Ненецкий автономный округ, Ноябрьск, Дружбы, 1	f	large
85941	13767	121	Ямало-Ненецкий автономный округ, Ноябрьск, Дзержинского, 10в	f	large
85940	13766	120	Ямало-Ненецкий автономный округ, Ноябрьск, Дзержинского, 10в	f	large
85939	13765	119	Ямало-Ненецкий автономный округ, Ноябрьск, Дзержинского, 7	f	large
85938	13764	118	Ямало-Ненецкий автономный округ, Ноябрьск, Дзержинского, 7	f	large
85931	13758	111	Ямало-Ненецкий автономный округ, Ноябрьск, Высоцкого, 40а	f	large
85930	13757	110	Ямало-Ненецкий автономный округ, Ноябрьск, Высоцкого, 40а	f	large
85929	13756	109	Ямало-Ненецкий автономный округ, Ноябрьск, Высоцкого, 40а	f	large
85954	13779	134	Ямало-Ненецкий автономный округ, Ноябрьск, 60 лет СССР, 7а	f	large
130851	13733	83	Ямало-Ненецкий автономный округ, Новый Уренгой, ОАО Новоуренгойский объединенный авиаотряд	f	medium
85924	13752	104	Ямало-Ненецкий автономный округ, Новый Уренгой, проспект Мира, 53	f	large
85897	13725	71	Ямало-Ненецкий автономный округ, Новый Уренгой, проспект Ленинградский, 9	f	large
85927	13754	107	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Юбилейный, 6 корп., 1	f	large
85920	13745	98	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Юбилейный, 6 корп., 3	f	large
130849	13727	74	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Энергетик	f	small
85915	13742	93	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Советский, 3 корп., 3	f	large
85914	13741	92	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Советский, 10 корп., 2	f	large
85922	13748	100	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Приозерный, 10а	f	large
85906	13731	81	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Оптимистов, 4 корп.3	f	large
85919	13744	97	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Мирный, 5 корп., 4	f	large
85918	13744	96	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Мирный, 5 корп., 4	f	large
85917	13743	95	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Мирный, 5 корп., 6	f	large
85916	13743	94	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Мирный, 5 корп., 6	f	large
85911	13739	89	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Дружба, 2 корп., 10	f	large
85909	13737	87	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Восточный, 7	f	large
85910	13737	88	Ямало-Ненецкий автономный округ, Новый Уренгой, мкр. Восточный, 7	f	large
85926	13730	106	Ямало-Ненецкий автономный округ, Новый Уренгой, Таежная, 51	f	large
85905	13730	80	Ямало-Ненецкий автономный округ, Новый Уренгой, Таежная, 51	f	large
85923	13751	103	Ямало-Ненецкий автономный округ, Новый Уренгой, Октябрьская, 22	f	large
85902	13728	77	Ямало-Ненецкий автономный округ, Новый Уренгой, Молодежная, 17а	f	large
85901	13718	76	Ямало-Ненецкий автономный округ, Новый Уренгой, Молодежная, 23	f	large
64853	64116	2933	Пермский край, Пермь, Мира, 92	f	large
85900	13718	75	Ямало-Ненецкий автономный округ, Новый Уренгой, Молодежная, 23	f	large
85928	13755	108	Ямало-Ненецкий автономный округ, Новый Уренгой, Звездная, 16	f	large
85908	13736	86	Ямало-Ненецкий автономный округ, Новый Уренгой, Губкина, 13	f	large
85907	13735	85	Ямало-Ненецкий автономный округ, Новый Уренгой, Губкина, 16а	f	large
130852	13734	84	Ямало-Ненецкий автономный округ, Новый Уренгой, Газовиков, 1	f	small
85925	13753	105	Ямало-Ненецкий автономный округ, Новый Уренгой, Гагарина, 1	t	large
85896	13724	70	Ямало-Ненецкий автономный округ, Новый Уренгой, 6 съезда КПСС, 4г	f	large
85895	13724	69	Ямало-Ненецкий автономный округ, Новый Уренгой, 6 съезда КПСС, 4г	f	large
85879	13699	46	Ямало-Ненецкий автономный округ, Надым, бульвар Стрижова, 2, Школа искусств	f	large
85877	13697	44	Ямало-Ненецкий автономный округ, Надым, Пионерская, ДК Прометей ООО Газпром добыча Надым	f	large
85873	13693	40	Ямало-Ненецкий автономный округ, Надым, Парковая, 4, Дворец торжественных обрядов	f	large
85884	13704	51	Ямало-Ненецкий автономный округ, Надым, Набережная им.Оруджева, 55, МОУ СОШ №6	f	large
85878	13698	45	Ямало-Ненецкий автономный округ, Надым, Набережная им.Оруджева, 13/1, МОУ СОШ №5	f	large
85874	13694	41	Ямало-Ненецкий автономный округ, Надым, Комсомольская, 25-А, МОУ СОШ №2	f	large
85872	13692	39	Ямало-Ненецкий автономный округ, Надым, Комсомольская, 2, МОУ СОШ №1	f	large
85883	13703	50	Ямало-Ненецкий автономный округ, Надым, Зверева, 42-А, Центр детского творчества	f	large
85881	13701	48	Ямало-Ненецкий автономный округ, Надым, Заводская, 7А, МОУ СОШ №9	f	large
85880	13700	47	Ямало-Ненецкий автономный округ, Надым, Заводская, 7-А, МОУ СОШ №9	f	large
85875	13695	42	Ямало-Ненецкий автономный округ, Надым, Геологоразведчиков, 5/1, МОУ СОШ №3	f	large
85854	13675	20	Ямало-Ненецкий автономный округ, Лабытнанги, площадь В.Нака, 2	f	large
85855	13676	21	Ямало-Ненецкий автономный округ, Лабытнанги, Школьная, 43	f	large
85853	13674	19	Ямало-Ненецкий автономный округ, Лабытнанги, Школьная, 18	f	large
85860	13682	27	Ямало-Ненецкий автономный округ, Лабытнанги, Революции, 14, МОУ СОШ №5	f	large
85850	13671	15	Ямало-Ненецкий автономный округ, Лабытнанги, Рабочая, 1	f	large
130839	13671	14	Ямало-Ненецкий автономный округ, Лабытнанги, Рабочая, 1	f	medium
85852	13673	18	Ямало-Ненецкий автономный округ, Лабытнанги, Октябрьская, 17	f	large
130840	13673	17	Ямало-Ненецкий автономный округ, Лабытнанги, Октябрьская, 17	f	medium
85851	13672	16	Ямало-Ненецкий автономный округ, Лабытнанги, Октябрьская, 17	f	large
85859	13681	26	Ямало-Ненецкий автономный округ, Лабытнанги, Корчагинцев, 7	f	large
130841	13680	25	Ямало-Ненецкий автономный округ, Лабытнанги, Дзержинского, 45	f	medium
85856	13677	22	Ямало-Ненецкий автономный округ, Лабытнанги, Дзержинского, 20	f	large
85858	13679	24	Ямало-Ненецкий автономный округ, Лабытнанги, Гиршгорна, 53А	f	large
85857	13678	23	Ямало-Ненецкий автономный округ, Лабытнанги, Гиршгорна, 53А	f	large
85846	13667	9	Ямало-Ненецкий автономный округ, Губкинский, микрорайон № 5, МЦ «Факел»	f	large
130837	13662	4	Ямало-Ненецкий автономный округ, Губкинский, 4 микрорайон, МОУ СОШ №5	f	medium
85839	13659	1	Ямало-Ненецкий автономный округ, Губкинский, 2 микрорайон, 1, МОУ СОШ №1	f	large
85845	13666	8	Ямало-Ненецкий автономный округ, Губкинский, 14 микрорайон, СОК Ямал	f	large
86006	13849	205	Ямало-Ненецкий автономный округ, Ямальский район, Яр-Сале, Худи-Сэроко, 8	f	large
86007	13850	206	Ямало-Ненецкий автономный округ, Ямальский район, поселок Сюнэйсале, Анагуричи, 22	f	large
86010	13853	209	Ямало-Ненецкий автономный округ, Ямальский район, поселок Сеяха, Вануйто, 9	t	large
130873	13847	203	Ямало-Ненецкий автономный округ, Ямальский район, поселок Салемал, Гагарина, 17	f	medium
86005	13848	204	Ямало-Ненецкий автономный округ, Ямальский район, поселок Панаевск, Обская, 6, МОШИ Панаевская ШколаИнтернат	f	large
86008	13851	207	Ямало-Ненецкий автономный округ, Ямальский район, село Новый порт, Полярная, 1	t	large
86009	13852	208	Ямало-Ненецкий автономный округ, Ямальский район, поселок Мыс-Каменный, Геологов, 5	t	large
130872	13846	202	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Шурышкары, Центральная, 13а	f	medium
130871	13845	201	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Питляр, Советская, 19	f	small
130870	13844	200	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Овгорт, Кооперативная, 30	t	medium
86004	13843	199	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Мужи, Комсомольская, 3	f	large
130869	13842	198	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Лопхари, Советская, 8	t	small
130856	13792	148	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Катровож, Школьная, 1	f	small
86003	13841	197	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Горки, Заводская, 8	f	large
130868	13840	196	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Восяхово, Советская, 17а	f	small
130867	13839	195	Ямало-Ненецкий автономный округ, Шурышкарский район, поселок Азовы, Школьная, 8	f	small
130864	13832	188	Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский, Пристанская, 23	f	medium
130866	13837	193	Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский, Почтовая, 31, МБУ Тазовский районный краеведческий музей	f	medium
130863	13831	187	Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский, Пиеттомина, 10	f	medium
85998	13830	186	Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский, Ленина, 30	f	large
85997	13829	185	Ямало-Ненецкий автономный округ, Тазовский район, поселок Тазовский, Геофизиков, 28а	f	large
86002	13838	194	Ямало-Ненецкий автономный округ, Тазовский район, поселок Новозаполярный, Культурноспортивный комплекс	t	large
130865	13834	190	Ямало-Ненецкий автономный округ, Тазовский район, поселок Находка, Подгорная, 2	t	medium
86001	13836	192	Ямало-Ненецкий автономный округ, Тазовский район, поселок Гыда, Советская, 3	t	large
85999	13833	189	Ямало-Ненецкий автономный округ, Тазовский район, поселок Газсале, Молодежная, 9	f	large
86000	13835	191	Ямало-Ненецкий автономный округ, Тазовский район, поселок Антипаюта, Ленина, 3	t	large
130860	13816	170	Ямало-Ненецкий автономный округ, Пуровский район, поселок Харампур, Айваседо Энтак, 6	t	small
85983	13814	168	Ямало-Ненецкий автономный округ, Пуровский район, поселок Ханымей, Молодежная, 15	f	large
85984	13815	169	Ямало-Ненецкий автономный округ, Пуровский район, поселок Ханымей, Мира, 53	t	large
130861	13817	171	Ямало-Ненецкий автономный округ, Пуровский район, поселок Халясавэй, Лесная, 3	t	small
85972	13800	155	Ямало-Ненецкий автономный округ, Пуровский район, поселок Уренгой, Геологов, 43	f	large
85971	13798	154	Ямало-Ненецкий автономный округ, Пуровский район, поселок Уренгой, 4 микрорайон, 39	f	large
85970	13797	153	Ямало-Ненецкий автономный округ, Пуровский район, поселок Уренгой, 3 микрорайон, 20	t	large
85979	13809	164	Ямало-Ненецкий автономный округ, Пуровский район, Тарко-Сале, Мира, 7А	f	large
85978	13808	163	Ямало-Ненецкий автономный округ, Пуровский район, Тарко-Сале, Мира, 7	f	large
130858	13801	156	Ямало-Ненецкий автономный округ, Пуровский район, поселок Сывдарма, Железнодорожная, 10	t	small
85969	13796	152	Ямало-Ненецкий автономный округ, Пуровский район, поселок Самбург, МУ Дом культуры Полярная звезда,	t	large
85980	13810	165	Ямало-Ненецкий автономный округ, Пуровский район, Пурпе-1, Победы, 3	f	large
85982	13813	167	Ямало-Ненецкий автономный округ, Пуровский район, поселок Пурпе, Молодежная, 15	f	large
85981	13812	166	Ямало-Ненецкий автономный округ, Пуровский район, поселок Пурпе, Железнодорожная, 5Б	f	large
85973	13802	157	Ямало-Ненецкий автономный округ, Пуровский район, поселок Пуровск, переулок Школьный, 1	t	large
130859	13803	158	Ямало-Ненецкий автономный округ, Пуровский район, поселок Пуровск, Новая, 9	t	medium
85943	13769	123	Ямало-Ненецкий автономный округ, Пуровский район, Ноябрьск, Ленина, 41	f	large
130855	13789	145	Ямало-Ненецкий автономный округ, Пуровский район, Ноябрьск, Аэропорт, Аэропорт	t	small
85861	13683	28	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Школьная, 17	f	large
85862	13684	29	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Украинских строителей, 10	f	large
85866	13688	33	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Пионерская, 4	f	large
85870	13689	37	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Муравленко, 20	f	large
130854	13750	102	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, Монтажников, 8	t	small
85867	13689	34	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Муравленко, 20	f	large
85864	13686	31	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Ленина, 61	f	large
85869	13690	36	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Дружбы народов, 104	f	large
85868	13690	35	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Дружбы народов, 104	f	large
85865	13687	32	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Губкина, 2	f	large
85863	13685	30	Ямало-Ненецкий автономный округ, Пуровский район, поселок Муравленко, Губкина, 14	f	large
85840	13660	2	Ямало-Ненецкий автономный округ, Пуровский район, Губкинский, 9 микрорайон, МОУ СОШ №4	f	large
85842	13663	5	Ямало-Ненецкий автономный округ, Пуровский район, Губкинский, 7 микрорайон, ДЮСШ ГДК Олимп	f	large
85843	13664	6	Ямало-Ненецкий автономный округ, Пуровский район, Губкинский, 6 микрорайон, МОУ СОШ №3	f	large
85841	13661	3	Ямало-Ненецкий автономный округ, Пуровский район, Губкинский, 3 микрорайон, 6	f	large
85844	13665	7	Ямало-Ненецкий автономный округ, Пуровский район, Губкинский, 14 микрорайон, МОУ СОШ № 7	f	large
130857	13795	151	Ямало-Ненецкий автономный округ, Приуральский район, поселок Харсаим, Школьная, 2	f	small
85968	13794	150	Ямало-Ненецкий автономный округ, Приуральский район, поселок Харп, Дзержинского, 11	f	large
85967	13793	149	Ямало-Ненецкий автономный округ, Приуральский район, поселок Харп, Дзержинского, 7, МУ культуры Дом культуры п. Харп	f	large
85966	13791	147	Ямало-Ненецкий автономный округ, Приуральский район, поселок Белоярск, Новая, 14	f	large
85965	13790	146	Ямало-Ненецкий автономный округ, Приуральский район, поселок Аксарка, Первомайская, 28А	f	large
85890	13717	63	Ямало-Ненецкий автономный округ, Надымский район, поселок Ямбург, Газопромысловое управление №2 ООО Газпром добыча Ямбург	t	large
85889	13716	62	Ямало-Ненецкий автономный округ, Надымский район, поселок Ямбург, Газопромысловое управление №6 ООО Газпром добыча Ямбург	t	large
85888	13715	61	Ямало-Ненецкий автономный округ, Надымский район, поселок Ямбург, Культурноспортивный комплекс ООО Газпром добыча Ямбург	t	large
130844	13710	56	Ямало-Ненецкий автономный округ, Надымский район, Ягельный, Дом культуры	t	medium
85885	13705	52	Ямало-Ненецкий автономный округ, Надымский район, Стар. Надым, Старонадымская средняя школа	f	large
85886	13709	55	Ямало-Ненецкий автономный округ, Надымский район, поселок Приозерный, Дом культуры	t	large
130842	13706	53	Ямало-Ненецкий автономный округ, Надымский район, поселок Правохеттинский, МКУК КДЦ	t	medium
85894	13722	67	Ямало-Ненецкий автономный округ, Надымский район, поселок Пангоды, Спортивная, 20, Клуб финского комплекса №1	t	large
85893	13721	66	Ямало-Ненецкий автономный округ, Надымский район, поселок Пангоды, Ленина, 43, МОУ СОШ №1	f	large
85892	13720	65	Ямало-Ненецкий автономный округ, Надымский район, поселок Пангоды, Ленина, 17, МОУ СОШ №2	f	large
85891	13719	64	Ямало-Ненецкий автономный округ, Надымский район, поселок Пангоды, Газодобытчиков, 24, МОУ ДОД Детская музыкальная школа п.Пангоды	f	large
85887	13713	59	Ямало-Ненецкий автономный округ, Надымский район, поселок Ныда, МОУ Школаинтернат среднего общегообразования	f	large
130845	13711	57	Ямало-Ненецкий автономный округ, Надымский район, поселок Нори, МОУ Норинская начальная школа	t	small
85921	13746	99	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, мкр. Студенческий, 1	f	large
130850	13732	82	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, мкр. Солнечный, квартал Армавирский	f	medium
85912	13740	90	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, мкр. Советский, 10п., 1	f	large
85913	13740	91	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, мкр. Советский, 10п., 1	f	large
130853	13749	101	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, мкр. Оптимистов, 4, МУ «ОМК» молодёжный клуб «Оптимист»	f	small
85904	13729	79	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, Юбилейная, 7	f	large
85903	13729	78	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, Юбилейная, 7	f	large
79233	10677	820	Челябинская область, Челябинск, Образцова, 7/1	f	large
85899	13726	73	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, 26 съезда КПСС, 10а	f	large
85898	13726	72	Ямало-Ненецкий автономный округ, Надымский район, Новый Уренгой, 26 съезда КПСС, 10а	f	large
85882	13702	49	Ямало-Ненецкий автономный округ, Надымский район, Надым, п.Аэропорт, Спортивно-оздоровительный комплекс 	t	large
85876	13696	43	Ямало-Ненецкий автономный округ, Надымский район, Надым, Ленинградский проспект, 11, Музей истории и археологии г.Надыма	f	large
130843	13707	54	Ямало-Ненецкий автономный округ, Надымский район, поселок Лонгъюган, Культурноспортивный комплекс	t	medium
85871	13691	38	Ямало-Ненецкий автономный округ, Надымский район, Лесной , Административное здание ООО Газтеплоэнергоремонт	f	large
130846	13712	58	Ямало-Ненецкий автономный округ, Надымский район, поселок Кутопьюган, МОУ Средняя общеобразовательная школаинтернат	t	medium
130847	13714	60	Ямало-Ненецкий автономный округ, Надымский район, Заполярный, Дом культуры	t	medium
85849	13669	12	Ямало-Ненецкий автономный округ, Красноселькупский район, поселок Толька, Центральная, 30, спортивный комплекс Снежинка	t	large
130838	13670	13	Ямало-Ненецкий автономный округ, Красноселькупский район, поселок Ратта, Центральная, 2, сельский Дом культуры	t	small
85848	13668	11	Ямало-Ненецкий автономный округ, Красноселькупский район, село Красноселькуп, Советская, 5, муниципальное образовательное учреждение «Радуга»	f	large
85847	13668	10	Ямало-Ненецкий автономный округ, Красноселькупский район, село Красноселькуп, Советская, 5, муниципальное образовательное учреждение «Радуга»	f	large
129907	10763	910	Челябинская область, городской округ Верхний Уфалей, Строителей, 15	f	medium
79939	11949	2216	Челябинская область, Южноуральск, Яблочкова, 23А	f	large
79928	11939	2205	Челябинская область, Южноуральск, Энергетиков, 18	f	large
79929	11940	2206	Челябинская область, Южноуральск, Строителей, 3	f	large
79934	11945	2211	Челябинская область, Южноуральск, Спортивная, 21	f	large
79932	11943	2209	Челябинская область, Южноуральск, Спортивная, 42А	f	large
79936	11946	2213	Челябинская область, Южноуральск, Советской Армии, 9А	f	large
79935	11946	2212	Челябинская область, Южноуральск, Советской Армии, 9А	f	large
129558	11933	2198	Челябинская область, Южноуральск, Советская, 112	f	large
129457	11895	2200	Челябинская область, Южноуральск, Советская, 2	f	medium
79927	11938	2204	Челябинская область, Южноуральск, Парковая, 2	f	large
79937	11947	2214	Челябинская область, Южноуральск, Павлова, 26	f	large
79931	11942	2208	Челябинская область, Южноуральск, Павлова, 41	f	large
79926	11937	2203	Челябинская область, Южноуральск, Московская, 16	f	large
79925	11935	2201	Челябинская область, Южноуральск, Ленина, 38	f	large
79924	11934	2199	Челябинская область, Южноуральск, Ленина, 38	f	large
79930	11941	2207	Челябинская область, Южноуральск, Куйбышева, 36Б	f	large
79938	11948	2215	Челябинская область, Южноуральск, Космонавтов, 19	f	large
79933	11944	2210	Челябинская область, Южноуральск, Космонавтов, 3В	f	large
79085	10564	665	Челябинская область, Челябинск, дом культуры Сокол 	f	large
79100	10576	683	Челябинская область, Челябинск, улица Ярослава Гашека, 1	f	large
79226	10668	813	Челябинская область, Челябинск, улица Энтузиастов, 15б	f	large
79225	10668	812	Челябинская область, Челябинск, улица Энтузиастов, 15б	f	large
79222	10668	809	Челябинская область, Челябинск, улица Энтузиастов, 15б	f	large
79207	10656	794	Челябинская область, Челябинск, улица Энгельса, 39	f	large
129471	11038	1188	Челябинская область, Челябинск, улица Угольная, 15	f	small
79862	11811	2069	Челябинская область, Челябинск, улица Свободы, 100а	f	large
79153	10620	739	Челябинская область, Челябинск, улица Салютная, 16	f	large
79815	11776	2019	Челябинская область, Челябинск, улица Пограничная, 4	f	large
79816	11776	2020	Челябинская область, Челябинск, улица Пограничная, 4	f	large
79707	11673	1891	Челябинская область, Челябинск, улица Пекинская, 25	t	large
79413	11098	1259	Челябинская область, Челябинск, улица Октябрьская, 11	f	large
79180	10639	766	Челябинская область, Челябинск, улица Октябрьская, 3	f	large
79861	11809	2068	Челябинская область, Челябинск, улица Овчинникова, 4	f	large
79860	11809	2066	Челябинская область, Челябинск, улица Овчинникова, 4	f	large
64851	64116	2931	Пермский край, Пермь, Мира, 92	f	large
79826	11781	2030	Челябинская область, Челябинск, улица Новороссийская, 83	f	large
79825	11781	2029	Челябинская область, Челябинск, улица Новороссийская, 83	f	large
130508	11704	1929	Челябинская область, Челябинск, улица Масленникова, 9	t	medium
79739	11704	1928	Челябинская область, Челябинск, улица Масленникова, 9	t	large
79168	10629	754	Челябинская область, Челябинск, улица Кулибина, 58	f	large
79859	11808	2065	Челябинская область, Челябинск, улица Красноармейская, 101	f	large
79884	11834	2097	Челябинская область, Челябинск, улица Короленко, 16	f	large
79883	11834	2096	Челябинская область, Челябинск, улица Короленко, 16	f	large
79896	11845	2112	Челябинская область, Челябинск, поселок Новосинеглазово, улица Кирова, 6	f	large
130618	11982	2255	Челябинская область, Челябинск, улица Каслинская, 64	f	small
79060	10553	640	Челябинская область, Челябинск, улица Захаренко, 13	f	large
79062	10553	642	Челябинская область, Челябинск, улица Захаренко, 13	f	large
79061	10553	641	Челябинская область, Челябинск, улица Захаренко, 13	f	large
79130	10602	716	Челябинская область, Челябинск, улица Жукова, 47	f	large
129562	11817	2076	Челябинская область, Челябинск, улица Елькина, 88, 1 этаж, левый холл	f	large
79865	11814	2073	Челябинская область, Челябинск, улица Елькина, 78	f	large
79864	11814	2072	Челябинская область, Челябинск, улица Елькина, 78	f	large
79091	10569	674	Челябинская область, Челябинск, улица Дегтярева, 33	f	large
79090	10569	673	Челябинская область, Челябинск, улица Дегтярева, 33	f	large
79742	11706	1932	Челябинская область, Челябинск, улица Грибоедова, 15	f	large
79741	11706	1931	Челябинская область, Челябинск, улица Грибоедова, 15	f	large
79149	10616	735	Челябинская область, Челябинск, улица Горького, 54	f	large
79813	11774	2017	Челябинская область, Челябинск, улица Гагарина, 7	f	large
129886	10723	869	Челябинская область, Челябинск, улица 40 Лет Октября, 33	f	medium
79084	10563	664	Челябинская область, Челябинск, улица 26 Бакинских Комиссаров, 107а	f	large
79847	11798	2051	Челябинская область, Челябинск, улица 1-я Трубосварочная, 4	f	large
78965	10514	541	Челябинская область, Челябинск, проспект Победы, 167	f	large
78944	10507	519	Челябинская область, Челябинск, проспект Победы, 113а	f	large
78943	10507	518	Челябинская область, Челябинск, проспект Победы, 113а	f	large
78956	10409	532	Челябинская область, Челябинск, проспект Победы, 162в	f	large
78955	10409	531	Челябинская область, Челябинск, проспект Победы, 162в	f	large
79838	11790	2042	Челябинская область, Челябинск, Энергетиков, 17	f	large
79837	11790	2041	Челябинская область, Челябинск, Энергетиков, 17	f	large
79835	11788	2039	Челябинская область, Челябинск, Энергетиков, 2	f	large
79817	11777	2021	Челябинская область, Челябинск, Энергетиков, 63	f	large
79224	10670	811	Челябинская область, Челябинск, Энгельса, 103	f	large
79221	10667	808	Челябинская область, Челябинск, Энгельса, 79	f	large
79112	10587	697	Челябинская область, Челябинск, Электростальская, 33	f	large
79170	10631	756	Челябинская область, Челябинск, Шуменская, 20а	f	large
79863	11813	2071	Челябинская область, Челябинск, Ширшова, 9	f	large
129516	11812	2070	Челябинская область, Челябинск, Ширшова, 9, 2 этаж правого холла	f	large
78953	6607	529	Челябинская область, Челябинск, Шенкурская, 13	f	large
78954	6607	530	Челябинская область, Челябинск, Шенкурская, 13	f	large
79078	10560	658	Челябинская область, Челябинск, Чичерина, 3	f	large
79077	10559	657	Челябинская область, Челябинск, Чичерина, 3	f	large
79076	10559	656	Челябинская область, Челябинск, Чичерина, 3	f	large
79075	10559	655	Челябинская область, Челябинск, Чичерина, 3	f	large
79003	8027	579	Челябинская область, Челябинск, Чичерина, 27б	f	large
79125	10599	711	Челябинская область, Челябинск, Черкасская, 1а	f	large
79895	11843	2111	Челябинская область, Челябинск, Челябинская, 7	f	large
79893	11843	2109	Челябинская область, Челябинск, Челябинская, 7	f	large
79026	10538	606	Челябинская область, Челябинск, Чайковского, 8а	f	large
79025	10538	605	Челябинская область, Челябинск, Чайковского, 8а	f	large
79024	10538	604	Челябинская область, Челябинск, Чайковского, 8а	f	large
79023	10538	603	Челябинская область, Челябинск, Чайковского, 8а	f	large
79022	10537	602	Челябинская область, Челябинск, Чайковского, 1	f	large
64844	72479	2924	Пермский край, Пермь, Мира, 26	f	large
79020	10536	600	Челябинская область, Челябинск, Чайковского, 20А	f	large
79872	11821	2081	Челябинская область, Челябинск, Цеховая, 8а	f	large
79231	10675	818	Челябинская область, Челябинск, Центральная, 3а	f	large
79858	11807	2064	Челябинская область, Челябинск, Цвиллинга, 54	f	large
79857	11806	2063	Челябинская область, Челябинск, Цвиллинга, 56	f	large
79232	10676	819	Челябинская область, Челябинск, Худякова, 16	f	large
79192	10646	779	Челябинская область, Челябинск, Хохрякова, 26а	f	large
79191	10646	778	Челябинская область, Челябинск, Хохрякова, 26а	f	large
79190	10646	777	Челябинская область, Челябинск, Хохрякова, 26а	f	large
79189	10646	776	Челябинская область, Челябинск, Хохрякова, 26а	f	large
79133	10604	719	Челябинская область, Челябинск, Хлебозаводская, 4	f	large
129557	11757	1988	Челябинская область, Челябинск, Харлова, 10, 1 этаж, коридор	f	large
130523	11826	2088	Челябинская область, Челябинск, Учебная, 5а	f	medium
79848	11796	2052	Челябинская область, Челябинск, Уральская, 2	f	large
79845	11796	2049	Челябинская область, Челябинск, Уральская, 2	f	large
78978	10520	554	Челябинская область, Челябинск, Университетская Набережная, 30а	f	large
78977	10520	553	Челябинская область, Челябинск, Университетская Набережная, 30а	f	large
78976	10520	552	Челябинская область, Челябинск, Университетская Набережная, 30а	f	large
78975	10520	551	Челябинская область, Челябинск, Университетская Набережная, 30а	f	large
78974	10519	550	Челябинская область, Челябинск, Университетская Набережная, 16а	f	large
78973	10519	549	Челябинская область, Челябинск, Университетская Набережная, 16а	f	large
79787	11759	1991	Челябинская область, Челябинск, Тухачевского, 15	f	large
79786	11759	1990	Челябинская область, Челябинск, Тухачевского, 15	f	large
79844	11795	2048	Челябинская область, Челябинск, Туруханская, 40	f	large
79087	10566	669	Челябинская область, Челябинск, Трудовая, 16	f	large
79086	10566	668	Челябинская область, Челябинск, Трудовая, 16	f	large
79880	11830	2093	Челябинская область, Челябинск, Троицкий тракт, 46	f	large
130528	11841	2107	Челябинская область, Челябинск, Троицкий тракт, 15	f	medium
130526	11838	2103	Челябинская область, Челябинск, Трактовая, 19а	f	medium
79851	11799	2056	Челябинская область, Челябинск, Тимирязева, 6	f	large
79849	11799	2054	Челябинская область, Челябинск, Тимирязева, 6	f	large
79108	10581	691	Челябинская область, Челябинск, Театральный переулок, 16а	f	large
79166	10627	752	Челябинская область, Челябинск, Танкистов, 144Б	f	large
79165	10627	751	Челябинская область, Челябинск, Танкистов, 144Б	f	large
79110	10583	693	Челябинская область, Челябинск, Сурикова, 5	f	large
130525	11828	2090	Челябинская область, Челябинск, Стрелковая, 37	f	small
79887	11836	2100	Челябинская область, Челябинск, Столбовая, 30	f	large
129453	10969	1116	Челябинская область, Челябинск, Станционная, 1, ж/д вокзал	f	medium
129530	10567	670	Челябинская область, Челябинск, Сталеваров, 1	f	large
79229	10673	816	Челябинская область, Челябинск, Сони Кривой, 54	f	large
79228	10672	815	Челябинская область, Челябинск, Сони Кривой, 79	f	large
79055	10551	635	Челябинская область, Челябинск, Солнечная, 10в	f	large
79054	10551	634	Челябинская область, Челябинск, Солнечная, 10в	f	large
79053	10551	633	Челябинская область, Челябинск, Солнечная, 10в	f	large
79049	10547	629	Челябинская область, Челябинск, Солнечная, 50а	f	large
79048	10547	628	Челябинская область, Челябинск, Солнечная, 50а	f	large
79524	11218	1388	Челябинская область, Челябинск, Советская, 106	f	large
79230	10674	817	Челябинская область, Челябинск, Смирных, 13а	f	large
129515	11810	2067	Челябинская область, Челябинск, Свободы, 100а, 1 этаж, 16 кабинет	f	large
79855	11804	2061	Челябинская область, Челябинск, Свободы, 155	f	large
79854	11803	2060	Челябинская область, Челябинск, Свободы, 82	f	large
79853	11803	2059	Челябинская область, Челябинск, Свободы, 82	f	large
79220	10666	807	Челябинская область, Челябинск, Свердловский проспект, 84а	f	large
79219	10665	806	Челябинская область, Челябинск, Свердловский проспект, 84а	f	large
79218	10665	805	Челябинская область, Челябинск, Свердловский проспект, 84а	f	large
79017	10534	597	Челябинская область, Челябинск, Свердловский проспект, 24	f	large
79016	10534	596	Челябинская область, Челябинск, Свердловский проспект, 24	f	large
79015	10534	595	Челябинская область, Челябинск, Свердловский проспект, 24	f	large
79014	10534	594	Челябинская область, Челябинск, Свердловский проспект, 24	f	large
79941	11956	2224	Челябинская область, Челябинск, Санаторная, 10, филиал школы №94	f	large
79155	10621	741	Челябинская область, Челябинск, Салютная, 16	f	large
79154	10621	740	Челябинская область, Челябинск, Салютная, 16	f	large
79082	10561	662	Челябинская область, Челябинск, Салавата Юлаева, 3б	f	large
79081	10561	661	Челябинская область, Челябинск, Салавата Юлаева, 3б	f	large
79080	10561	660	Челябинская область, Челябинск, Салавата Юлаева, 3б	f	large
79079	10561	659	Челябинская область, Челябинск, Салавата Юлаева, 3б	f	large
79011	9652	587	Челябинская область, Челябинск, Салавата Юлаева, 25а	f	large
79010	9652	586	Челябинская область, Челябинск, Салавата Юлаева, 25а	f	large
79009	9652	585	Челябинская область, Челябинск, Салавата Юлаева, 25а	f	large
79008	9652	584	Челябинская область, Челябинск, Салавата Юлаева, 25а	f	large
79005	8256	581	Челябинская область, Челябинск, Салавата Юлаева, 13	f	large
79004	8256	580	Челябинская область, Челябинск, Салавата Юлаева, 13	f	large
79006	8256	582	Челябинская область, Челябинск, Салавата Юлаева, 13	f	large
79007	8256	583	Челябинская область, Челябинск, Салавата Юлаева, 13	f	large
79158	10623	744	Челябинская область, Челябинск, Савина, 3	f	large
79157	10623	743	Челябинская область, Челябинск, Савина, 3	f	large
130524	11827	2089	Челябинская область, Челябинск, Рылеева, 8	f	medium
78952	6119	528	Челябинская область, Челябинск, Российская, 49а	f	large
78951	6119	527	Челябинская область, Челябинск, Российская, 49а	f	large
78950	5723	526	Челябинская область, Челябинск, Российская, 23	f	large
78949	5723	525	Челябинская область, Челябинск, Российская, 23	f	large
79021	10535	601	Челябинская область, Челябинск, Речная, 1а	f	large
79019	10535	599	Челябинская область, Челябинск, Речная, 1а	f	large
79018	10535	598	Челябинская область, Челябинск, Речная, 1а	f	large
79852	11802	2058	Челябинская область, Челябинск, Революции площадь, 5	f	large
79072	10558	652	Челябинская область, Челябинск, Рабоче-Крестьянская, 2а	f	large
79071	10558	651	Челябинская область, Челябинск, Рабоче-Крестьянская, 2а	f	large
78964	10513	540	Челябинская область, Челябинск, Работниц, 58	f	large
130602	11962	2229	Челябинская область, Челябинск, Привокзальная площадь, 1	f	small
79814	11775	2018	Челябинская область, Челябинск, Пограничная, 1	f	large
79789	11760	1993	Челябинская область, Челябинск, Пограничная, 21	f	large
79788	11760	1992	Челябинская область, Челябинск, Пограничная, 21	f	large
79780	11751	1982	Красноярский край, Лесосибирск, улица Победы, 6а	f	large
78986	10525	562	Челябинская область, Челябинск, Победы проспект, 303/1	f	large
78985	10524	561	Челябинская область, Челябинск, Победы проспект, 287	f	large
129412	10506	517	Челябинская область, Челябинск, Победы проспект, 113а	f	medium
78942	10505	516	Челябинская область, Челябинск, Победы проспект, 60	f	large
129861	4705	524	Челябинская область, Челябинск, Победы проспект, 144	f	medium
78948	4705	523	Челябинская область, Челябинск, Победы проспект, 144	f	large
79236	10679	823	Челябинская область, Челябинск, Пионерская, 1А	f	large
79031	10540	611	Челябинская область, Челябинск, Пионерская, 10а	f	large
79033	10540	613	Челябинская область, Челябинск, Пионерская, 10а	f	large
79032	10540	612	Челябинская область, Челябинск, Пионерская, 10а	f	large
79156	10622	742	Челябинская область, Челябинск, Первой Пятилетки, 21	f	large
79135	10603	721	Челябинская область, Челябинск, Пекинская, 20	f	large
79134	10603	720	Челябинская область, Челябинск, Пекинская, 20	f	large
79132	10603	718	Челябинская область, Челябинск, Пекинская, 20	f	large
79131	10603	717	Челябинская область, Челябинск, Пекинская, 20	f	large
79455	11153	1314	Челябинская область, Челябинск, Панькова, 32	f	large
79797	11765	2001	Челябинская область, Челябинск, Отечественная, 6	f	large
79012	10533	592	Челябинская область, Челябинск, Островского переулок, 8	f	large
79013	10533	593	Челябинская область, Челябинск, Островского переулок, 8	f	large
79856	11805	2062	Челябинская область, Челябинск, Орджоникидзе, 1	f	large
79182	10641	768	Челябинская область, Челябинск, Октябрьская, 30	f	large
79179	10638	765	Челябинская область, Челябинск, Октябрьская, 3	f	large
79178	10638	764	Челябинская область, Челябинск, Октябрьская, 3	f	large
79842	11793	2046	Челябинская область, Челябинск, Новороссийская, 27	f	large
79841	11792	2045	Челябинская область, Челябинск, Новороссийская, 63	f	large
79840	11792	2044	Челябинская область, Челябинск, Новороссийская, 63	f	large
79839	11791	2043	Челябинская область, Челябинск, Новороссийская, 8	f	large
79827	11782	2031	Челябинская область, Челябинск, Новороссийская, 77а	f	large
79812	11773	2016	Челябинская область, Челябинск, Новороссийская, 136	f	large
79811	11773	2015	Челябинская область, Челябинск, Новороссийская, 136	f	large
79810	11773	2014	Челябинская область, Челябинск, Новороссийская, 136	f	large
79807	11771	2011	Челябинская область, Челябинск, Новороссийская, 126	f	large
79464	11162	1324	Челябинская область, Челябинск, Московская, 26	f	large
79042	10544	622	Челябинская область, Челябинск, Молодогвардейцев, 12а	f	large
79040	10543	620	Челябинская область, Челябинск, Молодогвардейцев, 18	f	large
79041	10543	621	Челябинская область, Челябинск, Молодогвардейцев, 18	f	large
79039	10543	619	Челябинская область, Челябинск, Молодогвардейцев, 18	f	large
78991	10528	567	Челябинская область, Челябинск, Молодогвардейцев, 70б	f	large
78990	10528	566	Челябинская область, Челябинск, Молодогвардейцев, 70б	f	large
78989	10527	565	Челябинская область, Челябинск, Молодогвардейцев, 62в	f	large
78988	10526	564	Челябинская область, Челябинск, Молодогвардейцев, 56б	f	large
78987	10526	563	Челябинская область, Челябинск, Молодогвардейцев, 56б	f	large
78984	10523	560	Челябинская область, Челябинск, Молодогвардейцев, 43	f	large
78983	10523	559	Челябинская область, Челябинск, Молодогвардейцев, 43	f	large
78981	10522	557	Челябинская область, Челябинск, Молодогвардейцев, 61а	f	large
78982	10522	558	Челябинская область, Челябинск, Молодогвардейцев, 61а	f	large
79083	10562	663	Челябинская область, Челябинск, Молодова, 18	f	large
79051	10549	631	Челябинская область, Челябинск, Молдавская, 23Б	f	large
79052	10548	632	Челябинская область, Челябинск, Молдавская, 23Б	f	large
79050	10548	630	Челябинская область, Челябинск, Молдавская, 23Б	f	large
79746	11709	1936	Челябинская область, Челябинск, Мира, 43	f	large
79116	10591	701	Челябинская область, Челябинск, Мира, 96а	f	large
79114	10589	699	Челябинская область, Челябинск, Мира, 67А	f	large
129529	10586	696	Челябинская область, Челябинск, Мира, 46	f	large
79109	10582	692	Челябинская область, Челябинск, Мира, 46	f	large
79119	10594	705	Челябинская область, Челябинск, Металлургов шоссе, 53	f	large
79118	10594	704	Челябинская область, Челябинск, Металлургов шоссе, 53	f	large
79117	10592	702	Челябинская область, Челябинск, Металлургов шоссе, 47	f	large
79115	10590	700	Челябинская область, Челябинск, Металлургов шоссе, 70б	f	large
79828	11783	2032	Челябинская область, Челябинск, Машиностроителей, 31	f	large
79414	11099	1260	Челябинская область, Челябинск, Матросова	f	large
79831	11785	2035	Челябинская область, Челябинск, Масленникова, 21	f	large
79167	10628	753	Челябинская область, Челябинск, Марченко, 16А	f	large
79164	10626	750	Челябинская область, Челябинск, Марченко, 23г	f	large
79163	10626	749	Челябинская область, Челябинск, Марченко, 23г	f	large
79162	10626	748	Челябинская область, Челябинск, Марченко, 23г	f	large
79161	10625	747	Челябинская область, Челябинск, Марченко, 33	f	large
130522	11825	2087	Челябинская область, Челябинск, Марата, 8	f	medium
79188	10645	775	Челябинская область, Челябинск, Мамина, 21	f	large
79187	10645	774	Челябинская область, Челябинск, Мамина, 21	f	large
79186	10645	773	Челябинская область, Челябинск, Мамина, 21	f	large
79185	10644	772	Челябинская область, Челябинск, Мамина, 9	f	large
79184	10644	771	Челябинская область, Челябинск, Мамина, 9	f	large
79111	10585	695	Челябинская область, Челябинск, Липецкая, 27	f	large
79892	11842	2108	Челябинская область, Челябинск, Лермонтова, 17	f	large
130591	11936	2202	Челябинская область, Челябинск, Ленина проспект, 26	f	medium
79850	11800	2055	Челябинская область, Челябинск, Ленина проспект, 41А	f	large
79491	11189	1353	Челябинская область, Челябинск, Ленина проспект, 59	f	large
79227	10671	814	Челябинская область, Челябинск, Ленина проспект, 79	f	large
79217	10664	804	Челябинская область, Челябинск, Ленина проспект, 69	f	large
79214	10662	801	Челябинская область, Челябинск, Ленина проспект, 80	f	large
79160	10624	746	Челябинская область, Челябинск, Ленина проспект, 7	f	large
79159	10624	745	Челябинская область, Челябинск, Ленина проспект, 7	f	large
79139	10607	725	Республика Хакасия, Абакан, Ленина проспект, 13	f	large
129866	10565	667	Челябинская область, Челябинск, Лазурная, 12	f	medium
79869	11818	2078	Челябинская область, Челябинск, Курчатова, 7	f	large
79868	11818	2077	Челябинская область, Челябинск, Курчатова, 7	f	large
79866	11815	2074	Челябинская область, Челябинск, Курчатова, 9	f	large
79181	10640	767	Челябинская область, Челябинск, Кулибина, 58	f	large
79169	10630	755	Челябинская область, Челябинск, Кулибина, 60	f	large
79038	10542	618	Челябинская область, Челябинск, Куйбышева, 53	f	large
79037	10542	617	Челябинская область, Челябинск, Куйбышева, 53	f	large
79036	10541	616	Челябинская область, Челябинск, Куйбышева, 39	f	large
79035	10541	615	Челябинская область, Челябинск, Куйбышева, 39	f	large
79034	10541	614	Челябинская область, Челябинск, Куйбышева, 39	f	large
79889	11837	2102	Челябинская область, Челябинск, Кузнецова, 33	f	large
79888	11837	2101	Челябинская область, Челябинск, Кузнецова, 33	f	large
79886	11835	2099	Челябинская область, Челябинск, Кузнецова, 7	f	large
79885	11835	2098	Челябинская область, Челябинск, Кузнецова, 7	f	large
79142	10611	728	Челябинская область, Челябинск, Кудрявцева, 79	f	large
79143	10611	729	Челябинская область, Челябинск, Кудрявцева, 79	f	large
78947	10469	522	Челябинская область, Челябинск, Кудрявцева, 18	f	large
78946	10469	521	Челябинская область, Челябинск, Кудрявцева, 18	f	large
79836	11789	2040	Челябинская область, Челябинск, Кронштадтская, 10	f	large
79113	10588	698	Челябинская область, Челябинск, Краснооктябрьская, 26	f	large
79030	10539	610	Челябинская область, Челябинск, Красного Урала, 16	f	large
79029	10539	609	Челябинская область, Челябинск, Красного Урала, 16	f	large
79028	10539	608	Челябинская область, Челябинск, Красного Урала, 16	f	large
79027	10539	607	Челябинская область, Челябинск, Красного Урала, 16	f	large
79205	10654	792	Челябинская область, Челябинск, Красноармейская, 140	f	large
79204	10653	791	Челябинская область, Челябинск, Красноармейская, 93а	f	large
79201	10652	788	Челябинская область, Челябинск, Красноармейская, 88	f	large
79216	10663	803	Челябинская область, Челябинск, Красная, 38	f	large
79215	10663	802	Челябинская область, Челябинск, Красная, 38	f	large
79174	10634	760	Челябинская область, Челябинск, Котина, 22	f	large
79173	10634	759	Челябинская область, Челябинск, Котина, 22	f	large
79151	10618	737	Челябинская область, Челябинск, Котина, 48	f	large
79846	11797	2050	Челябинская область, Челябинск, Копейское шоссе, 5	f	large
79045	10545	625	Челябинская область, Челябинск, Комсомольский проспект, 55а	f	large
79044	10545	624	Челябинская область, Челябинск, Комсомольский проспект, 55а	f	large
79043	10545	623	Челябинская область, Челябинск, Комсомольский проспект, 55а	f	large
79212	10660	799	Челябинская область, Челябинск, Коммуны, 147	f	large
79211	10659	798	Челябинская область, Челябинск, Коммуны, 133	f	large
79096	10572	679	Челябинская область, Челябинск, Коммунистическая, 7	f	large
79095	10572	678	Челябинская область, Челябинск, Коммунистическая, 7	f	large
79792	11762	1996	Челябинская область, Челябинск, Коммунаров, 28	f	large
79785	11758	1989	Челябинская область, Челябинск, Коммунаров, 4	f	large
129556	11756	1987	Челябинская область, Челябинск, Коммунаров, 4, 1 этаж, спортзал	f	large
78971	10517	547	Челябинская область, Челябинск, Коммунальная, 48	f	large
79123	10597	709	Челябинская область, Челябинск, Комаровского, 7б	f	large
79122	10597	708	Челябинская область, Челябинск, Комаровского, 7б	f	large
79121	10596	707	Челябинская область, Челябинск, Комаровского, 11б	f	large
79120	10595	706	Челябинская область, Челябинск, Комаровского, 11б	f	large
129537	10643	770	Челябинская область, Челябинск, Комарова, 41, 2 этаж, холл	f	large
79183	10642	769	Челябинская область, Челябинск, Комарова, 41	f	large
79171	10632	757	Челябинская область, Челябинск, Комарова, 114	f	large
79894	11844	2110	Челябинская область, Челябинск, Кирова, 1	f	large
78963	10512	539	Челябинская область, Челябинск, Кирова, 44	f	large
78961	10510	537	Челябинская область, Челябинск, Кирова, 13б	f	large
78960	10510	536	Челябинская область, Челябинск, Кирова, 13б	f	large
78958	10508	534	Челябинская область, Челябинск, Кирова, 3а	f	large
78957	10508	533	Челябинская область, Челябинск, Кирова, 3а	f	large
79879	11829	2092	Челябинская область, Челябинск, Карабанова, 10а	f	large
79878	11829	2091	Челябинская область, Челябинск, Карабанова, 10а	f	large
79891	11840	2106	Челябинская область, Челябинск, Капитанская, 10а	f	large
78968	10515	544	Челябинская область, Челябинск, Калинина, 28	f	large
78967	10515	543	Челябинская область, Челябинск, Калинина, 28	f	large
78966	10515	542	Челябинская область, Челябинск, Калинина, 28	f	large
130527	11839	2105	Челябинская область, Челябинск, Зои Космодемьянской, 1	f	medium
79890	11839	2104	Челябинская область, Челябинск, Зои Космодемьянской, 1	f	large
79059	10552	639	Челябинская область, Челябинск, Захаренко, 3а	f	large
79058	10552	638	Челябинская область, Челябинск, Захаренко, 3а	f	large
79057	10552	637	Челябинская область, Челябинск, Захаренко, 3а	f	large
79056	10552	636	Челябинская область, Челябинск, Захаренко, 3а	f	large
79659	11470	1674	Челябинская область, Челябинск, Заводская, 34 Г	f	large
79107	10580	690	Челябинская область, Челябинск, Жукова, 16	f	large
79106	10580	689	Челябинская область, Челябинск, Жукова, 16	f	large
79105	10579	688	Челябинская область, Челябинск, Жукова, 27	f	large
79830	11784	2034	Челябинская область, Челябинск, Ереванская, 16	f	large
79829	11784	2033	Челябинская область, Челябинск, Ереванская, 16	f	large
79867	11816	2075	Челябинская область, Челябинск, Елькина, 88	f	large
79206	10655	793	Челябинская область, Челябинск, Елькина, 10	f	large
130529	11847	2114	Челябинская область, Челябинск, Дорожная, 3	f	medium
79876	11823	2085	Челябинская область, Челябинск, Доватора, 15	f	large
79874	11823	2083	Челябинская область, Челябинск, Доватора, 15	f	large
79871	11820	2080	Челябинская область, Челябинск, Доватора, 34	f	large
79870	11819	2079	Челябинская область, Челябинск, Доватора, 38	f	large
79823	11779	2027	Челябинская область, Челябинск, Дзержинского, 83а	f	large
79822	11779	2026	Челябинская область, Челябинск, Дзержинского, 83а	f	large
79821	11778	2025	Челябинская область, Челябинск, Дзержинского, 94	f	large
79103	10578	686	Челябинская область, Челябинск, Дегтярева, 72а	f	large
134602	11983	2256	Челябинская область, Челябинск, Двинская, 7, школа №, 54	f	large
78972	10518	548	Челябинская область, Челябинск, Двинская, 7	f	large
79897	11846	2113	Челябинская область, Челябинск, Дачный переулок, 22	f	large
78970	10516	546	Челябинская область, Челябинск, Дальневосточная, 2	f	large
78969	10516	545	Челябинская область, Челябинск, Дальневосточная, 2	f	large
79147	10614	733	Челябинская область, Челябинск, Грибоедова, 2	f	large
79146	10614	732	Челябинская область, Челябинск, Грибоедова, 2	f	large
79141	10609	727	Челябинская область, Челябинск, Грибоедова, 35	f	large
79150	10617	736	Челябинская область, Челябинск, Горького, 38	f	large
79144	10612	730	Челябинская область, Челябинск, Горького, 47б	f	large
79140	10608	726	Челябинская область, Челябинск, Горького, 11	f	large
78945	10458	520	Челябинская область, Челябинск, Горького, 79	f	large
134603	94446	2257	Челябинская область, Челябинск, Городок 11, 7, МОУ СОШ № 28	f	large
79801	11768	2005	Челябинская область, Челябинск, Гончаренко, 90	f	large
79074	10557	654	Челябинская область, Челябинск, Героя России Молодова, 18	f	large
79073	10557	653	Челябинская область, Челябинск, Героя России Молодова, 18	f	large
79070	10557	650	Челябинская область, Челябинск, Героя России Молодова, 18	f	large
130617	11907	2252	Челябинская область, Челябинск, Героев Танкограда, 23	f	medium
79172	10633	758	Челябинская область, Челябинск, Героев Танкограда, 104	f	large
79152	10619	738	Челябинская область, Челябинск, Героев Танкограда, 104	f	large
79949	11981	2253	Челябинская область, Челябинск, Генерала Мартынова, 7, офис 3	f	large
79752	11715	1944	Челябинская область, Гагарина, 7а	t	large
79047	10546	627	Челябинская область, Челябинск, Ворошилова, 16	f	large
79046	10546	626	Челябинская область, Челябинск, Ворошилова, 16	f	large
79235	10678	822	Челябинская область, Челябинск, Воровского, 64	f	large
79234	10678	821	Челябинская область, Челябинск, Воровского, 64	f	large
79223	10669	810	Челябинская область, Челябинск, Воровского, 36А	f	large
79210	10658	797	Челябинская область, Челябинск, Володарского, 20	f	large
64843	72479	2923	Пермский край, Пермь, Мира, 26	f	large
79209	10657	796	Челябинская область, Челябинск, Володарского, 18	f	large
79208	10657	795	Челябинская область, Челябинск, Володарского, 18	f	large
79843	11794	2047	Челябинская область, Челябинск, Васильевского, 75	f	large
79799	11766	2003	Челябинская область, Челябинск, Вагнера, 90	f	large
79798	11766	2002	Челябинская область, Челябинск, Вагнера, 90	f	large
79796	11761	2000	Челябинская область, Челябинск, Вагнера, 70А	f	large
79791	11761	1995	Челябинская область, Челябинск, Вагнера, 70А	f	large
79790	11761	1994	Челябинская область, Челябинск, Вагнера, 70А	f	large
79824	11780	2028	Челябинская область, Челябинск, Брестская, 17	f	large
79102	10577	685	Челябинская область, Челябинск, Богдана Хмельницкого, 7	f	large
79101	10577	684	Челябинская область, Челябинск, Богдана Хмельницкого, 7	f	large
79099	10575	682	Челябинская область, Челябинск, Богдана Хмельницкого, 24	f	large
79098	10574	681	Челябинская область, Челябинск, Богдана Хмельницкого, 24	f	large
79104	10573	687	Челябинская область, Челябинск, Богдана Хмельницкого, 12	f	large
79097	10573	680	Челябинская область, Челябинск, Богдана Хмельницкого, 12	f	large
79882	11832	2095	Челябинская область, Челябинск, Блюхера, 91	f	large
79881	11831	2094	Челябинская область, Челябинск, Блюхера, 69	f	large
79875	11822	2084	Челябинская область, Челябинск, Блюхера, 6	f	large
79873	11822	2082	Челябинская область, Челябинск, Блюхера, 6	f	large
78962	10511	538	Челябинская область, Челябинск, Береговая, 99	f	large
79456	11154	1315	Челябинская область, Челябинск, Бахметьева, 11	f	large
79834	11787	2038	Челябинская область, Челябинск, Батумская, 10	f	large
79833	11787	2037	Челябинская область, Челябинск, Батумская, 10	f	large
79832	11786	2036	Челябинская область, Челябинск, Батумская, 3	f	large
79804	11769	2008	Челябинская область, Челябинск, Барбюса, 65а	f	large
79803	11769	2007	Челябинская область, Челябинск, Барбюса, 65а	f	large
79802	11767	2006	Челябинская область, Челябинск, Барбюса, 140б	f	large
79800	11767	2004	Челябинская область, Челябинск, Барбюса, 140б	f	large
79177	10637	763	Челябинская область, Челябинск, Бажова, 32	f	large
79175	10635	761	Челябинская область, Челябинск, Бажова, 48	f	large
79148	10615	734	Челябинская область, Челябинск, Артиллерийская, 55а	f	large
79145	10613	731	Челябинская область, Челябинск, Артиллерийская, 100	f	large
134604	11985	2258	Челябинская область, Челябинск, Академика Макеева, 5А, 2 ЭТАЖ, ХОЛЛ	f	large
79238	10680	825	Челябинская область, Челябинск, Академика Макеева, 5а	f	large
79237	10680	824	Челябинская область, Челябинск, Академика Макеева, 5а	f	large
79820	11764	2024	Челябинская область, Челябинск, Агалакова, 46	f	large
79819	11764	2023	Челябинская область, Челябинск, Агалакова, 46	f	large
79818	11764	2022	Челябинская область, Челябинск, Агалакова, 46	f	large
79795	11764	1999	Челябинская область, Челябинск, Агалакова, 46	f	large
79794	11763	1998	Челябинская область, Челябинск, Агалакова, 19	f	large
79793	11763	1997	Челябинская область, Челябинск, Агалакова, 19	f	large
79094	10571	677	Челябинская область, Челябинск, 60 Лет Октября, 46	f	large
79092	10570	675	Челябинская область, Челябинск, 60 Лет Октября, 26	f	large
79093	10570	676	Челябинская область, Челябинск, 60 Лет Октября, 26	f	large
79089	10568	672	Челябинская область, Челябинск, 60 Лет Октября, 5	f	large
79088	10568	671	Челябинская область, Челябинск, 60 Лет Октября, 5	f	large
79129	10601	715	Челябинская область, Челябинск, 50 Лет ВЛКСМ, 1	f	large
79128	10601	714	Челябинская область, Челябинск, 50 Лет ВЛКСМ, 1	f	large
79127	10600	713	Челябинская область, Челябинск, 50 Лет ВЛКСМ, 7б	f	large
79126	10600	712	Челябинская область, Челябинск, 50 Лет ВЛКСМ, 7б	f	large
79124	10598	710	Челябинская область, Челябинск, 50 Лет ВЛКСМ, 16	f	large
79069	10556	649	Челябинская область, Челябинск, 40 лет Победы, 14А	f	large
79068	10556	648	Челябинская область, Челябинск, 40 лет Победы, 14А	f	large
79067	10556	647	Челябинская область, Челябинск, 40 лет Победы, 14А	f	large
79066	10556	646	Челябинская область, Челябинск, 40 лет Победы, 14А	f	large
79064	10555	644	Челябинская область, Челябинск, 40 Лет Победы, 17	f	large
79063	10554	643	Челябинская область, Челябинск, 40 Лет Победы, 17	f	large
79065	10554	645	Челябинская область, Челябинск, 40 Лет Победы, 17	f	large
79002	7839	578	Челябинская область, Челябинск, 40 Лет Победы, 24	f	large
79001	7839	577	Челябинская область, Челябинск, 40 Лет Победы, 24	f	large
79000	7839	576	Челябинская область, Челябинск, 40 Лет Победы, 24	f	large
79136	10605	722	Челябинская область, Челябинск, 32-й Годовщины Октября, 18а	f	large
79137	10605	723	Челябинская область, Челябинск, 32-й Годовщины Октября, 18а	f	large
79203	10651	790	Челябинская область, Челябинск, 3 Интернационала, 113	f	large
79202	10651	789	Челябинская область, Челябинск, 3 Интернационала, 113	f	large
79200	10651	787	Челябинская область, Челябинск, 3 Интернационала, 113	f	large
79199	10650	786	Челябинская область, Челябинск, 3 Интернационала, 61	f	large
79198	10650	785	Челябинская область, Челябинск, 3 Интернационала, 61	f	large
79197	10649	784	Челябинская область, Челябинск, 3 Интернационала, 61	f	large
79138	10606	724	Челябинская область, Челябинск, 26 Бакинских Комиссаров, 63	f	large
78995	10529	571	Челябинская область, Челябинск, 250-летия Челябинска, 7	f	large
78994	10529	570	Челябинская область, Челябинск, 250-летия Челябинска, 7	f	large
78993	10529	569	Челябинская область, Челябинск, 250-летия Челябинска, 7	f	large
78992	10529	568	Челябинская область, Челябинск, 250-летия Челябинска, 7	f	large
78999	6736	575	Челябинская область, Челябинск, 250-летия Челябинска, 15	f	large
78998	6736	574	Челябинская область, Челябинск, 250-летия Челябинска, 15	f	large
78997	6736	573	Челябинская область, Челябинск, 250-летия Челябинска, 15	f	large
78996	6736	572	Челябинская область, Челябинск, 250-летия Челябинска, 15	f	large
79195	10647	782	Челябинская область, Челябинск, 2-я Эльтонская, 16а	f	large
79194	10647	781	Челябинская область, Челябинск, 2-я Эльтонская, 16а	f	large
79193	10647	780	Челябинская область, Челябинск, 2-я Эльтонская, 16а	f	large
79213	10661	800	Челябинская область, Челябинск, 2-й Мелькомбинат, 26, участок 1	f	large
78959	10509	535	Челябинская область, Челябинск, Кирова, 3а	f	large
78980	10521	556	Челябинская область, Челябинск, Братьев Кашириных, 103б	f	large
78979	10521	555	Челябинская область, Челябинск, Братьев Кашириных, 103б	f	large
79806	11770	2010	Челябинская область, Челябинск, Барбюса, 79Б	f	large
79805	11770	2009	Челябинская область, Челябинск, Барбюса, 79Б	f	large
79176	10636	762	Челябинская область, Челябинск, Бажова, 46А	f	large
134601	11963	2230	Челябинская область, Чебаркуль, в/ч 89547, 1 этаж, фойе клуба в/ч 89547	t	large
129816	10437	449	Челябинская область, Чебаркуль, санаторий Каменный цветок, спортзал санаторияКаменный цветок	t	small
129815	10436	448	Челябинская область, Чебаркуль, санаторий УралВО	f	small
129814	10435	447	Челябинская область, Чебаркуль, Санаторий Еловое	f	medium
129813	10434	446	Челябинская область, Чебаркуль, санаторий Кисегач, клуб ООО Санаторий Кисегач	f	small
78932	10454	467	Челябинская область, Чебаркуль, Электростальская, 32 Б	f	large
78931	10453	466	Челябинская область, Чебаркуль, Электростальская, 32 Б	f	large
78930	10452	465	Челябинская область, Чебаркуль, Электростальская, 1А	f	large
129818	10439	451	Челябинская область, Чебаркуль, Шоссейная, 9	f	medium
78934	10456	469	Челябинская область, Чебаркуль, Фрунзе, 18	f	large
129821	10461	473	Челябинская область, Чебаркуль, Станционная, 10	t	medium
78922	10444	457	Челябинская область, Чебаркуль, Советская, 269А	f	large
78921	10432	456	Челябинская область, Чебаркуль, Советская, 45	f	large
78933	10455	468	Челябинская область, Чебаркуль, Мира, 21Б	f	large
78929	10451	464	Челябинская область, Чебаркуль, Мира, 19А	f	large
129817	10438	450	Челябинская область, Чебаркуль, Миасское шоссе, 5	f	small
78924	10446	459	Челябинская область, Чебаркуль, Ленина, 32 Б	f	large
78923	10445	458	Челябинская область, Чебаркуль, Ленина, 42	f	large
78920	10443	455	Челябинская область, Чебаркуль, Комсомольская, 7А	f	large
78919	10442	454	Челябинская область, Чебаркуль, Комсомольская, 7А	f	large
78918	10441	453	Челябинская область, Чебаркуль, Комсомольская, 7А	f	large
78936	10460	472	Челябинская область, Чебаркуль, Каширина, 58	f	large
129820	10459	471	Челябинская область, Чебаркуль, Каширина, 3	f	medium
78935	10457	470	Челябинская область, Чебаркуль, Каширина, 3	f	large
78926	10448	461	Челябинская область, Чебаркуль, Карпенко, 11	f	large
78928	10450	463	Челябинская область, Чебаркуль, 9 Мая, 9	f	large
78927	10449	462	Челябинская область, Чебаркуль, 9 Мая, 11	f	large
78925	10447	460	Челябинская область, Чебаркуль, 9 Мая, 9	f	large
129819	10440	452	Челябинская область, Чебаркуль, 1 Мая, 20	f	medium
130152	11139	1300	Челябинская область, Усть-Катав, 5	t	medium
79453	11147	1308	Челябинская область, Усть-Катав, Советская, 19	f	large
79447	11136	1297	Челябинская область, Усть-Катав, Революционная, 10	f	large
79450	11142	1303	Челябинская область, Усть-Катав, Рабочая, 39	f	large
79452	11145	1306	Челябинская область, Усть-Катав, Первомайская, 6	f	large
79446	11135	1296	Челябинская область, Усть-Катав, МКР3, 8а	f	large
79445	11133	1295	Челябинская область, Усть-Катав, МКР2, 39 	f	large
79444	11132	1294	Челябинская область, Усть-Катав, МКР2, 18	f	large
79443	11131	1293	Челябинская область, Усть-Катав, МКР2, 40	f	large
79442	11130	1292	Челябинская область, Усть-Катав, МКР1, 11	f	large
79451	11144	1305	Челябинская область, Усть-Катав, Ломоносова, 96а	f	large
79449	11141	1302	Челябинская область, Усть-Катав, Ленина, 40	f	large
130151	11138	1299	Челябинская область, Усть-Катав, Крупской, 158А	t	medium
130153	11143	1304	Челябинская область, Усть-Катав, Комсомольская, 40	f	medium
79448	11140	1301	Челябинская область, Усть-Катав, Комсомольская, 38	f	large
130155	11148	1309	Челябинская область, Усть-Катав, Железнодорожный переулок, 16	t	small
130150	11137	1298	Челябинская область, Усть-Катав, 40 Лет Октября, 37	f	medium
129718	10333	339	Челябинская область, Троицк	f	medium
129716	10314	320	Челябинская область, Троицк	f	small
78891	10321	327	Челябинская область, Троицк, Челябинская, 2	f	large
78886	10315	321	Челябинская область, Троицк, Циолковского, 12	f	large
129719	10334	340	Челябинская область, Троицк, Троицкая, 62	f	medium
78897	10328	334	Челябинская область, Троицк, Субботина, 56	f	large
78906	10339	345	Челябинская область, Троицк, Строителей, 24	f	large
78881	10309	315	Челябинская область, Троицк, Советская, 33	f	large
78880	10308	314	Челябинская область, Троицк, Советская, 31	f	large
78900	10331	337	Челябинская область, Троицк, Серафимовича, 7	f	large
78896	10327	333	Челябинская область, Троицк, Путевая, 49	f	large
129720	10340	346	Челябинская область, Троицк, Новая	f	medium
78889	10319	325	Челябинская область, Троицк, Малышева, 31	f	large
129717	10318	324	Челябинская область, Троицк, Малышева, 37	f	medium
78885	10313	319	Челябинская область, Троицк, Ленина, 135	f	large
78905	10338	344	Челябинская область, Троицк, Культуры, 6	f	large
78902	10335	341	Челябинская область, Троицк, Культуры	f	large
78903	10336	342	Челябинская область, Троицк, Крупской, 5	f	large
78893	10323	329	Челябинская область, Троицк, Крахмалева, 77	f	large
78892	10322	328	Челябинская область, Троицк, Крахмалева, 14	f	large
78882	10310	316	Челябинская область, Троицк, Красноармейская, 28	f	large
78883	10311	317	Челябинская область, Троицк, Климова, 2	f	large
129540	10326	332	Челябинская область, Троицк, Кирова, 30	f	large
78894	10324	330	Челябинская область, Троицк, Качинского, 2	f	large
78898	10329	335	Челябинская область, Троицк, Инженерная, 149	f	large
78884	10312	318	Челябинская область, Троицк, Иванова, 19	f	large
78890	10320	326	Челябинская область, Троицк, Жиркомбинат, 16	f	large
78899	10330	336	Челябинская область, Троицк, Дерибаса, 30	f	large
78901	10332	338	Челябинская область, Троицк, Гастелло, 60	f	large
129721	10341	347	Челябинская область, Троицк, Гагарина, 1	f	medium
78888	10317	323	Челябинская область, Троицк, Гагарина, 25	f	large
78887	10316	322	Челябинская область, Троицк, Гагарина, 13	f	large
78879	10307	313	Челябинская область, Троицк, Гагарина, 20	f	large
78895	10325	331	Челябинская область, Троицк, Автодромная, 2	f	large
78878	10306	312	Челябинская область, Троицк, 5 микрорайон	f	large
129715	10305	311	Челябинская область, Троицк, 5 микрорайон	f	medium
78877	10304	310	Челябинская область, Троицк, 2 микрорайон, 13	f	large
78904	10337	343	Челябинская область, Троицк, 10 квартал	f	large
79295	10778	925	Челябинская область, Трехгорный, Мира, 23	f	large
79428	11115	1276	Челябинская область, Снежинск, Свердлова, 8	f	large
79434	11120	1282	Челябинская область, Снежинск, Дзержинского, 25	f	large
130512	11719	1948	Челябинская область, поселок Синеглазово, Шоссейная, 9	t	small
79263	10722	868	Челябинская область, Сим, Симская, 22	f	large
79261	10719	865	Челябинская область, Сим, Нагорная, 79	t	large
129881	10713	859	Челябинская область, Сим, Лесная, 7	f	medium
79262	10721	867	Челябинская область, Сим, Курчатова, 8	f	large
79260	10718	864	Челябинская область, Сим, Кирова, 11	f	large
129884	10717	863	Челябинская область, Сим, Кирова, 9	f	medium
129882	10715	861	Челябинская область, Сим, Кирова, 3	f	medium
79264	10724	870	Челябинская область, Сим, Заводская, 1	t	large
79367	11034	1184	Челябинская область, Сатка, площадь Ленина, 2	f	large
79380	11053	1205	Челябинская область, Сатка, микрорайон Западный, 1	f	large
79379	11053	1204	Челябинская область, Сатка, микрорайон Западный, 1	f	large
79371	11041	1191	Челябинская область, Сатка, Солнечная, 28	f	large
79369	11039	1189	Челябинская область, Сатка, Солнечная, 4	f	large
130118	11045	1196	Челябинская область, Сатка, Пролетарская, 24	f	medium
79373	11044	1195	Челябинская область, Сатка, Пролетарская, 14	f	large
130117	11044	1194	Челябинская область, Сатка, Пролетарская, 14	f	medium
79378	11052	1203	Челябинская область, Сатка, Матросова, 8	f	large
79375	11047	1198	Челябинская область, Сатка, Ленина, 2а	f	large
79374	11046	1197	Челябинская область, Сатка, Ленина, 4	f	large
130119	11049	1200	Челябинская область, Сатка, Куйбышева, 2	f	medium
79377	11050	1201	Челябинская область, Сатка, Кирова, 7	f	large
130113	11035	1186	Челябинская область, Сатка, Карла Маркса, 45	f	medium
130112	11035	1185	Челябинская область, Сатка, Карла Маркса, 45	f	medium
130116	11042	1192	Челябинская область, Сатка, 50 лет ВЛКСМ, 26	f	medium
79372	11043	1193	Челябинская область, Сатка, 50 Лет ВЛКСМ, 24а	f	large
79382	11054	1207	Челябинская область, Сатка, 40 Лет Победы, 15	f	large
79381	11054	1206	Челябинская область, Сатка, 40 Лет Победы, 15	f	large
130120	11051	1202	Челябинская область, Сатка, 4 квартал, 90	f	medium
79376	11048	1199	Челябинская область, Сатка, 100летия Комбината Магнезит, 1	f	large
79756	11721	1950	Челябинская область, поселок Роза, Проходчиков, 4	f	large
78876	10283	289	Челябинская область, Пласт, Учебный городок, 1	f	large
129692	10284	290	Челябинская область, Пласт, Строителей, 8	f	small
78874	10282	286	Челябинская область, Пласт, Приисковый, 40	f	large
78873	10281	285	Челябинская область, Пласт, Октябрьская, 26	f	large
78872	10280	284	Челябинская область, Пласт, Октябрьская, 43	f	large
78871	10279	283	Челябинская область, Пласт, Октябрьская, 54	f	large
78870	10278	282	Челябинская область, Пласт, Мамина-Сибиряка, 2А	f	large
129691	10226	287	Челябинская область, Пласт, Красноармейская, 16	f	medium
78869	10277	281	Челябинская область, Пласт, 9 Января, 2а	f	large
78875	10141	288	Челябинская область, Пласт, Володарского, 2	f	large
79781	11752	1983	Челябинская область, поселок Первомайский, Нечепуренко, 3	f	large
79410	11096	1256	Челябинская область, Озеры, Цветочная, 12	f	large
79409	11096	1255	Челябинская область, Озеры, Цветочная, 12	f	large
79422	11106	1268	Челябинская область, Озерск, Южная, 15	f	large
79397	11086	1243	Челябинская область, Озерск, Уральская, 15	f	large
79943	11960	2227	Челябинская область, Озерск, Театральная, 1	f	large
79402	11091	1248	Челябинская область, Озерск, Студенческая, 7	f	large
79396	11085	1242	Челябинская область, Озерск, Советская, 43	f	large
79420	11104	1266	Челябинская область, Озерск, Семенова, 5	f	large
79403	11092	1249	Челябинская область, Озерск, Победы проспект, 15а	f	large
79419	11103	1265	Челябинская область, Озерск, Матросова, 44	f	large
79418	11102	1264	Челябинская область, Озерск, Матросова, 49	f	large
79417	11102	1263	Челябинская область, Озерск, Матросова, 49	f	large
79400	11089	1246	Челябинская область, Озерск, Лермонтова, 19	f	large
79411	11097	1257	Челябинская область, Озерск, Красная, 1а	f	large
79412	11097	1258	Челябинская область, Озерск, Красная, 1а	f	large
79404	11093	1250	Челябинская область, Озерск, Космонавтов, 27	f	large
79408	11095	1254	Челябинская область, Озерск, Карла Маркса, 14	f	large
79415	11100	1261	Челябинская область, Озерск, Калинина, 8	f	large
79416	11101	1262	Челябинская область, Озерск, Иртышская, 1	f	large
79421	11105	1267	Челябинская область, Озерск, Ермолаева, 26	f	large
79401	11090	1247	Челябинская область, Озерск, Герцена, 12	f	large
79407	11094	1253	Челябинская область, Озерск, Гайдара, 8	f	large
79406	11094	1252	Челябинская область, Озерск, Гайдара, 8	f	large
79395	11084	1241	Челябинская область, Озерск, Блюхера, 22	f	large
79394	11084	1240	Челябинская область, Озерск, Блюхера, 22	f	large
79405	11088	1251	Челябинская область, Озерск, Бажова, 14	f	large
79399	11088	1245	Челябинская область, Озерск, Бажова, 14	f	large
79398	11087	1244	Челябинская область, Озерск, Бажова, 28	f	large
79423	11109	1270	Челябинская область, Озерск, 8 Марта, 6	f	large
129490	11601	1816	Челябинская область, поселок Огнеупорный, Строительная, 10	f	small
130095	11018	1168	Челябинская область, Нязепетровск, Южная, 1	f	medium
130094	11017	1167	Челябинская область, Нязепетровск, Свободы, 38	f	small
79365	11013	1163	Челябинская область, Нязепетровск, Свердлова, 23	f	large
79364	11012	1162	Челябинская область, Нязепетровск, Свердлова, 1	f	large
130092	11015	1165	Челябинская область, Нязепетровск, Ленина, 97	f	small
79366	11014	1164	Челябинская область, Нязепетровск, Колина, 96	f	large
129533	11016	1166	Челябинская область, Нязепетровск, Клубная, 19	f	large
79363	11011	1161	Челябинская область, Нязепетровск, Бархатовой, 15	f	large
130552	11880	2147	Челябинская область, деревня Новое Поле, Садовая, 6	f	medium
79258	10712	858	Челябинская область, Миньяр, Чертова, 22	f	large
79255	10706	853	Челябинская область, Миньяр, Центральная, 7	f	large
79254	10705	852	Челябинская область, Миньяр, Советская, 97	f	large
129879	10708	855	Челябинская область, Миньяр, Куйбышева, 20	f	medium
129880	10710	857	Челябинская область, Миньяр, Кирова, 70	f	medium
129628	10162	148	Челябинская область, Миасс, Дом отдыха Золотой пляж	t	small
78808	10172	164	Челябинская область, Миасс, проспект Октября, 71	f	large
78809	10172	165	Челябинская область, Миасс, проспект Октября, 71	f	large
78810	10171	167	Челябинская область, Миасс, проспект Октября, 25	f	large
78807	10171	163	Челябинская область, Миасс, проспект Октября, 25	f	large
78803	10168	159	Челябинская область, Миасс, проспект Октября, 4	f	large
78802	10154	158	Челябинская область, Миасс, проспект Макеева, 23	f	large
78801	10154	157	Челябинская область, Миасс, проспект Макеева, 23	f	large
78822	10188	181	Челябинская область, Миасс, проспект Автозаводцев, 37А	f	large
78819	10185	178	Челябинская область, Миасс, проспект Автозаводцев, 5А	f	large
78823	10189	182	Челябинская область, Миасс, проезд Автозаводцев, 43	f	large
78798	10166	154	Челябинская область, Миасс, пр.Макеева, 14	f	large
78797	10166	153	Челябинская область, Миасс, пр.Макеева, 14	f	large
129546	10173	166	Челябинская область, Миасс, пр. Макеева, 39, ДДТ «Остров»	f	large
78818	10184	177	Челябинская область, Миасс, пл.Предзаводская, 1	f	large
129626	10160	146	Челябинская область, Миасс, Школьная, 47В	t	medium
78795	10164	151	Челябинская область, Миасс, Циолковского, 14	f	large
78794	10164	150	Челябинская область, Миасс, Циолковского, 14	f	large
78838	10197	197	Челябинская область, Миасс, Степана Разина, 4	f	large
78837	10197	196	Челябинская область, Миасс, Степана Разина, 4	f	large
78862	10220	223	Челябинская область, Миасс, Советская, 33	f	large
78825	10191	184	Челябинская область, Миасс, Романенко, 89	f	large
78815	10179	172	Челябинская область, Миасс, Романенко, 3	f	large
78851	10208	210	Челябинская область, Миасс, Ровная, 15	f	large
78859	10215	218	Челябинская область, Миасс, Пушкина, 53	f	large
78858	10215	217	Челябинская область, Миасс, Пушкина, 53	f	large
78857	10214	216	Челябинская область, Миасс, Пушкина, 8	f	large
78853	10210	212	Челябинская область, Миасс, Пролетарская, 12	f	large
78854	10211	213	Челябинская область, Миасс, Первомайская, 10	f	large
78852	10209	211	Челябинская область, Миасс, Первомайская, 5	f	large
78844	10201	203	Челябинская область, Миасс, Осипенко, 1	f	large
129545	10183	176	Челябинская область, Миасс, Орловская, 7, школа № 4	f	large
129544	10181	175	Челябинская область, Миасс, Орловская, 7, школа № 4	f	large
78817	10180	174	Челябинская область, Миасс, Орловская, 48	f	large
78816	10180	173	Челябинская область, Миасс, Орловская, 48	f	large
129634	10223	226	Челябинская область, Миасс, Озерная, клуб Урал	f	medium
78811	10175	168	Челябинская область, Миасс, Нахимова, 8	f	large
129627	10161	147	Челябинская область, Миасс, Нагорная, 1А	t	medium
78792	10159	145	Челябинская область, Миасс, Макурина, 154	f	large
78799	10167	155	Челябинская область, Миасс, Макеева проспект, 8Б	f	large
78800	10165	156	Челябинская область, Миасс, Макеева проспект, 39	f	large
78796	10165	152	Челябинская область, Миасс, Макеева проспект, 39	f	large
78832	10194	191	Челябинская область, Миасс, Лихачева, 33А	f	large
78831	10194	190	Челябинская область, Миасс, Лихачева, 33А	f	large
78827	10190	186	Челябинская область, Миасс, Лихачева, 15	f	large
78824	10190	183	Челябинская область, Миасс, Лихачева, 15	f	large
129531	10221	224	Челябинская область, Миасс, Ленина, 1, школа №32	t	large
129631	10217	220	Челябинская область, городской округ Миасс, Ленина, 17, ДК	f	medium
78856	10213	215	Челябинская область, Миасс, Ленина, 121	f	large
78793	10163	149	Челябинская область, Миасс, Курортная, 2	f	large
78846	10203	205	Челябинская область, Миасс, Кирова, 85	f	large
78845	10202	204	Челябинская область, Миасс, Кирова, 53	f	large
78814	10178	171	Челябинская область, Миасс, Керченская, 1	f	large
78812	10176	169	Челябинская область, Миасс, Керченская, 6	f	large
78820	10186	179	Челябинская область, Миасс, Калинина, 37	f	large
78847	10204	206	Челябинская область, Миасс, Зеленая, 16	f	large
78813	10177	170	Челябинская область, Миасс, Донская, 15	f	large
78843	10200	202	Челябинская область, Миасс, Готвальда, 48	f	large
78842	10199	201	Челябинская область, Миасс, Готвальда, 38	f	large
78841	10199	200	Челябинская область, Миасс, Готвальда, 38	f	large
78840	10198	199	Челябинская область, Миасс, Готвальда, 7	f	large
78848	10205	207	Челябинская область, Миасс, Герцена, 1	f	large
78806	10170	162	Челябинская область, Миасс, Вернадского, 1А	f	large
78855	10212	214	Челябинская область, Миасс, Березовская, 147	f	large
78835	10193	194	Челябинская область, Миасс, Ак.Павлова, 17	f	large
78834	10193	193	Челябинская область, Миасс, Ак.Павлова, 17	f	large
78828	10193	187	Челябинская область, Миасс, Ак.Павлова, 17	f	large
78821	10187	180	Челябинская область, Миасс, Автозаводцев, 21	f	large
78839	10196	198	Челябинская область, Миасс, 8 Марта, 131	f	large
78836	10196	195	Челябинская область, Миасс, 8 Марта, 131	f	large
78833	10195	192	Челябинская область, Миасс, 8 Марта, 134	f	large
78830	10192	189	Челябинская область, Миасс, 8 Июля, 45	f	large
78829	10192	188	Челябинская область, Миасс, 8 Июля, 45	f	large
78826	10192	185	Челябинская область, Миасс, 8 Июля, 45	f	large
78850	10207	209	Челябинская область, Миасс, 60 лет октября, 11, ОООМиасстрансплюс	f	large
78849	10206	208	Челябинская область, Миасс, 60 лет Октября, 12	f	large
129632	10218	221	Челябинская область, Миасс, 40 лет Октября, 14А, школа №23	t	medium
78805	10169	161	Челябинская область, Миасс, пр.Октября, 14	f	large
78804	10169	160	Челябинская область, Миасс, пр.Октября, 14	f	large
78860	10216	219	Челябинская область, Миасс, Нефтянников, 14, ДК Комсомолец	f	large
130558	11889	2156	Челябинская область, поселок Малая Сосновка, ОАО Челябинское по племенной работе, Административный корпус	t	small
79565	11249	1436	Челябинская область, Магнитогорск, проспект Пушкина, 17	f	large
130166	11249	1426	Челябинская область, Магнитогорск, проспект Пушкина, 17	f	medium
79550	11241	1417	Челябинская область, Магнитогорск, проспект Пушкина, 19	f	large
79482	11180	1343	Челябинская область, Магнитогорск, проспект Ленина , 38	f	large
79566	11257	1437	Челябинская область, Магнитогорск, проспект Ленина, 135	f	large
79544	11233	1408	Челябинская область, Магнитогорск, проспект Ленина, 114	f	large
79543	11233	1407	Челябинская область, Магнитогорск, проспект Ленина, 114	f	large
79513	11208	1376	Челябинская область, Магнитогорск, проспект Ленина, 86/1	f	large
79493	11191	1355	Челябинская область, Магнитогорск, проспект Ленина, 58/2	f	large
129548	11193	1357	Челябинская область, Магнитогорск, проспект К. Маркса, 47	f	large
129521	11234	1410	Челябинская область, Магнитогорск, проспект К. Маркса, 141/1	f	large
129520	11234	1409	Челябинская область, Магнитогорск, проспект К. Маркса, 141/1	f	large
79585	11267	1458	Челябинская область, Магнитогорск, проезд Сиреневый, 34	f	large
79531	11224	1395	Челябинская область, Магнитогорск, проезд Карла Маркса, 111	f	large
79537	11228	1401	Челябинская область, Магнитогорск, пр.Карла Маркса, 158	f	large
79506	11202	1369	Челябинская область, Магнитогорск, пр. Карла Маркса, 106	f	large
79504	11200	1367	Челябинская область, Магнитогорск, пр. Карла Маркса, 79	f	large
79471	11168	1331	Челябинская область, Магнитогорск, пр. К. Маркса, 52	f	large
79525	11219	1389	Челябинская область, Магнитогорск, переулок Советский, 11	f	large
79526	11220	1390	Челябинская область, Магнитогорск, пер. Советский, 11	f	large
79498	11196	1361	Челябинская область, Магнитогорск, имени газеты Правда, 79	f	large
79497	11196	1360	Челябинская область, Магнитогорск, имени газеты Правда, 79	f	large
79563	11255	1433	Челябинская область, Магнитогорск, Ярославского, 2	f	large
79564	11255	1434	Челябинская область, Магнитогорск, Ярославского, 2	f	large
130163	11240	1416	Челябинская область, Магнитогорск, Шоссейная, 13	f	medium
79547	11238	1413	Челябинская область, Магнитогорск, Школьный переулок, 3	f	large
129446	11247	1424	Челябинская область, Магнитогорск, Чкалова , 16А	f	medium
79562	11254	1432	Челябинская область, Магнитогорск, Чкалова, 104	t	large
79561	11253	1431	Челябинская область, Магнитогорск, Чкалова, 60а	f	large
79560	11253	1430	Челябинская область, Магнитогорск, Чкалова, 60а	f	large
79555	11245	1422	Челябинская область, Магнитогорск, Чкалова, 17	f	large
79469	11166	1329	Челябинская область, Магнитогорск, Урицкого, 11	f	large
79468	11165	1328	Челябинская область, Магнитогорск, Уральская, 162	f	large
79606	11284	1479	Челябинская область, Магнитогорск, Труда, 49	f	large
129550	11283	2254	Челябинская область, Магнитогорск, Труда, 47/1	f	large
79605	11283	1478	Челябинская область, Магнитогорск, Труда, 47/1	f	large
79604	11283	1477	Челябинская область, Магнитогорск, Труда, 47/1	f	large
79599	11279	1472	Челябинская область, Магнитогорск, Труда, 31/1	f	large
79593	11274	1466	Челябинская область, Магнитогорск, Труда, 36	f	large
79587	11269	1460	Челябинская область, Магнитогорск, Труда, 19/1	f	large
79586	11268	1459	Челябинская область, Магнитогорск, Труда, 19/1	f	large
79559	11252	1429	Челябинская область, Магнитогорск, Тихвинский переулок, 2	f	large
79611	11287	1484	Челябинская область, Магнитогорск, Тевосяна, 27/3	f	large
79610	11287	1483	Челябинская область, Магнитогорск, Тевосяна, 27/3	f	large
79609	11287	1482	Челябинская область, Магнитогорск, Тевосяна, 27/3	f	large
79607	11285	1480	Челябинская область, Магнитогорск, Тевосяна, 9/1	f	large
79530	11223	1394	Челябинская область, Магнитогорск, Суворова, 135	f	large
79529	11223	1393	Челябинская область, Магнитогорск, Суворова, 135	f	large
79528	11222	1392	Челябинская область, Магнитогорск, Суворова, 136/4	f	large
79527	11221	1391	Челябинская область, Магнитогорск, Суворова, 136/4	f	large
79523	11217	1387	Челябинская область, Магнитогорск, Суворова, 134/1	f	large
79522	11216	1386	Челябинская область, Магнитогорск, Суворова, 134/1	f	large
79510	11205	1373	Челябинская область, Магнитогорск, Суворова, 117	f	large
79509	11205	1372	Челябинская область, Магнитогорск, Суворова, 117	f	large
79508	11204	1371	Челябинская область, Магнитогорск, Суворова, 117/2	f	large
79472	11169	1332	Челябинская область, Магнитогорск, Суворова, 76а	f	large
79470	11167	1330	Челябинская область, Магнитогорск, Суворова, 25а	f	large
79486	11185	1348	Челябинская область, Магнитогорск, Строителей проспект, 56	f	large
79542	11232	1406	Челябинская область, Магнитогорск, Сталеваров, 13	f	large
79539	11230	1403	Челябинская область, Магнитогорск, Сталеваров, 11	f	large
79538	11229	1402	Челябинская область, Магнитогорск, Сталеваров, 8	f	large
79557	11248	1425	Челябинская область, Магнитогорск, Сосновая, 17А	f	large
79536	11227	1400	Челябинская область, Магнитогорск, Советской армии, 51А	f	large
79608	11286	1481	Челябинская область, Магнитогорск, Советская, 211	f	large
79601	11281	1474	Челябинская область, Магнитогорск, Советская, 199/1	f	large
79521	11215	1385	Челябинская область, Магнитогорск, Советская, 145/3	f	large
79520	11213	1383	Челябинская область, Магнитогорск, Советская, 70	f	large
79552	11242	1419	Челябинская область, Магнитогорск, Рубинштейна, 2а	f	large
79551	11242	1418	Челябинская область, Магнитогорск, Рубинштейна, 2а	f	large
79556	11246	1423	Челябинская область, Магнитогорск, Ржевского переулок, 4	f	large
130167	11250	1427	Челябинская область, Магнитогорск, Проспект Пушкина, 38	f	medium
79602	11278	1475	Челябинская область, Магнитогорск, Проспект Карла Маркса, 198/4	f	large
79598	11278	1471	Челябинская область, Магнитогорск, Проспект Карла Маркса, 198/4	f	large
79597	11277	1470	Челябинская область, Магнитогорск, Проспект Карла Маркса, 194/3	f	large
79512	11207	1375	Челябинская область, Магнитогорск, Проспект Карла Маркса, 97/1	f	large
79511	11207	1374	Челябинская область, Магнитогорск, Проспект Карла Маркса, 97/1	f	large
79503	11199	1366	Челябинская область, Магнитогорск, Проспект Карла Маркса, 86	f	large
64842	72479	2922	Пермский край, Пермь, Мира, 26	f	large
79502	11199	1365	Челябинская область, Магнитогорск, Проспект Карла Маркса, 86	f	large
129563	11266	1457	Челябинская область, Магнитогорск, Проезд Сереневый, 34	f	large
79558	11251	1428	Челябинская область, Магнитогорск, Полевая, 3	f	large
130168	11256	1435	Челябинская область, Магнитогорск, Покровская, 13	t	medium
79554	11244	1421	Челябинская область, Магнитогорск, Планерная, 2А	f	large
79467	11164	1327	Челябинская область, Магнитогорск, Писарева, 2	f	large
79454	11152	1313	Челябинская область, Магнитогорск, Панькова, 32	f	large
79490	11188	1352	Челябинская область, Магнитогорск, Набережная, 24/1 	f	large
79487	11186	1349	Челябинская область, Магнитогорск, Набережная, 1	f	large
79477	11175	1338	Челябинская область, Магнитогорск, Н.Шишка, 10	f	large
79463	11161	1323	Челябинская область, Магнитогорск, Московская, 45	f	large
79461	11160	1321	Челябинская область, Магнитогорск, Московская, 14	f	large
79462	11160	1322	Челябинская область, Магнитогорск, Московская, 14	f	large
79459	11158	1319	Челябинская область, Магнитогорск, Московская, 15	f	large
79458	11157	1318	Челябинская область, Магнитогорск, Московская, 7	f	large
79478	11176	1339	Челябинская область, Магнитогорск, Менделеева, 8	f	large
79553	11243	1420	Челябинская область, Магнитогорск, Маяковского, 28	f	large
79480	11178	1341	Челябинская область, Магнитогорск, Ломоносова, 21	f	large
79495	11194	1358	Челябинская область, Магнитогорск, Лесопарковая, 99	f	large
79494	11192	1356	Челябинская область, Магнитогорск, Ленинградская, 24	f	large
79488	11187	1350	Челябинская область, Магнитогорск, Ленинградская, 3	f	large
79484	11183	1346	Челябинская область, Магнитогорск, Ленинградская, 10А	f	large
79489	11181	1351	Челябинская область, Магнитогорск, Ленинградская, 21А	f	large
130161	11181	1344	Челябинская область, Магнитогорск, Ленинградская, 21А	f	medium
79545	11236	1411	Челябинская область, Магнитогорск, Ленина проспект, 124/3	f	large
79535	11226	1399	Челябинская область, Магнитогорск, Ленина проспект, 96	f	large
79534	11226	1398	Челябинская область, Магнитогорск, Ленина проспект, 96	f	large
79481	11179	1342	Челябинская область, Магнитогорск, Ленина проспект, 26	f	large
130160	11172	1336	Челябинская область, Магнитогорск, Ленина проспект, 12	f	small
79479	11177	1340	Челябинская область, Магнитогорск, Комсомольская, 6	f	large
79549	11239	1415	Челябинская область, Магнитогорск, Коммунаров, 51/1	f	large
79548	11239	1414	Челябинская область, Магнитогорск, Коммунаров, 51/1	f	large
79546	11237	1412	Челябинская область, Магнитогорск, Коммунальная, 7	f	large
79603	11282	1476	Челябинская область, Магнитогорск, Карла Маркса проспект, 198/4	f	large
79507	11203	1370	Челябинская область, Магнитогорск, Карла Маркса, 106	f	large
79584	11265	1456	Челябинская область, Магнитогорск, Калмыкова, 8	f	large
79583	11265	1455	Челябинская область, Магнитогорск, Калмыкова, 8	f	large
79582	11265	1454	Челябинская область, Магнитогорск, Калмыкова, 8	f	large
79581	11265	1453	Челябинская область, Магнитогорск, Калмыкова, 8	f	large
79577	11263	1448	Челябинская область, Магнитогорск, Калмыкова, 5	f	large
79579	11263	1450	Челябинская область, Магнитогорск, Калмыкова, 5	f	large
79578	11263	1449	Челябинская область, Магнитогорск, Калмыкова, 5	f	large
79576	11263	1447	Челябинская область, Магнитогорск, Калмыкова, 5	f	large
79485	11184	1347	Челябинская область, Магнитогорск, Калинина, 6	f	large
79483	11182	1345	Челябинская область, Магнитогорск, Калинина, 18	f	large
79476	11173	1337	Челябинская область, Магнитогорск, Казакова, 11	f	large
79475	11171	1335	Челябинская область, Магнитогорск, Казакова, 14	f	large
79519	11212	1382	Челябинская область, Магнитогорск, Индустриальная, 4	f	large
79499	11197	1362	Челябинская область, Магнитогорск, Индустриальная, 26	f	large
134607	11988	2261	Челябинская область, Магнитогорск, Жукова, 9, детский клуб	f	large
79614	11280	1487	Челябинская область, Магнитогорск, Жукова, 4/1	f	large
79613	11280	1486	Челябинская область, Магнитогорск, Жукова, 4/1	f	large
79600	11280	1473	Челябинская область, Магнитогорск, Жукова, 4/1	f	large
79616	11270	1489	Челябинская область, Магнитогорск, Жукова, 7/2	f	large
79612	11270	1485	Челябинская область, Магнитогорск, Жукова, 7/2	f	large
79588	11270	1461	Челябинская область, Магнитогорск, Жукова, 7/2	f	large
79580	11264	1452	Челябинская область, Магнитогорск, Жемчужная, 11	f	large
130169	11264	1451	Челябинская область, Магнитогорск, Жемчужная, 11	f	medium
79496	11195	1359	Челябинская область, Магнитогорск, Енисейская, 135	f	large
79516	11210	1379	Челябинская область, Магнитогорск, Дружбы, 33	f	large
79515	11210	1378	Челябинская область, Магнитогорск, Дружбы, 33	f	large
79505	11201	1368	Челябинская область, Магнитогорск, Дружбы, 36	f	large
79592	11273	1465	Челябинская область, Магнитогорск, Доменщиков, 22	f	large
79533	11225	1397	Челябинская область, Магнитогорск, Грязнова, 36	f	large
79532	11225	1396	Челябинская область, Магнитогорск, Грязнова, 36	f	large
79518	11211	1381	Челябинская область, Магнитогорск, Грязнова, 11	f	large
79517	11211	1380	Челябинская область, Магнитогорск, Грязнова, 11	f	large
79514	11209	1377	Челябинская область, Магнитогорск, Грязнова, 51	f	large
79596	11276	1469	Челябинская область, Магнитогорск, Галиуллина, 33/3	f	large
79595	11276	1468	Челябинская область, Магнитогорск, Галиуллина, 33/3	f	large
79594	11275	1467	Челябинская область, Магнитогорск, Галиуллина, 19/1	f	large
79591	11272	1464	Челябинская область, Магнитогорск, Галиуллина, 22/1	f	large
79590	11271	1463	Челябинская область, Магнитогорск, Галиуллина, 20	f	large
79589	11271	1462	Челябинская область, Магнитогорск, Галиуллина, 20	f	large
79541	11231	1405	Челябинская область, Магнитогорск, Галиуллина, 11/3	f	large
79540	11231	1404	Челябинская область, Магнитогорск, Галиуллина, 11/3	f	large
79501	11198	1364	Челябинская область, Магнитогорск, Гагарина, 33	f	large
79500	11198	1363	Челябинская область, Магнитогорск, Гагарина, 33	f	large
79492	11190	1354	Челябинская область, Магнитогорск, Гагарина, 12	f	large
79575	11262	1446	Челябинская область, Магнитогорск, Ворошилова, 27	f	large
79574	11262	1445	Челябинская область, Магнитогорск, Ворошилова, 27	f	large
79571	11260	1442	Челябинская область, Магнитогорск, Ворошилова, 16/1	f	large
79570	11259	1441	Челябинская область, Магнитогорск, Ворошилова, 3	f	large
79569	11258	1440	Челябинская область, Магнитогорск, Ворошилова, 11/1	f	large
79568	11258	1439	Челябинская область, Магнитогорск, Ворошилова, 11/1	f	large
79567	11258	1438	Челябинская область, Магнитогорск, Ворошилова, 11/1	f	large
79460	11159	1320	Челябинская область, Магнитогорск, Вокзальная, 144	f	large
79457	11156	1317	Челябинская область, Магнитогорск, Войкова, 60	f	large
79573	11261	1444	Челябинская область, Магнитогорск, Бориса Ручьева, 10	f	large
79572	11261	1443	Челябинская область, Магнитогорск, Бориса Ручьева, 10	f	large
79474	11170	1334	Челябинская область, Магнитогорск, Белинского, 82	f	large
79473	11170	1333	Челябинская область, Магнитогорск, Белинского, 82	f	large
130159	11155	1316	Челябинская область, Магнитогорск, Бахметьева, 11	f	medium
79615	11288	1488	Челябинская область, Магнитогорск, 50-летия Магнитки, 48	f	large
79466	11163	1326	Челябинская область, Магнитогорск, Вокзальная, 88	f	large
79465	11163	1325	Челябинская область, Магнитогорск, Вокзальная, 88	f	large
79362	11009	1159	Челябинская область, город Кыштым, Мира, 13	t	large
130088	11005	1155	Челябинская область, Кыштым, Школьная, 1	f	medium
79359	11002	1152	Челябинская область, Кыштым, Челюскинцев, 57	f	large
79358	11002	1151	Челябинская область, Кыштым, Челюскинцев, 57	f	large
130082	10996	1142	Челябинская область, Кыштым, Станционная, 1А	f	small
129455	11003	1153	Челябинская область, Кыштым, Садовая, 19, МОУ СОШ №3	f	medium
129536	10997	1145	Челябинская область, Кыштым, Республики, 12	f	large
129535	10997	1144	Челябинская область, Кыштым, Республики, 12	f	large
79357	11001	1150	Челябинская область, Кыштым, Ленина, 28	f	large
79356	11001	1149	Челябинская область, Кыштым, Ленина, 28	f	large
79354	10999	1147	Челябинская область, Кыштым, Ленина, 13	f	large
79353	10998	1146	Челябинская область, Кыштым, Ленина, 31	f	large
129534	10993	1143	Челябинская область, Кыштым, Кирова, 72, МОУ ОШ №4	f	large
129454	10993	1139	Челябинская область, Кыштым, Кирова, 72, МОУ ОШ №4	f	medium
130077	10992	1138	Челябинская область, Кыштым, Интернационала, 103	f	medium
79352	10991	1137	Челябинская область, Кыштым, Интернационала, 83	f	large
79351	10990	1136	Челябинская область, Кыштым, Интернационала, 103б	f	large
79349	10988	1134	Челябинская область, Кыштым, Интернационала, 103	f	large
130089	11006	1156	Челябинская область, Кыштым, Дальняя, клуб санатория Дальняя Дача	f	medium
129539	11008	1158	Челябинская область, Кыштым, Гагарина, 1, МОУ ОШ №11	f	large
79942	11957	2225	Челябинская область, Кыштым, Вокзальная, 14	f	large
79360	11004	1154	Челябинская область, Кыштым, В. Сергеевой, 77	f	large
79350	10989	1135	Челябинская область, Кыштым, Бажова, 4	f	large
79361	11007	1157	Челябинская область, Кыштым, 2 Южная, 1	f	large
79355	11000	1148	Челябинская область, Кыштым, Ветеранов, 26	f	large
79370	11040	1190	Челябинская область, Куса, Спартака, 1, Стадион Труд	f	large
129532	10972	1119	Челябинская область, Куса, Спартака, 1, Стадион Труд	f	large
79340	10965	1112	Челябинская область, Куса, Советская, 5, Школа №8	f	large
79345	10974	1121	Челябинская область, Куса, Свободы, 13, Школа №1	f	large
130062	10968	1115	Челябинская область, Куса, Свердлова, 18, Детская музыкальная школа	f	medium
79344	10971	1118	Челябинская область, Куса, Правды, 25	f	large
79343	10970	1117	Челябинская область, Куса, Правды, 25, Школа № 9	f	large
79342	10967	1114	Челябинская область, Куса, Ленинградская, 23, Школа №7	f	large
79341	10966	1113	Челябинская область, Куса, Есенина, 8	f	large
79339	10964	1111	Челябинская область, Куса, Бубнова, 4, Дворец культуры	f	large
130065	10973	1120	Челябинская область, Куса, 3 Интернационала, 3, Машиностроительный техникум	f	medium
129984	10878	1021	Челябинская область, поселок Круглое, Озерная, 13	t	small
79903	11864	2130	Челябинская область, поселок Красное Поле, Солнечная, 1	f	large
79697	11627	1844	Челябинская область, Красногорский, Победы, 16	f	large
79693	11624	1840	Челябинская область, поселок Красногорский, Ленина, 4	f	large
79765	11729	1960	Челябинская область, Коркино	f	large
79769	11733	1964	Челябинская область, Коркино, Энгельса, 73	f	large
79778	11745	1976	Челябинская область, Коркино, Чкалова, 115	f	large
79770	11735	1966	Челябинская область, Коркино, Цвиллинга, 38	f	large
79764	11728	1959	Челябинская область, Коркино, Цвиллинга, 1Б	f	large
79775	11740	1971	Челябинская область, Коркино, Сони Кривой, 8	f	large
79773	11738	1969	Челябинская область, Коркино, Сони Кривой, 10	f	large
79776	11743	1974	Челябинская область, Коркино, Пушкова, 7А	f	large
130518	11747	1978	Челябинская область, Коркино, Пролетарская, 39	f	medium
79779	11748	1979	Челябинская область, Коркино, Новый, 1	f	large
79774	11739	1970	Челябинская область, Коркино, Моргунова, 7	f	large
79772	11737	1968	Челябинская область, Коркино, Мира, 45	f	large
79771	11736	1967	Челябинская область, Коркино, Мира, 52	f	large
130514	11734	1965	Челябинская область, Коркино, Ленина, 18	f	medium
130517	11746	1977	Челябинская область, Коркино, Керамиков, 1	f	small
130516	11742	1973	Челябинская область, Коркино, Заводская, 1А	f	medium
79766	11730	1961	Челябинская область, Коркино, Горняков, 12	f	large
79763	11727	1958	Челябинская область, Коркино, 9 Января, 34А	f	large
79777	11744	1975	Челябинская область, Коркино, 30 лет ВЛКСМ, 171	f	large
130515	11741	1972	Челябинская область, Коркино, 30 лет ВЛКСМ, 27	f	medium
79768	11732	1963	Челябинская область, Коркино, 1 Мая, 44	f	large
79767	11731	1962	Челябинская область, Коркино, 1 Мая, 24	f	large
129561	11679	1897	Челябинская область, Копейск,, Меховова, 12, Фойе 1 этаж	f	large
79737	11702	1926	Челябинская область, Копейск, проспект Славы, 13	f	large
79720	11687	1906	Челябинская область, Копейск, проспект Победы, 42	f	large
79719	11687	1905	Челябинская область, Копейск, проспект Победы, 42	f	large
79718	11686	1904	Челябинская область, Копейск, пр. Победы, 34А	f	large
79736	11701	1925	Челябинская область, Копейск, пр. Ильича, 14	f	large
79722	11690	1909	Челябинская область, Копейск, Электровозная, 18	f	large
79721	11689	1908	Челябинская область, Копейск, Электровозная, 11	f	large
79709	11675	1893	Челябинская область, Копейск, Черняховского, 8	f	large
130504	11677	1895	Челябинская область, Копейск, Чернышевского, 47	f	medium
79710	11676	1894	Челябинская область, Копейск, Чернышевского, 45	f	large
79751	11714	1943	Челябинская область, Копейск, Троицкая, 3	f	large
79750	11714	1942	Челябинская область, Копейск, Троицкая, 3	f	large
79713	11681	1899	Челябинская область, Копейск, Театральная, 6	f	large
79712	11680	1898	Челябинская область, Копейск, Театральная, 14	f	large
79728	11695	1916	Челябинская область, Копейск, Свободы переулок, 2А	f	large
130503	11672	1890	Челябинская область, Копейск, Саратовская, 3Б	t	medium
79753	11716	1945	Челябинская область, Копейск, Российская, 25	f	large
79651	11462	1665	Челябинская область, Карталы, Свердлова, 12	f	large
79717	11685	1903	Челябинская область, Копейск, Победы проспект, 34Б	f	large
79725	11693	1913	Челябинская область, Копейск, Пионерская, 17	f	large
79724	11693	1912	Челябинская область, Копейск, Пионерская, 17	f	large
130509	11711	1938	Челябинская область, Копейск, Орджоникидзе, 32	t	medium
79738	11703	1927	Челябинская область, Копейск, Новосибирская, 21	t	large
79711	11678	1896	Челябинская область, Копейск, Меховова, 10	f	large
79715	11683	1901	Челябинская область, Копейск, Лихачева, 4	f	large
79745	11708	1935	Челябинская область, Копейск, Лизы Чайкиной, 33	f	large
79744	11708	1934	Челябинская область, Копейск, Лизы Чайкиной, 33	f	large
79754	11718	1947	Челябинская область, Копейск, Ленина, 12	t	large
79729	11696	1917	Челябинская область, Копейск, Ленина, 40	f	large
79723	11691	1910	Челябинская область, Копейск, Кузнецова, 18	f	large
79733	11698	1921	Челябинская область, Копейск, Коммунистический проспект, 3Б	f	large
79732	11698	1920	Челябинская область, Копейск, Коммунистический проспект, 3Б	f	large
79749	11713	1941	Челябинская область, Копейск, Коммунистическая, 27	f	large
79748	11712	1940	Челябинская область, Копейск, Коммунистическая, 12	t	large
130510	11712	1939	Челябинская область, Копейск, Коммунистическая, 12	t	medium
79740	11705	1930	Челябинская область, Копейск, Калинина, 18	f	large
130505	11688	1907	Челябинская область, Копейск, Ильфа, 8	t	medium
79743	11707	1933	Челябинская область, Копейск, Забойщиков, 51	t	large
79731	11697	1919	Челябинская область, Копейск, Гольца, 18	f	large
79730	11697	1918	Челябинская область, Копейск, Гольца, 18	f	large
130506	11692	1911	Челябинская область, Копейск, Борьбы, 14А	f	medium
79714	11682	1900	Челябинская область, Копейск, Борьбы, 59	f	large
79716	11684	1902	Челябинская область, Копейск, 4 Пятилетка, 63	f	large
79747	11710	1937	Челябинская область, Копейск, 21 Партсъезда, 1	f	large
79708	11674	1892	Челябинская область, Копейск, 16 лет Октября, 24	f	large
79706	11671	1889	Челябинская область, Копейск, Октябрьская, 29	t	large
79727	11694	1915	Челябинская область, Копейск, Жданова, 25	f	large
79726	11694	1914	Челябинская область, Копейск, Жданова, 25	f	large
130507	11700	1923	Челябинская область, Копейск , Карла Маркса, 7	f	medium
79734	11700	1922	Челябинская область, Копейск , Карла Маркса, 7	f	large
79735	11700	1924	Челябинская область, Копейск , Карла Маркса, 7	f	large
129686	10272	276	Кировская область, Киров, улица Приозерная, 5	t	small
129432	10841	987	Челябинская область, Катав-Ивановск, Цементников, 9/3	t	medium
129956	10838	985	Челябинская область, Катав-Ивановск, Учительская, 1а	t	medium
79308	10833	981	Челябинская область, Катав-Ивановск, Степана Разина, 25	f	large
79306	10830	978	Челябинская область, Катав-Ивановск, Остров, 7	f	large
129960	10845	991	Челябинская область, Катав-Ивановск, Лесная, 9а	t	medium
79307	10831	979	Челябинская область, Катав-Ивановск, Ленина, 19	f	large
129431	10828	977	Челябинская область, Катав-Ивановск, Ленина, 16	f	medium
79311	10839	986	Челябинская область, Катав-Ивановск, Коммунальная, 10	t	large
79305	10827	976	Челябинская область, Катав-Ивановск, Дмитрия Тараканова, 6	f	large
79310	10836	983	Челябинская область, Катав-Ивановск, Гагарина, 8	f	large
129912	10783	930	Челябинская область, Касли, Стадионная, 89	f	medium
129919	10788	937	Челябинская область, Касли, Ретнева, 22	f	medium
129924	10793	943	Челябинская область, Касли, Луначарского, 118	f	medium
129914	10784	932	Челябинская область, Касли, Лобашова, 137	f	medium
129913	10784	931	Челябинская область, Касли, Лобашова, 137	f	medium
129921	10790	940	Челябинская область, Касли, Ленина, 42	f	medium
129920	10790	939	Челябинская область, Касли, Ленина, 42	f	medium
129917	10787	935	Челябинская область, Касли, Ленина, 59	f	medium
129918	10787	936	Челябинская область, Касли, Ленина, 59	f	medium
129916	10786	934	Челябинская область, Касли, Ленина, 16	f	medium
129915	10785	933	Челябинская область, Касли, Ленина, 29	f	medium
79299	10789	938	Челябинская область, Касли, Куйбышева, 43	f	large
129923	10792	942	Челябинская область, Касли, Калинина, 28	f	medium
129922	10791	941	Челябинская область, Касли, Калинина, 28	f	medium
129911	10782	929	Челябинская область, Касли, 8 марта, 50	f	medium
130322	11466	1669	Челябинская область, Карталы, Хладопункт, 7	f	medium
79661	11472	1676	Челябинская область, Карталы, Учебный переулок, 4	t	large
79658	11469	1673	Челябинская область, Карталы, Славы, 4	f	large
79649	11460	1663	Челябинская область, Карталы, Просвещения, 53	t	large
79655	11438	1670	Челябинская область, Карталы, Орджоникидзе, 6	f	large
79652	11463	1666	Челябинская область, Карталы, Лобырина, 44А	f	large
79657	11468	1672	Челябинская область, Карталы, Ленина, 7А	f	large
79656	11467	1671	Челябинская область, Карталы, Ленина, 22	f	large
79653	11464	1667	Челябинская область, Карталы, Карташева, 12 А	f	large
79650	11461	1664	Челябинская область, Карталы, Гагарина, 142	t	large
79660	11471	1675	Челябинская область, Карталы, Братьев Кашириных, 12	f	large
79654	11465	1668	Челябинская область, Карталы, Акмолинская, 66	t	large
78787	10148	135	Челябинская область, Карабаш, Ремесленная, 3	f	large
129624	10156	142	Челябинская область, Карабаш, Пролетарская, 101	t	medium
78788	10149	136	Челябинская область, Карабаш, Подлесная, 6	f	large
129623	10155	141	Челябинская область, Карабаш, Освобождение Урала, 154	f	small
129622	10153	140	Челябинская область, Карабаш, Освобождение Урала, 64	f	medium
78790	10151	138	Челябинская область, Карабаш, Металлургов, 9	f	large
78789	10150	137	Челябинская область, Карабаш, Металлургов, 15/1	f	large
129621	10152	139	Челябинская область, Карабаш, Комсомольская, 2	f	medium
78791	10158	144	Челябинская область, Карабаш, Клубная, 1, Военный городок №1	f	large
129620	10147	134	Челябинская область, Карабаш, Декабристов, 2	f	medium
78742	10101	81	Челябинская область, Златоуст, прт Гагарина, МОУ СОШ №9	f	large
78741	10101	80	Челябинская область, Златоуст, прт Гагарина, МОУ СОШ №9	f	large
78762	10114	101	Челябинская область, Златоуст, проспект Мира, 2А, Дворец Победа ОАО Златмаш	f	large
78738	10099	77	Челябинская область, Златоуст, проспект Гагарина, 5 линия, 7, МОУ СОШ №10	f	large
78737	10099	76	Челябинская область, Златоуст, проспект Гагарина, 5 линия, 7, МОУ СОШ №10	f	large
78736	10098	75	Челябинская область, Златоуст, проспект Гагарина, 5 линия, 4, Центр образования	f	large
78735	10098	74	Челябинская область, Златоуст, проспект Гагарина, 5 линия, 4, Центр образования	f	large
78743	10102	82	Челябинская область, Златоуст, проспект Гагарина, 3 мр, МОУ СОШ №, 9	f	large
78740	10100	79	Челябинская область, Златоуст, проспект Гагарина, 8, МОУ СОШ №34	f	large
78739	10100	78	Челябинская область, Златоуст, проспект Гагарина, 8, МОУ СОШ №34	f	large
78734	10097	73	Челябинская область, Златоуст, проспект Гагарина, 2, МОУ СОШ №35	f	large
78733	10097	72	Челябинская область, Златоуст, проспект Гагарина, 2, МОУ СОШ №35	f	large
78781	10131	121	Челябинская область, Златоуст, пос. Строителей, МОУ СОШ №38	f	large
78780	10131	120	Челябинская область, Златоуст, пос. Строителей, МОУ СОШ №38	f	large
78757	10110	96	Челябинская область, Златоуст, Шишкина, 20, МОУ СОШ № 4	f	large
78756	10110	95	Челябинская область, Златоуст, Шишкина, 20, МОУ СОШ № 4	f	large
78766	10118	105	Челябинская область, Златоуст, Чкалова, 30, СПЦО № 2 МОУ СО № 1	f	large
78760	10112	99	Челябинская область, Златоуст, Тургенева, 16, ГОУ ВПО ЮУрГУ в г. Златоусте	f	large
129614	10142	129	Челябинская область, Златоуст, Тихомирова, 1, МУК СЦКС Клуб с. Куваши	f	medium
78714	10079	53	Челябинская область, Златоуст, Тельмана, 1, МОУ СОШ №, 45	f	large
78719	10084	58	Челябинская область, Златоуст, Румянцева, 93А, МОУ ДОД Музыкальная школа №3	f	large
78718	10083	57	Челябинская область, Златоуст, Румянцева, 43, ООО ЗП Электроизделия	f	large
78717	10082	56	Челябинская область, Златоуст, Румянцева, 19, МУК ЦБС филиал № 1	f	large
78715	10080	54	Челябинская область, Златоуст, Румянцева, 113А, ДОД Дом детства и юношества	f	large
78730	10094	69	Челябинская область, Златоуст, Профсоюзная, 7, МОУ СОШ №, 1	f	large
78729	10093	68	Челябинская область, Златоуст, Профсоюзная, 7, МОУ СОШ №, 1	f	large
78763	10115	102	Челябинская область, Златоуст, Просвещения, 6, МОУ СОШ №, 21	f	large
78770	10123	110	Челябинская область, Златоуст, Октябрьская, 4, Златоустовское мед. училище	f	large
78724	10089	63	Челябинская область, Златоуст, Н.Вокзальная, 1б, ООО АТП	f	large
78761	10113	100	Челябинская область, Златоуст, Мира проспект, 1, ГБО УСПО Златоустовский ПГТ	f	large
78773	10126	113	Челябинская область, Златоуст, Металлургов, 8, МОУ СОШ №25	f	large
78731	10095	70	Челябинская область, Златоуст, Машиностроителей, 2а, ГОУ НПО ПУ4	f	large
129444	10143	130	Челябинская область, Златоуст, Ленина, 38, МУК СЦКС ДК	f	medium
78769	10122	109	Челябинская область, Златоуст, Ленина, 30, МОУ СОШ №3	f	large
78727	10091	66	Челябинская область, Златоуст, Ленина, 1, МУК ДК Булат	f	large
87116	10134	125	Челябинская область, Златоуст, Кусинское шоссе, 21, ГОУ НПО ПУ28	f	large
78784	10133	124	Челябинская область, Златоуст, Кусинское шоссе, 1А, Ресурсный центр проф. обучения	t	large
78783	10133	123	Челябинская область, Златоуст, Кусинское шоссе, 1А, Ресурсный центр проф. обучения	t	large
78732	10096	71	Челябинская область, Златоуст, Космонавтов, 1, МУК ЦБС	f	large
78786	10140	128	Челябинская область, Златоуст, Копровая, 2, МУК ДКБулат РЦНТ клубРадуга	t	large
78728	10092	67	Челябинская область, Златоуст, Ковшова, 7, ГОУ СПО ЗТЭТ	f	large
78782	10132	122	Челябинская область, Златоуст, Кирова, 6, Торговый дом ОАО ЗМЗ	t	large
78772	10125	112	Челябинская область, Златоуст, Карла Маркса, 26, МУК ДК Металлург	f	large
78771	10124	111	Челябинская область, Златоуст, Карла Маркса, 10, МОУ СОШ №18	f	large
78723	10088	62	Челябинская область, Златоуст, К. Заслонова, 1, ООШ № 77	t	large
78749	10104	88	Челябинская область, Златоуст, Зеленая, МОУ СОШ № 15	f	large
78748	10104	87	Челябинская область, Златоуст, Зеленая, МОУ СОШ № 15	f	large
78747	10104	86	Челябинская область, Златоуст, Зеленая, МОУ СОШ № 15	f	large
78746	10104	85	Челябинская область, Златоуст, Зеленая, МОУ СОШ № 15	f	large
78759	10111	98	Челябинская область, Златоуст, Дворцовая, 18, МОУ СОШ №, 2	f	large
78758	10111	97	Челябинская область, Златоуст, Дворцовая, 18, МОУ СОШ №, 2	f	large
78764	10116	103	Челябинская область, Златоуст, Горького, 1А, МУК ЦБС филиал №21	f	large
78767	10120	107	Челябинская область, Златоуст, Веселовская, 50, ООШ №29	f	large
129611	10119	106	Челябинская область, Златоуст, Веселовская, 50, ООШ №29	f	medium
78785	10137	126	Челябинская область, Златоуст, В. Рязанова, 31, ООШ №12	f	large
78777	10129	117	Челябинская область, Златоуст, Б. Кирпичная, 50, Центр эстет. воспитания детей	f	large
78725	10090	64	Челябинская область, Златоуст, Аносова, 129, ООШ №, 17	f	large
78726	10090	65	Челябинская область, Златоуст, Аносова, 129, ООШ №, 17	f	large
78720	10085	59	Челябинская область, Златоуст, Аносова, 239, МОУ СОШ №90	f	large
78716	10081	55	Челябинская область, Златоуст, Аносова, 202, ГОУ НПО ПУ35	f	large
78721	10086	60	Челябинская область, Златоуст, 8го Марта, 6, ООШ №, 4	t	large
78753	10107	92	Челябинская область, Златоуст, 40летия Победы, 38а, МОУ СОШ №, 36	f	large
78752	10107	91	Челябинская область, Златоуст, 40летия Победы, 38а, МОУ СОШ №, 36	f	large
78751	10106	90	Челябинская область, Златоуст, 40летия Победы, 38а, МОУ СОШ №, 36	f	large
78750	10105	89	Челябинская область, Златоуст, 40летия Победы, 19, МОУ ДОД Музыкальная школа № 2	f	large
78754	10108	93	Челябинская область, Златоуст, 40-летия Победы, 38А, МОУ СОШ №, 36	f	large
78755	10109	94	Челябинская область, Златоуст, 40 лет Победы, 20, Опорный пункт правопорядка	f	large
78722	10087	61	Челябинская область, Златоуст, 3я Тесьминская, 125, Техническая школа ОАО РЖД	f	large
78774	10127	114	Челябинская область, Златоуст, 3я Н.Заводская, 6, ГОУ НПО ПЛ111	f	large
78765	10117	104	Челябинская область, Златоуст, 30 лет ВЛКСМ, 8, МОУ ООШ № 5	f	large
78779	10130	119	Челябинская область, Златоуст, 2 квартал, 28, МОУ СОШ №37	f	large
78778	10130	118	Челябинская область, Златоуст, 2 квартал, 28, МОУ СОШ №37	f	large
78768	10121	108	Челябинская область, Златоуст, 1я Нагорная, 61, ООШ №20	f	large
78776	10128	116	Челябинская область, Златоуст, 1-я Н.Заводская, 87, МОУ СОШ №8	f	large
78775	10128	115	Челябинская область, Златоуст, 1-я Н.Заводская, 87, МОУ СОШ №8	f	large
78745	10103	84	Челябинская область, Златоуст, прт Гагарина, 3 мр, 40: ГОУ СПО ЗПК	f	large
78744	10103	83	Челябинская область, Златоуст, прт Гагарина, 3 мр, 40: ГОУ СПО ЗПК	f	large
129543	10138	127	Челябинская область, Златоуст, 2я Закаменская, 23, Админ.здание №2 ОАО ЗЗМК	f	large
79677	11605	1820	Челябинская область, Еманжелинск, Школенко, 34	f	large
79683	11612	1827	Челябинская область, Еманжелинск, Чкалова, 10	f	large
79682	11611	1826	Челябинская область, Еманжелинск, Чкалова, 20	f	large
79681	11610	1825	Челябинская область, Еманжелинск, Чкалова, 26	f	large
79684	11613	1828	Челябинская область, Еманжелинск, Чайковского, 12	f	large
79688	11616	1832	Челябинская область, Еманжелинск, Фрунзе, 58	f	large
79689	11617	1833	Челябинская область, Еманжелинск, Титова, 1	f	large
79675	11602	1817	Челябинская область, Еманжелинск, Спартака, 67	f	large
79676	11603	1818	Челябинская область, Еманжелинск, Советская, 14	f	large
79686	11615	1830	Челябинская область, Еманжелинск, Матросова, 9	f	large
79687	11614	1831	Челябинская область, Еманжелинск, Матросова, 6	f	large
79685	11614	1829	Челябинская область, Еманжелинск, Матросова, 6	f	large
79680	11609	1824	Челябинская область, Еманжелинск, Горького, 70	f	large
79678	11606	1821	Челябинская область, Еманжелинск, Гагарина, 5а	f	large
129527	11604	1819	Челябинская область, Еманжелинск, Восточная, 2, ООО Коркинский эксковаторно вагонноремонтный завод, промплощадка	f	large
79679	11607	1822	Челябинская область, Еманжелинск, Вахрушева, 1	f	large
79269	10740	886	Челябинская область, Верхний Уфалей, Халтурина, 2а	f	large
79280	10753	900	Челябинская область, Верхний Уфалей, Суворова, 2а	f	large
79273	10745	891	Челябинская область, Верхний Уфалей, Прямицына, 47	f	large
79267	10738	884	Челябинская область, Верхний Уфалей, Окишева, 9	f	large
79272	10744	890	Челябинская область, Верхний Уфалей, Ленина, 157А	f	large
79270	10742	888	Челябинская область, Верхний Уфалей, Ленина, 164	f	large
79268	10739	885	Челябинская область, Верхний Уфалей, Ленина, 24	f	large
79276	10748	894	Челябинская область, Верхний Уфалей, Бабикова, 62	f	large
79621	11293	1494	Челябинская область, Верхнеуральск, Советская, 110	f	large
129598	10037	40	Челябинская область, поселок Березовка, Новая, 1	t	medium
129982	10876	1019	Челябинская область, поселок Баландино, Железнодорожная, 25	t	small
79256	10707	854	Челябинская область, Аша, Центральная, 11	f	large
79249	10698	844	Челябинская область, Аша, Фрунзе, 34	f	large
79250	10699	845	Челябинская область, Аша, Узкоколейная, 1А	f	large
129878	10704	851	Челябинская область, поселок Аша, Тополиная, 2	t	medium
129873	10694	839	Челябинская область, Аша, Толстого, 16	f	medium
79252	10701	847	Челябинская область, Аша, Танкистов, 15	f	large
129870	10685	830	Челябинская область, Аша, Советская, 26	f	medium
79247	10696	841	Челябинская область, поселок Аша, Симская, 1А	f	large
129871	10688	833	Челябинская область, Аша, Озимина, 1	f	medium
79241	10687	832	Челябинская область, поселок Аша, Озимина, 36	f	large
129877	10703	850	Челябинская область, Аша, Некрасова, 19	f	medium
129876	10702	849	Челябинская область, Аша, Мира, 23	f	small
129872	10692	837	Челябинская область, Аша, Ленина, 47	f	medium
79243	10690	835	Челябинская область, Аша, Ленина, 39	f	large
79239	10684	829	Челябинская область, Аша, Ленина, 11	f	large
129875	10697	843	Челябинская область, поселок Аша, Лебедева, 9	f	medium
79248	10697	842	Челябинская область, поселок Аша, Лебедева, 9	f	large
129885	10720	866	Челябинская область, Аша, Курчатова, 3	f	medium
79253	10700	848	Челябинская область, Аша, Коммунистическая, 25	f	large
79251	10700	846	Челябинская область, Аша, Коммунистическая, 25	f	large
79246	10695	840	Челябинская область, Аша, Декабристов, 10	f	large
79259	10714	860	Челябинская область, Аша, Давыдова, 10	f	large
79245	10693	838	Челябинская область, Аша, 40 Лет Победы, 21	f	large
79244	10691	836	Челябинская область, Аша, 40 Лет Победы, 10	f	large
79242	10689	834	Челябинская область, Аша, 22 Партсъезда, 8	f	large
129480	11950	2217	Челябинская область, городской округ Южноуральск, поселок Летягино, Нижняя , 1	t	small
130156	11149	1310	Челябинская область, городской округ Усть-Катав, поселок Тюбеляс, Школьная, 46а	t	small
130157	11150	1311	Челябинская область, городской округ Усть-Катав, поселок Минка, Долгая, 34	t	small
130154	11146	1307	Челябинская область, городской округ Усть-Катав, поселок Малый Бердяш, Центральная, 2А	t	small
130158	11151	1312	Челябинская область, городской округ Усть-Катав, поселок Вергаза, Нижняя, 3	t	small
129698	10288	294	Челябинская область, городской округ Пласт, поселок Чукса, Новоселов, 7	t	small
129704	10294	300	Челябинская область, городской округ Пласт, поселок Новый Кумляк, Нагорная, 51а	t	small
129697	10287	293	Челябинская область, городской округ Пласт, поселок Кочкарь, Советская, 76	f	small
129701	10291	297	Челябинская область, городской округ Пласт, поселок Котлик, Окружная, 36А	t	small
129699	10289	295	Челябинская область, городской округ Пласт, поселок Демарино, Школьная, 4	f	small
129700	10290	296	Челябинская область, городской округ Пласт, поселок Демарино, Центральная, 1	f	small
129707	10297	303	Челябинская область, городской округ Пласт, поселок Верхняя Санарка, Ленина, 71	f	medium
130021	10926	1069	Московская область, Подольский район, деревня Борисовка	t	small
129706	10296	302	Челябинская область, городской округ Пласт, поселок Борисовка, Школьная, 25	f	medium
130464	11608	1823	Челябинская область, городской округ Пласт, поселок Борисовка, Садовая, 26а	t	medium
129633	10222	225	Челябинская область, городской округ Миасс, поселок Устиново, Зеленая, 6, Школа	t	small
78861	10219	222	Челябинская область, городской округ Миасс, поселок Нижний Атлян, Городок	t	large
129625	10157	143	Челябинская область, городской округ Миасс, поселок Мухаметово, Центральная, клуб поселка	t	small
130091	11010	1160	Челябинская область, городской округ Кыштым, поселок Увильды, клуб санатория Лесное озеро	f	small
129594	9856	34	Челябинская область, городской округ Кыштым, поселок Увильды, Солнечный переулок, 4	f	medium
130081	10995	1141	Челябинская область, городской округ Кыштым, поселок Слюдорудник, Школьная, 1	f	small
130080	10994	1140	Челябинская область, городской округ Кыштым, поселок Северный, МОУ ДОУ детский сад №10	t	small
130520	11750	1981	Челябинская область, городской округ Коркино, поселок Шумаки, Школьная, 11	t	small
130513	11726	1957	Челябинская область, городской округ Коркино, поселок Роза, Средняя, 35	t	medium
79757	11722	1951	Челябинская область, городской округ Коркино, поселок Роза, Проходчиков, 17	f	large
79762	11699	1956	Челябинская область, городской округ Коркино, поселок Роза, Котельный, 2	f	large
79760	11723	1954	Челябинская область, городской округ Коркино, поселок Роза, Борьбы, 1	f	large
79758	11723	1952	Челябинская область, городской округ Коркино, поселок Роза, Борьбы, 1	f	large
79761	11725	1955	Челябинская область, городской округ Коркино, поселок Роза, 50 Лет Октября, 6	f	large
79759	11724	1953	Челябинская область, городской округ Коркино, поселок Роза, 50 Лет ВЛКСМ, 78	f	large
130519	11749	1980	Челябинская область, городской округ Коркино, поселок Дубровка-Челябинская, Пришкольная, ж.д. станция	t	medium
129619	10146	133	Челябинская область, городской округ Карабаш, поселок Красный Камень	t	small
129617	10144	131	Челябинская область, городской округ Златоуст, поселок Веселовка, Ленина, 58, МУК СЦКС Клуб села Веселовка	t	small
79698	11628	1845	Челябинская область, городской округ Еманжелинск, поселок Красногорский, Мира, 10А	f	large
129513	11629	1846	Челябинская область, городской округ Еманжелинск, поселок Красногорский, Лермонтова, 9	f	large
129514	11629	1847	Челябинская область, городской округ Еманжелинск, поселок Красногорский, Лермонтова, 9	f	large
79696	11626	1843	Челябинская область, городской округ Еманжелинск, поселок Красногорский, Ленина, 19	f	large
79695	11626	1842	Челябинская область, городской округ Еманжелинск, поселок Красногорский, Ленина, 19	f	large
79694	11625	1841	Челябинская область, городской округ Еманжелинск, поселок Красногорский, Западная, 24	f	large
130466	11619	1835	Челябинская область, городской округ Еманжелинск, поселок Зауральский, Пятилетки, 2	f	medium
130465	11618	1834	Челябинская область, городской округ Еманжелинск, поселок Зауральский, Новолуговая, 31	f	medium
79690	11620	1836	Челябинская область, городской округ Еманжелинск, поселок Зауральский, Заводская площадь, 1	f	large
79692	11622	1838	Челябинская область, городской округ Еманжелинск, поселок Зауральский, 3й квартал	f	large
79691	11621	1837	Челябинская область, городской округ Еманжелинск, поселок Зауральский, 2й квартал	f	large
129909	10765	912	Челябинская область, городской округ Верхний Уфалей, поселок Силач, Путевая, 51	t	small
129904	10760	907	Челябинская область, городской округ Верхний Уфалей, поселок Нижний Уфалей, переулок Пролетарский, 1	f	medium
79283	10759	906	Челябинская область, городской округ Верхний Уфалей, поселок Нижний Уфалей, Энгельса, 1	f	large
129905	10761	908	Челябинская область, городской округ Верхний Уфалей, поселок Нижний Уфалей, Механизаторов, 11а	t	small
129898	10741	887	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, клуб поселка Строителей	f	medium
129908	10764	911	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, переулок Школьный, 4	t	small
112932	72683	3483	Пермский край, Пермь, Мира, 1	f	\N
79275	10747	893	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Якушева, 25	f	large
79278	10711	897	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Шулина, 6	f	large
129899	10750	896	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Хохрякова, 18	f	medium
129906	10762	909	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Советская, 1	t	small
129900	10751	898	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Садовая, 12	t	medium
129903	10758	905	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Полевая, 1	t	small
79282	10755	902	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Победы, 43	f	large
79281	10754	901	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Победы, 42	f	large
79279	10752	899	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Победы, 19	f	large
129901	10756	903	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Мира, 1	t	small
129910	10766	913	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Ленина, 13	t	small
79277	10749	895	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Ленина, 169	f	large
79271	10743	889	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Ленина, 186	f	large
79274	10746	892	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Карла Маркса, 135А	f	large
129902	10757	904	Челябинская область, городской округ Верхний Уфалей, Верхний Уфалей, Бакальская, 3	t	medium
79673	11581	1791	Челябинская область, Чесменский район, поселок Чесма, Чапаева, 28А, т. (35169) 21753, УИК	f	large
79672	14607	1790	Челябинская область, Чесменский район, поселок Чесма, Ленина, 67	f	large
129526	11580	1789	Челябинская область, Чесменский район, поселок Черноборский, Советская, 32	f	large
129495	11577	1786	Челябинская область, Чесменский район, поселок Цвиллинга, Мира, 13, 1 этаж, кабинет главы	f	small
130455	11595	1810	Челябинская область, Чесменский район, поселок Углицкий, Школьная, 10	t	medium
130461	11600	1815	Челябинская область, Чесменский район, поселок Тарутино, Школьная, 16	f	medium
129437	11545	1793	Челябинская область, Чесменский район, поселок Тарасовка, 30 лет Победы, 11	f	medium
79674	11592	1807	Челябинская область, Чесменский район, поселок Светлое, Пушкина, 25	f	large
130432	11582	1792	Челябинская область, Чесменский район, поселок Редутово, Гагарина, 27	f	small
130441	11583	1798	Челябинская область, Чесменский район, поселок Порт-Артур, Ленина, 19	f	small
130446	11586	1801	Челябинская область, Чесменский район, поселок Новый Путь, Центральная, 21	t	small
130459	11598	1813	Челябинская область, Чесменский район, поселок Новоукраинский, Первомайская, 46А	t	small
130440	11395	1797	Челябинская область, Чесменский район, поселок Новотемирский, Ленина, 10	f	small
129440	11597	1812	Челябинская область, Чесменский район, поселок Новоеткульский, Комсомольская , 21А	t	medium
130439	11386	1796	Челябинская область, Чесменский район, поселок Натальинский, Чапаева, 4	f	small
130451	11590	1805	Челябинская область, Чесменский район, поселок Московский, Дружбы, 292	t	small
130460	11599	1814	Челябинская область, Чесменский район, поселок Луговой, Центральная, 21	f	small
130456	11596	1811	Челябинская область, Чесменский район, поселок Клубовка, Окружная, 21	t	small
130454	11594	1809	Челябинская область, Чесменский район, поселок Климовка, Ленина, 81	f	small
130431	11579	1788	Челябинская область, Чесменский район, поселок Камышный, Набережная, 271	t	small
129498	11585	1800	Челябинская область, Чесменский район, поселок Калиновский, Советская, 12	f	small
130453	11593	1808	Челябинская область, Чесменский район, поселок Зеленая Долина, Ленина, 20	t	small
129496	11578	1787	Челябинская область, Чесменский район, поселок Бускульский, Центральная, 8	t	small
129438	10983	1795	Челябинская область, Чесменский район, поселок Березинский, Кирова, 13	f	medium
129439	11584	1799	Челябинская область, Чесменский район, поселок Беловка, Центральная, 17	t	medium
130450	11589	1804	Челябинская область, Чесменский район, поселок Баландино, Набережная, 5	t	small
79196	10648	783	Челябинская область, Челябинский городской округ, поселок Чурилово	f	large
129850	10495	506	Челябинская область, Чебаркульский район, поселок Щапино	t	small
129856	10502	513	Челябинская область, Чебаркульский район, поселок Шахматово, Солнечная, 1А	f	medium
130598	11955	2222	Челябинская область, Чебаркульский район, поселок Шабунина, Колхозная, 23, Здание магазина сельпо	t	small
78941	10498	509	Челябинская область, Чебаркульский район, поселок Филимоново	f	large
129834	10478	489	Челябинская область, Чебаркульский район, поселок Уштаганка	f	small
78940	10490	501	Россия	f	large
79940	10486	2223	Челябинская область, Чебаркульский район, поселок Тимирязевский, УИК:п. Тимирязевский	f	large
129842	10486	497	Челябинская область, Чебаркульский район, поселок Тимирязевский, УИК:п. Тимирязевский	f	medium
129853	10499	510	Челябинская область, Чебаркульский район, поселок Темир	t	small
129840	10484	495	Челябинская область, Чебаркульский район, поселок Ступино	t	small
134605	94447	2259	Челябинская область, Чебаркульский район, поселок Спутник, Ленина, 18Б	f	small
129838	10482	493	Челябинская область, Чебаркульский район, поселок Сарафаново	f	medium
129845	10489	500	Челябинская область, Чебаркульский район, поселок Самарка	t	small
129848	10493	504	Челябинская область, Чебаркульский район, поселок Пустозерово	t	small
129825	10467	479	Челябинская область, Чебаркульский район, поселок Попово	f	medium
129829	10473	484	Россия	f	small
129837	10481	492	Челябинская область, Чебаркульский район, поселок Нижние Караси	t	small
129835	10479	490	Челябинская область, Чебаркульский район, поселок Непряхино	f	medium
129823	10464	476	Челябинская область, Чебаркульский район, поселок Мирный	t	small
129852	10497	508	Челябинская область, Чебаркульский район, поселок Мельниково	t	small
129843	10487	498	Челябинская область, Чебаркульский район, поселок Меведево	t	small
129847	10492	503	Челябинская область, Чебаркульский район, поселок Маскайка	t	small
129849	10494	505	Челябинская область, Чебаркульский район, поселок Малково, Куйбышева, 40, Здание кафе	t	medium
78939	10471	482	Челябинская область, Чебаркульский район, поселок Кундравы	f	large
129832	10476	487	Челябинская область, Чебаркульский район, поселок Крыжановка	f	small
129844	10488	499	Челябинская область, Чебаркульский район, поселок Коротаново	f	small
129826	10468	480	Челябинская область, Чебаркульский район, поселок Колотовка	t	small
130467	11623	1839	Алтайский край, Ключевский район, поселок Ключи	t	small
129824	10465	477	Челябинская область, Чебаркульский район, поселок Ключи	t	small
129831	10475	486	Челябинская область, Чебаркульский район, поселок Ключевка 2-я	f	small
129851	10496	507	Челябинская область, Чебаркульский район, поселок Камбулат	t	small
129827	10470	481	Челябинская область, Чебаркульский район, поселок Звягино	f	medium
129854	10500	511	Челябинская область, Чебаркульский район, поселок Зауралово	t	small
129858	10504	515	Челябинская область, Чебаркульский район, поселок Запивалово	t	small
129839	10483	494	Челябинская область, Чебаркульский район, поселок Десятилетие	t	small
129836	10480	491	Челябинская область, Чебаркульский район, поселок Верхние Караси	t	small
78938	10466	478	Челябинская область, Чебаркульский район, поселок Варламово	f	large
129828	10472	483	Челябинская область, Чебаркульский район, поселок Бутырки	f	small
129841	10485	496	Челябинская область, Чебаркульский район, поселок Боровое	f	medium
129830	10474	485	Россия	f	small
129833	10477	488	Челябинская область, Чебаркульский район, поселок Болотово	f	small
78937	10462	474	Россия	f	large
129846	10491	502	Челябинская область, Чебаркульский район, поселок Барсуки	t	small
129857	10503	514	Челябинская область, Чебаркульский район, поселок Барановка	t	small
129855	10501	512	Челябинская область, Чебаркульский район, поселок Алтынташ	f	small
129812	10433	445	Челябинская область, Уйский район, поселок Яринка, Строителей, 4	f	small
129542	10431	444	Челябинская область, Уйский район, поселок Фоминский, Клубная , 15 , актовый зал сельского клуба	f	small
78915	10423	436	Челябинская область, Уйский район, поселок Уйское, Таращенко, 67	f	large
78914	10422	435	Челябинская область, Уйский район, поселок Уйское, Пионерская, 41	f	large
78917	10425	438	Челябинская область, Уйский район, поселок Уйское, Ленина, 86	f	large
78254	5730	1099	Тюменская область, Ялуторовск, Ворошилова, 61	f	large
78916	10424	437	Челябинская область, Уйский район, поселок Уйское, Ленина, 22	f	large
129779	10394	407	Челябинская область, Уйский район, поселок Токмасский, Ленина, 20	t	small
129804	10421	434	Челябинская область, Уйский район, поселок Соколовское, Партизанская, 28	f	small
129788	10404	418	Челябинская область, Уйский район, поселок Речной, Клубная, 6	t	small
79347	10981	1128	Челябинская область, Уйский район, поселок Петропавловка, Лесная, 1, Петропавловская средняя школа	f	large
129793	10410	423	Челябинская область, Уйский район, поселок Петропавловка, Ленина, 18	f	medium
129809	10430	443	Челябинская область, Уйский район, поселок Октябрьский, Лесная, 2	f	small
129803	10420	433	Челябинская область, Уйский район, поселок Никольское, Центральная, 150	t	small
129790	10406	420	Челябинская область, Уйский район, поселок Нижнеусцелемово, Ленина, 13	f	medium
129795	10412	425	Челябинская область, Уйский район, поселок Мирный, Мира, 18	f	medium
129794	10411	424	Челябинская область, Уйский район, поселок Мирный, Мира, 3	f	medium
129789	10405	419	Челябинская область, Уйский район, поселок Маслово, Ленина, 9	f	medium
129483	10392	405	Челябинская область, Уйский район, поселок Магадеево, Школьная, 1 , актовый.зал сельского клуба	t	small
129802	10419	432	Челябинская область, Уйский район, поселок Лесной, Механическая, 47	t	small
129801	10418	431	Челябинская область, Уйский район, поселок Лебедевка, Зеленая, 137	t	small
78913	10400	414	Челябинская область, Уйский район, поселок Ларино, Дворцовая, 12	f	large
129784	10399	412	Челябинская область, Уйский район, поселок Кумляк, Нагорная, 33	f	medium
129800	10417	430	Челябинская область, Уйский район, поселок Краснокаменка, Ключевая, 42	t	small
129785	10401	415	Челябинская область, Уйский район, поселок Кочнево, Центральная, 5А	f	small
129781	10396	409	Челябинская область, Уйский район, поселок Кидыш, Ленина, 7А	f	medium
129799	10416	429	Челябинская область, Уйский район, поселок Зерновой, Садиковая, 28	t	small
129798	10415	428	Челябинская область, Уйский район, поселок Заозерный, Верхняя, 62	t	small
129786	10402	416	Челябинская область, Уйский район, Заматохина, Верхняя, 15	t	small
129783	10398	411	Челябинская область, Уйский район, поселок Гусары, Советская	t	small
129808	10429	442	Челябинская область, Уйский район, поселок Горки, Нагорная, 12А	t	small
129807	10428	441	Челябинская область, Уйский район, поселок Глазуновка, Солнечная, 8	f	small
129787	10403	417	Челябинская область, Уйский район, поселок Выдрино, Школьная, 2	f	small
129797	10414	427	Челябинская область, Уйский район, поселок Восточный, Кировская, 7А	f	small
129806	10427	440	Челябинская область, Уйский район, поселок Воронино, Мира, 7	f	small
129792	10408	422	Челябинская область, Уйский район, поселок Вишневка, Молодежная, 8/2	t	small
129780	10395	408	Челябинская область, Уйский район, поселок Вандышевка, Ленина, 20	f	medium
129796	10413	426	Челябинская область, Уйский район, поселок Булатово, Кульмухаметова, 27	f	small
129805	10426	439	Челябинская область, Уйский район, поселок Брюхово, Ленина, 11	t	small
129782	10397	410	Челябинская область, Уйский район, поселок Бирюковский, Школьная, 2	t	small
129791	10407	421	Челябинская область, Уйский район, поселок Березовка, Школьная, 28	f	small
129778	10393	406	Челябинская область, Уйский район, поселок Белово, Космонавтов, 25	f	medium
129775	10391	404	Челябинская область, Уйский район, поселок Аминево, Молодежная, 11А	f	medium
129456	11932	2197	Челябинская область, Увельский район, хутор Хуторка, Лесная, 1А	f	medium
79921	11920	2185	Челябинская область, Увельский район, поселок Хомутинино, Луначарского, 57	f	large
130577	11919	2184	Челябинская область, Увельский район, поселок Формачево, Станционная, 16, ж.д. станция	t	small
130566	11854	2173	Челябинская область, Увельский район, поселок Увельский, Щербакова, 8	f	medium
79918	11905	2171	Челябинская область, Увельский район, поселок Увельский, У. Громовой, 10	f	large
79917	11904	2170	Челябинская область, Увельский район, поселок Увельский, Советская, 7	f	large
79916	11903	2169	Челябинская область, Увельский район, поселок Увельский, Советская, 24	f	large
79914	11901	2167	Челябинская область, Увельский район, поселок Увельский, Советская, 38	f	large
130565	11906	2172	Челябинская область, Увельский район, поселок Увельский, Сафонова, 2Б	f	medium
79915	11902	2168	Челябинская область, Увельский район, поселок Увельский, Кирова, 12	f	large
129452	11918	2183	Челябинская область, Увельский район, поселок Синий Бор, Центральная, 4	f	medium
79922	11923	2188	Челябинская область, Увельский район, поселок Рождественка, Свободы, 58А	f	large
130578	11921	2186	Челябинская область, Увельский район, поселок Половинка, пер. Колхозный, 1	f	medium
130570	11912	2178	Челябинская область, Увельский район, поселок Подгорный, Гагарина, 3	t	small
130584	11929	2194	Челябинская область, Увельский район, поселок Петровское, Школьная, 30	f	medium
130613	11977	2246	Челябинская область, Увельский район, поселок Песчаное, Центральная, 25Б	f	medium
78907	10346	352	Челябинская область, Увельский район, поселок Песчаное, Советская, 17	f	large
130574	11916	2182	Челябинская область, Увельский район, поселок Нагорный, Школьная, 5	f	medium
130582	11926	2191	Челябинская область, Увельский район, поселок Мордвиновка, Школьная , 18А	f	small
130583	11928	2193	Челябинская область, Увельский район, поселок Михири, Мира, 34	t	small
130614	11978	2247	Челябинская область, Увельский район, поселок Мирный, Первостроителей, 4	f	small
130586	11931	2196	Челябинская область, Увельский район, поселок Малое Шумаково, Центральная, 15	f	small
79923	11927	2192	Челябинская область, Увельский район, поселок Красносельское, Островского, 2	f	large
130567	11908	2174	Челябинская область, Увельский район, поселок Копанцево, Набережная, 16 А	t	small
130580	11924	2189	Челябинская область, Увельский район, поселок Ключи, Рабочая, 21	t	small
130573	11915	2181	Челябинская область, Увельский район, поселок Кичигино, Мира, 60	f	medium
79920	11914	2180	Челябинская область, Увельский район, поселок Кичигино, Комсомольская, 29	f	large
130569	11910	2176	Челябинская область, Увельский район, поселок Катаево, Увельская, 24	t	small
79919	11911	2177	Челябинская область, Увельский район, поселок Каменский, Советская, 26	f	large
130581	11925	2190	Челябинская область, Увельский район, поселок Дуванкуль, Молодежная, 7Б	f	small
130579	11922	2187	Челябинская область, Увельский район, поселок Водопойка, Западная, 31	f	medium
130585	11930	2195	Челябинская область, Увельский район, поселок Большое Шумаково, Новая, 26	t	small
129451	11913	2179	Челябинская область, Увельский район, поселок Березовка, Школьная, 2 А	f	medium
78911	10365	377	Челябинская область, Троицкий район, поселок Ясные Поляны, Ленина, 54	f	large
129736	8939	361	Челябинская область, Троицкий район, поселок Шантарино, Школьная, 1А	f	small
129751	10368	380	Челябинская область, Троицкий район, поселок Чкалова, Центральная, 19	t	small
129773	10389	402	Челябинская область, Троицкий район, поселок Черноречье, Ленина, 1	f	small
129761	10378	390	Челябинская область, Троицкий район, поселок Целинный, Садовая, 19	f	medium
129753	10370	382	Челябинская область, Троицкий район, поселок Херсонский, Центральная, 502	t	small
129469	10351	357	Челябинская область, Троицкий район, поселок Травянка, Луговая, 41	f	small
130452	11591	1806	Челябинская область, Троицкий район, поселок Тогузак, Спутника, 19	f	small
129758	10375	387	Челябинская область, Троицкий район, поселок Тогузак, Левобережная, 15а	t	small
129730	10350	356	Челябинская область, Троицкий район, поселок Суналы, Мира, 11	t	small
129774	10390	403	Челябинская область, Троицкий район, поселок Стрелецк, Центральная, 8	t	small
129713	10302	308	Челябинская область, Троицкий район, поселок Степное, Центральная, 21	f	small
130199	11324	1528	Челябинская область, Троицкий район, поселок Степное, Труда, 1	f	medium
129714	10303	309	Челябинская область, Троицкий район, поселок Степное, Комсомольская, 28	f	medium
129712	10301	307	Челябинская область, Троицкий район, поселок Степнинское, Центральная, 18а	t	small
129734	10353	359	Челябинская область, Троицкий район, поселок Сливной, Центральная, 17	t	small
129768	10385	397	Челябинская область, Троицкий район, поселок Скалистый, Школьная, 11	f	medium
129723	10343	349	Челябинская область, Троицкий район, поселок Сбитнево, Центральная, 18	t	small
129763	10380	392	Челябинская область, Троицкий район, поселок Репино, Первомайская, 2	t	small
129760	10377	389	Челябинская область, Троицкий район, поселок Полесье, Заречная, 3	t	small
129766	10383	395	Челябинская область, Троицкий район, поселок Подгорное, Набережная, 3	f	small
129746	10361	373	Челябинская область, Троицкий район, поселок Плодовый, Набережная, 2а	f	small
129754	10371	383	Челябинская область, Троицкий район, поселок Осиповка, Центральная, 12	t	small
129750	10366	378	Челябинская область, Троицкий район, поселок Новый Мир, Южная, 19	f	medium
130449	11588	1803	Челябинская область, Троицкий район, поселок Новый Мир, 30 Лет победы, 11	f	small
78912	10367	379	Челябинская область, Троицкий район, поселок Нижняя Санарка, Советская, 17	f	large
129735	8570	360	Челябинская область, Троицкий район, поселок Морозкино, Школьная, 47	f	small
129729	10349	355	Челябинская область, Троицкий район, поселок Метличье, Северная, 1	t	small
129769	10386	398	Челябинская область, Троицкий район, поселок Логовой, Школьная, 1А	t	small
130487	11654	1872	Челябинская область, Троицкий район, поселок Лебедевка, Комсомольская, 6	f	small
129757	10374	386	Челябинская область, Троицкий район, поселок Лагерный, Садовая, 1	t	small
129745	10360	372	Челябинская область, Троицкий район, поселок Кумысное, Кольцевая, 6А	t	small
129759	10376	388	Челябинская область, Троицкий район, поселок Краснооктябрьский, Центральная, 17	t	small
129764	10381	393	Челябинская область, Троицкий район, поселок Кособродка, Красногвардейская, 23	t	small
129743	10358	370	Челябинская область, Троицкий район, поселок Клястицкое, Школьная, 14	f	medium
78908	9183	364	Челябинская область, Троицкий район, поселок Ключевка, Школьная, 11	f	large
129417	10356	368	Челябинская область, Троицкий район, поселок Кварцитный, Собко, 22, 1этаж	t	medium
129747	10362	374	Челябинская область, Троицкий район, поселок Карсы, Кооперативный, 9А	f	medium
129468	10347	353	Челябинская область, Троицкий район, поселок Каракулька, Молодежная, 1А	f	small
129748	10363	375	Челябинская область, Троицкий район, поселок Карабаново, Центральная, 26а	t	small
129765	10382	394	Челябинская область, Троицкий район, поселок Каменная Санарка, Школьная, 9А	t	small
129738	9612	365	Челябинская область, Троицкий район, поселок Каменная Речка, Школьная, 19	f	medium
129767	10384	396	Челябинская область, Троицкий район, поселок Каменка, Мира, 3	t	small
129749	10364	376	Челябинская область, Троицкий район, поселок Кадымцево, Рабочая, 12	t	small
129771	9626	400	Челябинская область, Троицкий район, поселок Искра, Мира, 15А	t	small
129725	10345	351	Челябинская область, Троицкий район, поселок Епанишниково, Набережная, 3	t	small
129728	10348	354	Челябинская область, Троицкий район, поселок Дробышево, Школьная, 1	f	small
129762	10379	391	Челябинская область, Троицкий район, поселок Дачный, Трудовая, 3а	t	small
129724	10344	350	Челябинская область, Троицкий район, поселок Бурханкуль, Центральная, 40	t	small
78910	10355	367	Челябинская область, Троицкий район, поселок Бобровка, Культуры, 1А	f	large
78909	10354	366	Челябинская область, Троицкий район, поселок Бобровка, Водопроводная, 2	f	large
129752	10369	381	Челябинская область, Троицкий район, поселок Берлин, Школьная, 27	f	small
129470	10357	369	Челябинская область, Троицкий район, поселок Березники, Новая, 51, 1 этаж	t	small
129770	10387	399	Челябинская область, Троицкий район, поселок Белоключевка, Школьная, 1а	t	small
129755	10372	384	Челябинская область, Троицкий район, поселок Белокаменка, Лассаля, 34	t	small
129722	10342	348	Челябинская область, Троицкий район, поселок Белозеры, Просвещения, 5	f	medium
129497	10823	1794	Челябинская область, Троицкий район, поселок Безводный, Центральная, 19	t	small
79809	11772	2013	Челябинская область, Сосновский район, поселок Южно-Челябинский Прииск	f	large
79808	11772	2012	Челябинская область, Сосновский район, поселок Южно-Челябинский Прииск	f	large
79877	11824	2086	Челябинская область, Сосновский район, поселок Южно-Челябинский Прииск, Федорова, 12	f	large
130555	11884	2151	Челябинская область, Сосновский район, поселок Чишма, Центральная, 32	t	small
130562	11898	2164	Челябинская область, Сосновский район, поселок Чипышево, Советская, 9 А	t	medium
130550	11877	2143	Челябинская область, Сосновский район, поселок Ужевка, Трактовая, 1Г	t	small
130534	11852	2119	Челябинская область, Сосновский район, поселок Туктубаево, Плановая, 7А	t	medium
130536	11855	2121	Челябинская область, Сосновский район, поселок Трубный, Центральная, 14	f	medium
85686	9308	155	Ханты-Мансийский автономный округ, Югорск, Садовая, 1Б	f	large
79911	11891	2158	Челябинская область, Сосновский район, поселок Томинский, Мира, 10	f	large
79908	11886	2153	Челябинская область, Сосновский район, поселок Теченский, Центральная, 20 А	f	large
130553	11882	2149	Челябинская область, Сосновский район, поселок Султаева, Школьная, 6	t	small
79910	11890	2157	Челябинская область, Сосновский район, поселок Солнечный, Мира, 13	t	large
130554	11883	2150	Челябинская область, Сосновский район, поселок Смольное, Школьная, 5	t	small
130557	11888	2155	Челябинская область, Сосновский район, поселок Смолино, Школьная, 1	t	medium
130544	11870	2136	Челябинская область, Сосновский район, поселок Северный, Клубная, 6	t	small
79909	11887	2154	Челябинская область, Сосновский район, поселок Саргазы, Мичурина, 10	f	large
79907	11881	2148	Челябинская область, Сосновский район, поселок Саккулово, Мира, 7	f	large
129772	10388	401	Челябинская область, Сосновский район, поселок Садовый, Центральная, 11а	t	small
130542	11868	2134	Челябинская область, Сосновский район, поселок Садовый, Трактовая, 14	t	medium
79906	11878	2145	Челябинская область, Сосновский район, поселок Рощино, Ленина, 9	f	large
79905	11878	2144	Челябинская область, Сосновский район, поселок Рощино, Ленина, 9	f	large
130560	11893	2160	Челябинская область, Сосновский район, поселок Полетаево-II, Советская, 54	t	small
79913	11896	2162	Челябинская область, Сосновский район, поселок Полетаево, Почтовая, 32Б	t	large
79912	11894	2161	Челябинская область, Сосновский район, поселок Полетаево, Полетаевская, 48	t	large
130561	11897	2163	Челябинская область, Сосновский район, поселок Полетаево, Новостройка, 1	t	medium
79898	11857	2123	Челябинская область, Сосновский район, поселок Полевой, Центральная, 26	t	large
130532	11850	2117	Челябинская область, Сосновский район, поселок Новый Кременкуль, Центральная, 1	t	small
129559	11876	2142	Челябинская область, Сосновский район, поселок Мирный, Школьная, 6	f	large
130549	11875	2141	Челябинская область, Сосновский район, деревня Медиак, Медиакская , 26	t	small
129588	9772	28	Челябинская область, Сосновский район, поселок Медиак, Центральная, 1	t	small
130546	11872	2138	Челябинская область, Сосновский район, поселок Мамаева, Лесная, 1 А	t	small
130545	11871	2137	Челябинская область, Сосновский район, поселок Малиновка, Школьная, 6	t	small
79904	11867	2133	Челябинская область, Сосновский район, поселок Кременкуль, Ленина, 3 А	f	large
130539	11862	2128	Челябинская область, Сосновский район, поселок Ключёвка, 1 Мая, контора ООО Заря	t	small
130540	11865	2131	Челябинская область, Сосновский район, поселок Ключи, Солнечная, 6	t	small
130548	11874	2140	Челябинская область, Сосновский район, поселок Кисегачинский, Больничная, 21	t	small
130547	11873	2139	Челябинская область, Сосновский район, поселок Касарги, Школьная, 14	t	medium
130535	11853	2120	Челябинская область, Сосновский район, поселок Кайгородово, Школьная, 63	t	small
130551	11879	2146	Челябинская область, Сосновский район, поселок Казанцево, Школьная, 5	t	medium
130541	11866	2132	Челябинская область, Сосновский район, поселок Заварухино, Центральная, 1	t	small
79902	11863	2129	Челябинская область, Сосновский район, поселок Есаульский, Трактористов, 6	f	large
79900	11859	2125	Челябинская область, Сосновский район, поселок Долгодеревенское, Строительная, 6	f	large
79901	11860	2126	Челябинская область, Сосновский район, поселок Долгодеревенское, Свердловская, 15	f	large
79899	11858	2124	Челябинская область, Сосновский район, поселок Долгодеревенское, Набережная, 1	f	large
130530	11848	2115	Челябинская область, Сосновский район, поселок Высокий, Молодежная, 152	t	small
130537	11856	2122	Челябинская область, Сосновский район, поселок Вознесенка, Школьная , 6	t	medium
130563	11899	2165	Челябинская область, Сосновский район, поселок Витаминный, Лесная, 12	t	small
130564	11900	2166	Челябинская область, Сосновский район, поселок Верхние Малюки, Школьная, 1	t	small
130531	11849	2116	Челябинская область, Сосновский район, поселок Бутаки, Ленина, 9	t	medium
130556	11885	2152	Челябинская область, Сосновский район, поселок Большое Таскино, Победы, 56	t	small
130538	11861	2127	Челябинская область, Сосновский район, поселок Большое Баландино, Озерная, 20А	t	medium
129711	10300	306	Челябинская область, Пластовский район, поселок Воронино, Береговой, 1	t	small
130543	11869	2135	Челябинская область, Сосновский район, поселок Большие Харлуши, Набережная, 19	t	small
130559	11892	2159	Челябинская область, Сосновский район, поселок Архангельское, Центральная, 66	f	medium
130612	11976	2245	Челябинская область, Сосновский район, поселок Альмеева, 1 Мая, 20 А	t	small
130533	11851	2118	Челябинская область, Сосновский район, поселок Алишева, Лесная, 13 А	t	small
130125	11057	1210	Челябинская область, Саткинский район, поселок Чёрная Речка, Нагорная, 142	t	small
130131	11067	1221	Челябинская область, Саткинский район, поселок Чулковка, Центральная, 19	f	medium
79383	11062	1216	Челябинская область, Саткинский район, поселок Сулея, Луговая, 36	f	large
130129	11063	1217	Челябинская область, Саткинский район, поселок Сулея, Кооперативная, 2а	f	medium
79393	11081	1237	Челябинская область, Саткинский район, поселок Рудничное, Нахимова, 1	t	large
130132	11068	1222	Челябинская область, Саткинский район, поселок Романовка, Школьная, 7	t	small
79384	11064	1218	Челябинская область, Саткинский район, поселок Межевой, Ширпышева, 2А	f	large
79386	11066	1220	Челябинская область, Саткинский район, поселок Межевой, Советская, 14	f	large
79385	11065	1219	Челябинская область, Саткинский район, поселок Межевой, Карла Маркса, 7а	f	large
129472	11055	1208	Челябинская область, Саткинский район, поселок Малый Бердяуш, Школьная, 27А	t	small
79346	10975	1122	Челябинская область, Саткинский район, поселок Магнитский, Рабочая, 9, Магнитская 8летняя школа	f	large
130067	10977	1124	Челябинская область, Саткинский район, поселок Магнитский, Карла Маркса, 20, Коррекционная школаинтернат	f	medium
130068	10978	1125	Челябинская область, Саткинский район, поселок Магнитский, Гагарина, 16, Магнитская средняя школа	f	medium
130127	11061	1215	Челябинская область, Саткинский район, поселок Жукатау, Наливная, 38а, ж.д. станция	t	small
129501	11083	1239	Челябинская область, Саткинский район, поселок Ельничный, Школьная, 1	t	small
130135	11071	1226	Челябинская область, Саткинский район, поселок Верхний Айск, Центральная, 58а	t	small
129499	11056	1209	Челябинская область, Саткинский район, поселок Большая Запань, Речная, 11	t	small
129541	11058	1212	Челябинская область, Саткинский район, поселок Бердяуш, Советская, 1А	t	large
130126	11059	1213	Челябинская область, Саткинский район, поселок Бердяуш, Красноармейская, 2А	t	medium
129538	11060	1214	Челябинская область, Саткинский район, поселок Бердяуш, Пушкина, 1А	t	large
129445	11080	1236	Челябинская область, Саткинский район, Бакал, Чкалова, 17	t	medium
79388	11074	1229	Челябинская область, Саткинский район, Бакал, Титова, 2	f	large
130137	11078	1234	Челябинская область, Саткинский район, Бакал, Леонова, 12	f	medium
130138	11079	1235	Челябинская область, Саткинский район, Бакал, Ленина, 69	f	medium
79391	11077	1232	Челябинская область, Саткинский район, Бакал, Ленина, 9	f	large
79392	11036	1233	Челябинская область, Саткинский район, Бакал, Ленина, 29	f	large
129500	11082	1238	Челябинская область, Саткинский район, Бакал, Кутузовых, 40	t	small
79387	11073	1228	Челябинская область, Саткинский район, Бакал, Калинина, 3	f	large
79390	11076	1231	Челябинская область, Саткинский район, Бакал, Андрея Костылева, 7	f	large
79389	11075	1230	Челябинская область, Саткинский район, Бакал, 50 лет ВЛКСМ, 2А	f	large
130136	11072	1227	Челябинская область, Саткинский район, деревня Алексеевка, Центральная, 27а	t	small
130134	11070	1224	Челябинская область, Саткинский район, поселок Айлино, Степана Разина, 2а1	f	medium
130133	11069	1223	Челябинская область, Саткинский район, поселок Айлино, Пугачева, 32	f	medium
79368	11037	1187	Челябинская область, Саткинский муниципальный район, Сатка, Сергея Маринина, 4	f	large
129703	10293	299	Челябинская область, Пластовский район, поселок Старый Кумляк, Центральная, 21	t	small
129710	10299	305	Челябинская область, Пластовский район, поселок Светлый, Школьный, 16	f	small
129467	10298	304	Челябинская область, Пластовский район, поселок Радиомайка, Мира, 50, 1 этаж	t	small
129466	10285	291	Челябинская область, Пластовский район, поселок Поляновка, Библиотечная, 1А	t	small
129705	10295	301	Челябинская область, Пластовский район, поселок Михайловка, Набережная, 51	t	small
129702	10292	298	Челябинская область, Пластовский район, поселок Кукушка, Холмистая, 12	t	small
129443	10286	292	Челябинская область, Пластовский район, село Верхняя Кабанка, Школьная, 9	f	medium
129664	10249	253	Челябинская область, Октябрьский район, поселок Шишминка, Центральная, 46, Сельская библиотека	t	small
129663	10248	252	Челябинская область, Октябрьский район, поселок Шипкино, Победы, 39, Сельский ДК	f	small
129690	10276	280	Челябинская область, Октябрьский район, поселок Чудиново, Ленина, 36, Сельский ДК	f	small
129649	10236	240	Челябинская область, Октябрьский район, поселок Чернякино, Центральная, 7, Сельская библиотека	t	small
129677	10266	270	Челябинская область, Октябрьский район, поселок Харлуши, Начальная школа	f	small
129687	10273	277	Челябинская область, Октябрьский район, поселок Уйско-Чебаркульская, Школьная, 10, Администрация УйскоЧебаркульского СП	f	medium
129464	10268	272	Челябинская область, Октябрьский район, поселок Теренкуль, Сельский ДК	f	small
129661	10246	250	Челябинская область, Октябрьский район, поселок Сысоево, Труда, 46, Ветеринарный участок Маякского СП	t	small
129672	10261	265	Челябинская область, Октябрьский район, поселок Степановка, Центральная, 4, Жилой дом	t	small
129465	10269	273	Челябинская область, Октябрьский район, поселок Спорное, 1 этаж фойе ФАП	f	small
129463	10267	271	Челябинская область, Октябрьский район, поселок Сосновенькое, Молодежная, 3, ФАП	t	small
129671	10260	264	Челябинская область, Октябрьский район, поселок Семеновка, Центральная, 1, Жилой дом	t	small
129684	10270	274	Челябинская область, Октябрьский район, поселок Свободный, Лесная, 5Б	f	small
78868	10265	269	Челябинская область, Октябрьский район, поселок Подовинное, Гагарина, 10, Сельский ДК	f	large
129644	10232	236	Челябинская область, Октябрьский район, поселок Окунево, Восточная, 1, Начальная школа	t	small
78863	10255	259	Челябинская область, Октябрьский район, поселок Октябрьское, Ленина, 48, Районный ДК	f	large
78865	10257	261	Челябинская область, Октябрьский район, поселок Октябрьское, Комсомольская, 54, МУП Октябрьский жилкомцентр	f	large
78866	10258	262	Челябинская область, Октябрьский район, поселок Октябрьское, Качалина, 34	f	large
78867	10259	263	Челябинская область, Октябрьский район, поселок Октябрьское, Восточная, 88	f	large
78864	10256	260	Челябинская область, Октябрьский район, поселок Октябрьское, 1 Мая, 18	f	large
129485	10264	268	Челябинская область, Октябрьский район, поселок Новомосковское, Октябрьская, 81, Сельский ДК	f	small
129685	10271	275	Челябинская область, Октябрьский район, поселок Нововарламово, Мира, 46, Селький ДК	f	small
129665	10250	254	Челябинская область, Октябрьский район, поселок Мяконьки, Советская, 15, Администрация Мяконькского СП	f	small
129658	10243	247	Челябинская область, Октябрьский район, поселок Могильное, Могильская, 10, Сельский ДК	t	small
129660	10245	249	Челябинская область, Октябрьский район, поселок Маячное, Центральная, 12	f	small
129461	10242	246	Челябинская область, Октябрьский район, поселок Лысково, Центральная, 9, Администрация Лысковского СП	f	small
129673	10262	266	Челябинская область, Октябрьский район, поселок Лебедки, Школьная, 2, Средняя школа	f	small
129645	10233	237	Челябинская область, Октябрьский район, поселок Лафетное, Рабочая, 1А, Начальная школа	t	small
129659	10244	248	Челябинская область, Октябрьский район, поселок Кузнецово, Кузнецовская, 9, Сельский ДК	t	small
129650	10237	241	Челябинская область, Октябрьский район, поселок Крутоярский, Школьная, 9, Средняя школа	f	medium
129450	10231	235	Челябинская область, Октябрьский район, поселок Кочердык, Школьная, 1, ДК Колос	f	medium
129674	10263	267	Челябинская область, Октябрьский район, поселок Киевка, Киевская, 23	t	small
129653	10240	244	Челябинская область, Октябрьский район, поселок Каракульское, Школьная, 17, Администрация Каракульского СП	f	medium
129689	10275	279	Челябинская область, Октябрьский район, поселок Камышное, Пионерская, 2, Начальная школа	t	small
129639	10228	232	Челябинская область, Октябрьский район, поселок Зуевка, Восточная, 2	t	small
129641	10230	234	Челябинская область, Октябрьский район, поселок Замериново, Северная, 23, Сельский ДК	t	small
129666	10251	255	Челябинская область, Октябрьский район, поселок Журавлиное, Советская, 25, Начальная школа	f	small
129662	10247	251	Челябинская область, Октябрьский район, поселок Деньгино, Свободы, 16	t	small
129459	10235	239	Челябинская область, Октябрьский район, поселок Горелое, Центральная, 15, Сельская библиотека	f	small
129670	10254	258	Челябинская область, Октябрьский район, поселок Ваганово, 1 мая, 63, средняя школа	f	small
129652	10239	243	Челябинская область, Октябрьский район, поселок Быково, Школьная, 4	t	small
129636	10225	230	Челябинская область, Октябрьский район, поселок Буланово, Центральная, 18, Сельский ДК	t	small
129458	10227	231	Челябинская область, Октябрьский район, поселок Боровое, Калинина, 11, Администрация Борового СП	f	small
129462	10252	256	Челябинская область, Октябрьский район, поселок Большеникольское, Центральная, 10, Сельский ДК	f	small
129688	10274	278	Челябинская область, Октябрьский район, поселок Березовский, Советская, 40, Сельский ДК	f	small
129635	10224	229	Челябинская область, Октябрьский район, поселок Барсучье, Молодежная, 17, Администрация Барсучанского СП	f	small
129646	10234	238	Челябинская область, Октябрьский район, поселок Банниково, Трудовая, 6, начальная школа, кв., 2	t	small
129640	10229	233	Челябинская область, Октябрьский район, поселок Бакшан, Южная, 33А, Сельский ДК	t	small
129460	10241	245	Челябинская область, Октябрьский район, поселок Александровка, Центральная, 20, Контора отделения №2 ООО КаракульАгро	t	small
129669	10253	257	Челябинская область, Октябрьский район, поселок Александровка, Береговая, 31, Досуговый центр Никольского СП	t	small
79348	10987	1133	Челябинская область, Озерский район, село Медведевка, Пономаренко, 2, Медведевская сельская администрация	f	large
130096	11019	1169	Челябинская область, Нязепетровский район, поселок Шемаха, Октябрьская, 21	f	medium
130103	11026	1176	Челябинская область, Нязепетровский район, поселок Ункурда, Просвещенская, 62	f	medium
130101	11024	1174	Челябинская область, Нязепетровский район, поселок Ташкинова, 27 съезда КПСС, 18	t	small
130097	11020	1170	Челябинская область, Нязепетровский район, поселок Сказ, Школьная, 13	t	small
129404	11031	1181	Челябинская область, Нязепетровский район, поселок Ситцева, Ленина, 64	f	medium
130106	11029	1179	Челябинская область, Нязепетровский район, поселок Нестерово, Советская, 32	f	small
130100	11023	1173	Челябинская область, Нязепетровский район, поселок Межевая, Мира, 33	t	small
130107	11030	1180	Челябинская область, Нязепетровский район, поселок Котово, Никитина, 2	f	small
130102	11025	1175	Челябинская область, Нязепетровский район, поселок Кедровый, Школьная, 1А	t	small
130104	11027	1177	Челябинская область, Нязепетровский район, поселок Калиновка, Гагарина, 7	t	small
130111	11033	1183	Челябинская область, Нязепетровский район, поселок Гривенка, Школьная, 26	f	small
130105	11028	1178	Челябинская область, Нязепетровский район, поселок Беляево, Молодежная, 29	t	small
130098	11021	1171	Челябинская область, Нязепетровский район, поселок Арасланово, Школьная, 17	t	small
130099	11022	1172	Челябинская область, Нязепетровский район, поселок Арасланово, Гагарина, 5А	t	medium
130110	11032	1182	Челябинская область, Нязепетровский район, поселок Аптрякова, Победы, 43А	f	small
129525	11576	1785	Челябинская область, Нагайбакский район, поселок Южный, Пионерская, 1	f	large
129503	11548	1757	Челябинская область, Нагайбакский район, поселок Чернореченский, Молодежная, 3	t	small
129524	11571	1780	Челябинская область, Нагайбакский район, поселок Фершампенуаз, Советская, 40	f	large
129523	11570	1779	Челябинская область, Нагайбакский район, поселок Фершампенуаз, Мира, 19	f	large
129474	11543	1753	Челябинская область, Нагайбакский район, поселок Требиятский, Труда, 25	t	small
130406	11556	1765	Челябинская область, Нагайбакский район, поселок Совхозный, переулок Школьный, 2/1	t	small
130426	11575	1784	Челябинская область, Нагайбакский район, поселок Слюда, Новая, 10	t	small
129435	11550	1759	Челябинская область, Нагайбакский район, поселок Северный, Мира, 9	f	medium
130421	11572	1781	Челябинская область, Нагайбакский район, поселок Рассвет, Молодежная, 1	t	small
129508	11562	1771	Челябинская область, Нагайбакский район, поселок Придорожный, Центральная, 22	t	small
129504	11549	1758	Челябинская область, Нагайбакский район, поселок Подгорный, Центральная , 26	t	small
130407	11557	1766	Челябинская область, Нагайбакский район, поселок Петровский, Центральная, 25	t	small
130420	11569	1778	Челябинская область, Нагайбакский район, поселок Переселенческий, Центральная, 27	t	small
79671	11563	1772	Челябинская область, Нагайбакский район, поселок Париж, Пионерская, 43а	f	large
129522	11560	1769	Челябинская область, Нагайбакский район, поселок Остроленский, Васильева, 49	f	large
130417	11566	1775	Челябинская область, Нагайбакский район, поселок Новочерниговский, Молодежная, 20а	t	small
129436	11555	1764	Челябинская область, Нагайбакский район, поселок Нагайбакский, Центральная, 15	f	medium
130402	11553	1762	Челябинская область, Нагайбакский район, поселок Набережный, Целинная, 20	t	small
130403	11554	1763	Челябинская область, Нагайбакский район, поселок Лесные Поляны, Центральная, 12	t	small
130414	11564	1773	Челябинская область, Нагайбакский район, поселок Лебединое, Новая, 1	t	small
129507	11561	1770	Челябинская область, Нагайбакский район, поселок Куропатнинский, Мира, 7	t	small
129406	11574	1783	Челябинская область, Нагайбакский район, поселок Курганный, Советская, 27	t	small
130399	11551	1760	Челябинская область, Нагайбакский район, поселок Куликовский, Советская, 21	t	small
129509	11565	1774	Челябинская область, Нагайбакский район, поселок Кужебаевский, Новая, 28	t	small
130419	11568	1777	Челябинская область, Нагайбакский район, поселок Крупское, Степная, 31	t	small
129434	11547	1756	Челябинская область, Нагайбакский район, поселок Кассельский, Труда, 2	f	medium
129473	11541	1751	Челябинская область, Нагайбакский район, поселок Калининский, переулок Южный, 1	t	small
129405	11573	1782	Челябинская область, Нагайбакский район, поселок Знаменка, Школьная, 19	t	small
129475	11544	1754	Челябинская область, Нагайбакский район, поселок Заречный, Комсомольская, 11	t	small
130418	11567	1776	Челябинская область, Нагайбакский район, поселок Гумбейский, Придорожная, 1	f	medium
130408	11558	1767	Челябинская область, Нагайбакский район, поселок Березовая Роща, Березовая, 4	t	small
130385	11542	1752	Челябинская область, Нагайбакский район, поселок Балканы, Советская, 6	f	small
129505	11552	1761	Челябинская область, Нагайбакский район, поселок Астафьевский, Советская, 10	t	small
129433	11540	1750	Челябинская область, Нагайбакский район, поселок Арсинский, Мира, 47	f	medium
130409	11559	1768	Челябинская область, Нагайбакский район, поселок Арасламбаевский, Школьная, 8	t	small
130390	11546	1755	Челябинская область, Нагайбакский район, поселок Александро-Невский, Советская, 30	t	small
130076	10986	1132	Челябинская область, Кусинский район, поселок Октябрьский, Школьная, 2	f	small
130066	10976	1123	Челябинская область, Кусинский район, поселок Магнитка, Карла Маркса, 18, Профессиональное училище № 36	f	medium
130069	10979	1126	Челябинская область, Кусинский район, поселок Ковали, Чернышевского, 95, Контора лесхоза	f	small
130071	10982	1129	Челябинская область, Кусинский район, поселок Каскиново, Школьная, 14, Каскиновская школа	f	small
130072	10984	1130	Челябинская область, Кусинский район, поселок Злоказово, Трактовая, 22, Злоказовская сельская администроация	f	medium
130073	10985	1131	Челябинская область, Кусинский район, поселок Вознесенка, Школьная, 4, школа	f	small
130070	10980	1127	Челябинская область, Кусинский район, поселок Александровка, Школьная, 6, Александровская школа	f	small
129423	10946	1093	Челябинская область, Кунашакский район, поселок Юлдашева, Школьная, 1	t	small
130048	10949	1096	Челябинская область, Кунашакский район, поселок Элеваторный, Вокзальная, 3	t	small
130052	10953	1100	Челябинская область, Кунашакский район, поселок Чекурова, Центральная, 5	t	small
79338	10955	1102	Челябинская область, Кунашакский район, поселок Халитово, Целинная, 24а	f	large
129424	10947	1094	Челябинская область, Кунашакский район, поселок Усть-Багаряк, Ленина, 222, 1 этаж	f	small
130047	10948	1095	Челябинская область, Кунашакский район, поселок Усть-Багаряк, Базарная, 1	f	medium
130024	10610	1073	Челябинская область, Кунашакский район, поселок Трудовой, Мира, 25	f	small
130054	10956	1103	Челябинская область, Кунашакский район, поселок Тахталым, Станционная, 6	t	small
130039	10943	1089	Челябинская область, Кунашакский район, поселок Татарская Караболка, Школьная, 5	t	small
130031	10934	1080	Челябинская область, Кунашакский район, поселок Сураково, Челябинская, 14а	t	small
130028	10931	1077	Челябинская область, Кунашакский район, поселок Султаново, Школьная, 3	f	small
129418	10928	1074	Челябинская область, Кунашакский район, поселок Сосновка, Озерная, б/н, 1 этаж	t	small
130049	10950	1097	Челябинская область, Кунашакский район, поселок Синарский, Станционная, 2а	t	small
130051	10952	1099	Челябинская область, Кунашакский район, деревня Серкино, Центральная, 1а	t	small
130037	10941	1087	Челябинская область, Кунашакский район, деревня Сарыкульмяк, Ленина, 57	t	small
130027	10929	1075	Челябинская область, Кунашакский район, поселок Разъезд N2, Железнодорожников,  красный уголок ЭЧ8	t	small
130030	10933	1079	Челябинская область, Кунашакский район, поселок Нугуманово, Школьная, 1	t	medium
130029	10932	1078	Челябинская область, Кунашакский район, поселок Новое Курманово, Ленина, 1	f	small
79335	10550	1072	Челябинская область, Кунашакский район, поселок Новобурино, Комсомольская, 1	f	large
79336	10930	1076	Челябинская область, Кунашакский район, поселок Муслюмово, Лесная, 2, ж.д. станция	f	large
79337	10935	1081	Челябинская область, Кунашакский район, поселок Муслюмово, Вокзальная, Дом культуры	f	large
129528	11107	1269	Челябинская область, Кунашакский район, поселок Метлино, Центральная, 61, Дом культуры, МУ ДК Синегорье	f	large
130022	10927	1070	Челябинская область, Кунашакский район, поселок Маяк, Центральная	t	small
130055	10957	1104	Челябинская область, Кунашакский район, поселок Мансурова, Дальняя, 31	t	small
130020	10925	1068	Челябинская область, Кунашакский район, поселок Лесной, клуб п.Лесной	f	small
79333	10923	1066	Челябинская область, Кунашакский район, поселок Кунашак, Пионерская, 52	f	large
79334	10924	1067	Челябинская область, Кунашакский район, поселок Кунашак, Ленина, 95	f	large
130057	10959	1106	Челябинская область, Кунашакский район, поселок Кунакбаева, Школьная, 11	t	small
130050	10951	1098	Челябинская область, Кунашакский район, поселок Кумкуль, Центральная, 1	t	small
130060	10962	1109	Челябинская область, Кунашакский район, поселок Кубагушева, Галлямова, 27а	t	small
130041	10944	1091	Челябинская область, Кунашакский район, поселок Карагайкуль, Молодежная, 30	t	small
130034	10938	1084	Челябинская область, Кунашакский район, поселок Каинкуль, Школьная, 12	t	small
130053	10954	1101	Челябинская область, Кунашакский район, поселок Иксанова, Центральная, 31	t	small
130038	10942	1088	Челябинская область, Кунашакский район, поселок Ибрагимова, Школьная, 1	t	small
130036	10940	1086	Челябинская область, Кунашакский район, поселок Голубинка, Береговая, 30	f	small
130058	10960	1107	Челябинская область, Кунашакский район, поселок Бурино, Школьная, 1	t	small
130035	10939	1085	Челябинская область, Кунашакский район, поселок Большой Куяш, Ленина, 155	f	medium
130042	10945	1092	Челябинская область, Кунашакский район, поселок Большая Тюлякова, Центральная, 8	t	medium
130056	10958	1105	Челябинская область, Кунашакский район, поселок Большая Казакбаева, Зеленая, 36	t	small
130059	10961	1108	Челябинская область, Кунашакский район, поселок Баязитова, Межозерная, 5а	t	small
130061	10963	1110	Челябинская область, Кунашакский район, поселок Баракова, Молодежная, 12	t	small
130023	10885	1071	Челябинская область, Кунашакский район, поселок Аширово	t	small
130033	10937	1083	Челябинская область, Кунашакский район, поселок Аминева, Школьная, 1а	f	medium
130019	10922	1065	Челябинская область, Красноармейский район, поселок Якупово, Центральная, 46	t	small
130009	10913	1056	Челябинская область, Красноармейский район, поселок Шуранкуль, Комсомольская, 23	t	small
130014	10918	1061	Челябинская область, Красноармейский район, поселок Шумово, Советская, 32А	f	medium
130002	10874	1048	Челябинская область, Красноармейский район, поселок Черкасово, Мира, 20	f	small
129996	10896	1038	Челябинская область, Красноармейский район, поселок Худяково, Набережная, 10А	t	small
130003	10906	1049	Челябинская область, Красноармейский район, поселок Харино, Молодежная, 27	t	small
129979	10872	1016	Челябинская область, Красноармейский район, поселок Ханжино, Учительская, 2	t	small
129980	10873	1017	Челябинская область, Красноармейский район, поселок Фроловка, Школьная, 10	t	small
129977	10869	1013	Челябинская область, Красноармейский район, поселок Феклино, Солнечная, 14	t	small
130501	11668	1886	Челябинская область, Красноармейский район, поселок Устьянцево, Солнечная, 1	t	small
130017	10920	1063	Челябинская область, Красноармейский район, поселок Устьянцево, Зеленая, 11	t	small
130012	10916	1059	Челябинская область, Красноармейский район, поселок Усольцево, Школьная, 4	t	small
129987	10882	1025	Челябинская область, Красноармейский район, поселок Тирикуль, Центральная, 22	t	small
130013	10917	1060	Челябинская область, Красноармейский район, поселок Теренкуль, Мира, 21	f	medium
129993	10892	1034	Челябинская область, Красноармейский район, поселок Таукаево, Салавата Юлаева, 9	t	small
129986	10881	1024	Челябинская область, Красноармейский район, поселок Тавранкуль, Школьная, 8	t	small
130005	10909	1052	Челябинская область, Красноармейский район, поселок Сычево, Мира, 61	t	small
130010	10914	1057	Челябинская область, Красноармейский район, поселок Сугояк, Казанцева, 109	f	medium
129997	10898	1040	Челябинская область, Красноармейский район, поселок Слава, Ленина, 32	f	small
129486	10919	1062	Челябинская область, Красноармейский район, поселок Сафоново, 40 лет Победы, 1	t	small
130006	10910	1053	Челябинская область, Красноармейский район, поселок Русская Теча, Советская, 32	f	medium
129981	10875	1018	Челябинская область, Красноармейский район, поселок Родник, Школьная, 4	f	small
130018	10921	1064	Челябинская область, Красноармейский район, поселок Пятково, Лесная, 13	t	small
129988	10883	1026	Челябинская область, Красноармейский район, поселок Попово, Центральная, 20	t	small
130001	10901	1043	Челябинская область, Красноармейский район, поселок Печенкино, Школьная, 13	t	small
129651	10238	242	Челябинская область, Красноармейский район, поселок Петровский, Чкалова, 18, Сельский ДК	t	small
79332	10907	1050	Челябинская область, Красноармейский район, поселок Петровский, Ленина, 27	f	large
129427	10899	1041	Челябинская область, Красноармейский район, поселок Пашнино 1-е, Ленина, 32	f	small
129990	10889	1031	Челябинская область, Красноармейский район, поселок Пашнино, Лесная, 11	t	small
79321	10870	1014	Челябинская область, Красноармейский район, поселок Октябрьский, Школьная, 1	f	large
130004	10908	1051	Челябинская область, Красноармейский район, поселок Озерный, Центральная, 23	t	small
130007	10911	1054	Челябинская область, Красноармейский район, поселок Нижнепетропавловское, Труда, 57А	t	small
79326	10893	1035	Челябинская область, Красноармейский район, поселок Мирный, Пионерская, 2	f	large
79331	10905	1047	Челябинская область, Красноармейский район, поселок Миасское, Школьная, 2А	f	large
79330	10904	1046	Челябинская область, Красноармейский район, поселок Миасское, Советская, 14	f	large
79329	10903	1045	Челябинская область, Красноармейский район, поселок Миасское, Советская, 8	f	large
79328	10902	1044	Челябинская область, Красноармейский район, поселок Миасское, Пионера, 30	f	large
130000	10900	1042	Челябинская область, Красноармейский район, поселок Луговой, Советская, 4	f	medium
129994	10894	1036	Челябинская область, Красноармейский район, поселок Лесной, Северная, 14	t	small
79327	10897	1039	Челябинская область, Красноармейский район, поселок Лазурный, Космонавтов, 3А	f	large
129995	10895	1037	Челябинская область, Красноармейский район, поселок Курейное, Трактовая, 7	t	small
130011	10915	1058	Челябинская область, Красноармейский район, поселок Кирды, Юбилейная, 51	t	small
79325	10888	1030	Челябинская область, Красноармейский район, поселок Канашево, Солнечная, 2	f	large
79324	10887	1029	Челябинская область, Красноармейский район, поселок Канашево, Механизаоров, 29	f	large
129991	10890	1032	Челябинская область, Красноармейский район, поселок Калуга-Соловьевка, Центральная, 6	t	small
79323	10886	1028	Челябинская область, Красноармейский район, поселок Дубровка, Ленина, 1	f	large
79322	10879	1022	Челябинская область, Красноармейский район, поселок Бродокалмак, Первая Краснознаменная, 5	f	large
129985	10880	1023	Челябинская область, Красноармейский район, поселок Бродокалмак, Могильникова, 51Б	f	medium
129989	10884	1027	Челябинская область, Красноармейский район, поселок Боровое, Центральная, 9	t	small
129992	10891	1033	Челябинская область, Красноармейский район, поселок Берсеневка, Школьная, 11	t	small
129978	10871	1015	Челябинская область, Красноармейский район, поселок Березово, Школьная, 8	t	small
129983	10877	1020	Челябинская область, Красноармейский район, поселок Береговой, Образцовая, 2	t	small
130008	10912	1055	Челябинская область, Красноармейский район, поселок Беликуль, Центральная, 20	t	small
129976	10868	1012	Челябинская область, Красноармейский район, поселок Ачликуль, Школьная, 1	t	small
129975	10867	1011	Челябинская область, Красноармейский район, поселок Алабуга, Комсомольская, 20А	f	medium
129560	11670	1888	Челябинская область, Копейск городской округ, Копейск, 2а, ДК им. ВахрушеваЖелезняка, 1 этаж, зал	f	large
79755	11720	1949	Челябинская область, Копейск городской округ, поселок Калачево, Зеленая, 9	t	large
130511	11717	1946	Челябинская область, Копейск городской округ, поселок Заозерный, Проектная, 17А	t	small
130607	11969	2236	Челябинская область, Кизильский район, поселок Чернышевский, Российская, 5	t	small
129479	11526	1736	Челябинская область, Кизильский район, поселок Черкасы, Береговая, 3	t	small
130609	11972	2240	Челябинская область, Кизильский район, поселок Чапаевский, Центральная, 4	t	small
130374	11530	1740	Челябинская область, Кизильский район, поселок Целинный, Дружбы, 20	t	small
130364	11519	1729	Челябинская область, Кизильский район, поселок Урал, Центральная, 23	f	small
130376	11533	1743	Челябинская область, Кизильский район, поселок Увальский, Молодежная, 8 Б	f	small
79669	11532	1742	Челябинская область, Кизильский район, поселок Сыртинский, 60 лет Октября, 16	f	large
130366	11521	1731	Челябинская область, Кизильский район, поселок Смородинка, Центральная, 18	t	small
130361	11516	1726	Челябинская область, Кизильский район, поселок Симбирка, Центральная, 23	t	small
130367	11522	1732	Челябинская область, Кизильский район, поселок Путь Октября, Октябрьская, 3	f	medium
79667	11525	1735	Челябинская область, Кизильский район, поселок Полоцкое, Мира, 16	f	large
130380	11538	1748	Челябинская область, Кизильский район, поселок Первомайка, Школьная, 1	t	small
129733	10352	358	Челябинская область, Кизильский район, поселок Первомайка, Школьная, 1	t	small
130379	11537	1747	Челябинская область, Кизильский район, поселок Октябрьский, Школьная, 1	t	small
130360	11515	1725	Челябинская область, Кизильский район, поселок Обручевка, Школьная, 12	f	medium
130375	11531	1741	Челябинская область, Кизильский район, поселок Новый Кондуровский, Школьная, 1	t	small
130363	11518	1728	Челябинская область, Кизильский район, поселок Новый, Пионерская, 16	t	small
130356	11511	1721	Челябинская область, Кизильский район, поселок Новопокровский, Ленина, 45	f	small
130359	11514	1724	Челябинская область, Кизильский район, поселок Новоершовский, Центральная, 13	f	medium
130372	11527	1737	Челябинская область, Кизильский район, поселок Новинка, Центральная, 5	t	small
130608	11970	2237	Челябинская область, Кизильский район, поселок Мартыновка, Школьная, 6	t	small
130477	11638	1856	Челябинская область, Кизильский район, поселок Лесной, Центральная, 39	t	small
130368	11523	1733	Челябинская область, Кизильский район, поселок Лесной, Центральная, 23	t	small
79946	11971	2239	Челябинская область, Кизильский район, поселок Кизильское, Советская, 67 Б	f	large
79665	11498	1719	Челябинская область, Кизильский район, поселок Кизильское, Советская, 67 Б	f	large
79945	11510	2238	Челябинская область, Кизильский район, поселок Кизильское, Комсомольская, 60	f	large
79666	11510	1720	Челябинская область, Кизильский район, поселок Кизильское, Комсомольская, 60	f	large
130373	11528	1738	Челябинская область, Кизильский район, поселок Кацбахский, Труда, 18	t	medium
130362	11517	1727	Челябинская область, Кизильский район, поселок Карабулак, Центральная, 15	t	small
130381	11539	1749	Челябинская область, Кизильский район, поселок Ильинка, Набережная, 12	t	small
79668	11529	1739	Челябинская область, Кизильский район, поселок Измайловский, Школьная, 2	f	large
79670	11534	1744	Челябинская область, Кизильский район, поселок Зингейский, Парковая, 16	t	large
130365	11520	1730	Челябинская область, Кизильский район, поселок Ждановский, Центральная, 18	t	small
130358	11513	1723	Челябинская область, Кизильский район, поселок Грязнушинский, Советская, 44	f	small
130378	11536	1746	Челябинская область, Кизильский район, поселок Гранитный, переулок Школьный, 3	f	medium
130377	11535	1745	Челябинская область, Кизильский район, поселок Браиловский, Центральная, 11	t	small
130357	11512	1722	Челябинская область, Кизильский район, поселок Богдановское, Мира, 5	f	medium
130369	11524	1734	Челябинская область, Кизильский район, поселок Амамбайка, Школьная, 1	t	small
129961	10853	999	Челябинская область, Катав-Ивановский район, Юрюзань, переулок Мичурина, 1	t	medium
79318	10850	996	Челябинская область, Катав-Ивановский район, Юрюзань, Советская, 108	f	large
79317	10849	995	Челябинская область, Катав-Ивановский район, Юрюзань, Советская, 100	f	large
79316	10848	994	Челябинская область, Катав-Ивановский район, Юрюзань, Советская, 61	t	large
79315	10847	993	Челябинская область, Катав-Ивановский район, Юрюзань, Советская, 57	t	large
79314	10846	992	Челябинская область, Катав-Ивановский район, Юрюзань, Советская, 22	t	large
79320	10852	998	Челябинская область, Катав-Ивановский район, Юрюзань, Сахарова, 8	t	large
79319	10851	997	Челябинская область, Катав-Ивановский район, Юрюзань, 3 Интернационала, 55	t	large
129973	10865	1009	Челябинская область, Катав-Ивановский район, поселок Шарлаш, Уральская, 15а	t	small
129967	10859	1004	Челябинская область, Катав-Ивановский район, поселок Тюлюк, Ленина, 43	t	small
79294	10777	924	Челябинская область, Катав-Ивановский район, Трехгорный городской округ, Строителей, 10	f	large
79293	10776	923	Челябинская область, Катав-Ивановский район, Трехгорный, Островского, 16	f	large
79288	10771	918	Челябинская область, Катав-Ивановский район, Трехгорный, Мира, 30	f	large
79287	10770	917	Челябинская область, Катав-Ивановский район, Трехгорный, Мира, 20	f	large
79286	10769	916	Челябинская область, Катав-Ивановский район, Трехгорный, Мира, 17	f	large
79284	10767	914	Челябинская область, Катав-Ивановский район, Трехгорный, Ленина, 6	f	large
79289	10772	919	Челябинская область, Катав-Ивановский район, Трехгорный, Космонавтов, 20а	f	large
79297	10780	927	Челябинская область, Катав-Ивановский район, Трехгорный, Карла Маркса, 30А	f	large
79285	10768	915	Челябинская область, Катав-Ивановский район, Трехгорный, Калинина, 3	f	large
79292	10775	922	Челябинская область, Катав-Ивановский район, Трехгорный, К.Маркса, 40а	f	large
79296	10779	926	Челябинская область, Катав-Ивановский район, Трехгорный, 60 лет Октября, 14	f	large
79290	10773	920	Челябинская область, Катав-Ивановский район, Трехгорный, 60 лет Октября, 6	f	large
79291	10774	921	Челябинская область, Катав-Ивановский район, Трехгорный, 50 лет Победы, 20	f	large
129966	10858	1003	Челябинская область, Катав-Ивановский район, поселок Совхозный, 34	t	small
129971	10863	1007	Челябинская область, Катав-Ивановский район, поселок Серпиевка, Карла Маркса, 34А	t	small
129959	10842	988	Челябинская область, Катав-Ивановский район, поселок Половинка, Станционная, д.станция Половинка-Катавская	t	small
129970	10862	1006	Челябинская область, Катав-Ивановский район, поселок Орловка, 1-й Советский переулок, 1Б	t	small
129493	10860	1005	Челябинская область, Катав-Ивановский район, поселок Меседа, Советская, 51	t	small
129963	10855	1001	Челябинская область, Катав-Ивановский район, поселок Лемеза, Островная, 2	t	small
129974	10866	1010	Челябинская область, Катав-Ивановский район, поселок Карауловка, Ворошилова, 2	t	small
129954	10832	980	Челябинская область, Катав-Ивановский район, поселок Верх-Катав, УстьКатавская, 78а	t	medium
79309	10835	982	Челябинская область, Катав-Ивановский район, поселок Верх-Катав, Свердловская, 50А	f	large
129955	10837	984	Челябинская область, Катав-Ивановский район, поселок Верх-Катав, Олега Кошевого, 15б	t	small
129492	10856	1002	Челябинская область, Катав-Ивановский район, поселок Верх-Катав, Нагорнова, 7	t	small
79313	10844	990	Челябинская область, Катав-Ивановский район, поселок Верх-Катав, Ленинградская, 32а	t	large
79312	10843	989	Челябинская область, Катав-Ивановский район, поселок Верх-Катав, Восточная, 31А	f	large
129962	10854	1000	Челябинская область, Катав-Ивановский район, поселок Бедярыш, Центральная, 45	t	small
129972	10864	1008	Челябинская область, Катав-Ивановский район, поселок Аратское, Пролетарская, 21а	t	small
129943	10815	965	Челябинская область, Каслинский район, поселок Юшково, Ленина, 37	t	small
129940	10812	962	Челябинская область, Каслинский район, поселок Щербаковка, Колхозная, 2	f	small
129949	10824	973	Челябинская область, Каслинский район, поселок Шабурово, Парковая, 2	f	medium
129936	10808	958	Челябинская область, Каслинский район, поселок Черкаскуль, Ленина, 23	t	small
129945	10817	967	Челябинская область, Каслинский район, поселок Усть-Караболка, Ленина, 25	t	small
79304	10819	969	Челябинская область, Каслинский район, поселок Тюбук, Ленина, 8	f	large
79303	10818	968	Челябинская область, Каслинский район, поселок Тюбук, Гагарина, 2	f	large
129951	10826	975	Челябинская область, Каслинский район, поселок Тимино, Ленина, ДК с.Тимино	t	small
79427	11114	1275	Челябинская область, Каслинский район, Снежинск, улица 40 Лет Октября, 15	f	large
79441	11127	1289	Челябинская область, Каслинский район, Снежинск, Строителей, 20	f	large
79432	11119	1280	Челябинская область, Каслинский район, Снежинск, Свердлова, 13	f	large
79424	11111	1272	Челябинская область, Каслинский район, Снежинск, Нечая, 5	f	large
79439	11125	1287	Челябинская область, Каслинский район, Снежинск, Мира, 22	f	large
79438	11124	1286	Челябинская область, Каслинский район, Снежинск, Мира, 15	f	large
79431	11118	1279	Челябинская область, Каслинский район, Снежинск, Ленина, 50	f	large
79440	11126	1288	Челябинская область, Каслинский район, Снежинск, Комсомольская, 8	f	large
79437	11123	1285	Челябинская область, Каслинский район, Снежинск, Комсомольская, 6	f	large
79436	11122	1284	Челябинская область, Каслинский район, Снежинск, Комсомольская, 4	f	large
79425	11112	1273	Челябинская область, Каслинский район, Снежинск, Комсомольская, 2	f	large
130147	11128	1290	Челябинская область, Каслинский район, Снежинск, Кирова, 2А	f	small
79435	11121	1283	Челябинская область, Каслинский район, Снежинск, Забабахина, 1	f	large
79433	11108	1281	Челябинская область, Каслинский район, Снежинск, Дзержинского, 39	f	large
79430	11117	1278	Челябинская область, Каслинский район, Снежинск, Васильева, 35	f	large
79429	11116	1277	Челябинская область, Каслинский район, Снежинск, Васильева, 54	f	large
79426	11113	1274	Челябинская область, Каслинский район, Снежинск, 40 лет Октября, 7	f	large
129932	10803	953	Челябинская область, Каслинский район, поселок Полднево, Центральная, 20	t	small
129942	10814	964	Челябинская область, Каслинский район, поселок Огневское, Школьная, 1А	f	medium
129941	10813	963	Челябинская область, Каслинский район, поселок Маук, Школьная, 15	f	medium
129950	10825	974	Челябинская область, Каслинский район, поселок Ларино, Ленина, школа с.Ларино	f	small
129944	10816	966	Челябинская область, Каслинский район, поселок Кызылова, Береговая, 41	t	small
129948	10822	972	Челябинская область, Каслинский район, поселок Красный Партизан, Победы, ДК п.Красный Партизан	t	small
129931	10802	952	Челябинская область, Каслинский район, поселок Клепалово, Береговая, 32	t	small
129938	10810	960	Челябинская область, Каслинский район, поселок Клеопино, Новгородцева, 10	t	small
129930	10801	951	Челябинская область, Каслинский район, поселок Зотино, Трактовая, 22	t	small
129939	10811	961	Челябинская область, Каслинский район, поселок Знаменка, Ленина, 32А	t	small
129937	10809	959	Челябинская область, Каслинский район, поселок Григорьевка, Ленина, 6	t	small
129947	10821	971	Челябинская область, Каслинский район, поселок Воскресенское, 1е Мая, 8	t	small
129935	10807	957	Челябинская область, Каслинский район, поселок Воздвиженка, Мира, 55	t	small
129926	10795	945	Челябинская область, Каслинский район, поселок Вишневогорск, Школьная, 5	f	small
79301	10797	947	Челябинская область, Каслинский район, поселок Вишневогорск, Советская, 79	f	large
79300	10796	946	Челябинская область, Каслинский район, поселок Вишневогорск, Пионерская, 13	f	large
129934	10806	956	Челябинская область, Каслинский район, поселок Булзи, Октябрьская, 1	f	medium
129506	11129	1291	Челябинская область, Каслинский район, поселок Ближний Береговой, Центральная, 11	t	small
79302	10805	955	Челябинская область, Каслинский район, поселок Береговой, Суворова, 17	f	large
129933	10804	954	Челябинская область, Каслинский район, поселок Береговой, Ленина, 13	f	medium
129929	10800	950	Челябинская область, Каслинский район, поселок Багаряк, Свердлова, 22	f	medium
129928	10799	949	Челябинская область, Каслинский район, поселок Багаряк, Пионерская, 18	f	medium
129927	10798	948	Челябинская область, Каслинский район, поселок Аракуль, Пионерская, 10/2	f	small
129946	10820	970	Челябинская область, Каслинский район, поселок Аллаки, Советская, школа	t	small
130331	11483	1687	Челябинская область, Карталинский район, поселок Южно-Степной, Мира, 3	t	medium
79662	11475	1679	Челябинская область, Карталинский район, поселок Центральный, Центральный переулок, 24	f	large
130347	11501	1705	Челябинская область, Карталинский район, поселок Татищево, Пушкина, 1	t	small
130327	11479	1683	Челябинская область, Карталинский район, поселок Сухореченский, Юбилейная, 32	f	small
130334	11486	1690	Челябинская область, Карталинский район, поселок Снежный, Черемушки, 7	f	medium
130330	11482	1686	Челябинская область, Карталинский район, поселок Сенной, Гагарина, 10	t	small
130351	11505	1709	Челябинская область, Карталинский район, поселок Родники, Школьная, 10	t	small
129756	10373	385	Челябинская область, Карталинский район, поселок Родники, Просвещения, 2а	f	medium
130328	11480	1684	Челябинская область, Карталинский район, поселок Рассветный, Набережная, 5	t	small
130336	11488	1692	Челябинская область, Карталинский район, поселок Песчанка, Лесная, 3	f	small
130326	11477	1682	Челябинская область, Карталинский район, поселок Первомайка, Центральная, 7	t	small
130346	11500	1704	Челябинская область, Карталинский район, поселок Ольховка, Пьянзина, 44	t	small
130325	11476	1681	Челябинская область, Карталинский район, поселок Озерный, Школьная, 2А	t	small
130324	11474	1678	Челябинская область, Карталинский район, поселок Новониколаевка, Центральная, 27 А	t	small
130329	11481	1685	Челябинская область, Карталинский район, поселок Новокатенино, Центральная, 1А	t	small
129547	11495	1700	Челябинская область, Карталинский район, поселок Новокаолиновый, Кирова, 2	f	large
130337	11489	1693	Челябинская область, Карталинский район, поселок Неплюевка, Слонова, 8	f	medium
130354	11508	1713	Челябинская область, Карталинский район, поселок Некрасово, Центральная, 1	f	small
130323	11473	1677	Челябинская область, Карталинский район, поселок Мичуринский, Садовая, 1А	f	medium
130342	11494	1699	Челябинская область, Карталинский район, поселок Михайловка, Центральная, 17	t	small
79664	11478	1718	Челябинская область, Карталинский район, поселок Локомотивный, Школьная, 25	f	large
79663	11447	1717	Челябинская область, Карталинский район, поселок Локомотивный, Ленина, 88	f	large
130355	11509	1714	Челябинская область, Карталинский район, поселок Красный Яр, Северная, 45	f	small
130352	11506	1710	Челябинская область, Карталинский район, поселок Краснотал, Центральная, 39А	t	small
130338	11490	1695	Челябинская область, Карталинский район, поселок Коноплянка, Терешковой, 24	t	small
130341	11493	1698	Челябинская область, Карталинский район, поселок Кизилчилик, Октябрьская, 29	f	small
130335	11487	1691	Челябинская область, Карталинский район, поселок Каракуль, Черемушки, 8	t	small
130344	11497	1702	Челябинская область, Карталинский район, поселок Запасное, Вокзальная, 21 А	t	small
130332	11484	1688	Челябинская область, Карталинский район, поселок Елизаветопольское, Центральная, 34	t	small
130340	11492	1697	Челябинская область, Карталинский район, поселок Еленинка, Будаковой, 21	f	medium
130343	11496	1701	Челябинская область, Карталинский район, поселок Джабык, Вокзальная, 2, ж.д. станция	f	medium
130348	11502	1706	Челябинская область, Карталинский район, поселок Горная, Пушкина, 15	t	small
130333	11485	1689	Челябинская область, Карталинский район, поселок Вишневый, Центральная, 17/2	t	small
130345	11499	1703	Челябинская область, Карталинский район, поселок Великопетровка, Мира, 34	t	medium
130353	11507	1711	Челябинская область, Карталинский район, поселок Варшавка, Центральная, 34	f	medium
130349	11503	1707	Челябинская область, Карталинский район, поселок Анненское, Переселенческая, 24	f	medium
130350	11504	1708	Челябинская область, Карталинский район, поселок Анненское, Ленина, 8	f	medium
130339	11491	1696	Челябинская область, Карталинский район, поселок Акмулла, Гагарина, 7	t	small
130495	11661	1879	Челябинская область, Еткульский район, поселок Шибаево, Халтурина, 11	t	small
130494	11660	1878	Челябинская область, Еткульский район, поселок Шеломенцево, Центральная, 19	f	small
130502	11669	1887	Челябинская область, Еткульский район, поселок Шатрово, Советская, 12	t	small
130480	11643	1861	Челябинская область, Еткульский район, поселок Таянды, Школьная, 1	t	small
130484	11650	1868	Челябинская область, Еткульский район, поселок Сухоруково, Центральная, 6	t	small
130473	11635	1853	Челябинская область, Еткульский район, поселок Соколово, Банная, 9	t	small
79705	11667	1885	Челябинская область, Еткульский район, поселок Селезян, Советская, 56	f	large
130472	11634	1852	Челябинская область, Еткульский район, поселок Сарыкуль, Школьная, 17	t	small
129737	9025	362	Челябинская область, Еткульский район, поселок Сары, Центральная, 19	t	small
130032	10936	1082	Челябинская область, Еткульский район, поселок Сары, Свердлова, 18	f	medium
130471	11633	1851	Челябинская область, Еткульский район, поселок Приозерный, Школьная, 11	t	small
130493	11659	1877	Челябинская область, Еткульский район, поселок Потапово, Центральная, 38	t	small
130488	11655	1873	Челябинская область, Еткульский район, поселок Погудино, Молодежная, 18	t	small
130486	11653	1871	Челябинская область, Еткульский район, поселок Погорелка, Береговая, 31	t	small
130497	11663	1881	Челябинская область, Еткульский район, поселок Писклово, Колхозная, 1а	f	small
130492	11658	1876	Челябинская область, Еткульский район, поселок Печенкино, Набережная, 22	t	small
130489	11656	1874	Челябинская область, Еткульский район, поселок Новобатурино, Центральная, 1	t	medium
130483	11649	1867	Челябинская область, Еткульский район, поселок Новобаландино, Молодежная, 25	t	small
130482	11648	1866	Челябинская область, Еткульский район, поселок Николаевка, Береговая, 35а	t	small
130500	11666	1884	Челябинская область, Еткульский район, поселок Назарово, Даровского, 39	t	small
129744	10359	371	Челябинская область, Еткульский район, поселок Лебедевка, Центральная, 5	t	small
130496	11662	1880	Челябинская область, Еткульский район, поселок Кораблево, Школьный пер, 1	t	small
130499	11665	1883	Челябинская область, Еткульский район, поселок Кораблево, Октябрьская, 7	t	small
130476	11637	1855	Челябинская область, Еткульский район, поселок Копытово, Мира, 19	t	small
79704	11652	1870	Челябинская область, Еткульский район, поселок Коелга, Чапаева, 6	f	large
79948	11975	2243	Челябинская область, Еткульский район, поселок Коелга, Заречная, 8а	f	large
79703	11647	1865	Челябинская область, Еткульский район, поселок Каратабан, Набережная, 27Б	f	large
129430	11657	1875	Челябинская область, Еткульский район, поселок Журавлево, Набережная, 24	t	small
79947	11973	2241	Челябинская область, Еткульский район, поселок Еткуль, Первомайская, 40	f	large
130610	11974	2242	Челябинская область, Еткульский район, поселок Еткуль, Ленина, 2	f	small
79702	11645	1863	Челябинская область, Еткульский район, поселок Еткуль, Ленина, 37	f	large
79701	11644	1862	Челябинская область, Еткульский район, поселок Еткуль, Ленина, 30	f	large
130611	11641	2244	Челябинская область, Еткульский район, поселок Еманжелинка, Октябрьская, 17А	f	medium
79699	11641	1859	Челябинская область, Еткульский район, поселок Еманжелинка, Октябрьская, 17А	f	large
79700	11642	1860	Челябинская область, Еткульский район, поселок Еманжелинка, Заречная, 21А	f	large
130485	11651	1869	Челябинская область, Еткульский район, поселок Долговка, Новая, 4	t	small
130479	11640	1858	Челябинская область, Еткульский район, поселок Депутатский, Центральная, 5а	t	small
130481	11646	1864	Челябинская область, Еткульский район, поселок Грознецкий, Труда, 17	t	small
130478	11639	1857	Челябинская область, Еткульский район, поселок Березняки, Лесная, 14	t	small
129491	11636	1854	Челябинская область, Еткульский район, поселок Белоусово, Октябрьская, 1	f	small
130470	11632	1850	Челябинская область, Еткульский район, поселок Белоносово, Советская, 15	f	medium
130468	11630	1848	Челябинская область, Еткульский район, поселок Бектыш, Комсомольская, 12	f	medium
130498	11664	1882	Челябинская область, Еткульский район, поселок Аткуль, Школьная, 10	t	small
129488	11319	1524	Челябинская область, Верхнеуральский район, поселок Этовна, Молодежная, 92	t	small
130212	11338	1542	Челябинская область, Верхнеуральский район, поселок Эстонский, Центральная, 26	t	small
130206	11331	1535	Челябинская область, Верхнеуральский район, поселок Шеметовский, Мира, 8	t	small
79629	11333	1537	Челябинская область, Верхнеуральский район, поселок Форштадт, Советская, 13	f	large
129494	11306	1511	Челябинская область, Верхнеуральский район, поселок Уфимский, Школьная, 4	f	small
130174	11298	1503	Челябинская область, Верхнеуральский район, поселок Урлядинский, Дружбы, 37	f	small
129487	11314	1519	Челябинская область, Верхнеуральский район, поселок Томинский, Мира, 3	t	small
130180	11304	1509	Челябинская область, Верхнеуральский район, поселок Тайсара, Школьная, 1	t	small
130193	11317	1522	Челябинская область, Верхнеуральский район, поселок Сухтелинский, Школьная, 12	t	small
130205	11330	1534	Челябинская область, Верхнеуральский район, поселок Сурменевский, Советская, 51	t	small
79628	11321	1525	Челябинская область, Верхнеуральский район, поселок Спасский, Ленина, 33	f	large
130183	11307	1512	Челябинская область, Верхнеуральский район, поселок Смирновский, Российская, 26	t	small
130179	11303	1508	Челябинская область, Верхнеуральский район, поселок Смеловский, Братьев Каширинных, 6	f	medium
130208	11334	1538	Челябинская область, Верхнеуральский район, поселок Сафроновский, Школьная, 7	t	small
130210	11336	1540	Челябинская область, Верхнеуральский район, поселок Самарский, Советская, 48	t	small
130171	11235	1499	Челябинская область, Верхнеуральский район, поселок Сабановский, Ветеранов, 11/2	t	small
130213	11320	1543	Челябинская область, Верхнеуральский район, поселок Полосинский, Солнечная, 14А	t	small
130185	11309	1514	Челябинская область, Верхнеуральский район, поселок Подольский, Российская, 31	t	small
79627	11310	1515	Челябинская область, Верхнеуральский район, поселок Петропавловский, Клубная, 1	f	large
130207	11332	1536	Челябинская область, Верхнеуральский район, поселок Новоурлядинский, Уральская, 7	t	small
130191	11315	1520	Челябинская область, Верхнеуральский район, поселок Новотоминский, Школьная, 1	t	small
130172	11134	1500	Челябинская область, Верхнеуральский район, поселок Новоозерный, Солнечная, 2	t	small
130188	11313	1518	Челябинская область, Верхнеуральский район, поселок Новокопаловский, Степная, 10	t	small
130198	11323	1527	Челябинская область, Верхнеуральский район, поселок Нововоронинский, Молодежная, 10	t	small
130211	11337	1541	Челябинская область, Верхнеуральский район, поселок Новоахуново, Клубная, 11	t	small
79624	11174	1497	Челябинская область, Верхнеуральский район, поселок Межозерный, Центральная, 9	f	large
79622	11294	1495	Челябинская область, Верхнеуральский район, поселок Межозерный, Спортивная, 9	f	large
79623	11295	1496	Челябинская область, Верхнеуральский район, поселок Межозерный, Ленина, 5А	f	large
130202	11327	1531	Челябинская область, Верхнеуральский район, поселок Малый Бугодак, Московская, 39	t	small
130175	11299	1504	Челябинская область, Верхнеуральский район, поселок Ложкина, Школьная, 13	t	small
130194	11318	1523	Челябинская область, Верхнеуральский район, поселок Линевка, Юбилейная, 17	t	small
130187	11312	1517	Челябинская область, Верхнеуральский район, поселок Крутой Лог, Школьная, 1	t	small
79626	11305	1510	Челябинская область, Верхнеуральский район, поселок Краснинский, Советская, 54	t	large
130186	11311	1516	Челябинская область, Верхнеуральский район, поселок Комсомольское, Школьная, 10	t	small
130204	11329	1533	Челябинская область, Верхнеуральский район, поселок Кожанов, Центральная, 152	t	small
130177	11301	1506	Челябинская область, Верхнеуральский район, поселок Кирса, Юбилейная, 19	f	medium
130192	11316	1521	Челябинская область, Верхнеуральский район, поселок Кидышевский, Центральная, 29	t	small
130173	11297	1502	Челябинская область, Верхнеуральский район, поселок Карагайский, микрорайон Карагайский Бор	t	small
79625	11296	1501	Челябинская область, Верхнеуральский район, поселок Карагайский, Советская, 5	f	large
130178	11302	1507	Челябинская область, Верхнеуральский район, поселок Казанцевский, Молодежная, 1	t	small
130197	11322	1526	Челябинская область, Верхнеуральский район, поселок Ивановский, Ленина, 21	t	small
130209	11335	1539	Челябинская область, Верхнеуральский район, поселок Дзержинка, Набережная, 4	f	small
130184	11308	1513	Челябинская область, Верхнеуральский район, поселок Горбуновский, Молодежная, 28	t	small
130200	11325	1529	Челябинская область, Верхнеуральский район, поселок Вятский, Мира, 22/1	t	small
130203	11328	1532	Челябинская область, Верхнеуральский район, поселок Волковский, Школьная, 15	t	small
79619	11291	1492	Челябинская область, Верхнеуральский район, Верхнеуральск, Советская, 20	f	large
79620	11292	1493	Челябинская область, Верхнеуральский район, Верхнеуральск, Розы Люксембург, 41	f	large
79617	11289	1490	Челябинская область, Верхнеуральский район, Верхнеуральск, Мира, 115	f	large
79618	11290	1491	Челябинская область, Верхнеуральский район, Верхнеуральск, Еремина, 33	f	large
130201	11326	1530	Челябинская область, Верхнеуральский район, поселок Большой Бугодак, Садовая, 1/2	t	small
130170	11206	1498	Челябинская область, Верхнеуральский район, поселок Бабарыкинский, Школьная, 4	t	small
130176	11300	1505	Челябинская область, Верхнеуральский район, поселок Александровский, Верхняя, 4	t	small
130321	11459	1662	Челябинская область, Варненский район, поселок Толсты, Уральская, 1А	f	medium
130320	11458	1661	Челябинская область, Варненский район, поселок Солнце, Центральная, 17В	t	small
130314	11454	1657	Челябинская область, Варненский район, поселок Саламат, Южная, 9	t	small
130307	11446	1650	Челябинская область, Варненский район, поселок Саламат, Привокзальная, 14, ж.д. станция	t	small
130301	11440	1644	Челябинская область, Варненский район, поселок Ракитный, Центральная, 19А	t	small
130313	11453	1656	Челябинская область, Варненский район, поселок Правда, Уральская, 2А	t	small
130312	11452	1655	Челябинская область, Варненский район, поселок Новый Урал, переулок Школьный, 2	f	medium
129413	11457	1660	Челябинская область, Варненский район, поселок Новопокровка, Советская, 89	f	medium
130305	11444	1648	Челябинская область, Варненский район, поселок Новокулевчи, Школьная, 12А	t	small
130300	11439	1643	Челябинская область, Варненский район, поселок Нововладимировский, Набережная, 7	t	small
130308	11448	1651	Челябинская область, Варненский район, поселок Николаевка, Набережная, 23А	f	medium
130287	11422	1627	Челябинская область, Варненский район, поселок Маслоковцы, Советская, 4А	t	small
130306	11445	1649	Челябинская область, Варненский район, поселок Лейпциг, Юбилейная, 20	t	medium
129484	11428	1633	Челябинская область, Варненский район, поселок Кызыл-Маяк	t	small
130304	11443	1647	Челябинская область, Варненский район, поселок Кулевчи, Завалищина, 39/2	t	medium
129411	11437	1642	Челябинская область, Варненский район, поселок Красный Октябрь, Гагарина, 35Б	f	medium
130294	11433	1638	Челябинская область, Варненский район, поселок Красноармейский, Озерная, 2А	t	small
130311	11451	1654	Челябинская область, Варненский район, поселок Красная Заря, переулок Школьный, 1	t	small
130293	11432	1637	Челябинская область, Варненский район, поселок Комсомольский, Труда, 8А	f	small
130303	11442	1646	Челябинская область, Варненский район, поселок Кинжитай, Центральная, 81	t	small
130292	11431	1636	Челябинская область, Варненский район, поселок Катенино	f	medium
130291	11430	1635	Челябинская область, Варненский район, поселок Караоба, Школьная, 2А	t	small
130297	11436	1641	Челябинская область, Варненский район, поселок Камышинка, Целинная, 151	t	small
130290	11429	1634	Челябинская область, Варненский район, поселок Казановка, Центральная, 108А	t	small
130317	11456	1659	Челябинская область, Варненский район, поселок Заречье, Центральная, 21	t	small
130310	11450	1653	Челябинская область, Варненский район, поселок Дружный, Центральная, 3	t	small
130040	10834	1090	Челябинская область, Варненский район, поселок Дружный, Центральная, 10	f	medium
130296	11435	1640	Челябинская область, Варненский район, поселок Городище, Гоголя, 19	f	small
130302	11441	1645	Челябинская область, Варненский район, поселок Владимировка, Школьная, 14	t	small
79944	11968	2235	Челябинская область, Варненский район, поселок Варна, Спартак, 22А	f	large
129549	11425	1630	Челябинская область, Варненский район, поселок Варна, Советская, 127	f	large
130606	11967	2234	Челябинская область, Варненский район, поселок Варна, Пугачева, 14	f	medium
79647	11426	1631	Челябинская область, Варненский район, поселок Варна, Пролетарская, 155	f	large
79646	11424	1629	Челябинская область, Варненский район, поселок Варна, Магнитогорская, 1	f	large
79648	11427	1632	Челябинская область, Варненский район, поселок Варна, Ленина, 27А	f	large
79645	11423	1628	Челябинская область, Варненский район, поселок Бородиновка, Школьная, 49	f	large
130309	11449	1652	Челябинская область, Варненский район, поселок Большевик, Школьная, 1	f	small
130295	11434	1639	Челябинская область, Варненский район, поселок Белоглинка, Центральная, 12А	t	small
79644	11421	1626	Челябинская область, Варненский район, поселок Арчаглы-Аят, Центральная, 12	f	large
129481	11455	1658	Челябинская область, Варненский район, поселок Алтырка, Центральная, 12	t	small
130284	11418	1623	Челябинская область, Варненский район, поселок Алексеевка, Школьная, 8	t	medium
130286	11420	1625	Челябинская область, Варненский район, поселок Александровка, Советская, 13	t	small
130469	11631	1849	Челябинская область, Варненский район, поселок Александровка, Набережная, 11а	t	small
130285	11419	1624	Челябинская область, Варненский район, поселок Алакамыс, Пролетарская, 2	t	small
130279	11410	1615	Челябинская область, Брединский район, поселок Ясная Поляна, Садовая, 34	t	small
130283	11417	1622	Челябинская область, Брединский район, поселок Сосновка, Школьная, 2	t	small
130282	11415	1620	Челябинская область, Брединский район, поселок Синий Шихан, Центральная, 45	t	small
129426	11404	1609	Челябинская область, Брединский район, поселок Светлые Озера, Центральная, 14	t	small
79643	11416	1621	Челябинская область, Брединский район, поселок Рымникский, Гатьятуллина, 1а	f	large
79642	11413	1618	Челябинская область, Брединский район, поселок Павловский, Молодежная, 2	f	large
129420	11398	1603	Челябинская область, Брединский район, поселок Октябрьский, Школьная, 4	t	small
130266	11399	1604	Челябинская область, Брединский район, поселок Новый, Целинная, 40А	t	small
129425	11403	1608	Челябинская область, Брединский район, поселок Новогеоргиевский, Школьная, 3	t	small
79641	11411	1616	Челябинская область, Брединский район, поселок Наследницкий, Новостройки, 5	f	large
129422	11402	1607	Челябинская область, Брединский район, поселок Могутовский, Дорожная, 18	t	small
129442	11390	1596	Челябинская область, Брединский район, поселок Мирное, Мира, 24	t	medium
129553	11396	1601	Челябинская область, Брединский район, поселок Маяк, Школьный переулок, 1	f	large
129489	11587	1802	Челябинская область, Брединский район, поселок Маяк, Мира, 15 А	t	small
130260	11393	1599	Челябинская область, Брединский район, поселок Мариинский, Комсомольская, 1	t	small
130277	11408	1613	Челябинская область, Брединский район, поселок Лебяжий, Центральная, 22	t	small
130280	11412	1617	Челябинская область, Брединский район, поселок Коряжный, Центральная, 30	t	small
130278	11409	1614	Челябинская область, Брединский район, поселок Комсомольский, Горького, 10	t	medium
130275	11406	1611	Челябинская область, Брединский район, поселок Княженский, Генерала Григорьева, 36	f	medium
129555	11405	1610	Челябинская область, Брединский район, поселок Калининский, пер. Школьный, 8	f	large
130276	11407	1612	Челябинская область, Брединский район, поселок Заозерный, Дорожная, 2А	t	small
129421	11401	1606	Челябинская область, Брединский район, поселок Гогино, Пристационная, 12	t	small
130263	11397	1602	Челябинская область, Брединский район, поселок Восход, Школьная, 3	t	small
130281	11414	1619	Челябинская область, Брединский район, поселок Восточный, Школьная, 1	t	small
129551	11382	1588	Челябинская область, Брединский район, поселок Бреды, мкр. Черемушки, 11	f	large
79639	11388	1594	Челябинская область, Брединский район, поселок Бреды, Фрунзе, 31	f	large
129441	11383	1589	Челябинская область, Брединский район, поселок Бреды, Пушкина, 52	f	medium
130254	11387	1593	Челябинская область, Брединский район, поселок Бреды, Победы, 8а	f	medium
129552	11385	1592	Челябинская область, Брединский район, поселок Бреды, Мира, 9	f	large
79640	11389	1595	Челябинская область, Брединский район, поселок Бреды, Гербанова, 15	f	large
79638	11384	1590	Челябинская область, Брединский район, поселок Бреды, Аэродромная, 42	f	large
129554	11400	1605	Челябинская область, Брединский район, поселок Боровое, Мира, 11	f	large
129410	11394	1600	Челябинская область, Брединский район, поселок Атамановский, Школьная, 15	t	medium
130259	11392	1598	Челябинская область, Брединский район, поселок Андреевский, Садиковая, 1а	f	medium
129419	11391	1597	Челябинская область, Брединский район, поселок Амурский, Центральная, 1	t	small
129897	10737	883	Челябинская область, Ашинский район, поселок Усть-Курышка	t	small
79266	10735	881	Челябинская область, Ашинский район, поселок Ук	t	large
129895	10734	880	Челябинская область, Ашинский район, поселок Точильный	t	small
129896	10736	882	Челябинская область, Ашинский район, поселок Сухая Атя	t	small
129883	10716	862	Челябинская область, Ашинский район, Сим, Кирова, 1	f	medium
79784	11755	1986	Челябинская область, Ашинский район, поселок Первомайский, Школьная, 12	f	large
79782	11753	1984	Челябинская область, Ашинский район, поселок Первомайский, Нечепуренко, 50	f	large
79783	11754	1985	Челябинская область, Ашинский район, поселок Первомайский, Мира, 4	f	large
129891	10730	876	Челябинская область, Ашинский район, поселок Муратовка, Муратовский сельский Дом культуры 	t	small
79257	10709	856	Челябинская область, Ашинский район, Миньяр, Ленина, 54	f	large
129893	10732	878	Челябинская область, Ашинский район, поселок Малояз, Малоязовский сельский клуб	t	small
79265	10728	874	Челябинская область, Ашинский район, поселок Кропачево, Свердлова, 96	f	large
129889	10727	873	Челябинская область, Ашинский район, поселок Кропачево, Рокутова, 14	f	medium
129888	10726	872	Челябинская область, Ашинский район, поселок Кропачево, Ленина, 161	f	small
129887	10725	871	Челябинская область, Ашинский район, поселок Кропачево, Ленина, 115	f	medium
129892	10731	877	Челябинская область, Ашинский район, поселок Илек, Администрация Илекского сельского поселения	t	small
129890	10729	875	Челябинская область, Ашинский район, поселок Ерал, Филиал МОУ СОШ №26 пгт. Кропачево в с. Ерал	t	medium
129894	10733	879	Челябинская область, Ашинский район, поселок Биянка	t	small
129607	7030	49	Челябинская область, Аргаяшский район, поселок Яраткулова, Центральная, 30	f	medium
130596	11953	2220	Челябинская область, Аргаяшский район, поселок Ялтырова, Школьная, 7	t	small
129572	8818	10	Челябинская область, Аргаяшский район, поселок Чубары, Советская, 4	t	small
129591	9789	31	Челябинская область, Аргаяшский район, поселок Чапаевка, Центральная, 34	t	small
129605	5978	47	Челябинская область, Аргаяшский район, поселок Худайбердинский, Садовая, 7	f	medium
130597	11954	2221	Челябинская область, Аргаяшский район, поселок Халитова, Озёрная, 6	t	small
129610	8389	52	Челябинская область, Аргаяшский район, поселок Уразбаева, Набережная, 30	t	small
129604	5543	46	Челябинская область, Аргаяшский район, поселок Старая Соболева, Лесная, 14	t	small
129590	9783	30	Челябинская область, Аргаяшский район, поселок Селяева, Труда, 53	t	small
129602	4922	44	Челябинская область, Аргаяшский район, поселок Норкино, Северная, 1	t	small
130594	11951	2218	Челябинская область, Аргаяшский район, поселок Новый Миасс, Луговая, 2А	t	small
129603	5080	45	Челябинская область, Аргаяшский район, поселок Новая Соболева, Родниковая, 5	f	medium
129587	9741	27	Челябинская область, Аргаяшский район, поселок Метелёва, Р.У.Кузыева, 9	t	small
129582	9452	20	Челябинская область, Аргаяшский район, поселок Маякский, Полевая, 1 А	t	small
129576	9154	14	Челябинская область, Аргаяшский район, деревня Малая Ультракова, Школьная, 4	t	small
129580	9324	18	Челябинская область, Аргаяшский район, поселок Мавлютова, Полевая, 32	t	medium
129574	9104	12	Челябинская область, Аргаяшский район, поселок Левашева, Интернациональная, 22 А	t	small
129609	8228	51	Челябинская область, Аргаяшский район, поселок Куянбаева, Колхозная, 14	t	small
129577	9251	15	Челябинская область, Аргаяшский район, поселок Курманова, Школьная, 18	f	medium
78712	9955	37	Челябинская область, Аргаяшский район, поселок Кулуево, Чапаева, 10	f	large
78713	9960	38	Челябинская область, Аргаяшский район, поселок Кулуево, Салавата Юлаева, 31	f	large
129571	8692	9	Челябинская область, Аргаяшский район, деревня Кузяшева, Школьная, 13А	t	medium
129592	9825	32	Челябинская область, Аргаяшский район, поселок Кузнецкое, Октябрьская, 117В	f	medium
129593	9839	33	Челябинская область, Аргаяшский район, поселок Кузнецкое, Ленина, 49	f	medium
129573	8878	11	Челябинская область, Аргаяшский район, поселок Кировский, Восточная, 10 А	t	small
129586	9699	26	Челябинская область, Аргаяшский район, поселок Камышевка, Советская, 24/2	f	medium
78711	9682	25	Челябинская область, Аргаяшский район, поселок Ишалино, Школьная, 30, жд. станция	f	large
129584	9560	23	Челябинская область, Аргаяшский район, поселок Ишалино, Школьная, 27	t	medium
129583	9550	22	Челябинская область, Аргаяшский район, поселок Илимбетова, М. Усманова, 27	t	small
78710	9544	21	Челябинская область, Аргаяшский район, поселок Дербишева, Набережная, 56	f	large
129595	9910	35	Челябинская область, Аргаяшский район, поселок Губернское, Братьев Кауровых, 10А	t	small
129596	9934	36	Челябинская область, Аргаяшский район, поселок Губернское, Архипова, 68 А	t	small
129569	10058	7	Челябинская область, Аргаяшский район, поселок Буланцы, Ветеранов, 10 В	t	small
129570	8618	8	Челябинская область, Аргаяшский район, деревня Большая Усманова, Пионерская, 14	t	small
129597	9966	39	Челябинская область, Аргаяшский район, поселок Большая Куйсарина, Школьная, 14	t	small
130595	11952	2219	Челябинская область, Аргаяшский район, поселок Большая Исянгильдина, Центральная, 21	t	small
129608	7430	50	Челябинская область, Аргаяшский район, поселок Биккулова, Колхозная, 34	t	small
129502	11110	1271	Челябинская область, Аргаяшский район, поселок Бижеляк, Омская, 13, фельдшерскоакушерский пункт, 1 этаж холл	t	small
129589	9777	29	Челябинская область, Аргаяшский район, поселок Бигарды, Зеленая, 2	t	small
129606	6373	48	Челябинская область, Аргаяшский район, поселок Башакуль, Школьная, 2	t	small
129579	9291	17	Челябинская область, Аргаяшский район, поселок Байрамгулово, Титова, 1	f	medium
129578	9267	16	Челябинская область, Аргаяшский район, поселок Байрамгулово, Титова, 31	f	medium
129600	4776	42	Челябинская область, Аргаяшский район, поселок Байгазина, Центральная, 25	t	medium
129601	4907	43	Челябинская область, Аргаяшский район, поселок Бажикаева, Школьная, 9	f	medium
129575	9120	13	Челябинская область, Аргаяшский район, поселок Аязгулова, Школьная, 2	f	medium
78708	10078	4	Челябинская область, Аргаяшский район, поселок Аргаяш, площадь СПТУ	t	large
129568	10012	5	Челябинская область, Аргаяшский район, поселок Аргаяш, Октябрьская, 23	f	medium
78707	10077	3	Челябинская область, Аргаяшский район, поселок Аргаяш, Ленина, 3	f	large
78705	10075	1	Челябинская область, Аргаяшский район, поселок Аргаяш, 8 Марта, 17	f	large
78706	10076	2	Челябинская область, Аргаяшский район, поселок Аргаяш, Чкалова, 20	f	large
129581	9427	19	Челябинская область, Аргаяшский район, поселок Аргази, Береговая, 4	t	small
78709	10049	6	Челябинская область, Аргаяшский район, поселок Акбашева, 30 лет Победы, 22	f	large
129599	4709	41	Челябинская область, Аргаяшский район, поселок Айбатова, Центральная, 35	t	small
129585	9604	24	Челябинская область, Аргаяшский район, поселок Абдырова, Солнечная, 8	t	small
79637	11380	1586	Челябинская область, Агаповский район, поселок Янгельский, Рабочая, 23а	f	large
130233	11360	1565	Челябинская область, Агаповский район, поселок Южный, Садовая, 8	t	small
130245	11374	1580	Челябинская область, Агаповский район, поселок Черноотрог, Мирный переулок, 45	t	small
130249	11378	1584	Челябинская область, Агаповский район, поселок Черниговский, 1 Мая, 71	f	medium
130234	11362	1567	Челябинская область, Агаповский район, поселок Харьковский, Центральная, 8	t	small
130248	11377	1583	Челябинская область, Агаповский район, поселок Утарка, Школьная, 4	t	small
130218	11347	1552	Челябинская область, Агаповский район, поселок Урожайный, Зеленая, 19/2	t	small
130250	11379	1585	Челябинская область, Агаповский район, поселок Требиат, Центральная, 1	t	small
130242	11372	1577	Челябинская область, Агаповский район, поселок Ташказган, Целинная, 74	t	small
130226	11355	1560	Челябинская область, Агаповский район, поселок Субутак, Школьная, 3, ж.д. станция	f	medium
129428	11356	1561	Челябинская область, Агаповский район, поселок Субутак, Северная, 7, ж.д. станция	f	small
130220	11349	1554	Челябинская область, Агаповский район, поселок Солодянка, переулок Сиреневый, 1	t	small
130244	11371	1579	Челябинская область, Агаповский район, поселок Светлогорск, Степная, 14	f	small
130241	11371	1576	Челябинская область, Агаповский район, поселок Светлогорск, Степная, 14	f	medium
130239	11369	1574	Челябинская область, Агаповский район, поселок Ржавка, Дружбы, 2	t	medium
78266	5718	1087	Тюменская область, Ялуторовск, Вокзальная, 15	f	large
79636	11367	1572	Челябинская область, Агаповский район, поселок Приморский, Клубная, 11	t	large
130240	11370	1575	Челябинская область, Агаповский район, поселок Приморский, Калинина, 1	t	small
79635	11363	1568	Челябинская область, Агаповский район, поселок Первомайский, Центральная, 29	f	large
130217	11346	1551	Челябинская область, Агаповский район, поселок Озерный, Набережная, 6	t	medium
130251	11381	1587	Челябинская область, Агаповский район, поселок Новоянгелька, Школьная, 12	t	medium
130222	11351	1556	Челябинская область, Агаповский район, поселок Новобурановка, Зеленая, 16	t	medium
130221	11350	1555	Челябинская область, Агаповский район, поселок Новобуранное, Зеленая, 3а	t	small
79634	11361	1566	Челябинская область, Агаповский район, поселок Наровчатка, Кооперативная, 12	f	large
130235	11364	1569	Челябинская область, Агаповский район, поселок Наваринка, Административная, 16	f	medium
130224	11353	1558	Челябинская область, Агаповский район, поселок Муравейник, Новая, 2	t	small
130236	11365	1570	Челябинская область, Агаповский район, поселок Малиновка, Клубная, 2	f	small
130225	11354	1559	Челябинская область, Агаповский район, поселок Магнитный, Молодежная, 8А	f	medium
130219	11348	1553	Челябинская область, Агаповский район, поселок Красноярский, Зеленая, 24	t	small
130232	11359	1564	Челябинская область, Агаповский район, поселок Кировский, 8 Марта, 1а	t	small
130246	11375	1581	Челябинская область, Агаповский район, поселок Зингейка, Студенческая, 15	t	small
130223	11352	1557	Челябинская область, Агаповский район, поселок Желтинский, Советская, 51	t	medium
130214	11342	1547	Челябинская область, Агаповский район, поселок Гумбейский, Садовая, 18а	t	small
130237	11366	1571	Челябинская область, Агаповский район, поселок Гумбейка, Привокзальная, 15, ж.д. станция	t	small
130231	11358	1563	Челябинская область, Агаповский район, поселок Вперед, Молодежная, 8А	f	small
130243	11373	1578	Челябинская область, Агаповский район, поселок Воздвиженка, Школьная, 5	t	small
130238	11368	1573	Челябинская область, Агаповский район, поселок Верхнекизильское, Школьная, 27/1	t	medium
79633	11344	1549	Челябинская область, Агаповский район, поселок Буранный, Волынцева, 1	f	large
130216	11345	1550	Челябинская область, Агаповский район, поселок Буранная, Железнодорожная, 1/1, ж.д. станция	f	medium
130247	11376	1582	Челябинская область, Агаповский район, поселок Базарский, Октябрьская, 43	t	small
129429	11357	1562	Челябинская область, Агаповский район, поселок Алексеевский, Мира, 1	t	small
79630	11339	1544	Челябинская область, Агаповский район, поселок Агаповка, Школьная, 52	f	large
79631	11340	1545	Челябинская область, Агаповский район, поселок Агаповка, Пролетарская, 44	f	large
79632	11341	1546	Челябинская область, Агаповский район, поселок Агаповка, Правобережная, 3	f	large
130215	11343	1548	Челябинская область, Агаповский район, поселок Аблязово, Степная, 12	t	small
79240	10686	831	Челябинская область, Ашинский район, поселок Аша, Озимина, 34	f	large
128274	9203	62	Ханты-Мансийский автономный округ, сельское поселение Унъюган, мкр. 40 лет Победы, 11	f	\N
128213	9145	34	Ханты-Мансийский автономный округ, сельское поселение Сосновка, Школьная, 1	t	\N
85605	9096	2	Ханты-Мансийский автономный округ, пгт.Березово, Ленина, 20, Здание начальной школы	f	large
85616	9151	37	Ханты-Мансийский автономный округ, городское поселение Октябрьское, Советская, 27, помещение ФОК	f	large
85613	9130	25	Ханты-Мансийский автономный округ, городское поселение Белоярский, Набережная, 16	f	large
85611	9128	23	Ханты-Мансийский автономный округ, городское поселение Белоярский, 3 микрорайон, 34, 3 микрорайон	f	large
85610	9127	22	Ханты-Мансийский автономный округ, городское поселение Белоярский, 3 микрорайон, 36	f	large
128298	9241	95	Ханты-Мансийский автономный округ, Ямки, Лесная, 30, начальная школа, детский сад	t	\N
128471	9458	277	Ханты-Мансийский автономный округ, деревня Ягурьях, Центральная, 14	t	\N
128318	9254	106	Ханты-Мансийский автономный округ, поселок Ягодный, Центральная, 20, культурноспортивный комплекс	t	\N
128296	9239	94	Ханты-Мансийский автономный округ, Юмас, Полевая, 16А	t	\N
85685	9307	154	Ханты-Мансийский автономный округ, Югорск, Чкалова, 1	f	large
85688	9310	157	Ханты-Мансийский автономный округ, Югорск, Спортивная, 6	f	large
85684	9306	153	Ханты-Мансийский автономный округ, Югорск, Садовая, 27	f	large
85692	9313	161	Ханты-Мансийский автономный округ, Югорск, Мира, 52	f	large
85691	9313	160	Ханты-Мансийский автономный округ, Югорск, Мира, 52	f	large
128348	9316	162	Ханты-Мансийский автономный округ, Югорск, Микрорайон Югорск 2, здание школы № 4.	f	\N
85689	9311	158	Ханты-Мансийский автономный округ, Югорск, Ленина, 18	f	large
85683	9305	152	Ханты-Мансийский автономный округ, Югорск, Ермака, 7	f	large
85690	9312	159	Ханты-Мансийский автономный округ, Югорск, Геологов, 13	f	large
128294	9235	91	Ханты-Мансийский автономный округ, Шугур, Школьная, 8, средняя школа	t	\N
128236	9173	48	Ханты-Мансийский автономный округ, Чемаши, микрорайон ВРЗ, Октябрьский район, Школьная, 15, МОУ Чемашинская СОШ	t	\N
128335	9260	112	Ханты-Мансийский автономный округ, село Чантырья, Шаимская, 11, Дом культуры	t	\N
85770	9479	291	Ханты-Мансийский автономный округ, Ханты-Мансийск, Ямская, 6	f	large
85780	9492	305	Ханты-Мансийский автономный округ, Ханты-Мансийск, Чехова, 81	f	large
85779	9491	304	Ханты-Мансийский автономный округ, Ханты-Мансийск, Чехова, 71	f	large
128487	9487	300	Ханты-Мансийский автономный округ, Ханты-Мансийск, Уральская, 11	f	medium
85777	9486	299	Ханты-Мансийский автономный округ, Ханты-Мансийск, Студенческая, 21	f	large
85782	9494	307	Ханты-Мансийский автономный округ, Ханты-Мансийск, Строителей, 10	f	large
85774	9483	296	Ханты-Мансийский автономный округ, Ханты-Мансийск, Свердлова, 27	f	large
85773	9482	295	Ханты-Мансийский автономный округ, Ханты-Мансийск, Рознина, 104	f	large
128486	9480	293	Ханты-Мансийский автономный округ, Ханты-Мансийск, Рознина, 35	f	medium
85771	9480	292	Ханты-Мансийский автономный округ, Ханты-Мансийск, Рознина, 35	f	large
85778	9489	302	Ханты-Мансийский автономный округ, Ханты-Мансийск, Мира, 104	f	large
85776	9485	298	Ханты-Мансийский автономный округ, Ханты-Мансийск, Мира, 40 	f	large
85768	9477	289	Ханты-Мансийский автономный округ, Ханты-Мансийск, Мира, 14А	f	large
85763	9279	282	Ханты-Мансийский автономный округ, Ханты-Мансийск, Луговая, 15	f	large
128484	9472	284	Ханты-Мансийский автономный округ, Ханты-Мансийск, Лермонтова, 19 А	f	medium
85687	9309	156	Ханты-Мансийский автономный округ, Ханты-Мансийск, Ленина, 24	f	large
128488	9488	301	Ханты-Мансийский автономный округ, Ханты-Мансийск, Кооперативная, 43	f	medium
85772	9481	294	Ханты-Мансийский автономный округ, Ханты-Мансийск, Комсомольская, 40	f	large
85775	9484	297	Ханты-Мансийский автономный округ, Ханты-Мансийск, Калинина, 24	f	large
85781	9493	306	Ханты-Мансийский автономный округ, Ханты-Мансийск, Дунина-Горкавича, 1	f	large
85769	9478	290	Ханты-Мансийский автономный округ, Ханты-Мансийск, Дзержинского, 7	f	large
128489	9490	303	Ханты-Мансийский автономный округ, Ханты-Мансийск, Горная, 21	f	medium
85767	9476	288	Ханты-Мансийский автономный округ, Ханты-Мансийск, Гагарина, 3	f	large
128485	9475	287	Ханты-Мансийский автономный округ, Ханты-Мансийск, Гагарина, 101	f	medium
85766	9474	286	Ханты-Мансийский автономный округ, Ханты-Мансийск, Гагарина, 133А	f	large
85765	9473	285	Ханты-Мансийский автономный округ, Ханты-Мансийск, Сургутская, 27	f	large
85764	9471	283	Ханты-Мансийский автономный округ, Ханты-Мансийск, Бориса Щербины, 3	f	large
128479	9466	280	Ханты-Мансийский автономный округ, Урманный, Клубная, 11	t	\N
128342	9272	122	Ханты-Мансийский автономный округ, Урай, микрорайон Западный, 16	f	medium
128343	9281	131	Ханты-Мансийский автономный округ, Урай, микрорайон 3, 55А	f	medium
85661	9276	127	Ханты-Мансийский автономный округ, Урай, микрорайон 2, 87	f	large
85651	9264	115	Ханты-Мансийский автономный округ, Урай, микрорайон 1Г, 65	f	large
85654	9268	118	Ханты-Мансийский автономный округ, Урай, микрорайон 1А, 73, микрорайон 1А	f	large
85652	9265	116	Ханты-Мансийский автономный округ, Урай, микрорайон 1А, 69а	f	large
85666	9283	133	Ханты-Мансийский автономный округ, Урай, Парковая, 1	f	large
85650	9263	114	Ханты-Мансийский автономный округ, Урай, Нагорная, 24	f	large
85659	9274	125	Ханты-Мансийский автономный округ, Урай, Микрорайон №2, 82	f	large
85658	9273	124	Ханты-Мансийский автономный округ, Урай, Микрорайон западный, 8	f	large
85657	9273	123	Ханты-Мансийский автономный округ, Урай, Микрорайон западный, 8	f	large
85653	9266	117	Ханты-Мансийский автономный округ, Урай, Маяковского, 17	f	large
85662	9277	128	Ханты-Мансийский автономный округ, Урай, Ленина, 4	f	large
85656	9271	121	Ханты-Мансийский автономный округ, Урай, Ленина, 51	f	large
85665	9282	132	Ханты-Мансийский автономный округ, Урай, Авиаторов, 24	f	large
85664	9280	130	Ханты-Мансийский автономный округ, Урай, 3-й микрорайон, 46А	f	large
85663	9278	129	Ханты-Мансийский автономный округ, Урай, 3-й микрорайон, 22	f	large
85660	9275	126	Ханты-Мансийский автономный округ, Урай, 2 микрорайон, 91	f	large
85655	9269	119	Ханты-Мансийский автономный округ, Урай, 1-й микрорайон, 74	f	large
128341	9270	120	Ханты-Мансийский автономный округ, Урай,  Ленина, 97	f	medium
85622	9179	51	Ханты-Мансийский автономный округ, Талинка, мкр. Центральный, 37	f	large
128241	9178	50	Ханты-Мансийский автономный округ, Талинка, 2-я Линия микрорайон, Октябрьский район, 2 микрорайон, 6	f	medium
128641	9636	403	Ханты-Мансийский автономный округ, Сургут, МОУ школа №22	f	\N
128590	9606	386	Ханты-Мансийский автономный округ, Сургут, проспект Пролетарский, 14а	f	\N
128578	9597	382	Ханты-Мансийский автономный округ, Сургут, проспект Пролетарский, 10/3	f	\N
128498	9542	355	Ханты-Мансийский автономный округ, Сургут, проспект Пролетарский, 5/1	f	\N
128495	9542	354	Ханты-Мансийский автономный округ, Сургут, проспект Пролетарский, 5/1	f	\N
128501	9542	356	Ханты-Мансийский автономный округ, Сургут, проспект Пролетарский, 5/1	f	\N
85822	9533	347	Ханты-Мансийский автономный округ, Сургут, проспект Мира, 44/2	f	large
85816	9527	341	Ханты-Мансийский автономный округ, Сургут, проспект Мира, 23	f	large
128539	9573	369	Ханты-Мансийский автономный округ, Сургут, проспект Ленина, 33а	f	\N
85805	9517	330	Ханты-Мансийский автономный округ, Сургут, проспект Ленина, 46	f	large
85785	9497	310	Ханты-Мансийский автономный округ, городской округ Сургут, проспект Ленина, 75	f	large
85783	9495	308	Ханты-Мансийский автономный округ, Сургут, проспект Ленина, 79	f	large
128599	9613	389	Ханты-Мансийский автономный округ, Сургут, проспект Комсомольский, 29	f	\N
128602	9613	390	Ханты-Мансийский автономный округ, Сургут, проспект Комсомольский, 29	f	\N
128594	9607	387	Ханты-Мансийский автономный округ, Сургут, проспект Комсомольский, 10	f	\N
128587	9603	385	Ханты-Мансийский автономный округ, город Сургут, проспект Комсомольский, 21/2	f	\N
128598	9610	388	Ханты-Мансийский автономный округ, Сургут, проезд Первопроходцев, 12/1	f	\N
128585	9600	384	Ханты-Мансийский автономный округ, Сургут, проезд Первопроходцев, 2	f	\N
128581	9599	383	Ханты-Мансийский автономный округ, Сургут, проезд Первопроходцев, 1А	f	\N
128523	9558	363	Ханты-Мансийский автономный округ, Сургут, проезд Дружбы, 12а	f	\N
128614	9619	394	Ханты-Мансийский автономный округ, Сургут, проезд Взлетный, 4	f	\N
128612	9616	393	Ханты-Мансийский автономный округ, Сургут, проезд Взлетный, 6	f	\N
128610	9616	392	Ханты-Мансийский автономный округ, Сургут, проезд Взлетный, 6	f	\N
128605	9615	391	Ханты-Мансийский автономный округ, Сургут, проезд Взлетный, 3	f	\N
128538	9570	368	Ханты-Мансийский автономный округ, Сургут, бульвар Свободы, 6	f	\N
85794	9506	319	Ханты-Мансийский автономный округ, Сургут, Энтузиастов, 1	f	large
85792	9504	317	Ханты-Мансийский автономный округ, Сургут, Энтузиастов, 31	f	large
85790	9502	315	Ханты-Мансийский автономный округ, Сургут, Энтузиастов, 49	f	large
85789	9501	314	Ханты-Мансийский автономный округ, Сургут, Энтузиастов, 54	f	large
85788	9500	313	Ханты-Мансийский автономный округ, Сургут, Энтузиастов, 61/а	f	large
128557	9584	375	Ханты-Мансийский автономный округ, Сургут, Энергетиков, 5/1	f	\N
128555	9582	374	Ханты-Мансийский автономный округ, Сургут, Энергетиков, 8	f	\N
128546	9576	371	Ханты-Мансийский автономный округ, Сургут, Энергетиков, 49	f	\N
128544	9575	370	Ханты-Мансийский автономный округ, Сургут, Энергетиков, 51	f	\N
128548	9578	372	Ханты-Мансийский автономный округ, Сургут, Энгельса, 7	f	\N
85812	9523	337	Ханты-Мансийский автономный округ, Сургут, Чехова, 5/2	f	large
85786	9498	311	Ханты-Мансийский автономный округ, Сургут, Флегонта Показаньева, 2	f	large
128627	9625	398	Ханты-Мансийский автономный округ, Сургут, Федорова, 6	f	\N
128623	9625	397	Ханты-Мансийский автономный округ, Сургут, Федорова, 6	f	\N
78253	5729	1098	Тюменская область, Ялуторовск, Бахтиярова, 60	f	large
128576	9595	381	Ханты-Мансийский автономный округ, Сургут, Федорова, 61/1	f	\N
128564	9587	377	Ханты-Мансийский автономный округ, Сургут, Федорова, 68а	f	\N
128505	9546	357	Ханты-Мансийский автономный округ, городской округ Сургут, Университетская, 25/2	f	\N
128659	9648	409	Ханты-Мансийский автономный округ, Сургут, Толстого, 20а	f	\N
128516	9554	361	Ханты-Мансийский автономный округ, Сургут, Сибирская, 2	f	\N
128520	9556	362	Ханты-Мансийский автономный округ, Сургут, Северная, 72а	f	\N
128669	9655	412	Ханты-Мансийский автономный округ, Сургут, поселок Юность, Саянская, 9а	f	\N
128514	9553	360	Ханты-Мансийский автономный округ, Сургут, Рабочая, 43	f	\N
85824	9535	349	Ханты-Мансийский автономный округ, Сургут, Пушкина, 10	f	large
85820	9531	345	Ханты-Мансийский автономный округ, Сургут, Пушкина, 8/2	f	large
85819	9530	344	Ханты-Мансийский автономный округ, Сургут, Пушкина, 15А	f	large
85818	9529	343	Ханты-Мансийский автономный округ, Сургут, Пушкина, 15	f	large
128562	9585	376	Ханты-Мансийский автономный округ, Сургут, Просвещения, 13	f	\N
128553	9580	373	Ханты-Мансийский автономный округ, Сургут, Просвещения, 50	f	\N
128674	9659	414	Ханты-Мансийский автономный округ, Сургут, Привокзальная, 23, здание ж/д вокзала	f	\N
128649	9641	406	Ханты-Мансийский автономный округ, Сургут, Привокзальная, 16/2	f	\N
85817	9528	342	Ханты-Мансийский автономный округ, Сургут, Островского, 16/1	f	large
85815	9526	340	Ханты-Мансийский автономный округ, Сургут, Островского, 21А	f	large
85804	9516	329	Ханты-Мансийский автономный округ, Сургут, Островского, 1а	f	large
128621	9622	396	Ханты-Мансийский автономный округ, Сургут, Нагорная, 7	f	\N
85793	9505	318	Ханты-Мансийский автономный округ, Сургут, Набережный проспект, 22	f	large
128628	9628	399	Ханты-Мансийский автономный округ, Сургут, Мостостроителей, 1/а	f	\N
128568	9589	378	Ханты-Мансийский автономный округ, Сургут, Московская, 33	f	\N
128661	9650	410	Ханты-Мансийский автономный округ, Сургут, Мечникова, 5а	f	\N
128657	9646	408	Ханты-Мансийский автономный округ, Сургут, Мечникова, 5	f	\N
128570	9591	379	Ханты-Мансийский автономный округ, Сургут, Мелик-Карамова, 74б	f	\N
128618	9621	395	Ханты-Мансийский автономный округ, Сургут, Мелик Карамова, 57а	f	\N
85823	9534	348	Ханты-Мансийский автономный округ, Сургут, Маяковского, 34а	f	large
85821	9532	346	Ханты-Мансийский автономный округ, Сургут, Маяковского, 41	f	large
85814	9525	339	Ханты-Мансийский автономный округ, Сургут, Лермонтова, 8/2	f	large
85813	9524	338	Ханты-Мансийский автономный округ, Сургут, Лермонтова, 7/2	f	large
85810	9521	335	Ханты-Мансийский автономный округ, Сургут, Лермонтова, 9	f	large
85809	9520	334	Ханты-Мансийский автономный округ, Сургут, Лермонтова, 3/1	f	large
85798	9510	323	Ханты-Мансийский автономный округ, Сургут, Ленинградская, 9	f	large
85797	9509	322	Ханты-Мансийский автономный округ, Сургут, Ленинградская, 10а	f	large
128647	9639	405	Ханты-Мансийский автономный округ, Сургут, Крылова, 29/1	f	\N
85784	9496	309	Ханты-Мансийский автономный округ, Сургут, Киртбая, 3/2	f	large
128636	9631	401	Ханты-Мансийский автономный округ, Сургут, Индустриальная, 24	f	\N
128490	9538	352	Ханты-Мансийский автономный округ, Сургут, Ивана Захарова, 23/1, общежитие УМВД	f	\N
128672	9657	413	Ханты-Мансийский автономный округ, Сургут, поселок Снежный, Еловая, 8	f	\N
85803	9515	328	Ханты-Мансийский автономный округ, городской округ Сургут, Декабристов, 5/1	f	large
85802	9514	327	Ханты-Мансийский автономный округ, Сургут, Декабристов, 8	f	large
85801	9513	326	Ханты-Мансийский автономный округ, Сургут, Декабристов, 16	f	large
85800	9512	325	Ханты-Мансийский автономный округ, Сургут, Григория Кукуевицкого, 10/4	f	large
85799	9511	324	Ханты-Мансийский автономный округ, Сургут, Григория Кукуевицкого, 12/3	f	large
85796	9508	321	Ханты-Мансийский автономный округ, Сургут, Григория Кукуевицкого, 9	f	large
85795	9507	320	Ханты-Мансийский автономный округ, Сургут, Григория Кукуевицкого, 3	f	large
128653	9644	407	Ханты-Мансийский автономный округ, Сургут, Грибоедова, 12	f	\N
128573	9593	380	Ханты-Мансийский автономный округ, Сургут, Геологическая, 7/1	f	\N
128492	9540	353	Ханты-Мансийский автономный округ, Сургут, Быстринская, 18/4	f	\N
85826	9537	351	Ханты-Мансийский автономный округ, Сургут, Быстринская, 20	f	large
85807	9518	332	Ханты-Мансийский автономный округ, Сургут, Бахилова, 5	f	large
85806	9518	331	Ханты-Мансийский автономный округ, Сургут, Бахилова, 5	f	large
85808	9519	333	Ханты-Мансийский автономный округ, Сургут, Бажова, 17	f	large
128644	9637	404	Ханты-Мансийский автономный округ, Сургут, Аэрофлотская, Спорткомплекс	f	\N
128639	9633	402	Ханты-Мансийский автономный округ, Сургут, Аэрофлотская, 22	f	\N
85791	9503	316	Ханты-Мансийский автономный округ, Сургут, Артема, 9	f	large
128535	9568	367	Ханты-Мансийский автономный округ, Сургут, 50 лет ВЛКСМ, 10/2	f	\N
128532	9566	366	Ханты-Мансийский автономный округ, Сургут, 50 лет ВЛКСМ, 9а	f	\N
128529	9563	365	Ханты-Мансийский автономный округ, Сургут, 50 лет ВЛКСМ, 6в	f	\N
128525	9562	364	Ханты-Мансийский автономный округ, Сургут, 50 лет ВЛКСМ, 6/1	f	\N
128511	9549	359	Ханты-Мансийский автономный округ, Сургут, 30 лет Победы, 26	f	\N
128507	9548	358	Ханты-Мансийский автономный округ, Сургут, 30 лет Победы, 54/1	f	\N
85825	9536	350	Ханты-Мансийский автономный округ, Сургут, 30 лет Победы, 39/1	f	large
128208	9144	33	Ханты-Мансийский автономный округ, Сорум, Центральная, 34	t	\N
85677	9298	145	Ханты-Мансийский автономный округ, Советский, мкр. Хвойный, 53 а	f	large
85671	9292	139	Ханты-Мансийский автономный округ, Советский, Советская, 10а	f	large
85672	9293	140	Ханты-Мансийский автономный округ, Советский, Ленина, 12	f	large
85674	9295	142	Ханты-Мансийский автономный округ, Советский, Киевская, 26а	f	large
85673	9294	141	Ханты-Мансийский автономный округ, Советский, Гастелло, 24	f	large
128420	9424	260	Ханты-Мансийский автономный округ, Сибирский, Центральная, 7	t	\N
85621	9162	44	Ханты-Мансийский автономный округ, Сергино, Центральная, 5, помещение МБУК КДЦ Овация	f	large
128182	9117	16	Ханты-Мансийский автономный округ, Светлый, Набережная, 21В, Здание спортивнооздоров. комп	t	\N
128192	9122	19	Ханты-Мансийский автономный округ, Саранпауль, Н.Вокуева, 12, Здание средней школы	t	\N
128188	9122	18	Ханты-Мансийский автономный округ, Саранпауль, Н.Вокуева, 12, Здание средней школы	t	\N
128987	9858	518	Ханты-Мансийский автономный округ, Радужный, 2, Городской парк культуры и отдыха, МУ СК Сибирь	f	\N
129006	9870	524	Ханты-Мансийский автономный округ, Радужный, Ломоносова, 25, здание КСК Досуг	f	\N
128990	9861	519	Ханты-Мансийский автономный округ, Радужный, 9 микрорайон, 10, МУ ГПМЦ Альянс	f	\N
129000	9869	522	Ханты-Мансийский автономный округ, Радужный, 7 микрорайон, 25, МОУ СОШ №5	f	\N
129001	9869	523	Ханты-Мансийский автономный округ, Радужный, 7 микрорайон, 25, МОУ СОШ №5	f	\N
128996	9866	521	Ханты-Мансийский автономный округ, Радужный, 6 микрорайон, 30, МОУ СОШ №8	f	\N
128994	9865	520	Ханты-Мансийский автономный округ, Радужный, 6 микрорайон, 30, МОУ СОШ №8	f	\N
129009	9873	525	Ханты-Мансийский автономный округ, Радужный, 3 микрорайон, 12, МОУ СОШ №3	f	\N
129012	9873	526	Ханты-Мансийский автономный округ, Радужный, 3 микрорайон, 12, МОУ СОШ №3	f	\N
128977	9854	515	Ханты-Мансийский автономный округ, 2 микрорайон, 19, МОУ СОШ №4	f	\N
128974	9854	514	Ханты-Мансийский автономный округ, 2 микрорайон, 19, МОУ СОШ №4	f	\N
128968	9852	512	Ханты-Мансийский автономный округ, Радужный, 1 микрорайон, 11, МОУ СОШ №2	f	\N
128972	9852	513	Ханты-Мансийский автономный округ, Радужный, 1 микрорайон, 11, МОУ СОШ №2	f	\N
128984	9855	517	Ханты-Мансийский автономный округ, Радужный,  5 микрорайон, 16, МОУ СОШ №6	f	\N
128982	9855	516	Ханты-Мансийский автономный округ, Радужный,  5 микрорайон, 16, МОУ СОШ №6	f	\N
85707	9366	193	Ханты-Мансийский автономный округ, Пыть-Ях, Советская, 1, КСК Россия	f	large
85714	9372	201	Ханты-Мансийский автономный округ, Пыть-Ях, Магистральная, 57, МОУ СОШ №, 6	f	large
85711	9369	197	Ханты-Мансийский автономный округ, Пыть-Ях, 5 микрорайон, 5А, МОУ СОШ № 5	f	large
85713	9371	200	Ханты-Мансийский автономный округ, Пыть-Ях, 3 микрорайон, 34А, МОУ СОШ №, 4	f	large
85712	9371	199	Ханты-Мансийский автономный округ, Пыть-Ях, 3 микрорайон, 34А, МОУ СОШ №, 4	f	large
85706	9365	192	Ханты-Мансийский автономный округ, Пыть-Ях, 2-й микрорайон, 5А, МОУ СОШ № 1	f	large
85705	9364	191	Ханты-Мансийский автономный округ, Пыть-Ях, 2-й микрорайон, 5А, МОУ СОШ №1	f	large
85703	9362	189	Ханты-Мансийский автономный округ, Пыть-Ях, 1 микрорвйон, 11А, ГДК Факел	f	large
85704	9363	190	Ханты-Мансийский автономный округ, Пыть-Ях, 1 микрорайон, 11А, ГДК Факел	f	large
85619	9160	42	Ханты-Мансийский автономный округ, Приобье, Югорская, 5, здание администрации поселения	f	large
85620	9161	43	Ханты-Мансийский автономный округ, Приобье, Школьная, 1	f	large
128885	9801	484	Ханты-Мансийский автономный округ, Покачи, Молодежная, 9/1, СОШ №1	f	\N
128905	9820	491	Ханты-Мансийский автономный округ, Покачи, Аганская, 11	f	\N
128231	9166	46	Ханты-Мансийский автономный округ, Перегребное, Строителей, 50, МКОУ ДОД Дом юного техника	f	\N
128266	9198	60	Ханты-Мансийский автономный округ, село Пальяново, Почтовая, 13/1, здание администрации	t	\N
85617	9152	38	Ханты-Мансийский автономный округ, Октябрьское, Светлая, 11	f	large
128279	9211	70	Ханты-Мансийский автономный округ, Нягань, проспект Нефтяников, 4	f	medium
85637	9221	80	Ханты-Мансийский автономный округ, Нягань, микрорайон №1, 25	f	large
85635	9219	78	Ханты-Мансийский автономный округ, Нягань, микрорайон №1, 25А	f	large
85623	9204	63	Ханты-Мансийский автономный округ, Нягань, Энергетиков, 55	f	large
85628	9212	71	Ханты-Мансийский автономный округ, Нягань, Солнечная, 7	f	large
85627	9210	69	Ханты-Мансийский автономный округ, Нягань, Сибирская, 32	f	large
85643	9229	87	Ханты-Мансийский автономный округ, Нягань, Речная, 191	f	large
85641	9227	85	Ханты-Мансийский автономный округ, Нягань, Речная, 57	f	large
85639	9225	83	Ханты-Мансийский автономный округ, Нягань, Пионерская, 2	f	large
85629	9213	72	Ханты-Мансийский автономный округ, Нягань, Микрорайон №7, 2	f	large
85636	9220	79	Ханты-Мансийский автономный округ, Нягань, Микрорайон №1, 52А	f	large
128278	9164	67	Ханты-Мансийский автономный округ, Нягань, Лазарева, 15к1	f	small
128281	9223	82	Ханты-Мансийский автономный округ, Нягань, Авиционная, 20	f	\N
85626	9209	68	Ханты-Мансийский автономный округ, Нягань, 30 лет Победы, 13	f	large
128276	9205	64	Ханты-Мансийский автономный округ, Нягань, 30 лет Победы, 12	f	\N
85632	9216	75	Ханты-Мансийский автономный округ, Нягань, 2-й микрорайон, 30, блок №1	f	large
85633	9217	76	Ханты-Мансийский автономный округ, Нягань, микрорайон №2, 50А	f	large
85631	9215	74	Ханты-Мансийский автономный округ, Нягань, микрорайон №2, 31	f	large
85625	9208	66	Ханты-Мансийский автономный округ, Нягань, Чернышова, 42	f	large
85642	9228	86	Ханты-Мансийский автономный округ, Нягань, Уральская, 7	f	large
85640	9226	84	Ханты-Мансийский автономный округ, Нягань, Пионерская, 30	f	large
85624	9207	65	Ханты-Мансийский автономный округ, Нягань, Комсомольская, 2Б	f	large
85638	9222	81	Ханты-Мансийский автономный округ, Нягань, Загородных, 7А	f	large
85634	9218	77	Ханты-Мансийский автономный округ, Нягань, 4-й микрорайон, 13	f	large
85630	9214	73	Ханты-Мансийский автономный округ, Нягань, 3-й микрорайон, 24	f	large
129400	10072	656	Ханты-Мансийский автономный округ, Нижневартовск, 6ГПЗ1	f	\N
129395	10068	654	Ханты-Мансийский автономный округ, Нижневартовск, поселок Дивный, 13	t	\N
129376	10056	648	Ханты-Мансийский автономный округ, Нижневартовск, поселок Магистраль, 47	f	\N
129169	9961	579	Ханты-Мансийский автономный округ, Нижневартовск, проспект Победы, 20В	f	\N
129172	9961	580	Ханты-Мансийский автономный округ, Нижневартовск, проспект Победы, 20В	f	\N
129165	9959	577	Ханты-Мансийский автономный округ, Нижневартовск, проспект Победы, 21Б	f	\N
129162	9959	576	Ханты-Мансийский автономный округ, Нижневартовск, проспект Победы, 21Б	f	\N
129166	9959	578	Ханты-Мансийский автономный округ, Нижневартовск, проспект Победы, 21Б	f	\N
129145	9952	571	Ханты-Мансийский автономный округ, Нижневартовск, проспект Победы, 3Б	f	\N
129283	10014	617	Ханты-Мансийский автономный округ, Нижневартовск, проезд Заозерный, 8Б	f	\N
129282	10014	616	Ханты-Мансийский автономный округ, Нижневартовск, проезд Заозерный, 8Б	f	\N
129287	10014	618	Ханты-Мансийский автономный округ, Нижневартовск, проезд Заозерный, 8Б	f	\N
129367	10048	645	Ханты-Мансийский автономный округ, Нижневартовск, Энтузиастов, 25	f	\N
129372	10051	646	Ханты-Мансийский автономный округ, Нижневартовск, Школьная, 26	f	\N
129301	10020	623	Ханты-Мансийский автономный округ, Нижневартовск, Чапаева, 15А	f	\N
129219	9985	595	Ханты-Мансийский автономный округ, Нижневартовск, Чапаева, 30	f	\N
129316	10026	628	Ханты-Мансийский автономный округ, Нижневартовск, ХантыМансийская, 41Б	f	\N
129313	10023	627	Ханты-Мансийский автономный округ, Нижневартовск, ХантыМансийская, 39Б	f	\N
129321	10023	629	Ханты-Мансийский автономный округ, Нижневартовск, ХантыМансийская, 39Б	f	\N
129308	10021	625	Ханты-Мансийский автономный округ, Нижневартовск, Ханты-Мансийская, 41А	f	\N
129312	10021	626	Ханты-Мансийский автономный округ, Нижневартовск, Ханты-Мансийская, 41А	f	\N
129296	10016	621	Ханты-Мансийский автономный округ, Нижневартовск, Спортивная, 21	f	\N
129290	10016	619	Ханты-Мансийский автономный округ, Нижневартовск, Спортивная, 21	f	\N
129293	10016	620	Ханты-Мансийский автономный округ, Нижневартовск, Спортивная, 21	f	\N
129204	9977	590	Ханты-Мансийский автономный округ, Нижневартовск, Спортивная, 6	f	\N
129158	9956	575	Ханты-Мансийский автономный округ, Нижневартовск, Пионерская, 9А	f	\N
129250	10002	606	Ханты-Мансийский автономный округ, Нижневартовск, Пермская, 25	f	\N
129255	10002	607	Ханты-Мансийский автономный округ, Нижневартовск, Пермская, 25	f	\N
129246	10000	604	Ханты-Мансийский автономный округ, Нижневартовск, Пермская, 19	f	\N
129248	10000	605	Ханты-Мансийский автономный округ, Нижневартовск, Пермская, 19	f	\N
129366	10046	644	Ханты-Мансийский автономный округ, Нижневартовск, Первомайская, 63	f	\N
129349	10040	639	Ханты-Мансийский автономный округ, Нижневартовск, Омская, 66А	f	\N
129348	10040	638	Ханты-Мансийский автономный округ, Нижневартовск, Омская, 66А	f	\N
129149	9954	572	Ханты-Мансийский автономный округ, Нижневартовск, Омская, 2А	f	\N
129153	9931	573	Ханты-Мансийский автономный округ, Нижневартовск, Омская, 16А	f	\N
129156	9931	574	Ханты-Мансийский автономный округ, Нижневартовск, Омская, 16А	f	\N
129269	10007	612	Ханты-Мансийский автономный округ, Нижневартовск, Нефтяников, 93А	f	\N
129272	10007	613	Ханты-Мансийский автономный округ, Нижневартовск, Нефтяников, 93А	f	\N
129265	10007	611	Ханты-Мансийский автономный округ, Нижневартовск, Нефтяников, 93А	f	\N
129225	9988	597	Ханты-Мансийский автономный округ, Нижневартовск, Нефтяников, 66А	f	\N
129233	9994	600	Ханты-Мансийский автономный округ, Нижневартовск, Мусы Джалиля, 20	f	\N
129238	9994	602	Ханты-Мансийский автономный округ, Нижневартовск, Мусы Джалиля, 20	f	\N
129228	9990	598	Ханты-Мансийский автономный округ, Нижневартовск, Мусы Джалиля, 51А	f	\N
129327	10030	631	Ханты-Мансийский автономный округ, Нижневартовск, Мира, 76В	f	\N
129330	10030	632	Ханты-Мансийский автономный округ, Нижневартовск, Мира, 76В	f	\N
129324	10028	630	Ханты-Мансийский автономный округ, Нижневартовск, Мира, 76Б	f	\N
129230	9993	599	Ханты-Мансийский автономный округ, Нижневартовск, Мира, 56Б	f	\N
129220	9987	596	Ханты-Мансийский автономный округ, Нижневартовск, Мира, 39	f	\N
129195	9973	587	Ханты-Мансийский автономный округ, Нижневартовск, Мира, 13А	f	\N
129197	9973	588	Ханты-Мансийский автономный округ, Нижневартовск, Мира, 13А	f	\N
129199	9975	589	Ханты-Мансийский автономный округ, Нижневартовск, Маршала Жукова, 40Б	f	\N
129191	9970	586	Ханты-Мансийский автономный округ, Нижневартовск, Маршала Жукова, 16А	f	\N
129345	10038	637	Ханты-Мансийский автономный округ, Нижневартовск, Ленина, 56	f	\N
129299	10017	622	Ханты-Мансийский автономный округ, городской округ Нижневартовск, Ленина, 23А	f	\N
129305	10017	624	Ханты-Мансийский автономный округ, городской округ Нижневартовск, Ленина, 23А	f	\N
129176	9964	581	Ханты-Мансийский автономный округ, Нижневартовск, Ленина, 9А	f	\N
129188	9968	585	Ханты-Мансийский автономный округ, Нижневартовск, Комсомольский бульвар, 10А	f	\N
129184	9968	584	Ханты-Мансийский автономный округ, Нижневартовск, Комсомольский бульвар, 10А	f	\N
129182	9967	583	Ханты-Мансийский автономный округ, Нижневартовск, Комсомольский бульвар, 3	f	\N
129179	9967	582	Ханты-Мансийский автономный округ, Нижневартовск, Комсомольский бульвар, 3	f	\N
129279	10011	615	Ханты-Мансийский автономный округ, Нижневартовск, Интернациональная, 3	f	\N
129276	10009	614	Ханты-Мансийский автономный округ, Нижневартовск, Интернациональная, 7А	f	\N
129393	10067	653	Ханты-Мансийский автономный округ, Нижневартовск, Индустриальная, 13	f	\N
129387	10063	651	Ханты-Мансийский автономный округ, Нижневартовск, Индустриальная, 95	f	\N
129373	10054	647	Ханты-Мансийский автономный округ, Нижневартовск, Зырянова, 4	f	\N
129383	10061	650	Ханты-Мансийский автономный округ, Нижневартовск, поселок Тепличный, Заводская, 9	f	\N
129379	10057	649	Ханты-Мансийский автономный округ, Нижневартовск, поселок Тепличный, Заводская, 9	f	\N
129352	10043	640	Ханты-Мансийский автономный округ, Нижневартовск, Дружбы Народов, 14	f	\N
129357	10043	641	Ханты-Мансийский автономный округ, Нижневартовск, Дружбы Народов, 14	f	\N
129342	10035	636	Ханты-Мансийский автономный округ, Нижневартовск, Дружбы Народов, 13Б	f	\N
129339	10035	635	Ханты-Мансийский автономный округ, Нижневартовск, Дружбы Народов, 13Б	f	\N
129334	10034	634	Ханты-Мансийский автономный округ, Нижневартовск, Дружбы Народов, 13А	f	\N
129333	10032	633	Ханты-Мансийский автономный округ, Нижневартовск, Дружбы Народов, 19А	f	\N
129263	10005	610	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 29А	f	\N
129259	10005	609	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 29А	f	\N
129242	9999	603	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 27А	f	\N
129256	9999	608	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 27А	f	\N
129214	9983	594	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 11	f	\N
129209	9980	592	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 17А	f	\N
129213	9980	593	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 17А	f	\N
129207	9979	591	Ханты-Мансийский автономный округ, Нижневартовск, Дзержинского, 17В	f	\N
129390	10065	652	Ханты-Мансийский автономный округ, Нижневартовск, Авиаторов, 4	f	\N
129362	10045	643	Ханты-Мансийский автономный округ, Нижневартовск, 60 лет Октября, 82	f	\N
129360	10045	642	Ханты-Мансийский автономный округ, Нижневартовск, 60 лет Октября, 82	f	\N
129237	9996	601	Ханты-Мансийский автономный округ, Нижневартовск, 60 лет Октября, 11/2	f	\N
129144	9950	570	Ханты-Мансийский автономный округ, Нижневартовск, 60 лет Октября, 6А	f	\N
129398	10070	655	Ханты-Мансийский автономный округ, Нижневартовск, 2П-2, 36	f	\N
128395	9378	205	Ханты-Мансийский автономный округ, Нефтеюганск, 24, СК Факел	t	\N
85736	9394	226	Ханты-Мансийский автономный округ, Нефтеюганск, Мира, 32, Нефтеюганский проф. лицей	f	large
85741	9400	233	Ханты-Мансийский автономный округ, Нефтеюганск, Магистральная, 20, Начальная школадетский сад №4	f	large
85742	9400	234	Ханты-Мансийский автономный округ, Нефтеюганск, Магистральная, 20, Начальная школадетский сад №4	f	large
85738	9396	228	Ханты-Мансийский автономный округ, Нефтеюганск, Жилая, 8к1, ООО Югансктранстепплосервис	f	large
85737	9395	227	Ханты-Мансийский автономный округ, город Нефтеюганск, Жилая, 8к1, ООО Югансктранстеплосервис	f	large
85735	9391	224	Ханты-Мансийский автономный округ, город Нефтеюганск, 9 микрорайон, 35, МОУ СОШ №3	f	large
85734	9391	223	Ханты-Мансийский автономный округ, город Нефтеюганск, 9 микрорайон, 35, МОУ СОШ №3	f	large
85732	9389	221	Ханты-Мансийский автономный округ, Нефтеюганск, 8А микрорайон, 17, МОУ СОШ №17	f	large
85731	9388	220	Ханты-Мансийский автономный округ, Нефтеюганск, 8 микрорайон, Центр доп. образования для детей	f	large
85730	9387	219	Ханты-Мансийский автономный округ, Нефтеюганск, 8 микрорайон, МОУ СОШ №6	f	large
85729	9387	218	Ханты-Мансийский автономный округ, Нефтеюганск, 8 микрорайон, МОУ СОШ №6	f	large
85728	9387	217	Ханты-Мансийский автономный округ, Нефтеюганск, 8 микрорайон, МОУ СОШ №6	f	large
85727	9385	216	Ханты-Мансийский автономный округ, город Нефтеюганск, 7 микрорайон, 31, МОУ СОШ №4	f	large
85726	9385	215	Ханты-Мансийский автономный округ, город Нефтеюганск, 7 микрорайон, 31, МОУ СОШ №4	f	large
85725	9384	214	Ханты-Мансийский автономный округ, Нефтеюганск, 5-й микрорайон, МОУ СОШ №2	f	large
85724	9384	213	Ханты-Мансийский автономный округ, Нефтеюганск, 5-й микрорайон, МОУ СОШ №2	f	large
85723	9383	212	Ханты-Мансийский автономный округ, Нефтеюганск, 3 микрорайон, 17, ЦКиД Строитель	f	large
85722	9382	211	Ханты-Мансийский автономный округ, Нефтеюганск, 3 микрорайон, 17, Центр молодежных инициатив	f	large
85721	9381	210	Ханты-Мансийский автономный округ, Нефтеюганск, 2 микрорайон, МОУ СОШ №5	f	large
85720	9381	209	Ханты-Мансийский автономный округ, Нефтеюганск, 2 микрорайон, МОУ СОШ №5	f	large
129014	9876	527	Ханты-Мансийский автономный округ, Мегион, Нефтеразведочная, 2а	f	\N
85760	9412	252	Ханты-Мансийский автономный округ, город Нефтеюганск, 16А микрорайон, 65, Начальная школа-детский сад №15	f	large
85758	9411	250	Ханты-Мансийский автономный округ, город Нефтеюганск, 16А микрорайон, 84, Лицей №1	f	large
85759	9410	251	Ханты-Мансийский автономный округ, Нефтеюганск, 16А микрорайон, 84, здание №84	f	large
85757	9410	249	Ханты-Мансийский автономный округ, Нефтеюганск, 16А микрорайон, 84, здание №84	f	large
85762	9413	254	Ханты-Мансийский автономный округ, Нефтеюганск, 16 микрорайон, 33, НКИ	f	large
85761	9413	253	Ханты-Мансийский автономный округ, Нефтеюганск, 16 микрорайон, 33, НКИ	f	large
85756	9409	248	Ханты-Мансийский автономный округ, Нефтеюганск, 14 микрорайон, МОУ СОШ №13	f	large
85755	9409	247	Ханты-Мансийский автономный округ, Нефтеюганск, 14 микрорайон, МОУ СОШ №13	f	large
85754	9408	246	Ханты-Мансийский автономный округ, город Нефтеюганск, 14 микрорайон, 1, СК Олимп	f	large
85753	9408	245	Ханты-Мансийский автономный округ, город Нефтеюганск, 14 микрорайон, 1, СК Олимп	f	large
85752	9407	244	Ханты-Мансийский автономный округ, город Нефтеюганск, 13 микрорайон, 68, МОУ СОШ №10	f	large
85751	9407	243	Ханты-Мансийский автономный округ, город Нефтеюганск, 13 микрорайон, 68, МОУ СОШ №10	f	large
85750	9406	242	Ханты-Мансийский автономный округ, Нефтеюганск, 13 микрорайон, Начальная школадетский сад №24	f	large
85749	9406	241	Ханты-Мансийский автономный округ, Нефтеюганск, 13 микрорайон, Начальная школадетский сад №24	f	large
85748	9405	240	Ханты-Мансийский автономный округ, город Нефтеюганск, 12 микрорайон, 60	f	large
85747	9404	239	Ханты-Мансийский автономный округ, город Нефтеюганск, 12 микрорайон, 60, МОУ СОШ №9	f	large
85746	9404	238	Ханты-Мансийский автономный округ, город Нефтеюганск, 12 микрорайон, 60, МОУ СОШ №9	f	large
85745	9403	237	Ханты-Мансийский автономный округ, Нефтеюганск, 12 микрорайон, 26, Департамент градостроительства	f	large
85744	9402	236	Ханты-Мансийский автономный округ, Нефтеюганск, 12 микрорайон, 24, УСО ХМАОЮгры КЦСОН Защита	f	large
85743	9401	235	Ханты-Мансийский автономный округ, Нефтеюганск, 12 микрорайон, 24	f	large
128403	9398	232	Ханты-Мансийский автономный округ, Нефтеюганск, 11 микрорайон, 62, МУК Центр национальных культур	f	\N
128400	9398	231	Ханты-Мансийский автономный округ, Нефтеюганск, 11 микрорайон, 62, МУК Центр национальных культур	f	\N
128398	9392	225	Ханты-Мансийский автономный округ, Нефтеюганск, 10 микрорайон, 14, МЦ Юность	f	medium
85719	9380	208	Ханты-Мансийский автономный округ, Нефтеюганск, 1 микрорайон, 28, МОУ СОШ №1	f	large
85718	9380	207	Ханты-Мансийский автономный округ, Нефтеюганск, 1 микрорайон, 28, МОУ СОШ №1	f	large
85717	9380	206	Ханты-Мансийский автономный округ, Нефтеюганск, 1 микрорайон, 28, МОУ СОШ №1	f	large
85733	9390	222	Ханты-Мансийский автономный округ, город Нефтеюганск, 8А микрорайон, МОУ СОШ №8	f	large
128330	9258	110	Ханты-Мансийский автономный округ, поселок Мулымья, Волгоградская, 33, Дом культуры	t	\N
85647	9243	97	Ханты-Мансийский автономный округ, Междуреченский, Центральная, 54	f	large
85646	9242	96	Ханты-Мансийский автономный округ, Междуреченский, Первомайская, 25	f	large
85649	9245	99	Ханты-Мансийский автономный округ, Междуреченский, Волгоградская, 11	f	large
85648	9244	98	Ханты-Мансийский автономный округ, Междуреченский, Волгоградская, 11	f	large
129027	9882	531	Ханты-Мансийский автономный округ, Мегион, Сутормина, 16/1	f	\N
129028	9882	532	Ханты-Мансийский автономный округ, Мегион, Сутормина, 16/1	f	\N
129020	9877	529	Ханты-Мансийский автономный округ, Мегион, Советская, 19	f	\N
129053	9892	540	Ханты-Мансийский автономный округ, Мегион, Свободы, 30	f	\N
129055	9892	541	Ханты-Мансийский автономный округ, Мегион, Свободы, 30	f	\N
129050	9891	539	Ханты-Мансийский автономный округ, Мегион, Свободы, 6	f	\N
129046	9889	538	Ханты-Мансийский автономный округ, Мегион, Свободы, 6/1	f	\N
129033	9884	533	Ханты-Мансийский автономный округ, Мегион, Проспект Победы, 6	f	\N
129036	9884	534	Ханты-Мансийский автономный округ, Мегион, Проспект Победы, 6	f	\N
129042	9887	536	Ханты-Мансийский автономный округ, Мегион, Нефтяников, 12	f	\N
129045	9887	537	Ханты-Мансийский автономный округ, Мегион, Нефтяников, 12	f	\N
129018	9876	528	Ханты-Мансийский автономный округ, Мегион, Нефтеразведочная, 2а	f	\N
129068	9901	545	Ханты-Мансийский автономный округ, Мегион, Ленина, 48	f	\N
129065	9899	544	Ханты-Мансийский автономный округ, город Мегион, Ленина, 20	f	\N
129061	9896	543	Ханты-Мансийский автономный округ, Мегион, поселок Высокий, Ленина, ж/д станция &quot;&quot;Мегион&quot;&quot;&quot;	f	\N
129059	9895	542	Ханты-Мансийский автономный округ, Мегион, Кузьмина, 3	f	\N
129039	9886	535	Ханты-Мансийский автономный округ, Мегион, Заречная, 16а	f	\N
129023	9880	530	Ханты-Мансийский автономный округ, Мегион, Геологов, 5	f	\N
129072	9905	546	Ханты-Мансийский автономный округ, Мегион, Гагарина, 44	f	\N
128328	9257	109	Ханты-Мансийский автономный округ, Луговой, Первомайский, 1, средняя школа	t	\N
128312	9249	104	Ханты-Мансийский автономный округ, Леуши, Волгоградская, 13, администрация поселения	t	\N
129078	9908	548	Ханты-Мансийский автономный округ, Ларьяк, Гагарина, 14	t	\N
128953	9844	507	Ханты-Мансийский автономный округ, Лангепас, Мира, 28, Гимназия № 6	f	\N
128951	9842	506	Ханты-Мансийский автономный округ, Лангепас, Мира, 28, СОШ № 4	f	\N
128936	9834	501	Ханты-Мансийский автономный округ, Лангепас, Мира, 21, СОШ № 3	f	\N
128933	9834	500	Ханты-Мансийский автономный округ, Лангепас, Мира, 21, СОШ № 3	f	\N
128958	9845	508	Ханты-Мансийский автономный округ, Лангепас, Ленина, 52, Колледж	f	\N
128928	9829	498	Ханты-Мансийский автономный округ, Лангепас, Ленина, 23	f	\N
128961	9847	509	Ханты-Мансийский автономный округ, Лангепас, Дружбы народов, 7, СОШ №5	f	\N
128962	9847	510	Ханты-Мансийский автономный округ, Лангепас, Дружбы народов, 7, СОШ №5	f	\N
128309	9248	103	Ханты-Мансийский автономный округ, Куминский, Почтовая, 43, культурный центр	f	\N
128481	9470	281	Ханты-Мансийский автономный округ, поселок Красноленинский, Обская, 19	t	\N
129074	9906	547	Ханты-Мансийский автономный округ, село Корлики, Дружбы, 14	t	\N
85645	9238	93	Ханты-Мансийский автономный округ, Кондинское, Советская, 11	f	large
128817	9761	461	Ханты-Мансийский автономный округ, Когалым, Янтарная, 11, СОШ №8	f	\N
128820	9761	462	Ханты-Мансийский автономный округ, Когалым, Янтарная, 11, СОШ №8	f	\N
128873	9791	480	Ханты-Мансийский автономный округ, Когалым, Широкая, 5а, ДК Сибирь	f	\N
128865	9786	477	Ханты-Мансийский автономный округ, Когалым, Степана Повха, 13, СОШ №7	f	\N
128862	9786	476	Ханты-Мансийский автономный округ, Когалым, Степана Повха, 13, СОШ №7	f	\N
128854	9781	474	Ханты-Мансийский автономный округ, Когалым, Сопочинского, 10, СЦ Юбилейный	f	\N
128857	9784	475	Ханты-Мансийский автономный округ, Когалым, Сибирская, 11, МКЦ Феникс	f	\N
128833	9770	467	Ханты-Мансийский автономный округ, Когалым, Северная, 1, СОШ №10	f	\N
128838	9770	468	Ханты-Мансийский автономный округ, Когалым, Северная, 1, СОШ №10	f	\N
128879	9795	482	Ханты-Мансийский автономный округ, Когалым, Привокзальная, 27, СОШ №9	f	\N
128877	9793	481	Ханты-Мансийский автономный округ, Когалым, Привокзальная, 27, СОШ№9	f	\N
128839	9774	469	Ханты-Мансийский автономный округ, Когалым, Прибалтийская, 19, СОШ №5	f	\N
128844	9774	470	Ханты-Мансийский автономный округ, Когалым, Прибалтийская, 19, СОШ №5	f	\N
128871	9788	479	Ханты-Мансийский автономный округ, Когалым, Набережная, 55а, СОШ №1	f	\N
128868	9788	478	Ханты-Мансийский автономный округ, Когалым, Набережная, 55а, СОШ №1	f	\N
128846	9775	471	Ханты-Мансийский автономный округ, Когалым, Мира, 17 , Школа искусств	f	\N
128832	9768	466	Ханты-Мансийский автономный округ, Когалым, Дружбы Народов, 10/1	f	\N
128828	9767	465	Ханты-Мансийский автономный округ, Когалым, Дружбы Народов, 10/1, СОШ №3	f	\N
128824	9764	464	Ханты-Мансийский автономный округ, Когалым, Дружбы Народов, 24	f	\N
128823	9762	463	Ханты-Мансийский автономный округ, Когалым, Дружбы Народов, 24, СОШ №8/2	f	\N
128849	9779	472	Ханты-Мансийский автономный округ, Когалым, Бакинская, 29, СОШ №6	f	\N
128852	9779	473	Ханты-Мансийский автономный округ, Когалым, Бакинская, 29, СОШ №6	f	\N
128475	9465	279	Ханты-Мансийский автономный округ, Кедровый, Ленина, 6 В	t	\N
128255	9189	56	Ханты-Мансийский автономный округ, поселок Заречный, Промысловая, 9	t	\N
85606	9101	6	Ханты-Мансийский автономный округ, поселок Березово, Авиаторов, 25	f	large
128201	9137	30	Ханты-Мансийский автономный округ, Белоярский, 39, СУ966	f	small
128200	9136	29	Ханты-Мансийский автономный округ, Белоярский, микрорайон Мирный, 18	f	medium
85614	9131	26	Ханты-Мансийский автономный округ, Белоярский, Школьная, 7	f	large
85615	9132	27	Ханты-Мансийский автономный округ, Белоярский, Центральная, 10	f	large
85612	9129	24	Ханты-Мансийский автономный округ, поселок Белоярский, Центральная, 3	f	large
85609	9126	21	Ханты-Мансийский автономный округ, поселок Белоярский, 3 микрорайон, 27а	f	large
85787	9499	312	Ханты-Мансийский автономный округ, городской округ Сургут, Сургут, проспект Ленина, 68/1	f	large
85740	9397	230	Ханты-Мансийский автономный округ, городской округ Нефтеюганск, Нефтеюганск, 11 микрорайон, МОУ СОШ №7	f	large
85739	9397	229	Ханты-Мансийский автономный округ, городской округ Нефтеюганск, Нефтеюганск, 11 микрорайон, МОУ СОШ №7	f	large
128436	9434	265	Ханты-Мансийский автономный округ, Ханты-Мансийский район, деревня Ярки, Новая, 4	t	\N
128450	9444	270	Ханты-Мансийский автономный округ, Ханты-Мансийский район, деревня Шапша, Молодежная, 1	f	small
128416	9420	258	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Цингалы, Советская, 28	t	\N
128429	9429	263	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Тюли, переулок Дружбы, 7	t	\N
128468	9457	276	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Троица, Молодежная, 4 а	t	\N
128456	9447	272	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Согом, Молодежная, 2	t	\N
128453	9446	271	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Селиярово, Лесная, 8а	f	\N
128424	9426	261	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Реполово, Школьная, 4	t	\N
128442	9438	267	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Пырьях, Набережная, 7	t	\N
128445	9440	268	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Нялинское, Мира, 71	t	\N
128465	9454	275	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Луговской, Гагарина, 2	t	\N
128439	9436	266	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Кышик, Советская, 1	t	\N
128462	9451	274	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Кирпичный, Комсомольская, 12 а	t	\N
128632	9630	400	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Кедровый, Кедровый, 13а	f	\N
128449	9442	269	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Зенково, Набережная, 8	t	\N
128472	9462	278	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Елизарово, переулок Школьный, 1	t	\N
128408	9418	256	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Горноправдинск, Поспелова, 5 Б	f	\N
128412	9418	257	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Горноправдинск, Поспелова, 5 Б	f	\N
128426	9428	262	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Выкатной, Школьная, 4	t	\N
128406	9415	255	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Бобровский, Юбилейная, 14	t	\N
128715	9693	428	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Белый Яр, Островского, 20/1	f	\N
128199	9134	28	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Белый Яр, 1 микрорайон, здание спортивного зала Олимп муниципального учреждения Дворец спорта	f	\N
128730	9705	433	Ханты-Мансийский автономный округ, Ханты-Мансийский район, поселок Белый Яр, Симонова, 1а	f	\N
128734	9706	434	Ханты-Мансийский автономный округ, Ханты-Мансийский район, Белый Яр, Лесная, 17б	f	\N
128458	9450	273	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Белогорье, Мира, 12	t	\N
128419	9422	259	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Батово, Центральная, 50а	t	\N
128433	9432	264	Ханты-Мансийский автономный округ, Ханты-Мансийский район, село Базьяны, Центральная, 36	t	\N
128765	9725	444	Ханты-Мансийский автономный округ, Сургутский район, сельское поселение Нижнесортымский, Северная, 34	f	\N
128752	9718	440	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский, переулок Тюменский, 14	f	\N
128744	9712	437	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский, переулок Парковый , 1	f	\N
128747	9714	438	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский, Строителей, 6	f	\N
128750	9716	439	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский, Савуйская, 13	f	\N
128741	9710	436	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Фёдоровский, Ленина, 17	f	\N
128808	9754	458	Ханты-Мансийский автономный округ, Сургутский район, поселок Ульт-Ягун, 35 лет Победы, 1/1	f	\N
128803	9753	457	Ханты-Мансийский автономный округ, Сургутский район, село Угут, поселок Малоюганский, переулок Угутский, 9	t	\N
128801	9750	456	Ханты-Мансийский автономный округ, Сургутский район, село Угут, Львовская, 26	t	\N
128811	9757	459	Ханты-Мансийский автономный округ, Сургутский район, поселок Тром-Аган, Центральная, 2	t	\N
128790	9742	452	Ханты-Мансийский автономный округ, Сургутский район, село Сытомино, Центральная, 61	t	\N
128785	9739	451	Ханты-Мансийский автономный округ, Сургутский район, поселок Солнечный, Управление по переработке газа	t	\N
128772	9730	447	Ханты-Мансийский автономный округ, Сургутский район, поселок Солнечный, Спортивная, 1а	f	\N
128781	9734	449	Ханты-Мансийский автономный округ, Сургутский район, поселок Солнечный, Космонавтов, 17	f	\N
128775	9733	448	Ханты-Мансийский автономный округ, Сургутский район, поселок Солнечный, Зои Космодемьянской, 19	f	\N
128784	9737	450	Ханты-Мансийский автономный округ, Сургутский район, деревня Сайгатина, Центральная, 24	t	\N
128796	9746	454	Ханты-Мансийский автономный округ, Сургутский район, деревня Русскинская, Ветеранов, 16	t	\N
128768	9727	445	Ханты-Мансийский автономный округ, Сургутский район, Нижнесортымский, Нефтяников, 7а	f	\N
128770	9729	446	Ханты-Мансийский автономный округ, Сургутский район, поселок Нижнесортымский, Хусаинова, 1	f	\N
128707	9686	425	Ханты-Мансийский автономный округ, Сургутский район, город Лянтор, микрорайон №7, Лянторская СОШ №4	f	\N
128711	9688	426	Ханты-Мансийский автономный округ, Сургутский район, Лянтор, микрорайон №6, микрорайон №6, ГДМ Строитель, холл 1 этажа	f	\N
128690	9672	419	Ханты-Мансийский автономный округ, Сургутский район, Лянтор, микрорайон №6, Лянторская СОШ №6, холл 1 этажа	f	\N
128680	9665	416	Ханты-Мансийский автономный округ, Сургутский район, город Лянтор, микрорайон №4, ДК Юбилейный, холл 1 этажа	f	\N
128684	9666	417	Ханты-Мансийский автономный округ, Сургутский район, город Лянтор, микрорайон №4, ДК Юбилейный, холл 2 этажа	f	\N
128703	9669	424	Ханты-Мансийский автономный округ, Сургутский район, город Лянтор, микрорайон №3, Лянторская СОШ №3	f	\N
128698	9678	422	Ханты-Мансийский автономный округ, Сургутский район, Лянтор, микрорайон №2, администрация г.Лянтор	f	\N
128687	9670	418	Ханты-Мансийский автономный округ, Сургутский район, Лянтор, микрорайон №2, Лянторская СОШ №7, холл 1 этажа	f	\N
128692	9675	420	Ханты-Мансийский автономный округ, Сургутский район, Лянтор, микрорайон №10, Лянторский нефтяной техникум	f	\N
128702	9681	423	Ханты-Мансийский автономный округ, Сургутский район, город Лянтор, микрорайон №1, Детско-юношеская спортивная школа	f	\N
128694	9676	421	Ханты-Мансийский автономный округ, Сургутский район, город Лянтор, микрорайон №1, Лянторская СОШ №1, актовый зал	f	\N
128678	9662	415	Ханты-Мансийский автономный округ, Сургутский район, город Лянтор, Набережная, 13	f	\N
128798	9749	455	Ханты-Мансийский автономный округ, Сургутский район, село Локосово, Центральная, 44	t	\N
128793	9745	453	Ханты-Мансийский автономный округ, Сургутский район, поселок Лемпино, Центральная, 13	t	\N
128353	9318	163	Ханты-Мансийский автономный округ, Сургутский район, поселок Лемпино, Солнечная, 1, ДК Праздник	t	\N
128814	9759	460	Ханты-Мансийский автономный округ, Сургутский район, поселок Высокий Мыс, Советская, 30А	t	\N
128723	9696	430	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр, микрорайон №1, Центр дополнительного образования	f	\N
128736	9708	435	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр, Маяковского, 11А	f	\N
128729	9703	432	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр, Лесная, 9/1	f	\N
128714	9691	427	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Белый Яр, Ермака, 4б	f	\N
128719	9694	429	Ханты-Мансийский автономный округ, Сургутский район, поселок Белый Яр, Островского, 20	f	\N
128726	9700	431	Ханты-Мансийский автономный округ, Сургутский район, поселок Белый Яр, Лесная, 8б	f	\N
128760	9723	443	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Барсово, Мостостроителей, 9	f	\N
128757	9723	442	Ханты-Мансийский автономный округ, Сургутский район, поселок городского типа Барсово, Мостостроителей, 9	f	\N
85681	9303	150	Ханты-Мансийский автономный округ, Советский район, сельское поселение Алябьевский, Ленина, 3а	f	large
85682	9304	151	Ханты-Мансийский автономный округ, Советский район, городское поселение Таежный, Железнодорожная, 15	f	large
85675	9296	143	Ханты-Мансийский автономный округ, Советский район, городское поселение Советский, Юности, 12	f	large
128347	9302	149	Ханты-Мансийский автономный округ, Советский район, городское поселение Малиновский, Советская, 8а	f	medium
85680	9301	148	Ханты-Мансийский автономный округ, Советский район, городское поселение Малиновский, Кузнецова, 18	f	large
128346	9285	135	Ханты-Мансийский автономный округ, Советский район, городское поселение Коммунистический, Матросова, 9	f	\N
85667	9284	134	Ханты-Мансийский автономный округ, Советский район, городское поселение Агириш, Дзержинского, 16	f	large
85676	9297	144	Ханты-Мансийский автономный округ, Советский район, Советский, Мира, 28	f	large
85670	9290	138	Ханты-Мансийский автономный округ, Советский район, поселок Советский, Ленина, 14	f	large
85669	9289	137	Ханты-Мансийский автономный округ, Советский район, Советский, Ленина, 45	f	large
85678	9299	146	Ханты-Мансийский автономный округ, Советский район, поселок Пионерский, Ленина, 27	f	large
85679	9300	147	Ханты-Мансийский автономный округ, Комсомольская, 8	f	large
85668	9288	136	Ханты-Мансийский автономный округ, Советский район, Зеленоборск, Политехническая улица, 18	f	large
128220	9153	39	Ханты-Мансийский автономный округ, Октябрьский район, п. Кормужиханка, Гагарина, 6	t	\N
128257	9192	57	Ханты-Мансийский автономный округ, Октябрьский район, п. Комсомольский, Октябрьская, 7, помещение сельского дома культуры	t	\N
128245	9184	53	Ханты-Мансийский автономный округ, Октябрьский район, п. Горнореченск, Речная, 34	t	\N
128227	9165	45	Ханты-Мансийский автономный округ, Октябрьский район, Шеркалы, микрорайон ВРЗ, Мира, 34А, Сельский Дом Культуры Триумф	t	\N
128269	9200	61	Ханты-Мансийский автономный округ, Октябрьский район, поселок Унъюган, 30 лет Победы, 14, МКУ Дом культуры Лесник	f	\N
85618	9159	41	Ханты-Мансийский автономный округ, Октябрьский район, поселок Приобье, Газовиков, 25, помещение КСК ХАРД	f	large
128234	9171	47	Ханты-Мансийский автономный округ, Октябрьский район, поселок Перегребное, Советская, 9, помещение КСК Феерия	f	\N
128239	9177	49	Ханты-Мансийский автономный округ, Октябрьский район, деревня Нижние Нарыкары, переулок Клубный, 2А, ДК	t	\N
128248	9186	54	Ханты-Мансийский автономный округ, Октябрьский район, поселок Малый Алтым, Зеленый переулок, 2	t	\N
128242	9181	52	Ханты-Мансийский автономный округ, Октябрьский район, Карымкары, Ленина, 18, здание администрации поселения	t	\N
128263	9196	59	Ханты-Мансийский автономный округ, Октябрьский район, поселок Каменное, Центральная, 6, помещение сельского клуба	t	\N
128251	9187	55	Ханты-Мансийский автономный округ, Октябрьский район, поселок Большой Атлым, Школьная, 32	t	\N
128262	9194	58	Ханты-Мансийский автономный округ, Октябрьский район, поселок Большие Леуши, Центральная, 28	t	\N
128224	9157	40	Ханты-Мансийский автономный округ, Октябрьский район, поселок Андра, 18, КСК Прометей	t	\N
129094	9922	554	Ханты-Мансийский автономный округ, Нижневартовский район, Покур, Центральная, 76	t	\N
128893	9810	487	Ханты-Мансийский автономный округ, Нижневартовский район, Покачи, Таежная, 19, КСК &amp;quot;&amp;quot;Нефтяник&amp;quot;&amp;quot;&amp;quot;	f	\N
128882	9796	483	Ханты-Мансийский автономный округ, Нижневартовский район, Покачи, Молодежная, 16, Ледовый Дворец Кристалл	f	\N
128898	9812	488	Ханты-Мансийский автономный округ, Нижневартовский район, Покачи, Мира, 7/1, ФОК Сибиряк	f	\N
128890	9805	486	Ханты-Мансийский автономный округ, Нижневартовский район, Покачи, Мира, 9, МОУ &quot;&quot;СОШ №2&quot;&quot;&quot;	f	\N
128889	9802	485	Ханты-Мансийский автономный округ, Нижневартовский район, Покачи, Мира, 9, МОУ СОШ №2	f	\N
128902	9818	490	Ханты-Мансийский автономный округ, Нижневартовский район, Покачи, Ленина, 10, СОШ №4 (правая часть здания)	f	\N
128900	9815	489	Ханты-Мансийский автономный округ, Нижневартовский район, Покачи, Ленина, 10, СОШ №4 левая часть здания	f	\N
129131	9942	566	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск, Центральная, 15б	f	\N
129135	9944	567	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск, Мелик Карамова, 16	f	\N
129129	9940	565	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск, Мелик Карамова, 5а	f	\N
129136	9945	568	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Новоаганск, 70 лет Октября, 6а	f	\N
128664	9653	411	Ханты-Мансийский автономный округ, Нижневартовский район, поселок Мостоотряд № 95, общежитие Мостострой 11	f	\N
128930	9830	499	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Солнечная, 17 А   , Фортуна	f	\N
128922	9826	496	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Парковая, 13 Б , СОШ № 2	f	\N
128924	9826	497	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Парковая, 13 Б , СОШ № 2	f	\N
128918	9824	495	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Парковая, 13Б,  СОШ № 2	f	\N
128914	9822	494	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Парковая, 3, СОШ № 1	f	\N
128909	9822	492	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Парковая, 3, СОШ № 1	f	\N
128913	9822	493	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Парковая, 3, СОШ № 1	f	\N
128948	9840	505	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Мира, 28, СОШ № 4	f	\N
128944	9840	504	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Мира, 28, СОШ № 4	f	\N
128965	9850	511	Ханты-Мансийский автономный округ, Нижневартовский район, Лангепас, Ленина, 45, Музейновыставочный центр	f	\N
128943	9837	503	Ханты-Мансийский автономный округ, Нижневартовский район, город Лангепас, Комсомольская, 3 Д, &amp;quot;&amp;quot;Патриот&amp;quot;&amp;quot;&amp;quot;	f	\N
128939	9837	502	Ханты-Мансийский автономный округ, Нижневартовский район, город Лангепас, Комсомольская, 3 Д, &amp;quot;&amp;quot;Патриот&amp;quot;&amp;quot;&amp;quot;	f	\N
129114	9933	560	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, переулок Молодёжный, 3	f	\N
129116	9933	561	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, переулок Молодёжный, 3	f	\N
129100	9925	556	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, Энергетиков, 2	f	\N
129120	9930	562	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, Школьная, 7	f	\N
129109	9930	559	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, Школьная, 7	f	\N
129105	9927	557	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, Школьная, 5	f	\N
129108	9927	558	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, Школьная, 5	f	\N
129126	9937	564	Ханты-Мансийский автономный округ, Нижневартовский район, поселок городского типа Излучинск, Лесная, 13	f	\N
129121	9936	563	Ханты-Мансийский автономный округ, Нижневартовский район, поселок Излучинск, Савкинская, 29	f	\N
129092	9920	553	Ханты-Мансийский автономный округ, Нижневартовский район, поселок Зайцева Речка, Центральная, 3	t	\N
129082	9913	550	Ханты-Мансийский автономный округ, Нижневартовский район, Ваховск, Таежная, 4	t	\N
129079	9912	549	Ханты-Мансийский автономный округ, Нижневартовский район, Ваховск, поселок Охтеурье, Летная, 20	t	\N
129089	9918	552	Ханты-Мансийский автономный округ, Нижневартовский район, село Вата, Центральная, 15	t	\N
129141	9948	569	Ханты-Мансийский автономный округ, Нижневартовский район, село Варьёган, Центральная, 21	t	\N
129098	9924	555	Ханты-Мансийский автономный округ, Нижневартовский район, село Вампугол, Зырянова, 13	t	\N
129086	9915	551	Ханты-Мансийский автономный округ, Нижневартовский район, село Аган, Новая, 16	t	\N
78247	5721	1090	Тюменская область, Ялуторовск, Кармелюка, 11	f	large
128371	9341	179	Ханты-Мансийский автономный округ, Нефтеюганский район, п. КС5, 8, Спорткомплекс	t	\N
128364	9337	177	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Юганская Обь, Тобольская, 25, ДК Гармония	t	\N
128372	9343	180	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Чеускино, Центральная, 8, Здание администрации	f	\N
128361	9334	176	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Усть-Юган, 5, Здание администрации	t	\N
128357	9332	175	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Усть-Юган, квартал 21, 40, Средняя школа	t	\N
128376	9346	181	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Сингапай, Центральная, 31, ДК Камертон	t	\N
128385	9356	186	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Сивыс-Ях, Новая, 2а, Начальная школа	t	\N
128366	9338	178	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Сентябрьский, Строение 65, Средняя школа	f	\N
85701	9350	183	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Салым, Привокзальная, 16, Средняя школа N 2	f	large
85702	9354	185	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Салым, Новая, 13, Средняя школа N 1	f	large
85708	9367	194	Ханты-Мансийский автономный округ, Нефтеюганский район, Пыть-Ях, Советская, 34, МОУ СОШ № 3	f	large
85715	9374	203	Ханты-Мансийский автономный округ, Нефтеюганский район, Пыть-Ях, Обская, 19, Дворовый клуб Черемушки	f	large
128394	9373	202	Ханты-Мансийский автономный округ, Нефтеюганский район, Пыть-Ях, Магистральная, 22, ООО УТТ Ространссервис	f	medium
128393	9370	198	Ханты-Мансийский автономный округ, Нефтеюганский район, Пыть-Ях, 7 микрорайон, Д/сад Аистенок ОАО ЮБ ГПК	f	medium
85710	9368	196	Ханты-Мансийский автономный округ, Нефтеюганский район, город Пыть-Ях, 5 микрорайон,, 5А, МОУ СОШ №, 5	f	large
85709	9368	195	Ханты-Мансийский автономный округ, Нефтеюганский район, город Пыть-Ях, 5 микрорайон,, 5А, МОУ СОШ №, 5	f	large
85716	9375	204	Ханты-Мансийский автономный округ, Нефтеюганский район, Пыть-Ях, 10 микрорайон Мамонтово, 50, МОУ ДОД ДЮСШ АйкидоРеал	f	large
85693	9320	165	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок городского типа Пойковский, Микрорайон 1, 37, Средняя школа N, 2 	f	large
128354	9320	164	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок городского типа Пойковский, Микрорайон 1, 37, Средняя школа N, 2 	f	medium
128355	9328	172	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок городского типа Пойковский, Байкальская, строение 15, ДК Байкал	f	medium
128356	9329	173	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, Шестая, 6, спортзал Сибиряк СОК Ермак	f	medium
85700	9330	174	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, Пятая, 5, ЛД Нефтяник	f	large
85699	9327	171	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, Промзона, 13А, ООО Энергонефть	f	large
85696	9323	168	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, Микрорайон 7, 93а, СОК Нептун	f	large
85694	9321	166	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, Микрорайон 5, 1, Средняя школа № 4	f	large
85695	9322	167	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, Микрорайон 4, 14, Средняя школа N, 1	f	large
85697	9325	169	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, Микрорайон 1, 112, ЦКиД Родник	f	large
85698	9326	170	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Пойковский, 3-й микрорайон, 13/14, Библиотека	f	large
128387	9358	187	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Куть-Ях, 7в, Средняя школа	t	\N
128392	9360	188	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Куть-Ях, Молодежная,  17, СК &quot;&quot;Лидер&quot;&quot;&quot;	t	\N
128378	9347	182	Ханты-Мансийский автономный округ, Нефтеюганский район, поселок Каркатеевский, Центральная, 17, КСК Ника	t	\N
128383	9353	184	Ханты-Мансийский автономный округ, Нефтеюганский район, КС-6, Самсоновское ЛПУ, Клуб	t	\N
128338	9262	113	Ханты-Мансийский автономный округ, Кондинский район, деревня Ушья , Мелитопольская, 5А, Дом культуры	t	\N
78242	5715	1084	Тюменская область, Ялуторовск, Железнодорожная, 8	f	large
128305	9247	102	Ханты-Мансийский автономный округ, Кондинский район, Поселок городского типа Мортка, Борисова, 5, средняя школа	f	\N
128302	9247	101	Ханты-Мансийский автономный округ, Кондинский район, Поселок городского типа Мортка, Борисова, 5, средняя школа	f	\N
128301	9246	100	Ханты-Мансийский автономный округ, Кондинский район, Поселок городского типа Междуреченский, Строителей, 17, ЦМИ Ориентир	f	medium
128325	9256	108	Ханты-Мансийский автономный округ, Кондинский район, Половинка, Комсомольская , 9А, Дом культуры	t	\N
128316	9250	105	Ханты-Мансийский автономный округ, Кондинский район, поселок Лиственичный, Центральная, 1, Дом культуры	t	\N
128283	9231	88	Ханты-Мансийский автономный округ, Кондинский район, село Кама, Ленина, 18 , Дом культуры	t	\N
128321	9255	107	Ханты-Мансийский автономный округ, Кондинский район, поселок Дальний, Центральная, 17, Дом культуры	t	\N
128290	9111	90	Ханты-Мансийский автономный округ, Кондинский район, село Болчары, Ленина, 49 , Сельский центр культуры	t	\N
128286	9233	89	Ханты-Мансийский автономный округ, Кондинский район, село Алтай, Ленина, 23А, Дом культуры	t	\N
128333	9259	111	Ханты-Мансийский автономный округ, Кодинский район, поселок Назарово, Центральная, 11, Дом культуры	t	\N
128163	9098	4	Ханты-Мансийский автономный округ, Березовский район, с.Теги, Таежная, 8, Здание средней школы	t	\N
128178	9112	14	Ханты-Мансийский автономный округ, Березовский район, п.Хулимсунт, мкр.3, 23, Здание администрации поселения	t	\N
128185	9118	17	Ханты-Мансийский автономный округ, Березовский район, п.Приполярный, мкр.4, 4А, Здание КСК	t	\N
128194	9124	20	Ханты-Мансийский автономный округ, Березовский район, поселок Сосьева, Школьная, 3, здание средней школы	t	\N
85604	9095	1	Ханты-Мансийский автономный округ, Березовский район, Поселок городского типа Березово, .Газопромысловая, 12, Здание администрации поселения	f	large
128181	9114	15	Ханты-Мансийский автономный округ, Березовский район, поселок Няксимволь, Советская, 10, Здание Дома культуры	t	\N
128166	9103	10	Ханты-Мансийский автономный округ, Березовский район, Игрим, Королева, 3, Здание Дома культуры	f	medium
128165	9103	9	Ханты-Мансийский автономный округ, Березовский район, Игрим, Королева, 3, Здание Дома культуры	f	medium
128170	9106	12	Ханты-Мансийский автономный округ, Березовский район, Игрим, Кооперативная, 31, Здание средней школы №1	f	\N
128169	9106	11	Ханты-Мансийский автономный округ, Березовский район, Игрим, Кооперативная, 31, Здание средней школы №1	f	\N
85608	9102	8	Ханты-Мансийский автономный округ, Березовский район, поселок Игрим, Кооперативная, 15	f	large
85607	9102	7	Ханты-Мансийский автономный округ, Березовский район, поселок Игрим, Кооперативная, 15	f	large
128173	9109	13	Ханты-Мансийский автономный округ, Березовский район, поселок Ванзетур, Центральная, 28, Здание Дома культуры	t	\N
128160	9097	3	Ханты-Мансийский автономный округ, Березовский район, Березово, Собянина, 50, Здание средней школы	f	medium
128164	9100	5	Ханты-Мансийский автономный округ, Березово, Астраханцева, 102, Здание столовой аэропорта	f	medium
128218	9150	36	Ханты-Мансийский автономный округ, Белоярский район, сельское поселение Казым, Каксина, 10	t	\N
128216	9147	35	Ханты-Мансийский автономный округ, Белоярский район, поселок Полноват, Советская, 24	t	\N
128202	9140	31	Ханты-Мансийский автономный округ, Белоярский район, село Лыхма, ЛПУ, 92/2	t	\N
128206	9142	32	Ханты-Мансийский автономный округ, Белоярский район, поселок Верхнеказымский, 3 микрорайон, 15	t	\N
78250	5726	1095	Тюменская область, Ялуторовск, Свободы, 195	f	large
78249	5725	1094	Тюменская область, Ялуторовск, Свободы, 193	f	large
78252	5728	1097	Тюменская область, Ялуторовск, Революции, 186	t	large
78246	5720	1089	Тюменская область, Ялуторовск, Революции, 96	f	large
78244	5677	1092	Тюменская область, Ялуторовск, Революции, 44	f	large
78267	5719	1088	Тюменская область, Ялуторовск, О.Кошевого, 2	t	large
78243	5716	1085	Тюменская область, Ялуторовск, Новикова, 19	f	large
78245	5724	1093	Тюменская область, Ялуторовск, Ленина, 48	f	large
78265	5717	1086	Тюменская область, Ялуторовск, Красноармейская, 40	f	large
78241	5713	1082	Тюменская область, Ялуторовск, Комсомольская, 63	f	large
78239	5711	1080	Тюменская область, Ялуторовск, Комсомольская, 13	f	large
78251	5727	1096	Тюменская область, Ялуторовск, Бахтиярова, 53	f	large
78248	5722	1091	Тюменская область, Ялуторовск, 50 лет Октября, 4	f	large
78034	5424	739	Тюменская область, Тюмень, улица Широтная, 115	f	large
78033	5424	738	Тюменская область, Тюмень, улица Широтная, 115	f	large
78216	5584	949	Тюменская область, Тюмень, улица Холодильная, 78	f	large
78215	5584	948	Тюменская область, Тюмень, улица Холодильная, 78	f	large
78164	5544	892	Тюменская область, Тюмень, поселок Матмасы, улица Строителей, 25	f	large
78044	5430	749	Тюменская область, Тюмень, улица Пермякова, 46	f	large
78214	5583	947	Тюменская область, Тюмень, улица Мельничная, 1	f	large
127399	5497	833	Тюменская область, Тюмень, деревня Плеханово, улица Ковалева, 9	f	medium
77995	5366	668	Тюменская область, Тюмень, улица Источник, 93А	f	large
78057	5439	764	Тюменская область, Тюмень, улица Герцена, 80	f	large
78118	5506	841	Тюменская область, Тюмень, улица Геологоразведчиков, 14	f	large
78117	5505	840	Тюменская область, Тюмень, улица Геологоразведчиков, 6а	f	large
78210	5579	943	Тюменская область, Тюмень, улица Борцов Октября, 3	f	large
78284	5533	877	Тюменская область, Тюмень, Ленинский район, микрорайон Лесной, 12к2	f	large
127388	5437	762	Тюменская область, Тюмень, Ялуторовская, 13	f	medium
78172	5551	902	Тюменская область, Тюмень, Юганский проезд, 6	f	large
78171	5551	901	Тюменская область, Тюмень, Юганский проезд, 6	f	large
127407	5551	903	Тюменская область, Тюмень, Юганский проезд, 6	f	\N
78010	5410	715	Тюменская область, Тюмень, Энергостроителей, 4	f	large
78009	5410	714	Тюменская область, Тюмень, Энергостроителей, 4	f	large
78131	5516	854	Тюменская область, Тюмень, Энергетиков, 36	f	large
78130	5515	853	Тюменская область, Тюмень, Энергетиков, 45	f	large
78128	5513	851	Тюменская область, Тюмень, Энергетиков, 44	f	large
78195	5567	928	Тюменская область, Тюмень, Щербакова, 94	f	large
78194	5567	927	Тюменская область, Тюмень, Щербакова, 94	f	large
78113	5499	835	Тюменская область, Тюмень, Школьная, 9А	f	large
78176	5553	907	Тюменская область, Тюмень, Шишкова, 15	f	large
78175	5553	906	Тюменская область, Тюмень, Шишкова, 15	f	large
78174	5553	905	Тюменская область, Тюмень, Шишкова, 15	f	large
78027	5422	732	Тюменская область, Тюмень, Широтная, 102	f	large
78024	5419	729	Тюменская область, Тюмень, Широтная, 116	f	large
78023	5419	728	Тюменская область, Тюмень, Широтная, 116	f	large
78022	5418	727	Тюменская область, Тюмень, Широтная, 114/1	f	large
78170	5550	900	Тюменская область, Тюмень, Шаимский проезд, 8а	f	large
78169	5550	899	Тюменская область, Тюмень, Шаимский проезд, 8а	f	large
78168	5550	898	Тюменская область, Тюмень, Шаимский проезд, 8а	f	large
78283	5481	815	Тюменская область, Тюмень, Калининский район, Червишевский тракт, 72	f	large
78099	5483	817	Тюменская область, Тюмень, Червишевский тракт, 15/1	f	large
127395	5479	814	Тюменская область, Тюмень, Червишевский тракт, 29	f	medium
78097	5479	813	Тюменская область, Тюмень, Червишевский тракт, 29	f	large
78098	5482	816	Тюменская область, Тюмень, Червишевский тракт, 13	f	large
127403	5536	881	Тюменская область, Тюмень, Чекистов, 42	f	medium
78212	5581	945	Тюменская область, Тюмень, Циолковского, 1	f	large
78220	5589	955	Тюменская область, Тюмень, Хохрякова, 88	f	large
127410	5586	951	Тюменская область, Тюмень, Холодильная, 120а	f	medium
78116	5502	838	Тюменская область, Тюмень, Холодильная, 81	f	large
78207	5577	940	Тюменская область, Тюмень, Харьковская, 48	f	large
78045	5431	750	Тюменская область, Тюмень, Федорова, 3	f	large
78046	5431	751	Тюменская область, Тюмень, Федорова, 3	f	large
78064	5447	772	Тюменская область, Тюмень, Уральская, 60	f	large
78281	5474	806	Тюменская область, Тюмень, Транспортная, 106	f	large
127406	5547	895	Тюменская область, Тюмень, Тобольский тракт, 24	f	small
78183	5559	914	Тюменская область, Тюмень, Тимуровцев, 32	f	large
78012	5412	717	Тюменская область, Тюмень, Таллинская, 1	f	large
78074	5454	782	Тюменская область, Тюмень, Таврическая, 2	f	large
78025	5420	730	Тюменская область, Тюмень, Суходольская, 15	f	large
78142	5527	867	Тюменская область, Тюмень, Судостроителей, 19/2	f	large
78163	5542	891	Тюменская область, Тюмень, Судоремонтная, 25	f	large
78162	5542	890	Тюменская область, Тюмень, Судоремонтная, 25	f	large
78161	5542	889	Тюменская область, Тюмень, Судоремонтная, 25	f	large
78159	5540	887	Тюменская область, Тюмень, Судоремонтная, 1А	f	large
78158	5540	886	Тюменская область, Тюмень, Судоремонтная, 1А	f	large
78013	5413	718	Тюменская область, Тюмень, Станционная, 34	f	large
78011	5411	716	Тюменская область, Тюмень, Станционная, 26	f	large
78103	5488	822	Тюменская область, Тюмень, Ставропольская, 1в	f	large
78102	5487	821	Тюменская область, Тюмень, Ставропольская, 11а корп., 1	f	large
127396	5486	820	Тюменская область, Тюмень, Ставропольская, 5к2	f	medium
78108	5493	828	Тюменская область, Тюмень, Союзная, 135а	f	large
78107	5493	827	Тюменская область, Тюмень, Союзная, 135а	f	large
78106	5493	826	Тюменская область, Тюмень, Союзная, 135а	f	large
127372	5391	693	Тюменская область, Тюмень, Советская, 21а	t	small
78209	5578	942	Тюменская область, Тюмень, Северная, 3	f	large
78208	5578	941	Тюменская область, Тюмень, Северная, 3	f	large
78101	5484	819	Тюменская область, Тюмень, Самарцева, 28	f	large
78100	5484	818	Тюменская область, Тюмень, Самарцева, 28	f	large
78072	5452	780	Тюменская область, Тюмень, Садовая, 121	f	large
78071	5452	779	Тюменская область, Тюмень, Садовая, 121	f	large
78070	5451	778	Тюменская область, Тюмень, Садовая, 109	f	large
78069	5451	777	Тюменская область, Тюмень, Садовая, 109	f	large
78068	5450	776	Тюменская область, Тюмень, Садовая, 64	f	large
127393	5462	790	Тюменская область, Тюмень, Рылеева, 34	f	medium
78061	5443	768	Тюменская область, Тюмень, Розы Люксембург, 12	f	large
78127	5512	850	Тюменская область, Тюмень, Рижская, 73	f	large
78126	5512	849	Тюменская область, Тюмень, Рижская, 73	f	large
78232	5600	970	Тюменская область, Тюмень, Республики, 19	f	large
78229	5597	966	Тюменская область, Тюмень, Республики, 47	f	large
78218	5587	952	Тюменская область, Тюмень, Республики, 83	f	large
78217	5585	950	Тюменская область, Тюмень, Республики, 129	f	large
78154	5535	880	Тюменская область, Тюмень, Республики, 206А	f	large
78153	5535	879	Тюменская область, Тюмень, Республики, 206А	f	large
78152	5534	878	Тюменская область, Тюмень, улица Республики, 237	f	large
78110	5494	830	Тюменская область, Тюмень, Революции, 199	f	large
78109	5494	829	Тюменская область, Тюмень, Революции, 199	f	large
127385	5407	711	Тюменская область, Тюмень, Ратная, здание Военторга	t	small
78227	5596	964	Тюменская область, Тюмень, Профсоюзная, 46	f	large
127412	5596	965	Тюменская область, Тюмень, Профсоюзная, 46	f	\N
78132	5517	855	Тюменская область, Тюмень, Пржевальского, 54	f	large
78184	5560	915	Тюменская область, Тюмень, Пирогова, 3	f	large
78123	5510	846	Тюменская область, Тюмень, Пермякова, 3	f	large
78122	5509	845	Тюменская область, Тюмень, Пермякова, 40	f	large
78121	5509	844	Тюменская область, Тюмень, Пермякова, 40	f	large
78043	5429	748	Тюменская область, Тюмень, Пермякова, 37	f	large
78042	5428	747	Тюменская область, Тюмень, Пермякова, 39А	f	large
78041	5428	746	Тюменская область, Тюмень, Пермякова, 39А	f	large
78040	5428	745	Тюменская область, Тюмень, Пермякова, 39А	f	large
78228	5599	968	Тюменская область, Тюмень, Первомайская, 3	f	large
78231	5599	969	Тюменская область, Тюмень, Первомайская, 3	f	large
78060	5442	767	Тюменская область, Тюмень, Первомайская, 55	f	large
78096	5477	812	Тюменская область, Тюмень, Пархоменко, 60	f	large
78095	5477	811	Тюменская область, Тюмень, Пархоменко, 60	f	large
78211	5580	944	Тюменская область, Тюмень, Пароходская, 31	f	large
78186	5561	917	Тюменская область, Тюмень, Павлова, 8	f	large
78185	5561	916	Тюменская область, Тюмень, Павлова, 8	f	large
78230	5598	967	Тюменская область, Тюмень, Осипенко, 2	f	large
78226	5595	963	Тюменская область, Тюмень, Орджоникидзе, 49	f	large
127411	5594	962	Тюменская область, Тюмень, Орджоникидзе, 59	f	medium
78038	5157	743	Тюменская область, Тюмень, Олимпийская, 20	f	large
78141	5526	866	Тюменская область, Тюмень, Одесская, 9	f	large
78133	5518	856	Тюменская область, Тюмень, Одесская, 54	f	large
78280	5464	793	Тюменская область, Тюмень, Новоселов, 1а	f	large
78080	5463	792	Тюменская область, Тюмень, Новоселов, 10	f	large
78079	5463	791	Тюменская область, Тюмень, Новоселов, 10	f	large
78177	5554	908	Тюменская область, Тюмень, Новая, 1А	f	large
78029	5421	734	Тюменская область, Тюмень, Николая Гондатти, 13	f	large
78028	5421	733	Тюменская область, Тюмень, Николая Гондатти, 13	f	large
78026	5421	731	Тюменская область, Тюмень, Николая Гондатти, 13	f	large
127408	5562	918	Тюменская область, Тюмень, Мусы Джалиля, 13	f	medium
78222	5590	957	Тюменская область, Тюмень, Мурманская, 31	f	large
78221	5590	956	Тюменская область, Тюмень, Мурманская, 31	f	large
78021	5417	726	Тюменская область, Тюмень, Моторостроителей, 6	f	large
78020	5417	725	Тюменская область, Тюмень, Моторостроителей, 6	f	large
78019	5417	724	Тюменская область, Тюмень, Моторостроителей, 6	f	large
78018	5416	723	Тюменская область, Тюмень, Моторостроителей, 6	f	large
78017	5416	722	Тюменская область, Тюмень, Моторостроителей, 6	f	large
78016	5415	721	Тюменская область, Тюмень, Моторостроителей, 2б	f	large
78092	5476	810	Тюменская область, Тюмень, Московский тракт, 137 корп., 2	f	large
78094	5475	809	Тюменская область, Тюмень, Московский тракт, 129/1	f	large
78093	5475	808	Тюменская область, Тюмень, Московский тракт, 129/1	f	large
78282	5475	807	Тюменская область, Тюмень, Московский тракт, 129/1	f	large
127394	5473	805	Тюменская область, Тюмень, Московский тракт, 22	f	medium
78091	5473	804	Тюменская область, Тюмень, Московский тракт, 22	f	large
78084	5467	797	Тюменская область, Тюмень, Московский тракт, 104	f	large
78083	5467	796	Тюменская область, Тюмень, Московский тракт, 104	f	large
78032	5423	737	Тюменская область, Тюмень, Монтажников, 10	f	large
78031	5423	736	Тюменская область, Тюмень, Монтажников, 10	f	large
78030	5423	735	Тюменская область, Тюмень, Монтажников, 10	f	large
78104	5489	823	Тюменская область, Тюмень, Молодежная, 81	f	large
78179	5556	910	Тюменская область, Тюмень, Мира, 1	f	large
78088	5470	801	Тюменская область, Тюмень, Мира, 14	f	large
78087	5470	800	Тюменская область, Тюмень, Мира, 14	f	large
78205	5575	938	Тюменская область, Тюмень, Минская, 9б	f	large
78112	5498	834	Тюменская область, Тюмень, Метелева	t	large
78224	5591	958	Тюменская область, Тюмень, Мельничная, 80	f	large
78206	5576	939	Тюменская область, Тюмень, Мельникайте, 42	f	large
78202	5573	935	Тюменская область, Тюмень, Мельникайте, 48	f	large
78140	5525	865	Тюменская область, Тюмень, Мельникайте, 61б	f	large
78135	5521	860	Тюменская область, Тюмень, Мельникайте, 74	f	large
78067	5449	775	Тюменская область, Тюмень, Мельзаводская, 19	f	large
78180	5557	911	Тюменская область, Тюмень, Мелиораторов, 15	f	large
78197	5569	930	Тюменская область, Тюмень, Маяковского, 10	f	large
78165	5546	894	Тюменская область, Тюмень, Малышева, 26	f	large
78286	5593	961	Тюменская область, Тюмень, Малыгина, 8/1	f	large
78285	5593	960	Тюменская область, Тюмень, Малыгина, 8/1	f	large
78086	5469	799	Тюменская область, Тюмень, Магнитогорская, 11	f	large
78085	5468	798	Тюменская область, Тюмень, Магнитогорская, 11	f	large
78066	5448	774	Тюменская область, Тюмень, Луначарского, 40	f	large
78065	5448	773	Тюменская область, Тюмень, Луначарского, 40	f	large
78063	5446	771	Тюменская область, Тюмень, Луначарского, 14	f	large
78062	5445	770	Тюменская область, Тюмень, Луначарского, 19	f	large
127390	5444	769	Тюменская область, Тюмень, Луначарского, 2	f	small
78050	5434	755	Тюменская область, Тюмень, Логунова, 15	f	large
78049	5433	754	Тюменская область, Тюмень, Логунова, 17	f	large
78048	5433	753	Тюменская область, Тюмень, Логунова, 17	f	large
78151	5532	876	Тюменская область, Тюмень, Ленинградская, 10	t	large
78150	5532	875	Тюменская область, Тюмень, Ленинградская, 10	t	large
78058	5440	765	Тюменская область, Тюмень, Ленина, 38	f	large
127216	5151	441	Тюменская область, Тюмень, Ленина, 26	f	small
78059	5441	766	Тюменская область, Тюмень, Крупской, 21	f	large
78225	5592	959	Тюменская область, Тюмень, Красных Зорь, 39	f	large
78134	5504	857	Тюменская область, Тюмень, Котовского, 56	f	large
78204	5574	937	Тюменская область, Тюмень, Коммунаров, 25	f	large
78203	5574	936	Тюменская область, Тюмень, Коммунаров, 25	f	large
78137	5523	862	Тюменская область, Тюмень, Киевская, 78	t	large
78136	5522	861	Тюменская область, Тюмень, Киевская, 63	f	large
78078	5461	789	Тюменская область, Тюмень, Кемеровская, 1б	f	large
78219	5588	953	Тюменская область, Тюмень, Карская, 38	f	large
78223	5588	954	Тюменская область, Тюмень, Карская, 38	f	large
78082	5466	795	Тюменская область, Тюмень, Карла Маркса, 108	f	large
78081	5465	794	Тюменская область, Тюмень, Карла Маркса, 110А	f	large
78149	5531	874	Тюменская область, Тюмень, Камчатская, 146	f	large
78148	5530	873	Тюменская область, Тюмень, Камчатская, 1а	f	large
78147	5530	872	Тюменская область, Тюмень, Камчатская, 1а	f	large
78090	5472	803	Тюменская область, Тюмень, Калинина, 5	f	large
78146	5529	871	Тюменская область, Тюмень, Казачьи Луга, 9к1	f	large
78178	5555	909	Тюменская область, Тюмень, Казаровская, 35	t	large
78114	5500	836	Тюменская область, Тюмень, Институтская, 4	f	large
78213	5582	946	Тюменская область, Тюмень, Индустриальная, 49	f	large
78166	5548	896	Тюменская область, Тюмень, Игримская, 27	f	large
78188	5564	922	Тюменская область, Тюмень, Заречный проезд, 4а	f	large
78200	5571	933	Тюменская область, Тюмень, Заозерная, 103	f	large
78199	5571	932	Тюменская область, Тюмень, Заозерная, 103	f	large
78160	5541	888	Тюменская область, Тюмень, Ершова, 9	f	large
78145	5528	870	Тюменская область, Тюмень, Домостроителей, 2а	f	large
78144	5528	869	Тюменская область, Тюмень, Домостроителей, 2а	f	large
78143	5528	868	Тюменская область, Тюмень, Домостроителей, 2а	f	large
78105	5492	825	Тюменская область, Тюмень, Демьяна Бедного, 100	f	large
127397	5491	824	Тюменская область, Тюмень, Демьяна Бедного, 109	f	medium
78053	5436	758	Тюменская область, Тюмень, Гнаровской, 1	f	large
78052	5435	757	Тюменская область, Тюмень, Гнаровской, 3А	f	large
78051	5435	756	Тюменская область, Тюмень, Гнаровской, 3А	f	large
78054	5285	759	Тюменская область, Тюмень, Гнаровской, 3	f	large
78055	5285	760	Тюменская область, Тюмень, Гнаровской, 3	f	large
78056	5285	761	Тюменская область, Тюмень, Гнаровской, 3	f	large
127404	5539	885	Тюменская область, Тюмень, Гилевская Роща, 4	f	small
78120	5508	843	Тюменская область, Тюмень, Геологоразведчиков, 39	f	large
78119	5507	842	Тюменская область, Тюмень, Геологоразведчиков, 19	f	large
78196	5568	929	Тюменская область, Тюмень, Газовиков, 30	f	large
78192	5566	925	Тюменская область, Тюмень, Газовиков, 6	f	large
78193	5566	926	Тюменская область, Тюмень, Газовиков, 6	f	large
78191	5565	924	Тюменская область, Тюмень, Газовиков, 11	f	large
78189	5565	923	Тюменская область, Тюмень, Газовиков, 11	f	large
78190	5563	920	Тюменская область, Тюмень, Газовиков, 3а	f	large
78187	5563	919	Тюменская область, Тюмень, Газовиков, 3а	f	large
127409	5563	921	Тюменская область, Тюмень, Газовиков, 3а	f	\N
127398	5496	832	Тюменская область, Тюмень, Гагарина, 4	f	medium
78156	5537	883	Тюменская область, Тюмень, Воровского, 11	f	large
78155	5537	882	Тюменская область, Тюмень, Воровского, 11	f	large
78089	5471	802	Тюменская область, Тюмень, Волгоградская, 70	f	large
78173	5552	904	Тюменская область, Тюмень, Ватутина, 14	f	large
78167	5549	897	Тюменская область, Тюмень, Ватутина, 55	f	large
78201	5572	934	Тюменская область, Тюмень, Береговая, 147	f	large
78198	5570	931	Тюменская область, Тюмень, Береговая, 24	f	large
78279	5455	783	Тюменская область, Тюмень, Белинского, 22к.1	f	large
78073	5453	781	Тюменская область, Тюмень, Белинского, 1А	f	large
78076	5459	787	Тюменская область, Тюмень, Барнаульская, 40	f	large
127392	5458	786	Тюменская область, Тюмень, Бакинских Комиссаров, 8	f	medium
78077	5460	788	Тюменская область, Тюмень, Бабарынка, 20б	f	large
78075	5457	785	Тюменская область, Тюмень, Авторемонтная, 24	f	large
78047	5432	752	Тюменская область, Тюмень, 9-го Мая проезд, 5	f	large
78182	5558	913	Тюменская область, Тюмень, 70 лет Октября, 5	f	large
78181	5558	912	Тюменская область, Тюмень, 70 лет Октября, 5	f	large
78157	5538	884	Тюменская область, Тюмень, 50 Лет Октября, 207а/1	f	large
78139	5524	864	Тюменская область, Тюмень, 50 Лет Октября, 41	f	large
78138	5524	863	Тюменская область, Тюмень, 50 Лет Октября, 41	f	large
78129	5514	852	Тюменская область, Тюмень, 50 Лет Октября, 62	f	large
78125	5511	848	Тюменская область, Тюмень, 50 Лет Октября, 84/2	f	large
78124	5511	847	Тюменская область, Тюмень, 50 Лет Октября, 84/2	f	large
78037	5426	742	Тюменская область, Тюмень, 30 лет Победы, 102	f	large
78036	5425	741	Тюменская область, Тюмень, 30 лет Победы, 106	f	large
78035	5425	740	Тюменская область, Тюмень, 30 лет Победы, 106	f	large
78039	5427	744	Тюменская область, Тюмень, 30 Лет Победы, 95/2	f	large
78015	5414	720	Тюменская область, Тюмень, 30 Лет Победы, 142	f	large
78014	5414	719	Тюменская область, Тюмень, 30 Лет Победы, 142	f	large
77972	5330	629	Тюменская область, Тобольск, микрорайон Южный, 5	f	large
77971	5330	628	Тюменская область, Тобольск, микрорайон Южный, 5	f	large
77978	5339	640	Тюменская область, Тобольск, микрорайон Менделеево, 6	t	large
77977	5339	639	Тюменская область, Тобольск, микрорайон Менделеево, 6	t	large
77945	5309	596	Тюменская область, Тобольск, Рощинский переулок, 25	f	large
78262	5310	597	Тюменская область, Тобольск, Ремезова, 26	f	large
77944	5308	595	Тюменская область, Тобольск, Ремезова, 72А	f	large
77943	5307	594	Тюменская область, Тобольск, Ремезова, 27А	f	large
77942	5306	593	Тюменская область, Тобольск, Ремезова, 36	f	large
127348	5325	622	Тюменская область, Тобольск, Р. Люксембург, 7	f	medium
77968	5328	625	Тюменская область, Тобольск, Пушкина, 22	f	large
127344	5304	591	Тюменская область, Тобольск, Полевая, 2	f	medium
127343	5302	589	Тюменская область, Тобольск, Панин бугор , Объединенный учебный центр УВД	t	small
77969	5329	626	Тюменская область, Тобольск, Ленина, 72	f	large
77970	5329	627	Тюменская область, Тобольск, Ленина, 72	f	large
77952	5316	604	Тюменская область, Тобольск, Знаменского, 85	f	large
77946	5311	598	Тюменская область, Тобольск, Знаменского, 52А	f	large
77976	5338	638	Тюменская область, Тобольск, Заводская, 15	f	large
78271	5337	637	Тюменская область, Тобольск, Железнодорожная, 5	f	large
78270	5336	636	Тюменская область, Тобольск, Железнодорожная, 20	f	large
77967	5327	624	Тюменская область, Тобольск, Декабристов, 21	f	large
127349	5332	632	Тюменская область, Тобольск, Береговая, 12	f	medium
77962	5322	618	Тюменская область, Тобольск, 9 микрорайон, 12	f	large
77961	5322	617	Тюменская область, Тобольск, 9 микрорайон, 12	f	large
77965	5324	621	Тюменская область, Тобольск, 8 микрорайон, 42	f	large
77964	5324	620	Тюменская область, Тобольск, 8 микрорайон, 42	f	large
77956	5320	612	Тюменская область, Тобольск, 7-й микрорайон, 53	f	large
77955	5320	611	Тюменская область, Тобольск, 7-й микрорайон, 53	f	large
77958	5321	614	Тюменская область, Тобольск, 7 микрорайон, 54	f	large
77957	5321	613	Тюменская область, Тобольск, 7 микрорайон, 54	f	large
127347	5319	610	Тюменская область, Тобольск, 6 микрорайон, 52	f	\N
127346	5319	609	Тюменская область, Тобольск, 6 микрорайон, 52	f	\N
77954	5318	608	Тюменская область, Тобольск, 6 микрорайон, 60	f	large
77953	5318	607	Тюменская область, Тобольск, 6 микрорайон, 60	f	large
77951	5315	603	Тюменская область, Тобольск, 4 микрорайон, 54	f	large
77950	5314	602	Тюменская область, Тобольск, 4 микрорайон, 47	f	large
77949	5313	601	Тюменская область, Тобольск, 4 микрорайон, 41	f	large
77948	5313	600	Тюменская область, Тобольск, 4 микрорайон, 41	f	large
77973	5331	630	Тюменская область, Тобольск, 2-я Трудовая, 3	f	large
78002	5383	685	Тюменская область, деревня Патрушево, Новая, 8	f	large
78000	5379	681	Тюменская область, поселок Московский, Озерная, 2	f	large
126885	4756	46	Тюменская область, поселок Московский, Новая, 10	f	small
78111	5495	831	Тюменская область, село Луговое, Андрея Туполева, 2	t	large
127077	4984	267	Тюменская область, Колесниково, Советская, 61	f	medium
77896	5113	393	Тюменская область, Ишим, Ялуторовская, 90	f	large
127204	5131	419	Тюменская область, Ишим, Чернышевского, 11	t	medium
127203	5128	416	Тюменская область, Ишим, Свердлова, 112	t	\N
77910	4862	414	Тюменская область, Ишим, Свердлова, 75	t	large
77920	5140	429	Тюменская область, Ишим, Республики, 95	f	large
77903	5125	405	Тюменская область, Ишим, Ражева, 1	f	large
127200	5127	407	Тюменская область, Ишим, Пушкина, 10	f	medium
77912	5130	418	Тюменская область, Ишим, Путиловская, 4	t	large
77898	5116	396	Тюменская область, Ишим, Петропавловская, 23	f	large
77900	5118	398	Тюменская область, Ишим, Орджоникидзе, 41	f	large
77905	4689	409	Тюменская область, Ишим, Одоевского, 54	f	large
77919	5138	427	Тюменская область, Ишим, Непомнящего, 146	f	large
127196	5120	400	Тюменская область, Ишим, М. Садовая, 71	f	\N
127197	5121	401	Тюменская область, Ишим, Луначарского, 62	f	\N
77901	5119	399	Тюменская область, Ишим, Луговая, 25	f	large
127198	5123	403	Тюменская область, Ишим, Ленина, 56	f	medium
77902	5122	402	Тюменская область, Ишим, Ленина, 1	f	large
77918	5137	426	Тюменская область, Ишим, Красина, 7	t	large
127205	5137	425	Тюменская область, Ишим, Красина, 7	t	medium
77917	5136	424	Тюменская область, Ишим, Красина, 3	t	large
77904	5126	406	Тюменская область, Ишим, Карла Маркса, 15	f	large
77897	5115	395	Тюменская область, Ишим, Казанская, 44	f	large
127199	5124	404	Тюменская область, Ишим, К. Маркса, 4	f	medium
127201	5110	408	Тюменская область, Ишим, К. Маркса, 36	f	medium
77909	4877	415	Тюменская область, Ишим, К. Маркса, 68	f	large
77911	5129	417	Тюменская область, Ишим, Ершова, 101	t	large
77915	5134	422	Тюменская область, Ишим, Деповская, 17	t	large
77913	5132	420	Тюменская область, Ишим, Деповская, 1	t	large
77914	5133	421	Тюменская область, Ишим, Большая, 190	f	large
127195	5114	394	Тюменская область, Ишим, 40 лет Победы, 19А	f	\N
77885	4973	256	Тюменская область, Заводоуковск, Дзержинского, 2	f	large
77882	4969	252	Тюменская область, Заводоуковск, Энергетиков, 8	f	large
127065	4963	245	Тюменская область, Заводоуковск, Щорса, 13	f	medium
77881	4968	251	Тюменская область, Заводоуковск, Шоссейная, 115	f	large
77878	4965	248	Тюменская область, Заводоуковск, Шоссейная, 171	f	large
127067	4971	254	Тюменская область, Заводоуковск, Школьная, 74	f	medium
77886	4975	258	Тюменская область, Заводоуковск, Сургутская, 13	f	large
127068	4974	257	Тюменская область, Заводоуковск, Совхозная, 184	t	small
77884	4972	255	Тюменская область, Заводоуковск, Республики, 1А	f	large
77877	4950	247	Тюменская область, Заводоуковск, Революционная, 113	f	large
77876	4962	244	Тюменская область, Заводоуковск, Механическая, 49	f	large
127066	4964	246	Тюменская область, Заводоуковск, Мелтораторов, 12Б	t	medium
77887	4976	259	Тюменская область, Заводоуковск, Королева, 8	t	large
77883	4970	253	Тюменская область, Заводоуковск, Заводская, 16	f	large
77875	4961	243	Тюменская область, Заводоуковск, Ермака, 4	f	large
77879	4966	249	Тюменская область, Заводоуковск, Екатерины Дружининой, 17	f	large
77985	5354	655	Тюменская область, поселок Боровский, улица Октябрьская, 3	f	large
78257	5759	1127	Тюменская область, Ярковский район, село Ярково, Полевая, 9	f	large
78256	5758	1126	Тюменская область, Ярковский район, село Ярково, Пионерская, 96	f	large
78258	5760	1128	Тюменская область, Ярковский район, село Ярково, Мира, 27	f	large
127537	5756	1124	Тюменская область, Ярковский район, село Щетково, Береговая, 1а	f	medium
127516	5733	1102	Тюменская область, Ярковский район, село Шатанова, Зеленая, 11	f	small
127532	5751	1119	Тюменская область, Ярковский район, село Чечкино, Мира, 83	f	small
127519	5736	1105	Тюменская область, Ярковский район, село Усть-Тавда, Мира, 13	t	small
127522	5740	1108	Тюменская область, Ярковский район, село Усалка, Школьная, 2	f	small
127531	5750	1118	Тюменская область, Ярковский район, село Староалександровка, Советская, 13	f	small
127535	5754	1122	Тюменская область, Ярковский район, село Сорокино, Центральная, 2	f	small
78255	5741	1109	Тюменская область, Ярковский район, село Покровское, Советская, 66	f	large
127517	5734	1103	Тюменская область, Ярковский район, село Плеханово, Школьная, 8	f	small
127538	5757	1125	Тюменская область, Ярковский район, село Петропавловка, Гагарина, 19	t	small
127524	5743	1111	Тюменская область, Ярковский район, село Новоселово, Центральная, 12	f	small
127526	5745	1113	Тюменская область, Ярковский район, село Новоалександровка, Центральная, 57	f	small
127534	5753	1121	Тюменская область, Ярковский район, село Мотуши, Центральная, 16	f	small
127529	5748	1116	Тюменская область, Ярковский район, село Маранка, Школьная, 19	f	small
127530	5749	1117	Тюменская область, Ярковский район, село Карбаны, Школьная, 8	f	small
127521	5738	1107	Тюменская область, Ярковский район, село Караульнояр, Советская, 24	f	small
127523	5742	1110	Тюменская область, Ярковский район, село Иевлево, Водопроводная, 7	f	small
127533	5752	1120	Тюменская область, Ярковский район, село Дубровное, Центральная, 5	f	medium
127514	5731	1100	Тюменская область, Ярковский район, село Гилево, Центральная, 31	t	medium
127525	5744	1112	Тюменская область, Ярковский район, село Варвара, Школьная, 23	f	medium
127518	5735	1104	Тюменская область, Ярковский район, село Большой Краснояр, Краснознаменная, 15	t	small
127515	5732	1101	Тюменская область, Ярковский район, село Аксарина, Сосновая, 3	f	small
78240	5712	1081	Тюменская область, Ялуторовский район, город Ялуторовск	f	large
78264	5714	1083	Тюменская область, Ялуторовский район, Ялуторовск, Комсомольская, 63	f	large
127506	5702	1072	Тюменская область, Ялуторовский район, село Южное, Береговая, 16	t	small
127510	5706	1076	Тюменская область, Ялуторовский район, село Черемушки, Центральная, 9	t	small
127500	5696	1066	Тюменская область, Ялуторовский район, село Хохлово, Мира, 36	f	small
127498	5694	1064	Тюменская область, Ялуторовский район, село Старый Кавдык, Советский переулок, 17	t	small
127503	5699	1069	Тюменская область, Ялуторовский район, село Прогресс, переулок Луговой, 4	f	small
127496	5692	1062	Тюменская область, Ялуторовский район, село Петелино, Ленина, 25	t	medium
127502	5698	1068	Тюменская область, Ялуторовский район, поселок Памятное, Ворошилова, 22	f	medium
127499	5695	1065	Тюменская область, Ялуторовский район, село Новый Кавдык, Новая, 20	t	small
127488	5684	1054	Тюменская область, Ялуторовский район, село Новоатьялово, Школьная, 26	f	medium
127501	5697	1067	Тюменская область, Ялуторовский район, село Криволукская, Гагарина, 2	f	small
127512	5709	1078	Тюменская область, Ялуторовский район, поселок Киева, Строителей, 1а	t	large
127511	5708	1077	Тюменская область, Ялуторовский район, село Карабаш, Школьная, 1	t	small
127505	5701	1071	Тюменская область, Ялуторовский район, село Зиново, Победы, 67б	f	small
127486	5682	1052	Тюменская область, Ялуторовский район, село Большое Тихвино, Русанова, 14, 627043	f	small
127509	5705	1075	Тюменская область, Ялуторовский район, поселок Беркут, Первомайская, 35	f	medium
127497	5693	1063	Тюменская область, Ялуторовский район, село Бердюгино, Набережная, 3	t	small
127489	5685	1055	Тюменская область, Ялуторовский район, село Аслана, Кирова, 33Б	f	medium
127504	5700	1070	Тюменская область, Ялуторовский район, село Анисимовка, Школьная, 3	t	small
127480	5676	1046	Тюменская область, Юргинский район, село Юргинское, Северная, 1	f	medium
127482	5678	1048	Тюменская область, Юргинский район, село Юргинское, Набережная, 29	t	medium
78238	5675	1045	Тюменская область, Юргинский район, село Юргинское, Ленина, 70	f	large
127481	5617	1047	Тюменская область, Юргинский район, село Юргинское, Жукова, 9	f	medium
127479	5674	1044	Тюменская область, Юргинский район, село Шипаково, Ленина, 28	f	small
127478	5673	1043	Тюменская область, Юргинский район, село Соколова, Дениса Бобова, 22	t	small
127470	5665	1035	Тюменская область, Юргинский район, село Синьга, 30 лет Победы, 1	t	small
127476	5671	1041	Тюменская область, Юргинский район, поселок Северо-Плетнево, Ленина, 36	f	medium
127483	5679	1049	Тюменская область, Юргинский район, село Палецкая, Колхозная, 44	t	small
127474	5669	1039	Тюменская область, Юргинский район, поселок Новый Тап, Центральная, 5	t	small
127475	5670	1040	Тюменская область, Юргинский район, поселок Новый Тап, Заречная, 38	f	small
127473	5668	1038	Тюменская область, Юргинский район, поселок Лесное, Лесная, 1	f	medium
127471	5666	1036	Тюменская область, Юргинский район, село Лабино, Ленина, 5	f	small
127484	5680	1050	Тюменская область, Юргинский район, село Заозерная, 63б	t	small
127469	5664	1034	Тюменская область, Юргинский район, село Володино, Кирова, 24	f	small
127468	5663	1033	Тюменская область, Юргинский район, село Бушуево, Береговая, 23	f	small
127467	5661	1032	Тюменская область, Юргинский район, село Агарак, Малахова, 66	f	small
127464	5658	1029	Тюменская область, Упоровский район, село Шашова, Речная, 24	t	small
127463	5657	1028	Тюменская область, Упоровский район, село Черная, Молодежная, 13	f	medium
127465	5659	1030	Тюменская область, Упоровский район, село Чащина, Центральная, 3	t	small
78288	5655	1026	Тюменская область, Упоровский район, село Упорово, Строителей, 21	f	large
78237	5654	1025	Тюменская область, Упоровский район, село Упорово, Крупской, 29	f	large
127462	5656	1027	Тюменская область, Упоровский район, село Упорово, Дзержинского, 1	f	medium
127461	5653	1024	Тюменская область, Упоровский район, село Тютрина, Школьная, 19	f	small
127460	5652	1023	Тюменская область, Упоровский район, поселок Суерка, 30 лет Победы, 4	f	medium
127450	5642	1013	Тюменская область, Упоровский район, село Слободчики, Садовая, 20А	t	small
127458	5650	1021	Тюменская область, Упоровский район, село Скородум, Центральная, 11	t	small
127456	5648	1019	Тюменская область, Упоровский район, село Пятково, Вишнякова, 6	f	medium
127442	5634	1005	Тюменская область, Упоровский район, село Октябрьский, Новая, 10	t	small
127452	5644	1015	Тюменская область, Упоровский район, село Одино, Северная, 45	f	small
127449	5641	1012	Тюменская область, Упоровский район, село Нифаки, Шоссейная, 14	t	small
127455	5647	1018	Тюменская область, Упоровский район, село Нижнеманай, Нижнеманайская, 65	t	small
127431	5623	994	Тюменская область, Упоровский район, село Морево, Заречная, 8	f	small
127435	5627	998	Тюменская область, Упоровский район, село Масали, Новый переулок, 5	f	medium
127439	5631	1002	Тюменская область, Упоровский район, село Маркова, Набережная,  15	t	small
127448	5640	1011	Тюменская область, Упоровский район, село Лыково, Заречная, 16	t	small
127454	5646	1017	Тюменская область, Упоровский район, село Липиха, Центральная, 3	f	small
127457	5649	1020	Тюменская область, Упоровский район, село Киселево, Семкова, 27	f	small
127438	5630	1001	Тюменская область, Упоровский район, село Кизак, Кизакская, 16А	t	small
127444	5636	1007	Тюменская область, Упоровский район, село Кашаир, Центральная, 26	t	small
127447	5639	1010	Тюменская область, Упоровский район, село Ингалинское, Школьная, 8	f	small
127441	5633	1004	Тюменская область, Упоровский район, село Емуртлинский, Нохрина, 6	f	medium
127440	5632	1003	Тюменская область, Упоровский район, село Емуртла, Свободы, 17А	f	medium
127443	5635	1006	Тюменская область, Упоровский район, село Емуртла, Ленинградская, 15А	f	small
127437	5629	1000	Тюменская область, Упоровский район, поселок Дубровинский, Заречная, 4	t	small
127436	5628	999	Тюменская область, Упоровский район, село Видонова, Советская, 17	t	small
127432	5624	995	Тюменская область, Упоровский район, село Бызово, Советская, 28	f	small
127428	5620	991	Тюменская область, Упоровский район, село Буньково, 50 лет Октября, 19	f	small
78234	5606	977	Тюменская область, Уватский район, село Уват, Ленина, 88	f	large
78233	5606	976	Тюменская область, Уватский район, село Уват, Ленина, 88	f	large
127418	5607	978	Тюменская область, Уватский район, село Уват, Иртышская, 19	f	small
78235	5610	982	Тюменская область, Уватский район, поселок Туртас, Школьная, 2	f	large
127421	5610	981	Тюменская область, Уватский район, поселок Туртас, Школьная, 2	f	medium
127422	5611	983	Тюменская область, Уватский район, поселок Туртас, Комсомольская, 21	f	small
127425	5614	986	Тюменская область, Уватский район, село Солянка, Центральная, 12	f	small
127424	5613	985	Тюменская область, Уватский район, село Першино, Мира, 6	f	small
127423	5612	984	Тюменская область, Уватский район, село Осинник, Комсомольска, 8	f	small
127420	5609	980	Тюменская область, Уватский район, поселок Нагорный, Нефтяников, 9А/2	f	small
127427	5619	990	Тюменская область, Уватский район, село Муген, 42	f	small
127416	5604	974	Тюменская область, Уватский район, село Красный Яр, Стивы Дорониной, 3	f	small
127419	5608	979	Тюменская область, Уватский район, село Ивановка, Орджоникидзе, 9	f	small
78287	5615	987	Тюменская область, Уватский район, село Демьянское, НПС, 27	f	large
78236	5618	989	Тюменская область, Уватский район, поселок Демьянка, Микрорайон Железнодорожный, 15	f	large
127414	5602	972	Тюменская область, Уватский район, село Горнослинкино, Северная, 5	f	small
127417	5605	975	Тюменская область, Уватский район, село Алымка, Центральная, 12Б	t	small
127360	5370	672	Тюменская область, Тюменский район, село Янтык, Молодежная, 8	f	small
127351	5342	643	Тюменская область, Тюменский район, село Якуши, Полевая, 1	t	small
127356	5352	653	Тюменская область, Тюменский район, село Щербак, Трактовая, 17	t	small
78008	5341	642	Тюменская область, Тюменский район, поселок Чикча, Гагарина, 16	f	large
78272	5340	641	Тюменская область, Тюменский район, село Червишево, Юбилейный квартал, 2	f	large
78007	5340	706	Тюменская область, Тюменский район, село Червишево, Юбилейный квартал, 2	f	large
127379	5401	704	Тюменская область, Тюменский район, село Чаплык, переулок Центральный, 11	t	small
127375	5395	698	Тюменская область, Тюменский район, село Ушакова, Новая, 2	f	medium
78006	5399	702	Тюменская область, Тюменский район, село Успенка, Коммунаров, 3	f	large
127358	5367	669	Тюменская область, Тюменский район, село Тураева, Аширбекова, 69	t	medium
78115	5501	837	Тюменская область, Тюменский район, поселок Тараскуль, Санаторная, 6	f	large
127363	5378	680	Тюменская область, Тюменский район, село Субботина, Школьная, 5а	t	small
78278	5398	701	Тюменская область, Тюменский район, поселок Созоново, Молодежная, 2	f	large
127377	5397	700	Тюменская область, Тюменский район, поселок Салаирка, Новая, 35	f	medium
127369	5387	689	Тюменская область, Тюменский район, село Пышминка, Береговая, 27	f	small
127376	5396	699	Тюменская область, Тюменский район, село Подъем, Лесная, 25, кв. 2	t	small
78005	5394	697	Тюменская область, Тюменский район, поселок Перевалово, Школьная, 13	f	large
127365	5382	684	Тюменская область, Тюменский район, село Падерина, Озерная, 8	t	medium
127374	5393	696	Тюменская область, Тюменский район, село Онохино, Касьянова, 22А	f	medium
78004	5393	695	Тюменская область, Тюменский район, село Онохино, Касьянова, 22А	f	large
127361	5373	675	Россия, Тюменская область, Тюменский район, село Новотуринский	t	medium
78003	5390	692	Тюменская область, Тюменский район, поселок Новотарманский, Центральная, 56	f	large
127366	5384	686	Тюменская область, Тюменский район, село Муллаши, Советская, 2	f	medium
78001	5380	682	Тюменская область, Тюменский район, поселок Московский, Озерная, 8	f	large
127373	5392	694	Тюменская область, Тюменский район, село Молчанова, Приозерная, 22	f	small
127383	5405	709	Тюменская область, Тюменский район, село Мичурино, Центральная, 64	f	small
127371	5389	691	Тюменская область, Тюменский район, село Марай, Школьная, 31	t	small
78277	5377	679	Тюменская область, Тюменский район, поселок Мальково, Совхозная, 23	f	large
127380	5402	705	Тюменская область, Тюменский район, село Малиновка, Центральная, 13	t	small
77999	5376	678	Тюменская область, Тюменский район, поселок Луговое, 60 лет Октября, 9	f	large
127384	5406	710	Тюменская область, Тюменский район, село Леваши, Рабочая, 32	f	small
127359	5369	671	Тюменская область, Тюменский район, село Кулига, Транспортная, 37	t	small
77998	5375	677	Тюменская область, Тюменский район, село Кулаково, Семеновых, 80	f	large
127352	5343	644	Тюменская область, Тюменский район, село Криводанова, Центральная, 9	f	medium
127362	5374	676	Тюменская область, Тюменский район, село Княжево, Ленина, 1а	f	small
77996	5371	673	Тюменская область, Тюменский район, село Каскара, Школьная, 12	f	large
77997	5372	674	Тюменская область, Тюменский район, село Каскара, Ленина, 5	f	large
78276	5368	670	Тюменская область, Тюменский район, поселок Каменка, Новая, 17	f	large
127378	5400	703	Тюменская область, Тюменский район, село Зырянка, Гагарина, 11	f	medium
127370	5388	690	Тюменская область, Тюменский район, село Железный Перебор, Мира, 10	f	small
77994	5365	667	Тюменская область, Тюменский район, поселок Ембаево, М. Джалиля, 74	f	large
127382	5404	708	Тюменская область, Тюменский район, село Друганова, Школьная, 15	t	small
127364	5381	683	Тюменская область, Тюменский район, село Гусево, Рабочая, 1а	f	small
77993	5364	666	Тюменская область, Тюменский район, поселок Горьковка, Сибирская, 12	f	large
77990	5359	661	Тюменская область, Тюменский район, поселок Винзили, Первомайская, 3	f	large
77991	5360	662	Тюменская область, Тюменский район, поселок Винзили, Комсомольская, 1	f	large
77989	5358	660	Тюменская область, Тюменский район, поселок Винзили, Заводская, 18А	f	large
77988	5358	659	Тюменская область, Тюменский район, поселок Винзили, Заводская, 18А	f	large
77992	5361	663	Тюменская область, Тюменский район, поселок Винзили, Вокзальная, 74	f	large
78275	5362	664	Тюменская область, Тюменский район, поселок Винзили, 60 лет Октября, 1	f	large
77986	5355	656	Тюменская область, Тюменский район, поселок Боровский, Советская, 12	f	large
77984	5353	654	Тюменская область, Тюменский район, поселок Боровский, Мира, 14	f	large
77987	5356	657	Тюменская область, Тюменский район, поселок Боровский, Ленинградская, 7	f	large
78274	5357	658	Тюменская область, Тюменский район, поселок Боровский, Герцена, 22А	f	large
78273	5351	652	Тюменская область, Тюменский район, поселок Борки, Советская, 26	f	large
127381	5403	707	Тюменская область, Тюменский район, село Большие Акияры, Совхозная,  124	t	medium
127368	5386	688	Тюменская область, Тюменский район, село Богандинское, Садовая, 1	f	small
127354	5349	650	Тюменская область, Тюменский район, поселок Богандинский, п/о Сосновое, 2	t	medium
77981	5346	647	Тюменская область, Тюменский район, поселок Богандинский, Юбилейная, 5Б	f	large
77980	5345	646	Тюменская область, Тюменский район, поселок Богандинский, Юбилейная, 3А	f	large
77983	5347	649	Тюменская область, Тюменский район, поселок Богандинский, Садовый, 1	f	large
77982	5347	648	Тюменская область, Тюменский район, поселок Богандинский, Садовый, 1	f	large
127353	5344	645	Тюменская область, Тюменский район, поселок Андреевский, пер. Лесной, 13	f	\N
127350	5333	633	Тюменская область, Тобольский район, Тобольск, Раздольная, 1а	f	\N
77974	5334	634	Тюменская область, Тобольский район, Тобольск, Мира, 8	f	large
77966	5326	623	Тюменская область, Тобольский район, Тобольск, Ленина, 26	f	large
77947	5312	599	Тюменская область, Тобольский район, город Тобольск, Знаменского, 58 а, 626150	f	large
77975	5335	635	Тюменская область, Тобольский район, город Тобольск, Гагарина, 22	f	large
77963	5323	619	Тюменская область, Тобольский район, Тобольск, 8 микрорайон, 8А	f	large
77960	5303	616	Тюменская область, Тобольский район, город Тобольск, 7-й микрорайон, 6А	f	large
77959	5303	615	Тюменская область, Тобольский район, город Тобольск, 7-й микрорайон, 6А	f	large
77979	5303	590	Тюменская область, Тобольский район, город Тобольск, 7-й микрорайон, 6А	f	large
78269	5317	631	Тюменская область, Тобольский район, Тобольск, 10-й микрорайон, 53	f	large
78268	5317	606	Тюменская область, Тобольский район, Тобольск, 10-й микрорайон, 53	f	large
78263	5317	605	Тюменская область, Тобольский район, Тобольск, 10-й микрорайон, 53	f	large
127314	5270	559	Тюменская область, Тобольский район, село Соколовка, Тобольская, 13	t	small
127337	5295	583	Тюменская область, Тобольский район, село Сибиряк, Советская, 3	t	small
127339	5297	585	Тюменская область, Тобольский район, село Санниково, Центральная,  27	t	small
77941	5294	582	Тюменская область, Тобольский район, поселок Прииртышский, Советская, 27	f	large
127312	5267	556	Тюменская область, Тобольский район, село Преображенка, Береговая, 17	t	small
127338	5296	584	Тюменская область, Тобольский район, село Полуянова, Первомайская, 10	f	small
127317	5273	562	Тюменская область, Тобольский район, село Октябрьский, Зелёная, 14	t	small
127332	5289	577	Тюменская область, Тобольский район, село Нижние Аремзяны, Сибирская, 17	f	medium
127333	5290	578	Тюменская область, Тобольский район, село Надцы, Школьная, 3	t	small
127320	5276	565	Тюменская область, Тобольский район, село Медянки-Татарские, Портовая, 10А	f	small
127340	5298	586	Тюменская область, Тобольский район, село Маслова, Школьная, 1	f	small
127331	5288	576	Тюменская область, Тобольский район, село Малая Зоркальцева, Учителей, 16	f	medium
127327	5283	572	Тюменская область, Тобольский район, село Кутарбитка, Школьная, 27	f	medium
127326	5282	571	Тюменская область, Тобольский район, село Карачино, Мира, 44 А	f	small
127334	5291	579	Тюменская область, Тобольский район, село Ингаир, 6	f	small
127324	5280	569	Тюменская область, Тобольский район, село Загваздина, Молодежная, 23	f	small
127325	5281	570	Тюменская область, Тобольский район, село Епанчина, пер. Школьный, 9	t	small
127321	5277	566	Тюменская область, Тобольский район, село Дегтярево, Цетральная, 41А	f	medium
127319	5275	564	Тюменская область, Тобольский район, село Ворогушино, Центральная, 1	f	small
127316	5272	561	Тюменская область, Тобольский район, село Верхние Аремзяны, Школьная, 5	f	small
127315	5271	560	Тюменская область, Тобольский район, село Булашово, Рабочая, 48	f	small
127318	5274	563	Тюменская область, Тобольский район, село Бизино, Ленина, 7А	f	medium
127313	5269	558	Тюменская область, Тобольский район, село Башкова, Строителей, 10	t	medium
77940	5268	557	Тюменская область, Тобольский район, село Байкалово, Советская, 10	f	large
127311	5266	555	Тюменская область, Тобольский район, село Абалак, Советская, 36	f	medium
127308	5263	552	Тюменская область, Сорокинский район, село Рядовичи, Сидякина, 20/1	t	small
127309	5264	553	Тюменская область, Сорокинский район, село Покровка, Центральная, 14	f	small
127297	5252	541	Тюменская область, Сорокинский район, село Осиновка, Советская, 35	f	small
127307	5262	551	Тюменская область, Сорокинский район, село Нижнепинигино, Центральная, 58а	t	small
127301	5256	545	Тюменская область, Сорокинский район, село Нефтяник, Центральная, 2	f	small
127306	5261	550	Тюменская область, Сорокинский район, село Калиновка, Зеленая, 10	f	small
127304	5259	548	Тюменская область, Сорокинский район, село Жидоусово, Молодежная, 8	f	small
127303	5258	547	Тюменская область, Сорокинский район, село Желнина, Школьная, 11А	f	small
127302	5257	546	Тюменская область, Сорокинский район, село Готопутово, Центральная, 40	f	medium
127299	5254	543	Тюменская область, Сорокинский район, село Ворсиха, Новая, 21	f	small
77939	5251	540	Тюменская область, Сорокинский район, село Большое Сорокино, Советская, 213	f	large
127296	5250	539	Тюменская область, Сорокинский район, село Большое Сорокино, Советская, 105	f	medium
77938	5249	538	Тюменская область, Сорокинский район, село Большое Сорокино, Ленина, 160	f	large
77937	5248	537	Тюменская область, Сорокинский район, село Большое Сорокино, 40 лет Октября, 1а	f	large
127298	5253	542	Тюменская область, Сорокинский район, село Александровка, Школьная, 1	f	small
127289	5239	528	Тюменская область, Сладковский район, село Хантиновка, Солнечная, 2	t	small
127295	5247	536	Тюменская область, Сладковский район, село Усово, Ленина, 17	f	medium
127227	5170	459	Тюменская область, Сладковский район, село Травное, Приозерная, 31	t	small
127294	5246	535	Тюменская область, Сладковский район, село Степное, Школьная, 2	f	small
78261	5245	534	Тюменская область, Сладковский район, село Сладково, Ленина, 104а	f	large
77936	5244	533	Тюменская область, Сладковский район, село Сладково, Ленина, 86	f	large
127293	5243	532	Тюменская область, Сладковский район, село Новоандреевка, Школьная, 5	f	medium
127292	5242	531	Тюменская область, Сладковский район, село Никулино, Центральная, 69	t	medium
127290	5240	529	Тюменская область, Сладковский район, село Менжинское, Карла Маркса,  17	t	small
77935	5238	527	Тюменская область, Сладковский район, поселок Маслянский, Сенная, 2	f	large
127286	5235	524	Тюменская область, Сладковский район, село Лопазное, Центральная, 18	f	small
127285	5234	523	Тюменская область, Сладковский район, село Александровка, Школьная, 22	f	medium
127284	5233	522	Тюменская область, Омутинский район, село Южно-Плетнево, Строительная, 24	f	small
127283	5232	521	Тюменская область, Омутинский район, село Шабаново, Шабановская, , 13	f	medium
127278	5227	516	Тюменская область, Омутинский район, поселок Ситниково, Победы, 31	f	medium
127280	5229	518	Тюменская область, Омутинский район, поселок Ситниково, МТС, 1	f	small
127282	5231	520	Тюменская область, Омутинский район, поселок Ситниково, Леонова, 2	t	small
127279	5228	517	Тюменская область, Омутинский район, поселок Ситниково, Заводская, 3	f	medium
127275	5224	513	Тюменская область, Омутинский район, село Омутинское, Тимирязева, 1А	f	medium
127273	5222	511	Тюменская область, Омутинский район, село Омутинское, Терешковой, 7	f	medium
77934	5220	509	Тюменская область, Омутинский район, село Омутинское, Советская, 128	f	large
77933	5217	506	Тюменская область, Омутинский район, село Омутинское, Лермонтова, 2	f	large
127271	5219	508	Тюменская область, Омутинский район, село Омутинское, Зятькова, 36	f	medium
127270	5218	507	Тюменская область, Омутинский район, село Омутинское, Герцена, 26	f	medium
127276	5225	514	Тюменская область, Омутинский район, село Омутинское, Вокзальная	f	small
127274	5223	512	Тюменская область, Омутинский район, село Омутинское, Водопроводная, 6	f	medium
127272	5221	510	Тюменская область, Омутинский район, село Омутинское, Вагайская, 21	f	medium
127269	5216	505	Тюменская область, Омутинский район, село Окуневское, Мира, 6	f	medium
127267	5214	503	Тюменская область, Омутинский район, село Крутинская, Центральная, 1	f	small
127277	5226	515	Тюменская область, Омутинский район, село Кашевская, здание сельского Дома культуры	t	small
127268	5215	504	Тюменская область, Омутинский район, село Журавлевское, Школьная, 3	f	small
127264	5211	500	Тюменская область, Омутинский район, село Вагай, Школьный переулок, 2	f	medium
127265	5212	501	Тюменская область, Омутинский район, село Вагай, Совхозная, 38	t	medium
127263	5210	499	Тюменская область, Омутинский район, село Вагай, Ленина, 32А	f	medium
127262	5209	498	Тюменская область, Омутинский район, село Большой Краснояр, Советская, 54	f	medium
127266	5213	502	Тюменская область, Омутинский район, село Большекрутинская, Центральная, 27	f	small
127260	5207	496	Тюменская область, Нижнетавдинский район, село Чугунаево, Лесная, 27	f	medium
127259	5206	495	Тюменская область, Нижнетавдинский район, село Черепаново, Советская, 12	f	small
127255	5202	491	Тюменская область, Нижнетавдинский район, поселок Тюнево, Школьная, 11	f	medium
127249	5196	485	Тюменская область, Нижнетавдинский район, село Тукман, Центральная, 8	t	small
127242	5186	475	Тюменская область, Нижнетавдинский район, село Торгили, Станционная, 6	f	small
127256	5203	492	Тюменская область, Нижнетавдинский район, село Средние Тарманы, Школьная, 41	t	medium
127254	5201	490	Тюменская область, Нижнетавдинский район, село Сартово, Зеленая, 1	t	small
127251	5198	487	Тюменская область, Нижнетавдинский район, село Паченка, Хохлова, 30	t	small
127237	5180	469	Тюменская область, Нижнетавдинский район, село Новопокровка, Центральная, 14	t	small
127246	5193	482	Тюменская область, Нижнетавдинский район, село Новоникольское, Центральная, 6	f	small
77932	5192	481	Тюменская область, Нижнетавдинский район, село Нижняя Тавда, Строителей, 2	f	large
77931	5191	480	Тюменская область, Нижнетавдинский район, село Нижняя Тавда, Новая, 50	f	large
77930	5190	479	Тюменская область, Нижнетавдинский район, село Нижняя Тавда, Мира, 10	f	large
127367	5385	687	Тюменская область, Нижнетавдинский район, поселок Нариманова, Центральная, 23А	f	medium
127244	5188	477	Тюменская область, Нижнетавдинский район, село Мияссы, Центральная, 9	f	small
127258	5205	494	Тюменская область, Нижнетавдинский район, поселок Лесозаводский, Мира, 11	t	small
127243	5187	476	Тюменская область, Нижнетавдинский район, село Кунчур, Лесная, 2	f	small
127239	5183	472	Тюменская область, Нижнетавдинский район, село Красный Яр, 70 лет Октября, 2	f	small
127253	5200	489	Тюменская область, Нижнетавдинский район, село Конченбург, Новая, 8	t	small
127250	5197	486	Тюменская область, Нижнетавдинский район, село Киндер, Центральная, 28	f	small
127252	5199	488	Тюменская область, Нижнетавдинский район, село Картымский, Железнодорожников, 2	t	small
127257	5204	493	Тюменская область, Нижнетавдинский район, поселок Карагандинский, Водозабор, 1	f	small
127240	5184	473	Тюменская область, Нижнетавдинский район, село Канаш, Молодежная, 4	f	small
127238	5182	471	Тюменская область, Нижнетавдинский район, поселок Иска, Береговая, 1	f	medium
127248	5195	484	Тюменская область, Нижнетавдинский район, село Веселая Грива, Центральная, 42	f	small
77929	5181	470	Тюменская область, Нижнетавдинский район, поселок Велижаны, Советская, 2	f	large
127236	5179	468	Тюменская область, Нижнетавдинский район, село Бухтал, Чапаева, 4	f	medium
127235	5178	467	Тюменская область, Нижнетавдинский район, село Березовка, Школьная, 27	f	small
127233	5176	465	Тюменская область, Нижнетавдинский район, село Антипино, Новопашина, 59	f	medium
127231	5174	463	Тюменская область, Нижнетавдинский район, село Андрюшино, Полевая, 2	f	medium
127229	5172	461	Тюменская область, Казанский район, село Яровское, Ленина, 34	f	medium
127226	5169	458	Тюменская область, Казанский район, село Чирки, Ельцова, 61	f	small
127228	5171	460	Тюменская область, Казанский район, поселок Челюскинцев, Гагарина, 14	f	medium
127224	5167	456	Тюменская область, Казанский район, село Смирное, Молодёжная, 5	t	small
127230	5173	462	Тюменская область, Казанский район, село Сладчанка, Центральная, 26	t	small
127222	5165	454	Тюменская область, Казанский район, село Пешнево, переулок Школьный, 8	f	small
127221	5164	453	Тюменская область, Казанский район, село Песчаное, Новая, 18	f	small
127220	5163	452	Тюменская область, Казанский район, село Огнево, Победы, 5	f	medium
77928	5162	451	Тюменская область, Казанский район, село Новоселезнево, Садова, 36	f	large
77927	5161	450	Тюменская область, Казанский район, село Новоселезнево, Ленина, 271	f	large
127207	5142	432	Тюменская область, Казанский район, село Новогеоргиевка, Центральная, 25	f	small
127210	5145	435	Тюменская область, Казанский район, село Малый Ченчерь, Малая, 32	f	small
127212	5147	437	Тюменская область, Казанский район, село Малые Ярки, 60 лет Октября, 25	t	small
127225	5168	457	Тюменская область, Казанский район, село Коротаевка, Зеленая, 18	t	small
127223	5166	455	Тюменская область, Казанский район, село Копотилово, Центральная, 24	f	small
77923	5156	446	Тюменская область, Казанский район, село Казанское, Луначарского, 22	f	large
75139	87486	2508	Свердловская область, Серов, Попова, 19	f	large
77924	5158	447	Тюменская область, Казанский район, село Казанское, Ленина, 64/1	f	large
77926	5160	449	Тюменская область, Казанский район, село Казанское, Ишимская, 20	f	large
77925	5159	448	Тюменская область, Казанский район, село Казанское, Ишимская, 42	f	large
77922	5152	442	Тюменская область, Казанский район, поселок Ильинка, Ленина, 26	f	large
127219	5155	445	Тюменская область, Казанский район, село Ельцово, Пограничная, 5	f	small
127214	5149	439	Тюменская область, Казанский район, село Дубынка, Ленина, 30	f	medium
127215	5150	440	Тюменская область, Казанский район, село Грачи, Зеленая, 37	f	medium
127213	5148	438	Тюменская область, Казанский район, село Гагарье, Лугова, 14	f	medium
127209	5144	434	Тюменская область, Казанский район, село Большой Ченчерь, Школьная, 45	f	small
127211	5146	436	Тюменская область, Казанский район, село Большие Ярки, Кирова, 1	f	medium
127218	5154	444	Тюменская область, Казанский район, село Благодатное, Мира, 40	f	small
127217	5153	443	Тюменская область, Казанский район, село Баландина, Центральная, 25	t	small
127206	5141	431	Тюменская область, Казанский район, село Афонькино, Мира, 2	f	medium
127192	5109	390	Тюменская область, Ишимский район, село Шаблыкино, Ленина, 61	t	medium
127189	5106	387	Тюменская область, Ишимский район, село Черемшанка, Новая, 6	f	small
127185	5102	383	Тюменская область, Ишимский район, поселок Тоболово, Школьная, 13	t	medium
127156	5070	351	Тюменская область, Ишимский район, село Таловка (Разъезд №38), Интернатская, 15	t	small
77895	5098	379	Тюменская область, Ишимский район, село Стрехнино, Стаханова, 6	f	large
77894	5097	378	Тюменская область, Ишимский район, село Стрехнино, Мелиоративная, 1А	f	large
127161	5076	357	Тюменская область, Ишимский район, село Синицына, Мира, 14	f	medium
127191	5108	389	Тюменская область, Ишимский район, село Савина, Димитрова, 20	t	small
127179	5094	375	Тюменская область, Ишимский район, село Равнец, Школьная, 12	f	small
127177	5092	373	Тюменская область, Ишимский район, село Прокуткино, Центральная, 24	f	medium
127174	5089	370	Тюменская область, Ишимский район, поселок Плодопитомник, Светлая, 1б	t	medium
127176	5091	372	Тюменская область, Ишимский район, поселок Плешково, Советская, 57	t	medium
127171	5086	367	Тюменская область, Ишимский район, село Пахомова, Новая, 33	f	small
127167	5082	363	Тюменская область, Ишимский район, деревня Патрушево, Центральная, 5	t	medium
127162	5077	358	Тюменская область, Ишимский район, село Орловка, Центральная, 201	t	small
127188	5105	386	Тюменская область, Ишимский район, село Опеновка, Дорожная, 1	t	small
77893	5071	352	Тюменская область, Ишимский район, поселок Октябрьский, Ленина, 32	f	large
127166	5081	362	Тюменская область, Ишимский район, село Ожогино, Школьная, 2/1	t	small
127170	5085	366	Тюменская область, Ишимский район, село Новотравное, Центральная, 28	t	medium
127168	5083	364	Тюменская область, Ишимский район, поселок Новолокти, Советская, 2	t	medium
127159	5074	355	Тюменская область, Ишимский район, поселок Новокировский, Животноводов, 20	f	small
127155	5069	350	Тюменская область, Ишимский район, село Нерпино, Центральная, 36А	t	small
127165	5065	361	Тюменская область, Ишимский район, поселок Мизоново, Зелёная, 4	t	medium
127151	5064	347	Тюменская область, Ишимский район, село Мезенка, Центральная, 56А	f	small
127154	5068	349	Тюменская область, Ишимский район, село Малоудалово, Центральная, 24/1	t	small
127180	5095	376	Тюменская область, Ишимский район, село Макарова, Васильева, 38	t	small
127169	5084	365	Тюменская область, Ишимский район, село Локти, Центральная, 44	t	small
127184	5101	382	Тюменская область, Ишимский район, село Лозовое, Надежд, 1Б	t	small
127163	5078	359	Тюменская область, Ишимский район, село Лариха, Советская, 14	f	medium
127186	5103	384	Тюменская область, Ишимский район, село Кукарцева, Победы,  32а	t	small
127158	5073	354	Тюменская область, Ишимский район, село Крутые Озерки, Центральная , 36	t	small
127181	5096	377	Тюменская область, Ишимский район, село Кошкарагай, Ишимская, 64	t	small
127160	5075	356	Тюменская область, Ишимский район, село Клепиково, Победы, 9	f	medium
127157	5072	353	Тюменская область, Ишимский район, село Карасуль, Гагарина, 36а	t	small
127178	5093	374	Тюменская область, Ишимский район, село Казанка, Мира, 24	t	small
77916	5135	423	Тюменская область, Ишимский район, город Ишим	f	large
77921	5139	430	Тюменская область, Ишимский район, Ишим, Уральская, 26А	f	large
78260	5139	428	Тюменская область, Ишимский район, Ишим, Уральская, 26А	f	large
127202	4706	410	Тюменская область, Ишимский район, Ишим, М. Садовая, 169	f	medium
77899	5117	397	Тюменская область, Ишимский район, Ишим, Курганская, 1	t	large
77908	4847	413	Тюменская область, Ишимский район, Ишим, К. Маркса, 56	f	large
77907	4708	412	Тюменская область, Ишимский район, Ишим, 30 лет ВЛКСМ, 28	f	large
77906	4708	411	Тюменская область, Ишимский район, Ишим, 30 лет ВЛКСМ, 28	f	large
127183	5100	381	Тюменская область, Ишимский район, село Зырянка, Дзержинского, 9Б	t	medium
127175	5090	371	Тюменская область, Ишимский район, поселок Заозерный, Победы, 27	f	medium
127187	5104	385	Тюменская область, Ишимский район, село Завьялово, Советская, 16	t	small
127152	5066	348	Тюменская область, Ишимский район, село Ершово (Безруково), Школьная площадь, 24	f	small
127150	5063	346	Тюменская область, Ишимский район, село Десятова, Центральная, 31	f	medium
127193	5111	391	Тюменская область, Ишимский район, село Голдобино, Школьный переулок, 3	t	small
127149	5062	345	Тюменская область, Ишимский район, село Гагарино, Новая, 30	f	medium
127148	5061	344	Тюменская область, Ишимский район, село Второпесьяново, Советская, 10 а	f	small
127164	5079	360	Тюменская область, Ишимский район, село Воронина, Центральная, 36	t	small
127173	5088	369	Тюменская область, Ишимский район, село Ваньковка,  Дорожная, 26	t	medium
127172	5087	368	Тюменская область, Ишимский район, село Быкова, Средняя,  14	t	small
127146	5059	342	Тюменская область, Ишимский район, село Бутусово, Центральная, 6	t	small
127144	5057	340	Тюменская область, Ишимский район, село Боровое, Школьная, 27	f	medium
127147	5060	343	Тюменская область, Ишимский район, село Борисовка, Центральная, 10	f	small
127145	5058	341	Тюменская область, Ишимский район, село Большой Остров, Зеленая, 30	f	small
127190	5107	388	Тюменская область, Ишимский район, село Большеудалово, Заречная, 5	t	small
127182	5099	380	Тюменская область, Ишимский район, село Бокаревка, п. Чернова, 1	t	small
77892	5055	338	Тюменская область, Исетский район, поселок Шорохово, Калинина, 13	f	large
127117	5025	308	Тюменская область, Исетский район, село Турушево, Полевая, 1	t	small
127139	5051	334	Тюменская область, Исетский район, село Станичное, Кирова, 10	f	small
127138	5050	333	Тюменская область, Исетский район, поселок Солобоево, Октябрьская, 33	f	medium
127137	5049	332	Тюменская область, Исетский район, поселок Слобода-Бешкиль, Им. Старцева, 44	t	medium
127119	5027	310	Тюменская область, Исетский район, село Сизикова, Механизаторов, 7	t	small
127126	5038	321	Тюменская область, Исетский район, село Решетникова, Свободы, 3	t	small
127133	5045	328	Тюменская область, Исетский район, село Рафайлово, Исаковых, 55	f	medium
127132	5044	327	Тюменская область, Исетский район, поселок Рассвет, Ленина, 15, 626393	t	medium
127131	5043	326	Тюменская область, Исетский район, село Онуфриево, Школьная, 1	t	small
127128	5040	323	Тюменская область, Исетский район, село Новикова, Ишимская, 2А	f	small
127129	5041	324	Тюменская область, Исетский район, село Минино, Мира, 3а	f	medium
127142	5054	337	Тюменская область, Исетский район, село Малыши, Береговая, 25	t	small
127130	5042	325	Тюменская область, Исетский район, село Лога, Школьная, 13	t	small
127124	5036	319	Тюменская область, Исетский район, село Кукушки, Северная, 2	f	small
127140	5052	335	Тюменская область, Исетский район, село Красногорское, Центральная, 62	t	small
127125	5037	320	Тюменская область, Исетский район, село Красново, Первомайская, 39	f	small
77891	5035	318	Тюменская область, Исетский район, поселок Коммунар, Ленина, 40	f	large
127123	5034	317	Тюменская область, Исетский район, поселок Кировский, Центральная, 2А	f	medium
77890	5033	316	Тюменская область, Исетский район, село Исетское, Строителей, 9	f	large
77889	5032	315	Тюменская область, Исетский район, село Исетское, Свердлова, 71	f	large
77888	5031	314	Тюменская область, Исетский район, село Исетское, Свердлова, 9	f	large
127143	5056	339	Тюменская область, Исетский район, поселок Зерновой, Рабочая, 8	t	small
127122	5030	313	Тюменская область, Исетский район, село Денисово, Гагарина, 20	f	small
127116	5024	307	Тюменская область, Исетский район, село Гаева, 60 лет Октября, 1А	t	small
127121	5029	312	Тюменская область, Исетский район, село Верхний Ингал, Янтимирова, 35	t	small
127120	5028	311	Тюменская область, Исетский район, село Верхнебешкиль, Революции, 8	f	small
127141	5053	336	Тюменская область, Исетский район, село Ботники, Береговая, 11	t	small
127135	5047	330	Тюменская область, Исетский район, село Битюки, Пановых, 6	t	small
127115	5023	306	Тюменская область, Исетский район, село Бархатово, Гагрина, 52а	t	medium
127114	5022	305	Тюменская область, Исетский район, село Архангельское, Школьная, 1	t	medium
127070	4978	261	Тюменская область, Заводоуковский район, село Яковлево, Набережная, 36	t	small
127101	5009	292	Тюменская область, Заводоуковский район, село Щучье, Приозерная, 6	f	small
127105	5013	296	Тюменская область, Заводоуковский район, Шиликуль, Приозерная, 29А	t	small
127093	5000	283	Тюменская область, Заводоуковский район, село Шестаково, Шоссейна, 19А	t	small
127073	4981	264	Тюменская область, Заводоуковский район, поселок Центральный, Центральная, 28	f	small
127097	5005	288	Тюменская область, Заводоуковский район, поселок Урожайный, Молодежная, 1	t	small
127100	5008	291	Тюменская область, Заводоуковский район, село Тумашово, Школьная, 9	f	small
127104	5012	295	Тюменская область, Заводоуковский район, село Сунгурово, Клубная, 5а	t	small
127098	5006	289	Тюменская область, Заводоуковский район, село Степной, Береговая, 2	t	small
127088	4995	278	Тюменская область, Заводоуковский район, село Старая Заимка, Клубная, 5А	f	medium
127090	4997	280	Тюменская область, Заводоуковский район, село Сосновка, Центральна, 52	f	medium
127099	5007	290	Тюменская область, Заводоуковский район, село Семеново, Центральная, 16	t	small
127111	5019	302	Тюменская область, Заводоуковский район, село Сединкино, Центральная, 4	t	small
127096	5004	287	Тюменская область, Заводоуковский район, село Речной, Шоссейная, 7	f	small
127109	5017	300	Тюменская область, Заводоуковский район, село Пономарева, Луговая, 39	f	small
127110	5018	301	Тюменская область, Заводоуковский район, село Першино, Центральная, 25	t	small
127095	5003	286	Тюменская область, Заводоуковский район, поселок Падун, Школьная, 3	f	medium
127094	5002	285	Тюменская область, Заводоуковский район, поселок Падун, Молодежная, 27	f	medium
127076	4983	266	Тюменская область, Заводоуковский район, село Озерки, 1я Озерная, 4	t	small
127102	5010	293	Тюменская область, Заводоуковский район, село Новолыбаево, Первомайская, 4А	t	medium
127086	4993	276	Тюменская область, Заводоуковский район, Новозаимская, Пионерская, 3	t	small
127083	4990	273	Тюменская область, Заводоуковский район, село Новая Заимка, Мира, 13	f	medium
127084	4991	274	Тюменская область, Заводоуковский район, село Новая Заимка, Ленина, 47	f	small
127082	4989	272	Тюменская область, Заводоуковский район, село Новая Заимка, Ленина, 180	f	medium
127081	4988	271	Тюменская область, Заводоуковский район, село Новая Заимка, Вокзальная, 1	f	medium
127085	4992	275	Тюменская область, Заводоуковский район, село Новая Заимка, Базарная, 2	f	medium
127106	5014	297	Тюменская область, Заводоуковский район, село Нижнеингал, Северная, 2	t	small
127075	4982	265	Тюменская область, Заводоуковский район, поселок Мичуринский, Лесная, 6	f	small
127089	4996	279	Тюменская область, Заводоуковский район, село Марково, Центральная, 23	t	small
127072	4980	263	Тюменская область, Заводоуковский район, село Лесной, Лесная, 26	f	small
78259	5001	284	Тюменская область, Заводоуковский район, поселок Лебедевка, Советская, 33	f	large
127080	4987	270	Тюменская область, Заводоуковский район, село Красная, Красная, 33	t	small
127091	4998	281	Тюменская область, Заводоуковский район, село Кошелева, Береговая, 13А	t	small
127107	5015	298	Тюменская область, Заводоуковский район, поселок Комсомольский, Дачная, 14	f	medium
127078	4985	268	Тюменская область, Заводоуковский район, Комиссарово, Лесная,  17	t	small
127103	5011	294	Тюменская область, Заводоуковский район, село Комарова, Притобольная, 22	t	small
127092	4999	282	Тюменская область, Заводоуковский район, село Каменка, Первомайская, 16А	t	small
77880	4967	250	Тюменская область, Заводоуковский район, город Заводоуковск, Вокзальная, 55, 627140	f	large
127079	4986	269	Тюменская область, Заводоуковский район, село Дронова, Новая, 1а	t	small
75140	87486	2509	Свердловская область, Серов, Попова, 19	f	large
127071	4979	262	Тюменская область, Заводоуковский район, село Горюново, Октябрьская, 32	f	small
127108	5016	299	Тюменская область, Заводоуковский район, село Гилево, Советская, 29	f	medium
127087	4994	277	Тюменская область, Заводоуковский район, село Боровинка, Ленина, 40А	f	medium
127069	4977	260	Тюменская область, Заводоуковский район, село Бигила, Советская, 1	f	small
127045	4934	217	Тюменская область, Голышмановский район, село Шулындино, Дзержинского, 2	t	small
127046	4935	218	Тюменская область, Голышмановский район, село Черемшанка, п. Лепустина,, 7	f	small
127063	4959	241	Тюменская область, Голышмановский район, село Усть-Ламенка, Пищика, 1	f	medium
127060	4956	238	Тюменская область, Голышмановский район, село Средние Чирки, Советская, 13	t	medium
127059	4955	237	Тюменская область, Голышмановский район, село Ражево, Строительная, 1	t	medium
127052	4947	230	Тюменская область, Голышмановский район, село Оськина, Центральная, 46	t	small
127064	4960	242	Тюменская область, Голышмановский район, село Новая Хмелевка, Школьная, 7	f	small
127053	4948	231	Тюменская область, Голышмановский район, село Никольск, Мира, 30	t	small
127058	4954	236	Тюменская область, Голышмановский район, село Медведево, Молодежная, 9	f	medium
127057	4953	235	Тюменская область, Голышмановский район, село Малышенка, 50 лет Октября, 1	f	medium
127061	4957	239	Тюменская область, Голышмановский район, село Лапушина, Мельникайте, 16	t	small
127056	4952	234	Тюменская область, Голышмановский район, поселок Ламенский, Пролетарская, 2	f	medium
127055	4951	233	Тюменская область, Голышмановский район, село Королево, Ленина, 12	f	medium
127054	4949	232	Тюменская область, Голышмановский район, село Земляная, Советская, 29	t	small
127051	4946	229	Тюменская область, Голышмановский район, село Евсино, Подоляка, 8	f	small
77873	4944	227	Тюменская область, Голышмановский район, поселок Голышманово, Садовая, 128	f	large
77871	4940	223	Тюменская область, Голышмановский район, поселок Голышманово, Садовая, 72	f	large
77870	4938	221	Тюменская область, Голышмановский район, поселок Голышманово, Садовая, 1	f	large
127047	4936	219	Тюменская область, Голышмановский район, поселок Голышманово, Московский переулок, 23	f	medium
77869	4937	220	Тюменская область, Голышмановский район, поселок Голышманово, Московская, 1А	f	large
127049	4941	224	Тюменская область, Голышмановский район, поселок Голышманово, Комсомольская, 86	f	medium
77872	4943	226	Тюменская область, Голышмановский район, поселок Голышманово, Карла Маркса, 160	f	large
127050	4942	225	Тюменская область, Голышмановский район, поселок Голышманово, К. Маркса, 92	f	medium
77874	4945	228	Тюменская область, Голышмановский район, поселок городского типа Голышманово, Молодежная, 18	f	large
127044	4933	216	Тюменская область, Голышмановский район, село Голышманово, Московская, 1	f	small
127043	4932	215	Тюменская область, Голышмановский район, село Гладилово, Кормильцева , 15	f	medium
127042	4931	214	Тюменская область, Голышмановский район, село Боровлянка, 60 лет Октября, 10	f	medium
127041	4930	213	Тюменская область, Голышмановский район, село Бескозобово, Пролетарская, 13	f	small
127033	4921	205	Тюменская область, Викуловский район, село Шешуки, Школьная, 1	t	small
127038	4927	210	Тюменская область, Викуловский район, село Чуртан, Фрунзенская, 33	f	small
127016	4903	188	Тюменская область, Викуловский район, село Чебаклей, Кузнецова, 4	f	small
127020	4908	192	Тюменская область, Викуловский район, село Усть-Барсук, Садовая, 20	t	small
127036	4925	208	Тюменская область, Викуловский район, село Староборовая, Солнечная, 19	t	small
127034	4923	206	Тюменская область, Викуловский район, село Сартам, Молодежная, 23	f	small
127032	4920	204	Тюменская область, Викуловский район, село Рябово, Советская, 4	f	small
127029	4917	201	Тюменская область, Викуловский район, село Поддубровное, Школьная, 1	f	small
127027	4915	199	Тюменская область, Викуловский район, село Озёрное, Советская, 58	t	medium
127030	4918	202	Тюменская область, Викуловский район, село Одино, Зелёная, 34	t	small
127025	4913	197	Тюменская область, Викуловский район, село Нововяткино, Мира, 7	f	small
127031	4919	203	Тюменская область, Викуловский район, село Малышево, Пушкина, 20	t	small
127039	4928	211	Тюменская область, Викуловский район, село Малахово, Радищева, 28	t	small
127022	4910	194	Тюменская область, Викуловский район, село Коточиги, 8 Марта, 4	f	medium
127026	4914	198	Тюменская область, Викуловский район, село Комиссаровка, Школьная, 2	t	small
127021	4909	193	Тюменская область, Викуловский район, село Каргалы, Советская, 13	f	medium
127018	4905	190	Тюменская область, Викуловский район, село Калинино, 60 лет СССР, 10/1	f	small
127013	4896	181	Тюменская область, Викуловский район, село Заборка, Центральная, 4	f	small
127017	4904	189	Тюменская область, Викуловский район, село Ермаки, Школьная, 3	f	small
127040	4929	212	Тюменская область, Викуловский район, село Доставалово, Ишимская, 2	t	small
127035	4924	207	Тюменская область, Викуловский район, село Долгушино, Озёрная, 26	t	small
77868	4902	187	Тюменская область, Викуловский район, село Викулово, Солнечная, 9	f	large
77865	4899	184	Тюменская область, Викуловский район, село Викулово, Ленина, 6	f	large
77866	4900	185	Тюменская область, Викуловский район, село Викулово, Кузнецова, 51	f	large
77867	4901	186	Тюменская область, Викуловский район, село Викулово, переулок Заводской, 6	f	large
127024	4912	196	Тюменская область, Викуловский район, село Бородино, Строителей, 2	t	small
127019	4906	191	Тюменская область, Викуловский район, село Борки, Молодёжная, 1	t	small
127015	4898	183	Тюменская область, Викуловский район, село Боково, Школьная, 45/3	f	small
127014	4897	182	Тюменская область, Викуловский район, село Березино, Новая, 3	f	small
127011	4894	179	Тюменская область, Викуловский район, село Балаганы, Ленина, 11	f	medium
127023	4911	195	Тюменская область, Викуловский район, село Базариха, переулок Строителей, 6	t	small
127028	4916	200	Тюменская область, Викуловский район, село Ачимово, Озерная, 38	t	small
126987	4867	154	Тюменская область, Вагайский район, село Юрмы, переул. Дорожный, 2	f	small
126984	4864	151	Тюменская область, Вагайский район, село Шишкина, Зеленая, 5А	f	small
126986	4866	153	Тюменская область, Вагайский район, село Шестовое, Совхозная, 18	f	small
126977	4856	144	Тюменская область, Вагайский район, село Черное, Библиотечная, 1	f	medium
127006	4888	174	Тюменская область, Вагайский район, село Фатеево, Мира, 1	t	small
126985	4865	152	Тюменская область, Вагайский район, село Ушаково, Ленина, 67А	f	small
126992	4872	159	Тюменская область, Вагайский район, село Тукуз, Береговая, 25	f	medium
127004	4886	172	Тюменская область, Вагайский район, село Супра, Новая, 27	f	small
126990	4870	157	Тюменская область, Вагайский район, село Сулейменская, Комсомольская, 13/2	t	small
126976	4852	140	Тюменская область, Вагайский район, село Старый Погост, Молодежная, 4	t	small
126998	4880	166	Тюменская область, Вагайский район, село Ренчики, Ренченская, 21а	t	small
126982	4861	149	Тюменская область, Вагайский район, село Птицкое, Школьная, 9	f	small
126979	4858	146	Тюменская область, Вагайский район, поселок Первомайский, Советская, 23	f	small
126931	4806	95	Тюменская область, Вагайский район, село Новые Юрты, Береговая, 5	t	small
126993	4873	160	Тюменская область, Вагайский район, село Малый Уват, Озерная, 16А	f	small
126983	4863	150	Тюменская область, Вагайский район, село Малые Конданы, Школьная, 1	t	small
127003	4885	171	Тюменская область, Вагайский район, село Курья, Школьная, 3	f	small
126973	4849	137	Тюменская область, Вагайский район, село Куларовское, Озерная, 28	t	small
126974	4850	138	Тюменская область, Вагайский район, село Куларово, Школьная, 1	t	small
127010	4893	178	Тюменская область, Вагайский район, село Кобякская, Школьная, 4а	t	small
126997	4878	164	Тюменская область, Вагайский район, село Касьяново, Школьная, 11	t	small
126991	4871	158	Тюменская область, Вагайский район, село Казанское, Школьная, 3	f	small
127005	4887	173	Тюменская область, Вагайский район, село Иртыш, Кедровая, 2А	t	small
127007	4889	175	Тюменская область, Вагайский район, село Инжура, Центральная, 18А	t	small
126988	4868	155	Тюменская область, Вагайский район, поселок Заречный, Школьная, 4а	t	large
77864	4879	165	Тюменская область, Вагайский район, село Дубровное, Запольная, 6	f	large
126999	4881	167	Тюменская область, Вагайский район, село Второсалинская, Центральная, 28а	t	small
127009	4891	177	Тюменская область, Вагайский район, село Второвагайское, Центральная, 9	t	small
126975	4851	139	Тюменская область, Вагайский район, село Вагай, Школьная, 28	f	\N
77861	4853	141	Тюменская область, Вагайский район, село Вагай, Мира, 18	f	large
77863	4855	143	Тюменская область, Вагайский район, село Вагай, Дорожный переулок, 5	f	large
77862	4854	142	Тюменская область, Вагайский район, село Вагай, Ленина, 6	f	large
126981	4860	148	Тюменская область, Вагайский район, село Бушмина, Октябрьская, 12	t	small
127001	4883	169	Тюменская область, Вагайский район, село Большой Карагай, Первомайская, 1	f	small
127008	4890	176	Тюменская область, Вагайский район, село Бегишево, переулок Школьный, 13	f	small
126955	4830	119	Тюменская область, Бердюжский район, село Шабурова, Мира,  7	t	small
126972	4848	136	Тюменская область, Бердюжский район, село Старорямова, Ленина, 34	f	small
126953	4828	117	Тюменская область, Бердюжский район, село Полозаозерье, площадь Волкова, 5	f	small
126960	4835	124	Тюменская область, Бердюжский район, село Пеганово, Ленина, 19	f	medium
126961	4836	125	Тюменская область, Бердюжский район, село Останино, Марикова, 26	t	small
126962	4837	126	Тюменская область, Бердюжский район, село Окунево, Ленина, 20	f	medium
126963	4838	127	Тюменская область, Бердюжский район, село Одышка, Береговая, 24	f	small
126958	4833	122	Тюменская область, Бердюжский район, село Мелехино, Ленина, 42	f	small
126957	4832	121	Тюменская область, Бердюжский район, село Луговая, Чехова, 40	t	small
126952	4827	116	Тюменская область, Бердюжский район, село Кутырева, Центральная, 34	f	small
126965	4840	129	Тюменская область, Бердюжский район, село Карькова, Центральная, 14	t	small
126954	4829	118	Тюменская область, Бердюжский район, село Истошино, Алексеева, 48	f	small
126967	4842	131	Тюменская область, Бердюжский район, село Зарослое, Новая, 16	f	small
126942	4817	106	Тюменская область, Бердюжский район, село Гагарина, Школьная, 25	f	\N
126971	4846	135	Тюменская область, Бердюжский район, село Воробьево, Центральная, 22	f	small
126956	4831	120	Тюменская область, Бердюжский район, село Босоногова, Победы, 45	t	small
126951	4826	115	Тюменская область, Бердюжский район, село Бердюжье, Чкалова, 91	f	small
126944	4819	108	Тюменская область, Бердюжский район, село Бердюжье, Чкалова, 40	f	small
126946	4821	110	Тюменская область, Бердюжский район, село Бердюжье, Молодежная, 7	f	medium
126950	4825	114	Тюменская область, Бердюжский район, село Бердюжье, Кирова, 1	f	small
126949	4824	113	Тюменская область, Бердюжский район, село Бердюжье, Кирова, 13	f	small
126943	4818	107	Тюменская область, Бердюжский район, село Бердюжье, Гнаровской, 1	f	small
126947	4822	111	Тюменская область, Бердюжский район, село Бердюжье, Герцена, 2	f	medium
126945	4820	109	Тюменская область, Бердюжский район, село Бердюжье, Аф. Калинина, 2	f	small
126941	4816	105	Тюменская область, Аромашевский район, село Юрминка, Молчанова, 19А	f	medium
126924	4799	88	Тюменская область, Аромашевский район, село Усть-Лотовка, Центральная, 26	t	small
126939	4814	103	Тюменская область, Аромашевский район, село Сорочкино, Советская, 95	f	small
126921	4796	85	Тюменская область, Аромашевский район, село Смородиновка, Школьная, 27а	t	small
126936	4811	100	Тюменская область, Аромашевский район, село Слободчики, Береговая, 2	f	small
126935	4810	99	Тюменская область, Аромашевский район, село Русаково	f	small
126927	4802	91	Тюменская область, Аромашевский район, село Овсово, Одина, 28	f	small
126933	4808	97	Тюменская область, Аромашевский район, село Новоуфимская, Лесная, 17	t	small
126930	4805	94	Тюменская область, Аромашевский район, село Новопетрово, Школьная, 5	t	small
126932	4807	96	Тюменская область, Аромашевский район, село Новопетрово, Посёлковая, 9	t	small
126928	4803	92	Тюменская область, Аромашевский район, село Новоберезовка, Центральная, 33	t	medium
126940	4815	104	Тюменская область, Аромашевский район, село Новоаптула, Салавата Юлаева, 77	f	small
126937	4812	101	Тюменская область, Аромашевский район, село Николаевка, Центральная, 15	t	small
126925	4800	89	Тюменская область, Аромашевский район, село Малиновка, Советская, 21	f	small
126922	4797	86	Тюменская область, Аромашевский район, село Кротово, Советская, 44	f	small
126920	4795	84	Тюменская область, Аромашевский район, село Кармацкая, Мира, 11	f	small
126923	4798	87	Тюменская область, Аромашевский район, село Вилкова, Центральная, 13	t	small
126938	4813	102	Тюменская область, Аромашевский район, село Валгина, Центральная,  9	t	small
126929	4804	93	Тюменская область, Аромашевский район, село Большой Кусеряк, Школьная, 26	t	small
126918	4793	82	Тюменская область, Аромашевский район, село Большескаредная, Центральная, 1	t	small
77860	4790	79	Тюменская область, Аромашевский район, село Аромашево, Октябрьская, 35	f	large
126917	4792	81	Тюменская область, Аромашевский район, село Аромашево, Ленина, 348	f	medium
126915	4789	78	Тюменская область, Аромашевский район, село Аромашево, Ленина, 158	f	medium
126919	4794	83	Тюменская область, Аромашевский район, село Аромашево, Декабристов, 12	t	medium
126916	4791	80	Тюменская область, Аромашевский район, село Аромашево, 1 Мая, 73	f	medium
126896	4769	59	Тюменская область, Армизонский район, село Яровое	f	small
126913	4787	76	Тюменская область, Армизонский район, село Южно-Дубровное, Береговая, 4	f	small
126895	4768	58	Тюменская область, Армизонский район, село Снегирева, Снегиревская, 1Б	t	small
126894	4767	57	Тюменская область, Армизонский район, село Семискуль, Семискульская, 19	t	small
126912	4786	75	Тюменская область, Армизонский район, село Раздолье, Школьная, 28	f	small
126909	4783	72	Тюменская область, Армизонский район, село Прохорово, Новая, 19	f	small
126914	4788	77	Тюменская область, Армизонский район, село Полое, Центральная, 19А	t	small
126899	4772	62	Тюменская область, Армизонский район, село Плоское, Старина, 53	f	small
126907	4781	70	Тюменская область, Армизонский район, село Орлово, Школьная, 8	f	small
126905	4779	68	Тюменская область, Армизонский район, село Няшино, Центральная, 1	t	small
126902	4775	65	Тюменская область, Армизонский район, село Новорямова, Мира, 6	t	small
126897	4770	60	Тюменская область, Армизонский район, село Менщиково, улица Школьная, 9	t	small
126900	4773	63	Тюменская область, Армизонский район, село Крашенева, Крашеневская, 26	t	small
126904	4778	67	Тюменская область, Армизонский район, село Красноорловское, Республики, 1/1	f	small
126903	4777	66	Тюменская область, Армизонский район, село Капралиха, Первомайская, 11	f	small
126901	4774	64	Тюменская область, Армизонский район, село Калмакское, Новая, 5	f	small
126898	4771	61	Тюменская область, Армизонский район, село Иваново, 50 лет Октября, 49	f	small
126906	4780	69	Тюменская область, Армизонский район, село Забошное, Набережная, 38	t	small
126910	4784	73	Тюменская область, Армизонский район, село Жиряково, Центральная, 61	f	small
126911	4785	74	Тюменская область, Армизонский район, село Вьялково, Центральная, 2А	t	small
126908	4782	71	Тюменская область, Армизонский район, село Бурлаки, Центральная, 14	t	small
77859	4766	56	Тюменская область, Армизонский район, село Армизонское, Рабочая, 20	f	large
126893	4765	55	Тюменская область, Армизонский район, село Армизонское, Ленина, 72	f	medium
77858	4763	53	Тюменская область, Армизонский район, село Армизонское, Кирова, 1	f	large
126892	4764	54	Тюменская область, Армизонский район, село Армизонское, Карла Маркса, 5	f	\N
126860	4731	21	Тюменская область, Абатский район, п. Нефтяников, Лесная, 1	t	small
126878	4749	39	Тюменская область, Абатский район, село Яузяк, пер. Школьный, 4	f	small
126849	4720	10	Тюменская область, Абатский район, село Шипунова, Игнатенко, 20	f	small
126887	4758	48	Тюменская область, Абатский район, село Шевырино, Маслова, 13	f	small
126877	4748	38	Тюменская область, Абатский район, село Челнокова, Погорельская, 3	t	small
126884	4755	45	Тюменская область, Абатский район, село Фирсова, Механизаторов, 8	t	small
126881	4752	42	Тюменская область, Абатский район, село Тушнолобово, Советская, 44	f	small
126876	4747	37	Тюменская область, Абатский район, село Тельцова, Школьная, 12	f	small
126889	4760	50	Тюменская область, Абатский район, село Татарская, Совхозная, 58	t	small
126852	4723	13	Тюменская область, Абатский район, село Сычево, Лермонтова, 31	t	small
126855	4726	16	Тюменская область, Абатский район, село Сысоева, Первомайская, 11	f	small
126868	4739	29	Тюменская область, Абатский район, село Старая Маслянка, 60 лет СССР, 57	f	small
126875	4746	36	Тюменская область, Абатский район, село Спирина, Мира, 12	f	small
126890	4761	51	Тюменская область, Абатский район, село Смоленка,  Зеленая, 23	t	small
126883	4754	44	Тюменская область, Абатский район, село Репьева, Аризонская, 15	t	small
75413	89129	2497	Свердловская область, Серов, Победы, 36	f	large
126874	4745	35	Тюменская область, Абатский район, село Погорелка, Центральная, 34	f	small
126879	4750	40	Тюменская область, Абатский район, село Партизан, 8 марта, 34	t	small
126867	4738	28	Тюменская область, Абатский район, село Пайкова, Школьная, 6	t	small
126872	4743	33	Тюменская область, Абатский район, село Ощепково, Пушкина, 12	f	medium
126869	4740	30	Тюменская область, Абатский район, село Назарово, 1 Мая, 2	f	small
126866	4737	27	Тюменская область, Абатский район, село Мешалкина, Зеленая, 40	t	small
126864	4735	25	Тюменская область, Абатский район, село Марай, Рабочая, 4	t	small
126865	4736	26	Тюменская область, Абатский район, поселок Майский, Юбилейная, 4	f	medium
126861	4732	22	Тюменская область, Абатский район, село Ленинка, Ленина, 39	f	medium
126858	4729	19	Тюменская область, Абатский район, село Лапина, Советская, 20	f	small
126854	4725	15	Тюменская область, Абатский район, село Костылева, Армизонская, 23	f	small
126856	4727	17	Тюменская область, Абатский район, село Конево, Советская, 42	f	medium
126880	4751	41	Тюменская область, Абатский район, село Камышинская, 8 марта, 13	t	small
126891	4762	52	Тюменская область, Абатский район, село Камышинка, Энергетиков, 12	t	small
126845	4715	6	Тюменская область, Абатский район, село Еремина, Маслова, 17	t	small
126863	4734	24	Тюменская область, Абатский район, село Восток, пер. Восточный, 7	t	small
126873	4744	34	Тюменская область, Абатский район, село Быструха, Центральная, 58	f	medium
126853	4724	14	Тюменская область, Абатский район, село Болдырево, Молодежная, 22	f	small
126844	4714	5	Тюменская область, Абатский район, село Бобыльск, Зеленая, 10	f	small
126850	4721	11	Тюменская область, Абатский район, село Банниково, Гагарина, 1	f	medium
77857	4712	3	Тюменская область, Абатский район, село Абатское, Ленина, 102	f	large
77855	4710	1	Тюменская область, Абатский район, село Абатское, Ленина, 14	f	large
126843	4713	4	Тюменская область, Абатский район, село Абатское, Дорожная, 50	f	medium
77856	4711	2	Тюменская область, Абатский район, село Абатское, 1 Мая, 56	f	large
122814	88976	2402	Свердловская область, станция Решёты, 14, Здание семейного общежития	t	small
122860	89164	2516	Свердловская область, п. Восточный, Парковая, 4а	t	small
75144	89159	2513	Свердловская область, Филькино, Путилова, 4	t	large
74370	87000	1030	Свердловская область, Туринск, Горького, 46	f	large
122586	87961	1776	Свердловская область, поселок Торфяник, Агатовая, 3	t	small
75036	86761	844	Свердловская область, Сысерть, микрорайон Новый, 29	f	large
75030	86753	838	Свердловская область, Сысерть, Энгельса, 23	f	large
75039	86768	847	Свердловская область, Сысерть, Чапаева, 1	f	large
74910	86800	877	Свердловская область, Сысерть, Трактовая, 15	f	large
75038	86766	846	Свердловская область, Сысерть, Тимерязева, 168	f	large
75037	86763	845	Свердловская область, Сысерть, Свердлова, 80	f	large
75034	86707	842	Свердловская область, Сысерть, Самстроя, 9	t	large
75033	86719	841	Свердловская область, Сысерть, Розы Люксембург, 56	f	large
75032	86756	840	Свердловская область, Сысерть, Орджоникидзе, 48	f	large
75035	86759	843	Свердловская область, Сысерть, Ленина, 32	f	large
75031	86754	839	Свердловская область, Сысерть, Красноармейская, 32	f	large
75596	89195	2532	Свердловская область, Сухой Лог, Юбилейная, 29а	f	large
75600	89208	2538	Свердловская область, Сухой Лог, Октябрьская, 14а	f	large
75588	89180	2524	Свердловская область, Среднеуральск, Металлистов, 36а	f	large
75193	89175	2522	Свердловская область, Среднеуральск, Калинина, 14	f	large
122244	86877	950	Свердловская область, село Смолинское, Специалистов, 14	t	medium
121853	86418	615	Свердловская область, поселок Сигнальный, Клубная, 29А	t	medium
75302	89088	2468	Свердловская область, Серов	f	large
75354	89100	2475	Свердловская область, Серов, пр.Серова, 67	f	large
75306	89094	2472	Свердловская область, Серов, пр.Серова, 1а	f	large
75305	89094	2471	Свердловская область, Серов, пр.Серова, 1а	f	large
75134	89137	2500	Свердловская область, Серов, пер.Толмачева, 4а	f	large
75415	89135	2499	Свердловская область, Серов, Я.Свердлова, 54а	f	large
75364	89113	2485	Свердловская область, Серов, Ф.Революции, 7	f	large
75141	89154	2510	Свердловская область, Серов, Строителей, 17	f	large
75138	89149	2506	Свердловская область, Серов, Республиканская, 30	f	large
75304	89092	2470	Свердловская область, Серов, Нансена, 60	f	large
75375	89127	2496	Свердловская область, Серов, Луначарского, 100	f	large
75142	89155	2511	Свердловская область, Серов, Ломоносова, 1	f	large
75137	89145	2504	Свердловская область, Серов, Лесозаводская, 34	f	large
75366	89115	2487	Свердловская область, Серов, Ленина, 167	f	large
75365	89115	2486	Свердловская область, Серов, Ленина, 167	f	large
75363	89111	2484	Свердловская область, Серов, Ленина, 156	f	large
75362	89109	2483	Свердловская область, Серов, Ленина, 185	f	large
75357	87417	2478	Свердловская область, Серов, Ленина, 193/8	f	large
75358	87417	2479	Свердловская область, Серов, Ленина, 193/8	f	large
75143	89158	2512	Свердловская область, Серов, Л.Чайкиной, 31	f	large
75356	89102	2477	Свердловская область, Серов, Крупской, 36	f	large
75355	89102	2476	Свердловская область, Серов, Крупской, 36	f	large
75353	89097	2474	Свердловская область, Серов, Крупской, 33	f	large
122848	89096	2473	Свердловская область, Серов, Крупской, 24	f	\N
75361	89106	2482	Свердловская область, Серов, Короленко, 16	f	large
75360	89106	2481	Свердловская область, Серов, Короленко, 16	f	large
75359	89104	2480	Свердловская область, Серов, Короленко, 35	f	large
122851	89143	2503	Свердловская область, Серов, Киселевское шоссе, 10	f	medium
75135	89138	2501	Свердловская область, Серов, Кирова, 51	f	large
75414	89132	2498	Свердловская область, Серов, Калинина, 22	f	large
75371	89122	2492	Свердловская область, Серов, Каквинская, 3	f	large
75367	89116	2488	Свердловская область, Серов, К.Маркса, 24	f	large
122849	89123	2493	Свердловская область, Серов, Зеленая, 7	f	\N
75370	89119	2491	Свердловская область, Серов, Зеленая, 14	f	large
75369	89119	2490	Свердловская область, Серов, Зеленая, 14	f	large
75368	87451	2489	Свердловская область, Серов, Зеленая, 1а	f	large
75373	89126	2494	Свердловская область, Серов, Заславского, 34	f	large
75374	89126	2495	Свердловская область, Серов, Заславского, 34	f	large
122855	89151	2507	Свердловская область, Серов, Восточная, 10а	f	small
75136	89141	2502	Свердловская область, Серов, 8 Марта, 16	f	large
75303	89073	2469	Свердловская область, Серов, 20 Партсъезда, 13	f	large
122853	89146	2505	Свердловская область, Серов, 1 Овощная ферма, 37	f	medium
122908	89320	2615	Свердловская область, Североуральск, очистные сооружения шахты 1616 бис	f	small
75709	89055	2617	Свердловская область, Североуральск, Степана Разина, 1	f	large
75469	89055	2451	Свердловская область, Североуральск, Степана Разина, 1	f	large
75295	89066	2457	Свердловская область, Североуральск, Советская, 28	f	large
75428	89047	2447	Свердловская область, Североуральск, Советская, 41	f	large
75292	89059	2454	Свердловская область, Североуральск, Свердлова, 5	f	large
75471	89058	2453	Свердловская область, Североуральск, Свердлова, 44	f	large
75708	89323	2616	Свердловская область, Североуральск, Молодежная, 22	f	large
75294	89064	2456	Свердловская область, Североуральск, Молодежная, 4	f	large
75090	89064	2567	Свердловская область, Североуральск, Молодежная, 4	f	large
75301	89084	2466	Свердловская область, Североуральск, Ленина, 7	f	large
75470	89053	2452	Свердловская область, Североуральск, Ленина, 24	f	large
75431	89053	2450	Свердловская область, Североуральск, Ленина, 24	f	large
75429	89049	2448	Свердловская область, Североуральск, Ленина, 44	f	large
75296	89069	2459	Свердловская область, Североуральск, Комсомольская, 44	f	large
75297	89072	2460	Свердловская область, Североуральск, Комарова, 13А	f	large
122844	89083	2465	Свердловская область, Североуральск, Кирова, 21	f	small
75430	89052	2449	Свердловская область, Североуральск, Каржавина, 27	f	large
122841	89067	2458	Свердловская область, Североуральск, поселок Баяновка, Гагарина, 7	f	small
75293	89061	2455	Свердловская область, Североуральск, Ватутина, 17А	f	large
122910	89325	2618	Свердловская область, Североуральск, Больничный переулок, 5	f	medium
122896	89258	2568	Свердловская область, Североуральск,  Советская, 71	f	small
75009	86614	756	Свердловская область, Реж, Спортивная, 1а	f	large
75012	86618	759	Свердловская область, Реж, Советская, 34	f	large
122029	86631	770	Свердловская область, Реж, П.Морозова, 58	f	small
122019	86606	748	Свердловская область, Ревда, Бытовые помещения участка подготовки материалов ЭСПЦ "НСММЗ"	t	medium
75004	86604	747	Свердловская область, Ревда, Дом культуры поселка Кирзавод	f	large
75001	86600	743	Свердловская область, Ревда, Энгельса, 47	f	large
122014	83661	728	Свердловская область, Ревда, Чехова, 15	f	medium
74758	86597	739	Свердловская область, Ревда, Чайковского, 27	f	large
74757	86596	738	Свердловская область, Ревда, Цветников, 36	f	large
74752	86590	733	Свердловская область, Ревда, Цветников, 46	f	large
74747	82541	726	Свердловская область, Ревда, Толстого, 1	f	large
122015	86588	732	Свердловская область, Ревда, Спортивная, 16	f	\N
122012	82944	727	Свердловская область, Ревда, Спортивная, 2	f	medium
122026	86610	752	Свердловская область, Ревда, С.Разина, 20а	f	small
74756	86595	737	Свердловская область, Ревда, Российская, 44	f	large
74748	86585	729	Свердловская область, Ревда, Российская, 12	f	large
122016	86592	735	Свердловская область, Ревда, Павла Зыкина, 32	f	\N
122018	86601	744	Свердловская область, Ревда, П.Зыкина, 38	f	medium
75000	86599	742	Свердловская область, Ревда, П.Зыкина, 18	f	large
74746	82059	725	Свердловская область, Ревда, Нахимова, 1	f	large
74755	86594	736	Свердловская область, Ревда, Мира, 42	f	large
74750	86587	731	Свердловская область, Ревда, Мира, 26а	f	large
75003	86603	746	Свердловская область, Ревда, Мамина-Сибиряка, 94	f	large
75006	86611	753	Свердловская область, Ревда, М.Горького, 40	f	large
74753	86591	734	Свердловская область, Ревда, М.Горького, 5	f	large
75005	86607	749	Свердловская область, Ревда, Лесная, 2	f	large
75002	86602	745	Свердловская область, Ревда, Ленина, 18	f	large
74395	87299	1236	Свердловская область, Ревда, Калинина, 31А	f	large
74999	86598	741	Свердловская область, Ревда, К.Либкнехта, 64	f	large
74749	86586	730	Свердловская область, Ревда, Жуковского, 22	f	large
74998	83799	740	Свердловская область, Ревда, Азина, 58	f	large
75291	89016	2428	Свердловская область, Полевской, микрорайон Зелёный Бор 1 , 26	f	large
75290	89016	2427	Свердловская область, Полевской, микрорайон Зелёный Бор 1 , 26	f	large
75289	89016	2426	Свердловская область, Полевской, микрорайон Зелёный Бор 1 , 26	f	large
75288	89016	2425	Свердловская область, Полевской, микрорайон Зелёный Бор 1 , 26	f	large
75240	88995	2412	Свердловская область, Полевской, Ялунина, 7, А	f	large
75239	88993	2411	Свердловская область, Полевской, Ялунина, 7А	f	large
75419	89023	2432	Свердловская область, Полевской, Челюскинцев, 1	f	large
75249	89014	2422	Свердловская область, Полевской, Ст. Разина, 51	f	large
75248	89011	2421	Свердловская область, Полевской, Ст. Разина, 48	f	large
75250	89011	2423	Свердловская область, Полевской, Ст. Разина, 48	f	large
122832	89033	2438	Свердловская область, Полевской, Северская, 1а 	f	\N
75251	89008	2424	Свердловская область, Полевской, Р. Люксембург, 95	f	large
75246	89008	2419	Свердловская область, Полевской, Р. Люксембург, 95	f	large
75244	89002	2416	Свердловская область, Полевской, Р. Люксембург, 4	f	large
75416	89018	2429	Свердловская область, Полевской, Победы, 26	f	large
122828	88992	2410	Свердловская область, Полевской, Партизанская, 38	f	medium
75421	89028	2434	Свердловская область, Полевской, Микрорайон 2, 15	f	large
75423	89031	2436	Свердловская область, Полевской, Малышева, 65	f	large
122834	89038	2440	Свердловская область, Полевской, Ленина, 70	f	medium
75243	88999	2415	Свердловская область, Полевской, Ленина, 16	f	large
75247	89010	2420	Свердловская область, Полевской, Коммунистическая, 31	f	large
75245	89005	2418	Свердловская область, Полевской, Коммунистическая, 14	f	large
75242	88998	2414	Свердловская область, Полевской, Коммунистическая, 3	f	large
75241	88998	2413	Свердловская область, Полевской, Коммунистическая, 3	f	large
75422	89030	2435	Свердловская область, Полевской, К. Маркса, 2, Б	f	large
75424	89030	2437	Свердловская область, Полевской, К. Маркса, 2, Б	f	large
75420	89025	2433	Свердловская область, Полевской, К. Маркса, 2	f	large
75418	89022	2431	Свердловская область, Полевской, К. Маркса, 11	f	large
122830	89004	2417	Свердловская область, Полевской, Вершинина, 37	f	medium
122836	89039	2441	Свердловская область, Полевской, поселок Мраморское, 1 Мая, 17	f	medium
75417	89019	2430	Свердловская область, Полевской, К. Маркса, 12	f	large
122812	88975	2401	Свердловская область, Первоуральск, ж/ст Хрустальная, Здание столовой (библиотеки)	t	small
75488	88888	2353	Свердловская область, Первоуральск, проспект Ильича, 6	f	large
75209	88939	2382	Свердловская область, Первоуральск, Энгельса, 13А	f	large
75485	88885	2350	Свердловская область, Первоуральск, Чкалова, 17	f	large
75483	88880	2348	Свердловская область, Первоуральск, Чкалова, 26	f	large
75486	88880	2351	Свердловская область, Первоуральск, Чкалова, 26	f	large
75489	88891	2354	Свердловская область, Первоуральск, Трубников, 64а	f	large
75482	88878	2347	Свердловская область, Первоуральск, Трубников, 46а	f	large
75540	88905	2365	Свердловская область, Первоуральск, Строителей, 7	f	large
75539	88905	2364	Свердловская область, Первоуральск, Строителей, 7	f	large
122795	88904	2362	Свердловская область, Первоуральск, Строителей, 7	f	\N
75534	88898	2359	Свердловская область, Первоуральск, Строителей, 9	f	large
75533	88898	2358	Свердловская область, Первоуральск, Строителей, 9	f	large
122808	88969	2398	Свердловская область, Первоуральск, Советская, 48	t	small
122811	88940	2399	Свердловская область, Первоуральск, Советская, 13	f	small
75472	88865	2337	Свердловская область, Первоуральск, Советская, 20в	f	large
75063	88865	2336	Свердловская область, Первоуральск, Советская, 20в	f	large
75585	88935	2380	Свердловская область, Первоуральск, Сантехизделий, 34	f	large
75548	88925	2375	Свердловская область, Первоуральск, СХПК Первоуральский, 8	f	large
75586	88937	2381	Свердловская область, Первоуральск, СТИ, 34	f	large
75584	88932	2379	Свердловская область, Первоуральск, Пушкина, 11а	f	large
75550	88929	2377	Свердловская область, Первоуральск, Проспект Ильича, 13	f	large
75211	88943	2384	Свердловская область, Первоуральск, Пролетарская, 70	f	large
122799	88919	2371	Свердловская область, Первоуральск, Пархоменко, 12	f	\N
75487	88886	2352	Свердловская область, Первоуральск, Папанинцев, 8	f	large
122806	88962	2393	Свердловская область, Первоуральск, поселок Перескачка, Новая, 4	t	small
75210	88942	2383	Свердловская область, Первоуральск, Набережная, 9	f	large
75532	88897	2357	Свердловская область, Первоуральск, Ленина, 21б	f	large
75219	88964	2395	Свердловская область, Первоуральск, Крупской, 49	f	large
75218	88964	2394	Свердловская область, Первоуральск, Крупской, 49	f	large
75819	88861	2334	Свердловская область, Первоуральск, Красноармейская, 22	f	large
75476	88871	2341	Свердловская область, Первоуральск, Космонавтов, 12	f	large
75475	88871	2340	Свердловская область, Первоуральск, Космонавтов, 12	f	large
75474	88868	2339	Свердловская область, Первоуральск, Космонавтов, 1	f	large
75473	88867	2338	Свердловская область, Первоуральск, Космонавтов, 15а	f	large
75820	88862	2335	Свердловская область, Первоуральск, Космонавтов, 19	f	large
75542	88911	2367	Свердловская область, Первоуральск, Комсомольская, 1В	f	large
75481	88877	2346	Свердловская область, Первоуральск, Комсомольская, 21б	f	large
75480	88877	2345	Свердловская область, Первоуральск, Комсомольская, 21б	f	large
75213	88948	2386	Свердловская область, Первоуральск, Коммуны, 2	f	large
75220	88966	2396	Свердловская область, Первоуральск, Клубная, 32	f	large
75543	88913	2368	Свердловская область, Первоуральск, Карбышева, 1	f	large
122797	88915	2369	Свердловская область, Первоуральск, Калинина, 30	f	medium
75490	88893	2355	Свердловская область, Первоуральск, Ильича проспект, 28а	f	large
75551	88931	2378	Свердловская область, Первоуральск, Ильича, 7	f	large
75215	88954	2389	Свердловская область, Первоуральск, Заводская, 17	f	large
75547	88923	2374	Свердловская область, Первоуральск, поселок Новоталица, З.Космодемьянской, 20	f	large
75546	88923	2373	Свердловская область, Первоуральск, поселок Новоталица, З.Космодемьянской, 20	f	large
75484	88882	2349	Свердловская область, Первоуральск, Гагарина, 77	f	large
75479	88875	2344	Свердловская область, Первоуральск, Ватутина, 73б	f	large
75478	88875	2343	Свердловская область, Первоуральск, Ватутина, 73б	f	large
75477	88873	2342	Свердловская область, Первоуральск, Ватутина, 45а	f	large
122796	88906	2363	Свердловская область, Первоуральск, Вайнера, 21А	f	\N
75536	88903	2361	Свердловская область, Первоуральск, Вайнера, 7	f	large
75544	88917	2370	Свердловская область, Первоуральск, Береговая, 48	f	large
75535	88900	2360	Свердловская область, Первоуральск, Береговая, 58	f	large
75549	88927	2376	Свердловская область, Первоуральск, 50 лет СССР, 11а	f	large
122801	88920	2372	Свердловская область, Первоуральск, 1ая Пильная, 1А	f	medium
75491	88894	2356	Свердловская область, Первоуральск, 1 Мая, 4А	f	large
134688	95007	2601	Свердловская область, поселок Пелым, Фестивальная, 12	f	\N
134687	95007	2600	Свердловская область, поселок Пелым, Фестивальная, 12	f	\N
75765	88833	2292	Свердловская область, Новоуральск, Чурина, 3	f	large
75776	88842	2304	Свердловская область, Новоуральск, Ленина, 69	t	large
75777	88842	2305	Свердловская область, Новоуральск, Ленина, 69	t	large
75770	88837	2297	Свердловская область, Новоуральск, Гагарина, 11	f	large
75467	88526	2106	Свердловская область, Нижняя Тура, Энгельса, 1	f	large
74762	86409	603	Свердловская область, Нижняя Тура, Чкалова, 11	f	large
74761	86409	602	Свердловская область, Нижняя Тура, Чкалова, 11	f	large
74766	86413	607	Свердловская область, Нижняя Тура, Пархоменко, 2	f	large
121862	86422	619	Свердловская область, Нижняя Тура, Набережная, 17	t	small
74764	86411	605	Свердловская область, Нижняя Тура, Молодежная, 10	f	large
74765	86412	606	Свердловская область, Нижняя Тура, Машиностроителей, 17А	t	large
74768	86358	609	Свердловская область, Нижняя Тура, Малышева, 26	f	large
75348	88563	2125	Свердловская область, Нижняя Тура, Ленина, 112	f	large
121852	86417	614	Свердловская область, Нижняя Тура, Ленина, 55	t	small
75335	88538	2112	Свердловская область, Нижняя Тура, Коммунистический прт, 36	f	large
74767	86324	608	Свердловская область, Нижняя Тура, Декабристов, 2А	f	large
74769	86381	610	Свердловская область, Нижняя Тура, Гайдара, 4	f	large
74763	86410	604	Свердловская область, Нижняя Тура, 40 лет Октября, 1Д	f	large
122756	88584	2137	Свердловская область, Нижняя Салда, Центральная, 52	f	small
75395	88574	2132	Свердловская область, Нижняя Салда, Фрунзе, 11	f	large
75349	88569	2129	Свердловская область, Нижняя Салда, Строителей,, 14	f	large
75350	88571	2130	Свердловская область, Нижняя Салда, Строителей, 21	f	large
75351	88537	2131	Свердловская область, Нижняя Салда, Строителей, 21	f	large
122754	88581	2136	Свердловская область, Нижняя Салда, Совхозная, 17 А	f	small
122752	88578	2134	Свердловская область, Нижняя Салда, Привокзальная, 21	t	small
122759	88585	2138	Свердловская область, Нижняя Салда, Первая, 34	t	small
75397	88579	2135	Свердловская область, Нижняя Салда, Карла Либкнехта, 79	t	large
75396	88576	2133	Свердловская область, Нижняя Салда, К.Маркса, 2	f	large
122784	88772	2287	Свердловская область, Нижний Тагил	f	\N
122775	88772	2246	Свердловская область, Нижний Тагил	f	\N
122767	88750	2232	Свердловская область, Нижний Тагил, Санаторий Руш, клуб санатория Руш	f	medium
75635	88672	2190	Свердловская область, Нижний Тагил, проспект Мира, 27	f	large
75747	88800	2267	Свердловская область, Тагилстроевский район, Нижний Тагил, проспект Мира, 67	f	large
75746	88800	2266	Свердловская область, Тагилстроевский район, Нижний Тагил, проспект Мира, 67	f	large
75745	88798	2265	Свердловская область, Тагилстроевский район, Нижний Тагил, проспект Мира, 58	f	large
75636	88674	2191	Свердловская область, Нижний Тагил, пр. Мира, 9	f	large
75407	88603	2149	Свердловская область, Нижний Тагил, Юности, 37	f	large
75405	88599	2147	Свердловская область, Нижний Тагил, Энтузиастов, 15	f	large
75402	88593	2144	Свердловская область, Нижний Тагил, Энтузиастов, 1А	f	large
75181	88630	2166	Свердловская область, Дзержинский район, Нижний Тагил, Энтузиастов, 35	f	large
75630	88665	2184	Свердловская область, Нижний Тагил, Щорса, 8А	f	large
75629	88665	2183	Свердловская область, Нижний Тагил, Щорса, 8А	f	large
75628	88663	2182	Свердловская область, Нижний Тагил, Щорса, 2	f	large
75730	88775	2247	Свердловская область, Нижний Тагил, Черноморская, 98	t	large
75733	88775	2250	Свердловская область, Нижний Тагил, Черноморская, 98	t	large
75700	88770	2245	Свердловская область, Нижний Тагил, Черноморская, 106	t	large
122765	88749	2231	Свердловская область, Нижний Тагил, Черноисточинское шоссе, 82	f	medium
75689	88744	2229	Свердловская область, Нижний Тагил, Черноисточинское шоссе, 60	f	large
75688	88743	2228	Свердловская область, Нижний Тагил, Черноисточинское шоссе, 60	f	large
75069	88813	2275	Свердловская область, Нижний Тагил, Черноисточинское шоссе, 13	f	large
75071	88813	2277	Свердловская область, Нижний Тагил, Черноисточинское шоссе, 13	f	large
75170	88739	2226	Свердловская область, Нижний Тагил, Челюскинцев, 61	f	large
75634	88670	2189	Свердловская область, Нижний Тагил, Циолковского, 41	f	large
122641	88142	1916	Свердловская область, Камышлов, Энгельса, 135	f	medium
75698	88767	2243	Свердловская область, Тагилстроевский район, Нижний Тагил, Хохрякова, 23	f	large
75697	88767	2242	Свердловская область, Тагилстроевский район, Нижний Тагил, Хохрякова, 23	f	large
75117	88712	2209	Свердловская область, Нижний Тагил, Фрунзе, 58/33	f	large
75123	88722	2215	Свердловская область, Нижний Тагил, Фрунзе, 25А	f	large
75122	88719	2214	Свердловская область, Нижний Тагил, Фрунзе, 39	f	large
75121	88719	2213	Свердловская область, Нижний Тагил, Фрунзе, 39	f	large
75078	88825	2284	Свердловская область, Нижний Тагил, Уральский проспект, 60а	f	large
75080	88827	2286	Свердловская область, Нижний Тагил, Уральский проспект, 78	f	large
75179	88627	2164	Свердловская область, Нижний Тагил, Тимирязева, 109	f	large
75180	88627	2165	Свердловская область, Нижний Тагил, Тимирязева, 109	f	large
75073	88820	2279	Свердловская область, Тагилстроевский район, Нижний Тагил, Тагилстроевская, 1а	f	large
75077	88817	2283	Свердловская область, Нижний Тагил, Тагилстроевская, 1б	f	large
75072	88817	2278	Свердловская область, Нижний Тагил, Тагилстроевская, 1б	f	large
75637	88677	2192	Свердловская область, Нижний Тагил, Строителей, 7	f	large
75690	88747	2230	Свердловская область, Нижний Тагил, Совхозная, 7	f	large
75695	88763	2240	Свердловская область, Нижний Тагил, Сланцевая, 13а	f	large
75207	88650	2176	Свердловская область, Нижний Тагил, Свердлова, 23А	f	large
75737	88785	2256	Свердловская область, Нижний Тагил, Решетникова, 29	f	large
122778	88785	2255	Свердловская область, Нижний Тагил, Решетникова, 29	f	medium
122777	88783	2254	Свердловская область, Нижний Тагил, Проезжая, 21	f	small
75732	88777	2249	Свердловская область, Тагилстроевский район, Нижний Тагил, Попова, 17	f	large
75731	88777	2248	Свердловская область, Тагилстроевский район, Нижний Тагил, Попова, 17	f	large
122762	88734	2223	Свердловская область, Нижний Тагил, Полуденская, 25	t	small
121958	86517	687	Свердловская область, Нижний Тагил, Покровское1, 65	f	medium
75067	88810	2273	Свердловская область, Тагилстроевский район, Нижний Тагил, Победы, 35	f	large
75066	88810	2272	Свердловская область, Тагилстроевский район, Нижний Тагил, Победы, 35	f	large
75624	88654	2178	Свердловская область, Дзержинский район, Нижний Тагил, Пихтовая, 12А	f	large
75625	88657	2179	Свердловская область, Нижний Тагил, Пихтовая, 16	f	large
75696	88765	2241	Свердловская область, Нижний Тагил, Перова, 133	f	large
75400	88589	2142	Свердловская область, Дзержинский район, Нижний Тагил, Патона, 7	f	large
75764	88802	2269	Свердловская область, Нижний Тагил, Пархоменко, 109	f	large
75763	88802	2268	Свердловская область, Нижний Тагил, Пархоменко, 109	f	large
75686	88698	2202	Свердловская область, Нижний Тагил, Пархоменко, 13	f	large
75626	88659	2180	Свердловская область, Дзержинский район, Нижний Тагил, Парковая, 13	f	large
75639	88680	2194	Свердловская область, Нижний Тагил, Островского, 3	f	large
75115	88707	2207	Свердловская область, Нижний Тагил, Оплетина, 11а	f	large
75114	88706	2206	Свердловская область, Нижний Тагил, Оплетина, 11А	f	large
75113	88703	2205	Свердловская область, Нижний Тагил, Оплетина, 10	f	large
75406	88601	2148	Свердловская область, Дзержинский район, Нижний Тагил, Окунева, 45	f	large
75632	88667	2187	Свердловская область, Нижний Тагил, Октябрьской революции, 7	f	large
75741	88792	2261	Свердловская область, Нижний Тагил, Октябрьской революции, 44	f	large
75740	88790	2260	Свердловская область, Нижний Тагил, Октябрьской революции, 2	f	large
75079	88815	2285	Свердловская область, Тагилстроевский район, Нижний Тагил, Октябрьский проспект, 16а	f	large
75070	88815	2276	Свердловская область, Тагилстроевский район, Нижний Тагил, Октябрьский проспект, 16а	f	large
75075	88803	2281	Свердловская область, Нижний Тагил, Октябрьский проспект, 16	f	large
75076	88803	2282	Свердловская область, Нижний Тагил, Октябрьский проспект, 16	f	large
75744	88797	2264	Свердловская область, Нижний Тагил, Новострой, 11	f	large
122783	88796	2263	Свердловская область, Нижний Тагил, Новострой, 11	f	\N
75130	88731	2222	Свердловская область, Нижний Тагил, Некрасова, 1	f	large
122782	88794	2262	Свердловская область, Нижний Тагил, Мира, 54	f	\N
75736	88780	2253	Свердловская область, Нижний Тагил, Металлургов, 1	f	large
75735	88780	2252	Свердловская область, Нижний Тагил, Металлургов, 1	f	large
122640	87990	1915	Свердловская область, Камышлов, Швельниса, 40	f	medium
75174	88621	2159	Свердловская область, Нижний Тагил, Максарева, 11А	f	large
75116	88710	2208	Свердловская область, Нижний Тагил, Липовый тракт, 11	f	large
75638	88679	2193	Свердловская область, Нижний Тагил, Ленина, 27	f	large
75645	88694	2200	Свердловская область, Нижний Тагил, Ленина, 38	f	large
75641	88684	2196	Свердловская область, Нижний Тагил, Ленина, 14	f	large
122764	88737	2225	Свердловская область, Нижний Тагил, Лайская, 19	t	medium
75627	88661	2181	Свердловская область, Нижний Тагил, Краснофлотская, 28	f	large
122781	88789	2259	Свердловская область, Тагилстроевский район, Нижний Тагил, Красногвардейская, 59	f	small
122785	88829	2288	Свердловская область, Нижний Тагил, Красногвардейская, 57а	f	small
75739	88787	2258	Свердловская область, Нижний Тагил, Красногвардейская, 15	f	large
75738	88787	2257	Свердловская область, Нижний Тагил, Красногвардейская, 15	f	large
75124	88723	2216	Свердловская область, Нижний Тагил, Красноармейская, 107а	f	large
75129	88729	2221	Свердловская область, Нижний Тагил, Космонавтов, 12	f	large
75128	88729	2220	Свердловская область, Нижний Тагил, Космонавтов, 12	f	large
75173	88620	2158	Свердловская область, Нижний Тагил, Коровина, 1	f	large
75403	88596	2145	Свердловская область, Нижний Тагил, Коминтерна, 41	f	large
75182	88632	2167	Свердловская область, Нижний Тагил, Коминтерна, 59	f	large
75694	88761	2239	Свердловская область, Тагилстроевский район, Нижний Тагил, Кольцова, 23	f	large
75642	88687	2197	Свердловская область, Нижний Тагил, Карла Маркса, 28	f	large
75640	88682	2195	Свердловская область, Нижний Тагил, Карла Маркса, 2	f	large
75064	88806	2270	Свердловская область, Нижний Тагил, Карла Либкнехта, 19	f	large
75065	88807	2271	Свердловская область, Тагилстроевский район, Нижний Тагил, Карла Либкнехта, 30	f	large
75171	88616	2156	Свердловская область, Дзержинский район, Нижний Тагил, Калинина, 2А	f	large
75450	88616	2155	Свердловская область, Дзержинский район, Нижний Тагил, Калинина, 2А	f	large
75189	88645	2174	Свердловская область, Нижний Тагил, Ильича, 12	f	large
75188	88643	2173	Свердловская область, Дзержинский район, Нижний Тагил, Ильича, 22	f	large
75187	88642	2172	Свердловская область, Дзержинский район, Нижний Тагил, Ильича, 37	f	large
75126	88728	2218	Свердловская область, Нижний Тагил, Известковая, 29	f	large
75125	88725	2217	Свердловская область, Нижний Тагил, Известковая, 9	f	large
75127	88725	2219	Свердловская область, Нижний Тагил, Известковая, 9	f	large
75109	88830	2290	Свердловская область, Нижний Тагил, Захарова, 1	f	large
75082	88830	2289	Свердловская область, Нижний Тагил, Захарова, 1	f	large
75178	88625	2163	Свердловская область, Нижний Тагил, Зари, 8	f	large
75177	88624	2162	Свердловская область, Нижний Тагил, Зари, 46Б	f	large
75176	88624	2161	Свердловская область, Нижний Тагил, Зари, 46Б	f	large
75175	88618	2160	Свердловская область, Нижний Тагил, Зари, 32	f	large
75172	88618	2157	Свердловская область, Нижний Тагил, Зари, 32	f	large
75186	88639	2171	Свердловская область, Нижний Тагил, Зари, 21	f	large
75183	88633	2168	Свердловская область, Нижний Тагил, Зари, 8	f	large
75208	88652	2177	Свердловская область, Дзержинский район, Нижний Тагил, Зари, 75	f	large
75185	88638	2170	Свердловская область, Дзержинский район, Нижний Тагил, Зари, 67А	f	large
75068	88812	2274	Свердловская область, Нижний Тагил, Жуковского, 5а	f	large
75074	88822	2280	Свердловская область, Нижний Тагил, Дружинина, 35	f	large
75734	88778	2251	Свердловская область, Нижний Тагил, Гвардейская, 20	f	large
75699	88768	2244	Свердловская область, Нижний Тагил , Гвардейская, 72	f	large
75111	88699	2203	Свердловская область, Нижний Тагил, Газетная, 83А	f	large
75685	88696	2201	Свердловская область, Нижний Тагил, Газетная, 27а	f	large
75643	88689	2198	Свердловская область, Нижний Тагил, Газетная, 27А	f	large
75644	88692	2199	Свердловская область, Нижний Тагил, Газетная, 71	f	large
75633	88668	2188	Свердловская область, Нижний Тагил, Газетная, 109	f	large
75693	88752	2235	Свердловская область, Нижний Тагил, Гагарина, 15	f	large
75692	88752	2234	Свердловская область, Нижний Тагил, Гагарина, 15	f	large
75691	88752	2233	Свердловская область, Нижний Тагил, Гагарина, 15	f	large
75118	88713	2210	Свердловская область, Нижний Тагил, Выйская, 68	f	large
75119	88715	2211	Свердловская область, Нижний Тагил, Верхняя Черепанова, 17А	f	large
75120	88717	2212	Свердловская область, Нижний Тагил, Верхняя Черепанова, 17а	f	large
75399	88588	2141	Свердловская область, Нижний Тагил, Вагоностроителей, 1	f	large
75398	88588	2140	Свердловская область, Нижний Тагил, Вагоностроителей, 1	f	large
75184	88635	2169	Свердловская область, Нижний Тагил, Вагоностроителей, 64	f	large
75401	88591	2143	Свердловская область, Нижний Тагил, Вагоностроителей, 14А	f	large
75411	88612	2153	Свердловская область, Дзержинский район, Нижний Тагил, Бобкова, 3	f	large
75410	88609	2152	Свердловская область, Нижний Тагил, Басова, 8	f	large
75409	88608	2151	Свердловская область, Нижний Тагил, Басова, 11А	f	large
75631	88614	2185	Свердловская область, Нижний Тагил, Алтайская, 35	f	large
75412	88614	2154	Свердловская область, Нижний Тагил, Алтайская, 35	f	large
75408	88606	2150	Свердловская область, Нижний Тагил, Алтайская, 51	f	large
75112	88702	2204	Свердловская область, Нижний Тагил, Аганичева, 26	f	large
75190	88648	2175	Свердловская область, Дзержинский район, Нижний Тагил, Тельмана, 19	f	large
75687	88741	2227	Свердловская область, Нижний Тагил, Радищева, 3	f	large
75404	88598	2146	Свердловская область, Нижний Тагил, Коминтерна, 47	f	large
74700	86309	553	Свердловская область, Нижние Серги, Нагорная, 20	f	large
74725	86273	520	Свердловская область, Невьянск, проспект Октябрьский, 21	f	large
74795	86268	511	Свердловская область, Невьянск, Советская, 28	f	large
74726	86274	521	Свердловская область, Невьянск, Самойлова, 4	f	large
121737	86276	523	Свердловская область, Невьянск, Ракетная, 24	f	\N
121736	86275	522	Свердловская область, Невьянск, Попова, 8	f	medium
74722	86270	517	Свердловская область, Невьянск, Малышева, 1	f	large
74798	86270	514	Свердловская область, Невьянск, Малышева, 1	f	large
74797	86270	513	Свердловская область, Невьянск, Малышева, 1	f	large
74724	86272	519	Свердловская область, Невьянск, Красноармейская, 13	f	large
74723	86272	518	Свердловская область, Невьянск, Красноармейская, 13	f	large
74721	86271	516	Свердловская область, Невьянск, Долгих,, 9	f	large
74799	86271	515	Свердловская область, Невьянск, Долгих,, 9	f	large
74796	86269	512	Свердловская область, Невьянск, Долгих, 69	f	large
121739	86277	524	Свердловская область, Невьянск, Демьяна Бедного, 15	t	small
121787	86333	564	Свердловская область, Михайловск, Энгельса, 29	f	medium
75465	88521	2104	Свердловская область, Лесной, Строителей, 22	f	large
75338	88544	2115	Свердловская область, Лесной, Мамина Сибиряка, 47а	f	large
122740	88488	2087	Свердловская область, Кушва, дер.Мостовая, клуб	t	small
122737	88469	2078	Свердловская область, Кушва, клуб	t	small
75453	88492	2089	Свердловская область, Кушва, пос.Строителей, 54б	f	large
75286	88478	2082	Свердловская область, Кушва, пер.Свердлова, 5	f	large
75456	88497	2092	Свердловская область, Кушва, Энергетиков, 6а	f	large
75330	88481	2084	Свердловская область, Кушва, Строителей, 10	f	large
75287	88480	2083	Свердловская область, Кушва, Строителей, 14	f	large
75457	88504	2095	Свердловская область, Кушва, Станционная, 80	f	large
75454	88494	2090	Свердловская область, Кушва, Союзов, 14	f	large
75331	88484	2085	Свердловская область, Кушва, Союзов, 14	f	large
122738	88473	2080	Свердловская область, Кушва, Союзов, 1а	f	\N
122741	88499	2093	Свердловская область, Кушва, Прокофьева, 11	f	\N
75451	88486	2086	Свердловская область, городской округ Кушва, Площадь Культуры, 1	f	large
75283	88471	2079	Свердловская область, Кушва, Первомайская, 41	f	large
75452	88490	2088	Свердловская область, Кушва, Маяковского, 13	f	large
75459	88509	2098	Свердловская область, Кушва, Луначарского, 5	f	large
75458	88505	2096	Свердловская область, Кушва, Лесорубов, 15	f	large
75455	88495	2091	Свердловская область, Кушва, Ленина, 176	f	large
75285	88476	2081	Свердловская область, Кушва, Ленина, 48	f	large
122745	88508	2097	Свердловская область, Кушва, Кушвинская, управление поселком	f	\N
75460	88512	2099	Свердловская область, Кушва, Коммуны, 4	f	large
74289	87283	1225	Свердловская область, Кушва, Иканина, 77	f	large
122743	88501	2094	Свердловская область, Кушва, Дзержинского, 1	f	medium
122024	86609	751	Свердловская область, Крылатовский, Кунгурская, 42	t	small
122731	88465	2073	Свердловская область, Красноуфимск, Ухтомского, 17	t	medium
122716	88444	2052	Свердловская область, Красноуфимск, Трактовая, 1а	f	\N
122725	88460	2068	Свердловская область, Красноуфимск, Сухобского, 10	t	\N
122723	88458	2066	Свердловская область, Красноуфимск, Сухобского, 35	t	medium
122732	88467	2075	Свердловская область, Красноуфимск, Станционная, 3	f	medium
75272	88452	2060	Свердловская область, Красноуфимск, Советская, 56	f	large
122720	88450	2058	Свердловская область, Красноуфимск, Советская, 2	f	medium
75235	88446	2054	Свердловская область, Красноуфимск, Селекционная, 22	f	large
75237	88449	2057	Свердловская область, Красноуфимск, Свердлова, 18	f	large
75275	88455	2063	Свердловская область, Красноуфимск, Саргинская, 12	f	large
122726	88461	2069	Свердловская область, Красноуфимск, Ремесленная, 7	f	medium
75234	88445	2053	Свердловская область, Красноуфимск, Р.Горбуновой, 13	f	large
122718	88447	2055	Свердловская область, Красноуфимск, Пролетарская, 62	f	medium
75277	88457	2065	Свердловская область, Красноуфимск, Отдыха, 4	f	large
75278	88459	2067	Свердловская область, Красноуфимск, Нефтяников, 12	f	large
122735	88468	2076	Свердловская область, Красноуфимск, Мира, 11	t	medium
75232	88443	2051	Свердловская область, Красноуфимск, Механизаторов, 24	f	large
122722	88453	2061	Свердловская область, Красноуфимск, Манчажская, 22	f	\N
122729	88463	2071	Свердловская область, Красноуфимск, Кирпично-Заводская, 41	f	medium
75236	88448	2056	Свердловская область, Красноуфимск, Докучаева, 3	f	large
75280	88462	2070	Свердловская область, Красноуфимск, Высокая, 14	f	large
75276	88456	2064	Свердловская область, Красноуфимск, Буткинская, 14	f	large
75282	88466	2074	Свердловская область, Красноуфимск, Березовая, 8	f	large
75281	88464	2072	Свердловская область, Красноуфимск, Березовая, 6	f	large
75274	88454	2062	Свердловская область, Красноуфимск, 8 Марта, 93	f	large
122721	88451	2059	Свердловская область, Красноуфимск, 8 Марта, 29	f	\N
122715	88442	2049	Свердловская область, Красноуральск, клуб поселка Чирок	t	small
122707	88434	2045	Свердловская область, Красноуральск, Шахтеров, 9	t	medium
75228	88430	2041	Свердловская область, Красноуральск, Челюскинцев, 14	t	large
75229	88430	2042	Свердловская область, Красноуральск, Челюскинцев, 14	t	large
122705	88421	2033	Свердловская область, Красноуральск, Советская, 2в	f	\N
75582	88418	2034	Свердловская область, Красноуральск, Советская, 2	f	large
75581	88418	2032	Свердловская область, Красноуральск, Советская, 2	f	large
75230	88431	2043	Свердловская область, Красноуральск, Победы, 1а	f	large
75231	88431	2044	Свердловская область, Красноуральск, Победы, 1а	f	large
75227	88428	2040	Свердловская область, Красноуральск, Парковая, 5	f	large
75583	88423	2035	Свердловская область, Красноуральск, Ленина, 6	f	large
75226	88426	2039	Свердловская область, Красноуральск, Каляева, 37	f	large
75225	88426	2038	Свердловская область, Красноуральск, Каляева, 37	f	large
75224	88289	2037	Свердловская область, Красноуральск, Каляева, 35а	f	large
75623	88289	2036	Свердловская область, Красноуральск, Каляева, 35а	f	large
122703	88416	2031	Свердловская область, Красноуральск, Воровского, 1	f	medium
122686	88389	2015	Свердловская область, Краснотурьинск, бульвар Мира, 13	f	medium
75526	88371	2005	Свердловская область, Краснотурьинск, Чкалова, 20	f	large
122689	88390	2016	Свердловская область, Краснотурьинск, Чернышевского, 3	f	medium
75530	88376	2009	Свердловская область, Краснотурьинск, Фрунзе, 60	f	large
122668	88338	1988	Свердловская область, Краснотурьинск, Серова, 29	f	medium
75578	88407	2024	Свердловская область, Краснотурьинск, Рюмина, 16	f	large
75577	88405	2023	Свердловская область, Краснотурьинск, Рюмина, 6	f	large
75576	88402	2022	Свердловская область, городской округ Краснотурьинск, Рюмина, 18	f	large
75531	88379	2010	Свердловская область, Краснотурьинск, Попова, 46	f	large
75522	88353	2000	Свердловская область, Краснотурьинск, Попова, 76	f	large
75518	88353	1995	Свердловская область, Краснотурьинск, Попова, 76	f	large
75575	88401	2021	Свердловская область, Краснотурьинск, Парковая,, 5	f	large
75521	88360	1999	Свердловская область, Краснотурьинск, Октябрьская, 45	f	large
75529	88358	2008	Свердловская область, Краснотурьинск, Октябрьская, 24	f	large
122676	88358	1998	Свердловская область, Краснотурьинск, Октябрьская, 24	f	medium
75520	88357	1997	Свердловская область, Краснотурьинск, Октябрьская, 34	f	large
122680	88381	2011	Свердловская область, Краснотурьинск, Молодежная, 7	f	medium
75573	88386	2014	Свердловская область, Краснотурьинск, Микова, 33	f	large
75574	88395	2018	Свердловская область, Краснотурьинск, Металлургов, 43	f	large
122692	88396	2019	Свердловская область, Краснотурьинск, Маркса, 35	f	medium
122682	88383	2012	Свердловская область, Краснотурьинск, Ленина проспект, 25	f	medium
75525	88366	2003	Свердловская область, Краснотурьинск, Ленина, 78	f	large
75523	88362	2001	Свердловская область, Краснотурьинск, Ленина, 80	f	large
75516	88347	1992	Свердловская область, Краснотурьинск, Космодемьянской, 7	f	large
75528	88375	2007	Свердловская область, Краснотурьинск, Колхозная, 11	f	large
75580	88354	2029	Свердловская область, Краснотурьинск, Клубная, 18	f	large
75519	88354	1996	Свердловская область, Краснотурьинск, Клубная, 18	f	large
122695	88399	2020	Свердловская область, Краснотурьинск, Карла Маркса, 31	f	medium
122691	88392	2017	Свердловская область, Краснотурьинск, Карла Маркса, 22 А	f	medium
122674	88350	1994	Свердловская область, Краснотурьинск, Животноводов, 5	f	small
122700	88415	2028	Свердловская область, Краснотурьинск, Восточная, 4	t	small
122685	88384	2013	Свердловская область, Краснотурьинск, Базстроевская, 1	f	medium
75517	88348	1993	Свердловская область, Краснотурьинск, Абоимова, 39	f	large
75056	88324	1980	Свердловская область, городской округ Кировград, Свердлова, 58	f	large
75054	88320	1978	Свердловская область, Кировград, Свердлова, 47	f	large
75052	88317	1976	Свердловская область, Кировград, Свердлова, 63	f	large
75051	88315	1975	Свердловская область, Кировград, Свердлова, 69	f	large
75055	88322	1979	Свердловская область, Кировград, Набережная, 7	f	large
75061	88335	1985	Свердловская область, Кировград, Максима Горького, 1	f	large
75053	88318	1977	Свердловская область, Кировград, Лермонтова, 67	f	large
75058	88328	1982	Свердловская область, Кировград, Ленина, 29	f	large
75057	88327	1981	Свердловская область, Кировград, Калинина, 4	f	large
75050	88312	1974	Свердловская область, Кировград, Дзержинского, 12	f	large
75043	88303	1966	Свердловская область, Качканар, 72	f	large
75790	88280	1954	Свердловская область, Качканар, 63	f	large
75042	88300	1965	Свердловская область, Качканар, микрорайон 5а, 14а	f	large
75044	88305	1967	Свердловская область, Качканар, Свердлова, 39а	f	large
75048	88290	1971	Свердловская область, Качканар, Свердлова, 20	f	large
75047	88290	1970	Свердловская область, Качканар, Свердлова, 20	f	large
75796	88290	1960	Свердловская область, Качканар, Свердлова, 20	f	large
75041	88298	1964	Свердловская область, Качканар, Гикалова, 5	f	large
75792	88281	1956	Свердловская область, Качканар, 8 микрорайон, 30	f	large
75791	88281	1955	Свердловская область, Качканар, 8 микрорайон, 30	f	large
75797	88292	1961	Свердловская область, Качканар, 6а микрорайон, 26	f	large
75794	88286	1958	Свердловская область, Качканар, 4 микрорайон, 62	f	large
75798	88295	1962	Свердловская область, Качканар, 11 микрорайон, 14а	f	large
75799	88297	1963	Свердловская область, Качканар, 11 микрорайон, 11	f	large
122667	88311	1972	Свердловская область, Качканар, 10 микрорайон, 61	f	\N
75046	88308	1969	Свердловская область, Качканар, 10 микрорайон, 5	f	large
75045	88306	1968	Свердловская область, Качканар, 10 микрорайон, 23	f	large
75148	88256	1942	Свердловская область, Карпинск, проезд Декабристов, 8	f	large
75105	88244	1936	Свердловская область, Карпинск, Школьный, 3	f	large
75104	88239	1934	Свердловская область, Карпинск, Шахтерский, 6	f	large
75786	88259	1944	Свердловская область, Карпинск, Трудовая, 41	f	large
122655	88265	1947	Свердловская область, Карпинск, Советская, 7	f	medium
75103	88237	1933	Свердловская область, Карпинск, Почтамтская, 37	f	large
75106	88250	1939	Свердловская область, Карпинск, Попова, 15	f	large
74292	87289	1229	Свердловская область, Карпинск, Волчанск, Пионерская, 10А	f	large
75107	88251	1940	Свердловская область, Карпинск, Мира, 61	f	large
75788	88263	1946	Свердловская область, Карпинск, Малышева, 1	f	large
75787	88261	1945	Свердловская область, Карпинск, Лесопильная, 71	f	large
75108	88253	1941	Свердловская область, Карпинск, Куйбышева, 27	f	large
75149	88257	1943	Свердловская область, Карпинск, Колхозная, 43а	f	large
122664	88274	1951	Свердловская область, Карпинск, Заречная, 38	f	medium
75093	88216	1922	Свердловская область, Камышлов	f	large
75092	88213	1921	Свердловская область, Камышлов, Энгельса, 171	f	large
75785	88210	1919	Свердловская область, Камышлов, Фарфористов, 11	f	large
75100	88232	1930	Свердловская область, Камышлов, Строителей, 15	f	large
122648	88229	1929	Свердловская область, Камышлов, Северная, 63	f	small
75099	88227	1928	Свердловская область, Камышлов, Северная, 72	f	large
75098	88225	1927	Свердловская область, Камышлов, Молокова, 9	f	large
75094	88217	1923	Свердловская область, Камышлов, Маяковского, 9	f	large
75096	88222	1925	Свердловская область, Камышлов, Ленинградская, 24	f	large
75102	88235	1932	Свердловская область, Камышлов, Куйбышева, 114	f	large
122644	88168	1918	Свердловская область, Камышлов, Красных Партизан,, 2 а	f	medium
75762	88168	1917	Свердловская область, Камышлов, Красных Партизан,, 2 а	f	large
75101	88233	1931	Свердловская область, Камышлов, Карловарская, 2 А	f	large
75097	88223	1926	Свердловская область, Камышлов, Карла Либкнехта, 14	f	large
75095	88220	1924	Свердловская область, Камышлов, Вокзальная, 14а	f	large
75715	88141	1881	Свердловская область, КаменскУральский, Челябинская, 19, школа № 17	f	large
75169	88131	1876	Свердловская область, Каменск-Уральский, проспект Победы, 33, библиотека им.Пушкина	f	large
75167	88128	1874	Свердловская область, Каменск-Уральский, проспект Победы, 79, школа №1	f	large
75158	88108	1865	Свердловская область, Каменск-Уральский, проспект Победы, 2, ДК Юность	f	large
75151	88094	1858	Свердловская область, Каменск-Уральский, проспект Победы, 58, школа № 31	f	large
75755	88188	1903	Свердловская область, Каменск-Уральский, бульвар Комсомольский, 46, школа №34	f	large
75754	88186	1902	Свердловская область, Каменск-Уральский, бульвар Комсомольский, 46, школа № 34	f	large
75758	88195	1906	Свердловская область, Каменск-Уральский, Школьная, 10, школа № 7	f	large
75717	88147	1883	Свердловская область, Каменск-Уральский, Челябинская, 29, школа № 40	f	large
75716	88145	1882	Свердловская область, Каменск-Уральский, Челябинская, 19, школа №17	f	large
75757	88191	1905	Свердловская область, Каменск-Уральский, Центральная, 13, Дворец спорта ОАО КУМЗ	f	large
121589	86176	421	Свердловская область, Каменск-Уральский, Центральная, 271	f	\N
75750	88178	1898	Свердловская область, Каменск-Уральский, Уральская, 31, школа № 23	f	large
75749	88175	1897	Свердловская область, Каменск-Уральский, Уральская, 43, Центр псих.мед.соц.сопровождения	f	large
75683	88085	1853	Свердловская область, Каменск-Уральский, Тевосяна, 2, школа № 10	f	large
75751	88180	1899	Свердловская область, Каменск-Уральский, Строителей, 24, школа № 2	f	large
122627	88069	1845	Свердловская область, Каменск-Уральский, Спиридонова, 25, центр Лада	f	\N
75152	88096	1859	Свердловская область, Каменск-Уральский, Пушкина, 1а, детский клубик Ровесник	f	large
122629	88089	1855	Свердловская область, Каменск-Уральский, Проспект Победы, 93	f	\N
75684	88086	1854	Свердловская область, Каменск-Уральский, Прокопьева, 25, школа № 38	f	large
75761	88207	1912	Свердловская область, Каменск-Уральский, Привокзальная, 15, Автовокзал	f	large
75154	88100	1861	Свердловская область, Каменск-Уральский, Привокзальная, 15, Здание автовокзала	f	large
75163	88119	1870	Свердловская область, Каменск-Уральский, Олега Кошевого, 2, город. Дом детского творчества	f	large
75725	88162	1891	Свердловская область, Каменск-Уральский, Октябрьская, 99, техникум строительства и ЖКХ	f	large
75724	88160	1890	Свердловская область, Каменск-Уральский, Октябрьская, 94а, школа № 25	f	large
75723	88159	1889	Свердловская область, Каменск-Уральский, Октябрьская, 94а, школа №25	f	large
75162	88117	1869	Свердловская область, Каменск-Уральский, Мусоргского, 9, школа № 19	f	large
75157	88106	1864	Свердловская область, Каменск-Уральский, Мусоргского, 7, школа Альфа	f	large
75161	88115	1868	Свердловская область, Каменск-Уральский, Мичурина, 61, школа № 60	f	large
75153	88098	1860	Свердловская область, Каменск-Уральский, Мичурина, 61, школа № 60	f	large
75711	88090	1856	Свердловская область, Каменск-Уральский, Мичурина, 10, школа № 15	f	large
75728	88169	1894	Свердловская область, Каменск-Уральский, Механизаторов, 20, Агропромышленный техникум	f	large
75726	88165	1892	Свердловская область, Каменск-Уральский, Механизаторов, 72, Детская юношеская спорт. школа	f	large
75159	88110	1866	Свердловская область, Каменск-Уральский, Машинистов, 51, домоуправлениеп.Хозспособ	f	large
75164	88121	1871	Свердловская область, Каменск-Уральский, Лесная, 2а, ЖЭУ № 2	f	large
75679	88076	1849	Свердловская область, Каменск-Уральский, Лермонтова, 101, школа № 4	f	large
75678	88074	1848	Свердловская область, Каменск-Уральский, Лермонтова, 2, школа №24	f	large
75677	88072	1847	Свердловская область, Каменск-Уральский, Лермонтова, 133, ДК Современник	f	large
75676	88070	1846	Свердловская область, Каменск-Уральский, Лермонтова, 133, ДК Современник	f	large
75675	88067	1844	Свердловская область, Каменск-Уральский, Лермонтова, 64, ЖЭУ № 10	f	large
75682	88082	1852	Свердловская область, Каменск-Уральский, Ленина, 34, УГТУУПИ	f	large
75681	88081	1851	Свердловская область, Каменск-Уральский, Ленина, 150, школа РОСТО	f	large
75680	88079	1850	Свердловская область, Каменск-Уральский, Ленина, 204, школа № 32	f	large
121574	86156	411	Свердловская область, Каменск-Уральский, Ленина, 57	f	medium
121570	86153	409	Свердловская область, Каменск-Уральский, Ленина, 40	t	small
122632	88152	1886	Свердловская область, Каменск-Уральский, Кутузова, 39, школа №34	f	\N
75156	88104	1863	Свердловская область, Каменск-Уральский, Кунавина, 7, школа №22, спортзал	f	large
75155	88102	1862	Свердловская область, Каменск-Уральский, Кунавина, 7, школа № 22, актовый зал	f	large
75166	88125	1873	Свердловская область, Каменск-Уральский, Кузнецова, 15, школа № 11	f	large
122630	88129	1875	Свердловская область, Каменск-Уральский, Кирова, 45, филиал библиотеки им. Пушкина	f	\N
75165	88123	1872	Свердловская область, Каменск-Уральский, Карла Маркса, 62, ЦКиНТ Орбита	f	large
75150	88093	1857	Свердловская область, Каменск-Уральский, Карла Маркса, 40а, библиотека профкома СинТЗ	f	large
75727	88166	1893	Свердловская область, Каменск-Уральский, Калинина, 67, школа-интернат № 27	f	large
75753	88183	1901	Свердловская область, Каменск-Уральский, Исетская, 12, школа №5	f	large
75748	88173	1896	Свердловская область, Каменск-Уральский, Исетская, 20, школа № 20	f	large
75729	88172	1895	Свердловская область, Каменск-Уральский, Исетская, 36, Центр образования	f	large
75722	88157	1888	Свердловская область, Каменск-Уральский, Железнодорожная, 40, детский клуб	f	large
75721	88154	1887	Свердловская область, Каменск-Уральский, Железнодорожная, 22, школа № 35	f	large
75719	88151	1885	Свердловская область, Каменск-Уральский, Железнодорожная, 10, МОУ ВСОШ №1	f	large
75160	88112	1867	Свердловская область, Каменск-Уральский, Добролюбова, 35, школа № 51	f	large
75714	88139	1880	Свердловская область, Каменск-Уральский, Дзержинского, 89а, школа № 16	f	large
75194	88134	1877	Свердловская область, Каменск-Уральский, Гоголя, 15, лицей №9	f	large
75752	88182	1900	Свердловская область, Каменск-Уральский, Алюминиевая, 2, ДК УАЗа	f	large
75718	88148	1884	Свердловская область, Каменск-Уральский, Алюминиевая, 47, театр Драмы	f	large
122631	88137	1879	Свердловская область, Каменск-Уральский, Алюминиевая, 77, Детская музыкальная школа №1	f	\N
75712	88135	1878	Свердловская область, Каменск-Уральский, Алюминиевая, 60, Политехнический колледж	f	large
75760	88198	1908	Свердловская область, Каменск-Уральский, 2я Рабочая, 99, библиотека	f	large
75200	87974	1825	Свердловская область, городской округ Ирбит, ул.Красноармейская, 1	f	large
75201	87974	1826	Свердловская область, городской округ Ирбит, ул.Красноармейская, 1	f	large
75672	88062	1839	Свердловская область, Ирбит, Южная, 12	f	large
75206	88046	1831	Свердловская область, Ирбит, Челюскинцев, 2	f	large
75666	88049	1833	Свердловская область, городской округ Ирбит, Советская, 96	f	large
75670	88057	1837	Свердловская область, Ирбит, Свердлова, 17а	f	large
75669	88055	1836	Свердловская область, Ирбит, Свердлова, 17	f	large
75668	88053	1835	Свердловская область, Ирбит, Свердлова, 16	f	large
75703	89298	2610	Свердловская область, Ирбит, Пролетарская, 28	f	large
75205	88043	1830	Свердловская область, Ирбит, Первомайская, 39	f	large
75202	88038	1827	Свердловская область, Ирбит, Орджоникидзе, 73	f	large
75203	88040	1828	Свердловская область, Ирбит, Мальгина, 53	f	large
75673	88059	1840	Свердловская область, Ирбит, М. Жукова, 4	f	large
75671	88059	1838	Свердловская область, Ирбит, М. Жукова, 4	f	large
75706	89318	2613	Свердловская область, Ирбит, Логинова, 22	f	large
75223	88047	1832	Свердловская область, городской округ Ирбит, Кирова, 172	f	large
75705	88052	2612	Свердловская область, Ирбит, Горького, 3	f	large
75667	88052	1834	Свердловская область, Ирбит, Горького, 3	f	large
122610	88009	1807	Свердловская область, Ивдель, Фестивальная, 15	f	small
75195	88011	1808	Свердловская область, Ивдель, Советская, 8	f	large
75449	88004	1805	Свердловская область, Ивдель, Данилова, 134	f	large
75448	88002	1804	Свердловская область, Ивдель, Ворошилова, 5	f	large
75197	88014	1810	Свердловская область, Ивдель, Вокзальная, 24	f	large
75198	88016	1811	Свердловская область, Ивдель, Бабкина, 3	f	large
75196	88012	1809	Свердловская область, Ивдель, 50 лет Октября, 17	f	large
122606	88001	1803	Свердловская область, Ивдель, Фрунзе, 38	f	medium
75325	87934	1732	Россия, Свердловская область, Екатеринбург, улица Эскадронная, 24	f	large
75324	87934	1731	Россия, Свердловская область, Екатеринбург, улица Эскадронная, 24	f	large
122528	87488	1377	Свердловская область, Екатеринбург, улица Школьная, 4	f	medium
75255	87911	1696	Россия, Пермский край, Пермь, улица Фрезеровщиков, 84	f	large
75313	87927	1720	Россия, Свердловская область, Екатеринбург, улица Титова, 28а	f	large
75312	87927	1719	Россия, Свердловская область, Екатеринбург, улица Титова, 28а	f	large
74415	87471	1365	Россия, Свердловская область, Екатеринбург, улица Соликамская, 4	t	large
74560	87657	1501	Россия, Свердловская область, Екатеринбург, улица Серова, 12	f	large
74643	87615	1468	Свердловская область, Екатеринбург, улица Рассветная, 9	f	large
74212	87341	1261	Свердловская область, Екатеринбург, улица Посадская, 51	f	large
74628	87598	1453	Россия, Свердловская область, Екатеринбург, улица Новгородцевой, 17а	f	large
74627	87598	1452	Россия, Свердловская область, Екатеринбург, улица Новгородцевой, 17а	f	large
75380	87955	1764	Россия, Свердловская область, Екатеринбург, улица Многостаночников, 21	f	large
75379	87955	1763	Россия, Свердловская область, Екатеринбург, улица Многостаночников, 21	f	large
74242	87416	1326	Свердловская область, Екатеринбург, улица Мамина-Сибиряка, 16	f	large
74241	87416	1325	Свердловская область, Екатеринбург, улица Мамина-Сибиряка, 16	f	large
122564	87746	1565	Свердловская область, Екатеринбург, улица Луганская, 1	f	medium
75266	87921	1708	Россия, Свердловская область, Екатеринбург, улица Крестинского, 45	f	large
75265	87921	1707	Россия, Свердловская область, Екатеринбург, улица Крестинского, 45	f	large
74531	87693	1533	Россия, Свердловская область, Екатеринбург, улица Краснолесья, 22	f	large
75494	87941	1740	Россия, Свердловская область, Екатеринбург, улица Колхозников, 78	f	large
74490	87837	1628	Свердловская область, Екатеринбург, улица Кировградская, 66	f	large
74489	87837	1627	Свердловская область, Екатеринбург, улица Кировградская, 66	f	large
74486	87831	1624	Россия, Свердловская область, Екатеринбург, улица Калинина, 48	f	large
74485	87831	1623	Россия, Свердловская область, Екатеринбург, улица Калинина, 48	f	large
75553	87855	1650	Россия, Свердловская область, Екатеринбург, улица Индустрии, 92	f	large
74510	87855	1648	Россия, Свердловская область, Екатеринбург, улица Индустрии, 92	f	large
74509	87855	1647	Россия, Свердловская область, Екатеринбург, улица Индустрии, 92	f	large
74254	87437	1338	Россия, Свердловская область, Екатеринбург, улица Гражданская, 6	t	large
74253	87437	1337	Россия, Свердловская область, Екатеринбург, улица Гражданская, 6	t	large
122273	86892	964	Россия, Московская область, Пушкинский район, поселок городского типа Черкизово, Вокзальная улица, 15	t	small
74463	87766	1580	Россия, Республика Хакасия, Абакан, улица Белоярская, 36	f	large
74232	87381	1303	Свердловская область, Екатеринбург, улица Бебеля, 122б	f	large
74231	87381	1302	Свердловская область, Екатеринбург, улица Бебеля, 122б	f	large
74457	87711	1574	Россия, Иркутская область, Иркутск, улица Байкальская, 47а	f	large
74535	87711	1542	Россия, Иркутская область, Иркутск, улица Байкальская, 47а	f	large
74543	87634	1484	Россия, Свердловская область, Екатеринбург, улица 8-го Марта, 89	f	large
74562	87659	1503	Свердловская область, Екатеринбург, Ясная, 1к1	f	large
74266	87366	1285	Свердловская область, Екатеринбург, Ясная, 20	f	large
74268	87366	1287	Свердловская область, Екатеринбург, Ясная, 20	f	large
74267	87366	1286	Свердловская область, Екатеринбург, Ясная, 20	f	large
74264	87362	1283	Свердловская область, Екатеринбург, Ясная, 16	f	large
74263	87362	1282	Свердловская область, Екатеринбург, Ясная, 16	f	large
74249	87430	1333	Свердловская область, Екатеринбург, Якова Свердлова, 11а	f	large
74405	87317	1246	Свердловская область, Екатеринбург, Юмашева, 20	f	large
122595	87967	1784	Свердловская область, Екатеринбург, Эскадронная, 24	f	\N
75329	87938	1736	Свердловская область, Екатеринбург, Энергетиков, 7	f	large
74557	87653	1498	Свердловская область, Екатеринбург, Щорса, 114	f	large
74556	87653	1497	Свердловская область, Екатеринбург, Щорса, 114	f	large
74555	87650	1496	Свердловская область, Екатеринбург, Щорса, 80а	f	large
75506	87947	1752	Свердловская область, Екатеринбург, Щербакова, 118	f	large
75618	87898	1685	Свердловская область, Екатеринбург, Шефская, 6	f	large
75565	87864	1662	Свердловская область, Екатеринбург, Шефская, 87а	f	large
75563	87864	1660	Свердловская область, Екатеринбург, Шефская, 87а	f	large
75562	87864	1659	Свердловская область, Екатеринбург, Шефская, 87а	f	large
75561	87864	1658	Свердловская область, Екатеринбург, Шефская, 87а	f	large
75560	87864	1657	Свердловская область, Екатеринбург, Шефская, 87а	f	large
74245	87421	1329	Свердловская область, Екатеринбург, Шевченко, 9	f	large
74563	87662	1504	Свердловская область, Екатеринбург, Шаумяна, 85	f	large
74649	87512	1475	Свердловская область, Екатеринбург, Шаумяна, 83	f	large
75378	87954	1762	Свердловская область, Екатеринбург, Черняховского, 32	f	large
75615	87895	1682	Россия, Свердловская область, Екатеринбург, Черноморский переулок, 8	f	large
74522	87806	1604	Россия, Свердловская область, Екатеринбург, Черниговский переулок, 8	f	large
74521	87806	1603	Россия, Свердловская область, Екатеринбург, Черниговский переулок, 8	f	large
74252	87435	1336	Свердловская область, Екатеринбург, Челюскинцев, 11	t	large
74251	87433	1335	Свердловская область, Екатеринбург, Челюскинцев, 102	t	large
74250	87431	1334	Свердловская область, Екатеринбург, Челюскинцев, 102	t	large
74246	87422	1330	Свердловская область, Екатеринбург, Челюскинцев, 110а	f	large
74668	86808	1437	Свердловская область, Екатеринбург, Чекистов, 21	f	large
74911	86808	882	Свердловская область, Екатеринбург, Чекистов, 21	f	large
75260	87302	1702	Свердловская область, Екатеринбург, Чайковского, 70	f	large
75262	87302	1704	Свердловская область, Екатеринбург, Чайковского, 70	f	large
75261	87302	1703	Свердловская область, Екатеринбург, Чайковского, 70	f	large
75259	87541	1701	Свердловская область, Екатеринбург, Циолковского, 70	f	large
74579	87745	1564	Свердловская область, Екатеринбург, Цвиллинга, 53	f	large
74651	87627	1478	Свердловская область, Екатеринбург, Хохрякова, 87	f	large
74647	87620	1473	Свердловская область, Екатеринбург, Хохрякова, 29А	f	large
74646	87620	1472	Свердловская область, Екатеринбург, Хохрякова, 29А	f	large
74515	87771	1595	Свердловская область, Екатеринбург, Хвойная, 91	f	large
74465	87771	1582	Свердловская область, Екатеринбург, Хвойная, 91	f	large
74612	87544	1414	Россия, Ленинградская область, Всеволожский район, Всеволожск, улица Фонвизина, 4	f	large
74488	87835	1626	Свердловская область, Екатеринбург, Фестивальная, 6	f	large
74471	87810	1609	Свердловская область, Екатеринбург, Фестивальная, 25	f	large
74525	87810	1607	Свердловская область, Екатеринбург, Фестивальная, 25	f	large
74523	87808	1605	Свердловская область, Екатеринбург, Фестивальная, 12	f	large
74475	87808	1613	Свердловская область, Екатеринбург, Фестивальная, 12	f	large
74524	87808	1606	Свердловская область, Екатеринбург, Фестивальная, 12	f	large
75317	87929	1724	Свердловская область, Екатеринбург, Ферганская, 22а	f	large
75316	87929	1723	Свердловская область, Екатеринбург, Ферганская, 22а	f	large
122594	87928	1783	Свердловская область, Екатеринбург, Ферганская, 22	f	\N
75315	87928	1722	Свердловская область, Екатеринбург, Ферганская, 22	f	large
75314	87928	1721	Свердловская область, Екатеринбург, Ферганская, 22	f	large
74237	87389	1308	Свердловская область, Екатеринбург, Феофанова, 10	f	large
74602	87527	1404	Свердловская область, Екатеринбург, Учителей, 2	f	large
74601	87527	1403	Свердловская область, Екатеринбург, Учителей, 2	f	large
74514	87789	1591	Россия, Свердловская область, Екатеринбург, Утренний переулок, 2	t	large
74513	87785	1590	Свердловская область, Екатеринбург, Утренний переулок, 2	t	large
74512	87783	1589	Россия, Свердловская область, Екатеринбург, Утренний переулок, 1а	f	large
74598	87519	1400	Свердловская область, Екатеринбург, Уральская, 50а	f	large
74597	87519	1399	Свердловская область, Екатеринбург, Уральская, 50а	f	large
74596	87519	1398	Свердловская область, Екатеринбург, Уральская, 50а	f	large
75328	87937	1735	Свердловская область, Екатеринбург, Умельцев, 1	f	large
75611	87870	1678	Свердловская область, Екатеринбург, Ульяновская, 13	f	large
75571	87870	1668	Свердловская область, Екатеринбург, Ульяновская, 13	f	large
75567	87870	1664	Свердловская область, Екатеринбург, Ульяновская, 13	f	large
74561	87647	1502	Свердловская область, Екатеринбург, Уктусская, 10	f	large
74552	87647	1493	Свердловская область, Екатеринбург, Уктусская, 10	f	large
74583	87505	1385	Свердловская область, Екатеринбург, Тургенева, 13	f	large
74462	87764	1579	Свердловская область, Екатеринбург, Трубачева, 76	f	large
74461	87762	1578	Свердловская область, Екатеринбург, Трубачева, 72	f	large
74599	87521	1401	Свердловская область, Екатеринбург, Трамвайный переулок, 15	f	large
75311	87926	1718	Свердловская область, Екатеринбург, Титова, 19	f	large
75310	87925	1717	Свердловская область, Екатеринбург, Титова, 11	f	large
75309	87925	1716	Свердловская область, Екатеринбург, Титова, 11	f	large
74422	87479	1372	Свердловская область, Екатеринбург, Техническая, 138	f	large
74417	87474	1367	Свердловская область, Екатеринбург, Техническая, 99	f	large
74416	87474	1366	Свердловская область, Екатеринбург, Техническая, 99	f	large
74696	87467	1362	Свердловская область, Екатеринбург, Техническая, 42а	f	large
74690	87460	1356	Свердловская область, Екатеринбург, Техническая, 23	t	large
122265	86887	960	Свердловская область, Екатеринбург, Техническая, 19, ТРК Таганский 	t	\N
121945	86505	679	Свердловская область, Екатеринбург, Техническая, 99	f	\N
74829	85873	244	Свердловская область, Екатеринбург, Техническая, 81	f	large
74687	87457	1353	Россия, Свердловская область, Екатеринбург, Теплоходный проезд, 6	f	large
74686	87457	1352	Россия, Свердловская область, Екатеринбург, Теплоходный проезд, 6	f	large
74830	85876	245	Россия, Свердловская область, Екатеринбург, Теплоходный проезд, 6	f	large
74573	87737	1558	Свердловская область, Екатеринбург, Тверитина, 20	f	large
74220	87351	1269	Свердловская область, Екатеринбург, Татищева, 78	f	large
122914	89329	2624	Свердловская область, Екатеринбург, Таганская, 75	f	medium
75568	87872	1665	Свердловская область, Екатеринбург, Таганская, 75	f	large
75253	87872	1693	Свердловская область, Екатеринбург, Таганская, 75	f	large
74554	87648	1495	Свердловская область, Екатеринбург, Сурикова, 31	f	large
74553	87648	1494	Свердловская область, Екатеринбург, Сурикова, 31	f	large
74218	87350	1267	Россия, Свердловская область, Екатеринбург, Субботников площадь, 1	t	large
74219	87350	1268	Россия, Свердловская область, Екатеринбург, Субботников площадь, 1	t	large
74656	87562	1424	Свердловская область, Екатеринбург, Студенческая, 26	f	large
122540	87562	1423	Свердловская область, Екатеринбург, Студенческая, 26	f	medium
74617	87554	1419	Свердловская область, Екатеринбург, Студенческая, 19	f	large
74426	87493	1379	Свердловская область, Екатеринбург, Строителей, 52	f	large
122529	87491	1378	Свердловская область, Екатеринбург, Стрелочников, 4а	f	medium
74551	87644	1492	Свердловская область, Екатеринбург, Степана Разина, 71	f	large
74550	87644	1491	Свердловская область, Екатеринбург, Степана Разина, 71	f	large
74549	87644	1490	Свердловская область, Екатеринбург, Степана Разина, 71	f	large
74548	87643	1489	Свердловская область, Екатеринбург, Степана Разина, 51	f	large
75607	87886	1674	Свердловская область, Екатеринбург, Стачек, 20	f	large
75566	87869	1663	Свердловская область, Екатеринбург, Стачек, 70	f	large
74501	87843	1639	Свердловская область, Екатеринбург, Стахановская, 43	f	large
74496	87843	1634	Свердловская область, Екатеринбург, Стахановская, 43	f	large
75616	87888	1683	Свердловская область, Екатеринбург, Старых большевиков, 22	f	large
75610	87888	1677	Свердловская область, Екатеринбург, Старых большевиков, 22	f	large
75609	87888	1676	Свердловская область, Екатеринбург, Старых большевиков, 22	f	large
75564	87867	1661	Свердловская область, Екатеринбург, Старых Большевиков, 82к1	f	large
75257	87917	1699	Свердловская область, Екатеринбург, Союзная, 26	f	large
74477	87819	1615	Свердловская область, Екатеринбург, Социалистическая, 2	f	large
74476	87819	1614	Свердловская область, Екатеринбург, Социалистическая, 2	f	large
74679	87447	1345	Свердловская область, Екатеринбург, Софьи Перовской, 111	f	large
74678	87447	1344	Свердловская область, Екатеринбург, Софьи Перовской, 111	f	large
74616	87552	1418	Свердловская область, Екатеринбург, Софьи Ковалевской, 10	f	large
74660	87516	1429	Свердловская область, Екатеринбург, Советская, 24а	f	large
74592	87516	1394	Свердловская область, Екатеринбург, Советская, 24а	f	large
74591	87516	1393	Свердловская область, Екатеринбург, Советская, 24а	f	large
74590	87516	1392	Свердловская область, Екатеринбург, Советская, 24а	f	large
74589	87516	1391	Свердловская область, Екатеринбург, Советская, 24а	f	large
74662	87569	1431	Свердловская область, Екатеринбург, Советская, 51	f	large
74698	86300	549	Россия, Московская область, Троицк, Сиреневый бульвар, 6	f	large
74636	87603	1461	Свердловская область, Екатеринбург, Сиреневый бульвар, 15в	f	large
74635	87603	1460	Свердловская область, Екатеринбург, Сиреневый бульвар, 15в	f	large
74634	87603	1459	Свердловская область, Екатеринбург, Сиреневый бульвар, 15в	f	large
74629	87599	1454	Свердловская область, Екатеринбург, Сиреневый бульвар, 6	f	large
74630	87599	1455	Свердловская область, Екатеринбург, Сиреневый бульвар, 6	f	large
74452	87752	1569	Свердловская область, Екатеринбург, Сибирский тракт, 1 км	f	large
74451	87750	1568	Свердловская область, Екатеринбург, Сибирский тракт, 1	f	large
74458	87758	1575	Россия, республика Татарстан, Казань, Сибирский тракт, 37	f	large
74559	87656	1500	Свердловская область, Екатеринбург, Серова, 10	f	large
74558	87656	1499	Свердловская область, Екатеринбург, Серова, 10	f	large
74430	87665	1507	Свердловская область, Екатеринбург, Серафимы Дерябиной, 49а	f	large
74429	87663	1506	Свердловская область, Екатеринбург, Серафимы Дерябиной, 49А	f	large
74428	87663	1505	Свердловская область, Екатеринбург, Серафимы Дерябиной, 49А	f	large
74272	87368	1291	Свердловская область, Екатеринбург, Серафимы Дерябиной, 27а	f	large
74262	87359	1281	Свердловская область, Екатеринбург, Серафимы Дерябиной, 17а	f	large
74261	87359	1280	Свердловская область, Екатеринбург, Серафимы Дерябиной, 17а	f	large
74260	87359	1279	Свердловская область, Екатеринбург, Серафимы Дерябиной, 17а	f	large
122583	87935	1733	Свердловская область, Екатеринбург, Селькоровская, 76/2 корп.1	f	\N
75321	87932	1728	Свердловская область, Екатеринбург, Селькоровская, 18	f	large
74695	87466	1361	Россия, Свердловская область, Екатеринбург, Седова проспект, 46	f	large
74694	87466	1360	Россия, Свердловская область, Екатеринбург, Седова проспект, 46	f	large
74693	87464	1359	Россия, Свердловская область, Екатеринбург, Седова проспект, 28	f	large
74692	87464	1358	Россия, Свердловская область, Екатеринбург, Седова проспект, 28	f	large
74691	87462	1357	Россия, Свердловская область, Екатеринбург, Седова проспект, 21	f	large
122544	87588	1444	Свердловская область, Екатеринбург, Севастопольская, 1	f	\N
74674	87587	1443	Свердловская область, Екатеринбург, Севастопольская, 1	f	large
75319	87930	1726	Свердловская область, Екатеринбург, Санаторная, 20	f	large
75318	87930	1725	Свердловская область, Екатеринбург, Санаторная, 20	f	large
74403	87313	1244	Свердловская область, Екатеринбург, Сакко и Ванцетти, 36	f	large
74402	87313	1243	Свердловская область, Екатеринбург, Сакко и Ванцетти, 36	f	large
74666	87577	1435	Свердловская область, Екатеринбург, Садовая, 18	f	large
74665	87574	1434	Свердловская область, Екатеринбург, Садовая, 18	f	large
74664	87574	1433	Свердловская область, Екатеринбург, Садовая, 18	f	large
74581	87748	1567	Свердловская область, Екатеринбург, Саввы Белых, 7	f	large
74580	87748	1566	Свердловская область, Екатеринбург, Саввы Белых, 7	f	large
122536	87500	1383	Свердловская область, Екатеринбург, Решетская, 55	f	small
74447	87683	1524	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 20	f	large
74446	87683	1523	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 20	f	large
74445	87682	1522	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 5	f	large
74444	87682	1521	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 5	f	large
74443	87679	1520	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 10	f	large
74442	87679	1519	Россия, Свердловская область, Екатеринбург, Решетникова проезд, 10	f	large
74491	87839	1629	Свердловская область, Екатеринбург, Республиканская, 1	f	large
74211	87339	1260	Свердловская область, Екатеринбург, Репина, 15	f	large
74208	87333	1257	Свердловская область, Екатеринбург, Репина, 2а	f	large
74511	87782	1588	Свердловская область, Екатеринбург, Реактивная, 35	f	large
74470	87779	1587	Свердловская область, Екатеринбург, Реактивная, 31	f	large
74639	87610	1464	Свердловская область, Екатеринбург, Рассветная, 9	f	large
74640	87608	1465	Свердловская область, Екатеринбург, Рассветная, 9	f	large
74641	87608	1466	Свердловская область, Екатеринбург, Рассветная, 9	f	large
74638	87608	1463	Свердловская область, Екатеринбург, Рассветная, 9	f	large
74906	85755	149	Свердловская область, Екатеринбург, Ракетная, 6	f	large
74209	87335	1258	Свердловская область, Екатеринбург, Радищева, 51	f	large
74676	87443	1342	Россия, Свердловская область, Екатеринбург, Пугачевский переулок, 5а	f	large
74675	87443	1341	Россия, Свердловская область, Екатеринбург, Пугачевский переулок, 5а	f	large
75495	87942	1741	Свердловская область, Екатеринбург, Походная, 84	f	large
74259	87337	1278	Свердловская область, Екатеринбург, Посадская, 75	f	large
74258	87337	1277	Свердловская область, Екатеринбург, Посадская, 75	f	large
74210	87337	1259	Свердловская область, Екатеринбург, Посадская, 75	f	large
75613	87877	1680	Свердловская область, Екатеринбург, Ползунова, 36	f	large
75570	87877	1667	Свердловская область, Екатеринбург, Ползунова, 36	f	large
121922	86488	664	Свердловская область, Екатеринбург, Победы, 70	t	small
74595	87518	1397	Свердловская область, Екатеринбург, Пионеров, 10а	f	large
74594	87518	1396	Свердловская область, Екатеринбург, Пионеров, 10а	f	large
74593	87518	1395	Свердловская область, Екатеринбург, Пионеров, 10а	f	large
74685	87454	1351	Свердловская область, Екатеринбург, Пехотинцев, 15	f	large
74684	87454	1350	Свердловская область, Екатеринбург, Пехотинцев, 15	f	large
74683	87452	1349	Свердловская область, Екатеринбург, Пехотинцев, 14	f	large
74682	87452	1348	Свердловская область, Екатеринбург, Пехотинцев, 14	f	large
74689	87376	1355	Свердловская область, Екатеринбург, Пехотинцев, 4А	f	large
74688	87376	1354	Свердловская область, Екатеринбург, Пехотинцев, 4А	f	large
74404	87314	1245	Россия, Свердловская область, Екатеринбург, Пестеревский переулок, 3	f	large
74605	87532	1407	Свердловская область, Екатеринбург, Первомайская, 73	f	large
122538	87511	1388	Свердловская область, Екатеринбург, Первомайская, 27	f	\N
122539	87511	1389	Свердловская область, Екатеринбург, Первомайская, 27	f	\N
122537	87506	1386	Свердловская область, Екатеринбург, Первомайская, 59	f	\N
75323	87933	1730	Свердловская область, Екатеринбург, Патриса Лумумбы, 79	f	large
75322	87933	1729	Свердловская область, Екатеринбург, Патриса Лумумбы, 79	f	large
74214	87344	1263	Свердловская область, Екатеринбург, Пальмиро Тольятти, 26А	f	large
74215	87343	1264	Свердловская область, Екатеринбург, Пальмиро Тольятти, 26а	f	large
74213	87343	1262	Свердловская область, Екатеринбург, Пальмиро Тольятти, 26а	f	large
75501	87944	1747	Свердловская область, Екатеринбург, Павлодарская, 40	f	large
75500	87944	1746	Свердловская область, Екатеринбург, Павлодарская, 40	f	large
75499	87944	1745	Свердловская область, Екатеринбург, Павлодарская, 40	f	large
74645	87617	1470	Свердловская область, Екатеринбург, Павла Шаманова, 24	f	large
74644	87617	1469	Свердловская область, Екатеринбург, Павла Шаманова, 24	f	large
74478	87820	1616	Россия, Свердловская область, Екатеринбург, Орджоникидзе проспект, 10	f	large
75256	87914	1697	Свердловская область, Екатеринбург, Онежская, 12	f	large
75327	87936	1734	Свердловская область, Екатеринбург, Окружная, 1	f	large
74626	87596	1451	Свердловская область, Екатеринбург, Новгородцевой, 9а	f	large
74625	87596	1450	Свердловская область, Екатеринбург, Новгородцевой, 9а	f	large
74697	86298	548	Свердловская область, Екатеринбург, Новгородцевой, 5А	f	large
74624	86298	1449	Свердловская область, Екатеринбург, Новгородцевой, 5А	f	large
74623	86298	1448	Свердловская область, Екатеринбург, Новгородцевой, 5А	f	large
74467	87773	1584	Свердловская область, Екатеринбург, Новая, 3	f	large
74466	87773	1583	Свердловская область, Екатеринбург, Новая, 3	f	large
74240	87413	1324	Свердловская область, Екатеринбург, Начдива Васильева, 1	t	large
74653	87628	1480	Свердловская область, Екатеринбург, Народной Воли, 21	f	large
74652	87628	1479	Свердловская область, Екатеринбург, Народной Воли, 21	f	large
74738	86528	695	Свердловская область, Екатеринбург, Надеждинская, 24	f	large
74737	86528	694	Свердловская область, Екатеринбург, Надеждинская, 24	f	large
74622	87592	1446	Свердловская область, Екатеринбург, Мурзинская, 36	f	large
74532	87696	1534	Свердловская область, Екатеринбург, Мостовая, 57	f	large
122503	87394	1310	Свердловская область, Екатеринбург, Московский тракт, 23а, 9км	f	medium
74572	87734	1557	Свердловская область, Екатеринбург, Мичурина, 181	f	large
74571	87734	1556	Свердловская область, Екатеринбург, Мичурина, 181	f	large
74577	87740	1562	Свердловская область, Екатеринбург, Мичурина, 229	f	large
75795	88287	1959	Свердловская область, Екатеринбург, Мира, 40	f	large
74610	87538	1412	Свердловская область, Екатеринбург, Мира, 46	f	large
74609	87538	1411	Свердловская область, Екатеринбург, Мира, 46	f	large
74657	87566	1426	Свердловская область, Екатеринбург, Мира, 22	f	large
122505	87395	1311	Свердловская область, Екатеринбург, Мира, 31	t	medium
74414	87469	1364	Свердловская область, Екатеринбург, Минометчиков, 48	f	large
74413	87469	1363	Свердловская область, Екатеринбург, Минометчиков, 48	f	large
74228	87378	1299	Свердловская область, Екатеринбург, Металлургов, 46	f	large
74227	87378	1298	Свердловская область, Екатеринбург, Металлургов, 46	f	large
74667	87579	1436	Свердловская область, Екатеринбург, Менделеева, 17	f	large
74473	87816	1611	Свердловская область, Екатеринбург, Машиностроителей, 11	t	large
74472	87815	1610	Свердловская область, Екатеринбург, Машиностроителей, 8	f	large
74518	87803	1600	Свердловская область, Екатеринбург, Машиностроителей, 16	f	large
74611	87540	1413	Свердловская область, Екатеринбург, Малышева, 134	f	large
74608	87537	1410	Свердловская область, Екатеринбург, Малышева, 117	f	large
74567	87729	1552	Свердловская область, Екатеринбург, Луначарского, 200	f	large
74566	87727	1551	Свердловская область, Екатеринбург, Луначарского, 173	f	large
74494	87840	1632	Свердловская область, Екатеринбург, Ломоносова, 57	f	large
74493	87840	1631	Свердловская область, Екатеринбург, Ломоносова, 57	f	large
74615	87550	1417	Свердловская область, Екатеринбург, Лодыгина, 8	f	large
74247	87424	1331	Свердловская область, Екатеринбург, Лермонтова, 11	f	large
75527	88373	2006	Россия, Краснодарский край, Краснодар, поселок Ленина	f	large
75524	88364	2002	Россия, Краснодарский край, Краснодар, поселок Ленина	f	large
74538	87719	1545	Россия, Архангельская область, Архангельск, Октябрьский район, Ленина площадь	f	large
122550	87619	1471	Свердловская область, Екатеринбург, Ленина проспект, 28	f	medium
74607	87535	1409	Россия, Астраханская область, Астрахань, Кировский район, улица Ленина	f	large
74606	87535	1408	Россия, Астраханская область, Астрахань, Кировский район, улица Ленина	f	large
74604	87531	1406	Россия, Астраханская область, Астрахань, Кировский район, улица Ленина	f	large
74603	87529	1405	Россия, Астраханская область, Астрахань, Кировский район, улица Ленина	f	large
74585	87509	1387	Россия, Астраханская область, Астрахань, Кировский район, улица Ленина	f	large
74648	87428	1474	Россия, Свердловская область, Екатеринбург, Ленина проспект, 8	f	large
74406	87319	1247	Россия, Свердловская область, Екатеринбург, Ленина проспект, 1	f	large
122302	86910	980	Россия, республика Коми, Сыктывкар, улица Ленина, 4	f	medium
75508	87950	1755	Свердловская область, Екатеринбург, Кутузова, 15	f	large
74424	87482	1374	Свердловская область, Екатеринбург, Кунарская, 28	f	large
74423	87482	1373	Свердловская область, Екатеринбург, Кунарская, 28	f	large
74454	87754	1571	Свердловская область, Екатеринбург, Куйбышева, 100а	f	large
74453	87754	1570	Свердловская область, Екатеринбург, Куйбышева, 100а	f	large
74570	87732	1555	Свердловская область, Екатеринбург, Куйбышева, 111	f	large
74481	87823	1619	Свердловская область, Екатеринбург, Кузнецова, 5	f	large
74479	87823	1617	Свердловская область, Екатеринбург, Кузнецова, 5	f	large
75308	87924	1715	Свердловская область, Екатеринбург, Крестинского, 13А	f	large
75307	87923	1714	Свердловская область, Екатеринбург, Крестинского, 33	f	large
75271	87923	1713	Свердловская область, Екатеринбург, Крестинского, 33	f	large
75270	87923	1712	Свердловская область, Екатеринбург, Крестинского, 33	f	large
75269	87922	1711	Свердловская область, Екатеринбург, Крестинского, 43	f	large
75268	87922	1710	Свердловская область, Екатеринбург, Крестинского, 43	f	large
75267	87922	1709	Свердловская область, Екатеринбург, Крестинского, 43	f	large
75389	87920	1773	Свердловская область, Екатеринбург, Крестинского, 47	f	large
75264	87920	1706	Свердловская область, Екатеринбург, Крестинского, 47	f	large
74206	87328	1255	Свердловская область, Екатеринбург, Крауля, 46	f	large
74205	87328	1254	Свердловская область, Екатеринбург, Крауля, 46	f	large
74412	87327	1253	Свердловская область, Екатеринбург, Крауля, 91	f	large
74410	87325	1251	Свердловская область, Екатеринбург, Крауля, 82а	f	large
74411	87323	1252	Свердловская область, Екатеринбург, Крауля, 82а	f	large
74409	87323	1250	Свердловская область, Екатеринбург, Крауля, 82а	f	large
74474	87813	1612	Свердловская область, Екатеринбург, Красных Партизан, 4	f	large
122576	87813	1608	Свердловская область, Екатеринбург, Красных Партизан, 4	f	medium
75572	87879	1669	Свердловская область, Екатеринбург, Красных Командиров, 11а	f	large
75621	87901	1688	Свердловская область, Екатеринбург, Краснофлотцев, 3	f	large
75620	87901	1687	Свердловская область, Екатеринбург, Краснофлотцев, 3	f	large
75619	87901	1686	Свердловская область, Екатеринбург, Краснофлотцев, 3	f	large
75617	87896	1684	Свердловская область, Екатеринбург, Краснофлотцев, 28а	f	large
74530	87691	1532	Свердловская область, Екатеринбург, Краснолесья, 22	f	large
74568	87716	1553	Свердловская область, Екатеринбург, Красноармейская, 27	f	large
74537	87716	1544	Свердловская область, Екатеринбург, Красноармейская, 27	f	large
74226	87375	1297	Свердловская область, Екатеринбург, Котельникова, 5а	f	large
74277	87375	1296	Свердловская область, Екатеринбург, Котельникова, 5а	f	large
74276	87375	1295	Свердловская область, Екатеринбург, Котельникова, 5а	f	large
74275	87375	1294	Свердловская область, Екатеринбург, Котельникова, 5а	f	large
75622	87902	1689	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 30к1	f	large
75605	87882	1672	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 54а	f	large
75604	87882	1671	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 54а	f	large
75559	87862	1656	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 99а	f	large
75558	87857	1655	Свердловская область, Екатеринбург, Космонавтов проспект, 65	f	large
75552	87857	1649	Свердловская область, Екатеринбург, Космонавтов проспект, 65	f	large
74508	87854	1646	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 43в	f	large
74499	87825	1637	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 23	f	large
74498	87825	1636	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 23	f	large
74480	87825	1618	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 23	f	large
74280	87260	1214	Россия, Свердловская область, Екатеринбург, Космонавтов проспект, 30к2	f	large
75512	87952	1759	Свердловская область, Екатеринбург, Косарева, 9	f	large
75511	87952	1758	Свердловская область, Екатеринбург, Косарева, 9	f	large
75510	87952	1757	Свердловская область, Екатеринбург, Косарева, 9	f	large
75498	87943	1744	Россия, Свердловская область, Екатеринбург, Короткий переулок, 7	f	large
75497	87943	1743	Россия, Свердловская область, Екатеринбург, Короткий переулок, 7	f	large
75496	87943	1742	Россия, Свердловская область, Екатеринбург, Короткий переулок, 7	f	large
75502	87945	1748	Россия, Свердловская область, Екатеринбург, Корейский переулок, 6	f	large
74618	87555	1420	Свердловская область, Екатеринбург, Комсомольская, 21	f	large
74614	87548	1416	Свердловская область, Екатеринбург, Комсомольская, 63	f	large
74613	87546	1415	Свердловская область, Екатеринбург, Комсомольская, 74	f	large
75557	87860	1654	Свердловская область, Екатеринбург, Коммунистическая, 81	f	large
75556	87860	1653	Свердловская область, Екатеринбург, Коммунистическая, 81	f	large
75555	87860	1652	Свердловская область, Екатеринбург, Коммунистическая, 81	f	large
75554	87860	1651	Свердловская область, Екатеринбург, Коммунистическая, 81	f	large
74504	87848	1642	Свердловская область, Екатеринбург, Коммунистическая, 53	f	large
74533	87697	1535	Свердловская область, Екатеринбург, Комбинатская, 7	t	large
75493	87940	1739	Свердловская область, Екатеринбург, Колхозников, 52	f	large
122546	87590	1445	Свердловская область, Екатеринбург, Коломенский переулок, 3	f	medium
74255	87439	1339	Свердловская область, Екатеринбург, Колмогорова, 70	f	large
74408	87321	1249	Свердловская область, Екатеринбург, Ключевская, 5а	f	large
74407	87321	1248	Свердловская область, Екатеринбург, Ключевская, 5а	f	large
74484	87828	1622	Свердловская область, Екатеринбург, Кировградская, 40а	f	large
74483	87828	1621	Свердловская область, Екатеринбург, Кировградская, 40а	f	large
75569	87874	1666	Свердловская область, Екатеринбург, Каширская, 73	f	large
74565	87724	1550	Свердловская область, Екатеринбург, Карла Маркса, 33	f	large
122552	87624	1477	Свердловская область, Екатеринбург, Карла Маркса, 5	f	medium
74460	87760	1577	Свердловская область, Екатеринбург, Каменотесов, 9	f	large
74459	87760	1576	Свердловская область, Екатеринбург, Каменотесов, 9	f	large
74497	87827	1635	Свердловская область, Екатеринбург, Калинина, 26а	f	large
74482	87827	1620	Свердловская область, Екатеринбург, Калинина, 26а	f	large
75254	87827	1694	Свердловская область, Екатеринбург, Калинина, 26а	f	large
75252	87827	1692	Свердловская область, Екатеринбург, Калинина, 26а	f	large
74663	87573	1432	Свердловская область, Екатеринбург, Июльская, 20	f	large
74659	87567	1428	Свердловская область, Екатеринбург, Июльская, 32	f	large
74658	87567	1427	Свердловская область, Екатеринбург, Июльская, 32	f	large
75386	87958	1770	Свердловская область, Екатеринбург, Инженерная, 48	f	large
75385	87958	1769	Свердловская область, Екатеринбург, Инженерная, 48	f	large
74507	87845	1645	Свердловская область, Екатеринбург, Ильича, 48А	f	large
74506	87845	1644	Свердловская область, Екатеринбург, Ильича, 48А	f	large
74500	87845	1638	Свердловская область, Екатеринбург, Ильича, 48А	f	large
74520	87804	1602	Свердловская область, Екатеринбург, Ильича, 26	f	large
74503	87846	1641	Свердловская область, Екатеринбург, Избирателей, 68	f	large
74502	87846	1640	Свердловская область, Екатеринбург, Избирателей, 68	f	large
75612	87890	1679	Свердловская область, Екатеринбург, Замятина, 11а	f	large
122523	87441	1340	Свердловская область, Екатеринбург, Завокзальная, 5	f	small
74257	87357	1276	Свердловская область, Екатеринбург, Заводская, 45	f	large
74256	87357	1275	Свердловская область, Екатеринбург, Заводская, 45	f	large
74225	87355	1274	Свердловская область, Екатеринбург, Заводская, 44	f	large
74224	87355	1273	Свердловская область, Екатеринбург, Заводская, 44	f	large
74223	87355	1272	Свердловская область, Екатеринбург, Заводская, 44	f	large
74222	87354	1271	Свердловская область, Екатеринбург, Заводская, 36б	f	large
74221	87354	1270	Свердловская область, Екатеринбург, Заводская, 36б	f	large
75435	87968	1786	Свердловская область, Екатеринбург, Жуковского площадь, 10	f	large
74600	87525	1402	Свердловская область, Екатеринбург, Железнодорожников, 3	f	large
74248	87427	1332	Свердловская область, Екатеринбург, Еремина, 10	f	large
74529	87689	1531	Свердловская область, Екатеринбург, Денисова-Уральского бульвар, 3	f	large
74528	87689	1530	Свердловская область, Екатеринбург, Денисова-Уральского бульвар, 3	f	large
74527	87689	1529	Свердловская область, Екатеринбург, Денисова-Уральского бульвар, 3	f	large
74526	87687	1528	Свердловская область, Екатеринбург, Денисова-Уральского бульвар, 9а	f	large
74450	87687	1527	Свердловская область, Екатеринбург, Денисова-Уральского бульвар, 9а	f	large
74569	87730	1554	Свердловская область, Екатеринбург, Декабристов, 49	f	large
74673	87584	1442	Свердловская область, Екатеринбург, Данилы Зверева, 30	f	large
74672	87582	1441	Свердловская область, Екатеринбург, Данилы Зверева, 8	f	large
74671	87582	1440	Свердловская область, Екатеринбург, Данилы Зверева, 8	f	large
74670	87580	1439	Свердловская область, Екатеринбург, Данилы Зверева, 11	f	large
74669	87580	1438	Свердловская область, Екатеринбург, Данилы Зверева, 11	f	large
75614	87892	1681	Свердловская область, Екатеринбург, Даниловская, 1	f	large
74434	87669	1511	Свердловская область, Екатеринбург, Громова, 138а	f	large
74433	87669	1510	Свердловская область, Екатеринбург, Громова, 138а	f	large
75382	87956	1766	Свердловская область, Екатеринбург, Грибоедова, 13	f	large
75381	87956	1765	Свердловская область, Екатеринбург, Грибоедова, 13	f	large
75377	87953	1761	Свердловская область, Екатеринбург, Грибоедова, 11А	f	large
75513	87953	1760	Свердловская область, Екатеринбург, Грибоедова, 11А	f	large
74239	87412	1323	Свердловская область, Екатеринбург, Готвальда, 15а	f	large
74234	87385	1305	Свердловская область, Екатеринбург, Готвальда, 15а	f	large
74230	87379	1301	Свердловская область, Екатеринбург, Готвальда, 19а	f	large
74229	87379	1300	Свердловская область, Екатеринбург, Готвальда, 19а	f	large
74534	87700	1536	Свердловская область, Екатеринбург, Городская, 2б	t	large
74536	87715	1543	Россия, Свердловская область, Екатеринбург, Горнистов проезд, 13	f	large
74469	87778	1586	Свердловская область, Екатеринбург, Главная, 1а	f	large
74468	87776	1585	Свердловская область, Екатеринбург, Главная, 21	f	large
75505	87946	1751	Свердловская область, Екатеринбург, Гаршина, 8б	f	large
75504	87946	1750	Свердловская область, Екатеринбург, Гаршина, 8б	f	large
75503	87946	1749	Свердловская область, Екатеринбург, Гаршина, 8б	f	large
121440	86005	335	Россия, Свердловская область, Екатеринбург, Гаринский переулок, 4	f	\N
74642	87612	1467	Свердловская область, Екатеринбург, Высоцкого, 22	f	large
122230	86870	943	Свердловская область, Екатеринбург, Высоцкого, 45	t	\N
74244	87419	1328	Свердловская область, Екатеринбург, Восточная, 26	f	large
74243	87419	1327	Свердловская область, Екатеринбург, Восточная, 26	f	large
74505	87851	1643	Свердловская область, Екатеринбург, Восстания, 34	f	large
74441	87678	1518	Свердловская область, Екатеринбург, Волгоградская, 37б	f	large
74440	87678	1517	Свердловская область, Екатеринбург, Волгоградская, 37б	f	large
74439	87676	1516	Свердловская область, Екатеринбург, Волгоградская, 45а	f	large
74438	87676	1515	Свердловская область, Екатеринбург, Волгоградская, 45а	f	large
74437	87674	1514	Свердловская область, Екатеринбург, Волгоградская, 47а	f	large
121863	86424	620	Свердловская область, Екатеринбург, Вокзальная, 22	t	small
74217	87347	1266	Россия, Свердловская область, Екатеринбург, Верх-Исетский бульвар, 23	f	large
74216	87347	1265	Россия, Свердловская область, Екатеринбург, Верх-Исетский бульвар, 23	f	large
75665	87906	1691	Свердловская область, Екатеринбург, Верстовая, 14	f	large
74650	87522	1476	Свердловская область, Екатеринбург, Вайнера, 54	f	large
74582	87503	1384	Свердловская область, Екатеринбург, Братьев Быковых, 34а	f	large
75509	87951	1756	Свердловская область, Екатеринбург, Бородина, 1	f	large
74207	87331	1256	Свердловская область, Екатеринбург, Большой Конный Полуостров, 9	f	large
74576	87738	1561	Свердловская область, Екатеринбург, Большакова, 18	f	large
74575	87738	1560	Свердловская область, Екатеринбург, Большакова, 18	f	large
74574	87738	1559	Свердловская область, Екатеринбург, Большакова, 18	f	large
74545	87638	1486	Свердловская область, Екатеринбург, Большакова, 65	f	large
74588	87513	1390	Свердловская область, Екатеринбург, Блюхера, 5А	f	large
75436	87969	1787	Свердловская область, Екатеринбург, Бисертская, 14	f	large
75492	87939	1738	Свердловская область, Екатеринбург, Бисертская, 30	f	large
75376	87939	1737	Свердловская область, Екатеринбург, Бисертская, 30	f	large
74419	87475	1369	Свердловская область, Екатеринбург, Билимбаевская, 26	f	large
74418	87475	1368	Свердловская область, Екатеринбург, Билимбаевская, 26	f	large
74739	86530	696	Свердловская область, Екатеринбург, Билимбаевская, 33	f	large
74637	87606	1462	Свердловская область, Екатеринбург, Бетонщиков, 3	f	large
74464	87769	1581	Свердловская область, Екатеринбург, Белоярская, 20	f	large
74265	87364	1284	Свердловская область, Екатеринбург, Белореченская, 26	f	large
74271	87348	1290	Свердловская область, Екатеринбург, Белореченская, 25	f	large
74270	87348	1289	Свердловская область, Екатеринбург, Белореченская, 25	f	large
74269	87348	1288	Свердловская область, Екатеринбург, Белореченская, 25	f	large
122666	88275	1952	Свердловская область, Екатеринбург, Белинского, 91	f	medium
75263	87919	1705	Свердловская область, Екатеринбург, Белинского, 226к3	f	large
74578	87742	1563	Свердловская область, Екатеринбург, Белинского, 163	f	large
74547	87641	1488	Свердловская область, Екатеринбург, Белинского, 123	f	large
74546	87641	1487	Свердловская область, Екатеринбург, Белинского, 123	f	large
74236	87387	1307	Свердловская область, Екатеринбург, Бебеля, 122а	f	large
74235	87387	1306	Свердловская область, Екатеринбург, Бебеля, 122а	f	large
74233	87383	1304	Свердловская область, Екатеринбург, Бебеля, 16	f	large
74681	87450	1347	Свердловская область, Екатеринбург, Бебеля, 150	f	large
74680	87450	1346	Свердловская область, Екатеринбург, Бебеля, 150	f	large
122582	87915	1698	Россия, Свердловская область, Екатеринбург, Бахчиванджи площадь, 1	t	small
75606	87885	1673	Свердловская область, Екатеринбург, Баумана, 7	f	large
75608	87881	1675	Свердловская область, Екатеринбург, Баумана, 17	f	large
75603	87881	1670	Свердловская область, Екатеринбург, Баумана, 17	f	large
74495	87833	1633	Свердловская область, Екатеринбург, Бакинских Комиссаров, 50	f	large
74492	87833	1630	Свердловская область, Екатеринбург, Бакинских Комиссаров, 50	f	large
74487	87833	1625	Свердловская область, Екатеринбург, Бакинских Комиссаров, 50	f	large
74456	87757	1573	Свердловская область, Екатеринбург, Байкальская, 41	f	large
74455	87757	1572	Свердловская область, Екатеринбург, Байкальская, 41	f	large
74564	87722	1549	Свердловская область, Екатеринбург, Бажова, 139	f	large
74541	87722	1548	Свердловская область, Екатеринбург, Бажова, 139	f	large
74540	87721	1547	Свердловская область, Екатеринбург, Бажова, 124	f	large
74539	87721	1546	Свердловская область, Екатеринбург, Бажова, 124	f	large
74677	87445	1343	Свердловская область, Екатеринбург, Артинская, 26	f	large
75320	87931	1727	Свердловская область, Екатеринбург, Аптекарская, 46	f	large
74401	87311	1242	Свердловская область, Екатеринбург, Антона Валека, 8А	f	large
74427	87497	1381	Свердловская область, Екатеринбург, Ангарская, 54а	f	large
74421	87477	1371	Свердловская область, Екатеринбург, Ангарская, 54А	f	large
74420	87477	1370	Свердловская область, Екатеринбург, Ангарская, 54А	f	large
75384	87957	1768	Свердловская область, Екатеринбург, Альпинистов, 27	f	large
75383	87957	1767	Свердловская область, Екатеринбург, Альпинистов, 27	f	large
74425	87483	1375	Свердловская область, Екатеринбург, Акулова, 29	f	large
74619	87558	1421	Свердловская область, Екатеринбург, Академическая, 16	f	large
74449	87686	1526	Свердловская область, Екатеринбург, Академика Постовского, 8	f	large
74448	87686	1525	Свердловская область, Екатеринбург, Академика Постовского, 8	f	large
74436	87672	1513	Свердловская область, Екатеринбург, Академика Бардина, 28	f	large
74435	87672	1512	Свердловская область, Екатеринбург, Академика Бардина, 28	f	large
74432	87668	1509	Свердловская область, Екатеринбург, Академика Бардина, 21Б	f	large
74431	87668	1508	Свердловская область, Екатеринбург, Академика Бардина, 21Б	f	large
74273	87371	1292	Свердловская область, Екатеринбург, Академика Бардина, 14	f	large
122310	86915	985	Свердловская область, Екатеринбург, Академика Бардина, 25к2	f	small
122826	88989	2409	Свердловская область, Екатеринбург, 8-го Марта, 145	f	small
75258	87918	1700	Свердловская область, Екатеринбург, 8-го Марта, 177	f	large
74544	87637	1485	Свердловская область, Екатеринбург, 8-го Марта, 89	f	large
74542	87633	1483	Свердловская область, Екатеринбург, 8-го Марта, 66	f	large
74654	87631	1481	Свердловская область, Екатеринбург, 8-го Марта, 84	f	large
74655	87631	1482	Свердловская область, Екатеринбург, 8-го Марта, 84	f	large
74633	87602	1458	Свердловская область, Екатеринбург, 40летия Комсомола, 22а	f	large
74632	87602	1457	Свердловская область, Екатеринбург, 40летия Комсомола, 22а	f	large
74631	87602	1456	Свердловская область, Екатеринбург, 40летия Комсомола, 22а	f	large
74519	87801	1601	Свердловская область, Екатеринбург,  Машиностроителей, 26	f	large
74517	87801	1599	Свердловская область, Екатеринбург,  Машиностроителей, 26	f	large
74516	87801	1598	Свердловская область, Екатеринбург,  Машиностроителей, 26	f	large
74661	87560	1430	Свердловская область, Екатеринбург,  Академическая, 21	f	large
74620	87560	1422	Свердловская область, Екатеринбург,  Академическая, 21	f	large
74397	87303	1238	Свердловская область, Дегтярск, Уральских Танкистов, 12	f	large
74400	87309	1241	Свердловская область, Дегтярск, Пролетарская, 40А	f	large
74399	87307	1240	Свердловская область, Дегтярск, Почтовая, 3	f	large
74392	87294	1232	Свердловская область, Волчанск, Советская, 3	f	large
74390	87291	1230	Свердловская область, Волчанск, Молодежная, 68	f	large
74393	87297	1233	Свердловская область, Волчанск, Карпинского, 12	f	large
121408	85966	314	Свердловская область, Верхотурье, Сенянского, 12	f	medium
74287	87279	1223	Свердловская область, Верхняя Тура, Первомайская, 28	t	large
74290	87285	1226	Свердловская область, Верхняя Тура, Машиностроителей, 16	f	large
74812	85922	290	Свердловская область, Верхняя Салда, Энгельса, 79	f	large
121389	85908	282	Свердловская область, Верхняя Салда, Строителей, 1	f	medium
74813	85927	292	Свердловская область, Верхняя Салда, Пушкина, 23	t	large
122476	87242	1197	Свердловская область, Верхняя Пышма, профилакторий "Селен", клубстоловая	f	small
121893	86469	643	Свердловская область, Верхняя Пышма, поселок Коптяки, Здание клуба	t	small
74306	87221	1179	Свердловская область, Верхняя Пышма, Щорса, 1А, МУК Агат	f	large
74382	87236	1193	Свердловская область, Верхняя Пышма, Чкалова, 87, Досуговый центр	f	large
74374	87223	1185	Свердловская область, Верхняя Пышма, Чистова, 9, Школа №33	f	large
74307	87223	1180	Свердловская область, Верхняя Пышма, Чистова, 9, Школа №33	f	large
74385	87241	1196	Свердловская область, Верхняя Пышма, Советская, 9, Магазин Продукты	f	large
74384	87238	1195	Свердловская область, Верхняя Пышма, Петрова, 59, ТВЦ Восток	f	large
74383	87237	1194	Свердловская область, Верхняя Пышма, Петрова, 43, Школа №25	f	large
74279	87259	1211	Свердловская область, Верхняя Пышма, Огнеупорщиков, 10А, Колледж им. И.И.Ползунова	f	large
74377	87231	1188	Свердловская область, Верхняя Пышма, Огнеупорщиков, 10А, Колледж им. И.И. Ползунова	f	large
74386	87244	1198	Свердловская область, Верхняя Пышма, Менделеевская, 7, Дом детского творчества	f	large
74376	87230	1187	Свердловская область, Верхняя Пышма, Машиностроителей, 6, Школа №3	f	large
74379	87232	1190	Свердловская область, Верхняя Пышма, Лесная, 1, Техникум Уралмашевец	f	large
74380	87234	1191	Свердловская область, Верхняя Пышма, Ленина, 47, Школа №22	f	large
74375	87229	1186	Свердловская область, Верхняя Пышма, Ленина, 48	f	large
74304	87218	1177	Свердловская область, Верхняя Пышма, Ленина, 12, АУ ДК Металлург	f	large
74373	87226	1184	Свердловская область, Верхняя Пышма, Кривоусова, 53, Техникум """"""""Юность""""""""	f	large
74372	87226	1183	Свердловская область, Верхняя Пышма, Кривоусова, 53, Техникум """"""""Юность""""""""	f	large
74371	87225	1182	Свердловская область, Верхняя Пышма, Кривоусова, 42, Школа №2	f	large
74308	87224	1181	Свердловская область, Верхняя Пышма, Кривоусова, 38	f	large
74381	87235	1192	Свердловская область, Верхняя Пышма, Красноармейская, 6, Школа №1	f	large
74305	87220	1178	Свердловская область, Верхняя Пышма, Калинина, 37Б, Школа №4	f	large
74378	87220	1189	Свердловская область, Верхняя Пышма, Калинина, 37Б, Школа №4	f	large
74387	87247	1200	Свердловская область, Верхняя Пышма, Дружбы, 1А, Здание Администрации	f	large
122495	87263	1215	Свердловская область, Верхний Тагил, поселок Белоречка, Горького, № 4	t	small
74855	85890	260	Свердловская область, Богданович	f	large
74843	85890	259	Свердловская область, Богданович	f	large
74842	85890	258	Свердловская область, Богданович	f	large
74839	85886	255	Свердловская область, Богданович, Школьная, 5	f	large
74838	85885	254	Свердловская область, Богданович, Школьная, 2	f	large
74837	85884	253	Свердловская область, Богданович, Степана Разина, 43	f	large
74835	85881	250	Свердловская область, Богданович, Спортивная, 16А	f	large
74831	85877	246	Свердловская область, Богданович, Советская, 2	f	large
74836	85882	251	Свердловская область, Богданович, Рокицанская, 6А	f	large
74841	85889	257	Свердловская область, Богданович, Пролетарская, 37	f	large
74840	85888	256	Свердловская область, Богданович, Пищевиков, 1	f	large
121364	85883	252	Свердловская область, Богданович, Некрасова, 1	f	medium
74833	85879	248	Свердловская область, Богданович, Кунавина, 31	f	large
74834	85880	249	Свердловская область, Богданович, Декабристов, 2	f	large
74832	85878	247	Свердловская область, Богданович, Гагарина, 32	f	large
122139	86774	852	Свердловская область, поселок Бобровский, Краснодеревцев, 37	f	medium
74331	87149	1136	Россия, Курская область, город Курск, улица Театральная, 7	f	large
74343	87172	1150	Россия, Свердловская область, Березовский, улица Ленина, 22	f	large
74303	87216	1174	Свердловская область, Березовский, улица Брусницина, 4	f	large
122471	87207	1168	Свердловская область, Березовский, Школьная, 3	f	small
74334	87154	1139	Свердловская область, Березовский, Шиловская, 3	f	large
74344	87174	1151	Свердловская область, Березовский, Транспортников, 46к1	f	large
74335	87156	1140	Свердловская область, Березовский, Театральная, 28	f	large
74333	87153	1138	Свердловская область, Березовский, Театральная, 13	f	large
74332	87151	1137	Свердловская область, Березовский, Театральная, 11	f	large
74299	87204	1167	Свердловская область, Березовский, Строителей, 1	f	large
74340	87169	1147	Свердловская область, Березовский, Спортивная, 7, СОК Лидер	f	large
74302	87187	1171	Свердловская область, Березовский, Смирнова, 1	f	large
74294	87187	1158	Свердловская область, Березовский, Смирнова, 1	f	large
74293	87187	1157	Свердловская область, Березовский, Смирнова, 1	f	large
74348	87185	1156	Свердловская область, Березовский, Смирнова, 3а	f	large
74345	87176	1152	Свердловская область, Березовский, Свободы, 108	f	large
121566	86147	406	Свердловская область, Березовский, Пионерская, 17	t	small
122475	87214	1173	Свердловская область, Березовский, Первого Мая, 17а	f	small
74339	87164	1145	Свердловская область, Березовский, Парковая, 10	f	large
122489	87255	1207	Свердловская область, Березовский, Октябрьская, 22, Фельдшерский пункт	t	small
74338	87163	1144	Свердловская область, Березовский, Мира, 5	f	large
74337	87163	1143	Свердловская область, Березовский, Мира, 5	f	large
74346	87180	1154	Свердловская область, Березовский, М.Горького, 3а	f	large
121935	86495	672	Свердловская область, Березовский, Луговая, 1	t	small
122458	87166	1146	Свердловская область, Березовский, Ленина, 48	f	medium
122473	87213	1172	Свердловская область, Березовский, поселок Сарапулка, Ленина, 58	f	\N
122463	87193	1161	Свердловская область, Березовский, Крылосова, 20	t	small
134686	95006	1149	Свердловская область, Березовский, Красных Героев, 7	f	\N
74341	87171	1148	Свердловская область, Березовский, Красных Героев, 1а	f	large
74336	87160	1142	Свердловская область, Березовский, Косых, 3	f	large
74296	87190	1160	Свердловская область, Березовский, Горького, 2а	f	large
74295	87189	1159	Свердловская область, Березовский, Горького, 2а	f	large
74301	87211	1170	Свердловская область, Березовский, Волкова, 1	f	large
122460	87178	1153	Россия, Свердловская область, Березовский, Березовский тракт, 9	f	medium
74347	87182	1155	Свердловская область, Березовский, Академика Королева, 1	f	large
121331	85854	217	Свердловская область, поселок Белоярский, санаторий Кристалл	t	small
121327	85851	215	Свердловская область, поселок Белоярский, Химиков, 12	f	medium
121329	85852	216	Свердловская область, поселок Белоярский, Свердлова, 1	t	medium
74807	85861	229	Свердловская область, поселок Белоярский, Привокзальная, 1А	f	large
74802	85848	212	Свердловская область, поселок Белоярский, Переулок Светлый, 2	f	large
74804	85850	214	Свердловская область, поселок Белоярский, Молодежная, 42 А	t	large
74800	85846	210	Свердловская область, поселок Белоярский, Милицейская, 25	f	large
74801	85847	211	Свердловская область, поселок Белоярский, Ленина, 257	f	large
121325	85849	213	Свердловская область, поселок Белоярский, Горем, 35	f	\N
74847	85831	189	Свердловская область, поселок Байкалово, Свердлова, 3	f	large
122454	87147	1135	Свердловская область, Асбест, медпункт	f	small
74980	87124	1111	Свердловская область, Асбест, Школьная, 30	f	large
74311	87128	1115	Свердловская область, Асбест, Чапаева, 28	f	large
74981	87125	1112	Свердловская область, Асбест, Чапаева, 2	f	large
74309	87126	1113	Свердловская область, Асбест, Физкультурников, 38	f	large
75648	89267	2576	Свердловская область, Асбест, поселок Малышева, Тимирязева, 1	f	large
74313	87130	1117	Свердловская область, Асбест, Советская, 2	f	large
74357	87123	1110	Свердловская область, Асбест, Советская, 14	f	large
74314	87103	1118	Свердловская область, Асбест, Советская, 10	f	large
74330	87146	1134	Свердловская область, Асбест, Серова, 2	f	large
75647	89265	2575	Свердловская область, Асбест, Садовая, 19	f	large
74326	87142	1130	Свердловская область, Асбест, Победы, 24	f	large
74319	87135	1123	Свердловская область, Асбест, Плеханова, 3/2	f	large
74329	87145	1133	Свердловская область, Асбест, Папанина, 52	f	large
74328	87144	1132	Свердловская область, Асбест, Осипенко, 32	f	large
74320	87136	1124	Свердловская область, Асбест, Октябрьской революции, 16	f	large
74318	87134	1122	Свердловская область, Асбест, Мира, 4/3	f	large
74317	87133	1121	Свердловская область, Асбест, Мира, 10	f	large
74310	87127	1114	Свердловская область, Асбест, Лесная, 36	f	large
74325	87141	1129	Свердловская область, Асбест, Ленинградская, 10	f	large
74321	87137	1125	Свердловская область, Асбест, Ленинградская, 29	f	large
74324	87140	1128	Свердловская область, Асбест, Ленина, 14	f	large
74322	87138	1126	Свердловская область, Асбест, Ленина, 26/3	f	large
74316	87132	1120	Свердловская область, Асбест, Ладыженского, 17	f	large
74315	87131	1119	Свердловская область, Асбест, Ладыженского, 7	f	large
74312	87129	1116	Свердловская область, Асбест, Калинина, 40	f	large
74323	87139	1127	Свердловская область, Асбест, Войкова, 71	f	large
74327	87143	1131	Свердловская область, Асбест, 8 Марта , 16	f	large
74895	85642	58	Свердловская область, Артёмовский, пер. Заводской, 2А	f	large
121114	81363	56	Свердловская область, Артёмовский, Пригородная, 2а	f	medium
74904	85655	70	Свердловская область, Артёмовский, Котовского, 4	f	large
74349	87084	1088	Свердловская область, Алапаевск, улица Николая Островского, 8/3	f	large
74971	87069	1078	Свердловская область, Алапаевск, Фрунзе, 46	f	large
74970	87067	1077	Свердловская область, Алапаевск, Фрунзе, 43	f	large
74966	87057	1072	Свердловская область, Алапаевск, Урицкого, 147	f	large
122428	87086	1089	Свердловская область, Алапаевск, Советская, 105	f	medium
74967	87058	1073	Свердловская область, Алапаевск, Розы Люксембург, 58	f	large
74972	87071	1079	Свердловская область, Алапаевск, Павлова, 41	f	large
74969	87062	1075	Свердловская область, Алапаевск, Павлова, 12	f	large
122432	87093	1093	Свердловская область, Алапаевск, поселок Зыряновский, Октябрьская, 8	t	medium
122427	87082	1087	Свердловская область, Алапаевск, Мира, 4	f	\N
74978	87081	1086	Свердловская область, Алапаевск, Мира, 7	f	large
122424	87064	1076	Свердловская область, Алапаевск, Ленина, 10	f	medium
74968	87061	1074	Свердловская область, Алапаевск, Ленина, 35	f	large
74965	87055	1071	Свердловская область, Алапаевск, Ленина, 77	f	large
74977	87076	1085	Свердловская область, Алапаевск, Краснофлотцев, 73	f	large
122426	87076	1083	Свердловская область, Алапаевск, Краснофлотцев, 73	f	medium
74975	87076	1082	Свердловская область, Алапаевск, Краснофлотцев, 73	f	large
74350	87090	1091	Свердловская область, Алапаевск, Клубная, 22	f	large
74351	87089	1092	Свердловская область, Алапаевск, Клубная, 24	f	large
122431	87089	1090	Свердловская область, Алапаевск, Клубная, 24	f	medium
74976	87079	1084	Свердловская область, Алапаевск, Говырина, 3	f	large
74973	87073	1080	Свердловская область, Алапаевск, Братьев Смольниковых, 134	f	large
74974	87074	1081	Свердловская область, Алапаевск, 3-го Интернационала, 10	f	large
75300	89078	2463	Свердловская область, городской округ Североуральск, поселок Черёмухово, Калинина, 38	f	large
75299	89077	2462	Свердловская область, городской округ Североуральск, поселок Черёмухово, Калинина, 19	f	large
122843	89080	2464	Свердловская область, городской округ Североуральск, поселок Сосьва (Долгая Паберега), 40 лет Октября, 21	f	\N
75298	89075	2461	Свердловская область, городской округ Североуральск, поселок Калья, Ленина, 33	f	large
122022	86608	750	Свердловская область, городской округ Ревда, поселок Мариинск, Мичурина, 1	f	medium
74394	87298	1235	Свердловская область, городской округ Ревда, Дегтярск, Советская, 33	f	large
74396	87300	1237	Свердловская область, городской округ Ревда, Дегтярск, Площадь Ленина, 1а	f	large
74398	87305	1239	Свердловская область, городской округ Ревда, Дегтярск, Культуры, 29	f	large
75427	89046	2444	Свердловская область, городской округ Полевской, поселок Полдневая, М. Горького, 10	f	large
75426	89041	2442	Свердловская область, городской округ Полевской, поселок Косой Брод, Советская, 25	f	large
75425	89035	2439	Свердловская область, городской округ Полевской, поселок Зюзельский, Ленина, 4	f	large
122816	88978	2403	Свердловская область, городской округ Первоуральск, поселок Старые Решёты, Школьная, 1	t	small
75221	88968	2397	Свердловская область, городской округ Первоуральск, поселок Новоуткинск, Культуры, 11	f	large
122384	87016	1039	Свердловская область, Туринский район, поселок Шухруповское, Мира, 10А	f	medium
75222	88972	2400	Свердловская область, городской округ Первоуральск, поселок Новоалексеевское, Буденого, 38	f	large
122805	88958	2391	Свердловская область, городской округ Первоуральск, поселок Крылосово, КИЗ, 13	f	medium
75216	88956	2390	Свердловская область, городской округ Первоуральск, поселок Битимка, Заречная, 8	f	large
122803	88952	2388	Свердловская область, городской округ Первоуральск, поселок Билимбай, Лермонтова, 5а	f	medium
75212	88946	2385	Свердловская область, городской округ Первоуральск, поселок Билимбай, Ленина, 84	f	large
75214	88950	2387	Свердловская область, городской округ Первоуральск, поселок Билимбай, Красноармейская, 62	f	large
122751	88566	2127	Свердловская область, городской округ Нижняя Тура, поселок Таёжный, Культуры, 6	f	medium
121859	86421	618	Свердловская область, городской округ Нижняя Тура, поселок Новая Тура, Советская, 38	t	small
75344	88554	2121	Свердловская область, городской округ Нижняя Тура, Лесной, Юбилейная, 6	f	large
75342	88550	2119	Свердловская область, городской округ Нижняя Тура, Лесной, Юбилейная, 2	f	large
75343	88553	2120	Свердловская область, городской округ Нижняя Тура, Лесной, Мира, 30	f	large
75337	88543	2114	Свердловская область, городской округ Нижняя Тура, Лесной, Мамина-Сибиряка, 47	f	large
75339	88541	2116	Свердловская область, городской округ Нижняя Тура, Лесной, Мамина-Сибиряка, 37	f	large
75336	88541	2113	Свердловская область, городской округ Нижняя Тура, Лесной, Мамина-Сибиряка, 37	f	large
75345	88556	2122	Свердловская область, городской округ Нижняя Тура, Лесной, Ленина, 94	f	large
75341	88549	2118	Свердловская область, городской округ Нижняя Тура, Лесной, Ленина, 69	f	large
75333	88533	2110	Свердловская область, городской округ Нижняя Тура, Лесной, Ленина, 22	f	large
75466	88523	2105	Свердловская область, городской округ Нижняя Тура, Лесной, Ленина, 10	f	large
75340	88546	2117	Свердловская область, городской округ Нижняя Тура, Лесной, Кирова, 58	f	large
75514	88530	2108	Свердловская область, городской округ Нижняя Тура, Лесной, Дзержинского, 1а	f	large
75347	88560	2124	Свердловская область, городской округ Нижняя Тура, Лесной, Горького, 11	f	large
75334	88536	2111	Свердловская область, городской округ Нижняя Тура, Лесной, Белинского, 49а	f	large
75468	88527	2107	Свердловская область, городской округ Нижняя Тура, Лесной, Белинского, 18	f	large
75346	88559	2123	Свердловская область, городской округ Нижняя Тура, Лесной, Бажова, 1а	f	large
74770	86415	612	Свердловская область, городской округ Нижняя Тура, поселок Ис, Ленина проспект, 83	f	large
121850	86416	613	Свердловская область, городской округ Нижняя Тура, поселок Ис, Ленина, 92	f	medium
121858	86420	617	Свердловская область, городской округ Нижняя Тура, поселок Большая Именная, Советская, 12	t	small
122749	88565	2126	Свердловская область, городской округ Нижняя Тура, поселок Ёлкино, Клубная, 16	t	medium
74288	87280	1224	Свердловская область, городской округ Кушва, Верхняя Тура, Машиностроителей, 4	f	large
74291	87286	1227	Свердловская область, городской округ Кушва, Верхняя Тура, Гробова, 1а	f	large
75462	88516	2101	Свердловская область, городской округ Кушва, поселок Баранчинский, Победы, 9	f	large
75461	88514	2100	Свердловская область, городской округ Кушва, поселок Баранчинский, Ленина, 1	f	large
75463	88518	2102	Свердловская область, городской округ Кушва, поселок Баранчинский, Коммуны, 18	f	large
121664	86225	469	Свердловская область, городской округ Красноуфимск, поселок Берёзовая Роща, Загородная, 4	f	small
122711	88438	2047	Свердловская область, городской округ Красноуральск, поселок Краснодольский, Матросова, клуб поселка Краснодольск	t	small
122713	88439	2048	Свердловская область, городской округ Красноуральск, поселок Дачный, Советская , клуб поселка Дачный	t	small
75515	88344	1991	Свердловская область, городской округ Краснотурьинск, поселок Рудничный, Пушкина, 22	f	large
122672	88342	1990	Свердловская область, городской округ Краснотурьинск, поселок Рудничный, Первомайская, 1	f	medium
122698	88412	2027	Свердловская область, городской округ Краснотурьинск, поселок Прибрежный, 3	t	\N
75579	88411	2026	Свердловская область, городской округ Краснотурьинск, Краснотурьинск, Краснотурьинская, 2	f	large
75059	88330	1983	Свердловская область, городской округ Кировград, поселок Нейво-Рудянка, Ржанникова, 10	f	large
75060	88333	1984	Свердловская область, городской округ Кировград, поселок Лёвиха, Малышева, 18	f	large
75062	88336	1986	Свердловская область, городской округ Кировград, поселок Карпушиха, Дарвина, 2Б	t	large
122497	87275	1221	Свердловская область, городской округ Кировград, Верхний Тагил, Чапаева, 60	f	medium
74281	87264	1216	Свердловская область, городской округ Кировград, Верхний Тагил, Чапаева, 54	f	large
74285	87272	1220	Свердловская область, городской округ Кировград, Верхний Тагил, Центральная, 3	f	large
74283	87268	1218	Свердловская область, городской округ Кировград, Верхний Тагил, Островского, 60	f	large
74284	87270	1219	Свердловская область, городской округ Кировград, Верхний Тагил, Ленина, 1	f	large
74282	87267	1217	Свердловская область, городской округ Кировград, Верхний Тагил, Ленина, 100	f	large
75789	88278	1953	Свердловская область, городской округ Качканар, поселок Валерьяновск, Кирова, 49	f	large
122652	88245	1937	Свердловская область, городской округ Карпинск, поселок Сосновка	f	medium
122654	88248	1938	Россия, Свердловская область, городской округ Карпинск, поселок Новая Княсьпа	t	small
122662	88271	1950	Свердловская область, городской округ Карпинск, поселок Кытлым	f	small
122659	88270	1949	Свердловская область, городской округ Карпинск, поселок Каквинские Печи	t	small
74391	87293	1231	Свердловская область, городской округ Карпинск, Волчанск, Мичурина, 9	f	large
122657	88268	1948	Свердловская область, городской округ Карпинск, поселок Веселовка	t	small
121604	86194	431	Свердловская область, городской округ Каменск-Уральский, поселок Черноусова, Кирова, 39а	t	small
121594	86184	426	Свердловская область, городской округ Каменск-Уральский, поселок Черемхово, Ленина, 43	t	small
121567	86148	407	Свердловская область, городской округ Каменск-Уральский, поселок Троицкое, Ленина, 32	t	small
121372	85001	267	Свердловская область, городской округ Каменск-Уральский, поселок Троицкое, Ленин, 194	f	\N
121584	86171	418	Свердловская область, городской округ Каменск-Уральский, поселок Травянское, Ворошилова, 9А	f	\N
74785	86150	408	Свердловская область, городской округ Каменск-Уральский, поселок Сосновское, Мира, 9а	f	large
121580	86166	416	Свердловская область, городской округ Каменск-Уральский, поселок Соколова, Ани Семянниковой, 5	t	small
74786	86163	414	Свердловская область, городской округ Каменск-Уральский, поселок Рыбниковское, Советская, 145	f	large
74773	86177	422	Свердловская область, городской округ Каменск-Уральский, поселок Позариха, Лесная, 14	f	large
121601	86189	429	Свердловская область, городской округ Каменск-Уральский, поселок Пирогово, Школьная, 20	t	small
75674	88064	1843	Свердловская область, городской округ Каменск-Уральский, поселок Первомайский, 27, общежитие ОАО КУЗОЦМ	f	large
122153	86787	866	Свердловская область, городской округ Каменск-Уральский, поселок Первомайский, Первомайская, 34Б	t	\N
121931	86493	670	Свердловская область, городской округ Каменск-Уральский, поселок Первомайский, Ленина, 40	f	medium
121559	86138	402	Свердловская область, городской округ Каменск-Уральский, поселок Первомайский, Кирова, 30	f	small
122626	88063	1842	Свердловская область, городской округ Каменск-Уральский, поселок Новый Завод, Кленовая, 1	f	medium
121596	86185	427	Свердловская область, городской округ Каменск-Уральский, поселок Новый Быт, Ленина, 6	t	medium
121587	86175	420	Свердловская область, городской округ Каменск-Уральский, поселок Новоисетское, Ленина, 24а	f	\N
122636	88202	1910	Свердловская область, городской округ Каменск-Уральский, поселок Монастырка, Комиссаров, 29, школа № 39	f	medium
74782	86132	399	Свердловская область, городской округ Каменск-Уральский, поселок Мартюш, Титова, 3	f	large
74781	86130	398	Свердловская область, городской округ Каменск-Уральский, поселок Мартюш, Ленина, 11	f	large
74784	86143	404	Свердловская область, городской округ Каменск-Уральский, поселок Маминское, Чапаева, 1В	f	large
121572	86154	410	Свердловская область, городской округ Каменск-Уральский, поселок Ленинский, Советская, 10б	t	small
121576	86159	412	Свердловская область, городской округ Каменск-Уральский, поселок Лебяжье, Советская, 10	t	small
121585	86173	419	Свердловская область, городской округ Каменск-Уральский, поселок Кремлёвка, помещение базы ОАО СинТЗ	t	small
74787	86165	415	Свердловская область, городской округ Каменск-Уральский, поселок Колчедан, Ленина, 38	f	large
121591	86180	423	Свердловская область, городской округ Каменск-Уральский, поселок Клевакинское, Уральская, 17	t	medium
121562	86140	403	Свердловская область, городской округ Каменск-Уральский, поселок Горный, Нагорная, 8а	t	small
121558	86134	400	Свердловская область, городской округ Каменск-Уральский, поселок Брод, Ворошилова, 2	f	medium
121582	86169	417	Свердловская область, городской округ Каменск-Уральский, поселок Большая Грязнуха, 8е Марта, 26а	f	small
121592	86182	424	Свердловская область, городской округ Каменск-Уральский, поселок Белоносова, Куйбышева, 64	t	small
121602	86191	430	Свердловская область, городской округ Каменск-Уральский, поселок Барабановское, Кирова, 32	f	small
75704	89315	2611	Свердловская область, городской округ Ирбит, Ирбит, Мальгина, 27	f	large
122616	88022	1815	Свердловская область, городской округ Ивдель, поселок Хорпия, Титова, 13	t	small
122622	88028	1819	Свердловская область, городской округ Ивдель, поселок Старая Сама, Горняков	t	small
122613	88020	1813	Свердловская область, городской округ Ивдель, поселок Северный, Ленина, 16	t	small
75658	89288	2588	Свердловская область, городской округ Ивдель, поселок Пелым, Фестивальная, 12	f	large
122625	88032	1821	Свердловская область, городской округ Ивдель, поселок Оус, Молодежная, 51	f	\N
122624	88031	1820	Свердловская область, городской округ Ивдель, поселок Маслово, Ленина, 24	t	small
122617	88024	1816	Свердловская область, городской округ Ивдель, поселок Екатерининка, Красноармейская, 1	t	medium
122620	88026	1818	Свердловская область, городской округ Ивдель, поселок Денежкино, Станционная, 20	t	small
122898	89289	2589	Свердловская область, городской округ Ивдель, поселок Атымья, Космонавтов, 5	f	\N
75388	87959	1772	Свердловская область, городской округ Екатеринбург, поселок Шабровский, Ленина, 24	f	large
75387	87959	1771	Свердловская область, городской округ Екатеринбург, поселок Шабровский, Ленина, 24	f	large
121903	86476	653	Свердловская область, городской округ Екатеринбург, поселок Северка, Горная, 3	t	small
75507	87949	1754	Свердловская область, городской округ Екатеринбург, поселок Рудный, Адмирала Ушакова, 24	f	large
122215	86851	921	Свердловская область, городской округ Екатеринбург, поселок Мостовка, Студенческая, 3	t	small
122500	87391	1309	Свердловская область, городской округ Екатеринбург, поселок Медный, Клуб по месту жительства Домовенок	t	small
75391	87960	1775	Свердловская область, городской округ Екатеринбург, поселок Горный Щит, Ленина, 12а	f	large
75390	87960	1774	Свердловская область, городской округ Екатеринбург, поселок Горный Щит, Ленина, 12а	f	large
75191	89172	2520	Свердловская область, городской округ Верхняя Пышма, Среднеуральск, Уральская, 14	f	large
75147	89169	2519	Свердловская область, городской округ Верхняя Пышма, Среднеуральск, Уральская, 18	f	large
75589	89181	2525	Свердловская область, городской округ Верхняя Пышма, Среднеуральск, Набережная, 8а	f	large
75145	89165	2517	Свердловская область, городской округ Верхняя Пышма, Среднеуральск, Набережная, 8 а	f	large
75192	89173	2521	Свердловская область, городской округ Верхняя Пышма, Среднеуральск, Лермонтова, 6	f	large
75146	89167	2518	Свердловская область, городской округ Верхняя Пышма, Среднеуральск, Ленина, 27 а	f	large
75587	89178	2523	Свердловская область, городской округ Верхняя Пышма, Среднеуральск, Бахтеева, 23	f	large
122490	87256	1208	Свердловская область, городской округ Верхняя Пышма, поселок Соколовка, Загородная, 12, Фельдшерский пункт	t	small
122484	87252	1205	Свердловская область, городской округ Верхняя Пышма, поселок Санаторный, Огородная, 13А, Фельдшерский пункт	f	small
122493	87258	1210	Свердловская область, городской округ Верхняя Пышма, поселок Мостовское, Садовая, 1, (Здание Администрации)	f	small
74278	87257	1209	Свердловская область, городской округ Верхняя Пышма, поселок Красный, Жданова, 23, Школа № 16	t	large
122479	87245	1199	Свердловская область, городской округ Верхняя Пышма, поселок Исеть, Станционная, 1, Управление щебзавода	f	medium
122480	87248	1201	Свердловская область, городской округ Верхняя Пышма, поселок Исеть, Мира, 18, Школа № 7	f	medium
74389	87251	1204	Свердловская область, городской округ Верхняя Пышма, поселок Балтым, Первомайская, 38, Школа № 9	f	large
122467	87199	1164	Свердловская область, городской округ Березовский, поселок Солнечный	t	small
121625	86206	445	Свердловская область, городской округ Березовский, поселок Октябрьский, Кабакова, 3	f	medium
74297	87194	1162	Свердловская область, городской округ Березовский, поселок Монетный, Пушкина, 21	f	large
122464	87197	1163	Свердловская область, городской округ Березовский, поселок Лубяной, Школьная	t	small
74298	87202	1166	Свердловская область, городской округ Березовский, поселок Лосиный	f	large
122469	87201	1165	Свердловская область, городской округ Березовский, поселок Безречный	t	small
75657	89285	2586	Свердловская область, городской округ Асбест, поселок Рефтинский	f	large
75655	89281	2584	Свердловская область, городской округ Асбест, поселок Рефтинский, Молодежная, 6	f	large
75653	89278	2582	Свердловская область, городской округ Асбест, поселок Рефтинский, Молодежная, 5	f	large
75656	89284	2585	Свердловская область, городской округ Асбест, поселок Рефтинский, Гагарина, 10	f	large
75652	89276	2581	Свердловская область, городской округ Асбест, поселок Рефтинский, Гагарина, 23	f	large
75650	89272	2578	Свердловская область, городской округ Асбест, поселок Малышева, Свободы, 13	f	large
75649	89270	2577	Свердловская область, городской округ Асбест, поселок Малышева, Свободы, 15 а	f	large
122897	89273	2579	Свердловская область, городской округ Асбест, поселок Малышева, Мопра, 18	f	\N
122453	87122	1109	Свердловская область, городской округ Асбест, поселок Красноармейский, общественноторговый центр	f	small
122441	87101	1097	Свердловская область, городской округ Алапаевск, поселок Нейво-Шайтанский, Уральских Рабочих, 3	f	medium
122442	87102	1098	Свердловская область, городской округ Алапаевск, поселок Нейво-Шайтанский, Спиридонова, 38	f	medium
122439	87099	1096	Свердловская область, городской округ Алапаевск, поселок Мелкозёрово, Школьная, 10	t	small
122435	87095	1094	Свердловская область, городской округ Алапаевск, поселок Западный, Мира, 5	f	medium
122436	87097	1095	Свердловская область, городской округ Алапаевск, поселок Асбестовский, Калинина, 11	t	medium
74960	87036	1053	Свердловская область, Шалинский район, поселок Шамары, Первомайская, 31	f	large
74961	87037	1054	Свердловская область, Шалинский район, поселок Шамары, Кирова, 52	f	large
122400	87034	1050	Свердловская область, Шалинский район, поселок Шаля, Энгельса, 54	f	medium
74958	87033	1049	Свердловская область, Шалинский район, поселок Шаля, Свердлова, 26	f	large
74957	87032	1048	Свердловская область, Шалинский район, поселок Шаля, Орджоникидзе, 5А	f	large
122418	87049	1067	Свердловская область, Шалинский район, поселок Чусовое (Шайтанка), Малышева, 2	f	medium
74963	87045	1063	Свердловская область, Шалинский район, поселок Сылва, Урицкого, 8	f	large
75664	89302	2602	Свердловская область, Шалинский район, поселок Староуткинск, Советская, 1	f	large
74962	87044	1061	Свердловская область, Шалинский район, поселок Сарга, Советская, 12	f	large
122409	87042	1059	Свердловская область, Шалинский район, поселок Роща (Большие Урмы), Первомайская, 24а	t	medium
122405	87040	1057	Свердловская область, Шалинский район, поселок Платоново, Советская, 1	t	medium
122419	87050	1068	Свердловская область, Шалинский район, поселок Мартьяново, Центральная, 31	t	small
122407	87041	1058	Свердловская область, Шалинский район, поселок Коптелы, Школьная, 12	t	small
122404	87039	1056	Свердловская область, Шалинский район, деревня Коптело-Шамары, Кропанцева, 28	f	small
74964	87047	1065	Свердловская область, Шалинский район, поселок Колпаковка, Школьная, 1а	f	large
122414	87046	1064	Свердловская область, Шалинский район, поселок Илим, Мира, 7	f	medium
122402	87038	1055	Свердловская область, Шалинский район, поселок Гора, 8 Марта, 11	f	medium
121062	82317	28	Свердловская область, Шалинский район, поселок Вогулка, Луговая, 3	t	small
122412	87043	1060	Свердловская область, Шалинский , поселок Сабик, Комсомольская, 6а	t	small
122415	87048	1066	Свердловская область, Шалинский, поселок Унь, Железнодорожная, 1	t	small
122391	87024	1043	Свердловская область, Туринский район, поселок Чукреевское, Победы, 5	f	small
122378	87011	1036	Свердловская область, Туринский район, поселок Чекуново, Садовая, 1Б	f	small
122380	87013	1037	Свердловская область, Туринский район, поселок Фабричное, Клубная, 1	f	medium
122389	87022	1042	Свердловская область, Туринский район, поселок Усениново, Пионерская, 37А	f	medium
74367	86995	1027	Свердловская область, Туринский район, Туринск, Спорта, 10	f	large
74365	86991	1025	Свердловская область, Туринский район, Туринск, Спорта, 16	f	large
74368	86996	1028	Свердловская область, Туринский район, Туринск, Путейцев, 12	f	large
74363	86987	1023	Свердловская область, Туринский район, Туринск, Косогорная, 7А	f	large
74366	86992	1026	Свердловская область, Туринский район, Туринск, Ивашева, 6	f	large
74369	86998	1029	Свердловская область, Туринский район, Туринск, Горького, 38	f	large
74362	86985	1022	Свердловская область, Туринский район, Туринск, Гагарина, 17	f	large
74364	86988	1024	Свердловская область, Туринский район, Туринск, 8 Марта, 80	f	large
122382	87015	1038	Свердловская область, Туринский район, поселок Смычка, Молодёжная, 7	f	small
122387	87020	1041	Свердловская область, Туринский район, поселок Назарово, Гагарина, 25	t	small
122373	87006	1033	Свердловская область, Туринский район, поселок Липовское, Петереноко, 23	f	medium
122385	87019	1040	Свердловская область, Туринский район, поселок Леонтьевское, Советская, 15	t	medium
122397	87030	1046	Свердловская область, Туринский район, поселок Ленское, Ленина, 9	f	medium
122371	87004	1032	Свердловская область, Туринский район, поселок Коркинское, Школьная, 4	f	medium
122369	87002	1031	Свердловская область, Туринский район, поселок Ерзовское, Кирова, 6	f	medium
122394	87026	1044	Свердловская область, Туринский район, поселок Дымковское, Ленина, 37	f	small
122376	87009	1034	Свердловская область, Туринский район, поселок Городище, Культуры, 1А	f	medium
122396	87028	1045	Свердловская область, Туринский район, поселок Благовещенское, Свердлова, 53Б	f	medium
122317	86925	991	Свердловская область, Тугулымский район, п. ж/д станции Тугулым, Победы, 12	f	medium
122346	86957	1007	Свердловская область, Тугулымский район, поселок Яр, Мира, 3	f	small
122335	86941	1000	Свердловская область, Тугулымский район, поселок Юшкова, переулок Школьный, 1	t	small
122353	86969	1013	Свердловская область, Тугулымский район, поселок Юшала	f	medium
122351	86965	1011	Свердловская область, Тугулымский район, поселок Юшала, Железнодорожная, 23	f	medium
74361	86966	1012	Свердловская область, Тугулымский район, поселок Юшала, Школьная, 5	f	large
122357	86973	1015	Свердловская область, Тугулымский район, поселок Щелконогова, Школьная, 1а	t	small
122320	86927	992	Свердловская область, Тугулымский район, поселок Филина, Молодежная, 13	t	small
122365	86980	1019	Свердловская область, Тугулымский район, поселок Тямкина, Новая, 9	t	\N
122316	86920	989	Свердловская область, Тугулымский район, поселок Тугулым, Школьная, 2	f	\N
74929	86923	990	Свердловская область, Тугулымский район, поселок Тугулым, Войкова, 2	f	large
122362	86977	1017	Свердловская область, Тугулымский район, поселок Трошково, Парковая, 7	f	medium
122349	86960	1009	Свердловская область, Тугулымский район, поселок Потаскуева, 8 Марта, 5	t	small
122329	86935	997	Свердловская область, Тугулымский район, поселок Полушина, Школьная, 2	t	small
122356	86971	1014	Свердловская область, Тугулымский район, поселок Ошкуково, Молодежная, 43	f	medium
122321	86929	993	Свердловская область, Тугулымский район, поселок Остров, Речная, 22	t	small
122340	86948	1003	Свердловская область, Тугулымский район, поселок Нижняя Коркина, Центральная, 21	t	small
122324	86905	994	Свердловская область, Тугулымский район, поселок Мальцево, Центральная, 2а	f	small
122341	86950	1004	Свердловская область, Тугулымский район, поселок Луговая, Центральная, 64а	f	small
122368	86983	1020	Свердловская область, Тугулымский район, поселок Колобова, Центральная, 16	t	small
122325	86931	995	Свердловская область, Тугулымский район, поселок Кармак, Привокзальная, 9	t	small
122337	86945	1002	Свердловская область, Тугулымский район, поселок Калачики, Клубная, 1	t	small
122360	86975	1016	Свердловская область, Тугулымский район, поселок Ивановка, Школьная, 10	t	small
122363	86979	1018	Свердловская область, Тугулымский район, поселок Зубково, Школьная, 59	f	small
74358	86943	1001	Свердловская область, Тугулымский район, поселок Заводоуспенское, Победы, 2	t	large
122270	86891	963	Свердловская область, Тугулымский район, поселок Журавлёва, Центральная, 2	t	small
74360	86963	1010	Свердловская область, Тугулымский район, поселок Ертарский, Кирова, 19	f	large
122344	86955	1006	Свердловская область, Тугулымский район, поселок Дёмино, Школьная, 33	f	small
122332	86938	998	Свердловская область, Тугулымский район, поселок Дубровина, Центральная, 12	t	small
122328	86934	996	Свердловская область, Тугулымский район, поселок Верховино, Филиппова, 6	f	\N
122347	86958	1008	Свердловская область, Тугулымский район, поселок Большой Рамыл, 8 марта, 15	t	small
74359	86952	1005	Свердловская область, Тугулымский р, поселок Луговской, Клубная, 25	f	large
122333	86939	999	Свердловская область, Тугулымский , деревня Ядрышникова, Юбилейная, 4	t	small
122294	86906	976	Свердловская область, Талицкий район, поселок Чупина, Совхозная, 8а	f	small
122229	86868	941	Свердловская область, Талицкий район, поселок Троицкий, Мичурина, 2А	f	\N
74941	86866	939	Свердловская область, Талицкий район, поселок Троицкий, Ленина, 22	f	large
74940	86865	938	Свердловская область, Талицкий район, поселок Троицкий, Ленина, 16	f	large
74939	86864	937	Свердловская область, Талицкий район, поселок Троицкий, Комарова, 21	f	large
74942	86867	940	Свердловская область, Талицкий район, поселок Троицкий, Железнодорожная, 30	f	large
122263	86886	959	Свердловская область, Талицкий район, поселок Трехозёрная, Мира, 1	f	medium
74938	86863	936	Свердловская область, Талицкий район, Талица, Советская, 65	f	large
74933	86855	929	Свердловская область, Талицкий район, Талица, Рябиновая, 8, школа №1	f	large
122292	86904	975	Свердловская область, Талицкий район, Талица, Нахимова, 8и, Административное здание И.П.Байлиева	f	\N
74937	86862	935	Свердловская область, Талицкий район, Талица, Луначарского, 57	f	large
122228	86861	933	Свердловская область, Талицкий район, Талица, Лермонтова, 2	f	\N
122225	86857	930	Свердловская область, Талицкий район, Талица, Ленина, 105	f	\N
74932	86854	928	Свердловская область, Талицкий район, Талица, Ленина, 71	f	large
122309	86914	984	Свердловская область, Талицкий район, Талица, Красноармейская, 55	f	\N
74935	86858	931	Свердловская область, Талицкий район, Талица, Красноармейская, 50	f	large
122250	86880	953	Свердловская область, Талицкий район, Талица, Калинина, 6	f	medium
122227	86859	932	Свердловская область, Талицкий район, Талица, Запышминская, 2а	f	medium
122312	86918	987	Свердловская область, Талицкий район, Талица, Заозерная, 76	f	small
74931	86853	927	Свердловская область, Талицкий район, город Талица, Урга, 2	f	large
74926	86902	973	Свердловская область, Талицкий район, поселок Пионерский, Советская, 5	f	large
122286	86900	971	Свердловская область, Талицкий район, поселок Первухина, Фестивальная, 16	t	small
122241	86875	948	Свердловская область, Талицкий район, поселок Пеньки, Советская, 17	t	small
122307	86912	982	Свердловская область, Талицкий район, поселок Панова, Береговая, 3	t	medium
122239	86874	947	Свердловская область, Талицкий район, поселок Нижний Катарач, Победы, 11	f	small
122277	86895	966	Свердловская область, Талицкий район, поселок Мохирёва, Советская, 2	f	small
122283	86898	969	Свердловская область, Талицкий район, поселок Мака, Центральная, 14	t	small
122301	86909	979	Московская область, Пушкинский район, деревня Луговая	f	small
122279	86896	967	Свердловская область, Талицкий район, поселок Кузнецовский, Ленина, 6	t	medium
122254	86882	955	Свердловская область, Талицкий район, поселок Красногорка, Центральная, 11	t	small
122284	86899	970	Свердловская область, Талицкий район, поселок Комсомольский, 70 лет Октября, 18	t	medium
122259	86884	957	Свердловская область, Талицкий район, поселок Казаковское, Набережная, 1	f	small
122249	86879	952	Свердловская область, Талицкий район, поселок Зарубина, Уральская, 18	t	small
122305	86911	981	Свердловская область, Талицкий район, поселок Завьяловское, Ленина, 335	f	medium
122257	86883	956	Свердловская область, Талицкий район, поселок Горскино, Новая, 1	t	small
122296	86907	977	Свердловская область, Талицкий район, поселок Горбуновское, Советская, 40	f	medium
74927	86917	986	Свердловская область, Талицкий район, поселок Вновь-Юрмытское, Победы, 12	t	large
122253	86881	954	Свердловская область, Талицкий район, поселок Вихляева, Центральная, 11	f	small
122247	86878	951	Свердловская область, Талицкий район, поселок Буткинское Озеро, переулок Центральный, 2	t	small
122234	86872	945	Свердловская область, Талицкий район, поселок Бутка, Строителей, 1	f	small
122232	86871	944	Свердловская область, Талицкий район, поселок Бутка, Совхозная, 16	f	small
74944	86869	942	Свердловская область, Талицкий район, поселок Бутка, Карла Маркса, 3	f	large
122236	86873	946	Свердловская область, Талицкий район, поселок Боровской, Школьная, 8	t	small
122291	86903	974	Свердловская область, Талицкий район, поселок Бор, Победы, 10	t	small
122275	86894	965	Свердловская область, Талицкий район, поселок Беляковское, Клубная, 10	f	small
122299	86908	978	Свердловская область, Талицкий район, поселок Белая Елань, Буденного, 85	f	medium
122261	86885	958	Свердловская область, Талицкий район, поселок Басмановское, Ленина, 42	t	medium
122281	86897	968	Свердловская область, Талицкий район, поселок Балаир, Жданова, 2	t	small
122314	86919	988	Свердловская область, Талицкий, Талица, Вокзальная, 53	f	small
122224	81451	925	Свердловская область, Тавдинский район, поселок Увал	t	small
122192	86826	897	Свердловская область, Тавдинский район, Тавда	f	medium
74914	86828	899	Свердловская область, Тавдинский район, Тавда, Шоссейная, 5	f	large
122187	86823	894	Свердловская область, Тавдинский район, Тавда, Чехова, 30	f	medium
122181	86821	891	Свердловская область, Тавдинский район, Тавда, Строителей, 5	t	medium
74922	86837	908	Свердловская область, Тавдинский район, Тавда, Свердлова, 83д	f	large
74916	86831	902	Свердловская область, Тавдинский район, Тавда, Рабочая, 44	f	large
74918	86833	904	Свердловская область, Тавдинский район, Тавда, Пушкина, 29	f	large
74913	86827	898	Свердловская область, Тавдинский район, Тавда, Омская, 1	f	large
122191	86825	896	Свердловская область, Тавдинский район, Тавда, Нахимова, 7	f	medium
122202	86843	913	Свердловская область, Тавдинский район, Тавда, Матросова, 19	f	medium
74930	86852	926	Свердловская область, Тавдинский район, Тавда, Ломоносова, 6	f	large
122189	86824	895	Свердловская область, Тавдинский район, Тавда, Лесопильщиков, 11	f	medium
74920	86835	906	Свердловская область, Тавдинский район, Тавда, Ленина, 71	f	large
74919	86834	905	Свердловская область, Тавдинский район, Тавда, Ленина, 91а	f	large
74917	86832	903	Свердловская область, Тавдинский район, Тавда, Ленина, 53	f	large
122195	86829	900	Свердловская область, Тавдинский район, Тавда, Куйбышева, 7а	f	medium
74921	86836	907	Свердловская область, Тавдинский район, Тавда, Кирова, 126	f	large
122185	86822	893	Свердловская область, Тавдинский район, Тавда, Кардонская, 45	f	medium
122183	86822	892	Свердловская область, Тавдинский район, Тавда, Кардонская, 45	f	medium
122200	86842	912	Свердловская область, Тавдинский район, Тавда, К. Маркса, 13	f	\N
122198	86840	911	Свердловская область, Тавдинский район, Тавда, К. Маркса, 42а	f	medium
74923	86839	910	Свердловская область, Тавдинский район, Тавда, К. Маркса, 18	f	large
74915	86830	901	Свердловская область, Тавдинский район, Тавда, 9е Января, 13	f	large
122214	86850	920	Московская область, Истринский район, поселок городского типа Снегири, деревня Ленино	t	small
122212	86849	919	Свердловская область, Тавдинский район, поселок Крутое, Центральная, 27	f	small
122222	81431	924	Свердловская область, Тавдинский район, поселок Кошуки	t	small
122208	86847	917	Свердловская область, Тавдинский район, поселок Карьер	f	small
122210	86848	918	Свердловская область, Тавдинский район, поселок Карабашка	f	medium
122206	86846	916	Брянская область, Суземский район, поселок Земляное	t	small
122217	86804	922	Тамбовская область, Тамбовский район, поселок Герасимовка	t	small
122204	86845	915	Свердловская область, Тавдинский район, поселок Большая Пустынь, Советская, 18	t	small
74925	86844	914	Свердловская область, Тавдинский район, поселок Азанка	f	large
122196	86838	909	Свердловская область, Тавдинский , Тавда, Герцена, 9	t	small
122166	86802	880	Свердловская область, Таборинский район, поселок Унже-Павинская, Центральная, 23	t	small
122179	86819	889	Свердловская область, Таборинский район, поселок Торомка, Лесная, 16	t	small
74912	86810	883	Свердловская область, Таборинский район, поселок Таборы, Октябрьская, 65	f	large
121067	82498	31	Свердловская область, Таборинский район, поселок Таборы, Молодежная, 171	t	\N
122165	86801	879	Свердловская область, Таборинский район, поселок Таборы, Красноармейская, 5, Ф/х """"Шпуровых"""" """	f	\N
122173	86813	886	Свердловская область, Таборинский район, поселок Пальмино, Центральная , 38	t	small
122169	86806	881	Свердловская область, Таборинский район, поселок Озерки, Центральная, 27	t	small
122175	86816	887	Свердловская область, Таборинский район, поселок Оверино, Советская, 13	f	small
122171	86812	884	Свердловская область, Таборинский район, поселок Кузнецово, Южная, 19	f	medium
122176	86817	888	Свердловская область, Таборинский район, поселок Добрино, Центральная , 15	f	small
75040	86795	873	Свердловская область, Сысертский район, поселок Щелкун, Ленина, 178	f	large
122159	86794	872	Свердловская область, Сысертский район, поселок Черданцево, Ленина, 58	f	medium
122132	86750	837	Свердловская область, Сысертский район, Сысерть, Энгельса, 153	f	medium
134684	95004	867	Свердловская область, Сысертский район, поселок Патруши, Колхозная, 1	f	\N
74955	86790	868	Свердловская область, Сысертский район, село Патруши, Колхозная, 23	f	large
122150	86785	864	Свердловская область, Сысертский район, поселок Новоипатово, Мира, 3	f	small
122146	86783	862	Свердловская область, Сысертский район, поселок Никольское, 1Мая, 76Б	f	medium
122144	86782	861	Свердловская область, Сысертский район, поселок Колос, 104	t	small
122143	86676	860	Свердловская область, Сысертский район, поселок Ключи, Ленина, 40	t	small
74952	86781	859	Московская область, Истринский район, деревня Кашино	f	large
74951	86780	858	Свердловская область, Сысертский район, поселок Двуреченск, Озерная, 13	f	large
74950	86779	857	Свердловская область, Сысертский район, поселок Двуреченск, Клубная, 12	f	large
74949	86778	856	Свердловская область, Сысертский район, поселок Верхняя Сысерть, Ленина, 22	f	large
122149	86784	863	Свердловская область, Сысертский район, поселок Верхняя Боёвка, Ленина, 2	f	small
122154	86791	869	Свердловская область, Сысертский район, поселок Бородулино, Садовая, 2	f	medium
74948	86777	855	Свердловская область, Сысертский район, поселок Большой Исток, Трудова, 48	f	large
122140	86775	853	Свердловская область, Сысертский район, поселок Большой Исток, Степана Разина, 11А	t	medium
134685	95005	876	Свердловская область, Сысертский район, поселок Большой Исток, Советская, 38	t	\N
74947	86776	854	Свердловская область, Сысертский район, поселок Большой Исток, Ленина, 119	t	large
122157	86793	871	Свердловская область, Сысертский район, поселок Большое Седельниково, Лесная, 318	t	medium
74956	86792	870	Свердловская область, Сысертский район, поселок Большое Седельниково, 1 Мая, 3	f	large
74946	86773	851	Свердловская область, Сысертский район, поселок Бобровский, переулок Советский, 9	f	large
74945	86772	850	Свердловская область, Сысертский район, поселок Бобровский, Калинина, 1А	t	large
122137	86771	849	Свердловская область, Сысертский район, поселок Асбест, Пролетарская, 5	f	small
122451	87054	1108	Свердловская область, Сысертский район, поселок Арамиль, Станционная, 1Е	t	medium
122446	87118	1106	Свердловская область, Сысертский район, поселок Арамиль, Свердлова, 8Б	t	medium
122445	87116	1105	Свердловская область, Сысертский район, Арамиль, Садовая, 10	f	medium
74356	87114	1104	Свердловская область, Сысертский район, Арамиль, Рабочая, 120А	f	large
74355	87111	1103	Свердловская область, Сысертский район, Арамиль, Красноармейская, 118	f	large
74353	87107	1101	Свердловская область, Сысертский район, Арамиль, Космонавтов, 9/4	f	large
74354	87109	1102	Свердловская область, Сысертский район, Арамиль, 1 Мая, 60	f	large
74352	87105	1100	Свердловская область, Сысертский район, Арамиль, 1 Мая, 12	f	large
122163	86797	875	Свердловская область, Сысертский район, поселок Аверинское, Советская, 96	f	small
122161	86796	874	Свердловская область, Сысертский район, поселок Абрамовское, Ленина, 50а	t	small
122875	89222	2545	Свердловская область, Сухоложский район, поселок Шата, Ленина, 10	t	small
122885	89241	2554	Свердловская область, Сухоложский район, поселок Филатовское, Ленина, 70А	f	medium
75602	89213	2541	Свердловская область, Сухоложский район, Сухой Лог	f	large
75598	89204	2536	Свердловская область, Сухоложский район, Сухой Лог, Юбилейная, 2	f	large
122865	89201	2535	Свердловская область, Сухоложский район, Сухой Лог, Юбилейная, 5	f	medium
122867	89211	2540	Свердловская область, Сухоложский район, Сухой Лог, Кунарская, 2	f	small
75593	89189	2529	Свердловская область, Сухоложский район, Сухой Лог, Горького, 11	f	large
75592	89187	2528	Свердловская область, Сухоложский район, Сухой Лог, Артиллеристов, 36 б	f	large
122889	89245	2556	Свердловская область, Сухоложский район, Сухой Лог, 8 Марта, 43	f	small
75597	89199	2534	Свердловская область, Сухоложский район, Сухой Лог, Юбилейная, 8а	f	large
122863	89198	2533	Свердловская область, Сухоложский район, Сухой Лог, Юбилейная, 23а	f	medium
75595	89193	2531	Свердловская область, Сухоложский район, Сухой Лог, Юбилейная, 10	f	large
75601	89209	2539	Свердловская область, Сухоложский район, Сухой Лог, Победы, 4	f	large
75599	89205	2537	Свердловская область, Сухоложский район, Сухой Лог, Кирова, 7б	f	large
75590	89184	2526	Свердловская область, Сухоложский район, Сухой Лог, Гоголя, 12	f	large
122882	89239	2553	Свердловская область, Сухоложский район, Сухой Лог, Ворошилова, 18А	t	small
75594	89191	2530	Свердловская область, Сухоложский район, Сухой Лог, Белинского, 41	f	large
75591	89185	2527	Свердловская область, Сухоложский район, Сухой Лог, 93 Стрелковой бригады, 7	f	large
122878	89229	2548	Свердловская область, Сухоложский район, поселок Светлое, Ленина, 17	f	small
122873	89220	2544	Свердловская область, Сухоложский район, поселок Рудянское, Калинина, 13	f	medium
75085	89237	2552	Свердловская область, Сухоложский район, поселок Новопышминское, Ильича, 6	f	large
75083	89230	2549	Свердловская область, Сухоложский район, поселок Курьи, Школьная, 3	f	large
75084	89235	2551	Свердловская область, Сухоложский район, поселок Курьи, Свердлова, 20	f	large
122881	89233	2550	Свердловская область, Сухоложский район, поселок Курьи, Батенева, 46	f	medium
75646	89225	2546	Свердловская область, Сухоложский район, поселок Знаменское, Горького, 19	f	large
122886	89243	2555	Свердловская область, Сухоложский район, поселок Заимка, Щепеткина, 1	f	small
122877	89226	2547	Свердловская область, Сухоложский район, поселок ГляденыСанаторий, Помещение Винокурского участкового лесничества	f	small
122871	89217	2543	Свердловская область, Сухоложский район, поселок Алтынай, Вокзальная, 54	f	small
122868	89215	2542	Свердловская область, Сухоложский район, поселок Алтынай, 1 Мая, 40	f	medium
122062	86662	794	Свердловская область, Сосьвинский район, поселок Восточный, Парковый переулок, 1	t	small
74989	86654	790	Свердловская область, Сосьвинский городской округ, Поселок Сосьва, Толмачева, 34	f	large
122858	86654	2515	Свердловская область, Сосьвинский городской округ, Поселок Сосьва, Толмачева, 34	f	small
122130	86748	836	Свердловская область, Слободо-Туринский район, поселок Юрты, Школасад	f	small
121322	85843	207	Свердловская область, Слободо-Туринский район, поселок Шадринка, Лаптева, 9	f	small
122126	86741	832	Свердловская область, Слободо-Туринский район, поселок Храмцово, Новая, 2а	f	small
122096	86709	817	Свердловская область, Слободо-Туринский район, поселок Усть-Ницинское, Школьная, 8	t	medium
75029	86744	834	Свердловская область, Слободо-Туринский район, поселок Туринская Слобода, Советская, 96	f	large
75028	86742	833	Свердловская область, Слободо-Туринский район, поселок Туринская Слобода, Ленина, 3	f	large
122101	86713	819	Свердловская область, Слободо-Туринский район, поселок Тимофеево, Ленина, 1	f	small
122121	86734	829	Свердловская область, Слободо-Туринский район, поселок Сладковское, Ленина проспект, 13	f	medium
122092	86703	815	Свердловская область, Слободо-Туринский район, поселок Решетникова (Симахина), Школьная, 29	t	small
122117	86729	827	Свердловская область, Слободо-Туринский район, поселок Пушкарёво, 45 лет Победы, 54	f	small
122112	86726	825	Свердловская область, Слободо-Туринский район, поселок Ницинское, Озерная, 27	f	medium
122122	86737	830	Свердловская область, Слободо-Туринский район, поселок Макуй, Центральный, 1	t	small
122095	86705	816	Свердловская область, Слободо-Туринский район, поселок Липчинское, Ленина, 14	t	medium
122119	86733	828	Свердловская область, Слободо-Туринский район, поселок Куминовское, Советская, 5	f	small
122102	86715	820	Свердловская область, Слободо-Туринский район, поселок Красный Яр, Школа, 14	f	small
122108	86722	823	Свердловская область, Слободо-Туринский район, поселок Краснослободское, Октябрьская, 40	f	medium
122115	86727	826	Свердловская область, Слободо-Туринский район, поселок Звезда, Новая, 1	t	\N
122099	86711	818	Свердловская область, Слободо-Туринский район, поселок Жирякова, 31, школа-сад	f	small
122105	86716	821	Свердловская область, Слободо-Туринский район, поселок Ермакова, дом Культуры	t	small
122106	86720	822	Свердловская область, Слободо-Туринский район, поселок Голякова, 35, Дом Культуры	t	small
122110	86723	824	Свердловская область, Слободо-Туринский район, поселок Бобровское, Бобровская, 1	t	small
122125	86738	831	Свердловская область, Слободо-Туринский район, поселок Андронова, Центральная, 39	f	\N
122128	86747	835	Свердловская область, Слободо-Туринский, поселок Туринская Слобода, Дегтева, 1	f	medium
122856	89161	2514	Свердловская область, Серовский район, поселок Черноярский, Заводская, 1а	t	small
74991	86659	792	Свердловская область, Серовский район, поселок Сосьва, Свободы, 75	t	large
74992	86661	793	Свердловская область, Серовский район, поселок Сосьва, Ленина,, 100	t	large
74988	86653	789	Свердловская область, Серовский район, поселок Сосьва, Ленина, 2а	f	large
74990	86657	791	Свердловская область, Серовский район, поселок Сосьва, Балдина, 49	t	large
122084	86695	810	Свердловская область, Серовский район, поселок Семёнова, Зеленая, 41	t	small
122076	86688	806	Свердловская область, Серовский район, поселок Романово, Центральная, 43	t	small
122083	86694	809	Свердловская область, Серовский район, поселок Поспелкова, Школьная, 10	t	small
122070	86682	803	Свердловская область, Серовский район, поселок Первомайский, Советская, 20	t	small
122078	86690	807	Свердловская область, Серовский район, поселок Пасынок, Теплоухова, 1	t	small
122081	86692	808	Свердловская область, Серовский район, поселок Морозково, Советская, 9	f	small
122086	86698	811	Свердловская область, Серовский район, поселок Маслова, Новая, 5	f	small
74995	86672	799	Свердловская область, Серовский район, поселок Ларьковка, Вокзальная , 41	t	large
122069	86674	800	Свердловская область, Серовский район, поселок Красный Яр, Октябрьская, 35	t	small
74996	86677	801	Свердловская область, Серовский район, поселок Красноярка, Ленина, 14	t	large
74997	86680	802	Свердловская область, Серовский район, поселок Красноглинный, Садовая, 15	t	large
122074	86685	805	Свердловская область, Серовский район, поселок Кошай, Ворошилова, 50	t	medium
122091	86701	813	Свердловская область, Серовский район, поселок Ключевой (Замарайка), Колхозная, 19а	t	small
122089	86700	812	Свердловская область, Серовский район, поселок Еловка Новая, Набережная, 9	t	small
121607	86195	434	Свердловская область, Серовский район, поселок Восточный	t	\N
122065	86664	795	Свердловская область, Серовский район, поселок Восточный, пер. Парковый, 2	t	medium
74993	86666	796	Свердловская область, Серовский район, поселок Восточный, Пушкина, 1	t	large
74994	86669	797	Свердловская область, Серовский район, поселок Восточный, Ленина, 11	t	large
122072	86684	804	Свердловская область, Серовский район, поселок Боровой, Центральная, 14	t	small
122067	86670	798	Свердловская область, Серовский, поселок Марсяты, Зеленая, 15	t	small
74987	86647	784	Свердловская область, Режевский район, поселок Черемисское, Дом культуры	f	large
122051	86645	782	Свердловская область, Режевский район, поселок Фирсово, Клуб	t	small
122041	86640	777	Свердловская область, Режевский район, поселок Сохарёво, Клуб	f	small
121578	86160	413	Свердловская область, Режевский район, поселок Соколово, Садовая, 1	t	small
122059	86650	787	Свердловская область, Режевский район, Реж	f	small
74759	86624	764	Свердловская область, Режевский район, Реж	f	large
122027	86628	768	Свердловская область, Режевский район, Реж, Строителей, 13	f	\N
75010	86615	757	Свердловская область, Режевский район, Реж, Спортивная, 8	f	large
75007	86612	754	Свердловская область, Режевский район, Реж, Пушкина, 2а	f	large
75014	86620	761	Свердловская область, Режевский район, Реж, Пионерская, 13	f	large
74985	86630	769	Свердловская область, Режевский район, Реж, П.Морозова, 56	f	large
74982	86626	766	Свердловская область, Режевский район, Реж, О.Кошевого, 9	f	large
75015	86621	762	Свердловская область, Режевский район, Реж, Металлургов, 8	f	large
75011	86616	758	Свердловская область, Режевский район, Реж, Ленина, 2	f	large
75008	86613	755	Свердловская область, Режевский район, Реж, Ленина, 30	f	large
74983	86627	767	Свердловская область, Режевский район, Реж, Калинина, 19б	f	large
74760	86625	765	Свердловская область, Режевский район, Реж, Калинина, 47	f	large
75013	86619	760	Свердловская область, Режевский район, Реж, Зеленая, 90	f	large
75016	86623	763	Свердловская область, Режевский район, Реж, Заводская, 3	f	large
122060	86651	788	Свердловская область, Режевский район, поселок Першино, Клуб	t	small
122037	86638	775	Свердловская область, Режевский район, поселок Ощепково, Клуб	f	small
122052	86646	783	Свердловская область, Режевский район, поселок Останино, Мира, 86, Школа №8	f	medium
121036	85627	15	Свердловская область, Режевский район, поселок Останино, Ленина, 14	t	\N
122057	86649	786	Свердловская область, Режевский район, поселок Октябрьское, Дом культуры	t	small
122048	86644	781	Свердловская область, Режевский район, поселок Липовское, Школа №9	f	medium
122042	86641	778	Свердловская область, Режевский район, поселок Ленёвское, Дом культуры	f	medium
122030	86633	771	Свердловская область, Режевский район, поселок Костоусово, Советская, 3, Дом культуры	f	\N
122054	86648	785	Свердловская область, Режевский район, поселок Колташи, Клуб	t	small
122044	86642	779	Свердловская область, Режевский район, поселок Клевакинское, Школа № 30	f	medium
122047	86643	780	Свердловская область, Режевский район, поселок Каменка, Клуб	t	small
121881	86458	637	Свердловская область, Режевский район, поселок Каменка, УралЛобва	t	small
122035	86635	773	Свердловская область, Режевский район, поселок Голендухино, Школа № 23	f	small
74986	86637	774	Свердловская область, Режевский район, поселок Глинское, Дом культуры	f	large
122038	86639	776	Свердловская область, Режевский район, поселок Арамашка, Школа №27	f	medium
122032	86634	772	Свердловская область, Реж, поселок Озерный, Школа № 46	t	medium
121975	86548	705	Свердловская область, Пышминский район, поселок Юрмытское, Кирова, 52	f	small
121984	86556	710	Свердловская область, Пышминский район, поселок Чупино, Павлика Морозова, 2а	f	\N
74745	86570	717	Свердловская область, Пышминский район, поселок Четкарино, Советская, 26	t	large
121987	86560	712	Свердловская область, Пышминский район, поселок Чернышово, Ленина, 2	f	medium
121992	86563	714	Свердловская область, Пышминский район, поселок Черемыш, Ленина, 56	f	medium
121972	86544	703	Свердловская область, Пышминский район, поселок Холкина, Карла Маркса, 15а	f	small
121995	86568	716	Свердловская область, Пышминский район, поселок Тупицыно, Ленина, 16	t	small
121977	86550	706	Свердловская область, Пышминский район, поселок Трифоново, Ленина, 93	f	\N
121990	86562	713	Свердловская область, Пышминский район, поселок Тимохинское, Халтурина, 2	f	\N
121969	86542	702	Свердловская область, Пышминский район, поселок Талица, Калинина, 38	f	small
122007	86582	723	Свердловская область, Пышминский район, поселок Речелга, Школьный переулок, 3	t	small
74742	86536	699	Свердловская область, Пышминский район, поселок Пышма, Куйбышева, 42	f	large
74741	86534	698	Свердловская область, Пышминский район, поселок Пышма, Куйбышева, 46	f	large
74740	86532	697	Свердловская область, Пышминский район, поселок Пышма, Куйбышева, 39	f	large
74743	86537	700	Свердловская область, Пышминский район, поселок Пышма, Комарова, 19	f	large
74744	86540	701	Свердловская область, Пышминский район, поселок Пышма, Бабкина, 3А	f	large
121986	86557	711	Свердловская область, Пышминский район, поселок Пылаева, 50 лет Октября, 33	f	small
121981	86554	709	Свердловская область, Пышминский район, поселок Пульниково, Школьная, 6	t	small
121974	86546	704	Свердловская область, Пышминский район, поселок Печёркино, Буденного, 5	f	medium
121999	86574	719	Свердловская область, Пышминский район, поселок Первомайский, Ленина, 10	t	medium
122006	86579	722	Свердловская область, Пышминский район, поселок Мартынова, Молодежная, 1а	t	small
121998	86572	718	Свердловская область, Пышминский район, поселок Комарова, Школьный переулок, 2	t	small
121980	86551	708	Свердловская область, Пышминский район, поселок Катарач	t	\N
121746	86283	532	Свердловская область, Невьянский район, с. Шурала, Советов, 48	f	small
122243	86876	949	Свердловская область, Пышминский район, поселок Катарач, Центральная, 43	t	small
121994	86566	715	Свердловская область, Пышминский район, поселок Духовая, Механизаторов, 261	t	small
122004	86577	721	Свердловская область, Пышминский район, поселок Боровлянское, Ленина, 27	t	medium
121967	86523	692	Свердловская область, Пригородный район, поселок Южаково	f	\N
121924	86489	665	Свердловская область, Пригородный район, поселок Шумиха, Гаражная, 7	t	small
121942	86501	677	Свердловская область, Пригородный район, поселок Шиловка, Ленина, 34	t	small
121673	86231	475	Свердловская область, Пригородный район, поселок Шиловка, 1 Мая, 1	t	small
75020	86479	656	Свердловская область, Пригородный район, поселок Черноисточинск, Юбилейная, 7А	f	large
121906	86478	655	Свердловская область, Пригородный район, поселок Черноисточинск, Кирова, 2А	f	medium
121965	86522	691	Свердловская область, Пригородный район, поселок Усть-Утка, Советская, 2	t	small
75019	86477	654	Свердловская область, Пригородный район, поселок Уралец, Ленина, 10	f	large
121925	86490	667	Свердловская область, Пригородный район, поселок Сулём, Гагарина, 52	t	small
122772	88757	2237	Свердловская область, Пригородный район, поселок Студёный, Мичурина,, 7б	t	small
121902	86475	652	Свердловская область, Пригородный район, поселок Синегорский, Мира, 6	t	medium
121117	85644	60	Свердловская область, Пригородный район, поселок Покровское, Юбилейная, 1	f	medium
75026	86514	685	Свердловская область, Пригородный район, поселок Покровское, Школьная, 11А	f	large
121952	86512	683	Свердловская область, Пригородный район, поселок Петрокаменское, Почтовая, 1А	f	\N
121950	86510	682	Свердловская область, Пригородный район, поселок Новопаньшино, Советская	f	\N
121968	86525	693	Свердловская область, Пригородный район, поселок Новоасбест, Пионерская, 8	f	\N
121915	86485	661	Свердловская область, Пригородный район, поселок Новая Башкарка, Уральская, 5	f	small
75023	86500	676	Свердловская область, Пригородный район, поселок Николо-Павловское, Юбилейная, 11А	f	large
121940	86499	675	Свердловская область, Пригородный район, поселок Николо-Павловское, Совхозная, 4	f	\N
121939	86497	674	Свердловская область, Пригородный район, поселок Мурзинка, Декабристов, 5	f	small
121913	86484	660	Свердловская область, Пригородный район, поселок Мокроусское, Ленина, 3А	t	small
122288	86901	972	Свердловская область, Пригородный район, поселок Маркова, Мира, 46	t	small
121936	86496	673	Свердловская область, Пригородный район, поселок Малая Лая, Ленина, 60	f	small
121946	86506	680	Свердловская область, Пригородный район, поселок Ленёвка, Центральная, 201	t	small
121899	86474	651	Свердловская область, Пригородный район, поселок Лая, Привокзальная, 3а	t	\N
121933	86494	671	Свердловская область, Пригородный район, поселок Лая, Ленина, 1а	f	\N
121930	86492	669	Свердловская область, Пригородный район, поселок Краснополье, Красногвардейская, 32	f	small
121928	86491	668	Свердловская область, Пригородный район, поселок Кайгородское, Ленина, 103А	f	small
121959	86518	688	Свердловская область, Пригородный район, поселок Зональный, Центральная, 8	f	small
121949	86508	681	Свердловская область, Пригородный район, поселок Горноуральский	t	small
121897	86471	649	Свердловская область, Пригородный район, поселок Горноуральский, 49, Территориальная администрация	f	\N
121963	86521	690	Свердловская область, Пригородный район, поселок Горноуральский, Уральская, 35	t	\N
121898	86472	650	Свердловская область, Пригородный район, поселок Горноуральский, 49, Теририториальная администрация р.п. Горноуральский	f	\N
121896	86440	648	Свердловская область, Пригородный район, поселок Висимо-Уткинск, Ленина, 1	f	medium
121961	86519	689	Свердловская область, Пригородный район, поселок Висим, Мамина-Сибиряка, 4	f	\N
121917	86486	662	Свердловская область, Пригородный район, поселок Бызово, Ленина, 4А	t	small
121920	86487	663	Свердловская область, Пригородный район, поселок Бродово, Новая, 23	f	\N
121953	86513	684	Свердловская область, Пригородный район, поселок Беляковка, Совхозная, 7	t	small
121911	86482	659	Свердловская область, Пригородный район, поселок Башкарка, Школьная, 2	f	\N
121910	86481	658	Свердловская область, Пригородный район, поселок Балакино, Ленина, 17	t	small
74899	85648	64	Свердловская область, Артемовский район, Артёмовский, Мира, 17	f	large
121944	86503	678	Свердловская область, Пригородный район, поселок Анатольская, Привокзальная, 13	t	\N
121955	86515	686	Свердловская область, Пригородный , поселок Покровское, Птицеводов, 24	f	medium
122838	89043	2443	Свердловская область, Полевской, поселок Станционный-Полевской, Гагарина, 3	f	medium
75217	88960	2392	Свердловская область, Первоуральск, поселок Кузино, Демьяна Бедного, 16	t	large
121880	86456	636	Свердловская область, Новолялинский район, поселок Юрты, Административное здание ЦЛЗУ ООО """"""""Новолялинский ЦБК	t	small
121886	86463	639	Свердловская область, Новолялинский район, поселок Шайтанка, Здание школы	t	small
121884	86461	638	Свердловская область, Новолялинский район, поселок Старая Ляля, Здание школы	t	small
121890	86467	641	Свердловская область, Новолялинский район, поселок Салтаново, Здание детского сада Незабудка	f	small
121887	86465	640	Свердловская область, Новолялинский район, поселок Савинова, Здание Дома культуры	f	small
121877	86455	635	Свердловская область, Новолялинский район, поселок Павда, Здание клуба	f	small
74716	86431	624	Свердловская область, Новолялинский район, Новая Ляля, Энгельса, 22	f	large
74715	86429	623	Свердловская область, Новолялинский район, Новая Ляля, Челюскинцев, 1	f	large
121868	86437	627	Свердловская область, Новолялинский район, Новая Ляля, Островского, 1	f	medium
74772	86427	622	Свердловская область, Новолялинский район, Новая Ляля, Лермонтова, 22	f	large
74771	86426	621	Свердловская область, Новолялинский район, Новая Ляля, Клубный переулок, 1	f	large
74717	86436	626	Свердловская область, Новолялинский район, Новая Ляля, Кирова, 2	f	large
74718	86439	628	Свердловская область, Новолялинский район, Новая Ляля, Гайдара, 75	f	large
121866	86434	625	Свердловская область, Новолялинский район, Новая Ляля, Гагарина, 12	f	medium
121892	86468	642	Свердловская область, Новолялинский район, поселок Лопаево, Здание школы	f	small
121876	86453	634	Свердловская область, Новолялинский район, поселок Лобва, Чкалова, 1	f	medium
121873	86451	633	Свердловская область, Новолялинский район, поселок Лобва, Чехова, 11	f	medium
121869	86443	629	Свердловская область, Новолялинский район, поселок Лобва, Советская, 40	f	medium
74719	86447	631	Свердловская область, Новолялинский район, поселок Лобва, Партсъезда, 2	f	large
121872	86444	630	Свердловская область, Новолялинский район, поселок Лобва, Островского, 6	f	medium
74720	86448	632	Свердловская область, Новолялинский район, поселок Лобва, Кузнецова, 9	f	large
75332	88532	2109	Свердловская область, Нижняя Тура, Лесной, Карла Маркса, 15	f	large
121847	86414	611	Свердловская область, Нижнетуринский городской округ, поселок Ис, Молодежная, 1	f	medium
122916	89330	2630	Свердловская область, Нижнетуринский, Нижняя Тура, Пирогова , 6, СОШ №3	f	\N
121829	86392	593	Свердловская область, Нижнесергинский район, поселок Шарама, Набережная, 19	t	\N
121825	86388	591	Свердловская область, Нижнесергинский район, поселок Уфа-Шигири, Рассветная, 15	f	small
121822	86385	590	Свердловская область, Нижнесергинский район, поселок Урмикеево, Совхозная, 4	f	medium
121837	86399	597	Свердловская область, Нижнесергинский район, поселок Тюльгаш, Черемушки, 8 а	f	small
121808	86370	583	Свердловская область, Нижнесергинский район, поселок Талица, Клубный, 2	t	\N
121813	86374	585	Свердловская область, Нижнесергинский район, поселок Старобухарово, Советская, 36 а	f	small
121816	86379	587	Свердловская область, Нижнесергинский район, поселок Сосновый Бор (Новоселы)	t	small
121830	86393	594	Свердловская область, Нижнесергинский район, Село Шокурово, Ленина, 93	f	medium
121844	86407	601	Свердловская область, Нижнесергинский район, поселок Рябиновка, Лесная, 15	t	small
121834	86398	596	Свердловская область, Нижнесергинский район, поселок Перепряжка, Мубаракшина, 59	f	small
121791	86352	574	Свердловская область, Нижнесергинский район, поселок Первомайское, Ленина, 52	f	small
121807	86369	582	Свердловская область, Нижнесергинский район, поселок Отевка, Мира, 24	f	small
121841	86404	599	Свердловская область, Нижнесергинский район, Нижние Серги, 3, школа	t	medium
121782	86318	557	Свердловская область, Нижнесергинский район, Нижние Серги, Санаторий "Курорт Нижние Серги", административный корпус	f	medium
74897	85646	62	Свердловская область, Артемовский район, Артёмовский, Мира, 14	f	large
121778	86312	555	Свердловская область, Нижнесергинский район, Нижние Серги, городок Солнечный, 3	f	medium
74701	86311	554	Свердловская область, Нижнесергинский район, Нижние Серги, Титова, 39	f	large
74702	86320	558	Свердловская область, Нижнесергинский район, Нижние Серги, Стахановцев, 10	f	large
121774	86302	550	Свердловская область, Нижнесергинский район, Нижние Серги, Пролетарская, 13	f	medium
121781	86316	556	Свердловская область, Нижнесергинский район, Нижние Серги, Мякутина, 19	f	medium
74699	86306	552	Свердловская область, Нижнесергинский район, Нижние Серги, Ленина, 30	f	large
121777	86304	551	Свердловская область, Нижнесергинский район, Нижние Серги, Ленина, 2	f	medium
121814	86377	586	Свердловская область, Нижнесергинский район, поселок Накоряково, Победы, 17	f	small
121789	86334	565	Свердловская область, Нижнесергинский район, поселок Михайловский Завод, Чкалова, 19	f	small
121839	86401	598	Свердловская область, Нижнесергинский район, Михайловск, Уральская, 21	t	medium
74706	86331	563	Свердловская область, Нижнесергинский район, Михайловск, Кирова, 57	f	large
74705	86328	562	Свердловская область, Нижнесергинский район, Михайловск, Кирова, 43 А	f	large
74704	86327	561	Свердловская область, Нижнесергинский район, Михайловск, Кирова, 26	f	large
74703	86323	560	Свердловская область, Нижнесергинский район, Михайловск, Кирова, 25	f	large
121785	86321	559	Свердловская область, Нижнесергинский район, Михайловск, Демьяна Бедного, 10	f	medium
121842	86405	600	Свердловская область, Нижнесергинский район, Михайловск, Грязнова,, 61	f	small
121798	86361	578	Свердловская область, Нижнесергинский район, поселок Малиновый, Дом культуры	t	small
121792	86354	575	Свердловская область, Нижнесергинский район, поселок Лазоревый, Химмашевская, 4	f	small
121832	86396	595	Свердловская область, Нижнесергинский район, поселок Красноармеец, Ленина, 7 а	f	medium
121811	86372	584	Свердловская область, Нижнесергинский район, поселок Контуганово, переулок Клубный, 2	f	small
121796	86359	577	Свердловская область, Нижнесергинский район, поселок Ключевая, Первомайская, 73/2	f	\N
121794	86356	576	Свердловская область, Нижнесергинский район, поселок Ключевая, Первомайская, 70	f	\N
121801	86363	579	Свердловская область, Нижнесергинский район, поселок Кленовское, Красных Партизан, 2а	f	medium
121803	86365	580	Свердловская область, Нижнесергинский район, поселок Кленовское, Азина, 4,2	f	small
121805	86366	581	Свердловская область, Нижнесергинский район, поселок Киселёвка, Центральная, 49	t	small
122893	89255	2564	Свердловская область, Нижнесергинский район, поселок Киргишаны, Трактовая, 95	f	\N
74713	86349	572	Свердловская область, Нижнесергинский район, поселок Дружинино, Калинина, 7а	f	large
74714	86351	573	Свердловская область, Нижнесергинский район, поселок Дружинино, Азина, 13	f	large
74710	86343	569	Свердловская область, Нижнесергинский район, поселок Верхние Серги, Пришкольная, 1	f	large
74709	86341	568	Свердловская область, Нижнесергинский район, поселок Верхние Серги, Ленина, 68	f	large
74707	86337	566	Свердловская область, Нижнесергинский район, поселок Верхние Серги, Володарского, 8 А	f	large
121819	86382	588	Свердловская область, Нижнесергинский район, поселок Васькино, Школьная, 13	f	small
75089	89254	2563	Свердловская область, Нижнесергинский район, поселок Бисерть, Чапаева, 7	f	large
122892	89252	2562	Свердловская область, Нижнесергинский район, поселок Бисерть, Революции, 110а	f	\N
75086	89249	2560	Свердловская область, Нижнесергинский район, поселок Бисерть, Октябрьская, 10	f	large
122891	89247	2559	Свердловская область, Нижнесергинский район, поселок Бисерть, Ленина, 23	f	medium
75087	89250	2561	Свердловская область, Нижнесергинский район, поселок Бисерть, Дзержинского, 2а	f	large
74712	86347	571	Свердловская область, Нижнесергинский район, поселок Атиг, Заводская, 8	f	large
74711	86345	570	Свердловская область, Нижнесергинский район, поселок Атиг, Гагарина, 19	f	large
121821	86383	589	Свердловская область, Нижнесергинский район, поселок Аракаево, Азина, 1	f	small
121826	86389	592	Свердловская область, Нижнесергинский район, поселок Акбаш, Мысф Джаиля, 87	f	medium
74708	86339	567	Свердловская область, Нижнесергинский , Верхние Серги, Володарского, 2	f	large
121760	82029	541	Свердловская область, Невьянский район, поселок Шайдуриха, Ленина, 84	f	\N
74728	86279	527	Свердловская область, Невьянский район, поселок Цементный, Ленина, 33	f	large
74729	86279	528	Свердловская область, Невьянский район, поселок Цементный, Ленина, 33	f	large
121766	86293	544	Свердловская область, Невьянский район, поселок Федьковка, Ленина, 54	t	small
75815	88856	2329	Свердловская область, Невьянский район, поселок Тарасково, Ленина, 30	f	large
121744	86282	531	Свердловская область, Невьянский район, поселок Таватуй, Центральная, 1	t	small
121770	86295	546	Свердловская область, Невьянский район, поселок Таватуй, Лесная, 10а	t	small
121769	86294	545	Свердловская область, Невьянский район, поселок Середовина, Промышленная, 13	t	small
121764	86292	543	Свердловская область, Невьянский район, поселок Ребристый, Ленина, 8	t	medium
75816	88858	2331	Свердловская область, Невьянский район, поселок Починок, Ленина, 15	t	large
122793	88857	2330	Свердловская область, Невьянский район, поселок Пальники, Восточная, 2А	t	\N
121754	86288	537	Свердловская область, Невьянский район, поселок Осиновка, КМаркса, 92	t	small
75808	88851	2321	Свердловская область, Невьянский район, Новоуральск, Чкалова, 11	f	large
75778	88843	2306	Свердловская область, Невьянский район, Новоуральск, Фрунзе, 7	f	large
75809	88852	2322	Свердловская область, Невьянский район, Новоуральск, Свердлова, 13	t	large
75707	89319	2614	Свердловская область, Невьянский район, Новоуральск, Микрорайон 15, 2	f	large
75810	88853	2323	Свердловская область, Невьянский район, Новоуральск, Ленина, 99	t	large
75811	88853	2324	Свердловская область, Невьянский район, Новоуральск, Ленина, 99	t	large
75805	88849	2318	Свердловская область, Невьянский район, Новоуральск, Юбилейная, 7	f	large
75804	88849	2317	Свердловская область, Невьянский район, Новоуральск, Юбилейная, 7	f	large
75806	88848	2319	Свердловская область, Невьянский район, Новоуральск, Юбилейная, 7А	f	large
75803	88848	2316	Свердловская область, Невьянский район, Новоуральск, Юбилейная, 7А	f	large
75766	88834	2293	Свердловская область, Невьянский район, Новоуральск, Чурина, 16	f	large
75769	88836	2296	Свердловская область, Невьянский район, Новоуральск, Театральный проезд, 20	f	large
75768	88836	2295	Свердловская область, Невьянский район, Новоуральск, Театральный проезд, 20	f	large
75800	88846	2313	Свердловская область, Невьянский район, Новоуральск, Советская, 19А	f	large
75784	88846	2312	Свердловская область, Невьянский район, Новоуральск, Советская, 19А	f	large
75807	88850	2320	Свердловская область, Невьянский район, Новоуральск, Свердлова, 1А	f	large
75802	88847	2315	Свердловская область, Невьянский район, Новоуральск, С.Дудина, 7	f	large
75801	88847	2314	Свердловская область, Невьянский район, Новоуральск, С.Дудина, 7	f	large
75779	88844	2307	Свердловская область, Невьянский район, Новоуральск, Победы, 18	f	large
75780	88844	2308	Свердловская область, Невьянский район, Новоуральск, Победы, 18	f	large
75772	88838	2299	Свердловская область, Невьянский район, Новоуральск, Первомайская, 11	t	large
75771	88838	2298	Свердловская область, Невьянский район, Новоуральск, Первомайская, 11	t	large
75767	88835	2294	Свердловская область, Невьянский район, Новоуральск, Мичурина, 5	f	large
75774	88839	2301	Свердловская область, Невьянский район, Новоуральск, Ленина, 38А	f	large
75773	88656	2300	Свердловская область, Невьянский район, Новоуральск, Ленина, 34	f	large
75775	88841	2303	Свердловская область, Невьянский район, город Новоуральск, Крупской, 2	f	large
75818	88854	2333	Свердловская область, Невьянский район, город Новоуральск, Корнилова, 7/1	f	large
75814	88854	2327	Свердловская область, Невьянский район, город Новоуральск, Корнилова, 7/1	f	large
75813	88854	2326	Свердловская область, Невьянский район, город Новоуральск, Корнилова, 7/1	f	large
75812	88854	2325	Свердловская область, Невьянский район, город Новоуральск, Корнилова, 7/1	f	large
75110	88832	2291	Свердловская область, Невьянский район, Новоуральск, Комсомольская, 14	f	large
75781	88832	2309	Свердловская область, Невьянский район, Новоуральск, Комсомольская, 14	f	large
122792	88855	2328	Свердловская область, Невьянский район, Новоуральск, Загородное шоссе, 12	t	small
75783	88845	2311	Свердловская область, Невьянский район, Новоуральск, Автозаводская, 25	f	large
75782	88845	2310	Свердловская область, Невьянский район, Новоуральск, Автозаводская, 25	f	large
121749	86285	534	Свердловская область, Невьянский район, поселок Нижние Таволги, Макаренко, 3Б	t	small
121763	86291	542	Свердловская область, Невьянский район, поселок Кунара, Победы, 14а	t	small
121753	86287	536	Свердловская область, Невьянский район, поселок Конёво, Горького, 1а	t	medium
121756	86289	538	Свердловская область, Невьянский район, поселок Киприно, Трактористов, 5	t	small
74730	86280	529	Свердловская область, Невьянский район, поселок Калиново, Советская, 4	f	large
121772	86296	547	Свердловская область, Невьянский район, поселок Забельный, Уральская, 3	t	small
121751	86286	535	Свердловская область, Невьянский район, поселок Верхние Таволги, Мира, 44	t	small
75133	89263	2573	Свердловская область, Невьянский район, поселок Верх-Нейвинский, Площадь Революции, 1	f	large
75132	89263	2572	Свердловская область, Невьянский район, поселок Верх-Нейвинский, Площадь Революции, 1	f	large
121741	86278	525	Свердловская область, Невьянский район, поселок Вересковый, 5	f	small
74731	86284	533	Свердловская область, Невьянский район, поселок Быньги, Мартьянова, 42	f	large
121742	86281	530	Свердловская область, Невьянский район, поселок Аять, Ленина, 8	t	medium
121759	86290	540	Свердловская область, Невьянский район, поселок Аятское, Калинина, 18	t	medium
75817	88859	2332	Свердловская область, Невьянский , город Новоуральск, Корнилова, 9В	f	large
74793	86249	492	Свердловская область, Красноуфимский район, село Юва, Октября, 1б	f	large
121672	86230	474	Свердловская область, Красноуфимский район, поселок Чувашково, Школьная, 2	f	small
121688	86240	483	Свердловская область, Красноуфимский район, поселок Чигвинцево, Набережная, 16б 1	t	small
121653	86220	464	Свердловская область, Красноуфимский район, поселок Чатлык, Ленина, 43	f	medium
121720	86259	502	Свердловская область, Красноуфимский район, поселок Усть-Бугалыш, Лесная, 40А	t	small
121677	86233	477	Свердловская область, Красноуфимский район, поселок Усть-Баяк, Октября, 2	f	small
121724	86261	504	Свердловская область, Красноуфимский район, поселок Татарская Еманзельга, Советская, 78	f	small
121702	86250	493	Свердловская область, Красноуфимский район, поселок Сызги, Центральная, 18	f	small
121705	86252	495	Свердловская область, Красноуфимский район, поселок Средний Бугалыш, Советская, 21	f	small
121707	86253	496	Свердловская область, Красноуфимский район, поселок Средний Бугалыш, Ленина, 5	f	medium
121684	86237	480	Свердловская область, Красноуфимский район, поселок Средний Баяк, Новая, 18	f	small
121722	86260	503	Свердловская область, Красноуфимский район, поселок Сарсы-Вторые, Ленина, 76	f	medium
121729	86265	508	Свердловская область, Красноуфимский район, поселок Саргая, Труда, 7а	t	small
121697	86246	489	Свердловская область, Красноуфимский район, поселок Сарана, Советская, 35	f	medium
74734	86245	488	Свердловская область, Красноуфимский район, поселок Сарана, Горького, 1	f	large
121713	86256	499	Свердловская область, Красноуфимский район, поселок Русский Усть-Маш, Школьная, 9	f	small
121680	86234	478	Свердловская область, Красноуфимский район, поселок Рахмангулово, Ленина, 62а	f	small
74732	86228	472	Свердловская область, Красноуфимский район, поселок Приданниково, Первомайская, 1а	f	large
121668	86227	471	Свердловская область, Красноуфимский район, поселок Подгорная, Виктора Прокудина, 50	t	small
121704	86251	494	Свердловская область, Красноуфимский район, поселок Озерки, Сосновая, 1а	f	small
121718	86258	501	Свердловская область, Красноуфимский район, поселок Новый Бугалыш, Садовая, 8	f	small
121648	86217	461	Свердловская область, Красноуфимский район, поселок Новое Село, Уральская, 2	f	small
121645	86216	460	Свердловская область, Красноуфимский район, поселок Нижнеиргинское, Октябрьская, 10	f	medium
74735	86248	491	Свердловская область, Красноуфимский район, поселок Натальинск, Советская, 4	f	large
121699	86247	490	Свердловская область, Красноуфимский район, поселок Натальинск, Ленина, 31	f	\N
121716	86257	500	Свердловская область, Красноуфимский район, поселок Марийский Усть-Маш, Заречная, 16	t	small
121696	86244	487	Свердловская область, Красноуфимский район, поселок Марийские Ключики, Советская, 17	f	small
45517	49362	166	Курганская область, Шадринск, Спартака, 18	f	large
121676	86232	476	Свердловская область, Красноуфимский район, поселок Крылово, Гагарина, 2	f	medium
121733	86267	510	Свердловская область, Красноуфимский район, поселок Криулино, Советская , 57	f	\N
74733	86239	482	Свердловская область, Красноуфимский район, поселок Криулино, Советская, 26	f	large
121655	86221	465	Свердловская область, Красноуфимский район, поселок Красный Турыш, Молодёжная, 2	t	small
121644	86215	459	Свердловская область, Красноуфимский район, поселок Красносоколье, Центральная, 6	t	small
121691	86242	485	Свердловская область, Красноуфимский район, поселок Красная Поляна, Центральная, 5А	t	small
121662	86224	468	Свердловская область, Красноуфимский район, поселок Ключики, Студенческая, 22	f	medium
121694	86243	486	Свердловская область, Красноуфимский район, поселок Калиновка, Заречная, 24а	f	small
121690	86241	484	Свердловская область, Красноуфимский район, поселок Зауфа, Новая, 1а	t	small
121732	86266	509	Свердловская область, Красноуфимский район, поселок Дегтярка, Трактовая, 22	t	small
121712	86255	498	Свердловская область, Красноуфимский район, поселок Голенищево, Заречная, 20	t	small
121660	86223	467	Свердловская область, Красноуфимский район, поселок Верхняя Ирга, Кунгурская , 1	t	small
121710	86254	497	Свердловская область, Красноуфимский район, поселок Верхний Бугалыш, Советская, 27	t	small
121686	86238	481	Свердловская область, Красноуфимский район, поселок Верхний Баяк, Нагорная, 9	t	small
121670	86229	473	Свердловская область, Красноуфимский район, поселок Верх-Никитино, Центральная, 29а	t	small
121651	86219	463	Свердловская область, Красноуфимский район, поселок Верх-Бобровка, Свободы, 2	t	small
121658	86222	466	Свердловская область, Красноуфимский район, поселок Большой Турыш, Совхозная, 1	f	medium
121649	86218	462	Свердловская область, Красноуфимский район, поселок Большое Кошаево, Октября, 17	t	small
121726	86262	505	Свердловская область, Красноуфимский район, поселок Большая Тавра, Советская, 6а	f	small
121681	86236	479	Свердловская область, Красноуфимский район, поселок Бишково, Ленина, 22	t	small
121666	86226	470	Свердловская область, Красноуфимский район, поселок Александровское, Александровская, 4	f	small
74794	86263	506	Свердловская область, Красноуфимский, поселок Русская Тавра, Мира, 10	f	large
121728	86264	507	Свердловская область, Красноуфимский, поселок Приданниково, Первомайская, 1а, ОМЦ Маяк	f	\N
122670	88341	1989	Свердловская область, Краснотурьинск, поселок Рудничный, Клубная, 8	f	medium
75756	88190	1904	Свердловская область, Красногорский район, Каменск-Уральский, Трудовые резервы, 8а, ДК Металлург	f	large
122633	88200	1909	Свердловская область, Красногорский район, Каменск-Уральский, Железнодородная станция УАЗ, помещение ж/д станции УАЗ	f	small
75759	88197	1907	Свердловская область, Красногорский район, Каменск-Уральский, 2я Рабочая, 53, школа № 14	f	large
75793	88283	1957	Свердловская область, Качканарский городской округ, Качканар, 4-й микрорайон, 64	f	large
121623	86205	444	Свердловская область, Камышловский район, поселок Шипицына, Кондратьева, 23	f	\N
121616	86202	441	Свердловская область, Камышловский район, поселок Чикунова, Нагорная, 12 А	t	medium
121612	86199	438	Свердловская область, Камышловский район, поселок Фадюшина, Народная, 40	t	medium
121610	86197	436	Свердловская область, Камышловский район, поселок Раздольное, Школьная, 16	t	small
121614	86200	439	Свердловская область, Камышловский район, поселок Ожгиха, Советская, 3	t	medium
121630	86210	449	Свердловская область, Камышловский район, поселок Обуховское, Санаторий, Клуб	f	small
74776	86208	447	Свердловская область, Камышловский район, поселок Обуховское, Школьная, 1 Б	f	large
121609	86196	435	Свердловская область, Камышловский район, поселок Никольское, пер.Школьный, 7	f	small
121638	81152	454	Свердловская область, Камышловский район, поселок Куровское, Новая, 2	t	medium
121619	86203	442	Свердловская область, Камышловский район, поселок Куваева, Титова, 7	t	small
121093	85636	44	Свердловская область, Камышловский район, поселок Кокшарова, Молодежная, 6	f	small
121636	86214	453	Свердловская область, Камышловский район, поселок Квашнинское, Ленина, 49	f	medium
121626	86207	446	Свердловская область, Камышловский район, поселок Калиновское, Советская, 25	f	\N
121620	86204	443	Свердловская область, Камышловский район, поселок Захаровское, Бачурина, 2 А	f	medium
74777	86211	450	Свердловская область, Камышловский район, поселок Галкинское, Мира, 91	f	large
74775	86201	440	Свердловская область, Камышловский район, поселок Восход, Комсомольская, 10 А	t	large
121633	86212	451	Свердловская область, Камышловский район, поселок Большое Пульниково, Красных Партизан, 29	f	small
74774	86198	437	Свердловская область, Камышловский район, поселок Баранникова, Ленина, 3	f	large
121564	86144	405	Свердловская область, Каменский район, поселок Шилова, Ленина, 30	t	small
121598	86187	428	Свердловская область, Каменский район, поселок Сипавское, Советская, 11б	f	medium
121552	86122	394	Свердловская область, Ирбитский район, поселок Якшина, Ленина, 51	f	small
121553	86125	395	Свердловская область, Ирбитский район, поселок Шмаковское, Кирова, 30	t	small
74850	86049	358	Свердловская область, Ирбитский район, поселок Чёрновское, Советская, 55	f	large
121484	86053	359	Свердловская область, Ирбитский район, поселок Чубаровское, Октябрьская, 12в	t	\N
121538	86109	387	Свердловская область, Ирбитский район, поселок Чернорицкое, Пролетарская, 51	f	small
121505	86077	371	Свердловская область, Ирбитский район, поселок Чащина, Школьная, 8	t	small
121494	86063	364	Свердловская область, Ирбитский район, поселок Харловское (Харлово), Советская, 10	f	medium
121502	86072	369	Свердловская область, Ирбитский район, поселок Фомина, Советская, 72А	f	medium
121550	86121	393	Свердловская область, Ирбитский район, поселок Стриганское, Октябрьская, 75	t	medium
122906	89312	2609	Свердловская область, Ирбитский район, поселок Спутник, Гагарина, 3	f	small
121510	86081	373	Свердловская область, Ирбитский район, поселок Симанова (Татарщина), Береговая, 5	t	\N
121479	86045	356	Свердловская область, Ирбитский район, поселок Рябиновый, Центральная, 10	t	small
121461	86028	347	Свердловская область, Ирбитский район, поселок Рудное, Центральная, 30А	f	small
121507	86078	372	Свердловская область, Ирбитский район, поселок Речкалова, Центральная, 24	f	medium
121526	86097	381	Свердловская область, Ирбитский район, поселок Ретнева, Дорожная, 8	f	small
121532	86103	384	Свердловская область, Ирбитский район, поселок Пьянково, Юбилейная, 29д	f	\N
121495	86064	365	Свердловская область, Ирбитский район, поселок Прядеина, Прядеинская, 27	t	small
74852	86128	397	Свердловская область, Ирбитский район, поселок Пионерский, Ожиганова, 10	f	large
74851	86068	367	Свердловская область, Ирбитский район, поселок Пионерский, Мира, 31Б	f	large
121546	86117	391	Свердловская область, Ирбитский район, поселок Першина, улица Школьная, 1	t	small
121528	86098	382	Свердловская область, Ирбитский район, поселок Осинцевское, Молодежная, 13	f	small
122483	87250	1203	Свердловская область, Ирбитский район, поселок Ольховка, Торфянников, 2, Школа №2	t	small
121498	86066	366	Свердловская область, Ирбитский район, поселок Новгородова, Школьная, 1	f	medium
121463	86030	348	Свердловская область, Ирбитский район, поселок Ницинское, Центральная, 60	f	medium
121486	86055	360	Свердловская область, Ирбитский район, поселок Никитина, Комсомольская, 47А	f	small
122900	89307	2606	Свердловская область, Ирбитский район, поселок Нижняя, Набережная, 12	f	\N
121499	86070	368	Свердловская область, Ирбитский район, поселок Мельникова, Новая, 16	f	small
121555	86126	396	Свердловская область, Ирбитский район, поселок Лопатково, переулок Школьный, 2	t	\N
121544	86114	390	Свердловская область, Ирбитский район, поселок Лаптева, Центральная, 2	t	small
121468	86033	350	Свердловская область, Ирбитский район, поселок Курьинский, Площадная, 10	f	\N
121542	86112	389	Свердловская область, Ирбитский район, поселок Крутихинское, Советская, 12	t	small
121465	86031	349	Свердловская область, Ирбитский район, поселок Ключи, Урицкого, 2	f	medium
121504	86074	370	Свердловская область, Ирбитский район, поселок Кириллова, Центральная, 60	f	small
121482	86048	357	Свердловская область, Ирбитский район, поселок Кирга, Новая, 4	f	medium
121533	86104	385	Свердловская область, Ирбитский район, поселок Килачёвское, Ленина, 36	f	medium
75204	88041	1829	Свердловская область, Ирбитский район, Ирбит, Пролетарская, 61	f	large
121487	86056	361	Свердловская область, Ирбитский район, поселок Знаменское, переулок Знаменский, 13	f	medium
121515	86087	376	Свердловская область, Ирбитский район, поселок Зайково, Школьная, 10	f	small
121514	86084	375	Свердловская область, Ирбитский район, поселок Зайково, Студенческая, 1	f	medium
121518	86089	377	Свердловская область, Ирбитский район, поселок Зайково, Мира, 3	f	medium
121512	86082	374	Свердловская область, Ирбитский район, поселок Зайково, Коммунистическая, 181	f	medium
121520	86091	378	Свердловская область, Ирбитский район, поселок Зайково, Александра Матросова, 24	f	small
121474	86039	353	Свердловская область, Ирбитский район, поселок Дубская, Центральная, 22	f	medium
121475	86042	354	Свердловская область, Ирбитский район, поселок Гуни, Советская, 10	t	small
121540	86111	388	Свердловская область, Ирбитский район, поселок Горки, Советская, 16	f	medium
121478	86044	355	Свердловская область, Ирбитский район, поселок Гаёва, Чайкина, 26	f	medium
121469	86035	351	Свердловская область, Ирбитский район, поселок Волково, переулок Береговой, 2	t	small
121489	86059	362	Свердловская область, Ирбитский район, поселок Большой Камыш (Галищева), переулок Галишевский, 2	t	small
121530	86100	383	Свердловская область, Ирбитский район, поселок Большая Кочёвка, Кирова, 19А	f	small
121492	86061	363	Свердловская область, Ирбитский район, поселок Болшая Зверева, Советская, 22	t	\N
121472	86037	352	Свердловская область, Ирбитский район, поселок Бердюгина, Советская, 18	f	medium
121536	86106	386	Свердловская область, Ирбитский район, поселок Белослудское	t	small
121547	86119	392	Свердловская область, Ирбитский район, поселок Анохинское, Центральная, 21А	t	small
122904	89310	2608	Свердловская область, Ирбитский , деревня Удинцева, Садовая, 2	t	small
121523	86095	380	Свердловская область, Ирбитский, поселок Скородумское, Жукова, 76	t	small
122525	87487	1376	Свердловская область, Екатеринбург, поселок Палкино, переулок Школьный, 3	t	small
121441	86007	336	Свердловская область, Гаринский район, поселок Нихвор, Молодежная, 29	t	\N
121452	86018	341	Свердловская область, Гаринский район, поселок Зыкова, Центральная, 10	t	\N
74792	86002	333	Свердловская область, Гаринский район, поселок Гари, Комсосмольская, 52	f	large
121438	86003	334	Свердловская область, Гаринский район, поселок Гари, Колхозная, 38	f	small
121444	86010	337	Свердловская область, Гаринский район, поселок Андрюшино, Трудовая, 6	t	\N
121420	85983	324	Свердловская область, Верхотурский район, поселок Усть-Салда, Центральная, 10	f	small
121099	85639	47	Свердловская область, Верхотурский район, поселок Таёжный, Школьная, 1	t	\N
121429	85993	329	Свердловская область, Верхотурский район, поселок Прокопьевская Салда, Сенянского, 40	t	small
74791	85978	321	Свердловская область, Верхотурский район, поселок Привокзальный, Чапаева, 35	f	large
74790	85959	319	Свердловская область, Верхотурский район, поселок Привокзальный, Советская, 6	f	large
121414	85976	320	Свердловская область, Верхотурский район, поселок Привокзальный, Садовая, 10	f	medium
121411	85974	318	Свердловская область, Верхотурский район, поселок Привокзальный, Крайняя, 6	f	small
121422	85985	325	Свердловская область, Верхотурский район, поселок Меркушино, Центральная, 10	f	small
121417	85981	323	Свердловская область, Верхотурский район, поселок Красногорское, Ленина, 8	f	small
121432	85995	330	Свердловская область, Верхотурский район, поселок Косолманка, Клубная, 28	t	small
121424	85987	326	Свердловская область, Верхотурский район, поселок Кордюково, Центральная, 36	f	medium
121427	85992	328	Свердловская область, Верхотурский район, поселок Карпунинский, Первое мая, 2	t	small
121434	85998	331	Свердловская область, Верхотурский район, поселок Карелино, Клубная, 14	t	small
121425	85990	327	Свердловская область, Верхотурский район, поселок Дерябино, Молодежная, 7	f	small
121405	85964	313	Свердловская область, Верхотурский район, Верхотурье, Совхозная, 12	f	\N
74788	85967	315	Свердловская область, Верхотурский район, Верхотурье, Мелиораторов, 31	f	large
74789	85970	316	Свердловская область, Верхотурский район, Верхотурье, Куйбышева, 2	f	large
121415	85980	322	Свердловская область, Верхотурский район, Верхотурье, Ершова, 15	f	medium
121435	86000	332	Свердловская область, Верхотурский район, Верхотурье, 70 лет Октября, 4	f	small
121409	85971	317	Свердловская область, Верхотурский район, Верхотурье, 20 лет Победы, 82	f	\N
122486	87253	1206	Свердловская область, Верхняя Пышма, поселок Половинный, Мира, 3	t	small
74388	87249	1202	Свердловская область, Верхняя Пышма, поселок Кедровое, Школьников, 4, Школа № 24	t	large
121400	85958	308	Свердловская область, Верхнесалдинский район, поселок Северная, 8 Марта, 2	f	small
75662	89297	2594	Свердловская область, Верхнесалдинский район, поселок Свободный, Свободы, 19	f	large
75661	89295	2593	Свердловская область, Верхнесалдинский район, поселок Свободный, Кузнецова, 71	f	large
75660	89294	2592	Свердловская область, Верхнесалдинский район, поселок Свободный, Карбышева, 70	f	large
75659	89292	2591	Свердловская область, Верхнесалдинский район, поселок Свободный, Карбышева, 9	f	large
121397	85954	306	Свердловская область, Верхнесалдинский район, поселок Песчаный Карьер, Центральная, 14	t	\N
121398	85955	307	Свердловская область, Верхнесалдинский район, поселок Никитино, Центральная, 12	f	small
121402	85961	309	Свердловская область, Верхнесалдинский район, поселок Нелоба, Центральная, 29	t	small
121404	85962	310	Свердловская область, Верхнесалдинский район, поселок Малыгино, Клуб	t	small
121856	86419	616	Свердловская область, Верхнесалдинский район, поселок Выя, Привокзальная, 12А	t	small
74820	85939	299	Свердловская область, Верхнесалдинский район, Верхняя Салда, Энгельса, 87	f	large
74819	85934	298	Свердловская область, Верхнесалдинский район, Верхняя Салда, Энгельса, 87к.2	f	large
74817	85934	296	Свердловская область, Верхнесалдинский район, Верхняя Салда, Энгельса, 87к.2	f	large
74815	85931	294	Свердловская область, Верхнесалдинский район, Верхняя Салда, Энгельса, 47	f	large
74814	85928	293	Свердловская область, Верхнесалдинский район, Верхняя Салда, Энгельса, 40	f	large
74865	85914	286	Свердловская область, Верхнесалдинский район, Верхняя Салда, Энгельса, 32	f	large
74864	85914	285	Свердловская область, Верхнесалдинский район, Верхняя Салда, Энгельса, 32	f	large
121393	85925	291	Свердловская область, Верхнесалдинский район, Верхняя Салда, Фрунзе, 23	f	medium
121384	85905	280	Свердловская область, Верхнесалдинский район, Верхняя Салда, Труда, 1	t	small
74824	85947	303	Свердловская область, Верхнесалдинский район, Верхняя Салда, Спортивная, 17	f	large
74823	85946	302	Свердловская область, Верхнесалдинский район, Верхняя Салда, Спортивная, 10	f	large
74816	85932	295	Свердловская область, Верхнесалдинский район, Верхняя Салда, Сабурова, 11	f	large
74863	85913	284	Свердловская область, Верхнесалдинский район, Верхняя Салда, Рабочей молодежи, 1	f	large
121391	85911	283	Свердловская область, Верхнесалдинский район, Верхняя Салда, Народная стройка, 1А	f	medium
74811	85921	289	Свердловская область, Верхнесалдинский район, Верхняя Салда, Ленина, 12	f	large
74810	85919	288	Свердловская область, Верхнесалдинский район, Верхняя Салда, Ленина, 16	f	large
121386	85907	281	Свердловская область, Верхнесалдинский район, Верхняя Салда, Ленина, 64	f	medium
74822	85944	301	Свердловская область, Верхнесалдинский район, Верхняя Салда, Воронова, 13, 1	f	large
74821	85941	300	Свердловская область, Верхнесалдинский район, Верхняя Салда, Воронова, 12, 1	f	large
74818	85936	297	Свердловская область, Верхнесалдинский район, Верхняя Салда, Воронова, 11	f	large
74866	85917	287	Свердловская область, Верхнесалдинский район, Верхняя Салда, Парковая, 1	f	large
74825	85950	304	Свердловская область, Верхнесалдинский район, поселок Басьяновский, Ленина, 10	t	large
121394	85951	305	Свердловская область, Верхнесалдинский, поселок Ежевичный, Клуб	t	small
121378	85901	272	Свердловская область, Богдановичский район, поселок Чернокоровское, Комсомольская, 47	f	medium
121366	85892	262	Свердловская область, Богдановичский район, поселок Тыгиш, Ленина, 47	f	\N
121368	85893	263	Свердловская область, Богдановичский район, поселок Кунарское, Ленина, 25	f	\N
74856	85891	261	Свердловская область, Богдановичский район, поселок Коменки, 30 Лет Победы, 14	f	large
121371	84839	266	Свердловская область, Богдановичский район, поселок Каменноозёрское, Ленина, 5	f	\N
121381	85902	273	Свердловская область, Богдановичский район, поселок Ильинское, Ленина, 22Б	f	medium
74858	85894	264	Свердловская область, Богдановичский район, поселок Грязновское, Ленина, 46Б	f	large
45510	49355	159	Курганская область, Шадринск, Спартака, 17	f	large
121377	85900	271	Свердловская область, Богдановичский район, поселок Гарашкинское, Ильича, 15А	f	medium
121374	85899	270	Калужская область, Тарусский район, поселок Волковское	f	\N
121373	85896	268	Свердловская область, Богдановичский район, поселок Байны, Степана Щипачева, 41	f	\N
74862	85897	269	Свердловская область, Богдановичский, поселок Полдневой, Вокзальная, 5	f	large
74300	87209	1169	Свердловская область, Березовский, пос.Кедровка, в/ч	f	large
121341	85857	224	Свердловская область, Белоярский район, п.Прохладный, Свердлова, 21В	f	\N
121360	85869	239	Свердловская область, Белоярский район, поселок Черноусово, Центральная, 5 А	t	medium
121355	84508	234	Свердловская область, Белоярский район, поселок Чернобровкина, Ленина, 5 А	t	small
121363	85871	242	Свердловская область, Белоярский район, поселок Хромцово, Калинина, 2А	t	small
74854	84721	235	Свердловская область, Белоярский район, поселок Студенческий, Мира, 23 А	f	large
74827	85870	241	Свердловская область, Белоярский район, поселок Совхозный, Первомайская, 4А	f	large
122448	87120	1107	Свердловская область, Белоярский район, поселок Светлый, 42А	f	medium
121333	85855	218	Свердловская область, Белоярский район, поселок Режик, Центральная, 39	t	small
121342	85858	225	Свердловская область, Белоярский район, поселок Рассоха, Уральская, 6	t	small
121345	14617	226	Свердловская область, Белоярский район, поселок Поварня, Ленина, 64	t	\N
74953	86786	865	Свердловская область, Белоярский район, поселок Октябрьский, Чапаева, 2Б	f	large
121339	84276	222	Свердловская область, Белоярский район, поселок Некрасово, Ленина, 22	f	medium
121346	85859	227	Свердловская область, Белоярский район, поселок Малобрусянское, Ленина, 38	t	small
121334	85856	219	Свердловская область, Белоярский район, поселок Малиновка, Набережная, 2, кв.2	t	small
121350	85864	232	Свердловская область, Белоярский район, поселок Логиново, 8 Марта, 56	t	medium
122601	87992	1799	Свердловская область, Белоярский район, поселок Курманка, Юбилейная, 1	f	medium
121634	86213	452	Свердловская область, Белоярский район, поселок Кочневское, Юбилейная, 2	t	medium
74828	85872	243	Свердловская область, Белоярский район, поселок Кочневское, Ударников, 9	f	large
74806	84311	223	Свердловская область, Белоярский район, поселок Косулино, Уральская, 62	f	large
121352	85865	233	Свердловская область, Белоярский район, поселок Колюткино, Красноармейская, 3 А	t	small
74826	85867	237	Свердловская область, Белоярский район, поселок Камышево, Школьная, 19	t	large
121337	84049	221	Свердловская область, Белоярский район, поселок Измоденова, Кирова, 32б	t	small
121358	85868	238	Свердловская область, Белоярский район, поселок Златогорова, Советская, 7	t	small
75446	87995	1800	Свердловская область, Белоярский район, Заречный, Трактовая, 38	f	large
75445	87985	1796	Свердловская область, Белоярский район, Заречный, Ленинградская, 15а	f	large
75443	87981	1794	Свердловская область, Белоярский район, Заречный, Ленинградская, 6а	f	large
75442	87981	1793	Свердловская область, Белоярский район, Заречный, Ленинградская, 6а	f	large
75440	87978	1791	Свердловская область, Белоярский район, Заречный, Ленина, 27	f	large
75439	87976	1790	Свердловская область, Белоярский район, Заречный, Ленина, 22	f	large
75438	87973	1789	Свердловская область, Белоярский район, Заречный, Ленина, 11	f	large
75444	87984	1795	Свердловская область, Белоярский район, Заречный, Алещенкова, 22а	f	large
75441	87980	1792	Свердловская область, Белоярский район, Заречный, Алещенкова, 6	f	large
75437	87971	1788	Свердловская область, Белоярский район, Заречный, Алещенкова, 19	f	large
122596	87988	1797	Свердловская область, Белоярский район, Заречный, 50 лет ВЛКСМ, здание офиса ООО ВИЗАВЕСТ	f	small
121348	85860	228	Свердловская область, Белоярский район, поселок Гусева, Ленина, 48	t	small
74808	85862	230	Свердловская область, Белоярский район, поселок Гагарский, воинская часть, школа №14	f	large
122599	87989	1798	Свердловская область, Белоярский район, поселок Гагарка, Клубная, 2	t	small
75091	89259	2569	Свердловская область, Белоярский район, поселок Верхнее Дуброво, Строителй, 5	f	large
75131	89261	2570	Свердловская область, Белоярский район, поселок Верхнее Дуброво, Клубная, 8	f	large
74805	84038	220	Свердловская область, Белоярский район, поселок Бруснятское, Советская, 33	f	large
122603	87996	1801	Свердловская область, Белоярский район, поселок Боярка, 8 марта, 12	f	small
74809	85863	231	Свердловская область, Белоярский район, поселок Большебрусянское, Школьная, 1	f	large
121356	85866	236	Свердловская область, Белоярский район, поселок Белореченский, Восточная, 14	t	medium
121324	85844	208	Свердловская область, Байкаловский район, поселок Шаламы, Советская, 9	t	small
121304	83941	198	Свердловская область, Байкаловский район, поселок Шадринка, Лаптева, 2	f	small
121320	85842	206	Свердловская область, Байкаловский район, поселок Чурманское, Мамарина, 46	t	medium
121316	85840	204	Свердловская область, Байкаловский район, поселок Пелевина, Новая, 77	f	medium
121313	85839	203	Свердловская область, Байкаловский район, поселок Нижняя Иленка, Советская, 5	f	medium
121302	82483	197	Свердловская область, Байкаловский район, поселок Менщикова, Кайгородова, 5	t	small
121311	85838	202	Свердловская область, Байкаловский район, поселок Малая Серкова, Набережная, 3	t	small
121296	81220	194	Свердловская область, Байкаловский район, поселок Макушина, Центральная, 19	f	small
121309	85837	201	Свердловская область, Байкаловский район, поселок Ляпуново, Техническая, 16	t	medium
122001	86575	720	Свердловская область, Байкаловский район, поселок Липовка, Административный корпус СОГУЗ СБВЛ	f	small
121308	85836	200	Свердловская область, Байкаловский район, поселок Липовка, Аникина, 1	f	small
121306	85835	199	Свердловская область, Байкаловский район, Краснополянское, Советская, 24	f	medium
121300	81831	196	Свердловская область, Байкаловский район, поселок Игнатьева, Набережная, 262	t	small
121297	81349	195	Свердловская область, Байкаловский район, поселок Елань, Советская, 27	f	medium
122268	86890	962	Свердловская область, Байкаловский район, поселок Елань, Кузнецова, 2	t	medium
121317	85841	205	Свердловская область, Байкаловский район, поселок Гуляева, Дзержинского, 48	t	small
122220	81250	923	Свердловская область, Байкаловский район, поселок Городище	t	medium
121293	81009	193	Свердловская область, Байкаловский район, поселок Городище, Советская, 47	f	medium
121291	85682	192	Свердловская область, Байкаловский район, поселок Вязовка, Советская, 55	f	medium
121287	85832	190	Свердловская область, Байкаловский район, поселок Байкалово, Октябрьская, 40	f	medium
74846	85830	188	Свердловская область, Байкаловский район, поселок Байкалово, Кузнецова, 10	f	large
74845	85829	187	Свердловская область, Байкаловский район, поселок Байкалово, Кузнецова, 30	f	large
121290	85833	191	Свердловская область, Байкаловский район, поселок Баженовское, Советская, 29	f	medium
121261	85801	172	Свердловская область, Ачитский район, поселок Ялым, Дружбы, 1	f	small
74844	85826	184	Свердловская область, Ачитский район, поселок Уфимский, Советская, 130	f	large
121282	85824	183	Свердловская область, Ачитский район, поселок Уфимский, Железнодорожная, 11А	f	medium
121257	85798	170	Свердловская область, Ачитский район, поселок Тюш, Трактовая, 22А	f	small
121270	85812	177	Свердловская область, Ачитский район, поселок Судницына, Мира, 13	t	small
121253	85794	168	Свердловская область, Ачитский район, поселок Сарга (Грачи), Уральская, 5	f	small
121232	85773	158	Свердловская область, Ачитский район, поселок Русский Потам, Трактовая, 13	f	medium
121231	85770	157	Свердловская область, Ачитский район, поселок Русские Карши (Одина), Красных Партизан, 19	f	small
121254	85795	169	Свердловская область, Ачитский район, поселок Осыпь, Центральная, 52	f	small
121269	85809	176	Свердловская область, Ачитский район, поселок Нижний Арий, 50 лет Октября, 1А	f	small
121236	85776	160	Свердловская область, Ачитский район, поселок Марийские Карши, Ленина, 24	f	small
121242	85783	163	Свердловская область, Ачитский район, поселок Малый Ут, Светлая, 13	t	small
121244	85784	164	Свердловская область, Ачитский район, поселок Лямпа, Труда, 34А	f	small
121222	85763	153	Свердловская область, Ачитский район, поселок Кочкильда, Центральная, 18	t	small
121247	85788	165	Свердловская область, Ачитский район, поселок Корзуновка, Молодёжная, 1	f	small
121276	85817	180	Свердловская область, Ачитский район, поселок Конёвка, Пролетарская, 33	f	small
121267	85808	175	Свердловская область, Ачитский район, поселок Кирчигаз, Центральная, 35	t	small
74867	85660	72	Свердловская область, Артемовский район, Артёмовский, Лесная, 23	f	large
121280	85821	182	Свердловская область, Ачитский район, поселок Катырева, Советская, 4	t	small
121265	85806	174	Свердловская область, Ачитский район, поселок Карги, Ленина, 23	f	small
121258	85799	171	Свердловская область, Ачитский район, поселок Заря, Советская, 29	f	\N
121279	85820	181	Свердловская область, Ачитский район, поселок Еманзельга, Новая, 12	t	small
121235	85775	159	Свердловская область, Ачитский район, поселок Верхний Потам, Школьная, 2	t	small
121272	85813	178	Свердловская область, Ачитский район, поселок Верхний Арий, Свердлова, 32	t	small
121229	85768	156	Свердловская область, Ачитский район, поселок Верх-Тиса, Центральная, 11	f	small
121227	85767	155	Свердловская область, Ачитский район, поселок Быково, Трактовая, 41	t	small
121240	85781	162	Свердловская область, Ачитский район, поселок Большой Ут, Молодежная, 2	f	small
121224	85765	154	Свердловская область, Ачитский район, поселок Бакряж, Советская, 2а	f	medium
74907	85758	151	Свердловская область, Ачитский район, поселок Ачит, Ленина , 4	f	large
74908	85760	152	Свердловская область, Ачитский район, поселок Ачит, Ленина, 3	f	large
121249	85789	166	Свердловская область, Ачитский район, поселок Афанасьевское, Советская, 5	f	medium
121250	85792	167	Свердловская область, Ачитский район, поселок Афанасьевский, Беляева, 27	t	small
121238	85779	161	Свердловская область, Ачитский район, поселок Артемейкова, Гагарина, 17	f	small
121263	85804	173	Свердловская область, Ачитский , поселок Гайны, пер. Школьный, 1	f	small
121274	85815	179	Свердловская область, Ачитский, поселок Ключ, Ленина, 37	f	small
75654	89280	2583	Свердловская область, Асбест, поселок Рефтинский, Юбилейная, 1а	f	large
121215	85751	146	Свердловская область, Артинский район, поселок Черкасовка, Молодежная, 17	t	small
121191	85738	131	Свердловская область, Артинский район, поселок Чекмаш, Трактовая, 5	t	small
121149	85715	103	Свердловская область, Артинский район, поселок Усть-Югуш, 8-го Марта, 1	f	small
121217	85752	147	Свердловская область, Артинский район, поселок Усть-Манчаж, Школьная, 4	t	small
121175	85730	121	Свердловская область, Артинский район, поселок Токари, Пролетарская, 4	t	small
121212	85750	145	Свердловская область, Артинский район, поселок Сухановка, Ленина, 179	t	medium
121209	85748	142	Свердловская область, Артинский район, поселок Старые Арти, Ленина, 159	f	medium
121197	85742	135	Свердловская область, Артинский район, поселок Соколята, Победы, 41	t	small
121203	85745	139	Свердловская область, Артинский район, поселок Симинчи, Советская, 1а	f	small
121210	85749	144	Свердловская область, Артинский район, поселок Сенная, Свердлова, 242	t	small
74848	85728	119	Свердловская область, Артинский район, Село Манчаж, Школьная, 15	f	large
121199	85743	137	Свердловская область, Артинский район, поселок Свердловское, Ленина, 34	f	medium
74849	85740	133	Свердловская область, Артинский район, поселок Сажино, Ленина, 19	f	large
121188	85737	129	Свердловская область, Артинский район, поселок Пристань, Советская, 8	f	medium
121182	85734	126	Свердловская область, Артинский район, поселок Поташка, Юбилейная, 20	t	medium
121181	85733	125	Свердловская область, Артинский район, поселок Пантелейково, Трактовая, 49а	f	small
121162	85722	111	Свердловская область, Артинский район, поселок Омельково, Заречная, 232	t	small
121177	85731	122	Свердловская область, Артинский район, поселок Новый Златоуст, Кирова, 1	t	small
121207	85747	141	Свердловская область, Артинский район, поселок Нижний Бардым, Школьная, 7	f	small
121169	85726	116	Свердловская область, Артинский район, поселок Малая Тавра, Советская, 7	f	medium
121160	85721	110	Свердловская область, Артинский район, поселок Малая Дегтярка, Культуры, 21	t	small
121164	85723	113	Свердловская область, Артинский район, поселок Курки, Заречная, 54	f	small
121194	85741	134	Свердловская область, Артинский район, поселок Конёво, Советская, 21	f	small
121172	85729	120	Свердловская область, Артинский район, поселок Кадочниково, Трактовая, 23а	t	small
121153	85717	105	Свердловская область, Артинский район, поселок Дружино-Бардым, Советская, 151	t	small
121205	85746	140	Свердловская область, Артинский район, поселок Верхний Бардым, Трактовая, 12	t	small
121158	85720	109	Свердловская область, Артинский район, поселок Большие Карзи, Советская, 20	t	small
45518	49363	167	Курганская область, Шадринск, Спартака, 8	f	large
121155	85718	107	Свердловская область, Артинский район, поселок Биткино, Советская, 48	t	small
121186	85736	128	Свердловская область, Артинский район, поселок Берёзовка, Трактовая, 3	t	medium
121157	85719	108	Свердловская область, Артинский район, поселок Бараба, Юбилейная, 11	f	small
121369	85895	265	Свердловская область, Артинский район, поселок Бараба, Ленина, 59а	f	\N
121219	85753	148	Свердловская область, Артинский район, поселок Бакийково	t	small
121171	85727	117	Свердловская область, Артинский район, поселок Багышково, Советская, 51	t	small
121193	85739	132	Свердловская область, Артинский район, поселок Афонасково, Новая, 3	t	small
121185	85735	127	Свердловская область, Артинский район, поселок Артя-Шигири, Школьная, 8	t	small
74881	85711	99	Свердловская область, Артинский район, поселок Арти, Фрунзе, 145	f	large
74886	85725	115	Свердловская область, Артинский район, поселок Арти, Лесная, 2	f	large
74884	85714	102	Свердловская область, Артинский район, поселок Арти, Ленина, 258	f	large
74885	85713	106	Свердловская область, Артинский район, поселок Арти, Ленина, 82	f	large
74883	85713	101	Свердловская область, Артинский район, поселок Арти, Ленина, 82	f	large
74882	85712	100	Свердловская область, Артинский район, поселок Арти, Королева, 50	f	large
74880	85667	98	Свердловская область, Артинский район, поселок Арти, Дерябина, 13	f	large
74879	85667	97	Свердловская область, Артинский район, поселок Арти, Дерябина, 13	f	large
121201	85744	138	Свердловская область, Артинский район, поселок Андрейково, Эрыкана, 32	f	small
121151	85716	104	Свердловская область, Артинский район, поселок Азигулово, Советска, 37	f	medium
121178	85732	123	Свердловская область, Артинский, поселок Манчаж, Школьная, 15, СОЦ	f	\N
121167	85724	114	Свердловская область, Артинский, поселок Малые Карзи, Юбилейная, 6а	f	medium
121129	85690	86	Свердловская область, Артемовский район, поселок Шогринское, 8 Марта, 36Б	f	medium
74877	85681	82	Свердловская область, Артемовский район, поселок Сосновый Бор, Дача Черёмушки, 6	f	large
74878	85695	89	Свердловская область, Артемовский район, поселок Покровское, Красных Партизан, 3	f	large
121123	85684	83	Свердловская область, Артемовский район, поселок Писанец, Школьная, 3	f	small
121139	85702	92	Свердловская область, Артемовский район, поселок Незевай, Школьная, 1	f	small
121131	85691	87	Свердловская область, Артемовский район, поселок Мостовское, Ленина, 18	f	medium
121136	85700	91	Свердловская область, Артемовский район, поселок Липино, Школьная, 3А	t	small
121124	85686	84	Свердловская область, Артемовский район, поселок Лебёдкино, Гагарина, 1	f	medium
74875	85677	80	Свердловская область, Артемовский район, поселок Красногвардейский, Усиевича, 16	f	large
74874	85675	79	Свердловская область, Артемовский район, поселок Красногвардейский, Некрасова, 1	f	large
74876	85678	81	Свердловская область, Артемовский район, поселок Красногвардейский, Комсомольская, 2А	f	large
74870	85666	75	Свердловская область, Артемовский район, поселок Буланаш, Театральная, 1	f	large
74869	85663	74	Свердловская область, Артемовский район, поселок Буланаш, Кутузова, 23А	f	large
74872	85671	77	Свердловская область, Артемовский район, поселок Буланаш, Комсомольская, 7	f	large
74871	85669	76	Свердловская область, Артемовский район, поселок Буланаш, Комсомольская, 21	f	large
74868	85662	73	Свердловская область, Артемовский район, поселок Буланаш, Грибоедова, 1	f	large
74873	85673	78	Свердловская область, Артемовский район, поселок Буланаш, Белинского, 32	f	large
121126	85688	85	Свердловская область, Артемовский район, поселок Бичур, Советская, 2А	t	small
74903	85654	69	Свердловская область, Артемовский район, Артёмовский, Чайковского, 2А	f	large
121118	85645	61	Свердловская область, Артемовский район, Артёмовский, Станционная, 1К	t	medium
121140	85703	93	Свердловская область, Артемовский район, Артёмовский, Прилепского, 2А	t	small
74902	85653	68	Свердловская область, Артемовский район, Артёмовский, Площадь Советов, 6	f	large
74893	84692	55	Свердловская область, Артемовский район, Артёмовский, Переулок Заводской, 2а	f	large
121285	85827	185	Свердловская область, Артемовский район, Артёмовский, Октябрьская, 5, Ж/Д вокзал	f	\N
74900	85649	65	Свердловская область, Артемовский район, Артёмовский, Мира, 13	f	large
74905	85658	71	Свердловская область, Артемовский район, Артёмовский, Лесная, 10	f	large
74894	81368	57	Свердловская область, Артемовский район, Артёмовский, Кронштадтская, 12	f	large
74898	85647	63	Свердловская область, Артемовский район, Артёмовский, Красный Луч, 37а	f	large
121143	85705	94	Свердловская область, Артемовский район, Артёмовский, Котовского, 4	f	medium
121121	85651	67	Свердловская область, Артемовский район, Артёмовский, Комсомольская, 2	f	medium
74901	85650	66	Свердловская область, Артемовский район, Артёмовский, Комсомольская, 6	f	large
74896	85643	59	Свердловская область, Артемовский район, Артёмовский, 8 Марта, 66	f	large
121134	85697	90	Свердловская область, Артемовский городской округ, село Мироново, Школьный переулок, 5	f	medium
121133	85694	88	Свердловская область, Артемовский, поселок Большое Трифоново, Советская, 13	f	medium
121052	81658	23	Свердловская область, Алапаевский район, поселок Ячменёва, Центральная, 31	t	small
121029	85623	11	Свердловская область, Алапаевский район, поселок Ясашная, Клубная, 11	f	\N
121060	82240	27	Свердловская область, Алапаевский район, поселок Ярославское, Матвеева, 18	t	small
121064	82364	29	Свердловская область, Алапаевский район, поселок Ялунинское, Мира, 49 а	f	\N
121098	85638	46	Свердловская область, Алапаевский район, поселок Хабарчиха, Школьная, 10	t	\N
121105	83991	49	Свердловская область, Алапаевский район, поселок Фоминское, Центральная, 8	t	small
121030	85624	12	Свердловская область, Алапаевский район, поселок Толмачёво, Ленина, 28	t	medium
121022	85617	3	Свердловская область, Алапаевский район, поселок Строкинка, Почтовая, 72	t	small
121111	84520	52	Свердловская область, Алапаевский район, поселок Санкино, Кедровая, 10	t	\N
121075	83636	35	Свердловская область, Алапаевский район, поселок Самоцвет, Школьная, 40	t	small
121077	83788	36	Свердловская область, Алапаевский район, поселок Раскатиха, Ленина, 23	f	small
121043	85630	18	Свердловская область, Алапаевский район, поселок Первунова, Победы, 8	t	small
121035	85626	14	Свердловская область, Алапаевский район, поселок Нижняя Синячиха, Спиридоновская, 47	f	medium
121050	81536	22	Свердловская область, Алапаевский район, поселок Невьянское, Ленина, 55	f	\N
121108	84191	51	Свердловская область, Алапаевский район, поселок Муратково, Лесников, 14	t	\N
121084	83928	39	Свердловская область, Алапаевский район, поселок Мугайское, 70 лет Октября, 17	f	\N
121045	85430	19	Свердловская область, Алапаевский район, поселок Михалёва, Школьная, 3	t	small
121085	85632	40	Свердловская область, Алапаевский район, поселок Махнёво, Профсоюзная, 2 б	t	medium
121091	85635	43	Свердловская область, Алапаевский район, поселок Махнёво, Победы, 23	f	medium
121089	85634	42	Свердловская область, Алапаевский район, поселок Махнёво, Победы, 102	f	medium
121087	85633	41	Свердловская область, Алапаевский район, поселок Махнёво, Победы, 32	f	medium
121074	83418	34	Свердловская область, Алапаевский район, поселок Курорт Самоцвет, Центральная, 15	f	\N
121025	85618	4	Свердловская область, Алапаевский район, поселок Курорт ''Самоцвет'', Курортная, 28	f	small
121055	81724	24	Свердловская область, Алапаевский район, поселок Костино, Молодежная, 3	f	\N
121066	82423	30	Свердловская область, Алапаевский район, поселок Коптелово, Красных орлов, 52	f	\N
121629	86209	448	Свердловская область, Алапаевский район, поселок Кокшарова, Школьная, 2А	t	small
121059	82006	26	Свердловская область, Алапаевский район, поселок Клевакино, Центральная, 30	f	\N
121103	85641	48	Свердловская область, Алапаевский район, поселок Кишкинское, Корелина, 1	t	small
121038	85628	16	Свердловская область, Алапаевский район, поселок Кировское (Монастырское), Школьная, 9	t	\N
121069	82599	32	Свердловская область, Алапаевский район, поселок Катышка, Красных Партизан, 10	f	small
121082	83878	38	Свердловская область, Алапаевский район, поселок Измоденово, Мира, 18	f	\N
121033	85625	13	Свердловская область, Алапаевский район, поселок Заря, Набережная, 20	f	\N
121021	85616	2	Свердловская область, Алапаевский район, поселок Ельничная, Клубная, 17	t	small
121079	83833	37	Свердловская область, Алапаевский район, поселок Деево, Ленина, 34	f	\N
121048	81374	21	Свердловская область, Алапаевский район, поселок Голубковское, 60 лет Октября, 9	t	\N
121047	85455	20	Свердловская область, Алапаевский район, поселок Гаранинка	t	\N
74959	87035	1051	Свердловская область, Алапаевский район, поселок Вогулка, Советская, 66	f	large
74889	85621	7	Свердловская область, Алапаевский район, поселок Верхняя Синячиха, Октябрьская, 16а	f	large
74888	85620	6	Свердловская область, Алапаевский район, поселок Верхняя Синячиха, Октябрьская, 2 а	f	large
74890	82179	8	Свердловская область, Алапаевский район, поселок Верхняя Синячиха, Октябрьская, 17	f	large
74891	85622	10	Свердловская область, Алапаевский район, поселок Верхняя Синячиха, Ленина, 23	f	large
121027	85404	9	Свердловская область, Алапаевский район, поселок Верхняя Синячиха, Красной Гвардии, 11	f	medium
74887	85619	5	Свердловская область, Алапаевский район, поселок Верхняя Синячиха, Бажова, 46	f	large
121056	81915	25	Свердловская область, Алапаевский район, поселок Бутакова, Советская, 7	t	small
121019	85615	1	Свердловская область, Алапаевский район, поселок Бубчиково, Ленина, 2	f	\N
121096	85637	45	Свердловская область, Алапаевский район, поселок Большая Ерзовка, Центральная, 21	f	small
121106	84084	50	Свердловская область, Алапаевский район, поселок Болотовское, Центральная, 15	t	small
121040	85629	17	Свердловская область, Алапаевский район, поселок Бобровка, Клубная, 11	t	small
121072	83103	33	Свердловская область, Алапаевский район, поселок Арамашево, Школьная, 1	f	\N
121113	84664	53	Свердловская область, Алапаевский , поселок Калач, Центральная, 29	t	small
74783	86137	401	Свердловская область,  Каменский район, поселок Покровское, Ленина, 128	f	large
45428	49272	77	Курганская область, урган, Отдыха, 7А	f	large
45427	49272	76	Курганская область, урган, Отдыха, 7А	f	large
45405	49272	54	Курганская область, урган, Отдыха, 7А	f	large
46486	50330	1151	Курганская область, Юргамыш, Энергетиков, 22А	f	medium
46407	50264	1072	Курганская область, Щучье, 2	f	small
46403	50260	1068	Курганская область, Щучье, площадь Победы, 3	f	large
46401	50258	1066	Курганская область, Щучье, Школьная, 19	f	medium
46402	50259	1067	Курганская область, Щучье, Пролетарская, 1	f	small
46409	50266	1074	Курганская область, Щучье, Мира, 34	f	large
46408	50265	1073	Курганская область, Щучье, Маршала Жукова Г. К, 5	f	medium
46404	50261	1069	Курганская область, Щучье, Ленина, 9	f	small
46406	50263	1071	Курганская область, Щучье, Калинина, 20	f	medium
46410	50267	1075	Курганская область, Щучье, К. Маркса, 33	f	small
46405	50262	1070	Курганская область, Щучье, 1ое Мая, 45	f	small
46360	50217	1025	Курганская область, Шумиха, бульвар 50-тилетия Октября, 4	f	medium
46367	50224	1032	Курганская область, Шумиха, Советская, 91	f	large
46355	50212	1020	Курганская область, Шумиха, Советская, 36	f	medium
46359	50216	1024	Курганская область, Шумиха, Смолина, 36	f	medium
46371	50228	1036	Курганская область, Шумиха, Победы, 21	f	large
46365	50222	1030	Курганская область, Шумиха, Морозова, 56	f	medium
46369	50226	1034	Курганская область, Шумиха, Магистральная, 1	f	large
46366	50223	1031	Курганская область, Шумиха, Ленина, 112	f	large
46362	50219	1027	Курганская область, Шумиха, Ленина, 72	f	large
46364	50221	1029	Курганская область, Шумиха, Комсомольская, 33	f	large
46361	50218	1026	Курганская область, Шумиха, Кирова, 19	f	medium
46372	50229	1037	Курганская область, Шумиха, Квартал Новостроек, 17	f	large
46370	50227	1035	Курганская область, Шумиха, Гоголя, 36	f	medium
46368	50225	1033	Курганская область, Шумиха, Гоголя, 141	f	medium
46357	50214	1022	Курганская область, Шумиха, Гоголя, 28	f	medium
46363	50220	1028	Курганская область, Шумиха, Воронкова, 29	f	medium
46356	50213	1021	Курганская область, Шумиха, Бульвар 50летия Октября, 2	f	medium
45524	49369	173	Курганская область, Шадринск, Свердлова, 97	f	large
45515	49360	164	Курганская область, Шадринск, Свердлова, 43	f	large
45508	49353	157	Курганская область, Шадринск, Кирова, 48	f	large
45507	49352	156	Курганская область, Шадринск, Энергетиков, 11	f	large
45506	49351	155	Курганская область, Шадринск, Щеткина, 4	f	large
46497	50355	1163	Курганская область, Шадринск, Февральская, 197	f	large
45505	49350	154	Курганская область, Шадринск, Труда, 43	f	large
45504	49349	153	Курганская область, Шадринск, Труда, 1	f	large
45502	49347	151	Курганская область, Шадринск, Тобольская, 22	f	large
46501	50099	1167	Курганская область, Шадринск, Свердлова, 132	f	large
45523	49368	172	Курганская область, город Шадринск, Свердлова, 91	f	large
45534	49367	183	Курганская область, Шадринск, Свердлова, 59	f	large
45522	49367	171	Курганская область, Шадринск, Свердлова, 59	f	large
45519	49364	168	Курганская область, Шадринск, Свердлова, 49	f	large
45512	49357	161	Курганская область, Шадринск, Свердлова, 3	f	large
46502	50359	1168	Курганская область, Шадринск, Розы Люксембург, 1	f	large
45521	49366	170	Курганская область, Шадринск, Розы Люксембург, 18	f	large
45497	49342	146	Курганская область, Шадринск, Проектная, 8	f	large
45503	49348	152	Курганская область, Шадринск, Первомайская, 63	f	large
45499	49344	148	Курганская область, Шадринск, Мичурина, 6	f	large
46500	50358	1166	Курганская область, Шадринск, Михайловская, 180А	f	small
46499	50357	1165	Курганская область, город Шадринск, Михайловская, 79	f	medium
45511	49356	160	Курганская область, Шадринск, Луначарского, 8	f	medium
45501	49346	150	Курганская область, Шадринск, Ломоносова, 12	f	large
45516	49361	165	Курганская область, Шадринск, Ленина, 95	f	large
45513	49358	162	Курганская область, Шадринск, Красноармейская, 93	f	large
46524	50380	1191	Курганская область, Шадринск, Крайняя, 17	t	small
45498	49343	147	Курганская область, Шадринск, Кооперативная, 4	f	large
45520	49365	169	Курганская область, Шадринск, Карла Либкнехта, 3	f	medium
46503	50360	1169	Курганская область, Шадринск, Демьяна Бедного, 5	f	small
45509	49354	158	Курганская область, Шадринск, Батуринская, 34	f	large
45514	49359	163	Курганская область, Шадринск, Архангельского, 58	f	large
45500	49345	149	Курганская область, Шадринск, Автомобилистов, 30	f	large
45496	49341	145	Курганская область, Шадринск, Автомобилистов, 84	f	large
45495	49340	144	Курганская область, Шадринск, Автомобилистов, 20	f	medium
46498	50356	1164	Курганская область, Шадринск, 4го Уральского полка, 30	f	large
46204	50061	868	Курганская область, Целинное, Свердлова, 48	f	large
46074	49927	733	Курганская область, Петухово, Чапаева, 62	f	large
46073	49926	732	Курганская область, Петухово, Строительная, 1А	f	medium
46489	50347	1155	Курганская область, Петухово, Первомайская, 51	f	small
46069	49922	728	Курганская область, Петухово, Линейная, 1	f	large
46072	49925	731	Курганская область, Петухово, Красная, 186	f	large
46071	49924	730	Курганская область, Петухово, Красная, 66	f	medium
46068	49921	727	Курганская область, Петухово, Кирова, 34	f	medium
46067	49920	726	Курганская область, Петухово, Карла Маркса, 59	f	large
46066	49919	725	Курганская область, Петухово, Карла Маркса, 55	f	large
46065	49918	724	Курганская область, Петухово, К.Маркса, 5	f	medium
45951	49803	610	Курганская область, Макушино, Ново-Северная, 32	f	medium
45987	49839	646	Курганская область, Макушино, Лесная, 4	f	large
45949	49801	608	Курганская область, Макушино, Ленина, 68	f	large
45948	49800	607	Курганская область, Макушино, Ленина, 95	f	large
45947	49799	606	Курганская область, Макушино, Демьяна Бедного, 2	f	large
45952	49804	611	Курганская область, Макушино, В.Ушаковой, 1А	f	medium
45950	49802	609	Курганская область, Макушино, 2я Вокзальная, 11	f	medium
46521	50377	1187	Курганская область, Лесниково, Студенческий, 1	f	small
45911	49763	570	Курганская область, поселок Лебяжье, Кирова, 2	f	medium
45853	49702	512	Курганская область, Куртамыш, пр.Конституции, 5	f	large
45849	49698	508	Курганская область, Куртамыш, Студенческая, 1	f	large
45852	49701	511	Курганская область, Куртамыш, Пролетарская, 8	f	large
45844	49693	503	Курганская область, Куртамыш, Правды, 15	f	large
45847	49696	506	Курганская область, Куртамыш, Парковый переулок, 6	f	medium
45846	49695	505	Курганская область, Куртамыш, Ленина, 4	f	large
45851	49700	510	Курганская область, Куртамыш, Колхозная, 23	f	large
45850	49699	509	Курганская область, Куртамыш, XXII Партсъезда, 172	f	large
45406	49273	55	Курганская область, Курган, Заозерный район, улица Алексеева, 1	f	large
45407	49274	56	Курганская область, город Курган, улица Алексеева, 14	f	large
45425	49288	74	Курганская область, Курган, проспект Машиностроителей, 17	f	large
45386	49259	35	Курганская область, Курган, проспект Машиностроителей, 12	f	large
45443	49302	92	Курганская область, Курган, проспект Конституции, 68	f	large
45442	49301	91	Курганская область, Курган, проспект Конституции, 60	f	large
45441	49300	90	Курганская область, Курган, проспект Конституции, 75	f	large
45462	49317	111	Курганская область, Курган, площадь Слосмана, 5	f	large
134619	94451	291	Курганская область, Курган, пл.Собанина, 1, здание автовокзала	f	\N
134618	94450	290	Курганская область, Курган, Центральный район, пл.Слосмана, 6, здание центрального железнодорожного вокзала	f	\N
45390	49261	39	Курганская область, Курган, микрорайон Керамзитный, 11	f	large
45389	49260	38	Курганская область, Курган, Яблоневая, 2а, общежитие и спортбаза КГУ	f	medium
45434	49294	83	Курганская область, Курган, Электровозная, 23	f	large
45481	49332	130	Курганская область, Курган, Школьная, 38	t	small
45391	49262	40	Курганская область, Курган, Центральная, 24	f	large
45435	49295	84	Курганская область, Курган, Центральная, 1	f	small
45412	49278	61	Курганская область, Курган, Фарафонова, 27	f	large
45411	49278	60	Курганская область, Курган, Фарафонова, 27	f	large
45352	49238	1	Курганская область, Курган, Урожайная, 147А	f	large
45373	48953	22	Курганская область, Курган, Урицкого, 153	f	large
45368	49248	17	Курганская область, Курган, Урицкого, 193	f	large
45367	49248	16	Курганская область, Курган, Урицкого, 193	f	large
45366	49248	15	Курганская область, Курган, Урицкого, 193	f	large
45399	49266	48	Курганская область, Курган, Тимирязева, 38А	f	large
45397	49266	46	Курганская область, Курган, Тимирязева, 38А	f	large
45396	49266	45	Курганская область, Курган, Тимирязева, 38А	f	large
45490	49319	139	Курганская область, Курган, Станционная, 44	f	large
45466	49319	115	Курганская область, Курган, Станционная, 44	f	large
45461	49316	110	Курганская область, Курган, Станционная, 6	f	large
45465	49318	114	Курганская область, Курган, Станционная, 26	f	large
45464	49318	113	Курганская область, Курган, Станционная, 26	f	large
45463	49318	112	Курганская область, Курган, Станционная, 26	f	large
45355	49240	4	Курганская область, Курган, Спортивная, 11	f	large
45354	49240	3	Курганская область, Курган, Спортивная, 11	f	large
45445	49303	94	Курганская область, Курган, Солнечный бульвар, 8	f	large
45444	49303	93	Курганская область, Курган, Солнечный бульвар, 8	f	large
45474	49327	123	Курганская область, Курган, Советская , 63	f	large
45375	49250	24	Курганская область, Курган, Советская, 160	f	large
45388	49250	37	Курганская область, Курган, Советская, 160	f	medium
45376	49251	25	Курганская область, Курган, Советская, 108	f	large
45392	49263	41	Курганская область, Курган, Советская, 41	f	large
45479	49330	128	Курганская область, Курган, Сиреневая, 25А	f	large
45433	49293	82	Курганская область, Курган, Сады Зауралья, 2, ЗАО Сады Зауралья	f	large
45468	49321	117	Курганская область, Курган, Центральный район, Пушкина, 137	f	large
45358	49243	7	Курганская область, Курган, Пугачева, 97	f	large
45383	49256	32	Курганская область, Курган, Пролетарская, 62	f	large
45432	49292	81	Курганская область, Курган, Правды, 53, здание школы №75	f	large
45431	49292	80	Курганская область, Курган, Правды, 53, здание школы №75	f	large
45450	49307	99	Курганская область, Курган, Победы, 10	f	large
45449	49307	98	Курганская область, Курган, Победы, 10	f	large
45380	49252	29	Курганская область, Курган, Пичугина, 36	f	large
45377	49252	26	Курганская область, Курган, Пичугина, 36	f	large
45398	49267	47	Курганская область, Курган, Пирогова, 17	f	large
45430	49291	79	Курганская область, Курган, Омская, 1Б	f	large
45384	49257	33	Курганская область, Курган, Некрасова, 10	f	large
45448	49306	97	Курганская область, Курган, Центральный район, Невежина, 26к2	f	large
45394	49264	43	Курганская область, Курган, Московская, 26	f	large
45393	49264	42	Курганская область, Курган, Московская, 26	f	large
45429	49290	78	Курганская область, Курган, Молодежи, 35	f	large
45365	49247	14	Курганская область, Курган, Максима Горького, 216	f	large
45363	49247	12	Курганская область, Курган, Максима Горького, 216	f	large
45356	49241	5	Курганская область, Курган, Ломоносова, 41	f	medium
46438	50296	1103	Курганская область, Курган, Ломоносова, 41	f	medium
45382	49255	31	Курганская область, Курган, Ленина, 37	f	large
45467	49320	116	Курганская область, Курган, Ленина, 37	f	large
45477	49328	126	Курганская область, Курган, Куйбышева, 49	f	large
45476	49328	125	Курганская область, Курган, Куйбышева, 49	f	large
45364	49246	13	Курганская область, Курган, Куйбышева, 144А	f	large
45362	49246	11	Курганская область, Курган, Куйбышева, 144А	f	large
45485	49269	134	Курганская область, Курган, Кузнецова, 6А	f	large
45401	49269	50	Курганская область, Курган, Кузнецова, 6А	f	large
45369	49237	18	Курганская область, Курган, Кравченко, 28	f	large
45370	49237	19	Курганская область, Курган, Кравченко, 28	f	large
45482	49333	131	Курганская область, Курган, Котовского, 92	f	large
45436	49296	85	Курганская область, Курган, Космонавтов, 5А	f	large
45440	49299	89	Курганская область, Курган, Конституции проспект, 56	f	large
45439	49298	88	Курганская область, Курган, Конституции проспект, 53	f	large
45438	49298	87	Курганская область, Курган, Конституции проспект, 53	f	large
45489	49309	138	Курганская область, Курган, Коли Мяготина, 67	f	large
45452	49309	101	Курганская область, Курган, Коли Мяготина, 67	f	large
45374	49249	23	Курганская область, Курган, Коли Мяготина, 176	f	large
45483	49334	132	Курганская область, Курган, Коли Мяготина, 176	f	large
45475	49324	124	Курганская область, Курган, Кирова, 52	f	large
45471	49324	120	Курганская область, Курган, Кирова, 52	f	large
45379	49254	28	Курганская область, Курган, Карла Маркса, 70	f	large
45372	42136	21	Курганская область, Курган, Карла Маркса, 84А	f	large
45371	42136	20	Курганская область, Курган, Карла Маркса, 84А	f	large
45473	49326	122	Курганская область, Курган, Карла Маркса, 52	f	large
46246	50104	910	Курганская область, Курган, Карельцева, 84	f	large
45459	49314	108	Курганская область, Курган, Карельцева, 32	f	large
45458	49313	107	Курганская область, Курган, Карельцева, 103	f	large
45457	49313	106	Курганская область, Курган, Карельцева, 103	f	large
45395	49265	44	Курганская область, Курган, Карбышева, 12А	f	large
46463	50322	1128	Курганская область, Курган, Карбышева, 12А	f	large
45480	49331	129	Курганская область, Курган, Карбышева, 56	f	large
45478	49329	127	Курганская область, Курган, Интернатовская, 46	f	large
45454	49310	103	Курганская область, Курган, Зорге, 37	f	large
45455	49311	104	Курганская область, Курган, Зорге, 24	f	large
45488	49289	137	Курганская область, Курган, Дзержинского, 3	f	large
45426	49289	75	Курганская область, Курган, Дзержинского, 3	f	large
45424	49287	73	Курганская область, Курган, Дзержинского, 1а	f	large
45387	49258	36	Курганская область, Курган, Дзержинского, 46	f	large
45385	49258	34	Курганская область, Курган, Дзержинского, 46	f	large
45378	49253	27	Курганская область, Курган, Гоголя, 107А	f	large
45381	49253	30	Курганская область, Курган, Гоголя, 107А	f	large
45469	49322	118	Курганская область, Курган, Гоголя, 30	f	large
45472	49325	121	Курганская область, Курган, Гоголя, 54	f	large
45437	49297	86	Курганская область, Курган, Глинки, 14	f	large
45486	49305	135	Курганская область, Курган, Галкинская, 59А	f	large
45447	49305	96	Курганская область, Курган, Галкинская, 59А	f	large
45361	49245	10	Курганская область, Курган, Гайдара, 9	f	large
45357	49242	6	Курганская область, Курган, Гагарина, 64	f	large
45353	49239	2	Курганская область, Курган, Гагарина, 41С12	f	large
45470	49323	119	Курганская область, Курган, Васильева, 7	f	large
45460	49315	109	Курганская область, Курган, Васильева, 7	f	large
45360	49244	9	Курганская область, Курган, Бородина, 41	f	large
45359	49244	8	Курганская область, Курган, Бородина, 41	f	large
45446	49304	95	Курганская область, Курган, Бажова, 116	f	large
45404	49271	53	Курганская область, Курган, Анфиногенова, 66	f	large
45403	49271	52	Курганская область, Курган, Анфиногенова, 66	f	large
45408	49275	57	Курганская область, Курган, Алексеева, 11	f	large
45402	49270	51	Курганская область, Курган, 9 Мая, 8	f	large
45422	49285	71	Курганская область, Курган, 6-й микрорайон, 16А	f	large
45421	49285	70	Курганская область, Курган, 6-й микрорайон, 16А	f	large
45487	49335	136	Курганская область, Курган, 6-й микрорайон, 6б, ДЮСШ №3	f	large
45420	49284	69	Курганская область, Курган, Заозерный район, 6-й микрорайон, 6 микрорайон, 16а, МОУ ДОД ДЮСШ № 316а	f	large
45418	49282	67	Курганская область, Курган, 5-й микрорайон, 15	f	large
46248	49282	912	Курганская область, Курган, 5-й микрорайон, 15	f	large
45419	49283	68	Курганская область, Курган, 5-й микрорайон, 23	f	large
45416	49280	65	Курганская область, Курган, 3-й микрорайон, 32	f	large
45415	49280	64	Курганская область, Курган, 3-й микрорайон, 32	f	large
45417	49281	66	Курганская область, Курган, 3-й микрорайон, 25	f	large
45414	49279	63	Курганская область, Курган, 3-й микрорайон, 4А	f	large
45413	49279	62	Курганская область, Курган, 3-й микрорайон, 4А	f	large
45484	49277	133	Курганская область, Курган, 1-й микрорайон, 7	f	large
45410	49277	59	Курганская область, Курган, 1-й микрорайон, 7	f	large
45409	49276	58	Курганская область, Курган, 1-й микрорайон, 11К1	f	large
46247	50105	911	Курганская область, Курган, 1-й микрорайон, 7	f	large
45453	49308	102	Курганская область, Курган, 1 Мая, 19а	f	large
45451	49308	100	Курганская область, Курган, 1 Мая, 19а	f	large
45400	49268	49	Курганская область, Курган, Карбышева, 52	f	large
45746	49594	405	Курганская область, Катайск, Советская, 1	f	medium
45747	49595	406	Курганская область, Катайск, Островского, 4	f	medium
45748	49596	407	Курганская область, Катайск, Маяковского, 1	f	medium
45754	49602	413	Курганская область, Катайск, Матросова, 81	f	large
45753	49601	412	Курганская область, Катайск, Матросова, 66	f	large
45786	49635	445	Курганская область, Катайск, Ленина, 217	f	medium
45752	49600	411	Курганская область, Катайск, Ленина, 210	f	large
45750	49598	409	Курганская область, Катайск, Ленина, 184	f	medium
45749	49597	408	Курганская область, Катайск, Ленина, 195	f	medium
45757	49605	416	Курганская область, Катайск, Красноармейская, 23	f	medium
45788	49637	447	Курганская область, Катайск, Комарова, 16	f	small
45755	49603	414	Курганская область, Катайск, Гагарина, 24	f	medium
45756	49604	415	Курганская область, Катайск, Боровая, 1	f	medium
45787	49636	446	Курганская область, Катайск, 30 лет Победы, 4	f	medium
45751	49599	410	Курганская область, Катайск, 30 лет Победы, 7	f	medium
45741	49589	400	Курганская область, Каргаполье, Пушкина , 28Б	f	medium
45727	49575	384	Курганская область, Каргаполье, Новая, 1А	f	medium
45645	49492	299	Курганская область, Далматово, Советская, 233	f	medium
45644	49492	298	Курганская область, Далматово, Советская, 233	f	large
45643	49491	297	Курганская область, Далматово, Советская, 193	f	large
45642	49490	296	Курганская область, Далматово, Советская, 177	f	large
45640	49488	294	Курганская область, Далматово, Советская, 112	f	medium
45639	49487	293	Курганская область, Далматово, Советская, 151	f	large
45638	49486	292	Курганская область, Далматово, Советская, 110	f	medium
45651	49499	305	Курганская область, Далматово, Гагарина, 84	f	small
45648	49496	302	Курганская область, Далматово, Гагарина, 93	f	small
45647	49495	301	Курганская область, Далматово, Гагарина, 80	f	small
45646	49493	300	Курганская область, Далматово, 8 Марта, 95	f	small
45641	49489	295	Курганская область, Далматово, 4-го Уральского полка, 109	f	large
45820	49669	479	Курганская область, поселок Введенское, Ленина, 40	f	large
46205	50010	869	Курганская область, село Большое Чаусово, Лесная, 13	f	large
46460	50319	1125	Курганская область, Юргамышский район, поселок сельского типа Кипель, Советская, 81	f	medium
46484	50344	1149	Курганская область, Юргамышский район, поселок Юргамыш, Труда, 147	f	medium
46482	50342	1147	Курганская область, Юргамышский район, поселок Юргамыш, Свободы, 25	f	medium
46485	50277	1150	Курганская область, Юргамышский район, поселок Юргамыш, Мичурина, 2	f	medium
46483	50343	1148	Курганская область, Юргамышский район, поселок Юргамыш, Мира, 58	f	medium
46481	50341	1146	Курганская область, Юргамышский район, поселок Юргамыш, Ленина, 22	f	medium
46480	50340	1145	Курганская область, Юргамышский район, поселок Юргамыш, Блюхера, 2	f	medium
46511	50368	1177	Курганская область, Юргамышский район, Юргамыш, Линейная, 5	f	medium
46465	50324	1130	Курганская область, Юргамышский район, село Шемелино, Центральная, 26	t	small
46477	50337	1142	Курганская область, Юргамышский район, село Чинеево, Школьная, 2	f	small
46475	50335	1140	Курганская область, Юргамышский район, село Фадюшино, Центральная, 50	f	small
46453	50312	1118	Курганская область, Юргамышский район, Туманова	t	small
46474	50334	1139	Курганская область, Юргамышский район, село Таловка, Центральная, 2	f	small
46473	50333	1138	Курганская область, Юргамышский район, село Скоблино, Школьная, 48	f	medium
77014	2692	71	Томская область, Томск, Хмельницкого, 40	f	large
46459	50318	1124	Курганская область, Юргамышский район, село Редуть, 2я Деревенская, 7А	t	small
46468	50327	1133	Курганская область, Юргамышский район, село Раздольная, Центральная, 16	t	small
46476	50336	1141	Курганская область, Юргамышский район, Плотникова, Набережная, 10	t	small
46467	50326	1132	Курганская область, Юргамышский район, село Петровское, Береговая, 6, Красноуральский сельсовет	t	small
46472	50332	1137	Курганская область, Юргамышский район, село Пески, Центральная, 39	f	small
46461	50320	1126	Курганская область, Юргамышский район, Падун, Победа, 21	f	small
46455	50314	1120	Курганская область, Юргамышский район, село Норильное, Клиновая, 16	f	small
46487	50345	1152	Курганская область, Юргамышский район, поселок Новый Мир, Ленина, 19	f	large
46478	50338	1143	Курганская область, Юргамышский район, село Новая Заворина, Центральная, 66	t	small
46488	50346	1153	Курганская область, Юргамышский район, село Нива, Заводская, 2	t	small
46469	50328	1134	Курганская область, Юргамышский район, село Малое Белое, Школьная, 2	f	medium
46464	50323	1129	Курганская область, Юргамышский район, Кулаш, Верхняя, 17	t	small
46466	50325	1131	Курганская область, Юргамышский район, село Красный Уралец, Ленина, 4	f	medium
46462	50321	1127	Курганская область, Юргамышский район, село Кислянское, Маюрова, 4	f	medium
46458	50317	1123	Курганская область, Юргамышский район, село Караси, Советская, 35А	f	medium
46479	50339	1144	Курганская область, Юргамышский район, Зырянка, Центральная, 5	t	small
46457	50316	1122	Курганская область, Юргамышский район, село Ерохина, Степная, 1	t	small
46470	50329	1135	Курганская область, Юргамышский район, село Губерля, Школьная, 10	f	small
46456	50315	1121	Курганская область, Юргамышский район, поселок Горохово, Школьная, 37	f	large
46454	50313	1119	Курганская область, Юргамышский район, село Гагарье, Молодёжная, 1Б	f	small
46471	50331	1136	Курганская область, Юргамышский район, село Вохменка, Баранова, 43	f	small
46452	50311	1117	Курганская область, Юргамышский район, село Вилкино, Ленина, 1	f	small
46421	50279	1086	Курганская область, Щучанский район, село Яковлевка	t	small
46427	50285	1092	Курганская область, Щучанский район, поселок Чумляк	f	medium
46448	50307	1113	Курганская область, Щучанский район, село Чудняково, Центральная, 23	t	small
46419	50276	1084	Курганская область, Щучанский район, село Чистое	f	small
46432	50290	1097	Курганская область, Щучанский район, село Чесноковка 1-я, Солнечная, 27	t	small
46449	50308	1114	Курганская область, Щучанский район, село Чердаки, Быкова, 15	t	small
46451	50310	1116	Курганская область, Щучанский район, село Утичье, А. Усова, 16А	f	small
46414	50271	1079	Курганская область, Щучанский район, село Тунгуй	t	small
46416	50273	1081	Курганская область, Щучанский район, село Сухоборское	f	medium
46428	50286	1093	Курганская область, Щучанский район, село Советская	t	small
46444	50302	1109	Курганская область, Щучанский район, село Пуктыш, Озёрная, 63	f	small
46411	50268	1076	Курганская область, Щучанский район, село Плановый	t	large
46439	50297	1104	Курганская область, Щучанский район, село Пивкино, Центральная, 1	f	small
46435	50293	1100	Курганская область, Щучанский район, село Пивкино, Станционная, 16	t	small
46440	50298	1105	Курганская область, Щучанский район, село Петрушино, Петрушино, 39	t	small
46442	50300	1107	Курганская область, Щучанский район, село Петровское, Чапаева, 7	t	small
46450	50309	1115	Курганская область, Щучанский район, поселок Песчанское, Павших Борцов, 5А	f	medium
46422	50280	1087	Курганская область, Щучанский район, село Отрадное	f	small
46412	50269	1077	Курганская область, Щучанский район, село Нифанка	f	small
46447	50306	1112	Курганская область, Щучанский район, село Николаевка, Советская, 1	f	small
46446	50305	1111	Курганская область, Щучанский район, село Никитино, Никитинская, 18	t	small
46445	50304	1110	Курганская область, Щучанский район, село Михайловка, Центральная, 24А	f	small
46424	50282	1089	Курганская область, Щучанский район, село Медведское	f	medium
46437	50295	1102	Курганская область, Щучанский район, село Майка	f	medium
46420	50278	1085	Курганская область, Щучанский район, поселок Курорт Озеро	f	small
46441	50299	1106	Курганская область, Щучанский район, село Куликово, Центральная, 15А	t	small
46431	50289	1096	Курганская область, Щучанский район, село Красноярское, Цветочная, 4	t	small
46430	50288	1095	Курганская область, Щучанский район, село Косулино, Солнечная, 59	f	small
46413	50270	1078	Курганская область, Щучанский район, село Козино	f	small
46426	50284	1091	Курганская область, Щучанский район, село Клюквенная	t	small
46433	50291	1098	Курганская область, Щучанский район, поселок Каясан, Железнодорожная, 73А	f	medium
46443	50301	1108	Курганская область, Щучанский район, село Калмаково-Миасское, Береговая, 24	t	small
46423	50281	1088	Курганская область, Щучанский район, село Зайково	f	small
46417	50274	1082	Курганская область, Щучанский район, село Даньково	t	small
46415	50272	1080	Курганская область, Щучанский район, село Варгановское	f	small
46429	50287	1094	Курганская область, Щучанский район, село Белоярское, Ленина, 75	f	small
46418	50275	1083	Курганская область, Щучанский район, село Арасланова	t	small
46436	50294	1101	Курганская область, Щучанский район, Алакуль, Привокзальная, 20	t	small
46373	50230	1038	Курганская область, Шумихинский район, село Чесноково, Центральная, 3	t	small
46400	50257	1065	Курганская область, Шумихинский район, село Хохлы, Центральная, 18	t	small
46397	50254	1062	Курганская область, Шумихинский район, село Трусилово, Агеева, 3	f	small
46378	50235	1043	Курганская область, Шумихинский район, село Травяное, Центральная, 13	f	small
46394	50251	1059	Курганская область, Шумихинский район, село Столбово, Центральная, 3	f	small
46380	50237	1045	Курганская область, Шумихинский район, село Стариково, Советская, 3	f	medium
46396	50253	1061	Курганская область, Шумихинский район, село Сажино, Старая, 1	f	small
46395	50252	1060	Курганская область, Шумихинский район, село Птичье, Зеленовка, 2А	f	medium
46374	50231	1039	Курганская область, Шумихинский район, село Прошкино, Первая, 52	f	small
46398	50255	1063	Курганская область, Шумихинский район, село Петухи, Центральная, 52	f	small
46376	50233	1041	Курганская область, Шумихинский район, село Михайловка, Центральная, 13	t	small
46388	50245	1053	Курганская область, Шумихинский район, село Межлесье, Центральная, 5	t	small
46393	50250	1058	Курганская область, Шумихинский район, село Малое Дюрягино, Центральная, 36	f	small
46399	50256	1064	Курганская область, Шумихинский район, село Кушма, Советская, 20	f	small
46379	50236	1044	Курганская область, Шумихинский район, село Куликово, Центральная, 2	t	small
46385	50242	1050	Курганская область, Шумихинский район, село Крутая Горка, Центральная, 7	f	medium
46386	50243	1051	Курганская область, Шумихинский район, село Красный Холм, Рабочая, 21	t	small
46387	50244	1052	Курганская область, Шумихинский район, село Котлик, Озерная, 15	t	small
46383	50240	1048	Курганская область, Шумихинский район, село Кипель, Шиловская, 4	f	small
46381	50238	1046	Курганская область, Шумихинский район, село Карачельское, Центральная, 84	f	medium
46390	50247	1055	Курганская область, Шумихинский район, село Карандашово, Набережная, 4	f	small
46389	50246	1054	Курганская область, Шумихинский район, село Каменное, Парковое кольцо, 2	f	small
46384	50241	1049	Курганская область, Шумихинский район, село Горшково, Длинная, 12	t	small
46375	50232	1040	Курганская область, Шумихинский район, село Галкино, Калинина, 1	f	medium
46382	50239	1047	Курганская область, Шумихинский район, село Большое Дюрягино, Центральная, 32	f	small
46377	50234	1042	Курганская область, Шумихинский район, село Большая Рига, Центральная, 1	f	medium
46391	50248	1056	Курганская область, Шумихинский район, село Благовещенское, Молодежная, 31	t	small
46392	50249	1057	Курганская область, Шумихинский район, село Березово, Центральная, 34	f	small
46354	50211	1018	Курганская область, Шатровский район, село Яутла, Школьная, 9	f	small
46353	50210	1017	Курганская область, Шатровский район, село Широково, Советская, 26	f	small
46323	50179	987	Курганская область, Шатровский район, поселок Шатрово, Элеваторная, 10	f	medium
46322	50178	986	Курганская область, Шатровский район, поселок Шатрово, Федосеева, 94	f	medium
46320	50176	984	Курганская область, Шатровский район, поселок Шатрово, Федосеева, 64	f	large
46201	50058	865	Курганская область, Шатровский район, поселок Шатрово, Федосеева, 55	f	medium
46492	50350	1158	Курганская область, Шадринский район, село Прогресс, Садовая, 17	f	small
46321	50177	985	Курганская область, Шатровский район, поселок Шатрово, 30 лет Победы, 1	f	large
46306	50162	970	Курганская область, Шатровский район, село Черное Макарово, Рабочая, 9А	f	small
46350	50207	1014	Курганская область, Шатровский район, село Терсюкское, А.И. Киселева, 24	f	medium
46348	50205	1012	Курганская область, Шатровский район, село Спицыно, Мира, 85	f	small
46347	50204	1011	Курганская область, Шатровский район, село Сопинина, Велесова, 16	f	small
45902	49754	561	Курганская область, Шатровский район, село Смолина, Северная, 5	f	small
46346	50203	1010	Курганская область, Шатровский район, село Сладчанка, Садовая, 33	f	small
46344	50201	1008	Курганская область, Шатровский район, село Самохвалово, Школьная, 13	f	medium
46331	50187	995	Курганская область, Шатровский район, село Саломатова, Центральная, 21	t	small
46352	50209	1016	Курганская область, Шатровский район, село Портнягино, Зеленая, 102	t	small
45903	49755	562	Курганская область, Шатровский район, село Поротова, Центральная, 17	f	small
46343	50200	1007	Курганская область, Шатровский район, село Ожогино, Центральная, 38	f	small
46342	50199	1006	Курганская область, Шатровский район, село Мостовское, Школьная, 28	f	medium
45904	49756	563	Курганская область, Шатровский район, поселок Мехонское, Мира, 4	f	small
46339	50196	1003	Курганская область, Шатровский район, поселок Мехонское, Ленина, 29	t	small
46337	50193	1001	Курганская область, Шатровский район, поселок Мехонское, Красных Уральцев, 15	f	large
46338	50195	1002	Курганская область, Шатровский район, село Ленская, И. Сташкова, 1	f	small
46335	50191	999	Курганская область, Шатровский район, село Кызылбай, Центральная, 73	f	small
46336	50192	1000	Курганская область, Шатровский район, поселок Кызылбай, Газовик, 26	f	small
46349	50206	1013	Курганская область, Шатровский район, село Коршунова, Лесная, 18	t	small
46334	50190	998	Курганская область, Шатровский район, село Кондинское, Центральная, 11	f	small
46333	50189	997	Курганская область, Шатровский район, село Кодское, Школьная, 1	f	medium
46340	50197	1004	Курганская область, Шатровский район, село Ключи, Береговая, 18	f	small
46327	50183	991	Курганская область, Шатровский район, село Каширцево, Механизаторов, 13	f	small
46332	50188	996	Курганская область, Шатровский район, село Камышевка, Ленина, 11	f	medium
46345	50202	1009	Курганская область, Шатровский район, село Ирюм, Свободная, 14	t	small
46329	50185	993	Курганская область, Шатровский район, село Ильино, Центральная, 8	f	medium
46328	50184	992	Курганская область, Шатровский район, село Изъедугино, Школьная, 15	f	small
46341	50198	1005	Курганская область, Шатровский район, село Духовка, Центральная, 19	t	small
46330	50186	994	Курганская область, Шатровский район, село Дружинина, Центральная, 2	t	small
46324	50180	988	Курганская область, Шатровский район, село Дворцы, Центральная, 8	f	small
46326	50182	990	Курганская область, Шатровский район, село Дальняя Кубасова, Заречная, 151	f	small
46351	50208	1015	Курганская область, Шатровский район, село Воротниково, Пролетарская, 25	t	small
46325	50181	989	Курганская область, Шатровский район, поселок Барино, Поселковая, 27	f	large
46307	50163	971	Курганская область, Шадринский район, село Юлдус, Мира, 12	f	medium
46493	50351	1159	Курганская область, Шадринский район, село Шахматово, Гусиная, 12	t	small
46289	50144	953	Курганская область, Шадринский район, село Чистопрудное, Ленина, 19	f	medium
46288	50143	952	Курганская область, Шадринский район, село Черемисское, Советская, 14	f	small
46269	50124	933	Курганская область, Шадринский район, село Фрунзе, Кольцевая, 5	t	small
46312	50168	976	Курганская область, Шадринский район, село Тюленёво, Механизаторов, 7	f	small
46309	50165	973	Курганская область, Шадринский район, село Титова, Садовая, 31	t	small
46315	50171	979	Курганская область, Шадринский район, село Тарасова, Советская, 5	f	small
46292	50147	956	Курганская область, Шадринский район, село Сухринское, Школьная, 58	f	medium
46317	50173	981	Курганская область, Шадринский район, село Сосновское, Ленина, 1	f	small
46291	50146	955	Курганская область, Шадринский район, село Соровское, пер. Центральный, 2	f	small
46308	50164	972	Курганская область, Шадринский район, село Сибирки, Гизатуллина, 32А 	t	small
46274	50129	938	Курганская область, Шадринский район, село Просвет, Зелёная, 18	t	small
46283	50138	947	Курганская область, Шадринский район, Понькино, Кирова, 2	f	small
46495	50353	1161	Курганская область, Шадринский район, поселок Погорелка, ПМК3	f	small
46491	50349	1157	Курганская область, Шадринский район, поселок Погорелка, Северная, 17	f	medium
46301	50157	965	Курганская область, Шадринский район, поселок Погорелка, Исетская, 8	f	medium
46278	50133	942	Курганская область, Шадринский район, село Погадайское, Рабочая, 2	f	small
46268	50123	932	Курганская область, Шадринский район, село Песчанотаволжанское, Рабочая, 1	f	small
46314	50170	978	Курганская область, Шадринский район, поселок Ольховка, Ленина, 152	f	large
46275	50130	939	Курганская область, Шадринский район, село Октябрь, Будённого, 3	f	small
46290	50145	954	Курганская область, Шадринский район, село Нижнеполевское, Макеева, 26	f	small
46310	50166	974	Курганская область, Шадринский район, Неонилинское, Центральная, 61	f	small
46294	50149	958	Курганская область, Шадринский район, село Мыльниково, Набережная, 25А	f	medium
45901	49753	560	Курганская область, Шадринский район, село Могилева, Поселковая, 1, 2	t	small
46273	50128	937	Курганская область, Шадринский район, село Мингали, Трудовая, 70	t	small
46302	50158	966	Курганская область, Шадринский район, село Маслянское, Советская, 54	f	medium
46296	50151	960	Курганская область, Шадринский район, село Мальцево, Ленина, 41	f	medium
46281	50136	945	Курганская область, Шадринский район, село Макарово, Труда, 3А	f	small
46285	50140	949	Курганская область, Шадринский район, село Красномыльское, Набережная, 40Б	f	medium
46282	50137	946	Курганская область, Шадринский район, поселок Красная Нива, Зелёная Роща, 2	f	large
46277	50132	941	Курганская область, Шадринский район, поселок Красная Звезда, Ленина, 31	f	medium
46490	50348	1156	Курганская область, Шадринский район, село Комсомольская, Новая, 2	t	small
46272	50127	936	Курганская область, Шадринский район, село Колесниково, Береговая, 49	t	small
46304	50160	968	Курганская область, Шадринский район, село Кокорина, Уральская, 59	t	small
46284	50139	948	Курганская область, Шадринский район, село Коврига, Барыкина, 34А	f	small
46300	50156	964	Курганская область, Шадринский район, село Ключи, Мира, 9	f	medium
46295	50150	959	Курганская область, Шадринский район, поселок Канаши, 8 Марта	f	large
46313	50169	977	Курганская область, Шадринский район, село Ичкино, Советская, 11	f	small
46305	50161	969	Курганская область, Шадринский район, село Ильтяково, Молодёжная, 17	f	small
46298	50154	962	Курганская область, Шадринский район, село Иванищевское, Молодёжная, 2	t	small
46318	50174	982	Курганская область, Шадринский район, село Зеленоборское, пер. Школьный, 2	f	small
46293	50148	957	Курганская область, Шадринский район, село Замараевское, Восточная, 38	t	small
46494	50352	1160	Курганская область, Шадринский район, село Завьялова, Мира, 3	t	small
46280	50135	944	Курганская область, Шадринский район, село Жеребенкова, Труда, 12	t	small
46276	50131	940	Курганская область, Шадринский район, поселок Демьяна Бедного, Советская, 2	t	small
46279	50134	943	Курганская область, Шадринский район, село Демино, Ленина, 14	t	small
46316	50172	980	Курганская область, Шадринский район, село Глубокая, Капитана Быкова, 36	f	small
46299	50155	963	Курганская область, Шадринский район, Ганино, Садовая, 12кв.1	f	small
46303	50159	967	Курганская область, Шадринский район, село Верхозино, Советская, 75	f	medium
46286	50141	950	Курганская область, Шадринский район, село Верхняя Полевая, Мира, 36	f	medium
46311	50167	975	Курганская область, Шадринский район, село Борчаниново, Центральная, 43	f	small
46270	50125	934	Курганская область, Шадринский район, село Большое Кабанье, Ленина, 17	t	small
46271	50126	935	Курганская область, Шадринский район, поселок Батурино, Гагарина, 7	f	large
46287	50142	951	Курганская область, Шадринский район, село Барневское, Железнодорожная, 9	t	small
46319	50175	983	Курганская область, Шадринский район, село Байрак, Советская, 6	t	small
46297	50153	961	Курганская область, Шадринский район, село Агапино, Зелёная, 26	f	small
46508	50365	1174	Курганская область, Частоозерский район, село Шестаково, Луговая, 29, кв.1	t	small
46267	50122	931	Курганская область, Частоозерский район, село Чердынцево, Центральная, 58	f	small
77106	2779	169	Томская область, Томск, Ференца Мюнниха, 12/1	f	large
46256	50113	920	Курганская область, Частоозерский район, село Чебачье, Садовая, 17	t	small
46251	50108	915	Курганская область, Частоозерский район, поселок Частоозерье, Энергетиков, 9	f	medium
46512	50369	1178	Курганская область, Частоозерский район, поселок Частоозерье, Октябрьская, 186	f	small
46250	50107	914	Курганская область, Частоозерский район, поселок Частоозерье, Октябрьская, 139	f	medium
46249	50106	913	Курганская область, Частоозерский район, поселок Частоозерье, Береговая, 4	f	medium
46265	50120	929	Курганская область, Частоозерский район, Сивково, Советская, 17	f	small
46263	50118	927	Курганская область, Частоозерский район, село Песьяное, Береговая, 22	t	small
46259	50114	923	Курганская область, Частоозерский район, село Окуневка, Мира, 21	t	small
46260	50115	924	Курганская область, Частоозерский район, село Новотроицкое, Красноармейская, 11	f	small
46509	50366	1175	Курганская область, Частоозерский район, село Малодолгие, Школьная, 13	f	small
46264	50119	928	Курганская область, Частоозерский район, село Лиханово, Советская, 1	t	small
46266	50121	930	Курганская область, Частоозерский район, село Лебяжье, Зелёная, 19	t	small
46253	50110	917	Курганская область, Частоозерский район, село Казанцево, Лесная, 19	t	small
46262	50117	926	Курганская область, Частоозерский район, село Долгие, Советская, 1	f	small
46252	50109	916	Курганская область, Частоозерский район, село Денисова, Центральная, 54	t	small
46261	50116	925	Курганская область, Частоозерский район, село Гомзино, Центральная, 15	t	small
46257	50023	921	Курганская область, Частоозерский район, село Восточное, Пушкина, 2	f	small
46258	49932	922	Курганская область, Частоозерский район, село Волчье, Центральная, 25	f	small
46255	50112	919	Курганская область, Частоозерский район, село Бутырино, Центральная, 31	f	small
46254	50111	918	Курганская область, Частоозерский район, село Беляковское, Калинина, 14	t	small
46241	50098	905	Курганская область, Целинный район, село Чалкино, Береговая, 41кв.2	t	small
46202	50059	866	Курганская область, Целинный район, Целинное, 8 Марта , 59	f	large
46203	50060	867	Курганская область, Целинный район, поселок Целинное, Кооперативная, 23	f	medium
46214	50070	878	Курганская область, Целинный район, село Фроловка, Центральная, 13	t	small
46216	50072	880	Курганская область, Целинный район, село Усть-Уйское, Киров, 35	f	medium
46237	50094	901	Курганская область, Целинный район, село Трехозерки, Школьный переулок, 12	f	small
46232	50089	896	Курганская область, Целинный район, село Становое, Центральная, 41	f	small
46231	50088	895	Курганская область, Целинный район, село Сетово, Центральная, 49	f	small
46215	50071	879	Курганская область, Целинный район, село Рыбное, Школьная, 17	f	small
46208	50064	872	Курганская область, Целинный район, село Рачеевка, Школьня, 2	f	small
46244	50102	908	Курганская область, Целинный район, село Пруды, Клубная, 1	t	small
46213	50069	877	Курганская область, Целинный район, село Приозерная, Притобольная, 8	t	small
46239	50096	903	Курганская область, Целинный район, село Полынный Лог, Лесная, 13, кв.1	t	small
46233	50090	897	Курганская область, Целинный район, поселок Половинное, Школьная, 26	f	small
46234	50091	898	Курганская область, Целинный район, поселок Половинное, Советская, 53	f	medium
46218	50075	882	Курганская область, Целинный район, село Подуровка, Береговая, 15	t	small
46219	50076	883	Курганская область, Целинный район, село Пески, Ленина, 4	f	medium
46227	50084	891	Курганская область, Целинный район, Первомайка, Здание конторы бригады № 2 ЗАО Куйбышевское	t	small
46228	50085	892	Курганская область, Целинный район, село Патранино, Школьная, 2	t	small
46225	50082	889	Курганская область, Целинный район, село Николаевка, Центральная, 22	t	small
46220	50077	884	Курганская область, Целинный район, село Молоденки, Конторская, 1	t	small
46238	50095	902	Курганская область, Целинный район, село Михалево, Советская, 1	f	medium
46207	50063	871	Курганская область, Целинный район, село Матвеевка, Клубная, 8	f	medium
46243	50101	907	Курганская область, Целинный район, село Марс, Школьная, 1, кв.2	f	small
46226	50083	890	Курганская область, Целинный район, село Мануйлово	t	small
46240	50097	904	Курганская область, Целинный район, село Луговое, Большая, 57	t	small
77105	2779	168	Томская область, Томск, Ференца Мюнниха, 12/1	f	large
46230	50087	894	Курганская область, Целинный район, село Листвянка, Советская, 22	t	small
46224	50081	888	Курганская область, Целинный район, село Кременевка, Центральная, 13	t	small
46217	50073	881	Курганская область, Целинный район, село Красный Октябрь, Речная, 10	t	small
46242	50100	906	Курганская область, Целинный район, поселок Костыгин Лог, Строителей, 5	f	medium
46229	50086	893	Курганская область, Целинный район, село Косолапово, Школьная, 11	f	medium
46222	50079	886	Курганская область, Целинный район, поселок Кислянка, Подорожко, 28	f	small
46221	50078	885	Курганская область, Целинный район, поселок Кислянка, Заречная, 49	f	small
46212	50068	876	Курганская область, Целинный район, село Казак-Кочердык, Советская, 6	f	medium
46211	50067	875	Курганская область, Целинный район, село Иванково, Школьная, 5	f	small
46245	50103	909	Курганская область, Целинный район, село Зеленая Сопка, Центральная, 3	t	small
46210	50066	874	Курганская область, Целинный район, село Заманилки, пер. Школьный, 4	f	small
46206	50062	870	Курганская область, Целинный район, село Дулино, Центральная, 50	f	small
46235	50092	899	Курганская область, Целинный район, село Дудино, им. В. Пяткова, 34	f	small
46236	50093	900	Курганская область, Целинный район, село Воздвиженка, Школьная, 3	f	small
46209	50065	873	Курганская область, Целинный район, село Большое Дубровное, Школьная, 5	f	small
46223	50080	887	Курганская область, Целинный район, село Белоозерки, Лесная, 1	t	small
46189	50045	853	Курганская область, Сафакулевский район, село Яланское, Ленина, 12	f	small
46193	50050	857	Курганская область, Сафакулевский район, село Сулюклино, Колхозная, 12	f	medium
46181	50037	845	Курганская область, Сафакулевский район, село Сулейманово, Ленина, 2	f	medium
46187	50043	851	Курганская область, Сафакулевский район, село Субботино	f	small
46183	50039	847	Курганская область, Сафакулевский район, село Сокольники, Центральная, 6	t	small
46198	50055	862	Курганская область, Сафакулевский район, поселок Сафакулево, Энергетиков, 1	f	medium
46199	50056	863	Курганская область, Сафакулевский район, поселок Сафакулево, Чапаева, 1а	f	large
46197	50054	861	Курганская область, Сафакулевский район, поселок Сафакулево, Ленина, 11	f	small
46176	50032	840	Курганская область, Сафакулевский район, Сарт-Абдрашево, Октябрьская, 40	f	medium
46180	50036	844	Курганская область, Сафакулевский район, село Сарт-Абдрашево, Больничная улица, 1А	f	small
46178	50034	842	Курганская область, Сафакулевский район, Преображенка, Школьная, 4	t	small
46174	50030	838	Курганская область, Сафакулевский район, село Озерная, Набережная, 2в	t	small
46184	50040	848	Курганская область, Сафакулевский район, село Надеждинка, Школьная, 2	f	small
46188	50044	852	Курганская область, Сафакулевский район, село Мурзабаева, Центральная, 32	t	small
46195	50052	859	Курганская область, Сафакулевский район, село Мартыновка, Труда, 16	f	small
46170	50026	834	Курганская область, Сафакулевский район, село Мансурово, Школьная, 6	f	small
46191	50047	855	Курганская область, Сафакулевский район, село Максимовка, Братьев Михолап, 1	t	small
46169	50025	833	Курганская область, Сафакулевский район, село Карасево, 70 Лет Октября, 9	f	small
46172	50028	836	Курганская область, Сафакулевский район, село Камышное, Комсомольская, 27	f	medium
46190	50046	854	Курганская область, Сафакулевский район, село Калмык-Абдрашево, Школьная, 31	f	small
46182	50038	846	Курганская область, Сафакулевский район, село Бурматово, Центральная, 2	t	small
46186	50042	850	Курганская область, Сафакулевский район, село Бугуй, Школьная, 6	t	small
46168	50024	832	Курганская область, Сафакулевский район, Боровичи (Боровое), Центральная, 96	f	small
46173	50029	837	Курганская область, Сафакулевский район, село Большое Султаново, Школьная, 25	t	small
46196	50053	860	Курганская область, Сафакулевский район, село Бикбирды, Заречная, 11	t	small
46192	50049	856	Курганская область, Сафакулевский район, село Белое Озеро (Белое), Аптыкаевская, 10	f	small
46179	50035	843	Курганская область, Сафакулевский район, село Баязитово, Школьная, 12	t	small
46167	50022	831	Курганская область, Сафакулевский район, село Бахарево, Школьная, 29А	t	small
46185	50041	849	Курганская область, Сафакулевский район, село Бакаево, Школьная, 21а	t	small
46177	50033	841	Курганская область, Сафакулевский район, село Азналино, Зелёная, 15	f	small
46171	50027	835	Курганская область, Сафакулевский район, село Аджитарово	f	small
46194	50051	858	Курганская область, Сафакулевский район, село Абултаево, Школьная, 1	f	small
46163	50018	827	Курганская область, Притобольный район, поселок сельского типа Боровлянка	f	medium
46166	50021	830	Курганская область, Притобольный район, село Ясная	t	small
46148	50002	811	Курганская область, Притобольный район, село Ярославское	f	small
46155	50009	819	Курганская область, Притобольный район, село Ялым	f	small
46142	49996	805	Курганская область, Притобольный район, село Чернавское	f	small
46146	50000	809	Курганская область, Притобольный район, село Утятское	f	medium
46152	50006	816	Курганская область, Притобольный район, село Туманова	t	small
46143	49997	806	Курганская область, Притобольный район, село Раскатиха	f	medium
46165	50020	829	Курганская область, Притобольный район, село Притобольное	f	small
46162	50017	826	Курганская область, Притобольный район, село Плотниково	f	medium
46151	50005	814	Курганская область, Притобольный район, село Патраки	t	small
46149	50003	812	Курганская область, Притобольный район, село Осиновка	f	small
46147	50001	810	Курганская область, Притобольный район, село Обухово	f	small
46157	50012	821	Курганская область, Притобольный район, село Обрядовка	f	small
46156	50011	820	Курганская область, Притобольный район, село Новокаминка, Центральная, 14	t	small
46161	50016	825	Курганская область, Притобольный район, село Нижняя Алабуга	f	small
46145	49999	808	Курганская область, Притобольный район, село Нагорское	f	medium
46164	50019	828	Курганская область, Притобольный район, село Мочалово	f	small
46141	49995	804	Курганская область, Притобольный район, поселок Межборное	f	medium
46144	49998	807	Курганская область, Притобольный район, село Камышное	f	small
46159	50014	823	Курганская область, Притобольный район, село Ершовка	t	small
46150	50004	813	Курганская область, Притобольный район, село Давыдовка	f	small
46139	49993	802	Курганская область, Притобольный район, поселок Глядянское, Красноармейская, 17	f	large
46138	49992	801	Курганская область, Притобольный район, поселок Глядянское, Красноармейская, 38	f	large
46137	49991	800	Курганская область, Притобольный район, поселок Глядянское, Красноармейская, 44	f	large
46158	50013	822	Курганская область, Притобольный район, село Гладковское	f	small
46154	50008	818	Курганская область, Притобольный район, село Водный	f	small
46153	50007	817	Курганская область, Притобольный район, село Верхнеберезово	f	small
46160	50015	824	Курганская область, Притобольный район, село Банщиково	t	small
46140	49994	803	Курганская область, Притобольный район, село Арсеновка	f	medium
46134	49988	796	Курганская область, Половинский район, Яровое, Центральная, 1	f	small
46131	49985	793	Курганская область, Половинский район, село Чулошное, Советская, 1	f	small
46129	49983	791	Курганская область, Половинский район, село Чернавчик, Береговая, 13	f	small
46130	49984	792	Курганская область, Половинский район, село Хлупово, Садиковский, 2	f	medium
46122	49976	784	Курганская область, Половинский район, село Филиппово	t	small
46133	49987	795	Курганская область, Половинский район, село Успенка, 22, кв. 1	t	small
46128	49982	790	Курганская область, Половинский район, село Сухмень, Ленина, 13	f	small
46127	49981	789	Курганская область, Половинский район, село Сумки, станция Сумки	f	small
46125	49979	787	Курганская область, Половинский район, село Сумки, Ленинская, 45	f	medium
46115	49969	777	Курганская область, Половинский район, село Романово, Центральная, 34А	f	small
46123	49977	785	Курганская область, Половинский район, село Привольное, Озерная, 1	f	small
46116	49970	778	Курганская область, Половинский район, поселок Половинное, Советская, 50	f	medium
46117	49971	779	Курганская область, Половинский район, поселок Половинное, Победы, 12	f	large
46118	49972	780	Курганская область, Половинский район, поселок Половинное, Карла Маркса, 14	f	large
46114	49968	776	Курганская область, Половинский район, село Пищальное, Ленина, 18	f	small
46121	49975	783	Курганская область, Половинский район, село Петровка	f	small
45943	49795	602	Курганская область, Лебяжьевский район, село Кузинка, 14	t	small
46111	49965	773	Курганская область, Половинский район, село Новые Байдары, Молодежная, 2	f	small
46132	49986	794	Курганская область, Половинский район, село Новая Украинка, 23	t	small
46110	49964	772	Курганская область, Половинский район, село Менщиково, Советская, 31	t	small
46112	49966	774	Курганская область, Половинский район, село Марай, Школьная, 2	f	small
46126	49980	788	Курганская область, Половинский район, село Малодубровное, улица Победы, 71	t	small
46136	49990	798	Курганская область, Половинский район, село Казенное, Веселая, 14	t	small
46113	49967	775	Курганская область, Половинский район, село Жилино, Чуйкова, 27	t	small
46120	49974	782	Курганская область, Половинский район, село Дубровка, Сиреневая, 25	f	small
46109	49963	771	Курганская область, Половинский район, село Воскресенское, Советская, 43	f	small
46124	49978	786	Курганская область, Половинский район, село Воздвиженка	t	small
46108	49962	770	Курганская область, Половинский район, село Васильевка, Молодежная, 10, кв.2	f	small
46107	49961	769	Курганская область, Половинский район, село Булдак, Школьная, 18	f	small
46106	49960	768	Курганская область, Половинский район, село Башкирское, Ленина, 39	f	medium
46135	49989	797	Курганская область, Половинский район, село Батырево	t	small
46105	49959	767	Курганская область, Половинский район, село Байдары, Школьная, 43	f	small
46091	49945	752	Курганская область, Петуховский район, село Утчанское, Озёрная, 16	t	small
46097	49951	758	Курганская область, Петуховский район, село Троицкое, Молодежная, 6	f	small
46063	49916	722	Курганская область, Петуховский район, село Стрельцы, Озёрная, 31	f	small
46104	49958	765	Курганская область, Петуховский район, село Староберезово, Центральная, 4/1	t	small
46102	49956	763	Курганская область, Петуховский район, село Рынки, Школьная, 2	f	small
46089	49943	750	Курганская область, Петуховский район, село Пьянково, Железнодорожная, 3	t	small
46101	49955	762	Курганская область, Петуховский район, село Подувальная, Школьная, 13/2	t	small
46075	49928	734	Курганская область, Петуховский район, Петухово, здание ИП Кривоногов	f	small
46099	49953	760	Курганская область, Петуховский район, село Петухово, Набережная, 13	f	small
46088	49942	749	Курганская область, Петуховский район, село Песьяное, Московская, 22/1	t	small
46095	49949	756	Курганская область, Петуховский район, село Пашково, Школьная, 13	f	small
46094	49948	755	Курганская область, Петуховский район, поселок Октябрьское, Озёрная, 9	f	medium
46081	49935	742	Курганская область, Петуховский район, село Новое Ильинское, Молодежная, 31	f	small
46090	49944	751	Курганская область, Петуховский район, село Новогеоргиевка 2-я, Центральная, 35	f	small
46103	49957	764	Курганская область, Петуховский район, село Новогеоргиевка 1-я, Тополиная, 2/2	t	small
46087	49941	748	Курганская область, Петуховский район, село Новоберезово, Береговая, 60	f	small
46078	49931	739	Курганская область, Петуховский район, село Новая Лебяжка, Новолебяжьевская, 30	t	small
46084	49938	745	Курганская область, Петуховский район, село Матасы, Береговая, 3А	f	small
46496	50354	1162	Курганская область, Петуховский район, поселок Курорт Озеро Медвежье, гл. корп. Курорта Озеро Медвежье	f	small
46086	49940	747	Курганская область, Петуховский район, Курорт ''Озеро Медвежье'', Мира, 1	f	medium
46098	49952	759	Курганская область, Петуховский район, село Казанцевское, Школьная, 41	t	small
46082	49936	743	Курганская область, Петуховский район, село Зотино, Школьная, 54	f	small
46092	49946	753	Курганская область, Петуховский район, село Золотовка, контора ООО Северное	t	small
46080	49934	741	Курганская область, Петуховский район, село Жидки, Новая, 18	f	small
46085	49939	746	Курганская область, Петуховский район, село Горбуново, Привокзальная, 8	t	small
46083	49937	744	Курганская область, Петуховский район, село Горбунешное, Школьная, 17	t	small
46093	49947	754	Курганская область, Петуховский район, село Воробьи, Плакуновская, 19	t	small
46096	49950	757	Курганская область, Петуховский район, село Буранное, Приозёрная, 3	t	small
46100	49954	761	Курганская область, Петуховский район, село Большое Приютное, С. Баева, 65	f	small
46077	49930	738	Курганская область, Петуховский район, село Большое Каменное, Набережная, 49	f	small
77127	2796	192	Россия, Томская область	f	large
46079	49933	740	Курганская область, Петуховский район, село Большое Гусиное, Северная, 9А/5	f	small
46064	49917	723	Курганская область, Петуховский район, село Богданы, Советская, 29	t	small
46076	49929	735	Курганская область, Петуховский район, село Актабан, Советская, 17	f	medium
46039	49892	698	Курганская область, Мокроусовский район, Щигры, Молодежная, 28	f	small
46061	49914	720	Курганская область, Мокроусовский район, село Шелепово, Школьная, 10	f	small
46034	49887	693	Курганская область, Мокроусовский район, село Чесноково, 28Б	t	small
46054	49907	713	Курганская область, Мокроусовский район, село Утичье, 70 лет Октября, 7а	f	small
46038	49891	697	Курганская область, Мокроусовский район, село Уварово, Центральная, 20	f	small
46044	49897	703	Курганская область, Мокроусовский район, село Травное, Школьная, 2	f	medium
46055	49908	714	Курганская область, Мокроусовский район, село Тетерье, Школьная, 1А	t	small
46042	49895	701	Курганская область, Мокроусовский район, село Сунгурова, 40 лет Победы, 28	f	small
46048	49901	707	Курганская область, Мокроусовский район, село Старопершино, Школьная, 22	f	small
46057	49910	716	Курганская область, Мокроусовский район, село Рассвет, Вострецова, 4	t	small
46033	49886	692	Курганская область, Мокроусовский район, село Пороги, 37	t	small
46053	49906	712	Курганская область, Мокроусовский район, село Отставное, 17А	t	small
46059	49912	718	Курганская область, Мокроусовский район, село Одино, Октябрьская, 1а	f	small
46047	49900	706	Курганская область, Мокроусовский район, село Новотроицкое, Войкова, 18	t	small
46031	49885	690	Курганская область, Мокроусовский район, поселок Мокроусово, Советская, 1	f	small
46023	49877	682	Курганская область, Мокроусовский район, поселок Мокроусово, Советская, 27	f	small
46027	49881	686	Курганская область, Мокроусовский район, поселок Мокроусово, Сабанина, 15	f	small
46024	49878	683	Курганская область, Мокроусовский район, поселок Мокроусово, Октябрьская, 25	f	small
46029	49883	688	Курганская область, Мокроусовский район, поселок Мокроусово, Механизаторов, 32	f	small
46032	49858	691	Курганская область, Мокроусовский район, поселок Мокроусово, Лесная, 13а	f	small
46028	49882	687	Курганская область, Мокроусовский район, поселок Мокроусово, Куйбышева, 7	f	medium
46026	49880	685	Курганская область, Мокроусовский район, поселок Мокроусово, Береговая, 7А	f	medium
46025	49879	684	Курганская область, Мокроусовский район, поселок Мокроусово, 40 лет Победы, 18	f	medium
46046	49899	705	Курганская область, Мокроусовский район, село Михайловка, Центральная, 7	f	small
46056	49909	715	Курганская область, Мокроусовский район, село Межеумное, Вторая Школьная, 4	t	small
46051	49904	710	Курганская область, Мокроусовский район, село Малое Середкино, 9А	t	small
46043	49896	702	Курганская область, Мокроусовский район, село Малое Песьяново, 28	t	small
46050	49903	709	Курганская область, Мокроусовский район, село Малое Мостовское, 2-я Береговая, 7	f	small
46058	49911	717	Курганская область, Мокроусовский район, село Лопарево, Школьная, 17	f	small
46040	49893	699	Курганская область, Мокроусовский район, село Лапушки, Дружбы, 10	f	small
46060	49913	719	Курганская область, Мокроусовский район, село Куртан, Победы, 14	f	small
46052	49905	711	Курганская область, Мокроусовский район, село Круглое, 40а	t	small
46045	49898	704	Курганская область, Мокроусовский район, село Круглое, 13	t	small
46035	49888	694	Курганская область, Мокроусовский район, село Крепость, переулок Школьный, 2	f	small
46036	49889	695	Курганская область, Мокроусовский район, село Кокарево, Центральная, 27А	t	small
46037	49890	696	Курганская область, Мокроусовский район, село Карпунино, А. Прокопьева, 3	f	small
46049	49902	708	Курганская область, Мокроусовский район, село Дмитриевка, Новая, 4	t	small
46062	49915	721	Курганская область, Мокроусовский район, село Большое Щучье, 14	t	small
46041	49894	700	Курганская область, Мокроусовский район, село Большое Песьяное, 12	t	small
46021	49875	680	Курганская область, Мишкинский район, село Шаламово, Советская, 36	f	small
46011	49865	670	Курганская область, Мишкинский район, село Троицкое (Штанное), Береговая, 21	t	small
46014	49868	673	Курганская область, Мишкинский район, село Сосново, Солнечная, 13	f	small
45654	49502	308	Курганская область, Далматовский район	t	small
46001	49854	660	Курганская область, Мишкинский район, село Сладкокарасинское, Школьная, 12	t	small
45999	49852	658	Курганская область, Мишкинский район, село Сладкое, Станционная, 1	t	small
46018	49872	677	Курганская область, Мишкинский район, село Первомайское, Советская, 5	f	small
46016	49870	675	Курганская область, Мишкинский район, село Островное, Береговая, 21	t	small
46015	49869	674	Курганская область, Мишкинский район, село Новые Пески, Луговая, 28	f	small
46013	49867	672	Курганская область, Мишкинский район, село Мыркайское, Центральная, 43	f	small
46022	49876	681	Курганская область, Мишкинский район, село Мокрушино, Озёрная, 9	t	small
45993	49846	652	Курганская область, Мишкинский район, поселок городского типа Мишкино, Победы, 6	f	medium
45991	49843	650	Курганская область, Мишкинский район, поселок Мишкино, Строительная, 7	f	medium
45992	49845	651	Курганская область, Мишкинский район, поселок Мишкино, Северная, 2	f	small
45995	49848	654	Курганская область, Мишкинский район, поселок Мишкино, Рабоче-крестьянская, 136 А	f	large
45990	49842	649	Курганская область, Мишкинский район, поселок Мишкино, Первомайская, 24	f	large
45989	49841	648	Курганская область, Мишкинский район, поселок Мишкино, Ленина, 1	f	small
45988	49840	647	Курганская область, Мишкинский район, поселок Мишкино, Ленина, 23	f	large
45994	49847	653	Курганская область, Мишкинский район, поселок Мишкино, Заводская, 28	f	small
46017	49871	676	Курганская область, Мишкинский район, село Маслово, Южная, 10	t	small
46012	49866	671	Курганская область, Мишкинский район, село Масли, Новая, 6	f	small
46005	49859	664	Курганская область, Мишкинский район, село Малое Окунево, Сиреневая, 10	f	small
46009	49863	668	Курганская область, Мишкинский район, село Лебяжье, Береговая, 37	t	small
46010	49864	669	Курганская область, Мишкинский район, село Купай, Центральная, 23	f	small
46008	49862	667	Курганская область, Мишкинский район, поселок Краснознаменское, Мира, 5	f	medium
46007	49861	666	Курганская область, Мишкинский район, село Коровье, Ленина, 34	f	small
46510	50367	1176	Курганская область, Мишкинский район, поселок Кирово, Кирова, 52	f	medium
46006	49860	665	Курганская область, Мишкинский район, поселок Кирово, Кирова, 50	f	medium
45996	49849	655	Курганская область, Мишкинский район, село Иванковское, Николаева, 20	f	small
46004	49857	663	Курганская область, Мишкинский район, село Дубровное, Советская, 44	f	medium
46002	49855	661	Курганская область, Мишкинский район, село Гладышево, Центральная, 29	f	small
46019	49873	678	Курганская область, Мишкинский район, село Гаганова, Школьная, 4	t	small
46000	49853	659	Курганская область, Мишкинский район, село Восход, Садовая, 5 Б	f	medium
45998	49851	657	Курганская область, Мишкинский район, село Введенское, Советская, 35	f	medium
45997	49850	656	Курганская область, Мишкинский район, село Варлаково	f	small
46020	49874	679	Курганская область, Мишкинский район, село Бутырское, Центральная, 35	t	small
46003	49856	662	Курганская область, Мишкинский район, село Бутырское, Лесная, 33	t	small
45955	49807	614	Курганская область, Макушинский район, село Ясные Зори, Яснозаринская, 1а	t	small
45968	49820	627	Курганская область, Макушинский район, село Чебаки, Центральная, 7	f	small
45958	49810	617	Курганская область, Макушинский район, село Ударник, Центральная, 5	t	small
45962	49814	621	Курганская область, Макушинский район, село Трюхино, Школьная, 2	f	small
45985	49837	644	Курганская область, Макушинский район, село Требушинное, Береговая, 63	f	small
45966	49818	625	Курганская область, Макушинский район, село Степное, Мира, 5	f	medium
45970	49822	629	Курганская область, Макушинский район, село Слевное, Молодежная, 6а	f	small
45972	49824	631	Курганская область, Макушинский район, село Сетовное, Школьная, 35	f	small
45953	49805	612	Курганская область, Макушинский район, село Садовод, Пролетарская, 11	f	small
45977	49829	636	Курганская область, Макушинский район, Раздолье, Центральная, 9	t	small
45980	49832	639	Курганская область, Макушинский район, село Профинтерн, Дерибасовская, 4	t	small
45978	49830	637	Курганская область, Макушинский район, село Привольное, Центральная, 1	f	small
45963	49815	622	Курганская область, Макушинский район, село Покровка, Центральная, 12	t	small
77033	2692	92	Томская область, Томск, Хмельницкого, 40	f	large
45965	49817	624	Курганская область, Макушинский район, поселок Пионерское, Советская, 7	f	medium
45986	49838	645	Курганская область, Макушинский район, село Пеган, Центральная , 15	t	small
45956	49808	615	Курганская область, Макушинский район, село Обутковское, Т.Дрязгова, 2Б	f	medium
45983	49835	642	Курганская область, Макушинский район, село Неверовское, Лесная, 7	f	small
45984	49836	643	Курганская область, Макушинский район, село Моховое, Молодежная, 15	f	small
45964	49816	623	Курганская область, Макушинский район, село Моршиха, Советская, 14	f	medium
45971	49823	630	Курганская область, Макушинский район, село Мартино, Школьная, 16	f	small
45959	49811	618	Курганская область, Макушинский район, Макушино, Ленина, 133А	f	small
45957	49809	616	Курганская область, Макушинский район, село Копырено, Центральная, 9А	f	small
45976	49828	635	Курганская область, Макушинский район, село Коновалово, Молодежная, 1	f	medium
45981	49833	640	Курганская область, Макушинский район, село Клюквенное, Глинских, 34	f	small
45960	49812	619	Курганская область, Макушинский район, село Казаркино, Школьная, 15	f	small
45974	49826	633	Курганская область, Макушинский район, село Золотое, Центральная, 7	f	small
45954	49806	613	Курганская область, Макушинский район, село Журавлевка, Восточная, 15А	f	small
45973	49825	632	Курганская область, Макушинский район, село Гренадеры, Центральная, 20	f	small
45969	49821	628	Курганская область, Макушинский район, село Братанники, Крестьянская, 14а	t	small
45982	49834	641	Курганская область, Макушинский район, село Бородинка, Мира, 21	t	small
45979	49831	638	Курганская область, Макушинский район, село Большое Курейное, Первомайская, 47	f	medium
45975	49827	634	Курганская область, Макушинский район, село Большое Кривинское, Центральная, 6	t	small
45967	49819	626	Курганская область, Макушинский район, село Басковское, Школьная, 1а	f	small
45961	49813	620	Курганская область, Макушинский район, село Антипино, Центральная, 15	t	small
45940	49792	599	Курганская область, Лебяжьевский район, Юдино, Широкая, 7	t	small
45945	49797	604	Курганская область, Лебяжьевский район, село Черемушки, Садовая, 2	f	small
45946	49798	605	Курганская область, Лебяжьевский район, село Чаешное, Сиреневая, 2	t	small
45916	49768	575	Курганская область, Лебяжьевский район, село Центральное, Ленина, 29	f	medium
45944	49796	603	Курганская область, Лебяжьевский район, село Хутора, Центральная, 64	f	small
45931	49783	590	Курганская область, Лебяжьевский район, село Суерская, Весенняя, 23	t	small
45941	49793	600	Курганская область, Лебяжьевский район, село Речное, Центральная, 3	f	small
45938	49790	597	Курганская область, Лебяжьевский район, село Прилогино, Центральная, 15	f	small
45936	49788	595	Курганская область, Лебяжьевский район, село Плоское, Придорожная, 1	f	small
45929	49781	588	Курганская область, Лебяжьевский район, село Песьяное, Школьная, 4	f	small
45925	49777	584	Курганская область, Лебяжьевский район, село Островное, Школьная, 2	t	small
45933	49785	592	Курганская область, Лебяжьевский район, село Налимово, Садовая, 1, кв. 2	f	small
45930	49782	589	Курганская область, Лебяжьевский район, село Менщиково, Центральная, 51	f	small
45927	49779	586	Курганская область, Лебяжьевский район, поселок Лопатки, Комсомольская, 2	f	small
45928	49780	587	Курганская область, Лебяжьевский район, поселок Лопатки, Карла Маркса, 30	f	medium
45924	49776	583	Курганская область, Лебяжьевский район, село Лисье, Молодежная, 7	f	small
45935	49787	594	Курганская область, Лебяжьевский район, Лебяжье 1-е, Кривина, 2	f	small
45907	49759	566	Курганская область, Лебяжьевский район, поселок Лебяжье, Спортивная, 32	f	medium
45912	49764	571	Курганская область, Лебяжьевский район, поселок Лебяжье, Пушкина, 23	f	medium
45910	49762	569	Курганская область, Лебяжьевский район, поселок Лебяжье, Пушкина, 17	f	large
45913	49765	572	Курганская область, Лебяжьевский район, поселок Лебяжье, Первомайская, 11	f	medium
45909	49761	568	Курганская область, Лебяжьевский район, поселок Лебяжье, Карла Маркса, 87	f	medium
45908	49760	567	Курганская область, Лебяжьевский район, поселок Лебяжье, Железнодорожная, 124	f	medium
45923	49775	582	Курганская область, Лебяжьевский район, село Кукушкино, Советская, 23	t	small
45932	49784	591	Курганская область, Лебяжьевский район, село Кузнецово, Озерная, 8	t	small
45939	49791	598	Курганская область, Лебяжьевский район, село Красная Горка, Зеленая, 2	t	small
45922	49774	581	Курганская область, Лебяжьевский район, село Камышное, Озёрная, 46	f	small
45920	49772	579	Курганская область, Лебяжьевский район, село Калашное, Центральная, 6	f	small
45942	49794	601	Курганская область, Лебяжьевский район, село Желтики, 34	t	small
45918	49770	577	Курганская область, Лебяжьевский район, село Дубровное, Центральная, 34	f	small
45934	49786	593	Курганская область, Лебяжьевский район, село Головное, Школьная, 3	f	small
45906	49758	565	Курганская область, Лебяжьевский район, село Верхнеглубокое, Молодёжная, 5	f	small
45919	49771	578	Курганская область, Лебяжьевский район, Василки, 1	f	medium
45915	49767	574	Курганская область, Лебяжьевский район, село Большое Моховое, Молодежная, 1	f	small
45937	49789	596	Курганская область, Лебяжьевский район, село Белянино, Центральная, 6	f	small
45917	49769	576	Курганская область, Лебяжьевский район, село Балакуль, Центральная, 19	f	small
45926	49778	585	Курганская область, Лебяжьевский район, село Баксары, Южная, 18	t	small
45914	49766	573	Курганская область, Лебяжьевский район, село Арлагуль, Центральная, 64, кв.2	f	small
45921	49773	580	Курганская область, Лебяжьевский район, село Александровка, Зеленая, 9	t	small
45886	49737	545	Курганская область, Куртамышский район, село Ярки, Центральная, 1	f	small
45867	49717	526	Курганская область, Куртамышский район, село Язево, Северная, 7	t	small
45870	49720	529	Курганская область, Куртамышский район, село Чесноковка, Школьная, 2	t	small
45877	49727	536	Курганская область, Куртамышский район, село Черноборье, Школьная, 5А	f	small
45897	49749	556	Курганская область, Куртамышский район, село Угловое, Новая, 15	f	small
45860	49709	519	Курганская область, Куртамышский район, село Сычево, Полевая, 13	f	small
45864	49713	523	Курганская область, Куртамышский район, село Стрижово, Крестьянская, 22А	t	small
45891	49742	550	Курганская область, Куртамышский район, село Степное, Молодёжная, 161	t	small
45873	49723	532	Курганская область, Куртамышский район, село Сосновка, Школьная, 6	t	small
45862	49711	521	Курганская область, Куртамышский район, село Сорокино, Новая, 9	f	small
45893	49745	552	Курганская область, Куртамышский район, поселок Советское, Школьная, 9	f	medium
45892	49744	551	Курганская область, Куртамышский район, село Пушкино, Центральная, 66	f	medium
45857	49706	516	Курганская область, Куртамышский район, село Птичье, Главная, 12	t	small
45888	49739	547	Курганская область, Куртамышский район, село Песьяное, Зеленая, 24	f	medium
45883	49734	542	Курганская область, Куртамышский район, село Перевалово, Школьная, 5	f	small
45887	49738	546	Курганская область, Куртамышский район, село Пепелино, Центральная, 94	f	small
45869	49719	528	Курганская область, Куртамышский район, село Острова, Центральная, 2	f	small
45884	49735	543	Курганская область, Куртамышский район, село Обанино, Центральная, 14	f	small
45856	49705	515	Курганская область, Куртамышский район, село Новая Калиновка, Центральная, 16	t	small
45880	49731	539	Курганская область, Куртамышский район, поселок Нижнее, Садовая, 10	f	medium
45879	49730	538	Курганская область, Куртамышский район, село Маслово, Радужная, 12	f	small
45882	49733	541	Курганская область, Куртамышский район, село Малетино, Центральная, 65	f	small
45890	49741	549	Курганская область, Куртамышский район, село Лебяжье, Центральная, 20	f	small
45845	49694	504	Курганская область, Куртамышский район, Куртамыш, Югова, 2а	f	large
45848	49697	507	Курганская область, Куртамышский район, Куртамыш, XXII партсъезда, 44	f	large
45866	49716	525	Курганская область, Куртамышский район, село Курмыши, Южная, 14А	t	small
45896	49748	555	Курганская область, Куртамышский район, село Красная Звезда, Центральная, 1А	t	small
45878	49728	537	Курганская область, Куртамышский район, село Косулино, Центральная, 6	f	medium
45874	49724	533	Курганская область, Куртамышский район, село Костылево, Школьная, 1А	f	small
45881	49732	540	Курганская область, Куртамышский район, Коновалова, Центральная, 22В	f	small
45895	49747	554	Курганская область, Куртамышский район, село Коминтерн, Центральная, 11А	t	small
45889	49740	548	Курганская область, Куртамышский район, село Ключики, Центральная, 2	f	small
77013	2692	70	Томская область, Томск, Хмельницкого, 40	f	large
45876	49726	535	Курганская область, Куртамышский район, село Клоктухино, Лесная, 31А	f	small
45885	49736	544	Курганская область, Куртамышский район, село Кислое, Центральная, 30	t	small
45872	49722	531	Курганская область, Куртамышский район, село Камыши, Школьная, 8	f	small
45871	49721	530	Курганская область, Куртамышский район, село Каминское, Мичурина, 8	f	small
45868	49718	527	Курганская область, Куртамышский район, село Камаган, Торговый, 6	f	medium
45865	49714	524	Курганская область, Куртамышский район, село Закоулово, Клубный, 6	f	small
45863	49712	522	Курганская область, Куртамышский район, село Закомалдино, Центральная, 11	f	small
45861	49710	520	Курганская область, Куртамышский район, село Жуково, Новая, 1	f	small
45858	49707	517	Курганская область, Куртамышский район, село Долговка, Октябрьская, 4Г	f	medium
45894	49746	553	Курганская область, Куртамышский район, село Добровольное, Центральная, 3А	f	small
45875	49725	534	Курганская область, Куртамышский район, село Вехти, Центральная, 65А	f	small
45859	49708	518	Курганская область, Куртамышский район, село Верхнее, Центральная, 22	f	medium
45855	49704	514	Курганская область, Куртамышский район, село Березово, Школьная, 5	f	small
45854	49703	513	Курганская область, Куртамышский район, село Белоногово, Центральная, 37А	f	small
45825	49674	484	Курганская область, Кетовский район, поселок сельского типа Новая Сидоровка, Садовая, 3	f	large
45797	49646	456	Курганская область, Кетовский район, микрорайон КГСХА, здание ДК КГСХА	f	small
45833	49682	492	Курганская область, Кетовский район, поселок Шмаково, Заречная, 7	f	large
45814	49663	473	Курганская область, Кетовский район, деревня Шкодинское, Заречная, 8	t	small
45837	49686	496	Курганская область, Кетовский район, село Чесноки, Дорожная, 3	f	medium
45830	49679	489	Курганская область, Кетовский район, село Чашинский, Заречная, 34	f	small
46522	50378	1188	Курганская область, Кетовский район, село Усть-Утяк, Дом культуры Санаторий Лесники	f	small
45800	49649	459	Курганская область, Кетовский район, село Усть-Утяк	f	medium
45803	49652	462	Курганская область, Кетовский район, село Темляково, Центральный переулок, 9	f	small
45827	49676	486	Курганская область, Кетовский район, село Сычево, Труда, 6	f	medium
45832	49681	491	Курганская область, Кетовский район, поселок Старый Просвет, Томина, 15	f	medium
45805	49654	464	Курганская область, Кетовский район, село Становая, Фрунзе, 1	f	medium
45811	49660	470	Курганская область, Кетовский район, село Светлые Поляны, 1 микрорайон, 15	f	medium
45840	49689	499	Курганская область, Кетовский район, село Садовое, Ленина, 4Б	f	large
45842	49691	501	Курганская область, Кетовский район, село Романовка, Центральная, 10	f	small
45808	49657	467	Курганская область, Кетовский район, село Ровная, Центральная, 9	f	small
45831	49680	490	Курганская область, Кетовский район, поселок Просвет, Южная, 14	f	large
45796	49645	455	Курганская область, Кетовский район, село Придорожный, Центральная, 4	f	small
45836	49685	495	Курганская область, Кетовский район, село Пименовка, Школьный переулок, 9	f	small
45816	49665	475	Курганская область, Кетовский район, поселок Падеринское, Центральная, 3	f	medium
45834	49683	493	Курганская область, Кетовский район, село Орловка, Сиреневая, 41	f	small
45843	49692	502	Курганская область, Кетовский район, село Новокомогоровка, Береговая, 20, кв.1	f	small
45817	49666	476	Курганская область, Кетовский район, село Новое Лушниково, Центральная, 20	f	small
45807	49656	466	Курганская область, Кетовский район, село Митино, Советская, 15	f	medium
45838	49687	497	Курганская область, Кетовский район, поселок Менщиково, В. Менщикова, 1А	f	large
45806	49655	465	Курганская область, Кетовский район, село Марково, Победы, 11А	f	medium
45810	49659	469	Курганская область, Кетовский район, село Лукино, Приозерная, 85	t	small
45841	49690	500	Курганская область, Кетовский район, село Логоушка, Интернатовская, 1	f	small
45823	49672	482	Курганская область, Кетовский район, село Логоушка, Заречная, 1	f	small
45828	49677	487	Курганская область, Кетовский район, село Логовушка, Советская, 2	f	small
45801	49650	460	Курганская область, Кетовский район, поселок Лесниково, Лицей им. А.В. Тюнина	f	small
45799	49648	458	Курганская область, Кетовский район, поселок Лесниково, Кирова, 28	f	large
45826	49675	485	Курганская область, Кетовский район, село Кропани, Школьный переулок, 2	f	small
45812	49661	471	Курганская область, Кетовский район, поселок Колташево, Почтовая, 23	f	large
45809	49658	468	Курганская область, Кетовский район, село Колесниково, Центральная, 10	f	medium
45793	49642	452	Курганская область, Кетовский район, село Кетово, Ленина, 131	f	large
45792	49641	451	Курганская область, Кетовский район, Кетово, Красина, 21	f	large
45795	49644	454	Курганская область, Кетовский район, село Кетово, Космонавтов, 41	f	large
45791	49640	450	Курганская область, Кетовский район, село Кетово, Космонавтов, 43	f	large
45804	49653	463	Курганская область, Кетовский район, поселок Каширино, Ленина, 23	f	large
45829	49678	488	Курганская область, Кетовский район, поселок Иковка, Миронова, 45	f	large
45815	49664	474	Курганская область, Кетовский район, Залесовский, Лесная, 14	f	small
45813	49662	472	Курганская область, Кетовский район, село Грачево, Озёрная, 42	f	small
45839	49688	498	Курганская область, Кетовский район, село Галишово, Октябрьская, 142	f	small
45821	49670	480	Курганская область, Кетовский район, Введенское, Пушкина, 11	f	large
45824	49673	483	Курганская область, Кетовский район, поселок Введенское, Гоголя, 8Б	f	large
45818	49667	477	Курганская область, Кетовский район, село Большое Чаусово, Пичугина, 3а	f	large
45835	49684	494	Курганская область, Кетовский район, село Большое Раково, Луговая, 14	f	small
45819	49668	478	Курганская область, Кетовский район, село Белый Яр, Совхозная, 2	f	small
45802	49651	461	Курганская область, Кетовский район, село Бараба, Боброва, 109	f	medium
45900	49752	559	Курганская область, Кетовский район, село Балки, ООО Кетовское предприятие по строительству, ремонту и содержанию автомобильных дорог 	f	small
45769	49618	428	Курганская область, Катайский район, село Шутихинское, Школа	f	medium
45759	49607	418	Курганская область, Катайский район, село Шутино	f	small
45790	49639	449	Курганская область, Катайский район, село Чусовая, медпункт	t	small
45765	49614	424	Курганская область, Катайский район, село Черемисское	t	small
45779	49628	438	Курганская область, Катайский район, село Ушаковское, школа	f	small
45767	49616	426	Курганская область, Катайский район, село Улугушское	f	small
45768	49617	427	Курганская область, Катайский район, село Петропавловское, Школа	f	small
45780	49629	439	Курганская область, Катайский район, село Оконечникова, клуб	t	small
45777	49626	436	Курганская область, Катайский район, село Никитинское	t	small
45784	49633	443	Курганская область, Катайский район, село Марай, Дом культуры	f	small
45760	49608	419	Курганская область, Катайский район, село Лукина	f	small
45775	49624	434	Курганская область, Катайский район, село Лобаново, Школа	f	small
45761	49609	420	Курганская область, Катайский район, село Корюково	f	small
45773	49622	432	Курганская область, Катайский район, село Камышино, клуб	t	small
45771	49620	430	Курганская область, Катайский район, село Казанцева	f	small
45778	49627	437	Курганская область, Катайский район, село Ипатова, клуб	f	small
45764	49613	423	Курганская область, Катайский район, поселок Ильинское	f	large
45782	49631	441	Курганская область, Катайский район, село Зырянка, школа	t	small
45789	49638	448	Курганская область, Катайский район, село Заречье	t	small
45763	49612	422	Курганская область, Катайский район, село Гусиное	t	small
45772	49621	431	Курганская область, Катайский район, село Верхняя Теча, средняя школа	f	small
45766	49615	425	Курганская область, Катайский район, село Верхние Пески, школа	t	small
45785	49634	444	Курганская область, Катайский район, село Верхнеключевское, школа	f	medium
45770	49619	429	Курганская область, Катайский район, село Бугаево, начальная школа	f	small
45762	49610	421	Курганская область, Катайский район, село Боровское	f	medium
45783	49632	442	Курганская область, Катайский район, село Борисова, Дом культуры	f	small
45781	49630	440	Курганская область, Катайский район, село Большое Касаргульское, школа	f	small
45776	49625	435	Курганская область, Катайский район, село Басказык	t	small
45774	49623	433	Курганская область, Катайский район, село Анчугово, медпункт	f	small
45711	49559	367	Курганская область, Каргапольский район, село Шахматова, Горная, 25	f	small
45717	49565	373	Курганская область, Каргапольский район, село Чемякина, Центральная, 36	t	small
45721	49569	377	Курганская область, Каргапольский район, село Чаши, Советская, 1	t	small
45738	49586	397	Курганская область, Каргапольский район, поселок Чаши, Советская , 18В	f	large
45737	49585	396	Курганская область, Каргапольский район, село Усть-Миасское, Советская, 19	f	small
45716	49564	372	Курганская область, Каргапольский район, село Тукманное, Центральная, 30	t	small
45736	49584	395	Курганская область, Каргапольский район, село Твердыш, Школьная, 1	t	small
45734	49582	393	Курганская область, Каргапольский район, Тагильская, Октябрьская, 32Б	f	medium
45733	49581	392	Курганская область, Каргапольский район, село Сосновка, Школьная, 1	t	small
45732	49580	390	Курганская область, Каргапольский район, село Соколово, Советская, 15	f	small
45731	49579	389	Курганская область, Каргапольский район, село Северная, Молодежная, 3	f	small
45713	49561	369	Курганская область, Каргапольский район, село Салтосарайская, Дачная, 3	t	small
45730	49578	388	Курганская область, Каргапольский район, село Осиновское, Советская , 1В	f	medium
45729	49577	387	Курганская область, Каргапольский район, село Окуневское, Школьная, 24	f	medium
45728	49576	386	Курганская область, Каргапольский район, село Новоиковское, Центральная, 46	f	small
45745	49593	404	Курганская область, Каргапольский район, село Нечунаева, Исетская, 47	t	small
45707	49555	363	Курганская область, Каргапольский район, село Малышева, Клубная, 22	f	medium
45726	49574	383	Курганская область, Каргапольский район, село Майский, Ленина, 3	f	medium
45725	49573	382	Курганская область, Каргапольский район, поселок Красный Октябрь, Чкалова, 23	f	medium
45722	49570	378	Курганская область, Каргапольский район, поселок Красный Октябрь, Ленина, 99	f	medium
45723	49571	380	Курганская область, Каргапольский район, поселок Красный Октябрь, Заводская, 2	f	medium
45724	49572	381	Курганская область, Каргапольский район, поселок Красный Октябрь, Гагарина, 1	f	medium
46520	50376	1186	Курганская область, Каргапольский район, Ключи, Зеленая, 3А	f	small
46505	50362	1171	Курганская область, Каргапольский район, поселок Каргаполье, Щорса, 3	f	medium
45739	49587	398	Курганская область, Каргапольский район, поселок Каргаполье, Ленина, 14	f	medium
46507	50364	1173	Курганская область, Каргапольский район, поселок Каргаполье, Крупской, 91	f	small
45744	49592	403	Курганская область, Каргапольский район, поселок Каргаполье, Крупской, 67	f	small
45740	49588	399	Курганская область, Каргапольский район, поселок Каргаполье, Калинина, 25	f	medium
45743	49591	402	Курганская область, Каргапольский район, поселок Каргаполье, Горького, 29А	f	medium
46504	50361	1170	Курганская область, Каргапольский район, Каргаполье, Гагарина, 4	f	medium
45742	49590	401	Курганская область, Каргапольский район, поселок Каргаполье, Гагарина, 5	f	medium
45720	49568	376	Курганская область, Каргапольский район, село Зауральская, Вишневая, 3	f	small
45718	49566	374	Курганская область, Каргапольский район, село Журавлево, Лабарешных, 28	f	small
45714	49562	370	Курганская область, Каргапольский район, село Житниковское, Советская , 29А	f	medium
45715	49563	371	Курганская область, Каргапольский район, село Жикина, Лесная, 37	t	small
45712	49560	368	Курганская область, Каргапольский район, поселок Долговское, Победы, 130	f	medium
45706	49554	362	Курганская область, Каргапольский район, село Деулина, Центральная, 15	f	small
45735	49583	394	Курганская область, Каргапольский район, село Дачный, Советская, 8	t	small
45709	49557	365	Курганская область, Каргапольский район, село Вяткино, Комсомольская, 8А	f	small
45710	49558	366	Курганская область, Каргапольский район, село Володина, Механизаторов, 22А	f	small
45708	49556	364	Курганская область, Каргапольский район, село Брылино, Советская, 2	f	medium
45705	49553	361	Курганская область, Каргапольский район, село Большое Банниково, Советская, 43	f	small
45719	49567	375	Курганская область, Каргапольский район, село Бакланское, Центральная, 23	t	small
45702	49550	358	Курганская область, Звериноголовский район, село Украинец, Победы, 23	f	small
45701	49549	357	Курганская область, Звериноголовский район, поселок Труд и Знание, 40лет Победы, 1	f	small
45700	49548	356	Курганская область, Звериноголовский район, село Северный, Центральная, 5	t	small
45699	49547	355	Курганская область, Звериноголовский район, село Редуть, Школьная, 16	t	small
45704	49552	360	Курганская область, Звериноголовский район, поселок Прорывное, Ленина, 16	f	medium
45697	49545	353	Курганская область, Звериноголовский район, село Отряд-Алабуга, Советская, 6	f	small
45698	49546	354	Курганская область, Звериноголовский район, село Озерное, Школьная, 32	f	small
45696	49544	352	Курганская область, Звериноголовский район, село Лебедевка, Южная, 6	t	small
45695	49543	351	Курганская область, Звериноголовский район, село Круглое, Ленина, 2а	f	medium
45693	49541	349	Курганская область, Звериноголовский район, Красногорка, Центральная, 17/2	t	small
45694	49542	350	Курганская область, Звериноголовский район, село Комсомольская, Школьная, 13	f	small
45703	49551	359	Курганская область, Звериноголовский район, село Искра, Школьная, 16	f	medium
45692	49540	348	Курганская область, Звериноголовский район, село Зубаревка, Центральная, 22	t	small
45690	49538	346	Курганская область, Звериноголовский район, поселок Звериноголовское, Октябрьская, 26	f	large
45689	49537	345	Курганская область, Звериноголовский район, поселок Звериноголовское, Кравченко, 45	f	large
45691	49539	347	Курганская область, Звериноголовский район, поселок Звериноголовское, Косаревой, 11А	f	medium
45688	49536	344	Курганская область, Звериноголовский район, село Жаворонки, Школьная, 2	t	small
45687	49535	343	Курганская область, Звериноголовский район, село Верхняя Алабуга, Школьная, 4	t	small
45686	49534	342	Курганская область, Звериноголовский район, село Бугровое, Школьная, 35	f	small
45680	49528	335	Курганская область, Далматовский район, село Ясная Поляна	f	small
45653	49501	307	Курганская область, Далматовский район, село Язовка	t	small
45677	49525	332	Курганская область, Далматовский район, село Юровка	t	small
45666	49514	321	Курганская область, Далматовский район, село Широковское	f	small
45661	49509	315	Курганская область, Далматовский район, село Уральцевское	f	small
45678	49526	333	Курганская область, Далматовский район, поселок Уксянское	f	large
45663	49511	318	Курганская область, Далматовский район, село Тамакульское	f	small
45659	49507	313	Курганская область, Далматовский район, село Смирново	f	small
45656	49504	310	Курганская область, Далматовский район, село Сараткуль	t	small
45685	49533	340	Курганская область, Далматовский район, поселок Песчано-Коледино	f	medium
45675	49523	330	Курганская область, Далматовский район, село Пески	f	small
45674	49522	329	Курганская область, Далматовский район, село Першинское	f	small
45655	49503	309	Курганская область, Далматовский район, село Параткуль	f	small
45664	49512	319	Курганская область, Далматовский район	t	small
45682	49530	337	Курганская область, Далматовский район, село Павелево	f	medium
45662	49510	317	Курганская область, Далматовский район, село Новосельское	t	small
45683	49531	338	Курганская область, Далматовский район, поселок Новопетропавловское	f	large
45660	49508	314	Курганская область, Далматовский район, село Нижний Яр	f	small
45665	49513	320	Курганская область, Далматовский район, село Мясниково	f	small
45676	49524	331	Курганская область, Далматовский район, село Макарьевское	t	small
45679	49527	334	Курганская область, Далматовский район, поселок Любимово	f	medium
45684	49532	339	Курганская область, Далматовский район, село Лебяжье	f	small
45671	49519	326	Курганская область, Далматовский район, село Крутиха	f	medium
45657	49505	311	Курганская область, Далматовский район, село Кривское	f	medium
45667	49515	322	Курганская область, Далматовский район, село Крестовка	t	small
45670	49518	325	Курганская область, Далматовский район, село Красноисетское	f	small
45673	49521	328	Курганская область, Далматовский район, село Ключевское	f	small
45669	49517	324	Курганская область, Далматовский район, село Затеченское	f	medium
45672	49520	327	Курганская область, Далматовский район	t	small
45652	49500	306	Курганская область, Далматовский район, Вознесенское	f	small
45668	49516	323	Курганская область, Далматовский район, село Верхний Яр	f	small
45649	49497	303	Курганская область, Далматовский район, село Верхний Суварыш	t	small
45681	49529	336	Курганская область, Далматовский район, село Белоярка 1-я	f	small
45658	49506	312	Курганская область, Далматовский район	t	small
45634	49482	286	Курганская область, Варгашинский район, село Яблочное, Андреева, 19	f	small
45613	49462	265	Курганская область, Варгашинский район, село Юрахлы, в помещении табельной	t	small
45637	49485	289	Курганская область, Варгашинский район, село Шмаково, Береговая, 65	t	small
45636	49484	288	Курганская область, Варгашинский район, село Шастово, Центральная, 3	f	small
45635	49483	287	Курганская область, Варгашинский район, село Урал, Больничная, 2	t	small
45633	49481	285	Курганская область, Варгашинский район, село Терпугово, Молодежная, 17	t	small
45632	49480	284	Курганская область, Варгашинский район, село Сычево, Школьная, 2	f	small
45631	49478	283	Курганская область, Варгашинский район, село Строево, Центральная, 43	f	small
45630	49477	282	Курганская область, Варгашинский район, село Спорное, Садовая, 25	f	small
45628	49475	280	Курганская область, Варгашинский район, село Попово, Пролетарская, 27Б	f	small
45626	49473	278	Курганская область, Варгашинский район, село Пичугино, Пионерская, 11	f	medium
45625	49472	277	Курганская область, Варгашинский район, село Ошурково, Школьная, 2	f	small
45623	49470	275	Курганская область, Варгашинский район, поселок Мостовское, Гоголя, 5	f	medium
45622	49469	274	Курганская область, Варгашинский район, поселок Мостовское, Больничная, 2	f	small
45621	49468	273	Курганская область, Варгашинский район, село Медвежье, Центральная, 12	f	small
45620	49467	272	Курганская область, Варгашинский район, село Лихачи, Чапаева, 21	f	small
45627	49474	279	Курганская область, Варгашинский район, село Кабанье, Озерная, 38Б	t	small
45624	49471	276	Курганская область, Варгашинский район, село Заложное, Центральная, 26	f	small
45619	49466	271	Курганская область, Варгашинский район, село Дундино, Центральная, 2 а	f	small
45618	49465	270	Курганская область, Варгашинский район, село Дубровное, Новая, 12А	f	small
45617	49464	269	Курганская область, Варгашинский район, село Верхнесуерское, Гагарина, 1А	f	medium
46425	50283	1090	Курганская область, Варгашинский район, поселок Варгаши, Социалистическая, 58	f	small
45608	49457	260	Курганская область, Варгашинский район, поселок Варгаши, Социалистическая, 92	f	medium
45607	49456	259	Курганская область, Варгашинский район, поселок Варгаши, Социалистическая, 114	f	medium
45606	49455	258	Курганская область, Варгашинский район, поселок Варгаши, Социалистическая, 200	f	medium
45609	49458	261	Курганская область, Варгашинский район, поселок Варгаши, Осипенко, 29 а	f	medium
45610	49459	262	Курганская область, Варгашинский район, поселок Варгаши, Механизаторов, 12	f	medium
45604	49453	256	Курганская область, Варгашинский район, поселок Варгаши, Матросова, 50	f	medium
46434	50292	1099	Курганская область, Варгашинский район, поселок Варгаши, Космонавтов, 1А	f	medium
46513	50370	1179	Курганская область, Варгашинский район, поселок Варгаши, Комсомольская, 36	f	medium
46514	50371	1180	Курганская область, Варгашинский район, поселок Варгаши, Кирова, 107 в	f	small
45612	49461	264	Курганская область, Варгашинский район, поселок Варгаши, Кирова, 85а	f	large
45611	49460	263	Курганская область, Варгашинский район, поселок Варгаши, Кирова, 81	f	small
45615	49416	267	Курганская область, Варгашинский район, село Варгаши, Центральная, 75	f	small
45605	49454	257	Курганская область, Варгашинский район, поселок городского типа Варгаши, Комсомольская, 42	f	medium
45629	49476	281	Курганская область, Варгашинский район, село Большое Просеково, Молодежная, 5	f	small
45616	49438	268	Курганская область, Варгашинский район, село Белово, Школьная, 25	f	small
45614	49404	266	Курганская область, Варгашинский район, село Барашково, Школьная, 7	f	small
45603	49452	255	Курганская область, Белозерский район, село Ягодная	f	small
45599	49448	250	Курганская область, Белозерский район, село Юрково	t	small
45602	49451	254	Курганская область, Белозерский район, село Чимеево	f	small
45586	49434	236	Курганская область, Белозерский район, село Усть-Суерское	t	small
45588	49436	239	Курганская область, Белозерский район, село Тюменцева	f	small
45585	49433	235	Курганская область, Белозерский район, село Стенниково	t	small
45566	49412	215	Курганская область, Белозерский район, село Стеклозавод	f	small
45601	49450	252	Курганская область, Белозерский район, село Скопино	f	small
45600	49449	251	Курганская область, Белозерский район, село Скаты	f	small
45598	49447	249	Курганская область, Белозерский район, село Светлый Дол	f	medium
45594	49443	245	Курганская область, Белозерский район, село Рычково	f	small
45582	49430	232	Курганская область, Белозерский район, село Романовское	f	small
45592	49441	243	Курганская область, Белозерский район, село Речкино	f	small
45593	49442	244	Курганская область, Белозерский район, село Редькино	f	small
45590	49439	241	Курганская область, Белозерский район, село Пьянково	f	small
45579	49426	228	Курганская область, Белозерский район, село Полевое	t	small
45571	49418	220	Курганская область, Белозерский район, село Подборная, Здание Подборновского сельского клуба	t	small
45581	49429	231	Курганская область, Белозерский район, село Петуховское	t	small
45587	49435	238	Курганская область, Белозерский район, село Першино	f	medium
45584	49432	234	Курганская область, Белозерский район, село Памятное	f	medium
45597	49446	248	Курганская область, Белозерский район, село Орловка	t	small
45580	49428	230	Курганская область, Белозерский район, село Новодостовалово	f	small
45578	49425	227	Курганская область, Белозерский район, село Нижнетобольное	f	small
45570	49417	219	Курганская область, Белозерский район, село Мясникова	f	small
45596	49445	247	Курганская область, Белозерский район, село Мендерское	t	small
45569	49415	218	Курганская область, Белозерский район, село Масляная	t	small
45589	49437	240	Курганская область, Белозерский район, село Малый Камаган	t	small
45577	49424	226	Курганская область, Белозерский район, село Малый Заполой	t	small
45574	49421	223	Курганская область, Белозерский район, село Лихачи, Здание бывшей Лихачихинской начальной школы	t	small
45564	49410	213	Курганская область, Белозерский район, село Куликово	f	small
45563	49409	212	Курганская область, Белозерский район, село Корюкина	f	medium
45595	49444	246	Курганская область, Белозерский район, село Кирово	f	small
45573	49420	222	Курганская область, Белозерский район, село Зюзино	f	small
45591	49440	242	Курганская область, Белозерский район, село Екимово	t	small
45562	49408	211	Курганская область, Белозерский район, село Доможирова	t	small
45583	49431	233	Курганская область, Белозерский район, село Волосникова	t	small
45568	49414	217	Курганская область, Белозерский район, село Боровское	f	medium
45565	49411	214	Курганская область, Белозерский район, село Боровлянка	f	medium
45575	49422	224	Курганская область, Белозерский район, село Большой Камаган	f	small
45572	49419	221	Курганская область, Белозерский район, село Большое Зарослое	f	small
45567	49413	216	Курганская область, Белозерский район, село Березовский	t	small
45558	49403	207	Курганская область, Белозерский район, село Березово	t	small
45560	49406	209	Курганская область, Белозерский район, Белозерское, Советская, 30	f	large
45561	49407	210	Курганская область, Белозерский район, поселок Белозерское, Карла Маркса, 36	f	large
45559	49405	208	Курганская область, Белозерский район, поселок Белозерское, Карла Маркса, 6	f	large
45557	49402	206	Курганская область, Белозерский район, село Баярак	f	small
45576	49423	225	Курганская область, Белозерский район, село Ачикуль	t	small
45554	49399	203	Курганская область, Альменевский район, село Ягодное, Центральная, 12	f	small
45551	49396	200	Курганская область, Альменевский район, село Юламаново, Шахты, 11	f	small
45531	49376	180	Курганская область, Альменевский район, село Щучанка, Школьная, 18	t	small
45550	49395	199	Курганская область, Альменевский район, село Шарипово, Школьная, 4	f	small
45546	49390	195	Курганская область, Альменевский район, село Чистое, Школьная, 2	f	small
45538	49382	187	Курганская область, Альменевский район, село Учкулево, Центральная, 31	t	small
45540	49384	189	Курганская область, Альменевский район, село Убалина, Аминева, 27	t	small
45542	49386	191	Курганская область, Альменевский район, село Танрыкулово, Советская, 12	f	small
45556	49401	205	Курганская область, Альменевский район, село Солнечная, Центральная, 10	t	small
45541	49385	190	Курганская область, Альменевский район, село Рыбное, Школьная, 13	f	small
45549	49394	198	Курганская область, Альменевский район, село Поляна, Школьная, 2	t	small
45543	49387	192	Курганская область, Альменевский район, село Подъясово, Школьная, 14	t	small
45539	49383	188	Курганская область, Альменевский район, село Парамоново, Советская, 25	f	small
45547	49392	196	Курганская область, Альменевский район, поселок Мир, Советская, 19	f	medium
45536	49380	185	Курганская область, Альменевский район, село Малышева, Центральная, 11	f	small
45529	49374	178	Курганская область, Альменевский район, село Майлык, Майлыкская, 15	t	small
45544	49388	193	Курганская область, Альменевский район, село Крутой Лог, Почтовая, 2	t	small
45535	49379	184	Курганская область, Альменевский район, село Казенное, Центральная, 21	t	medium
45545	49389	194	Курганская область, Альменевский район, село Казаккулово, Малая, 1	t	small
45530	49375	179	Курганская область, Альменевский район, село Искандарово, Кирпичная, 1	t	small
45533	49378	182	Курганская область, Альменевский район, село Иванково, пер. Советский, 1а, Иванковский сельсовет	t	small
45532	49377	181	Курганская область, Альменевский район, село Иванково, Российская, 7	f	small
45555	49400	204	Курганская область, Альменевский район, село Вишняково, Центральная, 46	f	small
45553	49398	202	Курганская область, Альменевский район, село Бухарово, Береговая, 18	f	small
45528	49373	177	Курганская область, Альменевский район, село Бороздинка, Школьная, 2	f	small
45548	49393	197	Курганская область, Альменевский район, село Байганино, Комсомольская,, 14	t	small
45552	49397	201	Курганская область, Альменевский район, село Аскарово, Молодёжная, 22	t	small
45525	49370	174	Курганская область, Альменевский район, поселок Альменево, Комсомола, 2	f	large
45527	49372	176	Курганская область, Альменевский район, поселок Альменево, В.И.Ленина, 103	f	medium
45526	49371	175	Курганская область, Альменевский район, поселок Альменево, 8 Марта, 2	f	large
45537	49381	186	Курганская область, Альменевский район, село Алакуль, Озерная, 1	t	small
77089	2765	152	Томская область, Томск, поселок Светлый, 33	f	large
77088	2764	151	Томская область, Томск, поселок Светлый, 33	f	large
77087	2763	150	Томская область, Томск, поселок Светлый, 33, телефон: 98-32-78, 98-11-77	f	large
77078	2751	138	Томская область, Томск, поселок Светлый, 33	f	large
77231	3060	467	Россия, Томская область	f	large
76954	2638	5	Россия, Томская область	f	large
77137	2800	202	Россия, Томская область	f	large
77132	2800	197	Россия, Томская область	f	large
76959	2642	10	Россия, Томская область	f	large
76981	2662	33	Россия, Томская область	f	large
77138	2806	203	Россия, Томская область	f	large
77116	2782	179	Россия, Томская область	f	large
77110	2782	173	Россия, Томская область	f	large
76971	95187	23	Россия, Томская область, Томск, проспект Фрунзе, 158	f	large
76984	2664	36	Россия, Томская область	f	large
76956	2636	7	Россия, Томская область	f	large
76953	2636	4	Россия, Томская область	f	large
76952	2636	3	Россия, Томская область	f	large
125538	3108	516	Россия, Томская область, Кривошеинский район	f	medium
125427	2987	387	Россия, Томская область, Бакчарский район	f	medium
77144	2813	210	Россия, Томская область	f	large
77136	2805	201	Россия, Томская область	f	large
77133	2801	198	Россия, Томская область	f	large
77031	2707	90	Томская область, Томск, проспект Ленина, 27а	f	large
77028	2705	87	Томская область, Томск, проспект Кирова, 56а	f	large
77006	2669	60	Томская область, Томск, проспект Кирова, 12	f	large
76989	2669	42	Томская область, Томск, проспект Кирова, 12	f	large
76967	2650	18	Россия, Томская область	f	large
76976	2659	28	Россия, Томская область	f	large
125316	2690	67	Томская область, Томск, село Эушта, Школьная , 3	t	small
77009	2688	65	Томская область, Томск, Школьная, 18	f	large
77008	2687	64	Томская область, Томск, село Тимирязевское, Школьная, 18	f	large
77125	2794	190	Россия, Томская область, Шегарский район	f	large
76961	2644	12	Томская область, Томск, Челюскинцев, 20	f	large
77075	2749	135	Томская область, Томск, Центральная, 4а	f	large
77074	2747	134	Томская область, Томск, Центральная, 4а	f	large
77073	2746	133	Томская область, Томск, Центральная, 4а	f	large
77035	2692	94	Томская область, Томск, Хмельницкого, 40	f	large
77128	2797	193	Томская область, Томск, Ферганская, 25	f	large
77005	2682	58	Томская область, Томск, Федора Лыткина, 18	f	large
77004	2681	57	Томская область, Томск, Федора Лыткина, 14	f	large
77003	2680	56	Томская область, Томск, Федора Лыткина, 12	f	large
77010	2689	66	Томская область, Томск, село Дзержинское, Фабричная, 11	f	large
77000	2678	53	Томская область, Томск, Учебная, 41	f	large
76996	2674	49	Томская область, Томск, Учебная, 37а	f	large
77025	2703	84	Томская область, Томск, Усова, 56, телефон: 55-35-57	f	large
77021	2699	79	Томская область, Томск, Усова, 68	f	large
77020	2696	78	Томская область, Томск, Усова, 68	f	large
77017	2696	75	Томская область, Томск, Усова, 68	f	large
77080	2753	140	Томская область, Томск, Угрюмова, 1/2	f	large
77130	2798	195	Томская область, Томск, Трудовая, 18/1	f	large
77129	2798	194	Томская область, Томск, Трудовая, 18/1	f	large
76970	2654	22	Томская область, Томск, Тверская, 74	f	large
77135	2803	200	Россия, Томская область	f	large
77134	2802	199	Россия, Томская область	f	large
77052	2727	112	Томская область, Томск, Суворова, 5	f	large
77051	2726	111	Томская область, Томск, Суворова, 5	f	large
77044	2718	103	Томская область, Томск, поселок Спутник, Спутник, 18	t	large
125314	2685	62	Томская область, Томск, поселок Нижний Склад, Сплавная, 56	t	small
77096	2770	159	Томская область, Томск, Соляная площадь, 2	f	large
125659	3241	650	Томская область, Томск, поселок Басандайка, Советская, 1а, школа	t	medium
77121	2789	184	Томская область, Томск, Смирнова, 48А, 73-96-39	f	large
77120	2788	183	Томская область, Томск, Смирнова, 50	f	large
77102	2777	165	Томская область, Томск, Смирнова, 28	f	large
77118	2777	181	Томская область, Томск, Смирнова, 28	f	large
77104	2777	167	Томская область, Томск, Смирнова, 28	f	large
77101	2776	164	Томская область, Томск, Смирнова, 44	f	large
76974	2658	26	Томская область, Томск, Сибирская, 29/1	f	large
76963	2646	14	Томская область, Томск, Сибирская, 81ак1	f	large
76962	2645	13	Томская область, Томск, Сибирская, 81А	f	large
77093	2767	156	Томская область, Томск, Сергея Лазо, 26/1	f	large
77066	2739	126	Томская область, Томск, Сергея Лазо, 26/1	f	large
77065	2738	125	Томская область, Томск, Сергея Лазо, 26/1	f	large
77063	2737	123	Томская область, Томск, Сергея Лазо, 22	f	large
77076	2737	136	Томская область, Томск, Сергея Лазо, 22	f	large
77064	2737	124	Томская область, Томск, Сергея Лазо, 22	f	large
76968	2651	19	Томская область, Томск, Сергея Вицмана, 32	f	large
77083	2758	145	Томская область, Томск, Северный Городок, 61	f	large
125592	3160	570	Томская область, Томск, Свердлова, 39	f	small
77094	2768	157	Томская область, Томск, Пушкина, 29	f	large
77046	2722	106	Томская область, Томск, Пушкина, 54/1, телефон: 66-05-0666-05-04	f	large
77045	2720	105	Томская область, Томск, Пушкина, 54/1	f	large
77001	2679	54	Томская область, Томск, село Тимирязевское, Путевая, 1Д	f	large
76991	2671	44	Томская область, Томск, Пирогова, 2	f	large
76993	2637	46	Томская область, Томск, Пирогова, 2	f	large
76992	2637	45	Томская область, Томск, Пирогова, 2	f	large
77043	2717	102	Томская область, Томск, Переездный переулок, 3	f	large
77126	2795	191	Томская область, Томск, Первомайская, 65	f	large
77181	2850	252	Россия, Томская область, Асиновский район	f	large
77038	2712	97	Томская область, Томск, Партизанская, 16	f	large
77037	2711	96	Томская область, Томск, Партизанская, 17	f	large
76987	2666	39	Томская область, Томск, Октябрьская, 16	f	large
77100	2774	163	Томская область, Томск, Октябрьская, 16, телефон: 65-39-6465-31-64	f	large
77095	2769	158	Томская область, Томск, Новосибирская, 38	f	large
77079	2752	139	Томская область, Томск, Новосибирская, 38	f	large
77068	2741	128	Томская область, Томск, Новосибирская, 39	f	large
77067	2740	127	Томская область, Томск, Новосибирская, 39	f	large
76978	2656	30	Томская область, Томск, Никитина, 26	f	large
76975	2656	27	Томская область, Томск, Никитина, 26	f	large
76972	2656	24	Томская область, Томск, Никитина, 26	f	large
77002	2676	55	Томская область, Томск, Нахимова, 30	f	large
76998	2676	51	Томская область, Томск, Нахимова, 30	f	large
76997	2675	50	Томская область, Томск, Нахимова, 30	f	large
125323	2791	186	Томская область, Томск, Мостовая, 24	f	small
77019	2698	77	Томская область, Томск, Мокрушина, 10	f	large
77018	2697	76	Томская область, Томск, Мокрушина, 22	f	large
77077	2750	137	Томская область, Томск, Мичурина, 4	f	large
77042	2716	101	Томская область, Томск, Мичурина, 4	f	large
77039	2713	98	Томская область, Томск, Мичурина, 4	f	large
125319	2719	104	Томская область, Томск, МПС, 8/1	f	medium
125312	2667	40	Томская область, Томск, Ленина проспект, 49А	f	medium
76986	2657	38	Томская область, Томск, Лебедева, 6	f	large
76979	2657	31	Томская область, Томск, Лебедева, 6	f	large
76973	2657	25	Томская область, Томск, Лебедева, 6	f	large
76964	2647	15	Томская область, Томск, Лебедева, 94	f	large
76960	2643	11	Томская область, Томск, Лебедева, 94	f	large
125318	2700	80	Томская область, Томск, Косарева, 9	f	medium
125311	2652	20	Россия, Томская область	f	medium
77119	2787	182	Россия, Томская область	f	large
77024	2702	83	Томская область, Томск, Киевская, 111	f	large
77023	2695	82	Томская область, Томск, Киевская, 111, телефон: 55-74-34	f	large
77016	2695	74	Томская область, Томск, Киевская, 111, телефон: 55-74-34	f	large
76969	2653	21	Томская область, Томск, Киевская, 64а	f	large
77027	2704	86	Томская область, Томск, Карташова, 47	f	large
77026	2704	85	Томская область, Томск, Карташова, 47	f	large
77139	2807	204	Томская область, Томск, Карла Маркса, 50, телефон: 40-74-0240-62-97	f	large
77122	2790	185	Томская область, Томск, Карла Маркса, 21	f	large
77115	2786	178	Томская область, Томск, Карла Ильмера, 15/1	f	large
77114	2785	177	Томская область, Томск, Карла Ильмера, 4	f	large
77117	2784	180	Томская область, Томск, Карла Ильмера, 11	f	large
77113	2784	176	Томская область, Томск, Карла Ильмера, 11	f	large
77112	2784	175	Томская область, Томск, Карла Ильмера, 11	f	large
77159	2831	229	Томская область, Томск, Калинина, 88	f	large
77158	2829	228	Томская область, Томск, Калинина, 72	f	large
77086	2762	149	Томская область, Томск, Иркутский тракт, 181	f	large
77085	2761	148	Томская область, Томск, Иркутский тракт, 122/1	f	large
77084	2760	147	Томская область, Томск, Иркутский тракт, 122/1	f	large
77059	2734	119	Томская область, Томск, Иркутский тракт, 175	f	large
77058	2733	118	Томская область, Томск, Иркутский тракт, 175	f	large
77050	2725	110	Томская область, Томск, Иркутский тракт, 86/1	f	large
77048	2724	108	Томская область, Томск, Иркутский тракт, 51/3	f	large
77049	2723	109	Томская область, Томск, Иркутский тракт, 51/3	f	large
77047	2723	107	Томская область, Томск, Иркутский тракт, 51/3	f	large
77041	2715	100	Томская область, Томск, Иркутский тракт, 15, телефон: 75-12-81	f	large
77109	2781	172	Томская область, Томск, Интернационалистов, 12	f	large
77108	2780	171	Томская область, Томск, Интернационалистов, 11, телефон: 62-40-17 62-40-18	f	large
77107	2780	170	Томская область, Томск, Интернационалистов, 11, телефон: 62-40-17 62-40-18	f	large
77071	2744	131	Томская область, Томск, Ивановского, 8	f	large
77070	2743	130	Томская область, Томск, Ивана Черных, 97	f	large
77061	2736	121	Томская область, Томск, Ивана Черных, 123/1	f	large
77062	2735	122	Томская область, Томск, Ивана Черных, 123/1	f	large
77060	2735	120	Томская область, Томск, Ивана Черных, 123/1	f	large
77054	2729	114	Томская область, Томск, Ивана Черных, 101	f	large
77053	2728	113	Томская область, Томск, Ивана Черных, 97, телефон: 67-44-54	f	large
76966	95186	17	Томская область, Томск, Енисейская, 36	f	large
77022	2701	81	Томская область, Томск, Елизаровых, 2	f	large
77012	2691	69	Томская область, Томск, Елизаровых, 47	f	large
77011	2691	68	Томская область, Томск, Елизаровых, 47	f	large
77072	2745	132	Томская область, Томск, Демьяна Бедного, 4	f	large
76999	2677	52	Томская область, Томск, Горького, 55	f	large
77036	2710	95	Томская область, Томск, Герцена, 7	f	large
76988	2668	41	Томская область, Томск, Герцена, 7	f	large
76985	2665	37	Томская область, Томск, Герцена, 49	f	large
76980	2661	32	Томская область, Томск, Герцена, 18	f	large
76977	2660	29	Томская область, Томск, Герцена, 47	f	large
77015	2694	73	Томская область, Томск, посёлок Геологов, Геологов, 11а	t	large
77040	2714	99	Томская область, Томск, Вокзальная, 67	f	large
77131	2799	196	Томская область, Томск, Войкова, 86	f	large
125315	2686	63	Томская область, Томск, село Тимирязевское, Водозаборная улица, 1	t	small
77034	2709	93	Томская область, Томск, Вершинина, 48	f	large
77029	2706	88	Томская область, Томск, Вершинина, 17	f	large
77030	2706	89	Томская область, Томск, Вершинина, 17	f	large
76990	2670	43	Томская область, Томск, Вершинина, 46	f	large
125572	3143	550	Томская область, Томск, Вавилова, 8	f	small
76951	2635	2	Томская область, Томск, Вавилова, 8	f	large
76950	2634	1	Томская область, Томск, Вавилова, 8/1	f	large
77092	2766	155	Томская область, Томск, Бирюкова, 22	f	large
77091	2766	154	Томская область, Томск, Бирюкова, 22	f	large
77090	2766	153	Томская область, Томск, Бирюкова, 22	f	large
77069	2742	129	Томская область, Томск, Беринга, 24	f	large
77057	2732	117	Томская область, Томск, Беринга, 4	f	large
77056	2731	116	Томская область, Томск, Беринга, 4	f	large
77055	2730	115	Томская область, Томск, Беринга, 4	f	large
77097	2771	160	Томская область, Томск, Белозерская улица, 12	f	large
77007	2684	61	Томская область, Томск, Белинского, 55	f	large
77082	2756	143	Томская область, Томск, Бела Куна, 20	f	large
77081	2754	141	Томская область, Томск, Бела Куна, 1	f	large
125313	2683	59	Томская область, Томск, Басандайская, 11	t	medium
77099	2773	162	Томская область, Томск, Ачинская, 20	f	large
77098	2772	161	Томская область, Томск, Ачинская, 20	f	large
76995	2673	48	Томская область, Томск, Аркадия Иванова, 49	f	large
76994	2672	47	Томская область, Томск, Аркадия Иванова, 4	f	large
76955	2639	6	Россия, Томская область	f	large
76965	2648	16	Томская область, Томск, Алтайская, 120/1, телефон: 454849	f	large
76958	2641	9	Томская область, Томск, Алтайская, 120/1	f	large
76957	2640	8	Томская область, Томск, Алтайская, 120/1	f	large
76983	2663	35	Томская область, Томск, Алексея Беленца, 11	f	large
76982	2663	34	Томская область, Томск, Алексея Беленца, 11	f	large
77103	2778	166	Томская область, Томск, 79-й Гвардейской Дивизии, 25	f	large
77111	2783	174	Томская область, Томск, 79 Гвардейской дивизии, 21, телефон: 76-29-26	f	large
77124	2792	189	Томская область, Томск, 5-й Армии, 24	f	large
77123	2792	187	Томская область, Томск, 5-й Армии, 24	f	large
125324	2793	188	Томская область, Томск, 5-й Армии, 24, телефон: 46-11-44	f	medium
125393	2938	337	Томская область, село Сугот, переулок Клубный, 1	t	small
77207	2958	356	Томская область, Стрежевой, площадь Нефтяников, 2	f	large
77210	2960	359	Томская область, Стрежевой, Н. Мержи, 1	f	large
77215	2965	364	Томская область, Стрежевой, Молодежная, 3	f	large
77206	2957	355	Томская область, Стрежевой, Коммунальная, 1	f	large
77204	2955	353	Томская область, Стрежевой, Викулова, 1	f	large
77205	2956	354	Томская область, Стрежевой, Буровиков, 18	f	large
77214	2964	363	Томская область, Стрежевой, 4 микрорайон, 458	f	large
77213	2963	362	Томская область, Стрежевой, 4 микрорайон, 458	f	large
77212	2962	361	Томская область, Стрежевой, 4 микрорайон, 460	f	large
77211	2961	360	Томская область, Стрежевой, 4 микрорайон, 433/1	f	large
77208	2959	357	Томская область, Стрежевой, 3 микрорайон, 324	f	large
77209	2855	358	Томская область, Стрежевой, 3 микрорайон, 324, телефон: 52969	f	large
125392	2937	336	Россия, Томская область, село Староабрамкино	t	small
77178	2846	248	Томская область, Северск, проспект Мира, 11, телефон: 54-68-14	f	large
77170	2839	240	Томская область, Северск, проспект Коммунистический, 103	f	large
77163	2834	233	Томская область, Северск, проспект Коммунистический, 119	f	large
77148	2814	214	Томская область, Северск, проспект Коммунистический, 39	f	large
77145	2814	211	Томская область, Северск, проспект Коммунистический, 39	f	large
77175	2843	245	Томская область, Северск, просп. Коммунистический, 56	f	large
77169	2838	239	Томская область, Северск, просп. Коммунистический, 119	f	large
77152	2823	221	Томская область, Северск, пер.Чекист, 2	f	large
125328	2822	220	Томская область, Северск, поселок Орловка, Школьный переулок, 4	t	medium
77155	2824	225	Томская область, Северск, Чапаева, 22	f	large
77153	2824	222	Томская область, Северск, Чапаева, 22	f	large
125327	2819	217	Томская область, Северск, Чайковского, 15	f	medium
77141	2810	207	Томская область, Северск, Строителей, 27	f	large
77140	2809	206	Томская область, Северск, Строителей, 38	f	large
125325	2808	205	Томская область, Северск, Сосновая , 16	f	small
77171	2840	241	Томская область, Северск, Северная, 18	f	large
77157	2828	227	Томская область, Северск, Победы, 8б	f	large
77156	2827	226	Томская область, Северск, Победы, 12А	f	large
77149	2817	215	Томская область, Северск, Пионерская, 12	f	large
125326	2818	216	Томская область, Северск, Первомайская, 30	f	small
77146	2815	212	Томская область, Северск, Парковая, 2а	f	large
77154	2826	224	Томская область, Северск, Ленинградская, 11	f	large
77168	2837	238	Томская область, Северск, Курчатова, 14	f	large
77167	2837	237	Томская область, Северск, Курчатова, 14	f	large
77166	2836	236	Томская область, Северск, Курчатова, 16	f	large
77165	2836	235	Томская область, Северск, Курчатова, 16	f	large
77164	2835	234	Томская область, Северск, Курчатова, 7	f	large
77176	2844	246	Томская область, Северск, Крупской, 14	f	large
77177	2845	247	Томская область, Северск, Коммунистический проспект, 65	f	large
77174	2842	244	Томская область, Северск, Калинина, 46А	f	large
77173	2842	243	Томская область, Северск, Калинина, 46А	f	large
77172	2841	242	Томская область, Северск, Калинина, 109	f	large
77160	2832	230	Томская область, Северск, Калинина, 104	f	large
77143	2812	209	Томская область, Северск, Калинина, 25	f	large
77142	2811	208	Томская область, Северск, Калинина, 43А	f	large
77147	2816	213	Томская область, Северск, Горького, 32	f	large
125367	2896	296	Томская область, село Пудино, Горького, 8	f	medium
125371	2900	301	Томская область, Колпашево, Обская, 65/7	f	medium
125365	2894	294	Томская область, Кедровый, 1 микрорайон, 42	f	medium
125364	2893	293	Томская область, Кедровый, 1 микрорайон, 61	f	medium
77255	3257	665	Томская область, поселок Зональная Станция, Совхозная, 18	f	large
77251	3246	655	Томская область, поселок Зональная Станция, Совхозная, 10, здание администрации каб. № 5	f	large
77254	3256	664	Томская область, поселок Зональная Станция, Зеленая, 40	f	large
77162	2833	232	Томская область, ЗАТО Северск, просп. Коммунистический, 141	f	large
77161	2833	231	Томская область, ЗАТО Северск, просп. Коммунистический, 141	f	large
125670	3258	666	Томская область, поселок Госсортучасток, Центральная, Центральная контора сортоиспытательной станции	t	small
125663	3245	654	Томская область, Аэропорт, 7, телефон: 964-814	f	medium
125662	3244	653	Томская область, поселок Аэропорт, 7, здание детского сада	f	small
77184	2858	259	Томская область, Асино, проспект Ленина, 47	f	large
125331	2851	253	Томская область, Асино, проспект Ленина, 36	f	small
77187	2861	262	Томская область, Асино, Тельмана, 39	f	large
77183	2857	258	Томская область, Асино, Ивана Буева, 38	f	large
125334	2856	257	Томская область, Асино, Гончарова, 46	f	medium
125752	3350	760	Томская область, Шегарский район, село Федораевка, Набережная, 2	t	small
125739	3337	747	Томская область, Шегарский район, село Татьяновка, Центральная, 36	t	small
125656	3198	644	Томская область, Шегарский район, село Половинка (Базанаково), Центральная, 9	t	small
125749	3347	757	Томская область, Шегарский район, село Победа, Ленина, 68	f	medium
125756	3354	764	Томская область, Шегарский район, село Новоильинка, Новая, 9-2, телефон: 29-794	t	small
125755	3353	763	Томская область, Шегарский район, село Новоильинка, Новая, 2	t	small
125768	3368	777	Томская область, Шегарский район, село Нащёково, Сибирская, 2	t	medium
125751	3349	759	Томская область, Шегарский район, село Монастырка, Советская, 32а	t	small
125473	3036	439	Томская область, Шегарский район, село Михайловка (Кочубай), Гончарова, 42	f	medium
125761	3359	769	Томская область, Шегарский район, село Мельниково, Школьная, 68	f	medium
77268	3364	773	Томская область, Шегарский район, село Мельниково, Чапаева, 60	f	large
125762	3360	770	Томская область, Шегарский район, село Мельниково, Чапаева, 23	f	medium
125766	3366	775	Томская область, Шегарский район, село Мельниково, Суворова, 3, телефон: 21-974	f	medium
125763	3361	771	Томская область, Шегарский район, село Мельниково, Московская, 13	f	medium
125760	3358	768	Томская область, Шегарский район, село Мельниково, Московская, 24	f	medium
125767	3367	776	Томская область, Шегарский район, село Мельниково, Коммунистическая, 101	t	medium
125765	3365	774	Томская область, Шегарский район, село Мельниково, Коммунистическая, 24	f	medium
125764	3363	772	Томская область, Шегарский район, село Мельниково, Калинина, 55	f	small
125742	3340	750	Томская область, Шегарский район, село Маркелово, Рабочая, 1	f	medium
125758	3356	766	Томская область, Шегарский район, село Малобрагино, Школьная, 1	t	small
125747	3345	755	Томская область, Шегарский район, село Каргала, Юбилейная, 14	f	medium
125743	3341	751	Томская область, Шегарский район, село Гынгазово, Центральная , 45	f	small
125754	3352	762	Томская область, Шегарский район, село Гусево, Гагарина, 10а	f	small
125753	3351	761	Томская область, Шегарский район, село Гусево, Гагарина, 7	f	small
125740	3338	748	Томская область, Шегарский район, село Вороновка, Кооперативная, 9а, телефон: 35-145	f	small
125759	3357	767	Томская область, Шегарский район, село Бушуево, Энергетическая, 6а	t	small
125672	3260	668	Томская область, Шегарский район, село Батурино, Цветочная, 11, школа	t	medium
125744	3342	752	Томская область, Шегарский район, село Баткат, пер. Кооперативный, 1	t	medium
125745	3343	753	Томская область, Шегарский район, село Бабарыкино, Советская, 27	f	small
125738	3336	746	Томская область, Шегарский район, село Анастасьевка, Школьный, 2	f	small
125730	3299	738	Томская область, Чаинский район, село Черёмушки, Светлая, 16	f	small
125724	3323	732	Томская область, Чаинский район, село Чемондаевка, Трактовая, 1	t	small
125723	3322	731	Томская область, Чаинский район, село Чаинск, Комсомольская, 14	t	small
125712	3311	720	Томская область, Чаинский район, село Усть-Бакчар, Центральная, 17	f	medium
125728	3327	736	Томская область, Чаинский район, село Трудовой, Трудовой, 22-1	f	small
125710	3309	718	Томская область, Чаинский район, село Третья Тига, Центральная, 23	t	small
125722	3321	730	Томская область, Чаинский район, село Тоинка, Мостовая, 2	t	small
125726	3325	734	Томская область, Чаинский район, село Сухой Лог, Центральная, 24	t	small
125715	3314	723	Томская область, Чаинский район, село Стрельниково, Береговая, 22	t	small
125733	3331	741	Россия, Томская область, Чаинский район, село Подгорное	f	small
125732	3330	740	Томская область, Чаинский район, село Подгорное, МК-44	f	medium
125734	3332	742	Томская область, Чаинский район, село Подгорное, Трактовая, 49	f	medium
125737	3335	745	Томская область, Чаинский район, село Подгорное, Советская, 21б	f	medium
125731	3329	739	Томская область, Чаинский район, село Подгорное, Подлесная, 6,1	f	small
125736	3334	744	Томская область, Чаинский район, село Подгорное, Ленинская, 11	f	medium
125735	3333	743	Томская область, Чаинский район, село Подгорное, Горная, 1	f	medium
125717	3316	725	Томская область, Чаинский район, село Обское, Школьная, 20	f	small
125713	3312	721	Томская область, Чаинский район, село Новые Ключи, Больничная, 5	f	small
125718	3317	726	Томская область, Чаинский район, село Новоколомино, Обская, 24	f	small
125711	3310	719	Томская область, Чаинский район, село Нижняя Тига, Трактовая, 3	f	small
125727	3326	735	Томская область, Чаинский район, село Мушкино, Октябрьская, 29	t	small
125709	3308	717	Томская область, Чаинский район, село Лось-Гора (Шоры-Еры), Трактовая, 9	t	small
125716	3315	724	Томская область, Чаинский район, село Лесоучасток-Чая, Набережная, 23а	t	small
125719	3318	727	Томская область, Чаинский район, село Леботер, Пролетарская, 8	f	small
125720	3319	728	Томская область, Чаинский район, село Коломинские Гривы, Советская, 21	f	medium
125725	3324	733	Томская область, Чаинский район, село Ермиловка, Новая, 23	t	small
125721	3320	729	Томская область, Чаинский район, село Гришкино, Советская, 19	t	small
125729	3328	737	Томская область, Чаинский район, село Григорьевка, Энергетиков, 3	f	small
125708	3307	716	Томская область, Чаинский район, село Гореловка, Центральная, 34	t	small
125714	3313	722	Томская область, Чаинский район, село Варгатер, Центральная, 42	f	small
125707	3306	715	Томская область, Чаинский район, село Бундюр, Школьная, 10	f	small
125673	3261	669	Томская область, Томский район, село Яр, Октябрьская, 80, Дом культуры	t	small
77262	3292	701	Томская область, Томский район, село Чёрная Речка, Береговая, 5, школа	f	large
125689	3282	691	Томская область, Томский район, село Халдеево, Лесная, 1а	t	small
125694	3288	696	Томская область, Томский район, село Турунтаево, Школьная, 4, здание администрации	f	small
125688	3281	690	Томская область, Томский район, село Турунтаево, Школьная, 4, здание администрации	f	small
125757	3355	765	Томская область, Томский район, село Трубачево, Центральная, 7	t	medium
15704	8720	55	Республика Хакасия, Абакан, Тельмана, 93	f	large
125676	3265	673	Томская область, Томский район, село Томское, Маяковского, 1, школа	t	medium
125699	3293	702	Томская область, Томский район, село Тахтамышево, Советская, 42, школа	f	medium
125687	3280	689	Томская область, Томский район, село Сухоречье, Лесная, 34, здание администрации	t	small
125691	3285	693	Томская область, Томский район, село Спасо-Яйское, Сибирская, 53, ООО «ПП Воронино»	t	small
125674	3263	671	Томская область, Томский район, село Синий Утёс, Парковая, 5, школа	t	small
125686	3279	688	Томская область, Томский район, село Семилужки, Иркутский тракт, 2, здание школы	f	medium
77151	2821	219	Томская область, Томский район, поселок Самусь, проспект Ленина, 28	f	large
125654	3236	642	Томская область, Томский район, село Рыбалово, Коммунистическая, 9	f	medium
125651	3233	639	Томская область, Томский район, село Рыбалово, Коммунистическая, 9, Дом культуры	f	small
125696	3290	698	Томская область, Томский район, село Романовка, Новая, 7/1, административное здание	t	small
77261	3273	681	Томская область, Томский район, село Рассвет, 11, административное здание	f	large
125704	3303	712	Томская область, Томский район, село Поросино, Школьная, 2а, школа	t	medium
125690	3283	692	Томская область, Томский район, село Подломск, Молодежная, 9	f	small
125666	3249	658	Томская область, Томский район, село Плотниково, Рабочая, 14, магазин	t	small
125667	3250	659	Томская область, Томский район, село Петухово, Новостройка, 4А, Дом культуры	t	small
125705	3304	713	Томская область, Томский район, село Петрово, Гагарина, 21	t	small
125692	3286	694	Томская область, Томский район, село Перовка, Лесная, 2, ФАП	t	small
77256	3262	670	Томская область, Томский район, село Октябрьское, Железнодорожная, 29а	f	large
125698	3291	700	Томская область, Томский район, село Новорождественское, Советская, 56	t	small
125697	3291	699	Томская область, Томский район, село Новорождественское, Советская, 56	t	medium
125685	3278	687	Томская область, Томский район, село Новомихайловка, Центральная, 49к.2, ФАП	t	small
125693	3287	695	Томская область, Томский район, село Новоархангельское, Советская, 55, Дом культуры	f	small
77266	3284	708	Томская область, Томский район, село Нелюбино, Почтовая, 1, Дом культуры	f	large
125661	3243	652	Томская область, Томский район, село Наумовка, Советская, 7а, здание администрации	t	medium
77250	3239	648	Томская область, Томский район, село Моряковский Затон, Советская, 27	f	large
77249	3238	647	Томская область, Томский район, село Моряковский Затон, Советская, 35, телефон: 927-395	f	large
77248	3225	646	Томская область, Томский район, село Моряковский Затон, Советская, 29	f	large
77259	3271	679	Томская область, Томский район, село Молодёжный, 2, здание Дома культуры	f	large
125664	3247	656	Томская область, Томский район, село Мирный, Трудовая, 2, культурно-спортивный центр	f	medium
125660	3242	651	Томская область, Томский район, село Межениновка, Первомайская, 22, Дом культуры, библиотека	t	small
125658	3240	649	Томская область, Томский район, село Межениновка, Первомайская, 22, Дом культуры	t	small
125695	3289	697	Томская область, Томский район, село Мазалово, Г.Николаевой, 12	t	medium
125681	3275	683	Томская область, Томский район, село Лязгино, Центральная , 19	t	small
125669	3255	663	Томская область, Томский район, село Лучаново, Зеленая, 21а, детский сад телефон: 962-146	f	medium
77032	2708	91	Томская область, Томский район, село Лоскутово, Ленина, 27а	f	large
125652	3234	640	Томская область, Томский район, село Лаврово, Центральная, 25	t	small
77265	3297	706	Томская область, Томский район, село Курлек, Трактовая, 48а	f	large
125703	3301	710	Томская область, Томский район, село Кудринский Участок, Бодажкова, 6, ФАП	t	small
125683	3276	685	Томская область, Томский район, поселок Корнилово, Гагарина, 33	f	medium
125682	3276	684	Томская область, Томский район, поселок Корнилово, Гагарина, 33	f	medium
77260	3272	680	Томская область, Томский район, село Копылово, Новая, 18	f	large
125675	3264	672	Томская область, Томский район, село Коларово, Центральная, 12, Дом культуры	t	small
125655	3237	643	Томская область, Томский район, село Козюлино, Центральная, 40	t	small
77263	3294	703	Томская область, Томский район, село Кисловка, Мира, 16	f	large
77264	3295	704	Томская область, Томский район, село Кафтанчиково, Коммунистическая, 86	f	large
125650	3232	638	Томская область, Томский район, село Карбышево, Центральная, 25, телефон: 250-921	t	small
125700	3296	705	Томская область, Томский район, село Кандинка, Советская, 11а, Дом культуры	f	medium
125701	3298	707	Томская область, Томский район, село Калтай, Ленина , 74	f	medium
77257	3266	674	Томская область, Томский район, село Итатка, Гагарина, 1	t	large
77267	3302	711	Томская область, Томский район, село Зоркальцево, Трактовая, 29	f	large
125657	3216	645	Томская область, Томский район, село Губино, Совхозная, 3, телефон: 916-267	f	small
125345	2872	274	Томская область, Томский район, село Гарь, Почтовая, 4, телефон: 57124	t	small
125525	3096	503	Томская область, Томский район, село Вороново, Уткина, 17	f	medium
125684	3277	686	Томская область, Томский район, село Воронино, Центральная, 74, Дом культуры	t	medium
125671	3259	667	Томская область, Томский район, село Вершинино, Советская, 55, школа	t	small
125653	3235	641	Томская область, Томский район, село Верхнее Сеченово, Ветеранов, 25-1	t	small
125706	3305	714	Томская область, Томский район, село Борики, Школьная, 1, школа	t	small
125665	3248	657	Томская область, Томский район, село Бол. Протопопово, 12 к.31, комендантская о/л Восход	t	small
77253	3252	661	Томская область, Томский район, село Богашево, Советская, 6	f	large
77252	3251	660	Томская область, Томский район, село Богашево, Новостройка, 1а	f	large
125649	3231	637	Томская область, Томский район, село Берёзкино, Сибирская, 25	t	small
125668	3254	662	Томская область, Томский район, село Белоусово, Мира, 8, клуб-филиал	t	small
125530	3101	508	Томская область, Томский район, село Батурино, Школьная, 1	t	small
125680	3274	682	Томская область, Томский район, село Аркашево, Озерная, 2/2, мед.пункткаб. фельдшера	t	small
125416	2976	376	Томская область, Томский район, село Александровское, мкр.Казахстан, 16	f	medium
77216	2966	365	Томская область, Томский район, село Александровское, Советская, 32	f	large
125677	3267	675	Томская область, Томский район, село Александровское, Пионерская, 2, здание администрации	t	medium
77219	2975	375	Томская область, Томский район, село Александровское, Ленина, 9	f	large
125702	3300	709	Томская область, Томский район, село 86-й Квартал, Школьная, 31а	t	small
125638	3217	624	Томская область, Тегульдетский район, село Четь-Конторка, Садовая, 2/1, МОУ ""Четь-Конторская ООШ""	t	small
125648	3230	636	Томская область, Тегульдетский район, село Черный Яр, п. Орловка, Щитовая, 6, МОУ Черноярская СОШ	f	small
125639	3218	625	Томская область, Тегульдетский район, село Центрополигон, Советская, 4, Центрополигонский библиотечно-досуговый центр	t	small
77246	3222	629	Томская область, Тегульдетский район, село Тегульдет, Садовая, 12, РЦТ и Д	f	large
125641	3220	627	Томская область, Тегульдетский район, село Тегульдет, Пушкина, 34, Южный филиал ГУП ТО Областное ДРСУ телефон: 2-19-31	f	small
125640	3219	626	Томская область, Тегульдетский район, село Тегульдет, Парковая, 52, филиал Тегульдетское лесничество	f	small
77247	3223	630	Томская область, Тегульдетский район, село Тегульдет, Октябрьская, 37, ОГОУ НПО ПУ-36	f	large
125642	3221	628	Томская область, Тегульдетский район, село Тегульдет, Ленина, 35, МУЗ Тегульдетская ЦРБ	f	small
125637	3215	623	Томская область, Тегульдетский район, село Покровский Яр, Лесная, 3, Покровоярский библиотечно-досуговый центр	t	small
125647	3229	635	Томская область, Тегульдетский район, село Озерное, Озерская, 8/1, ФАП	t	small
125646	3228	634	Томская область, Тегульдетский район, село Новошумилово, Новая, 17, Новошумиловский библиотечно-досуговый центр	t	small
125636	3214	622	Томская область, Тегульдетский район, село Куяновская Гарь, Куяновская, 4	t	small
125643	3224	631	Томская область, Тегульдетский район, село Красный Яр, Ленинская, 17, МОУ Берегаевская СОШ	f	medium
125524	3095	502	Томская область, Тегульдетский район, село Красный Яр, Коммунистическая, 40	t	small
125644	3226	632	Томская область, Тегульдетский район, село Красная Горка, Советская, 31	t	small
125448	3010	411	Томская область, Тегульдетский район, село Белый Яр, Чкалова, 8	f	medium
125645	3227	633	Томская область, Тегульдетский район, село Белый Яр, Центральная, 2, Администрация	t	small
125635	3213	621	Томская область, Тегульдетский район, село Байгалы, Байгалинская, 15, ФАП	t	small
15658	8720	9	Республика Хакасия, Абакан, Тельмана, 93	f	large
125615	3188	598	Томская область, Первомайский район, село Францево, Здание ФАП	t	small
125621	3194	604	Томская область, Первомайский район, село Успенка, 38 кв. 2, здание медпункта	t	small
77242	3181	591	Томская область, Первомайский район, село Улу-Юл, Комарова, 26, здание дома культуры	f	large
125611	3184	594	Томская область, Первомайский район, село Улу-Юл, Дорожная, 1, здание школы	t	small
125632	3210	618	Томская область, Первомайский район, село Уйданово, Центральная, 37, здание дома культуры	t	small
125618	3191	601	Томская область, Первомайский район, село Узень, Дом культуры	t	small
125628	3205	614	Томская область, Первомайский район, село Туендат, Шамского, 26, здание дома культуры	t	small
125625	3202	611	Томская область, Первомайский район, село Торбеево, Советская, 38а, здание дома культуры	t	small
125616	3189	599	Томская область, Первомайский район, село Сергеево, Школьная, 3, здание дома культуры	t	medium
125617	3190	600	Томская область, Первомайский район, село Сахалинка, Дом культуры	t	small
77245	3197	607	Томская область, Первомайский район, село Первомайское, Ленинская , 108, контора ДРСУ	f	large
77243	3195	605	Томская область, Первомайский район, село Первомайское, Ленинская, 33, здание районного Дома культуры	f	large
125609	3182	592	Томская область, Первомайский район, село Первомайское, микрорайон Первомайский, Комсомольская , 33/1	t	small
77244	3196	606	Томская область, Первомайский район, село Первомайское, Больничная, 32, здание Асиновского межрайонного Узла связи	f	large
125629	3206	615	Томская область, Первомайский район, село Орехово, Ленина, 9, здание дома культуры	t	medium
125623	3200	609	Томская область, Первомайский район, село Новый, Клубная, 2, здание Дома культуры	f	medium
125627	3204	613	Томская область, Первомайский район, село Новомариинка, Центральная улица, 42, здание дома культуры	t	small
125634	3212	620	Томская область, Первомайский район, село Малиновка, Центральная, 16, здание медпункта	t	small
125626	3203	612	Томская область, Первомайский район, село Ломовицк 2, Центральная улица, 13, здание дома культуры	t	small
125630	3208	616	Томская область, Первомайский район, село Куяново, Центральная, 18, здание дома культуры	t	small
125624	3201	610	Томская область, Первомайский район, село Крутоложное, 40 Лет Победы, 28 а, здание дома культуры	t	small
125613	3186	596	Томская область, Первомайский район, поселок Комсомольск, Первомайская, 10а, здание школы	f	medium
125612	3185	595	Томская область, Первомайский район, поселок Комсомольск, Первомайская, 11а	f	medium
125631	3209	617	Томская область, Первомайский район, село Калмаки, Центральная, 14, здание школы	t	small
125678	3268	676	Томская область, Первомайский район, село Заречный, Светлая, 9	t	small
125620	3193	603	Томская область, Первомайский район, село Ежи, Советская, 23, здание дома культуры	t	small
125619	3192	602	Томская область, Первомайский район, село Вознесенка, Сергеевское , Дом культуры	t	small
125633	3211	619	Томская область, Первомайский район, село Берёзовка, Центральная, 1, здание дома культуры	t	small
125622	3199	608	Томская область, Первомайский район, село Беляй, Зеленая, 1, здание дома культуры	f	medium
125614	3187	597	Томская область, Первомайский район, село Балагачёво, здание ФАП	t	small
125610	3183	593	Томская область, Первомайский район, село Альмяково, Советская улица, 32, здание Администрации сельского поселения	t	small
125608	3180	590	Томская область, Парабельский район, поселок Шпалозавод, Центральная, 2	t	medium
125606	3178	588	Томская область, Парабельский район, деревня Усть-Чузик, Набережная, 4	t	small
125605	3177	587	Томская область, Парабельский район, село Толмачево, Молодёжная, 1а	t	small
125604	3176	586	Томская область, Парабельский район, поселок Тарск, Школьная, 3	t	small
125603	3175	585	Томская область, Парабельский район, поселок Талиновка, Центральная, 5	t	small
125602	3174	584	Томская область, Парабельский район, село Старица, Советская, 56	t	small
125369	2898	298	Томская область, Парабельский район, село Рогалёво, Рабочая, 7	t	small
125601	3173	583	Томская область, Парабельский район, поселок Прокоп, Центральная, 24	t	small
125599	3169	579	Томская область, Парабельский район, село Парабель, Шишкова, 75	f	small
125600	3172	582	Томская область, Парабельский район, село Парабель, Советская, 78	f	medium
77241	3171	581	Томская область, Парабельский район, село Парабель, Советская, 78	f	large
77239	3168	578	Томская область, Парабельский район, село Парабель, Советская, 36	f	large
77238	3167	577	Томская область, Парабельский район, село Парабель, Советская, 21	f	large
77240	3170	580	Томская область, Парабельский район, село Парабель, Некрасова, 1а	f	large
125598	3166	576	Томская область, Парабельский район, село Новосельцево, Лесная, 1а	f	small
125597	3165	575	Томская область, Парабельский район, Новиково, Совхозная, 3, телефон: 27780	t	small
125595	3163	573	Томская область, Парабельский район, деревня Нельмач, Сибирская, 22	t	small
125594	3162	572	Томская область, Парабельский район, село Нарым, Куйбышева, 16	t	medium
125596	3164	574	Томская область, Парабельский район, деревня Малое Нестерово, Трудовая, 20	t	small
125368	2897	297	Томская область, Парабельский район, село Лушниково, Геологическая, 33, телефон: 34-506	f	small
125593	3161	571	Томская область, Парабельский район, деревня Луговское, Молодежная, 14	t	small
125591	3159	569	Томская область, Парабельский район, поселок Кирзавод, Центральная, 40	t	medium
125366	2895	295	Томская область, Парабельский район, Кедровый, поселок Останино, Лесная, 3	f	small
125590	3158	568	Томская область, Парабельский район, поселок Заводской, 60 Лет СССР, 17	t	small
125607	3179	589	Томская область, Парабельский район, деревня Верхняя Чигара, Красноармейская, 19	t	small
125588	3156	566	Томская область, Парабельский район, село Алатаево, Советская, 15	t	small
125568	3139	546	Томская область, Молчановский район, село Фёдоровка (Нижняя Фёдоровка), Зеленая, 15	t	small
125574	2489	552	Томская область, Молчановский район, село Тунгусово, Школьная, 2	f	small
125575	2621	553	Томская область, Молчановский район, село Тунгусово, Центральная, 23	f	small
125576	3144	554	Томская область, Молчановский район, село Тунгусово, Кнакиса, 5	f	small
125586	3154	564	Томская область, Молчановский район, село Сулзат, Клубная, 1	t	small
125587	3155	565	Томская область, Молчановский район, село Суйга, Комарова, 29	t	medium
125570	3141	548	Томская область, Молчановский район, село Соколовка, Центральная, 53	f	small
125578	3146	556	Томская область, Молчановский район, село Сарафановка, Школьная, 38	f	small
125453	3018	419	Томская область, Молчановский район, поселок Сайга, Молодогвардейская, 3	f	medium
125580	3148	558	Томская область, Молчановский район, поселок Нарга (Новостройка), Свердлова, 9, телефон: 32475	f	medium
125579	3147	557	Томская область, Молчановский район, поселок Нарга (Новостройка), Карла Маркса, 41	f	medium
125561	3132	539	Томская область, Молчановский район, село Молчаново, Советская , 13	f	medium
125567	3138	545	Томская область, Молчановский район, село Молчаново, Комарова, 2А	f	medium
125565	3136	543	Томская область, Молчановский район, село Молчаново, Западная, 1а	f	medium
125562	3133	540	Томская область, Молчановский район, село Молчаново, Димтрова, 40	f	medium
125564	3135	542	Томская область, Молчановский район, село Молчаново, Димитрова, 78	f	medium
125563	3134	541	Томская область, Молчановский район, село Молчаново, Димитрова, 71	f	medium
125566	3137	544	Томская область, Молчановский район, село Молчаново, Валикова, 17а	f	medium
125583	3151	561	Томская область, Молчановский район, поселок Могочин, Октябрьская улица, 10	f	medium
125582	3150	560	Томская область, Молчановский район, поселок Могочин, Октябрьская, 5	f	medium
125584	3152	562	Томская область, Молчановский район, поселок Могочин, Калинина, 33	f	medium
125581	3149	559	Томская область, Молчановский район, поселок Могочин, Вокзальный переулок, 10	f	medium
125569	3140	547	Томская область, Молчановский район, село Майково, Школьная, 13	t	small
125573	3127	551	Томская область, Молчановский район, село Колбинка, Мира, 20	t	small
125585	3153	563	Томская область, Молчановский район, село Игреково, Центральная , 24/1	t	small
125571	3142	549	Томская область, Молчановский район, село Гришино, Луговая, 30	t	small
125577	3145	555	Томская область, Молчановский район, село Верхняя Фёдоровка, Центральная, 14-1	t	small
125551	3121	529	Томская область, Кривошеинский район, село Рыбалово, Колхозная, 35А	t	small
125544	3114	522	Томская область, Кривошеинский район, село Пудовка, Центральная, 64	t	small
125466	3029	432	Томская область, Зырянский район, село Причулымский, Степная, 15	f	medium
125552	3122	530	Томская область, Кривошеинский район, село Петровка, Комсомольская, 12	f	small
125548	3118	526	Томская область, Кривошеинский район, село Новониколаевка, Центральная, 28	t	small
125543	3113	521	Томская область, Кривошеинский район, село Новокривошеино, Школьная, 2	t	small
125542	3112	520	Томская область, Кривошеинский район, село Новоисламбуль (Чёрная Речка), Светлая, 36	t	small
125555	3125	533	Томская область, Кривошеинский район, село Никольское, перулок Центральный, 6	t	small
125508	3074	481	Томская область, Кривошеинский район, село Малиновка, Школьная, 13	t	small
77258	3270	678	Томская область, Кривошеинский район, село Малиновка, Чулымская, 30, здание администрации	f	large
125679	3269	677	Томская область, Кривошеинский район, село Малиновка, Чулымская, 30, здание администрации	f	small
125545	3115	523	Томская область, Кривошеинский район, село Малиновка, Рабочая, 22	t	small
125534	3104	512	Томская область, Кривошеинский район, село Кривошеино, проспект Ленина, 30	f	medium
125537	3107	515	Томская область, Кривошеинский район, село Кривошеино, Октябрьская, 24	f	medium
125539	3109	517	Томская область, Кривошеинский район, село Кривошеино, Ленина, 9	f	medium
125535	3105	513	Томская область, Кривошеинский район, село Кривошеино, Коммунистическая, 43	f	small
125536	3106	514	Томская область, Кривошеинский район, село Кривошеино, Зеленая, 37А, телефон: 21168	f	medium
125540	3110	518	Томская область, Кривошеинский район, село Кривошеино, Заводская, 14	f	medium
125559	3130	537	Томская область, Кривошеинский район, поселок Красный Яр, Школьная, 1	f	medium
125557	3128	535	Томская область, Кривошеинский район, поселок Красный Яр, Советская, 19	f	medium
125558	3129	536	Томская область, Кривошеинский район, поселок Красный Яр, Осиновский, 1	f	medium
125556	3126	534	Томская область, Кривошеинский район, село Карнаухово, Центральная, 26	t	small
125550	3120	528	Томская область, Кривошеинский район, село Иштан, Школьная, 1	f	small
125541	3111	519	Томская область, Кривошеинский район, село Жуково, Центральная , 21	f	small
125553	3123	531	Томская область, Кривошеинский район, село Елизарьево, Советская, 22	t	small
125554	3124	532	Томская область, Кривошеинский район, село Егорово, Центральная, 4	t	small
125546	3116	524	Томская область, Кривошеинский район, село Володино, Советская, 31	f	medium
125547	3117	525	Томская область, Кривошеинский район, село Володино, Коммунистическая, 39	f	small
125560	3131	538	Томская область, Кривошеинский район, село Вознесенка, Центральная, 27	t	small
125549	3119	527	Томская область, Кривошеинский район, село Белосток, Школьная, 35	t	small
125402	2948	346	Томская область, Колпашевский район, деревня Юдино, Совхозная, 14	t	small
125399	2944	343	Томская область, Колпашевский район, деревня Чугунка, Центральная, 43	t	small
77203	2932	331	Томская область, Колпашевский район, село Чажемто, Фестивальная, 4	f	large
125391	2936	335	Томская область, Колпашевский район, Чажемто, Магистральная, 4, телефон: 21263	f	medium
125395	2940	339	Томская область, Колпашевский район, поселок Усть-Чая, Кооперативная, 1, телефон: 32421	t	small
125384	2926	325	Россия, Томская область	f	small
77199	2924	323	Томская область, Колпашевский район, село Тогур, Советская, 64	f	large
77200	2925	324	Томская область, Колпашевский район, село Тогур, Свердлова, 15, телефон: 57682	f	large
125383	2922	322	Томская область, Колпашевский район, село Тогур, Мичурина, 8, телефон: 46270	f	medium
77202	2929	328	Томская область, Колпашевский район, село Тогур, Лермонтова, 40	f	large
77201	2928	327	Томская область, Колпашевский район, село Тогур, Лермонтова, 40	f	large
125385	2927	326	Томская область, Колпашевский район, село Тогур, Источная улица, 6-2	t	small
125397	2942	341	Томская область, Колпашевский район, деревня Тискино, Братская, 29	t	small
125390	2935	334	Томская область, Колпашевский район, село Старокороткино, Центральная, 43	f	small
125387	2931	330	Россия, Томская область, Колпашевский район, деревня Север	t	small
125389	2934	333	Томская область, Колпашевский район, село Озерное, Трактовая, 9	f	medium
125400	2945	344	Томская область, Колпашевский район, село Новоселово, Центральная, 36	f	medium
125398	2943	342	Томская область, Колпашевский район, село Новоильинка, пер.Школьный, 6	f	small
15651	8714	2	Республика Хакасия, Абакан, Хакасская, 68	f	large
125394	2939	338	Томская область, Колпашевский район, деревня Новогорное, Береговая, 42	f	small
125388	2933	332	Томская область, Колпашевский район, деревня Могильный-Мыс, Зеленая, 22	f	small
125401	2946	345	Томская область, Колпашевский район, деревня Маракса 1-я, Юбилейная, 24	f	small
125405	2951	349	Томская область, Колпашевский район, поселок Куржино, Лесная, 2	t	small
125408	2954	352	Томская область, Колпашевский район, Копыловка, Школьная, 1	t	small
77193	2907	308	Томская область, Колпашевский район, Колпашево, микрорайон Геолог, 20	f	large
77189	2886	300	Томская область, Колпашевский район, Колпашево, переулок Чапаева, 23, телефон: 51123	f	large
77195	2914	314	Томская область, Колпашевский район, Колпашево, переулок Озерный, 10	f	large
125379	2915	315	Томская область, Колпашевский район, Колпашево, переулок Лазо, 6	f	medium
77191	2903	304	Томская область, Колпашевский район, Колпашево, Толстого, 14	f	large
125375	2909	310	Томская область, Колпашевский район, Колпашево, Портовая, 64, телефон: 41844	t	medium
77192	2905	306	Томская область, Колпашевский район, Колпашево, Победы, 12	f	large
125370	2876	299	Томская область, Колпашевский район, Колпашево, Победы, 75	f	medium
125382	2921	321	Томская область, Колпашевский район, Колпашево, Науки, 20	f	medium
125377	2912	312	Томская область, Колпашевский район, Колпашево, Комсомольская, 3/1	f	medium
125378	2913	313	Томская область, Колпашевский район, Колпашево, Коммунистическая, 4	f	medium
77194	2908	309	Томская область, Колпашевский район, Колпашево, Кирова, 32	f	large
125374	2906	307	Томская область, Колпашевский район, Колпашево, Кирова, 30	f	medium
77190	2901	302	Томская область, Колпашевский район, Колпашево, Кирова, 45	f	large
125376	2910	311	Томская область, Колпашевский район, Колпашево, Дорожная, 24	f	medium
77196	2916	316	Томская область, Колпашевский район, Колпашево, Горького, 22	f	large
77198	2920	320	Томская область, Колпашевский район, Колпашево, Гоголя, 99	f	large
125381	2919	319	Томская область, Колпашевский район, Колпашево, Гоголя, 87	f	medium
125380	2918	318	Томская область, Колпашевский район, Колпашево, Гоголя, 91/1	f	medium
77197	2917	317	Томская область, Колпашевский район, Колпашево, Гоголя, 87/2	f	large
125406	2952	350	Томская область, Колпашевский район, Инкино, Кооперативный, 11, телефон: 93136	f	medium
125407	2953	351	Томская область, Колпашевский район, село Иванкино, Школьная, 7	t	small
125404	2950	348	Томская область, Колпашевский район, поселок Дальнее, Школьная, 1/1	t	small
125386	2930	329	Томская область, Колпашевский район, деревня Волково, Волкова, 18/1	t	small
125396	2941	340	Томская область, Колпашевский район, деревня Большая Саровка, Советская, 35/1	f	medium
125403	2949	347	Томская область, Колпашевский район, деревня Белояровка, Мира, 9	t	small
125529	3100	507	Томская область, Кожевниковский район, село Чилино, Советская, 1	f	medium
125514	3080	487	Томская область, Кожевниковский район, село Хмелевка, Советская, 59	t	small
77237	3094	501	Томская область, Кожевниковский район, село Уртам, Фрунзе, 25	f	large
125515	3081	488	Томская область, Кожевниковский район, село Терсалгай, Зеленая, 4	t	small
125532	3040	510	Томская область, Кожевниковский район, село Тека, Школьная, 1	t	small
125511	3077	484	Томская область, Кожевниковский район, село Старая Ювала, Ульяновская, 34	f	medium
125522	3092	499	Томская область, Кожевниковский район, село Сафроновка, Школьная, 4	t	small
125516	3082	489	Томская область, Кожевниковский район, село Песочнодубровка, Молодежная, 37	f	medium
125527	3098	505	Томская область, Кожевниковский район, село Осиновка, Мира, 13	f	small
125533	3103	511	Томская область, Кожевниковский район, село Новосергеевка, Молодёжная, 8	t	small
125521	3091	498	Томская область, Кожевниковский район, село Новопокровка, Садовая, 2А	f	small
125518	3084	491	Томская область, Кожевниковский район, село Муллова, Центральная, 22	t	small
125517	3083	490	Томская область, Кожевниковский район, село Кожевниково-на-Шегарке, Комсомольская, 24	t	small
77235	3087	494	Томская область, Кожевниковский район, село Кожевниково, Ленина, 10	f	large
77233	3085	492	Томская область, Кожевниковский район, село Кожевниково, Кирова, 40	f	large
77236	3088	495	Томская область, Кожевниковский район, село Кожевниково, Гагарина, 9	f	large
77234	3086	493	Томская область, Кожевниковский район, село Кожевниково, Гагарина, 20	f	large
125519	3089	496	Томская область, Кожевниковский район, село Киреевск, Карла Маркса, 21	t	small
125510	3076	483	Томская область, Кожевниковский район, село Зайцево, Школьная, 24	f	small
125528	3099	506	Томская область, Кожевниковский район, село Ерестная, Школьная, 10, телефон: 34448	t	small
125526	3097	504	Томская область, Кожевниковский район, село Еловка, Новая, 10	f	small
125512	3078	485	Томская область, Кожевниковский район, село Елгай, Школьная, 2	t	small
125523	3093	500	Томская область, Кожевниковский район, село Десятово, Школьная, 15А, телефон: 23458	f	small
125509	3075	482	Томская область, Кожевниковский район, село Борзуновка, Гагарина, 25, телефон: 54132	t	small
125531	3102	509	Томская область, Кожевниковский район, село Базой, Советская, 16	f	small
125520	3090	497	Томская область, Кожевниковский район, село Аркадьево, Октябрьская, 10	f	small
125513	3079	486	Томская область, Кожевниковский район, село Аптала, Садовая, 13	t	small
125504	3070	477	Томская область, Каргасокский район, д. Лозунга, Береговая, 39	t	small
125487	3048	455	Томская область, Каргасокский район, село Усть-Тым, Береговая, 62	t	small
125501	3067	474	Томская область, Каргасокский район, село Тымск, Кедровая, 16	t	small
125505	3071	478	Томская область, Каргасокский район, село Староюгино, Лесная, 16а	t	small
125486	3045	452	Томская область, Каргасокский район, деревня Старая Березовка, Центральная, 5	t	small
77226	3046	453	Томская область, Каргасокский район, поселок Средний Васюган, Студенческая, 11	t	large
125498	3064	471	Томская область, Каргасокский район, село Сосновка, Школьная, 18	t	small
125502	3068	475	Томская область, Каргасокский район, село Пятый километр, Тополевая, 16	t	small
125497	3063	470	Томская область, Каргасокский район, село Павлово, Школьная, 1	f	medium
125485	3044	451	Томская область, Каргасокский район, Новый Тевриз, Центральная, 5	t	small
77227	3047	454	Томская область, Каргасокский район, поселок Новый Васюган, Советская, 49	t	large
125506	3072	479	Томская область, Каргасокский район, поселок Новоюгино, Центральная, 44/2	t	small
125489	3050	457	Россия, Орловская область, Орел, Студенческая улица, 5	t	small
125492	3053	460	Томская область, Каргасокский район, село Напас, Кооперативная, 1/1	t	small
125493	3054	461	Томская область, Каргасокский район, село Мыльджино, Береговая, 41	t	small
125491	3052	459	Томская область, Каргасокский район, поселок Молодежный, Гагарина, 10, телефон: 44-1-41	t	small
125500	3066	473	Томская область, Каргасокский район, село Киндал, Школьная, 4	t	small
125490	3051	458	Томская область, Каргасокский район, село Киевский, Лесная, 4	t	small
125496	3062	469	Томская область, Каргасокский район, село Каргасок, Энтузиастов, 2	f	medium
125495	3059	466	Томская область, Каргасокский район, Каргасок, Советская, 40	f	medium
77230	3057	464	Томская область, Каргасокский район, село Каргасок, Октябрьская, 97	f	large
77228	3055	462	Томская область, Каргасокский район, село Каргасок, Октябрьская, 1	f	large
77229	3056	463	Томская область, Каргасокский район, Каргасок, М. Горького, 16	f	large
77232	3061	468	Томская область, Каргасокский район, село Каргасок, Лугинецкая, 1	f	large
125494	3058	465	Томская область, Каргасокский район, село Каргасок, Кирова, 104	f	medium
125499	3065	472	Томская область, Каргасокский район, поселок Восток, Заводская, 22	t	small
125488	3049	456	Томская область, Каргасокский район, село Вертикос, Молодежная, 1	f	small
125503	3069	476	Томская область, Каргасокский район, село Бондарка, Центральная, 58	t	small
125507	3073	480	Томская область, Каргасокский район, деревня Большая Грива, Советская, 6	t	small
125479	2804	445	Томская область, Зырянский район, село Шиняево, Луговая, 54/1	t	small
125483	3042	449	Томская область, Зырянский район, село Чердаты, Советская, 1а	f	medium
125468	3031	434	Томская область, Зырянский район, село Цыганово, Чапаева, 62	f	small
125476	3039	442	Томская область, Зырянский район, село Тукай, Лесная, 1	t	small
125474	3037	440	Томская область, Зырянский район, село Туендат, Нагорная, 9	t	small
125469	3032	435	Томская область, Зырянский район, село Семёновка, Боровая, 3	f	medium
125482	3041	448	Томская область, Зырянский район, село Прушинский, Береговая, 10	t	small
125475	3038	441	Томская область, Зырянский район, село Окунеево, Октябрьская, 32	t	small
125471	3034	437	Томская область, Зырянский район, село Мишутино, Центральная, 56	t	small
125484	3043	450	Россия, Рязанская область, Ряжский район, поселок Кучуково	t	small
125465	3028	431	Томская область, Зырянский район, село Красноярка, Школьная, 1	f	small
125481	2923	447	Томская область, Зырянский район, село Иловка, Чкалова, 1	f	small
125462	3025	428	Томская область, Зырянский район, село Зырянское, Советская, 111	f	medium
125461	3024	427	Томская область, Зырянский район, село Зырянское, Советская, 18	f	medium
125459	2748	425	Томская область, Зырянский район, село Зырянское, Свердлова, 25	f	small
125457	3022	423	Томская область, Зырянский район, село Зырянское, Калинина, 1	f	medium
125458	2633	424	Томская область, Зырянский район, село Зырянское, Калинина, 90	f	small
125463	3026	429	Томская область, Зырянский район, село Зырянское, Ефанова, 22	f	medium
125470	3033	436	Томская область, Зырянский район, село Дубровка, Новая, 1	t	small
125472	3035	438	Томская область, Зырянский район, село Громышевка, Ленина, 103	t	small
125478	2775	444	Томская область, Зырянский район, село Высокое, Мира, 62/3	t	small
125464	3027	430	Томская область, Зырянский район, село Богословка, Горького, 2, телефон: 35123	f	medium
125467	3030	433	Томская область, Зырянский район, село Берлинка, Луговая, 68	f	medium
125480	2911	446	Томская область, Зырянский район, село Беловодовка, Советская, 45	t	small
77150	2820	218	Томская область, ЗАТО Северск, поселок Самусь, проспект Ленина, 28	f	large
125451	3016	417	Томская область, Верхнекетский район, поселок Ягодное, Советская, 2	f	medium
125450	3015	416	Томская область, Верхнекетский район, поселок Центральный, пер. Школьный, 11	t	small
77224	3012	413	Томская область, Верхнекетский район, поселок Степановка, Аптечный переулок, 2	f	large
125456	3021	422	Томская область, Верхнекетский район, село Палочка, Молодежная, 26	t	small
125452	3017	418	Томская область, Верхнекетский район, Нибегинский, Новошкольная, 1	t	small
125455	3020	421	Томская область, Верхнекетский район, поселок Макзыр, Центральная, 16	t	small
125454	3019	420	Томская область, Верхнекетский район, поселок Лисица, Таежная, 16, телефон: 3-51-31	t	small
77225	3013	414	Томская область, Верхнекетский район, поселок Клюквинка, Центральная, 4	f	large
77223	3011	412	Томская область, Верхнекетский район, поселок Катайга, Кирова, 39	t	large
125449	3014	415	Томская область, Верхнекетский район, поселок Дружный, Центральная, 3	f	small
77220	3006	407	Томская область, Верхнекетский район, поселок Белый Яр, Чкалова, 8	f	large
77222	3008	409	Томская область, Верхнекетский район, поселок Белый Яр, Котовского, 1 строение 1, пом у-2, телефон: 2-19-98	f	large
77221	3007	408	Томская область, Верхнекетский район, поселок Белый Яр, Гагарина, 55	f	large
125447	3009	410	Томская область, Верхнекетский район, Белый Яр, Вокзальная, 7 А	f	medium
125421	2981	381	Томская область, Бакчарский район, село Чумакаевка, Центральная, 10, телефон: 36191	t	small
125434	2993	394	Томская область, Бакчарский район, село Чернышевка, Центральная, 1	f	small
125438	2997	398	Томская область, Бакчарский район, хутор Хуторское, Центральная, 17	t	small
125431	2991	391	Томская область, Бакчарский район, село Сухое, Центральная, 24-1	t	small
125437	2996	397	Томская область, Бакчарский район, село Пчелка, Центральная, 6-1	f	small
125420	2980	380	Томская область, Бакчарский район, село Поротниково, Советская, 19	f	small
125419	2979	379	Томская область, Бакчарский район, село Полынянка, Мира, 18	t	small
125418	2978	378	Томская область, Бакчарский район, село Плотниково, Школьная, 4, телефон: 39436	f	medium
125422	2982	382	Томская область, Бакчарский район, село Первомайск (Воробьёвка), Луговая, 9	t	small
125442	3001	402	Томская область, Бакчарский район, село Парбиг, Советская, 76, телефон: 44286	f	small
125441	3000	401	Томская область, Бакчарский район, село Парбиг, Новосибирская, 10, телефон: 44380	f	medium
125443	3002	403	Томская область, Бакчарский район, село Парбиг, Кооперативная, 13	f	medium
125435	2994	395	Томская область, Бакчарский район, село Панычево, Центральная, 24-2	t	small
125444	3003	404	Томская область, Бакчарский район, село Новая Бурка, Ленина, 25	t	small
125446	3005	406	Томская область, Бакчарский район, село Кёнга, Совесткая, 41	t	small
125440	2999	400	Томская область, Бакчарский район, село Крыловка, Школьная , 11	f	small
125445	3004	405	Томская область, Бакчарский район, село Кедровка, Центральная, 15-2	t	small
125589	3157	567	Томская область, Бакчарский район, село Высокий Яр	t	small
125439	2998	399	Томская область, Бакчарский район, село Высокий Яр, Больничный, 16	f	small
125432	2504	392	Томская область, Бакчарский район, село Вавиловка, Центральная, 2	f	small
125417	2977	377	Томская область, Бакчарский район, село Бородинск, Школьная, 22	t	small
125433	2992	393	Томская область, Бакчарский район, село Большая Галка, Центральная , 28	t	small
125436	2995	396	Томская область, Бакчарский район, село Богатырёвка, Ленина, 10	f	small
125423	2983	383	Томская область, Бакчарский район, село Бакчар, Целинная, 11	f	medium
125429	2989	389	Томская область, Бакчарский район, село Бакчар, Трактовый, 27	f	medium
125425	2985	385	Томская область, Бакчарский район, село Бакчар, Октябрьская, 62	f	medium
125430	2990	390	Томская область, Бакчарский район, село Бакчар, Ленина, 44, телефон 41564	f	small
125426	2986	386	Томская область, Бакчарский район, село Бакчар, Ленина, 44, телефон: 21371	f	medium
125428	2988	388	Томская область, Бакчарский район, село Бакчар, Вицмана, 2	f	small
125424	2984	384	Томская область, Бакчарский район, село Бакчар, Вицмана, 2, телефон: 21272	f	medium
125348	2875	277	Томская область, Асиновский район, село Ново-Кусково, Библиотечная, 8	f	small
125361	2890	290	Томская область, Асиновский район, село Ягодное, Школьная, 1д	f	medium
125363	2892	292	Томская область, Асиновский район, село Цветковка, Советская, 35-1	t	small
125350	2878	279	Томская область, Асиновский район, село Филимоновка, Школьная, 2	f	small
125357	2885	286	Томская область, Асиновский район, село Феоктистовка, Волкова, 36	t	small
125360	2889	289	Томская область, Асиновский район, село Тихомировка, Береговая, 36	t	small
125353	2881	282	Томская область, Асиновский район, село Светлый, имени Б.Н.Сидоренко, 6	f	small
125358	2887	287	Томская область, Асиновский район, село Победа, Советская, 22	t	small
125341	2868	270	Томская область, Асиновский район, село Первопашинск (Кайлушка), Береговая, 13, телефон: 30243	t	small
125347	2874	276	Томская область, Асиновский район, село Новониколаевка, Школьная, 2	f	medium
125349	2877	278	Томская область, Асиновский район, село Ново-Кусково, Школьная, 57, телефон: 45122	f	medium
125352	2880	281	Томская область, Асиновский район, село Новиковка, Советская, 14	f	small
125355	2883	284	Томская область, Асиновский район, село Нижние Соколы, Центральная, 40/1	t	small
125354	2882	283	Томская область, Асиновский район, село Моисеевка, пер.Школьный, 1	t	small
125342	2869	271	Томская область, Асиновский район, село Михайловка, Центральная, 14А	t	small
125344	2871	273	Томская область, Асиновский район, село Минаевка, Больничный переулок, 1	f	medium
125362	2891	291	Томская область, Асиновский район, село Мало-Жирово, Центральная, 70	f	small
125343	2870	272	Томская область, Асиновский район, село Копыловка, Береговая, 6а	t	small
125351	2879	280	Томская область, Асиновский район, село Казанка, Партизанская, 73	f	small
125356	2884	285	Томская область, Асиновский район, село Воронино-Пашня, Новая, 4	t	small
125748	3346	756	Томская область, Асиновский район, село Вознесенка, Советская, 37	f	small
125346	2873	275	Томская область, Асиновский район, село Большой Кордон, Центральная, 8	f	small
125359	2888	288	Томская область, Асиновский район, село Больше-Дорохово, Центральная, 26	f	small
125340	2867	269	Томская область, Асиновский район, поселок Батурино, Рабочая, 59	f	medium
125339	2721	268	Томская область, Асиновский район, поселок Батурино, Рабочая, 21	f	medium
125746	3344	754	Томская область, Асиновский район, поселок Батурино, Новая, 1	t	small
125338	2866	267	Томская область, Асиновский район, поселок Батурино, Железнодорожная, 26	t	small
77179	2848	250	Томская область, Асиновский район, Асино	f	large
125332	2852	254	Томская область, Асиновский район, Асино, проспект Ленина, 19	f	medium
125333	2853	255	Томская область, Асиновский район, Асино, Советская, 46	f	medium
125335	2863	264	Томская область, Асиновский район, Асино, Свободы, 2	t	medium
77188	2862	263	Томская область, Асиновский район, Асино, Павлика Морозова, 6	f	large
125336	2864	265	Томская область, Асиновский район, Мирная, 39	f	medium
125337	2865	266	Томская область, Асиновский район, Асино, Кирова, 8	f	medium
77180	2849	251	Томская область, Асиновский район, Асино, Ивана Буева, 38	f	large
125330	2847	249	Томская область, Асиновский район, Асино, Гончарова, 268	t	small
77182	2854	256	Томская область, Асиновский район, Асино, В.В.Липатова, 11	f	large
77185	2859	260	Томская область, Асиновский район, Асино, Боровая, 5	f	large
77186	2860	261	Томская область, Асиновский район, Асино, 370 Стрелковой дивизии, 26а	f	large
125411	2969	368	Томская область, Александровский район, поселок Северный, Дорожная , 4	t	small
125412	2970	369	Томская область, Александровский район, деревня Октябрьский, Школьная, 4	t	small
125413	2971	370	Томская область, Александровский район, село Новоникольское, Школьный, 5 стр.1	t	small
125414	2972	371	Томская область, Александровский район, село Назино, Молодежная, 9/1	t	small
125415	2973	372	Томская область, Александровский район, село Лукашкин Яр, Центральная, 6	t	small
125410	2968	367	Томская область, Александровский район, село Ларино, Обская, 10	t	small
77217	2947	373	Томская область, Александровский район, село Александровское, переулок Солнечный, 2	f	large
77218	2974	374	Томская область, Александровский район, село Александровское, Пушкина, 54б	f	large
125409	2967	366	Томская область, Александровский район, село Александровское, Партизанская, 88 стр.1	f	medium
15786	8822	137	Республика Хакасия, Черногорск, Советская, 46	f	large
15789	8825	140	Республика Хакасия, Черногорск, переулок Клубный, 5	f	medium
15800	8836	151	Республика Хакасия, Черногорск, Юбилейная, 19А	f	medium
15798	8834	149	Республика Хакасия, Черногорск, Юбилейная, 28А	f	large
15797	8833	148	Республика Хакасия, Черногорск, Чапаева, 49А	f	large
15794	8830	145	Республика Хакасия, Черногорск, Чапаева, 27А	f	large
15792	8828	143	Республика Хакасия, Черногорск, Чайковского, 7	f	large
15780	8817	131	Республика Хакасия, Черногорск, Фрунзе, 17	f	large
15779	8817	130	Республика Хакасия, Черногорск, Фрунзе, 17	f	large
15803	8839	154	Республика Хакасия, Черногорск, Советская, 104	f	medium
15791	8827	142	Республика Хакасия, Черногорск, Советская, 82В	f	large
15790	8826	141	Республика Хакасия, Черногорск, Советская, 79	f	medium
15777	8815	128	Республика Хакасия, Черногорск, Советская, 26	f	large
15804	8840	155	Республика Хакасия, Черногорск, Пушкина, 7А	f	large
15774	8812	125	Республика Хакасия, Черногорск, Парковая, 16	f	medium
15773	8812	124	Республика Хакасия, Черногорск, Парковая, 16	f	large
15772	8811	123	Республика Хакасия, Черногорск, Октябрьская, 42	f	medium
15771	8810	122	Республика Хакасия, Черногорск, Октябрьская, 82	f	large
15769	8808	120	Республика Хакасия, Черногорск, Октябрьская, 86	f	medium
15784	8820	135	Республика Хакасия, Черногорск, Мира, 1А	f	medium
15783	8820	134	Республика Хакасия, Черногорск, Мира, 1А	f	large
15788	8824	139	Республика Хакасия, Черногорск, Максима Горького, 11	f	medium
15778	8816	129	Республика Хакасия, Черногорск, Максима Горького, 3	f	medium
15806	8842	157	Республика Хакасия, Черногорск, Ленина, 73	f	medium
15809	8845	160	Республика Хакасия, Черногорск, Космонавтов, 44	f	medium
15805	8841	156	Республика Хакасия, Черногорск, Космонавтов, 32	f	large
15795	8831	146	Республика Хакасия, Черногорск, Космонавтов, 21А	f	large
15775	8813	126	Республика Хакасия, Черногорск, Комсомольская, 107	f	large
15770	8809	121	Республика Хакасия, Черногорск, Кирова, 77	f	large
15802	8838	153	Республика Хакасия, Черногорск, Калинина, 38	f	large
15801	8837	152	Республика Хакасия, Черногорск, Калинина, 32	f	large
15799	8835	150	Республика Хакасия, Черногорск, Калинина, 15А	f	large
15776	8814	127	Республика Хакасия, Черногорск, Дружбы, 1А	f	medium
15793	8829	144	Республика Хакасия, Черногорск, Дзержинского, 12	f	medium
15787	8823	138	Республика Хакасия, Черногорск, Горная, 96	f	large
15785	8821	136	Республика Хакасия, Черногорск, Бограда, 104	f	medium
15781	8819	132	Республика Хакасия, Черногорск, Бограда, 3	f	large
15782	8819	133	Республика Хакасия, Черногорск, Бограда, 3	f	large
15808	8844	159	Республика Хакасия, город Черногорск, 30 лет Победы, 93	f	large
15807	8843	158	Республика Хакасия, Черногорск, 30 лет Победы, 93	f	large
15796	8832	147	Республика Хакасия, город Черногорск, Космонавтов, 4А	f	large
15767	8806	118	Республика Хакасия, Сорск, ООО Сорский-горно-обогатительный комбинат, ЦЕНТР - Промплощадка	f	small
15764	8803	115	Республика Хакасия, Сорск, Кирова, 32а	f	large
15763	8802	114	Республика Хакасия, Сорск, Кирова, 20	f	large
15765	8804	116	Республика Хакасия, Сорск, Геологов, 2	f	large
15766	8805	117	Республика Хакасия, Сорск, Боградская, 16	t	medium
15762	8801	113	Республика Хакасия, Сорск, 50 лет Октября, 36	f	large
15745	8785	96	Республика Хакасия, Саяногорск, микрорайон Заводской, 6А	f	large
15753	8792	104	Республика Хакасия, Саяногорск, Школьная, 4	f	large
15746	8786	97	Республика Хакасия, Саяногорск, Центральный мкр, 9а	f	large
15747	8787	98	Республика Хакасия, Саяногорск, Центральный микрорайон, 1г	f	large
15740	8781	91	Республика Хакасия, Саяногорск, Советский мкр, 11	f	large
15741	8781	92	Республика Хакасия, Саяногорск, Советский мкр, 11	f	large
15739	8780	90	Республика Хакасия, Саяногорск, Ленинградский мкр, 51	f	large
15738	8780	89	Республика Хакасия, Саяногорск, Ленинградский мкр, 51	f	large
15736	8778	87	Республика Хакасия, Саяногорск, Ленинградский микрорайон, 52	f	large
15735	8778	86	Республика Хакасия, Саяногорск, Ленинградский микрорайон, 52	f	large
15752	8791	103	Республика Хакасия, Саяногорск, Комсомольский мкр, 60	f	large
15750	8789	101	Республика Хакасия, Саяногорск, Интернациональный мкр, 15	f	large
15749	8789	100	Республика Хакасия, Саяногорск, Интернациональный мкр, 15	f	large
15743	8783	94	Республика Хакасия, город Саяногорск, Заводской мкр, 34	f	large
15742	8782	93	Республика Хакасия, Саяногорск, Заводской микрорайон, 60	f	large
15744	8784	95	Республика Хакасия, Саяногорск, Заводской, 29	f	large
15751	8790	102	Республика Хакасия, город Саяногорск, Енисейский микрорайон, 20	f	large
15754	8793	105	Республика Хакасия, Саяногорск, Геологов, 6	f	large
15812	8848	163	Республика Хакасия, село Подсинее, Октябрьская, 8	f	large
15811	8847	162	Республика Хакасия, село Подсинее, Зеленая, 4	f	large
15723	8766	74	Республика Хакасия, Абакан, станция Подсиний	t	small
15908	8945	259	Россия, Республика Хакасия, Абакан, улица Ширинская, 4	t	small
16009	9047	360	Россия, Республика Хакасия, Абакан, улица Центральная, 29	t	small
16002	9040	353	Россия, Республика Хакасия, Абакан, улица Центральная, 1	t	small
15937	8974	288	Россия, Республика Хакасия, Абакан, улица Центральная, 7	t	small
15882	8918	233	Россия, Республика Хакасия, Абакан, улица Центральная, 33	t	small
15862	8898	213	Россия, Республика Хакасия, Абакан, улица Центральная, 27	t	small
15846	8882	197	Россия, Республика Хакасия, Абакан, улица Центральная, 40	t	small
15706	8760	57	Республика Хакасия, Абакан, улица Тельмана, 98Б	f	large
86035	9063	377	Россия, Республика Хакасия, Абакан, улица Советская, 16	t	small
15850	8886	201	Россия, Республика Хакасия, Абакан, улица Советская, 8	t	small
15679	8739	30	Республика Хакасия, Абакан, улица Павших Коммунаров, 100	f	large
15847	8883	198	Россия, Республика Хакасия, Абакан, улица Нагорная, 4	t	small
15861	8897	212	Россия, Республика Хакасия, Абакан, улица Набережная, 6	t	small
16016	9053	367	Россия, Республика Хакасия, Абакан, улица Молодежная, 15	t	small
15993	9031	344	Республика Хакасия, Абакан, д. Чапаево, улица Мира, 67	t	medium
86036	9067	379	Россия, Республика Хакасия, Абакан, улица Кадышева, 22	t	small
15689	8748	40	Республика Хакасия, Абакан, улица Жукова, 90	f	large
15714	8763	65	Республика Хакасия, Абакан, Ярыгина, 43	f	large
15659	8721	10	Республика Хакасия, Абакан, Ярыгина, 28	f	large
15657	8719	8	Республика Хакасия, Абакан, Щетинкина, 27	f	large
15656	8719	7	Республика Хакасия, Абакан, Щетинкина, 27	f	large
15655	8718	6	Республика Хакасия, Абакан, Щетинкина, 13	f	large
15839	8874	190	Республика Хакасия, Абакан, Школьная, 23	f	small
15660	8722	11	Республика Хакасия, Абакан, Чернышевского, 43	f	large
15716	8722	67	Республика Хакасия, Абакан, Чернышевского, 43	f	large
15675	8735	26	Республика Хакасия, Абакан, Челюскинцев, 6	f	large
15674	8735	25	Республика Хакасия, Абакан, Челюскинцев, 6	f	large
15677	8737	28	Республика Хакасия, Абакан, Хлебная, 28	f	large
15690	8749	41	Республика Хакасия, Абакан, Хакасская, 6	f	large
15715	8723	66	Республика Хакасия, Абакан, Хакасская, 165	f	large
15661	8723	12	Республика Хакасия, Абакан, Хакасская, 165	f	large
15705	8720	56	Республика Хакасия, Абакан, Тельмана, 93	f	large
15707	8747	58	Республика Хакасия, Абакан, Стофато, 18	f	large
15688	8747	39	Республика Хакасия, Абакан, Стофато, 18	f	large
15664	8726	15	Республика Хакасия, Абакан, Советская, 175	f	large
15663	8725	14	Республика Хакасия, Абакан, Советская, 171	f	large
15709	8757	60	Россия, Республика Хакасия, Абакан, Северный проезд, 11	f	large
15712	8757	63	Россия, Республика Хакасия, Абакан, Северный проезд, 11	f	large
15700	8757	51	Россия, Республика Хакасия, Абакан, Северный проезд, 11	f	large
15721	8754	72	Республика Хакасия, Абакан, Рыбацкая, 19	f	large
15696	8754	47	Республика Хакасия, Абакан, Рыбацкая, 19	f	large
15691	8740	42	Республика Хакасия, Абакан, Пушкина, 30а	f	large
15680	8740	31	Республика Хакасия, Абакан, Пушкина, 30а	f	large
15665	8727	16	Республика Хакасия, Абакан, Пушкина, 190	f	large
15662	8724	13	Республика Хакасия, Абакан, Пушкина, 122	f	large
15654	8717	5	Республика Хакасия, Абакан, Пушкина, 72	f	large
15650	8713	1	Республика Хакасия, Абакан, Пушкина, 92	f	large
15671	8732	22	Республика Хакасия, Абакан, Пирятинская, 20	f	large
15669	8730	20	Республика Хакасия, Абакан, Пирятинская, 8	f	large
15668	8729	19	Республика Хакасия, Абакан, Пирятинская, 26	f	large
15667	8729	18	Республика Хакасия, Абакан, Пирятинская, 26	f	large
15693	8751	44	Республика Хакасия, Абакан, Павших Коммунаров, 52	f	large
15678	8738	29	Республика Хакасия, Абакан, Павших Коммунаров, 131	f	large
15676	8736	27	Республика Хакасия, Абакан, Павших Коммунаров, 129	f	large
15692	8750	43	Республика Хакасия, Абакан, Островского, 24	f	large
15695	8753	46	Республика Хакасия, Абакан, Молодежная, 20	f	large
15653	8716	4	Республика Хакасия, Абакан, Лермонтова, 12	f	large
15711	8716	62	Республика Хакасия, Абакан, Лермонтова, 12	f	large
15702	8716	53	Республика Хакасия, Абакан, Лермонтова, 12	f	large
15683	8743	34	Россия, Республика Хакасия, Абакан, Ленина проспект, 48	f	large
15652	8715	3	Россия, Республика Хакасия, Абакан, Ленина проспект, 90	f	large
15703	8759	54	Республика Хакасия, Абакан, Крылова, 73А	f	large
15699	8756	50	Республика Хакасия, Абакан, Комарова, 15	f	large
15698	8756	49	Республика Хакасия, Абакан, Комарова, 15	f	large
15697	8755	48	Республика Хакасия, Абакан, Комарова, 12	f	large
15713	8755	64	Республика Хакасия, Абакан, Комарова, 12	f	large
15681	8741	32	Республика Хакасия, Абакан, Комарова, 6	f	large
15719	8762	70	Республика Хакасия, Абакан, Зоотехническая, 6	f	large
15710	8762	61	Республика Хакасия, Абакан, Зоотехническая, 6	f	large
15687	8746	38	Республика Хакасия, Абакан, Зеленая, 1	f	large
15694	8752	45	Республика Хакасия, Абакан, Жукова, 10	f	large
15722	8758	73	Россия, Республика Хакасия, Абакан, Дружбы Народов проспект, 21	f	large
15701	8758	52	Россия, Республика Хакасия, Абакан, Дружбы Народов проспект, 21	f	large
15720	8731	71	Республика Хакасия, Абакан, Гагарина, 82а	f	large
15670	8731	21	Республика Хакасия, Абакан, Гагарина, 82а	f	large
15684	8744	35	Республика Хакасия, Абакан, Вяткина, 14	f	large
15682	8742	33	Республика Хакасия, Абакан, Вяткина, 8	f	large
15685	8745	36	Россия, Республика Хакасия, Абакан, Весенний проезд, 6	f	large
15686	8745	37	Россия, Республика Хакасия, Абакан, Весенний проезд, 6	f	large
15666	8728	17	Республика Хакасия, Абакан, Богдана Хмельницкого, 158	f	large
15672	8733	23	Республика Хакасия, Абакан, Белоярская, 60	f	large
15673	8734	24	Республика Хакасия, Абакан, Аскизская, 145	f	large
15733	8776	84	Республика Хакасия, Абаза, Энтузиастов, 4	f	large
15732	8775	83	Республика Хакасия, Абаза, ТЭЦ, 10	f	medium
15734	8777	85	Республика Хакасия, Абаза, Ленина, 31А	f	large
15728	8771	79	Республика Хакасия, Абаза, Ленина, 8А	f	large
15727	8770	78	Республика Хакасия, Абаза, Ленина, 16-Г	f	medium
15726	8769	77	Республика Хакасия, Абаза, Ленина, 24А	f	large
15731	8774	82	Республика Хакасия, Абаза, Кулакова, 83-А	f	medium
15730	8773	81	Республика Хакасия, Абаза, Кулакова, 5	f	medium
15729	8772	80	Республика Хакасия, Абаза, Кулакова, 3	f	medium
15724	8767	75	Республика Хакасия, Абаза, Геологическая, 4	f	medium
15725	8768	76	Республика Хакасия, город Абаза, Вокзальная, 7	f	medium
16015	9052	366	Республика Хакасия, Ширинский район, поселок городского типа Шира, Щетинина, 151	f	medium
16013	9050	364	Республика Хакасия, Ширинский район, поселок городского типа Шира, Школьная, 7	f	large
16014	9051	365	Республика Хакасия, Ширинский район, поселок городского типа Шира, Рабочая, 3	f	large
16012	9014	363	Республика Хакасия, Ширинский район, поселок городского типа Шира, Октябрьская, 80	f	large
16011	9049	362	Республика Хакасия, Ширинский район, поселок городского типа Шира, Гаражная, 1	f	medium
16029	9068	380	Республика Хакасия, Ширинский район, село Черное Озеро, Центральная, 2	t	medium
16034	9075	385	Республика Хакасия, Ширинский район, село Целинное, Ленина, 7	f	medium
16036	9077	387	Республика Хакасия, Ширинский район, село Фыркал, Гагарина, 12	f	medium
16020	9057	371	Республика Хакасия, Ширинский район, поселок городского типа Туим, Первомайская, 5	f	large
16021	9058	372	Республика Хакасия, Ширинский район, Туим, Орджоникидзе, 111	f	small
67870	9059	373	Республика Хакасия, Ширинский район, поселок городского типа Туим, Микрорайон, 8	f	large
16018	9055	369	Республика Хакасия, Ширинский район, село Топанов, Школьная, 8	t	small
16031	9070	382	Республика Хакасия, Ширинский район, село Талкин Ключ, Нижняя, 16	t	small
16039	9080	390	Республика Хакасия, Ширинский район, село Сон, Ленина, 4	t	small
16035	9076	386	Республика Хакасия, Ширинский район, село Соленоозерное, Карла Маркса, 42	f	small
16025	9062	376	Республика Хакасия, Ширинский район, село Малый Спирин, Победы, 13	f	medium
16017	9054	368	Республика Хакасия, Ширинский район, село Малый Кобежиков, Таежная, 39	t	small
16023	9061	374	Республика Хакасия, Ширинский район, поселок городского типа Коммунар, 50 лет ВЛКСМ, 6	f	large
16024	9061	375	Республика Хакасия, Ширинский район, поселок городского типа Коммунар, 50 лет ВЛКСМ, 6	t	medium
16019	9056	370	Республика Хакасия, Ширинский район, село Колодезный, Микрорайон, 1	f	large
16027	9065	378	Республика Хакасия, Ширинский район, село Ефремкино, Трактовая, 1	t	small
128159	9072	383	Республика Хакасия, Ширинский район, село Джирим, 50 лет ВЛКСМ, 14	t	medium
16040	9081	391	Республика Хакасия, Ширинский район, село Гольджа, Мира, 15	t	small
15940	8977	291	Республика Хакасия, Ширинский район, село Гайдаровск, Целинная, 3	t	small
86037	9073	384	Республика Хакасия, Ширинский район, село Ворота, Гагарина, 2	t	small
16038	9079	389	Республика Хакасия, Ширинский район, село Власьево, Октябрьская, 1	f	small
16037	9078	388	Республика Хакасия, Ширинский район, село Борец, Ленина, 12	f	medium
16041	9082	392	Республика Хакасия, Ширинский район, село Беренжак, Школьная, 15	t	small
16030	9069	381	Республика Хакасия, Ширинский район, село Белый Балахчин, Новая, 30	t	small
15810	8846	161	Республика Хакасия, Усть-Абаканский район, город Черногорск, поселок Пригорск, Администрация поселка	f	large
16001	9039	352	Республика Хакасия, Усть-Абаканский район, село Чарков, Ленина, 19, здание сельского Дома культуры	f	large
16003	9041	354	Республика Хакасия, Усть-Абаканский район, село Усть-Бюр, Ленина, 50, здание сельского Дома культуры	f	large
15982	9019	333	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Спортивная, 6а, здание Дома культуры им. Гагарина	f	large
15977	9015	328	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Подгорный квартал, здание библиотеки	f	medium
15981	9018	332	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Октябрьская, 17, здание районного Дома культуры Дружба	f	large
15980	9017	331	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Мира, 44, здание школы № 2	f	large
15979	9017	330	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Мира, 44, здание школы № 2	f	large
15978	9016	329	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Мира, 40а, здание культурного досугового центра Имидж	f	large
15984	9021	335	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Кирова, 38, здание школы № 1	f	large
15985	9022	336	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Заречная, 1, здание сельского Дома культуры	t	small
15986	9023	337	Республика Хакасия, Усть-Абаканский район, поселок городского типа Усть-Абакан, Добровольского, 14, здание ПУ-12	f	small
15987	9024	338	Республика Хакасия, Усть-Абаканский район, поселок Усть-Абакан, Волкова, 15, здание коррекционной школы	f	small
15983	9020	334	Республика Хакасия, Усть-Абаканский район, поселок Усть-Абакан, 30 лет Победы, 1, здание школы № 3	f	large
15989	9027	340	Республика Хакасия, Усть-Абаканский район, село Тепличный, Ленина, 40а, здание сельского Дома культуры	f	large
15995	9033	346	Республика Хакасия, Усть-Абаканский район, село Ташеба, Вокзальная, 2, здание сельского клуба	t	medium
15929	8966	280	Республика Хакасия, Усть-Абаканский район, село Сонское, Линейная, 8	t	medium
16008	9046	359	Республика Хакасия, Усть-Абаканский район, село Солнечное, 10-й Пятилетки, 15, здание сельского Дома культуры	t	medium
15994	9032	345	Республика Хакасия, Усть-Абаканский район, село Сапогов, Майская, 35, здание сельского Дома культуры	t	medium
15988	9026	339	Республика Хакасия, Усть-Абаканский район, село Расцвет, Школьная, 1в, здание сельского Дома культуры	f	medium
15996	9034	347	Республика Хакасия, Усть-Абаканский район, село Райков, 30 лет Победы, 10, здание школы	f	large
16006	9044	357	Республика Хакасия, Усть-Абаканский район, село Мохов, Школьная, 1	t	small
16005	9043	356	Республика Хакасия, Усть-Абаканский район, село Московское, Советская, 30, здание администрации МО Московский сельсовет	t	medium
16010	9048	361	Республика Хакасия, Усть-Абаканский район, село Курганная, Урожайная, 4, здание школы	t	small
16004	9042	355	Республика Хакасия, Усть-Абаканский район, село Ковыльная, Школьная, 20, здание сельского Дома культуры	t	small
16000	9038	351	Республика Хакасия, Усть-Абаканский район, Капчалы, Школьная, 20, здание сельского Дома культуры	t	small
15991	9029	342	Республика Хакасия, Усть-Абаканский район, село Калинино, Школьная, 58, здание сельского Дома культуры	f	large
15992	9030	343	Республика Хакасия, Усть-Абаканский район, село Калинино, Советская, 88, здание сельского Дома культуры	f	medium
15998	9036	349	Республика Хакасия, Усть-Абаканский район, село Имени Ильича, Ленина, 1, здание школы	t	small
15990	9028	341	Республика Хакасия, Усть-Абаканский район, село Зеленое, Хакасская, 6, здание сельского Дома культуры	f	large
15997	9035	348	Республика Хакасия, Усть-Абаканский район, село Доможаков, Механизаторская, 46, здание сельского Дома культуры	t	medium
15999	9037	350	Республика Хакасия, Усть-Абаканский район, село Весеннее, Мира, 26, здание сельского Дома культуры	t	medium
16007	9045	358	Республика Хакасия, Усть-Абаканский район, село Вершино-Биджа, 30 лет Победы, 81, здание сельского Дома культуры	t	medium
15970	9007	321	Республика Хакасия, Таштыпский район, село Чиланы, Центральная, 39	t	small
15975	9012	326	Республика Хакасия, Таштыпский район, село Харой, Хакасская, 3	t	small
15965	9002	316	Республика Хакасия, Таштыпский район, село Харачул, Школьная, 20	t	small
66071	8994	394	Республика Хакасия, Таштыпский район, село Таштып, Ленина, 37	f	small
15957	8994	308	Республика Хакасия, Таштыпский район, село Таштып, Ленина, 37	f	large
66072	8995	395	Республика Хакасия, Таштыпский район, село Таштып, Карла Маркса, 47	f	small
15958	8995	309	Республика Хакасия, Таштыпский район, село Таштып, Карла Маркса, 47	f	large
15971	9008	322	Республика Хакасия, Таштыпский район, село Печегол, Мирная, 4	t	small
15953	8990	304	Республика Хакасия, Таштыпский район, село Нижний Матур, Центральная, 8	t	small
66070	8991	393	Республика Хакасия, Таштыпский район, село Нижний Курлугаш, Мира, 13	t	small
15954	8991	305	Республика Хакасия, Таштыпский район, село Нижний Курлугаш, Мира, 13	t	small
15972	9009	323	Республика Хакасия, Таштыпский район, село Нижний Имек, Советская, 23	f	small
15955	8992	306	Республика Хакасия, Таштыпский район, село Нижние Сиры, Советская, 28 А	f	small
15952	8989	303	Республика Хакасия, Таштыпский район, село Матур, Клубная, 7	t	medium
15963	9000	314	Республика Хакасия, Таштыпский район, село Малые Арбаты, Советская, 81 Д	t	medium
15966	9003	317	Республика Хакасия, Таштыпский район, село Малая Сея, Центральная, 42	t	small
15960	8997	311	Республика Хакасия, Таштыпский район, село Кызылсуг, Луговая, 10	t	small
15976	9013	327	Республика Хакасия, Таштыпский район, село Кубайка, Набережная, 4Б	t	small
15973	9010	324	Республика Хакасия, Таштыпский район, село Имек, Юбилейная, 16 А	f	medium
15968	9005	319	Республика Хакасия, Таштыпский район, село Верхняя Сея, Школьная, 32	t	small
15974	9011	325	Республика Хакасия, Таштыпский район, село Верхний Имек, Молодежная, 7А	t	small
15956	8993	307	Республика Хакасия, Таштыпский район, село Верхние Сиры, Октябрьская, 25-1	t	small
15961	8998	312	Республика Хакасия, Таштыпский район, село Верх-Таштып, Школьная, 23	t	small
15969	9006	320	Республика Хакасия, Таштыпский район, село Бутрахты, Кунучакова, 19	t	small
15964	9001	315	Республика Хакасия, Таштыпский район, село Большие Арбаты, Сосновая, 20	t	small
15967	9004	318	Республика Хакасия, Таштыпский район, село Большая Сея, Советская, 17	f	small
128158	8999	313	Республика Хакасия, Таштыпский район, село Арбаты, Титова, 9	t	medium
15959	8996	310	Республика Хакасия, Таштыпский район, село Анчул, Советская, 21	t	small
128157	8973	287	Республика Хакасия, Орджоникидзевский район, село Устинкино, Советская, 13	f	medium
15949	8986	300	Республика Хакасия, Орджоникидзевский район, село Сарала, Центральная, 151	t	medium
15951	8988	302	Республика Хакасия, Орджоникидзевский район, село Приисковое, Заводская, 15	t	small
15938	8975	289	Республика Хакасия, Орджоникидзевский район, село Подкамень, Центральная, 2	t	small
15950	8987	301	Республика Хакасия, Орджоникидзевский район, село Орджоникидзевское, пер. Школьный, 6	t	small
15941	8978	292	Республика Хакасия, Орджоникидзевский район, село Новомарьясово, Ленина, 29	t	medium
15945	8982	296	Республика Хакасия, Орджоникидзевский район, село Монастырево, Школьная, 15	t	small
15935	8972	286	Республика Хакасия, Орджоникидзевский район, село Малый Сютик, Песочная, 6	t	small
15939	8976	290	Республика Хакасия, Орджоникидзевский район, село Костино, Центральная, 1	t	small
15933	8970	284	Республика Хакасия, Орджоникидзевский район, село Копьево, Механизаторов, 11А	f	medium
15931	8968	282	Республика Хакасия, Орджоникидзевский район, поселок городского типа Копьево, Партизанская, 16	f	large
15930	8967	281	Республика Хакасия, Орджоникидзевский район, поселок городского типа Копьево, Партизанская, 6А	f	large
15932	8969	283	Республика Хакасия, Орджоникидзевский район, поселок городского типа Копьево, Залинейная, 23	f	small
15943	8980	294	Республика Хакасия, Орджоникидзевский район, село Конгарово, Центральная, 29	t	small
15947	8984	298	Республика Хакасия, Орджоникидзевский район, село Кожухово, Залинейная, 7	t	small
15944	8981	295	Республика Хакасия, Орджоникидзевский район, село Когунек, Центральная, 52	t	small
15948	8985	299	Республика Хакасия, Орджоникидзевский район, село Кобяково, Мира, 32	t	small
15946	8983	297	Республика Хакасия, Орджоникидзевский район, село Июс, Центральная, 5	t	medium
15942	8979	293	Республика Хакасия, Орджоникидзевский район, село Горюново, Новая, 13	t	small
15934	8971	285	Республика Хакасия, Орджоникидзевский район, село Большой Сютик, Молодежная, 14	t	small
15912	8949	263	Республика Хакасия, Боградский район, село Черемушка, Трактовая, 8	t	small
15911	8948	262	Республика Хакасия, Боградский район, село Усть-Ерба, Молодежная, 17	t	small
86033	8950	264	Республика Хакасия, Боградский район, село Троицкое, Молодежная, 16	f	small
15917	8954	268	Республика Хакасия, Боградский район, село Толчея, Школьная, 13	t	small
15918	8955	269	Республика Хакасия, Боградский район, село Таежная, Школьная, 10	t	small
15919	8956	270	Республика Хакасия, Боградский район, село Советская Хакасия, Школьная, 5	t	medium
15904	8941	255	Республика Хакасия, Боградский район, село Сарагаш, Зеленая, 1	t	medium
86034	8965	279	Республика Хакасия, Боградский район, село Пушное, Зеленая, 2	t	small
15916	8953	267	Республика Хакасия, Боградский район, село Полиндейка, Зеленая, 12	t	small
128156	8943	257	Республика Хакасия, Боградский район, село Первомайское, Школьная, 2Н	t	medium
15920	8957	271	Республика Хакасия, Боградский район, село Красный Камень, Торговая, 6	t	small
15927	8964	278	Республика Хакасия, Боградский район, село Карасуг, Подгорная, 6	t	small
15910	8947	261	Республика Хакасия, Боградский район, село Знаменка, Дзержинского, 75	f	large
15907	8944	258	Республика Хакасия, Боградский район, село Заречная, Степная, 10б	t	small
15926	8963	277	Республика Хакасия, Боградский район, село Верх-Ерба, Школьная, 10Б	t	small
15909	8946	260	Республика Хакасия, Боградский район, село Борозда, Горная, 4А	t	small
15915	8952	266	Республика Хакасия, Боградский район, село Бородино, Пушкина, 20	f	medium
15925	8962	276	Республика Хакасия, Боградский район, село Большая Ерба, Зеленая, 2А	f	medium
15923	8960	274	Республика Хакасия, Боградский район, село Боград, Партизанская, 19	f	medium
67869	8958	272	Республика Хакасия, Боградский район, село Боград, Новая, 18	f	large
15922	8959	273	Республика Хакасия, Боградский район, село Боград, 50 лет Октября, 19	f	large
15924	8961	275	Республика Хакасия, Боградский район, село Белелик, Центральная, 24	t	small
15905	8942	256	Республика Хакасия, Боградский район, село Базандаиха, Центральная, 7	t	small
15914	8951	265	Республика Хакасия, Боградский район, село Абакано-Перевоз, Новая, 1	t	small
15898	8934	249	Республика Хакасия, Бейский район, д. Новокурск, Садовая, 58	f	medium
15892	8928	243	Республика Хакасия, Бейский район, село Шалгинов, Школьная, 19	t	small
15760	8799	111	Республика Хакасия, Бейский район, поселок Черемушки, 48	f	small
15758	8797	109	Республика Хакасия, Бейский район, поселок Черемушки, №51, поселок Черемушки	f	large
15761	8800	112	Республика Хакасия, Бейский район, поселок городского типа Черемушки, 33	f	large
15759	8798	110	Республика Хакасия, Бейский район, поселок городского типа Черемушки, 14	f	large
15891	8927	242	Республика Хакасия, Бейский район, село Чаптыков, Набережная, 4	t	small
15894	8930	245	Республика Хакасия, Бейский район, село Уты, Кооперативная, 5	t	small
15885	8921	236	Республика Хакасия, Бейский район, село Усть-Киндирла, Чебодаева, 46	t	small
15883	8919	234	Республика Хакасия, Бейский район, село Табат, Ленина, 140А	f	large
15897	8933	248	Республика Хакасия, Бейский район, село Сабинка, Молодежная, 1А	f	medium
15895	8931	246	Республика Хакасия, Бейский район, село Новотроицкое, пер. Гаражный, 1	f	medium
15902	8938	253	Республика Хакасия, Бейский район, село Новониколаевка, Мира, 62	t	small
15901	8937	252	Республика Хакасия, Бейский район, село Новоенисейка, Ленина, 15А	f	medium
15881	8917	232	Республика Хакасия, Бейский район, село Маткичек, Школьная, 4	t	small
15879	8915	230	Республика Хакасия, Бейский район, село Малый Монок, Школьная, 20	t	small
15755	8794	106	Республика Хакасия, Бейский район, поселок городского типа Майна, Советская, 2	f	large
15756	8795	107	Республика Хакасия, Бейский район, поселок городского типа Майна, Победы, 8	f	large
15890	8926	241	Республика Хакасия, Бейский район, село Куйбышево, Октябрьская, 3	f	small
15878	8914	229	Республика Хакасия, Бейский район, село Красный Катамор, Школьная, 5	t	small
15900	8936	251	Республика Хакасия, Бейский район, село Красный Катамор, Ленина, 49	t	small
15893	8929	244	Республика Хакасия, Бейский район, село Койбалы, Школьная, 8	t	small
15896	8932	247	Республика Хакасия, Бейский район, село Кирба, Октябрьская, 12	f	large
15899	8935	250	Республика Хакасия, Бейский район, село Калы, Гагарина, 15	f	small
15903	8940	254	Республика Хакасия, Бейский район, село Дмитриевка, Молодежная, 24	t	small
15889	8925	240	Республика Хакасия, Бейский район, село Дехановка, Щетинкина, 24	t	small
15884	8920	235	Республика Хакасия, Бейский район, село Буденновка, Ленина, 32	f	small
15880	8916	231	Республика Хакасия, Бейский район, село Бондарево, 50 лет Октября, 4А	f	large
15877	8913	228	Республика Хакасия, Бейский район, село Большой Монок, Октябрьская, 49	t	small
15757	8796	108	Республика Хакасия, Бейский район, село Богословка, Центральная, 64	t	small
15886	8922	237	Республика Хакасия, Бейский район, село Бея, Площадь Советов, 20А	f	large
15887	8923	238	Республика Хакасия, Бейский район, село Бея, Павших партизан, 24	f	medium
15888	8924	239	Республика Хакасия, Бейский район, село Бея, Лесная, 1	f	medium
15868	8904	219	Республика Хакасия, Аскизский район, село Шора, Центральная, 18	t	small
15849	8885	200	Республика Хакасия, Аскизский район, село Усть-Чуль, Тейская, 39	t	medium
15860	8896	211	Республика Хакасия, Аскизский район, село Усть-Хоиза, Школьная, 4	t	small
15854	8890	205	Республика Хакасия, Аскизский район, село Усть-Камышта, Мира, 1А	f	large
15844	8880	195	Республика Хакасия, Аскизский район, село Усть-Есь, Советская, 73	f	medium
15876	8912	227	Республика Хакасия, Аскизский район, село Усть-База, Школьная, 11	t	small
15855	8891	206	Республика Хакасия, Аскизский район, село Пуланколь, Победы, 9	t	medium
15845	8881	196	Республика Хакасия, Аскизский район, село Полтаков, Первомайская, 8	f	medium
15848	8884	199	Республика Хакасия, Аскизский район, село Нижняя Тея, Школьная, 1	f	small
15874	8910	225	Республика Хакасия, Аскизский район, село Нижняя База, Школьная, 3	t	small
15870	8906	221	Республика Хакасия, Аскизский район, село Неожиданный, Октябрьская, 3	t	small
15838	8873	189	Республика Хакасия, Аскизский район, село Луговая, Степная, 8	f	small
128155	8895	210	Республика Хакасия, Аскизский район, село Кызлас, Превомайская, 1	t	medium
15853	8889	204	Республика Хакасия, Аскизский район, село Катанов, Школьная, 2	f	medium
15856	8892	207	Республика Хакасия, Аскизский район, село Камышта, Баланкульская, 16	t	small
86038	8894	209	Республика Хакасия, Аскизский район, село Казановка, Новая, 22	t	small
15852	8888	203	Республика Хакасия, Аскизский район, село Илиморов, Чахсы-Хоных, 21	t	small
15867	8903	218	Республика Хакасия, Аскизский район, поселок городского типа Вершина Теи, Советская, 5	f	large
67871	8902	217	Республика Хакасия, Аскизский район, поселок городского типа Вершина Теи, Советская, 36	f	large
15851	8887	202	Республика Хакасия, Аскизский район, село Верхняя Тея, Тейская, 35	t	small
15875	8911	226	Республика Хакасия, Аскизский район, село Верхняя База, Солнечная, 14	t	small
15857	8893	208	Республика Хакасия, Аскизский район, село Верхний Аскиз, Мира, 71	t	medium
15865	8901	216	Республика Хакасия, Аскизский район, поселок городского типа Бискамжа, Железнодорожная, 4	f	large
15864	8900	215	Республика Хакасия, Аскизский район, село Бирикчуль, Советская, 8	f	medium
15863	8899	214	Республика Хакасия, Аскизский район, село Бирикчуль, Богдана Ховруна, 5	f	large
15843	8879	194	Республика Хакасия, Аскизский район, село Бельтирское, Щорса, 6	f	small
15842	8877	193	Республика Хакасия, Аскизский район, село Бельтирское, Ленина, 37	f	large
15841	8876	192	Республика Хакасия, Аскизский район, село Бельтирское, Абаканская, 29	f	large
15869	8905	220	Республика Хакасия, Аскизский район, село Балыкса, переулок Почтовый, 12	f	large
15871	8907	222	Республика Хакасия, Аскизский район, поселок Аскиз, Советская, 2	t	large
15872	8908	223	Республика Хакасия, Аскизский район, поселок Аскиз, Октябрьская, 22	f	large
15873	8909	224	Республика Хакасия, Аскизский район, поселок городского типа Аскиз, Нагорная, 30	t	small
15835	8870	186	Республика Хакасия, Аскизский район, село Аскиз, Советская, 20	f	large
15837	8872	188	Республика Хакасия, Аскизский район, село Аскиз, Промышленная, 28	f	large
15836	8871	187	Республика Хакасия, Аскизский район, село Аскиз, Горького, 10	f	large
15840	8875	191	Республика Хакасия, Аскизский район, село Анхаков (Ворошилово), Школьная, 16	t	small
15813	8849	164	Республика Хакасия, Алтайский район, д. Кайбалы, пер. Проспектный, д. 4	f	small
15824	8860	175	Республика Хакасия, Алтайский район, село Смирновка, Алтайская, 34	f	small
15821	8857	172	Республика Хакасия, Алтайский район, село Сартыков, Мира, 49	f	small
15834	8869	185	Республика Хакасия, Алтайский район, село Очуры, Советская, 144	f	medium
15833	8869	184	Республика Хакасия, Алтайский район, село Очуры, Советская, 144	f	medium
15828	8864	179	Республика Хакасия, Алтайский район, село Новороссийское, Щетинкина, 7	f	medium
15832	8868	183	Республика Хакасия, Алтайский район, село Новомихайловка, Новая, 10 А	f	medium
15826	8862	177	Республика Хакасия, Алтайский район, село Лукьяновка, Центральная, 2Б	f	small
15825	8861	176	Республика Хакасия, Алтайский район, село Летник, Молодежная, 2	t	small
15823	8859	174	Республика Хакасия, Алтайский район, село Краснополье, Строителей, 11	f	small
15831	8867	182	Республика Хакасия, Алтайский район, село Кирово, Ленина, 88	f	medium
15820	8856	171	Республика Хакасия, Алтайский район, село Изыхские Копи, Ленина, 2	f	large
15827	8863	178	Республика Хакасия, Алтайский район, село Герасимово, Комсомольская, 1А	f	small
15829	8865	180	Республика Хакасия, Алтайский район, село Берёзовка, пер. Березовый, 1	t	small
15819	8855	170	Республика Хакасия, Алтайский район, село Белый Яр, переулок Садовый, 5 Д	f	large
15818	8854	169	Республика Хакасия, Алтайский район, село Белый Яр, Советская, 4	f	large
15817	8853	168	Республика Хакасия, Алтайский район, село Белый Яр, Октябрьская, 20	f	large
15816	8852	167	Республика Хакасия, Алтайский район, село Белый Яр, Кирова, 46	f	medium
15814	8850	165	Республика Хакасия, Алтайский район, село Белый Яр, Кирова, 165	f	large
15815	8851	166	Республика Хакасия, Алтайский район, село Белый Яр, Аткниных, 80	f	large
15822	8858	173	Республика Хакасия, Алтайский район, село Аршанов, Ленина, 68	f	medium
15830	8866	181	Республика Хакасия, Алтайский район, село Алтай, Школьный переулок, 6	t	small
126563	4555	35	Республика Тыва, Кызыл, Юбилейная, 14	f	\N
14299	4552	32	Республика Тыва, Кызыл, Эрзинская, 8	f	large
14280	4534	13	Республика Тыва, Кызыл, Щетинкина-Кравченко, 46	f	large
14289	4543	22	Республика Тыва, Кызыл, Советская, 14	f	large
14284	4538	17	Республика Тыва, Кызыл, Салчака Тока, 14	f	large
14283	4537	16	Республика Тыва, Кызыл, Салчака Тока, 2	f	large
14286	4540	19	Республика Тыва, Кызыл, Ровенская, 25	f	large
14276	4530	9	Республика Тыва, Кызыл, Рабочая, 58	f	large
14275	4529	8	Республика Тыва, Кызыл, Рабочая, 4	f	large
14274	4529	7	Республика Тыва, Кызыл, Рабочая, 4	f	large
126561	4551	31	Республика Тыва, Кызыл, Правобережная, 54	f	\N
14297	4550	30	Республика Тыва, Кызыл, Правобережная, 54	f	large
14273	4528	6	Республика Тыва, Кызыл, Оюна Курседи, 54	f	large
14272	4527	5	Республика Тыва, Кызыл, Оюна Курседи, 4	f	large
14296	4549	29	Республика Тыва, Кызыл, Московская, 105/1	f	large
14295	4549	28	Республика Тыва, Кызыл, Московская, 105/1	f	large
14293	4547	26	Республика Тыва, Кызыл, Лопсанчапа, 29/2	f	large
14271	4526	4	Республика Тыва, Кызыл, Лермонтова, 1	f	large
14304	4557	37	Республика Тыва, Кызыл, Ленина, 36	f	large
126560	4533	12	Республика Тыва, Кызыл, Ленина, 1	f	\N
14282	4536	15	Республика Тыва, Кызыл, Красноармейская, 176	f	large
14278	4532	11	Республика Тыва, Кызыл, Красноармейская, 76	f	large
14285	4539	18	Республика Тыва, Кызыл, Кочетова, 165	f	large
14281	4535	14	Республика Тыва, Кызыл, Кочетова, 59/1	f	large
14270	4525	3	Республика Тыва, Кызыл, Колхозная, 56	f	large
14269	4524	2	Республика Тыва, Кызыл, Колхозная, 67	f	\N
14268	4523	1	Республика Тыва, Кызыл, Колхозная, 2А	f	large
14291	4545	24	Республика Тыва, Кызыл, Кечил-оола, 2а	f	large
14290	4544	23	Республика Тыва, Кызыл, Кечил-оола, 15	f	large
14288	4542	21	Республика Тыва, Кызыл, Кечил-оола, 73	f	large
14294	4548	27	Республика Тыва, Кызыл, Калинина, 1	f	large
14292	4546	25	Республика Тыва, Кызыл, Калинина, 1в	f	large
14287	4541	20	Республика Тыва, Кызыл, Калинина, 116	f	medium
14277	4531	10	Республика Тыва, Кызыл, Интернациональная, 106	f	large
14301	4554	34	Республика Тыва, Ак-Довурак, Юбилейная, 1	f	large
126562	4553	33	Республика Тыва, Ак-Довурак, Центральная, 23	f	\N
126564	4558	38	Республика Тыва, Ак-Довурак, Ленина, 24	f	\N
14303	4556	36	Республика Тыва, Ак-Довурак, Данзырык-калдар-оола, 76	f	large
14446	4700	179	Республика Тыва, Эрзинский район, поселок Эрзин, С. Тока, 8	f	\N
126683	4703	182	Республика Тыва, Эрзинский район, поселок Нарын, Чаа Суур, 1	f	\N
126681	4701	180	Республика Тыва, Эрзинский район, поселок Морен, Дажимба Данил, 19	f	\N
14448	4702	181	Республика Тыва, Эрзинский район, поселок Булун-Бажы, Галина Доваадор, 20	f	\N
14445	4699	178	Республика Тыва, Эрзинский район, поселок Бай-Даг, Ленина, 46	f	\N
126676	4695	174	Республика Тыва, Чеди-Хольский кожуун, поселок Элегест, Школьная, 5	f	\N
126667	4684	164	Республика Тыва, Улуг-Хемский район, поселок Эйлиг-Хем, Маадыр-оола, 2	f	\N
126672	4691	170	Республика Тыва, Улуг-Хемский район, поселок Шанчы, Даваа Самбуу, 13	f	\N
14422	4675	155	Республика Тыва, Улуг-Хемский район, Шагонар, Саяно-Шушенская, 2а	f	\N
14424	4677	157	Республика Тыва, Улуг-Хемский район, Шагонар, Октябрьская, 32	f	large
14423	4676	156	Республика Тыва, Улуг-Хемский район, Шагонар, Октябрьская, 28	f	large
14425	4678	158	Республика Тыва, Улуг-Хемский район, Шагонар, Дружба, 55А	f	\N
126665	4682	162	Республика Тыва, Улуг-Хемский район, поселок Чодураа, Школьная, 13	f	\N
14435	4688	168	Республика Тыва, Улуг-Хемский район, поселок Чаа-Холь, Школьная, 1	f	\N
14427	4680	160	Республика Тыва, Улуг-Хемский район, поселок Хайыракан, Кускелдей, 12	f	\N
126666	4683	163	Республика Тыва, Улуг-Хемский район, поселок Торгалыг, Советская, 51	f	\N
14434	4687	167	Республика Тыва, Улуг-Хемский район, поселок Ишти-Хем, Школьная, 1	f	small
14428	4681	161	Республика Тыва, Улуг-Хемский район, поселок Ийи-Тал, Барык, 14	f	\N
126669	4686	166	Республика Тыва, Улуг-Хемский район, поселок Арыскан, Гагарина, 29	f	\N
126668	4685	165	Республика Тыва, Улуг-Хемский район, поселок Арыг-Узю, Кочетова, 23	f	\N
126662	4679	159	Республика Тыва, Улуг-Хемский район, поселок Арыг-Бажы, Айлыг-Кыйыг, 25	f	\N
126673	4692	171	Республика Тыва, Улуг-Хемский район, поселок Ак-Дуруг, Ленина , 1	f	\N
126658	4673	153	Республика Тыва, Тоджинский район, поселок Ырбан, Промышленная, 9	f	\N
126654	4669	149	Республика Тыва, Тоджинский район, поселок Тоора-Хем, Советская, 26	f	\N
126655	4670	150	Республика Тыва, Тоджинский район, поселок Тоора-Хем, Енисейская, 49	f	\N
126659	4674	154	Республика Тыва, Тоджинский район, поселок Сыстыг-Хем, Школьная , 4	f	\N
126657	4672	152	Республика Тыва, Тоджинский район, поселок Ий, Советская, 15	f	\N
126656	4671	151	Республика Тыва, Тоджинский район, поселок Адыр-Кежиг, Анчы, 28	f	\N
126648	4663	143	Республика Тыва, Тес-Хемский район, сумон Чыргаланды, Ленина, 30	f	\N
126650	4665	145	Республика Тыва, Тес-Хемский район, поселок Шуурмак, Набережная, 5	f	\N
126647	4662	142	Республика Тыва, Тес-Хемский район, поселок Самагалтай, Кунаа, 42	f	\N
126651	4666	146	Республика Тыва, Тес-Хемский район, поселок Оо-Шынаа, Чооду Кежик-оола, 32	f	\N
126652	4667	147	Республика Тыва, Тес-Хемский район, поселок О-Шынаа, Артына С.А, 1	f	\N
126649	4664	144	Республика Тыва, Тес-Хемский район, поселок Берт-Даг, Ленина, 17	f	\N
126653	4668	148	Республика Тыва, Тес-Хемский район, поселок Ак-Эрик, Дружбы, 18	f	\N
14408	4661	141	Республика Тыва, Тере-Хольский кожуун, поселок Кунгуртуг, Комсомольская, 45	f	small
126677	4696	175	Республика Тыва, Тандинский район, поселок Чал-Кежиг (Элегест), Школьная, 1	f	\N
126674	4693	172	Республика Тыва, Тандинский район, поселок Хову-Аксы, Мира, 1	f	\N
14399	4653	132	Республика Тыва, Тандинский район, поселок Усть-Хадын (Хадын-Аксы), Туметея, 16	f	small
126631	4636	116	Республика Тыва, Тандинский район, поселок Усть-Хадын (Хадын-Аксы), Маады Парынмаа, 8	f	\N
14405	4659	138	Республика Тыва, Тандинский район, поселок Успенка, Оюн Сенгиижик, 22	f	small
126643	4652	131	Республика Тыва, Тандинский район, поселок Сосновка, Красных Партизан, 88	f	\N
14402	4656	135	Республика Тыва, Тандинский район, поселок Сой, Санаторная, 5	f	small
14443	4697	176	Республика Тыва, Тандинский район, поселок Сайлыг, Терешкова, 5	f	\N
14404	4658	137	Республика Тыва, Тандинский район, поселок Межегей (Алаак), Ленина, 38	f	medium
14401	4655	134	Республика Тыва, Тандинский район, поселок Кызыл-Арыг (Кызларик), Школьная, 26	f	small
14406	4660	139	Республика Тыва, Тандинский район, поселок Кочетово, Ленина, 28	f	medium
126642	4651	130	Республика Тыва, Тандинский район, поселок Дурген, Шоссейная, 14а	f	\N
126645	4657	136	Республика Тыва, Тандинский район, поселок Владимировка, Горького , 10	f	\N
126644	4654	133	Республика Тыва, Тандинский район, поселок Балгазын, Советская, 108	f	\N
126641	4650	129	Республика Тыва, Тандинский район, поселок Бай-Хаак, Советская, 88	f	\N
126637	4646	125	Республика Тыва, Сут-Хольский район, поселок Суг-Аксы, Чолгаалчылар, 20	f	\N
126639	4648	127	Республика Тыва, Сут-Хольский район, поселок Кызыл-Тайга, Ыймажап, 34	f	\N
126638	4647	126	Республика Тыва, Сут-Хольский район, поселок Кара-Чыраа, Арат, 37	f	\N
126640	4649	128	Республика Тыва, Сут-Хольский район, поселок Ишкин, Мурзууна, 69	f	\N
126636	4644	124	Республика Тыва, Сут-Хольский район, поселок Бора-Тайга, Найырал, 68	f	\N
126584	4580	60	Республика Тыва, Сут-Хольский район, поселок Баян-Тала, Самбуу, 20	f	\N
14389	4642	122	Республика Тыва, Сут-Хольский район, поселок Алдан-Маадыр, Самбажык	f	medium
126635	4643	123	Республика Тыва, Сут-Хольский район, поселок Ак-Даш, Найырал, 31	f	\N
126616	4618	98	Республика Тыва, Пий-Хемский район, поселок Ээрбек, Школьная, 14	f	\N
126634	4641	121	Республика Тыва, Пий-Хемский район, поселок Шивилиг, Первомайская, 2	f	\N
14444	4698	177	Республика Тыва, Пий-Хемский район, Холчук, Новая, 5 	f	small
126632	4637	117	Республика Тыва, Пий-Хемский район, поселок Уюк, Беспалова , 45	f	\N
14379	4632	112	Республика Тыва, Пий-Хемский район, Туран, Советская, 11, ДЮЦ г.Турана	f	large
4408	26198	679	Республика Бурятия, Улан-Удэ, Чайковского, 8	f	large
126628	4631	111	Республика Тыва, Пий-Хемский район, Туран, Комсомольская, 44	f	\N
126627	4630	110	Республика Тыва, Пий-Хемский район, Туран, Комсомольская, 16	f	\N
14376	4629	109	Республика Тыва, Пий-Хемский район, Туран, 30 лет Тувы, 10, Контора ШАМ	f	medium
126630	4635	115	Республика Тыва, Пий-Хемский район, поселок Тарлаг, Школьный, 3	f	\N
14385	4638	118	Республика Тыва, Пий-Хемский район, поселок Суш, Зеленая, 15	f	small
126633	4639	119	Республика Тыва, Пий-Хемский район, поселок Сесерлиг (Германовка), Мандараа, 3А	f	\N
14380	4633	113	Республика Тыва, Пий-Хемский район, поселок Найырал, Площадь Победы, Контора МТФ Туранское	f	small
126629	4634	114	Республика Тыва, Пий-Хемский район, поселок Аржаан, Советская, 1	f	\N
126622	4624	104	Республика Тыва, Овюрский район, поселок Чаа-Суур (Арыг-Бажы), Мезил-оола, 14	f	\N
126624	4626	106	Республика Тыва, Овюрский район, поселок Хандагайты, Школьный переулок, 1	f	\N
126625	4627	107	Республика Тыва, Овюрский район, поселок Солчур (Арыг-Бажы), Дамдын, 1	f	\N
126626	4628	108	Республика Тыва, Овюрский район, поселок Саглы, Чанчы-Хоо, 2	f	\N
126623	4625	105	Республика Тыва, Овюрский район, поселок Дус-Даг, Мунзук Севен-оола, 8	f	\N
126621	4623	103	Республика Тыва, Овюрский район, поселок Ак-Чыраа, Ирбитей, 1	f	\N
126619	4621	101	Республика Тыва, Монгун-Тайгинский район, поселок Мугур-Аксы, Саны-Шири, 58	f	\N
126618	4620	100	Республика Тыва, Монгун-Тайгинский район, поселок Мугур-Аксы, Кошкар-оола, 3	f	\N
126620	4622	102	Республика Тыва, Монгун-Тайгинский район, поселок Кызыл-Хая, Кечил, 10	f	\N
126614	4615	95	Республика Тыва, Кызылский район, поселок Шамбалыг, 40 лет Сов. Тувы, 1	f	\N
126610	4611	91	Республика Тыва, Кызылский район, поселок Черби, Школьная, 8	f	\N
126613	4614	94	Республика Тыва, Кызылский район, поселок Целинное, Кужугет Серена, 30	f	\N
126617	4619	99	Республика Тыва, Кызылский район, поселок Усть-Элегест, Горная, 1	f	\N
126612	4613	93	Республика Тыва, Кызылский район, поселок Терлиг-Хая, Энтузиастов, 6	f	\N
126615	4616	96	Республика Тыва, Кызылский район, поселок Сукпак, Фрунзе, 1В	f	\N
14364	4617	97	Республика Тыва, Кызылский район, поселок Сукпак, Геологов, 13, агро-лицей	f	medium
126646	4645	140	Республика Тыва, Кызылский район, поселок Кунгуртуг, Дружба, 4	f	\N
126609	4610	90	Республика Тыва, Кызылский район, поселок Кара-Хаак, Механизаторская, 10	f	\N
14354	4607	87	Республика Тыва, Кызылский район, поселок Каа-Хем, пер.Чооду Кидиспея, 5, столовая ЦСРН по Кызылскому кожууну	f	large
126608	4609	89	Республика Тыва, Кызылский район, поселок Каа-Хем, Таежная, 19	f	\N
126607	4606	86	Республика Тыва, Кызылский район, поселок Каа-Хем, Таежная, 17	f	\N
14355	4608	88	Республика Тыва, Кызылский район, поселок Каа-Хем, Народная, 1, Кок-Тейская шк.№2	f	large
126611	4612	92	Республика Тыва, Кызылский район, поселок Баян-Кол, Базыр Тулуш, 15	f	\N
126604	4602	82	Республика Тыва, Каа-Хемский район, поселок Эржей, Центральная, 5	f	\N
126605	4603	83	Республика Тыва, Каа-Хемский район, поселок Усть-Ужеп, Набережная, 14	f	\N
126602	4599	79	Республика Тыва, Каа-Хемский район, поселок Усть-Бурен (Грязнуха), Красных партизан, 52	f	\N
126595	4591	71	Республика Тыва, Каа-Хемский район, поселок Суг-Бажы, Валентина Хажики, 13	f	\N
126603	4601	81	Республика Тыва, Каа-Хемский район, поселок Сизим, Центральная, 28	f	\N
126600	4596	76	Республика Тыва, Каа-Хемский район, поселок Сарыг-Сеп (Знаменка), Енисейская, 162	f	\N
126597	4593	73	Республика Тыва, Каа-Хемский район, поселок Кундустуг (Федоровка), Центральная, 20	f	\N
126599	4595	75	Республика Тыва, Каа-Хемский район, поселок Кок-Хаак, Центральная, 104	f	\N
14352	4605	85	Республика Тыва, Каа-Хемский район, поселок Ильинка, Мира, 39	f	medium
126601	4598	78	Республика Тыва, Каа-Хемский район, поселок Дерзиг-Аксы (Даниловка), Магистральная, 1	f	\N
126596	4592	72	Республика Тыва, Каа-Хемский район, поселок Бурен-Хем (Зубовка), Енисейская, 26	f	\N
126606	4604	84	Республика Тыва, Каа-Хемский район, поселок Бурен-Бай-Хаак, Ленина, 34	f	\N
126598	4594	74	Республика Тыва, Каа-Хемский район, поселок Бояровка, Гагарина, 8	f	\N
14347	4600	80	Республика Тыва, Каа-Хемский район, Авыйган, Юбилейная, 1	f	small
14344	4597	77	Республика Тыва, Каа-Хемский кожуун, поселок Сарыг-Сеп (Знаменка), пер.Первомайский, 20	f	large
126585	4581	61	Республика Тыва, Дзун-Хемчикскийй район, поселок Ийме, Ленина, 7	f	\N
126594	4590	70	Республика Тыва, Дзун-Хемчикский район, поселок Элдиг-Хем, Ленина, 5	f	\N
126593	4589	69	Республика Тыва, Дзун-Хемчикский район, поселок Шеми, Найырал, 34	f	\N
126592	4588	68	Республика Тыва, Дзун-Хемчикский район, поселок Чыргакы, Ийистер, 48	f	\N
126591	4587	67	Республика Тыва, Дзун-Хемчикский район, поселок Чыраа-Бажы, Ленина, 45	f	\N
126583	4579	59	Республика Тыва, Дзун-Хемчикский район, Чадан, Сельская, 2	f	\N
126582	4578	58	Республика Тыва, Дзун-Хемчикский район, Чадан, Победы, 86	f	\N
126581	4577	57	Республика Тыва, Дзун-Хемчикский район, Чадан, Победы, 26	f	\N
126580	4576	56	Республика Тыва, Дзун-Хемчикский район, Чадан, Ленина, 57	f	\N
126589	4585	65	Республика Тыва, Дзун-Хемчикский район, поселок Хорум-Даг, Ховалыг Оюу, 24	f	\N
126588	4584	64	Республика Тыва, Дзун-Хемчикский район, поселок Хондергей, Октябрьская, 15	f	\N
126587	4583	63	Республика Тыва, Дзун-Хемчикский район, поселок Хайыракан, Данзы-Белек, 58	f	\N
126586	4582	62	Республика Тыва, Дзун-Хемчикский район, поселок Теве-Хая, Садовая, 1	f	\N
126590	4586	66	Республика Тыва, Дзун-Хемчикский район, поселок Бажын-Алаак, Карла Маркса, 59	f	\N
126579	4575	55	Республика Тыва, Барун-Хемчикский район, поселок Эрги-Барлык, Самбу, 23	f	\N
126577	4573	53	Республика Тыва, Барун-Хемчикский район, поселок Шекпээр (Биче-Тей), Октябрьская, 3	f	\N
126578	4574	54	Республика Тыва, Барун-Хемчикский район, поселок Хонделен, Чургуй-оол, 5	f	\N
14313	4566	46	Республика Тыва, Барун-Хемчикский район, поселок Кызыл-Мажалык (Барун), Чургуй-оол, 42	f	large
14314	95190	47	Республика Тыва, Барун-Хемчикский район, поселок Кызыл-Мажалык (Барун), Авиация, МОУ СОШ №2	f	large
126576	4572	52	Республика Тыва, Барун-Хемчикский район, поселок Дон-Терезин, Набережная, 1	f	\N
126575	4571	51	Республика Тыва, Барун-Хемчикский район, поселок Бижиктик-Хая, Ленина, 1	f	\N
126574	4570	50	Республика Тыва, Барун-Хемчикский район, поселок Барлык, Октябрьская, 26	f	\N
126573	4569	49	Республика Тыва, Барун-Хемчикский район, поселок Аянгаты (Сарыг-Бель), М. Чыргала, 5	f	\N
126572	4568	48	Республика Тыва, Барун-Хемчикский район, поселок Аксы-Барлык (Алдын-Булак), Культура, 9	f	\N
126571	4565	45	Республика Тыва, Бай-Тайгинский район, поселок Шуй, Нордуп, 46	f	\N
126567	4561	41	Республика Тыва, Бай-Тайгинский район, поселок Хемчик, Чудурукпай, 16	f	\N
126565	4559	39	Республика Тыва, Бай-Тайгинский район, поселок Тээли (Бай-Тайга), Ленина, 23	f	\N
126671	4690	169	Республика Тыва, Бай-Тайгинский район, поселок Кызыл-Даг, Ховалыг Сайын-оол, 22	f	\N
126569	4563	43	Республика Тыва, Бай-Тайгинский район, поселок Кара-Холь (Тапсы-Аксы), Монгуш Эдуард, 8	f	\N
126566	4560	40	Республика Тыва, Бай-Тайгинский район, поселок Дружба, Хараар-Тей, 31	f	\N
126570	4564	44	Республика Тыва, Бай-Тайгинский район, поселок Бай-Тал (Чон-Терек), Мира, 39	f	\N
126568	4562	42	Республика Тыва, Бай-Тайгинский кожуун, сумон Кызыл-Даг, Коп-Соок, 16	f	\N
4494	26265	765	Республика Бурятия, Улан-Удэ, Дом творчества п. Сосновый бор	f	large
4493	26264	764	Республика Бурятия, Улан-Удэ, поселок Сосновый бор, МОУ Средняя общеобразовательная школа №5 (здание начальной школы)	f	large
4376	26170	647	Республика Бурятия, Улан-Удэ, станция Мостовой	t	small
4381	26174	652	Республика Бурятия, Улан-Удэ, проспект 50-летия Октября, 29	f	large
4407	26197	678	Республика Бурятия, Улан-Удэ, микрорайон Новый Зеленый, 1	f	large
4488	26259	759	Республика Бурятия, Улан-Удэ, Энергетик, 1	f	large
4487	26259	758	Республика Бурятия, Улан-Удэ, Энергетик, 1	f	large
4482	26255	753	Республика Бурятия, Улан-Удэ, Шумяцкого, 4	f	large
4485	26257	756	Республика Бурятия, Улан-Удэ, Шукшина, 1	f	large
4398	26189	669	Республика Бурятия, Улан-Удэ, Шаляпина, 14А	f	large
4416	26204	687	Республика Бурятия, городской округ Улан-Удэ, Чкалова, 1	f	large
4417	26203	688	Республика Бурятия, Улан-Удэ, Чкалова, 8	f	medium
4415	26203	686	Республика Бурятия, Улан-Удэ, Чкалова, 8	f	large
4421	26203	692	Республика Бурятия, Улан-Удэ, Чкалова, 8	f	large
4363	26160	634	Республика Бурятия, городской округ Улан-Удэ, Чертенкова, 100	f	large
4362	26160	633	Республика Бурятия, городской округ Улан-Удэ, Чертенкова, 100	f	large
4410	26198	681	Республика Бурятия, Улан-Удэ, Чайковского, 8	f	large
4442	26223	713	Республика Бурятия, город Улан-Удэ, Цыбикова, 2	f	large
4441	26223	712	Республика Бурятия, город Улан-Удэ, Цыбикова, 2	f	large
4374	26168	645	Республика Бурятия, Улан-Удэ, Цивилева, 50	f	large
4379	26172	650	Республика Бурятия, Улан-Удэ, Хоца Намсараева, 5	f	large
4420	26205	691	Республика Бурятия, Улан-Удэ, Туполева, 14А	f	large
4419	26205	690	Республика Бурятия, Улан-Удэ, Туполева, 14А	f	medium
4418	26205	689	Республика Бурятия, Улан-Удэ, Туполева, 14А	f	large
4446	26226	717	Республика Бурятия, Улан-Удэ, Трубачеева, 152	f	large
4399	26190	670	Республика Бурятия, Улан-Удэ, Трактовая, 1	f	large
4524	26292	795	Республика Бурятия, Улан-Удэ, Толстихина, 2Б	f	large
4462	26238	733	Республика Бурятия, Улан-Удэ, Тобольская, 53	f	large
4461	26238	732	Республика Бурятия, Улан-Удэ, Тобольская, 53	f	large
4444	26224	715	Республика Бурятия, Улан-Удэ, Терешковой, 56	f	large
4443	26224	714	Республика Бурятия, Улан-Удэ, Терешковой, 56	f	large
4439	26221	710	Республика Бурятия, Улан-Удэ, Терешковой, 13	f	large
4428	26212	699	Республика Бурятия, Улан-Удэ, Терешковой, 1	f	large
4515	26284	786	Республика Бурятия, Улан-Удэ, Талалихина, 64	f	large
4514	26284	785	Республика Бурятия, Улан-Удэ, Талалихина, 64	f	large
4507	26278	778	Республика Бурятия, Улан-Удэ, Сухэ-Батора, 5	f	large
4414	26202	685	Республика Бурятия, Улан-Удэ, Столичная, 2А	f	large
4403	26194	674	Республика Бурятия, Улан-Удэ, Сперанского, 54А	f	medium
4486	26258	757	Республика Бурятия, городской округ Улан-Удэ, Совхозная, 50Д	f	large
4504	26275	775	Республика Бурятия, Улан-Удэ, Советская, 43	f	large
4506	26277	777	Республика Бурятия, Улан-Удэ, Смолина, 24А	f	large
4502	26273	773	Республика Бурятия, город Улан-Удэ, Смолина, 14	f	large
4435	26217	706	Республика Бурятия, городской округ Улан-Удэ, Северная, 92	f	large
4412	26199	683	Республика Бурятия, Улан-Удэ, Севастопольская, 3	f	large
4409	26199	680	Республика Бурятия, Улан-Удэ, Севастопольская, 3	f	large
4489	26260	760	Республика Бурятия, Улан-Удэ, Сахалинская, 32	f	large
4405	26195	676	Республика Бурятия, Улан-Удэ, Родины, 8	f	large
4404	26195	675	Республика Бурятия, Улан-Удэ, Родины, 8	f	large
4430	26214	701	Республика Бурятия, город Улан-Удэ, Ринчино, 7	f	large
4382	26175	653	Республика Бурятия, Улан-Удэ, Революции 1905 года, 32	f	large
4373	26167	644	Республика Бурятия, Улан-Удэ, Революции 1905 года, 71	f	large
4372	26167	643	Республика Бурятия, Улан-Удэ, Революции 1905 года, 71	f	large
4433	26216	704	Республика Бурятия, Улан-Удэ, Раздольная, 15	f	large
4434	26216	705	Республика Бурятия, Улан-Удэ, Раздольная, 15	f	large
4520	26288	791	Республика Бурятия, Улан-Удэ, Радикальцева, 5А	f	large
4378	26165	649	Республика Бурятия, Улан-Удэ, Железнодорожный район, Пушкина, 8	f	large
4369	26165	640	Республика Бурятия, Улан-Удэ, Железнодорожный район, Пушкина, 8	f	large
4365	26161	636	Республика Бурятия, Улан-Удэ, Пушкина, 40	f	large
4364	26161	635	Республика Бурятия, Улан-Удэ, Пушкина, 40	f	large
4366	26162	637	Республика Бурятия, город Улан-Удэ, Пушкина, 24А	f	large
4454	26233	725	Республика Бурятия, Улан-Удэ, Пугачева, 39	f	large
4517	26285	788	Республика Бурятия, Улан-Удэ, Покровская, 32	f	large
4516	26285	787	Республика Бурятия, Улан-Удэ, Покровская, 32	f	large
4457	26235	728	Республика Бурятия,  Улан-Удэ, Пищевая, 13	f	large
4456	26235	727	Республика Бурятия,  Улан-Удэ, Пищевая, 13	f	large
4509	26279	780	Республика Бурятия, Улан-Удэ, Партизанская, 42	f	medium
4508	26279	779	Республика Бурятия, Улан-Удэ, Партизанская, 42	f	large
4467	26243	738	Республика Бурятия, город Улан-Удэ, Павлова, 68	f	large
4497	26268	768	Республика Бурятия, Улан-Удэ, Оцимика, 10	f	large
4496	26267	767	Республика Бурятия, Улан-Удэ, Оцимика, 20	f	large
4395	26185	666	Республика Бурятия, Улан-Удэ, Октябрьская, 29	f	medium
4393	26185	664	Республика Бурятия, Улан-Удэ, Октябрьская, 29	f	large
4511	26280	782	Республика Бурятия, Улан-Удэ, Новая, 44	f	large
4510	26280	781	Республика Бурятия, Улан-Удэ, Новая, 44	f	large
4402	26193	673	Республика Бурятия, Улан-Удэ, Н.Нищенко, 19	f	medium
4469	26245	740	Республика Бурятия, Улан-Удэ, Мокрова, 18	f	large
4521	26289	792	Республика Бурятия, город Улан-Удэ, Микрорайон Вагжанова, 3 участок	f	large
4513	26283	784	Республика Бурятия, Улан-Удэ, Микрорайон Аэропорт, 11, микрорайон Аэропорт	f	large
4411	26200	682	Республика Бурятия, Улан-Удэ, Магистральная, 3	f	large
4367	26163	638	Республика Бурятия, Улан-Удэ, Лысогорская, 85а	f	large
4386	26179	657	Республика Бурятия, Улан-Удэ, Лимонова, 5	f	large
4503	26274	774	Республика Бурятия, Улан-Удэ, Ленина, 20	f	large
4499	26270	770	Республика Бурятия, Улан-Удэ, Куйбышева, 40	f	medium
4484	26256	755	Республика Бурятия, Улан-Удэ, Крылова, 77А	f	large
4483	26256	754	Республика Бурятия, Улан-Удэ, Крылова, 77А	f	large
4481	26254	752	Республика Бурятия, Улан-Удэ, Краснофлотская, 2	f	large
4478	26252	749	Республика Бурятия, Улан-Удэ, Краснофлотская, 46	f	large
4479	26252	750	Республика Бурятия, Улан-Удэ, Краснофлотская, 46	f	large
4413	26201	684	Республика Бурятия, Улан-Удэ, Краснодонская, 2а	f	large
4384	26177	655	Республика Бурятия,  Улан-Удэ, Красноармейская, 24	f	large
4392	26184	663	Республика Бурятия, Улан-Удэ, Комсомольская, 29	f	large
4460	26237	731	Республика Бурятия, Улан-Удэ, Ключевская, 60	f	large
4459	26237	730	Республика Бурятия, Улан-Удэ, Ключевская, 60	f	large
4458	26236	729	Республика Бурятия, городской округ Улан-Удэ, Ключевская, 94	f	large
4453	26232	724	Республика Бурятия, Улан-Удэ, Ключевская, 41	f	large
4452	26231	723	Республика Бурятия, Улан-Удэ, Ключевская, 23А	f	large
4450	26229	721	Республика Бурятия, Улан-Удэ, Ключевская, 44А	f	large
4447	26227	718	Республика Бурятия, Улан-Удэ, Ключевская, 21	f	large
4440	26222	711	Республика Бурятия, город Улан-Удэ, Октябрьский район, Карла Маркса, 31	f	large
4472	26247	743	Республика Бурятия, Улан-Удэ, Калашникова, 12	f	large
4471	26247	742	Республика Бурятия, Улан-Удэ, Калашникова, 12	f	large
4526	26282	797	Республика Бурятия, Улан-Удэ, Кабанская, 49	f	large
4525	26282	796	Республика Бурятия, Улан-Удэ, Кабанская, 49	f	large
4401	26192	672	Республика Бурятия, Улан-Удэ, Зеленхоз	f	large
4474	26248	745	Республика Бурятия,  Улан-Удэ, Жердева, 122	f	large
4473	26248	744	Республика Бурятия,  Улан-Удэ, Жердева, 122	f	large
4451	26230	722	Республика Бурятия, город Улан-Удэ, Жердева, 27	f	large
4449	26228	720	Республика Бурятия, Улан-Удэ, Жердева, 19	f	large
4448	26228	719	Республика Бурятия, Улан-Удэ, Жердева, 19	f	large
4505	26276	776	Республика Бурятия, город Улан-Удэ, Ербанова, 3	f	medium
4529	26295	800	Республика Бурятия, Улан-Удэ, Дорожная, 42	f	large
4377	26171	648	Республика Бурятия, Улан-Удэ, Добролюбова, 5	f	medium
4368	26164	639	Республика Бурятия, Улан-Удэ, Дзержинского, 13	f	large
4528	26294	799	Республика Бурятия, Улан-Удэ, Гурульбинская, 12А	f	large
4490	26261	761	Республика Бурятия, город Улан-Удэ, Горхонская, 3	f	large
4427	26211	698	Республика Бурятия, Улан-Удэ, Геологическая, 9	f	large
4426	26210	697	Республика Бурятия, Улан-Удэ, Геологическая, 10	f	large
4390	26182	661	Республика Бурятия, город Улан-Удэ, Гвардейская, 1А	f	large
4455	26234	726	Республика Бурятия, Улан-Удэ, Гармаева, 43	f	large
4383	26176	654	Республика Бурятия, Улан-Удэ, Гагарина, 12	f	large
4375	26169	646	Республика Бурятия, Улан-Удэ, Гагарина, 26А	f	large
4518	26286	789	Республика Бурятия, Улан-Удэ, Воронежская, 5	f	large
4400	26191	671	Республика Бурятия, город Улан-Удэ, Верхняя Березовка, кафе Максим	f	large
4397	26188	668	Республика Бурятия, Улан-Удэ, Буйко, 27А	f	large
4396	26187	667	Республика Бурятия, Улан-Удэ, Буйко, 2Б	f	large
4523	26291	794	Республика Бурятия, Улан-Удэ, Батарейная, 60	f	large
4527	26293	798	Республика Бурятия, Улан-Удэ, Баргузинская, 18	f	medium
4501	26272	772	Республика Бурятия, Улан-Удэ, Балтахинова, 38	f	large
4425	26209	696	Республика Бурятия, Улан-Удэ, Бабушкина, 2	f	large
4429	26213	700	Республика Бурятия, Улан-Удэ, Бабушкина, 31	f	large
4432	26215	703	Республика Бурятия, Улан-Удэ, 113 квартал, 4, 113 квартал	f	large
4431	26215	702	Республика Бурятия, Улан-Удэ, 113 квартал, 4, 113 квартал	f	large
4385	26178	656	Республика Бурятия,  Улан-Удэ, проспект 50-летия Октября, 58	f	large
4465	26241	736	Республика Бурятия, Улан-Удэ, Октябрьский район, Строителей, 16	f	large
4371	26166	642	Республика Бурятия,  Улан-Удэ, Революции 1905 года, 100	f	large
4370	26166	641	Республика Бурятия,  Улан-Удэ, Революции 1905 года, 100	f	large
4259	26055	530	Республика Бурятия, Северобайкальск, проспект Ленинградский, 10	f	large
4261	26057	532	Республика Бурятия, Северобайкальск, проспект 60 лет СССР, 12	f	large
4267	26063	538	Республика Бурятия, Северобайкальск, Космонавтов, 13	f	large
4269	26065	540	Республика Бурятия, Северобайкальск, 60 лет ВЛКСМ, 6	f	large
4145	25955	416	Республика Бурятия, Кяхта, Цыбиктарова, 1	f	small
4137	25947	408	Республика Бурятия, Кяхта, Крупской, 42	f	large
4033	25844	304	Республика Бурятия, Каменск, Вокзальная, 1	t	small
3952	25764	223	Республика Бурятия, Закаменск, здание Закаменского ДРСуч	f	medium
3948	25759	219	Республика Бурятия, Закаменск, здание районного Дворца культуры	f	large
3945	25756	216	Республика Бурятия, Закаменск, здание МОУ СОШ №5 г. Закаменск	f	large
3944	25755	215	Республика Бурятия, Закаменск, здание МОУ СОШ №4 г. Закаменск	f	medium
4276	26072	547	Республика Бурятия, Гусиноозерск, 9 микрорайон, МОУ ООШ № 7	f	large
4043	25854	314	Республика Бурятия, Бабушкин, 3 Интернационала, 47	f	large
4391	26183	662	Республика Бурятия, городской округ Улан-Удэ, Улан-Удэ, Комсомольская, 28А	f	large
4512	26281	783	Республика Бурятия, городской округ Улан-Удэ, Улан-Удэ, микрорайон Сокол, 4а	f	large
4495	26266	766	Республика Бурятия, городской округ Улан-Удэ, Улан-Удэ, Ясная, 1, МОУ «Средняя общеобразовательная школа №24»	f	large
4380	26173	651	Республика Бурятия, городской округ Улан-Удэ, Чертенкова, 3	f	large
4498	26269	769	Республика Бурятия, городской округ Улан-Удэ, Тарбагатайская, 49	f	large
4519	26287	790	Республика Бурятия, городской округ Улан-Удэ, Радикальцева, 5Б	f	large
4387	26180	658	Республика Бурятия, городской округ Улан-Удэ, Улан-Удэ, Комсомольская, 3	f	large
4394	26186	665	Республика Бурятия, городской округ Улан-Удэ, Буйко, 2А	f	large
4562	26327	833	Республика Бурятия, Хоринский район, село Хоринск, Хоринская, 68	f	large
4563	26328	834	Республика Бурятия, Хоринский район, село Хоринск, Театральная, 8	f	large
4561	26326	832	Республика Бурятия, Хоринский район, село Хоринск, Ленина, 38	f	large
4540	26305	811	Республика Бурятия, Хоринский район, село Хасурта, Центральная, 113 A	t	small
4548	26313	819	Республика Бурятия, Хоринский район, село Хандагай, Школьная, 8	t	small
4542	26307	813	Республика Бурятия, Хоринский район, село Удинск, Ленина, 87	t	medium
4539	26304	810	Республика Бурятия, Хоринский район, Тэгда, Центральная, 26А	t	large
4537	26302	808	Республика Бурятия, Хоринский район, село Тохорюкта, Школьная, 16	t	small
4546	26311	817	Республика Бурятия, Хоринский район, село Тарбагатай, Тарбагатайская, 32	t	small
4547	26312	818	Республика Бурятия, Хоринский район, село Санномыск, Ленина, 1	t	small
4555	26320	826	Республика Бурятия, Хоринский район, село Ониноборск, Школьная, 6	t	small
4538	26303	809	Республика Бурятия, Хоринский район, село Ойбонт, Центральная, 22	t	small
4549	26314	820	Республика Бурятия, Хоринский район, село Нарын, Магистральная, 36	t	small
4536	26301	807	Республика Бурятия, Хоринский район, село Малая Курба, Школьная, 6	t	small
4554	26319	825	Республика Бурятия, Хоринский район, село Майла, Школьная, 9	t	small
4551	26316	822	Республика Бурятия, Хоринский район, село Кульский Станок, Школьная, 5	t	small
4550	26315	821	Республика Бурятия, Хоринский район, село Кульск, Кульская, 13А	t	small
4557	26322	828	Республика Бурятия, Хоринский район, село Зун-Хурай, Школьная, 7	t	small
4544	26309	815	Республика Бурятия, Хоринский район, село Додо-Гол, Советская, 34	t	small
4545	26310	816	Республика Бурятия, Хоринский район, село Верхние Тальцы, Комсомольская, 1А	t	medium
4556	26321	827	Республика Бурятия, Хоринский район, село Булум, Школьная, 5	t	small
4543	26308	814	Республика Бурятия, Хоринский район, село Баян-Гол, Клубная, 3Б	t	small
4541	26306	812	Республика Бурятия, Хоринский район, село Барун-Хасурта, Балбарова, 403	t	small
4558	26323	829	Республика Бурятия, Хоринский район, село Ашанга, Центральная, 1	t	small
4560	26325	831	Республика Бурятия, Хоринский район, село Ашанга, Харитонова, 25	t	small
4553	26318	824	Республика Бурятия, Хоринский район, село Анинск, Строительная, 4	t	small
4559	26324	830	Республика Бурятия, Хоринский район, село Амгаланта, Интернациональная, 26	t	small
4552	26317	823	Республика Бурятия, Хоринский район, село Алан, Коммунистическая, 16	t	small
4327	26124	598	Республика Бурятия, Тункинский район, село Шулута, Гагарина, 10	f	small
4357	26155	628	Республика Бурятия, Тункинский район, село Шимки, Октябрьская, 44	t	small
4330	26127	601	Республика Бурятия, Тункинский район, село Шанай, Советская, помещение школы-сад	t	small
4356	26154	627	Республика Бурятия, Тункинский район, село Хужиры, Школьная, 1	f	medium
4360	26158	631	Республика Бурятия, Тункинский район,  Хойтогол, Квартал 10, 37	t	small
4350	26147	621	Республика Бурятия, Тункинский район, село Харбяты, Ербанова, 5	t	small
4341	26138	612	Республика Бурятия, Тункинский район, село Улбугай, пер. Лесной, 4	t	small
4358	26156	629	Республика Бурятия, Тункинский район, село Туран, Центральная, 78	t	small
4336	26133	607	Республика Бурятия, Тункинский район, село Тунка, Горького, 61	f	medium
4328	26125	599	Республика Бурятия, Тункинский район, село Торы, Трактовая, 26	f	medium
4342	26139	613	Республика Бурятия, Тункинский район, Толтой, Кооперативная, 5	f	small
4337	26134	608	Республика Бурятия, Тункинский район, Токурен, Траковая, 6	f	small
4340	26137	611	Республика Бурятия, Тункинский район, село Талое, Каменушка, 12а	f	small
4343	26140	614	Республика Бурятия, Тункинский район, село Тагархай, Балданова, 12	t	small
4339	26136	610	Республика Бурятия, Тункинский район, село Табалангут, Молодежная, 2а	t	small
4348	26145	619	Республика Бурятия, Тункинский район, село Охор-Шибирь, Школьная, 1	f	small
4351	26148	622	Республика Бурятия, Тункинский район, село Нуган, Калинина, помещение школы-сад	f	small
4359	26157	630	Республика Бурятия, Тункинский район, село Ниловка, Центральная, 32	t	small
4335	26132	606	Республика Бурятия, Тункинский район, село Никольск, Трактовая, 2	f	small
4361	26159	632	Республика Бурятия, Тункинский район, село Монды, Ленина, 38	t	medium
4349	26146	620	Республика Бурятия, Тункинский район, село Малый Жемчуг, Тулаева, 21	t	small
4354	26151	625	Россия, Республика Бурятия, Тункинский район, село Кырен	f	medium
4352	26149	623	Республика Бурятия, Тункинский район, село Кырен, Чапаева, 16	f	medium
4355	26152	626	Республика Бурятия, Тункинский район, село Кырен, Ленина, 135	f	medium
4353	26150	624	Республика Бурятия, Тункинский район, село Кырен, Ленина, 98	f	medium
4329	26126	600	Республика Бурятия, Тункинский район, село Зун-Мурино, Индиры Ганди, б/н	f	medium
4346	26143	617	Республика Бурятия, Тункинский район, село Зактуй, Школьная	t	small
4347	26144	618	Республика Бурятия, Тункинский район, село Жемчуг, Советская, 2	f	medium
4228	26024	499	Республика Бурятия, Тункинский район, село Еловка, Школьная, 2А	t	small
4333	26130	604	Республика Бурятия, Тункинский район, село Еловка, Комсомольская, 1	t	small
4331	26128	602	Республика Бурятия, Тункинский район, село Далахай, Ленина, 1	t	small
4332	26129	603	Республика Бурятия, Тункинский район, село Гужиры, Истомина, 25	t	small
4338	26135	609	Республика Бурятия, Тункинский район, село Галбай, Ленина, 20	t	small
4334	26131	605	Республика Бурятия, Тункинский район, село Ахалик, Ленина, 30	t	small
4345	26142	616	Республика Бурятия, Тункинский район, село Аршан, Трактовая, 74А	f	medium
4344	26141	615	Республика Бурятия, Тункинский район, село Аршан, Трактовая, 30	f	medium
4320	26117	591	Республика Бурятия, Тарбагатайский район, село Харитоново, Калинина, 40	t	small
4318	26115	589	Республика Бурятия, Тарбагатайский район, село Хандагатай, Антонова, 37	f	small
4314	26111	585	Республика Бурятия, Тарбагатайский район, село Тарбагатай, Рокоссовского, 3	f	large
4313	26109	584	Республика Бурятия, Тарбагатайский район, село Тарбагатай, Ленина, 31	f	large
4312	26108	583	Республика Бурятия, Тарбагатайский район, село Пестерево, Кирова, 60 А	t	small
4326	26123	597	Республика Бурятия, Тарбагатайский район, село Николаевский, Октябрьская, 1	t	medium
4315	26112	586	Республика Бурятия, Тарбагатайский район, село Нижний Жирим, Калинина, 47	t	small
4308	26104	579	Республика Бурятия, Тарбагатайский район, село Надеино, Ленина, 77	t	small
4307	26103	578	Республика Бурятия, Тарбагатайский район, село Куйтун, Ленина, 65 А	t	medium
4310	26106	581	Республика Бурятия, Тарбагатайский район, село Десятниково, Ленина, 32	f	small
4316	26113	587	Республика Бурятия, Тарбагатайский район, село Верхний Жирим, Советская, 10	t	medium
4311	26107	582	Республика Бурятия, Тарбагатайский район, село Бурнашево, Молодежная, 28	t	small
4309	26105	580	Республика Бурятия, Тарбагатайский район, село Большой Куналей, Ленина, 173	t	medium
4317	26114	588	Республика Бурятия, Тарбагатайский район, село Барыкино-Ключи, Ленина, 20	t	small
4319	26116	590	Республика Бурятия, Тарбагатайский район, село Барыкино, Ленина, 98	t	small
4293	26089	564	Республика Бурятия, Селенгинский район, улус Зурган-Дэбэ, средняя школа	t	medium
4281	26077	552	Республика Бурятия, Селенгинский район, село Ягодное, начальная школа	t	small
4287	26083	558	Республика Бурятия, Селенгинский район, село Шана, начальная школа	f	small
4299	26095	570	Республика Бурятия, Селенгинский район, село Усть-Урма, школа-интернат	t	small
4174	25975	445	Республика Бурятия, Селенгинский район, село Усть-Алташа (Алташа), Солнечная, 4	t	small
4300	26096	571	Республика Бурятия, Селенгинский район, село Удунга, клуб	t	small
4280	26076	551	Республика Бурятия, Селенгинский район, село Тохой, Дом культуры	f	large
4301	26097	572	Республика Бурятия, Селенгинский район, село Темник (Ацула), Садовая, 32	t	small
4298	26094	569	Республика Бурятия, Селенгинский район, село Ташир, средняя школа	t	medium
4284	26080	555	Республика Бурятия, Селенгинский район, село Таежный, основная школа	t	small
4303	26099	574	Республика Бурятия, Селенгинский район, село Средний Убукун, Е.Волковой, 18Б	t	small
4285	26081	556	Республика Бурятия, Селенгинский район, поселок городского типа Селендума, СДК	f	large
4286	26082	557	Республика Бурятия, Селенгинский район, поселок Селендума, Фрунзе, 19, администрация с.Селендума	f	small
4289	26085	560	Республика Бурятия, Селенгинский район, село Поворот, школа-интернат	t	small
4290	26086	561	Республика Бурятия, Селенгинский район, село Нур-Тухум, переулок Школьный, 1А	t	small
4288	26084	559	Республика Бурятия, Селенгинский район, село Новоселенгинск, Дом культуры	f	large
4294	26090	565	Республика Бурятия, Селенгинский район, село Зурган-Дэбэ (Ноёхон), Солнечная, 1, Здание администрации МО СП	t	small
4304	26100	575	Республика Бурятия, Селенгинский район, село Жаргаланта, Ленина, 28	t	small
4296	26092	567	Республика Бурятия, Селенгинский район, Ехэ-Цаган, средняя школа	t	small
4292	26088	563	Республика Бурятия, Селенгинский район, село Енхор, начальная школа	t	small
4305	26101	576	Республика Бурятия, Селенгинский район, село Дэдэ-Сутой, Средняя школа	t	small
4291	26087	562	Республика Бурятия, Селенгинский район, село Дэбэн (Обон-Гызык), начальная школа	t	small
3796	25609	67	Республика Бурятия, Селенгинский район, село Дэбэн (Обон-Гызык), Дэбэн, 15	t	small
4295	26091	566	Республика Бурятия, Селенгинский район, Гусиноозерск, СОШ № 92	t	large
4279	26075	550	Россия, Республика Бурятия, Селенгинский район, город Гусиноозерск	t	small
4272	26068	543	Республика Бурятия, Селенгинский район, Гусиноозерск, Пушкина, 34, ГЦД Россия	f	large
4270	26066	541	Республика Бурятия, Селенгинский район, Гусиноозерск, Ленина, 19, Спорткомплекс	f	large
4277	26073	548	Республика Бурятия, Селенгинский район, город Гусиноозерск, Красноармейская, 1, СОШ №6	f	large
4306	26102	577	Республика Бурятия, Селенгинский район, Гусиноозерск, Комсомольская, 6, МУ ДК Шахтер	f	large
4271	26067	542	Республика Бурятия, Селенгинский район, Гусиноозерск, Колхозная, 2А, Гусиноозерская гимназия	f	large
4274	26070	545	Республика Бурятия, Селенгинский район, Гусиноозерск, Ключевская, 14А, СОШ №4	f	large
4273	26069	544	Республика Бурятия, Селенгинский район, Гусиноозерск, Водная, 1	f	large
4275	26071	546	Республика Бурятия, Селенгинский район, Гусиноозерск, 6 микрорайон, 20а, СОШ № 5	f	large
4283	26079	554	Республика Бурятия, Селенгинский район, село Бараты, средняя школа	t	small
4282	26078	553	Республика Бурятия, Селенгинский район, село Ардасан, начальная школа	t	small
4258	26054	529	Россия, Республика Бурятия, Северобайкальский район, поселок городского типа Янчукан	t	small
4246	26042	517	Республика Бурятия, Северобайкальский район, село Холодная, Ленина, 12	t	small
4251	26047	522	Республика Бурятия, Северобайкальский район, село Уоян, Набережная, 1а	t	small
4260	26056	531	Республика Бурятия, Северобайкальский район, Северобайкальск, проспект Пролетарский, 2	f	large
4264	26060	535	Республика Бурятия, Северобайкальский район, Северобайкальск, проспект 60 лет СССР, 40а	f	large
4262	26058	533	Республика Бурятия, Северобайкальский район, город Северобайкальск, проспект 60 лет СССР, 19	f	large
4263	26059	534	Республика Бурятия, Северобайкальский район, Северобайкальск, пр-т Ленинградский, 11	f	large
4268	26064	539	Республика Бурятия, Северобайкальский район, Северобайкальск, переулок Пионерский, 4	f	large
4266	26062	537	Республика Бурятия, Северобайкальский район, Северобайкальск, Пер. Школьный, 6	f	large
4265	26061	536	Республика Бурятия, Северобайкальский район, Северобайкальск, Мира, 4	f	large
4252	26048	523	Республика Бурятия, Северобайкальский район, Новый Уоян, Лесоводов, 6	t	medium
4254	26050	525	Республика Бурятия, Северобайкальский район, Новый Уоян, Добровольцев, 15	t	medium
4256	26052	527	Республика Бурятия, Северобайкальский район, поселок городского типа Новый Уоян, Байкальская, здание ком. магазина 	t	small
4253	26049	524	Республика Бурятия, Северобайкальский район, поселок городского типа Новый Уоян, 70 лет Октября, 33	t	medium
4255	26051	526	Республика Бурятия, Северобайкальский район, поселок Новый Уоян, Восточная, 8	t	small
4243	26039	514	Республика Бурятия, Северобайкальский район, поселок городского типа Нижнеангарск, Рабочая, 127а	f	medium
4241	26037	512	Республика Бурятия, Северобайкальский район, Нижнеангарск, Победы, 2	f	medium
4244	26040	515	Республика Бурятия, Северобайкальский район, Нижнеангарск, Озерная, 8	f	medium
4242	26038	513	Республика Бурятия, Северобайкальский район, поселок городского типа Нижнеангарск, Кооперативная, 87	f	large
4257	26053	528	Республика Бурятия, Северобайкальский район, село Кумора, Юбилейная, 14	t	small
4248	26044	519	Республика Бурятия, Северобайкальский район, поселок городского типа Кичера, Центральная, 1	t	medium
4247	26043	518	Республика Бурятия, Северобайкальский район, Кичера, Мелиораторов, 7б	t	medium
4249	26045	520	Республика Бурятия, Северобайкальский район, село Верхняя Заимка, Советская , 37, здание администрации села	t	medium
4245	26041	516	Республика Бурятия, Северобайкальский район, село Байкальское, Победы, 7А	t	medium
4250	26046	521	Республика Бурятия, Северобайкальский район, село Ангоя, Космонавтов, 2	t	medium
4240	26036	511	Республика Бурятия, Северо-Байкальский район, поселок Нижнеангарск, Победы, 43	f	large
4206	26005	477	Республика Бурятия, Прибайкальский район, село Ярцы, курорт Байкальский Бор	f	small
4236	26032	507	Республика Бурятия, Прибайкальский район, село Югово, 40 лет Октября, 31	f	small
4217	26013	488	Республика Бурятия, Прибайкальский район, село Халзаново, Мелиораторов, 8	t	small
4222	26018	493	Республика Бурятия, Прибайкальский район, село Турунтаево, Профсоюзная, 2	f	large
4221	26017	492	Республика Бурятия, Прибайкальский район, село Турунтаево, Ленина, 75	f	medium
4220	26016	491	Республика Бурятия, Прибайкальский район, село Турунтаево, 50 лет Октября, 3	f	large
4219	26015	490	Республика Бурятия, Прибайкальский район, село Турунтаево, 16 квартал, ТУСМ	f	small
4204	26003	475	Республика Бурятия, Прибайкальский район, село Турка, Школьная, 34	f	large
4235	26031	506	Республика Бурятия, Прибайкальский район, село Троицкое, 60 лет Октября, 30	f	small
4230	26026	501	Республика Бурятия, Прибайкальский район, село Татаурово, Школьная, 20	f	large
4237	26033	508	Республика Бурятия, Прибайкальский район, село Таловка, Лазо, 3а	f	large
4238	26034	509	Республика Бурятия, Прибайкальский район, село Таловка, Гагарина, 1	t	small
4229	26025	500	Республика Бурятия, Прибайкальский район, село Старое Татаурово, Юбилейная, 93	f	medium
4202	26001	473	Республика Бурятия, Прибайкальский район, село Соболиха, Набережная, 1	t	small
3801	25614	72	Республика Бурятия, Прибайкальский район, село Покровка, Подгорная, 21а	t	small
4211	26007	482	Республика Бурятия, Прибайкальский район, село Нестерово, Комсомольская, 34А	f	small
4239	26035	510	Республика Бурятия, Прибайкальский район, село Мостовка, Молодежная, 19	f	medium
4226	26022	497	Республика Бурятия, Прибайкальский район, село Лиственничное, Заводская, 1	t	small
4208	14700	479	Республика Бурятия, Прибайкальский район, село Котокель, Озерная, 27	t	small
4223	26019	494	Республика Бурятия, Прибайкальский район, село Кома, Коммунистическая, 75а	t	medium
4209	14701	480	Республика Бурятия, Прибайкальский район, село Кика, Трактовая, 28	f	small
4216	26012	487	Республика Бурятия, Прибайкальский район, село Карымск, Чкалова, 30А	f	small
4225	26021	496	Республика Бурятия, Прибайкальский район, село Итанца, Советская, 28	f	medium
4205	26004	476	Республика Бурятия, Прибайкальский район, село Исток, Братьев Ильиных, 73	t	small
4218	26014	489	Республика Бурятия, Прибайкальский район, село Иркилик, Братьев Седуновых, 24	t	medium
4234	26030	505	Республика Бурятия, Прибайкальский район, село Ильинка, Павлова, 9	f	small
4232	26028	503	Республика Бурятия, Прибайкальский район, село Ильинка, Октябрьская, 123	f	large
4231	26027	502	Республика Бурятия, Прибайкальский район, село Ильинка, Октябрьская, 65а	f	medium
4233	26029	504	Республика Бурятия, Прибайкальский район, село Ильинка, Коммунистическая, 63	f	medium
4215	26011	486	Республика Бурятия, Прибайкальский район, село Зырянск, Партизанская, 1А	f	small
4201	26000	472	Республика Бурятия, Прибайкальский район, село Золотой Ключ, Набережная, 13	t	small
4210	14702	481	Республика Бурятия, Прибайкальский район, село Гурулево, Центральная, 12а	t	small
4207	26006	478	Республика Бурятия, Прибайкальский район, село Гремячинск, Пионерская, 23	f	medium
4203	26002	474	Россия, Республика Бурятия, Прибайкальский район, село Горячинск	f	medium
4213	26009	484	Республика Бурятия, Прибайкальский район, село Бурля, 12	t	small
4224	26020	495	Республика Бурятия, Прибайкальский район, село Бурдуково, Октябрьская, 32	t	small
4212	26008	483	Республика Бурятия, Прибайкальский район, село Батурино, Монастырская, 2Б	f	small
4214	26010	485	Республика Бурятия, Прибайкальский район, село Ангыр, Центральная, 35	f	small
4198	25997	469	Республика Бурятия, Окинский район, село Хара-Хужир, Набережная, 8	t	small
4191	25990	462	Республика Бурятия, Окинский район, село Сорок, Школьный переулок, 14	t	small
4192	25991	463	Республика Бурятия, Окинский район, село Сорок, Центральная, 6	t	small
4199	25998	470	Республика Бурятия, Окинский район, село Саяны, Лесная, 2	t	small
4190	25989	461	Республика Бурятия, Окинский район, село Самарта, административное здание рудника Холбинский	t	small
4195	25994	466	Республика Бурятия, Окинский район, село Орлик, 26, Комсомольская предприятие Коммунальник	t	small
4196	25995	467	Республика Бурятия, Окинский район, село Орлик, Школьная, 1а	t	small
4193	25992	464	Республика Бурятия, Окинский район, село Орлик, Школьная, 10, Поликлиника МУЗ Окинская центральная районная больница, детская консультация	t	small
4194	25993	465	Республика Бурятия, Окинский район, село Орлик, Советская, 29	t	small
4197	25996	468	Республика Бурятия, Окинский район, село Орлик, Молодежная, 13	t	small
4164	25958	435	Республика Бурятия, Мухоршибирский район, село Шинестуй, Октябрьская, 19	f	small
4189	25988	460	Республика Бурятия, Мухоршибирский район, село Шаралдай, И.Калашникова, 100	t	large
4187	14698	458	Республика Бурятия, Мухоршибирский район, село Цолга, Школьная, 5	t	medium
4181	25981	452	Республика Бурятия, Мухоршибирский район, село Хонхолой, Школьная, 4	f	large
4182	25982	453	Республика Бурятия, Мухоршибирский район, село Харьястка, Арсаланова, 9	f	small
4180	25980	451	Республика Бурятия, Мухоршибирский район, село Харашибирь, Ленина, 1А	f	medium
4179	25979	450	Республика Бурятия, Мухоршибирский район, село Тугнуй, Комсомольская, 2Б	f	medium
4188	25987	459	Республика Бурятия, Мухоршибирский район, село Тахай,  Ленина, здание школы	t	small
4177	25977	448	Республика Бурятия, Мухоршибирский район, село Степной, Пионерская, здание клуба	f	small
4175	25976	446	Республика Бурятия, Мухоршибирский район, село Саган-Нур, Молодежная, 10	f	large
4176	25976	447	Республика Бурятия, Мухоршибирский район, село Саган-Нур, Молодежная, 10	f	large
4173	25974	444	Республика Бурятия, Мухоршибирский район, село Подлопатки, Ленина, 50	t	medium
4172	25973	443	Республика Бурятия, Мухоршибирский район, село Новый Заган, Солнечная, 1	t	medium
4171	25972	442	Республика Бурятия, Мухоршибирский район, село Новый Заган, Партизанская, 2	t	medium
4178	25978	449	Республика Бурятия, Мухоршибирский район, село Новоспасск, Манзанова, здание клуба	f	small
4170	25971	441	Республика Бурятия, Мухоршибирский район, село Никольск, Ленина, 14а	f	large
4169	25970	440	Республика Бурятия, Мухоршибирский район, село Нарсата, Ленина, 38	f	small
3849	25662	120	Республика Бурятия, Джидинский район, село Боргой, Советская, 1	t	small
4167	25968	438	Республика Бурятия, Мухоршибирский район, село Мухоршибирь, Доржиева, 32	f	large
4166	25967	437	Республика Бурятия, Мухоршибирский район, село Мухоршибирь, Доржиева, 26	f	large
4165	25966	436	Республика Бурятия, Мухоршибирский район, село Мухоршибирь, 30 лет Победы, 18	f	large
4163	25965	434	Республика Бурятия, Мухоршибирский район, село Кусоты, Ленина, 1а	f	medium
4161	25963	432	Республика Бурятия, Мухоршибирский район, село Калиновка, Солнечная, 1	f	small
4186	25986	457	Республика Бурятия, Мухоршибирский район, село Зандин, 50 Лет Октября, 1	t	small
4184	25984	455	Республика Бурятия, Мухоршибирский район, село Гашей, Гагарина, 10	t	small
4162	25964	433	Республика Бурятия, Мухоршибирский район, село Галтай, Лодоева, 13	f	small
4168	25969	439	Республика Бурятия, Мухоршибирский район, село Верхний Сутай, Заречная, 8	t	small
4160	25962	431	Республика Бурятия, Мухоршибирский район, село Бом, Советская, 6	f	small
4159	25961	430	Республика Бурятия, Мухоршибирский район, село Бар, Ленина, 78	f	small
4185	25985	456	Республика Бурятия, Мухоршибирский район, село Балта, Балтинская, 10	t	small
4157	25960	428	Республика Бурятия, Муйский район, село Усть-Муя, Муйская сельская администрация	t	medium
4158	25960	429	Республика Бурятия, Муйский район, село Усть-Муя, Муйская сельская администрация	f	small
4154	25957	425	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	t	small
4153	25957	424	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	f	medium
4152	25957	423	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	f	large
4151	25957	422	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	f	large
4150	25957	421	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	f	large
4148	25957	419	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	f	large
4149	25957	420	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	f	medium
4147	25957	418	Россия, Республика Бурятия, Муйский район, поселок городского типа Таксимо	f	medium
4155	25959	426	Республика Бурятия, Муйский район, Северомуйск	t	large
4156	25959	427	Республика Бурятия, Муйский район, Северомуйск	t	large
3773	25586	44	Республика Бурятия, Муйский район, село Витим, Первомайская, 2	t	small
4116	25926	387	Республика Бурятия, Кяхтинский район, село Энхэ-Тала, Школьная, школа	t	small
4111	25921	382	Республика Бурятия, Кяхтинский район, село Шарагол, Октябрьская, 20	t	small
4106	25916	377	Республика Бурятия, Кяхтинский район, село Шазагай, Степанова, клуб	t	small
4126	25936	397	Республика Бурятия, Кяхтинский район, село Чикой, Нагорная, 1	f	medium
4112	25922	383	Республика Бурятия, Кяхтинский район, село Хутор, Советская, 23	t	small
4133	25943	404	Республика Бурятия, Кяхтинский район, село Хоронхой, Школьная, 1	f	large
4115	25925	386	Республика Бурятия, Кяхтинский район, село Холой, Клубная, ФП	t	small
4125	25935	396	Республика Бурятия, Кяхтинский район, село Хилгантуй, Молодежная, школа	t	small
4128	25938	399	Республика Бурятия, Кяхтинский район, село Харьяста, Набережная, 7	t	small
4103	25913	374	Республика Бурятия, Кяхтинский район, село Хамнигадай, Лесная, 31	t	small
4132	25942	403	Республика Бурятия, Кяхтинский район, село Усть-Кяхта, Школьная, 8	f	large
4119	25929	390	Республика Бурятия, Кяхтинский район, село Усть-Киран, площадь Победы, 7	f	medium
4096	25906	367	Республика Бурятия, Кяхтинский район, село Усть-Дунгуй, Центральная, 42	f	medium
4117	25927	388	Республика Бурятия, Кяхтинский район, село Унгуркуй, Школьная, 39	f	small
4098	25908	369	Республика Бурятия, Кяхтинский район, село Уладый, Набережная, 1	f	small
4108	25918	379	Республика Бурятия, Кяхтинский район, село Убур-Киреть, Партизанская, школа	f	small
4105	25915	376	Республика Бурятия, Кяхтинский район, село Тамир, Школьная, 1 А	f	small
4131	25941	402	Республика Бурятия, Кяхтинский район, село Субуктуй, Школьная, 8 А	t	small
4104	25914	375	Республика Бурятия, Кяхтинский район, село Семеновка, Дорожная, 31	t	small
4118	25928	389	Республика Бурятия, Кяхтинский район, село Полканово, Кооперативная, 7	t	small
4100	25910	371	Республика Бурятия, Кяхтинский район, село Первомайское, Рабочая,  8	f	small
4114	25924	385	Республика Бурятия, Кяхтинский район, село Октябрьский, Дорожная, здание администрации	f	small
4129	25939	400	Республика Бурятия, Кяхтинский район, село Новодесятниково, Баннова, 15	t	small
4135	25945	406	Республика Бурятия, Кяхтинский район, поселок городского типа Наушки, Железнодорожная, 4	f	large
4134	25944	405	Республика Бурятия, Кяхтинский район, поселок городского типа Наушки, Железнодорожная, 2	f	large
4124	25934	395	Республика Бурятия, Кяхтинский район, село Мурочи, Школьная, 24	t	small
4097	25907	368	Республика Бурятия, Кяхтинский район, село Малая Кудара, Школьная, 3	t	small
4143	25953	414	Республика Бурятия, Кяхтинский район, поселок Майский, кафе Чайная	f	large
4140	25950	411	Республика Бурятия, Кяхтинский район, Кяхта, Юбилейная, 1а	f	large
4136	25946	407	Республика Бурятия, Кяхтинский район, Кяхта, Советская, 5	f	large
4138	25948	409	Республика Бурятия, Кяхтинский район, Кяхта, Крупской, 42, Центральная межпоселенческая библиотека. 	f	large
4142	25952	413	Республика Бурятия, Кяхтинский район, Кяхта, Сухэ-Батора, 1	f	large
4139	25949	410	Республика Бурятия, Кяхтинский район, Кяхта, Пограничная, 69	f	large
4141	25951	412	Республика Бурятия, Кяхтинский район, Кяхта, Горнозелентуйская, 14	f	large
4144	25954	415	Республика Бурятия, Кяхтинский район, Кяхта, Гармаева, 53	f	large
4121	25931	392	Республика Бурятия, Кяхтинский район, село Курорт Киран, Озерная, клуб	f	small
4102	25912	373	Республика Бурятия, Кяхтинский район, село Кудара-Сомон, Ломоносова, 52	f	large
4123	25933	394	Республика Бурятия, Кяхтинский район, село Киран, Заречная, 17	t	small
4130	25940	401	Республика Бурятия, Кяхтинский район, село Калинишна, Трактовая, 17, кв. 1	t	small
4107	25917	378	Республика Бурятия, Кяхтинский район, село Ивановка, Луговая, клуб	t	small
4122	25932	393	Республика Бурятия, Кяхтинский район, село Дурены, Школьная, 17	t	small
4099	25909	370	Республика Бурятия, Кяхтинский район, село Дунгуй, Жарникова, 28	t	small
4120	25930	391	Республика Бурятия, Кяхтинский район, село Бурдуны, Центральная, клуб	t	small
4127	25937	398	Республика Бурятия, Кяхтинский район, село Большой Луг, Цыбиктарова, 47	t	medium
4113	25923	384	Республика Бурятия, Кяхтинский район, село Большая Кудара, Евдокимова, школа	t	medium
4101	25911	372	Республика Бурятия, Кяхтинский район, село Ара-Алцагат, Школьная, 27	f	small
4109	25919	380	Республика Бурятия, Кяхтинский район, село Анагустай, Заринская, 16	t	small
4302	26098	573	Республика Бурятия, Курумканский район, улус Харгана, Ленина, 12	f	medium
4093	25903	364	Республика Бурятия, Курумканский район, село Элэсун, Ленина, 61	t	small
4090	25900	361	Республика Бурятия, Курумканский район, село Шаманка, Рабочая, 42	t	small
4087	25897	358	Республика Бурятия, Курумканский район, село Хонхино, бр.Данжуровых, 26В	t	small
4092	25902	363	Республика Бурятия, Курумканский район, село Улюнхан, Ленина, 10	t	medium
4091	25901	362	Республика Бурятия, Курумканский район, село Сахули, Набережная, 10	t	small
4080	25890	351	Республика Бурятия, Курумканский район, село Могойто, Трактовая, 2	t	medium
4089	25899	360	Республика Бурятия, Курумканский район, село Майский, Ленина, 7	t	medium
4085	25895	356	Республика Бурятия, Курумканский район, село Курумкан, заимка Ехэ-Нуга	t	small
4083	25893	354	Республика Бурятия, Курумканский район, село Курумкан, Набережная, 13	t	small
4084	25894	355	Республика Бурятия, Курумканский район, село Курумкан, Балдакова, 45А	t	medium
4081	25891	352	Республика Бурятия, Курумканский район, село Курумкан, Балдакова, 13	t	large
4082	25892	353	Республика Бурятия, Курумканский район, поселок Курумкан, Ленина, 42а	t	large
4086	25896	357	Республика Бурятия, Курумканский район, село Барагхан (Саранхур), Ленина, 29	t	medium
4094	25904	365	Республика Бурятия, Курумканский район, село Арзгун (Разгон), Комсомольская, 5	t	medium
4079	25889	350	Республика Бурятия, Курумканский район, село Аргада, Здание библиотеки	t	small
4095	25905	366	Республика Бурятия, Курумканский район, село Аргада, Хышиктуева, 14	t	large
4078	25888	349	Республика Бурятия, Курумканский район, село Аргада, Верхняя Аргада, 1	t	small
4088	25898	359	Республика Бурятия, Курумканский район, село Алла, Ленина, 49, Дыренская СОШ	t	medium
3817	25629	88	Республика Бурятия, Джидинский район, село Армак, Центральная, 32	f	small
4069	25879	340	Республика Бурятия, Кижингинский район, улус Могсохон, Советская, 28	t	medium
4056	25868	327	Республика Бурятия, Кижингинский район, село Эдэрмэг, Школьная, 6	t	small
4071	25881	342	Республика Бурятия, Кижингинский район, село Чесан, Центральная	t	small
4074	25884	345	Республика Бурятия, Кижингинский район, село Хуртэй, Клубная, 15	t	medium
4058	25870	329	Республика Бурятия, Кижингинский район, село Ушхайта, Центральная, 30	t	small
4064	25874	335	Республика Бурятия, Кижингинский район, село Усть-Орот, Центральная улица, 27	f	small
4063	25873	334	Республика Бурятия, Кижингинский район, село Усть-Орот, Центральная, 25	t	small
4068	25878	339	Республика Бурятия, Кижингинский район, село Улзытэ, Советская, 20	t	small
4066	25876	337	Республика Бурятия, Кижингинский район, село Сулхара, Профсоюзная, 22	t	small
4055	25867	326	Республика Бурятия, Кижингинский район, село Новокижингинск, Строитетелей, 1	t	large
4054	25866	325	Республика Бурятия, Кижингинский район, село Новокижингинск, Мира, 58	t	small
4070	25880	341	Республика Бурятия, Кижингинский район, село Михайловка, Школьная, 34	t	small
4057	25869	328	Республика Бурятия, Кижингинский район, село Леоновка, Школьная, 2	t	small
4077	25887	348	Республика Бурятия, Кижингинский район, село Куорка, Номтоева, 4	t	small
4075	25885	346	Республика Бурятия, Кижингинский район, село Кулькисон, Раднаева, 50	t	small
4061	25803	332	Республика Бурятия, Кижингинский район, село Красный Яр, Школьная, 2	t	small
4065	25875	336	Республика Бурятия, Кижингинский район, село Кодунский Станок (Худанский Станок), Центральная , 21	t	small
4059	25871	330	Республика Бурятия, Кижингинский район, село Кижинга, проспект Ленина, 4	f	large
4076	25886	347	Республика Бурятия, Кижингинский район, село Кижинга, Советская, 149	f	large
4060	25872	331	Республика Бурятия, Кижингинский район, село Кижинга, Советская, 159	f	large
4067	25877	338	Республика Бурятия, Кижингинский район, село Иннокентьевка, Центральная, 6	t	small
4073	25883	344	Республика Бурятия, Кижингинский район, село Загустай, Дарижапова, 41	t	medium
4072	25882	343	Республика Бурятия, Кижингинский район, село Булак, Центральная, 21	t	small
4062	25858	333	Республика Бурятия, Кижингинский район, село Бахлайта, Рабочая, 8	t	small
4023	25834	294	Республика Бурятия, Кабанский район, село Шигаево, Советская, 43 А	f	small
3993	25804	264	Республика Бурятия, Кабанский район, село Шергино, Почтовая, 2	f	small
3984	25794	255	Республика Бурятия, Кабанский район, село Шерашово, 34-2	f	small
3994	25805	265	Республика Бурятия, Кабанский район, село Хандала, Братьев Мункоевых, 3	f	small
3995	25806	266	Республика Бурятия, Кабанский район, село Фофоново, Школьная, 18	f	small
3998	25809	269	Республика Бурятия, Кабанский район, село Тресково, Шашина, 51	f	large
4032	25843	303	Республика Бурятия, Кабанский район, село Тимлюй, Советская, 36	t	medium
4022	25833	293	Республика Бурятия, Кабанский район, село Творогово, Школьная, 17А	f	medium
3997	25808	268	Республика Бурятия, Кабанский район, село Таракановка, Терешковой, 12	t	small
4050	25862	321	Республика Бурятия, Кабанский район, поселок городского типа Танхой, Центральная, 13	t	small
4049	25861	320	Республика Бурятия, Кабанский район, поселок городского типа Танхой, Центральная, 55	f	small
3978	25788	249	Республика Бурятия, Кабанский район, село Сухая, Школьная, 6	f	small
4026	25837	297	Республика Бурятия, Кабанский район, село Степной Дворец, Трактовая, 23	f	small
4008	25819	279	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, мкр.Солнечный, 48	f	large
4006	25817	277	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, мкр. Березовый, 56	f	large
4005	25816	276	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, 51, мкр. Южный	f	large
4004	25815	275	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, 40, мкр. Южный	f	large
4007	25818	278	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, микрорайон Солнечный, 42	f	large
4003	25814	274	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, микрорайон Березовый, 55	f	large
4001	25812	272	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, микрорайон Березовый, 58	f	large
4000	25811	271	Республика Бурятия, Кабанский район, поселок городского типа Селенгинск, Мостовая, 24	f	small
3991	25801	262	Республика Бурятия, Кабанский район, село Романово, Братьев Голубевых, 54 А	t	small
4025	25836	296	Республика Бурятия, Кабанский район, село Ранжурово, Трактовая, 17 В	t	small
4039	25850	310	Республика Бурятия, Кабанский район, село Посольское, Набережная, 53	t	medium
4036	25847	307	Республика Бурятия, Кабанский район, село Посольская, Центральная, 11	f	medium
4048	25860	319	Республика Бурятия, Кабанский район, село Переемная, Табельная	t	small
3981	25791	252	Республика Бурятия, Кабанский район, село Оймур, Рабочая, 35 А	f	small
3982	25792	253	Республика Бурятия, Кабанский район, село Оймур, Октябрьская, 4	f	medium
4010	25821	281	Республика Бурятия, Кабанский район, село Нюки, Трактовая, 8 А	f	small
3979	25789	250	Республика Бурятия, Кабанский район, село Новый Энхэлук, Лесная, 8	f	small
3996	25807	267	Республика Бурятия, Кабанский район, село Никольск, Школьная, 17	f	small
4047	25859	318	Республика Бурятия, Кабанский район, село Мишиха, Табельная	t	small
4042	25853	313	Республика Бурятия, Кабанский район, село Мантуриха, Железнодорожная, 3	t	small
4021	25832	292	Республика Бурятия, Кабанский район, село Малое Колесово, Тупышева, 10 А	t	small
3986	25796	257	Республика Бурятия, Кабанский район, село Кудара, Нелюбина, 2 А	f	medium
3985	25795	256	Республика Бурятия, Кабанский район, село Кудара, Куйбышева, 1	f	small
3987	25797	258	Республика Бурятия, Кабанский район, село Кудара, Боброва, 2	f	small
3989	25799	260	Республика Бурятия, Кабанский район, село Красный Яр, Карачовых, 58	f	small
3988	25798	259	Россия, Республика Бурятия, Кабанский район, село Корсаково	f	medium
4046	25857	317	Республика Бурятия, Кабанский район, село Клюевка, Парижской Коммуны, 17	f	medium
4019	25830	290	Республика Бурятия, Кабанский район, село Каргино, Трактовая, 21	f	small
4031	25842	302	Республика Бурятия, Кабанский район, поселок городского типа Каменск, мкр. Молодежный, 18	f	large
4030	25841	301	Республика Бурятия, Кабанский район, поселок городского типа Каменск, Луговая, 2	f	large
4029	25840	300	Республика Бурятия, Кабанский район, поселок городского типа Каменск, Комсомольская, 17	f	large
4028	25839	299	Республика Бурятия, Кабанский район, Каменск, Прибайкальская, 3 Б	f	large
4018	25829	289	Россия, Республика Бурятия, Кабанский район, село Кабанск	f	small
4017	25828	288	Республика Бурятия, Кабанский район, село Кабанск, переулок Октябрьский, 83	f	medium
4013	25824	284	Республика Бурятия, Кабанский район, село Кабанск, Совхозная, 1	f	medium
4014	25825	285	Республика Бурятия, Кабанский район, село Кабанск, Маяковского, 1	f	medium
4016	25827	287	Республика Бурятия, Кабанский район, село Кабанск, 8 марта, 1	f	large
4015	25826	286	Республика Бурятия, Кабанский район, село Кабанск, 1 мая, 52	f	large
4027	25838	298	Республика Бурятия, Кабанский район, село Истомино, Лесная, 12 А	f	small
4040	25851	311	Республика Бурятия, Кабанский район, село Исток, Трактовая, 30	t	small
3977	25787	248	Республика Бурятия, Кабанский район, село Заречье, Речная, 19	f	small
4012	25823	283	Республика Бурятия, Кабанский район, село Закалтус, Клубная, 1А	f	small
3990	25800	261	Республика Бурятия, Кабанский район, село Жилино, Коневой Н.Е, 33 	t	small
4011	25822	282	Республика Бурятия, Кабанский район, село Елань, Клубная, 2 А	f	small
3980	25790	251	Республика Бурятия, Кабанский район, село Дулан, Центральная, 17 А	f	small
3983	25793	254	Республика Бурятия, Кабанский район, село Дубинино, Подгорная, 3 Б	f	small
4034	25845	305	Республика Бурятия, Кабанский район, село Горный, ФАП №11	t	small
4053	25865	324	Республика Бурятия, Кабанский район, село Выдрино, Школьная, 4 А	f	large
4052	25864	323	Республика Бурятия, Кабанский район, село Выдрино, Октябрьская, 1	f	large
4051	25863	322	Республика Бурятия, Кабанский район, село Выдрино, Красных Партизан, Сельский клуб	f	medium
3992	25802	263	Республика Бурятия, Кабанский район, село Быково, Трактовая, 94	f	small
3999	25810	270	Республика Бурятия, Кабанский район, село Брянск, Истомина, 94	f	medium
4041	25852	312	Республика Бурятия, Кабанский район, село Боярский, ЖД вокзал	t	small
4024	25835	295	Республика Бурятия, Кабанский район, село Борки, Молодежная, 36	t	small
4020	25831	291	Республика Бурятия, Кабанский район, село Большое Колесово, Ленина, 41 	f	medium
4035	25846	306	Республика Бурятия, Кабанский район, село Большая Речка, Вагжанова, 102	f	small
4009	25820	280	Республика Бурятия, Кабанский район, село Береговая, Селенгинская, 1 А	t	small
4038	25849	309	Республика Бурятия, Кабанский район, село Байкальский Прибой, Вокзальная, ЖД магазин	t	small
4044	25855	315	Республика Бурятия, Кабанский район, Бабушкин, Комсомольская, 19	f	large
4045	25856	316	Республика Бурятия, Кабанский район, Бабушкин, 3 Интернационала, 35	f	large
3972	25782	243	Республика Бурятия, Иволгинский район, село Хурамша, Ленина, 27, здание СДК	f	medium
3960	25772	231	Республика Бурятия, Иволгинский район, село Хойтобэе, Иркутский переулок, 8б, здание сельского клуба	f	large
3920	25731	191	Республика Бурятия, Иволгинский район, село Улус Оронгой, сельская школа	t	small
4110	25920	381	Республика Бурятия, Иволгинский район, село Улус Оронгой, Ранжурова, школа	t	small
3974	25784	245	Республика Бурятия, Иволгинский район, село Улус Оронгой, Абидуева, 56 а, здание ОСШ	f	large
3961	25773	232	Республика Бурятия, Иволгинский район, село Тапхар, 22, здание СДК	t	small
3958	25770	229	Республика Бурятия, Иволгинский район, село Сужа, Советская, 23, здание ОСШ	f	large
3955	25767	226	Республика Бурятия, Иволгинский район, село Сотниково, Трактовая, 18, здание средней школы	f	large
3954	25766	225	Республика Бурятия, Иволгинский район, село Сотниково, Партизанская, 27, здание сельского Дома культуры	f	large
4321	26118	592	Республика Бурятия, Иволгинский район, село Солонцы, Бабушкина, 38	f	medium
4324	26121	595	Республика Бурятия, Иволгинский район, село Саратовка, Ленина	f	small
3956	25768	227	Республика Бурятия, Иволгинский район, село Поселье, Советская, 37	f	medium
3953	25765	224	Республика Бурятия, Иволгинский район, село Ошурково, Школьная, здание начальной ОШ	t	small
3973	25783	244	Республика Бурятия, Иволгинский район, село Оронгой, Почтовая, 5, здание фельдшерского пункта	f	medium
3959	25771	230	Республика Бурятия, Иволгинский район, село Нижняя Иволга, Коммунистическая, 43	f	large
4322	26119	593	Республика Бурятия, Иволгинский район, село Нижний Саянтуй, Ленина, 35	f	large
3962	25774	233	Республика Бурятия, Иволгинский район, село Красноярово, Партизанская, 53, здание ОСШ	f	small
3967	25778	238	Республика Бурятия, Иволгинский район, село Колобки, Центральная, 6А, здание ООШ	t	small
3971	14609	242	Республика Бурятия, Иволгинский район, село Кокорино, здание СОШ	t	small
3968	25779	239	Республика Бурятия, Иволгинский район, село Ключи, здание СДК	f	small
3976	25786	247	Республика Бурятия, Иволгинский район, село Кибалино, Проточная, 25 а, здание ОСШ	t	small
3970	25781	241	Республика Бурятия, Иволгинский район, село Каленово, Школьная, 9, здание СОШ	f	medium
3966	25761	237	Республика Бурятия, Иволгинский район, село Иволгинск, квартал Студенческий, здание БРАТ	f	medium
3963	25775	234	Республика Бурятия, Иволгинский район, село Иволгинск, Первомайская, 22, здание Бурятмелиоводхоз	f	large
3965	25777	236	Республика Бурятия, Иволгинский район, село Иволгинск, Ленина, 32, здание РДК	f	large
3964	25776	235	Республика Бурятия, Иволгинский район, село Иволгинск, Ленина, 42, здание МОУ ДОД Иволгинский	f	large
3957	25769	228	Республика Бурятия, Иволгинский район, село Гурульба, Луговая, 26 а, здание ОСШ	f	large
3975	25785	246	Республика Бурятия, Иволгинский район, село Ганзурино, Набережная, 77, здание СОШ	f	small
4323	26120	594	Республика Бурятия, Иволгинский район, село Вознесеновка, Школьная, 9	f	small
3969	25780	240	Республика Бурятия, Иволгинский район, село Верхняя Иволга, Центральная, 17 а, здание СДК	f	medium
4325	26122	596	Республика Бурятия, Иволгинский район, село Верхний Саянтуй, Ленина, 73	t	small
3939	25750	210	Республика Бурятия, Закаменский район, сельское поселение Усть-Бургалтайское, здание МОУ Усть-Бургалтайская СОШ	f	small
3934	25745	205	Республика Бурятия, Закаменский район, сельское поселение Мылинское, здание МОУ Мылинская СОШ	t	small
3925	25736	196	Республика Бурятия, Закаменский район, село Шара-Азарга, здание МОУ Шара-Азаргинская СОШ	t	small
3931	25742	202	Республика Бурятия, Закаменский район, село Цакир, здание МОУ Цакирская СОШ	f	small
3932	25743	203	Республика Бурятия, Закаменский район, село Цаган-Морин, здание МОУ Цаган-Моринская СОШ	t	small
3938	25749	209	Республика Бурятия, Закаменский район, село Хуртага, здание МОУ Хуртагинская СОШ	f	small
3927	25738	198	Республика Бурятия, Закаменский район, село Хужир, здание МОУ ""Хужирская начальная школа-сад""	t	small
3943	25754	214	Республика Бурятия, Закаменский район, село Холтосон, здание МОУ Холтосонская СОШ	t	medium
3942	25753	213	Республика Бурятия, Закаменский район, село Харацай, здание МОУ Харацайская СОШ	t	small
3937	25748	208	Республика Бурятия, Закаменский район, село Хамней, здание МОУ Хамнейская СОШ	f	small
3922	25733	193	Республика Бурятия, Закаменский район, село Утата, здание МОУ Утатуйская СОШ	t	small
3929	25740	200	Республика Бурятия, Закаменский район, село Улентуй, здание МОУ Улентуйская СОШ	t	small
3941	25752	212	Республика Бурятия, Закаменский район, село Улекчин, здание МОУ Улекчинская СОШ	f	medium
3923	25734	194	Республика Бурятия, Закаменский район, село Санага, здание МОУ Санагинская СОШ	t	medium
3926	25737	197	Республика Бурятия, Закаменский район, село Нурта, здание МОУ Нуртинская СОШ	t	small
3940	25751	211	Республика Бурятия, Закаменский район, село Михайловка, здание МОУ Михайловская СОШ	f	medium
3951	25763	222	Республика Бурятия, Закаменский район, Закаменск, здание ГУ Центр занятости по Закаменскому району	f	medium
3950	25762	221	Республика Бурятия, Закаменский район, Закаменск, здание Закаменского филиала РГУ ветеринарии 	f	medium
3949	25760	220	Республика Бурятия, Закаменский район, Закаменск, здание МУК Межпоселенческая центральная библиотека	f	medium
3947	25758	218	Республика Бурятия, Закаменский район, город Закаменск, здание МУДОД Центр дополнительного образования	f	large
3946	25757	217	Республика Бурятия, Закаменский район, город Закаменск, Закаменская районная гимназия	f	large
3930	25741	201	Республика Бурятия, Закаменский район, село Ехэ-Цакир, здание МОУ Ехэ-Цакирская СОШ	f	small
3924	25735	195	Республика Бурятия, Закаменский район, село Енгорбой, здание МОУ Енгорбойская СОШ	t	small
3928	25739	199	Республика Бурятия, Закаменский район, село Дутулур, здание МОУ Дутулурская СОШ	f	medium
3921	25732	192	Республика Бурятия, Закаменский район, село Далахай, здание МОУ Дабатуйская СОШ	t	small
3936	25747	207	Республика Бурятия, Закаменский район, село Бургуй, здание МОУ Бургуйская СОШ	f	small
3933	25744	204	Республика Бурятия, Закаменский район, село Бортой, здание МОУ Бортойская СОШ	t	small
3935	25746	206	Республика Бурятия, Закаменский район, село Баянгол, здание МОУ Баянгольская СОШ	t	medium
3815	25627	86	Республика Бурятия, Заиграевский район, улус Хонхолой, Цыдыпова, 24	t	small
3909	25720	180	Республика Бурятия, Заиграевский район, село Эрхирик, Гагарина, 1, администрация	t	large
3892	25705	163	Республика Бурятия, Заиграевский район, село Шэнэ-Буса, Центральная, 24, школа	f	small
3905	25716	176	Республика Бурятия, Заиграевский район, село Шабур, Советская, 14 а, эдание администрации	t	medium
3898	25709	169	Республика Бурятия, Заиграевский район, село Челутай, 3-й км, переулок Связи, 1, дом культуры	t	medium
3896	25707	167	Республика Бурятия, Заиграевский район, село Челутай, Клубная, 3,  (дом культуры)	t	medium
3891	25704	162	Республика Бурятия, Заиграевский район, село Хара-Шибирь, сельский клуб	t	small
3902	25713	173	Республика Бурятия, Заиграевский район, село Хара-Кутул, Центральная, 13, сельский клуб	t	small
3887	25700	158	Республика Бурятия, Заиграевский район, село Усть-Брянь, Победы, 10, дом культуры	t	medium
3915	25726	186	Республика Бурятия, Заиграевский район, село Унэгэтэй, Школьная, 6	t	large
3886	25699	157	Россия, Республика Бурятия, Заиграевский район, село Тодогто	t	small
3899	25710	170	Республика Бурятия, Заиграевский район, село Ташелан, Ленина, 29	f	small
3897	25708	168	Республика Бурятия, Заиграевский район, село Татарский Ключ, Спортивная, 5, дом культуры	t	large
3910	25721	181	Республика Бурятия, Заиграевский район, село Старый Онохой, Клубная, 1, (дом культуры)	t	medium
3913	25724	184	Республика Бурятия, Заиграевский район, село Старая Курба, Школьная, 1, школа	t	small
3839	25652	110	Республика Бурятия, Джидинский район, село Белоозерск, Школьная, 49	f	medium
3903	25714	174	Республика Бурятия, Заиграевский район, село Старая Брянь, Центральная, 64 а,  (дом культуры)	t	small
3912	25723	183	Республика Бурятия, Заиграевский район, село Первомаевка, Школьная, 10, школа	t	medium
3877	25690	148	Республика Бурятия, Заиграевский район, село Онохой-Шибирь, Харза, 39	t	small
3882	25695	153	Республика Бурятия, Заиграевский район, поселок Онохой, Серова, 3	f	large
3885	25698	156	Республика Бурятия, Заиграевский район, поселок городского типа Онохой, Школьная, 33	f	large
3881	25694	152	Республика Бурятия, Заиграевский район, поселок городского типа Онохой, Серова, 11	f	large
3884	25697	155	Республика Бурятия, Заиграевский район, Онохой, Промышленная, 18, клуб	t	medium
3883	25696	154	Республика Бурятия, Заиграевский район, поселок городского типа Онохой, 40 Лет ЛПК, 11, автошкола	f	medium
3890	25703	161	Республика Бурятия, Заиграевский район, село Новоильинск, Полевая, 1, школа	f	large
3889	25702	160	Республика Бурятия, Заиграевский район, село Новоильинск, Ленина, 33, центр молодежи	f	large
3914	25725	185	Республика Бурятия, Заиграевский район, село Новая Курба, Советская, 3, дом культуры	t	small
3895	25675	166	Республика Бурятия, Заиграевский район, село Новая Брянь, Октябрьская, 1 , дом культуры	f	large
3894	25648	165	Республика Бурятия, Заиграевский район, село Новая Брянь, Октябрьская, 1, (дом культуры)	f	large
3888	25701	159	Республика Бурятия, Заиграевский район, село Нижние Тальцы, Новая, 12, дом культуры	f	medium
3911	25722	182	Республика Бурятия, Заиграевский район, село Нарын-Ацагат, Раднаева, 25, дом культуры	t	small
3901	25712	172	Республика Бурятия, Заиграевский район, село Нарын, Школьная, 12	t	small
3900	25711	171	Республика Бурятия, Заиграевский район, село Мухор-Тала, Афанасьева, 29	t	small
3908	25719	179	Республика Бурятия, Заиграевский район, село Кижа, Железнодорожная, 6 , вокзал	t	small
3893	25706	164	Республика Бурятия, Заиграевский район, село Илька, Трактовая, 6, дом культуры	f	large
3880	25693	151	Республика Бурятия, Заиграевский район, поселок городского типа Заиграево, пер.Молодежный, 2	f	medium
3879	25692	150	Республика Бурятия, Заиграевский район, поселок городского типа Заиграево, Ленина, 39, дом культуры	f	large
3878	25691	149	Республика Бурятия, Заиграевский район, поселок городского типа Заиграево, Ленина, 39, дом культуры	f	large
3919	25730	190	Республика Бурятия, Заиграевский район, село Добо-Ёнхор, сельская библиотека	t	small
3907	25718	178	Республика Бурятия, Заиграевский район, село Горхон, Лесная, 20, (ново-горхонская школа)	t	medium
3906	25717	177	Республика Бурятия, Заиграевский район, село Горхон, Железнодорожная, 22 , школа	t	large
3904	25715	175	Республика Бурятия, Заиграевский район, село Атхатай, Гаражная, 1, сельский клуб	t	small
3916	25727	187	Республика Бурятия, Заиграевский район, село Ангир, 24	t	small
3856	25669	127	Республика Бурятия, Еравнинский район, село Эгита, Гомбоева, 33, Эгитуйская СОШ	t	small
3870	25683	141	Республика Бурятия, Еравнинский район, село Ширинга, Школьная, 3	t	small
3876	25689	147	Республика Бурятия, Еравнинский район, поселок Целинный, переулок Школьный, 3	t	small
3872	25685	143	Республика Бурятия, Еравнинский район, село Хорга, Бадмаева, 11, Сельский клуб	t	small
3854	25667	125	Республика Бурятия, Еравнинский район, село Хангир, Хангирская, б/н	t	small
3853	25666	124	Республика Бурятия, Еравнинский район, село Усть-Эгита, Дамдинова, 15, сельский дом культуры	t	medium
3851	25664	122	Республика Бурятия, Еравнинский район, село Ульдурга, Ленина, 46	t	medium
3858	25671	129	Республика Бурятия, Еравнинский район, село Улзытэ (Занультуй), Центральная, Сельский клуб с.Улзытэ	t	small
3861	25674	132	Республика Бурятия, Еравнинский район, село Укыр, Центральная, 14\\1	t	small
3869	25682	140	Республика Бурятия, Еравнинский район, село Тулдун, Ленина, 16, Дом культуры	t	small
3852	25665	123	Республика Бурятия, Еравнинский район, село Тужинка, Почтовая, 4	t	small
3875	25688	146	Республика Бурятия, Еравнинский район, село Телемба, Ланцева, 11, Телембинская СОШ	t	medium
3864	25678	135	Россия, Республика Бурятия, Еравнинский район, село Сосново-Озерское	f	medium
3865	25677	136	Республика Бурятия, Еравнинский район, село Сосново-Озерское, Перовмайская, 115, Районный дом культуры	f	medium
3863	25677	134	Республика Бурятия, Еравнинский район, село Сосново-Озерское, Перовмайская, 115, Районный дом культуры	f	medium
3866	25679	137	Республика Бурятия, Еравнинский район, село Сосново-Озерское, Первомайская, 115	f	medium
3867	25680	138	Республика Бурятия, Еравнинский район, село Сосново-Озерское, Заречная, 8	f	medium
3772	25585	43	Республика Бурятия, Еравнинский район, село Романовка, Первомайская, 2	t	medium
3855	25668	126	Республика Бурятия, Еравнинский район, село Поперечное, Школьная, 3	t	small
3873	25686	144	Республика Бурятия, Еравнинский район, село Озерный, Комсомольская, 1, Озерниная СОШ	t	small
3857	25670	128	Республика Бурятия, Еравнинский район, село Можайка, Цырендылыкова, 28, Дом культуры	t	medium
3859	25672	130	Республика Бурятия, Еравнинский район, село Комсомольское, Советская, 22, Дом культуры	t	small
3874	25687	145	Республика Бурятия, Еравнинский район, село Исинга, Клубная, 2	t	medium
3868	25681	139	Республика Бурятия, Еравнинский район, село Домна, Сампилова, 11	t	small
3871	25684	142	Республика Бурятия, Еравнинский район, село Гунда, Ленина, Дом культуры	t	medium
3860	25673	131	Республика Бурятия, Еравнинский район, село Гонда, Школьная, 8, Дом культуры	t	small
3862	25676	133	Республика Бурятия, Еравнинский район, село Гарам, Орлова, 12, Дом культуры	t	small
3819	25631	90	Россия, Республика Бурятия, Джидинский район, село Шартыкей	f	small
3838	25651	109	Республика Бурятия, Джидинский район, село Цагатуй, Шарапова, 5	t	small
3848	25661	119	Республика Бурятия, Джидинский район, село Цаган-Усун, Набережная, 15	t	small
3821	25633	92	Республика Бурятия, Джидинский район, село Хулдат, Центральная, 74	t	small
3843	25656	114	Республика Бурятия, Джидинский район, село Хужир, Ульянова, 45	t	small
4200	25999	471	Республика Бурятия, Джидинский район, село Хужир, Патархеева, 42	t	small
3825	25637	96	Республика Бурятия, Джидинский район, село Улзар, Центральная, 8	t	small
3827	25639	98	Республика Бурятия, Джидинский район, село Тэнгэрэк, Ленина, 2, сельский Мельница	t	small
3840	25653	111	Республика Бурятия, Джидинский район, село Тасархай, Советская, 52	t	small
3824	25636	95	Республика Бурятия, Джидинский район, село Старый Укырчелон, Советская, 98	t	small
3834	25646	105	Республика Бурятия, Джидинский район, село Петропавловка, Терешковой, 9	f	large
3835	25647	106	Республика Бурятия, Джидинский район, село Петропавловка, Свердлова, 52	f	large
3833	25645	104	Республика Бурятия, Джидинский район, село Петропавловка, Свердлова, 49	f	large
3832	25644	103	Республика Бурятия, Джидинский район, село Петропавловка, Балтахинова, 45	f	large
3822	25634	93	Республика Бурятия, Джидинский район, село Оёр, Центральная, 98	f	small
3841	25654	112	Республика Бурятия, Джидинский район, село Нюгуй, Школьная, 12	t	small
3820	25632	91	Республика Бурятия, Джидинский район, село Нижний Торей, А-Мельникова, 54	f	medium
3826	25638	97	Республика Бурятия, Джидинский район, село Нижний Бургалтай, Яковлева, 2	f	small
3818	25630	89	Республика Бурятия, Джидинский район, село Нарын, Центральная, 65	f	small
3830	25642	101	Республика Бурятия, Джидинский район, село Нарын, Вампилова, 10	t	small
3850	25663	121	Республика Бурятия, Джидинский район, село Инзагатуй, Школьная, 11	t	small
3846	25659	117	Республика Бурятия, Джидинский район, село Енхор, Ленина, 11	t	small
3837	25650	108	Республика Бурятия, Джидинский район, село Дэдэ-Ичетуй, Ленина, 35	t	medium
3842	25655	113	Республика Бурятия, Джидинский район, село Дырестуй, Ленина, 48	f	medium
3836	25649	107	Республика Бурятия, Джидинский район, село Додо-Ичетуй, Центральная, 8	t	small
3845	25658	116	Республика Бурятия, Джидинский район, поселок городского типа Джида, Торговая, 20б	f	large
3844	25657	115	Республика Бурятия, Джидинский район, поселок городского типа Джида, Торговая, 16	f	large
3829	25641	100	Республика Бурятия, Джидинский район, село Гэгэтуй, Ч.Раднаева, 5	f	medium
3823	25635	94	Республика Бурятия, Джидинский район, село Верхний Торей, Гармаева, 44	t	small
3828	25640	99	Республика Бурятия, Джидинский район, село Верхний Бургалтай, Набережная, 20	t	small
3831	25643	102	Республика Бурятия, Джидинский район, село Булык, переулок Клубный, 47	f	small
3847	25660	118	Республика Бурятия, Джидинский район, село Боций, Ленина, 40	t	small
3816	25628	87	Республика Бурятия, Джидинский район, село Алцак, Центральная, 6	t	small
3811	25623	82	Республика Бурятия, Бичурский район, село Шибертуй, Елаева, 1	t	medium
3813	25625	84	Республика Бурятия, Бичурский район, село Шанага, Токтохоева, 23	t	small
3791	25604	62	Республика Бурятия, Бичурский район, село Хаян, Центральная, 7	t	small
3810	25622	81	Республика Бурятия, Бичурский район, село Узкий Луг, Ленина, 52	t	small
3795	25608	66	Республика Бурятия, Бичурский район, село Топка, Смородникова, 1	t	small
3787	25600	58	Республика Бурятия, Бичурский район, село Сухой Ручей, Комсомольская, 1	t	small
3793	25606	64	Республика Бурятия, Бичурский район, село Старые Ключи, Заречная, 15	f	small
3794	25607	65	Республика Бурятия, Бичурский район, село Средний Харлун, Центральная, 4	t	small
3808	25620	79	Республика Бурятия, Бичурский район, село Слобода, Гагарина, 2	t	small
3782	25595	53	Республика Бурятия, Бичурский район, село Сахарный Завод, Набережная, 4	f	medium
3814	25626	85	Республика Бурятия, Бичурский район, село Потанино, Центральная, 1	t	medium
3807	25568	78	Республика Бурятия, Бичурский район, село Поселье, Ленина, 47	t	small
4227	26023	498	Республика Бурятия, Бичурский район, село Покровка, Первомайская, 28	t	small
3800	25613	71	Республика Бурятия, Бичурский район, село Петропавловка, Гагарина, 38а	t	medium
3792	25605	63	Республика Бурятия, Бичурский район, село Окино-Ключи, Центральная, 16	f	medium
3802	25615	73	Республика Бурятия, Бичурский район, село Новосретенка, Иванова, 139	t	small
3799	25612	70	Республика Бурятия, Бичурский район, село Нижний Мангиртуй, Лесная, 47	t	small
3803	25616	74	Республика Бурятия, Бичурский район, село Мотня, Новая, 57	t	small
3805	25618	76	Республика Бурятия, Бичурский район, село Малый Куналей, Школьная, 2	t	small
3806	25619	77	Республика Бурятия, Бичурский район, село Малый Куналей, Советская, 12	t	large
3790	25603	61	Республика Бурятия, Бичурский район, село Елань, Логовского, 84	t	medium
3788	25601	59	Республика Бурятия, Бичурский район, село Дунда-Киреть, Центральная, 31	t	small
3812	25624	83	Республика Бурятия, Бичурский район, село Дабатуй, Школьная, 7	t	small
3804	25617	75	Республика Бурятия, Бичурский район, село Гутай, Центральная, 26	t	small
3798	25611	69	Республика Бурятия, Бичурский район, село Верхний Мангиртуй, Дружбы, 1а	t	small
3809	25621	80	Республика Бурятия, Бичурский район, село Буй, Трактовая, 25	t	small
3780	25593	51	Республика Бурятия, Бичурский район, село Бичура, Соломенникова, 35	f	large
3784	25597	55	Республика Бурятия, Бичурский район, село Бичура, Советская, 7а	f	large
3778	25591	49	Республика Бурятия, Бичурский район, село Бичура, Советская, 45	f	large
3785	25598	56	Республика Бурятия, Бичурский район, село Бичура, Рабочая, 27	f	large
3779	25592	50	Республика Бурятия, Бичурский район, село Бичура, Краснопартизанская, 60	f	medium
3786	25599	57	Республика Бурятия, Бичурский район, село Бичура, Коммунинстическая, 341	f	medium
3783	25596	54	Республика Бурятия, Бичурский район, село Бичура, Кирова, 38	f	medium
3781	25594	52	Республика Бурятия, Бичурский район, село Бичура, Калинина, 150	f	medium
3797	25610	68	Республика Бурятия, Бичурский район, село Билютай, Молодежная, 11	t	small
3789	25602	60	Республика Бурятия, Бичурский район, село Ара-Киреть, Назимова, 44	t	small
3776	25589	47	Республика Бурятия, Баунтовский район, село Ципикан, Центральная, 9, здание администрации	t	small
3774	25587	45	Республика Бурятия, Баунтовский район, село Усть-Джилинда, Северная, 19, В помещении школы	t	small
3777	25590	48	Республика Бурятия, Баунтовский район, село Уакит, Советская, 4, В помещении школы	t	small
3769	25582	40	Республика Бурятия, Баунтовский район, село Северный, Геологическая, 15	t	small
3771	25584	42	Республика Бурятия, Баунтовский район, село Россошино, Центральная, 1, В помещении администрации сельского поселения Усойское	t	small
3770	25583	41	Республика Бурятия, Баунтовский район, село Монгой, Школьная, 1, В помещении школы	t	small
3768	25581	39	Республика Бурятия, Баунтовский район, село Маловский, Центральная, 14	t	large
3775	25588	46	Республика Бурятия, Баунтовский район, село Варваринский, Красноармейская, 37, здание школы	t	small
3766	25580	37	Республика Бурятия, Баунтовский район, село Багдарин, Ленина, 45	f	large
3767	25527	38	Республика Бурятия, Баунтовский район, село Багдарин, Ленина, 103а	t	large
4183	25983	454	Республика Бурятия, Баргузинский район, у.Хошун-Узур, Кооперативная, 13	f	small
3763	25577	34	Республика Бурятия, Баргузинский район, село Ярикто, Центральная, 11	t	small
3755	25569	26	Республика Бурятия, Баргузинский район, поселок Юбилейный, Калинина, 7А	t	medium
3736	25549	7	Республика Бурятия, Баргузинский район, Шапеньково, Лесная, 16Б	t	small
3748	25561	19	Республика Бурятия, Баргузинский район, село Читкан, Профсоюзная, 32	t	medium
3764	25578	35	Республика Бурятия, Баргузинский район, село Хилгана, Очирова, 2А	t	medium
3760	25574	31	Республика Бурятия, Баргузинский район, село Хара-Усун, Центральная, 6	t	small
3737	25550	8	Республика Бурятия, Баргузинский район, поселок городского типа Усть-Баргузин, Щербакова, 9	f	large
3743	25556	14	Республика Бурятия, Баргузинский район, поселок городского типа Усть-Баргузин, Производственная, 6	f	medium
3740	25553	11	Республика Бурятия, Баргузинский район, поселок городского типа Усть-Баргузин, Оцимика, 24	f	large
3742	25555	13	Республика Бурятия, Баргузинский район, поселок городского типа Усть-Баргузин, Ленина, 24	f	large
3739	25552	10	Республика Бурятия, Баргузинский район, поселок городского типа Усть-Баргузин, Ватутина, 43	f	large
3749	25562	20	Республика Бурятия, Баргузинский район, село Уро, переулок Школьный, 2	t	small
3751	25564	22	Республика Бурятия, Баргузинский район, село Уро, Советская, 2	f	small
3758	25572	29	Республика Бурятия, Баргузинский район, село Уржил, Караликская, 1	t	small
3761	25575	32	Республика Бурятия, Баргузинский район, село Улюн, Очирова, 23	t	medium
3762	25576	33	Республика Бурятия, Баргузинский район, село Улюкчикан, Цыденжапова, 16	t	small
3753	25566	24	Республика Бурятия, Баргузинский район, село Суво, Кабашова, 5	t	small
3759	25573	30	Республика Бурятия, Баргузинский район, село Соёл, Колхозная, 20	t	small
3734	25547	5	Республика Бурятия, Баргузинский район, село Нестериха, Школьная, 18	t	small
3750	25563	21	Республика Бурятия, Баргузинский район, село Малое Уро, Комсомольская, 36	t	small
3741	25554	12	Республика Бурятия, Баргузинский район, село Максимиха, Клубная, 19	f	small
3745	25558	16	Республика Бурятия, Баргузинский район, село Макаринино (Башарово), Набережная, 41	t	small
3744	25557	15	Республика Бурятия, Баргузинский район, село Курбулик (Покойники), Нагорная, 2	t	small
3756	25570	27	Республика Бурятия, Баргузинский район, село Ина, Центральная, 3	t	small
3747	25560	18	Республика Бурятия, Баргузинский район, село Зорино, Набережная, 18	t	small
3752	25565	23	Республика Бурятия, Баргузинский район, село Душелан, Бр.Чирковых, 2	t	small
3738	25551	9	Республика Бурятия, Баргузинский район, село Гусиха, Баргузинская, 24	t	small
3765	25579	36	Республика Бурятия, Баргузинский район, село Борогол, Энгельса, 30	t	small
3754	25567	25	Республика Бурятия, Баргузинский район, село Бодон, Ленина, 19	t	small
3757	25571	28	Республика Бурятия, Баргузинский район, село Баянгол (Чебукчен), Ленина, 69	t	large
3735	25548	6	Республика Бурятия, Баргузинский район, поселок городского типа Баргузин, м-н Старый Аэропорт, Административное здание метеостанции	f	small
3733	25546	4	Республика Бурятия, Баргузинский район, Баргузин, Очирова, Административное здание ООО 	f	medium
3731	25544	2	Республика Бурятия, Баргузинский район, поселок городского типа Баргузин, Калинина, 51а	f	large
3730	25543	1	Республика Бурятия, Баргузинский район, поселок городского типа Баргузин, Дзержинского, 19	f	large
3732	25545	3	Республика Бурятия, Баргузинский район, поселок городского типа Баргузин, Братьев Козулиных, 19	f	medium
3746	25559	17	Республика Бурятия, Баргузинский район, село Адамово, Советская, 40	f	small
4576	15070	13	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 32	f	large
4575	15069	12	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 14	f	large
4572	15066	9	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 50	f	large
4571	15065	8	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 70	f	large
4570	15064	7	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 63	f	large
58795	66491	454	Омская область, Омск, Декабристов, 121	f	large
4568	15062	5	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 93	f	large
4567	15061	4	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 154	f	large
4565	15059	2	Республика Алтай, Горно-Алтайск, проспект Коммунистический, 121	f	large
4574	15068	11	Республика Алтай, Горно-Алтайск, Чорос-Гуркина, 14	f	large
4573	15067	10	Республика Алтай, Горно-Алтайск, Чорос-Гуркина, 42	f	large
4581	15075	18	Республика Алтай, Горно-Алтайск, Социалистическая, 5	f	large
4579	15073	16	Республика Алтай, Горно-Алтайск, Социалистическая, 21	f	large
4569	15063	6	Республика Алтай, Горно-Алтайск, П.Сухова, 2	f	large
4577	15071	14	Республика Алтай, Горно-Алтайск, П.Кучияк, 61	f	large
4583	15077	20	Республика Алтай, Горно-Алтайск, Льва Толстого, 72	f	large
4578	15072	15	Республика Алтай, Горно-Алтайск, Ленкина, 1	f	large
4582	15076	19	Республика Алтай, Горно-Алтайск, Ленина, 79	f	large
4585	14850	22	Республика Алтай, Горно-Алтайск, Ленина, 11	f	large
4584	14756	21	Республика Алтай, Горно-Алтайск, Ленина, 195	f	large
4564	15058	1	Республика Алтай, Горно-Алтайск, Заводская, 3	f	large
4566	14749	3	Республика Алтай, Горно-Алтайск, Больничная, 13	f	large
4580	15074	17	Республика Алтай, Горно-Алтайск, Барнаульская, 8	f	large
109227	94873	225	Республика Алтай, Шебалинский район, поселок Шыргайту, Песчаная, 28	t	\N
4797	94889	236	Республика Алтай, Шебалинский район, поселок Шебалино, Советская, 11А	f	large
4796	94889	235	Республика Алтай, Шебалинский район, поселок Шебалино, Советская, 11А	f	large
4792	15250	231	Республика Алтай, Шебалинский район, поселок Черга, Октябрьская, 122	f	large
4791	15249	230	Республика Алтай, Шебалинский район, поселок Улусчерга, Советская, 44	t	small
4801	94890	239	Республика Алтай, Шебалинский район, поселок Топучая, Центральная, 32	t	small
4798	15258	237	Республика Алтай, Шебалинский район, поселок Мыюта, Трактовая, 8Г	f	small
4790	15248	229	Республика Алтай, Шебалинский район, поселок Мухор-Черга, Заречная, 13	t	small
4789	15247	228	Республика Алтай, Шебалинский район, поселок Мариинск, Центральная, 14	t	small
4803	15264	241	Республика Алтай, Шебалинский район, поселок Малая Черга, Школьная, 6	t	small
109231	94874	240	Республика Алтай, Шебалинский район, поселок Кумалыр, Центральная, 38	t	\N
4783	94888	222	Республика Алтай, Шебалинский район, поселок Каспа, Телесова, 44	t	small
109228	15252	232	Республика Алтай, Шебалинский район, поселок Камлак, Центральная, 71А	f	\N
4795	15255	234	Республика Алтай, Шебалинский район, поселок Камай, Центральная, 5	t	small
4788	15246	227	Республика Алтай, Шебалинский район, поселок Ильинка, Центральная, 65	t	medium
109230	15260	238	Республика Алтай, Шебалинский район, поселок Дьектиек, Школьная, 4	f	\N
4804	15265	242	Республика Алтай, Шебалинский район, поселок Верх-Черга, Центральная, 18	t	small
4784	15240	223	Республика Алтай, Шебалинский район, поселок Верх-Апшуяхта, Центральная, 45	t	small
109226	15242	224	Республика Алтай, Шебалинский район, поселок Беш-Озек, Центральная, 20	f	\N
4787	15245	226	Республика Алтай, Шебалинский район, поселок Барагаш, Партизанская, 1	t	medium
109229	15254	233	Республика Алтай, Шебалинский район, поселок Актел, Молодежная, 1В	t	\N
109225	15229	212	Республика Алтай, Чойский район, поселок Ынырга, Тихоновского, 8	f	\N
4774	15227	211	Республика Алтай, Чойский район, поселок Ынырга, Тихоновского, 8	f	small
4768	15223	207	Республика Алтай, Чойский район, поселок Чоя, Социалистическая, 28	f	medium
4769	15224	208	Республика Алтай, Чойский район, поселок Чоя, Ленина, 38	f	medium
4772	15230	213	Республика Алтай, Чойский район, поселок Ускуч (Верх-Пьянково), Заречная, 1	t	small
4777	15231	214	Республика Алтай, Чойский район, поселок Уймень, Центральная, 6	t	small
4780	15234	217	Республика Алтай, Чойский район, поселок Туньжа, Центральная, 22	t	small
4771	15226	210	Республика Алтай, Чойский район, поселок Советское, Совхозная, 10	t	small
4773	15236	219	Республика Алтай, Чойский район, поселок Сейка, Школьная, 37	f	medium
4781	15235	218	Республика Алтай, Чойский район, поселок Сейка, Школьная, 37а	f	medium
4779	15233	216	Республика Алтай, Чойский район, поселок Паспаул, Трактовая, 36	f	small
4778	15232	215	Республика Алтай, Чойский район, поселок Паспаул, Трактовая, 36	f	medium
58789	66487	448	Омская область, Омск, Декабристов, 178	f	large
4770	15225	209	Республика Алтай, Чойский район, поселок Киска, Дружная, 1	f	small
4782	15238	221	Республика Алтай, Чойский район, поселок Каракокша, Тартыкова, 32	f	small
4775	15237	220	Республика Алтай, Чойский район, поселок Каракокша, Тартыкова, 32	f	medium
109224	15222	206	Республика Алтай, Чойский район, поселок Гусевка, Зеленая, 9	f	\N
4756	94887	193	Республика Алтай, Чемальский район, поселок Элекмонар, Советская, 1	f	small
4758	15216	195	Республика Алтай, Чемальский район, поселок Элекмонар, Советская, 142	f	medium
4757	15215	194	Республика Алтай, Чемальский район, поселок Элекмонар, Советская, 35	f	small
4747	15207	184	Республика Алтай, Чемальский район, поселок Эдиган, Центральная, 10	t	small
4765	94886	202	Республика Алтай, Чемальский район, поселок Чепош, Кучияк, 29	f	medium
4753	15213	190	Республика Алтай, Чемальский район, поселок Чемал, Советская, 48	f	small
4754	15212	191	Республика Алтай, Чемальский район, поселок Чемал, Советская, 3	f	medium
4752	15212	189	Республика Алтай, Чемальский район, поселок Чемал, Советская, 3	f	small
4755	15214	192	Республика Алтай, Чемальский район, поселок Чемал, Пчелкина, 4	f	medium
4751	15211	188	Республика Алтай, Чемальский район, поселок Чемал, Пчелкина, 89	f	small
4750	15210	187	Республика Алтай, Чемальский район, поселок Чемал, Курортная, 1	f	small
109222	15192	203	Республика Алтай, Чемальский район, поселок Усть-Сема, Зеленая, 2	f	\N
4761	15219	198	Республика Алтай, Чемальский район, поселок Узнезя, Новые Черемушки, 13	f	small
4763	15221	200	Республика Алтай, Чемальский район, поселок Турбаза Катунь, Сосновая, 5	f	small
4749	15209	186	Республика Алтай, Чемальский район, поселок Толгоек, Энергетиков, 4	t	small
4746	14687	205	Республика Алтай, Чемальский район, поселок Ороктой, Центральная, 17	t	small
109223	15203	204	Республика Алтай, Чемальский район, поселок Куюс, Центральная, 17	t	\N
4748	15208	185	Республика Алтай, Чемальский район, поселок Еланда, Катунская, 30	t	small
4764	94885	201	Республика Алтай, Чемальский район, поселок Бешпельтир, Центральная, 31	f	small
4759	15217	196	Республика Алтай, Чемальский район, поселок Аюла, Центральная, 17	f	small
4762	15220	199	Республика Алтай, Чемальский район, поселок Аскат, Озерная, 20	f	small
4760	15218	197	Республика Алтай, Чемальский район, поселок Анос, Центральная, 51	f	small
4740	15199	177	Республика Алтай, Усть-Коксинский район, поселок Чендек, медпункт	t	small
4805	15206	183	Республика Алтай, Усть-Коксинский район, поселок Чендек, Центральная, 6, кв 2	t	small
4739	15198	176	Республика Алтай, Усть-Коксинский район, поселок Чендек, Центральная, 48	t	small
4720	15176	157	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, переулок Школьный, 8	f	medium
4728	15186	165	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Школьная, 8	f	small
4741	15200	178	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Центральная, 15	f	medium
4735	15194	172	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Центральная, 28	t	medium
4727	15185	164	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Центральная, 23	t	small
4722	15178	159	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Центральная, 3	t	small
4724	15182	161	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Харитошкина, 5	f	large
4742	15201	179	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Советская, 130	t	medium
4723	15179	160	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Набережная, 3	f	medium
4725	15183	162	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Клубный переулок, 6/2	t	small
4715	15205	182	Республика Алтай, Усть-Коксинский район, поселок Усть-Кокса, Заря Алтая, 1	f	small
4733	15191	170	Республика Алтай, Усть-Коксинский район, поселок Тихонькая, Центральная, 11	t	small
4716	15172	153	Республика Алтай, Усть-Коксинский район, поселок Талда, Центральная, 20	f	small
4731	15189	168	Республика Алтай, Усть-Коксинский район, поселок Огневка, Скосырева, 2а	f	small
4729	15187	166	Республика Алтай, Усть-Коксинский район, поселок Огневка, Садовая, 27	f	small
4730	15188	167	Республика Алтай, Усть-Коксинский район, поселок Огневка, Новая, 9	f	small
4743	15202	180	Республика Алтай, Усть-Коксинский район, поселок Катанда, Сухова, 45	t	small
4744	15204	181	Республика Алтай, Усть-Коксинский район, поселок Катанда, Ленина, 46	t	small
4726	15184	163	Республика Алтай, Усть-Коксинский район, поселок Кастахта, Заречная, 2	t	small
4717	15173	154	Республика Алтай, Усть-Коксинский район, поселок Карагай, Школьная, 30	t	small
4718	15174	155	Республика Алтай, Усть-Коксинский район, поселок Карагай, Зеленая, 1	t	small
4738	15197	175	Республика Алтай, Усть-Коксинский район, поселок Горбуново, Центральная, 39	t	small
4736	15195	173	Республика Алтай, Усть-Коксинский район, поселок Горбуново, Центральная, 1	t	small
4737	15196	174	Республика Алтай, Усть-Коксинский район, поселок Горбуново, Первомайская, 4	t	small
4734	15193	171	Республика Алтай, Усть-Коксинский район, поселок Верх-Уймон, Школьная, 11	t	small
4732	15190	169	Республика Алтай, Усть-Коксинский район, поселок Верх-Уймон, Центральная, 5	t	small
4721	15177	158	Республика Алтай, Усть-Коксинский район, поселок Амур, переулок Новый, 9	t	small
4719	15175	156	Республика Алтай, Усть-Коксинский район, поселок Амур, Советская, 45	f	small
4706	15162	143	Республика Алтай, Усть-Канский район, поселок Яконур, Кудачина, 28	f	large
4703	15159	140	Республика Алтай, Усть-Канский район, поселок Ябоган, Ленинская, 18	f	medium
4710	15166	147	Республика Алтай, Усть-Канский район, поселок Черный Ануй, Центральная, 7	t	small
4708	15164	145	Республика Алтай, Усть-Канский район, поселок Усть-Мута, Центральная, 46	t	small
4693	15149	130	Республика Алтай, Усть-Канский район, поселок Усть-Кумир, Зеленая, 27	t	small
4700	15156	137	Республика Алтай, Усть-Канский район, поселок Усть-Кан, Первомайская, 1	f	large
4696	15152	133	Республика Алтай, Усть-Канский район, поселок Тюдрала, Мира, 34	t	small
4712	15168	149	Республика Алтай, Усть-Канский район, поселок Турата, Елеусова, 22	t	small
4695	15151	132	Республика Алтай, Усть-Канский район, поселок Талица, Партизанская, 12	t	small
4694	15150	131	Республика Алтай, Усть-Канский район, поселок Санаровка, Волонковская, 17	t	small
109221	15161	142	Республика Алтай, Усть-Канский район, поселок Оро, Школьная, 2	f	\N
4701	15157	138	Республика Алтай, Усть-Канский район, поселок Мендур-Соккон, Казакова, 23	t	small
4702	15158	139	Республика Алтай, Усть-Канский район, поселок Кырлык, Победы, 147	f	medium
4691	15171	152	Республика Алтай, Усть-Канский район, поселок Коргон, Набережная, 18	t	small
4698	15154	135	Республика Алтай, Усть-Канский район, поселок Козуль, Молодежная, 18	t	small
4707	15163	144	Республика Алтай, Усть-Канский район, поселок Келей, Тан-Чолмон, 62	t	small
4697	15153	134	Республика Алтай, Усть-Канский район, поселок Кайсын, Центральная, 3	t	small
4692	15148	129	Республика Алтай, Усть-Канский район, поселок Владимировка, Центральная, 33	t	small
4704	15160	141	Республика Алтай, Усть-Канский район, поселок Верх-Ябоган, Нагорная, 1	t	small
4709	15165	146	Республика Алтай, Усть-Канский район, поселок Верх-Мута, Чапаева, 10	t	small
4714	15170	151	Республика Алтай, Усть-Канский район, поселок Верх-Ануй, Ануйская, 63	t	small
4713	15169	150	Республика Алтай, Усть-Канский район, поселок Белый Ануй, Советская, 64	t	medium
109212	15130	120	Республика Алтай, Улаганский район, поселок Язула, Набережная, 1	t	\N
109218	15143	126	Республика Алтай, Улаганский район, поселок Чибит, Кокышева, 10	t	\N
109220	15147	128	Республика Алтай, Улаганский район, поселок Чибиля, Набережная, 38	f	\N
109219	15144	127	Республика Алтай, Улаганский район, поселок Улаган, А.В.Санаа, 18	f	\N
109211	15128	119	Республика Алтай, Улаганский район, поселок Саратан, Школьная 13	f	\N
109214	15135	122	Республика Алтай, Улаганский район, поселок Паспарта, Куюкова, 62	t	\N
109216	15139	124	Республика Алтай, Улаганский район, поселок Коо, Южная, 12	t	\N
109210	15126	118	Республика Алтай, Улаганский район, поселок Кара-Кудюр, Набережная, 4	f	\N
109215	15136	123	Республика Алтай, Улаганский район, поселок Балыкча, Центральная, 20	t	\N
109213	15132	121	Республика Алтай, Улаганский район, поселок Балыктуюль, Центральная, 91	f	\N
109217	15141	125	Республика Алтай, Улаганский район, поселок Акташ, Ст.Мохова, 21	f	\N
4669	14737	106	Республика Алтай, Турочакский район, поселок Яйлю, Школьная, 10	t	small
4673	15118	110	Республика Алтай, Турочакский район, поселок Чуйка, школа	t	small
4668	14724	105	Республика Алтай, Турочакский район, поселок Усть-Пыжа, Центральная, 43	t	small
4659	15125	117	Республика Алтай, Турочакский район, поселок Удаловка, Береговая, 14	t	small
4661	14758	98	Республика Алтай, Турочакский район, поселок Турочак, Советская, 75	f	large
4660	14757	97	Республика Алтай, Турочакский район, поселок Турочак, Советская, 75	f	large
4667	14723	104	Республика Алтай, Турочакский район, поселок Тулой, Строительная, 1	t	small
4664	14872	101	Республика Алтай, Турочакский район, поселок Тондошка, Береговая, 18	t	small
109209	15120	112	Республика Алтай, Турочакский район, поселок Суранаш, ФАП	t	\N
4663	14763	100	Республика Алтай, Турочакский район, поселок Санькин-Аил, Рудничный район, Боровая, 4	t	small
4679	15123	115	Республика Алтай, Турочакский район, поселок Озеро-Куреево, Центральная, 20	t	small
4676	15121	113	Республика Алтай, Турочакский район, поселок Майск, Центральная, 3Б	t	small
4674	15119	111	Республика Алтай, Турочакский район, поселок Курмач-Байгол, школа	t	small
4666	14722	103	Республика Алтай, Турочакский район, поселок Кебезень, Центральная, 34	t	small
4662	14760	99	Республика Алтай, Турочакский район, поселок Каяшкан, Центральная, 33	t	small
4678	15122	114	Республика Алтай, Турочакский район, поселок Каначак, Береговая, 5	t	small
4670	14738	107	Республика Алтай, Турочакский район, поселок Иогач, Школьная, 8	f	large
4658	15124	116	Республика Алтай, Турочакский район, поселок Дмитриевка, Морозова, 41	t	small
4665	14707	102	Республика Алтай, Турочакский район, поселок Верх-Бийск, Школьная, 13	t	small
4672	15117	109	Республика Алтай, Турочакский район, поселок Бийка, Центральная, клуб	t	small
4671	14746	108	Республика Алтай, Турочакский район, поселок Артыбаш, Бийская, 13	f	small
109208	14725	75	Республика Алтай, Онгудайский район, с.Малый Яломан, Садовая, 19	t	\N
4652	14750	91	Республика Алтай, Онгудайский район, поселок Шиба, Трактовая, 31	t	small
4643	14734	82	Республика Алтай, Онгудайский район, поселок Шашикман, Победы, 12	f	medium
4639	14729	78	Республика Алтай, Онгудайский район, поселок Хабаровка, Центральная, 43	t	small
4640	14730	79	Республика Алтай, Онгудайский район, поселок Улита, Советская, 26	t	small
4649	14743	88	Республика Алтай, Онгудайский район, поселок Туекта, Семенова, 66	t	small
4653	14751	92	Республика Алтай, Онгудайский район, поселок Теньга, Центральная, 31	f	small
4651	14747	90	Республика Алтай, Онгудайский район, поселок Талда, Яш-Корбо, 19а	t	small
4642	14732	81	Республика Алтай, Онгудайский район, поселок Онгудай, Советская, 80	f	large
4641	14732	80	Республика Алтай, Онгудайский район, поселок Онгудай, Советская, 80	f	large
4654	14752	93	Республика Алтай, Онгудайский район, поселок Озерное, Центральная, 11	t	small
4699	15155	136	Республика Алтай, Онгудайский район, поселок Озерное, Казакова, 3	t	small
4644	14736	83	Республика Алтай, Онгудайский район, поселок Нижняя Талда, Талду, 38	f	small
4650	14744	89	Республика Алтай, Онгудайский район, поселок Нефтебаза, Новая, 25	t	small
4634	14716	73	Республика Алтай, Онгудайский район, поселок Малая Иня, Подгорная, 1	t	small
4638	14728	77	Республика Алтай, Онгудайский район, поселок Купчегень, Трактовая, 13	t	small
4648	14742	87	Республика Алтай, Онгудайский район, поселок Кулада, Этенова, 32	t	small
4657	14755	96	Республика Алтай, Онгудайский район, поселок Каярлык, Меес-Дьяны, 40	t	small
4645	14739	84	Республика Алтай, Онгудайский район, поселок Каракол, Чорос-Гуркина, 43	f	medium
4711	15167	148	Республика Алтай, Онгудайский район, поселок Каракол, Центральная 11	t	small
4655	14753	94	Республика Алтай, Онгудайский район, Кара Кобы, Подгорная, 5	f	small
4632	14714	71	Республика Алтай, Онгудайский район, поселок Иодро, Центральная, 9	t	small
4635	14717	74	Республика Алтай, Онгудайский район, поселок Иня, Подгорная, 40	t	small
4633	14715	72	Республика Алтай, Онгудайский район, поселок Инегень, Центральная, 14	t	small
4656	14754	95	Республика Алтай, Онгудайский район, поселок Ело, Почтовая, 21	f	medium
4647	14741	86	Республика Алтай, Онгудайский район, поселок Боочи, 60-лет Победы, 31	t	small
4637	14727	76	Республика Алтай, Онгудайский район, поселок Большой Яломан, Центральная, 45	t	small
4646	14740	85	Республика Алтай, Онгудайский район, поселок Бичикту-Боом, Сетерлинская, 21	t	small
4620	15108	57	Республика Алтай, Майминский район, поселок Усть-Муны, Кошурникова, 23	f	medium
4628	15116	65	Республика Алтай, Майминский район, поселок Урлу-Аспак, переулок Школьный, Здание школы	t	small
4629	14708	66	Россия, Республика Алтай, Майминский район, поселок Средний Сайдыс	t	small
4617	15105	54	Республика Алтай, Майминский район, поселок Соузга, Трактовая, 11	f	large
4622	15110	59	Россия, Липецкая область, село Подгорное	f	small
4619	15107	56	Республика Алтай, Майминский район, поселок Манжерок, Советская	f	medium
4618	15106	55	Республика Алтай, Майминский район, поселок Манжерок, Дружбы	f	medium
4605	15096	42	Республика Алтай, Майминский район, поселок Майма, Советская, 50	f	medium
4604	14713	70	Республика Алтай, Майминский район, поселок Майма, Советская, 79	f	large
4631	14711	68	Республика Алтай, Майминский район, поселок Майма, Советская, 190	f	large
4603	14712	69	Республика Алтай, Майминский район, поселок Майма, Подгорная, 4	f	large
109207	14861	45	Республика Алтай, Майминский район, поселок Майма, Мира, 10	f	\N
4609	15060	46	Республика Алтай, Майминский район, поселок Майма, Механизаторов, 12	f	medium
4614	15102	51	Республика Алтай, Майминский район, поселок Майма, Ленина, 89	f	medium
4607	15098	44	Республика Алтай, Майминский район, поселок Майма, Ленина, 15А	f	medium
4606	15097	43	Республика Алтай, Майминский район, поселок Майма, Ленина, 6	f	large
4610	14706	47	Республика Алтай, Майминский район, поселок Майма, Ленина, 56	f	medium
4612	15100	49	Республика Алтай, Майминский район, поселок Майма, Зональная, 13	f	medium
4611	15099	48	Республика Алтай, Майминский район, поселок Майма, Гидростроителей	f	medium
4613	15101	50	Республика Алтай, Майминский район, поселок Майма, 50 лет Победы	f	medium
4625	15113	62	Республика Алтай, Майминский район, поселок Кызыл-Озек, Советская	f	large
4624	15112	61	Республика Алтай, Майминский район, поселок Кызыл-Озек, Советская	f	large
4615	15103	52	Республика Алтай, Майминский район, поселок Карлушка, Дом культуры	f	small
4630	14710	67	Россия, Республика Алтай, Майминский район, поселок Карасук	f	small
4616	15104	53	Республика Алтай, Майминский район, поселок Дубровка, Школьная	f	small
4621	15109	58	Республика Алтай, Майминский район, поселок Верх-Карагуж, Заречная, 2	f	small
4626	15114	63	Республика Алтай, Майминский район, поселок Бирюля	f	medium
4623	15111	60	Республика Алтай, Майминский район, поселок Алферово, Центральная	f	medium
4627	15115	64	Россия, Саратовская область, село Александровка	t	small
4589	15080	26	Республика Алтай, Кош-Агачский район, поселок Чаган-Узун, Центральная, 19	t	\N
4596	15089	35	Республика Алтай, Кош-Агачский район, поселок Теленгит-Сортогой, Центральная, 1	f	\N
4597	15090	36	Республика Алтай, Кош-Агачский район, поселок Тебелер, Советская, 21	f	\N
4600	15093	39	Республика Алтай, Кош-Агачский район, поселок Ташанта, Пограничная, 9а	t	\N
4590	15081	27	Республика Алтай, Кош-Агачский район, поселок Ортолык, Кокышева, 31	t	\N
4591	15082	28	Республика Алтай, Кош-Агачский район, поселок Мухор-Тархата, Бухарова, 3	t	\N
4588	15079	25	Республика Алтай, Кош-Агачский район, поселок Кызыл-Таш, Белеекова, 24	t	\N
4587	14658	24	Республика Алтай, Кош-Агачский район, поселок Курай, Зеленая, 3	t	\N
4594	15085	31	Республика Алтай, Кош-Агачский район, поселок Кош-Агач, Советская, 53	f	\N
4807	15086	32	Республика Алтай, Кош-Агачский район, поселок Кош-Агач, Новочуйская, 35	f	\N
4595	15087	33	Республика Алтай, Кош-Агачский район, поселок Кош-Агач, Молодежная, 11	f	\N
4806	15088	34	Республика Алтай, Кош-Агачский район, поселок Кош-Агач, Восточная, 1а	f	\N
4593	15084	30	Республика Алтай, Кош-Агачский район, поселок Кош-Агач, Абая, 20	f	\N
4599	15092	38	Республика Алтай, Кош-Агачский район, поселок Кокоря, Молодежная, 1	t	\N
4598	15091	37	Республика Алтай, Кош-Агачский район, поселок Жана-Аул, Абая, 9	t	\N
4601	15094	40	Республика Алтай, Кош-Агачский район, поселок Беляши (Джазатор), Центральная, 4	t	\N
109206	15083	29	Республика Алтай, Кош-Агачский район, поселок Бельтир, Школьная, 2	t	\N
59631	67348	1319	Омская область, деревня Приветная, Новая, 3	t	large
58658	66410	317	Россия, Омская область, Омск, улица космонавта Волкова, 5б	f	large
58657	66410	316	Россия, Омская область, Омск, улица космонавта Волкова, 5б	f	large
58656	66410	315	Россия, Омская область, Омск, улица космонавта Волкова, 5б	f	large
58655	66410	314	Россия, Омская область, Омск, улица космонавта Волкова, 5б	f	large
58625	66389	284	Россия, Омская область, Омск, улица Энтузиастов, 11б	f	large
58633	66396	292	Россия, Омская область, Омск, улица Энергетиков, 64	f	large
58505	66307	164	Россия, Омская область, Омск, улица Шота Руставели, 1	f	large
58504	66307	163	Россия, Омская область, Омск, улица Шота Руставели, 1	f	large
58797	66492	456	Россия, Омская область, Омск, улица Чокана Валиханова, 17	f	large
58796	66492	455	Россия, Омская область, Омск, улица Чокана Валиханова, 17	f	large
58799	66494	458	Россия, Омская область, Омск, улица Чкалова, 3	f	large
58489	66294	148	Россия, Омская область, Омск, улица Чайковского, 68	f	large
58488	66294	147	Россия, Омская область, Омск, улица Чайковского, 68	f	large
58487	66293	146	Россия, Омская область, Омск, улица Чайковского, 5	f	large
58486	66293	145	Россия, Омская область, Омск, улица Чайковского, 5	f	large
58785	66484	444	Россия, Омская область, Омск, улица Циолковского, 1	f	large
58786	66484	445	Россия, Омская область, Омск, улица Циолковского, 1	f	large
58944	66646	616	Омская область, Омск, улица Центральная, 3	f	small
59598	67327	1286	Россия, Московская область, городской округ Лосино-Петровский, деревня Осеево, Центральная улица, 44	f	small
58445	66265	104	Россия, Омская область, Омск, улица Хасан Озеро, 1	f	large
58630	66393	289	Россия, Омская область, Омск, улица ХХ Партсъезда, 12	f	large
58602	66374	261	Россия, Омская область, Омск, улица ХХ Партсъезда, 48	f	large
58606	66377	265	Россия, Омская область, Омск, улица ХIХ Партсъезда, 35	f	large
58409	66238	68	Россия, Омская область, Омск, улица Фугенфирова, 5а	f	large
58408	66238	67	Россия, Омская область, Омск, улица Фугенфирова, 5а	f	large
58407	66237	66	Россия, Омская область, Омск, улица Фугенфирова, 11	f	large
58406	66237	65	Россия, Омская область, Омск, улица Фугенфирова, 11	f	large
58748	66427	407	Россия, Омская область, Омск, улица Фрунзе, 71	f	large
58701	66427	360	Россия, Омская область, Омск, улица Фрунзе, 71	f	large
58439	66258	98	Россия, Омская область, Омск	f	large
58438	66258	97	Россия, Омская область, Омск	f	large
58453	66271	112	Россия, Омская область, Омск, улица Усадебная, 13	f	large
58452	66271	111	Россия, Омская область, Омск, улица Усадебная, 13	f	large
58622	66387	281	Россия, Омская область, Омск, улица Тимофея Белозерова, 5	f	large
58621	66387	280	Россия, Омская область, Омск, улица Тимофея Белозерова, 5	f	large
58620	66386	279	Россия, Омская область, Омск, улица Тимофея Белозерова, 6	f	large
58610	66380	269	Россия, Омская область, Омск, улица Тимофея Белозерова, 20	f	large
58609	66380	268	Россия, Омская область, Омск, улица Тимофея Белозерова, 20	f	large
59778	67496	1469	Россия, Омская область, Омск, улица Тарская, 10	f	large
58353	66209	12	Россия, Омская область, Омск, улица Суровцева, 49/66	f	large
58509	66310	168	Россия, Омская область, Омск, улица Спортивная, 74	f	large
58676	66419	335	Россия, Омская область, Омск, улица Сибниисхоз, 3	f	large
58675	66419	334	Россия, Омская область, Омск, улица Сибниисхоз, 3	f	large
58359	66214	18	Россия, Омская область, Омск, улица Седова, 57	f	large
58358	66212	17	Россия, Омская область, Омск, улица Седова, 55а	f	large
58572	66356	231	Россия, Омская область, Омск, улица Свободы, 157	f	large
58571	66356	230	Россия, Омская область, Омск, улица Свободы, 157	f	large
58617	66384	276	Россия, Омская область, Омск, улица Светлая, 5	f	large
58616	66384	275	Россия, Омская область, Омск, улица Светлая, 5	f	large
58615	66384	274	Россия, Омская область, Омск, улица Светлая, 5	f	large
58793	66489	452	Омская область, Омск, улица Садовая, 52а	f	large
58538	66332	197	Россия, Омская область, Омск, улица Романенко, 15а	f	large
58537	66332	196	Россия, Омская область, Омск, улица Романенко, 15а	f	large
58699	66249	358	Россия, Омская область, Омск, улица Рабиновича, 93а	f	large
58405	66236	64	Россия, Омская область, Омск, улица Путилова, 2	f	large
58404	66236	63	Россия, Омская область, Омск, улица Путилова, 2	f	large
58841	66530	511	Россия, Омская область, Омск, улица Промышленная, 42	f	large
59752	67468	1442	Россия, Омская область, Омск, улица Почтовая, 4	f	medium
58499	66303	158	Омская область, Омск, улица Поморцева, 50	f	medium
58515	66315	174	Россия, Омская область, Омск, улица Плеханова, 59	f	large
58514	66315	173	Россия, Омская область, Омск, улица Плеханова, 59	f	large
58545	66336	204	Россия, Омская область, Омск, улица Петра Осминина, 16а	f	large
58368	66219	27	Россия, Омская область, Омск, улица Перелета, 1	f	large
58987	66690	661	Омская область, Исилькульский район, Первомайская, 77	f	large
58982	66685	656	Россия, Омская область, Омск, поселок Большие Поля, улица Первомайская, 2	f	large
58674	66418	333	Россия, Омская область, Омск, поселок Большие Поля, улица Первомайская, 2	f	large
58531	66329	190	Россия, Омская область, Омск, улица Пархоменко, 7	f	large
58774	66476	433	Россия, Омская область, Омск, улица Омская, 75	f	large
58773	66476	432	Россия, Омская область, Омск, улица Омская, 75	f	large
58772	66475	431	Россия, Омская область, Омск, улица Омская, 106	f	large
58771	66475	430	Россия, Омская область, Омск, улица Омская, 106	f	large
58770	66475	429	Россия, Омская область, Омск, улица Омская, 106	f	large
58543	66334	202	Россия, Омская область, Омск, улица Олимпийская, 7а	f	large
58542	66334	201	Россия, Омская область, Омск, улица Олимпийская, 7а	f	large
58541	66334	200	Россия, Омская область, Омск, улица Олимпийская, 7а	f	large
60020	67738	1716	Россия, Омская область, Омск, улица Октябрьская, 127	f	large
58836	66525	506	Россия, Омская область, Омск, улица Октябрьская, 3	f	large
58700	66426	359	Россия, Омская область, Омск, улица Октябрьская, 92	f	large
58343	66204	2	Россия, Омская область, Омск, улица Новостройка, 20б	f	large
58342	66204	1	Россия, Омская область, Омск, улица Новостройка, 20б	f	large
58372	66221	31	Россия, Омская область, Омск, улица Новороссийская, 2	f	large
58459	66262	118	Россия, Омская область, Омск, улица Моторная, 9	f	large
58458	66262	117	Россия, Омская область, Омск, улица Моторная, 9	f	large
58457	66262	116	Россия, Омская область, Омск, улица Моторная, 9	f	large
58465	66276	124	Россия, Омская область, Омск, улица Молодогвардейская, 33	f	large
58462	66274	121	Россия, Омская область, Омск, улица Молодова, 12	f	large
58461	66274	120	Россия, Омская область, Омск, улица Молодова, 12	f	large
58460	66274	119	Россия, Омская область, Омск, улица Молодова, 12	f	large
58432	66252	91	Россия, Омская область, Омск, улица Менжинского, 1в	f	large
58429	66250	88	Россия, Омская область, Омск, улица Мельничная, 102	f	large
58428	66248	87	Россия, Омская область, Омск, улица Мельничная, 89/3	f	large
58349	66206	8	Россия, Омская область, Омск, улица Мельничная, 4	f	large
58348	66206	7	Россия, Омская область, Омск, улица Мельничная, 4	f	large
58347	66206	6	Россия, Омская область, Омск, улица Мельничная, 4	f	large
58527	66326	186	Россия, Омская область, Омск, улица Масленникова, 144	f	large
58526	66325	185	Россия, Омская область, Омск, улица Масленникова, 171	f	large
58513	66313	172	Россия, Омская область, Омск, улица Масленникова, 43	f	large
58597	66371	256	Россия, Омская область, Омск, улица Мамина-Сибиряка, 9	f	large
58632	66395	291	Россия, Омская область, Омск, улица Магистральная, 22	f	large
58599	66372	258	Россия, Омская область, Омск, улица Магистральная, 70	f	large
58598	66372	257	Россия, Омская область, Омск, улица Магистральная, 70	f	large
58485	66291	144	Россия, Омская область, Омск, улица Лобкова, 17	f	large
58842	66531	512	Россия, Омская область, Омск, улица Лермонтова, 32	f	large
58803	66497	462	Россия, Омская область, Омск, улица Лермонтова, 131	f	large
59764	67481	1454	Россия, Омская область, Омск, улица Ленина, 15а	f	medium
59761	67478	1451	Россия, Омская область, Омск, улица Ленина, 8	f	medium
59497	67220	1181	Россия, Омская область, Омск, улица Ленина, 13	f	medium
58957	66658	630	Россия, Омская область, Омск, улица Ленина, 45	f	medium
58956	66657	629	Россия, Омская область, Омск, улица Ленина, 12	f	large
58878	66574	548	Россия, Омская область, Омск, улица Ленина, 16	f	medium
58851	66541	521	Россия, Омская область, Омск, улица Ленина, 5	f	medium
58798	66493	457	Россия, Омская область, Омск, улица Ленина, 36	f	large
58794	66490	453	Россия, Омская область, Омск, улица Ленина, 48/1	f	large
58766	66473	425	Россия, Омская область, Омск, улица Куйбышева, 79а	f	large
58605	66376	264	Россия, Омская область, Омск, улица Круговая, 2/1	f	large
58604	66376	263	Россия, Омская область, Омск, улица Круговая, 2/1	f	large
58703	66428	362	Россия, Омская область, Омск, улица Красный Путь, 22а	f	large
58702	66428	361	Россия, Омская область, Омск, улица Красный Путь, 22а	f	large
58681	66424	340	Россия, Омская область, Омск, улица Красный Путь, 68	f	large
58680	66423	339	Россия, Омская область, Омск, улица Красный Путь, 80в	f	large
58731	66451	390	Россия, Омская область, Омск, улица Краснознаменная, 26/1	f	large
59773	67491	1463	Россия, Омская область, Омск, поселок Большие Поля, улица Комсомольская	f	large
59748	67464	1438	Россия, Омская область, Омск, поселок Большие Поля, улица Комсомольская, 12	f	medium
59746	67462	1436	Россия, Омская область, Омск, поселок Большие Поля, улица Комсомольская, 1	f	medium
58614	66383	273	Россия, Омская область, Омск, улица Коммунальная, 13б	f	large
58613	66383	272	Россия, Омская область, Омск, улица Коммунальная, 13б	f	large
58578	66359	237	Россия, Омская область, Омск, улица Кирова, 7а	f	large
58579	66358	238	Россия, Омская область, Омск, улица Кирова, 7а	f	large
58577	66358	236	Россия, Омская область, Омск, улица Кирова, 7а	f	large
58516	66316	175	Россия, Омская область, Омск, улица Ипподромная, 1	f	large
58769	66474	428	Россия, Омская область, Омск, улица Звездова, 96	f	large
58768	66474	427	Россия, Омская область, Омск, улица Звездова, 96	f	large
58767	66474	426	Россия, Омская область, Омск, улица Звездова, 96	f	large
58419	66244	78	Россия, Омская область, Омск, улица Звездная, 2б	f	large
58666	66412	325	Россия, Омская область, Омск, улица Заозерная, 11г	f	large
58665	66412	324	Россия, Омская область, Омск, улица Заозерная, 11г	f	large
58664	66412	323	Россия, Омская область, Омск, улица Заозерная, 11г	f	large
58663	66412	322	Россия, Омская область, Омск, улица Заозерная, 11г	f	large
58734	66454	393	Россия, Омская область, Омск, улица Завертяева, 30	f	large
58730	66450	389	Россия, Омская область, Омск, улица Завертяева, 31	f	large
58728	66448	387	Россия, Омская область, Омск, улица Завертяева, 5	f	large
59055	66765	730	Россия, Московская область, Наро-Фоминский район, Наро-Фоминск, улица Ермолаева	t	small
58536	66331	195	Россия, Омская область, Омск, улица Ермолаева, 5а	f	large
58534	66331	193	Россия, Омская область, Омск, улица Ермолаева, 5а	f	large
58535	66331	194	Россия, Омская область, Омск, улица Ермолаева, 5а	f	large
58749	66462	408	Россия, Омская область, Омск, улица Достоевского, 2	f	large
58685	66390	344	Россия, Омская область, Омск, улица Долгирева, 91	f	large
58686	65818	345	Россия, Омская область, Омск, улица Долгирева, 117	f	large
58444	66264	103	Россия, Омская область, Омск, улица Добролюбова, 22	f	large
58442	66261	101	Россия, Омская область, Омск, улица Добролюбова, 15	f	large
58389	66229	48	Россия, Омская область, Омск, улица Дмитриева, 2/8	f	large
58388	66229	47	Россия, Омская область, Омск, улица Дмитриева, 2/8	f	large
58387	66229	46	Россия, Омская область, Омск, улица Дмитриева, 2/8	f	large
58364	66217	23	Россия, Омская область, Омск, улица Дмитриева, 13	f	large
58363	66217	22	Россия, Омская область, Омск, улица Дмитриева, 13	f	large
58362	66216	21	Россия, Омская область, Омск, улица Дмитриева, 13/10	f	large
58361	66216	20	Россия, Омская область, Омск, улица Дмитриева, 13/10	f	large
58417	66243	76	Россия, Омская область, Омск, улица Дианова, 18/2	f	large
58416	66243	75	Россия, Омская область, Омск, улица Дианова, 18/2	f	large
58418	66243	77	Россия, Омская область, Омск, улица Дианова, 18/2	f	large
58412	66239	71	Россия, Омская область, Омск, улица Дианова, 12/2	f	large
58411	66239	70	Россия, Омская область, Омск, улица Дианова, 12/2	f	large
58410	66239	69	Россия, Омская область, Омск, улица Дианова, 12/2	f	large
58792	66488	451	Россия, Омская область, Омск, улица Декабристов, 112	f	large
58791	66488	450	Россия, Омская область, Омск, улица Декабристов, 112	f	large
58790	66488	449	Россия, Омская область, Омск, улица Декабристов, 112	f	large
58763	66471	422	Россия, Омская область, Омск, улица Декабристов, 35	f	large
87039	66504	468	Россия, Омская область, Омск, улица Гуртьева, 1б	f	large
58603	66375	262	Россия, Омская область, Омск, улица Грозненская, 7	f	large
59563	67290	1250	Россия, Омская область, Омск, улица Гагарина, 3	f	medium
58747	66461	406	Россия, Омская область, Омск, улица Волочаевская, 17г	f	large
58746	66461	405	Россия, Омская область, Омск, улица Волочаевская, 17г	f	large
58745	66461	404	Россия, Омская область, Омск, улица Волочаевская, 17г	f	large
58744	66461	403	Россия, Омская область, Омск, улица Волочаевская, 17г	f	large
58352	66208	11	Россия, Омская область, Омск, улица Володарского, 74	f	large
58351	66208	10	Россия, Омская область, Омск, улица Володарского, 74	f	large
58468	66278	127	Россия, Омская область, Омск, улица Волго-Донская, 15	f	large
58469	66278	128	Россия, Омская область, Омск, улица Волго-Донская, 15	f	large
58547	66337	206	Россия, Омская область, Омск, улица Василия Товстухо, 4	f	large
58546	66337	205	Россия, Омская область, Омск, улица Василия Товстухо, 4	f	large
87038	66502	467	Россия, Омская область, Омск, поселок Светлый, улица Василия Маргелова, 400/1	f	large
58478	66285	137	Россия, Омская область, Омск, поселок Светлый, улица Василия Маргелова, 400/1	f	large
58477	66285	136	Россия, Омская область, Омск, поселок Светлый, улица Василия Маргелова, 400/1	f	large
59776	67494	1466	Россия, Омская область, Омск, улица Бульварная, 15	f	medium
58751	66464	410	Россия, Омская область, Омск, улица Булатова, 101	f	large
58612	66381	271	Россия, Омская область, Омск, улица Бородина, 19	f	large
58611	66381	270	Россия, Омская область, Омск, улица Бородина, 19	f	large
58518	66318	177	Россия, Омская область, Омск, улица Богдана Хмельницкого, 214	f	large
58346	66205	5	Россия, Омская область, Омск, улица Бетховена, 1	f	large
58470	66279	129	Россия, Омская область, Омск, улица Батумская, 28	f	large
58662	66411	321	Россия, Омская область, Омск, улица Бархатовой, 6г	f	large
58661	66411	320	Россия, Омская область, Омск, улица Бархатовой, 6г	f	large
58660	66411	319	Россия, Омская область, Омск, улица Бархатовой, 6г	f	large
58659	66411	318	Россия, Омская область, Омск, улица Бархатовой, 6г	f	large
58735	66446	394	Россия, Омская область, Омск, улица Барнаульская, 134	f	large
58725	66446	384	Россия, Омская область, Омск, улица Барнаульская, 134	f	large
58718	66440	377	Россия, Омская область, Омск, улица Багратиона, 7	f	large
58441	66260	100	Россия, Омская область, Омск, улица Артема Избышева, 3	f	large
58760	66469	419	Россия, Омская область, Омск, улица Арсеньева, 1	f	large
58759	66469	418	Россия, Омская область, Омск, улица Арсеньева, 1	f	large
58758	66469	417	Россия, Омская область, Омск, улица Арсеньева, 1	f	large
58645	66404	304	Россия, Омская область, Омск, улица Андрианова, 4	f	large
58644	66403	303	Россия, Омская область, Омск, улица Андрианова, 24	f	large
58639	66399	298	Россия, Омская область, Омск, улица Андрианова, 14/3	f	large
58638	66399	297	Россия, Омская область, Омск, улица Андрианова, 14/3	f	large
58637	66399	296	Россия, Омская область, Омск, улица Андрианова, 14/3	f	large
58434	66254	93	Россия, Омская область, Омск, улица Ангарская, 7а	f	large
58433	66253	92	Россия, Омская область, Омск, улица Ангарская, 7а	f	large
58450	66269	109	Россия, Омская область, Омск, улица Алексея Полторацкого, 54	f	large
58448	66268	107	Россия, Омская область, Омск, улица Алексея Полторацкого, 57а	f	large
58447	66267	106	Россия, Омская область, Омск, улица Алексея Полторацкого, 51	f	large
58449	66267	108	Россия, Омская область, Омск, улица Алексея Полторацкого, 51	f	large
58357	66211	16	Россия, Омская область, Омск, улица Авиагородок, 27	f	large
58356	66211	15	Россия, Омская область, Омск, улица Авиагородок, 27	f	large
58380	66226	39	Россия, Омская область, Омск, улица 70 Лет Октября, 20/1	f	large
58382	66225	41	Россия, Омская область, Омск, улица 70 Лет Октября, 20/3	f	large
58381	66225	40	Россия, Омская область, Омск, улица 70 Лет Октября, 20/3	f	large
58379	66225	38	Россия, Омская область, Омск, улица 70 Лет Октября, 20/3	f	large
58560	66347	219	Россия, Омская область, Омск, улица 6-я Шинная, 9	f	large
58559	66346	218	Россия, Омская область, Омск, улица 6-я Шинная, 9	f	large
58467	66277	126	Россия, Омская область, Омск, улица 6-я Станционная, 31	f	large
58466	66277	125	Россия, Омская область, Омск, улица 6-я Станционная, 31	f	large
58464	66275	123	Россия, Омская область, Омск, улица 6-я Станционная, 11	f	large
58463	66275	122	Россия, Омская область, Омск, улица 6-я Станционная, 11	f	large
58757	66467	416	Россия, Омская область, Омск, улица 6-я Ремесленная, 13	f	large
58756	66467	415	Россия, Омская область, Омск, улица 6-я Ремесленная, 13	f	large
58755	66467	414	Россия, Омская область, Омск, улица 6-я Ремесленная, 13	f	large
58594	66368	253	Россия, Омская область, Омск, улица 50 Лет Профсоюзов, 105	f	large
58593	66368	252	Россия, Омская область, Омск, улица 50 Лет Профсоюзов, 105	f	large
58837	66526	507	Россия, Омская область, Омск, улица 50 Лет ВЛКСМ, 3	f	large
58580	66360	239	Россия, Омская область, Омск, улица 5-я Рабочая, 44	f	large
58556	66343	215	Россия, Омская область, Омск, улица 5-я Кордная, 3	f	large
58752	66465	411	Россия, Омская область, Омск, улица 5 Армии, 141	f	large
58733	66453	392	Россия, Омская область, Омск, поселок Степной, улица 40 Лет Ракетных Войск, 8	f	large
58711	66435	370	Россия, Омская область, Омск, улица 4-я Челюскинцев, 2а	f	large
58710	66435	369	Россия, Омская область, Омск, улица 4-я Челюскинцев, 2а	f	large
58582	66361	241	Россия, Омская область, Омск, улица 4-я Транспортная, 56	f	large
58581	66361	240	Россия, Омская область, Омск, улица 4-я Транспортная, 56	f	large
58647	66405	306	Россия, Омская область, Омск, улица 4-я Поселковая, 38	f	large
58646	66405	305	Россия, Омская область, Омск, улица 4-я Поселковая, 38	f	large
58492	66296	151	Россия, Омская область, Омск, улица 4-я Марьяновская, 67а	f	large
58689	66021	348	Россия, Омская область, Омск, улица 35-я Северная, 3	f	large
58712	66436	371	Россия, Омская область, Омск, улица 33-я Северная, 48	f	large
58719	66442	378	Россия, Омская область, Омск, улица 30-я Северная, 121	f	large
58690	66043	349	Россия, Омская область, Омск, улица 30-я Северная, 71	f	large
58587	66365	246	Россия, Омская область, Омск, улица 30-я Рабочая, 14а	f	large
58519	66319	178	Россия, Омская область, Омск, улица 3-я Транспортная, 7	f	large
58475	66283	134	Россия, Омская область, Омск, улица 3-я Станционная, 69	f	large
58474	66283	133	Россия, Омская область, Омск, улица 3-я Станционная, 69	f	large
58383	66227	42	Омская область, Омск, улица 3-я Островская, 164	f	large
58472	66281	131	Россия, Омская область, Омск, Ленинский район, улица 3-я Ленинградская, 50	f	medium
58558	66345	217	Россия, Омская область, Омск, улица 3-я Кордная, 25а	f	large
58557	66344	216	Россия, Омская область, Омск, улица 3-я Кордная, 25а	f	large
58715	66438	374	Россия, Омская область, Омск, улица 27-я Северная, 90	f	large
58714	66438	373	Россия, Омская область, Омск, улица 27-я Северная, 90	f	large
58484	66290	143	Россия, Омская область, Омск, улица 25 Лет Октября, 4	f	large
58761	66432	420	Россия, Омская область, Омск, улица 24-я Северная, 216	f	large
58707	66432	366	Россия, Омская область, Омск, улица 24-я Северная, 216	f	large
58691	66071	350	Россия, Омская область, Омск, улица 24-я Северная, 119	f	large
58727	66447	386	Россия, Омская область, Омск, улица 21-я Амурская, 20а	f	large
58726	66447	385	Россия, Омская область, Омск, улица 21-я Амурская, 20а	f	large
58724	66445	383	Россия, Омская область, Омск, улица 21-я Амурская, 17	f	large
58723	66445	382	Россия, Омская область, Омск, улица 21-я Амурская, 17	f	large
58720	66443	379	Россия, Омская область, Омск, улица 21-я Амурская, 15	f	large
58717	66439	376	Россия, Омская область, Омск, улица 21-я Амурская, 5	f	large
58716	66439	375	Россия, Омская область, Омск, улица 21-я Амурская, 5	f	large
58350	66207	9	Россия, Омская область, Омск, улица 20 Лет Октября, 12а	f	large
58426	66246	85	Россия, Омская область, Омск, улица 2-я Солнечная, 15	f	large
58425	66246	84	Россия, Омская область, Омск, улица 2-я Солнечная, 15	f	large
58424	66246	83	Россия, Омская область, Омск, улица 2-я Солнечная, 15	f	large
58423	66246	82	Россия, Омская область, Омск, улица 2-я Солнечная, 15	f	large
58741	66458	400	Россия, Омская область, Омск, улица 2-я Производственная, 37	f	large
58670	66415	329	Россия, Омская область, Омск, улица 2-я Поселковая, 1	f	large
58471	66280	130	Россия, Омская область, Омск, улица 2-я Ленинградская, 24	f	large
58496	66300	155	Россия, Омская область, Омск, улица 19-я Марьяновская, 40а	f	large
58495	66299	154	Россия, Омская область, Омск, улица 19-я Марьяновская, 40а	f	large
58695	66109	354	Россия, Омская область, Омск, улица 18-я Северная, 91	f	large
58694	66109	353	Россия, Омская область, Омск, улица 18-я Северная, 91	f	large
58693	66109	352	Россия, Омская область, Омск, улица 18-я Северная, 91	f	large
58692	66109	351	Россия, Омская область, Омск, улица 18-я Северная, 91	f	large
58584	66363	243	Россия, Омская область, Омск, улица 17-я Рабочая, 89	f	large
58583	66362	242	Россия, Омская область, Омск, улица 17-я Рабочая, 89	f	large
58497	66301	156	Россия, Омская область, Омск, улица 13-я Комсомольская, 1	f	large
58355	66210	14	Россия, Омская область, Омск, улица 12 Декабря, 114	f	large
58354	66210	13	Россия, Омская область, Омск, улица 12 Декабря, 114	f	large
58510	66270	169	Россия, Омская область, Омск, улица 10-я Чередовая, 32а	f	large
58451	66270	110	Россия, Омская область, Омск, улица 10-я Чередовая, 32а	f	large
58491	66295	150	Россия, Омская область, Омск, улица 1-я Красной Звезды, 25	f	large
58490	66295	149	Россия, Омская область, Омск, улица 1-я Красной Звезды, 25	f	large
58493	66297	152	Россия, Омская область, Омск, улица 1-го Мая, 25	f	large
58443	66263	102	Омская область, Омск, Ленинский административный округ, академика Павлова, 24	f	large
58427	66247	86	Омская область, Омск, Я.М.Сметнева, 5	f	large
58627	66391	286	Омская область, Омск, Энтузиастов, 25б	f	large
58626	66391	285	Омская область, Омск, Энтузиастов, 25б	f	large
58608	66379	267	Омская область, Омск, Энтузиастов, 47	f	large
58854	66544	524	Омская область, Омск, Школьный переулок, 4	f	large
58762	66470	421	Омская область, Омск, Чкалова, 25	f	large
58575	66357	234	Омская область, Омск, Харьковская, 21	f	large
58574	66357	233	Омская область, Омск, Харьковская, 21	f	large
58573	66357	232	Омская область, Омск, Харьковская, 21	f	large
58709	66434	368	Омская область, Омск, ХХII Партсъезда, 19	f	large
58678	66421	337	Омская область, Омск, Физкультурная, 1	f	large
58393	66230	52	Россия, Омская область, Омск, Туполева бульвар, 1	f	large
58392	66230	51	Россия, Омская область, Омск, Туполева бульвар, 1	f	large
58391	66230	50	Россия, Омская область, Омск, Туполева бульвар, 1	f	large
58390	66230	49	Россия, Омская область, Омск, Туполева бульвар, 1	f	large
58431	66251	90	Омская область, Омск, Талалихина, 29а	f	large
58430	66251	89	Омская область, Омск, Талалихина, 29а	f	large
58750	66463	409	Омская область, Омск, Т.К. Щербанева, 20	f	medium
58787	66485	446	Россия, Омская область, Омск, Спортивный проезд, 9	f	large
58456	66272	115	Россия, Омская область, Омск, Сибирский проспект, 6а	f	large
58455	66272	114	Россия, Омская область, Омск, Сибирский проспект, 6а	f	large
58454	66272	113	Россия, Омская область, Омск, Сибирский проспект, 6а	f	large
58677	66420	336	Омская область, Омск, Сибаковская, 6	f	large
58619	66385	278	Омская область, Омск, Сергея Тюленина, 5	f	large
58618	66385	277	Омская область, Омск, Сергея Тюленина, 5	f	large
58576	66324	235	Омская область, Омск, Свободы, 54	f	large
58525	66324	184	Омская область, Омск, Свободы, 54	f	large
58687	65867	346	Омская область, Омск, Сазонова, 199	f	large
58554	66341	213	Омская область, Омск, Российская, 10	f	large
58553	66341	212	Омская область, Омск, Российская, 10	f	large
58552	66341	211	Омская область, Омск, Российская, 10	f	large
58403	66235	62	Омская область, Омск, Путилова, 12а	f	large
58402	66235	61	Омская область, Омск, Путилова, 12а	f	large
58401	66235	60	Омская область, Омск, Путилова, 12а	f	large
58503	66306	162	Омская область, Омск, Правды, 30	f	large
58589	66366	248	Омская область, Омск, Полевая, 95	f	medium
58588	66366	247	Омская область, Омск, Полевая, 95	f	large
60144	67868	1842	Россия, Омская область, Омск, Победы бульвар	f	medium
60104	67828	1802	Россия, Омская область, Омск, Победы бульвар, 10	f	large
58548	66338	207	Омская область, Омск, Петра Осминина, 22	f	large
58688	66004	347	Омская область, Омск, Орджоникидзе, 287	f	large
58473	66282	132	Россия, Омская область, Омск, Омская Птицефабрика поселок, 53	f	medium
58775	66457	434	Омская область, Омск, Омская, 197	f	large
58740	66457	399	Омская область, Омск, Омская, 197	f	large
58570	66355	229	Омская область, Омск, Ноябрьская, 13	f	medium
59848	67572	1540	Омская область, Омск, поселок Большие Поля, Новая, 1	f	small
58528	66327	187	Омская область, Омск, Николая Кузнецова, 4а	f	large
58673	66417	332	Россия, Омская область, Омск, Мира проспект, 2а	f	large
58672	66416	331	Россия, Омская область, Омск, Мира проспект, 5	f	large
58671	66416	330	Россия, Омская область, Омск, Мира проспект, 5	f	large
58669	66414	328	Россия, Омская область, Омск, Мира проспект, 9	f	large
58648	66406	307	Россия, Омская область, Омск, Мира проспект, 11	f	large
58643	66402	302	Россия, Омская область, Омск, Мира проспект, 55а	f	large
58642	66401	301	Россия, Омская область, Омск, Мира проспект, 165д	f	large
58641	66401	300	Россия, Омская область, Омск, Мира проспект, 165д	f	large
58640	66400	299	Россия, Омская область, Омск, Мира проспект, 169г	f	large
58629	66392	288	Россия, Омская область, Омск, Мира проспект, 58	f	large
58628	66392	287	Россия, Омская область, Омск, Мира проспект, 58	f	large
58596	66370	255	Россия, Омская область, Омск, Мира проспект, 90/1	f	large
58595	66369	254	Россия, Омская область, Омск, Мира проспект, 96б	f	large
58592	66367	251	Россия, Омская область, Омск, Мира проспект, 102а	f	large
58591	66367	250	Россия, Омская область, Омск, Мира проспект, 102а	f	large
58590	66367	249	Россия, Омская область, Омск, Мира проспект, 102а	f	large
58668	66407	327	Россия, Омская область, Омск, Менделеева проспект, 32в	f	large
58652	66407	311	Россия, Омская область, Омск, Менделеева проспект, 32в	f	large
58651	66407	310	Россия, Омская область, Омск, Менделеева проспект, 32в	f	large
58650	66407	309	Россия, Омская область, Омск, Менделеева проспект, 32в	f	large
58649	66407	308	Россия, Омская область, Омск, Менделеева проспект, 32в	f	large
58345	66200	4	Омская область, Омск, Мельничная, 44	f	large
58344	66200	3	Омская область, Омск, Мельничная, 44	f	large
58631	66394	290	Омская область, Омск, Магистральная, 40	f	large
58483	66289	142	Омская область, Омск, Лобкова, 5	f	large
58440	66259	99	Омская область, Омск, Лобкова, 2	f	large
58375	66222	34	Россия, Омская область, Омск, Лесной проезд, 5	f	large
58374	66222	33	Россия, Омская область, Омск, Лесной проезд, 5	f	large
58373	66222	32	Россия, Омская область, Омск, Лесной проезд, 5	f	large
59772	67490	1462	Омская область, Омск, Ленина, 36	f	large
58508	66308	167	Омская область, Омск, Крыловская, 50	f	large
58506	66308	165	Омская область, Омск, Крыловская, 50	f	large
58805	66498	464	Омская область, Омск, Красных Зорь, 108б	f	large
58804	66498	463	Омская область, Омск, Красных Зорь, 108б	f	large
58679	66422	338	Омская область, Омск, Красный Путь, 143	f	large
58502	66305	161	Омская область, Омск, Красноярова, 1/1	f	medium
58729	66449	388	Омская область, Омск, Краснознаменная, 3	f	large
58550	66339	209	Россия, Омская область, Омск, Космический проспект, 14а	f	large
58549	66339	208	Россия, Омская область, Омск, Космический проспект, 14а	f	large
58533	66330	192	Россия, Омская область, Омск, Космический проспект, 79	f	large
58532	66330	191	Россия, Омская область, Омск, Космический проспект, 79	f	large
58530	66328	189	Россия, Омская область, Омск, Космический проспект, 13	f	large
58529	66328	188	Россия, Омская область, Омск, Космический проспект, 13	f	large
58624	66388	283	Россия, Омская область, Омск, Королева проспект, 2	f	large
58623	66388	282	Россия, Омская область, Омск, Королева проспект, 2	f	large
58422	66245	81	Омская область, Омск, Комкова, 3в	f	large
58421	66245	80	Омская область, Омск, Комкова, 3в	f	large
58420	66245	79	Омская область, Омск, Комкова, 3в	f	large
58367	66218	26	Россия, Омская область, Омск, Комарова проспект, 27/3	f	large
58366	66218	25	Россия, Омская область, Омск, Комарова проспект, 27/3	f	large
58365	66218	24	Россия, Омская область, Омск, Комарова проспект, 27/3	f	large
58360	66215	19	Омская область, Омск, Ключевая, 37	f	large
58788	66486	447	Россия, Омская область, Омск, Карла Маркса проспект, 24а	f	large
58564	66350	223	Россия, Омская область, Омск, Камерный переулок, 47	f	large
58563	66350	222	Россия, Омская область, Омск, Камерный переулок, 47	f	large
58562	66349	221	Россия, Омская область, Омск, Камерный переулок, 47а	f	large
58561	66348	220	Россия, Омская область, Омск, Камерный переулок, 47а	f	large
58844	66533	514	Россия, Омская область, Омск, Иртышская набережная, 7	f	small
58517	66317	176	Омская область, Омск, Ипподромная, 12	f	large
58739	66456	398	Омская область, Омск, Иванишко, 31	f	large
58738	66456	397	Омская область, Омск, Иванишко, 31	f	large
58737	66456	396	Омская область, Омск, Иванишко, 31	f	large
58400	66234	59	Россия, Омская область, Омск, Заречный бульвар, 3	f	large
58399	66233	58	Россия, Омская область, Омск, Заречный бульвар, 3	f	large
58398	66232	57	Россия, Омская область, Омск, Заречный бульвар, 5	f	large
58397	66232	56	Россия, Омская область, Омск, Заречный бульвар, 5	f	large
58395	66231	54	Россия, Омская область, Омск, Заречный бульвар, 8	f	large
58394	66231	53	Россия, Омская область, Омск, Заречный бульвар, 8	f	large
58396	66231	55	Россия, Омская область, Омск, Заречный бульвар, 8	f	large
58732	66452	391	Россия, Омская область, Омск, поселок Загородный, Загородный микрорайон, 13	f	large
58684	66292	343	Омская область, Омск, Долгирева, 79	f	large
58683	66292	342	Омская область, Омск, Долгирева, 79	f	large
58386	66228	45	Омская область, Омск, Дмитриева, 4к3	f	large
58385	66228	44	Омская область, Омск, Дмитриева, 4к3	f	large
58384	66228	43	Омская область, Омск, Дмитриева, 4к3	f	large
58476	66284	135	Россия, Омская область, Омск, Дальний поселок, 1	f	large
58498	66302	157	Омская область, Омск, Гуртьевской дивизии, 7	f	medium
58507	66309	166	Омская область, Омск, Гуртьева, 1б	f	large
58481	66287	140	Россия, Омская область, Омск, Входной микрорайон, 101	f	large
58480	66286	139	Россия, Омская область, Омск, Входной микрорайон, 22/2	f	large
58479	66286	138	Россия, Омская область, Омск, Входной микрорайон, 22/2	f	large
58437	66257	96	Омская область, Омск, Всеволода Иванова, 13	f	large
58435	66255	94	Омская область, Омск, Всеволода Иванова, 5	f	large
58377	66223	36	Омская область, Омск, Волгоградская, 34б	f	large
58376	66223	35	Омская область, Омск, Волгоградская, 34б	f	large
58371	66220	30	Омская область, Омск, Кировский административный округ, Ватутина, 13 к.1	f	large
58370	66220	29	Омская область, Омск, Кировский административный округ, Ватутина, 13 к.1	f	large
58369	66220	28	Омская область, Омск, Кировский административный округ, Ватутина, 13 к.1	f	large
58436	66256	95	Омская область, Омск, В.Иванова, 13а	f	large
58654	66408	313	Омская область, Омск, Блюхера, 22в	f	large
58653	66408	312	Омская область, Омск, Блюхера, 22в	f	large
58806	66499	465	Россия, Омская область, Омск, Биофабрика поселок, 14	f	large
58544	66335	203	Омская область, Омск, 75 Гвардейской бригады, 10, Октябрьский административный округ	f	large
58754	66466	413	Омская область, Омск, 7-я Ремесленная, 77	f	large
58753	66466	412	Омская область, Омск, 7-я Ремесленная, 77	f	large
58540	66333	199	Омская область, Омск, 50 лет ВЛКСМ, 7б	f	large
58539	66333	198	Омская область, Омск, 50 лет ВЛКСМ, 7б	f	large
58801	66472	460	Россия, Омская область, Омск, 5-я линия, 117б	f	large
58765	66472	424	Россия, Омская область, Омск, 5-я линия, 117б	f	large
58764	66472	423	Россия, Омская область, Омск, 5-я линия, 117б	f	large
58567	66352	226	Омская область, Омск, 5-я Кордная, 43а	f	large
58566	66352	225	Омская область, Омск, 5-я Кордная, 43а	f	large
58522	66322	181	Омская область, Омск, 3-я Транспортная, 2	f	large
58521	66321	180	Омская область, Омск, 3-я Транспортная, 2	f	large
58565	66351	224	Омская область, Омск, 3-я Молодежная, 65	f	large
58713	66437	372	Омская область, Омск, 24-я Северная, 121	f	large
58586	66364	245	Омская область, Омск, 22-я Рабочая, 80	f	large
58585	66364	244	Омская область, Омск, 22-я Рабочая, 80	f	large
58634	66397	293	Омская область, Омск, 22 Апреля, 20а	f	large
58635	66397	294	Омская область, Омск, 22 Апреля, 20а	f	large
58722	66444	381	Омская область, Омск, 21-я Амурская, 19	f	large
58721	66444	380	Омская область, Омск, 21-я Амурская, 19	f	large
58494	66298	153	Омская область, Омск, 2-я Электровозная, 15	f	large
58524	66323	183	Россия, Омская область, Омск, военный городок 16-й, 16-й Военный городок, 108	f	large
58523	66323	182	Россия, Омская область, Омск, военный городок 16-й, 16-й Военный городок, 108	f	large
58777	66477	436	Россия, Омская область, Омск, 14-я линия, 41	f	large
58776	66477	435	Россия, Омская область, Омск, 14-я линия, 41	f	large
58501	66304	160	Россия, Омская область, Омск, военный городок 14-й, 14-й Военный городок, 148	f	large
58500	66304	159	Россия, Омская область, Омск, военный городок 14-й, 14-й Военный городок, 148	f	large
58736	66455	395	Омская область, Омск, 10 Лет Октября, 149	f	large
58802	66496	461	Омская область, Омск, 1-я Учхозная, 25	f	large
58697	66213	356	Омская область, Омск, 1-я Северная, 39	f	large
58696	66213	355	Омская область, Омск, 1-я Северная, 39	f	large
58698	66213	357	Омская область, Омск, 1-я Северная, 39	f	large
58569	66354	228	Омская область, Омск, поселок Волжский, 1-я Полевая, 7	f	small
58601	66373	260	Омская область, Омск, 1-я Осенняя, 45	f	large
58600	66373	259	Омская область, Омск, 1-я Осенняя, 45	f	large
58708	66433	367	Омская область, Омск, 1-й Челюскинцев проезд	f	large
59605	67335	1293	Омская область, поселок Новомосковка, Интернациональная, 5	t	medium
59396	67102	1078	Омская область, поселок Муромцево, Зеленая, 22	f	large
59632	67350	1320	Омская область, поселок Магистральный, улица Молодежная, 13в	f	large
60181	67898	1880	Омская область, Шербакульский район, поселок Яблоновка, Центральная, 26	f	small
60149	67872	1848	Омская область, Шербакульский район, поселок Шербакуль, площадь Гуртьева, 2	f	large
60150	67873	1849	Омская область, Шербакульский район, поселок Шербакуль, Чапаева, 27	f	large
56407	64272	102	Новосибирская область, Барабинск	f	medium
60148	67871	1847	Омская область, Шербакульский район, поселок Шербакуль, Гуртьева, 1	f	large
60160	67883	1859	Омская область, Шербакульский район, поселок Шахат, Джамбула, 3	f	small
60183	67900	1882	Омская область, Шербакульский район, поселок Чадское, Школьная, 23	f	small
60173	67890	1872	Омская область, Шербакульский район, поселок Центральное, Советская, 3А	f	small
60174	67891	1873	Омская область, Шербакульский район, поселок Тарналы, Фермерская, 1	f	small
60175	67892	1874	Омская область, Шербакульский район, поселок Таловское, Северная, 38	f	medium
60184	67901	1883	Омская область, Шербакульский район, поселок Солнцево, Центральная, 27	f	small
60178	67895	1877	Омская область, Шербакульский район, поселок Славянское, Зеленая, 13	f	small
60155	67878	1854	Омская область, Шербакульский район, поселок Путиловка, Центральная, 32	f	small
60162	67885	1861	Омская область, Шербакульский район, поселок Новоскатовка, Центральная, 30	f	small
60154	67877	1853	Омская область, Шербакульский район, поселок Максимовка, Ленина, 19	f	medium
60157	67880	1856	Омская область, Шербакульский район, поселок Кутузовка, Молодежная, 45	f	medium
60161	67884	1860	Омская область, Шербакульский район, поселок Кудук-Чилик, Школьная, 6	f	small
60163	67785	1862	Омская область, Шербакульский район, поселок Крушановка, 30 лет Целины, 17	f	small
60177	67894	1876	Омская область, Шербакульский район, поселок Красный Восток, Победы, 16	f	small
59621	14621	1309	Омская область, Шербакульский район, поселок Красноярка, Ленина, 15	f	large
60172	67889	1871	Омская область, Шербакульский район, поселок Комиссаровское-1, Центральная, 1а	f	small
60182	67899	1881	Омская область, Шербакульский район, поселок Кокчинск, Школьная, 27	f	small
60180	67897	1879	Омская область, Шербакульский район, поселок Карагаш, Центральная, 25	f	small
60168	53471	1867	Омская область, Шербакульский район, поселок Кайчубай, Мира, 6	f	small
60164	67797	1863	Омская область, Шербакульский район, поселок Изюмовка, Школьная, 25	f	medium
60156	67879	1855	Омская область, Шербакульский район, поселок Елизаветино, Школьная, 2	f	small
60159	67882	1858	Омская область, Шербакульский район, поселок Екатеринославка, Школьная, 38	f	large
60158	67881	1857	Омская область, Шербакульский район, поселок Дубровка, Центральная, 28	f	small
60167	67713	1866	Омская область, Шербакульский район, поселок Вишневка, Школьная, 11а	f	small
60152	67875	1851	Омская область, Шербакульский район, поселок Вербовка, Мира, 26а	f	small
60171	67888	1870	Омская область, Шербакульский район, поселок Борисовское, Советская, 17	f	medium
60170	67887	1869	Омская область, Шербакульский район, поселок Большой Искак, Пролетарская, 5 а	f	small
60153	67876	1852	Омская область, Шербакульский район, поселок Большевасильевка, Лесная, 2	f	small
60151	67874	1850	Омская область, Шербакульский район, поселок Бабеж, Победы, 18	f	medium
60169	67886	1868	Омская область, Шербакульский район, поселок Александровское, Ленина, 33	f	large
58917	66620	589	Омская область, Черлакский район, д. Большое Озеро, Центральная, 20/1	t	small
60103	67827	1801	Омская область, Черлакский район, поселок Черлак, Транспортная, 40	f	large
60102	67826	1800	Омская область, Черлакский район, поселок Черлак, Красноармейская, 52	f	large
60105	67829	1803	Омская область, Черлакский район, поселок Черлак, Зеленая, 170	f	large
60101	67825	1799	Омская область, Черлакский район, поселок Черлак, Береговая, 13	f	small
60106	67830	1804	Омская область, Черлакский район, поселок Черлак, 4 Восточная, 38а	f	large
60108	67832	1806	Омская область, Черлакский район, поселок Черлак, 20 Лет Победы, 6	f	large
60121	67844	1819	Омская область, Черлакский район, поселок Целинное (отд. N3 свх. Красный Октябрь), Школьная, 4	f	small
60143	67867	1841	Омская область, Черлакский район, Татарское, Привокзальная, 9-2, ЖД ст. Черлак	f	small
60138	67862	1836	Омская область, Черлакский район, поселок Татарка	f	medium
60136	67860	1834	Омская область, Черлакский район, поселок Суворовка (отд. №4 свх. Коммунист), Центральная, 4	f	small
60125	67848	1823	Омская область, Черлакский район, поселок Стретенка, Школьная , 23	f	small
60132	67856	1830	Омская область, Черлакский район, поселок Соляное	f	large
60133	67857	1831	Омская область, Черлакский район, поселок Соляное, Октябрьская, 53	f	small
60135	67859	1833	Омская область, Черлакский район, поселок Северное, Центральная, 49	f	small
60112	67835	1810	Омская область, Черлакский район, поселок Путь Ленина, Транспортная, 4	f	small
60113	67836	1811	Омская область, Черлакский район, поселок Пробуждение (отд. №3 свх. Елизаветинский), Школьная, 22	f	small
60134	67858	1832	Омская область, Черлакский район, поселок Привольное (отд. №2 свх. Коммунист), Зеленая, 21	f	small
60130	67854	1828	Омская область, Черлакский район, поселок Преображенка, 1 Переулок, 4	t	small
60137	67861	1835	Омская область, Черлакский район, поселок Подлесное (отд. №5 свх. Коммунист)	f	small
60128	67851	1826	Омская область, Черлакский район, поселок Погранично-Григорьевка, Восточная, 3	t	small
60110	67833	1808	Омская область, Черлакский район, поселок Первый Шаг, Лесная, 2	f	small
60141	67865	1839	Омская область, Черлакский район, поселок Ольховка, Центральная, 8	f	small
60131	67855	1829	Омская область, Черлакский район, поселок Ольговка	f	small
60129	67852	1827	Омская область, Черлакский район, поселок Николаевка, Мельникова, 13	f	medium
60139	67863	1837	Омская область, Черлакский район, поселок Народно-Степное, еленая, 25а	f	small
60140	67864	1838	Омская область, Черлакский район, поселок Народно-Береговое, Центральная, 17	f	small
60122	67845	1820	Омская область, Черлакский район, поселок Михайловка	f	small
60126	67849	1824	Омская область, Черлакский район, поселок Медет, Школьная,, 9	f	small
60109	67737	1807	Омская область, Черлакский район, поселок Малый Атмас, Школьная, 27	f	small
60146	67869	1844	Омская область, Черлакский район, поселок Макаркино, Советская, 53	f	small
60123	67846	1821	Омская область, Черлакский район, поселок Лесная База, Российская, 9/2	f	small
60142	67866	1840	Омская область, Черлакский район, поселок Кузнецовка, Молодежная, 2	f	small
60118	67841	1816	Омская область, Черлакский район, поселок Крупское, Октябрьская, 2в	f	small
60120	67843	1818	Омская область, Черлакский район, поселок Красный Октябрь, Победы, 31	f	medium
60119	67842	1817	Омская область, Черлакский район, поселок Красный Овцевод, Школьная, 26б	f	small
60127	67850	1825	Омская область, Черлакский район, поселок Козинка, Школьная, 4	f	small
60115	67838	1813	Омская область, Черлакский район, поселок Иртыш, Ленина, 98	f	large
60147	67870	1845	Омская область, Черлакский район, поселок Золотухино, Кооперативная, 48	f	small
60111	67834	1809	Омская область, Черлакский район, поселок Елизаветинка, Центральная, 15	f	medium
60124	67847	1822	Омская область, Черлакский район, поселок Джартаргуль, Почтовая, 16	f	small
60114	67837	1812	Омская область, Черлакский район, поселок Гринск, Школьная, 26	f	small
60117	67840	1815	Омская область, Черлакский район, поселок Верхнеильинка, Мира, 38	f	small
60145	95159	1843	Омская область, Черлакский район, поселок Васьковка, Советская , 21	f	small
60116	67839	1814	Омская область, Черлакский район, поселок Бердниково, Октябрьская, 65	f	small
59121	66830	797	Омская область, Хангаласский район, село Чапаево, Зеленая, 37	f	small
60100	67823	1797	Омская область, Усть-Ишимский район, поселок Ярково, Октябрьская, 16	f	small
60087	67810	1784	Омская область, Усть-Ишимский район, поселок Южный, Магистральная, 1 А	t	small
60099	67822	1796	Омская область, Усть-Ишимский район, поселок Эбаргуль, Центральная, 6	f	small
60097	67820	1794	Омская область, Усть-Ишимский район, поселок Утускун, Советская, 33	f	small
60090	67813	1787	Омская область, Усть-Ишимский район, поселок Усть-Ишим, Школьная, 18, Общежитие ПУ-50	f	small
60094	67817	1791	Омская область, Усть-Ишимский район, поселок Усть-Ишим, Советская , 35, ДК	f	small
60091	67814	1788	Омская область, Усть-Ишимский район, поселок Усть-Ишим, Садовая , 39, АТП	f	medium
60089	67812	1786	Омская область, Усть-Ишимский район, поселок Усть-Ишим, Карбышева, 23, Лесхоз	f	small
60093	67816	1790	Омская область, Усть-Ишимский район, поселок Усть-Ишим, Горького, 1, ДНТ	f	small
60092	67815	1789	Омская область, Усть-Ишимский район, поселок Усть-Ишим, Горького, 28, ДДТ	f	small
60095	67818	1792	Омская область, Усть-Ишимский район, поселок Усть-Ишим, Агалакова , 33 А, Метеостанция	f	small
60088	67811	1785	Омская область, Усть-Ишимский район, поселок Усть-Ишим, 40 лет Октября, 107, ПУ-50	f	medium
60085	67807	1782	Омская область, Усть-Ишимский район, поселок Слободчики, Центральная, 24	f	small
60084	67806	1781	Омская область, Усть-Ишимский район, поселок Скородум, Советская, 36	f	medium
60077	67799	1774	Омская область, Усть-Ишимский район, поселок Саургачи, Школьная, 9	f	small
60083	67805	1780	Омская область, Усть-Ишимский район, поселок Паново, Центральная, 16	f	small
60081	67803	1778	Омская область, Усть-Ишимский район, поселок Орехово, Школьная, 32	f	small
60080	67802	1777	Омская область, Усть-Ишимский район, поселок Никольск, Советская, 18	f	small
59192	66896	870	Омская область, Усть-Ишимский район, поселок Никольск, Советская, 1	f	small
60073	67794	1770	Омская область, Усть-Ишимский район, поселок Малая Бича, Лесная, 17	f	medium
112574	67824	1798	Омская область, Усть-Ишимский район, поселок Летние, Центральная, 16, клуб	t	small
59623	67288	1311	Омская область, Усть-Ишимский район, поселок Красноярка, Санаторий Колос	f	medium
60072	67793	1769	Омская область, Усть-Ишимский район, поселок Кайнаул, 45	f	small
60078	67800	1775	Омская область, Усть-Ишимский район, поселок Кайлы, Школьная, 2	f	small
60098	67821	1795	Омская область, Усть-Ишимский район, поселок Ильчебага, Гаражная, 6	f	small
60107	67831	1805	Омская область, Усть-Ишимский район, поселок Затон, Колеватова, 1	f	small
60076	67798	1773	Омская область, Усть-Ишимский район, поселок Загваздино, Советская, 78	f	small
60082	67804	1779	Омская область, Усть-Ишимский район, поселок Борки, Центральная, 21	f	small
60075	67796	1772	Омская область, Усть-Ишимский район, поселок Большая Тебендя, Школьная, 1	f	small
60074	67795	1771	Омская область, Усть-Ишимский район, поселок Большая Тава, Центральная, 13	f	small
60071	67792	1768	Омская область, Усть-Ишимский район, поселок Большая Бича, Школьная, 2	f	small
60070	67791	1767	Омская область, Усть-Ишимский район, поселок Бакшеева, 46	f	small
60086	67808	1783	Омская область, Усть-Ишимский район, поселок Ашеваны, Центральная, 3	f	small
60096	67819	1793	Омская область, Усть-Ишимский район, поселок Аксёново, Советская, 33	f	small
60026	67744	1722	Омская область, Тюкалинский район, поселок Ярославка, Ленина, 32	f	small
59322	67027	1003	Омская область, Тюкалинский район, поселок Чистое, Солнечная, 26	f	small
60037	67755	1733	Омская область, Тюкалинский район, поселок Черноусово, Центральная, 25/А	f	small
60025	67743	1721	Омская область, Тюкалинский район, поселок Чащино, Центральная, 28А	f	small
60066	67787	1762	Омская область, Тюкалинский район, поселок Хутора, Школьная, 2/А	f	small
60012	67730	1708	Омская область, Тюкалинский район, Тюкалинское городское поселение, Калинина, 70/А	f	large
60017	67734	1713	Омская область, Тюкалинский район, Тюкалинск, Первомайская, 7	f	small
60016	67734	1712	Омская область, Тюкалинский район, Тюкалинск, Первомайская, 7	f	large
60019	67736	1715	Омская область, Тюкалинский район, Тюкалинск, Ленина, 41	f	small
60013	67731	1709	Омская область, Тюкалинский район, Тюкалинск, Калинина, 70/А	f	small
60018	67735	1714	Омская область, Тюкалинский район, Тюкалинск, 30 лет Победы, 34	f	large
60014	67732	1710	Омская область, Тюкалинский район, Тюкалинск, 2-ая Береговая, 2а	f	large
60015	67733	1711	Омская область, Тюкалинский район, Тюкалинск, 2-Магистральная, 3	f	medium
60021	67739	1717	Омская область, Тюкалинский район, Тюкалинск, 1-Кооперативная, 13	f	medium
60064	67784	1760	Омская область, Тюкалинский район, поселок Троицк, Школьная, 6	f	small
60058	67778	1754	Омская область, Тюкалинский район, поселок Старый Конкуль, Новая, 19	f	small
60062	67782	1758	Омская область, Тюкалинский район, поселок Старосолдатское, Советская, 8/А	f	medium
60069	67790	1765	Омская область, Тюкалинский район, поселок Соколовка, Центральная, 16/А	f	small
59059	66769	734	Омская область, Тюкалинский район, поселок Сергеевка, Сергеевский сельский клуб	f	small
60040	67759	1736	Омская область, Тюкалинский район, поселок Сарыбалы, Юбилейная, 27	t	small
60060	67780	1756	Омская область, Тюкалинский район, поселок Сажино, Центральная, 17	f	medium
60033	67751	1729	Омская область, Тюкалинский район, поселок Приозёрка, Почтовая, 4	f	small
60044	67763	1740	Омская область, Тюкалинский район, поселок Охотниково, Центральная, 19	f	small
60068	67789	1764	Омская область, Тюкалинский район, поселок Островная, Береговая, 24	f	small
60065	67786	1761	Омская область, Тюкалинский район, поселок Орлово-Кукушкино, Центральная, 7	f	small
56396	64263	91	Новосибирская область, Барабинск	f	large
60052	67772	1748	Омская область, Тюкалинский район, поселок Орловка, Центральная, 28	t	small
60059	67779	1755	Омская область, Тюкалинский район, поселок Октябрьский, Ленина, 28	f	medium
59613	67120	1301	Омская область, Тюкалинский район, поселок Октябрьский, Зеленая, 1А	f	small
60030	67748	1726	Омская область, Тюкалинский район, поселок Оброскино, Школьная, 20/А	f	small
60055	67775	1751	Омская область, Тюкалинский район, поселок Новый Кошкуль, Ленина, 18/А	f	medium
60057	67777	1753	Омская область, Тюкалинский район, поселок Новый Конкуль, Центральная, 9/А	f	small
60051	67770	1747	Омская область, Тюкалинский район, поселок Нагибино, Юбилейная, 12	f	medium
60048	67767	1744	Омская область, Тюкалинский район, поселок Малиновка, Ленина, 5	f	medium
60029	67747	1725	Омская область, Тюкалинский район, поселок Максимовка, Молодежная, 19/А	f	small
60067	67788	1763	Омская область, Тюкалинский район, поселок Луговая (Николаевка), Луговая, 1	f	small
60036	67754	1732	Омская область, Тюкалинский район, поселок Лидинка, Центральная, 2/А	f	small
60024	67742	1720	Омская область, Тюкалинский район, поселок Лаптево (Первомайский), Центральная, 10/А	f	small
60039	67757	1735	Омская область, Тюкалинский район, поселок Кумыра, Ленина, 25	f	small
60061	67781	1757	Омская область, Тюкалинский район, поселок Красный Шар, Центральная, 13	f	small
60045	67764	1741	Омская область, Тюкалинский район, поселок Красноусово, Ленина, 16	f	medium
60056	67776	1752	Омская область, Тюкалинский район, поселок Кошкуль, Центральная, 13/А	f	small
60042	67761	1738	Омская область, Тюкалинский район, поселок Коршуновка, Школьная, 2/А	f	small
60041	67760	1737	Омская область, Тюкалинский район, поселок Коршуновка, Школьная, 2/А	f	small
60035	67753	1731	Омская область, Тюкалинский район, поселок Короли, Центральная, 24	f	small
60047	67766	1743	Омская область, Тюкалинский район, поселок Климино, Центральная, 18	f	small
60050	67769	1746	Омская область, Тюкалинский район, поселок Каспиль, Заозерная, 7/А	f	small
60063	67783	1759	Омская область, Тюкалинский район, поселок Карбаиново, Школьная, 6	f	small
60038	67756	1734	Омская область, Тюкалинский район, поселок Кабырдак, Аптечная, 1	f	medium
60054	67774	1750	Омская область, Тюкалинский район, поселок Ильинка, Центральная, 19	f	small
60023	67741	1719	Омская область, Тюкалинский район, поселок Зотино, Центральная, 20/А	f	small
60049	67768	1745	Омская область, Тюкалинский район, поселок Залесная, Лесная, 22	f	small
60043	67762	1739	Омская область, Тюкалинский район, поселок Журавлёвка (Казанка), Зеленая, 15	f	small
60028	67746	1724	Омская область, Тюкалинский район, поселок Гуровка, Мира, 43а	f	small
60046	67765	1742	Омская область, Тюкалинский район, поселок Вторая Пятилетка, Центральная, 38/А	f	small
60032	67750	1728	Омская область, Тюкалинский район, поселок Восточный, Озерная, 6/А	f	small
60034	67752	1730	Омская область, Тюкалинский район, поселок Валуевка, Березовая, 3д	f	small
60031	67749	1727	Омская область, Тюкалинский район, поселок Белоглазово, Озерная, 31б	f	small
60027	67745	1723	Омская область, Тюкалинский район, поселок Бекишево, Мира, 43/А	f	small
60022	67740	1718	Омская область, Тюкалинский район, поселок Атрачи, Ленина, 32/А	f	medium
59989	67706	1684	Омская область, Тевризский район, поселок Фёдоровка, Федоровская, 20	f	small
60009	67727	1704	Омская область, Тевризский район, поселок Утьма, Победы, 26	f	small
60007	67725	1702	Омская область, Тевризский район, поселок Утузы, Советская, 57	f	small
60011	67729	1706	Омская область, Тевризский район, поселок Ураш, переулок Клубный, 1	f	small
59984	67701	1679	Омская область, Тевризский район, поселок Тевриз, Советская, 93	f	medium
59982	67699	1677	Омская область, Тевризский район, поселок Тевриз, Советская, 28	f	medium
59981	67698	1676	Омская область, Тевризский район, поселок Тевриз, Советская, 14	f	medium
59986	67703	1681	Омская область, Тевризский район, поселок Тевриз, Парковая, 2-А	f	medium
59980	67697	1675	Омская область, Тевризский район, поселок Тевриз, Павлика Морозова, 7-А	f	small
59983	67700	1678	Омская область, Тевризский район, поселок Тевриз, Максима Горького, 1	f	medium
59979	67696	1674	Омская область, Тевризский район, поселок Тевриз, Карбышева, 33	f	medium
59978	67695	1673	Омская область, Тевризский район, поселок Тевриз, Гуртьева, 51	f	medium
59977	67694	1672	Омская область, Тевризский район, поселок Тевриз, Гуртьева, 60	f	medium
59985	67702	1680	Омская область, Тевризский район, поселок Тевриз, Гагарина, 53	f	small
59992	67709	1687	Омская область, Тевризский район, поселок Ташетканы, Береговая, 36	f	small
59999	67717	1694	Омская область, Тевризский район, поселок Тайчи, Школьная, 3	f	small
60010	67728	1705	Омская область, Тевризский район, поселок Тавинск, Молодежная, 9	f	small
60002	67720	1697	Омская область, Тевризский район, поселок Поддол, Центральная, 2	f	small
60006	67724	1701	Омская область, Тевризский район, поселок Петрово, Школьная, 13	f	small
60004	67722	1699	Омская область, Тевризский район, поселок Петелино, Школьная, 2	f	small
59991	67708	1686	Омская область, Тевризский район, поселок Нагорно-Аевск, Школьная, 8	f	small
60008	67726	1703	Омская область, Тевризский район, поселок Малая Кулары, 41, Здание школы	f	small
59987	67704	1682	Омская область, Тевризский район, поселок Кускуны, Школьная, 2	f	small
60003	67721	1698	Омская область, Тевризский район, поселок Кузнецово, Гагарина, 2	f	small
60001	67719	1696	Омская область, Тевризский район, поселок Кипо-Кулары, Береговая, 14	f	small
60000	67718	1695	Омская область, Тевризский район, поселок Кип, Переулок Набережный, 2	f	small
60079	67801	1776	Омская область, Тевризский район, поселок Кайсы, Кайсинская, 8	f	small
59998	67716	1693	Омская область, Тевризский район, поселок Иванов-Мыс, Береговая, 38	f	small
59997	67715	1692	Омская область, Тевризский район, поселок Журавлёвка, Клубная, 1	f	small
59996	67714	1691	Омская область, Тевризский район, поселок Ермиловка, Северная, 42	f	small
59995	67712	1690	Омская область, Тевризский район, поселок Екатериновка, Школьная, 2	f	small
59994	67711	1689	Омская область, Тевризский район, поселок Бородинка, Школьная, 3	f	small
59993	67710	1688	Омская область, Тевризский район, поселок Белый Яр, Гагарина, 18	f	medium
59990	67707	1685	Омская область, Тевризский район, поселок Бакшеево, Зеленая, 24	f	small
60005	67723	1700	Омская область, Тевризский район, поселок Байбы, Школьная, 1	f	small
59988	67705	1683	Омская область, Тевризский район, поселок Александровка, Молодежная, 2	f	small
59970	67687	1664	Омская область, Тарский район, с.Екатерининское, поселок Большие Поля, Комсомольская, 1/1	f	small
59966	67683	1660	Омская область, Тарский район, поселок Черняево, Победы, 22	f	small
59938	67658	1632	Омская область, Тарский район, поселок Чекрушево, Первомайская, 28	f	medium
59964	67681	1658	Омская область, Тарский район, поселок Фрунзе, Коммуны, 3А	f	small
59960	67677	1654	Омская область, Тарский район, поселок Усть-Тара, Зеленая, 35	f	small
59935	67654	1629	Омская область, Тарский район, поселок Тимирка, Центральная, 23	t	small
59953	67670	1647	Омская область, Тарский район, поселок Тимино, Центральная, 8	f	small
59910	67635	1604	Омская область, Тарский район, Тара	f	medium
59905	67630	1599	Омская область, Тарский район, Тара, Школьная, 69	f	large
59904	67629	1598	Омская область, Тарский район, Тара, Чкалова, 37	f	large
59902	67627	1596	Омская область, Тарский район, Тара, Транспортная, 22	f	small
59901	67626	1595	Омская область, Тарский район, Тара, Транспортная, 19	f	large
59907	67632	1601	Омская область, Тарский район, Тара, Советская, 42	f	large
59906	67631	1600	Омская область, Тарский район, Тара, Советская, 25	f	large
59903	67628	1597	Омская область, Тарский район, Тара, Советская, 75	f	large
59916	67640	1610	Омская область, Тарский район, Тара, Сельскохозяйственная, 1	f	medium
59915	14614	1609	Омская область, Тарский район, Тара, Радищева, 17	f	large
59900	67625	1594	Омская область, Тарский район, Тара, Нерпинская, 48	f	medium
59913	67638	1607	Омская область, Тарский район, Тара, Немчиновская, 69	f	large
59914	67639	1608	Омская область, Тарский район, Тара, Лихачева, 2	f	medium
59908	67633	1602	Омская область, Тарский район, Тара, Ленина, 93	f	large
59912	67637	1606	Омская область, Тарский район, Тара, Калинина, 4	f	large
59911	67636	1605	Омская область, Тарский район, Тара, Избышева, 38	f	medium
59899	67624	1593	Омская область, Тарский район, Тара, Елецкого, 1	f	medium
59898	67623	1592	Омская область, Тарский район, Тара, Елецкого, 28	f	large
59909	67634	1603	Омская область, Тарский район, Тара, Александровская, 78	f	large
59952	67669	1646	Омская область, Тарский район, поселок Соусканово, Зеленый переулок, 5/2	f	small
59709	67427	1398	Омская область, Полтавский район, поселок Добрянка, Мира, 23 А	f	small
59973	67690	1667	Омская область, Тарский район, поселок Сидоровка, Черемуховая, 13	f	small
59944	52720	1638	Омская область, Тарский район, поселок Сеитово, Молодежная, 12	f	small
59945	67662	1639	Омская область, Тарский район, поселок Себеляково, Школьная, 13	f	small
59940	67660	1634	Омская область, Тарский район, поселок Самсоново, Комсомольская, 33	f	small
59933	67652	1627	Омская область, Тарский район, поселок Пятилетка, Интернациональная, 47	f	small
59932	67651	1626	Омская область, Тарский район, поселок Пологрудово, Советская, 10	f	medium
59925	67643	1619	Омская область, Тарский район, поселок Пихтовое, Рабочая, 9	t	small
59939	67659	1633	Омская область, Тарский район, поселок Петрово, Зеленая, 4/2	f	small
59041	66750	716	Омская область, Тарский район, поселок Петровка, Петровский сельский клуб	f	small
59923	67544	1617	Омская область, Тарский район, поселок Петровка, Таежная, 10	f	small
59946	67663	1640	Омская область, Тарский район, поселок Орлово, Блочная, 14	f	small
59974	67691	1668	Омская область, Тарский район, поселок Новоермаковка, Таежная, 39	f	small
59941	67661	1635	Омская область, Тарский район, поселок Нерпинский Кордон, 2 Кордон, 16	f	small
59975	67692	1669	Омская область, Тарский район, поселок Нагорное, Центральная, 34Б	f	small
59928	67647	1622	Омская область, Тарский район, поселок Межевная, Центральная, 7/2	t	small
59958	67675	1652	Омская область, Тарский район, поселок Междуречье, Центральная, 14	f	medium
59957	67674	1651	Омская область, Тарский район, поселок Междуречье, Советская, 49	f	small
59962	67679	1656	Омская область, Тарский район, поселок Машканка, Центральная, 24	f	small
59929	67648	1623	Омская область, Тарский район, поселок Мартюшево, Разгуляевой, 55	f	medium
59948	67665	1642	Омская область, Тарский район, поселок Лоскутово, Школьная, 1	f	small
59949	67666	1643	Омская область, Тарский район, поселок Ложниково, Тарская, 30	f	small
59922	67520	1616	Омская область, Тарский район, поселок Литковка, Лесная, 53	f	small
59927	67645	1621	Омская область, Тарский район, поселок Курляно-Дубовка, Мира, 18	f	small
59942	67471	1636	Омская область, Тарский район, поселок Крапивка, переулок Школьный, 1	f	small
59965	67682	1659	Омская область, Тарский район, поселок Коренево, Сельскохозяйственная, 27	f	small
59956	67673	1650	Омская область, Тарский район, поселок Коновалово, Центральная	f	small
59967	67684	1661	Омская область, Тарский район, поселок Кольтюгино, Хуторская, 40	f	small
59950	67667	1644	Омская область, Тарский район, поселок Кириллино, Школьная, 20	f	small
59961	67678	1655	Омская область, Тарский район, поселок Киргап, Садовая, 19	f	small
59921	51659	1615	Омская область, Тарский район, поселок Киксы, Центральная, 30/2	t	small
59943	52268	1637	Омская область, Тарский район, поселок Ишеево, Центральная, 1	f	small
59924	67620	1618	Омская область, Тарский район, поселок Имшегал, Центральная, 17	f	small
59976	67693	1670	Омская область, Тарский район, поселок Ивановка, Молодежная, 15А	f	small
59963	67680	1657	Омская область, Тарский район, поселок Заливино, Советская, 12А	f	medium
59972	67689	1666	Омская область, Тарский район, поселок Ермаковка, Центральная, 50	f	small
59969	67686	1663	Омская область, Тарский район, поселок Екатерининскоое, Советская, 64	f	large
59926	67644	1620	Омская область, Тарский район, поселок Егоровка, пер.Первый, 2	f	small
59937	67657	1631	Омская область, Тарский район, поселок Гриневичи, Школьная, 14	f	small
59955	67672	1649	Омская область, Тарский район, поселок Вставское, Свободы, 2	f	small
59954	67671	1648	Омская область, Тарский район, поселок Большие Туралы, Школьная, 14	f	medium
59947	67664	1641	Омская область, Тарский район, поселок Большие Кучки, Центральная, 14	f	small
59930	67649	1624	Омская область, Тарский район, поселок Бобровка, Центральная, 27	f	small
59931	67650	1625	Омская область, Тарский район, поселок Баженово, Центральная, 44	f	small
59936	67656	1630	Омская область, Тарский район, поселок Атирка, Восточная, 2А	f	medium
59959	67676	1653	Омская область, Тарский район, поселок Атак, Горская, 9	f	small
59859	67583	1552	Омская область, Таврический район, ст. Стрела, Тополиная, 7	f	medium
59876	67600	1569	Омская область, Таврический район, поселок Черноглазовка, Лесная, 11 Б	f	small
59153	66862	830	Омская область, Таврический район, поселок Черниговка, Здание администрации сельского поселения	f	medium
59861	67585	1554	Омская область, Таврический район, поселок Черниговка, Центральная, 21	f	small
59890	67614	1583	Омская область, Таврический район, поселок Харламово, Мира, 1 В	f	large
59875	67599	1568	Омская область, Таврический район, поселок Тихорецкое, Почтовая, 1 А	f	small
59850	67574	1543	Омская область, Таврический район, поселок Таврическое, площадь Победы, 12	f	large
59852	67576	1545	Омская область, Таврический район, поселок Таврическое, Пролетарская, 29 А	f	large
59851	67575	1544	Омская область, Таврический район, поселок Таврическое, Пролетарская, 29 А	f	large
59857	67581	1550	Омская область, Таврический район, поселок Таврическое, Пионерская, 6	f	large
59858	67582	1551	Омская область, Таврический район, поселок Таврическое, Пансионатная, 9	f	small
59855	67579	1548	Омская область, Таврический район, поселок Таврическое, Лермонтова, 65	f	large
59854	67578	1547	Омская область, Таврический район, поселок Таврическое, Ленина, 141	f	large
59853	67577	1546	Омская область, Таврический район, поселок Таврическое, Клименко, 8	f	large
59874	67598	1567	Омская область, Таврический район, поселок Таврическое, Зеленая, 6 Б, Отделение № 4	f	small
59856	67580	1549	Омская область, Таврический район, поселок Таврическое, Гагарина, 16	f	large
59886	67610	1579	Омская область, Таврический район, поселок Сосновское, Улыбина, 4	f	large
59885	67609	1578	Омская область, Таврический район, поселок Сосновское, Улыбина, 5	f	large
59880	67604	1573	Омская область, Таврический район, поселок Сосновка, Сосновка, 18 А	f	small
59867	67591	1560	Омская область, Таврический район, поселок Солоновка, Березовая, 12 Б	f	small
59889	67613	1582	Омская область, Таврический район, поселок Садовое, переулок Сосновский	f	small
59881	67605	1574	Омская область, Таврический район, поселок Пристанское, Совхозная, 2	f	large
59879	67603	1572	Омская область, Таврический район, поселок Прииртышье, Ленина, 11	f	large
59884	67608	1577	Омская область, Таврический район, поселок Победа, Зеленая, 7	f	small
59865	67589	1558	Омская область, Таврический район, поселок Пальцевка, Карбышева, 14 А	f	small
59871	67595	1564	Омская область, Таврический район, поселок Новоуральский, Школьная, 15 А	f	large
59873	67597	1566	Омская область, Таврический район, поселок Новоуральский, Майская, 3 А	f	small
59862	67586	1555	Омская область, Таврический район, поселок Новоселецк, Садовая, 21	f	small
59863	67587	1556	Омская область, Таврический район, поселок Новобелозеровка, Центральная, 23	f	small
59893	67617	1586	Омская область, Таврический район, поселок Неверовка, Пушкина, 9	f	medium
59897	67622	1590	Омская область, Таврический район, поселок Муртук, Центральная, 10	f	small
59868	67592	1561	Омская область, Таврический район, поселок Любомировка, Лизы Чайкиной, 6	f	large
59866	67590	1559	Омская область, Таврический район, поселок Луговое, Ленина, 2 А	f	large
59891	67615	1584	Омская область, Таврический район, поселок Лобково, Тупик, 2/1	f	small
59888	67612	1581	Омская область, Таврический район, поселок Лесное, Школьная, 1 А	f	small
59895	67619	1588	Омская область, Таврический район, поселок Коянбай (Куямбай), переулок Зеленый, 2	f	small
59860	67584	1553	Омская область, Таврический район, поселок Копейкино, Школьная, 23	f	small
59864	67588	1557	Омская область, Таврический район, поселок Карповка, Первомайская, 3	f	medium
59892	67616	1585	Омская область, Таврический район, поселок Камышино, Камышинская, 25	f	small
59896	67621	1589	Омская область, Таврический район, поселок Зеленополье, Школьная, 1	f	small
59877	67601	1570	Омская область, Таврический район, поселок Жатва, Энергетиков, 5 Б	f	small
59878	67602	1571	Омская область, Таврический район, поселок Жатва, Солнечная, 16 А	f	small
59887	67611	1580	Омская область, Таврический район, поселок Воронково, Одесская, 14	f	small
59869	67593	1562	Омская область, Таврический район, поселок Веселые Рощи, Центральная, 22	f	small
59870	67594	1563	Омская область, Таврический район, поселок Березовка, Центральная, 13	f	small
59882	67606	1575	Омская область, Таврический район, поселок Баландино, Школьная, 21	f	small
59883	67607	1576	Омская область, Таврический район, поселок Байдалин, Лесная, 14	t	small
59894	67618	1587	Омская область, Таврический район, поселок Андреевка, переулок Зеленый, 2	f	small
59971	67688	1665	Омская область, Сивинский район, село Екатерининское, Интернатовская, Здание БСУ СО "Дом-интернат"	f	small
59834	67558	1526	Омская область, Седельниковский район, поселок Хмелёвка, Хмелевская, 36	f	small
59838	67562	1530	Омская область, Седельниковский район, поселок Усть-Инцы, Заречная, 16	f	small
59840	67564	1532	Омская область, Седельниковский район, поселок Унара, Школьная, 1	f	small
59829	67553	1521	Омская область, Седельниковский район, поселок Тамбовка, Центральная, 42	f	small
59839	67563	1531	Омская область, Седельниковский район, поселок Сыщиково, Ишимская, 33	f	small
59846	67570	1538	Омская область, Седельниковский район, поселок Седельниково, Советская, 22	f	medium
59845	67569	1537	Омская область, Седельниковский район, поселок Седельниково, Пролетарская, 41	f	medium
59847	67571	1539	Омская область, Седельниковский район, поселок Седельниково, Кропотова, 17	f	medium
59842	67566	1534	Омская область, Седельниковский район, поселок Седельниково, Избышева, 18А	f	medium
59844	67568	1536	Омская область, Седельниковский район, поселок Седельниково, Горького, 24	f	medium
59843	67567	1535	Омская область, Седельниковский район, поселок Седельниково, Горького, 3Б	f	medium
59819	67543	1511	Омская область, Седельниковский район, поселок Саратовка, Школьная, 8	f	small
59820	67545	1512	Омская область, Седельниковский район, поселок Рагозино, Советская, 1	f	small
59821	67546	1513	Омская область, Седельниковский район, поселок Петропавловка	f	small
59836	67560	1528	Омская область, Седельниковский район, поселок Павловка, Павловская, 41, Голубовское сельское поселение	f	small
59830	67554	1522	Омская область, Седельниковский район, поселок Новоуйка, З.Максименко, 2	f	small
59826	67550	1518	Омская область, Седельниковский район, поселок Новоалександровка, Александровская, 5	f	small
59835	67559	1527	Омская область, Седельниковский район, поселок Михайловка, Михайловская, 55	f	small
59109	66817	785	Омская область, Седельниковский район, поселок Михайловка, Верхняя, 53, школа	f	small
59831	67555	1523	Омская область, Седельниковский район, поселок Лилейка, Лилейская, 27	f	small
59824	67548	1516	Омская область, Седельниковский район, поселок Лебединка, Центральная, 23	f	small
59837	67561	1529	Омская область, Седельниковский район, поселок Кукарка, Центральная, 12	f	small
59832	67556	1524	Омская область, Седельниковский район, поселок Короленка	f	small
59649	67370	1337	Омская область, Седельниковский район, поселок Короленка, Центральная, 2 Б	t	small
59823	67547	1515	Омская область, Седельниковский район, поселок Кейзес, Советская, 1	f	small
59822	67547	1514	Омская область, Седельниковский район, поселок Кейзес, Советская, 1	f	small
59818	67542	1510	Омская область, Седельниковский район, поселок Ельничное, Центральная, 4	f	small
59817	67541	1509	Омская область, Седельниковский район, поселок Елизарово	f	small
59827	67551	1519	Омская область, Седельниковский район, поселок Евлантьевка, Кропотова, 12	f	small
59849	67573	1541	Омская область, Седельниковский район, поселок Денисовка, Набережная, 9А	f	small
59833	67557	1525	Омская область, Седельниковский район, поселок Голубовка, Новая, 21	f	small
59841	67565	1533	Омская область, Седельниковский район, поселок Богомель, Зеленая, 5	f	small
59137	66847	814	Омская область, Седельниковский район, поселок Богдановка, Здание школы	f	small
59828	67552	1520	Омская область, Седельниковский район, поселок Богдановка, Озерная, 31/2	f	small
59825	67549	1517	Омская область, Седельниковский район, поселок Бакино	f	small
59919	50735	1613	Омская область, Саргатский район, с.Васисс, Кирова, 24	f	small
59810	67533	1501	Омская область, Саргатский район, поселок Щербаки, Кооперативная, 46, Администрация с/п	f	small
59786	67504	1477	Омская область, Саргатский район, поселок Черноозерье, Зеленая, 20, МОУ Черноозерская НОШ	f	small
59805	67528	1496	Омская область, Саргатский район, поселок Хохлово, Центральная, 1, МОУ Хохловская СОШ, кабинет ОБЖ	f	medium
59782	67500	1473	Омская область, Саргатский район, поселок Урусово, Заозерная, 35, Бывшая МОУ Урусовская ООШ	f	small
59814	67537	1505	Омская область, Саргатский район, поселок Увальная Бития, Подгорная, 15, Администрация с/п, фойе	f	small
59614	67132	1302	Омская область, Омский район, поселок Ключи, Березовая, 9	f	large
59797	67519	1488	Омская область, Саргатский район, поселок Тамбовка, Центральная, 4, Бывшая МОУ Тамбовская ООШ, фойе	f	small
59784	67502	1475	Омская область, Саргатский район, поселок Саргатское	f	medium
59780	67498	1471	Омская область, Саргатский район, поселок Саргатское, Худенко, 1а	f	large
59779	67497	1470	Омская область, Саргатский район, поселок Саргатское, Худенко, 67	f	medium
59777	67495	1468	Омская область, Саргатский район, поселок Саргатское, Трактовая, 38	f	large
59783	67501	1474	Омская область, Саргатский район, поселок Саргатское, Октябрьская, 12	f	medium
59793	67514	1484	Омская область, Саргатский район, поселок Преображенка, Центральная, 22А, Сельский клуб, фойе	f	small
59804	67527	1495	Омская область, Саргатский район, поселок Плоское, Центральная, 34	f	small
59398	67104	1080	Омская область, Саргатский район, поселок Павловка, Центральная , здание ФАП	f	small
59792	67513	1483	Омская область, Саргатский район, поселок Павловка, Центральная, 28б, Павловская НОШ, фойе	t	small
59809	67532	1500	Омская область, Саргатский район, поселок Орловка, Центральная, 35, Сельский клуб	f	small
59798	67521	1489	Омская область, Саргатский район, Новотроицкое, Юбилейная, 4, Сельский Дом культуры, фойе	f	small
59794	67516	1485	Омская область, Саргатский район, поселок Новопокровка, Зеленая, 15, Бывшая МОУ Новопокровская НОШ	t	small
59791	67510	1482	Омская область, Саргатский район, поселок Николаевка, Зеленая, 6, Николаевская НОШ	t	small
59795	67517	1486	Омская область, Саргатский район, поселок Нижнеиртышское, Центральная, 3, Администрация с/п, актовый зал	f	large
59790	67509	1481	Омская область, Саргатский район, поселок Михайловка, Центральная, 29В, Сельский клуб, фойе	f	small
59803	67526	1494	Омская область, Саргатский район, поселок Куртайлы, Бывшая МОУ Куртайлинская НОШ, учебный 	f	small
59788	67506	1479	Омская область, Саргатский район, поселок Красный Путь, Цветочная, 32, МОУ Краснопутинская НОШ	f	small
59808	67531	1499	Омская область, Саргатский район, поселок Карманово, Новая, 2, Бывшая МОУ Кармановская НОШ, учебный класс	f	small
59813	67536	1504	Омская область, Саргатский район, поселок Калмакуль (Чугуново), Калмакульская, 1, МОУ Калмакульская НОШ	f	small
59816	67540	1507	Омская область, Саргатский район, поселок Калачевка, Светлая, 39, ФАП, фойе	f	small
59807	67530	1498	Омская область, Саргатский район, поселок Казырлы, Центральная, 22, Сельский клуб, фойе	f	small
59806	67529	1497	Омская область, Саргатский район, поселок Интенис, Центральная, 18, Интенисская ООШ, фойе	f	small
59787	67505	1478	Омская область, Саргатский район, поселок Ивановка, Карбышева, 30, Сельский клуб, фойе	f	small
59781	67499	1472	Омская область, Саргатский район, поселок Заготзерно, Садовая, 38, ФАП	f	small
59801	67524	1492	Омская область, Саргатский район, поселок Десподзиновка, Центральная, 26, Сельский Дом культуры	f	small
59811	67534	1502	Омская область, Саргатский район, поселок Горькое, Центральная, 22	f	small
59800	67523	1491	Омская область, Саргатский район, поселок Галицыно, Центральная, 16, Бывшая МОУ Галицынская НОШ, учебный класс	f	small
59796	67518	1487	Омская область, Саргатский район, поселок Верблюжье, Почтовая, 29, Администрация с/п, актовый зал	f	medium
59799	67522	1490	Омская область, Саргатский район, поселок Большешипицыно, Центральная, 14, Бывшая МОУ Большешипицинская НОШ, учебный класс	f	small
59812	67535	1503	Омская область, Саргатский район, поселок Беспалово, Молодежная, 16	f	small
59789	67508	1480	Омская область, Саргатский район, поселок Баженово, Саргатская, 26А, Администрация с/п с. Баженово, актовый зал,	f	medium
59785	67503	1476	Омская область, Саргатский район, поселок Андреевка, 1 Мая, 2, Администрация с/п, актовый зал	f	medium
59815	67538	1506	Омская область, Саргатский район, поселок Аксеново, Центральная, 24, ФАП, фойе	t	small
59802	67525	1493	Омская область, Саргатский муниципальный район, поселок Индеры, Центральная, 17, МОУ «Индерская НОШ», фойе	f	small
59763	67480	1453	Омская область, Русско-Полянский район, поселок Черноусовка, Мартыненко, 33	f	small
59760	67477	1450	Омская область, Русско-Полянский район, поселок Цветочное, Кооперативная, 14	f	large
59765	67482	1455	Омская область, Русско-Полянский район, поселок Хлебодаровка, 25лет Совхоза, 1	f	medium
59766	67483	1456	Омская область, Русско-Полянский район, поселок Тогунас, Школьная, 15	f	small
59769	67486	1459	Омская область, Русско-Полянский район, поселок Тамчилик, Магистральная, 10	t	small
59753	67469	1443	Омская область, Русско-Полянский район, поселок Степное, Вторая, 18	f	small
59767	67484	1457	Омская область, Русско-Полянский район, поселок Степановка, Зеленая, 1	f	small
59771	67489	1461	Омская область, Русско-Полянский район, поселок Солнечное, Титова, 1	f	large
59775	67493	1465	Омская область, Русско-Полянский район, поселок Русская Поляна, Северная, 70	f	medium
59774	67492	1464	Омская область, Русско-Полянский район, поселок Русская Поляна, Ленина, 120	f	large
59751	67467	1441	Омская область, Русско-Полянский район, поселок Ротовка, Тельмана, 25	f	small
59749	67465	1439	Омская область, Русско-Полянский район, поселок Розовка, Степная, 1	f	small
59756	67473	1446	Омская область, Русско-Полянский район, поселок Пограничное, Центральная, 14	f	small
59757	67474	1447	Омская область, Русско-Полянский район, поселок Озерное, Главная, 10А	f	small
59770	67488	1460	Омская область, Русско-Полянский район, поселок Невольное, Школьная, 60	f	small
59754	67470	1444	Омская область, Русско-Полянский район, поселок Логуновка, Сибирская, 7	f	small
59762	67479	1452	Омская область, Русско-Полянский район, поселок Жуковка, Школьная, 10	f	small
59759	67476	1449	Омская область, Русско-Полянский район, поселок Добровольск, Ленина, 14в	f	medium
59750	67466	1440	Омская область, Русско-Полянский район, поселок Волотовка, Степная, 3	f	small
59758	67475	1448	Омская область, Русско-Полянский район, поселок Бузан, Школьная, 4	f	small
59747	67463	1437	Омская область, Русско-Полянский район, поселок Бас-Агаш, Молодежная, 9	f	small
59755	67472	1445	Омская область, Русско-Полянский район, поселок Алабота, Набережная, 7	f	medium
59768	67485	1458	Омская область, Русско-Полянский район, Андриановка, 60 лет Победы, 19	f	small
59714	67432	1403	Омская область, Полтавский район, поселок Щегловка, Труда, 38	f	small
59721	50611	1410	Омская область, Полтавский район, поселок Шахово, Юбилейная, 24	f	small
59730	67446	1419	Омская область, Полтавский район, поселок Шаровка, Марии Долиной, 12	f	small
59729	67445	1418	Омская область, Полтавский район, поселок Хмаровка, Центральная, 5	f	small
59720	67407	1409	Омская область, Полтавский район, поселок Увальное, Озерная, 15	f	small
59732	67448	1421	Омская область, Полтавский район, поселок Терпенье, Школьная, 4	f	small
59741	67457	1430	Омская область, Полтавский район, поселок Соловьевка, Победы, 2	f	medium
59745	67461	1434	Омская область, Полтавский район, поселок Смелое, Юбилейная, 23	f	small
59713	67431	1402	Омская область, Полтавский район, поселок Святогорск, Школьная, 27	f	small
59740	67456	1429	Омская область, Полтавский район, поселок Полтавка, Пушкина, 3	f	large
59739	67455	1428	Омская область, Полтавский район, поселок Полтавка, Победы, 28	f	large
59728	67444	1417	Омская область, Полтавский район, поселок Платово, Центральная, 3	f	small
59733	67449	1422	Омская область, Полтавский район, поселок Ольгино, Победы, 14	f	large
59744	67460	1433	Омская область, Полтавский район, поселок Ольвиополь, Школьная, 11, сельский клуб	f	small
59712	67430	1401	Омская область, Полтавский район, поселок Новотимофеевка, Горького, 28	f	small
59719	67437	1408	Омская область, Полтавский район, поселок Новосергеевка, Центральная, 19	f	small
59731	67447	1420	Омская область, Полтавский район, поселок Новоильиновка, Ленина, 5	f	medium
59737	67453	1426	Омская область, Полтавский район, поселок Никополь	f	small
59743	67459	1432	Омская область, Полтавский район, поселок Мечебилово, Центральная, 16	f	small
59742	67458	1431	Омская область, Полтавский район, поселок Лубянск, Почтовая, 1А	f	small
59736	67452	1425	Омская область, Полтавский район, поселок Крым, Школьная, 18	f	small
59718	67436	1407	Омская область, Полтавский район, поселок Краснопутиловка, Школьный переулок, 2, сельский клуб	f	small
59726	67442	1415	Омская область, Полтавский район, поселок Красногорка, Ленина, 6	f	medium
59725	67441	1414	Омская область, Полтавский район, поселок Коконовка, Школьная, 30	f	small
59724	67440	1413	Омская область, Полтавский район, поселок Каменка, Школьная, 2	f	small
59722	67438	1411	Омская область, Полтавский район, поселок Еремеевка, 50 лет Октября, 10	f	large
59708	67426	1397	Омская область, Полтавский район, поселок Длинное, Центральная, 49	f	small
59723	67439	1412	Омская область, Полтавский район, поселок Гостиловка, Центральная, 20	f	small
58919	66623	591	Омская область, Полтавский район, поселок Георгиевка, Центральная, 53 а	f	medium
59710	67428	1399	Омская область, Полтавский район, поселок Воронцовка, Ленина, 39	f	medium
59705	67423	1394	Омская область, Полтавский район, поселок Вольное, Садовая, 6	f	medium
59707	67425	1396	Омская область, Полтавский район, поселок Бородинка, Садовая, 13	f	small
59716	67434	1405	Омская область, Полтавский район, поселок Бельдеж №7, Лесная, 1	f	small
59715	67433	1404	Омская область, Полтавский район, поселок Бельдеж №3, Школьная, 3	f	small
59717	67435	1406	Омская область, Полтавский район, поселок Бельдеж №12, Ленина, 27 А	f	small
59727	67443	1416	Омская область, Полтавский район, поселок Белотурковка, Центральная, 5	f	small
59706	67424	1395	Омская область, Полтавский район, поселок Бежевка, Труда, 18	f	small
59734	67450	1423	Омская область, Полтавский район, поселок Андрюшевка, Солнечная, 7	f	small
59686	67403	1374	Омская область, Павлоградский район, поселок Ясная Поляна, Центральная, 3а	f	small
59692	67410	1380	Омская область, Павлоградский район, поселок Ярмоклеевка, Центральная, 17/2	f	small
59676	67393	1364	Омская область, Павлоградский район, поселок Явлено-Покровка, Советская, 2	f	small
59681	67398	1369	Омская область, Павлоградский район, поселок Юрьевка, Новая, 2	f	medium
59695	67413	1383	Омская область, Павлоградский район, поселок Южное, Центральная, 19	f	medium
59684	67401	1372	Омская область, Павлоградский район, поселок Хорошки, 20 Лет Победы, 13	f	medium
59701	67419	1389	Омская область, Павлоградский район, поселок Топольки, Центральная, 12	f	small
59700	67418	1388	Омская область, Павлоградский район, поселок Тихвинка, Школьная, 9	f	small
59698	67416	1386	Омская область, Павлоградский район, поселок Тихвинка, Школьная, 2	f	medium
59697	67415	1385	Омская область, Павлоградский район, поселок Степное, Школьная, 10	f	small
59689	67406	1377	Омская область, Павлоградский район, поселок Семяновка, Клубная, 2	f	small
59696	67414	1384	Омская область, Павлоградский район, поселок Раздольное, Школьная, 4	f	small
59703	67421	1391	Омская область, Павлоградский район, поселок Пашенная Роща, Центральная, 29	f	small
59674	67391	1362	Омская область, Павлоградский район, поселок Павлоградка, Пролетарская, 34а	f	large
59673	67390	1361	Омская область, Павлоградский район, поселок Павлоградка, Пролетарская, 32	f	large
59672	67389	1360	Омская область, Павлоградский район, поселок Павлоградка, Ленина, 64	f	large
59671	67388	1359	Омская область, Павлоградский район, поселок Павлоградка, Ленина, 68	f	large
59675	67392	1363	Омская область, Павлоградский район, поселок Павлоградка, Зеленая, 11	f	large
59702	67420	1390	Омская область, Павлоградский район, поселок Новоуральское, Центральная, 24	f	medium
59677	67394	1365	Омская область, Павлоградский район, поселок Назаровка, Центральная, 23	f	small
59693	67411	1381	Омская область, Павлоградский район, поселок Милоградовка	f	medium
59694	67412	1382	Омская область, Павлоградский район, поселок Милоградовка, Зеленая, 1	f	small
59688	67405	1376	Омская область, Павлоградский район, поселок Логиновка, пер.Советский, 8	f	medium
59679	67396	1367	Омская область, Павлоградский район, поселок Липов Кут, Школьная, 12	f	small
59699	67417	1387	Омская область, Павлоградский район, поселок Краснодарка, Зеленая, 26	f	small
59687	67404	1375	Омская область, Павлоградский район, поселок Кохановка, Советская, 16А	f	small
59690	67408	1378	Омская область, Павлоградский район, поселок Константиноградка, Магистральная, 15/1	f	small
59704	67422	1392	Омская область, Павлоградский район, поселок Золотухино, Колхозная, 8	f	small
59682	67399	1370	Омская область, Павлоградский район, поселок Дувановка, Центральная, 13	f	small
59685	67402	1373	Омская область, Павлоградский район, поселок Глинкино, Школьная, 19	f	small
59691	67409	1379	Омская область, Павлоградский район, поселок Божедаровка, Центральная, 10	f	small
59680	67397	1368	Омская область, Павлоградский район, поселок Богодуховка, Степная, 23	f	medium
59678	67395	1366	Омская область, Павлоградский район, поселок Бердовка, Центральная, 8/2	f	small
59683	67400	1371	Омская область, Павлоградский район, поселок Белоусовка, Центральная, 23а	f	small
59667	67384	1355	Омская область, Омский район, поселок имени Комиссарова, Музейная, 1	f	small
59643	67363	1331	Омская область, Омский район, поселок Чернолучье, 50 лет Октября, 62 А	f	small
59668	67385	1356	Омская область, Омский район, поселок Чернолучинский, Поселковая, 4 Б	f	small
59669	67386	1357	Омская область, Омский район, поселок Чернолучинский, Пионерская, 16	f	medium
59658	67379	1346	Омская область, Омский район, поселок Хвойный, Хвойная, 1 А	f	small
59616	67166	1304	Омская область, Омский район, поселок Харино, Центральная, 117 А	f	large
59652	67373	1340	Омская область, Омский район, поселок Халдеевка, Центральная, 13	f	small
59666	67383	1354	Омская область, Омский район, поселок Усть-Заостровка, Степная, 21	f	large
59606	67336	1294	Омская область, Омский район, поселок Ульяновка, Школьная, 19	f	large
59648	67368	1336	Омская область, Омский район, поселок Трусовка, Центральная, 13 Б	f	small
59664	50447	1352	Омская область, Омский район, поселок Троицкое, Октябрьская, 1 А	f	large
59670	67387	1358	Омская область, Омский район, поселок Троицкое, Бульвар Школьный, 1	f	medium
59659	67380	1347	Омская область, Омский район, поселок Розовка, Парковая, 5	f	large
59602	67331	1290	Омская область, Омский район, поселок Речной, Центральная, 7 А	f	large
59633	67351	1321	Омская область, Омский район, поселок Ребровка, Школьная, 3	f	small
59635	67354	1323	Омская область, Омский район, поселок Ракитинка, Центральная, 19 А	t	large
59629	67346	1317	Омская область, Омский район, поселок Пятилетка, Центральная, 12 Б	f	medium
59656	67377	1344	Вологодская область, Белозерский район, село Пушкино	f	large
59174	66877	852	Омская область, Омский район, поселок Пушкино, Крылова, 23	f	small
59641	67360	1329	Омская область, Омский район, поселок Путинцево, Мира	t	small
59619	67254	1307	Омская область, Омский район, поселок Покрово-Иртышское, Центральная, 59	f	small
59653	67374	1341	Омская область, Омский район, поселок Покровка, Центральная, 45 В	f	large
59657	67378	1345	Омская область, Омский район, поселок Подгородка, Зеленая, 2 В	f	medium
59646	67366	1334	Омская область, Омский район, поселок Петровка, Школьная, 11	f	large
59630	67347	1318	Омская область, Омский район, поселок Петровка, Полевая, 1	f	large
59644	67364	1332	Омская область, Омский район, поселок Омский, Ленина, 1	f	large
59642	67362	1330	Омская область, Омский район, поселок Новотроицкое, Ленина, 37	f	large
59639	67358	1327	Омская область, Омский район, поселок Новоомский, Титова, 40	f	medium
59638	67357	1326	Омская область, Омский район, поселок Новоомский, Гагарина, 1	f	large
59654	67375	1342	Омская область, Омский район, поселок Никоновка, Центральная, 21, кв. 2	f	small
59711	67429	1400	Омская область, Омский район, поселок Никоновка, Победы, 25	f	small
59603	67332	1291	Омская область, Омский район, поселок Николенко, Центральная, 13 А	f	small
59624	67341	1312	Омская область, Омский район, поселок Нижняя Ильинка, Зеленая, 73	t	small
59660	67381	1348	Омская область, Омский район, поселок Нива, Лесная, 20	f	small
59636	67355	1324	Омская область, Омский район, поселок Надеждино, Центральная, 39	f	large
59634	67352	1322	Омская область, Омский район, поселок Морозовка, 60 лет Победы, 4	f	large
59610	49611	1298	Омская область, Омский район, поселок Мельничное, Школьная, 21	f	medium
59347	67050	1028	Омская область, Омский район, поселок Лузино, Северная, 10	f	small
59628	67345	1316	Омская область, Омский район, поселок Лузино, Майорова, 12	f	large
59627	67344	1315	Омская область, Омский район, поселок Лузино, Майорова, 8	f	large
59626	67343	1314	Омская область, Омский район, поселок Лузино, Комсомольская, 19	f	large
59625	67342	1313	Омская область, Омский район, поселок Лузино, 30 лет Победы, 14	f	large
59622	49743	1310	Омская область, Омский район, поселок Красноярка, Мичурина, 58	f	large
60179	67896	1878	Омская область, Омский район, поселок Красноярка, Ленина, 32	f	medium
59620	67266	1308	Омская область, Омский район, поселок Красная Тула, Центральная, 10	t	small
59608	67338	1296	Омская область, Омский район, поселок Красная Горка, Школьная, 4 А	f	medium
59618	67218	1306	Омская область, Омский район, поселок Комсомол, Центральная, 32	f	small
59615	67132	1303	Омская область, Омский район, поселок Ключи, Березовая, 9	f	large
59655	67376	1343	Омская область, Омский район, поселок Классино, Центральная, 48, кв. 2	f	small
59650	67371	1338	Омская область, Омский район, поселок Калиновка, Гагарина, 9	f	small
59612	49729	1300	Омская область, Омский район, поселок Калинино, Советская, 2 Б	f	large
59640	67359	1328	Омская область, Омский район, поселок Калачево, Школьная, 19А	f	small
59611	49715	1299	Омская область, Омский район, поселок Иртышский, Ленина, 21	f	large
59607	67337	1295	Омская область, Омский район, поселок Дружино, Кленовая, 1 А	f	large
59651	67372	1339	Омская область, Омский район, поселок Девятириковка, Школьная, 11	f	small
59637	67356	1325	Липецкая область, Липецк, поселок Дачный, улица Дачная	f	small
59276	66983	956	Омская область, Омский район, поселок Дачный, Школьная, 8А	f	small
59609	67339	1297	Омская область, Омский район, поселок Горячий Ключ, Лесная, 3	f	large
59599	67328	1287	Омская область, Омский район, поселок Вперед, 70	f	small
59665	67382	1353	Омская область, Омский район, поселок Верхний Карбуш, Школьная, 4	f	small
59647	67367	1335	Омская область, Омский район, поселок Бородинка, Центральная, 38	f	small
59604	67333	1292	Омская область, Омский район, поселок Богословка, Ленина, 34	f	large
59645	67365	1333	Омская область, Омский район, поселок Березянка, Центральная, 9 А	f	small
59617	67179	1305	Омская область, Омский район, поселок Ачаирский, Центральная, 2	f	large
59601	67330	1289	Омская область, Омский район, поселок Ачаир, Школьная, 44	f	large
59600	67329	1288	Омская область, Омский район, поселок Андреевский, Центральная, 4	f	small
59597	14688	1285	Омская область, Омский район, поселок Андреевка, Школьная, 6	f	large
59575	67303	1262	Омская область, Оконешниковский район, поселок Язово, Школьная, 2а, здание школы	f	small
59573	67301	1260	Омская область, Оконешниковский район, поселок Чистово, Дзержинского, 49, здание администрации	f	medium
59569	67296	1256	Омская область, Оконешниковский район, поселок Стрельниково, Стрельникова, 8	f	small
59596	67326	1283	Омская область, Оконешниковский район, поселок Соловьевка, Зеленая, 5, здание клуба	f	small
59587	67316	1274	Омская область, Оконешниковский район, поселок Сергеевка, Центральная, 6, Дом культуры	f	medium
59583	67312	1270	Омская область, Оконешниковский район, поселок Рождественка, Школьная, 1, здание школы	f	small
59572	67299	1259	Омская область, Оконешниковский район, поселок Пресновка, Центральная, 2, клуб	f	small
59589	67318	1276	Омская область, Оконешниковский район, поселок Павловка, Школьная, 22, здание клуба	f	small
59578	67307	1265	Омская область, Оконешниковский район, поселок Орловка, Центральная, 15, здание клуба	t	small
59591	67320	1278	Омская область, Оконешниковский район, поселок Ольховка, Школьная, 19, здание клуба	f	small
59562	67289	1249	Омская область, Оконешниковский район, поселок Оконешниково, Пролетарская, 67, Дом культуры	f	medium
59565	67292	1252	Омская область, Оконешниковский район, поселок Оконешниково, Маяковского, 9, школа	f	medium
59566	67293	1253	Омская область, Оконешниковский район, поселок Оконешниково, Коммунистическая, 169, БУ КЦСОН	f	medium
59564	67291	1251	Омская область, Оконешниковский район, поселок Оконешниково, Коммунистическая, 87, школа №1	f	medium
59595	67325	1282	Омская область, Оконешниковский район, поселок Николаевка, Почтовая, 17, жилой дом	f	small
59568	67295	1255	Омская область, Оконешниковский район, поселок Михайловка, Школьная , 10, клуб	f	small
59584	67313	1271	Омская область, Оконешниковский район, поселок Маяк, Лесная, 5, здание администрации	f	small
59586	67315	1273	Омская область, Оконешниковский район, поселок Мариновка, Школьная, 13, здание школы	f	small
59579	67308	1266	Омская область, Оконешниковский район, поселок Любимовка, Ленина, 32, здание администрации с.п	f	medium
59577	67305	1264	Омская область, Оконешниковский район, поселок Ленинск, Первомайская, 25, здание клуба	f	small
59571	67298	1258	Омская область, Оконешниковский район, поселок Куломзино, Ленина, 23, здание администрации с.п	f	small
59576	67304	1263	Омская область, Оконешниковский район, поселок Крестики, Центральная, 16, здание администрации с.п	f	medium
59570	67297	1257	Омская область, Оконешниковский район, поселок Красовка	f	medium
59588	67317	1275	Омская область, Оконешниковский район, поселок Кочковатое, Школьная, 2	f	small
59582	67311	1269	Омская область, Оконешниковский район, поселок Костяковка, Центральная, 27, здание клуба	f	small
59581	67310	1268	Омская область, Оконешниковский район, поселок Кирилловка, Зеленая, 26, здание школы	f	small
59580	67309	1267	Омская область, Оконешниковский район, поселок Камышино, Целинная, 16А	f	small
59592	67321	1279	Омская область, Оконешниковский район, поселок Золотая Нива, Садовая, 28, здание школы	f	medium
59594	67324	1281	Омская область, Оконешниковский район, поселок Елизаветино, Центральная, 36	f	small
59590	67319	1277	Омская область, Оконешниковский район, поселок Волчино, Зеленая, 9	f	small
59593	67323	1280	Омская область, Оконешниковский район, поселок Березовка, Центральная, 36	f	small
59585	67314	1272	Омская область, Оконешниковский район, поселок Андреевка, Школьная, 8, здание клуба	f	small
59574	67302	1261	Омская область, Оконешниковский район, поселок Алексеевка, Первомайская, 22	f	small
59560	67286	1246	Омская область, Одесский район, поселок Цветково, Почтовая, 19	f	small
59556	67281	1242	Омская область, Одесский район, поселок Тишанка, Школьная, 4	f	small
59545	67270	1231	Омская область, Одесский район, поселок Славгородка, Школьная, 10	f	small
59555	67280	1241	Омская область, Одесский район, поселок Сарат, Центральная, 34	f	small
59561	67287	1247	Омская область, Одесский район, поселок Побочино, Октябрьская, 32б	f	medium
59554	67279	1240	Архангельская область, Котласский район, село Песчанка	f	small
59557	67282	1243	Омская область, Одесский район, поселок Орехово, Мира, 3а	f	medium
59544	67269	1230	Омская область, Одесский район, поселок Одесское, Ленина, 36а	f	large
59543	67268	1229	Омская область, Одесский район, поселок Одесское, Ленина, 27	f	large
59552	67277	1238	Омская область, Одесский район, поселок Лукьяновка, Центральный, 3	f	large
59550	67275	1236	Омская область, Одесский район, поселок Желанное, Ленина, 22	f	large
59559	67285	1245	Омская область, Одесский район, поселок Громогласово, Центральная, 16	f	small
59553	67278	1239	Омская область, Одесский район, поселок Генераловка, Школьный, 1	f	small
59549	67274	1235	Омская область, Одесский район, поселок Ганновка, Романенко, 4	f	medium
59548	67273	1234	Омская область, Одесский район, поселок Буняковка, Школьный, 8	f	medium
59551	67276	1237	Омская область, Одесский район, поселок Брезицк, Центральная, 9	f	small
59558	67283	1244	Омская область, Одесский район, поселок Бобровица, Бобровицкая, 21	t	small
59547	67272	1233	Омская область, Одесский район, поселок Благодаровка, Центральная, 23	f	medium
59546	67271	1232	Омская область, Одесский район, поселок Белосток, Ленина, 20	f	medium
59539	67263	1224	Омская область, Нововаршавский район, поселок Черлакское, Школьная, 13	f	medium
60176	67893	1875	Омская область, Нововаршавский район, поселок Славянка, Центральная, 60	f	small
59538	67262	1223	Омская область, Нововаршавский район, поселок Славянка, Рассохина, 30	f	large
59529	67252	1214	Омская область, Нововаршавский район, поселок Сибирское, Центральная, 1А	f	small
59535	67259	1220	Омская область, Нововаршавский район, поселок Русановка, Центральная, 14	f	medium
59526	67249	1211	Омская область, Нововаршавский район, поселок Рассохино, Береговая, 3	f	small
59530	67253	1215	Омская область, Нововаршавский район, поселок Победа, Центральная, 6	f	medium
59272	66979	952	Омская область, Нововаршавский район, поселок Победа, Новая, 2	f	small
59534	67258	1219	Омская область, Нововаршавский район, поселок Победа, Зеленая, 21	f	small
59542	67267	1227	Омская область, Нововаршавский район, поселок Платоновка, Школьная, 10-а	t	small
59541	67265	1226	Омская область, Нововаршавский район, поселок Пичугино, Школьная, 6	f	small
59527	67250	1212	Омская область, Нововаршавский район, поселок Новороссийка, Школьная, 2	f	medium
59523	67246	1208	Омская область, Нововаршавский район, поселок Новоивановка, Новоивановская, 15а	f	small
59521	67244	1206	Омская область, Нововаршавский район, поселок Нововаршавка, Школьная, 13,а	f	large
59511	67234	1196	Омская область, Нововаршавский район, поселок Нововаршавка, Красный Путь, 141	f	medium
59510	67233	1195	Омская область, Нововаршавский район, поселок Нововаршавка, Красноармейская, 3	f	medium
59509	67233	1194	Омская область, Нововаршавский район, поселок Нововаршавка, Красноармейская, 3	f	large
59508	67232	1193	Омская область, Нововаршавский район, поселок Нововаршавка, Красноармейская, 4	f	large
59525	67248	1210	Омская область, Нововаршавский район, поселок Нетесово, Гагарина, 2	f	small
59533	67257	1218	Омская область, Нововаршавский район, поселок Моисеевка, Нижняя, 17	f	small
59536	67260	1221	Омская область, Нововаршавский район, поселок Любовский, Ветеранов, 7	f	small
59537	67261	1222	Омская область, Нововаршавский район, поселок Любовка, Школьная, 8	f	small
59512	67235	1197	Омская область, Нововаршавский район, поселок Красный Яр, Мельничная, 9	f	small
59520	67243	1205	Омская область, Нововаршавский район, поселок Караман, Береговая, 20	f	small
59532	67256	1217	Омская область, Нововаршавский район, поселок Каразюк, переулок Школьный, 2	f	small
59524	67247	1209	Омская область, Нововаршавский район, поселок Изумрудное, Центральная, 3	f	small
59522	67245	1207	Омская область, Нововаршавский район, поселок Жар-Агач, Верхняя, 10	f	small
59516	67239	1201	Омская область, Нововаршавский район, поселок Ермаковка, Парковая, 5	f	medium
59531	67255	1216	Омская область, Нововаршавский район, поселок Дробышево, Центральная, 16	f	small
59515	67238	1200	Омская область, Нововаршавский район, поселок Большегривское, Ленина, 16	f	large
59514	67237	1199	Омская область, Нововаршавский район, поселок Большегривское, Гагарина, 20	f	large
59528	67251	1213	Омская область, Нововаршавский район, поселок Богдановка, Школьная, 2	f	small
59513	67236	1198	Омская область, Нововаршавский район, поселок Бобринка, Ленина, 46	f	large
59519	67242	1204	Омская область, Нововаршавский район, поселок Береговое, Победы, 30	f	small
59518	67241	1203	Омская область, Нововаршавский район, поселок Алкул, Школьная, 14	f	small
59517	67240	1202	Омская область, Нововаршавский район, поселок Александровка, Центральная, 21	f	small
59501	67225	1185	Омская область, Нижнеомский район, поселок Хутора, Молодежная, 17А	f	small
59478	67194	1162	Омская область, Нижнеомский район, поселок Хортицы, К. Маркса, 7	f	medium
59491	67211	1175	Омская область, Нижнеомский район, поселок Хомутинка, Центральная, 9А	f	small
59490	67210	1174	Омская область, Нижнеомский район, поселок Хомутинка, 70 лет Октября, 15	f	medium
59479	67195	1163	Омская область, Нижнеомский район, поселок Удачная, Советская, 12	t	small
59503	67227	1187	Омская область, Нижнеомский район, поселок Старомалиновка, Пролетарская, 10	f	medium
59487	67207	1171	Омская область, Нижнеомский район, поселок Соловецкое, Школьная, 21	f	small
59469	67180	1153	Омская область, Нижнеомский район, поселок Смирновка, Центральная, 20 В	f	small
59488	67208	1172	Омская область, Нижнеомский район, поселок Слободка (Малая Омка), Центральная, 3, здание школы	f	small
59494	67215	1178	Омская область, Нижнеомский район, поселок Сидоровка, Зеленая, 2	f	small
59492	67212	1176	Омская область, Нижнеомский район, поселок Рязанка, Новая, 13/1	f	small
59473	67187	1157	Омская область, Нижнеомский район, поселок Рождественка, Интернациональная, 17	t	small
59507	67231	1191	Омская область, Нижнеомский район, поселок Радищево, Школьная, 5	f	small
59500	67224	1184	Омская область, Нижнеомский район, поселок Пустынное, Нииз, 15	t	small
59468	67178	1152	Омская область, Нижнеомский район, поселок Пугачевка, Центральная, 18	f	small
59465	67174	1149	Омская область, Нижнеомский район, поселок Придорожное, Центральная, 6	f	small
59486	67206	1170	Омская область, Нижнеомский район, поселок Полтавка	f	small
59738	67454	1427	Омская область, Нижнеомский район, поселок Полтавка, Победы, 139	f	large
59495	67216	1179	Омская область, Нижнеомский район, поселок Покровка, Школьная, 6	t	small
59505	67229	1189	Омская область, Нижнеомский район, поселок Петропавловка, Школьная, 2	f	small
59472	67184	1156	Омская область, Нижнеомский район, поселок Паутовка, Советская, 1	t	small
59274	66981	954	Омская область, Нижнеомский район, поселок Отрадновка, Школьная, 2А	f	small
59496	67219	1180	Омская область, Нижнеомский район, поселок Отрадновка, Рабочая, 3 А	f	small
59480	67197	1164	Омская область, Нижнеомский район, поселок Озерное, Зеленая, 15	t	small
59504	67228	1188	Омская область, Нижнеомский район, поселок Новотроицк, Советская, 13	f	small
59475	67191	1159	Омская область, Нижнеомский район, поселок Новоивановка, Школьная, 2	t	small
59498	67221	1182	Омская область, Нижнеомский район, поселок Николаевка, Зеленая, 11 А	f	small
59462	67171	1146	Омская область, Нижнеомский район, поселок Нижняя Омка (Красный Восток), Юбилейная, 2	f	medium
59459	67168	1143	Омская область, Нижнеомский район, поселок Нижняя Омка (Красный Восток), Школьная, 9	f	medium
59460	67169	1144	Омская область, Нижнеомский район, поселок Нижняя Омка (Красный Восток), Транспортная, 55	f	large
59461	67170	1145	Омская область, Нижнеомский район, поселок Нижняя Омка (Красный Восток), Романенко, 38	f	small
59458	67167	1142	Омская область, Нижнеомский район, поселок Нижняя Омка (Красный Восток), Ленина, 79	f	medium
59485	67204	1169	Омская область, Нижнеомский район, поселок Медвежья Грива, Центральная, 6	t	small
59474	67188	1158	Омская область, Нижнеомский район, поселок Любимовка, Зеленая, 12	t	small
59484	67203	1168	Омская область, Нижнеомский район, поселок Локти, Центральная, 16	f	small
59483	67202	1167	Омская область, Нижнеомский район, поселок Локти, Калачинская, 10	f	small
59476	67192	1160	Омская область, Нижнеомский район, поселок Лесной, Колупаева, 13	f	small
59466	67175	1150	Омская область, Нижнеомский район, поселок Лаврино, Школьная, 3	t	small
59489	67209	1173	Омская область, Нижнеомский район, поселок Киршовка, Школьная, 13 А	f	small
59464	67173	1148	Омская область, Нижнеомский район, поселок Камышинка, Центральная, 13	f	small
59481	67199	1165	Омская область, Нижнеомский район, поселок Измайловка, Школьная, 14	t	small
59471	67183	1155	Омская область, Нижнеомский район, поселок Зенкуль, Центральная, 21	f	small
59493	67213	1177	Омская область, Нижнеомский район, поселок Еланчино, Трудовая, 18А	t	small
59482	67201	1166	Омская область, Нижнеомский район, поселок Глухониколаевка, Административный переулок, 1	f	small
59506	67230	1190	Омская область, Нижнеомский район, поселок Воскресенка, Школьная, 3	f	small
59463	67172	1147	Омская область, Нижнеомский район, поселок Вишневка, Южная, 2	f	small
59477	67193	1161	Омская область, Нижнеомский район, поселок Виноградовка, Трудовая, 19	f	small
59499	67222	1183	Омская область, Нижнеомский район, поселок Борисовка, Заовражная, 3А	f	small
59502	67226	1186	Омская область, Нижнеомский район, поселок Бещаул, Сибирская, 7	f	small
59470	67181	1154	Омская область, Нижнеомский район, поселок Ачаирка, Центральная, 22	t	small
59467	67177	1151	Омская область, Нижнеомский район, поселок Антоновка, Петра Ильичева, 15	f	medium
59421	67128	1104	Омская область, Называевский район, поселок Ястреб, Школьная, 10	f	small
59439	67147	1122	Омская область, Называевский район, поселок Черняевка, Школьная, 5	f	small
59454	67162	1137	Омская область, Называевский район, поселок Черемновка, Центральная, 25	f	small
59455	67163	1138	Омская область, Называевский район, поселок Фомиха, Центральная, 23	f	small
59450	67158	1133	Омская область, Называевский район, поселок Утичье, Школьная, 7	f	small
59424	67131	1107	Омская область, Называевский район, поселок Тупицыно, Зелёная, 21	f	small
59443	67151	1126	Омская область, Называевский район, поселок Сырьевка, Школьная, 33	f	small
59431	67139	1114	Омская область, Называевский район, поселок Сулу Терек (аул №2), Центральная, 1	f	small
59419	67126	1102	Омская область, Называевский район, поселок Староназываевка, Центральная, 11	f	small
59447	67155	1130	Омская область, Называевский район, поселок Старинка, Школьная, 31	f	small
59451	67159	1134	Омская область, Называевский район, поселок Спасск, Школьная, 1	f	small
59441	67149	1124	Омская область, Называевский район, поселок Рыбье, Южная, 19, кв. 1	f	small
59662	67300	1350	Омская область, Называевский район, поселок Ростовка, 5	f	large
59661	67300	1349	Омская область, Называевский район, поселок Ростовка, 5	f	large
59663	67300	1351	Омская область, Называевский район, поселок Ростовка, 5	f	large
59457	67165	1140	Омская область, Называевский район, поселок Ростовка, Северная, 3	f	small
59415	67122	1098	Омская область, Называевский район, поселок Редкое, Школьная, 1	f	small
59414	67121	1097	Омская область, Называевский район, поселок Путь Социализма (Путиловка), Школьная, 3	f	small
59440	67148	1123	Омская область, Называевский район, поселок Покровка, Зелёная, 38	f	small
59425	67133	1108	Омская область, Называевский район, поселок Носовка, Центральная, 31	f	small
57702	65778	1396	Новосибирская область, Искитим	f	large
59448	67156	1131	Омская область, Называевский район, поселок Новоосиново, Зеленая, 1	f	small
59418	67125	1101	Омская область, Называевский район, поселок Нововоскресенка (Ерасовка), Центральная, 11	f	small
59417	67124	1100	Омская область, Называевский район, поселок Нахимовка, Зелёная, 16	f	small
59438	67146	1121	Омская область, Называевский район, поселок Налимово, Школьная, 8	f	small
59407	67113	1090	Омская область, Называевский район, Называевск, переулок Транспортный, 23	f	medium
59405	67111	1088	Омская область, Называевский район, Называевск, Чкалова, 18	f	large
59404	67110	1087	Омская область, Называевский район, Называевск, Пролетарская, 66	f	large
59402	67108	1085	Омская область, Называевский район, Называевск, Пролетарская, 27	f	large
59403	67109	1086	Омская область, Называевский район, Называевск, Красная, 105	f	large
59401	67107	1084	Омская область, Называевский район, Называевск, Кирова, 44	f	medium
59400	67106	1083	Омская область, Называевский район, Называевск, Кирова, 21	f	large
59406	67112	1089	Омская область, Называевский район, Называевск, Вокзальная, 5	f	large
59435	67143	1118	Омская область, Называевский район, поселок Муравьевка, Колхозная, 47	f	small
59138	66848	815	Омская область, Называевский район, поселок Михайловка, Здание школы	f	medium
59951	67668	1645	Омская область, Называевский район, поселок Михайловка, Новая, 6	f	small
59445	67153	1128	Омская область, Называевский район, поселок Михайловка, Зелёная, 18	f	small
59410	67116	1093	Омская область, Называевский район, поселок Милютино, Озёрная, 2	f	small
59432	67140	1115	Омская область, Называевский район, поселок Мангут, Кирова, 10	f	medium
59430	67138	1113	Омская область, Называевский район, поселок Лорис-Меликово (Дунаевка), Ленина, 19	f	medium
59456	67164	1139	Омская область, Называевский район, поселок Лески, Зелёная, 18	t	small
59429	67137	1112	Омская область, Называевский район, поселок Лебяжье, Центральная, 14 кв. 1	f	small
59409	67115	1092	Омская область, Называевский район, Кочковатский, остановочный пункт Кочковатский, 44, кв. 2	f	small
59411	67117	1094	Омская область, Называевский район, поселок Кочковатка, Южная, 2	f	small
59434	67142	1117	Омская область, Называевский район, поселок Котино, Зелёная, 46	f	small
59453	67161	1136	Омская область, Называевский район, поселок Константиновка, Школьная, 10А	f	small
59426	67134	1109	Омская область, Называевский район, поселок Князево, Советская, 5	f	medium
59423	67130	1106	Омская область, Называевский район, поселок Кисляки, Центральная, 8	f	small
59437	67145	1120	Омская область, Называевский район, поселок Кирей (аул №1), Абая, 22	f	small
59422	67129	1105	Омская область, Называевский район, поселок Караульное, Центральная, 14	f	small
59449	67157	1132	Омская область, Называевский район, поселок Каран-Гарал, Отобая, 3	f	small
59413	67119	1096	Омская область, Называевский район, поселок Калмацкое, Центральная, 18	f	small
59427	67135	1110	Омская область, Называевский район, поселок Кабаново, Центральная, 24, кв. 1	f	small
59420	67127	1103	Омская область, Называевский район, поселок Искра, Горького, 10	f	small
59416	67123	1099	Омская область, Называевский район, поселок Жирновка, Бондаренко, 51	f	small
59428	67136	1111	Омская область, Называевский район, поселок Дурбет, Центральная, 8	f	small
59205	66909	884	Омская область, Называевский район, поселок Драгунский, Центральная, 5	f	small
59452	67160	1135	Омская область, Называевский район, поселок Драгунка, Слободская, 21	f	small
59444	67152	1127	Омская область, Называевский район, поселок Гагаринка, Центральная, 22	f	small
59433	67141	1116	Омская область, Называевский район, поселок Бузан, Озерная, 32	f	small
59412	67118	1095	Омская область, Называевский район, поселок Большепесчанка, Советская, 54	f	medium
59436	67144	1119	Омская область, Называевский район, поселок Богословка (Моховое), Центральная, д. 4, кв. 1	f	small
59408	67114	1091	Омская область, Называевский район, поселок Богодуховка, Молодёжная, 2	f	small
59442	67150	1125	Омская область, Называевский район, поселок Батареевка, Центральная, 22	f	small
59446	67154	1129	Омская область, Называевский район, поселок Байымбет (аул №6), Школьная, 31	f	small
59380	67083	1062	Омская область, Муромцевский район, поселок Юдинка, Центральная, 23	f	small
57699	65775	1393	Новосибирская область, Искитим	f	large
59377	67080	1059	Омская область, Муромцевский район, поселок Черталы, Новостройка, 2	f	small
59389	67095	1071	Омская область, Муромцевский район, поселок Ушаково, Школьная, 12	f	small
59388	67094	1070	Омская область, Муромцевский район, поселок Ушаково, Ушаковская, 31	f	small
59361	67062	1043	Омская область, Муромцевский район, поселок Тармакла, Молодежная, 185	f	small
59356	67057	1038	Омская область, Муромцевский район, поселок Танатово, Мира , 6, ФАП	f	small
59370	67071	1052	Омская область, Муромцевский район, поселок Сперановка	f	small
59390	67096	1072	Омская область, Муромцевский район, поселок Самохвалово, Центральная, 58	f	small
59385	67090	1067	Омская область, Муромцевский район, поселок Рязаны, Центральная, 50	f	small
59382	67085	1064	Омская область, Муромцевский район, поселок Поречье, Зеленая, 25б	f	small
59399	67105	1081	Омская область, Муромцевский район, поселок Плотбище, Школьная, 1	f	small
59357	67058	1039	Омская область, Муромцевский район, поселок Окунёво, Центральная, 75	f	small
59368	67069	1050	Омская область, Муромцевский район, поселок Новорождественка, Центральная, 38	f	small
59378	67081	1060	Омская область, Муромцевский район, поселок Низовое, Трактовая, 54	f	small
59374	67076	1056	Омская область, Муромцевский район, поселок Мыс, Тарская, 16	f	small
59394	67100	1076	Омская область, Муромцевский район, поселок Муромцево, Лисина, 174	f	large
59395	67101	1077	Омская область, Муромцевский район, поселок Муромцево, Ленина, 66	f	small
59392	67098	1074	Омская область, Муромцевский район, поселок Муромцево, Ленина, 144	f	large
59391	67097	1073	Омская область, Муромцевский район, поселок Муромцево, Ленина, 33	f	large
59397	67103	1079	Омская область, Муромцевский район, поселок Муромцево, Кооперативная, 29	f	large
59371	67072	1053	Омская область, Муромцевский район, поселок Моховой Привал, Юбилейная, 3	f	small
59363	67064	1045	Омская область, Муромцевский район, поселок Михайловка, Солнечная, 34	f	small
59355	67056	1037	Омская область, Муромцевский район, поселок Лисино, Центральная, 10	f	small
59376	67079	1058	Омская область, Муромцевский район, поселок Курнево, Центральная, 9	t	small
59364	67065	1046	Омская область, Муромцевский район, поселок Курганка, Береговая, 58	f	small
59367	67068	1049	Омская область, Муромцевский район, поселок Костино, 40 лет Победы, 17	f	small
59373	67074	1055	Омская область, Муромцевский район, поселок Копьево, Копьевская, 7	t	small
59360	67061	1042	Омская область, Муромцевский район, поселок Кондратьево, Ленина, 107	f	small
59358	67059	1040	Омская область, Муромцевский район, поселок Кокшенёво, улица Центральная, 61	f	small
59366	67067	1048	Омская область, Муромцевский район, поселок Качесово, Центральная, 45 г	f	small
59362	67063	1044	Омская область, Муромцевский район, поселок Карбыза, Центральная, 10	f	small
59386	67091	1068	Омская область, Муромцевский район, поселок Караклинка, Старая, 3	t	small
59365	67066	1047	Омская область, Муромцевский район, поселок Камышино-Курское, Зеленая, 1б	f	medium
59384	67089	1066	Омская область, Муромцевский район, поселок Инцисс, Молодежная, 8А	t	small
59387	67093	1069	Омская область, Муромцевский район, поселок Игоревка, Песчаная, 28	f	small
59372	67073	1054	Омская область, Муромцевский район, поселок Захаровка, Центральная, 21	f	small
59375	67077	1057	Омская область, Муромцевский район, поселок Дурново, Центральная, 6, Дом культуры	f	small
59359	67060	1041	Омская область, Муромцевский район, поселок Гурово, Центральная, 3	f	medium
59381	67084	1063	Омская область, Муромцевский район, поселок Гузенево, Центральная, 13	f	small
59369	67070	1051	Омская область, Муромцевский район, поселок Большеникольск, Центральная, 22	f	small
59379	67082	1061	Омская область, Муромцевский район, поселок Большекрасноярка, Центральная, 54, сельский клуб	f	small
59354	67055	1036	Омская область, Муромцевский район, поселок Бергамак, Центральная, 20	f	small
59352	67053	1034	Омская область, Муромцевский район, поселок Артын, Боровая, 7	f	medium
59393	67099	1075	Омская область, Муромцевский, поселок Муромцево, Нахимова, 4	f	medium
59317	67023	998	Омская область, Москаленский район, поселок Ясная Поляна, Центральная, 12	f	small
59348	48971	1029	Омская область, Москаленский район, поселок Элита, Ленина, 2	f	large
59333	67036	1014	Омская область, Москаленский район, поселок Шефер, Центральная, 13	f	small
59315	67021	996	Омская область, Москаленский район, поселок Шевченко, Центральная, 40Б	f	medium
59339	67042	1020	Омская область, Москаленский район, поселок Тумба, 8	f	small
59345	67048	1026	Омская область, Москаленский район, поселок Тумановка, Центральная, 36	f	medium
59336	67039	1017	Омская область, Москаленский район, поселок Татьяновка, Школьная, 13	f	small
59349	49494	1030	Омская область, Москаленский район, поселок Степок, Западная, 2а	f	small
59330	67033	1011	Омская область, Москаленский район, поселок Спартак, Центральная, 19	f	small
59335	67038	1016	Омская область, Москаленский район, поселок Селивановка, Школьная, 1	f	small
59350	67051	1031	Омская область, Москаленский район, поселок Северное, Центральная, 21, здание Дома культуры	f	small
60165	67809	1864	Омская область, Москаленский район, поселок Северное, Гагарина, 28	f	small
59323	67028	1004	Омская область, Москаленский район, поселок Розенталь, Центральная, 40в	f	small
59342	67045	1023	Омская область, Москаленский район, поселок Родная Долина, 40 лет Победы, 8	f	small
59351	67052	1032	Омская область, Москаленский район, поселок Помурино, Центральная, 23	f	small
59334	67037	1015	Омская область, Москаленский район, поселок Новоцарицыно, Центральная, 62	f	large
59343	67046	1024	Омская область, Москаленский район, поселок Новоалександровка, Центральная, 32	f	small
59306	67012	987	Омская область, Москаленский район, поселок Москаленки	f	large
59307	67013	988	Омская область, Москаленский район, поселок Москаленки, Пролетарская, 12	f	large
59304	67010	985	Омская область, Москаленский район, поселок Москаленки, Пионерская, 2	f	large
59320	67016	1001	Омская область, Москаленский район, поселок Москаленки, Механизаторов, 1	f	small
59310	67016	991	Омская область, Москаленский район, поселок Москаленки, Механизаторов, 1	f	large
59309	67015	990	Омская область, Москаленский район, поселок Москаленки, Комсомольская, 137	f	medium
59305	67011	986	Омская область, Москаленский район, поселок Москаленки, Комсомольская, 1	f	medium
59308	67014	989	Омская область, Москаленский район, поселок Москаленки, 1 Северная, 65	f	medium
59332	67035	1013	Омская область, Москаленский район, поселок Мироновка, Литау, 32	f	small
59344	67047	1025	Омская область, Москаленский район, поселок Миролюбовка	f	small
59327	67030	1008	Омская область, Москаленский район, поселок Майский, Мира, 1	f	small
59313	67019	994	Омская область, Москаленский район, поселок Красный Флаг, Молодежная, 14	f	small
59346	67049	1027	Омская область, Москаленский район, поселок Красное Знамя, Школьная, 2	f	medium
59321	67026	1002	Омская область, Москаленский район, поселок Корнеевка, Центральная, 11	f	small
59324	47967	1005	Омская область, Москаленский район, поселок Клаус, Центральная, 54	f	small
59338	67041	1019	Омская область, Москаленский район, поселок Кзыл-Агаш, Школьная, 12	f	small
59316	67022	997	Омская область, Москаленский район, поселок Инсарка, Центральная, 20	f	small
59331	67034	1012	Омская область, Москаленский район, поселок Ильичевка, Школьная, 2	f	medium
59314	67020	995	Омская область, Москаленский район, поселок Илеуш, Акжигита, 11	f	small
59329	67032	1010	Омская область, Москаленский район, поселок Ивановка, Школьная, 47а	f	medium
59325	48937	1006	Омская область, Москаленский район, поселок Звездино, Школьная, 2	f	medium
59337	67040	1018	Омская область, Москаленский район, поселок Жанааул, Центральная, 21	f	small
59319	67025	1000	Омская область, Москаленский район, поселок Екатериновка, Центральная, 10	f	medium
59341	67044	1022	Омская область, Москаленский район, поселок Доброе Поле, Центральная, 5	f	small
59318	67024	999	Омская область, Москаленский район, поселок Гольбштадт, Центральная, 37	f	small
59340	67043	1021	Омская область, Москаленский район, поселок Гвоздевка, Школьная, 34	f	medium
59311	67017	992	Омская область, Москаленский район, поселок Волчанка, здание сельского клуба	f	small
59326	67029	1007	Омская область, Москаленский район, поселок Веселый, Фрайгонгова, 7	f	small
59312	67018	993	Омская область, Москаленский район, поселок Алексеевка, Центральная, 50г	f	medium
59292	66998	972	Омская область, Марьяновский район, поселок Шереметьевка, переулок Школьный, 3	f	small
59279	66986	959	Омская область, Марьяновский район, поселок Чебуренки, Центральная, 5	f	small
59281	66912	961	Омская область, Марьяновский район, поселок Уютное, Школьная, 11	f	small
59282	66988	962	Омская область, Марьяновский район, поселок Усовка, Зеленая, 17	f	medium
59303	67009	983	Омская область, Марьяновский район, поселок Степное, Молодежная, 24	f	medium
59296	67002	976	Омская область, Марьяновский район, поселок Райнфельд, Зеленая, 53	f	small
59293	66999	973	Омская область, Марьяновский район, поселок Пикетное, 1-я Советская, 4А	f	medium
59300	67006	980	Омская область, Марьяновский район, поселок Петровка, Центральная, 32	f	small
59280	66987	960	Омская область, Марьяновский район, поселок Охровка, Южная, 7	f	small
59297	67003	977	Омская область, Марьяновский район, поселок Орловка, 50 лет Октября, 1	f	medium
59299	67005	979	Омская область, Марьяновский район, поселок Новая Шараповка, Молодежная, 11	f	medium
59273	66980	953	Омская область, Марьяновский район, поселок Нейдорф, Школьная, 2А	f	small
59271	66978	951	Омская область, Марьяновский район, поселок Москаленский, Мира, 1Б	f	large
59289	66995	969	Омская область, Марьяновский район, поселок Михайловка, Пономаренко, 17	f	small
59278	66985	958	Омская область, Марьяновский район, поселок Марьяновский, Школьная, 27А	f	medium
59266	66973	946	Омская область, Марьяновский район, поселок Марьяновка, Южная, 17	f	large
59270	66977	950	Омская область, Марьяновский район, поселок Марьяновка, Садовая, 1	f	large
59268	66975	948	Омская область, Марьяновский район, поселок Марьяновка, Победы, 4А	f	large
59267	66974	947	Омская область, Марьяновский район, поселок Марьяновка, Победы, 77	f	large
59269	66976	949	Омская область, Марьяновский район, поселок Марьяновка, Ленина, 12	f	large
59302	67008	982	Омская область, Марьяновский район, поселок Малая Степнинка, Центральная, 19	f	small
59275	66982	955	Омская область, Марьяновский район, поселок Лесногорский, Школьная, 5	f	small
59283	66989	963	Омская область, Марьяновский район, поселок Конезаводский, Октябрьская, 35	f	large
59285	66991	965	Омская область, Марьяновский район, поселок Кара-Терек, Школьная, 7	f	small
59295	67001	975	Омская область, Марьяновский район, поселок Имени Чапаева, Центральная, 4	f	small
59290	66996	970	Новосибирская область, Новосибирск, садовое общество "Зеленая долина"	f	small
59294	67000	974	Омская область, Марьяновский район, поселок Заря Свободы, Ленина, 59	f	medium
59277	66984	957	Омская область, Марьяновский район, поселок Домбай, Центральная, 14А	f	small
59284	66990	964	Омская область, Марьяновский район, поселок Голенки, Школьная, 14	f	small
59286	66992	966	Омская область, Марьяновский район, поселок Васильевка, Школьная, 28	f	small
59291	66997	971	Омская область, Марьяновский район, поселок Большая Роща, Школьная, 2	f	small
59288	66994	968	Омская область, Марьяновский район, поселок Боголюбовка, пер. Центральный, 10	f	medium
59298	67004	978	Омская область, Марьяновский район, поселок Березовка, Центральная, 36	f	small
59287	66993	967	Омская область, Марьяновский район, поселок Алексеевка, Новая, 24	f	small
59265	66972	944	Омская область, Любинский район, поселок Южный, Пикетинская, 19/2	f	small
59204	66908	883	Омская область, Любинский район, поселок Щучье, Центральная, 35	f	small
59249	66955	928	Омская область, Любинский район, поселок Шулаевка, Центральная, 18/2	f	small
59262	66969	941	Омская область, Любинский район, поселок Шандровка, Пролетарская, 27	f	small
59263	66970	942	Омская область, Любинский район, поселок Чулково, Колхозная, 50	f	small
59260	66967	939	Омская область, Любинский район, поселок Центрально-Любинский, Школьная, 4	f	medium
59225	66930	904	Омская область, Любинский район, поселок ХVI Партсъезд, Центральная, 17	f	small
59219	66924	898	Омская область, Любинский район, поселок Филатовка, Школьная, 29	f	small
59224	66929	903	Омская область, Любинский район, поселок Федоровка, Школьная, 21	f	small
59264	66971	943	Омская область, Любинский район, поселок Урожайный, Центральная, 45	f	small
59257	66963	936	Омская область, Любинский район, поселок Увало-Ядрино, Советская, 44	f	medium
59210	66915	889	Омская область, Любинский район, поселок Тарлык, Вторая, 21	f	small
59255	66961	934	Омская область, Любинский район, поселок Тавричанка, Молодежная, 4	f	medium
59214	66919	893	Омская область, Любинский район, поселок Субботинка, Молодёжная, 3/1	f	small
56411	64276	106	Новосибирская область, Барабинск	f	medium
59259	66965	938	Омская область, Любинский район, поселок Степановка, Здание конторы СПК Сибирь	t	small
59131	66840	808	Омская область, Любинский район, поселок Степановка, здание сельского клуба	t	small
59245	66950	924	Омская область, Любинский район, поселок Смоляновка, Школьная, 2	f	small
59253	66959	932	Омская область, Любинский район, поселок Северо-Любинский, Никифорова, 20	f	large
59252	66958	931	Омская область, Любинский район, поселок Ровная Поляна, Южная, 37	f	small
59250	66956	929	Омская область, Любинский район, поселок Протопоповка, Зеленая, 7	f	small
59247	66952	926	Омская область, Любинский район, поселок Пролетарский, Октябрьская, 6	f	small
59328	67031	1009	Омская область, Любинский район, поселок Пролетарский, Клубная, 11	f	small
59217	66922	896	Омская область, Любинский район, поселок Помогаевка, Школьная, 37	f	small
59241	66946	920	Омская область, Любинский район, поселок Политотдел (Маяк), Ленина, 32 а	f	small
59244	66949	923	Омская область, Любинский район, поселок Новокиевка, Куйбышева, 47	f	medium
59242	66947	921	Омская область, Любинский район, поселок Новоархангелка, Советская, 40	f	medium
59213	66918	892	Омская область, Любинский район, поселок Мокшино, Центральная, 18	f	small
59222	66927	901	Омская область, Любинский район, поселок Матюшино, Центральная, 40А	f	small
59232	66937	911	Омская область, Любинский район, поселок Любинский, Ремесленная, 65	f	large
59229	66934	908	Омская область, Любинский район, поселок Любинский, Почтовая, 6	f	large
59231	66936	910	Омская область, Любинский район, поселок Любинский, Победы бульвар, 10	f	medium
59236	66941	915	Омская область, Любинский район, поселок Любинский, Октябрьская, 188	f	medium
59230	66935	909	Омская область, Любинский район, поселок Любинский, Мопра, 99	f	medium
59234	66939	913	Омская область, Любинский район, поселок Любинский, Матросова, 5	f	medium
59233	66938	912	Омская область, Любинский район, поселок Любинский, Максима Горького, 102	f	large
59235	66940	914	Омская область, Любинский район, поселок Любинский, Ленина, 12	f	medium
59237	66942	916	Омская область, Любинский район, поселок Любинский, 70 Лет Октября, 11	f	medium
59238	66943	917	Омская область, Любинский район, поселок Любино-Малороссы, Старожильская, 46	f	small
59239	66944	918	Омская область, Любинский район, поселок Любино-Малороссы, Мира, 1 в	f	medium
59261	66968	940	Омская область, Любинский район, поселок Луговой, Пролетарская, 5	f	small
59226	66931	905	Омская область, Любинский район, поселок Красный Яр, улица Октябрьская, 33	f	large
59228	66933	907	Омская область, Любинский район, поселок Красный Яр, поселок Большие Поля, Первомайская, 2	f	large
59227	66932	906	Омская область, Любинский район, поселок Красный Яр, Октябрьская, 16	f	large
59251	66957	930	Омская область, Любинский район, поселок Кочки, Солнечная , 47	f	small
59240	66945	919	Омская область, Любинский район, поселок Китайлы, Западная, 9	f	small
59221	66926	900	Омская область, Любинский район, поселок Квасовка, Новая, 2 В	f	small
59212	66917	891	Омская область, Любинский район, поселок Капустино, Центральная, 16	f	small
59246	66951	925	Омская область, Любинский район, поселок Канаковка, Труда, 33	f	small
59223	66928	902	Омская область, Любинский район, поселок Камышловский, Зелёная, 2	f	large
59258	66964	937	Омская область, Любинский район, поселок Калиновка, 41, Здание досугового объекта	f	small
59220	66925	899	Омская область, Любинский район, поселок Казанка, Школьная, 2	f	medium
59215	66920	894	Омская область, Любинский район, поселок Замелетеновка, Ленина, 41	f	medium
59211	66916	890	Омская область, Любинский район, поселок Веселая Поляна, Октябрьская, 3	f	small
59256	66962	935	Омская область, Любинский район, поселок Быструха, Центральная, 36	f	small
59248	66954	927	Омская область, Любинский район, поселок Борятино, Борятинская, 10	t	small
59207	66911	886	Омская область, Любинский район, поселок Большемогильное, Школьная, 35	f	small
59209	66914	888	Омская область, Любинский район, поселок Большаковка, Центральная, 27	f	medium
59206	66910	885	Омская область, Любинский район, поселок Боголюбовка, Школьная, 28	f	medium
59216	66921	895	Омская область, Любинский район, поселок Беляевка, Центральная, 42	f	small
59254	66960	933	Омская область, Любинский район, поселок Барсуковка, Труда, 9	f	small
59218	66923	897	Омская область, Любинский район, поселок Бабайловка, Школьная, 2	f	small
59208	66913	887	Омская область, Любинский район, поселок Астрахановка, Центральная, 26	f	small
59203	66907	882	Омская область, Любинский район, поселок Алексеевка, переулок Школьный, 2	f	large
59383	67087	1065	Омская область, Любинский район, поселок Алексеевка, Центральная, 7а	t	small
58912	66614	584	Омская область, Любинский район, поселок Алексеевка, Зеленая, 7	f	small
59243	66948	922	Омская область, Любинский район, поселок Авлы, Центральная, 39	f	small
59934	67653	1628	Омская область, Крутинский район, поселок им. Максима Горького, Новая, 1	f	medium
59180	66883	858	Омская область, Крутинский район, поселок Яман, Центральная, 25А	f	medium
59187	66891	865	Омская область, Крутинский район, поселок Ширяево, Центральная, 1	f	small
59193	66897	871	Омская область, Крутинский район, поселок Шипуново, Центральная, 16	f	medium
59176	66879	854	Омская область, Крутинский район, поселок Чумановка, Зелёная, 12	f	small
59175	66878	853	Омская область, Крутинский район, поселок Чикишево, Лермонтова, 1	f	small
59197	66901	875	Омская область, Крутинский район, поселок Усть-Логатка, Заречная, 34А, д. им. М. Горького	f	small
59201	66905	879	Омская область, Крутинский район, поселок Усть-Китерма, Школьная, 1	f	small
59191	66895	869	Омская область, Крутинский район, поселок Толоконцево, Зелёная, 5	f	small
59185	66889	863	Омская область, Крутинский район, поселок Стахановка, Стахановская, 17	f	small
59195	66899	873	Омская область, Крутинский район, поселок Сингуль, Светлая, 11	f	small
59172	66875	850	Омская область, Крутинский район, поселок Самаровка, Школьная, 6	f	small
59202	66906	880	Омская область, Крутинский район, поселок Салтаим, Центральная, 27	f	small
59177	66880	855	Омская область, Крутинский район, поселок Рыжково, Зелёная, 8	f	small
59188	66892	866	Омская область, Крутинский район, поселок Паново, Зелёная, 4	f	medium
59186	66890	864	Омская область, Крутинский район, поселок Ольгино, Новая, 1	f	small
59173	66876	851	Омская область, Крутинский район, поселок Оглухино, Советская, 45	f	medium
58936	66638	608	Омская область, Крутинский район, поселок Новопокровка, Центральная, 3	f	medium
59196	66900	874	Омская область, Крутинский район, поселок Новокарасук, 50 лет Октября, 14	f	medium
59171	66874	849	Омская область, Крутинский район, поселок Новгородцево, 1, Школа	f	small
60053	67773	1749	Омская область, Крутинский район, поселок Никольск, Молодежная, 14	f	small
59164	66871	842	Омская область, Крутинский район, поселок Крутинка, переулок Больничный, 21	f	medium
59163	66870	841	Омская область, Крутинский район, поселок Крутинка, Ленина, 69	f	medium
59162	66869	840	Омская область, Крутинский район, поселок Крутинка, Ленина, 16	f	medium
59161	66869	839	Омская область, Крутинский район, поселок Крутинка, Ленина, 16	f	medium
59169	66872	847	Омская область, Крутинский район, поселок Крутинка, Красный Путь, 196	f	small
59167	14680	845	Омская область, Крутинский район, поселок Крутинка, Заречная, 10	f	small
59166	14679	844	Омская область, Крутинский район, поселок Крутинка, Вишневского, 43	f	large
59165	14679	843	Омская область, Крутинский район, поселок Крутинка, Вишневского, 43	f	medium
59189	66893	867	Омская область, Крутинский район, поселок Красный Яр, Зелёная, 24А	f	small
59182	66885	860	Омская область, Крутинский район, поселок Красный Пахарь, Набережная, 18	f	small
59198	66902	876	Омская область, Крутинский район, поселок Коломенка, Школьная, 7	f	small
59178	66881	856	Омская область, Крутинский район, поселок Колодцы, Викуловская, 16А	f	small
59200	66904	878	Омская область, Крутинский район, поселок Китерма, Ленина, 23	f	small
59190	66894	868	Омская область, Крутинский район, поселок Камчатка, Центральная, 13	f	small
59170	66873	848	Омская область, Крутинский район, поселок Калачики, Зелёная, 2	f	small
59183	66886	861	Омская область, Крутинский район, поселок Зимино, Центральная, 3	f	medium
59199	66903	877	Омская область, Крутинский район, поселок Заозёрная, Северная, 5	f	small
59184	66887	862	Омская область, Крутинский район, поселок Гуляй-Поле, Школьная, 4	t	small
59194	66898	872	Омская область, Крутинский район, поселок Горькое, Новая, 15	f	small
59179	66882	857	Омская область, Крутинский район, поселок Верхний Яман, Верх-Яманская, 15	f	small
59156	14678	833	Омская область, Кормиловский район, поселок Юрьево, Здание школы	f	medium
59139	66849	816	Омская область, Кормиловский район, поселок Фоминовка 2-я, Здание сельского клуба	f	small
59145	66854	822	Омская область, Кормиловский район, поселок Фоминовка 1-я, Здание сельского клуба	f	small
59151	14677	828	Омская область, Кормиловский район, Сыропятское ж/д ст, Здание ФАП	t	small
59150	66858	827	Омская область, Кормиловский район, поселок Сыропятское, Здание ФАП	f	small
59149	66857	826	Омская область, Кормиловский район, поселок Сыропятское, Здание дома культуры	f	medium
59155	66864	832	Омская область, Кормиловский район, поселок Станкеевка, Здание сельского клуба	f	small
59148	66856	825	Омская область, Кормиловский район, поселок Спайка, Здание сельского клуба	f	small
59143	66852	820	Омская область, Кормиловский район, поселок Салтыковка, Здание сельского клуба	f	small
59160	66868	837	Омская область, Кормиловский район, поселок Рощинский, Здание сельского клуба	f	small
59147	66855	824	Омская область, Кормиловский район, поселок Победитель, Здание школы	f	medium
59144	66853	821	Омская область, Кормиловский район, поселок Новоселье, здание школы	f	small
59133	66843	810	Омская область, Кормиловский район, поселок Новая Деревня, Здание сельского клуба	f	small
59159	66867	836	Омская область, Кормиловский район, поселок Никитино, Здание ФАП	f	small
59154	66863	831	Омская область, Кормиловский район, поселок Немировка, Здание дома культуры	f	medium
59142	66851	819	Омская область, Кормиловский район, поселок Некрасовка, Здание дома культуры	f	medium
59920	51601	1614	Омская область, Кормиловский район, поселок Михайловка, Новая, 8	f	small
59134	66844	811	Омская область, Кормиловский район, поселок Корниловка, Здание сельского клуба	f	small
59128	66837	805	Омская область, Кормиловский район, поселок Кормиловка, Юбилейная, 26	f	medium
59122	66831	799	Омская область, Кормиловский район, поселок Кормиловка, Энергетиков, 4	f	medium
59126	66835	803	Омская область, Кормиловский район, поселок Кормиловка, Ленина, 112	f	large
59124	66833	801	Омская область, Кормиловский район, поселок Кормиловка, Ленина, 22	f	medium
59123	66832	800	Омская область, Кормиловский район, поселок Кормиловка, Ленина, 37	f	large
59127	66836	804	Омская область, Кормиловский район, поселок Кормиловка, Кирова, 87	f	medium
59125	66834	802	Омская область, Кормиловский район, поселок Кормиловка, Базарный переулок, 17	f	large
59158	66866	835	Омская область, Кормиловский район, поселок Кольцово, Здание ФАП	f	small
59157	66865	834	Омская область, Кормиловский район, поселок Игнатьево, Здание ФАП	f	small
59136	66846	813	Омская область, Кормиловский район, поселок Зотино, Здание сельского клуба	f	small
59140	14611	817	Омская область, Кормиловский район, поселок Ефимовка, здание сельского клуба	f	small
59135	66845	812	Омская область, Кормиловский район, поселок Георгиевка, Здание дома культуры	f	medium
59146	14676	823	Омская область, Кормиловский район, поселок Веселый Привал (Варлаковка), Здание школы	f	small
59132	66842	809	Омская область, Кормиловский район, поселок Борки, Здание школы	f	medium
59152	66861	829	Омская область, Кормиловский район, поселок Байкал, Здание ФАП	t	small
60166	52859	1865	Омская область, Колосовский район, а. Артакшил, Ленина, 12	f	small
59120	66829	796	Омская область, Колосовский район, поселок Тоскино, Центральная, 39, сельский клуб	f	small
59119	66828	795	Омская область, Колосовский район, поселок Таскатлы, Центральная, 39, сельский дом культуры	f	small
59118	66827	794	Омская область, Колосовский район, поселок Талбакуль, Почтовая, 3, сельский дом культуры	f	small
59117	66826	793	Омская область, Колосовский район, поселок Строкино, К.Строкина, 1, сельский дом культуры	f	medium
59116	66825	792	Омская область, Колосовский район, поселок Сафоново, Саргатская, 17-А	f	small
59115	66824	791	Омская область, Колосовский район, поселок Плотниково, Рабочая, 9, ФАП	t	small
59114	66823	790	Омская область, Колосовский район, поселок Плахино, Центральная, 26	f	small
59113	66822	789	Омская область, Колосовский район, поселок Новотроицк, К. Остапова, 20, сельский клуб	f	small
59112	66821	788	Омская область, Колосовский район, поселок Новологиново, Центральная, 46, сельский дом культуры	f	small
59111	66819	787	Омская область, Колосовский район, поселок Николаевка, Николаевская, 53, детский сад	t	small
59019	66726	693	Омская область, Исилькульский район, поселок Мясники	f	small
59108	66816	784	Омская область, Колосовский район, поселок Меркутлы, Б.Зеленая, 1	f	small
59107	66814	783	Омская область, Колосовский район, поселок Ламаново, Центральная, 30-Б, сельский дом культуры	f	small
59106	66813	782	Омская область, Колосовский район, поселок Кутырлы, Советская, 30	f	medium
59105	66812	781	Омская область, Колосовский район, поселок Крайчиково, Ленина, 1, сельский дом культуры	f	small
59104	66811	780	Омская область, Колосовский район, поселок Корсино, Центральная, 9, сельский дом культуры	f	small
59102	14674	778	Омская область, Колосовский район, поселок Колосовка, Свердлова, 22	f	large
59101	66809	777	Омская область, Колосовский район, поселок Колосовка, Ленина, 7, районный дом культуры	f	large
59103	66810	779	Омская область, Колосовский район, поселок Колосовка, Кирова, 58, ПУ-55	f	large
59100	66808	776	Омская область, Колосовский район, поселок Коготово, Коготовская, 51, сельский клуб	f	small
59099	66807	775	Омская область, Колосовский район, поселок Кабурлы, Центральная, 29	f	small
59098	66806	774	Омская область, Колосовский район, поселок Зелёная (Ильинка), Хуторская, 4, начальная школа	f	small
59097	66805	773	Омская область, Колосовский район, поселок Дубрава (Николаевка), Дубравинская, 30	f	small
59096	66804	772	Омская область, Колосовский район, поселок Владимировка, Обоянская, 27 А, школа	f	small
59095	66803	771	Омская область, Колосовский район, поселок Бражниково, Луговая, 5, сельский дом культуры	f	small
59094	66802	770	Омская область, Колосовский район, поселок Аникино, Выселки, 4, школа	f	small
59093	66801	769	Омская область, Колосовский район, поселок Александровка, 2-я Заимка, 5	f	small
59066	66776	741	Омская область, Калачинский район, поселок Царицыно, Администрация Царицынского сельского поселения	f	medium
59062	66772	737	Омская область, Калачинский район, поселок Тургеневка, Тургеневский сельский клуб	f	small
59046	66755	721	Омская область, Калачинский район, поселок Таволжанка, Таволжанский сельский клуб	f	small
59073	66783	748	Омская область, Калачинский район, поселок Стеклянка, Стеклянский сельский клуб	f	small
59049	66758	724	Омская область, Калачинский район, поселок Старый Ревель, Староревельский сельский клуб	f	small
59038	66747	713	Омская область, Калачинский район, поселок Стародубка, МКОУ Воскресенская СОШ структурное подразделение ООШ	f	small
59042	66751	717	Омская область, Калачинский район, поселок Сорочино, Сорочинский ДК	f	large
59070	66780	745	Омская область, Калачинский район, поселок Семеновка, Семеновский сельский клуб	f	small
59069	66779	744	Омская область, Калачинский район, поселок Розенталь, Розентальский сельский клуб	f	small
59072	66782	747	Омская область, Калачинский район, поселок Репинка, Репинский ДК	f	medium
59064	66774	739	Омская область, Калачинский район, поселок Осокино, Осокинский ДК	f	large
59050	66759	725	Омская область, Калачинский район, поселок Орловка, ДК	f	small
59047	66756	722	Омская область, Калачинский район, поселок Новый Свет, Новосветский ДК	f	medium
59051	66760	726	Омская область, Калачинский район, поселок Новый Ревель, Новоревельский ДК	f	small
59063	66773	738	Омская область, Калачинский район, поселок Новое Село, Новосельский сельский клуб	f	small
59057	66767	732	Омская область, Калачинский район, поселок Львовка, МКОУ Львовская СОШ	f	small
59058	66768	733	Омская область, Калачинский район, поселок Лагушино, Лагушинский ДК	f	medium
59060	66770	735	Омская область, Калачинский район, поселок Куликово (Восресенского), ДК	f	large
59039	66748	714	Омская область, Калачинский район, поселок Куликово (Восресенского), Куликовский сельский клуб	f	small
59048	66757	723	Омская область, Калачинский район, поселок Крутые Луки, Крутолучинский сельский клуб	f	small
59054	66764	729	Омская область, Калачинский район, поселок Ковалево, Ковалевский ДК	f	small
59040	66749	715	Омская область, Калачинский район, поселок Кибер-Спасское, Киберспасский сельский клуб	f	small
59083	66792	758	Омская область, Калачинский район, Калачинск, Черепова, 87	f	large
59086	66795	761	Омская область, Калачинский район, Калачинск, Строительная, 3а	f	large
59090	66798	765	Омская область, Калачинский район, Калачинск, Смирнова, 42	f	large
59089	66797	764	Омская область, Калачинский район, Калачинск, Смирнова, 7	f	large
59088	66796	763	Омская область, Калачинский район, Калачинск, Смирнова, 19	f	large
59076	66786	751	Омская область, Калачинский район, Калачинск, Семашко, 23	f	large
59078	66788	753	Омская область, Калачинский район, Калачинск, Пионерская, 3	f	large
58986	66689	660	Омская область, Калачинский район, Калачинск, Первомайская, 70	f	large
59082	66791	757	Омская область, Калачинский район, Калачинск, Осминина, 48А	f	large
59080	66789	755	Омская область, Калачинский район, Калачинск, Новоселов, 1а	f	large
59079	66789	754	Омская область, Калачинский район, Калачинск, Новоселов, 1а	f	medium
59091	66799	766	Омская область, Калачинский район, Калачинск, Крупской, 132	f	large
59077	66787	752	Омская область, Калачинский район, Калачинск, Красноармейская, 27	f	large
59081	66790	756	Омская область, Калачинский район, Калачинск, Комбинатовская, 1Б	f	medium
59075	66785	750	Омская область, Калачинский район, Калачинск, Калинина, 25	f	large
59087	66677	762	Омская область, Калачинский район, Калачинск, Калинина, 62	f	large
59074	66784	749	Омская область, Калачинский район, Калачинск, Калачинская, 27	f	medium
59085	66794	760	Омская область, Калачинский район, Калачинск, Заводская, 61	f	large
59084	66793	759	Омская область, Калачинский район, Калачинск, Заводская	f	large
59056	66766	731	Омская область, Калачинский район, поселок Кабанье, Администрация Кабаньевского сельского поселения	f	medium
59065	66775	740	Омская область, Калачинский район, поселок Индейка (Березовский), Березовский ДК	f	medium
59053	66763	728	Омская область, Калачинский район, поселок Илюшкино, Лесная, 5-2	t	small
59044	66753	719	Омская область, Калачинский район, поселок Измайловка, ФАП 	f	small
59052	66761	727	Омская область, Калачинский район, поселок Ивановка, Администрация Ивановского сельского поселения	f	medium
59043	66752	718	Омская область, Калачинский район, поселок Докучаевка, Докучаевский сельский клуб	f	small
59045	66754	720	Омская область, Калачинский район, поселок Глуховка, Глуховский ДК	f	medium
59071	66781	746	Красноярский край, Рыбинский район, поселок Воскресенка	f	small
59068	66778	743	Омская область, Калачинский район, поселок Великорусское, Великорусский ДК	f	medium
59061	66771	736	Омская область, Калачинский район, поселок Архангелка, Архангельский сельский клуб	f	small
59008	66713	682	Омская область, Исилькульский район, поселок Южный, Клуб	t	small
59031	66740	705	Омская область, Исилькульский район, поселок Хутор №12, клуб	f	small
59002	66706	676	Омская область, Исилькульский район, поселок Улендыкуль, Школа	f	small
59036	66745	710	Омская область, Исилькульский район, поселок Украинка, ДК	f	large
59141	66850	818	Омская область, Исилькульский район, поселок Сосновка, Здание школы	f	medium
59029	66738	703	Омская область, Исилькульский район, поселок Солнцевка, ДК	f	large
59017	66724	691	Омская область, Исилькульский район, поселок Северный, Клуб	f	small
59005	66710	679	Омская область, Исилькульский район, поселок Северный, Контора	t	small
58984	66687	658	Омская область, Исилькульский район, поселок Северный, 36	f	large
59016	66723	690	Омская область, Исилькульский район, поселок Рославка, Школа	t	small
59012	66718	686	Омская область, Исилькульский район, поселок Пучково, Школа	f	small
59027	66735	701	Омская область, Исилькульский район, поселок Первотаровка, Клуб	f	medium
59035	66744	709	Омская область, Исилькульский район, поселок Ночка, Клуб	f	small
59024	66732	698	Омская область, Исилькульский район, поселок Новорождественка, Школа	f	medium
59003	66707	677	Омская область, Исилькульский район, поселок Новопетроград, Клуб	f	small
59021	66728	695	Омская область, Исилькульский район, поселок Новолосево, Школа	f	small
59033	66742	707	Омская область, Исилькульский район, поселок Новодонка, Школа	f	small
59014	66720	688	Омская область, Исилькульский район, поселок Николайполь, Детский сад	f	small
59032	66741	706	Омская область, Исилькульский район, поселок Мясники, Школа	f	small
59020	66727	694	Омская область, Исилькульский район, поселок Медвежье, Школа	f	medium
59013	66719	687	Омская область, Исилькульский район, поселок Маргенау, ДК	f	medium
59023	66731	697	Омская область, Исилькульский район, поселок Лукерьино, Клуб	t	small
59015	66721	689	Омская область, Исилькульский район, поселок Лесной, Школа	f	medium
59007	66712	681	Омская область, Исилькульский район, поселок Ленинский, Школа	f	small
59022	66729	696	Омская область, Исилькульский район, поселок Культжугут, Клуб	f	small
59034	66743	708	Омская область, Исилькульский район, поселок Кудряевка, ФАП	f	small
58999	66702	673	Омская область, Исилькульский район, поселок Ксеньевка, Клуб	t	small
59010	66716	684	Омская область, Исилькульский район, поселок Кромы, Школа	f	small
59001	66705	675	Омская область, Исилькульский район, поселок Красновознесенка, Клуб	f	small
59018	66725	692	Омская область, Исилькульский район, поселок Комсомольский, Школа	f	small
59009	66715	683	Омская область, Исилькульский район, поселок Каскат, Клуб	f	small
58991	66694	665	Омская область, Исилькульский район, Исилькуль, улица Строителей, 2	f	large
58983	66686	657	Омская область, Исилькульский район, Исилькуль, улица Пушкина, 32	f	large
58995	66698	669	Омская область, Исилькульский район, Исилькуль, улица Партизанская, 5	f	medium
58989	66692	663	Омская область, Исилькульский район, Исилькуль, улица Ленина, 98 А	f	large
58996	66699	670	Омская область, Исилькульский район, Исилькуль, улица Крупской, 6	f	medium
58994	66697	668	Омская область, Исилькульский район, Исилькуль, улица Деповская, 14	f	medium
58985	66688	659	Омская область, Исилькульский район, Исилькуль, Тельмана, 187	f	large
58997	66700	671	Омская область, Исилькульский район, Исилькуль, Степная, 43	f	medium
58992	66695	666	Омская область, Исилькульский район, Исилькуль, Степная, 5	f	large
58993	66696	667	Омская область, Исилькульский район, Исилькуль, Партизанская, 198	f	large
58981	66684	655	Омская область, Исилькульский район, Исилькуль, Октябрьская , 16	f	large
58988	66691	662	Омская область, Исилькульский район, Исилькуль, Ленинградская, 56	f	large
58990	66693	664	Омская область, Исилькульский район, Исилькуль, Ленина, 94	f	large
59028	66736	702	Омская область, Исилькульский район, поселок Емонтаево, частный дом	t	small
59025	66733	699	Омская область, Исилькульский район, поселок Евсюки, Клуб	f	small
59011	66717	685	Омская область, Исилькульский район, поселок Гофнунгсталь, Школа	f	small
59030	66739	704	Омская область, Исилькульский район, поселок Водяное, Клуб	f	small
59000	66704	674	Омская область, Исилькульский район, поселок Васютино, Клуб	f	small
59006	66711	680	Омская область, Исилькульский район, поселок Боровое, школа	f	small
59004	66708	678	Омская область, Исилькульский район, поселок Боевой, ДК	f	large
59067	66777	742	Омская область, Исилькульский район, поселок Благовещенка, Благовещенский сельский клуб	f	small
58998	66701	672	Омская область, Исилькульский район, поселок Баррикада, Ленина	f	medium
59026	66734	700	Омская область, Исилькульский район, поселок Аполлоновка, Школа	f	medium
58977	66680	650	Омская область, Знаменский район, поселок Шухово	f	medium
58974	66676	647	Омская область, Знаменский район, поселок Чередово, Зелёная , 17, Дом культуры	f	small
58970	66672	643	Омская область, Знаменский район, поселок Усть-Шиш, Советская, 25, Школа	f	small
58968	66670	641	Омская область, Знаменский район, поселок Усть-Тамак, Зелёная, 22Б, школа	t	small
58980	66683	653	Омская область, Знаменский район, поселок Тузаклы, Зелёная, 8, Школа	f	small
58973	66675	646	Омская область, Знаменский район, поселок Солдатка, Солдатская, 47, Школа	f	small
58971	66673	644	Омская область, Знаменский район, поселок Семёновка, Школьная, 2, Школа	f	small
58972	66674	645	Омская область, Знаменский район, поселок Пушкарёво, Школьная, 1-A, Школа	f	small
58969	66671	642	Омская область, Знаменский район, поселок Новоягодное, Школьная, 1А, школа	f	small
58976	66679	649	Омская область, Знаменский район, поселок Никольск, Центральная, 41, Школа	f	small
58963	66665	636	Омская область, Знаменский район, поселок Мамешево, Центральная, 9, Сельский клуб	f	small
58979	66682	652	Омская область, Знаменский район, поселок Малобутаково, Зелёная, 2, Школа	f	small
58975	66678	648	Омская область, Знаменский район, поселок Котовщиково, Новая, 1, Школа	t	small
58962	66664	635	Омская область, Знаменский район, поселок Копейкино, Молодежная , 16, Школа	t	small
58978	66681	651	Омская область, Знаменский район, поселок Кондрашино, Центральная, 26, Школа	f	small
58959	66660	632	Омская область, Знаменский район, поселок Киселёво, Новая , 2, Школа	f	small
58967	66669	640	Омская область, Знаменский район, поселок Качуково, Тавлетова, 26, Школа	f	small
58960	66661	633	Омская область, Знаменский район, поселок Знаменское, Новостроевская, 9, контора ЗАО Знаменский лён	f	small
58958	66659	631	Омская область, Знаменский район, поселок Знаменское, Ленина, 72, школа	f	large
58955	66656	628	Омская область, Знаменский район, поселок Знаменское, Гагарина, 15, дом детского творчества	f	large
58964	66666	637	Омская область, Знаменский район, поселок Завьялово, Школьная, 1А, средняя школа	f	medium
58961	66662	634	Омская область, Знаменский район, поселок Бутаково, Школьная, 8, Школа	f	small
58966	66668	639	Омская область, Знаменский район, поселок Авяк, Вятка , 24, Школа	f	small
59110	66818	786	Омская область, Дорогобужский район, поселок Мясники, Мясниковская, 13	f	small
59353	67054	1035	Омская область, Горьковский район, д. карташово, Центральная, 16	f	small
58954	66655	626	Омская область, Горьковский район, поселок Яковлевка, Центральная, 23 а	f	small
58953	66654	625	Омская область, Горьковский район, поселок Чучкино, переулок Зеленый, 3 а	f	small
58952	66653	624	Омская область, Горьковский район, поселок Чулино, Центральная, 15	f	small
58951	66652	623	Омская область, Горьковский район, поселок Ударный, Производственная, 5	f	small
58950	47475	622	Омская область, Горьковский район, поселок Сягаевка, Клубная, 8	f	small
58949	66651	621	Омская область, Горьковский район, поселок Сухое, Кирова, 1	f	medium
58948	66650	620	Омская область, Горьковский район, поселок Спасское, Озерная, 36	f	small
58947	66649	619	Омская область, Горьковский район, поселок Соснино, Луговая, 2	f	small
58946	66648	618	Омская область, Горьковский район, поселок Согра, Большая, 18	f	small
58945	66647	617	Омская область, Горьковский район, поселок Серебряное, Красноярова, 2 б	f	medium
58943	66645	615	Омская область, Горьковский район, поселок Саратово, Центральная, 23Б	f	small
58942	66644	614	Омская область, Горьковский район, поселок Рощино, В. Гулака, 11	f	small
58941	66643	613	Московская область, Подольск	f	small
58940	66642	612	Омская область, Горьковский район, поселок Павлодаровка (Канавка), Центральная, 39	f	medium
58939	66641	611	Омская область, Горьковский район, поселок Осиповка, Центральная, 21 а	f	small
58938	66640	610	Ростовская область, Зерноградский район, село Октябрьское	f	medium
58937	66639	609	Омская область, Горьковский район, поселок Новоюрьево, Центральная, 42	f	small
59181	66884	859	Омская область, Горьковский район, поселок Новопокровка, Центральная, 18	f	small
58935	66637	607	Омская область, Горьковский район, поселок Новооболонь, Новая, 38	f	small
58934	66636	606	Омская область, Горьковский район, поселок Максимовка, Центральная, 28	f	small
58933	66635	605	Омская область, Горьковский район, поселок Лежанка, Советская, 3 а	f	medium
58932	66634	604	Омская область, Горьковский район, поселок Крутиха, Центральная, 31	f	small
58931	66633	603	Омская область, Горьковский район, поселок Красная Поляна, Центральная, 16	f	medium
58930	66632	602	Омская область, Горьковский район, поселок Кирсаново, Центральная, 16	f	small
58929	66631	601	Омская область, Горьковский район, поселок Карасево, Школьная, 3/1	f	small
58928	66630	600	Омская область, Горьковский район, поселок Калачинская, Центральная, 2	f	small
58927	46502	599	Омская область, Горьковский район, поселок Исаковка, Новая, 22	f	small
58926	66609	598	Омская область, Горьковский район, поселок Исаевка, 2-я Малая, 1	f	small
59130	66839	807	Омская область, Горьковский район, поселок Дубровка, Здание сельского клуба	f	small
58925	66629	597	Омская область, Горьковский район, поселок Дубровка, Школьная, 1	f	small
58924	66628	596	Омская область, Горьковский район, поселок Демьяновка, Ленина, 22	f	small
58920	66624	592	Омская область, Горьковский район, поселок Горьковское, Павлика Морозова, 6	f	large
58923	66627	595	Омская область, Горьковский район, поселок Горьковское, Маяковского, 29	f	large
58922	66626	594	Омская область, Горьковский район, поселок Горьковское, Ленина, 12	f	medium
58921	66625	593	Омская область, Горьковский район, поселок Горьковское, Кирова, 18	f	large
59735	67451	1424	Омская область, Горьковский район, поселок Георгиевка, Центральная, 17	f	small
58918	66622	590	Омская область, Горьковский район, поселок Веселый, Зеленая, 4	f	small
58916	66619	588	Омская область, Горьковский район, поселок Богданово, Центральная , 38	f	small
58915	66618	587	Омская область, Горьковский район, поселок Бельсенды-Казах, Школьная, 22/1	t	small
58914	66616	586	Омская область, Горьковский район, поселок Астыровка, 30 лет Победы, 40	f	medium
58913	66615	585	Омская область, Горьковский район, поселок Алексеевский, Юбилейная, 26	f	medium
59129	66838	806	Омская область, Горьковский район, поселок Алексеевка, Здание ДДЮТ	f	medium
58911	66613	583	Омская область, Горьковский район, поселок Аксеновка, Центральная, 16	f	small
58910	66612	582	Омская область, Горьковский район, поселок Агафоновка, Новая, 4	t	small
58909	66610	580	Омская область, Большеуковский район, поселок Чернецовка, Иванова, 3	f	small
58907	66607	578	Омская область, Большеуковский район, поселок Чебаклы, Молодёжная, 22в	f	small
58908	66608	579	Омская область, Большеуковский район, поселок Чаунино, Школьная, 14а	f	small
58903	66603	574	Омская область, Большеуковский район, поселок Форпост, Ямщицкая, 8	f	small
58905	66605	576	Омская область, Большеуковский район, поселок Фирстово, Калинина, 11	f	small
58904	66604	575	Омская область, Большеуковский район, поселок Уралы, Центральная, 62	f	small
58895	66595	566	Омская область, Большеуковский район, поселок Уки, Молодёжная, 1	f	small
58901	66601	572	Омская область, Большеуковский район, поселок Становка, Школьная, 1	f	small
58894	66594	565	Омская область, Большеуковский район, поселок Решетино, Клементьева, 2	f	small
58900	66600	571	Омская область, Большеуковский район, поселок Листвяги, Школьная, 1	f	small
58902	66602	573	Омская область, Большеуковский район, поселок Коновалиха, Школьный переулок, 25	f	small
58893	66593	564	Омская область, Большеуковский район, поселок Верхние Уки, Кольцевая, 9/2	f	small
58899	66599	570	Омская область, Большеуковский район, поселок Большие Уки, Карла Маркса, 11	f	medium
58898	66598	569	Омская область, Большеуковский район, поселок Большие Уки, Калинина, 43	f	medium
58897	66597	568	Омская область, Большеуковский район, поселок Большие Уки, Избышева, 20	f	large
58896	66596	567	Омская область, Большеуковский район, поселок Белогривка, П.Сидельникова, 2	f	small
58906	66606	577	Омская область, Большеуковский район, поселок Баслы, Центральная, 25	f	small
58892	66592	563	Омская область, Большеуковский район, поселок Аёв, Березовая, 1а	f	medium
58877	66573	547	Омская область, Большереченский район, поселок Яланкуль, Школьная, 25	f	small
58864	66556	534	Омская область, Большереченский район, поселок Яготово, Южная, 3	t	small
58859	66550	529	Омская область, Большереченский район, поселок Шуево, Дорожная, 15	t	small
58889	66589	559	Омская область, Большереченский район, поселок Шипицино, Школьная, 11	f	large
58880	66576	550	Омская область, Большереченский район, поселок Черново, Центральная, 1	f	small
58868	66561	538	Омская область, Большереченский район, поселок Черналы, Приозерная, 56	f	small
58861	66552	531	Омская область, Большереченский район, поселок Чеплярово, Береговая, 67	f	small
58874	66570	544	Омская область, Большереченский район, поселок Чебаклы, Центральная, 7	f	small
58875	66571	545	Омская область, Большереченский район, поселок Уваровка, Школьная, 71	f	small
58867	66560	537	Омская область, Большереченский район, поселок Тусказань, Казанская, 78	f	small
58879	66575	549	Омская область, Большереченский район, поселок Трубчевка, Центральная, 1	f	small
58858	66548	528	Омская область, Большереченский район, поселок Терехово, Иртышская, 34	f	small
58850	66540	520	Омская область, Большереченский район, поселок Такмык, Школьная, 5А	f	small
58872	66567	542	Омская область, Большереченский район, поселок Сухокарасук, Лесная, 16	t	small
58857	66547	527	Омская область, Большереченский район, поселок Секменево, Береговая, 65	f	small
58886	66584	556	Омская область, Большереченский район, поселок Рямовка, Рязанская, 48А	t	small
58881	66578	551	Омская область, Большереченский район, поселок Русиново, Центральная, 9	t	small
58884	66582	554	Омская область, Большереченский район, поселок Ростовка, Зеленая, 17	t	small
58852	66542	522	Омская область, Большереченский район, поселок Решетниково	f	small
58862	66553	532	Омская область, Большереченский район, поселок Почекуево, Школьный переулок, 19	f	medium
58849	66539	519	Омская область, Большереченский район, поселок Осихино, Центральная, 11	f	small
58856	66546	526	Омская область, Большереченский район, поселок Новологиново, Советская, 70	f	medium
58887	66586	557	Омская область, Большереченский район, поселок Моховое Озеро, Луговая, 25а	t	small
58885	66583	555	Омская область, Большереченский район, поселок Могильно-Посельское, Чехова, 97	f	medium
58883	66580	553	Омская область, Большереченский район, поселок Милино, Победы, 25	f	small
58870	66564	540	Омская область, Большереченский район, поселок Курносово, Советов, 28	f	medium
58873	66569	543	Омская область, Большереченский район, поселок Куйгалы, Школьная, 2	t	small
58848	66538	518	Омская область, Большереченский район, поселок Криводаново, Школьная, 20	t	small
58846	66535	516	Омская область, Большереченский район, поселок Красный Яр, Советов, 6	f	large
58863	66554	533	Омская область, Большереченский район, поселок Кошкуль, Центральная, 1	f	small
58865	66557	535	Омская область, Большереченский район, поселок Коршуново, Центральная, 1	t	small
58855	66545	525	Омская область, Большереченский район, поселок Колбышево, Новая, 2б	f	small
58890	66590	560	Омская область, Большереченский район, поселок Кирсановка, Кирсановская, 32	f	small
58869	66563	539	Омская область, Большереченский район, поселок Каракуль, Лесная, 26	t	small
58882	66579	552	Омская область, Большереченский район, поселок Ингалы, Школьная, 2а	f	medium
58871	66565	541	Омская область, Большереченский район, поселок Добролюбовка, Зеленая, 10	f	small
58891	66591	561	Омская область, Большереченский район, поселок Гущино, Гущинская, 16а	f	small
58853	66543	523	Омская область, Большереченский район, поселок Ботвино, Центральная, 9	f	small
58843	66532	513	Омская область, Большереченский район, поселок Большеречье, Трудовая, 1	f	large
58840	66529	510	Омская область, Большереченский район, поселок Большеречье, О.Бронского, 4	f	medium
58838	66527	508	Омская область, Большереченский район, поселок Большеречье, Коммунистическая, 21	f	large
58839	66528	509	Омская область, Большереченский район, поселок Большеречье, Дорожная, 27	f	medium
58866	66559	536	Омская область, Большереченский район, поселок Большеречье, Гагарина, 48	f	small
58835	66524	505	Омская область, Большереченский район, поселок Большеречье, 50 лет ВЛКСМ, 28	f	large
58888	66588	558	Омская область, Большереченский район, поселок Большемурлы, Молодежная, 1б	f	small
58860	66551	530	Омская область, Большереченский район, поселок Берняжка, Береговая, 23	f	small
58876	66572	546	Омская область, Большереченский район, поселок Березовка, Школьный переулок, 1	f	small
58847	66536	517	Омская область, Большереченский район, поселок Безымянная, Центральная, 4/1	f	small
58815	66409	484	Омская область, Азовский Немецкий Национальный район, поселок Ягодное, 1 Мая, 8	f	small
58814	66382	483	Омская область, Азовский Немецкий Национальный район, поселок Южное, Школьная, 1	f	small
58833	66522	502	Омская область, Азовский Немецкий Национальный район, поселок Цветнополье, Кирова, 66	f	large
58832	66521	501	Омская область, Азовский Немецкий Национальный район, поселок Тулумбай, Березовая, 14	f	small
58818	66054	487	Омская область, Азовский Немецкий Национальный район, поселок Трубецкое, Колхозная, 34	f	medium
58828	66517	497	Омская область, Азовский Немецкий Национальный район, поселок Сосновка, Школьная , 17	f	large
58827	66516	496	Омская область, Азовский Немецкий Национальный район, поселок Сереброполье, Школьная, 37	f	small
58820	66441	489	Омская область, Азовский Немецкий Национальный район, поселок Сегизбай, Школьная, 10	f	small
58817	66035	486	Омская область, Азовский Немецкий Национальный район, поселок Руслановка, Российская, 10	f	small
58834	66523	503	Омская область, Азовский Немецкий Национальный район, поселок Розо-Долина, Центральная, 40	f	small
58825	66514	494	Омская область, Азовский Немецкий Национальный район, поселок Пришиб, Центральная, 31	f	small
58811	66510	480	Омская область, Азовский Немецкий Национальный район, поселок Привальное, Карла Маркса, 48	f	medium
58831	66520	500	Омская область, Азовский Немецкий Национальный район, поселок Поповка, Школьная, 24А	f	small
58812	66273	481	Омская область, Азовский Немецкий Национальный район, поселок Пахомовка, Центральная, 51	f	small
58830	66519	499	Омская область, Азовский Немецкий Национальный район, поселок Новинка, Ленина, 18	f	small
58829	66518	498	Омская область, Азовский Немецкий Национальный район, поселок Мирная Долина, Ворошилова, 61	f	small
58826	66515	495	Омская область, Азовский Немецкий Национальный район, поселок Кудук-Чилик, Центральная, 26	f	small
58824	66513	493	Омская область, Азовский Немецкий Национальный район, поселок Круч, Центральная, 15	f	small
58823	66512	492	Омская область, Азовский Немецкий Национальный район, поселок Кошкарево, Центральная, 17	f	small
58822	66511	491	Омская область, Азовский Немецкий Национальный район, поселок Звонарев Кут, Школьная, 44	f	medium
58821	66468	490	Омская область, Азовский Немецкий Национальный район, поселок Гуф, Школьная, 8	f	medium
58819	66127	488	Омская область, Азовский Немецкий Национальный район, поселок Березовка, Школьная, 1	f	large
58813	66314	482	Омская область, Азовский Немецкий Национальный район, поселок Бердянка, Совхозная, 11	f	small
59301	67007	981	Московская область, Серебряно-Прудский район, деревня Александровка	f	small
58816	65956	485	Омская область, Азовский Немецкий Национальный район, поселок Александровка, Советская, 39	f	medium
58809	66508	478	Омская область, Азовский Немецкий Национальный район, поселок Азово, Советская, 22А	f	medium
58810	66509	479	Омская область, Азовский Немецкий Национальный район, поселок Азово, Бульвар Дружбы, 1	f	large
58808	66507	477	Омская область, Азовский Немецкий Национальный район, поселок Азово, 40 лет Октября, 11	f	medium
58807	66506	476	Омская область, Азовский Немецкий Национальный район, поселок Азово, 1 Мая, 19	f	large
56494	64367	189	Новосибирская область, п.Каревски, Первомайская , 13	f	small
112480	65643	1268	Новосибирская область, п. Сибиряк, Центральная, 12	t	\N
57328	65349	1022	Новосибирская область, Татарск	f	small
57319	65341	1013	Новосибирская область, Татарск	f	large
57317	65339	1011	Новосибирская область, Татарск	f	medium
57316	65338	1010	Новосибирская область, Татарск	f	large
57322	65344	1016	Новосибирская область, Татарск, Школьный, 18	f	large
57325	65346	1019	Новосибирская область, Татарск, Татарская, 12 А	f	large
57321	65343	1015	Новосибирская область, Татарск, Пушкина, 93	f	large
57312	65334	1006	Новосибирская область, Татарск, Никишиной, 2а	f	small
57326	65347	1020	Новосибирская область, Татарск, Мичурина, 1	f	medium
57320	65342	1014	Новосибирская область, Татарск, Ленина, 33	f	large
57314	65336	1008	Новосибирская область, Татарск, Комиссаровская, 24	f	large
57315	65337	1009	Новосибирская область, Татарск, Интернациональная, 21	f	large
57313	65335	1007	Новосибирская область, Татарск, Зеленая , 2	f	large
57318	65340	1012	Новосибирская область, Татарск, Закриевского, 87	f	large
57324	65345	1018	Новосибирская область, Татарск, Аэродромная, 1 А	f	large
57323	65345	1017	Новосибирская область, Татарск, Аэродромная, 1 А	f	large
57327	65348	1021	Новосибирская область, Татарск, А. Матросова, 106	f	large
57741	65810	1433	Новосибирская область, Обь	f	small
57740	65809	1432	Новосибирская область, Обь	f	large
57738	65808	1430	Новосибирская область, Обь, Толмачевская средняя общеобразовательная школа №60	f	large
57730	65803	1423	Новосибирская область, Обь	f	large
57732	65805	1426	Новосибирская область, Обь, Шевченко, 11а	f	large
57733	65805	1425	Новосибирская область, Обь, Шевченко, 11а	f	large
57739	65807	1431	Новосибирская область, Обь, ЖКО Аэропорта, 25/1	f	large
57737	65807	1429	Новосибирская область, Обь, ЖКО Аэропорта, 25/1	f	large
57736	65807	1428	Новосибирская область, Обь, ЖКО Аэропорта, 25/1	f	large
57735	65806	1427	Новосибирская область, Обь, Геодезическая, 21	f	large
58213	66091	1907	Новосибирская область, Новосибирск, Октябрьский район	f	large
58058	65991	1752	Россия, Новосибирская область, Новосибирск, Ленинский район, Горский микрорайон, 7	f	large
58040	65991	1734	Россия, Новосибирская область, Новосибирск, Ленинский район, Горский микрорайон, 7	f	large
58039	65991	1733	Россия, Новосибирская область, Новосибирск, Ленинский район, Горский микрорайон, 7	f	large
58038	65991	1732	Россия, Новосибирская область, Новосибирск, Ленинский район, Горский микрорайон, 7	f	large
57986	65959	1680	Новосибирская область, Новосибирск, Кировский район, улица Немировича-Данченко	f	large
58146	66055	1840	Новосибирская область, Новосибирск, улица Ключ-Камышенское Плато, 1а	f	large
58145	66055	1839	Новосибирская область, Новосибирск, улица Ключ-Камышенское Плато, 1а	f	large
58185	66076	1879	Новосибирская область, Новосибирск, улица Кирова	f	large
58215	66093	1909	Новосибирская область, Октябрьский район, Новосибирск, улица Гусинобродский Тракт, 39	f	medium
57768	65831	1462	Россия, Новосибирская область, Новосибирск, Дзержинский район, улица Гоголя, 217	f	large
58208	66088	1902	Новосибирская область, Новосибирск, улица Владимира Высоцкого, 1	f	large
58207	66088	1901	Новосибирская область, Новосибирск, улица Владимира Высоцкого, 1	f	large
58109	66029	1803	Новосибирская область, Новосибирск, улица 9-й Гвардейской Дивизии, 6	f	large
58104	66029	1798	Новосибирская область, Новосибирск, улица 9-й Гвардейской Дивизии, 6	f	large
58103	66029	1797	Новосибирская область, Новосибирск, улица 9-й Гвардейской Дивизии, 6	f	large
58044	65995	1738	Россия, Новосибирская область, Новосибирск, проспект Карла Маркса, 31	f	large
58043	65994	1737	Россия, Новосибирская область, Новосибирск, проспект Карла Маркса, 31	f	large
58041	65992	1735	Россия, Новосибирская область, Новосибирск, проспект Карла Маркса, 35/1	f	large
57824	65856	1518	Россия, Новосибирская область, Новосибирск, проспект Димитрова, 4	f	large
57908	94866	1537	Новосибирская область, Новосибирск, проспект Димитрова, 144	f	medium
57765	94864	1459	Новосибирская область, Новосибирск, проспект Дзержинского, 34/1	f	large
57790	94864	1484	Новосибирская область, Новосибирск, проспект Дзержинского, 34/1	f	large
57764	94864	1458	Новосибирская область, Новосибирск, проспект Дзержинского, 34/1	f	large
57791	65842	1485	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 79	f	large
57794	65841	1488	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 60	f	large
57789	65841	1483	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 60	f	large
57788	65841	1482	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 60	f	large
57787	65840	1481	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 43	f	large
57786	65840	1480	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 43	f	large
57777	65836	1471	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 1	f	large
57767	65830	1461	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 26	f	large
57766	65830	1460	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 26	f	medium
57763	65828	1457	Россия, Новосибирская область, Новосибирск, проспект Дзержинского, 83	f	large
58161	66063	1855	Новосибирская область, Новосибирск, Якушева, 21	f	large
58333	66178	2027	Новосибирская область, Новосибирск, Ядринцевская , 46	f	large
58255	66122	1949	Новосибирская область, Новосибирск, Энгельса, 6	f	large
58254	66122	1948	Новосибирская область, Новосибирск, Энгельса, 6	f	large
58252	66122	1946	Новосибирская область, Новосибирск, Энгельса, 6	f	large
58303	66152	1997	Новосибирская область, Новосибирск, Экваторная , 5	f	large
58302	66152	1996	Новосибирская область, Новосибирск, Экваторная , 5	f	large
58301	66152	1995	Новосибирская область, Новосибирск, Экваторная , 5	f	large
58300	66152	1994	Новосибирская область, Новосибирск, Экваторная , 5	f	large
58223	66100	1917	Новосибирская область, Новосибирск, Эйхе, 1	f	large
58229	66104	1923	Новосибирская область, Новосибирск, Шмидта, 3	f	large
56419	64283	113	Новосибирская область, Новосибирск, Школьная, 9	f	medium
58053	66000	1747	Россия, Новосибирская область, Новосибирск, Чулымская улица, 114	f	large
57998	65968	1692	Новосибирская область, Новосибирск, Чигорина, 8	f	large
57997	65968	1691	Новосибирская область, Новосибирск, Чигорина, 8	f	large
57996	65968	1690	Новосибирская область, Новосибирск, Чигорина, 8	f	large
58178	66073	1872	Новосибирская область, Новосибирск, Чехова, 271	f	large
58177	66073	1871	Новосибирская область, Новосибирск, Чехова, 271	f	large
58006	65971	1700	Новосибирская область, Новосибирск, Чемская, 38	f	large
58005	65971	1699	Новосибирская область, Новосибирск, Чемская, 38	f	large
58004	65971	1698	Новосибирская область, Новосибирск, Чемская, 38	f	large
58336	66181	2030	Новосибирская область, Новосибирск, Чаплыгина, 59	f	large
57448	94826	1141	Россия, Новосибирская область, Новосибирск, Центральная улица, 2	f	small
56685	64596	382	Новосибирская область, Каргатский район, Центральная , 24	f	small
56343	64190	37	Россия, Московская область, городской округ Лосино-Петровский, деревня Осеево, Центральная улица, 1	f	small
57212	65201	906	Новосибирская область, Новосибирск, Центральная, 14	f	small
56413	64277	107	Новосибирская область, Новосибирск, Центральная, 27, Варламовский сельсовет	f	small
58092	66025	1786	Новосибирская область, Новосибирск, Хилокская , 4	f	large
58086	66019	1780	Новосибирская область, Новосибирск, Халтурина, 30/1	f	large
58335	66180	2029	Новосибирская область, Новосибирск, Фрунзе, 5/2	f	large
58319	66165	2013	Новосибирская область, Новосибирск, Фрунзе, 57А	f	large
58311	66159	2005	Новосибирская область, Новосибирск, Фрунзе, 53	f	large
58306	66155	2000	Новосибирская область, Новосибирск, Фрунзе, 96	f	large
57970	65941	1662	Новосибирская область, Новосибирск, Флотская, 21А	f	large
58073	66011	1767	Новосибирская область, Новосибирск, Филатова, 9	f	large
58227	66102	1921	Новосибирская область, Новосибирск, Физкультурная , 16А	f	large
58226	66102	1920	Новосибирская область, Новосибирск, Физкультурная , 16А	f	large
58193	66079	1887	Новосибирская область, Новосибирск, Федосеева, 38	f	large
58192	66079	1886	Новосибирская область, Новосибирск, Федосеева, 38	f	large
58191	66079	1885	Новосибирская область, Новосибирск, Федосеева, 38	f	large
58190	66079	1884	Новосибирская область, Новосибирск, Федосеева, 38	f	large
57843	65853	1515	Новосибирская область, Новосибирск, Фабричная , 8	f	large
57933	65924	1624	Новосибирская область, Новосибирск, Учительская, 42	f	large
57932	65924	1623	Новосибирская область, Новосибирск, Учительская, 42	f	large
58299	66151	1993	Новосибирская область, Новосибирск, Ученых, 10	f	large
58247	66118	1941	Новосибирская область, Новосибирск, Ученическая , 8	f	large
58246	66118	1940	Новосибирская область, Новосибирск, Ученическая , 8	f	large
57995	65967	1689	Новосибирская область, Новосибирск, Урманова, 26	f	large
58242	66115	1936	Новосибирская область, Новосибирск, Узорная, 1/2	f	large
58241	66115	1935	Новосибирская область, Новосибирск, Узорная, 1/2	f	large
58140	66049	1834	Новосибирская область, Новосибирск, Ударная , 21	f	large
58139	66049	1833	Новосибирская область, Новосибирск, Ударная , 21	f	large
58138	66049	1832	Новосибирская область, Новосибирск, Ударная , 21	f	large
58182	66074	1876	Новосибирская область, Новосибирск, Тургенева, 202	f	large
58181	66074	1875	Новосибирская область, Новосибирск, Тургенева, 202	f	large
58180	66074	1874	Новосибирская область, Новосибирск, Тургенева, 202	f	large
58179	66074	1873	Новосибирская область, Новосибирск, Тургенева, 202	f	large
58170	66068	1864	Новосибирская область, Новосибирск, Тургенева, 84	f	large
57987	65960	1681	Новосибирская область, Новосибирск, Тульская , 86	f	large
58286	66144	1980	Новосибирская область, Новосибирск, Тружеников, 16а	f	large
58285	66144	1979	Новосибирская область, Новосибирск, Тружеников, 16а	f	large
58189	66078	1883	Новосибирская область, Новосибирск, Тополевая, 31	f	large
58188	66078	1882	Новосибирская область, Новосибирск, Тополевая, 31	f	large
58119	66037	1813	Новосибирская область, Новосибирск, Титова, 7	f	large
58095	66026	1789	Новосибирская область, Новосибирск, Титова, 94	f	large
58094	66026	1788	Новосибирская область, Новосибирск, Титова, 94	f	large
58093	66026	1787	Новосибирская область, Новосибирск, Титова, 94	f	large
58130	66024	1824	Новосибирская область, Новосибирск, Титова, 43/2	f	large
58129	66024	1823	Новосибирская область, Новосибирск, Титова, 43/2	f	large
58128	66024	1822	Новосибирская область, Новосибирск, Титова, 43/2	f	large
58091	66024	1785	Новосибирская область, Новосибирск, Титова, 43/2	f	large
57880	65893	1574	Новосибирская область, Новосибирск, Тимирязева, 81а	f	large
57879	65893	1573	Новосибирская область, Новосибирск, Тимирязева, 81а	f	large
57878	65893	1572	Новосибирская область, Новосибирск, Тимирязева, 81а	f	large
57875	65891	1569	Новосибирская область, Новосибирск, Тимирязева, 2	f	large
57867	65885	1561	Новосибирская область, Новосибирск, Тимирязева, 6	f	large
57756	65823	1450	Новосибирская область, Новосибирск, Театральная, 1	f	large
57755	65823	1449	Новосибирская область, Новосибирск, Театральная, 1	f	large
57922	65916	1613	Новосибирская область, Новосибирск, Танковая , 9/1	f	large
57921	65916	1612	Новосибирская область, Новосибирск, Танковая , 9/1	f	large
57944	65928	1635	Новосибирская область, Новосибирск, Столетова, 22	f	large
57943	65928	1634	Новосибирская область, Новосибирск, Столетова, 22	f	large
58134	66046	1828	Новосибирская область, Новосибирск, Степная , 57	f	large
58057	66003	1751	Новосибирская область, Новосибирск, Станционная , 8а	f	medium
58060	66005	1754	Новосибирская область, Новосибирск, Станционная, 50/1	f	large
58135	66047	1829	Новосибирская область, Новосибирск, Станиславского, 30	f	large
58123	66040	1817	Новосибирская область, Новосибирск, Станиславского, 23	f	large
58090	66023	1784	Новосибирская область, Новосибирск, Станиславского, 2/1	f	large
58087	66020	1781	Новосибирская область, Новосибирск, Станиславского, 6б	f	large
57975	65947	1669	Новосибирская область, Новосибирск, Станиславского, 33	f	large
57874	65890	1568	Новосибирская область, Новосибирск, Союза Молодежи, 10	f	large
57873	65890	1567	Новосибирская область, Новосибирск, Союза Молодежи, 10	f	large
57872	65890	1566	Новосибирская область, Новосибирск, Союза Молодежи, 10	f	large
57974	65944	1666	Новосибирская область, Новосибирск, Солидарности, 71Б	f	large
57973	65944	1665	Новосибирская область, Новосибирск, Солидарности, 71Б	f	large
57972	65942	1664	Новосибирская область, Новосибирск, Солидарности, 65	f	large
57971	65942	1663	Новосибирская область, Новосибирск, Солидарности, 65	f	large
57838	65869	1532	Новосибирская область, Новосибирск, Советская, 63	f	large
57844	65852	1514	Новосибирская область, Новосибирск, Советская, 93	f	large
56439	64308	133	Новосибирская область, Новосибирск, Советская, 27	f	small
56434	64302	128	Новосибирская область, Новосибирск, Советская, 1	f	medium
58031	65985	1725	Новосибирская область, Новосибирск, Сибиряков-Гвардейцев, 58	f	large
57840	65870	1534	Новосибирская область, Новосибирск, Сибирская, 30	f	large
57839	65870	1533	Новосибирская область, Новосибирск, Сибирская, 30	f	large
57841	65854	1535	Новосибирская область, Новосибирск, Сибирская, 35	f	large
57842	65854	1516	Новосибирская область, Новосибирск, Сибирская, 35	f	large
58324	66169	2018	Новосибирская область, Новосибирск, Серебренниковская , 2/1	f	large
58327	66172	2021	Новосибирская область, Новосибирск, Серебренниковская, 36	f	large
58325	66170	2019	Новосибирская область, Новосибирск, Серебренниковская, 10	f	large
57780	65835	1474	Новосибирская область, Новосибирск, Селезнева, 46	f	large
57776	65835	1470	Новосибирская область, Новосибирск, Селезнева, 46	f	large
57900	65906	1594	Новосибирская область, Новосибирск, Северная, 1	f	large
57899	65906	1593	Новосибирская область, Новосибирск, Северная, 1	f	large
57897	65904	1591	Новосибирская область, Новосибирск, Северная, 31	f	large
57896	65904	1590	Новосибирская область, Новосибирск, Северная, 31	f	large
58112	66030	1806	Новосибирская область, Новосибирск, Связистов, 135	f	large
58106	66030	1800	Новосибирская область, Новосибирск, Связистов, 135	f	large
58105	66030	1799	Новосибирская область, Новосибирск, Связистов, 135	f	large
57832	65863	1526	Новосибирская область, Новосибирск, Саратовская, 24а	f	large
58163	66064	1857	Новосибирская область, Новосибирск, Садовая, 26	f	medium
58162	66064	1856	Новосибирская область, Новосибирск, Садовая, 26	f	large
58003	65970	1697	Новосибирская область, Новосибирск, Саввы Кожевникова, 21	f	large
58002	65970	1696	Новосибирская область, Новосибирск, Саввы Кожевникова, 21	f	large
58001	65969	1695	Новосибирская область, Новосибирск, Саввы Кожевникова, 21/1	f	large
58000	65969	1694	Новосибирская область, Новосибирск, Саввы Кожевникова, 21/1	f	large
57999	65969	1693	Новосибирская область, Новосибирск, Саввы Кожевникова, 21/1	f	large
58287	66145	1981	Новосибирская область, Новосибирск, Русская , 35	f	large
58293	66147	1987	Новосибирская область, Новосибирск, Русская, 1а	f	large
58283	66142	1977	Новосибирская область, Новосибирск, Российская , 3	f	large
58282	66142	1976	Новосибирская область, Новосибирск, Российская , 3	f	large
58334	66179	2028	Новосибирская область, Новосибирск, Романова, 23	f	large
57964	65937	1656	Новосибирская область, Новосибирск, Родники, 4	f	large
58120	66038	1814	Новосибирская область, Новосибирск, Римского-Корсакова, 22	f	large
57977	65949	1671	Новосибирская область, Новосибирск, Римского-Корсакова, 13	f	large
57754	65822	1448	Новосибирская область, Новосибирск, Республиканская , 15/1	f	large
57753	65822	1447	Новосибирская область, Новосибирск, Республиканская , 15/1	f	large
57752	65822	1446	Новосибирская область, Новосибирск, Республиканская , 15/1	f	large
57751	65822	1445	Новосибирская область, Новосибирск, Республиканская , 15/1	f	large
58197	66083	1891	Новосибирская область, Новосибирск, Радиотехническая, 57а	f	large
57782	65838	1476	Новосибирская область, Новосибирск, Промышленная, 1/1	f	large
57781	65838	1475	Новосибирская область, Новосибирск, Промышленная, 1/1	f	large
57783	65838	1477	Новосибирская область, Новосибирск, Промышленная, 1/1	f	medium
57304	65322	998	Новосибирская область, Новосибирск, Приозерная , 11 А	t	small
58253	66123	1947	Новосибирская область, Новосибирск, Приморская, 3	f	large
58240	66114	1934	Россия, Новосибирская область, Новосибирск, Прибрежный переулок, 9	f	large
58082	66016	1776	Новосибирская область, Новосибирск, Порт-Артурская , 1а	f	large
58081	66016	1775	Новосибирская область, Новосибирск, Порт-Артурская , 1а	f	large
57748	65817	1440	Новосибирская область, Новосибирск, Полякова, 1в	f	large
58289	66133	1983	Новосибирская область, Новосибирск, Полевая , 5	f	large
58271	66133	1965	Новосибирская область, Новосибирск, Полевая , 5	f	large
58125	66041	1819	Новосибирская область, Новосибирск, Плахотного, 31	f	large
58111	66032	1805	Новосибирская область, Новосибирск, Плахотного, 10	f	large
58110	66032	1804	Новосибирская область, Новосибирск, Плахотного, 10	f	large
58052	65999	1746	Новосибирская область, Новосибирск, Планировочная, 7/2	f	large
58051	65998	1745	Новосибирская область, Новосибирск, Планировочная, 7	f	large
58050	65998	1744	Новосибирская область, Новосибирск, Планировочная, 7	f	large
58249	66119	1943	Новосибирская область, Новосибирск, Пихтовая, 44	f	large
58248	66119	1942	Новосибирская область, Новосибирск, Пихтовая, 44	f	large
58276	66138	1970	Новосибирская область, Новосибирск, Пирогова, 10	f	large
58013	65975	1707	Новосибирская область, Новосибирск, Петухова, 100	f	large
58012	65975	1706	Новосибирская область, Новосибирск, Петухова, 100	f	large
58220	66120	1944	Новосибирская область, Новосибирск, Первомайская улица, 1	f	large
58231	66106	1925	Новосибирская область, Новосибирск, Первомайская , 202	f	large
58228	66103	1922	Новосибирская область, Новосибирск, Первомайская , 174	f	large
58233	94871	1927	Новосибирская область, Новосибирск, Первомайская, 206	f	large
58234	66110	1928	Новосибирская область, Новосибирск, Первомайская, 236	f	medium
58222	66099	1916	Новосибирская область, Новосибирск, Первомайская, 96	f	large
58221	66098	1915	Новосибирская область, Новосибирск, Первомайская, 82	f	large
58127	66042	1821	Новосибирская область, Новосибирск, Пархоменко, 2	f	large
58126	66042	1820	Новосибирская область, Новосибирск, Пархоменко, 2	f	large
58216	66094	1910	Новосибирская область, Новосибирск, Панфиловцев, 41	f	large
58033	65986	1727	Новосибирская область, Новосибирск, Палласа, 28	f	large
58032	65986	1726	Новосибирская область, Новосибирск, Палласа, 28	f	large
57905	65910	1599	Новосибирская область, Новосибирск, Охотская, 84	f	large
57904	65910	1598	Новосибирская область, Новосибирск, Охотская, 84	f	large
58328	66174	2022	Новосибирская область, Новосибирск, Октябрьская, 89А	f	large
57834	65865	1528	Новосибирская область, Новосибирск, Октябрьская, 5	f	large
58243	66116	1937	Новосибирская область, Новосибирск, Одоевского, 1	f	large
57939	65926	1630	Новосибирская область, Новосибирск, Объединения, 82/2	f	large
57938	65926	1629	Новосибирская область, Новосибирск, Объединения, 82/2	f	large
57937	65926	1628	Новосибирская область, Новосибирск, Объединения, 82/2	f	large
57968	65939	1660	Новосибирская область, Новосибирск, Новоуральская, 11/3	f	large
57967	65939	1659	Новосибирская область, Новосибирск, Новоуральская, 11/3	f	large
57966	65938	1658	Новосибирская область, Новосибирск, Новоуральская, 21	f	large
57965	65938	1657	Новосибирская область, Новосибирск, Новоуральская, 21	f	large
58264	66128	1958	Новосибирская область, Новосибирск, Новоморская, 12	f	large
57985	65958	1679	Новосибирская область, Новосибирск, Новогодняя, 20/2	f	large
57984	65957	1678	Новосибирская область, Новосибирск, Новогодняя, 14/1	f	large
57935	65925	1626	Новосибирская область, Новосибирск, Новая Заря, 27	f	large
57934	65925	1625	Новосибирская область, Новосибирск, Новая Заря, 27	f	large
57936	65925	1627	Новосибирская область, Новосибирск, Новая Заря, 27	f	large
58148	66056	1842	Новосибирская область, Новосибирск, Никитина, 2	f	large
58147	66056	1841	Новосибирская область, Новосибирск, Никитина, 2	f	large
58137	66048	1831	Новосибирская область, Новосибирск, Немировича-Данченко, 20/2	f	large
58136	66048	1830	Новосибирская область, Новосибирск, Немировича-Данченко, 20/2	f	large
57981	65953	1675	Новосибирская область, Новосибирск, Немировича-Данченко, 137/1	f	large
57979	65951	1673	Новосибирская область, Новосибирск, Немировича-Данченко, 121	f	large
57980	65952	1674	Новосибирская область, Кировский район, Новосибирск, Немировича-Данченко, 102/2	f	large
58321	66167	2015	Новосибирская область, Новосибирск, Некрасова, 82	f	large
58320	66166	2014	Новосибирская область, Новосибирск, Некрасова, 84	f	large
58313	66161	2007	Новосибирская область, Новосибирск, Некрасова, 4	f	large
58079	66014	1773	Новосибирская область, Новосибирск, Невельского, 53/1	f	large
58078	66014	1772	Новосибирская область, Новосибирск, Невельского, 53/1	f	large
57920	65915	1611	Новосибирская область, Новосибирск, Народная , 67	f	large
57919	65915	1610	Новосибирская область, Новосибирск, Народная , 67	f	large
57918	65915	1609	Новосибирская область, Новосибирск, Народная , 67	f	large
57926	65918	1617	Новосибирская область, Новосибирск, Народная, 37	f	large
57925	65917	1616	Новосибирская область, Новосибирск, Народная, 11	f	large
57924	65917	1615	Новосибирская область, Новосибирск, Народная, 11	f	large
57923	65917	1614	Новосибирская область, Новосибирск, Народная, 11	f	large
58054	66001	1748	Новосибирская область, Новосибирск, Моторная, 16	f	large
58273	66135	1967	Россия, Новосибирская область, Новосибирск, Морской проспект, 23	f	large
58261	66121	1955	Новосибирская область, Новосибирск, Молодости, 15	f	large
58251	66121	1945	Новосибирская область, Новосибирск, Молодости, 15	f	large
57991	65964	1685	Новосибирская область, Новосибирск, Мира, 14	f	large
57990	65963	1684	Новосибирская область, Новосибирск, Мира, 1	f	large
57946	65929	1637	Новосибирская область, Новосибирск, Макаренко, 25/1	f	large
57945	65929	1636	Новосибирская область, Новосибирск, Макаренко, 25/1	f	large
57942	65927	1633	Новосибирская область, Новосибирск, Макаренко, 28	f	large
57941	65927	1632	Новосибирская область, Новосибирск, Макаренко, 28	f	large
57940	65927	1631	Новосибирская область, Новосибирск, Макаренко, 28	f	large
57969	65940	1661	Новосибирская область, Новосибирск, Магистральная, 16	f	large
57901	65907	1595	Новосибирская область, Новосибирск, Магаданская , 2А	f	large
58277	66139	1971	Новосибирская область, Новосибирск, Лыкова, 4	f	large
57804	65847	1498	Новосибирская область, Новосибирск, Липецкая, 25/2	f	large
57803	65847	1497	Новосибирская область, Новосибирск, Липецкая, 25/2	f	large
57864	65883	1558	Новосибирская область, Новосибирск, Линейная , 33/4	f	large
57863	65883	1557	Новосибирская область, Новосибирск, Линейная , 33/4	f	large
57862	65883	1556	Новосибирская область, Новосибирск, Линейная , 33/4	f	large
57849	65876	1543	Новосибирская область, Новосибирск, Линейная , 223	f	large
58304	66153	1998	Новосибирская область, Новосибирск, Лесосечная, 4	f	large
112466	65519	1159	Новосибирская область, Новосибирск, Лесная , 1	t	\N
58340	66070	1914	Новосибирская область, Новосибирск, Ленинградская , 113	f	large
58174	66070	1868	Новосибирская область, Новосибирск, Ленинградская , 113	f	large
57903	65909	1597	Новосибирская область, Заельцовский район, Новосибирск, Лебедевская, 1	f	large
58206	66087	1900	Новосибирская область, Новосибирск, Лазурная , 10/1	f	large
58205	66087	1899	Новосибирская область, Новосибирск, Лазурная , 10/1	f	large
58212	66090	1906	Новосибирская область, Новосибирск, Лазурная, 27	f	large
58211	66090	1905	Новосибирская область, Новосибирск, Лазурная, 27	f	large
58210	66090	1904	Новосибирская область, Новосибирск, Лазурная, 27	f	large
57950	65931	1641	Новосибирская область, Новосибирск, Курчатова, 37/1	f	large
57949	65931	1640	Новосибирская область, Новосибирск, Курчатова, 37/1	f	large
58102	66028	1796	Новосибирская область, Новосибирск, Курганская , 36а	f	large
58100	66028	1794	Новосибирская область, Новосибирск, Курганская , 36а	f	large
58101	66028	1795	Новосибирская область, Новосибирск, Курганская , 36а	f	large
57818	65851	1512	Новосибирская область, Новосибирск, Куприна, 4	f	large
57816	65851	1510	Новосибирская область, Новосибирск, Куприна, 4	f	large
57815	65851	1509	Новосибирская область, Новосибирск, Куприна, 4	f	large
57817	65851	1511	Новосибирская область, Новосибирск, Куприна, 4	f	large
57907	65871	1536	Новосибирская область, Новосибирск, Кубовая , 107/1	f	large
57906	65911	1600	Новосибирская область, Новосибирск, Кубовая, 47б	f	large
57831	65862	1525	Новосибирская область, Новосибирск, Кубановская , 17а	f	large
58307	66156	2001	Новосибирская область, Новосибирск, Крылова, 18	f	large
57912	65912	1603	Новосибирская область, Новосибирск, Кропоткина, 132/2	f	large
57911	65912	1602	Новосибирская область, Новосибирск, Кропоткина, 132/2	f	large
57910	65912	1601	Новосибирская область, Новосибирск, Кропоткина, 132/2	f	large
57857	65879	1551	Новосибирская область, Новосибирск, Кропоткина, 110	f	large
57856	65879	1550	Новосибирская область, Новосибирск, Кропоткина, 110	f	large
57855	65879	1549	Новосибирская область, Новосибирск, Кропоткина, 110	f	large
57854	65878	1548	Новосибирская область, Новосибирск, Кропоткина, 119	f	large
57853	65878	1547	Новосибирская область, Новосибирск, Кропоткина, 119	f	large
57852	65878	1546	Новосибирская область, Новосибирск, Кропоткина, 119	f	large
57848	65875	1542	Новосибирская область, Новосибирск, Кропоткина, 265	f	large
57847	65875	1541	Новосибирская область, Новосибирск, Кропоткина, 265	f	large
57846	65874	1540	Новосибирская область, Новосибирск, Кропоткина, 126/2	f	large
57845	65874	1539	Новосибирская область, Новосибирск, Кропоткина, 126/2	f	large
112501	65934	1648	Новосибирская область, Новосибирск, Красных Зорь, 7	f	\N
58338	66183	2032	Россия, Новосибирская область, Новосибирск, Красный проспект, 4	f	small
58337	66182	2031	Россия, Новосибирская область, Новосибирск, Красный проспект, 75	f	large
58314	66162	2008	Россия, Новосибирская область, Новосибирск, Красный проспект, 72	f	large
58305	66154	1999	Россия, Новосибирская область, Новосибирск, Красный проспект, 48	f	large
57894	65902	1588	Россия, Новосибирская область, Новосибирск, Красный проспект, 171/4	f	large
57893	65901	1587	Россия, Новосибирская область, Новосибирск, Красный проспект, 167	f	large
57861	65882	1555	Россия, Новосибирская область, Новосибирск, Красный проспект, 153	f	large
57859	65880	1553	Россия, Новосибирская область, Новосибирск, Красный проспект, 83/1	f	large
57858	65880	1552	Россия, Новосибирская область, Новосибирск, Красный проспект, 83/1	f	large
58265	66129	1959	Новосибирская область, Новосибирск, Красноуфимская, 8	f	large
57960	65935	1652	Новосибирская область, Новосибирск, Кочубея, 11/1	f	large
57959	65935	1651	Новосибирская область, Новосибирск, Кочубея, 11/1	f	large
57958	65935	1650	Новосибирская область, Новосибирск, Кочубея, 11/1	f	large
57957	65935	1649	Новосибирская область, Новосибирск, Кочубея, 11/1	f	large
58114	66033	1808	Новосибирская область, Новосибирск, Котовского, 2а	f	large
58113	66033	1807	Новосибирская область, Новосибирск, Котовского, 2а	f	large
58088	66022	1782	Новосибирская область, Новосибирск, Котовского, 16	f	large
58089	66007	1783	Новосибирская область, Новосибирск, Котовского, 38	f	large
58062	66007	1756	Новосибирская область, Новосибирск, Котовского, 38	f	large
58042	65993	1736	Россия, Новосибирская область, Новосибирск, Космическая улица, 21	f	large
58046	65996	1740	Новосибирская область, Новосибирск, Космическая, 10	f	large
58045	65996	1739	Новосибирская область, Новосибирск, Космическая, 10	f	large
57825	65857	1519	Россия, Новосибирская область, Новосибирск, Комсомольский проспект, 20	f	large
58217	66095	1911	Новосибирская область, Новосибирск, Коммунстроевская , 161	f	large
58326	66171	2020	Новосибирская область, Новосибирск, Коммунистическая, 58	f	large
56427	64292	121	Новосибирская область, Новосибирск, Колхозная , 17	f	small
58061	66006	1755	Новосибирская область, Новосибирск, Клубная, 39	f	large
58085	66006	1779	Новосибирская область, Новосибирск, Клубная, 39	f	large
58167	66066	1861	Новосибирская область, Новосибирск, Кирова, 327	f	large
58166	66066	1860	Новосибирская область, Новосибирск, Кирова, 327	f	large
58165	66066	1859	Новосибирская область, Новосибирск, Кирова, 327	f	large
58083	66017	1777	Новосибирская область, Новосибирск, Киевская , 14	f	large
58072	66010	1766	Новосибирская область, Новосибирск, Киевская , 15а	f	large
58071	66010	1765	Новосибирская область, Новосибирск, Киевская , 15а	f	large
58070	66010	1764	Новосибирская область, Новосибирск, Киевская , 15а	f	large
58069	66009	1763	Новосибирская область, Новосибирск, Киевская , 7	f	large
58068	66009	1762	Новосибирская область, Новосибирск, Киевская , 7	f	large
58067	66009	1761	Новосибирская область, Новосибирск, Киевская , 7	f	large
58066	66008	1760	Новосибирская область, Новосибирск, Киевская, 5	f	large
58065	66008	1759	Новосибирская область, Новосибирск, Киевская, 5	f	large
58064	66008	1758	Новосибирская область, Новосибирск, Киевская, 5	f	large
58063	66008	1757	Новосибирская область, Новосибирск, Киевская, 5	f	large
58059	65990	1753	Новосибирская область, Новосибирск, Карла Маркса, 26	f	large
58037	65990	1731	Новосибирская область, Новосибирск, Карла Маркса, 26	f	large
58332	66177	2026	Новосибирская область, Новосибирск, Каменская , 56	f	large
58330	66175	2024	Новосибирская область, Новосибирск, Каменская , 68	f	medium
58308	66157	2002	Новосибирская область, Новосибирск, Каменская , 82	f	large
57785	65839	1479	Новосибирская область, Новосибирск, Индустриальная, 4а	f	large
57784	65839	1478	Новосибирская область, Новосибирск, Индустриальная, 4а	f	large
58274	66136	1968	Новосибирская область, Новосибирск, Ильича, 21	f	large
58280	66140	1974	Новосибирская область, Новосибирск, Иванова, 9	f	large
58279	66140	1973	Новосибирская область, Новосибирск, Иванова, 9	f	large
58278	66140	1972	Новосибирская область, Новосибирск, Иванова, 9	f	large
58270	66132	1964	Новосибирская область, Новосибирск, Иванова, 49	f	large
58268	66130	1962	Новосибирская область, Новосибирск, Иванова, 36	f	large
58267	66130	1961	Новосибирская область, Новосибирск, Иванова, 36	f	large
58266	66130	1960	Новосибирская область, Новосибирск, Иванова, 36	f	large
58030	65984	1724	Новосибирская область, Новосибирск, Зорге, 2	f	large
58029	65983	1723	Новосибирская область, Новосибирск, Зорге, 42а	f	large
58028	65982	1722	Новосибирская область, Новосибирск, Зорге, 12	f	large
58027	65981	1721	Новосибирская область, Новосибирск, Зорге, 78/1	f	large
58026	65981	1720	Новосибирская область, Новосибирск, Зорге, 78/1	f	large
58023	65979	1717	Новосибирская область, Новосибирск, Зорге, 259/1	f	large
58022	65979	1716	Новосибирская область, Новосибирск, Зорге, 259/1	f	large
58021	65979	1715	Новосибирская область, Новосибирск, Зорге, 259/1	f	large
58011	65974	1705	Новосибирская область, Новосибирск, Зорге, 149	f	large
58010	65974	1704	Новосибирская область, Новосибирск, Зорге, 149	f	large
58009	65974	1703	Новосибирская область, Новосибирск, Зорге, 149	f	large
112503	65946	1668	Новосибирская область, Новосибирск, Зорге, 42а	f	\N
58239	66113	1933	Новосибирская область, Новосибирск, Звездная, 8А	f	large
58238	66113	1932	Новосибирская область, Новосибирск, Звездная, 8А	f	large
58080	66015	1774	Новосибирская область, Новосибирск, Забалуева, 74	f	large
58077	66013	1771	Новосибирская область, Новосибирск, Забалуева, 47	f	large
58076	66013	1770	Новосибирская область, Новосибирск, Забалуева, 47	f	large
58075	66012	1769	Новосибирская область, Новосибирск, Забалуева, 10а	f	large
58074	66012	1768	Новосибирская область, Новосибирск, Забалуева, 10а	f	large
57898	65905	1592	Новосибирская область, Новосибирск, Жуковского, 98	f	small
57877	65892	1571	Новосибирская область, Новосибирск, Жуковского, 113/5	f	large
57876	65892	1570	Новосибирская область, Новосибирск, Жуковского, 113/5	f	large
58275	66137	1969	Новосибирская область, Новосибирск, Жемчужная, 16	f	large
57805	65820	1499	Новосибирская область, Новосибирск, Есенина, 15	f	large
57822	65820	1443	Новосибирская область, Новосибирск, Есенина, 15	f	large
57889	65898	1583	Новосибирская область, Новосибирск, Ереванская, 14	f	large
57887	65898	1581	Новосибирская область, Новосибирск, Ереванская, 14	f	large
57886	65898	1580	Новосибирская область, Новосибирск, Ереванская, 14	f	large
57888	65898	1582	Новосибирская область, Новосибирск, Ереванская, 14	f	large
57868	65886	1562	Новосибирская область, Новосибирск, Ельцовская , 31	f	large
57866	65884	1560	Новосибирская область, Новосибирск, Ельцовская, 5	f	large
57865	65884	1559	Новосибирская область, Новосибирск, Ельцовская, 5	f	large
57882	65894	1576	Новосибирская область, Новосибирск, Дуси Ковальчук, 191	f	large
57881	65894	1575	Новосибирская область, Новосибирск, Дуси Ковальчук, 191	f	large
57870	65888	1564	Новосибирская область, Новосибирск, Дуси Ковальчук, 85	f	large
57869	65887	1563	Новосибирская область, Новосибирск, Дуси Ковальчук, 65А	f	large
58316	66163	2010	Новосибирская область, Новосибирск, Достоевского, 27	f	large
58315	66163	2009	Новосибирская область, Новосибирск, Достоевского, 27	f	large
57819	65819	1513	Новосибирская область, Новосибирск, Дзержинский район, Доватора улица	f	large
57821	65819	1442	Новосибирская область, Новосибирск, Дзержинский район, Доватора улица	f	large
57820	65819	1441	Новосибирская область, Новосибирск, Дзержинский район, Доватора улица	f	large
57802	65846	1496	Новосибирская область, Новосибирск, Доватора, 33/4	f	large
57801	65846	1495	Новосибирская область, Новосибирск, Доватора, 33/4	f	large
57800	65846	1494	Новосибирская область, Новосибирск, Доватора, 33/4	f	large
58198	66084	1892	Новосибирская область, Новосибирск, Добролюбова, 223	f	large
58195	66081	1889	Новосибирская область, Новосибирск, Добролюбова, 162	f	large
58194	66080	1888	Новосибирская область, Новосибирск, Добролюбова, 160	f	large
57895	65903	1589	Новосибирская область, Новосибирск, Дмитрия Донского, 6А	f	large
58296	66149	1990	Россия, Новосибирская область, Новосибирск, Детский проезд, 10	f	large
58295	66149	1989	Россия, Новосибирская область, Новосибирск, Детский проезд, 10	f	large
57775	65834	1469	Новосибирская область, Новосибирск, Гоголя, 188/1	f	large
57774	65834	1468	Новосибирская область, Новосибирск, Гоголя, 188/1	f	large
57773	65834	1467	Новосибирская область, Новосибирск, Гоголя, 188/1	f	large
57771	65832	1465	Новосибирская область, Новосибирск, Гоголя, 195	f	large
57770	65832	1464	Новосибирская область, Новосибирск, Гоголя, 195	f	large
57769	65832	1463	Новосибирская область, Новосибирск, Гоголя, 195	f	large
58318	66164	2012	Новосибирская область, Новосибирск, Гоголя, 35а	f	large
58317	66164	2011	Новосибирская область, Новосибирск, Гоголя, 35а	f	large
57772	65833	1466	Новосибирская область, Новосибирск, Гоголя, 233	f	large
58256	66124	1950	Новосибирская область, Новосибирск, Гидромонтажная, 58	f	large
58232	66107	1926	Новосибирская область, Новосибирск, Героев Революции, 103	f	large
58230	66105	1924	Новосибирская область, Новосибирск, Героев Революции, 68	f	large
58225	66101	1919	Новосибирская область, Новосибирск, Героев Революции, 6	f	large
58224	66101	1918	Новосибирская область, Новосибирск, Героев Революции, 6	f	large
58291	66146	1985	Новосибирская область, Новосибирск, Вяземская, 4	f	large
58292	66146	1986	Новосибирская область, Новосибирск, Вяземская, 4	f	large
58290	66146	1984	Новосибирская область, Новосибирск, Вяземская, 4	f	large
58048	65997	1742	Новосибирская область, Новосибирск, Выставочная , 36	f	large
58047	65997	1741	Новосибирская область, Новосибирск, Выставочная , 36	f	large
58049	65997	1743	Новосибирская область, Новосибирск, Выставочная , 36	f	large
58116	66034	1810	Новосибирская область, Новосибирск, Выставочная, 8	f	large
58115	66034	1809	Новосибирская область, Новосибирск, Выставочная, 8	f	large
58164	66065	1858	Новосибирская область, Новосибирск, Выборная , 126	f	large
58144	94870	1838	Новосибирская область, Новосибирск, Выборная, 120	f	large
58160	66062	1854	Новосибирская область, Новосибирск, Выборная, 111/1	f	large
58159	66062	1853	Новосибирская область, Новосибирск, Выборная, 111/1	f	large
58155	66060	1849	Новосибирская область, Новосибирск, Выборная, 120	f	large
58154	66060	1848	Новосибирская область, Новосибирск, Выборная, 120	f	large
57793	65843	1487	Новосибирская область, Новосибирск, Волочаевская, 111	f	large
57792	65843	1486	Новосибирская область, Новосибирск, Волочаевская, 111	f	large
57836	65868	1530	Россия, Новосибирская область, Новосибирск, Вокзальная магистраль, 12	f	large
58173	66069	1867	Новосибирская область, Новосибирск, Воинская , 3	f	large
58172	66069	1866	Новосибирская область, Новосибирск, Воинская , 3	f	large
58171	66069	1865	Новосибирская область, Новосибирск, Воинская , 3	f	large
58218	66096	1912	Новосибирская область, Новосибирск, Военный Городок, 17	f	large
57833	94865	1527	Новосибирская область, Новосибирск, Владимировская , 15	f	large
58209	66089	1903	Новосибирская область, Новосибирск, Владимира Высоцкого, 1	f	large
58158	66061	1852	Новосибирская область, Новосибирск, Вилюйская, 28	f	large
58157	66061	1851	Новосибирская область, Новосибирск, Вилюйская, 28	f	large
58156	66061	1850	Новосибирская область, Новосибирск, Вилюйская, 28	f	large
58250	66131	1963	Новосибирская область, Новосибирск, Ветлужская, 28а	f	large
57982	65954	1676	Новосибирская область, Новосибирск, Вертковская , 2	f	large
57978	65950	1672	Новосибирская область, Новосибирск, Вертковская, 16	f	large
57983	65955	1677	Новосибирская область, Новосибирск, Ватутина, 61а	f	large
57993	65965	1687	Новосибирская область, Новосибирск, Бурденко, 55	f	large
57992	65965	1686	Новосибирская область, Новосибирск, Бурденко, 55	f	large
58153	66059	1847	Новосибирская область, Новосибирск, Бугурусланская, 19	f	large
58152	66059	1846	Новосибирская область, Новосибирск, Бугурусланская, 19	f	large
58034	65987	1728	Новосибирская область, Новосибирск, Бородина, 14	f	medium
58294	66148	1988	Новосибирская область, Новосибирск, Боровая партия, 13	f	large
58339	66097	1913	Новосибирская область, Новосибирск, Бориса Богаткова, 51	f	large
58204	66086	1898	Новосибирская область, Новосибирск, Бориса Богаткова, 189	f	large
58203	66086	1897	Новосибирская область, Новосибирск, Бориса Богаткова, 189	f	large
58202	66086	1896	Новосибирская область, Новосибирск, Бориса Богаткова, 189	f	large
58201	66085	1895	Новосибирская область, Новосибирск, Бориса Богаткова, 187	f	large
58200	66085	1894	Новосибирская область, Новосибирск, Бориса Богаткова, 187	f	large
58199	66085	1893	Новосибирская область, Новосибирск, Бориса Богаткова, 187	f	large
57809	65848	1503	Новосибирская область, Новосибирск, Бориса Богаткова, 241/1	f	large
57808	65848	1502	Новосибирская область, Новосибирск, Бориса Богаткова, 241/1	f	large
57807	65848	1501	Новосибирская область, Новосибирск, Бориса Богаткова, 241/1	f	large
57806	65848	1500	Новосибирская область, Новосибирск, Бориса Богаткова, 241/1	f	large
58151	66058	1845	Новосибирская область, Новосибирск, Большевистская, 32	f	large
58150	66058	1844	Новосибирская область, Новосибирск, Большевистская, 32	f	large
58149	66057	1843	Новосибирская область, Новосибирск, Большевистская, 175/6	f	large
57931	65923	1622	Новосибирская область, Новосибирск, Богдана Хмельницкого, 51	f	large
57929	65921	1620	Новосибирская область, Новосибирск, Богдана Хмельницкого, 40	f	large
57927	65919	1618	Новосибирская область, Новосибирск, Богдана Хмельницкого, 37	f	large
58263	66126	1957	Новосибирская область, Новосибирск, Бердышева, 19	f	large
58260	66126	1954	Новосибирская область, Новосибирск, Бердышева, 19	f	large
58259	66126	1953	Новосибирская область, Новосибирск, Бердышева, 19	f	large
58258	66126	1952	Новосибирская область, Новосибирск, Бердышева, 19	f	large
58169	66067	1863	Новосибирская область, Новосибирск, Белинского, 1	f	large
58168	66067	1862	Новосибирская область, Новосибирск, Белинского, 1	f	large
58262	66125	1956	Новосибирская область, Новосибирск, Барьерная, 8	f	large
58257	66125	1951	Новосибирская область, Новосибирск, Барьерная, 8	f	large
57930	65922	1621	Новосибирская область, Новосибирск, Александра Невского, 1а	f	medium
58236	66111	1930	Новосибирская область, Новосибирск, Аксенова, 21	f	large
58235	66111	1929	Новосибирская область, Новосибирск, Аксенова, 21	f	large
58298	66150	1992	Новосибирская область, Новосибирск, Академическая, 9	f	large
58297	66150	1991	Новосибирская область, Новосибирск, Академическая, 9	f	large
57813	65849	1507	Новосибирская область, Новосибирск, Адриена Лежена, 22	f	large
57812	65849	1506	Новосибирская область, Новосибирск, Адриена Лежена, 22	f	large
57811	65849	1505	Новосибирская область, Новосибирск, Адриена Лежена, 22	f	large
57810	65849	1504	Новосибирская область, Новосибирск, Адриена Лежена, 22	f	large
57750	65821	1444	Новосибирская область, Новосибирск, Адриена Лежена, 16	f	large
57799	65845	1493	Новосибирская область, Новосибирск, Авиастроителей , 16	f	large
57798	65845	1492	Новосибирская область, Новосибирск, Авиастроителей , 16	f	large
57797	65845	1491	Новосибирская область, Новосибирск, Авиастроителей , 16	f	large
57795	65844	1489	Новосибирская область, Новосибирск, Авиастроителей, 10	f	large
57796	65844	1490	Новосибирская область, Новосибирск, Авиастроителей, 10	f	large
58108	66031	1802	Новосибирская область, Ленинский район, Новосибирск, 9-й Гвардейской Дивизии, 20	f	large
58107	66031	1801	Новосибирская область, Ленинский район, Новосибирск, 9-й Гвардейской Дивизии, 20	f	large
57759	65824	1453	Новосибирская область, Новосибирск, 3-й Почтовый переулок, 21	f	large
57758	65824	1452	Новосибирская область, Новосибирск, 3-й Почтовый переулок, 21	f	large
57757	65824	1451	Новосибирская область, Новосибирск, 3-й Почтовый переулок, 21	f	large
56422	64287	116	Россия, Новосибирская область, Новосибирск, 2-я Школьная улица, 2а	f	small
56421	64285	115	Новосибирская область, Новосибирск, 2-я Школьная, 1	f	medium
57871	65889	1565	Новосибирская область, Новосибирск, 2-я Союза Молодежи, 31	f	large
58055	66002	1749	Новосибирская область, Новосибирск, 2-я Портовая, 36	f	large
58056	66002	1750	Новосибирская область, Новосибирск, 2-я Портовая, 36	f	large
57829	65861	1523	Новосибирская область, Новосибирск, 1905 года, 39	f	large
57830	65861	1524	Новосибирская область, Новосибирск, 1905 года, 39	f	large
57828	65860	1522	Новосибирская область, Новосибирск, 1905 года, 41	f	large
57826	65858	1520	Новосибирская область, Новосибирск, 1905 года, 12	f	large
57823	65855	1517	Новосибирская область, Новосибирск, 1905 года, 61	f	large
58008	65973	1702	Россия, Новосибирская область, Новосибирск, 15-й Бронный переулок, 20а	f	large
57902	65908	1596	Новосибирская область, Новосибирск, 1-я Шевцовой, 83	f	large
58237	66112	1931	Новосибирская область, Новосибирск, 1-я Механическая , 18	f	large
58124	66039	1818	Новосибирская область, Новосибирск, 1-й переулок Серафимовича, 4а	f	large
58122	66039	1816	Новосибирская область, Новосибирск, 1-й переулок Серафимовича, 4а	f	large
58121	66039	1815	Новосибирская область, Новосибирск, 1-й переулок Серафимовича, 4а	f	large
57988	65961	1682	Россия, Новосибирская область, Новосибирск, 1-й Чукотский переулок, 8	f	medium
58133	66045	1827	Россия, Новосибирская область, Новосибирск, 1-й Петропавловский переулок, 10	f	medium
57835	65866	1529	Новосибирская область, Новосибирск, Щетинкина, 33	f	large
57779	65837	1473	Новосибирская область, Новосибирск, Фрунзе, 63/1	f	large
57778	65837	1472	Новосибирская область, Новосибирск, Фрунзе, 63/1	f	large
57948	65930	1639	Новосибирская область, Новосибирск, Фадеева, 50/1	f	large
57947	65930	1638	Новосибирская область, Новосибирск, Фадеева, 50/1	f	large
58288	66143	1982	Новосибирская область, Новосибирск, Тружеников, 10	f	large
58284	66143	1978	Новосибирская область, Новосибирск, Тружеников, 10	f	large
58118	66036	1812	Новосибирская область, Новосибирск, Титова, 14	f	large
58117	66036	1811	Новосибирская область, Новосибирск, Титова, 14	f	large
58099	66027	1793	Новосибирская область, Новосибирск, Титова, 202	f	large
58098	66027	1792	Новосибирская область, Новосибирск, Титова, 202	f	large
58097	66027	1791	Новосибирская область, Новосибирск, Титова, 202	f	large
58096	66027	1790	Новосибирская область, Новосибирск, Титова, 202	f	large
57989	65962	1683	Новосибирская область, Новосибирск, Сибиряков-Гвардейцев, 44/6	f	large
57976	65948	1670	Новосибирская область, Новосибирск, Серафимовича, 32	f	large
58245	66117	1939	Новосибирская область, Новосибирск, Пришвина, 3	f	large
58244	66117	1938	Новосибирская область, Новосибирск, Пришвина, 3	f	large
58016	65976	1710	Новосибирская область, Новосибирск, Петухова, 86	f	large
58015	65976	1709	Новосибирская область, Новосибирск, Петухова, 86	f	large
58014	65976	1708	Новосибирская область, Новосибирск, Петухова, 86	f	large
57917	65914	1608	Новосибирская область, Новосибирск, Олеко Дундича, 1/1	f	large
57916	65914	1607	Новосибирская область, Новосибирск, Олеко Дундича, 1/1	f	large
57915	65914	1606	Новосибирская область, Новосибирск, Олеко Дундича, 1/1	f	large
58196	66082	1890	Новосибирская область, Новосибирск, Никитина, 147	f	large
58331	66176	2025	Новосибирская область, Новосибирск, Максима Горького, 93	f	large
58329	66173	2023	Новосибирская область, Новосибирск, Ломоносова, 59	f	large
58312	66160	2006	Новосибирская область, Новосибирск, Крылова, 61А	f	large
58310	66158	2004	Новосибирская область, Новосибирск, Крылова, 44	f	large
58309	66158	2003	Новосибирская область, Новосибирск, Крылова, 44	f	large
57914	65913	1605	Новосибирская область, Новосибирск, Кропоткина, 323	f	large
57913	65913	1604	Новосибирская область, Новосибирск, Кропоткина, 323	f	large
57956	65933	1647	Новосибирская область, Новосибирск, Красных Зорь, 7	f	large
57955	65933	1646	Новосибирская область, Новосибирск, Красных Зорь, 7	f	large
57954	65933	1645	Новосибирская область, Новосибирск, Красных Зорь, 7	f	large
58025	65980	1719	Новосибирская область, Новосибирск, Зорге, 181/1	f	large
58024	65980	1718	Новосибирская область, Новосибирск, Зорге, 181/1	f	large
58020	65978	1714	Новосибирская область, Новосибирск, Зорге, 21	f	large
58019	65978	1713	Новосибирская область, Новосибирск, Зорге, 21	f	large
58017	65977	1711	Новосибирская область, Новосибирск, Зорге, 39	f	large
58018	65977	1712	Новосибирская область, Новосибирск, Зорге, 39	f	large
57884	65896	1578	Новосибирская область, Новосибирск, Залесского, 4	f	large
57883	65895	1577	Новосибирская область, Новосибирск, Дуси Ковальчук, 187	f	large
57860	65881	1554	Новосибирская область, Новосибирск, Дуси Ковальчук, 179	f	large
57850	65877	1544	Новосибирская область, Новосибирск, Дуси Ковальчук, 270/2	f	large
57851	65877	1545	Новосибирская область, Новосибирск, Дуси Ковальчук, 270/2	f	large
58323	66168	2017	Новосибирская область, Новосибирск, Достоевского, 77	f	large
58322	66168	2016	Новосибирская область, Новосибирск, Достоевского, 77	f	large
58176	66072	1870	Новосибирская область, Новосибирск, Добролюбова, 113	f	large
58175	66072	1869	Новосибирская область, Новосибирск, Добролюбова, 113	f	large
57837	65859	1531	Новосибирская область, Новосибирск, Дмитрия Шамшурина, 43	f	medium
57827	65859	1521	Новосибирская область, Новосибирск, Дмитрия Шамшурина, 43	f	large
58184	66075	1878	Новосибирская область, Новосибирск, Декабристов, 86	f	large
58183	66075	1877	Новосибирская область, Новосибирск, Декабристов, 86	f	large
58007	65972	1701	Новосибирская область, Новосибирск, Водозабор, 1	f	large
58186	66077	1880	Новосибирская область, Новосибирск, Бориса Богаткова, 46	f	large
58187	66077	1881	Новосибирская область, Новосибирск, Бориса Богаткова, 46	f	large
57928	65920	1619	Новосибирская область, Новосибирск, Богдана Хмельницкого, 40	f	large
57891	65899	1585	Новосибирская область, Новосибирск, Аэропорт, 21/1	f	large
57890	65899	1584	Новосибирская область, Новосибирск, Аэропорт, 21/1	f	large
57994	65966	1688	Новосибирская область, Новосибирск, Аникина, 2	f	large
57125	65108	819	Новосибирская область, село Новолуговое, улица Андреева, 57, здание администрации с/совета	f	large
112451	65474	1129	Новосибирская область, поселок Николо-Гавриловка, Центральная, 18	t	\N
56941	94756	638	Новосибирская область, Купино, Р.Люксембург, 8	f	large
56933	64885	630	Новосибирская область, Куйбышев	f	large
56932	64885	629	Новосибирская область, Куйбышев	f	large
56924	64878	621	Новосибирская область, Куйбышев	f	large
56921	64876	618	Новосибирская область, Куйбышев	f	large
56918	64874	615	Новосибирская область, Куйбышев	f	large
56915	64872	612	Новосибирская область, Куйбышев	f	large
56912	64870	609	Новосибирская область, Куйбышев	f	large
56911	64857	608	Новосибирская область, Куйбышев	f	large
56930	64883	627	Новосибирская область, Куйбышев, квартал 5, 1	f	large
56931	64884	628	Новосибирская область, Куйбышев, Партизанская, 95	f	large
56917	64873	614	Новосибирская область, Куйбышев, Интернатская, 2А	f	large
56916	64873	613	Новосибирская область, Куйбышев, Интернатская, 2А	f	large
56926	64879	623	Новосибирская область, Куйбышев, Закраевского, 104	f	large
56925	64879	622	Новосибирская область, Куйбышев, Закраевского, 104	f	large
56928	64881	625	Новосибирская область, Куйбышев, Володарского, 61	f	large
56914	64871	611	Новосибирская область, Куйбышев, Молодежная, 7	f	large
56913	64871	610	Новосибирская область, Куйбышев, Молодежная, 7	f	large
57110	65092	804	Новосибирская область, Краснообск, 209, школа-гимназия № 13	f	large
57106	65088	800	Новосибирская область, Краснообск, 77, здание ДДТ Мастер	f	large
57726	65801	1420	Новосибирская область, Искитим	f	large
57723	65799	1417	Новосибирская область, Искитим	f	large
57722	65798	1416	Новосибирская область, Искитим	f	large
57720	65796	1414	Новосибирская область, Искитим	f	large
57713	65789	1407	Новосибирская область, Искитим	f	large
57711	65787	1405	Новосибирская область, Искитим	f	large
57709	65785	1403	Новосибирская область, Искитим	f	medium
57708	65784	1402	Новосибирская область, Искитим	f	large
57705	65781	1399	Новосибирская область, Искитим	f	medium
57719	65795	1413	Новосибирская область, Искитим, проспект Юбилейный, 4	f	large
57721	65797	1415	Новосибирская область, Искитим, микрорайон Южный, 52	f	large
57729	65802	1422	Новосибирская область, Искитим, микрорайон Подгорный, 46Б	f	medium
57727	65802	1421	Новосибирская область, Искитим, микрорайон Подгорный, 46Б	f	large
57724	65800	1418	Новосибирская область, Искитим, микрорайон Подгорный, 35	f	large
57725	65800	1419	Новосибирская область, Искитим, микрорайон Подгорный, 35	f	large
57715	65791	1409	Новосибирская область, Искитим, микрорайон Индустриальный, 11Б	f	large
57714	65790	1408	Новосибирская область, Искитим, микрорайон Индустриальный, 9А	f	large
57728	65774	1392	Новосибирская область, Искитим, Элеваторная, 2А	f	large
57703	65779	1397	Новосибирская область, Искитим, Школьная, 41	f	large
57710	65786	1404	Новосибирская область, Искитим, Пушкина, 79	f	large
57718	65794	1412	Новосибирская область, Искитим, Прорабская, 2а	f	large
57701	65777	1395	Новосибирская область, Искитим, Нагорная, 2А	f	large
57716	65792	1410	Новосибирская область, Искитим, Литейная, 5	f	large
57707	65783	1401	Новосибирская область, Искитим, Комсомольская, 6а	f	large
57706	65782	1400	Новосибирская область, Искитим, Комсомольская, 28	f	large
57704	65780	1398	Новосибирская область, Искитим, Кирова, 35	f	large
57700	65776	1394	Новосибирская область, Искитим, Заводская, 1А	f	medium
57717	65793	1411	Новосибирская область, Искитим, Дачная, 1	f	medium
57712	65788	1406	Новосибирская область, Искитим, Советская, 252	f	large
57694	65772	1388	Новосибирская область, Бердск	f	large
57695	65772	1389	Новосибирская область, Бердск	f	large
57677	65761	1371	Новосибирская область, Бердск	f	large
57664	65750	1358	Новосибирская область, Бердск	f	large
57663	65750	1357	Новосибирская область, Бердск	f	large
57659	65746	1353	Новосибирская область, Бердск, ГУАССО Бердский пансионат ветеранов труда им. М.И.Калинина	f	medium
57658	65745	1352	Новосибирская область, Бердск, здание корпуса № 1 ЗАО "Сосновка"	f	medium
57682	65764	1376	Новосибирская область, Бердск, Школьная, 5	f	large
57681	65764	1375	Новосибирская область, Бердск, Школьная, 5	f	large
57683	65765	1377	Новосибирская область, Бердск, Пушкина, 38	f	large
57661	65748	1355	Новосибирская область, Бердск, Попова, 12	f	large
57660	65747	1354	Новосибирская область, Бердск, Парижской Коммуны, 15	f	large
57674	65758	1368	Новосибирская область, Бердск, Островского, 69	f	large
57680	65763	1374	Новосибирская область, Бердск, Озерная, 32	f	large
57697	65773	1391	Новосибирская область, Бердск, Микрорайон, 39	f	large
57696	65773	1390	Новосибирская область, Бердск, Микрорайон, 39	f	large
57691	65770	1385	Новосибирская область, Бердск, Микрорайон, 48Б	f	large
57690	65770	1384	Новосибирская область, Бердск, Микрорайон, 48Б	f	large
57689	65769	1383	Новосибирская область, Бердск, Микрорайон, 12	f	large
57688	65769	1382	Новосибирская область, Бердск, Микрорайон, 12	f	large
57673	65757	1367	Новосибирская область, Бердск, М.Горького, 7/3	f	large
57672	65757	1366	Новосибирская область, Бердск, М.Горького, 7/3	f	large
57693	65771	1387	Новосибирская область, Бердск, Лунная, 23	f	large
57692	65771	1386	Новосибирская область, Бердск, Лунная, 23	f	large
57675	65759	1369	Новосибирская область, Бердск, Ленина, 104	f	large
57670	65755	1364	Новосибирская область, Бердск, Ленина, 34	f	large
57667	65753	1361	Новосибирская область, Бердск, Ленина, 31	f	large
57685	65766	1379	Новосибирская область, Бердск, Кутузова, 34	f	large
57684	65766	1378	Новосибирская область, Бердск, Кутузова, 34	f	large
57669	65754	1363	Новосибирская область, Бердск, Комсомольская, 31	f	large
57668	65754	1362	Новосибирская область, Бердск, Комсомольская, 31	f	large
57666	65752	1360	Новосибирская область, Бердск, Комсомольская, 29	f	large
57686	65767	1380	Новосибирская область, Бердск, Кольцова, 2	f	large
57676	65760	1370	Новосибирская область, Бердск, Вокзальная, 54	f	large
57665	65751	1359	Новосибирская область, Бердск, Вокзальная, 50	f	large
57687	65768	1381	Новосибирская область, Бердск, Рогачева, 11	f	large
57679	65762	1373	Новосибирская область, Бердск, Котовского, 20	f	large
57678	65762	1372	Новосибирская область, Бердск, Котовского, 20	f	large
57671	65756	1365	Новосибирская область, Бердск, К. Маркса, 26	f	large
57698	65744	1351	Новосибирская область, Бердск, Боровая, 101	f	large
56393	64260	88	Новосибирская область, Барабинск	f	large
56409	64274	104	Новосибирская область, Барабинск, переулок Халтурина, 31А	f	large
56400	64267	95	Новосибирская область, Барабинск, переулок Гутова, 18	f	large
56397	64264	92	Новосибирская область, Барабинск, Ульяновская, 66	f	large
56404	64262	99	Новосибирская область, Барабинск, Сельская, 2	f	large
56395	64262	90	Новосибирская область, Барабинск, Сельская, 2	f	medium
56390	94703	85	Новосибирская область, Барабинск, Мира, 227	f	large
56399	64266	94	Новосибирская область, Барабинск, Луначарского, 79а	f	large
56405	64270	100	Новосибирская область, Барабинск, Ленина, 102	f	medium
56402	64268	97	Новосибирская область, Барабинск, Коммунистическая, 10а	f	medium
56401	64268	96	Новосибирская область, Барабинск, Коммунистическая, 10а	f	large
56398	64265	93	Новосибирская область, Барабинск, Карла Маркса, 111	f	large
56394	64261	89	Новосибирская область, Барабинск, Калинина, 5	f	large
56392	64259	87	Новосибирская область, Барабинск, Калинина, 5	f	medium
56391	64258	86	Новосибирская область, Барабинск, Ермака, 91	f	large
56408	64273	103	Новосибирская область, Барабинск, Деповская, 15	f	medium
56403	64269	98	Новосибирская область, Барабинск, Барабинская, 164	f	large
56410	64275	105	Новосибирская область, Барабинск, Пролетарская, 54	f	medium
57594	65667	1288	Новосибирская область, городской округ Новосибирск, поселок Озерный, переулок Школьный, 1	f	small
57123	65106	817	Новосибирская область, городской округ Новосибирск, поселок Озерный, в/ч 12202, здание магазина	t	large
112456	65489	1138	Новосибирская область, городской округ Новосибирск, поселок Озерный, Луговая, 4	t	\N
56923	64877	620	Новосибирская область, городской округ Куйбышев, Куйбышев, Карла Либкнехта, 1	f	large
56922	64877	619	Новосибирская область, городской округ Куйбышев, Куйбышев, Карла Либкнехта, 1	f	large
56608	64502	302	Новосибирская область, городской округ Бердск, поселок Мичуринский	f	small
57102	94785	796	Новосибирская область, городской округ Бердск, поселок Мичуринский, Солнечная, 10	f	large
57662	65749	1356	Новосибирская область, городской округ Бердск, Бердск, 36, Санаторий "Бердский"	f	medium
56606	64500	300	Новосибирская область, городской округ Бердск, поселок Агролес, Жемчужная, 2, здание школы	f	large
56406	64271	101	Новосибирская область, городской округ Барабинск, Барабинск, Некрасова, 65	f	medium
112442	65412	1079	Пермский край, Юсьвинский район, село Мокрушино	t	\N
112496	65726	1337	Тульская область, Щекинский район, поселок Залесный	t	\N
112357	64327	150	Костромская область, Чухломский район, поселок Малинино	t	\N
57631	65712	1325	Новосибирская область, Чулымский район, Чулым	f	medium
57630	65711	1324	Новосибирская область, Чулымский район, Чулым, 3, комбинат Техника	f	small
57626	65708	1320	Новосибирская область, Чулымский район, Чулым	f	large
57625	65707	1319	Новосибирская область, Чулымский район, Чулым, станция Чулымская	f	large
57624	65706	1318	Новосибирская область, Чулымский район, Чулым	f	medium
56553	43154	247	Новосибирская область, Чулымский район, Чулым, станция Чулымская	f	medium
57629	94863	1323	Новосибирская область, Чулымский район, Чулым, Элеваторная, 34	f	medium
57627	46442	1321	Новосибирская область, Чулымский район, Чулым, Трудовая, 64а	f	large
57634	65715	1328	Новосибирская область, Чулымский район, Чулым, Трактовая, 47	f	medium
57633	65714	1327	Новосибирская область, Чулымский район, Чулым, Северная, 7	f	medium
57632	65713	1326	Новосибирская область, Чулымский район, Чулым, Нефтянников, 8	f	small
57628	65709	1322	Новосибирская область, Чулымский район, Чулым, Льва Толстого, 12	f	large
57647	65730	1340	Новосибирская область, Чулымский район, поселок Чикман, Больничная, 18	f	medium
112497	65728	1338	Новосибирская область, Чулымский район, поселок Филимоновский	t	\N
57648	65731	1341	Новосибирская область, Чулымский район, поселок Ужаниха, Гриценко, 3	f	large
57651	65734	1344	Новосибирская область, Чулымский район, поселок Серебрянское, Советская, 40Б	f	large
112499	65741	1349	Новосибирская область, Чулымский район, поселок Секты, Трактовая, 45	t	\N
57637	65718	1331	Новосибирская область, Чулымский район, поселок Пенек	f	small
57645	65729	1339	Новосибирская область, Чулымский район, поселок Осиновский, Молодежная, 22	f	small
57642	65724	1336	Новосибирская область, Чулымский район, поселок Новоиткульское	f	small
57655	65739	1348	Новосибирская область, Чулымский район, поселок Кузнецкий, Школьная	f	small
57652	65735	1345	Новосибирская область, Чулымский район, поселок Кокошишо, Лесная, 7	f	medium
57654	65738	1347	Новосибирская область, Чулымский район, поселок Кабинетное	f	medium
112495	65723	1335	Курганская область, Каргапольский район, село Иткуль	t	\N
112500	65743	1350	Новосибирская область, Чулымский район, поселок Илюшино	t	\N
57635	65716	1329	Новосибирская область, Чулымский район, поселок Золотая Грива, Центральная , 16	f	medium
57650	65733	1343	Новосибирская область, Чулымский район, поселок Воздвиженский, Центральная, 13	f	medium
57640	65721	1334	Новосибирская область, Чулымский район, поселок Большеникольское, Центральная, 35	f	medium
57639	65720	1333	Новосибирская область, Чулымский район, поселок Базово	f	medium
112375	64899	646	Новосибирская область, Чулымский район, поселок Алексеевка, Алексеевская, 14/1	t	\N
57620	65701	1314	Новосибирская область, Чистоозерный район, поселок Яминка, Шевченко, 11	f	small
57622	94862	1316	Новосибирская область, Чистоозерный район, поселок Яблоневка, Озерная, 40	f	small
112482	65658	1281	Новосибирская область, Чистоозерный район, поселок Юдино, Октябрьская, 16	t	\N
57608	94857	1302	Новосибирская область, Чистоозерный район, поселок Шипицыно, Школьная, 16	f	medium
57623	65705	1317	Новосибирская область, Чистоозерный район, поселок Чистоозерное	f	medium
57585	65655	1279	Новосибирская область, Чистоозерный район, поселок Чистоозерное	f	large
57581	65651	1275	Новосибирская область, Чистоозерный район, поселок Чистоозерное, Энергетиков, 8	f	medium
57582	94845	1276	Новосибирская область, Чистоозерный район, поселок Чистоозерное, Покрышкина, 14	f	large
57583	94846	1277	Новосибирская область, Чистоозерный район, поселок Чистоозерное, 50 лет Октября, 3	f	medium
57584	65654	1278	Новосибирская область, Чистоозерный район, поселок Чистоозерное, 50 лет Октября, 9	f	large
57610	65688	1304	Новосибирская область, Чистоозерный район, поселок Чебаклы, Лесная, 19	f	small
112483	65660	1283	Новосибирская область, Чистоозерный район, поселок Чаячье	t	\N
112490	65684	1300	Новосибирская область, Чистоозерный район, поселок Цветнополье, Цветнополье, 26	t	\N
57600	94853	1294	Новосибирская область, Чистоозерный район, поселок Троицкое, 60 лет Октября, 4	f	small
112485	65668	1289	Новосибирская область, Чистоозерный район, поселок Табулгинский, Центральная, 30А	t	\N
112484	65666	1287	Новосибирская область, Чистоозерный район, поселок Табулга	t	\N
57592	94850	1286	Новосибирская область, Чистоозерный район, поселок Табулга, Школьная, 2	f	small
112487	65675	1295	Новосибирская область, Чистоозерный район, поселок Старый Кошкуль	t	\N
57616	94860	1310	Новосибирская область, Чистоозерный район, поселок Романовка, Школьная, 48	f	small
57615	94859	1309	Новосибирская область, Чистоозерный район, поселок Польяново, Первомайская, 29	f	small
56946	64895	643	Новосибирская область, Чистоозерный район, поселок Покровка, Покровская, 41	f	small
57602	94854	1296	Новосибирская область, Чистоозерный район, поселок Павловка, Проселочная, 2	f	small
57586	65656	1280	Новосибирская область, Чистоозерный район, поселок Ольховка, Кирова, 9	f	small
57590	94848	1284	Новосибирская область, Чистоозерный район, поселок Ольгино, Черниговка, 1	f	small
57612	65690	1306	Новосибирская область, Чистоозерный район, поселок Олтарь, Центральная, 11	f	small
57609	94858	1303	Новосибирская область, Чистоозерный район, поселок Новопокровка, Школьная, 27	f	small
57599	94852	1293	Новосибирская область, Чистоозерный район, поселок Новопесчаное, Молодежная, 35	f	small
57605	94855	1299	Новосибирская область, Чистоозерный район, поселок Новокрасное, Молодежная, 35	f	small
56544	64426	238	Новосибирская область, Чистоозерный район, поселок Новоалексеевка, Самарская, 12	t	small
57596	94851	1290	Новосибирская область, Чистоозерный район, поселок Новая Кулында, Центральная, 26	f	medium
112489	65681	1298	Московская область, Луховицкий район, деревня Мухино	t	\N
112488	65679	1297	Новосибирская область, Чистоозерный район, поселок Мироновка, Швачко, 14	t	\N
22763	47493	642	Красноярский край, Норильск, Рудная, 15	f	large
112493	65699	1312	Новосибирская область, Чистоозерный район, поселок Малая Тахта, Озерная, 30-1	t	\N
112486	65671	1291	Новосибирская область, Чистоозерный район, поселок Канавы	t	\N
57619	94861	1313	Новосибирская область, Чистоозерный район, поселок Ишимская, Центральная, 27	f	small
57591	94849	1285	Новосибирская область, Чистоозерный район, поселок Журавка, Центральная, 36Б	f	medium
57588	94847	1282	Новосибирская область, Чистоозерный район, поселок Елизаветинка, Центральная, 55	f	small
56475	64346	169	Новосибирская область, Чистоозерный район, поселок Георгиевка (Юхлино), Заречная, 27	t	small
57607	94856	1301	Новосибирская область, Чистоозерный район, поселок Варваровка, Молодежная, 29	f	small
112491	65693	1308	Новосибирская область, Чистоозерный район, поселок Бугриновка, Озерная, 18	t	\N
112494	65702	1315	Новосибирская область, Чистоозерный район, поселок Большая Тахта	t	\N
57611	65689	1305	Новосибирская область, Чистоозерный район, поселок Барабо-Юдино	f	small
56490	64362	184	Калининградская область, Черняховский район, село Тимофеевка	f	small
112431	65380	1051	Вологодская область, Череповецкий район, село Доронино	t	\N
57547	65609	1241	Новосибирская область, Черепановский район, поселок Ясная Поляна	f	small
57566	65632	1260	Новосибирская область, Черепановский район, поселок Ярки, Новая, 1/1	f	medium
56521	64397	216	Новосибирская область, Черепановский район, поселок Ярки, Ливенская, 2	f	small
57560	65626	1254	Новосибирская область, Черепановский район, поселок Южный	f	small
57569	94843	1263	Новосибирская область, Черепановский район, поселок Шурыгино, Советская, 24	f	medium
57533	65595	1227	Новосибирская область, Черепановский район, Черепаново	f	medium
57531	65593	1225	Новосибирская область, Черепановский район, Черепаново	f	medium
57528	65590	1222	Новосибирская область, Черепановский район, Черепаново	f	large
57536	65598	1230	Новосибирская область, Черепановский район, Черепаново, Юбилейная, 11	f	medium
57535	65597	1229	Новосибирская область, Черепановский район, Черепаново, Цыцаркина, 54	f	medium
57534	65596	1228	Новосибирская область, Черепановский район, Черепаново, Свободная, 59а	f	large
57532	65594	1226	Новосибирская область, Черепановский район, Черепаново, Свободная, 105	f	large
57525	65587	1219	Новосибирская область, Черепановский район, Черепаново, Пролетарская, 71а	f	large
57526	65588	1220	Новосибирская область, Черепановский район, Черепаново, Партизанская, 10б	f	large
57529	65591	1223	Новосибирская область, Черепановский район, Черепаново, Мичурина, 4	f	large
57530	65592	1224	Новосибирская область, Черепановский район, Черепаново, Линейная, 63	f	medium
57527	65589	1221	Новосибирская область, Черепановский район, Черепаново, Богдана Хмельницкого, 1	f	large
112481	65646	1270	Новосибирская область, Черепановский район, поселок Чащино, Центральная, 14	t	\N
112475	65614	1246	Новосибирская область, Черепановский район, поселок Татарка, Заречная, 9	t	\N
56790	64723	484	Новосибирская область, Черепановский район, поселок Семеновский, Молодёжная, 1	t	small
57555	65619	1249	Новосибирская область, Черепановский район, поселок Романово, Школьная, 5	f	small
57578	65648	1272	Новосибирская область, Черепановский район, поселок Пятилетка	f	medium
57562	94842	1256	Новосибирская область, Черепановский район, поселок Пушной, переулок Школьный, 7	f	large
112476	65623	1252	Новосибирская область, Черепановский район, поселок Привольный, Центральная, 8	t	\N
57538	65600	1232	Новосибирская область, Черепановский район, поселок Посевная	f	large
57537	65599	1231	Новосибирская область, Черепановский район, поселок Посевная	f	large
57544	65606	1238	Новосибирская область, Черепановский район, поселок Падун	f	small
57565	65631	1259	Новосибирская область, Черепановский район, поселок Отважный, Молодежная, 8	f	small
57546	65608	1240	Новосибирская область, Черепановский район, поселок Огнева Заимка, Кооперативная, 25	f	medium
57548	65610	1242	Новосибирская область, Черепановский район, поселок Новошмаково, Центральная, 19	f	small
57577	65647	1271	Новосибирская область, Черепановский район, поселок Нововоскресенка, Центральная , 25	f	small
57543	65605	1237	Новосибирская область, Черепановский район, поселок Медведск, Романова, 30	f	large
57563	65629	1257	Новосибирская область, Черепановский район, поселок Майский, Шоссейная, 2	f	medium
56796	64674	490	Новосибирская область, Черепановский район, поселок Майский, Клубная, 12	f	small
57549	65611	1243	Новосибирская область, Черепановский район, поселок Лихановский, Центральная, 20	f	small
57551	65613	1245	Новосибирская область, Черепановский район, поселок Листвянка, Школьная, 6	f	small
57573	65641	1267	Новосибирская область, Черепановский район, поселок Куриловка	f	small
57567	65618	1261	Новосибирская область, Черепановский район, поселок Крутишка, Школьная, 2а	f	small
57575	65644	1269	Новосибирская область, Черепановский район, поселок Карасево, Гагарина, 8а	f	medium
57568	65634	1262	Новосибирская область, Черепановский район, поселок Карагужево, Широкая, 6	f	small
57553	65616	1247	Новосибирская область, Черепановский район, поселок Искра, Центральная, 4а	f	medium
57580	65650	1274	Новосибирская область, Черепановский район, поселок Инской, Центральная, 4	f	small
57556	65620	1250	Новосибирская область, Черепановский район, поселок Зимовье, Ленина, 6	f	small
112477	65625	1253	Новосибирская область, Черепановский район, поселок Еловкино, Южная, 3	t	\N
57542	65604	1236	Новосибирская область, Черепановский район, поселок Дорогино	f	medium
57541	65603	1235	Новосибирская область, Черепановский район, поселок Дорогино	f	large
57540	65602	1234	Новосибирская область, Черепановский район, поселок Дорогино	f	large
57539	65601	1233	Новосибирская область, Черепановский район, поселок Дорогина Заимка	f	small
57579	65649	1273	Новосибирская область, Черепановский район, поселок Грибной, Мира, 33	f	small
57545	65607	1239	Новосибирская область, Черепановский район, поселок Высокая Поляна	f	small
112478	65637	1264	Новосибирская область, Черепановский район, поселок Виноград	t	\N
57572	94844	1266	Новосибирская область, Черепановский район, поселок Верх-Мильтюши, Торговая, 19/1	f	medium
57550	94840	1244	Новосибирская область, Черепановский район, поселок Бураново, Советская, 8	f	small
57561	65627	1255	Новосибирская область, Черепановский район, поселок Бочкарево, Школьная, 7	f	medium
57557	94841	1251	Новосибирская область, Черепановский район, село Безменово, Вокзальная, 23	f	large
57554	65617	1248	Новосибирская область, Черепановский район, поселок Безменово	f	small
57564	65630	1258	Новосибирская область, Черепановский район, поселок Бариново, Шоссейная, 4	f	small
57500	94834	1194	Новосибирская область, Чановский район, курортный поселок Озеро-Карачи, Школьная, 58	f	medium
57482	65538	1176	Новосибирская область, Чановский район, поселок Юрки, Центральная, 20	f	small
57522	65584	1216	Новосибирская область, Чановский район, поселок Щеглово, 2-ой переулок, 1/1	f	small
112461	65504	1147	Новосибирская область, Чановский район, поселок Черниговка, Заводская, 29	t	\N
57473	65529	1167	Новосибирская область, Чановский район, поселок Чаны	f	small
57470	65526	1164	Новосибирская область, Чановский район, поселок Чаны	f	medium
57468	65524	1162	Новосибирская область, Чановский район, поселок Чаны	f	large
57475	65531	1169	Новосибирская область, Чановский район, поселок Чаны, Пионерская, 1а	f	medium
57467	65523	1161	Новосибирская область, Чановский район, поселок Чаны, Маяковского, 60	f	medium
57471	65527	1165	Новосибирская область, Чановский район, поселок Чаны, Ленина, 254а	f	medium
57472	65528	1166	Новосибирская область, Чановский район, поселок Чаны, Зеленая, 30	f	small
57474	65530	1168	Новосибирская область, Чановский район, поселок Чаны, Бр.Желтиковых, 178	f	medium
57469	65525	1163	Новосибирская область, Чановский район, поселок Чаны, Бр.Желтиковых, 129	f	medium
57517	65578	1211	Новосибирская область, Чановский район, поселок Тебисское	f	medium
57518	65579	1212	Новосибирская область, Чановский район, поселок Тебис, Школьная, 1а	f	small
57503	65563	1197	Новосибирская область, Чановский район, поселок Тармакуль, Центральная, 52	f	small
57521	65583	1215	Новосибирская область, Чановский район, поселок Танчик, Центральная, 26а	f	small
57491	65549	1185	Новосибирская область, Чановский район, поселок Тайский, Тайская, 10/2	f	small
57514	65575	1208	Новосибирская область, Чановский район, поселок Таган, Береговая, 50	f	small
57078	65058	775	Новосибирская область, Мошковский район, поселок Мошнино	f	small
57512	94838	1206	Новосибирская область, Чановский район, поселок Старые Карачи, Центральная, 78В	f	medium
56628	64529	322	Новосибирская область, Чановский район, поселок Старая Преображенка, Советская, 2, помещение администрации МО	f	medium
57490	94833	1184	Новосибирская область, Чановский район, поселок Север, Центральная, 2Б/1	f	small
57519	94839	1213	Новосибирская область, Чановский район, поселок Приомский, Восточная, 12А	f	small
57494	65553	1188	Новосибирская область, Чановский район, поселок Полтавка, Школьная, 58	f	small
57511	94837	1205	Новосибирская область, Чановский район, поселок Покровка, Московская, 14	f	small
57507	94836	1202	Новосибирская область, Чановский район, поселок Погорелка, Центральная, 66	f	small
57492	65550	1186	Новосибирская область, Чановский район, поселок Песчаное Озеро, Центральная, 13	f	small
57476	65532	1170	Новосибирская область, Чановский район, поселок Песцы	f	small
57504	94835	1198	Новосибирская область, Чановский район, поселок Отреченское, Школьная, 8	f	medium
57513	65574	1207	Новосибирская область, Чановский район, поселок Осинцево, Широкая, 33а	f	medium
112373	64837	579	Новосибирская область, Чановский район, поселок Осинцево, Гагарина, 3/2	t	\N
57524	65586	1218	Новосибирская область, Чановский район, поселок Оравка, Центральная, 66	f	small
57499	65559	1193	Новосибирская область, Чановский район, Озеро-Карачинский сельсовет, Школьная, 32	f	small
57498	65558	1192	Новосибирская область, Чановский район, поселок Озеро-Карачи	f	medium
57502	65562	1196	Новосибирская область, Чановский район, поселок Новояркуль, Гагарина, 7	f	small
57516	65577	1210	Новосибирская область, Чановский район, поселок Новояблоновка	f	small
57480	65536	1174	Новосибирская область, Чановский район, поселок Новофеклино, Абрамовская, 19	f	small
57495	65554	1189	Новосибирская область, Чановский район, поселок Новопреображенка, Центральная, 82	f	small
57506	65567	1200	Новосибирская область, Чановский район, поселок Нововасильевский	f	small
112392	64988	717	Новосибирская область, Чановский район, поселок Николаевка, Зеленая, 36	t	\N
57477	65533	1171	Новосибирская область, Чановский район, поселок Моховое, Школьная, 1	f	small
57281	65286	975	Новосибирская область, Чановский район, поселок Моховое, Школьная, 2	t	small
57508	65570	1203	Новосибирская область, Чановский район, поселок Межгривный, Школьная, 1	f	small
57489	65547	1183	Новосибирская область, Чановский район, поселок Малый Тебис, Школьная, 26	f	small
57488	65546	1182	Новосибирская область, Чановский район, поселок Красное, Школьная, 6	f	small
57497	65557	1191	Новосибирская область, Чановский район, поселок Кошкуль, Северная, 14	f	small
112471	65556	1190	Новосибирская область, Чановский район, поселок Кошкуль, Кооперативная, 36	t	\N
112470	65552	1187	Новосибирская область, Чановский район, поселок Ковыльный	t	\N
57484	65540	1178	Новосибирская область, Чановский район, поселок Кабаклы	f	small
57515	65576	1209	Липецкая область, Чаплыгинский район, поселок Зенкино	f	small
57483	65539	1177	Новосибирская область, Чановский район, поселок Земляная Заимка, Центральная, 32	f	small
112472	65566	1199	Новосибирская область, Чановский район, поселок Двуозерный	t	\N
57478	65534	1172	Новосибирская область, Чановский район, поселок Блюдчанское	f	medium
57479	65535	1173	Новосибирская область, Чановский район, поселок Блюдцы, Центральная, 26	f	small
57501	65561	1195	Новосибирская область, Чановский район, поселок Белехта, Молодежная, 23	f	small
112473	65568	1201	Новосибирская область, Чановский район, поселок Аялу, Центральная, 12	f	\N
57464	65518	1158	Новосибирская область, Усть-Таркский район, поселок Яркуль-Матюшкино, Центральная, дом культуры	f	small
57461	94831	1155	Новосибирская область, Усть-Таркский район, поселок Яркуль, Школьная, 4	f	small
112449	65469	1126	Новосибирская область, Усть-Таркский район, поселок Янабино, Крестьянская, 4\\1	t	\N
57459	94830	1153	Новосибирская область, Усть-Таркский район, поселок Щербаки, Кооперативная, 2	f	small
112462	65506	1148	Новосибирская область, Усть-Таркский район, поселок Чичканка, Есенина, 10	t	\N
57481	65537	1175	Новосибирская область, Усть-Таркский район, поселок Черниговка, Большая, 20	f	small
58341	66196	1150	Новосибирская область, Усть-Таркский район, поселок Усть-Тарка	f	medium
57457	65509	1151	Новосибирская область, Усть-Таркский район, поселок Усть-Тарка, Дзержинского, 12, районный Дом культуры	f	large
112463	65507	1149	Новосибирская область, Усть-Таркский район, поселок Усть-Тарка, Комсомольская, 103	f	\N
57453	94828	1146	Новосибирская область, Усть-Таркский район, поселок Угуй, Центральная, 6	f	small
112457	65492	1140	Краснодарский край, Большой Сочи Лазаревский район, село Тихоновка	t	\N
112454	65483	1135	Новосибирская область, Усть-Таркский район, поселок Тарка	t	\N
112458	65494	1142	Новосибирская область, Усть-Таркский район, поселок Силиш, Старосилишинская, 11	t	\N
112460	65501	1145	Новосибирская область, Усть-Таркский район, поселок Резино, Центральная, 24	t	\N
57450	94827	1143	Новосибирская область, Усть-Таркский район, поселок Победа, Центральная, 30	f	small
57430	94819	1123	Новосибирская область, Усть-Таркский район, поселок Октябрьский, Школьная, 2	f	small
57209	65197	903	Новосибирская область, Усть-Таркский район, поселок Новоникольск, Центральная, 22а	t	small
57446	94825	1139	Новосибирская область, Усть-Таркский район, поселок Новоникольск, Центральная, 64	f	small
112455	65486	1137	Пермский край, Пермский район, село Мураши	t	\N
112464	65513	1154	Новосибирская область, Усть-Таркский район, поселок Михайловка, Луговая, 27	t	\N
112448	65468	1125	Новосибирская область, Усть-Таркский район, поселок Мирный, Школьная, 4	t	\N
57371	65397	1066	Новосибирская область, Усть-Таркский район, поселок Мирный, Школьная, 8	f	small
57463	94832	1157	Новосибирская область, Усть-Таркский район, поселок Мартыново, Степная, 13	f	small
57443	94824	1136	Новосибирская область, Усть-Таркский район, поселок Кушаги, Береговая, 21А	f	small
57440	94823	1133	Новосибирская область, Усть-Таркский район, поселок Козино, Школьная, 15	f	small
57438	94821	1131	Новосибирская область, Усть-Таркский район, поселок Камышево, Школьная, 42А	f	small
112370	64807	557	Краснодарский край, Ейский район, поселок Зеленая Роща	t	\N
57434	94820	1127	Новосибирская область, Усть-Таркский район, поселок Еланка, Гагарина, 39	f	medium
112447	65466	1124	Новосибирская область, Усть-Таркский район, поселок Дубровино, Озерная, 20	t	\N
57266	65074	960	Новосибирская область, Усть-Таркский район, поселок Дубровино, Кооперативная, 10	t	small
112459	65498	1144	Новосибирская область, Усть-Таркский район, поселок Дмитриевка, Зелёная , 16	t	\N
57439	94822	1132	Новосибирская область, Усть-Таркский район, поселок Верхнеомка, Школьная, 6	f	small
56673	64582	370	Новосибирская область, Усть-Таркский район, поселок Богословка, Школьная, 32А	f	small
57458	94829	1152	Новосибирская область, Усть-Таркский район, поселок Богословка, Зеленая, 21	f	small
57309	65329	1003	Челябинская область, Увельский район, поселок Кабанка	t	small
57403	65431	1097	Новосибирская область, Убинский район, поселок Черный Мыс, Руднева, 29	f	small
57407	65435	1101	Новосибирская область, Убинский район, поселок Херсонка	t	small
112446	65462	1121	Новосибирская область, Убинский район, поселок Убинское	f	\N
57396	65423	1090	Новосибирская область, Убинский район, поселок Убинское	f	large
57397	65424	1091	Новосибирская область, Убинский район, поселок Убинское, Элеваторная, 3	f	small
57395	65456	1116	Новосибирская область, Убинский район, поселок Убинское, Матросова, 26	f	large
57405	65433	1099	Новосибирская область, Убинский район, поселок Раисино	f	medium
57401	65429	1095	Московская область, Ногинский район, деревня Пешково	f	small
57402	65430	1096	Новосибирская область, Убинский район, поселок Орловское, Центральная, 24	f	small
57400	65428	1094	Новосибирская область, Убинский район, поселок Новодубровское, Центральная, 39	f	small
57412	65443	1106	Новосибирская область, Убинский район, поселок Новогандичево	f	small
57428	94818	1122	Новосибирская область, Убинский район, поселок Николаевский 2-й, Центральная, 21	f	small
57415	65446	1109	Новосибирская область, Убинский район, поселок Московка, Московская, 21	f	small
57413	65444	1107	Новосибирская область, Убинский район, поселок Кундран	f	small
112312	65448	1111	Новосибирская область, Убинский район, поселок Ксеньевка, Озерная, 19	t	\N
57409	65439	1103	Новосибирская область, Убинский район, поселок Круглоозерное	f	small
22717	47462	596	Красноярский край, Норильск, Пушкина, 8	f	large
57410	65440	1104	Новосибирская область, Убинский район, поселок Круглоозерное, Школьная, 19	f	medium
57398	65426	1092	Новосибирская область, Убинский район, поселок Крещенский, Цветочная, 10	t	small
112313	65451	1112	Новосибирская область, Убинский район, поселок Колмаково, Центральная, 13б	t	\N
57424	65458	1118	Новосибирская область, Убинский район, поселок Кожурла, Трудовая, 1	f	medium
57423	65457	1117	Новосибирская область, Убинский район, поселок Кожурла, Ленинская, 1	f	medium
57420	65453	1114	Новосибирская область, Убинский район, поселок Клубничная, Центральная, 7	t	small
57408	65437	1102	Новосибирская область, Убинский район, поселок Кирилловка, Школьная, 2	t	small
57406	65434	1100	Новосибирская область, Убинский район, поселок Каменка, Центральная, 39	f	small
57414	65445	1108	Новосибирская область, Убинский район, поселок Ермолаевка, Центральная, 23	f	small
57416	65447	1110	Новосибирская область, Убинский район, поселок Владимировское, Школьная, 26	f	small
57421	94817	1115	Новосибирская область, Убинский район, поселок Борисоглебский, Школьная, 9	f	small
57426	65461	1120	Новосибирская область, Убинский район, поселок Белоозерный	t	small
57404	94816	1098	Новосибирская область, Убинский район, поселок Асенкритово, Центральная, 39	f	small
57425	65459	1119	Новосибирская область, Убинский район, поселок Александро-Невское, Школьная, 16	f	small
112465	65516	1156	Нижегородская область, Тонкинский район, поселок Воробьи	t	\N
57419	65452	1113	Сахалинская область, Томаринский район, село Новоселово	f	small
112424	65366	1038	Новосибирская область, Тогучинский район, станция Изынский, Путейская, 4	t	\N
112425	65367	1039	Новосибирская область, Тогучинский район, станция Буготак, Железнодорожная, 4	t	\N
57352	65375	1047	Новосибирская область, Тогучинский район, поселок Янченково	f	medium
57370	94805	1065	Новосибирская область, Тогучинский район, поселок Юрты, Центральная, 99	f	medium
112438	65401	1069	Новосибирская область, Тогучинский район, поселок Шубкино	t	\N
57394	94815	1089	Новосибирская область, Тогучинский район, поселок Шахта, Долгих, 1	f	large
57392	65420	1087	Новосибирская область, Тогучинский район, поселок Чемское	f	small
57389	94814	1084	Новосибирская область, Тогучинский район, поселок Усть-Каменка, Мира, 24/1	f	medium
57335	65358	1030	Новосибирская область, Тогучинский район, Тогучин	f	large
57332	65355	1027	Новосибирская область, Тогучинский район, Тогучин	f	large
57330	65353	1025	Новосибирская область, Тогучинский район, Тогучин, Школьная, 2б	f	large
57329	94802	1024	Новосибирская область, Тогучинский район, Тогучин, Челюскинцев, 34	t	small
57331	65354	1026	Новосибирская область, Тогучинский район, Тогучин, Центральная, 60	f	large
57337	65360	1032	Новосибирская область, Тогучинский район, Тогучин, Трактовая, 2	f	large
57333	65356	1028	Новосибирская область, Тогучинский район, Тогучин, Свердлова, 5	f	large
57334	65357	1029	Новосибирская область, Тогучинский район, Тогучин, Никитина, 43	f	large
57336	65359	1031	Новосибирская область, Тогучинский район, Тогучин, Дзержинского, 10	f	large
57385	94812	1080	Новосибирская область, Тогучинский район, поселок Сурково, переулок Клубный, 2	f	medium
57382	94811	1077	Новосибирская область, Тогучинский район, поселок Степногутово, Школьная, 43	f	small
112437	65398	1067	Новосибирская область, Тогучинский район, поселок Старогутово, Центральная, 29	t	\N
112436	65392	1062	Новосибирская область, Тогучинский район, поселок Смирновка, Лесная, 5	t	\N
112434	65386	1056	Новосибирская область, Тогучинский район, поселок Саламатово, Крестьянская, 16	t	\N
57388	94813	1083	Новосибирская область, Тогучинский район, поселок Русско-Семеновский, Школьная, 16	f	small
57380	94810	1075	Новосибирская область, Тогучинский район, поселок Репьево, Центральная, 25	f	medium
57348	65370	1043	Новосибирская область, Тогучинский район, поселок Пойменное, Клубная, 2	f	medium
57357	65381	1052	Новосибирская область, Тогучинский район, поселок Новоабышево	f	small
57339	65362	1034	Новосибирская область, Тогучинский район, поселок Нечаевский, Весенняя, 12	f	medium
112444	65418	1085	Новосибирская область, Тогучинский район, поселок Налетиха, Центральная, 27	t	\N
56760	64751	508	Новосибирская область, Тогучинский район, поселок Мирный, Школьная, 17	f	small
57381	65409	1076	Новосибирская область, Тогучинский район, поселок Льниха, Центральная, 4	f	medium
57378	94809	1073	Новосибирская область, Тогучинский район, поселок Лекарственное, Центральная, 51	f	medium
57376	94807	1071	Новосибирская область, Тогучинский район, поселок Лебедево, Центральная, 51	f	medium
112435	65390	1060	Новосибирская область, Тогучинский район, поселок Кусмень, Новая, 6	t	\N
57368	65394	1063	Новосибирская область, Тогучинский район, поселок Курундус, Суворова, 15	f	medium
57362	65387	1057	Нижегородская область, Дальнеконстантиновский район, село Кудрино	f	medium
57373	94806	1068	Новосибирская область, Тогучинский район, поселок Кудельный Ключ, Лесная, 2	f	medium
57369	65395	1064	Новосибирская область, Тогучинский район, поселок Коурак	f	medium
112441	65411	1078	Новосибирская область, Тогучинский район, поселок Колтырак	t	\N
112430	65378	1049	Краснодарский край, Крыловский район, поселок Ковалевка	t	\N
57364	65389	1059	Новосибирская область, Тогучинский район, поселок Киик	f	medium
112440	65406	1074	Новосибирская область, Тогучинский район, поселок Карпысак	t	\N
112427	65372	1045	Новосибирская область, Тогучинский район, поселок Кадниха	t	\N
112423	65364	1036	Новосибирская область, Тогучинский район, поселок Изынский	t	\N
112432	65383	1054	Новосибирская область, Тогучинский район, поселок Изылы, Озёрная, 1	t	\N
57363	65388	1058	Новосибирская область, Тогучинский район, поселок Златоуст, Центральная, 56	f	small
57358	65382	1053	Новосибирская область, Тогучинский район, поселок Заречное, Гагарина, 1	f	medium
57386	65414	1081	Новосибирская область, Тогучинский район, поселок Долгово, Школьная, 2	f	small
57377	94808	1072	Новосибирская область, Тогучинский район, село Дергоусово, Школьная, 14	f	small
112429	65377	1048	Новосибирская область, Тогучинский район, поселок Гутово, Центральная, 9	t	\N
57346	94803	1041	Новосибирская область, Тогучинский район, поселок Горный, Юбилейная, 1	f	large
112400	65042	762	Новосибирская область, Тогучинский район, поселок Горный, Рабочая, 29	t	\N
57347	94804	1042	Новосибирская область, Тогучинский район, поселок Горный, Планетная, 4	f	large
112433	65384	1055	Хабаровский край, село Гаровка 1-я, улица Центральная	t	\N
56340	64186	34	Новосибирская область, Тогучинский район, поселок Владимировка, Садовая, 38	f	small
57393	65421	1088	Новосибирская область, Тогучинский район, поселок Владимировка, Озерная, 15/1	f	small
112443	65415	1082	Новосибирская область, Тогучинский район, поселок Верх-Ачино, Центральная, 19	t	\N
112426	65371	1044	Новосибирская область, Тогучинский район, поселок Вассино, Центральная, 20/5	t	\N
57342	65365	1037	Новосибирская область, Тогучинский район, поселок Буготак, переулок Центральный, 1в	f	medium
57340	65363	1035	Новосибирская область, Тогучинский район, поселок Борцово, Центральная, 7а	f	medium
112439	65402	1070	Новосибирская область, Тогучинский район, поселок Боровлянка, переулок Школьный, 5	t	\N
57366	65391	1061	Новосибирская область, Тогучинский район, поселок Березиково, Центральная, 1	f	medium
112445	65419	1086	Новосибирская область, Тогучинский район, поселок Аплаксино	t	\N
57288	65297	982	Новосибирская область, Татарский район, поселок Чернышевский	t	small
57264	65265	958	Новосибирская область, Татарский район, поселок Чаны-Сакан	t	small
57300	94468	994	Новосибирская область, Татарский район, поселок Ускюль, Комсомольская, 2 А	f	small
57302	94798	996	Новосибирская область, Татарский район, поселок Увальское, Школьная, 17	f	medium
57307	94800	1001	Новосибирская область, Татарский район, поселок Тайлаково, Озёрная, 17	t	small
57291	65302	985	Новосибирская область, Татарский район, поселок Степановка 2-я, Центральная, 11	t	small
112356	64306	132	Новосибирская область, Татарский район, поселок Сибиряк, Школьная, 12	t	\N
57284	65292	978	Новосибирская область, Татарский район, поселок Северотатарское	f	medium
57299	65313	993	Новосибирская область, Татарский район, поселок Розенталь, Клубная, 15	t	small
57285	65293	979	Новосибирская область, Татарский район, поселок Первомихайловка, Гагарина, 1	f	small
57275	94791	969	Новосибирская область, Татарский район, поселок Орловка, Молодёжная, 10	f	small
57262	65262	956	Новосибирская область, Татарский район, поселок Новотроицк, Центральная, 18 А	f	small
57283	65290	977	Новосибирская область, Татарский район, поселок Новотроицк, Клубная улица, 6	t	small
57265	94775	959	Новосибирская область, Татарский район, поселок Новопокровка, Зелёная, 32	f	medium
57293	65306	987	Новосибирская область, Татарский район, поселок Новопервомайское	f	medium
57269	94790	963	Новосибирская область, Татарский район, поселок Новомихайловка, Учительская, 1 Б	f	medium
56771	64698	465	Новосибирская область, Татарский район, поселок Новомихайловка, Большевистская, 23	f	medium
57263	65263	957	Новосибирская область, Татарский район, поселок Нововознесенка, Надежды, 26	f	small
57280	94794	974	Новосибирская область, Татарский район, поселок Никулино, Школьная, 7 А	f	small
57277	94792	971	Новосибирская область, Татарский район, поселок Николаевка, Ленина, 33	f	small
57296	94796	990	Новосибирская область, Татарский район, поселок Неудачино, 57	f	small
56463	64316	157	Вологодская область, Череповецкий район, село Минино	f	small
57298	65311	992	Новосибирская область, Татарский район, поселок Малый Ермак, Центральная, 9	t	small
57278	65282	972	Новосибирская область, Татарский район, поселок Малая Старинка, Школьная, 3	t	small
57306	94799	1000	Новосибирская область, Татарский район, поселок Лопатино, площадь Центральная, 7	f	small
57295	65308	989	Новосибирская область, Татарский район, поселок Кузнецово, Сухая, 5А	f	small
57310	94801	1004	Новосибирская область, Татарский район, поселок Красноярка, Центральная, 28	f	small
57308	65328	1002	Новосибирская область, Татарский район, поселок Кочневка, Зеленая, 67	f	small
57311	65333	1005	Новосибирская область, Татарский район, поселок Комбар, Центральная , 18 А	t	small
57297	94797	991	Новосибирская область, Татарский район, поселок Козловка, Приозёрная, 25 А	f	small
57260	65350	1023	Новосибирская область, Татарский район, поселок Киевка, Гагарина, 39	f	medium
56971	64926	668	Новосибирская область, Татарский район, поселок Камышино, Центральная, 33а	f	small
57305	65323	999	Новосибирская область, Татарский район, поселок Казачий Мыс, Школьная, 55	f	medium
57270	65272	964	Новосибирская область, Татарский район, поселок Казаткуль, Мира, 4	f	small
57268	65269	962	Нижегородская область, Нижний Новгород, улица Ивановка, 17	t	small
57279	94793	973	Новосибирская область, Татарский район, поселок Зубовка, Ленина, 8 Б	f	small
57290	65300	984	Новосибирская область, Татарский район, поселок Евгеньевка, Школьная, 6	t	small
57289	94795	983	Новосибирская область, Татарский район, поселок Дмитриевка, Школьная, 1	f	medium
57274	65277	968	Новосибирская область, Татарский район, поселок Городенка, Рыбака, 11 А	t	small
57276	65279	970	Новосибирская область, Татарский район, поселок Волово, Сибирская, 2	t	small
57301	65317	995	Новосибирская область, Татарский район, поселок Воздвиженка	t	small
57287	65295	981	Новосибирская область, Татарский район, поселок Ваховский, Школьная, 4	t	small
57282	65288	976	Новосибирская область, Татарский район, поселок Варваровка, Зеленая, 13	t	small
57261	65261	955	Новосибирская область, Татарский район, поселок Богдановка, Мира, 22	t	small
57292	65304	986	Воронежская область, Новоусманский район, поселок Безбожник	t	small
112420	65202	945	Новосибирская область, Сузунский район, с.Харьковка, Новая , 16А	t	\N
57259	65259	954	Новосибирская область, Сузунский район, поселок Шипуновский, Центральная, 26	f	small
57257	65257	952	Новосибирская область, Сузунский район, поселок Шипуново	f	medium
112419	65145	944	Свердловская область, Шалинский район, поселок Шигаево	t	\N
57254	65253	949	Новосибирская область, Сузунский район, поселок Шарчино, Советская, 47	f	medium
57246	65244	941	Новосибирская область, Сузунский район, поселок Шайдурово, Выглазова, 84	f	medium
57258	65258	953	Новосибирская область, Сузунский район, поселок Холодное	f	small
112415	65235	935	Новосибирская область, Сузунский район, поселок Тараданово, Полевая, 8	t	\N
57228	65219	922	Новосибирская область, Сузунский район, поселок Сузун	f	large
57232	65222	926	Новосибирская область, Сузунский район, поселок Сузун, Строительная, 35	f	large
57225	65223	927	Новосибирская область, Сузунский район, поселок Сузун, Партизанская, 213	f	large
57231	65221	925	Новосибирская область, Сузунский район, поселок Сузун, Молодежная, 1	f	large
22781	47504	660	Красноярский край, Норильск, Победы, 11	f	large
57230	65220	924	Новосибирская область, Сузунский район, поселок Сузун, Ленина, 14	f	large
57229	65220	923	Новосибирская область, Сузунский район, поселок Сузун, Ленина, 14	f	large
57227	65218	921	Новосибирская область, Сузунский район, поселок Сузун, Ленина, 53	f	large
57226	65217	920	Новосибирская область, Сузунский район, поселок Сузун, Ленина, 57	f	large
112422	65255	950	Новосибирская область, Сузунский район, поселок Плоское, Молодёжная, 16	t	\N
112412	65225	928	Новосибирская область, Сузунский район, поселок Нечунаевский, Лесниковская, 3	t	\N
57245	65243	940	Новосибирская область, Сузунский район, поселок Мышланка	f	medium
57234	65226	929	Новосибирская область, Сузунский район, поселок Мереть, Чкалова, 20	f	medium
57256	65256	951	Новосибирская область, Сузунский район, поселок Маюрово, Центральная, 13	f	small
57238	65233	933	Новосибирская область, Сузунский район, поселок Малышево, Центральная, 18	f	medium
56526	64401	220	Новосибирская область, Сузунский район, поселок Малышево, Озерная, 13А	t	small
112418	65245	942	Новосибирская область, Сузунский район, поселок Малая Крутишка	t	\N
112413	65227	930	Новосибирская область, Сузунский район, поселок Лесниковский, Рабочая, 1	t	\N
112417	65242	939	Новосибирская область, Сузунский район, поселок Красный Камешок	t	\N
57241	65237	936	Новосибирская область, Сузунский район, поселок Ключики	f	medium
57239	65234	934	Новосибирская область, Сузунский район, поселок Каргаполово	f	medium
112416	65238	937	Новосибирская область, Сузунский район, поселок Земледелец, Центральная, 5	t	\N
57253	65252	948	Новосибирская область, Сузунский район, поселок Заковряжино	f	large
57236	65229	931	Новосибирская область, Сузунский район, поселок Верх-Сузун, Мира, 20	f	medium
57251	65249	946	Новосибирская область, Сузунский район, поселок Болтово, Центральная, 7	f	medium
57243	65240	938	Новосибирская область, Сузунский район, поселок Бобровка	f	large
57248	65247	943	Новосибирская область, Сузунский район, поселок Битки, Ленина, 32А	f	large
112311	65441	1105	Брянская область, Стародубский район, поселок Суходолье	t	\N
57208	65196	902	Новосибирская область, Северный район, деревня Большие Кулики,, Красная, 1а, Красноярский сельсовет	f	small
57222	65212	916	Новосибирская область, Северный район, поселок Чуваши, Советская, 37, Чувашинский сельсовет	f	small
57220	65210	914	Новосибирская область, Северный район, поселок Чебаки, Советская, 16	f	small
57219	94789	913	Новосибирская область, Северный район, поселок Федоровка, Центральная, 29	f	small
57214	65204	908	Новосибирская область, Северный район, поселок Среднеичинский, Центральная, 14	f	small
57216	65206	910	Новосибирская область, Северный район, поселок Северное, Ленина, 18	f	large
57215	65205	909	Новосибирская область, Северный район, поселок Северное, Ленина, 18	f	large
57217	65207	911	Новосибирская область, Северный район, поселок Остяцк	f	small
57218	65208	912	Новосибирская область, Северный район, поселок Останинка, Зеленая, 30	f	small
57213	65203	907	Новосибирская область, Северный район, поселок Новотроицк	f	small
57223	65213	917	Новосибирская область, Северный район, поселок Коб-Кордон, Набережная, 40	f	small
56321	64158	15	Новосибирская область, Северный район, поселок Ивановка, Центральная, 29	f	small
57211	65200	905	Новосибирская область, Северный район, поселок Гражданцево	f	small
57221	65211	915	Новосибирская область, Северный район, поселок Витинск, Центральная, 10, Чебаковский сельсовет	f	small
112411	65216	919	Новосибирская область, Северный район, поселок Весёлая, Веселая, 3	t	\N
57207	65195	901	Новосибирская область, Северный район, поселок Верх-Красноярка	f	small
57204	65214	918	Новосибирская область, Северный район, поселок Биаза, Бугаева, 67	f	small
57206	65199	904	Новосибирская область, Северный район, поселок Бергуль, Гагарина, 12	f	small
57638	65719	1332	Новосибирская область, Северный район, поселок Алексеевка, Сибирская, 27	f	small
112450	65472	1128	Смоленская область, Сафоновский район, поселок Красноникольск	t	\N
57294	65307	988	Тамбовская область, Рассказовский район, поселок Платоновка	f	small
57192	65183	889	Новосибирская область, Ордынский район, поселок Шайдуровский	f	small
57202	65192	899	Новосибирская область, Ордынский район, поселок Чингисы, Школьная, 23	f	small
57171	65162	868	Новосибирская область, Ордынский район, поселок Чернаково, Ильича, 52	f	large
57188	65179	885	Новосибирская область, Ордынский район, поселок Черемшанка, Садовая, 2	f	small
57191	65182	888	Новосибирская область, Ордынский район, поселок Филиппово, Советская, 41	f	medium
57196	65187	893	Новосибирская область, Ордынский район, поселок Устюжанино, Школьная, 7	f	medium
57201	65191	898	Новосибирская область, Ордынский район, поселок Усть-Хмелевка	f	small
57189	65180	886	Новосибирская область, Ордынский район, поселок Усть-Луковка	f	medium
57195	94788	892	Новосибирская область, Ордынский район, поселок Усть-Алеус, Кириллова, 56	f	small
57179	65170	876	Новосибирская область, Ордынский район, поселок Степной	f	small
112371	64811	560	Новосибирская область, Ордынский район, поселок Степной, Школьная, 13	t	\N
57194	65185	891	Новосибирская область, Ордынский район, поселок Спирино, Ленина, 103	f	small
57190	65181	887	Новосибирская область, Ордынский район, поселок Рогалево, Советская, 25	f	medium
57197	65131	894	Новосибирская область, Ордынский район, поселок Пушкарево	f	small
57193	65184	890	Новосибирская область, Ордынский район, поселок Пролетарский	f	large
57174	65165	871	Новосибирская область, Ордынский район, поселок Плотниково, контора производственного участка ЗАО племзавод Ирмень	f	small
57184	65175	881	Новосибирская область, Ордынский район, поселок Петровский	f	large
57166	65157	863	Новосибирская область, Ордынский район, поселок Ордынское	f	large
57167	65158	864	Новосибирская область, Ордынский район, поселок Ордынское, Пушкина, 72	f	large
57168	65159	865	Новосибирская область, Ордынский район, поселок Ордынское, Октябрьская, 12	f	large
57169	65160	866	Новосибирская область, Ордынский район, поселок Ордынское, Западная, 3а	f	large
57183	65174	880	Новосибирская область, Ордынский район, поселок Новый Шарап, Мира, 81	f	large
57175	65166	872	Новосибирская область, Ордынский район, поселок Новопичугово	f	medium
57199	65189	896	Новосибирская область, Ордынский район, поселок Новокузьминка, Центральная, 29	f	small
57200	65190	897	Новосибирская область, Ордынский район, поселок Нижнекаменка	f	medium
57203	65194	900	Новосибирская область, Ордынский район, поселок Милованово, Береговая, 50а	t	small
57181	65172	878	Новосибирская область, Ордынский район, поселок Малый Чик	f	small
57177	65168	874	Новосибирская область, Ордынский район, поселок Малоирменка, Центральная, 7	f	small
57182	65173	879	Новосибирская область, Ордынский район, поселок Красный Яр	f	large
57176	65167	873	Новосибирская область, Ордынский район, поселок Козиха	f	medium
57187	65178	884	Новосибирская область, Ордынский район, поселок Кирза	f	large
57180	65171	877	Новосибирская область, Ордынский район, поселок Верх-Чик, Молодежная, 12	f	small
57172	65163	869	Новосибирская область, Ордынский район, поселок Верх-Ирмень, 20/1, Агрогородок	f	large
57173	65164	870	Новосибирская область, Ордынский район, поселок Верх-Ирмень, Кандикова, 69	f	large
57198	65188	895	Новосибирская область, Ордынский район, поселок Верх-Алеус	f	medium
57170	65161	867	Новосибирская область, Ордынский район, поселок Вагайцево, Космонавтов, 26	f	large
57186	65177	883	Новосибирская область, Ордынский район, поселок Бугринская Роща, Центральная, 5	f	small
57185	65176	882	Новосибирская область, Ордынский район, поселок Борисовский	f	small
57178	65169	875	Новосибирская область, Ордынский район, поселок Березовка, Центральная, 4	f	medium
112428	65374	1046	Омская область, Омский район, поселок Пятилетка	t	\N
57743	65812	1435	Новосибирская область, Новосибирский район, рабочий поселок Кольцово, 1А	f	large
57164	65152	858	Новосибирская область, Новосибирский район, поселок Ярково	f	large
57162	65150	856	Новосибирская область, Новосибирский район, поселок Ярково, Подгорбунского, 18, здание школы № 3	f	large
57103	65085	797	Новосибирская область, Новосибирский район, поселок Элитный, Минеральная, 8	f	large
57145	65132	839	Новосибирская область, Новосибирский район, поселок Тулинский, Академика Першилина, 21, Областной центр образования	f	large
57158	65146	852	Новосибирская область, Новосибирский район, поселок Толмачево	f	large
57157	65146	851	Новосибирская область, Новосибирский район, поселок Толмачево	f	large
57731	65804	1424	Новосибирская область, Новосибирский район, поселок Толмачево, Олега Кошевого, 30А	f	large
57133	65116	827	Новосибирская область, Новосибирский район, поселок Степной, Центральная, здание школы №33	f	small
56612	94722	306	Новосибирская область, Новосибирский район, поселок Сосновка, Школьная, 52А	f	medium
57132	65115	826	Новосибирская область, Новосибирский район, поселок Сосновка, Центральная, здание школы № 32	f	medium
57121	65103	815	Новосибирская область, Новосибирский район, поселок Советский, Береговая, здание школы № 29	f	small
57163	65151	857	Новосибирская область, Новосибирский район, поселок Сенчанка, Строителей, 32, здание Дома культуры	f	small
57138	65124	832	Новосибирская область, Новосибирский район, поселок Садовый, Совхозная, 3а	f	large
57129	65112	823	Новосибирская область, Новосибирский район, поселок Раздольное, Ленина, 2, здание школы № 19	f	large
112410	65156	862	Краснодарский край, Большой Сочи Хостинский район, поселок Прогресс	t	\N
57153	65140	847	Новосибирская область, Новосибирский район, поселок Приобский	f	medium
57127	65110	821	Новосибирская область, Новосибирский район, поселок Плотниково	f	large
57156	65143	850	Новосибирская область, Новосибирский район, поселок Пайвино	t	small
57124	65107	818	Новосибирская область, Новосибирский район, поселок Новолуговое	f	large
57909	94867	1538	Новосибирская область, Новосибирский район, поселок Мочище, здание санатория Обские зори	f	small
57122	65104	816	Новосибирская область, Новосибирский район, поселок Мочище, Первомайская, 166	f	large
57137	65123	831	Новосибирская область, Новосибирский район, поселок Мочище, Линейная, 68, здание администрации с/совета	f	large
57649	65732	1342	Новосибирская область, Новосибирский район, поселок Михайловский, Зеленая, 2А	f	small
57150	65137	844	Новосибирская область, Новосибирский район, поселок Марусино	f	large
57104	65086	798	Новосибирская область, Новосибирский район, поселок Ленинское, Ленина, 50, здание школы № 47	f	large
57139	65125	833	Новосибирская область, Новосибирский район, поселок Ленинский	f	medium
57151	94786	845	Новосибирская область, Новосибирский район, поселок Кудряшовский, Октябрьская , 16а	f	large
57152	65139	846	Новосибирская область, Новосибирский район, поселок Кудряшовский, Октябрьская , 16А	f	large
57134	65118	828	Новосибирская область, Новосибирский район, поселок Кубовая, здание школы № 31	f	small
57144	65130	838	Новосибирская область, Новосибирский район, поселок Крупской, Степная, 1, здание школы № 16	f	small
57149	65136	843	Новосибирская область, Новосибирский район, поселок Криводановка	f	large
57148	65136	842	Новосибирская область, Новосибирский район, поселок Криводановка	f	large
57147	65135	841	Новосибирская область, Новосибирский район, поселок Криводановка	f	large
57131	65114	825	Новосибирская область, Новосибирский район, поселок Красный Яр, 1, здание ДК	f	large
57146	65133	840	Новосибирская область, Новосибирский район, поселок Красный Восток, Советская, 65/1, зд. конторы ОАО "Тулинское"	t	small
57109	65091	803	Новосибирская область, Новосибирский район, поселок Краснообск, 75, здание школы № 1	f	large
57108	65090	802	Новосибирская область, Новосибирский район, поселок Краснообск, здание Дома Ученых	f	large
57107	65089	801	Новосибирская область, Новосибирский район, поселок Краснообск, 209, здание школы № 13	f	large
57105	65087	799	Новосибирская область, Новосибирский район, Краснообск, 76а, здание школы № 2	f	large
57161	65149	855	Новосибирская область, Новосибирский район, поселок Красномайский, Школьная, 17, здание школы № 49	f	small
57159	94787	853	Новосибирская область, Новосибирский район, поселок Красноглинное, Мира, 12	f	large
57747	65816	1439	Новосибирская область, Новосибирский район, поселок Кольцово	f	large
57746	65815	1438	Новосибирская область, Новосибирский район, поселок Кольцово, 30А	f	large
57745	65814	1437	Новосибирская область, Новосибирский район, поселок Кольцово, 14	f	large
57744	65813	1436	Новосибирская область, Новосибирский район, поселок Кольцово, 9а	f	large
57112	65094	806	Новосибирская область, Новосибирский район, поселок Каинская Заимка	f	small
57115	65097	809	Новосибирская область, Новосибирский район, поселок Издревая, Школьный переулок, 2, здание школы № 161	f	medium
57126	65109	820	Новосибирская область, Новосибирский район, поселок Издревая, Лесная, 3, здание клуба	f	medium
57135	65120	829	Новосибирская область, Новосибирский район, поселок Зеленый Мыс, Береговая, 14, помещение клуба дома-интерната	t	small
57128	65111	822	Новосибирская область, Новосибирский район, поселок Жеребцово	f	small
57117	65099	811	Новосибирская область, Новосибирский район, поселок Железнодорожный	f	large
57111	65093	805	Новосибирская область, Новосибирский район, поселок Двуречье	f	large
57130	65113	824	Новосибирская область, Новосибирский район, поселок Гусиный Брод, Центральная, 15а, здание школы № 18	f	medium
57165	65153	859	Новосибирская область, Новосибирский район, поселок Голубой Залив, м/район Сибирский, 14, ООО КЖЭК Горский, офис 2	f	small
57119	65101	813	Новосибирская область, Новосибирский район, поселок Восход	f	large
57120	65102	814	Новосибирская область, Новосибирский район, поселок Восход, Титова, 26, контора ЗАО "Чкаловское"	f	large
57141	65127	835	Новосибирская область, Новосибирский район, поселок Витаминка, Центральная, здание ФАП	t	small
57143	65129	837	Новосибирская область, Новосибирский район, поселок Верх-Тула, Советская, 14, здание школы № 14	f	large
57142	65129	836	Новосибирская область, Новосибирский район, поселок Верх-Тула, Советская, 14, здание школы № 14	f	large
57118	65100	812	Новосибирская область, Новосибирский район, поселок Быково, Школьная, 30, здание школы №10	f	small
112408	65154	860	Архангельская область, Коношский район, село Боровое	f	\N
57136	65122	830	Новосибирская область, Новосибирский район, поселок Бибиха, контора СТ Бибиха	t	small
57116	65098	810	Новосибирская область, Новосибирский район, поселок Березовка	f	large
56546	64428	240	Красноярский край, поселок Березовка, улица Центральная, 14	f	small
56987	64947	684	Новосибирская область, Новосибирский район, поселок Березовка, Школьная, 4	f	small
112409	65155	861	Астраханская область, Володарский район, село Береговое	f	\N
57113	65095	807	Новосибирская область, Новосибирский район, поселок Барышево, Матросова, 5, здание школы № 9	f	large
57114	65096	808	Новосибирская область, Новосибирский район, поселок Барышево, Институтский переулок, 4, МУ БКЦ Радуга	f	large
57160	65148	854	Новосибирская область, Новосибирский район, поселок Алексеевка, здание школы № 4	f	small
112376	64903	648	Свердловская область, Нижнесергинский район, поселок Дружинино	t	\N
57086	94782	783	Новосибирская область, Мошковский район, поселок Широкий Яр, Семилетка, 2а	f	medium
57085	65066	782	Новосибирская область, Мошковский район, поселок Участок-Балта, Кирова, 28а	f	small
57272	65274	966	Новосибирская область, Мошковский район, поселок Успенка, Союзная, 36	f	small
57071	65050	768	Новосибирская область, Мошковский район, поселок Успенка, Поросская, 1	f	small
112401	64953	763	Новосибирская область, Мошковский район, поселок Умрева, Восточная, 18а	t	\N
57081	94780	778	Новосибирская область, Мошковский район, поселок Томилово, Школьная, 8	f	small
57069	94777	766	Новосибирская область, Мошковский район, поселок Ташара, Обская, 8	f	medium
57068	65047	765	Новосибирская область, Мошковский район, поселок Ташара, Гагарина, 1в	f	large
57076	65056	773	Новосибирская область, Мошковский район, поселок Станционно-Ояшинский	f	large
57075	65055	772	Новосибирская область, Мошковский район, поселок Станционно-Ояшинский, Производственная, 8	f	large
57094	65077	791	Новосибирская область, Мошковский район, поселок Сокур	f	large
57093	65076	790	Новосибирская область, Мошковский район, поселок Сокур, квартал 4, 4	f	large
57096	65079	793	Новосибирская область, Мошковский район, поселок Смоленский, Победы, 17	f	medium
112402	65046	764	Новосибирская область, Мошковский район, поселок Сарачевка, Н.Передня, 7	t	\N
57080	94779	777	Новосибирская область, Мошковский район, поселок Сарапулка, Ленина, 8	f	medium
57077	94778	774	Новосибирская область, Мошковский район, поселок Радуга, Ключевская, 12	f	medium
112406	65081	794	Новосибирская область, Мошковский район, поселок Орск, Центральная, 2	t	\N
57089	65070	786	Новосибирская область, Мошковский район, поселок Октябрьский	f	large
57073	65052	770	Новосибирская область, Мошковский район, поселок Обской	f	medium
57064	65041	761	Новосибирская область, Мошковский район, поселок Новомошковское	f	medium
57061	65038	758	Новосибирская область, Мошковский район, поселок Мошково	f	large
57079	65059	776	Новосибирская область, Мошковский район, поселок Мошково, Школьная, 17	f	small
57060	65037	757	Новосибирская область, Мошковский район, поселок Мошково, Советская, 12	f	large
57059	65036	756	Новосибирская область, Мошковский район, поселок Мошково, Линейная, 61	f	large
57062	65039	759	Новосибирская область, Мошковский район, поселок Мошково, Западная, 2а	f	large
57063	65040	760	Новосибирская область, Мошковский район, поселок Красногорский	f	small
112407	65082	795	Новосибирская область, Мошковский район, поселок Кошево, Школьная, 4	t	\N
57082	94781	779	Новосибирская область, Мошковский район, поселок Кайлы, Школьная, 8	f	small
57095	65078	792	Новосибирская область, Мошковский район, поселок Емельяновский, Школьная, 9	f	small
57083	65063	780	Новосибирская область, Мошковский район, поселок Елтышево	f	small
57070	65049	767	Новосибирская область, Мошковский район, поселок Дубровино, Советская, 25	f	medium
57345	65368	1040	Новосибирская область, Мошковский район, поселок Горный, Советская, 15а	f	large
57087	94783	784	Новосибирская область, Мошковский район, поселок Вороново, Школьная, 2	f	small
112404	65064	781	Новосибирская область, Мошковский район, поселок Верх-Балта	t	\N
57072	65051	769	Новосибирская область, Мошковский район, поселок Белоярка	f	medium
57092	65075	789	Новосибирская область, Мошковский район, поселок Барлакский	f	small
57091	65073	788	Новосибирская область, Мошковский район, поселок Барлак	f	small
57088	94784	785	Новосибирская область, Мошковский район, поселок Балта, Шкрольная, 1	f	medium
57399	65427	1093	республика Башкортостан, Мишкинский район, село Крещенское	f	small
57024	94774	721	Новосибирская область, Маслянинский район, поселок Чупино, Центральная , 28а	f	small
112396	65012	736	Новосибирская область, Маслянинский район, поселок Чудиново, Школьная, 19	t	\N
57035	94776	732	Новосибирская область, Маслянинский район, поселок Суенга, Школьная, 10	f	small
112393	64993	720	Новосибирская область, Маслянинский район, поселок Серебренниково, Центральная, 25	t	\N
57047	65024	744	Новосибирская область, Маслянинский район, поселок Прямское	f	small
112394	65005	730	Новосибирская область, Маслянинский район, поселок Петени	t	\N
57045	65021	742	Новосибирская область, Маслянинский район, поселок Пеньково, Центральная, 17	f	small
57048	65025	745	Новосибирская область, Маслянинский район, поселок Пайвино, Центральная, 42	f	small
57043	65018	740	Новосибирская область, Маслянинский район, поселок Никоново	f	small
57032	65003	729	Новосибирская область, Маслянинский район, поселок Нижняя Матренка, Центральная, 24	f	small
57056	65033	753	Новосибирская область, Маслянинский район, поселок Маслянино	f	medium
57053	65030	750	Новосибирская область, Маслянинский район, поселок Маслянино	f	large
57051	65028	748	Новосибирская область, Маслянинский район, поселок Маслянино	f	large
57049	65026	746	Новосибирская область, Маслянинский район, поселок Маслянино	f	large
57055	65032	752	Новосибирская область, Маслянинский район, поселок Маслянино, Озерная, 136	f	large
57052	65029	749	Новосибирская область, Маслянинский район, поселок Маслянино, Ленинская, 46	f	medium
57050	65027	747	Новосибирская область, Маслянинский район, поселок Маслянино, Коммунистическая, 1	f	large
57054	65031	751	Новосибирская область, Маслянинский район, поселок Маслянино, Заводская, 10	f	large
57058	65035	755	Новосибирская область, Маслянинский район, поселок Маслянино, Больничная, 50б	f	medium
57057	65034	754	Новосибирская область, Маслянинский район, поселок Маслянино, Бердская, 27	f	large
57042	65017	739	Новосибирская область, Маслянинский район, поселок Мамоново	f	large
57040	65014	737	Новосибирская область, Маслянинский район, поселок Малая Томка, Центральная, 14	f	small
57027	64997	724	Новосибирская область, Маслянинский район, поселок Кинтереп	f	small
57038	65011	735	Новосибирская область, Маслянинский район, поселок Загора, Центральная, 7	f	small
112395	65009	734	Новгородская область, Валдайский район, село Жерновка	t	\N
57036	65008	733	Новосибирская область, Маслянинский район, поселок Елбань, Парковая, 9	f	medium
57034	65006	731	Новосибирская область, Маслянинский район, поселок Егорьевское, Почтовая, 7	f	medium
57031	65002	728	Новосибирская область, Маслянинский район, поселок Дубровка	f	medium
112397	65015	738	Новосибирская область, Маслянинский район, поселок Дресвянка, Новая, 4	t	\N
57029	64999	726	Новосибирская область, Маслянинский район, поселок Верх-Ики, Пролетарская, 3	f	small
57030	65001	727	Новосибирская область, Маслянинский район, поселок Борково	f	medium
57028	64998	725	Новосибирская область, Маслянинский район, поселок Большой Изырак	f	medium
57026	64996	723	Новосибирская область, Маслянинский район, поселок Березово	f	small
112398	65019	741	Новосибирская область, Маслянинский район, поселок Барсуково, Центральная, 37	t	\N
57022	94773	719	Новосибирская область, Маслянинский район, поселок Бажинск, Советская, 9	f	small
57025	64995	722	Новосибирская область, Маслянинский район, поселок Александровка	f	small
112414	65230	932	Курская область, Мантуровский район, поселок Камышенка	t	\N
58132	66044	1826	Новосибирская область, Ленинский район, Новосибирск, Крашенинникова, 6а	f	large
58131	66044	1825	Новосибирская область, Ленинский район, Новосибирск, Крашенинникова, 6а	f	large
56824	64762	518	Новосибирская область, Кыштовский район, поселок Черновка, Школьная, 12/1	f	medium
57013	94767	710	Новосибирская область, Кыштовский район, поселок Черновка, Центральная, 2	f	small
56997	64960	694	Новосибирская область, Кыштовский район, поселок Чернаковка, Нарымская, 18	f	small
57002	64966	699	Новосибирская область, Кыштовский район, поселок Усманка, Школьная, 10	f	small
57004	94763	701	Новосибирская область, Кыштовский район, поселок Сергеевка, Школьная, 3	f	small
112387	64965	698	Новосибирская область, Кыштовский район, поселок Пахомово, Соловьева, 26	t	\N
57016	94770	713	Новосибирская область, Кыштовский район, поселок Орловка, Центральная, 2	f	small
57613	65691	1307	Новосибирская область, Кыштовский район, поселок Орловка, Первомайская, 32	f	small
56994	94760	691	Новосибирская область, Кыштовский район, поселок Новый Майзас, Школьная, 7	f	small
57012	94766	709	Новосибирская область, Кыштовский район, поселок Новоложниково, Центральная, 8	f	small
56999	64962	696	Новосибирская область, Кыштовский район, поселок Межовка	f	small
57007	94764	704	Новосибирская область, Кыштовский район, поселок Малокрасноярка, Школьная, 1	f	small
112390	64975	705	Новосибирская область, Кыштовский район, поселок Малая Скирла, Горская, 32	t	\N
56992	64952	689	Новосибирская область, Кыштовский район, поселок Кыштовка	f	small
56989	64949	686	Новосибирская область, Кыштовский район, поселок Кыштовка, Садовая, 10	f	medium
56990	64950	687	Новосибирская область, Кыштовский район, поселок Кыштовка, Мелиоративная, 17	f	medium
56988	64948	685	Новосибирская область, Кыштовский район, поселок Кыштовка, Ленина, 40	f	large
56991	64951	688	Новосибирская область, Кыштовский район, поселок Кыштовка, Волкова, 55	f	large
56996	64959	693	Новосибирская область, Кыштовский район, поселок Куляба, Центральная, 31	f	small
57021	94772	718	Новосибирская область, Кыштовский район, поселок Крутиха, Матросовка, 1	f	small
112386	64958	692	Новосибирская область, Кыштовский район, поселок Коровинка	t	\N
57014	94768	711	Новосибирская область, Кыштовский район, поселок Колбаса, Центральная, 21	f	small
56481	64352	175	Новосибирская область, Кыштовский район, поселок Козловка, Школьная, 7	t	small
57018	64986	715	Новосибирская область, Кыштовский район, поселок Камышинка, Центральная, 60	f	small
57003	94762	700	Новосибирская область, Кыштовский район, поселок Заливино, Центральная, 15А	f	small
57010	64977	707	Новосибирская область, Кыштовский район, поселок Ерёмино	f	small
112385	64955	690	Новосибирская область, Кыштовский район, поселок Вятка, Центральная, 7	t	\N
112388	64969	702	Новосибирская область, Кыштовский район, поселок Воскресенка, Центральная, 17	t	\N
56336	64181	30	Новосибирская область, Кыштовский район, поселок Воскресенка, Центральная, 12	f	small
56998	94761	695	Новосибирская область, Кыштовский район, поселок Верх-Тарка, Волкова, 70	f	small
57017	64985	714	Новосибирская область, Кыштовский район, поселок Верх-Майзас, Нарымская, 30	f	small
57000	64963	697	Новосибирская область, Кыштовский район, поселок Вараксино	f	small
57015	94769	712	Новосибирская область, Кыштовский район, поселок Бочкарёвка, Школьная, 5	f	small
57009	94765	706	Новосибирская область, Кыштовский район, поселок Большеречье, Смоленская, 6А	f	small
57019	94771	716	Новосибирская область, Кыштовский район, поселок Берёзовка, Заречная, 8	f	small
112389	64971	703	Новосибирская область, Кыштовский район, поселок Бакейка, Центральная, 3	t	\N
56950	64901	647	Новосибирская область, Купинский район, поселок Яркуль, Советская, 43	f	medium
56956	64909	653	Новосибирская область, Купинский район, поселок Шаитик	f	small
56960	64914	657	Новосибирская область, Купинский район, поселок Чумашки	f	small
56954	64907	651	Новосибирская область, Купинский район, поселок Чаинка, Школьная, 19	f	small
56952	64904	649	Новосибирская область, Купинский район, поселок Тюменка	f	small
56944	64893	641	Брянская область, Суземский район, поселок Стеклянное	f	medium
112380	64928	670	Пензенская область, Беднодемьяновский район, Спасск	t	\N
56820	64758	514	Новосибирская область, Купинский район, поселок Советский, Ленина, 22а	f	small
56947	64896	644	Алтайский край, Первомайский район, поселок Сибирский	f	small
56968	64922	665	Новосибирская область, Купинский район, поселок Рождественка, Южная, 66	f	medium
57303	65319	997	Новосибирская область, Купинский район, поселок Рождественка, Светлая, 10 А	t	small
112474	65581	1214	Новосибирская область, Купинский район, поселок Рождественка, Путевая, 2А	t	\N
57286	65294	980	Новосибирская область, Купинский район, поселок Рождественка, Кооперативная, 23	f	small
112399	65023	743	Новосибирская область, Купинский район, поселок Петропавловка, Центральная, 16	t	\N
56967	64921	664	Новосибирская область, Купинский район, поселок Петровка, Центральная, 73	f	small
56945	94757	642	Новосибирская область, Купинский район, поселок Орловка, Центральная, 37	f	small
56983	64943	680	Новосибирская область, Купинский район, поселок Новоселье, Новосельский проспект, 109	f	medium
56959	64913	656	Новосибирская область, Купинский район, поселок Новорозино	f	small
56966	94755	663	Новосибирская область, Купинский район, поселок Новоключи, Школьная, 5	f	medium
56963	64917	660	Новосибирская область, Купинский район, поселок Новоказарино, Надежды, 19	f	small
112379	64925	667	Новосибирская область, Купинский район, поселок Моревка, Морьевская, 23А	t	\N
56985	64945	682	Новосибирская область, Купинский район, поселок Метелево, Центральная, 77	f	small
56972	64927	669	Новосибирская область, Купинский район, поселок Медяково, Пролетарская, 45	f	small
56955	94758	652	Новосибирская область, Купинский район, поселок Мальково, Школьная, 7	f	small
56964	64918	661	Новосибирская область, Купинский район, поселок Лягушье	f	medium
56965	64919	662	Новосибирская область, Купинский район, поселок Лукошино, Центральная, 39	f	small
56936	64887	633	Новосибирская область, Купинский район, Купино	f	large
56942	46158	639	Новосибирская область, Купинский район, Купино	f	large
56939	64890	636	Новосибирская область, Купинский район, Купино, Советов, 89	f	large
56937	64888	634	Новосибирская область, Купинский район, Купино, Советов, 1	f	large
56940	64891	637	Новосибирская область, Купинский район, Купино, Садовая, 143	f	large
56938	64889	635	Новосибирская область, Купинский район, Купино, Осипенко, 84	f	large
56943	64844	640	Новосибирская область, Купинский район, Купино, Новый городок, 34	f	large
57636	65717	1330	Новосибирская область, Купинский район, поселок Куликовка, Центральная, 53	f	medium
112374	64898	645	Новосибирская область, Купинский район, поселок Куликовка, Куликовская, 19А	t	\N
56961	64915	658	Новосибирская область, Купинский район, поселок Копкуль, Центральная, 9	f	small
56984	64944	681	Новосибирская область, Купинский район, поселок Киргинцево	f	medium
56969	64923	666	Новосибирская область, Купинский район, поселок Зятьковка, Центральная, 68а	f	small
56962	94759	659	Новосибирская область, Купинский район, поселок Вороновка, Центральная, 66	f	small
56978	64935	675	Новосибирская область, Купинский район, поселок Вишневка, Центральная, 35	f	small
56975	64932	672	Новосибирская область, Купинский район, поселок Веселый Кут	f	small
57523	65585	1217	Новосибирская область, Купинский район, поселок Васильевка, Центральная, 71	f	small
112382	64937	676	Новосибирская область, Купинский район, поселок Васильевка, Центральная, 23В	t	\N
56981	64940	678	Алтайский край, Благовещенский район, поселок Благовещенка	f	small
112378	64911	655	Новосибирская область, Купинский район, поселок Басково, Школьная, 8	t	\N
56976	64933	673	Новосибирская область, Купинский район, поселок Аполиха	f	small
56986	64946	683	Новосибирская область, Купинский район, поселок Алферовка, Солнечная, 31	f	small
56888	64845	585	Новосибирская область, Куйбышевский район, поселок Ярково	t	small
56895	64853	592	Новосибирская область, Куйбышевский район, поселок Шагир (Татары), Школьная, 9А	f	small
56908	64867	605	Новосибирская область, Куйбышевский район, поселок Чумаково, Советская, 17	f	large
56909	64868	606	Новосибирская область, Куйбышевский район, поселок Ушково	f	medium
56907	64866	604	Новосибирская область, Куйбышевский район, поселок Сергино	f	small
57509	65571	1204	Новосибирская область, Куйбышевский район, поселок Сергино, Речная, 30	f	small
56769	64696	463	Новосибирская область, Куйбышевский район, поселок Сартаково, Школьная, 2а	t	small
56901	64860	598	Новосибирская область, Куйбышевский район, поселок Помельцево, Северная, 1	f	small
56906	64865	603	Новосибирская область, Куйбышевский район, поселок Отрадненское	f	medium
56903	64862	600	Новосибирская область, Куйбышевский район, поселок Осиново	f	small
56885	64840	582	Новосибирская область, Куйбышевский район, поселок Омь, Береговая, 9/2	t	small
56899	64858	596	Новосибирская область, Куйбышевский район, поселок Новоичинское, Школьная, 1А	f	medium
56900	64859	597	Новосибирская область, Куйбышевский район, поселок Нагорное	f	large
56898	64856	595	Новосибирская область, Куйбышевский район, поселок Михайловка, Заимская, 2	f	small
56905	64864	602	Новосибирская область, Куйбышевский район, поселок Кульча	f	small
56935	64886	632	Новосибирская область, Куйбышевский район, Куйбышев, Партизанская, 2	f	large
56934	64886	631	Новосибирская область, Куйбышевский район, Куйбышев, Партизанская, 2	f	large
56929	64882	626	Новосибирская область, Куйбышевский район, Куйбышев, Партизанская, 50	f	large
56920	64875	617	Новосибирская область, Куйбышевский район, Куйбышев, Каинская, 78А	f	large
56919	64875	616	Новосибирская область, Куйбышевский район, Куйбышев, Каинская, 78А	f	large
56927	64880	624	Новосибирская область, Куйбышевский район, Куйбышев, Закраевского, 84	f	large
112348	64229	62	Новосибирская область, Куйбышевский район, поселок Красный Яр, Центральная, 31	t	\N
112498	65737	1346	Новосибирская область, Куйбышевский район, поселок Красновка, 17	t	\N
56892	64850	589	Новосибирская область, Куйбышевский район, поселок Константиновка (Опаринское), Центральная, 38	f	small
57273	65275	967	Новосибирская область, Куйбышевский район, поселок Константиновка (Опаринское), Ленина, 29 Б	f	small
56904	64863	601	Новосибирская область, Куйбышевский район, поселок Кондусла, Центральная, 2/1	f	medium
56897	64855	594	Новосибирская область, Куйбышевский район, поселок Комсомольский	f	small
56894	94754	591	Новосибирская область, Куйбышевский район, поселок Кама, Показановская, 35	f	medium
56896	64854	593	Новосибирская область, Куйбышевский район, поселок Ивушка	f	small
56893	64851	590	Новосибирская область, Куйбышевский район, поселок Зоново, Новая, 61	f	small
56902	64861	599	Новосибирская область, Куйбышевский район, поселок Заречный	f	small
56891	64849	588	Новосибирская область, Куйбышевский район, поселок Горбуново, Рабочая, 22	f	medium
56889	64847	586	Новосибирская область, Куйбышевский район, поселок Гжатск, Центральная, 149	f	medium
56886	64842	583	Новосибирская область, Куйбышевский район, поселок Веснянка, Центральная, 1	f	small
56887	64843	584	Новосибирская область, Куйбышевский район, поселок Верх-Ича, Молодежная, 2а	f	small
56884	64839	581	Новосибирская область, Куйбышевский район, поселок Булатово	f	small
56883	64838	580	Новосибирская область, Куйбышевский район, поселок Балман, Центральная, 22	f	small
56890	64848	587	Новосибирская область, Куйбышевский район, поселок Аул-Бергуль, Рапикова, 71	f	medium
56910	64869	607	Новосибирская область, Куйбышевский район, поселок Андреевка	f	small
56307	64146	1	Новосибирская область, Куйбышевский район, поселок Андреевка, Центральная, 20/1	f	small
56881	64835	578	Новосибирская область, Куйбышевский район, поселок Абрамово, Зеленая, 26	f	large
112381	64930	671	Новосибирская область, Красноярский район, село Украинка, Гагарина , 18	t	\N
56856	64797	550	Новосибирская область, Краснозерский район, поселок Чернаки, Молодежная, 16	f	small
56879	64830	573	Новосибирская область, Краснозерский район, поселок Целинный, Школьная, 1	t	small
112372	64812	561	Новосибирская область, Краснозерский район, поселок Хабаровский, Школьная, 8/2	t	\N
56837	64776	531	Новосибирская область, Краснозерский район, поселок Успенский	t	small
56847	64786	541	Новосибирская область, Краснозерский район, поселок Успенский, Рязань, 32	t	small
56878	64827	572	Новосибирская область, Краснозерский район, поселок Урожайный	t	small
56836	94745	530	Новосибирская область, Краснозерский район, поселок Ульяновка, Зеленорощенская, 9	f	small
56880	64831	574	Новосибирская область, Краснозерский район, поселок Светлое, Центральная, 1А	f	medium
56537	64417	231	Новосибирская область, Краснозерский район, поселок Светлое, Центральная, 53	t	small
56877	64826	571	Новосибирская область, Краснозерский район, поселок Садовый, Почтовая , 18	f	medium
56852	64792	546	Новосибирская область, Краснозерский район, поселок Рямское, Центральная улица, 13	t	small
56875	64824	569	Новосибирская область, Краснозерский район, поселок Полойка	f	large
56871	64820	565	Новосибирская область, Краснозерский район, поселок Половинное	f	large
56873	64822	567	Новосибирская область, Краснозерский район, поселок Половинное, Станционная, 57	f	small
56350	64202	45	Новосибирская область, Краснозерский район, поселок Половинное, Северная, 17	t	small
56872	64821	566	Новосибирская область, Краснозерский район, поселок Половинное, Молодежная, 1А	f	medium
56874	64823	568	Новосибирская область, Краснозерский район, поселок Половинное, Малининская, 17	f	medium
56860	64802	554	Новосибирская область, Краснозерский район, поселок Петропавловка, Полтавская, 6	f	medium
112384	64942	679	Новосибирская область, Краснозерский район, поселок Петропавловка, Зеленая, 38	t	\N
56862	64805	556	Новосибирская область, Краснозерский район, поселок Осинниковский, Московская, 24	t	small
56869	64817	563	Новосибирская область, Краснозерский район, поселок Орехов Лог	f	medium
56865	64809	559	Новосибирская область, Краснозерский район, поселок Октябрьский, Школьная, 25/1	f	medium
56833	94753	577	Новосибирская область, Краснозерский район, поселок Новый Баганенок, Мира, 4	f	small
56861	64803	555	Новосибирская область, Краснозерский район, поселок Нижнечеремошное	f	medium
56859	94750	553	Новосибирская область, Краснозерский район, поселок Мохнатый Лог, Молодежная, 6	f	medium
56855	64796	549	Новосибирская область, Краснозерский район, поселок Майское, Ломоносова, 11	f	medium
56876	64825	570	Новосибирская область, Краснозерский район, поселок Луговой	f	small
56854	64795	548	Новосибирская область, Краснозерский район, поселок Лотошное, Лазорская, 12	f	medium
56850	94747	544	Новосибирская область, Краснозерский район, поселок Локтенок, Центральная, 12	f	small
56853	94749	547	Новосибирская область, Краснозерский район, поселок Лобино, Полтава, 10А	f	medium
56839	64778	533	Новосибирская область, Краснозерский район, поселок Ленинградский, Новая, 20/2	f	small
56864	94751	558	Новосибирская область, Краснозерский район, поселок Курьинский, Школьная, 14	f	small
56846	64785	540	Новосибирская область, Краснозерский район, поселок Красный Хутор	f	small
56844	64783	538	Новосибирская область, Краснозерский район, поселок Краснозерское, Санаторий главный корпус	f	small
56843	64782	537	Новосибирская область, Краснозерский район, поселок Краснозерское	f	large
56840	64779	534	Новосибирская область, Краснозерский район, поселок Краснозерское	f	large
56841	64780	535	Новосибирская область, Краснозерский район, поселок Краснозерское, Советская, 2	f	large
56842	64781	536	Новосибирская область, Краснозерский район, поселок Краснозерское, Панарина, 1	f	large
56851	94748	545	Новосибирская область, Краснозерский район, поселок Конево, Дмитрия Пахомова, 2Б	f	medium
56849	94746	543	Новосибирская область, Краснозерский район, поселок Колыбелька, Центральная, 5	f	medium
56845	64784	539	Новосибирская область, Краснозерский район, поселок Кайгородский, Студенческая, 33А	f	medium
22677	47427	555	Красноярский край, Минусинск, Свердлова, 105	f	large
56838	64777	532	Новосибирская область, Краснозерский район, поселок Казанак, Набарежная, 24а	f	small
56868	64816	562	Новосибирская область, Краснозерский район, поселок Зуевский	t	small
56834	94744	528	Новосибирская область, Краснозерский район, поселок Зубково, Центральная, 62	f	medium
56835	64773	529	Новосибирская область, Краснозерский район, поселок Зубково, Новая, 26, станция Зубково	f	small
112453	65482	1134	Новосибирская область, Краснозерский район, поселок Зеленая Роща, Центральная, 19	t	\N
56870	64818	564	Новосибирская область, Краснозерский район, поселок Голубинский, Центральная, 71	t	small
56848	64788	542	Новосибирская область, Краснозерский район, поселок Гербаево, Новая, 6	f	small
56830	64771	527	Новосибирская область, Краснозерский район, поселок Ганино, Ганинская, 25	t	small
56832	64833	576	Новосибирская область, Краснозерский район, поселок Веселовское	f	medium
56831	94752	575	Новосибирская область, Краснозерский район, поселок Веселовское, Ленина, 24	f	medium
56858	64800	552	Новосибирская область, Краснозерский район, поселок Беспятый	f	small
56829	64769	526	Новосибирская область, Краснозерский район, поселок Аксениха	f	medium
112353	64293	122	Новосибирская область, Красногорский район, деревня Александровка, Длинная, 27	t	\N
56826	64764	520	Свердловская область, Талицкий район, поселок Троицкий	f	medium
56977	64934	674	Новосибирская область, Кочковский район, поселок Советский, Гагарина, 4	f	small
56823	64761	517	Псковская область, Островский район, село Решеты	f	large
56815	64767	524	Новосибирская область, Кочковский район, поселок Республиканский, Центральная, 5	f	small
57598	65672	1292	Новосибирская область, Кочковский район, поселок Покровка, Школьная, 4а	f	small
112452	65476	1130	Новосибирская область, Кочковский район, поселок Покровка, Центральная, 21	t	\N
56819	64757	513	Новосибирская область, Кочковский район, поселок Покровка, Центральная, 6	f	small
56822	64760	516	Новосибирская область, Кочковский район, поселок Новые Решеты	f	small
56817	64755	511	Новосибирская область, Кочковский район, поселок Новоцелинное, Комсомольская, 11	f	large
56818	64756	512	Новосибирская область, Кочковский район, поселок Красная Сибирь	f	medium
56828	64765	522	Новосибирская область, Кочковский район, поселок Кочки, Революционная, 10	f	large
56827	64765	521	Новосибирская область, Кочковский район, поселок Кочки, Революционная, 10	f	large
56816	64768	525	Новосибирская область, Кочковский район, поселок Жуланка, Лахина, 54	f	large
56821	64759	515	Свердловская область, городской округ Нижняя Тура, поселок Ермаковский	f	small
56814	64766	523	Новосибирская область, Кочковский район, поселок Быструха, Центральная, 60	f	large
56825	64763	519	Новосибирская область, Кочковский район, поселок Букреево Плесо	f	small
56802	64739	496	Новосибирская область, Коченевский район, поселок Шагалово, Школьная, 13	f	medium
56800	64737	494	Новосибирская область, Коченевский район, поселок Чистополье, Центральная, 13	f	medium
56813	64750	507	Новосибирская область, Коченевский район, поселок Чик	f	large
56812	64750	506	Новосибирская область, Коченевский район, поселок Чик	f	large
56785	64717	479	Новосибирская область, Коченевский район, поселок Чик, Новая, 2	f	small
56795	64731	489	Новосибирская область, Коченевский район, поселок Целинное	f	medium
56803	64740	497	Смоленская область, Ярцевский район, поселок Федосово	t	small
56792	64727	486	Новосибирская область, Коченевский район, село Федлсиха, Клубная, 12	f	medium
56787	64720	481	Московская область, Троицк, Центральная улица, 30	f	small
56772	64699	466	Новосибирская область, Коченевский район, поселок Студенкино, Лесная, 11	t	small
112479	65639	1265	Новосибирская область, Коченевский район, поселок Семеновский, Центральная, 15	t	\N
56784	64716	478	Калининградская область, Светлый	f	small
56801	64738	495	Новосибирская область, Коченевский район, поселок Речник, Центральная, 6	f	medium
56781	64713	475	Новосибирская область, Коченевский район, поселок Прокудское	f	large
56779	64711	473	Новосибирская область, Коченевский район, поселок Прокудское	f	large
56780	64712	474	Новосибирская область, Коченевский район, поселок Прокудское, Вокзальная, 57	f	medium
56487	64359	181	Тюменская область, Голышмановский район, село Усть-Ламенка	f	small
56776	64706	470	Новосибирская область, Коченевский район, поселок Поваренка, Центральный переулок, 6	f	medium
56770	64697	464	Новосибирская область, Коченевский район, поселок Ольшанский	f	small
56774	64703	468	Новосибирская область, Коченевский район, поселок Овчинниково, Советская, 15а	f	small
56775	64704	469	Новосибирская область, Коченевский район, поселок Новорощинский, Сибирская, 8	t	small
56788	64721	482	Новосибирская область, Коченевский район, поселок Новоотрубное (Улькино)	f	small
56763	64688	457	Новосибирская область, Коченевский район, поселок Новокремлевское, Маяковского, 6	f	large
56764	64689	458	Новосибирская область, Коченевский район, поселок Молот, Заводская, 5	t	small
56798	64733	492	Новосибирская область, Коченевский район, поселок Маслово, Центральная, 10	t	small
56799	64736	493	Новосибирская область, Коченевский район, поселок Малореченка, Школьная, 24	t	small
56794	64729	488	Московская область, Пушкинский район, поселок городского типа Лесной, Школьная улица	t	small
56768	64694	462	Новосибирская область, Коченевский район, поселок Лесная Поляна, Школьная, 4	f	medium
56766	64692	460	Новосибирская область, Коченевский район, поселок Крутологово	f	small
56786	64718	480	Новосибирская область, Коченевский район, поселок Крохалевка	t	small
56807	64745	501	Новосибирская область, Коченевский район, поселок Коченево	f	large
56805	64743	499	Новосибирская область, Коченевский район, поселок Коченево	f	large
56809	64747	503	Новосибирская область, Коченевский район, поселок Коченево, Строительная , 29	f	large
56810	64748	504	Новосибирская область, Коченевский район, поселок Коченево, Строительная, 15	f	large
56806	64744	500	Новосибирская область, Коченевский район, поселок Коченево, Малокузнецкая, 27а	f	large
56808	64746	502	Новосибирская область, Коченевский район, поселок Коченево, Максима Горького, 139а	f	large
56811	64749	505	Новосибирская область, Коченевский район, поселок Коченево, Кузнецкая, 176	f	large
112367	64708	471	Новосибирская область, Коченевский район, поселок Комихинский, Раздольная, 23	t	\N
56797	64732	491	Новосибирская область, Коченевский район, поселок Козлово, Центральная, 11	f	small
56783	64715	477	Новосибирская область, Коченевский район, поселок Катково, Лесная, 1	f	small
56804	64742	498	Новосибирская область, Коченевский район, поселок Казаково, Центральная, 15	f	small
56773	64702	467	Новосибирская область, Коченевский район, поселок Ермиловка, Школьная, 9	t	small
56759	64687	456	Новосибирская область, Коченевский район, поселок Дупленская, Садовая, 25	f	medium
56761	64752	509	Новосибирская область, Коченевский район, поселок Дружный, Цетральная, 1	f	small
56767	64693	461	Новосибирская область, Коченевский район, поселок Вахрушево, Московская, 8/3	f	small
56782	64714	476	Новосибирская область, Коченевский район, поселок Буньково, Молодёжная, 27	f	small
56789	64722	483	Новосибирская область, Коченевский район, поселок Белобородово, Новая, 4	f	small
112368	64754	510	Новосибирская область, Коченевский район, поселок Бармашево, Центральная, 17	t	\N
56778	64709	472	Новосибирская область, Коченевский район, поселок Антоновка, Школьная, 5	t	small
56740	64658	434	Новосибирская область, Колыванский район, поселок Юрт-Ора	t	small
56751	64673	445	Новосибирская область, Колыванский район, поселок Юрт-Акбалык, Центральная, 28	t	small
56737	94743	431	Новосибирская область, Колыванский район, поселок Южино, Школьная, 20	f	small
56749	64669	443	Новосибирская область, Колыванский район, поселок Черный Мыс, Лесная, 20	t	small
56731	64649	425	Новосибирская область, Колыванский район, поселок Чаус, Титова, 24	f	small
56742	64661	436	Новосибирская область, Колыванский район, поселок Тропино	f	small
56746	64665	440	Новосибирская область, Колыванский район, поселок Таловка	f	small
56732	64650	426	Новосибирская область, Колыванский район, поселок Соколово, Советская, 43	f	medium
56738	64656	432	Новосибирская область, Колыванский район, поселок Скала, Калинина, 3	f	large
56736	64654	430	Новосибирская область, Колыванский район, поселок Сидоровка, Советская, 28	f	small
56754	64677	448	Новосибирская область, Колыванский район, поселок Северный, Октябрьская, 2	t	small
56758	64683	452	Новосибирская область, Колыванский район, поселок Пономаревка, Береговая, 40 А	f	small
56753	64676	447	Новосибирская область, Колыванский район, поселок Пихтовка, Максима Горького, 8	f	medium
56743	64663	437	Новосибирская область, Колыванский район, поселок Паутовский	t	small
56735	64653	429	Новосибирская область, Колыванский район, поселок Новотырышкино, Мира, 15	f	medium
56748	64668	442	Новосибирская область, Колыванский район, поселок Новотроицк	f	small
112467	65522	1160	Новосибирская область, Колыванский район, поселок Новоалександровка, Иванова, 26	t	\N
57271	65273	965	Новосибирская область, Колыванский район, поселок Новоалександровка, Горького, 50	f	small
56756	64681	450	Новосибирская область, Колыванский район, поселок Мальчиха, Школьная, 11	t	small
56733	64651	427	Новосибирская область, Колыванский район, поселок Малый Оёш, Октябрьская, 9а	f	small
112492	65696	1311	Новосибирская область, Колыванский район, поселок Малиновка, Лесная, 4	t	\N
56747	64666	441	Новосибирская область, Колыванский район, поселок Малая Черемшанка	t	small
56755	64679	449	Новосибирская область, Колыванский район, поселок Лаптевка	f	small
56757	64682	451	Новосибирская область, Колыванский район, поселок Королевка, Школьная, 20	f	small
56726	64686	455	Новосибирская область, Колыванский район, поселок Колывань	f	large
56728	64646	422	Новосибирская область, Колыванский район, поселок Колывань	f	large
56727	64645	421	Новосибирская область, Колыванский район, поселок Колывань	f	large
56729	64647	423	Новосибирская область, Колыванский район, поселок Колывань, Чехова, 3а	f	medium
56725	64685	454	Новосибирская область, Колыванский район, поселок Колывань, Советская, 48	f	large
56724	64684	453	Новосибирская область, Колыванский район, поселок Колывань, Московская, 48	f	large
56752	64675	446	Новосибирская область, Колыванский район, поселок Кандаурово, Советская, 15	f	medium
56750	64671	444	Новосибирская область, Колыванский район, поселок Казанка, Зарипова, 42	f	small
56745	64664	439	Новосибирская область, Колыванский район, поселок Вьюны	f	small
56744	64664	438	Новосибирская область, Колыванский район, поселок Вьюны	f	small
56734	64652	428	Новосибирская область, Колыванский район, поселок Воробьево, Дорожная, 3	f	small
56741	64660	435	Новосибирская область, Колыванский район, поселок Боярка, Ленина, 8	f	medium
56730	64648	424	Новосибирская область, Колыванский район, поселок Большой Оёш, Суворова, 45	f	medium
56739	64657	433	Новосибирская область, Колыванский район, поселок Амба, Школьная, 9	f	small
56708	64626	405	Новосибирская область, Каргатский район, поселок Чернявский	t	small
56705	64622	402	Новосибирская область, Каргатский район, поселок Форпост-Каргат	f	small
56698	64613	395	Новосибирская область, Каргатский район, поселок Филино	t	small
56714	64635	411	Новосибирская область, Каргатский район, поселок Усть-Сумы	f	small
56700	64616	397	Новосибирская область, Каргатский район, поселок Третьяковский, Сельский клуб	t	small
56706	64623	403	Новосибирская область, Каргатский район, поселок Теренино	t	small
56713	64634	410	Новосибирская область, Каргатский район, поселок Сумы	f	small
56696	64610	393	Новосибирская область, Каргатский район, поселок Старомихайловский, Сельский клуб	t	small
56720	64641	417	Новосибирская область, Каргатский район, поселок Сапожковский, Сельский клуб	f	small
56717	64638	414	Новосибирская область, Каргатский район, поселок Петровский	f	small
56711	64631	408	Новосибирская область, Каргатский район, поселок Первотроицк	f	medium
56709	64628	406	Новосибирская область, Каргатский район, поселок Первомайский, Сельский клуб	t	small
56719	64640	416	Новосибирская область, Каргатский район, поселок Озерки 6-е, Школа	f	small
56704	64621	401	Новосибирская область, Каргатский район, поселок Натальинский, Сельский клуб	t	small
56692	64603	389	Новосибирская область, Каргатский район, поселок Набережное, Дом Культуры	f	medium
56702	64618	399	Новосибирская область, Каргатский район, поселок Мусы, Дом культуры	f	small
56715	64636	412	Новосибирская область, Каргатский район, поселок Москвинка	f	small
56721	64642	418	Новосибирская область, Каргатский район, поселок Маршанское	f	medium
56718	64639	415	Новосибирская область, Каргатский район, поселок Мамонтовое, Администрация сельсовета	f	small
112343	64214	52	Новосибирская область, Барабинский район, поселок Новогутово	t	\N
56697	64611	394	Новосибирская область, Каргатский район, поселок Лебедевский, Сельский клуб	t	small
56712	64632	409	Новосибирская область, Каргатский район, поселок Кубанский, Сельский клуб	t	small
56707	64625	404	Новосибирская область, Каргатский район, поселок Кольцовка	f	small
56691	64602	388	Новосибирская область, Каргатский район, Каргат	f	large
56690	64601	387	Новосибирская область, Каргатский район, Каргат	f	large
56689	64600	386	Новосибирская область, Каргатский район, Каргат	f	large
56688	64599	385	Новосибирская область, Каргатский район, Каргат	f	large
56687	64598	384	Новосибирская область, Каргатский район, Каргат	f	large
56686	64597	383	Новосибирская область, Каргатский район, Каргат, Советская, 124 А	f	large
56699	64615	396	Новосибирская область, Каргатский район, поселок Карган, Дом культуры	f	small
56722	64643	419	Новосибирская область, Каргатский район, поселок Иванкино	f	small
56701	64617	398	Новосибирская область, Каргатский район, поселок Груздевка, Бывший сельский клуб	t	small
56710	64630	407	Новосибирская область, Каргатский район, поселок Голубовский	t	small
56693	64604	390	Новосибирская область, Каргатский район, поселок Гавриловка, Сельский клуб	f	small
112391	64978	708	Новосибирская область, Каргатский район, поселок Гавриловка, Лесная, 10	t	\N
56703	64619	400	Новосибирская область, Каргатский район, поселок Верхний Каргат	f	small
56694	64605	391	Новосибирская область, Каргатский район, поселок Беркуты, Сельский клуб	t	small
56695	64608	392	Новосибирская область, Каргатский район, поселок Безлюдный, Сельский клуб	t	small
56723	64644	420	Новосибирская область, Каргатский район, поселок Аткуль	t	small
56716	64637	413	Новосибирская область, Каргатский район, поселок Алабуга	f	small
112405	65072	787	Курганская область, Каргапольский район, село Локти	t	\N
56650	64558	348	Новосибирская область, Карасукский район, поселок Ягодный, Школьная, 10	f	small
56648	94724	346	Новосибирская область, Карасукский район, поселок Шилово-Курья, Центральная, 27	f	medium
56682	64593	379	Новосибирская область, Карасукский район, поселок Чернокурья, Центральная, 42	f	medium
56649	64557	347	Новосибирская область, Карасукский район, поселок Чернозерка	f	small
56680	94741	377	Новосибирская область, Карасукский район, поселок Хорошее, Набережная, 8	f	medium
56675	64585	372	Новосибирская область, Карасукский район, поселок Троицкое, Зеленая, 37 Г	f	small
112336	64194	40	Новосибирская область, Карасукский район, поселок Троицкое, Зеленая, 22	t	\N
56681	94742	378	Новосибирская область, Карасукский район, поселок Токаревка, Мира, 47	f	small
56672	94739	369	Новосибирская область, Карасукский район, поселок Студеное, 35 лет Победы, 41 А	f	medium
56677	64587	374	Новосибирская область, Карасукский район, поселок Сорочиха	f	small
56662	64571	359	Амурская область, Шимановский район, поселок Свободный Труд	f	small
56657	94728	354	Новосибирская область, Карасукский район, поселок Рождественский, переулок Центральный, 10	f	small
56676	64586	373	Новосибирская область, Карасукский район, поселок Рассказово, Школьная, 17 Б	f	small
56653	94726	351	Новосибирская область, Карасукский район, поселок Поповка, Ленина, 45	f	medium
56668	94735	365	Новосибирская область, Карасукский район, поселок Павловка, Молодёжная, 26	f	small
112366	64560	349	Новосибирская область, Карасукский район, поселок Осолодино, Станционная, 1 А	t	\N
56667	64576	364	Еврейская автономная область, Ленинский район, село Октябрьское	f	medium
56678	64588	375	Новосибирская область, Карасукский район, поселок Озерное-Титово	t	small
56670	94737	367	Новосибирская область, Карасукский район, поселок Новоивановка, Сиреневая, 31	f	small
56660	94730	357	Новосибирская область, Карасукский район, поселок Нестеровка, Заречная, 39/2	f	small
56683	64594	380	Новосибирская область, Карасукский район, поселок Морозовка, Пушкина, 3 А	f	small
112377	64906	650	Новосибирская область, Карасукский район, поселок Михайловка, Центральная, 36	t	\N
56663	94732	360	Новосибирская область, Карасукский район, поселок Михайловка, Ценетральная, 33	f	medium
56674	64584	371	Новосибирская область, Карасукский район, поселок Луганск	t	small
56684	64595	381	Новосибирская область, Карасукский район, поселок Кучугур, Школьная, 1	f	small
56658	64567	355	Новосибирская область, Карасукский район, поселок Кукарка, Школьная, 29	f	small
56646	64554	344	Новосибирская область, Карасукский район, Карасук	f	large
56644	64552	342	Новосибирская область, Карасукский район, Карасук	f	large
56642	64550	340	Новосибирская область, Карасукский район, Карасук	f	large
56639	64547	337	Новосибирская область, Карасукский район, Карасук	f	large
56636	64545	334	Новосибирская область, Карасукский район, Карасук	f	large
56637	64519	335	Новосибирская область, Карасукский район, Карасук, Щорса, 17	f	large
56638	64546	336	Новосибирская область, Карасукский район, Карасук, Фрунзе, 89	f	large
56643	64551	341	Новосибирская область, Карасукский район, Карасук, Тургенева, 14	f	large
56641	64549	339	Новосибирская область, Карасукский район, Карасук, Сергея Лазо, 1	f	medium
56640	64548	338	Новосибирская область, Карасукский район, Карасук, Луначарского, 44	f	large
56645	64553	343	Новосибирская область, Карасукский район, Карасук, Ленина, 157	f	large
56665	94734	362	Новосибирская область, Карасукский район, поселок Карасарт, Центральная, 8	f	small
56659	94729	356	Новосибирская область, Карасукский район, поселок Калиновка, Школьная, 44	f	small
112468	65541	1179	Новосибирская область, Карасукский район, поселок Калиновка, Калиновская, 27	t	\N
56669	94736	366	Новосибирская область, Карасукский район, поселок Калачи, Набережная, 27	f	small
56666	64575	363	Новосибирская область, Карасукский район, поселок Кавкуй, Сельская, 14	f	small
56656	94727	353	Новосибирская область, Карасукский район, поселок Ирбизино, Центральная, 10	f	medium
56661	94731	358	Новосибирская область, Карасукский район, поселок Грамотино, Центральная, 6/2	f	small
56647	94723	345	Новосибирская область, Карасукский район, поселок Благодатное, Центральная, 24	f	medium
56652	94725	350	Новосибирская область, Карасукский район, поселок Белое, Пушкина, 1	f	medium
56679	94740	376	Новосибирская область, Карасукский район, поселок Астродым, Озерная, 30 Г	f	small
56671	94738	368	Новосибирская область, Карасукский район, поселок Анисимовка, Заречная, 28	f	small
56664	94733	361	Новосибирская область, Карасукский район, поселок Александровский, Центральная, 23	f	small
57953	65932	1644	Новосибирская область, Калининский район, Новосибирск, Курчатова, 13/1	f	large
57952	65932	1643	Новосибирская область, Калининский район, Новосибирск, Курчатова, 13/1	f	large
57951	65932	1642	Новосибирская область, Калининский район, Новосибирск, Курчатова, 13/1	f	large
57963	65936	1655	Новосибирская область, Калининский район, Новосибирск, Родники, 4	f	large
57962	65936	1654	Новосибирская область, Калининский район, Новосибирск, Родники, 4	f	large
57961	65936	1653	Новосибирская область, Калининский район, Новосибирск, Родники, 4	f	large
56573	64460	267	Новосибирская область, Искитимский район, поселок Шибково, Советская, 21, здание школы	f	small
56576	64465	270	Новосибирская область, Искитимский район, поселок Шибково, Береговая, 53А, здание администрации с/с	f	small
56581	94718	275	Новосибирская область, Искитимский район, поселок Шадрино, Центральная, 2А	f	small
56622	64520	316	Новосибирская область, Искитимский район, поселок Чупино	t	small
56567	64452	261	Новосибирская область, Искитимский район, поселок Чернореченский	f	large
56634	64538	328	Новосибирская область, Искитимский район, поселок Целинный	t	small
112369	64798	551	Новосибирская область, Искитимский район, поселок Целинный, Зелена, 2	t	\N
56595	64487	289	Новосибирская область, Искитимский район, поселок Харино, Центральная, 2А, помещение клуба	t	small
112365	64544	333	Новосибирская область, Искитимский район, поселок Факел Революции, Красный Факел, 2	f	\N
56593	64485	287	Новосибирская область, Искитимский район, поселок Усть-Чем, Центральная, 21А, клуб	f	small
56585	64474	279	Новосибирская область, Искитимский район, поселок Ургун, Школьная, 7, помещение школы	t	medium
56620	64517	314	Новосибирская область, Искитимский район, поселок Улыбино	f	large
56618	64515	312	Новосибирская область, Искитимский район, поселок Тула	f	small
56574	64461	268	Новосибирская область, Искитимский район, поселок Таскаево	t	small
56596	64489	290	Новосибирская область, Искитимский район, поселок Тальменка	f	large
112340	64206	47	Новосибирская область, Барабинский район, поселок Круглоозерка	t	\N
56623	64522	317	Новосибирская область, Искитимский район, поселок Степной, Первомайская, 16, помещение администрации МО	f	medium
56572	64459	266	Новосибирская область, Искитимский район, поселок Старый Искитим, Солнечный переулок, 2А, помещение Дома культуры	f	medium
56591	64483	285	Новосибирская область, Искитимский район, поселок Старососедово	t	small
56583	94719	277	Новосибирская область, Искитимский район, поселок Станция Евсино, Пушкина, 2	f	large
56619	64516	313	Новосибирская область, Искитимский район, поселок Советский, Школьная, 19, здание школы	f	small
57154	65141	848	Новосибирская область, Искитимский район, Село Новошилово, Степная, 18а, здание школы № 82	f	medium
56569	64454	263	Новосибирская область, Искитимский район, поселок Рябчинка	t	small
56568	64453	262	Новосибирская область, Искитимский район, поселок Рощинский	f	small
112363	64524	319	Новосибирская область, Искитимский район, поселок Раздольный, Лесная, 16	t	\N
56621	64518	315	Новосибирская область, Искитимский район, поселок Первомайский, Садовая, 17А, помещение школы	f	small
56627	64527	321	Новосибирская область, Искитимский район, поселок Октябрьский	t	small
56616	64512	310	Новосибирская область, Искитимский район, поселок Озерки	t	small
56592	64484	286	Новосибирская область, Искитимский район, поселок Новососедово	f	small
56632	64535	326	Новосибирская область, Искитимский район, поселок Новолокти, Советская, 5/5 , здание администрации с/с	f	medium
56575	64464	269	Новосибирская область, Искитимский район, поселок Новолебедевка, Центральная, 23А, клуб	t	small
56605	64499	299	Новосибирская область, Искитимский район, поселок Нижний Коен, Нагорный переулок, 7/1, Здание школы	t	small
56594	64486	288	Новосибирская область, Искитимский район, поселок Мосты, Рабочая, 5, помещение школы 	f	small
56604	64497	298	Новосибирская область, Искитимский район, поселок Морозово, Школьная, 6, школа	f	small
56580	64469	274	Новосибирская область, Искитимский район, поселок Морозово, Тимуровская, 3, помещение ДСОЛКД Тимуровец	f	small
56635	64540	329	Новосибирская область, Искитимский район, поселок Михайловка	t	small
56601	64494	295	Новосибирская область, Искитимский район, поселок Михайловка, Центральная, 17Б, школа	f	small
56611	64506	305	Новосибирская область, Искитимский район, поселок Маяк	f	small
56590	64481	284	Новосибирская область, Искитимский район, поселок Малиновка, Центральная, 31А, помещение клуба	f	small
56579	64468	273	Новосибирская область, Искитимский район, поселок Листвянский	f	large
56559	64444	253	Новосибирская область, Искитимский район, поселок Линево	f	large
56557	64448	331	Новосибирская область, Искитимский район, поселок Линево, пр.Мира, 50, Линевская школа № 4	f	large
56563	64448	257	Новосибирская область, Искитимский район, поселок Линево, пр.Мира, 50, Линевская школа № 4	f	large
56566	64450	260	Новосибирская область, Искитимский район, поселок Линево, пр.Коммунистический, 3, клуб НовЭЗа	f	large
56561	64446	255	Новосибирская область, Искитимский район, поселок Линево, пр.Коммунистический, 3, клуб ЗАО НОВЭЗ	f	large
56556	64542	330	Новосибирская область, Искитимский район, поселок Линево, Листвянская, 31А, Линевская школа № 3	f	large
56562	64447	256	Новосибирская область, Искитимский район, поселок Линево, Листвянская, 43А, детская художественная школа	f	large
56565	64445	259	Новосибирская область, Искитимский район, поселок Линево, Бульвар Ветеранов войны, 10, Линевская школа № 1	f	large
56560	64445	254	Новосибирская область, Искитимский район, поселок Линево, Бульвар Ветеранов войны, 10, Линевская школа № 1	f	large
56564	64449	258	Новосибирская область, Искитимский район, поселок Линево, 4-й микрорайон, 16 , МОУ Гимназия	f	large
56558	64443	252	Новосибирская область, Искитимский район, поселок Линево, 4-й микрорайон, 16, МОУ Гимназия № 1	f	large
112364	64543	332	Новосибирская область, Искитимский район, поселок Легостаево, Новый Поселок, 15А	f	\N
56589	64480	283	Новосибирская область, Искитимский район, поселок Легостаево, Милицейская, 12, помещение Дома культуры	f	large
56610	64505	304	Новосибирская область, Искитимский район, поселок Лебедевка	f	large
56571	64457	265	Новосибирская область, Искитимский район, поселок Койниха	t	small
22790	47512	669	Красноярский край, Сосновоборск, Весенняя, 3	f	large
56603	64496	297	Новосибирская область, Искитимский район, поселок Китерня, Центральная, 2б, помещение школы	f	small
56578	64467	272	Новосибирская область, Искитимский район, поселок Керамкомбинат, Центральная, 5, дом культуры	f	large
56629	64530	323	Новосибирская область, Искитимский район, поселок Каменка, Центральная, 10/2, помещение ФАПа	t	small
56599	64492	293	Новосибирская область, Искитимский район, поселок Калиновка	f	small
57355	65379	1050	Новосибирская область, Искитимский район, поселок Завьялово, Центральная, 6А	f	medium
56617	64514	311	Новосибирская область, Искитимский район, поселок Завьялово, Совхозная, 47, здание школы	f	medium
56597	94721	291	Новосибирская область, Искитимский район, поселок Елбаши, Центральная, 59	f	small
56577	64466	271	Новосибирская область, Искитимский район, поселок Евсино, Речная, 10А, здание клуба	f	medium
56602	64495	296	Новосибирская область, Искитимский район, поселок Дзержинский, Школьный переулок, 2, помещение школы	f	small
56588	64478	282	Новосибирская область, Искитимский район, поселок Девкино	t	small
56586	64476	280	Новосибирская область, Искитимский район, поселок Гусельниково, Центральная, 7, здание Дома культуры	f	medium
56630	64532	324	Новосибирская область, Искитимский район, поселок Горевка, Зеленая, 2, помещение школы	f	small
56633	64537	327	Новосибирская область, Искитимский район, поселок Гилево	t	small
56600	64493	294	Новосибирская область, Искитимский район, поселок Верх-Коен, Газовая, 1, помещение дома культуры	f	medium
56615	64511	309	Новосибирская область, Искитимский район, поселок Быстровка	f	medium
56609	64503	303	Новосибирская область, Искитимский район, поселок Бурмистрово	t	small
56614	64510	308	Новосибирская область, Искитимский район, поселок Бурмистрово, Береговая, 32, дом культуры	f	medium
56624	64523	318	Новосибирская область, Искитимский район, поселок Бородавкино, .Школьная, 6, здание школы	f	small
56626	64526	320	Новосибирская область, Искитимский район, поселок Березовка, Школьная, 2, помещение школы	f	small
56607	64501	301	Новосибирская область, Искитимский район, поселок Бердь, Речная, 24, клуб д.Бердь	f	small
56587	94720	281	Новосибирская область, Искитимский район, поселок Белово, Зеленая, 53	f	medium
56598	64491	292	Новосибирская область, Искитимский район, поселок Барабка	f	small
56631	64534	325	Новосибирская область, Искитимский район, поселок Алексеевский	t	small
56570	64456	264	Новосибирская область, Искитимский район, поселок Александровский	f	small
56554	43294	248	Новосибирская область, Здвинский район, поселок Щелчиха, Садовая, 21	t	small
56555	64439	249	Новосибирская область, Здвинский район, поселок Широкая Курья, Курьинская, 20	t	small
56552	94717	246	Новосибирская область, Здвинский район, поселок Чича, Утюпина, 34	t	small
56550	64434	244	Новосибирская область, Здвинский район, поселок Цветники, Центральная, 37	f	medium
56539	64419	233	Новосибирская область, Здвинский район, поселок Хапово, Ленина, 17А	f	small
56533	64413	227	Новосибирская область, Здвинский район, поселок Старогорносталево	f	medium
112360	64387	206	Новосибирская область, Здвинский район, поселок Сарыбалык, Набережная, 15	t	\N
56548	64431	242	Новосибирская область, Здвинский район, поселок Сарыбалык, Береговая, 9	f	medium
56527	64404	221	Новосибирская область, Здвинский район, поселок Петропавловский, Береговая, 8	t	small
56542	64423	236	Пермский край, Ильинский район, село Петраки	f	small
56547	64430	241	Новосибирская область, Здвинский район, поселок Новощербаки, Центральная, 20	t	small
56540	64420	234	Новосибирская область, Здвинский район, поселок Новороссийское, Центральная, 31	f	small
56528	94715	222	Новосибирская область, Здвинский район, поселок Новогребенщиково, Сартланская, 16/2	t	small
56538	64418	232	Новосибирская область, Здвинский район, поселок Нижний Чулым (Сарапулово)	f	medium
56536	64416	230	Новосибирская область, Здвинский район, поселок Нижний Урюм (Лохмоткино)	f	small
56551	94716	245	Новосибирская область, Здвинский район, поселок Михайловка (Кокуй), Северная, 19	f	small
56541	64421	235	Новосибирская область, Здвинский район, поселок Мамон, Садовая, 4	t	small
56543	64424	237	Новосибирская область, Здвинский район, поселок Маландино, Школьная, 7	f	small
22776	47493	655	Красноярский край, Норильск, Рудная, 15	f	large
56534	64414	228	Новосибирская область, Здвинский район, поселок Лянино, Центральная, 38	f	medium
56523	64441	250	Новосибирская область, Здвинский район, поселок Здвинск	f	large
56524	64442	251	Новосибирская область, Здвинский район, поселок Здвинск, Калинина, 11	f	large
56549	64433	243	Новосибирская область, Здвинский район, поселок Горькое Озеро, Озерная, 1	t	small
56545	64427	239	Калужская область, Калуга, улица Семеново Городище, 11	f	small
56531	64410	225	Новосибирская область, Здвинский район, поселок Верх-Урюм	f	medium
56529	64407	223	Новосибирская область, Здвинский район, поселок Верх-Каргат	f	medium
56530	64408	224	Новосибирская область, Здвинский район, поселок Бережки, Береговая, 1	t	small
56535	64415	229	Новосибирская область, Здвинский район, поселок Барлакуль, Центральная, 40	f	small
56532	64411	226	Новосибирская область, Здвинский район, поселок Алексотово, Молодежная, 13	t	small
56525	64400	219	Новосибирская область, Здвинский район, поселок Алексеевка, Центральная, 27	f	small
56518	64394	213	Новосибирская область, Доволенский район, поселок Шагалка, Центральная, 1	f	small
56520	64396	215	Новосибирская область, Доволенский район, поселок Утянка, Центральная, 49	f	small
56519	64395	214	Новосибирская область, Доволенский район, поселок Утянка, Центральная, 35	f	small
56517	64393	212	Новосибирская область, Доволенский район, Юбилейная, 37	f	medium
56515	64391	210	Новосибирская область, Доволенский район, поселок Суздалка	f	medium
112359	64385	205	Новосибирская область, Доволенский район, поселок Солонцовый, Солнечная, 7	t	\N
56513	64389	208	Новосибирская область, Доволенский район, поселок Согорное	f	medium
112469	65543	1180	Новосибирская область, Доволенский район, поселок Сарыбалык, Клубная, 1	t	\N
56503	64376	198	Новосибирская область, Доволенский район, поселок Покровка	f	small
56496	64369	191	Новосибирская область, Доволенский район, поселок Плеханово	f	small
56522	64398	217	Новосибирская область, Доволенский район, село Кротово, Партизанская , 23, Ярковский с/с	f	small
56509	64383	204	Новосибирская область, Доволенский район, поселок Красная Грива	f	small
56516	64392	211	Новосибирская область, Доволенский район, поселок Комендантка, Набережная, 7А	f	small
56507	64380	202	Новосибирская область, Доволенский район, поселок Комарье, Центральная, 29	f	medium
56506	64379	201	Новосибирская область, Доволенский район, поселок Индерь, Новая, 27Б	f	small
56504	64377	199	Новосибирская область, Доволенский район, поселок Ильинка	f	medium
56478	64349	172	Новосибирская область, Доволенский район, поселок Ильинка, Рабочая, 28	f	small
56505	94714	200	Новосибирская область, Доволенский район, поселок Дружный, Баганская, 24	f	small
56499	64372	194	Новосибирская область, Доволенский район, поселок Довольное	f	large
56498	64371	193	Новосибирская область, Доволенский район, поселок Довольное	f	large
56501	64374	196	Новосибирская область, Доволенский район, поселок Довольное, Рабочая, 1	f	small
56500	64373	195	Новосибирская область, Доволенский район, поселок Довольное, Пушкина, 1	f	large
56497	64370	192	Новосибирская область, Доволенский район, поселок Довольное, Коммунистическая, 12	f	medium
56512	64388	207	Новосибирская область, Доволенский район, поселок Даниловская Ферма, Центральная, 16	f	small
56495	64368	190	Новосибирская область, Доволенский район, поселок Волчанка, Центральная, 4	f	small
56514	64390	209	Новосибирская область, Доволенский район, поселок Брянский	f	small
56508	64381	203	Новосибирская область, Доволенский район, поселок Безногое	f	small
56493	64366	188	Новосибирская область, Доволенский район, поселок Баклуши, Гагарина, 9	f	medium
56502	64375	197	Новосибирская область, Доволенский район, поселок Баган, Школьная, 3	f	small
57487	65545	1181	Нижегородская область, Городецкий район, село Красноселье	f	small
112421	65251	947	Вологодская область, Вологодский район, село Бедрино	t	\N
56489	64361	183	Новосибирская область, Венгеровский район, поселок Шипицыно, Ленина, 55	f	small
56482	64354	176	Новосибирская область, Венгеровский район, поселок Чистое Озеро	t	small
56479	64350	173	Новосибирская область, Венгеровский район, поселок Чаргары, Школьная, 1	f	small
56488	94713	182	Новосибирская область, Венгеровский район, поселок Филошенка, Центральная, 7	f	small
56486	94712	180	Новосибирская область, Венгеровский район, поселок Усть-Изес, Ленина, 74	f	medium
56483	64355	177	Новосибирская область, Венгеровский район, поселок Урез, Зелёная, 2	f	small
56480	64351	174	Новосибирская область, Венгеровский район, поселок Туруновка, Новая, 6а	f	small
56466	64337	160	Новосибирская область, Венгеровский район, поселок Старый Тартас	f	small
56476	94711	170	Новосибирская область, Венгеровский район, поселок Сибирцево 2-е, Школьная, 12	f	medium
56474	64345	168	Новосибирская область, Венгеровский район, поселок Сибирцево 1-е, Центральная, 1	f	small
56457	64328	151	Новосибирская область, Венгеровский район, поселок Селикла, Советская, 49	f	small
56473	94710	167	Новосибирская область, Венгеровский район, поселок Петропавловка 2-я, Школьная, 44	f	small
56470	64341	164	Новосибирская область, Венгеровский район, поселок Петропавловка 1-я, Юбилейная, 12	f	small
56469	94709	163	Новосибирская область, Венгеровский район, поселок Павлово, Площадь, 1	f	small
56460	64332	154	Новосибирская область, Венгеровский район, поселок Орлово, Центральная, 49	t	small
112358	64334	155	Новосибирская область, Венгеровский район, поселок Ночка, Набережная, 6	t	\N
56465	64336	159	Новосибирская область, Венгеровский район, поселок Новый Тартас, Юбилейная, 3	f	medium
56464	94708	158	Новосибирская область, Венгеровский район, поселок Новые Кулики, Центральная, 22	f	small
57267	65268	961	Новосибирская область, Венгеровский район, поселок Минино, Зелёная, 24	t	small
56462	94704	156	Новосибирская область, Венгеровский район, поселок Меньшиково, Школьная, 1а	f	small
56485	64357	179	Новосибирская область, Венгеровский район, поселок Мариинка, Центральная, 26	f	small
56472	64343	166	Новосибирская область, Венгеровский район, поселок Красноярка, Набережная, 28	f	small
56459	64330	153	Новосибирская область, Венгеровский район, поселок Ключевая, Советская, 35	f	small
112183	64339	162	Новосибирская область, Венгеровский район, поселок Игнатьевка, Центральная, 31	t	\N
56467	64338	161	Красноярский край, село Зыково, улица Школьная, 1	f	small
56477	64348	171	Новосибирская область, Венгеровский район, поселок Заречье, Советская, 7	f	medium
112184	64342	165	Новосибирская область, Венгеровский район, поселок Григорьевка, Луговая, 21	t	\N
56458	94707	152	Новосибирская область, Венгеровский район, поселок Воробьёво, Дорожная, 1б	f	small
56334	64179	28	Новосибирская область, Венгеровский район, поселок Вознесенка, Школьная, 50	f	medium
56455	64325	149	Новосибирская область, Венгеровский район, поселок Вознесенка, Ленина, 49	f	medium
56453	64323	147	Новосибирская область, Венгеровский район, поселок Венгерово	f	large
56452	64322	146	Новосибирская область, Венгеровский район, поселок Венгерово, Луговая, 6	f	medium
56451	64364	186	Новосибирская область, Венгеровский район, поселок Венгерово, Ленина, 131	f	large
56491	64363	185	Новосибирская область, Венгеровский район, поселок Венгерово, Ленина, 213	f	medium
56454	64324	148	Новосибирская область, Венгеровский район, поселок Венгерово, Ленина, 66	f	large
56484	64356	178	Новосибирская область, Венгеровский район, поселок Бровничи, Центральная, 31	f	small
56437	64305	131	Новосибирская область, Болотнинский район, поселок Светлая Поляна, Садовая, 2	f	medium
112355	64300	127	Новосибирская область, Болотнинский район, поселок Правососновка, Сосновская, 35	t	\N
56440	64309	134	Новосибирская область, Болотнинский район, поселок Ояш, Школьная, 9	f	medium
56441	64310	135	Новосибирская область, Болотнинский район, поселок Ояш, 2-я Школьная улица, 24	f	small
56414	64278	108	Новосибирская область, Болотнинский район, поселок Кунчурук, Центральная улица, 13	f	small
56435	94705	129	Новосибирская область, Болотнинский район, поселок Кривояш, переулок Центральный, 4	f	small
56432	64299	126	Новосибирская область, Болотнинский район, поселок Корнилово, Новая, 5	f	small
112383	64939	677	Новосибирская область, Болотнинский район, поселок Киевка, Центральная, 24	t	\N
56417	64281	111	Новосибирская область, Болотнинский район, поселок Карасево, Центральная, 74а	f	medium
56418	64282	112	Новосибирская область, Болотнинский район, поселок Карасево, Молодежная улица, 4	f	small
56423	64288	117	Новосибирская область, Болотнинский район, поселок Зудово, Центральная , 71	f	medium
56424	64289	118	Новосибирская область, Болотнинский район, поселок Зудово, Бабахина, 53	f	small
112354	64297	125	Новосибирская область, Болотнинский район, поселок Елфимово, Центральная, 9	t	\N
56436	64304	130	Новосибирская область, Болотнинский район, поселок Егоровка, Школьная, 48	f	small
56415	64279	109	Новосибирская область, Болотнинский район, поселок Дивинка, Центральная , 20а	f	medium
56416	64280	110	Новосибирская область, Болотнинский район, поселок Дивинка, Центральная, 6	f	small
56412	64321	145	Новосибирская область, Болотнинский район, поселок Варламово, Почтовая , 21	f	small
56447	64317	141	Новосибирская область, Болотнинский район, Болотное	f	large
56445	64314	139	Новосибирская область, Болотнинский район, Болотное	f	large
56449	64319	143	Новосибирская область, Болотнинский район, Болотное, Ремесленная, 2	f	large
56444	64313	138	Новосибирская область, Болотнинский район, Болотное, Промышленная, 1	f	large
56450	64320	144	Новосибирская область, Болотнинский район, Болотное, Московская, 220	f	large
56443	64312	137	Новосибирская область, Болотнинский район, Болотное, Московская, 47	f	large
56442	64311	136	Новосибирская область, Болотнинский район, Болотное, Ленина, 4	f	large
56448	64318	142	Новосибирская область, Болотнинский район, Болотное, Березовская, 72а	f	medium
56446	94706	140	Новосибирская область, Болотнинский район, Болотное, 40 лет Победы, 8ж	f	medium
56425	64290	119	Новосибирская область, Болотнинский район, поселок Баратаевка, Пролетарская , 6	f	small
56429	64295	123	Новосибирская область, Болотнинский район, поселок Баратаевка, Озерная, 44	f	small
56426	64291	120	Новосибирская область, Болотнинский район, поселок Баратаевка, Береговая, 2	f	small
56420	64284	114	Новосибирская область, Болотнинский район, поселок Байкал, Центральная, 30	f	small
56430	64296	124	Новосибирская область, Болотнинский район, поселок Ача, Центральная улица, 5	f	small
56654	64563	352	Кемеровская область, Беловский район, поселок Осиновка	t	small
112339	64201	44	Новосибирская область, Барабинский район, станция Кирзинское, Вокзальная, 13	t	\N
56368	94689	63	Новосибирская область, Барабинский район, поселок Юный Пионер, Весенняя, 23	f	small
56351	94684	46	Новосибирская область, Барабинский район, поселок Шубинское, Новая, 1	f	small
56348	94683	43	Новосибирская область, Барабинский район, поселок Устьянцево, Центральная, 35	f	medium
56376	94694	71	Новосибирская область, Барабинский район, поселок Усть-Тандовка, переулок Школьный, 8	f	small
112344	64216	53	Новосибирская область, Барабинский район, поселок Труновское, Северная , 25/2	t	\N
56381	94696	76	Новосибирская область, Барабинский район, поселок Тополевка, Школьная, 9В	f	small
56362	94686	57	Новосибирская область, Барабинский район, поселок Таскаево, Центральная, 87	f	medium
56374	64238	69	Новосибирская область, Барабинский район, поселок Тандов (Аул-Тандов)	t	small
56365	94688	60	Новосибирская область, Барабинский район, поселок Старый Карапуз, Молодёжная, 24	f	small
112351	64248	77	Новосибирская область, Барабинский район, поселок Староярково	t	\N
56354	64209	49	Новосибирская область, Барабинский район, поселок Старощербаково (Марандино), Мира, 9	f	small
56377	64241	72	Новосибирская область, Барабинский район, поселок Сизево, Центральная, 47	f	small
56361	94685	56	Новосибирская область, Барабинский район, поселок Пензино (Моховое), Школьная, 7	f	small
56380	94695	75	Новосибирская область, Барабинский район, поселок Новоярково, Центральная, 25	f	small
56375	94693	70	Новосибирская область, Барабинский район, поселок Новочановское, Центральная, 29	f	medium
56356	64212	51	Новосибирская область, Барабинский район, поселок Новоульяновское, площадь Труда, 2	f	small
112352	64256	84	Новосибирская область, Барабинский район, поселок Новотандово	t	\N
56372	94691	67	Новосибирская область, Барабинский район, поселок Новоспасск, Центральная, 27	f	small
56957	64910	654	Новосибирская область, Барабинский район, поселок Новониколаевка, Южная, 35	f	small
56383	94697	78	Новосибирская область, Барабинский район, поселок Новониколаевка, Школьная, 51	f	small
56369	64231	64	Новосибирская область, Барабинский район, поселок Новокурупкаевка, Башира, 53	f	small
56359	64217	54	Новосибирская область, Барабинский район, поселок Новокозловское, Зеленая, 11	f	medium
112341	64208	48	Новосибирская область, Барабинский район, поселок Красный Пахарь, переулок Сельский, 5а	t	\N
56373	94692	68	Новосибирская область, Барабинский район, поселок Кожевниково (Голованово), Сибирская, 30	f	small
56388	94702	83	Новосибирская область, Барабинский район, поселок Квашнино, Рыбозаводская, 25	f	small
112346	64222	58	Новосибирская область, Барабинский район, поселок Кармышак	t	\N
56378	64242	73	Новосибирская область, Барабинский район, поселок Кармакла, Центральная, 29	f	small
56386	94700	81	Новосибирская область, Барабинский район, поселок Казанцево, Центральная, 32	f	small
56385	94699	80	Новосибирская область, Барабинский район, поселок Зюзя, Молодёжная, 14	f	medium
112349	64233	66	Новосибирская область, Барабинский район, поселок Дунаевка, Школьная, 5	t	\N
112342	64210	50	Новосибирская область, Барабинский район, поселок Горка, Центральная, 1	t	\N
112350	64243	74	Новосибирская область, Барабинский район, поселок Голованово, Школьная, 7	t	\N
56384	94698	79	Новосибирская область, Барабинский район, поселок Богатиха, Центральная, 45	f	small
56387	94701	82	Новосибирская область, Барабинский район, поселок Белово, Центральная, 55	f	small
56364	94687	59	Новосибирская область, Барабинский район, поселок Бакмасиха, Центральная, 11	f	small
56370	94690	65	Новосибирская область, Барабинский район, поселок Бадажки, Майская, 39	f	small
112345	64218	55	Новосибирская область, Барабинский район, поселок Арисово	t	\N
112347	64227	61	Новосибирская область, Барабинский район, поселок Абакумово, Зеленая, 8	t	\N
56320	62403	14	Новосибирская область, Баганский район, поселок Тычкино, Центральная, 7	f	small
56311	64153	5	Новосибирская область, Баганский район, поселок Теренгуль, Школьная, 49	f	small
56317	60388	11	Новосибирская область, Баганский район, поселок Стретинка, Жемчужная, 44	f	small
112328	64166	20	Новосибирская область, Баганский район, поселок Соловьевка, Приозерная, 25	t	\N
112331	64176	26	Новосибирская область, Баганский район, поселок Славянка, Светлая, 25	t	\N
56344	64191	38	Новосибирская область, Баганский район, поселок Савкино, Садовая, 32	f	medium
112323	64150	3	Новосибирская область, Баганский район, поселок Романовка, Зеленая, 28	t	\N
112322	64147	2	Новосибирская область, Баганский район, поселок Районная, переулок Половинный, 7	t	\N
112325	64160	16	Новосибирская область, Баганский район, поселок Подольск, Степная, 9	t	\N
56337	64182	31	Московская область, Ленинский район, деревня Петрушино	f	small
56765	64451	459	Новосибирская область, Баганский район, поселок Первомайский, Целинная, 1	t	small
112332	64177	27	Новосибирская область, Баганский район, поселок Первомайский, Переселенческая , 20А	t	\N
56338	64183	32	Новосибирская область, Баганский район, поселок Палецкое	f	medium
112333	64185	33	Кировская область, Шабалинский район, село Осинники	t	\N
112330	64174	25	Новосибирская область, Баганский район, поселок Нижний Баган, Молодежная, 20А	t	\N
56335	64180	29	Новосибирская область, Баганский район, поселок Мироновка, Центральная, 38	f	medium
56328	64169	22	Новосибирская область, Баганский район, поселок Лозовское, Центральная, 30	f	small
112403	65054	771	Россия, Тамбовская область, Уваровский район, поселок Кузнецовка	t	\N
56327	64168	21	Новосибирская область, Баганский район, поселок Кузнецовка, Центральная, 27	f	small
112334	64187	35	Новосибирская область, Баганский район, поселок Красный Остров, Зеленая, 32	t	\N
112329	64171	23	Алтайский край, Крутихинский район, поселок Караси	t	\N
112338	64198	42	Новосибирская область, Баганский район, поселок Казанка, Центральная, 30	f	\N
56324	64163	18	Новосибирская область, Баганский район, поселок Казанка, Центральная, 30	f	small
56793	64728	487	Новосибирская область, Баганский район, поселок Казанка, Весенняя, 1	f	small
112335	64192	39	Красноярский край, Минусинский район, поселок Кавказское	t	\N
112326	64161	17	Белгородская область, Волоконовский район, поселок Грушевка	t	\N
56319	60641	13	Новосибирская область, Баганский район, поселок Гнедухино, Молодежная, 29	f	small
56330	64172	24	Новосибирская область, Баганский район, поселок Водино	f	small
112337	64196	41	Новосибирская область, Баганский район, поселок Бронзовка	t	\N
56318	60603	12	Новосибирская область, Баганский район, поселок Бочаниха	f	small
56342	64189	36	Новосибирская область, Баганский район, поселок Большие Луки, Широкая, 50	f	small
56315	64157	9	Новосибирская область, Баганский район, поселок Баган, Сибиряков-Гвардейцев, 75	f	medium
56314	64156	8	Новосибирская область, Баганский район, поселок Баган, Максима Горького, 30	f	large
56312	64154	6	Новосибирская область, Баганский район, поселок Баган, Максима Горького, 18	f	small
56316	60292	10	Новосибирская область, Баганский район, поселок Баган, Куйбышева, 31	f	large
56313	64155	7	Новосибирская область, Баганский район, поселок Баган, Инкубаторская, 3	f	medium
112327	64164	19	Новосибирская область, Баганский район, поселок Александро-Невский, Степная, 39Б	t	\N
112324	64151	4	Новосибирская область, Баганский район, поселок III Интернационал	t	\N
24030	48783	1969	Красноярский край, с.Туруханск, Советская, 17	f	large
24020	42059	1954	Красноярский край, с.Зотино, Рабочая, 30	f	small
23012	47715	898	Красноярский край, с. Вознесенка, Солнечная, 4А	f	medium
24279	49048	2258	Красноярский край, с. Ванавара, Нефтеразведочная, 14	f	medium
23093	47805	988	Красноярский край, с. Богучаны, Ленина, 119	f	large
24270	49039	2249	Красноярский край, п.Суломай, Школьная, 1	t	small
24245	49015	2224	Красноярский край, п. Хета, Сельский дом культуры	t	small
23111	47824	1006	Красноярский край, п. Невонка, Юбилейная, 1А	t	large
23099	47811	994	Красноярский край, п. Гремучий, Береговая, 20 А	f	large
24263	49032	2242	Красноярский край, поселок Юкта, Центральная, 3	t	small
22855	47562	735	Красноярский край, деревня Шивера, Центральная, 4	f	small
23489	48234	1397	Красноярский край, поселок Шахтинский, Лесная, 2	t	small
22801	47521	680	Красноярский край, Шарыпово, 2 микрорайон, 8	f	large
22800	47521	679	Красноярский край, Шарыпово, 2 микрорайон, 8	f	large
22807	47524	686	Красноярский край, Шарыпово, 6 микрорайон, 23	f	large
22806	47524	685	Красноярский край, Шарыпово, 6 микрорайон, 23	f	large
22805	47523	684	Красноярский край, Шарыпово, 6 микрорайон, 58	f	large
22804	47523	683	Красноярский край, Шарыпово, 6 микрорайон, 58	f	large
22798	47519	677	Красноярский край, Шарыпово, 4 микрорайон, 26	f	large
22981	47688	864	Красноярский край, поселок Чистое Поле, Пришкольная, 19	f	medium
23486	48231	1394	Красноярский край, село Чечеул, Кооперативная, 8	f	large
24281	49050	2260	Красноярский край, поселок Чемдальск, Центральная, 2	t	small
24249	49019	2228	Красноярский край, село Хатанга, Советская, 24-А	f	large
24035	48788	1975	Красноярский край, поселок Фарково, Киевская, 13	t	small
24113	48864	2055	Красноярский край, Уяр, Л.Чайкиной, 15	f	medium
22230	47147	81	Красноярский край, поселок Усть-Мана, Дом культуры	t	medium
24066	48818	2008	Красноярский край, Ужур, Тракторная, 4а	f	large
24065	48817	2007	Красноярский край, Ужур, Строителей, 9	f	medium
24061	48813	2003	Красноярский край, Ужур, Ленина, 22	f	large
24063	48815	2005	Красноярский край, Ужур, Гоголя, 13	f	medium
24256	49025	2235	Красноярский край, поселок Тура, Таежная, 1	f	medium
24254	49023	2233	Красноярский край, поселок Тура, Советская, 10	f	large
24257	49026	2236	Красноярский край, поселок городского типа Тура, Увачана, 7	f	large
24255	49024	2234	Красноярский край, поселок городского типа Тура, Увачана, 13 А	f	medium
23687	48446	1612	Красноярский край, поселок Топольки, Набережная, 47	f	small
23016	47717	902	Красноярский край, деревня Терентьево, Гагарина, 14А	f	small
23996	41869	1928	Красноярский край, поселок Тасеево, Кирова, 51	f	medium
22777	47499	656	Красноярский край, Талнах, Энтузиастов, 5	f	large
22773	47499	652	Красноярский край, Талнах, Энтузиастов, 5	f	large
22772	47499	651	Красноярский край, Талнах, Энтузиастов, 5	f	large
23231	47964	1134	Красноярский край, поселок Сухая Балка, Почтовая, 7	t	small
86137	49043	2253	Красноярский край, поселок Суринда, Школьная, 3	t	small
22637	47387	508	Красноярский край, поселок Стрелка, Береговая, 6А	f	large
23229	47962	1132	Красноярский край, деревня Старцево, Новая, 2 А	t	small
22794	47515	673	Красноярский край, Сосновоборск, Юности, 7	f	large
22795	47516	674	Красноярский край, Сосновоборск, Энтузиастов, 26	f	large
22796	47517	675	Красноярский край, Сосновоборск, Труда, 21	f	large
22787	47509	666	Красноярский край, Сосновоборск, Труда, 5	f	large
22788	47510	667	Красноярский край, Сосновоборск, Ленинского Комсомола, 7	f	large
22793	47514	672	Красноярский край, Сосновоборск, 9 Пятилетки, 15	f	large
22792	47513	671	Красноярский край, Сосновоборск, 9 Пятилетки, 24	f	large
22791	47513	670	Красноярский край, Сосновоборск, 9 Пятилетки, 24	f	large
22789	47511	668	Красноярский край, Сосновоборск, 9 Пятилетки, 7	f	large
24154	48906	2097	Красноярский край, поселок Сорокино, Советская, 22А	f	small
23642	48399	1566	Красноярский край, поселок Сорокино, Советская, 6	t	small
22756	47489	635	Красноярский край, Снежногорск, Хантайская Набережная, 10	t	medium
23213	47942	1115	Красноярский край, поселок Снежница, Вокзальная, 3	f	small
24029	48782	1968	Красноярский край, Село Туруханск, Спандаряна, 37, РДК	f	large
134452	94352	2321	Красноярский край, Село Богучаны, промплощадка Богучаского алюминиевого завода	t	large
23094	47806	989	Красноярский край, Село Богучаны, Перенсона, 9	f	large
23097	47809	992	Красноярский край, Село Богучаны, Олимпийская, 1	f	large
23092	47804	987	Красноярский край, Село Богучаны, Октябрьская, 115	f	large
23095	47807	990	Красноярский край, Село Богучаны, Космонавтов, 12	f	large
23096	47808	991	Красноярский край, Село Богучаны, Заречная, 32	f	large
23685	48443	1610	Красноярский край, село Селиваниха, Набережная, 16	f	large
24032	48785	1971	Красноярский край, село Селиваниха, Дудинская, 6	t	small
23957	48702	1879	Красноярский край, поселок Северо-Енисейский, Карла Маркса, 26	f	medium
23950	48702	1880	Красноярский край, поселок Северо-Енисейский, Карла Маркса, 26	f	large
23028	47731	916	Красноярский край, деревня Свищево, Октябрьская, 13	f	small
22257	47173	109	Красноярский край, Светлогорск, Энергетиков, 19, здание КДЦ Заполярье	t	medium
22939	47644	822	Красноярский край, поселок Причулымский, Просвещения, 17	f	medium
22938	47642	821	Красноярский край, поселок Причулымский, Коммунаров, 1А	f	small
23228	47961	1131	Россия, Красноярский край, поселок Придорожный, улица Трактовая	t	small
111145	47648	826	Красноярский край, село Преображенка, Школьная, 3	f	medium
111222	48271	1439	Красноярский край, Поселок Сыромолотово, Солнечная, 32	f	\N
24251	49020	2230	Красноярский край, поселок Попигай, Сельский дом культуры	t	small
23249	47983	1154	Красноярский край, поселок Подтесово, Калинина, 43	f	large
22852	47559	732	Красноярский край, поселок Подгорный, Мира, 9	f	large
22851	47558	731	Красноярский край, поселок Подгорный, Лесная, 7	f	large
23238	47972	1141	Красноярский край, деревня Погорелка, Центральная, 13	f	small
23269	48007	1174	Красноярский край, Погодаево, Калинина, 22	t	small
23088	47802	983	Красноярский край, поселок Пинчуга, Ленина, 13а	t	large
23206	47935	1108	Красноярский край, поселок Памяти 13 Борцов, Советская , 49	f	medium
23208	47937	1110	Красноярский край, поселок Памяти 13 Борцов, Лесная, 15	f	large
23036	47740	925	Красноярский край, деревня Орловка, Октябрьская, 27	f	small
23132	47845	1029	Красноярский край, деревня Орловка, Лесная, 25	f	small
22231	47148	82	Красноярский край, деревня Овсянка, Клуб-филиал	f	large
22232	47149	83	Красноярский край, деревня Овсянка, Набережная, Библиотека-музей В.П. Астафьева	f	small
22743	47481	622	Красноярский край, Норильск, площадь Металлургов, 23	f	large
22742	47481	621	Красноярский край, Норильск, площадь Металлургов, 23	f	large
22779	47502	658	Красноярский край, Норильск, Шахтерская, 14	f	large
22752	47485	631	Красноярский край, Норильск, Хантайская, 17	f	large
22751	47485	630	Красноярский край, Норильск, Хантайская, 17	f	large
22749	47484	628	Красноярский край, Норильск, Талнахская, 64	f	large
22748	47484	627	Красноярский край, Норильск, Талнахская, 64	f	large
22747	47484	626	Красноярский край, Норильск, Талнахская, 64	f	large
22746	47483	625	Красноярский край, Норильск, Талнахская, 71а	f	large
22745	47483	624	Красноярский край, Норильск, Талнахская, 71а	f	large
22730	47472	609	Красноярский край, Норильск, Талнахская, 53а	f	large
22729	47472	608	Красноярский край, Норильск, Талнахская, 53а	f	large
22727	47471	606	Красноярский край, Талнахская, 54	f	large
22726	47470	605	Красноярский край, Норильск, Талнахская, 42	f	large
22759	47491	638	Красноярский край, Норильск, Строителей, 9	f	large
22758	47491	637	Красноярский край, Норильск, Строителей, 9	f	large
22732	47473	611	Красноярский край, Норильск, Советская, 5	f	large
22731	47473	610	Красноярский край, Норильск, Советская, 5	f	large
22741	47480	620	Красноярский край, Норильск, Площадь Металлургов, 15	f	large
22782	47505	661	Красноярский край, Норильск, Первомайская, 34	f	large
22724	47468	603	Красноярский край, Норильск, Павлова, 21	f	large
22723	47468	602	Красноярский край, Норильск, Павлова, 21	f	large
22755	47488	634	Красноярский край, Норильск, Озерная, 23	f	large
22784	47507	663	Красноярский край, Норильск, Норильская, 6	f	large
22785	47508	664	Красноярский край, Норильск, Надеждинская, 3а	f	large
22778	47501	657	Красноярский край, Норильск, Надеждинская, 16	f	large
22740	47479	619	Красноярский край, Норильск, Молодежный проезд, 7	f	large
22739	47479	618	Красноярский край, Норильск, Молодежный проезд, 7	f	large
22738	47478	617	Красноярский край, Норильск, Молодежный проезд, 19	f	large
22737	47478	616	Красноярский край, Норильск, Молодежный проезд, 19	f	large
22736	47477	615	Красноярский край, Норильск, Молодежный проезд, 17	f	large
22735	47477	614	Красноярский край, Норильск, Молодежный проезд, 17	f	large
22728	47469	607	Красноярский край, Норильск, Мира, 3	f	large
22725	47469	604	Красноярский край, Норильск, Мира, 3	f	large
22762	47492	641	Красноярский край, Норильск, Маслова, 1	f	large
22761	47492	640	Красноярский край, Норильск, Маслова, 1	f	large
22760	47492	639	Красноярский край, Норильск, Маслова, 1	f	large
22734	47476	613	Красноярский край, Норильск, Ленинский проспект, 45в	f	large
22733	47474	612	Красноярский край, Норильск, Ленинский проспект, 37в	f	large
22715	47460	594	Красноярский край, Норильск, Ленинский проспект, 9	f	large
22757	47490	636	Красноярский край, Норильск, Кравца, 8а	f	large
22716	47461	595	Красноярский край, Норильск, Комсомольская, 16	f	large
22714	47459	593	Красноярский край, Норильск, Комсомольская, 27	f	large
22713	47458	592	Красноярский край, Норильск, Комсомольская, 5	f	large
22720	47465	599	Красноярский край, Норильск, Кирова, 30	f	large
22771	47498	650	Красноярский край, Норильск, Игарская, 40	f	large
22770	47498	649	Красноярский край, Норильск, Игарская, 40	f	large
22768	47497	647	Красноярский край, Норильск, Игарская, 16	f	large
22775	47500	654	Красноярский край, Норильск, Енисейская, 26	f	large
22774	47500	653	Красноярский край, Норильск, Енисейская, 26	f	large
22719	47464	598	Красноярский край, Норильск, Ветеранов, 17	f	large
22754	47487	633	Красноярский край, Норильск, Вальковская, 6	f	large
22721	47466	600	Красноярский край, Норильск, Богдана Хмельницкого, 12	f	large
22750	47482	629	Красноярский край, Норильск, Бегичева, 11	f	large
22744	47482	623	Красноярский край, Норильск, Бегичева, 11	f	large
22769	47495	648	Красноярский край, Норильск, Бауманская, 22а	f	large
22767	47495	646	Красноярский край, Норильск, Бауманская, 22а	f	large
22766	47495	645	Красноярский край, Норильск, Бауманская, 22а	f	large
22765	47494	644	Красноярский край, Бауманская, 12	f	large
22764	47494	643	Красноярский край, Бауманская, 12	f	large
22780	47503	659	Красноярский край,  Норильск, Школьная, 10	f	large
22718	47463	597	Красноярский край, Норильск, Севастопольская, 8а	f	large
22783	47506	662	Красноярский край, Первомайская, 20А	f	large
22854	47561	734	Красноярский край, поселок Новый Путь, Юрия Гагарина, 2а	f	medium
23488	48233	1396	Красноярский край, поселок Новый Путь, Зеленая, 28	t	small
24252	49021	2231	Красноярский край, поселок Новорыбная, Сельский дом культуры	t	small
24143	48896	2086	Красноярский край, поселок Новокурск, Центральная, 53	t	small
22702	47447	580	Красноярский край, Назарово, Кузнечная, 8	f	large
22705	47450	583	Красноярский край, Назарово, Борисенко, 10	f	large
68003	48968	2190	Красноярский край, Назарово, Арбузова, 112А	f	large
22672	47422	549	Красноярский край, Минусинск, Штабная, 26	f	large
22676	47426	554	Красноярский край, Минусинск, Хвастанцева, 71	f	large
22679	47429	557	Красноярский край, Минусинск, Февральская, 9	f	large
22681	47430	559	Красноярский край, Минусинск, Тимирязева, 9а	f	large
22680	47430	558	Красноярский край, Минусинск, Тимирязева, 9а	f	large
22722	47467	601	Красноярский край, Минусинск, Талнахская, 23	f	large
22682	47431	560	Россия, Красноярский край, Минусинск, Сургуладзе проезд, 4	f	large
22674	47424	552	Россия, Красноярский край, Минусинск, Сургуладзе проезд, 6	f	large
24309	49070	2291	Красноярский край, Минусинск, Советская, 2г	f	medium
22684	47432	562	Россия, Красноярский край, Минусинск, Сафьяновых проезд, 13	f	large
22683	47432	561	Россия, Красноярский край, Минусинск, Сафьяновых проезд, 13	f	large
22675	47425	553	Красноярский край, Минусинск, Подсинская, 41	f	large
23952	48704	1882	Красноярский край, Минусинск, Октябрьская, 8	f	large
22669	47419	546	Красноярский край, Минусинск, Октябрьская, 95А	f	large
22667	47417	544	Красноярский край, Минусинск, Набережная, 93А	f	large
22673	47423	551	Красноярский край, Минусинск, Мира, 28	f	large
22692	47438	570	Красноярский край, Минусинск, Литейная, 1	f	large
22670	47420	547	Красноярский край, Минусинск, Ленина, 77	f	large
22691	47437	569	Красноярский край, Кызыльская, 6	f	large
22678	47428	556	Красноярский край, Минусинск, Крупской, 100	f	large
22690	47434	568	Красноярский край, Минусинск, Кретова, 9	f	large
22687	47434	565	Красноярский край, Минусинск, Кретова, 9	f	large
22688	47435	566	Красноярский край, Минусинск, Журавлева, 8	f	large
68020	47416	543	Красноярский край, Минусинск, Вокзальная, 18Д	f	large
22686	47433	564	Красноярский край, Минусинск, Ванеева, 8	f	large
22685	47433	563	Красноярский край, Минусинск, Ванеева, 8	f	large
22668	47418	545	Красноярский край, Минусинск, Автомобильная, 37	f	large
23212	47941	1114	Красноярский край, деревня Минино, Вокзальная, 9	f	large
23227	47960	1130	Красноярский край, поселок Минжуль, Лесная, Клуб	t	small
23082	47796	977	Красноярский край, поселок Манзя, Ленина, 20	t	large
24168	48920	2111	Красноярский край, поселок Малое Озеро, Центральная, 57	f	small
23013	39542	899	Вологодская область, Нюксенский район, село Лопатино	t	small
22650	47402	523	Красноярский край, Лесосибирск, 9-ый микрорайон, 10	f	large
22635	47385	506	Россия, Красноярский край, Лесосибирск, улица Комсомольская, 16	f	large
22656	47404	525	Россия, Красноярский край, Лесосибирск, улица Горького, 25	f	large
22639	47389	510	Красноярский край, Лесосибирск, микрорайон Строитель, 6	f	large
22665	47415	536	Красноярский край, Лесосибирск, Рябиновая, 1	f	medium
68019	47413	534	Красноярский край, Лесосибирск, Просвещения, 34	f	large
68018	47412	533	Красноярский край, Лесосибирск, Просвещения, 32	f	large
22660	47410	531	Красноярский край, Лесосибирск, Промышленная, 18	f	large
22659	47409	530	Красноярский край, Лесосибирск, Подгорная, 15	f	small
22643	47393	514	Красноярский край, Лесосибирск, Победы, 40а	f	large
22642	47392	513	Красноярский край, Лесосибирск, Победы, 31	f	large
22641	47391	512	Красноярский край, Лесосибирск, Победы, 42	f	large
22640	47390	511	Красноярский край, Лесосибирск, Победы, 48	f	large
22657	47407	528	Красноярский край, Лесосибирск, Пионерская, 8	f	large
68017	47405	526	Красноярский край, Лесосибирск, Первомайская, 10а	f	large
22636	47386	507	Красноярский край, Лесосибирск, поселок Стрелка, Октябрьская, 24	f	large
22658	47408	529	Красноярский край, Лесосибирск, Мичурина, 6	f	medium
22661	47411	532	Красноярский край, Лесосибирск, Ленинградская, 13	f	large
23266	48004	1171	Россия, Красноярский край, Лесосибирск, Клубный переулок, 3	t	small
22653	47403	524	Россия, Красноярский край, Лесосибирск, Клубный переулок, 3	f	large
22649	47399	520	Красноярский край, Лесосибирск, Клубная, 1Б	f	small
22655	47406	527	Красноярский край, Лесосибирск, Горького, 30	f	large
22647	47397	518	Красноярский край, Лесосибирск, Горького, 120	f	large
22646	47396	517	Красноярский край, Лесосибирск, Белинского, 16в	f	large
22645	47395	516	Красноярский край, Лесосибирск, Белинского, 21	f	large
22638	47388	509	Красноярский край, Лесосибирск, Абалаковская, 8	f	medium
22648	47398	519	Красноярский край, Лесосибирск, 7 микрорайон, 10	f	large
22664	47414	535	Красноярский край, Лесосибирск, 6 квартал, 7а	f	large
22651	47401	522	Красноярский край, Лесосибирск, 5 микрорайон, 5а	f	large
22652	47400	521	Красноярский край, Лесосибирск, 5 микрорайон, 5а	f	small
22644	47394	515	Красноярский край, Лесосибирск, Победы, 20а	f	large
23494	48239	1402	Красноярский край, село Левоборежное, Береговая, 12	f	small
111152	47842	1026	Красноярский край, поселок Лакино, Мира, 41	f	medium
22977	47684	860	Красноярский край, деревня Курбатово, Центральная, 29-2	t	small
23707	48467	1632	Красноярский край, Кулаково, Ангарская, 23	t	medium
23021	47721	908	Красноярский край, деревня Кузнецово, Кооперативная, 2	f	small
23235	47969	1138	Красноярский край, деревня Куваршино, Еланская, 34	t	small
24248	49018	2227	Красноярский край, поселок Кресты, Сельский дом культуры	t	small
23226	47959	1129	Красноярский край, поселок Красный Пахарь, Центральная, 11	t	small
111175	49087	2320	Красноярский край, Красноярск, 50/44, Академгородок	f	\N
68002	49061	2278	Красноярский край, Красноярск, Ленинский район	f	large
24318	47343	2300	Красноярский край, Красноярск	f	large
22578	47343	448	Красноярский край, Красноярск	f	large
22577	47343	447	Красноярский край, Красноярск	f	large
22575	47343	445	Красноярский край, Красноярск	f	large
22574	47343	444	Красноярский край, Красноярск	f	large
22572	47343	442	Красноярский край, Красноярск	f	large
22571	47343	441	Красноярский край, Красноярск	f	large
22570	47343	440	Красноярский край, Красноярск	f	large
22569	47343	439	Красноярский край, Красноярск	f	large
22568	47343	438	Красноярский край, Красноярск	f	large
22566	47343	436	Красноярский край, Красноярск	f	large
22563	47343	433	Красноярский край, Красноярск	f	large
22562	47343	432	Красноярский край, Красноярск	f	large
22561	47343	431	Красноярский край, Красноярск	f	large
22560	47343	430	Красноярский край, Красноярск	f	large
22559	47343	429	Красноярский край, Красноярск	f	large
22558	47343	428	Красноярский край, Красноярск	f	large
22557	47343	427	Красноярский край, Красноярск	f	large
22556	47343	426	Красноярский край, Красноярск	f	large
22554	47343	424	Красноярский край, Красноярск	f	large
22553	47343	423	Красноярский край, Красноярск	f	large
22551	47343	421	Красноярский край, Красноярск	f	large
22550	47343	420	Красноярский край, Красноярск	f	large
22549	47343	419	Красноярский край, Красноярск	f	large
22548	47343	418	Красноярский край, Красноярск	f	large
22547	47343	417	Красноярский край, Красноярск	f	large
22546	47343	416	Красноярский край, Красноярск	f	large
22543	47343	413	Красноярский край, Красноярск	f	large
22542	47343	412	Красноярский край, Красноярск	f	large
22540	47343	410	Красноярский край, Красноярск	f	large
22538	47343	408	Красноярский край, Красноярск	f	large
22537	47343	407	Красноярский край, Красноярск	f	large
22536	47343	406	Красноярский край, Красноярск	f	large
22535	47343	405	Красноярский край, Красноярск	f	large
22534	47343	404	Красноярский край, Красноярск	f	large
22533	47343	403	Красноярский край, Красноярск	f	large
22532	47343	402	Красноярский край, Красноярск	f	large
22531	47343	401	Красноярский край, Красноярск	f	large
22530	47343	400	Красноярский край, Красноярск	f	large
22529	47343	399	Красноярский край, Красноярск	f	large
22528	47343	398	Красноярский край, Красноярск	f	medium
22527	47343	397	Красноярский край, Красноярск	f	large
22524	47343	394	Красноярский край, Красноярск	f	medium
22523	47343	393	Красноярский край, Красноярск	f	large
22573	47343	443	Красноярский край, Красноярск	f	large
22552	47343	422	Красноярский край, Красноярск	f	large
22541	47343	411	Красноярский край, Красноярск	f	large
22522	47343	392	Красноярский край, Красноярск	f	large
22443	47287	310	Красноярский край, Красноярск, 50, Академгородок	f	large
23955	48707	1885	Красноярский край, Северо-Енисейский район, Северо-Енисейская, 9	f	small
22328	47226	189	Россия, Красноярский край, Красноярск, улица Новая, 16	f	\N
22616	47378	486	Красноярский край, Красноярск, улица Ленина, 63	f	\N
22332	47050	193	Россия, Красноярский край, Красноярск, улица Кутузова, 90	f	\N
22333	47050	194	Россия, Красноярский край, Красноярск, улица Кутузова, 90	f	\N
22436	47281	303	Россия, Красноярский край, Красноярск, улица Корнеева, 50	f	large
22370	47233	231	Россия, Красноярский край, Красноярск, улица Коммунальная, 12	f	\N
22614	47376	484	Россия, Красноярский край, Красноярск, улица Кирова, 24	f	\N
111174	49086	2319	Россия, Красноярский край, Красноярск, улица Вильского, 13	f	\N
22615	47377	485	Красноярский край, Красноярск, проспект Мира, 82	f	\N
22444	47288	311	Красноярский край, Красноярск, Октябрьский район, микрорайон Академгородок , 21	f	large
22348	44716	209	Красноярский край, Красноярск, имени Газеты Пионерская Правда, 5	f	\N
22349	44716	210	Красноярский край, Красноярск, имени Газеты Пионерская Правда, 5	f	\N
22483	47316	352	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 168а	f	large
22374	47237	235	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 126	f	\N
22372	47235	233	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 95	f	\N
22368	47231	229	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 92б	f	\N
22366	47229	227	Россия, Красноярский край, Красноярск, имени Газеты Красноярский Рабочий проспект, 156	f	\N
22478	47313	347	Красноярский край, Красноярск, академика Вавилова, 19а	f	large
22373	47236	234	Россия, Красноярский край, Красноярск, Якорный переулок, 3	f	\N
22326	47224	186	Красноярский край, Красноярск, Яковлева, 1а	f	large
22459	47299	326	Красноярский край, Красноярск, Юшкова, 38	f	large
22458	47299	325	Красноярский край, Красноярск, Юшкова, 38	f	large
22457	47298	324	Красноярский край, Красноярск, Юшкова, 8а	f	large
22456	47298	323	Красноярский край, Красноярск, Юшкова, 8а	f	large
22393	47249	257	Красноярский край, Красноярск, Юности, 16	f	large
22392	47249	256	Красноярский край, Красноярск, Юности, 16	f	large
22390	47247	254	Красноярский край, Красноярск, Юности, 28	f	large
22404	47257	268	Красноярский край, Красноярск, Энергетиков, 17	f	large
22403	47257	267	Красноярский край, Красноярск, Энергетиков, 17	f	large
22347	44312	208	Красноярский край, Красноярск, Щорса, 64	f	\N
22346	44312	207	Красноярский край, Красноярск, Щорса, 64	f	\N
22345	44258	206	Красноярский край, Красноярск, Щорса, 55	f	\N
22344	43994	205	Красноярский край, Красноярск, Щорса, 46	f	\N
22306	47210	166	Красноярский край, Красноярск, Щетинкина, 1	f	large
22303	47210	163	Красноярский край, Красноярск, Щетинкина, 1	f	large
24332	47354	2314	Красноярский край, Красноярск, Шумяцкого, 3	f	large
22581	47354	451	Красноярский край, Красноярск, Шумяцкого, 3	f	large
22580	47354	450	Красноярский край, Красноярск, Шумяцкого, 3	f	large
22421	47268	286	Красноярский край, Красноярск, Шевченко, 56	f	large
22420	47268	285	Красноярский край, Красноярск, Шевченко, 56	f	large
22419	47267	284	Красноярский край, Красноярск, Шевченко, 38	f	large
22418	47266	282	Красноярский край, Красноярск, Шевченко, 8	f	large
111173	49085	2318	Красноярский край, Красноярск, Чайковского, 13а	f	\N
22389	47246	253	Красноярский край, Красноярск, Чайковского, 13а	f	large
22607	47368	477	Красноярский край, Красноярск, Урицкого, 26	f	\N
22604	47368	474	Красноярский край, Красноярск, Урицкого, 26	f	\N
22617	47302	487	Красноярский край, Красноярск, Урицкого, 121	f	\N
22619	38775	489	Красноярский край, Красноярск, Урицкого, 106	f	\N
22590	47360	460	Красноярский край, Красноярск, Урванцева, 23	f	large
24323	47359	2305	Красноярский край, Красноярск, Урванцева, 26а	f	large
22589	47359	459	Красноярский край, Красноярск, Урванцева, 26а	f	large
22588	47359	458	Красноярский край, Красноярск, Урванцева, 26а	f	large
24327	47353	2309	Красноярский край, Красноярск, Урванцева, 10а	f	large
22579	47353	449	Красноярский край, Красноярск, Урванцева, 10а	f	large
68016	47352	446	Красноярский край, Красноярск, Урванцева, 10а	f	large
24219	48973	2195	Красноярский край, Красноярск, Урванцева, 30А	f	large
22318	47218	178	Красноярский край, Красноярск, Толстого, 43	f	large
22317	47218	177	Красноярский край, Красноярск, Толстого, 43	f	large
22315	47218	175	Красноярский край, Красноярск, Толстого, 43	f	large
22384	47243	248	Россия, Красноярский край, Красноярск, Тихий переулок, 18	f	large
22383	47243	247	Россия, Красноярский край, Красноярск, Тихий переулок, 18	f	large
22555	47348	425	Красноярский край, Красноярск, Тельмана, 29а	f	large
22611	47373	481	Красноярский край, Красноярск, Сурикова, 12	f	\N
22610	47372	480	Красноярский край, Красноярск, Сурикова, 2	f	\N
22497	47325	366	Красноярский край, Красноярск, Судостроительная, 38а	f	large
22496	47324	365	Красноярский край, Красноярск, Судостроительная, 50	f	large
22495	47324	364	Красноярский край, Красноярск, Судостроительная, 50	f	large
22493	47323	362	Красноярский край, Красноярск, Судостроительная, 105	f	large
22494	47323	363	Красноярский край, Красноярск, Судостроительная, 105	f	large
22628	47382	498	Красноярский край, Красноярск, Степана Разина, 39	f	\N
22627	47382	497	Красноярский край, Красноярск, Степана Разина, 39	f	\N
22427	47273	294	Красноярский край, Красноярск, Сопочная, 40	f	large
22600	47365	470	Россия, Красноярский край, Красноярск, Солнечный бульвар, 11	f	medium
22597	47363	467	Россия, Красноярский край, Красноярск, Солнечный бульвар, 9	f	large
22595	47363	465	Россия, Красноярский край, Красноярск, Солнечный бульвар, 9	f	large
22596	47363	466	Россия, Красноярский край, Красноярск, Солнечный бульвар, 9	f	large
24220	48974	2196	Красноярский край, Красноярск, Сергея Лазо	f	medium
22492	47322	361	Красноярский край, Красноярск, Семафорная, 123	f	large
22490	47320	359	Красноярский край, Красноярск, Семафорная, 227а	f	large
22487	47318	356	Красноярский край, Красноярск, Семафорная, 247а	f	large
22486	47318	355	Красноярский край, Красноярск, Семафорная, 247а	f	large
22479	47314	348	Красноярский край, Красноярск, Семафорная, 261	f	large
22358	46740	219	Красноярский край, Красноярск, Семафорная, 381/2	f	\N
22324	47222	184	Красноярский край, Красноярск, Северо-Енисейская, 42	f	large
22447	47291	314	Россия, Красноярский край, Красноярск, Свободный проспект, 75	f	large
22442	47286	309	Россия, Красноярский край, Красноярск, Свободный проспект, 61	f	large
22441	47285	308	Россия, Красноярский край, Красноярск, Свободный проспект, 67	f	large
22439	47283	306	Россия, Красноярский край, Красноярск, Свободный проспект, 48	f	large
22438	47283	305	Россия, Красноярский край, Красноярск, Свободный проспект, 48	f	large
22431	47277	298	Россия, Красноярский край, Красноярск, Свободный проспект, 82	f	large
22311	47216	171	Россия, Красноярский край, Красноярск, Свободный проспект, 36	f	large
24322	47358	2304	Россия, Красноярский край, Красноярск, Светлогорский переулок, 7	f	large
22587	47358	457	Россия, Красноярский край, Красноярск, Светлогорский переулок, 7	f	large
22586	47358	456	Россия, Красноярский край, Красноярск, Светлогорский переулок, 7	f	large
22601	47366	471	Красноярский край, Красноярск, Светлова, 6	f	large
22520	47341	389	Красноярский край, Красноярск, Свердловская, 126	f	large
22518	47339	387	Красноярский край, Красноярск, Свердловская, 101а	f	large
22516	47337	385	Красноярский край, Красноярск, Свердловская, 63	f	large
22400	47254	264	Красноярский край, Красноярск, Рейдовая, 67А	f	large
22299	47208	159	Красноярский край, Красноярск, Профсоюзов, 17	f	large
22298	47208	158	Красноярский край, Красноярск, Профсоюзов, 17	f	large
22476	47312	345	Красноярский край, Красноярск, Побежимова, 46а	f	large
22477	47312	346	Красноярский край, Красноярск, Побежимова, 46а	f	large
22603	47367	473	Красноярский край, Красноярск, Петрушина, 2	f	large
22602	47367	472	Красноярский край, Красноярск, Петрушина, 2	f	large
24314	49075	2296	Красноярский край, Красноярск, Петра Словцова, 14	f	large
22474	47310	341	Красноярский край, Красноярск, Петра Словцова, 14	f	large
22396	47251	260	Красноярский край, Красноярск, Песочная, 20	f	large
22395	47251	259	Красноярский край, Красноярск, Песочная, 20	f	large
22511	47333	380	Красноярский край, Красноярск, Парашютная, 8	f	large
22507	47333	376	Красноярский край, Красноярск, Парашютная, 8	f	large
22508	47333	377	Красноярский край, Красноярск, Парашютная, 8	f	large
22401	47255	265	Красноярский край, Красноярск, Одесская, 3	f	large
22624	47380	494	Красноярский край, Красноярск, Обороны, 21А	f	\N
24315	49076	2297	Красноярский край, Красноярск, Норильская, 1Д	f	medium
22440	47284	307	Красноярский край, Красноярск, Новая Заря, 2	f	large
22329	47227	190	Красноярский край, Красноярск, Новая, 32	f	\N
22382	47242	246	Красноярский край, Красноярск, Московская, 31	f	large
22381	47242	245	Красноярский край, Красноярск, Московская, 31	f	large
22380	47241	244	Красноярский край, Красноярск, Московская, 20а	f	large
22376	47238	240	Красноярский край, Красноярск, Московская, 2	f	large
22375	47238	239	Красноярский край, Красноярск, Московская, 2	f	large
22327	47225	188	Красноярский край, Красноярск, Мичурина, 75, строение 1	f	\N
22357	45877	218	Красноярский край, Красноярск, Мичурина, 37	f	\N
24282	49051	2261	Россия, Красноярский край, Красноярск, Мира проспект, 18	t	small
22612	47374	482	Россия, Красноярский край, Красноярск, Мира проспект, 44	f	\N
22599	47364	469	Красноярский край, Красноярск, Микуцкого, 10	f	large
22598	47364	468	Красноярский край, Красноярск, Микуцкого, 10	f	large
22314	47217	174	Красноярский край, Красноярск, Мечникова, 13	f	large
22313	47217	173	Красноярский край, Красноярск, Мечникова, 13	f	large
22312	47217	172	Красноярский край, Красноярск, Мечникова, 13	f	large
22567	47351	437	Россия, Красноярский край, Красноярск, Металлургов проспект, 14а	f	large
22565	47350	435	Россия, Красноярский край, Красноярск, Металлургов проспект, 4а	f	large
68011	47221	182	Красноярский край, Красноярск, Менжинского, 11	f	large
22323	47220	183	Красноярский край, Красноярск, Менжинского, 15	f	large
22321	47220	181	Красноярский край, Красноярск, Менжинского, 15	f	large
22320	47220	180	Красноярский край, Красноярск, Менжинского, 15	f	large
22319	47220	179	Красноярский край, Красноярск, Менжинского, 15	f	large
22295	47205	155	Красноярский край, Красноярск, Менжинского, 11	f	large
22426	47272	293	Красноярский край, Красноярск, Мелькомбинатская, 2	f	medium
22515	47336	384	Россия, Красноярский край, Красноярск, Медицинский переулок, 27	f	large
22514	47336	383	Россия, Красноярский край, Красноярск, Медицинский переулок, 27	f	large
22341	43634	202	Россия, Красноярский край, Красноярск, Маяковского переулок, 9	f	\N
22340	43558	201	Россия, Красноярский край, Красноярск, Маяковского переулок, 9	f	\N
22417	47264	281	Россия, Красноярский край, Красноярск, Машиностроителей проспект, 8	f	large
22416	47264	280	Россия, Красноярский край, Красноярск, Машиностроителей проспект, 8	f	large
22415	47264	279	Россия, Красноярский край, Красноярск, Машиностроителей проспект, 8	f	large
24324	49080	2306	Красноярский край, Красноярск, Мате Залки, 15	f	large
24326	47355	2308	Красноярский край, Красноярск, Мате Залки, 4а	f	large
22583	47355	453	Красноярский край, Красноярск, Мате Залки, 4а	f	large
22582	47355	452	Красноярский край, Красноярск, Мате Залки, 4а	f	large
22613	47375	483	Красноярский край, Красноярск, Марковского, 36	f	\N
22405	47258	269	Красноярский край, Красноярск, Ленинский район, Малая, 64	f	large
22307	47213	167	Красноярский край, Красноярск, Маерчака, 34	f	large
22305	47212	165	Красноярский край, Красноярск, Маерчака, 20	f	large
22409	47260	273	Красноярский край, Красноярск, Львовская, 43	f	large
22408	47260	272	Красноярский край, Красноярск, Львовская, 43	f	large
22407	47259	271	Красноярский край, Красноярск, Львовская, 24	f	large
22406	47259	270	Красноярский край, Красноярск, Львовская, 24	f	large
22296	47206	156	Красноярский край, Красноярск, Ломоносова, 47	f	large
22310	47215	170	Красноярский край, Красноярск, Лизы Чайкиной переулок, 5	f	large
22309	47215	169	Красноярский край, Красноярск, Лизы Чайкиной переулок, 5	f	large
22304	47211	164	Красноярский край, Красноярск, Лиды Прушинской, 2	f	large
22446	47290	313	Красноярский край, Красноярск, Лесная, 147	f	large
22634	47384	504	Красноярский край, Красноярск, Ленина, 90	f	\N
22621	38760	491	Красноярский край, Красноярск, Ленина, 114	f	\N
22618	38760	488	Красноярский край, Красноярск, Ленина, 114	f	\N
22620	38760	490	Красноярский край, Красноярск, Ленина, 114	f	\N
22316	47219	176	Красноярский край, Красноярск, Ладо Кецховели, 62	f	large
22342	43788	203	Красноярский край, Красноярск, Кутузова, 6	f	\N
22338	35145	199	Красноярский край, Красноярск, Кутузова, 52	f	\N
22339	35145	200	Красноярский край, Красноярск, Кутузова, 52	f	\N
22336	34562	197	Красноярский край, Красноярск, Кутузова, 72	f	\N
22337	34562	198	Красноярский край, Красноярск, Кутузова, 72	f	\N
22334	34502	195	Красноярский край, Красноярск, Кутузова, 91	f	\N
22335	34502	196	Красноярский край, Красноярск, Кутузова, 91	f	\N
22450	47293	317	Красноярский край, Красноярск, Курчатова, 7	f	large
22449	47292	316	Красноярский край, Красноярск, Курчатова, 1	f	large
22448	47292	315	Красноярский край, Красноярск, Курчатова, 1	f	large
22454	47296	321	Красноярский край, Красноярск, Крупской, 10в	f	large
22453	47295	320	Красноярский край, Красноярск, Крупской, 42	f	large
22452	47295	319	Красноярский край, Красноярск, Крупской, 42	f	large
22394	47250	258	Красноярский край, Красноярск, Красноярский Рабочий, 38	f	large
22500	47327	369	Красноярский край, Красноярск, Краснопресненская, 10	f	large
22302	47209	162	Красноярский край, Красноярск, Красной Армии, 19	f	large
22301	47209	161	Красноярский край, Красноярск, Красной Армии, 19	f	large
22300	47209	160	Красноярский край, Красноярск, Красной Армии, 19	f	large
22545	47347	415	Красноярский край, Красноярск, Краснодарская, 5-Б	f	large
22544	47347	414	Красноярский край, Красноярск, Краснодарская, 5-Б	f	large
111172	49084	2317	Красноярский край, Красноярск, Крайняя, 4	f	\N
22365	36745	226	Красноярский край, Красноярск, Корнетова, 12	f	\N
22437	47282	304	Красноярский край, Красноярск, Корнеева, 50	f	large
22605	47369	475	Красноярский край, Красноярск, Конституции СССР, 19	f	\N
22606	47369	476	Красноярский край, Красноярск, Конституции СССР, 19	f	\N
24293	49060	2272	Россия, Красноярский край, Красноярск, Комсомольский проспект, 15	f	large
22371	47234	232	Красноярский край, Красноярск, Коммунальная, 14	f	\N
111142	47232	230	Красноярский край, Красноярск, Коммунальная, 14	f	\N
22308	47214	168	Красноярский край, Красноярск, Комбайностроителей, 8	f	large
22485	47317	354	Красноярский край, Красноярск, Кольцевая, 3а	f	large
22484	47317	353	Красноярский край, Красноярск, Кольцевая, 3а	f	large
22482	38665	351	Красноярский край, Красноярск, Кольцевая, 12а	f	large
22481	38665	350	Красноярский край, Красноярск, Кольцевая, 12а	f	large
22387	47245	251	Красноярский край, Красноярск, Коломенская, 25	f	large
22388	47245	252	Красноярский край, Красноярск, Коломенская, 25	f	large
22386	47245	250	Красноярский край, Красноярск, Коломенская, 25	f	large
22519	47340	388	Красноярский край, Красноярск, Ключевская, 99	f	large
22517	47338	386	Красноярский край, Красноярск, Ключевская, 61	f	large
22521	47342	390	Красноярский край, Красноярск, Карьерная, 26А	f	large
22609	47371	479	Красноярский край, Красноярск, Карла Маркса, 37	f	\N
22608	47370	478	Красноярский край, Красноярск, Карла Маркса, 14	f	\N
22462	47301	329	Красноярский край, Красноярск, Карбышева, 28а	f	large
22461	47300	328	Красноярский край, Красноярск, Карбышева, 1	f	large
22460	47300	327	Красноярский край, Красноярск, Карбышева, 1	f	large
22468	47306	335	Красноярский край, Красноярск, Калинина, 79	f	medium
22467	47305	334	Красноярский край, Красноярск, Калинина, 80	f	medium
22466	47304	333	Красноярский край, Красноярск, Калинина, 67	f	large
22626	47381	496	Красноярский край, Красноярск, Енисейская, 1	f	\N
22625	47381	495	Красноярский край, Красноярск, Енисейская, 1	f	\N
22471	47308	338	Красноярский край, Красноярск, Елены Стасовой, 10	f	large
22564	47349	434	Красноярский край, Красноярск, Джамбульская, 24	f	large
22499	47326	368	Красноярский край, Красноярск, Делегатская, 18	f	large
22473	47309	340	Красноярский край, Красноярск, Гусарова, 16	f	large
22472	47309	339	Красноярский край, Красноярск, Гусарова, 16	f	large
22470	47307	337	Красноярский край, Красноярск, Гусарова, 56	f	large
22469	47307	336	Красноярский край, Красноярск, Гусарова, 56	f	large
22622	39296	492	Красноярский край, Красноярск, Горького, 97	f	\N
22402	47256	266	Красноярский край, Красноярск, Глинки, 2б	f	large
22343	43820	204	Красноярский край, Красноярск, Гастелло, 38	f	\N
22451	47294	318	Красноярский край, Красноярск, Высотная, 2	f	large
24325	49081	2307	Красноярский край, Красноярск, Воронова, 18а	f	large
111245	49003	2215	Красноярский край, Красноярск, Волочанская, СОШ №15	f	\N
22435	47280	302	Красноярский край, Красноярск, Волочаевская, 44	f	large
22434	47280	301	Красноярский край, Красноярск, Волочаевская, 44	f	large
22410	47261	274	Красноярский край, Красноярск, Волжская, 29А	f	large
22377	47239	241	Красноярский край, Красноярск, Волгоградская, 2а	f	large
22378	47239	242	Красноярский край, Красноярск, Волгоградская, 2а	f	large
24316	49077	2298	Красноярский край, Красноярск, Водянникова, 2	f	\N
22455	47297	322	Красноярский край, Красноярск, Вильского, 13	f	large
24319	49078	2301	Красноярский край, Красноярск, Взлетная, 20	f	large
24291	48972	2270	Красноярский край, Красноярск, Весны, 9а	f	large
24218	48972	2194	Красноярский край, Красноярск, Весны, 9а	f	large
22425	47271	290	Красноярский край, Красноярск, Верхняя, 3б	f	large
22464	47276	331	Красноярский край, Красноярск, Ботаническая, 22	f	large
22463	47276	330	Красноярский край, Красноярск, Ботаническая, 22	f	large
22430	47276	297	Красноярский край, Красноярск, Ботаническая, 22	f	large
22429	47275	296	Красноярский край, Красноярск, Борисова, 1	f	large
22424	47270	289	Красноярский край, Красноярск, Борисевича, 7	f	large
22423	47270	288	Красноярский край, Красноярск, Борисевича, 7	f	large
22422	47269	287	Красноярский край, Красноярск, Борисевича, 23	f	large
22297	47207	157	Красноярский край, Красноярск, Бограда, 91	f	large
22367	47230	228	Красноярский край, Красноярск, Базарная, 172	f	\N
22413	47263	277	Красноярский край, Красноярск, Аральская, 1	f	large
68013	47263	276	Красноярский край, Красноярск, Аральская, 1	f	large
68014	47262	278	Красноярский край, Красноярск, Аральская, 5	f	large
68012	47262	275	Красноярский край, Красноярск, Аральская, 5	f	large
22491	47321	360	Красноярский край, Красноярск, Анатолия Гладкова, 8	f	large
22330	47228	191	Красноярский край, Красноярск, Алеши Тимошенкова, 161	f	\N
22331	47228	192	Красноярский край, Красноярск, Алеши Тимошенкова, 161	f	\N
22498	47204	367	Красноярский край, Красноярск, Алеши Тимошенкова, 82	f	large
22294	47204	154	Красноярский край, Красноярск, Алеши Тимошенкова, 82	f	large
24321	49079	2303	Красноярский край, Красноярск, Алексеева, 95	f	large
24320	49079	2302	Красноярский край, Красноярск, Алексеева, 95	f	large
24292	49059	2271	Красноярский край, Красноярск, Алексеева, 29	f	large
22504	47331	373	Красноярский край, Красноярск, Александра Матросова, 30/10	f	large
22503	47330	372	Красноярский край, Красноярск, Александра Матросова, 20	f	large
22502	47329	371	Красноярский край, Красноярск, Александра Матросова, 15	f	large
22489	47319	358	Красноярский край, Красноярск, Александра Матросова, 12В	f	large
22488	47319	357	Красноярский край, Красноярск, Александра Матросова, 12В	f	large
22356	45782	217	Красноярский край, Красноярск, Академика Павлова, 24	f	\N
22355	45700	216	Красноярский край, Красноярск, Академика Павлова, 23	f	\N
22354	45700	215	Красноярский край, Красноярск, Академика Павлова, 23	f	\N
22353	45529	214	Красноярский край, Красноярск, Академика Павлова, 54	f	\N
22352	45163	213	Красноярский край, Красноярск, Академика Павлова, 70	f	\N
22351	45163	212	Красноярский край, Красноярск, Академика Павлова, 70	f	\N
22433	47279	300	Красноярский край, Красноярск, Академика Киренского, 70	f	large
22432	47278	299	Красноярский край, Красноярск, Академика Киренского, 28	f	large
22428	47274	295	Красноярский край, Красноярск, Академика Киренского, 26	f	large
22480	47315	349	Красноярский край, Красноярск, Академика Вавилова, 1В	f	large
22364	36691	225	Красноярский край, Красноярск, Академика Вавилова, 92	f	\N
22362	36589	223	Красноярский край, Красноярск, Академика Вавилова, 49б	f	\N
22363	36589	224	Красноярский край, Красноярск, Академика Вавилова, 49б	f	\N
22361	36342	222	Красноярский край, Красноярск, Академика Вавилова, 37	f	\N
22360	35973	221	Красноярский край, Красноярск, Академика Вавилова, 25	f	\N
22359	35370	220	Красноярский край, Красноярск, Академика Вавилова, 21	f	\N
22445	47289	312	Красноярский край, Красноярск, Академгородок, 50/44	f	large
22465	47303	332	Красноярский край, Красноярск, Азовская, 1	f	medium
22623	47379	493	Красноярский край, Красноярск, Ады Лебедевой, 89	f	\N
22350	45146	211	Россия, Красноярский край, Красноярск, Автобусный переулок, 4	f	\N
24331	49082	2313	Красноярский край, Красноярск, Авиаторов, 22-д	f	large
24330	49082	2312	Красноярский край, Красноярск, Авиаторов, 22-д	f	large
24329	49082	2311	Красноярский край, Красноярск, Авиаторов, 22-д	f	large
24328	49082	2310	Красноярский край, Красноярск, Авиаторов, 22-д	f	large
22591	47361	461	Красноярский край, Красноярск, 9 мая, 26	f	large
22585	47357	455	Красноярский край, Красноярск, 9 мая, 56а	f	large
22584	47356	454	Красноярский край, Красноярск, 9 Мая, 54	f	large
22513	47335	382	Красноярский край, Красноярск, 60 лет Октября, 21	f	large
22512	47335	381	Красноярский край, Красноярск, 60 лет Октября, 21	f	large
22506	47332	375	Красноярский край, Красноярск, 60 лет Октября, 96	f	large
22510	47265	379	Красноярский край, Красноярск, 60 лет Октября, 81	f	large
22505	47265	374	Красноярский край, Красноярск, 60 лет Октября, 81	f	large
68015	47334	378	Красноярский край, Красноярск, 60 Лет Октября, 81	f	large
22501	47328	370	Красноярский край, Красноярск, 60 Лет Октября, 137	f	large
22385	47244	249	Красноярский край, Красноярск, 52 Квартал, 1	f	large
22593	47362	463	Красноярский край, Красноярск, 40 лет победы, 24	f	large
24317	47362	2299	Красноярский край, Красноярск, 40 лет победы, 24	f	large
22594	47362	464	Красноярский край, Красноярск, 40 лет победы, 24	f	large
22592	47362	462	Красноярский край, Красноярск, 40 лет победы, 24	f	large
22184	47104	35	Красноярский край, Ачинск, Калинина, 8а	f	large
23951	48703	1881	Красноярский край, Красноярск, 40 Лет Победы, 12А	f	large
22630	47383	500	Красноярский край, Красноярск, 4-ая Продольная, 19	f	\N
22629	47383	499	Красноярский край, Красноярск, 4-ая Продольная, 19	f	\N
22631	47383	501	Красноярский край, Красноярск, 4-ая Продольная, 19	f	\N
22399	47253	263	Красноярский край, Красноярск, 26 Бакинских Комиссаров, 5Б	f	large
22398	47252	262	Красноярский край, Красноярск, 26 Бакинских Комиссаров, 24а	f	large
22397	47252	261	Красноярский край, Красноярск, 26 Бакинских Комиссаров, 24а	f	large
23485	48230	1393	Красноярский край, поселок Краснополянск, Центральная, 7	t	small
23100	47812	995	Красноярский край, поселок Красногорьевский, Ленина, 11А	f	large
23530	48278	1445	Красноярский край, Кодинск, Маяковского, 15	f	large
24262	49031	2241	Красноярский край, поселок Кислокан, улица Ветеранов, 8	t	small
23010	47714	896	Красноярский край, деревня Киндяково, Березовая, 1	t	small
23548	48297	1466	Красноярский край, поселок Кедровый, Школьная, 1	f	small
22881	47586	762	Красноярский край, поселок Кедровый, Жуковского, 2	f	large
22880	47586	761	Красноярский край, поселок Кедровый, Жуковского, 2	f	large
22275	47189	133	Красноярский край, Канск, поселок Строителей, 59	f	large
23953	48705	1883	Красноярский край, Канск, Юбилейная, 23	f	large
22278	47191	136	Красноярский край, Канск, Элеваторная, 23А	f	large
22270	47184	128	Красноярский край, Канск, Эйдемана, 17	f	large
22281	47193	139	Красноярский край, Канск, Шоссейная, 46	f	large
22280	47193	138	Красноярский край, Канск, Шоссейная, 46	f	large
22292	47202	150	Красноярский край, Канск, Солнечный, 85	f	large
22291	47202	149	Красноярский край, Канск, Солнечный, 85	f	large
22279	47192	137	Красноярский край, Канск, Северный микрорайон, Северный, 29	f	large
22282	47194	140	Красноярский край, Канск, Северная, 29	f	large
22266	47181	124	Красноярский край, Канск, Революции, 19	f	large
22283	47195	141	Красноярский край, Канск, Предмостная площадь, 11Б	f	large
22274	47188	132	Красноярский край, Канск, Николая Буды, 5	f	large
22290	47201	148	Красноярский край, Канск, Муромская, 13	f	large
22289	47201	147	Красноярский край, Канск, Муромская, 13	f	large
22285	47197	143	Красноярский край, Канск, Молодогвардейская, 5	f	large
22277	47190	135	Красноярский край, Канск, Мелькомбината переулок, 33	f	medium
22276	47190	134	Красноярский край, Канск, Мелькомбината переулок, 33	f	large
22261	47177	119	Красноярский край, Канск, Луначарского, 1	f	large
22267	47182	125	Красноярский край, Канск, Ленина, 10	f	large
22264	47179	122	Красноярский край, Канск, Крестьянская, 27	f	large
22272	47186	130	Красноярский край, Канск, Красноярская, 22	f	large
22271	47185	129	Красноярский край, Канск, Красноярская, 26	f	large
22269	47183	127	Красноярский край, Канск, Краснопартизанская, 29	f	large
22268	47183	126	Красноярский край, Канск, Краснопартизанская, 29	f	large
22273	47187	131	Красноярский край, Канск, Краевая, 66	f	large
24290	49058	2269	Красноярский край, Канск, Карьерный переулок, 14Б, .ДСУ-4	t	small
22265	47180	123	Красноярский край, Канск, Кайтымская, 56	f	large
22287	47199	145	Россия, Красноярский край, Канск, Индустриальный переулок, 1	f	large
22263	46952	121	Красноярский край, Канск, Земледелия, 39	f	large
22262	47178	120	Красноярский край, Канск, Бограда, 59	f	large
22288	47200	146	Красноярский край, Канск, 40 лет Октября, 65	f	large
22286	47198	144	Красноярский край, Канск, 40 лет Октября, 33	f	large
22284	47196	142	Красноярский край, Канск, 40 лет Октября, 5	f	large
23214	47944	1116	Красноярский край, поселок Каменный Яр, Заводская, 1	f	small
86209	47794	975	Красноярский край, деревня Каменка, Мира, 12	t	small
22954	47661	837	Красноярский край, деревня Каменка, Лесная, б/н	f	large
22891	47595	774	Красноярский край, деревня Каменка, Длинная, 18	f	small
23974	48727	1904	Красноярский край, село Иркутское, Советская, 48	f	small
22259	47175	116	Красноярский край, Игарка, Первый м-он, 19	f	large
22258	47174	112	Красноярский край, Игарка, Горького, 39а	f	medium
22260	47176	117	Красноярский край, Игарка, Второй м-он, 10а	f	large
23018	47718	904	Красноярский край, село Зыково, Школьная, 5б	f	large
23019	47719	905	Красноярский край, село Зыково, Советская, 27	f	large
23017	14683	903	Красноярский край, село Зыково, Клубная, 6	f	large
23487	48232	1395	Красноярский край, поселок Зеленый Луг, Первомайская, 14Б	t	small
22860	47568	740	Красноярский край, Зеленогорск, Первомайская, 10	f	large
22870	47577	750	Красноярский край, Зеленогорск, Парковая, 6	f	large
22869	47577	749	Красноярский край, Зеленогорск, Парковая, 6	f	large
22877	47583	757	Красноярский край, Зеленогорск, Диктатуры Пролетариата, 19А	f	large
22246	47163	97	Красноярский край, Заозерный, Победы, 9	f	large
22248	47164	99	Красноярский край, Заозерный, 40 лет Октября, 38	f	large
22247	47164	98	Красноярский край, Заозерный, 40 лет Октября, 38	f	large
22817	47533	697	Красноярский край, Железногорск, Свердлова, 47, Школа №92	f	large
22816	47532	696	Красноярский край, Железногорск, Свердлова, 63	f	large
22837	47547	717	Красноярский край, Железногорск, Саянская, 7	f	large
22836	47547	716	Красноярский край, Железногорск, Саянская, 7	f	large
22843	47551	723	Красноярский край, Железногорск, Ленинградский проспект, 77	f	large
22842	47551	722	Красноярский край, Железногорск, Ленинградский проспект, 77	f	large
22847	47554	727	Красноярский край, Железногорск, Белорусская, 45А	f	large
24250	48994	2229	Красноярский край, поселок Жданиха, Сельский дом культуры	t	small
23014	39758	900	Красноярский край, село Есаулово, Клубная, 4	f	large
23015	47716	901	Красноярский край, деревня Ермолаево, Первомайская, 1	f	large
22245	47162	96	Красноярский край, Енисейск, мкр. Полюс	f	large
22243	47160	94	Красноярский край, Енисейск, Рабоче-Крестьянская, 210	f	large
22241	47158	92	Красноярский край, Енисейск, Перенсона, 85	f	large
22240	47157	91	Красноярский край, Енисейск, Ленина, 130	f	large
22238	47155	89	Красноярский край, Енисейск, Ленина, 102	f	large
22237	47154	88	Красноярский край, Енисейск, Ленина, 44	f	large
22236	47153	87	Красноярский край, Енисейск, Куйбышева, 43	f	large
22239	47156	90	Красноярский край, Енисейск, Горького, 5	f	large
22244	47161	95	Красноярский край, Енисейск, Гастелло, 10	f	large
22242	47159	93	Красноярский край, Енисейск, Бабкина, 74	f	large
23202	47931	1104	Россия, Красноярский край, поселок Емельяново, улица Советская, 1а	t	small
23204	47933	1106	Красноярский край, поселок Емельяново, Центральная, 5А	t	small
23201	47930	1103	Красноярский край, поселок Емельяново, Центральная, 26	t	small
23200	47929	1102	Красноярский край, поселок Емельяново, Спортивная, 5	f	medium
23198	47927	1100	Красноярский край, поселок Емельяново, СПТУ-81, 3	f	medium
23197	47926	1099	Красноярский край, поселок Емельяново, Новая, 13а	f	large
23199	47928	1101	Красноярский край, поселок Емельяново, Московская, 371	f	large
23195	47924	1097	Красноярский край, поселок Емельяново, Декабристов, 85	f	large
68009	47925	1098	Красноярский край, поселок Емельяново, Московская, 289	f	large
24229	48990	2208	Красноярский край, Дудинка, ТМКОУ Дудинская средняя общеобразовательная школа № 4	f	large
24228	48987	2207	Красноярский край, Дудинка, ТМКОУ Дудинская средняя общеобразовательная школа № 7	f	large
24227	48986	2205	Красноярский край, Дудинка, ТМКОУ Дудинская средняя общеобразовательная школа № 3	f	large
24225	48980	2203	Красноярский край, Дудинка, ТМКОУ Дудинская средняя общеобразовательная школа № 1	f	large
24224	48978	2202	Красноярский край, Дудинка, ТМКОУ Дудинская средняя общеобразовательная школа № 5	f	large
23222	47955	1124	Красноярский край, поселок Дрокино, Московская, 13	f	medium
22850	47557	730	Красноярский край, поселок Додоново, Новоселов, 7	f	medium
22234	47151	85	Красноярский край, Дивногорск, поселок Манский, КГБУ Дивногорский	t	small
22233	47150	84	Красноярский край, Дивногорск	f	small
22229	47146	80	Красноярский край, Дивногорск, поселок Верхняя Бирюса	t	small
22224	47141	75	Красноярский край, Дивногорск, Чкалова, 169	f	large
22222	47139	73	Красноярский край, Дивногорск, Чкалова, 41	f	large
22221	47138	72	Красноярский край, Дивногорск, Спортивная, 2	f	large
22220	47137	71	Красноярский край, Дивногорск, Саянская, 12	f	large
22228	47145	79	Красноярский край, Дивногорск, Парковая, 10	f	large
22227	47144	78	Красноярский край, Дивногорск, Набережная, 9	f	large
22226	47143	77	Красноярский край, Дивногорск, Комсомольская, 6	f	large
22225	47142	76	Красноярский край, Дивногорск, Бочкина, 22	f	large
22223	47140	74	Красноярский край, Дивногорск, Б.Полевого, 3	f	large
24034	48787	1973	Красноярский край, село Горошиха, Северная, 11	t	small
22949	47655	832	Красноярский край, поселок Горный, Центральная, 16	f	large
23112	47825	1007	Красноярский край, поселок Говорково, Первомайский, 2	t	small
23933	48690	1862	Красноярский край, село Вознесенка, Центральная, 68	t	small
86169	47599	778	Красноярский край, село Вознесенка, Советская, 35 Б	t	small
23261	47997	1166	Красноярский край, Верхнепашино, Геофизиков, 10	t	large
23260	47996	1165	Красноярский край, село Вернепашино, Советская, 39	f	large
24278	49047	2257	Красноярский край, село Ванавара, Советская, 64	f	large
23219	47952	1121	Красноярский край, деревня Бугачево, Заречная, 19	t	small
22212	47130	63	Красноярский край, город Бородино	f	large
22211	47129	62	Красноярский край, город Бородино, мкр. Стахановский, 13	f	large
22214	47131	65	Красноярский край, Бородино, Советская, 68	f	large
22213	47131	64	Красноярский край, Бородино, Советская, 68	f	large
22217	47134	68	Красноярский край, Бородино, Октябрьская, 56	f	large
22216	47133	67	Красноярский край, город Бородино, Маяковского, 30	f	large
22215	47132	66	Красноярский край, Бородино, Ленина, 33	f	large
22218	47135	69	Красноярский край, Бородино, 9 Мая, 38	f	large
23960	48712	1890	Красноярский край, поселок Большие Пруды, Космонавтов, 12	f	small
22193	47113	44	Красноярский край, Боготол, Школьная, 70	f	\N
22201	47121	52	Красноярский край, Боготол, Урицкого, 8А	f	\N
22197	47117	48	Красноярский край, Боготол, 40 лет Октября, 27а	f	\N
22209	47119	60	Красноярский край, Боготол, Северная , 9	f	\N
22199	47119	50	Красноярский край, Боготол, Северная , 9	f	\N
22191	47111	42	Красноярский край, Боготол, Деповская, 3	f	\N
22195	47115	46	Красноярский край, Боготол, 40 лет Октября, 12	f	\N
23000	47704	886	Красноярский край, поселок Березовка, Центральная, 27	f	large
23006	47710	892	Красноярский край, поселок Березовка, Солнечная, 2а	f	large
23001	47705	887	Красноярский край, поселок Березовка, Советская, 47	f	large
23144	47858	1042	Красноярский край, поселок Березовка, Мира, 10	f	small
23003	47707	889	Красноярский край, поселок Березовка, Кирова, 116А	f	large
23005	47709	891	Красноярский край, поселок Березовка, Заводская, 57В	f	large
23004	47708	890	Красноярский край, поселок Березовка, Дружбы, 1В	f	large
22892	47596	775	Красноярский край, поселок Березовка, 2-ая Новая, 4	f	small
23493	48238	1401	Красноярский край, село Бережки, Новая, 9	f	small
23009	47713	895	Красноярский край, село Бархатово, Ленина, 2А	f	large
22960	47667	843	Красноярский край, поселок Балахта, Мудрова, 4	f	medium
24267	49036	2246	Красноярский край, село Байкит, Увачана, 15	f	large
24268	49037	2247	Красноярский край, село Байкит, Гагарина, 10	f	large
22178	47098	29	Россия, Красноярский край, Ачинск, 2-ой Юго-Восточный микрорайон	f	large
22177	47098	28	Россия, Красноярский край, Ачинск, 2-ой Юго-Восточный микрорайон	f	large
22165	47096	16	Красноярский край, Ачинск, 6-ой микрорайон, 18	f	large
22150	47083	1	Красноярский край, Ачинск	f	large
22163	47094	14	Красноярский край, Ачинск, микрорайон 8, 3	f	large
22162	47094	13	Красноярский край, Ачинск, микрорайон 8, 3	f	large
22164	47095	15	Красноярский край, Ачинск, микрорайон 7, 16	f	large
67994	48962	2151	Красноярский край, Ачинск, микрорайон 4, 30	f	large
22169	41895	20	Красноярский край, Ачинск, микрорайон 3, 40	f	large
22166	47065	17	Красноярский край, Ачинск, микрорайон 1, 54	f	large
22176	47097	27	Красноярский край, Ачинск, Юго-Восточный микрорайон, 10а	f	large
22175	47097	26	Красноярский край, Ачинск, Юго-Восточный микрорайон, 10а	f	large
68010	47107	38	Красноярский край, Ачинск, Чернявского, 13	f	large
22180	47100	31	Красноярский край, Ачинск, Чайковского, 17	f	large
22159	47091	10	Красноярский край, Ачинск, Трудовых Резервов, 5	f	medium
22190	47110	41	Красноярский край, Ачинск, Свердлова, 88	f	large
22179	47099	30	Красноярский край, Ачинск, Республики, 7	f	large
22160	47092	11	Красноярский край, Ачинск, Партизанская, 37	f	large
22158	47090	9	Красноярский край, Ачинск, Омская, 27	f	large
22157	47089	8	Красноярский край, Ачинск, Льва Толстого, 26	f	large
22181	47101	32	Красноярский край, Ачинск, Кравченко, 34	f	large
22161	47093	12	Красноярский край, Ачинск, Комсомольская, 7	f	large
22156	47088	7	Красноярский край, Ачинск, Кирова, 1	f	large
22154	47086	5	Красноярский край, Ачинск, Кирова, 32	f	large
22186	47106	37	Красноярский край, Ачинск, Калинина, 15	f	large
22153	47085	4	Красноярский край, Ачинск, Дружбы Народов, 8	f	large
22185	47105	36	Красноярский край, Ачинск, Декабристов, 33	f	large
22183	47103	34	Красноярский край, Ачинск, Гагарина, 27	f	large
22182	47102	33	Красноярский край, Ачинск, Гагарина, 20	f	large
22172	43232	23	Красноярский край, Ачинск, Гагарина, 22	f	large
22155	47087	6	Красноярский край, Ачинск, Береговая, 44	f	medium
22174	43450	25	Красноярский край, Ачинск, 5-ый микрорайон, 15	f	large
24208	43450	2152	Красноярский край, Ачинск, 5-ый микрорайон, 15	f	large
22173	43450	24	Красноярский край, Ачинск, 5-ый микрорайон, 15	f	large
22171	43203	22	Красноярский край, Ачинск, 4-ый микрорайон, 30	f	large
22170	41841	21	Красноярский край, Ачинск, 3-ий микрорайон, 38	f	large
22168	41841	19	Красноярский край, Ачинск, 3-ий микрорайон, 38	f	large
22188	47108	39	Красноярский край, Ачинск, 3 микрорайон , 17 А	f	large
22152	47084	3	Красноярский край, Ачинск, 3 микрорайон, 36А	f	large
22151	47084	2	Красноярский край, Ачинск, 3 микрорайон, 36А	f	large
22189	47109	40	Красноярский край, Ачинск, 3 микрорайон, 40	f	large
22167	41640	18	Красноярский край, Ачинск, 2-ой микрорайон, 17	f	large
23631	48389	1553	Красноярский край, Артёмовск, Ольховская, 46	f	medium
23445	48190	1352	Красноярский край, село Анцирь, Советская, 48	f	large
24284	49053	2263	Красноярский край, Эвенкийский район, п.Оскоба, Лесная, 6	t	small
24261	49030	2240	Красноярский край, Эвенкийский район, поселок Эконда, Максима Ялогира, 7А	t	small
24265	49034	2244	Красноярский край, Эвенкийский район, поселок Учами, Таежная, 1	t	small
24266	49035	2245	Красноярский край, Эвенкийский район, поселок Тутончаны, Набережная, 5	f	small
24258	49027	2237	Красноярский край, Эвенкийский район, Тура, Нефтяников, 2Д	f	small
24273	49042	2252	Красноярский край, Эвенкийский район, поселок Полигус, Бояки, 1	t	small
86136	49033	2243	Красноярский край, Эвенкийский район, поселок Нидым, 70 лет Октября, 8	t	small
86138	49046	2256	Красноярский край, Эвенкийский район, Мирюга, Лесная, 1А	t	small
24275	49044	2254	Красноярский край, Эвенкийский район, поселок Куюмба, Солнечная, 19	t	small
24280	49049	2259	Красноярский край, Эвенкийский район, поселок Ванавара, Спортивная, 11	f	medium
24272	49041	2251	Красноярский край, Эвенкийский район, поселок Бурный, Таежная, 9	t	small
24269	49038	2248	Красноярский край, Эвенкийский район, село Байкит, Центральная, 10	f	small
24179	48930	2123	Красноярский край, Шушенский район, поселок городского типа Шушенское, Тельмана, 3	f	\N
24172	48923	2116	Красноярский край, Шушенский район, поселок городского типа Шушенское, Первомайская, 1	f	\N
24171	48922	2115	Красноярский край, Шушенский район, поселок Шушенское, квартал Строителей, 1	f	\N
24170	48921	2114	Красноярский край, Шушенский район, поселок Шушенское, квартал СХТ, 20	f	\N
24177	48928	2121	Красноярский край, Шушенский район, поселок Шушенское, Полукольцевая, 6	f	\N
24174	48925	2118	Красноярский край, Шушенский район, поселок Шушенское, Победы, 3а	f	\N
24173	48924	2117	Красноярский край, Шушенский район, поселок Шушенское, Победы, 3а	f	\N
24175	48926	2119	Красноярский край, Шушенский район, поселок Шушенское, Новая, 2	f	\N
24176	48927	2120	Красноярский край, Шушенский район, поселок Шушенское, 2 микрорайон, 27	f	\N
24178	48929	2122	Красноярский край, Шушенский район, поселок Шушенское, 1 микрорайон, 12	f	\N
24185	48939	2129	Красноярский край, Шушенский район, поселок Шунеры, Победы, 28	f	\N
24186	48940	2130	Красноярский край, Шушенский район, поселок Шарып, Большая, 24	t	\N
24191	48945	2135	Красноярский край, Шушенский район, поселок Субботино, Ленина, 22	t	\N
24193	48947	2137	Красноярский край, Шушенский район, поселок Средняя Шушь, Ленина, 34	t	\N
24199	48954	2143	Красноярский край, Шушенский район, поселок Синеборск, Ленина, 24	f	\N
24190	48944	2134	Красноярский край, Шушенский район, поселок Сизая, Ленина, 40	t	\N
24187	48941	2131	Красноярский край, Шушенский район, поселок Саянск, Малая, 37	t	\N
23855	48613	1782	Красноярский край, Шушенский район, поселок Новопокровка, Шинкарева, 23	t	small
24188	48942	2132	Красноярский край, Шушенский район, поселок Новопокровка, Большая, 50	f	\N
24197	48951	2141	Красноярский край, Шушенский район, поселок Нижняя Коя, Центральная, 36	f	\N
24192	48946	2136	Красноярский край, Шушенский район, поселок Майский, Центральная, 27/2	t	\N
24198	48952	2142	Красноярский край, Шушенский район, поселок Лыткино, Советская, 26	t	\N
24194	48948	2138	Красноярский край, Шушенский район, поселок Ленск, Ленина, 49, Субботинский сельсовет	t	\N
24287	49055	2266	Красноярский край, Шушенский район, поселок Козлово, Центральная, 8	t	\N
24184	48938	2128	Красноярский край, Шушенский район, поселок Каптырево, Малая, 19	f	\N
24196	48950	2140	Красноярский край, Шушенский район, поселок Казанцево, Ленина, 40	f	\N
24180	48931	2124	Красноярский край, Шушенский район, поселок Ильичево, Кирова , 10а	f	\N
24189	48943	2133	Красноярский край, Шушенский район, поселок Иджа, Большая, 34	f	\N
24181	48932	2125	Красноярский край, Шушенский район, поселок Зарничный, Ленина, 2А	f	\N
24182	48934	2126	Красноярский край, Шушенский район, поселок Ермолаево, Центральная, 24	f	\N
24200	48955	2144	Красноярский край, Шушенский район, поселок Дубенское, Октябрьская, 25А	f	\N
24201	48956	2145	Красноярский край, Шушенский район, поселок Весёлые Ключи, Комсомольская, 6	f	\N
24195	48949	2139	Красноярский край, Шушенский район, поселок Белозеровка, Ленина, 19	t	\N
24183	48936	2127	Красноярский край, Шушенский район, поселок Алтан, Школьная, 7б	f	\N
24155	48907	2098	Красноярский край, Шарыповский район, поселок Шушь, Октябрьская, 12	f	small
22810	47527	689	Красноярский край, Шарыповский район, город Шарыпово	f	large
22803	47522	682	Красноярский край, Шарыповский район, город Шарыпово	f	large
22802	47522	681	Красноярский край, Шарыповский район, город Шарыпово	f	large
22799	47520	678	Красноярский край, Шарыповский район, Шарыпово, переулок Школьный, 1	f	large
22814	47530	693	Красноярский край, Шарыповский район, Шарыпово, Шахтерская, 26	f	large
22808	47525	687	Красноярский край, Шарыповский район, Шарыпово, Северный микрорайон, 3	f	large
22811	47526	690	Красноярский край, Шарыповский район, город Шарыпово, Пионерный микрорайон, 52	f	large
22809	47526	688	Красноярский край, Шарыповский район, город Шарыпово, Пионерный микрорайон, 52	f	large
22815	47531	694	Красноярский край, Шарыповский район, город Шарыпово, Комсомольская, 28А	f	large
22797	47518	676	Красноярский край, Шарыповский район, город Шарыпово, Кирова, 9	f	large
24158	48910	2101	Красноярский край, Шарыповский район, поселок Холмогорское	f	large
24157	48909	2100	Красноярский край, Шарыповский район, поселок Холмогорское, Центральная, 12	f	small
24161	48913	2104	Красноярский край, Шарыповский район, поселок Темра, Калинина, 76А	t	small
23754	48509	1679	Красноярский край, Шарыповский район, поселок Сютик, Советская, 2А	f	small
24144	48897	2087	Красноярский край, Шарыповский район, поселок Скрипачи, Школьная, 9А	t	small
24169	48865	2112	Красноярский край, Шарыповский район, поселок Сартачуль, Набережная, 1	f	small
24151	48903	2094	Красноярский край, Шарыповский район, поселок Росинка, Центральная, 12	f	small
24148	48802	2091	Красноярский край, Шарыповский район, поселок Родники, Октябрьская, 17	f	medium
24164	48916	2107	Красноярский край, Шарыповский район, поселок Парная, Советская, 8А	f	medium
24166	48918	2109	Красноярский край, Шарыповский район, поселок Ораки, Центральная, 25а	f	small
24142	48895	2085	Красноярский край, Шарыповский район, поселок Новоалтатка, Советская, 1В	t	medium
24150	48902	2093	Красноярский край, Шарыповский район, поселок Никольск, Октябрьская, 34	f	small
24156	48908	2099	Красноярский край, Шарыповский район, поселок Можары, Центральная, 19	t	small
24162	48914	2105	Красноярский край, Шарыповский район, поселок Линево, Кирова, 14Б	t	small
24146	48899	2089	Красноярский край, Шарыповский район, поселок Крутоярский, Центральная, 19а	t	small
24165	48917	2108	Красноярский край, Шарыповский район, поселок Косые Ложки, Центральная, 30	f	small
24153	48905	2096	Красноярский край, Шарыповский район, поселок Инголь, квартал Путейский, 28А	f	medium
111167	48904	2095	Красноярский край, Шарыповский район, поселок Ивановка, Строителей , 1-А, (здание Ивановского сельсовета	f	medium
24138	48891	2081	Красноярский край, Шарыповский район, поселок Ершово, Садовая, 1В	t	small
86135	48901	2092	Красноярский край, Шарыповский район, поселок городского типа Дубинино, Школьная, 1, здание СОШ №13	f	small
22812	47528	691	Красноярский край, Шарыповский район, Дубинино, Школьная, 4	f	large
41774	39640	35	Кемеровская область, Анжеро-Судженск, Мира, 4	f	\N
22813	47529	692	Красноярский край, Шарыповский район, поселок городского типа Дубинино, Олега Кошевого, 16	f	large
24139	48892	2082	Красноярский край, Шарыповский район, поселок Гудково, Южная, 2	t	small
24307	49068	2286	Красноярский край, Шарыповский район, поселок Горячегорск, Центральная, 7	t	medium
86134	48894	2084	Красноярский край, Шарыповский район, поселок Горбы, Центральная, 28, здание СОШ №12	t	small
24160	48912	2103	Красноярский край, Шарыповский район, поселок Гляден, Новая, 2	f	small
24145	48898	2088	Красноярский край, Шарыповский район, поселок Глинка, Центральная, 2А	t	small
24167	48919	2110	Красноярский край, Шарыповский район, поселок Большое Озеро, Советская, 1	f	small
24163	48915	2106	Красноярский край, Шарыповский район, поселок Береш, Школьная, 11А	f	small
24137	48890	2080	Красноярский край, Шарыповский район, поселок Березовское, Просвещения, 3	t	large
24147	48900	2090	Красноярский край, Шарыповский район, поселок Белоозерка, Центральная, 28	t	small
23150	47869	1048	Красноярский край, Шарыповский район, поселок Александровка, Центральная, 49	f	small
24140	48893	2083	Красноярский край, Шарыповский район, поселок Александровка, Свободная, 24а-1	t	small
24159	48911	2102	Красноярский край, Шарыповский район, поселок Ажинское, Комсомольская, 1А	f	small
24124	48876	2066	Россия, Красноярский край, Уярский район, город Уяр	f	medium
24103	48854	2045	Красноярский край, Уярский район, Уяр, Уланова, 19	f	medium
24110	48861	2052	Красноярский край, Уярский район, Уяр, Ленина, 172 корп. 6	f	medium
24107	48858	2049	Красноярский край, Уярский район, Уяр, Ленина, 72	f	large
24104	48855	2046	Красноярский край, Уярский район, город Уяр, Ленина, 83	f	large
24114	48866	2056	Красноярский край, Уярский район, город Уяр, Красных Партизан, 81	f	medium
24111	48862	2053	Красноярский край, Уярский район, город Уяр, Интернациональная, 67а	f	medium
24109	48860	2051	Красноярский край, Уярский район, Уяр, Дзержинского, 221	f	large
24112	48863	2054	Красноярский край, Уярский район, Уяр, Громовой, 7	f	medium
24106	48857	2048	Красноярский край, Уярский район, город Уяр, Герцена, 46	f	large
24108	48859	2050	Красноярский край, Уярский район, Уяр, 30 лет ВЛКСМ, 131	f	large
24105	48856	2047	Красноярский край, Уярский район, город Уяр, 30 лет ВЛКСМ, 59	f	medium
23915	48674	1843	Красноярский край, Уярский район, поселок Татьяновка, Трактовая, 29	f	small
24121	48873	2063	Красноярский край, Уярский район, поселок Сушиновка, Школьная, 5	f	medium
24135	48888	2077	Красноярский край, Уярский район, поселок Сухоной, Механизаторов, 20	f	small
24123	48875	2065	Красноярский край, Уярский район, поселок Семеновка, клуб	t	small
24134	48887	2076	Красноярский край, Уярский район, поселок Покровка, Клуб	f	small
24131	48884	2073	Красноярский край, Уярский район, поселок Ольгино, Клуб	f	small
24129	48881	2071	Красноярский край, Уярский район, поселок Новопятницкое, Центральный переулок, 5	f	medium
24125	48877	2067	Красноярский край, Уярский район, поселок Новониколаевка, клуб	f	small
24122	48874	2064	Красноярский край, Уярский район, поселок Новомихайловка, Клуб	f	small
24130	48883	2072	Красноярский край, Уярский район, поселок Новоалександровка, Клуб	f	small
24118	48870	2060	Красноярский край, Уярский район, поселок Никольское, Школьная, 7	t	small
24126	48878	2068	Красноярский край, Уярский район, поселок Николаевка, Клуб	f	small
24119	48871	2061	Красноярский край, Уярский район, поселок Марьевка, Ленина, 9	t	small
24120	48872	2062	Красноярский край, Уярский район, поселок Каменно-Горновка, Клуб	t	small
24117	48869	2059	Красноярский край, Уярский район, поселок Жандат, Ленина, 3	t	small
24132	48885	2074	Красноярский край, Уярский район, поселок Громадск, Железнодорожная, 6	t	medium
24127	48879	2069	Красноярский край, Уярский район, поселок Восточное, Советская, 1	f	small
24128	48880	2070	Красноярский край, Уярский район, поселок Воронино, Клуб	f	small
24115	48867	2057	Красноярский край, Уярский район, поселок Балай, Ленина, 34	t	medium
24133	48886	2075	Красноярский край, Уярский район, поселок Авда, Юбилейная, 6	f	small
24083	48834	2025	Красноярский край, Ужурский район, поселок Яга, Советская, 10	t	small
24086	48837	2028	Красноярский край, Ужурский район, поселок Черноозерск, Школьная, 5	f	small
24205	48960	2149	Красноярский край, Ужурский район, поселок Ушканка, Главная, 3	t	small
24078	48829	2020	Красноярский край, Ужурский район, Усть-Изыкчуль (Марьясово), Центральная, 6	f	small
24062	48814	2004	Красноярский край, Ужурский район, Ужур, Советская, 50	f	large
24064	48816	2006	Красноярский край, Ужурский район, город Ужур, Кирова, 30	f	large
24069	48820	2011	Красноярский край, Ужурский район, город Ужур, Вокзальная, 2	f	large
111166	48819	2010	Красноярский край, Ужурский район, Ужур, Вокзальная, 34	f	medium
111165	48819	2009	Красноярский край, Ужурский район, Ужур, Вокзальная, 34	f	medium
24098	48849	2040	Красноярский край, Ужурский район, поселок Тургужан, Школьная, 31	t	small
24082	48833	2024	Красноярский край, Ужурский район, поселок Терехта, Крупской, 1	t	small
24085	48836	2027	Красноярский край, Ужурский район, поселок Тарханка, Советская, 6А	t	small
24206	48961	2150	Красноярский край, Ужурский район, поселок Тальники, Школьная, 9	f	small
24203	48958	2147	Красноярский край, Ужурский район, поселок Сухореченский, Садовая, 1	f	small
24100	48851	2042	Красноярский край, Ужурский район, поселок Сухая Долина, Российская, 18	f	small
24087	48838	2029	Красноярский край, Ужурский район, поселок Старая Кузурба, Новая, 22	t	small
22886	47590	768	Красноярский край, Ужурский район, поселок городского типа Солнечный, Неделина М.И., 106	f	large
22884	47588	766	Красноярский край, Ужурский район, поселок городского типа Солнечный, Неделина М.И, 35	f	large
22883	47587	765	Красноярский край, Ужурский район, поселок городского типа Солнечный, Неделина М.И, 10а	f	large
22882	47587	764	Красноярский край, Ужурский район, поселок городского типа Солнечный, Неделина М.И, 10а	f	large
22885	47589	767	Красноярский край, Ужурский район, поселок Солнечный, Солнечная, 16 стр.1	f	large
24084	48835	2026	Красноярский край, Ужурский район, поселок Солгон, Совхозная, 4	f	large
24101	48852	2043	Красноярский край, Ужурский район, поселок Солбатский, Мира, 11А	t	small
24091	48842	2033	Красноярский край, Ужурский район, поселок Приреченск, Октябрьская, 3	f	medium
24097	48848	2039	Красноярский край, Ужурский район, поселок Прилужье, Садовая, 1	f	small
24102	48853	2044	Красноярский край, Ужурский район, поселок Озеро Учум, Почтовая, 5	f	medium
24077	48828	2019	Красноярский край, Ужурский район, поселок Новоракитка, Победы, 7	f	small
24095	48846	2037	Красноярский край, Ужурский район, поселок Новая Кузурба, Школьная, 8	f	small
24074	48825	2016	Красноярский край, Ужурский район, поселок Михайловка, Тимирязева, 5	f	medium
22964	47671	847	Красноярский край, Ужурский район, поселок Марьясово, Центральная, 2	t	small
24088	48839	2030	Красноярский край, Ужурский район, поселок Малый Имыш, Кооперативная, 2	f	medium
24096	48847	2038	Красноярский край, Ужурский район, поселок Лопатка, Главная, 27	f	small
24072	48823	2014	Красноярский край, Ужурский район, поселок Локшино, Центральная, 19	t	medium
24070	48821	2012	Красноярский край, Ужурский район, поселок Кулун, Главная, 18	f	large
24075	48826	2017	Красноярский край, Ужурский район, поселок Крутояр, Главная, 28	f	large
24073	48824	2015	Красноярский край, Ужурский район, деревня Корнилово, Школьная, 27	t	small
24094	48845	2036	Красноярский край, Ужурский район, поселок Ильинка, Главная , 46	f	small
24081	48832	2023	Красноярский край, Ужурский район, поселок Изыкчуль, Ужурская, 31	t	small
24099	48850	2041	Красноярский край, Ужурский район, поселок Златоруновск, Мира, 7	f	medium
24080	48831	2022	Красноярский край, Ужурский район, поселок Васильевка	f	small
24089	48840	2031	Красноярский край, Ужурский район, поселок Большой Имыш, Школьная, 5	f	small
24090	48841	2032	Красноярский край, Ужурский район, поселок Березовый Лог, Первомайская, 22	f	small
24092	48843	2034	Красноярский край, Ужурский район, поселок Белопольск, Красноярская, 1-2	f	small
24079	48830	2021	Красноярский край, Ужурский район, поселок Белая Роща, Главная, 11	f	small
24071	48822	2013	Красноярский край, Ужурский район, поселок Ашпан, Школьная, 11	t	small
24093	48844	2035	Красноярский край, Ужурский район, поселок Арабкаево, Промышленная, 1	t	small
24076	48827	2018	Красноярский край, Ужурский район, поселок Андроново	f	small
24204	48959	2148	Красноярский край, Ужурский район, поселок Алексеевка, Звездная, 6	f	small
24260	49029	2239	Красноярский край, Тюхтетский район, поселок Чиринда, Заполярная, 7	t	small
40075	36624	1642	Иркутская область, Усть-Кут, Партизанская, 55	t	small
24059	48811	2001	Красноярский край, Тюхтетский район, поселок Чиндат, Центральная, 44	t	small
24040	48792	1980	Красноярский край, Тюхтетский район, поселок Тюхтет, Юбилейная, 1-Б, детский сад Солнышко	f	medium
24039	48791	1979	Красноярский край, Тюхтетский район, поселок Тюхтет, Советская, 12, районный Дом культуры	f	large
24038	48791	1978	Красноярский край, Тюхтетский район, поселок Тюхтет, Советская, 12, районный Дом культуры	f	large
24056	48809	1997	Красноярский край, Тюхтетский район, поселок Сплавной, Трактовая, 17, сельский Дом культуры	t	small
24050	48803	1990	Красноярский край, Тюхтетский район, поселок Соловьёвка, Боброва, 28-А, сельский клуб	f	small
24042	48794	1982	Красноярский край, Тюхтетский район, поселок Пузаново, Центральная, 17-А, сельский клуб	t	small
23048	47756	939	Красноярский край, Тюхтетский район, поселок Проточный, Советская, 7	t	small
24041	48793	1981	Красноярский край, Тюхтетский район, поселок Покровка, Заречная, 14-Б, сельский клуб	f	small
24057	48810	1998	Красноярский край, Тюхтетский район, поселок Поваренкино, Сибирская, 46, сельский Дом культуры	f	small
24060	48812	2002	Красноярский край, Тюхтетский район, поселок Пасечное, Чулымская, 3, сельский Дом культуры	t	small
24043	48795	1983	Красноярский край, Тюхтетский район, поселок Оскаровка, Колхозная, 20-А, сельский клуб	t	small
24048	48800	1988	Красноярский край, Тюхтетский район, поселок Новомитрополька, Советская, 46, сельский Дом культуры	f	small
24049	48801	1989	Красноярский край, Тюхтетский район, поселок Никольск, Лесная, 7-1, ФАП	t	small
24051	48804	1991	Красноярский край, Тюхтетский район, поселок Леонтьевка, Центральная, 3, администрация сельсовета	f	small
24046	48798	1986	Красноярский край, Тюхтетский район, поселок Ларнёвка, Верхняя, 15, сельский клуб	f	small
24045	48797	1985	Красноярский край, Тюхтетский район, поселок Лазарево, Шахова, 14, администрация сельсовета	f	small
24054	48807	1995	Красноярский край, Тюхтетский район, поселок Красинка, Советская, 8, администрация сельсовета	f	small
111154	48132	1296	Красноярский край, Тюхтетский район, поселок Ивановка, Интернациональная, 3	f	\N
24052	48805	1992	Красноярский край, Тюхтетский район, поселок Зареченка, Революции, 33, администрация сельсовета	f	small
24044	48796	1984	Красноярский край, Тюхтетский район, поселок Двинка, Советская, 10, Двинский сельсовет	f	small
24055	48808	1996	Красноярский край, Тюхтетский район, поселок Верх-Четск, Советская, 6, сельский Дом культуры	t	small
24047	48799	1987	Красноярский край, Тюхтетский район, поселок Васильевка, Еланьская, 29, сельский клуб	f	small
24053	48806	1993	Красноярский край, Тюхтетский район, поселок Безручейка, сельский клуб	t	small
24027	48780	1964	Красноярский край, Туруханский район, д.Сургутиха, Центральная, 14	t	small
24033	48786	1972	Красноярский край, Туруханский район, д.Старо-Туруханск, Декабристов, 29	t	small
24036	48789	1976	Красноярский край, Туруханский район, поселок Советская Речка, Центральная, 2	t	small
24026	48779	1962	Красноярский край, Туруханский район, поселок Келлог, Центральная, 33	t	small
24025	48778	1961	Красноярский край, Туруханский район, село Верхнеимбатск, Бограда, 17, дом культуры	t	small
24028	48781	1965	Красноярский край, Туруханский район, село Верещагино, Набережная, 9	t	small
24283	49052	2262	Красноярский край, Тунгусско-Чунский район, п.Муторай, Набережная, 14	t	small
24007	48757	1940	Красноярский край, Тасеевский район, поселок Ялай, Школьная, 2	f	small
24312	49073	2294	Красноярский край, Тасеевский район, поселок Шивера, Лесная, 35	t	small
22917	47621	800	Красноярский край, Тасеевский район, поселок Чигашет, Школьная, 39	t	small
24008	48758	1941	Красноярский край, Тасеевский район, поселок Хандала, Центральная, 6	f	small
24013	48762	1946	Красноярский край, Тасеевский район, поселок Фаначет, Центральная , 22	t	small
24014	48763	1947	Красноярский край, Тасеевский район, поселок Унжа, Карпачева, 39	t	small
24018	48768	1952	Красноярский край, Тасеевский район, поселок Троицк, Большевистская, 10	f	medium
66102	48746	1923	Красноярский край, Тасеевский район, поселок Тасеево, переулок Центральный, 1	f	medium
24037	48790	1977	Красноярский край, Тасеевский район, поселок Тасеево, Сурикова,, 10	f	large
23944	41313	1873	Красноярский край, Саянский район, поселок Межово, Новая, 34	t	medium
23997	48749	1929	Красноярский край, Тасеевский район, поселок Тасеево, Октябрьская, 141	f	medium
24136	48889	2079	Красноярский край, Тасеевский район, поселок Тасеево, Мичурина, 8	f	medium
23995	48715	1927	Красноярский край, Тасеевский район, поселок Тасеево, Луначарского, 6	f	medium
23994	48748	1925	Красноярский край, Тасеевский район, поселок Тасеево, Гагарина, 12	f	medium
23993	48747	1924	Красноярский край, Тасеевский район, поселок Тасеево, Лихачева, 18	f	large
111164	48750	1931	Красноярский край, Тасеевский район, поселок Сухово, Пролетарская, 7, здание сельской администрации	t	medium
24000	48751	1932	Красноярский край, Тасеевский район, поселок Струково, Раздолинская, 10 кв.2	t	small
24011	48761	1944	Красноярский край, Тасеевский район, поселок Скакальная, Гагарина, 40 кв.2	f	small
24004	48754	1937	Красноярский край, Тасеевский район, поселок Сивохино, Слобода, 1	f	small
24015	48764	1948	Красноярский край, Тасеевский район, поселок Мурма, Советская, 44 А	t	small
24006	48756	1939	Красноярский край, Тасеевский район, поселок Лукашино, Центральная, 18	f	small
24019	48769	1953	Красноярский край, Тасеевский район, поселок Лужки, Чкалова, 1	f	small
24005	48755	1938	Красноярский край, Тасеевский район, поселок Корсаково, Гагарина, 41	t	small
24001	48752	1934	Красноярский край, Тасеевский район, поселок Караульное, Октябрьская, 61	t	small
24010	48760	1943	Красноярский край, Тасеевский район, поселок Веселое, Советская, 39	t	small
24017	48766	1950	Красноярский край, Тасеевский район, поселок Вахрушево, Центральная, 4	t	small
24002	48753	1935	Красноярский край, Тасеевский район, поселок Бурмакино, Чапаева, 27	t	small
24016	48765	1949	Красноярский край, Тасеевский район, поселок Бартанас, Пролетарская, 13 А	t	small
24009	48759	1942	Красноярский край, Тасеевский район, поселок Бакчет, Кузнечная, 71	f	small
24253	49022	2232	Красноярский край, Таймырский Долгано-Ненцкий район, поселок Сындасско, Сельский дом культуры	t	small
24231	48995	2210	Красноярский край, Таймырский Долгано-Ненцкий район, Поселок Дудинка, МБУК Городской дом культуры	f	medium
24242	49012	2221	Красноярский край, Таймырский Долгано-Ненцкий район, Поселок Байкаловск, Дом культуры посёлка Байкаловск	t	small
24238	49006	2217	Красноярский край, Таймырский Долгано-Ненецкий район, п. Воронцово, Дом культуры поселка Воронцово	f	small
24243	49013	2222	Красноярский край, Таймырский Долгано-Ненецкий район, поселок Тухард, Дом культуры посёлка Тухард	t	small
24240	49009	2219	Красноярский край, Таймырский Долгано-Ненецкий район, село Караул, Дом культуры села Караул	f	medium
24226	48982	2204	Красноярский край, Таймырский Долгано-Ненецкий район, поселок Дудунка, ТМКОУ Дудинская гимназия	f	large
24239	49007	2218	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, п. Усть-Порт, Дом культуры	f	small
24241	49010	2220	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, п. Носок, Дом культуры поселка Носок	f	medium
24230	48992	2209	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, Общежитие КГБОУСПО Таймырский колледж	f	large
24232	48996	2211	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Дудинка, поселок Левинские Пески, Детский сад посёлка Левинские Пески	t	small
24223	48977	2199	Красноярский край, Таймырский Долгано-Ненецкий муниципальный район, городское поселение Диксон, МКУК Культурно-досуговый центр г.п. Диксон	f	medium
23973	48726	1903	Красноярский край, Сухобузимский район , село Миндерла, Степная, 10	f	large
23963	48716	1893	Красноярский край, Сухобузимский район , поселок Мингуль, Школьная, 3-а	f	small
23987	48740	1917	Красноярский край, Сухобузимский район , деревня Воробино, Школьная, 8	f	small
111163	48717	1894	Красноярский край, Сухобузимский район , поселок Борск, Ленина, 12	f	medium
23992	48745	1922	Красноярский край, Сухобузимский район, поселок Шошкино, Зеланая, 15-2	f	small
23965	48718	1895	Красноярский край, Сухобузимский район, поселок Шилинка, Новая, 2	f	small
23989	48742	1919	Красноярский край, Сухобузимский район, поселок Шила, Ленина, 75	f	large
23972	48725	1902	Красноярский край, Сухобузимский район, поселок Хлоптуново, Первомайская, 57	f	small
23988	48741	1918	Красноярский край, Сухобузимский район, село Толстомысово, Южная, 14	f	small
24288	49056	2267	Красноярский край, Сухобузимский район, поселок Сухобузимское, Юбилейная, 1	f	small
23984	48737	1914	Красноярский край, Сухобузимский район, поселок Сухобузимское, Центральная, 8	f	medium
23985	48738	1915	Красноярский край, Сухобузимский район, поселок Сухобузимское, Ленина, 33	f	medium
67993	48736	1913	Красноярский край, Сухобузимский район, поселок Сухобузимское, Ленина, 75-Б	f	large
23969	48722	1899	Красноярский край, Сухобузимский район, поселок Седельниково, 8 Марта, 9-а	f	small
23244	47978	1147	Красноярский край, Сухобузимский район, поселок Первомайский, Октябрьская, 3	t	small
23979	48732	1909	Красноярский край, Сухобузимский район, поселок Павловщина, Лукьянова, 30	t	medium
23991	48744	1921	Красноярский край, Сухобузимский район, поселок Новотроицкое, Ленина, 54	f	small
23975	48728	1905	Красноярский край, Сухобузимский район, поселок Нахвальское, Школьная, 15	t	small
23977	48730	1907	Красноярский край, Сухобузимский район, поселок Малое Нахвальское, Новая, 40	t	small
23978	48731	1908	Красноярский край, Сухобузимский район, поселок Малиновка, Трактовая, 39а	f	small
23970	48723	1900	Красноярский край, Сухобузимский район, поселок Кононово, Транспортная, 11	f	medium
23990	48743	1920	Красноярский край, Сухобузимский район, поселок Ковригино, Ленина, 23	f	small
23968	48721	1898	Красноярский край, Сухобузимский район, поселок Кекур, Центральная, 24	f	small
23981	48734	1911	Красноярский край, Сухобузимский район, деревня Карымская, Центральная, 24	f	small
23962	48714	1892	Красноярский край, Сухобузимский район, поселок Исток, Центральная, 17	f	small
23966	48719	1896	Красноярский край, Сухобузимский район, поселок Высотино, Площадь Победы, 1	f	medium
23126	47839	1022	Красноярский край, Сухобузимский район, поселок Бузуново, Механизаторов, 12 А	f	small
23986	48739	1916	Красноярский край, Сухобузимский район, поселок Бузим, здание базы отдыха Бузим	f	small
23961	48713	1891	Красноярский край, Сухобузимский район, поселок Бузим, Школьная, 1-а	f	small
23971	48724	1901	Красноярский край, Сухобузимский район, поселок Большой Балчуг, Центральная, 37	f	small
23976	48729	1906	Красноярский край, Сухобузимский район, поселок Берег Таскино, Береговая, 17-а	t	small
24301	49063	2280	Красноярский край, Сухобузимский район, поселок Атаманово, Школьная, 6	f	medium
67992	48711	1889	Красноярский край, Сухобузимский район, поселок Атаманово, Октябрьская, 47-В	f	large
23967	48720	1897	Красноярский край, Сухобузимский район, поселок Абакшино, Центральная, 48	f	small
23982	48735	1912	Красноярский край, Сухобузимский, деревня Татарская, Новая, 1	f	small
23980	48733	1910	Красноярский край, Сухобузимский, село Подсопки, Новая, 17	f	small
23949	48709	1887	Красноярский край, Северо-Енисейский район, рабочий поселок Северо-Енисейский, Ленина, 9	f	large
23954	48706	1884	Красноярский край, Северо-Енисейский район, поселок Северо-Енисейский, Энергетиков, 1	f	small
23958	48710	1888	Красноярский край, Северо-Енисейский район, поселок Вельмо, Центральная, 25	f	small
23956	48708	1886	Красноярский край, Северо-Енисейский район, поселок Брянка, Школьная, 42	f	small
23946	48611	1876	Красноярский край, Саянский район, поселок Чарга, Центральная, 12	t	small
86133	48701	1878	Красноярский край, Саянский район, поселок Усть-Анжа, Центральная, 34	t	small
23942	48699	1871	Красноярский край, Саянский район, поселок Унер, Советская, 43а	t	medium
23935	48692	1864	Красноярский край, Саянский район, поселок Тугач, Антонова, 7	t	medium
23945	41532	1875	Красноярский край, Саянский район, поселок Тинская, Ковалева, 1	t	small
23941	48698	1870	Красноярский край, Саянский район, поселок Средняя Агинка, Советская, 39	f	small
22985	47692	868	Красноярский край, Саянский район, поселок Петропавловка, Ленина, 17	t	small
23750	48505	1675	Красноярский край, Саянский район, поселок Павловка, Центральная, 23	f	medium
23934	48691	1863	Красноярский край, Саянский район, поселок Орье, Школьный, 2	t	small
86132	48696	1868	Красноярский край, Саянский район, поселок Орловка, Центральная, 48	t	small
23947	41700	1877	Красноярский край, Саянский район, поселок Нагорное, Кузьмина, 74	f	small
23128	47841	1025	Красноярский край, Саянский район, поселок Межово, Я.Стоценко, 39	f	small
40047	36596	1614	Иркутская область, Усть-Кут, Панихинская, 2	t	small
23932	48689	1861	Красноярский край, Саянский район, поселок Малиновка, Ленина, 46	t	small
23940	48697	1869	Красноярский край, Саянский район, поселок Кулижниково, Советская, 52	t	small
23937	48694	1866	Красноярский край, Саянский район, поселок Карлык, Таежная, 31	t	small
23936	48693	1865	Красноярский край, Саянский район, поселок Гладково, Киселева, 12А	t	small
23931	48688	1859	Красноярский край, Саянский район, поселок Большой Ильбин, Зеленая, 6	f	small
86131	48695	1867	Красноярский край, Саянский район, поселок Большой Арбай, Кооперативная, 42	t	small
23943	48700	1872	Красноярский край, Саянский район, поселок Благодатка, Центральная, 18	t	small
23930	48687	1858	Красноярский край, Саянский район, поселок Агинское, Строительная, 21	f	large
23928	48685	1856	Красноярский край, Саянский район, поселок Агинское, Советская, 149	f	large
23929	48686	1857	Красноярский край, Саянский район, поселок Агинское, Дружбы, 7а	f	large
23259	47995	1164	Красноярский край, Саянский район, поселок Абалаково, Школьная, 5а	t	medium
23257	47993	1162	Красноярский край, Саянский район, поселок Абалаково, Нефтяников, 14	f	large
23921	48680	1849	Красноярский край, Рыбинский район, поселок Чуриново, Подгорная, 31	f	small
23925	48683	1853	Красноярский край, Рыбинский район, поселок Усть-Кандыга, Советская, 39	t	small
23416	48158	1322	Красноярский край, Рыбинский район, поселок Успенка, Энергетиков, 9-1	t	\N
86156	48572	1739	Красноярский край, Рыбинский район, поселок Успенка, Центральная, 27а	f	small
23890	48648	1818	Красноярский край, Рыбинский район, поселок Успенка, Просвещения, 38	f	medium
22932	47636	815	Красноярский край, Рыбинский район, поселок Успенка, Новая, 4	t	small
22255	47171	106	Красноярский край, Рыбинский район, поселок городского типа Урал, Первомайская, 10	f	large
23912	48671	1840	Красноярский край, Рыбинский район, поселок Тульское, Зеленая, 30	f	small
23904	48662	1832	Красноярский край, Рыбинский район, поселок Старая Солянка, Школьная, 11	t	small
23920	48679	1848	Красноярский край, Рыбинский район, поселок Соловьевка, Школьная, 32	t	small
23922	48681	1850	Красноярский край, Рыбинский район, поселок Снегирёвка, Центральная, 17	f	small
23230	47963	1133	Красноярский край, Рыбинский район, поселок Сибиряк, Центральная, 13	f	small
24308	49069	2290	Красноярский край, Рыбинский район, поселок городского типа Саянский, Комсомольская, 5	f	large
23926	48684	1854	Красноярский край, Рыбинский район, поселок городского типа Саянский, Комсомольская, 4	f	large
23903	48661	1831	Красноярский край, Рыбинский район, поселок Рябинки, Лесная, 24	t	small
23914	48673	1842	Красноярский край, Рыбинский район, поселок Рыбное, Трактовая, 1 А	f	medium
23716	48477	1641	Красноярский край, Рыбинский район, поселок Рыбное, Советская, 49	t	small
23923	48665	1851	Красноярский край, Рыбинский район, поселок Переясловка, Садовая, 6	f	medium
23897	48655	1825	Красноярский край, Рыбинский район, поселок Новокамала, Шахтерская, 26	f	small
23896	48654	1824	Красноярский край, Рыбинский район, поселок Новокамала, Советская, 20 А	f	medium
23902	48660	1830	Красноярский край, Рыбинский район, поселок Новая Солянка, Южная, 16	f	medium
23901	48659	1829	Красноярский край, Рыбинский район, поселок Новая Солянка, 1-я Центральная, 13	f	large
23892	48650	1820	Красноярский край, Рыбинский район, поселок Новая Прилука, Низовая, 15, 1	t	small
23893	48651	1821	Красноярский край, Рыбинский район, поселок Новая Печера, Советская, 42	t	small
24246	49016	2225	Красноярский край, Рыбинский район, поселок Новая, Сельский дом культуры	t	small
23916	48675	1844	Красноярский край, Рыбинский район, поселок Новая, Молодежная, 1	f	small
23909	48668	1837	Красноярский край, Рыбинский район, поселок Низинка, Центральная, 6	t	small
23917	48676	1845	Красноярский край, Рыбинский район, поселок Налобино, Советская, 15	t	small
23894	48652	1822	Красноярский край, Рыбинский район, поселок Малая Камала, Трактовая, 8	f	small
23913	48672	1841	Красноярский край, Рыбинский район, Лощинка, Центральная, 16	t	small
23910	48669	1838	Красноярский край, Рыбинский район, поселок Лозовая, Центральная, 19	t	small
23924	48682	1852	Красноярский край, Рыбинский район, поселок Красногорьевка, Школьная, 21	f	small
22254	47170	105	Красноярский край, Рыбинский район, поселок городского типа Ирша, Победы, 4	f	medium
23467	48212	1374	Красноярский край, Рыбинский район, поселок Ивановка, Трактовая, 3	t	small
23899	48657	1827	Красноярский край, Рыбинский район, поселок Ивановка, Советская, 2 Б 2	f	small
22879	47585	759	Красноярский край, Рыбинский район, город Зеленогорск, Шолохова, 1	f	large
22872	47579	752	Красноярский край, Рыбинский район, город Зеленогорск, Строителей, 19	f	large
22871	47578	751	Красноярский край, Рыбинский район, город Зеленогорск, Строителей, 12А	f	large
22859	47567	739	Красноярский край, Рыбинский район, Зеленогорск, Советская, 5А	f	large
22876	47582	756	Красноярский край, Рыбинский район, город Зеленогорск, Парковая, 54А	f	large
22874	47580	754	Красноярский край, Рыбинский район, город Зеленогорск, Парковая, 40	f	large
22873	47580	753	Красноярский край, Рыбинский район, город Зеленогорск, Парковая, 40	f	large
22875	47581	755	Красноярский край, Рыбинский район, Зеленогорск, Набережная, 62	f	large
22865	47573	745	Красноярский край, Рыбинский район, Зеленогорск, Набережная, 28	f	large
22861	47569	741	Красноярский край, Рыбинский район, город Зеленогорск, Набережная, 14	f	large
22858	47566	738	Красноярский край, Рыбинский район, Зеленогорск, Набережная, 4	f	large
22866	47574	746	Красноярский край, Рыбинский район, город Зеленогорск, Заводская, 8а	f	large
22878	47584	758	Красноярский край, Рыбинский район, Зеленогорск, Диктатуры Пролетариата, 20	f	large
22864	47572	744	Красноярский край, Рыбинский район, город Зеленогорск, Гагарина, 21	f	large
22863	47571	743	Красноярский край, Рыбинский район, Зеленогорск, Гагарина, 11	f	large
22868	47576	748	Красноярский край, Рыбинский район, Зеленогорск, Бортникова, 23	f	large
22867	47575	747	Красноярский край, Рыбинский район, город Зеленогорск, Бортникова, 13	f	large
22862	47570	742	Красноярский край, Рыбинский район, город Зеленогорск, Бортникова, 1	f	large
22249	47165	100	Красноярский край, Рыбинский район, город Заозерный, Советская, 12	f	medium
22252	47168	103	Красноярский край, Рыбинский район, город Заозерный, Прохорова, 29	f	large
22251	47167	102	Красноярский край, Рыбинский район, Заозерный, Панина, 2	f	large
22250	47166	101	Красноярский край, Рыбинский район, Заозерный, Армейская, 1	f	small
22253	47169	104	Красноярский край, Рыбинский район, город Заозерный, 3-е Сентября, 22	f	medium
23905	48663	1833	Красноярский край, Рыбинский район, поселок Завировка, Победы, 1, 1	t	small
23919	48678	1847	Красноярский край, Рыбинский район, поселок Двуречное, Садовая, 6	f	medium
23898	48656	1826	Красноярский край, Рыбинский район, поселок Гмирянка, Центральная, 45	t	small
23918	48677	1846	Красноярский край, Рыбинский район, поселок Глубоково, Школьная, 22	t	small
23900	48658	1828	Красноярский край, Рыбинский район, поселок Воскресенка, Лесная, 24	t	small
23911	48670	1839	Красноярский край, Рыбинский район, поселок Верховая, Центральная, 10	t	small
23908	48667	1836	Красноярский край, Рыбинский район, поселок Бородино, Советская, 12	f	medium
23907	48666	1835	Красноярский край, Рыбинский район, поселок Большие Ключи, 40 лет Победы, 4	f	small
23891	48649	1819	Красноярский край, Рыбинский район, поселок Александровка, Советская, 29а	t	medium
23889	48647	1817	Красноярский край, Пировский район, поселок Чайда, Школьная, 7	t	small
24031	48784	1970	Красноярский край, Пировский район, поселок Туруханка, Портовая, здание аэровокзала	f	medium
23886	48644	1814	Красноярский край, Пировский район, поселок Троица, Мира, 63	f	medium
23883	48641	1811	Красноярский край, Пировский район, поселок Солоуха, Центральная, 26	f	small
23882	48640	1810	Красноярский край, Пировский район, поселок Пировское, 1 Мая, 28	f	large
22908	47612	791	Красноярский край, Пировский район, поселок Петропавловка, Молодежная, 16	t	small
23877	48635	1805	Красноярский край, Пировский район, поселок Омский, Школьная, 1а	t	small
23875	48633	1803	Красноярский край, Пировский район, поселок Новый Тимерщик, Центральная, 31	f	small
23438	48183	1344	Красноярский край, Пировский район, поселок Новотроицкое, Центральная, 29	f	small
23885	48643	1813	Красноярский край, Пировский район, поселок Новониколаевское, Бирнасовская, 29а	t	small
23888	48646	1816	Красноярский край, Пировский район, поселок Куренная Ошма, Солнечная, 22	f	small
23881	48639	1809	Красноярский край, Пировский район, поселок Комаровка, Центральный, 2	t	small
23880	48638	1808	Красноярский край, Пировский район, поселок Коврига, Зелёная, 2	f	small
23878	48636	1806	Красноярский край, Пировский район, поселок Кириково, Зеленая, 16	f	small
23876	48634	1804	Красноярский край, Пировский район, поселок Кетский, Центральная, 37	t	medium
23874	48632	1802	Красноярский край, Пировский район, поселок Икшурма, Школьная, 6	f	small
23884	48642	1812	Красноярский край, Пировский район, поселок Долгово, Качаева, 1	f	small
23879	48637	1807	Красноярский край, Пировский район, поселок Волоковое, Березовая, 28Б	t	small
23873	48631	1801	Красноярский край, Пировский район, поселок Бушуй, Молодёжная, 7	f	small
23887	48645	1815	Красноярский край, Пировский район, поселок Бельское, Дзержинского, 16а	f	small
23872	48630	1800	Красноярский край, Пировский район, поселок Алтат, Советская, 32	f	small
23734	48263	1659	Красноярский край, Пировский район, поселок Алтат, Партизанская, 1	f	small
24244	49014	2223	Красноярский край, Партизанский район, п. Катырык, сельский дом культуры	t	small
22974	47681	857	Красноярский край, Партизанский район, поселок Чистые Пруды, улица Школьная, 8	f	small
23859	48617	1786	Красноярский край, Партизанский район, поселок Хайдак, Центральная, 56	t	small
86130	48626	1795	Красноярский край, Партизанский район, поселок Хабайдак, Гагарина, 9А, помещение сельского клуба	t	small
23871	48595	1799	Красноярский край, Партизанский район, поселок Стойба, Советская, 5	t	medium
23854	48612	1781	Красноярский край, Партизанский район, поселок Солонечно-Талое, Партизанская, 26А	t	small
23869	48627	1797	Красноярский край, Партизанский район, поселок Партизанское, Советская, 23	f	large
111162	48628	1798	Красноярский край, Партизанский район, поселок Партизанское, 60 лет СССР, 4а, помещение библиотеки имени М.Д.Родкина	f	medium
86129	48616	1785	Красноярский край, Партизанский район, поселок Ной, Центральная, 33а, помещение сельского клуба	t	small
23862	48620	1789	Красноярский край, Партизанский район, поселок Новомихайловка, Кирова, 52	f	small
23866	48624	1793	Красноярский край, Партизанский район, поселок Мина, Школьная, 30	f	small
23867	48625	1794	Красноярский край, Партизанский район, поселок Мана, Лесная, 15	f	medium
23857	48615	1784	Красноярский край, Партизанский район, поселок Малый Имбеж, Зеленая, 56	f	small
23865	48623	1792	Красноярский край, Партизанский район, поселок Кой, Берегового, 56А	f	small
23864	48622	1791	Красноярский край, Партизанский район, поселок Кожелак, Центральная, 28	t	small
23861	48619	1788	Красноярский край, Партизанский район, поселок Ивашиха, Гагарина, 56	t	small
23856	48614	1783	Красноярский край, Партизанский район, поселок Запасной Имбеж, Центральная, 12	f	medium
24235	49001	2214	Красноярский край, Партизанский район, Дудинка, поселок Усть-Авам, Сельский дом культуры посёлка Усть-Авам	t	small
24021	48772	1955	Красноярский край, Партизанский район, село Ворогово, Андреевой, 27	f	medium
23853	48565	1780	Красноярский край, Партизанский район, поселок Вершино-Рыбное, Ленина, 31а	f	medium
23851	48535	1778	Красноярский край, Партизанский район, поселок Богуславка, Школьный переулок, 3	t	small
23841	48601	1768	Красноярский край, Новоселовский район, поселок Чулым, Советская, 26	f	medium
23840	48600	1767	Красноярский край, Новоселовский район, поселок Чесноки, Зеленая, 10	f	small
23832	48591	1759	Красноярский край, Новоселовский район, поселок Черная Кома, Народная, 55	f	small
23843	48603	1770	Красноярский край, Новоселовский район, поселок Увалы, Центральная, 31	f	small
23848	48608	1775	Красноярский край, Новоселовский район, поселок Толстый Мыс, Степная, 2в	f	small
23828	48587	1755	Красноярский край, Новоселовский район, поселок Тесь, Школьная, 5	f	small
23827	48586	1754	Красноярский край, Новоселовский район, поселок Тальцы, Победы, 4	f	small
23829	48588	1756	Красноярский край, Новоселовский район, поселок Табажак, Советская, 2	f	small
23844	48604	1771	Красноярский край, Новоселовский район, поселок Светлолобово, Мудрова, 21	f	medium
23830	48589	1757	Красноярский край, Новоселовский район, поселок Приморский, Советская, 20	f	small
23824	48583	1751	Красноярский край, Новоселовский район, поселок Новоселово, Школьная, 8	f	large
23823	48582	1750	Красноярский край, Новоселовский район, поселок Новоселово, Театральная, 11	f	large
23822	48581	1749	Красноярский край, Новоселовский район, поселок Новоселово, Почтовая, 1	f	large
23845	48605	1772	Красноярский край, Новоселовский район, поселок Николаевка, Рабочая, 1	f	small
23842	48602	1769	Красноярский край, Новоселовский район, поселок Легостаево, Октябрьская, 11	f	small
23839	48599	1766	Красноярский край, Новоселовский район, поселок Куртак, Школьный, 2	t	small
23837	48597	1764	Красноярский край, Новоселовский район, поселок Курганы, Советская, 2	t	small
23835	48594	1762	Красноярский край, Новоселовский район, поселок Кульчек, Клубная, 8	t	small
23826	48585	1753	Красноярский край, Новоселовский район, поселок Куллог, Центральная, 16	f	small
23831	48590	1758	Красноярский край, Новоселовский район, поселок Кома, Анашкина, 4	f	medium
23847	48607	1774	Красноярский край, Новоселовский район, поселок Камчатка, Береговая, 31а	t	small
23850	48610	1777	Красноярский край, Новоселовский район, поселок Интикуль, Октябрьская, 4а	f	small
23833	48592	1760	Красноярский край, Новоселовский район, поселок Енисей, Партизанская, 7	t	small
23838	48598	1765	Красноярский край, Новоселовский район, поселок Дивный, Центральная, 4	f	small
23834	48593	1761	Красноярский край, Новоселовский район, поселок Бескиш, Рабочая, 10	t	small
23836	48596	1763	Красноярский край, Новоселовский район, поселок Березовый, Маяковского, 11	t	small
23846	48606	1773	Красноярский край, Новоселовский район, поселок Бараит, Центральная, 9б	f	small
23849	48609	1776	Красноярский край, Новоселовский район, поселок Аёшка, Школьная, 20а	f	small
23825	48584	1752	Красноярский край, Новоселовский район, поселок Анаш, Октябрьская, 41	f	medium
86206	48551	1719	Красноярский край, Нижнеингашский район, поселок Южная Тунгуска, Трактовая, 26	t	small
86151	48567	1734	Красноярский край, Нижнеингашский район, поселок Эстония, Таллинская, 20	t	small
68008	48578	1745	Красноярский край, Нижнеингашский район, поселок Тины, Мира, 5	f	large
111159	48545	1714	Красноярский край, Нижнеингашский район, поселок городского типа Тинской, Молодежная, 20	t	medium
23791	48547	1716	Красноярский край, Нижнеингашский район, поселок городского типа Тинской, Вокзальная, 5	t	medium
23792	48548	1717	Красноярский край, Нижнеингашский район, поселок Тинской, Советская, 29	t	medium
23790	48546	1715	Красноярский край, Нижнеингашский район, поселок Тинской, Первомайская, 47	t	medium
86157	48573	1740	Красноярский край, Нижнеингашский район, поселок Стретенка, переулок Западный, 2	t	small
23818	48576	1744	Красноярский край, Нижнеингашский район, деревня Старцево, Центральная, 1	f	medium
86153	48569	1736	Красноярский край, Нижнеингашский район, поселок Соколовка, переулок Клубный, 1	t	small
86163	48574	1742	Красноярский край, Нижнеингашский район, поселок Поскотино, Центральная, 35	f	small
22918	47622	801	Красноярский край, Нижнеингашский район, поселок Покровка, Советская, 18Б	t	small
86155	48571	1738	Красноярский край, Нижнеингашский район, поселок Покровка, Зеленая, 13	f	small
86205	48549	1718	Красноярский край, Нижнеингашский район, поселок городского типа Поканаевка, Октябрьская , 3	t	small
86166	48580	1747	Красноярский край, Нижнеингашский район, поселок Поймо-Тины, Центральная, 1а	f	small
86152	48568	1735	Красноярский край, Нижнеингашский район, поселок Павловка, Центральная, 11	f	small
86148	48563	1731	Красноярский край, Нижнеингашский район, деревня Ошарово, Дачная, 31	f	small
24276	49045	2255	Красноярский край, Нижнеингашский район, поселок Ошарово, Набережная, 8А	t	small
86164	48575	1743	Красноярский край, Нижнеингашский район, поселок Новорождественка, Молодежная, 1	f	small
86149	48564	1732	Красноярский край, Нижнеингашский район, поселок Новоалександровка, Центральная, 49	t	small
86203	48538	1707	Красноярский край, Нижнеингашский район, поселок Новая Пойма, Центральная, 35/1	t	small
23784	48540	1709	Красноярский край, Нижнеингашский район, поселок Нижняя Пойма, Дзержинского, 8	f	large
68023	48541	1710	Красноярский край, Нижнеингашский район, поселок городского типа Нижняя Пойма, микрорайон Спутник , 18	f	large
23787	48543	1712	Красноярский край, Нижнеингашский район, поселок городского типа Нижняя Пойма, Семафорная, 1	f	large
22706	47451	584	Красноярский край, Назаровский район, Назарово, Труда, 11 Д	f	large
23786	48542	1711	Красноярский край, Нижнеингашский район, поселок городского типа Нижняя Пойма, Первомайская, 1	f	large
23778	48533	1703	Красноярский край, Нижнеингашский район, поселок Нижний Ингаш, Зеленая, 18	f	large
23780	48536	1705	Красноярский край, Нижнеингашский район, поселок городского типа Нижний Ингаш, Терешковой, 2	f	small
23779	48534	1704	Красноярский край, Нижнеингашский район, поселок городского типа Нижний Ингаш, Новая, 2б	f	large
23777	48532	1702	Красноярский край, Нижнеингашский район, поселок городского типа Нижний Ингаш, Лесная, 1	f	small
23803	48560	1728	Красноярский край, Нижнеингашский район, поселок городского типа Нижний Ингаш, Ленина, 157	f	medium
86154	48570	1737	Красноярский край, Нижнеингашский район, поселок Михайловка, Цетральная, 40	t	small
86144	48557	1725	Красноярский край, Нижнеингашский район, поселок Максаковка, Центральная, 25	f	small
86147	48562	1730	Красноярский край, Нижнеингашский район, поселок Кучерово, Центральная, 46	f	small
23788	48544	1713	Красноярский край, Нижнеингашский район, поселок Курдояки, Центральная, 1	t	small
86207	48552	1720	Красноярский край, Нижнеингашский район, поселок Кедровый, переулок Школьный, 4	t	small
86146	48561	1729	Красноярский край, Нижнеингашский район, поселок Касьяново, Центральная, 3	f	small
68004	48558	1726	Красноярский край, Нижнеингашский район, поселок Канифольный, Школьная, 1	f	large
86143	48556	1724	Красноярский край, Нижнеингашский район, поселок Ивановка, Центральная, 20	f	small
86165	48579	1746	Красноярский край, Нижнеингашский район, поселок Елизаветка, Центральная, 9	t	small
111160	48555	1723	Красноярский край, Нижнеингашский район, поселок Верхний Ингаш, Центральная, 83	f	medium
23781	48537	1706	Красноярский край, Нижнеингашский район, поселок Верхний Ингаш, Лаптева, 7	f	small
86145	48559	1727	Красноярский край, Нижнеингашский район, поселок Бельняки, Молодежная, 1а	t	small
86208	48553	1721	Красноярский край, Нижнеингашский район, поселок Александровка, Центральная, 25	f	small
23739	40247	1664	Красноярский край, Назаровский район, Ярлыково, Садовая, 3	f	small
23747	48502	1672	Красноярский край, Назаровский район, поселок Шипиловка, Нижняя, 6	f	small
23761	48516	1686	Красноярский край, Назаровский район, поселок Чердынь, Молодежная, 3	f	small
23764	48519	1689	Красноярский край, Назаровский район, поселок Холма, Гусарова, 43	t	small
23774	48529	1699	Красноярский край, Назаровский район, поселок Усть-Березовка, Заречная, 35а	f	small
23726	48487	1651	Красноярский край, Назаровский район, поселок Степноозерка, Центральная, 45	f	small
23766	48521	1691	Красноярский край, Назаровский район, поселок Степной, Школьная, 13	f	large
23757	48512	1682	Красноярский край, Назаровский район, поселок Старожилово, Центральная, 3	t	small
23769	48524	1694	Красноярский край, Назаровский район, поселок Средняя Березовка, Степная, 33А	f	small
23720	48481	1645	Красноярский край, Назаровский район, поселок Сохновка, Борьбы, 10	f	small
23756	48511	1681	Красноярский край, Назаровский район, поселок Скоробогатово, Центральная, 26	t	small
23763	48518	1688	Красноярский край, Назаровский район, поселок Сереуль, Борисенко, 29 а	t	small
23738	48475	1663	Красноярский край, Назаровский район, поселок Сереж, Клубная, 10	f	small
23758	48513	1683	Красноярский край, Назаровский район, поселок Селедково, Причулымская, 6 Б	t	small
23762	48517	1687	Красноярский край, Назаровский район, поселок Сахапта, Клубная, 17	t	medium
23730	48491	1655	Красноярский край, Назаровский район, поселок Прогресс, Центральная, 12	f	small
23759	48514	1684	Красноярский край, Назаровский район, поселок Преображенский, Комсомольская, 16	f	large
23767	48522	1692	Красноярский край, Назаровский район, поселок Предгорный, Полевая, 9	f	small
23755	48510	1680	Красноярский край, Назаровский район, поселок Подсосное, Школьная, 52Б	t	medium
23038	47742	927	Красноярский край, Назаровский район, поселок Петровка, Щетинкина, 38	t	small
23776	48531	1701	Красноярский край, Назаровский район, поселок Новоалександровка, Школьная, 56 а	f	small
23749	48504	1674	Красноярский край, Назаровский район, поселок Новая Сокса, Просвещения, 1 А	f	small
23722	48483	1647	Красноярский край, Назаровский район, поселок Нижний Ададым, Зеленая, 40 А	f	small
22708	47453	586	Красноярский край, Назаровский район, Назарово, Полиграфистов, 20	f	large
22710	47455	588	Красноярский край, Назаровский район, город Назарово, Ленина, 4А	f	large
22703	47448	581	Красноярский край, Назаровский район, город Назарово, Кузнечная, 6	f	large
22707	47452	585	Красноярский край, Назаровский район, Назарово, Кравченко, д.№2	f	large
22711	47456	589	Красноярский край, Назаровский район, Назарово, Клубная, 10	f	large
22700	47445	578	Красноярский край, Назаровский район, город Назарово, Карла Маркса, 46 А	f	large
22696	47442	574	Красноярский край, Назаровский район, Назарово, К.Маркса, д.№21	f	large
22695	47441	573	Красноярский край, Назаровский район, Назарово, К.Маркса, 17	f	large
22693	47439	571	Красноярский край, Назаровский район, город Назарово, Гуськова, 4	f	large
22709	47454	587	Красноярский край, Назаровский район, Назарово, Вокзальная, 5а	f	large
111169	48970	2192	Красноярский край, Назаровский район, Назарово, Борисенко, 10	f	\N
22704	47449	582	Красноярский край, Назаровский район, Назарово, Арбузова, 62	f	large
22701	47446	579	Красноярский край, Назаровский район, Назарово, Арбузова, 98	f	large
111168	48969	2191	Красноярский край, Назаровский район, город Назарово, 30 лет ВЛКСМ, 84	f	\N
22699	47444	577	Красноярский край, Назаровский район, Назарово, 30 лет ВЛКСМ, 84	f	large
22698	47443	576	Красноярский край, Назаровский район, город Назарово, 30 лет ВЛКСМ, 85А	f	large
22694	47440	572	Красноярский край, Назаровский район, Назарово, 30 лет ВЛКСМ, 95	f	large
23772	48527	1697	Красноярский край, Назаровский район, поселок Московка, Подгорная, 28	f	small
23770	48525	1695	Красноярский край, Назаровский район, поселок Медведовск, Московская, 1А	f	small
23737	48460	1662	Красноярский край, Назаровский район, поселок Лесные Поляны, Школьная, 14А	f	small
23752	48507	1677	Красноярский край, Назаровский район, поселок Куличка, Центральная, 20	f	small
23768	48523	1693	Красноярский край, Назаровский район, поселок Красногорский, Центральная, 3	f	small
23742	48497	1667	Красноярский край, Назаровский район, поселок Красная Сопка, Новая, 14	f	small
23741	48496	1666	Красноярский край, Назаровский район, поселок Красная Сопка, Вокзальная, 1	f	large
23736	48444	1661	Красноярский край, Назаровский район, поселок Красная Поляна, Мира, 33	f	large
23775	48530	1700	Красноярский край, Назаровский район, поселок Кольцово, Верхняя, 36	f	small
23729	48490	1654	Красноярский край, Назаровский район, поселок Кибитень, Центральная, 35	f	small
23746	48501	1671	Красноярский край, Назаровский район, поселок Каргала, Зеленая, 48А	f	small
23765	48520	1690	Красноярский край, Назаровский район, поселок Канаш, Верхняя, 14	t	small
23728	48489	1653	Красноярский край, Назаровский район, поселок Зеленая Горка, Цветочная, 7	f	small
23751	48506	1676	Красноярский край, Назаровский район, поселок Захаринка, Центральная, 18	f	small
23727	48488	1652	Красноярский край, Назаровский район, поселок Зарянка, Центральная, 6	f	small
23773	48528	1698	Красноярский край, Назаровский район, поселок Жгутово, Набережная, 16	f	small
23721	48482	1646	Красноярский край, Назаровский район, поселок Ельник, Комсомольская, 4	f	small
23732	48493	1657	Красноярский край, Назаровский район, поселок Дорохово, Зеленая, 39	f	medium
23733	48494	1658	Красноярский край, Назаровский район, поселок Дорохово, Верхняя, 56	f	medium
23731	48492	1656	Красноярский край, Назаровский район, поселок Голубки, Школьная, 20	f	small
23724	48485	1649	Красноярский край, Назаровский район, поселок Глядень, Элеваторная, 1	f	small
23723	48484	1648	Красноярский край, Назаровский район, поселок Глядень, Новая, 19	f	medium
23743	48498	1668	Красноярский край, Назаровский район, поселок Глядень, Пролетарская, 7А	f	small
23740	48495	1665	Красноярский край, Назаровский район, поселок Владимировка, Новая, 1	f	small
23771	48526	1696	Красноярский край, Назаровский район, поселок Верхняя Березовка, Заречная, 35	f	small
23719	48480	1644	Красноярский край, Назаровский район, поселок Верхний Ададым, Курская, 21А	f	small
23748	48503	1673	Красноярский край, Назаровский район, поселок Большая Сосновка, Школьная, 1А	f	small
23744	48499	1669	Красноярский край, Назаровский район, поселок Березовая Роща, Клубная, 16	f	small
23745	48500	1670	Красноярский край, Назаровский район, поселок Березняки, Дорожная, 25	f	small
23725	48486	1650	Красноярский край, Назаровский район, поселок Антропово, Романова, 21	f	small
23704	48464	1629	Красноярский край, Мотыгинский район, п. Мотыгино, Центральная, 8А	f	large
23703	48463	1628	Красноярский край, Мотыгинский район, п. Мотыгино, Советская, 28	f	large
23718	48479	1643	Красноярский край, Мотыгинский район, поселок Южно-Енисейск, Оборонная, 16	t	medium
23717	48478	1642	Красноярский край, Мотыгинский район, поселок Слюдрудник, Клубная, 2	t	small
23715	48476	1640	Красноярский край, Мотыгинский район, Поселок Раздолинск, Комсомольская, 11	t	large
23713	48473	1638	Красноярский край, Мотыгинский район, поселок Первомайск, Центральная, 7	t	medium
23714	48474	1639	Красноярский край, Мотыгинский район, поселок Партизанск, Центральная, 3	t	medium
23712	48472	1637	Красноярский край, Мотыгинский район, Орджоникидзе, Строителей, 30	t	medium
23710	48470	1635	Красноярский край, Мотыгинский район, поселок Новоангарск, Просвещения, 17, Новоангарский сельсовет	t	small
23711	48471	1636	Красноярский край, Мотыгинский район, поселок Новоангарск, 4 квартал, 8	t	medium
86171	47606	785	Красноярский край, Мотыгинский район, поселок Никольск, Советская, 39	f	small
23705	48465	1630	Красноярский край, Мотыгинский район, поселок Мотыгино, Шоссейная, 50	f	medium
23702	48462	1627	Красноярский край, Мотыгинский район, поселок Мотыгино, Советская, 128	f	medium
23709	48469	1634	Красноярский край, Мотыгинский район, поселок Машуковка, Центральная, 10	t	medium
23708	48468	1633	Красноярский край, Мотыгинский район, Кирсантьево, Новая, 22	t	small
23706	48466	1631	Красноярский край, Мотыгинский район, поселок Бельск, Советская, 11	f	small
23698	48457	1623	Красноярский край, Минусинский район, поселок имени Крупской, Вокзальная, 9а	t	small
23689	48448	1614	Красноярский край, Минусинский район, поселок Шошино, Хвастанцева, 48	f	medium
23701	48461	1626	Красноярский край, Минусинский район, поселок Тигрицкое, Ленина, 48	f	medium
23677	48435	1602	Красноярский край, Минусинский район, поселок Тесь, Мира, 14	f	large
23693	48452	1618	Красноярский край, Минусинский район, поселок Сухое Озеро, Школьная, 7	f	small
23676	48434	1601	Красноярский край, Минусинский район, поселок Суходол, Трактовая, 6	f	small
23688	48447	1613	Красноярский край, Минусинский район, поселок Солдатово, Некрасова, 43	f	small
23680	48438	1605	Красноярский край, Минусинский район, поселок Прихолмье, Зеленая, 19-1	t	medium
23681	48439	1606	Красноярский край, Минусинский район, поселок Притубинский, Комсомольская, 16	f	small
23691	48450	1616	Красноярский край, Минусинский район, поселок Пригородный, Веселая, 4	f	small
23686	48445	1611	Красноярский край, Минусинский район, поселок Опытное Поле, Набережная, 13	f	small
23684	48442	1609	Красноярский край, Минусинский район, поселок Озеро Тагарское, Юбилейная, 16	f	small
23672	48429	1597	Красноярский край, Минусинский район, поселок Новотроицкое, Мира, 2	f	medium
23671	48428	1596	Красноярский край, Минусинский район, поселок Николо-Петровка, Советская, 43Б	f	small
23696	48455	1621	Красноярский край, Минусинский район, поселок Малая Ничка, 1 Мая, 9	t	small
23675	48433	1600	Красноярский край, Минусинский район, поселок Малая Минуса, переулок Центральный, 6	f	large
23679	48437	1604	Красноярский край, Минусинский район, Малая Иня, Чапаева, 42	f	small
23682	48440	1607	Красноярский край, Минусинский район, поселок Лугавское, Ленина, 16	f	large
23683	48441	1608	Красноярский край, Минусинский район, поселок Кутужеково, Ленина, 21	f	small
22256	47172	108	Красноярский край, Минусинский район, поселок Курейка, Октябрьская, 1а	t	small
23594	48348	1516	Красноярский край, Минусинский район, поселок Кочергино, Школьная, 1А	f	medium
23697	48456	1622	Красноярский край, Минусинский район, поселок Коныгино, Боровая, 8	f	small
23700	48459	1625	Красноярский край, Минусинский район, поселок Колмаково, Луговая, 10	f	small
23674	48431	1599	Красноярский край, Минусинский район, поселок Кавказское, Калинина, 37-1	f	medium
23690	48449	1615	Красноярский край, Минусинский район, поселок Знаменка, Пролетарская, 58	f	large
23699	48458	1624	Красноярский край, Минусинский район, поселок Жерлык, Школьная, 2	f	small
23670	48427	1595	Красноярский край, Минусинский район, поселок Городок, Заводская, 5	f	large
40052	36601	1619	Иркутская область, Усть-Кут, Островского, 13	f	medium
23692	48451	1617	Красноярский край, Минусинский район, поселок Восточное, Ленина, 98	f	small
23694	48453	1619	Красноярский край, Минусинский район, поселок Верхняя Коя, Юбилейная, 2	f	small
23673	48430	1598	Красноярский край, Минусинский район, село Быстрая, переулок Молодежный, 2	f	medium
23695	48454	1620	Красноярский край, Минусинский район, поселок Большая Ничка, Автомобильная, 83	f	medium
23678	48436	1603	Красноярский край, Минусинский район, поселок Большая Иня, Ленина, 4	f	medium
23649	48406	1573	Красноярский край, Манский район, поселок Шалинское, Манская, 50	f	large
23650	48407	1574	Красноярский край, Манский район, поселок Шалинское, Ленина, 33	f	large
86195	48404	1571	Красноярский край, Манский район, поселок Тертеж, Юности, 1в	t	small
23103	47815	998	Красноярский край, Манский район, поселок Таежный, Новая, 6в	f	large
23654	48411	1578	Красноярский край, Манский район, поселок Сугристое, Лесная, 2	t	small
86201	48423	1590	Красноярский край, Манский район, поселок Степной Баджей, Партизанская, 1	f	small
86196	48409	1576	Красноярский край, Манский район, поселок Сосновка, Трактовая, 46Б	t	small
23648	48405	1572	Красноярский край, Манский район, поселок Сергеевка, Центральная, 38 А	t	small
86198	48412	1579	Красноярский край, Манский район, поселок Покосное, Зеленая , 2	t	small
23662	48419	1586	Красноярский край, Манский район, поселок Пимия, Центральная, 28	f	small
23641	48398	1565	Красноярский край, Манский район, поселок Первоманск, Крупской, 4	f	large
86200	48420	1587	Красноярский край, Манский район, поселок Орешное, Партизанская, 5	t	small
23643	48400	1567	Красноярский край, Манский район, поселок Новосельск, Железнодорожная, 72, кв.2	t	small
86162	48401	1568	Красноярский край, Манский район, поселок Новоникольск, Центральная, 34а	t	small
86197	48410	1577	Красноярский край, Манский район, поселок Новомихайловка, Здрестова, 20	t	small
23646	48403	1570	Красноярский край, Манский район, поселок Нижняя Есауловка, Школьная, 12	f	medium
23660	48417	1584	Красноярский край, Манский район, поселок Нарва, Кравченко, 45	f	small
23661	48418	1585	Красноярский край, Манский район, поселок Нарва, Заводская, 21	f	medium
23658	48415	1582	Красноярский край, Манский район, поселок Малый Унгут, Манская, 29	t	small
23639	48396	1563	Красноярский край, Манский район, поселок Кускун, Трактовая, 36	t	small
111158	48421	1588	Красноярский край, Манский район, поселок Колбинский, Советская , 2	f	medium
23656	48413	1580	Красноярский край, Манский район, поселок Кияй, Школьная, 2	t	small
86202	48424	1591	Красноярский край, Манский район, поселок Кирза, Чапаева, 28	f	small
24247	49017	2226	Красноярский край, Манский район, поселок Каяк, Сельский дом культуры	t	small
68022	48402	1569	Красноярский край, Манский район, поселок Камарчага, Линейная , 21	f	large
23669	48426	1594	Красноярский край, Манский район, поселок Жайма, Вокзальная, 2, пом.11	t	small
23668	48425	1593	Красноярский край, Манский район, поселок Выезжий Лог, Советская, 31а	f	small
23640	48397	1564	Красноярский край, Манский район, поселок Ветвистый, Мирная, 2	f	small
23651	48408	1575	Красноярский край, Манский район, поселок Верхняя Есауловка, Мира, 33	t	small
23657	48414	1581	Красноярский край, Манский район, поселок Большой Унгут, Юбилейная, 2	t	small
23665	48422	1589	Красноярский край, Манский район, поселок Анастасино, Мира, 5	f	small
22379	47240	243	Красноярский край, Ленинский, Красноярск, Московская, 20а	f	large
22993	47698	876	Красноярский край, Курагинский район, поселок Щетинкино, Школьная, 2	t	small
23638	48395	1560	Красноярский край, Курагинский район, поселок Щетинкино, Кравченко, 7	t	small
23588	48342	1510	Красноярский край, Курагинский район, поселок Шалоболино, Ленина, 38А	t	medium
23637	48394	1559	Красноярский край, Курагинский район, поселок городского типа Чибижек, Заречная, 30	t	small
23629	48387	1551	Красноярский край, Курагинский район, поселок Черемшанка, Октябрьская, 51	t	large
23156	47878	1054	Красноярский край, Курагинский район, поселок Черемшанка, Лесная, 23	f	small
23605	48360	1527	Красноярский край, Курагинский район, поселок Уральская (Грязнуха), Молодежная, 2а	f	small
23627	48385	1549	Красноярский край, Курагинский район, поселок Тюхтят, Центральная, 34, Можарский сельсовет	t	small
23616	48370	1538	Красноярский край, Курагинский район, поселок Тагашет, Трудовая, 31-А	f	small
24116	48868	2058	Красноярский край, Курагинский район, поселок Рощинский, Советская, 8	t	medium
23621	48376	1543	Красноярский край, Курагинский район, поселок Рощинский, Мира, 30, Рощинский сельсовет	f	medium
23611	48365	1533	Красноярский край, Курагинский район, поселок Прудный, Клубная, 1	f	small
23608	48362	1530	Красноярский край, Курагинский район, поселок Поначево, Горка, 37	t	small
23591	48345	1513	Красноярский край, Курагинский район, поселок Пойлово, Мира, 1-Б, Пойловский сельсовет	f	medium
23622	48378	1544	Красноярский край, Курагинский район, поселок Подгорный, Трактовая, 11	f	small
23628	48386	1550	Красноярский край, Курагинский район, поселок Петропавловка, Октябрьская, 7	t	small
23595	48349	1517	Красноярский край, Курагинский район, поселок Ойха, Мира, 6-А	f	small
23587	48341	1509	Красноярский край, Курагинский район, поселок Новопокровка, Школьная, 42-Б	f	small
23636	48393	1558	Красноярский край, Курагинский район, поселок Нижняя Быстрая, Центральная, 44-2	t	small
23592	48346	1514	Красноярский край, Курагинский район, поселок Мурино, Ленина, 14	f	small
23626	48384	1548	Красноярский край, Курагинский район, поселок Можарка, Школьная, 7-А, Можарский сельсовет	t	medium
23609	48363	1531	Красноярский край, Курагинский район, поселок Маринино, Школьная, 2	f	medium
23617	48371	1539	Красноярский край, Курагинский район, поселок Курское, Октябрьская, 48	f	small
23589	48343	1511	Красноярский край, Курагинский район, поселок Курганчики, Комсомольская, 46-А	t	small
23598	48352	1520	Красноярский край, Курагинский район, поселок Курагино, Трактовая, 20	f	large
23597	48351	1519	Красноярский край, Курагинский район, поселок Курагино, Партизанская, 47	f	large
23596	48350	1518	Красноярский край, Курагинский район, поселок Курагино, Партизанская, 8	f	medium
23600	48355	1522	Красноярский край, Курагинский район, поселок Курагино, Новостройка, 15	f	large
23599	48353	1521	Красноярский край, Курагинский район, поселок городского типа Курагино, Партизанская, 154	f	large
23603	48358	1525	Красноярский край, Курагинский район, поселок городского типа Курагино, Новостройка, 1	f	medium
23601	48356	1523	Красноярский край, Курагинский район, поселок городского типа Курагино, Монаенко, 2-Б	f	large
23602	48357	1524	Красноярский край, Курагинский район, поселок городского типа Курагино, Красноярская, 8-А	f	large
23618	48372	1540	Красноярский край, Курагинский район, поселок Красный Кордон, Железнодорожников, 5	f	small
23635	48392	1557	Красноярский край, Курагинский район, поселок городского типа Краснокаменск, Центральная, 8-А	f	large
23634	48392	1556	Красноярский край, Курагинский район, поселок городского типа Краснокаменск, Центральная, 8-А	f	large
23633	48391	1555	Красноярский край, Курагинский район, поселок городского типа Кошурниково, Центральная, 2-Б	f	large
23632	48390	1554	Красноярский край, Курагинский район, поселок городского типа Кошурниково, Невского, 12	f	large
23619	48373	1541	Красноярский край, Курагинский район, поселок Кордово, Наберажная, 32	f	medium
23625	48383	1547	Красноярский край, Курагинский район, поселок Имисское, Береговая, 15-А	t	medium
23590	48344	1512	Красноярский край, Курагинский район, деревня Ильинка, Боровая, 22	t	small
23613	48367	1535	Красноярский край, Курагинский район, поселок Заречный, Верхняя, 4	f	small
23614	48368	1536	Красноярский край, Курагинский район, поселок Загорье, Советская, 1	f	small
23620	48375	1542	Красноярский край, Курагинский район, поселок Журавлёво, Лесная, 8	t	medium
23624	48381	1546	Красноярский край, Курагинский район, поселок Жербатиха, Школьная, 29	f	small
23612	48366	1534	Красноярский край, Курагинский район, поселок Детлово, Ленина, 32	f	small
23623	48380	1545	Красноярский край, Курагинский район, поселок Бугуртак, Береговая, 19	f	small
23615	48369	1537	Красноярский край, Курагинский район, поселок Брагино, Центральная, 75	f	medium
23536	48284	1451	Красноярский край, Курагинский район, поселок городского типа Большая Ирба, Луговая, 4	t	small
23607	48361	1529	Красноярский край, Курагинский район, поселок городского типа Большая Ирба, Ленина, 2-А	f	large
23606	48361	1528	Красноярский край, Курагинский район, поселок городского типа Большая Ирба, Ленина, 2-А	f	large
23313	48052	1218	Красноярский край, Идринский район, поселок Идринское, Мира, 7	f	large
23604	48359	1526	Красноярский край, Курагинский район, поселок Березовское, Ленина, 4	f	medium
23593	48347	1515	Красноярский край, Курагинский район, поселок Белый Яр, Зеленая, 17	f	small
23610	48364	1532	Красноярский край, Курагинский район, поселок Байдово, Мира, 27	f	small
23630	48388	1552	Красноярский край, Курагинский район, город Артёмовск, Ольховская, 124	f	large
23586	48340	1508	Красноярский край, Курагинский район, поселок Алексеевка, Колхозный, 2	f	small
23585	48339	1507	Красноярский край, Краснотуранский район, поселок Уяр, Здание сельского дома культуры	f	small
23584	48338	1506	Красноярский край, Краснотуранский район, поселок Уза, Здание сельского дома культуры	f	small
23583	48337	1505	Красноярский край, Краснотуранский район, поселок Тубинск, Здание сельского дома культуры	t	medium
23582	48336	1504	Красноярский край, Краснотуранский район, поселок Теплый Ключ, здание сельского клуба	t	small
23581	48335	1503	Красноярский край, Краснотуранский район, поселок Саянск, Здание сельского дома культуры	t	medium
23580	48334	1502	Красноярский край, Краснотуранский район, поселок Сарушка, Здание сельского дома культуры	t	small
23579	48333	1501	Красноярский край, Краснотуранский район, поселок Салба, Здание сельского совета	t	small
23578	48332	1500	Красноярский край, Краснотуранский район, поселок Новоивановка, Здание конторы ЗАО Тубинск	t	small
23577	48331	1499	Красноярский край, Краснотуранский район, поселок Новая Сыда, Здание сельского дома культуры	f	small
23576	48330	1498	Красноярский край, Краснотуранский район, поселок Николаевка, Здание сельского дома культуры	f	small
23471	48216	1379	Красноярский край, Краснотуранский район, поселок Николаевка, Центральная, 79	t	small
23295	48033	1200	Красноярский край, Краснотуранский район, поселок Николаевка, Красных Партизан, 28	t	small
23575	48329	1497	Красноярский край, Краснотуранский район, поселок Моисеевка, Здание сельского дома	t	small
23574	48328	1495	Красноярский край, Краснотуранский район, поселок Лебяжье, Здание сельского дома культуры	f	medium
68007	48327	1494	Красноярский край, Краснотуранский район, поселок Краснотуранск, Советская, 20	f	large
23572	48326	1493	Красноярский край, Краснотуранский район, поселок Краснотуранск, Ленина, 39	f	large
68006	48325	1492	Красноярский край, Краснотуранский район, поселок Краснотуранск, Ленина, 20	f	large
23570	48324	1491	Красноярский край, Краснотуранский район, поселок Кортуз, Здание сельского дома культуры	f	medium
23568	48322	1489	Красноярский край, Краснотуранский район, поселок Кара-Беллык, Здание сельского клуба	t	small
23566	48320	1487	Красноярский край, Краснотуранский район, поселок Диссос, Здание сельского клуба	f	small
23567	48321	1488	Красноярский край, Краснотуранский район, поселок Джирим, Здание конторы ЗАО Тубинск	t	small
23565	48319	1486	Красноярский край, Краснотуранский район, поселок Галактионово, Здание сельского дома культуры	t	small
23564	48318	1485	Красноярский край, Краснотуранский район, поселок Восточное	f	medium
23323	48062	1228	Красноярский край, Краснотуранский район, поселок Восточное, Восточная, 1	t	small
23562	48316	1483	Красноярский край, Краснотуранский район, поселок Белоярск, Здание сельского дома культуры	t	small
23446	48191	1353	Красноярский край, Краснотуранский район, поселок Белоярск, переулок Тупиковый, 2	t	small
23563	48317	1484	Красноярский край, Краснотуранский район, поселок Беллык, Здание сельского дома культуры	f	medium
23561	48315	1482	Красноярский край, Краснотуранский район, поселок Александровка, Здание сельского клуба	f	small
23560	48313	1481	Красноярский край, Краснотуранский район, поселок Алгаштык, Здание начальной школы	f	small
23554	48306	1473	Красноярский край, Козульский район, поселок Шадрино, Советский, 7	f	small
23546	48295	1464	Красноярский край, Козульский район, поселок Старая Козулька, Трактовая, 38	t	small
23557	48309	1477	Красноярский край, Козульский район, поселок городского типа Новочернореченский, Советский район, 36	f	large
68005	48310	1478	Красноярский край, Козульский район, поселок городского типа Новочернореченский, Железнодорожная, 12	f	large
23559	48311	1479	Красноярский край, Козульский район, поселок Новочернореченский, Кооперативная, 30	f	large
23556	48308	1476	Красноярский край, Козульский район, поселок Новочернореченский, Деповская, 16	f	small
23553	48305	1472	Красноярский край, Козульский район, поселок Ничково, Школьный переулок, 2	t	small
23545	48294	1463	Красноярский край, Козульский район, поселок Лазурный, Центральная, 7	f	medium
111157	48304	1471	Красноярский край, Козульский район, поселок Красный Яр, Чулымская, 16Б	f	\N
23550	48301	1468	Красноярский край, Козульский район, поселок Косачи, Молодежна, 12	f	small
23541	48290	1459	Красноярский край, Козульский район, поселок городского типа Козулька, Школьная, 6 а	f	medium
23540	48289	1458	Красноярский край, Козульский район, поселок городского типа Козулька, Советская, 76	f	large
23539	48288	1457	Красноярский край, Козульский район, поселок городского типа Козулька, Советская, 60	f	medium
23538	48287	1456	Красноярский край, Козульский район, поселок городского типа Козулька, Советская, 7	f	large
23542	48291	1460	Красноярский край, Козульский район, поселок городского типа Козулька, Свердлова, 47	f	large
23543	48292	1461	Красноярский край, Козульский район, Козулька, 40 лет Победы, 70	f	large
23551	48302	1469	Красноярский край, Козульский район, поселок Заречный, в/ч 63185	t	small
23549	48299	1467	Красноярский край, Козульский район, поселок Жуковка, Школьная, 13	f	medium
111156	48303	1470	Красноярский край, Козульский район, поселок Балахтон, Молодежная, 2а	f	medium
23555	48307	1474	Красноярский край, Козульский район, поселок Аммала, Рабочая, 34-1	t	small
23524	48270	1436	Красноярский край, Кежемский район, п.Таежный, Первомайская	t	small
23537	48286	1452	Красноярский край, Кежемский район, село Яркино, Центральная, 74	f	small
23532	48279	1447	Красноярский край, Кежемский район, деревня Тагара, Первомайский переулок, 4	t	large
23523	48269	1435	Красноярский край, Кежемский район, Недокура, Супругов Самаль, 3	t	medium
23529	48277	1444	Красноярский край, Кежемский район, Кодинск, пр.Ленинского Комсомола, 24	f	large
23528	48276	1443	Красноярский край, Кежемский район, Кодинск, Колесниченко, 6А	f	large
23525	48273	1440	Красноярский край, Кежемский район, Кодинск, Колесниченко, 6	f	large
23533	48280	1448	Красноярский край, Кежемский район, деревня Климино, Ленина, 11	t	small
23535	48283	1450	Красноярский край, Кежемский район, поселок Имба (нежил.), Мира, 8	t	medium
23502	48247	1411	Красноярский край, Каратузский район, поселок Ширыштык, Мира , 33а	f	\N
23503	48248	1412	Красноярский край, Каратузский район, поселок Ширыштык, Мира, 41а	f	\N
23517	48262	1426	Красноярский край, Каратузский район, поселок Шалагино, Центральная, 22	t	\N
23520	48266	1429	Красноярский край, Каратузский район, поселок Чубчиково, Мира, 14А	t	\N
23516	48261	1425	Красноярский край, Каратузский район, поселок Черёмушка, Зеленая , 26б	t	\N
23522	48268	1431	Красноярский край, Каратузский район, поселок Уджей, Советская, 35	f	\N
23515	48260	1424	Красноярский край, Каратузский район, поселок Таяты, Советская, 2	t	\N
23514	48259	1423	Красноярский край, Каратузский район, поселок Таскино, Советская, 50	f	\N
23138	47851	1035	Красноярский край, Каратузский район, поселок Таловка, Советская, 16	f	medium
23518	48264	1427	Красноярский край, Каратузский район, поселок Старомолино, Центральная, 10	t	\N
23513	48258	1422	Красноярский край, Каратузский район, поселок Старая Копь, Советская, 24	f	\N
23509	48254	1418	Красноярский край, Каратузский район, поселок Средний Кужебар (Арсапка), Полтавская, 8	f	\N
23512	48257	1421	Красноярский край, Каратузский район, поселок Сагайское, Советская, 30	f	\N
23508	48253	1417	Красноярский край, Каратузский район, поселок Нижняя Буланка, Колхозная, 19	t	\N
23510	48255	1419	Красноярский край, Каратузский район, поселок Нижний Кужебар, Советская, 55	f	\N
23511	48256	1420	Красноярский край, Каратузский район, поселок Нижние Куряты, Советская, 63	f	\N
23507	48252	1416	Красноярский край, Каратузский район, поселок Моторское, Крупская, 1а	f	\N
23521	48267	1430	Красноярский край, Каратузский район, поселок Лебедёвка, Центральная, 16	t	\N
23506	48251	1415	Красноярский край, Каратузский район, поселок Качулька, Мира, 69а	f	\N
23499	48244	1408	Красноярский край, Каратузский район, поселок Каратузское, Шевченко, 16	f	\N
23500	48245	1409	Красноярский край, Каратузский район, поселок Каратузское, Советская, 21	f	\N
23498	48243	1407	Красноярский край, Каратузский район, поселок Каратузское, Революционная, 23	f	\N
23501	48246	1410	Красноярский край, Каратузский район, поселок Каратузское, Пушкина, 10	f	\N
23519	48265	1428	Красноярский край, Каратузский район, поселок Верхний Суэтук, Партизанская , 1	t	\N
23505	48250	1414	Красноярский край, Каратузский район, поселок Верхний Кужебар, Садовая, 6	t	\N
23504	48249	1413	Красноярский край, Каратузский район, поселок Верхний Кужебар, Ленина, 49	t	\N
23492	48237	1400	Красноярский край, Канский район, поселок Хаерино, Молодежная, 29/1	t	small
23497	48242	1405	Красноярский край, Канский район, поселок Филимоново, Луговая, 9	t	large
23483	48228	1391	Красноярский край, Канский район, поселок Терское, Центральная, 36	f	small
23449	48194	1356	Красноярский край, Канский район, поселок Тарай, Ушакова, 15	f	small
23452	48197	1359	Красноярский край, Канский район, поселок Тайна, Трактовая, 25	t	small
68024	47814	997	Красноярский край, Канский район, поселок Таежное, Новая, 6 В	f	large
23490	48235	1398	Красноярский край, Канский район, поселок Таежное, Ленина, 25	t	medium
23475	48220	1383	Красноярский край, Канский район, поселок Тагаши, Клубный переулок, 1	t	small
23481	48226	1389	Красноярский край, Канский район, поселок Сухая Речка, магазинная, 27	f	small
23456	48201	1363	Красноярский край, Канский район, поселок Степняки, Юбилейная, 1А	f	small
23478	48223	1386	Красноярский край, Канский район, поселок Сотниково, Комсомольская, 34	f	medium
23466	48211	1373	Красноярский край, Канский район, поселок Северо-Александровка, Пионерская, 19	t	small
23474	48219	1382	Красноярский край, Канский район, поселок Рудяное, Новая, 16	t	small
23496	48241	1404	Красноярский край, Канский район, поселок Польное, Лугова, 12	t	small
23482	48227	1390	Красноярский край, Канский район, поселок Петрушки, Соломенная, 2	t	small
23447	48192	1354	Красноярский край, Канский район, поселок Пермяково, Набережная, 36	t	small
23462	48207	1369	Красноярский край, Канский район, поселок Орловка, Новая, 9	t	small
23906	48664	1834	Красноярский край, Канский район, поселок Орешники, Солнечная, 11	t	small
23468	48213	1375	Красноярский край, Канский район, поселок Мокруша, Школьная, 6	t	medium
23460	48205	1367	Красноярский край, Канский район, поселок Малые Пруды, Московская, 12	t	small
23458	48203	1365	Красноярский край, Канский район, поселок Малая Уря, Набережная, 4	t	small
23470	48215	1377	Красноярский край, Канский район, поселок Любава, Центральная, 38	t	small
23453	48198	1360	Красноярский край, Канский район, поселок Леонтьевка, Центральная, 20	t	small
23495	48240	1403	Красноярский край, Канский район, поселок Крутая Горка, Луговая, 2/1	f	small
23477	48222	1385	Красноярский край, Канский район, поселок Круглово, Зеленая, 13	t	small
23484	48229	1392	Красноярский край, Канский район, поселок Красный Маяк, Победы, 64	f	medium
23491	48236	1399	Красноярский край, Канский район, поселок Красный Курыш, Центральная, 31/2	t	small
23463	48208	1370	Красноярский край, Канский район, поселок Зеленая Дубрава, Центральная, 3	f	small
23472	48217	1380	Красноярский край, Канский район, поселок Залесный, Первая, 10	t	small
23895	48653	1823	Красноярский край, Канский район, поселок Загорский, Школьная, 25	f	small
23459	48204	1366	Красноярский край, Канский район, поселок Дорожный, Первомайская, 7	t	small
23363	48105	1268	Красноярский край, Канский район, поселок Гремучая Падь, Центральная, сельский клуб	f	small
23464	48209	1371	Красноярский край, Канский район, поселок Георгиевка, Советская, 37	t	medium
23461	48206	1368	Красноярский край, Канский район, поселок Верх-Амонаш, Центральная, 2В	f	small
23479	48224	1387	Красноярский край, Канский район, поселок Бошняково, Центральная, 13	f	small
23457	48202	1364	Красноярский край, Канский район, поселок Большая Уря, 9 Пятилетки, 7	t	medium
23454	48199	1361	Красноярский край, Канский район, поселок Ашкаул, Кирова, 25	f	small
23451	48196	1358	Красноярский край, Канский район, поселок Астафьевка (Баженово), Пионерская, 14	f	medium
23473	48218	1381	Красноярский край, Канский район, поселок Архангельское (Облава), Центральная, 26А	t	small
23476	48221	1384	Красноярский край, Канский район, поселок Арефьевка, Молодежная, 1	f	small
23469	48214	1376	Красноярский край, Канский район, поселок Алега, Полевая, 46	t	small
23444	48189	1350	Красноярский край, Казачинский район, поселок Челноки, Ленина, 10	f	small
23443	48188	1349	Красноярский край, Казачинский район, поселок Талажанка, Советская, 32	t	small
23442	48187	1348	Красноярский край, Казачинский район, поселок Рождественское, Пушкина, 10А	f	small
23441	48186	1347	Красноярский край, Казачинский район, поселок Пятково, Школьная, 6	f	small
23440	48185	1346	Красноярский край, Казачинский район, поселок Пискуновка, Клубная, 9	f	small
23439	48184	1345	Красноярский край, Казачинский район, поселок Отношка, Школьная, 2А	f	small
23437	48181	1343	Красноярский край, Казачинский район, поселок Момотово, Центральная, 5	f	medium
23436	48180	1342	Красноярский край, Казачинский район, поселок Мокрушинское, Свердлова, 10	f	medium
22905	47609	788	Красноярский край, Казачинский район, поселок Матвеевка, Советская, 17	t	small
23435	48179	1341	Красноярский край, Казачинский район, поселок Матвеевка, Новая, 4	t	small
23433	48177	1339	Красноярский край, Казачинский район, поселок Кемское, Центральная, 30	t	small
24286	48176	2265	Красноярский край, Казачинский район, поселок Казачинское, Советская, 107	f	large
23432	48176	1338	Красноярский край, Казачинский район, поселок Казачинское, Советская, 107	f	large
23431	48174	1337	Красноярский край, Казачинский район, поселок Казанка, Школьная, 2А	f	small
23430	48173	1336	Красноярский край, Казачинский район, поселок Захаровка, Набережная, 30	f	small
23429	48172	1335	Красноярский край, Казачинский район, поселок Дудовка, Буденного, 13	f	small
23428	48171	1334	Красноярский край, Казачинский район, поселок Гамурино, Лесная, 46А	f	small
23427	48170	1333	Красноярский край, Казачинский район, поселок Галанино, Трактовая, 8,А	f	large
23426	48169	1332	Красноярский край, Казачинский район, поселок Вороковка, Советская, 29	f	small
23148	47865	1046	Красноярский край, Казачинский район, поселок Бобровка, Центральная, 43	f	small
111155	48162	1326	Красноярский край, Ирбейский район, поселок Юдино, Колхозная, 27	f	\N
23418	48160	1324	Красноярский край, Ирбейский район, поселок Чухломино, Комсомольская, 1а	f	\N
23411	48153	1317	Красноярский край, Ирбейский район, поселок Хомутово, Комсомольская, 9	t	\N
23413	48155	1319	Красноярский край, Ирбейский район, поселок Усть-Яруль, Строительная, 1а	f	\N
23412	48154	1318	Красноярский край, Ирбейский район, поселок Усть-Каначуль, Молодежная, 12	t	\N
23410	48152	1316	Красноярский край, Ирбейский район, поселок Тумаково, Советская, 2	f	\N
23406	48148	1312	Красноярский край, Ирбейский район, поселок Талое, Рабочая, 2А	f	\N
23400	48142	1306	Красноярский край, Ирбейский район, поселок Стрелка, Набережная, 18а	t	\N
23405	48147	1311	Красноярский край, Ирбейский район, поселок Степановка, Центральная, 18а	t	\N
23401	48143	1307	Красноярский край, Ирбейский район, поселок Сергеевка, Советская, 24	t	\N
23408	48150	1314	Красноярский край, Ирбейский район, поселок Рождественка, Центральная, 3а	t	\N
23415	48157	1321	Красноярский край, Ирбейский район, поселок Преображенка, Мира , 34а	t	\N
23450	48195	1357	Красноярский край, Ирбейский район, поселок Подьянда, Школьная, 21	t	small
23423	48165	1329	Красноярский край, Ирбейский район, поселок Петропавловка-1, Советская, 18	t	\N
23396	48138	1302	Красноярский край, Ирбейский район, поселок Первое Мая, Центральная, 21	f	\N
23404	48146	1310	Красноярский край, Ирбейский район, поселок Новотроицк, здание сельского клуба	t	\N
22987	47694	870	Красноярский край, Ирбейский район, поселок Новотроицк, Новотроицкая, 35	t	small
23403	48145	1309	Красноярский край, Ирбейский район, поселок Новоалександровка, здание сельского клуба	t	\N
23391	48133	1297	Красноярский край, Ирбейский район, поселок Николаевка, пер. Школьный, 4	t	\N
23421	48163	1327	Красноярский край, Ирбейский район, поселок Нагорная, Трактовая, 2а	t	\N
23388	48130	1294	Красноярский край, Ирбейский район, поселок Михайловка, Ленина, 27	t	\N
23386	48128	1292	Красноярский край, Ирбейский район, поселок Минушка, Центральная, 8	t	\N
23399	48141	1305	Красноярский край, Ирбейский район, поселок Мельничное, Школьная, 10	f	\N
23393	48135	1299	Красноярский край, Ирбейский район, поселок Малый Ирбей, Школьная, 11	t	\N
23397	48139	1303	Красноярский край, Ирбейский район, поселок Маловка, Школьная, 17а	f	\N
23419	48161	1325	Красноярский край, Ирбейский район, поселок Латынцево, Советская, 25	f	\N
23398	48140	1304	Красноярский край, Ирбейский район, поселок Коростелево, Солнечная, 36А	t	\N
23414	48156	1320	Красноярский край, Ирбейский район, поселок Каменка, Центральная, 53	f	\N
23394	48136	1300	Красноярский край, Ирбейский район, поселок Ирбейское, Ленина, 55	f	\N
23395	48137	1301	Красноярский край, Ирбейский район, поселок Ирбейское, Интеранциональная, 142	f	\N
23392	48134	1298	Красноярский край, Ирбейский район, поселок Изумрудный, переулок Центральный, 3	f	\N
23860	48618	1787	Красноярский край, Ирбейский район, поселок Ивановка, Суворова, 22	f	small
23037	47741	926	Красноярский край, Ирбейский район, поселок Ивановка, Колхозная, 2	t	small
23389	48131	1295	Красноярский край, Ирбейский район, поселок Елисеевка, 40 Лет Октября, 38	t	\N
23387	48129	1293	Красноярский край, Ирбейский район, поселок Верхняя Уря, 40 Лет Октября, 59	f	\N
23341	48082	1246	Красноярский край, Ирбейский район, поселок Васильевка, Таёжная, 2-2	f	small
23384	48126	1290	Красноярский край, Ирбейский район, поселок Васильевка, Ленина, 23	t	\N
23422	48164	1328	Красноярский край, Ирбейский район, поселок Бычковка, Таежная, 1а	f	\N
23417	48159	1323	Красноярский край, Ирбейский район, поселок Буинка, Центральная, 29	t	\N
23407	48149	1313	Красноярский край, Ирбейский район, поселок Богачёво, Центральная, 27	t	\N
23383	48125	1289	Красноярский край, Ирбейский район, поселок Благовещенка, Трактовая, 9А	f	\N
23409	48151	1315	Красноярский край, Ирбейский район, поселок Берёзовка, Центральная, 18	t	\N
23402	48144	1308	Красноярский край, Ирбейский район, поселок Альгинка, здание МОУ Альгинской основной общеобразовательной школы	t	\N
23382	48124	1288	Красноярский край, Ирбейский район, поселок Александровка, Красноармейский переулок, 2	f	\N
23385	48127	1291	Красноярский край, Ирбейский район, поселок Агул, Центральная, 14	t	\N
24259	49028	2238	Красноярский край, Илимпийский район, поселок Ессей, Центральная, 4	t	small
23355	48096	1260	Красноярский край, Иланский район, поселок Черниговка, Центральная, библиотека-клуб	t	small
23381	48123	1286	Красноярский край, Иланский район, поселок Хайрюзовка, Первомайская, штаб ФГУ ОИУ-3 ОУХД ГУФСИН России	t	small
23375	48117	1280	Красноярский край, Иланский район, поселок Троицк, Центральная, сельский клуб	t	small
22857	47565	737	Красноярский край, Иланский район, поселок Троицк, Нагорная, 27	f	small
23368	48110	1273	Красноярский край, Иланский район, поселок Тарака, Центральная, сельский клуб	t	small
23358	48099	1263	Красноярский край, Иланский район, поселок Степаново, Центральная, сельский Дом культуры	f	small
23360	48102	1265	Красноярский край, Иланский район, поселок Соколовка, Центральная, Администрация сельсовета	f	small
23380	48122	1285	Красноярский край, Иланский район, поселок Росляки, Центральная, начальная общеобразовательная школа	t	small
23378	48120	1283	Красноярский край, Иланский район, поселок Прокопьевка, Центральная, сельская библиотека	t	small
23361	48103	1266	Красноярский край, Иланский район, поселок Новосеменовка Баев, Центральная, сельский клуб	f	small
23364	48106	1269	Красноярский край, Иланский район, поселок Новопокровка, Центральная, Сельский Дом культуры	f	small
23366	48108	1271	Красноярский край, Иланский район, поселок Новоникольск, Центральная, сельский клуб-библиотека	f	small
23149	47868	1047	Красноярский край, Иланский район, Новоникольск, Советская, 50А	f	small
23377	48119	1282	Красноярский край, Иланский район, поселок Новониколаевка, Центральная, сельский Дом культуры	t	large
23753	48508	1678	Красноярский край, Иланский район, поселок Новониколаевка, Тамбовская, 22	f	small
23370	48112	1275	Красноярский край, Иланский район, поселок Новогеоргиевка (Печкина), Центральная, сельский клуб	t	small
23374	48116	1279	Красноярский край, Иланский район, поселок Лобачевка, Центральная, сельский клуб	t	small
23371	48113	1276	Красноярский край, Иланский район, поселок Кучердаевка, Центральная, сельский Дом культуры	f	small
23356	48097	1261	Красноярский край, Иланский район, поселок Курыш-Поповичи, Центральная, сельский клуб	f	small
23359	48101	1264	Красноярский край, Иланский район, поселок Красный Хлебороб, Центральная, здание бригадной конторы	t	small
23369	48111	1274	Красноярский край, Иланский район, поселок Краснинка, Центральная, школа	t	small
23365	48107	1270	Красноярский край, Иланский район, поселок Коха, Центральная, бывшая начальная школа	f	small
23357	48098	1262	Красноярский край, Иланский район, поселок Карапсель, Центральная, Сельский Дом культуры	f	medium
23349	48090	1254	Красноярский край, Иланский район, Иланский, пер. Алгасинский, 7	f	large
23351	48092	1256	Красноярский край, Иланский район, Иланский, Школьная, 17	f	large
23372	48114	1277	Красноярский край, Иланский район, город Иланский, Центральная, администрация сельсовета	t	medium
23350	48091	1255	Красноярский край, Иланский район, Иланский, Трактовая, 108	f	large
23352	48093	1257	Красноярский край, Иланский район, город Иланский, Первомайская, 42в	f	large
24221	48975	2197	Красноярский край, Иланский район, Иланский, Медицинская, 6	f	medium
23348	48089	1253	Красноярский край, Иланский район, город Иланский, Ленина, 56	f	large
23347	48088	1252	Красноярский край, Иланский район, Иланский, Ленина, 1	f	large
23346	48087	1251	Красноярский край, Иланский район, город Иланский, Красная, 53	f	large
23345	48086	1250	Красноярский край, Иланский район, Иланский, Коммунистическая, 91	f	large
23353	48094	1258	Красноярский край, Иланский район, город Иланский, 50 лет Краснохлеборобовской Коммуны, 8	f	medium
23379	48121	1284	Красноярский край, Иланский район, поселок Ельники, Центральная, сельский Дом культуры	t	small
23354	48095	1259	Красноярский край, Иланский район, поселок Далай, Центральная, Сельский Дом культуры	f	small
23376	48118	1281	Красноярский край, Иланский район, поселок Гавриловка, Центральная, сельская библиотека-клуб	f	small
23373	48115	1278	Красноярский край, Иланский район, поселок Верх-Атины, Центральная, сельский клуб	t	small
23455	48200	1362	Красноярский край, Иланский район, поселок Бражное, Коростелева, 19	f	large
23362	48104	1267	Красноярский край, Иланский район, поселок Богдановка, Центральная, сельский клуб	f	small
23448	48193	1355	Красноярский край, Иланский район, поселок Амонаш, Школьная, 4	f	small
23317	48056	1222	Красноярский край, Идринский район, поселок Центральный, Советская, 4	f	small
23325	48064	1230	Красноярский край, Идринский район, поселок Средняя Салба, Рабочий, 6	t	small
86150	48566	1733	Красноярский край, Идринский район, поселок Романовка, Таежная, 42	t	small
23334	48073	1239	Красноярский край, Идринский район, поселок Романовка, Молодежная, 21-2	t	small
23316	48055	1221	Красноярский край, Идринский район, Поселок Сибирь, Краснокаменная, 5	f	small
23320	48059	1225	Красноярский край, Идринский район, поселок Отрок, Школьная, 9	t	small
23333	48072	1238	Красноярский край, Идринский район, поселок Октябрьский, Центральная , 18	t	small
23343	48084	1248	Красноярский край, Идринский район, поселок Новотроицкое, Октябрьская, 44	t	small
23337	48078	1242	Красноярский край, Идринский район, поселок Новоберёзовка, Ленина, 70	f	small
23340	48081	1245	Красноярский край, Идринский район, поселок Никольское, Ленина, 86	f	small
23339	48080	1244	Красноярский край, Идринский район, поселок Мензот, Громовой, 39	t	small
23330	48069	1235	Красноярский край, Идринский район, поселок Малый Хабык, Мира, 69	f	small
23328	48067	1233	Красноярский край, Идринский район, поселок Майское Утро, Молодежная, 22	f	small
23332	48071	1237	Красноярский край, Идринский район, поселок Майский, Центральная, 5	t	small
23327	48066	1232	Красноярский край, Идринский район, поселок Куреж, Зеленая, 38	f	small
23336	48076	1241	Красноярский край, Идринский район, поселок Королевка, Заречная, 6	f	small
23321	48060	1226	Красноярский край, Идринский район, поселок Козино, Хохлатская, 23	t	small
23569	48323	1490	Красноярский край, Идринский район, поселок Кедровая, Здание сельского клуба	t	small
24271	49040	2250	Красноярский край, Идринский район, поселок Кедровая, Кедровая, 2	t	small
23863	48621	1790	Красноярский край, Идринский район, поселок Иннокентьевка, Красных Партизан, 38	f	small
23335	48075	1240	Красноярский край, Идринский район, поселок Иннокентьевка, Зеленая, 21	f	small
23315	48054	1220	Красноярский край, Идринский район, поселок Идринское, Титова, 30	f	medium
23314	48053	1219	Красноярский край, Идринский район, поселок Идринское, Октябрьская, 178	f	large
23344	48085	1249	Красноярский край, Идринский район, поселок Зезезино, Таёжная, 1	t	small
23342	48083	1247	Красноярский край, Идринский район, поселок Еленинск, Ленина, 33	f	small
23338	48079	1243	Красноярский край, Идринский район, поселок Екатериновка, Ленина, 17	f	small
23331	48070	1236	Красноярский край, Идринский район, поселок Добромысловский, Храпова, 2	t	small
23329	48068	1234	Красноярский край, Идринский район, поселок Большой Хабык, Ленина, 1	f	small
23326	48065	1231	Красноярский край, Идринский район, поселок Большой Телек, Советская, 47	f	small
23322	48061	1227	Красноярский край, Идринский район, поселок Большие Кныши, Байкалова, 17	t	small
23324	48063	1229	Красноярский край, Идринский район, поселок Большая Салба, Советская, 24	f	small
23318	48057	1223	Красноярский край, Идринский район, поселок Большая Идра, Советская, 25	f	small
86161	48058	1224	Красноярский край, Идринский район, поселок Адриха, Адрихинская , 38, здание сельского клуба	f	small
23304	48040	1209	Красноярский край, Ермаковский район, поселок Танзыбей, Мира, 32	t	large
23312	48051	1217	Красноярский край, Ермаковский район, поселок Семенниково, Трактовая, 38	f	medium
23300	48036	1205	Красноярский край, Ермаковский район, поселок Салба, Центральная, 18	f	small
23310	48049	1215	Красноярский край, Ермаковский район, поселок Разъезжее, Саянская, 55	f	medium
23294	48032	1199	Красноярский край, Ермаковский район, поселок Песочный, Центральная, 3а	t	small
23299	48035	1204	Красноярский край, Ермаковский район, поселок Ойский, Мира, 37	f	medium
23302	48038	1207	Красноярский край, Ермаковский район, поселок Новополтавка, Комсомольская, 24	f	medium
23296	48034	1201	Красноярский край, Ермаковский район, поселок Новоозерный, Центральная , 10	t	small
23308	48047	1213	Красноярский край, Ермаковский район, поселок Нижнеусинское, Кравченко, 38	f	small
23301	48037	1206	Красноярский край, Ермаковский район, поселок Нижнесуэтук, Ленина, 2	f	medium
23309	48048	1214	Красноярский край, Ермаковский район, поселок Мигна, Щетинкина, 48	f	medium
23298	47917	1203	Красноярский край, Ермаковский район, поселок Ивановка, Ленина, 8б	t	small
111153	48031	1198	Красноярский край, Ермаковский район, поселок Ермаковское, площадь Победы, 8	f	medium
23287	48025	1192	Красноярский край, Ермаковский район, поселок Ермаковское, Щетинкина, 11	f	medium
23305	48041	1210	Красноярский край, Ермаковский район, поселок Ермаковское, Трактовая, 42	f	medium
23290	48028	1195	Красноярский край, Ермаковский район, поселок Ермаковское, Старковых, 19	f	large
23291	48029	1196	Красноярский край, Ермаковский район, поселок Ермаковское, Российская, 42	f	large
23289	48027	1194	Красноярский край, Ермаковский район, поселок Ермаковское, Октябрьская, 53	f	medium
23286	48024	1191	Красноярский край, Ермаковский район, поселок Ермаковское, Мостовая, 5а	f	small
23288	48026	1193	Красноярский край, Ермаковский район, поселок Ермаковское, Ленина, 80	f	medium
23292	48030	1197	Красноярский край, Ермаковский район, поселок Ермаковское, 60 лет ВЛКСМ, 23	f	medium
23303	48039	1208	Красноярский край, Ермаковский район, поселок Григорьевка, Трактовая, 1	t	medium
23307	48044	1212	Красноярский край, Ермаковский район, поселок Верхнеусинское, Ленина, 119	f	medium
23311	48050	1216	Красноярский край, Ермаковский район, поселок Большая Речка, Ленина, 37	f	small
23306	48043	1211	Красноярский край, Ермаковский район, поселок Арадан, Нагорная, 1	f	small
23279	48017	1184	Красноярский край, Енисейский район, с.Ярцево, Матросова, 40а	f	large
23256	47992	1161	Красноярский край, Енисейский район, п.Новокаргино, Набережная, 8	t	large
23283	48022	1188	Красноярский край, Енисейский район, п. Александровский Шлюз, Лесная, 20	t	small
23274	48012	1179	Красноярский край, Енисейский район, д.Назимово, Ермака, 47	t	small
23265	48003	1170	Красноярский край, Енисейский район, д.Малобелая, 70 лет Октября, 19	t	small
23275	48013	1180	Красноярский край, Енисейский район, д.Колмогорово, Набережная, 8	t	small
23272	48010	1177	Красноярский край, Енисейский район, поселок Шишмарево, Школьная, 3	t	small
23254	47989	1159	Красноярский край, Енисейский район, поселок Шапкино, Центральная, 26	f	small
23255	47991	1160	Красноярский край, Енисейский район, поселок Шапкино, Мира, 16Б	t	small
40071	36620	1638	Иркутская область, Усть-Кут, Нефтяников, 27	f	large
23267	48005	1172	Красноярский край, Енисейский район, Чалбышево, Рождественского, 38	t	small
23258	47994	1163	Красноярский край, Енисейский район, деревня Усть-Тунгуска, Центральная, 32	t	small
23271	48009	1176	Красноярский край, Енисейский район, село Усть-Пит, Молодежная, 1	f	small
23268	48006	1173	Красноярский край, Енисейский район, поселок Усть-Кемь, Калинина, 5	f	large
86160	48023	1189	Красноярский край, Енисейский район, Село Сым, Набережная, 13	t	small
23251	47986	1156	Красноярский край, Енисейский район, Потапово, Административная, 2	f	medium
23248	47982	1153	Красноярский край, Енисейский район, поселок Подтесово, Талалихина, 8	f	large
24304	49066	2283	Красноярский край, Енисейский район, поселок Подтесово, Калинина, 6	f	large
23263	48001	1168	Красноярский край, Енисейский район, село Озерное, Ленинградская, 50	f	large
23276	48015	1181	Красноярский край, Енисейский район, Новый Городок, Восточная, 1	f	small
23273	48011	1178	Красноярский край, Енисейский район, поселок Новоназимово, Центральная, 50	t	medium
23277	48016	1182	Красноярский край, Енисейский район, село Маковское, Пролетарская, 31	t	small
23280	48019	1185	Красноярский край, Енисейский район, поселок Майское, Школьная, 12А	t	small
23281	48020	1186	Красноярский край, Енисейский район, поселок Кривляк, Рабочая, 3	t	medium
86159	48021	1187	Красноярский край, Енисейский район, Деревня Безымянка, Свободная, 1	t	small
23252	47987	1157	Красноярский край, Енисейский район, село Городище, 70 лет Октября, 26	t	small
23253	47988	1158	Красноярский край, Енисейский район, Высокогорский, Набережная, 7	f	medium
23262	47998	1167	Красноярский край, Енисейский район, Байкал, Набережная, 6	t	small
23270	48008	1175	Красноярский край, Енисейский район, деревня Анциферово, Лесная, 2	t	small
23278	47950	1183	Красноярский край, Енисейский район, Айдара, Лесная, 1	t	small
23217	47949	1119	Красноярский край, Емельяновский район, поселок Элита, Заводская, 19	f	large
23223	47956	1126	Красноярский край, Емельяновский район, село Шуваево, Просвещения, 3	f	medium
23232	47965	1135	Красноярский край, Емельяновский район, село Частоостровское, Советская, 56	t	large
23237	47971	1140	Красноярский край, Емельяновский район, село Устюг, Трактовая, 10	f	medium
23242	47976	1145	Красноярский край, Емельяновский район, Талое, Центральная, 13	t	medium
23221	47954	1123	Красноярский край, Емельяновский район, поселок Солонцы, Новостроек, 10	t	large
23233	47966	1136	Красноярский край, Емельяновский район, Серебряково, Центральная, 19	t	small
23246	47980	1149	Красноярский край, Емельяновский район, деревня Раскаты, Лесная, 1	t	small
23239	47973	1142	Красноярский край, Емельяновский район, деревня Плоское, Центральная, 15 А	f	small
23207	47936	1109	Красноярский край, Емельяновский район, поселок Памяти 13 Борцов, Кульутры, 8А	f	medium
23247	47981	1150	Красноярский край, Емельяновский район, село Никольское, Советская, 75 А	t	large
23547	48296	1465	Россия, Красноярский край, Емельяновский район, поселок Можарский	t	small
23220	47953	1122	Красноярский край, Емельяновский район, поселок Минино, Юбилейная, 26	t	medium
23241	47975	1144	Красноярский край, Емельяновский район, поселок Медведа, Центральная, 22	t	small
86158	47939	1112	Красноярский край, Емельяновский район, Малый Кемчуг, 60 лет СССР, 5	t	small
23234	47968	1137	Красноярский край, Емельяновский район, деревня Кубеково, Центральная, 2 А	t	small
23216	47948	1118	Красноярский край, Емельяновский район, поселок Кача, Вокзальная, 10	t	small
23215	47946	1117	Красноярский край, Емельяновский район, поселок Зеледеево, Центральная, 73	f	small
23225	47958	1128	Красноярский край, Емельяновский район, деревня Замятино, Новая, 6	t	small
23205	47934	1107	Красноярский край, Емельяновский район, поселок Емельяново, 4, Аэропорт	f	medium
23203	47932	1105	Красноярский край, Емельяновский район, поселок Емельяново, Рабочая, 5	f	small
23211	47940	1113	Красноярский край, Емельяновский район, деревня Еловая, Гурского, 16	t	large
23240	47974	1143	Красноярский край, Емельяновский район, село Гляден, Центральная, 41А	t	small
23243	47977	1146	Красноярский край, Емельяновский район, поселок Гаревое, Центральная, 6	t	small
24024	48777	1960	Красноярский край, Емельяновский район, поселок Бахта, Школьная, 5	t	small
23089	47772	984	Красноярский край, Богучанский район, п. Ангарский, Ленина, 18	f	large
23236	47970	1139	Красноярский край, Емельяновский район, деревня Барабаново, Горная, 10	t	small
23218	47951	1120	Красноярский край, Емельяновский район, село Арейское, Солнечная, 3	t	medium
23224	47957	1127	Красноярский край, Емельяновский район, поселок Арей, Центральная, 9А	f	small
86142	48554	1722	Красноярский край, Емельяновский район, поселок Алексеевка, Первомайская, 7а	t	small
23209	47938	1111	Красноярский край, Емельяновский, деревня Таскино, Школьная, 21	t	medium
111244	49000	2213	Красноярский край, Диксонский район, п. Хант. Оз., сельский Дом культуры	f	\N
111243	48998	2212	Красноярский край, Диксонский район, п. Потапово, сельский Дом культуры	f	\N
23190	47919	1092	Красноярский край, Дзержинский район, поселок Шеломки, Центральная, 15	t	medium
23173	47900	1071	Красноярский край, Дзержинский район, поселок Чурюково, Центральная, 30	t	small
23185	47913	1086	Красноярский край, Дзержинский район, Чемурай, Центральная, 4	t	small
23169	47895	1067	Красноярский край, Дзержинский район, поселок Усолка, Центральная , 1	f	small
23175	47902	1074	Красноярский край, Дзержинский район, поселок Улюколь, Центральная, 50	t	small
23188	47916	1089	Красноярский край, Дзержинский район, поселок Топол, Центральная, 46	t	small
23182	47909	1081	Красноярский край, Дзержинский район, поселок Таловая, Кедровая, 30	t	small
22963	47670	846	Красноярский край, Дзержинский район, поселок Таловая, Дружбы, 14	f	small
23465	48210	1372	Красноярский край, Дзержинский район, поселок Сухо-Ерша, Зеленая, 37	t	small
23183	47910	1082	Красноярский край, Дзержинский район, поселок Семеновка, Школьная, 40	t	small
23180	47907	1079	Красноярский край, Дзержинский район, поселок Плитная, Чулпан, 26	f	small
23179	47906	1078	Красноярский край, Дзержинский район, поселок Петровка (Алатка), Центральная, 15	f	small
23184	47911	1083	Красноярский край, Дзержинский район, поселок Орловка, Центральная, 43	f	small
23176	47903	1075	Красноярский край, Дзержинский район, поселок Новый, улица Школьная, 7	t	small
23171	47898	1069	Красноярский край, Дзержинский район, поселок Николаевка, Центральная, 52	t	small
23181	47908	1080	Красноярский край, Дзержинский район, поселок Нижний Танай, Набережная, 4	f	small
23174	47901	1073	Красноярский край, Дзержинский район, поселок Михайловка, Центральная, 58	f	small
23194	47923	1096	Красноярский край, Дзержинский район, поселок Макарово, Центральная, 30	t	small
23177	47904	1076	Красноярский край, Дзержинский район, поселок Курай, Новая, 1	f	medium
23189	47918	1091	Красноярский край, Дзержинский район, поселок Кондратьево, Центральная, 29	t	small
23187	47915	1088	Красноярский край, Дзержинский район, поселок Колон, Центральная, 15	t	small
23168	47893	1066	Красноярский край, Дзержинский район, поселок Кедровка, Центральная, 20	f	small
23191	47920	1093	Красноярский край, Дзержинский район, поселок Канарай, Школьная, 2	t	small
23167	47892	1065	Красноярский край, Дзержинский район, поселок Дзержинское, переулок Южный, 7	f	medium
23163	47888	1061	Красноярский край, Дзержинский район, поселок Дзержинское, Советская, 14	f	medium
23165	47890	1063	Красноярский край, Дзержинский район, поселок Дзержинское, Ракуса, 87	f	medium
23162	47887	1060	Красноярский край, Дзержинский район, поселок Дзержинское, Новый переулок, 1 а	f	medium
23166	47891	1064	Красноярский край, Дзержинский район, поселок Дзержинское, Кирова, 164	f	large
23161	47886	1059	Красноярский край, Дзержинский район, поселок Дзержинское, Кирова, 20	f	medium
23160	47885	1058	Красноярский край, Дзержинский район, поселок Дзержинское, Денисовская, 66	f	medium
23164	47889	1062	Красноярский край, Дзержинский район, поселок Дзержинское, Больничная, 7	f	small
23186	47914	1087	Красноярский край, Дзержинский район, поселок Денисово, Лесная, 5	f	medium
23172	47899	1070	Красноярский край, Дзержинский район, поселок Вознесенка, Центральная, 21	t	small
22912	47616	795	Красноярский край, Дзержинский район, поселок Борки, Лесная, 24	f	small
23193	47922	1095	Красноярский край, Дзержинский район, поселок Большая Степь, Калинина, 9	t	small
23192	47921	1094	Красноярский край, Дзержинский район, поселок Батов, Кайтымская, 35	t	small
23178	47905	1077	Красноярский край, Дзержинский район, поселок Ашпатск, Центральная, 74	f	small
43444	41574	1679	Кемеровская область, Яя, Жуковского, 17	f	medium
23170	47897	1068	Красноярский край, Дзержинский район, поселок Александро-Ерша, Центральная, 66	f	small
23154	47875	1052	Красноярский край, Большеулуйский район, поселок Удачное, Советская, 22	f	small
24289	49057	2268	Красноярский край, Большеулуйский район, поселок Турецк, Колхозная, 22-А	t	small
23147	47864	1045	Красноярский край, Большеулуйский район, поселок Таежка, Центральная , 15	f	small
23153	47874	1051	Красноярский край, Большеулуйский район, поселок Сучково, Советская, 58	f	small
22856	47563	736	Красноярский край, Большеулуйский район, село Сосновый Бор, поселок Подгорный, Боровая, 2Б	f	small
23152	47873	1050	Красноярский край, Большеулуйский район, поселок Симоново, Мира, 35	t	small
23151	47872	1049	Красноярский край, Большеулуйский район, поселок Новая-Еловка, Советская, 50-Б	f	medium
23146	47861	1044	Красноярский край, Большеулуйский район, поселок Кытат, Таежная, 15	f	small
23155	47877	1053	Красноярский край, Большеулуйский район, поселок Карабановка, Лесная, 19-А	t	small
23145	47860	1043	Красноярский край, Большеулуйский район, поселок Елга, Дружбы, 3	f	small
23157	47881	1055	Красноярский край, Большеулуйский район, поселок Бычки, Центральная, 46	f	small
23143	47856	1041	Красноярский край, Большеулуйский район, поселок Большой Улуй, Советская, 123	f	large
23159	47884	1057	Красноярский край, Большеулуйский район, поселок Большой Улуй, Медицинская, 1	f	medium
23425	48167	1331	Красноярский край, Большеулуйский район, поселок Бобровка, Трактовая, 35 А	f	small
23134	47847	1031	Красноярский край, Большемуртинский район, поселок Язаевка, Набережная, 11	t	small
86213	47853	1038	Красноярский край, Большемуртинский район, поселок Юксеево, Центральная, 27	t	small
23122	47835	1018	Красноярский край, Большемуртинский район, поселок Тигино, пер.Садовый, 11	f	small
86212	47848	1032	Красноярский край, Большемуртинский район, поселок Российка, Заречная, 61	t	small
23131	47844	1028	Красноярский край, Большемуртинский район, поселок Раздольное, Центральная, 43	f	small
68026	47831	1014	Красноярский край, Большемуртинский район, поселок городского типа Предивинск, Луговая, 11	t	large
23141	47854	1039	Красноярский край, Большемуртинский район, поселок Пакуль, Лесная, 13	f	small
23139	47852	1036	Красноярский край, Большемуртинский район, поселок Муратово, Дачная, 1	t	small
86210	47843	1027	Красноярский край, Большемуртинский район, поселок Мостовское, Чуева , 27	t	small
23137	47850	1034	Красноярский край, Большемуртинский район, поселок Минск, Нагорная, 27/1	t	small
23120	47833	1016	Красноярский край, Большемуртинский район, поселок Малый Кантат, Новая, 24	f	small
86211	47846	1030	Красноярский край, Большемуртинский район, поселок Луговское, Центральная, 23/1	f	small
23127	47840	1023	Красноярский край, Большемуртинский район, поселок Красные Ключи, Советская, 26А	t	small
23480	48225	1388	Красноярский край, Большемуртинский район, поселок Комарово, Школьная, 13	f	small
23142	47855	1040	Красноярский край, Большемуртинский район, поселок Комарово, Центральная, 24	f	small
23124	47837	1020	Красноярский край, Большемуртинский район, поселок Казанка, Кооперативная, 30А	t	small
22971	47678	854	Россия, Тюменская область, Викуловский район, село Еловка	f	small
23125	47838	1021	Красноярский край, Большемуртинский район, поселок Еловка, Центральная, 1 А	f	small
23123	47836	1019	Красноярский край, Большемуртинский район, поселок Верх-Казанка, Солнечная, 17	t	small
23136	47849	1033	Красноярский край, Большемуртинский район, поселок Большой Кантат, Верхняя, 1	f	small
23116	47829	1012	Красноярский край, Большемуртинский район, поселок городского типа Большая Мурта, пер.Центральный, 10	f	large
23117	47830	1013	Красноярский край, Большемуртинский район, поселок Большая Мурта, Советская, 167 а	f	large
23115	47828	1011	Красноярский край, Большемуртинский район, поселок Большая Мурта, Кооперативная, 15	f	large
111151	47834	1017	Красноярский край, Большемуртинский район, поселок Бартат, Центральная , 40	f	medium
23119	47832	1015	Красноярский край, Большемуртинский район, поселок Айтат, Новая, 1	f	small
23113	47826	1008	Красноярский край, Богучанский район, п. Хребтовый, Киевская, 9 Б	f	medium
23086	47800	981	Красноярский край, Богучанский район, п. Беляки, Школьная, 22	t	small
23090	40073	985	Красноярский край, Богучанский район, деревня Ярки, Ленина, 9	t	small
23098	47810	993	Красноярский край, Богучанский район, поселок Шиверский, Центральный переулок, 10	t	medium
23108	47820	1003	Красноярский край, Богучанский район, поселок Чунояр, Партизанская, 33	f	large
23110	47823	1005	Красноярский край, Богучанский район, поселок Токучет, 50 лет Октября, 37 А	t	medium
23091	47803	986	Красноярский край, Богучанский район, Село Богучаны, Октябрьская, 63	f	large
23114	47827	1009	Красноярский край, Богучанский район, поселок Прилуки, здание школы	t	small
23087	47801	982	Красноярский край, Богучанский район, поселок Пинчуга, Ленина, 67	t	small
23109	94448	1004	Красноярский край, Богучанский район, поселок Осиновый Мыс, Советская, 46	f	large
23106	47818	1001	Красноярский край, Богучанский район, поселок Октябрьский, Победы, 19	f	large
23105	47817	1000	Красноярский край, Богучанский район, поселок Новохайский, Школьная, 8	t	medium
23081	47795	976	Красноярский край, Богучанский район, поселок Нижнетерянск, Октябрьская, 8	t	small
23107	47819	1002	Красноярский край, Богучанский район, поселок Малеево, Центральная, 3А	t	small
23104	47816	999	Красноярский край, Богучанский район, поселок Кежек, Черемушки, 12	t	small
23101	47813	996	Красноярский край, Богучанский район, Карабула, Центральная, 10	f	small
23084	47798	979	Красноярский край, Богучанский район, деревня Иркинеево, Октябрьская, 26	f	small
23085	47799	980	Красноярский край, Богучанский район, деревня Бедоба, Ленина, 8	t	small
23083	47797	978	Красноярский край, Богучанский район, поселок Артюгино, Юбилейная, 25	t	medium
86183	47775	956	Красноярский край, Боготольский район, д.Коробейниково, Школьная, 33	t	small
111150	47790	967	Красноярский край, Боготольский район, поселок Юрьевка, Центральная, 88, Юрьевский сельсовет	f	medium
86189	47785	964	Красноярский край, Боготольский район, поселок Шулдат, 50 лет Октября, 39	t	small
23072	47783	963	Красноярский край, Боготольский район, поселок Чайковский, помещение сельского Дома культуры	f	small
86178	47767	949	Красноярский край, Боготольский район, Село Медяково, Советская, 2	t	small
86186	47780	961	Красноярский край, Боготольский район, поселок Разгуляевка, Центральная, 62	t	small
86177	47766	948	Красноярский край, Боготольский район, поселок Орга, Мира , 33	t	small
86180	47770	952	Красноярский край, Боготольский район, поселок Малая Косуль, Береговая, 7	t	small
86194	47793	970	Красноярский край, Боготольский район, поселок Лебедевка, Верхняя, 17	t	small
111149	47778	959	Красноярский край, Боготольский район, поселок Критово, Переездная, 1, Критовский сельсовет	f	medium
111148	47776	957	Красноярский край, Боготольский район, поселок Красный Завод, Центральная, 7, Краснозаводский сельсовет	f	medium
86184	47777	958	Красноярский край, Боготольский район, поселок Красная Речка, Трактовая, 89, Краснозаводский сельсовет	f	small
86179	47769	951	Красноярский край, Боготольский район, поселок Каштан, Буркова, 7	t	small
23760	48515	1685	Красноярский край, Боготольский район, поселок Ильинка, Школьная, 4 А	f	small
86181	47773	954	Красноярский край, Боготольский район, поселок Ильинка, Пахомова, 41	t	small
86182	47774	955	Красноярский край, Боготольский район, поселок Дмитриевка, Октябрьская, 53, Вагинский сельсовет	t	small
86185	47779	960	Красноярский край, Боготольский район, поселок Гнетово, Центральная , 10	t	small
86193	47792	969	Красноярский край, Боготольский район, поселок Георгиевка, Центральная, 16	t	small
86176	47765	947	Красноярский край, Боготольский район, поселок Владимировка, Школьная, 1а	f	small
86191	47789	966	Красноярский край, Боготольский район, поселок Вишняково-Катеюл, Центральная, 7	t	small
86187	47781	962	Красноярский край, Боготольский район, поселок Вагино, Северная, 13	t	small
111147	47771	953	Красноярский край, Боготольский район, поселок Вагино, Кооперативная, 5	f	medium
23074	47788	965	Красноярский край, Боготольский район, поселок Булатово, помещение школы	f	small
111146	47768	950	Красноярский край, Боготольский район, поселок Большая Косуль, 101	f	medium
22208	47128	59	Красноярский край, Боготольский район, Боготол, Школьная, 75А	f	\N
111141	47114	45	Красноярский край, Боготольский район, Боготол, Совхозная, 24	f	\N
42383	40367	644	Кемеровская область, Новокузнецк, Левитана, 1	t	large
68021	47764	946	Красноярский край, Боготольский район, город Боготол, Советская , 11	f	large
24306	49067	2285	Красноярский край, Боготольский район, Боготол, Советская, 63	f	\N
22210	47125	61	Красноярский край, Боготольский район, Боготол, Сибирская, 34б	f	\N
22205	47125	56	Красноярский край, Боготольский район, Боготол, Сибирская, 34б	f	\N
22198	47118	49	Красноярский край, Боготольский район, город Боготол, Кирова , 18	f	\N
22207	47127	58	Красноярский край, Боготольский район, Боготол, Кирова, 78	f	\N
22206	47126	57	Красноярский край, Боготольский район, город Боготол, 40 лет Октября, 33	f	\N
22200	47120	51	Красноярский край, Боготольский район, город Боготол, 1-я Зарельсовая, 48	f	\N
24305	47120	2284	Красноярский край, Боготольский район, город Боготол, 1-я Зарельсовая, 48	f	\N
86192	47791	968	Красноярский край, Боготольский район, поселок Берёзовка, Ленинская, 8	t	small
23054	47763	945	Красноярский край, Боготольский район, поселок Александровка, Дом культуры	f	small
22196	47116	47	Красноярский край, Боготолькский район, город Боготол, Куйбышева, 43	f	\N
22192	47112	43	Красноярский край, Боготолькский район, город Боготол, Деповская, 17	f	\N
22204	47124	55	Красноярский край, Боготолькский район, Боготол, Промышленная, 6а	f	\N
23045	47752	936	Красноярский край, Бирилюсский район, поселок Шпагино-1, Центральная, 7	f	small
23039	47744	928	Красноярский край, Бирилюсский район, поселок Сурикова, Строительная, 21	f	medium
23031	47734	920	Красноярский край, Бирилюсский район, поселок Старая Еловка, Школьная, 1	t	small
23049	39886	940	Красноярский край, Бирилюсский район, поселок Сопка, Новая, 1	t	small
86172	47738	924	Красноярский край, Бирилюсский район, поселок Сахарное, Профсоюзная, 45	t	small
23040	47745	930	Красноярский край, Бирилюсский район, поселок городского типа Рассвет, Комсомольская, 15	f	large
23047	47755	938	Красноярский край, Бирилюсский район, поселок Промбор, Центральная, 13	t	small
23046	47754	937	Красноярский край, Бирилюсский район, поселок Полевое, Центральная, 3	t	small
23030	47733	919	Красноярский край, Бирилюсский район, поселок Новобирилюссы, Советская, 130	f	large
23029	47732	918	Красноярский край, Бирилюсский район, поселок Новобирилюссы, Советская, 151	f	large
23050	47757	941	Красноярский край, Бирилюсский район, поселок Нижний Тунуй, Новая, 23	t	small
23052	47759	943	Красноярский край, Бирилюсский район, поселок Муслинка, Центральная, 32	t	small
23042	47748	933	Красноярский край, Бирилюсский район, поселок Мендельский, Центральная, 12	t	small
23044	47750	935	Красноярский край, Бирилюсский район, поселок Маталассы, Школьная, 10	f	small
23043	47749	934	Красноярский край, Бирилюсский район, поселок Малая Кеть, Почтовая, 7	t	small
23051	47758	942	Красноярский край, Бирилюсский район, поселок Кирчиж, Советская, 9	t	small
23041	47747	931	Красноярский край, Бирилюсский район, поселок Кемчуг, Береговая, 3	t	small
23034	47737	923	Красноярский край, Бирилюсский район, поселок Зачулымка, Новая, 10	t	small
86173	47736	922	Красноярский край, Бирилюсский район, поселок Дорохта, Центральная, 2	t	small
24023	48776	1957	Красноярский край, Бирилюсский район, поселок Бор, Кирова, 78а, дом культуры	f	large
24022	48774	1956	Красноярский край, Бирилюсский район, поселок Бор, 60 лет Аэрофлота, 7	f	small
86174	47760	944	Красноярский край, Бирилюсский район, поселок Биктимировка, Зеленая, 31	t	small
23032	47735	921	Красноярский край, Бирилюсский район, поселок Арефьево, Школьная, 1	f	small
23424	48166	1330	Красноярский край, Бирилюсский район, поселок Александровка, Центральная, 23	t	small
23027	47729	915	Красноярский край, Березовский район, поселок Урман, Молодежная, 7	f	small
22849	47556	729	Красноярский край, Березовский район, поселок Тартат, 40 лет Октября, 6	f	medium
23022	47722	909	Красноярский край, Березовский район, поселок Маганск, Новая, 2	f	medium
23020	47720	907	Красноярский край, Березовский район, деревня Лукино, Мамина, 29	f	small
23852	48550	1779	Красноярский край, Березовский район, деревня Калиновка, Советская, 45	t	small
86199	48416	1583	Красноярский край, Березовский район, поселок Жержул, Нагорная, 2	t	small
22824	47538	704	Красноярский край, Березовский район, город Железногорск, Школьная, 18	f	large
22823	47537	703	Красноярский край, Березовский район, город Железногорск, Школьная, 34	f	large
22822	47496	702	Красноярский край, Березовский район, Железногорск, Школьная, 46	f	large
22821	47496	701	Красноярский край, Березовский район, Железногорск, Школьная, 46	f	large
22853	47560	733	Красноярский край, Березовский район, Железногорск, Толстого, 22	f	large
22846	47553	726	Красноярский край, Березовский район, город Железногорск, Сибирская, 19	f	small
22828	47542	708	Красноярский край, Березовский район, Железногорск, Свердлова, 5	f	large
22825	47539	705	Красноярский край, Березовский район, Железногорск, Парковая, 1	f	large
22829	47543	709	Красноярский край, Березовский район, Железногорск, Молодежная, 7	f	large
24222	48976	2198	Красноярский край, Березовский район, Железногорск, Ленинградский проспект, 32	f	large
22845	47552	725	Красноярский край, Березовский район, Железногорск, Ленинградский проспект, 81	f	large
22844	47552	724	Красноярский край, Березовский район, Железногорск, Ленинградский проспект, 81	f	large
22841	47550	721	Красноярский край, Березовский район, город Железногорск, Ленинградский проспект, 37	f	large
22826	47540	706	Красноярский край, Березовский район, Железногорск, Ленина, 23	f	large
22820	47536	700	Красноярский край, Березовский район, Железногорск, Ленина, 48	f	large
22827	47541	707	Красноярский край, Березовский район, город Железногорск, Крупской, 8	f	large
22835	47546	715	Красноярский край, Березовский район, город Железногорск, Королева, 7А	f	large
22834	47546	714	Красноярский край, Березовский район, город Железногорск, Королева, 7А	f	large
22833	47546	713	Красноярский край, Березовский район, город Железногорск, Королева, 7А	f	large
22818	47534	698	Красноярский край, Березовский район, Железногорск, Комсомольская, 35А	f	large
22832	47545	712	Красноярский край, Березовский район, Железногорск, Восточная, 25	f	large
22831	47545	711	Красноярский край, Березовский район, Железногорск, Восточная, 25	f	large
22830	47544	710	Красноярский край, Березовский район, город Железногорск, Восточная, 15	f	large
22848	47555	728	Красноярский край, Березовский район, Железногорск, Белорусская, 42	f	large
22819	47535	699	Красноярский край, Березовский район, город Железногорск, Андреева, 14	f	large
22840	47549	720	Красноярский край, Березовский район, город Железногорск, 60 лет ВЛКСМ, 32	f	large
22839	47548	719	Красноярский край, Березовский район, Железногорск, 60 лет ВЛКСМ, 18	f	large
22838	47548	718	Красноярский край, Березовский район, Железногорск, 60 лет ВЛКСМ, 18	f	large
23025	47726	912	Красноярский край, Березовский район, поселок Верхняя Базаиха, Школьная, 3	f	small
23026	47728	913	Красноярский край, Березовский район, Береть, Центральная, 1	f	small
23024	47724	911	Красноярский край, Березовский район, поселок Березовский, Победы, 1	f	small
23023	47723	910	Красноярский край, Березовский район, поселок Березовский, Нагорная, 6А, Сельский клуб	t	medium
23002	47706	888	Красноярский край, Березовский район, поселок Березовка, Юбилейная, 6	f	large
23008	47712	894	Красноярский край, Березовский район, поселок Березовка, Молодежная, 1	t	small
23007	47711	893	Красноярский край, Березовский район, поселок Березовка, Матросова, 21А	f	large
22995	47700	878	Красноярский край, Балахтинский район, д.Малая Тумна, Клубная, 1а	t	small
22991	47643	874	Красноярский край, Балахтинский район, поселок Ямская, Мира, 21а	f	small
22984	47691	867	Красноярский край, Балахтинский район, поселок Якушево, Новая, 2	f	small
22998	47703	881	Красноярский край, Балахтинский район, поселок Черемушки, Мира, 5	t	small
24300	49062	2279	Красноярский край, Балахтинский район, поселок Холодный Ключ, Школьная, 2	f	small
22975	47682	858	Красноярский край, Балахтинский район, поселок Угольный, Мира, 7А	f	small
22967	47674	850	Красноярский край, Балахтинский район, поселок Тюльково, Ленина, 118а	f	medium
22972	47679	855	Красноярский край, Балахтинский район, поселок Трясучая	t	small
22978	47685	861	Красноярский край, Балахтинский район, поселок Тойлук, Заречная, 18	t	small
22976	47683	859	Красноярский край, Балахтинский район, поселок Ровное, Школьная, 6	t	medium
22988	47695	871	Красноярский край, Балахтинский район, поселок Приморск, Карла Маркса, 18	t	large
22992	39346	875	Красноярский край, Балахтинский район, поселок Огур, Тольятти, 3а	t	medium
22986	47693	869	Красноярский край, Балахтинский район, поселок Могучий, Новая, 4	t	small
23250	47984	1155	Красноярский край, Балахтинский район, поселок Малая Тумна (Епишино), Лесная, 11	f	medium
23434	48178	1340	Красноярский край, Балахтинский район, поселок Курбатово, Береговая, 2	t	small
22969	47676	852	Красноярский край, Балахтинский район, поселок Крюково, Центральная, 37	f	small
22994	47699	877	Красноярский край, Балахтинский район, поселок Красный Ключ, Центральная, 15А	t	small
22965	47672	848	Красноярский край, Балахтинский район, поселок Красная, Центральная, 24б	f	small
22970	47677	853	Красноярский край, Балахтинский район, поселок Кожаны, 29, клуб	f	large
22968	47675	851	Красноярский край, Балахтинский район, поселок Ключи, Центральная, 6	f	small
22982	47689	865	Красноярский край, Балахтинский район, поселок Ильтюково, Космонавтов, 12	f	small
22990	47697	873	Красноярский край, Балахтинский район, поселок Ижульское, Ижульская, 10	t	small
23297	48000	1202	Красноярский край, Балахтинский район, село Жеблахты, Ойская, 63а	f	small
22989	47696	872	Красноярский край, Балахтинский район, поселок Даурское, Юности, 2	t	small
22979	47686	862	Красноярский край, Балахтинский район, поселок Грузенка, Московская, 18	t	small
22973	47680	856	Красноярский край, Балахтинский район, поселок Гладкий Мыс, Мира, 20	f	small
22983	47690	866	Красноярский край, Балахтинский район, поселок Вольный, Старая, 8	f	small
22997	47702	880	Красноярский край, Балахтинский район, поселок Виленка, Ленина, 43	f	small
22996	47701	879	Красноярский край, Балахтинский район, поселок Большие Сыры, Космонавтов, 15	f	medium
22966	47673	849	Красноярский край, Балахтинский район, поселок Безъязыково, переулок Центральный, 3	t	small
22980	47687	863	Красноярский край, Балахтинский район, поселок Балдаштык, Центральная, 4	t	small
22958	47665	841	Красноярский край, Балахтинский район, поселок Балахта, Ленина, 9	f	large
22956	47663	839	Красноярский край, Балахтинский район, поселок Балахта, 60 лет Октября, 11	f	large
22961	47668	844	Красноярский край, Балахтинский район, поселок городского типа Балахта, Чайковского, 40	f	large
22962	47669	845	Красноярский край, Балахтинский район, поселок городского типа Балахта, Переулок Школьный, 8	f	small
22957	47664	840	Красноярский край, Балахтинский район, поселок городского типа Балахта, Космонавтов, 19	f	medium
22959	47666	842	Красноярский край, Балахтинский район, поселок городского типа Балахта, Каткова, 22	f	medium
22951	47657	834	Красноярский край, Ачинский район, поселок Ястребово, Новая, 2	f	medium
22945	47650	828	Красноярский край, Ачинский район, поселок Тимонино, им.Ивченко М.Л, 34	f	small
22948	47654	831	Красноярский край, Ачинский район, поселок Тарутино, Переулок Клубный, б/н	f	large
22947	47653	830	Красноярский край, Ачинский район, поселок Покровка, Центральная, 26	f	small
23264	48002	1169	Красноярский край, Ачинский район, поселок Плотбище, Советская, 18	t	small
22955	47662	838	Красноярский край, Ачинский район, поселок Ольховка, Партизанская, 40а	t	small
22940	47645	823	Красноярский край, Ачинский район, поселок Нагорново, Уланова, 1А	t	small
22953	47659	836	Красноярский край, Ачинский район, поселок Малый Улуй, Центральная, 20	t	small
22944	47649	827	Красноярский край, Ачинский район, поселок Лапшиха, Советская, 13	f	small
23158	47882	1056	Красноярский край, Ачинский район, поселок Красная Заря, Зеленая, 27	f	small
23735	48354	1660	Красноярский край, Ачинский район, поселок Костеньки, Зеленая, 11А	t	small
22952	47658	835	Красноярский край, Ачинский район, поселок Ключи, Центральная, 5	f	medium
24333	49083	2315	Красноярский край, Ачинский район, Карловка, Армейская, здание казармы вч 74076-2	t	small
22941	47646	824	Красноярский край, Ачинский район, поселок Борцы, Центральная, 48	t	small
22942	47647	825	Красноярский край, Ачинский район, Большая Салырь, Школьная, 16	f	large
22936	47640	819	Красноярский край, Ачинский район, село Белый Яр, 12а, МПС	t	small
22937	47641	820	Красноярский край, Ачинский район, село Белый Яр, Трактовая, 55	f	medium
22946	47652	829	Красноярский край, Ачинский, поселок Малиновка, Квартал 1, 4	f	large
22950	47656	833	Красноярский край, Ачинский, поселок Берёзовый, Клубная, 3а	f	small
24313	49074	2295	Красноярский край, Абанский район, Хиндичет, Заречная, 16-1, Почетский сельсовет	t	small
22933	47637	816	Красноярский край, Абанский район, поселок Хандальск, Школьная, 20	t	small
22927	47631	810	Красноярский край, Абанский район, поселок Устьянск, Мира, 29Б	f	medium
22923	47627	806	Красноярский край, Абанский район, поселок Турово, Советская, 48	f	small
22900	47604	783	Красноярский край, Абанский район, поселок Стерлитамак, Центральная, 9	t	small
22904	47608	787	Красноярский край, Абанский район, поселок Средние Мангареки, Набережная, 10	t	small
24310	49071	2292	Красноярский край, Абанский район, поселок Сенное, Советская, 21-2	t	small
22922	47626	805	Красноярский край, Абанский район, поселок Самойловка, Советская, 56	f	medium
22925	47629	808	Красноярский край, Абанский район, поселок Пушкино, А.С. Пушкина, 26	f	small
22913	47617	796	Красноярский край, Абанский район, поселок Почет, Юбилейная, 10	t	small
22915	47619	798	Красноярский край, Абанский район, поселок Почет, Победы, 10	t	small
22921	47625	804	Красноярский край, Абанский район, поселок Покатеево, Советская, 36	t	small
22916	47620	799	Красноярский край, Абанский район, поселок Плахино, Школьная, 47-2	t	small
22935	47639	818	Красноярский край, Абанский район, поселок Пея, Больничная, 10	t	small
22931	47635	814	Красноярский край, Абанский район, поселок Огурцы, Береговая, 20А	f	small
22893	47597	776	Красноярский край, Абанский район, поселок Ношино, Советская, 46	t	small
22907	47611	790	Красноярский край, Абанский район, поселок Новоуспенка, Советская, 35	f	small
22906	47610	789	Красноярский край, Абанский район, поселок Новоуспенка, А.Лебедя, 25	f	small
22930	47634	813	Красноярский край, Абанский район, поселок Новокиевлянка, Покровская, 14	t	small
23367	48109	1272	Красноярский край, Абанский район, поселок Новгородка, Центральная, сельский Дом культуры	f	small
22894	47598	777	Красноярский край, Абанский район, поселок Мачино, Школьная, 4	t	small
24311	49072	2293	Красноярский край, Абанский район, поселок Малкас, Школьная, 2	f	small
111144	47602	781	Красноярский край, Абанский район, поселок Лазарево, Центральная, 22	f	medium
22926	47630	809	Красноярский край, Абанский район, поселок Кунгул, Советская, 10	t	small
22929	47633	812	Красноярский край, Абанский район, поселок Красный Яр, Школьная, 6	f	small
22910	47614	793	Красноярский край, Абанский район, поселок Канарай, Подгорная, 26	f	small
22899	47603	782	Красноярский край, Абанский район, поселок Заозерка, Сибирская, 15	t	small
22924	47628	807	Красноярский край, Абанский район, поселок Залипье, Молодежная, 17	f	small
86170	47605	784	Красноярский край, Абанский район, поселок Долженовка, Буденного, 38 Б	f	small
111143	47601	780	Красноярский край, Абанский район, поселок Долгий Мост, Советская , 98	f	medium
22896	47600	779	Красноярский край, Абанский район, поселок Долгий Мост, Дзержинского, 22	f	medium
22928	47632	811	Красноярский край, Абанский район, поселок Денисовка, Почтовая, 26	t	small
22909	47613	792	Красноярский край, Абанский район, поселок Гагарина, Молодежная, 16	t	small
22911	47615	794	Красноярский край, Абанский район, поселок Высокогородецк, Советская, 30	t	small
22919	47623	802	Красноярский край, Абанский район, поселок Восток, Первомайская, 20	f	small
22920	47624	803	Красноярский край, Абанский район, поселок Быстровка, Школьная, 3	f	small
22934	47638	817	Красноярский край, Абанский район, поселок Борзово, Железнодорожная, 2	t	small
22914	47618	797	Красноярский край, Абанский район, поселок Бирюса, Новая, 1	t	small
22890	47594	773	Красноярский край, Абанский район, поселок Апано-Ключи, Советская, 31	f	small
22903	47607	786	Красноярский край, Абанский район, поселок Алексеевка, Трактовая, 29	t	small
22887	47591	770	Красноярский край, Абанский район, поселок городского типа Абан, Советская, 71А	f	large
22888	47592	771	Красноярский край, Абанский район, поселок городского типа Абан, Пионерская, 3	f	large
24285	49054	2264	Красноярский край, Абанский район, поселок городского типа Абан, Больничная, 26	t	medium
22889	47593	772	Красноярский край, Абанский район, поселок городского типа Абан, Д.Бедного, 56	f	large
23527	48275	1442	Красноярский край, Кежемский район, Кодинск, Колесниченко, 10	f	large
23526	48274	1441	Красноярский край, Кежемский район, Кодинск, Колесниченко, 16	f	large
23534	48281	1449	Красноярский край, Кежемский район, село Заледеево, Октябрьская, 35	f	medium
43001	41075	1246	Кемеровская область, поселок станции Тальжино, Свердлова, 2	f	large
42647	40685	909	Россия, Кемеровская область, поселок Ясногорский, Центральная улица, 2	f	large
42858	40919	1114	Кемеровская область, поселок Ясногорский, Центральная, 11	f	medium
43171	41273	1415	Кемеровская область, Таштагол, К. Цеткин, 28	f	\N
43176	41278	1420	Кемеровская область, Таштагол, Геологическая, 62	f	\N
43168	41270	1412	Кемеровская область, Таштагол, 20 партсъезда, 86а	f	\N
42662	40703	923	Кемеровская область, Тайга, р-д Сураново	t	small
42658	40671	937	Кемеровская область, Тайга, р-д Кузель	f	small
42669	40713	930	Кемеровская область, Тайга, Щетинкина, 74	f	large
42665	40707	926	Кемеровская область, Тайга, Щетинкина, 56	f	large
42660	40701	921	Кемеровская область, Тайга, Трудовые резервы, 18	f	medium
42673	40590	934	Кемеровская область, Тайга, Советская, 101	f	large
42671	40715	932	Кемеровская область, Тайга, Привокзальная, 15	f	medium
42674	40630	935	Кемеровская область, Тайга, Почтовая, 99/2	f	large
42661	40702	922	Кемеровская область, Тайга, поселок Таёжный, Народная, 7	f	small
42659	40700	920	Кемеровская область, Тайга, Молокова, 31	f	medium
42668	40712	929	Кемеровская область, Тайга, Молодежная, 13	f	large
42666	40708	927	Кемеровская область, Тайга, Молодежная, 1	f	large
42667	40710	928	Кемеровская область, Тайга, Мира, 6	f	large
42672	40716	933	Кемеровская область, Тайга, Кирова, 57	f	large
42670	40714	931	Кемеровская область, Тайга, Кирова, 42	f	medium
42664	40705	925	Кемеровская область, Тайга, Кирова, 1	f	large
42675	40644	936	Кемеровская область, Тайга, Калинина, 106	f	large
42663	40704	924	Кемеровская область, Тайга, Деповская, 11	f	large
42848	40909	1105	Кемеровская область, деревня Сухово, Заречная улица, 2-А	t	small
43004	41078	1249	Кемеровская область, поселок Староабашево, Линейная, 2А	t	small
42761	40823	1023	Кемеровская область, Салаир, Приисковая, 1-а	t	medium
42760	40822	1022	Кемеровская область, Салаир, Мира, 23	t	small
41787	39649	48	Кемеровская область, поселок Рудничный, Советская, 7	f	\N
42566	40575	828	Кемеровская область, Прокопьевск, проспект Строителей, 93	f	large
42625	40652	887	Кемеровская область, Прокопьевск, переулок Городской, 31	f	medium
42602	40623	864	Кемеровская область, Прокопьевск, Революции, 2	f	large
42613	40636	875	Кемеровская область, Прокопьевск, Калинина, 1	f	large
42586	40603	848	Кемеровская область, Прокопьевск, Институтская, 41	f	large
42640	40678	902	Кемеровская область, Прокопьевск, Захаренко, 33	f	large
42569	40580	831	Кемеровская область, Прокопьевск, Есенина, 66	f	large
42570	40571	832	Кемеровская область, Прокопьевск, Есенина, 48	f	large
42612	40635	874	Кемеровская область, Прокопьевск, Вокзальная, 21	f	large
42862	40922	1116	Кемеровская область, поселок Пригородный, Центральная, 120-А	f	large
42540	40547	802	Кемеровская область, Осинниковский городской округ, Ефимова, 2	f	large
42537	40544	799	Кемеровская область, Осинники, улица 50 лет Октября, 33	f	large
42522	40520	784	Кемеровская область, Осинники, Шахтовая, 3	t	medium
42541	40548	803	Кемеровская область, Осинники, Советская, 6	f	large
42535	40540	797	Кемеровская область, Осинники, Советская, 23	f	large
42539	40546	801	Кемеровская область, Осинники, Победы, 54	f	large
42533	40535	795	Кемеровская область, Осинники, Победы, 11	f	large
42526	40291	788	Кемеровская область, Осинники, Куйбышева, 7	f	large
42530	40529	792	Кемеровская область, Осинники, Кирова, 17	f	large
42524	40498	786	Кемеровская область, Осинники, Заречная, 15	t	large
42538	40545	800	Кемеровская область, Осинники, Ефимова, 8	f	large
42529	40528	791	Кемеровская область, Осинники, Вокзальная, 13	t	large
42523	40521	785	Кемеровская область, Осинники, 9-я штольня, 29	t	large
42534	40539	796	Кемеровская область, Осинники, 50 лет Октября, 1	f	medium
42474	40453	735	Кемеровская область, Новокузнецк, улица Энтузиастов, 55, училище искусств	f	\N
42448	40429	709	Кемеровская область, Новокузнецк, улица Франкфурта, 16, художественная гимназия №70	f	\N
41903	39793	164	Россия, Кемеровская область	t	\N
42322	40306	583	Россия, Кемеровская область, Новокузнецкий район	f	\N
42321	40306	582	Россия, Кемеровская область, Новокузнецкий район	f	\N
42454	40435	715	Кемеровская область, Новокузнецк, проспект Строителей, 55, МАУ по орг. пасс.перевозок	f	\N
42452	40433	713	Кемеровская область, Новокузнецк, проспект Строителей, 17, ТУ 87	f	\N
42362	40341	623	Кемеровская область, Новокузнецк, проспект Советской Армии, 13	f	medium
42317	40303	578	Россия, Кемеровская область, Новокузнецкий район	f	\N
42316	40302	577	Кемеровская область, Новокузнецк, проспект Мира, 46	f	\N
42315	40302	576	Кемеровская область, Новокузнецк, проспект Мира, 46	f	\N
42314	40302	575	Кемеровская область, Новокузнецк, проспект Мира, 46	f	\N
41911	39801	172	Россия, Кемеровская область	f	\N
42496	40487	757	Кемеровская область, Новокузнецк, проспект Курако, 33	f	large
42478	40457	739	Кемеровская область, Новокузнецк, проспект Бардина, 14, Кузбассгражданпроект	f	\N
42319	40304	580	Россия, Кемеровская область, Новокузнецкий район	f	\N
42318	40304	579	Россия, Кемеровская область, Новокузнецкий район	f	\N
42310	40300	571	Россия, Кемеровская область, Новокузнецкий район	f	\N
42311	40300	572	Россия, Кемеровская область, Новокузнецкий район	f	\N
42312	40300	573	Россия, Кемеровская область, Новокузнецкий район	f	\N
42309	40300	570	Россия, Кемеровская область, Новокузнецкий район	f	\N
42307	40299	568	Кемеровская область, Новокузнецк, проспект Авиаторов, 76	f	\N
42308	40299	569	Кемеровская область, Новокузнецк, проспект Авиаторов, 76	f	\N
42367	40349	628	Кемеровская область, Новокузнецк, проезд Чекистов, 13	f	medium
42464	40445	725	Кемеровская область, Новокузнецк, проезд Кулакова, 3, лицей 84	f	\N
42463	40444	724	Кемеровская область, Новокузнецк, проезд Коммунаров, 1, Металлургический колледж	f	\N
42587	40605	849	Кемеровская область, Новокузнецк, Яворского, 5А	f	large
42278	40267	539	Кемеровская область, Новокузнецк, Юдина, 17	f	large
42377	40362	638	Кемеровская область, Новокузнецк, Шункова, 26	f	large
42376	40362	637	Кемеровская область, Новокузнецк, Шункова, 26	f	large
42392	40361	653	Кемеровская область, Новокузнецк, Шункова, 6	f	large
42375	40361	636	Кемеровская область, Новокузнецк, Шункова, 6	f	large
42385	40369	646	Кемеровская область, Новокузнецк, Шестакова, 17	f	large
42485	40467	746	Кемеровская область, Новокузнецк, Шебелинская, 10	f	medium
42492	40481	753	Кемеровская область, Новокузнецк, Читинский проезд, 2	f	medium
42498	40491	759	Кемеровская область, Новокузнецк, Черноморская, 1	f	large
42490	40477	751	Кемеровская область, Новокузнецк, Челюскина, 15	f	large
42489	40474	750	Кемеровская область, Новокузнецк, Челюскина, 16	f	large
42479	40458	740	Кемеровская область, Новокузнецк, Циолковского, 42а, школа 31	f	\N
42480	40458	741	Кемеровская область, Новокузнецк, Циолковского, 42а, школа 31	f	\N
42466	40447	727	Кемеровская область, Новокузнецк, Циолковского, 47, проф.лицей №10	f	\N
42467	40447	728	Кемеровская область, Новокузнецк, Циолковского, 47, проф.лицей №10	f	\N
42436	40417	697	Кемеровская область, Новокузнецк, Циолковского, 65, лицей 34	f	\N
42435	40417	696	Кемеровская область, Новокузнецк, Циолковского, 65, лицей 34	f	\N
42437	40399	698	Кемеровская область, Новокузнецк, Циолковского, 78а	f	\N
42449	40430	710	Кемеровская область, Новокузнецк, Франкфурта, 16, худ.гимн. №70	f	\N
42458	40439	719	Кемеровская область, Новокузнецк, Филиппова, 10, школа 2	f	\N
42410	40384	661	Кемеровская область, Новокузнецк, Уютная, 30	t	large
42461	40442	722	Кемеровская область, Новокузнецк, Ушинского, 5	f	\N
42407	40380	658	Кемеровская область, Новокузнецк, Тузовского, 17	f	large
42611	40634	873	Кемеровская область, Новокузнецк, Транспортная, 13	f	large
42511	40504	772	Кемеровская область, Новокузнецк, Транспортная, 57	f	large
42510	40504	771	Кемеровская область, Новокузнецк, Транспортная, 57	f	large
42477	40456	738	Кемеровская область, Новокузнецк, Транспортная, 29, МОУ СОШ 91	f	\N
42361	40338	622	Кемеровская область, Новокузнецк, Тореза, 11	f	large
42360	40338	621	Кемеровская область, Новокузнецк, Тореза, 11	f	large
42352	40329	613	Кемеровская область, Новокузнецк, Тореза, 22в	f	large
42341	40309	602	Кемеровская область, Новокузнецк, Тореза, 82а	f	large
42342	40309	603	Кемеровская область, Новокузнецк, Тореза, 82а	f	large
42370	40352	631	Кемеровская область, Новокузнецк, Томский проезд, 9	f	large
42369	40352	630	Кемеровская область, Новокузнецк, Томский проезд, 9	f	large
42451	40432	712	Кемеровская область, Новокузнецк, Тольятти, 52, школа 67	f	\N
42450	40431	711	Кемеровская область, Новокузнецк, Тольятти, 52, школа 57	f	\N
42444	40426	705	Кемеровская область, Новокузнецк, Тольятти, 39, школа-лицей 62	f	\N
42445	40426	706	Кемеровская область, Новокузнецк, Тольятти, 39, школа-лицей 62	f	\N
42446	40426	707	Кемеровская область, Новокузнецк, Тольятти, 39, школа-лицей 62	f	\N
42438	40420	699	Кемеровская область, Новокузнецк, Тольятти, 3, школа 103	f	\N
42428	40409	689	Кемеровская область, Новокузнецк, Тольятти, 30а, экологическая школа	f	\N
42429	40409	690	Кемеровская область, Новокузнецк, Тольятти, 30а, экологическая школа	f	\N
42357	40336	618	Кемеровская область, Новокузнецк, Строительная, 6	t	medium
42517	40510	778	Кемеровская область, Новокузнецк, Спортивная, 11б	f	medium
42495	40486	756	Кемеровская область, Новокузнецк, Сибиряков-Гвардейцев, 16	f	large
42125	40082	386	Кемеровская область, Новокузнецк, Сетевая, 32	f	large
42447	40428	708	Кемеровская область, Новокузнецк, Свердлова, 10, школа 72	f	\N
42313	40301	574	Кемеровская область, Новокузнецк, Рокоссовского, 21	f	\N
42506	40501	767	Кемеровская область, Новокузнецк, Редаково, 104	f	large
42398	40391	669	Кемеровская область, Новокузнецк, Разведчиков, 46	f	large
42397	40391	668	Кемеровская область, Новокузнецк, Разведчиков, 46	f	large
42394	40387	665	Кемеровская область, Новокузнецк, Радищева, 24	f	large
42412	40387	664	Кемеровская область, Новокузнецк, Радищева, 24	f	large
42408	40381	659	Кемеровская область, Новокузнецк, Пушкина, 26	f	large
42505	40497	766	Кемеровская область, Новокузнецк, Пролетарская, 81	f	large
42652	40690	914	Россия, Кемеровская область, Прокопьевский район	f	large
42641	40677	904	Россия, Кемеровская область, Прокопьевский район	f	large
42633	40665	895	Россия, Кемеровская область, Прокопьевский район	f	large
42599	40620	861	Россия, Кемеровская область, Прокопьевский район	f	large
42443	40425	704	Кемеровская область, Новокузнецк, Покрышкина, 18, школа 97	f	\N
42471	40449	732	Кемеровская область, Новокузнецк, Пионерский проспект, 36, школа 26	f	\N
42470	40449	731	Кемеровская область, Новокузнецк, Пионерский проспект, 36, школа 26	f	\N
42455	40436	716	Кемеровская область, Новокузнецк, Пионерский проспект, 9, школа-интернат 38	f	\N
42456	40437	717	Кемеровская область, Новокузнецк, Пионерский, 13, КУЗГПА	f	\N
42442	40424	703	Кемеровская область, Новокузнецк, Орджоникидзе, 23, Городской дворец культуры	f	\N
42328	40310	589	Кемеровская область, Новокузнецк, Олимпийская, 17	f	\N
42469	40448	730	Кемеровская область, Новокузнецк, Центральный район, Октябрьский проспект, 24а, школа №31	f	\N
42468	40448	729	Кемеровская область, Новокузнецк, Центральный район, Октябрьский проспект, 24а, школа №31	f	\N
42386	40370	647	Кемеровская область, Новокузнецк, Обнорского, 92	f	large
42320	40305	581	Кемеровская область, Новокузнецк, Новоселов, 53	f	\N
42331	40298	592	Кемеровская область, Новокузнецк, Новоселов, 19	f	\N
42306	40298	567	Кемеровская область, Новокузнецк, Новоселов, 19	f	\N
42415	40398	676	Кемеровская область, Новокузнецк, Новогодняя улица, 15а	t	medium
42423	40403	684	Кемеровская область, Новокузнецк, Новобайдаевская, 9	f	large
42422	40403	683	Кемеровская область, Новокузнецк, Новобайдаевская, 9	f	large
42391	40374	652	Кемеровская область, Новокузнецк, Народная, 31	f	large
42390	40372	651	Кемеровская область, Новокузнецк, Народная, 27	f	large
42389	40372	650	Кемеровская область, Новокузнецк, Народная, 27	f	large
42388	40372	649	Кемеровская область, Новокузнецк, Народная, 27	f	large
42401	40393	672	Кемеровская область, Новокузнецк, Мурманская, 54	t	large
42400	40392	671	Кемеровская область, Новокузнецк, Мурманская, 24	f	large
42399	40392	670	Кемеровская область, Новокузнецк, Мурманская, 24	f	large
42396	40390	667	Кемеровская область, Новокузнецк, Монтажная, 35	f	large
42497	40489	758	Кемеровская область, Новокузнецк, Мичурина, 4а	f	large
42406	40379	657	Кемеровская область, Новокузнецк, Маркшейдерская, 12	f	large
42651	40689	913	Кемеровская область, Новокузнецк, Луначарского, 10	f	large
42507	40502	768	Кемеровская область, Новокузнецк, Литейная улица, 112	t	large
42491	40479	752	Кемеровская область, Новокузнецк, Лесная, 1	f	large
42382	40366	643	Кемеровская область, Новокузнецк, Ленина, 119	f	large
42381	40365	642	Кемеровская область, Новокузнецк, Ленина, 78	f	large
42380	40364	641	Кемеровская область, Новокузнецк, Ленина, 61	f	large
42378	40363	639	Кемеровская область, Новокузнецк, Ленина, 41	f	large
42379	40363	640	Кемеровская область, Новокузнецк, Ленина, 41	f	large
42336	40319	597	Кемеровская область, Новокузнецк, Ладожская, 110	t	large
42629	40660	891	Кемеровская область, Новокузнецк, Кучина, 9	f	large
42512	40505	773	Кемеровская область, Новокузнецк, Кутузова, 84	f	large
42475	40454	736	Кемеровская область, Новокузнецк, Кутузова, 12, фак-т ин.яз	f	\N
42465	40446	726	Кемеровская область, Новокузнецк, Кутузова, 4, школа 31	f	\N
42405	40378	656	Кемеровская область, Новокузнецк, Кустарная, 47	t	medium
42501	40492	762	Кемеровская область, Новокузнецк, улица Куйбышева, 4	f	large
42500	40492	761	Кемеровская область, Новокузнецк, улица Куйбышева, 4	f	medium
42499	40492	760	Кемеровская область, Новокузнецк, улица Куйбышева, 4	f	large
42518	40511	779	Кемеровская область, Новокузнецк, Кубинская улица, 23а	t	large
42402	40396	675	Кемеровская область, Новокузнецк, Крупской, 35	t	large
42156	40122	417	Кемеровская область, Новокузнецк, Красина, 1	f	large
42324	40307	585	Кемеровская область, Новокузнецк, Косыгина, 73	f	\N
42323	40307	584	Кемеровская область, Новокузнецк, Косыгина, 73	f	\N
42305	40297	566	Кемеровская область, Новокузнецк, Косыгина, 49	f	\N
42330	40297	591	Кемеровская область, Новокузнецк, Косыгина, 49	f	\N
42329	40297	590	Кемеровская область, Новокузнецк, Косыгина, 49	f	\N
41946	39846	207	Кемеровская область, Новокузнецк, Коммунистическая, 14	f	large
42346	40325	607	Кемеровская область, Новокузнецк, Клименко, 7а	f	large
42345	40325	606	Кемеровская область, Новокузнецк, Клименко, 7а	f	large
42344	40324	605	Кемеровская область, Новокузнецк, Клименко, 36а	f	large
42343	40324	604	Кемеровская область, Новокузнецк, Клименко, 36а	f	large
42356	40332	617	Кемеровская область, Новокузнецк, Климасенко, 12к3	f	large
42355	40332	616	Кемеровская область, Новокузнецк, Климасенко, 12к3	f	large
42354	40331	615	Кемеровская область, Новокузнецк, Климасенко, 20к1	f	large
42335	40318	596	Кемеровская область, Новокузнецк, Климасенко, 1к2	f	large
42334	40316	595	Кемеровская область, Новокузнецк, Климасенко, 11/5	f	large
42333	40314	594	Кемеровская область, Новокузнецк, Климасенко, 21к5	f	large
42353	40312	614	Кемеровская область, Новокузнецк, Климасенко, 25а	f	large
42332	40312	593	Кемеровская область, Новокузнецк, Климасенко, 25а	f	large
42165	40137	426	Россия, Кемеровская область	f	large
42158	40123	419	Россия, Кемеровская область	f	large
42157	40123	418	Россия, Кемеровская область	t	medium
42135	40096	396	Россия, Кемеровская область	f	large
42122	40079	383	Россия, Кемеровская область	f	large
42121	40078	382	Кемеровская область, городской округ Киселевск, 1 Мая, 19	f	large
43332	41456	1573	Кемеровская область, Новокузнецк, Кирова, 13	f	large
42426	40408	687	Кемеровская область, Новокузнецк, Кирова, 79а, гимназия 44	f	\N
42427	40408	688	Кемеровская область, Новокузнецк, Кирова, 79а, гимназия 44	f	\N
41887	39770	148	Кемеровская область, Новокузнецк, Кирова, 41	f	large
42473	40452	734	Кемеровская область, Новокузнецк, Кирова, 42, СибГИУ	f	\N
42493	40483	754	Россия, Кемеровская область, Новокузнецкий район	f	medium
42404	40377	655	Кемеровская область, Новокузнецк, Кедровый переулок, 5	f	large
42487	40471	748	Кемеровская область, Новокузнецк, Карла Маркса, 5	f	large
42486	40469	747	Кемеровская область, Новокузнецк, Карла Маркса, 10	f	large
42403	40376	654	Кемеровская область, Новокузнецк, Кавказская, 5	t	large
42359	40337	620	Кемеровская область, Новокузнецк, Ижевский проезд, 14	f	large
42358	40337	619	Кемеровская область, Новокузнецк, Ижевский проезд, 14	f	large
42395	40389	666	Кемеровская область, Новокузнецк, Зыряновская, 99	f	large
42421	40402	682	Кемеровская область, Новокузнецк, Зорге, 36	f	large
42420	40402	681	Кемеровская область, Новокузнецк, Зорге, 36	f	large
42606	40628	868	Кемеровская область, Новокузнецк, Западная, 3	f	large
42483	40463	744	Кемеровская область, Новокузнецк, Жасминная, 8	f	large
42409	40383	660	Кемеровская область, Новокузнецк, Емельяновская, 1	t	large
42393	40385	663	Кемеровская область, Новокузнецк, Дузенко, 14а	f	large
42411	40385	662	Кемеровская область, Новокузнецк, Дузенко, 14а	f	large
42413	40394	673	Кемеровская область, Новокузнецк, Дорстроевская, 5а	t	large
42453	40434	714	Кемеровская область, Новокузнецк, ДОЗ, 17, Новок. уч-курсовой комб. а/тран	f	\N
42440	40422	701	Кемеровская область, Новокузнецк, Грдины, 6, школа 55	f	\N
42439	40414	700	Кемеровская область, Новокузнецк, Грдины, 6, школа 55	f	\N
42432	40414	693	Кемеровская область, Новокузнецк, Грдины, 6, школа 55	f	\N
42430	40411	691	Кемеровская область, Новокузнецк, Грдины, 20, гимназия 48	f	\N
42424	40405	685	Кемеровская область, Новокузнецк, Грдины, 20	f	\N
42368	40351	629	Кемеровская область, Новокузнецк, Горьковская, 33	f	large
42366	40346	627	Кемеровская область, Новокузнецк, Горьковская, 27а	f	large
42365	40346	626	Кемеровская область, Новокузнецк, Горьковская, 27а	f	large
42364	40345	625	Кемеровская область, Новокузнецк, Горьковская, 17	f	large
42363	40342	624	Кемеровская область, Новокузнецк, Горьковская, 15	f	large
42484	40464	745	Кемеровская область, Новокузнецк, Горноспасательная, 5	f	large
42604	40626	866	Кемеровская область, Новокузнецк, Волховская, 18	f	large
42630	40661	892	Кемеровская область, Новокузнецк, Волжская, 11	f	large
42503	40496	764	Кемеровская область, Новокузнецк, Вокзальная, 103	t	large
42504	40494	765	Кемеровская область, Новокузнецк, Вокзальная, 29	f	large
42502	40494	763	Кемеровская область, Новокузнецк, Вокзальная, 29	f	large
42516	40508	777	Кемеровская область, Новокузнецк, Водосточная, 1а	f	medium
42488	40472	749	Кемеровская область, Новокузнецк, Веры Соломиной, 12	f	large
42509	40503	770	Кемеровская область, Новокузнецк, Варшавская, 2	f	large
42508	40503	769	Кемеровская область, Новокузнецк, Варшавская, 2	t	large
42384	40368	645	Кемеровская область, Новокузнецк, Бугарева, 17	f	large
41800	39661	61	Россия, Кемеровская область, Беловский район	f	large
42515	40507	776	Кемеровская область, Новокузнецк, Батюшкова, 16а	f	large
42514	40506	775	Кемеровская область, Новокузнецк, Батюшкова, 3	f	large
42513	40506	774	Кемеровская область, Новокузнецк, Батюшкова, 3	f	large
42603	40624	865	Кемеровская область, Новокузнецк, Акмолинская, 17	f	large
110750	40515	781	Кемеровская область, Новокузнецк, Автодорожная , 91, здание магазина ООО Щербина	t	\N
42148	40101	409	Кемеровская область, Новокузнецк, 50 лет городу, 34	f	large
42419	40401	680	Кемеровская область, Новокузнецк, 40 лет Победы, 9	f	large
42418	40401	679	Кемеровская область, Новокузнецк, 40 лет Победы, 9	f	large
42416	40400	677	Кемеровская область, Новокузнецк, 40 лет Победы, 17	f	large
42417	40400	678	Кемеровская область, Новокузнецк, 40 лет Победы, 17	f	large
42351	40328	612	Кемеровская область, Новокузнецк, 40 лет ВЛКСМ, 52а	f	large
42348	40326	609	Кемеровская область, Новокузнецк, 40 лет ВЛКСМ, 98а	f	large
42347	40326	608	Кемеровская область, Новокузнецк, 40 лет ВЛКСМ, 98а	f	large
42340	40323	601	Кемеровская область, Новокузнецк, 40 лет ВЛКСМ, 112	f	large
42339	40323	600	Кемеровская область, Новокузнецк, 40 лет ВЛКСМ, 112	f	large
42338	40320	599	Кемеровская область, Новокузнецк, 40 лет ВЛКСМ, 112а	f	medium
42337	40320	598	Кемеровская область, Новокузнецк, 40 лет ВЛКСМ, 112а	f	large
41818	39676	79	Кемеровская область, Новокузнецк, 3 микрорайон, 34	f	large
41814	39676	75	Кемеровская область, Новокузнецк, 3 микрорайон, 34	f	large
42457	40438	718	Кемеровская область, Новокузнецк, Филиппова, 10, школа №2	f	\N
41801	39662	62	Кемеровская область, Беловский район, Октябрьская, 12	t	large
42857	40918	1113	Кемеровская область, поселок Новоискитимск, Новая улица, 2	f	medium
42293	40284	554	Кемеровская область, Мыски, квартал 7, 1, ДК "Юбилейный", танц.зал	f	\N
42292	40283	553	Кемеровская область, Мыски, квартал 7, 1, ДК Юбилейныйспорт.зал	f	\N
42288	40279	549	Кемеровская область, Мыски, бульвар Юбилейный, 4а, школа №4	f	\N
42289	40279	551	Кемеровская область, Мыски, бульвар Юбилейный, 4а, школа №4	f	\N
42304	40296	565	Кемеровская область, Мыски, Энергетиков, 15, школа №7	f	\N
42300	40292	561	Кемеровская область, Мыски, Энергетиков, 4, ТУ ГЭТК	f	\N
42303	40295	564	Кемеровская область, Мыски, Центральная, 4, школа №3	f	\N
42284	40275	545	Кемеровская область, Мыски, Рембазовская, 1	f	\N
42285	40275	546	Кемеровская область, Мыски, Рембазовская, 1	f	\N
42286	40277	547	Кемеровская область, Мыски, Первомайская , 15, ГЦК	f	\N
110660	40280	550	Кемеровская область, Мыски, Первомайская, 33, Спортивный клуб Меркурий	f	\N
42287	40278	548	Кемеровская область, Мыски, Первомайская, 35, ЦДО	f	\N
42282	40271	543	Кемеровская область, Мыски, Панфилова, 4а, школа №6	f	\N
42283	40273	544	Кемеровская область, Мыски, Олимпийская, 1, ООО Водоканал	f	\N
42302	40294	563	Кемеровская область, Мыски, Ленина, 8а, ДК им. Горького	f	\N
42301	40293	562	Кемеровская область, Мыски, Ленина, 8А, ДК им. Горькогомалый зал	f	\N
42295	40287	556	Кемеровская область, Мыски, Левологовая, 1, ЗАО ТУ ЗЖБК	f	\N
42294	40286	555	Кемеровская область, Мыски, 50 лет пионерии, 14, школа №2	f	\N
42299	40290	560	Кемеровская область, Мыски, 17 квартал, 24, школа №5	f	\N
42298	40290	559	Кемеровская область, Мыски, 17 квартал, 24, школа №5	f	\N
42842	40905	1101	Кемеровская область, деревня Мозжуха, Школьная, 1	f	small
43024	41100	1268	Кемеровская область, поселок Металлургов, Рабочая, 43	f	medium
43023	41099	1267	Кемеровская область, поселок Металлургов, Молодежная, 7	f	large
41831	39693	92	Кемеровская область, поселок Металлплощадка, Южная, 5А	f	large
41830	39693	91	Кемеровская область, поселок Металлплощадка, Южная, 5А	f	large
41809	39671	70	Кемеровская область, поселок Металлплощадка, Советская улица, 41	f	large
41810	39672	71	Кемеровская область, поселок Металлплощадка, Советская, 44	t	large
42845	40907	1103	Кемеровская область, поселок Металлплощадка, Зеленая, 4	f	large
42258	40249	519	Кемеровская область, Междуреченск, поселок Улус, бывшая школа	f	medium
42253	40242	514	Кемеровская область, Междуреченск, школа №16 ОРТОН	f	small
42252	40241	513	Кемеровская область, Междуреченск, Лесорубов, 9	f	small
42269	40259	530	Кемеровская область, Междуреченск, Кузнецкая, 51	f	large
42142	40109	403	Кемеровская область, Киселевск, бульвар Строителей, 10	f	large
42124	40081	385	Кемеровская область, Киселевск, Ярославского, 2а	f	large
42113	40063	374	Кемеровская область, Киселевск, Юргинская, 1	f	medium
42136	40098	397	Кемеровская область, Киселевск, Чумова, 2А	f	large
42132	40092	393	Кемеровская область, Киселевск, Чумова, 25	f	large
42123	40080	384	Кемеровская область, Киселевск, Черных, 17а	f	large
42162	40131	423	Кемеровская область, Киселевск, Цветочный переулок, 4а	f	large
42126	40083	387	Кемеровская область, Киселевск, Хмельницкого, 10	f	large
42119	40042	380	Кемеровская область, Киселевск, Фадеева, 2	f	large
42129	40087	390	Кемеровская область, Киселевск, Ускатная, 6а	f	large
42153	40119	414	Кемеровская область, Киселевск, Строителей проезд, 5	f	large
42159	40125	420	Кемеровская область, Киселевск, Садовая, 5	f	large
42166	40140	427	Кемеровская область, Киселевск, Рейдовая, 25а	f	large
42137	40100	398	Кемеровская область, Киселевск, Привольная, 17	t	medium
42152	40118	413	Кемеровская область, Киселевск, Пионерская, 7	f	large
42115	40066	376	Кемеровская область, Киселевск, Панфилова, 5	f	large
42127	40084	388	Кемеровская область, Киселевск, Нижне-Заводская, 2	f	medium
42164	40135	425	Кемеровская область, Киселевск, Мурманский переулок, 20	f	large
42144	40112	405	Кемеровская область, Киселевск, Мира, 40	f	large
42145	40112	406	Кемеровская область, Киселевск, Мира, 40	f	large
42161	40130	422	Кемеровская область, Киселевск, Лутугина, 39	f	medium
42160	40128	421	Кемеровская область, Киселевск, Лутугина, 12	f	large
42138	40103	399	Кемеровская область, Киселевск, Луговая, 10	f	large
42141	40108	402	Кемеровская область, Киселевск, Ленина, 35	f	medium
42140	40107	401	Кемеровская область, Киселевск, Ленина, 37	f	large
42646	40683	908	Кемеровская область, Киселевск, Кустарная, 35	f	large
42626	40654	888	Кемеровская область, Киселевск, Коксовая, 41	f	large
42163	40133	424	Кемеровская область, Киселевск, Кирпичный переулок, 7а	f	large
42120	40076	381	Кемеровская область, Киселевск, Дружбы, 11	f	medium
42155	40121	416	Кемеровская область, Киселевск, Дзержинского, 12	f	large
42149	40116	410	Кемеровская область, Киселевск, Весенняя, 9	f	large
42116	40067	377	Кемеровская область, Киселевск, Багратиона, 11а	f	large
42150	40117	411	Кемеровская область, Киселевск, 50 лет городу, 21	f	large
42147	40115	408	Кемеровская область, Киселевск, 50 лет городу, 20а	f	large
42128	40085	389	Кемеровская область, Киселевск, 50 лет Октября, 5А	f	large
41991	39914	252	Кемеровская область, Кемерово, Кировский район, 3а	f	large
41817	39679	78	Кемеровская область, Беловский район, улица Щетинкина, 61	t	medium
42593	40613	855	Кемеровская область, Кемерово, улица Шишкина, 24	f	large
42016	39942	277	Кемеровская область, Кемерово, Ленинский район, улица Тухачевского, 32	f	large
42068	39995	329	Кемеровская область, Кемерово, Заводский район, улица Трофимова, 45	f	large
41987	39906	248	Кемеровская область, Кемерово, Кировский район, улица Спартака, 16	f	large
41933	39824	194	Кемеровская область, Кемерово, Заводский район, улица Радищева, 7	f	large
41979	39895	240	Кемеровская область, Кемерово, Кировский район, улица Назарова, 8	f	large
42472	40451	733	Россия, Кемеровская область, Кемерово, Центральный район, улица Кирова, 33/36	f	\N
42074	39965	335	Кемеровская область, Кемерово, Центральный район, улица Гагарина, 146	f	large
42073	39965	334	Кемеровская область, Кемерово, Центральный район, улица Гагарина, 146	f	large
110502	39919	255	Россия, Кемеровская область, Кемерово, Кировский район, улица Василия Толстикова, 1	f	\N
42118	40072	379	Кемеровская область, городской округ Киселевск, Кировский район, Багратиона, 36	f	large
41993	39917	254	Кемеровская область, Кемерово, Кировский район, улица Багратиона, 2	f	large
42101	40047	362	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 52	f	large
42098	40040	359	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 59	f	large
42091	40027	352	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 2	f	large
42089	40024	350	Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 46б	f	large
42094	40022	355	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 105	f	large
42088	40022	349	Россия, Кемеровская область, Кемерово, Рудничный район, проспект Шахтеров, 105	f	large
110595	40050	364	Кемеровская область, Кемерово, проспект Шахтеров, 105, здание школы № 34	f	\N
43334	41458	1575	Россия, Кемеровская область, Тяжинский район	f	large
42528	40526	790	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 28	t	large
42527	40524	789	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 123	f	large
42139	40105	400	Кемеровская область, Кемерово, Центральный район, проспект Ленина, 50	f	large
42069	39997	330	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 62б	f	large
42067	39993	328	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 79	f	large
42066	39993	327	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 79	f	large
42059	39984	320	Кемеровская область, Кемерово, Центральный район, проспект Ленина, 62б	f	large
42042	39960	303	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 160а	f	large
42041	39960	302	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 160а	f	large
42040	39960	301	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 160а	f	large
42022	39948	283	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 130а	f	large
42021	39948	282	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 130а	f	large
42020	39946	281	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 126а	f	large
41953	39856	214	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 55а	f	large
41892	39779	153	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 105	f	large
41891	39777	152	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 84	f	large
41806	39668	67	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 9	t	large
41792	39655	53	Россия, Кемеровская область, Кемерово, Центральный район, проспект Ленина, 8	f	\N
41995	39920	256	Кемеровская область, Кемерово, Кировский район, имени Толстикова Василия, 1	f	large
42070	39999	331	Кемеровская область, Кемерово, Центральный район, город КемеровоГагарина, 118	f	large
42847	40908	1104	Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 73	f	large
42029	39955	290	Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 24в	f	large
42028	39955	289	Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 24в	f	large
42027	39955	288	Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 24в	f	large
42014	39938	275	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 47	f	large
42001	39925	262	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 50а	f	large
42000	39925	261	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 50а	f	large
41999	39925	260	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 50а	f	large
41998	39922	259	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 44б	f	large
41997	39922	258	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 44б	f	large
41996	39922	257	Россия, Кемеровская область, Кемерово, Ленинский район, бульвар Строителей, 44б	f	large
42097	40037	358	Кемеровская область, Кемерово, Рудничный район, Ю. Смирнова, 18а	f	large
42103	40051	365	Кемеровская область, Кемерово, Щегловская, 2	t	large
42093	40030	354	Кемеровская область, Кемерово, Рудничный район, Шахтерская, 9	f	large
42087	40020	348	Кемеровская область, Кемерово, Рудничный район, Черноморская, 38Б	t	large
42130	40089	391	Кемеровская область, Кемерово, Кировский район, Циолковского, 51	f	large
42100	40045	361	Кемеровская область, Кемерово, Рудничный район, Цимлянская, 6	f	large
41803	39665	64	Кемеровская область, Кемерово, Цимлянская, 58	t	large
41976	39891	237	Кемеровская область, Кемерово, Заводский район, Центральная, 157	t	large
41958	39862	219	Кемеровская область, Кемерово, Заводский район, Федоровского, 6	f	large
41957	39862	218	Кемеровская область, Кемерово, Заводский район, Федоровского, 6	f	large
41947	39848	208	Кемеровская область, Кемерово, Заводский район, Угловая, 141	f	large
42071	40000	332	Кемеровская область, Кемерово, Ленинский район, Тухачевского, 10	f	large
42117	40070	378	Кемеровская область, Кемерово, Томская, 20	f	large
42072	40002	333	Кемеровская область, Кемерово, Центральный район, Терешковой, 35	f	large
42134	40095	395	Кемеровская область, Кемерово, Рудничный район, Студенческая улица, 2	f	large
42133	40095	394	Кемеровская область, Кемерово, Рудничный район, Студенческая улица, 2	f	large
42043	39962	304	Россия, Кемеровская область, Кемерово, Центральный район, Советский проспект, 26	f	large
41952	39853	213	Кемеровская область, Кемерово, Центральный район, Соборная, 5а	f	large
42076	40005	337	Кемеровская область, Кемерово, Центральный район, Сибиряков-Гвардейцев, 332	f	large
42075	40005	336	Кемеровская область, Кемерово, Центральный район, Сибиряков-Гвардейцев, 332	f	large
41935	39829	196	Кемеровская область, Кемерово, Заводский район, Сергея Тюленина, 15	f	large
41944	39843	205	Кемеровская область, Кемерово, Заводский район, Семашко, 46	f	large
42052	39974	313	Кемеровская область, Кемерово, Центральный район, Рукавишникова, 15	f	large
42051	39974	312	Кемеровская область, Кемерово, Центральный район, Рукавишникова, 15	f	large
42086	40018	347	Кемеровская область, Кемерово, Рудничный район, Ракитянского, 81	f	large
41934	39826	195	Кемеровская область, Кемерово, Заводский район, Радищева, 5	f	large
42273	40263	534	Кемеровская область, Кемерово, Заводский район, Пушкина, 15	f	large
42271	40258	532	Кемеровская область, Кемерово, Заводский район, Пушкина, 18	f	large
42268	40258	529	Кемеровская область, Кемерово, Заводский район, Пушкина, 18	f	large
42266	40256	527	Кемеровская область, Кемерово, Заводский район, Пушкина, 22	f	large
42110	40061	372	Кемеровская область, Кемерово, Промшоссе,17, стадион Факел	f	\N
41951	39852	212	Кемеровская область, Кемерово, Заводский район, Пролетарская, 13	f	large
41950	39852	211	Кемеровская область, Кемерово, Заводский район, Пролетарская, 13	f	large
41949	39851	210	Кемеровская область, Кемерово, Заводский район, Пролетарская, 10	f	large
41948	39851	209	Кемеровская область, Кемерово, Заводский район, Пролетарская, 10	f	large
41928	39818	189	Кемеровская область, Кемерово, Плодопитомник, 39	f	small
42462	40443	723	Россия, Кемеровская область, Кемерово, Центральный район, Пионерский бульвар, 15	f	\N
42058	39983	319	Россия, Кемеровская область, Кемерово, Центральный район, Пионерский бульвар, 4а	f	large
110449	39821	192	Кемеровская область, Кемерово, Заводский район, Патриотов, 9, центр дополнительного образования детей	f	\N
41932	39823	193	Кемеровская область, Кемерово, Заводский район, Патриотов, 9	f	large
42114	40065	375	Кемеровская область, Кемерово, Рудничный район, Панфилова, 7	f	large
42525	40274	787	Кемеровская область, Кемерово, Заводский район, Осинниковский городской округРадищева, 1	t	large
41776	39642	37	Кемеровская область, Анжеро-Судженск, Мира, 7	f	\N
42046	39967	307	Кемеровская область, Кемерово, Центральный район, Орджоникидзе, 9	f	large
42080	40008	341	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 40а	f	large
42079	40008	340	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 40а	f	large
42064	39989	325	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 39	f	large
42063	39989	324	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 39	f	large
42062	39988	323	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 17а	f	large
42061	39988	322	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 17а	f	large
42060	39985	321	Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 8	f	large
42032	39957	293	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 85а	f	large
42031	39957	292	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 85а	f	large
42030	39957	291	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 85а	f	large
42024	39950	285	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 56б	f	large
42023	39950	284	Россия, Кемеровская область, Кемерово, Центральный район, Октябрьский проспект, 56б	f	large
42092	40029	353	Кемеровская область, Кемерово, Рудничный район, Озерная, 1а	f	large
41945	39845	206	Кемеровская область, Кемерово, Заводский район, Невьянская, 4а	f	large
42102	40049	363	Кемеровская область, Кемерово, Рудничный район, Нахимова, 177	f	large
42095	40033	356	Кемеровская область, Кемерово, Нахимова, 34А	f	large
42035	39958	296	Кемеровская область, Кемерово, Ленинский район, Московский проспект, 25а	f	large
42034	39958	295	Кемеровская область, Кемерово, Ленинский район, Московский проспект, 25а	f	large
42033	39958	294	Кемеровская область, Кемерово, Ленинский район, Московский проспект, 25а	f	large
41968	39877	229	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 9б	f	large
41967	39877	228	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 9б	f	large
41965	39874	226	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 20	f	large
41966	39873	227	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 20	f	large
41964	39873	225	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 20	f	large
41963	39871	224	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 7б	f	large
41962	39868	223	Россия, Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 7б	f	large
41961	39867	222	Кемеровская область, Кемерово, Заводский район, Молодежный проспект, 2а	f	large
41956	39861	217	Кемеровская область, Кемерово, Заводский район, Мичурина, 55	f	large
41813	39675	74	Кемеровская область, Кемерово, Маркса, 108	t	large
41971	39881	232	Кемеровская область, Кемерово, жилой район Пионер, Марата, 1	f	large
42039	39959	300	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 14а	f	large
42038	39959	299	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 14а	f	large
42037	39959	298	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 14а	f	large
42036	39959	297	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 14а	f	large
42026	39952	287	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 29а	f	large
42025	39952	286	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 29а	f	large
42008	39928	269	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34б	f	large
42007	39928	268	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34б	f	large
42006	39928	267	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34б	f	large
42005	39928	266	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34б	f	large
42004	39926	265	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34в	f	large
41773	39640	34	Кемеровская область, Анжеро-Судженск, Мира, 4	f	\N
42003	39926	264	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34в	f	large
42002	39926	263	Россия, Кемеровская область, Кемерово, Ленинский район, Ленинградский проспект, 34в	f	large
42050	39972	311	Россия, Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 44	f	large
42049	39971	310	Россия, Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 44	f	large
41942	39840	203	Россия, Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 83	f	large
41941	39837	202	Кемеровская область, Кемерово, Заводский район, Кузнецкий проспект, 262	f	large
41826	39688	87	Кемеровская область, Кемерово, Крылова, 88	t	large
42054	39977	315	Кемеровская область, Кемерово, Заводский район, Красноармейская, 117	f	large
42055	39978	316	Кемеровская область, Кемерово, Центральный район, Красная улица, 20	f	large
42057	39980	318	Кемеровская область, Кемерово, Центральный район, Красная, 6	f	large
42056	39980	317	Кемеровская область, Кемерово, Центральный район, Красная, 6	f	large
41960	39866	221	Кемеровская область, Кемерово, Заводский район, Котовского, 8	f	large
41959	39866	220	Кемеровская область, Кемерово, Заводский район, Котовского, 8	f	large
41954	39857	215	Кемеровская область, Кемерово, Заводский район, Космическая улица, 2	f	medium
41921	39811	182	Россия, Кемеровская область, Кемерово, Заводский район, Космическая улица, 8	f	large
41923	39813	184	Кемеровская область, Кемерово, Заводский район, Космическая, 31	f	large
41922	39813	183	Кемеровская область, Кемерово, Заводский район, Космическая, 31	f	large
42766	40831	1028	Кемеровская область, Кемерово, Заводский район, Комсомольская, 7	f	large
41943	39842	204	Кемеровская область, Кемерово, Заводский район, Коммунистическая, 59	f	medium
42601	40622	863	Кемеровская область, Кемерово, Центральный район, Кирова, 19	f	large
42531	40531	793	Кемеровская область, Кемерово, Центральный район, Кирова, 27	f	large
42425	40407	686	Кемеровская область, Кемерово, Кирова, 79а, гимназия 44	f	\N
41886	39769	147	Кемеровская область, Кемерово, Центральный район, Кирова, 4	f	large
41832	39694	93	Кемеровская область, Кемерово, Киевская, 38	f	large
42111	40062	373	Кемеровская область, Кемерово, Каракумская, 14, шк.№ 57	f	\N
42274	40264	535	Кемеровская область, Кемерово, Заводский район, Интернациональная, 35	f	large
42595	40615	857	Кемеровская область, Кемерово, Институтская улица, 106	f	large
42584	40601	846	Кемеровская область, Кемерово, Рудничный район, Институтская улица, 15	f	large
42099	40043	360	Кемеровская область, Кемерово, Рудничный район, Институтская, 20	f	large
42096	40036	357	Кемеровская область, Кемерово, Рудничный район, Институтская, 1	f	large
41990	39911	251	Кемеровская область, Кемерово, Кировский район, Инициативная, 125а	f	large
41989	39911	250	Кемеровская область, Кемерово, Кировский район, Инициативная, 125а	f	large
41988	39908	249	Кемеровская область, Кемерово, Кировский район, Инициативная, 90	f	large
41986	39905	247	Кемеровская область, Кемерово, Кировский район, Инициативная, 42	f	large
42112	40141	428	Кемеровская область, Кемерово, Индустриальная улица, 7а	f	large
41937	39832	198	Кемеровская область, Кемерово, Заводский район, Зейская, 54	f	large
42090	40025	351	Кемеровская область, Кемерово, Рудничный район, Елыкаевская улица, 151	f	large
41926	39814	187	Кемеровская область, Кемерово, Заводский район, микрорайон поселок Южный, Дружбы, 5	f	large
41925	39814	186	Кемеровская область, Кемерово, Заводский район, микрорайон поселок Южный, Дружбы, 5	f	large
41924	39814	185	Кемеровская область, Кемерово, Заводский район, микрорайон поселок Южный, Дружбы, 5	f	large
41977	39892	238	Кемеровская область, Кемерово, Докучаева, 1	f	large
41985	39903	246	Кемеровская область, Кемерово, Кировский район, Гурьевская улица, 14а	f	large
110980	41617	1718	Кемеровская область, Кемерово, Заводский район, Грузовая, 1, здание столовой	t	\N
42084	40013	345	Кемеровская область, Кемерово, Городецкая, 1А	t	large
42579	40592	841	Кемеровская область, Кемерово, Кировский район, Гайдара, 1	f	large
42532	40534	794	Кемеровская область, Кемерово, Центральный район, Гагарина, 7	f	large
42065	39991	326	Кемеровская область, Кемерово, Центральный район, Гагарина, 110	f	large
42015	39941	276	Кемеровская область, Кемерово, Ленинский район, Ворошилова, 17	f	large
42013	39937	274	Кемеровская область, Кемерово, Ленинский район, Ворошилова, 10б	f	large
42012	39934	273	Кемеровская область, Кемерово, Ворошилова, 10Б	f	large
42011	39932	272	Кемеровская область, Кемерово, Ленинский район, Ворошилова, 18д	f	large
42010	39932	271	Кемеровская область, Кемерово, Ленинский район, Ворошилова, 18д	f	large
42009	39931	270	Кемеровская область, Кемерово, Ворошилова, 22а	f	large
42078	40006	339	Кемеровская область, Кемерово, Центральный район, Волгоградская, 9а	f	large
42077	40006	338	Кемеровская область, Кемерово, Центральный район, Волгоградская, 9а	f	large
42019	39944	280	Кемеровская область, Кемерово, Центральный район, Волгоградская, 28в	f	large
42018	39944	279	Кемеровская область, Кемерово, Центральный район, Волгоградская, 28в	f	large
42017	39944	278	Кемеровская область, Кемерово, Центральный район, Волгоградская, 28в	f	large
42053	39975	314	Кемеровская область, Кемерово, Центральный район, Весенняя, 28	f	large
42048	39968	309	Кемеровская область, Кемерово, Центральный район, Весенняя, 17	f	large
42047	39968	308	Кемеровская область, Кемерово, Центральный район, Весенняя, 17	f	large
41936	39830	197	Кемеровская область, Кемерово, Заводский район, Веры Волошиной, 13	f	large
41930	39819	191	Кемеровская область, Кемерово, Заводский район, Веры Волошиной, 21	f	large
41929	39819	190	Кемеровская область, Кемерово, Заводский район, Веры Волошиной, 21	f	large
42085	40015	346	Кемеровская область, Кемерово, Рудничный район, Благовещенская улица, 53	t	large
41927	39816	188	Кемеровская область, Кемерово, Заводский район, Бийская, 37	f	large
41974	39888	235	Кемеровская область, Кемерово, Ягуновский жилой район, Белозерная, 42	f	large
41975	39889	236	Кемеровская область, Кемерово, Ягуновский жилой район, Баха, 23	t	large
41973	39885	234	Кемеровская область, Кемерово, Барнаульская, 23	f	large
42614	40637	876	Кемеровская область, Кемерово, Кировский район, Артема, 8	f	large
42083	40012	344	Кемеровская область, Кемерово, Рудничный район, Антипова, 4а	f	large
41992	39915	253	Кемеровская область, Кемерово, Кировский район, Александрова, 3	f	large
41984	39901	245	Кемеровская область, Кемерово, Кировский район, Александрова, 18	f	large
41983	39901	244	Кемеровская область, Кемерово, Кировский район, Александрова, 18	f	large
42045	39964	306	Кемеровская область, Кемерово, А.К.Боброва, 2	f	large
42044	39964	305	Кемеровская область, Кемерово, А.К.Боброва, 2	f	large
42536	40543	798	Кемеровская область, Кемерово, Центральный район, 50 лет Октября, 8	f	large
41982	39900	243	Кемеровская область, Кемерово, Кировский район, 40 лет Октября, 4	f	large
41981	39897	242	Кемеровская область, Кемерово, Кировский район, 40 лет Октября, 18	f	large
41980	39897	241	Кемеровская область, Кемерово, Кировский район, 40 лет Октября, 18	f	large
41978	39894	239	Кемеровская область, Кемерово, Кировский район, 40 лет Октября, 17в	f	large
41940	39835	201	Кемеровская область, Кемерово, Заводский район, 4-я Цветочная, 47	f	large
41939	39835	200	Кемеровская область, Кемерово, Заводский район, 4-я Цветочная, 47	f	large
110456	39834	199	Кемеровская область, Кемерово, Заводский район, 4-я Цветочная, 47, здание школы-№68	f	\N
41972	39882	233	Кемеровская область, Кемерово, жилой район Пионер, 2-я Аральская, 2а	f	large
41913	39803	174	Кемеровская область, Калтан, проспект Мира, 55 А	f	\N
41907	39797	168	Кемеровская область, Калтан, проспект Мира, 10	f	\N
41904	39794	165	Кемеровская область, Калтан, Спортивная, 14	t	\N
41914	39804	175	Кемеровская область, Калтан, Советский переулок, 9 А	f	\N
41900	39791	161	Кемеровская область, Калтан, Пожарского, 20	t	\N
41912	39802	173	Кемеровская область, Калтан, Мира проспект, 55 а	f	\N
110434	39798	169	Кемеровская область, Калтан, Мира, 33Б	f	\N
41906	39796	167	Кемеровская область, Калтан, Комсомольская, 7	f	\N
41910	39800	171	Кемеровская область, Калтан, Калинина, 40	f	\N
41909	39799	170	Кемеровская область, Калтан, Калинина, 38	f	\N
41905	39795	166	Кемеровская область, Калтан, Дзержинского, 3	f	\N
41901	39792	162	Кемеровская область, Калтан, Дзержинского, 19	f	\N
41902	39792	163	Кемеровская область, Калтан, Дзержинского, 19	f	\N
41919	39809	180	Кемеровская область, Калтан, 60 лет Октября, 20	f	\N
42914	40987	1167	Кемеровская область, поселок Ивановка, Центральная, 8	t	small
43037	41118	1281	Кемеровская область, поселок Загорский, 5а	f	large
42834	40899	1095	Кемеровская область, село Елыкаево, Клопова, 16	f	large
43009	41083	1254	Кемеровская область, поселок Елань, Победы, 14	f	large
42574	40582	836	Кемеровская область, поселок Елань, Обручева, 50	f	large
42573	40582	835	Кемеровская область, поселок Елань, Обручева, 50	f	large
41897	39788	158	Кемеровская область, Гурьевск, Мичурина, 11А	t	medium
41885	39768	146	Кемеровская область, Гурьевск, Мира, 1	t	medium
41888	39772	149	Кемеровская область, Гурьевск, Ленина, 30	f	medium
41890	39775	151	Кемеровская область, Гурьевск, Гагарина, 1	t	medium
41896	39787	157	Кемеровская область, Гурьевск, 7 Ноября, 15	t	medium
41879	39757	140	Кемеровская область, Березовский, Здание детского сада Родничок	f	small
41863	39733	124	Кемеровская область, Березовский, проезд Карбышева, 8	f	large
41862	39733	123	Кемеровская область, Березовский, проезд Карбышева, 8	f	large
41864	39734	125	Кемеровская область, Березовский, Школьная, 5	f	large
41870	39742	131	Кемеровская область, Березовский, Шахтеров п-т, 14	f	large
41859	39727	120	Кемеровская область, Березовский, Чехова, 10	t	large
41860	39728	121	Кемеровская область, Березовский, Советская, 5	t	large
41856	39723	117	Кемеровская область, Березовский, Резвых, 34	t	small
41869	39740	130	Кемеровская область, Березовский, Молодежный б-р, 19	f	large
41868	39740	129	Кемеровская область, Березовский, Молодежный б-р, 19	f	large
41867	39738	128	Кемеровская область, Березовский, Мира, 46	f	large
41866	39737	127	Кемеровская область, Березовский, Мира, 13	f	large
41878	39756	139	Кемеровская область, Березовский, Мира, 3	f	large
42798	40863	1060	Кемеровская область, Березовский, Механическая, 17	t	small
41874	39750	135	Кемеровская область, Березовский, Ленина проспект, 66	f	large
41876	39752	137	Кемеровская область, Березовский, Ленина п-т, 41	f	large
41875	39751	136	Кемеровская область, Березовский, Ленина п-т, 66	f	large
41872	39746	133	Кемеровская область, Березовский, Ленина п-т, 20	f	large
41865	39736	126	Кемеровская область, Березовский, Ермака, 1	t	small
41877	39754	138	Кемеровская область, Березовский, Волкова, 5а	f	large
41861	39731	122	Кемеровская область, Березовский, Больничная, 2	f	large
41858	39724	119	Кемеровская область, Березовский, А.Лужбина, 17	f	large
41857	39724	118	Кемеровская область, Березовский, А.Лужбина, 17	t	large
41871	39744	132	Кемеровская область, Березовский, 8 Марта, 14	f	large
41873	39748	134	Кемеровская область, Березовский, 40 лет Победы, 3	f	large
41823	39685	84	Кемеровская область, Белово, Хмельницкого, 49	f	large
41821	39682	82	Кемеровская область, Белово, Тимирязева, 30	t	large
41835	39697	96	Кемеровская область, Белово, поселок Новый Городок, Киевская, 50А	f	large
43003	41077	1248	Кемеровская область, село Атаманово, Центральная, 99б	f	large
41790	39653	51	Кемеровская область, Анжеро-Судженск, проспект Ленина, 18а	f	\N
41749	39609	10	Кемеровская область, Анжеро-Судженск, переулок Силовой, 1	f	\N
41786	39609	47	Кемеровская область, Анжеро-Судженск, переулок Силовой, 1	f	\N
41769	39636	30	Кемеровская область, Анжеро-Судженск, Школьная, 23	f	\N
41770	39636	31	Кемеровская область, Анжеро-Судженск, Школьная, 23	f	\N
41745	39602	6	Кемеровская область, Анжеро-Судженск, Челябинская, 18	f	\N
41743	39602	4	Кемеровская область, Анжеро-Судженск, Челябинская, 18	f	\N
41797	39658	58	Кемеровская область, Анжеро-Судженск, Чекистов, 1	f	\N
41785	39648	46	Кемеровская область, Анжеро-Судженск, Фестивальная, 1А	t	\N
41758	39622	19	Кемеровская область, Анжеро-Судженск, Угольная, 22	f	\N
41793	39622	54	Кемеровская область, Анжеро-Судженск, Угольная, 22	f	\N
41791	39654	52	Кемеровская область, Анжеро-Судженск, Солнечная, 2	f	\N
41750	39611	11	Кемеровская область, Анжеро-Судженск, Силовой, 1	f	\N
41789	39651	50	Кемеровская область, Анжеро-Судженск, Семеновка, 43	f	\N
41783	39646	44	Кемеровская область, Анжеро-Судженск, Северная, 31	f	\N
41778	39644	39	Кемеровская область, Анжеро-Судженск, Рабиновича, 25	f	\N
41781	39644	42	Кемеровская область, Анжеро-Судженск, Рабиновича, 25	f	\N
41747	39606	8	Кемеровская область, Анжеро-Судженск, Прокопьевская, 18А	f	\N
41748	39606	9	Кемеровская область, Анжеро-Судженск, Прокопьевская, 18А	f	\N
41752	39613	13	Кемеровская область, Анжеро-Судженск, Перовская, 27	f	\N
41766	39632	27	Кемеровская область, Анжеро-Судженск, Новобольничная, 79	f	\N
41756	39619	17	Кемеровская область, Анжеро-Судженск, Милицейская, 64	f	\N
41798	39659	59	Кемеровская область, Анжеро-Судженск, Менделеева, 73	f	\N
41742	39600	3	Кемеровская область, Анжеро-Судженск, Львовская, 13	f	\N
41741	39600	2	Кемеровская область, Анжеро-Судженск, Львовская, 13	f	\N
41775	39641	36	Кемеровская область, Анжеро-Судженск, Ленина, 15	f	\N
41762	39627	23	Кемеровская область, Анжеро-Судженск, Ленина, 10	f	\N
41772	39639	33	Кемеровская область, Анжеро-Судженск, Лебедянский переулок, 38	f	\N
41759	39623	20	Кемеровская область, Анжеро-Судженск, Куйбышева, 48	f	\N
41767	39633	28	Кемеровская область, Анжеро-Судженск, Кубанская, 3	f	\N
41777	39643	38	Кемеровская область, Анжеро-Судженск, Коминтерна, 9	f	\N
41771	39638	32	Кемеровская область, Анжеро-Судженск, Китатская, 15а	f	\N
41746	39605	7	Кемеровская область, Анжеро-Судженск, Киселевская, 11А	f	\N
41757	39620	18	Кемеровская область, Анжеро-Судженск, Кемсеть, 16	f	\N
41764	39629	25	Кемеровская область, Анжеро-Судженск, Карла Маркса, 1	f	\N
41796	39629	57	Кемеровская область, Анжеро-Судженск, Карла Маркса, 1	f	\N
41780	39629	41	Кемеровская область, Анжеро-Судженск, Карла Маркса, 1	f	\N
41782	39629	43	Кемеровская область, Анжеро-Судженск, Карла Маркса, 1	f	\N
41765	39631	26	Кемеровская область, Анжеро-Судженск, Динамитная, 33	f	\N
41744	39603	5	Кемеровская область, Анжеро-Судженск, Гурьевская, 3	f	\N
41763	39628	24	Кемеровская область, Анжеро-Судженск, Горького, 30	f	\N
41788	39650	49	Кемеровская область, Анжеро-Судженск, Гайдара, 50	t	\N
41753	39614	14	Кемеровская область, Анжеро-Судженск, Гагарина, 3	f	\N
41755	39617	16	Кемеровская область, Анжеро-Судженск, Восстания, 80	f	\N
41761	39626	22	Кемеровская область, Анжеро-Судженск, Войкова, 39	f	\N
41784	39647	45	Кемеровская область, Анжеро-Судженск, Водоканальная, 53	f	\N
41740	39599	1	Кемеровская область, Анжеро-Судженск, Водоканальная, 29а	f	\N
41760	39624	21	Кемеровская область, Анжеро-Судженск, Ванцетти, 6	f	\N
41754	39616	15	Кемеровская область, Анжеро-Судженск, Бийская, 64	f	\N
41751	39612	12	Кемеровская область, Анжеро-Судженск, Александра Матросова, 107	f	\N
41799	39660	60	Кемеровская область, Анжеро-Судженск, 6 пер. У.Громовой, 1	f	\N
41779	39645	40	Кемеровская область, Анжеро-Судженск, 137 Отд. Стр. Бригады, 7	f	\N
41794	39656	55	Кемеровская область, Анжеро-Судженск, 137 ОСБ, 2	f	\N
42520	40517	782	Кемеровская область, городской округ Осинники, Тайжина, Коммунистическая, 43	f	large
42521	40518	783	Кемеровская область, городской округ Осинники, поселок Тайжина, Дорожная, 2	f	large
42281	40270	542	Кемеровская область, городской округ Мыски, Чувашка, Алтын Шор, 4, клуб	t	\N
42291	40281	552	Кемеровская область, городской округ Мыски, поселок Бородино, Бородинская, 1, школа №10	f	\N
43457	41589	1692	Кемеровская область, Яшкинский район, поселок Яшкинский, Осенняя, 6	f	medium
43448	41578	1683	Кемеровская область, Яшкинский район, поселок Яшкино, Ленинская, 4	f	large
43446	41576	1681	Кемеровская область, Яшкинский район, поселок Яшкино, Куйбышева, 11а	f	large
43447	41577	1682	Кемеровская область, Яшкинский район, поселок Яшкино, Комарова, 24	f	large
43449	41579	1684	Кемеровская область, Яшкинский район, поселок Яшкино, Заводская, 16	f	large
43452	41583	1687	Кемеровская область, Яшкинский район, поселок Яшкино, Больничная, 16	f	medium
43451	41581	1686	Кемеровская область, Яшкинский район, поселок Яшкино, 50 лет Советской власти, 6	f	small
43450	41580	1685	Кемеровская область, Яшкинский район, Яшкино, Вторая, 9	f	large
43465	41598	1700	Кемеровская область, Яшкинский район, поселок Юрты-Константиновы, братьев Сидельниковых, 16	t	small
43480	41615	1715	Кемеровская область, Яшкинский район, Шахтер, Новая, 1	t	small
43460	41593	1695	Кемеровская область, Яшкинский район, поселок Хопкино, Железнодорожная, 23	f	small
43478	41613	1713	Кемеровская область, Яшкинский район, поселок Тутальская, М.Ракевича, 68А	t	small
43479	41614	1714	Кемеровская область, Яшкинский район, Таловка, Школьная, 13д	f	small
43464	41597	1699	Кемеровская область, Яшкинский район, поселок Соломатово, пер.Школьный, 1	f	small
43475	41609	1710	Кемеровская область, Яшкинский район, поселок Северная, Верхняя, 14а	t	small
43476	41610	1711	Кемеровская область, Яшкинский район, поселок Поломошное, Бениваленского, 18	t	medium
43477	41612	1712	Кемеровская область, Яшкинский район, поселок Поломошное, Базарная, 15а	t	medium
43474	41608	1709	Кемеровская область, Яшкинский район, поселок Пашково, Леонова, 11а	f	medium
43471	41605	1706	Кемеровская область, Яшкинский район, поселок Пача, Ленина, 14а	f	medium
43125	41224	1370	Кемеровская область, Яшкинский район, поселок Октябрьский, сельский клуб пос.Октябрьский	t	small
43456	41587	1691	Кемеровская область, Яшкинский район, поселок Нижняя Тайменка, Кирпичная, 3-2	t	small
43473	41607	1708	Кемеровская область, Яшкинский район, поселок Нижнеяшкино, Солнечная, 1	f	small
43481	41616	1716	Кемеровская область, Яшкинский район, поселок Мохово, Центральная, 23-2	t	small
43472	41606	1707	Кемеровская область, Яшкинский район, поселок Морковкино, Молодежная, 16	f	small
43470	41603	1705	Кемеровская область, Яшкинский район, поселок Литвиново, Строительная, 5	t	small
43466	41599	1701	Кемеровская область, Яшкинский район, поселок Литвиново, Октябрьская, 26а	t	medium
43462	41595	1697	Кемеровская область, Яшкинский район, поселок Ленинский, Больничная, 2	f	small
43463	41596	1698	Кемеровская область, Яшкинский район, поселок Кулаково, Береговая, 19	t	small
43469	41602	1704	Кемеровская область, Яшкинский район, поселок Красноселка, Мира, 1	t	medium
43468	41601	1703	Кемеровская область, Яшкинский район, Корчуганово, Клубная, 5а	t	small
43461	41594	1696	Кемеровская область, Яшкинский район, поселок Колмогорово, мкр.Молодежный, 5	f	large
43455	41586	1690	Кемеровская область, Яшкинский район, поселок Зырянка, Центральная, 19А	t	small
43459	41592	1694	Кемеровская область, Яшкинский район, поселок Дубровка, 40 лет Победы, 11Б	f	small
43454	41585	1689	Кемеровская область, Яшкинский район, поселок Власково, Центральная, 17	t	small
43458	41591	1693	Кемеровская область, Яшкинский район, Ботьево, Победы, 19	f	small
43467	41600	1702	Кемеровская область, Яшкинский район, поселок Балахнино, Центральная, 22	t	small
43453	41584	1688	Кемеровская область, Яшкинский район, поселок Акация, Мира, 6	t	medium
43409	41536	1644	Кемеровская область, Яйский район, поселок Яя-Борик, Центральная, 69	f	small
43432	41562	1667	Кемеровская область, Яйский район, Яя, Юбилейный, 12	f	medium
43435	41565	1670	Кемеровская область, Яйский район, Яя, Августовская, 11	f	medium
43440	41570	1675	Кемеровская область, Яйский район, поселок Яя, проспект Ленина, 7	f	medium
43433	41563	1668	Кемеровская область, Яйский район, поселок Яя, Юбилейный, 3	f	small
43431	41561	1666	Кемеровская область, Яйский район, поселок Яя, Юбилейная, 43	f	medium
43438	41568	1673	Кемеровская область, Яйский район, поселок Яя, Школьная, 5	f	large
43430	41560	1665	Кемеровская область, Яйский район, поселок Яя, Трактовая, 160	f	medium
43436	41566	1671	Кемеровская область, Яйский район, поселок Яя, Пионерская, 7	f	medium
43445	41575	1680	Кемеровская область, Яйский район, поселок Яя, Переулок Логовой, 20	f	small
43442	41572	1677	Кемеровская область, Яйский район, поселок Яя, Осоавиахимовская, 4	f	medium
43439	41569	1674	Кемеровская область, Яйский район, поселок Яя, Осоавиахимовская, 36А	f	small
43437	41567	1672	Кемеровская область, Яйский район, поселок Яя, Озерная, 3	f	small
43441	41571	1676	Кемеровская область, Яйский район, поселок Яя, Ленина, 9	f	medium
43434	41564	1669	Кемеровская область, Яйский район, поселок Яя, Западная улица, 76	f	small
43443	41573	1678	Кемеровская область, Яйский район, поселок Яя, Жуковского, 17	f	small
43408	41534	1643	Кемеровская область, Яйский район, поселок Щербиновка, Пролетарская, 18	t	small
43427	41557	1662	Кемеровская область, Яйский район, поселок Улановка, Ленина, 109	f	medium
43417	41544	1652	Кемеровская область, Яйский район, поселок Турат, Майская, 1А	f	small
43425	41555	1660	Кемеровская область, Яйский район, поселок Судженка, Советская, 61А	f	small
43416	41543	1651	Кемеровская область, Яйский район, Судженка, Механическая, 8	f	medium
43414	41541	1649	Кемеровская область, Яйский район, поселок Соболинка, Таежная, 31/2	t	small
43423	41551	1658	Кемеровская область, Яйский район, поселок Сергеевка, Сибирская, 29А	t	small
41795	39657	56	Кемеровская область, Яйский район, поселок Рудничный, Металлургов, 2а	f	\N
43426	41556	1661	Кемеровская область, Яйский район, поселок Ольговка, Октябрьская, 3	t	small
40070	36619	1637	Иркутская область, Усть-Кут, Нефтяников, 12	f	large
43407	41533	1642	Кемеровская область, Яйский район, поселок Новостройка, Гагарина, 13	t	small
43420	41547	1655	Кемеровская область, Яйский район, поселок Новониколаевка, Школьная, 38	f	medium
43415	41542	1650	Кемеровская область, Яйский район, поселок Назаровка, Школьная, 6	t	small
43013	41086	1257	Кемеровская область, Яйский район, поселок Михайловка, Зеленая, 5А	t	small
43429	41559	1664	Кемеровская область, Яйский район, поселок Медведчиково, Центральная, 23	t	small
43422	41550	1657	Кемеровская область, Яйский район, поселок Марьевка, Школьная, 4А	f	small
43421	41549	1656	Кемеровская область, Яйский район, поселок Мальцево, Набережная, 20	t	small
43406	41531	1641	Кемеровская область, Яйский район, поселок Майский, Героев Соцтруда, 32	f	small
41768	39634	29	Кемеровская область, Яйский район, поселок Красная Горка, Тепличная, 8	f	\N
43418	41545	1653	Кемеровская область, Яйский район, поселок Кайла, Садовая, 6	f	medium
43428	41558	1663	Россия, Кемеровская область, Яйский район, поселок Ишим	f	small
43413	41540	1648	Кемеровская область, Яйский район, поселок Емельяновка, Центральная, 1	f	small
43419	41546	1654	Кемеровская область, Яйский район, поселок Данковка, Советская, 46	t	small
43412	41539	1647	Кемеровская область, Яйский район, поселок Вознесенка, Центральная, 20	f	small
43411	41538	1646	Кемеровская область, Яйский район, поселок Верх-Великосельское, Советская, 27	t	small
43410	41537	1645	Кемеровская область, Яйский район, поселок Бекет, Центральная, 6	f	small
43405	41530	1640	Кемеровская область, Яйский район, поселок Безлесный, Ленинградская, 9	f	small
43424	41554	1659	Кемеровская область, Яйский район, Арышево, Арышева, 35	t	small
43386	41507	1621	Кемеровская область, Юргинский район, Юргинский, Дом Культуры	f	large
43382	41503	1617	Кемеровская область, Юргинский район, поселок Юрга II, Дом культуры	f	large
43381	41501	1616	Кемеровская область, Юргинский район, поселок Юрга II, школа	f	medium
42707	40757	968	Кемеровская область, Юргинский район, Юрга, пр.Победы, 15а	f	large
42697	40744	958	Кемеровская область, Юргинский район, Юрга, пр.Победы, 38б	f	large
42692	40735	953	Кемеровская область, Юргинский район, Юрга, пр.Победы, 4б	f	large
42691	40734	952	Кемеровская область, Юргинский район, Юрга, пр.Победы, 10в	f	large
42690	40734	951	Кемеровская область, Юргинский район, Юрга, пр.Победы, 10в	f	large
42687	40729	948	Кемеровская область, Юргинский район, Юрга, пр.Победы, 4в	f	large
42699	40746	960	Кемеровская область, Юргинский район, Юрга, пр.Кузбасский, 14а	f	large
42702	40752	963	Кемеровская область, Юргинский район, Юрга, б-р Металлургов, 5а	f	large
42700	40748	961	Кемеровская область, Юргинский район, Юрга, б-р Металлургов, 2а	f	large
42716	40766	977	Кемеровская область, Юргинский район, Юрга, Шоссейная, 100	f	large
42698	40742	959	Кемеровская область, Юргинский район, Юрга, Фестивальная, 7	f	large
42696	40742	957	Кемеровская область, Юргинский район, Юрга, Фестивальная, 7	f	large
42695	40739	956	Кемеровская область, Юргинский район, Юрга, Фестивальная, 3а	f	large
42713	40763	974	Кемеровская область, Юргинский район, Юрга, Строительная, 25	f	large
42715	40765	976	Кемеровская область, Юргинский район, Юрга, Осенняя, 54	f	large
42704	40754	965	Кемеровская область, Юргинский район, Юрга, Никитина, 30	f	large
42714	40764	975	Кемеровская область, Юргинский район, Юрга, Московская, 55	f	large
42710	40761	971	Кемеровская область, Юргинский район, Юрга, Московская, 33	f	large
42709	40759	970	Кемеровская область, Юргинский район, Юрга, Московская, 35	f	large
42706	40756	967	Кемеровская область, Юргинский район, Юрга, Московская, 50	f	large
42705	40755	966	Кемеровская область, Юргинский район, Юрга, Московская, 48	f	large
42712	40755	973	Кемеровская область, Юргинский район, Юрга, Московская, 48	f	large
42689	40733	950	Кемеровская область, Юргинский район, Юрга, Мира, 11б	f	large
42701	40750	962	Кемеровская область, Юргинский район, Юрга, Машиностроителей, 45а	f	large
42681	40720	942	Кемеровская область, Юргинский район, Юрга, Леонова, 12	f	large
42682	40722	943	Кемеровская область, Юргинский район, Юрга, Ленинградская, 10	f	large
42680	40718	941	Кемеровская область, Юргинский район, Юрга, Ленинградская, 27	f	large
42677	40684	938	Кемеровская область, Юргинский район, Юрга, Ленина, 97	f	large
42678	39664	939	Кемеровская область, Юргинский район, Юрга, Ленина, 55а	f	large
42676	40767	978	Кемеровская область, Юргинский район, Юрга, Колхозная, 21	f	large
42688	40731	949	Кемеровская область, Юргинский район, Юрга, Кирова, 46	f	large
42685	40725	946	Кемеровская область, Юргинский район, Юрга, Кирова, 23	f	large
42684	40724	945	Кемеровская область, Юргинский район, Юрга, Кирова, 14	f	large
42679	40490	940	Кемеровская область, Юргинский район, Юрга, Кирова, 7	f	large
42683	40723	944	Кемеровская область, Юргинский район, Юрга, Исайченко, 11	f	large
42686	40727	947	Кемеровская область, Юргинский район, Юрга, Достоевского, 10	f	large
42711	40758	972	Кемеровская область, Юргинский район, Юрга, Волгоградская, 3	f	large
42708	40758	969	Кемеровская область, Юргинский район, Юрга, Волгоградская, 3	f	large
42703	40753	964	Кемеровская область, Юргинский район, Юрга, Волгоградская, 20	f	large
43380	41500	1615	Кемеровская область, Юргинский район, поселок Юльяновка, фельдшерско - акушерский пункт	t	small
43379	41498	1614	Кемеровская область, Юргинский район, поселок Черный Падун, фельдшерско - акушерский пункт	t	small
43391	41513	1626	Кемеровская область, Юргинский район, поселок Филоново, клуб	t	small
43401	41526	1636	Кемеровская область, Юргинский район, поселок Томилово, клуб	f	small
43403	41528	1638	Кемеровская область, Юргинский район, поселок Талая, школа	f	medium
43383	41504	1618	Кемеровская область, Юргинский район, поселок Старый Шалай, клуб	t	small
43392	41515	1627	Кемеровская область, Юргинский район, поселок Сокольники, клуб	t	small
43385	41506	1620	Кемеровская область, Юргинский район, поселок Сарсаз, Дом Культуры	t	small
43373	41492	1608	Кемеровская область, Юргинский район, поселок Речной, школа	t	small
43404	41529	1639	Россия, Кемеровская область, Юргинский район, поселок Пятково	f	small
43389	41510	1624	Кемеровская область, Юргинский район, поселок Проскоково, школа	f	large
43390	41512	1625	Кемеровская область, Юргинский район, поселок Проскоково, Сосновая, 1	f	small
43393	41516	1628	Кемеровская область, Юргинский район, поселок Приречье, клуб	t	small
43374	41493	1609	Кемеровская область, Юргинский район, Поперечное, Дом Культуры	f	medium
43370	41454	1605	Кемеровская область, Юргинский район, поселок Новороманово, детская школа искуств	f	medium
43400	41525	1635	Кемеровская область, Юргинский район, Мальцево, Дом Культуры	f	small
43399	41524	1634	Кемеровская область, Юргинский район, Макурино, клуб	t	small
43375	41494	1610	Кемеровская область, Юргинский район, поселок Любаровка, клуб	t	small
43378	41497	1613	Кемеровская область, Юргинский район, поселок Линейный, школа	f	small
43387	41508	1622	Кемеровская область, Юргинский район, Лебяжье-Асаново, клуб	f	small
43369	41487	1604	Кемеровская область, Юргинский район, поселок Копылово, магазин ЧП Еровикова	t	small
43396	41520	1631	Кемеровская область, Юргинский район, поселок Кожевниково, клуб	t	small
43384	41505	1619	Кемеровская область, Юргинский район, поселок Зимник, школа	f	medium
43397	41522	1632	Россия, Кемеровская область, Юргинский район, поселок Зеледеево	f	small
43394	41517	1629	Кемеровская область, Юргинский район, поселок Заозерный, школа	f	small
43402	41527	1637	Кемеровская область, Юргинский район, поселок Елгино, школа	f	small
43372	41491	1607	Кемеровская область, Юргинский район, поселок Верх-Тайменка, школа	f	medium
43377	41496	1612	Кемеровская область, Юргинский район, Васильевка, клуб	t	small
43398	41523	1633	Кемеровская область, Юргинский район, Варюхино, клуб	f	small
43368	41486	1603	Кемеровская область, Юргинский район, Большеямное, клуб	f	small
43371	41489	1606	Кемеровская область, Юргинский район, Белянино, школа	f	small
43388	41509	1623	Кемеровская область, Юргинский район, поселок Безменово, Дом Культуры	f	small
43395	41518	1630	Кемеровская область, Юргинский район, поселок Алабучинка, клуб	t	small
43354	41480	1597	Кемеровская область, Чебулинский район, поселок Шестаково, Оренбурская, 2а	f	small
43357	41482	1599	Кемеровская область, Чебулинский район, поселок Чумай, Совхозная, 26	f	small
43344	41481	1598	Кемеровская область, Чебулинский район, поселок Усть-Чебула, Лесная, 1	f	small
43351	41478	1595	Кемеровская область, Чебулинский район, поселок Усть-Серта, Кирова, 4	f	medium
43365	41475	1592	Россия, Кемеровская область, Чебулинский район, поселок Усманка	f	small
43364	41467	1584	Кемеровская область, Чебулинский район, Покровка, Трактовая, 64	f	small
42931	41006	1184	Кемеровская область, Чебулинский район, поселок Покровка, Центральная, 31Б	f	small
43366	41466	1583	Кемеровская область, Чебулинский район, поселок Петропавловка, Центральная, 11	f	small
43346	41468	1585	Кемеровская область, Чебулинский район, поселок Орлово-Розово, Молодежная, 43	f	small
43345	41465	1582	Кемеровская область, Чебулинский район, поселок Новоказанка, Молодежная, 1а	f	small
43355	41472	1589	Кемеровская область, Чебулинский район, поселок Новоивановский, Трактовая, 1	f	medium
43362	41477	1594	Кемеровская область, Чебулинский район, поселок Николаевка, Центральная, 93	f	small
43348	41474	1591	Кемеровская область, Чебулинский район, поселок Михайловка, Набережная, 5	f	small
43353	41479	1596	Кемеровская область, Чебулинский район, поселок Курск-Смоленка, Советская, 58	f	small
43361	41483	1600	Кемеровская область, Чебулинский район, поселок Кураково, Юбилейная, 50а	f	small
43359	41485	1602	Кемеровская область, Чебулинский район, поселок Карачарово, Первомайская, 2	f	small
43358	41484	1601	Кемеровская область, Чебулинский район, поселок Казанка-20, Школьная, 1	t	small
43356	41473	1590	Кемеровская область, Чебулинский район, поселок Ивановка, Кооперативная, 1	f	small
43350	41470	1587	Кемеровская область, Чебулинский район, Дмитриевка, Октябрьская, 2а	f	small
43343	41464	1581	Кемеровская область, Чебулинский район, поселок Верх-Чебула, м-р. Южный, 8	f	medium
43340	41462	1579	Кемеровская область, Чебулинский район, поселок Верх-Чебула, Советская, 8	f	medium
43342	41463	1580	Кемеровская область, Чебулинский район, Верх-Чебула, Советская, 105	f	medium
43363	41476	1593	Кемеровская область, Чебулинский район, поселок Боровой, Центральна, 12	f	small
43349	41469	1586	Кемеровская область, Чебулинский район, поселок Алчедат, Октябрьская, 25	f	small
43347	41471	1588	Кемеровская область, Чебулинский район, поселок Алчедат, Воронова, 24а	f	small
43325	41449	1567	Кемеровская область, Тяжинский район, поселок Чулым, Школьная, 20, администрация	t	small
43300	41403	1542	Кемеровская область, Тяжинский район, поселок Чернышево, Чулымская, 4, СДК	t	small
43323	41447	1565	Кемеровская область, Тяжинский район, поселок Тёплая Речка, Горская, 9, СДК	t	small
43333	41457	1574	Кемеровская область, Тяжинский район, поселок Тяжинский, Чехова, 33, ТСШ №3	f	large
43336	41459	1576	Кемеровская область, Тяжинский район, поселок Тяжинский, Чапаева, 8, ТСШ №2	f	small
43331	41455	1572	Кемеровская область, Тяжинский район, поселок Тяжинский, Советская, 2, администрация пгт. Тяжинский	f	large
43338	41461	1578	Кемеровская область, Тяжинский район, поселок Тяжинский, Радищева, 99, КЭК	f	medium
43337	41460	1577	Кемеровская область, Тяжинский район, поселок Тяжинский, Рабочая, 10, Райгаз	f	small
43330	41453	1571	Кемеровская область, Тяжинский район, поселок Тяжинский, Коммунальная, 1	f	large
43317	41440	1559	Кемеровская область, Тяжинский район, поселок Тяжино-Вершинка, Ленина, 2а, СДК	t	small
43324	41448	1566	Кемеровская область, Тяжинский район, поселок Тисуль, Пушкина, 5 , школа	f	medium
43322	41446	1564	Кемеровская область, Тяжинский район, Ступишино, Кирова, 94, СДК	t	small
43299	41419	1541	Кемеровская область, Тяжинский район, поселок Старый Урюп, Советская, 15, СДК	t	small
43310	41430	1552	Кемеровская область, Тяжинский район, Старый Тяжин, Московская, 64, СДК	t	small
43321	41445	1563	Кемеровская область, Тяжинский район, поселок Сандайка, Береговая, 33, СДК	t	small
43304	41423	1546	Кемеровская область, Тяжинский район, поселок Путятинский, Центральная, 1а, СДК	t	small
43320	41444	1562	Кемеровская область, Тяжинский район, поселок Прокопьево, Курская, 22	t	small
43316	41439	1558	Кемеровская область, Тяжинский район, поселок Преображенка, Советская, 41а, школа	t	medium
43309	41429	1551	Кемеровская область, Тяжинский район, поселок Почаевка, Почаевская, 15, СДК	t	small
43298	41418	1540	Кемеровская область, Тяжинский район, поселок Новопреображенка, Молодежная, 1, СДК	t	small
43315	41438	1557	Кемеровская область, Тяжинский район, поселок Новопокровка (Маковка), Мира, 1а, СДК	t	small
43312	41433	1554	Кемеровская область, Тяжинский район, Новоподзорново, Пролетарская, 2, администрация	t	medium
43326	41450	1568	Кемеровская область, Тяжинский район, поселок Новомарьинка, Центральная, 52, СДК	t	small
43307	41427	1549	Кемеровская область, Тяжинский район, поселок Нововосточный, Советская, 1, СДК	f	small
43314	41436	1556	Кемеровская область, Тяжинский район, Малопичугино, Новая, 19а, СДК	t	small
43303	41422	1545	Кемеровская область, Тяжинский район, поселок Листвянка, Советская, 3, СДК	f	medium
43297	41417	1539	Кемеровская область, Тяжинский район, поселок Кубитет, Рабочая, 22, СДК	t	medium
43306	41425	1548	Кемеровская область, Тяжинский район, Ключевая, 22, контора	t	small
43329	41452	1570	Кемеровская область, Тяжинский район, поселок Итатский, Советская, 333	f	large
43327	41451	1569	Кемеровская область, Тяжинский район, поселок Итатский, Советская, 200, ДК	f	medium
43311	41431	1553	Кемеровская область, Тяжинский район, Изындаево, Школьная, 4	t	small
43302	41421	1544	Кемеровская область, Тяжинский район, поселок Заря, Наберажная, 4, СДК	t	small
43319	41442	1561	Кемеровская область, Тяжинский район, поселок Даниловка, Школьная, 22а , СДК	t	small
43318	41441	1560	Россия, Алтайский край, Ребрихинский район, поселок Георгиевка	t	small
43301	41420	1543	Кемеровская область, Тяжинский район, поселок Валерьяновка, Средняя, 36а, СДК	f	small
43296	41416	1538	Кемеровская область, Тяжинский район, Бороковка, Верхняя, 43, помещение СК	t	small
43305	41424	1547	Кемеровская область, Тяжинский район, Борисоглебское, Центральная, 20	t	small
43313	41434	1555	Кемеровская область, Тяжинский район, поселок Большая Покровка, Некрасова, 12, ДК	t	small
43295	41415	1537	Кемеровская область, Тяжинский район, поселок Акимо-Анненка, Центральная, 21, СДК	f	small
43163	41265	1407	Кемеровская область, Тосненский район, Тарасово, помещение учебного корпуса ПУ-82	t	small
43274	41389	1516	Кемеровская область, Топкинский район, поселок Шишино, Максима Горького, 21	f	large
43287	41406	1529	Кемеровская область, Топкинский район, поселок Черемичкино, м-он Дружба, 7	f	medium
43292	41411	1534	Кемеровская область, Топкинский район, поселок Цыпино, пер.Школьный, 11	t	small
43271	41385	1513	Кемеровская область, Топкинский район, поселок Центральный, Советская, 17	f	medium
43281	41398	1523	Кемеровская область, Топкинский район, поселок Хорошеборка, Школьная, 8	t	small
43267	41380	1509	Россия, Кемеровская область, Топкинский район, поселок Усть-Сосново	t	small
43269	41383	1511	Кемеровская область, Топкинский район, поселок Усть-Сосново, Красная	t	small
43265	41377	1507	Кемеровская область, Топкинский район, поселок Тыхта, Молодежная, 2/2	t	small
43289	41408	1531	Кемеровская область, Топкинский район, поселок Трещевский, Малыхина, 14	f	medium
43252	41342	1493	Кемеровская область, Топкинский район, Топки, м-он Солнечный, 10	f	large
43249	41355	1491	Кемеровская область, Топкинский район, Топки, м-он Красная Горка, 29	f	large
43248	41355	1490	Кемеровская область, Топкинский район, Топки, м-он Красная Горка, 29	f	large
43250	41355	1492	Кемеровская область, Топкинский район, Топки, м-он Красная Горка, 29	f	large
43255	41359	1497	Кемеровская область, Топкинский район, Топки, Топкинская, 2	f	large
43254	41359	1496	Кемеровская область, Топкинский район, Топки, Топкинская, 2	f	large
43260	41369	1502	Кемеровская область, Топкинский район, Топки, Революции, 189	f	large
43259	41367	1501	Кемеровская область, Топкинский район, Топки, Революции, 76	f	large
43258	41366	1500	Кемеровская область, Топкинский район, Топки, Революции, 49	f	large
43256	41362	1498	Кемеровская область, Топкинский район, Топки, Революции, 20	f	large
43246	41353	1488	Кемеровская область, Топкинский район, Топки, Пролетарская, 59	f	large
43243	41349	1485	Кемеровская область, Топкинский район, Топки, Пролетарская, 109	t	large
43247	41354	1489	Кемеровская область, Топкинский район, Топки, Пионерская, 60	f	large
43261	41370	1503	Кемеровская область, Топкинский район, Топки, Микрорайон, 8а	f	large
43244	41350	1486	Кемеровская область, Топкинский район, Топки, Максима Горького, 124а	f	large
43257	41363	1499	Кемеровская область, Топкинский район, Топки, Кузнецкая, 1	f	large
43245	41351	1487	Кемеровская область, Топкинский район, Топки, Калинина, 4	f	large
40072	36621	1639	Иркутская область, Усть-Кут, Набережная, 15	f	large
43251	41357	1494	Кемеровская область, Топкинский район, Топки, Заводская, 11	f	large
43253	41358	1495	Кемеровская область, Топкинский район, Топки, Алма-Атинская, 31	f	large
43278	41394	1520	Кемеровская область, Топкинский район, поселок Терехино, Центральная, 6а	t	small
43263	41373	1505	Кемеровская область, Топкинский район, поселок Среднеберезовский, Майская, 23	f	small
43277	41392	1519	Кемеровская область, Топкинский район, поселок Симаново, Школьная, 7/1	t	small
43270	41384	1512	Кемеровская область, Топкинский район, поселок Романовский, Леонова, 9	t	small
43276	41391	1518	Кемеровская область, Топкинский район, Рассвет, Ленина, 2а	f	medium
43280	41396	1522	Кемеровская область, Топкинский район, Раздолье, Центральная, 16	f	medium
43288	41407	1530	Кемеровская область, Топкинский район, поселок Пинигино, Центральная, 5	t	small
43282	41400	1524	Кемеровская область, Топкинский район, поселок Опарино, Центральная, 6	f	medium
43285	41404	1527	Кемеровская область, Топкинский район, Октябрьский, Центральная, 1а	t	small
43293	41412	1535	Кемеровская область, Топкинский район, поселок Мокроусовский, Центральная, 25	f	small
43286	41405	1528	Кемеровская область, Топкинский район, поселок Медынино, Центральная, 40/1	t	small
43291	41410	1533	Кемеровская область, Топкинский район, поселок Малый Корчуган, Центральная, 31	f	small
43264	41375	1506	Кемеровская область, Топкинский район, поселок Магистральный, Строителей, 19	f	small
43272	41386	1514	Кемеровская область, Топкинский район, Лукошкино, Кооперативная, 2	t	small
43275	41390	1517	Кемеровская область, Топкинский район, поселок Комсомольский, Центральная, 18	f	small
42912	40985	1165	Кемеровская область, Топкинский район, поселок Кокуй, Свободная, 21, квартира 1	t	small
43273	41388	1515	Кемеровская область, Топкинский район, поселок Козлово, Нагорного, 8	t	small
43279	41395	1521	Кемеровская область, Топкинский район, поселок Ключевой, Новая, 13	t	small
43266	41379	1508	Кемеровская область, Топкинский район, поселок Катково, Клубная, 2	t	small
43290	41409	1532	Кемеровская область, Топкинский район, поселок Знаменский, Клубная, 3	t	small
43283	41401	1525	Кемеровская область, Топкинский район, поселок Зарубино, Центральная, 9а	f	large
43284	41402	1526	Кемеровская область, Топкинский район, поселок Глубокое, Рабочая, 54	f	medium
43262	41372	1504	Кемеровская область, Топкинский район, поселок Верх-Падунский, Советская, 3	f	small
43294	41413	1536	Кемеровская область, Топкинский район, Большой Корчуган, Магистральная, 11	f	small
43268	41381	1510	Кемеровская область, Топкинский район, поселок Бархатово, Новая, 4	t	small
43217	41348	1484	Кемеровская область, Тисульский район, Центральный, Леонова, 14	t	small
43239	41345	1481	Кемеровская область, Тисульский район, поселок Утинка, Ленина, 39	f	small
43236	41334	1472	Кемеровская область, Тисульский район, поселок Усть-Колба, Советская, 45	f	small
43231	41329	1468	Кемеровская область, Тисульский район, поселок Усть-Барандат, Центральная, 24	f	small
43238	41340	1477	Кемеровская область, Тисульский район, поселок Третьяково, Береговая, 2А	f	small
43207	41311	1451	Кемеровская область, Тисульский район, поселок Тисуль, Терешковой, 27	f	large
43208	41312	1452	Кемеровская область, Тисульский район, поселок Тисуль, Октябрьская, 44	f	medium
43210	41314	1454	Кемеровская область, Тисульский район, поселок Тисуль, Ленина, 76	f	large
43209	41304	1453	Кемеровская область, Тисульский район, поселок Тисуль, Ленина, 76А	f	large
43205	41308	1449	Кемеровская область, Тисульский район, Тисуль, Заводская, 1	f	large
43206	41310	1450	Кемеровская область, Тисульский район, Тисуль, Гагарина, 17	f	large
43226	41338	1475	Кемеровская область, Тисульский район, поселок Тамбар, Калинина	f	medium
43232	41337	1474	Кемеровская область, Тисульский район, поселок Серебряково, Новая, 35А	t	small
43212	41315	1455	Кемеровская область, Тисульский район, поселок Ржавчик, Клубная, 1	f	small
43225	41336	1473	Кемеровская область, Тисульский район, поселок Полуторник, Школьная, 50	t	medium
43223	41324	1464	Кемеровская область, Тисульский район, поселок Новый Берикуль, Октябрьская, 7	t	small
43224	41325	1465	Кемеровская область, Тисульский район, поселок Московка, СДК	t	small
43219	41320	1461	Кемеровская область, Тисульский район, поселок Макаракский, Советская, 4	t	small
43235	41333	1471	Кемеровская область, Тисульский район, поселок Листвянка, Советская, 19Б	f	small
43242	41331	1469	Кемеровская область, Тисульский район, поселок Куликовка, Советская, 62	f	small
43240	41346	1482	Кемеровская область, Тисульский район, поселок Кондрашка, Школьная, 15	f	small
43216	41317	1458	Кемеровская область, Тисульский район, поселок Комсомольск, Октябрьская, 3	f	small
43221	41318	1459	Кемеровская область, Тисульский район, поселок Комсомольск, Ленина, 25	f	medium
43220	41319	1460	Кемеровская область, Тисульский район, Комсомольск, 1 мая, 2Б	f	small
43237	41332	1470	Кемеровская область, Тисульский район, поселок Колба, Школьная, 36	f	small
43228	41343	1479	Кемеровская область, Тисульский район, поселок Кайчак, Центральная, 1	f	small
43211	41341	1478	Кемеровская область, Тисульский район, поселок Дворниково, Центральная, 41	f	small
43230	41327	1467	Кемеровская область, Тисульский район, Вознесенка, Молодежная, 25	f	small
43241	41347	1483	Кемеровская область, Тисульский район, поселок Большой Берчикуль, пер. Советский, 2	f	small
43229	41326	1466	Кемеровская область, Тисульский район, поселок Большой Барандат, Школьная, 6	f	small
43227	41339	1476	Кемеровская область, Тисульский район, поселок Большепичугино, СДК	t	small
43218	41321	1462	Кемеровская область, Тисульский район, поселок Большая Натальевка, Почтовая, 3	t	small
43222	41323	1463	Кемеровская область, Тисульский район, поселок Берикульский, Горняка, 2	t	medium
43214	41316	1457	Кемеровская область, Тисульский район, поселок Белогорск, Юбилейная, 15	f	large
43213	41316	1456	Кемеровская область, Тисульский район, поселок Белогорск, Юбилейная, 15	f	large
43234	41344	1480	Кемеровская область, Тисульский район, поселок Байла, Трактовая, 20	f	small
43189	41291	1433	Кемеровская область, Таштагольский район, поселок Шерегеш, Советская, Дом творчества	f	\N
43191	41293	1435	Кемеровская область, Таштагольский район, поселок Шерегеш, Дзержинского, Кинотеатр Мустаг	f	\N
43190	41292	1434	Кемеровская область, Таштагольский район, поселок Шерегеш, Гагарина, 6	f	\N
43188	41290	1432	Кемеровская область, Таштагольский район, поселок Шерегеш, 19 партсъезда, Дом культуры Горняк	f	\N
43193	41295	1437	Россия, Кемеровская область, Таштагольский район, поселок Чугунаш	f	\N
43196	41298	1440	Кемеровская область, Таштагольский район, поселок Центральный, Здание школы № 29	t	\N
43187	41289	1431	Кемеровская область, Таштагольский район, поселок Темиртау, Центральная, 30	f	\N
43186	41288	1430	Кемеровская область, Таштагольский район, поселок Темиртау, Центральная, 16-а	f	\N
43178	41280	1422	Россия, Кемеровская область, Таштагольский район, Таштагол	f	\N
43177	41279	1421	Кемеровская область, Таштагольский район, Таштагол, Советская, 36-а	f	\N
43175	41277	1419	Кемеровская область, Таштагольский район, Таштагол, Поспелова, 6	f	\N
43173	41275	1417	Кемеровская область, Таштагольский район, Таштагол, Поспелова, 4	f	\N
43174	41276	1418	Кемеровская область, Таштагольский район, Таштагол, Ноградская, 10	f	\N
43172	41274	1416	Кемеровская область, Таштагольский район, Таштагол, Ноградская, 7	f	\N
43170	41272	1414	Кемеровская область, Таштагольский район, Таштагол, Ленина, 46	f	\N
43169	41271	1413	Кемеровская область, Таштагольский район, Таштагол, Ленина, 28	f	\N
43179	41281	1423	Кемеровская область, Таштагольский район, Таштагол, Коммунистическая, 26	f	\N
43167	41269	1411	Кемеровская область, Таштагольский район, Таштагол, Калинина, 16, 652990	f	\N
43201	41303	1445	Кемеровская область, Таштагольский район, поселок Спасск, Дом культуры Юность 652990	f	\N
43185	41287	1429	Кемеровская область, Таштагольский район, поселок Мундыбаш, Школьная, Здание школы № 95	f	\N
43184	41286	1428	Кемеровская область, Таштагольский район, поселок Мундыбаш, Октябрьская, Курсовая сеть аглофабрики	f	\N
43183	41285	1427	Кемеровская область, Таштагольский район, поселок Мундыбаш, Ленина, 2	f	\N
43195	41297	1439	Кемеровская область, Таштагольский район, поселок Калары, клуб	t	\N
43180	41282	1424	Кемеровская область, Таштагольский район, поселок Каз, Победы, 10	f	\N
43182	41284	1426	Кемеровская область, Таштагольский район, поселок Каз, Ленина, Клуб Юбилейный	f	\N
43181	41283	1425	Кемеровская область, Таштагольский район, поселок Каз, Горноспасательная, 1-а	f	\N
42154	40120	415	Кемеровская область, Таштагольский район, поселок Веселая Грива, Веселая, 41	f	large
43197	41299	1441	Кемеровская область, Таштагольский район, поселок Базанча, Клуб поселка Базанча	t	\N
43198	41300	1442	Кемеровская область, Таштагольский район, поселок Амзас, Здание школы № 164	t	\N
43199	41301	1443	Кемеровская область, Таштагольский район, поселок Алтамаш, Здание администрации поселка Алтамаш	t	\N
43161	41263	1405	Кемеровская область, Промышленновский район, поселок Шуринка, Дом Культуры деревни Шуринка	t	small
43153	41255	1397	Кемеровская область, Промышленновский район, поселок Цветущий, Клуб	t	small
43123	41222	1368	Кемеровская область, Промышленновский район, поселок Ушаково, медпункт	t	small
43128	41227	1373	Кемеровская область, Промышленновский район, Уфимцево, Дом культуры деревни Уфимцево	t	medium
43166	41268	1410	Кемеровская область, Промышленновский район, поселок Усть-Тарсьма, сельский клуб	t	small
43165	41267	1409	Кемеровская область, Промышленновский район, Усть-Каменка, МОУ Усть-Каменская ООШ	t	small
43155	41257	1399	Кемеровская область, Промышленновский район, поселок Труд, клуб села Труд	t	small
43164	41266	1408	Кемеровская область, Промышленновский район, поселок Титово, Дом Культуры	f	medium
43159	41261	1403	Кемеровская область, Промышленновский район, поселок Тарасово, Тарасовская СОШ	t	medium
43143	41243	1387	Кемеровская область, Промышленновский район, поселок Соревнование, МОУ Соревнованская ООШ	t	small
43131	41230	1376	Кемеровская область, Промышленновский район, поселок Ранний, помещение клуба поселка Ранний	t	small
43132	41232	1377	Кемеровская область, Промышленновский район, поселок Пьяново, Дом культуры	t	medium
43149	41250	1393	Кемеровская область, Промышленновский район, Пушкино, сельский клуб деревни Пушкино	t	small
43154	41256	1398	Кемеровская область, Промышленновский район, Протопопово, клуб деревни Протопопово	t	small
43118	41214	1362	Кемеровская область, Промышленновский район, поселок Промышленная, помещение МОУ СОШ № 3	t	large
43116	41212	1360	Кемеровская область, Промышленновский район, поселок Промышленная	t	large
43115	41211	1359	Кемеровская область, Промышленновский район, поселок Промышленная, Дворец Культуры	f	large
43114	41210	1358	Кемеровская область, Промышленновский район, поселок Промышленная	t	large
43112	41208	1356	Кемеровская область, Промышленновский район, поселок Промышленная, помещение МОУ СОШ № 2	t	large
43111	41207	1355	Кемеровская область, Промышленновский район, поселок Промышленная, контора ЗАО Ударник полей	f	large
43117	41213	1361	Кемеровская область, Промышленновский район, Промышленная, помещение 6-го сетевого участка	f	large
43113	41209	1357	Кемеровская область, Промышленновский район, Промышленная, помещение столовой ПМС-20	t	large
43120	41218	1364	Кемеровская область, Промышленновский район, поселок Прогресс, Дом культуры деревни Прогресс	t	small
43124	41223	1369	Кемеровская область, Промышленновский район, поселок Портнягино, медпункт	t	small
43127	41226	1372	Кемеровская область, Промышленновский район, Пор-Искитим, Дом культуры деревни Пор-Искитима	t	medium
43147	41248	1391	Тверская область, Ржевский район, поселок Плотниково	t	large
43146	41246	1390	Кемеровская область, Промышленновский район, поселок Плотниково, Заринский городской Дом Культуры	t	large
43142	41242	1386	Кемеровская область, Промышленновский район, поселок Плотниково, помещение железнодорожного вокзала	t	medium
43141	41241	1385	Кемеровская область, Промышленновский район, поселок Плотниково, Плотниковская библиотека (бывшее здание школы №2)	t	medium
43089	41176	1333	Кемеровская область, Промышленновский район, поселок Первомайский, основная школа п.Первомайский	f	small
43150	41251	1394	Кемеровская область, Промышленновский район, поселок Пархаевка, сельский клуб деревни Пархаевка	t	small
43136	41236	1380	Кемеровская область, Промышленновский район, поселок Падунская, Падунский сельский Дом культуры	t	small
43134	41233	1378	Кемеровская область, Промышленновский район, поселок Падунская, МОУ Падунская СОШ	t	medium
66529	41247	1375	Кемеровская область, Промышленновский район, поселок Окунево, помещение МОУ Окуневская СОШ	t	small
43129	41228	1374	Кемеровская область, Промышленновский район, поселок Окунево, Дом культуры села Окунево	t	medium
43308	41428	1550	Кемеровская область, Промышленновский район, поселок Октябрьский, Школьная, 2а, СДК	t	small
43137	41237	1381	Кемеровская область, Промышленновский район, Озерки, сельский Дом культуры деревни Озерки	t	small
43157	41259	1401	Кемеровская область, Промышленновский район, Морозово, Дом Культуры села Морозово	t	small
43126	41225	1371	Кемеровская область, Промышленновский район, Лебеди, здание администрации Лебедевской сельского поселения	t	medium
43148	41249	1392	Кемеровская область, Промышленновский район, поселок Краснинское, Дом Культуры села Краснинское	f	medium
43145	41245	1389	Кемеровская область, Промышленновский район, поселок Колычево, сельский Дом Культуры деревни Колычево	f	small
43144	41244	1388	Кемеровская область, Промышленновский район, поселок Колычево, сельский Дом культуры деревни Колычево	t	medium
43151	41252	1395	Кемеровская область, Промышленновский район, поселок Каменка, Дом Культуры деревни Каменка	t	medium
43162	41264	1406	Кемеровская область, Промышленновский район, поселок Калтышино, Калтышинский сельский клуб	t	small
43122	41221	1367	Кемеровская область, Промышленновский район, поселок Калинкино, Помещение молодежного центра дер.Калинкино	t	medium
43152	41254	1396	Кемеровская область, Промышленновский район, поселок Иваново-Родионовский, Сельский клуб	t	small
43121	41219	1365	Кемеровская область, Промышленновский район, поселок Журавлево, Дом культуры села Журавлево	t	medium
43158	41260	1402	Кемеровская область, Промышленновский район, поселок Еремино, Дом культуры деревни Еремино	t	small
43138	41238	1382	Кемеровская область, Промышленновский район, поселок Денисовка, помещение сельского клуба	t	small
43160	41262	1404	Кемеровская область, Промышленновский район, поселок Голубево, Дом Культуры поселка Голубево	t	small
43135	41235	1379	Кемеровская область, Промышленновский район, поселок Васьково, Васьковский сельский Дом Культуры	f	medium
43119	41216	1363	Кемеровская область, Промышленновский район, поселок Ваганово, Дом культуры села Ваганово	t	large
43140	41240	1384	Кемеровская область, Промышленновский район, поселок Березово, бывшее здание Березовской начальной школы	t	small
43041	41125	1285	Кемеровская область, Промышленновский район, поселок Березово, Школьная, 8	t	small
43156	41258	1400	Кемеровская область, Промышленновский район, поселок Байрак, клуб деревни Байрак	t	small
43139	41239	1383	Кемеровская область, Промышленновский район, поселок Абышево, Абышевский сельский Дом культуры	f	medium
43087	41174	1331	Кемеровская область, Прокопьевский район, поселок Ясная Поляна, СДК п.Ясная Поляна	f	medium
43093	41180	1337	Кемеровская область, Прокопьевский район, поселок Школьный, общежитие Аграрного колледжа	f	small
43090	41177	1334	Кемеровская область, Прокопьевский район, поселок Шарап, СДК	f	medium
43082	41166	1326	Кемеровская область, Прокопьевский район, поселок Чапаевский, библиотека п.Чапаевский	t	small
43110	41205	1354	Кемеровская область, Прокопьевский район, Углерод, здание ж/д станции Углерод	f	small
43070	41155	1315	Кемеровская область, Прокопьевский район, поселок Тыхта, СДК п.Тыхта	t	small
43108	41203	1352	Кемеровская область, Прокопьевский район, поселок Тырган, здание ж/д станции Тырган	t	small
43107	41201	1351	Кемеровская область, Прокопьевский район, поселок Трудармейский, администрация п.Трудармейский	f	large
43106	41198	1350	Кемеровская область, Прокопьевский район, поселок Трудармейский, начальная школа п.Трудармейский	t	large
43109	41204	1353	Кемеровская область, Прокопьевский район, Трудармейский, библиотека п.Трудармейский	f	large
43084	41160	1328	Кемеровская область, Прокопьевский район, поселок Тихоновка, СДК п.Тихоновка	f	small
43076	41160	1320	Кемеровская область, Прокопьевский район, поселок Тихоновка, СДК п.Тихоновка	t	small
43085	41171	1329	Кемеровская область, Прокопьевский район, Терентьевское, ДК с.Терентьевское	f	large
43083	41168	1327	Кемеровская область, Прокопьевский район, поселок Терентьевское, здание ГРП	f	medium
43086	41172	1330	Кемеровская область, Прокопьевский район, поселок Терентьевская, СДК	t	medium
43074	41158	1318	Кемеровская область, Прокопьевский район, поселок Соколово, средняя школа	f	small
43099	41187	1343	Кемеровская область, Прокопьевский район, поселок Смышляево, СДК	f	small
43079	41163	1323	Кемеровская область, Прокопьевский район, поселок Севск, библиотека п.Севск	f	medium
43100	41188	1344	Кемеровская область, Прокопьевский район, поселок Свободный, СДК	f	small
43077	41161	1321	Кемеровская область, Прокопьевский район, поселок Пушкино, СДК п.Пушкино	t	large
42588	40607	850	Кемеровская область, Прокопьевский район, Прокопьевский городской округ, Институтская, 24	f	large
42572	40581	834	Кемеровская область, Прокопьевский район, Прокопьевск, проспект Строителей, 25	f	large
42571	40581	833	Кемеровская область, Прокопьевский район, Прокопьевск, проспект Строителей, 25	f	large
42580	40594	842	Кемеровская область, Прокопьевский район, Прокопьевск, проспект Ленина, 17	f	large
42589	40608	851	Кемеровская область, Прокопьевский район, Прокопьевск, пр.Гагарина, 8	f	large
42610	40633	872	Кемеровская область, Прокопьевский район, Прокопьевск, пер. Соколовский, 1	t	medium
42594	40614	856	Кемеровская область, Прокопьевский район, Прокопьевск, Шишкина, 21	f	large
42642	40679	903	Кемеровская область, Прокопьевский район, Прокопьевск, Черных, 3	f	large
42635	40667	897	Кемеровская область, Прокопьевский район, Прокопьевск, Цикличная, 27	f	large
42634	40667	896	Кемеровская область, Прокопьевский район, Прокопьевск, Цикличная, 27	f	large
42643	40680	905	Кемеровская область, Прокопьевский район, Прокопьевск, Тюленевка, 5	t	large
42609	40632	871	Кемеровская область, Прокопьевский район, Прокопьевск, Союзная, 6	f	large
42608	40631	870	Кемеровская область, Прокопьевский район, Прокопьевск, Союзная, 4	f	large
42607	40629	869	Кемеровская область, Прокопьевский район, Прокопьевск, Союзная, 59	f	large
42598	40619	860	Кемеровская область, Прокопьевский район, Прокопьевск, Сафоновская, 28	f	large
42600	40621	862	Кемеровская область, Прокопьевский район, Прокопьевск, Революции, 67	f	large
42596	40617	858	Кемеровская область, Прокопьевский район, Прокопьевск, Проспектная, 111	f	large
42583	40600	845	Кемеровская область, Прокопьевский район, Прокопьевск, Прокопьевский переулок, 15	f	large
42581	40596	843	Кемеровская область, Прокопьевский район, Прокопьевск, Прокопьевский переулок, 14	f	large
42650	40688	912	Кемеровская область, Прокопьевский район, Прокопьевск, Прокопьевская, 75	f	large
42592	40612	854	Кемеровская область, Прокопьевский район, Прокопьевск, Подольская, 10	f	medium
42639	40676	901	Кемеровская область, Прокопьевский район, Прокопьевск, Пионерская, 68а	f	large
42638	40674	900	Кемеровская область, Прокопьевский район, Прокопьевск, Пионерская, 36	f	large
42637	40672	899	Кемеровская область, Прокопьевский район, Прокопьевск, Пионерская, 15	f	large
42627	40656	889	Кемеровская область, Прокопьевский район, Прокопьевск, Печорская, 4	f	large
42585	40602	847	Кемеровская область, Прокопьевский район, Прокопьевск, Петренко, 20	f	large
42577	40587	839	Кемеровская область, Прокопьевский район, Прокопьевск, Обручева, 65	f	large
42576	40587	838	Кемеровская область, Прокопьевский район, Прокопьевск, Обручева, 65	f	large
42575	40586	837	Кемеровская область, Прокопьевский район, Прокопьевск, Обручева, 53	f	large
42605	40627	867	Кемеровская область, Прокопьевский район, Прокопьевск, Морозовой, 62	f	large
42545	40552	807	Кемеровская область, Прокопьевский район, Прокопьевск, Молодогвардейцев, 30	f	\N
42636	40669	898	Кемеровская область, Прокопьевский район, Прокопьевск, Маганак, 47	f	large
42631	40662	893	Кемеровская область, Прокопьевский район, Прокопьевск, Крестьянская, 39	f	large
42623	40649	885	Кемеровская область, Прокопьевский район, Прокопьевск, Космонавта Волынова, 9	f	large
42624	40650	886	Кемеровская область, Прокопьевский район, Прокопьевск, Комсомольская, 4	f	large
42591	40610	853	Кемеровская область, Прокопьевский район, Прокопьевск, Институтская, 49	f	large
42590	40610	852	Кемеровская область, Прокопьевский район, Прокопьевск, Институтская, 49	f	large
42649	40687	911	Кемеровская область, Прокопьевский район, Прокопьевск, Зенковская, 21	f	medium
42582	40598	844	Кемеровская область, Прокопьевский район, Прокопьевск, Жолтовского, 42	f	large
39169	35803	736	Иркутская область, Иркутск, Радищева, 132	f	large
42567	40578	829	Кемеровская область, Прокопьевский район, Прокопьевск, Есенина, 80А	f	large
42568	40577	830	Кемеровская область, Прокопьевский район, Прокопьевск, Есенина, 66	f	large
42628	40659	890	Кемеровская область, Прокопьевский район, Прокопьевск, Дружбы, 27	f	large
42645	40682	907	Кемеровская область, Прокопьевский район, Прокопьевск, Гончарова, 78	f	medium
42644	40681	906	Кемеровская область, Прокопьевский район, Прокопьевск, Главная, 274	f	large
42578	40589	840	Кемеровская область, Прокопьевский район, Прокопьевск, Гайдара, 8	f	large
42597	40618	859	Кемеровская область, Прокопьевский район, Прокопьевск, Высокогорная, 2А	f	large
42648	40686	910	Кемеровская область, Прокопьевский район, Прокопьевск, Ветеранов, 20	f	medium
42653	40692	915	Кемеровская область, Прокопьевский район, Прокопьевск, 2-я Ярославская, 29	f	large
42565	40573	827	Кемеровская область, Прокопьевский район, Прокопьевск, 10-й микрорайон, 15а	f	large
42564	40572	826	Кемеровская область, Прокопьевский район, Прокопьевск, 10-й микрорайон, 18В	f	large
42563	40570	825	Кемеровская область, Прокопьевский район, Прокопьевск, 10-й микрорайон, 45	f	large
42562	40570	824	Кемеровская область, Прокопьевский район, Прокопьевск, 10-й микрорайон, 45	f	large
43088	41175	1332	Кемеровская область, Прокопьевский район, поселок Плодопитомник, СДК	f	small
43098	41186	1342	Кемеровская область, Прокопьевский район, поселок Новосафоновский, РДК п.Новосафоновский	t	large
43097	41185	1341	Кемеровская область, Прокопьевский район, поселок Новорождественское, ДК с.Новорождественское	t	small
43104	41195	1348	Кемеровская область, Прокопьевский район, поселок Михайловка, СДК с.Михайловка	f	medium
43092	41179	1336	Кемеровская область, Прокопьевский район, поселок Маяковка, СДК п.Маяковка	t	small
43071	41156	1316	Кемеровская область, Прокопьевский район, поселок Майский, СДК п.Майский	t	small
43091	41178	1335	Кемеровская область, Прокопьевский район, поселок Лучшево, СДК с.Лучшево	f	small
43073	41157	1317	Кемеровская область, Прокопьевский район, поселок Лукьяновка, СДК д.Лукьяновка	t	small
43080	41164	1324	Кемеровская область, Прокопьевский район, поселок Кутоново, СДК	t	small
42172	40149	434	Россия, Кемеровская область, Прокопьевский район, поселок Краснобродский	t	medium
42171	40147	433	Россия, Кемеровская область, Прокопьевский район, поселок Краснобродский	t	medium
42170	40145	432	Кемеровская область, Прокопьевский район, поселок Краснобродский, Новая, 45	f	large
42169	40144	431	Кемеровская область, Прокопьевский район, поселок Краснобродский, Новая, 59	f	large
42167	40142	429	Кемеровская область, Прокопьевский район, поселок Краснобродский, Новая, 44	f	large
42173	40151	435	Кемеровская область, Прокопьевский район, поселок Краснобродский, Линейная, 8	t	medium
42168	40143	430	Кемеровская область, Прокопьевский район, поселок Краснобродский, Комсомольская, 24	f	large
43069	41154	1314	Кемеровская область, Прокопьевский район, поселок Котино, ДК	f	medium
43081	41165	1325	Кемеровская область, Прокопьевский район, поселок Кольчегиз, СДК п.Кольчегиз	f	small
43075	41159	1319	Кемеровская область, Прокопьевский район, поселок Карагайла, СДК с.Карагайла	f	medium
43105	41197	1349	Кемеровская область, Прокопьевский район, поселок Каменный Ключ, здание администрации	t	medium
43094	41181	1338	Кемеровская область, Прокопьевский район, поселок Калачево, СДК п.Калачево	f	large
43095	41183	1339	Кемеровская область, Прокопьевский район, Калачево, магазин Сельпо	t	small
43096	41184	1340	Кемеровская область, Прокопьевский район, поселок Индустрия, СДК п.Индустрия	t	small
42146	40114	407	Кемеровская область, Прокопьевский район, Верх-Чумыш, Центральная, 2а	t	small
43101	41190	1345	Кемеровская область, Прокопьевский район, поселок Верх-Егос, СДК 	f	medium
43078	41162	1322	Кемеровская область, Прокопьевский район, поселок Бурлаки, СДК	f	medium
43102	41192	1346	Кемеровская область, Прокопьевский район, поселок Большой Керлегеш, СДК	t	small
43068	41153	1313	Кемеровская область, Прокопьевский район, поселок Большая Талда	f	large
42280	40269	541	Кемеровская область, Новокузнецкий район, поселок Чуазас, Центральная, 18, клуб	t	\N
43033	41113	1277	Кемеровская область, Новокузнецкий район, поселок Чичербаево, Центральная, 58-2	t	small
43044	41089	1288	Кемеровская область, Новокузнецкий район, поселок Чистогорский, 35Б	f	large
43043	41089	1287	Кемеровская область, Новокузнецкий район, поселок Чистогорский, 35Б	t	large
43047	41130	1291	Кемеровская область, Новокузнецкий район, Чистая Грива, 23А	t	small
43053	41136	1297	Россия, Кемеровская область, Новокузнецкий район, поселок Усть-Аскарлы	t	small
43032	41112	1276	Кемеровская область, Новокузнецкий район, поселок Успенка, Центральная, 10	t	small
43046	41129	1290	Кемеровская область, Новокузнецкий район, поселок Терехино, Центральная, 29-2	t	small
43014	41087	1258	Кемеровская область, Новокузнецкий район, поселок Таргайский Дом Отдыха, Лесная, 13	f	small
43005	41079	1250	Кемеровская область, Новокузнецкий район, поселок Тальжино, Центральная, 2Б	t	small
43018	41092	1262	Кемеровская область, Новокузнецкий район, поселок Тайлеп, Школьная, 2	f	small
43029	41108	1273	Кемеровская область, Новокузнецкий район, поселок Тагарыш, 6-2	t	small
43022	41097	1266	Кемеровская область, Новокузнецкий район, поселок Степной, Старцева, 15	f	large
43030	41109	1274	Кемеровская область, Новокузнецкий район, поселок Старое Ерунаково, Вокзальная, 11	t	small
43011	41085	1256	Кемеровская область, Новокузнецкий район, Сосновка, Кузнецкая, 10	f	large
43045	41128	1289	Кемеровская область, Новокузнецкий район, поселок Сидорово, Куюкова, 34А	t	medium
43025	41101	1269	Кемеровская область, Новокузнецкий район, поселок Северный, 201	t	small
43058	41143	1302	Кемеровская область, Новокузнецкий район, поселок Сары-Чумыш, Советская, 29	f	small
41915	39805	176	Кемеровская область, Новокузнецкий район, Сарбала, Советская, 11 А	t	\N
43035	41116	1279	Кемеровская область, Новокузнецкий район, поселок Рассвет, Центральная, 20А	f	medium
42296	40288	557	Россия, Кемеровская область, Новокузнецкий район, поселок Подобас	f	\N
43038	41119	1282	Кемеровская область, Новокузнецкий район, поселок Подгорный, Центральная, 1А	t	small
43050	41133	1294	Кемеровская область, Новокузнецкий район, поселок Осиновое Плесо, Суворова, 14	t	medium
42927	41002	1180	Кемеровская область, Новокузнецкий район, поселок Новый, Луговая, 1	f	small
110706	40360	635	Кемеровская область, Новокузнецкий район, Новокузнецк, пр. Авиаторов, 47, здание школы №107	f	\N
42431	40413	692	Кемеровская область, Новокузнецкий район, Новокузнецк, Тольятти, 3, школа №103	f	\N
42460	40440	721	Кемеровская область, Новокузнецкий район, Новокузнецк, Покрышкина, 36, педучилище№1	f	\N
42459	40440	720	Кемеровская область, Новокузнецкий район, Новокузнецк, Покрышкина, 36, педучилище№1	f	\N
42326	40308	587	Кемеровская область, Новокузнецкий район, Новокузнецк, Олимпийская, 20	f	\N
42327	40308	588	Кемеровская область, Новокузнецкий район, Новокузнецк, Олимпийская, 20	f	\N
42325	40308	586	Кемеровская область, Новокузнецкий район, Новокузнецк, Олимпийская, 20	f	\N
42519	40514	780	Кемеровская область, Новокузнецкий район, Новокузнецк, Ливинская, 38	t	large
42494	40484	755	Кемеровская область, Новокузнецкий район, Новокузнецк, Лермонтова, 6	t	medium
42476	40455	737	Кемеровская область, Новокузнецкий район, Новокузнецк, Кутузова, 44а, гимназия 17	f	\N
42414	40395	674	Кемеровская область, Новокузнецкий район, Новокузнецк, Интернатная, 2	t	medium
42434	40416	695	Кемеровская область, Новокузнецкий район, Новокузнецк, Дружбы, 42а, школа 101	f	\N
42433	40416	694	Кемеровская область, Новокузнецкий район, Новокузнецк, Дружбы, 42а, школа 101	f	\N
42350	40327	611	Кемеровская область, Новокузнецкий район, Новокузнецк, 40 лет ВЛКСМ, 76а	f	large
42349	40327	610	Кемеровская область, Новокузнецкий район, Новокузнецк, 40 лет ВЛКСМ, 76а	f	large
43017	41091	1261	Кемеровская область, Новокузнецкий район, поселок Николаевка, Школьная, 1	f	small
43028	41107	1272	Кемеровская область, Новокузнецкий район, поселок Недорезово (Пашкино), Центральная, 11	t	medium
43036	41117	1280	Кемеровская область, Новокузнецкий район, Мир, Куйбышева, 8	f	small
41917	39807	178	Кемеровская область, Новокузнецкий район, Малиновка, 60 лет Октября, 19	f	\N
41918	39808	179	Россия, Кемеровская область, Новокузнецкий район, поселок Малиновка	f	\N
43066	14675	1311	Кемеровская область, Новокузнецкий район, поселок Лыс, Мира, 22	f	small
43015	41088	1259	Кемеровская область, Новокузнецкий район, поселок Куртуково, Полосухина, 9А	f	medium
43065	41151	1310	Кемеровская область, Новокузнецкий район, поселок Кузедеево, Яценко, 22	f	small
43061	41147	1306	Кемеровская область, Новокузнецкий район, поселок Кузедеево, Станционная, 15	t	small
43062	41148	1307	Кемеровская область, Новокузнецкий район, поселок Кузедеево, Октябрьская, 8-1	f	medium
43063	41149	1308	Кемеровская область, Новокузнецкий район, поселок Кузедеево, Ленинская, 43	f	large
43064	41150	1309	Кемеровская область, Новокузнецкий район, поселок Кузедеево, 40 лет Победы, 16/2	f	small
43048	41131	1292	Кемеровская область, Новокузнецкий район, поселок Кругленькое, Мира, 2	t	small
43026	41104	1270	Кемеровская область, Новокузнецкий район, Красулино, Центральная, 4	f	medium
43057	41142	1301	Кемеровская область, Новокузнецкий район, поселок Красная Орловка, 60 лет Октября, 1Б	f	small
43039	41121	1283	Кемеровская область, Новокузнецкий район, поселок Костенково, Школьная, 33	f	medium
43040	41122	1284	Кемеровская область, Новокузнецкий район, поселок Костенково, Центральная, 1А	f	small
43059	41145	1304	Кемеровская область, Новокузнецкий район, поселок Кандалеп, Школьная, 15	t	small
43031	41110	1275	Кемеровская область, Новокузнецкий район, поселок Казанково, Юбилейная, 19	f	medium
43020	41095	1264	Кемеровская область, Новокузнецкий район, село Ильинка, Жиха, 12	f	large
43056	41141	1300	Кемеровская область, Новокузнецкий район, поселок Зеленый Луг, Новая, 5-2	t	small
43019	41093	1263	Кемеровская область, Новокузнецкий район, поселок Заречный, Юный Запсибовец	t	small
43054	41139	1298	Кемеровская область, Новокузнецкий район, поселок Загадное, Центральная, 34	t	small
43049	41132	1293	Кемеровская область, Новокузнецкий район, Есаулка, Лесная, 8	t	small
43034	41115	1278	Кемеровская область, Новокузнецкий район, Бунгур, Ленинская, 16А	t	small
43007	41081	1252	Кемеровская область, Новокузнецкий район, поселок Боровково, Школьная, 13Б	t	small
42297	40289	558	Кемеровская область, Новокузнецкий район, Берензас, Речная, 9а, клуб	t	\N
110906	41144	1303	Кемеровская область, Новокузнецкий район, Бенжереп 2-й, Зеленая, 2, здание ФАПа	t	\N
43060	41146	1305	Кемеровская область, Новокузнецкий район, поселок Бенжереп 1-й, Центральная, 18	f	small
43008	41082	1253	Кемеровская область, Новокузнецкий район, поселок Безруково, Коммунальная, 2	f	medium
43006	41080	1251	Кемеровская область, Новокузнецкий район, поселок Безруково, Коммунальная, 4	f	medium
43021	41096	1265	Кемеровская область, Новокузнецкий район, поселок Бедарево, Центральная, 12-1	t	small
43002	41076	1247	Кемеровская область, Новокузнецкий район, поселок Баевка, Зеленая, 46	t	small
43010	41084	1255	Кемеровская область, Новокузнецкий район, поселок Ашмарино, Советская, 15	t	small
43042	41126	1286	Кемеровская область, Новокузнецкий район, Апанас, Шабалова, 18Б	t	small
43027	41105	1271	Кемеровская область, Новокузнецкий район, Анисимово (Васьково), Центральная, 28	t	small
42441	40423	702	Кемеровская область, Новокузнецкий район, Абагур-Лесной, Громовой, 61, школа 16	f	\N
42255	40244	516	Кемеровская область, Междуреченский район, Междуреченск, АБК ЦОФ КУЗБАССКАЯ	f	small
42254	40243	515	Россия, Кемеровская область, Междуреченский район, Междуреченск	f	medium
42251	40240	512	Кемеровская область, Междуреченский район, Междуреченск, СДК пос.Камешек	f	medium
42250	40239	511	Кемеровская область, Междуреченский район, Междуреченск, ФАНТАЗИЯ	f	small
42276	40265	537	Кемеровская область, Междуреченский район, Междуреченск, проспект Строителей, 10	f	large
42275	40265	536	Кемеровская область, Междуреченский район, Междуреченск, проспект Строителей, 10	f	large
42277	40266	538	Кемеровская область, Междуреченский район, Междуреченск, проспект Коммунистический, 9	f	large
42234	40226	495	Кемеровская область, Междуреченский район, Междуреченск, проспект Коммунистический, 17	f	large
42256	40245	517	Кемеровская область, Междуреченский район, Междуреченск, ШИРОКИЙ ЛОГ, 42А	f	large
42248	40237	509	Кемеровская область, Междуреченский район, Междуреченск, УСИНСКАЯ, 27	f	large
42237	40229	498	Кемеровская область, Междуреченский район, Междуреченск, Строителей, 36	f	large
42233	40225	494	Кемеровская область, Междуреченский район, Междуреченск, Строителей, 23	f	large
41805	39667	66	Кемеровская область, Беловский район, Белово, Юности, 26	f	large
42241	40058	502	Кемеровская область, Междуреченский район, Междуреченск, СТРОИТЕЛЕЙ, 59	f	large
42270	40260	531	Кемеровская область, Междуреченский район, Междуреченск, Пушкина, 22	f	medium
42259	40250	520	Кемеровская область, Междуреченский район, Междуреченск, Проходчиков, 38	f	large
42265	40254	526	Кемеровская область, Междуреченский район, Междуреченск, ПУШКИНА, 30	f	large
42263	40254	524	Кемеровская область, Междуреченский район, Междуреченск, ПУШКИНА, 30	f	large
42260	40251	521	Кемеровская область, Междуреченский район, Междуреченск, ПРИТОМСКИЙ, ГДК ЮНОСТЬ	f	large
42245	40234	506	Кемеровская область, Междуреченский район, Междуреченск, Лазо, 33	f	large
42246	40235	507	Кемеровская область, Междуреченский район, Междуреченск, ЛАЗО, 33	f	large
42238	40230	499	Кемеровская область, Междуреченский район, Междуреченск, Кузнецкая, 32	f	large
42235	40227	496	Кемеровская область, Междуреченский район, Междуреченск, Коммунистический, 23	f	medium
42279	40268	540	Кемеровская область, Междуреченский район, Междуреченск, Комарова, 19А	f	large
42247	40236	508	Кемеровская область, Междуреченский район, Междуреченск, КУЗНЕЦКАЯ, 51	f	large
42240	40217	501	Кемеровская область, Междуреченский район, Междуреченск, КУЗНЕЦКАЯ, 27	f	large
42239	40190	500	Кемеровская область, Междуреченский район, Междуреченск, КУЗНЕЦКАЯ, 32	f	large
42249	40238	510	Кемеровская область, Междуреченский район, Междуреченск, ДУНАЕВСКОГО, 1а	f	large
42244	40233	505	Кемеровская область, Междуреченский район, Междуреченск, ГУЛИ КОРОЛЕВОЙ, 3	f	large
42243	40232	504	Кемеровская область, Междуреченский район, Междуреченск, ГУЛИ КОРОЛЕВОЙ, 11	f	large
42272	40262	533	Кемеровская область, Междуреченский район, Междуреченск, Вокзальная, 6	f	large
42267	40257	528	Кемеровская область, Междуреченский район, Междуреченск, Вокзальная, 42	f	large
42264	40255	525	Кемеровская область, Междуреченский район, Междуреченск, Вокзальная, 42	f	large
42236	40228	497	Кемеровская область, Междуреченский район, Междуреченск, Весенняя, 9	f	large
42257	40246	518	Кемеровская область, Междуреченский район, Междуреченск, Вахрушева, 3	f	medium
42262	40253	523	Кемеровская область, Междуреченский район, Междуреченск, Бульвар медиков, 7	f	large
42261	40252	522	Кемеровская область, Междуреченский район, Междуреченск, БРЯНСКАЯ, 6а	f	large
42242	40231	503	Кемеровская область, Междуреченский район, Междуреченск, 50 лет Комсомола, 36А	f	large
42979	41057	1227	Кемеровская область, Мариинский район, поселок Тюменево, Радищева, 53	t	small
42984	41062	1232	Кемеровская область, Мариинский район, поселок Тундинка, Лесная, 39 А	t	small
43000	41074	1245	Кемеровская область, Мариинский район, поселок Туйла, Паромская, 2 А	t	small
42962	40476	1214	Кемеровская область, Мариинский район, поселок Тенгулы, Городская, 27	t	small
42998	41072	1243	Кемеровская область, Мариинский район, поселок Таёжно-Михайловка, Школьный бульвар, 8	t	small
42999	41073	1244	Кемеровская область, Мариинский район, поселок Таежно-Александровка, Александровская, 31	t	small
42996	41070	1241	Кемеровская область, Мариинский район, поселок Суслово, Трактовая, 23	t	large
42995	41069	1240	Кемеровская область, Мариинский район, поселок Суслово, Стройка, 7	t	large
42991	41067	1237	Кемеровская область, Мариинский район, поселок Рубино, Школьная, 24	t	small
42974	41053	1223	Кемеровская область, Мариинский район, поселок Раевка, Центральная, 31	t	small
42972	41052	1222	Кемеровская область, Мариинский район, поселок Пристань 2-я, Весенняя, 13	f	medium
42975	41054	1224	Кемеровская область, Мариинский район, Приметкино, Центральная, 62	t	small
42958	41045	1210	Кемеровская область, Мариинский район, поселок Правдинка, Правдинская, 44 А	t	small
42983	41061	1231	Кемеровская область, Мариинский район, поселок Пихтовка, Лесная, 23	t	small
42980	41058	1228	Кемеровская область, Мариинский район, поселок Петровка, Центральная, 21	t	small
42992	40778	1238	Кемеровская область, Мариинский район, поселок Первомайский, Рабочая, 5	t	small
42963	40658	1215	Кемеровская область, Мариинский район, поселок Обояновка, Новая, 2	t	small
42988	41065	1235	Кемеровская область, Мариинский район, поселок Николаевка 2-я, Молодежная, 18 А	t	small
42959	39493	1211	Кемеровская область, Мариинский район, поселок Николаевка 1-я, Николаевская, 18	t	small
42990	41066	1236	Кемеровская область, Мариинский район, поселок Мелехино, Боровая, 17	t	small
42955	41042	1208	Кемеровская область, Мариинский район, Мариинск, Юбилейная, 1 А	f	large
42952	41038	1205	Кемеровская область, Мариинский район, Мариинск, Юбилейная, 26	f	medium
42954	41038	1207	Кемеровская область, Мариинский район, Мариинск, Юбилейная, 26	f	large
42951	41037	1204	Кемеровская область, Мариинский район, Мариинск, Юбилейная, 7	f	large
42946	41029	1199	Кемеровская область, Мариинский район, Мариинск, Чердынцева, 22	f	large
42936	41013	1189	Кемеровская область, Мариинский район, Мариинск, Фабричная, 1	f	large
42947	41030	1200	Кемеровская область, Мариинский район, Мариинск, Трудовая, 2	f	large
42953	41041	1206	Кемеровская область, Мариинский район, Мариинск, Сибиряков-Гвардейцев, 1	f	medium
42937	41014	1190	Кемеровская область, Мариинский район, Мариинск, Покрышкина, 25 А	f	large
42948	41032	1201	Кемеровская область, Мариинский район, Мариинск, Пальчикова, 1д	f	large
42938	41017	1191	Кемеровская область, Мариинский район, Мариинск, Ноградский, 3	f	large
42950	41035	1203	Кемеровская область, Мариинский район, Мариинск, Молодежная, 9	f	large
42944	41025	1197	Кемеровская область, Мариинский район, Мариинск, Ленина, 30	f	large
42943	41024	1196	Кемеровская область, Мариинский район, Мариинск, Ленина, 44	f	large
42945	40979	1198	Кемеровская область, Мариинский район, Мариинск, Ленина, 8	f	large
42939	41019	1192	Кемеровская область, Мариинский район, Мариинск, Котовского, 19	f	large
42941	41021	1194	Кемеровская область, Мариинский район, Мариинск, Достоевского, 8	f	large
42942	41022	1195	Кемеровская область, Мариинский район, Мариинск, Дорожная, 1	f	large
42949	41034	1202	Кемеровская область, Мариинский район, Мариинск, Добролюбова, 1	f	large
42935	41010	1188	Кемеровская область, Мариинский район, Мариинск, Гагарина, 8	f	large
42940	41020	1193	Кемеровская область, Мариинский район, Мариинск, 50 лет Октября, 73 А	f	large
42970	41050	1220	Кемеровская область, Мариинский район, Мальковка, Центральная, 14	t	small
42965	41047	1217	Кемеровская область, Мариинский район, поселок Малый Антибес, Просвещения, 1	f	small
42985	41063	1233	Кемеровская область, Мариинский район, поселок Малопесчанка, Победы, 1	t	small
42981	41059	1229	Кемеровская область, Мариинский район, поселок Лебяжий, Школьная, 7	t	small
42982	41060	1230	Кемеровская область, Мариинский район, поселок Куркули, Рабочая, 19	t	small
42976	41055	1225	Кемеровская область, Мариинский район, поселок Красные Орлы, Центральная, 4	t	medium
42994	41068	1239	Кемеровская область, Мариинский район, Константиновка, Центральная, 31	t	small
42961	40450	1213	Кемеровская область, Мариинский район, поселок Колеул, Ленина, 45	f	small
42987	41064	1234	Кемеровская область, Мариинский район, поселок Кирсановка, Победы, 1	t	small
42978	41056	1226	Кемеровская область, Мариинский район, Камышенка, Центральная, 25	t	small
42968	41049	1219	Кемеровская область, Мариинский район, поселок Калининский, Студенческая, 2 А	f	medium
42967	41048	1218	Кемеровская область, Мариинский район, поселок Кайдулы, Дорожная, 18	t	small
42997	41071	1242	Кемеровская область, Мариинский район, поселок Знаменка, Центральная, 53	t	small
42964	41046	1216	Кемеровская область, Мариинский район, поселок Болшой Антибес, Ленина, 68	t	small
42960	40418	1212	Кемеровская область, Мариинский район, поселок Благовещенка, Трактовая, 35	t	medium
42956	41044	1209	Кемеровская область, Мариинский район, поселок Белогородка, Пальчикова, 62А	t	small
42971	41051	1221	Кемеровская область, Мариинский район, поселок Антибесский, Зеленая, 10Б	t	small
42928	41003	1181	Кемеровская область, Ленинск-Кузнецкий район, поселок Шабаново, Советская, 71Б	f	large
42924	40999	1177	Кемеровская область, Ленинск-Кузнецкий район, поселок Чусовитино, Школьная, 22	f	medium
42918	40961	1171	Кемеровская область, Ленинск-Кузнецкий район, поселок Чкаловский, 50 Лет Октября, 1	f	medium
42900	40969	1153	Кемеровская область, Ленинск-Кузнецкий район, поселок Чесноково, Центральная, 8	f	small
42907	40978	1160	Кемеровская область, Ленинск-Кузнецкий район, поселок Худяшово, Центральная, 55	t	small
42911	40984	1164	Кемеровская область, Ленинск-Кузнецкий район, поселок Хрестиновский, Старательская, 41	t	small
40061	36610	1628	Иркутская область, Усть-Кут, Речников, 34	f	large
42904	40975	1157	Кемеровская область, Ленинск-Кузнецкий район, поселок Хмелево, Зеленая, 13	t	small
42906	40977	1159	Кемеровская область, Ленинск-Кузнецкий район, поселок Трекино, Горка, 16	t	small
42929	41004	1182	Кемеровская область, Ленинск-Кузнецкий район, поселок Торопово, Весенняя, 48А	f	small
42897	40966	1150	Кемеровская область, Ленинск-Кузнецкий район, поселок Солнечный, Апрельская, 3, квартира 2	t	small
42934	41009	1187	Россия, Рязанская область, Рязань, поселок Соколовка	t	small
42925	41000	1178	Кемеровская область, Ленинск-Кузнецкий район, поселок Семеново, Центральная, 34А	f	small
42916	40989	1169	Кемеровская область, Ленинск-Кузнецкий район, поселок Свердловский, Школьная, 13	t	medium
42915	40988	1168	Кемеровская область, Ленинск-Кузнецкий район, поселок Родниковый, Садовая, 15	t	small
42919	40994	1172	Россия, Кемеровская область, Ленинск-Кузнецкий район, поселок Ракитный	f	small
42895	40964	1148	Кемеровская область, Ленинск-Кузнецкий район, поселок Поселок Клейзавода, Заводская, 11	t	small
110771	40558	812	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Ягодная, 6, здание школы искусств № 54	t	\N
42544	40550	806	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Читинская, 47	f	\N
42547	40550	809	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Читинская, 47	f	\N
42558	40566	820	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Токарева, 6	f	\N
42557	40564	819	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Токарева, 1	f	\N
42552	40560	814	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Покрышкина, 7а	f	\N
42559	40567	821	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Панферова, 20	f	\N
42550	40559	813	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Мира, 5	f	\N
42555	40563	817	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Макаренко, 2	f	\N
42554	40562	816	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Крупской, 62	f	\N
42546	40553	808	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Крупской, 106	f	\N
42549	40556	811	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Кремлевская, 1	f	\N
42548	40554	810	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Кремлевская, 5	f	\N
42553	40561	815	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Космонавтов, 17	f	\N
42560	40568	822	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Карбышева, 1	f	\N
42561	40568	823	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Карбышева, 1	f	\N
42556	40565	818	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Заречная, 1	f	\N
42543	40551	805	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Бажова, 3	f	\N
42542	40549	804	Кемеровская область, Ленинск-Кузнецкий район, Полысаево, Бажова, 7	f	\N
42913	40986	1166	Кемеровская область, Ленинск-Кузнецкий район, поселок Подгорное, пер. Кольцевой, 10	t	medium
42926	41001	1179	Кемеровская область, Ленинск-Кузнецкий район, поселок Панфилово, Советская, 14А	f	large
42917	40991	1170	Кемеровская область, Ленинск-Кузнецкий район, поселок Павловка, Центральная, 43А	t	small
42933	41008	1186	Кемеровская область, Ленинск-Кузнецкий район, поселок Орловский, Магистральная, 1В	t	small
42902	40973	1155	Кемеровская область, Ленинск-Кузнецкий район, поселок Новопокровка, Центральная, 14	f	small
42920	40995	1173	Кемеровская область, Ленинск-Кузнецкий район, поселок Новопокасьма, Туснолобовой-Марченко, 1	f	small
42922	40997	1175	Кемеровская область, Ленинск-Кузнецкий район, поселок Новогородец, Никитинская, 30	t	small
42903	40974	1156	Кемеровская область, Ленинск-Кузнецкий район, поселок Новогеоргиевка, Молодежная, 29	f	medium
42932	41007	1185	Кемеровская область, Ленинск-Кузнецкий район, поселок Мусохраново, Советская, 60А	f	small
42921	40996	1174	Кемеровская область, Ленинск-Кузнецкий район, поселок Мирный, Весенняя, 4	t	medium
42217	40208	479	Россия, Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий	f	small
42220	40213	482	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Шахтеров, 21	t	large
42188	40172	450	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Текстильщиков, 4/4	f	large
40059	36608	1626	Иркутская область, Усть-Кут, Речников, 1	f	large
42185	40168	447	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Текстильщиков, 12	f	large
42189	40162	451	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Текстильщиков, 4/3	f	large
42181	40162	443	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Текстильщиков, 4/3	f	large
42194	40181	456	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Ленина, 15	f	large
42193	40178	455	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Ленина, 46	f	large
42192	40178	454	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Ленина, 46	f	large
42190	40174	452	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Ленина, 31	f	large
42186	40169	448	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Ленина, 61/3	f	large
42180	40161	442	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кольчугинский, 3	f	large
42215	40206	477	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кирова, 55	f	large
42213	40203	475	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кирова, 4	f	large
42212	40203	474	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кирова, 4	f	medium
42211	40202	473	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кирова, 25	f	large
42197	40182	459	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кирова, 106	f	medium
42195	40182	457	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кирова, 106	f	large
42191	40177	453	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Кирова, 99	f	medium
42216	40207	478	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, проспект Дзержинского, 29	f	large
42210	40201	472	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, площадь Кирова, 13а	f	large
42222	40215	484	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, переулок Челюскина, 20	f	large
42179	40155	441	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, бульвар Химиков, 7/1	f	large
42176	40155	438	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, бульвар Химиков, 7/1	f	large
42177	40157	439	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Юргинская, 6	f	large
42208	40199	470	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Энгельса, 6	f	large
42202	40191	464	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Широкая, 1	f	large
42227	40221	489	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Шилина, 1	f	large
42198	40185	460	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Шевцовой, 2	f	medium
42187	40164	449	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Топкинская, 8	f	large
42182	40164	444	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Топкинская, 8	f	large
42183	40165	445	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Телефонная, 5	f	small
42225	40218	487	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Суворова, 131	f	large
42224	40218	486	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Суворова, 131	f	large
42214	40205	476	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Суворова, 3	f	medium
42219	40211	481	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Советская, 159	f	large
42203	40192	465	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Садовая, 84	f	large
42184	40166	446	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Рылеева, 39	f	large
42228	40222	490	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Рубинштейна, 1	f	large
42201	40189	463	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Пушкина, 9	f	large
42196	40184	458	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Пушкина, 17	f	large
42174	40152	436	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Пирогова, 3	t	large
42204	40194	466	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Мусохранова, 2а	f	medium
42175	40154	437	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Лесной городок, 31	f	large
42221	40214	483	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Кирсанова, 3	f	large
42205	40195	467	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Зорина, 1	f	large
42200	40187	462	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Зварыгина, 6	f	large
42209	40200	471	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Горького, 10а	f	large
42206	40196	468	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Горького, 16	f	large
42231	40210	493	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Глинки, 1	f	large
42218	40210	480	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Глинки, 1	f	large
42199	40186	461	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Вокзальная, 30	f	large
42226	40220	488	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Витебская, 52	f	large
42230	40224	492	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, 7 Ноября, 4	f	large
42229	40223	491	Кемеровская область, Ленинск-Кузнецкий район, Ленинск-Кузнецкий, Ноября, 1а	f	large
42901	40970	1154	Кемеровская область, Ленинск-Кузнецкий район, поселок Красноярка, Центральная, 1	f	medium
42908	40945	1161	Кемеровская область, Ленинск-Кузнецкий район, Красное, 40 Лет Октября, 7	f	large
42909	40981	1162	Кемеровская область, Ленинск-Кузнецкий район, поселок Красное, 40 лет Октября, 2	f	large
42899	40968	1152	Кемеровская область, Ленинск-Кузнецкий район, поселок Красная Поляна, пер. Энергетиков, 10	t	small
42930	41005	1183	Кемеровская область, Ленинск-Кузнецкий район, поселок Камышино, Центральная, 68	f	medium
42896	40965	1149	Кемеровская область, Ленинск-Кузнецкий район, поселок Егозово, Полевая, 34	t	medium
42905	40976	1158	Кемеровская область, Ленинск-Кузнецкий район, поселок Драченино, переулок Рабочий, 1	t	large
42898	40967	1151	Кемеровская область, Ленинск-Кузнецкий район, поселок Демьяновка, Чкалова, 2	f	large
42894	40963	1147	Кемеровская область, Ленинск-Кузнецкий район, поселок Восходящий, Вострикова, 1А	f	medium
42923	40998	1176	Кемеровская область, Ленинск-Кузнецкий район, поселок Возвышенка, Октябрьская, 11, квартира 2	t	small
42910	40982	1163	Кемеровская область, Ленинск-Кузнецкий район, Ариничево, Центральная, 7	f	medium
42888	40958	1143	Кемеровская область, Крапивинский район, поселок Шевели, Московская, 3	f	medium
42875	40955	1141	Кемеровская область, Крапивинский район, поселок Тараданово, Садовая, 6	t	medium
42887	40935	1127	Кемеровская область, Крапивинский район, поселок Скарюпино, Школьная, 18	t	small
42893	40962	1146	Кемеровская область, Крапивинский район, поселок Сарапки, Центральная, 5-2	f	small
42874	40952	1138	Кемеровская область, Крапивинский район, поселок Поперечное, Набережная, 1	f	small
42883	40942	1132	Кемеровская область, Крапивинский район, поселок Плотниковский, Школьная, 2	t	small
42880	40953	1139	Кемеровская область, Крапивинский район, поселок Перехляй, Центральная, 14	t	medium
42890	40960	1145	Кемеровская область, Крапивинский район, поселок Новобарачаты, Советская, 1	t	small
42892	40932	1124	Кемеровская область, Крапивинский район, поселок Михайловский, Кооперативная	t	small
42873	40951	1137	Кемеровская область, Крапивинский район, поселок Междугорное, 60 лет октября	f	small
42879	40938	1129	Кемеровская область, Крапивинский район, поселок Максимово, Школьная, 3	f	small
42886	40934	1126	Кемеровская область, Крапивинский район, поселок Красные Ключи, Ленина	f	small
42866	40927	1120	Кемеровская область, Крапивинский район, поселок Крапивинский, Юбилейная, 4	f	large
42865	40926	1119	Кемеровская область, Крапивинский район, поселок Крапивинский, Мостовая, 32	f	large
42864	40925	1118	Кемеровская область, Крапивинский район, поселок Крапивинский, Кирова, 1А	f	large
42863	40924	1117	Кемеровская область, Крапивинский район, поселок Крапивинский, Кирова, 16А	f	large
42877	40947	1135	Кемеровская область, Крапивинский район, поселок Ключи, Центральная, 20	t	small
42881	40949	1136	Кемеровская область, Крапивинский район, поселок Каменный, Мира, 17	f	small
40058	36607	1625	Иркутская область, Усть-Кут, Речников, 2	f	large
42870	40943	1133	Кемеровская область, Крапивинский район, поселок Каменка, Почтовая, 17А	f	medium
42869	40930	1122	Кемеровская область, Крапивинский район, поселок Зеленогорский, Центральная, 425	f	large
42867	40928	1121	Кемеровская область, Крапивинский район, поселок Зеленогорский, Центральная, 29	f	large
42882	40940	1131	Кемеровская область, Крапивинский район, поселок Зеленовский, Школьная, 27	f	medium
42876	40956	1142	Кемеровская область, Крапивинский район, поселок Долгополово, Мира, 14	t	small
110865	40939	1130	Кемеровская область, Крапивинский район, поселок Борисово, Санаторий, здание санатория Борисовский	t	\N
42878	40937	1128	Кемеровская область, Крапивинский район, поселок Борисово, Геологов, 15	f	large
42889	40959	1144	Кемеровская область, Крапивинский район, поселок Березовка, Новая	t	small
42884	40954	1140	Кемеровская область, Крапивинский район, поселок Бердюгино, Школьная, 3	t	small
42885	40933	1125	Кемеровская область, Крапивинский район, поселок Барачаты, Юбилейная, 23	t	medium
42891	40931	1123	Кемеровская область, Крапивинский район, поселок Банново, Центральная, 6	t	medium
42871	40944	1134	Кемеровская область, Крапивинский район, поселок Арсеново, Почтовая, 40	t	small
42131	40090	392	Кемеровская область, Киселевский городской округ, Киселевск, Студенческая, 18/3	f	large
42151	40111	412	Кемеровская область, Киселевский городской округ, Киселевск, Весенняя, 7	f	large
42143	40111	404	Кемеровская область, Киселевский городской округ, Киселевск, Весенняя, 7	f	large
42855	40917	1112	Кемеровская область, Кемеровский район, Ягуново, Центральная, 25	f	large
42854	40916	1111	Кемеровская область, Кемеровский район, поселок Щегловский, Советская, 20	t	medium
42850	40912	1107	Кемеровская область, Кемеровский район, поселок Черемушки, Школьная, 10	t	small
42852	40914	1109	Кемеровская область, Кемеровский район, поселок Усть-Хмелевка, Школьная, 15	t	small
42825	40891	1087	Кемеровская область, Кемеровский район, поселок Успенка, Промысловая, 7-А	t	small
42835	40900	1096	Кемеровская область, Кемеровский район, поселок Тебеньковка, Центральная, 10	t	small
42832	40897	1093	Кемеровская область, Кемеровский район, Сухая Речка, Школьная, 7	f	small
42839	40903	1099	Кемеровская область, Кемеровский район, поселок Старочервово, Советская, 1	t	medium
42826	40892	1088	Кемеровская область, Кемеровский район, поселок Сосновка 2-я, Школьная, 1	t	small
42837	40902	1098	Кемеровская область, Кемеровский район, поселок Силино, Центральная, 11	f	medium
42824	40890	1086	Кемеровская область, Кемеровский район, поселок Разведчик, Коммунистическая, 3	f	medium
42109	40060	371	Кемеровская область, Кемеровский район, поселок Промышленновский, Промышленное шоссе, 56а, Д/К	f	\N
42851	40913	1108	Кемеровская область, Кемеровский район, поселок Подъяково, Кедровый бор	t	small
42836	40901	1097	Кемеровская область, Кемеровский район, поселок Осиновка, Центральная, 1-А	t	medium
43103	41193	1347	Кемеровская область, Кемеровский район, поселок Новостройка, СДК п.Новостройка	f	small
42830	40896	1092	Кемеровская область, Кемеровский район, поселок Новостройка, Набережная, 3	f	medium
42861	40921	1115	Кемеровская область, Кемеровский район, село Мазурово, Школьная, 2-А	f	medium
42828	40894	1090	Кемеровская область, Кемеровский район, поселок Кузбасский, Лобанова, 14	f	large
42108	40057	370	Россия, Свердловская область, городской округ Верхняя Пышма, поселок Кедровка	f	\N
42105	40053	367	Кемеровская область, Кемеровский район, поселок Кедровка, Стадионная, 22а, спорткомпл&amp;quot;Горняк&amp;quot	f	\N
42107	40055	369	Кемеровская область, Кемеровский район, поселок Кедровка, Советская, 5а, шк.№96	f	\N
42106	40054	368	Кемеровская область, Кемеровский район, поселок Кедровка, Новогодняя, 15а, Д/К Содружество	f	\N
42104	40052	366	Кемеровская область, Кемеровский район, поселок Кедровка, Новогодняя, 8, шк.52	f	\N
42841	40904	1100	Кемеровская область, Кемеровский район, поселок Звездный, Центральная, 12	f	medium
42853	40915	1110	Кемеровская область, Кемеровский район, поселок Верхотомское, Московская, 31	f	medium
42844	40906	1102	Кемеровская область, Кемеровский район, Благодатный, Весенняя, 1-А	f	small
42829	40895	1091	Кемеровская область, Кемеровский район, поселок Березово, Абызова, 14	f	large
42827	40893	1089	Кемеровская область, Кемеровский район, поселок Береговая, Молодежная, 1	f	large
42849	40911	1106	Кемеровская область, Кемеровский район, поселок Барановка, Центральная, 22-А	t	medium
42833	40898	1094	Кемеровская область, Кемеровский район, поселок Андреевка, Советская, 18	f	large
41916	39806	177	Кемеровская область, Калтан, поселок Малиновка, Советская, 44	t	\N
42801	40866	1063	Кемеровская область, Ижморский район, поселок Тёплая Речка, Строителей, 3	t	small
42815	40880	1077	Кемеровская область, Ижморский район, поселок Тунда, Ленина, 23	t	small
42823	40889	1085	Кемеровская область, Ижморский район, поселок Троицкое, Молодежная, 30	f	medium
42813	40878	1075	Кемеровская область, Ижморский район, поселок Симбирка, Новая, 177	f	small
42807	40872	1069	Кемеровская область, Ижморский район, поселок Святославка, Советская, 31А	f	small
42819	40884	1081	Кемеровская область, Ижморский район, поселок Почитанка, Ленинская, 66А	f	small
42818	40883	1080	Кемеровская область, Ижморский район, Постниково, Ленинская, 69А	f	small
42808	40873	1070	Россия, Оренбургская область, Пономаревский район, село Островка	t	small
42800	40865	1062	Кемеровская область, Ижморский район, поселок Ольговка, Лесная, 10	t	small
42803	40868	1065	Россия, Пензенская область, Сосновоборский район, село Новый Свет	f	small
42810	40875	1072	Кемеровская область, Ижморский район, поселок Новославянка, Молодежная, 13	f	small
42811	40876	1073	Кемеровская область, Ижморский район, поселок Новоорловка, Заречная, 27	t	small
42802	40867	1064	Кемеровская область, Ижморский район, поселок Нижегородка, Советская, 49	t	small
42822	40888	1084	Кемеровская область, Ижморский район, Ломачевка, Школьная, 6	t	small
42814	40879	1076	Кемеровская область, Ижморский район, поселок Летяжка, Молодежная, 23	t	small
42812	40877	1074	Кемеровская область, Ижморский район, Левашовка, Набережная, 7	t	small
42804	40869	1066	Кемеровская область, Ижморский район, поселок Красный Яр, Школьный переулок, 2	f	medium
42806	40871	1068	Кемеровская область, Ижморский район, поселок Красная Тайга, Центральная, 11-2	t	small
42809	40874	1071	Кемеровская область, Ижморский район, поселок Котовский, Школьная, 15	t	small
42799	40864	1061	Кемеровская область, Ижморский район, поселок Колыон, Микрорайон, 3	f	medium
42792	40860	1054	Кемеровская область, Ижморский район, поселок Ижморский, Почтовая, 8	f	medium
110857	40862	1059	Кемеровская область, Ижморский район, поселок Ижморский, Лесная, 25, Помещение отделения сестринского ухода ЦРБ	t	\N
42793	40861	1055	Кемеровская область, Ижморский район, поселок Ижморский, Ленинская, 84	f	large
42796	40261	1058	Кемеровская область, Ижморский район, поселок Ижморский, Ленинская, 119	f	medium
42795	40847	1057	Кемеровская область, Ижморский район, поселок Ижморский, Комсомольская, 5	f	medium
42794	40824	1056	Кемеровская область, Ижморский район, поселок Ижморский, Кирова, 4	f	medium
42790	40858	1052	Кемеровская область, Ижморский район, поселок Ижморка 2-я, Москалева, 51А	f	small
42805	40870	1067	Кемеровская область, Ижморский район, Иверка, Трактовая, 3-2	t	small
42821	40887	1083	Кемеровская область, Ижморский район, поселок Воскресенка, Школьная, 20	f	small
42817	40881	1079	Кемеровская область, Ижморский район, поселок Большая Песчанка, Ленинская, 53	f	small
42816	40538	1078	Кемеровская область, Ижморский район, поселок Берикуль, Молодежная, 2Б	f	small
42791	40859	1053	Кемеровская область, Ижморский район, поселок Азаново, Колхозная, 24	t	small
42775	40840	1037	Кемеровская область, Гурьевский район, Урск, Широкая, 29	t	small
42770	40835	1032	Кемеровская область, Гурьевский район, поселок Урск, Стахановская, 36	t	medium
42773	40838	1035	Кемеровская область, Гурьевский район, поселок Урск, Солнечная, 36	t	small
42771	40836	1033	Кемеровская область, Гурьевский район, поселок Урск, Пушкина, 40	t	small
42772	40837	1034	Кемеровская область, Гурьевский район, поселок Урск, Мира, 42	t	small
42774	40839	1036	Кемеровская область, Гурьевский район, поселок Урск, Алтайская, 29	t	small
42789	40857	1051	Кемеровская область, Гурьевский район, поселок Ур-Бедари, Советская, 48	t	small
42788	40856	1050	Кемеровская область, Гурьевский район, поселок Ур-Бедари, Проездная, 6	t	small
42779	40845	1041	Кемеровская область, Гурьевский район, Сосновка, 8 Марта, 14	t	medium
42780	40846	1042	Кемеровская область, Гурьевский район, поселок Сосновка, Пушкина, 9	t	small
42781	40848	1043	Кемеровская область, Гурьевский район, поселок Сосновка, Полевая, 1А	t	small
42782	40849	1044	Кемеровская область, Гурьевский район, поселок Сосновка, К.Маркса, 2	t	small
42767	40832	1029	Кемеровская область, Гурьевский район, Салаир, Станционная, 1	t	small
42765	40830	1027	Кемеровская область, Гурьевский район, Салаир, Ленина, 1	f	large
42762	40826	1024	Кемеровская область, Гурьевский район, Салаир, Крупской, 9	t	medium
42764	40828	1026	Кемеровская область, Гурьевский район, Салаир, Коммунистическая, 7	f	large
42769	40834	1031	Кемеровская область, Гурьевский район, Салаир, Гагарина, 102	f	medium
42768	40834	1030	Кемеровская область, Гурьевский район, Салаир, Гагарина, 102	f	small
42763	40827	1025	Кемеровская область, Гурьевский район, Салаир, Гагарина, 1	f	large
42784	40851	1046	Кемеровская область, Гурьевский район, поселок Раздольный, Шоссейная, 1	t	small
42783	40850	1045	Кемеровская область, Гурьевский район, поселок Раздольный, Центральная, 9а	t	medium
42785	40852	1047	Кемеровская область, Гурьевский район, поселок Раздольный, Клубная, 2	t	small
42778	40844	1040	Кемеровская область, Гурьевский район, поселок Новопестерево, Центральная, 39	f	small
42776	40842	1038	Кемеровская область, Гурьевский район, поселок Новопестерево, Степная, 22	f	medium
42777	40843	1039	Кемеровская область, Гурьевский район, поселок Новопестерево, Лесная, 5/1	t	small
42787	40855	1049	Кемеровская область, Гурьевский район, поселок Малая Салаирка, Трактовая, 2	f	large
41895	39784	156	Кемеровская область, Гурьевский район, Гурьевск, улица Лермонтова, 107	t	small
41881	39761	142	Кемеровская область, Гурьевский район, Гурьевск, пер. Лесной, 1	t	large
41884	39766	145	Кемеровская область, Гурьевский район, Гурьевск, Садовая улица, 8	t	large
41880	39760	141	Кемеровская область, Гурьевский район, Гурьевск, Революционная, 95	t	large
41893	39780	154	Кемеровская область, Гурьевский район, Гурьевск, Лермонтова, 9	t	large
41889	39773	150	Кемеровская область, Гурьевский район, Гурьевск, Ленина, 64	f	medium
41883	39764	144	Кемеровская область, Гурьевский район, Гурьевск, Коммунистическая, 23	f	large
41899	39790	160	Кемеровская область, Гурьевский район, Гурьевск, Коммунистическая, 12А	t	small
41898	39789	159	Кемеровская область, Гурьевский район, Гурьевск, Коммунистическая, 19	f	medium
41894	39782	155	Кемеровская область, Гурьевский район, Гурьевск, Войкова, 186	t	large
41882	39763	143	Кемеровская область, Гурьевский район, Гурьевск, 40 лет ВЛКСМ, 28	t	medium
42786	40853	1048	Кемеровская область, Гурьевский район, поселок Горскино, Революционная, 47	f	medium
43016	41090	1260	Кемеровская область, Гурьевский район, поселок Гавриловка, Молодежная, 11-1	f	small
42745	40804	1007	Кемеровская область, Беловский район, пос.ст.Разрез, контора вагонного депо ст.Разрез	t	small
41819	39680	80	Кемеровская область, Беловский район, микрорайон Старобелово, Фрунзе, 3	f	large
42743	40802	1005	Кемеровская область, Беловский район, поселок имени Ильича, контора ООО Светлана	t	small
42759	40820	1021	Кемеровская область, Беловский район, поселок Щебзавод, школа п.Щебзавод	t	large
42756	40817	1018	Кемеровская область, Беловский район, поселок Шестаки, клуб	t	small
42724	40777	986	Кемеровская область, Беловский район, поселок Хахалино, здание ФАП д.Хахалино	t	small
42728	40782	990	Кемеровская область, Беловский район, поселок Уроп, библиотека с.Уроп	t	small
42752	40811	1014	Кемеровская область, Беловский район, поселок Убинский, клуб п.Убинский	t	small
42732	40787	994	Кемеровская область, Беловский район, Степной, сельский клуб п.Степной	t	small
42721	40773	983	Кемеровская область, Беловский район, поселок Старопестерево, школа с.Старопестерево	f	medium
42720	40772	982	Кемеровская область, Беловский район, поселок Старопестерево, СДК Горняк с.Старопестерево	f	large
42755	40816	1017	Кемеровская область, Беловский район, поселок Старобачаты, Бачатская основная школа	f	medium
42754	40815	1016	Кемеровская область, Беловский район, поселок Старобачаты, СДК п.Старобачаты	f	large
42753	40813	1015	Кемеровская область, Беловский район, поселок Старобачаты, детский сад п.Старобачаты	f	medium
40066	36615	1633	Иркутская область, Усть-Кут, Пушкина, 70	f	large
42722	40775	984	Кемеровская область, Беловский район, поселок Снежинский, школа	f	medium
42734	40789	996	Кемеровская область, Беловский район, Сидоренково, школа с.Сидоренково	t	medium
42730	40785	992	Кемеровская область, Беловский район, Рямовая, клуб д.Рямовая	t	small
42750	40809	1012	Кемеровская область, Беловский район, поселок Проектная, вокзал п.ст.Проектная	t	small
42632	40664	894	Кемеровская область, Беловский район, поселок Проектная, Проектная, 96	f	large
42733	40788	995	Кемеровская область, Беловский район, поселок Поморцево, клуб	t	small
42739	40797	1001	Кемеровская область, Беловский район, Пермяки, школа с.Пермяки	t	large
42738	40796	1000	Кемеровская область, Беловский район, поселок Новый Каракан, клуб п.Новый Каракан	t	large
41837	39696	98	Кемеровская область, Беловский район, Новый Городок, Гражданская, 16	f	large
41834	39696	95	Кемеровская область, Беловский район, Новый Городок, Гражданская, 16	t	large
41836	39698	97	Кемеровская область, Беловский район, Новый Городок, Гастелло, 10	f	large
41833	39695	94	Кемеровская область, Беловский район, поселок Новый Городок, Киевская, 23	f	large
42740	40798	1002	Кемеровская область, Беловский район, поселок Новохудяково, клуб с.Новохудяково	t	small
42747	40806	1009	Кемеровская область, Беловский район, поселок Новороссийка, клуб д.Новороссийка	t	small
42742	40800	1004	Кемеровская область, Беловский район, поселок Новобачаты, школа с.Новобачаты	t	large
42717	40768	979	Кемеровская область, Беловский район, поселок Мохово, СДК с.Мохово	t	large
42751	40810	1013	Кемеровская область, Беловский район, поселок Мереть, ФП п.ст.Мереть	t	small
42725	40779	987	Кемеровская область, Беловский район, поселок Менчереп, Культурно-досуговый центр	t	medium
42723	40776	985	Кемеровская область, Беловский район, поселок Коротково, сельский клуб д.Коротково	t	small
42735	40790	997	Россия, Кемеровская область, Беловский район, поселок Коновалово	t	small
42749	40808	1011	Кемеровская область, Беловский район, поселок Конево, клуб с.Конево	t	small
42741	40799	1003	Кемеровская область, Беловский район, поселок Каралда, школа	t	small
42737	40794	999	Кемеровская область, Беловский район, Каракан, СДК им.Есенина с.Каракан	t	medium
42748	40807	1010	Кемеровская область, Беловский район, Калиновка, клуб д.Калиновка	t	small
42729	40783	991	Кемеровская область, Беловский район, поселок Инюшка, школа	t	small
41846	39713	107	Кемеровская область, Беловский район, поселок Инской, Энергетическая, 13	f	large
41847	39714	108	Кемеровская область, Беловский район, поселок Инской, Чистопольская, 13	f	large
41845	39712	106	Кемеровская область, Беловский район, поселок Инской, Парковая, 4	f	large
41848	39715	109	Кемеровская область, Беловский район, поселок Инской, Ильича, 28	f	large
42746	40805	1008	Кемеровская область, Беловский район, поселок Ивановка, СДК д.Ивановка	t	small
42719	40770	981	Кемеровская область, Беловский район, поселок Заря, клуб п.Заря	t	small
42718	40769	980	Кемеровская область, Беловский район, поселок Заринское, СДК	t	medium
41838	39699	99	Кемеровская область, Беловский район, поселок Заречное, Кузбасская, 57	t	small
42726	40780	988	Кемеровская область, Беловский район, поселок Задубровский, клуб п.Задубровский	t	small
42736	40792	998	Кемеровская область, Беловский район, поселок Евтино, СДК	t	medium
42727	40781	989	Россия, Кемеровская область, Беловский район, поселок Дунай-Ключ	t	small
41854	39721	115	Кемеровская область, Беловский район, поселок Грамотеино, Центральная, 1	t	large
41851	39718	112	Кемеровская область, Беловский район, поселок Грамотеино, Светлая, 22А	f	large
41850	39717	111	Кемеровская область, Беловский район, поселок Грамотеино, Светлая, 12А	f	large
41853	39720	114	Кемеровская область, Беловский район, поселок Грамотеино, Лесная, 1	t	large
41855	39722	116	Кемеровская область, Беловский район, поселок Грамотеино, Колмогоровская, 19А	t	large
41849	39716	110	Кемеровская область, Беловский район, поселок Грамотеино, Грамотеинская, 31	t	large
41852	39719	113	Кемеровская область, Беловский район, поселок Грамотеино, 7 Ноября, 16	t	large
42731	40786	993	Кемеровская область, Беловский район, поселок Вишневка, контора колхоза Вишневский	f	medium
42757	40818	1019	Кемеровская область, Беловский район, поселок Бускускан, общежитие	t	small
41822	39683	83	Кемеровская область, Беловский район, Белово, мкрн Бабанаково, Энгельса, 18	t	medium
41820	39681	81	Кемеровская область, Беловский район, Белово, Энгельса, 6	t	large
41824	39686	85	Кемеровская область, Беловский район, Белово, Шахтовая, 78	t	medium
41802	39663	63	Кемеровская область, Беловский район, Белово, Цинкзаводской пер, 22А	t	large
41812	39674	73	Кемеровская область, Беловский район, Белово, Советская, 60	f	large
41807	39669	68	Кемеровская область, Беловский район, Белово, Советская, 31	f	large
41829	39692	90	Кемеровская область, Беловский район, Белово, мкрн Чертинский, Победы, 21	t	large
41804	39666	65	Кемеровская область, Беловский район, Белово, Морозова, 4	t	large
41825	39687	86	Кемеровская область, Беловский район, Белово, Механическая улица, 1Б, мкрн Совхозный	t	large
41816	39678	77	Кемеровская область, Беловский район, Белово, Линейный переулок, 41	t	large
41811	39673	72	Кемеровская область, Беловский район, Белово, Ленина, 48	f	large
41808	39670	69	Кемеровская область, Беловский район, Белово, Ленина, 39	t	large
41827	39689	88	Кемеровская область, Беловский район, Белово, Боевая, 30	t	large
41815	39677	76	Кемеровская область, Беловский район, Белово, 3 микрорайон, 113	t	large
41828	39691	89	Кемеровская область, Беловский район, Белово, 3 Телеут, 24	f	small
42744	40803	1006	Кемеровская область, Беловский район, поселок Беково, СДК с.Беково	f	large
41844	39710	105	Кемеровская область, Беловский район, Бачатский, мкрн Финский, 27	f	medium
41841	39704	102	Кемеровская область, Беловский район, поселок Бачатский, Шевцовой, 33	f	large
41840	39702	101	Кемеровская область, Беловский район, поселок Бачатский, Шевцовой, 49	f	large
41843	39708	104	Кемеровская область, Беловский район, поселок Бачатский, Комсомольская, 10	f	large
41842	39706	103	Кемеровская область, Беловский район, поселок Бачатский, Комсомольская, 49	f	large
41839	39701	100	Кемеровская область, Беловский район, поселок Бачатский, 50 лет Октября, 9	f	large
42758	40819	1020	Кемеровская область, Беловский район, поселок Артышта, школа	t	small
86392	36838	1884	Иркутская область, с. Преображенка, Школьная, 4, Помещение спортивного зала МОУ СОШ	t	small
39353	35956	920	Иркутская область, п.Алексеевск, Чапаева, 47	f	large
39436	36038	1003	Иркутская область, п. Витимский, Школьная, 13	t	small
39356	35959	923	Иркутская область, д.Салтыково, сельский клуб	t	small
40245	36772	1812	Иркутская область, Шелехов, 135, микрорайон	f	large
40235	36762	1802	Иркутская область, Шелехов, переулок Садовый, 20	f	large
40242	36769	1809	Иркутская область, Шелехов, квартал315, квартал315	f	large
40243	36770	1810	Иркутская область, Шелехов, М-55, 628	f	large
40236	36763	1803	Иркутская область, Шелехов, Кочубея, 21 А	f	large
39360	35964	927	Иркутская область, село Чечуйск, Советская, 8	t	small
40176	36705	1743	Иркутская область, Черемхово, Щорса, 58	f	medium
40165	36699	1732	Иркутская область, Черемхово, Ференца Патаки, 1	f	medium
40164	36699	1731	Иркутская область, Черемхово, Ференца Патаки, 1	f	large
40153	36690	1720	Иркутская область, Черемхово, Толстого, 8	f	large
40152	36690	1719	Иркутская область, Черемхово, Толстого, 8	f	large
40186	36714	1753	Иркутская область, Черемхово, Спартаковская, 26	f	small
40187	36715	1754	Иркутская область, Черемхово, Сибирская, 3	f	small
40192	36719	1759	Иркутская область, Черемхово, Первомайская, 117	f	small
40150	36688	1717	Иркутская область, Черемхово, Первомайская, 87	f	medium
40173	36311	1740	Иркутская область, Черемхово, Маяковского, 195	f	large
40172	35789	1739	Иркутская область, Черемхово, Маяковского, 143	f	large
40177	36706	1744	Иркутская область, Черемхово, Краснодонская, 2	f	medium
40183	36711	1750	Иркутская область, Черемхово, Дударского, 13	f	large
40042	36591	1609	Иркутская область, Усть-Кут	t	small
40049	36598	1616	Иркутская область, Усть-Кут, Энергетический переулок, 1	f	medium
40057	36606	1624	Иркутская область, Усть-Кут, Школьный переулок, 2	f	large
40044	36593	1611	Иркутская область, Усть-Кут, Школьная, 3	t	medium
40051	36600	1618	Иркутская область, Усть-Кут, Советская, 97	f	large
110307	36602	1620	Иркутская область, Усть-Кут, Седова, 29	f	medium
68150	36612	1630	Иркутская область, Усть-Кут, Речников, 44а	f	large
40062	36611	1629	Иркутская область, Усть-Кут, Речников, 40	f	large
40068	36617	1635	Иркутская область, Усть-Кут, Коммунистическая, 13	t	large
40055	36604	1622	Иркутская область, Усть-Кут, Кирова, 80	f	large
40054	36603	1621	Иркутская область, Усть-Кут, Кирова, 18	f	large
40056	36605	1623	Иркутская область, Усть-Кут, Кедровая, 19	f	medium
40078	36628	1645	Иркутская область, Усть-Кут, Горбунова, 5	t	medium
40067	36616	1634	Иркутская область, Усть-Кут, Геологическая, 2	f	medium
40064	36613	1631	Иркутская область, Усть-Кут, Володарского, 65	f	large
40043	36592	1610	Иркутская область, Усть-Кут, Береговая, 10	t	small
40022	36578	1589	Иркутская область, Усть-Илимск, пр.Мира, 36	f	large
40000	36562	1567	Иркутская область, Усть-Илимск, Чайковского, 1	f	large
40009	36526	1576	Иркутская область, Усть-Илимск, Трудовая, 2	f	large
40006	36561	1573	Иркутская область, Усть-Илимск, Романтиков, 14	f	large
39999	36561	1566	Иркутская область, Усть-Илимск, Романтиков, 14	f	large
40005	36567	1572	Иркутская область, Усть-Илимск, Наймушина, 9	f	large
40004	36566	1571	Иркутская область, Усть-Илимск, Наймушина, 40	f	large
40001	36563	1568	Иркутская область, Усть-Илимск, Ленина, 20Б	f	large
40013	36572	1580	Иркутская область, Усть-Илимск, Дружбы Народов, 7	f	large
40012	36572	1579	Иркутская область, Усть-Илимск, Дружбы Народов, 7	f	large
40011	36571	1578	Иркутская область, Усть-Илимск, Дружбы Народов, 7	f	large
40017	36575	1584	Иркутская область, Усть-Илимск, Героев Труда, 19	f	large
40016	36575	1583	Иркутская область, Усть-Илимск, Героев Труда, 19	f	large
40014	36573	1581	Иркутская область, Усть-Илимск, Героев Труда, 19	f	large
40024	36580	1591	Иркутская область, Усть-Илимск, Георгия Димитрова, 10	f	large
39966	36538	1533	Россия, Иркутская область, Усолье-Сибирское, улица Толбухина, 21	f	large
39225	35840	792	Россия, Иркутская область, Усолье-Сибирское, улица Пушкина, 64	f	large
39968	36540	1535	Иркутская область, Усолье-Сибирское, улица Матросова, 2	f	large
39970	36542	1537	Россия, Иркутская область, Усолье-Сибирское, улица Луначарского, 10	f	large
38936	35606	502	Россия, Иркутская область, Усолье-Сибирское, улица Куйбышева, 11	f	medium
39955	36529	1522	Россия, Иркутская область, Усолье-Сибирское, улица Коростова, 35	f	large
39982	36546	1549	Россия, Иркутская область, Усолье-Сибирское, проспект Химиков, 15	f	large
39981	36546	1548	Россия, Иркутская область, Усолье-Сибирское, проспект Химиков, 15	f	large
39980	36546	1547	Россия, Иркутская область, Усолье-Сибирское, проспект Химиков, 15	f	large
39979	36546	1546	Россия, Иркутская область, Усолье-Сибирское, проспект Химиков, 15	f	large
39978	36545	1545	Россия, Иркутская область, Усолье-Сибирское, проспект Космонавтов, 1	f	large
39977	36545	1544	Россия, Иркутская область, Усолье-Сибирское, проспект Космонавтов, 1	f	large
39976	36545	1543	Россия, Иркутская область, Усолье-Сибирское, проспект Космонавтов, 1	f	large
39975	36545	1542	Россия, Иркутская область, Усолье-Сибирское, проспект Космонавтов, 1	f	large
39959	36532	1526	Россия, Иркутская область, Усолье-Сибирское, проезд Серегина, 34	f	large
39958	36532	1525	Россия, Иркутская область, Усолье-Сибирское, проезд Серегина, 34	f	large
40050	36599	1617	Иркутская область, Усолье-Сибирское, Щорса, 43	f	medium
39953	36527	1520	Россия, Иркутская область, Усолье-Сибирское, Фестивальный проезд, 11	f	large
39965	36537	1532	Иркутская область, Усолье-Сибирское, Толбухина, 52	f	large
39964	36537	1531	Иркутская область, Усолье-Сибирское, Толбухина, 52	f	large
39969	36541	1536	Иркутская область, Усолье-Сибирское, Розы Люксембург, 46	f	large
39948	36521	1515	Иркутская область, Усолье-Сибирское, Октябрьская, 4а	f	large
39945	36519	1512	Россия, Иркутская область, Усолье-Сибирское, Молотовая улица, 92	f	large
39951	36524	1518	Иркутская область, Усолье-Сибирское, Менделеева, 20	f	large
39974	36544	1541	Иркутская область, Усолье-Сибирское, Луначарского, 31	f	large
39973	36544	1540	Иркутская область, Усолье-Сибирское, Луначарского, 31	f	large
39972	36543	1539	Иркутская область, Усолье-Сибирское, Луначарского, 35а	f	large
39971	36543	1538	Иркутская область, Усолье-Сибирское, Луначарского, 35а	f	large
39949	36522	1516	Иркутская область, Усолье-Сибирское, Ленина, 1	f	medium
39950	36523	1517	Иркутская область, Усолье-Сибирское, Крупской, 37	f	large
39963	36536	1530	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 77	f	large
39961	36534	1528	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 51	f	large
39960	36533	1527	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 40	f	large
39954	36528	1521	Россия, Иркутская область, Усолье-Сибирское, Комсомольский проспект, 30	f	large
39957	36531	1524	Иркутская область, Усолье-Сибирское, Клары Цеткин, 8	f	large
39967	36539	1534	Иркутская область, Усолье-Сибирское, Карла Либкнехта, 58	f	large
39947	36520	1514	Иркутская область, Усолье-Сибирское, Интернациональная, 81	f	large
39946	36520	1513	Иркутская область, Усолье-Сибирское, Интернациональная, 81	f	large
39956	36530	1523	Иркутская область, Усолье-Сибирское, Жуковского, 45	f	large
39910	36484	1477	Иркутская область, поселок Усолье, 7, Дом офицеров	f	large
39520	36123	1087	Иркутская область, поселок Ук, Коммунистическая, 1	f	medium
39874	36457	1440	Иркутская область, Тулун, микрорайон Угольщиков, 33	t	medium
39873	36457	1439	Иркутская область, Тулун, микрорайон Угольщиков, 33	t	medium
39870	36454	1436	Иркутская область, Тулун, микрорайон Угольщиков, 43 А	t	medium
39869	36454	1435	Иркутская область, Тулун, микрорайон Угольщиков, 43 А	t	medium
39867	36452	1433	Иркутская область, Тулун, Строителей, 10	f	medium
39896	36472	1459	Иркутская область, Тулун, Совхозная, 17	f	medium
39887	36466	1453	Иркутская область, Тулун, Сигаева, 3	f	large
39886	36466	1452	Иркутская область, Тулун, Сигаева, 3	f	large
39885	36465	1451	Иркутская область, Тулун, Речная, 94	f	large
39898	36474	1461	Иркутская область, Тулун, Островского, 28	f	medium
39884	36464	1450	Иркутская область, Тулун, Мясокомбинатская, 29	f	medium
39881	36462	1447	Иркутская область, Тулун, Ленина, 7	f	medium
39866	36451	1432	Иркутская область, Тулун, Ватутина, 4	t	large
39797	36394	1364	Иркутская область, Тайшет	f	large
39792	36390	1359	Иркутская область, Тайшет, 4А	f	large
39791	36388	1358	Иркутская область, Тайшет, 20	f	large
39790	36387	1357	Иркутская область, Тайшет, 7А	f	large
86384	36395	1365	Иркутская область, Тайшет, мкр-н.Пахотищева, СОШ№20	f	small
39795	36392	1362	Иркутская область, Тайшет, Шевченко, 1	f	large
39794	36392	1361	Иркутская область, Тайшет, Шевченко, 1	f	large
39805	36403	1372	Иркутская область, Тайшет, Чапаева, 1	f	medium
39788	36385	1355	Иркутская область, Тайшет, Транспортная, 20	f	large
39787	36385	1354	Иркутская область, Тайшет, Транспортная, 20	f	large
39772	36370	1339	Иркутская область, Тайшет, Суворова, 13	f	small
39800	36397	1367	Иркутская область, Тайшет, Пушкина, 43	f	large
39802	36400	1369	Иркутская область, Тайшет, Пионерская, 50	f	large
39808	36406	1375	Иркутская область, Тайшет, Первомайская, 48	f	medium
39807	36405	1374	Иркутская область, Тайшет, Первомайская, 36	f	large
39796	36393	1363	Иркутская область, Тайшет, Мира, 4	f	large
39806	36404	1373	Иркутская область, Тайшет, Ленина, 113	f	large
39793	36391	1360	Иркутская область, Тайшет, Крупской, 123	f	large
39789	36386	1356	Иркутская область, Тайшет, Крупской, 91	f	large
110302	36396	1366	Иркутская область, Тайшет, Кирова, 234	f	medium
39786	36384	1353	Иркутская область, Тайшет, Ивана Бича, 1	f	large
39801	36399	1368	Иркутская область, Тайшет, Воинов Интернационалистов, 109	f	large
39803	36401	1370	Иркутская область, Тайшет, 50 лет ВЛКСМ, 87	f	medium
39704	36297	1271	Иркутская область, Сухой Ручей, Линейная, 20	t	small
39696	36289	1263	Иркутская область, Слюдянка, Слюдянских Красногвардейцев, 9	f	large
39703	36296	1270	Иркутская область, Слюдянка, Ленина, 8 А	f	large
39701	36294	1268	Иркутская область, Слюдянка, Ленина, 21	f	large
39682	36277	1249	Иркутская область, Свирск, Тимирязева, 10	f	medium
39681	36276	1248	Иркутская область, Свирск, Молодёжная, 1	f	medium
39693	36286	1260	Иркутская область, Свирск, Лесная, 1	f	small
39671	36264	1238	Иркутская область, Саянск, микрорайон Центральный, школа №4	f	large
39666	36264	1233	Иркутская область, Саянск, микрорайон Центральный, школа №4	f	large
39668	36265	1235	Иркутская область, Саянск, микрорайон Строителей, школа №5	f	large
39667	36265	1234	Иркутская область, Саянск, микрорайон Строителей, школа №5	f	large
39664	36262	1231	Иркутская область, Саянск, микрорайон Солнечный, школа №6	f	large
39663	36262	1230	Иркутская область, Саянск, микрорайон Солнечный, школа №6	f	large
39677	36273	1244	Иркутская область, Саянск, микрорайон Олимпийский	f	large
38734	35430	300	Иркутская область, поселок Сахарово, Молодежная, 18	t	small
39288	35898	855	Иркутская область, Преображенка, улица Советская, 8	t	small
86364	35966	929	Иркутская область, село Петропавловское, Советская, 15	t	small
39008	35681	574	Иркутская область, деревня Новолисиха, Клубная, 28	f	small
38974	35646	540	Иркутская область, поселок Новая Разводная, Совхозная, 35	t	medium
39494	36096	1061	Иркутская область, Нижнеудинск, переулок Красный, 2	f	large
39485	36087	1052	Иркутская область, Нижнеудинск, Шнеерсон, 4	f	large
39487	36089	1054	Иркутская область, Нижнеудинск, Циолковского, 10	f	large
39486	36088	1053	Иркутская область, Нижнеудинск, Советская, 37	f	large
39498	36100	1065	Иркутская область, Нижнеудинск, Петина, 145	f	medium
39490	36092	1057	Иркутская область, Нижнеудинск, П. Осипенко, 27	f	large
39488	36090	1055	Иркутская область, Нижнеудинск, Октябрьская, 3	f	large
39484	36086	1051	Иркутская область, Нижнеудинск, Нагорная, 2	f	large
39492	36094	1059	Иркутская область, Нижнеудинск, Маяковского, 40	f	medium
39495	36097	1062	Иркутская область, Нижнеудинск, Масловского, 34	f	large
39491	36093	1058	Иркутская область, Нижнеудинск, Лермонтова, 20	f	large
39489	36091	1056	Иркутская область, Нижнеудинск, Ленина, 10	f	medium
39499	36101	1066	Иркутская область, Нижнеудинск, Кржижановского, 24-а	f	large
39496	36098	1063	Иркутская область, Нижнеудинск, Краснопролетарская, 16	f	large
39483	36085	1050	Иркутская область, Нижнеудинск, Карла Маркса, 83	f	large
39501	36103	1068	Иркутская область, Нижнеудинск, Знаменская, 60	f	large
39497	36099	1064	Иркутская область, Нижнеудинск, Знаменская, 91	f	medium
39503	36105	1070	Иркутская область, Нижнеудинск, Гагарина, 11	f	large
39502	36104	1069	Иркутская область, Нижнеудинск, 6-й Пятилетки, 2	f	large
39493	36095	1060	Иркутская область, Нижнеудинск, 2-я Западная, 2	f	medium
38975	35647	541	Иркутская область, поселок Молодежный, МОУ Средняя общеобразовательная школа	f	large
38648	35348	214	Иркутская область, поселок Маракан, Школьная, 46	t	small
38642	35342	208	Иркутская область, Мамаканское муниципальное образование, Советская, 12	t	small
39433	36034	1000	Иркутская область, Мама, Советская, 19	f	large
68133	35671	565	Россия, Иркутская область, поселок Малая Топка, улица Ключевая, 27б	f	large
39370	35972	937	Иркутская область, поселок Куйтун, Красный Октябрь, 15	f	medium
39338	35941	905	Иркутская область, село Кривошапкино, Советская, 6	t	medium
39335	35938	902	Иркутская область, Красноярово	t	small
39435	36036	1002	Иркутская область, поселок Колотовка, Первомайская, 11	t	small
39340	35943	907	Иркутская область, Киренск, квартал Водников, 7а	f	large
39344	35947	911	Иркутская область, Киренск, Школьная, 4	t	small
39342	35945	909	Иркутская область, Киренск, Ленрабочих, 49, Киренский район, Киренское муниципальное образование	f	large
39343	35946	910	Иркутская область, Киренск, Алексеева, 1	f	medium
39258	35866	825	Россия, Иркутская область, Иркутск, Свердловский административный округ, Юбилейный микрорайон, 64	f	large
39257	35866	824	Россия, Иркутская область, Иркутск, Свердловский административный округ, Юбилейный микрорайон, 64	f	large
39256	35865	823	Иркутская область, Иркутск, 22	f	large
39255	35864	822	Иркутская область, Иркутск, 14	f	large
39254	35863	821	Россия, Иркутская область, Иркутск, Свердловский административный округ, Юбилейный микрорайон, 37	f	large
39253	35863	820	Россия, Иркутская область, Иркутск, Свердловский административный округ, Юбилейный микрорайон, 37	f	large
39252	35863	819	Россия, Иркутская область, Иркутск, Свердловский административный округ, Юбилейный микрорайон, 37	f	large
39241	35853	808	Россия, Иркутская область, Иркутск, Свердловский административный округ, Радужный микрорайон, 34б	f	large
39188	35816	755	Россия, Иркутская область, Иркутск, улица маршала Конева, 86	f	large
39077	35734	643	Россия, Иркутская область, Иркутск, улица генерала Доватора, 21	f	large
39078	35734	644	Россия, Иркутская область, Иркутск, улица генерала Доватора, 21	f	large
39079	35735	645	Россия, Иркутская область, Иркутск, улица генерала Воровского, 12	f	large
39046	35715	612	Россия, Иркутская область, Иркутск, улица академика Образцова, 23	f	large
39045	35715	611	Россия, Иркутская область, Иркутск, улица академика Образцова, 23	f	large
39054	35720	620	Россия, Иркутская область, Иркутск, улица Ярославского, 221	f	large
39037	35708	603	Россия, Иркутская область, Иркутск, улица Шпачека, 19	f	large
39347	35950	914	Россия, Иркутская область, Иркутск, улица Трудовых Резервов, 16	f	large
40046	36595	1613	Россия, Иркутская область, Иркутск, улица Трудовая, 5	f	large
39906	36480	1473	Россия, Иркутская область, Иркутск, улица Тимирязева, 42	t	small
39140	35778	707	Россия, Иркутская область, Иркутск, улица Степана Разина, 20	f	large
39159	35795	726	Россия, Иркутская область, Иркутск, улица Советская, 139	f	large
39130	35769	697	Россия, Иркутская область, Иркутск, улица Советская, 45	f	large
39122	35764	689	Россия, Иркутская область, Иркутск, улица Советская, 94	f	large
39121	35764	688	Россия, Иркутская область, Иркутск, улица Советская, 94	f	large
39114	35759	681	Россия, Иркутская область, Иркутск, улица Советская, 176	f	large
39113	35759	680	Россия, Иркутская область, Иркутск, улица Советская, 176	f	large
39112	35759	679	Россия, Иркутская область, Иркутск, улица Советская, 176	f	large
39028	35700	594	Россия, Иркутская область, Иркутск, улица Сибирских Партизан, 19	f	large
68134	35699	593	Россия, Иркутская область, Иркутск, улица Сибирских Партизан, 22	f	large
39026	35698	592	Россия, Иркутская область, Иркутск, улица Сибирских Партизан, 30	f	large
39064	35726	630	Россия, Иркутская область, Иркутск, улица Севастопольская, 218	f	large
39063	35726	629	Россия, Иркутская область, Иркутск, улица Севастопольская, 218	f	large
40065	36614	1632	Россия, Иркутская область, Иркутск, улица Российская, 3	f	large
39141	35779	708	Россия, Иркутская область, Иркутск, улица Российская, 3	f	large
39073	35731	639	Россия, Иркутская область, Иркутск, улица Розы Люксембург, 343	f	large
39071	35729	637	Россия, Иркутская область, Иркутск, улица Розы Люксембург, 317	f	large
39070	35729	636	Россия, Иркутская область, Иркутск, улица Розы Люксембург, 317	f	large
39133	35752	700	Россия, Иркутская область, Иркутск, улица Ржанова, 29	f	medium
39104	35752	671	Россия, Иркутская область, Иркутск, улица Ржанова, 29	f	large
39103	35752	670	Россия, Иркутская область, Иркутск, улица Ржанова, 29	f	large
39177	35809	744	Россия, Иркутская область, Иркутск, улица Рабочего Штаба, 99	f	large
39217	35834	784	Россия, Иркутская область, Иркутск, улица Профсоюзная, 3	f	large
39042	35711	608	Россия, Иркутская область, Иркутск, улица Просвещения, 14	f	large
39032	35704	598	Россия, Иркутская область, Иркутск, улица Просвещения, 13	f	large
39033	35704	599	Россия, Иркутская область, Иркутск, улица Просвещения, 13	f	large
40060	36609	1627	Россия, Иркутская область, Иркутск, улица Пролетарская, 10	f	large
39051	35718	617	Россия, Иркутская область, Иркутск, улица Пржевальского, 78	f	large
39339	35942	906	Россия, Иркутская область, Иркутск, улица Полины Осипенко, 8	f	large
39156	35792	723	Россия, Иркутская область, Иркутск, улица Поленова, 18а	f	large
39083	35738	649	Россия, Иркутская область, Иркутск, улица Пискунова, 128а	f	large
39044	35714	610	Иркутская область, Иркутск, улица Павла Красильникова, 54а	f	large
39030	35702	596	Россия, Иркутская область, Иркутск, улица Новаторов, 14	f	large
39022	35695	588	Россия, Иркутская область, Иркутск, улица Новаторов, 49	f	large
39021	35695	587	Россия, Иркутская область, Иркутск, улица Новаторов, 49	f	large
39034	35705	600	Россия, Иркутская область, Иркутск, улица Муравьева, 14	f	large
39041	35710	607	Россия, Иркутская область, Иркутск, улица Мира, 37	f	large
39040	35710	606	Россия, Иркутская область, Иркутск, улица Мира, 37	f	large
39039	35709	605	Россия, Иркутская область, Иркутск, улица Мира, 14	f	large
39038	35709	604	Россия, Иркутская область, Иркутск, улица Мира, 14	f	large
39084	35739	650	Россия, Иркутская область, Иркутск, улица Лыткина, 75	f	large
39908	36482	1475	Россия, Иркутская область, Иркутск, улица Лесная, 3	f	large
39236	35849	803	Россия, Иркутская область, Иркутск, улица Лермонтова, 134	f	large
39235	35848	802	Россия, Иркутская область, Иркутск, улица Лермонтова, 311	f	large
39233	35846	800	Россия, Иркутская область, Иркутск, улица Лермонтова, 128	f	large
39224	35839	791	Россия, Иркутская область, Иркутск, улица Лермонтова, 80	f	large
39160	35796	727	Россия, Иркутская область, Иркутск, улица Ленская, 2а	f	large
39029	35701	595	Россия, Иркутская область, Иркутск, улица Ленинградская, 75	f	large
39145	35782	712	Россия, Иркутская область, Иркутск, улица Ленина, 56	f	medium
39144	35782	711	Россия, Иркутская область, Иркутск, улица Ленина, 56	f	large
39139	35777	706	Россия, Иркутская область, Иркутск, улица Ленина, 8	f	large
38649	35349	215	Россия, Иркутская область, Иркутск, улица Ленина, 8	f	large
38643	35343	209	Россия, Иркутская область, Иркутск, улица Ленина, 4	f	large
39239	35851	806	Россия, Иркутская область, Иркутск, улица Костычева, 1	f	large
39238	35851	805	Россия, Иркутская область, Иркутск, улица Костычева, 1	f	large
39116	35761	683	Россия, Иркутская область, Иркутск, улица Коммунаров, 10	f	large
39143	35781	710	Иркутская область, Иркутск, улица Карла Маркса, 7	f	large
39124	35765	691	Россия, Иркутская область, Иркутск, улица Карла Либкнехта, 159	f	large
39123	35765	690	Россия, Иркутская область, Иркутск, улица Карла Либкнехта, 159	f	large
38798	35475	364	Россия, Иркутская область, река Бикей	t	large
39036	35707	602	Россия, Иркутская область, Иркутск, улица Жукова, 11	f	large
39136	35774	703	Россия, Иркутская область, Иркутск, улица Дорожная, 4	f	large
39081	35736	647	Россия, Иркутская область, Иркутск, улица Днепровская, 2а	f	medium
39080	35736	646	Россия, Иркутская область, Иркутск, улица Днепровская, 2а	f	large
39086	35741	652	Россия, Иркутская область, Иркутск, улица Депутатская, 45/2	f	large
39155	35791	722	Россия, Иркутская область, Иркутск, улица Декабрьских Событий, 119а	f	large
39219	35835	786	Россия, Иркутская область, Иркутск, улица Гоголя, 33	f	large
39218	35835	785	Россия, Иркутская область, Иркутск, улица Гоголя, 33	f	large
39171	35804	738	Россия, Иркутская область, Иркутск, улица Вьюжная, 2	f	large
39088	35742	654	Россия, Иркутская область, Иркутск, улица Волжская, 14/1	f	large
39087	35742	653	Россия, Иркутская область, Иркутск, улица Волжская, 14/1	f	large
39048	35716	614	Россия, Иркутская область, Иркутск, улица Василия Ледовского, 17	f	large
39049	35716	615	Россия, Иркутская область, Иркутск, улица Василия Ледовского, 17	f	large
39047	35716	613	Россия, Иркутская область, Иркутск, улица Василия Ледовского, 17	f	large
39222	35837	789	Россия, Иркутская область, Иркутск, улица Валентины Терешковой, 38	f	large
39221	35837	788	Россия, Иркутская область, Иркутск, улица Валентины Терешковой, 38	f	large
39072	35730	638	Россия, Иркутская область, Иркутск, улица Баумана, 232	f	large
39062	35725	628	Россия, Иркутская область, Иркутск, улица Баумана, 214а	f	large
39061	35725	627	Россия, Иркутская область, Иркутск, улица Баумана, 214а	f	large
39050	35717	616	Россия, Иркутская область, Иркутск, улица Баумана, 50	f	large
39167	35801	734	Россия, Иркутская область, Иркутск, улица Баррикад, 34	f	large
39166	35801	733	Россия, Иркутская область, Иркутск, улица Баррикад, 34	f	large
39164	35798	731	Россия, Иркутская область, Иркутск, улица Баррикад, 135	f	large
39163	35798	730	Россия, Иркутская область, Иркутск, улица Баррикад, 135	f	large
39161	35797	728	Россия, Иркутская область, Иркутск, улица Баррикад, 147	f	large
39162	35797	729	Россия, Иркутская область, Иркутск, улица Баррикад, 147	f	large
39137	35775	704	Россия, Иркутская область, Иркутск, улица Байкальская, 202	f	large
39132	35771	699	Россия, Иркутская область, Иркутск, улица Байкальская, 263	f	large
39109	35756	676	Россия, Иркутская область, Иркутск, улица Байкальская, 267	f	large
39102	35751	669	Россия, Иркутская область, Иркутск, улица Байкальская, 209	f	large
39101	35751	668	Россия, Иркутская область, Иркутск, улица Байкальская, 209	f	large
39091	35745	657	Россия, Иркутская область, Иркутск, улица Байкальская, 126	f	large
39125	35743	692	Россия, Иркутская область, Иркутск, улица Байкальская, 105	f	large
39089	35743	655	Россия, Иркутская область, Иркутск, улица Байкальская, 105	f	large
39249	35860	816	Россия, Иркутская область, Иркутск, улица Багратиона, 45	f	large
39248	35859	815	Россия, Иркутская область, Иркутск, улица Аносова, 2	f	large
39245	35856	812	Россия, Иркутская область, Иркутск, улица Ангаргэсстроя, 1	f	large
39198	35823	765	Россия, Иркутская область, Иркутск, улица Алмазная, 18	f	large
39243	35854	810	Россия, Иркутская область, Иркутск, улица Академическая, 5а	f	large
39242	35854	809	Россия, Иркутская область, Иркутск, улица Академическая, 5а	f	large
39223	35838	790	Россия, Иркутская область, Иркутск, улица 5-я Железнодорожная, 53	f	large
39170	35803	737	Иркутская область, Иркутск, Радищева, 132	f	medium
39090	35744	656	Россия, Иркутская область, Иркутск, улица 4-я Советская, 1	f	large
39129	35767	696	Россия, Иркутская область, Иркутск, улица 30 Иркутской Дивизии, 24	f	large
39214	35831	781	Россия, Иркутская область, Иркутск, улица 2-я Железнодорожная, 4	f	large
39157	35793	724	Россия, Иркутская область, Иркутск, улица 1-я Красноказачья, 10а	f	large
39216	35833	783	Иркутская область, Иркутск, поселок Затон	t	medium
110295	35788	719	Иркутская область, Иркутск, переулок Волконского, 7	f	medium
39154	35788	721	Иркутская область, Иркутск, переулок Волконского, 7	f	large
39250	35861	817	Иркутская область, Иркутск, микрорайон Юбилейный, 100	f	large
39251	35862	818	Иркутская область, Иркутск, микрорайон Юбилейный, 9а	t	large
39212	35829	779	Иркутская область, Иркутск, микрорайон Университетскийё, 85	f	large
39211	35829	778	Иркутская область, Иркутск, микрорайон Университетскийё, 85	f	large
39210	35829	777	Иркутская область, Иркутск, микрорайон Университетскийё, 85	f	large
39208	35827	775	Иркутская область, Иркутск, микрорайон Университетский, 33	f	large
39207	35827	774	Иркутская область, Иркутск, микрорайон Университетский, 33	f	large
39209	35828	776	Иркутская область, Иркутск, микрорайон Университетский, 70	f	large
39180	35810	747	Иркутская область, Иркутск, микрорайон Топкинский, 42	f	large
39179	35810	746	Иркутская область, Иркутск, микрорайон Топкинский, 42	f	large
39240	35852	807	Иркутская область, Иркутск, микрорайон Радужный, 34а	f	large
39203	35826	770	Иркутская область, Иркутск, микрорайон Первомайский, 57	f	large
39206	35826	773	Иркутская область, Иркутск, микрорайон Первомайский, 57	f	large
39205	35826	772	Иркутская область, Иркутск, микрорайон Первомайский, 57	f	large
39204	35826	771	Иркутская область, Иркутск, микрорайон Первомайский, 57	f	large
39202	35825	769	Иркутская область, Иркутск, микрорайон Первомайский, 10	f	large
39201	35825	768	Иркутская область, Иркутск, микрорайон Первомайский, 10	f	large
39200	35825	767	Иркутская область, Иркутск, микрорайон Первомайский, 10	f	large
39182	35812	749	Иркутская область, Иркутск, микрорайон Зелёный, 46	f	large
39183	35813	750	Иркутская область, Иркутск, микрорайон Зелёный, 11а	f	large
39181	35811	748	Иркутская область, Иркутск, микрорайон Зелёный, 42	f	large
39108	35755	675	Россия, Иркутская область, Иркутск, маршала Жукова проспект, 56	f	large
39107	35754	674	Россия, Иркутская область, Иркутск, маршала Жукова проспект, 36	f	large
39106	35753	673	Россия, Иркутская область, Иркутск, маршала Жукова проспект, 2	f	large
39105	35753	672	Россия, Иркутская область, Иркутск, маршала Жукова проспект, 2	f	large
39192	35819	759	Иркутская область, Иркутск, бульвар Валентина Рябикова, 13а	f	large
39191	35819	758	Иркутская область, Иркутск, бульвар Валентина Рябикова, 13а	f	large
39232	35845	799	Иркутская область, Иркутск, академика Курчатова, 13а	f	large
39067	35727	633	Иркутская область, Иркутск, Ярославского, 268	f	large
39066	35727	632	Иркутская область, Иркутск, Ярославского, 268	f	large
39065	35727	631	Иркутская область, Иркутск, Ярославского, 268	f	large
39134	35772	701	Иркутская область, Иркутск, Ядринцева, 1-и	f	large
39135	35773	702	Иркутская область, Иркутск, Ширямова, 6а	f	large
39175	35806	742	Иркутская область, Иркутск, Шевцова, 16	f	large
39174	35806	741	Иркутская область, Иркутск, Шевцова, 16	f	large
39228	35842	795	Иркутская область, Иркутск, Чернышевского, 15	f	large
39227	35842	794	Иркутская область, Иркутск, Чернышевского, 15	f	large
39260	35867	827	Иркутская область, Иркутск, Челнокова, 1	t	small
39075	35732	641	Иркутская область, Иркутск, Центральная, 16а	f	large
39074	35732	640	Иркутская область, Иркутск, Центральная, 16а	f	large
39647	36247	1214	Иркутская область, Иркутск, Трактовая, 5	f	small
39142	35780	709	Иркутская область, Иркутск, Сухэ-Батора, 9	f	large
39118	35762	685	Иркутская область, Иркутск, Советская, 44	f	large
39117	35762	684	Иркутская область, Иркутск, Советская, 44	f	large
38972	35644	538	Иркутская область, Иркутск, Сибирская, 2	t	medium
39060	35724	626	Иркутская область, Иркутск, Севастопольская, 214	f	large
39059	35724	625	Иркутская область, Иркутск, Севастопольская, 214	f	large
39058	35724	624	Иркутская область, Иркутск, Севастопольская, 214	f	large
39056	35722	622	Иркутская область, Иркутск, Розы Люксембург, 150	f	large
39176	35808	743	Иркутская область, Иркутск, Рабочего Штаба, 6	f	large
39031	35703	597	Россия, Иркутская область, Иркутск, Пулковский переулок, 26	f	large
39092	35746	658	Россия, Иркутская область, Иркутск, Постышева бульвар, 33	f	large
39093	35746	659	Россия, Иркутская область, Иркутск, Постышева бульвар, 33	f	large
39076	35733	642	Иркутская область, Иркутск, Ленинский административный округ, Полярная, 95/1	f	large
39346	35949	913	Россия, Иркутская область, Иркутск, Партизанская улица, 12	f	large
39111	35758	678	Иркутская область, Иркутск, Омулевского, 49	f	large
39082	35737	648	Иркутская область, Иркутск, Олонская, 6	f	medium
38941	35612	507	Иркутская область, Иркутск, Новокшонова, 2а	f	large
39025	35697	591	Иркутская область, Иркутск, Новаторов, 24	f	large
39168	35802	735	Иркутская область, Иркутск, Нестерова, 32	f	medium
39150	35786	717	Иркутская область, Иркутск, Некрасова, 2	f	large
39247	35858	814	Иркутская область, Иркутск, Мухиной, 3	f	large
39187	35815	754	Иркутская область, Иркутск, Маршала Конева, 22	f	large
39186	35815	753	Иркутская область, Иркутск, Маршала Конева, 22	f	large
39185	35815	752	Иркутская область, Иркутск, Маршала Конева, 22	f	large
39197	35822	764	Иркутская область, Иркутск, Мамина-Сибиряка, 35	f	large
39196	35822	763	Иркутская область, Иркутск, Мамина-Сибиряка, 35	f	large
39024	35696	590	Иркутская область, Иркутск, Макаренко, 6	f	large
39023	35696	589	Иркутская область, Иркутск, Макаренко, 6	f	large
39237	35850	804	Иркутская область, Иркутск, Лермонтова, 331	f	large
39234	35847	801	Иркутская область, Иркутск, Лермонтова, 130	f	large
39231	35844	798	Иркутская область, Иркутск, Лермонтова, 83	f	large
39230	35844	797	Иркутская область, Иркутск, Лермонтова, 83	f	large
39229	35843	796	Иркутская область, Иркутск, Лермонтова, 92	f	large
39351	35954	918	Иркутская область, Иркутск, Ленина, 16	t	medium
39128	35766	695	Иркутская область, Иркутск, Красных Мадьяр, 123	f	large
39127	35766	694	Иркутская область, Иркутск, Красных Мадьяр, 123	f	large
39126	35766	693	Иркутская область, Иркутск, Красных Мадьяр, 123	f	large
39158	35794	725	Иркутская область, Иркутск, Красноярская, 11	f	large
39115	35760	682	Иркутская область, Иркутск, Красного Восстания, 2	f	large
38773	35458	339	Иркутская область, Иркутск, Космонавтов, 9	f	large
38772	35458	338	Иркутская область, Иркутск, Космонавтов, 9	f	large
68135	35944	908	Россия, Иркутская область, Иркутск, Коммунистическая улица, 2	f	large
38944	35615	510	Иркутская область, Иркутск, Коммунистическая, 54	f	medium
39165	35800	732	Иркутская область, Иркутск, Каштаковская, 52	f	large
39120	35763	687	Иркутская область, Иркутск, Карла Либкнехта, 131	f	large
39119	35763	686	Иркутская область, Иркутск, Карла Либкнехта, 131	f	large
39153	35790	720	Иркутская область, Иркутск, Иосифа Уткина, 19	f	large
39098	35749	664	Иркутская область, Иркутск, Зверева, 10	f	large
39097	35749	663	Иркутская область, Иркутск, Зверева, 10	f	large
39096	35749	662	Иркутская область, Иркутск, Зверева, 10	f	large
39226	35841	793	Иркутская область, Иркутск, Звездинская, 12	f	large
39110	35757	677	Иркутская область, Иркутск, Дорожная, 29а	f	large
38997	35669	563	Иркутская область, Иркутск, Дорожная, 9	t	small
39151	35787	718	Иркутская область, Иркутск, Декабрьских Событий, 88	f	large
39173	35805	740	Иркутская область, Иркутск, Госпитальная, 2	f	large
39172	35805	739	Иркутская область, Иркутск, Госпитальная, 2	f	large
39244	35855	811	Иркутская область, Иркутск, Гидростроителей, 6	f	large
39213	35830	780	Иркутская область, Иркутск, Воронежская, 2	f	large
39043	35712	609	Иркутская область, Иркутск, Воинская Площадка, 26	f	medium
39195	35821	762	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 47а	f	large
39194	35821	761	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 47а	f	large
39193	35820	760	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 63	f	large
39190	35818	757	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 22а	f	large
39189	35817	756	Россия, Иркутская область, Иркутск, Валентина Рябикова бульвар, 11б	f	large
39215	35832	782	Иркутская область, Иркутск, Боткина, 1	t	large
39246	35857	813	Иркутская область, Иркутск, Безбокова, 1а	f	large
39100	35750	667	Иркутская область, Иркутск, Байкальская, 230	f	large
39199	35824	766	Иркутская область, Иркутск, Афанасьева, 8	f	large
39035	35706	601	Иркутская область, Иркутск, Авиастроителей, 4а	f	large
39149	35785	716	Россия, Иркутская область, Иркутск, 8 Марта переулок, 1	f	large
39148	35785	715	Россия, Иркутская область, Иркутск, 8 Марта переулок, 1	f	large
38948	35619	514	Иркутская область, Иркутск, 5-й Армии, 63	f	large
39085	35740	651	Иркутская область, Иркутск, 30 Иркутской Дивизии, 24	f	large
39057	35723	623	Россия, Иркутская область, Иркутск, 15-й Советский переулок, 2	f	large
39053	35719	619	Россия, Иркутская область, Иркутск, 12-й Советский переулок, 4	f	large
39052	35719	618	Россия, Иркутская область, Иркутск, 12-й Советский переулок, 4	f	large
39069	35728	635	Иркутская область, Иркутск, Ярославского, 380	f	large
39068	35728	634	Иркутская область, Иркутск, Ярославского, 380	f	large
39055	35721	621	Иркутская область, Иркутск, Ярославского, 211	f	large
39099	35747	665	Иркутская область, Иркутск, Байкальская, 176	f	large
39095	35747	661	Иркутская область, Иркутск, Байкальская, 176	f	large
39094	35747	660	Иркутская область, Иркутск, Байкальская, 176	f	large
38946	35617	512	Иркутская область, Зима, микрорайон Ангарский	f	large
38949	35620	515	Иркутская область, Зима, Мира, 1а	f	large
38947	35618	513	Иркутская область, Зима, Ленина, 6	f	large
38867	35537	433	Иркутская область, поселок Залари, Российская, 17	f	large
38863	35533	429	Иркутская область, поселок Жигалово, Рабочая, 1	t	medium
39448	36050	1015	Иркутская область, Железногорск-Илимский, квартал, 823	f	large
39286	35896	853	Иркутская область, село Ербогачен, Ленина, 5	f	medium
38960	35631	526	Россия, Иркутская область, поселок Дзержинск, улица Центральная, 18	f	large
38829	35499	395	Иркутская область, Братск, переулок 4-й Коммунальный, 21	f	medium
38776	35459	342	Иркутская область, Братск, бульвар Победы, 8	f	large
38775	35459	341	Иркутская область, Братск, бульвар Победы, 8	f	large
38774	35459	340	Иркутская область, Братск, бульвар Победы, 8	f	large
38810	35485	376	Иркутская область, Братск, Юбилейная, 37А	f	large
38812	35486	378	Иркутская область, Братск, Юбилейная, 5	f	large
38811	35486	377	Иркутская область, Братск, Юбилейная, 5	f	large
38770	35455	336	Иркутская область, Братск, Фридриха Энгельса, 5А	f	large
38769	35455	335	Иркутская область, Братск, Фридриха Энгельса, 5А	f	large
38838	35508	404	Иркутская область, Братск, Томская, 6	f	large
68131	35510	406	Иркутская область, Братск, Спортивная, 1А	f	large
38753	35444	319	Иркутская область, Братск, Снежная, 39	f	large
38752	35444	318	Иркутская область, Братск, Снежная, 39	f	large
38751	35444	317	Иркутская область, Братск, Снежная, 39	f	large
38779	35462	345	Иркутская область, Братск, Рябикова, 16	f	large
38820	35493	386	Иркутская область, Братск, Приморская, 47	f	large
38819	35493	385	Иркутская область, Братск, Приморская, 47	f	large
38746	35440	312	Иркутская область, Братск, Подбельского, 9	f	large
38745	35440	311	Иркутская область, Братск, Подбельского, 9	f	large
38815	35489	381	Иркутская область, Братск, Погодаева, 8	f	large
38777	35460	343	Иркутская область, Братск, Обручева, 41	f	large
38764	35452	330	Иркутская область, Братск, Обручева, 11а	f	large
38763	35452	329	Иркутская область, Братск, Обручева, 11а	f	large
38761	35450	327	Иркутская область, Братск, Обручева, 40А	f	large
38760	35450	326	Иркутская область, Братск, Обручева, 40А	f	large
38803	35479	369	Иркутская область, Братск, Набережная, 42А	f	large
38816	35490	382	Иркутская область, Братск, Макаренко, 40	f	large
38762	35451	328	Иркутская область, Братск, Ленина, 25	f	large
38789	35466	355	Иркутская область, Братск, Крупской, 29	f	large
38788	35466	354	Иркутская область, Братск, Крупской, 29	f	large
38771	35457	337	Иркутская область, Братск, Космонавтов, 1	f	large
38755	35445	321	Иркутская область, Братск, Комсомольская, 39	f	large
38754	35445	320	Иркутская область, Братск, Комсомольская, 39	f	large
38744	35439	310	Иркутская область, Братск, Комсомольская, 10Г	f	large
38768	35454	334	Иркутская область, Братск, К. Маркса, 11	f	large
38767	35454	333	Иркутская область, Братск, К. Маркса, 11	f	large
38839	35509	405	Иркутская область, Братск, Иркутская, 16	f	large
38835	35505	401	Иркутская область, Братск, Енисейская, 45А	f	medium
38758	35448	324	Иркутская область, Братск, Депутатская, 9	f	large
38759	35448	325	Иркутская область, Братск, Депутатская, 9	f	large
38833	35502	399	Иркутская область, Братск, Горького, 18	f	medium
38831	35500	397	Иркутская область, Братск, Горького, 1а	f	large
38830	35500	396	Иркутская область, Братск, Горького, 1а	f	large
38805	35481	371	Иркутская область, Братск, Гидростроителей, 67	f	large
38804	35480	370	Иркутская область, Братск, Гидростроителей, 54	f	large
38784	35464	350	Иркутская область, Братск, Гагарина, 21А	f	large
38783	35464	349	Иркутская область, Братск, Гагарина, 21А	f	large
38782	35464	348	Иркутская область, Братск, Гагарина, 21А	f	large
38792	35469	358	Иркутская область, Братск, Возрождения, 30А	f	large
38664	35359	230	Иркутская область, поселок Бохан, Карла Маркса, 3	f	large
110323	36832	1872	Иркутская область, Бодайбо, Школьная, 3	t	medium
38632	35331	198	Иркутская область, Бодайбо, улица Урицкого, 51	f	large
38640	35339	206	Иркутская область, Бодайбо, Центральная, 10	t	small
38641	35340	207	Иркутская область, Бодайбо , Солнечная, 8	t	small
38638	35337	204	Иркутская область, Бодайбо, Ремесленная, 47	f	large
38634	35333	200	Иркутская область, Бодайбо, Почтовый переулок, 6	f	large
38637	35336	203	Иркутская область, Бодайбо, Петра Поручикова, 41 А	f	large
38650	35350	216	Иркутская область, Бодайбо, Набережная улица, 46	t	medium
38639	35338	205	Иркутская область, Бодайбо , Мехколонна, 135, МОУ ДО ДООЦ Лыжная база Таежная	f	medium
38635	35334	201	Иркутская область, Бодайбо, Иркутская, 1	t	large
38631	35329	197	Иркутская область, Бодайбо, Железнодорожная, 1	f	large
38630	35328	196	Иркутская область, Бодайбо, Аэропортовая, 25	t	medium
38647	35347	213	Иркутская область, Бодайбо, Артемовская, 20	t	medium
38646	35346	212	Иркутская область, Бодайбо, Артемовская, 10	t	medium
38636	35335	202	Иркутская область, Бодайбо, 60 лет Октября, 77 Б	f	medium
38633	35332	199	Иркутская область, Бодайбо, 30 лет Победы, 7	f	large
39777	36375	1344	Иркутская область, Бирюсинск, Октябрьская, 23	t	large
39780	36378	1347	Иркутская область, Бирюсинск, Марата, 10	t	small
110289	35345	211	Иркутская область, Балахнинское муниципальное образование, Школьная, 2	f	medium
38572	35269	138	Иркутская область, Ангарск, 5, Средняя школа № 25	f	large
38571	35269	137	Иркутская область, Ангарск, 5, Средняя школа № 25	f	large
38567	35265	133	Иркутская область, Ангарск, 3, Спортивный комплекс АТОМ-спортквартал189	f	large
38564	35262	130	Россия, Иркутская область, Ангарск, 181-й квартал, 1	f	large
38562	35260	128	Иркутская область, Ангарск, 13, Гимназия № 1нач.школа Орленок	f	large
38561	35259	127	Россия, Иркутская область, Ангарск, 178-й квартал, 6	f	large
38558	35257	124	Россия, Иркутская область, Ангарск, 22-й микрорайон, 17	f	large
38553	35254	119	Иркутская область, Ангарск, 18-й микрорайон, 13, Общественная организация АРДИ	f	large
38549	35250	115	Иркутская область, Ангарск, 34, Средняя школа № 30	f	large
38548	35249	114	Иркутская область, Ангарск, Средняя школа № 30мкр.1534	f	large
38544	35245	110	Иркутская область, Ангарск, 64, Средняя школа № 40мкр.1064	f	large
38542	35243	108	Иркутская область, Ангарск, 35, Средняя школа № 35	f	large
38541	35243	107	Иркутская область, Ангарск, 35, Средняя школа № 35	f	large
38535	35240	101	Иркутская область, Ангарск, 20, Средняя школа № 39	f	large
38533	35238	99	Иркутская область, Ангарск, 21	f	large
38531	35236	97	Иркутская область, Ангарск, 25, Средняя школа № 4	f	large
38530	35235	96	Иркутская область, Ангарск, 25, Средняя школа №4	f	large
38523	35229	89	Россия, Иркутская область, Ангарск, 96-й квартал, 5	f	large
38538	35228	104	Иркутская область, Ангарск, Средняя школа № 7	f	large
38537	35228	103	Иркутская область, Ангарск, Средняя школа № 7	f	large
38522	35227	88	Иркутская область, Ангарск, 20, Средняя школа № 2	f	large
38521	35227	87	Иркутская область, Ангарск, 20, Средняя школа № 2	f	large
38503	35211	69	Россия, Иркутская область, Ангарск, 86-й квартал, 4	f	large
38501	35209	67	Иркутская область, Ангарск, Средняя школа № 24	f	large
38499	35207	65	Иркутская область, Ангарск, 21, Средняя школа №27	f	large
38498	35205	64	Иркутская область, Ангарск, 21, Ангарский лицей № 1	f	large
38497	35204	63	Россия, Иркутская область, Ангарск, 72-й квартал, 21	f	large
38495	35202	61	Иркутская область, Ангарск, 5/6, УСКС ОАО АНХК, офис 8	f	large
38487	35194	53	Иркутская область, Ангарск, кв.83, Автотранспортный техникум	f	large
80092	33466	42	Забайкальский край, Чита, Дивизионная, вл. 3	f	large
39434	36035	1001	Россия, Иркутская область, Ангарск, улица Урицкого, 5а	f	large
39146	35783	713	Россия, Иркутская область, Ангарск, улица Урицкого, 22	f	large
40069	36618	1636	Россия, Иркутская область, Ангарск, улица Маяковского, 41	t	large
39220	35836	787	Иркутская область, Ангарск, улица Маяковского, 14	f	large
38493	35200	59	Россия, Иркутская область, Ангарск, улица Кирова, 2а	f	large
38489	35196	55	Россия, Иркутская область, Ангарск, улица Кирова, 38	f	large
38525	35231	91	Иркутская область, Ангарск, проспект Карла Маркса, 71а, ЗАО МСУ-76 Электрон	f	large
38547	35248	113	Иркутская область, Ангарск, мкр.15, 16, Средняя школа № 29	f	large
38543	35244	109	Иркутская область, Ангарск, мкр.1064, Средняя школа № 40	f	large
38545	35246	111	Иркутская область, Ангарск, мкр., 983, Школа искусств № 3	f	large
38536	35218	102	Иркутская область, Ангарск, мкр., 1218, Спец. школа № 2	f	large
38486	35157	52	Иркутская область, Ангарск, мкр. Цементный, Средняя школа №21	f	large
38573	35270	139	Иркутская область, Ангарск, мкр. Новый-440, Средняя школа № 25	f	large
38532	35237	98	Иркутская область, Ангарск, мкр. 8, 21, Средняя школа № 5	f	large
38529	35234	95	Иркутская область, Ангарск, мкр. 6а, 16, Средняя школа № 15	f	large
38528	35234	94	Иркутская область, Ангарск, мкр. 6а, 16, Средняя школа № 15	f	large
38540	35242	106	Иркутская область, Ангарск, мкр. 12а, 14, Школа искусств №4	f	large
38551	35253	117	Иркутская область, Ангарск, микрорайон 17А, 22а	f	large
38539	35241	105	Иркутская область, Ангарск, микрорайон 12а, 7а, ДЮСШ Сибирь	f	large
38514	35221	80	Иркутская область, Ангарск, квартал94, 17	f	large
38517	35223	83	Иркутская область, Ангарск, квартал93, 25, Средняя школа № 3	f	large
38516	35223	82	Иркутская область, Ангарск, квартал93, 25, Средняя школа № 3	f	large
38519	35225	85	Иркутская область, Ангарск, квартал9221, 21, Средняя школа №6	f	large
38518	35224	84	Иркутская область, Ангарск, квартал9221, Средняя школа № 6	f	large
38568	35266	134	Иркутская область, Ангарск, квартал21118, Ангарский лицей №2	f	large
38566	35264	132	Иркутская область, Ангарск, квартал189, 3	f	large
38565	35263	131	Иркутская область, Ангарск, квартал А, 20, МОУ ДОД Гармония	f	large
38524	35230	90	Иркутская область, Ангарск, квартал 983, Школа-интернат № 7	f	large
38509	35216	75	Иркутская область, Ангарск, квартал 95, 20, Средняя школа № 20	f	large
38515	35222	81	Иркутская область, Ангарск, квартал 94, 29, Средняя школа № 38	f	large
38506	35213	72	Иркутская область, Ангарск, квартал 85, 32, Ангарское муниципальное образованиеСредняя школа № 32	f	large
38505	35213	71	Иркутская область, Ангарск, квартал 85, 32, Ангарское муниципальное образованиеСредняя школа № 32	f	large
38508	35215	74	Иркутская область, Ангарск, квартал 7, 16, Школа олимпийского резерва Сибиряк, лыжная база	f	large
68137	35203	62	Иркутская область, Ангарск, квартал 63, 1, ДК Нефтехимик	f	large
38574	35271	140	Иркутская область, Ангарск, квартал 4, 6, Основная школа №22	f	large
38569	35267	135	Иркутская область, Ангарск, квартал 207/2103, Средняя школа № 36	f	large
38510	35217	76	Иркутская область, Ангарск, Чайковского, 60, АГТА	f	large
38484	35192	50	Иркутская область, Ангарск, Трактовая, 15	f	large
38491	35198	57	Иркутская область, Ангарск, Советская улица, 16, Средняя школа № 14	f	large
38526	35232	92	Иркутская область, Ангарск, Полевая улица, 29, ЗАО Стальконструкция	f	large
38801	35477	367	Россия, Иркутская область, река Падун	f	large
38494	35201	60	Россия, Иркутская область, Ангарск, Московская улица, 37	f	large
38490	35197	56	Иркутская область, Ангарск, Московская улица, 10, Средняя школа № 14	f	large
38513	35220	79	Россия, Иркутская область, Ангарск, Ленинградский проспект, 6	f	large
38512	35220	78	Россия, Иркутская область, Ангарск, Ленинградский проспект, 6	f	large
38511	35219	77	Россия, Иркутская область, Ангарск, Ленинградский проспект, 13	f	large
38560	35258	126	Иркутская область, Ангарск, Кольский переулок, 7, Средняя школа № 37	f	large
38559	35258	125	Иркутская область, Ангарск, Кольский переулок, 7, Средняя школа № 37	f	large
39147	35784	714	Иркутская область, Ангарск, Карла Маркса, 47	f	large
68136	35193	51	Иркутская область, Ангарск, Заводская, 4	f	large
38520	35226	86	Иркутская область, Ангарск, Гражданская улица, 1, Техническая школа ДОССАФ, мкр.14, 1	f	large
38507	35214	73	Иркутская область, Ангарск, Горького, 36, Школа олимпийского резерва Сибиряк	f	large
38500	35208	66	Иркутская область, Ангарск, Горького, 8, Ангарское муниципальное образование Средняя школа № 10	f	large
39762	36359	1329	Иркутская область, Ангарск, Гагарина, 7	t	medium
38534	35239	100	Иркутская область, Ангарск, Блудова, 20, Средняя школа № 39	f	large
38488	35195	54	Иркутская область, Ангарск, 91-й квартал, 8, Средняя школа № 12	f	large
38502	35210	68	Иркутская область, Ангарск, 88-й квартал, Средняя школа № 19	f	large
38504	35212	70	Иркутская область, Ангарск, 85-й квартал, 31, НОУДО Русич	f	large
38492	35199	58	Иркутская область, Ангарск, 52-й квартал, 1, Ангарский политехнический техникум	f	large
38527	35233	93	Иркутская область, Ангарск, 277-й квартал, 15, Индустриальный техникум	f	large
38570	35268	136	Иркутская область, Ангарск, 206-й квартал, 6, Детская юношеская спорт.школа Ермак	f	large
38563	35261	129	Иркутская область, Ангарск, 180-й квартал, 1, Ангарское муниципальное образованиеИндустриальный техникум	f	large
38555	35255	121	Иркутская область, Ангарск, 18-й микрорайон, 15, Гимназия №8	f	large
38554	35255	120	Иркутская область, Ангарск, 18-й микрорайон, 15, Гимназия №8	f	large
38552	35251	118	Иркутская область, Ангарск, 17-й микрорайон, 17, Средняя школа № 17	f	large
38550	35251	116	Иркутская область, Ангарск, 17-й микрорайон, 17, Средняя школа № 17	f	large
38546	35247	112	Иркутская область, Ангарск, 15-й микрорайон, 16, Средняя школа № 29	f	large
39354	35957	921	Иркутская область, поселок Алексеевск, Ленский, 2	t	medium
40237	36764	1804	Иркутская область, городской округ Шелехов, Шелехов, Орловских комсомольцев, 2	f	large
39500	36102	1067	Иркутская область, городской округ Нижнеудинск, Нижнеудинск, Петина, 124	f	large
38943	35614	509	Иркутская область, городской округ Зима, Зима, Степная, 12	f	large
40293	36819	1860	Иркутская область, Эхирит-Булагатский район, поселок Шохтой, Школьная, 8	t	small
40288	36814	1855	Иркутская область, Эхирит-Булагатский район, поселок Харат, Ленина, ДК	t	medium
40298	36824	1865	Иркутская область, Эхирит-Булагатский район, поселок Харанут, Школьная, 41А	t	small
86390	36802	1843	Иркутская область, Эхирит-Булагатский район, поселок Харазаргай, Дом культуры	t	small
40284	36810	1851	Иркутская область, Эхирит-Булагатский район, поселок Хабаровск, Центральная, 11	t	small
40262	36787	1829	Иркутская область, Эхирит-Булагатский район, поселок Усть-Ордынский, пер.Коммунальный, 7	f	large
40266	36791	1833	Иркутская область, Эхирит-Булагатский район, поселок Усть-Ордынский, Чапаева, 23	f	large
40263	36788	1830	Иркутская область, Эхирит-Булагатский район, поселок Усть-Ордынский, Первомайская, 3	f	medium
40268	36793	1835	Иркутская область, Эхирит-Булагатский район, поселок Усть-Ордынский, Ленина, 5	f	large
40265	36790	1832	Иркутская область, Эхирит-Булагатский район, поселок Усть-Ордынский, Ленина, 35	f	large
40267	36792	1834	Иркутская область, Эхирит-Булагатский район, поселок Усть-Ордынский, Буденного, 2	f	large
40264	36789	1831	Иркутская область, Эхирит-Булагатский район, поселок Усть-Ордынский, 50 лет Октября, 35	f	large
40294	36820	1861	Иркутская область, Эхирит-Булагатский район, поселок Тугутуй, Степная, 23	t	medium
40280	36806	1847	Иркутская область, Эхирит-Булагатский район, поселок Серафимовск, переулок Школьный, 2	t	small
40299	36826	1866	Иркутская область, Эхирит-Булагатский район, поселок Свердлово, Советская, 19	t	small
40286	36812	1853	Иркутская область, Эхирит-Булагатский район, поселок Отонхой, Школьная, 12	t	small
110322	36811	1852	Иркутская область, Эхирит-Булагатский район, поселок Олой, Трактовая, 24, ФАП	t	medium
40281	36807	1848	Иркутская область, Эхирит-Булагатский район, поселок Новониколаевск, Советская, 40	t	small
40274	36800	1841	Иркутская область, Эхирит-Булагатский район, поселок Нижняя Идыга, Шабагановская, 2	f	small
40282	36808	1849	Иркутская область, Эхирит-Булагатский район, поселок Муромцовка, Школьная, 3	t	small
40302	36829	1869	Иркутская область, Эхирит-Булагатский район, поселок Куяда, Молодежная, 8	t	small
40269	36794	1836	Иркутская область, Эхирит-Булагатский район, поселок Кулункун (Ата), Школьная, 4	t	small
40277	36803	1844	Иркутская область, Эхирит-Булагатский район, поселок Кукунут, Школьная, 10	t	small
40271	36796	1838	Россия, Иркутская область, Эхирит-Булагатский район, поселок Кударейка	t	small
40290	36816	1857	Иркутская область, Эхирит-Булагатский район, поселок Корсук, Трактовая, 8	t	small
40295	36821	1862	Иркутская область, Эхирит-Булагатский район, поселок Комой, Школьная, 3	t	small
40303	36830	1870	Иркутская область, Эхирит-Булагатский район, поселок Капсал, Центральная, 16	f	small
40291	36817	1858	Иркутская область, Эхирит-Булагатский район, поселок Ишины, Нагорная, 4	t	small
40301	36828	1868	Иркутская область, Эхирит-Булагатский район, поселок Захал, Свердлова, 39	t	small
40304	36831	1871	Иркутская область, Эхирит-Булагатский район, поселок Зады, Депутатская, 2	t	small
40300	36827	1867	Иркутская область, Эхирит-Булагатский район, поселок Еловка, Школьная, 10	t	small
40292	36818	1859	Иркутская область, Эхирит-Булагатский район, поселок Гушит, Школьная, 13	t	small
40272	36797	1839	Иркутская область, Эхирит-Булагатский район, поселок Гаханы, Советская, 17	t	medium
40275	36801	1842	Иркутская область, Эхирит-Булагатский район, поселок Верхняя Идыга, Бохолдой, 1	t	small
40289	36815	1856	Иркутская область, Эхирит-Булагатский район, поселок Верхний Кукут, Российская, ДК	t	small
40270	36795	1837	Иркутская область, Эхирит-Булагатский район, поселок Булуса, Молодежная, 9	t	small
40297	36823	1864	Иркутская область, Эхирит-Булагатский район, поселок Большая Кура, Центральная, 40Б	t	small
40273	36799	1840	Иркутская область, Эхирит-Булагатский район, поселок Бозой, Ленина, 44	t	medium
40287	36813	1854	Иркутская область, Эхирит-Булагатский район, поселок Баянгазуй, Школьная, 5	t	small
40279	36805	1846	Иркутская область, Эхирит-Булагатский район, поселок Байтог, Советская, 2А	t	small
40278	36804	1845	Иркутская область, Эхирит-Булагатский район, поселок Ахины, Ленина, 29А	t	small
40296	36822	1863	Иркутская область, Эхирит-Булагатский район, поселок Алужина, Центральная, 126	t	small
40244	36771	1811	Иркутская область, Шелеховский район, Шелехов, 11 А	f	large
40249	36775	1816	Иркутская область, Шелеховский район, Шелехов, микрорайон 418	f	large
40248	36774	1815	Иркутская область, Шелеховский район, Шелехов, микрорайон 4, 30б	f	large
40247	36773	1814	Иркутская область, Шелеховский район, Шелехов, микрорайон, 148	f	large
40246	36773	1813	Иркутская область, Шелеховский район, Шелехов, микрорайон, 148	f	large
40240	36767	1807	Иркутская область, Шелеховский район, Шелехов, квартал 4, 24	f	large
40238	36765	1805	Иркутская область, Шелеховский район, Шелехов, квартал 1839	f	large
40239	36766	1806	Иркутская область, Шелеховский район, Шелехов, Орловских комсомольцев, 46	f	large
40251	36776	1818	Иркутская область, Шелеховский район, Шелехов, Микрорайон 444	f	large
40250	36776	1817	Иркутская область, Шелеховский район, Шелехов, Микрорайон 444	f	large
40241	36768	1808	Иркутская область, Шелеховский район, Шелехов, Ленина, 3	f	large
40260	36785	1827	Иркутская область, Шелеховский район, поселок Шаманка, Советская, 23	f	medium
40257	36782	1824	Иркутская область, Шелеховский район, Чистые Ключи	f	large
40259	36784	1826	Иркутская область, Шелеховский район, поселок Подкаменная, Железнодорожная, 15	t	medium
40258	36783	1825	Иркутская область, Шелеховский район, поселок Олха, Школьная, 5	f	large
40261	36786	1828	Иркутская область, Шелеховский район, поселок Моты, переулок Солнечный, 7/1	f	small
40256	36781	1823	Иркутская область, Шелеховский район, поселок Введенщина, Мира, 20	f	large
40253	36778	1820	Иркутская область, Шелеховский район, поселок Большой Луг (Ханчин), Клубная, 24	f	large
40252	36777	1819	Иркутская область, Шелеховский район, поселок Большой Луг (Ханчин), 2-я Железнодорожная, 15	f	large
40255	36780	1822	Иркутская область, Шелеховский район, поселок Баклаши, Ангарская, 104	f	large
40254	36779	1821	Иркутская область, Шелеховский район, поселок Баклаши, 8 Марта, 13	f	large
40204	36731	1771	Иркутская область, Чунский район, поселок Чунский, м-н Северный, 9	f	medium
40202	36729	1769	Иркутская область, Чунский район, поселок Чунский, Солнечная, 5	f	large
40203	36730	1770	Иркутская область, Чунский район, поселок Чунский, Советская, 24 А	f	large
40201	36728	1768	Иркутская область, Чунский район, поселок Чунский, Мира, 31	f	large
40200	36727	1767	Иркутская область, Чунский район, поселок Чунский, Ленина, 56	f	large
40199	36726	1766	Иркутская область, Чунский район, поселок Чунский, Ленина, 71	f	large
40198	36725	1765	Иркутская область, Чунский район, поселок Чунский, Коморова, 1	f	medium
40197	36724	1764	Иркутская область, Чунский район, поселок Чунский, Комарова, 1	f	medium
40196	36723	1763	Иркутская область, Чунский район, поселок Чунский, 50 лет Октября, 1 А	f	large
40195	36722	1762	Иркутская область, Чунский район, поселок Чунский, 50 лет Октября, 9 А	f	large
40218	36744	1785	Иркутская область, Чунский район, поселок Хоняки, Совхозная, 62	t	small
40223	36750	1790	Иркутская область, Чунский район, поселок Таргиз, Школьная, 5	t	small
40224	36751	1791	Иркутская область, Чунский район, поселок Сосновка, Первомайская, 6	t	medium
40233	36760	1800	Иркутская область, Чунский район, поселок Приудинск, Мира, 21	t	small
40227	36754	1794	Иркутская область, Чунский район, поселок Пионерский, Рабочая, 1	t	small
40226	36753	1793	Иркутская область, Чунский район, поселок Парчум, Центральная, 20	t	medium
40220	36747	1787	Иркутская область, Чунский район, поселок Паренда, Совхозная, 15	t	small
40213	36739	1780	Иркутская область, Чунский район, поселок Октябрьский, Советская, 12	t	small
40212	36739	1779	Иркутская область, Чунский район, поселок Октябрьский, Советская, 12	t	small
110321	36738	1778	Иркутская область, Чунский район, поселок Октябрьский, Октябрьская, 39	t	medium
40216	36742	1783	Иркутская область, Чунский район, поселок Октябрьский, Красные Зори, 39 А	f	small
40217	36743	1784	Иркутская область, Чунский район, поселок Октябрьский, Звездная, 17	f	small
40214	36740	1781	Иркутская область, Чунский район, поселок Октябрьский, Декабристов, 9	t	medium
40215	36741	1782	Иркутская область, Чунский район, поселок Октябрьский, Горького, 17	f	large
40228	36755	1795	Иркутская область, Чунский район, поселок Новочунка, Толстого, 9	f	large
40230	36757	1797	Иркутская область, Чунский район, поселок Новобалтурина, Береговая, 11	t	small
40232	36759	1799	Иркутская область, Чунский район, поселок Мухино, Школьная, 4	t	small
40206	36733	1773	Иркутская область, Чунский район, поселок Лесогорск, Шастина, 24	f	large
40208	36735	1775	Иркутская область, Чунский район, поселок Лесогорск, Рабочая, 33	f	large
40209	36736	1776	Иркутская область, Чунский район, поселок Лесогорск, Мелиораторов, 27	f	medium
40207	36734	1774	Иркутская область, Чунский район, поселок Лесогорск, Ленина, 6	f	large
40221	36748	1788	Иркутская область, Чунский район, поселок Кулиш, Совхозная, 1	t	small
40225	36752	1792	Иркутская область, Чунский район, поселок Каменск, Молодежная, 30а	t	medium
40222	36749	1789	Иркутская область, Чунский район, поселок Изыкан, Ангарская, 10	t	small
40229	36756	1796	Иркутская область, Чунский район, поселок Заводской, Первомайская, 5	t	small
40219	36746	1786	Иркутская область, Чунский район, поселок Веселый, Мира, 2	f	large
40231	36758	1798	Иркутская область, Чунский район, поселок Бунбуй, Советская, 31	t	small
40205	36732	1772	Иркутская область, Чунский район, поселок Бидога, Советская, 6	t	small
40210	36737	1777	Иркутская область, Чунский район, поселок Баянда, Зеленая, 1	t	small
40137	36675	1704	Иркутская область, Черемховский район, поселок Юлинск, Дроздова, 7	t	small
40156	36693	1723	Россия, Иркутская область, Черемховский район, Черемхово	f	medium
40149	36687	1716	Иркутская область, Черемховский район, Черемхово, проезд Краснопеева, 9	f	large
40157	36694	1724	Иркутская область, Черемховский район, Черемхово, переулок Пролетарский, 9А	f	large
40155	36692	1722	Иркутская область, Черемховский район, Черемхово, переулок Копейский, 1	f	medium
40188	36716	1755	Иркутская область, Черемховский район, Черемхово, Ярославского, 33	f	large
40190	36717	1757	Иркутская область, Черемховский район, Черемхово, Шевченко, 71	f	large
40189	36717	1756	Иркутская область, Черемховский район, Черемхово, Шевченко, 71	f	large
40175	36493	1742	Иркутская область, Черемховский район, Черемхово, Фрунзе, 1	f	medium
40166	36700	1733	Иркутская область, Черемховский район, Черемхово, Ференца Патаки, 8	f	medium
40154	35640	1721	Иркутская область, Черемховский район, Черемхово, Советская, 2	f	large
40180	36709	1747	Иркутская область, Черемховский район, Черемхово, Российская, 8	f	small
40159	36695	1726	Иркутская область, Черемховский район, Черемхово, Пролетарский переулок, 4	f	medium
40158	36695	1725	Иркутская область, Черемховский район, Черемхово, Пролетарский переулок, 4	f	large
40147	36685	1714	Иркутская область, Черемховский район, Черемхово, Первомайская, 87	f	medium
40168	36701	1735	Иркутская область, Черемховский район, Черемхово, Орджоникидзе, 15	f	large
40167	36701	1734	Иркутская область, Черемховский район, Черемхово, Орджоникидзе, 15	f	large
40179	36708	1746	Иркутская область, Черемховский район, Черемхово, Маяковского, 172	f	large
40169	36702	1736	Иркутская область, Черемховский район, Черемхово, Маяковского, 124	f	small
40174	36381	1741	Иркутская область, Черемховский район, Черемхово, Маковского, 14	f	small
86389	36721	1761	Иркутская область, Черемховский район, Черемхово, Ленина, 83	f	small
40163	36698	1730	Иркутская область, Черемховский район, Черемхово, Ленина, 25	f	medium
40162	36697	1729	Иркутская область, Черемховский район, Черемхово, Ленина, 19	f	large
40148	36686	1715	Иркутская область, Черемховский район, Черемхово, Ленина, 26	f	medium
40151	36689	1718	Иркутская область, Черемховский район, Черемхово, Красношахтерская, 91	f	medium
40182	36710	1749	Иркутская область, Черемховский район, Черемхово, Забойщика, 12	f	large
40181	36710	1748	Иркутская область, Черемховский район, Черемхово, Забойщика, 12	f	medium
40178	36707	1745	Иркутская область, Черемховский район, Черемхово, Ершовская, 26/1	f	small
40184	36712	1751	Иркутская область, Черемховский район, Черемхово, Дударского, 25	f	large
40185	36713	1752	Иркутская область, Черемховский район, Черемхово, Детская, 31	f	medium
40161	36696	1728	Иркутская область, Черемховский район, Черемхово, Декабрьских Событий, 49	f	large
40160	36696	1727	Иркутская область, Черемховский район, Черемхово, Декабрьских Событий, 49	f	medium
40191	36718	1758	Иркутская область, Черемховский район, Черемхово, Врубовая, 5	f	small
40171	36704	1738	Иркутская область, Черемховский район, Черемхово, Бердниковой, 83	f	medium
40170	36703	1737	Иркутская область, Черемховский район, Черемхово, Бердниковой, 44	f	large
40145	36683	1712	Иркутская область, Черемховский район, поселок Чемодариха, Школьная, 12	t	small
86387	36678	1707	Иркутская область, Черемховский район, поселок Худорожкина, Колхозная, 2	f	small
40135	36673	1702	Иркутская область, Черемховский район, поселок Хандагай, 3	t	small
40139	36677	1706	Иркутская область, Черемховский район, поселок Узкий Луг, Центральная, 92	t	small
40138	36676	1705	Иркутская область, Черемховский район, поселок Тунгуска, Октябрьская, 33	t	small
110320	36674	1703	Иркутская область, Черемховский район, поселок Тальники, Лесозаготовительная, 15	t	medium
110346	36856	1939	Иркутская область, Черемховский район, поселок Табук, Солнечная, 49, школа	t	medium
40143	36681	1710	Иркутская область, Черемховский район, поселок Старый Кутугун, Сосновая, 20	t	small
40102	36640	1669	Иркутская область, Черемховский район, поселок Средний Булай, Советская, 39	t	small
39688	36282	1255	Иркутская область, Черемховский район, Свирск, Хасановских боёв, 1	f	medium
39687	36282	1254	Иркутская область, Черемховский район, Свирск, Хасановских боёв, 1	f	medium
39684	36279	1251	Иркутская область, Черемховский район, Свирск, Хасановских боёв, 7	f	medium
39685	36279	1252	Иркутская область, Черемховский район, Свирск, Хасановских боёв, 7	f	medium
39683	36278	1250	Иркутская область, Черемховский район, Свирск, Тимирязева, 4	f	medium
39694	36287	1261	Иркутская область, Черемховский район, Свирск, Серегина, МОУ ООШ	f	small
39680	36275	1247	Иркутская область, Черемховский район, Свирск, О.Кошевого, 17	f	medium
39679	36275	1246	Иркутская область, Черемховский район, Свирск, О.Кошевого, 17	f	medium
39690	36284	1257	Иркутская область, Черемховский район, Свирск, Мира, 4	f	medium
39691	36284	1258	Иркутская область, Черемховский район, Свирск, Мира, 4	f	medium
39686	36280	1253	Иркутская область, Черемховский район, Свирск, Ленина, 4	f	medium
39692	36285	1259	Иркутская область, Черемховский район, Свирск, Киевская, 16	f	medium
39689	36283	1256	Иркутская область, Черемховский район, Свирск, Дзержинского, 4	f	medium
40133	36671	1700	Иркутская область, Черемховский район, поселок Саянское, Совхозная, 1	t	medium
40131	36669	1698	Иркутская область, Черемховский район, поселок Савинская, 50	t	small
40141	36679	1708	Иркутская область, Черемховский район, поселок Рысево, Российсская, 5	f	medium
40132	36670	1699	Иркутская область, Черемховский район, поселок Русская Аларь, Центральная, 38	t	small
40144	36682	1711	Иркутская область, Черемховский район, поселок Поздеева, Нагорная, 1	t	small
40110	36648	1677	Иркутская область, Черемховский район, поселок Петровка, Морозова, 26	t	small
40101	36639	1668	Иркутская область, Черемховский район, поселок Паршевникова, Северная, 20-2	t	small
110319	36667	1696	Иркутская область, Черемховский район, поселок Парфеново, Мира, 25	f	medium
40128	36666	1695	Иркутская область, Черемховский район, поселок Онот, Школьная, 8	t	medium
40126	36664	1693	Иркутская область, Черемховский район, поселок Новостройка, Школьная, 30	t	medium
110318	36662	1691	Иркутская область, Черемховский район, поселок Новогромово, Советская, 17	f	medium
110317	36660	1689	Иркутская область, Черемховский район, поселок Нижняя Иреть, Советская, 10	t	medium
40116	36654	1683	Иркутская область, Черемховский район, поселок Нены, Школьная, 24	f	small
39907	36481	1474	Иркутская область, Черемховский район, поселок Мышелевка, Щорса, 8В, кв.46	t	small
39905	36479	1472	Иркутская область, Черемховский район, поселок Мышелевка, Ленина, 31	t	medium
39909	36483	1476	Иркутская область, Черемховский район, поселок Мишелевка, переулок Бельский, 6	t	medium
40119	36657	1686	Иркутская область, Черемховский район, поселок Михайловка, Советская, 8а	f	large
40120	36658	1687	Иркутская область, Черемховский район, поселок Михайловка, Заречная, 13	f	small
40121	36659	1688	Иркутская область, Черемховский район, поселок Михайловка, Горького, 1а	f	large
40118	36656	1685	Иркутская область, Черемховский район, поселок Михайловка, Iкв, 6	f	large
40117	36655	1684	Иркутская область, Черемховский район, поселок Михайловка, IIкв, 5	f	large
40114	36652	1681	Иркутская область, Черемховский район, поселок Лохово, Школьная, 27	f	medium
40106	36644	1673	Иркутская область, Черемховский район, поселок Козлова, Нижняя, 12	f	small
40104	36642	1671	Иркутская область, Черемховский район, поселок Ключи, Школьная, 3а	t	small
40146	36684	1713	Иркутская область, Черемховский район, поселок Кирзавод, Полевая, 22	t	small
110347	36857	1940	Иркутская область, Черемховский район, поселок Катом, Тополиная, 4, клуб	t	medium
40112	36650	1679	Иркутская область, Черемховский район, поселок Каменно-Ангарск, Совхозная, 1	f	small
86386	36665	1694	Иркутская область, Черемховский район, поселок Инга, Берёзовая, 13-1	t	small
110316	36647	1676	Иркутская область, Черемховский район, поселок Зерновое, Иркутская, 5	f	medium
40115	36653	1682	Россия, Иркутская область, Черемховский район, поселок Жмурова	f	small
40134	36672	1701	Иркутская область, Черемховский район, поселок Жалгай, 5	t	small
40107	36645	1674	Иркутская область, Черемховский район, поселок Голуметь, Кирова	t	large
110345	36855	1938	Иркутская область, Черемховский район, поселок Голуметь, Калинина, 10а, ДК	t	medium
40130	36668	1697	Иркутская область, Черемховский район, поселок Герасимова, улица Центральная, 48	t	small
40108	36646	1675	Иркутская область, Черемховский район, поселок Верхняя Иреть	t	small
40105	36643	1672	Иркутская область, Черемховский район, поселок Верхний Булай, Булайская, 48	t	small
40103	36641	1670	Иркутская область, Черемховский район, поселок Бельск, Иванова, 34а	f	large
86388	36680	1709	Иркутская область, Черемховский район, поселок Белобородова, Центральная, 1-1	f	small
40111	36649	1678	Иркутская область, Черемховский район, поселок Бархатова, Ангарская, 11	f	small
40113	36651	1680	Иркутская область, Черемховский район, поселок Балухарь, Школьная, 2	t	small
40123	36661	1690	Иркутская область, Черемховский район, поселок Бажей, Луговая, 30	t	small
40100	36638	1667	Иркутская область, Черемховский район, поселок Алехино, Площадь Труда, 12	f	medium
40090	36846	1904	Иркутская область, Усть-Удинский район, поселок Юголок, Мира, 1	t	medium
40095	36850	1909	Иркутская область, Усть-Удинский район, поселок Чичкова, Центральная, 20	f	small
86400	36631	1648	Иркутская область, Усть-Удинский район, поселок Халюты, Центральная, 3а	t	small
40086	36625	1657	Россия, Иркутская область, Усть-Удинский район, поселок Усть-Уда	f	large
86402	36625	1660	Россия, Иркутская область, Усть-Удинский район, поселок Усть-Уда	f	small
110314	36625	1661	Россия, Иркутская область, Усть-Удинский район, поселок Усть-Уда	t	small
110313	36625	1659	Россия, Иркутская область, Усть-Удинский район, поселок Усть-Уда	t	small
110312	36625	1658	Россия, Иркутская область, Усть-Удинский район, поселок Усть-Уда	t	small
40085	36635	1652	Иркутская область, Усть-Удинский район, поселок Усть-Уда, Пионерская, 10	f	large
110311	36635	1656	Иркутская область, Усть-Удинский район, поселок Усть-Уда, Пионерская, 10	t	small
86401	36635	1655	Иркутская область, Усть-Удинский район, поселок Усть-Уда, Пионерская, 10	f	small
110310	36635	1654	Иркутская область, Усть-Удинский район, поселок Усть-Уда, Пионерская, 10	t	small
110309	36635	1653	Иркутская область, Усть-Удинский район, поселок Усть-Уда, Пионерская, 10	t	small
40094	36798	1908	Иркутская область, Усть-Удинский район, поселок Усть-Малой, Ленина, 14	t	small
39656	36256	1223	Иркутская область, Усть-Удинский район, поселок Тагай, Школьная, 1	t	small
86408	36845	1897	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
110334	36845	1903	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
110333	36845	1902	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
110332	36845	1900	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
110331	36845	1899	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
110330	36845	1898	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
110329	36845	1896	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
110328	36845	1895	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
86409	36845	1901	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	small
40089	36845	1894	Иркутская область, Усть-Удинский район, поселок Средняя Муя, Лесная, 5	t	medium
86405	36637	1889	Иркутская область, Усть-Удинский район, поселок Светлолобово, Совхозная, 2А	f	small
86407	36637	1893	Иркутская область, Усть-Удинский район, поселок Светлолобово, Совхозная, 2А	t	small
110326	36637	1890	Иркутская область, Усть-Удинский район, поселок Светлолобово, Совхозная, 2А	t	small
110327	36637	1892	Иркутская область, Усть-Удинский район, поселок Светлолобово, Совхозная, 2А	t	small
86406	36637	1891	Иркутская область, Усть-Удинский район, поселок Светлолобово, Совхозная, 2А	t	small
40088	36637	1665	Иркутская область, Усть-Удинский район, поселок Светлолобово, Совхозная, 2А	f	small
110315	36637	1666	Иркутская область, Усть-Удинский район, поселок Светлолобово, Совхозная, 2А	t	small
110344	36854	1937	Иркутская область, Усть-Удинский район, поселок Подволочное, Советская, 16	t	small
86385	36854	1936	Иркутская область, Усть-Удинский район, поселок Подволочное, Советская, 16	t	small
86422	36854	1935	Иркутская область, Усть-Удинский район, поселок Подволочное, Советская, 16	t	small
86420	36854	1933	Иркутская область, Усть-Удинский район, поселок Подволочное, Советская, 16	t	small
86419	36854	1932	Иркутская область, Усть-Удинский район, поселок Подволочное, Советская, 16	t	small
86421	36854	1934	Иркутская область, Усть-Удинский район, поселок Подволочное, Советская, 16	t	small
40099	36854	1931	Иркутская область, Усть-Удинский район, поселок Подволочное, Советская, 16	t	small
38950	35621	516	Россия, Иркутская область, Усть-Удинский район, поселок Новая Уда	f	large
40093	36849	1907	Иркутская область, Усть-Удинский район, поселок Новая Уда, Юбилейная, 1	t	medium
110308	36632	1649	Иркутская область, Усть-Удинский район, поселок Молька, Радищева, 25	f	medium
40087	36636	1662	Иркутская область, Усть-Удинский район, поселок Михайловщина, Набережная, 9	f	small
86403	36636	1663	Иркутская область, Усть-Удинский район, поселок Михайловщина, Набережная, 9	f	small
86404	36636	1664	Иркутская область, Усть-Удинский район, поселок Михайловщина, Набережная, 9	t	small
40080	36630	1647	Иркутская область, Усть-Удинский район, поселок Малышевка, Центральная, 23	f	medium
40083	36633	1650	Иркутская область, Усть-Удинский район, поселок Лобагай, Советская, 18	t	small
110335	36851	1916	Иркутская область, Усть-Удинский район, поселок Ключи, Комарова, 4	t	small
86414	36851	1915	Иркутская область, Усть-Удинский район, поселок Ключи, Комарова, 4	t	small
86413	36851	1914	Иркутская область, Усть-Удинский район, поселок Ключи, Комарова, 4	t	small
80097	33470	47	Забайкальский край, Чита, Белорусская, 1	f	large
86412	36851	1913	Иркутская область, Усть-Удинский район, поселок Ключи, Комарова, 4	t	small
86410	36851	1911	Иркутская область, Усть-Удинский район, поселок Ключи, Комарова, 4	t	small
86411	36851	1912	Иркутская область, Усть-Удинский район, поселок Ключи, Комарова, 4	t	small
40096	36851	1910	Иркутская область, Усть-Удинский район, поселок Ключи, Комарова, 4	t	small
40091	36847	1905	Иркутская область, Усть-Удинский район, поселок Кижа, Мира, 4	t	small
40084	36634	1651	Иркутская область, Усть-Удинский район, поселок Игжей, Некрасова, 1	f	medium
40092	36848	1906	Иркутская область, Усть-Удинский район, поселок Балаганка, Рабочая, 41	t	small
110342	36853	1929	Иркутская область, Усть-Удинский район, поселок Аталанка, Школьная, 8	t	small
110343	36853	1930	Иркутская область, Усть-Удинский район, поселок Аталанка, Школьная, 8	t	small
110341	36853	1927	Иркутская область, Усть-Удинский район, поселок Аталанка, Школьная, 8	t	small
110340	36853	1926	Иркутская область, Усть-Удинский район, поселок Аталанка, Школьная, 8	t	small
110339	36853	1925	Иркутская область, Усть-Удинский район, поселок Аталанка, Школьная, 8	t	small
86418	36853	1928	Иркутская область, Усть-Удинский район, поселок Аталанка, Школьная, 8	t	small
40098	36853	1924	Иркутская область, Усть-Удинский район, поселок Аталанка, Школьная, 8	t	small
86417	36852	1923	Иркутская область, Усть-Удинский район, поселок Аносово, Набережная, 8	t	small
110338	36852	1922	Иркутская область, Усть-Удинский район, поселок Аносово, Набережная, 8	t	small
110337	36852	1920	Иркутская область, Усть-Удинский район, поселок Аносово, Набережная, 8	t	small
110336	36852	1918	Иркутская область, Усть-Удинский район, поселок Аносово, Набережная, 8	t	small
86416	36852	1921	Иркутская область, Усть-Удинский район, поселок Аносово, Набережная, 8	t	small
86415	36852	1919	Иркутская область, Усть-Удинский район, поселок Аносово, Набережная, 8	t	small
40097	36852	1917	Иркутская область, Усть-Удинский район, поселок Аносово, Набережная, 8	t	medium
40045	36594	1612	Иркутская область, Усть-Кутский район, поселок Янталь, улица Лесная, 10	f	large
40073	36622	1640	Иркутская область, Усть-Кутский район, поселок Подымахино, Мира, 1	t	medium
40079	36629	1646	Иркутская область, Усть-Кутский район, поселок Ния, Тбилисская, 5	t	medium
39334	35937	901	Иркутская область, Усть-Кутский район, поселок Небель, Молодежная, 10	t	small
40074	36623	1641	Иркутская область, Усть-Кутский район, поселок Верхнемарково, Центральная, 4	t	small
40076	36626	1643	Иркутская область, Усть-Кутский район, поселок Верхнемарково, Фонтанная, 7а	t	medium
40077	36627	1644	Иркутская область, Усть-Кутский район, поселок Верхнемарково, 40 лет Победы, 47	t	small
39989	36552	1556	Иркутская область, Усть-Илимский район, р.п. Железнодорожный, Ленина, 68	f	large
39994	36556	1561	Иркутская область, Усть-Илимский район, поселок Эдучанка, Ермака, 4	f	medium
39995	36557	1562	Иркутская область, Усть-Илимский район, поселок Эдучанка, Дзержинского, 9	f	medium
40030	36582	1597	Иркутская область, Усть-Илимский район, Усть-Илимск, проспект Дружбы Народов, 70	f	large
40029	36582	1596	Иркутская область, Усть-Илимский район, Усть-Илимск, проспект Дружбы Народов, 70	f	large
40028	36582	1595	Иркутская область, Усть-Илимский район, Усть-Илимск, проспект Дружбы Народов, 70	f	large
40027	36581	1594	Иркутская область, Усть-Илимский район, Усть-Илимск, проспект Дружбы Народов, 38	f	large
40026	36581	1593	Иркутская область, Усть-Илимский район, Усть-Илимск, проспект Дружбы Народов, 38	f	large
40037	36586	1604	Иркутская область, Усть-Илимский район, Усть-Илимск, Энгельса, 7	f	large
40038	36585	1605	Иркутская область, Усть-Илимский район, Усть-Илимск, Энгельса, 7	f	large
40036	36585	1603	Иркутская область, Усть-Илимский район, Усть-Илимск, Энгельса, 7	f	large
40035	36585	1602	Иркутская область, Усть-Илимский район, Усть-Илимск, Энгельса, 7	f	large
40007	36568	1574	Иркутская область, Усть-Илимский район, Усть-Илимск, Солнечная, 2	f	medium
40003	36565	1570	Иркутская область, Усть-Илимский район, Усть-Илимск, Наймушина, 30	f	large
40034	36584	1601	Иркутская область, Усть-Илимский район, Усть-Илимск, Карла Маркса, 45	f	large
40021	36577	1588	Иркутская область, Усть-Илимский район, Усть-Илимск, Карла Маркса, 21	f	large
40020	36577	1587	Иркутская область, Усть-Илимский район, Усть-Илимск, Карла Маркса, 21	f	large
40019	36576	1586	Иркутская область, Усть-Илимский район, Усть-Илимск, Карла Маркса, 7	f	large
40018	36576	1585	Иркутская область, Усть-Илимский район, Усть-Илимск, Карла Маркса, 7	f	large
40015	36574	1582	Иркутская область, Усть-Илимский район, Усть-Илимск, Героев Труда, 19	f	large
40025	36579	1592	Иркутская область, Усть-Илимский район, Усть-Илимск, Георгия Димитрова, 10	f	large
40023	36579	1590	Иркутская область, Усть-Илимский район, Усть-Илимск, Георгия Димитрова, 10	f	large
40002	36564	1569	Иркутская область, Усть-Илимский район, Усть-Илимск, Булгакова, 7	f	large
40010	36570	1577	Иркутская область, Усть-Илимский район, Усть-Илимск, Братская, 45	f	large
40008	36569	1575	Иркутская область, Усть-Илимский район, Усть-Илимск, Братская, 8	f	medium
40033	36583	1600	Иркутская область, Усть-Илимский район, Усть- Илимск, Карла Маркса, 45	f	large
40032	36583	1599	Иркутская область, Усть-Илимский район, Усть- Илимск, Карла Маркса, 45	f	large
40031	36583	1598	Иркутская область, Усть-Илимский район, Усть- Илимск, Карла Маркса, 45	f	large
68148	36550	1553	Иркутская область, Усть-Илимский район, поселок Тубинский, Спортивная, 13	f	large
68149	36560	1565	Иркутская область, Усть-Илимский район, поселок Седаново, Солнечная, 15а	f	large
39997	36559	1564	Иркутская область, Усть-Илимский район, поселок Подъеланка, Мира, 8	t	small
39985	36549	1552	Иркутская область, Усть-Илимский район, поселок Невон, Сказочная, 1	f	large
68147	36548	1551	Иркутская область, Усть-Илимский район, поселок Невон, Кеульская, 9	f	large
68146	36547	1550	Иркутская область, Усть-Илимский район, поселок Кеуль, Ленина, 4	t	large
39991	36553	1558	Иркутская область, Усть-Илимский район, поселок Железнодорожный, Ленина, 30 а	f	large
39990	36553	1557	Иркутская область, Усть-Илимский район, поселок Железнодорожный, Ленина, 30 а	f	large
39932	36506	1499	Иркутская область, Усть-Илимский район, поселок Железнодорожный, Комсомольская, 28А	t	large
39988	36551	1555	Иркутская область, Усть-Илимский район, поселок Железнодорожный, Дорожная, 4	f	large
39987	36551	1554	Иркутская область, Усть-Илимский район, поселок Железнодорожный, Дорожная, 4	f	large
39996	36558	1563	Иркутская область, Усть-Илимский район, поселок Ершово, Комарова, 15	t	medium
110306	36554	1559	Иркутская область, Усть-Илимский район, поселок Бадарминск, Школьная, 6	f	medium
39993	36555	1560	Иркутская область, Усть-Илимский район, поселок Бадарма, Молодежная, 3	t	small
39936	36510	1503	Иркутская область, Усольский район, поселок Целоты, Мира, 35	t	small
39919	36494	1486	Иркутская область, Усольский район, поселок Холмушино, Набережная, 86	t	small
39944	36518	1511	Иркутская область, Усольский район, поселок Ходарей, Набережная, 20	t	small
39911	36485	1478	Иркутская область, Усольский район, поселок Хайта, Центральная, ОСП ДК с.Хайта	t	small
39931	36505	1498	Иркутская область, Усольский район, поселок Тельма, Крупской, 11	f	large
39930	36504	1497	Иркутская область, Усольский район, поселок Тельма, 2-я Советская, 4	f	large
39934	36508	1501	Иркутская область, Усольский район, поселок Тельма, 2-я Железнодорожная, 1А	f	small
39943	36517	1510	Иркутская область, Усольский район, поселок Тальяны, Клубная, 2	t	medium
39923	36497	1490	Иркутская область, Усольский район, поселок Тайтурка, Пеньковского, 8	f	large
39921	36495	1488	Иркутская область, Усольский район, поселок Тайтурка, Ленина, 21	f	medium
39920	36495	1487	Иркутская область, Усольский район, поселок Тайтурка, Ленина, 21	f	small
39922	36496	1489	Иркутская область, Усольский район, поселок Тайтурка, Гоголя, 2	f	large
39927	36501	1494	Иркутская область, Усольский район, поселок Средний, Дом офицеров п.Средний	t	large
39926	36500	1493	Иркутская область, Усольский район, поселок Средний, 3-я Степная, 14	t	large
68145	36486	1479	Иркутская область, Усольский район, поселок Сосновка, Лесная, 2-б, школа	f	large
39941	36515	1508	Иркутская область, Усольский район, поселок Раздолье, Мира, 25	t	medium
86399	36516	1509	Иркутская область, Усольский район, поселок Октябрьский, Октябрьская, 24	t	small
39928	36502	1495	Иркутская область, Усольский район, поселок Новомальтинск, Квартал, 21	f	large
39938	36512	1505	Россия, Иркутская область, Усольский район, поселок Новожилкино	f	large
39917	36491	1484	Иркутская область, Усольский район, поселок Мальта, Школьная, 21А	f	large
39916	36490	1483	Иркутская область, Усольский район, поселок Мальта, Разведочная, 17	t	medium
39918	36492	1485	Иркутская область, Усольский район, поселок Мальта, Ленина, 83	t	small
39924	36498	1491	Иркутская область, Усольский район, поселок Кочерикова, Главная, ОСП клуб д.Кочерикова	t	small
39939	36513	1506	Иркутская область, Усольский район, поселок Ключевая, Рабочая, 7А	t	small
39925	36499	1492	Иркутская область, Усольский район, поселок Буреть, Набережная, ОСП клуб д.Буреть	t	small
39935	36509	1502	Иркутская область, Усольский район, поселок Большой Елань, Победы, 2	f	large
39937	36511	1504	Иркутская область, Усольский район, поселок Большежилкина, Мира, 21, кв.2	t	medium
39915	36489	1482	Иркутская область, Усольский район, поселок Белореченский, 109	f	large
39914	36488	1481	Иркутская область, Усольский район, поселок Белореченский, 106	f	large
39913	36487	1480	Иркутская область, Усольский район, поселок Белореченский, 48	f	large
39929	36503	1496	Иркутская область, Усольский район, поселок Бадай, Совхозная, 11	t	small
39825	36417	1392	Иркутская область, Тулунский район, п.1 отделение Государственной селекционной станции, Зерновая, 20а, п.1 отделение Государственной селекционной станции	t	small
39830	36422	1397	Иркутская область, Тулунский район, поселок Шуба, Клубная, 2	t	medium
68144	36419	1394	Иркутская область, Тулунский район, поселок Шерагул, Гагарина, 20	f	large
39821	36414	1388	Иркутская область, Тулунский район, поселок Центральные Мастерские, Докучаева, 2	t	medium
39857	36445	1424	Иркутская область, Тулунский район, поселок Целинные Земли, Шолохова, 16	f	small
39831	36423	1398	Иркутская область, Тулунский район, поселок Харгажин, Нижняя, 5	t	small
39832	36424	1399	Иркутская область, Тулунский район, поселок Уталай, Центральная, 25	t	small
39816	36409	1383	Иркутская область, Тулунский район, поселок Утай, Нагорная, 30	t	small
39859	36447	1426	Иркутская область, Тулунский район, поселок Усть-Кульск, Школьная, 11	t	small
39853	36442	1420	Иркутская область, Тулунский район, поселок Умыган, И.Каторжного, 77	f	medium
39820	36413	1387	Иркутская область, Тулунский район, поселок Уйгат, Школьная, 1	t	small
39872	36456	1438	Иркутская область, Тулунский район, Тулун, микрорайон Угольщиков, 34	t	medium
39871	36455	1437	Иркутская область, Тулунский район, Тулун, микрорайон Угольщиков, 4	t	medium
39863	36449	1429	Иркутская область, Тулунский район, Тулун, Угольная, 8 Г	f	medium
39888	35095	1454	Иркутская область, Тулунский район, Тулун, Сигаева, 17	f	large
39865	36450	1431	Иркутская область, Тулунский район, Тулун, Сибстроя, 11	f	medium
39864	36450	1430	Иркутская область, Тулунский район, Тулун, Сибстроя, 11	f	medium
39897	36473	1460	Иркутская область, Тулунский район, Тулун, Пугачева, 9	f	medium
39889	36468	1455	Иркутская область, Тулунский район, Тулун, Протасюка, 49	f	large
110303	36415	1389	Иркутская область, Тулунский район, Тулун, Мичурина, 36, п.4 отделение Государственной селекционной станции	t	medium
39868	36453	1434	Иркутская область, Тулунский район, Тулун, Мира, 3	t	medium
39900	36475	1463	Иркутская область, Тулунский район, Тулун, Ломоносова, 26	f	medium
110305	36475	1462	Иркутская область, Тулунский район, Тулун, Ломоносова, 26	f	medium
39883	36463	1449	Иркутская область, Тулунский район, Тулун, Ленина, 3А	f	medium
39882	36463	1448	Иркутская область, Тулунский район, Тулун, Ленина, 3А	f	medium
39880	36461	1446	Иркутская область, Тулунский район, Тулун, Ленина, 96	f	medium
39879	36460	1445	Иркутская область, Тулунский район, Тулун, Ленина, 91	f	large
39878	36459	1444	Иркутская область, Тулунский район, Тулун, Ленина, 101	f	medium
39877	36459	1443	Иркутская область, Тулунский район, Тулун, Ленина, 101	f	medium
39890	36469	1456	Иркутская область, Тулунский район, Тулун, Красноармейская, 4	f	medium
39862	36448	1428	Иркутская область, Тулунский район, Тулун, Заречная 2-я, 9	f	medium
39876	36458	1442	Иркутская область, Тулунский район, Тулун, Жданова, 1 Б	t	medium
39875	36458	1441	Иркутская область, Тулунский район, Тулун, Жданова, 1 Б	t	medium
39892	36470	1457	Иркутская область, Тулунский район, Тулун, Ермакова, 5	f	medium
39894	36471	1458	Иркутская область, Тулунский район, Тулун, Горячкина, 12	f	medium
39902	36476	1465	Иркутская область, Тулунский район, Тулун, Блюхера, 60	f	large
39901	36476	1464	Иркутская область, Тулунский район, Тулун, Блюхера, 60	f	large
39828	36420	1395	Иркутская область, Тулунский район, поселок Трактовая, Лесная, 10	t	small
86395	36412	1386	Иркутская область, Тулунский район, поселок Сибиряк, Садовая, 13	t	small
39815	36398	1382	Иркутская область, Тулунский район, поселок Северный Кадуй, Новая, 8	t	small
39837	36429	1404	Иркутская область, Тулунский район, поселок Петровск, Центральная, 14	t	small
86396	36428	1403	Иркутская область, Тулунский район, поселок Перфилово, 50 лет Октября, 39	t	small
39811	36332	1378	Иркутская область, Тулунский район, поселок Паберега, Набережная, 29	t	small
39842	36434	1409	Иркутская область, Тулунский район, поселок Одон, Набережная, 23	t	small
39829	36421	1396	Иркутская область, Тулунский район, поселок Новотроицк, Школьная, 20	t	small
39854	36443	1421	Иркутская область, Тулунский район, поселок Никитаево, Кировская, 47	t	medium
39835	36427	1402	Иркутская область, Тулунский район, поселок Нижний Манут, Набережная, 24	t	small
39848	36438	1415	Иркутская область, Тулунский район, поселок Нижний Бурбук, Зеленая, 4	t	small
39850	36440	1417	Иркутская область, Тулунский район, поселок Мугун, Ленина, 61	t	medium
68141	36410	1384	Иркутская область, Тулунский район, поселок Котик, Центральная, 1а	t	large
39849	36439	1416	Иркутская область, Тулунский район, поселок Ишидей, Школьная, 37	t	small
39844	36436	1411	Иркутская область, Тулунский район, поселок Икей, пер.Пионерский, 9	t	medium
39841	36433	1408	Иркутская область, Тулунский район, поселок Изегол, Ленина, 38	t	small
39818	36411	1385	Иркутская область, Тулунский район, поселок Заусаево, Кирова, 48	t	small
39840	36432	1407	Иркутская область, Тулунский район, поселок Едогон, Ленина, 70	t	medium
110304	36431	1406	Иркутская область, Тулунский район, поселок Евдокимовский, Центральная, 19	t	medium
39858	36446	1425	Иркутская область, Тулунский район, поселок Гуран, Бурлова, 36	f	medium
39833	36425	1400	Иркутская область, Тулунский район, поселок Гадалей, Степная, 1а	t	medium
86397	36435	1410	Иркутская область, Тулунский район, поселок Владимировка, Полевая, 5	t	small
39810	36408	1377	Иркутская область, Тулунский район, поселок Бурхун, Трактовая, 13	t	small
39824	36416	1391	Иркутская область, Тулунский район, поселок Булюшкина, Школьная, 1	t	small
39813	36389	1381	Иркутская область, Тулунский район, поселок Будагово, Школьная, 12	f	small
39838	36430	1405	Иркутская область, Тулунский район, поселок Бадар, Братская, 20	t	medium
39855	36444	1422	Иркутская область, Тулунский район, поселок Афанасьева, Ленина, 8	f	small
86398	36437	1414	Иркутская область, Тулунский район, поселок Аршан, Школьная, 1	t	small
39852	36441	1419	Иркутская область, Тулунский район, поселок Алгатуй, Солнечная, 16	t	medium
39834	36426	1401	Иркутская область, Тулунский район, поселок Азей (Листвянка), Школьная, 27	t	small
39826	36418	1393	Иркутская область, Тулунский район, поселок Азей (Листвянка), Привокзальная, 12	t	medium
39782	36380	1349	Иркутская область, Тайшетский район, поселок Юрты, Школьная, 9	f	medium
39785	36383	1352	Иркутская область, Тайшетский район, поселок Юрты, Советская, 25А	f	medium
39784	36383	1351	Иркутская область, Тайшетский район, поселок Юрты, Советская, 25А	f	medium
39781	36379	1348	Иркутская область, Тайшетский район, поселок Юрты, Матросова, 5	f	medium
39783	36382	1350	Иркутская область, Тайшетский район, поселок Юрты, Дружбы, 6	f	medium
39741	36336	1308	Иркутская область, Тайшетский район, поселок Шиткино, Кирова, 19	f	medium
39742	36337	1309	Иркутская область, Тайшетский район, поселок Шиткино, Барковская, 21	f	medium
110301	36357	1327	Иркутская область, Тайшетский район, поселок Шелехово, Первомайская, 8	f	medium
39736	36330	1303	Иркутская область, Тайшетский район, поселок Шелаево, Советская, 49	t	medium
39733	36327	1300	Иркутская область, Тайшетский район, поселок Черчет, Ленина, 57	t	small
39764	36361	1331	Иркутская область, Тайшетский район, поселок Троицк, Центральная, 13	t	small
39731	36325	1298	Иркутская область, Тайшетский район, поселок Тремина, Центральная, 55	t	small
39766	36364	1333	Иркутская область, Тайшетский район, поселок Тимирязева, Зеленая, 29	t	small
39725	36319	1292	Иркутская область, Тайшетский район, поселок Тамтачет, Гайнулина, 1В	t	medium
86377	36354	1324	Иркутская область, Тайшетский район, поселок Талая, Советская, 109	t	small
39804	36402	1371	Иркутская область, Тайшетский район, Тайшет, поселок 10-го сельхоза	t	small
86382	36369	1338	Иркутская область, Тайшетский район, поселок Старый Акульшет, Бирюсинская, 30	t	small
39758	36355	1325	Иркутская область, Тайшетский район, поселок Соляная, Береговая, 3	f	medium
39759	36356	1326	Иркутская область, Тайшетский район, поселок Сереброво, Профсоюзная, 19	t	small
86380	36365	1334	Иркутская область, Тайшетский район, поселок Сафроновка, Зеленая, 55	t	small
86379	36363	1332	Иркутская область, Тайшетский район, поселок Рождественка, Колхозная, 6	t	small
39754	36350	1321	Иркутская область, Тайшетский район, поселок Разгон, Железнодорожная, 4	t	small
39768	36366	1335	Иркутская область, Тайшетский район, поселок Половино-Черемхово, Трактовая, 78	f	medium
39723	36317	1290	Иркутская область, Тайшетский район, поселок Полинчет, Центральная, 9	t	small
38922	35591	488	Иркутская область, Тайшетский район, поселок Покровка, Центральная, 28 А	t	medium
86375	36329	1302	Иркутская область, Тайшетский район, поселок Пея, Капустина, 5	t	small
39773	36371	1340	Иркутская область, Тайшетский район, поселок Парижская Коммуна, Школьная, 18	t	small
39753	36349	1320	Иркутская область, Тайшетский район, поселок Облепиха, Трактовая, 15а	t	small
39751	36347	1318	Иркутская область, Тайшетский район, деревня Новый Акульшет, Трактовая, 44	t	small
39732	36326	1299	Иркутская область, Тайшетский район, поселок Новотремино, Зеленая, 13	t	small
39729	36323	1296	Иркутская область, Тайшетский район, поселок Новобирюсинский, Советская, 9	t	medium
39728	36322	1295	Иркутская область, Тайшетский район, поселок Новобирюсинский, Ленина, 22, помещение администрации	t	medium
39755	36351	1322	Иркутская область, Тайшетский район, поселок Николаевка, 40 лет Октября, 17, ДК	t	medium
86376	36334	1306	Иркутская область, Тайшетский район, поселок Нижняя Заимка, Пионерская, 1	t	small
39748	36344	1315	Иркутская область, Тайшетский район, поселок Невельская, Транспортная, 2, станции Невельская	t	small
39734	36328	1301	Иркутская область, Тайшетский район, поселок Мирный, Школьная, 11А	t	medium
39769	36367	1336	Иркутская область, Тайшетский район, поселок Конторка, Трактовая, 61	t	small
39740	36335	1307	Иркутская область, Тайшетский район, поселок Коновалова, Трактовая, 12А	t	small
39724	36318	1291	Иркутская область, Тайшетский район, поселок Кондратьево, Центральная, 36	t	small
39746	36341	1313	Иркутская область, Тайшетский район, поселок Квиток, Первомайская, 52	t	large
39749	36345	1316	Иркутская область, Тайшетский район, поселок Квиток, Октябрьская, 10	t	small
39747	36343	1314	Иркутская область, Тайшетский район, поселок Квиток, Калинина, 31	t	large
39738	36333	1305	Иркутская область, Тайшетский район, поселок Иванов Мыс, Молодежная, 12	t	small
86378	36360	1330	Иркутская область, Тайшетский район, поселок Заречное, Ленина, 16	t	small
39730	36324	1297	Иркутская область, Тайшетский район, поселок Джогино, Больничная, 8	f	small
39726	36320	1293	Иркутская область, Тайшетский район, поселок Горевая, Мира, 4	t	small
39737	36331	1304	Иркутская область, Тайшетский район, поселок Бузыканово, Школьная, 1	f	small
39743	36338	1310	Иркутская область, Тайшетский район, поселок Борисово, Центральная, 15А	t	small
39775	36373	1342	Иркутская область, Тайшетский район, Бирюсинск, Советская, 19А	t	large
39778	36376	1345	Иркутская область, Тайшетский район, Бирюсинск, Октябрьская, 10	t	large
39779	36377	1346	Иркутская область, Тайшетский район, Бирюсинск, Ленина, 65	t	large
39776	36374	1343	Иркутская область, Тайшетский район, Бирюсинск, Дружбы, 49	t	large
86381	36368	1337	Иркутская область, Тайшетский район, поселок Бирюса, переулок Школьный, 14	t	small
110300	36346	1317	Иркутская область, Тайшетский район, поселок Березовка, Школьная, 20	t	medium
86383	36372	1341	Иркутская область, Тайшетский район, поселок Акульшет, Юбилейная, 1	t	small
39716	36309	1283	Россия, Иркутская область, Слюдянский район, поселок Утулик	f	medium
39720	36314	1287	Иркутская область, Слюдянский район, поселок Тибельти, Набережная, 5	t	small
39711	36304	1278	Иркутская область, Слюдянский район, поселок Солзан, Терешковой, 13 А	t	small
39697	36290	1264	Иркутская область, Слюдянский район, Слюдянка, Ржанова, 2	f	large
68140	36292	1266	Иркутская область, Слюдянский район, Слюдянка, Ленина, 83б	f	large
39698	36291	1265	Иркутская область, Слюдянский район, Слюдянка, Ленина, 90	f	large
39702	36295	1269	Иркутская область, Слюдянский район, Слюдянка, Куприна, 2	f	large
39700	36293	1267	Иркутская область, Слюдянский район, Слюдянка, Гранитная, 1	f	large
39695	36288	1262	Иркутская область, Слюдянский район, Слюдянка, Героя Ивана Тонконог, 2	f	large
39718	36312	1285	Иркутская область, Слюдянский район, поселок Новоснежная	t	small
39717	36310	1284	Россия, Иркутская область, Слюдянский район, поселок Мурино	t	small
39722	36316	1289	Россия, Иркутская область, Слюдянский район, поселок Маритуй, станция Маритуй	t	small
39940	36514	1507	Иркутская область, Слюдянский район, поселок Култук, Трактовая, 8	f	small
39712	36305	1279	Иркутская область, Слюдянский район, поселок Култук, Кооперативный переулок, 6 Б	f	large
39713	36306	1280	Иркутская область, Слюдянский район, поселок Култук, Кирова, 165	f	large
86394	36841	1887	Иркутская область, Слюдянский район, поселок Быстрая, Советская, 36	f	small
39719	36313	1286	Иркутская область, Слюдянский район, поселок Быстрая, Советская, 50	f	small
39709	36302	1276	Иркутская область, Слюдянский район, Байкальск, микрорайон Южный 2 квартал, 51	f	large
39705	36298	1272	Иркутская область, Слюдянский район, Байкальск, Школьный переулок, 1	f	large
39708	36301	1275	Иркутская область, Слюдянский район, Байкальск, Гагарина, 146 Б	f	large
39707	36300	1274	Иркутская область, Слюдянский район, Байкальск, Гагарина, 208	f	large
39706	36299	1273	Иркутская область, Слюдянский район, Байкальск, Гагарина, 211	f	large
39710	36303	1277	Иркутская область, Слюдянский район, Байкальск, 3 квартал	f	large
39721	36315	1288	Иркутская область, Слюдянский район, Байкал, Набережная, 10	t	small
39715	36308	1282	Иркутская область, Слюдянский район, поселок Андрияновская, п.ж.д.ст.Андриановская	t	small
39714	36307	1281	Иркутская область, Слюдянский район, поселок Ангасолка, ж.д.ст.Ангасолка	t	small
39626	36226	1193	Иркутская область, Осинский район, поселок Шотой, Шотойская, 11	t	small
39633	36233	1200	Иркутская область, Осинский район, поселок Хокта, Центральная, 8	t	small
39639	36239	1206	Иркутская область, Осинский район, поселок Харай, Озерная, 5	t	small
39651	36251	1218	Иркутская область, Осинский район, поселок Хайга, Правая Хайга, 2	f	small
39642	36242	1209	Иркутская область, Осинский район, поселок Усть-Алтан, Ленина, 22	f	medium
39655	36255	1222	Иркутская область, Осинский район, поселок Унгин, Школьная, 8	f	medium
39631	36231	1198	Иркутская область, Осинский район, поселок Русские Янгуты, Школьная, 1	f	medium
39643	36243	1210	Иркутская область, Осинский район, поселок Рассвет, Ленина, 2а	f	small
39629	36229	1196	Иркутская область, Осинский район, поселок Прохоровка, Ворошилова, 6	t	small
39649	36249	1216	Иркутская область, Осинский район, поселок Приморский, Октябрьская, 16	f	large
68139	36238	1205	Иркутская область, Осинский район, поселок Оса, Свердлова, 83	f	large
68138	36237	1204	Иркутская область, Осинский район, поселок Оса, Свердлова, 55	f	large
39636	36236	1203	Иркутская область, Осинский район, поселок Оса, Свердлова, 3	f	medium
39627	36227	1194	Иркутская область, Осинский район, поселок Онгосор, Онгосорская, 37	t	small
39632	36232	1199	Иркутская область, Осинский район, поселок Онгой, Нагорная, 22	t	small
39652	36252	1219	Иркутская область, Осинский район, поселок Обуса, 11 Комсомольцев, 21	f	medium
39634	36234	1201	Иркутская область, Осинский район, поселок Мольта (Каха), Молодежная, 2	t	small
39640	36240	1207	Иркутская область, Осинский район, село Майск, Трактовая, 9	f	medium
39635	36235	1202	Иркутская область, Осинский район, поселок Лузгина, Жданова, 35	f	medium
39648	36248	1215	Иркутская область, Осинский район, поселок Кутанка, Ленина, 1	f	small
39644	36244	1211	Иркутская область, Осинский район, поселок Ирхидей, Ленина, 5	f	medium
39645	36245	1212	Иркутская область, Осинский район, поселок Жданово, Хлебоприемная	f	small
39628	36228	1195	Иркутская область, Осинский район, поселок Енисей (Бурятский Янгут), Павлова, 40	t	medium
39630	36230	1197	Иркутская область, Осинский район, поселок Грязнушка, Гагарина, 60	t	small
39653	36253	1220	Иркутская область, Осинский район, поселок Горхон, Горхонская, 34	t	small
39654	36254	1221	Иркутская область, Осинский район, поселок Борохал, Борохальская, 5	t	small
39646	36246	1213	Иркутская область, Осинский район, поселок Бильчир, Ленина, 24	f	medium
39641	36241	1208	Иркутская область, Осинский район, поселок Абрамовка (Пахаленская), Центральная, 49	f	small
39625	36225	1192	Иркутская область, Ольхонский район, поселок Ялга, Восточная, 5	t	small
39619	36220	1186	Иркутская область, Ольхонский район, поселок Шара-Тогот, 50 лет Победы, 7	t	small
39617	36218	1184	Иркутская область, Ольхонский район, поселок Хурай-Нур, Молодежная, 11	t	small
39624	36224	1191	Иркутская область, Ольхонский район, поселок Хужир, Советская, 2	t	medium
39623	36223	1190	Иркутская область, Ольхонский район, поселок Харанцы, Байкальская, 4	t	small
86371	36219	1185	Иркутская область, Ольхонский район, поселок Тонта, Лесная, школа	t	small
39614	36215	1181	Иркутская область, Ольхонский район, поселок Таловка, Молодежная, 1	t	small
39620	36221	1187	Иркутская область, Ольхонский район, поселок Сахюрта, Центральная, 13	t	small
39615	36216	1182	Иркутская область, Ольхонский район, поселок Нарин-Кунта, Солнечная, 27	t	small
39609	36210	1176	Иркутская область, Ольхонский район, поселок Куртун, Центральная, 28	t	small
39613	36214	1180	Иркутская область, Ольхонский район, поселок Куреть, М. Копыловой, 15 б	t	small
39612	36213	1179	Иркутская область, Ольхонский район, поселок Косая Степь, Верховая, 7	t	small
39616	36217	1183	Иркутская область, Ольхонский район, поселок Еланцы, Советская, 7	f	large
86374	36217	1189	Иркутская область, Ольхонский район, поселок Еланцы, Советская, 7	f	small
39610	36211	1177	Иркутская область, Ольхонский район, поселок Бугульдейка, Ленина, 13	t	medium
39611	36212	1178	Иркутская область, Ольхонский район, поселок Алагуй, Центральная, 2	t	small
39580	36183	1147	Иркутская область, Нукутский район, поселок Шараты, Юбилейная, 7	f	small
39602	36203	1169	Иркутская область, Нукутский район, поселок Шалоты, Коммунаров, 21	t	small
39576	36179	1143	Иркутская область, Нукутский район, поселок Целинный, Советская, 17	f	small
39584	36187	1151	Иркутская область, Нукутский район, поселок Харёты, Центральная, 32	f	medium
39598	36199	1165	Иркутская область, Нукутский район, поселок Хамхар, Школьная, 2	t	small
39593	36194	1160	Иркутская область, Нукутский район, поселок Хадахан, Административная, 2	t	medium
39577	36180	1144	Иркутская область, Нукутский район, поселок Ункурлик, Школьная, 1	f	small
39582	36185	1149	Иркутская область, Нукутский район, поселок Тангуты, Нагорная, 7	f	small
39591	36121	1158	Иркутская область, Нукутский район, поселок Степное, пер. Школьный, 5	t	small
39590	36037	1157	Иркутская область, Нукутский район, поселок Первомайское, Ленина, 58	t	medium
39597	36198	1164	Иркутская область, Нукутский район, поселок Нукуты, Октябрьская, 3	t	medium
39607	36208	1174	Иркутская область, Нукутский район, поселок Новонукутский, Шолохова, 1	f	medium
39606	36207	1173	Иркутская область, Нукутский район, поселок Новонукутский, Чехова, 26	f	medium
39604	36205	1171	Иркутская область, Нукутский район, поселок Новонукутский, Ленина, 27	f	medium
39605	36206	1172	Иркутская область, Нукутский район, поселок Новонукутский, Ербанова, 2	f	medium
39587	36190	1154	Иркутская область, Нукутский район, поселок Новоленино, школьная, 6	f	medium
39650	36250	1217	Иркутская область, Нукутский район, поселок Новоленино, Мира, 6	f	medium
39579	36182	1146	Иркутская область, Нукутский район, поселок Наймодай, Школьная, 3	t	small
39594	36195	1161	Иркутская область, Нукутский район, поселок Мельхитуй (Русский Мельхитуй), Школьный переулок, 2	t	small
39596	36197	1163	Иркутская область, Нукутский район, поселок Мельхитуй (Русский Мельхитуй), Центральная, 4	t	small
39600	36201	1167	Иркутская область, Нукутский район, поселок Макарьевская, Лесная, 22	t	small
39581	36184	1148	Иркутская область, Нукутский район, поселок Куйта, пер. Школьный, 2	t	small
39603	36204	1170	Иркутская область, Нукутский район, поселок Кирилловская (Вершина), Школьная, 1	t	small
39588	36191	1155	Иркутская область, Нукутский район, поселок Зунгар, Центральная, 5	t	small
39589	36192	1156	Иркутская область, Нукутский район, поселок Заходы, Школьная, 1	t	small
39608	36209	1175	Иркутская область, Нукутский район, поселок Заречный, Советская, 20	f	small
39595	36196	1162	Иркутская область, Нукутский район, поселок Закулей, Имегенова, 1	t	medium
39583	36186	1150	Иркутская область, Нукутский район, поселок Ей, Школьная, 4	t	small
19415	16992	1896	Алтайский край, Рубцовск, Степана Разина, 196	f	large
39592	36193	1159	Иркутская область, Нукутский район, поселок Дружный, Школьная, 11	t	small
39599	36200	1166	Иркутская область, Нукутский район, поселок Ворот-Онгой, Школьная, 6	t	small
39586	36189	1153	Иркутская область, Нукутский район, поселок Васильевское, Центральная, 14	t	small
39585	36188	1152	Иркутская область, Нукутский район, поселок Большебаяновская, Лесная, 20	t	small
39601	36202	1168	Иркутская область, Нукутский район, поселок Алтарик, Комсомольская, 1	t	small
39549	36152	1116	Иркутская область, Нижнеудинский район, станция Шеберта, Привокзальная, 2-б	t	small
39523	36126	1090	Иркутская область, Нижнеудинский район, поселок Шумский, Советская, 38	f	large
39529	36132	1096	Иркутская область, Нижнеудинский район, поселок Шум, Нагорная, 2-а	t	small
39546	36149	1113	Иркутская область, Нижнеудинский район, поселок Шеберта, Трактовая, 4	t	medium
39531	36134	1098	Иркутская область, Нижнеудинский район, поселок Швайкина, Школьная, 8	t	small
39539	36142	1106	Россия, Иркутская область, Нижнеудинский район, поселок Чехово	t	small
39535	36138	1102	Иркутская область, Нижнеудинский район, поселок Чалоты, Центральная, 14	t	small
39552	36155	1119	Иркутская область, Нижнеудинский район, поселок Худоеланское, Школьная, 1-а	f	medium
39551	36154	1118	Иркутская область, Нижнеудинский район, поселок Худоеланское, Московская, 45-а	f	medium
39555	36158	1122	Иркутская область, Нижнеудинский район, поселок Хингуй, б/н	t	small
39513	36115	1080	Иркутская область, Нижнеудинский район, поселок Усть-Кадуй, переулок Школьный, 1	t	small
39543	36146	1110	Иркутская область, Нижнеудинский район, поселок Унгудул, Первомайская, 17	t	small
39517	36119	1084	Иркутская область, Нижнеудинский район, поселок Укар, Центральная, б/н	t	small
39519	36122	1086	Иркутская область, Нижнеудинский район, поселок Ук, 40 лет Победы, 9а	f	large
39532	36135	1099	Иркутская область, Нижнеудинский район, поселок Уват, Мира, 5	t	small
39553	36156	1120	Иркутская область, Нижнеудинский район, поселок Талый Ключ, Центральная, 26	t	small
39567	36170	1134	Иркутская область, Нижнеудинский район, Таежный, Почтовая, 7	t	small
39564	36167	1131	Иркутская область, Нижнеудинский район, поселок Старый Алзамай, Кирова, 20	t	small
39533	36136	1100	Иркутская область, Нижнеудинский район, поселок Солонцы, Школьная, 1	t	small
39526	36129	1093	Иркутская область, Нижнеудинский район, поселок Рубахина, Береговая, 33	t	small
39538	36141	1105	Иркутская область, Нижнеудинский район, поселок Привольное, Центральная, 10а	t	small
39537	36140	1104	Иркутская область, Нижнеудинский район, поселок Порог, Новая, 31-в	t	small
39525	36128	1092	Иркутская область, Нижнеудинский район, поселок Подгорный, Просвещения, 10	t	small
39562	36165	1129	Иркутская область, Нижнеудинский район, поселок Первомайский (Алгашет), Центральная, 19	t	small
86369	36145	1109	Иркутская область, Нижнеудинский район, поселок Орик, Центральная, 1	t	small
39565	36168	1132	Иркутская область, Нижнеудинский район, поселок Новокиевск, Школьная, 14	t	small
39512	36114	1079	Иркутская область, Нижнеудинский район, поселок Новое Село (Большой Курят), поселок Балакшин Бор	t	small
39559	36162	1126	Иркутская область, Нижнеудинский район, поселок Новое Село (Большой Курят), Шевченко, 15-а	t	small
39518	36120	1085	Иркутская область, Нижнеудинский район, Нижнеудинск, Центральная, 42	t	small
39524	36127	1091	Иркутская область, Нижнеудинский район, поселок Мельница, Ленина, 42	f	large
39545	36148	1112	Иркутская область, Нижнеудинский район, поселок Марга, Клубная, 16	t	small
39560	36163	1127	Иркутская область, Нижнеудинский район, поселок Мара, Московская, 1-б	t	small
39530	36133	1097	Иркутская область, Нижнеудинский район, поселок Майский, Школьная, 9	t	small
39515	36117	1082	Иркутская область, Нижнеудинский район, поселок Лесной, Просвещения, 15	t	small
39534	36137	1101	Иркутская область, Нижнеудинский район, поселок Кушун, Центральная, 24	t	small
39557	36160	1124	Иркутская область, Нижнеудинский район, поселок Куряты, Мира, 25б	t	small
39540	36143	1107	Иркутская область, Нижнеудинский район, поселок Кургатей, б/н	t	small
39536	36139	1103	Иркутская область, Нижнеудинский район, поселок Кирей-Муксут, Школьная, 7	t	small
86370	36169	1133	Иркутская область, Нижнеудинский район, поселок Катарма, Катарминская, 21	t	small
86368	36144	1108	Иркутская область, Нижнеудинский район, поселок Катарбей, Советская, 78	t	small
39522	36125	1089	Иркутская область, Нижнеудинский район, поселок Камышет, Мира, 1	t	medium
39558	36161	1125	Иркутская область, Нижнеудинский район, поселок Каменка, Садовая, 51в	f	small
39554	36157	1121	Иркутская область, Нижнеудинский район, поселок Кадуй, Дорожная, 2	t	small
39544	36147	1111	Иркутская область, Нижнеудинский район, поселок Иргей, Клубная, 6	t	small
39561	36164	1128	Иркутская область, Нижнеудинский район, поселок Замзор, Школьная, 6	t	medium
39563	36166	1130	Иркутская область, Нижнеудинский район, поселок Загорье, Школьная, 5	t	small
39548	36151	1115	Иркутская область, Нижнеудинский район, поселок Даур, Советская, 63	t	small
39527	36130	1094	Иркутская область, Нижнеудинский район, поселок Вознесенский, Транспортная, 7	f	medium
39521	36124	1088	Иркутская область, Нижнеудинский район, поселок Водопадный, Молодежная, 1	t	small
39550	36153	1117	Иркутская область, Нижнеудинский район, поселок Вершина, Школьная, 12	t	small
39556	36159	1123	Россия, Иркутская область, Нижнеудинский район, поселок Верхний Хингуй	t	small
39547	36150	1114	Иркутская область, Нижнеудинский район, поселок Большеверстовск, Советская, 35	t	small
39511	36113	1078	Иркутская область, Нижнеудинский район, поселок Атагай, переулок Клубный, 1-а	f	large
39510	36112	1077	Иркутская область, Нижнеудинский район, Алзамай, Рабочая, 20	f	medium
110299	36108	1073	Иркутская область, Нижнеудинский район, Алзамай, Первомайская, 61	f	medium
39504	36106	1071	Иркутская область, Нижнеудинский район, Алзамай, Первомайская, 84	f	medium
39509	36111	1076	Иркутская область, Нижнеудинский район, Алзамай, Некрасова, 10	f	medium
39507	36109	1074	Иркутская область, Нижнеудинский район, Алзамай, Линейная, 6	f	medium
39505	36107	1072	Иркутская область, Нижнеудинский район, Алзамай, Комсомольская, 8	f	medium
39508	36110	1075	Иркутская область, Нижнеудинский район, Алзамай, Вокзальная, 37	f	medium
39528	36131	1095	Иркутская область, Нижнеудинский район, поселок Абалаково, Центральная, 21	t	small
39475	36077	1042	Иркутская область, Нижнеилимский район, поселок Янгель, мкр. Космонавтов, 9а	t	medium
39464	36066	1031	Иркутская область, Нижнеилимский район, поселок Шестаково, Ленина, 20А	t	small
39463	36065	1030	Иркутская область, Нижнеилимский район, поселок Шестаково, Ленина, 20б	t	medium
39461	36063	1028	Иркутская область, Нижнеилимский район, поселок Чёрная, Железнодорожная, 10	t	small
39471	36073	1038	Иркутская область, Нижнеилимский район, поселок Чистополянский, Ленина, 1	t	small
39467	36069	1034	Иркутская область, Нижнеилимский район, поселок Хребтовая, Трактовая, 43	f	small
39468	36070	1035	Иркутская область, Нижнеилимский район, поселок Хребтовая, Калинина, 1	f	large
39465	36067	1032	Иркутская область, Нижнеилимский район, поселок Суворовский, Зеленая, 91	t	medium
39460	36062	1027	Иркутская область, Нижнеилимский район, поселок Соцгородок, Школьная, 1	t	medium
39462	36064	1029	Иркутская область, Нижнеилимский район, поселок Семигорск, Семигорская, 10	t	medium
39466	36068	1033	Иркутская область, Нижнеилимский район, поселок Селезнёвский, Нагорная, 2-1	t	small
39474	36076	1041	Иркутская область, Нижнеилимский район, поселок Рудногорск, Школьная, 1	f	large
39473	36075	1040	Иркутская область, Нижнеилимский район, поселок Рудногорск, Вокзальная, 10	f	large
39458	36060	1025	Иркутская область, Нижнеилимский район, поселок Речушка, Красноярская, 20	t	large
39476	36078	1043	Иркутская область, Нижнеилимский район, поселок Радищев, 5	t	medium
110298	36079	1044	Иркутская область, Нижнеилимский район, поселок Новоилимск, Зверева, 20	t	medium
39482	36084	1049	Иркутская область, Нижнеилимский район, поселок Новая Игирма, микрорайон Химки, 33	f	large
39479	36081	1046	Иркутская область, Нижнеилимский район, поселок Новая Игирма, квартал 332	f	large
39481	36083	1048	Иркутская область, Нижнеилимский район, поселок Новая Игирма, Пионерская, 27	f	large
39480	36082	1047	Иркутская область, Нижнеилимский район, поселок Новая Игирма, Бархатова, 11	f	large
39478	36080	1045	Иркутская область, Нижнеилимский район, поселок Коршуновский, Ленина, 7А	t	medium
39472	36074	1039	Иркутская область, Нижнеилимский район, поселок Каймоновский, Лесная, 1а	t	small
39457	36059	1024	Иркутская область, Нижнеилимский район, поселок Игирма, МОУ Игирменская ООШ	t	medium
39459	36061	1026	Иркутская область, Нижнеилимский район, поселок Заярск, Заярская, 1	t	small
39455	36057	1022	Иркутская область, Нижнеилимский район, поселок Заморский, Ленина, 6	t	small
39441	36043	1008	Иркутская область, Нижнеилимский район, Железногорск-Илимский	f	large
39452	36054	1019	Иркутская область, Нижнеилимский район, Железногорск-Илимский, пос. Донецкого ЛПХ, 34	t	small
39451	36053	1018	Иркутская область, Нижнеилимский район, Железногорск-Илимский, микрорайон1035	f	large
39449	36051	1016	Иркутская область, Нижнеилимский район, Железногорск-Илимский, квартал829	f	large
39444	36046	1011	Иркутская область, Нижнеилимский район, Железногорск-Илимский, квартал334	f	large
39442	36044	1009	Иркутская область, Нижнеилимский район, Железногорск-Илимский, квартал145	f	medium
39446	36048	1013	Иркутская область, Нижнеилимский район, Железногорск-Илимский, квартал 6а, 4	f	large
39445	36047	1012	Иркутская область, Нижнеилимский район, Железногорск-Илимский, квартал 6, 17а	f	large
39443	36045	1010	Иркутская область, Нижнеилимский район, Железногорск-Илимский, квартал 243	f	large
39447	36049	1014	Иркутская область, Нижнеилимский район, Железногорск-Илимский, квартал, 717	f	large
39450	36052	1017	Иркутская область, Нижнеилимский район, Железногорск-Илимский, Энтузиастов, 2А	f	medium
68143	36840	1886	Иркутская область, Нижнеилимский район, Железногорск-Илимский, 3 квартал, 15а, ДК	f	large
39453	36055	1020	Иркутская область, Нижнеилимский район, поселок Дальний, Школьная, МОУ Дальнинская СОШ	t	medium
39469	36071	1036	Иркутская область, Нижнеилимский район, поселок Видим, Нагорная, 1а	f	medium
39470	36072	1037	Иркутская область, Нижнеилимский район, поселок Видим, Железнодорожная, 1	f	small
39454	36056	1021	Иркутская область, Нижнеилимский район, поселок Брусничный, Ленина, 11	t	small
39456	36058	1023	Иркутская область, Нижнеилимский район, поселок Березняки, Янгеля, 25	f	medium
39439	36041	1006	Иркутская область, Мамско-Чуйский район, п. Согдиондон, Мира, 24	t	small
39440	36042	1007	Иркутская область, Мамско-Чуйский район, п. Горно-Чуйский, Советская, 26	t	small
39437	36039	1004	Иркутская область, Мамско-Чуйский район, поселок Мусковит, Комсомольская, 7	t	small
39438	36040	1005	Иркутская область, Мамско-Чуйский район, поселок Луговский, Школьная, 26	t	small
39432	36033	999	Иркутская область, Куйтунский район, станция Мингатуй, Ленина	t	small
39431	36032	998	Иркутская область, Куйтунский район, поселок Чеботариха, Мира, 75	t	medium
39396	35997	963	Иркутская область, Куйтунский район, поселок Харчев, Макарова, 18, 2	t	small
110297	36030	996	Иркутская область, Куйтунский район, поселок Харик, Озерная, 10	f	medium
39394	35995	961	Иркутская область, Куйтунский район, поселок Харик, Ленина, 10	f	large
39386	35988	953	Иркутская область, Куйтунский район, поселок Хаихта, Зеленая, 4-2	t	small
39427	36028	994	Иркутская область, Куйтунский район, поселок Уян, 1-я Советская, 6	t	medium
39426	36027	993	Иркутская область, Куйтунский район, поселок Уховский, Комсомольская, 6а	t	medium
39421	36022	988	Иркутская область, Куйтунский район, поселок Усть-Када, Лесная, 5	t	small
38934	35604	500	Иркутская область, Куйтунский район, поселок Урункуй, Пионерская, 23	t	small
39424	36025	991	Иркутская область, Куйтунский район, поселок Тулюшка, Мира, 9	f	large
39423	36024	990	Иркутская область, Куйтунский район, поселок Тулюшка, Ленина, 29 А	t	small
39381	35983	948	Иркутская область, Куйтунский район, поселок Тобино, Степная, 17	t	small
39410	36011	977	Иркутская область, Куйтунский район, поселок Тихорут, Степная, 24	t	small
39380	35982	947	Иркутская область, Куйтунский район, поселок Сулкет, Трактовая, 33	t	small
39414	36015	981	Иркутская область, Куйтунский район, поселок Станица 3-я, Центральная, 46 А	t	small
86365	35998	964	Иркутская область, Куйтунский район, поселок Сосновский, Трактовая, 5-2	t	small
39400	36001	967	Иркутская область, Куйтунский район, поселок Садовый, Центральная, 15-1	t	small
39420	36021	987	Иркутская область, Куйтунский район, поселок Панагино, Центральная, 1	t	small
39812	36362	1379	Иркутская область, Куйтунский район, поселок Октябрьский 2-й, Школьная, 10	t	small
39391	35992	958	Иркутская область, Куйтунский район, поселок Окинский, Верхняя, 15	t	small
39419	36020	986	Иркутская область, Куйтунский район, поселок Новая Тельба, Ленина, 1	t	small
39422	36023	989	Иркутская область, Куйтунский район, поселок Новая Када, Мира, 56	t	small
86367	36019	985	Иркутская область, Куйтунский район, поселок Наратай, Набережная, 21	t	small
39417	36018	984	Иркутская область, Куйтунский район, поселок Мингатуй, Мира, 15	t	small
39382	35984	949	Иркутская область, Куйтунский район, поселок Малая Кочерма, Школьная, 2	t	small
39425	36026	992	Иркутская область, Куйтунский район, поселок Майский, Лесная, 1 Б	t	small
39398	35999	965	Иркутская область, Куйтунский район, поселок Листвянка, Школьная, 19	t	small
39412	36013	979	Иркутская область, Куйтунский район, поселок Лермонтовский, Лазо, 7	t	small
39409	36010	976	Иркутская область, Куйтунский район, поселок Ленинский, Солнечная, 18	t	small
39405	36006	972	Иркутская область, Куйтунский район, поселок Кундуй, переулок Советский, 2 А	t	medium
39374	35976	941	Иркутская область, Куйтунский район, поселок Куйтун, Чернышевского, 5	f	medium
39375	35977	942	Иркутская область, Куйтунский район, поселок Куйтун, Фрунзе, 78	f	medium
39377	35979	944	Иркутская область, Куйтунский район, поселок Куйтун, Тургенева, 1	f	medium
39376	35978	943	Иркутская область, Куйтунский район, поселок Куйтун, Нахимова, 2	f	medium
39373	35975	940	Иркутская область, Куйтунский район, поселок Куйтун, Молодежная, 16	f	small
39369	35971	936	Иркутская область, Куйтунский район, поселок Куйтун, Коммунальная, 31	f	medium
39371	35960	938	Иркутская область, Куйтунский район, поселок Куйтун, Киевская, 2 А	f	medium
39372	35974	939	Иркутская область, Куйтунский район, поселок Куйтун, Карла Маркса, 24	f	large
39368	35970	935	Иркутская область, Куйтунский район, поселок Куйтун, Карла Маркса, 4	f	medium
39378	35980	945	Иркутская область, Куйтунский район, поселок Куйтун, 1-я Рабочая, 1	f	medium
39428	36029	995	Иркутская область, Куйтунский район, поселок Красный Яр (Подьяр), Зеленая, 27	t	small
39385	35987	952	Иркутская область, Куйтунский район, поселок Ключи, Центральная, 46	t	small
39403	36004	970	Иркутская область, Куйтунский район, поселок Карымск, Набережная, 6 А	t	medium
39402	36003	969	Иркутская область, Куйтунский район, поселок Карымск, Набережная, 6	f	large
39416	36017	983	Иркутская область, Куйтунский район, поселок Каранцай, Российская, 55 А	t	small
39401	36002	968	Иркутская область, Куйтунский район, поселок Каразей, Мира, 49	t	medium
39415	36016	982	Россия, Иркутская область, Куйтунский район, поселок Или	t	small
39408	36009	975	Иркутская область, Куйтунский район, поселок Игнино, Ленина, 5	t	medium
39413	36014	980	Иркутская область, Куйтунский район, поселок Еланский, Заречная, 13 А	t	small
39389	35990	956	Иркутская область, Куйтунский район, поселок Бурук, Ленина, 23	f	small
39390	35991	957	Иркутская область, Куйтунский район, поселок Броды, Центральная, 13	t	small
38933	35603	499	Иркутская область, Куйтунский район, Зиминское районное муниципальное образование, Хазанское муниципальное образование, поселок Боровое, Школьная, 1А	t	small
39392	35993	959	Россия, Иркутская область, Куйтунский район, поселок Большой Кашелак	t	small
39387	35989	954	Иркутская область, Куйтунский район, поселок Березовский, Школьная, 3	t	small
39388	35768	955	Иркутская область, Куйтунский район, поселок Барлук, Школьная, 17 А	f	medium
39399	36000	966	Иркутская область, Куйтунский район, поселок Ахтинский, Центральная, 21	t	small
39430	36031	997	Иркутская область, Куйтунский район, поселок Аршан, Лесная, 20	t	small
39393	35994	960	Иркутская область, Куйтунский район, поселок Апраксина, Советская, 26	t	small
39384	35986	951	Иркутская область, Куйтунский район, поселок Андрюшино, Советская, 73а	t	medium
86366	36008	974	Иркутская область, Куйтунский район, поселок Амур, Центральная, 37б	t	small
39379	35981	946	Иркутская область, Куйтунский район, поселок Алкин, переулок Больничный, 1	t	small
39383	35985	950	Иркутская область, Куйтунский район, поселок Александро-Невский Завод, 1-я Заречная, 12	t	small
39406	36007	973	Иркутская область, Куйтунский район, поселок Александро-Невская Станица, Центральная, 41	t	small
39357	35961	924	Иркутская область, Киренский район, с.Алымовка, Центральная, 5	t	small
39361	35965	928	Иркутская область, Киренский район, поселок Юбилейный, Гагарина, 2	t	small
39345	35948	912	Иркутская область, Киренский район, деревня Сидорова, сельский клуб	t	small
39336	35939	903	Иркутская область, Киренский район, Макарово, Полевая, 47	t	medium
39337	35940	904	Иркутская область, Киренский район, Криволукское муниципальное образование, Боровкова, 8	t	small
39349	35952	916	Иркутская область, Киренский район, Киренск, Майская, 16	t	medium
39352	35955	919	Иркутская область, Киренский район, село Змеиново	t	small
39355	35958	922	Иркутская область, Киренский район, Алексеевское муниципальное образование, поселок Воронежский, Первомайская, 2	t	small
39359	35963	926	Иркутская область, Киренский район, Алымовское муниципальное образование, село Банщиково, улица Центральная, 2	t	small
39308	35912	875	Иркутская область, Качугский район, поселок Щапова, Ключевая, 23	t	small
39309	35913	876	Иркутская область, Качугский район, поселок Шейна, Школьная, 21	t	small
39323	35926	890	Иркутская область, Качугский район, поселок Харбатово, Трактовая, 28 А	t	medium
86393	36839	1885	Иркутская область, Качугский район, поселок Харбатово, Новая, 24, бар	t	small
39327	35930	894	Иркутская область, Качугский район, поселок Хальск, Кольцевая, 20	t	small
39318	35922	885	Иркутская область, Качугский район, поселок Толмачева, Киселева, 47	t	small
39303	35907	870	Иркутская область, Качугский район, поселок Тимирязева, Совхозная, 23	t	small
39329	35932	896	Иркутская область, Качугский район, поселок Полоскова, Трактовая, 34 Б	t	small
39324	35927	891	Иркутская область, Качугский район, поселок Никилей, Школьная, 12	t	small
39328	35931	895	Иркутская область, Качугский район, поселок Манзурка, Октябрьская, 13	t	medium
39313	35917	880	Иркутская область, Качугский район, поселок Малый Тарель, Петровская, 15	t	small
39301	35890	868	Иркутская область, Качугский район, поселок Малые Голы, Трактовая, 4	t	small
39326	35929	893	Иркутская область, Качугский район, поселок Литвинова, Гаражная, 19 А	t	small
39300	35880	867	Иркутская область, Качугский район, поселок Краснояр (Басай), Трактовая, 39	t	medium
39325	35928	892	Иркутская область, Качугский район, поселок Корсукова, Школьная, 4	t	small
39331	35934	898	Иркутская область, Качугский район, поселок Копылова, Лесная, 39	t	small
39296	35713	863	Иркутская область, Качугский район, поселок Качуг, пер. Восточный, 2	f	large
39295	35905	862	Иркутская область, Качугский район, поселок Качуг, Юбилейная, 2 А	f	large
39298	35807	865	Иркутская область, Качугский район, поселок Качуг, Пуляевского, 77	t	medium
39299	35870	866	Иркутская область, Качугский район, поселок Качуг, Маяковского, 12	t	medium
39294	35904	861	Иркутская область, Качугский район, поселок Качуг, Красноармейская, 42	f	large
39297	35799	864	Иркутская область, Качугский район, поселок Качуг, Каландарашвили, 209	f	large
39332	35935	899	Иркутская область, Качугский район, поселок Карлук, Школьная, 26	t	small
39305	35909	872	Иркутская область, Качугский район, поселок Исеть, Береговая, 43	t	small
39330	35933	897	Иркутская область, Качугский район, поселок Заречное, Центральная, 19	t	small
39315	35919	882	Иркутская область, Качугский район, поселок Залог, Центральная, 27	t	small
39320	35921	887	Иркутская область, Качугский район, поселок Верхоленск, Федосеева, 44 А	t	small
39317	35921	884	Иркутская область, Качугский район, поселок Верхоленск, Федосеева, 44 А	t	medium
39307	35911	874	Иркутская область, Качугский район, поселок Бутаково, Совхозная, 37	t	small
39304	35908	871	Иркутская область, Качугский район, поселок Босогол, Мархеева, 13	t	small
39316	35920	883	Иркутская область, Качугский район, поселок Большой Тарель, Пуляевского, 12	t	small
39314	35918	881	Иркутская область, Качугский район, поселок Большой Косогол, Центральная, 12	t	small
39302	35906	869	Иркутская область, Качугский район, поселок Большие Голы, Береговая, 23	t	small
39312	35916	879	Иркутская область, Качугский район, поселок Бирюлька, Окладникова, 13	t	small
39311	35915	878	Иркутская область, Качугский район, поселок Бирюлька, Ленина, 41	t	medium
39319	35923	886	Иркутская область, Качугский район, поселок Белоусово, Победы, 19	t	small
39310	35914	877	Иркутская область, Качугский район, поселок Ацикяк, Трактовая, 16	t	small
18062	15640	492	Алтайский край, Рубцовск, Степана Разина, 200	f	large
39333	35936	900	Иркутская область, Качугский район, поселок Аргун, Центральная, 16 Б	t	small
39306	35910	873	Иркутская область, Качугский район, поселок Анга, Советская, 23 А	t	medium
39289	35899	856	Иркутская область, Катангский район, Село Подволошино, Майская, 22	t	small
39285	35895	852	Иркутская область, Катангский район, Село Ербогачен, Авиаторов, 11	t	medium
86391	36837	1883	Россия, Иркутская область, Казачинско-Ленский район	t	small
39264	35872	831	Иркутская область, Казачинско-Ленский район, поселок Улькан, Машурова, 16	f	large
39263	35871	830	Иркутская область, Казачинско-Ленский район, поселок Улькан, Лесная, 4	f	large
39265	35873	832	Иркутская область, Казачинско-Ленский район, поселок Улькан, Дзержинского, 10	f	large
39266	35874	833	Иркутская область, Казачинско-Ленский район, поселок Тарасово, 26	t	small
39578	36181	1145	Иркутская область, Казачинско-Ленский район, поселок Новоселово, Центральная, 20	t	small
39274	35883	841	Иркутская область, Казачинско-Ленский район, поселок Небель, Ленина, 21	t	small
39272	35881	839	Иркутская область, Казачинско-Ленский район, поселок Магистральный, д. Седанкина	f	small
39268	35876	835	Иркутская область, Казачинско-Ленский район, поселок Магистральный, Российская, 4	f	large
110296	35877	836	Иркутская область, Казачинско-Ленский район, поселок Магистральный, Пугачева, 40	f	medium
39271	35879	838	Иркутская область, Казачинско-Ленский район, поселок Магистральный, Ленина, 4	f	large
39270	35878	837	Иркутская область, Казачинско-Ленский район, поселок Магистральный, Карбышева, В/Ч75238	t	small
39273	35882	840	Иркутская область, Казачинско-Ленский район, поселок Магистральный, 60 лет Октября, 5	f	large
39262	35869	829	Иркутская область, Казачинско-Ленский район, поселок Кунерма, Железнодорожная	t	small
39267	35875	834	Иркутская область, Казачинско-Ленский район, поселок Конец-Луг, 40 лет Победы, 10	t	medium
39277	35886	844	Иркутская область, Казачинско-Ленский район, поселок Ключи, 30 лет Победы, 37	t	medium
39275	35884	842	Иркутская область, Казачинско-Ленский район, поселок Казачинское, Октябрьская, 20	f	large
39276	35885	843	Иркутская область, Казачинско-Ленский район, поселок Казачинское, Коммунистическая, 5	f	large
38970	35642	536	Иркутская область, Иркутский район, рабочий поселок Маркова, Мира, 13	f	large
38998	35670	564	Иркутская область, Иркутский район, д. Столбова, Центральная, 2	f	small
39017	35691	583	Иркутская область, Иркутский район, поселок Ширяева, Ленина, 26	f	medium
38990	35662	556	Иркутская область, Иркутский район, поселок Черемушка, Дзержинского, 28А	f	small
68142	35685	1882	Иркутская область, Иркутский район, поселок Хомутово, Колхозная, 138	f	large
39012	35685	578	Иркутская область, Иркутский район, поселок Хомутово, Колхозная, 138	f	large
39011	35684	577	Иркутская область, Иркутский район, поселок Хомутово, Кирова, 10 Б	f	large
39004	35677	570	Иркутская область, Иркутский район, поселок Усть-Куда, Муханова, 5	f	medium
39005	35678	571	Иркутская область, Иркутский район, поселок Усть-Куда, Геологическая, 3	f	medium
39001	35674	567	Иркутская область, Иркутский район, поселок Усть-Балей, Ангарская, 27	t	small
38994	35666	560	Иркутская область, Иркутский район, поселок Урик, Лунина, 2 Г	f	large
38984	35656	550	Иркутская область, Иркутский район, поселок Турская, Центральная, 26	f	small
39019	35693	585	Иркутская область, Иркутский район, поселок Тихонова Падь, Центральная, 71	t	small
38993	35665	559	Иркутская область, Иркутский район, поселок Сосновый Бор, Мелехова, 10	f	medium
38992	35664	558	Иркутская область, Иркутский район, поселок Смоленщина, Горького, 33	f	large
38957	35628	523	Иркутская область, Иркутский район, поселок Сайгуты, Комсомольская, 31	t	small
38978	35650	544	Иркутская область, Иркутский район, поселок Рязановщина, Школьная, 20 В	t	small
38989	35661	555	Иркутская область, Иркутский район, поселок Ревякина, Молодежная, 8	f	medium
39014	35687	580	Иркутская область, Иркутский район, поселок Позднякова, Российская, 1	f	small
39015	35688	581	Иркутская область, Иркутский район, поселок Плишкино, Центральная МОУ Плишкинская ООШ	t	medium
39006	35679	572	Иркутская область, Иркутский район, поселок Пивовариха, Дачная, 6	f	large
39009	35682	575	Иркутская область, Иркутский район, поселок Патроны, Школьная, 2	f	small
38968	35639	534	Иркутская область, Иркутский район, поселок Падь-Мельничная, Заводской, 1	t	small
38987	35652	553	Иркутская область, Иркутский район, поселок Оёк, Кирова, 91 Д	f	small
38980	35652	546	Иркутская область, Иркутский район, поселок Оёк, Кирова, 91 Д	f	large
39350	35953	917	Иркутская область, Иркутский район, поселок Никольск, сельский клуб	t	small
38976	35648	542	Иркутская область, Иркутский район, поселок Никольск, Комсомольская площадь, 9	f	medium
38996	35668	562	Иркутская область, Иркутский район, поселок Московщина, Центральная, 33	t	small
38973	35645	539	Иркутская область, Иркутский район, поселок Молодежный, Совхозная, 2	f	large
38969	35641	535	Иркутская область, Иркутский район, поселок Маркова, Мира, 15	f	large
38971	35643	537	Иркутская область, Иркутский район, поселок Маркова, Лесная, 2	f	medium
38966	35637	532	Иркутская область, Иркутский район, село Мамоны, Садовая, 11	f	large
38952	35623	518	Иркутская область, Иркутский район, поселок Малое Голоустное, Мира, 24	f	large
38967	35638	533	Иркутская область, Иркутский район, поселок Малая Еланка, Мелиораторов, 12	f	medium
38988	35660	554	Иркутская область, Иркутский район, поселок Максимовщина, клуб воинской части №51870	f	small
38965	35636	531	Иркутская область, Иркутский район, поселок Максимовщина, Советская, 30 А	f	large
38985	35658	551	Иркутская область, Иркутский район, поселок Максимовщина, Веселая, 2	f	small
39018	35692	584	Иркутская область, Иркутский район, поселок Лыловщина, Мира, 2	f	small
38962	35633	528	Иркутская область, Иркутский район, поселок Листвянка, Октябрьская, 1	f	medium
38963	35634	529	Иркутская область, Иркутский район, поселок Листвянка, Горького, 89	f	medium
38979	35651	545	Иркутская область, Иркутский район, поселок Кыцигировка (Майск), Кыцигировская, 1 А	f	small
39013	35686	579	Иркутская область, Иркутский район, поселок Куда, Ленина, 7 А	f	large
38982	35654	548	Иркутская область, Иркутский район, поселок Коты, Депутатская, 41	f	small
38961	35632	527	Иркутская область, Иркутский район, поселок Карлук, Гагарина, 2	f	large
39002	35675	568	Иркутская область, Иркутский район, поселок Зорино-Быково, Трактовая, А -2	t	small
38986	35659	552	Иркутская область, Иркутский район, поселок Жердовка, Трактовая, 9 Б	f	small
39000	35672	566	Иркутская область, Иркутский район, поселок Еловка, Центральная, 16 А	f	small
38977	35649	543	Иркутская область, Иркутский район, поселок Егоровщина, Школьная, 15	f	small
38995	35667	561	Иркутская область, Иркутский район, поселок Грановщина, Загоскина, 70 В	f	medium
39020	35694	586	Иркутская область, Иркутский район, поселок Горяшина, 40 лет Октября, 21	f	small
39007	35680	573	Иркутская область, Иркутский район, поселок Горячий Ключ, Учительская, 7	t	medium
38954	35625	520	Иркутская область, Иркутский район, поселок Горохово, Школьная, 15	t	medium
86363	35626	521	Иркутская область, Иркутский район, поселок Горохово, Советская, 38	f	small
39016	35689	582	Иркутская область, Иркутский район, поселок Горный, клуб воинской части №36728	t	small
38981	35653	547	Иркутская область, Иркутский район, поселок Галки, Первомайская, 41 А	f	small
38959	35630	525	Иркутская область, Иркутский район, поселок Верхний Кет, Центральная, 10	t	small
39003	35676	569	Иркутская область, Иркутский район, поселок Быкова, Калинина, 6 А	t	small
38958	35629	524	Иркутская область, Иркутский район, поселок Бухун, Некрасова, 11	t	small
38983	35655	549	Иркутская область, Иркутский район, поселок Бутырки, Придорожная, 1	f	small
39010	35683	576	Иркутская область, Иркутский район, поселок Бурдаковка, Лесная, 11	f	small
38991	35663	557	Иркутская область, Иркутский район, поселок Бургаз, Центральная, 69	f	small
38953	35624	519	Иркутская область, Иркутский район, поселок Большое Голоустное, Байкальская, 26-1	t	small
38951	35622	517	Иркутская область, Иркутский район, поселок Большая Речка, Ленина, 8а	f	large
38956	35627	522	Иркутская область, Иркутский район, поселок Баруй, Маяковского, 22	t	small
39358	35962	925	Иркутская область, Иркутская область, деревня Никулина, сельский клуб	t	small
38913	35582	479	Иркутская область, Зиминский район, поселок Черемшанка, Школьная, 2а	t	small
38932	35602	498	Иркутская область, Зиминский район, поселок Центральный Хазан, Мира, 57	f	large
38929	35599	495	Иркутская область, Зиминский район, поселок Харайгун, Центральная, 21	t	small
38930	35600	496	Иркутская область, Зиминский район, поселок Филипповск, Новокшонова, 65	t	small
38925	35594	491	Иркутская область, Зиминский район, поселок Ухтуй, Лесная, 11	f	medium
38923	35592	489	Иркутская область, Зиминский район, поселок Услон, 40 лет Победы, 3а	t	medium
38910	35579	476	Иркутская область, Зиминский район, поселок Сологубово, Школьная, 11	t	small
39678	36274	1245	Иркутская область, Зиминский район, Саянск, микрорайон Олимпийский	f	large
39673	36269	1240	Иркутская область, Зиминский район, Саянск, 7, детский спортклуб Искра	f	large
39665	36263	1232	Иркутская область, Зиминский район, Саянск, 2, Центральная библиотека	f	large
39659	36259	1226	Иркутская область, Зиминский район, Саянск, микрорайон Юбилейный, школа №1	f	large
39658	36258	1225	Иркутская область, Зиминский район, Саянск, микрорайон Юбилейный, школа №3	f	large
39657	36257	1224	Иркутская область, Зиминский район, Саянск, микрорайон Юбилейный, 65, Картинная галерея	f	large
39672	36268	1239	Иркутская область, Зиминский район, Саянск, микрорайон Строителей, 26, Детско-юношеская спортшкола	f	large
39675	36271	1242	Иркутская область, Зиминский район, Саянск, микрорайон Олимпийский, школа №2	f	large
39660	36260	1227	Иркутская область, Зиминский район, Саянск, микрорайон Олимпийский, 23, Спорткомплекс	f	large
39662	36261	1229	Иркутская область, Зиминский район, Саянск, микрорайон Октябрьский, школа №7	f	large
39661	36261	1228	Иркутская область, Зиминский район, Саянск, микрорайон Октябрьский, школа №7	f	large
39674	36270	1241	Иркутская область, Зиминский район, Саянск, микрорайон Молодежный, 2, Клуб Вертикаль	t	small
39669	36266	1236	Иркутская область, Зиминский район, Саянск, микрорайон Мирный, 2, клуб Пилигрим	f	large
39670	36267	1237	Иркутская область, Зиминский район, Саянск, микрорайон Ленинградский, 2, ф-л Центральной библиотеки	f	large
38924	35593	490	Иркутская область, Зиминский район, поселок Самара, Черемушки, 2	t	medium
38917	35586	483	Иркутская область, Зиминский район, поселок Перевоз, Молодежная, 7	t	small
38918	35587	484	Иркутская область, Зиминский район, поселок Перевоз, Вокзальная, 2	t	small
38926	35595	492	Иркутская область, Зиминский район, поселок Норы, Солнечная, 11	t	small
38921	35590	487	Иркутская область, Зиминский район, поселок Новолетники, Центральная, 60	t	small
38927	35597	493	Иркутская область, Зиминский район, поселок Мордино, Школьная, 3	t	small
38919	35588	485	Иркутская область, Зиминский район, поселок Масляногорск, Полевая, 20	f	medium
38915	35584	481	Иркутская область, Зиминский район, поселок Кимильтей, Чкалова, 70	f	large
39404	36005	971	Иркутская область, Зиминский район, поселок Кимильтей, Вокзальная, ж/д станция Кимильтей	f	small
38914	35583	480	Иркутская область, Зиминский район, поселок Зулумай, Центральная, 33-1	t	small
38939	35610	505	Иркутская область, Зиминский район, Зима, Трактовая, 2	f	large
38937	35607	503	Иркутская область, Зиминский район, Зима, Садовая, 43	f	large
38938	35608	504	Иркутская область, Зиминский район, Зима, Орджоникидзе, 49	f	large
38935	35605	501	Иркутская область, Зиминский район, Зима, Куйбышева, 13	f	large
38940	35611	506	Иркутская область, Зиминский район, Зима, Кирова, 12	f	large
38945	35616	511	Иркутская область, Зиминский район, Зима, Бограда, 59	f	large
38942	35613	508	Иркутская область, Зиминский район, Зима, Ангарская, 6	f	large
38928	35598	494	Иркутская область, Зиминский район, поселок Глинки, Центральная, 59	t	small
38920	35589	486	Иркутская область, Зиминский район, поселок Верхнеокинский, Школьная, 10	t	small
38911	35580	477	Иркутская область, Зиминский район, поселок Буря, Центральная, 53	t	small
38931	35601	497	Иркутская область, Зиминский район, поселок Большеворонежский, Молодежная, 1	t	small
38908	35577	474	Иркутская область, Зиминский район, поселок Батама, Ленина, 40	t	medium
38909	35578	475	Иркутская область, Зиминский район, поселок Басалаевка, Речная, 62	t	small
38916	35585	482	Иркутская область, Зиминский район, поселок Баргадай (Кяхта, Обуздина), Школьная, 20	t	small
38883	35551	449	Иркутская область, Заларинский район, поселок Щербакова, Набережная, 10	t	small
38892	35560	458	Иркутская область, Заларинский район, поселок Черемшанка, Советская, 37	t	small
38888	35556	454	Иркутская область, Заларинский район, поселок Чаданова, Трактовая, 10	t	small
38894	35562	460	Иркутская область, Заларинский район, поселок Хор-Тагна, Леспромхозовская, 6	t	medium
38879	35547	445	Иркутская область, Заларинский район, поселок Холмогой, Юбилейная, 1	t	medium
38900	35568	466	Иркутская область, Заларинский район, поселок Ханжиново, переулок Солнечный, 2	t	medium
38887	35555	453	Иркутская область, Заларинский район, поселок Халты, Дудкина, 6	t	small
38902	35570	468	Иркутская область, Заларинский район, поселок Тыреть 2-я, Верхняя, 9	t	small
38903	35572	469	Иркутская область, Заларинский район, поселок Тыреть 1-я, микр.Солерудник, 9	f	large
68132	35573	470	Иркутская область, Заларинский район, поселок Тыреть, Школьная, 55	f	large
38881	35549	447	Иркутская область, Заларинский район, поселок Троицк, Ленина, 35	t	medium
38895	35563	461	Иркутская область, Заларинский район, поселок Тагна, Дорожная, 24	t	small
38893	35561	459	Иркутская область, Заларинский район, поселок Среднепихтинский, Центральная, 22	t	small
38880	35548	446	Иркутская область, Заларинский район, поселок Сорты, Трактовая, 18	t	medium
38878	35546	444	Иркутская область, Заларинский район, поселок Сенная Падь, Центральная, 27	t	small
38906	35575	472	Иркутская область, Заларинский район, поселок Семеновское, Ленина, 1а	t	small
38877	35545	443	Иркутская область, Заларинский район, поселок Романова, Школьная, 8	t	small
86359	35553	451	Иркутская область, Заларинский район, поселок Романенкина, Центральная, 32	t	small
38876	35544	442	Иркутская область, Заларинский район, поселок Ремезовский, Центральная, 24	t	small
38875	35543	441	Иркутская область, Заларинский район, поселок Новочеремхово, Центральная, 12	t	small
38899	35567	465	Иркутская область, Заларинский район, поселок Николаевский, переулок Верхний, 5	t	small
86360	35557	455	Иркутская область, Заларинский район, поселок Муруй, Центральная, школа	t	small
38886	35554	452	Иркутская область, Заларинский район, поселок Мойган, Центральная, 25	t	small
38897	35565	463	Иркутская область, Заларинский район, поселок Моисеевка, Школьная, 2	t	medium
38874	35542	440	Иркутская область, Заларинский район, поселок Минеева, пер.Клубный, 1	t	small
38905	35574	471	Иркутская область, Заларинский район, поселок Мейеровка, Олейникова, 4	t	small
38871	35504	437	Иркутская область, Заларинский район, поселок Красное Поле (Тарасова), Механизаторов, 24	t	small
86362	35576	473	Иркутская область, Заларинский район, поселок Корсунгай, Ербанова, школа	t	small
38873	35541	439	Иркутская область, Заларинский район, поселок Илганское, Центральная, 2	t	small
38866	35536	432	Иркутская область, Заларинский район, поселок Залари, Победы, 50	f	large
38869	35539	435	Иркутская область, Заларинский район, поселок Залари, Ленина, 15	f	large
38868	35538	434	Иркутская область, Заларинский район, поселок Залари, Ленина, 76	f	large
38865	35535	431	Иркутская область, Заларинский район, поселок Залари, Лазо, 1	f	large
38882	35550	448	Иркутская область, Заларинский район, поселок Заблагар, Набережная, 1	t	small
38891	35559	457	Иркутская область, Заларинский район, поселок Жизневка, Юбилейная, 5	t	small
38884	35552	450	Иркутская область, Заларинский район, поселок Дмитриевка, Центральная, 13	t	small
110294	35442	436	Иркутская область, Заларинский район, поселок Владимир, Школьная, 23	t	medium
38901	35569	467	Иркутская область, Заларинский район, поселок Веренка, Новая, 2	t	medium
38898	35566	464	Иркутская область, Заларинский район, поселок Большая Заимка, Первомайская	t	small
86361	35564	462	Иркутская область, Заларинский район, поселок Благодатный, Ветеранов, 42	t	small
38872	35540	438	Иркутская область, Заларинский район, поселок Бажир, Юбилейная, 14	t	small
38890	35558	456	Иркутская область, Заларинский район, поселок Бабагай, пер.Школьный, 4	t	small
38852	35522	418	Иркутская область, Жигаловский район, с.Луконово, Полевая, 17	t	small
38844	35514	410	Иркутская область, Жигаловский район, поселок Якимовка, Центральная, 29	t	small
38843	35513	409	Иркутская область, Жигаловский район, поселок Чикан, Школьная, 1	t	small
38858	35528	424	Иркутская область, Жигаловский район, поселок Усть-Илга, Молодёжная, 2	t	small
38849	35519	415	Иркутская область, Жигаловский район, поселок Тыпта, Таежная, 23	t	small
38845	35515	411	Иркутская область, Жигаловский район, поселок Тутура, Кооперативная, 5	t	small
38851	35521	417	Иркутская область, Жигаловский район, поселок Тимошино, Николаева, 3	t	small
38854	35524	420	Иркутская область, Жигаловский район, поселок Рудовка, Школьная, 4	t	small
38855	35525	421	Иркутская область, Жигаловский район, поселок Пономарёва, Центральная, 31	t	small
38857	35527	423	Иркутская область, Жигаловский район, поселок Петрово, Ленская, 50	t	small
38847	35517	413	Иркутская область, Жигаловский район, поселок Нижняя Слобода, Центральная, 2	t	small
38842	35512	408	Иркутская область, Жигаловский район, поселок Коношаново, Ленская, 26	t	small
38850	35520	416	Иркутская область, Жигаловский район, поселок Качень, Речная, 4	t	small
110293	35516	412	Иркутская область, Жигаловский район, поселок Знаменка, Магистральная, 79	t	medium
38864	35534	430	Иркутская область, Жигаловский район, поселок Жигалово, Сосновая, 1	f	small
38861	35531	427	Иркутская область, Жигаловский район, поселок Жигалово, Советская, 11	f	medium
38860	35530	426	Иркутская область, Жигаловский район, поселок Жигалово, Партизанская, 48	f	medium
38859	35529	425	Иркутская область, Жигаловский район, поселок Жигалово, Неугодниковская, 45	f	medium
38862	35532	428	Иркутская область, Жигаловский район, поселок Жигалово, Колчанова, 16	t	medium
38848	35518	414	Иркутская область, Жигаловский район, поселок Дальняя Закора, Школьная, 4	t	small
38853	35523	419	Иркутская область, Жигаловский район, поселок Головновка, Центральная, 16	t	small
38856	35526	422	Иркутская область, Жигаловский район, поселок Воробьева, Таежная, 38	t	small
38818	35492	384	Иркутская область, Братский район, жилой район Энергетик, Наймушина, 26а	f	large
38809	35484	375	Иркутская область, Братский район, жилой район Энергетик, Зверева, 7	f	large
110292	35410	280	Иркутская область, Братский район, поселок Шумилово, Гагарина, 2	t	medium
38703	35399	269	Иркутская область, Братский район, поселок Худобок, Центральная, 39в	t	small
38697	35393	263	Иркутская область, Братский район, поселок Тэмь, Ленина, 24	f	small
38732	35428	298	Иркутская область, Братский район, поселок Турма, Гагарина, 26	f	large
38724	35420	290	Иркутская область, Братский район, поселок Тарма, 1-ая Нагорная, 16	f	medium
38699	35395	265	Иркутская область, Братский район, поселок Тангуй, Ленина, 54	f	large
38705	35401	271	Иркутская область, Братский район, поселок Сосновый, Школьная, 1	t	small
38693	35389	259	Иркутская область, Братский район, поселок Прибрежный, переулок Школьный, 4	f	large
38704	35400	270	Иркутская область, Братский район, поселок Покосное, Сибирская, 22	f	large
38692	35388	258	Иркутская область, Братский район, поселок Новое Приречье, Новая, 7	t	small
38723	35419	289	Иркутская область, Братский район, поселок Новодолоново, Лесная, 1	t	small
38740	35436	306	Иркутская область, Братский район, поселок Мамырь, Центральная, 2	t	small
86356	35392	262	Иркутская область, Братский район, поселок Луговой, Таежная, 5	t	small
38720	35416	286	Иркутская область, Братский район, поселок Леонова, Кооперативная, 21	f	small
38719	35415	285	Иркутская область, Братский район, поселок Кумейка, Школьная, 1	f	small
38725	35421	291	Иркутская область, Братский район, поселок Кузнецовка, Почтовая, 19	f	medium
38717	35413	283	Иркутская область, Братский район, поселок Куватка, Лесная, 4а	f	medium
86357	35402	272	Иркутская область, Братский район, поселок Кобь, Школьная, 1	t	small
38733	35429	299	Иркутская область, Братский район, поселок Кобляково, Сазонова, 8	f	medium
38718	35414	284	Иркутская область, Братский район, поселок Ключи-Булак, Ленина, 2	f	large
38739	35435	305	Иркутская область, Братский район, поселок Кежемский, Октябрьская, 7	f	large
38695	35391	261	Иркутская область, Братский район, поселок Кардой, Трактовая, 56	t	small
38721	35417	287	Иркутская область, Братский район, поселок Калтук, Погодаева, 12 б	f	large
38694	35390	260	Иркутская область, Братский район, поселок Илир, Кирова, 14	f	medium
38737	35433	303	Иркутская область, Братский район, поселок Зяба, Кооперативная, 3а	t	small
38701	35397	267	Иркутская область, Братский район, поселок Зарбь, Центральная, 56	t	small
38736	35432	302	Иркутская область, Братский район, поселок Дубынино, Центральная, 26а	t	small
39348	35951	915	Иркутская область, Братский район, поселок Воронино, сельский клуб	t	small
38727	94942	293	Иркутская область, Братский район, Вихоревка, Школьная, 9	f	large
38730	94944	296	Иркутская область, Братский район, Вихоревка, Пионерская, 18	f	large
68128	36835	1880	Иркутская область, Братский район, Вихоревка, Пионерская, 35, школа 10	f	large
68127	36835	1879	Иркутская область, Братский район, Вихоревка, Пионерская, 35, школа 10	f	large
68126	36835	1878	Иркутская область, Братский район, Вихоревка, Пионерская, 35, школа 10	f	large
68125	36834	1877	Иркутская область, Братский район, Вихоревка, Пионерская, 18, школа №2	f	large
68129	36836	1881	Иркутская область, Братский район, Вихоревка, Октябрьская, 7, ДШИ	f	large
38729	94943	295	Иркутская область, Братский район, Вихоревка, Ленина, 35	f	large
38728	94943	294	Иркутская область, Братский район, Вихоревка, Ленина, 35	f	large
86358	36833	1876	Иркутская область, Братский район, Вихоревка, Ленина, 21	f	small
110324	36833	1875	Иркутская область, Братский район, Вихоревка, Ленина, 21	f	medium
68124	36833	1874	Иркутская область, Братский район, Вихоревка, Ленина, 21	f	large
38731	94945	297	Иркутская область, Братский район, Вихоревка, Дзержинского, 101	f	large
68123	35437	1873	Иркутская область, Братский район, Вихоревка, Дзержинского, 101, школа	f	large
68122	35437	307	Иркутская область, Братский район, Вихоревка, Дзержинского, 101, школа	f	large
68121	35422	292	Иркутская область, Братский район, Вихоревка, 35 лет Победы, 15а	f	large
38644	35344	210	Иркутская область, Братский район, поселок Васильевский, Ленских Событий, 42	t	small
38735	35431	301	Иркутская область, Братский район, поселок Бурнинская Вихоря (Бурнинск), Первомайская, 18	t	small
38742	35438	308	Иркутская область, Братский район, Братск, площадь 50 лет Октября, 112	f	large
38743	35438	309	Иркутская область, Братский район, Братск, площадь 50 лет Октября, 112	f	large
38796	35473	362	Иркутская область, Братский район, Братск, Школьная, 19	f	large
38750	35443	316	Иркутская область, Братский район, Братск, Снежная, 2, Центральный округ, жилой район Центральный,	f	large
38749	35443	315	Иркутская область, Братский район, Братск, Снежная, 2, Центральный округ, жилой район Центральный,	f	large
38800	35476	366	Иркутская область, Братский район, Братск, Пролетарская, 50	f	large
38799	35476	365	Иркутская область, Братский район, Братск, Пролетарская, 50	f	large
38813	35487	379	Иркутская область, Братский район, Братск, Приморская, 9А	f	large
38817	35491	383	Иркутская область, Братский район, Братск, Погодаева, 13/15	f	large
38757	35447	323	Иркутская область, Братский район, Братск, Пионерская, 13Б	f	large
38808	35483	374	Иркутская область, Братский район, Братск, Олимпийская, 17	f	large
38807	35482	373	Иркутская область, Братский район, Братск, Олимпийская, 25	f	large
38806	35482	372	Иркутская область, Братский район, Братск, Олимпийская, 25	f	large
38814	35488	380	Иркутская область, Братский район, Братск, Наймушина, 18А	f	large
38766	35453	332	Иркутская область, Братский район, Братск, Курчатова, 54	f	large
38765	35453	331	Иркутская область, Братский район, Братск, Курчатова, 54	f	large
38791	35467	357	Иркутская область, Братский район, Братск, Крупской, 39	f	large
38790	35467	356	Иркутская область, Братский район, Братск, Крупской, 39	f	large
38785	35465	351	Иркутская область, Братский район, Братск, Крупской, 5	f	large
38787	35465	353	Иркутская область, Братский район, Братск, Крупской, 5	f	large
38786	35465	352	Иркутская область, Братский район, Братск, Крупской, 5	f	large
68130	35461	344	Иркутская область, Братский район, Братск, Комсомольская, 75	f	large
38748	35441	314	Иркутская область, Братский район, Братск, Кирова, 9	f	large
38747	35441	313	Иркутская область, Братский район, Братск, Кирова, 9	f	large
38826	35497	392	Иркутская область, Братский район, Братск, Заводская, 11Б	f	large
38825	35497	391	Иркутская область, Братский район, Братск, Заводская, 11Б	f	large
38824	35496	390	Иркутская область, Братский район, Братск, Заводская, 3Б	f	large
38823	35496	389	Иркутская область, Братский район, Братск, Заводская, 3Б	f	large
38828	35498	394	Иркутская область, Братский район, Братск, Енисейская, 66/7	f	large
38827	35498	393	Иркутская область, Братский район, Братск, Енисейская, 66/7	f	large
38841	35511	407	Иркутская область, Братский район, Братск, Еловая, 20	f	large
38802	35478	368	Иркутская область, Братский район, Братск, Гидростроителей, 31	f	large
38834	35503	400	Иркутская область, Братский район, Братск, Гайнулина, 71	f	medium
38793	35470	359	Иркутская область, Братский район, Братск, Гагарина, 16	f	large
38781	35463	347	Иркутская область, Братский район, Братск, Гагарина, 49	f	large
38780	35463	346	Иркутская область, Братский район, Братск, Гагарина, 49	f	large
38756	35446	322	Иркутская область, Братский район, Братск, Верхняя, 30А	f	large
38832	35501	398	Иркутская область, Братский район, Братск, Байкальская, 43	f	large
38837	35507	403	Иркутская область, Братский район, Братск, Ангарстроя, 11	f	large
38738	35434	304	Иркутская область, Братский район, поселок Боровской, Школьная, 1	t	small
38722	35418	288	Иркутская область, Братский район, поселок Большеокинское, Первомайская, 4	t	medium
38698	35394	264	Иркутская область, Братский район, поселок Барчим, Мира, 38а	t	small
38700	35396	266	Иркутская область, Братский район, поселок Бада, Пионерская, 3 а	t	small
38702	35398	268	Иркутская область, Братский район, поселок Александровка, Советская, 16	t	small
38680	35376	246	Иркутская область, Боханский район, д. Баргазово, Дорожная, 1	f	small
38663	35358	229	Иркутская область, Боханский район, поселок Шунта, Депутатская, 1	f	small
38655	35341	221	Россия, Иркутская область, Боханский район, поселок Чилим	t	small
38661	35356	227	Иркутская область, Боханский район, поселок Хохорск, Ленина, 8	f	medium
38662	35357	228	Иркутская область, Боханский район, поселок Харатирген, Ленина, 49	f	small
38653	35353	219	Иркутская область, Боханский район, поселок Харагун, Школьная, 9	f	small
38670	35365	236	Иркутская область, Боханский район, поселок Хандагай, Комсомольская, 18	f	small
38656	35006	222	Иркутская область, Боханский район, поселок Укыр, Школьная, 24	f	medium
38685	35381	251	Иркутская область, Боханский район, поселок Угольная, Школьная, 3	t	small
38654	35252	220	Иркутская область, Боханский район, поселок Тихоновка, Ленина, 13	f	large
38671	35366	237	Иркутская область, Боханский район, поселок Тараса, Ленина, 17	f	medium
110291	35387	257	Иркутская область, Боханский район, поселок Середкино, Ленина, 2	f	medium
38660	35355	226	Иркутская область, Боханский район, поселок Русиновка, Ключевая, 5	f	small
38657	35181	223	Иркутская область, Боханский район, поселок Петрограновка, Лесная, 44	t	small
38674	35369	240	Иркутская область, Боханский район, поселок Олонки, Калинина, 5	f	large
38672	35367	238	Иркутская область, Боханский район, поселок Новый Алендарь, Школьная, 1	f	small
38659	35354	225	Иркутская область, Боханский район, поселок Нововоскресенка, Ленина, 15	f	small
38669	35364	235	Иркутская область, Боханский район, поселок Новая Ида, Центральная, 44	f	medium
38690	35386	256	Иркутская область, Боханский район, поселок Мутинова, Полевая, 1	f	small
38686	35382	252	Иркутская область, Боханский район, поселок Морозова, Школьная, 10	f	small
38658	35206	224	Россия, Иркутская область, Боханский район, поселок Манькова	f	small
38687	35383	253	Иркутская область, Боханский район, поселок Логанова, Трудовая, 26	t	small
38688	35384	254	Иркутская область, Боханский район, поселок Крюкова, Кузнецовская, 36	t	small
38684	35380	250	Иркутская область, Боханский район, поселок Каменка, Школьная, 1	f	medium
38682	35378	248	Иркутская область, Боханский район, поселок Калашникова, Школьная, 8	t	small
38689	35385	255	Иркутская область, Боханский район, поселок Казачье, Мира, 10	f	medium
38675	35371	241	Иркутская область, Боханский район, поселок Захаровская, Трактовая, 9	t	small
38667	35362	233	Иркутская область, Боханский район, поселок Заглик, Трактовая, 19	f	small
38652	35352	218	Иркутская область, Боханский район, поселок Дундай, Центральная, 32	f	small
38681	35377	247	Иркутская область, Боханский район, поселок Грязная, Пионерская, 3	t	small
38683	35379	249	Иркутская область, Боханский район, поселок Гречехан, Колхозная, 12	f	small
38676	35372	242	Иркутская область, Боханский район, поселок Грехневка, Школьная, 2	t	small
38677	35373	243	Иркутская область, Боханский район, поселок Воробьевка, Школьная, 15	f	small
38651	35351	217	Иркутская область, Боханский район, поселок Вершина, Советская, 47	f	small
110290	35375	245	Иркутская область, Боханский район, поселок Буреть,красная Буреть, Центральная, 27	f	medium
38673	35368	239	Иркутская область, Боханский район, поселок Буреть,красная Буреть, Мира, 26	f	small
38668	35363	234	Иркутская область, Боханский район, поселок Булык, Ленина, 10	f	small
38665	35360	231	Иркутская область, Боханский район, поселок Бохан, Ленина, 50	f	large
38666	35361	232	Иркутская область, Боханский район, поселок Бохан, Киевская, 4	f	small
38678	35374	244	Иркутская область, Боханский район, поселок Александровское, Дзержинского, 35	t	medium
86373	35323	191	Иркутская область, Баяндаевский район, поселок Шитхулун, улица Трактовая, 51	t	small
38607	35305	173	Иркутская область, Баяндаевский район, поселок Шаманка, Бурлова, 38	f	small
110288	35321	189	Иркутская область, Баяндаевский район, поселок Хогот, Трактовая, 85	t	medium
38617	35315	183	Иркутская область, Баяндаевский район, поселок Хатар-Хадай, Трактовая, 2	t	small
38604	35302	170	Иркутская область, Баяндаевский район, поселок Харагун, Трактовая, 4	f	small
38627	35325	193	Россия, Иркутская область, Баяндаевский район, поселок Хандагай	t	small
38608	35306	174	Иркутская область, Баяндаевский район, поселок Улан, Подгорная, 12	f	small
38629	35327	195	Иркутская область, Баяндаевский район, поселок Тухум, Центральная, 1А	t	small
38605	35303	171	Иркутская область, Баяндаевский район, поселок Тургеневка, Советская, 56	f	small
86372	35322	190	Иркутская область, Баяндаевский район, поселок Старый Хогот, Трактовая, 31, кв.2	f	small
38606	35304	172	Иркутская область, Баяндаевский район, поселок Половинка (Гоголевка), пер.Клубный, 5	f	small
38609	35307	175	Иркутская область, Баяндаевский район, поселок Покровка, Мира, 1	t	medium
38613	35311	179	Иркутская область, Баяндаевский район, поселок Ользоны, Титова, 13	t	medium
38621	35319	187	Иркутская область, Баяндаевский район, поселок Нуху-Нур, Хургалдайраг, 7	t	small
38618	35316	184	Иркутская область, Баяндаевский район, поселок Наумовка, Центральная, 36	f	small
38620	35318	186	Иркутская область, Баяндаевский район, поселок Нагалык, Ленина, 6	t	small
38611	35309	177	Иркутская область, Баяндаевский район, поселок Люры, Чкалова, 2А	f	small
38614	35312	180	Иркутская область, Баяндаевский район, поселок Кокорина, Центральная, 12	f	small
38626	35324	192	Иркутская область, Баяндаевский район, поселок Кайзаран, Клубная, 13	t	small
38615	35313	181	Иркутская область, Баяндаевский район, поселок Загатуй, Микрорайон-141	f	medium
38622	35320	188	Иркутская область, Баяндаевский район, поселок Еленинск, Горная, 1	t	small
38603	35301	169	Иркутская область, Баяндаевский район, поселок Васильевка, Центральная, 12	f	small
38612	35310	178	Иркутская область, Баяндаевский район, поселок Бохолдой, Муринская, 14	f	small
38610	35308	176	Иркутская область, Баяндаевский район, поселок Баяндай, Гагарина, 40	t	large
38616	35314	182	Иркутская область, Баяндаевский район, поселок Бахай 1-й, Муринская, 26	f	small
38628	35326	194	Иркутская область, Баяндаевский район, поселок Байша, Центральная, 64Б	t	small
38619	35317	185	Иркутская область, Баяндаевский район, поселок Бадагуй (Гахан), Урбаева, 2	f	small
38599	35296	165	Иркутская область, Балаганский район, поселок Шарагай, Центральная, 13	t	small
86355	35289	158	Иркутская область, Балаганский район, поселок Ташлыкова, Школьная, 2, Школа	t	small
38594	35291	160	Иркутская область, Балаганский район, поселок Тарнополь, Садовый, 6	t	small
38598	35295	164	Иркутская область, Балаганский район, поселок Тарасовск, Школьная, 14	t	small
38596	35293	162	Иркутская область, Балаганский район, поселок Метляева, Трудовая, 19	t	small
38600	35297	166	Иркутская область, Балаганский район, поселок Кумарейка, Первомайская, 2	t	medium
38591	35288	157	Иркутская область, Балаганский район, поселок Коновалово, Лесная, 10	t	medium
38597	35294	163	Иркутская область, Балаганский район, поселок Заславская, Ленина, 11	f	medium
38593	35290	159	Иркутская область, Балаганский район, поселок Бирит, 2 Советская, 1	t	small
38602	35299	168	Иркутская область, Балаганский район, поселок Балаганск, Горького, 31	f	large
38601	35298	167	Иркутская область, Балаганский район, поселок Балаганск, Горького, 33	f	large
38595	35292	161	Иркутская область, Балаганский район, поселок Анучинск, Школьная, 6-1	t	small
38575	35272	141	Иркутская область, Ангарский район, поселок Савватеевка, Клубная, 2	f	large
38576	35274	142	Иркутская область, Ангарский район, поселок Одинск, Молодежная, 2а, Спорткомплекс	f	large
38580	35277	146	Иркутская область, Ангарский район, поселок Мегет, Адм.здание ОАО Хлебная база №15	f	medium
38579	35276	145	Иркутская область, Ангарский район, поселок Мегет, переулок Школьный, 8, Мегетская средняя школа	f	large
38578	35276	144	Иркутская область, Ангарский район, поселок Мегет, переулок Школьный, 8, Мегетская средняя школа	f	large
38577	35275	143	Иркутская область, Ангарский район, поселок Мегет, кв-л 17	f	large
38581	35278	147	Иркутская область, Ангарский район, поселок Мегет, Детсадовская, 6, Мегетская средняя школа	f	large
39933	36507	1500	Иркутская область, Ангарский район, село Биликтуй, Советская, 47кв.1	t	medium
38557	35256	123	Иркутская область, Ангарский район, Ангарск, мкр.1916, Средняя школа № 9	f	large
38556	35256	122	Иркутская область, Ангарский район, Ангарск, мкр.1916, Средняя школа № 9	f	large
38470	35176	35	Иркутская область, Аларский район, поселок Шаховская, Центральная, 37	t	small
38459	35165	24	Иркутская область, Аларский район, поселок Шалоты, Центральная, 23	t	small
38450	35155	15	Иркутская область, Аларский район, поселок Хуруй, Первая, 23	t	small
38444	35149	9	Иркутская область, Аларский район, поселок Халты, Светлая, 22	t	small
38441	35146	6	Иркутская область, Аларский район, поселок Угольная, Советская	t	small
38474	35180	39	Иркутская область, Аларский район, поселок Тютрина, Новая, 5-2	t	small
38483	35190	48	Иркутская область, Аларский район, поселок Тыргетуй, Советская, 33-1	t	medium
38481	35188	46	Иркутская область, Аларский район, поселок Табарсук, Чумакова, 14	t	medium
38458	35164	23	Иркутская область, Аларский район, поселок Отрадная, Новая, 16	t	small
38479	35186	44	Иркутская область, Аларский район, поселок Ныгда, Советская, 12	t	medium
38477	35184	42	Иркутская область, Аларский район, поселок Нельхай, Мира, 7	t	small
38453	35159	18	Иркутская область, Аларский район, поселок Нарены (Левые Нарены), Центральная, 12	t	small
38476	35183	41	Иркутская область, Аларский район, поселок Мольта, Трактовая, 29А	t	small
38473	35179	38	Иркутская область, Аларский район, поселок Могоенок, Лесная, 1А	t	small
38469	35175	34	Иркутская область, Аларский район, поселок Маниловская, Советская, 40	t	small
38472	35178	37	Иркутская область, Аларский район, поселок Малый Кутулик, Школьная, 1А	t	small
38471	35177	36	Иркутская область, Аларский район, поселок Маломолева, Центральная, 14А	t	small
38466	35172	31	Иркутская область, Аларский район, поселок Кутулик, Шилова, 1	f	large
38465	35171	30	Иркутская область, Аларский район, поселок Кутулик, Советская, 49	f	large
38464	35170	29	Иркутская область, Аларский район, поселок Кутулик, Ветеринарная, 18	f	medium
38439	35143	4	Иркутская область, Аларский район, поселок Куркат, Центральная, 37	t	small
38912	35581	478	Иркутская область, Аларский район, поселок Кундулун, Партизанская, 10	t	small
38438	35142	3	Иркутская область, Аларский район, поселок Кукунур, Центральная, 3	t	small
38462	35168	27	Иркутская область, Аларский район, поселок Куйта, Центральная, 23	t	small
38468	35174	33	Иркутская область, Аларский район, поселок Корховская, Центральная, 22	t	small
38480	35187	45	Иркутская область, Аларский район, деревня Кирюшина, Звездочка, 34-2	t	small
38457	35163	22	Иркутская область, Аларский район, поселок Киркей, Центральная, 32	t	small
38482	35189	47	Иркутская область, Аларский район, поселок Икинат (Зангей), Ербанова, 2А	t	small
38461	35167	26	Иркутская область, Аларский район, поселок Идеал, Коммунаров, 17	t	medium
38452	35158	17	Иркутская область, Аларский район, поселок Иванова, Белорусская, 4-2	t	small
38456	35162	21	Иркутская область, Аларский район, поселок Иваническое, Юбилейная, 7А	t	medium
38455	35161	20	Иркутская область, Аларский район, поселок Зоны, Центральная, 12	t	medium
38460	35166	25	Иркутская область, Аларский район, поселок Заречное, Первая, 9	t	small
38467	35173	32	Иркутская область, Аларский район, поселок Занина, Центральная, 51	t	small
38451	35156	16	Иркутская область, Аларский район, поселок Забитуй, 70 лет Октября, 24	t	large
38449	35154	14	Иркутская область, Аларский район, поселок Егоровская, Центральная, 1	t	small
38463	35169	28	Иркутская область, Аларский район, поселок Головинское, Васильева, 6	t	large
38443	35148	8	Иркутская область, Аларский район, поселок Высотская, Нагорная, 27	t	small
38447	35152	12	Иркутская область, Аларский район, поселок Быково, Мира, 11А	t	small
80132	33508	86	Забайкальский край, Читинский район, Чита, проспект Фадеева, 2	f	large
40125	36663	1692	Иркутская область, Аларский район, поселок Бурятский Забитуй (Малиновка), Школьная	f	small
38454	35160	19	Иркутская область, Аларский район, поселок Бурятская, Верхняя	t	small
38478	35185	43	Иркутская область, Аларский район, поселок Буркова, Школьная, 2А	t	small
38448	35153	13	Иркутская область, Аларский район, поселок Бахтай, Ербанова, 21	t	medium
38475	35182	40	Иркутская область, Аларский район, поселок Апхульта, Октябрьская, 11	t	small
38446	35151	11	Иркутская область, Аларский район, поселок Апхайта, Победы, 12А	t	small
38445	35150	10	Иркутская область, Аларский район, поселок Ангарский, Ленина, 15	t	small
38442	35147	7	Иркутская область, Аларский район, Аляты, Жана Зимина, 1А	t	medium
38437	35141	2	Иркутская область, Аларский район, поселок Алзобей, Школьная, 14	t	small
38440	35144	5	Иркутская область, Аларский район, поселок Александровск, Центральная, 50	t	small
38436	35140	1	Иркутская область, Аларский район, поселок Аларь, Лазо, 14-2	t	medium
80320	34275	862	Забайкальский край, Шилка, Бородина, 11	f	large
80156	33536	114	Забайкальский край, Чита, здание станции Черновской Забайкальской железной дороги	f	large
109603	33537	115	Забайкальский край, Чита, проезд Булгакова, 60	f	medium
80054	33428	1	Забайкальский край, Чита, мкр. Геофизический, 14А	f	large
80055	33429	2	Забайкальский край, Чита, микрорайон Северный, 1	f	large
80315	33429	830	Забайкальский край, Чита, микрорайон Северный, 1	f	large
80109	33482	59	Забайкальский край, Чита, Ярославского, 47	f	large
109601	33532	110	Забайкальский край, Чита, Юбилейная, 1	f	medium
80138	33514	92	Забайкальский край, Чита, Труда, 14	f	large
80147	33523	101	Забайкальский край, Чита, Строителей, 26	f	large
80128	33504	82	Забайкальский край, Чита, Романовский Тракт, 77, Железнодорожный административный район,	f	large
80123	33499	77	Забайкальский край, Чита, Ползунова, 11	f	large
109802	33784	371	Забайкальский край, Чита, Первомайская, 36а	f	medium
80068	33440	15	Забайкальский край, Чита, Новобульварная, 32	f	large
80113	33486	64	Забайкальский край, Чита, Луговая, 87	f	large
80103	33476	53	Забайкальский край, Чита, Ленина, 2, Ингодинский административный район	f	large
80107	33480	57	Забайкальский край, Чита, Лазо, 28	f	large
80060	33433	7	Забайкальский край, Чита, Красной Звезды, 36А	f	large
80058	33431	5	Забайкальский край, Чита, Красной Звезды, 7	f	large
80120	33496	74	Забайкальский край, Чита, Карла Маркса, 10	f	large
80102	33475	52	Забайкальский край, Чита, Забайкальского Рабочего, 16	f	large
80075	33446	22	Забайкальский край, Чита, Журавлева, 3	f	large
80071	33443	18	Забайкальский край, Чита, Журавлева, 77	f	large
80150	33527	105	Забайкальский край, Чита, Жилой городок, 15	f	large
80104	33477	54	Забайкальский край, Чита, Декабристов, 12	f	large
80080	33451	27	Забайкальский край, Чита, район Центральный, Горького, 39А	f	large
80079	33450	26	Забайкальский край, Чита, район Центральный, Горького, 38	f	large
80088	33460	36	Забайкальский край, Чита, Геофизический микрорайон, 14А	f	large
80059	33432	6	Забайкальский край, Чита, Геодезическая, 45	f	large
80096	33469	46	Забайкальский край, Чита, Гагарина, 1	f	large
80118	33494	72	Забайкальский край, городской округ Чита, Вайнштейна, 1	f	large
80090	33462	38	Забайкальский край, Чита, Балябина, 1	f	large
80101	33474	51	Забайкальский край, Чита, Бабушкина, 28	f	large
80089	33461	37	Забайкальский край, Чита, Бабушкина, 125	f	large
80078	33449	25	Забайкальский край, Чита, Бабушкина, 129, Центральный административный район	f	large
80155	33534	112	Забайкальский край, Чита, Агрогородок Опытный, 10	f	large
80144	33520	98	Забайкальский край, Чита, 6 микрорайон, 4А	f	large
80135	33511	89	Забайкальский край, Чита, 4 микрорайон, 13-А	f	large
80134	33510	88	Забайкальский край, Чита, 4 микрорайон, 15-Б	f	large
80072	33444	19	Забайкальский край, Чита, Хабаровская, 2	f	large
80112	33484	62	Забайкальский край, Чита, Промышленная, 49, Ингодинский административный район	f	large
80083	33454	30	Забайкальский край, Чита, Кайдаловская, 15, Центральный административный район	f	large
80133	33509	87	Забайкальский край, Чита, 5 микрорайон, 5, Черновский административный район	f	large
80069	33441	16	Забайкальский край, Чита, Курнатовского, 45а, Центральный административный район	f	large
109611	33547	125	Забайкальский край, Петровск-Забайкальский, площадь Ленина, дворец культуры	f	medium
109610	33546	124	Забайкальский край, Петровск-Забайкальский, Чехова, 14	f	medium
80158	33544	122	Забайкальский край, Петровск-Забайкальский, Федосеевка, 3	f	large
80159	33554	131	Забайкальский край, Петровск-Забайкальский, Станционная, 20	f	large
109615	33552	129	Забайкальский край, Петровск-Забайкальский, Спортивная, 9	f	medium
109612	33548	126	Забайкальский край, Петровск-Забайкальский, Спортивная, 20	f	medium
80157	33543	121	Забайкальский край, Петровск-Забайкальский, Островского, 60	f	large
109609	33545	123	Забайкальский край, Петровск-Забайкальский, Некрасова, 1	f	medium
109607	33541	119	Забайкальский край, Петровск-Забайкальский, Нагорная, 2	f	medium
80160	33557	135	Забайкальский край, Петровск-Забайкальский, Нагаева, 2	f	large
109616	33553	130	Забайкальский край, Петровск-Забайкальский, Мира, 1	f	small
109614	33550	128	Забайкальский край, Петровск-Забайкальский, Микрорайон 1, гимназия №1	f	medium
109620	33559	137	Забайкальский край, Петровск-Забайкальский, Лесная, 68	f	medium
109619	33558	136	Забайкальский край, Петровск-Забайкальский, Лесная, 19	f	small
109613	33549	127	Забайкальский край, Петровск-Забайкальский, Ленина, 16	f	medium
109618	33556	134	Забайкальский край, Петровск-Забайкальский, Лазо, 1	f	medium
109608	33542	120	Забайкальский край, Петровск-Забайкальский, Красная, 14	f	small
109606	33540	118	Забайкальский край, Петровск-Забайкальский, Декабристов, 14	f	small
109605	33539	117	Забайкальский край, Петровск-Забайкальский, Горбачевского, 17	f	medium
80284	34057	642	Забайкальский край, Нерчинск, Красноармейская, 140, ДЮСШ	f	large
109997	34055	640	Забайкальский край, Нерчинск, Береговая, СОШ № 2	f	medium
80251	33860	448	Забайкальский край, Краснокаменск, Средняя школа №8	f	large
80250	33860	447	Забайкальский край, Краснокаменск, Средняя школа №8	f	large
80246	33857	443	Забайкальский край, Краснокаменск, Средняя школа №5	f	large
80245	33857	442	Забайкальский край, Краснокаменск, Средняя школа №5	f	large
109816	33804	389	Забайкальский край, Балей, Чернышевского, 14	f	medium
80126	33502	80	Забайкальский край, городской округ Чита, Чита, Трактовая, 40	f	large
80087	33458	34	Забайкальский край, городской округ Чита, Чита, Профсоюзная, 14	f	large
109596	33487	65	Забайкальский край, городской округ Чита, Чита, Молоковский Тракт, 124, Ингодинский административный район	t	small
80106	33479	56	Забайкальский край, городской округ Чита, Чита, Ингодинская, 19, Ингодинский административный район	f	large
80099	33472	49	Забайкальский край, городской округ Чита, Чита, Баргузинская, 41	f	large
80111	33483	61	Забайкальский край, городской округ Чита, Чита, 1-й Микрорайон, 16	f	large
80110	33483	60	Забайкальский край, городской округ Чита, Чита, 1-й Микрорайон, 16	f	large
80322	34278	864	Забайкальский край, Шилкинский район, Шилка, Ленина, 53	f	large
110178	34282	868	Забайкальский край, Шилкинский район, Шилка, Забелина, школа	f	small
80324	34281	867	Забайкальский край, Шилкинский район, Шилка, Вокзальная, 3	f	large
80323	34280	866	Забайкальский край, Шилкинский район, Шилка, Балябина, 162	f	large
80321	34276	863	Забайкальский край, Шилкинский район, Шилка, Балябина, 64	f	large
110192	34304	889	Забайкальский край, Шилкинский район, село Чирон, Советская, Дом культуры	t	medium
80325	34283	869	Забайкальский край, Шилкинский район, поселок городского типа Холбон, Просвещенская, 16а	f	large
110190	34302	887	Забайкальский край, Шилкинский район, село Усть-Теленгуй, Советская, 19	t	small
110209	34321	906	Забайкальский край, Шилкинский район, село Усть-Ножовая, Зеленая, 1	t	small
110207	34319	904	Забайкальский край, Шилкинский район, село Ульяновка, Центральная, 23б	t	small
110188	34300	885	Забайкальский край, Шилкинский район, село Средняя Кия, Центральная, Дом культуры	f	small
110200	34312	897	Забайкальский край, Шилкинский район, село Саввино, Жалган, 2	t	small
110195	34307	892	Забайкальский край, Шилкинский район, село Размахнино, Зеленская, 1	t	medium
80330	34290	875	Забайкальский край, Шилкинский район, Первомайский, Чкалова, 2	f	large
80329	34288	874	Забайкальский край, Шилкинский район, поселок городского типа Первомайский, Строительная, 2	f	large
80327	34286	872	Забайкальский край, Шилкинский район, поселок Первомайский, микрорайон, 19	f	large
80328	34287	873	Забайкальский край, Шилкинский район, поселок Первомайский, Пролетарская, 3	f	large
80326	34285	871	Забайкальский край, Шилкинский район, поселок Первомайский, Ленина, 40	f	large
110203	34315	900	Забайкальский край, Шилкинский район, село Островки, Центральная, 20	f	small
110208	34320	905	Забайкальский край, Шилкинский район, село Ононское, Школьная, интернат	t	medium
110194	34306	891	Забайкальский край, Шилкинский район, село Номоконово, Школьная, 12	t	small
110201	34313	898	Забайкальский край, Шилкинский район, село Новоберезовское, Центральная, 48	f	small
110202	34314	899	Забайкальский край, Шилкинский район, село Нижняя Хила, Советская, 21	t	small
110185	34297	882	Забайкальский край, Шилкинский район, село Митрофаново, Глазова, Дом культуры	f	small
110183	34295	880	Забайкальский край, Шилкинский район, село Мирсаново, Кирова, ДК	t	medium
110189	34301	886	Забайкальский край, Шилкинский район, село Кыэкен, Соболева, Библиотека	t	small
110196	34308	893	Забайкальский край, Шилкинский район, село Красноярово, Центральная, 42	t	small
110186	34298	883	Забайкальский край, Шилкинский район, село Кокуй-Комогорцево, Центральная, Дом культуры	f	small
110193	34305	890	Забайкальский край, Шилкинский район, село Кироча, Заимочная, 18	t	small
110184	34296	881	Забайкальский край, Шилкинский район, село Кибасово (Выселок), Лазо, Клуб	t	small
80331	34294	879	Забайкальский край, Шилкинский район, село Казаново, Октябрьской революции, 61	f	large
110199	34311	896	Забайкальский край, Шилкинский район, село Зубарево, Центральная, 26	t	small
110198	34310	895	Забайкальский край, Шилкинский район, село Галкино, Центральная, 16	t	small
110205	34317	902	Забайкальский край, Шилкинский район, село Верхняя Хила, Советская, 27	f	medium
110206	34318	903	Забайкальский край, Шилкинский район, село Васильевка, Клубная, 1А	f	small
110187	34299	884	Забайкальский край, Шилкинский район, село Богомягково, И.П. Богомягкова, Дом культуры	f	small
110179	34284	870	Забайкальский край, Шилкинский район, поселок городского типа Арбагар, Первомайская, 3	t	small
110165	34260	846	Забайкальский край, Шелопугинский район, село Шивия, Центральная, 8	f	small
110164	34259	845	Забайкальский край, Шелопугинский район, село Шивия, Верхняя, 20	t	small
110175	34271	858	Забайкальский край, Шелопугинский район, село Шелопугино, Центральная, 21а	t	small
110172	34268	855	Забайкальский край, Шелопугинский район, село Шелопугино, Центральная, 1	f	small
110171	34267	854	Забайкальский край, Шелопугинский район, село Шелопугино, Советская, 136	f	medium
80318	34266	853	Забайкальский край, Шелопугинский район, село Шелопугино, Советская, 17	f	large
110174	34270	857	Забайкальский край, Шелопугинский район, село Шелопугино, Набережная, 20	t	small
110173	34269	856	Забайкальский край, Шелопугинский район, село Шелопугино, Лазо, 2	f	medium
110177	34273	860	Забайкальский край, Шелопугинский район, село Нижняя Шахтама, Первомайская улица, 10	t	small
110176	34272	859	Забайкальский край, Шелопугинский район, село Нижняя Шахтама, Нагорная улица, 1	f	small
110161	34255	841	Забайкальский край, Шелопугинский район, село Мироново, Школьная, 17А	f	small
110160	34254	840	Забайкальский край, Шелопугинский район, село Мироново, Центральная, 29а	f	small
110167	34262	849	Забайкальский край, Шелопугинский район, село Малый Тонтой, Чугуевского, 24	t	small
110166	34261	848	Забайкальский край, Шелопугинский район, село Малый Тонтой, Атавина, 18	t	small
110163	34258	844	Забайкальский край, Шелопугинский район, село Копунь, Верхняя, 23	t	small
110162	34257	843	Забайкальский край, Шелопугинский район, Копунское, Нагорная, 22	f	small
110168	34263	850	Забайкальский край, Шелопугинский район, село Глинянка, Центральная, 18	t	small
110169	34264	851	Забайкальский край, Шелопугинский район, село Глинянка, Трактовая, 16	f	small
80319	34274	861	Забайкальский край, Шелопугинский район, село Вершино-Шахтаминский, Трактовая, 2	t	large
109785	33755	342	Забайкальский край, Читинский район, поселок городского типа Яблоново, Школьная, 16	t	medium
109786	33756	343	Забайкальский край, Читинский район, поселок городского типа Яблоново, Вокзальная, 60	t	small
80197	33740	328	Забайкальский край, Читинский район, село Шишкино, Центральная, 48а	f	large
80142	33518	96	Забайкальский край, Читинский район, Чита, проспект Фадеева, 29	f	large
80317	34256	842	Забайкальский край, Читинский район, Чита, мкр. Октябрьский, 3	f	large
80057	33430	4	Забайкальский край, Читинский район, Чита, микрорайон Северный, 50	f	large
80056	33430	3	Забайкальский край, Читинский район, Чита, микрорайон Северный, 50	f	large
80127	33503	81	Забайкальский край, Читинский район, Чита, Ямаровская, 4, Железнодорожный административный район	f	large
80091	33465	41	Забайкальский край, Читинский район, Чита, Юности, 6	f	large
80151	33528	106	Забайкальский край, Читинский район, Чита, Школьная, 1, Черновский административный район	f	large
80081	33452	28	Забайкальский край, Читинский район, Чита, Чайковского, 6	f	large
80140	33516	94	Забайкальский край, Читинский район, Чита, Текстильщиков, 14	f	large
80148	33524	102	Забайкальский край, Читинский район, Чита, Строителей, 17, Черновский административный район	f	large
80145	33521	99	Забайкальский край, Читинский район, Чита, Строителей, 9	f	large
109602	33535	113	Забайкальский край, Читинский район, Чита, Сретенская, 22	f	medium
80125	33501	79	Забайкальский край, Читинский район, Чита, Рахова, 15	f	large
80149	33525	103	Забайкальский край, Читинский район, Чита, Ранетная, 7	f	large
80085	33456	32	Забайкальский край, Читинский район, Чита, Полины Осипенко, 18	f	large
80064	33436	11	Забайкальский край, Читинский район, Чита, Подгорбунского, 98, Центральный административный район	f	large
80077	33448	24	Забайкальский край, Читинский район, Чита, Новобульварная, 28, Центральный административный район	f	large
80066	33438	13	Забайкальский край, Читинский район, Чита, Новобульварная, 60	f	large
80063	33435	10	Забайкальский край, Читинский район, Чита, Новобульварная, 64, Центральный административный район	f	large
80117	33493	71	Забайкальский край, Читинский район, Чита, Недорезова, 16	f	large
80139	33515	93	Забайкальский край, Читинский район, Чита, Назара Широких, 10-А	f	large
80115	33491	69	Забайкальский край, Читинский район, Чита, Малая, 2	f	large
80129	33505	83	Забайкальский край, Читинский район, Чита, Магистральная, 15а	f	large
80122	33498	76	Забайкальский край, Читинский район, Чита, Магистральная, 11	f	large
80082	33453	29	Забайкальский край, Читинский район, Чита, Ленинградская, 67	f	large
80108	33481	58	Забайкальский край, Читинский район, Чита, Лазо, 81	f	large
80116	33492	70	Забайкальский край, Читинский район, Чита, Краснознаменная, 48	f	large
80136	33512	90	Забайкальский край, Читинский район, Чита, Космонавтов, 10, Черновский административный район,	f	large
109599	33526	104	Забайкальский край, Читинский район, Чита, Ключевая, 18-А	f	medium
80121	33497	75	Забайкальский край, Читинский район, Чита, Карла Маркса, 1	f	large
80095	33468	45	Забайкальский край, Читинский район, Чита, Каларская, 30	f	large
80094	33468	44	Забайкальский край, Читинский район, Чита, Каларская, 30	f	large
80084	33455	31	Забайкальский край, Читинский район, Чита, Кайдаловская, 10а	f	large
80062	33434	9	Забайкальский край, Читинский район, Чита, Июньская, 2	f	large
80061	33434	8	Забайкальский край, Читинский район, Чита, Июньская, 2	f	large
109604	33538	116	Забайкальский край, Читинский район, Чита, Зыкова, 1-А	f	medium
80119	33495	73	Забайкальский край, Читинский район, Чита, Донская, 11	f	large
109600	33530	108	Забайкальский край, Читинский район, Чита, Гайдара, 4	f	medium
80152	33529	107	Забайкальский край, Читинский район, Чита, Гайдара, 3А	f	large
80141	33517	95	Забайкальский край, Читинский район, Чита, Весенняя, 16-А	f	large
80137	33513	91	Забайкальский край, Читинский район, Чита, Весенняя, 13	f	large
80124	33500	78	Забайкальский край, Читинский район, Чита, Ватутина, 18	f	large
80074	33437	21	Забайкальский край, Читинский район, Чита, Богомягкова, 23а	f	large
80065	33437	12	Забайкальский край, Читинский район, Чита, Богомягкова, 23а	f	large
80114	33489	67	Забайкальский край, Читинский район, Чита, Баргузинская, 49, Ингодинский административный район	f	large
80070	33442	17	Забайкальский край, Читинский район, Чита, Балябина, 44	f	large
109595	33485	63	Забайкальский край, Читинский район, Чита, Балейская, 2	f	medium
80098	33471	48	Забайкальский край, Читинский район, Чита, Бабушкина, 2б	f	large
80076	33447	23	Забайкальский край, Читинский район, Чита, Бабушкина, 66, Центральный административный район	f	large
18019	15604	449	Алтайский край, Рубцовск, Сельмашская, 38А	f	large
109594	33464	40	Забайкальский край, Читинский район, Чита, Анохина, 56	f	small
109593	33463	39	Забайкальский край, Читинский район, Чита, Анохина, 71, Центральный административный район	f	small
80073	33445	20	Забайкальский край, Читинский район, Чита, Анохина, 110	f	large
80105	33478	55	Забайкальский край, Читинский район, Чита, Амурская, 15	f	large
80146	33522	100	Забайкальский край, Читинский район, Чита, Автозаводская, 3-А	f	large
80086	33457	33	Забайкальский край, Читинский район, Чита, 9 Января, 64	f	large
80143	33519	97	Забайкальский край, Читинский район, Чита, 6 микрорайон, 5	f	large
80131	33507	85	Забайкальский край, Читинский район, Чита, 5 микрорайон, 4	f	large
80130	33506	84	Забайкальский край, Читинский район, Чита, 5 микрорайон, 3	f	large
80154	33533	111	Забайкальский край, Читинский район, Чита, 40 лет октября, 17	f	large
80153	33531	109	Забайкальский край, Читинский район, Чита, 40 лет октября, 6	f	large
80067	33439	14	Забайкальский край, Читинский район, Чита, Богомягкова, 121	f	large
109794	33768	354	Забайкальский край, Читинский район, село Черново, Центральная, ФАП	t	small
109775	33743	330	Забайкальский край, Читинский район, село Угдан, Центральная, 25	f	medium
109778	33747	334	Забайкальский край, Читинский район, село Тасей, Центральная, 12	t	small
109799	33774	360	Забайкальский край, Читинский район, село Танха, Центральная, 41	f	small
109805	33788	374	Забайкальский край, Читинский район, село Сыпчегур, Комсомольская, контора лесничества	t	small
109783	33753	340	Забайкальский край, Читинский район, село Сохондо, Центральная, 78а	t	medium
80346	34279	865	Забайкальский край, Читинский район, село Смоленка, Садовая , 2а	t	large
80199	33744	331	Забайкальский край, Читинский район, село Смоленка, Садовая, 2а	f	large
109795	33769	355	Забайкальский край, Читинский район, село Сивяково, Советская, 34	t	medium
109779	33748	335	Россия, Забайкальский край, Читинский район, село Преображенка	t	small
109773	33738	326	Забайкальский край, Читинский район, село Подволок, Центральная, 18	t	small
80093	33467	43	Забайкальский край, Читинский район, Песчанка, 765, ДОС	f	large
109806	33789	375	Забайкальский край, Читинский район, село Оленгуй, Центральная, 47	t	small
109798	33773	359	Забайкальский край, Читинский район, село Новотроицк, Шоссейная, 10	f	medium
80211	33781	368	Забайкальский край, Читинский район, поселок Новокручининский, Рабочая, 34	f	large
80212	33783	370	Забайкальский край, Читинский район, поселок городского типа Новокручининский, Фабричная, 1а	f	large
109801	33782	369	Забайкальский край, Читинский район, поселок городского типа Новокручининский, Ленинградская, 36	f	medium
80209	33779	366	Забайкальский край, Читинский район, поселок городского типа Новокручининский, Заводская, 10	f	large
80210	33780	367	Забайкальский край, Читинский район, Новокручининский, Дорожная, 29	f	large
80201	33760	347	Забайкальский край, Читинский район, село Новая Кука, микрорайон Забайкальская птицефабрика, 66	f	large
80213	33791	377	Забайкальский край, Читинский район, село Маккавеево, Советская, 47	f	large
80214	33792	378	Забайкальский край, Читинский район, село Маккавеево, Бутина, 35	f	large
109788	33758	345	Забайкальский край, Читинский район, село Лесной Городок, Трактовая, 8	t	medium
109789	33759	346	Забайкальский край, Читинский район, село Лесная, Таежная, 25	t	medium
109807	33790	376	Забайкальский край, Читинский район, село Ленинский, Первомайская, 7	t	small
109793	33767	353	Забайкальский край, Читинский район, село Колочное 1-е	f	medium
109776	33745	332	Забайкальский край, Читинский район, село Карповка, мкр.ДФТБ	t	medium
109781	33751	338	Забайкальский край, Читинский район, село Иргень, Центральная, Дом культуры	t	small
109791	33762	349	Забайкальский край, Читинский район, село Ингода, Центральная, 17	f	medium
109797	33772	358	Забайкальский край, Читинский район, село Ильинка, Набережная, 20	f	small
109777	33746	333	Забайкальский край, Читинский район, село Иван-Озеро, Центральная, 15	t	small
80204	33771	357	Забайкальский край, Читинский район, село Засопка, Школьная, 25	f	large
109790	33761	348	Забайкальский край, Читинский район, село Жипковщина, Школьная, 20а	f	small
109796	33770	356	Забайкальский край, Читинский район, село Ерёмино, Центральная, 16	f	small
109803	33785	372	Забайкальский край, Читинский район, село Елизаветино, Пионерская, 6	t	medium
109792	33763	350	Забайкальский край, Читинский район, село Домно-Ключи, Партизанская, 72а	t	small
80203	33766	352	Забайкальский край, Читинский район, село Домна, Центральная, 10	f	large
80202	33765	351	Забайкальский край, Читинский район, село Домна, Геологическая, 1а	f	large
109804	33787	373	Забайкальский край, Читинский район, село Верхний-Нарым, Зеленая, 3а	t	small
80198	33741	329	Забайкальский край, Читинский район, село Верх-Чита, Центральная, 6	f	large
109772	33737	325	Забайкальский край, Читинский район, село Бургень, Школьная, 17	t	small
80200	33750	337	Забайкальский край, Читинский район, село Беклемишево, Бурлова, 12	f	large
80208	33776	364	Забайкальский край, Читинский район, поселок Атамановка, Матюгина, 156	f	large
80206	33776	362	Забайкальский край, Читинский район, поселок Атамановка, Матюгина, 156	f	large
80205	33775	361	Забайкальский край, Читинский район, поселок городского типа Атамановка, Рабочая, 3	f	large
80207	33777	363	Забайкальский край, Читинский район, поселок городского типа Атамановка, Заводская, 1	f	large
109780	33749	336	Забайкальский край, Читинский район, село Арахлей, Центральная, 15	t	small
109774	33739	327	Забайкальский край, Читинский район, село Авдей, Весенняя, 4а	t	small
80310	34221	805	Забайкальский край, Чернышевский район, Чернышевск, Молодежная, 12	f	large
80309	34220	804	Забайкальский край, Чернышевский район, поселок Чернышевск, Центральная, 8	f	large
110132	34218	803	Забайкальский край, Чернышевский район, поселок Чернышевск, Лазо, 23	t	medium
110133	34224	808	Забайкальский край, Чернышевский район, поселок Чернышевск, Железнодорожная, 59	f	small
80312	34223	807	Забайкальский край, Чернышевский район, поселок городского типа Чернышевск, Первомайская, 70	f	large
80308	34217	802	Забайкальский край, Чернышевский район, поселок городского типа Чернышевск, Партизанская, 26	f	large
80307	34217	801	Забайкальский край, Чернышевский район, поселок городского типа Чернышевск, Партизанская, 26	f	large
80311	34222	806	Забайкальский край, Чернышевский район, Чернышевск, Журавлева, 61а	f	large
80316	34249	834	Забайкальский край, Чернышевский район, село Утан, Погодаева, 45б	t	large
110159	34253	839	Забайкальский край, Чернышевский район, село Урюм, здание администрации	t	small
110158	34252	838	Забайкальский край, Чернышевский район, село Урюм, Папанина, 39	t	small
110151	34244	828	Забайкальский край, Чернышевский район, село Укурей, Транспортная, 1	t	medium
110145	34237	822	Забайкальский край, Чернышевский район, Старый Олов, Ленина, 49а	t	medium
110143	34235	820	Забайкальский край, Чернышевский район, село Новый Олов, Партизанская, 9	t	small
110144	34236	821	Забайкальский край, Чернышевский район, село Новый Олов, Журавлёво, 17А	t	small
110146	34238	823	Забайкальский край, Чернышевский район, село Новоильинск, Ленина, 49А	t	small
110156	34250	835	Забайкальский край, Чернышевский район, село Мильгидун, Молодежная, 21	t	medium
110152	34245	829	Забайкальский край, Чернышевский район, село Курлыч, Школьная, 1	t	small
110147	34239	824	Забайкальский край, Чернышевский район, село Комсомольское, Набережная , 6	f	medium
110149	34241	826	Забайкальский край, Чернышевский район, село Комсомольское, Базарная, 127	t	small
110154	34247	832	Забайкальский край, Чернышевский район, село Икшица, здание средней школы	t	small
80313	34229	813	Забайкальский край, Чернышевский район, Жирекен, здание МОУ СОШ	f	large
110138	34229	815	Забайкальский край, Чернышевский район, Жирекен, здание МОУ СОШ	t	small
80314	34230	814	Забайкальский край, Чернышевский район, поселок Жирекен, здание Центра досуга	f	large
110153	34246	831	Забайкальский край, Чернышевский район, село Гаур, Центральная, 2	f	small
110157	34251	837	Забайкальский край, Чернышевский район, село Бушулей, Железнодорожная, 7-10	t	small
110134	34225	809	Забайкальский край, Чернышевский район, поселок Букачача, Вокзальная, 1	t	small
110137	34228	812	Забайкальский край, Чернышевский район, поселок городского типа Букачача, Центральная, 16	t	medium
110136	34227	811	Забайкальский край, Чернышевский район, поселок городского типа Букачача, Фабричный переулок, 2	t	small
110135	34226	810	Забайкальский край, Чернышевский район, поселок городского типа Букачача, Клубный проспект, 1	t	medium
110150	34243	827	Забайкальский край, Чернышевский район, село Байгул, Советская, 5	f	medium
110148	94933	825	Забайкальский край, Чернышевский район, село Багульный, Набережная, 10	f	small
110155	34248	833	Забайкальский край, Чернышевский район, село Алеур, Кирова, 45а	f	medium
110139	34231	816	Забайкальский край, Чернышевский район, поселок городского типа Аксеново-Зиловское, здание клуба железнодорожников	t	medium
110142	34234	819	Забайкальский край, Чернышевский район, поселок Аксеново-Зиловское, микрорайон Берёзка, здание ТСЖ	t	small
110141	34233	818	Забайкальский край, Чернышевский район, поселок Аксеново-Зиловское, Октябрьская, 9	t	medium
110140	34232	817	Забайкальский край, Чернышевский район, поселок Аксеново-Зиловское, Западная, 1	t	medium
80194	33728	317	Забайкальский край, Хилокский район, село Хушенга, Центральная, 24	f	large
80190	33714	303	Забайкальский край, Хилокский район, Хилок, Новая, 22 	f	large
80188	33712	301	Забайкальский край, Хилокский район, Хилок, Кирова, 37 А	f	large
80186	33710	299	Забайкальский край, Хилокский район, Хилок, Калинина, 16	f	large
80187	33711	300	Забайкальский край, Хилокский район, Хилок, Ленина, 20	f	large
80189	33713	302	Забайкальский край, Хилокский район, Хилок, Карла Маркса, 78	f	large
109765	33726	315	Забайкальский край, Хилокский район, село Хилогосон, СДК	f	small
80195	33732	320	Забайкальский край, Хилокский район, село Харагун, Шоссеная, 43	t	large
109768	33731	319	Забайкальский край, Хилокский район, село Харагун, Вокзальная, 20	t	medium
109757	33715	304	Россия, Забайкальский край, Хилокский район, село Ушоты	t	small
109761	33721	310	Забайкальский край, Хилокский район, село Тэрэпхэн, СДК	t	small
80196	33735	323	Забайкальский край, Хилокский район, поселок городского типа Могзон, Советская, 47	t	large
109770	33734	322	Забайкальский край, Хилокский район, поселок городского типа Могзон, Комсомольская, 20	t	medium
109769	33733	321	Забайкальский край, Хилокский район, поселок городского типа Могзон, Деповская, 1	f	medium
80193	33724	313	Забайкальский край, Хилокский район, село Линево Озеро, Хлуднева, 7	f	large
109760	33720	309	Забайкальский край, Хилокский район, село Зурун, СДК	t	small
109758	33716	305	Забайкальский край, Хилокский район, село Закульта, Школьная, 11	t	small
109763	33723	312	Забайкальский край, Хилокский район, село Жипхеген, Таёжная, 25	f	medium
109767	33729	318	Забайкальский край, Хилокский район, село Дайгур, медпункт	t	small
109764	33725	314	Забайкальский край, Хилокский район, село Гыршелун, Первомайская, 4	f	medium
109762	33722	311	Забайкальский край, Хилокский район, село Глинка, Администрация	t	small
80192	33718	307	Забайкальский край, Хилокский район, село Бада, Пионерская, 43	t	large
80191	33717	306	Забайкальский край, Хилокский район, село Бада, Лесная, 44	t	large
109743	33703	279	Забайкальский край, Улетовский район, село Шехолан, Школьная, 1	t	small
109739	33698	274	Россия, Забайкальский край, Улетовский район, село Шебартуй 2-й	t	small
109752	32126	291	Забайкальский край, Улетовский район, село Черемхово, Чехова, 24	f	small
109751	32055	290	Забайкальский край, Улетовский район, село Хадакта, Большая, 16	f	medium
80180	30198	287	Забайкальский край, Улетовский район, Улеты, Лазо, 124	f	large
80181	31686	288	Забайкальский край, Улетовский район, село Улеты, Кооперативная, 16	f	large
80182	31782	289	Забайкальский край, Улетовский район, село Улеты, Дорожная, 14	f	large
109753	33354	292	Забайкальский край, Улетовский район, село Татаурово, Кирова, 108	f	medium
109741	33700	276	Забайкальский край, Улетовский район, село Танга, Партизанская, 1а	f	medium
109740	33699	275	Забайкальский край, Улетовский район, село Новосалия, Центральная, 40	t	small
80179	33702	278	Забайкальский край, Улетовский район, село Николаевское, Октябрьская, 68	f	large
109738	33697	273	Забайкальский край, Улетовский район, село Ленинский, Ленина, 6	t	medium
109755	33706	295	Забайкальский край, Улетовский район, село Красная Речка, Совхозная, 6	t	small
80183	33414	293	Забайкальский край, Улетовский район, Дровяная, Кирова, 39	f	large
109746	31643	282	Забайкальский край, Улетовский район, село Доронинское, Пионерская, 22	t	medium
109742	33701	277	Забайкальский край, Улетовский район, село Дешулан, Октябрьская, 16	t	small
80184	33707	296	Забайкальский край, Улетовский район, Горный, Площадь Тюрина, 1	f	large
109756	33709	298	Забайкальский край, Улетовский район, поселок городского типа Горный, Таёжная, МОУ СОШ №2	f	medium
80185	33708	297	Забайкальский край, Улетовский район, поселок городского типа Горный, Молодежная, 33	f	large
109745	33688	281	Забайкальский край, Улетовский район, село Горекацан, Шоссейная, 6	f	small
109744	33704	280	Забайкальский край, Улетовский район, село Горека, Школьная, бн	t	small
109754	33705	294	Забайкальский край, Улетовский район, село Голубичная, Набережная, 6	t	small
109750	33654	286	Забайкальский край, Улетовский район, село Бальзой	t	small
109749	33631	285	Забайкальский край, Улетовский район, село Арта, Советская, 25	t	medium
109737	33696	272	Забайкальский край, Улетовский район, село Арей, Школьная, 2	f	small
109748	33577	284	Забайкальский край, Улетовский район, село Аблатукан, Трудовая, 26	t	small
109747	33551	283	Забайкальский край, Улетовский район, село Аблатуйский Бор, Центральная, 62	f	small
109735	33694	270	Забайкальский край, Тунгокоченский район, село Усугли, Советская, 1	t	small
109732	33691	267	Забайкальский край, Тунгокоченский район, село Тунгокочен, Центральная, 7	t	medium
109728	33687	263	Забайкальский край, Тунгокоченский район, село Нижний Стан, ФАП	t	small
109729	33676	264	Забайкальский край, Тунгокоченский район, село Нижний Стан, СДК	t	small
109727	33686	262	Забайкальский край, Тунгокоченский район, Нижнестанское, Клубная, 1	t	medium
109722	33679	255	Забайкальский край, Тунгокоченский район, поселок Вершино-Дарасунский, Центральная, 31	f	medium
109723	33682	258	Забайкальский край, Тунгокоченский район, поселок Вершино-Дарасунский, Рабочая, 1	f	medium
109720	33677	253	Забайкальский край, Тунгокоченский район, поселок Вершино-Дарасунский, Подгорная, 1	f	medium
80177	33680	256	Забайкальский край, Тунгокоченский район, поселок Вершино-Дарасунский, Лесная, 13	f	large
109724	33683	259	Забайкальский край, Тунгокоченский район, поселок городского типа Вершино-Дарасунский, Центральная, 1	f	small
109721	33678	254	Забайкальский край, Тунгокоченский район, поселок городского типа Вершино-Дарасунский, Дарасунская, 78	f	medium
80178	33681	257	Забайкальский край, Тунгокоченский район, поселок Вершино-Дарасунский, Цыборо, 1	f	large
109734	33693	269	Забайкальский край, Тунгокоченский район, село Верхние Усугли, Кооперативная, 2а	t	medium
80176	33675	252	Забайкальский край, Тунгокоченский район, село Верхние Усугли, Клубная, 1	f	large
109715	33670	247	Забайкальский край, Тунгиро-Олекминский район, село Тупик, Нагорная, 20	t	medium
109716	33671	248	Забайкальский край, Тунгиро-Олекминский район, село Заречное, Центральная, 3	t	small
110125	34210	794	Забайкальский край, Сретенский район, село Шилкинский Завод, Центральная, 1	t	small
110113	34198	782	Забайкальский край, Сретенский район, село Чикичей, Титкова, 29	t	small
110124	34209	793	Забайкальский край, Сретенский район, село Чалбучи, Луговая, 2	t	small
110119	34204	788	Забайкальский край, Сретенский район, село Фирсово, Набережная, 36	f	small
110111	34195	780	Забайкальский край, Сретенский район, село Усть-Наринзор, Центральная, 4	f	small
110105	34189	774	Забайкальский край, Сретенский район, село Усть-Курлыч, Школьная, Школа	t	small
110129	34214	798	Забайкальский край, Сретенский район, поселок городского типа Усть-Карск, Киргизова, 20	t	medium
110128	34213	797	Забайкальский край, Сретенский район, поселок Усть-Карск, Советская, 18	t	medium
110120	34205	789	Забайкальский край, Сретенский район, село Уктыча, Набережная, 13	t	small
110099	34179	764	Забайкальский край, Сретенский район, Сретенск, Энергетиков, 6	f	small
110096	34176	761	Забайкальский край, Сретенский район, Сретенск, Фабричная, 6	f	small
110103	34184	769	Забайкальский край, Сретенский район, Сретенск, Сельская, 51	f	small
110098	34178	763	Забайкальский край, Сретенский район, Сретенск, Партизанская, 37	f	medium
110101	34181	766	Забайкальский край, Сретенский район, Сретенск, Набережная, 69	f	small
110097	34177	762	Забайкальский край, Сретенский район, Сретенск, Молодежная, 2	f	small
110100	34180	765	Забайкальский край, Сретенский район, Сретенск, Луначарского, 226	f	medium
80303	34182	767	Забайкальский край, Сретенский район, Сретенск, Клубная, 3	f	large
110102	34183	768	Забайкальский край, Сретенский район, Сретенск, Вокзальная, 1	f	small
110108	34192	777	Забайкальский край, Сретенский район, село Нижняя Куэнга, Нагорная, 11	t	small
110117	34202	786	Забайкальский край, Сретенский район, село Молодовск, Набережная, 50а	t	small
110118	34203	787	Забайкальский край, Сретенский район, село Ломы, Молодежная, 28	f	small
110115	34200	784	Забайкальский край, Сретенский район, село Кулан, Новая, 14	t	small
110121	34206	790	Забайкальский край, Сретенский район, село Кудея, Нижняя, 9, кв.2	t	small
80306	34187	772	Забайкальский край, Сретенский район, поселок Кокуй, ПУ-30	f	large
109870	33896	484	Забайкальский край, Сретенский район, поселок Кокуй, Новая, 14	t	small
80304	34185	770	Забайкальский край, Сретенский район, поселок Кокуй, Заводская, 22	f	large
80305	34186	771	Забайкальский край, Сретенский район, поселок городского типа Кокуй, 2-Набережная, 10	f	large
110104	34188	773	Забайкальский край, Сретенский район, поселок городского типа Кокуй, 1-Луговая, 6	f	medium
110106	34190	775	Забайкальский край, Сретенский район, село Дунаево, Школьная, 9	t	small
110107	34191	776	Забайкальский край, Сретенский район, село Дунаево, Нагорная, 2	t	small
110112	34197	781	Забайкальский край, Сретенский район, село Делюн, Центральная, 21	t	small
110131	34216	800	Забайкальский край, Сретенский район, село Горбица, Набережная, 4а	t	small
110109	34193	778	Забайкальский край, Сретенский район, село Верхняя Кузнга, Центральная, 17	t	small
110130	34215	799	Забайкальский край, Сретенский район, село Верхние Куларки, Молодежная, 1	t	small
110123	34208	792	Забайкальский край, Сретенский район, Ботовское, Шилкинская, 26	t	small
110122	34207	791	Забайкальский край, Сретенский район, село Бори, Центральная, 1	t	small
110110	34194	779	Забайкальский край, Сретенский район, село Болотово, Центральная, 32	t	small
110116	34201	785	Забайкальский край, Сретенский район, село Алия, Красноармейская, 46	t	small
110114	34199	783	Забайкальский край, Сретенский район, село Адом, Зеленая, 16	t	small
110093	34173	758	Забайкальский край, Приаргунский район , Приаргунск, Магистральная, здание Приаргунского ДЭУ	f	medium
110077	34150	737	Забайкальский край, Приаргунский район, село Усть-Тасуркай, Советская, Здание Администрации	t	small
110075	34148	735	Забайкальский край, Приаргунский район, село Урулюнгуй, Аксенова, 30	t	medium
110089	34165	751	Забайкальский край, Приаргунский район, село Улан, Юбилейная, здание школы	t	small
110090	34166	752	Забайкальский край, Приаргунский район, село Талман-Борзя, Юбилейная, 12	t	small
110080	34154	740	Забайкальский край, Приаргунский район, село Староцурухайтуй, Колхозная, 70а	t	medium
110076	34149	736	Забайкальский край, Приаргунский район, село Селинда, Нагорная, 9А	t	small
80301	34170	756	Забайкальский край, Приаргунский район, поселок Приаргунск, Ленина, Центр Досуга	f	large
80302	34171	757	Забайкальский край, Приаргунский район, поселок городского типа Приаргунск, Строительная, здание ПУ-31	f	large
80300	34169	755	Забайкальский край, Приаргунский район, поселок городского типа Приаргунск, Декабристов, здание ДЮСШ	f	large
110085	34159	745	Забайкальский край, Приаргунский район, Пограничный поселок, Школьная, 10	t	small
110083	34157	743	Забайкальский край, Приаргунский район, село Погадаево, Советская, 16	f	small
110087	34161	747	Забайкальский край, Приаргунский район, село Норинск, помещение Администрации	t	small
110079	34153	739	Забайкальский край, Приаргунский район, село Новоцурухайтуй, Федорова, 70а	f	medium
110092	34168	754	Забайкальский край, Приаргунский район, село Новоцурухайтуй, Лазо, Агроремтех	f	small
110091	34167	753	Забайкальский край, Приаргунский район, село Новоивановка, Советская, 13	t	small
80298	34162	748	Забайкальский край, Приаргунский район, село Молодёжный, Молодежная, 25	f	large
110088	34163	749	Забайкальский край, Приаргунский район, село Кути, Молодежная, 4	t	small
110095	34175	760	Забайкальский край, Приаргунский район, Кличка, Социалистическая, 4	t	medium
110094	34174	759	Забайкальский край, Приаргунский район, поселок городского типа Кличка, Ленина, 18	t	medium
110082	34156	742	Забайкальский край, Приаргунский район, село Зоргол, Пешкова, 16	t	medium
110081	34155	741	Забайкальский край, Приаргунский район, село Дурой, Баженова, 34а	t	medium
80299	34164	750	Забайкальский край, Приаргунский район, село Досатуй, Юбилейная, 4	f	large
110084	34158	744	Забайкальский край, Приаргунский район, село Горда, Школьная, 8	t	small
110078	34152	738	Забайкальский край, Приаргунский район, село Верхний Тасуркай, Ленина, Дом Культуры	t	small
110086	34160	746	Забайкальский край, Приаргунский район, село Верея, Новая, помещение ФАП	t	small
110074	34147	734	Забайкальский край, Приаргунский район, село Бырка, Новая, 12	t	medium
110073	34146	733	Забайкальский край, Приаргунский район, село Бырка, Кооперативная, 19	t	small
80175	33669	246	Забайкальский край, Петровск-Забайкальский район, село Хохотуй, Кооперативная, 31А	f	large
109708	33658	235	Забайкальский край, Петровск-Забайкальский район, село Харауз, Нагорная, 43	t	medium
109702	33651	229	Забайкальский край, Петровск-Забайкальский район, село Усть-Обор, Клубная, 11	f	medium
109714	33668	245	Забайкальский край, Петровск-Забайкальский район, село Толбага, Почтовая, 20-А	t	small
109711	33663	240	Забайкальский край, Петровск-Забайкальский район, поселок Тарбагатай, Кооперативная, 57	f	medium
109712	33664	241	Забайкальский край, Петровск-Забайкальский район, поселок городского типа Тарбагатай, Заводская, 18	f	medium
109699	33646	224	Забайкальский край, Петровск-Забайкальский район, село Пески, Вакарина, 43	f	small
109705	33655	232	Забайкальский край, Петровск-Забайкальский район, село Орсук, Трактовая, 20	t	small
109703	33652	230	Забайкальский край, Петровск-Забайкальский район, село Обор, Центральная, 60	f	small
80174	33666	243	Забайкальский край, Петровск-Забайкальский район, поселок Новопавловка, Советская, 2	f	large
80173	33665	242	Забайкальский край, Петровск-Забайкальский район, поселок Новопавловка, Заводская, 10	f	large
109700	33647	225	Забайкальский край, Петровск-Забайкальский район, село Новая Зардама, Центральная, 17	t	small
80169	33649	227	Забайкальский край, Петровск-Забайкальский район, село Малета, Пионерская, 16	f	large
80170	33650	228	Забайкальский край, Петровск-Забайкальский район, село Малета, Комсомольская, 47	f	large
109707	33657	234	Забайкальский край, Петровск-Забайкальский район, село Лесоучасток Катангар, Нагаева, 17	t	small
109709	33661	238	Забайкальский край, Петровск-Забайкальский район, село Кули, Шахтовая, 7	t	small
109706	33656	233	Забайкальский край, Петровск-Забайкальский район, село Катангар, Центральная, 35	t	small
109704	33653	231	Забайкальский край, Петровск-Забайкальский район, село Катаево, Центральная, 46	f	medium
109713	33667	244	Забайкальский край, Петровск-Забайкальский район, село Зугмара, Колхозная,, 20	t	small
109710	33662	239	Забайкальский край, Петровск-Забайкальский район, село Баляга-Катангар, Улан-Туя, 13	t	small
80172	33660	237	Забайкальский край, Петровск-Забайкальский район, поселок городского типа Баляга, Шоссейная, 25-А	f	large
80171	33659	236	Забайкальский край, Петровск-Забайкальский район, поселок городского типа Баляга, Клубная, 18	f	large
110072	34145	732	Забайкальский край, Ононский район, село Чиндант 1-й, Солнечная, 30	t	small
110070	34143	730	Забайкальский край, Ононский район, село Чиндант 1-й, Нагорная, 13	t	small
110071	34144	731	Забайкальский край, Ононский район, село Чиндант 1-й, Васильева, 30	t	small
110068	34141	728	Забайкальский край, Ононский район, село Холуй-База, Молодежная, 6	t	small
110069	34142	729	Забайкальский край, Ононский район, село Холуй-База, Кушурская, 2	t	small
110060	34133	720	Забайкальский край, Ононский район, село Тут-Халтуй, Школьная, 38	t	small
110061	34134	721	Забайкальский край, Ононский район, село Тут-Халтуй, Ленина, 13	t	small
110059	34132	719	Забайкальский край, Ононский район, село Новый Дурулгуй, Центральная, 18	t	small
110058	34131	718	Забайкальский край, Ононский район, село Новый Дурулгуй, Ветрова, 18	f	medium
110066	34139	726	Забайкальский край, Ононский район, село Новая Заря, Центральная, 22	t	medium
80297	34125	712	Забайкальский край, Ононский район, село Нижний Цасучей, Комсомольская, 42	f	large
110067	34140	727	Забайкальский край, Ононский район, село Кулусутай, Казачий переулок, 10	f	medium
110065	34138	725	Забайкальский край, Ононский район, село Красная Ималка, Молодежная, 5	t	small
110064	34137	724	Забайкальский край, Ононский район, Ималкинское, Ленина, 45	t	small
110053	34126	713	Забайкальский край, Ононский район, село Верхний Цасучей, Григорьева, 16	f	medium
110063	34136	723	Забайкальский край, Ононский район, село Буйлэсан, Центральная, 2	t	small
110062	34135	722	Забайкальский край, Ононский район, село Буйлэсан, Центральная, 32	t	small
110055	34128	715	Забайкальский край, Ононский район, село Большевик, Школьная, 1	f	small
110056	34129	716	Забайкальский край, Ононский район, село Большевик, Центральная, 15	t	small
110057	34130	717	Забайкальский край, Ононский район, село Большевик, Ленина, 22	t	small
110054	34127	714	Забайкальский край, Ононский район, село Большевик, Ленина, 57	f	small
80294	34117	705	Забайкальский край, Оловяннинский район, Ясногорск, КСЦ	f	large
80293	34117	704	Забайкальский край, Оловяннинский район, Ясногорск, КСЦ	f	large
80292	34117	703	Забайкальский край, Оловяннинский район, Ясногорск, КСЦ	f	large
80291	34116	702	Забайкальский край, Оловяннинский район, село Ясная, школа № 2	f	large
80290	34116	701	Забайкальский край, Оловяннинский район, село Ясная, школа № 2	f	large
110029	34093	677	Забайкальский край, Оловяннинский район, село Хара-Бырка, школа	f	small
110044	34111	695	Забайкальский край, Оловяннинский район, село Хада-Булак, школа	t	medium
110048	34115	700	Забайкальский край, Оловяннинский район, село Уртуйский, администрация	t	small
110035	34099	684	Забайкальский край, Оловяннинский район, село Улятуй, школа	t	medium
110043	34110	694	Забайкальский край, Оловяннинский район, село Улан-Цацык, школа	t	small
110040	34105	690	Забайкальский край, Оловяннинский район, село Турга, школа	t	small
110026	34089	673	Россия, Забайкальский край, Оловяннинский район, село Тополевка	t	small
80287	34090	674	Забайкальский край, Оловяннинский район, село Степь, школа	f	large
110038	34102	687	Забайкальский край, Оловяннинский район, село Победа, фельдшерско-акушерский пункт	t	small
110027	34091	675	Забайкальский край, Оловяннинский район, село Ононск, школа	f	small
80296	34124	711	Забайкальский край, Оловяннинский район, Оловянная, здание редакции газеты Ленинский путь	f	large
110052	34123	710	Забайкальский край, Оловяннинский район, поселок городского типа Оловянная, административное здание учреждения ЯГ-14/7	t	small
110051	34122	709	Забайкальский край, Оловяннинский район, Оловянная, здание МУП Коммунальное хозяйство	f	medium
110050	34121	708	Забайкальский край, Оловяннинский район, поселок городского типа Оловянная, школа № 1	f	medium
80295	34120	707	Забайкальский край, Оловяннинский район, поселок Оловянная, школа № 235	f	large
110049	34119	706	Забайкальский край, Оловяннинский район, поселок Оловянная, районный Дом культуры	f	medium
110046	34113	698	Забайкальский край, Оловяннинский район, село Мирная, школа	f	medium
110028	34092	676	Забайкальский край, Оловяннинский район, село Кулинда, школа	t	small
110036	34100	685	Забайкальский край, Оловяннинский район, село Комкай, библиотека	t	small
110032	34096	680	Забайкальский край, Оловяннинский район, село Караксар, сельское поселение Единенское	t	small
80288	34104	689	Забайкальский край, Оловяннинский район, Калангуй, школа	f	large
80289	34106	691	Забайкальский край, Оловяннинский район, поселок городского типа Золотореченск, школа	f	large
110033	34097	681	Забайкальский край, Оловяннинский район, село Заря, сельский клуб	t	small
110031	34095	679	Забайкальский край, Оловяннинский район, село Единение, школа	t	small
110039	34103	688	Забайкальский край, Оловяннинский район, село Долгокыча, школа	f	medium
110030	34094	678	Забайкальский край, Оловяннинский район, село Верхний Шаранай, школа	t	small
110047	34114	699	Забайкальский край, Оловяннинский район, село Бырка, школа	t	small
110037	34101	686	Забайкальский край, Оловяннинский район, село Бурулятуй, здание школы	t	small
110042	34109	693	Забайкальский край, Оловяннинский район, село Булум, школа	t	small
110045	34112	696	Забайкальский край, Оловяннинский район, село Безречная, школа	t	medium
110034	34098	682	Забайкальский край, Оловяннинский район, село Аренда, школа	t	small
110041	34108	692	Забайкальский край, Оловяннинский район, село Антия, школа	t	small
110009	34070	654	Забайкальский край, Нерчинско-Заводский район, сельское поселение Булдуруйское, Балябина, 3	t	small
110024	34087	671	Забайкальский край, Нерчинско-Заводский район, село Широкая, Садовая, 8	t	small
110022	34085	669	Забайкальский край, Нерчинско-Заводский район, село Чашино-Ильдикан, Мира, 15	t	small
110021	34083	668	Забайкальский край, Нерчинско-Заводский район, село Уровские Ключи, Новая, 8	t	small
110019	34081	665	Забайкальский край, Нерчинско-Заводский район, село Олочи, Набережная, 18	t	small
18048	15631	478	Алтайский край, Рубцовск, Светлова, 90	f	large
80286	34080	664	Забайкальский край, Нерчинско-Заводский район, село Нерчинский Завод, Булгаковой, 2	f	large
110018	34079	663	Забайкальский край, Нерчинско-Заводский район, село Михайловка, Перфильева, 16	t	medium
109989	34046	632	Забайкальский край, Нерчинско-Заводский район, село Михайловка, Молодежная, 3, Библиотека	t	small
110017	34078	662	Забайкальский край, Нерчинско-Заводский район, село Ишага, Центральная, здание сельского Дома культуры	t	small
110016	34077	661	Забайкальский край, Нерчинско-Заводский район, село Ивановка, Молодежная, 20	t	small
110010	34071	655	Забайкальский край, Нерчинско-Заводский район, село Ивановка, Конторская, 4 к 2	t	small
110014	34075	659	Забайкальский край, Нерчинско-Заводский район, село Горный Зерентуй, Пушкина, 10	t	medium
110013	34074	658	Забайкальский край, Нерчинско-Заводский район, село Горбуновка, Центральная, 21	t	small
110012	34073	657	Забайкальский край, Нерчинско-Заводский район, село Георгиевка, Клубная, 18	t	small
110008	34069	653	Забайкальский край, Нерчинско-Заводский район, село Булдуруй-1, Солнечная, 63а	t	small
110023	34086	670	Забайкальский край, Нерчинско-Заводский район, село Булдуруй-1, Верхняя, 64	t	small
110015	34076	660	Забайкальский край, Нерчинско-Заводский район, село Большой Зерентуй, Центральная, 9	t	small
110007	34068	652	Забайкальский край, Нерчинско-Заводский район, село Большой Зерентуй, Советский переулок, 7	t	medium
110020	34082	667	Забайкальский край, Нерчинско-Заводский район, село Аргунск, Сурина, 5	t	small
110006	34067	651	Забайкальский край, Нерчинско-Заводский район, село Аргунск, Советская, 5	t	small
110011	34072	656	Забайкальский край, Нерчинско-Заводский район, село Аргунск, Дорожная, 10	t	small
110005	34066	650	Забайкальский край, Нерчинский район, городское поселение Нерчинское, Тетерина-Петрова, 3, СОШ № 1	f	medium
109991	34048	634	Забайкальский край, Нерчинский район, село Шивки, Верхняя, Сельский клуб	f	small
109993	34051	636	Забайкальский край, Нерчинский район, село Савватеево, Центральная,, 30	t	small
80283	34045	631	Забайкальский край, Нерчинский район, поселок городского типа Приисковый, Центральная, 2, Дом культуры	f	large
109981	34037	623	Забайкальский край, Нерчинский район, село Правые Кумаки, Центральная, 21, Администрация	t	small
109994	34052	637	Забайкальский край, Нерчинский район, село Пешково, Центральная, 35, Дом культуры	t	medium
109974	34030	616	Забайкальский край, Нерчинский район, село Олинск, Рабочая, 7	f	medium
109975	34031	617	Забайкальский край, Нерчинский район, село Олекан, Молодёжная, 2	f	medium
109987	34043	629	Забайкальский край, Нерчинский район, село Нижние Ключи, Советская, 4, Дом культуры	t	small
80285	34063	647	Забайкальский край, Нерчинский район, Нерчинск, Студгородок, 1, Аграрный техникум	f	large
110003	34064	648	Забайкальский край, Нерчинский район, Нерчинск, Советская, 18, ОСОШ	f	medium
110002	34061	646	Забайкальский край, Нерчинский район, Нерчинск, Советская, 2, кинотеатр 	f	medium
110004	34065	649	Забайкальский край, Нерчинский район, Нерчинск, Рабочая, 37, СПТУ-29	f	medium
109998	34056	641	Забайкальский край, Нерчинский район, Нерчинск, Пушкинская, 26, школа №2	f	medium
109999	34058	643	Забайкальский край, Нерчинский район, Нерчинск, Первомайская, 82	f	medium
110001	34060	645	Забайкальский край, Нерчинский район, Нерчинск, Достовалова, 3, Дом культуры	f	medium
110000	34059	644	Забайкальский край, Нерчинский район, Нерчинск, Достовалова, 11, СОШ № 9	f	medium
109996	34054	639	Забайкальский край, Нерчинский район, Нерчинск, Дорожная, 8	f	medium
109985	34041	627	Забайкальский край, Нерчинский район, село Нагорный, Октябрьская, 19, Дом культуры	t	small
109982	34038	624	Забайкальский край, Нерчинский район, село Левые Кумаки, Набережная, 21, Дом культуры	t	small
109973	34029	615	Забайкальский край, Нерчинский район, село Крупянка, Советская, 14	t	small
109979	34035	621	Забайкальский край, Нерчинский район, село Кангил, Центральная, 25, Сельский клуб	t	small
109990	34047	633	Забайкальский край, Нерчинский район, село Калинино, Новая, 3, Администрация	t	small
109976	34032	618	Забайкальский край, Нерчинский район, село Илим, Советская, 26, администрация	t	medium
80282	34027	614	Забайкальский край, Нерчинский район, село Зюльзя, К-Маркса, 7	t	large
109657	33597	176	Забайкальский край, Красночикойский район, село Аца, Горная, 2	t	small
109977	34033	619	Забайкальский край, Нерчинский район, село Знаменка, Школьная, 3, Дом культуры	f	medium
109983	34039	625	Забайкальский край, Нерчинский район, село Заречный, Набережная, 9	f	medium
109986	34042	628	Забайкальский край, Нерчинский район, село Верхний Умыкэй, Центральная, 37, Дом культуры	t	small
109988	34044	630	Забайкальский край, Нерчинский район, село Верхние Ключи, Центральная, 56, Дом культуры	t	small
109992	34049	635	Забайкальский край, Нерчинский район, село Бишигино, Набережная, 40, Дом культуры	t	small
109980	34036	622	Забайкальский край, Нерчинский район, село Березово, Казанушка, 12, Библиотека	t	small
109978	34034	620	Забайкальский край, Нерчинский район, село Беломестново, Центральная, 14-2, медицинский пункт	t	small
109995	34053	638	Забайкальский край, Нерчинский район, село Андронниково, Луговая, 14	t	small
109970	34022	609	Забайкальский край, Могочинский район, село Чалдонка, Набережная, 10	t	small
109968	34020	607	Забайкальский край, Могочинский район, село Таптугары, Школьная, 1	f	small
109967	34019	606	Забайкальский край, Могочинский район, село Семиозерный, Советская, 20	f	medium
80281	34025	612	Забайкальский край, Могочинский район, село Сбега, Центральная, 5	f	large
109964	34011	598	Забайкальский край, Могочинский район, Могоча, Шулешко, 10	f	medium
80274	34009	596	Забайкальский край, Могочинский район, Могоча, Советская, 32	f	large
109963	34010	597	Забайкальский край, Могочинский район, Могоча, Промышленная, 11	f	medium
80273	34008	595	Забайкальский край, Могочинский район, Могоча, Красноармейская, 1	f	large
80275	34012	599	Забайкальский край, Могочинский район, Могоча, Комсомольская, 13	f	large
80276	34013	600	Забайкальский край, Могочинский район, Могоча, Клубная, 1	f	large
80277	34014	601	Забайкальский край, Могочинский район, Могоча, Березовая, 29	f	large
109966	34017	604	Забайкальский край, Могочинский район, село Кудеча, Школьная, 1	t	small
109971	34023	610	Забайкальский край, Могочинский район, поселок городского типа Ксеньевка, Приисковая, Клуб	f	medium
80280	34024	611	Забайкальский край, Могочинский район, поселок Ксеньевка, Камерона, 8	f	large
80279	34018	605	Забайкальский край, Могочинский район, поселок городского типа Ключевский, Школьная, 40	t	large
109969	34021	608	Забайкальский край, Могочинский район, поселок городского типа Итака (Главный Стан), Школа	t	small
109965	34016	603	Забайкальский край, Могочинский район, поселок Давенда, Октябрьская, 5	t	medium
80278	34015	602	Забайкальский край, Могочинский район, Амазар, Клубная, 15	f	large
110246	34366	957	Забайкальский край, Могойтуйский район, село Цугол, здание администрации СП	t	medium
110249	34369	960	Забайкальский край, Могойтуйский район, село Цаган-Челутай, здание сельского комплекса бытовых услуг	f	medium
110242	34362	953	Забайкальский край, Могойтуйский район, село Цаган-Ола, здание администрации СП	t	medium
110238	34357	948	Забайкальский край, Могойтуйский район, село Харганаша, здание сельского клуба	t	small
80345	34361	952	Забайкальский край, Могойтуйский район, село Хара-Шибирь	t	large
110239	34358	949	Забайкальский край, Могойтуйский район, село Ушарбай, здание администрации СП	f	medium
110247	34367	958	Забайкальский край, Могойтуйский район, село Ортуй, здание Дома культуры	f	medium
80342	34352	943	Забайкальский край, Могойтуйский район, Могойтуй, Гагарина, 18	f	large
80344	34354	945	Забайкальский край, Могойтуйский район, поселок Могойтуй, переулок Черемушки, 1	f	large
80341	34351	942	Забайкальский край, Могойтуйский район, поселок городского типа Могойтуй, Ленина, 3	f	large
80343	34353	944	Забайкальский край, Могойтуйский район, Могойтуй, Зугалайская, б/н	f	large
110248	34368	959	Забайкальский край, Могойтуйский район, село Кусоча, здание Дома культуры	t	medium
110252	34372	963	Забайкальский край, Могойтуйский район, село Курульжа, здание сельского клуба"	t	small
110241	34360	951	Забайкальский край, Могойтуйский район, село Зугалай, здание Дома культуры	f	medium
110237	34356	947	Забайкальский край, Могойтуйский район, село Догой, здание Дома культуры	f	small
110240	34359	950	Забайкальский край, Могойтуйский район, село Бурятская, здание сельского клуба	t	small
110250	34370	961	Забайкальский край, Могойтуйский район, село Бильчиртуй, здание клуба гарнизона	t	small
18059	15638	489	Алтайский край, Рубцовск, пер.Станционный, 42В	f	large
110253	34373	964	Забайкальский край, Могойтуйский район, село Ара-Булак, здание офиса ОАО ""Славянка"""	t	small
110251	34371	962	Забайкальский край, Могойтуйский район, село Ага (Хила), здание Дома культуры	f	medium
110236	34355	946	Забайкальский край, Могойтуйский район, село Ага (Хила), здание Дома культуры	f	medium
109694	33641	219	Забайкальский край, Кыринский район, село Ульхун-Партия, Богомолова, 44	f	medium
109696	33643	221	Забайкальский край, Кыринский район, село Тырин, Молодежная, 2	f	small
109693	33639	217	Забайкальский край, Кыринский район, село Тарбальджей, Пионерская, 20В	t	small
109689	33635	213	Забайкальский край, Кыринский район, село Мордой, Центральная, здание администрации	t	small
109697	33644	222	Забайкальский край, Кыринский район, Михайло-Павловское, Дзержинского, 1	t	small
80168	33640	218	Забайкальский край, Кыринский район, село Мангут, Колхозная, 67	f	large
109690	33636	214	Забайкальский край, Кыринский район, село Любовь, Клубная, 1	t	medium
80166	33632	210	Забайкальский край, Кыринский район, село Кыра, Профсоюзная, 6	f	large
80167	33633	211	Забайкальский край, Кыринский район, село Кыра, Горького, 6	f	large
109692	33638	216	Забайкальский край, Кыринский район, село Кыра, Балуева, 1	t	medium
109688	33634	212	Забайкальский край, Кыринский район, село Гавань, Новая, 2	t	small
109695	33642	220	Забайкальский край, Кыринский район, село Верхний Ульхун, Ленина, 47а	f	medium
109686	33629	208	Забайкальский край, Кыринский район, село Билютуй, Пионерская, 18	t	medium
109685	33628	207	Забайкальский край, Кыринский район, село Алтан, Трактовая, 108	t	medium
109652	33592	171	Забайкальский край, Красночикойский район, село Ямаровка, Центральная, 16	t	small
109650	33590	169	Забайкальский край, Красночикойский район, село Ядрихино, Центральная, 2	t	small
109671	33613	192	Забайкальский край, Красночикойский район, село Этытэй, Советская, 9	t	small
109654	33594	173	Забайкальский край, Красночикойский район, село Шимбилик, Центральная, 86	f	small
109651	33591	170	Забайкальский край, Красночикойский район, село Черемхово, Центральная, 61	t	medium
109681	33623	202	Забайкальский край, Красночикойский район, село Хилкотой, Набережная, 16	t	small
109658	33598	177	Забайкальский край, Красночикойский район, село Фомичево, Центральная, 18	t	small
109683	33626	205	Забайкальский край, Красночикойский район, село Усть-Урлук, Вторая, 1	t	small
80165	33625	204	Забайкальский край, Красночикойский район, село Урлук, Школьная, 9	f	large
109655	33595	174	Забайкальский край, Красночикойский район, село Осиновка, Центральная, 23	t	small
109677	33619	198	Забайкальский край, Красночикойский район, село Нижний Нарым, Центральная, 121	t	small
109664	33604	183	Забайкальский край, Красночикойский район, село Малоархангельск, Центральная, 110	t	medium
80164	33606	185	Забайкальский край, Красночикойский район, село Красный Чикой, Первомайская, 61	f	large
80163	33605	184	Забайкальский край, Красночикойский район, село Красный Чикой, Первомайская, 1	f	large
109659	33599	178	Забайкальский край, Красночикойский район, село Красные Речки (Дурново), Первомайская, 27	t	small
109661	33601	180	Забайкальский край, Красночикойский район, село Коротково, Советская, 59	f	small
109656	33596	175	Забайкальский край, Красночикойский район, село Захарово, Центральная, 37	f	medium
109679	33621	200	Забайкальский край, Красночикойский район, село Жиндокон, Транспортная, 25а	t	small
109680	33622	201	Забайкальский край, Красночикойский район, село Жиндо-1, Советская, 40а	t	small
109678	33620	199	Забайкальский край, Красночикойский район, село Гутай, Центральная, 49а	t	small
109673	33615	194	Забайкальский край, Красночикойский район, село Верхний Шергольджин, Центральная, 52	f	small
109662	33602	181	Забайкальский край, Красночикойский район, село Быково, Заречная, 16	t	small
109674	33616	195	Забайкальский край, Красночикойский район, село Бурсомон, Новая, 2	t	small
109675	33617	196	Забайкальский край, Красночикойский район, Большая речка, Советская, 24	t	medium
109663	33603	182	Забайкальский край, Красночикойский район, село Барахоево, Октябрьская, 109	t	small
109672	33614	193	Забайкальский край, Красночикойский район, село Байхор, Центральная, 5	t	small
109670	33612	191	Забайкальский край, Красночикойский район, село Байхор, Центральная, 31	t	small
109653	33593	172	Забайкальский край, Красночикойский район, село Афонькино, Шоссейная, 8	t	small
109665	33607	186	Забайкальский край, Красночикойский район, село Архангельское (Качен), Колхозная, 1	t	medium
109676	33618	197	Забайкальский край, Красночикойский район, село Альбитуй, Адрияновская, 10	f	small
109666	33608	187	Забайкальский край, Красночикойский район, село Александровка (Карымка), Центральная, 13	f	small
109845	33869	458	Забайкальский край, Краснокаменский район, село Юбилейный, Дом культуры п.Юбилейный	f	medium
80255	33867	456	Забайкальский край, Краснокаменский район, село Целинный, Дом культуры	f	large
109843	33865	454	Забайкальский край, Краснокаменский район, село Соктуй-Милозан, Дом культуры с.Соктуй-Милозан	f	medium
109842	33864	453	Забайкальский край, Краснокаменский район, село Октябрьский, здание администрации	t	small
109844	33868	457	Забайкальский край, Краснокаменский район, село Маргуцек, Дом культуры п.Маргуцек	t	medium
109846	33870	459	Забайкальский край, Краснокаменский район, село Куйтун, Дом культуры	t	small
109850	33874	463	Россия, Забайкальский край, Краснокаменский район, Краснокаменск	t	small
80253	33862	450	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №3	f	large
80252	33861	449	Забайкальский край, Краснокаменский район, Краснокаменск, УМП ЖКУ	f	large
80249	33859	446	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №7	f	large
80248	33859	445	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №7	f	large
80247	33858	444	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №6	f	large
80244	33856	441	Забайкальский край, Краснокаменский район, Краснокаменск, Общежитие 9-ти этажное	f	large
80243	33854	440	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №4	f	large
80242	33854	439	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №4	f	large
80241	33853	438	Забайкальский край, Краснокаменский район, Краснокаменск, Профессиональное училище №11	f	large
80240	33852	437	Забайкальский край, Краснокаменский район, Краснокаменск, Дом культуры Даурия	f	large
80239	33851	436	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №1	f	large
80238	33850	435	Забайкальский край, Краснокаменский район, Краснокаменск, Специальная коррекционная школа №11	f	large
80237	33849	434	Забайкальский край, Краснокаменский район, Краснокаменск, Средняя школа №2	f	large
80236	33848	433	Забайкальский край, Краснокаменский район, Краснокаменск, Школа-гимназия №9	f	large
80235	33847	432	Забайкальский край, Краснокаменский район, Краснокаменск, Районный Дом культуры Строитель	f	large
80254	33866	455	Забайкальский край, Краснокаменский район, село Ковыли, Дом культуры п.Ковыли	t	large
109848	33872	461	Забайкальский край, Краснокаменский район, село Капцегайтуй, Здание администрации	f	small
109849	33873	462	Забайкальский край, Краснокаменский район, село Кайластуй, Дом культуры с.Кайластуй	f	medium
109847	33871	460	Забайкальский край, Краснокаменский район, село Богдановка, Дом культуры с.Богдановка	t	small
109946	33982	568	Забайкальский край, Карымский район, село Урульга, Центральная, здание библиотеки	f	small
80264	33980	567	Забайкальский край, Карымский район, село Урульга, Забелина, 1	f	large
109959	34003	590	Забайкальский край, Карымский район, село Тыргетуй, Центральная, 16	t	small
109958	34002	589	Забайкальский край, Карымский район, село Тыргетуй, Центральная, 68	f	medium
109957	34001	588	Забайкальский край, Карымский район, село Новодоронинск, Центральная, 47	t	small
109944	33978	565	Забайкальский край, Карымский район, село Нарын-Талача, Школьная, 1	f	small
109945	33979	566	Забайкальский край, Карымский район, село Нарын-Талача, Центральная, 28	f	small
109943	33977	564	Забайкальский край, Карымский район, село Нарын-Талача, Иландинская, здание библиотеки	f	small
109952	33988	574	Забайкальский край, Карымский район, село Маяки, Лесная, здание школы	t	small
109951	33987	573	Забайкальский край, Карымский район, село Маяки, Никифорова, 35	t	small
109960	94931	591	Забайкальский край, Карымский район, поселок Курорт-Дарасун, здание Дома культуры военного санатория	f	small
80267	33991	577	Забайкальский край, Карымский район, Карымское, Ангарская, 1	f	large
80269	33993	579	Забайкальский край, Карымский район, поселок городского типа Карымское, Торговый переулок, 24	f	large
80268	33992	578	Забайкальский край, Карымский район, Карымское, Ленинградская, 100	f	large
80266	33990	576	Забайкальский край, Карымский район, поселок Карымское, Ленинградская, 76	f	large
80265	33989	575	Забайкальский край, Карымский район, поселок Карымское, Верхняя, 32	f	large
109949	94930	571	Забайкальский край, Карымский район, село Кайдалово, Телевизионная, 9	f	small
109947	33983	569	Забайкальский край, Карымский район, село Кайдалово, Советская, 24	f	medium
109948	33984	570	Забайкальский край, Карымский район, село Кайдалово, Вокзальная, 3	t	small
109953	33994	580	Забайкальский край, Карымский район, село Кадахта, Советская, 31	t	medium
109955	33996	582	Забайкальский край, Карымский район, село Жимбира, Новая, 2	t	small
80270	33998	585	Забайкальский край, Карымский район, поселок Дарасун, Транспортная, 1	f	large
80272	34000	587	Забайкальский край, Карымский район, поселок Дарасун, Почтовая, 5	f	large
80271	33999	586	Забайкальский край, Карымский район, поселок Дарасун, Нагорная, 49	f	large
109962	34007	593	Забайкальский край, Карымский район, поселок Дарасун, Дорожная, 20	f	medium
109956	33997	584	Забайкальский край, Карымский район, поселок Дарасун, Дорожная, здание Дарасунского лесничества	f	medium
109961	94932	592	Забайкальский край, Карымский район, поселок городского типа Дарасун, Дом культуры санатория Дарасун	f	medium
109954	33995	581	Забайкальский край, Карымский район, село Большая Тура, Железнодорожная, 44	t	medium
109950	33986	572	Забайкальский край, Карымский район, село Адриановка, Школьная, 14	t	medium
110025	34088	672	Забайкальский край, Калганский район, село Явленка, Советская, 3	t	small
109942	33976	563	Забайкальский край, Калганский район, село Шивия, Гагарина, 30	t	small
109941	33975	562	Забайкальский край, Калганский район, село Чупрово, Школьная, 15	t	small
109940	33974	561	Забайкальский край, Калганский район, село Чингильтуй, Новая, 9	t	small
109939	33973	560	Забайкальский край, Калганский район, село Средняя Борзя, Советская, 1	t	small
109938	33972	559	Забайкальский край, Калганский район, село Нижний Калгукан, Центральная, 59	t	medium
109937	33971	558	Забайкальский край, Калганский район, село Козлово, Валько, 31	t	small
80263	33970	557	Забайкальский край, Калганский район, село Калга, Гаражная, 1	f	large
109936	33968	556	Забайкальский край, Калганский район, село Кадая, Советская, 44	t	medium
109935	33967	555	Забайкальский край, Калганский район, село Доно, Нагорная, 56	t	medium
109934	33966	554	Забайкальский край, Калганский район, село Верхний Калгукан, Молодёжная,, 13а	t	small
109933	33965	553	Забайкальский край, Калганский район, село Бура, В. Козлова, 42	t	small
109648	33588	167	Забайкальский край, Каларский район, село Чара, Озерная, 35	f	medium
109644	33584	163	Забайкальский край, Каларский район, село Чара, Озерная, 35	f	medium
109647	33587	166	Забайкальский край, Каларский район, село Чара, 60 лет ВЛКСМ, 7	f	medium
109645	33585	164	Забайкальский край, Каларский район, село Чапо-Олого, Набережная, 1	t	small
109640	33580	159	Забайкальский край, Каларский район, село Удокан, Иркутская, 6	t	small
109637	33576	156	Забайкальский край, Каларский район, поселок Новая Чара, Магистральная, 22 А	f	medium
109636	33576	155	Забайкальский край, Каларский район, поселок Новая Чара, Магистральная, 22 А	f	medium
109635	33576	154	Забайкальский край, Каларский район, поселок Новая Чара, Магистральная, 22 А	f	medium
109641	33581	160	Забайкальский край, Каларский район, поселок городского типа Новая Чара, Центральная, 1	f	small
109639	33579	158	Забайкальский край, Каларский район, поселок городского типа Новая Чара, Центральная, 1	f	small
109638	33578	157	Забайкальский край, Каларский район, поселок городского типа Новая Чара, Юбилейная, 6	f	small
109649	33589	168	Забайкальский край, Каларский район, село Кюсть-Кемда, Беляева, 8	t	small
109642	33582	161	Забайкальский край, Каларский район, село Куанда, Энтузиастов, 4	f	medium
109643	33583	162	Забайкальский край, Каларский район, село Куанда, Советская, 10	f	small
109646	33586	165	Забайкальский край, Каларский район, село Икабья, 1 микрорайон, 8	t	small
80100	33473	50	Забайкальский край, Ингодинский , Чита, Александро-Заводская, 30	f	large
109926	33958	546	Забайкальский край, Забайкальский район, село Черноозерский, Совхозная, 23	t	medium
109930	33962	550	Забайкальский край, Забайкальский район, село Степной, Здание Степнинской основной школы"	f	medium
109931	33963	551	Забайкальский край, Забайкальский район, село Рудник Абагайтуй, имени молодой гвардии , Средняя школа	t	small
109929	33961	549	Забайкальский край, Забайкальский район, село Красный Великан, Здание начальной школы	t	small
109927	33959	547	Забайкальский край, Забайкальский район, село Красный Великан, Центральная, 22	f	small
109928	33960	548	Забайкальский край, Забайкальский район, село Красный Великан, Шоссейная, СДК	f	small
80260	33953	540	Забайкальский край, Забайкальский район, Забайкальск, Красноармейская, 53	f	large
80259	33952	539	Забайкальский край, Забайкальский район, поселок городского типа Забайкальск, Железнодорожная, 14а	f	large
80258	33951	538	Забайкальский край, Забайкальский район, поселок Забайкальск, Красноармейская, 32а	f	large
80261	33954	541	Забайкальский край, Забайкальский район, поселок Забайкальск, Дружбы, 1А	f	large
80262	33957	544	Забайкальский край, Забайкальский район, село Даурия, Здание МУК ИБДЦ Камертон	f	large
109924	33956	543	Забайкальский край, Забайкальский район, село Даурия, Здание Администрации сельского поселения ""Даурское"", ДОС 10"	f	medium
109925	33936	545	Забайкальский край, Забайкальский район, село Даурия, 28, Средняя школа с. Даурия	f	medium
109923	33955	542	Забайкальский край, Забайкальский район, село Билитуй, переулок Степной, 4	f	medium
109932	33964	552	Забайкальский край, Забайкальский район, село Абагайтуй, Пограничная, 7	t	medium
110234	94940	940	Забайкальский край, Дульдургинский район, село Чиндалей, Балданжабона, 2	f	medium
110235	94941	941	Забайкальский край, Дульдургинский район, село Узон, Октябрьская , 56	t	medium
110233	94939	939	Забайкальский край, Дульдургинский район, село Токчин, Ленина, 17	t	medium
110232	94937	937	Забайкальский край, Дульдургинский район, село Таптанай, Калинина, 54-а	f	small
110230	94934	935	Забайкальский край, Дульдургинский район, село Красноярово, Школьная, 7	t	small
110231	94936	936	Забайкальский край, Дульдургинский район, село Иля, Новая, 27	t	small
80340	94938	938	Забайкальский край, Дульдургинский район, село Зуткулей, Ленина, 21	t	large
80338	34339	930	Забайкальский край, Дульдургинский район, село Дульдурга, Энергетиков, 17	f	large
110226	34338	929	Забайкальский край, Дульдургинский район, село Дульдурга, Кирова, 4	f	medium
80339	34340	931	Забайкальский край, Дульдургинский район, село Дульдурга, 8 марта, 7	f	large
110229	34343	934	Забайкальский край, Дульдургинский район, село Бальзино, Чкалова, 63	f	medium
110228	94935	933	Забайкальский край, Дульдургинский район, село Ара-Иля, Советская, 1	t	small
110227	34341	932	Забайкальский край, Дульдургинский район, село Алханай, Далаева, 15	f	medium
109910	33938	525	Забайкальский край, Газимуро-Заводский район, село Широкая, Строительная, 4 а	t	small
109914	33942	529	Забайкальский край, Газимуро-Заводский район, село Ушмун, Заречная, 2	t	small
109902	33928	516	Забайкальский край, Газимуро-Заводский район, село Трубачево, Центральная, 58	t	small
109909	33937	524	Забайкальский край, Газимуро-Заводский район, село Тайна, Центральная, 25 	t	small
109912	33940	527	Забайкальский край, Газимуро-Заводский район, село Солонечный, Мира, 42	t	medium
109911	33939	526	Забайкальский край, Газимуро-Заводский район, село Новоширокинский, 34, Здание сельской администрации	f	medium
109917	33945	532	Забайкальский край, Газимуро-Заводский район, село Луговское, Майская, 26	t	small
109915	33943	530	Забайкальский край, Газимуро-Заводский район, село Кунгара, Центральная, 4	t	small
109904	33930	518	Забайкальский край, Газимуро-Заводский район, село Корабль, Центральная,, 9	t	small
109913	33941	528	Забайкальский край, Газимуро-Заводский район, село Калдага, Центральная, 15	t	small
109905	33931	519	Забайкальский край, Газимуро-Заводский район, село Игдоча, Центральная, 28	t	small
109920	33948	535	Забайкальский край, Газимуро-Заводский район, село Зерен, Журавлева, 11	t	small
109919	33947	534	Забайкальский край, Газимуро-Заводский район, село Закаменная, Журавлева, 30	t	small
109903	33929	517	Забайкальский край, Газимуро-Заводский район, село Догье, Майская, 7	t	small
109908	33935	523	Забайкальский край, Газимуро-Заводский район, село Газимурский Завод, Рабочая, 11А	f	small
80257	33933	521	Забайкальский край, Газимуро-Заводский район, село Газимурский Завод, Журавлева, 10 а	f	large
109907	33934	522	Забайкальский край, Газимуро-Заводский район, село Газимурский Завод, Волкова, 12 а	f	medium
109901	33927	515	Забайкальский край, Газимуро-Заводский район, село Газимурские Кавыкучи, Трактовая, 13	t	small
109916	33944	531	Забайкальский край, Газимуро-Заводский район, село Бурукан, Школьная, 8	t	small
109918	33946	533	Забайкальский край, Газимуро-Заводский район, село Батакан, Центральная, 47	t	small
109835	33823	408	Забайкальский край, Борзинский район, село Южное, Помещение МОУ Южнинская ООШ	t	small
109834	33822	407	Забайкальский край, Борзинский район, село Шоноктуй, Нагорная, 1	t	small
80219	33827	412	Забайкальский край, Борзинский район, Шерловая Гора, Оловянная, 4	f	large
80218	33826	411	Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора, помещение Дома детского творчества	f	large
109838	33830	415	Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора, Шоссейная, 6а	f	small
80220	33829	414	Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора, Ленина, 14	f	large
109837	33828	413	Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора, Ленина, 4	f	medium
109836	33824	409	Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора, Горького, 12	f	medium
80217	33825	410	Забайкальский край, Борзинский район, поселок городского типа Шерловая Гора, 50 лет Октября	f	large
109833	33821	406	Забайкальский край, Борзинский район, село Чиндант 2-й, МОУ Чиндантская ООШ	t	medium
109832	33820	405	Забайкальский край, Борзинский район, село Цаган-Олуй, помещение МОУ: Цаган-Олуйская СОШ	t	medium
109831	33819	404	Забайкальский край, Борзинский район, село Хада-Булак, помещение МОУ: Хада-Булакская СОШ	t	medium
109830	33818	403	Забайкальский край, Борзинский район, село Усть-Озёрная, помещение МОУ: Усть-Озерская СОШ	t	small
109829	33817	402	Забайкальский край, Борзинский район, село Соловьёвск, помещение МОУ: Соловьевская СОШ	t	medium
109828	33816	401	Забайкальский край, Борзинский район, село Приозерное, помещение МОУ: Приозернинская ООШ	t	small
109827	33815	400	Забайкальский край, Борзинский район, село Передняя Бырка, помещение МОУ: Перебнебыркинская СОШ	t	medium
109824	33812	397	Забайкальский край, Борзинский район, село Олдонда, помещение МОУ: Олдондинская НОШ	t	small
109826	33814	399	Забайкальский край, Борзинский район, село Новоборзинское, помещение администрации СП Новоборзинское	t	small
109823	33811	396	Забайкальский край, Борзинский район, село Курунзулай, Матафонова, 26	t	small
109822	33810	395	Забайкальский край, Борзинский район, село Кондуй, Центральная, 43 А	t	medium
109825	33813	398	Забайкальский край, Борзинский район, село Ключевское, Партизанская, 8	t	small
109840	33846	431	Забайкальский край, Борзинский район, Борзя, помещение МОУ: СОШ № 26	f	medium
80234	33844	430	Забайкальский край, Борзинский район, Борзя, помещение клуба ОДОРА	f	large
80233	33844	429	Забайкальский край, Борзинский район, Борзя, помещение клуба ОДОРА	f	large
80230	33841	426	Забайкальский край, Борзинский район, Борзя, Шамсутдинова, 13	f	large
80225	33836	421	Забайкальский край, Борзинский район, Борзя, Советская, 52	f	large
80231	33842	427	Забайкальский край, Борзинский район, Борзя, Свердлова, 10	f	large
80224	33835	420	Забайкальский край, Борзинский район, Борзя, Савватеевская, 31	f	large
80228	33839	424	Забайкальский край, Борзинский район, Борзя, Оздоровительная, 2	f	large
80226	33837	422	Забайкальский край, Борзинский район, Борзя, Ленина, 26	f	large
80229	33840	425	Забайкальский край, Борзинский район, Борзя, Лазо, 33, помещение	f	large
80223	33834	419	Забайкальский край, Борзинский район, Борзя, Лазо, 29	f	large
80221	33831	416	Забайкальский край, Борзинский район, Борзя, Коновалова, 21	f	large
80222	33833	418	Забайкальский край, Борзинский район, Борзя, Карла Маркса, 118	f	large
109839	33832	417	Забайкальский край, Борзинский район, Борзя, Карла Маркса, 204	f	medium
80227	33838	423	Забайкальский край, Борзинский район, Борзя, Журавлева, 6 А	f	large
80232	33843	428	Забайкальский край, Борзинский район, Борзя, Дзержинского, 31	f	large
109821	33809	394	Забайкальский край, Борзинский район, село Биликтуй, Погодаева, 16	t	small
109820	33808	393	Забайкальский край, Борзинский район, село Акурай, Центральная, 2	t	small
109878	33904	492	Забайкальский край, Балейский район, село Ундино-Поселье, Советская, 25	f	medium
109890	33916	504	Забайкальский край, Балейский район, село Унда, Энергетиков, 1а	f	medium
109887	33913	501	Забайкальский край, Балейский район, село Подойницыно, Школьная, 9	t	small
109889	33915	503	Забайкальский край, Балейский район, село Подойницыно, Центральная,, 20	t	small
109885	33911	499	Забайкальский край, Балейский район, село Подойницыно, Трактовая, 22	t	small
109886	33912	500	Забайкальский край, Балейский район, село Подойницыно, Советская, 15	t	small
109888	33914	502	Забайкальский край, Балейский район, село Подойницыно, Кирова, 11А	t	small
109882	33908	496	Забайкальский край, Балейский район, село Нижний Кокуй, Школьный переулок, 3	t	small
109884	33910	498	Забайкальский край, Балейский район, село Нижний Кокуй, Первомайская, 26	t	small
109883	33909	497	Забайкальский край, Балейский район, село Нижний Кокуй, Колхозная, 1А	t	small
109897	33923	511	Забайкальский край, Балейский район, село Нижний Ильдикан, Центральная, 17	t	small
109894	33920	508	Забайкальский край, Балейский район, село Нижний Ильдикан, Центральная, 11	t	small
109896	33922	510	Забайкальский край, Балейский район, село Нижний Ильдикан, Специалистов, 1	t	small
109895	33921	509	Забайкальский край, Балейский район, село Нижний Ильдикан, Кишиневская, 9	t	small
109900	33926	514	Забайкальский край, Балейский район, село Нижнее Гирюнино, Трактовая, 20А	t	small
109898	33924	512	Забайкальский край, Балейский район, село Нижнее Гирюнино, Заречная, 6	t	small
109881	33907	495	Забайкальский край, Балейский район, село Матусово, Центральная, 7а	t	small
109879	33905	493	Забайкальский край, Балейский район, село Матусово, Центральная, 24	t	small
109880	33906	494	Забайкальский край, Балейский район, село Матусово, Колхозная, 1	t	small
109891	33917	505	Забайкальский край, Балейский район, село Казаковский Промысел, Котовского, 2-1	t	medium
109893	33919	507	Забайкальский край, Балейский район, село Жидка, Новая, 6А	t	small
109892	33918	506	Забайкальский край, Балейский район, село Жидка, Клубная, 4А	t	small
109818	33806	391	Забайкальский край, Балейский район, Балей, Чернышевского, Помещение поликлиники мкр. Отмахово	f	medium
109817	33805	390	Забайкальский край, Балейский район, Балей, Чернышевского, помещение школы №6	f	medium
109814	33802	387	Забайкальский край, Балейский район, Балей, Советская, 24	f	small
109808	33793	379	Забайкальский край, Балейский район, Балей, Пролетарская, 8	f	small
109819	33807	392	Забайкальский край, Балейский район, Балей, Новоколхозная, Помещение медпункта Подхоза	f	small
109810	33796	382	Забайкальский край, Балейский район, Балей, Матросова, 48	f	medium
109812	33800	385	Забайкальский край, Балейский район, Балей, Ленина, 6	f	medium
80216	33797	383	Забайкальский край, Балейский район, Балей, Ленина, 26	f	large
109811	33799	384	Забайкальский край, Балейский район, Балей, Кирова, 22	f	medium
109809	33794	380	Забайкальский край, Балейский район, Балей, Дарасунская, 7	f	medium
109813	33801	386	Забайкальский край, Балейский район, Балей, Ведерникова, 10	f	medium
109815	33803	388	Забайкальский край, Балейский район, Балей, Блюхера, 27	f	small
80215	33795	381	Забайкальский край, Балейский район, Балей, 5-ое Декабря, Помещение школы №14	f	large
109875	94929	489	Забайкальский край, Александрово-Заводский район, село Шаранча, Новая, 11/2	t	small
109859	33884	473	Забайкальский край, Александрово-Заводский район, село Шаранча, Молодежная, 5	t	small
109874	33900	488	Забайкальский край, Александрово-Заводский район, село Чиндагатай, Школьная, 10	t	small
109876	33902	490	Забайкальский край, Александрово-Заводский район, село Чиндагатай, Центральная, 9	t	small
109872	33898	486	Забайкальский край, Александрово-Заводский район, село Савво-Борзя, Школьная, 14	t	small
109869	33895	483	Забайкальский край, Александрово-Заводский район, село Онон-Борзя, Лесная, 4	t	small
109873	33899	487	Забайкальский край, Александрово-Заводский район, село Новый Акатуй, Центральная, 36	t	small
18053	15633	483	Алтайский край, Рубцовск, Федоренко, 17	f	large
109852	33877	466	Забайкальский край, Александрово-Заводский район, село Новый Акатуй, Центральная, 10	t	small
109868	33894	482	Забайкальский край, Александрово-Заводский район, село Новый Акатуй, Лунина, 15	t	medium
109867	33893	481	Забайкальский край, Александрово-Заводский район, село Николаевка, Центральная, 37	t	small
109865	33890	479	Забайкальский край, Александрово-Заводский район, село Маньково, Кооперативная, 17	t	small
109864	33889	478	Забайкальский край, Александрово-Заводский район, село Манкечур, Центральная, 16	t	small
109871	33897	485	Забайкальский край, Александрово-Заводский район, село Манкечур, Садовая, 5	t	small
109862	94928	476	Забайкальский край, Александрово-Заводский район, село Кутугай, Центральная, 3	t	small
109861	33886	475	Забайкальский край, Александрово-Заводский район, село Кузнецово, Школьная, 23	t	small
109857	94926	471	Забайкальский край, Александрово-Заводский район, село Кокуй 2-й, Бохтинское, Молодежная, 13-в	t	small
109863	33888	477	Забайкальский край, Александрово-Заводский район, село Кокуй 1-й, Центральная, 16	t	small
109860	94927	474	Забайкальский край, Александрово-Заводский район, село Клин, Нагорная, 2	t	small
109854	33879	468	Забайкальский край, Александрово-Заводский район, село Бутунтай, Школьная, 1	t	small
109866	33891	480	Забайкальский край, Александрово-Заводский район, село Бутунтай, Молодежная, 21	t	small
109856	33881	470	Забайкальский край, Александрово-Заводский район, село Бохто, Центральная, 31	t	small
109853	33878	467	Забайкальский край, Александрово-Заводский район, село Бохто, Нагорная, 17	t	small
109877	33903	491	Забайкальский край, Александрово-Заводский район, село Александровский Завод, Школьная, 1	t	small
80256	33876	465	Забайкальский край, Александрово-Заводский район, село Александровский Завод, Советская, 35	f	large
109858	33883	472	Забайкальский край, Александрово-Заводский район, село Александровский Завод, Нагорная, 3	t	small
109634	33575	153	Забайкальский край, Акшинский район, село Усть-Иля, Школьная, 37А	f	small
109633	33574	152	Забайкальский край, Акшинский район, село Урейск, Партизанская, 98	f	medium
109632	33573	151	Забайкальский край, Акшинский район, село Улача, Центральная, 7	f	small
109631	33572	150	Забайкальский край, Акшинский район, село Убур-Тохтор, Мира, 20	f	small
109630	33571	149	Забайкальский край, Акшинский район, село Тохтор, Лесная, 5	f	small
109629	33570	148	Забайкальский край, Акшинский район, село Такеча, Школьная, 1	t	small
109628	33569	147	Забайкальский край, Акшинский район, село Орой, Молодёжная, 13	f	small
109627	33568	146	Забайкальский край, Акшинский район, село Новокургатай, Центральная, 120-А	f	small
109626	33567	145	Забайкальский край, Акшинский район, село Новоказачинск, им. братьев Макаровых, 40	t	small
109625	33566	144	Забайкальский край, Акшинский район, село Нарасун, Ленина, 61	f	medium
109624	33565	143	Забайкальский край, Акшинский район, село Могойтуй, Школьная, 6	f	medium
109623	33564	142	Забайкальский край, Акшинский район, село Курулга, Центральная, 1	t	small
109622	33563	141	Забайкальский край, Акшинский район, село Дорожное, Центральная, 8	f	small
109621	33562	140	Забайкальский край, Акшинский район, село Бытэв, Школьная, 3	f	small
80162	33561	139	Забайкальский край, Акшинский район, село Акша, Партизанская, 22	f	large
80161	33560	138	Забайкальский край, Акшинский район, село Акша, Карла Маркса, 51	f	large
110212	34325	914	Забайкальский край, Агинский район, село Южный Аргалей, здание сельского Дома культуры	f	small
110211	34324	913	Забайкальский край, Агинский район, село Челутай, Центральная, 15	f	medium
110218	34330	920	Забайкальский край, Агинский район, село Цокто-Хангил, здание сельского Дома культуры	f	medium
110213	34326	915	Забайкальский край, Агинский район, село Хойто-Ага, Ленина, 18	f	medium
110217	34329	919	Забайкальский край, Агинский район, село Урда-Ага, здание сельского клуба	t	small
110216	34329	918	Забайкальский край, Агинский район, село Урда-Ага, здание сельского клуба	t	small
110215	34328	917	Забайкальский край, Агинский район, село Урда-Ага, Ленина, 2	f	medium
110219	34331	921	Забайкальский край, Агинский район, село Судунтуй, Школьная, 1	t	medium
110214	34327	916	Забайкальский край, Агинский район, село Сахюрта (Дунда-Ага), Ленина, 18	f	medium
18054	15634	484	Алтайский край, Рубцовск, Тракторная, 158	f	large
110224	34335	926	Забайкальский край, Агинский район, поселок городского типа Орловский, здание конторы агрокооператива Хилинский	t	small
110223	34334	925	Забайкальский край, Агинский район, поселок городского типа Орловский, здание Дома культуры	t	medium
110225	34336	927	Забайкальский край, Агинский район, поселок Орловский, общежитие акционерного общества Забота	t	small
80337	34337	928	Забайкальский край, Агинский район, поселок городского типа Новоорловск, здание молодежного центра	t	large
110222	34277	924	Забайкальский край, Агинский район, село Кункур, Школьная, 14	f	medium
110220	34332	922	Забайкальский край, Агинский район, Гунэй, дание администрации сельского поселения ""Гунэй"""	t	medium
110221	34333	923	Забайкальский край, Агинский район, село Будулан, здание сельского Дома культуры	t	small
80336	34323	912	Забайкальский край, Агинский район, село Амитхаша (Агинский Дацан), переулок Клубный, 1	f	large
80335	34118	911	Забайкальский край, Агинский район, поселок городского типа Агинское, Ранжурова, 25Е	f	large
80334	34005	910	Забайкальский край, Агинский район, Агинское, Ленина, 146	f	large
80333	33981	909	Забайкальский край, Агинский район, поселок городского типа Агинское, Комсомольская, 59	f	large
80332	33969	908	Забайкальский край, Агинский район, поселок Агинское, Комсомольская, 17	f	large
17820	15442	249	Алтайский край, пос.Бельмесево, Отечественная, 22	f	large
67876	15663	516	Алтайский край, Яровое, квартал В, 19	f	large
18083	15660	513	Алтайский край, город Яровое, квартал Б, 31	f	large
18081	15658	511	Алтайский край, Яровое, квартал А, 21	f	large
18082	15659	512	Алтайский край, Яровое, Ленина, 9	f	large
18084	15661	514	Алтайский край, Яровое, Гагарина, 10	f	large
18085	15662	515	Алтайский край, Яровое, 40 лет Октября, 1	f	large
19211	16795	1685	Алтайский край, поселок Угловское, Ленина, 34	f	large
19144	16726	1618	Алтайский край, поселок Троицкое, Рабочая, 16	f	large
19079	16665	1543	Алтайский край, поселок Тальменка, Юбилейная, 19	f	large
19078	16664	1542	Алтайский край, поселок Тальменка, Мехзаводская, 23	f	large
19070	16656	1534	Алтайский край, поселок Тальменка, Кирова, 73	f	large
19006	16527	1467	Алтайский край, поселок Солтон, Демьяна Бедного, 3	f	large
18980	16566	1433	Алтайский край, поселок Солонешное, Партизанская, 86	f	medium
18981	16567	1434	Алтайский край, поселок Солонешное, Красноармейская, 17	f	large
18069	15647	499	Алтайский край, Славгород, микрорайон 3, средняя школа №15	f	large
18078	15655	508	Алтайский край, Славгород, микрорайон 2, средняя школа №17	f	large
18071	15649	501	Алтайский край, Славгород, Энгельса, 73	f	large
18077	15654	507	Алтайский край, город Славгород, Титова, 169	f	large
18080	15657	510	Алтайский край, Славгород, поселок Бурсоль, Советская, 3	f	medium
18073	15650	503	Алтайский край, Славгород, Розы Люксембург, 121	f	large
18072	15650	502	Алтайский край, Славгород, Розы Люксембург, 121	f	large
67901	15653	506	Алтайский край, Славгород, Первомайская, 194	f	large
18922	16508	1374	Алтайский край, Славгород, село Пановка, Новая, 10	t	small
67906	15652	505	Алтайский край, Славгород, Ленина, 243	f	large
18921	16507	1373	Алтайский край, Славгород, село Знаменка, Ленина, 31	f	large
19403	16987	1884	Алтайский край, Славгород, Космонавтов, 156	f	large
18924	16510	1376	Алтайский край, Славгород, поселок Нововознесеновка, Кооперативный, 9	f	medium
18930	16515	1382	Алтайский край, Славгород, Карла Маркса, 285	f	large
67900	15651	504	Алтайский край, Славгород, Карла Маркса, 169	f	large
18070	15648	500	Алтайский край, Славгород, 2-ая вокзальная, 27	f	large
19414	16991	1895	Алтайский край, город Рубцовск, тр.Новоегорьевский, 4	f	large
18038	15623	468	Алтайский край, Рубцовск, проспект Ленина, 36	f	large
18022	15607	452	Алтайский край, Рубцовск, проспект Ленина, 187	f	large
18027	15611	457	Алтайский край, Рубцовск, пр.Рубцовский, 62	f	large
18040	15625	470	Алтайский край, город Рубцовск, пр.Ленина, 7	f	large
18033	15618	463	Алтайский край, Рубцовск, пр.Ленина, 48	f	large
18029	15613	459	Алтайский край, Рубцовск, пр.Ленина, 171А	f	large
18028	15612	458	Алтайский край, Рубцовск, пр.Ленина, 136	f	large
18021	15606	451	Алтайский край, Рубцовск, пр.Ленина, 190	f	large
18024	15609	454	Алтайский край, Рубцовск, переулок Пионерский, 31	f	large
18061	15638	491	Алтайский край, Рубцовск, пер.Станционный, 42В	f	large
18047	15631	477	Алтайский край, Рубцовск, Светлова, 90	f	large
18065	15643	495	Алтайский край, Рубцовск, Рихарда Зорге, 157	f	large
18060	15639	490	Алтайский край, Рубцовск, Рихарда Зорге, 121	f	large
18063	15641	493	Алтайский край, Рубцовск, Рихарада Зорге, 121	f	large
18064	15642	494	Алтайский край, Рубцовск, Районная, 14	f	large
19412	15608	1893	Алтайский край, Рубцовск, Пролетарская, 284А	f	large
18023	15608	453	Алтайский край, Рубцовск, Пролетарская, 284А	f	large
18017	15602	447	Алтайский край, Рубцовск, Пролетарская, 412А	f	large
18016	15601	446	Алтайский край, Рубцовск, Пролетарская, 412	f	large
19411	15603	1892	Алтайский край, Рубцовск, Осипенко, 182В	f	large
18018	15603	448	Алтайский край, Рубцовск, Осипенко, 182В	f	large
19413	16990	1894	Алтайский край, Рубцовск, Октябрьская, 3А	f	large
18043	15628	473	Алтайский край, Рубцовск, Октябрьская, 68	f	large
18044	15628	474	Алтайский край, Рубцовск, Октябрьская, 68	f	large
18057	15637	487	Алтайский край, Рубцовск, Одесская, 6	f	large
18020	15605	450	Алтайский край, Рубцовск, Красная, 99	f	large
18055	15635	485	Алтайский край, Рубцовск, Кондратюка, 4	f	large
18050	15629	480	Алтайский край, Рубцовск, Комсомольская, 21	f	large
18045	15629	475	Алтайский край, Рубцовск, Комсомольская, 21	f	large
18042	15627	472	Алтайский край, Рубцовск, Комсомольская, 97	f	large
18041	15626	471	Алтайский край, Рубцовск, Комсомольская, 99	f	large
18039	15624	469	Алтайский край, Рубцовск, Комсомольская, 134	f	large
18034	15619	464	Алтайский край, Рубцовск, Комсомольская, 158	f	large
18031	15616	461	Алтайский край, Рубцовск, Комсомольская, 204	f	large
18030	15615	460	Алтайский край, Рубцовск, Карла Маркса, 141	f	large
18036	15621	466	Алтайский край, город Рубцовск, Дзержинского, 20	f	large
67883	15622	467	Алтайский край, Рубцовск, Громова, 7	f	large
18032	15617	462	Алтайский край, Рубцовск, Громова, 29	f	large
18026	15610	456	Алтайский край, Рубцовск, Гражданский переулок, 52	f	large
18025	15610	455	Алтайский край, Рубцовск, Гражданский переулок, 52	f	large
18035	15620	465	Алтайский край, Рубцовск, Бульвар Победы, 11	f	large
18058	15636	488	Алтайский край, Рубцовск, Брусилова, 41	f	large
18056	15636	486	Алтайский край, Рубцовск, Брусилова, 41	f	large
18052	15632	482	Алтайский край, Рубцовск, Алтайская, 179	f	large
18051	15632	481	Алтайский край, Рубцовск, Алтайская, 179	f	large
18046	15630	476	Алтайский край, Рубцовск, Алтайская, 112А	f	large
18049	15581	479	Алтайский край, Рубцовск, Алтайская, 169А	f	large
18870	16459	1322	Алтайский край, поселок Родино, Рабочий, 20	f	large
18814	16401	1265	Алтайский край, поселок Поспелиха, 8 Марта, 48	f	large
18010	15596	440	Алтайский край, Новоалтайск, Энгельса, 1	f	large
18002	15589	432	Алтайский край, Новоалтайск, Трактовая, 88	f	large
18013	15598	443	Алтайский край, Новоалтайск, Союза Республик, 3	f	large
18007	15593	437	Алтайский край, Новоалтайск, Прудская, 8	f	large
18006	15592	436	Алтайский край, Новоалтайск, Прудская, 9	f	large
18005	15592	435	Алтайский край, Новоалтайск, Прудская, 9	f	large
17996	15584	426	Алтайский край, Новоалтайск, Попова, 16	f	large
18014	15599	444	Алтайский край, Новоалтайск, Мерзликина, 15	f	large
18009	15595	439	Алтайский край, Новоалтайск, Менделеева, 48	f	large
17990	15577	420	Алтайский край, Новоалтайск, Майская, 125	f	large
17989	15577	419	Алтайский край, Новоалтайск, Майская, 125	f	large
18008	15594	438	Алтайский край, Новоалтайск, Космонавтов, 16	f	large
18003	15590	433	Алтайский край, Новоалтайск, Анатолия, 13	f	large
17999	15586	429	Алтайский край, Новоалтайск, 8-й микрорайон, 24	f	medium
17998	15586	428	Алтайский край, Новоалтайск, 8-й микрорайон, 24	f	large
67880	15582	424	Алтайский край, Новоалтайск, 22 Партсъезда, 9а	f	large
109234	15585	427	Алтайский край, Новоалтайск, 2-Залинейная, 14	f	medium
18660	16242	1109	Алтайский край, поселок Михайловское, К.Маркса, 41	f	large
18453	16034	891	Алтайский край, поселок Марковка, Новая, 19	f	small
18640	16222	1089	Алтайский край, поселок Крестьянка, Новая, 2	f	large
18512	16092	956	Алтайский край, поселок Краснощеково, Молодежная, 25а	f	large
18441	16022	879	Алтайский край, поселок Ключи, Центральная, 29	f	large
17967	15559	397	Алтайский край, Камень-на-Оби, Томская, 2	f	medium
17986	15571	416	Алтайский край, Камень-на-Оби, Терешковой, 21	f	medium
17982	15571	412	Алтайский край, Камень-на-Оби, Терешковой, 21	f	large
17983	15572	413	Алтайский край, Камень-на-Оби, Новоярковский тракт, 12а	f	large
17985	15574	415	Алтайский край, Камень-на-Оби, Николаева, 38	f	medium
17971	15562	401	Алтайский край, Камень-на-Оби, Некрасова, 2	f	large
17984	15573	414	Алтайский край, Камень-на-Оби, Мира, 6	f	large
17981	15570	411	Алтайский край, Камень-на-Оби, Мамонтова, 20	f	large
17972	15563	402	Алтайский край, Камень-на-Оби, Ленина, 29	f	large
17968	15557	398	Алтайский край, Камень-на-Оби, Куйбышева, 48	f	large
17965	15557	395	Алтайский край, Камень-на-Оби, Куйбышева, 48	f	large
17979	15568	409	Алтайский край, Камень-на-Оби, Карла Маркса, 106	f	large
17978	15568	408	Алтайский край, Камень-на-Оби, Карла Маркса, 106	f	large
17969	15560	399	Алтайский край, Камень-на-Оби, Громова, 19	f	large
17980	15569	410	Алтайский край, Камень-на-Оби, Гагарина, 111	f	large
17958	15551	388	Алтайский край, Змеиногорск, Шумакова, 5	f	large
17961	15554	391	Алтайский край, Змеиногорск, Чернышевского, 1	f	large
17964	15556	394	Алтайский край, город Змеиногорск, с.Лазурка, Центральная, 3	t	small
17956	15549	386	Алтайский край, Змеиногорск, Семипалатинская, 3	f	large
67905	15555	393	Алтайский край, Змеиногорск, Пугачева, 18	f	large
109233	15555	392	Алтайский край, Змеиногорск, Пугачева, 18	f	medium
17959	15552	389	Алтайский край, Змеиногорск, Ленина, 30	f	large
17957	15550	387	Алтайский край, город Змеиногорск, Ленина, 3	f	large
17960	15553	390	Алтайский край, Змеиногорск, Барнаульский тракт, 46	f	large
17954	15547	384	Алтайский край, Заринск, пер.2-й Железнодорожный, 3	f	large
17953	15546	383	Алтайский край, Заринск, Центральная, 24	f	large
17949	15543	379	Алтайский край, Заринск, Таратынова, 13/1	f	large
17948	15543	378	Алтайский край, Заринск, Таратынова, 13/1	f	large
19428	16996	1916	Алтайский край, Заринск, Сыркина, 43	f	large
17951	15544	381	Алтайский край, Заринск, Строителей, 22/1	f	large
17950	15544	380	Алтайский край, Заринск, Строителей, 22/1	f	large
17947	15542	377	Алтайский край, Заринск, Союза Республик, 6	f	large
17946	15541	376	Алтайский край, Заринск, Союза Республик, 7/2	f	large
17955	15548	385	Алтайский край, Заринск, Заринская, 58	f	large
17945	15540	375	Алтайский край, Заринск, 40 лет Победы, 4/2	f	large
17941	15537	371	Алтайский край, Заринск, 25 Партсъезда, 7	f	large
17940	15536	370	Алтайский край, Заринск, 25 Партсъезда, 36/2	f	large
17939	15536	369	Алтайский край, Заринск, 25 Партсъезда, 36/2	f	large
17938	15536	368	Алтайский край, Заринск, 25 Партсъезда, 36/2	f	large
18285	94900	720	Алтайский край, поселок Завьялово, Дорожная, 38	f	large
18673	16256	1122	Алтайский край, поселок Дегтярка, Ленина, 55	f	large
18618	16199	1067	Алтайский край, Горняк, Элеваторная, 1	f	large
18616	16197	1065	Алтайский край, Горняк, Первомайская, 28	f	large
18614	16195	1063	Алтайский край, Горняк, Островского, 17	f	large
18612	16193	1061	Алтайский край, Горняк, Ленина, 5	f	large
18617	16198	1066	Алтайский край, Горняк, Заводская, 5	f	small
18615	16196	1064	Алтайский край, Горняк, Больничная, 18	f	large
17909	15512	339	Алтайский край, Бийск, клуб Фоминское	f	large
17927	15527	357	Алтайский край, город Бийск, улица Кутузова, 9	f	large
67872	15520	349	Алтайский край, Бийск, Чайковского, 4/1	f	large
17879	15490	309	Алтайский край, Бийск, Центральный, 10	f	large
17895	15501	325	Алтайский край, Бийск, Урожайная, 19	f	medium
17914	15507	344	Алтайский край, Бийск, Ударная, 75	f	large
17903	15507	333	Алтайский край, Бийск, Ударная, 75	f	large
17880	15488	310	Алтайский край, Бийск, Тургенева, 215	f	large
17877	15488	307	Алтайский край, Бийск, Тургенева, 215	f	large
17872	15484	302	Алтайский край, Бийск, Тургенева, 66	f	large
17871	15484	301	Алтайский край, Бийск, Тургенева, 66	f	large
17906	15510	336	Алтайский край, Бийск, Трофимова, 27	f	large
17900	15504	330	Алтайский край, Бийск, Трофимова, 45	f	large
17869	15482	299	Алтайский край, Бийск, Трофимова, 6	f	large
17842	15460	272	Алтайский край, Бийск, Телеграфный, 65	f	large
17923	15523	353	Алтайский край, Бийск, Социалистическая, 30	f	large
17917	15518	347	Алтайский край, Бийск, Социалистическая, 80	f	large
17898	15502	328	Алтайский край, город Бийск, Социалистическая, 123	f	large
17896	15502	326	Алтайский край, город Бийск, Социалистическая, 123	f	large
17937	15535	367	Алтайский край, Бийск, Советская, 199/1	f	large
17933	15531	363	Алтайский край, Бийск, Советская, 219/5	f	large
17932	15530	362	Алтайский край, Бийск, Советская, 199/7	f	large
17931	15529	361	Алтайский край, Бийск, Советская, 212	f	large
17930	15529	360	Алтайский край, Бийск, Советская, 212	f	large
17929	15529	359	Алтайский край, Бийск, Советская, 212	f	large
17848	15465	278	Алтайский край, город Бийск, Советская, 78	f	large
17847	15464	277	Алтайский край, Бийск, Советская, 58	f	large
17846	15464	276	Алтайский край, Бийск, Советская, 58	f	large
17845	15463	275	Алтайский край, Бийск, Советская, 30	f	large
17862	15475	292	Алтайский край, Бийск, Смольный переулок, 5	f	large
17899	15503	329	Алтайский край, Бийск, Севастопольская, 39	f	large
17897	15503	327	Алтайский край, Бийск, Севастопольская, 39	f	large
17857	15471	287	Алтайский край, Бийск, Самарская, 46	f	large
17841	15459	271	Алтайский край, Бийск, Революции, 98	f	medium
17918	15519	348	Алтайский край, Бийск, Разина, 61	f	large
17908	15511	338	Алтайский край, Бийск, Разина, 5	f	large
17870	15483	300	Алтайский край, Бийск, Раздольная, 28	f	medium
17928	15528	358	Алтайский край, Бийск, Радищева, 28	f	large
17926	15526	356	Алтайский край, Бийск, Радищева, 20	f	large
17884	15493	314	Алтайский край, город Бийск, Пушкина, 188-а	f	large
17883	15493	313	Алтайский край, город Бийск, Пушкина, 188-а	f	large
17867	15480	297	Алтайский край, Бийск, Промышленная, 9	f	large
17936	15534	366	Алтайский край, Бийск, Приречная, 3/2	f	large
17924	15524	354	Алтайский край, Бийск, Прибыткова, 9	f	large
17850	15467	280	Алтайский край, Бийск, Подгорная, 78	f	large
17868	15481	298	Алтайский край, Бийск, Петрова, 21	f	large
17894	15500	324	Алтайский край, Бийск, Нефтебаза, 4	f	large
17889	15468	319	Алтайский край, Бийск, Мухачева, 228/1	f	large
17855	15468	285	Алтайский край, Бийск, Мухачева, 228/1	f	large
17852	15468	282	Алтайский край, Бийск, Мухачева, 228/1	f	large
17856	15469	286	Алтайский край, Бийск, Муромцевский, 8	f	large
17853	15469	283	Алтайский край, Бийск, Муромцевский, 8	f	large
17893	15499	323	Алтайский край, Бийск, Моторный, 5	f	large
17892	15499	322	Алтайский край, Бийск, Моторный, 5	f	large
17922	15521	352	Алтайский край, Бийск, Можайского, 6	f	large
17920	15521	350	Алтайский край, Бийск, Можайского, 6	f	large
17866	15479	296	Алтайский край, город Бийск, Мерлина, 25	f	large
17901	15505	331	Алтайский край, Бийск, Мартьянова, 42	f	large
17935	15533	365	Алтайский край, Бийск, Майская, 16	f	large
17885	15494	315	Алтайский край, Бийск, Льнокомбинат, 22	f	large
17843	15461	273	Алтайский край, Бийск, Льва Толстого, 152	f	large
17882	15492	312	Алтайский край, Бийск, Луговая, 99а	f	large
17907	15508	337	Алтайский край, Бийск, Липового, 74/3	f	large
17904	15508	334	Алтайский край, Бийск, Липового, 74/3	f	large
17886	15496	316	Алтайский край, Бийск, Лермонтова, 201	f	large
17921	15522	351	Алтайский край, Бийск, Ленинградская, 53	f	large
17851	15462	281	Алтайский край, Бийск, Ленина, 139	f	large
17844	15462	274	Алтайский край, Бийск, Ленина, 139	f	large
17858	15472	288	Алтайский край, Бийск, Л.Толстого, 108	f	large
17838	15456	268	Алтайский край, Бийск, Кулундинская, 19	f	large
17840	15458	270	Алтайский край, Бийск, Куйбышева, 106	f	medium
17873	15485	303	Алтайский край, город Бийск, Крылова, 32	f	large
17876	15487	306	Алтайский край, Бийск, Красноярский, 87	f	large
17875	15486	305	Алтайский край, Бийск, Красильникова, 152	f	large
17874	15486	304	Алтайский край, Бийск, Красильникова, 152	f	large
17859	15473	289	Алтайский край, Бийск, Короленко, 53	f	large
17854	15470	284	Алтайский край, Бийск, Короленко, 47/2	f	large
17863	15476	293	Алтайский край, Бийск, Железнодорожный, 3	f	large
17839	15457	269	Алтайский край, Бийск, Динамовская, 4	f	large
67899	15525	355	Алтайский край, город Бийск, Декабристов, 1	f	large
17878	15489	308	Алтайский край, Бийск, Горького, 212	f	large
17912	15515	342	Алтайский край, Бийск, Горно-Алтайская, 60	f	large
17915	15514	345	Алтайский край, Бийск, Горно-Алтайская, 56	f	large
17911	15514	341	Алтайский край, Бийск, Горно-Алтайская, 56	f	large
17905	15509	335	Алтайский край, Бийск, Горно-Алтайская, 52	f	large
17934	15532	364	Алтайский край, Бийск, Гайдара, 5	f	large
17887	15466	317	Алтайский край, Бийск, Волочаевская, 6	f	large
17849	15466	279	Алтайский край, Бийск, Волочаевская, 6	f	large
17902	15506	332	Алтайский край, Бийск, Воинов-Интернационалистов, 76	f	large
17916	15517	346	Алтайский край, Бийск, Васильева, 52	f	large
17910	15513	340	Алтайский край, Бийск, Васильева, 61/1	f	large
17864	15477	294	Алтайский край, город Бийск, Вали Максимовой, 91а	f	large
17891	15474	321	Алтайский край, Бийск, Вали Максимовой, 13	f	medium
17861	15474	291	Алтайский край, Бийск, Вали Максимовой, 13	f	large
17860	15474	290	Алтайский край, Бийск, Вали Максимовой, 13	f	large
17865	15478	295	Алтайский край, Бийск, Вагонная, 65	f	large
17913	15516	343	Алтайский край, Бийск, 8 Марта, 16	f	large
17888	15497	318	Алтайский край, Бийск, 3-я Мало-Угреневская, 18	f	large
17825	15447	254	Алтайский край, Белокуриха, Академика Мясникова, 25	f	large
17735	15370	163	Алтайский край, Барнаул, 38	f	large
67890	15287	16	Россия, Алтайский край, Барнаул, улица Шевченко, 158	f	large
17612	15307	40	Россия, Алтайский край, Барнаул, улица Советской Армии, 54а	f	large
17611	15307	39	Россия, Алтайский край, Барнаул, улица Советской Армии, 54а	f	large
17705	15355	133	Россия, Алтайский край, Барнаул, улица Попова, 66	f	large
17704	15355	132	Россия, Алтайский край, Барнаул, улица Попова, 66	f	large
17703	15355	131	Россия, Алтайский край, Барнаул, улица Попова, 66	f	large
17757	15387	186	Россия, Алтайский край, Барнаул, улица Петра Сухова, 11	f	large
17756	15387	185	Россия, Алтайский край, Барнаул, улица Петра Сухова, 11	f	large
67904	15425	230	Россия, Алтайский край, Барнаул, Центральный район, улица Мамонтова, 218а	f	large
17609	15305	37	Россия, Алтайский край, Барнаул, улица Зеленая Роща, 1	f	large
17723	15363	151	Россия, Алтайский край, Барнаул, улица Гущина, 189	f	large
17722	15363	150	Россия, Алтайский край, Барнаул, улица Гущина, 189	f	large
17710	15357	138	Россия, Алтайский край, Барнаул, улица Георгия Исакова, 206	f	large
17709	15357	137	Россия, Алтайский край, Барнаул, улица Георгия Исакова, 206	f	large
17618	15310	46	Россия, Алтайский край, Барнаул, улица Георгия Исакова, 120а	f	large
17617	15310	45	Россия, Алтайский край, Барнаул, улица Георгия Исакова, 120а	f	large
17616	15310	44	Россия, Алтайский край, Барнаул, улица Георгия Исакова, 120а	f	large
67886	16979	1871	Россия, Алтайский край	f	large
4466	26242	737	Республика Бурятия, городской округ Улан-Удэ, проспект Строителей, 16	f	large
4464	26240	735	Республика Бурятия, городской округ Улан-Удэ, проспект Строителей, 60	f	large
4463	26239	734	Республика Бурятия, городской округ Улан-Удэ, проспект Строителей, 72	f	large
17780	15406	209	Алтайский край, Барнаул, проспект Ленина, 38	f	large
17742	15378	171	Алтайский край, Барнаул, проспект Ленина, 68	f	large
17604	15302	32	Россия, Алтайский край, Барнаул, проспект Ленина, 145	f	large
17603	15301	31	Россия, Алтайский край, Барнаул, проспект Ленина, 148	f	large
17599	15297	27	Россия, Алтайский край, Барнаул, проспект Ленина, 89	f	large
17598	15296	26	Алтайский край, Барнаул, проспект Ленина, 69	f	medium
17770	15398	199	Россия, Алтайский край, Барнаул, проспект Космонавтов, 23	f	large
17613	15306	41	Россия, Алтайский край, Барнаул, проспект Коммунаров, 100	f	large
17610	15306	38	Россия, Алтайский край, Барнаул, проспект Коммунаров, 100	f	large
17812	15434	241	Алтайский край, Барнаул, просп.Дзержинского, 27	f	large
18136	15713	566	Россия, Алтайский край, Барнаул, площадь Победы, 1	f	large
17786	15411	215	Россия, Алтайский край, Барнаул, переулок Ядринцева, 76	f	large
4389	26181	660	Республика Бурятия, городской округ Улан-Удэ, Радищева, 5	f	large
4388	26181	659	Республика Бурятия, городской округ Улан-Удэ, Радищева, 5	f	large
17797	15421	226	Россия, Алтайский край, Барнаул, переулок Некрасова, 18	f	large
17778	15404	207	Россия, Алтайский край, Барнаул, переулок Некрасова, 65	f	large
17747	15381	176	Россия, Алтайский край, Барнаул, бульвар 9 Января, 99	f	large
17746	15381	175	Россия, Алтайский край, Барнаул, бульвар 9 Января, 99	f	large
17721	15362	149	Алтайский край, Барнаул, Юрина, 220	f	large
17720	15362	148	Алтайский край, Барнаул, Юрина, 220	f	large
17724	15360	152	Алтайский край, Барнаул, Юрина, 196	f	large
17716	15360	144	Алтайский край, Барнаул, Юрина, 196	f	large
17715	15360	143	Алтайский край, Барнаул, Юрина, 196	f	large
17714	15359	142	Алтайский край, Барнаул, Юрина, 203	f	large
17713	15359	141	Алтайский край, Барнаул, Юрина, 203	f	large
17712	15358	140	Алтайский край, Барнаул, Юрина, 239	f	large
17711	15358	139	Алтайский край, Барнаул, Юрина, 239	f	large
17708	15356	136	Алтайский край, Барнаул, Юрина, 287	f	large
17707	15356	135	Алтайский край, Барнаул, Юрина, 287	f	large
17706	15356	134	Алтайский край, Барнаул, Юрина, 287	f	large
67896	16989	1914	Алтайский край, Барнаул, Энтузиастов, 34	f	large
67889	16989	1890	Алтайский край, Барнаул, Энтузиастов, 34	f	large
17683	15345	111	Алтайский край, Барнаул, Энтузиастов, 26	f	large
17682	15345	110	Алтайский край, Барнаул, Энтузиастов, 26	f	large
17681	15345	109	Алтайский край, Барнаул, Энтузиастов, 26	f	large
17666	15339	94	Алтайский край, Барнаул, Энтузиастов, 5	f	large
17732	15367	160	Алтайский край, Барнаул, Эмилии Алексеевой, 84	f	large
17731	15366	159	Алтайский край, Барнаул, Эмилии Алексеевой, 60	f	large
17763	15392	192	Алтайский край, Барнаул, Э.Алексеевой, 56	f	large
19423	15334	1911	Алтайский край, Барнаул, Шумакова, 22	f	large
17655	15334	83	Алтайский край, Барнаул, Шумакова, 22	f	large
17654	15334	82	Алтайский край, Барнаул, Шумакова, 22	f	large
17653	15334	81	Алтайский край, Барнаул, Шумакова, 22	f	large
17652	15334	80	Алтайский край, Барнаул, Шумакова, 22	f	large
17699	15353	127	Алтайский край, Барнаул, Шукшина, 30	f	large
17698	15353	126	Алтайский край, Барнаул, Шукшина, 30	f	large
17697	15353	125	Алтайский край, Барнаул, Шукшина, 30	f	large
17696	15352	124	Алтайский край, Барнаул, Шукшина, 29/258	f	large
17695	15352	123	Алтайский край, Барнаул, Шукшина, 29/258	f	large
19296	16881	1771	Россия, Алтайский край, Барнаул, Октябрьский район, микрорайон ВРЗ, Школьная улица, 6	t	small
17818	15440	247	Алтайский край, Барнаул, Школьная, 65	f	large
17734	15369	162	Алтайский край, Барнаул, поселок Гоньба, Школьная, 12	f	large
19404	16988	1885	Алтайский край, Барнаул, Школьная, 18	f	medium
17761	15390	190	Алтайский край, Барнаул, Чудненко, 62	f	large
17760	15390	189	Алтайский край, Барнаул, Чудненко, 62	f	large
17791	15415	220	Алтайский край, Барнаул, Чкалова, 194	f	large
17782	15408	211	Алтайский край, Барнаул, Чкалова, 68	f	large
17606	15303	34	Алтайский край, Барнаул, Червонная, 9	f	large
17605	15303	33	Алтайский край, Барнаул, Червонная, 9	f	large
17602	15300	30	Алтайский край, Барнаул, Червонная, 8	f	large
17814	15436	243	Алтайский край, Барнаул, Чайковского, 8	f	large
17811	15430	240	Алтайский край, Барнаул, поселок Южный, Чайковского, 21	f	large
17807	15430	236	Алтайский край, Барнаул, поселок Южный, Чайковского, 21	f	large
17813	15435	242	Алтайский край, Барнаул, Чайковского, 22	f	large
17808	15431	237	Алтайский край, Барнаул, Чайковского, 31	f	large
17647	15331	75	Алтайский край, Барнаул, Центральная, 25	f	medium
19227	16811	1702	Алтайский край, Барнаул, Центральная, 47е	f	large
17736	15371	164	Алтайский край, Барнаул, поселок Казенная Заимка, Цветущая, 1	f	large
17629	15318	57	Алтайский край, Барнаул, Фурманова, 14	f	large
17628	15317	56	Алтайский край, Барнаул, Фурманова, 12	f	large
19405	15427	1886	Алтайский край, Барнаул, Фомина, 130	f	large
17804	15427	233	Алтайский край, Барнаул, Фомина, 130	f	large
17769	15397	198	Алтайский край, Барнаул, Тимуровская, 33	f	large
17768	15397	197	Алтайский край, Барнаул, Тимуровская, 33	f	large
17765	15394	194	Алтайский край, Барнаул, Тимуровская, 23	f	large
17764	15393	193	Алтайский край, Барнаул, Тимуровская, 15	f	large
17619	15311	47	Россия, Алтайский край, Барнаул, Телефонная улица, 50а	f	large
17752	15384	181	Алтайский край, Барнаул, Союза Республик, 36а	f	large
17781	15407	210	Россия, Алтайский край, Барнаул, Социалистический проспект, 68	f	large
17597	15295	25	Россия, Алтайский край, Барнаул, Социалистический проспект, 126	f	large
17596	15295	24	Россия, Алтайский край, Барнаул, Социалистический проспект, 126	f	large
17595	15294	23	Россия, Алтайский край, Барнаул, Социалистический проспект, 126б	f	large
19410	15332	1891	Алтайский край, Барнаул, Соловьиная, 45	f	large
17648	15332	76	Алтайский край, Барнаул, Соловьиная, 45	f	large
17702	15354	130	Алтайский край, Барнаул, Солнечная Поляна, 11	f	large
17701	15354	129	Алтайский край, Барнаул, Солнечная Поляна, 11	f	large
17700	15354	128	Алтайский край, Барнаул, Солнечная Поляна, 11	f	large
19401	15346	1881	Алтайский край, Барнаул, Солнечная Поляна, 51	f	large
17685	15346	113	Алтайский край, Барнаул, Солнечная Поляна, 51	f	large
17684	15346	112	Алтайский край, Барнаул, Солнечная Поляна, 51	f	large
17627	15316	55	Алтайский край, Барнаул, Советской Армии, 73	f	large
17744	15379	173	Россия, Алтайский край, Барнаул, Смольная улица, 46	f	large
17743	15379	172	Россия, Алтайский край, Барнаул, Смольная улица, 46	f	large
17608	15304	36	Россия, Алтайский край, Барнаул, Северо-Западная улица, 37	f	large
17607	15304	35	Россия, Алтайский край, Барнаул, Северо-Западная улица, 37	f	large
19425	15336	1913	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 34	f	large
19419	15336	1901	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 34	f	large
19424	15336	1912	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 34	f	large
17660	15336	88	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 34	f	large
17659	15336	87	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 34	f	large
19407	15335	1888	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 64	f	large
17658	15335	86	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 64	f	large
17657	15335	85	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 64	f	large
17656	15335	84	Россия, Алтайский край, Барнаул, Северный Власихинский проезд, 64	f	large
17645	15329	73	Россия, Алтайский край, Барнаул, село Власиха, Ракитная улица, 2	f	large
17815	15437	244	Алтайский край, Барнаул, Радужная, 97	f	large
17741	15377	170	Алтайский край, Барнаул, Путиловская, 51	f	large
17751	15383	180	Алтайский край, Барнаул, Профинтерна, 32а	f	large
17749	15383	178	Алтайский край, Барнаул, Профинтерна, 32а	f	large
17750	15382	179	Алтайский край, Барнаул, Профинтерна, 53а	f	large
17748	15382	177	Алтайский край, Барнаул, Профинтерна, 53а	f	large
17792	15416	221	Алтайский край, Барнаул, Пролетарская, 224	f	large
17762	15391	191	Алтайский край, Барнаул, Петра Сухова, 71	f	large
19418	15328	1900	Алтайский край, Барнаул, село Власиха, Первомайская, 50	f	large
17644	15328	72	Алтайский край, Барнаул, село Власиха, Первомайская, 50	f	large
17790	15414	219	Россия, Алтайский край, Барнаул, Партизанская улица, 195	f	large
17789	15414	218	Россия, Алтайский край, Барнаул, Партизанская улица, 195	f	large
17678	15343	106	Алтайский край, Барнаул, Панфиловцев, 8	f	large
17677	15343	105	Алтайский край, Барнаул, Панфиловцев, 8	f	large
17676	15343	104	Алтайский край, Барнаул, Панфиловцев, 8	f	large
17675	15342	103	Алтайский край, Барнаул, Панфиловцев, 13	f	large
17674	15342	102	Алтайский край, Барнаул, Панфиловцев, 13	f	large
17673	15342	101	Алтайский край, Барнаул, Панфиловцев, 13	f	large
17665	15338	93	Алтайский край, Барнаул, Павловский тракт, 100	f	large
17664	15338	92	Алтайский край, Барнаул, Павловский тракт, 100	f	large
17663	15338	91	Алтайский край, Барнаул, Павловский тракт, 100	f	large
17662	15337	90	Россия, Алтайский край, Барнаул, Павловский тракт, 112а	f	large
17661	15337	89	Россия, Алтайский край, Барнаул, Павловский тракт, 112а	f	large
67895	15322	1910	Россия, Алтайский край, Барнаул, Павловский тракт, 68а	f	large
67882	15322	64	Россия, Алтайский край, Барнаул, Павловский тракт, 68а	f	large
17635	15321	63	Россия, Алтайский край, Барнаул, Павловский тракт, 68	f	large
17634	15321	62	Россия, Алтайский край, Барнаул, Павловский тракт, 68	f	large
17633	15321	61	Россия, Алтайский край, Барнаул, Павловский тракт, 68	f	large
17817	15439	246	Алтайский край, Барнаул, Опытная станция, 20	f	large
17641	15325	69	Алтайский край, Барнаул, Новосибирская улица, 8Б	f	large
17640	15325	68	Алтайский край, Барнаул, Новосибирская улица, 8Б	f	large
17643	15327	71	Алтайский край, Барнаул, поселок Пригородный, Новосибирская, 44	f	large
19406	15432	1887	Алтайский край, Барнаул, Мусоргского, 38	f	large
17809	15432	238	Алтайский край, Барнаул, Мусоргского, 38	f	large
17730	15365	158	Алтайский край, Барнаул, Монтажников, 14	f	large
17729	15365	157	Алтайский край, Барнаул, Монтажников, 14	f	large
17728	15365	156	Алтайский край, Барнаул, Монтажников, 14	f	large
17591	15290	19	Россия, Алтайский край, Барнаул, Железнодорожный район, Молодежная улица, 51	f	large
17589	15288	17	Алтайский край, Барнаул, Молодежная, 55	f	large
17819	15441	248	Алтайский край, Барнаул, Мира, 13	f	large
17773	15399	202	Алтайский край, Барнаул, Маяковского, 25	f	medium
17772	15399	201	Алтайский край, Барнаул, Маяковского, 25	f	large
17771	15399	200	Алтайский край, Барнаул, Маяковского, 25	f	large
17816	15438	245	Алтайский край, Барнаул, Матросская улица, 94	f	large
19400	16985	1880	Алтайский край, Барнаул, Малахова, 175	f	medium
17767	15396	196	Алтайский край, Барнаул, Малахова, 21	f	large
17766	15396	195	Алтайский край, Барнаул, Малахова, 21	f	large
17646	15330	74	Алтайский край, Барнаул, Лесной поселок, 12	f	small
17680	15344	108	Алтайский край, Барнаул, Ленинградская, 8	f	large
17679	15344	107	Алтайский край, Барнаул, Ленинградская, 8	f	large
17795	15418	224	Алтайский край, Барнаул, Кутузова, 18	f	large
17794	15418	223	Алтайский край, Барнаул, Кутузова, 18	f	large
17637	15323	65	Алтайский край, Барнаул, Куета, 29	f	medium
17783	15409	212	Россия, Алтайский край, Барнаул, Красноармейский проспект, 62	f	large
17594	15293	22	Россия, Алтайский край, Барнаул, Красноармейский проспект, 110	f	large
17593	15292	21	Россия, Алтайский край, Барнаул, Красноармейский проспект, 98	f	large
17630	15291	58	Россия, Алтайский край, Барнаул, Красноармейский проспект, 133	f	large
17592	15291	20	Россия, Алтайский край, Барнаул, Красноармейский проспект, 133	f	large
17590	15289	18	Россия, Алтайский край, Барнаул, Красноармейский проспект, 94	f	large
17798	15422	227	Алтайский край, Барнаул, Короленко, 80	f	large
17796	15419	225	Алтайский край, Барнаул, Короленко, 13	f	large
17779	15405	208	Россия, Алтайский край, Барнаул, Комсомольский проспект, 80	f	large
17740	15376	169	Алтайский край, Барнаул, Комсомольский проспект, 71	f	large
17788	15413	217	Алтайский край, Барнаул, Интернациональная, 80	f	large
67903	15412	216	Алтайский край, Барнаул, Интернациональная, 80	f	large
17806	15429	235	Россия, Алтайский край, Барнаул, Змеиногорский тракт, 89	f	large
17805	15428	234	Россия, Алтайский край, Барнаул, Змеиногорский тракт, 49	f	large
17810	15433	239	Алтайский край, Барнаул, поселок Садоводов, Змеиногорский тракт, 118	f	large
17600	15298	28	Россия, Алтайский край, Барнаул, Деповская улица, 32	f	large
67881	15299	29	Алтайский край, Барнаул, Деповская, 32	f	large
17727	15364	155	Алтайский край, Барнаул, Гущина, 158	f	large
17726	15364	154	Алтайский край, Барнаул, Гущина, 158	f	large
17725	15364	153	Алтайский край, Барнаул, Гущина, 158	f	large
17719	15361	147	Алтайский край, Барнаул, Гущина, 177	f	large
17718	15361	146	Алтайский край, Барнаул, Гущина, 177	f	large
17717	15361	145	Алтайский край, Барнаул, Гущина, 177	f	large
17758	15388	187	Алтайский край, Барнаул, Горно-Алтайская улица, 17	f	large
17755	15385	184	Россия, Алтайский край, Барнаул, Горно-Алтайская улица, 7	f	large
17753	15385	182	Россия, Алтайский край, Барнаул, Горно-Алтайская улица, 7	f	large
17754	15386	183	Алтайский край, Барнаул, Горно-Алтайская, 20	f	large
17691	15350	119	Алтайский край, Барнаул, Георгия Исакова, 195	f	large
17690	15350	118	Алтайский край, Барнаул, Георгия Исакова, 195	f	large
17689	15350	117	Алтайский край, Барнаул, Георгия Исакова, 195	f	large
17622	15313	50	Алтайский край, Барнаул, Георгия Исакова, 138	f	large
17621	15313	49	Алтайский край, Барнаул, Георгия Исакова, 138	f	large
17620	15312	48	Алтайский край, Барнаул, Георгия Исакова, 113а	f	large
17615	15309	43	Алтайский край, Барнаул, Воронежская, 2	f	large
17614	15309	42	Алтайский край, Барнаул, Воронежская, 2	f	large
17745	15380	174	Алтайский край, Барнаул, Водопроводная, 87	f	large
17651	15333	79	Алтайский край, Барнаул, Взлетная, 28	f	large
17650	15333	78	Алтайский край, Барнаул, Взлетная, 28	f	large
17649	15333	77	Алтайский край, Барнаул, Взлетная, 28	f	large
18408	15989	844	Россия, Алтайский край, Барнаул, Боровая улица, 6	f	small
17639	15324	67	Алтайский край, Барнаул, Благовещенская, 11	f	large
17638	15324	66	Алтайский край, Барнаул, Благовещенская, 11	f	large
17694	15351	122	Алтайский край, Барнаул, Антона Петрова, 218	f	large
17693	15351	121	Алтайский край, Барнаул, Антона Петрова, 218	f	large
17692	15351	120	Алтайский край, Барнаул, Антона Петрова, 218	f	large
17688	15349	116	Алтайский край, Барнаул, Антона Петрова, 150	f	large
17687	15349	115	Алтайский край, Барнаул, Антона Петрова, 150	f	large
17686	15347	114	Алтайский край, Барнаул, Антона Петрова, 146г	f	large
17626	15315	54	Алтайский край, Барнаул, Антона Петрова, 112	f	large
17625	15314	53	Алтайский край, Барнаул, Антона Петрова, 130	f	large
17624	15314	52	Алтайский край, Барнаул, Антона Петрова, 130	f	large
17623	15314	51	Алтайский край, Барнаул, Антона Петрова, 130	f	large
17800	15424	229	Алтайский край, Барнаул, Анатолия, 193	f	large
17793	15417	222	Алтайский край, Барнаул, Анатолия, 304	f	large
17803	15426	232	Алтайский край, Барнаул, Аванесова, 132	f	large
17802	15423	231	Алтайский край, Барнаул, Аванесова, 134	f	large
17799	15423	228	Алтайский край, Барнаул, Аванесова, 134	f	large
17733	15368	161	Россия, Алтайский край, Барнаул, 9-й Заводской проезд, 40	f	medium
17759	15389	188	Алтайский край, Барнаул, 80 Гвардейской Дивизии, 41	f	large
17672	15341	100	Алтайский край, Барнаул, 50 лет СССР, 10	f	large
17671	15341	99	Алтайский край, Барнаул, 50 лет СССР, 10	f	large
17670	15341	98	Алтайский край, Барнаул, 50 лет СССР, 10	f	large
17669	15340	97	Алтайский край, Барнаул, 50 лет СССР, 53	f	large
17668	15340	96	Алтайский край, Барнаул, 50 лет СССР, 53	f	large
17667	15340	95	Алтайский край, Барнаул, 50 лет СССР, 53	f	large
17632	15320	60	Алтайский край, Барнаул, 42 Краснознаменной Бригады, 8	f	large
19408	15319	1889	Алтайский край, Барнаул, 42 Краснознаменной Бригады, 8	f	large
17631	15319	59	Алтайский край, Барнаул, 42 Краснознаменной Бригады, 8	f	large
17785	15410	214	Алтайский край, Барнаул, Папанинцев, 115	f	large
17784	15410	213	Алтайский край, Барнаул, Папанинцев, 115	f	large
18148	15725	579	Алтайский край, поселок Баево, Терешковой, 25	f	large
18125	15702	555	Алтайский край, Алтайское, Карла Маркса, 51	f	large
67897	15280	9	Алтайский край, Алейск, пер.Пляжный, 4	f	large
17574	15274	2	Алтайский край, Алейск, Энергетиков, 5	f	medium
17575	15275	3	Алтайский край, Алейск, Школьная, 23	f	large
17587	15286	15	Алтайский край, Алейск, Ширшова, 14	f	large
17586	15285	14	Алтайский край, Алейск, Ширшова, 12	f	large
17583	15282	11	Алтайский край, Алейск, Ульяновский, 94	f	large
17579	15279	7	Алтайский край, Алейск, Ульяновский, 5	f	large
17577	15277	5	Алтайский край, Алейск, Первомайская, 2	f	large
17580	15256	8	Алтайский край, Алейск, Первомайская, 84	f	large
17582	15281	10	Алтайский край, Алейск, Партизанская, 92	f	large
17578	15278	6	Алтайский край, Алейск, Комсомольская, 18	f	large
17584	15283	12	Алтайский край, Алейск, Дорожная, 6а	f	medium
17576	15276	4	Алтайский край, Алейск, Давыдова, 185	f	large
17573	15273	1	Алтайский край, Алейск, Ветеранов, 8	f	large
109240	15903	758	Алтайский край, поселок Аламбай, Ленина, 30	t	medium
19363	16949	1841	Алтайский край, Шипуновский район, поселок Эстония, Мира, 23а	t	small
19387	16973	1865	Алтайский край, Шипуновский район, поселок Шипуново, Южный, 35	f	large
19379	16965	1857	Алтайский край, Шипуновский район, Шипуново, Школьная, 24	f	medium
19386	16972	1864	Алтайский край, Шипуновский район, поселок Шипуново, Целинная, 25	f	medium
19385	16971	1863	Алтайский край, Шипуновский район, поселок Шипуново, Совхозный, 37	f	large
19389	16975	1867	Алтайский край, Шипуновский район, поселок Шипуново, Мостовая, 13	f	medium
19388	16974	1866	Алтайский край, Шипуновский район, поселок Шипуново, Луначарского, 76	f	large
19384	16970	1862	Алтайский край, Шипуновский район, поселок Хлопуново, Мамонтова, 16	f	medium
19359	16945	1837	Алтайский край, Шипуновский район, поселок Усть-Порозиха, Центральная, 13	f	small
19383	16969	1861	Алтайский край, Шипуновский район, поселок Урлапово, Фрунзе, 15	f	medium
19381	16967	1859	Алтайский край, Шипуновский район, поселок Тугозвоново, Ползунова, 1	f	large
19380	16966	1858	Алтайский край, Шипуновский район, поселок Самсоново, Октябрьская, 16	f	medium
19378	16964	1856	Алтайский край, Шипуновский район, поселок Родино, Мамонтовская, 10	f	large
19377	16963	1855	Алтайский край, Шипуновский район, село Порожнее, Центральная, 1	f	medium
19376	16962	1854	Алтайский край, Шипуновский район, поселок Первомайское, Тарасова, 36	f	medium
19362	16948	1840	Алтайский край, Шипуновский район, поселок Озерки, Сергея Качусова, 3	f	small
19371	16957	1849	Алтайский край, Шипуновский район, поселок Новый Путь, Весенняя, 15	f	small
19382	16968	1860	Алтайский край, Шипуновский район, поселок Новосельское, Целинная, 1а	t	small
19375	16961	1853	Алтайский край, Шипуновский район, поселок Новоивановка, Советская, 38	f	small
19374	16960	1852	Алтайский край, Шипуновский район, поселок Нечунаево, 1-е Черемушки, 15	f	medium
19354	16939	1832	Алтайский край, Шипуновский район, поселок Метели, Майская, 26	f	small
19372	16958	1850	Алтайский край, Шипуновский район, поселок Кузнечиха, Новая, 10	f	small
19370	16956	1848	Алтайский край, Шипуновский район, поселок Красный Яр, Садовая, 40	f	medium
19358	16944	1836	Алтайский край, Шипуновский район, поселок Кособоково, Центральная, 6а	f	small
19365	16951	1843	Алтайский край, Шипуновский район, поселок Коробейниково, Школьная, 3	t	small
19369	16955	1847	Алтайский край, Шипуновский район, поселок Комариха, Дубинина, 16	f	medium
19373	16959	1851	Алтайский край, Шипуновский район, поселок Качусово, Школьная, 28	f	small
19368	16954	1846	Алтайский край, Шипуновский район, поселок Ильинка, Школьный, 4	f	small
19364	16950	1842	Алтайский край, Шипуновский район, поселок Зеркалы, Центральная, 3	f	medium
67892	15860	713	Алтайский край, Шипуновский район, поселок Ельцовка, им.Рыжакова, 24	f	large
19361	16947	1839	Алтайский край, Шипуновский район, поселок Ельцовка, Советская, 42	f	medium
19360	16946	1838	Алтайский край, Шипуновский район, поселок Горьковское (Осинники), Октябрьская, 40	f	large
18819	16406	1270	Алтайский край, Шипуновский район, поселок Гавриловский, Молодёжная, 13	f	small
19357	16943	1835	Алтайский край, Шипуновский район, поселок Воробьево, Центральная, 27	t	small
19356	16941	1834	Алтайский край, Шипуновский район, поселок Быково, Главный, 3	f	medium
19355	16940	1833	Алтайский край, Шипуновский район, поселок Бобровка, Молодежная , 26	f	medium
19367	16953	1845	Алтайский край, Шипуновский район, поселок Бестужево, Набережная, 28а	f	small
19353	16938	1831	Алтайский край, Шипуновский район, поселок Белоглазово, Комарова, 30	f	medium
19352	16937	1830	Алтайский край, Шипуновский район, поселок Баталово, Рукина, 16	f	small
19366	16952	1844	Алтайский край, Шипуновский район, поселок Андреевка, Центральная, 24	f	small
19337	16922	1815	Алтайский край, Шелаболихинский район, поселок Шелаболиха, Пушкина, 37	f	large
19336	16921	1814	Алтайский край, Шелаболихинский район, поселок Шелаболиха, Ленина, 27	f	large
19351	16936	1829	Алтайский край, Шелаболихинский район, поселок Чайкино, Набережная, 4	f	small
19347	16932	1825	Алтайский край, Шелаболихинский район, поселок Селезнево, Советская, 20	f	small
19350	16935	1828	Алтайский край, Шелаболихинский район, поселок Подгорный, Школьная улица, 38	f	small
19346	16931	1824	Алтайский край, Шелаболихинский район, поселок Омутское, Цветочная, 16а	f	small
19338	16923	1816	Алтайский край, Шелаболихинский район, село Новообинцево, Садовая, 40	f	medium
86041	16929	1822	Алтайский край, Шелаболихинский район, поселок Макарово, Орловская, 11	f	small
19340	16925	1818	Алтайский край, Шелаболихинский район, поселок Кучук, Михайлова, 40	f	medium
19349	16934	1827	Алтайский край, Шелаболихинский район, поселок Крутишка, Совхозная, 2	f	medium
19348	16933	1826	Алтайский край, Шелаболихинский район, поселок Киприно, Советская, 30	f	large
19339	16924	1817	Алтайский край, Шелаболихинский район, село Иня, Нагорная, 7	t	small
19345	16930	1823	Алтайский край, Шелаболихинский район, поселок Ильинка, Школьная, 19	f	medium
19343	16928	1821	Алтайский край, Шелаболихинский район, поселок Ивановка, пер. Клубный, 5	f	small
19342	16927	1820	Алтайский край, Шелаболихинский район, поселок Верх-Кучук, Центральная, 32	f	medium
19341	16926	1819	Алтайский край, Шелаболихинский район, поселок Батурово, Новая, 16	f	small
19326	16911	1802	Алтайский край, Чарышский район, с.Первомайское, Кузнечная, 8	f	small
19323	16908	1799	Алтайский край, Чарышский район, поселок Щебнюха, Центральная, 7	t	small
19318	16903	1794	Алтайский край, Чарышский район, поселок Чарышское, Центральная, 31	f	large
19330	16915	1806	Алтайский край, Чарышский район, поселок Чайное, Сосновская, 16	t	small
19316	16901	1792	Алтайский край, Чарышский район, поселок Усть-Тулатинка, Центральная, 46	f	small
19335	16920	1811	Алтайский край, Чарышский район, село Усть-Пихтовка, Садовая, 14	t	small
19314	16899	1790	Алтайский край, Чарышский район, поселок Тулата, Центральная, 24	f	medium
19328	16913	1804	Алтайский край, Чарышский район, поселок Сосновка, Лиственная, 12	t	small
19308	16893	1784	Алтайский край, Чарышский район, поселок Сентелек, Центральная, 48	f	medium
19310	16895	1786	Алтайский край, Чарышский район, поселок Покровка, Рабочая, 2	t	small
19324	16909	1800	Алтайский край, Чарышский район, поселок Озерки, Коммунистическая, 24	f	small
19327	16912	1803	Алтайский край, Чарышский район, поселок Маяк, Советская, 5	f	small
19309	16894	1785	Алтайский край, Чарышский район, поселок Машенка, Мараловодов, 5/1	t	small
19333	16918	1809	Алтайский край, Чарышский район, поселок Маральи Рожки, Луговая, 59	f	small
19331	16916	1807	Алтайский край, Чарышский район, поселок Маралиха, Центральная, 59	f	medium
19319	94922	1795	Алтайский край, Чарышский район, поселок Малый Бащелак, Центральная, 43	f	medium
19334	16919	1810	Алтайский край, Чарышский район, поселок Малая Маралиха, Лесная, 11, кв.2	t	small
19311	16896	1787	Алтайский край, Чарышский район, поселок Майорка, Центральная, 15	t	small
19317	16902	1793	Алтайский край, Чарышский район, поселок Красный Партизан, Центральная, 30	f	large
86111	16914	1805	Алтайский край, Чарышский район, поселок Красные Орлы, Речная, 29	t	small
19313	16898	1789	Алтайский край, Чарышский район, поселок Комендантка, Центральная, 32	t	small
19320	16905	1796	Алтайский край, Чарышский район, поселок Ивановка, Центральная, 15	t	small
19315	16900	1791	Алтайский край, Чарышский район, поселок Долинское, Центральная, 26	f	small
86110	16906	1797	Алтайский край, Чарышский район, поселок Боровлянка, Центральная, 24/2	t	small
19322	16907	1798	Алтайский край, Чарышский район, поселок Большой Бащелак, Подгорная, 1	t	small
19169	16751	1643	Алтайский край, Чарышский район, село Большая Речка, переулок Клубный, 7А	f	small
19312	16897	1788	Алтайский край, Чарышский район, поселок Березовка, Центральная, 27	f	medium
19325	16910	1801	Алтайский край, Чарышский район, поселок Алексеевка, Центральная, 19	f	small
19307	16892	1783	Алтайский край, Чарышский район, поселок Аба, Набережная, 4а	t	small
109274	16877	1767	Алтайский край, Целинный район, поселок Шалап, Ленина, 4а	f	medium
19302	16887	1777	Алтайский край, Целинный район, поселок Чесноково, Первомайская, 6	t	small
19286	16871	1761	Алтайский край, Целинный район, поселок Целинное, Советская, 25	f	large
19287	16872	1762	Алтайский край, Целинный район, поселок Целинное, Победы, 5	f	large
19288	16873	1763	Алтайский край, Целинный район, поселок Целинное, Ленина, 52	f	large
19290	16875	1765	Алтайский край, Целинный район, поселок Хомутино, Зеленая, 21	f	small
19304	16889	1779	Алтайский край, Целинный район, поселок Сухая Чемровка, Молодежная, 6	f	medium
19305	16890	1780	Алтайский край, Целинный район, поселок Сверчково, Советская, 3	t	small
19300	16885	1775	Алтайский край, Целинный район, поселок Поповичи, Центральная, 22	f	small
19301	16886	1776	Алтайский край, Целинный район, поселок Победа, Ленина, 5	f	medium
19298	16883	1773	Алтайский край, Целинный район, поселок Овсянниково, Школьная, 19	f	medium
19297	16882	1772	Алтайский край, Целинный район, поселок Марушка, Советская, 18	f	medium
19299	16884	1774	Алтайский край, Целинный район, поселок Локоть, Лесная, 10	t	small
19303	16888	1778	Алтайский край, Целинный район, поселок Ложкино, Советская, 22а	f	medium
19294	16879	1769	Алтайский край, Целинный район, поселок Еланда, Коммунистическая, 14	f	medium
19295	16880	1770	Алтайский край, Целинный район, поселок Дружба, Центральная, 21	f	medium
19293	16878	1768	Алтайский край, Целинный район, поселок Воеводское, пер.Магистральный, 6	f	large
19306	16891	1781	Алтайский край, Целинный район, поселок Верх-Яминское, Бийская, 5	t	small
19289	16874	1764	Алтайский край, Целинный район, поселок Верх-Марушка, Центральная, 13	f	medium
19291	16876	1766	Алтайский край, Целинный район, поселок Бочкари, Пушкина, 1	f	large
19267	16852	1742	Алтайский край, Хабарский район, поселок Хабары, Южная, 2А	f	medium
19268	16853	1743	Алтайский край, Хабарский район, поселок Хабары, Ленина, 93	f	medium
19265	16850	1740	Алтайский край, Хабарский район, поселок Хабары, Ленина, 57	f	large
19266	16851	1741	Алтайский край, Хабарский район, поселок Хабары, Кайгородова, 1	f	large
19269	16854	1744	Алтайский край, Хабарский район, поселок Утянка, Гагарина, 14А	f	medium
19284	16869	1759	Алтайский край, Хабарский район, поселок Усть-Курья, Молодежная, 11А	f	small
19273	16858	1748	Алтайский край, Хабарский район, поселок Топольное, Ломоносова, 33	f	small
19276	16861	1751	Алтайский край, Хабарский район, поселок Свердловское, переулок Школьный, 17	f	medium
19274	16859	1749	Алтайский край, Хабарский район, поселок Рассвет, Школьная, 13	f	small
19280	16865	1755	Алтайский край, Хабарский район, поселок Поперечное, Центральная, 152	t	small
18679	16262	1128	Алтайский край, Хабарский район, поселок Полевое, Молодежная, 66А	f	large
5880	32479	1073	республика Дагестан, Махачкала, ГАМИДОВА, 81	f	large
19283	16868	1758	Алтайский край, Хабарский район, поселок Плесо-Курья, Центральная, 4А	f	small
19272	16857	1747	Алтайский край, Хабарский район, поселок Пионер Труда, Черемушки, 20	t	small
18678	16261	1127	Алтайский край, Хабарский район, поселок Орлово, Ленина, 40	f	large
19279	16864	1754	Алтайский край, Хабарский район, поселок Новоплотава, Школьная, 15А	f	small
19270	16855	1745	Алтайский край, Хабарский район, поселок Новоильинка, Славгородская, 33А	f	large
19278	16863	1753	Алтайский край, Хабарский район, поселок Мичуринское, 50 лет Октября, 10	f	medium
19275	16860	1750	Алтайский край, Хабарский район, поселок Мартовка, Ленина, 66	f	medium
19277	16862	1752	Алтайский край, Хабарский район, поселок Малопавловка, Центральная, 37	t	small
18675	16258	1124	Алтайский край, Хабарский район, поселок Красноармейский, Мира, 56	f	small
19285	16870	1760	Алтайский край, Хабарский район, поселок Коротояк, Вокзальная, 14Б	f	large
19281	16866	1756	Алтайский край, Хабарский район, поселок Зятькова Речка, Юбилейная, 16	f	medium
19282	16867	1757	Алтайский край, Хабарский район, поселок Васильевка, пер. Южный, 5	t	small
19271	16856	1746	Алтайский край, Хабарский район, поселок Богатское, Коваленко, 48	t	small
18684	16267	1133	Алтайский край, Хабарский район, поселок Александровка, 44, Немецкий национальный район	f	small
19256	16840	1731	Алтайский край, Усть-Пристанский район, с.Коловый Мыс, Центральная, 13	t	small
19263	16848	1738	Алтайский край, Усть-Пристанский район, поселок Чеканиха, Центральная, 7	t	small
19252	16836	1727	Алтайский край, Усть-Пристанский район, поселок Усть-Чарышская Пристань, Пятилетка, 18	f	large
19251	16835	1726	Алтайский край, Усть-Пристанский район, поселок Усть-Чарышская Пристань, Пушкина, 13	f	large
19253	16837	1728	Алтайский край, Усть-Пристанский район, поселок Усть-Чарышская Пристань, Краснооктябрьская, 35	f	large
19254	16838	1729	Алтайский край, Усть-Пристанский район, поселок Усть-Чарыш, Молодежная, 12	t	small
19258	16842	1733	Алтайский край, Усть-Пристанский район, поселок Усть-Журавлиха, Комсомольская, 1д	f	small
19250	16834	1725	Алтайский край, Усть-Пристанский район, поселок Троицкое (Барчиха), Комсомольская, 17	f	small
19249	16833	1724	Алтайский край, Усть-Пристанский район, поселок Романово, Пушкина, 1	f	small
19259	16843	1734	Алтайский край, Усть-Пристанский район, поселок Нижняя Гусиха, Кирова, 17	f	medium
19261	16846	1736	Алтайский край, Усть-Пристанский район, поселок Нижнеозерное, Юбилейная, 18	f	medium
19257	16841	1732	Алтайский край, Усть-Пристанский район, поселок Красноярка, 50 лет Октября, 1б	f	medium
19262	16847	1737	Алтайский край, Усть-Пристанский район, поселок Краснодарское, Комсомольская, 7	f	small
19260	16844	1735	Алтайский край, Усть-Пристанский район, поселок Коробейниково, Комсомольская, 33а	f	large
19264	16849	1739	Алтайский край, Усть-Пристанский район, поселок Клепиково, Советская, 33	t	small
19255	16839	1730	Алтайский край, Усть-Пристанский район, поселок Елбанка, Новая, 57	f	medium
19247	16831	1722	Алтайский край, Усть-Пристанский район, поселок Вяткино, Целинная, 6	f	medium
19248	16832	1723	Алтайский край, Усть-Пристанский район, поселок Брусенцево, Пушкина, 49	f	medium
19246	16830	1721	Алтайский край, Усть-Пристанский район, поселок Белово, Школьная, 25	f	small
19237	16822	1712	Алтайский край, Усть-Калманский район, поселок Усть-Камышенка, Центральная, 5	f	small
19223	16807	1698	Алтайский край, Усть-Калманский район, поселок Усть-Калманка, Партизанская, 30	f	large
19221	16805	1696	Алтайский край, Усть-Калманский район, поселок Усть-Калманка, Ленина, 24	f	large
19222	16806	1697	Алтайский край, Усть-Калманский район, поселок Усть-Калманка, Горького, 53	f	large
19234	16819	1709	Алтайский край, Усть-Калманский район, поселок Усть-Ермилиха, Центральная, 2а	t	small
19229	16813	1704	Алтайский край, Усть-Калманский район, поселок Степной, Овражная, 8	t	small
19244	16828	1719	Алтайский край, Усть-Калманский район, поселок Слюдянка, Центральная, 22	f	small
19226	16810	1701	Алтайский край, Усть-Калманский район, поселок Приозерный, Школьная, 17	f	small
19230	16814	1705	Алтайский край, Усть-Калманский район, поселок Пономарево, переулок Школьный, 3	f	small
19241	16825	1716	Алтайский край, Усть-Калманский район, поселок Огни, Партизанская, 40	f	medium
19240	16825	1715	Алтайский край, Усть-Калманский район, поселок Огни, Партизанская, 40	f	medium
19224	16808	1699	Алтайский край, Усть-Калманский район, поселок Новый Чарыш, Школьная, 4	f	small
19239	16824	1714	Алтайский край, Усть-Калманский район, поселок Новотроенка, Центральная, 31	t	small
19238	16823	1713	Алтайский край, Усть-Калманский район, поселок Новокалманка, Школьная, 31	f	medium
19235	16820	1710	Алтайский край, Усть-Калманский район, поселок Новобураново, Октябрьская, 8	f	medium
19243	16827	1718	Алтайский край, Усть-Калманский район, поселок Михайловка, Ленина, 75б	f	medium
19242	16826	1717	Алтайский край, Усть-Калманский район, поселок Михайловка, Ленина, 75б	f	medium
19232	16816	1707	Алтайский край, Усть-Калманский район, поселок Кабаново, Ползунова, 21	f	medium
19231	16815	1706	Алтайский край, Усть-Калманский район, поселок Западный, Центральная, 15	t	small
19236	16821	1711	Алтайский край, Усть-Калманский район, поселок Ельцовка, Центральная, 33	t	small
19228	16812	1703	Алтайский край, Усть-Калманский район, поселок Дружба, Центральная, 4	t	small
19225	16809	1700	Алтайский край, Усть-Калманский район, поселок Восточный, Школьная, 8	f	small
19245	16829	1720	Алтайский край, Усть-Калманский район, поселок Верх-Слюдянка, Большевистская, 10	t	small
19233	16817	1708	Алтайский край, Усть-Калманский район, поселок Бураново, Нагорная, 4	t	small
19207	16791	1681	Алтайский край, Угловский район, поселок Шадруха, Кооперативная, 18	f	small
19212	16796	1686	Алтайский край, Угловский район, поселок Угловское, Калинина, 3	f	large
19220	16804	1694	Алтайский край, Угловский район, поселок Топольное, Кооперативная, 50	f	medium
19200	16783	1674	Алтайский край, Угловский район, поселок Симоново, Центральная, 23	f	medium
19205	16789	1679	Алтайский край, Угловский район, поселок Павловка, Кооперативная, 42	f	medium
19204	16788	1678	Алтайский край, Угловский район, поселок Озерно-Кузнецовский лесхоз, Центральная , 2-Б	f	small
19203	16787	1677	Алтайский край, Угловский район, поселок Озерно-Кузнецово, Советская, 47	f	large
19213	16797	1687	Алтайский край, Угловский район, поселок Новоугловский, Школьная, 16	f	small
19216	16800	1690	Алтайский край, Угловский район, поселок Наумовка, С.Платонова, 32	t	small
19208	16792	1682	Алтайский край, Угловский район, поселок Мирный, Комсомольская, 16	f	medium
19210	16794	1684	Алтайский край, Угловский район, поселок Ляпуново, Школьная, 18	t	small
19218	16802	1692	Алтайский край, Угловский район, поселок Лаптев Лог, Кооперативная, 52	f	medium
19215	16799	1689	Алтайский край, Угловский район, поселок Куйбышево, Центральная, 72	f	small
19214	16798	1688	Алтайский край, Угловский район, поселок Круглое, Ленина, 8	f	medium
19202	16785	1676	Алтайский край, Угловский район, поселок Кормиха (Кроликово), Центральная, 40	t	small
19201	16784	1675	Алтайский край, Угловский район, поселок Валовой Кордон, Центральная, 76	f	small
19217	16801	1691	Алтайский край, Угловский район, поселок Борисовка, Молодежная, 13	t	small
19209	16793	1683	Алтайский край, Угловский район, поселок Бор-Кособулат, Лесная, 4	f	small
19219	16803	1693	Алтайский край, Угловский район, поселок Беленькое, Кооперативная, 43	f	small
19206	16790	1680	Алтайский край, Угловский район, поселок Алексеевка, Степная, 13	f	small
19199	16782	1673	Алтайский край, Тюменцевский район, поселок Юдиха, Кузнецова, 19	f	small
19190	16773	1664	Алтайский край, Тюменцевский район, поселок Шарчино, Ульяновская, 6	f	large
19186	16769	1660	Алтайский край, Тюменцевский район, поселок Черемшанка, Центральный переулок, 4	f	small
19192	16775	1666	Алтайский край, Тюменцевский район, поселок Урывка, Центральная, 22	f	small
19182	16765	1656	Алтайский край, Тюменцевский район, поселок Тюменцево, Октябрьская, 6	f	large
19181	16764	1655	Алтайский край, Тюменцевский район, поселок Тюменцево, Ленина, 104з	f	large
19180	16763	1654	Алтайский край, Тюменцевский район, поселок Тюменцево, Барнаульская, 16	f	large
19191	16774	1665	Алтайский край, Тюменцевский район, поселок Трубачево, Центральная, 15	t	small
19194	16777	1668	Алтайский край, Тюменцевский район, поселок Свободный, Заводская, 12	f	small
19198	16781	1672	Алтайский край, Тюменцевский район, поселок Мезенцево, Центральная, 5	f	small
19187	16770	1661	Алтайский край, Тюменцевский район, поселок Кулундинский, Кулундинская, 30	t	small
19188	16771	1662	Алтайский край, Тюменцевский район, поселок Королевский, Центральный, 16	f	medium
19183	16766	1657	Алтайский край, Тюменцевский район, поселок Ключи, Запорожская, 15	f	small
19195	16778	1669	Алтайский край, Тюменцевский район, поселок Карповский, Центральная, 34	f	small
19193	16776	1667	Алтайский край, Тюменцевский район, поселок Заводской, Центральная, 23а	f	small
19184	16767	1658	Алтайский край, Тюменцевский район, поселок Грязново, Центральная, 14	f	small
19189	16772	1663	Алтайский край, Тюменцевский район, поселок Вылково, Центральный, 6	f	large
19196	16779	1670	Алтайский край, Тюменцевский район, поселок Березовка, Молодежная, 5а	f	medium
19185	16768	1659	Алтайский край, Тюменцевский район, поселок Андроново, Центральная, 3	f	small
19178	16761	1652	Алтайский край, Троицкий район, поселок Южаково, Рабочая, 5	t	small
19147	16729	1621	Алтайский край, Троицкий район, поселок Червянка, Центральная, 12	t	small
19159	16741	1633	Алтайский край, Троицкий район, поселок Хайрюзовка, Советская, 54	f	small
19148	16730	1622	Алтайский край, Троицкий район, поселок Уткуль, Центральная, 1	t	small
86078	16742	1634	Алтайский край, Троицкий район, поселок Усть-Гавриловка, Школьная, 40, кв.1	f	small
19150	16732	1624	Алтайский край, Троицкий район, поселок Тюмень, Набережная, 18	t	small
19176	16759	1650	Алтайский край, Троицкий район, поселок Троицкое, пер. Лермонтова, 26	f	large
19143	16725	1617	Алтайский край, Троицкий район, поселок Троицкое, Комсомольская, 30	f	large
19142	16724	1616	Алтайский край, Троицкий район, поселок Троицкое, Комсомольская, 30	f	large
19164	16746	1638	Алтайский край, Троицкий район, поселок Талдинка, Центральная, 41А	t	small
19155	16737	1629	Алтайский край, Троицкий район, поселок Степной, Молодежная, 1А	f	small
18435	16016	871	Алтайский край, Троицкий район, поселок Раздольный, переулок Школьный, 1	t	small
19168	16750	1642	Алтайский край, Троицкий район, поселок Петровка, 50 лет Алтая, 30А	f	medium
19170	16752	1644	Алтайский край, Троицкий район, поселок Песьянка, Школьная, 6А	f	small
19172	16755	1646	Алтайский край, Троицкий район, поселок Октябрьский, Юбилейная, 9	f	small
19175	16758	1649	Алтайский край, Троицкий район, поселок Озеро-Петровское, Линейная, 2	t	small
19161	16743	1635	Алтайский край, Троицкий район, поселок Новоеловка, Елютина, 146	f	small
19177	16760	1651	Алтайский край, Троицкий район, поселок Многоозерный, Октябрьская, 1А	f	small
19179	16762	1653	Алтайский край, Троицкий район, поселок Лесной, Заречная, 19	t	small
19152	16734	1626	Алтайский край, Троицкий район, поселок Ленинский, Коммунарская, 77	t	small
19165	16747	1639	Алтайский край, Троицкий район, поселок Краснояры, переулок Парковый, 1	f	medium
19173	16756	1647	Алтайский край, Троицкий район, поселок Клюквенный, Центральная, 3, кв.1	t	small
19158	16740	1632	Алтайский край, Троицкий район, поселок Кипешино, Сибирская, 10	t	small
19154	16736	1628	Алтайский край, Троицкий район, поселок Зеленая Поляна, Школьная, 22	f	medium
19153	16735	1627	Алтайский край, Троицкий район, поселок Загайново, Школьная, 16	f	small
19174	16757	1648	Алтайский край, Троицкий район, поселок Заводское, 50 лет Октября, 2	f	large
19166	16748	1640	Алтайский край, Троицкий район, поселок Еремино, Школьная, 21	f	small
19163	16745	1637	Алтайский край, Троицкий район, поселок Ельцовка, Ленина, 98	f	medium
19167	16749	1641	Алтайский край, Троицкий район, поселок Горновое, Молодежная, 36	f	medium
19171	16754	1645	Алтайский край, Троицкий район, поселок Гордеевский, Зеленая, 37	f	large
19162	16744	1636	Алтайский край, Троицкий район, поселок Гордеевка, Алтайская, 33	f	small
19156	16738	1630	Алтайский край, Троицкий район, поселок Вершинино, Центральная, 42	t	small
19151	16733	1625	Алтайский край, Троицкий район, поселок Боровлянский, Боровлянская, 20А	f	small
109273	16727	1619	Алтайский край, Троицкий район, поселок Боровлянка, Фефелова, 64А	f	medium
19146	16728	1620	Алтайский край, Троицкий район, поселок Боровлянка, Октябрьская, 61Б	f	medium
86077	16739	1631	Алтайский край, Троицкий район, поселок Белое, 40 лет Победы, 13	f	small
19149	16731	1623	Алтайский край, Троицкий район, поселок Беловский, Советская, 11	f	large
19135	16719	1609	Алтайский край, Третьяковский район, поселок Шипуниха, Михайлова, 12	f	small
19130	16714	1604	Алтайский край, Третьяковский район, поселок Третьяково, Центральная, 25	f	medium
19399	16984	1879	Алтайский край, Третьяковский район, поселок Степной, Западная, 12	f	small
19398	16709	1878	Алтайский край, Третьяковский район, поселок Староалейское, Колхозная, 3	f	medium
19125	16709	1599	Алтайский край, Третьяковский район, поселок Староалейское, Колхозная, 3	f	large
19124	16708	1598	Алтайский край, Третьяковский район, поселок Староалейское, Калашникова, 38	f	small
19123	16708	1597	Алтайский край, Третьяковский район, поселок Староалейское, Калашникова, 38	f	large
19136	16720	1610	Алтайский край, Третьяковский район, поселок Семеновка, Центральная, 22	f	small
19126	16710	1600	Алтайский край, Третьяковский район, поселок Садовый, Дорожная, 10	f	medium
19139	16723	1613	Алтайский край, Третьяковский район, поселок Плоское, Центральная, 71	f	medium
19132	16716	1606	Алтайский край, Третьяковский район, поселок Первомайский, Центральная, 8	f	medium
109272	16718	1608	Алтайский край, Третьяковский район, поселок Первокаменка, Советская, 1	f	medium
86057	16713	1603	Алтайский край, Третьяковский район, поселок Новокамышенка, Советская, 19	f	small
19137	16721	1611	Алтайский край, Третьяковский район, поселок Новоалейское, Центральная, 86	f	small
19131	16715	1605	Алтайский край, Третьяковский район, поселок Михайловка, Центральная, 39 Б	f	small
19127	16711	1601	Алтайский край, Третьяковский район, поселок Корболиха, Кирова, 34	f	large
19128	16712	1602	Алтайский край, Третьяковский район, поселок Екатерининское, Титова, 53	f	large
86109	16722	1612	Алтайский край, Третьяковский район, поселок Верх-Алейка, Центральная, 10	f	small
19122	16707	1590	Алтайский край, Топчихинский район, поселок Чистюнька, Партизанская, 4	f	large
19121	16706	1589	Алтайский край, Топчихинский район, поселок Чаузово (Большая Речка), Лесная, 53	f	small
19120	16705	1588	Алтайский край, Топчихинский район, поселок Хабазино, Гагарина, 2	f	small
19119	16704	1587	Алтайский край, Топчихинский район, поселок Фунтики, Юбилейная, 21	f	large
19112	16697	1580	Алтайский край, Топчихинский район, поселок Труд, Центральная, 18	f	small
19099	16684	1567	Алтайский край, Топчихинский район, поселок Топчиха, Партизанская, 42	f	large
19098	16684	1566	Алтайский край, Топчихинский район, поселок Топчиха, Партизанская, 42	f	large
19097	16683	1565	Алтайский край, Топчихинский район, поселок Топчиха, Куйбышева, 4	f	large
19096	16682	1564	Алтайский край, Топчихинский район, поселок Топчиха, Куйбышева, 37	f	large
19104	16689	1572	Алтайский край, Топчихинский район, поселок Топольный, Центральная, 14	t	small
19118	16703	1586	Алтайский край, Топчихинский район, поселок Сидоровка, Октябрьская, 24	f	medium
19117	16702	1585	Алтайский край, Топчихинский район, поселок Покровка, Школьная, 24	f	small
19113	16698	1581	Алтайский край, Топчихинский район, поселок Победим, Ленина, 12	f	medium
19110	16695	1578	Алтайский край, Топчихинский район, поселок Песчаное, Школьная, 26	t	small
19111	16696	1579	Алтайский край, Топчихинский район, поселок Переяславка, Губина, 26	f	medium
19109	16694	1577	Алтайский край, Топчихинский район, поселок Парфеново, Школьная, 18	f	large
19108	16693	1576	Алтайский край, Топчихинский район, поселок Макарьевка, Центральная, 4	f	medium
19107	16692	1575	Алтайский край, Топчихинский район, поселок Листвянка, Центральная, 32	f	small
19106	16691	1574	Алтайский край, Топчихинский район, поселок Красноярка, Центральная, 51	f	small
19115	16700	1583	Алтайский край, Топчихинский район, поселок Колпаково, Центральная, 1	f	small
19105	16690	1573	Алтайский край, Топчихинский район, поселок Ключи, Молодежная, 5	f	medium
19103	16688	1571	Алтайский край, Топчихинский район, поселок Кировскаий, Садовая, 33	f	medium
19102	16687	1570	Алтайский край, Топчихинский район, поселок Зимино, Партизанская, 13	f	medium
19114	16699	1582	Алтайский край, Топчихинский район, поселок Зеленый, Московская, 21	f	small
19116	16701	1584	Алтайский край, Топчихинский район, поселок Дружба, Садовая, 5	f	small
19101	16686	1569	Алтайский край, Топчихинский район, поселок Володарка, Володарского, 3	f	medium
19100	16685	1568	Алтайский край, Топчихинский район, поселок Белояровка, Гагарина, 37	f	medium
19087	16673	1555	Алтайский край, Тогульский район, поселок Шумиха, Новаря, 5	t	small
19089	16675	1557	Алтайский край, Тогульский район, поселок Уксунай, Кузнецкая, 45	t	small
19091	16677	1559	Алтайский край, Тогульский район, поселок Топтушка, Новая, 14	f	small
19083	16669	1551	Алтайский край, Тогульский район, поселок Тогул, Школьная, 20	f	large
19082	16668	1550	Алтайский край, Тогульский район, поселок Тогул, Совхозная, 25	f	medium
19084	16670	1552	Алтайский край, Тогульский район, поселок Тогул, Пролетарская, 1	f	medium
19081	16667	1549	Алтайский край, Тогульский район, поселок Тогул, Октябрьская, 4	f	large
19086	16672	1554	Алтайский край, Тогульский район, поселок Титово, Центральная, 21	t	small
19092	16678	1560	Алтайский край, Тогульский район, поселок Старый Тогул, Центральная, 2	f	medium
19088	16674	1556	Алтайский край, Тогульский район, поселок Новоиушино, Центральная, 7	f	small
86083	16671	1553	Алтайский край, Тогульский район, поселок Льнозавод, Заводская, 1	f	small
19094	16680	1562	Алтайский край, Тогульский район, поселок Колонково, Бийская, 15	t	small
19090	16676	1558	Алтайский край, Тогульский район, поселок Верх-Коптелка, Лесная, 12	f	small
19095	16681	1563	Алтайский край, Тогульский район, поселок Бураново, Молодежная, 10	t	small
19093	16679	1561	Алтайский край, Тогульский район, поселок Антипино, Мокарова, 53	f	large
19059	16645	1523	Алтайский край, Тальменский район, станция Озерки, Калинина, 22	f	large
19067	16653	1531	Алтайский край, Тальменский район, поселок Язово, Центральная, 80	f	small
19066	16652	1530	Алтайский край, Тальменский район, поселок Шишкино, Советская, 7	f	small
19049	16635	1513	Алтайский край, Тальменский район, поселок Шипицыно, Школьная, 2	t	small
19065	16651	1529	Алтайский край, Тальменский район, поселок Шадринцево, Садовая, 34	f	medium
19056	16642	1520	Алтайский край, Тальменский район, поселок Таскаево, Клубная, 6	f	small
19073	16659	1537	Алтайский край, Тальменский район, поселок Тальменка, Учительская, 2а	f	large
67926	16655	1533	Алтайский край, Тальменский район, поселок Тальменка, Партизанская, 53	f	large
19080	16666	1544	Алтайский край, Тальменский район, поселок Тальменка, Парковая, 21	f	large
19076	16662	1540	Алтайский край, Тальменский район, поселок Тальменка, Октябрьская, 57	f	large
19077	16663	1541	Алтайский край, Тальменский район, поселок Тальменка, Лисавенко, 49	f	large
19068	16654	1532	Алтайский край, Тальменский район, поселок Тальменка, Куйбышева, 91	f	large
19071	16657	1535	Алтайский край, Тальменский район, поселок Тальменка, Кирова, 19	f	large
19074	16660	1538	Алтайский край, Тальменский район, поселок Тальменка, Анисимовская, 24	f	large
19075	16661	1539	Алтайский край, Тальменский район, поселок Тальменка, 60 лет СССР, 3	f	large
19072	16658	1536	Алтайский край, Тальменский район, поселок Тальменка, 30 лет ВЛКСМ, 17	f	large
19064	16650	1528	Алтайский край, Тальменский район, поселок Староперуново, Советская, 13	f	small
19063	16649	1527	Алтайский край, Тальменский район, поселок Среднесибирский, Юбилейная, 2	f	large
19048	16634	1512	Алтайский край, Тальменский район, поселок Сандалово, Новая, 6	t	small
19062	16648	1526	Алтайский край, Тальменский район, поселок Речкуново, Школьная, 11	f	small
19058	16644	1522	Алтайский край, Тальменский район, поселок Озерки, Юбилейная, 2	f	large
19060	16646	1524	Алтайский край, Тальменский район, Озерки, Промышленная, 61	f	large
19057	16643	1521	Алтайский край, Тальменский район, поселок Озерки, Новая, 4	f	large
19055	16641	1519	Алтайский край, Тальменский район, поселок Новотроицк, Советская, 62	f	medium
19054	16640	1518	Алтайский край, Тальменский район, поселок Новоперуново, Зеленая, 8	f	large
19046	16632	1510	Алтайский край, Тальменский район, поселок Новоеловка, Школьная, 19	f	small
86040	16630	1508	Алтайский край, Тальменский район, поселок Наумово, Октябрьская, 2а	f	small
19052	16638	1516	Алтайский край, Тальменский район, поселок Лушниково, Советская, 43	f	small
19050	16636	1514	Алтайский край, Тальменский район, поселок Луговое, Центральная, 77	f	medium
18785	16372	1235	Алтайский край, Тальменский район, поселок Лесная Поляна, Центральная, 15а	f	small
19047	16633	1511	Алтайский край, Тальменский район, поселок Ларичиха, Строительная, 2	f	large
19045	16631	1509	Алтайский край, Тальменский район, поселок Курочкино, Школьная, 11	f	medium
19053	16639	1517	Алтайский край, Тальменский район, поселок Кошелево, Школьная, 14	f	small
19043	16629	1507	Алтайский край, Тальменский район, поселок Кашкарагаиха, Советская, 1а	f	medium
19042	16628	1506	Алтайский край, Тальменский район, поселок Казанцево, Центральная, 10	f	small
19041	16627	1505	Алтайский край, Тальменский район, поселок Зайцево, Центральная, 45	f	medium
86081	16626	1504	Алтайский край, Тальменский район, поселок Загайново, Центральная, 89а	f	small
19039	16625	1503	Алтайский край, Тальменский район, поселок Забродино, микрорайон Черемушки, 18	f	small
19051	16637	1515	Алтайский край, Тальменский район, поселок Выползово, Центральная, 2	f	small
19061	16647	1525	Алтайский край, Тальменский район, поселок Восточный, Береговая, 37	f	small
67925	16624	1502	Алтайский край, Тальменский район, поселок Анисимово, Тальменская, 4в	f	large
19032	16619	1493	Алтайский край, Табунский район, поселок Хорошее, Молодежная, 4	f	small
19030	16617	1491	Алтайский край, Табунский район, поселок Успенка, Комсомольская, 38	f	small
19022	16609	1483	Алтайский край, Табунский район, поселок Удальное, Мира, 31	f	small
109271	16607	1481	Алтайский край, Табунский район, поселок Табуны, Московская, 21	f	medium
19019	16606	1480	Алтайский край, Табунский район, поселок Табуны, Ленина, 17	f	large
19028	16615	1489	Алтайский край, Табунский район, поселок Сереброполь, Ленина, 75	f	medium
19029	16616	1490	Алтайский край, Табунский район, поселок Саратовка, Целинная, 37	t	small
19021	16608	1482	Алтайский край, Табунский район, поселок Самбор, пер.Центральный, 10	f	small
18559	16139	1005	Алтайский край, Табунский район, поселок Орловка, Озерная, 22а	f	small
19025	16612	1486	Алтайский край, Табунский район, поселок Новокиевка, Свердлова, 19	f	small
19031	16618	1492	Алтайский край, Табунский район, поселок Николаевка, Лермонтова, 37	f	small
19035	16622	1496	Алтайский край, Табунский район, поселок Лебедино, Ленина, 14	f	small
19034	16621	1495	Алтайский край, Табунский район, поселок Канны, Ленина, 31	f	small
19027	16614	1488	Алтайский край, Табунский район, поселок Камышенка, Гагарина, 10	f	small
19023	16610	1484	Алтайский край, Табунский район, поселок Забавное, пер.Школьный, 2	f	small
19033	16620	1494	Алтайский край, Табунский район, поселок Большеромановка, Ленина, 46	f	medium
19024	16611	1485	Алтайский край, Табунский район, поселок Алтайское, Гагарина, 5	f	large
19026	16613	1487	Алтайский край, Табунский район, поселок Александровка, Центральная, 22	f	small
86065	16602	1476	Алтайский край, Суетский район, поселок имени Владимира Ильича, Ленина, 14	t	small
86059	16605	1479	Алтайский край, Суетский район, поселок Осиновский, Ленина, 1/а	f	small
19017	16604	1478	Алтайский край, Суетский район, поселок Октябрьский, Школьная, 1	f	small
19016	16603	1477	Алтайский край, Суетский район, поселок Нижняя Суетка, Школьная, 36	f	large
18217	15796	651	Алтайский край, Суетский район, поселок Мельниковка, Мичурина, 48	f	small
19014	16600	1475	Алтайский край, Суетский район, поселок Верхняя Суетка, Целинная, 63	f	large
19013	16599	1474	Алтайский край, Суетский район, поселок Боронск, Центральная, 24	t	small
19008	16594	1469	Алтайский край, Солтонский район, поселок Шатабол, Центральная, 2	t	small
19004	16591	1465	Алтайский край, Солтонский район, поселок Усть-Куют, Заводская, 13/2	f	small
19007	94921	1468	Алтайский край, Солтонский район, поселок Урунск, Школьная, 6	f	small
86055	16597	1472	Алтайский край, Солтонский район, поселок Тосток, Центральная, 5А	t	small
19010	16596	1471	Алтайский край, Солтонский район, поселок Сузоп, Центральная, 21	f	medium
19005	16592	1466	Алтайский край, Солтонский район, поселок Солтон, Ленина, 5	f	large
19003	16590	1464	Алтайский край, Солтонский район, поселок Сайдып, Центральная, 2	f	small
86107	16595	1470	Алтайский край, Солтонский район, поселок Новотроицк, Центральная, 6	t	small
19000	16587	1461	Алтайский край, Солтонский район, поселок Новая Ажинка, Боровая, 27А	t	small
19001	16588	1462	Алтайский край, Солтонский район, поселок Нижняя Ненинка, Жданова, 55	f	medium
18999	16586	1460	Алтайский край, Солтонский район, поселок Ненинка, Октябрьская, 47	f	medium
18998	16585	1459	Алтайский край, Солтонский район, поселок Макарьевка, Полевая, 28	f	small
18995	16582	1456	Алтайский край, Солтонский район, поселок Караган, Нагорная, 2	t	small
18996	16583	1457	Алтайский край, Солтонский район, поселок Карабинка, 50 лет Победы, 5	f	medium
18997	16584	1458	Алтайский край, Солтонский район, поселок Излап, Центральная, 10	t	small
19197	16780	1671	Алтайский край, Солтонский район, поселок Вознесенка, Луговая, 24	t	small
18994	16581	1455	Алтайский край, Солтонский район, поселок Березово, Центральная, 1	f	small
19002	16589	1463	Алтайский край, Солтонский район, поселок Акатьево, Береговая, 4А	t	small
18976	16562	1429	Алтайский край, Солонешенский район, поселок Юртное, Советская, 24	t	small
86051	16565	1432	Алтайский край, Солонешенский район, поселок Черемшанка, Октябрьская, 45	t	small
18989	16575	1442	Алтайский край, Солонешенский район, поселок Туманово, Советская, 25	f	small
18992	16579	1445	Алтайский край, Солонешенский район, поселок Топольное, Виталия Табачкова, 32В	f	medium
86052	16570	1437	Алтайский край, Солонешенский район, поселок Тележиха, Петра Сухова, 49	t	small
86049	16564	1431	Алтайский край, Солонешенский район, поселок Тальменка, Центральная, 30	t	small
86106	16578	1444	Алтайский край, Солонешенский район, поселок Степное, Центральная, 6	f	small
18982	16568	1435	Алтайский край, Солонешенский район, поселок Солонешное, Советская, 31	f	large
109270	16563	1430	Алтайский край, Солонешенский район, поселок Сибирячиха, Советская, 43	f	medium
18993	16580	1446	Алтайский край, Солонешенский район, поселок Рыбное, Школьная, 9	t	small
86105	16574	1441	Алтайский край, Солонешенский район, поселок Новая Жизнь, Коммунарская, 8	t	small
86102	16571	1438	Алтайский край, Солонешенский район, поселок Лютаево, Центральная, 9	f	small
86103	16572	1439	Алтайский край, Солонешенский район, поселок Карпово, Набережная, 1	f	small
18983	16569	1436	Алтайский край, Солонешенский район, поселок Искра, Школьная, 13	t	small
86069	16577	1443	Алтайский край, Солонешенский район, поселок Демино, Кокорина, 13	t	small
86104	16573	1440	Алтайский край, Солонешенский район, поселок Большая Тихая, Советская, 1	t	small
86101	16561	1428	Алтайский край, Солонешенский район, поселок Березовка, Восточная, 4	f	small
19012	16598	1473	Алтайский край, Солонешенский район, поселок Александровка, Победы, 50	f	medium
18974	16560	1427	Алтайский край, Советский район, поселок Шульгинка, 3п.А	f	large
18966	16552	1419	Алтайский край, Советский район, поселок Шульгин Лог, Школьная, 67	f	medium
18968	16554	1421	Алтайский край, Советский район, поселок Хуторки, Центральная, 36	t	small
18967	16553	1420	Алтайский край, Советский район, поселок Урожайное, Автозаводская, 17	f	large
18970	16556	1423	Алтайский край, Советский район, поселок Талица, Сибирская, 35	f	small
18958	16544	1411	Алтайский край, Советский район, поселок Советское, Октябрьская, 40	f	large
18957	16543	1410	Алтайский край, Советский район, поселок Советское, Октябрьская, 2	f	large
18962	16548	1415	Алтайский край, Советский район, поселок Сетовка, Советская, 49б	f	medium
18969	16555	1422	Алтайский край, Советский район, поселок Семилетка, Садовая, 3	f	small
18963	16549	1416	Алтайский край, Советский район, поселок Половинка, Центральная, 40	f	medium
18965	16551	1418	Алтайский край, Советский район, поселок Платово, Молодежная, 3	f	small
18959	16545	1412	Алтайский край, Советский район, поселок Никольское, пер.Школьный, 4	f	medium
18947	16533	1399	Алтайский край, Советский район, поселок Ленинское, Красноярская, 11	t	small
18973	16559	1426	Алтайский край, Советский район, поселок Красный Яр, Центральная, 29	f	medium
18964	16550	1417	Алтайский край, Советский район, поселок Колово, Советская, 3	f	small
18960	16546	1413	Алтайский край, Советский район, поселок Колбаны, Молодежная, 2	t	small
18971	16557	1424	Алтайский край, Советский район, поселок Кокши, Советская, 35	f	medium
18972	16558	1425	Алтайский край, Советский район, поселок Карасук, Ветеранов, 21	t	small
18961	16547	1414	Алтайский край, Советский район, поселок Глинка, Центральная, 30п.В	f	small
86100	16531	1397	Алтайский край, Смоленский район, поселок Южный, Советская, 6	t	small
18955	16541	1407	Алтайский край, Смоленский район, поселок Черновая, Нагорная, 3	f	small
18935	16520	1387	Алтайский край, Смоленский район, поселок Усть-Катунь, Комсомольская, 37	f	small
67924	16540	1406	Алтайский край, Смоленский район, поселок Точильное, Школьная, 21	f	large
18953	16539	1405	Алтайский край, Смоленский район, поселок Сычевка, Центральная, 33	f	large
86097	16524	1391	Алтайский край, Смоленский район, поселок Степное, Озерная, 6	t	small
5311	31929	504	республика Дагестан, Дербент, Х.Тагиева, 1	f	large
18933	16518	1385	Алтайский край, Смоленский район, поселок Старотырышкино, Каньшакова, 1а	f	small
67923	16538	1404	Алтайский край, Смоленский район, поселок Солоновка, Советская, 64	f	large
18948	16534	1400	Алтайский край, Смоленский район, поселок Смоленское, Энергетическая, 1	f	large
67922	16536	1402	Алтайский край, Смоленский район, поселок Смоленское, Советская, 144	f	large
18951	16537	1403	Алтайский край, Смоленский район, поселок Смоленское, Песчаная, 71а	f	small
18949	16535	1401	Алтайский край, Смоленский район, поселок Смоленское, Красноярская, 94	f	large
18941	16526	1393	Алтайский край, Смоленский район, поселок Песчаное, Онухова, 15а	t	small
18946	16532	1398	Алтайский край, Смоленский район, поселок Первомайское, Совхозная, 9	f	small
67921	16530	1396	Алтайский край, Смоленский район, поселок Новотырышкино, Советская, 78	f	large
86099	16529	1395	Алтайский край, Смоленский район, поселок Линевский, им.Волкова, 10	f	small
18940	16525	1392	Алтайский край, Смоленский район, поселок Линевский, Скорикова, 2	f	medium
18956	16542	1408	Алтайский край, Смоленский район, поселок Красный Городок, Центральная, 20	t	small
67920	16522	1389	Алтайский край, Смоленский район, поселок Кировский, Нагорная, 7	f	large
18936	16521	1388	Алтайский край, Смоленский район, поселок Катунское, Мальцева, 61а	f	medium
18934	16519	1386	Алтайский край, Смоленский район, поселок Верх-Обский, Центральная, 14г	f	large
17824	15446	253	Алтайский край, Смоленский район, Белокуриха, Шукшина, 1	f	large
17827	15308	256	Алтайский край, Смоленский район, Белокуриха, Соболева, 24	f	medium
17830	15420	259	Алтайский край, Смоленский район, Белокуриха, Объездная, 2	f	large
17829	15395	258	Алтайский край, Смоленский район, Белокуриха, Бийская, 40	f	large
17826	15448	255	Алтайский край, Смоленский район, Белокуриха, Академика Мясникова, 24/1	f	large
17823	15445	252	Алтайский край, Смоленский район, Белокуриха, Академика Мясникова, 18/1	f	large
18932	16517	1384	Алтайский край, Смоленский район, поселок Ануйское, Центральная, 10	f	medium
18938	16523	1390	Алтайский край, Смоленский район, поселок Александровка, Зеленая, 10	f	small
18929	16514	1381	Алтайский край, Славгородский район, Славгород, поселок Семеновка, Кулундинская, 10	f	medium
18926	16511	1378	Алтайский край, Славгородский район, Славгород, село Пригородное, Гагарина, 24а	f	small
18927	16512	1379	Алтайский край, Славгородский район, поселок Селекционное, Молодежная, 14а	f	large
18928	16513	1380	Алтайский край, Славгородский район, поселок Райгород, Первомайская, 41	t	small
18925	16285	1377	Алтайский край, Славгородский район, поселок Покровка, Школьная, 5	f	medium
18923	16509	1375	Алтайский край, Славгородский район, поселок Максимовка, Центральная, 47	f	small
18672	16255	1121	Алтайский край, Славгородский район, поселок Гришковка, Ленина, 71	f	large
86082	15656	509	Алтайский край, Славгородский район, поселок Балластный Карьер, школа №23	t	small
18931	16516	1383	Алтайский край, Славгородский район, поселок Архангельское, Красных Партизан, 23	f	small
18920	16506	1372	Алтайский край, Рубцовский район, поселок Тишинка, Центральная, 47	f	small
18919	16505	1371	Алтайский край, Рубцовский район, поселок Саратовка, Новая, 6	f	medium
18918	16504	1370	Алтайский край, Рубцовский район, поселок Самарка, Ленина, 17	f	medium
18909	16495	1361	Алтайский край, Рубцовский район, поселок Романовка, Молодежная, 11	f	small
18917	16503	1369	Алтайский край, Рубцовский район, поселок Ракиты, Октябрьская, 26в	f	medium
18916	16502	1368	Алтайский край, Рубцовский район, поселок Пушкино, Новая, 25	f	small
19402	16986	1883	Алтайский край, Рубцовский район, поселок Приозерный, Школьная, 2/2	f	small
18912	16498	1364	Алтайский край, Рубцовский район, поселок Половинкино, Советская, 70	f	medium
18911	16497	1363	Алтайский край, Рубцовский район, поселок Новосклюиха, Мира, 38	f	medium
18908	16494	1360	Алтайский край, Рубцовский район, поселок Новониколаевка, Вовченко, 4	f	large
18907	16493	1359	Алтайский край, Рубцовский район, поселок Новоалександровка, Центральная, 21	f	large
18914	16500	1366	Алтайский край, Рубцовский район, поселок Мичуринский, Центральная, 38	f	small
19395	16981	1874	Алтайский край, Рубцовский район, поселок Мамонтово, Советская, 19	f	medium
18644	16226	1093	Алтайский край, Рубцовский район, поселок Мамонтово, Советская, 142	f	large
18647	16229	1096	Алтайский край, Рубцовский район, поселок Мамонтово, Партизанская, 314	f	large
67918	16228	1095	Алтайский край, Рубцовский район, поселок Мамонтово, Партизанская, 162	f	large
18645	16227	1094	Алтайский край, Рубцовский район, поселок Мамонтово, Партизанская, 188	f	large
18906	16492	1358	Алтайский край, Рубцовский район, поселок Мамонтово, Комсомольская, 19	f	small
18648	16230	1097	Алтайский край, Рубцовский район, поселок Мамонтово, Захарова, 65	f	large
18905	16491	1357	Алтайский край, Рубцовский район, поселок Куйбышево, Центральная, 4	f	medium
18915	16501	1367	Алтайский край, Рубцовский район, поселок Колос, Топольная, 10	f	small
18899	16485	1351	Алтайский край, Рубцовский район, поселок Катково, Баталова, 25	f	small
18913	16499	1365	Алтайский край, Рубцовский район, поселок Зеленая Дубрава, Топольная, 24	f	medium
18895	16481	1347	Алтайский край, Рубцовский район, поселок Захарово, Ленина, 52	f	small
18904	16490	1356	Алтайский край, Рубцовский район, поселок Дальний, Центральный, 9	f	medium
18903	16489	1355	Алтайский край, Рубцовский район, поселок Вишневка, Молодежная, 34	f	medium
18901	16487	1353	Алтайский край, Рубцовский район, поселок Веселоярск, Центральный, 3	f	large
18902	16488	1354	Алтайский край, Рубцовский район, поселок Веселоярск, Куйбышева, 14	f	large
18900	16486	1352	Алтайский край, Рубцовский район, поселок Большая Шелковка, Советская, 55	f	medium
18898	16484	1350	Алтайский край, Рубцовский район, поселок Бобково, Новая, 5	f	medium
18897	16483	1349	Алтайский край, Рубцовский район, поселок Березовка, Молодежная, 1а	f	medium
18896	16482	1348	Алтайский край, Рубцовский район, поселок Безрукавка, Советская, 20	f	large
18894	16480	1346	Алтайский край, Романовский район, поселок Тамбовский, Центральная, 1А	f	medium
18893	16479	1345	Алтайский край, Романовский район, поселок Сидоровка, Советская, 87	f	large
18891	16477	1343	Алтайский край, Романовский район, поселок Романово, Советская, 52	f	large
18890	16476	1342	Алтайский край, Романовский район, поселок Романово, Советская, 62	f	large
18892	16478	1344	Алтайский край, Романовский район, поселок Романово, Мамонтовская, 59	f	large
18889	16475	1341	Алтайский край, Романовский район, поселок Рассвет, Школьная, 2	f	small
18887	16473	1339	Алтайский край, Романовский район, поселок Мормыши, Захарова, 30	f	small
18885	16471	1337	Алтайский край, Романовский район, поселок Майский, пер.Школьный, 5	f	small
18886	16472	1338	Алтайский край, Романовский район, поселок Казанцево, Школьная, 5	f	small
18884	16470	1336	Алтайский край, Романовский район, поселок Закладное, Советская, 6	f	medium
18883	16469	1335	Алтайский край, Романовский район, поселок Дубровино, Советская, 45А	f	small
18882	16468	1334	Алтайский край, Романовский район, поселок Гуселетово, 30 лет Победы, 1	f	medium
18881	16467	1333	Алтайский край, Романовский район, поселок Грановка, Титова, 12	f	small
18880	16466	1332	Алтайский край, Романовский район, поселок Гилев Лог, Советская, 88	f	medium
18888	16474	1340	Алтайский край, Романовский район, поселок Бурановка, Молодежная, 19	f	small
18879	16465	1331	Алтайский край, Родинский район, поселок Ярославцев Лог, Ленина, 53	t	medium
18878	16464	1330	Алтайский край, Родинский район, поселок Шаталовка, Садовая, 22	f	medium
18876	16462	1328	Алтайский край, Родинский район, поселок Центральное, Школьная, 2	f	medium
18869	16458	1321	Алтайский край, Родинский район, поселок Тизек, Комсомольская, 5	t	small
18874	16460	1326	Алтайский край, Родинский район, поселок Степной Кучук, Гагарина, 3а	f	medium
18875	16461	1327	Алтайский край, Родинский район, поселок Степное, Садовая, 9	f	large
18871	16253	1323	Алтайский край, Родинский район, поселок Родино, Шевченко, 5а	f	large
18873	16301	1325	Алтайский край, Родинский район, поселок Родино, Мелиораторов, 5	f	large
18872	16269	1324	Алтайский край, Родинский район, поселок Родино, Ленина, 234	f	large
18868	16457	1320	Алтайский край, Родинский район, поселок Разумовка, Ленина, 15а	f	small
109269	16456	1319	Алтайский край, Родинский район, поселок Раздольное, Детсадовская, 1	f	medium
18865	16454	1317	Алтайский край, Родинский район, поселок Покровка, Аврамкова, 71	f	medium
86075	16453	1316	Алтайский край, Родинский район, поселок Новотроицк, Первомайская, 9	f	small
18863	94920	1315	Алтайский край, Родинский район, поселок Мирный, Ленина, 19а	f	large
18877	16463	1329	Алтайский край, Родинский район, поселок Красный Алтай, Новая, 2	f	small
18862	16451	1314	Алтайский край, Родинский район, поселок Кочки, Партизанская, 1	f	medium
18860	16449	1312	Алтайский край, Родинский район, поселок Каяушка, Ленина, 25	f	small
18859	16448	1311	Алтайский край, Родинский район, поселок Зеленый Луг, Школьная, 10а	f	small
86073	16450	1313	Алтайский край, Родинский район, поселок Зеленая Дубрава, пер. Восточный, 4	t	small
18866	16455	1318	Алтайский край, Родинский район, поселок Вячеславка (Красная Нива), Советская, 26	f	small
18858	16447	1310	Алтайский край, Родинский район, поселок Вознесенка, Сухова, 85	f	small
18837	16425	1289	Алтайский край, Ребрихинский район, станция Ребриха, Касмалинская, 33	f	large
109265	16436	1299	Алтайский край, Ребрихинский район, поселок Ясная Поляна, Комсомольская, 2	f	medium
109264	16433	1296	Алтайский край, Ребрихинский район, поселок Шумилиха, Ленина, 84	f	medium
67888	16435	1298	Алтайский край, Ребрихинский район, поселок Усть-Мосиха, Центральная, 2	f	large
109268	16445	1308	Алтайский край, Ребрихинский район, поселок Рожнев Лог, Ленина, 40	f	medium
18835	16423	1287	Алтайский край, Ребрихинский район, поселок Ребриха, проспект Победы, 73	f	medium
18834	16422	1286	Алтайский край, Ребрихинский район, поселок Ребриха, пр-т Победы, 47	f	large
18853	16442	1305	Алтайский край, Ребрихинский район, поселок Ребриха, Партизанская, 68	f	large
18836	16424	1288	Алтайский край, Ребрихинский район, поселок Ребриха, Максима Горького, 50	f	medium
18833	16421	1285	Алтайский край, Ребрихинский район, поселок Ребриха, Ленина, 134	f	large
18841	16430	1293	Алтайский край, Ребрихинский район, поселок Подстепное, 50 лет ВЛКСМ, 2	f	medium
18855	16444	1307	Алтайский край, Ребрихинский район, поселок Плоскосеминский, Школьная, 34а	f	small
18857	16446	1309	Алтайский край, Ребрихинский район, поселок Пеньки, переулок Степной	f	small
109263	16431	1294	Алтайский край, Ребрихинский район, поселок Паново, Кузбасс, 1	f	medium
18850	16439	1302	Алтайский край, Ребрихинский район, поселок Орел, Почтовая, 11	f	small
18843	16432	1295	Алтайский край, Ребрихинский район, поселок Молодежный, Ленина, 6	f	small
18845	16434	1297	Алтайский край, Ребрихинский район, поселок Куликово, Партизанская, 32	f	small
18852	16441	1304	Алтайский край, Ребрихинский район, поселок Ключевка, Центральная, 26	t	small
18849	16438	1301	Алтайский край, Ребрихинский район, поселок Клочки, Павловская, 39	f	medium
109267	16443	1306	Алтайский край, Ребрихинский район, поселок Зимино, Центральная, 59	f	medium
18851	16440	1303	Алтайский край, Ребрихинский район, поселок Зеленая Роща, Зеленорощинская, 32	f	small
18840	16429	1292	Алтайский край, Ребрихинский район, поселок Георгиевка, Комсомольская, 61	f	medium
109262	16428	1291	Алтайский край, Ребрихинский район, поселок Ворониха, Советская, 2А	f	medium
109266	16437	1300	Алтайский край, Ребрихинский район, поселок Боровлянка, Школьная, 29	f	medium
67885	16426	1290	Алтайский край, Ребрихинский район, поселок Белово, Быкова, 7	f	large
18828	16416	1279	Алтайский край, Поспелихинский район, поселок Хлебороб, Садовая, 19	f	medium
18831	16419	1282	Алтайский край, Поспелихинский район, поселок Факел Социализма, Молодежная, 9	f	small
18821	16408	1272	Алтайский край, Поспелихинский район, поселок Поспелихинский, Школьная, 9	f	medium
18815	16402	1266	Алтайский край, Поспелихинский район, поселок Поспелиха, Целинная, 12	f	large
18817	16404	1268	Алтайский край, Поспелихинский район, поселок Поспелиха, Кондратюка, 28	f	large
18813	16400	1264	Алтайский край, Поспелихинский район, поселок Поспелиха, Коммунистическая, 21	f	large
18816	16403	1267	Алтайский край, Поспелихинский район, поселок Поспелиха, Гончарова, 48	f	large
18825	16413	1276	Алтайский край, Поспелихинский район, поселок Поломошное, Школьная, 2	f	small
109261	16414	1277	Алтайский край, Поспелихинский район, поселок Озимая, Центральная, 1	f	medium
18910	16496	1362	Алтайский край, Поспелихинский район, поселок Новороссийский, Центральный, 10	f	medium
18818	16405	1269	Алтайский край, Поспелихинский район, поселок Николаевка, Ленинская, 5	f	large
18827	16415	1278	Алтайский край, Поспелихинский район, поселок Мамонтово, Лермонтова, 10	f	large
109260	16412	1275	Алтайский край, Поспелихинский район, поселок Красноярское, Советская, 17	f	medium
18829	16417	1280	Алтайский край, Поспелихинский район, поселок Котляровка, Центральная, 1	f	small
18830	16418	1281	Алтайский край, Поспелихинский район, поселок Клепечиха, Парковый переулок, 14	f	large
18820	16407	1271	Алтайский край, Поспелихинский район, поселок Калмыцкие Мысы, Трактовая, 35	f	large
86096	16420	1283	Алтайский край, Поспелихинский район, поселок Вавилонский, Дорожная, 18	f	small
18822	16409	1273	Алтайский край, Поспелихинский район, поселок Большевик, Алейская, 5	f	small
18823	16410	1274	Алтайский край, Поспелихинский район, поселок 12 Лет Октября, Школьная, 7	f	medium
18812	16399	1262	Алтайский край, Петропавловский район, поселок Соловьиха, Ленина, 117/1	f	medium
18811	16398	1261	Алтайский край, Петропавловский район, поселок Петропавловское, Партизанская, 21	f	large
18810	16397	1260	Алтайский край, Петропавловский район, поселок Петропавловское, Ленина, 105	f	large
18809	16396	1259	Алтайский край, Петропавловский район, поселок Паутово, Комсомольская, 6	f	medium
18808	16395	1258	Алтайский край, Петропавловский район, поселок Новообинка, Советская, 82	f	medium
18807	16394	1257	Алтайский край, Петропавловский район, поселок Николаевка, Советская, 50	f	medium
18806	16393	1256	Алтайский край, Петропавловский район, поселок Камышенка, Советская, 96	f	large
18805	16392	1255	Алтайский край, Петропавловский район, поселок Зеленый Дол, Фрунзе, 10	f	large
18804	16391	1254	Алтайский край, Петропавловский район, поселок Антоньевка, Советская, 21	f	large
18803	16390	1253	Алтайский край, Петропавловский район, поселок Алексеевка, Колхозная, 1Б	f	large
18796	16383	1246	Алтайский край, Первомайский район, поселок Фирсово, Центральная, 33	f	medium
18770	16357	1220	Алтайский край, Первомайский район, поселок Таловка, Парковая, 6	f	small
18759	16345	1209	Алтайский край, Первомайский район, поселок Старокрайчиково, Центральная, 20	f	small
18799	16386	1249	Алтайский край, Первомайский район, поселок Сосновка, Лесная, 92	f	small
18780	16367	1230	Алтайский край, Первомайский район, поселок Сорочий Лог, Центральная, 5	f	large
18794	16381	1244	Алтайский край, Первомайский район, поселок Солнечное, Первая, 5б	f	small
18783	16370	1233	Алтайский край, Первомайский район, поселок Сибирский, Советская, 1	f	large
67878	16977	1869	Алтайский край, Первомайский район, поселок Сибирский, Кедровая, 5, Строителей	f	large
19392	16978	1870	Алтайский край, Первомайский район, поселок Сибирский, 40 лет РВСН, 9	f	large
19390	16976	1868	Алтайский край, Первомайский район, поселок Сибирский, 40 лет РВСН, 15	f	large
18761	16348	1211	Алтайский край, Первомайский район, поселок Северный, Ленина, 17	f	large
18795	16382	1245	Алтайский край, Первомайский район, поселок Санниково, Новый переулок, 1	f	large
18784	16371	1234	Алтайский край, Первомайский район, поселок Рогуличный, Школьная, 20	t	small
18801	16388	1251	Алтайский край, Первомайский район, поселок Рассказиха, Гуляева-Сусанина, 48	f	small
18760	16346	1210	Алтайский край, Первомайский район, поселок Пурысево, Молодежная, 3	f	small
18793	16380	1243	Алтайский край, Первомайский район, поселок Правда, Школьная, 5а	f	small
18773	16360	1223	Алтайский край, Первомайский район, поселок Повалиха, Школьная, 2	f	large
18765	16352	1215	Алтайский край, Первомайский район, поселок Первомайское, Центральная, 1	f	large
18764	16351	1214	Алтайский край, Первомайский район, поселок Первомайское, Молодежная, 4	f	large
18786	16373	1236	Алтайский край, Первомайский район, поселок Октябрьское, Приозерная, 12	f	small
18789	16376	1239	Алтайский край, Первомайский район, поселок Новочесноковка (Демино), Центральная, 43а	t	small
18767	16354	1217	Алтайский край, Первомайский район, поселок Новоповалиха, Школьная, 16	f	small
18762	16349	1212	Алтайский край, Первомайский район, поселок Новокраюшкино, Школьная, 2	f	small
18788	16375	1238	Алтайский край, Первомайский район, поселок Новокопылово, Лесная, 1а	t	small
18771	16358	1221	Алтайский край, Первомайский район, поселок Новоберезовка, Интернациональная, 1	f	small
17992	15579	422	Алтайский край, Первомайский район, город Новоалтайск, переулок Профсоюзный, 55	f	large
109276	16983	1877	Алтайский край, Первомайский район, Новоалтайск, Прудская, 8	f	\N
18004	15591	434	Алтайский край, Первомайский район, Новоалтайск, Парковая, 2	f	large
17991	15578	421	Алтайский край, Первомайский район, Новоалтайск, П. Корчагина, 1	f	large
17993	15580	423	Алтайский край, Первомайский район, Новоалтайск, Крылова, 5	f	large
19397	15583	1876	Алтайский край, Первомайский район, Новоалтайск, Коммунистическая, 4	f	large
17995	15583	425	Алтайский край, Первомайский район, Новоалтайск, Коммунистическая, 4	f	large
18001	15588	431	Алтайский край, Первомайский район, Новоалтайск, Деповская, 19б	f	large
18000	15587	430	Алтайский край, Первомайский район, Новоалтайск, Деповская, 14	f	large
18015	15600	445	Алтайский край, Первомайский район, город Новоалтайск, Геологов, 72	f	large
18012	15597	442	Алтайский край, Первомайский район, Новоалтайск, Белоярская, 164	f	large
18011	15597	441	Алтайский край, Первомайский район, Новоалтайск, Белоярская, 164	f	large
18802	16389	1252	Алтайский край, Первомайский район, поселок Нижняя Петровка, Школьная, 6	t	small
18772	16359	1222	Алтайский край, Первомайский район, поселок Малая Повалиха, Центральная, 9-2	f	small
18781	16368	1231	Алтайский край, Первомайский район, поселок Логовское, Титова, 6	f	large
18800	16387	1250	Алтайский край, Первомайский район, поселок Лесной, Центральная, 15	f	small
18763	16350	1213	Алтайский край, Первомайский район, поселок Лебяжье, Зеленая, 21	f	small
18776	16363	1226	Алтайский край, Первомайский район, поселок Казачий, Ленина, 14	f	medium
18779	16366	1229	Алтайский край, Первомайский район, поселок Ильича (Черемшаека), Калинина, 2	f	small
18777	16364	1227	Алтайский край, Первомайский район, поселок Зудилово, Пионерская, 24	f	large
18769	16356	1219	Алтайский край, Первомайский район, поселок Журавлиха, Молодежная, 14	f	medium
18787	16374	1237	Алтайский край, Первомайский район, поселок Жилино, Ленина, 29	f	medium
18766	16353	1216	Алтайский край, Первомайский район, поселок Голышево, Плотникова, 23	f	small
18768	16355	1218	Алтайский край, Первомайский район, поселок Волга, Рабочая, 30	f	small
18775	16362	1225	Алтайский край, Первомайский район, поселок Боровиха, Рабочая, 10	f	large
18774	16361	1224	Алтайский край, Первомайский район, поселок Боровиха, Вокзальная, 8	f	large
18798	16385	1248	Алтайский край, Первомайский район, поселок Бобровка, Майская, 4б	f	large
18797	16384	1247	Алтайский край, Первомайский район, поселок Бобровка, Ленина, 79	f	large
18782	16369	1232	Алтайский край, Первомайский район, поселок Бешенцево, Буферная, 56	f	small
18790	16377	1240	Алтайский край, Первомайский район, поселок Баюновские Ключи, Центральная, 24а	f	large
18758	16344	1208	Алтайский край, Первомайский район, поселок Акулово, Ленина, 47	f	medium
18751	16337	1201	Алтайский край, Панкрушихинский район, поселок Урываево, Ленина, 8	f	small
86058	16333	1197	Алтайский край, Панкрушихинский район, поселок Романово, Школьная, 34	f	small
18741	16327	1191	Алтайский край, Панкрушихинский район, поселок Подойниково, Советская, 2	f	medium
18742	16328	1192	Алтайский край, Панкрушихинский район, поселок Первомайский, пер.Школьный, 4	t	small
18738	16324	1188	Алтайский край, Панкрушихинский район, поселок Панкрушиха, Ленина, 25	f	large
18739	16325	1189	Алтайский край, Панкрушихинский район, поселок Панкрушиха, Зеленая, 2	f	large
86080	16340	1204	Алтайский край, Панкрушихинский район, поселок Павловский, 49	t	small
18745	16331	1195	Алтайский край, Панкрушихинский район, поселок Луковка, Ленинская, 34	f	medium
18746	16332	1196	Алтайский край, Панкрушихинский район, поселок Ленский, Школьная, 1	t	small
18748	16334	1198	Алтайский край, Панкрушихинский район, поселок Кызылту, Центральная, 2	f	small
18756	16342	1206	Алтайский край, Панкрушихинский район, поселок Кривое, Центральная, 1	f	small
18744	16330	1194	Алтайский край, Панкрушихинский район, поселок Конево, Центральная, 10	f	small
18753	16339	1203	Алтайский край, Панкрушихинский район, поселок Зятьково, Новостройка, 1	f	medium
18752	16338	1202	Алтайский край, Панкрушихинский район, поселок Зыково, Школьная, 10	f	small
86098	16528	1394	Алтайский край, Панкрушихинский район, поселок Заречный, Центральная, 3	t	small
18743	16329	1193	Алтайский край, Панкрушихинский район, поселок Высокая Грива, Центральная, 21	f	small
18749	16335	1199	Алтайский край, Панкрушихинский район, поселок Велижанка, Центральная, 38	f	medium
18755	16341	1205	Алтайский край, Панкрушихинский район, поселок Борисовский, Кузнецова, 13	f	small
18740	16326	1190	Алтайский край, Панкрушихинский район, поселок Березовский, пер.Школьный, 9	f	medium
86095	16343	1207	Алтайский край, Панкрушихинский район, поселок Береговое, Клубная, 1	f	small
18750	16336	1200	Алтайский край, Панкрушихинский район, поселок Алексеевский, Центральная, 3	f	small
18716	16302	1165	Алтайский край, Павловский район, поселок имени Мамонтова, Центральная, 6	t	small
18730	16316	1179	Алтайский край, Павловский район, поселок Шахи, Загайнова, 32	f	large
18733	16319	1182	Алтайский край, Павловский район, поселок Чернопятово, Молодежная, 32	f	medium
18722	16308	1171	Алтайский край, Павловский район, поселок Черемное, Школьная, 2	f	large
18723	16309	1172	Алтайский край, Павловский район, поселок Черемное, Центральная, 18	f	medium
18721	16307	1170	Алтайский край, Павловский район, поселок Черемное, Ленина, 9	f	large
18728	16314	1177	Алтайский край, Павловский район, поселок Урожайный, Целинная, 14	f	small
18724	16310	1173	Алтайский край, Павловский район, поселок Стуково, Центральная, 91	f	medium
18717	16303	1166	Алтайский край, Павловский район, поселок Советский, Центральная, 14	f	small
18736	16322	1185	Алтайский край, Павловский район, поселок Сибирские Огни, Майская, 4	f	medium
18725	16311	1174	Алтайский край, Павловский район, поселок Сараи, Сарайская, 85/1	f	small
109259	16296	1160	Алтайский край, Павловский район, поселок Рогозиха, Школьная, 3А	f	medium
67894	16318	1181	Алтайский край, Павловский район, поселок Прутской, Центральная, 43	f	large
18702	16287	1151	Алтайский край, Павловский район, поселок Павловск, Студенческая, 12	f	large
18703	16288	1152	Алтайский край, Павловский район, поселок Павловск, Свирина, 10	f	large
18704	16289	1153	Алтайский край, Павловский район, поселок Павловск, Пионерская, 13	f	large
18705	16290	1154	Алтайский край, Павловский район, поселок Павловск, Малахова, 109	f	large
67919	16291	1155	Алтайский край, Павловский район, поселок Павловск, Ленина, 11	f	large
18707	16292	1156	Алтайский край, Павловский район, поселок Павловск, Красный Алтай, 66	f	large
18701	16286	1150	Алтайский край, Павловский район, поселок Павловск, Заводская, 4	f	large
86056	16315	1178	Алтайский край, Павловский район, поселок Озерный, Озерная, 22	t	small
86071	16317	1180	Алтайский край, Павловский район, поселок Нагорный, Партизанская, 11	t	small
86072	16306	1169	Алтайский край, Павловский район, поселок Молодежный, Школьная, 7	f	small
18713	16298	1162	Алтайский край, Павловский район, поселок Лебяжье, Центральная, 42	f	medium
19332	16917	1808	Алтайский край, Павловский район, поселок Красный Май, Совхозная, 11	t	small
18735	16321	1184	Алтайский край, Павловский район, поселок Красный Май, Майская, 14	f	small
18710	16295	1159	Алтайский край, Павловский район, поселок Красная Дубрава, Ленина, 1	f	small
18727	16313	1176	Алтайский край, Павловский район, поселок Комсомольский, Московская, 8	f	large
18719	16305	1168	Алтайский край, Павловский район, поселок Колыванское, Гагарина, 34	f	large
18734	16320	1183	Алтайский край, Павловский район, поселок Касмала, Калинина, 32	t	small
86074	16323	1186	Алтайский край, Павловский район, поселок Жуковка, Октябрьская, 31	f	small
18709	16294	1158	Алтайский край, Павловский район, поселок Елунино, Чкалова, 23	f	medium
18712	16297	1161	Алтайский край, Павловский район, поселок Бурановка, Школьная, 1	f	medium
86053	16293	1157	Алтайский край, Павловский район, поселок Боровиково, Партизанская, 4	f	small
18718	16304	1167	Алтайский край, Павловский район, поселок Арбузовка, Центральная, 57	f	small
18715	16300	1164	Алтайский край, Павловский район, поселок Арбузовка, Молодежная, 11	f	small
18714	16299	1163	Алтайский край, Павловский район, Арбузовка, Ленина, 1А, станция Арбузовка	f	small
18696	16280	1145	Алтайский край, Новичихинский район, поселок Токарево, Садовая, 84	f	medium
18695	16279	1144	Алтайский край, Новичихинский район, поселок Солоновка, Школьная, 1А	f	medium
18687	16271	1136	Алтайский край, Новичихинский район, поселок Поломошное, Школьная, 1	f	medium
18689	16273	1138	Алтайский край, Новичихинский район, поселок Петровский, Центральная, 1	f	small
18692	16276	1141	Алтайский край, Новичихинский район, поселок Павловка, Центральная, 77	f	small
18685	16268	1134	Алтайский край, Новичихинский район, поселок Новичиха, Морозова, 2	f	large
5285	31904	478	республика Дагестан, Дербент, Тахо-Годи, 1	f	large
18686	16270	1135	Алтайский край, Новичихинский район, поселок Новичиха, Красноармейская, 18	f	large
18690	16274	1139	Алтайский край, Новичихинский район, поселок Невский, Партизанская, 4	f	small
18697	16281	1146	Алтайский край, Новичихинский район, поселок Мельниково, Ленинская, 104	f	medium
18691	16275	1140	Алтайский край, Новичихинский район, поселок Мамонтово, Барнаульская	t	small
86094	16272	1137	Алтайский край, Новичихинский район, поселок Лобаниха, Октябрьская, 6	f	small
18693	16277	1142	Алтайский край, Новичихинский район, поселок Красноярка, Школьная, 8	f	small
18700	16284	1149	Алтайский край, Новичихинский район, поселок Ильинский, Центральная, 24	f	small
18699	16283	1148	Алтайский край, Новичихинский район, поселок Долгово, Кооперативная, 15	f	medium
18694	16278	1143	Алтайский край, Новичихинский район, поселок 10 Лет Октября, Островского, 2	f	small
18677	16260	1126	Алтайский край, Немецкий район, поселок Николаевка, Садова, 27	f	medium
18683	16266	1132	Алтайский край, Немецкий Национальный район, поселок Шумановка, Ленина, 44	f	medium
18682	16265	1131	Алтайский край, Немецкий Национальный район, поселок Редкая Дубрава, Октябрьская, 55	f	large
18680	16263	1129	Алтайский край, Немецкий Национальный район, поселок Протасово, Школьная, 25а	f	medium
18681	16264	1130	Алтайский край, Немецкий Национальный район, поселок Подсосново, Гагарина, 86	f	large
18674	16257	1123	Алтайский край, Немецкий Национальный район, поселок Кусак, Энгельса, 39	f	large
18676	16259	1125	Алтайский край, Немецкий Национальный район, поселок Камыши, Луговая, 27а	f	small
18671	16254	1120	Алтайский край, Немецкий Национальный район, поселок Гальбштадт, Клубная, 4	f	large
18664	16246	1113	Алтайский край, Михайловский район, поселок Ракиты, Украинская, 114 А	f	large
18665	16247	1114	Алтайский край, Михайловский район, поселок Полуямки, Советская, 2	f	medium
18669	16251	1118	Алтайский край, Михайловский район, поселок Николаевка, Лисевцева, 14	f	medium
18670	16252	1119	Алтайский край, Михайловский район, поселок Неводное, Кравченко, 38	f	small
18666	16248	1115	Алтайский край, Михайловский район, поселок Назаровка, Ленина, 76 Г	f	small
18663	16245	1112	Алтайский край, Михайловский район, поселок Михайловское, Шоссейная, 74	f	large
18662	16244	1111	Алтайский край, Михайловский район, поселок Михайловское, Крупской, 37	f	large
18661	16243	1110	Алтайский край, Михайловский район, поселок Михайловское, К.Маркса, 38	f	large
18659	16241	1108	Алтайский край, Михайловский район, поселок Михайловское, К.Маркса, 13	f	large
18657	16239	1106	Алтайский край, Михайловский район, поселок Малиновое Озеро, Советская, 20	f	medium
18658	16240	1107	Алтайский край, Михайловский район, поселок Малиновое Озеро, Мамонтова, 17 А	f	large
18668	16250	1117	Алтайский край, Михайловский район, поселок Бастан, Горького, 2	f	medium
18667	16249	1116	Алтайский край, Михайловский район, поселок Ащегуль, Ленина, 35	f	small
18656	16238	1105	Алтайский край, Мамонтовский район, поселок Черная Курья, Новая, 2-А	f	medium
18655	16237	1104	Алтайский край, Мамонтовский район, поселок Украинка, Центральная, 2	f	small
18654	16236	1103	Алтайский край, Мамонтовский район, поселок Травное, Молодежная, 38	f	small
18653	16235	1102	Алтайский край, Мамонтовский район, поселок Суслово, Партизанская, 59	f	medium
18651	16233	1100	Алтайский край, Мамонтовский район, поселок Покровка, Победы, 7	f	medium
18652	16234	1101	Алтайский край, Мамонтовский район, поселок Первомайский, Магистральная, 6	f	medium
18650	16232	1099	Алтайский край, Мамонтовский район, поселок Островное (Семеновка), Гребенникова, 34	f	large
18649	16231	1098	Алтайский край, Мамонтовский район, поселок Малые Бутырки, Советская, 30	f	medium
18643	16225	1092	Алтайский край, Мамонтовский район, поселок Костин Лог, Советская, 50	f	large
67917	16223	1090	Алтайский край, Мамонтовский район, поселок Корчино, Комсомольская, 22	f	large
18642	16224	1091	Алтайский край, Мамонтовский район, поселок Комсомольский, Октябрьская, 13-Б	f	medium
18639	16221	1088	Алтайский край, Мамонтовский район, поселок Кадниково, Партизанская, 79	f	medium
18638	16220	1087	Алтайский край, Мамонтовский район, поселок Ермачиха, Мира, 13	f	small
18637	16219	1086	Алтайский край, Мамонтовский район, поселок Гришенское, Центральная, 104	f	medium
109258	16218	1085	Алтайский край, Мамонтовский район, поселок Буканское, Победы, 30	f	medium
18632	16214	1081	Алтайский край, Локтевский район, поселок Устьянка, Кирова, 49	f	medium
18620	16201	1069	Алтайский край, Локтевский район, поселок Успенка, Юбилейная, 23	f	medium
18627	16209	1076	Алтайский край, Локтевский район, поселок Советский Путь, Школьная, 10б	f	medium
18621	16203	1070	Алтайский край, Локтевский район, поселок Самарка, Центральная, 67	f	medium
18628	16210	1077	Алтайский край, Локтевский район, поселок Ремовский, Гагарина, 25	f	medium
18631	16213	1080	Алтайский край, Локтевский район, поселок Покровка, Школьная, 4	f	medium
18629	16211	1078	Алтайский край, Локтевский район, поселок Новенькое, Школьная, 42	f	small
18626	16208	1075	Алтайский край, Локтевский район, поселок Николаевка, Клочкова, 28	f	small
18623	16205	1072	Алтайский край, Локтевский район, поселок Масальский, Советская, 11	f	large
18630	16212	1079	Алтайский край, Локтевский район, поселок Локоть, Советская, 34	f	large
19133	16717	1607	Алтайский край, Локтевский район, поселок Крючки, Центральная, 19	f	small
18619	16200	1068	Алтайский край, Локтевский район, поселок Кировский, Школьная, 12	f	medium
18622	94919	1071	Алтайский край, Локтевский район, поселок Золотуха, Молодежная, 20а	f	medium
18624	16206	1073	Алтайский край, Локтевский район, поселок Ермошиха, Школьная, 3	f	small
18611	16192	1060	Алтайский край, Локтевский район, Горняк, Усадебная, 15	f	large
18613	16194	1062	Алтайский край, Локтевский район, Горняк, Островского, 35	f	large
18635	16217	1084	Алтайский край, Локтевский район, поселок Гилево, Школьная, 1	f	medium
18625	16207	1074	Алтайский край, Локтевский район, поселок Георгиевка, Емцева, 22а	f	small
18634	16216	1083	Алтайский край, Локтевский район, поселок Вторая Каменка, Трибунского, 69	f	medium
18633	16215	1082	Алтайский край, Локтевский район, поселок Александровка, Советская, 30	f	medium
18601	16181	1049	Алтайский край, Кытмановский район, поселок Черкасово, Центральная, 40	t	small
18595	16175	1043	Алтайский край, Кытмановский район, поселок Червово, Молодежная, 30	t	medium
18592	16172	1040	Алтайский край, Кытмановский район, поселок Улус-Тараба, Новая, 28	f	small
18603	16183	1051	Алтайский край, Кытмановский район, поселок Тяхта, Молодежная, 4	f	small
18606	16187	1054	Алтайский край, Кытмановский район, поселок Тягун, Лесная, 6	f	medium
18602	16182	1050	Алтайский край, Кытмановский район, поселок Сунгай, Максакова, 22	t	medium
86092	16171	1039	Алтайский край, Кытмановский район, поселок Старая Тараба, Черемнова, 16	f	small
86093	16191	1058	Алтайский край, Кытмановский район, поселок Сосновый Лог, Садовая, 10а	f	small
18604	16184	1052	Алтайский край, Кытмановский район, поселок Семено-Красилово, Черемушки, 11	f	small
86060	16179	1047	Алтайский край, Кытмановский район, поселок Порошино, Центральная, 58	t	small
18593	16173	1041	Алтайский край, Кытмановский район, поселок Петрушиха, Школьная, 12	f	small
18597	16177	1045	Алтайский край, Кытмановский район, поселок Отрадное, Черемушки, 44	t	small
18600	16180	1048	Алтайский край, Кытмановский район, поселок Октябрьский, Советская, 6	f	large
86087	15935	790	Алтайский край, Кытмановский район, поселок Озерное, Пушкина, 2	t	small
18598	16178	1046	Алтайский край, Кытмановский район, поселок Новохмелевка, Новая, 10	t	small
18609	16190	1057	Алтайский край, Кытмановский район, поселок Новоозерное, Центральная, 4	f	small
18596	16176	1044	Алтайский край, Кытмановский район, поселок Новая Тараба, Целинная, 39	f	medium
18607	16188	1055	Алтайский край, Кытмановский район, поселок Кытманушка, Республики, 24а	f	small
18589	16169	1037	Алтайский край, Кытмановский район, поселок Кытманово, Советская, 11	f	large
18590	16170	1038	Алтайский край, Кытмановский район, поселок Кытманово, Комсомольская, 41	f	large
18594	16174	1042	Алтайский край, Кытмановский район, поселок Курья, Весенняя, 6	f	small
86076	16186	1053	Алтайский край, Кытмановский район, поселок Каменка, Школьная, 7	t	small
18587	16167	1035	Алтайский край, Кытмановский район, поселок Калиновский, Чумышская, 42а	t	small
18588	16168	1036	Россия, Алтайский край, Кытмановский район, поселок Заречное	t	small
18330	15911	766	Алтайский край, Кытмановский район, поселок Жуланиха, Ленина, 6	t	medium
18450	16031	888	Алтайский край, Ключевский район, поселок Петровка, Чапаева, 17	f	small
18586	16166	1034	Алтайский край, Кытмановский район, поселок Дмитро-Титово, Целинная, 30	f	medium
18608	16189	1056	Алтайский край, Кытмановский район, поселок Беспалово, Западная, 38	t	small
18571	16151	1017	Алтайский край, Курьинский район, поселок имени 8 Марта, Центральная, 29	f	small
18577	16157	1023	Алтайский край, Курьинский район, поселок Усть-Таловка, Полевая, 50	f	medium
18578	16158	1024	Алтайский край, Курьинский район, поселок Трусово, Сибирская, 7	f	medium
18576	16156	1022	Алтайский край, Курьинский район, поселок Ручьёво, Центральная, 30	f	small
18573	16153	1019	Алтайский край, Курьинский район, поселок Подхоз, Центральная, 17	f	small
18582	16162	1028	Алтайский край, Курьинский район, поселок Новофирсово, Локтевская, 20	f	medium
18584	16164	1030	Алтайский край, Курьинский район, поселок Новознаменка, Краснознаменская, 22	f	small
18585	16165	1031	Алтайский край, Курьинский район, поселок Курья, Советская, 52	f	large
18575	16155	1021	Алтайский край, Курьинский район, поселок Курья, Гагарина, 36	f	large
18581	16161	1027	Алтайский край, Курьинский район, поселок Кузнецово, Центральная, 51	f	medium
18583	16163	1029	Алтайский край, Курьинский район, поселок Краснознаменка, Коммунистическая, 14	f	medium
18572	16152	1018	Алтайский край, Курьинский район, поселок Колывань, Ломоносова, 2	f	large
18574	16154	1020	Алтайский край, Курьинский район, поселок Казанцево, Школьная, 15	f	small
18579	16159	1025	Алтайский край, Курьинский район, поселок Ивановка, Парковый переулок, 4а	f	medium
18580	16160	1026	Алтайский край, Курьинский район, поселок Горновка, Центральная, 35	f	small
18570	16150	1016	Алтайский край, Курьинский район, поселок Бугрышиха, Алтайская, 12	t	small
18560	16140	1006	Алтайский край, Кулундинский район, поселок Троицк, Молодежная, 14	f	small
18557	16137	1003	Алтайский край, Кулундинский район, поселок Смирненькое, Ленина, 36	t	small
18552	16132	998	Алтайский край, Кулундинский район, поселок Сергеевка, Юбилейная, 34	f	small
18556	16136	1002	Алтайский край, Кулундинский район, поселок Семеновка, Центральная, 59	f	small
18555	16135	1001	Алтайский край, Кулундинский район, поселок Попасное, Попасновская, 32	t	small
18558	16138	1004	Алтайский край, Кулундинский район, поселок Октябрьский, Советская, 5	f	large
18561	16141	1007	Алтайский край, Кулундинский район, поселок Новопетровка, Восточная, 3ф	f	small
18568	16148	1014	Алтайский край, Кулундинский район, поселок Мирабилит, Садовая, 18	f	small
18553	16133	999	Алтайский край, Кулундинский район, поселок Курск, Ленина, 53	f	medium
18550	16130	996	Алтайский край, Кулундинский район, поселок Кулунда, Советская, 67	f	large
18546	16126	992	Алтайский край, Кулундинский район, поселок Кулунда, Советская, 28	f	large
19396	16982	1875	Алтайский край, Кулундинский район, поселок Кулунда, Пушкина, 17а	f	large
109257	16127	993	Алтайский край, Кулундинский район, поселок Кулунда, Песчаная, 19	f	medium
19416	16993	1898	Алтайский край, Кулундинский район, поселок Кулунда, Октябрьская, 155	f	large
19421	16129	1907	Алтайский край, Кулундинский район, поселок Кулунда, Ломоносова, 10	f	small
19420	16129	1906	Алтайский край, Кулундинский район, поселок Кулунда, Ломоносова, 10	f	small
18549	16129	995	Алтайский край, Кулундинский район, поселок Кулунда, Ломоносова, 10	f	large
19417	16128	1899	Алтайский край, Кулундинский район, поселок Кулунда, Ленина, 46	f	medium
18548	16128	994	Алтайский край, Кулундинский район, поселок Кулунда, Ленина, 46	f	large
18565	16145	1011	Алтайский край, Кулундинский район, поселок Константиновка, Центральная, 41	f	small
18569	16149	1015	Алтайский край, Кулундинский район, поселок Кирей, Амангельды, 1	f	small
18551	16131	997	Алтайский край, Кулундинский район, поселок Златополь, Партизанская, 13	f	medium
18563	16143	1009	Алтайский край, Кулундинский район, поселок Екатериновка, Центральная, 39	f	small
18567	16147	1013	Алтайский край, Кулундинский район, поселок Городецк, Молодежная, 6	f	small
18566	16146	1012	Алтайский край, Кулундинский район, поселок Воздвиженка, Советская, 27	f	small
18554	16134	1000	Алтайский край, Кулундинский район, поселок Виноградовка, Центральная, 39	t	small
18564	16144	1010	Алтайский край, Кулундинский район, поселок Белоцерковка, Целинная, 19	t	small
86091	16142	1008	Алтайский край, Кулундинский район, поселок Ананьевка, Восточная, 28а	f	small
86090	16124	988	Алтайский край, Крутихинский район, поселок Радостный, Михайловичей, 11	f	small
18533	16114	977	Алтайский край, Крутихинский район, Прыганка, Крутихинская, 1	f	medium
18545	16125	989	Алтайский край, Крутихинский район, поселок Подборный, Центральная, 40	f	small
18538	16119	982	Алтайский край, Крутихинский район, поселок Подборный, Центральная, 23	f	small
86089	16123	987	Алтайский край, Крутихинский район, поселок Московский, Центральная, 14	f	small
18542	16122	986	Алтайский край, Крутихинский район, поселок Масляха, Зеленая, 16	f	small
18541	16121	985	Алтайский край, Крутихинский район, поселок Маловолчанка, Ленина, 98	f	medium
18539	94918	983	Алтайский край, Крутихинский район, поселок Крутиха, Ленинградская, 23	f	large
18540	16120	984	Алтайский край, Крутихинский район, поселок Крутиха, Ленинградская, 15	f	large
18537	16118	981	Алтайский край, Крутихинский район, поселок Караси, Карасевская, 8А	f	small
109256	16117	980	Алтайский край, Крутихинский район, поселок Заковряшино, Садовая, 4	f	medium
18535	16116	979	Алтайский край, Крутихинский район, поселок Долганка, Гагарина, 5	f	large
18534	94917	978	Алтайский край, Крутихинский район, поселок Волчно-Бурлинская, Бурлинская, 25	f	large
109255	16113	976	Алтайский край, Крутихинский район, поселок Буян, Целинная, 10	f	medium
18531	94916	975	Алтайский край, Крутихинский район, поселок Боровое, Советская, 10	f	small
86066	16111	974	Алтайский край, Крутихинский район, поселок Большой Лог, Большелоговская, 12/1	f	small
109254	16109	972	Алтайский край, Краснощековский район, поселок Чинета, Березовая, 18	t	medium
18519	16099	963	Алтайский край, Краснощековский район, поселок Харлово, Колхозная, 28	f	large
18529	16110	973	Алтайский край, Краснощековский район, поселок Усть-Чагырка, Молодежная, 3а	t	small
18527	16108	971	Алтайский край, Краснощековский район, поселок Усть-Пустынка, Самакаева, 1	f	small
18524	16104	968	Алтайский край, Краснощековский район, поселок Усть-Козлуха, Советская, 30а	f	medium
86042	16096	960	Алтайский край, Краснощековский район, поселок Усть-Белое, Школьная, 11	f	small
109251	16095	959	Алтайский край, Краснощековский район, поселок Суетка, Советская, 61	f	medium
67916	16103	967	Алтайский край, Краснощековский район, поселок Новошипуново, Мира, 38	f	large
18525	16105	969	Алтайский край, Краснощековский район, поселок Маралиха, Ленина, 1	f	large
109253	16107	970	Алтайский край, Краснощековский район, поселок Куйбышево, Школьный переулок, 16	f	medium
18511	16091	955	Алтайский край, Краснощековский район, поселок Краснощеково, Садовая, 17	f	large
67913	16093	957	Алтайский край, Краснощековский район, поселок Краснощеково, Ленина, 121	f	large
67914	16097	961	Алтайский край, Краснощековский район, поселок Карпово 2-е, Школьная, 10	f	large
86045	16098	962	Алтайский край, Краснощековский район, поселок Карпово 1-е, 12	f	small
67915	16100	964	Алтайский край, Краснощековский район, поселок Березовка, Гагарина, 10	f	large
18792	16379	1242	Алтайский край, Краснощековский район, поселок Березовка, 40 лет Победы, 38	f	large
18791	16378	1241	Алтайский край, Краснощековский район, поселок Березовка, 40 лет Победы, 44	f	large
18514	16094	958	Алтайский край, Краснощековский район, поселок Акимовка, Новая, 19	f	medium
18510	16090	952	Алтайский край, Красногорский район, поселок имени Фрунзе, Центральная, 26	f	small
109250	16085	947	Алтайский край, Красногорский район, поселок Усть-Кажа, Центральная, 26	f	medium
67875	16082	944	Алтайский край, Красногорский район, поселок Усть-Иша, Советская, 22	f	large
18493	16073	935	Алтайский край, Красногорский район, поселок Ужлеп, Дорожная, 12	f	small
18496	16076	938	Алтайский край, Красногорский район, поселок Талый, Центральная, 19	f	small
18495	16075	937	Алтайский край, Красногорский район, поселок Тайна, Заречная, 25	t	small
18487	94915	929	Алтайский край, Красногорский район, поселок Старая Суртайка, Центральная, 28	t	small
109249	16079	941	Алтайский край, Красногорский район, поселок Соусканиха, Центральная, 20	t	medium
18508	16088	950	Алтайский край, Красногорский район, село Сосновка, Центральная, 3	t	small
109248	16074	936	Алтайский край, Красногорский район, поселок Новозыково, Центральная, 25	f	medium
18488	16068	930	Алтайский край, Красногорский район, поселок Новая Суртайка, Береговая, 13 , кв.1	t	small
18486	16066	928	Алтайский край, Красногорский район, поселок Мост-Иша, Автомобилистов, 10	f	small
18497	16077	939	Алтайский край, Красногорский район, поселок Мануильское, переулок Клубный, 6	f	small
86043	16087	949	Алтайский край, Красногорский район, поселок Макарьевское, Центральная, 42	t	small
18498	16078	940	Алтайский край, Красногорский район, поселок Луговое, Зеленая, 12	t	small
18501	16081	943	Алтайский край, Красногорский район, поселок Лебяжье, Центральная, 15	t	small
18491	16071	933	Алтайский край, Красногорский район, поселок Красногорское, пер.Рабочий, 4	f	large
18490	16070	932	Алтайский край, Красногорский район, поселок Красногорское, Юбилейная, 14	f	large
18489	16069	931	Алтайский край, Красногорский район, поселок Красногорское, Советская, 84	f	large
18504	16084	946	Алтайский край, Красногорский район, поселок Карагуж, Алтухова, 9	f	small
18492	16072	934	Алтайский край, Красногорский район, поселок Карагайка, переулок Школьный, 1	t	small
18500	16080	942	Алтайский край, Красногорский район, поселок Каменка, Центральная, 12	t	small
18506	16086	948	Алтайский край, Красногорский район, поселок Кажа, Центральная, 32	t	small
18503	16083	945	Алтайский край, Красногорский район, поселок Горный, Советская, 7А	t	small
67874	16065	927	Алтайский край, Красногорский район, поселок Быстрянка, Победы, 19	f	large
67873	16064	926	Алтайский край, Красногорский район, поселок Березовка, Советская, 49А	f	large
18509	16089	951	Алтайский край, Красногорский район, поселок Балыкса, Центральная, 28 кв.2	t	small
18473	16054	911	Алтайский край, Косихинский район, село Филатово, Центральная, 28	f	small
18469	16050	907	Алтайский край, Косихинский район, поселок Украинский, Центральная, 2	f	medium
18475	16056	913	Алтайский край, Косихинский район, поселок Сохарево, Советская, 5	f	small
18481	16061	919	Алтайский край, Косихинский район, поселок Романово, Советская, 22	f	small
18461	16042	899	Алтайский край, Косихинский район, поселок Пустынь, Центральная, 3	f	small
18464	16045	902	Алтайский край, Косихинский район, поселок Полковниково, Школьная, 1А	f	medium
18479	16060	917	Алтайский край, Косихинский район, поселок Плотниково, Верхняя, 30	f	small
18468	16049	906	Алтайский край, Косихинский район, поселок Озеро-Красилово, Школьная, 1	f	small
18467	16048	905	Алтайский край, Косихинский район, поселок Овчинниково, Центральная, 23	f	small
67898	16043	900	Алтайский край, Косихинский район, поселок Налобиха, Тельмана, 64	f	large
18463	16044	901	Алтайский край, Косихинский район, поселок Налобиха, Республики, 5	f	large
18465	16046	903	Алтайский край, Косихинский район, поселок Малахово, Кооперативная, 7	f	medium
18476	16057	914	Алтайский край, Косихинский район, поселок Лучевое, Центральная, 6	f	small
18472	16053	910	Алтайский край, Косихинский район, поселок Лосиха, Победы, 5	f	medium
86039	16052	909	Алтайский край, Косихинский район, поселок Логовое, Садовая, 4/1	f	small
18458	16039	896	Алтайский край, Косихинский район, поселок Косиха, Рабочая, 76	f	medium
18460	16041	898	Алтайский край, Косихинский район, поселок Косиха, Луговая, 1А	f	medium
18459	16040	897	Алтайский край, Косихинский район, поселок Косиха, Комсомольская, 2	f	large
18466	16047	904	Алтайский край, Косихинский район, поселок Контошино, Центральная, 56	f	medium
18474	16055	912	Алтайский край, Косихинский район, поселок Каркавино, Рабочая, 22	f	small
18483	16063	921	Алтайский край, Косихинский район, поселок Глушинка, Садовая, 9	f	small
18470	16051	908	Алтайский край, Косихинский район, поселок Восход, Школьная, 5	f	small
18477	16058	915	Алтайский край, Косихинский район, поселок Верх-Жилино, Молодежная, 38А	f	small
18478	16059	916	Алтайский край, Косихинский район, поселок Верх-Бобровка, Центральная, 57	f	small
18482	16062	920	Алтайский край, Косихинский район, поселок Баюново, Элеваторная, 6	f	small
18444	16025	882	Алтайский край, Ключевский район, поселок Целинный, Пушкина, 4	f	large
67912	16026	883	Алтайский край, Ключевский район, поселок Северка, Октябрьская, 2	f	large
18457	16038	895	Алтайский край, Ключевский район, поселок Покровка, Пролетарская, 56	f	small
18447	16028	885	Алтайский край, Ключевский район, поселок Платовка, Восточная, 18	f	small
18455	16036	893	Алтайский край, Ключевский район, поселок Петухи, Кирова, 5	f	medium
18449	16030	887	Алтайский край, Ключевский район, поселок Новополтава, Пролетарская, 7	f	medium
18452	16033	890	Алтайский край, Ключевский район, поселок Красный Яр, Западная, 3	f	small
18442	16023	880	Алтайский край, Ключевский район, поселок Ключи, Урицкого, 50	f	large
18443	16024	881	Алтайский край, Ключевский район, поселок Ключи, Делегатская, 3	f	large
18454	16035	892	Алтайский край, Ключевский район, поселок Каип, Центральная, 24	f	medium
18448	16029	886	Алтайский край, Ключевский район, поселок Истимис, Кирова, 1а	f	medium
18451	16032	889	Алтайский край, Ключевский район, поселок Зеленая Поляна, Школьный, 1	f	small
18456	16037	894	Алтайский край, Ключевский район, поселок Западный Угол, Центральная, 19	f	small
18446	16027	884	Алтайский край, Ключевский район, поселок Васильчуки, Центральная, 13	f	large
18436	16017	872	Алтайский край, Каменский район, поселок Филипповский, Сибирская, 4-б	f	small
18439	94914	875	Алтайский край, Каменский район, поселок Толстовский, Центральная, 47	f	medium
18440	16021	876	Алтайский край, Каменский район, поселок Тамбовский, Тамбовская, 58	f	small
18420	16001	856	Алтайский край, Каменский район, поселок Столбово, Мичурина, 41	t	medium
18431	16012	867	Алтайский край, Каменский район, поселок Самарский, Центральная, 15	f	small
18430	16011	866	Алтайский край, Каменский район, поселок Рыбное, Гагарина, 8	f	medium
18434	94912	870	Алтайский край, Каменский район, поселок Поперечное, Центральная, 26	f	medium
18429	16010	865	Алтайский край, Каменский район, поселок Плотниково, Совхозная, 5	f	small
18419	94908	855	Алтайский край, Каменский район, поселок Октябрьский, Центральная, 22а	f	small
18425	16006	861	Алтайский край, Каменский район, поселок Обское, Озерная, 1-г	f	small
18438	94913	874	Алтайский край, Каменский район, поселок Новоярки, Центральная, 72	f	large
18426	16007	862	Алтайский край, Каменский район, поселок Мыски, юбилейная, 2	f	small
18423	16004	859	Алтайский край, Каменский район, поселок Малетино, Январская, 33	t	small
18427	94909	863	Алтайский край, Каменский район, поселок Луговое, Школьная, 2	f	medium
18433	94911	869	Алтайский край, Каменский район, поселок Корнилово, Каменская, 82	f	large
18422	16003	858	Алтайский край, Каменский район, поселок Ключи, Центральная, 7	t	small
17976	15566	406	Алтайский край, Каменский район, Камень-на-Оби, Северная, 56	f	large
17970	15561	400	Алтайский край, Каменский район, Камень-на-Оби, Пушкина, 55	f	large
17975	15565	405	Алтайский край, Каменский район, Камень-на-Оби, Первомайская, 115	f	large
17974	15565	404	Алтайский край, Каменский район, Камень-на-Оби, Первомайская, 115	f	large
17973	15564	403	Алтайский край, Каменский район, Камень-на-Оби, Ленина, 53	f	large
17988	15576	418	Алтайский край, Каменский район, Камень-на-Оби, Кондратюка, 5	f	small
17977	15567	407	Алтайский край, Каменский район, Камень-на-Оби, Кондратюка, 32	f	medium
17987	15575	417	Алтайский край, Каменский район, Камень-на-Оби, Колесникова, 362	f	medium
17966	15558	396	Алтайский край, Каменский район, Камень-на-Оби, Гоголя, 91	f	large
18428	16009	864	Алтайский край, Каменский район, поселок Калиновка, Рабочая, 8	f	small
18437	16018	873	Алтайский край, Каменский район, поселок Зеленая Дубрава, Центральная, 10-б	f	small
18416	15997	852	Алтайский край, Каменский район, поселок Духовая, Весенняя, 21	t	small
18421	16002	857	Алтайский край, Каменский район, поселок Дресвянка, школьная, 9	t	small
109247	16005	860	Алтайский край, Каменский район, поселок Гонохово, Советская, 71	f	medium
18432	94910	868	Алтайский край, Каменский район, поселок Ветренотелеутское, Центральная, 60	f	small
18417	94907	853	Алтайский край, Каменский район, поселок Верх-Аллак, Школьная, 7	f	small
18415	15996	851	Алтайский край, Каменский район, поселок Аллак, Тамбовская, 4	t	medium
18418	15999	854	Алтайский край, Каменский район, поселок III Интернационал, Интернациональная, 29	t	small
18414	15995	850	Алтайский край, Калманский район, поселок Шилово, Школьная, 10	f	small
18413	15994	849	Алтайский край, Калманский район, поселок Шадрино, Кировская, 76	f	small
18412	15993	848	Алтайский край, Калманский район, поселок Усть-Алейка, Партизанская, 41	f	medium
18411	15992	847	Алтайский край, Калманский район, поселок Троицк, Большевистская, 67	f	medium
18409	15990	845	Алтайский край, Калманский район, поселок Панфилово, Пензенская, 11	f	small
18726	16312	1175	Алтайский край, Калманский район, поселок Новые Зори, Комсомольская, 2	f	large
109282	17001	1921	Алтайский край, Калманский район, поселок Новороманово, Школьная, 19	f	\N
109281	17000	1920	Алтайский край, Калманский район, поселок Новороманово, Строителшьная, 5	f	\N
18407	15988	843	Алтайский край, Калманский район, поселок Новороманово, Коммунистическая, 26	f	large
18406	15987	842	Алтайский край, Калманский район, поселок Новобарнаулка, Новобарнаульская, 15	t	small
18405	15986	841	Алтайский край, Калманский район, поселок Логовской, Логовская, 10	f	small
18404	15985	840	Алтайский край, Калманский район, поселок Кубанка, Центральная, 28	f	medium
109246	15991	846	Алтайский край, Калманский район, поселок Калманка, Чаузова, 14	f	medium
109280	16999	1919	Алтайский край, Калманский район, поселок Калманка, Ленина, 20	f	\N
18402	15983	838	Алтайский край, Калманский район, поселок Калманка, Ленина, 7	f	large
18403	15984	839	Алтайский край, Калманский район, поселок Калистратиха, Школьная, 14	f	medium
18401	15982	837	Алтайский край, Калманский район, поселок Ивановка, Ивановская, 4	f	small
18400	15981	836	Алтайский край, Калманский район, поселок Зимари, Центральная, 56	f	medium
18399	15980	835	Алтайский край, Калманский район, поселок Бураново, Ерушева, 18	f	medium
18398	15979	834	Алтайский край, Калманский район, поселок Алтай, Советская, 27	f	medium
18397	15978	833	Алтайский край, Калманский район, поселок Александровка, Молодежная, 28	f	small
18396	15833	832	Алтайский край, Зональный район, поселок Шубенка, Ленина, 43	f	medium
18387	15968	823	Алтайский край, Зональный район, поселок Урожайный, Школьная, 8	f	small
18394	15975	830	Алтайский край, Зональный район, поселок Соколово, Кирова, 38	f	large
18393	15974	829	Алтайский край, Зональный район, поселок Савиново, Садовая, 17А	f	small
18391	15972	827	Алтайский край, Зональный район, поселок Плешково, Почтовый, 12	f	large
18390	15971	826	Алтайский край, Зональный район, поселок Октябрьский (Степной), Советская, 16	f	medium
18389	15970	825	Алтайский край, Зональный район, поселок Новая Чемровка, Бийская, 4А	f	large
18386	15967	822	Алтайский край, Зональный район, поселок Новая Михайловка, Школьная, 15	f	small
67911	15976	831	Алтайский край, Зональный район, поселок Мирный, Ленина, 2Г	f	large
18388	15969	824	Алтайский край, Зональный район, поселок Луговское, Парковая, 24	f	large
18392	15973	828	Алтайский край, Зональный район, поселок Комарово, Школьная, 15А	f	small
18385	15966	821	Алтайский край, Зональный район, поселок Зональное, Ленина, 16	f	large
18384	15965	820	Алтайский край, Зональный район, поселок Буланиха, Советская, 36	f	large
18383	15964	819	Алтайский край, Змеиногорский район, поселок Черепановск, Центральная, 36	f	small
18372	15953	808	Алтайский край, Змеиногорский район, поселок Утка, Речная, 20б	f	small
18375	15956	811	Алтайский край, Змеиногорский район, поселок Тушканиха, Пролетарская, 29	f	small
109244	15962	817	Алтайский край, Змеиногорский район, поселок Таловка, Советская, 63	f	medium
67877	15960	815	Алтайский край, Змеиногорский район, поселок Саввушка, Центральная, 41	f	large
18373	15954	809	Алтайский край, Змеиногорский район, поселок Предгорный, Декабристов, 2	f	small
18378	15959	814	Алтайский край, Змеиногорский район, поселок Отрада, Зеленая, 25	f	small
109243	15957	812	Алтайский край, Змеиногорский район, поселок Октябрьский, 40 лет Победы, 10	f	medium
18380	15961	816	Алтайский край, Змеиногорский район, поселок Новохарьковка, Школьная, 6	f	small
18369	15950	805	Алтайский край, Змеиногорский район, поселок Новокузнецовка, Центральная, 36	f	small
18303	15883	738	Алтайский край, Змеиногорский район, поселок Никольск, Центральная, 5	f	small
86044	15955	810	Алтайский край, Змеиногорский район, поселок Никольск, Парковая, 25	f	small
18377	15958	813	Алтайский край, Змеиногорский район, поселок Локоток, Новая, 1А	f	small
109242	15952	807	Алтайский край, Змеиногорский район, поселок Кузьминка, Центральная , 18	f	medium
18367	15948	803	Алтайский край, Змеиногорский район, поселок Карамышево, Советская, 1	f	large
18366	15947	802	Алтайский край, Змеиногорский район, поселок Гальцовка, Косачева, 20	f	small
18370	15951	806	Алтайский край, Змеиногорский район, поселок Воронеж, Центральная, 7	f	small
5289	31908	482	республика Дагестан, Дербент, Таги-Заде, 2	f	large
109245	15963	818	Алтайский край, Змеиногорский район, поселок Беспаловский, Центральная, 1	f	medium
18368	15949	804	Алтайский край, Змеиногорский район, поселок Березовка, Молодежная, 2	f	small
67902	15946	801	Алтайский край, Змеиногорский район, поселок Барановка, Центральная, 51	f	large
18361	15942	797	Алтайский край, Заринский район, станция Шпагино, Привокзальная, 10а	t	small
18363	15944	799	Алтайский край, Заринский район, поселок Яново, Центральная, 12	t	small
18348	15929	784	Алтайский край, Заринский район, поселок Шпагино, Центральная, 5-2	t	small
18337	15918	773	Алтайский край, Заринский район, поселок Широкий Луг, Победы, 21	t	small
18358	15939	794	Алтайский край, Заринский район, поселок Хмелевка, Коммунистическая, 52	t	medium
86088	15937	792	Алтайский край, Заринский район, поселок Тягун, Титова, 1	t	small
18357	15938	793	Алтайский край, Заринский район, поселок Тягун, Советская, 12	t	large
18338	15919	774	Алтайский край, Заринский район, поселок Старокопылово, Мира, 55	t	small
109241	15933	788	Алтайский край, Заринский район, поселок Стародраченино, Ленина, 2а	f	medium
86062	15908	763	Алтайский край, Заринский район, поселок Староглушинка, Центральная, 39	t	small
18326	15907	762	Алтайский край, Заринский район, поселок Среднекрасилово, Центральная, 44	t	small
18349	15930	785	Алтайский край, Заринский район, поселок Сосновка, Фрунзе, 7	f	small
18344	15925	780	Алтайский край, Заринский район, поселок Смирново, Лесная, 2	f	small
18355	15936	791	Алтайский край, Заринский район, поселок Смазнево, Первая Майская, 1	f	large
18345	15926	781	Алтайский край, Заринский район, поселок Новоманошкино, Молодежная, 2	f	medium
86063	15909	764	Алтайский край, Заринский район, поселок Новокрасилово, Зелёная, 21/1	t	small
18343	15924	779	Алтайский край, Заринский район, поселок Новокопылово, Центральная, 45	f	medium
18336	15917	772	Алтайский край, Заринский район, поселок Новозыряново, Калинина, 39	f	small
18359	15940	795	Алтайский край, Заринский район, поселок Новодресвянка, Новодресвянская, 2а	t	small
18339	15920	775	Алтайский край, Заринский район, поселок Новодраченино, Центральная, 28	f	medium
18333	15914	769	Алтайский край, Заринский район, поселок Мостовой, Партизанская, 30а	t	small
18334	15915	770	Алтайский край, Заринский район, поселок Мироновка, Школьная, 8	t	small
18351	15932	787	Алтайский край, Заринский район, поселок Малиновка, Центральная, 1	t	small
18335	15916	771	Алтайский край, Заринский район, поселок Комарское, Молодежная, 21	f	medium
18353	15934	789	Алтайский край, Заринский район, поселок Кокорское, Новая, 7а	f	small
18360	15941	796	Алтайский край, Заринский район, поселок Клабуковка, Лесная, 1	t	small
18364	15945	800	Алтайский край, Заринский район, поселок Каменушка, Школьная, 3	f	small
18341	15922	777	Алтайский край, Заринский район, поселок Казанцево, Центральная, 14	t	small
18346	15927	782	Алтайский край, Заринский район, поселок Инюшево, Центральная, 34	t	small
18332	15913	768	Алтайский край, Заринский район, поселок Зыряновка, Советская, 10	t	small
86086	15923	778	Алтайский край, Заринский район, поселок Змазнево, Новая, 9	t	small
17944	15538	374	Алтайский край, Заринский район, Заринск, Союза Республик, 14/2	f	large
17942	15538	372	Алтайский край, Заринский район, Заринск, Союза Республик, 14/2	f	large
17952	15545	382	Алтайский край, Заринский район, Заринск, Мира, 14	f	large
19427	16995	1915	Алтайский край, Заринский район, Заринск, Комсомольская, 13	f	large
17943	15539	373	Алтайский край, Заринский район, Заринск, 25 Партсъезда, 3	f	large
18329	15910	765	Алтайский край, Заринский район, поселок Гришино, Центральная, 3	f	small
18325	15906	761	Алтайский край, Заринский район, поселок Гоношиха, Новая, 38а	f	small
67884	15912	767	Алтайский край, Заринский район, поселок Голуха, Привокзальная, 2	f	large
18347	15928	783	Алтайский край, Заринский район, поселок Голубцово, Центральная, 13-2	t	small
18324	15905	760	Алтайский край, Заринский район, поселок Воскресенка, Германа Титова, 1/2	t	small
18522	16102	966	Алтайский край, Заринский район, поселок Верх-Камышенка, Юбилейная, 13	f	medium
18323	15904	759	Алтайский край, Заринский район, поселок Верх-Камышенка, Центральная, 34	f	medium
109252	16101	965	Алтайский край, Заринский район, поселок Верх-Камышенка, Молодежная, 22а	f	medium
18350	15931	786	Алтайский край, Заринский район, поселок Боровлянка, Центральная, 14	t	small
18362	15943	798	Алтайский край, Заринский район, поселок Батунный, Школьная, 6	f	small
86085	15921	776	Алтайский край, Заринский район, поселок Афонино, Центральная, 17а	t	small
18320	15901	755	Алтайский край, Залесовский район, поселок Шатуново, Партизанская, 14	f	medium
18317	15898	752	Алтайский край, Залесовский район, поселок Черемушкино, Николаева, 30	f	medium
18315	15895	750	Алтайский край, Залесовский район, поселок Тундриха, Комсомольская, 18	f	small
18301	15881	736	Алтайский край, Залесовский район, поселок Талица, Центральная, 23	f	small
18304	15884	739	Алтайский край, Залесовский район, поселок Пролетарская Крепость, Мира, 6	f	small
18313	15893	748	Алтайский край, Залесовский район, поселок Пещерка, Совхозная, 4	f	medium
18311	15891	746	Алтайский край, Залесовский район, поселок Муравей, Центральная, 24	f	small
18319	15900	754	Алтайский край, Залесовский район, поселок Малый Калтай, Молодежная, 16	f	small
18312	15892	747	Алтайский край, Залесовский район, поселок Кордон, Школьная, 22	f	medium
18321	15902	756	Алтайский край, Залесовский район, поселок Калиновка, Коммунаров, 13	f	small
18316	15896	751	Алтайский край, Залесовский район, поселок Заплывино, 50 лет Алтая, 33	f	small
18308	15888	743	Алтайский край, Залесовский район, поселок Залесово, пер. Школьный, 6	f	large
18307	15887	742	Алтайский край, Залесовский район, поселок Залесово, Партизанская, 63	f	large
18309	15889	744	Алтайский край, Залесовский район, поселок Залесово, Ленинская, 3	f	large
18310	15890	745	Алтайский край, Залесовский район, поселок Залесово, Крупской, 4	f	small
18306	15886	741	Алтайский край, Залесовский район, поселок Залесово, Коммунистическая, 51	f	large
109239	15885	740	Алтайский край, Залесовский район, поселок Думчево, Школьная, 37	f	medium
86061	15894	749	Алтайский край, Залесовский район, поселок Гуниха, Октябрьская, 23	f	small
18318	15899	753	Алтайский край, Залесовский район, поселок Видоново, Заречная, 19	f	small
18302	15882	737	Алтайский край, Залесовский район, поселок Борисово, Коммунистическая, 14а	f	medium
18300	15879	735	Алтайский край, Залесовский район, поселок Большой Калтай, Нагорная, 25	f	small
18291	94903	726	Алтайский край, Завьяловский район, село Чистоозёрка, Советская, 54	f	large
18290	15869	725	Алтайский край, Завьяловский район, поселок Чернавка, Юбилейная, 21	f	medium
18295	15874	730	Алтайский край, Завьяловский район, поселок Харитоново, Советская, 20	f	large
18292	15871	727	Алтайский край, Завьяловский район, поселок Тумановский, Молодежная, 1	f	small
18297	94905	732	Алтайский край, Завьяловский район, поселок Светлый, Центральная, 40	f	medium
18296	15875	731	Алтайский край, Завьяловский район, поселок Овечкино, Центральная, 3	f	medium
18293	15872	728	Алтайский край, Завьяловский район, поселок Малиновский, Целинная, 16	f	large
18289	15868	724	Алтайский край, Завьяловский район, поселок Камышенка, Куйбышева, 22	f	medium
86054	15867	723	Алтайский край, Завьяловский район, поселок Завьялово, Школьный переулок, 1	t	small
18286	94901	721	Алтайский край, Завьяловский район, поселок Завьялово, Центральная, 13	f	large
18287	94902	722	Алтайский край, Завьяловский район, поселок Завьялово, Комунаров, 20	f	large
18298	94906	733	Алтайский край, Завьяловский район, поселок Гонохово, Центральная, 91	f	large
18294	94904	729	Алтайский край, Завьяловский район, поселок Глубокое, Центральная, 32	f	large
18299	15878	734	Алтайский край, Завьяловский район, поселок Гилевка, Центральная, 9	f	large
18280	15862	715	Алтайский край, Ельцовский район, поселок Черемшанка, Береговая, 15	f	small
18282	15864	717	Алтайский край, Ельцовский район, поселок Пуштулим, Советская, 25	f	medium
18281	15863	716	Алтайский край, Ельцовский район, поселок Новокаменка, Новая, 15	f	small
67893	15861	714	Алтайский край, Ельцовский район, поселок Мартыново, пер.Партизанский, 5	f	large
86084	15865	718	Алтайский край, Ельцовский район, поселок Верх-Неня, им.Леухина, 1	t	small
109238	15851	704	Алтайский край, Егорьевский район, поселок Шубинка (Бугор), Молодежная, 60	f	medium
18277	15859	712	Алтайский край, Егорьевский район, поселок Титовка, Советская, 2	f	medium
67910	15858	711	Алтайский край, Егорьевский район, поселок Сросты, Советская, 171	f	large
18271	15853	706	Алтайский край, Егорьевский район, поселок Перешеечный, Лесхозная, 67	f	small
18274	15856	709	Алтайский край, Егорьевский район, поселок Первомайское, Ленина, 36	f	medium
18273	15855	708	Алтайский край, Егорьевский район, поселок Новоегорьевское, Машинцева, 18	f	large
18272	15854	707	Алтайский край, Егорьевский район, поселок Новоегорьевское, Машинцева, 16	f	large
18275	15857	710	Алтайский край, Егорьевский район, поселок Мирный, Центральная, 19а	f	small
18268	15850	703	Алтайский край, Егорьевский район, поселок Малая Шелковка, Масловского, 68	f	medium
18270	15852	705	Алтайский край, Егорьевский район, поселок Лебяжье, Молодежная, 20/1	f	large
18266	15848	701	Алтайский край, Егорьевский район, поселок Кругло-Семенцы, Центральная, 80	f	small
18267	15849	702	Алтайский край, Егорьевский район, поселок Борисовка, Центральная, 28а	f	small
18265	15847	700	Алтайский край, Волчихинский район, поселок Усть-Кормиха, Набережная, 46	f	small
18264	15846	699	Алтайский край, Волчихинский район, поселок Усть-Волчиха, Почтовая, 11	f	medium
18256	15838	691	Алтайский край, Волчихинский район, поселок Солоновка, Мамонтова, 11	f	medium
18258	15840	693	Алтайский край, Волчихинский район, поселок Селиверстово (Белгачи), Центральная, 53	f	medium
18259	15841	694	Алтайский край, Волчихинский район, поселок Пятков Лог, Ленина, 76	f	small
18255	15837	690	Алтайский край, Волчихинский район, поселок Приборовое, Партизанская, 91	f	small
109237	15835	688	Алтайский край, Волчихинский район, поселок Правда, Береговая, 60	f	medium
109279	16998	1918	Алтайский край, Волчихинский район, поселок Плодосовхоз, Молодежная, 10/А	f	\N
18261	15843	696	Алтайский край, Волчихинский район, поселок Новокормиха, Центральная, 13	f	medium
18257	15839	692	Алтайский край, Волчихинский район, поселок Малышев Лог, Октябрьская, 44/Б	f	medium
18260	15842	695	Алтайский край, Волчихинский район, поселок Коминтерн, Гагарина, 11	f	small
18254	15836	689	Алтайский край, Волчихинский район, поселок Вострово, Советская, 15/В	f	large
18250	15831	685	Алтайский край, Волчихинский район, поселок Волчиха, Свердлова, 6	f	large
18251	15832	686	Алтайский край, Волчихинский район, поселок Волчиха, Матросова, 4	f	large
18249	15830	684	Алтайский край, Волчихинский район, поселок Волчиха, Ленина, 63	f	large
18252	15834	687	Алтайский край, Волчихинский район, поселок Волчиха, 30 лет Октября, 70	f	large
18698	16282	1147	Алтайский край, Волчихинский район, поселок Веселая Дубрава, Боровская	f	small
18263	15845	698	Алтайский край, Волчихинский район, поселок Бор-Форпост, Сидорова, 10	f	medium
18262	15844	697	Алтайский край, Волчихинский район, поселок Березовский, Кошевого, 8/А	f	small
18247	15828	682	Алтайский край, Быстроистокский район, поселок Хлеборобное, Целинная, 10	f	large
18248	15829	683	Алтайский край, Быстроистокский район, поселок Усть-Ануй, Центральная, 51	f	small
18243	15824	678	Алтайский край, Быстроистокский район, поселок Приобский, Молодежная, 2	f	medium
18245	15826	680	Алтайский край, Быстроистокский район, поселок Новопокровка, Советская, 120	f	medium
18244	15825	679	Алтайский край, Быстроистокский район, поселок Верх-Озерное, Центральная, 7а	f	small
18246	15827	681	Алтайский край, Быстроистокский район, поселок Верх-Ануйское, Советская, 20	f	large
18240	94899	675	Алтайский край, Быстроистокский район, поселок Быстрый Исток, Советская, 55	f	medium
18242	15823	677	Алтайский край, Быстроистокский район, поселок Быстрый Исток, Советская, 13	f	large
18241	15822	676	Алтайский край, Быстроистокский район, поселок Быстрый Исток, Советская, 24	f	large
18239	15820	674	Алтайский край, Быстроистокский район, поселок Акутиха, Коммунистическая, 39	t	medium
18227	15807	661	Алтайский край, Бурлинский район, поселок Чернавка, Центральная, 38	t	small
18225	15805	659	Алтайский край, Бурлинский район, поселок Цветополь, Центральная, 31А	f	small
18237	15818	671	Алтайский край, Бурлинский район, поселок Устьянка, Советская, 57	f	medium
18223	15803	657	Алтайский край, Бурлинский район, поселок Притыка, Набережная, 22А	f	small
18231	15811	665	Алтайский край, Бурлинский район, поселок Петровка, Школьный переулок, 5А	t	small
18230	15810	664	Алтайский край, Бурлинский район, поселок Первомайское, Школьная, 13А	f	small
5313	31931	506	республика Дагестан, Дербент, Советская, 11	f	large
18233	15813	667	Алтайский край, Бурлинский район, поселок Партизанское, Жуковского, 5	f	small
18226	15806	660	Алтайский край, Бурлинский район, поселок Орехово, Чапаева, 42	f	medium
18229	15809	663	Алтайский край, Бурлинский район, поселок Новосельское, Гагарина, 9	f	medium
18235	15815	669	Алтайский край, Бурлинский район, поселок Новопесчаное, Центральная, 12	f	medium
18228	15808	662	Алтайский край, Бурлинский район, поселок Новоандреевка, Вишневская, 24	f	small
18236	15817	670	Алтайский край, Бурлинский район, поселок Новоалексеевка, Школьная, 6А	f	small
18224	15804	658	Алтайский край, Бурлинский район, поселок Михайловка, Ленина, 17Б	f	medium
18238	15819	672	Алтайский край, Бурлинский район, поселок Лесное, Школьная, 12	f	small
18234	15814	668	Алтайский край, Бурлинский район, поселок Гусиная Ляга, переулок Школьный, 2	f	small
18222	15802	656	Алтайский край, Бурлинский район, поселок Бурла, Первомайская, 42	f	large
18220	15800	654	Алтайский край, Бурлинский район, поселок Бурла, Ленина, 12	f	large
18221	15801	655	Алтайский край, Бурлинский район, поселок Бурла, Гоголя, 68	f	medium
18232	15812	666	Алтайский край, Бурлинский район, поселок Асямовка, Титова, 19	f	small
18218	15797	652	Алтайский край, Благовещенский район, поселок Яготино, Мира, 30	f	medium
18216	15795	650	Алтайский край, Благовещенский район, поселок Шимолино, Центральная, 1	f	medium
18219	15798	653	Алтайский край, Благовещенский район, поселок Тельманский, Калинина, 32	f	small
18211	15790	645	Алтайский край, Благовещенский район, поселок Татьяновка, Комсомольская, 36	f	small
18215	15794	649	Алтайский край, Благовещенский район, поселок Суворовка, Советская, 18	f	medium
18196	15775	630	Алтайский край, Благовещенский район, поселок Степное Озеро, Химиков, 2	f	large
18193	15772	627	Алтайский край, Благовещенский район, поселок Степное Озеро, Мира, 17	f	large
18195	15774	629	Алтайский край, Благовещенский район, поселок Степное Озеро, Мира, 12	f	large
18194	15773	628	Алтайский край, Благовещенский район, поселок Степное Озеро, Микитона, 13	f	large
18213	15792	647	Алтайский край, Благовещенский район, поселок Орлеан, Ленина, 19а	f	small
18212	15791	646	Алтайский край, Благовещенский район, поселок Новокулундинка, Мира, 42	f	medium
18210	15789	644	Алтайский край, Благовещенский район, поселок Николаевка, Школьный, 17	f	medium
18209	15788	643	Алтайский край, Благовещенский район, поселок Нижний Кучук, Центральная, 24	f	small
18206	15785	640	Алтайский край, Благовещенский район, поселок Леньки, Центральная, 7	f	medium
18207	15786	641	Алтайский край, Благовещенский район, поселок Леньки, Маяковского, 75	f	medium
109236	15771	626	Алтайский край, Благовещенский район, поселок Леньки, Маяковского, 75	f	\N
18205	15784	639	Алтайский край, Благовещенский район, поселок Леньки, Ленина, 4	f	large
19036	16623	1497	Алтайский край, Благовещенский район, поселок Елизаветград, Интернациональная, 43	f	small
18208	15787	642	Россия, Алтайский край, Благовещенский район, поселок Дмитриевка	t	small
18204	15783	638	Алтайский край, Благовещенский район, поселок Глядень 1-й, Школьный, 4	f	large
18199	15778	633	Алтайский край, Благовещенский район, поселок Благовещенка, Урицкого, 2	f	large
18200	15779	634	Алтайский край, Благовещенский район, поселок Благовещенка, Советская, 47	f	large
18202	15781	636	Алтайский край, Благовещенский район, поселок Благовещенка, Ленина, 82	f	large
18201	15780	635	Алтайский край, Благовещенский район, поселок Благовещенка, Ленина, 95	f	large
67909	15777	632	Алтайский край, Благовещенский район, поселок Благовещенка, Колхозный переулок, 114	f	large
18197	15776	631	Алтайский край, Благовещенский район, поселок Благовещенка, Клубная, 18	f	large
18214	15793	648	Алтайский край, Благовещенский район, поселок Байгамут, Абая, 3	f	small
18203	15782	637	Алтайский край, Благовещенский район, поселок Алексеевка, Центральная, 10	t	medium
18181	15758	613	Алтайский край, Бийский район, поселок Ясная Поляна, Школьная, 1	t	small
18186	94898	618	Алтайский край, Бийский район, поселок Шебалино, Ленина, 23	f	large
18164	15741	596	Алтайский край, Бийский район, поселок Чуйский, Центральная, 11	f	small
18192	15770	624	Алтайский край, Бийский район, поселок Усятское, Советская, 6	f	medium
18166	15743	598	Алтайский край, Бийский район, поселок Усть-Катунь, Школьный, 14	t	small
18170	15747	602	Алтайский край, Бийский район, поселок Студенческий, Фермерская, 23	t	small
18169	15746	601	Алтайский край, Бийский район, поселок Старая Чемровка, Советская, 64	t	small
18171	94896	603	Алтайский край, Бийский район, поселок Стан-Бехтемир, Колхозная, 32а	f	medium
18185	15762	617	Алтайский край, Бийский район, поселок Сростки, Советская, 104	f	large
18175	15752	607	Алтайский край, Бийский район, поселок Семеновод, Латунина, 1к	f	small
67908	15764	619	Алтайский край, Бийский район, поселок Светлоозерское, Центральная, 26	f	large
18178	15755	610	Алтайский край, Бийский район, поселок Пригородный, Новая, 15	t	small
86079	15767	621	Алтайский край, Бийский район, поселок Полеводка, Трактовая, 1	t	small
18183	15760	615	Алтайский край, Бийский район, поселок Первомайское, Степная, 24а	f	large
18184	15761	616	Алтайский край, Бийский район, поселок Первомайское, Мира, 4	f	large
18179	15756	611	Алтайский край, Бийский район, поселок Новиково, Советская, 30	f	large
18191	15769	623	Алтайский край, Бийский район, поселок Мальцева Курья, Озерная, 29а	t	small
67907	15753	608	Алтайский край, Бийский район, поселок Малоугренево, пл.Щигорева, 4	f	large
18174	94897	606	Алтайский край, Бийский район, поселок Малоенисейское, Советская, 98	f	large
18172	15749	604	Алтайский край, Бийский район, поселок Лесное, Советская, 20	f	large
18190	15768	622	Алтайский край, Бийский район, поселок Ключи, Советская, 17	f	small
18168	94895	600	Алтайский край, Бийский район, поселок Заря, Центральная, 18а	f	medium
18188	15765	620	Алтайский край, Бийский район, поселок Заозерный, Лесная, 6	t	small
18167	15744	599	Алтайский край, Бийский район, поселок Енисейское, В.Максимовой, 24А	f	large
18182	15759	614	Алтайский край, Бийский район, поселок Восточный, Школьная, 13	t	small
18165	94894	597	Алтайский край, Бийский район, поселок Верх-Катунское, Ленина, 23б	f	large
18163	94893	595	Алтайский край, Бийский район, поселок Верх-Бехтемир, Советский, 12	f	medium
18177	15754	609	Алтайский край, Бийский район, поселок Боровой, Пионерская, 9	f	small
18162	94892	594	Алтайский край, Бийский район, поселок Большеугренево, Смирнова, 11	f	medium
86064	15757	612	Алтайский край, Бийский район, поселок Бехтемир-Аникино, Аникинская, 40	t	small
18173	15750	605	Алтайский край, Бийский район, поселок Амурский, Катунская, 18	f	small
18161	15738	592	Алтайский край, Баевский район, поселок Чуманка, Ленина, 28	t	small
18153	15730	584	Алтайский край, Баевский район, поселок Ситниково, Почтовая, 8	f	medium
18152	15729	583	Алтайский край, Баевский район, поселок Сафроново, Школьная, 3	t	small
18150	15727	581	Алтайский край, Баевский район, поселок Прослауха, Центральная, 22	f	medium
18155	15732	586	Алтайский край, Баевский район, поселок Покровка, Центральная, 31	t	small
18160	15737	591	Алтайский край, Баевский район, поселок Плотава, Центральная, 21	f	medium
18151	15728	582	Алтайский край, Баевский район, поселок Паклино, Береговая, 11	f	small
18156	15733	587	Алтайский край, Баевский район, поселок Павловка, Пушкина, 9	t	small
18154	15731	585	Алтайский край, Баевский район, поселок Нижнечуманка, Кулундинская, 39	f	medium
18157	15734	588	Алтайский край, Баевский район, поселок Нижнепайва, Центральный переулок, 3	f	small
18159	15736	590	Алтайский край, Баевский район, поселок Верх-Чуманка, Набережная, 22а	f	medium
18158	15735	589	Алтайский край, Баевский район, поселок Верх-Пайва, Советская, 6	f	medium
67891	15726	580	Алтайский край, Баевский район, поселок Баево, Терешковой, 21	f	large
18147	15724	578	Алтайский край, Баевский район, поселок Баево, Мира, 30	f	large
18145	15722	575	Алтайский край, Алтайский район, поселок Тоурак, Центральная, 11	t	small
18134	15711	564	Алтайский край, Алтайский район, поселок Старобелокуриха, Советская, 85	f	large
18143	15720	573	Алтайский край, Алтайский район, поселок Сараса, Кузьмина, 48	f	medium
18133	15710	563	Алтайский край, Алтайский район, поселок Россоши, Ленина, 19	f	medium
18142	15719	572	Алтайский край, Алтайский район, поселок Пролетарка, Школьная, 2	f	small
18139	15716	569	Алтайский край, Алтайский район, поселок Нижнекаянча, Школьная, 11	f	small
67887	15709	562	Алтайский край, Алтайский район, поселок Нижнекаменка, 60 лет октября, 80	f	large
18135	15712	565	Алтайский край, Алтайский район, поселок Макарьевка, Центральная, 47	f	small
18146	15723	576	Алтайский край, Алтайский район, поселок Куяча, Центральная, 20	f	small
18144	15721	574	Алтайский край, Алтайский район, поселок Куяган, Октябрьская, 2	f	medium
18141	15718	571	Алтайский край, Алтайский район, поселок Комар, Кедровая, 5	f	small
18137	15714	567	Алтайский край, Алтайский район, поселок Катунь, Центральная, 6	f	small
86070	15715	568	Алтайский край, Алтайский район, поселок Верх-Ая, Школьная, 7	f	small
18140	15717	570	Алтайский край, Алтайский район, поселок Белое, Центральная, 18	f	small
18130	15707	560	Алтайский край, Алтайский район, поселок Алтайское, Целинная, 28	f	medium
18128	15705	558	Алтайский край, Алтайский район, поселок Алтайское, Советская, 211	f	large
18127	15704	557	Алтайский край, Алтайский район, поселок Алтайское, Советская, 97	f	large
18126	15703	556	Алтайский край, Алтайский район, поселок Алтайское, Советская, 3	f	large
18124	15701	554	Алтайский край, Алтайский район, поселок Алтайское, Лесная, 9	f	small
18131	15708	561	Алтайский край, Алтайский район, поселок Алтайское, Ленина, 87	f	large
67879	15706	559	Алтайский край, Алтайский район, поселок Алтайское, Автомобильный переулок, 5	f	large
18116	15693	546	Алтайский край, Алейский район, поселок Чернышевский, Степная, 31	f	small
18121	15698	551	Алтайский край, Алейский район, поселок Урюпино, Школьная, 22	f	medium
18102	15679	532	Алтайский край, Алейский район, поселок Уржум, Садовая, 18	f	small
18105	15682	535	Алтайский край, Алейский район, поселок Троицкий, Молодежная, 7а	f	small
86046	15677	530	Алтайский край, Алейский район, поселок Толстая Дуброва, Молодежная, 36	f	small
18104	15681	534	Алтайский край, Алейский район, поселок Солнечный, Школьная, 1	f	medium
18120	94891	550	Алтайский край, Алейский район, поселок Совхозный, Гагарина, 8	f	small
18097	15674	527	Алтайский край, Алейский район, поселок Серебренниково, Садовая, 6	t	small
86068	15696	549	Алтайский край, Алейский район, поселок Савинка (Совинское), Центральная, 37	f	small
18101	15678	531	Алтайский край, Алейский район, поселок Приятельский, Центральная, 34	f	small
18118	15695	548	Алтайский край, Алейский район, поселок Плотава, Советская, 13	f	small
18091	15668	521	Алтайский край, Алейский район, поселок Первомайский, Луговая, 4	f	small
18117	15694	547	Алтайский край, Алейский район, поселок Осколково, Советская, 82	f	medium
18090	15667	520	Алтайский край, Алейский район, поселок Октябрьский, Мира, 3	t	small
18112	15689	542	Алтайский край, Алейский район, поселок Новоникольский, Береговая, 6	f	small
18095	15672	525	Алтайский край, Алейский район, поселок Новоколпаково, Приозерная, 1	f	small
18115	15692	545	Алтайский край, Алейский район, поселок Моховское, Центральная, 16	f	medium
86047	15666	519	Алтайский край, Алейский район, поселок Мамонтовский, Мира, 1	t	small
18114	15691	544	Алтайский край, Алейский район, поселок Малиновка, Центральная, 32г	f	small
18088	15665	518	Алтайский край, Алейский район, поселок Малахово, Школьный, 1	f	small
86050	15700	553	Алтайский край, Алейский район, поселок Красный Яр, Молодежная, 33а	f	small
18111	15688	541	Алтайский край, Алейский район, поселок Краснодубровский, Юбилейная, 8	f	small
18110	15687	540	Алтайский край, Алейский район, поселок Кондратьевский, Первомайская, 13а	f	small
18108	15685	538	Алтайский край, Алейский район, поселок Кировское, Советская, 1	f	small
18107	15684	537	Алтайский край, Алейский район, поселок Кашино, Октябрьская, 52	f	medium
18106	15683	536	Алтайский край, Алейский район, поселок Кабаково, Центральная, 2б	f	medium
18103	15680	533	Алтайский край, Алейский район, поселок Заветы Ильича, Школьная, 8	f	medium
86048	15686	539	Алтайский край, Алейский район, поселок Дубровский, Центральная, 24	t	small
18099	15676	529	Алтайский край, Алейский район, поселок Дружба, Пионерская, 36	f	large
86067	15675	528	Алтайский край, Алейский район, поселок Ветелки, Центральная, 29	f	small
18122	15699	552	Алтайский край, Алейский район, поселок Вавилон, Комсомольская, 34	f	medium
18096	15673	526	Алтайский край, Алейский район, поселок Боровское, Кирова, 56	f	medium
18113	15690	543	Алтайский край, Алейский район, поселок Бориха, Центральная, 1	f	medium
18094	15671	524	Алтайский край, Алейский район, поселок Большепанюшево, Садовая, 2б	f	small
18093	15670	523	Алтайский край, Алейский район, поселок Безголосово, Центральная, 24	f	medium
18092	15669	522	Алтайский край, Алейский район, поселок Александровский, Центральная, 1	f	small
109235	15664	517	Алтайский край, Алейский район, поселок Алейский, Мира, 2	f	medium
130650	12137	133	республика Чеченская, с. Нижний Нойбер, К.Л. Тепсуева, 40, СОШ №2	f	\N
130649	12136	132	республика Чеченская, с. Нижний Нойбер, К.Л. Тепсуева, 26, СОШ №1	f	\N
16167	12169	165	республика Чеченская, село Курчалой, С.Абуева	f	large
130634	12124	117	республика Чеченская, Гудермес, СШ №10Еременко	f	\N
130628	12118	111	республика Чеченская, Гудермес, пр-кт им.А-Х.Кадырова, 14, ДДТ	f	\N
130629	12119	112	республика Чеченская, Гудермес, Школьная, 20	f	\N
130627	12109	101	республика Чеченская, Гудермес, Свободы, 68, ГУП «Чеводоканал»	f	\N
130632	12122	115	республика Чеченская, Гудермес, Партизанская, 4, СОШ № 1	f	\N
130630	12120	113	республика Чеченская, Гудермес, Нурадилова, 22, СШ №2	f	\N
16396	12453	454	республика Чеченская, Грозный, Ярыш-Мардинское сельское поселение, Здание администрации	f	small
16387	12443	445	республика Чеченская, Грозный, гор. Иванова, СОШ №26	f	large
16128	12094	87	республика Чеченская, Грозный, проспект Кадырова, 51	f	medium
16390	12447	448	республика Чеченская, Грозный, гор.Маяковского, УКК ОАО Грознефтегаз	f	large
130771	12450	451	республика Чеченская, Грозный, г-к. Маяковского, 109, СОШ №44	f	\N
130772	12451	452	республика Чеченская, Грозный, г-к Нефтемайск, СОШ №17	f	\N
16392	12449	450	республика Чеченская, Грозный, г-к Маяковского, СОШ №10	f	large
130770	12445	446	республика Чеченская, Грозный, Яблочная, Гимназия №4	f	\N
16116	12082	75	республика Чеченская, Грозный, Школьная, СОШ	f	large
16112	12078	71	республика Чеченская, Грозный, Школьная, СОШ №2	f	large
16129	12095	88	республика Чеченская, Грозный, Шерипова, 17	f	large
16354	12403	403	республика Чеченская, Грозный, Ш.А.Митаева, 97	f	large
16133	12100	92	республика Чеченская, Грозный, Ц.Уадьба, 1	f	large
130759	12419	420	республика Чеченская, Грозный, Ханкальская, 87, СОШ № 23	f	\N
16373	12426	427	республика Чеченская, Грозный, Фонтанная, 7	f	large
16342	12390	390	республика Чеченская, Грозный, Фасадная, 22	f	large
16339	12375	387	республика Чеченская, Грозный, Ученическая, 2	f	large
16350	12399	399	республика Чеченская, Грозный, Урожайная, 23	f	large
16391	12446	447	республика Чеченская, Грозный, Угольная, 320	f	large
16389	12448	449	республика Чеченская, Грозный, Турбинная, 1а	f	large
16121	12087	80	республика Чеченская, Грозный, Трудовая, 1	f	large
16359	12408	408	республика Чеченская, Грозный, Субботников, 60	f	large
16108	12073	67	республика Чеченская, Грозный, Сторителей, СДК	f	medium
16382	12436	438	республика Чеченская, Грозный, Старопромысловское шоссе, 38	f	large
16341	12389	389	республика Чеченская, Грозный, Социалистическая, 10	f	large
16134	12101	93	республика Чеченская, Грозный, Советская, СОШ	f	large
130761	12424	425	республика Чеченская, Грозный, Сайханова, 93, ПУ-7	f	\N
16125	12091	84	республика Чеченская, Грозный, Нурадилова, 179	f	large
16381	12437	439	республика Чеченская, Грозный, Новаторов, 29	f	large
16345	12393	393	республика Чеченская, Грозный, Николаева, 50	f	large
16370	12423	424	республика Чеченская, Грозный, Нахимова, 161	f	large
16358	12407	407	республика Чеченская, Грозный, Моздокская, 34	f	large
16123	12089	82	республика Чеченская, Грозный, Митаева, 41	f	large
16109	12074	68	республика Чеченская, Грозный, Маяковского, 3а	f	large
16126	12092	85	республика Чеченская, Грозный, Майская, 51	f	large
130757	12418	418	республика Чеченская, Грозный, М.Х. Митаева, 4, СОШ №16	f	\N
130756	12417	417	республика Чеченская, Грозный, М.Х. Митаева, 30, ГПТУ №13	f	\N
130758	12417	419	республика Чеченская, Грозный, М.Х. Митаева, 30, ГПТУ №13	f	\N
16352	12401	401	республика Чеченская, Грозный, Ляпидевского, 9	f	large
16353	12402	402	республика Чеченская, Грозный, Лермонтова, 2	f	large
130746	12400	400	республика Чеченская, Грозный, Л. Яшина, 20, СОШ №60	f	\N
16357	12406	406	республика Чеченская, Грозный, Кутузова, 5	f	large
16376	12429	430	республика Чеченская, Грозный, Крупская, 10	f	large
16343	12391	391	республика Чеченская, Грозный, Коперника, СОШ №63	f	medium
16122	12088	81	республика Чеченская, Грозный, Комсомольская, 5	f	large
130768	12440	442	республика Чеченская, Грозный, Кольцова, 101, РДКБ	f	\N
16355	12404	404	республика Чеченская, Грозный, Кирова пр, 29	f	large
16367	12420	421	республика Чеченская, Грозный, Кадырова пр, СШ №18	f	large
130760	12422	423	республика Чеченская, Грозный, Кадырова, 256 а, СОШ №25	f	\N
16118	12084	77	республика Чеченская, Грозный, Кадырова, 6	f	large
130769	12442	444	республика Чеченская, Грозный, Заветы Ильича, 1, СОШ №37	f	\N
130767	12439	441	республика Чеченская, Грозный, Заветы Ильича, 48, СОШ №54	f	\N
16119	12085	78	республика Чеченская, Грозный, З.Умаровой, 5	f	large
16127	12093	86	республика Чеченская, Грозный, З. Умаровой, 5	f	small
16340	12388	388	республика Чеченская, Грозный, Донецкая, 1	f	large
16349	12398	398	республика Чеченская, Грозный, Дарвина, 17	f	large
16344	12392	392	республика Чеченская, Грозный, Д.Бедного, 26	f	large
16334	12385	382	республика Чеченская, Грозный, Гурьевская, 11, Гимназия №2	f	large
16333	12384	381	республика Чеченская, Грозный, Гурьевская, 11	f	large
16346	12394	394	республика Чеченская, Грозный, Грибоедова, 88	f	large
16383	12441	443	республика Чеченская, Грозный, Галкина, 139	f	large
16140	12107	99	республика Чеченская, Грозный, Ворошилова, 3	f	large
16338	12387	386	республика Чеченская, Грозный, Воронежская, 140	f	large
16337	12387	385	республика Чеченская, Грозный, Воронежская, 140	f	large
16117	12083	76	республика Чеченская, Грозный, Возрождения, 35	f	large
16336	12386	384	республика Чеченская, Грозный, Верхоянская, 6	f	large
16335	12386	383	республика Чеченская, Грозный, Верхоянская, 6	f	large
16377	12430	431	республика Чеченская, Грозный, Буровиков, 13	f	large
130762	12427	428	республика Чеченская, Грозный, Батумская, 47, СОШ № 91	f	\N
16375	12428	429	республика Чеченская, Грозный, Баррикадная, 1	f	large
16368	12421	422	республика Чеченская, Грозный, Алексеева, 160	f	large
16347	12396	396	республика Чеченская, Грозный, Агрономическая, 74	f	large
16348	12397	397	республика Чеченская, Грозный, Абухова, 2	f	large
130747	12405	405	республика Чеченская, Грозный, А. Айдамирова, 133, ГКОУ Президентский лицей	f	\N
16372	12425	426	республика Чеченская, Грозный, 8-Марта, 35	f	large
16380	12433	434	республика Чеченская, Грозный, 56-участок, СШ №9	f	large
16379	12432	433	республика Чеченская, Грозный, 20-й участок, СШ №29	f	large
16378	12431	432	республика Чеченская, Грозный, 12-участок, ПУ №4	f	large
130708	12266	262	республика Чеченская, станица Ассиновская, Центральная Усадьба, СШ №2, ГЗ Ассинский	f	\N
16046	12012	5	республика Чеченская, Аргун, пер. Свободы, 1	f	large
130622	12014	7	республика Чеченская, Аргун, Шоссейная, 59	f	\N
130620	12008	1	республика Чеченская, Аргун, Шоссейная, 59, СОШ №1	f	\N
16049	12009	8	республика Чеченская, Аргун, Титова, 2а	f	large
16043	12009	2	республика Чеченская, Аргун, Титова, 2а	f	large
16045	12011	4	республика Чеченская, Аргун, Ленина, 133	f	large
130621	12013	6	республика Чеченская, Аргун, Кутузова, 6	f	\N
16050	12015	9	республика Чеченская, Аргун, А.Х. Кадырова, СОШ №3	f	medium
16044	12010	3	республика Чеченская, Аргун, А.Х. Кадырова, СОШ№3	f	large
16330	12379	376	республика Чеченская, Шелковской район, село Шелковская, Школьная, 35	f	large
16327	12376	373	республика Чеченская, Шелковской район, село Шелковская, Школьная, 4	f	small
16313	12361	359	республика Чеченская, Шелковской район, село Шелковская, Школьная, 1	f	large
16319	12369	367	республика Чеченская, Шелковской район, село Шелковская, Ткачева, 11	f	large
16312	12360	358	республика Чеченская, Шелковской район, село Шелковская, Советской, 19	f	large
16320	12368	366	республика Чеченская, Шелковской район, село Шелковская, Советская, 3	f	large
16317	12365	363	республика Чеченская, Шелковской район, село Шелковская, Советская, 62	f	large
16309	12357	355	республика Чеченская, Шелковской район, село Шелковская, Орджоникидзе, 62	f	small
16318	12366	364	республика Чеченская, Шелковской район, село Шелковская, Октябрская, 9	f	large
16321	12367	365	республика Чеченская, Шелковской район, село Шелковская, Озерная, 3	f	large
130742	12380	377	республика Чеченская, Шелковской район, село Шелковская, Мира, 4, ООШ	f	\N
16328	12377	374	республика Чеченская, Шелковской район, село Шелковская, Ленина, 5	f	medium
16322	12370	368	республика Чеченская, Шелковской район, село Шелковская, Маркелова, 14	f	large
16323	12371	369	республика Чеченская, Шелковской район, село Харьковское, Советская, 5	f	medium
16271	12308	304	республика Чеченская, Шалинский район, Шали, Школьная, СОШ	f	large
16326	12374	372	республика Чеченская, Шелковской район, село Старощедринская, Советская, 52, Администрация	f	large
130741	12363	361	республика Чеченская, Шелковской район, село Старогладковская, Советская, 15, СДК	f	\N
16329	12378	375	республика Чеченская, Шелковской район, село ОТФ Колхоза Имени Ленина, Ленина, 62	f	large
16325	12373	371	республика Чеченская, Шелковской район, село ОТФ Колхоза Имени Ленина, Ленина, 52	f	large
16311	12359	357	республика Чеченская, Шелковской район, село ОТФ Колхоза Имени Ленина, Ленина, 45	f	large
16255	12291	287	республика Чеченская, Шелковской район, село ОТФ Колхоза Имени Ленина, Ленина, 35	f	large
16324	12372	370	республика Чеченская, Шелковской район, село Коби, Хетагурова, 81	f	medium
130739	12358	356	республика Чеченская, Шелковской район, село Дубовская, Дружбы, 11-а, НШ	f	\N
16316	12364	362	республика Чеченская, Шелковской район, село Воскресенское, Комарова, 14	f	medium
16332	12381	378	республика Чеченская, Шелковской район, село Бурунское, Школьная, 1, СОШ	f	small
130736	12343	340	республика Чеченская, Шатойский район, село Юкерч-Келой, Шатойская, частный дом Дундулова И.Я.	f	\N
130724	12329	328	республика Чеченская, Шатойский район, Шикарой, Школьная, 2, Администрация	f	\N
16298	12345	342	республика Чеченская, Шатойский район, село Шатой, Эштиева, 29	f	small
16299	12346	343	республика Чеченская, Шатойский район, село Шатой, Школьная, 4	f	medium
130734	12341	338	республика Чеченская, Шатойский район, село Шатой, Школьная, 5, СОШ	f	\N
16304	12351	348	республика Чеченская, Шатойский район, село Шатой, Центральная, 48	f	small
16301	12348	345	республика Чеченская, Шатойский район, село Шатой, Халида Асуева, 10	f	small
16291	12337	335	республика Чеченская, Шатойский район, село Шатой, Советская, 22, СОШ	f	large
16307	12354	351	республика Чеченская, Шатойский район, село Шатой, Подгорная, 8	f	small
16308	12355	352	республика Чеченская, Шатойский район, село Шатой, Лесная, 55	f	small
16292	12339	336	республика Чеченская, Шатойский район, село Шатой, Лесная, 57	f	medium
16302	12349	346	республика Чеченская, Шатойский район, село Шатой, Ленина, Здании ОСШ	f	small
16306	12353	350	республика Чеченская, Шатойский район, село Шатой, Заречная, 55	f	small
16305	12352	349	республика Чеченская, Шатойский район, село Шатой, Ахмадова, 60	f	small
130723	12328	327	республика Чеченская, Шатойский район, поселок Шарой, Кадырова, 6, ФАП	f	\N
16289	12325	324	республика Чеченская, Шатойский район, поселок Шарой, А-Кадырова, 16	f	small
130725	12330	329	республика Чеченская, Шатойский район, поселок Хуландой, Эрзи-Ара, 3, здание администрации	f	\N
130722	12327	326	республика Чеченская, Шатойский район, поселок Хакмадой, Центральная, 19, Администрация	f	\N
130735	12342	339	республика Чеченская, Шатойский район, село Урдюхой, Школьная, 12, ООШ	f	\N
16303	12350	347	республика Чеченская, Шатойский район, село Улус-Керт, Ленина, 23	f	small
130733	12340	337	республика Чеченская, Шатойский район, село Памятой, Центральная, б/н СОШ	f	\N
16300	12347	344	республика Чеченская, Шатойский район, село Мусолт-Аул, А. Агаевой, 4, НСШ	f	small
130726	12331	330	республика Чеченская, Шатойский район, село Кири, Мира, 8, Администрация	f	\N
130728	12333	332	республика Чеченская, Шатойский район, село Кенхи, Школьная, 1, СОШ №1	t	\N
130730	12335	334	республика Чеченская, Шатойский район, село Кенхи, Подгорная, 104, СОШ №3	f	\N
130729	12334	333	республика Чеченская, Шатойский район, село Кенхи, Ахмата Кадырова, 5, Администрация	f	\N
130727	12332	331	республика Чеченская, Шатойский район, село Бутти, Мира, 16, Администрация	f	\N
16297	12344	341	республика Чеченская, Шатойский район, село Борзой, В. Мучарова, 37	f	medium
16290	12326	325	республика Чеченская, Шаройский район, поселок Шарой, Мира, 3	f	small
16288	12323	321	республика Чеченская, Шалинский район, Шали, СОШ №10	f	large
16281	12316	314	республика Чеченская, Шалинский район, Шали, Школьная, СОШ №1	f	large
16280	12315	313	республика Чеченская, Шалинский район, Шали, Школьная, СОШ №1	f	large
16279	12315	312	республика Чеченская, Шалинский район, Шали, Школьная, СОШ №1	f	large
16276	12312	309	республика Чеченская, Шалинский район, Шали, Школьная, №1 СОШ	f	large
16272	12308	305	республика Чеченская, Шалинский район, Шали, Школьная, СОШ	f	large
16286	12321	319	республика Чеченская, Шалинский район, Шали, Учительская, СОШ №1	f	large
16270	12307	303	республика Чеченская, Шалинский район, Шали, Терская, 33	f	large
130718	12306	302	республика Чеченская, Шалинский район, Шали, Терская, 33, СОШ №2	f	\N
16282	12317	315	республика Чеченская, Шалинский район, Шали, Речная, СОШ №3	f	large
16287	12322	320	республика Чеченская, Шалинский район, Шали, Моздокская, СОШ №9	f	large
16266	12303	299	республика Чеченская, Шалинский район, Шали, Ленина, СОШ №3	f	large
16265	12302	298	республика Чеченская, Шалинский район, Шали, Ленина, СОШ №2	f	large
16264	12301	297	республика Чеченская, Шалинский район, Шали, Ленина, СОШ №1	f	large
16268	12305	301	республика Чеченская, Шалинский район, Шали, Кирова, СОШ	f	large
16285	12320	318	республика Чеченская, Шалинский район, Шали, Кадырова, СОШ №6	f	large
16284	12319	317	республика Чеченская, Шалинский район, Шали, Кадырова, 120	f	large
16283	12318	316	республика Чеченская, Шалинский район, Шали, Баумана, СОШ №4	f	large
16278	12314	311	республика Чеченская, Шалинский район, Шали, А-Х.Кадырова	f	large
16277	12313	310	республика Чеченская, Шалинский район, Шали, А-Х.Кадырова, СОШ	f	large
16274	12310	307	республика Чеченская, Шалинский район, Шали, А-Х. Кадырова, ООШ	f	large
16273	12309	306	республика Чеченская, Шалинский район, Шали, А-Х. Кадырова, СОШ	f	large
130717	12304	300	республика Чеченская, Шалинский район, Шали, А-Х. Кадырова, 31, СДК	f	\N
130666	12180	177	республика Чеченская, Шалинский район, село Цоцкин-Юрт, Гагарина, СОШ №2	f	\N
130667	12181	178	республика Чеченская, Шалинский район, село Цоцкин-Юрт, А-Х. Кадырова, СОШ №3	f	\N
16170	12171	168	республика Чеченская, Шалинский район, село Центорой, Сакказова, 25	f	large
16169	12171	167	республика Чеченская, Шалинский район, село Центорой, Сакказова, 25	f	large
16106	12071	65	республика Чеченская, Шалинский район, село Совхоз Южный, Южная	f	large
16166	12168	164	республика Чеченская, Шалинский район, село Совхоз Южный, Южная, 6	f	large
130719	12311	308	республика Чеченская, Шалинский район, село Новые Атаги, А-К. Кадырова, 176, СОШ №1	f	\N
130668	12189	185	республика Чеченская, Шалинский район, село Ники-Хита, СОШ	f	\N
16181	12182	179	республика Чеченская, Шалинский район, село Курчалой, Школьная, СДК	f	medium
16164	12166	162	республика Чеченская, Шалинский район, село Курчалой, Школьная, 1	f	large
16183	12185	181	республика Чеченская, Шалинский район, село Курчалой, Шидиева, 1	f	large
16184	12186	182	республика Чеченская, Шалинский район, село Курчалой, Центральная, 19	f	small
16168	12170	166	республика Чеченская, Шалинский район, село Курчалой, Майская, 47	f	large
16165	12167	163	республика Чеченская, Шалинский район, село Курчалой, М.Шатаева, 1	f	large
16185	12187	183	республика Чеченская, Шалинский район, село Курчалой, Восточная, 11	f	small
16173	12174	171	республика Чеченская, Шалинский район, село Курчалой, Ахмада Кадырова, 85	f	large
16178	12179	176	республика Чеченская, Шалинский район, село Курчалой, А.Х.Кадырова, СОШ №1	f	large
16172	12173	170	республика Чеченская, Шалинский район, село Курчалой, А.Р.Кадырова, СОШ №3	f	large
16177	12178	175	республика Чеченская, Шалинский район, село Курчалой, А.Кадырова, 27	f	large
16182	12184	180	республика Чеченская, Шалинский район, село Курчалой, А-Х.Кадырова, 5	f	medium
16175	12176	173	республика Чеченская, Шалинский район, село Курчалой, А-Х.Кадырова, 17	f	large
16174	12175	172	республика Чеченская, Шалинский район, село Курчалой, А-Х..Кадырова, 64	f	large
16262	12298	294	республика Чеченская, Урус-Мартановский район, село Шалажи, Л.Д.Магомадова, 63	f	large
16261	12297	293	республика Чеченская, Урус-Мартановский район, Урус-Мартан, пер.Школьный, СОШ	f	large
16238	12274	270	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Эльсанукаева, 1	f	large
16253	12289	285	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Школьная, 8а	f	large
130712	12277	273	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Степная, 3, ЦЗН	f	\N
16263	12299	295	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Сайдаева, 45	f	large
16259	12295	291	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Сааева, 2	f	large
16247	12283	279	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Пролетарская, 42	f	large
16250	12286	282	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Надречная, 11	f	large
16237	12273	269	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Маяковского, 10	f	large
16244	12280	276	республика Чеченская, Урус-Мартановский район, Урус-Мартан, М. Мерзоева, 1	f	large
130713	12278	274	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Куйбышева, 129	f	\N
130711	12275	271	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Куйбышева, 216, СОШ №4	f	\N
16243	12279	275	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Кирова, 82	f	large
16240	12276	272	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Калинина, 2а	f	large
16236	12272	268	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Каланчакская, 76	f	large
16235	12271	267	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Каланчакская, 40	f	large
16258	12294	290	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Кадырова, 39	f	large
16251	12287	283	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Кадырова, СОШ №2	f	large
16252	12288	284	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Кавказская, 120	f	large
16254	12290	286	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Дадарова, 243	f	large
16260	12296	292	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Героев, 54-А	f	large
16256	12292	288	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Ганчарова, 79	f	large
16246	12282	278	республика Чеченская, Урус-Мартановский район, Урус-Мартан, Вахитова, 54	f	large
16234	12270	266	республика Чеченская, Урус-Мартановский район, Урус-Мартан, 1-я А.Шерипова, 47	f	large
16233	12269	265	республика Чеченская, Урус-Мартановский район, Урус-Мартан, 1-я А.Шерипова, 27	f	large
16257	12293	289	республика Чеченская, Урус-Мартановский район, село Гойское, М.Дадаева, 59	f	large
130715	12285	281	республика Чеченская, Урус-Мартановский район, село Гехи, Эльдарханова, 11, ГУП «госхоз Гехинский»	f	\N
16248	12284	280	республика Чеченская, Урус-Мартановский район, село Алхан-Юрт, Х.Нурадилова, 53	f	medium
130714	12281	277	республика Чеченская, Урус-Мартановский район, село Алхазурово, А. Кадырова, СОШ № 2	f	\N
130669	12190	186	республика Чеченская, Ножай-Юртовский район, село Эникали, СОШ	f	\N
130697	12256	251	республика Чеченская, Ножай-Юртовский район, село Шовхол-Берди, Молодежная, 16, МОУ «СОШ с. Шовхал-Берды»	f	\N
16225	12233	229	республика Чеченская, Ножай-Юртовский район, село Чурч-Ирзу, Школьная, №3	f	medium
130686	12245	240	республика Чеченская, Ножай-Юртовский район, село Центорой, А. Митаева, 3, МОУ «НОШ с. Центарой»	f	\N
130695	12254	249	республика Чеченская, Ножай-Юртовский район, село Хочч-Ара, Речная, 8, МОУ ООШ с. Хочи-Ара	f	\N
130670	12191	187	республика Чеченская, Ножай-Юртовский район, село Хиди-Хутор, СОШ	f	\N
130691	12250	245	республика Чеченская, Ножай-Юртовский район, село Турни-Хутор, Кункуева, 18, МОУ СОШ с. Турты-Хутор	f	\N
130681	12238	233	республика Чеченская, Ножай-Юртовский район, Татай-Хутор, А.А. Кадырова, 48, СОШ	f	\N
130692	12251	246	республика Чеченская, Ножай-Юртовский район, село Саясан, А.А. Кадырова, 10, МОУ «СОШ с. Саясан»	f	\N
130694	12253	248	республика Чеченская, Ножай-Юртовский район, село Рогун-Кажа, А.А. Кадырова, 3, МОУ СОШ с. Рогун-Кажа	f	\N
16228	12236	232	республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт, Нурадилова, 15	f	medium
16227	12235	231	республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт, Кадырова, 26	f	medium
16232	12241	236	республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт, Гези-Хаджи, 7	f	medium
16224	12232	228	республика Чеченская, Ножай-Юртовский район, село Ножайт-Юрт, А.А.Кадырова, 152	f	large
16088	12053	47	республика Чеченская, Ножай-Юртовский район, село Морзой-Мохк, М.Кишиева, 27	f	small
130699	12258	253	республика Чеченская, Ножай-Юртовский район, село Мескеты, А.А. Кадырова, 19, МОУ СОШ	f	\N
130659	12146	142	республика Чеченская, Ножай-Юртовский район, село Малые Шуани, Дружбы, 21, Администрация	f	\N
130688	12247	242	республика Чеченская, Ножай-Юртовский район, село Малые Шуани, А.А. Кадырова, 2, «ООШ с. Шуани»	f	\N
130680	12234	230	республика Чеченская, Ножай-Юртовский район, Зандакское сельское поселение, А.А. Кадырова, 57, СОШ №2	f	\N
130687	12246	241	республика Чеченская, Ножай-Юртовский район, село Замай-Юрт, И. Цабаева, 5, МОУ «СОШ с. Замай-Юрт»	f	\N
16186	12188	184	республика Чеченская, Ножай-Юртовский район, село Джагларги, Центральная, 5	f	small
130682	12239	234	республика Чеченская, Ножай-Юртовский район, село Даттых, А.А. Кадырова, 36, СОШ	f	\N
130643	12130	126	республика Чеченская, Ножай-Юртовский район, село Гордали, Мамакаева, 18, СШ	f	\N
130685	12244	239	республика Чеченская, Ножай-Юртовский район, село Гордали, А.А. Кадырова, 1, МОУ «СОШ с. Гордали»	f	\N
130683	12242	237	республика Чеченская, Ножай-Юртовский район, село Гендерген, А.А. Кадырова, 21, СОШ	f	\N
130690	12249	244	республика Чеченская, Ножай-Юртовский район, село Гансолчу, А.А. Кадырова, 7, МОУ «СОШ с. Гансолчу»	f	\N
130701	12260	255	республика Чеченская, Ножай-Юртовский район, село Галайты, А.А. Кадырова, 19, МОУ «СОШ с. Галайты»	f	\N
16231	12240	235	республика Чеченская, Ножай-Юртовский район, село Булгат-Изру, Школьная	f	medium
130644	12131	127	республика Чеченская, Ножай-Юртовский район, село Бильты, Школьная, 1, СШ	f	\N
130698	12257	252	республика Чеченская, Ножай-Юртовский район, село Бешил-Ирзой, Кадырова, 24, МОУ «ООШ с. Бешил-Ирзу	f	\N
130700	12259	254	республика Чеченская, Ножай-Юртовский район, село Бетти-Мохк, А.А. Кадырова, 6, МОУ «СОШ с. Бетти-Мохк»	f	\N
130703	12262	257	республика Чеченская, Ножай-Юртовский район, село Беной-Ведено, А.А. Кадырова, 93, МОУ «СОШ с. Беной-Ведено»	f	\N
130684	12243	238	республика Чеченская, Ножай-Юртовский район, село Беной, А.А. Кадырова, 34, МОУ «СОШ с. Беной»	f	\N
130702	12261	256	республика Чеченская, Ножай-Юртовский район, село Балансу, А.А. Кадырова, 19, СОШ	f	\N
130689	12248	243	республика Чеченская, Ножай-Юртовский район, село Аллерой, Аллероева, 1, СОШ с. Аллерой	f	\N
130696	12255	250	республика Чеченская, Ножай-Юртовский район, село Айти-Мохк, А.А. Кадырова, 31, МОУ «СОШ с. Айти-Мохк»	f	\N
16201	12206	202	республика Чеченская, Наурский район, село Центральная Усадьба Колхоза Имени Мичурина, 1 	f	large
16195	12200	196	республика Чеченская, Наурский район, село Центральная Усадьба Колхоза Имени Мичурина, Центральная, 23	f	large
16209	12215	211	республика Чеченская, Наурский район, село Фрунзенское, Гагарина, 14	f	medium
16215	12221	217	республика Чеченская, Наурский район, село Савельевская, Бектамирова, 1А	f	large
130675	12217	213	республика Чеченская, Наурский район, село Новотерское, Победы, 4, СДК	f	\N
130674	12213	209	республика Чеченская, Наурский район, Николаевское сельское поселение, Чехова, 1, СОШ	f	\N
16222	12228	224	республика Чеченская, Наурский район, село Наурская, Советская, 34	f	large
16216	12222	218	республика Чеченская, Наурский район, село Наурская, Северная, 118	f	large
16213	12219	215	республика Чеченская, Наурский район, село Наурская, Пролетарская, 34	f	large
16218	12224	220	республика Чеченская, Наурский район, село Наурская, Октябрьская, 30А	f	large
16217	12223	219	республика Чеченская, Наурский район, село Наурская, Мира, 17	f	large
16221	12227	223	республика Чеченская, Наурский район, село Наурская, Ленина, 25	f	large
130676	12218	214	республика Чеченская, Наурский район, село Наурская, Ленина, СОШ	f	\N
16208	12214	210	республика Чеченская, Наурский район, село Наурская, Ленина, 30А	f	large
16214	12220	216	республика Чеченская, Наурский район, село Наурская, Кооперативная, 2 а	f	large
16210	12216	212	республика Чеченская, Наурский район, село Наурская, Гагарина, 40	f	large
16219	12225	221	республика Чеченская, Наурский район, село Наурская, Алленова, 33	f	large
130677	12229	225	республика Чеченская, Наурский район, село Ищерская, Л. Голикова, 7, СОШ	f	\N
16220	12226	222	республика Чеченская, Наурский район, село Алпатово, Клубная, 1Б	f	large
16202	12207	203	республика Чеченская, Надтеречный район, с. Братское, им. Лаудаева, 1, СОШ	f	large
16200	12205	201	республика Чеченская, Надтеречный район, село Лакха-Невре, А.А.Кадырова, 18	f	large
16203	12209	205	республика Чеченская, Надтеречный район, село Лакха-Невре, А.А.Кадырова, 4	f	medium
130671	12194	190	республика Чеченская, Надтеречный район, село Знаменское, 9, СОШ	f	\N
16204	12210	206	республика Чеченская, Надтеречный район, село Знаменское, Школьная, 1	f	medium
16197	12202	198	республика Чеченская, Надтеречный район, село Знаменское, Центральная, 17, СОШ №, 3	f	large
16192	12197	193	республика Чеченская, Надтеречный район, село Знаменское, Пионерская, 7	f	large
16206	12212	208	республика Чеченская, Надтеречный район, Новый городок, 10А	f	large
16196	12201	197	республика Чеченская, Надтеречный район, село Знаменское, Московская, 10, Гимназия № 10	f	large
16188	12193	189	республика Чеченская, Надтеречный район, село Знаменское, Мира, 31	f	medium
16191	12196	192	республика Чеченская, Надтеречный район, село Знаменское, Ленина, 30	f	large
16198	12203	199	республика Чеченская, Надтеречный район, село Знаменское, А.А.Кадырова, 41	f	large
16187	12192	188	республика Чеченская, Надтеречный район, село Знаменское, А.А.Кадырова, 6	f	small
16193	12198	194	республика Чеченская, Надтеречный район, село Знаменское, А-Х.Кадырова, 74	f	large
16194	12199	195	республика Чеченская, Надтеречный район, село Знаменское, 40 лет Победы, 36	f	large
16205	12211	207	республика Чеченская, Надтеречный район, поселок Горагорский, Центральная, 38	f	large
130673	12208	204	республика Чеченская, Надтеречный район, Братское, Лаудаева, СДК	f	\N
130672	12204	200	республика Чеченская, Надтеречный район, Бено-Юрт, Х. Исаева, 20, Участковая больница	f	\N
16190	12195	191	республика Чеченская, Надтеречный район, село Банкин-Юрт, Ленина, 33	f	large
16154	12153	149	республика Чеченская, Итум-Калинский район, село Кокадой, А. Кадырова, 10, ООШ	f	small
16157	12156	152	республика Чеченская, Итум-Калинский район, село Итум-Кале, Ченты-Аргунская, 14	f	small
16153	12152	148	республика Чеченская, Итум-Калинский район, село Итум-Кале, Хачероева, 7	f	small
16159	12158	154	республика Чеченская, Итум-Калинский район, село Итум-Кале, Ушкалоевская, 1А	f	small
16158	12157	153	республика Чеченская, Итум-Калинский район, село Итум-Кале, Ушкалоевская, 1а	f	small
16155	12154	150	республика Чеченская, Итум-Калинский район, село Итум-Кале, Ушкалоевская, 13	f	small
16161	12160	156	республика Чеченская, Итум-Калинский район, село Итум-Кале, М.Я.Узуева, 8	f	small
16156	12155	151	республика Чеченская, Итум-Калинский район, село Итум-Кале, Дадаева, 25	f	small
16162	12161	157	республика Чеченская, Итум-Калинский район, село Итум-Кале, А.Кадырова, 9	f	small
16160	12159	155	республика Чеченская, Итум-Калинский район, село Итум-Кале, А.Кадырова, 38	f	small
130647	12134	130	республика Чеченская, Гудермесский район, село Энгель-Юрт, Школьная, СШ №1	f	\N
130646	12133	129	республика Чеченская, Гудермесский район, село Энгель-Юрт, А. Кадырова, 15, СОШ № 2	f	\N
130656	12143	139	республика Чеченская, Гудермесский район, село Хангаш-Юрт, Терская, СШ	f	\N
130653	12140	136	республика Чеченская, Гудермесский район, Новый Энгеной, Мартовская, Админ	f	\N
130635	12125	118	республика Чеченская, Гудермесский район, поселок городского типа Новогрозненский, Жукова, СШ №1	f	\N
130651	12138	134	республика Чеченская, Гудермесский район, село Мелчу-Хе, Администрация села	f	\N
130642	12129	125	республика Чеченская, Гудермесский район, село Кошкельды, Х. Нурадилова, 70, Спорткомлекс Кошкельдинский	f	\N
130641	12128	124	республика Чеченская, Гудермесский район, село Кошкельды, А. Кадырова, 9, контора госхоза «Кошкельдинский»	f	\N
130658	12145	141	республика Чеченская, Гудермесский район, село Комсомольское, А.А. Кадырова, 65, СОШ №, 1	f	\N
130645	12132	128	республика Чеченская, Гудермесский район, село Кади-Юрт, Школьная, СШ	f	\N
130638	12052	121	республика Чеченская, Гудермесский район, село Ишхойюрт, М. Эсембаева, 2, СОШ № 1	f	\N
130652	12139	135	республика Чеченская, Гудермесский район, село Ислахан-Юрт, СШ №1	f	\N
130655	12142	138	республика Чеченская, Гудермесский район, село Джалка, А. Кадырова, 3, СОШ № 1	f	\N
130654	12141	137	республика Чеченская, Гудермесский район, село Джалка, А. Кадырова, 3, НШ при СОШ №1	f	\N
130661	12148	144	республика Чеченская, Гудермесский район, село Дарбанхи, СОШ	f	\N
16148	12115	108	республика Чеченская, Гудермесский район, Гудермес, пр. А. Кадырова, 110	f	large
16150	12117	110	республика Чеченская, Гудермесский район, Гудермес, Школьная, 9	f	large
16146	12113	106	республика Чеченская, Гудермесский район, Гудермес, Центральная, СОШ №8	f	large
130636	12126	119	республика Чеченская, Гудермесский район, Гудермес, Победы, 54, СШ №2	f	\N
16142	12110	102	республика Чеченская, Гудермесский район, Гудермес, Октябрьская, 35	f	large
16145	12112	105	республика Чеченская, Гудермесский район, Гудермес, Котовского, 3	f	large
16144	12112	104	республика Чеченская, Гудермесский район, Гудермес, Котовского, 3	f	large
130633	12123	116	республика Чеченская, Гудермесский район, Гудермес, Кирова, 2, ГУП Чечавтотранс	f	\N
16143	12111	103	республика Чеченская, Гудермесский район, Гудермес, Кирова, 173	f	large
16147	12114	107	республика Чеченская, Гудермесский район, Гудермес, Интернациональная, 56	f	large
130631	12121	114	республика Чеченская, Гудермесский район, Гудермес, А. Кадырова, 20, СОШ № 9	f	\N
16149	12116	109	республика Чеченская, Гудермесский район, Гудермес, 84-й Морской бригады, 28	f	large
130639	12076	122	республика Чеченская, Гудермесский район, село Герзель-Аул, контора гз Восточный	f	\N
130640	12127	123	республика Чеченская, Гудермесский район, село Герзель-Аул, Мира, 36А, СОШ №2	f	\N
130648	12135	131	республика Чеченская, Гудермесский район, село Верхний Суворов-Юрт, Школьная, 3, СШ №2	f	\N
130660	12147	143	республика Чеченская, Гудермесский район, село Брагуны, Химикова, 1, СОШ №1	f	\N
130657	12144	140	республика Чеченская, Гудермесский район, село Азамат-Юрт, Кадырова, 7, СОШ №1	f	\N
130709	12267	263	республика Чеченская, Грозненский район, ст.Ассиновская, Заводская, 66, СШ №3	f	\N
130710	12268	264	республика Чеченская, Грозненский район, ст.Ассиновская, Бакина, 58, СШ №1	f	\N
130707	12183	261	республика Чеченская, Грозненский район, с.Серноводск, Гагарина, 10, СШ №4	f	\N
130704	12263	258	республика Чеченская, Грозненский район, с.Серноводск, Бр. Гайтукаевых, 55, СШ №1	f	\N
130705	12264	259	республика Чеченская, Грозненский район, с.Серноводск, 2-ой пер. Мичурина, 6, СШ №3	f	\N
130749	12410	410	республика Чеченская, Грозненский район, село Старая Сунжа, У.Р. Даудова, 94, МУК «Старосунженский»	f	\N
130748	12409	409	республика Чеченская, Грозненский район, село Старая Сунжа, И.Х. Хаджиханова, СОШ №65	f	\N
130706	12265	260	республика Чеченская, Грозненский район, Серноводск, Кадырова	f	\N
16395	12452	453	республика Чеченская, Грозненский район, село Садовое, Черкаская, 35	f	large
16136	12103	95	республика Чеченская, Грозненский район, село Радужное, Шоссейная, 17	f	large
130766	12438	440	республика Чеченская, Грозненский район, Пригородное, Шефская, 23, ПУ №11	f	\N
16135	12102	94	республика Чеченская, Грозненский район, село Побединское, Школьный, 1	f	large
16076	12040	35	республика Чеченская, Грозненский район, село Октябрьское, Береговая, 15	f	medium
16139	12106	98	республика Чеченская, Грозненский район, село Нагорное, Тракторная, 1	f	medium
16138	12105	97	республика Чеченская, Грозненский район, село Керлаюрт, Школьная, 4	f	medium
16137	12104	96	республика Чеченская, Грозненский район, село Долинский, Молодежная, 1	f	medium
16130	12096	89	республика Чеченская, Грозненский район, Грозный, Школьная, 1	f	large
16124	12090	83	республика Чеченская, Грозненский район, Грозный, Нурадилова, 100	f	large
16114	12080	73	республика Чеченская, Грозненский район, Грозный, Нагорная, 2	f	large
16111	12077	70	республика Чеченская, Грозненский район, Грозный, Кадырова, 1	f	large
16113	12079	72	республика Чеченская, Грозненский район, Грозный, Арсаханова, 15	f	medium
16394	12108	100	республика Чеченская, Грозненский район, Грозный, 50-лет Октября, СОШ	f	medium
16115	12081	74	республика Чеченская, Грозненский район, село Гикаловский, Октябрьская, 1	f	medium
16110	12075	69	республика Чеченская, Грозненский район, село Виноградное, Ленина, 50а	f	large
130750	12411	411	республика Чеченская, Грозненский район, село Алхан-Чуртский, Садовая , 1, СОШ №64	f	\N
16132	12099	91	республика Чеченская, Грозненский район, село Алхан-Кала, Шерипова, 92	f	large
130626	12097	90	республика Чеченская, Грозненский район, село Алхан-Кала, Нурадилова, 56, СОШ №, 1	f	\N
16103	12068	62	Россия, республика Чеченская, Веденский район, поселок разрушенный Хой	f	small
16078	12042	37	республика Чеченская, Веденский район, село Эшилхотой, Школьная, 8	f	small
16092	12057	51	республика Чеченская, Веденский район, село Эрсеной, Школьная, 3	f	small
16093	12058	52	республика Чеченская, Веденский район, село Элистанжи, СОШ	f	large
16085	12049	44	республика Чеченская, Веденский район, село Ца-Ведено, Центральная, 15	f	small
16083	12047	42	республика Чеченская, Веденский район, село Ца-Ведено, А.А.Кадырова, 24	f	medium
16094	12059	53	республика Чеченская, Веденский район, село Хатуни, Школьная, 25	f	large
16095	12060	54	республика Чеченская, Веденский район, село Тевзана, Школьная, 14	f	large
16097	12062	56	республика Чеченская, Веденский район, село Сельментаузен, А.А.Кадырова, 33	f	medium
16087	12051	46	республика Чеченская, Веденский район, село Первомайское, Школьная, 1	f	small
130625	12066	60	республика Чеченская, Веденский район, село Нижние Курчали, Новая, 2, СОШ	f	\N
16077	12041	36	республика Чеченская, Веденский район, село Нефтянка, Школьная, 11	f	small
16090	12055	49	республика Чеченская, Веденский район, село Меседой, Частный дом	f	small
16096	12061	55	республика Чеченская, Веденский район, село Махкеты, СОШ	f	large
16081	12045	40	республика Чеченская, Веденский район, село Дышне-Ведено, Х.Бекбулатова, СОШ №2	f	large
16080	12044	39	республика Чеченская, Веденский район, село Дышне-Ведено, А.А.Кадырова, СОШ №1	f	large
16100	12065	59	республика Чеченская, Веденский район, село Дарго, А.А.Кадырова, 154	f	medium
16099	12064	58	республика Чеченская, Веденский район, село Дарго, А.А.Кадырова, 62	f	medium
16089	12054	48	республика Чеченская, Веденский район, село Гуни, Школьная, СОШ	f	small
16084	12048	43	республика Чеченская, Веденский район, село Верхатой, СОШ	f	small
16098	12063	57	республика Чеченская, Веденский район, село Ведено, с.Дуц-Хутор, 1	f	small
16082	12046	41	республика Чеченская, Веденский район, село Ведено, Школьная, 10	f	small
16079	12043	38	республика Чеченская, Веденский район, село Ведено, Ш.Мугуева, 8	f	large
16102	12067	61	республика Чеченская, Веденский район, село Ведено, Х.Нурадилова, 15	f	small
16105	12070	64	республика Чеченская, Веденский район, село Ведено, А.А.Кадырова, 49	f	small
16104	12069	63	республика Чеченская, Веденский район, село Ведено, А.А.Кадырова, 8	f	small
16075	12039	34	республика Чеченская, Веденский район, село Ведено, А.А.Кадырова, 22	f	large
16086	12050	45	республика Чеченская, Веденский район, село Беной, Кадырова, ООШ	f	small
16091	12056	50	республика Чеченская, Веденский район, село Агишбатой, Центральная, 8	f	small
16068	12032	27	республика Чеченская, Ачхой-Мартановский район, село Катыр-Юрт, А.Кадырова, 118	f	large
16120	12086	79	республика Чеченская, Ачхой-Мартановский район, село Закан-Юрт, Школьная, 13	f	large
16072	12036	31	республика Чеченская, Ачхой-Мартановский район, село Бамут, Школьная, 9	f	large
16071	12035	30	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Школьная, 17	f	large
16060	12025	19	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Школьная, 10	f	large
16062	12027	21	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Шерипова	f	large
16056	12021	15	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Чапаева, 66	f	large
16057	12022	16	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Х.Нурадилова, 150	f	medium
16053	12018	12	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Х.Нурадилова, 185	f	medium
16070	12034	29	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Садовая, 28	f	medium
16069	12033	28	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Орджоникидзе, 64	f	large
130624	12031	26	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Мамакаева, 42	f	\N
16055	12020	14	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Мамакаева, 6	f	large
16054	12019	13	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Мамакаева, 19	f	large
16051	12016	10	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Им.Кунтаева, 1	f	large
16074	12038	33	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Грейдерная, 23	f	large
16066	12030	25	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Гайрбекова, 39	f	large
16065	12030	24	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Гайрбекова, 39	f	large
16073	12037	32	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Гагарина, 3	f	small
16064	12029	23	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, Ахмата Кадырова	f	large
16061	12026	20	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, А.Кадырова, 14	f	large
16059	12024	18	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, А.Кадырова, 9	f	large
16058	12023	17	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, А.Кадырова, 130	f	medium
16052	12017	11	республика Чеченская, Ачхой-Мартановский район, село Ачхой-Мартан, А.Кадырова, 13	f	large
16176	12177	174	республика Чеченская, Курчалоевский район, село Курчалой, М.Даудова, СОШ №1	f	large
11152	89533	110	республика Северная Осетия-Алания, село Троицкое, Кирова, 100	f	large
11161	89556	119	республика Северная Осетия-Алания, Моздок, мкр-н Моздок-121 	f	large
11156	89551	114	республика Северная Осетия-Алания, Моздок, Мира, 1	f	large
11153	89548	111	республика Северная Осетия-Алания, Моздок, Кирова, 91	f	large
11343	89723	301	республика Северная Осетия-Алания, Владикавказ, Средняя школа	t	large
11305	89692	263	республика Северная Осетия-Алания, Владикавказ, Спутник	f	large
11384	89756	342	республика Северная Осетия-Алания, Владикавказ, проспект Коста, 283	f	large
11381	89753	339	республика Северная Осетия-Алания, Владикавказ, проспект Коста, 286	f	large
11367	89742	325	республика Северная Осетия-Алания, Владикавказ, проспект Коста, 172	f	large
11368	89728	326	республика Северная Осетия-Алания, Владикавказ, проспект Коста, 195	f	large
11347	89727	305	республика Северная Осетия-Алания, Владикавказ, проспект Коста, 38	f	medium
11344	89724	302	республика Северная Осетия-Алания, Владикавказ, проспект Коста, 11	f	medium
11353	89733	311	республика Северная Осетия-Алания, Владикавказ, проспект Доватора, 11А	f	large
11374	89746	332	республика Северная Осетия-Алания, Владикавказ, площадь Победы, 1	f	large
11301	89688	259	республика Северная Осетия-Алания, Владикавказ, Шмулевича, 41	f	large
11300	89687	258	республика Северная Осетия-Алания, Владикавказ, Шмулевича, 10а	f	large
11329	89713	287	республика Северная Осетия-Алания, Владикавказ, Чкалова, 8	f	medium
11328	89712	286	республика Северная Осетия-Алания, Владикавказ, Чкалова, 8	f	large
11284	89674	242	республика Северная Осетия-Алания, Владикавказ, Церетели, 25	f	large
11298	89686	256	республика Северная Осетия-Алания, Владикавказ, Церетели, 7	f	medium
11361	89737	319	республика Северная Осетия-Алания, Владикавказ, Цейская, 1	f	large
11369	89654	327	республика Северная Осетия-Алания, Владикавказ, Тогоева, 48	f	large
11324	89709	282	республика Северная Осетия-Алания, Владикавказ, Тельмана, 2	f	large
11318	89702	276	республика Северная Осетия-Алания, Владикавказ, Тельмана, 31в	f	large
11296	89684	254	республика Северная Осетия-Алания, Владикавказ, Тамаева, 15	f	large
11340	89720	298	республика Северная Осетия-Алания, Владикавказ, Севастопольская, 7а, Промышленный муниципальный округ	f	large
11286	89676	244	республика Северная Осетия-Алания, Владикавказ, Революции, 34	f	medium
11293	89681	251	республика Северная Осетия-Алания, Владикавказ, Пушкинская, 47	f	large
11291	89679	249	республика Северная Осетия-Алания, Владикавказ, Пушкинская, 40	f	medium
11260	89652	218	республика Северная Осетия-Алания, Владикавказ, Пролетарская, 43	f	large
11317	89701	275	республика Северная Осетия-Алания, Владикавказ, Пожарского, 21, Промышленный муниципальный округ	f	large
11279	89670	237	республика Северная Осетия-Алания, Владикавказ, Павленко, 69	f	large
11274	89666	232	республика Северная Осетия-Алания, Владикавказ, Осетинская горка, 1	f	large
11273	89665	231	республика Северная Осетия-Алания, Владикавказ, Осетинская горка, 1	f	large
11322	89707	280	республика Северная Осетия-Алания, Владикавказ, Огурцова, 2, Промышленный муниципальный округ	f	large
11319	89703	277	республика Северная Осетия-Алания, Владикавказ, Николаева, 44	f	large
11316	89700	274	республика Северная Осетия-Алания, Владикавказ, Николаева, 42	f	medium
11382	89754	340	республика Северная Осетия-Алания, Владикавказ, Московская, 16	f	large
11339	89719	297	республика Северная Осетия-Алания, Владикавказ, Молодежная, 7	f	large
11315	89699	273	республика Северная Осетия-Алания, Владикавказ, Мичурина /Остаева, 8/5	f	medium
11326	89711	284	республика Северная Осетия-Алания, Владикавказ, Миллеров, 30	f	large
11325	89710	283	республика Северная Осетия-Алания, Владикавказ, Миллера, 32	f	medium
11338	89718	296	республика Северная Осетия-Алания, Владикавказ, Маркова, 44	f	large
11333	89714	291	республика Северная Осетия-Алания, Владикавказ, Маркова, 26	f	large
11295	89683	253	республика Северная Осетия-Алания, Владикавказ, Маркова, 2а	f	medium
11393	89763	351	республика Северная Осетия-Алания, Владикавказ, М. Пехотинцев, 5	f	large
11392	89762	350	республика Северная Осетия-Алания, Владикавказ, М. Пехотинцев, 7А	f	large
11380	89752	338	республика Северная Осетия-Алания, Владикавказ, Леонова, 5/5	f	large
11379	89751	337	республика Северная Осетия-Алания, Владикавказ, Леонова, 2	f	large
11285	89675	243	республика Северная Осетия-Алания, Владикавказ, Ленина, 4	f	large
11383	89755	341	республика Северная Осетия-Алания, Владикавказ, Леваневского, 279	f	large
11372	89744	330	республика Северная Осетия-Алания, Владикавказ, Леваневского, 53	f	large
11371	89743	329	республика Северная Осетия-Алания, Владикавказ, Леваневского, 49	f	large
11354	89734	312	республика Северная Осетия-Алания, Владикавказ, Кырджалийская, 19	f	large
11280	89671	238	республика Северная Осетия-Алания, Владикавказ, Кутузова, 74а	f	large
11278	89669	236	республика Северная Осетия-Алания, Владикавказ, Кутузова, 72	f	large
11277	89669	235	республика Северная Осетия-Алания, Владикавказ, Кутузова, 72	f	large
11304	89691	262	республика Северная Осетия-Алания, Владикавказ, Куйбышева, 126б	f	large
11303	89690	261	республика Северная Осетия-Алания, Владикавказ, Куйбышева, 126б	f	large
11302	89689	260	республика Северная Осетия-Алания, Владикавказ, Куйбышева, 75	f	large
11294	89682	252	республика Северная Осетия-Алания, Владикавказ, Куйбышева, 66	f	large
11365	89740	323	республика Северная Осетия-Алания, Владикавказ, Коцоева, 66	f	large
11364	89739	322	республика Северная Осетия-Алания, Владикавказ, Коцоева, 43	f	large
11373	89745	331	республика Северная Осетия-Алания, Владикавказ, Коста проспект, 221	f	large
11275	89667	233	республика Северная Осетия-Алания, Владикавказ, Коста Хетагурова/Кантемирова, 23/23а	f	large
11348	89705	306	республика Северная Осетия-Алания, Владикавказ, Коблова, 5	f	large
11288	89678	246	республика Северная Осетия-Алания, Владикавказ, Кирова, 46	f	medium
11378	89750	336	республика Северная Осетия-Алания, Владикавказ, Кесаева, 135	f	large
11377	89749	335	республика Северная Осетия-Алания, Владикавказ, Калоева, 408	f	large
11375	89747	333	республика Северная Осетия-Алания, Владикавказ, Калинина, 2	f	large
11227	89618	185	республика Северная Осетия-Алания, Владикавказ, К. Хетагурова, 44	f	medium
11366	89741	324	республика Северная Осетия-Алания, Владикавказ, К. Маркса, 36	f	large
11363	89738	321	республика Северная Осетия-Алания, Владикавказ, К. Маркса, 19	f	large
11323	89708	281	республика Северная Осетия-Алания, Владикавказ, Иристонская, 3	f	large
11321	89706	279	республика Северная Осетия-Алания, Владикавказ, Иристонская, 25	f	large
11313	89698	271	республика Северная Осетия-Алания, Владикавказ, Иристонская, 43	f	medium
11312	89697	270	республика Северная Осетия-Алания, Владикавказ, Иристонская, 70	f	large
11334	89715	292	республика Северная Осетия-Алания, Владикавказ, Интернациональная, 24	f	large
11376	89748	334	республика Северная Осетия-Алания, Владикавказ, З. Космодемьянской, 3	f	large
11356	89735	314	республика Северная Осетия-Алания, Владикавказ, Доватора проспект, 35А	f	large
11355	89735	313	республика Северная Осетия-Алания, Владикавказ, Доватора проспект, 35А	f	large
11352	89732	310	республика Северная Осетия-Алания, Владикавказ, Доватора пр, 7А	f	large
11405	89772	363	республика Северная Осетия-Алания, Владикавказ, Дзусова, 28	f	large
11403	89771	361	республика Северная Осетия-Алания, Владикавказ, Дзусова, 36	f	large
11402	89771	360	республика Северная Осетия-Алания, Владикавказ, Дзусова, 36	f	large
11404	89771	362	республика Северная Осетия-Алания, Владикавказ, Дзусова, 36	f	large
11401	89770	359	республика Северная Осетия-Алания, Владикавказ, Дзусова, 24А	f	large
11262	89655	220	республика Северная Осетия-Алания, Владикавказ, Джимиева, 48	f	medium
11297	89685	255	республика Северная Осетия-Алания, Владикавказ, Джанаева, 36	f	large
11276	89668	234	республика Северная Осетия-Алания, Владикавказ, Гэсовская, 3	f	large
11271	89664	229	республика Северная Осетия-Алания, Владикавказ, Гэсовская, 3	f	large
11385	89757	343	республика Северная Осетия-Алания, Владикавказ, Гугкаева, 24	f	large
11346	89726	304	республика Северная Осетия-Алания, Владикавказ, Грибоедова, 1	f	large
11345	89725	303	республика Северная Осетия-Алания, Владикавказ, Герцена, 7	f	large
11351	89731	309	республика Северная Осетия-Алания, Владикавказ, Гастелло, 67	f	large
11388	89760	346	республика Северная Осетия-Алания, Владикавказ, Галковского, 221	f	large
11387	89759	345	республика Северная Осетия-Алания, Владикавказ, Галковского, 227А	f	large
11386	89758	344	республика Северная Осетия-Алания, Владикавказ, Галковского, 235А	f	large
11350	89730	308	республика Северная Осетия-Алания, Владикавказ, Гадиева, 77	f	large
11349	89729	307	республика Северная Осетия-Алания, Владикавказ, Гадиева, 10	f	large
11238	89629	196	республика Северная Осетия-Алания, Владикавказ, Гагарина, 18	f	large
11396	89766	354	республика Северная Осетия-Алания, Владикавказ, Владикавказская, 12/2	f	large
11409	89775	367	республика Северная Осетия-Алания, Владикавказ, Весенняя, 17	f	large
11408	89775	366	республика Северная Осетия-Алания, Владикавказ, Весенняя, 17	f	large
11390	89761	348	республика Северная Осетия-Алания, Владикавказ, Весенняя, 6	f	large
11389	89761	347	республика Северная Осетия-Алания, Владикавказ, Весенняя, 6	f	large
11391	89761	349	республика Северная Осетия-Алания, Владикавказ, Весенняя, 6	f	large
11292	89680	250	республика Северная Осетия-Алания, Владикавказ, Ватутина, 46	f	large
11287	89677	245	республика Северная Осетия-Алания, Владикавказ, В. Баллаева, 17	f	large
11247	89639	205	республика Северная Осетия-Алания, Владикавказ, Бибилова, 27	f	large
11320	89704	278	республика Северная Осетия-Алания, Владикавказ, Бзарова, 29	f	large
11357	89736	315	республика Северная Осетия-Алания, Владикавказ, Барбашова, 43Б	f	large
11281	89672	239	республика Северная Осетия-Алания, Владикавказ, Армянская, 30/1	f	large
11407	89774	365	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 28	f	large
11406	89773	364	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 28	f	large
11400	89769	358	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 12	f	large
11399	89768	357	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 12	f	large
11398	89767	356	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 7	f	large
11397	89767	355	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 7	f	large
11395	89765	353	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 23	f	large
11394	89764	352	республика Северная Осетия-Алания, Владикавказ, А. Кесаева, 23	f	large
11087	89483	45	республика Северная Осетия-Алания, Ардон, Ленина, 40	f	large
11230	89621	188	республика Северная Осетия-Алания, Пригородный район, село Чермен, Орджоникидзе, 31	f	medium
11245	89637	203	республика Северная Осетия-Алания, Пригородный район, село Сунжа, Бибилова, 48	f	large
11270	89663	228	республика Северная Осетия-Алания, Пригородный район, поселок Первомайский, Клуб воинской части	t	small
11235	89626	193	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Ю. Кучиева, 39	f	large
11234	89625	192	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Ю. Кучиева, 96А	f	large
11229	89620	187	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Школьная, 17	f	large
11236	89627	194	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Ф. Кастро, 4	f	large
11237	89628	195	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Терешковой, 56	f	large
11266	89659	224	республика Северная Осетия-Алания, Пригородный район, Р. Люксембург, 2Г	f	large
11259	89651	217	республика Северная Осетия-Алания, Пригородный район, Пролетарская, 1	f	large
11242	89634	200	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Павла Тедеева, 2	f	large
11240	89632	198	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Павла Тедеева, 72	f	large
11239	89630	197	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Павла Тедеева, 58	f	large
11244	89636	202	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Октябрьская, 3	f	large
11251	89644	209	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Мира, 37	f	large
11160	89555	118	республика Северная Осетия-Алания, Моздокский район, Моздок, Вокзальная, 17	f	large
11241	89633	199	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Маяковского, 12	f	large
11258	89650	216	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Ленина, 120	f	large
11257	89648	215	республика Северная Осетия-Алания, Пригородный район, Ленина, 107	f	large
11255	89648	213	республика Северная Осетия-Алания, Пригородный район, Ленина, 107	f	large
11248	89640	206	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Ленина, 24	f	large
11243	89635	201	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Ленина, 16	f	large
11226	89617	184	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Коммунальная, 38	f	large
11249	89641	207	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Кирова, 1	f	large
11231	89622	189	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Кирова, 5	f	large
11228	89619	186	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Калинина, 16	f	large
11267	89660	225	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Гагарина, 6	f	large
11253	89646	211	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Владикавказская, 58	f	large
11268	89661	226	республика Северная Осетия-Алания, Пригородный район, село Октябрьское, Вильямса, 1	f	large
11232	89623	190	республика Северная Осетия-Алания, Пригородный район, 50 Лет Октября, 10	f	large
11263	89656	221	республика Северная Осетия-Алания, Пригородный район, село Кобан, АМС Кобанского сельского поселения	t	small
11265	89658	223	республика Северная Осетия-Алания, Пригородный район, село Кармадон, АМС Кармадонского сельского поселен	t	small
11233	89624	191	республика Северная Осетия-Алания, Пригородный район, село Камбилеевское, Ю. Кучиева, 85	f	large
11254	89647	212	республика Северная Осетия-Алания, Пригородный район, Владикавказ, Некрасова, 2	f	large
11246	89638	204	республика Северная Осетия-Алания, Пригородный район, Владикавказ, Комсомольская, 41	f	large
11250	89642	208	республика Северная Осетия-Алания, Пригородный район, Владикавказ, Коминтерна, 55	f	large
11256	89649	214	республика Северная Осетия-Алания, Пригородный район, Владикавказ, Калоева, 35	f	large
11261	89653	219	республика Северная Осетия-Алания, Пригородный район, село Верхняя Саниба, Губа Губиева, 48	t	medium
11252	89645	210	республика Северная Осетия-Алания, Пригородный район, село Архонская, Крупской, 45	f	medium
11269	89662	227	Россия, республика Северная Осетия-Алания, Пригородный район, село Алханчурт	f	medium
11197	89590	155	республика Северная Осетия-Алания, Правобережный район, село Хумалаг, Советская, 3	f	large
11200	89593	158	республика Северная Осетия-Алания, Правобережный район, село Раздзог, Ленина, 10	f	small
11193	89586	151	республика Северная Осетия-Алания, Правобережный район, Школьная, 1	f	large
11212	89606	170	республика Северная Осетия-Алания, Правобережный район, Беслан, Цаликова, 2	f	large
11220	89614	178	республика Северная Осетия-Алания, Правобережный район, Беслан, Хлебный, 3	f	large
11192	89585	150	республика Северная Осетия-Алания, Правобережный район, Беслан, Суджаева, 58	f	large
11208	89602	166	республика Северная Осетия-Алания, Правобережный район, Беслан, Сигова, 11	f	large
11210	89604	168	республика Северная Осетия-Алания, Правобережный район, Беслан, Привокзальная, 5	f	large
11213	89607	171	республика Северная Осетия-Алания, Правобережный район, Беслан, Подгорная, 87	f	large
11204	89598	162	республика Северная Осетия-Алания, Правобережный район, Беслан, Октябрьская, 15	f	large
11222	89616	180	республика Северная Осетия-Алания, Правобережный район, Беслан, Окружная, 7	f	large
11207	89601	165	республика Северная Осетия-Алания, Правобережный район, Беслан, Ленина, 14	f	large
11203	89596	161	республика Северная Осетия-Алания, Правобережный район, Беслан, Ленина, 70	f	large
11196	89589	154	республика Северная Осетия-Алания, Правобережный район, Беслан, Ленина, 71	f	large
11195	89588	153	республика Северная Осетия-Алания, Правобережный район, Ленина, 45	f	large
11206	89600	164	республика Северная Осетия-Алания, Правобережный район, Беслан, Котовского, 2	f	large
7486	38922	40	республика Карачаево-Черкесская, Черкесск, Ставропольская, 36	f	medium
11209	89603	167	республика Северная Осетия-Алания, Правобережный район, Беслан, Кооперативная, 10	f	large
11218	89612	176	республика Северная Осетия-Алания, Правобережный район, Беслан, Коминтерна, 128	f	large
11217	89611	175	республика Северная Осетия-Алания, Правобережный район, Беслан, Коминтерна, 130	f	large
11205	89599	163	республика Северная Осетия-Алания, Правобережный район, Беслан, Иристонская, 84А	f	large
11219	89613	177	республика Северная Осетия-Алания, Правобережный район, Беслан, Дзарахохова, 39	f	large
11202	89595	160	республика Северная Осетия-Алания, Правобережный район, Беслан, Джимиева, 48	f	large
11221	89615	179	республика Северная Осетия-Алания, Правобережный район, Беслан, Гагарина, 36	f	large
11214	89608	172	республика Северная Осетия-Алания, Правобережный район, Беслан, Вокзальная, 1	f	large
11216	89610	174	республика Северная Осетия-Алания, Правобережный район, Беслан, Братьев Ногаевых, 132	f	large
11194	89587	152	республика Северная Осетия-Алания, Правобережный район, Беслан, Бзарова, 35	f	large
11215	89609	173	республика Северная Осетия-Алания, Правобережный район, Беслан, Бесланская, 1	f	large
11201	89594	159	республика Северная Осетия-Алания, Правобережный район, село Батако, Плиева, 80	f	medium
11189	89582	147	республика Северная Осетия-Алания, Моздокский район, село Черноярский, Красный уголок ж.д. станции Черноярская	f	small
11188	89581	146	республика Северная Осетия-Алания, Моздокский район, село Черноярский, Красная, 51	f	medium
11186	89579	144	республика Северная Осетия-Алания, Моздокский район, село Хурикау, Гагарина, 28-А	t	medium
11167	89562	125	республика Северная Осетия-Алания, Моздокский район, село Троицкое, Октябрьская, 44	f	large
11168	89563	126	республика Северная Осетия-Алания, Моздокский район, село Троицкое, Виноградная, 34	f	large
11171	89566	129	республика Северная Осетия-Алания, Моздокский район, село Терская, Ленина, 19	f	large
11147	89543	105	республика Северная Осетия-Алания, Моздокский район, село Тельман, Никулиной, 7	t	small
11184	89577	142	республика Северная Осетия-Алания, Моздокский район, село Сухотское, Садовая, 50	f	medium
11179	89572	137	республика Северная Осетия-Алания, Моздокский район, село Советский, Центральная, 19	f	small
11177	89571	135	республика Северная Осетия-Алания, Моздокский район, село Садовый, Театральная, 5	t	medium
11182	89575	140	республика Северная Осетия-Алания, Моздокский район, село Раздольное, Октябрьская, 7	f	medium
11191	89584	149	республика Северная Осетия-Алания, Моздокский район, село Притеречный, Кирова, 24	t	large
11176	89570	134	республика Северная Осетия-Алания, Моздокский район, село Предгорное, Коркмасова, 1-А	f	medium
11181	89574	139	республика Северная Осетия-Алания, Моздокский район, село Павлодольская, Уварова пер, 1	f	large
11180	89573	138	республика Северная Осетия-Алания, Моздокский район, село Павлодольская, К. Хетагурова пер, 18	f	large
11187	89580	145	республика Северная Осетия-Алания, Моздокский район, село Новоосетинская, Октябрьская, 57	f	medium
11155	89550	113	республика Северная Осетия-Алания, Моздокский район, Моздок, пл. 50 лет Октября, 43-А	f	large
11154	89549	112	республика Северная Осетия-Алания, Моздокский район, Моздок, Юбилейная, 13	f	large
11162	89557	120	республика Северная Осетия-Алания, Моздокский район, Моздок, Элеваторная, 1	f	medium
11151	89547	109	республика Северная Осетия-Алания, Моздокский район, Моздок, Чкалова, 2-Б	f	large
11157	89552	115	республика Северная Осетия-Алания, Моздокский район, Моздок, Фрунзе, 12	f	large
11158	89553	116	республика Северная Осетия-Алания, Моздокский район, Моздок, Первомайская, 130	f	large
11163	89558	121	республика Северная Осетия-Алания, Моздокский район, Моздок, Лебедева-Кумача, 58	f	large
11159	89554	117	республика Северная Осетия-Алания, Моздокский район, Моздок, Кирова, 110	f	large
11150	89546	108	республика Северная Осетия-Алания, Моздокский район, Моздок, Кирова, 41	f	large
11149	89545	107	республика Северная Осетия-Алания, Моздокский район, Моздок, Кирова, 20	f	large
11148	89544	106	республика Северная Осетия-Алания, Моздокский район, Моздок, Кирова, 7	f	large
11164	89559	122	республика Северная Осетия-Алания, Моздокский район, Моздок, Гастелло, 4	f	large
7482	38918	36	республика Карачаево-Черкесская, Черкесск, Ставропольская, 35	f	large
11185	89578	143	республика Северная Осетия-Алания, Моздокский район, село Малгобек, Советская, 33	f	small
11166	89561	124	республика Северная Осетия-Алания, Моздокский район, село Луковская, Усанова, 35	f	large
11165	89560	123	республика Северная Осетия-Алания, Моздокский район, село Луковская, Усанова, 33	f	large
11174	89568	132	республика Северная Осетия-Алания, Моздокский район, село Кизляр, Первомайская, 39	f	large
11175	89569	133	республика Северная Осетия-Алания, Моздокский район, село Кизляр, Мира, 52	f	large
11173	88686	131	республика Северная Осетия-Алания, Моздокский район, село Кизляр, Мира, 54	f	large
11172	89567	130	республика Северная Осетия-Алания, Моздокский район, село Киевское, Кирова, 1	f	large
11170	89565	128	республика Северная Осетия-Алания, Моздокский район, село Калининский, Береговая, 26	f	large
11190	89583	148	республика Северная Осетия-Алания, Моздокский район, село Елбаево, Бегиева, 1	t	small
11183	89576	141	республика Северная Осетия-Алания, Моздокский район, село Виноградное, Советская, 3	f	large
11169	89564	127	республика Северная Осетия-Алания, Моздокский район, село Веселовское, Х. Хугаева, 2	f	large
11134	89529	92	республика Северная Осетия-Алания, Кировский район, село Эльхотово, Школьный переулок, 1	f	large
11136	89531	94	республика Северная Осетия-Алания, Кировский район, село Эльхотово, Чшиева, 68	f	large
11135	89530	93	республика Северная Осетия-Алания, Кировский район, село Эльхотово, Мира, 66	f	large
11142	89538	100	республика Северная Осетия-Алания, Кировский район, село Эльхотово, Ленина, 44	f	large
11137	89532	95	республика Северная Осетия-Алания, Кировский район, село Эльхотово, Ленина, 19	f	large
11139	89535	97	республика Северная Осетия-Алания, Кировский район, село Эльхотово, Зортова, 13	f	large
11138	89534	96	республика Северная Осетия-Алания, Кировский район, село Эльхотово, Бр. Бароевых, 5	f	large
11140	89536	98	республика Северная Осетия-Алания, Кировский район, село Эльхотово, А.Карсанова, 1	f	large
11141	89537	99	республика Северная Осетия-Алания, Кировский район, село Комсомольское, Ленина, 46	f	medium
11146	89542	104	республика Северная Осетия-Алания, Кировский район, село Иран, Плиева, 13Б	f	small
11145	89541	103	республика Северная Осетия-Алания, Кировский район, село Змейская, Таболова, 36А	f	medium
11143	89539	101	республика Северная Осетия-Алания, Кировский район, село Змейская, Ленина, 101	f	large
11144	89540	102	республика Северная Осетия-Алания, Кировский район, село Змейская, Бондаря, 49	f	large
11125	89520	83	республика Северная Осетия-Алания, Ирафский район, село Чикола, Хидирова, 22	f	medium
11115	89510	73	республика Северная Осетия-Алания, Ирафский район, село Чикола, Хасцаева, 125	f	medium
11112	89509	70	республика Северная Осетия-Алания, Ирафский район, село Чикола, Хасцаева, 75	f	small
11110	89507	68	республика Северная Осетия-Алания, Ирафский район, село Чикола, М.Будтуева, 97	f	small
11107	89504	65	республика Северная Осетия-Алания, Ирафский район, село Чикола, М.Будтуева, 35	f	small
11114	89496	72	республика Северная Осетия-Алания, Ирафский район, село Чикола, М.Будтуева, 195	f	medium
11108	89505	66	республика Северная Осетия-Алания, Ирафский район, село Чикола, М.Баликоева, 67	f	medium
11111	89508	69	республика Северная Осетия-Алания, Ирафский район, село Чикола, Ленина, 57	f	medium
11113	89484	71	республика Северная Осетия-Алания, Ирафский район, село Чикола, Дедегкаева, 57	f	small
11109	89506	67	республика Северная Осетия-Алания, Ирафский район, село Чикола, Бр.Албегоновых, 89	f	medium
11106	89503	64	республика Северная Осетия-Алания, Ирафский район, село Чикола, Бр.Албегоновых, 1	f	medium
11122	89517	80	республика Северная Осетия-Алания, Ирафский район, село Хазнидон	f	medium
11123	89518	81	республика Северная Осетия-Алания, Ирафский район, село Толдзгун	f	small
11118	89513	76	Россия, республика Северная Осетия-Алания, Ирафский район, село Сурх-Дигора	f	medium
11117	89512	75	республика Северная Осетия-Алания, Ирафский район, село Сурх-Дигора	f	small
11132	89528	90	республика Северная Осетия-Алания, Ирафский район, село Стур-Дигора	t	small
11121	89516	79	республика Северная Осетия-Алания, Ирафский район, село Средний Урух	f	small
11116	89511	74	республика Северная Осетия-Алания, Ирафский район, село Советский	f	small
11198	89591	156	республика Северная Осетия-Алания, Ирафский район, село Советский, Советская, 68	f	large
11120	89515	78	республика Северная Осетия-Алания, Ирафский район, село Новый Урух	f	small
11129	89525	87	Россия, республика Северная Осетия-Алания, Ирафский район, село Мацута	t	small
11128	89524	86	республика Северная Осетия-Алания, Ирафский район, село Махческ	t	small
11124	89519	82	республика Северная Осетия-Алания, Ирафский район, село Лескен, Тубеева, 70	f	medium
11127	89523	85	Россия, республика Северная Осетия-Алания, Ирафский район, село Камунта	t	small
11131	89527	89	Россия, республика Северная Осетия-Алания, Ирафский район, село Дзинага	t	small
11119	89514	77	республика Северная Осетия-Алания, Ирафский район, село Дзагепбарз	f	small
11130	89526	88	Россия, республика Северная Осетия-Алания, Ирафский район, село Ахсау	t	small
11126	89522	84	республика Северная Осетия-Алания, Ирафский район, село Ахсарисар	f	small
11100	89498	58	республика Северная Осетия-Алания, Дигорский район, село Дур-Дур, Маяковского, 45	f	medium
11095	89492	53	республика Северная Осетия-Алания, Дигорский район, Дигора, Сталина, 20	f	large
11094	89491	52	республика Северная Осетия-Алания, Дигорский район, Дигора, Сталина, 32	f	large
11097	89494	55	республика Северная Осетия-Алания, Дигорский район, Дигора, Плиева, 128	f	medium
11102	89500	60	республика Северная Осетия-Алания, Дигорский район, Дигора, Партизанская, 15	f	large
11098	89495	56	республика Северная Осетия-Алания, Дигорский район, Дигора, Мира, 45	f	medium
11101	89499	59	республика Северная Осетия-Алания, Дигорский район, Дигора, Ленина, 35	f	small
11092	89489	50	республика Северная Осетия-Алания, Дигорский район, Дигора, Кокиева, 7	f	large
11093	89490	51	республика Северная Осетия-Алания, Дигорский район, Дигора, Кесаева, 32	f	large
11104	89502	62	республика Северная Осетия-Алания, Дигорский район, Дигора, Калицова, 79	f	large
11103	89501	61	республика Северная Осетия-Алания, Дигорский район, Дигора, К. Маркса, 25	f	large
11099	89497	57	республика Северная Осетия-Алания, Дигорский район, Дигора, Дзотова, 30	f	medium
11096	89493	54	республика Северная Осетия-Алания, Дигорский район, Дигора, Бр. Тахоховых, 32	f	medium
11341	89721	299	республика Северная Осетия-Алания, Владикавказ городской округ, Чми, Средняя школа	t	medium
11308	89693	266	республика Северная Осетия-Алания, Владикавказ городской округ, поселок городского типа Заводской, Эльхотовская, 40	f	large
11307	89693	265	республика Северная Осетия-Алания, Владикавказ городской округ, поселок городского типа Заводской, Эльхотовская, 40	f	large
11311	89696	269	республика Северная Осетия-Алания, Владикавказ городской округ, поселок городского типа Заводской, Остаева, 5	f	large
11310	89694	268	республика Северная Осетия-Алания, Владикавказ городской округ, поселок городского типа Заводской, Бульварная, 73	f	large
11309	89694	267	республика Северная Осетия-Алания, Владикавказ городской округ, поселок городского типа Заводской, Бульварная, 73	f	large
11342	89722	300	республика Северная Осетия-Алания, Владикавказ городской округ, село Балта, Средняя школа	t	medium
11083	89479	41	Россия, республика Северная Осетия-Алания, Ардонский район, село Бекан	f	small
11091	89488	49	республика Северная Осетия-Алания, Ардонский район, Ардон, Хетагурова, 50	f	small
11078	89474	36	республика Северная Осетия-Алания, Ардонский район, Ардон, Тогузова, 50	f	large
11081	89477	39	республика Северная Осетия-Алания, Ардонский район, Ардон, Советов, 5	f	large
11082	89478	40	республика Северная Осетия-Алания, Ардонский район, Ардон, Пролетарская, 83	f	large
11088	89485	46	республика Северная Осетия-Алания, Ардонский район, Ардон, Мамиева, 51	f	large
11089	89486	47	республика Северная Осетия-Алания, Ардонский район, Ардон, Ленина, 38	f	medium
11086	89482	44	республика Северная Осетия-Алания, Ардонский район, Ардон, Ленина, 24	f	large
11084	89480	42	республика Северная Осетия-Алания, Ардонский район, Ардон, Ленина, 37	f	large
11080	89476	38	республика Северная Осетия-Алания, Ардонский район, Ардон, Кирова, 180	f	large
11079	89475	37	республика Северная Осетия-Алания, Ардонский район, Ардон, Зангиева, 90	f	large
11090	89487	48	республика Северная Осетия-Алания, Ардонский район, Ардон, Бритаева, 27	f	small
11085	89481	43	республика Северная Осетия-Алания, Ардонский район, Ардон, Абациевых, 6	f	large
11075	89471	33	республика Северная Осетия-Алания, Алагирский район, Цейское сельское поселение	t	small
11059	89455	17	республика Северная Осетия-Алания, Алагирский район, село Цаликово, Комсомольская, 24	f	small
11061	89457	19	республика Северная Осетия-Алания, Алагирский район, село Хаталдон, Кцоева, 50	f	medium
11053	89449	11	республика Северная Осетия-Алания, Алагирский район, село Рамоново, ДК	f	medium
11070	89466	28	Россия, республика Северная Осетия-Алания, Алагирский район, поселок Нузал	t	small
11067	89463	25	республика Северная Осетия-Алания, Алагирский район, село Нижний Унал, ДК с.Унал	t	small
11076	89472	34	республика Северная Осетия-Алания, Алагирский район, поселок Нижний Зарамах	t	small
11057	89453	15	Россия, республика Северная Осетия-Алания, Алагирский район, село Нижний Бирагзанг	f	small
11077	89473	35	республика Северная Осетия-Алания, Алагирский район, село Нар	t	small
11069	89465	27	республика Северная Осетия-Алания, Алагирский район, поселок Мизур, ДК 	t	medium
11068	89464	26	республика Северная Осетия-Алания, Алагирский район, поселок Мизур, 1, Нач.школа при д/с п.Мизур	t	medium
11063	89459	21	республика Северная Осетия-Алания, Алагирский район, село Майрамадаг, Дзуцева, 32	f	medium
11335	89716	293	республика Северная Осетия-Алания, Алагирский район, село Карца, Карцинская, 82, Промышленный муниципальный округ	f	large
11337	89717	295	республика Северная Осетия-Алания, Алагирский район, село Карца, Дружбы, 66	f	large
11336	89717	294	республика Северная Осетия-Алания, Алагирский район, село Карца, Дружбы, 66	f	large
11066	89462	24	республика Северная Осетия-Алания, Алагирский район, село Зинцар, ДК с.Зинцар	t	small
11062	89458	20	республика Северная Осетия-Алания, Алагирский район, поселок Дзуарикау, Бр.Газдановых, 15	f	medium
11065	89461	23	республика Северная Осетия-Алания, Алагирский район, поселок Верхний Фиагдон, ДК п.В.Фиагдон	t	large
11074	89470	32	республика Северная Осетия-Алания, Алагирский район, поселок Бурон, ДК п.Бурон	t	medium
11073	89469	31	республика Северная Осетия-Алания, Алагирский район, Алагир, Административное здание	t	small
11071	89467	29	республика Северная Осетия-Алания, Алагирский район, Алагир, Рудоуправление	t	small
11064	89460	22	республика Северная Осетия-Алания, Алагирский район, Алагир	t	small
11058	89454	16	республика Северная Осетия-Алания, Алагирский район, Алагир, Цаликова, 73	f	medium
11046	89444	4	республика Северная Осетия-Алания, Алагирский район, Алагир, Сталина, 74	f	large
11060	89456	18	республика Северная Осетия-Алания, Алагирский район, Ленина, 23	f	medium
11054	89450	12	республика Северная Осетия-Алания, Алагирский район, Алагир, Ленина, 63	f	large
11047	89445	5	республика Северная Осетия-Алания, Алагирский район, Алагир, ЛЕНИНА, 109	f	large
11044	89442	2	республика Северная Осетия-Алания, Алагирский район, Алагир, Л.Толстого, 69	f	large
11048	89446	6	республика Северная Осетия-Алания, Алагирский район, Алагир, Комсомольская, 78	f	large
11056	89452	14	республика Северная Осетия-Алания, Алагирский район, Алагир, Кирова, 80	f	medium
11050	89448	8	республика Северная Осетия-Алания, Алагирский район, Алагир, Калаева, 2	f	large
11049	89447	7	республика Северная Осетия-Алания, Алагирский район, Алагир, Калаева, 7	f	large
11045	89443	3	республика Северная Осетия-Алания, Алагирский район, Алагир, К.Хетагурова, 138	f	large
11043	89441	1	республика Северная Осетия-Алания, Алагирский район, Алагир, К.Хетагурова, 231	f	large
11055	89451	13	республика Северная Осетия-Алания, Алагирский район, Алагир, Алагирская, 4	f	small
7491	38927	45	республика Карачаево-Черкесская, Черкесск, Космонавтов, 3	f	large
7495	38931	49	республика Карачаево-Черкесская, Черкесск, СОШ №12	f	large
7492	38928	46	Россия, республика Карачаево-Черкесская, Черкесск	f	large
7487	38923	41	республика Карачаево-Черкесская, Черкесск, Фабричная, 139	f	large
7478	38914	32	республика Карачаево-Черкесская, Черкесск, Тургеневская, 75	f	large
134629	94956	1	республика Карачаево-Черкесская, Черкесск, Тихая, 29	f	large
7483	38919	37	республика Карачаево-Черкесская, Черкесск, Строителей, 3	f	large
7481	38917	35	республика Карачаево-Черкесская, Черкесск, Ставропольская, 117	f	large
7480	38916	34	республика Карачаево-Черкесская, Черкесск, Ставропольская, 107	f	large
7477	38913	31	республика Карачаево-Черкесская, Черкесск, Ставропольская, 41	f	large
134630	94957	11	республика Карачаево-Черкесская, Черкесск, Советская, 27	f	large
7470	38906	24	республика Карачаево-Черкесская, Черкесск, Подгорная, 124	f	large
7468	38904	22	республика Карачаево-Черкесская, Черкесск, Подгорная, 7	f	large
7471	38907	25	республика Карачаево-Черкесская, Черкесск городской округ, Первомайская, 26	f	large
7467	38903	21	республика Карачаево-Черкесская, Черкесск, Первомайская, 99	f	large
7493	38929	47	республика Карачаево-Черкесская, Черкесск, Парковая, 15	f	large
7490	38926	44	республика Карачаево-Черкесская, Черкесск, Парковая, 1а	f	large
7469	38905	23	республика Карачаево-Черкесская, Черкесск, Октябрьская, 186	f	large
7454	38890	8	республика Карачаево-Черкесская, Черкесск, Октябрьская, 56	f	large
7452	38888	6	республика Карачаево-Черкесская, Черкесск, Октябрьская, 3	f	large
7455	38891	9	республика Карачаево-Черкесская, Черкесск, Международная, 8	f	large
7476	38912	30	республика Карачаево-Черкесская, Черкесск, Леонова, 1	f	large
7496	38932	50	республика Карачаево-Черкесская, Черкесск, Ленина, 387	f	large
7479	38915	33	республика Карачаево-Черкесская, Черкесск, Ленина, 149	f	large
7474	38910	28	республика Карачаево-Черкесская, Черкесск, Ленина, 71	f	large
7472	38908	26	республика Карачаево-Черкесская, Черкесск, Ленина, 66	f	large
7460	38896	14	республика Карачаево-Черкесская, Черкесск, Ленина, 8	f	large
7453	38889	7	республика Карачаево-Черкесская, Черкесск, Крупской, 84	f	large
7450	38886	4	республика Карачаево-Черкесская, Черкесск, Крупской, 29	f	large
7473	38909	27	республика Карачаево-Черкесская, Черкесск, Красноармейская, 66	f	large
7464	38900	18	республика Карачаево-Черкесская, Черкесск, Красноармейская, 49	f	large
7462	38898	16	республика Карачаево-Черкесская, Черкесск, Красноармейская, 50	f	medium
7485	38921	39	республика Карачаево-Черкесская, Черкесск, Кочубея, 172	f	large
7484	38920	38	республика Карачаево-Черкесская, Черкесск, Кочубея, 28	f	large
7498	38934	52	республика Карачаево-Черкесская, Черкесск, Космонавтов, 30	f	large
7494	38930	48	республика Карачаево-Черкесская, Черкесск, Космонавтов, 31, СОШ №17	f	large
134631	94958	20	республика Карачаево-Черкесская, Черкесск, Кирова, 19	f	large
7451	38887	5	республика Карачаево-Черкесская, Черкесск, Карла Маркса, 160а	f	large
7465	38901	19	республика Карачаево-Черкесская, Черкесск, Кавказская, 58	f	large
7459	38895	13	республика Карачаево-Черкесская, Черкесск, Кавказская, 126	f	large
7497	38933	51	республика Карачаево-Черкесская, Черкесск, Доватора, 84	f	large
7489	38925	43	республика Карачаево-Черкесская, Черкесск, Доватора, 64	f	large
7488	38924	42	республика Карачаево-Черкесская, Черкесск, Доватора, 19	f	medium
7449	38885	3	республика Карачаево-Черкесская, Черкесск, Демиденко, 157	f	large
7448	38884	2	республика Карачаево-Черкесская, Черкесск, Гутякулова, 2	f	large
7463	38899	17	республика Карачаево-Черкесская, Черкесск, Горького, 5	f	large
7461	38897	15	республика Карачаево-Черкесская, Черкесск, Горького, 1	f	large
7475	38911	29	республика Карачаево-Черкесская, Черкесск, Ворошилова, 1	f	large
7458	38894	12	республика Карачаево-Черкесская, Черкесск, Балахонова, 73	f	large
7456	38892	10	республика Карачаево-Черкесская, Черкесск, Кавказская, 17	f	medium
7680	39118	234	республика Карачаево-Черкесская, село Хабез, Хабекова, 95	f	large
7657	39093	211	республика Карачаево-Черкесская, Усть-Джегута, м-н Московский, Гимназия №6	f	large
7656	39092	210	республика Карачаево-Черкесская, Усть-Джегута, м-н Московский, МДШИ	f	large
7655	39091	209	республика Карачаево-Черкесская, Усть-Джегута, м-н Московский, ДК	f	large
7654	39090	208	республика Карачаево-Черкесская, Усть-Джегута, м-н Московский, Гимназия №4	f	large
7665	39101	219	республика Карачаево-Черкесская, Усть-Джегута, Школьная, филиал МОУ СОШ №2	f	large
7664	39100	218	республика Карачаево-Черкесская, Усть-Джегута, Первомайская, МОУ СОШ №2	f	large
7663	39099	217	республика Карачаево-Черкесская, Усть-Джегута, Морозова, ЦКиД	f	large
7666	39102	220	республика Карачаево-Черкесская, Усть-Джегута, Курортная, 58	f	large
7660	39096	214	республика Карачаево-Черкесская, Усть-Джегута, Курортная, ОООТриз	f	large
7659	39095	213	республика Карачаево-Черкесская, Усть-Джегута, Коммунистическая, МОУ СОШ №3	f	large
7661	39097	215	республика Карачаево-Черкесская, Усть-Джегута, Богатырева, МКОУ Лицей №1 г.Усть-Джегуты	f	large
7658	39094	212	республика Карачаево-Черкесская, Усть-Джегута, Балахонова, МОУ СОШ №5	f	large
7513	38950	67	республика Карачаево-Черкесская, Теберда, Тебердинская, 4	f	large
7515	38952	69	республика Карачаево-Черкесская, Теберда, Орджоникидзе, 24	f	medium
7502	38938	56	республика Карачаево-Черкесская, Карачаевск, Эркенова, 5	f	large
7514	38951	68	республика Карачаево-Черкесская, Карачаевск, Советская, 2	f	medium
7510	38947	64	республика Карачаево-Черкесская, Карачаевск, Советская, 56	f	medium
7508	38945	62	республика Карачаево-Черкесская, Карачаевск, Речной, 1	f	medium
7507	38944	61	республика Карачаево-Черкесская, Карачаевск, Пушкина, 52	f	medium
7516	38953	70	республика Карачаево-Черкесская, Карачаевск, Пихтовый Мыс, 2	f	small
7501	38937	55	республика Карачаево-Черкесская, Карачаевск, Мира, 13	f	large
7500	38936	54	республика Карачаево-Черкесская, Карачаевск, Мира, 31	f	large
7504	38940	58	республика Карачаево-Черкесская, Карачаевск, Магометова, 8	f	medium
7583	39020	137	республика Карачаево-Черкесская, Карачаевск, Ленина, 3а	f	large
7506	38943	60	республика Карачаево-Черкесская, Карачаевск, Ленина, 45 А	f	large
7505	38942	59	республика Карачаево-Черкесская, Карачаевск, Ленина, 29	f	small
7503	38939	57	республика Карачаево-Черкесская, Карачаевск, Ленина, 27	f	large
7589	39026	143	республика Карачаево-Черкесская, Карачаевск, Курортная, 75	f	large
7579	39016	133	республика Карачаево-Черкесская, Карачаевск, Курджиева, 38	f	large
7584	39021	138	республика Карачаево-Черкесская, Карачаевск, Колиева, 14а	f	large
7509	38946	63	республика Карачаево-Черкесская, Карачаевск, Калинина, 2	f	large
7586	39023	140	республика Карачаево-Черкесская, Карачаевск, Гагарина, 132а	f	large
7518	38955	72	республика Карачаево-Черкесская, Хабезский район, село Эльбурган, Ленина, 30	f	large
7681	39119	235	республика Карачаево-Черкесская, Хабезский район, Хабез, Советская, 42	f	large
7689	39126	243	республика Карачаево-Черкесская, Хабезский район, село Псаучье-Дахе, Школьная , 1	f	large
7687	39124	241	республика Карачаево-Черкесская, Хабезский район, село Новохумаринский, Хапсирокова, 34	f	small
7685	39122	239	республика Карачаево-Черкесская, Хабезский район, село Малый Зеленчук, Калмыкова, 10	f	large
7690	39127	244	республика Карачаево-Черкесская, Хабезский район, село Кызыл-Юрт, Булатукова, 4	f	small
7684	39121	238	республика Карачаево-Черкесская, Хабезский район, село Кош-Хабль, хАБЕКОВА, 14	f	large
7692	39129	246	республика Карачаево-Черкесская, Хабезский район, село Инжич-Чукун, С.Дерева, 47	f	medium
7517	38954	71	республика Карачаево-Черкесская, Хабезский район, село Инжич-Чукун, Ленина, 50	f	large
7683	39120	237	республика Карачаево-Черкесская, Хабезский район, село Зеюко, Атажукина, 82	f	large
7682	39120	236	республика Карачаево-Черкесская, Хабезский район, село Зеюко, Атажукина, 82	f	medium
7677	39114	231	республика Карачаево-Черкесская, Хабезский район, село Жако, Акова, 8	f	large
7691	39128	245	республика Карачаево-Черкесская, Хабезский район, село Бесленей, Гутякулова, 44	f	large
7686	39123	240	республика Карачаево-Черкесская, Хабезский район, село Бавуко, Набережная, 10	f	small
7679	39117	233	республика Карачаево-Черкесская, Хабезский район, село Али-Бердуковский, Ленина, 40	f	large
7678	39115	232	республика Карачаево-Черкесская, Хабезский район, село Али-Бердуковский, Кушхова, 12	f	large
7688	39125	242	республика Карачаево-Черкесская, Хабезский район, село Абазакт, Центральная, 32	f	small
7672	39109	226	республика Карачаево-Черкесская, Усть-Джегутинский район, аул Джегута, МОУ СОШ а.Джегута	f	large
7675	39112	229	республика Карачаево-Черкесская, Усть-Джегутинский район, село Эльтаркач, МОУ СОШ а.Эльтаркач	f	large
7662	39098	216	республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута, Морозова, МОУ Лицей №7	f	large
5308	31926	501	республика Дагестан, Дербент, Советская, 6	f	large
7667	39103	221	республика Карачаево-Черкесская, Усть-Джегутинский район, Усть-Джегута, Краснопартизанская, ДК цемпоселка	f	medium
7673	39110	227	республика Карачаево-Черкесская, Усть-Джегутинский район, село Новая Джегута, МОУ СОШ а.Новая Джегута	f	large
7671	39108	225	республика Карачаево-Черкесская, Усть-Джегутинский район, село Кызыл-Кала, МОУ СОШ а.Кызыл-Кала	t	large
7523	38960	77	республика Карачаево-Черкесская, Усть-Джегутинский район, село Кубина, Джегутанова, 36	f	large
7669	39105	223	республика Карачаево-Черкесская, Усть-Джегутинский район, село Красногорская, МОУ СОШ	f	large
7676	39113	230	республика Карачаево-Черкесская, Усть-Джегутинский район, село Койдан, МОУ СОШ	f	medium
7668	39104	222	республика Карачаево-Черкесская, Усть-Джегутинский район, село Гюрюльдеук, ДК	f	large
7674	39111	228	республика Карачаево-Черкесская, Усть-Джегутинский район, Гюрюльдеук, МОУ СОШ	f	large
7670	39107	224	республика Карачаево-Черкесская, Усть-Джегутинский район, село Важное, МОУ СОШ	f	large
7639	39076	193	республика Карачаево-Черкесская, Урупский район, поселок Уруп, Красная, 30	t	medium
7647	39083	201	республика Карачаево-Черкесская, Урупский район, поселок Пхия, Центральная, 8	t	small
7649	39085	203	республика Карачаево-Черкесская, Урупский район, село Псемен, Ставропольская, 3	f	small
7653	39089	207	республика Карачаево-Черкесская, Урупский район, село Предгорное, Садовая, 40	f	small
7644	39080	198	республика Карачаево-Черкесская, Урупский район, село Преградная, Прогонная, 15	f	small
7645	39081	199	республика Карачаево-Черкесская, Урупский район, село Преградная, Подгорная, 22	f	large
7643	39079	197	республика Карачаево-Черкесская, Урупский район, село Преградная, Пионерская, 19	f	large
7642	39078	196	республика Карачаево-Черкесская, Урупский район, село Преградная, Красная, 111	f	large
7641	38979	195	республика Карачаево-Черкесская, Урупский район, поселок Медногорский, Спортивная, 1	f	large
7640	39077	194	республика Карачаево-Черкесская, Урупский район, поселок Медногорский, Бардина, 5-Б	f	large
7646	39082	200	республика Карачаево-Черкесская, Урупский район, село Кызыл-Уруп, Пионерская, 4	f	medium
7650	39086	204	республика Карачаево-Черкесская, Урупский район, поселок городского типа Курджиново, Н. Василенко, 58	f	large
7652	39088	206	республика Карачаево-Черкесская, Урупский район, поселок Курджиново, Школьная, 35	f	small
7651	39087	205	республика Карачаево-Черкесская, Урупский район, поселок Курджиново, Крайняя, 1	f	medium
7648	39084	202	республика Карачаево-Черкесская, Урупский район, поселок Курджиново, Гагарина, 62	f	small
7638	39075	192	республика Карачаево-Черкесская, Прикубанский район, село Чапаевское, Центральная, 130	f	large
7637	39074	191	республика Карачаево-Черкесская, Прикубанский район, село Чапаевское, Центральная, 111	f	large
7627	39064	181	республика Карачаево-Черкесская, Прикубанский район, село Холоднородниковское, Садовая, 6	f	medium
7622	39059	176	республика Карачаево-Черкесская, Прикубанский район, поселок Ударный, Мира, 2	f	medium
7626	39063	180	республика Карачаево-Черкесская, Прикубанский район, село Таллык, Шоссейная, 25в	f	medium
7628	39065	182	республика Карачаево-Черкесская, Прикубанский район, село Счастливое, Школьная, 1	f	large
7624	39061	178	республика Карачаево-Черкесская, Прикубанский район, село Солнечный, Луговая, 3	f	small
7629	39066	183	республика Карачаево-Черкесская, Прикубанский район, село Светлое, Байчорова, 23	f	medium
7621	39058	175	республика Карачаево-Черкесская, Прикубанский район, село Родниковский, Лесная, 7а	f	small
134635	94962	75	республика Карачаево-Черкесская, Прикубанский район, село Псыж, Кунижева, 173	f	large
134634	94961	74	республика Карачаево-Черкесская, Прикубанский район, село Псыж, Кунижева, 51	f	large
7631	39068	185	республика Карачаево-Черкесская, Прикубанский район, село Пристань, Джегутинская, 1	t	medium
7633	39070	187	республика Карачаево-Черкесская, Прикубанский район, село Пригородное, Центральная, 32	f	medium
7630	39067	184	республика Карачаево-Черкесская, Прикубанский район, село Привольный, Космонавтов, 21	t	medium
7623	39060	177	республика Карачаево-Черкесская, Прикубанский район, село Октябрьский, Интернациональная, 1в	f	large
7625	39062	179	республика Карачаево-Черкесская, Прикубанский район, село Новый, Дружбы, 1а	f	small
7632	39069	186	республика Карачаево-Черкесская, Прикубанский район, село Николаевское, Школьная, 17	f	large
7618	39055	172	республика Карачаево-Черкесская, Прикубанский район, село Мичуринский, Центральная, 45	f	medium
7620	39057	174	республика Карачаево-Черкесская, Прикубанский район, село Майский, Шоссейная, 1	f	medium
134633	94960	73	республика Карачаево-Черкесская, Прикубанский район, село Кара-Паго, Колмсомольская, 13	t	small
7617	39054	171	республика Карачаево-Черкесская, Прикубанский район, село Кавказский, Татаркулова, 3	f	large
7634	39071	188	республика Карачаево-Черкесская, Прикубанский район, село Ильичевское, Школьная, 2	f	medium
7635	39072	189	республика Карачаево-Черкесская, Прикубанский район, село Знаменка, Мира, 110	t	large
7636	39073	190	республика Карачаево-Черкесская, Прикубанский район, село Дружба, 50 лет Октября, 155	f	large
7619	39056	173	республика Карачаево-Черкесская, Прикубанский район, село Водораздельный, Советская, 4	t	small
7610	39047	164	республика Карачаево-Черкесская, Ногайский район, поселок городского типа Эркен-Шахар, Некрасова, 2	f	large
7593	39030	147	республика Карачаево-Черкесская, Малокарачаевский район, село Элькуш, Центральная, 35	t	small
7600	39037	154	республика Карачаево-Черкесская, Малокарачаевский район, село Учкекен, Школьная, 7	f	large
7599	39036	153	республика Карачаево-Черкесская, Малокарачаевский район, село Учкекен, Хабова, 23	f	large
7598	39035	152	республика Карачаево-Черкесская, Малокарачаевский район, село Учкекен, Ленина, 128	f	large
7597	39034	151	республика Карачаево-Черкесская, Малокарачаевский район, село Учкекен, Ленина, 114	f	large
7601	39038	155	республика Карачаево-Черкесская, Малокарачаевский район, село Учкекен, Ижаева, 1	f	large
7605	39042	159	республика Карачаево-Черкесская, Малокарачаевский район, село Терезе, Ленина, 109	f	large
7604	39041	158	республика Карачаево-Черкесская, Малокарачаевский район, село Терезе, Ленина, 13	f	large
7596	39033	150	республика Карачаево-Черкесская, Малокарачаевский район, село Рим-Горский, Школьная, 42	f	large
7603	39040	157	республика Карачаево-Черкесская, Малокарачаевский район, село Первомайское, Шоссейная, 73	f	large
7602	39039	156	республика Карачаево-Черкесская, Малокарачаевский район, село Первомайское, Совхозная, 4	f	large
7606	39043	160	республика Карачаево-Черкесская, Малокарачаевский район, село Кызыл-Покун, Советская, 33б	f	medium
134648	94975	148	республика Карачаево-Черкесская, Малокарачаевский район, село Красный Курган, Боташева, 1	f	large
7607	39044	161	республика Карачаево-Черкесская, Малокарачаевский район, село Красновосточный, Школьная, 17	f	large
7608	39045	162	республика Карачаево-Черкесская, Малокарачаевский район, село Красновосточный, Макова, 15	f	large
134647	94974	146	республика Карачаево-Черкесская, Малокарачаевский район, село Кичи-Балык, Центральная, 2	t	small
7595	39032	149	республика Карачаево-Черкесская, Малокарачаевский район, село Джага, Школьная, 47	f	large
7499	38935	53	республика Карачаево-Черкесская, Карачаевский район, поселок Эльбрусский, Горняцкая, 25	t	small
7576	39013	130	республика Карачаево-Черкесская, Карачаевский район, Хурзук, Дж.Байрамукова, 58	t	medium
7577	39014	131	республика Карачаево-Черкесская, Карачаевский район, село Учкулан, Учкуланская, 25	t	medium
7512	38949	66	Россия, республика Карачаево-Черкесская, Карачаевский район, Теберда	f	large
7591	39028	145	республика Карачаево-Черкесская, Карачаевский район, поселок городского типа Правокубанский	f	large
7587	39024	141	республика Карачаево-Черкесская, Карачаевский район, Новый Карачай, Тоторкулова, 52	f	large
7581	39018	135	республика Карачаево-Черкесская, Карачаевский район, село Новая Теберда, Шоссейная, 19а	t	medium
7582	39019	136	республика Карачаево-Черкесская, Карачаевский район, село Новая Теберда, Центральная, 27	f	medium
7585	39022	139	республика Карачаево-Черкесская, Карачаевский район, село Нижняя Мара, Хапаева, 8	f	medium
7590	39027	144	республика Карачаево-Черкесская, Карачаевский район, село Кумышское, Комсомольская, 18а	f	large
7588	39025	142	республика Карачаево-Черкесская, Карачаевский район, село Кубрань, Садовая	f	small
7578	39015	132	республика Карачаево-Черкесская, Карачаевский район, село Карт-Джурт, Алиева, 30	t	small
7580	39017	134	республика Карачаево-Черкесская, Карачаевский район, село Джингирик, Центральная, 27	f	medium
134632	94959	65	Россия, республика Карачаево-Черкесская, Карачаевск городской округ, поселок Орджоникидзевский	f	large
7566	39002	120	республика Карачаево-Черкесская, Зеленчукский район, село Хусы-Кардоник, Октябрьская, 11	f	small
7573	39010	127	республика Карачаево-Черкесская, Зеленчукский район, село Хасаут-Греческое, Надежды Кецеровой, 65б	t	small
7560	38996	114	республика Карачаево-Черкесская, Зеленчукский район, село Фроловский, Шоссейная, 19	t	small
7575	39012	129	республика Карачаево-Черкесская, Зеленчукский район, станица Сторожевая 2, Горная, 4	f	medium
7553	38989	107	республика Карачаево-Черкесская, Зеленчукский район, село Сторожевая, Ленина, 102	f	large
7551	38987	105	республика Карачаево-Черкесская, Зеленчукский район, село Сторожевая, Ленина, 46	f	medium
7550	38986	104	республика Карачаево-Черкесская, Зеленчукский район, село Сторожевая, Карачаевская, 27	f	large
7552	38988	106	республика Карачаево-Черкесская, Зеленчукский район, село Сторожевая, Заводская, 1	f	large
7564	39000	118	республика Карачаево-Черкесская, Зеленчукский район, хутор Ново-Исправненский, Октябрьская, 56	t	small
7567	39003	121	республика Карачаево-Черкесская, Зеленчукский район, село Нижняя Ермоловка, Асфальтная, 57	f	small
7569	39005	123	республика Карачаево-Черкесская, Зеленчукский район, село Нижний Архыз, САО РАН, холл лабораторного корпуса	f	small
7572	39008	126	республика Карачаево-Черкесская, Зеленчукский район, село Маруха, Белана, 192	f	large
7548	38984	102	республика Карачаево-Черкесская, Зеленчукский район, село Лесо-Кефарь, Школьная, сельский клуб	t	small
7571	39007	125	республика Карачаево-Черкесская, Зеленчукский район, село Кызыл-Октябрьский, Школьная, 7	f	large
7570	39006	124	республика Карачаево-Черкесская, Зеленчукский район, село Кызыл-Октябрьский, Алиева, 21	f	large
7554	38990	108	республика Карачаево-Черкесская, Зеленчукский район, село Кобу-Баши, Школьная, 13	t	small
7558	38994	112	республика Карачаево-Черкесская, Зеленчукский район, село Кардоникская, Советская, 190	f	large
7556	38992	110	республика Карачаево-Черкесская, Зеленчукский район, село Кардоникская, Октябрьская, 38	f	large
7559	38995	113	республика Карачаево-Черкесская, Зеленчукский район, село Кардоникская, Ленина, 76	f	large
7557	38993	111	республика Карачаево-Черкесская, Зеленчукский район, село Кардоникская, Красная, 49	f	large
7555	38991	109	республика Карачаево-Черкесская, Зеленчукский район, село Кардоникская, Заводская, 31	f	large
7563	38999	117	республика Карачаево-Черкесская, Зеленчукский район, село Исправная, Красная, 129	f	medium
7562	38998	116	республика Карачаево-Черкесская, Зеленчукский район, село Исправная, Кооперативная, 20	f	large
7561	38997	115	республика Карачаево-Черкесская, Зеленчукский район, село Исправная, Казачья, 86	f	medium
7549	38985	103	республика Карачаево-Черкесская, Зеленчукский район, село Ильич, Красноармейская, 14	t	small
7547	38983	101	Россия, республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская	f	large
7546	38982	100	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Советская, 110	f	large
7542	38977	96	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Набережная, 3	f	large
7544	38980	98	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Ленина, 100	f	large
7541	38976	95	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Ленина, 74	f	large
7540	38975	94	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Ленина, 47	f	large
7545	38981	99	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Красноармейская, 65	f	medium
7538	38973	92	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Карбышева, контора ХРУ № 6200 кабинет	f	small
134646	94973	97	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Калинина, 190а	f	large
7539	38974	93	республика Карачаево-Черкесская, Зеленчукский район, село Зеленчукская, Заводская, 58-А	f	large
7565	39001	119	республика Карачаево-Черкесская, Зеленчукский район, село Даусуз, Юрия Хатуевва, 104	f	large
7568	39004	122	республика Карачаево-Черкесская, Зеленчукский район, поселок Архыз, Мостовая, 3	t	small
7535	94946	89	республика Карачаево-Черкесская, Адыге-Хабльский район, село Эрсакон, улица Ленина, 70	f	large
134650	94977	168	республика Карачаево-Черкесская, Адыге-Хабльский район, село Эркен-Юрт, Ленина, 80	t	large
7609	39046	163	республика Карачаево-Черкесская, Адыге-Хабльский район, поселок городского типа Эркен-Шахар, К.Мижевой, 15	f	large
7616	39053	170	республика Карачаево-Черкесская, Адыге-Хабльский район, село Эркен-Халк, Ахлова, 66	f	medium
134642	94969	85	республика Карачаево-Черкесская, Адыге-Хабльский район, село Тапанта, Ворошилова, 23	t	small
7533	94948	87	республика Карачаево-Черкесская, Адыге-Хабльский район, село Старокувинский, Октябрьская улица, 51	f	medium
134638	94965	81	республика Карачаево-Черкесская, Адыге-Хабльский район, село Спарта, Кирова, 38а	t	small
134637	94964	79	республика Карачаево-Черкесская, Адыге-Хабльский район, село Садовое, Полевая, 14	t	large
134644	94971	90	республика Карачаево-Черкесская, Адыге-Хабльский район, село Новокувинский, Широкая, 17	t	small
7613	39050	167	республика Карачаево-Черкесская, Адыге-Хабльский район, село Кызыл-Тогай, Победы, 10	t	small
134645	94972	91	республика Карачаево-Черкесская, Адыге-Хабльский район, село Киево-Жураковский, Школьная, 7	t	small
134649	94976	166	республика Карачаево-Черкесская, Адыге-Хабльский район, село Икон-Халк, Ленина, 108	f	large
7615	94950	169	республика Карачаево-Черкесская, Адыге-Хабльский район, село Евсеевский, Гагарина, 22б	f	small
134640	94967	83	республика Карачаево-Черкесская, Адыге-Хабльский район, село Дубянский, Школьная, 1	t	small
134641	94968	84	республика Карачаево-Черкесская, Адыге-Хабльский район, село Грушка, Гагарина, 44	t	small
7534	94949	88	республика Карачаево-Черкесская, Адыге-Хабльский район, село Вако-Жиле, Первомайская, 43	f	medium
134639	94966	82	республика Карачаево-Черкесская, Адыге-Хабльский район, село Баралки, Октябрьская, 37	t	small
7526	94947	80	республика Карачаево-Черкесская, Адыге-Хабльский район, село Апсуа, Школьная, 13	f	medium
7524	38961	78	республика Карачаево-Черкесская, Адыге-Хабльский район, село Адыге-Хабль, Советская, 15	f	large
7611	39048	165	республика Карачаево-Черкесская, Адыге-Хабльский район, село Адиль-Халк, Джелябиева, 76	f	large
134643	94970	86	республика Карачаево-Черкесская, Адыге-Хабльский район, село Абаза-Хабль, Первомайская, 36	t	small
134636	94963	76	республика Карачаево-Черкесская, Абазинский район, Псыж, Кунижева, 259	f	large
6930	37047	93	республика Кабардино-Балкарская, ст. Александровская, Октябрьская, 36	f	large
6939	37056	102	республика Кабардино-Балкарская, село Хасанья, Дружбы	f	large
7181	37300	344	республика Кабардино-Балкарская, Тырныауз, Эльбрусский, 24	f	large
7188	37306	351	республика Кабардино-Балкарская, Тырныауз, Баксанская, 15	f	large
7094	37213	257	республика Кабардино-Балкарская, Терек, Теунова, 2	f	large
7095	37214	258	республика Кабардино-Балкарская, Терек, Терская, 98	f	large
7092	37211	255	республика Кабардино-Балкарская, Терек, Ленина, 49	f	large
7090	37209	253	республика Кабардино-Балкарская, Прохладный, разъезд Шарданово, Клуб путевой машинной станции №143	f	small
7072	37191	235	республика Кабардино-Балкарская, Прохладный, Строительная, 272 а	f	large
7071	37190	234	республика Кабардино-Балкарская, Прохладный, Остапенко, 14	f	large
7081	37200	244	республика Кабардино-Балкарская, Прохладный, Ленина, 21	f	large
7086	37205	249	республика Кабардино-Балкарская, Прохладный, Кавказская, 2 Б	f	large
7089	37208	252	республика Кабардино-Балкарская, Прохладный, Дзержинского, 35	f	large
7082	37201	245	республика Кабардино-Балкарская, Прохладный, Головко, 70	f	large
7074	37193	237	республика Кабардино-Балкарская, Прохладный, Агрономический переулок, 11	f	large
7013	37132	176	республика Кабардино-Балкарская, Нальчик, им. братьев Кушховых, 79А	f	medium
6990	37108	153	республика Кабардино-Балкарская, Нальчик, Эльбрусская, 4	f	large
7012	37131	175	республика Кабардино-Балкарская, Нальчик, Щорса, 6	f	medium
6956	37074	119	республика Кабардино-Балкарская, Нальчик, Шортанова, 14	f	large
7000	37118	163	республика Кабардино-Балкарская, Нальчик, Шогенцукова, 28	f	large
6999	37117	162	республика Кабардино-Балкарская, Нальчик, Шогенцукова, 14	f	large
6967	37085	130	республика Кабардино-Балкарская, Нальчик, Шогенцукова, 7	f	large
6940	37057	103	республика Кабардино-Балкарская, Нальчик, Шогенцукова, 5А	f	large
6983	37102	146	республика Кабардино-Балкарская, Нальчик, Шогенова, 26	f	large
7026	37145	189	республика Кабардино-Балкарская, Нальчик, Чеченская, 17	f	large
6985	37104	148	республика Кабардино-Балкарская, Нальчик, Чернышевского, 165	f	medium
6984	37103	147	республика Кабардино-Балкарская, Нальчик, Чернышевского, 173	f	large
6962	37080	125	республика Кабардино-Балкарская, Нальчик, Чайковского, 26	f	large
6938	37055	101	республика Кабардино-Балкарская, Нальчик, Ульбашева, 11	f	large
7005	37123	168	республика Кабардино-Балкарская, Нальчик, Тырныаузская, 1, МОУ СОШ № 24	f	large
6979	37097	142	республика Кабардино-Балкарская, Нальчик, Туриста, 7Б	f	large
6977	37095	140	республика Кабардино-Балкарская, Нальчик, Туриста, 54	f	large
6973	37091	136	республика Кабардино-Балкарская, Нальчик, Тимошенко, 60	f	medium
7028	37147	191	республика Кабардино-Балкарская, Нальчик, Тимирязева, 7	f	large
7004	37122	167	республика Кабардино-Балкарская, Нальчик, Тепличный, 17	f	large
6949	37066	112	республика Кабардино-Балкарская, Нальчик, Тарчокова, 52Б	f	large
6948	37065	111	республика Кабардино-Балкарская, Нальчик, Тарчокова, 52	f	large
6941	37058	104	республика Кабардино-Балкарская, Нальчик, Тарчокова, 32	f	large
6968	37086	131	республика Кабардино-Балкарская, Нальчик, Революционная, 8	f	large
6997	37115	160	республика Кабардино-Балкарская, Нальчик, Пушкина, 85	f	large
6980	37099	143	республика Кабардино-Балкарская, Нальчик, Профсоюзная, 185	f	large
6978	37096	141	республика Кабардино-Балкарская, Нальчик, Профсоюзная, 122	f	large
6989	37107	152	республика Кабардино-Балкарская, Нальчик, Пачева, 55	f	large
7003	37121	166	республика Кабардино-Балкарская, Нальчик, Огоньянца, 25	f	large
7025	37144	188	республика Кабардино-Балкарская, Нальчик, Неделина, 8а	f	large
7022	37141	185	республика Кабардино-Балкарская, Нальчик, Неделина, 20	f	large
7023	37142	186	республика Кабардино-Балкарская, Нальчик, Мусукаева, 26 А	f	large
6986	37059	149	республика Кабардино-Балкарская, Нальчик, Московская, 6А	f	large
6942	37059	105	республика Кабардино-Балкарская, Нальчик, Московская, 6А	f	large
6988	37106	151	республика Кабардино-Балкарская, Нальчик, Мечникова, 130А	f	large
6959	37077	122	республика Кабардино-Балкарская, Нальчик, Матросова, 5	f	large
7002	37120	165	республика Кабардино-Балкарская, Нальчик, Мальбахова, 17 А	f	large
6993	37111	156	республика Кабардино-Балкарская, Нальчик, Мальбахова, 117	f	medium
6996	37114	159	республика Кабардино-Балкарская, Нальчик, Ленина, 69	f	large
6995	37113	158	республика Кабардино-Балкарская, Нальчик, Ленина, 53	f	medium
6957	37075	120	республика Кабардино-Балкарская, Нальчик, Кулиева, 12	f	large
6955	37073	118	республика Кабардино-Балкарская, Нальчик, Кулиева, 28А	f	large
6944	37061	107	республика Кабардино-Балкарская, Нальчик, Кулиева, 5	f	medium
6943	37060	106	республика Кабардино-Балкарская, Нальчик, Кулиева, 9	f	large
6998	37116	161	республика Кабардино-Балкарская, Нальчик, Коммунаров, 20	f	large
6992	37110	155	республика Кабардино-Балкарская, Нальчик, Комарова, 51	f	large
7035	37155	198	республика Кабардино-Балкарская, Нальчик, Коллонтай, 6	f	large
7009	37128	172	республика Кабардино-Балкарская, Нальчик, Кирова, 341	f	large
6954	37072	117	республика Кабардино-Балкарская, Нальчик, Кирова, 8	f	large
6945	37062	108	республика Кабардино-Балкарская, Нальчик, Катханова, 91	f	large
6958	37076	121	республика Кабардино-Балкарская, Нальчик, Карашаева, 17	f	large
7030	37149	193	республика Кабардино-Балкарская, Нальчик, Канкошева, 97	f	large
6947	37064	110	республика Кабардино-Балкарская, Нальчик, Каменская, 4	f	large
6991	37109	154	республика Кабардино-Балкарская, Нальчик, Калюжного, 15	f	large
6976	37094	139	республика Кабардино-Балкарская, Нальчик, Калмыкова, 246	f	large
7034	37154	197	республика Кабардино-Балкарская, Нальчик, Калинина, 262	f	large
7033	37153	196	республика Кабардино-Балкарская, Нальчик, Калинина, 262 А	f	large
7029	37148	192	республика Кабардино-Балкарская, Нальчик, Калинина, 99	f	large
7017	37136	180	республика Кабардино-Балкарская, Нальчик, Кабардинская, 198	f	large
7001	37119	164	республика Кабардино-Балкарская, Нальчик, Кабардинская, 55	f	large
6961	37079	124	республика Кабардино-Балкарская, Нальчик, Инессы Арманд, 43	f	large
7024	37143	187	республика Кабардино-Балкарская, Нальчик, Ингушская, 9 А	f	large
7020	37139	183	республика Кабардино-Балкарская, Нальчик, Ингушская, 2	f	large
7007	37126	170	республика Кабардино-Балкарская, Нальчик, Идарова, 139 А	f	large
7006	37125	169	республика Кабардино-Балкарская, Нальчик, Идарова, 160 А	f	large
6970	37088	133	республика Кабардино-Балкарская, Нальчик, Захарова, 77	f	large
6971	37089	134	республика Кабардино-Балкарская, Нальчик, Залиханова, 4	f	large
6969	37087	132	республика Кабардино-Балкарская, Нальчик, Заводская, 6	f	large
7027	37146	190	республика Кабардино-Балкарская, Нальчик, Дагестанская, 148	f	large
6972	37090	135	республика Кабардино-Балкарская, Нальчик, Дагестанская, 89	f	large
6994	37112	157	республика Кабардино-Балкарская, Нальчик, Горького, 17	f	large
6966	37084	129	республика Кабардино-Балкарская, Нальчик, Горького, 11	f	large
6960	37078	123	республика Кабардино-Балкарская, Нальчик, Головко, 89	f	large
7015	37134	178	республика Кабардино-Балкарская, Нальчик, Гагарина, 10	f	large
6953	37071	116	республика Кабардино-Балкарская, Нальчик, Ватутина, 6	f	large
6950	37067	113	республика Кабардино-Балкарская, Нальчик, Ватутина, 28	f	large
6981	37100	144	республика Кабардино-Балкарская, Нальчик, Будаева, 13	f	large
6952	37069	115	республика Кабардино-Балкарская, Нальчик, Байсултанова, 74-11-40	f	large
6951	37068	114	республика Кабардино-Балкарская, Нальчик, Байсултанова, 33	f	large
6935	37052	98	республика Кабардино-Балкарская, Нальчик, Бабаева, 33	f	large
7014	37133	177	республика Кабардино-Балкарская, Нальчик, Б. Хмельницкого, 17	f	large
7008	37127	171	республика Кабардино-Балкарская, Нальчик, Б. Хмельницкого, 34 А	f	medium
7018	37137	181	республика Кабардино-Балкарская, Нальчик, Ашурова, 3	f	large
7019	37124	182	республика Кабардино-Балкарская, Нальчик, Ашурова, 22	f	large
6946	37063	109	республика Кабардино-Балкарская, Нальчик, Ахметова, 58	f	large
6936	37053	99	республика Кабардино-Балкарская, Нальчик, Аттоева, 15	f	large
7011	37130	174	республика Кабардино-Балкарская, Нальчик, 9-е Января, 1	f	large
7032	37151	195	республика Кабардино-Балкарская, Нальчик, 2-я Надречная, 127	f	large
7031	37150	194	республика Кабардино-Балкарская, Нальчик, 2-я Надречная, 120	f	large
6982	37101	145	республика Кабардино-Балкарская, Нальчик, 2-ой Таманской дивизии, 422	f	large
6975	37093	138	республика Кабардино-Балкарская, Нальчик, 2-ой Таманской дивизии, 450	f	large
6974	37092	137	республика Кабардино-Балкарская, Нальчик, 2-ой Таманской дивизии, 27	f	large
6919	37040	82	республика Кабардино-Балкарская, Майский, Ленина, 24	f	large
6928	37045	91	республика Кабардино-Балкарская, Майский, Железнодорожная, 54	f	large
6920	35045	83	республика Кабардино-Балкарская, Майский, Горького, 112	f	medium
6923	35273	86	республика Кабардино-Балкарская, Майский, 9 Мая, 1	f	large
6877	36996	40	республика Кабардино-Балкарская, Баксан, переулок Куашева, 16	f	large
6865	36986	28	республика Кабардино-Балкарская, Баксан, Эльбрусская, 15	f	large
6870	36991	33	республика Кабардино-Балкарская, Баксан, Шукова, 1	f	large
6869	36990	32	республика Кабардино-Балкарская, Баксан, Шукова, 2	f	large
6873	36980	36	республика Кабардино-Балкарская, Баксан, Шукова, 142	f	large
6879	36998	42	республика Кабардино-Балкарская, Баксан, Кокова, 223	f	large
6878	36997	41	республика Кабардино-Балкарская, Баксан, Баксанова, 86	f	large
7191	37309	354	республика Кабардино-Балкарская, Эльбрусский район, поселок городского типа Эльбрус, Эльбрусская, 23	f	small
7193	37311	356	Россия, республика Кабардино-Балкарская, Эльбрусский район, поселок Эльбрус	f	medium
7192	37310	355	республика Кабардино-Балкарская, Эльбрусский район, поселок Эльбрус	f	large
7185	37303	348	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, проспект Эльбрусский, 21	f	large
7189	37307	352	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, пр. Эльбрусский, 89	f	large
25663	90646	41	Ставропольский край, Ставрополь, Серова, 420	f	large
7187	37305	350	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, Энеева, 29	f	large
7183	37301	346	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, Мичурина, 1 А	f	large
7182	37301	345	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, Мичурина, 1 А	f	medium
7186	37304	349	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, Мизиева, 5	f	medium
7184	37302	347	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, Гызыева, 5	f	medium
7180	37299	343	республика Кабардино-Балкарская, Эльбрусский район, Тырныауз, Автогаражная, 2	f	small
7176	37295	339	республика Кабардино-Балкарская, Эльбрусский район, Сельское поселение Кенделен, Ленина, 294 Г	f	medium
7174	37293	337	республика Кабардино-Балкарская, Эльбрусский район, Кенделен, Энеева, 78	f	medium
7175	37294	338	республика Кабардино-Балкарская, Эльбрусский район, Кенделен, Ленина, 241	f	medium
7173	37292	336	республика Кабардино-Балкарская, Эльбрусский район, село Гунделен, 800-Погибших, 7	f	medium
7190	37308	353	республика Кабардино-Балкарская, Эльбрусский район, поселок Верхний Баксан, Школьная, 2	f	small
7179	37298	342	республика Кабардино-Балкарская, Эльбрусский район, село Былым, Тебердиева, 47	f	large
7178	37297	341	республика Кабардино-Балкарская, Эльбрусский район, село Бедык, Байсултанова, 18	f	small
7050	37171	213	республика Кабардино-Балкарская, Черекский район, поселок Советское, Угнич, 12	f	small
7172	37291	335	республика Кабардино-Балкарская, Черекский район, поселок городского типа Советское, Мечиева К.Б., 1	f	medium
7171	37290	334	республика Кабардино-Балкарская, Черекский район, поселок городского типа Советское, Мечиева К.Б, 143	f	large
7170	37289	333	республика Кабардино-Балкарская, Черекский район, Кашхатау, Мечиева К.Б, 193	f	large
7167	37286	330	республика Кабардино-Балкарская, Черекский район, село Карасу, Школьная, 21	f	small
7158	37277	321	республика Кабардино-Балкарская, Черекский район, село Зарагиж, Ленина, 82	f	large
7160	37279	323	республика Кабардино-Балкарская, Черекский район, село Жемтала, Сталина, 50	f	large
7159	37278	322	республика Кабардино-Балкарская, Черекский район, село Жемтала, Ленина, 82	f	large
7155	37274	318	республика Кабардино-Балкарская, Черекский район, село Герпегеж, Холамкая, 42	f	medium
67835	37280	324	республика Кабардино-Балкарская, Черекский район, село Верхняя Жемтала, Настуева, 80	f	large
7163	37282	326	республика Кабардино-Балкарская, Черекский район, село Верхняя Балкария, Таулуева, 112	f	medium
7162	37281	325	республика Кабардино-Балкарская, Черекский район, село Верхняя Балкария, Таулуева, 93	f	medium
7165	37284	328	республика Кабардино-Балкарская, Черекский район, село Верхняя Балкария, Настуева, 25	f	medium
7164	37283	327	республика Кабардино-Балкарская, Черекский район, село Верхняя Балкария, Асанова, 41	f	small
7166	37285	329	республика Кабардино-Балкарская, Черекский район, село Безенги, Османова Э.Х., 69	f	medium
7169	37288	332	республика Кабардино-Балкарская, Черекский район, село Бабугент, Тогузаева, 26	f	large
7168	37287	331	республика Кабардино-Балкарская, Черекский район, село Бабугент, Мокаева, 34	f	large
7157	37276	320	республика Кабардино-Балкарская, Черекский район, село Аушигер, Кушхова, 7	f	large
7156	37275	319	республика Кабардино-Балкарская, Черекский район, село Аушигер, Бицуева, 194	f	medium
7150	37269	313	республика Кабардино-Балкарская, Чегемский район, село Яникой, Ленина, 96	f	large
7149	37268	312	республика Кабардино-Балкарская, Чегемский район, село Шалушка, переулок Колхозный, 8	f	large
7147	37266	310	республика Кабардино-Балкарская, Чегемский район, село Шалушка, Ленина, 60б	f	large
7148	37267	311	республика Кабардино-Балкарская, Чегемский район, село Шалушка, А.Г.Юанова, 1	f	large
7142	37261	305	республика Кабардино-Балкарская, Чегемский район, село Чегем 2-й, Ленина, 169	f	large
7141	37260	304	республика Кабардино-Балкарская, Чегемский район, село Чегем 2-й, Ленина, 72	f	large
7146	37265	309	республика Кабардино-Балкарская, Чегемский район, Чегем 1-й, Свободы, 160	f	large
7137	37256	300	республика Кабардино-Балкарская, Чегемский район, Чегем 1-й, Кулиева, 38	f	medium
7144	37263	307	республика Кабардино-Балкарская, Чегемский район, Чегем 1-й, Баксанское шоссе, 7	f	large
7145	37264	308	республика Кабардино-Балкарская, Чегемский район, Чегем 1-й, Баксанское Шоссе, 25а	f	large
7143	37262	306	республика Кабардино-Балкарская, Чегемский район, Чегем 1-й, А.С. Кярова, 6	f	large
7138	37257	301	республика Кабардино-Балкарская, Чегемский район, село Хуштосырт, Балкарская, 22	f	medium
7154	37273	317	республика Кабардино-Балкарская, Чегемский район, Сельское поселение Звездный, Ленина, 16	f	large
7139	37258	302	республика Кабардино-Балкарская, Чегемский район, село Нижний Чегем, К.Кулиева, 84	f	large
7152	37271	315	республика Кабардино-Балкарская, Чегемский район, село Нартан, Ленина, 141	f	large
7151	37270	314	республика Кабардино-Балкарская, Чегемский район, село Нартан, Ленина, 100	f	large
7153	37272	316	республика Кабардино-Балкарская, Чегемский район, село Нартан, А.Тухужева, 1	f	large
7140	37259	303	республика Кабардино-Балкарская, Чегемский район, село Лечинкай, Канукоева Н.Т, 66	f	large
7036	37156	199	республика Кабардино-Балкарская, Чегемский район, село Адиюх, Нарткалинское шоссе, 167	f	large
7117	37236	280	республика Кабардино-Балкарская, Урванский район, село Шитхала, Мира, 51	f	medium
7115	37234	278	республика Кабардино-Балкарская, Урванский район, село Черная Речка, Ленина, 100	f	large
6914	37035	77	республика Кабардино-Балкарская, Урванский район, село Хатуей, Бараова, 16	f	large
6915	37036	78	республика Кабардино-Балкарская, Урванский район, село Урух, Кирова, 27	f	large
7119	37238	282	республика Кабардино-Балкарская, Урванский район, село Урвань, Школьная, 24	f	large
7118	37237	281	республика Кабардино-Балкарская, Урванский район, село Урвань, Братьев Кафоевых, 132	f	large
6909	37030	72	республика Кабардино-Балкарская, Урванский район, село Ташлы-Тала, Ленина, 38	f	small
7123	37242	286	республика Кабардино-Балкарская, Урванский район, село Старый Черек, Ленина, 134	f	large
7122	37241	285	республика Кабардино-Балкарская, Урванский район, село Старый Черек, Куашева, 3	f	large
7126	37245	289	республика Кабардино-Балкарская, Урванский район, село Псынабо, Пролетарская, 24	f	large
7125	37244	288	республика Кабардино-Балкарская, Урванский район, село Псыкод, Ленина, 3	f	large
7120	37239	283	республика Кабардино-Балкарская, Урванский район, село Псыгансу, Ленина, 109	f	large
7121	37240	284	республика Кабардино-Балкарская, Урванский район, село Псыгансу, Грейдерная, 4	f	large
6913	37034	76	республика Кабардино-Балкарская, Урванский район, село Озрек, Кабалоева, 1	f	medium
7124	37243	287	республика Кабардино-Балкарская, Урванский район, село Нижний Черек, Ленина, 69	f	large
7132	37251	295	республика Кабардино-Балкарская, Урванский район, Нарткала, Тарчокова, 17	f	large
7136	37255	299	республика Кабардино-Балкарская, Урванский район, Нарткала, Пушкина, 76	f	large
7130	37249	293	республика Кабардино-Балкарская, Урванский район, Нарткала, Массаева, 31	f	large
7131	37250	294	республика Кабардино-Балкарская, Урванский район, Нарткала, Ленина, 72	f	large
7134	37253	297	республика Кабардино-Балкарская, Урванский район, Нарткала, Кабардинская, 115	f	large
7133	37252	296	республика Кабардино-Балкарская, Урванский район, Нарткала, Кабардинская, 131	f	large
7129	37248	292	республика Кабардино-Балкарская, Урванский район, Нарткала, Жамборова, 4	f	large
7135	37254	298	республика Кабардино-Балкарская, Урванский район, Нарткала, Гурфова, 4	f	large
7116	37235	279	республика Кабардино-Балкарская, Урванский район, село Морзох, Комсомольская, 1	f	medium
7127	37246	290	республика Кабардино-Балкарская, Урванский район, село Кахун, Октябрьская, 100	f	large
7128	37247	291	республика Кабардино-Балкарская, Урванский район, село Кахун, Кирова, 140	f	large
6908	37029	71	республика Кабардино-Балкарская, Урванский район, село Ерокко, Массаева, 55	f	medium
7114	37233	277	республика Кабардино-Балкарская, Урванский район, село Герменчик, Центральная, 10	f	large
6910	37031	73	республика Кабардино-Балкарская, Урванский район, село Верхний Лескен, Ленина, 19	f	small
6905	37026	68	республика Кабардино-Балкарская, Урванский район, село Аргудан, Суншева, 28	f	large
6906	37027	69	республика Кабардино-Балкарская, Урванский район, село Аргудан, Жигунова, 105	f	large
6912	37033	75	республика Кабардино-Балкарская, Урванский район, село Анзорей, Хамгокова, 27	f	large
6911	37032	74	республика Кабардино-Балкарская, Урванский район, село Анзорей, Степная	f	large
7110	37229	273	республика Кабардино-Балкарская, Терский район, село Урожайное, Ленина, 55	f	large
7111	37230	274	республика Кабардино-Балкарская, Терский район, село Терекское, Ленина, 1	f	large
7093	37212	256	республика Кабардино-Балкарская, Терский район, Терек, Ленина, 14	f	large
7091	37210	254	республика Кабардино-Балкарская, Терский район, Терек, Карданова, 66	f	large
7102	37221	265	республика Кабардино-Балкарская, Терский район, село Тамбовское, Дружбы, 166	f	large
7105	37224	268	республика Кабардино-Балкарская, Терский район, Сельское поселение Нижний Курп, Ногмова, 2	f	medium
7098	37217	261	республика Кабардино-Балкарская, Терский район, село Плановское, Гагарина, 2	f	large
7112	37231	275	республика Кабардино-Балкарская, Терский район, село Новое Хамидие, Кудаева, 54Б	f	large
7113	37232	276	республика Кабардино-Балкарская, Терский район, Ново-Хамидие, Матросова, 10 а	f	medium
7109	37228	272	республика Кабардино-Балкарская, Терский район, село Новая Балкария, Центральная, 24	f	medium
7107	37226	270	республика Кабардино-Балкарская, Терский район, село Красноармейское, Центральная, 45	f	large
7096	37215	259	республика Кабардино-Балкарская, Терский район, село Интернациональное, Парковая, 1	f	small
7104	37223	267	республика Кабардино-Балкарская, Терский район, село Инаркой, Дышекова, 10	f	medium
7108	37227	271	республика Кабардино-Балкарская, Терский район, село Джулат, Сибилова, 1	f	small
7097	37216	260	республика Кабардино-Балкарская, Терский район, село Дейское, Мальбахова, 149	f	large
7103	37222	266	республика Кабардино-Балкарская, Терский район, село Верхний Курп, Ашхотова, 54	f	large
7100	37219	263	республика Кабардино-Балкарская, Терский район, село Верхний Акбаш, Ленина, 25	f	large
7101	37220	264	республика Кабардино-Балкарская, Терский район, село Верхний Акбаш, Гоголя, 1	f	small
7099	37218	262	республика Кабардино-Балкарская, Терский район, село Белоглинское, Пачева, 10	f	small
7106	37225	269	республика Кабардино-Балкарская, Терский район, село Арик, Дружбы, 16	f	large
7047	37168	210	республика Кабардино-Балкарская, Прохладненский район, село старая Солдатская, Зенковского, 14	f	small
7038	37158	201	республика Кабардино-Балкарская, Прохладненский район, сельское поселение Малакановское, Интернациональная, 1	f	small
7057	37178	220	республика Кабардино-Балкарская, Прохладненский район, село Янтарное, Ленина, 7	f	medium
7055	37176	218	республика Кабардино-Балкарская, Прохладненский район, село Черниговское, Кравченко	f	small
7059	37180	222	республика Кабардино-Балкарская, Прохладненский район, село Учебный, Школьная, 1	f	medium
7041	37161	204	республика Кабардино-Балкарская, Прохладненский район, село Ульяновское, Школьная, 2а	f	small
7046	37166	209	республика Кабардино-Балкарская, Прохладненский район, село Солдатская, Пилипенко, 56	f	large
7045	37165	208	республика Кабардино-Балкарская, Прохладненский район, станица Солдатская, Пилипенко, 40	f	large
7056	37177	219	республика Кабардино-Балкарская, Прохладненский район, село Саратовский, Садовая, б/н	f	small
7068	37187	231	республика Кабардино-Балкарская, Прохладненский район, село Псыншоко, Центральная, 34	f	small
7070	37189	233	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Строительная, 284	f	large
7075	37194	238	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Свободы, 178	f	large
7073	37192	236	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Пролетарская, 220	f	large
7083	37202	246	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Привокзальная площадь, 15-я дистанция сигнализации и связи	f	large
7084	37203	247	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Привокзальная Площадь, ж/д ст.Прохладная Красный уголок	f	large
7079	37198	242	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Петренко, 48	f	large
67834	37207	251	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Овчарова, 66/1	f	large
7078	37197	241	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Ленина, 76	f	large
25662	90645	40	Ставропольский край, Ставрополь, Серова, 451	f	large
7077	37196	240	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Ленина, 104	f	large
7080	37199	243	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Головко, 309	f	large
7076	37195	239	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Гагарина переулок, 16	f	large
7087	37206	250	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Боронтова, 99	f	large
7085	37204	248	республика Кабардино-Балкарская, Прохладненский район, Прохладный, Боронтова, 275	f	large
7061	37182	224	республика Кабардино-Балкарская, Прохладненский район, село Пролетарское, Ленина, 193	f	large
7065	37184	228	республика Кабардино-Балкарская, Прохладненский район, село Прималкинское, Октябрьская, 206	f	large
7064	37183	227	республика Кабардино-Балкарская, Прохладненский район, село Прималкинское, Кныш, 150	f	large
7063	37070	226	республика Кабардино-Балкарская, Прохладненский район, село Приближная, Кооперативный, 7а	f	large
7067	37186	230	республика Кабардино-Балкарская, Прохладненский район, село Новополтавское, Третьякова, 128	f	medium
7066	37185	229	республика Кабардино-Балкарская, Прохладненский район, село Новопокровский, Широкий переулок, 34	f	medium
7060	37181	223	республика Кабардино-Балкарская, Прохладненский район, село Лесное, Ивановского, 5	f	medium
7039	37159	202	республика Кабардино-Балкарская, Прохладненский район, село Красносельское, Театральная, б/н	f	large
7058	37179	221	республика Кабардино-Балкарская, Прохладненский район, село Комсомольское, Виноградная, 3	f	small
7049	37170	212	республика Кабардино-Балкарская, Прохладненский район, село Карагач, Абубекирова, 111	f	large
7048	37169	211	республика Кабардино-Балкарская, Прохладненский район, село Карагач, Абубекирова, 100	f	large
7044	37164	207	республика Кабардино-Балкарская, Прохладненский район, село Заречное, Зеленая, б/н	f	medium
7062	37152	225	республика Кабардино-Балкарская, Прохладненский район, село Екатериноградская, Ленина, 50а	f	large
7037	37157	200	республика Кабардино-Балкарская, Прохладненский район, село Дальное, Школьная, 8	f	medium
7040	37160	203	республика Кабардино-Балкарская, Прохладненский район, село Граничное, Свободы, 2	f	small
7052	37173	215	республика Кабардино-Балкарская, Прохладненский район, село Грабовец, Красноармейская, 29/1	f	small
7042	37162	205	республика Кабардино-Балкарская, Прохладненский район, село Гвардейское, Центральная, 5	f	small
7043	37163	206	республика Кабардино-Балкарская, Прохладненский район, село Виноградное, Мира	f	small
7051	37172	214	республика Кабардино-Балкарская, Прохладненский район, село Благовещенка, Ленина, 98	f	large
7053	37174	216	республика Кабардино-Балкарская, Прохладненский район, село Алтуд, Комсомольская, 25	f	large
7054	37175	217	республика Кабардино-Балкарская, Прохладненский район, село Алтуд, Аптечная, 54	f	large
7016	37135	179	республика Кабардино-Балкарская, Нальчик городской округ, Нальчик, Кабардинская, 191	f	large
7010	37129	173	республика Кабардино-Балкарская, Нальчик городской округ, Нальчик, Ю. Фучика, 5	f	large
7021	37140	184	республика Кабардино-Балкарская, Нальчик городской округ, Нальчик, Неделина, 9	f	large
6965	37083	128	республика Кабардино-Балкарская, Нальчик городской округ, Нальчик, Инессы Арманд, 30	f	large
6963	37081	126	республика Кабардино-Балкарская, Нальчик городской округ, Нальчик, Балкарская, 3	f	large
67833	37054	100	республика Кабардино-Балкарская, Нальчик городской округ, Нальчик, Аттоева, 43	f	large
6931	37048	94	республика Кабардино-Балкарская, Майский район, станция Котляревская, Лебедевых, 93	f	large
6929	37046	92	республика Кабардино-Балкарская, Майский район, село Сарский, Мичурина, 6	f	small
6933	37050	96	республика Кабардино-Балкарская, Майский район, село Новоивановское, Ленина, 162	f	large
6924	37041	87	республика Кабардино-Балкарская, Майский район, Майский, Административное здание Зверохозяйства Майский	f	medium
6922	35082	85	республика Кабардино-Балкарская, Майский район, Майский, Трудовая, 46	f	medium
6921	36931	84	республика Кабардино-Балкарская, Майский район, Майский, Октябрьская, 46	f	large
6925	37042	88	республика Кабардино-Балкарская, Майский район, Майский, Медведева, 10	f	large
6926	37043	89	республика Кабардино-Балкарская, Майский район, Майский, Кирова, 227	f	large
6927	37044	90	республика Кабардино-Балкарская, Майский район, Майский, Калинина, 125	f	large
6917	37038	80	республика Кабардино-Балкарская, Майский район, Майский, Горького, 116	f	large
6918	37039	81	республика Кабардино-Балкарская, Майский район, Майский, Гагарина, 10	f	large
6916	37037	79	республика Кабардино-Балкарская, Майский район, Майский, 9 Мая, 181	f	large
6934	37051	97	республика Кабардино-Балкарская, Майский район, село Колдрасинский, Центральная, 18	f	small
6907	37028	70	республика Кабардино-Балкарская, Лескенский район, село Второй Лескен, Шортанова, 46	f	large
6880	36999	43	республика Кабардино-Балкарская, Зольский район, село Этоко, Школьный, 1	f	medium
6882	37001	45	республика Кабардино-Балкарская, Зольский район, село Шардаково, Ленина, 64	f	large
67832	37021	63	республика Кабардино-Балкарская, Зольский район, село Хабаз, Ленина, 67	f	large
86011	37017	59	республика Кабардино-Балкарская, Зольский район, село Совхозное, Школьная, 1А	f	small
6888	37007	51	республика Кабардино-Балкарская, Зольский район, Сельское поселение Камлюково, Школьная, 2	f	large
6881	37000	44	республика Кабардино-Балкарская, Зольский район, село Светловодское, Октябрьская, 94а	f	large
67842	37015	58	республика Кабардино-Балкарская, Зольский район, село Сармаково, Ленина, 211	f	large
67841	37014	57	республика Кабардино-Балкарская, Зольский район, село Сармаково, Ленина, 152	f	large
67840	37013	56	республика Кабардино-Балкарская, Зольский район, Сармаково, Ленина, 51	f	large
6887	37006	50	республика Кабардино-Балкарская, Зольский район, село Псынодаха, Ленина, 108	f	large
6889	37008	52	республика Кабардино-Балкарская, Зольский район, село Приречное, Буденного, 9	f	medium
6932	37049	95	республика Кабардино-Балкарская, Зольский район, село Октябрьское, 50 Лет Октября, 42	f	medium
6892	37011	55	республика Кабардино-Балкарская, Зольский район, село Малка, Ленина, 60	f	large
6891	37010	54	республика Кабардино-Балкарская, Зольский район, село Малка, Ленина, 173	f	large
6890	37009	53	республика Кабардино-Балкарская, Зольский район, село Малка, Ленина, 371	f	large
6901	37022	64	республика Кабардино-Балкарская, Зольский район, село Кичмалка, Чкалова, 34	f	large
67831	37018	60	республика Кабардино-Балкарская, Зольский район, село Каменномостское, Ленина, 46	f	large
6898	37019	61	республика Кабардино-Балкарская, Зольский район, село Каменномостское, Кумыкова, 5	f	large
6899	37020	62	республика Кабардино-Балкарская, Зольский район, село Каменномостское, Куважукова, 101	f	large
6886	37005	49	республика Кабардино-Балкарская, Зольский район, село Зольское, Советская, 96	f	medium
6904	37025	67	республика Кабардино-Балкарская, Зольский район, поселок Залукокоаже, Пятигорская, 1	f	large
6902	37023	65	республика Кабардино-Балкарская, Зольский район, поселок Залукокоаже, Комсомольская, 34	f	large
6903	37024	66	республика Кабардино-Балкарская, Зольский район, поселок Залукокоаже, Кавказская, 8	f	large
6885	37004	48	республика Кабардино-Балкарская, Зольский район, село Залукодес, Школьная, 6	f	large
6884	37003	47	республика Кабардино-Балкарская, Зольский район, село Дженал, Центральная, 1	f	small
6883	37002	46	республика Кабардино-Балкарская, Зольский район, село Белокаменское, Центральная, 2	f	small
110348	36977	20	республика Кабардино-Балкарская, Баксанский район, село Псычох, Ленина, 11	f	medium
67836	36976	19	республика Кабардино-Балкарская, Баксанский район, село Псыхурей, Катханова, 128	f	large
6853	36973	16	республика Кабардино-Балкарская, Баксанский район, село Нижний Куркужин, Октябрьская, 185	f	large
6852	36972	15	республика Кабардино-Балкарская, Баксанский район, село Нижний Куркужин, Октябрьская, 260	f	large
7177	37296	340	республика Кабардино-Балкарская, Баксанский район, село Лашкута, Мира, 12	f	medium
67838	36982	24	республика Кабардино-Балкарская, Баксанский район, село Куба-Таба, Советская, 3а	f	large
6860	36981	23	республика Кабардино-Балкарская, Баксанский район, село Куба, Комсомольская, 80	f	large
67837	36979	22	республика Кабардино-Балкарская, Баксанский район, село Куба, Комсомольская, здание СДК	f	large
6763	35062	56	республика Ингушская, Назрановский район, Назрань, Суворова, 4	f	large
6862	36983	25	республика Кабардино-Балкарская, Баксанский район, село Кременчуг-Константиновское, Садовая, 56	f	large
67839	36984	26	республика Кабардино-Балкарская, Баксанский район, село Кишпек, Школьная, 4	f	large
6838	36957	1	республика Кабардино-Балкарская, Баксанский район, село Исламей, переулок Алихбердова, 13	f	large
6839	36959	2	республика Кабардино-Балкарская, Баксанский район, село Исламей, Эльбрусская, 129	f	large
6841	36961	4	республика Кабардино-Балкарская, Баксанский район, село Исламей, Надречная, 96	f	large
6840	36960	3	республика Кабардино-Балкарская, Баксанский район, село Исламей, Надречная, 127	f	large
6846	36966	9	республика Кабардино-Балкарская, Баксанский район, село Заюково, Кирова, 413	f	large
6844	36964	7	республика Кабардино-Балкарская, Баксанский район, село Заюково, Кирова, 242	f	large
6843	36963	6	республика Кабардино-Балкарская, Баксанский район, село Заюково, Казаноко, 135	f	large
6842	36962	5	республика Кабардино-Балкарская, Баксанский район, село Заюково, Казаноко, б/н	f	large
6845	36965	8	республика Кабардино-Балкарская, Баксанский район, село Заюково, Дикинова, 5	f	large
110349	36978	21	республика Кабардино-Балкарская, Баксанский район, село Жанхотеко, Пролетарская, 34	f	medium
6855	36975	18	республика Кабардино-Балкарская, Баксанский район, село Верхний Куркужин, Октябрьская, 158	f	medium
6854	36974	17	республика Кабардино-Балкарская, Баксанский район, село Верхний Куркужин, Октябрьская, 10	f	medium
6848	36968	11	республика Кабардино-Балкарская, Баксанский район, село Баксаненок, Березгова, 122	f	large
6847	36967	10	республика Кабардино-Балкарская, Баксанский район, село Баксаненок, Баксанская, 68	f	large
6849	36969	12	республика Кабардино-Балкарская, Баксанский район, село Баксаненок, Ахметова, 4	f	large
6867	36988	30	республика Кабардино-Балкарская, Баксанский район, Баксан, Угнич, 1	f	large
6866	36987	29	республика Кабардино-Балкарская, Баксанский район, Баксан, Р.Калмыкова, 1	f	large
6871	36992	34	республика Кабардино-Балкарская, Баксанский район, Баксан, Панаиоти, 9	f	large
6868	36989	31	республика Кабардино-Балкарская, Баксанский район, Баксан, Николаева, 2	f	large
6864	36985	27	республика Кабардино-Балкарская, Баксанский район, Баксан, Ленина, 23	f	large
6874	36993	37	республика Кабардино-Балкарская, Баксанский район, Баксан, Иванова переулок, 1	f	large
6872	36958	35	республика Кабардино-Балкарская, Баксанский район, Баксан, Бесланеева, 7Б	f	large
6876	36995	39	республика Кабардино-Балкарская, Баксанский район, Баксан, Баксанова, 24	f	large
6875	36994	38	республика Кабардино-Балкарская, Баксанский район, Баксан, Апанасова, 72	f	large
6850	36970	13	республика Кабардино-Балкарская, Баксанский район, село Атажукино, Катанчиева, 56	f	large
6851	36971	14	республика Кабардино-Балкарская, Баксанский район, село Атажукино, Апшева, 85	f	large
6732	35031	25	республика Ингушская, Малгобек, Осканова , 14, Культурно-досуговый центр	f	\N
6734	35033	27	республика Ингушская, Малгобек, Обороны Кавказа, 9, Средняя школа №9	f	small
6730	35029	23	республика Ингушская, Малгобек, Нурадилова , 108, Издательство газеты Сердало	f	large
6736	35035	29	республика Ингушская, Малгобек, Калинина , 11, Средняя школа №1	f	\N
6728	35027	21	республика Ингушская, Малгобек, Гоголя , 2, Средняя школа №18	f	large
6729	35028	22	республика Ингушская, Малгобек, Гарданова , 108, Детский сад №5	f	large
6725	35024	18	республика Ингушская, Малгобек, Гарданова , 54, Школа детского техн, творчества	f	\N
110285	35135	126	республика Ингушская, Сунженский район, село Чемульга, Широкая, 1	f	\N
6835	35137	128	республика Ингушская, Сунженский район, село Троицкая	f	large
6821	35122	114	республика Ингушская, Сунженский район, село Троицкая, Шоссейная, 1	f	\N
6820	35121	113	республика Ингушская, Сунженский район, село Троицкая, Ленина, 45	f	\N
6819	35120	112	республика Ингушская, Сунженский район, село Троицкая, Колхозная, 112, Дом культуры	f	\N
6814	35115	107	республика Ингушская, Сунженский район, село Орджоникидзевская, Энгельса, 68	f	large
6834	35136	127	республика Ингушская, Сунженский район, село Орджоникидзевская, Шерипова, 98	f	medium
6818	35119	111	республика Ингушская, Сунженский район, село Орджоникидзевская, Трудовая, 1	f	large
6816	35117	109	республика Ингушская, Сунженский район, село Орджоникидзевская, Рабочая, 85	f	\N
6829	35130	122	республика Ингушская, Сунженский район, село Орджоникидзевская, Осканова, 24	f	medium
6811	35112	104	республика Ингушская, Сунженский район, село Орджоникидзевская, Осканова, 73, ДК	f	\N
6817	35118	110	республика Ингушская, Сунженский район, село Орджоникидзевская, Новая Кирова, 10	f	medium
110282	35124	116	республика Ингушская, Сунженский район, село Орджоникидзевская, Мира, 9	f	\N
6809	35110	102	республика Ингушская, Сунженский район, село Орджоникидзевская, Менделеева, 36	f	large
6822	35123	115	республика Ингушская, Сунженский район, село Орджоникидзевская, Ленина, 68	f	\N
6810	35111	103	республика Ингушская, Сунженский район, село Орджоникидзевская, Ленина, 157	f	large
6815	35116	108	республика Ингушская, Сунженский район, село Орджоникидзевская, Демченко, 68	f	large
6812	35113	105	республика Ингушская, Сунженский район, село Орджоникидзевская, Грозненская, 1	f	large
6813	35114	106	республика Ингушская, Сунженский район, село Орджоникидзевская, Висаитова, 20	f	large
6825	35126	118	республика Ингушская, Сунженский район, село Орджоникидзевская, Ленина, 46	f	large
6824	35125	117	республика Ингушская, Сунженский район, село Нестеровская, Шоссейная, 1	f	\N
6715	35014	8	республика Ингушская, Сунженский район, поселок Карабулак, Фрунзе, 12	f	large
6720	35019	13	республика Ингушская, Сунженский район, поселок Карабулак, Осканова, 139	f	large
6719	35018	12	республика Ингушская, Сунженский район, поселок Карабулак, Осканова, 120	f	large
6717	35016	10	республика Ингушская, Сунженский район, поселок Карабулак, Осканова, 65	f	large
6716	35015	9	республика Ингушская, Сунженский район, поселок Карабулак, Осканова, 76	f	large
6714	35013	7	республика Ингушская, Сунженский район, поселок Карабулак, Осканова, 1	f	small
6718	35017	11	республика Ингушская, Сунженский район, поселок Карабулак, Джабагиева, 139	f	large
6831	35132	124	республика Ингушская, Сунженский район, село Даттых, Кавказская, 1	f	small
6828	35129	121	республика Ингушская, Сунженский район, село Галашки, Шоссейная, 43	f	medium
6826	35127	119	республика Ингушская, Сунженский район, село Галашки, Школьная, 48	f	large
6827	35128	120	республика Ингушская, Сунженский район, село Галашки, Исламская, 31	f	medium
6830	35131	123	республика Ингушская, Сунженский район, село Верхний Алкун, Мира, 30	f	\N
6832	35133	125	республика Ингушская, Сунженский район, Берд-Юрт, 6-Линия, 1	f	small
6781	35080	74	республика Ингушская, Назрановский район, село Яндырка, Орджоникидзе, 69	f	large
6780	35079	73	республика Ингушская, Назрановский район, село Яндырка, Орджоникидзе, 9	f	large
6782	35081	75	республика Ингушская, Назрановский район, село Яндырка, Мальсагова, 14	f	large
6801	35102	94	республика Ингушская, Назрановский район, село Экажево, Осканова, 68	f	large
6800	35101	93	республика Ингушская, Назрановский район, село Экажево, Осканова, 65	f	large
6799	35100	92	республика Ингушская, Назрановский район, Ингушская, 47	f	large
6798	35099	91	республика Ингушская, Назрановский район, село Экажево, Бекова, 7	f	large
6787	35087	80	республика Ингушская, Назрановский район, село Сурхахи, Школьная, 1	f	large
6786	35086	79	республика Ингушская, Назрановский район, село Сурхахи, Т.Аушева, 34	f	\N
6804	35105	97	республика Ингушская, Назрановский район, село Плиево, Осканова, 44	f	large
110254	35011	5	республика Ингушская, Назрановский район, село Ольгети, Путина, 37	f	\N
6765	35064	58	республика Ингушская, Назрановский район, село Насыр Корт, Почтовая, 32	f	large
6768	35067	61	республика Ингушская, Назрановский район, село Насыр Корт, Партизанская, 4	f	large
6767	35066	60	республика Ингушская, Назрановский район, село Насыр Корт, Муталиева, 24	f	large
6766	35065	59	республика Ингушская, Назрановский район, Назрань, Эсмурзиева, 23	f	large
6764	35063	57	республика Ингушская, Назрановский район, Назрань, Школьная, 21	f	large
6778	35077	71	республика Ингушская, Назрановский район, Назрань, Фабричная, 3	f	large
6785	35085	78	республика Ингушская, Назрановский район, Назрань, Т.Аушева, 65	f	large
6784	35084	77	республика Ингушская, Назрановский район, Назрань, Т.Аушева, 6	f	large
6806	35107	99	республика Ингушская, Назрановский район, Назрань, Осканова, 97	f	large
6805	35106	98	республика Ингушская, Назрановский район, Назрань, Осканова, 94	f	large
6779	35078	72	республика Ингушская, Назрановский район, Назрань, Осканова, 29	f	large
6771	35070	64	республика Ингушская, Назрановский район, Назрань, Осканова, 27	f	large
6774	35073	67	республика Ингушская, Назрановский район, Назрань, Муталиева, 24	f	large
6776	35075	69	республика Ингушская, Назрановский район, Назрань, Московская, 35	f	large
6770	35069	63	республика Ингушская, Назрановский район, Назрань, Коммунальная, 1	f	large
6772	35071	65	республика Ингушская, Назрановский район, Назрань, Картоева, 98	f	large
6775	35074	68	республика Ингушская, Назрановский район, Назрань, Кавказская, 10	f	large
6777	35076	70	республика Ингушская, Назрановский район, Назрань, Ингушская, 27	f	large
6802	35103	95	республика Ингушская, Назрановский район, Назрань, Зязикова, 5	f	large
6797	35098	90	республика Ингушская, Назрановский район, Назрань, Джабагиева, 1 а	f	large
6796	35097	89	республика Ингушская, Назрановский район, Назрань, Джабагиева, 2	f	large
6795	35096	88	республика Ингушская, Назрановский район, Назрань, Дахкильгова, 9	f	large
6794	35094	87	республика Ингушская, Назрановский район, Назрань, Дахкильгова, 36	f	large
6792	35092	85	республика Ингушская, Назрановский район, Назрань, Базоркино, 7	f	\N
6773	35072	66	республика Ингушская, Назрановский район, Назрань, Базоркина, 68	f	large
6762	35061	55	республика Ингушская, Назрановский район, Назрань, Албогачиева, 143	f	large
6807	35108	100	республика Ингушская, Назрановский район, Назрань, Осканова, 14	f	large
6788	35088	81	республика Ингушская, Назрановский район, Магас, Зязикова, 28	f	large
6721	35020	14	республика Ингушская, Назрановский район, Магас, А.Бокова, 1	f	large
6710	35009	3	республика Ингушская, Назрановский район, село Ляжги, Точиева, 8	f	small
6790	35090	83	республика Ингушская, Назрановский район, село Кантышево, Школьная, 14	f	large
6793	35093	86	республика Ингушская, Назрановский район, село Кантышево, Шерипова, 1	f	large
6791	35091	84	республика Ингушская, Назрановский район, село Кантышево, Дзаурова, 33	f	large
6713	35012	6	республика Ингушская, Назрановский район, село Гули, Укурова, 17	f	medium
6761	35060	54	республика Ингушская, Назрановский район, село Гамурзиево, Албогачиева, 7	f	large
6808	35109	101	республика Ингушская, Назрановский район, село Гайрбек-Юрт, Центральная, 1	f	small
6783	35083	76	республика Ингушская, Назрановский район, село Гази-Юрт, Школьная, 10	f	medium
6711	35010	4	республика Ингушская, Назрановский район, село Бейни, Центральная, 12	f	small
6803	35104	96	республика Ингушская, Назрановский район, село Барсуки, Левобережная, 27	f	medium
6769	35068	62	республика Ингушская, Назрановский район, село Альтиево, Школьная, б/н	f	\N
6789	35089	82	республика Ингушская, Назрановский район, село Али-Юрт, Ахриева, 58	f	large
6749	35048	42	республика Ингушская, Малгобекский район, село Южное, Базоркина, 6	f	\N
6757	35056	50	республика Ингушская, Малгобекский район, село Средние Ачалуки, Школьная, 2	f	medium
6756	35055	49	республика Ингушская, Малгобекский район, село Средние Ачалуки, Рабочая, 6	f	large
6740	35039	33	республика Ингушская, Малгобекский район, село Сагопши, Школьная, 80	f	large
6739	35038	32	республика Ингушская, Малгобекский район, село Сагопши, Школьная, 73	f	large
6741	35040	34	республика Ингушская, Малгобекский район, село Сагопши, Гарданова, 38	f	large
6744	35043	37	республика Ингушская, Малгобекский район, село Пседах, Фрунзе, 2а	f	\N
6752	35051	44	республика Ингушская, Малгобекский район, село Новый Редант, Шоссейная	f	\N
6754	35053	47	республика Ингушская, Малгобекский район, село Нижние Ачалуки, Шоссейная, 17	f	large
6755	35054	48	республика Ингушская, Малгобекский район, село Нижние Ачалуки, Кооперативная, 15	f	large
6722	35021	15	республика Ингушская, Малгобекский район, Малгобек, пер.Осканова, 2, школа-гимназия №1	f	medium
6759	35058	52	республика Ингушская, Малгобекский район, Малгобек, Эсамбаева, 45	f	large
6753	35052	46	республика Ингушская, Малгобекский район, Малгобек, Шоссейная, 24	f	\N
6748	35047	41	республика Ингушская, Малгобекский район, Малгобек, Школьная, 30	f	large
6747	35047	40	республика Ингушская, Малгобекский район, Малгобек, Школьная, 30	f	large
6743	35042	36	республика Ингушская, Малгобекский район, Малгобек, Школьная, 20	f	large
6726	35025	19	республика Ингушская, Малгобекский район, Малгобек, Школьная, 9, Школа-интернат №4	f	large
6745	35044	38	республика Ингушская, Малгобекский район, Малгобек, Укурова, 13	f	\N
6733	35032	26	республика Ингушская, Малгобекский район, Малгобек, Пушкина, 27, Средняя школа №11	f	\N
6727	35026	20	республика Ингушская, Малгобекский район, Малгобек, Орджоникидзе , 7, Средняя школа №3	f	\N
110286	35138	130	республика Ингушская, Малгобекский район, Малгобек, Оздоева, 82	f	large
6837	35138	130	республика Ингушская, Малгобекский район, Малгобек, Оздоева, 82	f	\N
6742	35041	35	республика Ингушская, Малгобекский район, Малгобек, Нурадилова, 35	f	large
6723	35022	16	республика Ингушская, Малгобекский район, Малгобек, Нурадилова, 64, Станция скорой помощи	f	\N
6750	35049	43	республика Ингушская, Малгобекский район, Малгобек, Молодежная, 13	f	medium
110269	35050	45	республика Ингушская, Малгобекский район, Малгобек, Кавказская, 1	f	large
6738	35037	31	республика Ингушская, Малгобекский район, Малгобек, Кабардинская, 48, Частное кафе	f	large
6731	35030	24	республика Ингушская, Малгобекский район, Малгобек, Железнодорожная, 16, Средняя школа №6	f	\N
6724	35023	17	республика Ингушская, Малгобекский район, Малгобек, Горданова , 23, ОСШ №20	f	\N
6737	35036	30	республика Ингушская, Малгобекский район, Малгобек, Гарданова , 39	f	\N
6735	35034	28	республика Ингушская, Малгобекский район, Малгобек, Вокзальная, 25, Средняя школа №13	f	\N
6746	35046	39	республика Ингушская, Малгобекский район, село Инарки, Укурова, 47	f	\N
6758	35057	51	республика Ингушская, Малгобекский район, село Верхние Ачалуки, Чапанова, 7	f	\N
6760	35059	53	республика Ингушская, Малгобекский район, село Вежарий, Советская, 1	f	\N
6708	35007	1	республика Ингушская, Джейрахский район, село Джайрах, Льянова, 35	f	large
6709	35008	2	республика Ингушская, Джейрахский район, село Армхи, Льянова, 53	t	small
6705	33273	1898	республика Дагестан, Южно-Сухокумск, площадь Имама Шамиля, ГЦК городской дворец культуры	f	large
6704	33272	1897	республика Дагестан, Южно-Сухокумск, Комарова, школа №4	f	large
6706	33274	1899	республика Дагестан, Южно-Сухокумск, Горького, ПУ №28 (политехническое училище)	f	large
6404	32982	1597	республика Дагестан, Хасавюрт, фабричная, 48	f	large
6391	32974	1584	республика Дагестан, Хасавюрт, Ярыксувская, 5	f	large
6390	32973	1583	республика Дагестан, Хасавюрт, Ярыксувская, 5	f	large
6389	32973	1582	республика Дагестан, Хасавюрт, Ярыксувская, 5	f	large
6408	32984	1601	республика Дагестан, Хасавюрт, Хизроева, 35	f	large
6407	32984	1600	республика Дагестан, Хасавюрт, Хизроева, 35	f	large
6383	32968	1576	республика Дагестан, Хасавюрт, Тотурбиева, 65	f	large
6376	32559	1569	республика Дагестан, Хасавюрт, Тотурбиева, 61	f	large
6395	32977	1588	республика Дагестан, Хасавюрт, Стальского, 27	f	large
6380	32762	1573	республика Дагестан, Хасавюрт, Нурадилова, 53	f	large
6379	32762	1572	республика Дагестан, Хасавюрт, Нурадилова, 53	f	large
6399	32979	1592	республика Дагестан, Хасавюрт, Новая, 1	f	large
6398	32979	1591	республика Дагестан, Хасавюрт, Новая, 1	f	large
6403	32981	1596	республика Дагестан, Хасавюрт, Махачкалинское шоссе, 29 А	f	large
6402	32981	1595	республика Дагестан, Хасавюрт, Махачкалинское шоссе, 29 А	f	large
6400	32980	1593	республика Дагестан, Хасавюрт, Махачкалинское шоссе, 29	f	large
6401	32980	1594	республика Дагестан, Хасавюрт, Махачкалинское шоссе, 29	f	large
6388	32972	1581	республика Дагестан, Хасавюрт, Махачкалинское шоссе, 10	f	large
6373	32965	1566	республика Дагестан, Хасавюрт, Коркмасова, 1	f	large
6375	32847	1568	республика Дагестан, Хасавюрт, Кандуровская, 96	f	large
6374	32966	1567	республика Дагестан, Хасавюрт, Кандауровская, 96	f	large
6377	32573	1570	республика Дагестан, Хасавюрт, Калинина, 4	f	large
6382	32967	1575	республика Дагестан, Хасавюрт, Казбекова, 92	f	large
6381	32967	1574	республика Дагестан, Хасавюрт, Казбекова, 92	f	large
6385	32970	1578	республика Дагестан, Хасавюрт, Имама Шамиля, 117	f	large
6392	32975	1585	республика Дагестан, Хасавюрт, Заречная проез1, 2	f	large
6372	32964	1565	республика Дагестан, Хасавюрт городской округ, Завокзальная, 71	f	large
6371	32964	1564	республика Дагестан, Хасавюрт городской округ, Завокзальная, 71	f	large
6384	32969	1577	республика Дагестан, Хасавюрт, Даибова, 6	f	large
6387	32971	1580	республика Дагестан, Хасавюрт, Буйнакская, 95	f	large
6386	32971	1579	республика Дагестан, Хасавюрт, Буйнакская, 95	f	large
6406	32983	1599	республика Дагестан, Хасавюрт, Бригадная, 15	f	large
6405	32983	1598	республика Дагестан, Хасавюрт, Бригадная, 15	f	large
6378	32682	1571	республика Дагестан, Хасавюрт, Батырмурзаева, 65	f	large
6397	32978	1590	республика Дагестан, Хасавюрт, Автобусная, 27	f	large
6396	32978	1589	республика Дагестан, Хасавюрт, Автобусная, 27	f	large
6394	32976	1587	республика Дагестан, Хасавюрт, 40 лет Октября, 2	f	large
6393	32976	1586	республика Дагестан, Хасавюрт, 40 лет Октября, 2	f	large
6410	32985	1603	республика Дагестан, Хасавюрт городской округ, Датуева, 70	f	large
6409	32985	1602	республика Дагестан, Хасавюрт городской округ, Датуева, 70	f	large
5913	32511	1106	республика Дагестан, Махачкала	f	large
5848	32448	1041	республика Дагестан, Махачкала, Центр - помещение ж/д вокзала ""г. Махачкала"""	f	small
5838	32439	1031	республика Дагестан, Махачкала, Центр - помещение МОУ СОШ № 	f	large
5833	32435	1026	республика Дагестан, Махачкала	f	large
5834	32435	1027	республика Дагестан, Махачкала	f	large
5156	31772	349	республика Дагестан, Махачкала, здание АФ	t	small
5912	32510	1105	республика Дагестан, Махачкала, проспект Акушинского, 13	f	large
5955	32553	1148	республика Дагестан, Махачкала, 85	f	large
5866	32465	1059	республика Дагестан, Ленинский район, Махачкала, Ярагского, 67	f	large
5860	32459	1053	республика Дагестан, Ленинский район, Махачкала, Ярагского, 15	f	large
5900	32499	1093	республика Дагестан, Махачкала, Ярагского, 78	f	large
5869	32468	1062	республика Дагестан, Махачкала, Ярагского, 75	f	large
5868	32467	1061	республика Дагестан, Махачкала, ЮСУПОВА, 70	f	large
5953	32551	1146	республика Дагестан, Махачкала, Энгельса, 3-в	f	large
5946	32544	1139	республика Дагестан, Махачкала, Энгельса, 12Б	f	large
5942	32540	1135	республика Дагестан, Махачкала, Энгельса, 11	f	large
5939	32537	1132	республика Дагестан, Махачкала, Энгельса, 48а	f	large
5938	32536	1131	республика Дагестан, Махачкала, Энгельса, 48-а	f	large
5932	32530	1125	республика Дагестан, Махачкала, Энгельса, 23	f	large
5931	32530	1124	республика Дагестан, Махачкала, Энгельса, 23	f	large
5801	32410	994	республика Дагестан, Махачкала, Эмирова, 7	f	large
5930	32529	1123	республика Дагестан, Махачкала, Школьная, 22	f	large
5944	32542	1137	республика Дагестан, Махачкала, Шамиля, 14А	f	large
5937	32535	1130	республика Дагестан, Махачкала, Шамиля, 44А	f	large
5934	32532	1127	республика Дагестан, Махачкала, Шамиля, 42-б	f	large
5914	32512	1107	республика Дагестан, Махачкала, Шамиля, 70	f	large
5871	32470	1064	республика Дагестан, Махачкала, Шамиля, 47к1	f	large
5874	32473	1067	республика Дагестан, Махачкала, ШАМИЛЯ, 85А	f	large
5872	32471	1065	республика Дагестан, Махачкала, ШАМИЛЯ, 47корпус 2	f	large
5888	32487	1081	республика Дагестан, Махачкала, Хушет, МДОУ 21	f	large
5886	32485	1079	республика Дагестан, Махачкала, Хушет, ДОМ КУЛЬТУРЫ	f	large
5948	32546	1141	республика Дагестан, Махачкала, Хуршилова, 3	f	large
5949	32547	1142	республика Дагестан, Советский район, Махачкала, Хуршилова, 14	f	large
5887	32486	1080	республика Дагестан, Махачкала, ХУШЕТ, МОУ 16	f	large
5911	32509	1104	республика Дагестан, Махачкала, Танкаева, 58 КОРП.2	f	large
5951	32549	1144	республика Дагестан, Махачкала, Североосетинская, 87корп 2	f	large
5950	32548	1143	республика Дагестан, Махачкала, Североосетинская, 87	f	large
5864	32463	1057	республика Дагестан, Махачкала, СТУДЕНЧЕСКИЙ ПЕРЕУЛОК, 3 к2	f	large
5863	32462	1056	республика Дагестан, Махачкала, СТУДЕНЧЕСКИЙ ПЕРЕУЛОК, 3 к1	f	large
5936	32534	1129	республика Дагестан, Махачкала, Проспект шамиля, 46	f	large
5943	32541	1136	республика Дагестан, Махачкала, Проспект Шамиля, 14	f	large
5935	32533	1128	республика Дагестан, Махачкала, Проспект Шамиля, 24	f	large
5933	32531	1126	республика Дагестан, Махачкала, Проспект Шамиля, 42-б	f	medium
5877	32476	1070	республика Дагестан, Махачкала, Проспект Шамиля, 89Д	f	large
5807	32415	1000	республика Дагестан, Махачкала, Островского, 18	f	large
5878	32477	1071	республика Дагестан, Махачкала, О.КОШЕВОГО, 34А	f	large
5867	32466	1060	республика Дагестан, Махачкала, НИКОЛАЕВА, 1	f	large
5895	32494	1088	республика Дагестан, Махачкала, НАСРУТДИНОВА, 44Д корпус 2	f	large
5894	32493	1087	республика Дагестан, Махачкала, НАСРУТДИНОВА, 44Д корпус 1	f	large
5851	32451	1044	республика Дагестан, Махачкала, НАСРУТДИНОВА, 63-Б	f	large
5850	32450	1043	республика Дагестан, Махачкала, НАСРУТДИНОВА, 53Б	f	large
5849	32449	1042	республика Дагестан, Махачкала, НАСРУТДИНОВА, 61	f	large
5893	32492	1086	республика Дагестан, Махачкала, Н-КЯХУЛАЙ, МОУ48	f	large
5892	32491	1085	республика Дагестан, Махачкала, Н-КЯХУЛАЙ, МОУ 32	f	large
5809	32416	1002	республика Дагестан, Махачкала, Маяковского, 52	f	large
5808	32416	1001	республика Дагестан, Махачкала, Маяковского, 52	f	large
5910	32508	1103	республика Дагестан, Махачкала, Ляхова, 1	f	large
5923	32522	1116	республика Дагестан, Махачкала, Ломоносова, 13-а	f	large
5901	32500	1094	республика Дагестан, Махачкала, Ленина, 12	f	large
5898	32497	1091	республика Дагестан, Махачкала, Ленина, 16	f	large
5897	32496	1090	республика Дагестан, Махачкала, Ленина, 43	f	medium
5800	32409	993	республика Дагестан, Махачкала, Левина, 39	f	large
5799	32409	992	республика Дагестан, Махачкала, Левина, 39	f	large
5856	32455	1049	республика Дагестан, Махачкала, Лаптиева, 45 корпус 2	f	large
5855	32454	1048	республика Дагестан, Махачкала, Лаптиева, 45к1	f	large
5854	32453	1047	республика Дагестан, Махачкала, Лаптиева, 51	f	large
5857	32456	1050	республика Дагестан, Ленинский район, Махачкала, ЛАПТИЕВА, 28	f	large
5853	32452	1046	республика Дагестан, Махачкала, ЛАПТИЕВА, 59-А	f	large
5852	32452	1045	республика Дагестан, Махачкала, ЛАПТИЕВА, 59-А	f	large
5810	32417	1003	республика Дагестан, Махачкала, Л.Чайкиной, 30	f	large
5905	32504	1098	республика Дагестан, Махачкала, Коркмасова, 8	f	large
5811	32418	1004	республика Дагестан, Махачкала, Каммаева, 8	f	large
5822	32426	1015	республика Дагестан, Махачкала, Казбекова, 39А	t	large
5819	32424	1012	республика Дагестан, Махачкала, Казбекова, 153	t	large
5818	32424	1011	республика Дагестан, Махачкала, Казбекова, 153	t	large
5817	32423	1010	республика Дагестан, Махачкала, Казбекова, 155	t	large
5816	32421	1009	республика Дагестан, Махачкала, Казбекова, 39А	t	large
5821	32421	1014	республика Дагестан, Махачкала, Казбекова, 39А	t	large
5908	32506	1101	республика Дагестан, Махачкала, И.Казака, 1	f	medium
5907	32505	1100	республика Дагестан, Махачкала, И.Казака, 1	f	large
5875	32474	1068	республика Дагестан, Махачкала, И-Казака, 32Ак1	f	large
5876	32475	1069	республика Дагестан, Махачкала, И-КАЗАКА, 32А корпус 2	f	large
5870	32469	1063	республика Дагестан, Махачкала, И-КАЗАКА, 14 А	f	large
5903	32502	1096	республика Дагестан, Махачкала, Дзержинского, 21	f	large
5906	32502	1099	республика Дагестан, Махачкала, Дзержинского, 21	f	large
5909	32507	1102	республика Дагестан, Махачкала, Дахадаева, 90	f	large
5859	32458	1052	республика Дагестан, Ленинский район, Махачкала, Даниялова, 77	f	large
5896	32495	1089	республика Дагестан, Махачкала, Горького, 5	f	large
5873	32472	1066	республика Дагестан, Махачкала, Гамидова, 59В	f	large
5861	32460	1054	республика Дагестан, Махачкала, Гамидова, 10к1	f	large
5803	32412	996	республика Дагестан, Махачкала, Гаджиева, 170	f	large
5802	32411	995	республика Дагестан, Махачкала, Гаджиева, 162	f	large
5815	32420	1008	республика Дагестан, Кировский район, Махачкала, Гаджиева, 180	t	large
5814	32420	1007	республика Дагестан, Кировский район, Махачкала, Гаджиева, 180	f	large
5804	32413	997	республика Дагестан, Кировский район, Махачкала, Гаджиева, 174	f	large
5924	32523	1117	республика Дагестан, Махачкала, Гагарина, 54В	f	large
5920	32519	1113	республика Дагестан, Махачкала, Гагарина, 6 д.3	f	large
5919	32518	1112	республика Дагестан, Махачкала, Гагарина, 11-а	f	large
5885	32484	1078	республика Дагестан, Махачкала, Гагарина, 120	f	large
5884	32483	1077	республика Дагестан, Махачкала, Гагарина, 116	f	large
5882	32481	1075	республика Дагестан, Махачкала, Гагарина, 90	f	large
5881	32480	1074	республика Дагестан, Махачкала, Гагарина, 51	f	large
5921	32520	1114	республика Дагестан, Советский район, Махачкала, Гагарина, туп. 6	f	large
5862	32461	1055	республика Дагестан, Махачкала, ГАМИДОВА, 10 корпус 2	f	large
5879	32478	1072	республика Дагестан, Махачкала, ГАГАРИНА, 80А	f	large
5865	32464	1058	республика Дагестан, Махачкала, Г.Цадасы, 51	f	large
5925	32524	1118	республика Дагестан, Махачкала, Г. Омарова, 9 корп.1	f	large
5926	32525	1119	республика Дагестан, Советский район, Махачкала, Г. Омарова, 9к2	f	large
5798	32408	991	республика Дагестан, Махачкала, Буйнакского, 11	f	large
5858	32457	1051	республика Дагестан, Махачкала, Бейбулатова, 28	f	large
5904	32503	1097	республика Дагестан, Махачкала, Батырая, 4	f	large
5954	32552	1147	республика Дагестан, Махачкала, Акушинского 1-а , 5-а	f	large
5831	32433	1024	республика Дагестан, Махачкала, Акушинского, 94	t	large
5830	32432	1023	республика Дагестан, Махачкала, Акушинского, 98-Д	t	large
5829	32431	1022	республика Дагестан, Махачкала, Акушинского, 92-б	t	large
5828	32430	1021	республика Дагестан, Махачкала, Акушинского, 92-Б	t	large
5827	32429	1020	республика Дагестан, Махачкала, Акушинского, 90	t	large
5825	32428	1018	республика Дагестан, Махачкала, Акушинского, 86	t	large
5826	32428	1019	республика Дагестан, Махачкала, Акушинского, 86	t	large
5823	32427	1016	республика Дагестан, Махачкала, Акушинского, 7-линия	f	large
5824	32427	1017	республика Дагестан, Махачкала, Акушинского, 7-линия	f	large
5820	32425	1013	республика Дагестан, Махачкала, Акушинского, 26	t	large
5806	32414	999	республика Дагестан, Махачкала, Акушинского, 16	f	large
5805	32414	998	республика Дагестан, Махачкала, Акушинского, 16	f	large
5947	32545	1140	республика Дагестан, Махачкала, Айвазовского, 7	f	large
5945	32543	1138	республика Дагестан, Советский район, Махачкала, Агасиева, 5	f	large
5917	32515	1110	республика Дагестан, Махачкала, Абубакарова, 119	f	large
5902	32501	1095	республика Дагестан, Махачкала, Абубакарова, 8	f	large
5922	32521	1115	республика Дагестан, Махачкала, АКАЕВА, 13	f	large
5883	32482	1076	республика Дагестан, Махачкала, АКАЕВА, 69	f	large
5928	32527	1121	республика Дагестан, Махачкала, А-Султана, 30	f	large
5890	32489	1083	республика Дагестан, Махачкала, А-Султана, 1к2	f	large
5889	32488	1082	республика Дагестан, Махачкала, А-СУЛТАНА, 1 к1	f	large
5918	32517	1111	республика Дагестан, Советский район, Махачкала, А-Алиева, 44	f	large
5952	32550	1145	республика Дагестан, Махачкала, 6-магистральная, 3	f	large
5812	32419	1005	республика Дагестан, Махачкала, Громова, 6а	f	large
5813	32419	1006	республика Дагестан, Махачкала, Громова, 6а	f	large
5916	32514	1109	республика Дагестан, Махачкала, Аскерханова, 12	f	large
5927	32526	1120	республика Дагестан, Махачкала, А-Султана, 8-г	f	large
5615	32223	808	республика Дагестан, Кизляр, Циолковского, 6, Гимназия	f	large
5614	32222	807	республика Дагестан, Кизляр, Победы, ДК КЭМЗ	f	large
5613	32221	806	республика Дагестан, Кизляр, Победы, 93	f	large
5605	32213	798	республика Дагестан, Кизляр, Октябрьская, 47	f	large
5607	32215	800	республика Дагестан, Кизляр, Набережная, 44	f	large
5600	32208	793	республика Дагестан, Кизляр, Набережная, 1	f	large
5604	32212	797	республика Дагестан, Кизляр, Мичурина, 6	f	large
5611	32219	804	республика Дагестан, Кизляр, Махачкалинская, ЦГСЭН	f	large
5609	32217	802	республика Дагестан, Кизляр, Коммунистическая, 53	f	large
5601	32209	794	республика Дагестан, Кизляр, Коммунистическая, школа № 4	f	large
5608	32216	801	республика Дагестан, Кизляр, Грозненская, 103	f	large
5606	32214	799	республика Дагестан, Кизляр, Грозненская, 29	f	large
5603	32211	796	республика Дагестан, Кизляр, Горького, 4а	f	large
5610	32218	803	республика Дагестан, Кизляр, Герцена, 57	f	large
5602	32210	795	республика Дагестан, Кизляр, Багратиона, 23	f	large
5612	32220	805	республика Дагестан, Кизляр, 40 лет Дагестана, филиал ДГУ	f	large
5545	32153	738	республика Дагестан, Кизилюрт, Омара Чохского, 1	f	large
5528	32137	721	республика Дагестан, Кизилюрт, Молодёжная, 7	f	medium
5544	32152	737	республика Дагестан, Кизилюрт, Магомедгаджиева, 19	f	large
5532	32141	725	республика Дагестан, Кизилюрт, Ленина , 101А	f	medium
5541	32150	734	республика Дагестан, Кизилюрт, Заводская, 3	t	medium
5542	32150	735	республика Дагестан, Кизилюрт, Заводская, 3	t	large
5543	32151	736	республика Дагестан, Кизилюрт, Дахадаева, 28	f	large
5538	32147	731	республика Дагестан, Кизилюрт, Гамзата Цадаса, 80	f	large
5537	32146	730	республика Дагестан, Кизилюрт, Гамзата Цадаса, 73	f	large
5534	32143	727	республика Дагестан, Кизилюрт, Гамзата Цадаса, 40А	f	large
5531	32140	724	республика Дагестан, Кизилюрт, Гамзата Цадаса, 2А	f	large
5527	32136	720	республика Дагестан, Кизилюрт, Газимагомедова, 59А	f	large
5526	32135	719	республика Дагестан, Кизилюрт, Газимагомедова, 124	f	large
5540	32149	733	республика Дагестан, Кизилюрт, Гагарина, 40А	f	large
5539	32148	732	республика Дагестан, Кизилюрт, Гагарина, 74А	f	large
5536	32145	729	республика Дагестан, Кизилюрт, Гагарина, 54	f	large
5535	32144	728	республика Дагестан, Кизилюрт, Гагарина, 42 а	f	large
5533	32142	726	республика Дагестан, Кизилюрт, Гагарина, 40	f	large
5530	32139	723	республика Дагестан, Кизилюрт, Гагарина, 16	f	large
5529	32138	722	республика Дагестан, Кизилюрт, Вишневского, 9	f	large
5525	32134	718	республика Дагестан, Кизилюрт, Алиева, 92	f	large
5464	32083	657	республика Дагестан, Каспийск, Аэропорт Махачкала	t	small
5449	32068	642	республика Дагестан, Каспийск, ПО. Кирпичный завод, МОУ№5	f	large
5445	32064	638	республика Дагестан, Каспийск, А-АЛИЕВА, МЕД. УЧИЛИЩЕ	f	large
5446	32065	639	республика Дагестан, Каспийск, Хизроева, Дом культуры	f	large
5450	32069	643	республика Дагестан, Каспийск, ХАЛИЛОВА	f	large
5443	32062	636	республика Дагестан, Каспийск, ХАЛИЛОВА, 7	f	large
5460	32079	653	республика Дагестан, Каспийск, ТРУДОВАЯ, 13	f	large
5447	32066	640	республика Дагестан, Каспийск, Орджоникидзе, 8	f	large
5448	32067	641	республика Дагестан, Каспийск, ОРДЖОНИКИДЗЕ, 3	f	large
5452	32000	645	республика Дагестан, Каспийск, ОРДЖОНИКИДЗЕ, 16	f	large
5459	32078	652	республика Дагестан, Каспийск, ОКТЯБРЬСКАЯ, ГОУ ОБЩЕОБРАЗОВАТЕЛЬНАЯ ШК.-ИН.№2	f	large
5453	32072	646	республика Дагестан, Каспийск, Назарова, 3	f	large
5451	32070	644	республика Дагестан, Каспийск, Мира, 7	f	large
5458	32077	651	республика Дагестан, Каспийск, МАТРОСОВА, 3	f	large
5456	32075	649	республика Дагестан, Каспийск, Ленина, МОУ КАДЕТСКАЯ МОРСКАЯ Ш-И	f	large
5444	32063	637	республика Дагестан, Каспийск, Ленина, 74	f	large
5462	32081	655	республика Дагестан, Каспийск, Дахадаева, 58	f	large
5461	32080	654	республика Дагестан, Каспийск, Гамзатова, 35	f	large
5463	32082	656	республика Дагестан, Каспийск, Буйнакского, 100А	f	large
5455	32074	648	республика Дагестан, Каспийск, АЛФЕРОВА, 4	f	large
5454	32073	647	республика Дагестан, Каспийск, АЛФЕРОВА, ЛИЦЕЙ№1	f	large
5457	32076	650	республика Дагестан, Каспийск, АБДУЛМАНАПОВА, 10	f	large
5337	31941	530	республика Дагестан, Избербаш, пр.Ленина, 6, Здание СШ №10	f	large
5335	31954	528	республика Дагестан, Избербаш, пл.Ленина, 2, Здание ГДК	f	large
5334	31953	527	республика Дагестан, Избербаш, Шевченко, 2, Административное здание Педколледжа	f	large
5342	31960	535	республика Дагестан, Избербаш, Свободы, 10, Здание СШ №1	f	large
5340	31958	533	республика Дагестан, Избербаш, Октябрьская, 2А, Горпромкомбмнат им.И.Шамиля	f	large
5330	31949	523	республика Дагестан, Избербаш, Нефтяников, 1, Здание института Финансов и права	f	large
5338	31956	531	республика Дагестан, Избербаш, Маяковского, 119, Здание СШ №11	f	large
5336	31955	529	республика Дагестан, Избербаш, Дербентская, 4, Административное здание Избербашгаз	f	large
5333	31952	526	республика Дагестан, Избербаш, Гамидова, 14, Узел почтовой связи	f	large
5331	31950	524	республика Дагестан, Избербаш, Гамидова, 7, Здание СШ №2	f	large
5339	31957	532	республика Дагестан, Избербаш, Буйнакского, 111, общежитие Радиозавода	f	large
5332	31951	525	республика Дагестан, Избербаш, Буйнакского, 30, административное здание ИГЭС	f	large
5341	31959	534	республика Дагестан, Избербаш, Абубакарова, 4, Здание ПУ	f	large
5344	31962	537	республика Дагестан, Избербаш, Геолога Брода, 12/2	f	large
5343	31961	536	республика Дагестан, Избербаш, Геолога Брода, 29, Здание СШ №12	f	large
5318	31936	511	республика Дагестан, Дербент, Здание СОШ №17	f	large
5304	31923	497	республика Дагестан, Дербент	f	large
5301	31920	494	республика Дагестан, Дербент, Здание СОШ №20	f	large
5303	31922	496	республика Дагестан, Дербент, Шахбазова, 63	f	large
5316	31934	509	республика Дагестан, Дербент, Х.Тагиева, 35	f	large
5300	31919	493	республика Дагестан, Дербент городской округ, Советская, 41	f	large
5310	31928	503	республика Дагестан, Дербент, Свердлова, 8	f	large
5319	31937	512	республика Дагестан, Дербент, Сальмана, 38	f	large
5294	31913	487	республика Дагестан, Дербент, Сальмана, 48	f	large
5314	31932	507	республика Дагестан, Дербент, С.Габиева, 20	f	large
5317	31935	510	республика Дагестан, Дербент, Приморская, 42	f	large
5305	31924	498	республика Дагестан, Дербент, Оскара, 26	f	large
5315	31933	508	республика Дагестан, Дербент, Новокарьерная, 2	f	large
5284	31903	477	республика Дагестан, Дербент, Маскина, 55	f	large
5296	31915	489	республика Дагестан, Дербент, Ленина, 66	f	large
5295	31914	488	республика Дагестан, Дербент, Ленина, 103	f	large
5291	31910	484	республика Дагестан, Дербент, Ленина, 35	f	large
5286	31905	479	республика Дагестан, Дербент, Ленина, 2	f	large
5299	31918	492	республика Дагестан, Дербент, Крупской, 20	f	large
5298	31917	491	республика Дагестан, Дербент, Крупской, 4	f	large
5293	31912	486	республика Дагестан, Дербент, Красноармейский, 56	f	large
5302	31921	495	республика Дагестан, Дербент, Гоголя, 2А	f	large
5312	31930	505	республика Дагестан, Дербент, Генриха Гасанова, 10	f	large
5287	31906	480	республика Дагестан, Дербент, Вокзальная, 54	f	large
5292	31911	485	республика Дагестан, Дербент, Буйнакского, 51	f	large
5309	31927	502	республика Дагестан, Дербент, 345 ДСД, 6	f	large
5307	31925	500	республика Дагестан, Дербент, 345 ДСД, 8	f	large
5306	31925	499	республика Дагестан, Дербент, 345 ДСД, 8	f	large
5290	31909	483	республика Дагестан, Дербент, 3 Интернационала, 2	f	large
5297	31916	490	республика Дагестан, Дербент городской округ, площадь Свободы, 18	f	large
5179	31796	372	республика Дагестан, Дагестанские Огни, Кирова, 21	f	large
5184	31801	377	республика Дагестан, Дагестанские Огни, Аллея Дружбы, 13	f	large
5175	31792	368	республика Дагестан, поселок Дагестанские Огни, Революции, 9	f	large
5177	31794	370	республика Дагестан, поселок Дагестанские Огни, Некрасова, 3а	f	large
5182	31799	375	республика Дагестан, поселок Дагестанские Огни, М.Горького, 6	f	large
5180	31797	373	республика Дагестан, поселок Дагестанские Огни, Лермонтова, 35	f	large
5178	31795	371	республика Дагестан, поселок Дагестанские Огни, Леваневского переулок, 2а	f	large
5183	31800	376	республика Дагестан, поселок Дагестанские Огни, Козленко, 26	f	large
5176	31793	369	республика Дагестан, поселок Дагестанские Огни, Кирова площадь, 1	f	large
5185	31802	378	республика Дагестан, поселок городского типа Дагестанские Огни, Школьная, 67	f	large
5181	31798	374	республика Дагестан, поселок городского типа Дагестанские Огни, М.Гаджиева, 45 а	f	large
5072	31691	265	республика Дагестан, Буйнакск, СОШ №10	f	large
5068	31687	261	республика Дагестан, Буйнакск, Жил Массив Западный, СОШ №6	f	large
5076	31695	269	республика Дагестан, Буйнакск, Ярагского, 2А	f	large
5056	31679	249	республика Дагестан, Буйнакск, Шамхалова, 3	f	large
5063	31551	256	республика Дагестан, Буйнакск, Чкалова, 7	f	large
5070	31689	263	республика Дагестан, Буйнакск, Циалковского, 13	f	large
5069	31688	262	республика Дагестан, Буйнакск, Хизроева, 57	f	large
5067	31671	260	республика Дагестан, Буйнакск, Хизроева, 18	f	large
5057	31680	250	республика Дагестан, Буйнакск, Фрунзе, 2	f	large
5058	31681	251	республика Дагестан, Буйнакск, Салаватова, 56	f	large
5074	31693	267	республика Дагестан, Буйнакск, Мр. Дружба, СОШ №9	f	large
5071	31690	264	республика Дагестан, Буйнакск, Ленина, 62	f	large
5061	31684	254	республика Дагестан, Буйнакск, Ленина, 6	f	large
5066	31627	259	республика Дагестан, Буйнакск, Ленина, 51	f	large
5065	31610	258	республика Дагестан, Буйнакск, Ленина, 42	f	large
5073	31692	266	республика Дагестан, Буйнакск, Имама Шамиля, 134	f	large
5059	31682	252	республика Дагестан, Буйнакск, Имама Газимагомеда, 46	f	large
5060	31683	253	республика Дагестан, Буйнакск, Дж. Казикумухского, 84	f	large
5064	31567	257	республика Дагестан, Буйнакск, Буйнакского, 29	f	large
5062	31685	255	республика Дагестан, Буйнакск, Аскерханова, 18	f	large
5075	31694	268	республика Дагестан, Буйнакск, Гамзата Цадаса, 32	f	large
5370	31989	563	республика Дагестан	t	small
6703	33271	1896	республика Дагестан, Шамильский район, село Цекоб	t	small
6702	33270	1895	республика Дагестан, Шамильский район, село Хучада	t	small
6700	33268	1893	республика Дагестан, Шамильский район, село Хотода	t	medium
6701	33269	1894	республика Дагестан, Шамильский район, село Хорода	t	small
6699	33267	1892	республика Дагестан, Шамильский район, село Хонох	t	small
6698	33266	1891	республика Дагестан, Шамильский район, село Хебда	f	large
6697	33265	1890	республика Дагестан, Шамильский район, село Урчух	t	small
6696	33264	1889	республика Дагестан, Шамильский район, село Уриб	t	medium
6695	33263	1888	республика Дагестан, Шамильский район, село Урада	t	medium
6693	33261	1886	республика Дагестан, Шамильский район, село Тлях	t	small
6692	33260	1885	республика Дагестан, Шамильский район, село Тлянуб	t	small
6691	33259	1884	республика Дагестан, Шамильский район, село Тидиб	t	medium
6690	33258	1883	республика Дагестан, Шамильский район, село Телетль	f	large
6689	33257	1882	республика Дагестан, Шамильский район, село Сомода	t	small
6688	33256	1881	республика Дагестан, Шамильский район, село Ругельда	t	small
6687	33255	1880	республика Дагестан, Шамильский район, село Ругельда	t	small
6686	33254	1879	республика Дагестан, Шамильский район, село Ратлуб	t	small
6683	33251	1876	республика Дагестан, Шамильский район, село Нитаб	t	small
6684	33252	1877	республика Дагестан, Шамильский район, село Нижний Батлух	f	large
6682	33250	1875	республика Дагестан, Шамильский район, село Накитль	t	small
6681	33249	1874	республика Дагестан, Шамильский район, село Мусрух	t	small
6680	33248	1873	республика Дагестан, Шамильский район, село Могох	t	small
6679	33247	1872	республика Дагестан, Шамильский район, село Митлиуриб	t	small
6678	33246	1871	республика Дагестан, Шамильский район, село Мачада	t	small
6677	33245	1870	республика Дагестан, Шамильский район, село Куаниб	t	small
6675	33243	1868	республика Дагестан, Шамильский район, село Кахиб	t	medium
6674	33242	1867	республика Дагестан, Шамильский район, село Зиуриб	t	small
6673	33241	1866	республика Дагестан, Шамильский район, село Заната	t	small
6672	33240	1865	республика Дагестан, Шамильский район, село Датуна	t	small
6671	33239	1864	республика Дагестан, Шамильский район, село Дагбаш	t	small
6670	33238	1863	республика Дагестан, Шамильский район, село Гоор-Хиндах	t	small
6669	33237	1862	республика Дагестан, Шамильский район, село Гоор	t	small
6668	33236	1861	республика Дагестан, Шамильский район, село Голотль	f	large
6667	33235	1860	республика Дагестан, Шамильский район, село Гоготль	t	small
6666	33234	1859	республика Дагестан, Шамильский район, село Гента	t	small
6665	33233	1858	республика Дагестан, Шамильский район, Геницориб	t	small
6694	33262	1887	республика Дагестан, Шамильский район, село Верхний Тогох	t	small
6664	33232	1857	республика Дагестан, Шамильский район, село Верхний Колоб	t	small
6663	33231	1856	республика Дагестан, Шамильский район, село Верхний Батлух	t	small
6661	33229	1854	республика Дагестан, Шамильский район, село Асаб	t	medium
6660	33228	1853	республика Дагестан, Шамильский район, село Андых	t	medium
6653	33221	1846	республика Дагестан, Чародинский район, село Шалиб	t	small
6642	33211	1835	республика Дагестан, Чародинский район, село Чуниб	t	small
6631	33200	1824	республика Дагестан, Чародинский район, село Читаб	t	small
6245	32841	1438	республика Дагестан, Чародинский район, село Чильдаб	t	small
6630	33199	1823	республика Дагестан, Чародинский район, село Чвадаб	t	small
6657	33225	1850	республика Дагестан, Чародинский район, село Чарода	t	small
6652	33220	1845	республика Дагестан, Чародинский район, село Чарода	t	small
6648	33216	1841	республика Дагестан, Чародинский район, село Цуриб	f	large
6645	33213	1838	республика Дагестан, Чародинский район, село Цулда	t	small
6637	33206	1830	республика Дагестан, Чародинский район, село Ценеб	t	small
6616	33184	1809	республика Дагестан, Чародинский район, село Цемер	f	small
6641	33210	1834	республика Дагестан, Чародинский район, село Хурух	t	small
6613	33181	1806	республика Дагестан, Чародинский район, село Хитаб	t	small
6633	33202	1826	республика Дагестан, Чародинский район, село Хинуб	t	small
6611	33179	1804	республика Дагестан, Чародинский район, село Хилих	t	small
6646	33214	1839	республика Дагестан, Чародинский район, село Утлух, сельсовет Суметинский	t	small
6625	33193	1818	республика Дагестан, Чародинский район, село Тлярош	t	small
6617	33185	1810	республика Дагестан, Чародинский район, село Тляробазутль, сельсовет Гилибский	t	small
6624	33192	1817	республика Дагестан, Чародинский район, село Талух	t	small
6644	33212	1837	республика Дагестан, Чародинский район, село Сумета	t	small
6649	33217	1842	республика Дагестан, Чародинский район, село Содаб	t	small
6627	33195	1820	республика Дагестан, Чародинский район, Село Урух-сота, сельсовет Гочобский 	t	small
6647	33215	1840	республика Дагестан, Чародинский район, село Сачада	t	small
6621	33189	1814	республика Дагестан, Чародинский район, село Ритляб	t	small
6634	33203	1827	республика Дагестан, Чародинский район, село Нукуш	t	small
6638	33207	1831	республика Дагестан, Чародинский район, село Мукутль	t	small
6656	33224	1849	республика Дагестан, Чародинский район, село Мугурух	t	small
6643	33196	1836	республика Дагестан, Чародинский район, село Мугурух	t	small
6650	33218	1843	республика Дагестан, Чародинский район, село Мощоб	t	small
6636	33205	1829	республика Дагестан, Чародинский район, село Магар	t	small
6640	33209	1833	республика Дагестан, Чародинский район, село Кучраб, сельсовет Магарский	t	small
6615	33183	1808	республика Дагестан, Чародинский район, село Кутих	t	small
6609	33177	1802	республика Дагестан, Чародинский район, село Кубатль	t	small
6629	33198	1822	республика Дагестан, Чародинский район, село Косрода	t	small
6612	33180	1805	республика Дагестан, Чародинский район, село Кесериб	t	small
6619	33187	1812	республика Дагестан, Чародинский район, село Карануб	t	small
6632	33201	1825	республика Дагестан, Чародинский район, село Ириб	t	small
6658	33226	1851	республика Дагестан, Чародинский район, село Дусрах, сельсовет Дусрахский, кутан Шамильский	t	small
6628	33197	1821	республика Дагестан, Чародинский район, село Дусрах	t	small
6618	33186	1811	республика Дагестан, Чародинский район, село Доронуб	t	small
6623	33191	1816	республика Дагестан, Чародинский район, Гунух - Мурух	t	small
6626	33194	1819	республика Дагестан, Чародинский район, село Гочоб	t	small
6622	33190	1815	республика Дагестан, Чародинский район, село Гочада	t	small
6620	33188	1813	республика Дагестан, Чародинский район, село Гоаб	t	small
6659	33227	1852	республика Дагестан, Чародинский район, село Гилиб, сельсовет Гилибский	t	small
6614	33182	1807	республика Дагестан, Чародинский район, село Гилиб	t	small
6651	33219	1844	республика Дагестан, Чародинский район, село Гидиб	t	small
6639	33208	1832	республика Дагестан, Чародинский район, село Багинуб	t	small
6608	33176	1801	республика Дагестан, Чародинский район, село Арчиб	t	small
6610	33178	1803	республика Дагестан, Чародинский район, село Алчуниб	t	small
6590	33164	1783	республика Дагестан, Цунтинский район, с.Мекали	t	small
6581	33155	1774	республика Дагестан, Цунтинский район, с.Азильта	t	small
6561	33135	1754	республика Дагестан, Цунтинский район, село Эльбок	t	small
6580	33154	1773	республика Дагестан, Цунтинский район, село Шаури	t	small
6566	33140	1759	республика Дагестан, Цунтинский район, село Шапих, здание школы	t	small
6593	33167	1786	республика Дагестан, Цунтинский район, село Шаитли	t	small
6578	33152	1771	республика Дагестан, Цунтинский район, село Чатли	t	small
6569	33143	1762	республика Дагестан, Цунтинский район, село Чалях	t	small
6568	33142	1761	республика Дагестан, Цунтинский район, село Цутрах	t	small
6577	33151	1770	республика Дагестан, Цунтинский район, село Цохок	t	small
6584	33158	1777	республика Дагестан, Цунтинский район, село Цибари	t	small
6586	33160	1779	республика Дагестан, Цунтинский район, село Цехок	t	small
6565	33139	1758	республика Дагестан, Цунтинский район, село Хупри, здание школы	t	small
6564	33138	1757	республика Дагестан, Цунтинский район, село Хупри, здание школы	t	small
6562	33136	1755	республика Дагестан, Цунтинский район, село Хибиятль, здание школы	t	small
6587	33161	1780	республика Дагестан, Цунтинский район, село Хетох	t	small
6582	33156	1775	республика Дагестан, Цунтинский район, село Хебатли	t	small
25658	90641	36	Ставропольский край, Ставрополь, Серова, 278	f	medium
6592	33166	1785	республика Дагестан, Цунтинский район, село Хамаитли	t	small
6576	33150	1769	республика Дагестан, Цунтинский район, село Удок	t	small
6589	33163	1782	республика Дагестан, Цунтинский район, село Тляцуда	t	small
6574	33148	1767	республика Дагестан, Цунтинский район, село Терутли	t	small
6585	33159	1778	республика Дагестан, Цунтинский район, Село Берих	t	small
6591	33165	1784	республика Дагестан, Цунтинский район, село Сагада	t	small
6571	33145	1764	республика Дагестан, Цунтинский район, село Ретлоб	t	small
6583	33157	1776	республика Дагестан, Цунтинский район, село Мокок	t	small
6575	33149	1768	республика Дагестан, Цунтинский район, село Махалотли	t	small
6595	33169	1788	республика Дагестан, Цунтинский район, село Китури	t	small
6567	33141	1760	республика Дагестан, Цунтинский район, село Китлярта	t	small
6570	33144	1763	республика Дагестан, Цунтинский район, село Кимятли	t	small
6558	33132	1751	республика Дагестан, Цунтинский район, село Кидеро, здание школы	t	small
6605	33175	1798	республика Дагестан, Цунтинский район, село Качалайский	t	medium
6607	33175	1800	республика Дагестан, Цунтинский район, село Качалайский	t	small
6606	33175	1799	республика Дагестан, Цунтинский район, село Качалайский	t	medium
6572	33146	1765	республика Дагестан, Цунтинский район, село Ицирах	t	small
6559	33133	1752	республика Дагестан, Цунтинский район, село Зехида, здание школы	t	small
6560	33134	1753	республика Дагестан, Цунтинский район, село Гутатли, здание школы	t	small
6557	33131	1750	республика Дагестан, Цунтинский район, село Генух, здание школы	t	small
6594	33168	1787	республика Дагестан, Цунтинский район, село Гениятль	t	small
6563	33137	1756	республика Дагестан, Цунтинский район, село Вициятль, здание школы	t	small
6599	33171	1792	республика Дагестан, Цунтинский район, Бежта	f	medium
6598	33171	1791	республика Дагестан, Цунтинский район, Бежта	f	medium
6597	33171	1790	республика Дагестан, Цунтинский район, Бежта	f	large
6596	33170	1789	республика Дагестан, Цунтинский район, Ачи-Чунгур	t	small
6579	33153	1772	республика Дагестан, Цунтинский район, село Акды	t	small
6535	33108	1728	республика Дагестан, Цумадинский район, село Эчеда, школа	t	\N
6529	33101	1722	республика Дагестан, Цумадинский район, село Эгдада , администрация	t	\N
6531	33103	1724	республика Дагестан, Цумадинский район, село Цумада-Урух, школа	t	\N
6550	33124	1743	республика Дагестан, Цумадинский район, село Цумада, школа	t	\N
6530	33102	1723	республика Дагестан, Цумадинский район, село Цумада, школа	t	\N
6527	33099	1720	республика Дагестан, Цумадинский район, село Цедатли, школа	t	\N
6511	33082	1704	республика Дагестан, Цумадинский район, село Хуштада, редакция	t	\N
6510	33081	1703	республика Дагестан, Цумадинский район, село Хуштада, администрация	t	\N
6548	33121	1741	республика Дагестан, Цумадинский район, село Хушет, администрация	t	\N
6544	33117	1737	Россия, республика Дагестан, Цумадинский район, село Хонох	t	\N
6543	33116	1736	Россия, республика Дагестан, Цумадинский район, село Хварши	t	\N
6536	33109	1729	Россия, республика Дагестан, Цумадинский район, село Хвайни	t	\N
6556	33130	1749	республика Дагестан, Цумадинский район, село Ургалай, школа	t	\N
6509	33080	1702	республика Дагестан, Цумадинский район, село Тлондода, клуб	t	\N
6513	33084	1706	республика Дагестан, Цумадинский район, село Тленхора, вет.лечебница	t	\N
6521	33093	1714	республика Дагестан, Цумадинский район, село Тисси-Ахитли, школа	t	\N
6551	33125	1744	республика Дагестан, Цумадинский район, село Тисси, школа	t	\N
6514	33085	1707	республика Дагестан, Цумадинский район, село Тисси, школа	t	\N
6552	33126	1745	республика Дагестан, Цумадинский район, село Тинди, школа	t	\N
6516	33087	1709	республика Дагестан, Цумадинский район, село Тинди, спортзал	t	\N
6515	33086	1708	республика Дагестан, Цумадинский район, село Тинди, школа	t	\N
6518	33089	1711	республика Дагестан, Цумадинский район, село Тенли, школа	t	\N
6538	33111	1731	республика Дагестан, Цумадинский район, село Сильди, школа	t	\N
6553	33127	1746	республика Дагестан, Цумадинский район, село Саситли, школа	t	\N
6533	33105	1726	Россия, республика Дагестан, Цумадинский район, село Саситли	t	\N
6541	33114	1734	республика Дагестан, Цумадинский район, село Сантлада, школа	t	\N
6532	33104	1725	республика Дагестан, Цумадинский район, село Ричаганих, школа	t	\N
6512	33083	1705	республика Дагестан, Цумадинский район, село Ново-Хуштада, школа	t	\N
6546	33119	1739	республика Дагестан, Цумадинский район, село Нижние Хваршини, администрация	t	\N
6526	33098	1719	Россия, республика Дагестан, Цумадинский район, село Нижние Гаквари	t	\N
6545	33118	1738	республика Дагестан, Цумадинский район, село Метрада, администрация	t	\N
6503	33074	1696	республика Дагестан, Цумадинский район, село Маштихи , школа	f	\N
6505	33076	1698	Россия, республика Дагестан, Цумадинский район, село Кочали	t	\N
6504	33075	1697	республика Дагестан, Цумадинский район, село Колих, гостиница	t	\N
6554	33128	1747	республика Дагестан, Цумадинский район, село Кеди, школа	t	\N
6534	33107	1727	республика Дагестан, Цумадинский район, село Кеди, школа	t	\N
6542	33115	1735	республика Дагестан, Цумадинский район, село Квантлада, школа	t	\N
6507	33078	1700	республика Дагестан, Цумадинский район, село Кванада, администрация	t	\N
6540	33113	1733	республика Дагестан, Цумадинский район, село Инхоквари, администрация	t	\N
6539	33112	1732	республика Дагестан, Цумадинский район, село Инхоквари, школа	t	\N
6508	33079	1701	Россия, республика Дагестан, Цумадинский район, село Гимерсо	t	\N
6506	33077	1699	республика Дагестан, Цумадинский район, село Гигих, клуб	t	\N
6524	33096	1717	республика Дагестан, Цумадинский район, село Гигатль, школа	t	\N
6549	33123	1742	республика Дагестан, Цумадинский район, село Гигатли-Урух, школа	t	\N
6525	33097	1718	республика Дагестан, Цумадинский район, село Гигатли-Урух, школа	t	\N
6519	33091	1712	республика Дагестан, Цумадинский район, село Гвинайчи , школа	t	\N
6523	33095	1716	Россия, республика Дагестан, Цумадинский район, село Гачитли	t	\N
6537	33110	1730	республика Дагестан, Цумадинский район, село Гакко, школа	t	\N
6555	33129	1748	Россия, республика Дагестан, Цумадинский район, село Гадири	t	\N
6522	33094	1715	Россия, республика Дагестан, Цумадинский район, село Гадири	t	\N
6517	33088	1710	республика Дагестан, Цумадинский район, село Гадаичи, школа	t	\N
6547	33120	1740	республика Дагестан, Цумадинский район, село Верхние Хваршини, школа	t	\N
6528	33100	1721	республика Дагестан, Цумадинский район, село Верхние Гаквари, школа	t	\N
6520	33092	1713	республика Дагестан, Цумадинский район, село Акнада, школа	t	\N
6502	33073	1695	республика Дагестан, Цумадинский район, село Агвали, школа	f	\N
6487	33058	1680	республика Дагестан, Хунзахский район, кутан СПК Тлайлухский, здание НШ	f	small
6473	33044	1666	республика Дагестан, Хунзахский район, село Эбута, здание НШ	f	small
6480	33051	1673	республика Дагестан, Хунзахский район, село Шотода, здание с/адм	f	small
6486	33057	1679	республика Дагестан, Хунзахский район, село Цельмес, здание СДК 	f	small
6478	33049	1671	республика Дагестан, Хунзахский район, село Цалкита, СДК	f	small
6446	33017	1639	республика Дагестан, Хунзахский район, село Хунзах, здание РДНТ	f	large
6450	33021	1643	республика Дагестан, Хунзахский район, село Хини, здание НШ	f	small
6496	33067	1689	республика Дагестан, Хунзахский район, село Хиндах, здание с/адм	f	small
6477	33048	1670	республика Дагестан, Хунзахский район, село Химакоро	f	small
6474	33045	1667	республика Дагестан, Хунзахский район, село Хачта, здание СПК	f	small
6458	33029	1651	республика Дагестан, Хунзахский район, село Хариколо, здание СДК	f	small
6493	33064	1686	республика Дагестан, Хунзахский район, село Харахи, здание НШ	f	small
6492	33063	1685	республика Дагестан, Хунзахский район, село Харахи, здание СДК	t	medium
6466	33037	1659	республика Дагестан, Хунзахский район, село Уздалросо	f	small
6485	33056	1678	республика Дагестан, Хунзахский район, село Тлайлух, здание СДК	f	small
6472	33043	1665	республика Дагестан, Хунзахский район, село Тануси, здание с/адм	f	small
6500	33071	1693	республика Дагестан, Хунзахский район, село Тадколо, здание НШ	f	small
6467	33038	1660	республика Дагестан, Хунзахский район, село Тагада, здание с/библиотеки	f	small
6482	33053	1675	республика Дагестан, Хунзахский район, село Сиух	f	small
6481	33052	1674	республика Дагестан, Хунзахский район, село Сиух, здание сельской администрации	f	small
26692	91647	1071	Ставропольский край, Пятигорск, Калинина, 50	f	large
6499	33070	1692	республика Дагестан, Хунзахский район, село Очло, здание СДК	f	small
6494	33065	1687	республика Дагестан, Хунзахский район, село Орота, здание СДК 	t	medium
6463	33034	1656	республика Дагестан, Хунзахский район, село Оркачи, здание с/адм	f	small
6484	33055	1677	республика Дагестан, Хунзахский район, Ондокоро, здание СПК	f	small
6469	33040	1662	республика Дагестан, Хунзахский район, село Обода, здание СДК 	t	medium
6452	33023	1645	республика Дагестан, Хунзахский район, село Накитль, здание НШ	f	small
6488	33059	1681	республика Дагестан, Хунзахский район, село Мушули, здание СДК	f	small
6498	33069	1691	республика Дагестан, Хунзахский район, село Мочох, здание СДК	f	small
6465	33036	1658	республика Дагестан, Хунзахский район, село Малый Гоцатль, здание СДК	f	small
6491	33062	1684	республика Дагестан, Хунзахский район, село Малая Амуша, здание с/библиотеки 	f	small
6497	33068	1690	республика Дагестан, Хунзахский район, село Коло, здание СДК	f	small
6468	33039	1661	республика Дагестан, Хунзахский район, село Кахикал, здание СДК	f	small
6460	33031	1653	республика Дагестан, Хунзахский район, село Ках, здание СДК	f	small
6451	33022	1644	республика Дагестан, Хунзахский район, село Заиб, здание ОШ	f	small
6470	33041	1663	республика Дагестан, Хунзахский район, село Гортколо, здание НШ	f	small
6449	33020	1642	республика Дагестан, Хунзахский район, село Гонох, здание НШ	f	small
6448	33019	1641	республика Дагестан, Хунзахский район, село Геничутль	f	small
6475	33046	1668	республика Дагестан, Хунзахский район, село Гацалух, здание СДК	f	small
6462	33033	1655	республика Дагестан, Хунзахский район, село Буцра, здание СОШ	f	small
6461	33032	1654	республика Дагестан, Хунзахский район, село Буцра, здание СДК	t	medium
6464	33035	1657	республика Дагестан, Хунзахский район, село Большой Гоцатль, здание СДК	f	large
6456	33027	1649	республика Дагестан, Хунзахский район, село Батлаич, здание СДК	t	medium
6447	33018	1640	республика Дагестан, Хунзахский район, село Баитль, здание НШ	f	small
6479	33050	1672	республика Дагестан, Хунзахский район, село Ахтини, здание СПК	f	small
6476	33047	1669	республика Дагестан, Хунзахский район, село Ахалчи, здание СДК	f	small
6455	33026	1648	республика Дагестан, Хунзахский район, село Арани, здание сельской администрации	t	medium
6457	33028	1650	республика Дагестан, Хунзахский район, село Арада	f	small
6490	33061	1683	республика Дагестан, Хунзахский район, село Амущи, здание с/адм	t	medium
6483	33054	1676	республика Дагестан, Хунзахский район, село Амишти, здание сельской администрации	f	small
6445	33016	1638	республика Дагестан, Хивский район, село Юхари-Ярак, Сельский дом культуры	t	small
6418	31970	1611	республика Дагестан, Хивский район, село Юхари-Захит, Зд. админ &quot;&quot;с/с Захитский&quot;&quot;&quot;	t	medium
6444	33015	1637	республика Дагестан, Хивский район, село Юхари-Архит	t	small
6442	33013	1635	республика Дагестан, Хивский район, село Чувек, Сельский дом культуры	t	small
6441	33012	1634	республика Дагестан, Хивский район, село Чиликар, Сельский дом культуры	t	small
6440	33011	1633	республика Дагестан, Хивский район, село Чере, Общеобразовательная школа	t	small
6439	33010	1632	республика Дагестан, Хивский район, село Цудук, Общеобразовательная школа	t	small
6438	32289	1631	республика Дагестан, Хивский район, село Цнал, Сельский дом культуры	t	small
6437	33009	1630	республика Дагестан, Хивский район, село Цлак, Сельская библиотека	t	small
6435	33007	1628	республика Дагестан, Хивский район, село Хоредж, Спортзал средней школы	t	medium
6434	33006	1627	республика Дагестан, Хивский район, село Хив, Спортзал ДЮСШ	f	large
6443	33014	1636	республика Дагестан, Хивский район, село Фурдаг, Сельский дом культуры	t	small
6433	33005	1626	республика Дагестан, Хивский район, село Уртиль	t	small
6432	33004	1625	республика Дагестан, Хивский район, село Урга, Общеобразовательная школа	t	small
6428	33000	1621	республика Дагестан, Хивский район, село Межгюль, Средняя школа село Межгюль	t	medium
6427	32999	1620	республика Дагестан, Хивский район, село Ляхля, Здан.адм. мо сельсовет Ляхлинский	t	small
6426	32998	1619	республика Дагестан, Хивский район, село Лака	t	small
6425	32997	1618	республика Дагестан, Хивский район, Куштиль, Сельский дом культуры	t	medium
6424	32996	1617	республика Дагестан, Хивский район, село Куг, здание администрации МО село Куг	t	medium
6423	32995	1616	республика Дагестан, Хивский район, село Кувиг	t	small
6422	32994	1615	республика Дагестан, Хивский район, село Кошкент, Сельский дом культуры	t	small
6421	32993	1614	республика Дагестан, Хивский район, село Конциль, Сельский дом культуры	t	small
6420	32992	1613	республика Дагестан, Хивский район, село Конди, СДК	t	medium
6419	32991	1612	республика Дагестан, Хивский район, село Зильдик, Сельский дом культуры	t	small
6417	31594	1610	республика Дагестан, Хивский район, село Дардакент, Сельский клуб	t	small
6416	31436	1609	республика Дагестан, Хивский район, село Вертиль, сельская библиотека	t	small
6436	33008	1629	республика Дагестан, Хивский район, село Ашага-Цинит, Средняя общеобразовательная школа	t	medium
6414	32989	1607	республика Дагестан, Хивский район, село Ашага-Архит, Сельский дом культуры	t	medium
6411	32986	1604	республика Дагестан, Хивский район, село Атрик, Сельский дом культуры	t	small
6413	32988	1606	республика Дагестан, Хивский район, село Асакент, Начальная школа	t	small
6412	32987	1605	республика Дагестан, Хивский район, село Арчуг, Начальная школа	t	small
6369	32962	1562	республика Дагестан, Хасавюртовский район, село Эндирей, Здание школы №2	t	medium
6368	32961	1561	республика Дагестан, Хасавюртовский район, село Эндирей, Здание школы №1	f	large
6367	32960	1560	республика Дагестан, Хасавюртовский район, село Эндирей, Здание дома культуры	f	large
6340	32936	1533	республика Дагестан, Хасавюртовский район, село Шагада, Здание школы	t	medium
6318	32914	1511	республика Дагестан, Хасавюртовский район, село Чагаротар, Здание школы 	f	large
6335	32931	1528	республика Дагестан, Хасавюртовский район, село Цияб Ичичали, Здание дома культуры	f	large
6323	32919	1516	республика Дагестан, Хасавюртовский район, село Хамавюрт, Здание дома культуры 	f	large
6328	32924	1521	республика Дагестан, Хасавюртовский район, село Тукита, Здание дома культуры	t	medium
6307	32904	1500	республика Дагестан, Хасавюртовский район, село Теречное, Здание дома культуры	f	large
6361	32955	1554	республика Дагестан, Хасавюртовский район, село Темир-Аул, Здание школы	f	large
6362	32955	1555	республика Дагестан, Хасавюртовский район, село Темир-Аул, Здание школы	t	small
6341	32937	1534	республика Дагестан, Хасавюртовский район, село Сулевкент, Здание дома культуры	f	large
6327	32923	1520	республика Дагестан, Хасавюртовский район, село Солнечное, Здание школы	f	large
6326	32922	1519	республика Дагестан, Хасавюртовский район, село Солнечное, здание дома культуры	f	large
6309	32906	1502	республика Дагестан, Хасавюртовский район, село Советское, здание школы	t	medium
6336	32932	1529	республика Дагестан, Хасавюртовский район, село Сиух, Здание школы 	f	large
6370	32963	1563	республика Дагестан, Хасавюртовский район, Село Тотурбийкала, здание школы	f	large
6349	32944	1542	республика Дагестан, Хасавюртовский район, Садовое, Здание школы	t	medium
6352	32947	1545	республика Дагестан, Хасавюртовский район, село Покровское, Здание школы	f	large
6353	32947	1546	республика Дагестан, Хасавюртовский район, село Покровское, Здание школы	t	small
6310	32907	1503	республика Дагестан, Хасавюртовский район, село Первомайское, Здание дома культуры	t	medium
6331	32927	1524	республика Дагестан, Хасавюртовский район, село Османюрт, Здание библиотеки	t	medium
6312	32909	1505	республика Дагестан, Хасавюртовский район, село Октябрьское, Здание сельской администрации	f	large
6324	32920	1517	республика Дагестан, Хасавюртовский район, село Нурадилово	f	large
6348	32943	1541	республика Дагестан, Хасавюртовский район, село Новый Костек, Здание школы 	f	large
6333	32929	1526	республика Дагестан, Хасавюртовский район, Новососитли, Здание сельской администрации	f	large
6315	32912	1508	республика Дагестан, Хасавюртовский район, село Новосельское, Здание школы	f	large
6316	32912	1509	республика Дагестан, Хасавюртовский район, село Новосельское, Здание школы	t	small
26699	91654	1078	Ставропольский край, Пятигорск, Зорге, 8	f	large
6313	32910	1506	республика Дагестан, Хасавюртовский район, село Новогагатлинское, Здание школы	f	large
6360	32954	1553	республика Дагестан, Хасавюртовский район, село Муцалаул, Здание школы №2	t	small
6359	32953	1552	республика Дагестан, Хасавюртовский район, село Муцал-Аул, Здание школы №1	t	medium
6358	32952	1551	республика Дагестан, Хасавюртовский район, село Муцал-Аул, Здание дома культуры	f	large
6317	32913	1510	республика Дагестан, Хасавюртовский район, село Моксоб, Здание школы	t	small
6345	32941	1538	республика Дагестан, Хасавюртовский район, село Куруш, Здание дома культуры	f	large
6344	32940	1537	республика Дагестан, Хасавюртовский район, село Куруш, здание школы №2	f	large
6346	32942	1539	республика Дагестан, Хасавюртовский район, село Костек, сельсовет Костекский, Здание школы	f	large
6347	32942	1540	республика Дагестан, Хасавюртовский район, село Костек, сельсовет Костекский, Здание школы	t	medium
6364	32957	1557	республика Дагестан, Хасавюртовский район, село Кокрек, Здание школы	f	large
6363	32956	1556	республика Дагестан, Хасавюртовский район, село Кокрек, сельсовет Кокрекский, Здание дома культуры	f	large
6366	32959	1559	республика Дагестан, Хасавюртовский район, поселок Карланюрт, Здание сельского клуба	t	small
6365	32958	1558	республика Дагестан, Хасавюртовский район, поселок Карланюрт, Здание сельской администрации 	f	large
6334	32930	1527	республика Дагестан, Хасавюртовский район, село Кандаураул, Здание школы	f	large
6343	32939	1536	республика Дагестан, Хасавюртовский район, село Казма-Аул, Здание школы 	t	small
6342	32938	1535	республика Дагестан, Хасавюртовский район, село Казма-Аул, Здание дома культуры	t	medium
6311	32908	1504	республика Дагестан, Хасавюртовский район, село Дзержинское, Здание дома культуры	f	large
6351	32946	1544	республика Дагестан, Хасавюртовский район, село Боташ-Юрт, Здание школы	f	large
6350	32945	1543	республика Дагестан, Хасавюртовский район, село Бота-Юрт, Здание спортивного зала	f	large
6325	32921	1518	республика Дагестан, Хасавюртовский район, село Борагангечув, Здание школы	f	large
6322	32918	1515	республика Дагестан, Хасавюртовский район, село Баташ-Юрт, Здание дома культуры	f	large
6332	32928	1525	республика Дагестан, Хасавюртовский район, село Баммат-Юрт, Здание дома культуры	f	large
6357	32951	1550	республика Дагестан, Хасавюртовский район, село Байрамаул, Здание дома культуры	f	small
6356	32950	1549	республика Дагестан, Хасавюртовский район, село Байрамаул, Здание школы	f	large
6501	33072	1694	республика Дагестан, Хасавюртовский район, село Архида, здание СДК	f	small
6321	32917	1514	республика Дагестан, Хасавюртовский район, село Аксай, Здание школы - интернат	f	large
6320	32916	1513	республика Дагестан, Хасавюртовский район, Аксай, Здание школы №2	f	large
6319	32915	1512	республика Дагестан, Хасавюртовский район, село Аксай, Здание школы №1 	f	large
6308	32905	1501	республика Дагестан, Хасавюртовский район, село Акбулатьюрт, Здание сельской администрации	t	small
6339	32935	1532	республика Дагестан, Хасавюртовский район, село Адиль-Отар, Здание ФАП	t	small
6338	32934	1531	республика Дагестан, Хасавюртовский район, село Адиль-Отар, Здание школы	t	medium
6337	32933	1530	республика Дагестан, Хасавюртовский район, село Адиль-Отар, Здание дома культуры 	t	medium
6329	32925	1522	республика Дагестан, Хасавюртовский район, село Аджимажагатюрт, Здание дома культуры	t	medium
6283	32880	1476	республика Дагестан, Унцукульский район, с.Хинтлимита, здание филиала художественной фабрики	t	small
6279	32876	1472	республика Дагестан, Унцукульский район, поселок Шамилькала, здание дома кольтуры поселка	t	medium
6278	32875	1471	республика Дагестан, Унцукульский район, поселок Шамилькала, здание ДОУ №8	t	medium
6277	32874	1470	республика Дагестан, Унцукульский район, поселок Шамилькала, здание поселковой средней школы	t	medium
6306	32903	1499	республика Дагестан, Унцукульский район, село Цатаних, здание школы	t	small
6305	32902	1498	республика Дагестан, Унцукульский район, село Цатаних, здание администрации села	t	small
6284	32881	1477	республика Дагестан, Унцукульский район, село Харачи	t	small
6282	32879	1475	республика Дагестан, Унцукульский район, село Унцукуль, здание ДОУ №2 Ласточка, сельсовет Унцукульский	f	large
6281	32878	1474	республика Дагестан, Унцукульский район, село Унцукуль, здание районного дома культуры	f	large
6280	32877	1473	республика Дагестан, Унцукульский район, село Унцукуль, здание средней школы №1 	f	medium
6285	32882	1478	республика Дагестан, Унцукульский район, село Моксох, здание основной школы 	t	small
6288	32885	1481	республика Дагестан, Унцукульский район, село Майданский, здание средней школы	f	large
6302	32899	1495	республика Дагестан, Унцукульский район, село Колоб	t	small
6301	32898	1494	республика Дагестан, Унцукульский район, село Колоб, здание начальной школы 	t	small
6298	32895	1491	республика Дагестан, Унцукульский район, село Кахабросо, здание администрации с\\с	t	small
6303	32900	1496	республика Дагестан, Унцукульский район, село Иштибури, здание МУП Колхоз Иштибуринский	t	small
6300	32897	1493	республика Дагестан, Унцукульский район, село Иштибури, здание администрации	t	small
6293	32890	1486	республика Дагестан, Унцукульский район, село Ирганай, здание спорткомплекса	t	small
6292	32889	1485	республика Дагестан, Унцукульский район, село Ирганай, здание администрации села	t	medium
6304	32901	1497	республика Дагестан, Унцукульский район, село Инквалита, здание начальной школы	t	small
6287	32884	1480	республика Дагестан, Унцукульский район, село Зирани, здание начальной школы	t	small
6296	32893	1489	республика Дагестан, Унцукульский район, село Гимры	t	small
6295	32892	1488	республика Дагестан, Унцукульский район, село Гимры, здание сельского дома культуры	t	large
6294	32891	1487	республика Дагестан, Унцукульский район, село Гимры, здание средней школы	t	large
6299	32896	1492	республика Дагестан, Унцукульский район, село Бетли, здание библиотеки	t	small
6286	32883	1479	республика Дагестан, Унцукульский район, село Балахани, здание администрации с\\с	f	large
6297	32894	1490	республика Дагестан, Унцукульский район, село Ашильта, здание администрации села	t	medium
6291	32888	1484	республика Дагестан, Унцукульский район, село Аракани, сельсовет Араканский, здание МУП совхоз Араканский	t	small
6290	32887	1483	республика Дагестан, Унцукульский район, село Аракани, здание консервного завода	t	small
6289	32886	1482	республика Дагестан, Унцукульский район, село Аракани, здание администрации с\\с	t	medium
6246	32842	1439	республика Дагестан, Тляратинский район, селение Чадаколоб, сельсовет Чадаколобский	t	small
6261	32858	1454	республика Дагестан, Тляратинский район, селение Калининаул, сельсовет Гиндибский	t	small
6260	32857	1453	республика Дагестан, Тляратинский район, селение Ибрагимотар, сельсовет Гиндибский	t	medium
6224	32821	1417	республика Дагестан, Тляратинский район, селение Верхняя-Тохота, сельсовет Тохотинский	t	small
6252	32849	1445	республика Дагестан, Тляратинский район, селение Бежуда, сельсовет Начадинский	t	small
6258	32855	1451	республика Дагестан, Тляратинский район, селение Акнада, сельсовет Кособский	t	small
6262	32859	1455	республика Дагестан, Тляратинский район, населенный пункт Тельмана	t	small
6265	32862	1458	республика Дагестан, Тляратинский район, населенный пункт Гутанаул	t	small
6266	32863	1459	республика Дагестан, Тляратинский район, село колхоза имени Дахадаева	t	small
6275	32872	1468	республика Дагестан, Тляратинский район, Янгибина, сельсовет Гведышский	t	small
6269	32866	1462	республика Дагестан, Тляратинский район, село Шидиб	t	small
6248	32844	1441	республика Дагестан, Тляратинский район, Шидиб, сельсовет Шидибский	t	small
6217	32814	1410	республика Дагестан, Тляратинский район, село Чодода	t	small
6226	32823	1419	республика Дагестан, Тляратинский район, село Цумилух, сельсовет Саниортинский	t	small
6221	32818	1414	республика Дагестан, Тляратинский район, село Цимгуда	t	small
6259	32856	1452	республика Дагестан, Тляратинский район, село Хиндах	t	small
6244	32840	1437	республика Дагестан, Тляратинский район, село Хидиб, сельсовет Хидибский	t	small
6250	32846	1443	республика Дагестан, Тляратинский район, село Харада	t	small
6170	32768	1363	республика Дагестан, Табасаранский район, село Урзиг	t	small
6239	32835	1432	республика Дагестан, Тляратинский район, село Хамар, сельсовет Тляратинский	t	small
6233	32830	1426	республика Дагестан, Тляратинский район, село Хадиял	t	small
6276	32873	1469	республика Дагестан, Тляратинский район, Фрунзе	t	small
6238	32834	1431	республика Дагестан, Тляратинский район, село Укал	t	small
6223	32820	1416	республика Дагестан, Тляратинский район, село Тохота	t	small
6236	32804	1429	республика Дагестан, Тляратинский район, село Тлярата	f	large
6222	32819	1415	республика Дагестан, Тляратинский район, село Тлянада, сельсовет Колобский, селение Тлянада	t	small
6264	32861	1457	республика Дагестан, Тляратинский район, Тельмана-Теречный, сельсовет Колобский	t	small
6229	32826	1422	республика Дагестан, Тляратинский район, село Талсух	t	small
6235	32832	1428	республика Дагестан, Тляратинский район, село Сикар	t	small
6225	32822	1418	республика Дагестан, Тляратинский район, село Саниорта	t	small
6218	32815	1411	республика Дагестан, Тляратинский район, село Салда	t	small
6230	32827	1423	республика Дагестан, Тляратинский район, село Росноб	t	small
6274	32871	1467	республика Дагестан, Тляратинский район, Орджоникидзе, сельсовет Гведышский	t	small
6256	32853	1449	республика Дагестан, Тляратинский район, село Нойрух	t	small
6227	32824	1420	республика Дагестан, Тляратинский район, село Нитилсух	t	small
6255	32852	1448	республика Дагестан, Тляратинский район, село Никлида	t	small
6234	32831	1427	республика Дагестан, Тляратинский район, Никар	t	small
6251	32848	1444	республика Дагестан, Тляратинский район, село Начада, сельсовет Начадинский	t	small
6237	32833	1430	республика Дагестан, Тляратинский район, село Надар	t	small
6254	32851	1447	республика Дагестан, Тляратинский район, село Мазада, сельсовет Мазадинский	t	small
6268	32865	1461	республика Дагестан, Тляратинский район, Ленина	t	medium
6249	32845	1442	республика Дагестан, Тляратинский район, село Ланда, сельсовет Шидибский	t	small
6241	32837	1434	республика Дагестан, Тляратинский район, село Кутлаб	t	small
6272	32869	1465	республика Дагестан, Тляратинский район, село Кособ	t	small
6257	32854	1450	республика Дагестан, Тляратинский район, село Кособ, сельсовет Кособский	t	small
6270	32867	1463	республика Дагестан, Тляратинский район, Качалай, сельсовет Мазадинский	t	small
6231	32828	1424	республика Дагестан, Тляратинский район, село Кардиб	t	small
6271	32868	1464	республика Дагестан, Тляратинский район, Каратюбе, сельсовет Хиндахский	t	small
6267	32864	1460	республика Дагестан, Тляратинский район, село Камилух, сельсовет Камилухский, населенный пункт Караузек	t	small
6212	32809	1405	республика Дагестан, Тляратинский район, село Камилух	t	small
6263	32860	1456	республика Дагестан, Тляратинский район, село Калоб, сельсовет	t	small
6220	32817	1413	республика Дагестан, Тляратинский район, село Калоб	t	small
6273	32870	1466	республика Дагестан, Тляратинский район, Жданова	t	small
6253	32850	1446	республика Дагестан, Тляратинский район, село Жажада	t	small
6216	32813	1409	республика Дагестан, Тляратинский район, село Гортноб	t	small
6232	32829	1425	республика Дагестан, Тляратинский район, село Гиндиб	t	small
6214	32811	1407	республика Дагестан, Тляратинский район, село Герель	t	small
6213	32810	1406	республика Дагестан, Тляратинский район, село Генеколоб, сельсовет Камилухский	t	small
6243	32839	1436	республика Дагестан, Тляратинский район, село Гендух, сельсовет Гведышский	t	small
6242	32838	1435	республика Дагестан, Тляратинский район, село Гведыш, сельсовет Гведышский	t	small
6228	32825	1421	республика Дагестан, Тляратинский район, село Гараколоб	t	small
6219	32816	1412	республика Дагестан, Тляратинский район, село Гагар	t	small
6215	32812	1408	республика Дагестан, Тляратинский район, село Бетельда, сельсовет Герельский	t	small
6240	32836	1433	республика Дагестан, Тляратинский район, село Барнаб	t	small
6247	32843	1440	республика Дагестан, Тляратинский район, село Анцух	t	small
6573	33147	1766	республика Дагестан, Тарумовский район, село колхоза имени 40 лет Октября	t	small
6211	32808	1404	республика Дагестан, Тарумовский район, село Юрковка, Здание администрации	f	large
26059	91013	437	Ставропольский край, Железноводск, Семашко, 33	f	small
6210	32807	1403	республика Дагестан, Тарумовский район, село Тарумовка, здание Новой школы	f	large
6209	32806	1402	республика Дагестан, Тарумовский район, село Тарумовка, здание Дом культуры	f	large
6208	32805	1401	республика Дагестан, Тарумовский район, село Таловка, Дом культуры	f	large
6207	32803	1400	республика Дагестан, Тарумовский район, село Рассвет, с-с Уллубиевский, здание администрации	t	medium
6206	32802	1399	республика Дагестан, Тарумовский район, село Раздолье, здание Дома культуры	t	medium
6205	32801	1398	республика Дагестан, Тарумовский район, село Привольный, здание школы, Школа	t	small
6204	32800	1397	республика Дагестан, Тарумовский район, село Новоромановка, Дома культуры	t	medium
6203	32799	1396	республика Дагестан, Тарумовский район, село Новониколаевка, здание Школы	t	small
6202	32798	1395	республика Дагестан, Тарумовский район, село Новодмитриевка	f	large
6201	32797	1394	республика Дагестан, Тарумовский район, село Новогеоргиевка, Дом культуры	f	large
6431	33003	1624	республика Дагестан, Тарумовский район, село Кутан, Общежитие СПК Юзбековский	t	small
6430	33002	1623	Россия	t	small
6200	32796	1393	республика Дагестан, Тарумовский район, село Кочубей, Школа	t	medium
6199	32795	1392	республика Дагестан, Тарумовский район, село Кочубей, здание школы, Школа №1 	f	large
6198	32794	1391	республика Дагестан, Тарумовский район, село Кочубей, Здание отгонного животноводства	f	large
4929	31547	122	республика Дагестан, Тарумовский район, село Кочубей	t	small
6676	33244	1869	республика Дагестан, Тарумовский район, село Кочубей, Зона Отдыха	t	small
6197	32793	1390	республика Дагестан, Тарумовский район, село Коктюбей, здание Дом культуры	t	medium
6196	32792	1389	республика Дагестан, Тарумовский район, село Карабаглы, здание Дом культуры	t	medium
6195	32791	1388	республика Дагестан, Тарумовский район, село Калиновка, здание Дом культуры	f	large
6193	32789	1386	республика Дагестан, Тарумовский район, село Вышеталовка, здание Школы	t	small
6192	32788	1385	республика Дагестан, Тарумовский район, село Александро-Невское, Дом культуры	f	large
6157	32754	1350	республика Дагестан, Табасаранский район, с Ново-Лидже, здание Школы	f	small
6144	32741	1337	республика Дагестан, Табасаранский район, с Джугдиль, здание Школы	t	medium
6133	32732	1326	республика Дагестан, Табасаранский район, с Гелинбатан, сельсовет Марагинский	t	small
6191	32787	1384	республика Дагестан, Табасаранский район, село Ягдыг	t	small
6189	32786	1382	республика Дагестан, Табасаранский район, село Чурдаф	t	small
6188	32785	1381	республика Дагестан, Табасаранский район, село Чулат	t	medium
6187	32784	1380	республика Дагестан, Табасаранский район, село Цухтыг, сельсовет Аракский	t	small
6186	32783	1379	республика Дагестан, Табасаранский район, село Цуртиль	t	small
6158	32755	1351	республика Дагестан, Табасаранский район, Цантиль, здание Школы	t	small
6185	32782	1378	республика Дагестан, Табасаранский район, село Цантиль	t	small
6184	32781	1377	республика Дагестан, Табасаранский район, село Цанак	f	small
6183	32780	1376	республика Дагестан, Табасаранский район, село Цанак	t	medium
6181	32779	1374	республика Дагестан, Табасаранский район, село Хучни	f	large
6182	32779	1375	республика Дагестан, Табасаранский район, село Хучни	f	medium
6180	32778	1373	республика Дагестан, Табасаранский район, село Хустиль	t	small
6179	32777	1372	республика Дагестан, Табасаранский район, село Хуряк	t	small
6178	32776	1371	республика Дагестан, Табасаранский район, село Хурик	f	large
6151	32748	1344	республика Дагестан, Табасаранский район, село Хужник, здание СДК	t	medium
6177	32775	1370	республика Дагестан, Табасаранский район, село Хели-Пенджик	t	medium
6176	32774	1369	республика Дагестан, Табасаранский район, село Хапиль	t	medium
6175	32773	1368	республика Дагестан, Табасаранский район, село Ханак	t	small
6174	32772	1367	республика Дагестан, Табасаранский район, село Ханак	t	medium
6173	32771	1366	республика Дагестан, Табасаранский район, село Халаг	t	medium
6172	32770	1365	республика Дагестан, Табасаранский район, Фиргиль	t	small
6171	32769	1364	республика Дагестан, Табасаранский район, село Ушниг	t	small
6169	32767	1362	республика Дагестан, Табасаранский район, село Улуз, Сельсовет Кужникский	t	small
6168	32766	1361	республика Дагестан, Табасаранский район, село Туруф	t	small
6167	32765	1360	республика Дагестан, Табасаранский район, село Тураг	t	medium
6166	32764	1359	республика Дагестан, Табасаранский район, село Тинит	f	large
6165	32763	1358	республика Дагестан, Табасаранский район, село Татиль	t	medium
6164	32761	1357	республика Дагестан, Табасаранский район, село Сиртич, Ниже административного здания с/а, здание Школы	f	large
6163	32760	1356	республика Дагестан, Табасаранский район, Сиртич, Выше административного здания с/а, здание СДК	t	medium
4936	31554	129	республика Дагестан, Табасаранский район, село Сиртич	t	small
6162	32759	1355	республика Дагестан, Табасаранский район, село Сикух, здание ДК	t	small
6160	32757	1353	республика Дагестан, Табасаранский район, село Рушуль, здание Школа	t	small
6159	32756	1352	республика Дагестан, Табасаранский район, село Пилиг, сельсовет Хурикский, здание Школы	t	small
6156	32753	1349	республика Дагестан, Табасаранский район, село Ниграс, здание Школы 	t	medium
6155	32752	1348	республика Дагестан, Табасаранский район, село Марага	t	small
6136	32613	1329	республика Дагестан, Табасаранский район, село Марага, Гумрал	t	small
6154	32751	1347	республика Дагестан, Табасаранский район, село Лидже, здание СДК	t	small
6153	32750	1346	республика Дагестан, Табасаранский район, село Кюряг, здание СДК	t	small
6152	32749	1345	республика Дагестан, Табасаранский район, село Куркак, здание ДК	t	small
6149	32746	1342	республика Дагестан, Табасаранский район, село Караг, сельсовет Кужникский, здание школы	t	small
6148	32745	1341	республика Дагестан, Табасаранский район, село Зиль, здание Школы	t	small
6147	32744	1340	республика Дагестан, Табасаранский район, село Ерси, здание Школы	f	large
6146	32743	1339	республика Дагестан, Табасаранский район, село Дюбек, здание администрации	f	large
6143	32740	1336	республика Дагестан, Табасаранский район, село Джульджаг, здание Библиотеки 	t	medium
6145	32742	1338	республика Дагестан, Табасаранский район, село Джули	t	small
6142	32739	1335	республика Дагестан, Табасаранский район, село Дарваг, Ниже административного здания с/а, здание СДК	t	medium
6141	32738	1334	республика Дагестан, Табасаранский район, село Дарваг, Выше административного здания с/а	f	large
6140	32737	1333	республика Дагестан, Табасаранский район, село Дагни	t	small
6190	32736	1383	республика Дагестан, Табасаранский район, село Гюхряг	t	small
6139	32736	1332	республика Дагестан, Табасаранский район, село Гюхряг	t	medium
6138	32735	1331	республика Дагестан, Табасаранский район, село Гурхунь	t	small
6137	32707	1330	республика Дагестан, Табасаранский район, село Гурик, сельсовет Гурикский	t	medium
6161	32758	1354	республика Дагестан, Табасаранский район, село Гуми, здание Клуба	t	small
6150	32747	1343	республика Дагестан, Табасаранский район, село Гуми, здание ДК	t	small
6135	32734	1328	республика Дагестан, Табасаранский район, село Гуми	t	small
6134	32733	1327	республика Дагестан, Табасаранский район, село Гисик	t	small
6132	32731	1325	республика Дагестан, Табасаранский район, село Гасих, сельсовет Джульджагский	t	small
6131	32730	1324	республика Дагестан, Табасаранский район, село Вечрик	t	small
6130	32729	1323	республика Дагестан, Табасаранский район, село Бурганкент, здание ДК	t	small
6129	32728	1322	республика Дагестан, Табасаранский район, село Афна, здание ДК, сельсовет Гуминский	t	small
6128	32727	1321	республика Дагестан, Табасаранский район, село Аркит, здание СДК	t	small
6127	32726	1320	республика Дагестан, Табасаранский район, село Арак, здание СДК	t	small
6126	32725	1319	республика Дагестан, Табасаранский район, село Акка, Здание СДК	t	small
6093	32691	1286	республика Дагестан, Сулейман-Стальский район, село Юхари-Стал, здание сельского клуба	f	large
6116	32715	1309	республика Дагестан, Сулейман-Стальский район, село Юхари-Картас, здание сельского клуба	f	small
6096	32694	1289	республика Дагестан, Сулейман-Стальский район, село Эминхюр, здание сельской администрации	f	large
6106	32704	1299	республика Дагестан, Сулейман-Стальский район, село Экендиль, здание сельского клуба	f	small
6118	32717	1311	республика Дагестан, Сулейман-Стальский район, село Шихикент, здание сельского клуба	f	small
6098	32696	1291	республика Дагестан, Сулейман-Стальский район, село Чухверкент, здание сельского клуба	f	large
6109	32708	1302	республика Дагестан, Сулейман-Стальский район, село Цмур	f	small
6122	32721	1315	республика Дагестан, Сулейман-Стальский район, село Хтун, здание сельского клуба	f	small
6112	32711	1305	республика Дагестан, Сулейман-Стальский район, село Уллугатаг, здание школы	f	small
6115	32714	1308	республика Дагестан, Сулейман-Стальский район, село Татарханкент, здание школы	f	small
6088	32686	1281	республика Дагестан, Сулейман-Стальский район, село Сийидкент	f	medium
6108	32706	1301	республика Дагестан, Сулейман-Стальский район, село Сардаркент, здание сельского клуба	f	medium
6113	32712	1306	республика Дагестан, Сулейман-Стальский район, село Сайтаркент, здание сельского клуба	f	small
6114	32713	1307	республика Дагестан, Сулейман-Стальский район, село Птикент, здание сельского клуба	f	small
6121	32720	1314	республика Дагестан, Сулейман-Стальский район, село Пиперкент	f	small
6092	32690	1285	республика Дагестан, Сулейман-Стальский район, село Орта Стал, здание сельской администрации	f	large
6104	32702	1297	республика Дагестан, Сулейман-Стальский район, село Нютюг, здание сельского клуба	f	medium
6124	32723	1317	республика Дагестан, Сулейман-Стальский район, село Новый Испик, здание сельской администрации	f	medium
6097	32695	1290	республика Дагестан, Сулейман-Стальский район, село Новомака, здание сельского клуба	f	large
6101	32699	1294	республика Дагестан, Сулейман-Стальский район, село Куркент, здание школы №2	f	medium
6100	32698	1293	республика Дагестан, Сулейман-Стальский район, село Куркент, здание школы №1	f	large
6110	32709	1303	республика Дагестан, Сулейман-Стальский район, село Качалкент	f	small
6089	32687	1282	республика Дагестан, Сулейман-Стальский район, село Кахцуг, здание школы	f	small
6085	32683	1278	республика Дагестан, Сулейман-Стальский район, село Касумкент, Школьная, здание школы	f	large
6084	32681	1277	республика Дагестан, Сулейман-Стальский район, село Касумкент, Мира, здание ветлечебницы	f	large
6086	32684	1279	республика Дагестан, Сулейман-Стальский район, село Касумкент, Ленина, здание дворца культцры	f	large
6087	32685	1280	республика Дагестан, Сулейман-Стальский район, село Касумкент, Аминова, здание школы	f	large
6103	32701	1296	республика Дагестан, Сулейман-Стальский район, село Карчаг, здание сельского клуба	f	large
5777	32387	970	республика Дагестан, Сулейман-Стальский район, село Картас-Казмаляр, Здание дома культуры	f	large
6111	32710	1304	республика Дагестан, Сулейман-Стальский район, село Ичин, здание школы	f	small
6123	32722	1316	республика Дагестан, Сулейман-Стальский район, село Испик, здание школы	f	small
6120	32719	1313	республика Дагестан, Сулейман-Стальский район, село Зухрабкент, здание сельского клуба	f	small
6105	32703	1298	республика Дагестан, Сулейман-Стальский район, село Зизик, сельского клуба 	f	medium
6099	32697	1292	республика Дагестан, Сулейман-Стальский район, село Даркуш, здание сельской администрации	f	large
6095	32693	1288	республика Дагестан, Сулейман-Стальский район, село Герейхановское, сельсовет Герейхановский, здание сельского клуба 	f	large
6094	32692	1287	республика Дагестан, Сулейман-Стальский район, село Герейхановское, здание сельского клуба	f	large
6119	32718	1312	республика Дагестан, Сулейман-Стальский район, село Буткент	f	small
6415	32990	1608	республика Дагестан, Сулейман-Стальский район, село Ашага-Стал, Сельский дом культуры	t	medium
6090	32688	1283	республика Дагестан, Сулейман-Стальский район, село Ашага-Стал, здание сельской администрации	f	large
6117	32716	1310	республика Дагестан, Сулейман-Стальский район, село Ашага-Картас	f	small
6125	32724	1318	республика Дагестан, Сулейман-Стальский район, село Асаликент, здание сельского клуба	f	small
6107	32705	1300	республика Дагестан, Сулейман-Стальский район, село Алкадар, здание сельского клуба	f	medium
5929	32528	1122	республика Дагестан, Советский район, поселок Тарки, Здание администрации 	f	large
6082	32679	1275	республика Дагестан, Сергокалинский район, село Урахи, СДК	t	medium
6075	32672	1268	республика Дагестан, Сергокалинский район, село Сергокала	f	medium
6073	32670	1266	республика Дагестан, Сергокалинский район, село Сергокала, контора ГУП им.Х.Магомедовой	f	large
6078	32675	1271	республика Дагестан, Сергокалинский район, село Сергокала, Матросова, здание ЦБС	f	medium
6076	32673	1269	республика Дагестан, Сергокалинский район, село Сергокала, Буйнакского, здание РЕРЦ	f	large
6080	32677	1273	республика Дагестан, Сергокалинский район, село Сергокала, Буденного, здание МДОУ №3	f	medium
6074	32671	1267	республика Дагестан, Сергокалинский район, село Сергокала, 50 лет Октября	f	large
6079	32676	1272	республика Дагестан, Сергокалинский район, село Сергокала, 50 Лет Октября, здание Райпо	f	large
6077	32674	1270	республика Дагестан, Сергокалинский район, село Сергокала, 317 стрелковой дивизии, 7	f	medium
6072	32669	1265	республика Дагестан, Сергокалинский район, село Новые Мугри, СДК 	t	small
6070	32667	1263	республика Дагестан, Сергокалинский район, село Нижние Мулебки, здание СОШ	t	medium
6058	32655	1251	республика Дагестан, Сергокалинский район, село Нижние Махаргимахи, СДК	t	small
6069	32666	1262	республика Дагестан, Сергокалинский район, село Мюрего, здание ГУП ""Красный Октябрь""" 	t	large
6068	32665	1261	республика Дагестан, Сергокалинский район, село Мюрего, СОШ	t	medium
6067	32664	1260	республика Дагестан, Сергокалинский район, село Мюрего, СДК	t	medium
6066	32663	1259	республика Дагестан, Сергокалинский район, село Мургук, СДК	t	large
6065	32662	1258	республика Дагестан, Сергокалинский район, село Миглакасимахи, СДК	t	medium
6064	32661	1257	республика Дагестан, Сергокалинский район, село Мамаул, СДК	t	small
6083	32680	1276	республика Дагестан, Сергокалинский район, Краснопартизанск, СДК	t	medium
6062	32659	1255	республика Дагестан, Сергокалинский район, село Кичи-Гамри, Контора колхоза Гамринский	t	large
6061	32658	1254	республика Дагестан, Сергокалинский район, село Канасираги, СДК	t	medium
6081	32678	1274	республика Дагестан, Сергокалинский район, село Кадиркент, СДК	t	medium
6060	32657	1253	республика Дагестан, Сергокалинский район, село Дегва, СДК	t	medium
6059	32656	1252	республика Дагестан, Сергокалинский район, село Ванаши-Махи	t	medium
6071	32668	1264	республика Дагестан, Сергокалинский район, село Бурхимахи, здание СОШ 	t	medium
6057	32654	1250	республика Дагестан, Сергокалинский район, село Бурдеки, СДК	t	medium
6063	32660	1256	республика Дагестан, Сергокалинский район, село Балтамахи, СДК 	t	small
6056	32653	1249	республика Дагестан, Сергокалинский район, село Аялизмахи, СДК	t	medium
6055	32652	1248	республика Дагестан, Сергокалинский район, село Аймаумахи, здание СДК	t	small
6035	32632	1228	республика Дагестан, Рутульский район, с. Согют, Здание школы	t	small
6039	32636	1232	республика Дагестан, Рутульский район, с. Дженых, Зданиие школы	t	small
6023	32620	1216	республика Дагестан, Рутульский район, с. Асталай, сельсовет Ихрекский, Здание школы	t	small
6052	32649	1245	республика Дагестан, Рутульский район, прикутан Правда, Здание школы	t	small
6044	32641	1237	республика Дагестан, Рутульский район, прикутан Камбулат, Здание школы	t	small
6013	32609	1206	республика Дагестан, Рутульский район, село Шиназ, Здание школы	t	small
6012	32608	1205	республика Дагестан, Рутульский район, село Шиназ, Здание сельского клуба	t	medium
6034	32631	1227	республика Дагестан, Рутульский район, село Цахур, Здание сельского клуба	t	small
6033	32630	1226	республика Дагестан, Рутульский район, село Хнях, Здание школы	t	small
6010	32606	1203	республика Дагестан, Рутульский район, село Хнях, Здание школы	t	small
6004	32600	1197	республика Дагестан, Рутульский район, село Хлют, Здание дома культуры	t	medium
6003	32599	1196	республика Дагестан, Рутульский район, село Хлют, Здание администрации	t	small
6002	32598	1195	республика Дагестан, Рутульский район, село Хлют, Здание школы	t	small
6009	32605	1202	республика Дагестан, Рутульский район, село Рутул, Здание школы №2	f	medium
6008	32604	1201	республика Дагестан, Рутульский район, село Рутул	f	medium
123467	91024	447	Ставропольский край, Железноводск, Свободы, 102А	f	\N
6007	32603	1200	республика Дагестан, Рутульский район, село Рутул, РАЙПО	f	small
6006	32602	1199	республика Дагестан, Рутульский район, село Рутул, Здание шклоы №1	f	medium
6048	32645	1241	республика Дагестан, Рутульский район, Новый Борч, Здание сельского клуба	t	small
6026	32623	1219	республика Дагестан, Рутульский район, село Нижний Катрух, здание школы	t	small
6042	32639	1235	республика Дагестан, Рутульский район, село Мухух, Здание школы	t	small
6054	32651	1247	республика Дагестан, Рутульский район, село Муслах, Здание школы	t	small
6050	32647	1243	республика Дагестан, Рутульский район, село Муслах, Здание школы	t	small
6036	32633	1229	республика Дагестан, Рутульский район, село Муслах, Здание сельского клуба	t	small
6051	32648	1244	республика Дагестан, Рутульский район, село Мишлеш, Здание школы	t	small
6038	32635	1231	республика Дагестан, Рутульский район, село Мишлеш, Здание сельского клуба	t	small
6037	32634	1230	республика Дагестан, Рутульский район, село Мишлеш, Здание сельской больницы	t	small
6021	32618	1214	республика Дагестан, Рутульский район, село Михрек	t	small
6020	32617	1213	республика Дагестан, Рутульский район, село Михрек, сельсовет Мюхрекский, Здание школы	t	small
6032	32629	1225	республика Дагестан, Рутульский район, село Миких, Здание школы	t	small
6016	32612	1209	республика Дагестан, Рутульский район, село Лучек, Здание сельского клуба	t	small
6011	32607	1204	республика Дагестан, Рутульский район, село Куфа, сельсовет Рутульский, Здание сельского клуба	t	small
6043	32640	1236	республика Дагестан, Рутульский район, село Кусур, здание школы	t	small
6031	32628	1224	республика Дагестан, Рутульский район, село Курдул, Здание сельского клуба	t	small
6040	32637	1233	республика Дагестан, Рутульский район, село Корш, здание школы	t	small
6005	32601	1198	республика Дагестан, Рутульский район, село Кича, Здание дома культуры	t	small
6018	32615	1211	республика Дагестан, Рутульский район, село Кина, Здание сельского клуба	t	small
6053	32650	1246	республика Дагестан, Рутульский район, село Кальял, прикутан Уланхол, Здание колхоза	t	small
6046	32643	1239	республика Дагестан, Рутульский район, село Кальял, Здание школы	t	small
6014	32610	1207	республика Дагестан, Рутульский район, село Кала, здание сельского клуба	t	small
6025	32622	1218	республика Дагестан, Рутульский район, поселок Ихрек, Здание школы	t	small
6024	32621	1217	республика Дагестан, Рутульский район, село Ихрек, Здание сельского клуба	t	medium
6030	32627	1223	республика Дагестан, Рутульский район, село Гельмец, Здание сельадминистрации	t	small
6029	32626	1222	республика Дагестан, Рутульский район, село Гельмец, Здание школы	t	small
6017	32614	1210	республика Дагестан, Рутульский район, село Вруш, Здание школы	t	small
6028	32625	1221	республика Дагестан, Рутульский район, село Верхний Катрух, Здание сельского клуба	t	small
6049	32646	1242	республика Дагестан, Рутульский район, село Борч, Здание сельского клуба	t	small
6047	32644	1240	республика Дагестан, Рутульский район, село Борч, Здание школы	t	medium
6022	32619	1215	республика Дагестан, Рутульский район, село Аран, Здание школы	t	small
6015	32611	1208	республика Дагестан, Рутульский район, село Амсар, Здание сельского клуба	t	small
5998	32594	1191	республика Дагестан, Ногайский район, село Эдиге, Здание дома культуры	t	small
5992	32588	1185	республика Дагестан, Ногайский район, село Шумлелик, Здание школы	t	medium
5989	32585	1182	республика Дагестан, Ногайский район, село Червленные Буруны	t	small
5988	32584	1181	республика Дагестан, Ногайский район, село Червленные Буруны, Здание школы	t	small
5987	32583	1180	республика Дагестан, Ногайский район, село Червленные Буруны, Ферма №1 , Здание школы	t	small
5986	32582	1179	республика Дагестан, Ногайский район, село Червленные Буруны, Здание дома культуры	f	large
5981	32577	1174	республика Дагестан, Ногайский район, село Уй-Салган, Здание сельского дома культуры	t	small
6001	32597	1194	республика Дагестан, Ногайский район, село Терекли-Мектеб, Здание школы	f	large
6000	32596	1193	республика Дагестан, Ногайский район, село Терекли-Мектеб, Здание детской юношеско-спортивной школы	f	large
5999	32595	1192	республика Дагестан, Ногайский район, село Терекли-Мектеб, Здание районного дома культуры	f	large
5982	32578	1175	республика Дагестан, Ногайский район, село Ортатюбе, Здание сельского дома культуры	t	medium
5990	32586	1183	республика Дагестан, Ногайский район, село Нариман, Здание сельской администрации	f	large
5996	32592	1189	республика Дагестан, Ногайский район, село Ленинаул, Здание школы	t	small
5363	31982	556	республика Дагестан, Ногайский район, село Ленинаул, здание СШ №2	t	large
5362	31981	555	республика Дагестан, Ногайский район, село Ленинаул, здание дома культуры 	t	large
5361	31980	554	республика Дагестан, Ногайский район, село Ленинаул	t	large
5985	32581	1178	республика Дагестан, Ногайский район, село Кунбатар, Здание сельской администрации 	f	large
5993	32589	1186	республика Дагестан, Ногайский район, село Кумли, Здание дома культуры	t	medium
5994	32590	1187	республика Дагестан, Ногайский район, село Карасу, Здание школы	t	medium
5983	32579	1176	республика Дагестан, Ногайский район, село Карагас, Здание сельской администрации	f	large
5997	32593	1190	республика Дагестан, Ногайский район, село Калининаул, Здание школы	t	small
6194	32790	1387	республика Дагестан, Ногайский район, поселок Иммунный, Дом культуры	t	small
6707	33275	1900	республика Дагестан, Ногайский район, село Восточно-Сухокумск, школа №3	f	small
5984	32580	1177	республика Дагестан, Ногайский район, село Боранчи, Здание школы	t	small
5991	32587	1184	республика Дагестан, Ногайский район, село Батыр-Мурза, Здание школы	t	small
5980	32576	1173	республика Дагестан, Новолакский район, село Ямансу, Здание дома культуры	t	medium
5979	32575	1172	республика Дагестан, Новолакский район, село Шушия, Здание школы	t	small
5975	32572	1168	республика Дагестан, Новолакский район, село Чапаево, Здание школы	f	large
5957	32555	1150	республика Дагестан, Новолакский район, село Чапаево	t	small
5977	32574	1170	республика Дагестан, Новолакский район, село Тухчар, Здание школы	t	small
5973	32570	1166	республика Дагестан, Новолакский район, село Тухчар, Здание дома культуры	f	large
5965	32563	1158	республика Дагестан, Новолакский район, село Тухчар, Здание школы	f	large
5978	32567	1171	республика Дагестан, Новолакский район, село Новочуртах, Здание администрации с/с	t	small
5969	32567	1162	республика Дагестан, Новолакский район, село Новочуртах, Здание администрации с/с	t	medium
5964	32562	1157	республика Дагестан, Новолакский район, село Новочуртах, Здание дома культуры	f	large
5972	32569	1165	республика Дагестан, Новолакский район, село Новолакское, Здание школы 	t	medium
5967	32565	1160	республика Дагестан, Новолакский район, село Новолакское, Здание администрации с/с	f	large
5962	32560	1155	республика Дагестан, Новолакский район, село Новолакское, Здание дома культуры	f	large
5968	32566	1161	республика Дагестан, Новолакский район, село Новокули, Здание школы	f	large
5976	32566	1169	республика Дагестан, Новолакский район, село Новокули, Здание школы	t	medium
5971	32561	1164	республика Дагестан, Новолакский район, село Новокули, Здание администрации с/с	t	small
5963	32561	1156	республика Дагестан, Новолакский район, село Новокули, Здание администрации с/с	t	small
5961	32557	1154	республика Дагестан, Новолакский район, село Дучи, Здание администрации с/с	t	small
5959	32557	1152	республика Дагестан, Новолакский район, село Дучи, Здание администрации с/с	t	small
5974	32571	1167	республика Дагестан, Новолакский район, село Гамиях, Здание администрации с/с	f	large
5966	32564	1159	республика Дагестан, Новолакский район, село Гамиях, Здание дома культуры	t	small
5960	32558	1153	республика Дагестан, Новолакский район, село Гамиях, здание школы	f	large
5958	32556	1151	республика Дагестан, Новолакский район, село Банайюрт, Здание дома культуры	t	medium
5956	32554	1149	республика Дагестан, Новолакский район, село Ахар, Здание администрации с/с	t	small
5840	32441	1033	республика Дагестан, Махачкала городской округ, село Шамхал Термен, МОУ СОШ № 44	f	large
5839	32440	1032	республика Дагестан, Махачкала городской округ, поселок городского типа Шамхал, Центр - помещение МОУ СОШ № 47	f	large
5837	32438	1030	республика Дагестан, Махачкала городской округ, поселок городского типа Шамхал, Центр - помещение МОУ СОШ № 45	f	large
5836	32437	1029	республика Дагестан, Махачкала городской округ, поселок городского типа Шамхал, Центр - помещение Дом культуры	f	large
5845	32445	1038	республика Дагестан, Махачкала городской округ, поселок городского типа Сулак, Центр - помещение МОУ СОШ № 21	f	large
5844	32445	1037	республика Дагестан, Махачкала городской округ, поселок городского типа Сулак, Центр - помещение МОУ СОШ № 21	f	large
5847	32447	1040	республика Дагестан, Махачкала городской округ, поселок Семендер, МОУ СОШ	t	large
5835	32436	1028	республика Дагестан, Махачкала городской округ, поселок городского типа Ленинкент, Центр - помещение МОУ СОШ № 35 Спортзал	f	large
5843	32444	1036	республика Дагестан, Махачкала городской округ, село Красноармейское, Центр - помещение МОУ СОШ № 25 	f	large
5940	32538	1133	республика Дагестан, Махачкала городской округ, поселок городского типа Альбурикент, Лесная, 12 к1	f	large
5941	32539	1134	республика Дагестан, Махачкала , поселок городского типа Альбурикент, Лесная, 12 к2	f	large
5785	32395	978	республика Дагестан, Магарамкентский район, село Яруквалар	f	small
5771	32382	964	республика Дагестан, Магарамкентский район, село Яраг-Казмаляр, Здание дома культуры	f	large
5790	32400	983	республика Дагестан, Магарамкентский район, село Чахчах Казмаляр, здание дома культуры	f	medium
5774	32385	967	республика Дагестан, Магарамкентский район, село Целягюн, Здание школы	f	large
5793	32403	986	республика Дагестан, Магарамкентский район, село Хтун Казмаляр, Здание дома культуры	f	large
5763	32374	956	республика Дагестан, Магарамкентский район, село Хорель, Здание дома культуры	f	medium
5783	32393	976	республика Дагестан, Магарамкентский район, село Ходжаказмаляр, Здание дома культуры	f	medium
5787	32397	980	республика Дагестан, Магарамкентский район, село Филя, Здание дома культуры	f	large
5792	32402	985	республика Дагестан, Магарамкентский район, село Тагиркент-Казмаляр, Здание школы	f	large
5791	32401	984	республика Дагестан, Магарамкентский район, село Тагиркент-Казмаляр, Здание дома культуры	f	large
5770	32381	963	республика Дагестан, Магарамкентский район, село Тагиркент	f	small
5776	32386	969	республика Дагестан, Магарамкентский район, село Советское, Здание дома культуры	f	large
5775	32386	968	республика Дагестан, Магарамкентский район, село Советское, Здание дома культуры	f	large
5795	32405	988	республика Дагестан, Магарамкентский район, село Самур, Здание дома культуры	f	large
5794	32404	987	республика Дагестан, Магарамкентский район, село Самур, Здание школы	f	large
5797	32407	990	республика Дагестан, Магарамкентский район, село Приморский, Здание дома культуры	f	small
5784	32394	977	республика Дагестан, Магарамкентский район, село Оружба, Здание дома культуры	f	large
5782	32392	975	республика Дагестан, Магарамкентский район, село Новый Аул, Здание дома 	f	small
5780	32390	973	республика Дагестан, Магарамкентский район, село Новый Аул, Здание школы	f	large
5761	32372	954	республика Дагестан, Магарамкентский район, село Мугерган, Здание дома культуры, -	f	large
5760	32371	953	республика Дагестан, Магарамкентский район, село Мака-Казмаляр	t	small
5769	32380	962	республика Дагестан, Магарамкентский район, село Магарамкент, Здание школы №1	f	large
5768	32379	961	республика Дагестан, Магарамкентский район, село Магарамкент, дание ДЮСШ	f	large
5767	32378	960	республика Дагестан, Магарамкентский район, село Магарамкент, Здание дома культуры	f	large
5789	32399	982	республика Дагестан, Магарамкентский район, село КчунКазмаляр, Здание школы	f	medium
5766	32377	959	республика Дагестан, Магарамкентский район, село Куйсун, Здание дома культуры	f	large
5765	32376	958	республика Дагестан, Магарамкентский район, село Куйсун, Здание школы	f	large
5762	32373	955	республика Дагестан, Магарамкентский район, село Кирка, Здание дома культуры	f	medium
5781	32391	974	республика Дагестан, Магарамкентский район, село Киличхай, Здание дома культуры	f	small
5788	32398	981	республика Дагестан, Магарамкентский район, село Кабир-Казмаляр, Здание дома культуры	f	large
5764	32375	957	республика Дагестан, Магарамкентский район, село Джепель, Здание дома культуры	f	small
5759	32370	952	республика Дагестан, Магарамкентский район, село Гарах, Здание администрации, -	f	small
5773	32384	966	республика Дагестан, Магарамкентский район, село Гапцах, Здание дома культуры	f	large
5772	32383	965	республика Дагестан, Магарамкентский район, село Гапцах, Здание дома культуры	f	large
5779	32389	972	республика Дагестан, Магарамкентский район, село Бутказмаляр, здание школы	f	large
5778	32388	971	республика Дагестан, Магарамкентский район, село Бутказмаляр, Здание дома культуры	f	large
5796	32406	989	республика Дагестан, Магарамкентский район, село Бильбиль Казмаляр, Здание дома культуры	f	large
5786	32396	979	республика Дагестан, Магарамкентский район, село Азад-Оглы, Здание дома культуры	f	large
5757	32368	950	республика Дагестан, Левашинский район, село Эбдалая, Здание администрации с\\с	t	medium
5756	32367	949	республика Дагестан, Левашинский район, село Чуни, Здание дома культуры	t	medium
5714	32325	907	республика Дагестан, Левашинский район, село Чахимахи, Здание начальной школы	t	small
5751	32362	944	республика Дагестан, Левашинский район, село Цудахар, Здание СПТУ 	f	large
5750	32361	943	республика Дагестан, Левашинский район, село Хахита	t	medium
5746	32357	939	республика Дагестан, Левашинский район, село Хаджамахи, Здание фруктово-консервного завода	f	large
5745	32356	938	республика Дагестан, Левашинский район, Хаджалмахи, Здание средней школы	t	medium
5747	32358	940	республика Дагестан, Левашинский район, село Хаджал-Махи, Здание основной школы	f	large
5744	32355	937	республика Дагестан, Левашинский район, село Урма, Здание начальной школы	t	medium
5743	32354	936	республика Дагестан, Левашинский район, село Урма, Здание средней школы	f	large
5742	32353	935	республика Дагестан, Левашинский район, село Уллу-Ая, Здание администрации с\\с	f	large
5741	32352	934	республика Дагестан, Левашинский район, село Уллу-Ая, Здание основной школы	f	large
5727	32338	920	республика Дагестан, Левашинский район, Телагу, Здание начальной школы	t	medium
5749	32360	942	республика Дагестан, Левашинский район, село Ташкапур, Здание средней школы	t	medium
5754	32365	947	республика Дагестан, Левашинский район, Тарлимахи, Здание начальной школы	t	small
5758	32369	951	республика Дагестан, Левашинский район, село Тагиркент, Здание начальной школы	t	medium
5723	32334	916	республика Дагестан, Левашинский район, село Сулейбакент, Здание средней школы	t	medium
5740	32351	933	республика Дагестан, Левашинский район, село Охли, Здание дома культуры	f	large
5707	32317	900	республика Дагестан, Левашинский район, село Орада Чугли, Здание дома культуры	t	medium
5739	32350	932	республика Дагестан, Левашинский район, село Нижние Чугли, Здание дома культуры	f	large
5748	32359	941	республика Дагестан, Левашинский район, село Нижние Убекимахи, Здание основной школы	t	medium
5716	32327	909	республика Дагестан, Левашинский район, село Нижние Лабкомахи, Здание начальной школы	t	small
5709	32319	902	республика Дагестан, Левашинский район, село Нижнее Аршимахи, Здание дома культуры	t	small
5738	32349	931	республика Дагестан, Левашинский район, село Наскент, Здание спортзала	t	medium
5737	32348	930	республика Дагестан, Левашинский район, село Наскент, Здание дома культуры	f	large
5734	32345	927	республика Дагестан, Левашинский район, село Мусультемахи, Здание СПК им. Нурова	t	medium
5733	32344	926	республика Дагестан, Левашинский район, село Мекеги, Здание средней школы	t	medium
5732	32343	925	республика Дагестан, Левашинский район, село Мекеги, Здание дома культуры	f	large
5731	32342	924	республика Дагестан, Левашинский район, село Леваши, Здание средней школы № 1	f	large
5730	32341	923	республика Дагестан, Левашинский район, село Леваши, Здание средней школы № 2 	f	large
5729	32340	922	республика Дагестан, Левашинский район, село Леваши	f	large
5728	32339	921	республика Дагестан, Левашинский район, село Кутиша	f	large
5725	32336	918	республика Дагестан, Левашинский район, село Куппа	f	large
5753	32364	946	республика Дагестан, Левашинский район, село Кулибухна	t	small
26066	91021	444	Ставропольский край, Железноводск, Свободы, 14	f	medium
5724	32335	917	республика Дагестан, Левашинский район, село Кулецма, Здание средней школы	f	large
5722	32333	915	республика Дагестан, Левашинский район, село Карлабко, Здание дома культуры 	f	large
5752	32363	945	республика Дагестан, Левашинский район, село Карекадани, Здание дома культуры	t	medium
5720	32331	913	республика Дагестан, Левашинский район, село Какамахи	f	large
5726	32337	919	республика Дагестан, Левашинский район, село Иргали, Здание основной школы 	t	small
5713	32324	906	республика Дагестан, Левашинский район, Зуримахи	t	small
5721	32332	914	республика Дагестан, Левашинский район, село Дитуншимахи, Здание начальной школы	t	small
5719	32330	912	республика Дагестан, Левашинский район, село Джангамахи, Здание дома культуры	t	medium
5736	32347	929	республика Дагестан, Левашинский район, село Гургумахи, Здание администрации с\\с	t	small
5755	32366	948	республика Дагестан, Левашинский район, село Верхняя Цухта, Здание дома культуры	f	large
5715	32326	908	республика Дагестан, Левашинский район, село Верхние Лабкомахи, Здание дома культуры	t	medium
5717	32328	910	республика Дагестан, Левашинский район, село Верхнее-Убекимахи, Здание основной школы	t	medium
5708	32318	901	республика Дагестан, Левашинский район, село Верхнее Аршимахи, Здание дома культуры	t	medium
5710	32320	903	республика Дагестан, Левашинский район, село Буртанимахи, Здание начальной школы	t	small
5712	32323	905	республика Дагестан, Левашинский район, село Аялакаб, Здание дома культуры	t	medium
5711	32322	904	республика Дагестан, Левашинский район, село Ахкент, Здание СПК	t	medium
5735	32346	928	республика Дагестан, Левашинский район, село Аллатемахи, Здание спортивного зала	t	medium
5718	32329	911	республика Дагестан, Левашинский район, село Айнакаб, Здание начальной школы	t	small
5697	32307	890	республика Дагестан, Лакский район, село Шовкра, Здание сельского клуба	f	small
5689	32298	882	республика Дагестан, Лакский район, село Шахува	f	small
5698	32308	891	республика Дагестан, Лакский район, село Шара, Здание дома культуры	f	small
5680	32274	873	республика Дагестан, Лакский район, село Чуртах, Здание сельского клуба	t	small
5686	32295	879	республика Дагестан, Лакский район, село Чукна, Здание школы	f	small
5706	32316	899	республика Дагестан, Лакский район, село Хурхи, Здание сельской библиотеки	f	small
5700	32310	893	республика Дагестан, Лакский район, село Хурукра, Здание школы	f	small
5699	32309	892	республика Дагестан, Лакский район, село Хури	f	small
5703	32313	896	республика Дагестан, Лакский район, село Хуна	f	small
5675	32284	868	республика Дагестан, Лакский район, село Хулисма	t	small
5688	32297	881	республика Дагестан, Лакский район, село Харазма, Здание дома культуры	t	small
5694	32303	887	республика Дагестан, Лакский район, село Ури, Здание сельадминистрации	f	small
5690	32299	883	республика Дагестан, Лакский район, село Унчукатль, Здание сельадминистрации	f	small
5704	32314	897	республика Дагестан, Лакский район, село Курла	f	small
5685	32294	878	республика Дагестан, Лакский район, село Куркли, Здание школы	f	small
5687	32296	880	республика Дагестан, Лакский район, село Кунды, Здание дома культуры	f	medium
5702	32312	895	республика Дагестан, Лакский район, село Кумух, Контора колхоза	f	small
5682	32291	875	республика Дагестан, Лакский район, село Кумух, Здание дома культуры	f	large
5683	32292	876	республика Дагестан, Лакский район, село Кума, Здание дома культуры	f	small
5679	32288	872	республика Дагестан, Лакский район, село Кулушац, Здание сельадминистрации	t	small
5701	32311	894	республика Дагестан, Лакский район, село Кукни, Здание школы	f	small
5681	32290	874	республика Дагестан, Лакский район, село Кубра	t	small
5677	32286	870	республика Дагестан, Лакский район, село Куба	t	small
5692	32301	885	республика Дагестан, Лакский район, село Караша	f	small
5676	32285	869	республика Дагестан, Лакский район, село Кара, Здание сельадминистрации	t	small
5695	32304	888	республика Дагестан, Лакский район, село Камахал, Здание сельадминистрации	f	small
5705	32315	898	республика Дагестан, Лакский район, село Иниша, Здание сельской библиотеки	f	small
5519	32131	712	республика Дагестан, Кизилюртовский район, село Султан-Янгиюрт	f	large
5673	32282	866	республика Дагестан, Лакский район, село Бурши, Здание сельской библиотеки	t	small
5691	32300	884	республика Дагестан, Лакский район, Балисма, Здание дома культуры	t	small
5684	32293	877	республика Дагестан, Лакский район, село Багикла	f	small
5693	32302	886	республика Дагестан, Лакский район, Арусси , Контора колхоза 	t	small
5672	32281	865	республика Дагестан, Курахский район, село Штул, здание библиотеки	t	small
5671	32280	864	республика Дагестан, Курахский район, село Штул, Здание СДК	t	small
5670	32279	863	республика Дагестан, Курахский район, село Шимихюр, Здание СДК	t	small
5669	32278	862	республика Дагестан, Курахский район, село Хюрехюр	t	small
6102	32700	1295	республика Дагестан, Курахский район, село Хпюк, здание сельской администрации	f	small
5668	32277	861	республика Дагестан, Курахский район, село Хпюк, Здание школы	t	small
5667	32276	860	республика Дагестан, Курахский район, село Хпедж, Здание СДК	t	small
5666	32275	859	республика Дагестан, Курахский район, село Хвередж, Здание СДК	t	small
5665	32273	858	республика Дагестан, Курахский район, село Усуг	t	small
5664	32272	857	республика Дагестан, Курахский район, село Урсун, Здание библиотеки, сельсовет Шимихюрский	t	small
5663	32271	856	республика Дагестан, Курахский район, УКУЗ, Здание библиотеки	t	small
5662	32270	855	республика Дагестан, Курахский район, село Сараг	t	small
5661	32269	854	республика Дагестан, Курахский район, село Ругун	t	small
5660	32268	853	республика Дагестан, Курахский район, село Моллакент, Здание СДК	t	medium
5659	32267	852	республика Дагестан, Курахский район, село Кутул, здание СДК	t	small
5657	32265	850	республика Дагестан, Курахский район, село Курах, Здание Школы №2	f	medium
5656	32264	849	республика Дагестан, Курахский район, село Курах, Здание РДК	f	large
5655	32263	848	республика Дагестан, Курахский район, село Кумук, здание СДК	t	medium
5654	32262	847	республика Дагестан, Курахский район, село Кукваз, Здание СДК 	t	small
5649	32256	842	республика Дагестан, Курахский район, село Кочхюр, Здание СДК	t	medium
5653	32261	846	республика Дагестан, Курахский район, село Квардал, Здание библиотеки	t	small
5652	32259	845	республика Дагестан, Курахский район, село Кабир, Здание СДК 	f	large
5651	32258	844	республика Дагестан, Курахский район, село Икра, Здание СДК	t	large
5650	32257	843	республика Дагестан, Курахский район, село Гельхен, Здание СДК	t	small
5648	32255	841	республика Дагестан, Курахский район, село Бахцуг, Здание школы	t	small
5647	32254	840	республика Дагестан, Курахский район, село Ашар, Здание СДК	t	small
5646	32253	839	республика Дагестан, Курахский район, село Ашакент, Здание СДК	t	small
5645	32252	838	республика Дагестан, Курахский район, село Ахнит, Здание школы	t	small
5171	31788	364	республика Дагестан, Кумторкалинский район, с. Ново-Шангода, здание школы	t	small
5642	32249	835	республика Дагестан, Кумторкалинский район, село Шамхал-Янги-Юрт, Здание СОШ	t	medium
5638	32245	831	республика Дагестан, Кумторкалинский район, село Учкент, Здание Дома культуры	f	large
5168	31785	361	республика Дагестан, Кумторкалинский район, село Уллубиевка, здание школы	t	small
5637	32244	830	республика Дагестан, Кумторкалинский район, село Тюбе, Здание СОШ	f	large
5636	32244	829	республика Дагестан, Кумторкалинский район, село Тюбе, Здание СОШ	f	large
5640	32247	833	республика Дагестан, Кумторкалинский район, село Темиргое, Здание СОШ 	f	large
5167	31784	360	республика Дагестан, Кумторкалинский район, село Сафар-Али, СДК	t	small
6453	33024	1646	республика Дагестан, Кумторкалинский район, село Самилах, здание СДК	t	medium
6685	33253	1878	республика Дагестан, Кумторкалинский район, село Новая Урада	t	small
6459	33030	1652	республика Дагестан, Кумторкалинский район, Красное Село, здание СДК	f	small
5635	32243	828	республика Дагестан, Кумторкалинский район, село Коркмаскала, Свердлова, Школа	f	large
5634	32242	827	республика Дагестан, Кумторкалинский район, село Коркмаскала, Свердлова, Клуб	f	large
6471	33042	1664	республика Дагестан, Кумторкалинский район, село Квами	f	small
5639	32246	832	республика Дагестан, Кумторкалинский район, село Алмало, Здание СОШ	t	medium
5641	32248	834	республика Дагестан, Кумторкалинский район, село Аджидада, здание СОШ	f	large
5099	31715	292	республика Дагестан, Кумторкалинский район, село Аджидада, здание клуба	t	small
5624	32232	817	республика Дагестан, Кулинский район, село Цыйша, здание СДК	t	small
5629	32237	822	республика Дагестан, Кулинский район, село Цущар, здание Администрации	t	small
5630	32238	823	республика Дагестан, Кулинский район, село Цовкра 2-я, здание СДК	t	small
5620	32228	813	республика Дагестан, Кулинский район, село Цовкра 1-я, здание СДК	t	small
5632	32240	825	республика Дагестан, Кулинский район, село Хосрех, ферма №3 здание Ветучастка	t	small
5617	32225	810	республика Дагестан, Кулинский район, село Хосрех, здание СДК	t	large
5628	32236	821	республика Дагестан, Кулинский район, село Хойхи, здание СДК	t	small
5623	32231	816	республика Дагестан, Кулинский район, село Хойми, здание СДК	t	small
5619	32227	812	республика Дагестан, Кулинский район, село Сумбаталь, здание СДК	t	small
5626	32234	819	республика Дагестан, Кулинский район, село Сукиях, здание СДК	t	small
5633	32241	826	республика Дагестан, Кулинский район, село Кули, здание СПК племхоз Кулинский	t	small
5618	32226	811	республика Дагестан, Кулинский район, село Кули, здание СДК	f	large
5622	32230	815	республика Дагестан, Кулинский район, село Кая, здание СДК	t	small
5627	32235	820	республика Дагестан, Кулинский район, село Кани	t	small
5625	32233	818	республика Дагестан, Кулинский район, село Вихли, здание СДК	t	medium
5621	32229	814	республика Дагестан, Кулинский район, село Вачи, здание Администрации	f	medium
5832	32434	1025	республика Дагестан, Кировский район, поселок городского типа Ленинкент, Центр - помещение школы Перспектива	t	medium
5842	32443	1035	республика Дагестан, Кировский район, село Богатыревка, Центр - помещение Клуб	f	large
5133	31749	326	республика Дагестан, Кизлярский район, кутан Арбакол, Здание агрофирмы	t	small
5597	32205	790	республика Дагестан, Кизлярский район, село имени Кирова, Здание СДК	t	small
5570	32178	763	республика Дагестан, Кизлярский район, село имени Жданова, здание Администрации	f	large
5598	32206	791	республика Дагестан, Кизлярский район, село Ясная Поляна, Здание СДК	t	medium
5595	32203	788	республика Дагестан, Кизлярский район, село Южное, Здание школы	f	large
5564	32172	757	республика Дагестан, Кизлярский район, село Юбилейное, Здание СДК	f	large
5589	32197	782	республика Дагестан, Кизлярский район, село Черняевка, Здание Администрации	f	large
5593	32201	786	республика Дагестан, Кизлярский район, село Цветковка, здание СДК	f	large
5599	32207	792	республика Дагестан, Кизлярский район, село Хуцеевка	t	medium
5587	32195	780	республика Дагестан, Кизлярский район, село Тушиловка, Здание Администрации	t	small
5584	32192	777	республика Дагестан, Кизлярский район, село Степное, Здание школы	t	small
5568	32176	761	республика Дагестан, Кизлярский район, село Старый Терек, Здание конторы колхоза	t	small
5594	32202	787	республика Дагестан, Кизлярский район, село Серебряковка, Здание школы	t	small
5591	32199	784	республика Дагестан, Кизлярский район, село Сар-Сар, Здание клуба	t	small
5549	32157	742	республика Дагестан, Кизлярский район, село Сангиши, Здание школы	t	small
5573	32181	766	республика Дагестан, Кизлярский район, село Рыбалко, Здание школы 	f	large
5596	32204	789	республика Дагестан, Кизлярский район, село Речное, Здание д/сада	t	small
5565	32173	758	республика Дагестан, Кизлярский район, село Пролетарское, Здание СДК	f	large
5557	32165	750	республика Дагестан, Кизлярский район, село Персидское, Здание школы	t	small
5561	32169	754	республика Дагестан, Кизлярский район, село Первомайское, Здание школы	t	medium
5563	32171	756	республика Дагестан, Кизлярский район, село Первокизлярское, Здание школы	t	small
5585	32193	778	республика Дагестан, Кизлярский район, село Огузер, Здание СДК	t	medium
5569	32177	762	республика Дагестан, Кизлярский район, село Новый Бирюзяк, Здание СДК	t	medium
5135	31751	328	республика Дагестан, Кизлярский район, село Новые Бухты, СДК	t	small
5582	32190	775	республика Дагестан, Кизлярский район, село Новомонастырское, здание школы	t	medium
5583	32191	776	республика Дагестан, Кизлярский район, село Новокрестьяновское, Здание школы	t	medium
5580	32188	773	республика Дагестан, Кизлярский район, село Новокохановское, Здание Администрации 	t	medium
5556	32164	749	республика Дагестан, Кизлярский район, село Новогладковка, Здание школы	t	small
5592	32200	785	республика Дагестан, Кизлярский район, село Нововладимирское, Здание школы	t	small
5586	32194	779	республика Дагестан, Кизлярский район, село Новая Серебряковка, Здание совхоза Мареновский	t	medium
5577	32185	770	республика Дагестан, Кизлярский район, село Некрасовка, Здание СДК	t	medium
5562	32170	755	республика Дагестан, Кизлярский район, село Михеевское, Здание школы	t	small
5552	32160	745	республика Дагестан, Кизлярский район, село Малое Козыревское, здание школы	t	small
5578	32186	771	республика Дагестан, Кизлярский район, село Малая Арешевка, Здание СДК	f	large
5554	32162	747	республика Дагестан, Кизлярский район, село Макаровское, Здание школы	t	small
5590	32198	783	республика Дагестан, Кизлярский район, село Курдюковское, Здание СДК 	t	small
5571	32179	764	республика Дагестан, Кизлярский район, село Красный Восход, Здание Администрации	f	large
5581	32189	774	республика Дагестан, Кизлярский район, село Краснооктябрьское, Здание почты	t	medium
5572	32180	765	республика Дагестан, Кизлярский район, село Краснооктябрьское, Здание школы	t	medium
5566	32174	759	республика Дагестан, Кизлярский район, село Крайновка, Здание Администрации	f	large
5154	31770	347	республика Дагестан, Кизлярский район, Крайновка, здание агрофирмы	t	small
5152	31768	345	республика Дагестан, Кизлярский район, село Крайновка, СДК	t	small
5559	32167	752	республика Дагестан, Кизлярский район, село Косякино, Здание конторы АО "Дружба	t	medium
5616	32224	809	республика Дагестан, Кизлярский район, поселок городского типа Комсомольский, Советская, 19	f	large
5567	32175	760	республика Дагестан, Кизлярский район, село Коллективизатор	t	small
5575	32183	768	республика Дагестан, Кизлярский район, село Кардоновка, Здание СДК 	f	large
5174	31791	367	республика Дагестан, Кизлярский район, Калантар, здание агрофирмы	t	small
5551	32159	744	республика Дагестан, Кизлярский район, село Имени Карла Маркса, Здание школы	f	large
5097	31714	290	республика Дагестан, Кизлярский район, село Зеленый бугор, здание клуба	t	small
5098	31714	291	республика Дагестан, Кизлярский район, село Зеленый бугор, здание клуба	t	small
5574	32182	767	республика Дагестан, Кизлярский район, село Заречное, Здание СДК	t	medium
5547	32155	740	республика Дагестан, Кизлярский район, село Ефимовка, Здание школы	t	small
5576	32184	769	республика Дагестан, Кизлярский район, село Дагестанское, Здание школы	t	small
5579	32187	772	республика Дагестан, Кизлярский район, село Вышеталовка, Здание школы	t	medium
5558	32166	751	республика Дагестан, Кизлярский район, село Вперед, Здание школы	f	large
5588	32196	781	республика Дагестан, Кизлярский район, село Брянск, Здание Администрации	t	medium
5560	32168	753	республика Дагестан, Кизлярский район, село Бондареновка, Здание школы	t	small
5550	32158	743	республика Дагестан, Кизлярский район, село Большой Бредихин, здание СДК	f	large
5555	32163	748	республика Дагестан, Кизлярский район, село Большезадоевское, Здание д/сада	f	large
5553	32161	746	республика Дагестан, Кизлярский район, село Большая Арешевка, Здание школы	t	large
5147	31763	340	республика Дагестан, Кизлярский район, село Большая Арешевка, здание агрофирмы	t	small
5548	32156	741	республика Дагестан, Кизлярский район, село Александрийская, Здание совхоза	f	large
5546	32154	739	республика Дагестан, Кизлярский район, село Аверьяновка, Здание СДК	f	large
4871	31488	64	республика Дагестан, Кизлярский район, село Аверьяновка, дом. пред СПК 	t	small
5516	32130	709	республика Дагестан, Кизилюртовский район, село Шушановка	f	large
5524	32133	717	республика Дагестан, Кизилюртовский район, село Чонтаул	f	large
5522	32133	715	республика Дагестан, Кизилюртовский район, село Чонтаул	f	large
5523	32133	716	республика Дагестан, Кизилюртовский район, село Чонтаул	t	large
5521	32132	714	республика Дагестан, Кизилюртовский район, Ханар	f	large
5520	32131	713	республика Дагестан, Кизилюртовский район, село Султан-Янгиюрт	f	large
25665	90648	43	Ставропольский край, Ставрополь, Серова, 523	f	large
5518	32131	711	республика Дагестан, Кизилюртовский район, село Султан-Янгиюрт	f	large
5517	32131	710	республика Дагестан, Кизилюртовский район, село Султан-Янгиюрт	f	large
5499	32116	692	республика Дагестан, Кизилюртовский район, село Старый Миатли	t	medium
5515	32129	708	республика Дагестан, Кизилюртовский район, село Стальское	f	large
5514	32128	707	республика Дагестан, Кизилюртовский район, село Стальское	f	large
5513	32127	706	республика Дагестан, Кизилюртовский район, село Стальское	f	large
5512	32125	705	республика Дагестан, Кизилюртовский район, село Новый Чиркей	f	large
5511	32124	704	республика Дагестан, Кизилюртовский район, село Новый Чиркей	f	large
5510	32124	703	республика Дагестан, Кизилюртовский район, село Новый Чиркей	f	large
5495	32113	688	республика Дагестан, Кизилюртовский район, село Новые Гадари	t	small
5506	32121	699	республика Дагестан, Кизилюртовский район, село Нечаевка	t	medium
5507	32121	700	республика Дагестан, Кизилюртовский район, село Нечаевка	f	large
5505	32121	698	республика Дагестан, Кизилюртовский район, село Нечаевка	f	large
5508	32122	701	республика Дагестан, Кизилюртовский район, село Мацеевка	t	small
5504	32120	697	республика Дагестан, Кизилюртовский район, село Кульзеб	f	large
5501	32118	694	республика Дагестан, Кизилюртовский район, село Комсомольское	f	large
5500	32117	693	республика Дагестан, Кизилюртовский район, село Кироваул	f	large
6489	33060	1682	республика Дагестан, Кизилюртовский район, село Аркида, здание НШ	f	small
5491	32110	684	республика Дагестан, Кизилюртовский район, село Акнада, Акнадинская СОШ	f	large
6454	33025	1647	республика Дагестан, Кизилюртовский район, село Акаро, здание ОШ	f	small
5496	32114	689	республика Дагестан, Кизилюртовский район, cело Новозубутли	t	small
5509	32123	702	республика Дагестан, Кизилюртовский район, cело Нижнечирюрт	f	large
5503	32119	696	республика Дагестан, Кизилюртовский район, cело Комсомолец	f	large
5502	32119	695	республика Дагестан, Кизилюртовский район, cело Комсомолец	f	large
5497	32112	690	республика Дагестан, Кизилюртовский район, cело Зубутли-Миатли	f	large
5494	32112	687	республика Дагестан, Кизилюртовский район, cело Зубутли-Миатли	f	large
5493	32112	686	республика Дагестан, Кизилюртовский район, cело Зубутли-Миатли	f	large
5498	32112	691	республика Дагестан, Кизилюртовский район, cело Зубутли-Миатли	t	medium
5492	32111	685	республика Дагестан, Кизилюртовский район, cело Гельбах	f	large
5479	32099	672	республика Дагестан, Каякентский район, с.Сагаси-Дейбук, здание школы	f	large
5470	32090	663	республика Дагестан, Каякентский район, с.Кулкам, здание школы	f	small
5478	32098	671	республика Дагестан, Каякентский район, село Утамыш, здание ГУП Утамышский	f	large
5475	32095	668	республика Дагестан, Каякентский район, село Усемикент, здание ГУП Усемикентский	f	large
5484	32103	677	республика Дагестан, Каякентский район, село Первомайское, здание ПСШ №1	f	large
5483	32102	676	республика Дагестан, Каякентский район, село Первомайское	f	large
5482	32101	675	республика Дагестан, Каякентский район, село Первомайское, здание СДЮСШ	f	large
5480	32100	673	республика Дагестан, Каякентский район, село Новый Дейбук, здание СДК	f	small
5486	32105	679	республика Дагестан, Каякентский район, село Новые Викри, здание СДК	f	large
5466	32085	659	республика Дагестан, Каякентский район, село Новокаякент, здание ЖДС	f	large
5468	32088	661	республика Дагестан, Каякентский район, село Новокаякент, мкр.Гоктёбе, здание школы	t	small
5467	32086	660	республика Дагестан, Каякентский район, село Новокаякент, мкр. Сельхозтехника, здание Ясли-сада	f	medium
5465	32084	658	республика Дагестан, Каякентский район, село Новокаякент, Новая, здание РДК	f	large
4825	31442	18	республика Дагестан, Каякентский район, МУП Тпигский	f	small
4826	31443	19	республика Дагестан, Каякентский район, МУП Агульский	f	small
5474	32094	667	республика Дагестан, Каякентский район, село Каякент, здание КСШ №3	f	large
5473	32093	666	республика Дагестан, Каякентский район, село Каякент, здание КСШ №2	f	large
5472	32092	665	республика Дагестан, Каякентский район, село Каякент, здание СДК	f	large
5471	32091	664	республика Дагестан, Каякентский район, село Каякент, здание КСШ №1	f	large
5481	32087	674	республика Дагестан, Каякентский район, село Каранай-Аул, здание школы	f	large
5490	32109	683	республика Дагестан, Каякентский район, село Капкайкент, здание школы	f	medium
5469	32089	662	республика Дагестан, Каякентский район, село Инчхе, сельсовет Новокаякентский, здание школы	f	small
5487	32106	680	республика Дагестан, Каякентский район, село Дружба, здание СДК	f	large
5489	32108	682	республика Дагестан, Каякентский район, село Джаванкент	f	medium
5485	32104	678	республика Дагестан, Каякентский район, село Герга, здание СДК	f	large
5488	32107	681	республика Дагестан, Каякентский район, село Башлыкент, здание СДК	f	large
5477	32097	670	республика Дагестан, Каякентский район, село Алхаджакент, здание СПК 	f	small
5476	32096	669	республика Дагестан, Каякентский район, село Алхаджакент, здание СДК	f	medium
5435	32054	628	республика Дагестан, Карабудахкентский район, село Уллубийаул, Дом Культура	f	large
5421	32041	614	республика Дагестан, Карабудахкентский район, село Параул, Школа	f	small
5420	32040	613	республика Дагестан, Карабудахкентский район, село Параул, изиева, Школа	f	large
5419	32039	612	республика Дагестан, Карабудахкентский район, село Параул, Изиева, Школа	f	large
5439	32058	632	республика Дагестан, Карабудахкентский район, поселок Манаскент, Школа	f	large
5438	32058	631	республика Дагестан, Карабудахкентский район, поселок Манаскент, Школа	f	large
5437	32057	630	республика Дагестан, Карабудахкентский район, поселок Манас, Дом культуры	f	large
5436	32056	629	республика Дагестан, Карабудахкентский район, поселок Манас, Школа	f	large
5434	32053	627	республика Дагестан, Карабудахкентский район, село Ленинкент, Администрация 	f	medium
5413	32033	606	республика Дагестан, Карабудахкентский район, село Карабудахкент, Райгаз	f	large
5415	32035	608	республика Дагестан, Карабудахкентский район, село Карабудахкент, Дахадаева, Дворец культуры	f	large
5412	32032	605	республика Дагестан, Карабудахкентский район, село Карабудахкент, Дауда Карабудахкентского, Школа	f	medium
5411	32031	604	республика Дагестан, Карабудахкентский район, село Карабудахкент, Гамзатова, Здание УОС	f	large
5416	32036	609	республика Дагестан, Карабудахкентский район, село Карабудахкент, Абдуллаева, Автошкола	f	large
5414	32034	607	республика Дагестан, Карабудахкентский район, село Карабудахкент, Абакарова А, Школа	f	large
5426	32047	619	республика Дагестан, Карабудахкентский район, Какамахи, Клуб	f	medium
5425	32046	618	республика Дагестан, Карабудахкентский район, село Кака-Шура, Школа	f	large
5424	32045	617	республика Дагестан, Карабудахкентский район, село Кака-Шура, Дом культура	f	large
5440	32059	633	республика Дагестан, Карабудахкентский район, село Зеленоморск, Школа	f	medium
5423	32044	616	республика Дагестан, Карабудахкентский район, село Доргели, Дом культура	f	large
5422	32042	615	республика Дагестан, Карабудахкентский район, село Доргели, Школа	f	large
5432	32051	625	республика Дагестан, Карабудахкентский район, село Джанга, Клуб	t	medium
5428	32049	621	республика Дагестан, Карабудахкентский район, село Гурбуки	f	large
5427	32048	620	республика Дагестан, Карабудахкентский район, село Гурбуки, администрация	f	large
5433	32052	626	республика Дагестан, Карабудахкентский район, село Губден, Клуб	f	small
5431	32050	624	республика Дагестан, Карабудахкентский район, село Губден, Школа	f	large
5430	32050	623	республика Дагестан, Карабудахкентский район, село Губден, Школа	f	large
5429	32050	622	республика Дагестан, Карабудахкентский район, село Губден, Школа	f	large
5418	32038	611	республика Дагестан, Карабудахкентский район, село Гели, Дом культуры	f	large
5442	32061	635	республика Дагестан, Карабудахкентский район, поселок городского типа Ачису, Администрация	f	large
5417	32037	610	республика Дагестан, Карабудахкентский район, село Аданак, Администрация	f	medium
5407	32027	600	республика Дагестан, Кайтагский район, село Янгикент, Дом культуры	t	medium
5402	32022	595	республика Дагестан, Кайтагский район, село Шиляги, Дом культуры	t	medium
5401	32021	594	республика Дагестан, Кайтагский район, село Чумли, Дом культуры	t	medium
5373	31992	566	республика Дагестан, Кайтагский район, село Чахдикна, Здание библиотеки	t	small
5398	32018	591	республика Дагестан, Кайтагский район, село Хунгия, Здание школы	t	small
5382	32002	575	республика Дагестан, Кайтагский район, село Хадаги, Дом культуры	t	small
5409	32029	602	республика Дагестан, Кайтагский район, село Тумеллер, Дом культуры	t	small
5372	31991	565	республика Дагестан, Кайтагский район, село Сурхачи, Дом культуры	t	small
5388	32008	581	республика Дагестан, Кайтагский район, село Сургия	t	small
5400	32020	593	республика Дагестан, Кайтагский район, село Санчи, Дом культуры	f	large
5380	31999	573	республика Дагестан, Кайтагский район, село Рука, Здание школы	t	medium
5399	32019	592	республика Дагестан, Кайтагский район, село Родниковый, Дом культуры	t	medium
5394	32014	587	республика Дагестан, Кайтагский район, село Пиляки, Здание школы	t	small
5408	32028	601	республика Дагестан, Кайтагский район, село Новая Барша, Здание школы	t	small
5403	32023	596	республика Дагестан, Кайтагский район, село Мижигли, Здание школы	t	small
5383	32003	576	республика Дагестан, Кайтагский район, село Машаты, Дом культуры	t	small
5410	32030	603	республика Дагестан, Кайтагский район, село Маллакент, Здание школы	t	small
5396	32016	589	республика Дагестан, Кайтагский район, село Маджалис, Дом культуры	f	large
5395	32015	588	республика Дагестан, Кайтагский район, село Маджалис, Дом культуры 	f	medium
5387	32007	580	республика Дагестан, Кайтагский район, село Лища, Здание библиотеки	t	small
5406	32026	599	республика Дагестан, Кайтагский район, село Кулиджа, Дом культуры	t	small
5393	32013	586	республика Дагестан, Кайтагский район, село Кирцик, Дом культуры 	t	small
5392	32012	585	республика Дагестан, Кайтагский район, село Кирки, Дом культуры	t	small
5391	32011	584	республика Дагестан, Кайтагский район, село Карталай, Дом культуры	t	small
5390	32010	583	республика Дагестан, Кайтагский район, село Карацан, Дом культуры 	t	medium
5405	32025	598	республика Дагестан, Кайтагский район, село Дуреги, Здание школы	t	small
5385	32005	578	республика Дагестан, Кайтагский район, село Джирабачи, Здание школы	t	small
5384	32004	577	республика Дагестан, Кайтагский район, село Джинаби, Дом культуры	t	medium
5381	32001	574	республика Дагестан, Кайтагский район, село Джибахни, Дом культуры	t	medium
5379	31998	572	республика Дагестан, Кайтагский район, село Джавгат, сельсовет Джавгатский, Дом культуры	t	large
5386	32006	579	республика Дагестан, Кайтагский район, село Дакниса, здание школы	t	small
5378	31997	571	республика Дагестан, Кайтагский район, село Гулли, Дом культуры	t	large
5389	32009	582	республика Дагестан, Кайтагский район, село Гулды, Здание школы	t	small
5375	31994	568	республика Дагестан, Кайтагский район, село Газия	t	small
5376	31995	569	республика Дагестан, Кайтагский район, село Варсит, Дом культуры	t	small
5374	31993	567	республика Дагестан, Кайтагский район, село Баршамай, Дом культуры	t	large
5377	31996	570	республика Дагестан, Кайтагский район, село Бажлук, Здание школы	t	small
5371	31990	564	республика Дагестан, Кайтагский район, село Ахмедкент, Дом культуры	f	medium
5404	32024	597	республика Дагестан, Кайтагский район, село Адага, Здание школы	t	small
5397	32017	590	республика Дагестан, Кайтагский район, село Абдашка, Дом культуры	f	large
5369	31988	562	республика Дагестан, Казбековский район, село Хубар, здание клуба	t	large
5360	31979	553	республика Дагестан, Казбековский район, село Калининаул, здание школы №2	t	large
5359	31978	552	республика Дагестан, Казбековский район, село Калининаул, здание СПК	t	large
5358	31977	551	республика Дагестан, Казбековский район, село Инчха, здание СОШ	t	large
5357	31976	550	республика Дагестан, Казбековский район, село Имросов, сельсовет Артлухский, здание клуба	t	small
5356	31975	549	республика Дагестан, Казбековский район, село Дылым, здание школы	f	large
5355	31974	548	республика Дагестан, Казбековский район, село Дылым, здание РДК	f	large
5354	31973	547	республика Дагестан, Казбековский район, село Дылым, здание школы	f	large
5353	31972	546	республика Дагестан, Казбековский район, поселок Дубки	t	large
5352	31971	545	республика Дагестан, Казбековский район, поселок Дубки, здание школы	t	large
5351	31969	544	республика Дагестан, Казбековский район, село Гуни, СПК Новая жизнь	t	large
5350	31968	543	республика Дагестан, Казбековский район, село Гостала, здание сельского дома культуры	t	small
5349	31967	542	республика Дагестан, Казбековский район, село Гертма, здание сельского дома культуры	t	large
5348	31966	541	республика Дагестан, Казбековский район, село Буртунай, здание сельского дома культуры 	t	large
5347	31965	540	республика Дагестан, Казбековский район, село Ахтачикан, здание Клуба	t	small
5365	31984	558	республика Дагестан, Казбековский район, село Артлух, здание СПК	t	small
5346	31964	539	республика Дагестан, Казбековский район, село Артлух, здание библиотеки	t	small
5345	31963	538	республика Дагестан, Казбековский район, село Алмак, здании сельского клуба	t	large
5326	31945	519	республика Дагестан, Докузпаринский район, село Усухчай, Здание сельского дома культуры	f	large
5322	31940	515	республика Дагестан, Докузпаринский район, село Текипиркент, Здание сельского дома культуры	t	small
5321	31939	514	республика Дагестан, Докузпаринский район, село Новое Каракюре, Здание школы	t	medium
5329	31948	522	республика Дагестан, Докузпаринский район, село Мискинджи, Здание школы	t	large
5328	31947	521	республика Дагестан, Докузпаринский район, село Микрах, Здание администрации	t	large
5325	31944	518	республика Дагестан, Докузпаринский район, село Куруш, Здание сельского дома культуры	t	medium
5327	31946	520	республика Дагестан, Докузпаринский район, село Килер, Здание сельского дома культуры	t	medium
5324	31943	517	республика Дагестан, Докузпаринский район, село Кара-Кюре, здание школы	t	medium
5323	31942	516	республика Дагестан, Докузпаринский район, село Каладжух	t	large
5320	31938	513	республика Дагестан, Докузпаринский район, село Авадан, Здание администрации	t	large
5260	31879	453	республика Дагестан, Дербентский район, село Чинар, Здание СДК	t	large
5269	31888	462	республика Дагестан, Дербентский район, село Хазар, Здание СДК	t	large
5245	31864	438	республика Дагестан, Дербентский район, село Уллутеркеме, Здание СДК	t	medium
5247	31866	440	республика Дагестан, Дербентский район, село Татляр, здание агрофирмы Татляр	t	medium
5251	31870	444	республика Дагестан, Дербентский район, село Салик, Здание агрофирмы Шейхляр	t	large
5264	31883	457	республика Дагестан, Дербентский район, село Сабнова, Здание школы	t	large
5249	31868	442	республика Дагестан, Дербентский район, село Рыбзавод - 51, Здание бывшей школы	t	small
5268	31887	461	республика Дагестан, Дербентский район, село Рукель, Здание школы	t	large
5272	31891	465	республика Дагестан, Дербентский район, село Рубас, Здание агрофирмы Рубас	t	large
5252	31871	445	республика Дагестан, Дербентский район, село Падар, Здание СДК	t	large
5282	31901	475	республика Дагестан, Дербентский район, село Нюгди, Здание администрации	t	large
6429	33001	1622	республика Дагестан, Дербентский район, село Новофриг, Средняя школа	f	large
5266	31885	459	республика Дагестан, Дербентский район, село Нижний Джалган, сельсовет Хазарский, Здание школы	t	large
5271	31890	464	республика Дагестан, Дербентский район, село Музаим, Здание школы 	t	large
5267	31886	460	республика Дагестан, Дербентский район, село Мугарты, Здание школы	t	medium
5261	31880	454	республика Дагестан, Дербентский район, село Митаги-Казмаляр, Здание СДК	t	medium
5262	31881	455	республика Дагестан, Дербентский район, село Митаги, Здание администрации	t	small
5256	31875	449	республика Дагестан, Дербентский район, поселок Мамедкала, Здание школы №1	t	large
5255	31874	448	республика Дагестан, Дербентский район, поселок городского типа Мамедкала, Здание школы №2	t	large
5254	31873	447	республика Дагестан, Дербентский район, поселок городского типа Мамедкала, Здание клуба	t	large
5283	31902	476	республика Дагестан, Дербентский район, село Куллар, Здание СДК	t	large
5273	31892	466	республика Дагестан, Дербентский район, село Коммуна, Здание школы 	t	medium
5246	31865	439	республика Дагестан, Дербентский район, село Карадаглы, Здание магазина 	t	small
5250	31869	443	республика Дагестан, Дербентский район, село Кала	t	large
5248	31867	441	республика Дагестан, Дербентский район, село Имени Мичурина, Здание агрофирмы Каспий	t	large
5263	31882	456	республика Дагестан, Дербентский район, село Зидьян-Казмаляр, Здание СДК	t	medium
5270	31889	463	республика Дагестан, Дербентский район, Дюзляр, здание школы	t	small
5242	31861	435	республика Дагестан, Дербентский район, село Джемикент, Здание администрации 	t	large
5265	31884	458	республика Дагестан, Дербентский район, село Джалган, Здание СДК	t	small
5244	31825	437	республика Дагестан, Дербентский район, село Деличобан, Здание СДК	t	large
5258	31877	451	республика Дагестан, Дербентский район, село Геджух, Здание СДК	t	large
5257	31876	450	республика Дагестан, Дербентский район, село Геджух, здание музыкальной школы	t	large
5243	31862	436	республика Дагестан, Дербентский район, село Великент, Здание СДК	t	large
5259	31878	452	республика Дагестан, Дербентский район, село Бильгады, Здание СДК	t	small
5253	31872	446	республика Дагестан, Дербентский район, село Берикей	t	large
5279	31898	472	республика Дагестан, Дербентский район, поселок Белиджи, Здание школы имени Лезгинцева	t	large
5278	31897	471	республика Дагестан, Дербентский район, поселок Белиджи, Здание школы №2	t	large
5277	31896	470	республика Дагестан, Дербентский район, поселок Белиджи, Здание СДК	t	large
5280	31899	473	республика Дагестан, Дербентский район, поселок городского типа Белиджи, Здание школы-гимназии	t	large
5276	31895	469	республика Дагестан, Дербентский район, поселок городского типа Белиджи, Здание школы №1	t	large
5281	31900	474	республика Дагестан, Дербентский район, село Белиджи, Здание СДК	t	large
5644	32251	837	республика Дагестан, Дербентский район, село Арабляр, Здание школы 	t	small
5275	31894	468	республика Дагестан, Дербентский район, поселок Араблинский, Здание агрофирмы Араблинское	t	large
5643	32250	836	республика Дагестан, Дербентский район, село Аладаш, Школа	t	medium
5274	31893	467	республика Дагестан, Дербентский район, село Аглоби, Здание школы	t	large
5288	31863	481	республика Дагестан, Дербент городской округ, Дербент, Буйнакского, 17	f	large
5210	31828	403	республика Дагестан, Дахадаевский район, село Шулерчи, Помещение начальной школы	t	small
5203	31820	396	республика Дагестан, Дахадаевский район, село Шадни, Помещение сельского клуба	t	small
5190	31807	383	республика Дагестан, Дахадаевский район, село Чищили, Помещение дома культуры	t	small
5205	31822	398	республика Дагестан, Дахадаевский район, село Цураи, Помещение Дома Культуры	t	small
5204	31821	397	республика Дагестан, Дахадаевский район, село Цизгари, Помещение дома культуры	t	small
5212	31830	405	республика Дагестан, Дахадаевский район, село Хуршни	t	small
5221	31840	414	республика Дагестан, Дахадаевский район, село Хулабаркмахи, Помещение средней школы	t	small
5230	31849	423	республика Дагестан, Дахадаевский район, село Худуц, Помещение дома культуры	t	small
5211	31829	404	республика Дагестан, Дахадаевский район, село Харбук, Помещение дома культуры 	t	large
5237	31856	430	республика Дагестан, Дахадаевский район, Урцаки, Помещение дома культуры	t	small
5218	31836	411	республика Дагестан, Дахадаевский район, село Урхнища, Помещение сельской библиотеки	t	small
5219	31837	412	республика Дагестан, Дахадаевский район, Уркудта, Помещение сельской библиотеки 	t	small
5223	31842	416	республика Дагестан, Дахадаевский район, село Уркарах, Помещение начальной школы	t	small
5187	31804	380	республика Дагестан, Дахадаевский район, село Уркарах, Спортзал УМГ	f	large
5186	31803	379	республика Дагестан, Дахадаевский район, село Уркарах, Районный Дом Культуры	f	large
5188	31805	381	республика Дагестан, Дахадаевский район, село Уркарах, Пироговский, Здание УМЛицея	f	large
5215	31833	408	республика Дагестан, Дахадаевский район, село Урари, омещение Дома Культуры	t	small
5234	31853	427	республика Дагестан, Дахадаевский район, село Ураги, Помещение дома культуры	t	small
5193	31810	386	республика Дагестан, Дахадаевский район, село Трисанчи, Здание средней школы	t	large
5238	31857	431	республика Дагестан, Дахадаевский район, село Сутбук	t	small
5189	31806	382	республика Дагестан, Дахадаевский район, село Новый Уркарах, сельсовет Уркарахский, Здание школы	t	medium
5206	31823	399	республика Дагестан, Дахадаевский район, село Морское, помещение Дома Культуры	t	medium
5213	31831	406	республика Дагестан, Дахадаевский район, село Мирзидты, Помешение начальной школы	t	small
5207	31824	400	республика Дагестан, Дахадаевский район, село Меусиша, Помещение Дома Культуры	t	large
5227	31846	420	республика Дагестан, Дахадаевский район, село Кунки, помещение дома культуры	t	medium
5196	31813	389	республика Дагестан, Дахадаевский район, село Кудагу, Помещение Дома Культуры	t	small
5235	31854	428	республика Дагестан, Дахадаевский район, поселок Кубачи, Помещение средней школы	f	large
5236	31855	429	республика Дагестан, Дахадаевский район, поселок Кубачи, Новый, Помещение администрации поселка	f	large
5222	31841	415	республика Дагестан, Дахадаевский район, село Кищамахи, Помещение начальной школы	t	small
5209	31827	402	республика Дагестан, Дахадаевский район, село Кища, Здание Кищинской МГ	t	large
5208	31826	401	республика Дагестан, Дахадаевский район, село Кища, Помещение Дома Культуры	t	large
5225	31844	418	республика Дагестан, Дахадаевский район, село Карбучимахи, Помещение дома культуры	t	small
5200	31817	393	республика Дагестан, Дахадаевский район, село Калкни, Помещение Дома Культуры	t	medium
5231	31850	424	республика Дагестан, Дахадаевский район, село Ицари, Помещение сельского клуба	t	small
5198	31815	391	республика Дагестан, Дахадаевский район, село Ираки, Помещение сельского клуба	t	small
5197	31814	390	республика Дагестан, Дахадаевский район, село Ираги, Помещение Дома Культуры	t	medium
5194	31811	387	республика Дагестан, Дахадаевский район, село Зубанчи, Помещение дома культуры	t	medium
5195	31812	388	республика Дагестан, Дахадаевский район, село Зильбачи, Сельский Дом Культуры	t	medium
5224	31843	417	республика Дагестан, Дахадаевский район, село Дуакар, Помещение начальной школы	t	small
5220	31839	413	республика Дагестан, Дахадаевский район, село Дуакар, Помещение администрации с/с	t	small
5229	31848	422	республика Дагестан, Дахадаевский район, село Дирбакмахи, Помещение неполной средней школы	t	small
5199	31816	392	республика Дагестан, Дахадаевский район, село Дибгаши, Помещение Дома Культуры	t	medium
5191	31808	384	республика Дагестан, Дахадаевский район, село Дибгалик, Сельский Дом Культуры	t	small
5232	31851	425	республика Дагестан, Дахадаевский район, село Дзилебки	t	small
5192	31809	385	республика Дагестан, Дахадаевский район, село Джурмачи, сельсовет Трисанчинский, Сельский дом культуры	t	small
5201	31818	394	республика Дагестан, Дахадаевский район, село Гунакари, Помещение сельского клуба 	t	small
5214	31832	407	республика Дагестан, Дахадаевский район, село Гуладты, Помещение дома культуры	t	small
5241	31860	434	республика Дагестан, Дахадаевский район, село Губа-Кутан, Помещение конторы СПК Карбачимахи	t	small
5202	31819	395	республика Дагестан, Дахадаевский район, село Бускри, Помещение дома культуры 	t	medium
5239	31858	432	республика Дагестан, Дахадаевский район, село Бакни, Помещение Дома Культуры	t	small
5216	31834	409	республика Дагестан, Дахадаевский район, село Аяцури, Помещение неполной средней школы	t	small
5226	31845	419	республика Дагестан, Дахадаевский район, село Аяцимахи	t	small
5228	31847	421	республика Дагестан, Дахадаевский район, село Ашты	t	small
5172	31789	365	республика Дагестан, Гунибский район, село Шулани, здание школы	t	small
5157	31773	350	республика Дагестан, Гунибский район, село Хутни, здание школы	t	small
5164	31780	357	республика Дагестан, Гунибский район, село Хоточ, СДК	t	medium
5163	31779	356	республика Дагестан, Гунибский район, село Хиндах, СДК	t	medium
5173	31790	366	республика Дагестан, Гунибский район, село Унты, здание школы	t	small
5148	31764	341	республика Дагестан, Гунибский район, село Тлогоб, СДК	t	medium
5160	31776	353	республика Дагестан, Гунибский район, село Согратль, СДК	t	medium
5146	31762	339	республика Дагестан, Гунибский район, Силта, здание Силтинской школы	t	small
5158	31774	351	республика Дагестан, Гунибский район, село Салта, СДК	t	small
5155	31771	348	республика Дагестан, Гунибский район, село Ругуджа, СДК	t	medium
5153	31769	346	республика Дагестан, Гунибский район, село Обох, здание администрации села	t	small
5161	31777	354	республика Дагестан, Гунибский район, село Наказух, СДК	t	small
5141	31757	334	республика Дагестан, Гунибский район, село Н.Кегер, СДК	t	small
5151	31767	344	республика Дагестан, Гунибский район, село Мегеб, СДК	t	small
5145	31761	338	республика Дагестан, Гунибский район, село Кудали, СДК	t	medium
5142	31758	335	республика Дагестан, Гунибский район, село Корода	t	small
5166	31783	359	республика Дагестан, Гунибский район, село Коммуна, СДК	t	small
5139	31755	332	республика Дагестан, Гунибский район, село Кегер, СДК	t	small
5143	31759	336	республика Дагестан, Гунибский район, село Карадах, СДК	t	small
5137	31753	330	республика Дагестан, Гунибский район, село Гуниб, Площадь Шамиля, СДК	f	large
5138	31754	331	республика Дагестан, Гунибский район, село Гуниб, Пирогова, здание больницы	f	small
5136	31752	329	республика Дагестан, Гунибский район, село Гонода, здание администрации	t	medium
5134	31750	327	республика Дагестан, Гунибский район, село Бухты	t	small
5132	31748	325	республика Дагестан, Гунибский район, село Бацада, Сельский дом культуры	t	medium
5149	31765	342	республика Дагестан, Гунибский район, село Агада, здание школы	t	medium
5115	31731	308	республика Дагестан, Гумбетовский район, село Шпрингель	t	small
5119	31735	312	республика Дагестан, Гумбетовский район, село Шабдух	t	small
5130	31746	323	республика Дагестан, Гумбетовский район, село Читль	t	small
5131	31747	324	республика Дагестан, Гумбетовский район, село Чирката	t	small
5125	31741	318	республика Дагестан, Гумбетовский район, село Цияб-Цилитль	t	small
5124	31740	317	республика Дагестан, Гумбетовский район, село Цилитль	t	small
5108	31724	301	республика Дагестан, Гумбетовский район, село Цанатль	t	small
5104	31720	297	республика Дагестан, Гумбетовский район, село Тлярата	t	small
5107	31723	300	республика Дагестан, Гумбетовский район, село Тантари	t	small
5114	31730	307	республика Дагестан, Гумбетовский район, село Средний Арадирих	t	small
5121	31737	314	республика Дагестан, Гумбетовский район, Первомайск	t	small
5123	31739	316	республика Дагестан, Гумбетовский район, Отавтюбе	t	small
5110	31726	303	республика Дагестан, Гумбетовский район, село Новые Аргвани	t	small
5113	31729	306	республика Дагестан, Гумбетовский район, село Нижний Арадирих	t	large
5128	31744	321	республика Дагестан, Гумбетовский район, село Нижнее Инхо	t	small
5103	31719	296	республика Дагестан, Гумбетовский район, село Нарыш, Сельсовет Мехельтинский	t	small
5111	31727	304	республика Дагестан, Гумбетовский район, село Нанибика	t	medium
5101	31717	294	республика Дагестан, Гумбетовский район, село Мехельта, сельский	f	medium
5100	31716	293	республика Дагестан, Гумбетовский район, село Мехельта, райцентр	f	medium
5116	31732	309	республика Дагестан, Гумбетовский район, село Кучкаркум	t	small
5106	31722	299	республика Дагестан, Гумбетовский район, село Кунзах	t	medium
5127	31743	320	республика Дагестан, Гумбетовский район, село Килятль	t	medium
5120	31736	313	республика Дагестан, Гумбетовский район, село Ичичали	t	small
5122	31738	315	республика Дагестан, Гумбетовский район, село Ингиши	t	small
5105	31721	298	республика Дагестан, Гумбетовский район, село Игали	t	small
5118	31734	311	республика Дагестан, Гумбетовский район, село Данух	t	small
5117	31733	310	республика Дагестан, Гумбетовский район, село Данух	t	small
5126	31742	319	республика Дагестан, Гумбетовский район, село Гадари	t	large
5112	31728	305	республика Дагестан, Гумбетовский район, село Верхний Арадерих	t	small
5129	31745	322	республика Дагестан, Гумбетовский район, село Верннее Инхо	t	small
5109	31725	302	республика Дагестан, Гумбетовский район, село Аргвани	t	small
5084	31701	277	республика Дагестан, Гергебильский район, село Чалда, здание школы	t	small
5094	31711	287	республика Дагестан, Гергебильский район, село Хвартикуни, здание клуба 	t	medium
5096	31713	289	республика Дагестан, Гергебильский район, село Хварада, здание библиотеки	t	small
5095	31712	288	республика Дагестан, Гергебильский район, село Тунзы, здание клуба	t	small
5092	31709	285	республика Дагестан, Гергебильский район, село Мурада, здание клуба	t	small
5089	31706	282	республика Дагестан, Гергебильский район, село Могох, здание клуба	t	small
5088	31705	281	республика Дагестан, Гергебильский район, село Маали, здание школы 	t	large
5086	31703	279	республика Дагестан, Гергебильский район, село Курми, здание клуба	t	medium
5087	31704	280	республика Дагестан, Гергебильский район, село Кудутль	t	small
5083	31700	276	республика Дагестан, Гергебильский район, село Кикуни, здание школы	t	large
5085	31702	278	республика Дагестан, Гергебильский район, село Ипута, здание библиотеки	t	small
5091	31708	284	республика Дагестан, Гергебильский район, село Дарада, здание клуба	t	small
5090	31707	283	республика Дагестан, Гергебильский район, село Гоцоб, здание библиотеки	t	small
5093	31710	286	республика Дагестан, Гергебильский район, Горбони, здание клуба	t	small
5081	31698	274	республика Дагестан, Гергебильский район, село Гергебиль, здание клуба	f	large
5080	31698	273	республика Дагестан, Гергебильский район, село Гергебиль, здание клуба	f	large
5082	31699	275	республика Дагестан, Гергебильский район, село Аймаки, здание школы	t	large
5054	31678	247	республика Дагестан, Буйнакский район, село Эрпели, здание средней школы, школа	t	large
5055	31678	248	республика Дагестан, Буйнакский район, село Эрпели, здание средней школы, школа	t	small
5053	31677	246	республика Дагестан, Буйнакский район, село Чиркей, здание дом культуры	t	large
5052	31676	245	республика Дагестан, Буйнакский район, село Чиркей, здании средней школы	t	large
5051	31675	244	республика Дагестан, Буйнакский район, село Чиркей, здание администрации села	t	large
5050	31674	243	республика Дагестан, Буйнакский район, село Чанкурбе, в здании сельского клуба 	t	medium
5041	31664	234	республика Дагестан, Буйнакский район, село Чабанмахи, здание администрации	t	large
5049	31673	242	республика Дагестан, Буйнакский район, село Халимбекаул, здание средней школы	t	large
5891	32490	1084	республика Дагестан, Буйнакский район, село Талги	f	large
5039	31662	232	республика Дагестан, Буйнакский район, село Такалай, здание средней школы	t	small
5038	31661	231	республика Дагестан, Буйнакский район, село Новый Кумух, здание администрации	t	large
5033	31655	226	республика Дагестан, Буйнакский район, село Нижний Каранай, бывшее здание медпункта	t	small
5044	31667	237	республика Дагестан, Буйнакский район, село Нижний Дженгутай, здание сельского клуба	t	large
5043	31666	236	республика Дагестан, Буйнакский район, село Нижний Дженгутай, здание средней школы 	t	large
5048	31672	241	республика Дагестан, Буйнакский район, село Нижнее Казанище, здание средней школы №3	t	large
5047	31670	240	республика Дагестан, Буйнакский район, село Нижнее Казанище, здание средней школы №4	t	medium
5046	31669	239	республика Дагестан, Буйнакский район, село Нижнее Казанище, здание средней школы №1	t	large
5045	31668	238	республика Дагестан, Буйнакский район, село Нижнее Казанище, здание дома культуры	t	large
5042	31665	235	республика Дагестан, Буйнакский район, село Манасаул, здание дома культуры	t	medium
5037	31660	230	республика Дагестан, Буйнакский район, село Кафыр-Кумух, бывшее здание магазина сельпо	t	medium
5040	31663	233	республика Дагестан, Буйнакский район, село Кара-Махи, здание средней школы	t	large
5036	31659	229	республика Дагестан, Буйнакский район, село Кадар, здание дома культуры	t	large
5034	31656	227	республика Дагестан, Буйнакский район, село Дуранги, здание средней школы	t	small
5032	31654	225	республика Дагестан, Буйнакский район, село Верхний Каранай, здание сельского клуба	t	medium
5031	31653	224	республика Дагестан, Буйнакский район, село Верхний Дженгутай, здание сельского клуба	t	large
5035	31658	228	республика Дагестан, Буйнакский район, село Верхние Ишкарты, сельсовет Ишкартынский, здание сельского клуба, клуб	t	medium
5030	31652	223	республика Дагестан, Буйнакский район, село Верхнее Казанище, здание сельского клуба	t	small
5029	31651	222	республика Дагестан, Буйнакский район, село Верхнее Казанище, здание средней школы №2	t	large
5028	31650	221	республика Дагестан, Буйнакский район, село Верхнее Казанище, Здание средней школы №1	t	large
5027	31649	220	республика Дагестан, Буйнакский район, село Буглен, Здание средней школы	t	large
5025	31647	218	республика Дагестан, Буйнакский район, село Атланаул, Здание средней школы	t	large
5022	31644	215	республика Дагестан, Буйнакский район, село Аркас, сельский клуб	t	small
5026	31648	219	республика Дагестан, Буйнакский район, село Акайтала, Здание сельского клуба	t	small
5441	32060	634	республика Дагестан, Буйнакский район, село Агачаул, Школа	f	large
4984	31603	177	республика Дагестан, Ботлихский район, участок Чиртинский, сельсовет Ботлихский	t	large
4980	31599	173	республика Дагестан, Ботлихский район, кутан Старокаратюбинский, сельсовет Ансалтинский	t	small
5018	31639	211	республика Дагестан, Ботлихский район, кутан Прикутанский, сельсовет Чанковский	t	small
4994	31614	187	республика Дагестан, Ботлихский район, кутан Комархуторский	t	small
5010	31631	203	республика Дагестан, Ботлихский район, кутан Джугутский, сельсовет Рикванинский	t	small
5017	31638	210	республика Дагестан, Ботлихский район, село Чанко, сельсовет Чанковский, участок Шивортинский	t	small
5016	31637	209	республика Дагестан, Ботлихский район, село Чанко	t	small
4975	31593	168	республика Дагестан, Ботлихский район, село Цибилта	t	small
5014	31635	207	республика Дагестан, Ботлихский район, село Хелетури	t	small
5013	31634	206	республика Дагестан, Ботлихский район, село Тлох, участок Тлох 2	t	medium
5012	31633	205	республика Дагестан, Ботлихский район, село Тлох	t	large
4986	31605	179	республика Дагестан, Ботлихский район, село Тасута	t	small
5011	31632	204	республика Дагестан, Ботлихский район, село Тандо	t	small
4993	31613	186	республика Дагестан, Ботлихский район, Село Беледи	t	small
5004	31624	197	республика Дагестан, Ботлихский район, село Рушуха	t	small
5009	31630	202	республика Дагестан, Ботлихский район, село Риквани, сельсовет Рикванинский	t	small
5008	31629	201	республика Дагестан, Ботлихский район, село Рахата	t	small
5007	31628	200	республика Дагестан, Ботлихский район, село Рахата, 2	t	small
5006	31626	199	республика Дагестан, Ботлихский район, село Рахата	t	large
5003	31623	196	республика Дагестан, Ботлихский район, село Ортаколо	t	small
5005	31625	198	республика Дагестан, Ботлихский район, село Нижнее Инхело	t	medium
5002	31622	195	республика Дагестан, Ботлихский район, село Муни	t	small
5001	31621	194	республика Дагестан, Ботлихский район, село Муни	t	large
5000	31620	193	республика Дагестан, Ботлихский район, село Миарсо	t	large
4999	31619	192	республика Дагестан, Ботлихский район, село Кижани	t	small
4998	31618	191	республика Дагестан, Ботлихский район, село Кижани	t	small
4997	31617	190	республика Дагестан, Ботлихский район, село Кванхидатли	t	small
4996	31616	189	республика Дагестан, Ботлихский район, село Зило	t	small
4995	31615	188	республика Дагестан, Ботлихский район, село Зило	t	medium
4992	31612	185	республика Дагестан, Ботлихский район, село Зиберхали	t	small
4974	31592	167	республика Дагестан, Ботлихский район, село Гунха	t	small
4990	31609	183	республика Дагестан, Ботлихский район, село Гагатли	t	small
4989	31608	182	республика Дагестан, Ботлихский район, село Гагатли	t	small
4988	31607	181	республика Дагестан, Ботлихский район, село Гагатли	t	large
4985	31604	178	республика Дагестан, Ботлихский район, село Ботлих	t	large
4983	31602	176	республика Дагестан, Ботлихский район, село Ботлих, сельсовет Ботлихский	f	large
4987	31606	180	республика Дагестан, Ботлихский район, село Ашино	t	small
4982	31601	175	республика Дагестан, Ботлихский район, село Ашали	t	small
4981	31600	174	республика Дагестан, Ботлихский район, село Ашали	t	small
4979	31598	172	республика Дагестан, Ботлихский район, село Ансалта	t	small
4978	31597	171	республика Дагестан, Ботлихский район, село Ансалта, сельсовет Ансалтинский	t	medium
4973	31591	166	республика Дагестан, Ботлихский район, село Анди, участок Саталалский	t	medium
4972	31590	165	республика Дагестан, Ботлихский район, село Анди	t	large
4971	31589	164	республика Дагестан, Ботлихский район, село Алак	t	small
4970	31588	163	республика Дагестан, Ботлихский район, село Алак	t	medium
4969	31588	162	республика Дагестан, Ботлихский район, село Алак	t	small
6601	33173	1794	республика Дагестан, Бежтинский Участок район, село Тлядал	t	small
6604	33174	1797	республика Дагестан, Бежтинский Участок район, село Гунзиб	t	small
6603	33174	1796	республика Дагестан, Бежтинский Участок район, село Гунзиб	t	small
6602	33174	1795	республика Дагестан, Бежтинский Участок район, село Гунзиб	t	small
6600	33172	1793	республика Дагестан, Бежтинский Участок район, село Бежта	f	small
4947	31565	140	республика Дагестан, Бабаюртовский район, село Чанкаюрт, сельсовет Адиль-Янгиюртовский, Здание школы	t	small
6654	33222	1847	республика Дагестан, Бабаюртовский район, Цадах	t	small
4951	31570	144	республика Дагестан, Бабаюртовский район, село Хасанай, Здание СДК	t	medium
5368	31987	561	республика Дагестан, Бабаюртовский район, село Хамзаюрт, здание школы	t	small
4946	31564	139	республика Дагестан, Бабаюртовский район, село Хамамат-Юрт, Здание СДК	t	large
4945	31563	138	республика Дагестан, Бабаюртовский район, село Уцмиюрт, Здание СДК	t	large
4961	31580	154	республика Дагестан, Бабаюртовский район, село Тюпкутан (Алимпашаюрт), Здание школы	t	small
5366	31985	559	республика Дагестан, Бабаюртовский район, село Турщунай, здание школы	t	small
4949	31568	142	республика Дагестан, Бабаюртовский район, село Турщунай, сельсовет Туршунайский, Здание сельского клуба	t	medium
5367	31986	560	республика Дагестан, Бабаюртовский район, село Татаюрт, прикутанного хозяйства Учтюбе, здание школы	t	small
4963	31582	156	республика Дагестан, Бабаюртовский район, село Татаюрт, Здание школы	t	large
4965	31584	158	республика Дагестан, Бабаюртовский район, село Тамаза-Тюбе, Здание сельской администрации	t	large
4966	31585	159	республика Дагестан, Бабаюртовский район, село Старое Тамазатюбе, Здание сельского клуба, сельсовет Тамазатюбинский	t	small
4950	31569	143	республика Дагестан, Бабаюртовский район, село Советское, Здание сельского клуба 	t	medium
5696	32306	889	республика Дагестан, Бабаюртовский район, село Сангар	t	small
4964	31583	157	республика Дагестан, Бабаюртовский район, село Новокаре, здание школы	t	large
4967	31586	160	республика Дагестан, Бабаюртовский район, село Новая Коса, Сельсовет Новокосинский, Здание сельской администрации	t	small
4960	31579	153	республика Дагестан, Бабаюртовский район, село Мужукай	t	small
4952	31571	145	республика Дагестан, Бабаюртовский район, село Люксембург, Здание школы	t	large
6495	33066	1688	республика Дагестан, Бабаюртовский район, село Львовский 7-й, здание НШ	f	small
5364	31983	557	республика Дагестан, Бабаюртовский район, село Львовский 6-й, здание школы №2	t	small
5140	31756	333	республика Дагестан, Бабаюртовский район, село Львовский 1-й	t	small
4968	31587	161	республика Дагестан, Бабаюртовский район, село Львовский 1-й, Здание сельской администрации	t	medium
4976	31595	169	республика Дагестан, Бабаюртовский район, село Кутан-Бутуш, сельсовет Андийский	t	medium
5144	31760	337	республика Дагестан, Бабаюртовский район, Кородинский кутан, здание АФ	t	small
4953	31572	146	республика Дагестан, Бабаюртовский район, село Герменчик, Здание СДК	t	large
4962	31581	155	республика Дагестан, Бабаюртовский район, село Геметюбе, Здание школы	t	medium
6662	33230	1855	республика Дагестан, Бабаюртовский район, село Бабаюрт, улица Зона Отдыха, Бабаюртовская зона	t	small
4959	31578	152	республика Дагестан, Бабаюртовский район, село Бабаюрт, Мира, 129, Здание ПМК-1 Газпром	f	large
4956	31575	149	республика Дагестан, Бабаюртовский район, село Бабаюрт, Ленина, 1, Здание школы	f	large
4954	31573	147	республика Дагестан, Бабаюртовский район, село Бабаюрт, Ирчи-Казака , 80, Здание школы	f	large
4958	31577	151	республика Дагестан, Бабаюртовский район, село Бабаюрт, Дж. Алиева, 61, Здание школы	f	large
4955	31574	148	республика Дагестан, Бабаюртовский район, село Бабаюрт, Дж. Алиева, 24, Здание МУ 	f	large
4957	31576	150	республика Дагестан, Бабаюртовский район, село Бабаюрт, Алиева, 49, Здание Дзержинского филиала ФГУ	f	large
6588	33162	1781	республика Дагестан, Бабаюртовский район, село Ахайотар	t	small
5674	32283	867	республика Дагестан, Бабаюртовский район, село Арцалу, Сельсовет Буршинский, Контора колхоза	t	small
5020	31641	213	республика Дагестан, Бабаюртовский район, село Анхвала, сельсовет Шодродинский	t	small
4948	31566	141	республика Дагестан, Бабаюртовский район, село Адиль-Янги-Юрт, Здание школы	t	large
4944	31562	137	республика Дагестан, Ахтынский район, село Ялак, клуб	t	small
4943	31561	136	республика Дагестан, Ахтынский район, село Хрюг, школа	t	medium
4942	31560	135	республика Дагестан, Ахтынский район, село Хрюг, клуб	t	medium
4941	31559	134	республика Дагестан, Ахтынский район, село Хнов	t	small
4940	31558	133	республика Дагестан, Ахтынский район, село Хнов, клуб	t	medium
4937	31555	130	республика Дагестан, Ахтынский район, село Ухул	t	small
4934	31552	127	республика Дагестан, Ахтынский район, село Усур, клуб	t	medium
4939	31557	132	республика Дагестан, Ахтынский район, село Старый Хкем, сельсовет Ахтынский, клуб	t	small
4935	31553	128	республика Дагестан, Ахтынский район, село Смугул, клуб	t	small
4938	31556	131	республика Дагестан, Ахтынский район, Село Фий, клуб	t	medium
4933	31521	126	республика Дагестан, Ахтынский район, село Миджах, клуб	t	small
4932	31550	125	республика Дагестан, Ахтынский район, село Луткун, клуб	t	medium
4931	31549	124	республика Дагестан, Ахтынский район, село Луткун, школа	t	large
4930	31548	123	республика Дагестан, Ахтынский район, село Куркал	t	medium
4928	31546	121	республика Дагестан, Ахтынский район, село Калук, клуб	t	medium
4927	31545	120	республика Дагестан, Ахтынский район, село Кака, клуб	t	large
4926	31544	119	республика Дагестан, Ахтынский район, село Зрых, клуб	t	large
4925	31543	118	республика Дагестан, Ахтынский район, село Джаба, клуб	t	small
4924	31542	117	республика Дагестан, Ахтынский район, село Гогаз, клуб	t	small
4923	31541	116	республика Дагестан, Ахтынский район, село Гдынк, клуб	t	small
4922	31540	115	республика Дагестан, Ахтынский район, село Гдым, клуб	t	small
4921	31539	114	республика Дагестан, Ахтынский район, село Ахты, здание сырзавода	f	medium
4918	31536	111	республика Дагестан, Ахтынский район, село Ахты	t	small
4917	31535	110	республика Дагестан, Ахтынский район, село Ахты	f	medium
4915	31533	108	республика Дагестан, Ахтынский район, село Ахты, Самурского, Музыкальная школа	f	medium
4914	31532	107	республика Дагестан, Ахтынский район, село Ахты, Ленина, Кантора Агасиева	f	large
4913	31531	106	республика Дагестан, Ахтынский район, село Ахты, Ленина, Районный дом культуры	f	large
4920	31538	113	республика Дагестан, Ахтынский район, село Ахты, Байрамова, Ахтынская СОШ №2	f	large
4919	31537	112	республика Дагестан, Ахтынский район, село Ахты, Байрамова, Ахтынская ООШ №3	f	large
4916	31534	109	республика Дагестан, Ахтынский район, село Ахты, Аливердиева, Ахтынская СОШ №1	f	large
4911	31529	104	республика Дагестан, Ахвахский район, село Цолода, здание школы	t	small
4910	31528	103	республика Дагестан, Ахвахский район, село Цолода, здание школы	t	medium
4895	31512	88	республика Дагестан, Ахвахский район, село Цвакилколо, здание школы	t	small
4891	31508	84	республика Дагестан, Ахвахский район, село Тукита, здание Администрации	t	small
4899	31516	92	республика Дагестан, Ахвахский район, село Тлиси, здание школы	t	small
4906	31524	99	республика Дагестан, Ахвахский район, село Тлибишо, здание сельхозкооператива	t	small
4898	31515	91	республика Дагестан, Ахвахский район, село Тлибишо, здание сельхозкооператива	t	small
4897	31514	90	республика Дагестан, Ахвахский район, село Тлибишо, здание школы	t	small
4905	31523	98	республика Дагестан, Ахвахский район, село Тад-Магитль, здание школы	t	small
4894	31511	87	республика Дагестан, Ахвахский район, село Тад-Магитль, здание школы	t	medium
4882	31499	75	республика Дагестан, Ахвахский район, село Рачабулда, здание библиотеки	t	small
4887	31504	80	республика Дагестан, Ахвахский район, село Рацитль, здание школы	t	small
4900	31517	93	республика Дагестан, Ахвахский район, село Местерух, здание сельхозкооператива	t	small
4890	31507	83	республика Дагестан, Ахвахский район, село Местерух, здание клуба	t	small
4904	31522	97	республика Дагестан, Ахвахский район, село Лологонитль, здание школы	t	medium
4896	31513	89	республика Дагестан, Ахвахский район, село Лологонитль, здание школы	t	small
4902	31519	95	республика Дагестан, Ахвахский район, село Кудиябросо, здание сельхозкооператива	t	small
4893	31510	86	республика Дагестан, Ахвахский район, село Кудиябросо, здание школы	t	medium
4907	31525	100	республика Дагестан, Ахвахский район, село Карата, здание сельхозкооператива 	t	small
4880	31497	73	республика Дагестан, Ахвахский район, село Карата, здание гимназии	f	small
4879	31496	72	республика Дагестан, Ахвахский район, село Карата, здание школы	f	large
4912	31530	105	республика Дагестан, Ахвахский район, село Ингердах, здание школы	t	small
4889	31506	82	республика Дагестан, Ахвахский район, село Ингердах, здание школы	t	medium
4903	31520	96	республика Дагестан, Ахвахский район, село Изано, здание школы	t	small
4892	31509	85	республика Дагестан, Ахвахский район, село Изано	t	small
4901	31518	94	республика Дагестан, Ахвахский район, село Верхнее Инхело, здание сельхозкооператива 	t	medium
4886	31503	79	республика Дагестан, Ахвахский район, село Верхнее Инхело, здание Администрации	t	small
4908	31526	101	республика Дагестан, Ахвахский район, село Арчо, здание сельхозкооператива	t	small
4881	31498	74	республика Дагестан, Ахвахский район, село Арчо	t	small
4883	31500	76	республика Дагестан, Ахвахский район, село Анчик, здание школы	t	small
4831	31448	24	республика Дагестан, Акушинский район, с. Панжи, здание СШ	f	large
4851	31468	44	республика Дагестан, Акушинский район, село Шумхримахи, здание СШ	f	medium
4878	31495	71	республика Дагестан, Акушинский район, село Шукты, здание сельский клуб	f	small
4876	31493	69	республика Дагестан, Акушинский район, село Цугни, здание сельской администрации 	f	medium
4861	31478	54	республика Дагестан, Акушинский район, село Уцулимахи, здание сельский клуб	f	small
4874	31491	67	республика Дагестан, Акушинский район, село Усиша, сельсовет Усишинский, здание СШ	t	medium
4873	31490	66	республика Дагестан, Акушинский район, село Усиша, здание СШ	t	large
4870	31487	63	республика Дагестан, Акушинский район, село Урхучимахи, здание сельский клуб	f	medium
4833	31450	26	республика Дагестан, Акушинский район, село Ургубамахи, здание СШ	t	small
4875	31492	68	республика Дагестан, Акушинский район, село Ургани, здание СШ	t	small
4868	31485	61	республика Дагестан, Акушинский район, село Уллучара, здание с/адм	f	small
4843	31460	36	республика Дагестан, Акушинский район, село Узнимахи, здание СШ	t	large
4867	31484	60	республика Дагестан, Акушинский район, село Тебекмахи, здание сельский клуб	t	large
4864	31481	57	республика Дагестан, Акушинский район, село Танты, здание с/адм	f	medium
4832	31449	25	республика Дагестан, Акушинский район, село Семгамахи, здание СШ	f	small
4863	31480	56	республика Дагестан, Акушинский район, село Наци, здание СШ	f	small
4860	31477	53	республика Дагестан, Акушинский район, село Нахки, здание сельский клуб	f	small
4859	31476	52	республика Дагестан, Акушинский район, село Муги, здание гимназии	t	large
4858	31475	51	республика Дагестан, Акушинский район, село Муги, здание СШ	t	large
4857	31474	50	республика Дагестан, Акушинский район, село Муги, Кутан Аралык, спец. дом	f	small
4869	31486	62	республика Дагестан, Акушинский район, село Куркимахи, здание СШ	t	medium
4866	31483	59	республика Дагестан, Акушинский район, село Куркимахи, здание СШ	f	small
4856	31473	49	республика Дагестан, Акушинский район, село Куркимахи, здание СШ	f	small
4862	31479	55	республика Дагестан, Акушинский район, село Кулиямахи, здание сельский клуб	f	small
4840	31457	33	республика Дагестан, Акушинский район, село Кули, здание библиотека	f	small
4855	31472	48	республика Дагестан, Акушинский район, село Кассагумахи, здание с/адм	f	small
4830	31447	23	республика Дагестан, Акушинский район, село Карша, Здание СШ	f	medium
4853	31470	46	республика Дагестан, Акушинский район, село Кавкамахи, Кутан спец. дом	f	small
4852	31469	45	республика Дагестан, Акушинский район, село Кавкамахи, здание сельский клуб	f	medium
4872	31489	65	республика Дагестан, Акушинский район, село Зильмукмахи, здание СШ	f	small
4850	31467	43	республика Дагестан, Акушинский район, село Дубримахи, здание сельского клуба	t	large
4828	31445	21	республика Дагестан, Акушинский район, село Гумрамахи, здание СШ	t	small
4865	31482	58	республика Дагестан, Акушинский район, село Гуладтымахи, здание сельский клуб	f	small
4849	31466	42	республика Дагестан, Акушинский район, село Гинта, здание СШ	t	medium
4847	31464	40	республика Дагестан, Акушинский район, село Гиба, здание сельской администрации	t	medium
4848	31465	41	республика Дагестан, Акушинский район, село Герхмахи, здание СШ	t	large
4846	31463	39	республика Дагестан, Акушинский район, село Гапшима, здание спортзал	t	large
4845	31462	38	республика Дагестан, Акушинский район, село Верхние Мулебки, здание с/адм	t	medium
4844	31461	37	республика Дагестан, Акушинский район, село Бутри, здание с/адм	f	medium
4842	31459	35	республика Дагестан, Акушинский район, село Бургимакмахи, здание с/адм	f	large
4841	31458	34	республика Дагестан, Акушинский район, село Балхар, кутан спец дом	f	small
4839	31456	32	республика Дагестан, Акушинский район, село Балхар, здание с/адм	f	medium
4838	31455	31	республика Дагестан, Акушинский район, село Аметеркамахи, здание СШ	f	small
4837	31454	30	республика Дагестан, Акушинский район, село Аметеркамахи, здание сельский клуб	f	medium
4836	31453	29	республика Дагестан, Акушинский район, село Алиханмахи, здание СШ	f	medium
4835	31452	28	республика Дагестан, Акушинский район, село Акуша, ДОМ СПЕЦ КУТАН Ног Р-Н	f	small
4834	31451	27	республика Дагестан, Акушинский район, село Акуша, здание с/адм	f	medium
4829	31446	22	республика Дагестан, Акушинский район, село Акуша, Здание СПК	f	large
4824	31441	17	республика Дагестан, Агульский район, село Яркуг, Клуб	t	small
5233	31852	426	республика Дагестан, Агульский район, село Шари, Помещение сельского клуба	t	small
4822	31439	15	республика Дагестан, Агульский район, село Чираг, Клуб	t	small
4823	31440	16	республика Дагестан, Агульский район, село Цирхе, Школа	t	small
4820	31437	13	республика Дагестан, Агульский район, село Хутхул, Администрация	f	small
4819	31435	12	республика Дагестан, Агульский район, село Худиг, клуб	t	small
4821	31438	14	республика Дагестан, Агульский район, село Фите, Клуб 	t	small
4818	31434	11	республика Дагестан, Агульский район, село Тпиг, Школа	f	large
4817	31433	10	республика Дагестан, Агульский район, село Рича, Школа	f	medium
4816	31432	9	республика Дагестан, Агульский район, село Миси, Школа	t	small
4815	31431	8	республика Дагестан, Агульский район, село Кураг, Администрация	t	small
4814	31430	7	республика Дагестан, Агульский район, село Дулдуг, Школа	f	small
4813	31429	6	республика Дагестан, Агульский район, село Гоа, клуб	t	small
4812	31428	5	республика Дагестан, Агульский район, село Буршаг	t	small
4811	31427	4	республика Дагестан, Агульский район, село Буркихан, Администрация	f	small
4810	31426	3	республика Дагестан, Агульский район, село Бедюк, Клуб	t	small
4809	31425	2	республика Дагестан, Агульский район, село Арсуг, Клуб	t	small
4808	31424	1	республика Дагестан, Агульский район, село Амух, Администрация	f	small
5841	32442	1034	республика Дагестан, Кировский район, село Шамхал Термен, Центр - помещение Клуб	f	large
25737	90710	114	Россия, Ставропольский край, Ставрополь, улица Шпаковская, 109	f	large
25736	90710	113	Россия, Ставропольский край, Ставрополь, улица Шпаковская, 109	f	large
26541	91491	919	Ставропольский край, Ставрополь, улица Широкая, МУККТ Долина	f	small
123462	91014	438	Россия, Ставропольский край, Ставрополь, улица Чайковского, 1	f	\N
25679	90657	57	Россия, Ставропольский край, Ставрополь, улица Советская, 12а	f	large
25734	90708	111	Россия, Ставропольский край, Ставрополь, улица Серова, 4к2	f	large
25664	90647	42	Ставропольский край, Ставрополь, улица Серова, 422	f	large
26748	91704	1127	Россия, Ставропольский край, Ставрополь, улица Сельская	f	large
25692	90670	70	Россия, Ставропольский край, Ставрополь, улица Репина, 146	f	large
26072	91027	450	Россия, Ставропольский край, Ставрополь, улица Пушкина, 1	f	large
25694	90672	72	Россия, Ставропольский край, Ставрополь, улица Пригородная, 70	f	large
25656	90639	34	Россия, Ставропольский край, Ставрополь, улица Пономарева, 1	f	large
25764	90733	141	Россия, Ставропольский край, Ставрополь, улица Пирогова, 58	f	large
26050	91005	428	Ставропольский край, Ставрополь, улица Октябрьская, 21	f	large
25707	90682	83	Россия, Ставропольский край, Ставрополь, улица Октябрьская, 164а	f	large
25701	90678	79	Россия, Ставропольский край, Ставрополь, улица Октябрьская, 184	f	large
25695	90673	73	Россия, Ставропольский край, Ставрополь, улица Огородная, 2	f	large
25640	90622	18	Россия, Ставропольский край, Ставрополь, улица Объездная, 8	f	large
25728	90702	105	Россия, Ставропольский край, Ставрополь	f	large
25729	90703	106	Россия, Ставропольский край, Ставрополь, улица Мира, 365	f	large
25653	90636	31	Россия, Ставропольский край, Ставрополь, улица Мира, 310	f	large
25650	90633	28	Россия, Ставропольский край, Ставрополь, улица Маяковского, 16	f	large
25629	90610	7	Россия, Ставропольский край, Ставрополь, улица Маршала Жукова, 9	f	medium
25623	90604	1	Россия, Ставропольский край, Ставрополь, улица Ломоносова, 5	f	large
26062	91017	440	Россия, Ставропольский край, Ставрополь, улица Ленина, 10	f	large
123443	90870	278	Россия, Ставропольский край, Ставрополь, улица Ленина, 67	f	\N
25733	90707	110	Россия, Ставропольский край, Ставрополь, улица Ленина, 384	f	large
25722	90696	99	Россия, Ставропольский край, Ставрополь, улица Ленина, 456	f	large
25624	90605	2	Россия, Ставропольский край, Ставрополь, улица Ленина, 251	f	large
25987	90954	365	Россия, Ставропольский край, Ставрополь, улица Красная, 38	f	large
25635	90617	13	Россия, Ставропольский край, Ставрополь, улица Комсомольская, 65	f	large
25752	90725	129	Ставропольский край, Ставрополь, улица Доваторцев, 53к3	f	large
25677	90655	55	Россия, Ставропольский край, Ставрополь, улица Дзержинского, 137	f	large
25697	90674	75	Россия, Ставропольский край, Ставрополь, улица Гоголя, 36	f	large
25685	90663	63	Россия, Ставропольский край, Ставрополь, улица Геннадия Голенева, 18	f	large
26140	91096	518	Россия, Ставропольский край, Ставрополь, улица Гагарина, 21	f	large
25678	90656	56	Россия, Ставропольский край, Ставрополь, улица Вавилова, 40	f	large
25709	90684	87	Россия, Ставропольский край, Ставрополь, улица Бруснева, 10	f	large
25668	90650	46	Россия, Ставропольский край, Ставрополь, улица Биологическая, 20	f	large
25660	90643	38	Ставропольский край, Ставрополь, улица Ашихина, 63	f	large
25756	90727	133	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 48	f	large
25755	90727	132	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 48	f	large
25757	90722	134	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 49	f	large
25749	90722	126	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 49	f	large
25744	90717	121	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 19	f	large
25743	90716	120	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 14	f	large
25742	90716	119	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 14	f	large
25741	90714	118	Россия, Ставропольский край, Ставрополь, улица 50 Лет ВЛКСМ, 16к3	f	large
25766	90735	143	Ставропольский край, Ставрополь, улица 45-я Параллель, квартал 52964А	f	large
25717	90692	95	Россия, Ставропольский край, Ставрополь, Юности проспект, 42	f	large
25713	90688	91	Ставропольский край, Ставрополь, Юности проспект, 20	f	large
25712	90687	90	Ставропольский край, Ставрополь, Юности проспект, 3	f	large
25711	90686	89	Россия, Ставропольский край, Ставрополь, Юности проспект, 7	f	large
25710	90685	88	Россия, Ставропольский край, Ставрополь, Юности проспект, 5	f	large
25732	90706	109	Ставропольский край, Ставрополь, Шпаковская, 85	f	large
123451	90883	291	Ставропольский край, Ставрополь, Шевченко, 9	f	\N
26032	90995	409	Россия, Ставропольский край, Ставрополь, Чкалова переулок, 3	f	small
25652	90635	30	Россия, Ставропольский край, Ставрополь, Чкалова переулок, 27а	f	large
25657	90640	35	Россия, Ставропольский край, Ставрополь, Черняховского проезд, 3	f	large
25690	90668	68	Ставропольский край, Ставрополь, Чапаевский проезд, 21	f	large
25689	90667	67	Ставропольский край, Ставрополь, Чапаева, 4	f	large
25739	90712	116	Ставропольский край, Ставрополь, Фестивальный переулок, 17	f	large
25738	90711	115	Ставропольский край, Ставрополь, Фестивальный переулок, 17	f	large
25763	90732	140	Ставропольский край, Ставрополь, Тухачевского, 18	f	large
25762	90731	139	Ставропольский край, Ставрополь, Тухачевского, 17, Промышленный район	f	large
25760	90731	137	Ставропольский край, Ставрополь, Тухачевского, 17, Промышленный район	f	large
25750	90723	127	Ставропольский край, Ставрополь, Тухачевского, 2, Промышленный район	f	large
25642	90624	20	Ставропольский край, Ставрополь, Туапсинская, 6	f	large
25696	90671	74	Ставропольский край, Ставрополь, Трунова, 71	f	large
25693	90671	71	Ставропольский край, Ставрополь, Трунова, 71	f	large
25735	90709	112	Ставропольский край, Ставрополь, Серова, 4к2	f	large
25666	90648	44	Ставропольский край, Ставрополь, Серова, 523	f	large
26754	91710	1133	Ставропольский край, Ставрополь, Розы Люксембург, 68а	f	large
25628	90609	6	Ставропольский край, Ставрополь, Пушкина, 8	f	large
25691	90669	69	Ставропольский край, Ставрополь, Пригородная, 226	f	large
25702	90679	80	Россия, Ставропольский край, Ставрополь, Попова переулок, 16а	f	large
25916	90886	294	Ставропольский край, Ставрополь, Победы, 1	f	large
25748	90721	125	Ставропольский край, Ставрополь, Пирогова, 34к4	f	large
25765	90734	142	Ставропольский край, Ставрополь, Пирогова, 64А	f	large
25725	90698	102	Ставропольский край, Ставрополь, Осетинская, 3	f	large
25680	90659	58	Ставропольский край, Ставрополь, Октябрьской Революции проспект, 4	f	large
25630	90612	8	Россия, Ставропольский край, Ставрополь, Октябрьской Революции проспект, 27	f	large
25700	90677	78	Ставропольский край, Ставрополь, Октябрьская, 180	f	large
25699	90676	77	Ставропольский край, Ставрополь, Октябрьская, 101	f	large
25641	90623	19	Ставропольский край, Ставрополь, Объездная, 3/1	f	large
25724	90697	101	Ставропольский край, Ставрополь, Мира, 458	f	large
25723	90697	100	Ставропольский край, Ставрополь, Мира, 458	f	large
25649	90632	27	Ставропольский край, Ставрополь, Мира, 262/15	f	large
25647	90630	25	Ставропольский край, Ставрополь, Мира, 284	f	large
25646	90629	24	Ставропольский край, Ставрополь, Мира, 306	f	large
25645	90628	23	Ставропольский край, Ставрополь, Мира, 347	f	medium
25643	90625	21	Ставропольский край, Ставрополь, Мира, 349	f	large
25706	90681	82	Россия, Ставропольский край, Ставрополь, Макарова переулок, 1	f	large
25676	90653	49	Ставропольский край, Ставрополь, Магистральная, 16/1	f	large
25648	90631	26	Ставропольский край, Ставрополь, Лермонтова, 189а	f	large
26139	91095	517	Ставропольский край, Ставрополь, Ленина, 111	f	large
25720	90694	97	Ставропольский край, Ставрополь, Ленина, 419	f	large
25637	90619	15	Ставропольский край, Ставрополь, Ленина, 73	f	large
25632	90614	10	Ставропольский край, Ставрополь, Ленина, 274	f	large
25631	90613	9	Ставропольский край, Ставрополь, Ленина, 292	f	large
25627	90608	5	Ставропольский край, Ставрополь, Ленина, 3/А	f	large
25625	90606	3	Ставропольский край, Ставрополь, Ленина, 267	f	large
25715	90690	93	Россия, Ставропольский край, Ставрополь, Кулакова проспект, 2	f	large
25714	90689	92	Россия, Ставропольский край, Ставрополь, Кулакова проспект, 23	f	large
26230	91185	608	Ставропольский край, Ставрополь, Крылова переулок, 16	f	large
25659	90642	37	Россия, Ставропольский край, Ставрополь, Крупской переулок, 31	f	large
25731	90705	108	Ставропольский край, Ставрополь, Краснофлотская, 185	f	large
25730	90704	107	Ставропольский край, Ставрополь, Краснофлотская, 88	f	large
25902	90872	280	Ставропольский край, Ставрополь, Кочубея проезд, 153	f	large
25633	90615	11	Ставропольский край, Ставрополь, Комсомольская, 64	f	large
26055	91009	433	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 37	f	large
25684	90662	62	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 11	f	large
25683	90661	61	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 11	f	large
25682	90660	60	Россия, Ставропольский край, Ставрополь, Карла Маркса проспект, 7	f	large
25681	90654	59	Ставропольский край, Ставрополь, Карла Маркса проспект, 64	f	large
25644	90626	22	Россия, Ставропольский край, Ставрополь, Зоотехнический переулок, 6	f	large
25768	90737	145	Ставропольский край, Ставрополь, Доваторцев, 66	f	large
25751	90724	128	Ставропольский край, Ставрополь, Доваторцев, 47	f	large
25651	90634	29	Ставропольский край, Ставрополь, Добролюбова, 18	f	medium
25687	90665	65	Ставропольский край, Ставрополь, Дзержинского, 1	f	large
25726	90699	103	Ставропольский край, Ставрополь, Дзержинского, 231	f	large
25639	90621	17	Россия, Ставропольский край, Ставрополь, Гризодубовой переулок, 9а	f	large
25638	90620	16	Россия, Ставропольский край, Ставрополь, Гризодубовой переулок, 9а	f	large
25636	90618	14	Россия, Ставропольский край, Ставрополь, Готвальда проезд, 6	f	large
25634	90616	12	Ставропольский край, Ставрополь, Геннадия Голенева, 46	f	large
26831	91776	1210	Ставропольский край, Ставрополь, Гагарина, 12	f	medium
25747	90720	124	Россия, Ставропольский край, Ставрополь, Ворошилова проспект, 10к1	f	large
25746	90719	123	Ставропольский край, Ставрополь, Ворошилова проспект, 7/2А	f	large
25745	90718	122	Россия, Ставропольский край, Ставрополь, Ворошилова проспект, 8	f	large
25716	90691	94	Ставропольский край, Ставрополь, Васякина, 127а	f	large
25708	90683	86	Ставропольский край, Ставрополь, Бруснева, 10	f	large
25719	90693	96	Россия, Ставропольский край, Ставрополь, Ботанический проезд, 7	f	large
25669	90651	47	Ставропольский край, Ставрополь, Биологическая, 18	f	large
25688	90666	66	Ставропольский край, Ставрополь, Бабушкина, 2А	f	large
25754	90726	131	Ставропольский край, Ставрополь, 50 Лет ВЛКСМ, 38	f	large
25753	90726	130	Ставропольский край, Ставрополь, 50 Лет ВЛКСМ, 38	f	large
25759	90729	136	Ставропольский край, Ставрополь, 50 Лет ВЛКСМ, 65	f	large
25758	90729	135	Ставропольский край, Ставрополь, 50 Лет ВЛКСМ, 65	f	large
25767	90736	144	Ставропольский край, Ставрополь, 45-я Параллель, 3к1	f	large
25686	90664	64	Ставропольский край, Ставрополь, Фрунзе, 2	f	large
25654	90637	32	Ставропольский край, Ставрополь, Серова, 272	f	large
123409	90739	146	Ставропольский край, Ставрополь, Родосская, 3	f	\N
25698	90675	76	Ставропольский край, Ставрополь, Октябрьская, 66	f	large
25661	90644	39	Ставропольский край, Ставрополь, Мичурина, 55	f	large
25626	90607	4	Ставропольский край, Ставрополь, Михаила Морозова, 5	f	large
25667	90649	45	Ставропольский край, Ставрополь, Мимоз, 24	f	large
25740	90713	117	Ставропольский край, Ставрополь, Доваторцев, 50к1	f	large
25655	90638	33	Ставропольский край, Ставрополь, Абрамовой, 2	f	large
26740	91695	1119	Ставропольский край, поселок Свободы, Калинина, 150	f	large
26594	91548	973	Ставропольский край, Светлоград, Тургенева, 27	f	large
26599	91553	978	Ставропольский край, Светлоград, Кузнечная, 285, учебный корпус	f	large
26592	91546	971	Ставропольский край, Светлоград, Гагарина, 1	f	large
26696	91651	1075	Ставропольский край, Пятигорск, проспект Калинина, 11	f	large
26712	91667	1091	Ставропольский край, Пятигорск, Шоссейная, 103	f	large
26733	91688	1112	Ставропольский край, Пятигорск, Школьная, 47	f	large
26700	91655	1079	Ставропольский край, Пятигорск, Фучика, 4к3	f	large
26732	91687	1111	Ставропольский край, Пятигорск, Февральская, 283	f	large
26731	91686	1110	Ставропольский край, Пятигорск, Февральская, 54	f	large
26691	91646	1070	Ставропольский край, Пятигорск, Университетская, 41	f	large
26688	91643	1067	Ставропольский край, Пятигорск, Университетская, 6	f	large
26749	91705	1128	Ставропольский край, Пятигорск, Украинская, 57	f	large
26680	91635	1059	Ставропольский край, Пятигорск, Теплосерная, 52	f	large
26717	91672	1096	Ставропольский край, Пятигорск, Советская, 164	f	large
26736	91691	1115	Ставропольский край, Пятигорск, Прогонная, 3	f	medium
26693	91648	1072	Ставропольский край, Пятигорск, Подстанционная, 23	f	large
26725	91680	1104	Ставропольский край, Пятигорск, Пестова, 32	f	large
26694	91649	1073	Ставропольский край, Пятигорск, Панагюриште, 14а	f	large
26727	91682	1106	Ставропольский край, Пятигорск, Нежнова, 19	f	large
26701	91656	1080	Ставропольский край, Пятигорск, Московская, 76	f	large
26756	91712	1135	Ставропольский край, Пятигорск, Мира, 187	f	large
26686	91641	1065	Ставропольский край, Пятигорск, Механизаторов, 12	f	medium
26753	91709	1132	Ставропольский край, Пятигорск, Матвеева, 35а	f	large
26743	91698	1122	Ставропольский край, Пятигорск, Маршала Жукова, 39а	f	large
26738	91693	1117	Ставропольский край, Пятигорск, Лесная, 1а	f	small
26710	91665	1089	Ставропольский край, Пятигорск, Ленина, 116а	f	large
26708	91663	1087	Ставропольский край, Пятигорск, Ленина, 51	f	large
26698	91653	1077	Ставропольский край, Пятигорск, Кучуры, 24	f	large
26697	91652	1076	Ставропольский край, Пятигорск, Кучуры, 8	f	large
26752	91708	1131	Ставропольский край, Пятигорск, Куйбышева, 4	f	large
26745	91700	1124	Ставропольский край, Пятигорск, Крутой переулок, 5	f	large
26755	91711	1134	Ставропольский край, Пятигорск, Краснознаменная, 32	f	large
26729	91684	1108	Ставропольский край, Пятигорск, Кочубея, 21	f	large
26730	91685	1109	Ставропольский край, Пятигорск, Комарова, 7	f	large
26728	91683	1107	Ставропольский край, Пятигорск, Коллективная, 3	f	large
26689	91644	1068	Ставропольский край, Пятигорск, Кирова, 68	f	large
26681	91636	1060	Ставропольский край, Пятигорск, Кирова, 30	f	large
26695	91650	1074	Ставропольский край, Пятигорск, Калинина, 9	f	large
26739	91694	1118	Ставропольский край, Пятигорск, Железнодорожная, 121	f	large
26746	91702	1125	Ставропольский край, Пятигорск, Ессентукская, 76А	f	large
26734	91689	1113	Ставропольский край, Пятигорск, Ермолова, 213	f	large
26687	91642	1066	Ставропольский край, Пятигорск, Дзержинского, 12	f	large
26750	91706	1129	Ставропольский край, Пятигорск, Бештаугорская, 45А	f	large
26703	91658	1082	Ставропольский край, Пятигорск, Аллея Строителей, 2	f	large
26702	91657	1081	Ставропольский край, Пятигорск, Аллея Строителей, 7	f	large
26747	91703	1126	Ставропольский край, Пятигорск, Адмиральского, 8п4	f	large
26735	91690	1114	Ставропольский край, Пятигорск, 5-й переулок, 1к1А	f	large
26690	91645	1069	Ставропольский край, Пятигорск, 40 лет Октября, 99	f	large
26704	91659	1083	Ставропольский край, Пятигорск, 295 стрелковой дивизии, 14	f	large
26726	91681	1105	Ставропольский край, Пятигорск, 1-я Набережная, 26	f	large
26751	91707	1130	Ставропольский край, Пятигорск, 50 лет ВЛКСМ, 48	f	large
26175	91130	553	Ставропольский край, Новопавловск, Комсомольская, 75	f	large
26495	91443	873	Ставропольский край, Нефтекумск, м-он № 2, 2, МОУ СОШ №3	f	large
26295	91252	673	Ставропольский край, Невинномысск, пер. Садовый, 6	f	small
26466	91412	838	Ставропольский край, Невинномысск, бульвар Мира, 24	f	large
26464	91410	836	Ставропольский край, Невинномысск, бульвар Мира, 17	f	large
26459	91409	831	Ставропольский край, Невинномысск, бульвар Мира, 9	f	large
26490	91432	862	Ставропольский край, Невинномысск, Школьная, 52	f	large
26450	91436	866	Ставропольский край, Невинномысск, Шевченко, 6/А	f	large
26470	91416	842	Ставропольский край, Невинномысск, Чкалова, 67	f	large
26257	91214	635	Ставропольский край, Невинномысск, Чапаева, 169/а	f	large
26456	91407	828	Ставропольский край, Невинномысск, Чайковского, 2а	f	large
26291	91248	669	Ставропольский край, Невинномысск, Центральная, 3	t	small
26283	91240	661	Ставропольский край, Невинномысск, Центральная, 6	f	small
26491	91433	863	Ставропольский край, Невинномысск, Социалистическая, 184	f	large
123504	91413	839	Ставропольский край, Невинномысск, Северная, 14	f	\N
123507	91413	841	Ставропольский край, Невинномысск, Северная, 14	f	\N
26465	91411	837	Ставропольский край, Невинномысск, Северная, 9/А	f	large
26290	91247	668	Ставропольский край, Невинномысск, Садовая, 43/б	t	small
26471	91417	843	Ставропольский край, Невинномысск, Революционная, 9	f	large
26485	91428	857	Ставропольский край, Невинномысск, Пушкина, 2	f	large
26458	91408	830	Ставропольский край, Невинномысск, Павлова, 17	f	large
26285	91242	663	Ставропольский край, Невинномысск, Молодежный переулок , 4	f	small
26446	91403	824	Ставропольский край, Невинномысск, Мичурина, 1	f	large
26468	91415	840	Ставропольский край, Невинномысск, Мира б-р, 27	f	large
26277	91234	655	Ставропольский край, Невинномысск, Мира, 8	t	small
26457	91406	829	Ставропольский край, Невинномысск, Менделеева, 25	f	large
26455	91406	827	Ставропольский край, Невинномысск, Менделеева, 25	f	large
26454	91405	826	Ставропольский край, Невинномысск, Менделеева, 68	f	large
26461	91397	833	Ставропольский край, Невинномысск, Менделеева, 5А	f	large
26460	91397	832	Ставропольский край, Невинномысск, Менделеева, 5А	f	large
26463	91053	835	Ставропольский край, Невинномысск, Менделеева, 16/А	f	large
26462	91053	834	Ставропольский край, Невинномысск, Менделеева, 16/А	f	large
26449	91435	865	Ставропольский край, Невинномысск, Маяковского, 24	f	large
26448	91434	864	Ставропольский край, Невинномысск, Матросова, 165	f	large
26453	91439	869	Ставропольский край, Невинномысск, Луначарского, 149	f	large
26452	91438	868	Ставропольский край, Невинномысск, Луначарского, 28	f	large
26487	91430	859	Ставропольский край, Невинномысск, Ленина, 107	f	large
26268	91225	646	Ставропольский край, Невинномысск, Ленина, 44/а	f	medium
26276	91233	654	Ставропольский край, Невинномысск, Кумукова, 20	f	medium
26279	91236	657	Ставропольский край, Невинномысск, Королева, 4/а	f	medium
26479	91422	851	Ставропольский край, Невинномысск, Кооперативная, 98	f	large
26478	91422	850	Ставропольский край, Невинномысск, Кооперативная, 98	f	large
26483	91425	855	Ставропольский край, Невинномысск, Калинина, 182/1	f	large
26482	91423	854	Ставропольский край, Невинномысск, Калинина, 159А	f	large
26480	91423	852	Ставропольский край, Невинномысск, Калинина, 159А	f	large
26451	91437	867	Ставропольский край, Невинномысск, Зои Космодемьянской, 1	f	large
26266	91223	644	Ставропольский край, Невинномысск, Гайнулина, 82А	f	medium
123508	91427	856	Ставропольский край, Невинномысск, Гагарина, 114	f	\N
26477	91421	849	Ставропольский край, Невинномысск, Гагарина, 53Б	f	large
26476	91421	848	Ставропольский край, Невинномысск, Гагарина, 53Б	f	large
26475	91420	847	Ставропольский край, Невинномысск, Гагарина, 43Б	f	large
26473	91419	845	Ставропольский край, Невинномысск, Гагарина, 56	f	large
26474	91418	846	Ставропольский край, Невинномысск, Гагарина, 62/А	f	large
26472	91418	844	Ставропольский край, Невинномысск, Гагарина, 62/А	f	large
26489	91431	861	Ставропольский край, Невинномысск, Апанасенко, 82А	f	large
26488	91431	860	Ставропольский край, Невинномысск, Апанасенко, 82А	f	large
26256	91213	634	Ставропольский край, Невинномысск, 60 лет Октября, 1	f	large
26447	91404	825	Ставропольский край, Невинномысск, 30 лет Победы, 6	f	large
26486	91429	858	Ставропольский край, Невинномысск, Ленина, 85-а	f	large
26871	91812	1250	Ставропольский край, Михайловск, Транспортный пер, 13	f	large
26854	91797	1233	Ставропольский край, Михайловск, Войкова, 567/4	f	large
26398	91354	776	Ставропольский край, Минеральные Воды, проспект 22 партсъезда, 94	f	large
26390	91347	768	Ставропольский край, Минеральные Воды, пр-т К. Маркса, 64	f	large
26399	91355	777	Ставропольский край, Минеральные Воды, пр-т 22 партсъезда, 133	f	large
26394	91351	772	Ставропольский край, Минеральные Воды, пр-т 22 партсъезда, 42	f	large
26393	91350	771	Ставропольский край, Минеральные Воды, пр-т 22 партсъезда, 12	f	large
26382	91339	760	Ставропольский край, Минеральные Воды, Фрунзе, 52	f	large
26380	91211	758	Ставропольский край, Минеральные Воды, Толстого, 43	f	large
26389	91346	767	Ставропольский край, Минеральные Воды, Ставропольская, 37	f	large
26388	91345	766	Ставропольский край, Минеральные Воды, Ставропольская, 25	f	large
26397	91322	775	Ставропольский край, Минеральные Воды, Советская, 32	f	large
26403	91359	781	Ставропольский край, Минеральные Воды, Пушкина, 10	f	large
26400	91356	778	Ставропольский край, Минеральные Воды, Новоселов, 8	f	large
26405	91361	783	Ставропольский край, Минеральные Воды, Новая, 2	f	large
26386	91343	764	Ставропольский край, Минеральные Воды, Московская, 37	f	large
26385	91342	763	Ставропольский край, Минеральные Воды, Московская, 29	f	large
26404	91360	782	Ставропольский край, Минеральные Воды, Линейная, 2	f	large
26383	91340	761	Ставропольский край, Минеральные Воды, Красная, 45	f	large
26384	91341	762	Ставропольский край, Минеральные Воды, Калинина, 111	f	large
26387	91344	765	Ставропольский край, Минеральные Воды, Железноводская, ДК авиаработников	f	large
26381	91338	759	Ставропольский край, Минеральные Воды, Желатиновая, 9	f	large
26406	91362	784	Ставропольский край, Минеральные Воды, Дружбы, 35	f	large
26395	91352	773	Ставропольский край, Минеральные Воды, Гагарина, 90а	f	large
26402	91358	780	Ставропольский край, Минеральные Воды, Анджиевского, 1	f	large
26401	91357	779	Ставропольский край, Минеральные Воды, Анджиевского, 33	f	large
26396	91353	774	Ставропольский край, Минеральные Воды, 50 лет Октября, 48а	f	large
26407	91363	785	Ставропольский край, Минеральные Воды, 5 км, МУП Маршрут	f	large
26392	91349	770	Ставропольский край, Минеральные Воды, Ленина, 67	f	large
26391	91348	769	Ставропольский край, Минеральные Воды, Ленина, 27а	f	large
26373	91331	751	Ставропольский край, Лермонтов, Химиков проезд, 5	f	large
26375	91333	753	Ставропольский край, Лермонтов, Решетника, 3	f	large
26374	91332	752	Ставропольский край, Лермонтов, Решетника, 2Б	f	large
26372	91330	750	Ставропольский край, Лермонтов, Нагорная, 6	f	large
26378	91336	756	Ставропольский край, Лермонтов, Ленина, 18	f	large
26377	91335	755	Ставропольский край, Лермонтов, Комсомольская, 6	f	large
26371	91329	749	Ставропольский край, Лермонтов, Горняков, 54	f	large
26376	91334	754	Ставропольский край, Лермонтов, Гагарина, 12	f	large
26684	91639	1063	Ставропольский край, село Констатиновская, Ленина, 11	f	large
26224	91179	602	Ставропольский край, Кисловодск, улица Горького, 27	f	large
26226	91181	604	Ставропольский край, Кисловодск, улица Вокзальная, 2	f	large
26214	91169	592	Ставропольский край, Кисловодск, проспект Победы, 37	f	large
26210	91165	588	Ставропольский край, Кисловодск, проезд Цандера, 17	f	large
26196	91151	574	Ставропольский край, Кисловодск, пр.Победы, 157	f	large
26231	91186	609	Ставропольский край, Кисловодск, пр.Мира, 12	f	large
26238	91193	616	Ставропольский край, Кисловодск, пр.Ленина, 30	f	small
26232	91187	610	Ставропольский край, Кисловодск, пер.Саперный, 10	f	large
26219	91174	597	Ставропольский край, Кисловодск, Щербакова, 20	f	large
26204	91159	582	Ставропольский край, Кисловодск, Школьная, 13	f	large
26228	91183	606	Ставропольский край, Кисловодск, Чкалова, 71	f	large
26201	91156	579	Ставропольский край, Кисловодск, Челюскинцев, 5	f	large
26197	91152	575	Ставропольский край, Кисловодск, Чапаева, 87	f	large
26240	91196	618	Ставропольский край, Кисловодск, Урицкого, 1	f	small
26209	91164	587	Ставропольский край, Кисловодск, У.Алиева, 37	f	large
26200	91155	578	Ставропольский край, Кисловодск, У.Алиева, 91	f	large
26198	91153	576	Ставропольский край, Кисловодск, Терская, 12	f	large
26208	91163	586	Ставропольский край, Кисловодск, Седлогорская, 157	f	small
26207	91162	585	Ставропольский край, Кисловодск, Седлогорская, 112	f	large
26206	91161	584	Ставропольский край, Кисловодск, Седлогорская, 42	f	large
26236	91191	614	Ставропольский край, Кисловодск, Пятигорская, 4	f	small
26241	91197	619	Ставропольский край, Кисловодск, Прудная, 107	f	small
26244	91200	622	Ставропольский край, Кисловодск, Профинтерна, 35	f	small
26223	91178	601	Ставропольский край, Кисловодск, Островского, 3	f	large
26211	91166	589	Ставропольский край, Кисловодск, Островского, 27	f	large
26235	91190	613	Ставропольский край, Кисловодск, Ольховская, 80	f	large
26205	91160	583	Ставропольский край, Кисловодск, Октябрьская, 43	f	large
26215	91170	593	Ставропольский край, Кисловодск, Одесская, 3	f	large
26218	91173	596	Ставропольский край, Кисловодск, Нелюбина, 5	f	large
26202	91157	580	Ставропольский край, Кисловодск, Набережная, 43-а	f	large
26212	91167	590	Ставропольский край, Кисловодск, Ленинградская, 22	f	large
26227	91182	605	Ставропольский край, Кисловодск, Кутузова, 44	f	large
26242	91198	620	Ставропольский край, Кисловодск, Коминтерна, 10	f	small
26217	91172	595	Ставропольский край, Кисловодск, Кирова, 70	f	large
26239	91194	617	Ставропольский край, Кисловодск, К.Цеткин, 2	f	small
26203	91158	581	Ставропольский край, Кисловодск, Зеркальный переулок, 21	f	large
123497	91192	615	Ставропольский край, Кисловодск, Дзержинского пр, 14	f	\N
26243	91199	621	Ставропольский край, Кисловодск, Герцена, 18	f	small
26225	91180	603	Ставропольский край, Кисловодск, Б.Хмельницкого, 7	f	medium
26213	91168	591	Ставропольский край, Кисловодск, Андрея Губина, 53	f	large
26229	91184	607	Ставропольский край, Кисловодск, Авиации, 23	f	large
26216	91171	594	Ставропольский край, Кисловодск, 8 Марта, 1	f	large
26221	91176	599	Ставропольский край, Кисловодск, 40 лет Октября, 25	f	large
26234	91189	612	Ставропольский край, Кисловодск, Ярошенко, 11	f	large
26233	91188	611	Ставропольский край, Кисловодск, Мира, 9	f	large
26199	91154	577	Ставропольский край, Кисловодск, М.Расковой, 5	f	large
26220	91175	598	Ставропольский край, Кисловодск, Жуковского, 11	f	large
26761	91718	1140	Ставропольский край, Зеленокумск, 1, МУК Зеленокумское гор. социально-культурное объединение, 1 	f	small
26777	91734	1156	Ставропольский край, Зеленокумск, Степная, 60	f	small
26773	91730	1152	Ставропольский край, Зеленокумск, Советская, 14	f	large
26770	91727	1149	Ставропольский край, Зеленокумск, Первомайская, 69	f	large
26766	91723	1145	Ставропольский край, Зеленокумск, Мельничная, 40	f	large
26765	91722	1144	Ставропольский край, Зеленокумск, З.Космодемьянской, 13	f	large
26652	91608	1031	Ставропольский край, Железноводск, Юбилейная, 2	f	large
26054	91008	432	Ставропольский край, Железноводск, Энгельса, 29	f	large
26053	91008	431	Ставропольский край, Железноводск, Энгельса, 29	f	large
26070	91025	448	Ставропольский край, Железноводск, Шоссейная, 137	f	large
26067	91022	445	Ставропольский край, Железноводск, Шоссейная, 211в	f	large
123464	91020	443	Ставропольский край, Железноводск, Шоссейная, 207Б	f	\N
26056	91010	434	Ставропольский край, Железноводск, Чапаева, 29	f	large
26048	91003	426	Ставропольский край, Железноводск, Суворова, 55	f	large
123472	91032	455	Ставропольский край, Железноводск, Спортивная, 9	f	\N
123470	91030	453	Ставропольский край, Железноводск, Свердлова, 15	f	\N
123458	91011	435	Ставропольский край, Железноводск, Проскурина, 56	f	\N
26052	91007	430	Ставропольский край, Железноводск, Проскурина, 37	f	large
123456	91004	427	Ставропольский край, Железноводск, Октябрьская, 55	f	\N
26061	91015	439	Ставропольский край, Железноводск, Лермонтова, 2А	f	small
26063	91018	441	Ставропольский край, Железноводск, Ленина, 2а	f	small
26051	91006	429	Ставропольский край, Железноводск, Космонавтов, 35	f	large
26076	91031	454	Ставропольский край, Железноводск, Колхозная, 68	f	large
26073	91028	451	Ставропольский край, Железноводск, Клары Цеткин, 1	f	large
26074	91029	452	Ставропольский край, Железноводск, Кирова, 6	f	small
26064	91019	442	Ставропольский край, Железноводск, Глинки, 1а	f	medium
26068	91023	446	Ставропольский край, Железноводск, Шоссейная, 211б	f	large
26017	90982	395	Ставропольский край, Ессентуки, Ямпольского, 15	f	large
26016	90981	394	Ставропольский край, Ессентуки, Энгельса, 34А	f	large
26028	90992	406	Ставропольский край, Ессентуки, Шоссейная, 24	f	large
26015	90980	393	Ставропольский край, Ессентуки, Чкалова, 14	f	large
26014	90980	392	Ставропольский край, Ессентуки, Чкалова, 14	f	large
26040	90999	413	Ставропольский край, Ессентуки, Пятигорская, 8	f	small
26043	91001	415	Ставропольский край, Ессентуки, Пушкина, 22	f	large
26033	90996	410	Ставропольский край, Ессентуки, Привокзальная площадь, 1А	f	small
26029	90993	407	Ставропольский край, Ессентуки, Правды, 11	f	large
26010	90976	388	Ставропольский край, Ессентуки, Первомайская, 67-А	f	large
26018	90983	396	Ставропольский край, Ессентуки, Октябрьская,, 333	f	large
26024	90989	402	Ставропольский край, Ессентуки, Октябрьская, 441	f	large
26025	90988	403	Ставропольский край, Ессентуки, Октябрьская, 419	f	large
26023	90988	401	Ставропольский край, Ессентуки, Октябрьская, 419	f	large
26021	90986	399	Ставропольский край, Ессентуки, Октябрьская, 444	f	large
26019	90984	397	Ставропольский край, Ессентуки, Октябрьская, 333	f	large
26008	90974	386	Ставропольский край, Ессентуки, Оборонная, 45	f	large
26012	90978	390	Ставропольский край, Ессентуки, Маркова, 65	f	large
26042	91000	414	Ставропольский край, Ессентуки, Ленина, 32	f	small
26011	90977	389	Ставропольский край, Ессентуки, Кисловодская, 203	f	large
26004	90969	382	Ставропольский край, Ессентуки, Кисловодская, 11	f	large
26002	90969	380	Ставропольский край, Ессентуки, Кисловодская, 11	f	large
26026	90990	404	Ставропольский край, Ессентуки, Иглина, 4	f	large
26020	90985	398	Ставропольский край, Ессентуки, Ермолова, 137	f	large
26022	90987	400	Ставропольский край, Ессентуки, Долина Роз, 7	f	large
26007	90973	385	Ставропольский край, Ессентуки, Гагарина, 58	f	large
26003	90970	381	Ставропольский край, Ессентуки, Гагарина, 34	f	large
26006	90972	384	Ставропольский край, Ессентуки, Вокзальная, 45А	f	large
26005	90971	383	Ставропольский край, Ессентуки, Вокзальная, 45-а	f	large
26013	90979	391	Ставропольский край, Ессентуки, Буачидзе, 1-5	f	large
26009	90975	387	Ставропольский край, Ессентуки, Большая Боргустанская, 80-А	f	large
26027	90991	405	Ставропольский край, Ессентуки, Белоугольная, 6	f	large
26035	90997	411	Ставропольский край, Ессентуки, Баталинская, 9	f	small
26038	90998	412	Ставропольский край, Ессентуки, Анджиевского, 8	f	small
25927	90715	305	Ставропольский край, Георгиевск, Шоссейная, 14	f	large
25929	90627	307	Ставропольский край, Георгиевск, Чугурина, 18	f	large
25920	90890	298	Ставропольский край, Георгиевск, Урицкого, 41	f	large
25937	90903	315	Ставропольский край, Георгиевск, Тургенева/Гагарина, 28/242	f	large
25935	90901	313	Ставропольский край, Георгиевск, Тургенева, 9	f	large
25934	90900	312	Ставропольский край, Георгиевск, Тургенева, 16	f	large
25943	90909	321	Ставропольский край, Георгиевск, Тронина, 10/1	f	large
25930	90896	308	Ставропольский край, Георгиевск, Тимирязева, 34	f	large
25922	90892	300	Ставропольский край, Георгиевск, Советская, 26	f	large
25942	90908	320	Ставропольский край, Георгиевск, Салогубова, 5/1	f	large
25928	90603	306	Ставропольский край, Георгиевск, Пушкина, 25	f	large
25925	90895	303	Ставропольский край, Георгиевск, Луначарского, 41	f	large
25938	90904	316	Ставропольский край, Георгиевск, Кочубея, 5	f	large
25936	90902	314	Ставропольский край, Георгиевск, Кочубея, 9	f	large
25932	90898	310	Ставропольский край, Георгиевск, Кирова, 124	f	large
25939	90905	317	Ставропольский край, Георгиевск, Калинина, 152	f	large
25931	90897	309	Ставропольский край, Георгиевск, Калинина, 51	f	large
25933	90899	311	Ставропольский край, Георгиевск, Ермолова, 35	f	large
25941	90907	319	Ставропольский край, Георгиевск, Дружбы, 31	f	large
25926	90701	304	Ставропольский край, Георгиевск, Горийская/Пушкина, 5/25а	f	large
25924	90894	302	Ставропольский край, Георгиевск, Гагарина, 76	f	large
25923	90893	301	Ставропольский край, Георгиевск, Гагарина, 66	f	large
25921	90891	299	Ставропольский край, Георгиевск, Володарского, 120	f	large
25944	90910	322	Ставропольский край, Георгиевск, Быкова, 81	f	large
25940	90906	318	Ставропольский край, Георгиевск, Батакская, 10	f	large
26876	91816	1255	Ставропольский край, село Верхнерусское, Подгорная, 154	f	large
26875	91816	1254	Ставропольский край, село Верхнерусское, Подгорная, 154	f	large
25876	90848	254	Ставропольский край, Буденновск, микрорайон 8МОУ лицей №, 8	f	large
25872	90844	250	Ставропольский край, Буденновск, Гимназия № 9	f	large
25878	90850	256	Ставропольский край, Буденновск, проспект Космонавтов, 1	f	large
25901	90871	279	Ставропольский край, Буденновск, пер.Центральный, 1	f	large
25889	90859	267	Ставропольский край, Буденновск, парк им. Гагарина, МУ культуры Центр досуга Радуга	f	large
25873	90845	251	Ставропольский край, Буденновск, микрорайон 8, ГОУ СПО Региональный политехническ	f	large
25877	90849	255	Ставропольский край, Буденновск, микрорайон 7Менделеева, ОУ СК Полимер	f	large
25879	90851	257	Ставропольский край, Буденновск, микрорайон, 316	f	large
25890	90860	268	Ставропольский край, Буденновск, Пушкинская, 111	f	large
25881	90853	259	Ставропольский край, Буденновск, Прикумская, 56	f	large
25888	90818	266	Ставропольский край, Буденновск, Октябрьская, 52	f	large
25882	90854	260	Ставропольский край, Буденновск, Микрорайон 1МУП, Гостиничный комплекс Прикумье	f	large
25884	90856	262	Ставропольский край, Буденновск, Льва Толстого, 123	f	large
25883	90855	261	Ставропольский край, Буденновск, Льва Толстого, 16	f	large
25887	90793	265	Ставропольский край, Буденновск городской округ, Лопатина, 152	f	large
25892	90862	270	Ставропольский край, Буденновск, Кумская, 47	f	large
25891	90861	269	Ставропольский край, Буденновск, Кирова, 125	f	large
25886	90858	264	Ставропольский край, Буденновск, Водопроводная, 2	f	large
25875	90847	253	Ставропольский край, Буденновск, Менделеева, микрорайон 7, МОУ СОШ №, 6	f	large
26274	91231	652	Ставропольский край, село Балахоновское, Первомайская, 8/б	f	large
26903	91843	1282	Ставропольский край, Шпаковский район, село Цимлянский, Школьная, 2	f	large
26880	91820	1259	Ставропольский край, Шпаковский район, село Холодногорский, Подгорная, 25/1	f	small
26899	91839	1278	Ставропольский край, Шпаковский район, село Темнореченский, Невинномысская, 31	f	medium
26901	91841	1280	Ставропольский край, Шпаковский район, село Темнолесская, Центральная, 129	f	large
26886	91826	1265	Ставропольский край, Шпаковский район, село Ташла, Центральная, 83А	f	small
26896	91836	1275	Ставропольский край, Шпаковский район, село Татарка, Ленина, 112	f	large
26897	91837	1276	Ставропольский край, Шпаковский район, село Татарка, З. Космодемьянской, 24	f	large
26894	91834	1273	Ставропольский край, Шпаковский район, село Сенгилеевское, Пирогова, 34Б	f	large
26900	91840	1279	Ставропольский край, Шпаковский район, село Садовый, Островского, 3В	f	small
26895	91835	1274	Ставропольский край, Шпаковский район, село Приозерный, Школьная, 1	f	small
26885	91825	1264	Ставропольский край, Шпаковский район, село Петропавловка, Октябрьская, 17Б	f	small
26891	91831	1270	Ставропольский край, Шпаковский район, село Пелагиада, Школьная, 24	f	large
26893	91833	1272	Ставропольский край, Шпаковский район, село Пелагиада, Садовая, 26	f	large
26892	91832	1271	Ставропольский край, Шпаковский район, село Пелагиада, Партизанская, 17	f	large
26904	91844	1283	Ставропольский край, Шпаковский район, село Новый Бешпагир, Школьная, 1	f	small
26890	91830	1269	Ставропольский край, Шпаковский район, село Новомарьевская, Свердлова, 44	f	large
26877	91817	1256	Ставропольский край, Шпаковский район, село Нижнерусский, Центральная, 20	f	medium
26888	91828	1267	Ставропольский край, Шпаковский район, село Надежда, Раздольная, 1А	f	large
123560	91827	1266	Ставропольский край, Шпаковский район, село Надежда, Рабочая, 13	f	\N
26889	91829	1268	Ставропольский край, Шпаковский район, село Надежда, Комсомольская, 13	f	large
26861	91803	1240	Ставропольский край, Шпаковский район, Михайловск, Отделение №1	f	large
26860	91802	1239	Ставропольский край, Шпаковский район, Михайловск, Шпака, 24	f	large
26859	91802	1238	Ставропольский край, Шпаковский район, Михайловск, Шпака, 24	f	large
26865	91807	1244	Ставропольский край, Шпаковский район, Михайловск, Розы Люксембург, 316	f	large
26870	91811	1249	Ставропольский край, Шпаковский район, Михайловск, Пушкина, 50	f	large
26869	91811	1248	Ставропольский край, Шпаковский район, Михайловск, Пушкина, 50	f	large
26853	91796	1232	Ставропольский край, Шпаковский район, Михайловск, Орджоникидзе, 246	f	large
26866	91808	1245	Ставропольский край, Шпаковский район, Михайловск, Октябрьская, 116/2	f	large
26864	91806	1243	Ставропольский край, Шпаковский район, Михайловск, Октябрьская, 318	f	large
123556	91800	1236	Ставропольский край, Шпаковский район, Михайловск, Октябрьская, 319/3	f	\N
26863	91805	1242	Ставропольский край, Шпаковский район, Михайловск, Новая, 10	f	large
123555	91799	1235	Ставропольский край, Шпаковский район, Михайловск, Никонова, 49/1	f	\N
26872	91813	1251	Ставропольский край, Шпаковский район, Михайловск, Ленина, 1	f	large
26862	91804	1241	Ставропольский край, Шпаковский район, Михайловск, Ленина, 152А	f	large
26855	91798	1234	Ставропольский край, Шпаковский район, Михайловск, Кузьминовская, 2	f	large
26858	91801	1237	Ставропольский край, Шпаковский район, Михайловск, Кирова, 13	f	large
26873	91814	1252	Ставропольский край, Шпаковский район, Михайловск, Гагарина, 171/2	f	large
26867	91809	1246	Ставропольский край, Шпаковский район, Михайловск, Гагарина, 79	f	large
26868	91810	1247	Ставропольский край, Шпаковский район, Михайловск, Вокзальная, 2	f	large
26902	91842	1281	Ставропольский край, Шпаковский район, село Липовчанский, Лесная, 31	f	small
26874	91815	1253	Ставропольский край, Шпаковский район, село Кожевников, дом Культуры 	f	small
26882	91822	1261	Ставропольский край, Шпаковский район, село Калиновка, Кавказская, 57	f	small
26884	91824	1263	Ставропольский край, Шпаковский район, село Казинка, Ленина, 119	f	large
123558	91821	1260	Ставропольский край, Шпаковский район, село Дубовка, Кирова, 1А	f	\N
26879	91819	1258	Ставропольский край, Шпаковский район, село Демино, переулок Школьный, 1	f	large
26878	91818	1257	Ставропольский край, Шпаковский район, село Вязники, заезд Весенний, 1	f	small
26898	91838	1277	Ставропольский край, Шпаковский район, село Верхнеегорлыкский, Шолохова, 28	f	small
26883	91823	1262	Ставропольский край, Шпаковский район, село Верхнедубовский, Ленина, 10	f	small
26842	91590	1221	Ставропольский край, Туркменский район, село Ясный, Школьная, 4	f	medium
26848	91791	1227	Ставропольский край, Туркменский район, село Шарахалсун, Краснознаменская, 94 а	f	large
26834	91147	1213	Ставропольский край, Туркменский район, село Чур, Советская, 20	f	medium
123550	91792	1228	Ставропольский край, Туркменский район, село Троицкий, Западная, 11	f	\N
123553	91794	1230	Ставропольский край, Туркменский район, село Таврический, Победы, 58	f	\N
26846	91789	1225	Ставропольский край, Туркменский район, село Сабан-Антуста, Мира, 57а	f	medium
26836	91450	1215	Ставропольский край, Туркменский район, село Поперечный, Набережная, 19	f	small
26837	91462	1216	Ставропольский край, Туркменский район, село Овощи, Красная, 75	f	large
26843	91602	1222	Ставропольский край, Туркменский район, село Новокучерлинский, Школьная, 12	f	small
26840	91524	1219	Ставропольский край, Туркменский район, село Малые Ягуры, Пионерская, 29	f	large
26833	91016	1212	Ставропольский край, Туркменский район, село Летняя Ставка, Советская, 17	f	large
26832	90658	1211	Ставропольский край, Туркменский район, село Летняя Ставка, Советская, 114	f	large
26847	91790	1226	Ставропольский край, Туркменский район, село Кучерла, Стадионная, 29	f	large
26850	91793	1229	Ставропольский край, Туркменский район, село Куликовы Копани, Горького, 14	f	large
26844	91701	1223	Ставропольский край, Туркменский район, село Красный Маныч, Школьная, 1	f	large
26838	91500	1217	Ставропольский край, Туркменский район, село Красная Поляна, Степная, 9/1	f	small
26845	91743	1224	Ставропольский край, Туркменский район, село Кендже-Кулак, Ленина, 49	f	medium
26839	91512	1218	Ставропольский край, Туркменский район, село Камбулат, Свободы, 55	f	large
26841	91538	1220	Ставропольский край, Туркменский район, село Казгулак, Ленина, 117	f	large
26835	91195	1214	Ставропольский край, Туркменский район, село Березовский, Советская, 14	f	small
26818	91777	1197	Ставропольский край, Труновский район, село Труновское, ленина, 4в	f	large
26819	91778	1198	Ставропольский край, Труновский район, село Труновское, Ленина, 130	f	large
123549	91775	1196	Ставропольский край, Труновский район, село Труновское, Гагарина, 171	f	\N
26829	91788	1208	Ставропольский край, Труновский район, село Сухой Лог, Спортивная, 2/1	f	small
26826	91785	1205	Ставропольский край, Труновский район, село Правоегорлыкский, Советская, 5	f	small
26830	91717	1209	Ставропольский край, Труновский район, село Подлесное, Садовая, 18А	f	large
26827	91786	1206	Ставропольский край, Труновский район, село Новотерновский, Зои Комодемьянской, 19	f	small
26828	91787	1207	Ставропольский край, Труновский район, село Нижняя Терновка, Луговая, 12	f	small
26809	91767	1188	Ставропольский край, Труновский район, село Невдахин, Невдахина, 35	f	small
123546	91774	1195	Ставропольский край, Труновский район, село Ключевское, Ленина, 1	f	\N
26825	91784	1204	Ставропольский край, Труновский район, село Имени Кирова, Комарова, 22	f	large
26815	91773	1194	Ставропольский край, Труновский район, село Донское, Трунова, 27	f	large
26810	91768	1189	Ставропольский край, Труновский район, село Донское, Садовая, 60а	f	large
123544	91770	1191	Ставропольский край, Труновский район, село Донское, Пролетарская, 93А	f	\N
26813	91771	1192	Ставропольский край, Труновский район, село Донское, Первомайская, 2	f	large
26814	91772	1193	Ставропольский край, Труновский район, село Донское, Ленина, 225А	f	large
26811	91769	1190	Ставропольский край, Труновский район, село Донское, Комарова, 6а	f	large
26821	91780	1200	Ставропольский край, Труновский район, село Безопасное, переулок Степной, 1	f	small
26820	91779	1199	Ставропольский край, Труновский район, село Безопасное, Ставропольская, 1	f	medium
26824	91783	1203	Ставропольский край, Труновский район, село Безопасное, Партизанская, 56	f	medium
26823	91782	1202	Ставропольский край, Труновский район, село Безопасное, Ленина , 116 а	f	large
26822	91781	1201	Ставропольский край, Труновский район, село Безопасное, Ленина, 20	f	large
26794	91752	1173	Россия, Ставропольский край, Степновский район, село Сунженский	f	small
26287	91244	665	Ставропольский край, Степновский район, село Сунженский, Лысенко, 18	t	small
26805	91763	1184	Ставропольский край, Степновский район, село Степное, пл. Ленина, 19	f	large
123541	91765	1186	Ставропольский край, Степновский район, село Степное, Садовая, 93	f	\N
26806	91764	1185	Ставропольский край, Степновский район, село Степное, Додонова, 40	f	large
26804	91762	1183	Ставропольский край, Степновский район, село Соломенское, Административная пл, 14	f	large
26802	91760	1181	Ставропольский край, Степновский район, село Ольгино, Шоссейная, 34	f	large
123539	91757	1178	Ставропольский край, Степновский район, село Озерное, Мира, 24	f	\N
26797	91755	1176	Ставропольский край, Степновский район, село Новоникольский, Центральная, 64	f	small
26801	91759	1180	Ставропольский край, Степновский район, село Новоиргаклинский, Мира, 9	f	small
123537	91754	1175	Ставропольский край, Степновский район, село Никольское, Шоссейная, 40	f	\N
26800	91758	1179	Ставропольский край, Степновский район, село Иргаклы, Молодежная, 2Б	f	large
26803	91761	1182	Ставропольский край, Степновский район, село Зеленая Роща, пер. Школьный, 3	f	medium
123542	91766	1187	Россия, Ставропольский край, Степновский район, село Восточный	f	\N
26798	91756	1177	Ставропольский край, Степновский район, село Верхнестепной, пл. Ленина, 18	f	large
26795	91753	1174	Ставропольский край, Степновский район, село Варениковское, Школьный пер, 7	f	medium
26793	91751	1172	Ставропольский край, Степновский район, село Богдановка, Мира, 21	f	medium
26789	91747	1168	Ставропольский край, Советский район, село Солдато-Александровское, Пролетарская, 87	f	large
26788	91746	1167	Ставропольский край, Советский район, село Солдато-Александровское, Ленина пл, 1	f	large
26787	91745	1166	Ставропольский край, Советский район, село Солдато-Александровское, Культурная, 83	f	large
26785	91742	1164	Ставропольский край, Советский район, село Солдато-Александровское, 25 партсъезда, 16	f	medium
26786	91744	1165	Ставропольский край, Советский район, село Солдато-Александровское, 17 партсъезда, 119	f	large
26782	91739	1161	Ставропольский край, Советский район, село Селивановка, Шоссейная, 1	f	medium
26784	91741	1163	Ставропольский край, Советский район, село Правокумское, Ленина, 45	f	large
26783	91740	1162	Ставропольский край, Советский район, село Отказное, Мостовая, 5	f	large
123535	91738	1160	Ставропольский край, Советский район, село Нины, Октябрьская, 9	f	\N
26780	91737	1159	Ставропольский край, Советский район, село Нины, Кирова, 29	f	large
26791	91749	1170	Ставропольский край, Советский район, село Михайловка, Шоссейная, 59	f	medium
26759	91715	1138	Ставропольский край, Советский район, село Кононов, Школьная, 26	f	small
26790	91748	1169	Ставропольский край, Советский район, село Колесников, пер.1-й Ленинский, 15	f	small
26778	91735	1157	Ставропольский край, Советский район, село Ковганский, Фестивальная, 37	f	small
26764	91721	1143	Ставропольский край, Советский район, Зеленокумск, площадь Ленина, 14	f	large
26767	91724	1146	Ставропольский край, Советский район, Зеленокумск, пл.Ленина, 52	f	large
26763	91720	1142	Ставропольский край, Советский район, Зеленокумск, пл.1 Мая, 4а	f	large
26771	91728	1150	Ставропольский край, Советский район, Зеленокумск, Семенова, 12	f	large
26762	91719	1141	Ставропольский край, Советский район, Зеленокумск, Пугачева, 209	f	large
26768	91725	1147	Ставропольский край, Советский район, Зеленокумск, Ленина, 237	f	large
26775	91732	1154	Ставропольский край, Советский район, Зеленокумск, Кумской пер, 4	f	large
26774	91731	1153	Ставропольский край, Советский район, Зеленокумск, Крайнева, 72	f	large
26769	91726	1148	Ставропольский край, Советский район, Зеленокумск, Ессентукская, 180	f	large
26779	91736	1158	Ставропольский край, Советский район, Зеленокумск, 50 лет Октября, 27	f	medium
26776	91733	1155	Ставропольский край, Советский район, Зеленокумск, 50 лет Октября, 63	f	large
123533	91729	1151	Ставропольский край, Советский район, Зеленокумск, 50 лет Октября, 35	f	\N
26760	91716	1139	Ставропольский край, Советский район, село Горькая Балка, Октябрьская, 16	f	large
26758	91714	1137	Ставропольский край, Советский район, село Восточный, Октябрьская, 18	f	large
26792	91750	1171	Ставропольский край, Советский район, село Андреевский, Школьная, 1	f	medium
26741	91696	1120	Ставропольский край, Пятигорск городской округ, поселок Свободы, Энгельса, 61	f	large
26744	91699	1123	Ставропольский край, Пятигорск городской округ, поселок Свободы, Пащенко, 112	f	large
26742	91697	1121	Ставропольский край, Пятигорск городской округ, поселок городского типа Свободы, Энгельса, 104	f	large
26685	91640	1064	Ставропольский край, Пятигорск городской округ, село Нижнеподкумский, Зубалова, 35а	f	large
26683	91638	1062	Ставропольский край, Пятигорск городской округ, село Констатиновская, Октябрьская, 108	f	large
26716	91671	1095	Россия, Ставропольский край, Пятигорск городской округ, поселок Горячеводский	f	large
26707	91662	1086	Ставропольский край, Пятигорск городской округ, поселок Горячеводский, Советская, 87	f	large
26709	91664	1088	Ставропольский край, Пятигорск городской округ, поселок Горячеводский, Ленина, 55	f	large
26706	91661	1085	Ставропольский край, Пятигорск городской округ, поселок Горячеводский, Ленина, 25	f	large
26715	91670	1094	Ставропольский край, Пятигорск городской округ, поселок Горячеводский, Кабардинская, 1	f	large
26711	91666	1090	Ставропольский край, Пятигорск городской округ, поселок Горячеводский, Георгиевская, 174/1	f	large
26714	91669	1093	Ставропольский край, Пятигорск городской округ, поселок Горячеводский, 8-я линия, 54	f	large
26705	91660	1084	Ставропольский край, Пятигорск городской округ, поселок городского типа Горячеводский, Советской Армии, 32	f	large
26713	91668	1092	Ставропольский край, Пятигорск городской округ, поселок городского типа Горячеводский, Больничная, 1	f	large
26678	91633	1057	Россия, Ставропольский край, Предгорный район, село Ясная Поляна	f	large
26679	91634	1058	Ставропольский край, Предгорный район, село Ясная Поляна, Спортивная, 27	f	large
26674	91629	1053	Ставропольский край, Предгорный район, село Юца, Почтовый переулок	f	large
26675	91630	1054	Ставропольский край, Предгорный район, село Юца, Луценко, 115	f	large
26676	91631	1055	Ставропольский край, Предгорный район, село Юца, Канищева, 2	f	large
26672	91627	1051	Ставропольский край, Предгорный район, село Этока, 50 лет Октября, 458	f	large
26671	91626	1050	Ставропольский край, Предгорный район, село Этока, 50 лет Октября, 144	f	medium
26667	91622	1046	Ставропольский край, Предгорный район, село Урожайный, переулок Садовый, 1	f	medium
26670	91625	1049	Ставропольский край, Предгорный район, село Тамбукан, Кирова, 16В	f	medium
26665	91620	1044	Ставропольский край, Предгорный район, село Суворовская, Шоссейная	f	large
26661	91616	1040	Ставропольский край, Предгорный район, село Суворовская, Советская	f	large
26659	91614	1038	Ставропольский край, Предгорный район, село Суворовская, Советская, 30	f	large
26663	91618	1042	Ставропольский край, Предгорный район, село Суворовская, Нагорная, 255	f	large
26662	91617	1041	Ставропольский край, Предгорный район, село Суворовская, Карла Маркса	f	large
26660	91615	1039	Ставропольский край, Предгорный район, село Суворовская, Заводская, 42Б	f	large
26664	91619	1043	Ставропольский край, Предгорный район, село Свобода, Гагарина	f	medium
123531	91621	1045	Ставропольский край, Предгорный район, село Санамер, Тельмана, 60	f	\N
26677	91632	1056	Ставропольский край, Предгорный район, село Садовое, Мира, 127	f	large
26655	91610	1034	Ставропольский край, Предгорный район, село Пятигорский, Красноармейская, 20	f	large
26654	91610	1033	Ставропольский край, Предгорный район, село Пятигорский, Красноармейская, 20	f	large
26737	91692	1116	Ставропольский край, Предгорный район, село Привольное, Школьная, 6	f	small
26651	91607	1030	Ставропольский край, Предгорный район, село Подкумок, Крупской, 3	f	large
26669	91624	1048	Ставропольский край, Предгорный район, село Новоборгустанский, Кубанская, 37	f	small
26650	91606	1029	Ставропольский край, Предгорный район, село Новоблагодарное, Ленина, 54	f	large
26657	91612	1036	Ставропольский край, Предгорный район, село Нижнеэтокский, Шоссейная, б/н	f	small
26649	91605	1028	Ставропольский край, Предгорный район, село Нежинский, Дом культуры	f	large
26647	91603	1026	Ставропольский край, Предгорный район, село Мирный, Шоссейная, 25А	f	large
26648	91604	1027	Россия, Ставропольский край, Предгорный район, село Левоберезовский	f	medium
26668	91623	1047	Ставропольский край, Предгорный район, село Имени Чкалова, Якорная, 11	f	small
26644	91599	1023	Ставропольский край, Предгорный район, село Ессентукская, Юцкий переулок, 1	f	large
26643	91598	1022	Ставропольский край, Предгорный район, село Ессентукская, Этокская, 4	f	large
26645	91600	1024	Ставропольский край, Предгорный район, село Ессентукская, Садовое Кольцо, 5	f	large
26641	91596	1020	Ставропольский край, Предгорный район, село Ессентукская, Гагарина, 72	f	large
26640	91595	1019	Ставропольский край, Предгорный район, село Ессентукская, Гагарина, 52	f	large
26642	91597	1021	Ставропольский край, Предгорный район, село Ессентукская, Гагарина, 101	f	large
26673	91628	1052	Ставропольский край, Предгорный район, село Джуца, Ореховая, 12/1	f	large
26646	91601	1025	Ставропольский край, Предгорный район, село Горный	f	medium
26639	91594	1018	Ставропольский край, Предгорный район, село Винсады, Ленина, 41	f	large
123529	91593	1017	Ставропольский край, Предгорный район, село Винсады, Ленина, 27	f	\N
123526	91592	1016	Ставропольский край, Предгорный район, село Винсады, Ленина, 30	f	\N
26656	91611	1035	Ставропольский край, Предгорный район, село Верхнетамбуканский, Зеленая, 2	t	small
26653	91609	1032	Ставропольский край, Предгорный район, село Быкогорка, Кошевого, 31	f	large
26636	91591	1015	Ставропольский край, Предгорный район, село Боргустанская, Кооперативная, 18А	f	large
26635	91589	1014	Ставропольский край, Предгорный район, село Боргустанская, Буденного, 12А	f	large
123524	91588	1013	Ставропольский край, Предгорный район, село Бекешевская, Московская, 9	f	\N
26623	91577	1002	Ставропольский край, Петровский район, село Шведино, Ленина, 39	f	large
8565	43290	378	республика Коми, Ухта, Интернациональная, 56	f	large
26620	91574	999	Ставропольский край, Петровский район, село Шангала, 60 лет Октября, 31А	f	large
26627	91581	1006	Ставропольский край, Петровский район, село Сухая Буйвола, Красная, 9	f	large
26613	91567	992	Ставропольский край, Петровский район, село Соленое Озеро, Курортная, 7А	f	medium
26605	91559	984	Ставропольский край, Петровский район, Светлоград, площадь Выставочная, 25	f	large
26595	91549	974	Ставропольский край, Петровский район, Светлоград, площадь 50-лет Октября, 10	f	large
26593	91547	972	Ставропольский край, Петровский район, Светлоград, Транспортная, 25	f	large
26604	91558	983	Ставропольский край, Петровский район, Светлоград, Садовая, 28 А	f	large
123522	91565	990	Ставропольский край, Петровский район, Светлоград, Матросова, 195А	f	\N
26610	91564	989	Ставропольский край, Петровский район, Светлоград, Матросова, 2	f	large
26607	91561	986	Ставропольский край, Петровский район, Светлоград, Малыгина, 31	f	large
26608	91562	987	Ставропольский край, Петровский район, Светлоград, Комсомольская, 14	f	large
26603	91557	982	Ставропольский край, Петровский район, Светлоград, Коминтерна, 13	f	large
26601	91555	980	Ставропольский край, Петровский район, Светлоград, Кисличанская, 241	f	large
123519	91554	979	Ставропольский край, Петровский район, Светлоград, Кисличанская, 90	f	\N
123517	91550	975	Ставропольский край, Петровский район, Светлоград, Горная, 11-Н	f	\N
26606	91560	985	Ставропольский край, Петровский район, Светлоград, Выставочная площадь, б/н	f	large
26609	91563	988	Ставропольский край, Петровский район, Светлоград, Высотная, 9	f	large
26598	91552	977	Ставропольский край, Петровский район, Светлоград, Бассейная, 143	f	large
26597	91551	976	Ставропольский край, Петровский район, Светлоград, Бассейная, 93	f	large
123521	91556	981	Ставропольский край, Петровский район, Светлоград, 60 лет Октября, 4	f	\N
26624	91578	1003	Ставропольский край, Петровский район, село Рогатая Балка, Первомайская, 75	f	large
26625	91579	1004	Ставропольский край, Петровский район, село Пшеничный, Пролетарская, дом б/н	t	small
26633	91587	1012	Ставропольский край, Петровский район, село Просянка, Мира, 58	f	large
26621	91575	1000	Ставропольский край, Петровский район, село Прикалаусский, Почтовая, 1	f	large
26631	91585	1010	Ставропольский край, Петровский район, село Ореховка, Толстого, 1А	f	large
26612	91566	991	Ставропольский край, Петровский район, село Носачев, Урожайная, 75	f	small
26622	91576	1001	Ставропольский край, Петровский район, село Николина Балка, Шоссейная, 28	f	large
26617	91571	996	Ставропольский край, Петровский район, село Кугуты, Железнодорожная, 120	f	small
26615	91569	994	Ставропольский край, Петровский район, село Константиновское, Октябрьская, 1А	f	large
26614	91568	993	Ставропольский край, Петровский район, село Константиновское, Ленина, 94	f	large
26616	91570	995	Ставропольский край, Петровский район, село Константиновское, Ледовского, 2Б	f	large
26632	91586	1011	Ставропольский край, Петровский район, село Донская Балка, Ленина, 106	f	large
26628	91582	1007	Ставропольский край, Петровский район, село Гофицкое, Советская, 71	f	large
26629	91583	1008	Ставропольский край, Петровский район, село Гофицкое, Ленина, 194	f	large
26626	91580	1005	Ставропольский край, Петровский район, село Горный, Степная, 2А	t	small
26630	91584	1009	Ставропольский край, Петровский район, село Высоцкое, Центральная, 68	f	large
26618	91572	997	Ставропольский край, Петровский район, село Благодатное, Советская, 34	f	large
26619	91573	998	Ставропольский край, Петровский район, село Благодатное, Петровская, 1	f	large
26586	91540	965	Ставропольский край, Новоселицкий район, село Щелкан, Школьная, 3	f	medium
26582	91535	961	Ставропольский край, Новоселицкий район, село Чернолесское, Ленина, 43	f	large
26583	91536	962	Ставропольский край, Новоселицкий район, село Чернолесское, Карла Маркса пер, 7 В	f	large
26589	91543	968	Ставропольский край, Новоселицкий район, село Падинское, Красная, 119	f	large
26590	91544	969	Ставропольский край, Новоселицкий район, село Новый Маяк, Школьная, 4	f	medium
26581	91534	960	Ставропольский край, Новоселицкий район, село Новоселицкое, Шоссейная, 43	f	large
26579	91532	958	Ставропольский край, Новоселицкий район, село Новоселицкое, Школьная, 26	f	large
26331	91288	709	Ставропольский край, Курский район, село Каново, Ленина, 32 В	f	large
26580	91533	959	Ставропольский край, Новоселицкий район, село Новоселицкое, Ставропольская, 94	f	large
26585	91539	964	Ставропольский край, Новоселицкий район, село Китаевское, Ленина, 86	f	large
26587	91541	966	Ставропольский край, Новоселицкий район, село Журавское, Шоссейная, 8	f	large
26591	91545	970	Ставропольский край, Новоселицкий район, село Жуковский, Веселая, 4	t	small
26584	91537	963	Ставропольский край, Новоселицкий район, село Долиновка, Байрамова, 150	f	large
26588	91542	967	Ставропольский край, Новоселицкий район, село Артезианский, Веселая, 19	f	small
26567	91519	945	Ставропольский край, Новоалександровский район, село Южный, 55МУЗ НЦРБ фельдшерский пункт	f	small
26565	91517	943	Ставропольский край, Новоалександровский район, село Чапцев, Заречная, 22, МУК СДК	t	small
26554	91505	932	Ставропольский край, Новоалександровский район, село Фельдмаршальский, Ленина, 164, СДК	f	medium
26546	91496	924	Ставропольский край, Новоалександровский район, село Ударный, Центральная, 11, МУК СДК	t	small
26571	91523	949	Ставропольский край, Новоалександровский район, село Темижбекский, Момотова, 7, МУК СДК	f	large
26566	91518	944	Ставропольский край, Новоалександровский район, село Славенский, МОУ СОШ № 4 фельдшерский пункт	t	small
26542	91492	920	Ставропольский край, Новоалександровский район, село Светлый, оветская, 9А, СДК	f	large
26551	91502	929	Ставропольский край, Новоалександровский район, село Румяная Балка, Южная, 26А, СДК	t	small
26550	91501	928	Ставропольский край, Новоалександровский район, село Родионов, Степная, 18, МУК СДК	t	small
26575	91528	953	Ставропольский край, Новоалександровский район, село Расшеватская, Советская, 3, МОУ СОШ № 9	f	large
26574	91527	952	Ставропольский край, Новоалександровский район, село Расшеватская, Ленина, 54, МУК СДК	f	large
26577	91530	955	Ставропольский край, Новоалександровский район, село Рассвет, Красная, 10, МУК СДК	f	small
26553	91504	931	Ставропольский край, Новоалександровский район, село Раздольное, Ленина, 72, СДК	f	large
26572	91525	950	Ставропольский край, Новоалександровский район, село Радуга, Ленина, 9, МУК СДК	f	large
26549	91499	927	Ставропольский край, Новоалександровский район, село Равнинный, Молодежная, 18А, МДОУ Д/с Теремок	f	medium
26545	91495	923	Ставропольский край, Новоалександровский район, село Присадовый, Школьная, 11, МУК СДК	f	medium
26416	91372	794	Ставропольский край, Новоалександровский район, село Первомайский, Школьная, 13	f	small
26562	91514	940	Ставропольский край, Новоалександровский район, село Первомайский, Широкая, 46, МУК СДК	t	small
26570	91522	948	Ставропольский край, Новоалександровский район, село Озерный, МУЗ НЦРБ фельдшерский пункт	t	small
26532	91482	910	Ставропольский край, Новоалександровский район, Новоалександровск, пер.Красноармейский, 77, МОУ СОШ №, 12	f	large
26530	91480	908	Ставропольский край, Новоалександровский район, Новоалександровск, пер.Красноармейский, 5, ГДК Строитель	f	large
26538	91488	916	Ставропольский край, Новоалександровский район, Новоалександровск, пер. Энгельса, 4, МДОу Д/с Красная шапочка	f	large
26529	91479	907	Ставропольский край, Новоалександровский район, Новоалександровск, Тургенева, 29/1	f	large
26537	91487	915	Ставропольский край, Новоалександровский район, Новоалександровск, Советская, 150а, МОУ СОШ №3	f	large
26535	91485	913	Ставропольский край, Новоалександровский район, Новоалександровск, Мичурина, 1, МДОУ Д/с Чебурашка	f	large
26534	91484	912	Ставропольский край, Новоалександровский район, Новоалександровск, Лермонтова, 20, МОУ СОШ № 5	f	large
26540	91490	918	Ставропольский край, Новоалександровский район, Новоалександровск, Ленина, 70, ДЮЦ	f	large
26539	91489	917	Ставропольский край, Новоалександровский район, Новоалександровск, Ленина, 101, РДК	f	large
26536	91486	914	Ставропольский край, Новоалександровский район, Новоалександровск, Калинина, 124, Магазин райпотребсоюза	f	large
26531	91481	909	Ставропольский край, Новоалександровский район, Новоалександровск, Железнодорожная, 139А, УП Рынок Центральный	f	large
123514	91483	911	Ставропольский край, Новоалександровский район, Новоалександровск, Ворошилова, 50	f	\N
26543	91493	921	Ставропольский край, Новоалександровский район, село Мокрая Балка, Центральная, 27, МОУ СОШ №13	t	small
26573	91526	951	Ставропольский край, Новоалександровский район, село Лиманный, Карла Маркса, 31, МУК СДК	t	small
26555	91506	933	Ставропольский край, Новоалександровский район, село Курганный, Социалистическая, 1, СДК	t	small
26564	91516	942	Ставропольский край, Новоалександровский район, село Красночервонный, Ленина, 16, МУК СДК	f	large
26569	91521	947	Ставропольский край, Новоалександровский район, поселок Краснокубанский, МУК СДК	t	small
26548	91498	926	Ставропольский край, Новоалександровский район, село Краснозоринский, Юбилейный переулок, 1А, МУК СДК	f	medium
26556	91507	934	Ставропольский край, Новоалександровский район, село Краснодарский, Калинина, 28, СДК	t	small
26561	91513	939	Ставропольский край, Новоалександровский район, село Керамик, Заводская, 38, МУК СДК	t	small
26547	91497	925	Ставропольский край, Новоалександровский район, село Кармалиновская, Красная, 80/1	f	large
26578	91531	956	Ставропольский край, Новоалександровский район, село Заречный, Восточная, 6а, СДК	t	small
26560	91511	938	Ставропольский край, Новоалександровский район, село Григорополисская, Шмидта, 39, МОУ СОШ №, 2	f	large
26558	91509	936	Ставропольский край, Новоалександровский район, село Григорополисская, Тимирязева, 92, НПО Лицей им.М.И.Платова	f	large
26559	91510	937	Ставропольский край, Новоалександровский район, село Григорополисская, Р.Люксембург, 13А, МУК СДК	f	large
26557	91508	935	Ставропольский край, Новоалександровский район, село Григорополисская, Демьяна Бедного, 17, СДК Южный	f	medium
26576	91529	954	Ставропольский край, Новоалександровский район, село Горьковский, Комсомольская, 33, МУК СДК	f	medium
26568	91520	946	Ставропольский край, Новоалександровский район, село Восточный, МУЗ НЦРБ фельдшерский пункт	f	small
26552	91503	930	Ставропольский край, Новоалександровский район, село Воскресенская, Школьная, 18, МОУ ООШ № 13	t	small
26563	91515	941	Ставропольский край, Новоалександровский район, село Воровский, Школьный переулок, 1А, Филиал МОУ СОШ № 4	t	small
26544	91494	922	Ставропольский край, Новоалександровский район, село Виноградный, Заречная, 4, МУК СДК	t	small
26518	91468	896	Ставропольский край, Нефтекумский район, село Ямангой, Ленина, МОУ ООШ № 19	t	small
26523	91473	901	Ставропольский край, Нефтекумский район, село Уч-Тюбе, Ленина, 19, отделение МОУ СОШ №, 16	t	small
26524	91474	902	Ставропольский край, Нефтекумский район, село Уллуби-Юрт, 60-лет Октября, 42, МОУ СОШ №, 11	f	medium
26527	91477	905	Ставропольский край, Нефтекумский район, село Тукуй-Мектеб, Эдиге, 35-А, ДК а.Тукуй-Мектеб	f	large
26505	91454	883	Ставропольский край, Нефтекумский район, село Озек-Суат, О.Сеитова, 92, ДК с.Озек-Суат	f	medium
26506	91455	884	Ставропольский край, Нефтекумский район, село Озек-Суат, Мира, 53-А, ДК с.Озек-Суат	t	small
26516	91466	894	Ставропольский край, Нефтекумский район, село Новкус-Артезиан, Кирова, ДК а.Новкус-Артезиан	f	large
26498	91446	876	Ставропольский край, Нефтекумский район, Нефтекумск, МОУ СОШ № 2	f	large
26494	91442	872	Ставропольский край, Нефтекумский район, Нефтекумск, пл.Ленина, ДК Нефтяник	f	large
26496	91444	874	Ставропольский край, Нефтекумский район, Нефтекумск, м-он № 2, 14, администрация города	f	large
26497	91445	875	Ставропольский край, Нефтекумский район, Нефтекумск, м-он № 1, 17, МУП ЖХ	f	large
26500	91448	878	Ставропольский край, Нефтекумский район, Нефтекумск, Ленина, 42, МОУ ДОД ДХШ	f	large
26499	91447	877	Ставропольский край, Нефтекумский район, Нефтекумск, Ленина, МОУ ДОД ЦВР	f	large
26493	91441	871	Ставропольский край, Нефтекумский район, Нефтекумск, Анны Шилиной, 26, бывшее МУ Межшкольный комбинат	f	large
26492	91440	870	Ставропольский край, Нефтекумский район, Нефтекумск, Анны Шилиной, 1, 3МОУ СОШ №	f	large
26526	91476	904	Ставропольский край, Нефтекумский район, село Махмуд-Мектеб, Советская, 63В, МОУ СОШ № 15	f	large
26525	91475	903	Ставропольский край, Нефтекумский район, село Кунай, Степная, ДК а.Кунай	t	small
26517	91467	895	Ставропольский край, Нефтекумский район, село Кок-Бас, Ленина, ДК а.Кок-Бас	t	small
26522	91472	900	Ставропольский край, Нефтекумский район, село Каясула, Советская, 43, ДК	f	large
26521	91471	899	Ставропольский край, Нефтекумский район, село Каясула, Советская, 43-Г, ДК с.Каясула	f	large
26330	91287	708	Ставропольский край, Курский район, село Зайцев, Школьная, 55	f	medium
26514	91464	892	Ставропольский край, Нефтекумский район, село Каратюбе, Ленина, 44-Б	f	large
26520	91470	898	Ставропольский край, Нефтекумский район, село Зункарь, Молодежная, администрация МО	f	medium
123511	91457	886	Ставропольский край, Нефтекумский район, село Зимняя Ставка, Новая, 16	f	\N
26501	91449	879	Ставропольский край, Нефтекумский район, поселок Затеречный, Строительная	f	large
26504	91453	882	Ставропольский край, Нефтекумский район, поселок Затеречный, Котельная, 20/1, МОУ ДОД ЗДМШ	f	medium
26503	91452	881	Ставропольский край, Нефтекумский район, поселок Затеречный, Комсомольская, 10, МУ ДК	f	large
26502	91451	880	Ставропольский край, Нефтекумский район, поселок Затеречный, Горького	f	large
26513	91463	891	Ставропольский край, Нефтекумский район, село Бияш, Степная, 36-Б, контора ПУ № 4 СПКк Восток	t	small
26519	91469	897	Ставропольский край, Нефтекумский район, село Бейсей, А.Шабанова, 42/1, ДК	t	small
26511	91460	889	Ставропольский край, Нефтекумский район, село Ачикулак, площадь Ленина, МУ ДК	f	large
26512	91461	890	Ставропольский край, Нефтекумский район, село Ачикулак, пл.Ленина, МУ ДК с.Ачикулак	f	large
123513	91459	888	Ставропольский край, Нефтекумский район, село Ачикулак, Червонная, 40	t	\N
26515	91465	893	Ставропольский край, Нефтекумский район, село Артезиан-Мангит, Ленина, ДК	t	small
26509	91458	887	Ставропольский край, Нефтекумский район, село Андрей-Курган, Правобережная, 4-А, ДК х.Андрей-Курган	f	large
26528	91478	906	Ставропольский край, Нефтекумский район, село Абрам-Тюбе, Курманалиева, 32, МОУ СОШ №17	f	medium
26507	91456	885	Ставропольский край, Нефтекумский район, село Абдул-Газы, А.Эюпова, 58ДК , а.Абдул-Газы	t	small
26292	91249	670	Ставропольский край, Невинномысск городской округ, село Усть-Невинский, Набережная, 69/б	f	medium
26270	91227	648	Ставропольский край, Невинномысск городской округ, село Степной, Центральная, 37/а	t	small
26284	91241	662	Ставропольский край, Невинномысск городской округ, село Стародворцовский, Ленина, 50	f	small
26282	91239	660	Ставропольский край, Невинномысск городской округ, село Свистуха, Казачья, 2	t	small
26262	91219	640	Ставропольский край, Невинномысск городской округ, село Саратовский, Мира, 59/а	t	small
26288	91245	666	Ставропольский край, Невинномысск городской округ, село Рощинский, Мира, 57	t	small
26658	91613	1037	Ставропольский край, Невинномысск городской округ, село Родниковский, Шоссейная	f	small
26261	91218	639	Ставропольский край, Невинномысск городской округ, поселок Петровский, 40 лет Победы, 1/а	t	small
26296	91253	674	Ставропольский край, Невинномысск городской округ, село Новая Деревня, Ленина, 64	f	large
26249	91205	627	Ставропольский край, Невинномысск городской округ, Невинномысск, Вокзальная, 50	f	large
26278	91235	656	Ставропольский край, Невинномысск городской округ, село Надзорное, Ленина, 24	f	medium
26253	91209	631	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Фабричная, 42	f	large
26251	91207	629	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Скрипникова, 67	f	large
26246	91202	624	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Партизанская, 56	f	large
26250	91206	628	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Октябрьской революции, 63	f	large
26248	91204	626	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Октябрьской революции, 11	f	large
26254	91210	632	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Гагарина, 83	f	large
26247	91203	625	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Бульварная, 144	f	large
26255	91212	633	Ставропольский край, Невинномысск городской округ, село Кочубеевское, Балахонова, 1	f	large
26264	91221	642	Ставропольский край, Невинномысск городской округ, село Казьминское, Советская, 70	f	large
26263	91220	641	Ставропольский край, Невинномысск городской округ, село Казьминское, Революционная, 60	f	large
26273	91230	651	Ставропольский край, Невинномысск городской округ, село Заветное, Баркова, 17	f	large
26294	91251	672	Ставропольский край, Невинномысск городской округ, село Дегтяревский, Ленина, 36	f	medium
26289	91246	667	Ставропольский край, Невинномысск городской округ, село Георгиевская, Молодежная, 4	f	medium
26260	91217	638	Ставропольский край, Невинномысск городской округ, село Веселое, Зеленая, 15	f	large
26265	91222	643	Ставропольский край, Невинномысск городской округ, село Беловский, Центральная, 75	t	small
26286	91243	664	Ставропольский край, Невинномысск городской округ, село Барсуковский, Центральная, 7	t	small
26281	91238	659	Ставропольский край, Невинномысск городской округ, село Барсуковская, Ленина, 37	f	large
26275	91232	653	Ставропольский край, Невинномысск городской округ, село Балахоновское, пл. Гетало, 3	f	large
26267	91224	645	Ставропольский край, Невинномысск городской округ, село Андреевский, Центральная, 8	t	small
26271	91228	649	Ставропольский край, Невинномысск, село Вревское, Почтовая, 62	f	large
123502	91400	821	Ставропольский край, Минераловодский район, село Фруктовый, Королева, 1	f	\N
26440	91396	818	Ставропольский край, Минераловодский район, село Ульяновка, Дом культуры	f	large
26421	91377	799	Ставропольский край, Минераловодский район, село Сухая Падина, Дом культуры	f	small
26445	91402	823	Ставропольский край, Минераловодский район, село Сунжа, Дом культуры	f	medium
26420	91376	798	Ставропольский край, Минераловодский район, село Старотарский, Дом культуры	f	small
26418	91374	796	Ставропольский край, Минераловодский район, село Славянский, Дом культуры	f	medium
26422	91378	800	Ставропольский край, Минераловодский район, село Розовка, Дом культуры	f	large
123499	91394	816	Ставропольский край, Минераловодский район, село Прикумское, Ленина, 56	f	\N
26433	91389	811	Ставропольский край, Минераловодский район, село Побегайловка, Дом культуры	f	large
26426	91382	804	Ставропольский край, Минераловодский район, село Перевальный, Дом культуры	f	large
26414	91370	792	Ставропольский край, Минераловодский район, село Первомайский, Дом культуры	f	large
26415	91371	793	Ставропольский край, Минераловодский район, село Первомайский, Московская, 18А	f	medium
26437	91393	815	Ставропольский край, Минераловодский район, село Орбельяновка, библиотека	f	large
26432	91388	810	Ставропольский край, Минераловодский район, село Новотерский, Дворец культуры, фойе	f	large
26427	91383	805	Ставропольский край, Минераловодский район, село Новотерский, Дом культуры, спорт зал	f	large
26425	91381	803	Ставропольский край, Минераловодский район, село Нижняя Александровка, Дом культуры	f	large
26444	91401	822	Ставропольский край, Минераловодский район, село Нижнебалковский, Дом культуры	f	small
26424	91380	802	Ставропольский край, Минераловодский район, село Нагутское, Дом культуры	f	large
26419	91375	797	Ставропольский край, Минераловодский район, село Марьины Колодцы, административное здание	f	large
26429	91385	807	Ставропольский край, Минераловодский район, село Ленинский, Дом культуры	f	large
26412	91368	790	Ставропольский край, Минераловодский район, село Левокумка, Степная, 6	f	large
26411	91367	789	Ставропольский край, Минераловодский район, село Левокумка, Мостовая, 2А	f	large
26431	91387	809	Россия, Ставропольский край, Минераловодский район, село Кумской	f	small
26436	91392	814	Ставропольский край, Минераловодский район, село Кумагорск, 1, помешение бывшей библиотеки	f	small
26430	91386	808	Ставропольский край, Минераловодский район, село Красный Пахарь, 9 Мая, 26	f	large
26434	91390	812	Ставропольский край, Минераловодский район, село Канглы, Дом культуры	f	large
26435	91391	813	Ставропольский край, Минераловодский район, село Канглы, ул.Шоссейная, 2 / д.11	f	small
26417	91373	795	Ставропольский край, Минераловодский район, село Загорский, МОУ Средняя образ.школа №, 18	f	large
26379	91337	757	Ставропольский край, Минераловодский район, село Евдокимовский, ДК	f	medium
26439	91395	817	Ставропольский край, Минераловодский район, село Долина, библиотека	f	large
26423	91379	801	Ставропольский край, Минераловодский район, село Греческое, Дом культуры	f	medium
26441	91398	819	Ставропольский край, Минераловодский район, село Гражданское, МБУ Гражданское социально-культурное объединение	f	large
123500	91399	820	Ставропольский край, Минераловодский район, село Гражданское, Пролетарская, 23А	f	\N
26428	91384	806	Ставропольский край, Минераловодский район, село Бородыновка, Дом культуры	f	large
8564	43289	377	республика Коми, Ухта, Интернациональная, 72	f	large
26410	91366	788	Ставропольский край, Минераловодский район, поселок Анджиевский, административное здание ООО Стройтранс 	f	large
26409	91365	787	Ставропольский край, Минераловодский район, поселок Анджиевский, Дом культуры	f	large
26408	91364	786	Ставропольский край, Минераловодский район, поселок Анджиевский, Береговая, 2б	f	medium
26370	91328	748	Ставропольский край, Лермонтов городской округ, село Острогорка, Комсомольская, 15-в	f	large
26360	91317	738	Ставропольский край, Левокумский район, село Урожайное, площадь Ленина, 1	f	large
26363	91320	741	Ставропольский край, Левокумский район, село Турксад, Шоссейная, 24	f	large
26364	91321	742	Ставропольский край, Левокумский район, село Приозерское, Мира, 35	f	large
26357	91314	735	Ставропольский край, Левокумский район, село Правокумское, Советская, 2	f	large
26358	91315	736	Ставропольский край, Левокумский район, село Правокумское, Гагарина, 10	f	large
26356	91313	734	Ставропольский край, Левокумский район, село Новокумский, Мичурина, 1	f	large
26365	91323	743	Ставропольский край, Левокумский район, село Николо-Александровское, Кооперативная, 116	f	large
26366	91324	744	Ставропольский край, Левокумский район, село Ленинский, Мира, 1	f	small
26354	91311	732	Ставропольский край, Левокумский район, село Левокумское, Пролетарская, 177	f	large
26352	91309	730	Ставропольский край, Левокумский район, село Левокумское, Пролетарская, 46	f	large
26353	91310	731	Ставропольский край, Левокумский район, село Левокумское, Комсомольская, 62	f	large
26355	91312	733	Ставропольский край, Левокумский район, село Левокумское, Борцов Революции, 22	f	large
26367	91325	745	Ставропольский край, Левокумский район, село Кумская Долина, Гагарина, 17	f	large
26369	91327	747	Ставропольский край, Левокумский район, село Заря, Красная, 10	f	large
26359	91316	737	Ставропольский край, Левокумский район, село Владимировка, Лыхова, 16	f	large
26852	91795	1231	Ставропольский край, Левокумский район, село Владимировка, Ленина, 78	f	large
26362	91319	740	Ставропольский край, Левокумский район, село Величаевское, Сестер Антоновых, 2	f	large
26361	91318	739	Ставропольский край, Левокумский район, село Величаевское, Пушкина, 65	f	large
26368	91326	746	Ставропольский край, Левокумский район, село Бургун-Маджары, Ленина, 75	f	medium
26332	91289	710	Ставропольский край, Курский район, село Эдиссия, Свердлова, 18	f	large
26333	91290	711	Ставропольский край, Курский район, село Эдиссия, Исаакяна, 21	f	large
26335	91292	713	Ставропольский край, Курский район, село Уваровское, Колхозная, 2	f	medium
26341	91298	719	Ставропольский край, Курский район, село Стодеревская, Советская, 1	f	large
26340	91297	718	Ставропольский край, Курский район, село Серноводское, Октябрьская, 1	f	medium
26337	91294	715	Ставропольский край, Курский район, село Русское, Школьная, 12	f	large
26336	91293	714	Ставропольский край, Курский район, село Русское, Кооперативная, 120 А	f	large
26351	91308	729	Ставропольский край, Курский район, село Рощино, Ленина, 20	f	medium
26329	91286	707	Ставропольский край, Курский район, село Ростовановское, Ленина, 14	f	large
26327	91284	705	Ставропольский край, Курский район, село Ровный, Крестьянская, 3	f	small
26328	91285	706	Ставропольский край, Курский район, село Пролетарский, Мира, 9	f	large
26343	91300	721	Ставропольский край, Курский район, село Привольный, Центральная, 45	f	small
26345	91302	723	Ставропольский край, Курский район, село Полтавское, Кооперативная, 1 Б	f	large
26325	91282	703	Ставропольский край, Курский район, село Новая Деревня, Зеленого, 50	f	medium
26348	91305	726	Ставропольский край, Курский район, село Мирный, Мира, 21	f	large
26320	91277	698	Ставропольский край, Курский район, село Курская, Школьный переулок, 14	f	large
26319	91276	697	Ставропольский край, Курский район, село Курская, Школьный переулок, 2	f	large
26323	91280	701	Ставропольский край, Курский район, село Курская, Титова, 12	f	large
26324	91281	702	Ставропольский край, Курский район, село Курская, Кондратенко, 60	f	large
26321	91278	699	Ставропольский край, Курский район, село Курская, Калинина, 226	f	large
26322	91279	700	Ставропольский край, Курский район, село Курская, Акулова, 56	f	large
26344	91301	722	Ставропольский край, Курский район, село Кировский, Комсомольская, 19А	t	small
26346	91303	724	Ставропольский край, Курский район, село Дыдымкин, Тивилева, 3	f	medium
26326	91283	704	Ставропольский край, Курский район, село Добровольное, Миропольская, 35	t	small
26339	91296	717	Ставропольский край, Курский район, село Графский, Школьная, 5	f	medium
26342	91299	720	Ставропольский край, Курский район, село Галюгаевская, Бражненко, 11	f	large
26349	91306	727	Ставропольский край, Курский район, село Бурунный, Кооперативная, 9	t	small
26338	91295	716	Ставропольский край, Курский район, село Бугулов, Школьная, 25	f	medium
26350	91307	728	Ставропольский край, Курский район, село Березкин, Школьная, 8	t	small
26334	91291	712	Ставропольский край, Курский район, село Балтийский, Школьная, 1 А	f	large
26347	91304	725	Ставропольский край, Курский район, село Ага-Батыр, Южная, 21	f	medium
26318	91275	696	Ставропольский край, Красногвардейский район, село Штурм, Партизанская, 9	f	medium
26311	91268	689	Ставропольский край, Красногвардейский район, село Средний, 60 лет Октября, 61	f	small
26310	91267	688	Ставропольский край, Красногвардейский район, село Родыки, Памяти, 115	f	large
26308	91265	686	Ставропольский край, Красногвардейский район, село Привольное, Шоссейная, 2а	f	large
26309	91266	687	Ставропольский край, Красногвардейский район, село Привольное, Пролетарская, 108	f	large
26313	91270	691	Ставропольский край, Красногвардейский район, село Преградное, Красная, 78А	f	large
26316	91273	694	Ставропольский край, Красногвардейский район, село Покровское, Шоссейная, 107	f	large
26315	91272	693	Ставропольский край, Красногвардейский район, село Новомихайловское, Ленина, 74	f	large
26314	91271	692	Ставропольский край, Красногвардейский район, село Медвеженский, Красногвардейская, 27	f	large
26307	91264	685	Ставропольский край, Красногвардейский район, село Ладовская Балка, Мира, 22	f	large
26306	91263	684	Ставропольский край, Красногвардейский район, село Ладовская Балка, Кооперативная, 7	f	large
26305	91262	683	Ставропольский край, Красногвардейский район, село Красногвардейское, Ярмарочная, 11	f	large
26302	91259	680	Ставропольский край, Красногвардейский район, село Красногвардейское, Школьная, 12	f	large
26301	91258	679	Ставропольский край, Красногвардейский район, село Красногвардейское, Первомайская, 2	f	large
26300	91257	678	Ставропольский край, Красногвардейский район, село Красногвардейское, Микояна, 69	f	large
26303	91260	681	Ставропольский край, Красногвардейский район, село Красногвардейское, Ленина, 44	f	large
26304	91261	682	Ставропольский край, Красногвардейский район, село Красногвардейское, Красная, 262	f	large
26299	91256	677	Ставропольский край, Красногвардейский район, село Красногвардейское, Колпаковская, 42/1	f	medium
26317	91274	695	Ставропольский край, Красногвардейский район, село Коммунар, Мира, 1	f	large
26312	91269	690	Ставропольский край, Красногвардейский район, село Дмитриевское, Октябрьская, 27	f	large
26269	91226	647	Ставропольский край, Кочубеевский район, село Цветное, Садовая, 20	t	small
26297	91254	675	Ставропольский край, Кочубеевский район, село Прогресс, Мира, 38	f	medium
26293	91250	671	Ставропольский край, Кочубеевский район, Невинномысск, Красная, 19А	f	large
26252	91208	630	Ставропольский край, Кочубеевский район, Кочубеевское, Восточная, 63	f	large
26258	91215	636	Ставропольский край, Кочубеевский район, село Ивановское, Калинина, 117	f	large
26272	91229	650	Ставропольский край, Кочубеевский район, село Заветное, Почтовая, 1	f	large
26259	91216	637	Ставропольский край, Кочубеевский район, село Воронежское, Школьный переулок, 9	f	medium
26280	91237	658	Ставропольский край, Кочубеевский район, село Барсуковская, Ленина, 43	f	large
26222	91177	600	Ставропольский край, Кисловодск городской округ, село Аликоновка, Прямая, 4	f	large
26195	91150	573	Ставропольский край, Кировский район, село Фазанный, Рабочая, 4	f	medium
26186	91140	564	Ставропольский край, Кировский район, село Старопавловская, Ленинская	f	large
26180	91135	558	Ставропольский край, Кировский район, село Советская, Шилиной переулок, 21	f	large
26182	91136	560	Ставропольский край, Кировский район, село Советская, Кирова, 9	f	large
26193	91148	571	Ставропольский край, Кировский район, село Прогресс, Зеленый переулок, 1	f	medium
25834	90806	212	Ставропольский край, Арзгирский район, село Арзгир, Энгельса, 23	f	large
26184	91138	562	Ставропольский край, Кировский район, село Орловка, Октябрьская, 31	f	large
26178	91133	556	Ставропольский край, Кировский район, Новопавловск, промзона	f	large
26174	91129	552	Ставропольский край, Кировский район, Новопавловск, пл.Ленина, Дворец культуры им.С.М.Романько	f	large
26177	91132	555	Ставропольский край, Кировский район, Новопавловск, Центральная, 12	f	large
123487	91131	554	Ставропольский край, Кировский район, Новопавловск, Садовая, 109	f	\N
26173	91128	551	Ставропольский край, Кировский район, Новопавловск, Октябрьская, 80	f	large
26179	91134	557	Ставропольский край, Кировский район, Новопавловск, Кирова, 33, фойе №2	f	large
26172	91127	550	Ставропольский край, Кировский район, Новопавловск, Кирова, 33	f	large
26189	91143	567	Ставропольский край, Кировский район, село Марьинская, Победы, 54 Е	f	large
123489	91142	566	Ставропольский край, Кировский район, село Марьинская, Победы, 54 Ж	f	\N
26187	91141	565	Ставропольский край, Кировский район, село Марьинская, Кутузова, Средняя школа	f	large
26194	91149	572	Ставропольский край, Кировский район, село Комсомолец, Клубная, 22	f	large
26185	91139	563	Ставропольский край, Кировский район, село Коммаяк, Ленина, 31	f	large
123491	91144	568	Ставропольский край, Кировский район, село Зольская, Первомайская, 5	f	\N
123492	91145	569	Ставропольский край, Кировский район, село Зольская, Октябрьская, 1	f	\N
123494	91146	570	Ставропольский край, Кировский район, село Зольская, 30 лет Победы, 2	f	\N
26183	91137	561	Ставропольский край, Кировский район, село Горнозаводское, Калинина, 78	f	large
26162	91116	538	Ставропольский край, Ипатовский район, село Юсуп-Кулакский, Центральная, 62	f	medium
26171	91126	547	Ставропольский край, Ипатовский район, село Тахта, Ленина, 115	f	large
123484	91110	532	Ставропольский край, Ипатовский район, село Софиевский Городок, Дорожный, 25 	f	\N
26152	91109	531	Ставропольский край, Ипатовский район, село Софиевка, Пролетарская, 44	f	small
26170	91125	546	Ставропольский край, Ипатовский район, село Советское Руно, Центральная площадь, 2	f	large
26150	91107	529	Ставропольский край, Ипатовский район, село Родники, Новая, 33	f	small
26169	91124	545	Ставропольский край, Ипатовский район, село Первомайское, Попова, 37	f	large
26168	91123	544	Ставропольский край, Ипатовский район, село Октябрьское, Калинина, 122/1	f	large
26166	91120	542	Ставропольский край, Ипатовский район, село Нижний Барханчак, Буденного, 29Б	t	small
26163	91117	539	Ставропольский край, Ипатовский район, село Мелиорация, Шоссейная, 6	t	small
26164	91118	540	Ставропольский край, Ипатовский район, село Малый Барханчак, Центральная, 14	f	medium
26161	91115	537	Ставропольский край, Ипатовский район, село Лиман, Ленина, 71	f	large
26159	91113	535	Ставропольский край, Ипатовский район, село Лесная Дача, Мира, 10	f	small
26167	91121	543	Ставропольский край, Ипатовский район, село Крестьянское, Почтовая, 58	t	small
26155	91112	534	Ставропольский край, Ипатовский район, село Красочный, Центральная, 8	f	large
26160	91114	536	Ставропольский край, Ипатовский район, село Красная Поляна, Ленина, 55	f	small
26142	91099	521	Ставропольский край, Ипатовский район, село Кочержинский	t	small
26154	91111	533	Ставропольский край, Ипатовский район, село Кевсала, Ленина, 165	f	large
26137	91093	515	Ставропольский край, Ипатовский район, Ипатово, Орджоникидзе, 76	f	large
26136	91092	514	Ставропольский край, Ипатовский район, Ипатово, Орджоникидзе, 116	f	large
26135	91091	513	Ставропольский край, Ипатовский район, Ипатово, Ленина, 347	f	large
26141	91098	520	Ставропольский край, Ипатовский район, Ипатово, Заречная, 37	f	large
26138	91094	516	Ставропольский край, Ипатовский район, Ипатово, Голубовского, 137	f	large
26134	91090	512	Ставропольский край, Ипатовский район, Ипатово, Голубовского, 295	f	large
26151	91108	530	Ставропольский край, Ипатовский район, село Золотаревка, Юбилейная, 39	f	medium
26148	91105	527	Ставропольский край, Ипатовский район, село Дружный, Новая, 3	t	small
26149	91106	528	Ставропольский край, Ипатовский район, село Добровольное, Ленина, 126	f	medium
26147	91104	526	Ставропольский край, Ипатовский район, село Винодельненский, Советская, 1	f	large
26165	91119	541	Ставропольский край, Ипатовский район, село Верхний Барханчак, Гагарина, 38А	t	small
26146	91103	525	Ставропольский край, Ипатовский район, село Бурукшун, Музыкальный, 7	f	large
26143	91100	522	Ставропольский край, Ипатовский район, село Большевик, Ленина, 1	f	large
26145	91102	524	Ставропольский край, Ипатовский район, село Большая Джалга, Ленина, 55	f	medium
26144	91101	523	Ставропольский край, Ипатовский район, село Большая Джалга, Базарная, 6	f	large
26109	91065	487	Ставропольский край, Изобильненский район, село Широбоков, Победы, 35	f	medium
26121	91077	499	Ставропольский край, Изобильненский район, село Филимоновская, Пушкина, 9	f	medium
26110	91066	488	Ставропольский край, Изобильненский район, село Тищенское, Мира, 14	f	large
26124	91080	502	Ставропольский край, Изобильненский район, село Сухой, Тюльпина, 27-А	f	small
123480	91078	500	Ставропольский край, Изобильненский район, село Староизобильная, Мира, 60	f	\N
26125	91081	503	Ставропольский край, Изобильненский район, село Спорный, Мира, 92/19	f	large
26102	91058	480	Ставропольский край, Изобильненский район, поселок Солнечнодольск, б-р Школьный, 2	f	large
26100	91056	478	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Школьный б-р, 4	f	large
26099	91055	477	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Школьный б-р, 6	f	large
26104	91060	482	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Молодежная, 3	f	large
26103	91059	481	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Молодежная, 4	f	large
26101	91057	479	Ставропольский край, Изобильненский район, поселок Солнечнодольск, Молодежная, 6	f	large
26123	91079	501	Ставропольский край, Изобильненский район, село Смыков, Центральная, 43	t	small
26106	91062	484	Ставропольский край, Изобильненский район, поселок Рыздвяный, Южная, 19	f	large
26105	91061	483	Ставропольский край, Изобильненский район, поселок Рыздвяный, Советская, 21	f	large
26107	91063	485	Ставропольский край, Изобильненский район, поселок Рыздвяный, Восточная, 4	f	large
26127	91083	505	Ставропольский край, Изобильненский район, село Рождественская, Ленина, 174	f	large
26126	91082	504	Ставропольский край, Изобильненский район, село Рождественская, Ленина, 125	f	medium
26112	91068	490	Ставропольский край, Изобильненский район, село Птичье, Кошевого, 1Б	f	medium
26111	91067	489	Ставропольский край, Изобильненский район, село Птичье, Карла Маркса, 31	f	large
26128	91084	506	Ставропольский край, Изобильненский район, село Подлужное, Калинина, 3	f	large
26114	91070	492	Ставропольский край, Изобильненский район, село Передовой, Октября, 55	f	large
26116	91072	494	Ставропольский край, Изобильненский район, село Новотроицкая, Шоссейная, 8	f	large
26117	91073	495	Ставропольский край, Изобильненский район, село Новотроицкая, Первомайская, 164	f	large
26118	91074	496	Ставропольский край, Изобильненский район, село Новотроицкая, Мещерякова, 120	f	large
26119	91075	497	Ставропольский край, Изобильненский район, село Новотроицкая, Ленина, 306	f	medium
26108	91064	486	Ставропольский край, Изобильненский район, село Новоизобильный, Школьная, 18	f	medium
26133	91089	511	Ставропольский край, Изобильненский район, село Найденовка, Ленина, 1	f	small
26130	91086	508	Ставропольский край, Изобильненский район, село Московское, Мира, 51	f	large
26129	91085	507	Ставропольский край, Изобильненский район, село Московское, Ленина, 175	f	large
26131	91087	509	Ставропольский край, Изобильненский район, село Московское, Гоголя, 73	f	small
26113	91069	491	Ставропольский край, Изобильненский район, село Красная Балка, Красная, 135	f	large
26120	91076	498	Ставропольский край, Изобильненский район, село Каменнобродская, Мира, 13	f	large
26083	91038	461	Ставропольский край, Изобильненский район, Изобильный, 5-Б	f	large
123477	91049	472	Ставропольский край, Изобильненский район, Изобильный, Южная, 97А	f	\N
26079	91034	457	Ставропольский край, Изобильненский район, Изобильный, Электронная, 8	f	large
26084	91039	462	Ставропольский край, Изобильненский район, Изобильный, Школьная, 1	f	large
26085	91040	463	Ставропольский край, Изобильненский район, Изобильный, Промышленная, 118/3	f	large
123478	91052	475	Ставропольский край, Изобильненский район, Изобильный, Привокзальная площадь	f	\N
26093	91048	471	Ставропольский край, Изобильненский район, Изобильный, Новотроицкое шоссе, 1	f	large
26089	91044	467	Ставропольский край, Изобильненский район, Изобильный, Ленина, 63	f	large
26088	91043	466	Ставропольский край, Изобильненский район, Изобильный, Ленина, 16	f	large
26087	91042	465	Ставропольский край, Изобильненский район, Изобильный, Ленина, 61	f	large
26086	91041	464	Ставропольский край, Изобильненский район, Изобильный, Ленина, 16	f	large
26082	91037	460	Ставропольский край, Изобильненский район, Изобильный, Крупской, 2-А	f	large
26098	91054	476	Ставропольский край, Изобильненский район, Изобильный, Красноармейская, 69	f	large
123474	91036	459	Ставропольский край, Изобильненский район, Изобильный, Красная, 6	f	\N
26080	91035	458	Ставропольский край, Изобильненский район, Изобильный, Красная, 6	f	large
26090	91045	468	Ставропольский край, Изобильненский район, Изобильный, Колхозная, 2-А	f	large
26092	91047	470	Ставропольский край, Изобильненский район, Изобильный, Заводская, 1	f	large
26095	91050	473	Ставропольский край, Изобильненский район, Изобильный, Доватора, 388	f	large
26078	91033	456	Ставропольский край, Изобильненский район, Изобильный, Доватора, 1	f	large
26091	91046	469	Ставропольский край, Изобильненский район, Изобильный, Бонивура, 1	f	large
26096	91051	474	Ставропольский край, Изобильненский район, Изобильный, 50 лет Октября, 29	f	large
26115	91071	493	Ставропольский край, Изобильненский район, село Гаевская, Красная, 32-б	t	small
26132	91088	510	Ставропольский край, Изобильненский район, село Беляев, Пролетарская, 107	f	small
123468	91026	449	Ставропольский край, Железноводск городской округ, поселок Иноземцево, 8 марта, 5А	f	\N
26001	90968	379	Ставропольский край, Грачевский район, село Тугулук, Гагарина, 10	f	large
25998	90965	376	Ставропольский край, Грачевский район, село Старомарьевка, Свердлова, 65	f	large
25997	90964	375	Ставропольский край, Грачевский район, село Старомарьевка, Красная, 50	f	medium
25999	90966	377	Ставропольский край, Грачевский район, село Старомарьевка, Войкова, 95	f	medium
25994	90961	372	Ставропольский край, Грачевский район, село Спицевка, площадь Революции, 16	f	large
25992	90959	370	Ставропольский край, Грачевский район, село Сергиевское, Карла Маркса, 11	f	large
25993	90960	371	Ставропольский край, Грачевский район, село Октябрь, Садовая, 31а	f	small
25996	90963	374	Ставропольский край, Грачевский район, село Новоспицевский, Центральная, 8	f	small
25988	90955	366	Ставропольский край, Грачевский район, село Нагорный, Октябрьская	f	small
25989	90956	367	Ставропольский край, Грачевский район, село Кугульта, Советская, 55	f	large
25990	90957	368	Ставропольский край, Грачевский район, село Кугульта, Красная, 113	f	large
26000	90967	378	Ставропольский край, Грачевский район, село Кизилов, Центральная, 1	t	small
25983	90950	361	Ставропольский край, Грачевский район, село Грачевка, Шоссейная, 8	f	large
25985	90952	363	Ставропольский край, Грачевский район, село Грачевка, Ставропольская, 75Б	f	large
25984	90951	362	Ставропольский край, Грачевский район, село Грачевка, Советская, 13	f	large
25991	90958	369	Ставропольский край, Грачевский район, село Верхняя Кугульта, Ленина, 17	f	large
25982	90949	360	Ставропольский край, Грачевский район, село Бешпагир, Ленина, 59А	f	large
25981	90948	359	Ставропольский край, Грачевский район, село Бешпагир, Ленина, 10в	f	large
25995	90962	373	Ставропольский край, Грачевский район, село Базовый, Красная, 19	f	small
25979	90946	357	Ставропольский край, Георгиевский район, село Шаумянский, Советская, 1	f	large
25977	90944	355	Ставропольский край, Георгиевский район, село Урухская, Ленина, 20	f	large
25948	90914	326	Россия, Ставропольский край, Георгиевский район, село Терский	f	small
25968	90935	346	Ставропольский край, Георгиевский район, село Приэтокский, Центральная, 2	f	small
25975	90942	353	Ставропольский край, Георгиевский район, село Подгорная, Ленина, 51	f	large
25974	90941	352	Ставропольский край, Георгиевский район, село Подгорная, Ленина, 66	f	large
25957	90923	335	Ставропольский край, Георгиевский район, село Падинский, 40 лет Победы, 17	f	large
25972	90939	350	Ставропольский край, Георгиевский район, село Обильное, Советская, 46	f	large
25973	90940	351	Ставропольский край, Георгиевский район, село Обильное, Ленина, 75	f	large
25969	90936	347	Ставропольский край, Георгиевский район, село Новый, 60 лет СССР, 14	f	large
25976	90943	354	Ставропольский край, Георгиевский район, село Новоульяновский, Кооперативная, 1	f	large
25980	90947	358	Ставропольский край, Георгиевский район, село Новомихайловский, Продольная, 34	t	small
25970	90937	348	Ставропольский край, Георгиевский район, село Новозаведенное, Школьная, 31 а	f	large
25971	90938	349	Ставропольский край, Георгиевский район, село Новозаведенное, Кооперативная, 3 г	f	large
25978	90945	356	Ставропольский край, Георгиевский район, село Нижнезольский, Школьная, 24	f	medium
25965	90932	343	Ставропольский край, Георгиевский район, село Незлобная, Юбилейная, 141	f	large
25962	90929	340	Ставропольский край, Георгиевский район, село Незлобная, Школьная, 18	f	large
25961	90927	339	Ставропольский край, Георгиевский район, село Незлобная, Школьная, 20	f	large
25966	90933	344	Ставропольский край, Георгиевский район, село Незлобная, Упорная, 43	f	large
25964	90931	342	Ставропольский край, Георгиевский район, село Незлобная, Степная, 229	f	large
25967	90934	345	Ставропольский край, Георгиевский район, село Незлобная, Незлобненская, 23А	f	large
25963	90930	341	Ставропольский край, Георгиевский район, село Незлобная, Ленина, 224	f	large
25959	90925	337	Ставропольский край, Георгиевский район, село Лысогорская, Школьная, 73	f	large
25958	90924	336	Ставропольский край, Георгиевский район, село Лысогорская, Школьная, 114	f	large
25960	90926	338	Ставропольский край, Георгиевский район, село Лысогорская, Ленина, 190	f	large
25952	90918	330	Ставропольский край, Георгиевский район, село Краснокумское, Юбилейная, 4	f	large
25953	90919	331	Ставропольский край, Георгиевский район, село Краснокумское, Пионерская, 23	f	large
25954	90920	332	Ставропольский край, Георгиевский район, село Краснокумское, Курченко, 1	f	large
25956	90922	334	Ставропольский край, Георгиевский район, Краснокумское, Кирова, 1/2	f	large
25955	90921	333	Ставропольский край, Георгиевский район, село Краснокумское, Кирова, 16	f	large
123454	90916	328	Ставропольский край, Георгиевский район, село Георгиевская, Кооперативный, 9	f	\N
25951	90917	329	Ставропольский край, Георгиевский район, село Георгиевская, Выгонная, 85	f	large
25949	90915	327	Ставропольский край, Георгиевский район, село Балковский, Новая, 18	f	medium
25947	90913	325	Ставропольский край, Георгиевский район, село Александрийская, Комсомольский, 13	f	large
25946	90912	324	Ставропольский край, Георгиевский район, село Александрийская, Комсомольский, 11	f	large
25945	90911	323	Ставропольский край, Георгиевский район, село Александрийская, Гагарина, 308	f	large
25912	90882	290	Ставропольский край, Буденновский район, село Херсонский, Октябрьская, 107	t	small
25917	90887	295	Ставропольский край, Буденновский район, село Толстово-Васюковское, Школьная, 2а	f	medium
123453	90884	292	Ставропольский край, Буденновский район, село Терек, Школьная, 5	f	\N
123449	90881	289	Ставропольский край, Буденновский район, село Преображенское, Артезианская, 19	f	\N
25910	90880	288	Ставропольский край, Буденновский район, село Прасковея, 1, корпус сельхозтехникума	f	small
123446	90879	287	Ставропольский край, Буденновский район, село Прасковея, Ленина, 33А	f	\N
25907	90877	285	Ставропольский край, Буденновский район, село Прасковея, Дзержинского, 66	f	large
25906	90876	284	Ставропольский край, Буденновский район, село Прасковея, Дзержинского, 92	f	large
123444	90878	286	Ставропольский край, Буденновский район, село Прасковея, Борцов Революции, 18	f	\N
25919	90889	297	Ставропольский край, Буденновский район, село Правобережный, Октябрьская, 91	f	small
25915	90885	293	Ставропольский край, Буденновский район, село Плаксейка, Железнодорожная, 1	t	small
25899	90869	277	Ставропольский край, Буденновский район, Буденновск, 3, контора бригады	t	small
25903	90873	281	Ставропольский край, Буденновский район, Буденновск, Советская, 81	f	large
25896	90866	274	Ставропольский край, Буденновский район, Буденновск, Почтовая, 14	f	large
25898	90868	276	Ставропольский край, Буденновский район, Буденновск, Кировская, 18г	f	large
123439	90865	273	Ставропольский край, Буденновский район, село Архиповское, Советская, 147	f	\N
25893	90863	271	Ставропольский край, Буденновский район, село Архангельское, Советская, 71	f	large
8548	43276	361	республика Коми, Ухта, Кольцевая, 19	f	large
25894	90864	272	Ставропольский край, Буденновский район, село Архангельское, Румянцева, 254	f	medium
25905	90875	283	Ставропольский край, Буденновск городской округ, Буденновск, Совхозная, 55	f	medium
25904	90874	282	Ставропольский край, Буденновск городской округ, Буденновск, Советская, 130	f	large
25918	90888	296	Ставропольский край, Буденновск городской округ, Буденновск, Ленина, 125	f	large
123440	90867	275	Ставропольский край, Буденновск городской округ, Буденновск, Виноградная, 6А	f	\N
25880	90852	258	Ставропольский край, Буденновск городской округ, Буденновск, микрорайон 1, МОУ СОШ №, 2	f	large
25874	90846	252	Ставропольский край, Буденновск городской округ, Буденновск, микрорайон 833-А	f	large
25871	90843	249	Ставропольский край, Благодарненский район, село Эдельбай, Манкаева, 70	f	medium
25870	90842	248	Ставропольский край, Благодарненский район, село Шишкино, Дьякова, 55	f	medium
25869	90841	247	Ставропольский край, Благодарненский район, село Ставропольский, Советская, 3	f	large
25868	90840	246	Ставропольский край, Благодарненский район, село Спасское, Красная, 171	f	large
123434	90838	243	Ставропольский край, Благодарненский район, село Сотниковское, Советская, 290/1	f	\N
25866	90839	244	Ставропольский край, Благодарненский район, село Сотниковское, Красная, 162	f	large
25864	90837	242	Ставропольский край, Благодарненский район, село Мирное, Красная, 46 б	f	medium
25862	90835	240	Ставропольский край, Благодарненский район, село Каменная Балка, Школьная, 22	f	large
25861	90834	239	Ставропольский край, Благодарненский район, село Елизаветинское, Ленина, 136	f	large
25860	90833	238	Ставропольский край, Благодарненский район, село Бурлацкое, Красная, 91	f	large
25859	90832	237	Ставропольский край, Благодарненский район, село Большевик, Зеленая Роща бульвар, 44	f	medium
123436	90824	245	Ставропольский край, Благодарненский район, Благодарный, пл.Строителей, 2	f	\N
25851	90824	229	Ставропольский край, Благодарненский район, Благодарный, пл.Строителей, 2	f	large
25846	90819	224	Ставропольский край, Благодарненский район, Благодарный, пер.Школьный, 5 а	f	large
25852	90825	230	Ставропольский край, Благодарненский район, Благодарный, пер.Кочубея, 25	f	large
25849	90822	227	Ставропольский край, Благодарненский район, Благодарный, Советская, 209	f	large
25847	90820	225	Ставропольский край, Благодарненский район, Благодарный, Советская, 396	f	large
25855	90828	233	Ставропольский край, Благодарненский район, Благодарный, Первомайская, 1	f	large
25853	90826	231	Ставропольский край, Благодарненский район, Благодарный, Первомайская, 22	f	large
123563	91845	1284	Ставропольский край, Благодарненский район, Благодарный, Московская, 250	f	\N
123431	90823	228	Ставропольский край, Благодарненский район, Благодарный, Московская, 112	f	\N
25854	90827	232	Ставропольский край, Благодарненский район, Благодарный, Ленина, 251	f	large
25848	90821	226	Ставропольский край, Благодарненский район, Благодарный, Комсомольская, 16	f	large
25863	90836	241	Ставропольский край, Благодарненский район, село Алтухов, Чапаева, 33	f	medium
25858	90831	236	Ставропольский край, Благодарненский район, село Алексеевское, Ленина, 117	f	large
25856	90829	234	Ставропольский край, Благодарненский район, село Александрия, Пролетарская, 121/1	f	large
123432	90830	235	Ставропольский край, Благодарненский район, село Александрия, Красная, 240	f	\N
25845	90817	223	Ставропольский край, Арзгирский район, село Чограйский, переулок Сквозной, 2	f	medium
25844	90816	222	Ставропольский край, Арзгирский район, село Серафимовское, Ленина, 46А	f	large
25843	90815	221	Ставропольский край, Арзгирский район, село Садовое, Школьная, 38	f	large
25842	90814	220	Ставропольский край, Арзгирский район, село Родниковское, Бульварная, 79	f	medium
25841	90813	219	Ставропольский край, Арзгирский район, село Петропавловское, Студенческая, 78	f	large
25840	90812	218	Ставропольский край, Арзгирский район, село Новоромановское, Ленина, 130	f	large
25839	90811	217	Ставропольский край, Арзгирский район, село Каменная Балка, Бульварная, 21	f	medium
25838	90810	216	Ставропольский край, Арзгирский район, село Башанта, Оджаева, 16	f	small
25837	90809	215	Ставропольский край, Арзгирский район, село Арзгир, имени Оджаева, 51	f	large
8547	43275	360	республика Коми, Ухта, Кирпичная, 23	f	large
25835	90807	213	Ставропольский край, Арзгирский район, село Арзгир, Пети Базалеева, 8	f	large
25836	90808	214	Ставропольский край, Арзгирский район, село Арзгир, Горького, 18	f	large
25818	90788	196	Ставропольский край, Апанасенковский район, село Хлебный, Каменная, 2 а	f	small
123428	90805	211	Ставропольский край, Апанасенковский район, село Рагули, Советская, 56	f	\N
25832	90803	210	Ставропольский край, Апанасенковский район, село Манычское, Октябрьская, 48	f	large
123427	90802	209	Ставропольский край, Апанасенковский район, село Малая Джалга, Красная, 59	f	\N
25830	90801	208	Ставропольский край, Апанасенковский район, село Киевка, Октябрьская, 82	f	large
123418	90797	204	Ставропольский край, Апанасенковский район, село Дивное, Советская, 43	f	\N
25824	90795	202	Ставропольский край, Апанасенковский район, село Дивное, Советская, 197	f	large
123425	90800	207	Ставропольский край, Апанасенковский район, село Дивное, О.Кошевого, 180	f	\N
123421	90798	205	Ставропольский край, Апанасенковский район, село Дивное, Кашубы, 4	f	\N
25825	90796	203	Ставропольский край, Апанасенковский район, село Дивное, Вокзальная, 16	f	large
123422	90799	206	Ставропольский край, Апанасенковский район, село Дивное, 8 марта, 58	f	\N
25823	90794	201	Ставропольский край, Апанасенковский район, село Дербетовка, Красная, 27	f	large
25822	90792	200	Ставропольский край, Апанасенковский район, село Вознесеновское, Шоссейная, 15	f	large
123416	90791	199	Ставропольский край, Апанасенковский район, село Воздвиженское, Октябрьская, 89	f	\N
25817	90787	195	Ставропольский край, Апанасенковский район, село Водный, Пушкина, 16А	f	small
25820	90790	198	Ставропольский край, Апанасенковский район, село Белые Копани, Советская, 38	f	medium
25819	90789	197	Ставропольский край, Апанасенковский район, село Апанасенковское, Комсомольский пер, 12	f	large
25816	90786	194	Ставропольский край, Апанасенковский район, село Айгурский, Садовая, 26	f	medium
25807	90777	185	Ставропольский край, Андроповский район, село Янкуль, пер. Клубный, 2	f	large
25794	90765	172	Ставропольский край, Андроповский район, село Суркуль, Горького, 55	f	medium
25811	90781	189	Ставропольский край, Андроповский район, село Султан, Ленина, 102	f	medium
25813	90783	191	Ставропольский край, Андроповский район, село Солуно-Дмитриевское, Совхозная, 2	f	large
25814	90784	192	Ставропольский край, Андроповский район, село Солуно-Дмитриевское, Советская, 35	f	large
25803	90773	181	Ставропольский край, Андроповский район, село Подгорное, Цветочная, 5	t	small
25810	90780	188	Ставропольский край, Андроповский район, село Новая Янкуль, Победы, 15Б	f	large
25809	90779	187	Ставропольский край, Андроповский район, село Нижнеколонский, Центральная, 65	t	small
25815	90785	193	Ставропольский край, Андроповский район, село Куршава, Красная, 49	f	large
25797	90738	175	Ставропольский край, Андроповский район, село Курсавка, Октябрьская, 148	f	medium
25793	90764	171	Ставропольский край, Андроповский район, село Курсавка, Красная, 27	f	large
25796	90767	174	Ставропольский край, Андроповский район, село Курсавка, Войтика, 205	f	large
25795	90766	173	Ставропольский край, Андроповский район, село Курсавка, 1-е Мая, 12	f	large
25812	90782	190	Ставропольский край, Андроповский район, село Крымгиреевское, Кирова, 76	f	large
25801	90771	179	Ставропольский край, Андроповский район, село Красноярское, Подтенная, 4	f	medium
25808	90778	186	Ставропольский край, Андроповский район, село Кианкиз, Титова, 1А	f	small
123415	90776	184	Ставропольский край, Андроповский район, село Каскадный, Центральная, 7А	f	\N
123411	90772	180	Ставропольский край, Андроповский район, село Казинка, Школьная, 34	f	\N
123412	90775	183	Ставропольский край, Андроповский район, село Дубовая Балка, Школьная, 36Б	f	\N
25798	90768	176	Ставропольский край, Андроповский район, село Воровсколесская, Красная, 93	f	large
25799	90769	177	Ставропольский край, Андроповский район, село Воровсколесская, Грековская, 31/2	f	small
25804	90774	182	Ставропольский край, Андроповский район, село Водораздел, Школьная, 1	f	large
25800	90770	178	Ставропольский край, Андроповский район, село Алексеевское, Красная, 66	f	small
25773	90761	168	Ставропольский край, Александровский район, село Средний, Клубная, 1	f	large
25769	90754	161	Ставропольский край, Александровский район, село Северное, Мира, 16/А	f	large
25771	90763	170	Ставропольский край, Александровский район, село Садовое, Ленина, 16Б	f	large
25775	90759	166	Ставропольский край, Александровский район, село Саблинское, Октябрьская, 47	f	large
25774	90760	167	Ставропольский край, Александровский район, село Новокавказский, Средняя, 3	f	large
25772	90762	169	Ставропольский край, Александровский район, село Круглолесское, Советская, 46	f	large
25791	90756	163	Ставропольский край, Александровский район, село Калиновское, Глазкова, 366	f	large
25790	90755	162	Ставропольский край, Александровский район, село Калиновское, Глазкова, 206	f	large
25770	90753	160	Ставропольский край, Александровский район, село Дубовая Роща, Маяковского, 1	f	small
25792	90757	164	Ставропольский край, Александровский район, село Грушевское, Кирова, 69/5	f	large
25776	90758	165	Ставропольский край, Александровский район, село Всадник, 60 лет Октября, 12	f	small
25787	90750	157	Ставропольский край, Александровский район, село Александровское, Энгельса, 26	f	large
25784	90747	154	Ставропольский край, Александровский район, село Александровское, Щорса, 47	f	medium
25783	90746	153	Ставропольский край, Александровский район, село Александровское, Речной переулок, 9	f	large
25779	90742	149	Ставропольский край, Александровский район, село Александровское, Р.Люксембург, 1	f	large
25781	90744	151	Ставропольский край, Александровский район, село Александровское, Ленинская, 171	f	large
25789	90752	159	Ставропольский край, Александровский район, село Александровское, Красноармейская, 616	f	large
25778	90741	148	Ставропольский край, Александровский район, село Александровское, Красноармейская, 230	f	large
25777	90740	147	Ставропольский край, Александровский район, село Александровское, Красноармейская, 296	f	large
25788	90751	158	Ставропольский край, Александровский район, село Александровское, Калинина, 352	f	large
25786	90749	156	Ставропольский край, Александровский район, село Александровское, Калинина, 200	f	large
25785	90748	155	Ставропольский край, Александровский район, село Александровское, К.Маркса, 108	f	large
25780	90743	150	Ставропольский край, Александровский район, село Александровское, К.Маркса, 44	f	large
25782	90745	152	Ставропольский край, Александровский район, село Александровское, Виноградная, 2	f	large
8566	43291	379	республика Коми, Ухта, проспект Ленина, 40	f	large
8537	43265	350	республика Коми, Ухта, проспект Ленина, 6А	f	large
8570	43295	383	республика Коми, Ухта, проспект Космонавтов, 21А	f	large
8560	43286	373	республика Коми, Ухта, набережная Нефтяников, 19	f	large
8559	43286	372	республика Коми, Ухта, набережная Нефтяников, 19	f	large
8558	43285	371	республика Коми, Ухта, набережная Нефтяников, 18	f	large
8557	43285	370	республика Коми, Ухта, набережная Нефтяников, 18	f	large
8554	43282	367	республика Коми, Ухта, набережная Газовиков, 4/2	f	large
8535	43263	348	республика Коми, Ухта, Юбилейная, 14А	f	large
8534	43262	347	республика Коми, Ухта, Юбилейная, 22	f	large
8549	43277	362	республика Коми, Ухта, Школьная, 7	f	large
8551	43279	364	республика Коми, Ухта, Тихоновича, 3	f	large
8556	43284	369	республика Коми, Ухта, Строителей проезд, 25	f	large
8555	43283	368	республика Коми, Ухта, Строителей проезд, 15	f	large
8553	43281	366	республика Коми, Ухта, Строителей проезд, 1	f	large
8576	43301	389	республика Коми, Ухта, Совхозная, 4	f	large
8568	43293	381	республика Коми, Ухта, Советская, 14	f	large
8561	43287	374	республика Коми, Ухта, Советская, 5	f	large
8569	43218	382	республика Коми, Ухта, Советская, 2	f	large
8572	43297	385	республика Коми, Ухта, Сенюкова, 47	f	large
8571	43296	384	республика Коми, Ухта, Сенюкова, 49	f	large
8533	43261	346	республика Коми, Ухта, Севастопольская, 11	f	large
8567	43292	380	республика Коми, Ухта, Пионергорский проезд, 5	f	large
8542	43270	355	республика Коми, Ухта, Первомайская, 44	f	large
8541	43269	354	республика Коми, Ухта, Оплеснина, 13	f	large
8539	43267	352	республика Коми, Ухта, Оплеснина, 28	f	large
8544	43272	357	республика Коми, Ухта, Октябрьская, 7	f	large
8536	43264	349	республика Коми, Ухта, Октябрьская, 28/2	f	large
8550	43278	363	республика Коми, Ухта, Озерная, 10	f	large
8562	43288	375	республика Коми, Ухта, Ленина проспект, 26	f	large
8563	43289	376	республика Коми, Ухта, Интернациональная, 72	f	large
8540	43268	353	республика Коми, Ухта, Дзержинского, 17	f	large
8532	43260	345	республика Коми, Ухта, Дежнева, 16	f	medium
8543	43271	356	республика Коми, Ухта, Горького, 13	f	large
8531	43259	344	республика Коми, Ухта, Бушуева, 2	f	large
8552	43280	365	республика Коми, Ухта, Авиационная, 5	f	large
8538	43266	351	республика Коми, Ухта, 30 лет Октября, 1б	f	large
8445	43171	258	республика Коми, Усинск, Строителей, 11	f	large
8437	43164	250	республика Коми, Усинск, Строителей, 12	f	large
8435	43163	248	республика Коми, Усинск, Строителей, 4А	f	large
8436	43162	249	республика Коми, Усинск, Строителей, 10	f	large
8434	43162	247	республика Коми, Усинск, Строителей, 10	f	large
8443	43169	256	республика Коми, Усинск, Нефтяников, 37	f	large
8439	43166	252	республика Коми, Усинск, Нефтяников, 44А	f	large
8433	43161	246	республика Коми, Усинск, Молодежная, 10	f	large
8432	43160	245	республика Коми, Усинск, Молодежная, 16/1	f	large
8431	43159	244	республика Коми, Усинск, Молодежная, 30	f	large
8430	43158	243	республика Коми, Усинск, Молодежная, 31	f	large
8427	43156	240	республика Коми, Усинск, Комсомольская, 5А	f	large
8426	43155	239	республика Коми, Усинск, Комсомольская, 28	f	large
8428	43155	241	республика Коми, Усинск, Комсомольская, 28	f	large
8441	43168	254	республика Коми, Усинск, Возейская, 9	f	large
8442	43167	255	республика Коми, Усинск, Возейская, 9А	f	large
8440	43167	253	республика Коми, Усинск, Возейская, 9А	f	large
8438	43165	251	республика Коми, Усинск, 60 лет Октября, 3А	f	large
8429	43157	242	республика Коми, Усинск, 60 лет Октября, 2А	f	large
8192	42965	5	республика Коми, Сыктывкар, дом культуры	f	small
8201	42971	14	Россия, республика Коми, Сыктывкар, улица Школьная, 16	f	large
8200	42971	13	Россия, республика Коми, Сыктывкар, улица Школьная, 16	f	large
8205	42973	18	Россия, республика Коми, Сыктывкар, улица Советская, 59	f	large
8203	42973	16	Россия, республика Коми, Сыктывкар, улица Советская, 59	f	large
8216	42980	29	Россия, республика Коми, Сыктывкар, улица Морозова, 118	f	large
8215	42980	28	Россия, республика Коми, Сыктывкар, улица Морозова, 118	f	large
8242	42996	55	Россия, республика Коми, Сыктывкар, улица Красных Партизан, 68	f	large
8241	42996	54	Россия, республика Коми, Сыктывкар, улица Красных Партизан, 68	f	large
8240	42996	53	Россия, республика Коми, Сыктывкар, улица Красных Партизан, 68	f	large
8235	42992	48	Россия, республика Коми, Сыктывкар, улица Коммунистическая, 25	f	large
8227	42986	40	Россия, республика Коми, Сыктывкар, улица Катаева, 14	f	large
8226	42986	39	Россия, республика Коми, Сыктывкар, улица Катаева, 14	f	large
8238	42994	51	республика Коми, Сыктывкар, Юхнина, 22	f	large
8289	43026	102	республика Коми, Сыктывкар, Юности, 4/1	f	large
8288	43026	101	республика Коми, Сыктывкар, Юности, 4/1	f	large
8210	42977	23	республика Коми, Сыктывкар, Южная, 15	f	large
8277	43018	90	республика Коми, Сыктывкар, Школьный переулок, 6	f	large
8276	43018	89	республика Коми, Сыктывкар, Школьный переулок, 6	f	large
8275	43018	88	республика Коми, Сыктывкар, Школьный переулок, 6	f	large
8202	42972	15	республика Коми, Сыктывкар, Школьная, 13	f	large
8237	42993	50	республика Коми, Сыктывкар, Чернова, 12	f	large
8236	42993	49	республика Коми, Сыктывкар, Чернова, 12	f	large
8193	42966	6	республика Коми, Сыктывкар, Ухтинская, 4	f	large
8264	43011	77	республика Коми, Сыктывкар, Тентюковская, 425	f	large
8263	43009	76	республика Коми, Сыктывкар, Тентюковская, 353	f	large
8231	42989	44	республика Коми, Сыктывкар, Старовского, 53	f	large
8230	42989	43	республика Коми, Сыктывкар, Старовского, 53	f	large
8204	42974	17	республика Коми, Сыктывкар, Сплавная, 1	f	medium
8188	42961	1	республика Коми, Сыктывкар, Снежная, 41	f	large
8274	43017	87	республика Коми, Сыктывкар, Славы, 18	f	large
8273	43016	86	республика Коми, Сыктывкар, Славы, 30	f	large
8272	43016	85	республика Коми, Сыктывкар, Славы, 30	f	large
8271	43016	84	республика Коми, Сыктывкар, Славы, 30	f	large
8270	43016	83	республика Коми, Сыктывкар, Славы, 30	f	large
8224	42984	37	республика Коми, Сыктывкар, Ручейная, 27	f	large
8209	42976	22	республика Коми, Сыктывкар, Пушкина, 75	f	large
8208	42976	21	республика Коми, Сыктывкар, Пушкина, 75	f	large
8254	43005	67	республика Коми, Сыктывкар, Печорская, 30	f	large
8253	43004	66	республика Коми, Сыктывкар, Печорская, 12	f	medium
8252	43004	65	республика Коми, Сыктывкар, Печорская, 12	f	large
8262	43008	75	республика Коми, Сыктывкар, Петрозаводская, 44	f	large
8261	43008	74	республика Коми, Сыктывкар, Петрозаводская, 44	f	large
8260	43008	73	республика Коми, Сыктывкар, Петрозаводская, 44	f	large
8259	43008	72	республика Коми, Сыктывкар, Петрозаводская, 44	f	large
8243	42997	56	республика Коми, Сыктывкар, Первомайская, 32	f	large
8245	42999	58	республика Коми, Сыктывкар, Орджоникидзе, 21	f	large
8190	42963	3	республика Коми, Сыктывкар, Олега Кошевого, 1	f	medium
8234	42991	47	Россия, республика Коми, Сыктывкар, Октябрьский проспект, 24	f	large
8287	43025	100	республика Коми, Сыктывкар, Набережный проезд, 11	f	large
8286	43024	99	республика Коми, Сыктывкар, Набережный проезд, 11	f	large
8217	42981	30	республика Коми, Сыктывкар, Морозова, 114	f	large
8213	42979	26	республика Коми, Сыктывкар, Морозова, 175	f	large
8214	42979	27	республика Коми, Сыктывкар, Морозова, 175	f	large
8285	43023	98	республика Коми, Сыктывкар, Мира, 10/1	f	large
8282	43021	95	республика Коми, Сыктывкар, Мира, 14А	f	large
8281	43021	94	республика Коми, Сыктывкар, Мира, 14А	f	large
8279	43019	92	республика Коми, Сыктывкар, Мира, 42/1	f	large
8278	43019	91	республика Коми, Сыктывкар, Мира, 42/1	f	large
8212	42978	25	республика Коми, Сыктывкар, Маркова, 13	f	large
8211	42978	24	республика Коми, Сыктывкар, Маркова, 13	f	large
8258	43007	71	республика Коми, Сыктывкар, Малышева, 6	f	large
8257	43007	70	республика Коми, Сыктывкар, Малышева, 6	f	large
8256	43007	69	республика Коми, Сыктывкар, Малышева, 6	f	large
8267	43013	80	республика Коми, Сыктывкар, Магистральная, 13	f	large
8266	43013	79	республика Коми, Сыктывкар, Магистральная, 13	f	large
8249	43002	62	республика Коми, Сыктывкар, Кутузова, 11	f	large
8248	43002	61	республика Коми, Сыктывкар, Кутузова, 11	f	large
8194	42967	7	республика Коми, Сыктывкар, Корабельная, 1В	f	large
8223	42983	36	республика Коми, Сыктывкар, Коммунистическая, 74	f	large
8222	42983	35	республика Коми, Сыктывкар, Коммунистическая, 74	f	large
8221	42983	34	республика Коми, Сыктывкар, Коммунистическая, 74	f	large
8280	43020	93	республика Коми, Сыктывкар, Комарова, 9	f	large
8229	42988	42	республика Коми, Сыктывкар, Катаева, 29	f	large
8228	42987	41	республика Коми, Сыктывкар, Катаева, 9	f	large
8225	42985	38	республика Коми, Сыктывкар, Катаева, 37а	f	large
8251	43003	64	республика Коми, Сыктывкар, Карла Маркса, 145	f	large
8250	43003	63	республика Коми, Сыктывкар, Карла Маркса, 145	f	large
8244	42998	57	республика Коми, Сыктывкар, Карла Маркса, 202	f	large
8247	43001	60	республика Коми, Сыктывкар, Интернациональная, 95	f	large
8207	42975	20	республика Коми, Сыктывкар, Интернациональная, 167	f	large
8206	42975	19	республика Коми, Сыктывкар, Интернациональная, 167	f	large
8239	42995	52	республика Коми, Сыктывкар, Дырнос, 1	f	large
8233	42990	46	республика Коми, Сыктывкар, Димитрова, 8	f	large
8232	42990	45	республика Коми, Сыктывкар, Димитрова, 8	f	large
8220	42982	33	республика Коми, Сыктывкар, Димитрова, 44/1	f	large
8219	42982	32	республика Коми, Сыктывкар, Димитрова, 44/1	f	large
8218	42982	31	республика Коми, Сыктывкар, Димитрова, 44/1	f	large
8265	43012	78	республика Коми, Сыктывкар, Верхний Чов, 60	f	large
8189	42962	2	республика Коми, Сыктывкар, Большая, 6/1	f	large
8196	42968	9	республика Коми, Сыктывкар, Белинского, 15	f	large
8195	42968	8	республика Коми, Сыктывкар, Белинского, 15	f	large
8199	42970	12	республика Коми, Сыктывкар, Банбана, 21	f	large
8198	42970	11	республика Коми, Сыктывкар, Банбана, 21	f	large
8246	43000	59	республика Коми, Сыктывкар, Бабушкина, 4	f	large
8191	42964	4	республика Коми, Сыктывкар, Лесовозная, 22А	f	large
8284	43022	97	республика Коми, Сыктывкар, Космонавтов, 14	f	large
8283	43022	96	республика Коми, Сыктывкар, Космонавтов, 14	f	large
8512	43240	325	республика Коми, Сосногорск, Пионерская, 13	f	large
8503	43231	316	республика Коми, Сосногорск, Первомайская, 1А	f	large
8514	43242	327	республика Коми, Сосногорск, Орджоникидзе, 23	f	large
8506	43235	319	республика Коми, Сосногорск, Лермонтова, 12	f	large
8505	43234	318	республика Коми, Сосногорск, Лермонтова, 6	f	large
8510	43238	323	республика Коми, Сосногорск, 6 микрорайон, 18Б	f	large
8509	43237	322	республика Коми, Сосногорск, 6 микрорайон, 35	f	large
8508	43237	321	республика Коми, Сосногорск, 6 микрорайон, 35	f	medium
8507	43236	320	республика Коми, Сосногорск, 5 микрорайон, 39	f	large
8366	43096	179	республика Коми, Печора, Советская, 16а	f	large
8365	43095	178	республика Коми, Печора, Советская, 12а	f	large
8368	43098	181	республика Коми, Печора, Совесткая, 33	f	large
8392	43120	205	республика Коми, Печора, Печорский проспект, 3	f	large
8389	43117	202	республика Коми, Печора, Печорский проспект, 31а	f	large
8388	43116	201	республика Коми, Печора, Печорский проспект, 65	f	large
8385	43113	198	республика Коми, Печора, Московская, 28	f	large
8384	43113	197	республика Коми, Печора, Московская, 28	f	large
8373	43102	186	республика Коми, Печора, Ленина, 30А	f	large
8394	43121	207	республика Коми, Печора, Гагарина, 44	f	large
8390	43118	203	республика Коми, Печора, Гагарина, 17	f	large
8387	43115	200	республика Коми, Печора, Булгаковой, 11	f	large
8345	43079	158	республика Коми, Инта, Южная, 8а	f	large
8344	43079	157	республика Коми, Инта, Южная, 8а	f	large
8354	43086	167	республика Коми, Инта, Куратова, 20	f	large
8351	43083	164	республика Коми, Инта, Куратова, 32	f	large
8350	43083	163	республика Коми, Инта, Куратова, 32	f	large
8346	43080	159	республика Коми, Инта, Коммунистическая, 22	f	medium
8363	43093	176	республика Коми, Инта, Восточная, 100	t	medium
8362	43093	175	республика Коми, Инта, Восточная, 100	t	medium
8602	43327	414	республика Коми, Емва, Пионерская, 20	f	large
8417	43145	230	республика Коми, Вуктыл, Коммунистическая, 4	f	large
8421	43149	234	республика Коми, Вуктыл, Таёжная, 4	f	large
8418	43146	231	республика Коми, Вуктыл, Комсомольская, 1	f	large
8420	43148	233	республика Коми, Вуктыл, Коммунистическая, 11	f	large
8320	43055	133	республика Коми, Воркута, Яновского, 5	f	large
8318	43053	131	республика Коми, Воркута, Шахтерская набережная, 12А	f	large
8316	43051	129	республика Коми, Воркута, Чернова, 7	f	large
8321	43056	134	республика Коми, Воркута, Центральная площадь, 9	f	large
8311	43048	124	республика Коми, Воркута городской округ, Тиманская, 6А	f	large
8310	43048	123	республика Коми, Воркута городской округ, Тиманская, 6А	f	large
8309	43047	122	республика Коми, Воркута, Тиманская, 12	f	large
8305	43043	118	республика Коми, Воркута, Суворова, 25А	f	large
8328	43063	141	республика Коми, Воркута, Строительная, 13	f	large
8335	43070	148	республика Коми, Воркута, Привокзальный переулок, 2	f	large
8314	43049	127	республика Коми, Воркута, Пищевиков бульвар, 20А	f	large
8308	43046	121	республика Коми, Воркута, Пирогова, 9Б	f	large
8307	43045	120	республика Коми, Воркута, Пирогова, 1	f	large
8332	43067	145	республика Коми, Воркута, Пионерская, 30	f	large
8330	43065	143	республика Коми, Воркута, Парковая, 20А	f	large
8333	43068	146	республика Коми, Воркута, Московская, 8А	f	large
8334	43069	147	республика Коми, Воркута, Матвеева, 37А	f	large
8329	43064	142	республика Коми, Воркута, Ломоносова, 15А	f	large
8306	43044	119	республика Коми, Воркута, Лермонтова, 10	f	large
8326	43061	139	республика Коми, Воркута, Ленина, 34А	f	large
8324	43059	137	республика Коми, Воркута, Ленина, 47	f	large
8323	43058	136	республика Коми, Воркута, Ленина, 44	f	large
8322	43057	135	республика Коми, Воркута, Ленина, 46	f	large
8315	43050	128	республика Коми, Воркута, Ленина, 58	f	large
8313	42892	126	республика Коми, Воркута, Ленина, 51	f	large
8327	43062	140	республика Коми, Воркута, Коммунальная, 6	f	large
8331	43066	144	республика Коми, Воркута, Дончука, 16	f	large
8325	43060	138	республика Коми, Воркута, Дончука, 9Б	f	large
8319	43054	132	республика Коми, Воркута, Димитрова, 9	f	large
8317	43052	130	республика Коми, Воркута, Димитрова, 13	f	large
8312	43033	125	республика Коми, Воркута, Возейская, 8	f	large
8304	43042	117	республика Коми, Воркута, 3-я Линейная, 22	f	large
8582	43306	395	республика Коми, Ухтинский район, поселок Ярега, Шахтинская, 9	f	large
8584	43308	397	республика Коми, Ухтинский район, поселок Ярега, Строительная, 10	f	large
8583	43307	396	республика Коми, Ухтинский район, поселок Ярега, Советская, 31	f	large
8585	43309	398	республика Коми, Ухтинский район, поселок Ярега, Октябрьская, 45	f	large
8573	43298	386	республика Коми, Ухтинский район, поселок Шудаяг, Шахтинская, 9	f	large
8575	43300	388	республика Коми, Ухтинский район, поселок Шудаяг, Павлова, 13	f	medium
8545	43273	358	республика Коми, Ухтинский район, село Седью, Центральная, 5	f	medium
8546	43274	359	республика Коми, Ухтинский район, село Кэмдин, 44	f	medium
8577	43302	390	республика Коми, Ухтинский район, село Кедвавом, Центральная, 1	t	small
8581	43305	394	республика Коми, Ухтинский район, поселок Водный, Октябрьская, 5а	f	large
8579	43303	392	республика Коми, Ухтинский район, поселок Водный, Ленина, 16а	f	large
8578	43303	391	республика Коми, Ухтинский район, поселок Водный, Ленина, 16а	f	large
8580	43304	393	республика Коми, Ухтинский район, поселок Боровой, Советская, 5А	f	large
65917	43183	270	республика Коми, Усть-Цилемский район, дер.Чукчино, Сельхозтехника, 72	f	medium
8474	43201	287	республика Коми, Усть-Цилемский район, село Харъяга, Здание Харъяжской основной общеобразовательной школы	t	small
8469	43196	282	Россия, республика Коми, Усть-Цилемский район, село Хабариха	t	small
8465	43192	278	Россия, республика Коми, Усть-Цилемский район, село Филиппово	t	medium
65919	43185	272	республика Коми, Усть-Цилемский район, село Усть-Цильма, Советская , 134	f	large
65918	43184	271	республика Коми, Усть-Цилемский район, село Усть-Цильма, Батманова, 84	f	large
8468	43195	281	Россия, республика Коми, Усть-Цилемский район, село Уег	t	small
8466	43193	279	Россия, республика Коми, Усть-Цилемский район, село Трусово	t	medium
8462	43188	275	Россия, республика Коми, Усть-Цилемский район, село Степановская	t	small
8470	43197	283	Россия, республика Коми, Усть-Цилемский район, село Среднее Бугаево	t	small
8461	43187	274	республика Коми, Усть-Цилемский район, село Синегорье, Здание Синегорской средней общеобразовательной школы	t	small
8460	43186	273	Россия, республика Коми, Усть-Цилемский район, село Сергеево-Щелья	t	small
8467	43194	280	Россия, республика Коми, Усть-Цилемский район, село Рочево	t	small
8471	43198	284	Россия, республика Коми, Усть-Цилемский район, село Окунев Нос	t	medium
8473	43200	286	республика Коми, Усть-Цилемский район, село Новый Бор	t	medium
8455	43181	268	Россия, республика Коми, Усть-Цилемский район, село Нерица	t	small
8472	43199	285	республика Коми, Усть-Цилемский район, село Медвежка, Здание Межвежской начальной школы-детского сада	t	small
65916	43182	269	республика Коми, Усть-Цилемский район, село Коровий Ручей, Школьная, 2	f	medium
8463	43189	276	Россия, республика Коми, Усть-Цилемский район, село Замежная	t	medium
8464	43190	277	Россия, республика Коми, Усть-Цилемский район, село Загривочная	t	small
8475	43202	288	Россия, республика Коми, Усть-Цилемский район, село Ермица	t	small
8711	43439	522	республика Коми, Усть-Куломский район, село Ярашъю, Центральная, 12	t	medium
65938	43447	528	республика Коми, Усть-Куломский район, село Ягкедж, Парковая, 3А	t	small
8699	43425	511	республика Коми, Усть-Куломский район, поселок Югыдъяг, Комсомольская, 40	t	large
8704	43430	515	республика Коми, Усть-Куломский район, село Шэръяг, Центральная, 10	f	small
8702	43427	513	республика Коми, Усть-Куломский район, село Усть-Нем, Совхозная, 15В	f	medium
8692	43419	505	республика Коми, Усть-Куломский район, село Усть-Кулом, Советская, 35	f	large
8691	43418	504	республика Коми, Усть-Куломский район, село Усть-Кулом, Ленина, 5	f	large
65936	43436	519	республика Коми, Усть-Куломский район, село Тимшер, Советская, 3	t	medium
8701	43426	512	республика Коми, Усть-Куломский район, село Смолянка, Школьная, 2	t	medium
8712	43440	523	республика Коми, Усть-Куломский район, село Скородум, 124	f	medium
8683	43410	496	республика Коми, Усть-Куломский район, село Руч, Центральная, 213	f	medium
8718	43449	529	республика Коми, Усть-Куломский район, село Пузла, Г.Тимушева, 3А	t	small
8714	43442	525	республика Коми, Усть-Куломский район, село Помоздино, В.Т.Чисталева, 1	f	large
8710	43438	521	республика Коми, Усть-Куломский район, село Пожегдин, Центральная, 49	t	small
8709	43437	520	республика Коми, Усть-Куломский район, село Пожег, Школьная, 21	t	medium
8690	43417	503	республика Коми, Усть-Куломский район, село Паспом, Школьная, 14	f	small
65934	43429	514	республика Коми, Усть-Куломский район, село Парч, Сельская, 40	f	small
8687	43414	500	республика Коми, Усть-Куломский район, село Озъяг, Школьная, 9А	f	small
8689	43416	502	республика Коми, Усть-Куломский район, село Носим, Совхозная, 26	f	small
8696	43423	509	республика Коми, Усть-Куломский район, село Нижний Воч, Центральная, 191	t	small
65935	43432	517	республика Коми, Усть-Куломский район, село Мыелдино, Центральная, 89, Здание дома культуры	t	small
8707	43434	518	республика Коми, Усть-Куломский район, село Лопъювад, Комсомольская, 4	t	small
8694	43421	507	республика Коми, Усть-Куломский район, Логинъяг, Центральная, 6	t	small
8686	43413	499	республика Коми, Усть-Куломский район, село Кужба, Центральная, 44А	f	small
65933	43420	506	республика Коми, Усть-Куломский район, село Керчомъя, Центральная, 22	f	medium
8688	43415	501	республика Коми, Усть-Куломский район, село Кебаньель, Гагарина, 1А	f	large
8695	43422	508	республика Коми, Усть-Куломский район, село Зимстан, Интернациональная, 1	t	large
8705	43431	516	республика Коми, Усть-Куломский район, село Дон, Центральная, 73	f	small
8715	43443	526	республика Коми, Усть-Куломский район, село Диасеръя, Школьный переулок, 1	t	small
8698	43424	510	республика Коми, Усть-Куломский район, село Дзель, Центральная, 88	t	small
134651	94978	497	республика Коми, Усть-Куломский район, село Деревянск, Центральная, 246 А	f	small
8685	43412	498	республика Коми, Усть-Куломский район, село Деревянск, Подгорная, 12	f	small
65937	43444	527	республика Коми, Усть-Куломский район, село Вольдино, Центральная, 49В	f	small
8713	43441	524	республика Коми, Усть-Куломский район, село Бадъельск, 111А	t	small
8682	43409	495	республика Коми, Усть-Куломский район, село Аныб, Центральная, 184	t	small
8642	43368	455	республика Коми, Усть-Вымский район, село Яг, Молодежная, 17	f	small
8647	43373	460	республика Коми, Усть-Вымский район, село Черный Яр, 11	f	small
8648	43374	461	республика Коми, Усть-Вымский район, село Усть-Вымь, Центральная, 64	f	medium
8652	43378	465	республика Коми, Усть-Вымский район, село Туискерес, Школьная, 91	f	small
8649	43375	462	республика Коми, Усть-Вымский район, село Студенец, Клубная, 2	f	medium
8654	43380	467	республика Коми, Усть-Вымский район, село Семуково, Береговая, 45	f	small
8656	43382	469	республика Коми, Усть-Вымский район, Микунь, Пионерская, 31	f	large
8655	43381	468	республика Коми, Усть-Вымский район, Микунь, Комсомольская, 6	f	large
8657	43383	470	республика Коми, Усть-Вымский район, Микунь, Гоголя, 19	f	large
8635	43361	448	республика Коми, Усть-Вымский район, село Мадмас, Школьная, 32	t	medium
8653	43379	466	республика Коми, Усть-Вымский район, село Лыаты, 53	f	small
8650	43376	463	республика Коми, Усть-Вымский район, село Коквицы, 70	f	small
8651	43377	464	республика Коми, Усть-Вымский район, село Кожмудор, Центральная, 42	f	small
8637	43363	450	республика Коми, Усть-Вымский район, село Казлук, Центральная, 10А	f	medium
8645	43371	458	республика Коми, Усть-Вымский район, село Илья-Шор, Центральная, 31	f	small
8639	43365	452	республика Коми, Усть-Вымский район, поселок Жешарт, Свердлова, 13	f	large
8638	43364	451	республика Коми, Усть-Вымский район, поселок Жешарт, Первомайская, 23	f	large
8641	43367	454	республика Коми, Усть-Вымский район, поселок Жешарт, Мира, 2	f	large
8640	43366	453	республика Коми, Усть-Вымский район, поселок Жешарт, Мира, 7	f	large
8636	43362	449	республика Коми, Усть-Вымский район, село Донаелв, Северная, 1	t	small
8644	43370	457	республика Коми, Усть-Вымский район, село Вездино, Центральная, 25	t	small
65928	43384	471	республика Коми, Усть-Вымский район, село Вежайка, Станционная, 5	f	small
8643	43369	456	республика Коми, Усть-Вымский район, село Арабач, пер.Клубный, 26А	f	small
8646	43372	459	республика Коми, Усть-Вымский район, село Айкино, Центральная, 131	f	large
8451	43177	264	республика Коми, Усинский район, село Щельябож, Центральная, 36	t	small
8447	43173	260	республика Коми, Усинский район, село Усть-Уса, Советская, 36	f	medium
8449	43175	262	республика Коми, Усинский район, село Усть-Лыжа, Центральная, 16	t	small
8444	43170	257	республика Коми, Усинский район, поселок Парма, Школьная, 13А	f	large
8448	43174	261	республика Коми, Усинский район, село Новикбож, Школьная, 7	f	small
8453	43179	266	республика Коми, Усинский район, село Мутный Материк, Центральная, 56	t	medium
8446	43172	259	республика Коми, Усинский район, село Колва, Центральная, 35	f	small
8452	43178	265	республика Коми, Усинский район, село Захарвань, Школьный переулок, 1	t	small
8450	43176	263	республика Коми, Усинский район, село Акись, здание дома культуры	t	small
8612	43338	425	республика Коми, Удорский район, село Ыджыдъяг, Лесная, 7	t	small
8623	43349	436	республика Коми, Удорский район, село Чупрово, 152	t	small
65924	43343	430	республика Коми, Удорский район, село Чим, Школьный переулок, 10	f	small
8614	43340	427	республика Коми, Удорский район, село Чернутьево, 64	t	small
8626	43352	439	республика Коми, Удорский район, поселок Усогорск, Привокзальная, 9	f	small
8625	43351	438	республика Коми, Удорский район, поселок Усогорск, Ленина, 18	f	large
8624	43350	437	республика Коми, Удорский район, поселок Усогорск, Дружбы, 17	f	large
8629	43355	442	республика Коми, Удорский район, село Солнечный, Таежная, 7	f	small
65926	43357	444	республика Коми, Удорский район, село Селэгвож, Привокзальная, 16	f	small
8613	43339	426	республика Коми, Удорский район, село Сельыб, 84	t	small
8627	43353	440	республика Коми, Удорский район, село Разгорт	f	small
8622	43348	435	республика Коми, Удорский район, село Муфтюга, 106	t	small
8633	43359	446	республика Коми, Удорский район, село Мозындор, Ленина, 14	f	small
65925	43356	443	республика Коми, Удорский район, поселок Междуреченск, 5Интернациональная, 5	f	large
8616	43342	429	республика Коми, Удорский район, село Малая Пысса, 40	t	small
8619	43345	432	республика Коми, Удорский район, село Кривое, 12	t	small
8611	43336	424	республика Коми, Удорский район, село Кослан, Центральная, 140А	f	large
8618	43344	431	республика Коми, Удорский район, село Ертом, 45/1	t	small
65927	43358	445	республика Коми, Удорский район, село Едва, Комсомольская, 1	f	medium
8609	43334	422	республика Коми, Удорский район, село Глотово, 48	t	small
8634	43360	447	республика Коми, Удорский район, село Волжский, Административный переулок, 1	f	small
8620	43346	433	республика Коми, Удорский район, село Важгорт, 211	t	small
8610	43335	423	республика Коми, Удорский район, село Буткан, 133	t	small
8615	43341	428	республика Коми, Удорский район, село Большая Пысса, Центральная, 19/1	t	small
8621	43347	434	республика Коми, Удорский район, село Большая Пучкома, 129	t	small
134701	95162	441	республика Коми, Удорский район, поселок Благоево, Дружбы, 8	f	large
8660	43386	473	республика Коми, Троицко-Печорский район, село Якша, Школьная, 25	t	medium
8666	43393	479	республика Коми, Троицко-Печорский район, село Усть-Илыч, Центральная, 82	t	small
8670	43397	483	Россия, республика Коми, Троицко-Печорский район, поселок Троицко-Печорск	f	medium
8674	43401	487	республика Коми, Троицко-Печорский район, поселок Троицко-Печорск, кв.южный, 13	f	large
65932	43402	488	республика Коми, Троицко-Печорский район, поселок Троицко-Печорск, кв.Южный, 13	f	small
8672	43399	485	республика Коми, Троицко-Печорский район, поселок Троицко-Печорск, Портовая, 4	f	large
8680	43407	493	республика Коми, Троицко-Печорский район, село Тимушбор, Лесная, 13	t	small
8679	43406	492	республика Коми, Троицко-Печорский район, село Русаново, Школьная, 16	t	small
8664	43390	477	республика Коми, Троицко-Печорский район, село Приуральский, Лесная, 4	t	small
8678	43405	491	республика Коми, Троицко-Печорский район, село Покча, Центральная, 13	f	small
8665	43391	478	республика Коми, Троицко-Печорский район, село Палью, Школьная, 1	t	small
8676	43403	489	республика Коми, Троицко-Печорский район, поселок Нижняя Омра, Советская, 6а	f	medium
8681	43408	494	республика Коми, Троицко-Печорский район, село Митрофан-Дикост	t	small
8659	43385	472	республика Коми, Троицко-Печорский район, село Курья, Школьная, 21	t	small
8661	43387	474	республика Коми, Троицко-Печорский район, село Комсомольск-на-Печоре, Комсомольская, 12	t	medium
8662	43388	475	республика Коми, Троицко-Печорский район, село Знаменка, Сплавная, 15	t	small
8663	43389	476	республика Коми, Троицко-Печорский район, село Еремеево, Попова, 53	t	small
8511	43239	324	республика Коми, Сосногорский район, Сосногорск, Куратова, 4	f	large
8667	43394	480	республика Коми, Троицко-Печорский район, село Белый Бор, Комсомольская, 17	f	small
8677	43404	490	республика Коми, Троицко-Печорский район, село Бадъель, улица Почтовая, 8	f	small
8671	43398	484	республика Коми, Троицко-Печорский, поселок Троицко-Печорск, Ленина, 17	f	large
8788	43519	600	республика Коми, Сысольский район, село Шугрэм, Центральная, 1а	t	small
8775	43507	588	республика Коми, Сысольский район, село Шорсай, 28	f	medium
8773	43505	586	республика Коми, Сысольский район, село Чухлэм, местечко Чоййыв, 31	f	small
8789	43520	601	республика Коми, Сысольский район, село Пыелдино, 16	f	small
8777	43509	590	республика Коми, Сысольский район, село Первомайский, Центральная, 11а	f	medium
8795	43526	607	республика Коми, Сысольский район, село Палауз, Большая, 48	t	small
8785	43516	597	республика Коми, Сысольский район, село Куратово, 57	f	medium
8778	43510	591	республика Коми, Сысольский район, село Куниб, 34	f	small
8792	43523	604	республика Коми, Сысольский район, село Исанево, Центральная, 5	t	small
8786	43517	598	республика Коми, Сысольский район, село Заречное, 60а	f	small
8791	43522	603	республика Коми, Сысольский район, село Заозерье, Центральная, 25	t	medium
8774	43506	587	республика Коми, Сысольский район, село Ельбаза, Новосельская, 7	t	small
8454	43180	267	республика Коми, Сысольский район, село Денисовка, Центральная, 12	t	small
8794	43525	606	республика Коми, Сысольский район, село Гагшор, 92	f	small
8776	43508	589	республика Коми, Сысольский район, село Вотча, 2а	t	small
8787	43518	599	республика Коми, Сысольский район, село Визиндор, Комсомольская, 3а	f	small
8782	43513	594	республика Коми, Сысольский район, село Визинга, 114	f	small
8783	43514	595	республика Коми, Сысольский район, село Визинга, Советская, 17	f	large
8781	43512	593	республика Коми, Сысольский район, село Визинга, Советская, 17	f	large
8780	43511	592	республика Коми, Сысольский район, село Визинга, Советская, 37а	f	large
8784	43515	596	республика Коми, Сысольский район, село Визинга, Оплеснина, 47	f	large
8790	43521	602	республика Коми, Сысольский район, село Бортом, 20	f	small
8793	43524	605	республика Коми, Сысольский район, село Бортом, Центральная, 28	t	small
8750	43483	563	республика Коми, Сыктывдинский район, село Яснэг, Ленина, 13	t	medium
65944	43497	578	республика Коми, Сыктывдинский район, село Язель, 8, железнодорожная станция Язель	f	small
8752	43485	565	республика Коми, Сыктывдинский район, село Ыб, м.Погост, 133	f	medium
65942	43490	570	республика Коми, Сыктывдинский район, село Шошка, Педегрезд, 11	f	small
8766	43498	579	республика Коми, Сыктывдинский район, село Часово, Береговая, 18Б	f	medium
8770	43502	583	республика Коми, Сыктывдинский район, село Слудка, Новоселов, 8	f	medium
65943	43496	577	республика Коми, Сыктывдинский район, село Парчег, Боровая, 17	f	small
8769	43501	582	республика Коми, Сыктывдинский район, село Палевицы, Набережная, 9	f	medium
65941	43487	567	республика Коми, Сыктывдинский район, село Пажга, 1 микрорайон, 22	f	large
65940	43482	562	республика Коми, Сыктывдинский район, село Озел, Озёльская, 55А	t	small
8756	43489	569	республика Коми, Сыктывдинский район, поселок Нювчим, Первомайская, 8	f	small
8771	43503	584	республика Коми, Сыктывдинский район, село Мандач, Лесная, 44	t	small
8767	43499	580	республика Коми, Сыктывдинский район, село Красная, 69	t	small
8768	43500	581	республика Коми, Сыктывдинский район, село Ивановка, Северная, 20	f	small
8763	43495	576	республика Коми, Сыктывдинский район, село Зеленец, 2 квартал, 17А	f	large
8751	43484	564	республика Коми, Сыктывдинский район, село Захарово, 49	t	small
8753	43486	566	Россия, республика Коми, Сыктывдинский район, село Гарьинский	f	medium
8759	43491	572	республика Коми, Сыктывдинский район, село Выльгорт, Тимирязева, 36	f	large
8758	43476	571	республика Коми, Сыктывдинский район, село Выльгорт, Северная, 22	f	medium
8762	43494	575	республика Коми, Сыктывдинский район, село Выльгорт, Домны Каликовой, 60	f	medium
8761	43493	574	республика Коми, Сыктывдинский район, село Выльгорт, Домны Каликовой, 57	f	large
8501	43229	314	республика Коми, Сосногорский район, село Усть-Ухта, Лесная, 8А	f	medium
65920	43241	326	республика Коми, Сосногорский район, Сосногорск, Спортивная, 6	f	large
8502	43230	315	республика Коми, Сосногорский район, село Порожок, Дом фольклорного творчества	t	small
8523	43251	336	республика Коми, Сосногорский район, село Поляна, Мира, 12	f	medium
8519	43247	332	республика Коми, Сосногорский район, поселок Нижний Одес, площадь Ленина, 3	f	large
8518	43246	331	республика Коми, Сосногорский район, поселок Нижний Одес, Северная, 4А	f	large
8516	43244	329	республика Коми, Сосногорский район, поселок Нижний Одес, Северная, 8	f	large
8515	43243	328	республика Коми, Сосногорский район, поселок Нижний Одес, Пионерская, 3А	f	large
8517	43245	330	республика Коми, Сосногорский район, поселок Нижний Одес, Ленина, 1А	f	large
8527	43255	340	республика Коми, Сосногорский район, село Малая Пера, Советская, 10	f	large
8525	43253	338	республика Коми, Сосногорский район, село Керки, Лесная, 16А	f	medium
8528	43256	341	республика Коми, Сосногорский район, село Ирасль, 40 лет Победы, 5	t	medium
8521	43249	334	республика Коми, Сосногорский район, поселок Войвож, Октябрьская, 23	f	medium
8522	43250	335	республика Коми, Сосногорский район, поселок Войвож, Кирова, 2А	f	large
65921	43254	339	республика Коми, Сосногорский район, село Вис, Ленина, 14	f	medium
8520	43248	333	республика Коми, Сосногорский район, село Верхнеижемский, Садовая, 107	t	medium
8524	43252	337	республика Коми, Сосногорск городской округ, дер.Пожня, Дом культуры	t	small
8504	43233	317	республика Коми, Сосногорск городской округ, Сосногорск, Гоголя, 7	f	large
8850	43583	663	республика Коми, Прилузский район, село Якуньель, Первомайская, 9	t	small
8818	43552	631	республика Коми, Прилузский район, село Читаево, Центральная, 22	t	small
8830	43563	643	республика Коми, Прилузский район, село Черныш, Центральная, 59	t	small
8844	43577	657	республика Коми, Прилузский район, село Черемуховка, Центральная, 74	f	small
8843	43576	656	республика Коми, Прилузский район, село Черемуховка, Октябрьская, 22	f	medium
8832	43565	645	республика Коми, Прилузский район, село Чекша, Центральная, 13	f	small
8829	43562	642	республика Коми, Прилузский район, село Усть-Лопью, Центральная, 26	f	small
8816	43550	629	республика Коми, Прилузский район, село Спаспоруб, Лобанова, 2	f	medium
8851	43584	664	республика Коми, Прилузский район, село Слудка, Центральная, 2	t	small
8852	43585	665	республика Коми, Прилузский район, село Прокопьевка, Центральная, 17	f	small
8815	43549	628	республика Коми, Прилузский район, село Поруб-Кеповская, 19	t	small
8845	43578	658	республика Коми, Прилузский район, село Пожемаяг, Центральная, 7	t	small
8831	43564	644	республика Коми, Прилузский район, село Орысь, Центральная, 14	t	small
8838	43571	651	республика Коми, Прилузский район, село Оньмесь, Лесная, 2	t	small
8825	43543	638	республика Коми, Прилузский район, село Объячево, Центральная, 9	f	large
8826	43559	639	республика Коми, Прилузский район, село Объячево, Мира, 69	f	large
8823	43557	636	республика Коми, Прилузский район, село Объячево, Мира, 132	f	medium
8824	43530	637	республика Коми, Прилузский район, село Объячево, Мира, 81	f	large
8834	43567	647	республика Коми, Прилузский район, село Ношуль, Советская, 29	f	medium
8833	43566	646	республика Коми, Прилузский район, село Ношуль, Калинина, 10	f	small
8847	43580	660	республика Коми, Прилузский район, село Мутница, Дуговая, 18	f	small
8813	43547	626	республика Коми, Прилузский район, село Лойма, Центральная, 20	f	small
8835	43568	648	республика Коми, Прилузский район, село Лихачевская, Школьная, 6	t	small
8842	43575	655	республика Коми, Прилузский район, село Летка, Советская, 61	f	large
8841	43574	654	республика Коми, Прилузский район, село Летка, Советская, 62	f	large
8819	43553	632	республика Коми, Прилузский район, село Кыддзявидзь, Гагарина, 12	t	small
8828	43561	641	республика Коми, Прилузский район, село Коржинский, Лесная, 15	t	small
8811	43545	624	республика Коми, Прилузский район, село Коржинский, Лесная, 15	t	small
8812	43546	625	республика Коми, Прилузский район, село Козловская, 21	f	small
8822	43556	635	республика Коми, Прилузский район, село Калининская, 55	t	small
8817	43551	630	республика Коми, Прилузский район, село Занулье, Центральная, 29	t	small
8846	43579	659	республика Коми, Прилузский район, село Гыркашор, Мира, 4	t	small
8849	43582	662	республика Коми, Прилузский район, село Гурьевка, Школьная, 9	f	medium
8840	43573	653	республика Коми, Прилузский район, село Гостиногорка, 16а	f	small
8814	43548	627	республика Коми, Прилузский район, село Галахтионовская, 22	t	small
8820	43554	633	республика Коми, Прилузский район, село Вухтым, Центральная, 22	f	small
8821	43555	634	республика Коми, Прилузский район, село Вухтым, Спортивная, 2	f	small
8839	43572	652	республика Коми, Прилузский район, село Верхолузье, Центральная, 21	t	small
8837	43570	650	республика Коми, Прилузский район, село Велодоръя, Молодежная, 1а	t	small
8836	43569	649	республика Коми, Прилузский район, село Ваймес, Школьная, 6	t	small
8827	43560	640	республика Коми, Прилузский район, село Беляевская, 51	f	small
8848	43581	661	республика Коми, Прилузский район, село Архиповка, Школьная, 5	f	small
8406	43133	219	республика Коми, Печорский район, пос.Новая Березовка, Лесная, 34, кв.1	t	small
8407	43134	220	республика Коми, Печорский район, село Чикшино, Центральная, 2	f	medium
8403	43130	216	республика Коми, Печорский район, село Усть-Кожва, Речная, 12	t	small
8410	43137	223	республика Коми, Печорский район, село Талый, Центральная, 1	t	small
8371	43101	184	республика Коми, Печорский район, поселок Сыня, Восточная, 5	f	small
8404	43131	217	республика Коми, Печорский район, село Соколово, Центральная, 23	t	small
8412	43140	225	республика Коми, Печорский район, село Рыбница, Лесная, 17	t	small
8397	43124	210	республика Коми, Печорский район, поселок Путеец, Парковая, 2а	f	medium
8409	43136	222	республика Коми, Печорский район, село Причал, Набережная, 3	t	small
8381	43110	194	республика Коми, Печорский район, село Приуральское, Школьная, 15	t	small
8374	43103	187	республика Коми, Печорский район, Печора, Советская, 47	f	large
8396	43123	209	республика Коми, Печорский район, Печора, Печорский проспект, 47	f	large
8393	43114	206	республика Коми, Печорский район, Печора, Печорский проспект, 75	f	large
8386	43114	199	республика Коми, Печорский район, Печора, Печорский проспект, 75	f	large
8411	43139	224	республика Коми, Печорский район, Печора, Набережная, 2а	t	small
8391	43119	204	республика Коми, Печорский район, Печора, Ленинградская, 10	f	large
8372	43097	185	республика Коми, Печорский район, Печора, Комсомольская, 27	f	large
8367	43097	180	республика Коми, Печорский район, Печора, Комсомольская, 27	f	large
8369	43099	182	республика Коми, Печорский район, Печора, Деповская, 19	f	medium
8380	43109	193	республика Коми, Печорский район, село Озерный, Центральная, 31	f	medium
8402	43129	215	республика Коми, Печорский район, село Набережный, Школьная, 44	f	small
8377	43106	190	республика Коми, Печорский район, село Медвежская, Молодежная, 27	t	small
8398	43125	211	республика Коми, Печорский район, село Луговой, Русанова, 1	f	small
8378	43107	191	республика Коми, Печорский район, село Красный Яг, Свободы, 7	t	small
8370	43100	183	республика Коми, Печорский район, поселок Косью, Лесная, 6, кв.5	f	small
8376	43105	189	республика Коми, Печорский район, село Конецбор, Почтовая, 29	t	small
8400	43127	213	республика Коми, Печорский район, поселок Кожва, Мира, 14	f	large
8375	43104	188	республика Коми, Печорский район, село Кедровый Шор, Речная, 15	t	small
8408	43135	221	республика Коми, Печорский район, поселок Каджером, Театральная, 23	f	large
8401	43128	214	республика Коми, Печорский район, поселок Изъяю, Центральная, 7	f	large
8413	43141	226	республика Коми, Печорский район, село Зеленоборск, Рабочая, 7	t	small
8383	43112	196	республика Коми, Печорский район, село Даниловка, Центральная, 46	t	small
8379	43108	192	республика Коми, Печорский район, село Бызовая, Совхозная, 12	t	small
8405	43132	218	республика Коми, Печорский район, поселок Березовка, Таежная, 2	t	small
8399	43126	212	республика Коми, Печорский район, село Белый-Ю, Лесная, 3, кв.17	t	small
8382	43111	195	республика Коми, Печорский район, село Аранец, Центральная, 39	t	small
8395	43122	208	республика Коми, Печора городской округ, Печора, Спортивная, 42	f	large
8724	43455	536	республика Коми, Корткеросский район, село Усть-Лэкчим, Школьная, 1А	f	medium
65913	43472	553	республика Коми, Корткеросский район, село Уръель, Центральная, 12	f	\N
65939	43478	558	республика Коми, Корткеросский район, село Троицк, 119	t	small
8747	43479	559	республика Коми, Корткеросский район, село Сюзяыб, 30а	f	small
8737	43468	549	республика Коми, Корткеросский район, село Сторожевск, Дружбы, 27	f	large
8734	43465	546	республика Коми, Корткеросский район, село Приозерный, Центральная, 6	f	medium
8722	43454	535	республика Коми, Корткеросский район, село Позтыкерес, Светлая, 20	t	small
8740	43470	551	республика Коми, Корткеросский район, село Подъельск, Восточная, 11	f	medium
8742	43474	555	республика Коми, Корткеросский район, село Подтыбок, Центральная, 9	f	large
8733	43464	545	республика Коми, Корткеросский район, село Пезмег, Братьев Покровских, 53	f	small
8748	43480	560	республика Коми, Корткеросский район, село Нившера, 729	t	large
8736	43467	548	республика Коми, Корткеросский район, село Небдино, Центральная, 90	f	small
8719	43451	532	республика Коми, Корткеросский район, село Намск, Школьная, 19А	f	medium
134652	43452	533	республика Коми, Корткеросский район, село Мордино, Пушкина, 7	f	large
8731	43462	543	республика Коми, Корткеросский район, село Маджа, Центральная, 5А	f	small
8727	43458	539	республика Коми, Корткеросский район, село Корткерос, Советская, 213	f	medium
8725	43456	537	республика Коми, Корткеросский район, село Корткерос, Советская, 187	f	medium
8726	43457	538	республика Коми, Корткеросский район, село Корткерос, Набережная, 2	f	large
8728	43459	540	республика Коми, Корткеросский район, село Корткерос, Дорожная, 11	f	small
8741	43471	552	республика Коми, Корткеросский район, село Керес, Центральная, 40	t	medium
8729	43460	541	республика Коми, Корткеросский район, село Додзь, Центральная, 90	f	small
8744	43475	556	республика Коми, Корткеросский район, село Выльыб, 66	f	small
8739	43469	550	республика Коми, Корткеросский район, село Вомын, 125	f	medium
8730	43461	542	республика Коми, Корткеросский район, село Визябож, Школьная, 1	f	medium
8721	43453	534	республика Коми, Корткеросский район, село Веселовка, Советская, 10	f	small
8735	43466	547	республика Коми, Корткеросский район, село Важкуръя, 74/1	f	small
8743	43473	554	республика Коми, Корткеросский район, село Большелуг, Центральная, 13	f	medium
8746	43477	557	республика Коми, Корткеросский район, село Богородск, Школьная, 59	f	small
8732	43463	544	республика Коми, Корткеросский район, село Аджером, Школьная, 1	f	medium
8800	43533	613	республика Коми, Койгородский район, село Ужга, Ягдорская, 9	f	small
8801	43534	614	республика Коми, Койгородский район, село Седтыдор, Центральная, 34	f	small
8797	43528	610	республика Коми, Койгородский район, село Подзь, Советская, 15	f	medium
8803	43536	616	республика Коми, Койгородский район, село Нючпас, Центральная, 20	t	small
8810	43544	623	республика Коми, Койгородский район, село Нижний Турунъю, Заречная, 1	t	small
8807	43540	620	республика Коми, Койгородский район, село Кузьель, Смоленская, 15	t	small
8808	43541	621	республика Коми, Койгородский район, село Ком, Центральная, 9	t	small
8806	43539	619	республика Коми, Койгородский район, село Койдин, Центральная, 12	f	large
8804	43537	617	республика Коми, Койгородский район, село Койгородок, Советская, 44А	f	large
8805	43538	618	республика Коми, Койгородский район, село Койгородок, Интернациональная, 55	f	small
8809	43542	622	республика Коми, Койгородский район, поселок Кажим, Набережная, 1	f	medium
8796	43527	609	республика Коми, Койгородский район, село Иван-Чомья, Центральная, 17	t	small
8798	43529	611	республика Коми, Койгородский район, село Зимовка, Ленина, 8А	t	small
8799	43531	612	республика Коми, Койгородский район, село Грива, Советская, 23	f	small
8802	43535	615	республика Коми, Койгородский район, село Вежъю, Пушкина, 14	t	small
8590	43314	403	республика Коми, Княжпогостский район, село Шошка, Центральная, 26	f	small
8586	43310	399	республика Коми, Княжпогостский район, село Чиньяворык, Дзержинского, 4	f	large
65922	43319	408	республика Коми, Княжпогостский район, село Чернореченский, Клубный переулок, 10, СОШ	f	small
8589	43313	402	республика Коми, Княжпогостский район, село Туръя, 81	t	small
8597	43321	409	республика Коми, Княжпогостский район, село Тракт, Лесная, 20	f	medium
8594	43318	407	республика Коми, Княжпогостский район, поселок Синдор, Строителей, 15	f	large
8607	43332	419	республика Коми, Княжпогостский район, село Серегово, Советская, 30	f	medium
8593	43317	406	Россия, республика Коми, Княжпогостский район, село Ропча	f	medium
65923	43323	410	республика Коми, Княжпогостский район, село Ракпас, Дзержинского, 11	f	small
8587	43311	400	республика Коми, Княжпогостский район, село Мещура, Пионерская, 3	t	small
8608	43333	420	республика Коми, Княжпогостский район, село Ляли, Центральная, 10	f	small
8591	43315	404	республика Коми, Княжпогостский район, село Княжпогост, Центральная, 42	f	small
8592	43316	405	республика Коми, Княжпогостский район, село Иоссер, Центральная, 10	f	small
8599	43324	411	республика Коми, Княжпогостский район, Емва, Чапаева, 1	f	large
8605	43330	417	республика Коми, Княжпогостский район, Емва, Московская, 10	f	large
8601	43326	413	республика Коми, Княжпогостский район, Емва, Коммунистическая, 9	f	large
8603	43328	415	республика Коми, Княжпогостский район, Емва, Дзержинского, 100	f	large
8600	43325	412	республика Коми, Княжпогостский район, Емва, Дзержинского, 72	f	large
8604	43329	416	республика Коми, Княжпогостский район, Емва, Волгоградская, 2а	f	medium
8606	43331	418	республика Коми, Княжпогостский район, Емва, 60 лет Октября, 57	f	large
8588	43312	401	республика Коми, Княжпогостский район, село Ветью, Школьная, 6	t	small
8361	43092	174	республика Коми, Интинский район, село Юсьтыдор, 18	t	medium
8342	43077	155	республика Коми, Интинский район, село Петрунь, Центральная, 38	t	small
8341	43076	154	республика Коми, Интинский район, село Косьювом, 70	t	small
8339	43074	152	Россия, республика Коми, Интинский район, Инта	t	large
8359	43090	172	республика Коми, Интинский район, Инта, Мира, 2	f	large
8358	43089	171	республика Коми, Интинский район, Инта, Мира, 16	f	large
8356	43088	169	республика Коми, Интинский район, Инта, Мира, 14	f	large
8349	43082	162	республика Коми, Интинский район, Инта, Мира, 51	f	large
8348	43082	161	республика Коми, Интинский район, Инта, Мира, 51	f	large
8353	43085	166	республика Коми, Интинский район, Инта, Куратова, 19	f	large
8347	43081	160	республика Коми, Интинский район, Инта, Куратова, 66	f	large
8360	43091	173	республика Коми, Интинский район, Инта, Кирова, 14	f	large
8357	43087	170	республика Коми, Интинский район, Инта, Горького, 8	f	large
8355	43087	168	республика Коми, Интинский район, Инта, Горького, 8	f	large
8352	43084	165	республика Коми, Интинский район, Инта, Горького, 16	f	large
8343	43078	156	республика Коми, Интинский район, поселок Верхняя Инта, Советской армии, 2	t	large
8340	43075	153	республика Коми, Интинский район, село Адзьвавом, 55	t	small
8487	43215	300	республика Коми, Ижемский район, село Ыргеншар, Центральная, 19	f	small
8495	43223	308	Россия, республика Коми, Ижемский район, поселок Щельяюр	t	large
8499	43227	312	Россия, республика Коми, Ижемский район, село Чика	t	small
8494	43222	307	республика Коми, Ижемский район, село Усть-Ижма, Центральная, 100	f	small
8478	43206	291	республика Коми, Ижемский район, село Том, Речная, 84	t	medium
8483	43211	296	республика Коми, Ижемский район, село Сизябск, 60 лет Октября, 18	t	medium
8496	43224	309	республика Коми, Ижемский район, село Пиль-Егор, Центральная, 24	t	small
8497	43225	310	республика Коми, Ижемский район, село Няшабож, Центральная, 220	t	medium
8479	43207	292	республика Коми, Ижемский район, село Мошъюга, 87	t	small
8481	43209	294	республика Коми, Ижемский район, село Мохча, Центральная, 150	t	medium
8493	43221	306	республика Коми, Ижемский район, село Малое Галово, Центральная, 17	f	small
8484	43212	297	республика Коми, Ижемский район, село Ласта, Центральная, 19	t	small
8489	43217	302	республика Коми, Ижемский район, село Краснобор, им.братьев Семяшкиных, 110	t	small
8476	43204	289	республика Коми, Ижемский район, село Койю, Центральная, 412	t	small
8500	43228	313	республика Коми, Ижемский район, село Кипиево, Лесная, 115	t	medium
8492	43220	305	республика Коми, Ижемский район, село Кельчиюр, Центральная, 129	f	small
8477	43205	290	республика Коми, Ижемский район, село Картаель, Лесная, 92	f	small
8486	43214	299	республика Коми, Ижемский район, село Ижма, Советская, 49	f	large
8485	43213	298	республика Коми, Ижемский район, село Ижма, Советская, 49	f	large
8488	43216	301	республика Коми, Ижемский район, село Диюр, Клубная, 50	f	small
8480	43208	293	республика Коми, Ижемский район, село Гам, Центральная, 40	t	small
8490	43191	303	республика Коми, Ижемский район, село Вертеп, Школьная, 27	t	medium
8498	43226	311	республика Коми, Ижемский район, село Брыкаланск, Набережная, 39	t	small
8491	43219	304	республика Коми, Ижемский район, село Большое Галово, Центральная, 31	t	small
8482	43210	295	республика Коми, Ижемский район, село Бакур, Центральная, 50	t	medium
8425	43153	238	республика Коми, Вуктыльский район, село Шердино, Мира, 8	t	small
8415	43143	228	республика Коми, Вуктыльский район, село Усть-Соплеск, Школьная, 12	t	small
8416	43144	229	республика Коми, Вуктыльский район, село Подчерье, Зарубина, 1	t	medium
8422	43150	235	республика Коми, Вуктыльский район, село Лемтыбож, Лесная, 11	t	small
8423	43151	236	республика Коми, Вуктыльский район, село Лемты, 40 лет Победы, 6	t	small
8424	43152	237	республика Коми, Вуктыльский район, село Дутово, Советская, 1	t	medium
8419	43147	232	республика Коми, Вуктыл городской округ, Вуктыл, Комсомольская, 14	f	large
8336	43071	149	республика Коми, Воркутинский район, поселок Сивомаскинский, Лесная, 1	f	medium
8302	43040	115	республика Коми, Воркутинский район, поселок Северный, Юго-Западная, 5	f	large
8301	43039	114	республика Коми, Воркутинский район, поселок Северный, Юго-Западная, 17	f	large
8300	43038	113	республика Коми, Воркутинский район, поселок Северный, Спортивная, 3	f	medium
8303	43041	116	республика Коми, Воркутинский район, поселок Северный, Карла Маркса, 9	f	large
8292	43029	105	республика Коми, Воркутинский район, поселок Комсомольский, Свердлова, 3А	f	large
8291	43028	104	республика Коми, Воркутинский район, поселок Заполярный, Фрунзе, 26	f	large
8337	43072	150	республика Коми, Воркутинский район, поселок Елецкий, Школьная, 4	t	small
8296	43034	109	республика Коми, Воркутинский район, поселок Воргашор, Юбилейный переулок, 10	f	large
8294	43031	107	республика Коми, Воркутинский район, поселок Воргашор, Энтузиастов, 26Б	f	large
8293	43030	106	республика Коми, Воркутинский район, поселок Воргашор, Энтузиастов, 15А	f	large
8299	43037	112	республика Коми, Воркутинский район, поселок Воргашор, Ленинского Комсомола, 2А	f	large
8297	43035	110	республика Коми, Воркутинский район, поселок Воргашор, Катаева, 29	f	large
8298	43036	111	республика Коми, Воркутинский район, поселок Воргашор, Есенина, 2А	f	large
65915	43032	108	республика Коми, Воркутинский район, поселок Воргашор, Воргашорская, 10	f	large
8028	39362	398	республика Карелия, ст. Шуйская, Петровское шоссе, 2 А	f	large
8038	39414	408	республика Карелия, деревня Ужесельга, Центральная, 12 А	f	small
8128	39503	523	республика Карелия, Суоярви, Суоярвское шоссе, 164	f	large
8126	39501	520	республика Карелия, Суоярви, Ленина, 11	f	large
7830	39211	146	республика Карелия, Сортавала городской округ	f	large
7836	39217	152	республика Карелия, Сортавала городской округ, Школьная	f	medium
7840	39221	156	республика Карелия, Сортавала городской округ, Центральная	f	small
7837	39218	153	республика Карелия, Сортавала городской округ, Мира, 3-А	f	large
134537	39223	158	республика Карелия, Сортавала	f	small
134536	39220	155	республика Карелия, Сортавала	t	small
7833	39214	149	республика Карелия, Сортавала	f	small
7832	39213	148	республика Карелия, Сортавала, поселок Рюттю	f	small
7824	39205	140	республика Карелия, Сортавала, Промышленная, 17	f	large
7826	39207	142	республика Карелия, Сортавала, Победы, 12	f	large
7822	39203	138	республика Карелия, Сортавала, Набережная Ладожской флотилии, 2	f	large
110358	39210	145	республика Карелия, Сортавала, Локомотивная, 4, детский сад Ивушка	f	\N
7821	39202	137	республика Карелия, Сортавала, Комсомольская, 5	f	medium
7825	39206	141	республика Карелия, Сортавала, Карельская, 86-А	f	large
7843	39224	159	республика Карелия, Сортавала, Выборгское шоссе, 9	f	medium
7827	39208	143	республика Карелия, Сортавала, Выборгское Шоссе, 3	f	large
7823	39204	139	республика Карелия, Сортавала, Бондарева, 3-а	f	large
7820	39201	136	республика Карелия, Сортавала, Гагарина, 13	f	large
8101	39476	482	республика Карелия, Сегежа, Строителей, 27	f	large
134551	39479	486	республика Карелия, Сегежа, Лейгубская	t	medium
8094	39470	475	республика Карелия, Сегежа, Кирова, 30	f	large
8106	39480	487	республика Карелия, Сегежа, Гористая, 83а	f	medium
8066	39442	444	республика Карелия, Пудож, Комсомольская, 43	f	large
8065	39441	443	республика Карелия, Пудож, Комсомольская, 5	f	large
7847	39228	164	республика Карелия, Питкяранта, Ленина, 30	f	large
7848	39229	165	республика Карелия, Питкяранта, Горького, 3	f	large
7844	39225	161	республика Карелия, Питкяранта, Гоголя, 9/а	f	large
86014	39268	216	Россия, Орловская область, Орел, улица Железнодорожная, 18	f	small
7795	39187	105	республика Карелия, Петрозаводск, Чернышевского, 14а	f	large
8117	39491	498	республика Карелия, Петрозаводск, ЦЕНТРАЛЬНАЯ, 5	t	small
7714	39139	24	республика Карелия, Петрозаводск, Трудовых Резервов, 7	f	large
7713	39139	23	республика Карелия, Петрозаводск, Трудовых Резервов, 7	f	large
7693	39130	1	республика Карелия, Петрозаводск, Сулажгорского Кирпичного Завода, 11	f	large
7736	39154	46	Россия, республика Карелия, Петрозаводск, Студенческий переулок, 14	f	large
7735	39154	45	Россия, республика Карелия, Петрозаводск, Студенческий переулок, 14	f	large
7859	39239	174	республика Карелия, Петрозаводск, Советская, 11	f	medium
7727	39149	37	республика Карелия, Петрозаводск, Советская, 15	f	large
7701	39135	11	республика Карелия, Петрозаводск, Советская, 11	f	large
7728	39135	38	республика Карелия, Петрозаводск, Советская, 11	f	large
7812	39193	122	республика Карелия, Петрозаводск, Птицефабрика, 2	f	large
7819	39200	130	республика Карелия, Петрозаводск, Промышленная, 9, УИК №130	f	\N
7763	39146	73	Россия, республика Карелия, Петрозаводск, Попова переулок, 8	f	large
7724	39146	34	Россия, республика Карелия, Петрозаводск, Попова переулок, 8	f	large
7810	39192	120	республика Карелия, Петрозаводск, Петрова, 7Б	f	large
7809	39192	119	республика Карелия, Петрозаводск, Петрова, 7Б	f	large
7726	39148	36	Россия, республика Карелия, Петрозаводск, Первомайский проспект, 38	f	large
7723	39145	33	республика Карелия, Петрозаводск, Первомайский проспект, 46	f	large
7702	39136	12	Россия, республика Карелия, Петрозаводск, Первомайский проспект, 37а	f	large
7698	39133	8	Россия, республика Карелия, Петрозаводск, Первомайский проспект, 56	f	large
7697	39133	7	Россия, республика Карелия, Петрозаводск, Первомайский проспект, 56	f	large
7711	39138	21	республика Карелия, Петрозаводск, Пархоменко, 48	f	large
7712	39106	22	республика Карелия, Петрозаводск, Пархоменко, 28	f	large
7705	39106	15	республика Карелия, Петрозаводск, Пархоменко, 28	f	large
7706	39106	16	республика Карелия, Петрозаводск, Пархоменко, 28	f	large
7784	39182	94	республика Карелия, Петрозаводск, Парфёнова, 8а	f	large
7783	39182	93	республика Карелия, Петрозаводск, Парфёнова, 8а	f	large
7779	39182	89	республика Карелия, Петрозаводск, Парфёнова, 8а	f	large
7722	39144	32	Россия, республика Карелия, Петрозаводск, Октябрьский проспект, 64	f	large
7721	39144	31	Россия, республика Карелия, Петрозаводск, Октябрьский проспект, 64	f	large
7805	39191	115	республика Карелия, Петрозаводск, Нойбранденбургская, 15	f	large
7808	39191	118	республика Карелия, Петрозаводск, Нойбранденбургская, 15	f	large
7807	39191	117	республика Карелия, Петрозаводск, Нойбранденбургская, 15	f	large
7806	39191	116	республика Карелия, Петрозаводск, Нойбранденбургская, 15	f	large
7725	39147	35	республика Карелия, Петрозаводск, Мурманская, 30	f	large
7778	39181	88	Россия, республика Карелия, Петрозаводск, Лососинское шоссе, 33к5	f	large
7798	39188	108	республика Карелия, Петрозаводск, Ломоносова, 65	f	large
7700	39134	10	республика Карелия, Петрозаводск, Локомотивная, 49	f	large
7699	39134	9	республика Карелия, Петрозаводск, Локомотивная, 49	f	large
7762	39174	72	республика Карелия, Петрозаводск, Лесная, 17	f	large
8156	39529	574	республика Карелия, Петрозаводск, Ленинградская, 11	f	large
7733	39153	43	республика Карелия, Петрозаводск, Ленинградская, 19	f	large
7731	39151	41	республика Карелия, Петрозаводск, Ленинградская, 11	f	large
7743	39159	53	Россия, республика Карелия, Петрозаводск, Ленина проспект, 33	f	large
7761	39171	71	Россия, республика Карелия, Петрозаводск, Ла-Рошель набережная, 11	f	large
7757	39171	67	Россия, республика Карелия, Петрозаводск, Ла-Рошель набережная, 11	f	large
7756	39170	66	республика Карелия, Петрозаводск, Кузьмина, 50	f	large
7746	39162	56	республика Карелия, Петрозаводск, Красноармейская, 31	f	large
7738	39156	48	республика Карелия, Петрозаводск, Красная, 8	f	large
7794	39185	104	Россия, республика Карелия, Петрозаводск, Комсомольский проспект, 21а	f	large
7793	39185	103	Россия, республика Карелия, Петрозаводск, Комсомольский проспект, 21а	f	large
7791	39185	101	Россия, республика Карелия, Петрозаводск, Комсомольский проспект, 21а	f	large
7788	39185	98	Россия, республика Карелия, Петрозаводск, Комсомольский проспект, 21а	f	large
7797	39165	107	республика Карелия, Петрозаводск, Коммунистов, 51	f	large
7796	39165	106	республика Карелия, Петрозаводск, Коммунистов, 51	f	large
7750	39165	60	республика Карелия, Петрозаводск, Коммунистов, 51	f	large
67845	39190	121	республика Карелия, Петрозаводск, Ключевая, 20	f	large
67844	39190	114	республика Карелия, Петрозаводск, Ключевая, 20	f	large
7803	39190	113	республика Карелия, Петрозаводск, Ключевая, 20	f	large
7802	39190	112	республика Карелия, Петрозаводск, Ключевая, 20	f	large
7740	39155	50	республика Карелия, Петрозаводск, Кирова, 12	f	large
7737	39155	47	республика Карелия, Петрозаводск, Кирова, 12	f	large
7753	39168	63	республика Карелия, Петрозаводск, Калинина, 54	f	large
7754	39166	64	республика Карелия, Петрозаводск, Калинина, 41	f	large
7751	39166	61	республика Карелия, Петрозаводск, Калинина, 41	f	large
7774	39179	84	Россия, республика Карелия, Петрозаводск, Интернационалистов бульвар, 2	f	large
7792	39179	102	Россия, республика Карелия, Петрозаводск, Интернационалистов бульвар, 2	f	large
7776	39179	86	Россия, республика Карелия, Петрозаводск, Интернационалистов бульвар, 2	f	large
7775	39179	85	Россия, республика Карелия, Петрозаводск, Интернационалистов бульвар, 2	f	large
67843	39141	26	республика Карелия, Петрозаводск, Зайцева, 57	f	large
7718	39140	28	республика Карелия, Петрозаводск, Зайцева, 24	f	large
7715	39140	25	республика Карелия, Петрозаводск, Зайцева, 24	f	large
7696	39132	6	республика Карелия, Петрозаводск, Жуковского, 32	f	large
7752	39167	62	Россия, республика Карелия, Петрозаводск, Гюллинга набережная, 3	f	large
7749	39164	59	Россия, республика Карелия, Петрозаводск, Гюллинга набережная, 3	f	large
7748	39164	58	Россия, республика Карелия, Петрозаводск, Гюллинга набережная, 3	f	large
7787	39184	97	республика Карелия, Петрозаводск, Генерала Фролова, 12	f	large
7786	39184	96	республика Карелия, Петрозаводск, Генерала Фролова, 12	f	large
7785	39184	95	республика Карелия, Петрозаводск, Генерала Фролова, 12	f	large
7755	39169	65	республика Карелия, Петрозаводск, Варламова, 34	f	large
7732	39152	42	Россия, республика Карелия, Петрозаводск, Варкауса набережная, 5	f	large
7734	39152	44	Россия, республика Карелия, Петрозаводск, Варкауса набережная, 5	f	large
7720	39142	30	Россия, республика Карелия, Петрозаводск, Варкауса набережная, 15	f	large
7717	39142	27	Россия, республика Карелия, Петрозаводск, Варкауса набережная, 15	f	large
7768	39177	78	республика Карелия, Петрозаводск, Берёзовая Аллея, 31	f	large
7773	39178	83	республика Карелия, Петрозаводск, Березовая Аллея, 23	f	large
7772	39178	82	республика Карелия, Петрозаводск, Березовая Аллея, 23	f	large
7771	39178	81	республика Карелия, Петрозаводск, Березовая Аллея, 23	f	large
7770	39176	80	республика Карелия, Петрозаводск, Березовая Аллея, 28	f	large
7769	39176	79	республика Карелия, Петрозаводск, Березовая Аллея, 28	f	large
7767	39176	77	республика Карелия, Петрозаводск, Березовая Аллея, 28	f	large
7766	39175	76	республика Карелия, Петрозаводск, Березовая Аллея, 42	f	large
7765	39175	75	республика Карелия, Петрозаводск, Березовая Аллея, 42	f	large
7764	39175	74	республика Карелия, Петрозаводск, Березовая Аллея, 42	f	large
7782	39183	92	республика Карелия, Петрозаводск, Балтийская, 4	f	large
7781	39183	91	республика Карелия, Петрозаводск, Балтийская, 4	f	large
7780	39183	90	республика Карелия, Петрозаводск, Балтийская, 4	f	large
7801	39189	111	республика Карелия, Петрозаводск, Антонова, 10а	f	large
7800	39189	110	республика Карелия, Петрозаводск, Антонова, 10а	f	large
7799	39189	109	республика Карелия, Петрозаводск, Антонова, 10а	f	large
7744	39160	54	республика Карелия, Петрозаводск, Анохина, 16	f	large
7760	39173	70	Россия, республика Карелия, Петрозаводск, Александра Невского проспект, 57	f	large
8161	39534	579	республика Карелия, Кондопога, Комсомольская, 27 , СОШ №7	f	large
7759	39173	69	Россия, республика Карелия, Петрозаводск, Александра Невского проспект, 57	f	large
7758	39172	68	Россия, республика Карелия, Петрозаводск, Александра Невского проспект, 64	f	large
7747	39163	57	Россия, республика Карелия, Петрозаводск, Александра Невского проспект, 8	f	large
7777	39180	87	республика Карелия, Петрозаводск, Хейкконена, 41	f	large
7790	39186	100	республика Карелия, Петрозаводск, Сортавальская, 7б	f	large
7789	39186	99	республика Карелия, Петрозаводск, Сортавальская, 7б	f	large
7730	39150	40	республика Карелия, Петрозаводск, Советская, 12	f	large
7729	39150	39	республика Карелия, Петрозаводск, Советская, 12	f	large
7739	39157	49	республика Карелия, Петрозаводск, Пушкинская, 17	f	large
7704	39137	14	республика Карелия, Петрозаводск, Островского, 26	f	large
7703	39137	13	республика Карелия, Петрозаводск, Островского, 26	f	large
7710	39009	20	республика Карелия, Петрозаводск, Олонецкая, 75	f	large
7709	39009	19	республика Карелия, Петрозаводск, Олонецкая, 75	f	large
7695	39131	5	республика Карелия, Петрозаводск, Новосулажгорская, 29	f	large
7694	39131	4	республика Карелия, Петрозаводск, Новосулажгорская, 29	f	large
7719	39143	29	республика Карелия, Петрозаводск, Московская, 12а	f	large
8134	39509	532	республика Карелия, Петрозаводск, Клубная, 3	f	medium
7708	39116	18	республика Карелия, Петрозаводск, Зелёная, 7	f	large
7707	39116	17	республика Карелия, Петрозаводск, Зелёная, 7	f	large
7741	39158	51	республика Карелия, Петрозаводск, Антикайнена, 4	f	large
7742	39158	52	республика Карелия, Петрозаводск, Антикайнена, 4	f	large
7745	39161	55	республика Карелия, Петрозаводск, Анохина, 37а	f	large
8034	39410	404	республика Карелия, поселок Новая Вилга, Нововилговское шоссе, 15	f	large
67851	39405	399	республика Карелия, поселок Мелиоративный, Петрозаводская, 33а , МОУ СОШ №, 2	f	large
7959	39335	297	республика Карелия, Медвежьегорск, Советская, 6	f	large
7958	39334	296	республика Карелия, Медвежьегорск, Советская, 15	f	large
7960	39336	298	республика Карелия, Медвежьегорск, Куйбышева, 19	f	large
7957	39333	295	республика Карелия, Медвежьегорск, К.Либкнехта, 8	f	large
7955	39331	293	республика Карелия, Медвежьегорск, Дзержинского, 18	f	large
7954	39330	292	республика Карелия, Медвежьегорск, Дзержинского, 29	f	large
7915	39289	242	республика Карелия, Лахденпохья, Фанерная, 8	f	large
7917	39291	244	республика Карелия, Лахденпохья, Садовая, 22	f	medium
7919	39293	246	республика Карелия, Лахденпохья, Ленинградское шоссе, 5	f	medium
7918	39292	245	республика Карелия, Лахденпохья, Ленина, 45	f	medium
7914	39288	241	республика Карелия, Лахденпохья, Ладожской флотилии, 1	f	large
7916	39290	243	республика Карелия, Лахденпохья, Заходского, 2	f	medium
134542	39354	320	республика Карелия, Костомукша, Строителей, 5	f	large
8147	39520	565	республика Карелия, Костомукша, Советская, 14	f	large
8148	39521	566	республика Карелия, Костомукша, Перттунена, 14	f	small
8150	39523	568	республика Карелия, Костомукша, Первооткрывателей, 1	f	large
8154	39526	572	республика Карелия, Костомукша, Первомайская, 3	f	large
8151	39524	569	республика Карелия, Костомукша, Октябрьская, 4	f	large
8153	39525	571	республика Карелия, Костомукша, Ленина пл., 1	f	large
8152	39525	570	республика Карелия, Костомукша, Ленина пл., 1	f	large
8149	39522	567	республика Карелия, Костомукша, Ленина, 19	f	large
8155	39527	573	республика Карелия, Костомукша, Калевала, 7	f	large
8169	39541	587	республика Карелия, Кондопога, пр.Калинина, 10	f	large
8165	39537	583	республика Карелия, Кондопога, пр. Калинина , 13 А	f	large
8164	39537	582	республика Карелия, Кондопога, пр. Калинина , 13 А	f	large
8167	39539	585	республика Карелия, Кондопога, б.Юности, 9	f	large
8174	39547	592	республика Карелия, Кондопога, Советов, 36	f	large
8171	39544	589	республика Карелия, Кондопога, Советов, 19	f	large
8159	39532	577	республика Карелия, Кондопога, Сандальская набережная, 33	f	small
8172	39545	590	республика Карелия, Кондопога, Пролетарская, 29	f	large
8163	39536	581	республика Карелия, Кондопога, Пролетарская, 1	f	large
8160	39533	578	республика Карелия, Кондопога, Пролетарская, 40 , 40 ДЮСШ№2	f	large
134555	39531	576	республика Карелия, Кондопога, Кондопожская, 102б, Помещение здравпункта 	t	small
8173	39546	591	республика Карелия, Кондопога, Заводская, 24	f	large
8170	39543	588	республика Карелия, Кондопога, Заводская, 38	f	large
8166	39538	584	республика Карелия, Кондопога, Б.Юности, 9	f	large
7897	39272	221	республика Карелия, Кемь, Пролетарский пр., 18	f	large
7899	39274	223	республика Карелия, Кемь, Пролетарский пр, 38а	f	large
7901	39276	225	республика Карелия, Кемь, Кирова пл, 6	f	large
7838	39219	154	республика Карелия, село Кааламо, 40 лет Победы	f	large
7841	39222	157	республика Карелия, поселок Валаам	f	small
7871	39232	188	республика Карелия, Беломорск, Мерецкова, 8	f	large
7872	39232	189	республика Карелия, Беломорск, Мерецкова, 8	f	large
8131	39506	529	республика Карелия, Суоярвский район, село Тойвола, Школьная, 1	f	small
8127	39502	521	республика Карелия, Суоярвский район, Суоярви, Суоярвское шоссе, 2	f	large
8125	39500	519	республика Карелия, Суоярвский район, Суоярви, Гагарина, 15	f	large
8130	39505	528	республика Карелия, Суоярвский район, село Суоеки, Ленина, 4	f	small
8143	39518	543	Россия, республика Карелия, Суоярвский район, село Суйстамо	f	small
8141	39516	541	республика Карелия, Суоярвский район, село Райконкоски, Советская, 12	f	medium
8136	39511	536	республика Карелия, Суоярвский район, поселок Поросозеро, Заводская, 11	f	large
8135	39510	535	республика Карелия, Суоярвский район, поселок Поросозеро, Больничная, 18	f	large
8144	39519	545	республика Карелия, Суоярвский район, село Пийтсиеки, Центральная, 16-а	f	medium
8132	39507	530	республика Карелия, Суоярвский район, поселок Найстенъярви, Заводская, 1	f	large
8133	39508	531	Россия, республика Карелия, Суоярвский район, Найстенъярви	f	small
8140	39515	540	республика Карелия, Суоярвский район, село Лоймола, Суоярское шоссе, 16	f	medium
134554	39517	542	республика Карелия, Суоярвский район, село Леппясюрья, Центральная, 29	f	small
134553	39504	526	республика Карелия, Суоярвский район, село Леппяниэми, ФАП	t	small
8137	39512	537	Россия, республика Карелия, Суоярвский район, село Гумарино	f	small
8138	39513	538	Россия, республика Карелия, Суоярвский район, село Вегарус	f	small
7828	39209	144	республика Карелия, Сортавала городской округ, село Хюмпеля	f	small
7831	39212	147	республика Карелия, Сортавала городской округ, поселок Хелюля, Центральная	f	medium
7834	39215	150	республика Карелия, Сортавала городской округ, село Туокслахти	f	small
134535	39216	151	республика Карелия, Сортавала городской округ, село Партала	t	small
8114	39488	495	республика Карелия, Сегежский район, поселок Черный Порог, Болотная, 9	f	small
8099	39474	480	республика Карелия, Сегежский район, Сегежа, пр-д Бумажников, 7	f	large
8098	39474	479	республика Карелия, Сегежский район, Сегежа, пр-д Бумажников, 7	f	large
8104	39478	485	республика Карелия, Сегежский район, Сегежа, Спиридонова, 27	f	large
8103	39478	484	республика Карелия, Сегежский район, Сегежа, Спиридонова, 27	f	large
8096	39472	477	республика Карелия, Сегежский район, Сегежа, Советская, 8	f	large
8095	39471	476	республика Карелия, Сегежский район, Сегежа, Советская, 20	f	large
8102	39477	483	республика Карелия, Сегежский район, Сегежа, Монтажников пр-д, 4	f	large
8097	39473	478	республика Карелия, Сегежский район, Сегежа, Мира, 23	f	large
8100	39475	481	республика Карелия, Сегежский район, Сегежа, Лесокультурная, 14	f	large
8107	39481	488	республика Карелия, Сегежский район, Сегежа, Анохина, 15	f	small
8111	39485	492	республика Карелия, Сегежский район, поселок Пристань Надвоицы, Набережная, 15	f	small
8120	39495	501	республика Карелия, Сегежский район, село Попов Порог, Кирова, 4	f	small
86019	39497	503	республика Карелия, Сегежский район, село Полга, Центральная, 8	f	small
8116	39490	497	республика Карелия, Сегежский район, поселок Олений, Набережная, 21	t	small
8110	39484	491	республика Карелия, Сегежский район, поселок Надвоицы, Ленина, 14	f	large
8109	39483	490	республика Карелия, Сегежский район, поселок Надвоицы, Строителей, 8	f	large
8108	39482	489	республика Карелия, Сегежский район, село Надвоицы, Строителей, 1	f	large
8119	39494	500	республика Карелия, Сегежский район, село Кочкома, Центральная, 42а	f	small
8112	39486	493	республика Карелия, Сегежский район, поселок Каменный Бор, Комсомольская, 1а	f	medium
113353	74665	123	Псковская область, Великие Луки, Щорса, 59	f	medium
8118	39492	499	республика Карелия, Сегежский район, поселок Идель, Школьная, 1	f	small
8121	39496	502	республика Карелия, Сегежский район, село Волдозеро, Центральная, 8	f	small
8124	39499	505	Россия, республика Карелия, Сегежский район, село Вожмогора	t	small
134552	39487	494	республика Карелия, Сегежский район, поселок Верхний, штаб ФКУ ЛИУ-4 УФСИН России по Республике Карелия	t	small
8115	39489	496	республика Карелия, Сегежский район, село Вача, Центральная, 1	t	small
8123	39498	504	республика Карелия, Сегежский район, поселок Валдай, Школьная, 7	f	large
8079	39456	457	республика Карелия, Пудожский район, поселок Шальский, Стеклянская, 74	f	medium
8078	39455	456	республика Карелия, Пудожский район, поселок Шальский, Октябрьская, 20	f	large
8087	39463	466	республика Карелия, Пудожский район, село Тамбичозеро, Центральная, 4	t	small
8086	39462	465	республика Карелия, Пудожский район, село Тамбицы, Школьная, 4	t	small
8080	39457	458	республика Карелия, Пудожский район, село Семеново, 82	f	small
8071	39447	449	республика Карелия, Пудожский район, село Рагнукса, Школьная, 5а	f	small
8084	39460	463	республика Карелия, Пудожский район, поселок Пяльма, Школьная, 24	f	large
8085	39461	464	республика Карелия, Пудожский район, село Пудожгорский, Молодежная, 2	f	medium
8064	39440	442	республика Карелия, Пудожский район, Пудож, Пионерская, 21	f	large
8067	39443	445	республика Карелия, Пудожский район, Пудож, К.Маркса, 79	f	large
8093	39469	473	республика Карелия, Пудожский район, село Приречный, Центральная, 14	t	small
8073	39450	451	республика Карелия, Пудожский район, село Подпорожье, Школьная, 24	f	medium
8092	39468	472	республика Карелия, Пудожский район, село Погост, 13	t	small
8083	39459	461	республика Карелия, Пудожский район, село Песчаное, 27	f	small
8082	39458	460	республика Карелия, Пудожский район, село Онежский, Советская, 13	f	small
134550	39449	450	республика Карелия, Пудожский район, село Куганаволок, 114	f	small
8090	39466	469	республика Карелия, Пудожский район, село Кубовская, 52	t	small
8089	39465	468	республика Карелия, Пудожский район, село Кубово, Победы, 4а	f	medium
8088	39464	467	республика Карелия, Пудожский район, село Кривцы, Горького, 5	f	large
8076	39453	454	республика Карелия, Пудожский район, село Красноборский, Центральная, 1	f	small
8069	39445	447	республика Карелия, Пудожский район, село Колово, 5	f	small
8070	39446	448	республика Карелия, Пудожский район, село Колово, Школьная, 3	f	medium
8075	39452	453	республика Карелия, Пудожский район, село Каршево, Школьная, 47	f	small
8032	39408	402	республика Карелия, Пудожский район, село Заозерье, Центральная, 7	f	large
8091	39467	471	республика Карелия, Пудожский район, село Водла, Комсомольская, 13а	f	medium
8074	95095	452	республика Карелия, Пудожский район, село Бочилово, Лесная, 29	f	small
8081	39388	459	республика Карелия, Пудожский район, село Авдеево, 68	f	small
8054	39429	429	республика Карелия, Пряжинский район, село Эссойла, Октябрьская, 11	f	large
8031	39407	401	республика Карелия, Пряжинский район, село Чална	f	large
8046	39421	421	республика Карелия, Пряжинский район, село Чална, Школьная, 17А	f	large
8057	39432	432	республика Карелия, Пряжинский район, село Сяпся, Школьная, 11	f	small
8055	39430	430	республика Карелия, Пряжинский район, село Соддер, Школьная, 5	f	small
8051	39426	426	республика Карелия, Пряжинский район, село Святозеро, Олонецкая, 5	f	medium
8059	39435	434	Россия, Калужская область, Малоярославецкий район, поселок Савиново	f	small
8044	39419	419	республика Карелия, Пряжинский район, поселок Пряжа, Советская, 89	f	large
8043	39419	418	республика Карелия, Пряжинский район, поселок Пряжа, Советская, 89	f	large
8056	39431	431	Россия, Саратовская область, Лысогорский район, село Новые Пески	f	small
8050	39425	425	республика Карелия, Пряжинский район, село Матросы, Пряжинское шоссе, 20	f	medium
8049	39424	424	Россия, республика Карелия, Пряжинский район, село Кутижма	f	small
134549	39433	433	республика Карелия, Пряжинский район, село Кудама, Пионерская, 1	f	small
8053	39428	428	республика Карелия, Пряжинский район, село Крошнозеро, Магистральная, 14	f	small
8063	39439	439	Россия, республика Карелия, Пряжинский район, село Колатсельга	f	small
68665	74663	121	Псковская область, Великие Луки, Фурманова, 67	f	large
8062	39438	438	республика Карелия, Пряжинский район, село Койвусельга, Гагарина, 1	f	small
8061	39437	437	республика Карелия, Пряжинский район, село Кинелахта, Центральная, 16	f	small
134547	39423	423	Россия, республика Карелия, Пряжинский район, село Виллагора	t	small
8047	39422	422	Россия, республика Карелия, Пряжинский район, село Виданы	f	small
8139	39514	539	республика Карелия, Пряжинский район, село Вешкелица, Стойкина, 6	f	small
134548	39427	427	Россия, республика Карелия, Пряжинский район, село Верхние Важины	t	small
8060	39436	435	республика Карелия, Пряжинский район, село Велдозеро, Школьная, 2	f	medium
134546	39416	415	республика Карелия, Прионежский район, д. Верхручей, 23 А	t	small
8033	39409	403	республика Карелия, Прионежский район, село Ялгуба	f	small
8027	39328	397	республика Карелия, Прионежский район, село Шуя, Школьная, 10 А	f	large
8041	39417	416	республика Карелия, Прионежский район, село Шелтозеро, Лисицыной, 3	f	medium
8042	39418	417	республика Карелия, Прионежский район, село Рыбрека	f	medium
8024	14673	394	республика Карелия, Прионежский район, село Пухта, 39	f	small
8037	39413	407	республика Карелия, Прионежский район, село Педасельга, Радиоцентр, 5	f	small
8026	39404	396	республика Карелия, Прионежский район, поселок Пай, Кировская, 10	f	medium
134545	39403	395	республика Карелия, Прионежский район, село Ладва-Ветка, Молодежная, 4б, Администрация сельского поселения	f	large
8023	39402	393	республика Карелия, Прионежский район, село Ладва, Советская, 129	f	large
8039	39415	414	республика Карелия, Прионежский район, село Кварцитный, 25	f	large
8036	39412	406	республика Карелия, Прионежский район, село Деревянное, Набережная, 21	f	large
8030	39406	400	Россия, республика Карелия, Прионежский район, село Деревянка	f	large
8035	39411	405	республика Карелия, Прионежский район, село Вилга, Прионежское шоссе, 17	f	medium
7861	39242	177	республика Карелия, Питкярантский район, д. Мансила, Совхозная, 3	f	small
7857	39237	172	республика Карелия, Питкярантский район, село Янисъярви, 8/А	f	small
7852	39233	168	республика Карелия, Питкярантский район, Янис, Полевая, Адм. здание ООО Ладожское	f	small
7855	39235	170	республика Карелия, Питкярантский район, Хийденсельга, Ладожская, 4	f	large
7856	39236	171	республика Карелия, Питкярантский район, поселок Харлу, 2-Речная, 2	f	medium
7851	39230	166	республика Карелия, Питкярантский район, село Ууксу, Геологическая, 9	f	small
7865	39240	175	республика Карелия, Питкярантский район, Салми, Свирских дивизий, 2	f	medium
7858	39238	173	республика Карелия, Питкярантский район, село Рауталахти, Центральная, 16	f	small
7845	39226	162	Россия, республика Карелия, Питкярантский район, Питкяранта	f	large
7863	39241	176	республика Карелия, Питкярантский район, Мийнала, Совхозная, 3	f	small
7854	39234	169	республика Карелия, Питкярантский район, поселок Ляскеля, Советская, 33	f	medium
7849	39231	167	республика Карелия, Питкярантский район, поселок Импилахти, Советская, 3	f	medium
8014	39393	376	республика Карелия, Олонецкий район, село Устье-Видлицы, Привокзальная, 13, бывш. фельдшерско-акушерский пункт	f	medium
8006	39384	368	республика Карелия, Олонецкий район, село Устье Тулоксы, Мурзанова, библиотека	f	small
8010	39389	372	республика Карелия, Олонецкий район, село Тукса, Новая, 1а, администрация Агрофирма "Тукса"	f	large
8009	39387	371	республика Карелия, Олонецкий район, село Рыпушкалицы, 20б, школа	f	large
8002	39380	363	республика Карелия, Олонецкий район, Олонец, Урицкого, 9детская музыкальная школа	f	large
8000	39378	361	республика Карелия, Олонецкий район, Олонец, Урицкого, 4а, СОШ №1	f	large
8008	39386	370	республика Карелия, Олонецкий район, Олонец, Полевая, 41, СОШ № 2	f	small
7999	39377	360	республика Карелия, Олонецкий район, Олонец, Красноармейская, 19, Детско-юношеская спортивная школа	f	large
8001	39379	362	республика Карелия, Олонецкий район, Олонец, Карла Маркса, 3а, СОШ №1	f	large
8016	39395	378	республика Карелия, Олонецкий район, село Нурмолицы, 32а, администрация поселения	f	small
8021	39400	388	республика Карелия, Олонецкий район, село Михайловское, Новая, 15а, дом культуры	f	small
8022	39401	389	республика Карелия, Олонецкий район, село Мегрега, Школьный пер, 3, администрация Племсовхоз Мегрега	f	medium
8020	39399	386	республика Карелия, Олонецкий район, село Куйтежа, Ленина, 12а, школа	f	medium
8018	39397	384	республика Карелия, Олонецкий район, село Коткозеро, Олонецкая, 10, дом культуры	f	medium
8017	39396	379	республика Карелия, Олонецкий район, село Ковера, 60-летия Великого Октября, 25, школа	f	small
8004	39382	365	республика Карелия, Олонецкий район, поселок Ильинский, Леселидзе, 46, Центр клубных инициатив	f	medium
67849	39381	364	республика Карелия, Олонецкий район, поселок Ильинский, Заводская, 15, детская музыкальная школа	f	large
8013	39392	375	республика Карелия, Олонецкий район, село Гавриловка, магазин сельпо	f	small
8011	39390	373	республика Карелия, Олонецкий район, село Видлица, Школьная, школа № 28	f	large
8007	39385	369	республика Карелия, Олонецкий район, село Верховье, 22а, бывш д/с Ивушка	f	medium
8019	39398	385	республика Карелия, Олонецкий район, село Верхнеолонецкий, Школьная, 4, школа	f	small
8015	39394	377	республика Карелия, Олонецкий район, село Большие Горы, дом культуры	f	small
8005	39383	366	республика Карелия, Олонецкий район, село Алексала, столовая Плем хоз Ильиское 	f	small
7991	39368	352	республика Карелия, Муезерский район, село Тумба, Первомайская, 3	f	small
7996	39374	357	республика Карелия, Муезерский район, село Тикша, Школьная, 1	f	small
134543	39365	349	республика Карелия, Муезерский район, поселок Суккозеро, Советская, 23	f	large
7998	39376	359	республика Карелия, Муезерский район, село Ругозеро, Еремеева, 30	f	medium
7995	39373	356	республика Карелия, Муезерский район, село Реболы, Моккиева, 1	f	medium
7987	39364	348	республика Карелия, Муезерский район, село Пенинга, Ленина, 26	f	medium
7989	39366	350	республика Карелия, Муезерский район, село Ондозеро, Рабочая, 1А	t	small
7984	39361	345	республика Карелия, Муезерский район, поселок Муезерский, Октябрьская, 27	f	large
7985	39361	346	республика Карелия, Муезерский район, поселок Муезерский, Октябрьская, 27	f	large
7992	39369	353	республика Карелия, Муезерский район, село Мотко, Комсомольская, 15	f	small
134544	39371	354	республика Карелия, Муезерский район, село Лендеры, Первомайская, 4	f	large
7997	39375	358	республика Карелия, Муезерский район, поселок Ледмозеро, 50 лет ВЛКСМ	f	large
7994	39372	355	республика Карелия, Муезерский район, село Кимоваара, Советская, 5	t	small
7990	39367	351	республика Карелия, Муезерский район, село Гимолы, Ленина, 17	f	small
7986	39363	347	республика Карелия, Муезерский район, село Волома, 23 съезда, 1А	f	large
7978	39355	321	республика Карелия, Медвежьегорский район, село Шуньга, Совхозная, 15	f	medium
7966	39342	305	республика Карелия, Медвежьегорский район, село Шлюз 9, школа	f	small
7975	39352	318	республика Карелия, Медвежьегорский район, село Шалговаара, Советская, 20	f	small
7970	39347	310	республика Карелия, Медвежьегорский район, село Челмужи, Гагарина, 60	f	medium
7972	39349	313	республика Карелия, Медвежьегорский район, село Чебино, Центральная, 52	f	small
7980	39357	323	республика Карелия, Медвежьегорский район, село Толвуя, Гористая, 7	f	large
7965	39341	304	республика Карелия, Медвежьегорский район, Сосновка, Конституции, 3	f	medium
7971	39348	311	республика Карелия, Медвежьегорский район, село Сергиево, Гагарина, 5	f	small
7964	39340	303	республика Карелия, Медвежьегорский район, поселок Повенец, Копейкина, 4	f	large
7961	39337	300	республика Карелия, Медвежьегорский район, поселок Пиндуши, Ленина, 8-а	f	large
7962	39338	301	республика Карелия, Медвежьегорский район, поселок Пиндуши, Конституции, 19	f	large
7974	39351	316	республика Карелия, Медвежьегорский район, село Паданы, Гористая, 5	f	large
7969	39345	309	республика Карелия, Медвежьегорский район, село Огорелыши, Центральная, 17	f	small
7967	39343	306	республика Карелия, Медвежьегорский район, село Новая Габсельга, Дорожная, 10-а	f	small
7956	39332	294	республика Карелия, Медвежьегорский район, Медвежьегорск, К.Либкнехта, 20-а	f	large
7976	39353	319	республика Карелия, Медвежьегорский район, село Маслозеро, Школьная, 19	t	small
7963	39339	302	республика Карелия, Медвежьегорский район, село Лумбуши, Совхозная, 10	f	medium
7983	39360	326	республика Карелия, Медвежьегорский район, село Ламбасручей, Школьная, 5	f	medium
7973	39350	315	республика Карелия, Медвежьегорский район, село Кумса 2, Лесная, 2	f	small
7979	39356	322	республика Карелия, Медвежьегорский район, село Кажма, Дом досуга	f	small
7968	39344	307	республика Карелия, Медвежьегорский район, село Верх. Волозеро, Центральная, школа	f	small
7981	39358	324	республика Карелия, Медвежьегорский район, село Великая Нива, Ригачина, 3	f	small
7982	39359	325	республика Карелия, Медвежьегорский район, село Великая Губа, Рябова, 25-а	f	large
7939	39315	270	республика Карелия, Лоухский район, село Энгозеро, Советская, 12	f	medium
7951	39327	283	республика Карелия, Лоухский район, поселок Чупа, Пионерская, 94	f	large
7950	39326	282	республика Карелия, Лоухский район, поселок Чупа, Коргуева, 7а	f	large
7946	39322	278	республика Карелия, Лоухский район, поселок Чкаловский, Набережная, 14	f	small
7953	39329	285	республика Карелия, Лоухский район, село Хетоламбина, Новая, 1	f	small
7948	39324	280	республика Карелия, Лоухский район, село Тэдино, Слюдяная, 10	f	small
7942	39318	274	республика Карелия, Лоухский район, село Тунгозеро, Комсомольская, 12	f	small
7943	39319	275	республика Карелия, Лоухский район, село Софпорог, Центральная, 1	f	small
7945	39321	277	республика Карелия, Лоухский район, село Сосновый, Школьная, 1	f	medium
7941	39317	273	республика Карелия, Лоухский район, поселок Пяозерский, Дружбы, 23	f	large
7947	39323	279	республика Карелия, Лоухский район, село Плотина, Клубная, 2	f	small
7952	39279	284	республика Карелия, Лоухский район, село Малиновая Варакка, Слюдяная, 3	f	small
7937	39313	268	республика Карелия, Лоухский район, поселок Лоухи, Советская, 46	f	large
7938	39314	269	республика Карелия, Лоухский район, поселок Лоухи, Железнодорожная, 1	f	large
7949	39325	281	республика Карелия, Лоухский район, поселок Лоухи, Дачный переулок, 6	f	medium
7944	39320	276	республика Карелия, Лоухский район, поселок Кестеньга, Набережная, 41	f	large
134541	39316	271	республика Карелия, Лоухский район, поселок Амбарный, Ленина, 18	f	medium
7926	39301	255	республика Карелия, Лахденпохский район, село Эстерло, Центральная, 13	f	small
7925	39300	254	республика Карелия, Лахденпохский район, поселок Элисенваара, Петровского, 1	f	medium
7932	39308	262	республика Карелия, Лахденпохский район, село Хухтерву, Центральная	f	small
7933	39309	263	республика Карелия, Лахденпохский район, село Хийтола, Ленина, 16	f	medium
7934	39310	264	республика Карелия, Лахденпохский район, село Тоунан, Правды, 2а	f	small
7935	39311	266	республика Карелия, Лахденпохский район, село Тиурула, Солнечная, 6а	f	small
7931	39307	261	республика Карелия, Лахденпохский район, село Терву, Школьная, 14	f	small
7924	39299	253	республика Карелия, Лахденпохский район, село Раухала, Центральная, 2	f	small
7921	39295	249	республика Карелия, Лахденпохский район, село Мийнала, Школьная, 4	f	small
7922	39297	251	республика Карелия, Лахденпохский район, село Лумиваара, Центральная, 22	f	small
7920	39294	247	республика Карелия, Лахденпохский район, Лахденпохья, Трубачева, 1	f	large
7929	39305	259	республика Карелия, Лахденпохский район, село Ласанен, Ленинградская, 3	f	small
86015	39303	257	Россия, республика Карелия, Лахденпохский район, село Ламминкюля	f	small
7928	39304	258	республика Карелия, Лахденпохский район, село Куркиеки, Ленина, 25	f	medium
7936	39312	267	республика Карелия, Лахденпохский район, село Куликово, Ленина, 4	f	small
7923	39298	252	республика Карелия, Лахденпохский район, село Ихала, Центральная, 46	f	medium
134539	39302	256	республика Карелия, Лахденпохский район, село Вялимяки, Зеленая, 9	t	small
134540	39306	260	республика Карелия, Лахденпохский район, село Алхо, Лесная, 5	t	small
8187	39561	605	Россия, республика Карелия, Кондопожский район, село Янишполе	f	large
134556	39554	599	Россия, республика Карелия, Кондопожский район, село Эльмус	t	small
134561	39558	603	республика Карелия, Кондопожский район, село Уница, Заречная	t	small
8186	39560	604	Россия, республика Карелия, Кондопожский район	f	small
134557	39555	600	Россия, республика Карелия, Кондопожский район	t	small
110360	39551	596	Россия, республика Карелия, Кондопожский район, село Спасская Губа	f	medium
8179	39552	597	Россия, республика Карелия, Кондопожский район, село Нелгомозеро	f	small
134559	39557	602	Россия, республика Карелия, Кондопожский район, село Кяппесельга	f	medium
67852	39549	594	Россия, республика Карелия, Кондопожский район, село Кончезеро	f	large
8168	39540	586	республика Карелия, Кондопожский район, Кондопога, Строительная, 2	f	large
8162	39535	580	республика Карелия, Кондопожский район, Кондопога, Пролетарская, 14, СОШ №1	f	large
134558	39556	601	Россия, республика Карелия, Кондопожский район, село Кедрозеро	f	medium
8180	39553	598	республика Карелия, Кондопожский район, поселок Гирвас, средняя школа	f	large
8175	39548	593	Россия, республика Карелия, Кондопожский район, село Березовка	f	medium
7907	39283	231	республика Карелия, Кемский район, поселок Рабочеостровск, Советская, 11	f	large
7909	39285	233	республика Карелия, Кемский район, село Панозеро, Ленина, 2	f	small
7910	39286	234	республика Карелия, Кемский район, село Кузема, Вокзальная, 4	f	small
7908	39284	232	республика Карелия, Кемский район, поселок Кривой Порог, Кольцевая, 16-а	f	large
7903	39278	227	республика Карелия, Кемский район, Кемь, шоссе 1 Мая, 24	f	small
7904	39280	228	республика Карелия, Кемский район, Кемь, пр. Пролетарский, 18	f	large
7900	39275	224	республика Карелия, Кемский район, Кемь, Пролетарский пр, 55	f	large
7902	39277	226	республика Карелия, Кемский район, Кемь, Октябрьская, 1	f	large
7898	39273	222	республика Карелия, Кемский район, Кемь, Каменева, 6	f	large
7905	39281	229	республика Карелия, Кемский район, поселок Гайжево, Ломоносова, 15-б	f	small
7906	39282	230	республика Карелия, Кемский район, поселок Бабгуба, Ручьевая, 1-а	f	medium
7913	39287	235	Россия, республика Карелия, Кемский район, село 14-й километр	f	medium
110359	39269	217	республика Карелия, Калевальский район, село Юшкозеро, Советская, 10	f	\N
7896	39271	219	республика Карелия, Калевальский район, село Луусалма, Советская, 15	t	small
86013	39266	214	республика Карелия, Калевальский район, село Куусиниэми, Набережная, 12	f	small
7895	39270	218	республика Карелия, Калевальский район, село Кепа, Карельская, 1	f	small
67846	39264	212	республика Карелия, Калевальский район, поселок Калевала, Советская, 15а	f	large
7890	39265	213	республика Карелия, Калевальский район, поселок Калевала, Ленина, 42	f	large
67847	39267	215	республика Карелия, Калевальский район, поселок Боровой, Советская, 13	f	large
134538	39263	207	республика Карелия, Беломорский район, село Шуерецкое, Советская, 5	f	small
7883	39257	200	республика Карелия, Беломорский район, село Хвойный, Набережная, 19	f	small
7879	39253	196	республика Карелия, Беломорский район, село Сумский Посад, 57	f	small
7881	39255	198	республика Карелия, Беломорский район, село Сумский Посад, Школьная, 4	f	small
7880	39254	197	республика Карелия, Беломорский район, село Сумский Посад, Набережная, 16	f	small
7886	39260	205	республика Карелия, Беломорский район, поселок Сосновец, Кирова, 22	f	large
7885	39259	203	республика Карелия, Беломорский район, село Пушной, Пионерская, 9	f	small
7878	39252	195	республика Карелия, Беломорский район, село Нюхча, 161	f	small
7887	39261	206	республика Карелия, Беломорский район, село Новое Машезеро, Почтовая, 2	f	small
7877	39251	194	республика Карелия, Беломорский район, поселок Маленьга, Школьная, 16	t	small
7884	39258	202	республика Карелия, Беломорский район, поселок Летнереченский, Школьная, 19	f	large
7882	39256	199	республика Карелия, Беломорский район, село Колежма, 161	t	small
7875	39249	192	республика Карелия, Беломорский район, поселок Золотец, Центральная, 10А	f	medium
7876	39250	193	республика Карелия, Беломорский район, поселок Вирандозеро, Советская, 21	f	medium
7867	39244	184	республика Карелия, Беломорский район, Беломорск, Школьный переулок, 4	f	small
7868	39245	185	республика Карелия, Беломорский район, Беломорск, Строительная, 18	f	large
7873	39247	190	республика Карелия, Беломорский район, Беломорск, Ленинская, 29	f	medium
7870	39246	187	республика Карелия, Беломорский район, Беломорск, Ленинская, 15А	f	large
7874	39248	191	республика Карелия, Беломорский район, Беломорск, Водников, 29	f	medium
68761	75108	583	Псковская область, Себеж, Шоссейная, 1б	f	large
113713	75109	584	Псковская область, Себеж, Первомайская, 56	f	medium
68680	74679	137	Псковская область, деревня Родина, Школьная, 3	f	large
113494	74861	325	Псковская область, Пыталово, Победы, 77а	f	medium
68726	74860	324	Псковская область, Пыталово, М.Горького, 16	f	large
113493	74859	323	Псковская область, Пыталово, Красноармейская, 51	f	medium
113492	74858	322	Псковская область, Пыталово, Белорусская, 18а	f	medium
68638	74601	89	Россия, Псковская область, Псков, улица Юбилейная, 67а	f	large
68593	74601	42	Россия, Псковская область, Псков, улица Юбилейная, 67а	f	large
68592	74601	41	Россия, Псковская область, Псков, улица Юбилейная, 67а	f	large
68746	75031	501	Россия, Псковская область, Псков, улица Советская, 20	f	large
68571	74582	20	Россия, Псковская область, Псков, улица Пригородная, 9	f	large
68653	74650	108	Россия, Псковская область, Псков, улица Пионерская, 4	f	large
113533	74903	369	Россия, Ростовская область, Таганрог, улица Петровская	f	medium
68591	74600	40	Россия, Псковская область, Псков, улица Народная, 55	f	large
68590	74600	39	Россия, Псковская область, Псков, улица Народная, 55	f	large
68614	74614	64	Россия, Псковская область, Псков, улица Коммунальная, 19	f	large
68613	74613	63	Россия, Псковская область, Псков, улица Коммунальная, 30	f	large
68612	74613	62	Россия, Псковская область, Псков, улица Коммунальная, 30	f	large
68606	74608	55	Россия, Псковская область, Псков, улица Коммунальная, 48	f	large
68598	74604	47	Россия, Псковская область, Псков, улица Коммунальная, 71а	f	large
68580	74592	29	Россия, Псковская область, Псков, улица Комдива Кирсанова, 5	f	large
68562	74574	11	Россия, Псковская область, Псков, улица Заводская, 3	f	large
68564	74577	13	Россия, Псковская область, Псков, улица Вокзальная, 48	f	large
68579	74591	28	Псковская область, Псков, Яна Райниса, 41	f	large
68561	74573	10	Псковская область, Псков, Я.Фабрициуса, 16	f	large
68563	74575	12	Псковская область, Псков, Юрия Гагарина, 5а	f	large
68610	74610	59	Псковская область, Псков, Юбилейная, 87а	f	large
68594	74602	43	Псковская область, Псков, Юбилейная, 34	f	large
113640	75023	493	Псковская область, Псков, Школьная, 15, помещение медецинского пункта	t	small
68628	74626	78	Псковская область, Псков, Труда, 49А	f	large
68627	74625	77	Псковская область, Псков, Труда, 51	f	large
68631	74621	81	Псковская область, Псков, Труда, 25	f	large
68623	74621	73	Псковская область, Псков, Труда, 25	f	large
68632	74627	82	Псковская область, Псков, Текстильная, 18	f	large
68629	74627	79	Псковская область, Псков, Текстильная, 18	f	large
68576	74588	25	Псковская область, Псков, Советской Армии, 54	f	large
68558	74571	7	Псковская область, Псков, Советская, 106	f	large
113348	74623	90	Россия, Псковская область, Псков, Сиреневый бульвар, 15	f	medium
68625	74623	75	Россия, Псковская область, Псков, Сиреневый бульвар, 15	f	large
68624	74623	74	Россия, Псковская область, Псков, Сиреневый бульвар, 15	f	large
68554	74567	3	Псковская область, Псков, Свердлова, 56	f	large
68587	74598	36	Псковская область, Псков, Розы Люксембург, 18	f	large
68588	74598	37	Псковская область, Псков, Розы Люксембург, 18	f	large
68611	74611	60	Россия, Псковская область, Псков, Рижский проспект, 64	f	large
68578	74590	27	Псковская область, Псков, Рельсовая, 2	f	large
68557	74570	6	Псковская область, Псков, Победы площадь, 1	f	large
68597	74603	46	Псковская область, Псков, Печорская, 3	f	large
68596	74603	45	Псковская область, Псков, Печорская, 3	f	large
68595	74603	44	Псковская область, Псков, Печорская, 3	f	large
68617	74616	67	Псковская область, Псков, Пароменская, 9	f	large
68616	74616	66	Псковская область, Псков, Пароменская, 9	f	large
113389	74730	193	Псковская область, Псков, Островская, 23	f	small
68585	74596	34	Псковская область, Псков, Ольгинская набережная, 13/2	f	large
68570	74581	19	Псковская область, Псков, Николая Васильева, 79	f	large
68569	74581	18	Псковская область, Псков, Николая Васильева, 79	f	large
68589	74599	38	Псковская область, Псков, Народная, 20	f	large
68622	74620	72	Псковская область, Псков, Набат, 5	f	large
68583	74594	32	Псковская область, Псков, Максима Горького, 28	f	large
68582	74593	31	Псковская область, Псков, Максима Горького, 61	f	large
68581	74593	30	Псковская область, Псков, Максима Горького, 61	f	large
68567	74579	16	Псковская область, Псков, Льва Толстого, 18	f	large
68566	74579	15	Псковская область, Псков, Льва Толстого, 18	f	large
68565	74578	14	Псковская область, Псков, Льва Толстого, 4	f	large
68621	74619	71	Псковская область, Псков, Леона Поземского, 65	f	large
68620	74618	70	Псковская область, Псков, Леона Поземского, 124	f	large
68574	74585	23	Россия, Псковская область, Псков, Ленинградское шоссе, 49	f	large
68573	74584	22	Россия, Псковская область, Псков, Ленинградское шоссе, 24	f	large
68553	74566	2	Псковская область, Псков, Ленина, 10	f	large
68552	74565	1	Псковская область, Псков, Ленина, 2	f	large
68556	74569	5	Псковская область, Псков, Кузнецкая, 13	f	large
68584	74595	33	Псковская область, Псков, Красноармейская, 1	f	large
68586	74597	35	Псковская область, Псков, Конная, 6	f	large
68615	74615	65	Псковская область, Псков, Киселёва, 8	f	large
68575	74586	24	Псковская область, Псков, Карбышева, 4	f	large
68555	74568	4	Псковская область, Псков, Калинина, 5	f	large
68636	74631	86	Псковская область, Псков, Инженерная, 16а	f	large
68630	74628	80	Псковская область, Псков, Инженерная, 90а	f	large
68637	74633	88	Псковская область, Псков, Индустриальная, 1а	f	large
68568	74580	17	Россия, Псковская область, Псков, Зональное шоссе, 11	f	large
68626	74624	76	Псковская область, Псков, Звёздная, 12	f	large
68609	74609	58	Псковская область, Псков, Западная, 5	f	large
68608	74609	57	Псковская область, Псков, Западная, 5	f	large
68607	74609	56	Псковская область, Псков, Западная, 5	f	large
68605	74607	54	Псковская область, Псков, Западная, 19	f	large
68604	74607	53	Псковская область, Псков, Западная, 19	f	large
68603	74607	52	Псковская область, Псков, Западная, 19	f	large
68602	74605	51	Псковская область, Псков, Байкова, 6	f	large
68601	74605	50	Псковская область, Псков, Байкова, 6	f	large
68599	74605	48	Псковская область, Псков, Байкова, 6	f	large
68600	74605	49	Псковская область, Псков, Байкова, 6	f	large
68635	74629	85	Псковская область, Псков, Алтаева, 2	f	large
68634	74629	84	Псковская область, Псков, Алтаева, 2	f	large
68633	74629	83	Псковская область, Псков, Алтаева, 2	f	large
68618	74617	68	Псковская область, Псков, Алексея Алёхина, 20	f	large
68619	74617	69	Псковская область, Псков, Алексея Алёхина, 20	f	large
68560	74572	9	Псковская область, Псков, 23 июля, 9	f	large
68559	74572	8	Псковская область, Псков, 23 июля, 9	f	large
68577	74589	26	Псковская область, Псков, 1-я Посёлочная, 15	f	large
68755	75079	554	Псковская область, Порхов, Ленина, 5	f	large
68752	75076	551	Псковская область, Порхов, Ленина, 32 А	f	large
113383	74674	186	Псковская область, Печоры, Свободы, 34	f	small
68697	74587	182	Псковская область, Печоры, Вокзальная, 11	f	large
68712	74786	250	Псковская область, Остров, 25 Октября, 23	f	large
113529	74899	365	Псковская область, Опочка, Пролетарская, 56	f	medium
68722	74836	299	Псковская область, Новоржев, Германа, 65	f	large
113445	74803	267	Псковская область, поселок Нефедино	t	small
68771	75144	617	Псковская область, Невель, Урицкого, 36	f	large
68773	75140	619	Псковская область, Невель, Ленина, 5 А	f	large
68768	75140	614	Псковская область, Невель, Ленина, 5 А	f	large
68766	75140	612	Псковская область, Невель, Ленина, 5 А	f	large
68704	74747	210	Псковская область, Дно, Петрова, 55	f	large
68642	74639	96	Россия, Псковская область, деревня Голубово, улица Парковая, 4	f	large
113364	74698	154	Псковская область, деревня Голубово, Парковая, 11	f	small
113662	75051	521	Псковская область, Гдов, Школьный переулок	f	medium
68671	74670	128	Псковская область, Великие Луки, пр.Гагарина, 81	f	large
68661	74659	117	Псковская область, Великие Луки, пр.Гагарина, 9к.2	f	large
68658	74656	114	Псковская область, Великие Луки, пр.Гагарина, 5	f	large
68678	74677	135	Псковская область, Великие Луки, пр. Гагарина, 128, МОУ СОШ №6	f	large
68677	74676	134	Псковская область, Великие Луки, пр. Гагарина, 128	f	large
68644	74642	99	Псковская область, Великие Луки, площадь Юбилейная, 4	f	large
68645	74642	100	Псковская область, Великие Луки, площадь Юбилейная, 4	f	large
68663	74661	119	Псковская область, Великие Луки, площадь Калинина, 6А	f	large
68662	74660	118	Псковская область, Великие Луки, площадь Калинина, 6а	f	large
68650	74647	105	Псковская область, Великие Луки, переулок Некрасова, 7	f	large
113352	74651	109	Псковская область, Великие Луки, пер.Некрасова, 10	f	medium
68639	74636	93	Псковская область, Великие Луки, наб.Новослоболдская, 24, Строительный коледж	f	large
134670	94995	101	Псковская область, Великие Луки, Юбилейная, 2, СОШ№1	f	large
68669	74668	126	Псковская область, Великие Луки, Щорса, 90	f	large
68647	74644	102	Псковская область, Великие Луки, Третьей Ударной Армии, 69к1	f	large
68651	74648	106	Псковская область, Великие Луки, Половская, 3	f	large
68657	74655	113	Псковская область, Великие Луки, Первомайская, 16/2	f	large
68641	74638	95	Псковская область, Великие Луки, Парковая, 2, МОУ Кадетская школа	f	large
68659	74657	115	Псковская область, Великие Луки, Октябрьский проспект, 28/13	f	large
68655	74653	111	Псковская область, Великие Луки, Октябрьский проспект, 50	f	large
113351	74640	97	Псковская область, Великие Луки, Новосокольническая, 1	f	medium
68666	74664	122	Псковская область, Великие Луки, Малышева, 13	f	large
68668	74667	125	Псковская область, Великие Луки, М.Кузьмина, 20	f	large
68652	74649	107	Псковская область, Великие Луки, Ленина площадь, 3	f	large
68660	74658	116	Псковская область, Великие Луки, К.Зверева, 29	f	large
68656	74654	112	Псковская область, Великие Луки, К.Зверева, 24/27	f	large
68640	74637	94	Псковская область, Великие Луки, Зелёная, 7	f	large
68670	74669	127	Псковская область, Великие Луки, Заслонова, 42а, Детский сад № 16 «Березка»	f	large
68664	74662	120	Псковская область, Великие Луки, Заслонова, 42а	f	large
68674	74672	131	Псковская область, Великие Луки, Дружбы, 23к2	f	large
68673	74671	130	Псковская область, Великие Луки, Дружбы, 33/20	f	large
68672	74671	129	Псковская область, Великие Луки, Дружбы, 33/20	f	large
68649	74646	104	Псковская область, Великие Луки, Горная, 3	f	large
68676	74675	133	Псковская область, Великие Луки, Глинки, 38, ГОУ НПО ПЛ №8	f	large
68675	74673	132	Псковская область, Великие Луки, Глинки, ГОУ НПО ПЛ №5	f	large
68648	74645	103	Псковская область, Великие Луки, Гастелло, 8	f	large
68667	74666	124	Псковская область, Великие Луки, Гагарина проспект, 61	f	large
68654	74652	110	Псковская область, Великие Луки, Витебская, 2	f	large
68643	74641	98	Псковская область, Великие Луки, Винатовского, 10/2, ВГСХА	f	large
113765	75173	650	Псковская область, Усвятский район, село Шершни, Бывшее здание администрации с/п	f	small
113757	75165	642	Россия, Ярославская область, Брейтовский район, поселок Чурилово	t	small
113761	75169	646	Россия, Смоленская область, Краснинский район, поселок Церковище	f	small
68775	75163	640	Псковская область, Усвятский район, поселок Усвяты, Карла Маркса, 17	f	large
113756	75164	641	Псковская область, Усвятский район, поселок Усвяты, 25 Октября, 77	f	small
113758	75166	643	Россия, Псковская область, Усвятский район, село Узкое	f	small
113759	75167	644	Россия, Псковская область, Усвятский район, село Удвяты	f	small
113763	75171	648	Россия, Псковская область, Усвятский район, село Стеревнево	f	small
113764	75172	649	Россия, Псковская область, Усвятский район, село Северики	t	small
113446	74804	268	Россия, республика Башкортостан, деревня Алексеевка	f	small
113760	75168	645	Россия, Московская область, Сергиево-Посадский район, деревня Адамово	t	small
113657	75043	513	Псковская область, Стругокрасненский район, село Цапелька, Новосельская, 16	f	small
113661	75047	517	Псковская область, Стругокрасненский район, село Хредино, Заречная, 10	f	small
113645	75028	498	Псковская область, Стругокрасненский район, поселок Струги-Красные, Сосновая, 1А	f	small
68745	75030	500	Псковская область, Стругокрасненский район, поселок Струги-Красные, Советская, 14	f	large
68744	75029	499	Псковская область, Стругокрасненский район, поселок Струги-Красные, Мира, 8А	f	large
113646	75032	502	Псковская область, Стругокрасненский район, поселок Струги-Красные, Жертв Революции, 7А	f	medium
113653	75039	509	Псковская область, Стругокрасненский район, село Сиковицы, Центральная, 7	f	small
113658	75044	514	Россия, Псковская область, Стругокрасненский район, село Ротный Двор	t	small
113650	75036	506	Псковская область, Стругокрасненский район, село Ровное, Народная, 20-а	f	small
113651	75037	507	Псковская область, Стругокрасненский район, село Пятчино, Владимира Ислентьева, 6	f	small
113453	74811	275	Россия, Красноярский край, деревня Погорелка	f	small
113680	75064	539	Россия, Ленинградская область, Лужский район, деревня Новоселье	f	small
113654	75040	510	Псковская область, Стругокрасненский район, село Новоселье, Евстафьева, 1	f	medium
113656	74951	512	Псковская область, Стругокрасненский район, село Молоди, Молодейская, 51	t	small
113377	74718	172	Россия, Псковская область, Псковский район	f	medium
113660	75046	516	Псковская область, Стругокрасненский район, село Лудони, Школьная, 3	f	small
113659	75045	515	Россия, Псковская область, Стругокрасненский район, село Катежно	t	small
113655	75041	511	Псковская область, Стругокрасненский район, село Заполье, Школьная, 2	t	small
113413	74758	222	Псковская область, Стругокрасненский район, село Заклинье	f	small
113591	74970	440	Россия, Псковская область, Стругокрасненский район, село Загорье	t	small
113652	75038	508	Псковская область, Стругокрасненский район, село Ждани, Труда, 7	f	small
113721	75119	593	Псковская область, Себежский район, село Чернея	f	small
113715	75111	586	Россия, Псковская область, Себежский район, село Ульяновщина	f	medium
113724	75122	596	Россия, Псковская область, Себежский район, озеро Себежское	f	small
113716	75112	587	Россия, Псковская область, Себежский район, село Техомичи	t	small
113732	75132	605	Россия, Псковская область, Себежский район, село Сутоки	f	small
113711	75106	581	Псковская область, Себежский район, Себеж, переулок Почтовый, 7а	f	medium
113712	75107	582	Псковская область, Себежский район, Себеж, Ленинская, 51	f	medium
113710	75105	580	Псковская область, Себежский район, Себеж, Красноармейская, 15	f	medium
68760	75104	579	Псковская область, Себежский район, Себеж, 7-го Ноября, 21-а	f	large
113720	75118	592	Россия, Псковская область, Себежский район	t	small
113735	75136	608	Россия, Псковская область, Себежский район, село Мостище	f	small
113358	74687	144	Псковская область, Себежский район, село Лопатово, 76	f	medium
113714	75110	585	Россия, Псковская область, Себежский район, село Кузнецовка	f	medium
113723	75121	595	Псковская область, Себежский район, Кортеньки	t	small
113734	75135	607	Россия, Псковская область, Себежский район, село Кицково	f	small
113733	75133	606	Россия, Псковская область, Себежский район, село Исаково	f	small
113730	75130	603	Псковская область, Себежский район, поселок Идрица, Учебный городок	f	medium
113731	75131	604	Псковская область, Себежский район, поселок Идрица, Островского, 1а	t	medium
113729	75129	602	Псковская область, Себежский район, поселок Идрица, Ленина, 18	f	medium
68763	75128	601	Псковская область, Себежский район, поселок Идрица, Ленина, 28	f	large
113718	75116	590	Россия, Псковская область, Себежский район	f	small
113726	75125	598	Псковская область, Себежский район, село Дубровка	f	small
113418	74766	230	Псковская область, Себежский район, село Дубровка, Центральная, 27	f	small
113719	75117	591	Псковская область, Себежский район, село Долосцы	t	small
113717	75115	589	Россия, Псковская область, Себежский район	f	small
113722	75120	594	Псковская область, Себежский район, село Глембочино, Муниципальное образование Себежское	f	small
113736	75137	609	Россия, Псковская область, Себежский район, село Галузино	t	small
113727	75126	599	Россия, Псковская область, Себежский район, село Бояриново	t	small
113737	75146	620	Псковская область, Себежский район, село Борки, Ленина, 19	f	medium
113725	75123	597	Псковская область, Себежский район, село Борисенки, Муниципальное образование Себежское	f	small
113728	75127	600	Россия, Псковская область, Себежский район, село Александрово	t	small
113504	74872	335	Псковская область, Пыталовский район, д.Скорды, административное здание с/п Носовская волость	f	small
113500	74868	331	Псковская область, Пыталовский район, село Стехны, Административное здание с/п Утроинская волость	f	small
113497	74864	328	Россия, Псковская область, Пыталовский район, село Скангали	t	small
113501	74869	332	Псковская область, Пыталовский район, Пыталово, Пушкинская, 6	f	medium
113506	74874	337	Псковская область, Пыталовский район, село Мирный, Административное здание с/п Линовская волость	t	small
113505	74873	336	Россия	f	small
113444	74802	266	Россия, республика Башкортостан, Уфа, деревня Карпово	f	medium
113498	74866	329	Псковская область, Пыталовский район, село Емилово, административное здание с/п Гавровская волость	f	small
113495	74862	326	Россия, Псковская область, Пыталовский район, село Вышгородок	f	medium
113499	74867	330	Россия, Псковская область, Пыталовский район, село Бороусы	f	small
113502	74870	333	Россия, Псковская область, Пыталовский район, село Белорусский	f	medium
113416	74764	228	Псковская область, Пушкиногорский район, село Сорокино, Лесная, 1	f	small
113518	74882	349	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Совхозный переулок, 13	f	small
113512	74878	343	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Садовая, 1	f	medium
113515	74865	346	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Пушкинская, 42	f	small
113513	74865	344	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Пушкинская, 42	f	medium
113511	74876	342	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Новоржевская, 23	f	medium
113508	74876	339	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Новоржевская, 23	f	medium
113510	74877	341	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Лермонтова, 13	f	medium
113509	74877	340	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Лермонтова, 13	f	medium
113507	74875	338	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Ленина, 5	f	medium
113514	74879	345	Псковская область, Пушкиногорский район, поселок Пушкинские Горы, Больничный городок, 14	f	medium
113521	74885	352	Псковская область, Пушкиногорский район, село Поляне, Советская, 7	f	small
113519	74883	350	Псковская область, Пушкиногорский район, село Подкрестье, 14	f	medium
113503	74871	334	Россия, Тверская область, Калязинский район, поселок Носово	f	small
113517	74881	348	Псковская область, Пушкиногорский район, село Козляки, административное здание ОАО Белогуль	f	small
113522	74886	353	Псковская область, Пушкиногорский район, село Исса, Центральная, 2	f	small
113520	74884	351	Псковская область, Пушкиногорский район, село Горелик, 85	f	small
113584	74963	433	Россия, Нижегородская область, Воскресенский район, село Богданово	f	small
113516	74880	347	Россия, Псковская область, Пушкиногорский район, село Блажи	f	small
68733	74921	387	Псковская область, Пустошкинский район, село Яссы, Помещение библиотеки	t	large
113561	74933	399	Россия, Псковская область, Пустошкинский район, село Щукино	f	small
113552	74924	390	Россия, Псковская область, Пустошкинский район, село Шалахово	f	small
113556	74928	394	Россия, Псковская область, Пустошкинский район, село Чурилово	f	small
113644	75027	497	Россия, Тверская область, Бологовский район, поселок Сопки	t	small
113558	74930	396	Псковская область, Пустошкинский район, село Соино, Сельский Дом культуры	t	small
113560	74932	398	Россия, Псковская область, Пустошкинский район, село Сергейцево	f	small
113555	74927	393	Россия, Псковская область, Пустошкинский район, село Ребле	t	small
68732	74917	384	Псковская область, Пустошкинский район, Пустошка, Октябрьская , 55	f	large
113548	74919	385	Псковская область, Пустошкинский район, Пустошка, Октябрьская, 34а, МОУ ДО Детско-юношеская спортивная школа	f	medium
113550	74922	388	Россия, Псковская область, Пустошкинский район, село Поддубье	f	medium
113682	75066	541	Россия, Псковская область, Пустошкинский район, село Ореховно	f	small
113563	74935	401	Россия, Псковская область, Пустошкинский район, село Криуха	t	small
113562	74934	400	Россия, Псковская область, Пустошкинский район, село Красное	f	small
113559	74931	397	Россия, Псковская область, Пустошкинский район, село Копылок	f	small
113553	74925	391	Псковская область, Пустошкинский район, село Забелевица, здание администрации	f	small
113557	74929	395	Россия, Псковская область, Пустошкинский район, село Долосцы	f	small
113551	74923	389	Россия, Псковская область, Пустошкинский район, село Гультяи	f	small
113554	74926	392	Россия, Псковская область, Пустошкинский район, село Алушково	f	small
113549	74920	386	Псковская область, Пустошкинский район, село Алоль, Здание администрации	f	medium
113755	75162	639	Псковская область, Псковский район, село Чернецово, 95	t	small
113422	74770	234	Псковская область, Псковский район, село Чернецово, 4, Административный центр	f	small
113669	75058	528	Россия, Ярославская область, Гаврилов-Ямский район, поселок Чернево	f	medium
68690	74715	169	Псковская область, Псковский район, деревня Череха	f	large
68689	74711	166	Псковская область, Псковский район, село Тямша, Солнечная, 1	f	large
68688	74710	165	Псковская область, Псковский район, село Тямша, Молодежная, 2	f	large
113371	74707	162	Россия, Псковская область, Псковский район	f	medium
113370	74706	161	Псковская область, Псковский район, Теребище	f	small
113367	74701	157	Россия, Псковская область, Псковский район	f	small
68691	74717	171	Россия, Псковская область, Псковский район	f	large
113369	74704	160	Псковская область, Псковский район, село Середка, Родионова, 10	f	medium
68687	74703	159	Псковская область, Псковский район, село Середка, Пушкинская, 42	f	large
113360	74689	146	Псковская область, Псковский район, село Селихново	f	small
68681	74680	138	Псковская область, Псковский район, село Родина, Юбилейная, 3	f	large
68682	74682	140	Псковская область, Псковский район, село Родина, Владимирская, 3 В	f	large
113376	74716	170	Россия, Псковская область, Псковский район	f	medium
113373	74709	164	Псковская область, Псковский район, село Подборовье	f	small
68686	74696	152	Россия, Псковская область, Псковский район	f	large
68685	74694	151	Россия, Псковская область, Псковский район	f	large
113378	74719	173	Псковская область, Псковский район, село Остров Залит	t	small
68683	74692	149	Псковская область, Псковский район, село Неелово 1-е, Юбилейная, 7	f	large
113368	74702	158	Россия, Псковская область, Псковский район	f	small
113372	74708	163	Россия, Псковская область, Псковский район	t	small
113361	74690	147	Россия, Псковская область, Псковский район	f	medium
113359	74688	145	Псковская область, Псковский район, село Карамышево, Советская, 3	f	medium
113362	74691	148	Псковская область, Псковский район, село Зайцево, 29	f	small
68679	74678	136	Псковская область, Псковский район, село Ершово, Коровина, 11, МОУ Остенская средняя общеобразовательная школа	f	large
68684	74693	150	Псковская область, Псковский район, село Дуброво	f	large
113375	74713	168	Псковская область, Псковский район, деревня Горнево	f	small
113588	74967	437	Россия, Тверская область, Бологовский район, поселок Гоголево	f	small
113366	74700	156	Псковская область, Псковский район, село Гверздонь, Центральная, 19	f	small
113356	74684	142	Псковская область, Псковский район, село Выставка, Центральная, 14	f	small
113365	74699	155	Псковская область, Псковский район, село Верхолино, Красных Партизан, 10	f	medium
113363	74697	153	Псковская область, Псковский район, село Ваулино, Строителей, 261	f	medium
113357	74686	143	Россия, Псковская область, Псковский район	f	medium
113355	74683	141	Россия, Псковская область, Псковский район	f	small
113374	74712	167	Псковская область, Псковский район, село Адворицы, Школьная, 1	t	small
113699	75092	566	Псковская область, Порховский район, село Ясно	f	small
113691	75083	558	Россия, Псковская область, Порховский район	f	small
113708	75102	577	Псковская область, Порховский район, село Хилово	f	medium
113709	75103	578	Россия, Псковская область, Порховский район	f	small
113703	75095	570	Россия, Псковская область, Порховский район	f	small
113697	75090	564	Псковская область, Порховский район, село Терептино	f	small
68762	75114	588	Псковская область, Порховский район, село Сосновый Бор	f	large
68759	75101	576	Россия, Псковская область, Порховский район	f	large
113707	75100	575	Псковская область, Порховский район, село Пуково	f	medium
68757	75081	556	Псковская область, Порховский район, Порхов, Порховская, 3	f	large
68753	75077	552	Псковская область, Порховский район, Порхов, Плеханова, 6	f	large
68756	75080	555	Псковская область, Порховский район, Порхов, Мебельная, 7	f	large
68754	75078	553	Псковская область, Порховский район, Порхов, Ленина, 14-А	f	large
113698	75091	565	Псковская область, Порховский район, село Попадинка	f	medium
68758	75098	573	Россия, Псковская область, Порховский район	f	large
113705	75097	572	Псковская область, Порховский район, село Павы	f	medium
113704	75096	571	Россия, Псковская область, Порховский район	f	small
113696	75089	563	Россия, Псковская область, Порховский район	f	small
113702	75085	569	Россия, Псковская область, Порховский район	t	small
113700	75093	567	Псковская область, Порховский район, село Логовино	f	small
113581	74962	430	Россия, Владимирская область, Александровский район, поселок Иваньково	f	small
113695	75088	562	Россия, Псковская область, Порховский район	f	medium
113683	75067	542	Россия, Новгородская область, Старорусский район, село Должицы	f	small
113693	75086	560	Псковская область, Порховский район, село Гора	t	small
113701	75094	568	Россия, Псковская область, Порховский район	f	medium
113692	75084	559	Россия, Псковская область, Порховский район	f	small
113694	75087	561	Псковская область, Порховский район, Боровичи	f	medium
113690	75082	557	Псковская область, Порховский район, село Береза	f	small
113706	75099	574	Россия, Псковская область, Порховский район	t	small
113684	75069	544	Псковская область, Плюсский район, поселок Плюсса, Победы, 46	f	medium
68750	75068	543	Псковская область, Плюсский район, поселок Плюсса, Ленина, 16	f	large
113685	75070	545	Россия, Псковская область, Плюсский район, село Нежадово	f	small
113681	75065	540	Россия, Псковская область, Плюсский район, село Ляды	f	medium
113687	75072	547	Псковская область, Плюсский район, село Курея, Центральная, 6	t	small
113686	75071	546	Россия, Псковская область, Плюсский район, село Кошелевицы	f	small
113679	75063	538	Россия, Псковская область, Плюсский район, село Заянье	f	small
68751	75075	550	Псковская область, Плюсский район, поселок Заплюсье, Дом культуры	f	large
113688	75073	548	Псковская область, Плюсский район, село Андромер, сельский клуб	t	small
113381	74723	177	Псковская область, Печорский район, село Ротово, Дом культуры	f	medium
113384	74685	187	Псковская область, Печорский район, село Подлесье, Митковицкая основная школа	f	small
68696	74576	181	Псковская область, Печорский район, Печоры, Свободы, 27	f	large
68695	74726	180	Псковская область, Печорский район, Печоры, Мира, 19	f	large
113382	74606	183	Псковская область, Печорский район, Печоры, Мелиораторов, 11а	f	medium
68694	74725	179	Псковская область, Печорский район, Печоры, Ленина, 7	f	large
68698	74622	184	Псковская область, Печорский район, Печоры, Индустриальная, 13	f	large
113766	75174	651	Псковская область, Печорский район, Печоры, Заводская, 1, здание административно-бытового корпуса ООО Евро-Керамика	f	\N
68699	74630	185	Псковская область, Печорский район, Печоры, Заводская, 6	f	large
113385	74695	188	Россия, Псковская область, Печорский район, село Паниковичи	f	medium
68692	74721	175	Псковская область, Печорский район, поселок Новый Изборок, Новоизборская средняя школа	f	large
113380	74722	176	Псковская область, Печорский район, поселок Новый Изборок, Октябрьская, 21, Ясли-сад Сказка	f	medium
113387	74727	190	Псковская область, Печорский район, село Лавры, Комсомольская, 6, Дом культуры	f	medium
113379	74720	174	Псковская область, Печорский район, село Крупп, Круппская основная школа	f	medium
113388	74728	191	Псковская область, Печорский район, село Киршино, Дом культуры	f	medium
68693	74724	178	Псковская область, Печорский район, село Изборск, Псковская, 31а, Изборский лицей	f	large
113523	74887	354	Псковская область, Печорский район, село Велье, Центральная, 28	f	small
113401	74743	205	Псковская область, Палкинский район, д.Вернявино	f	medium
113643	75026	496	Россия, Ленинградская область, Тихвинский район, деревня Шейкино	f	small
113390	74731	194	Псковская область, Палкинский район, село Слопыгино	f	small
113400	74742	204	Псковская область, Палкинский район, поселок Палкино, Сельский дом культуры	f	small
113399	74741	203	Псковская область, Палкинский район, поселок Палкино, Сельский дом культуры	f	small
68700	74729	192	Псковская область, Палкинский район, поселок Палкино, Островская, 14	f	large
113395	74737	199	Псковская область, Палкинский район, село Новая Уситва	f	small
113394	74735	198	Псковская область, Палкинский район, село Качаново	f	medium
113392	74733	196	Псковская область, Палкинский район, село Васильево	f	small
113456	74814	278	Россия, Псковская область, Островский район, село Шики	f	small
113437	74795	259	Россия, Псковская область, Островский район, село Черепягино	t	small
113458	74816	280	Россия, Псковская область, Островский район, село Спиры	t	small
113433	74782	246	Россия	f	small
113524	74888	355	Россия, Псковская область, Островский район, село Рубилово	f	small
113438	74796	260	Россия, Псковская область, Островский район, село Покаты	f	small
113457	74815	279	Россия, Псковская область, Островский район, село Подмогилье	t	small
113586	74965	435	Россия, Новгородская область, Холмский район, село Подберезье	f	medium
68710	74784	248	Россия, Псковская область, Островский район, Остров	f	large
113432	74781	245	Псковская область, Островский район, Остров, Фестивальная, 28-а	f	medium
68709	74779	243	Псковская область, Островский район, Остров, Фестивальная, Дом офицеров	f	large
68717	74793	257	Псковская область, Островский район, Остров, Тимура Апакидзе, 3	f	large
68713	74787	251	Псковская область, Островский район, Остров, Пригородная, 3	f	large
68711	74785	249	Псковская область, Островский район, Остров, Освобождения, 1	f	large
113435	74790	254	Псковская область, Островский район, Остров, Ветеранов войны, 60	f	small
68716	74791	255	Псковская область, Островский район, Остров, Б.Пионерская, 47	f	large
68718	74794	258	Псковская область, Островский район, Остров, Авиационная, 8	f	large
68714	74788	252	Псковская область, Островский район, Остров, 25 Октября, 51	f	large
68715	74789	253	Псковская область, Островский район, Остров, Б.Пионерская, 2	f	large
113642	75025	495	Россия, Московская область, Подольский район, деревня Наумово	f	small
113436	74792	256	Россия, Псковская область, Островский район, село Малая Губа	f	small
113455	74813	277	Псковская область, Островский район, село Лаврово	f	small
113447	74805	269	Россия, Нижегородская область, Павловский район, село Крюки	f	small
113441	74799	263	Россия, Ленинградская область, Тихвинский район, деревня Заборовье	f	small
113440	74798	262	Россия, Псковская область, Островский район, село Елины	f	small
113443	74801	265	Россия, Псковская область, Островский район, село Дуловка	f	small
113439	74797	261	Россия, Московская область, Раменский район, деревня Дубки	f	small
113449	74807	271	Россия, Московская область, Одинцовский район, деревня Дарьино	t	small
113448	74806	270	Россия, Псковская область, Островский район, село Гораи	f	small
113454	74812	276	Псковская область, Островский район, село Воронцово	f	small
113451	74809	273	Россия, Псковская область, Островский район, село Влазово	f	small
113450	74808	272	Псковская область, Островский район, село Большое Приезживо	f	small
113532	74902	368	Псковская область, Опочецкий район, село Разувайка, административное здание Пригородного лесничества	t	small
113538	74907	374	Россия, Ульяновская область, Барышский район, село Приозерный	f	small
68731	74896	362	Псковская область, Опочецкий район, Опочка, Стученко, 45	f	large
113526	74890	357	Псковская область, Опочецкий район, Опочка, Набережная, 3	f	medium
68729	74894	360	Псковская область, Опочецкий район, Опочка, Ленина, 64	f	large
68728	74893	359	Псковская область, Опочецкий район, Опочка, Ленина, 20	f	large
113528	74898	364	Псковская область, Опочецкий район, Опочка, Красногородская, 31А	f	medium
68727	74891	358	Псковская область, Опочецкий район, Опочка, Коммунальная, 4А	f	large
68730	74895	361	Псковская область, Опочецкий район, Опочка, Дзержинского, 62	f	large
113527	74897	363	Псковская область, Опочецкий район, Опочка, Гагарина, 65	f	medium
113530	74900	366	Псковская область, Опочецкий район, Опочка, Басковская, 50	f	medium
113543	74912	379	Псковская область, Опочецкий район, село Норкино, административное здание СП Глубоковская волость	f	small
113537	74906	373	Псковская область, Опочецкий район, село Матюшкино, административное здание СП Матюшкинская волость	f	small
113534	74892	370	Россия, Курганская область, Макушинский район, город Макушино	f	medium
113531	74901	367	Россия, Псковская область, Опочецкий район, село Ляпуны	f	small
113546	74915	382	Россия, Костромская область, Октябрьский район, поселок Лобово	f	small
113540	74909	376	Псковская область, Опочецкий район, село Лаптево, административное здание СП Болгатовская волость	f	small
113434	74783	247	Россия, Псковская область, Опочецкий район, село Кахново	t	small
113545	74914	381	Псковская область, Опочецкий район, село Звоны, административное здание СП Звонская волость	f	small
113542	74911	378	Псковская область, Опочецкий район, село Духново, административное здание СП Болгатовская волость	f	small
113544	74913	380	Псковская область, Опочецкий район, село Глубокое, административное здание СП Глубоковская волость	f	small
113536	74905	372	Россия, Новгородская область, Мошенской район, село Варыгино	f	small
113541	74910	377	Псковская область, Опочецкий район, село Болгатово, административное здание СП Болгатовская волость	f	small
113539	74908	375	Псковская область, Опочецкий район, село Белки	f	small
113587	74966	436	Россия, Тульская область, Ленинский район, поселок Барсуки	f	small
113535	74904	371	Псковская область, Опочецкий район, село Барсаново, здание СПК Опочецкий	t	small
113749	75155	632	Псковская область, Опочецкий район, село Барканы, 10	f	small
113547	74916	383	Псковская область, Опочецкий район, село Балахи, административное здание СП Звонская волость	f	small
113572	74948	418	Россия, Псковская область, Новосокольнический район, село Шахниха	f	medium
113565	74941	409	Россия, Псковская область, Новосокольнический район, село Харино-Бор	f	medium
113574	74952	420	Россия, Псковская область, Новосокольнический район, село Старосокольники	f	small
113578	74956	424	Россия, Псковская область, Новосокольнический район, село Руново	f	small
113568	74944	414	Псковская область, Новосокольнический район, село Ременье	f	small
113577	74955	423	Россия, Псковская область, Новосокольнический район, село Островки	f	small
113573	74949	419	Россия, Псковская область, Новосокольнический район, село Окни	f	small
68736	74938	406	Псковская область, Новосокольнический район, Новосокольники, Тихмянова, 10	f	large
68734	74936	404	Псковская область, Новосокольнический район, Новосокольники, Тихмянова, 8	f	large
68735	74937	405	Псковская область, Новосокольнический район, Новосокольники, Партизанская, 14	f	large
113564	74940	408	Псковская область, Новосокольнический район, Новосокольники, Загородная, 3а	f	medium
68737	74939	407	Псковская область, Новосокольнический район, Новосокольники, Воровского, 23	f	large
113570	74946	416	Россия, Псковская область, Новосокольнический район, село Насва	f	medium
113571	74947	417	Россия, Псковская область, Новосокольнический район, село Назимово	f	small
113569	74945	415	Россия, Псковская область, Новосокольнический район, село Маево	f	medium
113592	74971	441	Россия, Псковская область, Новосокольнический район, село Липшани	t	small
113575	74953	421	Россия, Псковская область, Новосокольнический район, село Захарино	f	small
113576	74954	422	Россия, Псковская область, Новосокольнический район, село Демя	t	small
113567	74943	412	Россия, Псковская область, Новосокольнический район, село Горожане	f	small
113566	74942	410	Россия, Псковская область, Новосокольнический район, село Вяз	f	small
113481	74846	308	Россия, Псковская область, Новоржевский район, село Стехново	f	small
113480	74845	307	Россия, Псковская область, Новоржевский район, село Орша	f	medium
68723	74837	300	Псковская область, Новоржевский район, Новоржев, Некрасова, 28	f	large
113479	74844	306	Россия, Псковская область, Новоржевский район, село Макарово	f	medium
113478	74843	305	Россия, Псковская область, Новоржевский район, село Жадрицы	f	medium
113452	74810	274	Россия, Московская область, Ленинский район, деревня Городище	f	medium
113477	74842	304	Псковская область, Новоржевский район, село Выбор, 8, МОУ Выборская общеобразовательная школа	f	medium
113476	74841	303	Псковская область, Новоржевский район, село Вехно	f	small
113475	74840	302	Россия, Псковская область, Новоржевский район, село Веска	f	medium
113474	74839	301	Россия, Псковская область, Новоржевский район, село Барута	f	small
113748	75154	631	Псковская область, Невельский район, д.Урочище Дубровка, 43	t	medium
113743	75149	626	Псковская область, Невельский район, село Щербино, 26	f	small
113740	75124	623	Псковская область, Невельский район, село Чернуха, 46	f	small
113750	75156	633	Псковская область, Невельский район, село Ушаково, 2	t	small
68774	75161	638	Псковская область, Невельский район, село Усть-Долыссы, Ленинградская, 19 А	f	large
113754	75160	637	Псковская область, Невельский район, село Туричино, Центральная, 53	f	medium
113752	75158	635	Псковская область, Невельский район, село Трехалево, 29	f	small
113742	75148	625	Псковская область, Невельский район, село Рыколево, 3	f	small
113753	75159	636	Псковская область, Невельский район, село Рукавец, 1	t	small
113739	75113	622	Псковская область, Невельский район, село Опухлики, 41	f	medium
113747	75153	630	Псковская область, Невельский район, село Новохованск, Ленина, 22	f	medium
68765	75139	611	Псковская область, Невельский район, Невель, М.Маметовой, 5	f	large
68764	75138	610	Псковская область, Невельский район, Невель, М.Маметовой, 78	f	large
68772	75145	618	Псковская область, Невельский район, Невель, Ленина, 7	f	large
68769	75142	615	Псковская область, Невельский район, Невель, Ленина, 5	f	large
68767	75141	613	Псковская область, Невельский район, Невель, Красный переулок, 3	f	large
68770	75143	616	Псковская область, Невельский район, Невель, Комсомольская, 4	f	large
113751	75157	634	Псковская область, Невельский район, село Ловец, 9	f	small
113745	75151	628	Псковская область, Невельский район, село Лобок, 21	f	small
113744	75150	627	Псковская область, Невельский район, село Лехово, Центральная, 10	f	small
113638	75021	491	Россия, Московская область, Подольский район, деревня Кресты	f	small
113582	74918	431	Россия, Тверская область, Спировский район, поселок Юхово	f	small
113580	74961	429	Россия, Псковская область, Локнянский район, село Рысино	f	medium
113590	74969	439	Россия, Псковская область, Локнянский район, село Прискуха	f	small
113583	74950	432	Россия, Псковская область, Локнянский район, село Миритиницы	f	small
68738	74957	425	Псковская область, Локнянский район, поселок Локня, Социалистическая, 32	f	large
68739	74958	426	Псковская область, Локнянский район, поселок Локня, Первомайская, 44	f	large
68740	74959	427	Псковская область, Локнянский район, поселок Локня, Октябрьская, 14	f	large
113579	74960	428	Россия, Псковская область, Локнянский район, село Крестилово	f	medium
113525	74889	356	Псковская область, Локнянский район, село Васильевское, Центральная, 18	f	small
113589	74968	438	Россия, Псковская область, Локнянский район, село Башово	f	small
113630	75016	483	Псковская область, Куньинский район, село Ушицы	f	medium
113636	75019	489	Россия, Псковская область, Куньинский район, село Усмынь	f	small
113632	74993	485	Россия, Псковская область, Куньинский район, село Слепнево	t	small
113634	75017	487	Россия, Псковская область, Куньинский район, село Пухново	f	small
113635	75018	488	Россия, Смоленская область, Ельнинский район, поселок Прихабы	f	small
113485	74838	314	Псковская область, Куньинский район, село Лукино	f	small
113627	75013	480	Псковская область, Куньинский район, поселок Кунья, переулок Новый, 1	f	small
113624	75010	477	Псковская область, Куньинский район, поселок Кунья, Полевая, 8а	f	small
113626	75012	479	Псковская область, Куньинский район, поселок Кунья, Дзержинского, 22	f	small
113623	75009	476	Псковская область, Куньинский район, поселок Кунья, Дзержинского, 108	f	medium
113622	75008	475	Псковская область, Куньинский район, поселок Кунья, Дзержинского, 17	f	medium
113625	75011	478	Псковская область, Куньинский район, поселок Кунья, Больничная, 9	f	medium
134672	94997	492	Псковская область, Куньинский район, село Каськово, админисирация сельского поселения Каськовская волость	f	small
113641	75024	494	Россия, Псковская область, Куньинский район, село Жижица	f	medium
113637	75020	490	Россия, Псковская область, Куньинский район, село Долговица	f	small
113631	74975	484	Россия, Псковская область, Куньинский район, село Встеселово	f	small
113629	75015	482	Псковская область, Куньинский район, село Боталово, 36, зд.ОООКр. знамя	f	small
134671	94996	481	Псковская область, Куньинский район, село Борок, 64фельдшерско-акушерский пункт	f	small
113746	75152	629	Псковская область, Красногородский район, село Усово, 56	f	small
113489	74855	318	Псковская область, Красногородский район, село Треньки, Здание сельской библиотеки	t	small
113483	74850	312	Россия, Московская область, Павлово-Посадский район, деревня Саурово	t	small
113490	74856	319	Псковская область, Красногородский район, село Покровское, Администрация муниципального образования Пограничная волость	f	small
113484	74825	313	Псковская область, Красногородский район, село Мыза, Центральная, 14	f	medium
113488	74854	317	Псковская область, Красногородский район, село Кресты, Администрация муниципального образования Пограничная волость	f	small
113482	74849	311	Псковская область, Красногородский район, поселок Красногородск, Школьная, 7	f	small
68725	74848	310	Псковская область, Красногородский район, поселок Красногородск, Советская, 50	f	large
68724	74847	309	Псковская область, Красногородский район, поселок Красногородск, Синерецкая, 39	f	large
113487	74853	316	Россия, Московская область, Красногорский район, поселок Архангельское, Ильинское шоссе, 4в	f	small
113491	74857	320	Псковская область, Красногородский район, село Золотово, Здание фельдшерско-акушерского пункта	t	small
113496	74863	327	Россия, Псковская область, Красногородский район, село Гавры	f	medium
113486	74852	315	Россия, Псковская область, Красногородский район, село Блясино	f	small
113403	74748	212	Россия, Псковская область, Дновский район, село Скугры	f	small
113407	74752	216	Псковская область, Дновский район, село Панкратово, административное здание ООО Панкратовское	f	small
113406	74751	215	Псковская область, Дновский район, село Морино	f	medium
113585	74964	434	Россия, Красноярский край, Бирилюсский район, поселок Михайлов Погост	f	medium
113404	74749	213	Псковская область, Дновский район, село Лукомо	f	small
113414	74759	223	Псковская область, Дновский район, село Искра	f	small
68703	74746	208	Псковская область, Дновский район, Дно, Энергетиков, 3	f	large
68701	74744	206	Псковская область, Дновский район, Дно, Омельянюка, 10	f	large
68702	74745	207	Псковская область, Дновский район, Дно, Ленина, 19	f	large
113408	74753	217	Псковская область, Дновский район, Дно, Космонавтов, 84	f	small
68705	14615	211	Псковская область, Дновский район, Дно, Бисениек, 10	f	large
113409	74754	218	Псковская область, Дновский район, село Дачное, Шоссейная, 42	f	small
113411	74756	220	Псковская область, Дновский район, село Гаврово	f	small
113410	74755	219	Россия	f	small
113405	74750	214	Псковская область, Дновский район, село Большое Юрково	f	small
113412	74757	221	Псковская область, Дновский район, село Белая	f	small
113424	74772	236	Псковская область, Дедовичский район, село Ясски, пер.Школьный, 2	f	small
113423	74771	235	Псковская область, Дедовичский район, село Станки, Центральная, 36	f	small
113419	74767	231	Псковская область, Дедовичский район, село Пожеревицы, 1-ая Советская, 44а	f	medium
113428	74776	240	Псковская область, Дедовичский район, село Погостище, Мира, 22	f	small
113415	74763	227	Псковская область, Дедовичский район, село Навережье, Центральная, 18	t	small
113425	74773	237	Псковская область, Дедовичский район, село Крутец, Центральная, 4	f	small
113430	74778	242	Псковская область, Дедовичский район, село Красные Горки, Советской Армии, 26	f	medium
113427	74775	239	Псковская область, Дедовичский район, село Дубишино, Центральная, 23	f	small
113426	74774	238	Псковская область, Дедовичский район, поселок Дедовичи, Энергетиков, 6	f	small
68707	74761	225	Псковская область, Дедовичский район, поселок Дедовичи, Энергетиков, 6	f	large
68706	74760	224	Псковская область, Дедовичский район, поселок Дедовичи, Пионерская, 10	f	large
68708	74762	226	Псковская область, Дедовичский район, поселок Дедовичи, Октябрьская, 11	f	large
113417	74765	229	Псковская область, Дедовичский район, село Горушка, Озёрная, 16	f	small
113421	74769	233	Псковская область, Дедовичский район, село Городовик, Торфяников, 1	t	small
113429	74777	241	Псковская область, Дедовичский район, село Вязье, Школьная, 7	f	medium
113675	71387	534	Россия, Псковская область, Гдовский район, поселок Ямм	f	medium
113670	75059	529	Россия, Ивановская область, Шуйский район, поселок Трутнево	f	medium
113667	75056	526	Псковская область, Гдовский район, Смуравьево-2, 16	t	medium
113673	74705	532	Россия, Псковская область, Гдовский район, село Самолва	f	small
113674	74851	533	Россия, Псковская область, Гдовский район, село Ремда	f	small
113677	75061	536	Россия, Псковская область, Гдовский район, село Полна	f	small
113663	75052	522	Россия, Псковская область, Гдовский район, село Полично	f	small
113668	75057	527	Россия, Ивановская область, Приволжский район, Плес	f	small
113678	75062	537	Псковская область, Гдовский район, село Первомайское	f	small
113676	75060	535	Псковская область, Гдовский район, село Партизанская	f	small
113672	75042	531	Россия, Московская область, Раменский район, деревня Островцы	f	small
113664	75053	523	Россия, Псковская область, Гдовский район, село Кануновщина	t	small
113386	74714	189	Псковская область, Гдовский район, село Залесье, Дом культуры	f	medium
68747	75048	518	Псковская область, Гдовский район, Гдов, Ленина, 14	f	large
68749	75050	520	Псковская область, Гдовский район, Гдов, Колхозная, 54	f	large
68748	75049	519	Псковская область, Гдовский район, Гдов, Карла Маркса, 53	f	large
113666	75055	525	Россия, Калужская область, Ульяновский район, поселок Вейно	t	small
113665	75054	524	Россия	f	medium
113607	74990	459	Псковская область, Великолукский район, пос. Нагорный, Лицей №, 24	f	medium
113600	74980	449	Псковская область, Великолукский район, д. Колюбаки, Мишагинский ФАП	f	small
113738	75147	621	Псковская область, Бежаницкий район, село Кошелево, 30 А	f	small
113619	75005	472	Псковская область, Великолукский район, село Шелково, Администрация сельского поселения	f	medium
113615	74999	468	Псковская область, Великолукский район, село Черпесса, Дом культуры	f	medium
113614	74998	467	Псковская область, Великолукский район, село Федорково, Плаксинский ФАП	f	small
113613	74997	466	Псковская область, Великолукский район, село Успенское, Администрация сельского поселения	f	medium
113611	74995	464	Псковская область, Великолукский район, село Урицкое, Дом культуры	f	small
113612	74996	465	Псковская область, Великолукский район, село Троица, школа	f	small
113596	74976	445	Псковская область, Великолукский район, село Тарасы, Библиотека	f	small
113617	75001	470	Псковская область, Великолукский район, село Суханово, Сухановский ФАП	f	small
113620	75006	473	Псковская область, Великолукский район, село Рыжково, Детский сад Ленок	f	medium
113597	74977	446	Псковская область, Великолукский район, село Русаново, Администрация сельского поселения	f	medium
113610	74994	463	Псковская область, Великолукский район, село Поречье, Администрация сельского поселения	f	medium
113609	74992	462	Псковская область, Великолукский район, село Поречье, Дом культуры	f	small
113594	74973	443	Псковская область, Великолукский район, село Полибино, Полибинский Дом культуры	f	small
113616	75000	469	Псковская область, Великолукский район, село Першино, школа	f	small
113606	74989	458	Псковская область, Великолукский район, село Переслегино, Дом культуры	f	medium
68743	74988	457	Псковская область, Великолукский район, село Переслегино, Администрация сельского поселения	f	large
113648	75034	504	Псковская область, Великолукский район, село Марьино, Центральная, 5	f	medium
113608	74991	461	Псковская область, Великолукский район, село Майкино, Детский сад Росинка	f	medium
68742	74985	454	Псковская область, Великолукский район, село Лычево, Администрация сельского поселения	f	large
113603	74984	453	Псковская область, Великолукский район, село Липец, бывшая школа	f	medium
113599	74979	448	Псковская область, Великолукский район, село Купуй, Администрация сельского поселения	f	medium
113649	75035	505	Россия, Псковская область, Великолукский район, село Костелево	t	small
113605	74987	456	Россия, Псковская область, Великолукский район	f	small
113741	75134	624	Псковская область, Великолукский район, село Иваново, 31	f	small
113598	74978	447	Псковская область, Великолукский район, село Иваново, школа	f	medium
68741	74983	452	Псковская область, Великолукский район, село Дубрава 1-я, школа	f	large
113602	74982	451	Псковская область, Великолукский район, село Дорожный, ДЭП №, 276	f	medium
113604	74986	455	Псковская область, Великолукский район, село Демидово, школа	f	small
113762	75170	647	Россия, Орловская область, Урицкий район, поселок Глазуново	f	small
113621	75007	474	Псковская область, Великолукский район, село Великополье, ФАП 	t	small
113601	74981	450	Псковская область, Великолукский район, село Булынино, Дом культуры	f	medium
113595	74974	444	Псковская область, Великолукский район, село Букрово 2-е, Администрация сельского поселения	f	small
113593	74972	442	Псковская область, Великолукский район, село Борки, администрация сельского поселения	f	medium
113618	75004	471	Псковская область, Великолукский район, село Баландино, Баландинский ФАП	f	medium
113473	74835	298	Россия, Псковская область, Бежаницкий район, село Шилово	f	small
113472	74834	297	Псковская область, Бежаницкий район, село Чихачево, Первомайская, 15	f	medium
113471	74833	296	Псковская область, Бежаницкий район, село Цевло, Советская, 1	f	small
113469	74831	294	Россия, Псковская область, Бежаницкий район, село Ублиска	f	small
113671	75003	530	Россия, Ярославская область, деревня Спицино	f	small
113420	74768	232	Псковская область, Бежаницкий район, село Сосонка, Центральная, 1	f	small
113470	74832	295	Россия, Псковская область, Бежаницкий район, село Сапрыгино	t	small
113468	74830	293	Россия, Псковская область, Бежаницкий район, село Махново	t	medium
113467	74829	292	Псковская область, Бежаницкий район, село Лющик, Октябрьская, 9	f	medium
113466	74828	291	Псковская область, Бежаницкий район, село Кудеверь, Школьная, 4-а	f	medium
113465	74827	290	Псковская область, Бежаницкий район, поселок Красный Луч, Советская, 26	f	medium
113689	75074	549	Псковская область, Бежаницкий район, село Заполье	f	small
113464	74826	289	Россия, Псковская область, Бежаницкий район, село Добрывичи	f	small
113463	74824	288	Россия, Псковская область, Бежаницкий район, село Дворцы	f	small
113442	74800	264	Россия, Псковская область, Бежаницкий район, поселок Гривы	t	small
113462	74823	287	Россия, Псковская область, Бежаницкий район, село Гора	t	small
113633	75002	486	Россия, Московская область, Волоколамский район, деревня Быково	f	small
68720	74821	285	Псковская область, Бежаницкий район, поселок Бежаницы, Смольная, 16	f	large
68721	74822	286	Псковская область, Бежаницкий район, поселок Бежаницы, Лары Михеенко, 20-а	f	large
68719	74820	284	Псковская область, Бежаницкий район, поселок Бежаницы, Зеленая, 16	f	large
113461	74819	283	Россия, Псковская область, Бежаницкий район, село Бардово	t	small
113460	74818	282	Россия, Псковская область, Бежаницкий район, село Ашево	f	medium
113459	74817	281	Россия, Псковская область, Бежаницкий район, село Аполье	t	small
112018	63545	316	Новгородская область, деревня Шолохово, МАУ Шолоховский сельский дом культуры	f	\N
86893	63615	385	Новгородская область, Пестовский район, Центральная, 68	f	small
112033	63560	331	Россия, Новгородская область, деревня Сырково, улица Пролетарская, 7а	f	\N
112110	63707	477	Новгородская область, Старая Русса, Пищевиков переулок, 8	f	\N
112107	63704	474	Новгородская область, Старая Русса, Ленинградская, 11	f	\N
112108	63705	475	Новгородская область, Старая Русса, Клары Цеткин, 41	f	\N
112095	63693	462	Новгородская область, Старая Русса, Карла Маркса, 24	f	\N
112103	63700	470	Новгородская область, Старая Русса, Карла Либкнехта, 22	f	\N
112098	63695	465	Новгородская область, Старая Русса, Володарского, 22	f	\N
112092	63690	459	Новгородская область, Старая Русса, Володарского, 10	f	\N
112065	63661	430	Новгородская область, Сольцы, проспект Советский, 11	f	medium
112024	63551	322	Новгородская область, деревня Слутка, 44	f	\N
68438	63634	403	Новгородская область, Пестово, Устюженское шоссе, 5	f	large
68434	63630	399	Новгородская область, Пестово, Устюженское шоссе, 27	f	large
68440	63636	405	Новгородская область, Пестово, Новгородская, 77	f	large
68441	63637	406	Новгородская область, Пестово, Боровичская, 92, административное здание филиала общества с ограниченной ответственностью «Межмуниципальное предприятие жилищно-коммунального хозяйства Новжилкоммунсервис» «Жилищно-коммунальное хозяйство Пестовского района»	f	large
68419	63576	347	Новгородская область, Окуловка, Театральная, 3	f	large
68417	63573	344	Новгородская область, Окуловка, Советская, 32А	f	large
68415	63571	342	Новгородская область, Окуловка, Николая Николаева, 34	f	large
111882	63414	166	Новгородская область, Малая Вишера, Карла Маркса, 18	f	medium
112030	63557	328	Россия, Новгородская область, деревня Григорово, улица Центральная, 6	f	\N
111986	63520	284	Россия, Новгородская область, Великий Новгород, улица Псковская, 50к2	f	\N
111960	63496	258	Россия, Новгородская область, Великий Новгород, улица Коровникова, 9к1	f	\N
111958	63496	256	Россия, Новгородская область, Великий Новгород, улица Коровникова, 9к1	f	\N
111943	63485	241	Россия, Новгородская область, Великий Новгород, улица Большая Санкт-Петербургская, 161	f	\N
111942	63485	240	Россия, Новгородская область, Великий Новгород, улица Большая Санкт-Петербургская, 161	f	\N
111930	63475	228	Россия, Новгородская область, Великий Новгород, улица Большая Дворцовая, 3	f	\N
111999	63528	297	Новгородская область, Великий Новгород, микрорайон Кречевицы, 79	f	\N
111945	63487	243	Новгородская область, Великий Новгород, микрорайон Кречевицы, 79	f	\N
111921	63466	219	Новгородская область, Великий Новгород, микрорайон Антоново, ГУ ФГБОУ ВПО НГУ им.Я.Мудрого	f	\N
111933	63478	231	Новгородская область, Великий Новгород, Яковлева, 15	f	\N
111941	63484	239	Новгородская область, Великий Новгород, Щусева, 12к2	f	\N
111935	63480	233	Новгородская область, Великий Новгород, Чудовская, 3	f	\N
111980	63514	278	Новгородская область, Великий Новгород, Чудинцева, 3	f	\N
111928	63473	226	Новгородская область, Великий Новгород, Фёдоровский Ручей, 19а	f	\N
111982	63516	280	Новгородская область, Великий Новгород, Троицкая, 13	f	\N
111924	63469	222	Новгородская область, Великий Новгород, Студенческая, 19	f	\N
111922	63467	220	Новгородская область, Великий Новгород, Студенческая, 5/1	f	\N
111959	63497	257	Новгородская область, Великий Новгород, Свободы, 14к2	f	\N
111954	63493	252	Новгородская область, Великий Новгород, Свободы, 14к2	f	\N
111949	63490	247	Новгородская область, Великий Новгород, Свободы, 6	f	\N
111948	63490	246	Новгородская область, Великий Новгород, Свободы, 6	f	\N
111929	63474	227	Новгородская область, Великий Новгород, Рогатица, 27/56	f	\N
111998	63463	296	Новгородская область, Великий Новгород, Рахманинова, 7	f	\N
111918	63463	216	Новгородская область, Великий Новгород, Рахманинова, 7	f	\N
111917	63463	215	Новгородская область, Великий Новгород, Рахманинова, 7	f	\N
111990	63522	288	Новгородская область, Великий Новгород, Псковская, 1	f	\N
111985	63519	283	Новгородская область, Великий Новгород, Псковская, 44к2	f	\N
111987	63518	285	Новгородская область, Великий Новгород, Псковская, 44к2	f	\N
112000	63518	298	Новгородская область, Великий Новгород, Псковская, 44к2	f	\N
111984	63518	282	Новгородская область, Великий Новгород, Псковская, 44к2	f	\N
111983	63517	281	Новгородская область, Великий Новгород, Прусская, 24	f	\N
111981	63515	279	Новгородская область, Великий Новгород, Прусская, 4	f	\N
111920	63465	218	Новгородская область, Великий Новгород, Парковая, 7	f	\N
112001	63529	299	Новгородская область, Великий Новгород, Октябрьская, 14	f	\N
111993	63524	291	Новгородская область, Великий Новгород, Октябрьская, 30	f	\N
111992	63524	290	Новгородская область, Великий Новгород, Октябрьская, 30	f	\N
111988	63521	286	Новгородская область, Великий Новгород, Октябрьская, 14	f	\N
111989	63521	287	Новгородская область, Великий Новгород, Октябрьская, 14	f	\N
111994	63525	292	Новгородская область, Великий Новгород, Новолучанская, 17	f	\N
111932	63477	230	Новгородская область, Великий Новгород, Новолучанская, 27	f	\N
111944	63486	242	Новгородская область, Великий Новгород, Новгородская, 6	f	\N
111974	63509	272	Новгородская область, Великий Новгород, Нехинская, 24	f	\N
111925	63470	223	Новгородская область, Великий Новгород, Московская, 30	f	\N
111946	63488	244	Новгородская область, Великий Новгород, Менделеева, 3	f	\N
111931	63476	229	Новгородская область, Великий Новгород, Людогоща, 4	f	\N
111969	63505	267	Новгородская область, Великий Новгород, Ломоносова, 22а	f	\N
111996	63500	294	Новгородская область, Великий Новгород, Ломоносова, 30	f	\N
111963	63500	261	Новгородская область, Великий Новгород, Ломоносова, 30	f	\N
111947	63489	245	Новгородская область, Великий Новгород, Ломоносова, 7а	f	\N
111950	63489	248	Новгородская область, Великий Новгород, Ломоносова, 7а	f	\N
111978	63512	276	Новгородская область, Великий Новгород, Кочетова, 23к2	f	\N
111977	63511	275	Новгородская область, Великий Новгород, Кочетова, 23к2	f	\N
111975	63510	273	Новгородская область, Великий Новгород, Кочетова, 28	f	\N
111973	63508	271	Новгородская область, Великий Новгород, Кочетова, 35п.4	f	\N
111970	63506	268	Новгородская область, Великий Новгород, Кочетова, 29к3	f	\N
111976	63506	274	Новгородская область, Великий Новгород, Кочетова, 29к3	f	\N
111964	63501	262	Новгородская область, Великий Новгород, Кочетова, 5к4	f	\N
111997	63527	295	Новгородская область, Великий Новгород, Космонавтов, 28	f	\N
111979	63513	277	Новгородская область, Великий Новгород, Коровникова, 15к2	f	\N
111957	63495	255	Новгородская область, Великий Новгород, Коровникова, 15к2	f	\N
111955	63494	253	Новгородская область, Великий Новгород, Коровникова, 11	f	\N
111956	63494	254	Новгородская область, Великий Новгород, Коровникова, 11	f	\N
111972	63507	270	Новгородская область, Великий Новгород, Зелинского, 30	f	\N
111971	63507	269	Новгородская область, Великий Новгород, Зелинского, 30	f	\N
111968	63504	266	Новгородская область, Великий Новгород, Зелинского, 15	f	\N
111967	63504	265	Новгородская область, Великий Новгород, Зелинского, 15	f	\N
111966	63503	264	Новгородская область, Великий Новгород, Зелинского, 6	f	\N
111965	63503	263	Новгородская область, Великий Новгород, Зелинского, 6	f	\N
111952	63492	250	Новгородская область, Великий Новгород, Зелинского, 42	f	\N
111953	63492	251	Новгородская область, Великий Новгород, Зелинского, 42	f	\N
111919	63464	217	Новгородская область, Великий Новгород, Державина, 6	f	\N
111995	63526	293	Новгородская область, Великий Новгород, Германа, 31	f	\N
35331	28985	330	Вологодская область, Вологда, Горького, 86А	f	large
111991	63523	289	Новгородская область, Великий Новгород, Великолукская, 17	f	\N
111934	63479	232	Новгородская область, Великий Новгород, Великая, 10	f	\N
111939	63483	237	Новгородская область, Великий Новгород, Большая Санкт-Петербургская, 118к3	f	\N
111940	63483	238	Новгородская область, Великий Новгород, Большая Санкт-Петербургская, 118к3	f	\N
111938	63482	236	Новгородская область, Великий Новгород, Большая Санкт-Петербургская, 94	f	\N
111937	63482	235	Новгородская область, Великий Новгород, Большая Санкт-Петербургская, 94	f	\N
111936	63481	234	Новгородская область, Великий Новгород, Большая Санкт-Петербургская, 46	f	\N
111927	63472	225	Новгородская область, Великий Новгород, Большая Московская, 37/9	f	\N
111926	63471	224	Новгородская область, Великий Новгород, Большая Московская, 70	f	\N
111923	63468	221	Новгородская область, Великий Новгород, Большая Московская, 53к2	f	\N
111914	63461	212	Новгородская область, Великий Новгород, Береговая, 48к3	f	\N
111962	63499	260	Россия, Новгородская область, Великий Новгород, Александра Корсунова проспект, 38	f	\N
111961	63498	259	Россия, Новгородская область, Великий Новгород, Александра Корсунова проспект, 38	f	\N
111951	63491	249	Россия, Новгородская область, Великий Новгород, Александра Корсунова проспект, 36к3	f	\N
111915	63462	213	Новгородская область, Великий Новгород, 20-го Января, 14	f	\N
111916	63462	214	Новгородская область, Великий Новгород, 20-го Января, 14	f	\N
68378	63320	73	Новгородская область, Валдай, просп.Комсомольский, 19/21	f	large
68375	63316	69	Новгородская область, Валдай, Студгородок, учебный корпус агротехнического техникума	f	large
111871	63331	84	Новгородская область, Валдай, Озёрная, 19	f	medium
68382	63325	78	Новгородская область, Валдай, Молотковская, 2	f	large
111869	63323	76	Новгородская область, Валдай, Комсомольский, 17	f	medium
68377	63319	72	Новгородская область, Валдай, Васильева проспект, 32а	f	large
68373	63270	22	Новгородская область, Боровичи, пл.им.Кирова, 9	f	large
68412	63282	34	Новгородская область, Боровичи, пл.Спасская, 1	f	large
111830	63268	20	Новгородская область, Боровичи, пл.Володарского, 15	f	medium
111834	63278	30	Новгородская область, Боровичи, Школьный Бульвар, 10	f	medium
68363	63259	11	Новгородская область, Боровичи, С.Перовской, 90	f	large
68407	63275	27	Новгородская область, Боровичи, Пушкинская, 14	f	large
68413	63283	35	Новгородская область, Боровичи, Новгородская, 1	f	large
111840	63288	41	Новгородская область, Боровичи, Ленинградская, 14	f	\N
111839	63288	40	Новгородская область, Боровичи, Ленинградская, 14	f	\N
111837	63286	38	Новгородская область, Боровичи, Ленинградская, 97	f	\N
111836	63285	37	Новгородская область, Боровичи, Ленинградская, 95	f	medium
111831	63271	23	Новгородская область, Боровичи, Коммунарная, 46	f	medium
112167	63763	534	Новгородская область, Шимский район, поселок Шимск, Ленина, 8а	f	\N
112168	63763	535	Новгородская область, Шимский район, поселок Шимск, Ленина, 8а	f	\N
112175	63770	542	Новгородская область, Шимский район, село Уторгош, Пионерская, 49а	f	\N
112176	63771	543	Новгородская область, Шимский район, село Турская Горка, Молодежная, 1	f	\N
112173	63768	540	Россия, Новгородская область, Шимский район, село Старый Медведь	f	\N
112164	63760	531	Новгородская область, Шимский район, село Подгощи, Заречная, 42	f	\N
112170	63765	537	Новгородская область, Шимский район, село Мшага-Ямская, Никольская, 1	f	\N
112172	63767	539	Новгородская область, Шимский район, село Менюша, 98	f	\N
112171	63766	538	Новгородская область, Шимский район, село Медведь, Театральная, 2	f	\N
112165	63761	532	Новгородская область, Шимский район, село Любыни, Солецкая, 3	f	\N
112166	63762	533	Новгородская область, Шимский район, село Красный Двор, Центральная, 19	f	\N
112161	63757	528	Новгородская область, Шимский район, село Коростынь, Садовая, 4	f	\N
112174	63769	541	Новгородская область, Шимский район, село Закибье, Новая, 27	f	\N
112163	63759	530	Новгородская область, Шимский район, село Горцы, 25	f	\N
112178	63773	545	Россия, Новгородская область, Шимский район, село Городище	f	\N
112162	63758	529	Новгородская область, Шимский район, село Веряжа, Центральная, 23	f	\N
112169	63764	536	Новгородская область, Шимский район, село Бор, Сосновая, 6	f	\N
112177	63772	544	Новгородская область, Шимский район, село Большой Уторгош, Центральная, 41	f	\N
112155	63751	522	Новгородская область, Чудовский район, Чудово, Титова, 10	f	\N
112158	63754	525	Новгородская область, Чудовский район, Чудово, Новопарковая, 1-а	f	\N
112157	63753	524	Новгородская область, Чудовский район, Чудово, Некрасова, 29-а	f	\N
112156	63752	523	Новгородская область, Чудовский район, Чудово, Некрасова, 19	f	\N
112160	63756	527	Новгородская область, Чудовский район, Чудово, Малый переулок, 9	f	\N
112159	63755	526	Новгородская область, Чудовский район, Чудово, Замкова, 1	f	\N
112154	63750	521	Новгородская область, Чудовский район, Чудово, Базовский переулок, 1	f	\N
112153	63749	520	Новгородская область, Чудовский район, село Успенское, Советская, 3	f	\N
112150	63746	517	Новгородская область, Чудовский район, село Трегубово, Школьная, 6	f	\N
112145	63741	512	Новгородская область, Чудовский район, село Суворовка, Советская, 14	t	\N
112149	63745	516	Новгородская область, Чудовский район, село Спасская-Полисть, Барсукова, 51	f	\N
112148	63744	515	Новгородская область, Чудовский район, село Селищи, Школьная, 2	f	\N
112144	63740	511	Россия, Новгородская область, Чудовский район, село Переход	t	\N
112146	63742	513	Новгородская область, Чудовский район, село Оскуй, Малая Набережная, 30	f	\N
112147	63743	514	Новгородская область, Чудовский район, поселок Краснофарфорный, Октябрьская, 1	f	\N
112151	63747	518	Новгородская область, Чудовский район, село Карловка, Центральная, 2	f	\N
112152	63748	519	Новгородская область, Чудовский район, село Зуево, Парковая, 1	f	\N
112143	63739	510	Новгородская область, Чудовский район, село Грузино, Школьная, 12	f	\N
112136	63732	503	Новгородская область, Холмский район, село Чекуново, Центральная, 10	f	\N
112133	63425	500	Новгородская область, Холмский район, Холм, Старорусская, 53	f	\N
112132	63729	499	Новгородская область, Холмский район, Холм, Октябрьская, 88	f	\N
112131	63728	498	Новгородская область, Холмский район, Холм, Октябрьская, 49	f	\N
112130	63727	497	Новгородская область, Холмский район, Холм, Красноармейская, 26а	f	\N
112138	63734	505	Новгородская область, Холмский район, село Тухомичи, Центральная, 4	f	\N
112142	63738	509	Новгородская область, Холмский район, село Тогодь, Молодежная, 5	f	\N
112135	63731	502	Новгородская область, Холмский район, село Сопки, Центральная, 8	f	\N
112140	63736	507	Новгородская область, Холмский район, село Наход, Центральная, 14	f	\N
112137	63733	504	Новгородская область, Холмский район, село Морхово, Звездная, 5	f	\N
112141	63737	508	Новгородская область, Холмский район, село Мамоново, Молодежная, 30	f	\N
112134	63730	501	Новгородская область, Холмский район, село Красный Бор, Центральная, 20	f	\N
112139	63735	506	Новгородская область, Холмский район, село Залесье, Комсомольская, 25	f	\N
112129	63726	496	Новгородская область, Хвойнинский район, село Юбилейный, пер.Спортивный, 1	f	\N
112112	63709	479	Новгородская область, Хвойнинский район, поселок Хвойная, Советская, 3	f	\N
112114	63711	481	Новгородская область, Хвойнинский район, поселок Хвойная, Связи, 41	f	\N
112113	63620	480	Новгородская область, Хвойнинский район, поселок Хвойная, Денисова, 1	f	\N
112127	63724	494	Новгородская область, Хвойнинский район, село Песь, пр.Школьный, 1-а	f	\N
112126	63723	493	Новгородская область, Хвойнинский район, село Остахново, Новая, 1-а	f	\N
112125	63722	492	Новгородская область, Хвойнинский район, село Минцы, Первомайская, 10	f	\N
112124	63721	491	Новгородская область, Хвойнинский район, село Миголощи, Денисова, 23-а	f	\N
112128	63725	495	Новгородская область, Хвойнинский район, село Лесной, Строительная, 22	f	\N
112123	63720	490	Новгородская область, Хвойнинский район, село Левоча, Никольская, 7	f	\N
112119	63716	486	Новгородская область, Хвойнинский район, село Кушавера, Советская, 1	f	\N
68403	63380	133	Новгородская область, Хвойнинский район, село Крестцы, Московская, 2а	f	large
112122	63719	489	Новгородская область, Хвойнинский район, село Кабожа, Линейная, 9	f	\N
112121	63718	488	Новгородская область, Хвойнинский район, село Звягино, Школьная, 6	f	\N
112118	63715	485	Новгородская область, Хвойнинский район, село Дворищи, Советская, 4	f	\N
112116	63713	483	Новгородская область, Хвойнинский район, село Горный, Песчаная, 10	f	\N
112120	63717	487	Новгородская область, Хвойнинский район, село Бугры, Молодежная, 5	t	\N
112117	63714	484	Новгородская область, Хвойнинский район, село Боровское, Молодежная, 13	f	\N
112115	63712	482	Новгородская область, Хвойнинский район, село Анциферово, Октябрьская, 22	f	\N
112089	63687	456	Новгородская область, Старорусский район, село Тулебля, Кольцевая, 25	f	\N
112088	63686	455	Новгородская область, Старорусский район, село Сусолово, 5	f	\N
112111	63708	478	Новгородская область, Старорусский район, Старая Русса	f	\N
112094	63692	461	Россия, Новгородская область, Старорусский район, Старая Русса	f	\N
112093	63691	460	Новгородская область, Старорусский район, Старая Русса, пл.Революции, 3	f	\N
112101	63698	468	Новгородская область, Старорусский район, Старая Русса, пер.Комсомольский, 1/38	f	\N
112099	63696	466	Новгородская область, Старорусский район, Старая Русса, пер.Комсомольский, 1/38	f	\N
112105	63702	472	Новгородская область, Старорусский район, Старая Русса, Якутских Стрелков, 35	f	\N
112091	63689	458	Новгородская область, Старорусский район, Старая Русса, Яковлева, 28	f	\N
112102	63699	469	Новгородская область, Старорусский район, Старая Русса, Трибуны, 4 А	f	\N
112104	63701	471	Новгородская область, Старорусский район, Старая Русса, Строителей, 6	f	\N
112109	63706	476	Новгородская область, Старорусский район, Старая Русса, Пролетарской Победы, 19	f	\N
112096	63598	463	Новгородская область, Старорусский район, Старая Русса, Минеральная, 62	f	\N
112097	63694	464	Новгородская область, Старорусский район, Старая Русса, Володарского, 34п.№2	f	\N
112100	63697	467	Новгородская область, Старорусский район, Старая Русса, Возрождения, 36 А	f	\N
112087	63685	454	Новгородская область, Старорусский район, село Святогорша, 5, Начальная школа-детский сад	f	\N
112086	63684	453	Новгородская область, Старорусский район, село Пробуждение, 7	f	\N
112085	63683	452	Новгородская область, Старорусский район, село Пинаевы Горки, Центральная, 31	f	\N
112084	63682	451	Россия, Новгородская область, Старорусский район, село Новосельский	f	\N
112083	63681	450	Новгородская область, Старорусский район, село Нагово, Школьная, 3	f	\N
112082	63680	449	Новгородская область, Старорусский район, село Медниково, Молодежная, 1 А	f	\N
112081	63679	448	Новгородская область, Старорусский район, село Луньшино, 72	f	\N
112080	63678	447	Новгородская область, Старорусский район, село Коровитчино, Центральная, 22	f	\N
112090	63688	457	Новгородская область, Старорусский район, село Ивановское, Центральная, 31	f	\N
112079	63677	446	Новгородская область, Старорусский район, село Залучье, Рендакова, 12	f	\N
112106	63703	473	Новгородская область, Старорусский район, село Дубовицы, Школьная, 5	f	\N
112078	63676	445	Новгородская область, Старорусский район, село Давыдово, 31	f	\N
112077	63675	444	Новгородская область, Старорусский район, село Взвад, Заводская, 1	f	\N
112076	63674	443	Новгородская область, Старорусский район, село Великое, 28	f	\N
112075	63673	442	Новгородская область, Старорусский район, село Буреги, Соборная, 1	f	\N
112074	63672	441	Новгородская область, Старорусский район, село Борисово, Центральная, 8	f	\N
112071	63669	438	Новгородская область, Старорусский район, село Большое Вороново, Центральная, 1	f	\N
112072	63670	439	Новгородская область, Старорусский район, село Большие Боры, 83	f	\N
112073	63671	440	Новгородская область, Старорусский район, село Большая Козона, 11 А	f	\N
112070	63668	437	Новгородская область, Старорусский район, село Астрилово, 28	f	\N
112069	63666	436	Новгородская область, Старорусский район, село Анишино 1-е, Зеленая, 5 Б	f	\N
86900	63648	417	Новгородская область, Солецкий район, село Толчино, Ветеранов, 18	f	small
68442	63502	435	Новгородская область, Солецкий район, Сольцы, Дом офицеров 	f	large
112066	63662	431	Новгородская область, Солецкий район, Сольцы, проспект Советский, 44Б	f	medium
112064	63659	428	Новгородская область, Солецкий район, Сольцы, Новгородская, 69а	f	medium
112068	63398	434	Новгородская область, Солецкий район, Сольцы, Молодежная, 16	f	medium
68432	63660	429	Новгородская область, Солецкий район, Сольцы, Красных Партизан, 4	f	large
68433	63663	432	Новгородская область, Солецкий район, Сольцы, Комсомола, 107	f	large
112067	63664	433	Новгородская область, Солецкий район, Сольцы, А.Матросов, 58-б	f	medium
86901	63650	419	Новгородская область, Солецкий район, село Светлицы, Первомайская, 11	f	small
86905	63655	424	Новгородская область, Солецкий район, село Ретно, В.Козлова, 11	f	small
86907	63657	426	Новгородская область, Солецкий район, село Песочки, Молодёжная, 18	f	small
86906	63656	425	Новгородская область, Солецкий район, село Невское, Невская, 69	f	small
86904	63654	423	Новгородская область, Солецкий район, село Куклино, Центральная, 29-а	f	small
86903	63653	422	Новгородская область, Солецкий район, село Жильско, Центральная, 60	f	small
86902	63652	421	Новгородская область, Солецкий район, село Дуброво, Ветеранов, 11	f	small
112062	63651	420	Новгородская область, Солецкий район, село Горки, Молодежная, 12	f	medium
112061	63649	418	Новгородская область, Солецкий район, село Выбити, Центральная, 79	f	medium
86899	63647	416	Новгородская область, Солецкий район, село Вшели, Центральная, 17	f	small
112063	63658	427	Новгородская область, Солецкий район, село Большое Заборовье, Вольная, 56	f	medium
112060	63646	415	Новгородская область, Поддорский район, село Селеево, Комсомольская, 5	f	\N
112058	63644	413	Новгородская область, Поддорский район, село Поддорье, Горького, 10	f	\N
112054	63640	409	Новгородская область, Поддорский район, село Переезд, Центральная, 44	f	\N
112059	63645	414	Новгородская область, Поддорский район, село Перегино, Центральная, 4	f	\N
112057	63643	412	Новгородская область, Поддорский район, село Нивки, Новая, 18	f	\N
112056	63642	411	Новгородская область, Поддорский район, село Масловское, Центральная, 30	f	\N
112053	63639	408	Новгородская область, Поддорский район, село Заозерье, Центральная, 23	t	\N
112055	63641	410	Новгородская область, Поддорский район, село Бураково, Октябрьская, 11	f	\N
112052	63638	407	Новгородская область, Поддорский район, село Белебелка, Советская, 48	f	\N
86912	63628	397	Новгородская область, Пестовский район, село Устюцкое, 56	f	small
86910	63626	395	Новгородская область, Пестовский район, село Семытино, 85	f	small
112051	63624	393	Новгородская область, Пестовский район, село Русское-Пестово, Лесная, 1А	f	medium
86913	63629	398	Новгородская область, Пестовский район, село Погорелово, 105	f	small
86896	63618	388	Новгородская область, Пестовский район, село Погорелово, 25	f	small
68435	63631	400	Новгородская область, Пестовский район, Пестово, Чапаева, 19, спортивный корпус Энергетик	f	large
68439	63635	404	Новгородская область, Пестовский район, Пестово, Советская, 15	f	large
68437	63633	402	Новгородская область, Пестовский район, Пестово, Советская, 11	f	large
68436	63632	401	Новгородская область, Пестовский район, Пестово, Почтовая, 5	f	large
112050	63623	392	Новгородская область, Пестовский район, село Охона, Центральная, 24	f	medium
86898	63621	390	Новгородская область, Пестовский район, село Лаптево, Советская, 28, административное здание Лаптевского сельского поселения	f	small
86895	63617	387	Новгородская область, Пестовский район, село Карпелово, 25, административное здание территориального отделения Быковского сельского поселения	f	small
86897	63619	389	Новгородская область, Пестовский район, село Вятка, Соловьева, 51	f	small
86909	63625	394	Новгородская область, Пестовский район, село Вотроса, 57административное здание территориального отделения Пестовского сельского поселения	f	small
86894	63616	386	Новгородская область, Пестовский район, село Быково, Школьная, 92, административное здание Быковского сельского поселения	f	small
86892	63614	384	Новгородская область, Пестовский район, село Богослово, Советская, 6, административное здание Богословского сельского поселения	f	small
86908	63622	391	Новгородская область, Пестовский район, село Беззубцево, 33	f	small
86911	63627	396	Новгородская область, Пестовский район, село Барсаниха, Молодежная, 17в	f	small
86891	63613	383	Новгородская область, Пестовский район, село Абросово, Ветеранов, 1а	f	small
112049	63605	375	Новгородская область, Парфинский район, село Федорково, Старорусская, 5	f	medium
112048	63604	374	Новгородская область, Парфинский район, село Федорково, Профсоюзная, 2	f	medium
112047	63603	373	Новгородская область, Парфинский район, село Сергеево, Строительная, 2	f	medium
68431	63610	380	Новгородская область, Парфинский район, село Пола, Пионерская, 10	f	large
68430	63609	379	Новгородская область, Парфинский район, село Пола, Мира, 12	f	large
68428	63601	371	Новгородская область, Парфинский район, поселок Парфино, Мира, 30а	f	large
68426	63599	369	Новгородская область, Парфинский район, поселок Парфино, Крупнова, 5	f	large
68429	63602	372	Новгородская область, Парфинский район, поселок Парфино, Карла Маркса, 62	f	large
68427	63600	370	Новгородская область, Парфинский район, поселок Парфино, Карла Маркса, 65	f	large
68425	63597	368	Новгородская область, Парфинский район, поселок Парфино, Карла Маркса, 70, УИК:Карла Маркса, 60каб.1017	f	large
86889	63611	381	Новгородская область, Парфинский район, село Новая Деревня, Центральная, 6	f	small
86888	63608	378	Новгородская область, Парфинский район, село Лажины, Советская, 5	f	small
86890	63612	382	Новгородская область, Парфинский район, село Кузьминское, 46	f	small
86887	63607	377	Новгородская область, Парфинский район, село Городок, Советская, 15	f	small
86886	63606	376	Новгородская область, Парфинский район, село Березицко, Школьная, 22	f	small
86874	63574	345	Новгородская область, Окуловский район, дер.Шуркино, Мира, 2Б	f	small
86882	63591	362	Новгородская область, Окуловский район, дер.Козловка, Новопокровская, 5	f	small
68422	63582	353	Новгородская область, Окуловский район, поселок Угловка, Центральная, 9	f	large
112044	63581	352	Новгородская область, Окуловский район, поселок Угловка, Молодежная, 11	f	medium
86883	63592	363	Новгородская область, Окуловский район, село Торбино, Луначарского, 42	f	small
112046	63594	365	Новгородская область, Окуловский район, село Топорок, Дзержинского, 6Б	f	medium
86876	63583	354	Новгородская область, Окуловский район, поселок Селище, 31	f	small
86885	63596	367	Новгородская область, Окуловский район, село Пузырево, 57	f	small
86875	63580	351	Новгородская область, Окуловский район, село Полищи, Центральная, 29	f	small
68418	63575	346	Новгородская область, Окуловский район, Окуловка, Парфенова, 10	f	large
68416	63572	343	Новгородская область, Окуловский район, Окуловка, Новгородская, 32	f	large
68414	63570	341	Новгородская область, Окуловский район, Окуловка, Ленина, 51	f	large
112043	63577	348	Новгородская область, Окуловский район, Окуловка, Грибоедова, 31	f	medium
86878	63585	356	Новгородская область, Окуловский район, село Озерки, 9, кв.13	f	small
86884	63595	366	Новгородская область, Окуловский район, село Мельница, Центральная, 19	f	small
68421	63579	350	Новгородская область, Окуловский район, поселок Кулотино, Кирова, 13	f	large
68420	63578	349	Новгородская область, Окуловский район, поселок Кулотино, Кирова, 13	f	large
68424	63593	364	Новгородская область, Окуловский район, поселок Котово, Ленина, 4	f	large
86880	63587	358	Новгородская область, Окуловский район, село Завод, 8	f	small
86881	63589	360	Новгородская область, Окуловский район, село Дерняки, 62	f	small
112045	63590	361	Новгородская область, Окуловский район, село Висленев Остров, 2	t	\N
68423	63588	359	Новгородская область, Окуловский район, село Боровенка, Кооперативная, 7	f	large
86877	63584	355	Новгородская область, Окуловский район, село Березовка, 66	f	small
86879	63586	357	Новгородская область, Окуловский район, село Березовик, Центральная, 9А	f	small
112035	63562	333	Новгородская область, Новгородский район, село Чечулино, 11	f	\N
112017	63544	315	Новгородская область, Новгородский район, село Частова, Центральная, 63	t	\N
112016	63543	314	Новгородская область, Новгородский район, село Холынья, 8Б	f	\N
112042	63569	340	Новгородская область, Новгородский район, деревня Трубичино, 2Б	f	\N
112003	63531	301	Россия, Новгородская область, Новгородский район, село Толстиково	f	\N
112041	63568	339	Новгородская область, Новгородский район, поселок Тесовский, Центральная, 5А	f	\N
112036	63563	334	Новгородская область, Новгородский район, поселок Тесово-Нетыльский, Советская, 17	f	\N
112037	63564	335	Новгородская область, Новгородский район, поселок Тесово-Нетыльский, Матросова, 11	f	\N
112008	63536	306	Новгородская область, Новгородский район, село Старое Ракомо, Школьная, 17	f	\N
112004	63532	302	Новгородская область, Новгородский район, село Сергово, 3	f	\N
112023	63550	321	Новгородская область, Новгородский район, село Савино, Школьная, 3	f	\N
112026	63553	324	Новгородская область, Новгородский район, поселок Пролетарий, Парковая, 5	f	\N
112027	63554	325	Новгородская область, Новгородский район, поселок Пролетарий, Ленина, 10	f	\N
112031	63558	329	Новгородская область, Новгородский район, село Подберезье, Центральная, 110	f	\N
86837	63391	144	Новгородская область, Крестецкий район, село Локотско, 44	f	small
112011	63539	309	Новгородская область, Новгородский район, село Панковка, Пионерская, 12	f	\N
112012	63539	310	Новгородская область, Новгородский район, село Панковка, Пионерская, 12	f	\N
112010	63538	308	Новгородская область, Новгородский район, поселок Панковка, Октябрьская, 3	f	\N
112040	63567	338	Россия, Новгородская область, Новгородский район, село Осия	t	\N
112020	63547	318	Новгородская область, Новгородский район, село Новоселицы, Школьная, 3	f	\N
112006	63534	304	Новгородская область, Новгородский район, село Новая Мельница, 26	f	\N
112014	63541	312	Новгородская область, Новгородский район, село Наволок, 9А	f	\N
112021	63548	319	Новгородская область, Новгородский район, село Мытно, Евстигнеева, 23	f	\N
112007	63535	305	Новгородская область, Новгородский район, село Лесная, 60 лет СССР, 17	f	\N
112029	63556	327	Новгородская область, Новгородский район, село Красные Станки, Центральная, 106	f	\N
112038	63565	336	Новгородская область, Новгородский район, село Кересть, Центральная, 28	t	\N
112009	63537	307	Новгородская область, Новгородский район, село Ильмень, Зеленая, 2А	f	\N
112032	63559	330	Новгородская область, Новгородский район, село Захарьино, Рахманинова, 8	f	\N
112005	63533	303	Новгородская область, Новгородский район, село Ермолино, 33А	f	\N
112025	63552	323	Новгородская область, Новгородский район, село Дубровка, 46/3	f	\N
112028	63555	326	Новгородская область, Новгородский район, село Гостцы, Школьная, 2	f	\N
112039	63566	337	Новгородская область, Новгородский район, село Гора, Черепанова, 99	f	\N
112019	63546	317	Новгородская область, Новгородский район, поселок Волховец, Пионерстроя, 1	f	\N
112013	63540	311	Новгородская область, Новгородский район, село Бронница, Бронницкая, 168	f	\N
112002	63530	300	Новгородская область, Новгородский район, село Борки, Заверяжская, 1	f	\N
112034	63561	332	Новгородская область, Новгородский район, село Болотная, 7	f	\N
112022	63549	320	Новгородская область, Новгородский район, село Божонка, Новая, 15	f	\N
112015	63542	313	Новгородская область, Новгородский район, село Белая Гора, 37	f	\N
111913	63460	211	Новгородская область, Мошенской район, село Чувашева Гора, 37	f	\N
111908	63455	206	Новгородская область, Мошенской район, село Устрека, 131а	f	\N
111907	63454	205	Новгородская область, Мошенской район, село Слоптово, 1а	f	\N
111912	63459	210	Новгородская область, Мошенской район, село Петрово, 73	f	\N
111906	63453	204	Новгородская область, Мошенской район, село Осташево, 56	f	\N
111911	63458	209	Новгородская область, Мошенской район, село Ореховно, 95	f	\N
111903	63450	201	Новгородская область, Мошенской район, село Новый Поселок, Молодежная, 3	f	\N
111909	63456	207	Новгородская область, Мошенской район, село Мошенское, Советская, 11	f	\N
111905	63452	203	Новгородская область, Мошенской район, село Меглецы, Софьи Лешерн, 6	f	\N
111901	63448	199	Новгородская область, Мошенской район, село Красная Гора, 9	f	\N
111902	63449	200	Новгородская область, Мошенской район, село Кабожа, 30	f	\N
111910	63457	208	Новгородская область, Мошенской район, село Дубишки, 12	t	\N
111900	63447	198	Новгородская область, Мошенской район, село Долгое, 2	f	\N
111899	63446	197	Новгородская область, Мошенской район, село Броди, 39	t	\N
111904	63451	202	Новгородская область, Мошенской район, село Барышево, 64	f	\N
111898	63445	196	Новгородская область, Маревский район, село Первомайский, пом.6	f	\N
111897	63444	195	Новгородская область, Маревский район, село Новая Русса, Центральная, 34	t	\N
111893	63440	191	Новгородская область, Маревский район, село Новая Деревня, Новая, 13	f	\N
111894	63441	192	Новгородская область, Маревский район, село Молвотицы, Школьная, 14	f	\N
111892	63439	190	Новгородская область, Маревский район, село Моисеево, Садовая, 6	f	\N
111888	63435	186	Новгородская область, Маревский район, село Марево, Советов, 44	f	\N
111889	63436	187	Новгородская область, Маревский район, село Марево, Мудрова, 19	f	\N
111896	63443	194	Новгородская область, Маревский район, село Мамоновщина, Центральная, 1	t	\N
111890	63437	188	Новгородская область, Маревский район, село Липье, Строителей, 1	f	\N
111895	63442	193	Новгородская область, Маревский район, село Горное, пер.Кленовый, 4	f	\N
111887	63434	185	Новгородская область, Маревский район, село Велилы, Советов, 7	f	\N
111683	60707	15	Ненецкий автономный округ, село Выучейский	t	small
111891	63438	189	Новгородская область, Маревский район, село Афаносово, Центральная, 37	t	\N
86859	63432	183	Россия, Новгородская область, Маловишерский район	f	small
86860	63433	184	Новгородская область, Маловишерский район, село Оксочи, Советов, 1	f	small
86857	63429	180	Новгородская область, Маловишерский район, село Мстинский Мост, Воровского, 5	f	small
68390	63415	167	Новгородская область, Маловишерский район, Малая Вишера, Московская, 23	f	large
68394	63420	172	Новгородская область, Маловишерский район, Малая Вишера, Заводской Домострой, 4А	f	large
111883	63419	171	Новгородская область, Маловишерский район, Малая Вишера, Заводской Домострой, 10	f	medium
68393	63418	170	Новгородская область, Маловишерский район, Малая Вишера, Заводской Домострой, 4а	f	large
68391	63416	168	Новгородская область, Маловишерский район, Малая Вишера, Гагарина, 14	f	large
68389	63413	165	Новгородская область, Маловишерский район, Малая Вишера, 50 Лет Октября, 16	f	large
68392	63417	169	Новгородская область, Маловишерский район, Малая Вишера, Школьная, 1	f	large
111885	63426	177	Новгородская область, Маловишерский район, село Красненка, Первомайская, 9	t	\N
86856	63428	179	Новгородская область, Маловишерский район, село Карпина Гора, 38	f	small
86855	63427	178	Новгородская область, Маловишерский район, село Дворищи, Школьная, 2	f	small
86854	63423	175	Новгородская область, Маловишерский район, село Гряды, Ленинградская, 12	f	small
86853	63421	173	Новгородская область, Маловишерский район, село Глутно, Славная, 5	f	small
111886	63431	182	Новгородская область, Маловишерский район, село Гарь, Северная, 3	t	\N
86858	63430	181	Новгородская область, Маловишерский район, село Веребье, 1 Мая, 47	f	small
111884	63424	176	Новгородская область, Маловишерский район, село Бурга, Новгородская, 3	f	medium
68395	63422	174	Новгородская область, Маловишерский район, поселок Большая Вишера, Поболотина, 3	f	large
86848	63403	155	Новгородская область, Любытинский район, село Ярцево, 43	f	small
86839	63393	146	Россия, Новгородская область, Любытинский район, село Шереховичи	f	small
86838	63392	145	Россия, Новгородская область, Любытинский район, село Слобода	f	small
86842	63396	149	Россия, Новгородская область, Любытинский район	f	small
68388	63412	164	Новгородская область, Любытинский район, поселок Неболчи, Комсомольская, 3	f	large
86852	63411	163	Новгородская область, Любытинский район, поселок Неболчи, Комсомольская, 3	f	small
68387	63405	157	Новгородская область, Любытинский район, поселок Любытино, Советов, 16	f	large
86847	63402	154	Новгородская область, Любытинский район, поселок Любытино, Советов, 10	f	small
86845	63400	152	Новгородская область, Любытинский район, поселок Любытино, Магистральная, 6	f	small
86843	63397	150	Новгородская область, Любытинский район, поселок Комарово, Речная, 11	f	small
68386	63404	156	Новгородская область, Любытинский район, поселок Зарубино, Пролетарская, 5	f	large
111880	63407	159	Россия, Новгородская область, Любытинский район, село Заполье	t	\N
86849	63406	158	Россия, Новгородская область, Любытинский район, село Дрегли	f	small
86846	63401	153	Россия, Новгородская область, Любытинский район, село Вычерема	f	small
86844	63399	151	Новгородская область, Любытинский район, село Высочка, 39	f	small
86850	63408	160	Россия, Новгородская область, Любытинский район, село Водогон	f	small
86841	63395	148	Россия, Новгородская область, Любытинский район	f	small
86851	63410	162	Новгородская область, Любытинский район, село Ваган, Советская, 14, УИК п. Неболчи	f	small
86840	63394	147	Россия, Новгородская область, Любытинский район, село Артем	f	small
68405	63382	135	Новгородская область, Крестецкий район, село Ямская Слобода, Ямская, 23	f	large
86833	63386	139	Новгородская область, Крестецкий район, село Усть-Волма, Советская, 1	f	small
86836	63390	143	Новгородская область, Крестецкий район, село Соменка, Зеленая, 58	f	small
86834	63387	140	Новгородская область, Крестецкий район, село Ручьи, Лесная, 1	f	small
86832	63385	138	Новгородская область, Крестецкий район, село Ольховка, 17	f	small
111879	63389	142	Новгородская область, Крестецкий район, село Новое Рахино, 26	f	medium
86835	63388	141	Новгородская область, Крестецкий район, село Лякова, 66	f	small
53188	60435	195	Мурманская область, Кандалакша, Пронина, 22а	f	large
68401	63378	131	Новгородская область, Крестецкий район, поселок Крестцы, Строителей, 5	f	large
68400	63378	130	Новгородская область, Крестецкий район, поселок Крестцы, Строителей, 5	f	large
68402	63379	132	Новгородская область, Крестецкий район, поселок Крестцы, Островская, 19	f	large
68404	63381	134	Новгородская область, Крестецкий район, поселок Крестцы, Валдайская, 2	f	large
111878	63383	136	Новгородская область, Крестецкий район, село Зайцево, Молодежная, 6а	f	medium
86873	63384	137	Новгородская область, Крестецкий район, село Вины, Центральная, 94	f	small
111877	63377	129	Новгородская область, Демянский район, село Ямник, Садовая, 2а	f	medium
86872	63376	128	Новгородская область, Демянский район, село Шишково, Центральная, 33	f	small
86871	63375	127	Новгородская область, Демянский район, село Черный Ручей, Центральная, 56А	f	small
86870	63374	126	Новгородская область, Демянский район, село Филиппова Гора, Центральная, 23	f	small
86869	63373	125	Новгородская область, Демянский район, село Старое Тарасово, 117	f	small
86868	63372	124	Россия, Новгородская область, Демянский район, село Полново	f	small
86867	63371	123	Новгородская область, Демянский район, село Пески, Центральная, 29/2	f	small
86866	63370	122	Новгородская область, Демянский район, село Новая Скребель, Береговая, 15	f	small
86865	63369	121	Новгородская область, Демянский район, село Никольское, Центральная, 25	f	small
86830	63359	111	Новгородская область, Демянский район, село Малые Луки, 7	f	small
68399	63368	120	Новгородская область, Демянский район, поселок Лычково, 1 Мая, 20	f	large
68398	63367	119	Новгородская область, Демянский район, поселок Кневицы, Центральная, 58	f	large
86864	63366	118	Новгородская область, Демянский район, село Ильина Гора, Молодежная, 5\\2	f	small
86863	63365	117	Новгородская область, Демянский район, село Жирково, Центральная, 15	f	small
68397	63363	115	Новгородская область, Демянский район, поселок Демянск, 10	f	large
68396	63362	114	Новгородская область, Демянский район, поселок Демянск, Ленина, 24	f	large
86861	63361	113	Новгородская область, Демянский район, село Вотолино, переулок Школьный, 4	f	small
86831	63360	112	Новгородская область, Демянский район, село Великий Завод, Центральная, 32	f	small
86829	63358	110	Новгородская область, Волотовский район, село Соловьево, Зеленая, 47	f	small
86827	63356	108	Новгородская область, Волотовский район, село Славитино, Центральная, 18	f	small
86822	63351	103	Новгородская область, Волотовский район, село Раглицы, Волотовская, 6	f	small
86820	63349	101	Новгородская область, Волотовский район, село Порожки, 2	f	small
86823	63352	104	Новгородская область, Волотовский район, село Дерглец, 47	f	small
86826	63355	107	Новгородская область, Волотовский район, село Горки Ратицкие, Центральная, 17	f	small
86825	63354	106	Новгородская область, Волотовский район, село Горицы, 50	f	small
86824	63353	105	Новгородская область, Волотовский район, село Геородцы, Центральная, 11	f	small
86821	63350	102	Новгородская область, Волотовский район, поселок Волот, Победы, 13	f	small
68385	63348	100	Новгородская область, Волотовский район, поселок Волот, Комсомольская, 38	f	large
86828	63357	109	Новгородская область, Волотовский район, село Верехново, 37	f	small
68384	63343	96	Новгородская область, Валдайский район, село Яжелбицы, Усадьба, 22	f	large
86816	63340	93	Новгородская область, Валдайский район, село Шуя, 59	f	small
86817	63341	94	Новгородская область, Валдайский район, село Семеновщина, Центральная, 104	f	small
111874	63339	92	Новгородская область, Валдайский район, село Рощино, 11	f	medium
86814	63335	88	Новгородская область, Валдайский район, село Приозерный, Центральная, 36	f	small
86810	63330	83	Новгородская область, Валдайский район, село Наволок, 20	f	small
111872	63336	89	Новгородская область, Валдайский район, село Любница, Молодежная, 79	f	medium
86815	63337	90	Новгородская область, Валдайский район, село Лутовенка, Школьная, 3	f	small
86809	63329	82	Новгородская область, Валдайский район, село Красилово, 5	f	small
86813	63334	87	Новгородская область, Валдайский район, село Костково, Центральная, 4	f	small
86812	63333	86	Новгородская область, Валдайский район, поселок Короцко, Центральная, 8а	f	small
86811	63332	85	Новгородская область, Валдайский район, село Ивантеево, Зеленая, 1	f	small
111870	63326	79	Новгородская область, Валдайский район, село Зимогорье, Почтовая, 3	f	medium
68383	63327	80	Новгородская область, Валдайский район, село Едрово, Сосновая, 54	f	large
86808	63328	81	Новгородская область, Валдайский район, село Добывалово, 6	f	small
86819	63345	97	Новгородская область, Валдайский район, село Дворец, 30	f	small
111873	63338	91	Новгородская область, Валдайский район, Валдай, Энергетиков, 16	f	medium
68379	63321	74	Новгородская область, Валдайский район, Валдай, Труда, 63а	f	large
68376	63318	71	Новгородская область, Валдайский район, Валдай, Молодежная, 14	f	large
111868	63317	70	Новгородская область, Валдайский район, Валдай, Мелиораторов, 1а	f	medium
68381	63324	77	Новгородская область, Валдайский район, Валдай, Луначарского, 27	f	large
68380	63322	75	Новгородская область, Валдайский район, Валдай, Гагарина, 42а	f	large
86818	63342	95	Новгородская область, Валдайский район, село Большое Замошье, Четвертая, 8	f	small
111867	63315	68	Новгородская область, Боровичский район, село Удино, Садовая, 9	f	\N
111853	63301	54	Новгородская область, Боровичский район, поселок Тухун, 25	f	\N
111864	63312	65	Новгородская область, Боровичский район, село Травково, Новая, 1	f	\N
111863	63311	64	Новгородская область, Боровичский район, село Сушилово, 2	f	\N
111866	63314	67	Новгородская область, Боровичский район, село Сутоки-Рядок, 14	f	\N
111860	63308	61	Новгородская область, Боровичский район, село Речка, 53	f	\N
111856	63304	57	Россия, Новгородская область, Боровичский район, село Прошково	f	\N
111858	63306	59	Новгородская область, Боровичский район, село Прогресс, Зеленая, 11	f	\N
111857	63305	58	Новгородская область, Боровичский район, село Починная Сопка, Советская, 67	f	\N
111854	63302	55	Новгородская область, Боровичский район, село Перелучи, Новая, 15	f	\N
111852	63300	53	Новгородская область, Боровичский район, село Передки, 16А	f	\N
111851	63299	52	Новгородская область, Боровичский район, село Опеченский Посад, 1 линия, 18	f	\N
111855	63303	56	Новгородская область, Боровичский район, село Круппа, Новая, 24	f	\N
111850	63298	51	Новгородская область, Боровичский район, село Кончанско-Суворовское, Молодёжная, 4	f	\N
111861	63309	62	Новгородская область, Боровичский район, село Коегоща, Центральная, 18	f	\N
111849	63297	50	Новгородская область, Боровичский район, поселок Кировский, Маяковского, 2	f	\N
111865	63313	66	Новгородская область, Боровичский район, село Желомля, 1	f	\N
111847	63295	48	Новгородская область, Боровичский район, село Железково, 16	f	\N
111845	63293	46	Россия, Новгородская область, Боровичский район, село Елигово	f	\N
111846	63294	47	Новгородская область, Боровичский район, село Егла, Советская, 90	f	\N
111844	63292	45	Новгородская область, Боровичский район, село Волок, Центральная, 1	f	\N
111862	63310	63	Новгородская область, Боровичский район, село Волгино, Центральная, 2е	f	\N
68410	63280	32	Новгородская область, Боровичский район, Боровичи, площадь Труда, 15	f	large
68372	63269	21	Новгородская область, Боровичский район, Боровичи, пл.Володарского, 32	f	large
68367	63263	15	Новгородская область, Боровичский район, Боровичи, Энгельса, 22	f	large
68409	63279	31	Новгородская область, Боровичский район, Боровичи, Школьный бульвар, 10	f	large
68366	63262	14	Новгородская область, Боровичский район, Боровичи, Сушанская, 11	f	large
68365	63261	13	Новгородская область, Боровичский район, Боровичи, Сушанская, 3	f	large
111833	63277	29	Новгородская область, Боровичский район, Боровичи, Советская, 124	f	medium
68364	63260	12	Новгородская область, Боровичский район, Боровичи, С.Перовской, 92А	f	large
111843	63291	44	Новгородская область, Боровичский район, Боровичи, Раздолье	f	\N
68411	63281	33	Новгородская область, Боровичский район, Боровичи, Р.Люксембург, 16	f	large
68371	63267	19	Новгородская область, Боровичский район, Боровичи, Подбельского, 47	f	large
68406	63274	26	Новгородская область, Боровичский район, Боровичи, Парковая, 1	f	large
111841	63289	42	Новгородская область, Боровичский район, Боровичи, Молодой Гвардии, 11А	f	\N
111835	63284	36	Новгородская область, Боровичский район, Боровичи, Ленинградская, 99	f	medium
68408	63276	28	Новгородская область, Боровичский район, Боровичи, Красноармейская, 2А	f	large
68369	63265	17	Новгородская область, Боровичский район, Боровичи, Кооперативная, 51	f	large
68374	63272	24	Новгородская область, Боровичский район, Боровичи, Коммунарная, 2	f	large
68370	63266	18	Новгородская область, Боровичский район, Боровичи, Декабристов, 55	f	large
111838	63287	39	Новгородская область, Боровичский район, Боровичи, Гончарная, 33	f	\N
111842	63290	43	Новгородская область, Боровичский район, Боровичи, В.Бианки, 35	f	\N
68368	63264	16	Новгородская область, Боровичский район, Боровичи, Ботаническая, 9	f	large
111859	63307	60	Новгородская область, Боровичский район, село Березник, 14, здание сельской библиотеки	f	\N
111848	63296	49	Новгородская область, Боровичский район, село Ануфриево, 82А	f	\N
86802	63252	4	Новгородская область, Батецкий район, село Черное, 46	f	small
111829	63257	9	Новгородская область, Батецкий район, село Новое Овсино, Школьная, 2	f	medium
86803	63253	5	Новгородская область, Батецкий район, село Мойка, Ветеранов, 6	f	small
86807	63258	10	Новгородская область, Батецкий район, село Мелковичи, Молодежная, 20	f	small
86806	63256	8	Новгородская область, Батецкий район, село Косицкое, Центральная, 28	f	small
86801	63251	3	Новгородская область, Батецкий район, село Городня, Юбилейная, 36	f	small
86805	63255	7	Новгородская область, Батецкий район, село Воронино, 31	f	small
86804	63254	6	Новгородская область, Батецкий район, село Вольная Горка, 90	f	small
68361	63249	1	Новгородская область, Батецкий район, поселок Батецкий, Советская, 4	f	large
68362	63250	2	Новгородская область, Батецкий район, поселок Батецкий, Первомайская, 24	f	large
111687	60711	19	Ненецкий автономный округ, село Щелино	t	small
111669	60693	1	Ненецкий автономный округ, село Шойна, Дом культуры	t	small
111671	60695	3	Ненецкий автономный округ, село Чижа	t	small
111700	60725	33	Ненецкий автономный округ, село Хорей-Вер	t	medium
111690	60714	22	Ненецкий автономный округ, село Хонгурей	t	small
111702	60727	35	Ненецкий автономный округ, село Усть-Кара	t	small
111686	60710	18	Ненецкий автономный округ, село Тошвиска	t	small
111693	60717	25	Ненецкий автономный округ, село Тельвиска	f	small
111676	60700	8	Ненецкий автономный округ, село Снопа	t	small
111689	60713	21	Ненецкий автономный округ, село Пылемец	t	small
111675	60699	7	Ненецкий автономный округ, село Ома	t	medium
111692	60716	24	Ненецкий автономный округ, село Оксино	t	small
111677	60701	9	Ненецкий автономный округ, село Нижняя Пеша	t	medium
111672	60696	4	Ненецкий автономный округ, село Несь	t	medium
111696	60721	29	Ненецкий автономный округ, село Нельмин Нос	t	medium
85601	60739	48	Ненецкий автономный округ, Нарьян-Мар, проезд капитана Матросова, 1	f	large
111705	60732	41	Ненецкий автономный округ, Нарьян-Мар, Юбилейная, 22	f	medium
85603	60741	50	Ненецкий автономный округ, Нарьян-Мар, Студенческая, 3	f	large
85602	60740	49	Ненецкий автономный округ, Нарьян-Мар, Студенческая, 1	f	large
111706	60734	43	Ненецкий автономный округ, Нарьян-Мар, Строительная, 13	f	medium
85599	60737	46	Ненецкий автономный округ, Нарьян-Мар, Смидовича, 20а	f	large
85597	60735	44	Ненецкий автономный округ, Нарьян-Мар, Рабочая, 22	f	large
85600	60738	47	Ненецкий автономный округ, Нарьян-Мар, Ленина, 23б	f	large
85598	60736	45	Ненецкий автономный округ, Нарьян-Мар, Ленина, 25	f	large
85596	60733	42	Ненецкий автономный округ, Нарьян-Мар, Заводская, 9	f	large
111694	60718	26	Московская область, Подольский район, деревня Макарово	t	small
111688	60712	20	Ненецкий автономный округ, село Лабожское	t	small
111695	60719	27	Ненецкий автономный округ, село Куя	t	small
85592	60720	28	Ненецкий автономный округ, село Красное	t	large
111684	60708	16	Ненецкий автономный округ, село Коткино	t	small
111670	60694	2	Хабаровский край, Имени Лазо район, село Кия	t	small
111699	60724	32	Ненецкий автономный округ, село Каратайка	t	medium
111691	60715	23	Красноярский край, деревня Каменка	t	small
85594	60730	38	Ненецкий автономный округ, поселок Искателей, 15	f	large
134955	95201	36	Ненецкий автономный округ, поселок Искателей, Юбилейная, 80А	f	medium
111704	60731	40	Ненецкий автономный округ, поселок Искателей, Тиманская, 24А	f	\N
85595	60679	39	Ненецкий автономный округ, поселок Искателей, Ардалина, 15	f	large
85593	60729	37	Ненецкий автономный округ, поселок Искателей, Академика Губкина, 5б, Здание ДЮСШ	f	large
111682	60706	14	Ненецкий автономный округ, село Индига	t	small
111681	60705	13	Вологодская область, Харовский район, поселок Волонга	t	small
111679	60703	11	Смоленская область, Смоленский район, поселок Волоковая	t	small
111674	60698	6	Ненецкий автономный округ, село Вижас	t	small
111678	60702	10	Ненецкий автономный округ, село Верхняя Пеша	t	small
111685	60709	17	Ненецкий автономный округ, село Великовисочное	t	small
111673	60697	5	Ненецкий автономный округ, поселок Бугрино, Колгуевский сельсовет	t	small
111680	60704	12	Ненецкий автономный округ, село Белушье	t	small
111697	60722	30	Ненецкий автономный округ, село Андег	t	small
111698	60723	31	Ненецкий автономный округ, поселок Амдерма	t	small
111701	60726	34	республика Коми, Интинский район, село Харута	t	medium
53270	60506	285	Мурманская область, ж-д ст. Лопарская, 16Б	f	small
53429	60649	474	Мурманская область, Снежногорск, мкр.Скальный, 5	f	large
53424	60644	469	Мурманская область, Снежногорск, Флотская, 10	f	large
53427	60647	472	Мурманская область, Снежногорск, Павла Стеблина, 19	f	large
53423	60643	468	Мурманская область, Снежногорск, Павла Стеблина, 5	f	large
53426	60646	471	Мурманская область, Снежногорск, Октябрьская, 12	f	large
53428	60648	473	Мурманская область, Снежногорск, Мира, 3	f	large
53425	60645	470	Мурманская область, Снежногорск, Валентина Бирюкова, 21	f	large
53397	60616	432	Мурманская область, Североморск, Советская, 23а	f	medium
53395	60615	431	Мурманская область, Североморск, Северная Застава, 1	f	large
53396	60614	430	Мурманская область, Североморск, Саши Ковалева, 7	f	large
53400	60618	435	Мурманская область, Североморск, Полярная, 11	f	large
53399	60618	434	Мурманская область, Североморск, Полярная, 11	f	large
53398	60617	433	Мурманская область, Североморск, Падорина, 2 	f	large
53406	60623	441	Мурманская область, Североморск, Кортик, 14	f	small
53403	60621	438	Мурманская область, Североморск, Комсомольская, 33	f	large
53402	60620	437	Мурманская область, Североморск, Комсомольская, 33	f	large
53401	60619	436	Мурманская область, Североморск, Колышкина, 11	f	large
53394	60613	429	Мурманская область, Североморск, Кирова, 19	f	large
53393	60613	428	Мурманская область, Североморск, Кирова, 19	f	large
53392	60613	427	Мурманская область, Североморск, Кирова, 19	f	large
53391	60612	426	Мурманская область, Североморск, Душенова, 13а	f	large
111661	60610	424	Мурманская область, Североморск, Душенова, 10а	f	\N
53389	60609	423	Мурманская область, Североморск, Душенова, 19а	f	large
53388	60609	422	Мурманская область, Североморск, Душенова, 19а	f	large
53387	60609	421	Мурманская область, Североморск, Душенова, 19а	f	large
53405	60622	440	Мурманская область, Североморск, Гвардейская, 26	f	large
53404	60622	439	Мурманская область, Североморск, Гвардейская, 26	f	large
53385	60607	419	Мурманская область, Поселок Африканда-1, Кирова проспект, 2, ЖКХ 	f	small
53373	60598	403	Мурманская область, Полярный, Лунина, 6	f	large
53371	60596	401	Мурманская область, Полярный, Красный Горн, 6	f	large
53370	60596	400	Мурманская область, Полярный, Красный Горн, 6	f	large
53367	60593	397	Мурманская область, Полярный, Котельникова, 6	f	large
53369	60595	399	Мурманская область, Полярный, Душенова, 4	f	large
53366	60592	396	Мурманская область, Полярный, Героев Североморцев, 3	f	large
53368	60594	398	Мурманская область, Полярный, Гаджиева, 3 	f	large
53372	60597	402	Мурманская область, Полярный, Гагарина, 1	f	large
53422	60642	467	Мурманская область, село Оленья Губа, Строителей, 26/1	f	large
53324	60558	351	Мурманская область, Оленегорск, Южная, 11а	f	large
53323	60558	350	Мурманская область, Оленегорск, Южная, 11а	f	large
53326	60560	353	Мурманская область, Оленегорск, Энергетиков, 3	f	large
53325	60559	352	Мурманская область, Оленегорск, Строительная, 61	f	large
53318	60554	345	Мурманская область, Оленегорск, Строительная, 22	f	large
53320	60481	347	Мурманская область, Оленегорск, Парковая, 26	f	large
53321	60481	348	Мурманская область, Оленегорск, Парковая, 26	f	large
53319	60555	346	Мурманская область, Оленегорск, Мира, 48	f	large
53316	60552	343	Мурманская область, Оленегорск, Мира, 38а	f	large
53315	60551	342	Мурманская область, Оленегорск, Мира, 38А	f	large
53322	60557	349	Мурманская область, Оленегорск, Ленинградский проспект, 5	f	large
111658	60391	134	Россия, Мурманская область, Мурманск, улица адмирала Лобова, 47	f	\N
53015	60319	19	Мурманская область, Мурманск, улица Халатина, 17	f	large
53016	60319	20	Мурманская область, Мурманск, улица Халатина, 17	f	large
53096	60329	100	Мурманская область, Мурманск, улица Туристов, 34а	f	\N
53035	60329	39	Мурманская область, Мурманск, улица Туристов, 34а	f	large
52997	60306	1	Мурманская область, Мурманск, улица Торцева, 15	f	large
53058	60345	62	Мурманская область, Мурманск, улица Скальная, 12	f	large
53059	60345	63	Мурманская область, Мурманск, улица Скальная, 12	f	large
53052	60342	56	Мурманская область, Мурманск, улица Папанина, 3	f	large
53051	60342	55	Мурманская область, Мурманск, улица Папанина, 3	f	large
53050	60342	54	Мурманская область, Мурманск, улица Папанина, 3	f	large
52999	60308	3	Мурманская область, Мурманск, улица Нахимова, 21	f	large
53141	60396	146	Мурманская область, Мурманск, улица Крупской, 13	f	large
53140	60396	145	Мурманская область, Мурманск, улица Крупской, 13	f	large
53049	60341	53	Мурманская область, Мурманск, улица Комсомольская, 13	f	large
53045	60337	49	Мурманская область, Мурманск, улица Карла Маркса, 13	f	large
53036	60330	40	Мурманская область, Мурманск, улица Карла Либкнехта, 34	f	large
53111	60380	115	Мурманская область, Мурманск, улица Зои Космодемьянской, 13	f	large
53110	60380	114	Мурманская область, Мурманск, улица Зои Космодемьянской, 13	f	large
53021	60322	25	Мурманская область, Мурманск, улица Александрова, 32/2	f	large
53020	60322	24	Мурманская область, Мурманск, улица Александрова, 32/2	f	large
53010	60315	14	Мурманская область, Мурманск, улица Александра Невского, 86	f	large
53009	60315	13	Мурманская область, Мурманск, улица Александра Невского, 86	f	large
53008	60315	12	Мурманская область, Мурманск, улица Александра Невского, 86	f	large
53435	60654	484	Мурманская область, Терский район	f	medium
53068	60351	72	Мурманская область, Мурманск, капитана Тарана, 1	f	large
53139	60395	144	Мурманская область, Мурманск, капитана Копытова, 36	f	large
53138	60395	143	Мурманская область, Мурманск, капитана Копытова, 36	f	large
53137	60395	142	Мурманская область, Мурманск, капитана Копытова, 36	f	large
53136	60395	141	Мурманская область, Мурманск, капитана Копытова, 36	f	large
53128	60389	132	Мурманская область, Мурманск, Якорный переулок, 5	f	large
53127	60389	131	Мурманская область, Мурманск, Якорный переулок, 5	f	large
53012	60316	16	Мурманская область, Мурманск, Чумбарова-Лучинского, 3Б	f	large
53011	60316	15	Мурманская область, Мурманск, Чумбарова-Лучинского, 3Б	f	large
53013	60316	17	Мурманская область, Мурманск, Чумбарова-Лучинского, 3Б	f	large
53086	60362	90	Мурманская область, Мурманск, Чехова, 11	f	large
53085	60362	89	Мурманская область, Мурманск, Чехова, 11	f	large
53038	60331	42	Мурманская область, Мурманск, Челюскинцев, 14	f	large
53037	60331	41	Мурманская область, Мурманск, Челюскинцев, 14	f	large
53017	60320	21	Мурманская область, Мурманск, Халатина, 7	f	large
52998	60307	2	Мурманская область, Мурманск, Торцева, 1	f	large
53097	60372	101	Мурманская область, Мурманск, Спортивная, 13	f	medium
53116	60383	120	Мурманская область, Мурманск, Спартака, 11	f	large
53115	60383	119	Мурманская область, Мурманск, Спартака, 11	f	large
53046	60338	50	Мурманская область, Мурманск, Софьи Перовской, 3	f	large
53063	60347	67	Мурманская область, Мурманск, Связи проезд, 30	f	large
53062	60347	66	Мурманская область, Мурманск, Связи проезд, 30	f	large
53002	60311	6	Мурманская область, Мурманск, Сафонова, 11	f	large
53001	60310	5	Мурманская область, Мурманск, Сафонова, 18	f	large
53000	60309	4	Мурманская область, Мурманск, Сафонова, 37	f	large
53073	60354	77	Мурманская область, Мурманск, Самойловой, 2	f	large
53084	60361	88	Мурманская область, Мурманск, Рылеева, 6	f	large
53047	60339	51	Мурманская область, Мурманск, Пушкинская, 3	f	large
53146	60399	151	Мурманская область, Мурманск, Прибрежная, 6	f	medium
53082	60359	86	Мурманская область, Мурманск, Полярные Зори, 1	f	large
53065	60348	69	Мурманская область, Мурманск, Полярные Зори, 60	f	large
53064	60348	68	Мурманская область, Мурманск, Полярные Зори, 60	f	large
53079	60357	83	Мурманская область, Мурманск, Полярной Дивизии, 1/16	f	large
53031	60326	35	Мурманская область, Мурманск, Подстаницкого, 1	f	medium
53095	60371	99	Мурманская область, Мурманск, Подгорная, 80	f	large
53034	60328	38	Мурманская область, Мурманск, Павлика Морозова, 3	f	large
53033	60328	37	Мурманская область, Мурманск, Павлика Морозова, 3	f	large
53113	60381	117	Мурманская область, Мурманск, Олега Кошевого, 12а	f	large
53112	60381	116	Мурманская область, Мурманск, Олега Кошевого, 12а	f	large
53030	60317	34	Мурманская область, Мурманск, Миронова, 5	f	large
53027	60317	31	Мурманская область, Мурманск, Миронова, 5	f	large
53028	60317	32	Мурманская область, Мурманск, Миронова, 5	f	large
53057	60344	61	Мурманская область, Мурманск, Мира, 12	f	large
53056	60344	60	Мурманская область, Мурманск, Мира, 12	f	large
53055	60344	59	Мурманская область, Мурманск, Мира, 12	f	large
53109	60350	113	Мурманская область, Мурманск, Лыжный проезд, 8	f	large
53108	60350	112	Мурманская область, Мурманск, Лыжный проезд, 8	f	large
53067	60350	71	Мурманская область, Мурманск, Лыжный проезд, 8	f	large
53103	60377	107	Мурманская область, Мурманск, Лесная, 39	f	large
53081	60358	85	Мурманская область, Мурманск, Ленина проспект, 14	f	large
53080	60358	84	Мурманская область, Мурманск, Ленина проспект, 14	f	large
53074	60353	78	Мурманская область, Мурманск, Ленина, 59	f	large
53072	60353	76	Мурманская область, Мурманск, Ленина, 59	f	large
53126	60387	130	Мурманская область, Мурманск, Ледокольный проезд, 23	f	large
53125	60387	129	Мурманская область, Мурманск, Ледокольный проезд, 23	f	large
53145	60398	150	Мурманская область, Мурманск, Крупской, 26	f	large
53144	60398	149	Мурманская область, Мурманск, Крупской, 26	f	large
134668	94993	453	Мурманская область, Мурманск, Коминтерна, 14	f	\N
53107	60379	111	Мурманская область, Мурманск, Кольский проспект, 27а	f	large
53078	60356	82	Мурманская область, Мурманск, Книповича, 48, кабинет 109	f	large
53076	60355	80	Мурманская область, Мурманск, Книповича, 35/2	f	large
53075	60355	79	Мурманская область, Мурманск, Книповича, 35/2	f	large
53077	60352	81	Мурманская область, Мурманск, Книповича, 36а	f	large
53071	60352	75	Мурманская область, Мурманск, Книповича, 36а	f	large
53070	60352	74	Мурманская область, Мурманск, Книповича, 36а	f	large
53101	60375	105	Мурманская область, Мурманск, Кирова проспект, 36/27	f	large
53100	60375	104	Мурманская область, Мурманск, Кирова проспект, 36/27	f	large
53099	60374	103	Мурманская область, Мурманск, Кирова , 17а	f	large
53043	60335	47	Мурманская область, Мурманск, Карла Либкнехта, 18а	f	large
53042	60335	46	Мурманская область, Мурманск, Карла Либкнехта, 18а	f	large
53105	60376	109	Мурманская область, Мурманск, Капитана Орликовой, 35	f	large
53104	60376	108	Мурманская область, Мурманск, Капитана Орликовой, 35	f	large
53102	60376	106	Мурманская область, Мурманск, Капитана Орликовой, 35	f	large
53061	60346	65	Мурманская область, Мурманск, Капитана Маклакова, 39	f	large
53060	60346	64	Мурманская область, Мурманск, Капитана Маклакова, 39	f	large
53048	60340	52	Мурманская область, Мурманск, Капитана Егорова, 5	f	large
53069	60349	73	Мурманская область, Мурманск, Капитана Буркова, 31	f	large
53066	60349	70	Мурманская область, Мурманск, Капитана Буркова, 31	f	large
53014	60318	18	Мурманская область, Мурманск, Казарменный переулок, 2	f	large
53024	60323	28	Мурманская область, Мурманск, Ивченко, 15	f	large
53023	60323	27	Мурманская область, Мурманск, Ивченко, 15	f	large
53022	60323	26	Мурманская область, Мурманск, Ивченко, 15	f	large
53114	60382	118	Мурманская область, Мурманск, Зои Космодемьянской, 2А	f	large
53280	60516	303	Мурманская область, Мурманск, Заречная, 60, ЗАТО Видяево	f	large
53279	60516	302	Мурманская область, Мурманск, Заречная, 60, ЗАТО Видяево	f	large
53032	60327	36	Мурманская область, Мурманск, Героев Североморцев проспект, 5к3	f	large
53007	60314	11	Мурманская область, Мурманск, Героев Североморцев проспект, 76/3	f	large
53006	60314	10	Мурманская область, Мурманск, Героев Североморцев проспект, 76/3	f	large
53005	60313	9	Мурманская область, Мурманск, Героев Североморцев проспект, 76/3	f	large
53004	60313	8	Мурманская область, Мурманск, Героев Североморцев проспект, 76/3	f	large
53142	60397	147	Мурманская область, Мурманск, Героев Рыбачьего, 58	f	large
53143	60397	148	Мурманская область, Мурманск, Героев Рыбачьего, 58	f	large
53135	60390	140	Мурманская область, Мурманск, Героев Рыбачьего, 15	f	large
53134	60390	139	Мурманская область, Мурманск, Героев Рыбачьего, 15	f	large
53129	60390	133	Мурманская область, Мурманск, Героев Рыбачьего, 15	f	large
53054	60343	58	Мурманская область, Мурманск, Георгия Седова, 8	f	large
53053	60343	57	Мурманская область, Мурманск, Георгия Седова, 8	f	large
53098	60373	102	Мурманская область, Мурманск, Генералова, 1/13	f	large
53083	60360	87	Мурманская область, Мурманск, Гвардейская, 14	f	large
53026	60324	30	Мурманская область, Мурманск, Гаджиева, 6А	f	large
53025	60324	29	Мурманская область, Мурманск, Гаджиева, 6А	f	large
53029	60325	33	Мурманская область, Мурманск, Гагарина, 21	f	large
53044	60336	48	Мурманская область, Мурманск, Володарского, 5	f	large
53119	60384	123	Мурманская область, Мурманск, Бочкова, 15	f	large
53118	60384	122	Мурманская область, Мурманск, Бочкова, 15	f	large
53117	60384	121	Мурманская область, Мурманск, Бочкова, 15	f	large
53124	60386	128	Мурманская область, Мурманск, Беринга, 18	f	large
53123	60386	127	Мурманская область, Мурманск, Беринга, 18	f	large
53122	60386	126	Мурманская область, Мурманск, Беринга, 18	f	large
53133	60394	138	Мурманская область, Мурманск, Баумана, 44	f	large
53132	60393	137	Мурманская область, Мурманск, Баумана, 39	f	large
53130	60392	135	Мурманская область, Мурманск, Баумана, 40	f	large
53131	60392	136	Мурманская область, Мурманск, Баумана, 40	f	large
53121	60385	125	Мурманская область, Мурманск, Баумана, 11	f	large
53120	60385	124	Мурманская область, Мурманск, Баумана, 11	f	large
53019	60321	23	Мурманская область, Мурманск, Аскольдовцев, 9	f	large
53018	60321	22	Мурманская область, Мурманск, Аскольдовцев, 9	f	large
53003	60312	7	Мурманская область, Мурманск, Адмирала Лобова, 18	f	large
53306	60541	330	Мурманская область, Мончегорск, пр.Металлургов, 30	f	large
53312	60548	336	Мурманская область, Мончегорск, пр. Металлургов, 1	f	medium
53310	60546	334	Мурманская область, Мончегорск, Царевского, 4а	f	large
53300	60535	324	Мурманская область, Мончегорск, Ферсмана, 7	f	large
53311	60547	335	Мурманская область, Мончегорск, Строительный проезд, 1	f	large
53309	60545	333	Мурманская область, Мончегорск, Строительная, 3	f	large
53304	60539	328	Мурманская область, Мончегорск, Проспект Кирова, 7	f	large
53307	60543	331	Мурманская область, Мончегорск, Новопроложенная, 7	f	large
53291	60527	315	Мурманская область, Мончегорск, Лесная, 10	f	large
53303	60538	327	Мурманская область, Мончегорск, Ленинградская наб, 43, корп.3	f	large
53301	60536	325	Мурманская область, Мончегорск, Котульского, 1	f	large
53294	60530	318	Мурманская область, Мончегорск, Кондрикова, 8	f	large
53293	60529	317	Мурманская область, Мончегорск, Кондрикова, 30	f	large
53308	60544	332	Мурманская область, Мончегорск, Комсомольская, 24	f	large
53297	60532	321	Мурманская область, Мончегорск, Комсомольская, 31/16	f	medium
53296	60532	320	Мурманская область, Мончегорск, Комсомольская, 31/16	f	medium
53302	60537	326	Мурманская область, Мончегорск, Кирова, 17	f	large
53295	60531	319	Мурманская область, Мончегорск, Бредова, 1	f	large
53292	60528	316	Мурманская область, Мончегорск, 3-я Нагорная, 42	f	large
53256	60483	266	Мурманская область, Кола, Победы, 7	f	large
53255	60482	265	Мурманская область, Кола, Защитников Заполярья проспект, 7	f	large
53441	60659	498	Мурманская область, село Коашва, 2, СДК н.п. Коашва	f	large
53234	60281	246	Мурманская область, Кировск, проспект Ленина, 25	f	large
53230	60281	242	Мурманская область, Кировск, проспект Ленина, 25	f	large
53232	60439	244	Мурманская область, Кировск, Советской Конституции, 10	f	large
53225	60467	237	Мурманская область, Кировск, Олимпийская, 57А	f	large
53224	60467	236	Мурманская область, Кировск, Олимпийская, 57А	f	large
53223	60466	235	Мурманская область, Кировск, Олимпийская, 8А	f	large
53222	60466	234	Мурманская область, Кировск, Олимпийская, 8А	f	large
53227	60107	239	Мурманская область, Кировск, Мира, 7	f	large
53231	60107	243	Мурманская область, Кировск, Мира, 7	f	large
53229	60107	241	Мурманская область, Кировск, Мира, 7	f	large
53228	59882	240	Мурманская область, Кировск, Мира, 9	f	large
53233	60449	245	Мурманская область, Кировск, Ленинградская, 2	f	large
53226	60468	238	Мурманская область, Кировск, Кондрикова, 5	f	large
53221	60465	233	Мурманская область, Кировск, Кирова, 27А	f	large
53220	60465	232	Мурманская область, Кировск, Кирова, 27А	f	large
53195	60440	202	Мурманская область, Кандалакша, Спекова, 50	f	large
53182	60430	189	Мурманская область, Кандалакша, Первомайская, 32	f	large
53181	60429	188	Мурманская область, Кандалакша, Первомайская, 9	f	large
53190	60436	197	Мурманская область, Кандалакша, Новая, 1	f	large
53189	60436	196	Мурманская область, Кандалакша, Новая, 1	f	large
53185	60433	192	Мурманская область, Кандалакша, Набережная, Набережная, 151	f	large
111663	60661	748	Мурманская область, Кандалакша, Мурманская, 24	f	\N
53198	60443	205	Мурманская область, Кандалакша, Высокая, 2	f	large
53180	60428	187	Мурманская область, Кандалакша, Восточная, 7	f	small
53179	60427	186	Мурманская область, Кандалакша, Беломорская, 19	f	small
53183	60431	190	Мурманская область, Кандалакша, Аэронавтов, 4а	f	large
53201	60445	208	Мурманская область, Кандалакша, 3-я Линия, 3	f	medium
53197	60442	204	Мурманская область, Кандалакша, 2-я Парковая, 11	f	medium
53196	60441	203	Мурманская область, Кандалакша, Кировская аллея, 1а	f	large
53298	60533	322	Мурманская область, Город Мончегорск, проспект Металлургов, 39А	f	large
134576	94435	462	Мурманская область, Гаджиево, Советская, 74/2	f	large
53420	60639	463	Мурманская область, Гаджиево, Колышкина, 114А	f	large
53421	60640	464	Мурманская область, Гаджиево, Душенова, 90А	f	large
53418	60637	461	Мурманская область, Гаджиево, Гаджиева, 40	f	large
53417	60636	460	Мурманская область, Гаджиево, Гаджиева, 33/1	f	large
53374	60599	407	Мурманская область, Белокаменка, Детский сад	f	small
53165	60415	170	Мурманская область, Апатиты, Ферсмана, 24	f	large
53161	60412	166	Мурманская область, Апатиты, Ферсмана, 40а	f	large
53151	60404	156	Мурманская область, Апатиты, Ферсмана, 14	f	large
53169	60419	174	Мурманская область, Апатиты, Строителей, 97	f	large
53149	60402	154	Мурманская область, Апатиты городской округ, Сидоренко, 22а	f	large
53159	60410	164	Мурманская область, Апатиты, Ленина, 24	f	medium
53158	60410	163	Мурманская область, Апатиты, Ленина, 24	f	large
53155	60407	160	Мурманская область, Апатиты, Ленина, 19а	f	large
53154	60406	159	Мурманская область, Апатиты, Ленина, 11	f	large
53153	60405	158	Мурманская область, Апатиты, Космонавтов, 19	f	large
53152	60405	157	Мурманская область, Апатиты, Космонавтов, 19	f	large
53167	60417	172	Мурманская область, Апатиты, Кирова, 18	f	large
53172	60421	177	Мурманская область, Апатиты, Зиновьева, 18	f	large
53164	60414	169	Мурманская область, Апатиты, Зиновьева, 5	f	large
53160	60411	165	Мурманская область, Апатиты, Зиновьева, 5а	f	large
53173	60420	178	Мурманская область, Апатиты, Жемчужная, 38	f	large
53170	60420	175	Мурманская область, Апатиты, Жемчужная, 38	f	large
53171	60418	176	Мурманская область, Апатиты, Дзержинского, 34	f	large
53168	60418	173	Мурманская область, Апатиты, Дзержинского, 34	f	large
53150	60403	155	Мурманская область, Апатиты, Дзержинского, 53	f	large
53163	60413	168	Мурманская область, Апатиты, Бредова, 2а	f	large
53162	60413	167	Мурманская область, Апатиты, Бредова, 2а	f	large
53156	60408	161	Мурманская область, Апатиты, Бредова, 27а	f	large
53157	60408	162	Мурманская область, Апатиты, Бредова, 27а	f	large
53434	60653	483	Мурманская область, Терский район, поселок Умба, Приморская, 43	f	medium
53438	60656	487	Мурманская область, Терский район, поселок Умба, Беломорская, 1А	f	large
53437	60655	486	Мурманская область, Терский район, поселок Умба, Беломорская, 1В	f	medium
53436	60655	485	Мурманская область, Терский район, поселок Умба, Беломорская, 1В	f	large
53433	60652	482	Мурманская область, Терский район, Умба, Совхозная, 12а	f	small
53432	60651	481	Мурманская область, Терский район, село Варзуга, Успенская, 75	f	small
53413	60630	448	Мурманская область, Североморск городской округ, Щукозеро, Агеева, 7а	f	medium
53408	60625	443	Мурманская область, Североморск городской округ, поселок Сафоново, Панина, 11а	f	large
53409	60627	444	Мурманская область, Североморск городской округ, поселок Росляково, Приморская, 2	f	large
53412	60629	447	Мурманская область, Североморск городской округ, поселок Росляково, Молодежная,, 14	f	medium
53411	60628	446	Мурманская область, Североморск городской округ, поселок Росляково, Заводкая, 1	f	large
53410	60628	445	Мурманская область, Североморск городской округ, поселок Росляково, Заводкая, 1	f	large
53341	60556	368	Мурманская область, Печенгский район, поселок Никель, пр.Гвардейский, 33	f	large
53343	60572	370	Мурманская область, Печенгский район, поселок Никель, Спортивная, 13	f	large
53342	60571	369	Мурманская область, Печенгский район, поселок Никель, Сидоровича, 16	f	medium
53337	60570	364	Мурманская область, Печенгский район, поселок Никель, Сидоровича, 13	f	medium
53340	60542	367	Мурманская область, Печенгский район, поселок Никель, Печенгская, 1 А	f	large
53338	60496	365	Мурманская область, Печенгский район, поселок Никель, Октябрьская, 1	f	large
53336	60569	363	Мурманская область, Печенгский район, поселок Никель, Гвардейский, 21	f	large
53339	60511	366	Мурманская область, Печенгский район, поселок Никель, Бредова, 2	f	large
53365	60591	390	Мурманская область, Печенгский район, село Корзуново, Филиал школы №7	f	small
53355	60578	376	Мурманская область, Печенгский район, Заполярный, Стрельцова, 1 А	f	large
53354	60582	381	Мурманская область, Печенгский район, Заполярный, Сафонова, 9 А	f	large
53350	60579	377	Мурманская область, Печенгский район, Заполярный, Мира, 2А	f	large
53348	60577	375	Мурманская область, Печенгский район, Заполярный, Ленинградская, 4 А	f	large
53356	60576	374	Мурманская область, Печенгский район, Заполярный, Ленина, 4	f	small
53353	60581	380	Мурманская область, Печенгский район, Заполярный, Крупской, 2 А	f	large
53352	60581	379	Мурманская область, Печенгский район, Заполярный, Крупской, 2 А	f	medium
53351	60580	378	Мурманская область, Печенгский район, Заполярный, Космонавтов, 6 А	f	large
53357	60583	383	Мурманская область, Печенгский район, Заполярный, Юбилейная, 14	f	medium
53358	60583	382	Мурманская область, Печенгский район, Заполярный, Юбилейная, 14	f	large
53328	60561	355	Мурманская область, Мончегорск городской округ, село Высокий, Сыромятникова, 13а	f	large
53327	60561	354	Мурманская область, Мончегорск городской округ, село Высокий, Сыромятникова, 13а	f	large
53314	60550	338	Мурманская область, Мончегорск городской округ, село 27 километр, Октябрьская, 14А	f	large
53313	60549	337	Мурманская область, Мончегорск городской округ, село 25 километр, Красный уголок	f	small
53286	60522	309	Мурманская область, Ловозерский район, поселок Ревда, Победы, 16а	f	large
53288	60524	311	Мурманская область, Ловозерский район, поселок Ревда, Металлургов, 6	f	large
53287	60523	310	Мурманская область, Ловозерский район, поселок Ревда, Металлургов, 5	f	large
53282	60518	305	Мурманская область, Ловозерский район, село Ловозеро, Советская, 30	f	large
53271	60513	291	Мурманская область, Кольский район, п.г.т. Туманный, Энергетиков, 2А	f	medium
53266	60498	278	Мурманская область, Кольский район, поселок Шонгуй, Комсомольская, 5	f	medium
53274	60512	290	Мурманская область, Кольский район, село Ура-Губа, Рыбацкая, 35	f	small
53277	60500	280	Мурманская область, Кольский район, село Тулома, Мира, 6	f	medium
53414	60631	449	Мурманская область, Кольский район, село Североморск 2I, Школьная, 7	f	large
53268	60503	283	Мурманская область, Кольский район, Пушной, Центральная, 14	f	medium
53269	60504	284	Мурманская область, Кольский район, село Песчаный, Ткачёва, 1	f	small
53262	60486	269	Мурманская область, Кольский район, поселок Мурмаши, Энергетиков, 19	f	large
53263	60487	270	Мурманская область, Кольский район, поселок Мурмаши, Советская, 18	f	large
53276	60492	273	Мурманская область, Кольский район, Мурмаши, Причальная, 30	f	large
53275	60490	272	Мурманская область, Кольский район, поселок Мурмаши, Гвардейская, 6	f	large
53261	60494	275	Мурманская область, Кольский район, поселок Молочный, Торговая, 1А	f	large
53260	60493	274	Мурманская область, Кольский район, поселок Молочный, Торговая, 8	f	large
53253	60509	288	Мурманская область, Кольский район, село Мишуково, Почтовая, 19	f	small
53251	60507	286	Мурманская область, Кольский район, село Минькино, 135	f	small
53252	60508	287	Мурманская область, Кольский район, Междуречье, Строительная, 5А	f	medium
53267	60499	279	Мурманская область, Кольский район, село Магнетиты, Набережная, 14	f	small
53257	60484	267	Мурманская область, Кольский район, Кола, Советский проспект, 41а	f	large
53258	60485	268	Мурманская область, Кольский район, Кола, Приморская, 2	f	large
53265	60497	277	Мурманская область, Кольский район, поселок Кильдинстрой, Советская улица, 2	f	large
53254	60510	289	Мурманская область, Кольский район, село Килпъявр, Небольсина, 12	f	small
53264	60495	276	Мурманская область, Кольский район, село Зверосовхоз, Зеленая, 14	f	large
53176	60424	182	Мурманская область, Кольский район, Заозерск, переулок Школьный, 6	f	large
53178	60426	184	Мурманская область, Кольский район, Заозерск, Мира, 5А	f	large
53177	60425	183	Мурманская область, Кольский район, Заозерск, Мира, 5А	f	large
53174	60422	180	Мурманская область, Кольский район, Заозерск, Колышкина, 16	f	large
53281	60517	304	Мурманская область, Кольский район, село Видяево, Нагорная, 5	f	large
53278	60502	282	Мурманская область, Кольский район, поселок Верхнетуломский, Дружбы, 20	f	large
53248	60480	261	Мурманская область, Ковдорский район, село Риколатва, Победы, 3А, ЖЭУ МУП	f	small
53245	60477	258	Мурманская область, Ковдорский район, село Куропта, место для голосования - МУК ""Сельский"	f	small
53237	60470	250	Мурманская область, Ковдорский район, Ковдор, Чехова, 8	f	large
53236	60470	249	Мурманская область, Ковдорский район, Ковдор, Чехова, 8	f	large
53244	60476	257	Мурманская область, Ковдорский район, Ковдор, Комсомольская, 6А	f	large
53243	60476	256	Мурманская область, Ковдорский район, Ковдор, Комсомольская, 6А	f	large
53239	60472	252	Мурманская область, Ковдорский район, Ковдор, Комсомольская, 14	f	large
53238	60471	251	Мурманская область, Ковдорский район, Ковдор, Комсомольская, 15	f	large
53241	60474	254	Мурманская область, Ковдорский район, Ковдор, Кирова, 24	f	large
53242	60475	255	Мурманская область, Ковдорский район, Ковдор, Школьная, 2	f	large
53247	60479	260	Мурманская область, Ковдорский район, село Енский, МОУ ДОД	f	large
53246	60478	259	Мурманская область, Ковдорский район, село Ена, МУК Сельский дом	f	small
53440	60658	497	Мурманская область, Кировск городской округ, Титан, 14, СДК н.п. Титан	f	large
53194	60438	201	Мурманская область, Кандалакшского района, Кандалакша, Спекова, 15	f	large
53193	60438	200	Мурманская область, Кандалакшского района, Кандалакша, Спекова, 15	f	large
53192	60437	199	Мурманская область, Кандалакшский район, Кандалакша, Спекова, 7	f	medium
53191	60437	198	Мурманская область, Кандалакшский район, Кандалакша, Спекова, 7	f	large
53187	60434	194	Мурманская область, Кандалакшский район, Кандалакша, Первомайская, 67	f	large
53186	60434	193	Мурманская область, Кандалакшский район, Кандалакша, Первомайская, 67	f	large
53184	60432	191	Мурманская область, Кандалакшский район, Кандалакша, Комсомольская, 10	f	large
53212	60456	219	Мурманская область, Кандалакшский район, поселок Зеленоборский, Школьная, 1А	f	large
53213	60457	220	Мурманская область, Кандалакшский район, поселок Зеленоборский, Центральная, 11а	f	medium
53207	60452	214	Мурманская область, Кандалакшский район, поселок Зареченск, Кумская, 2	f	medium
53204	60448	211	Мурманская область, Кандалакша городской округ, поселок Нивский, Букина, 1	f	large
53203	60447	210	Мурманская область, Кандалакша городской округ, село Лувеньга, Молодежная, 11	f	medium
53208	60453	215	Мурманская область, Кандалакша городской округ, село Ковдозеро, Первомайская	f	small
53211	60455	218	Мурманская область, Кандалакша городской округ, поселок Зеленоборский, Энергетическая, 24А	f	large
53210	60454	217	Мурманская область, Кандалакша городской округ, поселок Зеленоборский, Озерная, 27А	f	medium
53209	60454	216	Мурманская область, Кандалакша городской округ, поселок Зеленоборский, Озерная, 27А	f	large
53216	60458	221	Мурманская область, Кандалакша городской округ, село Алакуртти, Содружества, 1	f	medium
53217	60459	222	Мурманская область, Кандалакша городской округ, село Алакуртти, Набережная, 37	f	medium
53377	60601	411	Мурманская область, Апатиты городской округ, Полярные Зори, Сивко, 5	f	large
53376	60601	410	Мурманская область, Апатиты городской округ, Полярные Зори, Сивко, 5	f	large
53375	60600	409	Мурманская область, Апатиты городской округ, Полярные Зори, Пушкина, 18	f	large
53383	60605	417	Мурманская область, Апатиты городской округ, Полярные Зори, Партизан Заполярья, 5а, (гимназия)	f	large
53382	60605	416	Мурманская область, Апатиты городской округ, Полярные Зори, Партизан Заполярья, 5а, (гимназия)	f	large
53381	60604	415	Мурманская область, Апатиты городской округ, Полярные Зори, Курчатова, 25 , шк.№4	f	large
53380	60604	414	Мурманская область, Апатиты городской округ, Полярные Зори, Курчатова, 25 , шк.№4	f	large
53379	60602	413	Мурманская область, Апатиты городской округ, Полярные Зори, Белова, 7А, шк.№3	f	large
53378	60602	412	Мурманская область, Апатиты городской округ, Полярные Зори, Белова, 7А, шк.№3	f	large
53384	60606	418	Мурманская область, Апатиты городской округ, поселок Зашеек	f	medium
53386	60608	420	Мурманская область, Апатиты городской округ, поселок Африканда 2-я, Советская, 8	f	large
134573	94434	469	Ленинградская область, посекло Выра, Большой пр., 32-а , помещение музея Дом станционного смотрителя	f	\N
67380	52322	884	Ленинградская область, Тосно, Чехова, 8, МОУ Средняя общеобразовательная школа №4	f	\N
67379	52321	883	Ленинградская область, Тосно, Чехова, 8, МОУ Средняя общеобразовательная школа №4	f	\N
67381	52323	885	Ленинградская область, Тосно, Островского, 3А, МОУ ДОД Тосненская школа искусств	f	\N
66955	51707	193	Ленинградская область, Тосно, Октябрьская набережная , 35, ВНИИ пожарной охраны.	f	\N
67386	52328	890	Ленинградская область, Тосно, Октябрьская , 125, ООО ТПК ИСКОЖ-Тосно	f	\N
67378	52320	882	Ленинградская область, Тосно, Максима Горького, 5, МОУ Тосненская средняя общеобразовательная школа №3	f	\N
67389	52331	893	Ленинградская область, Тосно, Гоголя, 8, Гимназия №2	f	\N
67408	52291	839	Ленинградская область, Тихвин, 38, МОУ Лицей №7	f	\N
67409	52291	840	Ленинградская область, Тихвин, 38, МОУ Лицей №7	f	\N
67354	52300	853	Ленинградская область, Тихвин, Центролитовская, 5, Тихвинский промышленно-гуманитарный техникум	f	\N
67410	52292	841	Ленинградская область, Тихвин, Карла Маркса, 43, МОУ Средняя общеобразовательная школа №3	f	\N
67412	52293	843	Ленинградская область, Тихвин, 5 микрорайон, 37, МОУ Гимназия №2	f	\N
67411	52293	842	Ленинградская область, Тихвин, 5 микрорайон, 37, МОУ Гимназия №2	f	\N
67402	52288	833	Ленинградская область, Тихвин, 1 микрорайон, 37, МОУ Средняя общеобразовательная школа №6	f	\N
67403	52288	834	Ленинградская область, Тихвин, 1 микрорайон, 37, МОУ Средняя общеобразовательная школа №6	f	\N
66785	51639	108	Ленинградская область, Сясьстрой, Кирова, 162-а	f	\N
67541	52385	949	Ленинградская область, Сосновый Бор, проспект Героев, 62, Шахматный клуб	f	\N
67539	52383	947	Ленинградская область, Сосновый Бор, проспект Героев, 36, школа №4	f	\N
67538	52383	946	Ленинградская область, Сосновый Бор, проспект Героев, 36, школа №4	f	\N
67540	52384	948	Ленинградская область, Сосновый Бор, Солнечная, 31, Гимназия №5	f	\N
67260	52166	710	Ленинградская область, Сосновый Бор, Солнечная, 1	f	\N
67546	52388	954	Ленинградская область, Сосновый Бор, Молодежная, 32, школа №7	f	\N
67545	52388	953	Ленинградская область, Сосновый Бор, Молодежная, 32, школа №7	f	\N
67544	52387	952	Ленинградская область, Сосновый Бор, Молодежная, 31, школа №6	f	\N
67543	52387	951	Ленинградская область, Сосновый Бор, Молодежная, 31, школа №6	f	\N
67536	52337	944	Ленинградская область, Сосновый Бор, Малая Земля, 5, школа №3	f	\N
67537	52337	945	Ленинградская область, Сосновый Бор, Малая Земля, 5, школа №3	f	\N
67550	52390	958	Ленинградская область, Сосновый Бор, Липовский проезд, 13, школа №9	f	\N
67549	52390	957	Ленинградская область, Сосновый Бор, Липовский проезд, 13, школа №9	f	\N
67548	52389	956	Ленинградская область, Сосновый Бор, Ленинградская, 64, Лицей №8	f	\N
67547	52389	955	Ленинградская область, Сосновый Бор, Ленинградская, 64, Лицей №8	f	\N
67534	52381	942	Ленинградская область, Сосновый Бор, Космонавтов, 14, школа №2	f	\N
67535	52370	943	Ленинградская область, Сосновый Бор, Космонавтов, 22	f	\N
67533	52380	941	Ленинградская область, Сосновый Бор, Комсомольская, 11, школа №1	f	\N
67532	52380	940	Ленинградская область, Сосновый Бор, Комсомольская, 11, школа №1	f	\N
67531	52379	939	Ленинградская область, Сосновый Бор, Комсомольская, 2А	f	\N
67542	52386	950	Ленинградская область, Сосновый Бор, пр.Героев, 63А, ЦРЛ Гармония	f	\N
67347	52276	821	Ленинградская область, Сланцы, площадь Ленина, 1, Дворец культуры ОАО Завод Сланцы	f	\N
67346	52276	820	Ленинградская область, Сланцы, площадь Ленина, 1, Дворец культуры ОАО Завод Сланцы	f	\N
67503	52271	815	Ленинградская область, Сланцы, Шахтёрской Славы, 9б, Театр кукол	f	\N
67500	52267	812	Ленинградская область, Сланцы, Максима Горького, 9, МОУ СОШ №1	f	\N
67507	52275	819	Ленинградская область, Сланцы, Ломоносова, 39, МОУ Сланцевская СОШ №2	f	\N
67495	52262	807	Ленинградская область, Сланцы, Ленина, 25, Театр Бумс	f	\N
67513	52256	801	Ленинградская область, Сланцы, Комсомольское шоссе, 21, ГП Сланцевское ДРСУ	f	\N
67348	52277	822	Ленинградская область, Сланцы, Декабристов, 13, МУ Центр социального обслуживания пожилого возраста и инвалидоа Надежда	f	\N
67494	52261	806	Ленинградская область, Сланцы, Грибоедова, 19б, МОУ Сланцевская общеобразовательная школа №3	f	\N
66674	51651	125	Ленинградская область, Сертолово, Молодцова, 4к.2, школа №2, столовая	f	\N
66861	51808	300	Ленинградская область, Селезнёво, Детский сад Веселый ручеек	f	\N
67431	52220	765	Ленинградская область, Приозерск, Чапаева, 19, ГОУ СПО Приозерский политехнический колледж №5холл	f	\N
67438	52227	772	Ленинградская область, Приозерск, Ленина, 22, школа №5	f	\N
67437	52226	771	Ленинградская область, Приозерск, Исполкомская, 5, киноконцертный зал, холл 2-го этажа	f	\N
67435	52224	769	Ленинградская область, Приозерск, Гастелло, 3, МОУ Приозерская начальная школа-сад компенсирующего вида холл	f	\N
67281	52186	731	Ленинградская область, Подпорожье, Исакова, 19, помещение филиала Санкт-Петерб.инст. Внешнеэкон.связейЭкономики и права	f	\N
67285	52191	735	Ленинградская область, Подпорожье, Волкова, 29а	f	\N
67287	52193	737	Ленинградская область, Подпорожье, Горького, 13	f	\N
67315	52029	566	Ленинградская область, Отрадное, 1-й Советский проспект, 18, МОУ СШ №3	f	\N
67528	52376	936	Ленинградская область, Никольское, Октябрьская, 9А, МОУ СОШ №3 г.Никольское 1 этаж	f	\N
67244	52149	694	Ленинградская область, Луга, МОУ СОШ	f	\N
67242	52147	692	Ленинградская область, Луга, СОШ	f	\N
67234	52139	684	Ленинградская область, Луга, проспект Кирова, 74 , МОУ СОШ №3	f	\N
67232	52137	682	Ленинградская область, Луга, проспект Кирова, 75 , МУК Лужский городской ДК	f	\N
67230	52135	680	Ленинградская область, Луга, проспект Кирова, 39, МОУ ДОД Лужская школа искуссств	f	\N
67241	52146	691	Ленинградская область, Луга, проспект Володарского, 52, Лужский аграрно-промышленный колледж	f	\N
67240	52145	690	Ленинградская область, Луга, проспект Володарского, 15, ГУ Лужский центр занятости населения	f	\N
67238	52143	688	Ленинградская область, Луга, проспект Володарского, 30, Жилкомсервис №2	f	\N
67233	52138	683	Ленинградская область, Луга, Красной Артиллерии, 1	f	\N
67489	52134	679	Ленинградская область, Луга, Комсомольский проспект, 18, университет им. Кирилла и Мефодия	f	\N
67175	52075	616	Ленинградская область, Лодейное Поле, Свердлова, 4, МКОУ Лодейнопольская основная общеобразовательная школа №1	f	\N
67176	52076	617	Россия, Ленинградская область, Лодейное Поле, Октябрьский проспект, 40	f	\N
67171	52071	612	Ленинградская область, Лодейное Поле, Ленина проспект, 94, ОВО при ОМВО ОМВД по Лодейнопольскому р-нуспортзал	f	\N
67170	52070	611	Ленинградская область, Лодейное Поле, Ленина проспект, 54а, МКОУ Лодейнопольская СОШ №2	f	\N
67169	52069	610	Ленинградская область, Лодейное Поле, Ленина проспект, 54а, МКОУ Лодейнопольская начальная общеобразовательная школа	f	\N
67166	52065	607	Россия, Ленинградская область, Лодейное Поле, Ленина проспект, 10	f	\N
67168	52068	609	Ленинградская область, Лодейное Поле, Гагарина, 10п.2	f	\N
67331	52042	582	Ленинградская область, Кировск, бульвар Партизанской Славы, 10, МОУ Кировская СОШ №2	f	\N
67330	52042	581	Ленинградская область, Кировск, бульвар Партизанской Славы, 10, МОУ Кировская СОШ №2	f	\N
67332	52043	583	Ленинградская область, Кировск, Молодёжная, 4а , МОУ ДОД ЦДТ Юность	f	\N
67121	52005	540	Ленинградская область, Кириши, проспект Победы, 1, ГОУСПО ЛО Киришский политехнический колледж	f	\N
67123	52006	542	Ленинградская область, Кириши, Строителей, 12, МОУ Киришская средняя общеобразовательная школа №6	f	\N
67122	52006	541	Ленинградская область, Кириши, Строителей, 12, МОУ Киришская средняя общеобразовательная школа №6	f	\N
67118	52002	537	Ленинградская область, Кириши, Пионерская, 6, МОУ Киришская общеобразовательная школа №1	f	\N
67117	52002	536	Ленинградская область, Кириши, Пионерская, 6, МОУ Киришская общеобразовательная школа №1	f	\N
67113	51997	532	Ленинградская область, Кириши, Молодёжный бульвар, 30, МОУ Киришская Средняя общеобразовательная школа №7	f	\N
67111	51995	530	Ленинградская область, Кириши, Молодежный бульвар, 30, Средняя общеобразовательная школа №7	f	\N
66846	51792	284	Ленинградская область, Каменногорск, Ленинградское шоссе, 93, МОУ «Каменногорская средняя общеобразовательная школа»	f	\N
67024	51991	521	Ленинградская область, Ивангород, Льнопрядильная, 8, клуб Парусинка	f	\N
67064	51881	380	Ленинградская область, Гатчина, Чехова, 11	f	\N
67079	51894	395	Ленинградская область, Гатчина, Слепнева, 25	f	\N
67080	51894	396	Ленинградская область, Гатчина, Слепнева, 25	f	\N
66932	51875	372	Ленинградская область, Гатчина, Киргетова, 28	f	\N
67066	51883	382	Ленинградская область, Гатчина, Карла Маркса, 17А, Институт ГИЭФПТ	f	\N
67077	51891	393	Ленинградская область, Гатчина, Генерала Кныша, 72	f	\N
67075	51891	391	Ленинградская область, Гатчина, Генерала Кныша, 72	f	\N
67071	51888	387	Ленинградская область, Гатчина, Генерала Кныша, 14а	f	\N
67065	51882	381	Ленинградская область, Гатчина, Володарского, 17	f	\N
66808	51753	245	Ленинградская область, Выборг, пл. Школьная, 2	f	\N
66809	51754	246	Ленинградская область, Выборг, Школьная площадь, 4, МОУ «Средняя общеобразовательная школа №7»	f	\N
66813	51758	250	Ленинградская область, Выборг, Сухова, 7а, МДОУ Детский сад компенсирующего вида	f	\N
66804	51749	241	Ленинградская область, Выборг, Суворова, 4	f	\N
66818	51764	256	Ленинградская область, Выборг, Спортивная, 14, МБДОУ «Детский сад комбинированного вида «Улыбка»»	f	\N
66805	51750	242	Ленинградская область, Выборг, Советская, 16	f	\N
66834	51780	272	Ленинградская область, Выборг, Рубежная, 28а, Комплексный центр социального обслуживания «Выборг»	f	\N
66803	51748	240	Ленинградская область, Выборг, Пушкина, 12, 102-ой корпус МОУ « Гимназия»	f	\N
66823	51769	261	Ленинградская область, Выборг, Промышленная, 1, ГАОУ НПО ЛО Профессиональное училище № 46	f	\N
66825	51771	263	Ленинградская область, Выборг, Офицерская, 2, Выборгский филиал ФГОУ ВПО Санкт-Петербургского университета гражданской авиации	f	\N
66814	51759	251	Ленинградская область, Выборг, Ленинградское шоссе, 45а, МОУ Средняя общеобразовательная школа № 8	f	\N
66826	51772	264	Ленинградская область, Выборг, Горная, 10/3, МОУ Средняя общеобразовательная школа №37	f	\N
66800	51745	237	Ленинградская область, Выборг, Выборгская, 2, Выборгский институт АОУ ВПО «ЛГУ им. А.С. Пушкина»	f	\N
66837	51783	275	Ленинградская область, Выборг, Аристарха Макарова, 6, МДОУ Детский сад комбинированного вида № 25 Золотая рыбка	f	\N
66975	51725	214	Ленинградская область, Всеволожск, Межевая, 10, средняя школа №2	f	\N
66974	51725	213	Ленинградская область, Всеволожск, Межевая, 10, средняя школа №2	f	\N
66976	51726	215	Ленинградская область, Всеволожск, Ленинградская, 14/1, ЗАО Труд	f	\N
66971	51721	209	Ленинградская область, Всеволожск, Колтушское шоссе, 110, Дом культуры	f	\N
66970	51721	208	Ленинградская область, Всеволожск, Колтушское шоссе, 110, Дом культуры	f	\N
66980	51731	221	Ленинградская область, Всеволожск, Бибиковская, 2, моложежно-подростковый клуб Пульс	f	\N
66728	51604	73	Ленинградская область, Волхов, проспект Державина, 65, неполная коррекционная школа №4	f	\N
66737	51613	82	Ленинградская область, Волхов, Ломоносова, 7, гор.Гимназия	f	\N
66742	51530	2	Ленинградская область, Бокситогорск, Социалистическая, 26-А, МОУ СОШ №3	f	\N
66741	51529	1	Ленинградская область, Бокситогорск, Павлова, 20	f	\N
66744	51532	4	Ленинградская область, Бокситогорск, Косомольская, 5а, Культурный досуговый центр	f	\N
67519	52366	927	Ленинградская область, Тосненский район, городской посёлок Ульяновка, Колпинская, 6, МОУ ДОД Ульяновская детская музыкальная школа	f	\N
67467	52339	900	Ленинградская область, Тосненский район, городской посёлок Рябово, Мысленская, 7, филиал МУК Пельгорский ДК	f	\N
67481	52354	914	Ленинградская область, Тосненский район, посёлок Шапки, Нины Куковеровой, 4	f	\N
67479	52352	912	Ленинградская область, Тосненский район, деревня Чудской Бор, Новая, 1	f	\N
67483	52356	916	Ленинградская область, Тосненский район, деревня Фёдоровское, Шоссейная, 7, МУК Федоровский Дом культуры	f	\N
67482	52355	915	Ленинградская область, Тосненский район, посёлок Форносово, Павловское шоссе, 29-а, МУК Форносовский Дом культуры	f	\N
67390	52332	894	Ленинградская область, Тосненский район, поселок Ушаки, 19, МОУ Ушакинская средняя общеобразовательная школа №1	f	\N
67289	52195	739	Ленинградская область, Подпорожский район, Подпорожье, Северная, 40	f	\N
67463	52334	896	Ленинградская область, Тосненский район, поселок Ушаки, пр.Кирова, 200а, МОУ Ушакинская средняя общеобразовательная школа №2	f	\N
67462	52333	895	Ленинградская область, Тосненский район, поселок Ушаки, пр.Кирова, 143, МУК Ушакинский центр досуга и нар.творчества в селе Ушаки	f	\N
67520	52367	928	Ленинградская область, Тосненский район, поселок Ульяновка, Советский проспект, 3, МУК ТКЦ Саблино	f	\N
67522	52369	930	Ленинградская область, Тосненский район, посёлок Ульяновка, Володарский проспект, 70, МОУ СОШ №1правая рекреация СОШ	f	\N
67521	52368	929	Ленинградская область, Тосненский район, посёлок Ульяновка, Володарский проспект, 70, МОУ Ульяновская средняя общеобразовательная школа №1	f	\N
67518	52365	926	Ленинградская область, Тосненский район, посёлок Ульяновка, 2-я Футбольная улица, 1, МОУ Саблинская основная общеобразовательная школа	f	\N
67517	52364	925	Ленинградская область, Тосненский район, посёлок Ульяновка, 2-я Футбольная улица, 1, МОУ Саблинская основная общеобразовательная школа	f	\N
67476	52349	909	Ленинградская область, Тосненский район, деревня Трубников Бор, Мира, 1А, МОУ Трубниковская основная общеобразовательная школа	f	\N
67385	52327	889	Ленинградская область, Тосненский район, Тосно, улица Максима Горького, 5, помещение МОУ СОШ №3	f	\N
67383	52325	887	Россия, Ленинградская область, Тосненский район, Тосно, улица Максима Горького, 15	f	\N
67387	52329	891	Ленинградская область, Тосненский район, Тосно, проспект Ленина, 40, МУ СКК Космонавт	f	\N
67382	52324	886	Ленинградская область, Тосненский район, Тосно, проспект Ленина, 42, МОУ ДОД Дом детского творчества	f	\N
67376	52317	879	Ленинградская область, Тосненский район, Тосно, проспект Ленина, 24, МОУ Средняя общеобразовательная школа №1 г.Тосно	f	\N
67375	52316	878	Ленинградская область, Тосненский район, Тосно, проспект Ленина, 24, МОУ Средняя общеобразовательная школа №1 г.Тосно	f	\N
67384	52326	888	Ленинградская область, Тосненский район, Тосно, Советская, 10а, Комитет образования МО Тосненский район	f	\N
67388	52330	892	Ленинградская область, Тосненский район, Тосно, Пушкинская набережная, 1	f	\N
67374	52315	877	Ленинградская область, Тосненский район, Тосно, Московское шоссе, 40, аптека МУЗ Тосненская ЦРБ	f	\N
67393	52359	919	Ленинградская область, Тосненский район, посёлок Тельмана, 50	f	\N
67394	52348	920	Ленинградская область, Тосненский район, посёлок Тельмана, Октябрьская, 5	f	\N
67391	52357	917	Ленинградская область, Тосненский район, посёлок Тельмана, Ленинградская, 7, МОУ Тельмановская средняя общеобразовательная школа	f	\N
67392	52358	918	Ленинградская область, Тосненский район, посёлок Тельмана, Красноборская, 5	f	\N
67464	52335	897	Ленинградская область, Тосненский район, деревня Тарасово, 1	f	\N
67469	52341	902	Ленинградская область, Тосненский район, поселок Сельцо, 16, ОУ Сельцовская средняя общеобразовательная школа им.Е.М.Мелашенко	f	\N
67471	52343	904	Ленинградская область, Тосненский район, посёлок Сельцо, 18, МОУ Сельцовская средняя общеобразовательная школа им.Е.М.Мелашенко	f	\N
67468	52340	901	Ленинградская область, Тосненский район, посёлок Рябово, Рычина, 8, МУК Пельгорский Дом культуры	f	\N
67466	52338	899	Ленинградская область, Тосненский район, посёлок Радофинниково, Комсомольская, 6, МОУ Радофинниковская основная общеобразовательная школа	f	\N
67478	52351	911	Ленинградская область, Тосненский район, деревня Померанье, Московское шоссе, 27А	f	\N
67480	52353	913	Ленинградская область, Тосненский район, деревня Нурма, 8, МОУ ДОД Центр внешкольной работы 	f	\N
67377	52319	881	Ленинградская область, Тосненский район, деревня Новолисино, Заводская, 11, Новолисинская школа-интернат среднего общего образования	f	\N
67526	52374	934	Ленинградская область, Тосненский район, Никольское, Школьная , 11, МОУ Гимназия №1 г.Никольское	f	\N
67525	52373	933	Ленинградская область, Тосненский район, Никольское, Советский проспект, 166а, МУК Никольский ДК	f	\N
67523	52371	931	Россия, Ленинградская область, Тосненский район, Никольское, Первомайская улица, 12	f	\N
67524	52372	932	Ленинградская область, Тосненский район, Никольское, Первомайская, 10, МОУ СОШ №2 г.Никольское	f	\N
67529	52377	937	Ленинградская область, Тосненский район, Никольское, Октябрьская, 9А, МОУ СОШ №3 г.Никольское1 этаж	f	\N
67527	52375	935	Ленинградская область, Тосненский район, Никольское, Дачная, 6, МУ Спортивно-досуговый Центр Надежда	f	\N
67475	52347	908	Ленинградская область, Тосненский район, посёлок Любань, проспект Мельникова, 18, МДОУ №17 Детский сад общеразвивающего вида пос.Любань	f	\N
67470	52342	903	Россия, Ленинградская область, Тосненский район, посёлок Любань, проспект Мельникова, 15	f	\N
67474	52346	907	Ленинградская область, Тосненский район, Любань, Торговая улица, 16, магазин №69 Тосненского РАЙПО	f	\N
67472	52344	905	Ленинградская область, Тосненский район, Любань, Заводская улица, 1	f	\N
67473	52345	906	Ленинградская область, Тосненский район, посёлок Любань, Алексеенко, 24а, МОУ Любанская средняя общеобразовательная школа им.А.Н.Радищева	f	\N
67465	52336	898	Россия, Ленинградская область, Тосненский район, посёлок Лисино-Корпус	f	\N
67515	52362	923	Ленинградская область, Тосненский район, посёлок Красный Бор, пр. Советский, 47, МОУ Красноборская средняя общеобразовательная школа	f	\N
67516	52363	924	Ленинградская область, Тосненский район, посёлок Красный Бор, Культуры, 62А	f	\N
67514	52361	922	Ленинградская область, Тосненский район, посёлок Красный Бор, Комсомольская улица, 6, пус государственного предприятия радиовещания Радиоцентр-11	f	\N
67530	52378	938	Ленинградская область, Тосненский район, поселок Гладкое, Школьная, 5, Гладковская сельская библиотека	f	\N
67395	52360	921	Ленинградская область, Тосненский район, посёлок Войскорово, 3, МОУ Войскоровская средняя общеобразовательная школа	f	\N
67477	52350	910	Ленинградская область, Тосненский район, деревня Бабино-2, Московское шоссе, 63	f	\N
67371	52313	870	Ленинградская область, Тихвинский район, посёлок Шугозеро, Советская, 43, Администрация Шугозерского сельского поселения	f	\N
67372	52313	871	Ленинградская область, Тихвинский район, посёлок Шугозеро, Советская, 43, Администрация Шугозерского сельского поселения	f	\N
67370	52313	869	Ленинградская область, Тихвинский район, посёлок Шугозеро, Советская, 43, Администрация Шугозерского сельского поселения	f	\N
67363	52307	862	Ленинградская область, Тихвинский район, посёлок Цвылёво, 2, Цвылёвский культурно-спортивный комплекс	f	\N
67362	52307	861	Ленинградская область, Тихвинский район, посёлок Цвылёво, 2, Цвылёвский культурно-спортивный комплекс	f	\N
67361	52306	860	Ленинградская область, Тихвинский район, посёлок Цвылёво, 46а, МОУ Ильинская СОШ	f	\N
67352	52299	851	Ленинградская область, Тихвинский район, Тихвин, площадь Свободы, 1, МУ Тихвинский районный Дом Культуры	f	\N
67353	52299	852	Ленинградская область, Тихвинский район, Тихвин, площадь Свободы, 1, МУ Тихвинский районный Дом Культуры	f	\N
66912	51858	351	Ленинградская область, Тихвинский район, Тихвин, Школьная улица, Помещение участка электросети	f	\N
67417	52297	848	Ленинградская область, Тихвинский район, Тихвин, Школьная, 33, МОУ Средняя общеобразовательная школа №1	f	\N
67419	52296	850	Ленинградская область, Тихвинский район, Тихвин, Пролетарской Диктатуры, 47, МОУ СОШ №9	f	\N
67418	52296	849	Ленинградская область, Тихвинский район, Тихвин, Пролетарской Диктатуры, 47, МОУ СОШ №9	f	\N
67416	52296	847	Ленинградская область, Тихвинский район, Тихвин, Пролетарской Диктатуры, 47, МОУ СОШ №9	f	\N
67415	52295	846	Ленинградская область, Тихвинский район, Тихвин, Машиностроителей, 41, МОУ СОШ №1	f	\N
67356	52301	855	Ленинградская область, Тихвинский район, Тихвин, Зайцева, 1, ООО Тихвинский лесхимзавод	f	\N
67355	52301	854	Ленинградская область, Тихвинский район, Тихвин, Зайцева, 1, ООО Тихвинский лесхимзавод	f	\N
67405	52289	836	Ленинградская область, Тихвинский район, Тихвин, Борисова, 4, Медицинский колледж	f	\N
67413	52294	844	Ленинградская область, Тихвинский район, Тихвин, 6 микрорайон, 13, МОУ Средняя общеобразовательная школа №4	f	\N
67414	52294	845	Ленинградская область, Тихвинский район, Тихвин, 6 микрорайон, 13, МОУ Средняя общеобразовательная школа №4	f	\N
67406	52280	837	Ленинградская область, Тихвинский район, Тихвин, 3 микрорайон, 43, МОУ Лицей №8	f	\N
67407	52280	838	Ленинградская область, Тихвинский район, Тихвин, 3 микрорайон, 43, МОУ Лицей №8	f	\N
67404	52287	835	Ленинградская область, Тихвинский район, Тихвин, 1 микрорайон, 32, МОУ Средняя общеобразовательная школа №5	f	\N
67018	51985	515	Россия, Ленинградская область, Кингисеппский район, деревня Котлы	f	\N
67400	52287	831	Ленинградская область, Тихвинский район, Тихвин, 1 микрорайон, 32, МОУ Средняя общеобразовательная школа №5	f	\N
67359	52304	858	Ленинградская область, Тихвинский район, посёлок Сарка, Лесная, 8 \\11, Саркский фельдшерско-акушерский пункт	f	\N
67373	52314	872	Ленинградская область, Тихвинский район, деревня Пашозеро, Центральная, 1, МОУ Пашозерская основная общеобразовательная школа	f	\N
67360	52305	859	Ленинградская область, Тихвинский район, деревня Мелегежская Горка, 23, Андреевский центр культуры и отдыха	f	\N
67357	52302	856	Ленинградская область, Тихвинский район, посёлок Красава, Комсомольская, 16, МОУ Красавская ООШ	f	\N
67367	52310	866	Ленинградская область, Тихвинский район, деревня Коськово, Школьная, 4, МОУ Коськовская основная общеобразовательная школа	f	\N
67369	52312	868	Ленинградская область, Тихвинский район, поселок Ерёмина Гора, Народная, 77, МОУ Ерёминогорская средняя общеобразовательная школа	f	\N
67365	52309	864	Ленинградская область, Тихвинский район, деревня Горка, Центральная, 33, МОУ Горская основная общеобразовательная школа	f	\N
67368	52311	867	Ленинградская область, Тихвинский район, деревня Ганьково, переулок Клубный, 8, МУ Ганьковский культурный центр	f	\N
67364	52308	863	Ленинградская область, Тихвинский район, поселок Бор, 21, МОУ Борская средняя общеобразовательная школа	f	\N
67358	52303	857	Ленинградская область, Тихвинский район, посёлок Березовик, Лесная, 1, Березовский фельдшерско-акушерский пункт	f	\N
67399	52285	829	Ленинградская область, Сланцевский район, посёлок Черновское, Дом культуры	f	\N
67396	52282	826	Ленинградская область, Сланцевский район, поселок Старополье, Дом культуры	f	\N
67493	52260	805	Ленинградская область, Сланцевский район, Сланцы, улица Кирова, 18, ГУНПО Профессиональный лицей №15	f	\N
67491	52258	803	Россия, Ленинградская область, Сланцевский район, Сланцы, улица Кирова, 11	f	\N
67506	52274	818	Ленинградская область, Сланцевский район, Сланцы, улица Дзержинского, 4, ЗАГС	f	\N
67501	52269	813	Ленинградская область, Сланцевский район, Сланцы, Спортивная, 2, МОУ ДОД Сланцевская ДЮСШ	f	\N
67504	52272	816	Ленинградская область, Сланцевский район, Сланцы, Молодёжный проспект, 9, МОУ Сланцевская СОШ №6	f	\N
67505	52273	817	Ленинградская область, Сланцевский район, Сланцы, Максима Горького, 9, МОУ Сланцевская СОШ №1	f	\N
67502	52270	814	Ленинградская область, Сланцевский район, Сланцы, Ленина, 25 /4, МОУ ДОД Сланцевская детская музыкальная школа	f	\N
67497	52264	809	Ленинградская область, Сланцевский район, Сланцы, Ленина, 5, МУК Городской Дом культуры	f	\N
67498	52265	810	Ленинградская область, Сланцевский район, Сланцы, Климчука, 1, ФГОУ Сланцевский индустриальный техникум	f	\N
67492	52259	804	Ленинградская область, Сланцевский район, Сланцы, Кирова, 11, МОУ Сланцевская СОШ №3	f	\N
67496	52263	808	Ленинградская область, Сланцевский район, Сланцы, Грибоедова, 8, МОУ ДОД Сланцевский центр информационных технологий	f	\N
67499	52266	811	Ленинградская область, Сланцевский район, Сланцы, Гагарина, 2, поликлиника	f	\N
67512	52255	800	Ленинградская область, Сланцевский район, посёлок Сельхозтехника, Дом культуры	f	\N
67397	52283	827	Ленинградская область, Сланцевский район, поселок Овсище, Дом культуры	f	\N
67351	52281	825	Ленинградская область, Сланцевский район, деревня Новоселье, МОУ Новосельская основная образовательная школа	f	\N
67398	52284	828	Ленинградская область, Сланцевский район, деревня Ложголово, Загорская, 8 , МУК СДК	f	\N
67511	52254	799	Ленинградская область, Сланцевский район, деревня Загривье, МОУ Загривская СОШ	f	\N
67350	52279	824	Ленинградская область, Сланцевский район, деревня Гусева Гора, МУК СДК Рудно	f	\N
67349	52278	823	Ленинградская область, Сланцевский район, деревня Выскатка, Дом культуры	f	\N
67490	52257	802	Ленинградская область, Сланцевский район, деревня Большие Поля, ГБУ Сланцевская специальная общеобразовательная школа закрытого типа	f	\N
67458	52247	792	Ленинградская область, Приозерский район, остановочный пункт 69 км, Заводская, 1, административное здание завода ВНИИЗЕММАШ 2-й этаж	f	\N
67449	52238	783	Ленинградская область, Приозерский район, посёлок Суходолье, МОУ Громовская СОШ	f	\N
67455	52244	789	Ленинградская область, Приозерский район, посёлок Сосново, Связи, 13а, МОУ Сосновская СОШ	f	\N
67457	52246	791	Ленинградская область, Приозерский район, посёлок Сосново, Мичуринская, 2, Сосновский Дом творчествазал	f	\N
67456	52245	790	Ленинградская область, Приозерский район, посёлок Сосново, Механизаторов, 11 , обменный пункт ЗАО Сосновоагропромтехника	f	\N
67454	52243	788	Ленинградская область, Приозерский район, деревня Снегирёвка, Центральная, 19, КСК Снегиревскийхолл	f	\N
67461	52250	795	Ленинградская область, Приозерский район, посёлок Севастьяново, Новая, 4, Дом культуры, зал	f	\N
67448	52237	782	Ленинградская область, Приозерский район, посёлок Сапёрное, Школьная, 28МОУ Шумиловская СОШ	f	\N
67447	52236	781	Ленинградская область, Приозерский район, посёлок Ромашки, Новостроек, 14 школа	f	\N
67451	52240	785	Ленинградская область, Приозерский район, деревня Раздолье, Дом культуры	f	\N
67433	52222	767	Ленинградская область, Приозерский район, Приозерск, Северопарковая, 5, МОУ средняя общеобразовательная школа №1холл	f	\N
67430	52219	764	Ленинградская область, Приозерский район, Приозерск, Леншоссе, 33, контора Приозерского потребительского общества	f	\N
67432	52221	766	Ленинградская область, Приозерский район, Приозерск, Ленина, 45, МУК Культурный центр Карнавал холл	f	\N
67436	52225	770	Ленинградская область, Приозерский район, Приозерск, Калинина, 27, МОУ СОШ №4 актовый зал	f	\N
67434	52223	768	Ленинградская область, Приозерский район, Приозерск, Калинина, 20, МУК Приозерская межпоселенческая районнная библиотека холл.	f	\N
67440	52229	774	Ленинградская область, Приозерский район, посёлок Починок, Леншоссе, 15, Дом культуры	f	\N
67443	52232	777	Ленинградская область, Приозерский район, посёлок Плодовое, Дом культуры	f	\N
67450	52239	784	Ленинградская область, Приозерский район, посёлок Петровское, Шоссейная, 12, Дом культуры	f	\N
67442	52231	776	Ленинградская область, Приозерский район, посёлок Моторное, Приладожское шоссе, 5а, Дом культуры	f	\N
67459	52248	793	Ленинградская область, Приозерский район, посёлок Мичуринское, Первомайская, МОУ Мичуринская СОШ	f	\N
67444	52233	778	Ленинградская область, Приозерский район, посёлок Мельниково, Калинина, 3, Дом Культуры фойе	f	\N
67439	52228	773	Ленинградская область, Приозерский район, посёлок Ларионово, Ленинградская, 16, Дом культуры	f	\N
67510	52253	798	Ленинградская область, Приозерский район, посёлок Кузнечное, Юбилейная, 7а, Дом культуры Юбилейныймалый, малый зал	f	\N
67508	52251	796	Ленинградская область, Приозерский район, посёлок Кузнечное, Центральная, 4, МОУ Кузнеченская начальная школа-сад №12	f	\N
67509	52252	797	Ленинградская область, Приозерский район, поселок Кузнечное, Юбилейная, 7а, Дом культуры Юбилейный, танцевальный зал.	f	\N
67453	52242	787	Ленинградская область, Приозерский район, поселок Кривко, Фестивальная, 1, Дом культуры	f	\N
67460	52249	794	Ленинградская область, Приозерский район, деревня Красноозёрное, Школьная, 9, МОУ Красноозерненская ООШ-детский сад	f	\N
67441	52230	775	Ленинградская область, Приозерский район, посёлок Коммунары, Школьная, МОУ Коммунарская СОШхолл 1-го этажа	f	\N
67452	52241	786	Ленинградская область, Приозерский район, посёлок Запорожское, Советская, 14, Дом культуры	f	\N
67446	52235	780	Ленинградская область, Приозерский район, поселок Громово, Дом культуры	f	\N
67445	52234	779	Ленинградская область, Приозерский район, посёлок Громово, Центр досуга зал	f	\N
67293	52200	744	Ленинградская область, Подпорожский район, городской посёлок Никольский, Новая, 6	f	\N
67428	52216	762	Ленинградская область, Подпорожский район, деревня Ярославичи, Школьная, 8	f	\N
67291	52197	741	Ленинградская область, Подпорожский район, село Шеменичи, Деловая , 3, библиотека	f	\N
67290	52196	740	Ленинградская область, Подпорожский район, посёлок Токари, Исакова , 20	f	\N
67297	52203	748	Ленинградская область, Подпорожский район, деревня Родионово, Георгиевская, 31	f	\N
67288	52194	738	Ленинградская область, Подпорожский район, Подпорожье, проспект Ленина, 53а	f	\N
67284	52189	734	Россия, Ленинградская область, Подпорожский район, Подпорожье, проспект Ленина, 26	f	\N
67283	52188	733	Россия, Ленинградская область, Подпорожский район, Подпорожье, проспект Ленина, 2	f	\N
67282	52187	732	Ленинградская область, Подпорожский район, Подпорожье, Строителей, 2, помещение школы №8	f	\N
67286	52192	736	Ленинградская область, Подпорожский район, Подпорожье, Свирская, 82а	f	\N
67279	52184	729	Ленинградская область, Подпорожский район, Подпорожье, Свирская, 21	f	\N
67278	52183	728	Ленинградская область, Подпорожский район, Подпорожье, Промывные, 7, помещение управления ЗАО Погранское объединение карьеров	f	\N
67280	52185	730	Ленинградская область, Подпорожский район, Подпорожье, Гнаровской, 9, помещение школы №1	f	\N
67292	52199	743	Ленинградская область, Подпорожский район, посёлок Никольский, Лисициной, 18	f	\N
67424	52212	758	Ленинградская область, Подпорожский район, деревня Лукинская, Покровская , 17	f	\N
67296	52202	747	Ленинградская область, Подпорожский район, деревня Курпово, Клубная, 8	f	\N
67426	52214	760	Ленинградская область, Подпорожский район, посёлок Курба, Школьная, 8, Детский сад	f	\N
67429	52217	763	Ленинградская область, Подпорожский район, посёлок Кузра, Центральная, 13	f	\N
67420	52208	754	Ленинградская область, Подпорожский район, поселок Красный Бор, Школьная , 12а	f	\N
67298	52204	749	Ленинградская область, Подпорожский район, деревня Кипрушино, Школьная, 3	f	\N
67425	52213	759	Ленинградская область, Подпорожский район, поселок Кармановская, Немжинская, 25	f	\N
67427	52215	761	Ленинградская область, Подпорожский район, деревня Казыченская, Раздольная, 19	f	\N
67299	52205	750	Ленинградская область, Подпорожский район, деревня Гимрека, Петрозаводский тракт, 35	f	\N
67301	52206	752	Ленинградская область, Подпорожский район, посёлок Вознесенье, Пионерская, 49	f	\N
67300	52206	751	Ленинградская область, Подпорожский район, посёлок Вознесенье, Пионерская, 49	f	\N
67302	52207	753	Ленинградская область, Подпорожский район, посёлок Вознесенье, Лесозаводская, 8	f	\N
67421	52209	755	Ленинградская область, Подпорожский район, село Винницы, Советская, 66	f	\N
67422	52210	756	Ленинградская область, Подпорожский район, село Винницы, Лесная, 9, Районная больница	f	\N
67423	52211	757	Ленинградская область, Подпорожский район, село Винницы, Гражданская, 39	f	\N
67295	52201	746	Ленинградская область, Подпорожский район, посёлок Важины, Школьная, 13	f	\N
67294	52201	745	Ленинградская область, Подпорожский район, посёлок Важины, Школьная, 13	f	\N
67263	52169	713	Ленинградская область, Лужский район, городской посёлок Толмачёво, Толмачёва , 10, помешение МОУ СОШ	f	\N
67264	52170	714	Ленинградская область, Лужский район, городской посёлок Толмачёво, Прохорова, 43 , помещение ООО Областная управляющая компания	f	\N
67269	52175	719	Ленинградская область, Лужский район, посёлок при ж/д станции Низовская, Дзержинского, помещение библиотеки	f	\N
67223	52124	669	Ленинградская область, Лужский район, детский лагерь Зелёный Бор, корп.2	f	\N
67261	52167	711	Ленинградская область, Лужский район, деревня Ям-Тёсово, Центральная, 6-а , помещение ДК	f	\N
67259	52165	709	Ленинградская область, Лужский район, посёлок Тёсово-4, 20-го съезда КПСС, 7а , помещение администрации Тёсовского сельского поселения	f	\N
67252	52158	702	Ленинградская область, Лужский район, деревня Турово, 1 помещение фельдшерско - акушерского пункта	f	\N
67250	52156	700	Ленинградская область, Лужский район, деревня Торошковичи, Торговая, 3 , помещение Дома культуры	f	\N
67277	52182	727	Ленинградская область, Лужский район, поселок Торковичи, Стахановская, 1, помещение администрации Торковичского сельского поселения	f	\N
67257	52163	707	Ленинградская область, Лужский район, посёлок Скреблово, Центральная, 31 , помещение администрации Скребловского сельского поселения	f	\N
67276	52181	726	Ленинградская область, Лужский район, посёлок Серебрянский, Совхозная, 18-а, помещение администрации Серебрянского сельского поселения	f	\N
67275	52180	725	Россия, Ленинградская область, Лужский район, деревня Ретюнь	f	\N
67273	52179	723	Ленинградская область, Лужский район, деревня Рель, 6 кв.11 помещение администрации Осьминского сельского поселения	f	\N
67253	52159	703	Ленинградская область, Лужский район, деревня Раковно, Нагорная, 9, Клуб	f	\N
67262	52168	712	Ленинградская область, Лужский район, посёлок Приозерный, Центральная, 4-а, помещение администрации Ям-Тёсовского сельского поселения	f	\N
67266	52172	716	Россия, Ленинградская область, Лужский район, посёлок Плоское	f	\N
40769	37703	501	Калининградская область, Советск, Липовая, 2	f	large
67271	52177	721	Ленинградская область, Лужский район, деревня Пехенец, 1-а, помещение Дома культуры	f	\N
67274	52178	724	Ленинградская область, Лужский район, посёлок Осьмино, Ленина, 51-а, помещение администрации Осьминского сельского поселения	f	\N
67272	52178	722	Ленинградская область, Лужский район, посёлок Осьмино, Ленина, 51-а, помещение администрации Осьминского сельского поселения	f	\N
67256	52162	706	Ленинградская область, Лужский район, посёлок Оредеж, Комсомола, 7, помещение администрации Оредежского сельского поселения	f	\N
67268	52174	718	Ленинградская область, Лужский район, посёлок Мшинская, Пролетарская, 1 , помещение МОУ СОШ	f	\N
67255	52161	705	Ленинградская область, Лужский район, деревня Мерёво, помещение фельдшерско - акушерского пункта	f	\N
67258	52164	708	Россия, Ленинградская область, Лужский район, посёлок Межозёрный	f	\N
67247	52152	697	Ленинградская область, Лужский район, Луга-3, здание административного военного лесхоза Мичуринский	f	\N
67246	52151	696	Ленинградская область, Лужский район, Луга, 3/132, МДОУ детсад №13	f	\N
67245	52150	695	Ленинградская область, Лужский район, Луга, Дом офицеров	f	\N
67237	52142	687	Ленинградская область, Лужский район, Луга, улица Красной Артиллерии, 38	f	\N
67487	52132	677	Ленинградская область, Лужский район, Луга, проспект Урицкого, 16, МОУ СОШ №4	f	\N
67488	52133	678	Ленинградская область, Лужский район, Луга, проспект Кирова, 31, клуб Радуга	f	\N
67486	52131	676	Ленинградская область, Лужский район, Луга, проспект Кирова, 8, ЗАО Лужский трикотаж	f	\N
67239	52144	689	Ленинградская область, Лужский район, Е18, М20, 44, МОУ СОШ №6	f	\N
67236	52141	686	Ленинградская область, Лужский район, Луга, проспект Володарского, 13а, помещение МУК Районная библиотека	f	\N
67484	52128	673	Ленинградская область, Лужский район, Луга, Смоленская , 110, Лужское лесничество- филиал ЛОГБУ	f	\N
67231	52136	681	Ленинградская область, Лужский район, Луга, Смоленская, 85, МДОУ детсад №17	f	\N
67226	52127	672	Ленинградская область, Лужский район, Луга, Свободы, 23, МОУ СОШ №5	f	\N
67225	52126	671	Россия, Ленинградская область, Лужский район, Луга, Нижегородская улица, 126	f	\N
67224	52125	670	Ленинградская область, Лужский район, Луга, Мелиораторов, 3, Здание ОАО Спецстрой	f	\N
67235	52140	685	Ленинградская область, Лужский район, Луга, Красной Артиллерии, 24	f	\N
67485	52129	674	Ленинградская область, Лужский район, Луга, Красноармейская, 32, Клуб ОАО Лужский абразивный завод	f	\N
67243	52148	693	Ленинградская область, Лужский район, Луга, Комсомольский проспект, 21/74, МДОУ детсад №1	f	\N
67270	52176	720	Россия, Ленинградская область, Лужский район, посёлок Красный Маяк	f	\N
67254	52160	704	Ленинградская область, Лужский район, поселок Каменка, микрорайон Центральный, 14 , МОУ СОШ	f	\N
67251	52157	701	Ленинградская область, Лужский район, деревня Заклинье, Новая, 36, МОУ СОШ	f	\N
67265	52171	715	Ленинградская область, Лужский район, деревня Жельцы	f	\N
67249	52154	699	Ленинградская область, Лужский район, посёлок Дзержинского, Центральная, 4 , администрация Дзержинскогосельского поселения	f	\N
67267	52173	717	Ленинградская область, Лужский район, посёлок Волошово, Школьная, 22, МОУ СОШ	f	\N
67248	52153	698	Россия, Ленинградская область, Лужский район, посёлок Володарское	f	\N
47701	51553	24	Ленинградская область, Лужский район, деревня Бор, 44	f	large
67220	52121	665	Ленинградская область, Ломоносовский район, деревня Яльгелево, школа	f	\N
67198	52099	639	Ленинградская область, Ломоносовский район, деревня Шепелево, Ветеранов, 16, Дом культуры	f	\N
67221	52122	666	Ленинградская область, Ломоносовский район, село Русско-Высоцкое, школа	f	\N
67222	52122	667	Ленинградская область, Ломоносовский район, село Русско-Высоцкое, школа	f	\N
67219	52120	664	Россия, Ленинградская область, Ломоносовский район, посёлок Ропша	f	\N
67207	52106	650	Ленинградская область, Ломоносовский район, деревня Разбегаево, Дом культуры	f	\N
67218	52118	662	Ленинградская область, Ломоносовский район, поселок Пеники, Новая, школа	f	\N
67217	52117	661	Ленинградская область, Ломоносовский район, деревня Оржицы, Дом культуры	f	\N
67201	52101	642	Россия, Ленинградская область, Ломоносовский район, посёлок Новоселье	f	\N
67215	52115	659	Ленинградская область, Ломоносовский район, поселок Низино, Центральная, 48, школа	f	\N
67216	52116	660	Россия, Ленинградская область, Ломоносовский район, деревня Низино	f	\N
67203	52090	644	Ленинградская область, Ломоносовский район, деревня Малое Карлино, Дом культуры	f	\N
67213	52113	657	Ленинградская область, Ломоносовский район, поселок Лопухинка, Дом культуры	f	\N
67195	52097	636	Ленинградская область, Ломоносовский район, Лебяжье, Степаняна, 16, школа	f	\N
67196	52097	637	Ленинградская область, Ломоносовский район, Лебяжье, Степаняна, 16, школа	f	\N
67212	52112	656	Ленинградская область, Ломоносовский район, поселок Лаголово, Дом культуры	f	\N
67211	52111	655	Ленинградская область, Ломоносовский район, село Копорье, Дом культуры	f	\N
67209	52109	653	Ленинградская область, Ломоносовский район, деревня Кипень, Ропшинское шоссе, 23, школа	f	\N
67210	52110	654	Ленинградская область, Ломоносовский район, деревня Келози, школа	f	\N
67208	52107	651	Ленинградская область, Ломоносовский район, деревня Гостилицы, Дом культуры	f	\N
67206	52105	649	Ленинградская область, Ломоносовский район, деревня Горбунки, Дом Культуры	f	\N
67205	52105	648	Ленинградская область, Ломоносовский район, деревня Горбунки, Дом Культуры	f	\N
67204	52104	647	Ленинградская область, Ломоносовский район, Горбунки, Дом культуры	f	\N
67197	52098	638	Ленинградская область, Ломоносовский район, деревня Гора-Валдай, 27	f	\N
67214	52114	658	Ленинградская область, Ломоносовский район, деревня Глобицы, Школьная, 6, школа	f	\N
67202	52000	643	Ленинградская область, Ломоносовский район, деревня Виллози, 1а, Дом культуры	f	\N
67194	52096	635	Ленинградская область, Ломоносовский район, посёлок Большая Ижора, Астанина, 2, школа	f	\N
67200	52100	641	Ленинградская область, Ломоносовский район, посёлок Аннино, Садовая, 2, школа	f	\N
67199	52100	640	Ленинградская область, Ломоносовский район, посёлок Аннино, Садовая, 2, школа	f	\N
67190	52092	631	Ленинградская область, Лодейнопольский район, деревня Яровщина, 1 , помещение МКДОУ Яровщинская начальная школа-детский сад	f	\N
67181	52082	622	Ленинградская область, Лодейнопольский район, посёлок Янега, Пионерская, 4, административное здание	f	\N
67189	52091	630	Ленинградская область, Лодейнопольский район, посёлок Шархиничи, Прудовая, 2 а	f	\N
67173	52073	614	Ленинградская область, Лодейнопольский район, деревня Шамокша, 24, Дом культурызал 1-этаж	f	\N
67180	52081	621	Ленинградская область, Лодейнопольский район, деревня Харевщина, Молодежная, 5	f	\N
67182	52083	623	Ленинградская область, Лодейнопольский район, деревня Тервеничи, Центральная, 3, сельский Дом Культуры	f	\N
67178	52079	619	Ленинградская область, Лодейнопольский район, деревня Старая Слобода, 61, гостиница Старая Слобода холл	f	\N
67177	52077	618	Ленинградская область, Лодейнопольский район, посёлок Свирьстрой, Кирова проспект, 2, МКУ Свирьстройский центр культуры и досуга	f	\N
67185	52086	626	Ленинградская область, Лодейнопольский район, посёлок Ребовичи, 50 , административное здание Алеховщинского сельского поселения	f	\N
67192	52094	633	Ленинградская область, Лодейнопольский район, посёлок Рассвет, 8, МКУ Оятский Культурно-спортивный центр	f	\N
67184	52085	625	Ленинградская область, Лодейнопольский район, деревня Пирозерово, 28, помещение сельской библиотеки	f	\N
67186	52087	627	Ленинградская область, Лодейнопольский район, поселок Надпорожье, 71, помещение административного здания Алеховщинского сельского поселения	f	\N
67167	52066	608	Ленинградская область, Лодейнопольский район, Лодейное Поле, улица Титова, 48, МОУ Лодейнопольская средняя общеобразовательная школа №68	f	\N
67191	52093	632	Ленинградская область, Лодейнопольский район, деревня Имоченицы, 11, помещение Дома культуры	f	\N
67193	52095	634	Ленинградская область, Лодейнопольский район, деревня Доможирово, Школьная, 67, СДК	f	\N
67183	52084	624	Ленинградская область, Лодейнопольский район, деревня Вонозеро, 39, Сельский клуб	f	\N
47697	51549	20	Ленинградская область, Лодейнопольский район, деревня Анисимово, 12	f	small
67179	52080	620	Ленинградская область, Лодейнопольский район, деревня Андреевщина, административное здание Янегского сельского поселения	f	\N
67188	52089	629	Ленинградская область, Лодейнопольский район, село Алёховщина, Набережная, 23, МКОУ Алеховщинская средняя общеобразовательная школа	f	\N
67187	52088	628	Ленинградская область, Лодейнопольский район, село Алёховщина, Лодейнопольское шоссе, 2	f	\N
67161	52060	602	Ленинградская область, Кировский район, ст.Новый Быт, Волховская, 16, ФАП	f	\N
67345	52054	596	Россия, Ленинградская область, Кировский район, городской посёлок Назия	f	\N
67319	52032	570	Ленинградская область, Кировский район, городской посёлок Мга, Спортивная, 4, МУК КДЦ Мга	f	\N
67321	52034	572	Ленинградская область, Кировский район, городской посёлок Мга, Советский пр., 55, МОУ Мгинская СОШ	f	\N
66947	51702	185	Ленинградская область, Кировский район, посёлок имени Морозова, площадь Культуры, 3, Дом культуры	f	\N
66951	51702	189	Ленинградская область, Кировский район, посёлок имени Морозова, площадь Культуры, 3, Дом культуры	f	\N
66950	51705	188	Ленинградская область, Кировский район, посёлок имени Морозова, Хесина, 20, СОШ им. Морозова здание 2	f	\N
66949	51704	187	Ленинградская область, Кировский район, посёлок имени Морозова, Хесина, 20, СОШ им. Морозова	f	\N
67160	52059	601	Ленинградская область, Кировский район, село Шум, Советская, 22, администрация	f	\N
67159	52058	600	Ленинградская область, Кировский район, село Шум, Советская, 3-а, МУК Сельский культурно-досуговый центр	f	\N
67333	52044	584	Россия, Ленинградская область, Кировский район, Шлиссельбург, улица Малоневский Канал, 6	f	\N
67336	52047	587	Ленинградская область, Кировский район, Шлиссельбург, Красныйи проспект, 50, МОУ ДОД Шлиссельбурская музыкальная школа	f	\N
67335	52046	586	Ленинградская область, Кировский район, Шлиссельбург, Затонная, 1, клуб Парус	f	\N
67334	52045	585	Ленинградская область, Кировский район, Шлиссельбург, 18-го Января, 3а, СШ №1	f	\N
67164	52063	605	Ленинградская область, Кировский район, деревня Сухое, 32, администрация МО Суховское сельское поселение	f	\N
67322	52035	573	Ленинградская область, Кировский район, посёлок Старая Малукса, Новоселов, 1	f	\N
67323	52036	574	Ленинградская область, Кировский район, поселок Сологубовка, 95, ФАП	f	\N
67339	52049	590	Ленинградская область, Кировский район, деревня Синявино-2, Победы, 5, МКУ КДЦ Синявино	f	\N
67338	52048	589	Ленинградская область, Кировский район, Синявино, Лесная, 17, МОУ СОШ	f	\N
67337	52048	588	Ленинградская область, Кировский район, Синявино, Лесная, 17, МОУ СОШ	f	\N
67344	52053	595	Ленинградская область, Кировский район, село Путилово, Дорофеева, 5, МБУ Сельский ДК	f	\N
67343	52052	594	Ленинградская область, Кировский район, село Путилово, Братьев Пожарских	f	\N
67341	52050	592	Ленинградская область, Кировский район, посёлок Приладожский, 24 , ДК	f	\N
67340	52050	591	Ленинградская область, Кировский район, посёлок Приладожский, 24 , ДК	f	\N
67317	52030	568	Ленинградская область, Кировский район, посёлок Павлово, Спортивная, 1 , МУК ДК п. Павлово2-й этаж	f	\N
67316	52030	567	Ленинградская область, Кировский район, посёлок Павлово, Спортивная, 1 , МУК ДК п. Павлово2-й этаж	f	\N
67308	52023	559	Ленинградская область, Кировский район, Отрадное, Комсомольская, 5, МОУ ДОД Детская Школа искусств	f	\N
67311	52026	562	Ленинградская область, Кировский район, Отрадное, Железнодорожная , 20, МОУ Отрадненская СШ№2	f	\N
67314	52028	565	Ленинградская область, Кировский район, Отрадное, Железнодорожная, 20а, ДЮСШ	f	\N
67310	52025	561	Ленинградская область, Кировский район, Отрадное, Железнодорожная, 20, МОУ Отрадненская СШ№2	f	\N
67309	52024	560	Ленинградская область, Кировский район, Отрадное, Дружбы, 1, МОУ Лицей г.Отрадное	f	\N
67313	52027	564	Ленинградская область, Кировский район, Отрадное, Гагарина, 1, МУК КЦ Фортуна	f	\N
67312	52027	563	Ленинградская область, Кировский район, Отрадное, Гагарина, 1, МУК КЦ Фортуна	f	\N
67342	52051	593	Ленинградская область, Кировский район, деревня Назия, Староладожский канал, 3 , ФАП	f	\N
67156	52055	597	Ленинградская область, Кировский район, деревня Назия, Комсомольский пр., 15, МОК Культурно-Спортивный Комплекс Назия	f	\N
67158	52057	599	Ленинградская область, Кировский район, посёлок Назия, Октябрская, 14, ГОУ ЛО Назийский центр социальной адаптации	f	\N
67157	52056	598	Ленинградская область, Кировский район, посёлок Назия, Волховское шоссе, 1-а, ОАО ПО Баррикадазавод ЖБИ-2	f	\N
67324	52037	575	Ленинградская область, Кировский район, посёлок Молодцово, 9, МОУ Молодцовая основная общеобразовательная школа	f	\N
67320	52033	571	Ленинградская область, Кировский район, посёлок Мга, Комсомольский пр., 40, НОУ СОШ № 37 ОАО РЖД	f	\N
67165	52064	606	Ленинградская область, Кировский район, деревня Лаврово, Староладожский канал, 68, Сельский клуб	f	\N
67162	52061	603	Ленинградская область, Кировский район, посёлок Концы, Плитная, 12, ФАП	f	\N
67327	52040	578	Ленинградская область, Кировский район, Кировск, улица Горького, 16, МОУ Кировская гимназия им.Султана Баймагамбетова	f	\N
67329	52041	580	Россия, Ленинградская область, Кировский район, Кировск, Новая улица, 32к2	f	\N
67328	52041	579	Россия, Ленинградская область, Кировский район, Кировск, Новая улица, 32к2	f	\N
67326	52039	577	Ленинградская область, Кировский район, Кировск, Набережная, 27 , МБУК Районный Дом Культуры	f	\N
67325	52038	576	Ленинградская область, Кировский район, Кировск, Кирова, 8, МОУ Кировская гимназия им.Султана Баймагамбетова (прогимназия)	f	\N
67318	52031	569	Ленинградская область, Кировский район, деревня Горы, ПМС-28	f	\N
67163	52062	604	Ленинградская область, Кировский район, деревня Горка, 1, ФАП	f	\N
67306	52020	556	Ленинградская область, Киришский район, посёлок Тихорицы, Новая, 2	f	\N
67128	52011	547	Ленинградская область, Киришский район, деревня Среднее Село, Центральная, 3	f	\N
67032	52015	551	Ленинградская область, Киришский район, посёлок Пчевжа, Клубная, 6	f	\N
67033	52016	552	Ленинградская область, Киришский район, поселок Пчева, Героев, 13, Дом культуры	f	\N
67304	52018	554	Россия, Ленинградская область, Киришский район, деревня Мотохово	f	\N
67130	52013	549	Ленинградская область, Киришский район, деревня Могилёво, Центральная , 4	f	\N
67307	52021	557	Ленинградская область, Киришский район, деревня Кусино, Центральная, 20	f	\N
67129	52012	548	Ленинградская область, Киришский район, деревня Кукуй, Песочная, 14	f	\N
67116	52001	535	Ленинградская область, Киришский район, Кириши, проспект Ленина, 1, МОУ Киришская средняя общеобразовательная школа №3	f	\N
67114	51998	533	Ленинградская область, Киришский район, Кириши, проспект Ленина, 21, ЗАГС	f	\N
67119	52003	538	Ленинградская область, Киришский район, Кириши, площадь 60-летия Октября, 1, МОУ Киришский образовательный центр	f	\N
67029	51993	526	Ленинградская область, Киришский район, Кириши, Энергетиков, 29	f	\N
67028	51993	525	Ленинградская область, Киришский район, Кириши, Энергетиков, 29	f	\N
67124	52007	543	Ленинградская область, Киришский район, Кириши, Советская, 37, 2-этаж	f	\N
67112	51996	531	Россия, Ленинградская область, Киришский район, Кириши, Молодёжный бульвар, 25	f	\N
67120	52004	539	Ленинградская область, Киришский район, Кириши, Комсомольская, 5, МОУ Киришская средняя общеобразовательная школа №2	f	\N
67031	51994	528	Ленинградская область, Киришский район, Кириши, Декабристов Бестужевых, 15, МОУ Киришская средняя общеобразовательная школа №8	f	\N
67030	51994	527	Ленинградская область, Киришский район, Кириши, Декабристов Бестужевых, 15, МОУ Киришская средняя общеобразовательная школа №8	f	\N
67110	51994	529	Ленинградская область, Киришский район, Кириши, Декабристов Бестужевых, 15, МОУ Киришская средняя общеобразовательная школа №8	f	\N
67115	51999	534	Ленинградская область, Киришский район, Кириши, Волховская набережная, 10, МОУ Гимназия	f	\N
67127	52010	546	Ленинградская область, Киришский район, поселок Гремячево, Центральная, 37, Дом культуры	f	\N
67303	52017	553	Ленинградская область, Киришский район, поселок Городище, Песочная, 1Г	f	\N
67305	52019	555	Ленинградская область, Киришский район, посёлок Глажево, Дом Культуры Юбилейный	f	\N
67126	52009	545	Ленинградская область, Киришский район, посёлок Будогощь, Советская, 79	f	\N
67125	52008	544	Ленинградская область, Киришский район, посёлок Будогощь, Исполкомская, 1, Дом культуры	f	\N
67019	51986	516	Ленинградская область, Кингисеппский район, деревня Фалилеево, 34 , здание Фалилеевского досугого центраФалилеевская библиотека	f	\N
67014	51981	511	Ленинградская область, Кингисеппский район, посёлок Усть-Луга, квартал Ленрыба, 7	f	\N
67009	51974	505	Ленинградская область, Кингисеппский район, деревня Ополье, ДК	f	\N
67016	51983	513	Ленинградская область, Кингисеппский район, деревня Нежново, 13а, сельский клуб	f	\N
67022	51989	519	Ленинградская область, Кингисеппский район, деревня Кошкино, Парковая, 12, клуб	f	\N
67017	51984	514	Ленинградская область, Кингисеппский район, посёлок Котельский, Котельский сельский Дом культуры	f	\N
67020	51987	517	Ленинградская область, Кингисеппский район, посёлок Кингисеппский, 22, Дом культуры поселка Кингисепский	f	\N
67021	51988	518	Ленинградская область, Кингисеппский район, Кингисепп, Административное здание ЗАО Кингисеппская ПМК-12	f	\N
67007	51972	503	Ленинградская область, Кингисеппский район, Кингисепп	f	\N
67004	51971	500	Россия, Ленинградская область, Кингисеппский район, Кингисепп, улица Ковалевского, 9	f	\N
67005	51971	501	Россия, Ленинградская область, Кингисеппский район, Кингисепп, улица Ковалевского, 9	f	\N
66991	51958	486	Россия, Ленинградская область, Кингисеппский район, Кингисепп, улица Иванова, 26	f	\N
66988	51958	483	Россия, Ленинградская область, Кингисеппский район, Кингисепп, улица Иванова, 26	f	\N
67002	51970	498	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 63	f	\N
67006	51970	502	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 63	f	\N
66998	51965	493	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 59	f	\N
66997	51965	492	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 59	f	\N
66989	51959	484	Россия, Ленинградская область, Кингисеппский район, Кингисепп, проспект Карла Маркса, 40	f	\N
66990	51960	485	Ленинградская область, Кингисеппский район, Кингисепп, Школьная, 30, специально-учебно-производственная школа-интернат	f	\N
66994	51963	489	Ленинградская область, Кингисеппский район, Кингисепп, Октябрьская, 1/10-б	f	\N
66993	51962	488	Ленинградская область, Кингисеппский район, Кингисепп, Октябрьская, 1/10-б	f	\N
66987	51957	482	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Железнодорожная улица, 8	f	\N
67001	51969	497	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Восточная улица, 4	f	\N
67003	51969	499	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Восточная улица, 4	f	\N
66995	51964	490	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Большая Советская улица, 34	f	\N
66996	51964	491	Россия, Ленинградская область, Кингисеппский район, Кингисепп, Большая Советская улица, 34	f	\N
48171	51966	494	Ленинградская область, Кингисеппский район, Кингисепп, Большая Советская, 34	f	large
66992	51961	487	Ленинградская область, Кингисеппский район, Кингисепп, Большая Советская, 7а	f	\N
67000	51967	496	Ленинградская область, Кингисеппский район, Кингисепп, Химиков, 6	f	\N
66999	51967	495	Ленинградская область, Кингисеппский район, Кингисепп, Химиков, 6	f	\N
66986	51956	481	Ленинградская область, Кингисеппский район, Кингисеп, Театральная , 1	f	\N
67059	51956	480	Ленинградская область, Кингисеппский район, Кингисеп, Театральная , 1	f	\N
67012	51978	509	Ленинградская область, Кингисеппский район, посёлок Ивановское, здание библиотеки	f	\N
67025	51992	522	Ленинградская область, Кингисеппский район, Ивангород, Юрия Гагарина, 6	f	\N
67026	51979	523	Ленинградская область, Кингисеппский район, Ивангород, Восточная , 11, СОШ №1	f	\N
67027	51979	524	Ленинградская область, Кингисеппский район, Ивангород, Восточная , 11, СОШ №1	f	\N
67023	51990	520	Ленинградская область, Кингисеппский район, деревня Захонье-2, клуб	f	\N
67015	51982	512	Ленинградская область, Кингисеппский район, деревня Вистино, Ижорская, 6	f	\N
67013	51980	510	Ленинградская область, Кингисеппский район, деревня Большое Кузёмкино, микрорайон Центральный, 16	f	\N
67010	51976	507	Ленинградская область, Кингисеппский район, деревня Большая Пустомержа, ДК	f	\N
67008	51973	504	Ленинградская область, Кингисеппский район, посёлок Алексеевка, Дом культуры	f	\N
67082	51896	398	Ленинградская область, Гатчинский район, п. Др.Горка, Введенского, 20, 2эт	f	\N
67150	51932	446	Ленинградская область, Гатчинский район, деревня Шпаньково, им. Алексея Рыкунова, 39	f	\N
134566	94427	462	Ленинградская область, Гатчинский район, деревня Черново, 31	f	\N
66922	51865	361	Ленинградская область, Гатчинский район, деревня Чаща, Лесная, 7	f	\N
67034	51940	455	Ленинградская область, Гатчинский район, посёлок Торфяное, д.43а , сельский клуб	f	\N
67139	51922	435	Ленинградская область, Гатчинский район, деревня Тихковицы, 58-б, христианский центр Источник	f	\N
134569	94430	465	Ленинградская область, Гатчинский район, посёлок Терволово, Ленинградская, 14	f	\N
67229	51915	428	Ленинградская область, Гатчинский район, садоводство Тайцы, Советская улица, 7, КДЦ	f	\N
67134	51916	429	Ленинградская область, Гатчинский район, поселок Тайцы, Комсомольская, 26, Центр социально-диаконического обслуживания	f	\N
67055	51952	476	Ленинградская область, Гатчинский район, деревня Сяськелево, 10-а, 2 эт	f	\N
67054	51951	475	Ленинградская область, Гатчинский район, деревня Сяськелево, 10-а, 1 эт	f	\N
67050	51947	471	Ленинградская область, Гатчинский район, посёлок Сусанино, Петровский пр., 22	f	\N
67049	51947	470	Ленинградская область, Гатчинский район, посёлок Сусанино, Петровский пр., 22	f	\N
67152	51934	448	Ленинградская область, Гатчинский район, посёлок Суйда, Центральная, 2-а	f	\N
67058	51955	479	Россия, Ленинградская область, Гатчинский район, деревня Старые Низковицы	f	\N
67227	51913	426	Ленинградская область, Гатчинский район, поселок Сиверский-2, Военный городок	f	\N
67109	51913	425	Ленинградская область, Гатчинский район, поселок Сиверский-2, Военный городок	f	\N
67108	51913	424	Ленинградская область, Гатчинский район, поселок Сиверский-2, Военный городок	f	\N
67106	51912	422	Ленинградская область, Гатчинский район, поселок Сиверский, проспект Героев, 1	f	\N
67107	51912	423	Ленинградская область, Гатчинский район, поселок Сиверский, проспект Героев, 1	f	\N
67105	51911	421	Ленинградская область, Гатчинский район, поселок Сиверский, Строителей, 2	f	\N
67104	51911	420	Ленинградская область, Гатчинский район, поселок Сиверский, Строителей, 2	f	\N
67101	51908	417	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Республиканский проспект, 62	f	\N
67098	51905	414	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Красная улица, 19	f	\N
67093	51902	409	Ленинградская область, Гатчинский район, поселок Сиверский, Кезевская дорога, 64Е	f	\N
67103	51910	419	Ленинградская область, Гатчинский район, поселок Сиверский, Заводская улица, 7к1к	f	\N
67097	51904	413	Ленинградская область, Гатчинский район, поселок Сиверский, Достоевского, 13	f	\N
67099	51906	415	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Восточная улица, 1	f	\N
67092	51901	408	Ленинградская область, Гатчинский район, поселок Сиверский, Большой проспект, 97	f	\N
67102	51909	418	Ленинградская область, Гатчинский район, поселок Сиверский, 123-й Дивизии, 10	f	\N
67051	51948	472	Ленинградская область, Гатчинский район, посёлок Семрино, Большой проспект, 4-а	f	\N
134570	94431	466	Ленинградская область, Гатчинский район, село Рождествено, Большой пр, 106	f	\N
134567	94428	463	Ленинградская область, Гатчинский район, посёлок Пудость, Половинкиной, 89	f	\N
67037	51943	458	Ленинградская область, Гатчинский район, поселок Пудомяги, 7	f	\N
67035	51941	456	Ленинградская область, Гатчинский район, посёлок Пригородный, Садовая, 10	f	\N
67155	51937	451	Ленинградская область, Гатчинский район, посёлок Прибытково, Школьная, 2	f	\N
67038	51944	459	Ленинградская область, Гатчинский район, деревня Покровская, Покровская, 154	f	\N
67146	51928	442	Ленинградская область, Гатчинский район, посёлок Новый Учхоз, пл. Усова, 28	f	\N
66985	51939	454	Ленинградская область, Гатчинский район, посёлок Новый Свет, 82, МУК НКДЦ Лидер	f	\N
66984	51939	453	Ленинградская область, Гатчинский район, посёлок Новый Свет, 82, МУК НКДЦ Лидер	f	\N
66921	51864	360	Ленинградская область, Гатчинский район, посёлок Новинка, Вокзальная, 1	f	\N
67138	51920	433	Ленинградская область, Гатчинский район, село Никольское, Шипунова, 5	f	\N
134564	94425	460	Ленинградская область, Гатчинский район, посёлок Мыза-Ивановка, красный уголок	f	\N
66920	51863	359	Ленинградская область, Гатчинский район, поселок Мины, Школьная, 7, помещение Минской начальной школы-детский сад	f	\N
66983	51938	452	Ленинградская область, Гатчинский район, деревня Меньково, помещение Меньковской опытной станции	f	\N
67140	51923	436	Ленинградская область, Гатчинский район, деревня Малые Колпаны, Западная, 21	f	\N
67142	51925	438	Ленинградская область, Гатчинский район, деревня Малое Верево, 1	f	\N
67143	51926	439	Ленинградская область, Гатчинский район, деревня Малое Верево, Кутышева, 1-а , СКДЦ	f	\N
67036	51942	457	Ленинградская область, Гатчинский район, посёлок Лукаши, Школьная, 5, Средняя школа	f	\N
67083	51897	399	Ленинградская область, Гатчинский район, деревня Лампово, Совхозная, 11, МДОУ ДС комбинированного вида №28	f	\N
67091	49479	407	Россия, Ленинградская область, Гатчинский район, Коммунар, Садовая улица, 2	f	\N
67088	51692	404	Ленинградская область, Гатчинский район, Коммунар, Просвещения, 1	f	\N
67089	51900	405	Ленинградская область, Гатчинский район, Коммунар, Ленинградское шоссе, 3, ФОК Олимп	f	\N
67086	51568	402	Россия, Ленинградская область, Гатчинский район, Коммунар, Ленинградское шоссе, 22	f	\N
67087	51568	403	Россия, Ленинградская область, Гатчинский район, Коммунар, Ленинградское шоссе, 22	f	\N
67085	51899	401	Ленинградская область, Гатчинский район, Коммунар, Ижорская, 14	f	\N
67090	49427	406	Ленинградская область, Гатчинский район, Коммунар, Гатчинская, 12	f	\N
67084	51898	400	Россия, Ленинградская область, Гатчинский район, Коммунар, Антропшинская улица, 293	f	\N
67153	51935	449	Ленинградская область, Гатчинский район, посёлок Кобринское, Центральная, 16	f	\N
67052	51949	473	Ленинградская область, Гатчинский район, посёлок Кобралово, Центральная, 22	f	\N
67154	51936	450	Ленинградская область, Гатчинский район, посёлок Карташевская, Красная, 24	f	\N
134568	94429	464	Ленинградская область, Гатчинский район, деревня Ивановка	f	\N
67056	51953	477	Ленинградская область, Гатчинский район, поселок Жабино, Поселковая, 25	f	\N
67149	51931	445	Ленинградская область, Гатчинский район, посёлок Елизаветино, пл.Дружбы, 41 , Дом Культуры	f	\N
67148	51930	444	Ленинградская область, Гатчинский район, посёлок Елизаветино, Парковая , 17	f	\N
67081	51895	397	Ленинградская область, Гатчинский район, поселок Дружная Горка, Введенского, 20, 1 этаж	f	\N
134572	94433	468	Ленинградская область, Гатчинский район, посёлок Дивенский, Володарского, 28	f	\N
67062	51879	378	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Чкалова, 66	f	\N
67074	51890	390	Ленинградская область, Гатчинский район, Гатчина, улица Михаила Рысева, 32а	f	\N
66935	51876	375	Россия, Ленинградская область, Гатчинский район, Гатчина	f	\N
67061	51878	377	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Киргетова, 8	f	\N
66926	51869	366	Россия, Ленинградская область, Гатчинский район, Гатчина, улица Изотова, 17	f	\N
67060	51877	376	Россия, Ленинградская область, Гатчинский район, Гатчина, проспект 25-го Октября, 30а	f	\N
66928	51871	368	Россия, Ленинградская область, Гатчинский район, Гатчина, проспект 25-го Октября, 40	f	\N
66927	51870	367	Ленинградская область, Гатчинский район, Гатчина, проспект 25-го Октября, 46к2	f	\N
67069	51886	385	Россия, Ленинградская область, Гатчинский район, Гатчина, Школьная улица, 1	f	\N
67068	51885	384	Ленинградская область, Гатчинский район, Гатчина, Чкалова, 2	f	\N
67067	51884	383	Ленинградская область, Гатчинский район, Гатчина, Чкалова, 7	f	\N
67076	51892	392	Ленинградская область, Гатчинский район, Гатчина, Слепнева, 15а	f	\N
66930	51873	370	Россия, Ленинградская область, Гатчинский район, Гатчина, Рощинская улица, 5	f	\N
66929	51872	369	Россия, Ленинградская область, Гатчинский район, Гатчина, Рощинская улица, 7	f	\N
66923	51866	362	Ленинградская область, Гатчинский район, Гатчина, Крупской, 11	f	\N
67070	51887	386	Россия, Ленинградская область, Гатчинский район, Гатчина, Красноармейский проспект, 8	f	\N
66925	51868	365	Ленинградская область, Гатчинский район, Гатчина, Коли Подрядчикова, 9	f	\N
66924	51868	364	Ленинградская область, Гатчинский район, Гатчина, Коли Подрядчикова, 9	f	\N
67063	51880	379	Ленинградская область, Гатчинский район, Гатчина, Володарского, 32, Средняя школа №1	f	\N
66931	51874	371	Ленинградская область, Гатчинский район, Гатчина, Володарского, 39а	f	\N
66933	51104	373	Ленинградская область, Гатчинский район, Гатчина, Володарского, 32	f	\N
66934	51104	374	Ленинградская область, Гатчинский район, Гатчина, Володарского, 32	f	\N
67073	51889	389	Ленинградская область, Гатчинский район, Гатчина, Беляева, 14	f	\N
67072	51889	388	Ленинградская область, Гатчинский район, Гатчина, Беляева, 14	f	\N
28855	18331	395	Архангельская область, Котлас, Маяковского, 30	f	large
67078	51893	394	Ленинградская область, Гатчинский район, Гатчина, Авиатриссы Зверевой, 15, Библиотека	f	\N
67151	51933	447	Ленинградская область, Гатчинский район, посёлок Высокоключевой, Большой пр., 35 , здание средней школы	f	\N
66919	51862	358	Ленинградская область, Гатчинский район, поселок Вырица, проспект Урицкого, 88, помещение газового участка	f	\N
66917	51641	356	Россия, Ленинградская область, Гатчинский район, поселок Вырица, Ушаковская улица, 5	f	\N
66918	51737	357	Россия, Ленинградская область, Гатчинский район, поселок Вырица, Сиверское шоссе, 168	f	\N
66911	51857	350	Ленинградская область, Гатчинский район, поселок Вырица, Павловский проспект, 6	f	\N
66913	51859	352	Ленинградская область, Гатчинский район, поселок Вырица, Майский проспект, 41	f	\N
66914	51860	353	Ленинградская область, Гатчинский район, поселок Вырица, Жертв Революции, 20	f	\N
66916	51558	355	Ленинградская область, Гатчинский район, поселок Вырица, Ефимова, 14	f	\N
66915	51861	354	Ленинградская область, Гатчинский район, поселок Вырица, Жертв Революции, 20	f	\N
67144	51927	440	Ленинградская область, Гатчинский район, деревня Войсковицы, Молодежная , 1	f	\N
67145	51927	441	Ленинградская область, Гатчинский район, деревня Войсковицы, Молодежная , 1	f	\N
134565	94426	461	Ленинградская область, Гатчинский район, деревня Большое Рейзино, помещение конторы	f	\N
67228	51914	427	Ленинградская область, Гатчинский район, поселок Большие Тайцы, Ягодная, 12а	f	\N
67137	51919	432	Ленинградская область, Гатчинский район, деревня Большие Колпаны, Садовая, 4, Средняя школа	f	\N
67136	51918	431	Ленинградская область, Гатчинский район, деревня Большие Колпаны, Садовая, 8, Дом Культуры	f	\N
67141	51924	437	Ленинградская область, Гатчинский район, деревня Большие Колпаны, 30 лет Победы, 1 , Администрация	f	\N
67135	51917	430	Ленинградская область, Гатчинский район, деревня Большие Колпаны, Садовая, 8	f	\N
67095	51903	411	Ленинградская область, Гатчинский район, поселок Белогорка, Институтская, 1	f	\N
67096	51903	412	Ленинградская область, Гатчинский район, поселок Белогорка, Институтская, 1	f	\N
67094	51903	410	Ленинградская область, Гатчинский район, поселок Белогорка, Институтская, 1	f	\N
134571	94432	467	Ленинградская область, Гатчинский район, поселок Батово, 12, ДК	f	\N
66907	51853	346	Ленинградская область, Выборгский район, посёлок при ж/д станции Приветнинское, Военных строителей, 11, МОУ Приветнинская средняя общеобразовательная школа	f	\N
66839	51785	277	Ленинградская область, Выборгский район, посёлок Черкасово, Железнодорожная, 38-а	f	\N
66896	51842	335	Ленинградская область, Выборгский район, посёлок Цвелодубово, Центральная, 19, Общеобразовательная школа	f	\N
66865	51812	304	Россия, Ленинградская область, Выборгский район, посёлок Торфяновка	f	\N
66871	51818	310	Ленинградская область, Выборгский район, посёлок Токарево, уд. Кленовая, 5а	f	\N
66910	51856	349	Ленинградская область, Выборгский район, посёлок Тарасово, МОУ «Тарасовская начальная общеобразовательная школа»	f	\N
66872	51819	311	Ленинградская область, Выборгский район, посёлок Соколинское, Приморская, 21	f	\N
66870	51817	309	Ленинградская область, Выборгский район, посёлок Советский, Школьная, 17, МУ ЦКД «Движение»спортивный зал	f	\N
66668	51643	113	Ленинградская область, Выборгский район, посёлок Советский, Советская, 15-а	f	\N
66868	51815	307	Ленинградская область, Выборгский район, посёлок Советский, Садовая, 32	f	\N
66899	51845	338	Ленинградская область, Выборгский район, посёлок Семиозерье, Центральная, 58, МОУ «Семиозерская основная общеобразовательная школа»	f	\N
66858	51804	296	Ленинградская область, Выборгский район, Светогорск, Рощинская, 6, МОУ Средняя общеобразовательная школа № 1	f	\N
67133	51806	298	Ленинградская область, Выборгский район, Светогорск, Лесная, 15, МУ КСК Бассейн Дельфин	f	\N
67132	51805	297	Ленинградская область, Выборгский район, Светогорск, Лесная, 7а, Центр досуга «Заря»	f	\N
66860	51807	299	Ленинградская область, Выборгский район, Светогорск, Красноармейская улица, 3, 3ГБОУ СПО ЛО «Политехнический колледж»	f	\N
66857	51803	295	Ленинградская область, Выборгский район, Светогорск, Коробицына, 4 , Детский сад Лучик	f	\N
66879	51826	318	Ленинградская область, Выборгский район, посёлок Рябово, контора СПК Рябовский	f	\N
66894	51840	333	Ленинградская область, Выборгский район, посёлок Рощино, Социалистическая улица, 121, МДОУ Детский сад «Аистенок»	f	\N
66891	51837	330	Ленинградская область, Выборгский район, посёлок Рощино, Советская улица, 35, Дом Культуры	f	\N
66893	51839	332	Ленинградская область, Выборгский район, посёлок Рощино, Советская, 39	f	\N
66892	51838	331	Ленинградская область, Выборгский район, посёлок Рощино, Железнодорожная, 57, МОУ «Рощинская средняя общеобразовательная школа»	f	\N
66888	51834	327	Ленинградская область, Выборгский район, садоводство Решетниково, 5	f	\N
66897	51843	336	Ленинградская область, Выборгский район, посёлок Пушное, Школьная, 13, МОУ «Пушновская средняя общеобразовательная школа»	f	\N
66848	51794	286	Ленинградская область, Выборгский район, посёлок Пруды, МОУ «Прудовская начальная общеобразовательная школа»	f	\N
66876	51823	315	Ленинградская область, Выборгский район, Приморск, набережная Лебедева, 7, МОУД «Центр дополнительного образования»	f	\N
66875	51822	314	Ленинградская область, Выборгский район, Приморск, набережная Лебедева, 4, библиотека	f	\N
66877	51824	316	Ленинградская область, Выборгский район, Приморск, Школьная, 16	f	\N
66906	51852	345	Ленинградская область, Выборгский район, поселок Приветнинское, Лесная, 4, контора участка СПК “Поляны”	f	\N
66903	51849	342	Ленинградская область, Выборгский район, посёлок Поляны, Выборгское шоссе, 73, МОУ «Полянская средняя общеобразовательная школа»	f	\N
47709	51561	32	Ленинградская область, Выборгский район, посёлок Подборовье, Советская, 1	f	medium
66898	51844	337	Ленинградская область, Выборгский район, база отдыха Победа, Птицефабрика Ударник Дом культуры	f	\N
66908	51854	347	Ленинградская область, Выборгский район, посёлок Песочное, Литвинова, 25	f	\N
66838	51784	276	Ленинградская область, Выборгский район, посёлок Перово, Начальная школа-садТеремок	f	\N
66895	51841	334	Ленинградская область, Выборгский район, поселок Первомайское, А122, 11, помещение бывшего магазина	f	\N
66887	51833	326	Ленинградская область, Выборгский район, посёлок Первомайское, Ленина, 72, МУК КИЦ «Кивеннапа» Дворец Культуры	f	\N
66886	51833	325	Ленинградская область, Выборгский район, посёлок Первомайское, Ленина, 72, МУК КИЦ «Кивеннапа» Дворец Культуры	f	\N
66852	51798	290	Ленинградская область, Выборгский район, посёлок Михалёво, Новая	f	\N
66863	51810	302	Ленинградская область, Выборгский район, посёлок Лужайка, ОЛГБУ Ленобллес	f	\N
66856	51802	294	Ленинградская область, Выборгский район, посёлок Лосево, Новая, Лосевская начальная школа – детский сад	f	\N
66854	51800	292	Ленинградская область, Выборгский район, посёлок Лесогорский, Школьный переулок, 2, МОУ Лесогорская СОШ	f	\N
66855	51801	293	Ленинградская область, Выборгский район, посёлок Лесогорский, Летчиков, 9, МДОУ «Детский сад «Чебурашка»	f	\N
66889	51835	328	Ленинградская область, Выборгский район, посёлок Ленинское, Заречная улица, 24, МОУ «Ленинская основная общеобразовательная школа»	f	\N
66851	51797	289	Ленинградская область, Выборгский район, посёлок Красный Сокол, библиотека	f	\N
66882	51829	321	Ленинградская область, Выборгский район, посёлок Красносельское, Советская, 9а, Дом Культуры	f	\N
66880	51827	319	Ленинградская область, Выборгский район, посёлок Красная Долина, Средняя школа	f	\N
66883	51830	322	Ленинградская область, Выборгский район, посёлок Коробицыно, МДОУ «Детский сад «Рябинушка» пос. Коробицыно»	f	\N
66866	51813	305	Россия, Ленинградская область, Выборгский район, посёлок Кондратьево	f	\N
66905	51851	344	Ленинградская область, Выборгский район, посёлок Клеверное, Центральная, 6, сельский Клуб	f	\N
66884	51831	323	Ленинградская область, Выборгский район, посёлок Кирпичное, Комсомольская, МОУ «Кирилловская средняя общеобразовательная школа»	f	\N
66885	51832	324	Ленинградская область, Выборгский район, посёлок Кирилловское, Советская, 30	f	\N
66847	51793	285	Ленинградская область, Выборгский район, Каменногорск, Ленинградское шоссе, 93, МОУ «Каменногорская средняя общеобразовательная школа»	f	\N
66890	51836	329	Ленинградская область, Выборгский район, посёлок Ильичёво, Садовая, 3	f	\N
66853	51799	291	Россия, Ленинградская область, Выборгский район, посёлок Зайцево	f	\N
66843	51789	281	Ленинградская область, Выборгский район, посёлок Житково, Сельский ДК	f	\N
66878	51825	317	Ленинградская область, Выборгский район, посёлок Ермилово, Основная школа	f	\N
66909	51855	348	Ленинградская область, Выборгский район, посёлок Горьковское, Центральная, 6, сельский Клуб	f	\N
66840	51786	278	Ленинградская область, Выборгский район, посёлок Гончарово, КИЦ Гармония	f	\N
66874	51821	313	Ленинградская область, Выборгский район, посёлок Глебычево, МОУ «Глебычевская средняя общеобразовательная школа»	f	\N
66873	51820	312	Ленинградская область, Выборгский район, посёлок Глебычево, Мира	f	\N
66841	51787	279	Ленинградская область, Выборгский район, посёлок Гвардейское, Сельский ДК	f	\N
66842	51788	280	Ленинградская область, Выборгский район, посёлок Гаврилово, Центральная, 35	f	\N
66867	51814	306	Ленинградская область, Выборгский район, Высоцк, Ленинская, 4	f	\N
66821	51767	259	Ленинградская область, Выборгский район, Выборг, улица Гагарина, 38, МОУ «Средняя общеобразовательная школа № 12»	f	\N
66807	51752	244	Россия, Ленинградская область, Выборгский район, Выборг, проспект Ленина, 20	f	\N
66830	51776	268	Ленинградская область, Выборгский район, Выборг, имени А.К. Харитонова, 14, МБДОУ «Детский сад «Ромашка»	f	\N
66831	51777	269	Ленинградская область, Выборгский район, Выборг, Школьная, 8, МОУ «Средняя общеобразовательная школа № 9»	f	\N
66799	51744	236	Ленинградская область, Выборгский район, Выборг, Шестакова, 28	f	\N
66812	51757	249	Ленинградская область, Выборгский район, Выборг, Сухова, 2, ОАО «Выборгтеплоэнерго»	f	\N
66828	51774	266	Россия, Ленинградская область, Выборгский район, Выборг, Судостроительная улица, 16	f	\N
66824	51770	262	Ленинградская область, Выборгский район, Выборг, Смирновское шоссе, 15, ГП «Выборгское ДРЭУ»	f	\N
66835	51781	273	Ленинградская область, Выборгский район, Выборг, Рубежная, 38, МДОУ Детский сад № 32 «Росинка»	f	\N
66832	51778	270	Ленинградская область, Выборгский район, Выборг, Рубежная, 31, МОУ «Средняя общеобразовательная школа № 10»	f	\N
66822	51768	260	Ленинградская область, Выборгский район, Выборг, Рубежная, 31, МОУ «Средняя общеобразовательная школа №10»	f	\N
66801	51746	238	Ленинградская область, Выборгский район, Выборг, Прогонная, 9, Клуб «Балтика» МАУК «Культурно-досуговый комплекс»	f	\N
66820	51766	258	Ленинградская область, Выборгский район, Выборг, Приморское шоссе, 12а, МДОУ Детский сад комбинированного вида № 31 «Кораблик»	f	\N
66816	51762	254	Ленинградская область, Выборгский район, Выборг, Приморская, 34, МБОУ ДОД «Центр детского творчества»	f	\N
66815	51761	253	Ленинградская область, Выборгский район, Выборг, Приморская, 41, МАУ «Спортивно-зрелищный комплекс «Фаворит»	f	\N
66806	51751	243	Ленинградская область, Выборгский район, Выборг, Пограничная, 3, Детский сад Солнышко	f	\N
66811	51756	248	Ленинградская область, Выборгский район, Выборг, Первомайская, 12, МОУ «Средняя общеобразовательная школа № 6»	f	\N
66802	51747	239	Россия, Ленинградская область, Выборгский район, Выборг, Морская набережная, 5	f	\N
47929	51760	252	Россия, Ленинградская область, Выборгский район, Выборг, Ленинградское шоссе, 45а	f	large
66810	51755	247	Россия, Ленинградская область, Выборгский район, Выборг, Ленинградское шоссе, 26а	f	\N
66827	51773	265	Ленинградская область, Выборгский район, Выборг, Кировские Дачи, 2, МБДОУ «Детский сад комбинированного вида «Рябинка»	f	\N
66833	51779	271	Ленинградская область, Выборгский район, Выборг, Гагарина, 17А, Детский сад №19 Колосок	f	\N
66819	51765	257	Ленинградская область, Выборгский район, Выборг, Гагарина, 36, МОУ «Средняя общеобразовательная школа № 14»спортивный зал	f	\N
66817	51763	255	Ленинградская область, Выборгский район, Выборг, Гагарина, 36, МОУ Средняя общеобразовательная школа №14	f	\N
66836	51782	274	Ленинградская область, Выборгский район, Выборг, Большая Каменная, 6, ГАОУ СПО ЛО ВПК Александровский, общежитие	f	\N
66829	51775	267	Ленинградская область, Выборгский район, Выборг, Большая Гвардейская , 33, МОУ «Выборгская вечерняя общеобразовательная школа»	f	\N
66849	51795	287	Ленинградская область, Выборгский район, посёлок Возрождение, МОУ «Возрожденская средняя общеобразовательная школа»	f	\N
66845	51791	283	Ленинградская область, Выборгский район, поселок Вещево, Воинской Славы	f	\N
66864	51811	303	Ленинградская область, Выборгский район, посёлок Большое Поле, Римского-Корсакова, 17	f	\N
66844	51790	282	Ленинградская область, Выборгский район, посёлок Барышево, Барышевский сельский Дом Культуры	f	\N
66953	51706	191	Ленинградская область, Всеволожский район, п.Дубровка, Школьная , 17а	f	\N
66952	51706	190	Ленинградская область, Всеволожский район, п.Дубровка, Школьная , 17а	f	\N
66954	51706	192	Ленинградская область, Всеволожский район, п.Дубровка, Школьная , 17а	f	\N
66956	51708	194	Ленинградская область, Всеволожский район, посёлок имени Свердлова, мкр-н №1МОБУ Свердловская СОЩ №1	f	\N
66958	51710	196	Ленинградская область, Всеволожский район, посёлок имени Свердлова, мкр-н №2, МОБУ СОШ №2 неполная средняя школа	f	\N
66957	51709	195	Ленинградская область, Всеволожский район, посёлок имени Свердлова, мкр-н №1, Дом Культуры Нева	f	\N
66948	51703	186	Ленинградская область, Всеволожский район, посёлок имени Морозова, площадь Культуры, 4, Музыкальная школа	f	\N
66963	51714	201	Ленинградская область, Всеволожский район, деревня Янино-1, актовый зал	f	\N
66964	51715	202	Ленинградская область, Всеволожский район, деревня Янино-1, Новая, 16, Янинская средняя общеобразовательная школа	f	\N
66678	51656	134	Ленинградская область, Всеволожский район, деревня Юкки, Ленинградское шоссе, 26, Администрация	f	\N
66687	51663	143	Ленинградская область, Всеволожский район, Энтолово , Конно-спортивный клуб Дерби	f	\N
66946	51701	184	Ленинградская область, Всеволожский район, посёлок Щеглово, 11, МУ Щегловский сельский Дом культуры	f	\N
66945	51700	183	Ленинградская область, Всеволожский район, посёлок Щеглово, 58, МОУ Щегловская средняя школа	f	\N
66961	51712	199	Ленинградская область, Всеволожский район, деревня Хапо-Ое, МДОУ Детский сад №26	f	\N
66937	51691	175	Ленинградская область, Всеволожский район, посёлок Углово, клуб в/ч 11703	f	\N
66711	51684	167	Ленинградская область, Всеволожский район, посёлок Токсово, Буланова, 18, МУЗ Районная больница	f	\N
66714	51686	170	Ленинградская область, Всеволожский район, посёлок Токсово, Дорожников, 1, МОБУ Токсовская СОШ	f	\N
66713	51686	169	Ленинградская область, Всеволожский район, посёлок Токсово, Дорожников, 1, МОБУ Токсовская СОШ	f	\N
66962	51713	200	Ленинградская область, Всеволожский район, деревня Суоранда, Строителей, 19, ООО Оптен-кабель	f	\N
66705	51679	161	Ленинградская область, Всеволожский район, посёлок Стеклянный, неполная средняя общеобразовательная школа	f	\N
66795	51740	232	Ленинградская область, Всеволожский район, деревня Старая, Верхняя улица, МДОУ Детский сад №62	f	\N
66794	51740	231	Ленинградская область, Всеволожский район, деревня Старая, Верхняя улица, МДОУ Детский сад №62	f	\N
47809	51655	132	Ленинградская область, Всеволожский район, Сертолово, улица Молодцова, 18	f	large
47803	51652	126	Россия, Ленинградская область, Всеволожский район, Сертолово, улица Молодцова, 4	f	large
66676	51653	130	Ленинградская область, Всеволожский район, Сертолово, мкр-н Черная речка, 55, общеобразовательная школа, 1 этаж	f	\N
66675	51653	129	Ленинградская область, Всеволожский район, Сертолово, мкр-н Черная речка, 55, общеобразовательная школа, 1 этаж	f	\N
66677	51654	131	Ленинградская область, Всеволожский район, Сертолово, Молодцова, 18, школа №31 этаж	f	\N
66936	51690	174	Ленинградская область, Всеволожский район, посёлок Романовка, 24, МОУ №Романовка СОШ	f	\N
47850	51689	173	Ленинградская область, Всеволожский район, посёлок Романовка, 20	f	large
66716	51688	172	Ленинградская область, Всеволожский район, посёлок Романовка, 20, ДК Свеча	f	\N
66939	51694	177	Ленинградская область, Всеволожский район, посёлок Рахья, Севастьянова , 1 , средняя школа	f	\N
66938	51693	176	Ленинградская область, Всеволожский район, поселок Рахья, Октябрьское шоссе, 1, Дом культуры	f	\N
66715	51687	171	Ленинградская область, Всеволожский район, деревня Рапполово, Овражная, 21а, Библиотека	f	\N
66960	51711	198	Ленинградская область, Всеволожский район, деревня Разметелево, МОБУ Разметелевская СОШ	f	\N
66959	51711	197	Ленинградская область, Всеволожский район, деревня Разметелево, МОБУ Разметелевская СОШ	f	\N
66688	51664	144	Ленинградская область, Всеволожский район, деревня Порошкино, 19-а	f	\N
66797	51742	234	Ленинградская область, Всеволожский район, село Павлово, ин-т физиологии им.И.П.Павловаглавный корпус	f	\N
28851	18327	391	Архангельская область, Котлас, Маяковского, 34	f	large
66708	51682	164	Ленинградская область, Всеволожский район, садоводство Осельки, Ленинградская, 1а, Осельковская ООШ	f	\N
66698	51673	154	Ленинградская область, Всеволожский район, Новое Девяткино, 96а, Детский Сад №59	f	\N
66694	51670	150	Ленинградская область, Всеволожский район, деревня Новое Девяткино, 93а, Моложежный клуб	f	\N
66697	51672	153	Ленинградская область, Всеволожский район, деревня Новое Девяткино, Школьная, 1, МОУ Новодевяткинская СОШ №1	f	\N
66696	51672	152	Ленинградская область, Всеволожский район, деревня Новое Девяткино, Школьная, 1, МОУ Новодевяткинская СОШ №1	f	\N
66695	51671	151	Ленинградская область, Всеволожский район, поселок Новое Девяткино, д.19/1, Культурно-досуговый центр Рондо	f	\N
66703	51677	159	Ленинградская область, Всеволожский район, деревня Ненимяки, 83, пом.11	f	\N
66966	51717	204	Ленинградская область, Всеволожский район, посёлок Мурино, Центральная, 46	f	\N
66968	51719	206	Ленинградская область, Всеволожский район, посёлок Мурино, Оборонная , 32а, Конференц-зал	f	\N
66969	51720	207	Ленинградская область, Всеволожский район, посёлок Мурино, Оборонная, 32а	f	\N
66679	51657	135	Ленинградская область, Всеволожский район, поселок Лупполово, Зелёная улица, Детский Сад №28	f	\N
66706	51680	162	Ленинградская область, Всеволожский район, посёлок Лесное, Лесновская средняя общеобразовательная школа	f	\N
66709	51683	165	Ленинградская область, Всеволожский район, деревня Лесколово, Красноборская, Дом культуры	f	\N
66710	51683	166	Ленинградская область, Всеволожский район, деревня Лесколово, Красноборская, Дом культуры	f	\N
66967	51718	205	Ленинградская область, Всеволожский район, деревня Лаврики, МДОУ Детский сад №61	f	\N
66699	51674	155	Ленинградская область, Всеволожский район, деревня Куйвози, Александрова, 6	f	\N
66690	51666	146	Ленинградская область, Всеволожский район, посёлок Кузьмоловский, Школьная улица, 9, Музыкальная школа	f	\N
66693	51669	149	Ленинградская область, Всеволожский район, посёлок Кузьмоловский, Строителей, 7а, МОБ№ СОШ №1	f	\N
66692	51668	148	Ленинградская область, Всеволожский район, посёлок Кузьмоловский, Спортивная, 10 , МОБУ СОШ №2	f	\N
66689	51665	145	Ленинградская область, Всеволожский район, посёлок Кузьмоловский, Ленинградское шоссе, 8, Дом культуры	f	\N
66691	51667	147	Ленинградская область, Всеволожский район, деревня Кузьмолово, Заозерная, 5, кафе	f	\N
66796	51741	233	Ленинградская область, Всеволожский район, деревня Колтуши, Колтушская средняя школа им.И.П.Павлова	f	\N
66943	51698	181	Ленинградская область, Всеволожский район, деревня Ириновка, Ленинградское шоссе, Дом культуры	f	\N
66965	51716	203	Ленинградская область, Всеволожский район, деревня Заневка, 48, библиотека	f	\N
66702	51676	158	Ленинградская область, Всеволожский район, посёлок Заводской, 3, кв.18	f	\N
66701	51675	157	Ленинградская область, Всеволожский район, деревня Гарболово, школа	f	\N
66700	51675	156	Ленинградская область, Всеволожский район, деревня Гарболово, школа	f	\N
66790	51736	227	Ленинградская область, Всеволожский район, Всеволожск, проспект Грибоедова, 10, средняя школа №5	f	\N
66979	51730	220	Ленинградская область, Всеволожский район, Всеволожск, Шишканя, 1, Сельскохозяйственный колледж	f	\N
66791	51738	228	Ленинградская область, Всеволожский район, Всеволожск, Торговый проспект, 144, станция юных техников	f	\N
66789	51735	226	Ленинградская область, Всеволожский район, Всеволожск, Пушкинская, 61-а, Молодежно-подростковый клуб Энергия	f	\N
66982	51734	225	Ленинградская область, Всеволожский район, Всеволожск, Приютинская, 13, ПУ-56	f	\N
66793	51739	230	Ленинградская область, Всеволожский район, Всеволожск, Московская, общественный центр	f	\N
66792	51739	229	Ленинградская область, Всеволожский район, Всеволожск, Московская, общественный центр	f	\N
47888	51723	211	Россия, Ленинградская область, Всеволожский район, Всеволожск, Межевая улица, 14	f	large
66972	51722	210	Ленинградская область, Всеволожский район, Всеволожск, Межевая, 14, лицей №1	f	\N
66973	51724	212	Ленинградская область, Всеволожский район, Всеволожск, Александровская, 74, управление ЗАГС	f	\N
66798	51743	235	Ленинградская область, Всеволожский район, посёлок Воейково, Дом культуры	f	\N
66707	51681	163	Ленинградская область, Всеволожский район, деревня Верхние Осельки, Ленинградская, 32	f	\N
66704	51678	160	Ленинградская область, Всеволожский район, деревня Васкелово, Коробицына, 10б, Дом культуры	f	\N
66680	51658	136	Ленинградская область, Всеволожский район, деревня Вартемяги, Токсовское шоссе, 2, МОБУ Агалатовская СОШ	f	\N
66940	51695	178	Ленинградская область, Всеволожский район, деревня Ваганово, школа	f	\N
66685	51662	141	Ленинградская область, Всеволожский район, посёлок Бугры, Полевая улица, 3, МОБУ Бугровская СОШ актовый зал	f	\N
66686	51662	142	Ленинградская область, Всеволожский район, посёлок Бугры, Полевая улица, 3, МОБУ Бугровская СОШ актовый зал	f	\N
66942	51697	180	Ленинградская область, Всеволожский район, деревня Борисова Грива, ООО ЖилКомСервис-Рахья	f	\N
66941	51696	179	Ленинградская область, Всеволожский район, деревня Борисова Грива, Центральная, 65/1, магазин №29	f	\N
66683	51660	139	Ленинградская область, Всеволожский район, деревня Агалатово, военный городок д.161 Дом офицеров	f	\N
66681	51660	137	Ленинградская область, Всеволожский район, деревня Агалатово, военный городок д.161 Дом офицеров	f	\N
66682	51660	138	Ленинградская область, Всеволожский район, деревня Агалатово, военный городок д.161 Дом офицеров	f	\N
66781	51635	104	Ленинградская область, Волховский район, деревня Хвалово, Хваловский досуговый центр	f	\N
66780	51634	103	Ленинградская область, Волховский район, деревня Усадище, 134, ДК	f	\N
66669	51644	114	Россия, Ленинградская область, Волховский район, Сясьстрой	f	\N
66784	51638	107	Ленинградская область, Волховский район, Сясьстрой, 13, ПУ-24	f	\N
66670	51645	116	Ленинградская область, Волховский район, Сясьстрой, Культуры, 1а, МУП Сясьстройский коммунальные системы2 этаж	f	\N
66786	51640	109	Ленинградская область, Волховский район, Сясьстрой, Космонавтов, 9, дом детского творчества	f	\N
66787	51628	110	Ленинградская область, Волховский район, Сясьстрой, Космонавтов, 11, средняя школа № 1	f	\N
66788	51642	112	Ленинградская область, Волховский район, Сясьстрой, 25 Октября, 17, средняя школа № 2 Со	f	\N
47788	51544	111	Ленинградская область, Волховский район, Сясьстрой, Советская, 15а	f	large
66722	51597	67	Ленинградская область, Волховский район, село Старая Ладога, Советская, 1	f	\N
66774	51627	97	Ленинградская область, Волховский район, деревня Сорзуй, Лесная, 2, администрация	f	\N
66782	51636	105	Ленинградская область, Волховский район, посёлок Селиваново, Школьная, 13	f	\N
66672	51647	119	Ленинградская область, Волховский район, посёлок Свирица, Новая Свирица, 38, помещение досувого центра	f	\N
66772	51625	95	Ленинградская область, Волховский район, посёлок Рыбежно, Рыбеский СДК	f	\N
66783	51637	106	Ленинградская область, Волховский район, деревня Потанино, 13-а, МУКиС Потанинский СДК	f	\N
66770	51623	93	Ленинградская область, Волховский район, село Паша, Юбилейная, 4, Пашская средняя школа	f	\N
66768	51621	91	Ленинградская область, Волховский район, село Паша, Советская, 85 , администр Пашский ДУК92	f	\N
66767	51620	90	Ленинградская область, Волховский район, село Паша, Советская, 195, администр Пашского сельского поселения	f	\N
47764	51618	87	Ленинградская область, Волховский район, Новая Ладога, проспект Карла Маркса, 21	f	large
66740	51617	86	Ленинградская область, Волховский район, Новая Ладога, проспект К.Маркса, 38, ДК	f	\N
66766	51619	89	Ленинградская область, Волховский район, Новая Ладога, Ленинградская, 2, Новоладожская средняя школа №2	f	\N
66859	51619	88	Ленинградская область, Волховский район, Новая Ладога, Ленинградская, 2, Новоладожская средняя школа №2	f	\N
66773	51626	96	Ленинградская область, Волховский район, поселок Николаевщина, 51	f	\N
66776	51630	99	Ленинградская область, Волховский район, деревня Немятово-2, Петровская, 26	f	\N
66769	51622	92	Ленинградская область, Волховский район, деревня Надкопанье, Надкопанский клуб	f	\N
66771	51624	94	Ленинградская область, Волховский район, посёлок Лесозавод, Лесозаводской филиал Пашского детского сада	f	\N
66778	51632	101	Ленинградская область, Волховский район, посёлок Колчаново, Центральная, 41, детский санаторий Колчаново лечебный корпус	f	\N
66777	51631	100	Ленинградская область, Волховский район, посёлок Колчаново, м-н Алексино, 17, ДК	f	\N
66721	51596	66	Ленинградская область, Волховский район, деревня Кисельня, Кисельнинской средней школы	f	\N
66775	51629	98	Ленинградская область, Волховский район, деревня Иссад, микрорайон Центральный, 6	f	\N
66723	51598	68	Ленинградская область, Волховский район, деревня Вындин Остров, Школьная, 1а	f	\N
66725	51600	70	Ленинградская область, Волховский район, Волхов, красный уголок станции Волховстрой-1	f	\N
66727	51603	72	Ленинградская область, Волховский район, проспект Державина, 28, Культурно-спортивный центр Железнодорожник	f	\N
66733	51609	78	Ленинградская область, Волховский район, Волхов, площадь Ленина, 1 , Дворец Культуры	f	\N
66731	51607	76	Ленинградская область, Волховский район, Волхов, Островского, 6, дом детского творчества филиал	f	\N
66729	51605	74	Ленинградская область, Волховский район, Волхов, Нахимова, 1	f	\N
66734	51610	79	Ленинградская область, Волховский район, Волхов, Лукьянова, 4, школа №3	f	\N
66726	51602	71	Ленинградская область, Волховский район, Волхов, Коммунаров, 31, Детская школа искусств	f	\N
66732	51608	77	Россия, Ленинградская область, Волховский район, Волхов, Кировский проспект, 36	f	\N
66735	51611	80	Ленинградская область, Волховский район, Волхов, Калинина, 27, унитарное муниципальное предприятие ЖКХ Отдых	f	\N
66730	51606	75	Ленинградская область, Волховский район, Волхов, Зеленая, 21, типография	f	\N
66724	51599	69	Ленинградская область, Волховский район, Волхов, Воронежская, 4, Волховский строительный колледж	f	\N
66736	51612	81	Россия, Ленинградская область, Волховский район, Волхов, Волгоградская улица, 23	f	\N
66739	51616	85	Ленинградская область, Волховский район, Волхов, Авиационная улица, 40, курсы управления Го и ЧС	f	\N
66738	51614	83	Россия, Ленинградская область, Волховский район, Волхов, Авиационная улица, 33	f	\N
66779	51633	102	Ленинградская область, Волховский район, деревня Бережки, Песочная, 10	f	\N
66671	51646	118	Ленинградская область, Волховский район, посёлок Аврово, Центральная, 5, дом детского творчества	f	\N
47731	51584	54	Ленинградская область, Волосовский район, деревня Ущевицы, Ущевицкая начальная школа - сад	f	medium
47726	51579	49	Ленинградская область, Волосовский район, деревня Торосово, Торосовский дом культуры	f	large
66720	51594	64	Россия, Ленинградская область, Волосовский район, деревня Терпилицы	f	\N
47725	51578	48	Россия, Ленинградская область, Волосовский район, посёлок Сумино	f	large
66719	51593	63	Ленинградская область, Волосовский район, деревня Сельцо, Сельцовский Дом культуры.	f	\N
47729	51582	52	Ленинградская область, Волосовский район, деревня Реполка, Репольский ДК	f	small
47738	51591	61	Ленинградская область, Волосовский район, поселок Рабитицы, Рабитицкий дом культуры	f	large
47737	51590	60	Ленинградская область, Волосовский район, поселок Остроговицы, диспетчерская ОАО Остроговицы	f	small
47736	51589	59	Ленинградская область, Волосовский район, посёлок Курск, помещении администрации	f	large
47733	51586	56	Ленинградская область, Волосовский район, деревня Курковицы, здание администрации	f	large
47735	51588	58	Россия, Ленинградская область, Волосовский район	f	large
47734	51587	57	Ленинградская область, Волосовский район, посёлок Кикерино, Кикеринский дом культуры, Кикеринский дом культуры	f	large
47730	51583	53	Ленинградская область, Волосовский район, посёлок Каложицы, Детский дом №1	f	medium
47732	51585	55	Ленинградская область, Волосовский район, посёлок Калитино, Калитинский дом культуры	f	large
47728	51581	51	Россия, Ленинградская область, Волосовский район	f	large
47727	51580	50	Ленинградская область, Волосовский район, посёлок Зимитицы, Зимитицкий дом культуры	f	large
47719	51572	42	Ленинградская область, Волосовский район, Волосово, усадьба Сельхозтехники, 1	f	medium
47718	51571	41	Россия, Ленинградская область, Волосовский район, Волосово, проспект Вингиссара, 57	f	large
47717	51570	40	Ленинградская область, Волосовский район, Волосово, Красных партизан, 10/5	f	large
47715	51567	38	Ленинградская область, Волосовский район, Волосово, Красных командиров, 11	f	large
47716	51569	39	Ленинградская область, Волосовский район, Волосово, Гатчинское шоссе, 10	f	large
47739	51592	62	Ленинградская область, Волосовский район, деревня Большой Сабск, Сабский дом культуры	f	medium
40762	37698	494	Калининградская область, Советск, Кировоградская, 6	f	large
47724	51577	47	Ленинградская область, Волосовский район, деревня Большая Вруда, Большеврудская музыкальная школа	f	small
47723	51576	46	Россия, Ленинградская область, Волосовский район	f	large
47722	51575	45	Россия, Ленинградская область, Волосовский район, посёлок Беседа	f	medium
47721	51574	44	Ленинградская область, Волосовский район, деревня Бегуницы, Бегуницкая детская школа искусств	f	large
47720	51573	43	Ленинградская область, Волосовский район, деревня Бегуницы, Бегуницкий ДК	f	large
47699	51551	22	Ленинградская область, Бокситогорский район, посёлок при ж/д станции Большой Двор, 30	f	large
66763	51556	28	Ленинградская область, Бокситогорский район, деревня Утишье, Центральная, 17, муниципальный фонд.	f	\N
66747	51535	7	Ленинградская область, Бокситогорский район, поселок Сёгла, 7, кв 25 муниципальный фонд	f	\N
66759	51548	19	Ленинградская область, Бокситогорский район, село Сомино, Ярославская , 55, муниципальный фонд	f	\N
66717	51565	36	Ленинградская область, Бокситогорский район, посёлок Совхозный, 11, здание администрации Самойловского сельского поселения	f	\N
66765	51564	35	Ленинградская область, Бокситогорский район, поселок Сидорово, администрация	f	\N
66761	51552	23	Ленинградская область, Бокситогорский район, поселок Сельхозтехника, 16, здание детского дома.	f	\N
47711	51563	34	Ленинградская область, Бокситогорский район, деревня Радогощь, 9	f	small
66750	51538	10	Ленинградская область, Бокситогорский район, Пикалёво, Школьная , 40, школа №4 им. А.П Румянцева.	f	\N
66749	51537	9	Ленинградская область, Бокситогорский район, Пикалёво, Школьная , 38, АОУВПО ЛГУ им А.С. Пушкина	f	\N
66752	51540	12	Ленинградская область, Бокситогорский район, Пикалёво, Советская , 21, МАУ Хоз.-экспл.служба.	f	\N
66748	51536	8	Ленинградская область, Бокситогорский район, Пикалёво, Советская , 24, Пикалевкий дом детского творчества	f	\N
66751	51539	11	Ленинградская область, Бокситогорский район, Пикалёво, Пл. Комсомола, 1, Дворец культуры г. Пикалево.	f	\N
66755	51543	15	Ленинградская область, Бокситогорский район, Пикалёво, Металлургов , 13, Детская библиотека.	f	\N
66753	51541	13	Ленинградская область, Бокситогорский район, Пикалёво, Заводская, 21, школа №2	f	\N
66754	51542	14	Ленинградская область, Бокситогорский район, Пикалёво, 5-й микрорайон, 5, школа №3	f	\N
66764	51557	29	Ленинградская область, Бокситогорский район, деревня Ольеши, 22	f	\N
111280	51562	33	Ленинградская область, Бокситогорский район, поселок Озеро-Село, 1	f	\N
66718	51566	37	Ленинградская область, Бокситогорский район, посёлок Коли, 11, школа	f	\N
111278	51559	30	Ленинградская область, Бокситогорский район, деревня Климово, 33	f	\N
47703	51555	26	Ленинградская область, Бокситогорский район, посёлок Заборье, Школьная, 24	f	medium
134563	94424	27	Ленинградская область, Бокситогорский район, посёлок Заборье, Киевская, 2-А, Админ. Здание ЛОГУ ЛенОблЛес	f	\N
111279	51560	31	Ленинградская область, Бокситогорский район, деревня Журавлёво, 44	f	\N
66757	51546	17	Ленинградская область, Бокситогорский район, посёлок Ефимовский, Школьная , 5, Школа интернат для дитей-сирот	f	\N
66758	51547	18	Ленинградская область, Бокситогорский район, посёлок Ефимовский, Сенная, 15, Ефимовская средне образовательная	f	\N
66756	51545	16	Ленинградская область, Бокситогорский район, поселок Ефимовский, Комсомольская, 13, Культурно-досуговый центр.	f	\N
66760	51550	21	Ленинградская область, Бокситогорский район, деревня Дыми, 4 кв.1, муниципальный фонд	f	\N
66743	51531	3	Ленинградская область, Бокситогорский район, Бокситогорск, Южная улица, 23, ГОУ ПУ-№27	f	\N
66745	51533	5	Ленинградская область, Бокситогорский район, Бокситогорск, Школьная, 13, Бокситогорская гимназия.	f	\N
66746	51534	6	Ленинградская область, Бокситогорский район, Бокситогорск, Вишнякова, 22, Лен. Гос. Университет им. Пушкина	f	\N
40770	37704	502	Калининградская область, Советск, Школьная, 13	f	large
40761	37697	493	Калининградская область, Советск, Чапаева, 17	f	large
40772	37706	504	Калининградская область, Советск, Тургенева, 3д	f	large
40768	37702	500	Калининградская область, Советск, Тимирязева, 20	f	large
40765	37700	497	Калининградская область, Советск, Победы, 2	f	large
66520	14641	499	Калининградская область, Советск, Победы, 36	f	\N
40776	37709	508	Калининградская область, Советск, Калининградское шоссе, 16	f	large
40764	37699	496	Калининградская область, Советск, К.Маркса, 2	f	large
40763	37699	495	Калининградская область, Советск, К.Маркса, 2	f	large
40775	37708	507	Калининградская область, Советск, К.Лямина, 4	f	large
40771	37705	503	Калининградская область, Советск, Искры, 5	f	large
40774	37707	506	Калининградская область, Советск, Бурова, 4	f	large
40773	37707	505	Калининградская область, Советск, Бурова, 4	f	large
40766	37701	498	Калининградская область, Советск, Баумана, 6	f	large
40729	37668	455	Калининградская область, Светлый, Советская, 3	f	large
40733	37672	459	Калининградская область, Светлый, Рыбацкая, 1	f	large
40737	37676	463	Калининградская область, Светлый, Пионерская, 26	f	large
40736	37675	462	Калининградская область, Светлый, Парковая, 4	f	large
40728	37667	454	Калининградская область, Светлый, Молодежная, 6	f	large
40739	37678	465	Калининградская область, Светлый, Лопатина, 10	f	large
40735	37674	461	Калининградская область, Светлый, Коммунистическая, 7	f	large
40731	37670	457	Калининградская область, Светлый, Калининградская, 11	f	large
40732	37671	458	Калининградская область, Светлый, Калинина, 2	f	large
40727	37666	453	Калининградская область, Светлый, Калинина, 2	f	large
40730	37669	456	Калининградская область, Светлый, Заводская, 2	f	large
40734	37673	460	Калининградская область, Светлый, Восточная, 1	f	large
40719	37659	443	Калининградская область, Светлогорск, Яблоневая, 13, МАУ Дворец спорта Аквамарин	f	large
40718	37658	442	Калининградская область, Светлогорск, Новая, 3, МОУ СОШ №1	f	large
40347	37361	46	Калининградская область, Приморск, Железнодорожная, 8, Дом культур	f	\N
40685	37628	405	Калининградская область, Пионерский, Флотская, 20	f	large
40684	37628	404	Калининградская область, Пионерский, Флотская, 20	f	large
40683	37627	403	Калининградская область, Пионерский, Флотская, 2	f	large
40688	37630	408	Калининградская область, Пионерский, Рензаева, 26	f	large
40682	37626	402	Калининградская область, Пионерский, Комсомольская, 4	f	large
40687	37629	407	Калининградская область, Пионерский, Гагарина, 14	f	small
40681	37625	401	Калининградская область, Пионерский, Армейская, 1	f	large
40633	37580	345	Калининградская область, Неман, Первомайская, 10	f	large
40738	37677	464	Калининградская область, село Люблино, Гарнизонная, 2	f	large
40329	14642	28	Калининградская область, поселок Коса, Школьная, 18-А, школа Школьная	t	\N
40564	37528	273	Калининградская область, Калининград, улица Емельянова, 312	f	large
40471	37468	178	Калининградская область, Калининград, улица Багратиона, 105	f	large
40470	37468	177	Калининградская область, Калининград, улица Багратиона, 105	f	large
40511	37497	220	Калининградская область, Калининград, улица Артиллерийская, 16	f	large
40510	37497	219	Калининградская область, Калининград, улица Артиллерийская, 16	f	large
40514	37500	223	Калининградская область, Калининград, улица Александра Невского, 89	f	large
40567	37530	276	Калининградская область, Калининград, сержанта Колоскова, 10	f	large
40572	37534	281	Калининградская область, Калининград, проспект Мира, 136	f	large
40534	37510	243	Калининградская область, Калининград, полковника Ефремова, 12	f	large
40525	37510	234	Калининградская область, Калининград, полковника Ефремова, 12	f	large
40503	37490	210	Калининградская область, Калининград, подполковника Иванникова, 6	f	large
40487	37478	194	Калининградская область, Калининград, маршала Баграмяна набережная, 34	f	large
40486	37477	193	Калининградская область, Калининград, маршала Баграмяна набережная, 2	f	large
40602	37556	313	Калининградская область, Калининград, лейтенанта Яналова, 42	f	large
66502	14655	206	Калининградская область, Калининград, генерала Соммера, 23	f	\N
40497	37486	204	Калининградская область, Калининград, генерал-лейтенанта Озерова, 57	f	large
40506	37493	214	Калининградская область, Калининград, Юрия Гагарина, 55	f	large
40542	37520	251	Калининградская область, Калининград, Эпроновская, 31	f	large
40548	37522	257	Калининградская область, Калининград, Черниговская, 37	f	large
40595	37551	306	Калининградская область, Калининград, Чайковского, 50/52	f	large
40661	37606	376	Московская область, Наро-Фоминский район, садовое товарищество Лира, Центральная улица	f	medium
40490	37479	197	Калининградская область, Калининград, Фрунзе, 44	f	large
40558	37525	267	Калининградская область, Калининград, Ульяны Громовой, 67	f	large
40556	37471	265	Калининградская область, Калининград, Ульяны Громовой, 1	f	large
40478	37471	185	Калининградская область, Калининград, Ульяны Громовой, 1	f	medium
40557	37471	266	Калининградская область, Калининград, Ульяны Громовой, 1	f	large
66499	14653	183	Калининградская область, Калининград, Транспортный тупик, 10	f	\N
40492	37481	199	Калининградская область, Калининград, Томская, 19	f	large
40576	37535	285	Калининградская область, Калининград, Тенистая аллея, 35	f	large
40575	37535	284	Калининградская область, Калининград, Тенистая аллея, 35	f	large
40517	37503	226	Калининградская область, Калининград, Тельмана, 48	f	large
40465	37466	172	Калининградская область, Калининград, Судостроительная, 2	f	large
40466	37466	173	Калининградская область, Калининград, Судостроительная, 2	f	large
40475	37470	182	Калининградская область, Калининград, Суворова, 37	f	large
40474	37470	181	Калининградская область, Калининград, Суворова, 37	f	large
40452	37456	159	Калининградская область, Калининград, Суворова, 139А	f	large
40580	37537	289	Калининградская область, Калининград, Старшего сержанта Карташева, 111	f	large
40579	37537	288	Калининградская область, Калининград, Старшего сержанта Карташева, 111	f	large
40584	37540	295	Калининградская область, Калининград, Спортивная, 11	f	large
40606	37559	317	Калининградская область, Калининград, Солдатская, 7	f	large
40532	37515	241	Калининградская область, Калининград, Согласия, 39	f	large
40536	37515	245	Калининградская область, Калининград, Согласия, 39	f	large
40533	37515	242	Калининградская область, Калининград, Согласия, 39	f	large
40599	37554	310	Калининградская область, Калининград, Советский проспект, 48	f	large
40598	37554	309	Калининградская область, Калининград, Советский проспект, 48	f	large
40596	37552	307	Калининградская область, Калининград, Советский проспект, 13	f	large
40592	37548	303	Калининградская область, Калининград, Советский проспект, 1	f	large
40550	37523	259	Калининградская область, Калининград, Смелых аллея, 118	f	large
40549	37523	258	Калининградская область, Калининград, Смелых аллея, 118	f	large
40495	37484	202	Калининградская область, Калининград, Сергеева, 10	f	large
40481	37472	188	Калининградская область, Калининград, Свердлова, 25	f	large
40479	37472	186	Калининградская область, Калининград, Свердлова, 25	f	large
40571	37533	280	Калининградская область, Калининград, Радищева, 81	f	large
40570	37533	279	Калининградская область, Калининград, Радищева, 81	f	large
40568	37531	277	Калининградская область, Калининград, Пушкина, 10	f	large
40496	37485	203	Калининградская область, Калининград, Пролетарская, 66а	f	large
66504	14657	272	Калининградская область, Калининград, Подполковника Емельянова, 156	f	\N
40562	14657	271	Калининградская область, Калининград, Подполковника Емельянова, 156	f	large
40561	14657	270	Калининградская область, Калининград, Подполковника Емельянова, 156	f	large
40493	37482	200	Калининградская область, Калининград, Пионерская, 9	f	large
40456	37459	163	Калининградская область, Калининград, Балтийский район, Октябрьская площадь, 35	f	large
40455	37459	162	Калининградская область, Калининград, Балтийский район, Октябрьская площадь, 35	f	large
40521	37506	230	Калининградская область, Калининград, Озерная, 31	f	large
40545	37516	254	Калининградская область, Калининград, Новый Вал, 23	f	large
40538	37516	247	Калининградская область, Калининград, Новый Вал, 23	f	large
40537	37516	246	Калининградская область, Калининград, Новый Вал, 23	f	large
40565	37526	274	Калининградская область, Калининград, Николая Карамзина, 11	f	large
40559	37526	268	Калининградская область, Калининград, Николая Карамзина, 11	f	large
40500	37488	207	Калининградская область, Калининград, Московский проспект, 39	f	large
40485	37476	192	Калининградская область, Калининград, Московский проспект, 62	f	large
40484	37475	191	Калининградская область, Калининград, Московский проспект, 98	f	large
40483	37475	190	Калининградская область, Калининград, Московский проспект, 98	f	large
40507	37494	216	Калининградская область, Калининград, Молодой Гвардии, 2	f	large
35314	28973	313	Вологодская область, Вологда, Ярославская, 26а	f	large
40520	37505	229	Калининградская область, Калининград, Молодежная, 7	f	large
40610	37561	321	Калининградская область, Калининград, Мира, 1	f	large
40609	37561	320	Калининградская область, Калининград, Мира, 1	f	large
40608	37561	319	Калининградская область, Калининград, Мира, 1	f	large
40554	37524	263	Калининградская область, Калининград, Машиностроительная, 66	f	large
40553	37524	262	Калининградская область, Калининград, Машиностроительная, 66	f	large
40552	37524	261	Калининградская область, Калининград, Машиностроительная, 66	f	large
40551	37524	260	Калининградская область, Калининград, Машиностроительная, 66	f	large
40467	37446	174	Калининградская область, Калининград, Маршала Новикова, 5	f	large
40583	37539	292	Калининградская область, Калининград, Магнитогорская, 4	f	medium
40566	37529	275	Калининградская область, Калининград, Любы Шевцовой бульвар, 49	f	large
66503	14656	264	Россия, Калининградская область, Калининград, Любы Шевцовой бульвар, 39	f	\N
40482	37474	189	Калининградская область, Калининград, Литовский вал, 27а	f	large
40457	37460	164	Калининградская область, Калининград, Летняя, 48	f	large
40505	37492	213	Калининградская область, Калининград, Куйбышева, 15	f	large
40607	37560	318	Калининградская область, Калининград, Красная, 301	f	large
40603	37557	314	Калининградская область, Калининград, Красная, 119	f	large
40601	37555	312	Калининградская область, Калининград, Комсомольская, 67	f	large
40491	37480	198	Калининградская область, Калининград, Клиническая, 21	f	large
40594	37550	305	Калининградская область, Калининград, Кирова, 26	f	large
40593	37549	304	Калининградская область, Калининград, Кирова, 7	f	large
40469	37467	176	Калининградская область, Калининград, Киевская, 17	f	large
40605	37558	316	Калининградская область, Калининград, Каштановая Аллея, 143	f	large
40604	37558	315	Калининградская область, Калининград, Каштановая Аллея, 143	f	large
40586	37542	297	Калининградская область, Калининград, Каштановая Аллея, 141	f	large
40587	37543	298	Калининградская область, Калининград, Карла Маркса, 65	f	large
40453	37457	160	Калининградская область, Калининград, Камская, 4	f	large
40477	37461	184	Калининградская область, Калининград, Иванихиной, 7	f	large
40459	37461	166	Калининградская область, Калининград, Иванихиной, 7	f	large
40458	37461	165	Калининградская область, Калининград, Иванихиной, 7	f	large
40591	37547	302	Калининградская область, Калининград, Зоологическая, 1	f	large
40547	37521	256	Калининградская область, Калининград, Зои Космодемьянской, 26	f	large
40546	37521	255	Калининградская область, Калининград, Зои Космодемьянской, 26	f	large
40451	14647	158	Калининградская область, Калининград, Заводская, 26	t	large
40450	14647	157	Калининградская область, Калининград, Заводская, 26	t	large
40597	37553	308	Калининградская область, Калининград, Желябова переулок, 7	f	large
40460	37462	167	Калининградская область, Калининград, Дюнная, 18	f	large
40462	37463	169	Калининградская область, Калининград, Дрожжевая, 1	f	large
40461	37463	168	Калининградская область, Калининград, Дрожжевая, 1	f	large
40560	37527	269	Калининградская область, Калининград, Дзержинского, 163	f	large
40528	37511	237	Калининградская область, Калининград, Горького, 160	f	large
40526	37511	235	Калининградская область, Калининград, Горького, 160	f	large
40519	37504	228	Калининградская область, Калининград, Горького, 113	f	large
40518	37487	227	Калининградская область, Калининград, Горького, 66	f	large
40498	37487	205	Калининградская область, Калининград, Горького, 66	f	large
40524	37509	233	Калининградская область, Калининград, Герцена, 37	f	large
40531	37514	240	Калининградская область, Калининград, Гайдара, 87	f	large
40502	37489	209	Калининградская область, Калининград, Вагнера, 51	f	large
40501	37489	208	Калининградская область, Калининград, Вагнера, 51	f	large
40454	37458	161	Калининградская область, Калининград, Березовая, 2	f	large
40463	37464	170	Калининградская область, Калининград, Батальная, 11	f	large
40577	37536	286	Калининградская область, Калининград, Балтийское шоссе, 110	f	large
40480	37473	187	Калининградская область, Калининград, Бакинская, 13	f	large
40516	37502	225	Калининградская область, Калининград, Александра Невского, 165	f	large
35313	28973	312	Вологодская область, Вологда, Ярославская, 26а	f	large
40513	37499	222	Калининградская область, Калининград, Александра Невского, 14	f	large
110350	37546	300	Калининградская область, Калининград, космонавта Леонова, 6а	f	\N
40512	37498	221	Калининградская область, Калининград, Юрия Гагарина, 55	f	large
40468	37435	175	Калининградская область, Калининград, Школьная, 3	f	large
40588	37544	299	Калининградская область, Калининград, Чернышевского, 56	f	large
40473	37469	180	Калининградская область, Калининград, Серпуховская, 23	f	large
40472	37469	179	Калининградская область, Калининград, Серпуховская, 23	f	large
66500	14654	195	Калининградская область, Калининград, Сергея Тюленина, 4	f	\N
66501	14654	196	Калининградская область, Калининград, Сергея Тюленина, 4	f	\N
40539	37517	248	Калининградская область, Калининград, Мореходная, 3	f	large
66505	14627	282	Калининградская область, Калининград, Менделеева, 13	f	\N
66508	14627	290	Калининградская область, Калининград, Менделеева, 13	f	\N
66506	14627	283	Калининградская область, Калининград, Менделеева, 13	f	\N
40508	37495	217	Калининградская область, Калининград, Куйбышева, 91а	f	large
40585	37541	296	Калининградская область, Калининград, Кропоткина, 8	f	large
66509	14631	301	Калининградская область, Калининград, Комсомольская, 4	f	\N
40530	37513	239	Калининградская область, Калининград, Зеленая, 18а	f	large
40529	37513	238	Калининградская область, Калининград, Зеленая, 18а	f	large
40535	37512	244	Калининградская область, Калининград, Зеленая, 45	f	large
40527	37512	236	Калининградская область, Калининград, Зеленая, 45	f	large
40600	37538	311	Калининградская область, Калининград, Войнич, 1	f	large
40582	37538	291	Калининградская область, Калининград, Войнич, 1	f	large
40544	37519	253	Калининградская область, Калининград, Богдана Хмельницкого, 115	f	large
40543	37519	252	Калининградская область, Калининград, Богдана Хмельницкого, 115	f	large
40541	37519	250	Калининградская область, Калининград, Богдана Хмельницкого, 115	f	large
40540	37518	249	Калининградская область, Калининград, Богдана Хмельницкого, 27/31	f	large
40569	37532	278	Калининградская область, Калининград, Бассейная, 40	f	large
40509	37496	218	Калининградская область, Калининград, Александра Невского, 14	f	large
40504	37491	211	Калининградская область, Калининград, Александра Невского, 32	f	large
40403	37414	109	Калининградская область, Гусев, проспект Ленина, 21	f	large
40413	37419	118	Калининградская область, Гусев, Победы, 51а	f	large
40334	37352	33	Калининградская область, Балтийск, пр.Ленина, 41 , лицей №1	f	\N
40345	37359	44	Калининградская область, Балтийск, Ю.Иванова, 1 , ранее школа №	f	\N
40335	37353	34	Калининградская область, Балтийск, Чехова, 7, Детская поликлиника	f	\N
40340	37356	39	Калининградская область, Балтийск, Ушакова, 32, гимназия №7	f	\N
40341	37356	40	Калининградская область, Балтийск, Ушакова, 32, гимназия №7	f	\N
40339	37356	38	Калининградская область, Балтийск, Ушакова, 32, гимназия №7	f	\N
40338	37355	37	Калининградская область, Балтийск, Ушакова, 32, гимназия №7	f	\N
40343	37357	42	Калининградская область, Балтийск, Советская , 19, средняя школа №5	f	\N
40344	37357	43	Калининградская область, Балтийск, Советская , 19, средняя школа №5	f	\N
40333	37351	32	Калининградская область, Балтийск, Сенявина , 12, библиотека им.Белинского	f	\N
40332	37350	31	Калининградская область, Балтийск, Московская, 18, Дом детского творчества 	f	\N
40342	14643	41	Калининградская область, Балтийск, Мечникова, 5, ранее Вечерняя школа	t	\N
134532	94421	29	Калининградская область, Балтийск, Красной Армии, 31, ДОФ	f	\N
40331	37349	30	Калининградская область, Балтийск, Красной Армии, 31, средняя школа №6	f	\N
40337	37354	36	Калининградская область, Балтийск, Гоголя, 20, средняя школа №4	f	\N
40336	37354	35	Калининградская область, Балтийск, Гоголя, 20, средняя школа №4	f	\N
40805	37738	548	Калининградская область, Черняховский район, село Щеглы, Школьная, 5	f	small
40392	37404	98	Калининградская область, Черняховский район, село Шоссейное, Калининградское шоссе, 7	f	large
110351	37719	525	Калининградская область, Черняховский район, Черняховск, пер. Советский, 2	f	\N
40783	37716	522	Калининградская область, Черняховский район, Черняховск, Тольятти, 6	f	large
40788	37722	527	Калининградская область, Черняховский район, Черняховск, Театральная площадь, 1	f	large
40787	37721	526	Калининградская область, Черняховский район, Черняховск, Суворова, 11	f	large
40795	37729	534	Калининградская область, Черняховский район, Черняховск, Победы, 50	f	large
40790	37724	529	Калининградская область, Черняховский район, Черняховск, Победы, 40а	f	large
40782	37715	521	Калининградская область, Черняховский район, Черняховск, Победы, 32г	f	large
40796	37730	538	Калининградская область, Черняховский район, Черняховск, Октябрьская, 5	f	large
40780	37713	519	Калининградская область, Черняховский район, Черняховск, Ленинградская, 18/2	f	large
40779	37712	518	Калининградская область, Черняховский район, Черняховск, Ленинградская, 14	f	large
40778	37711	517	Калининградская область, Черняховский район, Черняховск, Ленинградская, 2а	f	large
40781	37714	520	Калининградская область, Черняховский район, Черняховск, Ленина, 17	f	large
40789	37723	528	Калининградская область, Черняховский район, Черняховск, Курчатова, 1	f	large
40791	37725	530	Калининградская область, Черняховский район, Черняховск, Каретная, 1	f	large
40794	37728	533	Калининградская область, Черняховский район, Черняховск, Калининградская, 23	f	large
40792	37726	531	Калининградская область, Черняховский район, Черняховск, Калининградская, 9	f	large
40777	37710	516	Калининградская область, Черняховский район, Черняховск, Горького, 2	f	large
40785	37718	524	Калининградская область, Черняховский район, Черняховск, Гагарина, 26	f	large
40784	37717	523	Калининградская область, Черняховский район, Черняховск, Гагарина, 6	f	large
40793	37727	532	Калининградская область, Черняховский район, Черняховск, 2-й Дачный переулок, 14б	f	large
40807	37740	550	Калининградская область, Черняховский район, село Тимофеевка, Центральная, 2	f	medium
40306	37327	2	Калининградская область, Черняховский район, село Совхозное, Центральная, 1	f	large
40809	37742	552	Калининградская область, Черняховский район, село Свобода, Школьная, 12	f	medium
40812	37745	555	Калининградская область, Черняховский район, село Пеньки, Детский переулок, 1	f	small
40326	37345	22	Калининградская область, Черняховский район, село Партизанское, Центральная, 31	f	medium
40813	37746	556	Калининградская область, Черняховский район, село Междуречье, Школьная, 5а	f	medium
40808	37741	551	Калининградская область, Черняховский район, село Краснополянское, Молодежная, 1	f	medium
40798	37732	540	Калининградская область, Черняховский район, село Каменское, Почтовая, 14	f	medium
40802	37736	544	Калининградская область, Черняховский район, село Калужское, Советская, 14	f	small
40801	37735	543	Калининградская область, Черняховский район, село Калиновка, Черняховского, 20	f	medium
40811	37744	554	Калининградская область, Черняховский район, село Заовражное, Калининградская, 17	f	medium
40806	37739	549	Московская область, Дмитровский район, коттеджный поселок Загорское	f	medium
40708	37648	430	Калининградская область, Черняховский район, поселок Железнодорожный, Коммунистическая, 27	f	large
40709	37649	431	Калининградская область, Черняховский район, поселок Железнодорожный, Вокзальная, 1	f	large
40797	37731	539	Калининградская область, Черняховский район, село Доваторовка, Мира, 8а	f	medium
40799	37733	541	Калининградская область, Черняховский район, село Глушково, Советской Конституции, 25	f	small
40810	37743	553	Калининградская область, Черняховский район, село Володаровка, здание дома культуры	f	small
66507	14630	287	Калининградская область, Центральный район, Калининград, Лужская, 27	f	\N
66519	14640	485	Калининградская область, Славский район, село Яснополянка, В помещении сельского клуба	f	\N
40758	37694	488	Калининградская область, Славский район, село Ясное, помещение Дома культуры	f	large
40756	37692	486	Калининградская область, Славский район, село Тимирязево, помещение адиминистрации поселения	f	large
40748	14649	478	Калининградская область, Славский район, село Советское, в помещении библиотеки	t	small
40743	37681	473	Калининградская область, Славский район, Славск, Советская, 23	f	large
40742	37680	472	Калининградская область, Славский район, Славск, Советская, 50	f	large
40757	37693	487	Калининградская область, Славский район, село Ржевское, помещение административного здания	f	medium
40754	37691	484	Калининградская область, Славский район, село Прохладное, помещение сельского клуба	f	medium
40752	37689	482	Калининградская область, Славский район, село Приозерье, помещение сельского клуба	f	small
40745	37683	475	Калининградская область, Славский район, село Придорожное, помещение библиотеки	f	small
40751	37688	481	Калининградская область, Славский район, село Охотное, помещение библиотеки	f	medium
40760	37696	491	Калининградская область, Славский район, село Мысовка, помещение Дома культуры	f	small
40417	37423	122	Смоленская область, Монастырщинский район, поселок Майское	f	medium
40673	37617	390	Калининградская область, Славский район, село Лужки, Школьная, 6	f	small
40749	37686	479	Калининградская область, Славский район, село Красное, помещение сельского клуба	f	small
40716	37656	438	Калининградская область, Славский район, село Красное, Центральная, 14	f	small
40753	37690	483	Калининградская область, Славский район, село Заповедное, помещение административного здания	f	medium
40746	37684	476	Калининградская область, Славский район, село Громово, помещение административного здания ПНИ	f	small
40750	37687	480	Калининградская область, Славский район, село Гастеллово, помещение административного здания	f	medium
40747	37685	477	Калининградская область, Славский район, поселок Высокое, помещение МБОУ Высоковская СОШ	f	small
40759	37695	490	Калининградская область, Славский район, село Вишневка, В конторе сельхозартели Бережки	f	small
40744	37682	474	Калининградская область, Славский район, село Большаково, Черняховского, 2в	f	large
66518	14639	466	Калининградская область, Светлый городской округ, село Взморье, Советская, 72	f	\N
40720	37660	444	Калининградская область, Светлогорский, Светлогорск, Калининградский проспект, 14, МОУ ДОД Детский юношеский центр	f	large
40672	37616	389	Калининградская область, Светлогорск городской округ, поселок Отрадное, Центральная, 16/2	f	small
40668	37612	385	Орловская область, Шаблыкинский район, поселок Чистополье	f	small
40707	37647	429	Калининградская область, Правдинский район, село Севское, Центральная, 7	f	medium
40704	37644	425	Калининградская область, Правдинский район, Правдинск, Кутузова, 28	f	large
40705	37645	426	Калининградская область, Правдинский район, Правдинск, Дзержинского, 1	f	large
40717	37657	439	Калининградская область, Правдинский район, село Новобобруйск, Фрунзенская, 24	f	small
40715	37655	437	Калининградская область, Правдинский район, село Мозырь, Октябрьская, 11	f	large
40710	37650	432	Калининградская область, Правдинский район, село Липняки, Пионерская, 1	f	medium
40712	37652	434	Калининградская область, Правдинский район, село Крылово, Центральная, 41	f	medium
40711	37651	433	Красноярский край, Минусинский район, поселок Знаменка	f	medium
40714	37654	436	Калининградская область, Правдинский район, село Ермаково, Школьная, 10	f	medium
40713	37653	435	Калининградская область, Правдинский район, село Домново, Калининградская, 6	f	large
40699	37640	419	Калининградская область, Полесский район, село Февральское, Центральная, 10	f	small
40694	37636	414	Калининградская область, Полесский район, село Тургенево, здание детского сада	f	medium
66514	14636	416	Калининградская область, Полесский район, село Саранск, Школьная, 1	f	\N
40691	37633	411	Калининградская область, Полесский район, Полесск, Театральная, 19	f	large
40689	37631	409	Калининградская область, Полесский район, Полесск, Советская, 12	f	large
40690	37632	410	Калининградская область, Полесский район, Полесск, Калининградская, 38	f	large
66515	14637	417	Калининградская область, Полесский район, село Новая-Деревня, Гвардейская, 28, здание школы	t	\N
40693	37635	413	Калининградская область, Полесский район, село Нахимово, Прохладная, здание библиотеки	f	small
40695	37637	415	Калининградская область, Полесский район, село Зеленое, переулок Торговый, 2	f	medium
40700	37641	420	Калининградская область, Полесский район, село Заливино, переулок Школьный, 5	f	medium
40702	37643	422	Калининградская область, Полесский район, село Залесье, Большаковская, 18	f	large
66516	14628	423	Калининградская область, Полесский район, поселок Дальнее, Полесская, 14	f	\N
40701	37642	421	Калининградская область, Полесский район, село Головкино, здание школы	f	medium
40666	37610	383	Калининградская область, Озерский район, село Суворовка, Центральная, 12а	f	medium
40420	37426	125	Воронежская область, Грибановский район, поселок Первомайское	f	medium
40671	37615	388	Калининградская область, Озерский район, село Олехово, Суворова, 67	f	small
40680	37624	397	Калининградская область, Озерский район, Озерск, площадь Победы, 1а	f	large
40679	37623	396	Калининградская область, Озерский район, Озерск, Московская, 1	f	large
40670	37614	387	Калининградская область, Озерский район, село Новостроево, Центральная, 6	f	medium
40678	37622	395	Калининградская область, Озерский район, село Новогурьевское, Гурьевская, 7г	f	medium
40675	37619	392	Калининградская область, Озерский район, село Нилово, Центральная, 14	f	small
40674	37618	391	Калининградская область, Озерский район, село Мальцево, Советская, 62	f	small
40667	37611	384	Калининградская область, Озерский район, село Львовское, Центральная, 24	f	small
40677	37621	394	Калининградская область, Озерский район, село Красноярское, Центральная, 14	f	medium
40663	14608	380	Калининградская область, Озерский район, село Карамышево, Садовая, 16	t	small
40662	37607	379	Калининградская область, Озерский район, село Гаврилово, Дзержинского, 40	f	small
40665	37609	382	Калининградская область, Озерский район, село Багратионово, Центральная, 38	f	small
40659	37604	374	Калининградская область, Нестеровский район, село Ясная-Поляна, Центральная, 33	f	large
40657	37602	372	Калининградская область, Нестеровский район, село Чистые-Пруды, Центральная, 33	f	medium
40648	37594	363	Калининградская область, Нестеровский район, село Чернышевское, Калининградская, 24	f	large
40660	37605	375	Калининградская область, Нестеровский район, село Фурмановка, Центральная, 38а	f	medium
40676	37620	393	Курганская область, Кетовский район, поселок сельского типа Садовое	f	medium
40647	37593	362	Калининградская область, Нестеровский район, Нестеров, Черняховского, 8	f	large
40646	37593	361	Калининградская область, Нестеровский район, Нестеров, Черняховского, 8	f	large
40653	37599	368	Калининградская область, Нестеровский район, село Невское, Садовая, 18	f	medium
40650	37596	365	Калининградская область, Нестеровский район, село Луговое, Нестеровская, 21	f	small
40658	37603	373	Калининградская область, Нестеровский район, село Краснолесье, Центральная, 2	f	small
40654	37600	369	Калининградская область, Нестеровский район, село Илюшино, Коммунальная, 3	f	large
40655	14625	370	Калининградская область, Нестеровский район, село Ильинское, Шоссейная, 5а	t	small
40651	37597	366	Калининградская область, Нестеровский район, село Бабушкино, Куйбышева, 61	f	medium
40656	37601	371	Калининградская область, Нестеровский, село Калинино, Центральная, 15	f	medium
40638	37585	350	Калининградская область, Неманский район, село Ульяново, Школьная, 8	f	medium
40641	37588	353	Калининградская область, Неманский район, село Ракитино, Центральная, 4	f	medium
40644	37591	356	Калининградская область, Неманский район, село Новоколхозное, Катаева, 3	f	medium
40630	37577	342	Калининградская область, Неманский район, Неман, Черняховского, 10	f	medium
40634	37581	346	Калининградская область, Неманский район, Неман, Советская, 35	f	large
40632	37579	344	Калининградская область, Неманский район, Неман, Советская, 17	f	large
40627	37574	339	Калининградская область, Неманский район, Неман, Советская, 2	f	large
40629	37576	341	Калининградская область, Неманский район, Неман, Полевая, 7	f	large
40628	37575	340	Калининградская область, Неманский район, Неман, Победы, 83	f	medium
40631	37578	343	Калининградская область, Неманский район, Неман, Октябрьская, 11	f	large
40637	37584	349	Калининградская область, Неманский район, поселок Маломожайское, Центральная, 30	f	medium
40639	37586	351	Калининградская область, Неманский район, село Лунино, Жилинская, 6	f	small
40636	14624	348	Калининградская область, Неманский район, село Лесное, Здание дома культуры	t	small
40645	37592	357	Калининградская область, Неманский район, село Канаш, Школьная, 10	f	small
40640	37587	352	Калининградская область, Неманский район, село Жилино, Комсомольская, 17	f	large
40642	37589	354	Калининградская область, Неманский район, село Ветрово, здание дома культуры	f	small
35292	28957	291	Вологодская область, Вологда, Элеваторная, 37	f	medium
40635	37582	347	Калининградская область, Неманский район, село Большое, Школьная, 2	f	medium
40643	37590	355	Калининградская область, Неманский район, село Акулово, 13, здание дома культуры	f	medium
40620	37567	331	Калининградская область, Краснознаменский район, село Хлебниково, Молодежная, 15а	f	small
66512	14634	326	Калининградская область, Краснознаменский район, село Узловое, Советская, 6	f	\N
40623	37570	334	Калининградская область, Краснознаменский район, село Тимофеево, Садовая, 2	f	medium
40617	37564	328	Калининградская область, Краснознаменский район, село Правдино, Советская, 3-а	f	small
40618	37565	329	Калининградская область, Краснознаменский район, село Победино, Победы, 22	f	small
40619	37566	330	Калининградская область, Краснознаменский район, поселок Острогожское, Краснознаменская, 23-а	f	small
66513	14635	327	Калининградская область, Краснознаменский район, село Ново-Уральское, Советская, 11	f	\N
40624	37571	335	Калининградская область, Краснознаменский район, село Неманское, Советская, 23	f	medium
40612	37563	323	Калининградская область, Краснознаменский район, Краснознаменск, Калининградская, 29	f	large
66510	14632	324	Калининградская область, Краснознаменский район, Краснознаменск, Калининградская, 39	f	\N
40625	37572	336	Калининградская область, Краснознаменский район, поселок Добровольск, площадь Героев, 5	f	large
66511	14633	325	Калининградская область, Краснознаменский район, село Весново, Советская, 7	f	\N
66498	14652	95	Калининградская область, Калининград городской округ, поселок Большое Исаково, Бариновой, 1	f	\N
40725	37665	449	Калининградская область, Зеленоградский район, поселок Янтарный, Советская, 74, спортивный зал	f	large
66517	14638	450	Калининградская область, Зеленоградский район, поселок Янтарный, Советская, 114	f	\N
40430	37437	137	Калининградская область, Зеленоградский район, поселок Рыбачий, Победы, 2	f	medium
40442	37448	149	Калининградская область, Зеленоградский район, село Романово, Школьная, 16а	f	large
40723	37663	447	Калининградская область, Зеленоградский район, поселок Приморье, Балтийский проспект, 14, МОУ СОШ	f	medium
40804	37737	547	Калининградская область, Зеленоградский район, село Привольное, Центральная, 23	f	medium
40446	37452	153	Калининградская область, Зеленоградский район, село Поваровка, Балтийская, 2а	f	medium
40438	37445	145	Калининградская область, Зеленоградский район, село Переславское, Гвардейская, 5	f	large
40440	14646	147	Калининградская область, Зеленоградский район, село Откосово, Прохладная, 19	t	medium
40318	37337	14	Калининградская область, Зеленоградский район, село Надеждино, Советская, 7	f	medium
40434	37441	141	Калининградская область, Зеленоградский район, село Муромское, Садовая, 2	f	large
40433	37440	140	Калининградская область, Зеленоградский район, село Моховое, Дорожная, 23	f	small
40431	37438	138	Калининградская область, Зеленоградский район, село Морское, Дачная, 9	f	small
40436	37443	143	Калининградская область, Зеленоградский район, село Мельниково, Новая, 6	f	medium
40435	37442	142	Калининградская область, Зеленоградский район, село Луговское, Кольцевая, 9а	f	medium
40439	14645	146	Калининградская область, Зеленоградский район, село Логвино, Молодёжная, 2а	t	small
40429	37436	136	Калининградская область, Зеленоградский район, село Лесной, Центральная, 9	f	small
40445	37451	152	Калининградская область, Зеленоградский район, село Красноторовка, Школьная, 5	f	medium
40447	37453	154	Калининградская область, Зеленоградский район, село Кострово, Школьная, 10	f	large
40441	37447	148	Калининградская область, Зеленоградский район, село Колосовка, Центральная, 3	f	large
40432	37439	139	Калининградская область, Зеленоградский район, село Коврово, Балтийская, 53	f	medium
40448	37454	155	Калининградская область, Зеленоградский район, Зеленоградск, Тургенева, 5б	f	large
40449	37455	156	Калининградская область, Зеленоградский район, Зеленоградск, Октябрьская, 7	f	large
40426	37432	133	Калининградская область, Зеленоградский район, Зеленоградск, Ленина, 20	f	large
40428	37434	135	Калининградская область, Зеленоградский район, Зеленоградск, Курортный проспект, 11	f	large
40425	37431	132	Калининградская область, Зеленоградский район, Зеленоградск, Курортный проспект, 5	f	large
40427	37433	134	Калининградская область, Зеленоградский район, Зеленоградск, Крымская, 5а, администрация	f	large
40443	37449	150	Калининградская область, Зеленоградский район, село Заостровье, Пионерская, 11	f	medium
40706	37646	428	Алтайский край, Алейский район, поселок Дружба	f	large
40724	37664	448	Калининградская область, Зеленоградский район, село Донское, Садовая, 7, МОУ СОШ	f	large
40444	37450	151	Калининградская область, Зеленоградский район, село Грачевка, Центральная, 12а	f	medium
40402	37413	108	Калининградская область, Зеленоградский район, село Васильково, Западная, 2	f	large
40622	37569	333	Калининградская область, Зеленоградский район, село Алексеевка, Шоссейная, 3	f	medium
40669	37613	386	Калининградская область, Гусевский район, село Юдино, Новая, 1а	f	small
40414	37420	119	Саратовская область, Марксовский район, село Фурманово	f	medium
40424	37430	129	Московская область, Сергиево-Посадский район, садовое товарищество Поселок Северный	f	small
40324	37343	20	Калининградская область, Гусевский район, село Северное, 21	f	large
40803	14650	546	Калининградская область, Гусевский район, село Покровское, Героев, 2	t	small
40415	37421	120	Калининградская область, Гусевский район, село Поддубы	f	medium
40422	37428	127	Калининградская область, Гусевский район, Ольховатка	f	small
40416	37422	121	Калининградская область, Гусевский район, село Михайловка	f	medium
40423	37429	128	Калининградская область, Гусевский район, село Маяковское	f	medium
40419	37425	124	Орловская область, Верховский район, поселок Кубановка	f	medium
40418	37424	123	Тульская область, Ефремовский район, поселок Красногорское	f	small
40421	37427	126	Саратовская область, Марксовский район, село Калининское	f	medium
40406	37417	112	Калининградская область, Гусевский район, Гусев, переулок Павлова, 4	f	large
40407	37358	113	Калининградская область, Гусевский район, Гусев, Юрия Смирнова, 20	f	large
40404	37415	110	Калининградская область, Гусевский район, Гусев, Ю. Смирнова, 20	f	large
40410	37396	115	Калининградская область, Гусевский район, Гусев, Ульяновых, 1	f	large
40409	37385	114	Калининградская область, Гусевский район, Гусев, Тимирязева, 3	f	large
40411	35300	116	Калининградская область, Гусевский район, Гусев, Советская, 10	f	large
40412	37418	117	Калининградская область, Гусевский район, Гусев, Железнодорожная, 46	f	large
40405	37416	111	Калининградская область, Гусевский район, Гусев, Артиллерийская, 2	f	large
40390	37402	96	Калининградская область, Гурьевский район, село Яблоневка, Центральная, 9	f	medium
40815	37747	558	Калининградская область, Гурьевский район, село Храброво, здание аэровокзала Храброво	f	small
40399	14644	105	Калининградская область, Гурьевский район, село Храброво, Александра Невского, 7	t	large
40393	37405	99	Калининградская область, Гурьевский район, село Ушаково, Победы, 7	f	medium
40698	37639	418	Калининградская область, Гурьевский район, село Сосновка, Центральная, 14	f	medium
40692	37634	412	Калининградская область, Гурьевский район, село Славянское, здание школы	f	large
40317	37336	13	Калининградская область, Гурьевский район, село Рябиновка, Мирная, 2	f	small
40686	14648	406	Калининградская область, Гурьевский район, село Рыбное, здание РГУ	t	medium
40385	37399	91	Калининградская область, Гурьевский район, село Родники, Марьина, 21	f	medium
40381	37394	87	Калининградская область, Гурьевский район, село Рассвет, Центральная, 17	f	small
40397	37409	103	Калининградская область, Гурьевский район, село Петрово, Октябрьская, 2	f	medium
40396	37408	102	Калининградская область, Гурьевский район, село Орловка, Центральная, 24	f	medium
40384	37398	90	Калининградская область, Гурьевский район, село Низовье, Калининградская, 18	f	medium
66497	14651	84	Калининградская область, Гурьевский район, село Некрасово, Центральная, 17	f	\N
40374	37388	80	Калининградская область, Гурьевский район, село Моргуново, Гурьева, 14а	f	medium
40398	37410	104	Калининградская область, Гурьевский район, село Матросово, Центральная, 20	f	large
40377	37391	83	Калининградская область, Гурьевский район, село Маршальское, Центральная, 5а	f	large
40395	37407	101	Калининградская область, Гурьевский район, село Малое Васильково, Степная, 1а	f	large
35342	28993	341	Вологодская область, Вологда, Горького, 115	f	large
40388	37401	94	Калининградская область, Гурьевский район, село Малое Васильково, Западная, 2	f	large
40387	37401	93	Калининградская область, Гурьевский район, село Малое Васильково, Западная, 2	f	large
40382	37395	88	Калининградская область, Гурьевский район, село Малинники, Молодежная, 15	f	medium
40814	37406	557	Калининградская область, Гурьевский район, село Луговое, Центральная, 2	f	medium
40394	37406	100	Калининградская область, Гурьевский район, село Луговое, Центральная, 2	f	large
40391	37403	97	Калининградская область, Гурьевский район, село Лесной, Багратионовская, 25	f	medium
40380	37393	86	Калининградская область, Гурьевский район, село Константиновка, Зеленая, 4	f	medium
40376	37390	82	Калининградская область, Гурьевский район, село Заречье, 20, Административное здание ОАО "Добрино"	f	medium
40386	37400	92	Калининградская область, Гурьевский район, село Заозерье, Центральная, 4	f	medium
40379	37392	85	Калининградская область, Гурьевский район, село Заливное, Центральная, 6	f	small
40375	37389	81	Калининградская область, Гурьевский район, село Добрино, Калининградская, 26	f	medium
40401	37412	107	Калининградская область, Гурьевский район, Гурьевск, Садовая, 19	f	large
40372	37386	78	Калининградская область, Гурьевский район, Гурьевск, Садовая, Гимназия №2	f	large
40371	37384	77	Калининградская область, Гурьевский район, Гурьевск, Ленина, СОШ №1	f	large
40370	37383	76	Калининградская область, Гурьевский район, Гурьевск, Ленина, СОШ №1	f	large
40373	37387	79	Калининградская область, Гурьевский район, Гурьевск, Заречная, ПУ-19	f	large
40383	37397	89	Калининградская область, Гурьевский район, село Высокое, Полевая, 18	f	medium
40664	37608	381	Калининградская область, Гвардейский район, село Яблоновка, Центральная, 29	f	small
40363	37376	67	Калининградская область, Гвардейский район, село Толпаки, Мира, 12	f	medium
40366	37379	70	Калининградская область, Гвардейский район, село Славинск, Ст.Козака, 7	f	large
40649	37595	364	Калининградская область, Гвардейский район, село Пригородное, Пригородная, 7	f	small
40360	37373	64	Калининградская область, Гвардейский район, село Озерки, Школьная, 1	f	large
40369	37382	73	Калининградская область, Гвардейский район, село Озерки, Садовая, 8	f	medium
40368	37381	72	Калининградская область, Гвардейский район, село Малиновка, здание Дома культуры	f	small
40364	37377	68	Калининградская область, Гвардейский район, село Красный Яр, Школьная, 7	f	medium
40361	37374	65	Калининградская область, Гвардейский район, село Комсомольск, Школьная, 7	f	large
40365	37378	69	Калининградская область, Гвардейский район, село Зорино, Центральная, 17	f	large
40359	37372	63	Калининградская область, Гвардейский район, поселок Знаменск, Шоссейная, здание клуба маргаринового завода	f	large
40358	37371	62	Калининградская область, Гвардейский район, поселок Знаменск, Советская, 5	f	large
40357	37370	61	Калининградская область, Гвардейский район, поселок Знаменск, Железнодорожная, 9	f	large
40362	37375	66	Калининградская область, Гвардейский район, село Заречье, Центральная, 18	f	medium
40348	37362	47	Калининградская область, Гвардейский район, село Дивное, Молодежная, 12 А , детский сад	f	\N
40354	37367	58	Калининградская область, Гвардейский район, Гвардейск, Юбилейная, 4	f	large
40353	37366	57	Калининградская область, Гвардейский район, Гвардейск, Юбилейная, 4	f	large
40351	37365	55	Калининградская область, Гвардейский район, Гвардейск, Тельмана, 6	f	large
40349	37363	53	Калининградская область, Гвардейский район, Гвардейск, Тельмана, 30а	f	large
40352	37363	56	Калининградская область, Гвардейский район, Гвардейск, Тельмана, 30а	f	large
40356	37369	60	Калининградская область, Гвардейский район, Гвардейск, Красноармейская, 24	f	large
40350	37364	54	Калининградская область, Гвардейский район, Гвардейск, Калининградская, 16	f	large
40355	37368	59	Калининградская область, Гвардейский район, Гвардейск, Вокзальная, Здание ж/д вокзала	f	small
40367	37380	71	Калининградская область, Гвардейский район, село Борское, 50	f	medium
40323	37342	19	Калининградская область, Багратионовский район, село Южный, 57	f	large
40321	37340	17	Калининградская область, Багратионовский район, село Чехово, Клубная, 3	f	medium
35339	28993	338	Вологодская область, Вологда, Горького, 115	f	large
40320	37339	16	Калининградская область, Багратионовский район, село Тишоно, Центральная, 4	f	small
40311	37332	7	Калининградская область, Багратионовский район, село Славское, Тхоржевского, 12	f	small
40305	37326	1	Калининградская область, Багратионовский район, село Пятидорожное, Красноармейская, 4	f	large
40652	37598	367	Калининградская область, Багратионовский район, село Пушкино, Центральная, 5	f	medium
40307	37328	3	Калининградская область, Багратионовский район, село Пограничное, Молодежная, 12	f	medium
40308	37329	4	Калининградская область, Багратионовский район, село Новомосковский, Школьная, 1	f	medium
40322	37341	18	Калининградская область, Багратионовский район, село Нивенское, Калининградская, 20	f	large
40310	37331	6	Калининградская область, Багратионовский район, село Медовое, Школьная, 7	f	small
40818	37750	589	Калининградская область, Багратионовский район, Мамоново, Центральная, 3	f	large
40817	37749	588	Калининградская область, Багратионовский район, Мамоново, Калининградское шоссе, 5	f	large
40816	37748	587	Калининградская область, Багратионовский район, Мамоново, Евсеева, 2	f	large
40800	37734	542	Калининградская область, Багратионовский район, село Липовка, Советская, 1	f	small
40328	37347	26	Калининградская область, Багратионовский район, Ладушкин, Сосновая, 12	f	medium
40327	37346	25	Калининградская область, Багратионовский район, Ладушкин, Победы, 12	f	large
40312	37167	8	Калининградская область, Багратионовский район, село Краснознаменское, Центральная, 21	f	medium
40309	37330	5	Калининградская область, Багратионовский район, село Корнево, Центральная, 3	f	large
40621	37568	332	Белгородская область, Борисовский район, поселок Заречное	f	small
40313	37138	9	Калининградская область, Багратионовский район, поселок Долгоруково, 1-я Народная, 1	f	large
40319	37338	15	Калининградская область, Багратионовский район, село Гвардейское, Школьная, 8а	f	large
40325	37344	21	Калининградская область, Багратионовский район, село Владимирово, Школьная, 8а	f	large
40315	37334	11	Калининградская область, Багратионовский район, Багратионовск, Пограничная, 57	f	large
40314	37333	10	Калининградская область, Багратионовский район, Багратионовск, Пограничная, 62	f	medium
40316	37335	12	Калининградская область, Багратионовский район, Багратионовск, Калининградская, 10	f	large
35890	29517	909	Вологодская область, Ясная Поляна, Механизаторов, 3-б	t	medium
35992	29605	1011	Вологодская область, Череповец, улица Юбилейная, 36	f	large
35955	29572	974	Вологодская область, Череповец, улица Центральная, 18, Средняя общеобразовательная школа № 36	f	large
35959	29576	978	Вологодская область, Череповец, улица Пионерская, 19	f	large
35981	29596	1000	Вологодская область, Череповец, улица Олимпийская, 59, Средняя общеобразовательная школа № 2	f	large
35927	29550	946	Вологодская область, Череповец, улица Металлургов, 40	f	large
35924	29547	943	Вологодская область, Череповец, улица Ленина, 149, общежитие	f	large
36003	29612	1022	Вологодская область, Череповец, улица Краснодонцев, 26а, Детско-юношеская спортивная школа № 4	f	large
35983	29598	1002	Вологодская область, Череповец, улица Космонавта Беляева, 32, Центр детского творчества	f	large
35914	29537	933	Вологодская область, Череповец, улица Батюшкова, 10, Начальная общеобразовательная школа № 41	f	large
35919	29542	938	Вологодская область, Череповец, проспект Строителей, 30, библиотека №10 МБУК Объединение библиотек	f	large
35996	29607	1015	Вологодская область, Череповец, Юбилейная, 9, Средняя общеобразовательная школа № 5	f	large
35997	29607	1016	Вологодская область, Череповец, Юбилейная, 9, Средняя общеобразовательная школа № 5	f	large
35995	29606	1014	Вологодская область, Череповец, Юбилейная, 11, Средняя общеобразовательная школа № 9	f	large
35994	29606	1013	Вологодская область, Череповец, Юбилейная, 11, Средняя общеобразовательная школа № 9	f	large
35993	29606	1012	Вологодская область, Череповец, Юбилейная, 11, Средняя общеобразовательная школа № 9	f	large
35911	29536	930	Вологодская область, Череповец, Шекснинский проспект, 27а, Центр профилактики правонарушений	f	large
35923	29546	942	Вологодская область, Череповец, Чкалова, 20а, Средняя общеобразовательная школа № 18	f	large
36000	29609	1019	Вологодская область, Череповец, Суворова, 5, Средняя общеобразовательная школа № 19	f	large
35922	29544	941	Вологодская область, Череповец, Индустриальный район, Строителей площадь, 1	f	large
35921	29544	940	Вологодская область, Череповец, Индустриальный район, Строителей площадь, 1	f	large
134699	95161	966	Вологодская область, Череповец, Сталеваров, 32	f	large
35933	29555	952	Вологодская область, Череповец, Сталеваров, 78, общежитие	f	large
35952	29570	971	Вологодская область, Череповец, Советский проспект, 60А, Средняя общеобразовательная школа № 1	f	large
35951	29570	970	Вологодская область, Череповец, Советский проспект, 60А, Средняя общеобразовательная школа № 1	f	large
35950	29569	969	Вологодская область, Череповец, Советский проспект, 35а	f	large
35949	29568	968	Вологодская область, Череповец, Советский проспект, 10, учебный корпус № 6 ЧГУ	f	large
35418	29054	417	Вологодская область, Череповец, Советский проспект, 21	f	large
35962	29579	981	Вологодская область, Череповец, Северное шоссе, 29, МБУК Объединение библиотек	f	large
36002	29611	1021	Вологодская область, Череповец, Победы проспект, 116, Средняя общеобразовательная школа № 34	f	large
36001	29611	1020	Вологодская область, Череповец, Победы проспект, 116, Средняя общеобразовательная школа № 34	f	large
35974	29588	993	Вологодская область, Череповец, Победы проспект, 147, Средняя общеобразовательная школа № 27	f	large
35973	29588	992	Вологодская область, Череповец, Победы проспект, 147, Средняя общеобразовательная школа № 27	f	large
35932	29554	951	Вологодская область, Череповец, Победы проспект, 18	f	large
35960	29577	979	Вологодская область, Череповец, Пионерская, 14, Средняя общеобразовательная школа № 33	f	large
35958	29575	977	Вологодская область, Череповец, Пионерская, 11, Средняя общеобразовательная школа № 13	f	large
35957	29575	976	Вологодская область, Череповец, Пионерская, 11, Средняя общеобразовательная школа № 13	f	large
36009	29616	1028	Вологодская область, Череповец, Первомайская, 48, Институт менеджмента и информац. технологий	f	large
35961	29578	980	Вологодская область, Череповец, Партизана Окинина, 5, Череповецкий химико-технологический колледж	f	large
35982	29597	1001	Вологодская область, Череповец, Олимпийская, 59, Средняя общеобразовательная школа № 21	f	large
35980	29595	999	Вологодская область, Череповец, Олимпийская, 59, Средняя общеобразовательная школа № 2	f	large
35910	29534	929	Вологодская область, Череповец, Октябрьский проспект, 70	f	large
35908	29532	927	Вологодская область, Череповец, Октябрьский проспект, 56, Детско-юнош. спорт. школа боевых искусств	f	large
35901	29527	920	Вологодская область, Череповец, Октябрьский проспект, 67, Начальная общеобразовательная школа № 43	f	large
35900	29526	919	Вологодская область, Череповец, Октябрьский проспект, 85, клуб Звезда МБУК Дворец металлургов	f	large
35954	29571	973	Вологодская область, Череповец, Набережная, 55, Средняя общеобразовательная школа № 25	f	large
35953	29571	972	Вологодская область, Череповец, Набережная, 55, Средняя общеобразовательная школа № 25	f	large
35965	29581	984	Вологодская область, Череповец, Моченкова, 10, Средняя общеобразовательная школа № 29	f	large
35964	29581	983	Вологодская область, Череповец, Моченкова, 10, Средняя общеобразовательная школа № 29	f	large
35966	29582	985	Вологодская область, Череповец, Молодёжная, 3	f	large
35918	29541	937	Вологодская область, Череповец, Менделеева, 14, Средняя общеобразовательная школа № 12	f	large
35915	29538	934	Вологодская область, Череповец, Матуринская, 58, Средняя общеобразовательная школа № 8	f	large
35946	29565	965	Вологодская область, Череповец, Максима Горького, 14, учебный корпус № 3 ЧГУ	f	large
35945	29564	964	Вологодская область, Череповец, Максима Горького, 22а, Дом музыки и кино	f	large
35907	29531	926	Вологодская область, Череповец, Любецкая, 19а, Начальная общеобразовательная школа № 39	f	large
35906	29530	925	Вологодская область, Череповец, Любецкая, 19, Средняя общеобразовательная школа № 40	f	large
35905	29530	924	Вологодская область, Череповец, Любецкая, 19, Средняя общеобразовательная школа № 40	f	large
35943	29562	962	Вологодская область, Череповец, Луначарского проспект, 44, Средняя общеобразовательная школа № 11	f	large
35942	29562	961	Вологодская область, Череповец, Луначарского проспект, 44, Средняя общеобразовательная школа № 11	f	large
35940	29560	959	Вологодская область, Череповец, Луначарского проспект, 53, общежитие	f	large
35913	29533	932	Вологодская область, Череповец, Ленинградская, 14, Средняя общеобразовательная школа № 32	f	large
35909	29533	928	Вологодская область, Череповец, Ленинградская, 14, Средняя общеобразовательная школа № 32	f	large
35912	29533	931	Вологодская область, Череповец, Ленинградская, 14, Средняя общеобразовательная школа № 32	f	large
35936	29557	955	Вологодская область, Череповец, Ленина, 111, Средняя общеобразовательная школа № 20	f	large
35935	29557	954	Вологодская область, Череповец, Ленина, 111, Средняя общеобразовательная школа № 20	f	large
35926	29549	945	Вологодская область, Череповец, Ленина, 134, общежитие	f	large
35967	29583	986	Вологодская область, Череповец, Леднёва, 7, Общеобразовательный лицей АМТЭК	f	large
35979	29594	998	Вологодская область, Череповец, Краснодонцев, 106, Центр детского творчества	f	large
35978	29592	997	Вологодская область, Череповец, Краснодонцев, 118, Череповецкая автомобильная школа ДОСААФ	f	large
35977	29591	996	Вологодская область, Череповец, Краснодонцев, 66, Средняя общеобразовательная школа № 10	f	large
35976	29590	995	Вологодская область, Череповец, Краснодонцев, 68, Средняя общеобразовательная школа № 24	f	large
35970	29587	989	Вологодская область, Череповец, Краснодонцев, 40а, Средняя общеобразовательная школа № 28	f	large
35972	29587	991	Вологодская область, Череповец, Краснодонцев, 40а, Средняя общеобразовательная школа № 28	f	large
35971	29587	990	Вологодская область, Череповец, Краснодонцев, 40а, Средняя общеобразовательная школа № 28	f	large
35968	29585	987	Вологодская область, Череповец, Краснодонцев, 17, библиотека № 3	f	large
36011	29617	1030	Вологодская область, Череповец, Красная, 5а, Средняя общеобразовательная школа № 7	f	large
36010	29617	1029	Вологодская область, Череповец, Красная, 5а, Средняя общеобразовательная школа № 7	f	large
35985	29600	1004	Вологодская область, Череповец, Космонавта Беляева, 48, Средняя общеобразовательная школа № 17	f	large
35984	29599	1003	Вологодская область, Череповец, Космонавта Беляева, 48, Средняя общеобразовательная школа № 17	f	large
35975	29589	994	Вологодская область, Череповец, Космонавта Беляева, 16, Средняя общеобразовательная школа № 26	f	large
35941	29561	960	Вологодская область, Череповец, Комсомольская, 8, общежитие индустриального колледжа	f	large
35989	29601	1008	Вологодская область, Череповец, Командарма Белова, 51, Средняя общеобразовательная школа № 30	f	large
35988	29601	1007	Вологодская область, Череповец, Командарма Белова, 51, Средняя общеобразовательная школа № 30	f	large
35987	29601	1006	Вологодская область, Череповец, Командарма Белова, 51, Средняя общеобразовательная школа № 30	f	large
35986	29601	1005	Вологодская область, Череповец, Командарма Белова, 51, Средняя общеобразовательная школа № 30	f	large
35925	29548	944	Вологодская область, Череповец, Клубный проезд, 2, Средняя общеобразовательная школа № 16	f	large
35917	29540	936	Вологодская область, Череповец, Доменщиков бульвар, 11, Средняя общеобразовательная школа № 21	f	large
35916	29539	935	Вологодская область, Череповец, Доменщиков бульвар, 11Б, Средняя общеобразовательная школа № 3	f	large
35904	29529	923	Вологодская область, Череповец, Городецкая, 20, Средняя общеобразовательная школа № 14	f	large
35903	29529	922	Вологодская область, Череповец, Городецкая, 20, Средняя общеобразовательная школа № 14	f	large
35902	29528	921	Вологодская область, Череповец, Городецкая, 26, Детско-юношеская спортивная школа № 4	f	large
36008	29615	1027	Вологодская область, Череповец, Гоголя, 34, Средняя общеобразовательная школа № 31	f	large
36007	29615	1026	Вологодская область, Череповец, Гоголя, 34, Средняя общеобразовательная школа № 31	f	large
36006	29614	1025	Вологодская область, Череповец, Гоголя, 21, Череповецкий техникум сферы обслуживания	f	large
36005	29614	1024	Вологодская область, Череповец, Гоголя, 21, Череповецкий техникум сферы обслуживания	f	large
36004	29613	1023	Вологодская область, Череповец, Гоголя, 36, общежитие	f	large
35332	28986	331	Вологодская область, Вологда, Горького, 93	f	large
35928	29551	947	Вологодская область, Череповец, Гагарина, 41, Средняя общеобразовательная школа № 15	f	large
35939	29559	958	Вологодская область, Череповец, Вологодская, 23, Средняя общеобразовательная школа № 4	f	large
35938	29559	957	Вологодская область, Череповец, Вологодская, 23, Средняя общеобразовательная школа № 4	f	large
35937	29558	956	Вологодская область, Череповец, Вологодская, 21, Средняя общеобразовательная школа № 22	f	large
35934	29556	953	Вологодская область, Череповец, Вологодская, 3, Детская школа искусств	f	large
35999	29608	1018	Вологодская область, Череповец, Архангельская, 7а, библиотека № 8 МБУК Объединение библиотек	f	large
35998	29608	1017	Вологодская область, Череповец, Архангельская, 7а, библиотека № 8 МБУК Объединение библиотек	f	large
35969	29586	988	Вологодская область, Череповец, Архангельская, 100Б, Центр детского творчества	f	large
35931	29553	950	Вологодская область, Череповец, Металлургов, 19, Средняя общеобразовательная школа № 6	f	large
35930	29553	949	Вологодская область, Череповец, Металлургов, 19, Средняя общеобразовательная школа № 6	f	large
35781	29408	795	Вологодская область, Устюжна, Ленина, 6	f	medium
35808	29437	823	Вологодская область, Устюжна, Коммунистический переулок, 41	f	medium
35648	29277	658	Вологодская область, Сокол, Суворова, 6	f	medium
35665	29293	676	Вологодская область, Сокол, Кооперативная, 14а	f	large
35658	29286	668	Вологодская область, Сокол, Беляева, 11/2	f	large
35582	29213	591	Вологодская область, Никольск, 25 Октября, 1	f	medium
35261	28930	250	Вологодская область, поселок Кувшиново, Дачная, 1	f	large
35456	29096	460	Вологодская область, Грязовец, Румянцевой, 43-Б, Детская консультация БУЗ Грязовецкая ЦРБ	f	large
35459	29099	463	Вологодская область, Грязовец, Комсомольская, 49 , Управление образования	f	large
35454	29094	458	Вологодская область, Грязовец, Газовиков, 26-А	f	large
35317	28949	316	Вологодская область, Вологда, улица Ярославская, 34а	f	large
35316	28949	315	Вологодская область, Вологда, улица Ярославская, 34а	f	large
35281	28949	280	Вологодская область, Вологда, улица Ярославская, 34а	f	large
35376	29017	375	Вологодская область, Вологда, улица Щетинина, 2а	f	large
35326	28980	325	Вологодская область, Вологда, улица Чернышевского, 114	f	large
35325	28980	324	Вологодская область, Вологда, улица Чернышевского, 114	f	large
35375	29016	374	Вологодская область, Вологда, улица Тендрякова, 46	f	large
35374	29016	373	Вологодская область, Вологда, улица Тендрякова, 46	f	large
35382	29022	381	Вологодская область, Вологда, улица Солодунова, 54	f	large
35347	28997	346	Вологодская область, Вологда, улица Пугачева, 40а	f	large
35353	29002	352	Вологодская область, Вологда, улица Пролетарская, 20	f	large
35309	28970	308	Вологодская область, Вологда, улица Пригородная, 12	f	large
35304	28966	303	Вологодская область, Вологда, улица Пригородная, 8	f	large
35302	28966	301	Вологодская область, Вологда, улица Пригородная, 8	f	large
35380	29020	379	Вологодская область, Вологда, улица Преображенского, 49	f	large
35298	28962	297	Вологодская область, Вологда, улица Пионерская, 20	f	large
35278	28946	277	Вологодская область, Вологда, улица Первомайская, 42	f	large
35116	28788	99	Вологодская область, Вологда, улица Первомайская, 3	f	large
35379	29019	378	Вологодская область, Вологда, улица Панкратова, 75	f	large
35328	28982	327	Вологодская область, Вологда, улица Некрасова, 51/18	f	large
35318	28974	317	Вологодская область, Вологда, улица Медуницинская, 21	f	large
35420	29057	419	Вологодская область, Вологда, улица Кирпичная, 3	f	small
35333	28987	332	Вологодская область, Вологда, улица Карла Маркса, 66а	f	large
35383	29023	382	Вологодская область, Вологда, улица Ильюшина, 15	f	large
35543	29175	552	Вологодская область, Вологда, улица Заречная, 52	f	large
35362	29009	361	Вологодская область, Вологда, улица Залинейная, 24в	f	large
35338	28992	337	Вологодская область, Вологда, улица Горького, 140	f	large
35336	28990	335	Вологодская область, Вологда, улица Горького, 105	f	large
35283	28951	282	Вологодская область, Вологда, улица Герцена, 60	f	large
35356	29005	355	Вологодская область, Вологда, проспект Победы, 50, школа №20	f	large
35295	28960	294	Вологодская область, Вологда, космонавта Беляева, 22А	f	large
35315	28973	314	Вологодская область, Вологда, Ярославская, 26а	f	large
35384	29024	383	Вологодская область, Вологда, Щетинина, 2а, Институт права и экономики ФСИН	f	large
35815	29444	830	Вологодская область, Вологда, Школьный переулок, 5	f	large
35324	28979	323	Вологодская область, Вологда, Чернышевского, 78	f	large
35323	28978	322	Вологодская область, Вологда, Чернышевского, 53	f	large
35322	28977	321	Вологодская область, Вологда, Чернышевского, 73	f	large
35280	28948	279	Вологодская область, Вологда, Техникумовский переулок, 4	f	large
35377	29018	376	Вологодская область, Вологда, Тендрякова, 46, Школа№28	f	large
35327	28981	326	Вологодская область, Вологда, Строителей, 10	f	large
35291	28956	290	Вологодская область, Вологда, Советский проспект, 120	f	large
35290	28956	289	Вологодская область, Вологда, Советский проспект, 120	f	large
35286	28954	285	Вологодская область, Вологда, Советский проспект, 54	f	large
35348	28998	347	Вологодская область, Вологда, Северная, 17	f	large
35341	28994	340	Вологодская область, Вологда, Северная, 6а	f	large
35340	28994	339	Вологодская область, Вологда, Северная, 6а	f	large
35334	28988	333	Вологодская область, Вологда, Саммера, 1	f	large
35357	29006	356	Вологодская область, Вологда, Пролетарская, 73	f	large
35276	28944	275	Вологодская область, Вологда, Пригородная, 8, школа №36	f	large
35319	28975	318	Вологодская область, Вологда, Пошехонское шоссе, 26	f	large
35355	29004	354	Вологодская область, Вологда, Победы проспект, 50	f	large
35354	29003	353	Вологодская область, Вологда, Победы проспект, 37	f	large
35289	28952	288	Вологодская область, Вологда, Пирогова, 26	f	large
35284	28952	283	Вологодская область, Вологда, Пирогова, 26	f	large
35297	28961	296	Вологодская область, Вологда, Пионерская, 20	f	large
35301	28965	300	Вологодская область, Вологда, Петрозаводская, 20	f	large
35300	28964	299	Вологодская область, Вологда, Петрозаводская, 24а	f	large
35386	29026	385	Вологодская область, Вологда, Первый МКР ГПЗ-23, 2б	f	large
35385	29025	384	Вологодская область, Вологда, Первый МКР ГПЗ-23, 17	f	large
35285	28953	284	Вологодская область, Вологда, Первомайская, 30	f	large
35329	28983	328	Вологодская область, Вологда, Открытая, 9	f	large
35310	28971	309	Вологодская область, Вологда, Осаново, 14а	f	small
35390	29028	389	Вологодская область, Вологда, Окружное шоссе, 23а	f	large
35389	29028	388	Вологодская область, Вологда, Окружное шоссе, 23а	f	large
35388	29028	387	Вологодская область, Вологда, Окружное шоссе, 23а	f	large
35330	28984	329	Вологодская область, Вологда, Некрасовский переулок, 15а	f	large
35299	28963	298	Вологодская область, Вологда, Московское шоссе, 34	f	medium
35312	28972	311	Вологодская область, Вологда, Можайского, 15а	f	large
35358	29000	357	Вологодская область, Вологда, Мира, 56	f	large
35351	29000	350	Вологодская область, Вологда, Мира, 56	f	large
35350	29000	349	Вологодская область, Вологда, Мира, 56	f	large
35346	28996	345	Вологодская область, Вологда, Машиностроительная, 26	f	large
35814	29443	829	Вологодская область, Вологда, Майский переулок, 4	f	large
35361	29008	360	Вологодская область, Вологда, Ленинградская, 5	f	large
35277	28945	276	Вологодская область, Вологда, Ленина, 17	f	large
35393	29029	392	Вологодская область, Вологда, Костромская, 6	f	large
35392	29029	391	Вологодская область, Вологда, Костромская, 6	f	large
35391	29029	390	Вологодская область, Вологда, Костромская, 6	f	large
35303	28967	302	Вологодская область, Вологда, Космонавта Беляева, 9	f	large
35296	28958	295	Вологодская область, Вологда, Космонавта Беляева, 13	f	large
35293	28958	292	Вологодская область, Вологда, Космонавта Беляева, 13	f	large
35288	28955	287	Вологодская область, Вологда, Козленская, 99	f	large
35287	28955	286	Вологодская область, Вологда, Козленская, 99	f	large
35279	28947	278	Вологодская область, Вологда, Козленская, 57	f	large
35360	29007	359	Вологодская область, Вологда, Кирова, 35	f	large
35359	29007	358	Вологодская область, Вологда, Кирова, 35	f	large
35349	28999	348	Вологодская область, Вологда, Канифольная, 1	f	small
35387	29027	386	Вологодская область, Вологда, Ильюшина, 23	f	large
35395	29031	394	Вологодская область, Вологда, Емельянова, 1	f	large
35345	28995	344	Вологодская область, Вологда, Дальняя, 32а	f	large
35344	28995	343	Вологодская область, Вологда, Дальняя, 32а	f	large
35343	28995	342	Вологодская область, Вологда, Дальняя, 32а	f	large
35275	28943	274	Вологодская область, Вологда, Городской Вал, 26а	f	large
35274	28942	273	Вологодская область, Вологда, Городской Вал, 26	f	medium
35282	28950	281	Вологодская область, Вологда, Герцена, 53	f	medium
35381	29021	380	Вологодская область, Вологда, Гагарина, 81	f	large
35371	29014	370	Вологодская область, Вологда, Гагарина, 46	f	large
35378	29014	377	Вологодская область, Вологда, Гагарина, 46	f	large
35365	29010	364	Вологодская область, Вологда, Гагарина, 40	f	large
35364	29010	363	Вологодская область, Вологда, Гагарина, 40	f	large
35363	29010	362	Вологодская область, Вологда, Гагарина, 40	f	large
35370	29013	369	Вологодская область, Вологда, Вологодская, 6а	f	large
35369	29013	368	Вологодская область, Вологда, Вологодская, 6а	f	large
35368	29013	367	Вологодская область, Вологда, Вологодская, 6а	f	large
35373	29015	372	Вологодская область, Вологда, Возрождения, 1	f	large
35372	29015	371	Вологодская область, Вологда, Возрождения, 1	f	large
35311	28969	310	Вологодская область, Вологда, Болонина, 32	f	large
35306	28969	305	Вологодская область, Вологда, Болонина, 32	f	large
35294	28959	293	Вологодская область, Вологда, Болонина, 25	f	large
35352	29001	351	Вологодская область, Вологда, Батюшкова, 4	f	medium
35307	28968	306	Вологодская область, Вологда, Архангельская, 11Б	f	large
35305	28968	304	Вологодская область, Вологда, Архангельская, 11Б	f	large
35308	28968	307	Вологодская область, Вологда, Архангельская, 11Б	f	large
35367	29012	366	Вологодская область, Вологда, Ананьинская, 45	f	large
35366	29011	365	Вологодская область, Вологда, Александра Клубова, 56	f	small
35335	28989	334	Вологодская область, Вологда, 6 Армии набережная, 199	f	large
35337	28991	336	Вологодская область, Вологда, Горького, 107	f	large
35320	28976	319	Вологодская область, Вологда, Горького, 57	f	large
35321	28976	320	Вологодская область, Вологда, Горького, 57	f	large
35031	28703	8	Вологодская область, Бабаево, Мира, 1	f	large
36044	29648	1063	Вологодская область, Шекснинский район, село Юрочкино, Школьная, 11	f	small
36033	29638	1052	Вологодская область, Шекснинский район, село Шигоево, 20	f	small
36018	29625	1037	Вологодская область, Шекснинский район, поселок Шексна 2-я, Юбилейная, 10	f	large
36019	29626	1038	Вологодская область, Шекснинский район, поселок Шексна, Шлюзовая, 20	f	large
36017	29624	1036	Вологодская область, Шекснинский район, поселок Шексна, Труда, 16	f	large
36015	29622	1034	Вологодская область, Шекснинский район, поселок Шексна, Октябрьская, 54	f	large
36016	29623	1035	Вологодская область, Шекснинский район, поселок Шексна, Зеленая, 15	f	medium
134700	29620	1032	Вологодская область, Шекснинский район, поселок Шексна, Дзержинского, 6	f	medium
36014	29621	1033	Вологодская область, Шекснинский район, Шексна, Гагарина, 16	f	large
36037	29642	1056	Вологодская область, Шекснинский район, село Чуровское, 17	f	medium
36041	29365	1060	Вологодская область, Шекснинский район, село Чернеево, 2	f	small
36020	29627	1039	Вологодская область, Шекснинский район, село Чебсара, Ленина, 4	f	large
36034	29639	1053	Вологодская область, Шекснинский район, село Чаромское, Шоссейная, 14	f	small
36046	29650	1065	Вологодская область, Шекснинский район, село Фоминское, 2	f	small
36031	29636	1050	Вологодская область, Шекснинский район, село Сыромяткино, 4	t	small
36039	29644	1058	Вологодская область, Шекснинский район, село Слизово, 21а	f	small
36030	29635	1049	Вологодская область, Шекснинский район, Сизьма, Ветеранов, 12а	f	small
36029	29634	1048	Вологодская область, Шекснинский район, село Раменье, 37	f	small
36021	29628	1040	Вологодская область, Шекснинский район, село Прогресс, Центральная, 54	f	medium
36023	29630	1042	Вологодская область, Шекснинский район, село Пача, Центральная, 28	f	small
36022	29629	1041	Вологодская область, Шекснинский район, село Нифантово, Нифантовская, 1а	f	large
36040	29610	1059	Вологодская область, Шекснинский район, село Нестерово, Нестерово, 3	f	small
36035	29640	1054	Вологодская область, Шекснинский район, село Медвежье, 18а	f	small
36038	29643	1057	Вологодская область, Шекснинский район, село Малинуха, 65	f	small
36042	29646	1061	Вологодская область, Шекснинский район, село Любомирово, Школьная, 11	f	large
36032	29637	1051	Вологодская область, Шекснинский район, село Княже, Зеленая, 2	f	small
36036	29641	1055	Вологодская область, Шекснинский район, село Квасюнино, 11	t	small
36028	29633	1047	Вологодская область, Шекснинский район, село Камешник, 9	f	small
36027	29632	1046	Вологодская область, Шекснинский район, село Игнатовское	t	small
36026	29602	1045	Вологодская область, Шекснинский район, село Ершово, 79	f	small
36024	29574	1043	Вологодская область, Шекснинский район, село Добрец, 61	t	small
36025	29584	1044	Вологодская область, Шекснинский район, село Демидово, 80	t	small
36043	29647	1062	Вологодская область, Шекснинский район, село Братково, Центральная, 8	f	small
36045	29649	1064	Вологодская область, Шекснинский район, Большое Ивановское, Сосновая, 4	f	large
35895	29522	914	Вологодская область, Череповецкий район, село Ягница, Журавлевская, 23	f	small
35894	29521	913	Вологодская область, Череповецкий район, село Яганово, Центральная, 15	f	medium
35892	29519	911	Вологодская область, Череповецкий район, село Щетинское, Рыбинская, 83	f	small
35853	29484	870	Вологодская область, Череповецкий район, село Шухободь, Центральная, 6	f	large
35874	29501	893	Вологодская область, Череповецкий район, село Шулма, Центральная, 15	f	large
35871	29498	890	Вологодская область, Череповецкий район, село Шишовка, 66	f	small
35891	29518	910	Вологодская область, Череповецкий район, село Шалимово, Молодежная, 2 а	f	small
35863	29490	882	Вологодская область, Череповецкий район, село Шайма, клуб воинской части	f	small
35867	29494	886	Вологодская область, Череповецкий район, село Чаево, Центральная, 5	f	small
35878	29505	897	Вологодская область, Череповецкий район, село Харламовская, 94	t	small
35857	29421	875	Вологодская область, Череповецкий район, село Улазорский, 13	t	small
35888	29515	907	Вологодская область, Череповецкий район, село Тоншалово, Труда, 3	f	large
35889	29516	908	Вологодская область, Череповецкий район, село Тоншалово, Рабочая, 14-а	f	large
35885	29512	904	Вологодская область, Череповецкий район, село Сурково, Центральная, 75	f	small
35880	29507	899	Вологодская область, Череповецкий район, поселок Суда, Пушкина, 6	f	large
35881	29508	900	Вологодская область, Череповецкий район, поселок Суда, Заводская, 4	f	large
35879	29506	898	Вологодская область, Череповецкий район, поселок Суда, Гагарина, 35	f	large
35855	29486	872	Вологодская область, Череповецкий район, село Романово, Центральная, 16	f	small
35860	29475	878	Вологодская область, Череповецкий район, село Починок, Новая, 7а	f	small
35856	29411	874	Вологодская область, Череповецкий район, село Поповка, Центральная, 5	f	small
35866	29493	885	Вологодская область, Череповецкий район, Песье, Березовая, 34	f	small
35858	29432	876	Вологодская область, Череповецкий район, село Новое Домозерово, 48	f	medium
35877	29504	896	Вологодская область, Череповецкий район, село Николо-Раменье, 15	f	small
35875	29502	894	Вологодская область, Череповецкий район, село Нелазское, Центральная, 1	f	small
35873	29500	892	Вологодская область, Череповецкий район, село Мякса, Советская, 37, 162646 , МУ Мяксинское СКО- Мяксинский ДК.	f	\N
35872	29499	891	Вологодская область, Череповецкий район, село Мякса, Советская, 37	f	large
35893	29520	912	Вологодская область, Череповецкий район, село Музга, Школьная, 14	f	small
35868	29495	887	Вологодская область, Череповецкий район, поселок Малечкино, Дом культуры	f	large
35865	29492	884	Вологодская область, Череповецкий район, село Коротово, Ленина, 12	f	large
35864	29491	883	Вологодская область, Череповецкий район, село Климовское, 21	f	large
35862	29489	881	Вологодская область, Череповецкий район, Ирдоматка, Новая, 10	f	large
35861	29488	880	Вологодская область, Череповецкий район, село Ивановское, Весенняя, 1	f	small
35859	29454	877	Вологодская область, Череповецкий район, село Городище, Лесная, 23	t	small
35886	29513	905	Вологодская область, Череповецкий район, село Горка-Заречье, Старая Горка, 2	t	small
35869	29496	888	Вологодская область, Череповецкий район, Воскресенское, 173, школа	f	small
35854	29485	871	Вологодская область, Череповецкий район, село Воскресенское, Советская, 38	f	large
35899	29525	918	Вологодская область, Череповецкий район, село Ботово, Ленина, 15	f	large
35896	29523	915	Вологодская область, Череповецкий район, село Борок, 44	t	small
35898	29524	917	Вологодская область, Череповецкий район, село Большой Двор, Центральная, 5	f	small
35883	29510	902	Вологодская область, Череповецкий район, село Большое Ново, Большеновская, 25	f	small
35887	29514	906	Вологодская область, Череповецкий район, село Батран, 31	f	small
35876	29503	895	Вологодская область, Череповецкий район, поселок Андогский, Бумажников, 13	f	small
35870	29497	889	Вологодская область, Череповецкий район, село Аксеново, 19	f	small
35852	29483	869	Вологодская область, Череповецкий район, село Абаканово, Школьная, 11	f	medium
35838	29468	855	Вологодская область, Чагодощенский район, село Чагода, Школьная, 15А	f	medium
35837	29468	854	Вологодская область, Чагодощенский район, село Чагода, Школьная, 15А	f	medium
35840	29470	857	Вологодская область, Чагодощенский район, село Чагода, Воззвания, 21А	f	medium
35839	29469	856	Вологодская область, Чагодощенский район, поселок Чагода, Центральная, 9	f	medium
35836	29467	853	Вологодская область, Чагодощенский район, поселок Чагода, Кирова, 5	f	medium
35835	29466	852	Вологодская область, Чагодощенский район, поселок Чагода, Кирова, 5А	f	medium
35834	29464	851	Вологодская область, Чагодощенский район, поселок Чагода, Кирова, 7	f	medium
35841	29471	858	Вологодская область, Чагодощенский район, поселок Чагода, Высоцкого, 73	f	medium
35851	29482	868	Вологодская область, Чагодощенский район, село Смердомский, Центральная, 14	f	medium
35842	29472	859	Вологодская область, Чагодощенский район, поселок Сазоново, Строителей, 5	f	medium
35844	29474	861	Вологодская область, Чагодощенский район, поселок Сазоново, Советская, 14	f	medium
35843	29473	860	Вологодская область, Чагодощенский район, поселок Сазоново, Советская, 47	f	medium
36048	29651	1067	Вологодская область, Чагодощенский район, село Покровское, Центральная, 4А	f	small
35850	29481	867	Вологодская область, Чагодощенский район, село Первомайский, Центральная, 1	f	small
35849	29480	866	Вологодская область, Чагодощенский район, село Мегрино, Северная, 6	f	small
35847	29478	864	Вологодская область, Чагодощенский район, село Избоищи, Набережная, 1	f	small
35846	29477	863	Вологодская область, Чагодощенский район, село Борисово, Спортивная, 2	f	small
35845	29476	862	Вологодская область, Чагодощенский район, село Белые Кресты, Кооперативная, 23А	f	medium
35848	29479	865	Вологодская область, Чагодощенский район, село Анишино, Мира, 7	f	small
35833	29463	850	Вологодская область, Харовский район, село Шапша, Центральная, 14	f	small
35812	29441	827	Вологодская область, Харовский район, Харовск, Энергетиков, 11	f	large
35816	29445	831	Вологодская область, Харовский район, Харовск, Школьная, 7	f	large
35813	29442	828	Вологодская область, Харовский район, Харовск, Свободы, 5	f	large
35817	29446	832	Вологодская область, Харовский район, Харовск, Клубная, 18	f	large
35822	29451	838	Вологодская область, Харовский район, село Сорожино, 34, Центр досуга	f	small
35831	29461	848	Вологодская область, Харовский район, поселок Ситинский, Мира, 12	f	small
35828	29458	845	Вологодская область, Харовский район, поселок Семигородняя, Спортивная, 25	f	small
35827	29457	843	Вологодская область, Харовский район, поселок Семигородняя, Комсомольская, 4	f	large
35819	29448	835	Вологодская область, Харовский район, село Семениха, 22, Дом культуры	f	small
35818	29447	833	Вологодская область, Харовский район, село Поповка, 70, библиотека	f	small
35832	29462	849	Вологодская область, Харовский район, Погост Никольский, Центральная, 4	f	small
35826	29456	842	Вологодская область, Харовский район, село Никулинское, 12, администрация Разинского сельского поселения	f	small
35821	29450	837	Вологодская область, Харовский район, село Нижнекубенский, Торговая, 7	f	small
35824	29453	840	Вологодская область, Харовский район, село Михайловское, Советская, 5	f	small
35823	29452	839	Вологодская область, Харовский район, село Кумзеро, 5, администрация Кумзерского сельского поселения	f	small
35820	29449	836	Вологодская область, Харовский район, село Золотава, 21, Дом культуры	f	small
35825	29455	841	Вологодская область, Харовский район, село Гора, 68, Дом культуры	f	small
35830	29460	847	Вологодская область, Харовский район, село Бараниха, Лесная, 11	f	small
35829	29459	846	Вологодская область, Харовский район, село Арзубиха, 100, администрация Слободского сельского поселения	f	small
35790	29417	804	Вологодская область, Устюженский район, Ярцево, 2	f	small
35811	29440	826	Вологодская область, Устюженский район, село Яковлевское, Центральная, 3	f	small
35787	29414	801	Вологодская область, Устюженский район, Устюжна, Терешковой, 50	f	medium
35786	29414	800	Вологодская область, Устюженский район, Устюжна, Терешковой, 50	f	large
35784	29412	798	Вологодская область, Устюженский район, Устюжна, Терешковой, 6-А	f	large
35809	29438	824	Вологодская область, Устюженский район, Устюжна, Пролетарская, 13	f	small
35788	29415	802	Вологодская область, Устюженский район, Устюжна, Набережная Декабристов, 42	f	medium
35780	29407	794	Вологодская область, Устюженский район, Устюжна, Ленина, 50	f	large
134698	29413	799	Вологодская область, Устюженский район, Устюжна, Карла Маркса, 53	f	small
35783	29410	797	Вологодская область, Устюженский район, Устюжна, Карла Маркса, 14	f	small
35782	29409	796	Вологодская область, Устюженский район, Устюжна, Интернациональная, 4	f	medium
35791	29418	805	Вологодская область, Устюженский район, село Степачево, Центральная, 19А	f	small
35800	29428	815	Вологодская область, Устюженский район, село Спасское, Центральная, 23	f	small
35804	29433	819	Вологодская область, Устюженский район, село Соболево, Центральная, 28	f	small
35797	29425	812	Вологодская область, Устюженский район, село Слуды, Школьная, 2	f	small
35805	29434	820	Вологодская область, Устюженский район, село Славынево, Центральная, 66	f	small
35803	29431	818	Вологодская область, Устюженский район, село Расторопово, Школьная, 4	f	small
35807	29436	822	Вологодская область, Устюженский район, село Оснополье, Центральная, 3	f	small
35802	29430	817	Вологодская область, Устюженский район, село Никола, Корелякова, 103	f	medium
35796	29424	811	Вологодская область, Устюженский район, село Модно, Центральная, 15	f	small
35794	29422	809	Вологодская область, Устюженский район, село Мережа, Школьная, 8-А	f	small
35801	29429	816	Вологодская область, Устюженский район, Мелечино, Административный, 1	f	small
35789	29416	803	Вологодская область, Устюженский район, село Малое Восное, 57	f	small
35792	29419	807	Вологодская область, Устюженский район, село Лентьево, Советская, 26	f	small
35806	29435	821	Вологодская область, Устюженский район, поселок Имени Желябова, Советская, 12	f	medium
35795	29423	810	Вологодская область, Устюженский район, село Долоцкое, Южный, 4	f	medium
35799	29427	814	Вологодская область, Устюженский район, село Даниловское, Центральная, 14-А	f	small
35798	29426	813	Вологодская область, Устюженский район, село Веницы, Школьная, 5	f	small
35793	29420	808	Вологодская область, Устюженский район, село Ванское, Центральная, 52	f	small
35810	29439	825	Вологодская область, Устюженский район, село Брилино, Центральная, 4	f	small
35766	29393	780	Вологодская область, Усть-Кубинский район, поселок Устье, Профсоюзная, 6	f	large
35768	29395	782	Вологодская область, Усть-Кубинский район, поселок Устье, Первомайская, 16	f	small
35767	29394	781	Вологодская область, Усть-Кубинский район, поселок Устье, Октябрьская, 19	f	large
35779	29406	793	Вологодская область, Усть-Кубинский район, Порохово, Полевая, 15	f	small
35774	29401	788	Вологодская область, Усть-Кубинский район, село Никольское, Садовая, 15	f	small
35778	29405	792	Вологодская область, Усть-Кубинский район, Никола-Корень, Курлаково, 4	f	small
35771	29398	785	Вологодская область, Усть-Кубинский район, село Никифоровская, Никольская, 5	f	small
35773	29400	787	Вологодская область, Усть-Кубинский район, село Митенское	f	small
35769	29396	783	Вологодская область, Усть-Кубинский район, село Марковская, Центральная, 15	f	small
35775	29402	789	Вологодская область, Усть-Кубинский район, село Королиха, Центральная, 8	f	small
35772	29399	786	Вологодская область, Усть-Кубинский район, село Заднее, Яковлева, 14	f	small
35777	29404	791	Вологодская область, Усть-Кубинский район, поселок Высокое, Нагорная, 23	f	small
35770	29397	784	Вологодская область, Усть-Кубинский район, село Богородское, Парковая, 8	f	small
35776	29403	790	Вологодская область, Усть-Кубинский район, Бережное, Совхозная, 6	f	medium
35753	29380	767	Вологодская область, Тотемский район, поселок Юбилейный, Школьная, 4	f	large
35741	29368	754	Вологодская область, Тотемский район, село Чуриловка, 82	f	small
35746	29373	760	Вологодская область, Тотемский район, село Устье, 63	f	small
35744	29371	758	Вологодская область, Тотемский район, поселок Усть-Царева, 31	f	medium
35763	29390	777	Вологодская область, Тотемский район, село Успенье, Центральная, 11	f	small
35735	29361	748	Вологодская область, Тотемский район, Тотьма, Осипенко, 5	f	medium
35738	29364	751	Вологодская область, Тотемский район, Тотьма, Набережная им. Кускова, 14	f	large
35736	29362	749	Вологодская область, Тотемский район, Тотьма, Ленина, 61	f	large
35734	29360	747	Вологодская область, Тотемский район, Тотьма, Ленина, 21	f	medium
35739	29366	752	Вологодская область, Тотемский район, Тотьма, Загородная, 99б	f	large
35737	29363	750	Вологодская область, Тотемский район, Тотьма, Загородная, 66	f	large
35733	29359	746	Вологодская область, Тотемский район, Тотьма, Володарского, 5	f	large
35760	29387	774	Вологодская область, Тотемский район, поселок Текстильщики, Энергетиков, 2а	f	large
35755	29382	769	Вологодская область, Тотемский район, село Советский, Октябрьская, 6	f	large
35752	29379	766	Вологодская область, Тотемский район, село Середская, 39	f	small
35754	29381	768	Вологодская область, Тотемский район, село Погорелово, Мира, 21	f	large
35759	29386	773	Вологодская область, Тотемский район, село Октябрьский, Механизаторов, 5	f	small
35764	29391	778	Вологодская область, Тотемский район, село Никольское, Рубцова, 30	f	small
35750	29377	764	Вологодская область, Тотемский район, село Мосеево, 17	f	small
35749	29376	763	Вологодская область, Тотемский район, поселок Михайловка, 68	f	small
35748	29375	762	Вологодская область, Тотемский район, село Медведево, 58	f	small
35758	29385	772	Вологодская область, Тотемский район, село Матвеево, Садовая, 9	f	small
35742	29369	756	Вологодская область, Тотемский район, село Кудринская, 36	f	small
35743	29370	757	Вологодская область, Тотемский район, село Крутая Осыпь, 46	f	small
35745	29372	759	Вологодская область, Тотемский район, село Красный Бор, Пролетарская, 1а	f	small
35762	29389	776	Вологодская область, Тотемский район, поселок Карица, Пролетарская, 3	f	small
35747	29374	761	Вологодская область, Тотемский район, поселок Камчуга, Школьная, 29	f	medium
35756	29383	770	Вологодская область, Тотемский район, село Задняя, Школьная, 6	f	medium
35751	29378	765	Вологодская область, Тотемский район, село Данилов Починок, 81	f	small
35740	29367	753	Вологодская область, Тотемский район, село Великий Двор, 46	f	small
35765	29392	779	Вологодская область, Тотемский район, село Бор, Центральная, 24	f	small
35715	29342	728	Вологодская область, Тарногский район, село Шебенгский Погост, Центральная, 5	f	small
35727	29353	740	Вологодская область, Тарногский район, село Тюприха, 28	f	small
35710	29337	723	Вологодская область, Тарногский район, село Тарногский Городок, Советская, 30	f	large
35709	29336	722	Вологодская область, Тарногский район, село Тарногский Городок, Советская, 41	f	large
35711	29338	724	Вологодская область, Тарногский район, село Слуда, Центральная, 1	f	small
35730	29356	743	Вологодская область, Тарногский район, село Сергиевская, 22а	f	small
35726	29351	739	Вологодская область, Тарногский район, село Ромашевский Погост, Молодежная, 2	f	small
35729	29355	742	Вологодская область, Тарногский район, село Раменье, 2а, сельский клуб	f	small
35757	29384	771	Вологодская область, Тарногский район, село Пятовская, Центральная, 4	f	medium
35720	29346	733	Вологодская область, Тарногский район, село Никифоровская, 25	f	small
35718	29344	731	Вологодская область, Тарногский район, село Нижнепаунинская, 2	f	small
35725	29350	738	Вологодская область, Тарногский район, село Красное, Красная, 12	f	medium
35732	29358	745	Вологодская область, Тарногский район, село Конторка, 17	f	small
35724	29349	737	Вологодская область, Тарногский район, село Каплинская	t	small
35722	29347	735	Вологодская область, Тарногский район, село Ильинская, 14	f	small
35731	29357	744	Вологодская область, Тарногский район, село Илезский Погост, 20	f	medium
35717	29343	730	Вологодская область, Тарногский район, село Игумновская, Центральная, 52	f	small
35728	29354	741	Вологодская область, Тарногский район, село Заречье, 60	f	small
35713	29340	726	Вологодская область, Тарногский район, село Евсеевская, 22	f	small
35719	29345	732	Вологодская область, Тарногский район, село Вощар, 1, дом культуры	f	small
35723	29348	736	Вологодская область, Тарногский район, Верховский Погост, 4	f	medium
35714	29341	727	Вологодская область, Тарногский район, село Верхнекокшенгский Погост, 10	f	small
35712	29339	725	Вологодская область, Тарногский район, село Афанасьевская, 31	f	small
35706	29333	719	Вологодская область, Сямженский район, село Шокша, Центральная, 16	f	small
35700	29328	713	Вологодская область, Сямженский район, село Ширега, 60	f	small
35691	29319	703	Вологодская область, Сямженский район, село Филинская, Центральная, 20	f	small
35707	29334	720	Вологодская область, Сямженский район, село Усть-Река, Центральная, 20	f	small
35703	29330	716	Вологодская область, Сямженский район, село Сямжа, Советская, 10	f	medium
35704	29331	717	Вологодская область, Сямженский район, село Сямжа, Славянская, 1	f	large
35705	29332	718	Вологодская область, Сямженский район, село Сямжа, Парковая, 4	f	large
35692	29320	704	Вологодская область, Сямженский район, село Согорки, Школьная, 7	f	small
35688	29316	700	Вологодская область, Сямженский район, село Самсоновская, 5	f	small
35699	29327	712	Вологодская область, Сямженский район, Раменье, Молодежная, 19	f	small
35697	29325	710	Вологодская область, Сямженский район, село Пигилинская, 17	f	small
35696	29324	709	Вологодская область, Сямженский район, село Ногинская, Поспелова, 3	f	medium
35689	29317	701	Вологодская область, Сямженский район, село Мирный, Подлесная, 3	f	small
35695	29323	708	Вологодская область, Сямженский район, село Коростелево, 34	f	small
35701	29329	714	Вологодская область, Сямженский район, село Копылово, Центральная, 17, Режская школа	f	small
35708	29335	721	Вологодская область, Сямженский район, село Истоминская, Истоминская, 2	f	small
35690	29318	702	Вологодская область, Сямженский район, село Житьево, Зелёная, 13	f	small
35698	29326	711	Вологодская область, Сямженский район, село Гремячий, Набережная, 4	f	medium
35761	29388	775	Вологодская область, Сямженский район, село Гремячий, Мира, 29	f	small
35693	29321	705	Вологодская область, Сямженский район, село Голузино, 7	f	small
35694	29322	706	Вологодская область, Сямженский район, село Георгиевская, Школьная, 5	f	small
35677	29305	688	Вологодская область, Сокольский район, село Щера, 55	f	small
35685	29313	696	Вологодская область, Сокольский район, село Чучково, Сельская, 1	f	small
35682	29310	693	Вологодская область, Сокольский район, село Чекшино, Молодежная, 10	f	medium
35646	29275	655	Вологодская область, Сокольский район, Сокол, Школьная, 5	f	large
35667	29295	678	Вологодская область, Сокольский район, Сокол, Шатенево, 43а	f	large
35657	29285	667	Вологодская область, Сокольский район, Сокол, Советская, 115	f	large
35656	29284	666	Вологодская область, Сокольский район, Сокол, Советская, 106	f	large
35655	29283	665	Вологодская область, Сокольский район, Сокол, Советская, 86	f	large
35654	29282	664	Вологодская область, Сокольский район, Сокол, Советская, 83	f	large
35653	29281	663	Вологодская область, Сокольский район, Сокол, Советская, 52	f	large
35652	29281	662	Вологодская область, Сокольский район, Сокол, Советская, 52	f	large
35651	29280	661	Вологодская область, Сокольский район, Сокол, Советская, 55а	f	large
35649	29278	659	Вологодская область, Сокольский район, Сокол, Советская, 30	f	large
35647	29276	657	Вологодская область, Сокольский район, Сокол, Советская, 16	f	medium
35663	29291	673	Вологодская область, Сокольский район, Сокол, Призводственная, 16	f	large
35660	29288	670	Вологодская область, Сокольский район, Сокол, Первая Глушицкая, 31	f	medium
35662	29290	672	Вологодская область, Сокольский район, Сокол, Мусинского, 4	f	large
35661	29289	671	Вологодская область, Сокольский район, Сокол, Менделеева, 37а	f	large
35664	29292	674	Вологодская область, Сокольский район, Сокол, Колхозная, 14а	f	large
35650	29279	660	Вологодская область, Сокольский район, Сокол, Кирова, 19	f	large
35666	29294	677	Вологодская область, Сокольский район, Сокол, Калинина, 21	f	large
35659	29287	669	Вологодская область, Сокольский район, Сокол, Беднякова, 33	f	medium
35679	29307	690	Вологодская область, Сокольский район, село Оларево, 21	f	small
35684	29312	695	Вологодская область, Сокольский район, село Огарово, 24	f	small
35676	29304	687	Вологодская область, Сокольский район, село Обросово, 65	f	medium
35673	29301	684	Вологодская область, Сокольский район, село Нестерово, 16	f	small
35675	29303	686	Вологодская область, Сокольский район, село Морженга, Центральная, 8	t	small
35680	29308	691	Вологодская область, Сокольский район, село Марковское, Центральная, 11	f	small
35678	29306	689	Вологодская область, Сокольский район, село Литега, 14	f	large
35668	29296	679	Вологодская область, Сокольский район, Кадников, Розы Люксембург, 58	f	large
35669	29297	680	Вологодская область, Сокольский район, Кадников, Р.Люксембург, 34	f	large
35670	29298	681	Вологодская область, Сокольский район, Кадников, Парковая, 8	f	medium
35681	29309	692	Вологодская область, Сокольский район, село Замошье, Школьная, 5	f	small
35683	29311	694	Вологодская область, Сокольский район, село Воробьево, Центральная, 2	f	medium
35674	29302	685	Вологодская область, Сокольский район, село Великий Двор, Центральная, 46	f	small
35672	29300	683	Вологодская область, Сокольский район, село Василево, 12	f	small
35686	29314	697	Вологодская область, Сокольский район, село Биряково, Н.Рубцова, 6	f	medium
35671	29299	682	Вологодская область, Сокольский район, село Архангельское, 43	f	small
35630	29259	639	Вологодская область, Нюксенский район, село Юшково, 28	f	small
35625	29255	634	Вологодская область, Нюксенский район, Пустыня, 17	f	small
35632	29261	641	Вологодская область, Нюксенский район, село Пески, 43	f	small
35637	29266	646	Вологодская область, Нюксенский район, село Озерки, Набережная, 45	f	small
35642	29271	651	Вологодская область, Нюксенский район, село Нюксеница, Юбилейная, 14-а, клуб газовиков	f	large
35640	29269	649	Вологодская область, Нюксенский район, село Нюксеница, Школьная, 1	f	medium
35638	29267	647	Вологодская область, Нюксенский район, село Нюксеница, Советская, 14	f	medium
35639	29268	648	Вологодская область, Нюксенский район, село Нюксеница, Первомайская, 13 А	f	small
35641	29270	650	Вологодская область, Нюксенский район, село Нюксеница, Культуры, 2	f	medium
35631	29260	640	Вологодская область, Нюксенский район, село Матвеевская, 43	f	small
35635	29264	644	Вологодская область, Нюксенский район, поселок Матвеево, Школьная, 6	f	small
35645	29274	654	Вологодская область, Нюксенский район, село Лесютино, Лесная, 1	f	small
35624	29254	633	Вологодская область, Нюксенский район, село Леваш, Школьная, 5	f	small
35636	29265	645	Вологодская область, Нюксенский район, село Красавино, Культуры, 8	f	small
35623	29253	632	Вологодская область, Нюксенский район, село Копылово, Молодежная, 18	f	small
35633	29262	642	Вологодская область, Нюксенский район, поселок Игмас, Октябрьская, 31	f	medium
35627	29257	636	Вологодская область, Нюксенский район, село Городищна, Школьная, 7	f	medium
35628	29258	637	Вологодская область, Нюксенский район, Городищна, Октябрьская, 26	f	small
35622	29252	631	Вологодская область, Нюксенский район, село Вострое, Полевая, 3	f	small
35626	29256	635	Вологодская область, Нюксенский район, село Брусноволовский Погост, Школьная, 8	f	small
35634	29263	643	Вологодская область, Нюксенский район, село Бобровское, Болотная, 12	f	small
35643	29272	652	Вологодская область, Нюксенский район, село Березово, Луговая, 17	f	small
35644	29273	653	Вологодская область, Нюксенский район, село Березовая Слободка, Полевая, 5	f	small
35608	29238	617	Вологодская область, Никольский район, село Шарженга	f	small
35610	29240	619	Вологодская область, Никольский район, Филинский починок, 54	f	small
35597	29228	606	Вологодская область, Никольский район, село Старина, 40	t	small
35614	29244	623	Вологодская область, Никольский район, село Скочково, Центральная, 9А	t	small
35602	29233	611	Вологодская область, Никольский район, село Рокуново, 62	t	small
35612	29242	621	Вологодская область, Никольский район, село Путилово, 48	t	small
35595	29226	604	Вологодская область, Никольский район, село Половина, 28	f	small
35618	29248	627	Вологодская область, Никольский район, село Полежаево, 48	f	small
35615	29245	624	Вологодская область, Никольский район, село Пермас, 51	f	small
35613	29243	622	Вологодская область, Никольский район, село Осиново, Городской край, 17А	f	medium
35611	29241	620	Вологодская область, Никольский район, село Никольское, 50-летия Победы, 14А	f	small
35584	29215	593	Вологодская область, Никольский район, Никольск, маршала Конева, 133В	f	large
36047	29214	1066	Вологодская область, Никольский район, Никольск, Советская, 161	f	small
35583	29214	592	Вологодская область, Никольский район, Никольск, Советская, 161	f	large
35586	29217	595	Вологодская область, Никольский район, Никольск, Кузнецова, 46	f	large
35605	29217	614	Вологодская область, Никольский район, Никольск, Кузнецова, 46	f	medium
134697	29212	590	Вологодская область, Никольский район, Никольск, Володарского, 10 , ЦРБ	f	large
35585	29216	594	Вологодская область, Никольский район, Никольск, Беляева, 53	f	medium
35587	29218	596	Вологодская область, Никольский район, Никольск, Энергетиков, 21	f	small
35609	29239	618	Вологодская область, Никольский район, село Нигино, Школьная, 11	f	small
35619	29249	628	Вологодская область, Никольский район, поселок Молодежный, 42, кв. 2	f	small
35226	28898	212	Вологодская область, Никольский район, поселок Молодежный, 4 А, Сельский клуб Молодежный филиал МБУК ВР КДО	f	small
35607	29237	616	Вологодская область, Никольский район, село Милофаново, 65	f	small
35616	29246	625	Вологодская область, Никольский район, село Куданский, 162	f	small
35592	29223	601	Вологодская область, Никольский район, село Кривяцкое, 4А	f	small
35594	29225	603	Вологодская область, Никольский район, село Котельное, 57	f	small
35603	29234	612	Вологодская область, Никольский район, село Кожаево, Школьная, 1	f	medium
35620	29250	629	Вологодская область, Никольский район, Кипшеньга, 60	f	medium
35621	29251	630	Вологодская область, Никольский район, село Калинино, 86	f	small
35589	29220	598	Вологодская область, Никольский район, село Ильинское, 103	f	small
35601	29232	610	Вологодская область, Никольский район, село Зеленцово, 139, здание администрации Зеленцовского сельского поселения	f	medium
35591	29222	600	Вологодская область, Никольский район, село Займище, 1	f	small
35598	29229	607	Вологодская область, Никольский район, село Завражье, Молодежная, 16	f	small
35600	29231	609	Вологодская область, Никольский район, поселок Дуниловский, Центральная, 4Б	f	medium
35599	29230	608	Вологодская область, Никольский район, поселок Высокинский, Центральная, 6А	f	small
35593	29224	602	Вологодская область, Никольский район, село Вахнево, 31	f	medium
35606	29236	615	Вологодская область, Никольский район, село Бутова Курья, 79	f	small
35596	29227	605	Вологодская область, Никольский район, село Борок, Советская, 21	f	large
35617	29247	626	Вологодская область, Никольский район, село Большое Сверчково, 17	f	small
35590	29221	599	Вологодская область, Никольский район, Байдарово, 2	f	small
35588	29219	597	Вологодская область, Никольский район, село Аргуново, Березовая, 27	f	medium
35604	29235	613	Вологодская область, Никольский район, Абатурово, 64А	f	medium
35576	29171	585	Вологодская область, Междуреченский район, село Шуйское, Советская, 12	f	medium
35539	29171	548	Вологодская область, Междуреченский район, село Шуйское, Советская, 12	f	large
35575	29208	584	Вологодская область, Междуреченский район, село Шиченга, Первомайская, 20	f	small
35580	29211	589	Вологодская область, Междуреченский район, село Шейбухта, Шейбухтовская, 1	f	small
35578	29210	587	Вологодская область, Междуреченский район, село Туровец, Комсомольская, 83	f	medium
35574	29207	583	Вологодская область, Междуреченский район, село Старое, Кооперативная, 4	f	medium
35573	29206	582	Вологодская область, Междуреченский район, село Спас-Ямщики, Новая, 8	f	small
35577	29209	586	Вологодская область, Междуреченский район, село Пионерский, Свободы, 1, начальная школа	f	small
35571	29204	580	Вологодская область, Междуреченский район, село Игумницево, Юбилейная, 10	f	small
35210	28882	196	Вологодская область, Междуреченский район, село Иваньково, 6, администрация сельского поселения Бекетовское	f	small
35579	29199	588	Вологодская область, Междуреченский район, село Гаврилково, Центральная, 6, дом культуры	f	small
35572	29205	581	Вологодская область, Междуреченский район, село Врагово, Октябрьская, 2	f	small
35570	29203	579	Вологодская область, Кичменгско-Городецкий район, село Югский, Центральная, 17	f	medium
35569	29202	578	Вологодская область, Кичменгско-Городецкий район, село Шонга, 10	f	medium
35568	29201	577	Вологодская область, Кичменгско-Городецкий район, село Шатенево, Центральная, 1	f	small
35545	29177	554	Вологодская область, Кичменгско-Городецкий район, село Торопово, 45	f	medium
28850	18326	390	Архангельская область, Котлас, Маяковского, 31	f	large
35550	29182	559	Вологодская область, Кичменгско-Городецкий район, село Слободка, 12	f	small
35556	29188	565	Вологодская область, Кичменгско-Городецкий район, село Слобода, 21, сельский клуб	f	small
35565	29197	574	Вологодская область, Кичменгско-Городецкий район, село Светица, 4	f	small
35564	29196	573	Вологодская область, Кичменгско-Городецкий район, село Сараево, 25	f	small
35546	29178	555	Вологодская область, Кичменгско-Городецкий район, село Подол, 40	f	small
35566	29198	575	Вологодская область, Кичменгско-Городецкий район, село Подволочье, Спортивная, 1	f	small
35549	29181	558	Вологодская область, Кичменгско-Городецкий район, село Олятово, 26	f	small
35552	29184	561	Вологодская область, Кичменгско-Городецкий район, село Нижняя Ентала, 40	f	small
35551	29183	560	Вологодская область, Кичменгско-Городецкий район, село Нижний Енангск, Центральная, 39	f	medium
35555	29187	564	Вологодская область, Кичменгско-Городецкий район, поселок Лаптюг, 60 А	f	small
35558	29190	567	Вологодская область, Кичменгско-Городецкий район, село Курилово, 33	f	small
35560	29192	569	Вологодская область, Кичменгско-Городецкий район, село Косково, Почтовая, 13, сельский клуб	f	medium
35222	28894	208	Вологодская область, Кичменгско-Городецкий район, село Коряковская, 1, Тавенгская начальная школа	f	small
35561	29193	570	Вологодская область, Кичменгско-Городецкий район, село Кобыльск, Центральная, 9	f	small
35547	29179	556	Вологодская область, Кичменгско-Городецкий район, село Кичменьга, 23	f	small
35542	29174	551	Вологодская область, Кичменгско-Городецкий район, село Кичменский Городок, Центральная, 8	f	large
35541	29173	550	Вологодская область, Кичменгско-Городецкий район, село Кичменский Городок, Лесная, 13	f	medium
35567	29200	576	Вологодская область, Кичменгско-Городецкий район, село Кильченга, Советская, 109, администрация	f	small
35563	29195	572	Вологодская область, Кичменгско-Городецкий район, село Исады, 15/2, ФАП	f	small
35559	29191	568	Вологодская область, Кичменгско-Городецкий район, село Еловино, Центральная, 14	f	small
35554	29186	563	Вологодская область, Кичменгско-Городецкий район, село Дорожково, 21	f	small
35548	29180	557	Вологодская область, Кичменгско-Городецкий район, поселок Гаражи, 61	f	small
35540	29172	549	Вологодская область, Кичменгско-Городецкий район, село Верняя Ентала, Центральная, 21	f	medium
35557	29189	566	Вологодская область, Кичменгско-Городецкий район, село Ваганово, 28 , дом культуры	f	small
35553	29185	562	Вологодская область, Кичменгско-Городецкий район, село Березовая Гора, 68	f	small
35544	29176	553	Вологодская область, Кичменгско-Городецкий район, село Ананино, Дорожная, 1	f	small
35562	29194	571	Вологодская область, Кичменгско-Городецкий район, село Алферово, Центральная, 31	f	small
35520	29154	524	Вологодская область, Кирилловский район, поселок Шиндалово, 8 А, Здание Дома культуры	f	small
35536	29168	540	Вологодская область, Кирилловский район, село Чарозеро, Центральная, 36	f	small
35534	29166	538	Вологодская область, Кирилловский район, село Ферапонтово, Слободская, 6	f	medium
35521	29155	525	Вологодская область, Кирилловский район, село Топорня, Клубный переулок, 4	t	small
35531	29163	535	Вологодская область, Кирилловский район, село Талицы, Советская, 31	f	large
35533	29165	537	Вологодская область, Кирилловский район, село Суховерхово, Центральная, 29	f	small
35529	29161	533	Вологодская область, Кирилловский район, село Рукино, 9, Здание библиотеки-клуба	f	small
134696	29159	531	Вологодская область, Кирилловский район, село Пустынь, 13, Здание администрации Пустынского ПНИ	t	small
35525	29157	529	Вологодская область, Кирилловский район, поселок Новостройка, Ленина, 1	f	small
35528	29160	532	Вологодская область, Кирилловский район, село Никольский Торжок, Захарьинская, 15	f	medium
35217	28888	203	Вологодская область, Кирилловский район, село Лукьяновская, 17, МБУК Вожегодская ЦБС	f	small
35537	29169	541	Вологодская область, Кирилловский район, село Коротецкая, Головинская, 1	f	small
35538	29170	542	Вологодская область, Кирилловский район, село Королево, 7, Здание Администрации поселения Чарозерское	f	small
35532	29164	536	Вологодская область, Кирилловский район, село Колкач, 107, Здание Администрации Талицкого поселения	f	small
85215	82035	1479	Санкт-Петербург, Комендантский проспект, 22к3	f	large
35524	29145	528	Вологодская область, Кирилловский район, село Коварзино, Центральная, 8	f	small
35518	29152	522	Вологодская область, Кирилловский район, Кириллов, Уверова, 23	f	large
35519	29153	523	Вологодская область, Кирилловский район, Кириллов, Советская, 19	f	large
35517	29151	521	Вологодская область, Кирилловский район, Кириллов, Гагарина, 108	f	large
35516	29150	520	Вологодская область, Кирилловский район, Кириллов, Гагарина, 30 А	f	large
35522	29156	526	Вологодская область, Кирилловский район, село Иванов Бор, Центральная, 18	f	small
35535	29167	539	Вологодская область, Кирилловский район, село Запань-Нова, 19, Здание Дома культуры	f	small
35523	29136	527	Вологодская область, Кирилловский район, село Горицы, Центральная, 38	f	small
35530	29162	534	Вологодская область, Кирилловский район, село Волокославинское, Преображенского, 49	f	medium
35526	29158	530	Вологодская область, Кирилловский район, село Вогнема, Центральная, 38	f	small
35505	29139	509	Вологодская область, Кадуйский район, поселок Хохлово, Школьная площадь, 2	f	large
35504	29139	508	Вологодская область, Кадуйский район, поселок Хохлово, Школьная площадь, 2	f	large
35510	29144	514	Вологодская область, Кадуйский район, поселок Фанерный Завод, Заводская, 25	f	small
35508	29142	512	Вологодская область, Кадуйский район, село Сосновка, Центральная, 5	f	small
35514	29148	518	Вологодская область, Кадуйский район, село Никольское, Городская, 4	f	small
35513	29148	517	Вологодская область, Кадуйский район, село Никольское, Городская, 4	f	small
35515	29149	519	Вологодская область, Кадуйский район, село Малая Рукавицкая, переулок Рабочий, 11	f	small
35512	29147	516	Вологодская область, Кадуйский район, село Маза, Центральная, 66	f	small
35498	29133	502	Вологодская область, Кадуйский район, село Крюково, Строителей, 2	f	large
35497	29133	501	Вологодская область, Кадуйский район, село Крюково, Строителей, 2	f	medium
35884	29511	903	Вологодская область, Кадуйский район, поселок Кривец, Новая, 32-а	f	small
35503	29138	507	Вологодская область, Кадуйский район, поселок Кадуй, Энтузиастов, 8А	f	large
35502	29138	506	Вологодская область, Кадуйский район, поселок Кадуй, Энтузиастов, 8А	f	large
35501	29137	505	Вологодская область, Кадуйский район, поселок Кадуй, Энтузиастов, 3, школа № 3	f	large
35500	29135	504	Вологодская область, Кадуйский район, поселок Кадуй, Энтузиастов, 3	f	large
35499	29134	503	Вологодская область, Кадуйский район, поселок Кадуй, Энтузиастов, 3, МОУ Кадуйская средняя общеобразовательная школа № 3	f	\N
35496	29132	500	Вологодская область, Кадуйский район, поселок Кадуй, Чехова, 1А	f	medium
35495	29131	499	Вологодская область, Кадуйский район, поселок Кадуй, Кирова, 49	f	medium
35494	29130	498	Вологодская область, Кадуйский район, поселок Кадуй, Кирова, 49, школа № 1	f	large
35066	28737	43	Вологодская область, Кадуйский район, село Верхний Двор, 72	f	small
35511	29146	515	Вологодская область, Кадуйский район, село Великое, Ветеранов, 8	f	small
35509	29143	513	Вологодская область, Кадуйский район, село Бойлово, Центральная, 18	f	small
35507	29141	511	Вологодская область, Кадуйский район, село Барановская, Центральная, 15	f	small
35506	29140	510	Вологодская область, Кадуйский район, село Андроново	f	small
35491	29126	495	Вологодская область, Грязовецкий район, село Юрово, Центральная, 2, Администрация МО Юровское	f	\N
35472	29110	476	Вологодская область, Грязовецкий район, село Хорошево, сосновая, 2, Администрация МО Комьянское	f	large
35473	29111	477	Вологодская область, Грязовецкий район, село Хорошево, Сосновая, 1 , Администрация МО Комьянское	f	small
35479	29113	483	Вологодская область, Грязовецкий район, село Фрол, 26, Администрация МО Перцевское	f	small
35492	29127	496	Вологодская область, Грязовецкий район, село Степурино, Полевая, 13 , Степуринский сельский клуб	f	\N
35488	29122	492	Вологодская область, Грязовецкий район, село Спасское, 32, лежский СДК	f	small
35476	29067	480	Вологодская область, Грязовецкий район, деревня Слобода, Школьная, 11А, Администрация МО Перцевское	f	medium
35493	29128	497	Вологодская область, Грязовецкий район, село Скородумка, Центральная, 47 , Чернецкий СДК	f	\N
35482	29116	486	Вологодская область, Грязовецкий район, село Сидоровское, Центральная, 8 , Сидоровский СДК	f	medium
85213	82034	1477	Санкт-Петербург, Комендантский проспект, 21к3	f	large
35486	29120	490	Вологодская область, Грязовецкий район, село Сидорово, Советская, 15 , Администрация МО Сидоровское	f	small
35480	29114	484	Вологодская область, Грязовецкий район, Ростилово, Молодежная, 5, Администрация МО Ростиловское	f	medium
35484	29118	488	Вологодская область, Грязовецкий район, село Плоское, Школьная, 11 , Плосковский сельский филиал БУК Межпоселенческая центральная библиотека	f	medium
35490	29125	494	Вологодская область, Грязовецкий район, село Панфилово, 61, Панфиловский сельский клуб	f	\N
35477	29078	481	Вологодская область, Грязовецкий район, село Палкино, Центральная, 15, Палкинский сельский клуб	t	small
35489	29123	493	Вологодская область, Грязовецкий район, село Минькино, Новая, 61	f	medium
35481	29115	485	Вологодская область, Грязовецкий район, поселок Льнозавода, Речная, 33	f	small
35483	29117	487	Вологодская область, Грязовецкий район, село Заемье, 19 , Заемский сельский клуб	f	small
35478	29089	482	Вологодская область, Грязовецкий район, село Жерноково, 86, Жерноковский СДК	f	small
35257	28926	246	Вологодская область, Грязовецкий район, село Дорожный, 2	f	large
35469	29108	473	Вологодская область, Грязовецкий район, Демьяново, 11 , Администрация Вохтожского городского поселения	f	medium
35453	29093	457	Вологодская область, Грязовецкий район, Грязовец, Революции, 104, спортивный комплекс Атлант	f	large
35461	29101	465	Вологодская область, Грязовецкий район, Грязовец, Рабочая, 1, здание ФАП	f	large
35458	29098	462	Вологодская область, Грязовецкий район, Грязовец, Карла Маркса, 71, БОУ ДОД Центр дополнительного образования детей	f	large
35457	29097	461	Вологодская область, Грязовецкий район, Грязовец, К.Маркса, 78, БОУ ДОД Грязовецкая детская школа искусств	f	large
35455	29095	459	Вологодская область, Грязовецкий район, Грязовец, Горького, МОУ Средняя общеобразовательная школа № 1	f	large
35460	29100	464	Вологодская область, Грязовецкий район, Грязовец, Гагарина, 46, МОУ Средняя общеобразовательная школа №2	f	large
35467	29106	471	Вологодская область, Грязовецкий район, село Вохтога, 76 , Вохтожский СДК	f	small
35462	29102	466	Вологодская область, Грязовецкий район, поселок Вохтога, пер.Свободы, 3, МОУ Вохтожская средняя общеобразовательная школа № 1	f	medium
35465	29104	469	Вологодская область, Грязовецкий район, поселок Вохтога, Юбилейная, 25, школа №2	f	small
35464	29103	468	Вологодская область, Грязовецкий район, поселок Вохтога, Юбилейная, 23, МУК Вохтожский ПДК	f	small
35463	29103	467	Вологодская область, Грязовецкий район, поселок Вохтога, Юбилейная, 23, МУК Вохтожский ПДК	f	small
35466	29105	470	Вологодская область, Грязовецкий район, поселок Вохтога, 24 Партсъезда, 10 , Клуб	f	small
35471	29109	475	Вологодская область, Грязовецкий район, село Вострогский, 17, МОУ Каменская общеобразовательная школа	f	small
35470	29109	474	Вологодская область, Грязовецкий район, село Вострогский, 17, МОУ Каменская общеобразовательная школа	f	medium
35485	29119	489	Вологодская область, Грязовецкий район, деревня Вараксино, 66, Администрация МО Ростиловское	f	small
35474	29112	478	Вологодская область, Грязовецкий район, поселок Бушуиха, Центральная, 9, Ведерковский СДК	f	small
35475	29056	479	Вологодская область, Грязовецкий район, поселок Бушуиха, Центральная, 7, Здание бывшей совхозной школы	f	small
35487	29121	491	Вологодская область, Грязовецкий район, село Анохино, Центральная, 42	f	medium
35468	29107	472	Вологодская область, Грязовецкий район, село Аксеново, 30 , Аксеновский сельский клуб	f	small
35443	29082	446	Вологодская область, Вытегорский район, село Янишево, Школьная, 5, МОУ Янишевская основная общеобразовательная школа	f	small
35419	29055	418	Вологодская область, Вытегорский район, село Шестово, 1	f	small
35431	29069	431	Вологодская область, Вытегорский район, село Тудозерский Погост, Молодёжная, 4	f	small
35432	29070	432	Вологодская область, Вытегорский район, село Сорокополье, Набережная, 1	f	small
35435	29073	436	Вологодская область, Вытегорский район, село Саминский Погост, 7	f	small
35452	29092	456	Вологодская область, Вытегорский район, село Прокшино, Архангельская, 8	f	small
35429	29066	429	Вологодская область, Вытегорский район, село Палтога, Школьная, 11	f	small
35430	29068	430	Вологодская область, Вытегорский район, село Палозеро, Архангельский тракт, 14 	t	small
35450	29090	454	Вологодская область, Вытегорский район, село Павшозеро, Школьная, 13	t	small
35421	29058	420	Вологодская область, Вытегорский район, село Ошта, Архангельский тракт, 52	f	medium
35436	29074	437	Вологодская область, Вытегорский район, село Октябрьский, Гагарина, 13	f	medium
35445	29084	448	Вологодская область, Вытегорский район, село Новостройка, Центральная, 3-а	t	small
35422	29059	421	Вологодская область, Вытегорский район, село Ниж. Водлица, Архангельский тракт, 48	f	small
35446	29085	450	Вологодская область, Вытегорский район, село Митино, 25	f	small
35451	29091	455	Вологодская область, Вытегорский район, село Мирный, Калинина, 10	f	medium
35427	29064	427	Вологодская область, Вытегорский район, село Межозерье, Почтовая, 5	f	small
35424	29061	423	Вологодская область, Вытегорский район, село Мегра, Центральная, 14	f	small
35434	29072	435	Вологодская область, Вытегорский район, село Макачево, Школьная, 12	f	small
35426	29063	426	Вологодская область, Вытегорский район, село Коштуги, Мира, 48	f	small
35428	29065	428	Вологодская область, Вытегорский район, село Кондушский Погост, Центральная, 22	f	small
35441	29080	444	Вологодская область, Вытегорский район, село Депо, Спортивная, 15	f	large
35442	29081	445	Вологодская область, Вытегорский район, село Депо, Архангельский тракт, 7, Белоручейская средняя общеобразовательная школа	f	medium
35440	29079	443	Вологодская область, Вытегорский район, село Девятины, Архангельский тракт, 118	f	large
35423	29060	422	Вологодская область, Вытегорский район, Горный Ручей, улица Школьная, 2	t	small
35417	29053	416	Вологодская область, Вытегорский район, Вытегра, Шевченко, 51	f	large
35415	29051	414	Вологодская область, Вытегорский район, Вытегра, Проспект Ленина, 52	f	large
35416	29052	415	Вологодская область, Вытегорский район, Вытегра, Луначарского проспект, 35	f	large
35414	29050	413	Вологодская область, Вытегорский район, Вытегра, Ленинградский тракт, 12	f	large
35444	29083	447	Вологодская область, Вытегорский район, село Волоков Мост, Болотная, 22-а	f	medium
35425	29062	424	Вологодская область, Вытегорский район, село Верхнее Понизовье, Школьная, 2	f	small
35439	29077	440	Вологодская область, Вытегорский район, деревня Боярская, 33	f	small
35438	29076	439	Вологодская область, Вытегорский район, село Белоусово, Школьная, 2-а	f	medium
35437	29075	438	Вологодская область, Вытегорский район, село Анхимово, 2-б	f	small
35448	29087	452	Вологодская область, Вытегорский район, село Анненский Мост, улица Лесная, 47, Дом культуры	t	large
35447	29086	451	Вологодская область, Вытегорский район, село Анненский Мост, Советский проспект, 10	f	medium
35433	29071	433	Вологодская область, Вытегорский район, Андомский Погост, Центральная, 44-а	f	medium
35449	29088	453	Вологодская область, Вытегорский район, село Александровское, Заречная, 3	t	small
35250	28920	239	Вологодская область, Вологодский район, село Шолохово, Школьная, 2	f	small
35254	28923	243	Вологодская область, Вологодский район, село Харачево, 12	f	medium
35255	28924	244	Вологодская область, Вологодский район, село Фофанцево, 24	f	medium
35260	28929	249	Вологодская область, Вологодский район, село Фетинино, 4	f	medium
35273	28941	262	Вологодская область, Вологодский район, поселок Федотово, 38	f	large
35272	28941	261	Вологодская область, Вологодский район, поселок Федотово, 38	f	large
35271	28940	260	Вологодская область, Вологодский район, село Уткино, Центральная, 19-а	f	medium
35268	28937	257	Вологодская область, Вологодский район, село Стризнево, Зеленая, 12	f	medium
35262	28931	251	Вологодская область, Вологодский район, село Сосновка, Молодежная, 3	f	large
35256	28925	245	Вологодская область, Вологодский район, село Семенково 2-е, 46	f	small
35258	28927	247	Вологодская область, Вологодский район, село Семенково, Первомайская, 9	f	large
35235	28893	223	Вологодская область, Вологодский район, село Северная Ферма, Центральная, 1	f	small
35249	28919	238	Вологодская область, Вологодский район, село Севастьяново, 44	f	small
35263	28932	252	Вологодская область, Вологодский район, село Помыгалово, здание санатория Новый Источник	f	medium
35264	28933	253	Вологодская область, Вологодский район, село Погорелово, Центральная, 1	f	medium
35267	28936	256	Вологодская область, Вологодский район, село Перьево, Школьный переулок, 3-б	f	medium
35237	28907	225	Вологодская область, Вологодский район, Остахово, Центральная, 1	f	medium
35251	28780	240	Вологодская область, Вологодский район, село Огарково, 35	f	large
35233	28905	221	Вологодская область, Вологодский район, деревня Новое , 61	f	medium
35246	28916	235	Вологодская область, Вологодский район, село Новленское, Советская, 24	f	medium
35248	28918	237	Вологодская область, Вологодский район, село Нефедово, Центральная, 25	f	small
35265	28934	254	Вологодская область, Вологодский район, село Непотягово, 50	f	large
35253	28922	242	Вологодская область, Вологодский район, село Надеево, 23	f	large
35234	28707	222	Вологодская область, Вологодский район, Мынчаково, 122	f	small
35406	29042	405	Вологодская область, Вологодский район, поселок Молочное, Парковая, 9а к1	f	small
35397	29033	396	Вологодская область, Вологодский район, поселок Молочное, Парковая, 3	f	small
35396	29032	395	Вологодская область, Вологодский район, поселок Молочное, Мира, 8	f	large
35394	29030	393	Вологодская область, Вологодский район, поселок Молочное, Емельянова, 7	f	large
35266	28935	255	Вологодская область, Вологодский район, село Можайское, 5 а	f	medium
35236	28906	224	Вологодская область, Вологодский район, село Макарово, Центральная, 4	f	medium
35240	28910	228	Вологодская область, Вологодский район, село Майский, 14, Дом культуры	f	large
35238	28908	226	Вологодская область, Вологодский район, село Лесково, 39	f	medium
35241	28911	229	Вологодская область, Вологодский район, село Куркино, Школьная, 7	f	medium
35232	28904	220	Вологодская область, Вологодский район, село Кубенское, Ленина, 50	f	large
35231	28903	219	Вологодская область, Вологодский район, село Кубенское, Ленина, 77	f	large
35269	28938	258	Вологодская область, Вологодский район, поселок Кипелово, Железнодорожная, 14	f	medium
35242	28912	230	Вологодская область, Вологодский район, село Ильинское, Садовая, 16	f	large
35243	28913	231	Вологодская область, Вологодский район, село Заря, 41	f	medium
35239	28909	227	Вологодская область, Вологодский район, село Ермаково, Строителей, 17	f	large
35259	28928	248	Вологодская область, Вологодский район, село Дубровское, Центральная, 8	f	medium
35244	28914	232	Вологодская область, Вологодский район, поселок Дикая, 24	f	small
35252	28921	241	Вологодская область, Вологодский район, село Грибково, 14	f	medium
35270	28939	259	Вологодская область, Вологодский район, село Горка, 37	f	small
35245	28915	233	Вологодская область, Вологодский район, село Васильевское, Торговая площадь, 2	f	large
35247	28917	236	Вологодская область, Вологодский район, село Березник, 56	f	medium
35215	28886	201	Вологодская область, Вожегодский район, село Яхреньга, Октябрьская, 31	t	small
35224	28896	210	Вологодская область, Вожегодский район, село Ючка, Октябрьская, 10	f	medium
35216	28887	202	Вологодская область, Вожегодский район, село Сосновица, 109, администрация сельского поселения Митюковское	f	small
35208	28880	194	Вологодская область, Вожегодский район, село Савинская, 49, Ухтомский сельский Дом культуры филиал МБУК ВР КДО	f	small
35230	28902	216	Вологодская область, Вожегодский район, село Покровское, 67, администрация сельского поселения Явенгское	f	small
35227	28899	213	Вологодская область, Вожегодский район, село Олеховская, 14 А, кабинет в здании начальной образовательной школы	f	small
35219	28890	205	Вологодская область, Вожегодский район, село Озерный, Центральная, 7	f	small
35223	28895	209	Вологодская область, Вожегодский район, село Огибалово, 75, администрация сельского поселения 	f	small
35218	28889	204	Вологодская область, Вожегодский район, село Мишутинская, 19, администрация сельского поселения Мишутинское	f	small
35228	28900	214	Вологодская область, Вожегодский район, село Михайловская, 1, администрация сельского поселения Явенгское	f	small
35225	28897	211	Вологодская область, Вожегодский район, село Марьинская, 9, администрация сельского поселения Явенгское	f	small
35214	28885	200	Вологодская область, Вожегодский район, село Кадниковский, Первомайская, 7	f	large
35220	28891	206	Вологодская область, Вожегодский район, село Деревенька, 63, администрация сельского поселения Нижнеслободское	f	medium
35221	28892	207	Вологодская область, Вожегодский район, село Гридино, 36, Тигинский сельский Дом культуры филиал МБУК ВР КДО	f	small
35212	28883	198	Вологодская область, Вожегодский район, село Воскресенское, 20, Пунемский сельский Дом культуры филиал МБУК ВР КДО	f	small
35205	28877	191	Вологодская область, Вожегодский район, поселок Вожега, Советская, 23	f	large
35207	28879	193	Вологодская область, Вожегодский район, поселок Вожега, Свободы, 3	f	large
35206	28878	192	Вологодская область, Вожегодский район, поселок Вожега, Садовая, 10	f	large
35209	28881	195	Вологодская область, Вожегодский район, село Бекетовская, 159, Бекетовский сельский Дом культуры филиал МБУК ВР КДО	f	medium
35213	28884	199	Вологодская область, Вожегодский район, село Бекетово, Школьная, 1	f	small
35229	28901	215	Вологодская область, Вожегодский район, село База, Советская, 60	f	small
35204	28876	190	Вологодская область, Верховажский район, село Шелота, Полевая, 2	f	small
35200	28872	186	Вологодская область, Верховажский район, село Чушевицы, Восточная, 14, дом детского творчества	f	medium
35186	28858	172	Вологодская область, Верховажский район, село Феклуха, Школьная, 2	t	small
35194	28866	180	Вологодская область, Верховажский район, село Урусовская, Новая, 34, ФОК	f	medium
35180	28852	166	Вологодская область, Верховажский район, село Теплый Ручей, Новая, 15	f	small
35195	28867	181	Вологодская область, Верховажский район, село Средняя, 37	f	small
35181	28853	167	Вологодская область, Верховажский район, село Сметанино, Советская, 37	f	medium
35198	28870	184	Вологодская область, Верховажский район, село Рогна, Лесная, 15	f	small
35203	28875	189	Вологодская область, Верховажский район, село Плосково, Центральная, 8	f	small
35189	28861	175	Вологодская область, Верховажский район, село Пежма, Центральная, 1	f	small
35197	28869	183	Вологодская область, Верховажский район, село Осташевская, 17	f	small
35185	28857	171	Вологодская область, Верховажский район, село Ногинская, Центральная, 18	f	small
35191	28863	177	Вологодская область, Верховажский район, село Наумиха, 18 А	f	small
35188	28860	174	Вологодская область, Верховажский район, село Морозово, Мира, 25	f	small
35182	28854	168	Вологодская область, Верховажский район, село Макарцево, Центральная, 8	f	small
35187	28859	173	Вологодская область, Верховажский район, село Леушинская, Центральная, 26	f	small
35199	28871	185	Вологодская область, Верховажский район, село Куколовская, Куколовская, 14	f	small
35184	28856	170	Вологодская область, Верховажский район, село Климушино, Стебенева, 15	f	small
35202	28874	188	Вологодская область, Верховажский район, село Каменка, переулок Школьный, 7	f	small
35196	28868	182	Вологодская область, Верховажский район, село Елисеевская, 29	f	small
35201	28873	187	Вологодская область, Верховажский район, село Владыкина Гора, 7	t	small
35179	28851	165	Вологодская область, Верховажский район, село Верховажье, переулок Лесной, 5	f	large
35177	28849	163	Вологодская область, Верховажский район, село Верховажье, Стебенева, 41	f	large
35178	28850	164	Вологодская область, Верховажский район, село Верховажье, Пионерская, 27А	f	large
35183	28855	169	Вологодская область, Верховажский район, село Великодворская, Центральная, 3	f	small
35193	28865	179	Вологодская область, Верховажский район, село Большое Ефимово, 13 , дом культуры	f	small
35192	28864	178	Вологодская область, Верховажский район, село Безымянная, 11	f	small
35190	28862	176	Вологодская область, Верховажский район, село Артемьевская, 53	f	small
35150	28822	136	Вологодская область, Великоустюгский район, дер.Бухинино, дом-интернат	f	small
35175	28847	161	Вологодская область, Великоустюгский район, село Юдино, 10	f	medium
35170	28842	156	Вологодская область, Великоустюгский район, село Щекино, Центральная, 19	f	small
35159	28831	145	Вологодская область, Великоустюгский район, село Чучеры, 22	f	small
35157	28829	143	Вологодская область, Великоустюгский район, село Чернево, 85	f	small
35171	28843	157	Вологодская область, Великоустюгский район, село Усть-Алексеево, Школьная, 1	f	large
35168	28840	154	Вологодская область, Великоустюгский район, село Теплогорье, Проезжая, 11	f	small
35166	28838	152	Вологодская область, Великоустюгский район, поселок Сусоловка, пер.Советский, 5	f	medium
35174	28846	160	Вологодская область, Великоустюгский район, село Стрига, 6А	f	medium
35113	28785	96	Вологодская область, Вашкинский район, село Троицкое, Мира, 2	f	small
35167	28839	153	Вологодская область, Великоустюгский район, село Северный, Колотова, 4А	f	small
35156	28828	142	Вологодская область, Великоустюгский район, поселок Полдарса, Гагарина, 1А	f	large
35164	28836	150	Вологодская область, Великоустюгский район, село Подсосенье, 13	f	small
35148	28820	134	Вологодская область, Великоустюгский район, село Плутово, Рабочая, 7а	f	small
35146	28818	132	Вологодская область, Великоустюгский район, село Первомайское, Полевая, 15	f	small
35155	28827	141	Вологодская область, Великоустюгский район, село Пеганово, Центральная, 53	f	small
134694	28835	148	Вологодская область, Великоустюгский район, поселок Новатор, Советская, 36	f	large
134695	28834	149	Вологодская область, Великоустюгский район, поселок Новатор, Советская, 1	f	large
35145	28817	131	Вологодская область, Великоустюгский район, село Мякинницыно, 9	f	small
35169	28841	155	Вологодская область, Великоустюгский район, село Морозовица, Центральная, 27	f	medium
35151	28823	137	Вологодская область, Великоустюгский район, поселок Ломоватка, Железнодорожная, 27	f	large
35154	28826	140	Вологодская область, Великоустюгский район, село Лодейка, 18	f	small
35140	28812	126	Вологодская область, Великоустюгский район, поселок Кузино, Лермонтова, 10	f	large
35141	28813	127	Вологодская область, Великоустюгский район, Красавино, Текстильщиков, 10	f	large
35142	28814	128	Вологодская область, Великоустюгский район, Красавино, Советский проспект, 152	f	large
35144	28816	130	Вологодская область, Великоустюгский район, Красавино, Революции, 18	f	large
35143	28815	129	Вологодская область, Великоустюгский район, Красавино, Культуры, 3	f	large
35158	28830	144	Вологодская область, Великоустюгский район, село Карасово, 5	f	small
35153	28825	139	Вологодская область, Великоустюгский район, село Ишутино, 24	f	small
35160	28832	146	Вологодская область, Великоустюгский район, Ильинское, 1	f	small
35161	28833	147	Вологодская область, Великоустюгский район, деревня Измарухово, 31	f	small
35173	28845	159	Вологодская область, Великоустюгский район, село Золотавцево, 13А	f	small
35147	28819	133	Вологодская область, Великоустюгский район, село Верхняя Шарденьга, 73	f	small
35165	28837	151	Вологодская область, Великоустюгский район, Верхнее Анисимово, 1	f	small
35137	28809	123	Вологодская область, Великоустюгский район, Великий Устюг, Советский проспект, 200	f	large
35136	28808	122	Вологодская область, Великоустюгский район, Великий Устюг, Советский проспект, 221	f	large
35131	28803	117	Вологодская область, Великоустюгский район, Великий Устюг, Советский проспект, 87	f	large
35134	28806	120	Вологодская область, Великоустюгский район, Великий Устюг, Площадь Коммуны, 14	f	large
35129	28801	115	Вологодская область, Великоустюгский район, Великий Устюг, П.Покровского, 2А	f	large
35130	28802	116	Вологодская область, Великоустюгский район, Великий Устюг, Набережная, 47	f	large
35124	28796	110	Вологодская область, Великоустюгский район, Великий Устюг, Московская, 7	f	large
35126	28798	112	Вологодская область, Великоустюгский район, Великий Устюг, Кузнецова, 2	f	large
35125	28797	111	Вологодская область, Великоустюгский район, Великий Устюг, Кузнецова, 22	f	large
35135	28807	121	Вологодская область, Великоустюгский район, Великий Устюг, Кооперативная, 7	f	large
35132	28804	118	Вологодская область, Великоустюгский район, Великий Устюг, Дежнёва, 4	f	large
35123	28795	109	Вологодская область, Великоустюгский район, Великий Устюг, Гледенская, 18	f	large
35138	28810	124	Вологодская область, Великоустюгский район, Великий Устюг, Вторая, 5	f	medium
35133	28805	119	Вологодская область, Великоустюгский район, Великий Устюг, А.Угловского, 14	f	large
35128	28800	114	Вологодская область, Великоустюгский район, Великий Устюг, 2-я Пролетарская, 8	f	large
35127	28799	113	Вологодская область, Великоустюгский район, Великий Устюг, 2-я Пролетарская, 36	f	large
35149	28821	135	Вологодская область, Великоустюгский район, село Васильевское, Парковая, 33	f	medium
35176	28848	162	Вологодская область, Великоустюгский район, село Бобровниково, 45	f	small
35152	28824	138	Вологодская область, Великоустюгский район, село Благовещенье, Школьная, 9	f	small
35172	28844	158	Вологодская область, Великоустюгский район, село Аристово, П.Виноградова, 8	f	medium
35120	28792	103	Вологодская область, Вашкинский район, село Покровское, Набережная Кемы, 9	f	small
35110	28782	93	Вологодская область, Вашкинский район, село Пиньшино, 18	f	small
35119	28791	102	Вологодская область, Вашкинский район, село Пиксимово, Молодёжная , 12	f	small
35108	28779	91	Вологодская область, Вашкинский район, село Первомайский, Гагарина, 32А	f	small
35122	28794	105	Вологодская область, Вашкинский район, село Парфеново, 5	f	small
35118	28790	101	Вологодская область, Вашкинский район, село Остров, Центральная, 7	f	small
35112	28784	95	Вологодская область, Вашкинский район, село Октябрьский, Лесная, 1	f	small
35114	28786	97	Вологодская область, Вашкинский район, село Новокемский, Чумакова, 2	f	medium
35115	28787	98	Вологодская область, Вашкинский район, село Липин Бор, Первомайская, 3	f	large
35111	28783	94	Вологодская область, Вашкинский район, село Ивановская, Советская, 1	f	small
35117	28789	100	Вологодская область, Вашкинский район, село Заречный, Механизаторов, 2	f	medium
35109	28781	92	Вологодская область, Вашкинский район, село Васильевская, Центральная, 16	f	small
35121	28793	104	Вологодская область, Вашкинский район, село Бонга, Юбилейная, 15	f	small
35107	28778	90	Вологодская область, Вашкинский район, село Андреевская, Центральная, 16	f	small
35094	28765	73	Вологодская область, Белозерский район, Панинская, 34	f	small
35101	28772	81	Вологодская область, Белозерский район, село Никоновская, Школьный переулок, 7	f	small
35106	28777	86	Вологодская область, Белозерский район, село Нижняя Мондома, Советская, 22	f	medium
35100	28771	80	Вологодская область, Белозерский район, село Мегринский, Центральная, 154	f	small
35086	28757	64	Вологодская область, Белозерский район, село Маэкса, Труда, 4	f	small
35103	28774	83	Вологодская область, Белозерский район, село Лаврово, Сельсоветская, 15	f	small
35105	28776	85	Вологодская область, Белозерский район, Куность, Центральная, 36	f	small
35102	28773	82	Вологодская область, Белозерский район, село Кукшево, 9	f	small
35097	28768	76	Вологодская область, Белозерский район, село Климшин Бор, Центральная, 1	f	small
35093	28764	72	Вологодская область, Белозерский район, село Карл Либкнехт, 1	f	small
35084	28755	61	Вологодская область, Белозерский район, село Зубово, Спортивная, 1	f	medium
35083	28754	60	Вологодская область, Белозерский район, село Зубово, Набережная, 23	f	medium
35099	28770	78	Вологодская область, Белозерский район, село Глушково, Молодежная, 35	f	small
35098	28769	77	Вологодская область, Белозерский район, село Георгиевское, Центральная, 10	f	small
35096	28767	75	Вологодская область, Белозерский район, село Визьма, Центральная, 46-а, дом культуры	f	small
35095	28766	74	Вологодская область, Белозерский район, село Бечевинка, Молодежная, 1	f	small
35104	28775	84	Вологодская область, Белозерский район, село Белый Ручей, Центральная, 31-а	f	small
35085	28756	63	Вологодская область, Белозерский район, Белозерск, Энгельса, 12	f	large
35087	28758	65	Вологодская область, Белозерский район, Белозерск, Фрунзе, 35	f	large
35090	28761	68	Вологодская область, Белозерский район, Белозерск, Советский проспект, 52	f	large
35088	28759	66	Вологодская область, Белозерский район, Белозерск, С.Дмитриева, 8	f	large
35089	28760	67	Вологодская область, Белозерский район, Белозерск, Карла Маркса, 35-а	f	large
35092	28763	71	Вологодская область, Белозерский район, село Артюшино, 20	f	small
35091	28762	69	Вологодская область, Белозерский район, Антушево, 102	f	small
35059	28730	36	Вологодская область, Бабушкинский район, село Юрманга, Юрманга, 26	f	small
35082	28753	59	Вологодская область, Бабушкинский район, село Юркино, 48	f	small
35070	28741	47	Вологодская область, Бабушкинский район, село Тиноватка, 21	t	small
35079	28750	56	Вологодская область, Бабушкинский район, село Тиманова Гора, 4	f	medium
35074	28745	51	Вологодская область, Бабушкинский район, село Скоково, 1	f	small
35078	28749	55	Вологодская область, Бабушкинский район, село Рослятино, Советская, 17	f	medium
35073	28744	50	Вологодская область, Бабушкинский район, село Подболотье, 77	f	small
35069	28740	46	Вологодская область, Бабушкинский район, село Миньково, Советская, 61	f	medium
35065	28736	42	Вологодская область, Бабушкинский район, село Логдуз, 22	f	small
35080	28751	57	Вологодская область, Бабушкинский район, поселок Кунож, 115	f	small
35068	28739	45	Вологодская область, Бабушкинский район, село Кулибарово, 5	f	small
35077	28748	54	Вологодская область, Бабушкинский район, село Красота, Школьная, 3	f	small
35062	28733	39	Вологодская область, Бабушкинский район, село Косиково, 13	f	small
35067	28738	44	Вологодская область, Бабушкинский район, село Комсомольский, 23	t	small
35072	28743	49	Вологодская область, Бабушкинский район, село Кокшарка, 1	f	small
35064	28735	41	Вологодская область, Бабушкинский район, село Козлец, 6	f	small
35058	28729	35	Вологодская область, Бабушкинский район, село Имени Бабушкина, Бабушкина, 65	f	large
35057	28728	34	Вологодская область, Бабушкинский район, село Имени Бабушкина, Бабушкина, 63	f	large
35063	28734	40	Вологодская область, Бабушкинский район, село Ида, Гагарина, 17	f	small
35076	28747	53	Вологодская область, Бабушкинский район, поселок Зайчики, Школьная, 15А	f	small
35075	28746	52	Вологодская область, Бабушкинский район, село Жубрино, 6А	f	small
35061	28732	38	Вологодская область, Бабушкинский район, село Демьяновский Погост, 15	f	small
35060	28731	37	Вологодская область, Бабушкинский район, село Воскресенское, Центральная, 26	f	medium
35071	28742	48	Вологодская область, Бабушкинский район, село Безгачиха, 7	f	small
35081	28752	58	Вологодская область, Бабушкинский район, село Аниково, 10	f	small
35055	28726	32	Вологодская область, Бабаевский район, село Торопово, Западная, 1	f	small
35038	28710	15	Вологодская область, Бабаевский район, поселок Тимошкино, Школьная, 3	t	small
35052	28723	29	Вологодская область, Бабаевский район, село Тимошино, Солнечная, 1	f	small
35054	28725	31	Вологодская область, Бабаевский район, село Смородинка, Набережная, 14	f	medium
35050	28721	27	Вологодская область, Бабаевский район, село Санинская, 30	f	small
35049	28720	26	Вологодская область, Бабаевский район, поселок Пяжелка, Центральная, 1	f	medium
35045	28717	22	Вологодская область, Бабаевский район, село Пожара, Школьная, 2	f	medium
35044	28716	21	Вологодская область, Бабаевский район, село Плесо, 9	f	small
35042	28714	19	Вологодская область, Бабаевский район, село Новое Лукино, 13	f	small
35043	28715	20	Вологодская область, Бабаевский район, село Новая Старина, 62	f	small
35033	28704	10	Вологодская область, Бабаевский район, село Малое Борисово, 10	f	small
35046	28718	23	Вологодская область, Бабаевский район, поселок Колошма, 61	f	small
35056	28727	33	Вологодская область, Бабаевский район, село Кийно, 64	f	small
35041	28713	18	Вологодская область, Бабаевский район, село Кийно, 48	f	small
35051	28722	28	Вологодская область, Бабаевский район, село Заполье, 48	f	small
35039	28711	16	Вологодская область, Бабаевский район, село Дубровка, 16	f	small
35048	28719	25	Вологодская область, Бабаевский район, село Григорьевская, 2	t	small
35040	28712	17	Вологодская область, Бабаевский район, село Горка, 65	f	small
35037	28709	14	Вологодская область, Бабаевский район, село Володино, Набережная, 7-А	f	small
35034	28705	11	Вологодская область, Бабаевский район, село Борисово-Судское, Комсомольская, 2	f	large
35024	28696	1	Вологодская область, Бабаевский район, Бабаево, Ухтомского, 18	f	large
35025	28697	2	Вологодская область, Бабаевский район, Бабаево, Советская, 31	f	large
35029	28701	6	Вологодская область, Бабаевский район, Бабаево, Садовая, 14	f	large
35026	28698	3	Вологодская область, Бабаевский район, Бабаево, Производственный переулок, 7	f	large
35030	28702	7	Вологодская область, Бабаевский район, Бабаево, Интернациональная, 42	f	large
35032	28700	9	Вологодская область, Бабаевский район, Бабаево, Гайдара, 9	f	large
35028	28700	5	Вологодская область, Бабаевский район, Бабаево, Гайдара, 9	f	large
35027	28699	4	Вологодская область, Бабаевский район, Бабаево, Гайдара, 9	f	large
35036	28708	13	Вологодская область, Бабаевский район, село Александровская, 8	f	small
35035	28706	12	Вологодская область, Бабаевский район, село Аксентьевская, 22	f	small
35053	28724	30	Вологодская область, Бабаевский , Верхневольский, Железнодорожная, 1	f	small
109363	18869	993	Архангельская область, Шенкурск, К.Либкнехта, 9	f	\N
29305	18749	868	Россия, Архангельская область, Северодвинск	t	small
29292	18744	855	Россия, Архангельская область, Северодвинск	f	large
29259	18724	822	Архангельская область, Северодвинск, проспект Труда, 25	f	large
68039	18746	865	Архангельская область, Северодвинск, Юбилейная, 17	f	large
29297	18746	860	Архангельская область, Северодвинск, Юбилейная, 17	f	large
29296	18746	859	Архангельская область, Северодвинск, Юбилейная, 17	f	large
29295	18746	858	Архангельская область, Северодвинск, Юбилейная, 17	f	large
29250	18717	813	Архангельская область, Северодвинск, Тургенева, 8	f	large
29249	18717	812	Архангельская область, Северодвинск, Тургенева, 8	f	large
29280	18736	843	Архангельская область, Северодвинск, Трухинова, 10	f	large
29279	18736	842	Архангельская область, Северодвинск, Трухинова, 10	f	large
29278	18736	841	Архангельская область, Северодвинск, Трухинова, 10	f	large
29277	18736	840	Архангельская область, Северодвинск, Трухинова, 10	f	large
29266	18727	829	Архангельская область, Северодвинск, Труда проспект, 14А	f	large
29265	18727	828	Архангельская область, Северодвинск, Труда проспект, 14А	f	large
29262	18727	825	Архангельская область, Северодвинск, Труда проспект, 14А	f	large
68036	18725	824	Архангельская область, Северодвинск, Труда проспект, 7Б	f	large
68035	18725	823	Архангельская область, Северодвинск, Труда проспект, 7Б	f	large
68034	18721	819	Архангельская область, Северодвинск, Торцева, 59	f	large
29255	18721	818	Архангельская область, Северодвинск, Торцева, 59	f	large
29254	18715	817	Архангельская область, Северодвинск, Торцева, 36	f	large
29247	18715	810	Архангельская область, Северодвинск, Торцева, 36	f	large
29238	18708	801	Архангельская область, Северодвинск, Торцева, 12	f	large
29236	18706	799	Архангельская область, Северодвинск, Торцева, 6	f	large
29241	18711	804	Архангельская область, Северодвинск, Строителей, 43А	f	large
29286	18738	849	Архангельская область, Северодвинск, Советских Космонавтов, 18	f	large
29239	18709	802	Архангельская область, Северодвинск, Республиканская, 21А	f	large
29243	18712	806	Архангельская область, Северодвинск, Профсоюзная, 21	f	large
29230	18704	793	Архангельская область, Северодвинск, Приморский бульвар, 50	f	large
29246	18714	809	Архангельская область, Северодвинск, Полярная, 12А	f	large
29245	18714	808	Архангельская область, Северодвинск, Полярная, 12А	f	large
29264	18728	827	Архангельская область, Северодвинск, Орджоникидзе, 15	f	large
29263	18728	826	Архангельская область, Северодвинск, Орджоникидзе, 15	f	large
29231	18705	794	Архангельская область, Северодвинск, Октябрьская, 31	f	large
29234	18664	797	Архангельская область, Северодвинск, Октябрьская, 2	f	large
29232	18631	795	Архангельская область, Северодвинск, Октябрьская, 31	f	large
29300	18739	863	Архангельская область, Северодвинск, Морской проспект, 56А	f	large
29299	18739	862	Архангельская область, Северодвинск, Морской проспект, 56А	f	large
29298	18739	861	Архангельская область, Северодвинск, Морской проспект, 56А	f	large
29287	18739	850	Архангельская область, Северодвинск, Морской проспект, 56А	f	large
29273	18732	836	Архангельская область, Северодвинск, Морской проспект, 12А	f	large
29272	18732	835	Архангельская область, Северодвинск, Морской проспект, 12А	f	large
29271	18731	834	Архангельская область, Северодвинск, Морской проспект, 9	f	large
29224	18700	787	Архангельская область, Северодвинск, Мира, 11	f	large
29227	18700	790	Архангельская область, Северодвинск, Мира, 11	f	large
29233	18653	796	Архангельская область, Северодвинск, Мира, 23В	f	large
29285	18737	848	Архангельская область, Северодвинск, Ломоносова, 83	f	large
29284	18737	847	Архангельская область, Северодвинск, Ломоносова, 83	f	large
29253	18720	816	Архангельская область, Северодвинск, Ленина проспект, 14	f	large
134516	18713	811	Архангельская область, Северодвинск, Ленина проспект, 31	f	large
68033	18713	807	Архангельская область, Северодвинск, Ленина проспект, 31	f	large
29301	18740	864	Архангельская область, Северодвинск, Лебедева, 10А	f	large
29294	18740	857	Архангельская область, Северодвинск, Лебедева, 10А	f	large
29288	18740	851	Архангельская область, Северодвинск, Лебедева, 10А	f	large
29223	18699	786	Архангельская область, Северодвинск, Корабельная, 1	f	large
68032	18710	805	Архангельская область, Северодвинск, Комсомольская, 7	f	large
29240	18710	803	Архангельская область, Северодвинск, Комсомольская, 7	f	large
29293	18745	856	Архангельская область, Северодвинск, Кирилкина, 3А	f	large
29269	18730	832	Архангельская область, Северодвинск, Карла Маркса, 33	f	large
29268	18730	831	Архангельская область, Северодвинск, Карла Маркса, 33	f	large
29270	18730	833	Архангельская область, Северодвинск, Карла Маркса, 33	f	large
29267	18729	830	Архангельская область, Северодвинск, Карла Маркса, 36	f	large
29257	18722	820	Архангельская область, Северодвинск, Капитана Воронина, 24	f	large
109341	18707	800	Архангельская область, Северодвинск, Железнодорожная, 23В	f	\N
29229	18703	792	Архангельская область, Северодвинск, Дзержинского, 11А	f	large
29228	18703	791	Архангельская область, Северодвинск, Дзержинского, 11А	f	large
29235	18701	798	Архангельская область, Северодвинск, Гоголя, 4	f	large
29225	18701	788	Архангельская область, Северодвинск, Гоголя, 4	f	large
29258	18723	821	Архангельская область, Северодвинск, Гагарина, 24	f	large
29252	18719	815	Архангельская область, Северодвинск, Гагарина, 15	f	large
68038	18733	838	Архангельская область, Северодвинск, Арктическая, 16	f	large
68037	18733	837	Архангельская область, Северодвинск, Арктическая, 16	f	large
29283	18735	846	Архангельская область, Северодвинск, Коновалова, 3А	f	large
29282	18735	845	Архангельская область, Северодвинск, Коновалова, 3А	f	large
29281	18735	844	Архангельская область, Северодвинск, Коновалова, 3А	f	large
29276	18735	839	Архангельская область, Северодвинск, Коновалова, 3А	f	large
29216	18692	778	Архангельская область, деревня Повракульская, 70 лет Октября, 8	t	small
29069	18541	624	Архангельская область, Онега, Матросова, 34	f	large
29065	18538	620	Архангельская область, Онега, Коминтерна, 64	f	large
29071	18543	626	Архангельская область, Онега, Гутина, 5	f	large
29068	18540	623	Архангельская область, Онега, Архангельская, 38	f	large
29067	18540	622	Архангельская область, Онега, Архангельская, 38	f	large
29037	18510	585	Архангельская область, Няндома, Строителей, 3	f	large
29033	18506	581	Архангельская область, Няндома, Строителей, 23А	f	large
29032	18505	580	Архангельская область, Няндома, Первомайская, 4	f	large
29039	18512	587	Архангельская область, Няндома, Красноармейская, 57А	f	large
29024	18498	572	Архангельская область, Новодвинск, Фронтовых бригад, 6	f	large
29027	18500	575	Архангельская область, Новодвинск, Уборевича, 43	f	large
29025	18396	573	Архангельская область, Новодвинск, Уборевича, 12	f	large
29019	18493	567	Архангельская область, Новодвинск, Солнечная, 1п.1	f	large
29016	18490	564	Архангельская область, Новодвинск, Солнечная, 15	f	large
29026	18499	574	Архангельская область, Новодвинск, Советов, 24	f	large
29020	18494	568	Архангельская область, Новодвинск, Мельникова, 14	f	large
29017	18491	565	Архангельская область, Новодвинск, Космонавтов, 5	f	large
109328	18502	577	Архангельская область, Новодвинск, Двинская, 45	f	\N
29028	18501	576	Архангельская область, Новодвинск, Двинская, 43	f	large
29022	18496	570	Архангельская область, Новодвинск, Ворошилова, 24	f	large
29023	18497	571	Архангельская область, Новодвинск, 50 лет Октября, 15	f	large
29021	18495	569	Архангельская область, Новодвинск, 3-й Пятилетки, 13	f	large
29018	18492	566	Архангельская область, Новодвинск, 3-й Пятилетки, 26	f	large
29001	18476	546	Архангельская область, Мирный, Овчинникова, 11	f	large
86260	18480	550	Архангельская область, Мирный, Неделина, 35	f	small
29002	18477	547	Архангельская область, Мирный, Неделина, 28	f	large
29004	18479	549	Архангельская область, Мирный, Ленина, 38	f	large
29000	18475	545	Архангельская область, Мирный, Ленина, 22	f	large
28999	18474	544	Архангельская область, Мирный, Дзержинского проспект, 8	f	large
28482	17972	11	Архангельская область, поселок Лесная Речка, Лахтинское шоссе, 135	f	large
28853	18329	393	Архангельская область, Котлас, им. 28-й Невельской дивизии, 1	f	large
28873	18349	413	Архангельская область, Котлас, Школьная, 5	f	medium
28870	18346	410	Архангельская область, Котлас, Ушакова, 6к.1	f	large
28848	18324	388	Архангельская область, Котлас, С-Щедрина, 2	f	large
28861	18337	401	Архангельская область, Котлас, Мелентьева, 18	f	large
28858	18334	398	Архангельская область, Котлас, Маяковского, 14	f	large
28857	18333	397	Архангельская область, Котлас, Маяковского, 23к.1	f	large
28865	18341	405	Архангельская область, Котлас, Мартемьяновская, 38	f	medium
28862	18338	402	Архангельская область, Котлас, Ленина, 103	f	large
28847	18323	387	Архангельская область, Котлас, Кузнецова, 7	f	large
28852	18328	392	Архангельская область, Котлас, Кедрова, 9	f	large
28860	18336	400	Архангельская область, Котлас, Карла Маркса, 31	f	large
28859	18335	399	Архангельская область, Котлас, Калинина, 21	f	large
28872	18348	412	Архангельская область, Котлас, Заполярная, 20	f	large
109319	18347	411	Архангельская область, Котлас, Заполярная, 19	f	\N
28869	18345	409	Архангельская область, Котлас, Герцена, 8к1	f	large
28866	18342	406	Архангельская область, Котлас, Володарского, 115	f	large
28864	18340	404	Архангельская область, Котлас, Виноградова, 38	f	large
28863	18339	403	Архангельская область, Котлас, Виноградова, 3	f	large
28867	18343	407	Архангельская область, Котлас, Багратиона, 64	f	large
28854	18330	394	Архангельская область, Котлас, 70-летия Октября, 21	f	large
28843	18320	383	Архангельская область, Коряжма, просп. Ленина, 37	f	large
28842	18319	382	Архангельская область, Коряжма, просп. Ленина, 29	f	large
28837	18314	377	Архангельская область, Коряжма, просп. Ленина, 8	f	large
28836	18313	376	Архангельская область, Коряжма, площадь им.В.И.Ленина, 1	f	large
28844	18297	384	Архангельская область, Коряжма, Советская, 15Г	f	large
28841	18318	381	Архангельская область, Коряжма, Пушкина, 11	f	large
28834	18311	374	Архангельская область, Коряжма, Набережная им.Н.Островского, 22	f	large
28840	18317	380	Архангельская область, Коряжма, Ленина проспект, 23	f	large
28835	18312	375	Архангельская область, Коряжма, Кутузова, 7Б	f	large
28846	18322	386	Архангельская область, Коряжма, Космонавтов, 1	f	large
28839	18316	379	Архангельская область, Коряжма, Кирова, 13	f	large
28838	18315	378	Архангельская область, Коряжма, Гоголя, 22	f	large
28845	18099	385	Архангельская область, Коряжма, Архангельская, 17	f	large
29209	18685	770	Архангельская область, поселок Катунино, Катунина, 11	f	large
29208	18685	769	Архангельская область, поселок Катунино, Катунина, 11	f	large
28767	18241	304	Архангельская область, Каргополь, Ленинградская, 63к.1	f	large
28766	18240	303	Архангельская область, Каргополь, Ленина, 53	f	large
28768	18242	305	Архангельская область, Каргополь, III Интернационала, 31	f	large
109308	18101	161	Архангельская область, Вельск, Некрасова, 11	f	\N
28641	18112	172	Архангельская область, Вельск, Заводская, 25	f	medium
28633	18104	164	Архангельская область, Вельск, Дзержинского, 88	f	large
28640	18111	171	Архангельская область, Вельск, Климовского, 5	f	large
29201	18678	762	Архангельская область, поселок Васьково, 50	t	medium
29190	18668	749	Архангельская область, деревня Большое Анисимово, 18	f	large
28547	18026	78	Архангельская область, Архангельск, остров Кего	f	large
28895	18371	435	Архангельская область, Архангельск, улица Школьная, 10	f	large
28496	17986	27	Россия, Архангельская область, Архангельск, улица Смольный Буян, 18к2	f	large
28531	18012	62	Россия, Архангельская область, Архангельск, Октябрьский район, улица Садовая, 61	f	large
28530	18012	61	Россия, Архангельская область, Архангельск, Октябрьский район, улица Садовая, 61	f	large
28563	18043	94	Россия, Архангельская область, Архангельск, улица Победы, 128к1	f	large
28492	17982	23	Россия, Архангельская область, Архангельск, улица Первомайская, 3	f	large
28476	17966	5	Россия, Архангельская область, Архангельск, улица Нахимова, 6к1	f	large
28565	18045	96	Россия, Архангельская область, Архангельск, улица Мудьюгская, 25	f	large
28584	18062	115	Россия, Архангельская область, Архангельск, улица Маяковского, 41	f	large
28586	18062	117	Россия, Архангельская область, Архангельск, улица Маяковского, 41	f	large
28596	18071	127	Россия, Архангельская область, Архангельск, улица Маймаксанская, 98	f	large
28583	18061	114	Россия, Архангельская область, Архангельск, улица Литейная, 19	f	large
28998	18473	543	Россия, Архангельская область, Архангельск, улица Ленина, 5	f	large
28577	18056	108	Россия, Архангельская область, Архангельск, улица Кутузова, 8	f	large
28545	18024	76	Россия, Архангельская область, Архангельск, улица Комсомольская, 5	f	large
28544	18024	75	Россия, Архангельская область, Архангельск, улица Комсомольская, 5	f	large
85212	82034	1476	Санкт-Петербург, Комендантский проспект, 21к3	f	large
28575	18054	106	Россия, Архангельская область, Архангельск, улица Кировская, 27	f	large
28600	18074	131	Россия, Архангельская область, Архангельск, улица Кирова, 7	f	large
28599	18074	130	Россия, Архангельская область, Архангельск, улица Кирова, 7	f	large
28589	18066	120	Россия, Архангельская область, Архангельск, улица Кедрова, 17	f	large
28564	18044	95	Россия, Архангельская область, Архангельск, улица Капитана Хромцова, 5к1	f	large
28567	18047	98	Архангельская область, Архангельск, Юнг ВМФ, 13	f	large
28569	18049	100	Архангельская область, Архангельск, Чупрова, 6	f	small
28516	18001	47	Архангельская область, Архангельск, Чумбарова-Лучинского проспект, 28	f	large
28480	17970	9	Архангельская область, Архангельск, Центральная, 28	f	medium
28615	18086	146	Архангельская область, Архангельск, Фёдора Абрамова, 14	f	large
28614	18086	145	Архангельская область, Архангельск, Фёдора Абрамова, 14	f	large
28613	18086	144	Архангельская область, Архангельск, Фёдора Абрамова, 14	f	large
28513	17998	44	Архангельская область, Архангельск, Урицкого, 68к3	f	large
28540	18020	71	Россия, Архангельская область, Архангельск, Троицкий проспект, 162	f	large
28539	18019	70	Россия, Архангельская область, Архангельск, Троицкий проспект, 130	f	large
28535	18016	66	Россия, Архангельская область, Архангельск, Троицкий проспект, 93	f	large
28534	18015	65	Россия, Архангельская область, Архангельск, Троицкий проспект, 51	f	large
28524	18007	55	Архангельская область, Архангельск, Тимме, 22к3	f	large
28523	18007	54	Архангельская область, Архангельск, Тимме, 22к3	f	large
28585	18063	116	Архангельская область, Архангельск, Терёхина, 3	f	large
28473	17963	2	Архангельская область, Архангельск, Сурповская, 26	f	medium
28546	18025	77	Архангельская область, Архангельск, Суворова, 2	f	large
28490	17979	19	Архангельская область, Архангельск, Стивидорская, 11	f	large
28570	18050	101	Архангельская область, Архангельск, Стадионная, 14	f	small
28543	18023	74	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 178	f	large
28542	18022	73	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 188к1	f	large
28532	18013	63	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 153	f	large
28538	18013	69	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 153	f	large
28515	18000	46	Россия, Архангельская область, Архангельск, Советских Космонавтов проспект, 69	f	large
28501	17991	32	Архангельская область, Архангельск, Смольный Буян, 18п.2	f	large
28497	17987	28	Архангельская область, Архангельск, Смольный Буян, 25к1	f	large
28598	18073	129	Архангельская область, Архангельск, Силикатчиков, 10	f	large
28488	17977	17	Архангельская область, Архангельск, Севстрой, 2	f	large
28536	18017	67	Россия, Архангельская область, Архангельск, Северной Двины набережная, 111	f	large
28514	17999	45	Россия, Архангельская область, Архангельск, Северной Двины набережная, 73	f	large
28502	17992	33	Архангельская область, Архангельск, Северной Двины набережная, 25	f	large
28494	17984	25	Архангельская область, Архангельск, Розы Шаниной, 6к1	f	large
28562	18042	93	Архангельская область, Архангельск, Родионова, 14	f	large
28486	17968	15	Архангельская область, Архангельск, Речников, 46	f	medium
28478	17968	7	Архангельская область, Архангельск, Речников, 46	f	large
28849	18325	389	Архангельская область, Архангельск, Пугачева, 20	f	medium
28626	18096	157	Архангельская область, Архангельск, Прокопия Галушина, 25к1	f	large
28619	18089	150	Архангельская область, Архангельск, Прокопия Галушина, 6	f	large
109307	18087	147	Архангельская область, Архангельск, Прокопия Галушина, 25	f	\N
28529	18011	60	Россия, Архангельская область, Архангельск, Приорова проезд, 2	f	large
28528	18011	59	Россия, Архангельская область, Архангельск, Приорова проезд, 2	f	large
28588	18065	119	Архангельская область, Архангельск, Приморская, 13	f	large
28594	18069	125	Архангельская область, Архангельск, Полярная, 4	f	large
28593	18069	124	Архангельская область, Архангельск, Полярная, 4	f	large
28559	18039	90	Архангельская область, Архангельск, Победы, 18к4	f	medium
28472	17962	1	Архангельская область, Архангельск, Пирсовая, 19	f	medium
28560	18040	91	Архангельская область, Архангельск, Пионерская, 82п.1	f	large
28572	18052	103	Архангельская область, Архангельск, Партизанская, 51	f	large
28506	17993	37	Россия, Архангельская область, Архангельск, Обводный Канал проспект, 30	f	large
28504	17993	35	Россия, Архангельская область, Архангельск, Обводный Канал проспект, 30	f	large
28499	17989	30	Россия, Архангельская область, Архангельск, Обводный Канал проспект, 12	f	large
28498	17988	29	Россия, Архангельская область, Архангельск, Обводный Канал проспект, 2	f	large
28505	17994	36	Россия, Архангельская область, Архангельск, Новгородский проспект, 66	f	large
28500	17990	31	Россия, Архангельская область, Архангельск, Новгородский проспект, 21	f	large
109306	17981	22	Архангельская область, Архангельск, Новгородский проспект, 34, 34п.2	f	\N
28590	18067	121	Россия, Архангельская область, Архангельск, Никольский проспект, 152	f	large
28608	18081	139	Архангельская область, Архангельск, Никитова, 1	f	large
28607	18081	138	Архангельская область, Архангельск, Никитова, 1	f	large
28617	18088	148	Россия, Архангельская область, Архангельск, Московский проспект, 43к2	f	large
28618	18088	149	Россия, Архангельская область, Архангельск, Московский проспект, 43к2	f	large
28558	18038	89	Архангельская область, Архангельск, Менделеева, 19	f	large
28489	17978	18	Архангельская область, Архангельск, Матросова, 1	f	large
28595	18070	126	Архангельская область, Архангельск, Маслова, 22	f	large
28574	18053	105	Архангельская область, Архангельск, Малиновского, 4	f	large
28573	18053	104	Архангельская область, Архангельск, Малиновского, 4	f	large
28566	18046	97	Архангельская область, Архангельск, Луганская, 6	f	large
109327	18478	548	Россия, Архангельская область	f	\N
28541	18021	72	Россия, Архангельская область, Архангельск, Ломоносова проспект, 269	f	large
28537	18018	68	Россия, Архангельская область, Архангельск, Ломоносова проспект, 211	f	large
28503	17985	34	Россия, Архангельская область, Архангельск, Ломоносова проспект, 80	f	large
28495	17985	26	Россия, Архангельская область, Архангельск, Ломоносова проспект, 80	f	large
28561	18041	92	Архангельская область, Архангельск, Лесотехническая, 1к1	f	large
28625	18095	156	Архангельская область, Архангельск, Лермонтова, 15	f	large
28621	18091	152	Россия, Архангельская область, Архангельск, Ленинградский проспект, 169	f	large
28620	18090	151	Россия, Архангельская область, Архангельск, Ленинградский проспект, 165к1	f	large
28612	18085	143	Россия, Архангельская область, Архангельск, Ленинградский проспект, 75	f	large
28604	18078	135	Россия, Архангельская область, Архангельск, Ленинградский проспект, 322	f	large
28602	18076	133	Россия, Архангельская область, Архангельск, Ленинградский проспект, 324	f	large
28493	17983	24	Россия, Архангельская область, Архангельск, Ленинградский проспект, 17	f	large
28533	18014	64	Россия, Архангельская область, Архангельск, Октябрьский район, Ленина площадь, 1	f	large
28582	18060	113	Архангельская область, Архангельск, Краснофлотская, 3	f	large
28484	17974	13	Архангельская область, Архангельск, Клепача, 3	f	large
28483	17973	12	Архангельская область, Архангельск, Клепача, 3к2	f	large
134690	95164	20	Архангельская область, Архангельск, Кирпичного Завода, 28	f	large
28579	18057	110	Архангельская область, Архангельск, Кировская, 21	f	large
28578	18057	109	Архангельская область, Архангельск, Кировская, 21	f	large
28576	18055	107	Архангельская область, Архангельск, Кировская, 12	f	large
28592	18068	123	Архангельская область, Архангельск, Кедрова, 34	f	large
28591	18068	122	Архангельская область, Архангельск, Кедрова, 34	f	large
29218	18694	780	Архангельская область, Архангельск, Кегостровская, 85	t	small
28603	18077	134	Архангельская область, Архангельск, Квартальная, 10	f	large
28601	18075	132	Архангельская область, Архангельск, Квартальная, 15	f	large
28622	18092	153	Архангельская область, Архангельск, Калинина, 21	f	large
28571	18051	102	Архангельская область, Архангельск, Ильича, 41	f	large
28487	17976	16	Архангельская область, Архангельск, Зеленец, 26	f	medium
28898	18374	438	Архангельская область, Архангельск, Железнодорожная, 17	t	small
28568	18048	99	Архангельская область, Архангельск, Емецкая, 19п2	f	large
28485	17975	14	Архангельская область, Архангельск, Дрейера, 9к3	f	medium
109357	18846	972	Архангельская область, Шенкурский район, село Демидовское, 5	t	\N
28522	18006	53	Россия, Архангельская область, Архангельск, Дзержинского проспект, 23	f	large
28521	18006	52	Россия, Архангельская область, Архангельск, Дзержинского проспект, 23	f	large
28475	17965	4	Архангельская область, Архангельск, Дежнёвцев, 12	f	large
28474	17964	3	Архангельская область, Архангельск, Дежнёвцев, 14	f	large
28623	18093	154	Архангельская область, Архангельск, Дачная, 57к3	f	large
28587	18064	118	Архангельская область, Архангельск, Георгия Седова набережная, 14	f	large
28549	18028	80	Архангельская область, Архангельск, Гагарина, 8к1	f	large
28527	18010	58	Архангельская область, Архангельск, Воскресенская, 95к3	f	large
28526	18008	57	Архангельская область, Архангельск, Воскресенская, 103к1	f	large
28525	18008	56	Архангельская область, Архангельск, Воскресенская, 103к1	f	large
28509	17996	40	Архангельская область, Архангельск, Воскресенская, 106к2	f	large
28508	17996	39	Архангельская область, Архангельск, Воскресенская, 106к2	f	large
28624	18094	155	Архангельская область, Архангельск, Воронина, 40	f	large
28609	18082	140	Архангельская область, Архангельск, Воронина, 30к1	f	large
28606	18080	137	Архангельская область, Архангельск, Воронина, 37к4	f	large
28605	18079	136	Архангельская область, Архангельск, Воронина, 27	f	large
28477	17967	6	Архангельская область, Архангельск, Адмирала Макарова, 33	f	large
28548	18027	79	Архангельская область, Архангельск, Авиационная, 23	f	large
28511	17997	42	Архангельская область, Архангельск, 23-й Гвардейской Дивизии, 9	f	large
28510	17997	41	Архангельская область, Архангельск, 23-й Гвардейской Дивизии, 9	f	large
28512	17995	43	Архангельская область, Архангельск, 23-й Гвардейской Дивизии, 8	f	large
28507	17995	38	Архангельская область, Архангельск, 23-й Гвардейской Дивизии, 8	f	large
28481	17971	10	Архангельская область, Архангельск, 2-я линия, 10к1	f	large
28479	17969	8	Архангельская область, Архангельск, 100-й Дивизии, 12	f	large
28581	18059	112	Архангельская область, Архангельск, 1-й Банный переулок, 2	f	large
28868	18344	408	Архангельская область, Антоново	f	small
29395	18841	967	Архангельская область, Шенкурский район, село Шипуновская, Школьная, 6	t	medium
29413	18867	991	Архангельская область, Шенкурский район, Шенкурск, Мира, 20	f	large
29414	18868	992	Архангельская область, Шенкурский район, Шенкурск, Кудрявцева, 18	f	large
29404	18856	981	Архангельская область, Шенкурский район, село Шелаша, Школьная, 22А	t	medium
29409	18863	987	Архангельская область, Шенкурский район, село Шеговары, Новая, 8	f	medium
29410	18864	988	Архангельская область, Шенкурский район, село Чушевская, Ивановская, 15	t	small
86253	18852	978	Архангельская область, Шенкурский район, село Усть-Паденьга, Новостроек, 28	t	small
29389	18834	960	Архангельская область, Шенкурский район, село Уколок, Школьная, 29	t	small
29403	18854	980	Архангельская область, Шенкурский район, село Тронинская, 44	t	small
109314	18217	279	Архангельская область, Шенкурский район, село Сельменьга, Набережная, 10	t	medium
29401	18851	977	Архангельская область, Шенкурский район, село Рыбогорская, 50	t	small
109355	18844	970	Архангельская область, Шенкурский район, село Ровдино, Пионерская, 4	t	\N
109358	18848	974	Архангельская область, Шенкурский район, село Плесо-Лесоучасток, 14	t	\N
29393	18839	965	Россия, Архангельская область, Шенкурский район, село Петровская	t	small
29412	18866	990	Архангельская область, Шенкурский район, село Одинцовская, 57	t	small
29408	18862	986	Россия, Архангельская область, Шенкурский район, село Носовская	t	small
29396	18842	968	Архангельская область, Шенкурский район, поселок Никольский Погост	t	small
29399	18847	973	Россия, Архангельская область, Шенкурский район, село Никольская	t	medium
109361	18857	982	Архангельская область, Шенкурский район, село Никифоровская, Лесной переулок, 2	t	medium
29400	18850	976	Россия, Архангельская область, Шенкурский район, село Куликовская	t	small
29397	18843	969	Россия, Архангельская область, Шенкурский район, село Красковская	t	small
134518	94411	983	Архангельская область, Шенкурский район, село Копалинская, 14	t	\N
86252	18837	963	Архангельская область, Шенкурский район, село Ивановское, 18	t	small
29390	18835	961	Архангельская область, Шенкурский район, село Дывлевская, 25	t	small
85211	82034	1475	Санкт-Петербург, Комендантский проспект, 21к3	f	large
29411	18865	989	Архангельская область, Шенкурский район, село Данковская, 28	t	small
29394	18840	966	Россия, Архангельская область, Шенкурский район	t	small
29406	18860	984	Архангельская область, Шенкурский район, Бобыкинская, 50 лет МТС, 8	t	small
134517	94410	971	Архангельская область, Шенкурский район, село Барановская, 53	t	\N
86251	18836	962	Архангельская область, Шенкурский район, село Артемьевская, 80	t	small
109359	18853	979	Архангельская область, Шенкурский район, село Алешковская, 15	t	\N
29380	18825	950	Архангельская область, Холмогорский район, село Часовня, 71	t	small
29371	18815	941	Архангельская область, Холмогорский район, село Часовенская, 19	t	small
29349	18792	919	Архангельская область, Холмогорский район, село Хомяковская, 90	f	small
29353	18796	923	Архангельская область, Холмогорский район, село Холмогоры, Октябрьская, 15	f	large
29352	18796	922	Архангельская область, Холмогорский район, село Холмогоры, Октябрьская, 15	f	large
29361	18804	931	Архангельская область, Холмогорский район, село Харлово, А.Д.Шиловского, 62А	t	large
109350	18808	934	Россия, Архангельская область, Холмогорский район, село Усть-Пинега	t	\N
29357	18800	927	Архангельская область, Холмогорский район, село Среднепогостская, 20	t	small
109352	18810	936	Архангельская область, Холмогорский район, поселок Светлый, 16	f	\N
86254	18861	985	Архангельская область, Холмогорский район, село Россохи, Сосновая, 18	t	small
29356	18799	926	Россия, Архангельская область, Холмогорский район, село Рембуево	t	small
86243	18824	949	Архангельская область, Холмогорский район, село Погост, 31	t	small
86244	18833	957	Архангельская область, Холмогорский район, село Погост, Почтовая, 10	t	small
29372	18817	942	Архангельская область, Холмогорский район, село Палово, Кольцевая, 1	t	small
29377	18822	947	Архангельская область, Холмогорский район, село Осередок, 3	t	small
29368	18812	938	Архангельская область, Холмогорский район, село Орлецы, 19	t	small
86242	18806	932	Архангельская область, Холмогорский район, село Малая Товра, 2	t	small
29358	18801	928	Архангельская область, Холмогорский район, поселок Луковецкий, Советская, 8	f	large
109349	18803	930	Архангельская область, Холмогорский район, село Ломоносово, 45А	f	medium
29367	18811	937	Архангельская область, Холмогорский район, село Кузомень, 27	t	small
29370	18814	940	Архангельская область, Холмогорский район, село Копачево, 53	f	small
86240	18793	920	Архангельская область, Холмогорский район, село Калитинская, 321	t	small
29373	18818	943	Архангельская область, Холмогорский район, село Казенщина, Гаражная, 1	t	small
29369	18813	939	Архангельская область, Холмогорский район, село Ичково, 47	t	small
109353	18830	954	Архангельская область, Холмогорский район, село Заболотье, 106А	f	medium
29376	18821	946	Архангельская область, Холмогорский район, село Емецк, Горончаровского, 53	f	large
29354	18797	924	Архангельская область, Холмогорский район, село Демидово, 3	t	small
109354	18832	956	Архангельская область, Холмогорский район, село Двинской, Лесная, 87	t	medium
29382	18828	952	Архангельская область, Холмогорский район, село Горка-Рудаковская, 25	t	small
29355	18798	925	Архангельская область, Холмогорский район, деревня Горка-Кузнечевская, 32	t	small
29363	18807	933	Архангельская область, Холмогорский район, село Горка, 43А	t	small
29383	18829	953	Архангельская область, Холмогорский район, село Верхняя Горка, 7	t	small
29348	18791	918	Архангельская область, Холмогорский район, село Васильевская, 165	f	medium
29378	18823	948	Архангельская область, Холмогорский район, Ваймужский, 40	t	small
29381	18826	951	Архангельская область, Холмогорский район, Бушковы, 4	t	small
29374	18819	944	Архангельская область, Холмогорский район, село Брин-Наволок, Набережная, 31	f	medium
29359	18802	929	Архангельская область, Холмогорский район, село Боярская, 16	t	small
29375	18820	945	Архангельская область, Холмогорский район, село Большая Гора, 18	t	small
109351	18809	935	Архангельская область, Холмогорский район, село Белогорский, Советская, 26	f	medium
86241	18794	921	Архангельская область, Холмогорский район, село Анашкино, 49А	t	small
29311	18756	875	Архангельская область, Устьянский район, д.Левоплосская, Центральная, 39	t	small
29319	18765	883	Россия, Архангельская область, Устьянский район, село Юрятинская	t	medium
29334	18781	898	Архангельская область, Устьянский район, село Шурай, Первомайская, 13	t	small
29321	18767	885	Архангельская область, Устьянский район, село Шангалы, Ленина, 40	t	medium
29320	18766	884	Архангельская область, Устьянский район, село Шангалы, 50 лет Октября, 1	t	large
29327	18773	891	Архангельская область, Устьянский район, село Чадрома, 46	t	small
29333	18780	897	Архангельская область, Устьянский район, село Филинская, 5, Административная	t	small
29332	18779	896	Архангельская область, Устьянский район, село Ульяновская, Строительная, 2	t	medium
29312	18757	876	Архангельская область, Устьянский район, село Студенец, Школьная, 3	t	small
29314	18759	878	Архангельская область, Устьянский район, село Строевское, Центральная, 35	t	medium
29322	18768	886	Архангельская область, Устьянский район, село Советский, Набережная, 4	t	medium
29324	18770	888	Архангельская область, Устьянский район, поселок Октябрьский, Магистральная, 13	t	large
29326	18772	890	Архангельская область, Устьянский район, поселок Октябрьский, Ленина, 58	f	large
29325	18771	889	Архангельская область, Устьянский район, поселок Октябрьский, Ленина, 43	f	large
29318	18764	882	Архангельская область, Устьянский район, село Нижнеборская, Сосновая, 18	t	small
29331	18778	895	Архангельская область, Устьянский район, село Нагорская, Школьная, 6	t	small
29345	18789	909	Архангельская область, Устьянский район, село Мирный, Центральная, 18	t	medium
109347	18775	892	Архангельская область, Устьянский район, село Маренинская, 70	t	\N
109348	18777	894	Архангельская область, Устьянский район, село Малый Дор, 10	t	\N
29329	18776	893	Архангельская область, Устьянский район, село Малодоры, Центральная, 15	f	medium
29338	18784	902	Архангельская область, Устьянский район, поселок Лойга, Садовая, 19	t	large
29323	18769	887	Архангельская область, Устьянский район, поселок Костылево, Гайдара, 7	t	small
29339	18785	903	Архангельская область, Устьянский район, поселок Кизема, Спортивная	t	large
86246	18786	904	Архангельская область, Устьянский район, поселок Кизема, Советов, 2	t	small
29341	18787	905	Архангельская область, Устьянский район, поселок Кизема, Северная, 5	t	medium
86247	18790	911	Архангельская область, Устьянский район, село Кидюга, Новая, 31	t	small
29307	18751	870	Архангельская область, Устьянский район, село Квазеньга, Пионерская, 5	t	small
29308	18753	871	Архангельская область, Устьянский район, село Кадыевская, 44	t	small
29336	18783	900	Архангельская область, Устьянский район, поселок Илеза, Школьная, 1	t	medium
29335	18782	899	Архангельская область, Устьянский район, поселок Илеза, Комсомольская, 4	t	small
29315	18760	879	Архангельская область, Устьянский район, село Едьма, Школьный переулок, 1	t	medium
29317	18762	881	Архангельская область, Устьянский район, село Дубровская, Орловская, 23	t	small
86245	18758	877	Архангельская область, Устьянский район, село Грунцовская, 1Б	t	small
29309	18754	872	Архангельская область, Устьянский район, село Глубокий, Школьная, 15	t	small
29310	18755	873	Архангельская область, Устьянский район, село Веригинская, 22	t	medium
29316	18761	880	Архангельская область, Устьянский район, село Березник, Центральная, 8А	t	medium
29342	18788	906	Архангельская область, Устьянский район, село Алферовская, Школьная, 6	t	small
29306	18750	869	Архангельская область, Соловецкий район, Соловецкий, Приморская, 7, школа	t	\N
86259	18682	766	Архангельская область, Приморский район, село Яреньга, Пионерская, 10	t	small
29193	18671	754	Архангельская область, Приморский район, поселок Ширшинский, 1	t	small
29192	18670	753	Архангельская область, Приморский район, поселок Ширшинский, 21	t	small
29198	18676	759	Архангельская область, Приморский район, село Хорьково, 2	t	small
109337	18672	756	Архангельская область, Приморский район, поселок Уемский, Заводская, 49	f	\N
29194	18672	755	Архангельская область, Приморский район, поселок Уемский, Заводская, 49	f	large
29214	18690	775	Архангельская область, Приморский район, деревня Талаги, 5	t	large
29213	18689	774	Архангельская область, Приморский район, село Талаги, 29	t	large
29187	18666	746	Архангельская область, Приморский район, село Рикасиха, 66	f	large
29207	18684	768	Архангельская область, Приморский район, село Пушлахта, 61	t	small
85209	82033	1473	Санкт-Петербург, Комендантский проспект, 17к3	f	large
109340	18693	779	Архангельская область, Приморский район, деревня Пустошь, 53	t	medium
29202	18679	763	Архангельская область, Приморский район, село Пертоминск, Беломорская, 4	t	small
86256	18691	776	Архангельская область, Приморский район, село Патракеевка, 10	t	small
29191	18669	750	Архангельская область, Приморский район, деревня Окулово, 1	t	medium
29197	18675	758	Россия, Архангельская область, Приморский район, село Новинки	t	medium
29212	18688	773	Россия, Архангельская область, Приморский район, село Нижняя Золотица	t	small
29304	18748	867	Архангельская область, Приморский район, село Ненокса	t	medium
86258	18680	764	Архангельская область, Приморский район, село Луда, 14	t	small
86215	18667	748	Архангельская область, Приморский район, деревня Луговой, 8, кв.2	t	small
86257	18681	765	Архангельская область, Приморский район, село Лопшеньга, Советская, 62	t	small
109339	18683	767	Архангельская область, Приморский район, село Летняя Золотица, Нижняя, 8	t	\N
29210	18686	771	Архангельская область, Приморский район, деревня Лахта, Геологов, 18	t	medium
29221	18697	783	Архангельская область, Приморский район, село Ластола, Северодвинская, 5	t	small
29186	18665	745	Архангельская область, Приморский район, село Лайский Док, Хуторская, 30	t	medium
29196	18673	757	Архангельская область, Приморский район, село Кузьмино, 63	t	small
29222	18698	784	Архангельская область, Приморский район, село Конецдворье, 61	t	small
29219	18695	781	Архангельская область, Приморский район, деревня Вознесенье, Центральная, 75	t	medium
29211	18687	772	Россия, Архангельская область, Приморский район, село Верхняя Золотица	t	small
109338	18677	760	Архангельская область, Приморский район, село Боброво, МОУ Бобровская СОШ	t	\N
29220	18696	782	Архангельская область, Приморский район, село Беломорье, 13, муниципальное образование Катунинское	t	small
29303	18747	866	Архангельская область, Приморский район, село Белое Озеро	t	small
29161	18637	719	Архангельская область, Плесецкий район, село Шелекса, Привокзальная, 15	t	small
109335	18652	733	Архангельская область, Плесецкий район, село Федово, Чапыгина, 13	t	\N
134515	94409	785	Архангельская область, Плесецкий район, село Усть-Поча, 61	t	\N
29184	18662	742	Архангельская область, Плесецкий район, село Ундозеро, Школьная, 10	t	small
29185	18663	743	Архангельская область, Плесецкий район, село Улитино, Стахановская, 16	t	medium
29173	18650	731	Архангельская область, Плесецкий район, село Североонежск, мкр.214	f	large
29174	18651	732	Архангельская область, Плесецкий район, село Североонежск, микрорайон, 213	f	large
29151	18626	709	Архангельская область, Плесецкий район, поселок Самодед, Самодедская, 12	t	large
29180	18658	738	Архангельская область, Плесецкий район, село Самково, Школьная, 11	t	medium
29159	18635	717	Россия, Архангельская область, Плесецкий район, поселок Савинский	f	large
29157	18633	715	Архангельская область, Плесецкий район, поселок Савинский, Цементников, 8	f	large
29158	18634	716	Архангельская область, Плесецкий район, поселок Савинский, 40 лет Победы, 14	f	large
29160	18636	718	Архангельская область, Плесецкий район, село Река-Емца, Набережная, 3	t	small
29170	18647	728	Архангельская область, Плесецкий район, поселок Пуксоозеро, Ленина, 5	t	large
29167	18644	725	Архангельская область, Плесецкий район, село Пукса, Центральная, 25Б	t	small
29182	18660	740	Архангельская область, Плесецкий район, село Поча, Школьная, 78	t	small
29168	18645	726	Архангельская область, Плесецкий район, село Подволочье, 57	t	small
29166	18643	724	Архангельская область, Плесецкий район, поселок Плесецк, Южная, 2	f	large
29163	18639	721	Архангельская область, Плесецкий район, поселок Плесецк, Фокина, 19	f	large
29165	18641	723	Архангельская область, Плесецкий район, поселок Плесецк, Партизанская, 17	f	large
29164	18640	722	Архангельская область, Плесецкий район, поселок Плесецк, Партизанская, 6	f	large
29162	18638	720	Архангельская область, Плесецкий район, поселок Плесецк, Ленина, 85	f	large
29155	18630	713	Архангельская область, Плесецкий район, село Первомайский, 6	t	small
29171	18648	729	Архангельская область, Плесецкий район, поселок Оксовский, Школьная, 11	f	large
29152	18627	710	Архангельская область, Плесецкий район, поселок Обозерский, Школьная, 11	t	large
29153	18628	711	Архангельская область, Плесецкий район, поселок Обозерский, Ломоносова, 68	t	large
29183	18661	741	Архангельская область, Плесецкий район, село Нижнее Устье, Набережная, 6А	t	medium
29150	18625	708	Архангельская область, Плесецкий район, село Ломовое, Школьная, 10	t	small
29176	18654	734	Архангельская область, Плесецкий район, село Липаково, Октябрьская, 12	t	medium
29154	18629	712	Архангельская область, Плесецкий район, село Летнеозерский, Лесная, 27А	t	small
29179	18657	737	Архангельская область, Плесецкий район, село Корякино, Молодёжная, 12	t	small
109336	18655	735	Архангельская область, Плесецкий район, село Конево, Ленинградская, 33	f	\N
29178	18656	736	Россия, Архангельская область, Плесецкий район, село Коковка	t	small
29156	18632	714	Архангельская область, Плесецкий район, поселок Емца, Партизанская, 10	t	large
29181	18659	739	Россия, Архангельская область, Плесецкий район, село Вершинино	t	medium
134514	94408	744	Архангельская область, Плесецкий район, село Верховский, Островского, 29	t	\N
29172	18649	730	Архангельская область, Плесецкий район, село Булатово, Линейная, 18	t	small
29169	18646	727	Архангельская область, Плесецкий район, деревня Бархатиха, 18	t	small
29119	18592	674	Архангельская область, Пинежский район, дер.Кушкопала, Советская, 28	t	medium
109334	18607	688	Архангельская область, Пинежский район, село Ясный, Октября, 12	t	\N
29116	18589	671	Архангельская область, Пинежский район, село Явзора, 28	t	small
29111	18583	666	Архангельская область, Пинежский район, село Шуйга, Строительная, 8Б	t	medium
29135	18610	690	Архангельская область, Пинежский район, село Шотогорка, Центральная, 5	t	small
29127	18601	682	Архангельская область, Пинежский район, село Шотова, Боровая, 11	t	small
29137	18612	692	Архангельская область, Пинежский район, село Широкое, Центральная, 28	t	small
29123	18596	678	Архангельская область, Пинежский район, село Шардонемь, Центральная, 139	f	small
29139	18614	694	Архангельская область, Пинежский район, село Чакола, Центральная, 23	t	small
29141	18615	695	Архангельская область, Пинежский район, село Труфанова, Центральная, 27	t	small
29142	18616	696	Архангельская область, Пинежский район, село Тайга, Лесная, 4А	t	small
29134	18608	689	Архангельская область, Пинежский район, поселок Таежный, 8А	t	small
29130	18604	685	Архангельская область, Пинежский район, село Сылога, Северная, 7	t	medium
29113	18585	668	Архангельская область, Пинежский район, село Сура, пер.Школьный, 9	f	medium
29109	18581	664	Архангельская область, Пинежский район, село Сульца, Южная, 37А	t	small
29107	18579	662	Архангельская область, Пинежский район, село Сосновка, Школьная, 3	t	medium
29131	18605	686	Архангельская область, Пинежский район, поселок Сия, 15	t	large
109333	18606	687	Архангельская область, Пинежский район, село Русковера, Пионерская, 9	t	medium
29136	18611	691	Архангельская область, Пинежский район, село Пиринем, Школьная, 1	t	small
29146	18621	700	Архангельская область, Пинежский район, поселок Пинега, Первомайская, 111	t	large
29145	18619	699	Архангельская область, Пинежский район, поселок Пинега, Первомайская, 36	t	large
29148	18623	702	Архангельская область, Пинежский район, село Петрово, 4	t	small
29118	18591	673	Архангельская область, Пинежский район, село Пачиха, Лесная, 1	t	small
109332	18586	669	Архангельская область, Пинежский район, поселок Новолавела, Советская, 1	t	\N
29122	18595	677	Архангельская область, Пинежский район, село Немнюга, 41А	t	small
29128	18602	683	Архангельская область, Пинежский район, село Междуреченский, Центральная, 11	t	large
29108	18580	663	Архангельская область, Пинежский район, село Мамониха, Ленина, 10	t	small
29110	18582	665	Архангельская область, Пинежский район, село Кулосега, Садовая, 8	t	small
29143	18617	697	Архангельская область, Пинежский район, село Кривые Озера, Центральная, 18	t	small
86250	18622	701	Архангельская область, Пинежский район, село Красная Горка, 6	t	small
29129	18603	684	Архангельская область, Пинежский район, село Кобелево, 43А	t	small
29121	18594	676	Архангельская область, Пинежский район, село Кеврола, 67	t	medium
29126	18600	681	Архангельская область, Пинежский район, село Карпогоры, Ф.Абрамова, 49	f	large
29125	18599	680	Архангельская область, Пинежский район, село Карпогоры, Ф.Абрамова, 45А	f	large
134513	18624	703	Архангельская область, Пинежский район, село Заозерье, 3	t	small
29106	18578	661	Архангельская область, Пинежский район, село Занюхча, Школьная, 2	t	small
86248	18588	670	Архангельская область, Пинежский район, село Заедовье, 25	t	small
29120	18593	675	Архангельская область, Пинежский район, село Еркино, Новая, 37А	t	small
29112	18584	667	Архангельская область, Пинежский район, село Городецк, Лесная, 4	t	small
29144	18618	698	Архангельская область, Пинежский район, село Воепала, Окружная, 10	t	small
86249	18590	672	Архангельская область, Пинежский район, село Веркола, Советская, 7	f	small
29138	18613	693	Архангельская область, Пинежский район, село Веегора, 75	t	small
29124	18597	679	Архангельская область, Пинежский район, село Ваймуша, Гагарина, 15	f	medium
29087	18559	642	Архангельская область, Онежский район, село Шомокша, Комсомольская, 7А	t	small
29092	18563	647	Архангельская область, Онежский район, село Шаста, Школьная, 10	t	small
29083	18555	638	Архангельская область, Онежский район, село Хачела, Набережная, 12	t	small
86234	18551	634	Архангельская область, Онежский район, село Усть-Кожа, Школьная, 8	t	small
29098	18570	653	Архангельская область, Онежский район, село Унежма, Горная, 1	t	small
29100	18572	655	Архангельская область, Онежский район, село Тамица, Мира, 39	t	small
29102	18574	657	Архангельская область, Онежский район, село Пурнема, Победы, 30	t	small
29089	18561	644	Архангельская область, Онежский район, село Прошково, Набережная, 5	t	small
29086	18558	641	Архангельская область, Онежский район, село Прилуки, Школьная, 1	t	small
29088	18560	643	Архангельская область, Онежский район, село Посад, Молодежная, 14	t	small
29078	18550	633	Архангельская область, Онежский район, село Порог, Победы, 39	f	small
86236	18571	654	Архангельская область, Онежский район, село Покровское, Усачёва, 3	f	small
29105	18577	660	Архангельская область, Онежский район, село Покровское, Мира, 10	t	small
29066	18539	621	Архангельская область, Онежский район, Онега, проспект Октябрьский, 147	f	large
29073	18545	628	Архангельская область, Онежский район, Онега, Целинная, 3/11	f	small
29070	18542	625	Архангельская область, Онежский район, Онега, Приморская, 1	f	large
29072	18544	627	Архангельская область, Онежский район, Онега, Онежская, 14	f	large
29091	18562	646	Архангельская область, Онежский район, село Нименьга, Центральная, 29	t	medium
29075	18547	630	Архангельская область, Онежский район, поселок Мудьюга, Железнодорожная, 32	t	medium
29094	18565	649	Архангельская область, Онежский район, поселок Малошуйка, Ленина, 69	t	large
29104	18575	659	Архангельская область, Онежский район, село Маложма, 22А	t	small
29101	18573	656	Архангельская область, Онежский район, село Кянда, Школьная, 15	t	small
29096	18568	651	Архангельская область, Онежский район, село Куша, Набережная, 22	t	small
29074	18546	629	Архангельская область, Онежский район, поселок Кодино, Пролетарская, 25	t	large
29084	18556	639	Архангельская область, Онежский район, село Ковкула, Первомайская, 26	t	small
29085	18557	640	Архангельская область, Онежский район, село Клещево, Набережная, 4	t	small
29082	18554	637	Архангельская область, Онежский район, село Каска, 35	t	small
29097	18569	652	Архангельская область, Онежский район, село Золотуха, Октябрьская, 2	t	small
29076	18548	631	Архангельская область, Онежский район, село Глазаниха, Центральная, 2	t	small
29093	18564	648	Архангельская область, Онежский район, село Ворзогоры, Никольская, 11	t	small
29077	18549	632	Архангельская область, Онежский район, село Вонгуда, Центральная, 33А	t	small
29080	18552	635	Архангельская область, Онежский район, село Большой Бор, Школьна, 3	t	small
86235	18553	636	Архангельская область, Онежский район, село Анциферовский Бор, Придорожная	t	small
29095	18566	650	Архангельская область, Онежский район, село Абрамовская, Победы, 6	t	small
29050	18524	598	Архангельская область, Няндомский район, село Шожма, Школьная, 14	t	small
29044	18517	592	Архангельская область, Няндомский район, село Шестиозерский, Вокзальная, 13	t	small
109330	18528	602	Архангельская область, Няндомский район, поселок Шалакуша, Заводская, 12	t	\N
29053	18527	601	Архангельская область, Няндомский район, поселок Шалакуша, Заводская, 10	t	large
28830	18307	369	Россия, Архангельская область, Коношский район, село Папинская	t	small
86223	18526	600	Архангельская область, Няндомский район, село Федосеевская, Центральная, 40	t	small
29056	18531	605	Архангельская область, Няндомский район, село Тарза, Строителей, 8	t	small
29057	18532	606	Архангельская область, Няндомский район, село Ступинская, Советская, 7	t	small
29047	18520	595	Архангельская область, Няндомский район, село Петариха, Школьная, 2	t	medium
29041	18514	589	Архангельская область, Няндомский район, Няндома, Школьная, 1	f	large
29030	18503	578	Архангельская область, Няндомский район, Няндома, Советская, 18	f	large
29035	18508	583	Архангельская область, Няндомский район, Няндома, Североморская, 7А	f	large
29040	18513	588	Архангельская область, Няндомский район, Няндома, Песочная, 7	f	small
29038	18511	586	Архангельская область, Няндомский район, Няндома, П.Морозова, 13	f	large
29036	18509	584	Архангельская область, Няндомский район, Няндома, Ленина, 49	f	large
29034	18507	582	Архангельская область, Няндомский район, Няндома, 60-летия Октября, 20А	f	large
29031	18504	579	Архангельская область, Няндомский район, Няндома, 60-летия Октября, 14	f	large
29049	18523	597	Архангельская область, Няндомский район, село Наволок, Молодежная, 7	t	small
29054	18529	603	Архангельская область, Няндомский район, село Лепша-Новый, Советская, 5	t	medium
86222	18525	599	Архангельская область, Няндомский район, село Лельма, Лесная, 2	t	small
29055	18530	604	Архангельская область, Няндомский район, село Ивакша, пер.Клубный, 2	t	small
109329	18521	596	Архангельская область, Няндомский район, поселок Заозерный, Лесная, 18	t	medium
29045	18518	593	Архангельская область, Няндомский район, село Волковская, Центральная, 9	t	small
29043	18516	591	Архангельская область, Няндомский район, село Бурачиха, переулок Лесной, 19	t	medium
29046	18519	594	Архангельская область, Няндомский район, село Большой Двор, Центральная, 1	t	small
29042	18515	590	Архангельская область, Няндомский район, село Андреевская, Новая, 4А	t	small
28990	18466	533	Архангельская область, Мезенский район, село Чижгора, Центральная, 8	t	small
28984	18461	528	Архангельская область, Мезенский район, село Целегора, 49	t	small
28993	18468	535	Архангельская область, Мезенский район, село Сояна, Октябрьская, 25	t	small
28989	18465	532	Архангельская область, Мезенский район, село Сафоново, Новая, 12	t	small
28996	18472	537	Архангельская область, Мезенский район, село Ручьи, Советская, 40	t	small
28987	18464	531	Архангельская область, Мезенский район, село Мосеево, 13	t	small
28971	18447	516	Архангельская область, Мезенский район, Мезень, Садовая, 9	f	large
28972	18449	517	Архангельская область, Мезенский район, Мезень, Набережная, 17	f	medium
28973	18450	518	Архангельская область, Мезенский район, село Лампожня, 23	t	small
28991	18471	536	Архангельская область, Мезенский район, село Койда, 121-а	t	small
28981	18458	526	Архангельская область, Мезенский район, село Козьмогородское, Набережная, 11	t	small
28979	18456	524	Архангельская область, Мезенский район, село Кимжа, 40	t	small
28976	18453	521	Архангельская область, Мезенский район, поселок Каменка, Федоркова, 12	f	large
28977	18454	522	Архангельская область, Мезенский район, поселок Каменка, Свободы, 1	f	medium
28975	18452	520	Архангельская область, Мезенский район, село Заозерье, 23к1	t	small
28974	18451	519	Архангельская область, Мезенский район, село Заакакурье, 5	t	small
28980	18457	525	Архангельская область, Мезенский район, село Жердь, Торцева, 31	t	small
28978	18455	523	Архангельская область, Мезенский район, село Дорогорское, Советская, 32	t	small
28992	18467	534	Архангельская область, Мезенский район, село Долгощелье, Октябрьская, 8	t	medium
28986	18463	530	Архангельская область, Мезенский район, село Бычье, Советская, 4	t	small
28982	18459	527	Архангельская область, Мезенский район, село Березник, Набережная, 8 , здание Дома Культуры	t	small
28985	18462	529	Архангельская область, Мезенский район, село Азаполье, 26	t	small
28961	18436	501	Россия, Архангельская область, Лешуконский район, село Юрома	t	small
28967	18443	507	Россия, Архангельская область, Лешуконский район, село Чуласа	t	small
28955	18430	495	Россия, Архангельская область, Лешуконский район, село Ценогора	t	small
28968	18444	508	Россия, Архангельская область, Лешуконский район, село Усть-Чуласа	t	small
85210	82033	1474	Санкт-Петербург, Комендантский проспект, 17к3	f	large
28953	18428	493	Россия, Архангельская область, Лешуконский район, село Усть-Кыма	t	small
28958	18433	498	Россия, Архангельская область, Лешуконский район, село Смоленец	t	small
28956	18431	496	Россия, Архангельская область, Лешуконский район, село Селище	t	small
28692	18165	225	Архангельская область, Лешуконский район, Северный, Центральная, 2А	t	small
28947	18421	487	Россия, Архангельская область, Лешуконский район, село Родома	t	small
28957	18432	497	Россия, Архангельская область, Лешуконский район, село Пылема	t	small
109325	18438	503	Россия, Архангельская область, Лешуконский район, село Палуга	t	\N
28969	18445	509	Россия, Архангельская область, Лешуконский район, село Олема	t	small
68030	18442	506	Архангельская область, Лешуконский район, село Лешуконское, Победы, 35	f	large
28964	18439	504	Архангельская область, Лешуконский район, село Лешуконское, Победы, 12	f	large
28965	18440	505	Архангельская область, Лешуконский район, село Лешуконское, Октябрьская, 28	f	large
28950	18424	490	Россия, Архангельская область, Лешуконский район, село Кысса	t	small
28952	18426	492	Россия, Архангельская область, Лешуконский район, село Койнас	t	medium
28962	18437	502	Россия, Архангельская область, Лешуконский район, село Кеслома	t	small
28970	18446	510	Россия, Архангельская область, Лешуконский район, село Кеба	t	small
28948	18422	488	Россия, Архангельская область, Лешуконский район, село Зубово	t	small
28951	18425	491	Россия, Архангельская область, Лешуконский район, село Засулье	t	small
28949	18423	489	Россия, Архангельская область, Лешуконский район, село Вожгора	t	medium
28960	18435	500	Россия, Архангельская область, Лешуконский район, село Большая Нисогора	t	small
28959	18434	499	Россия, Архангельская область, Лешуконский район, село Березник	t	small
28954	18429	494	Россия, Архангельская область, Лешуконский район, село Белощелье	t	small
28927	18401	467	Архангельская область, Ленский район, село Яренск, Трудовая, 32	f	large
28926	18400	466	Архангельская область, Ленский район, село Яренск, Дубинина, 4А	f	large
28930	18404	470	Россия, Архангельская область, Ленский район, село Усть-Очея	t	small
28944	18418	484	Архангельская область, Ленский район, село Урдома, Нянда, 26	t	small
28943	18417	483	Архангельская область, Ленский район, село Урдома, Мира, 11А	t	large
28942	18416	482	Архангельская область, Ленский район, поселок Урдома, Вычегодская, 45	t	large
28941	18415	481	Россия, Архангельская область, Ленский район, село Тыва	t	small
28936	18410	476	Россия, Архангельская область, Ленский район, село Сойга	t	small
28939	18413	479	Россия, Архангельская область, Ленский район, село Селивановская	t	small
28929	18403	469	Архангельская область, Ленский район, село Лысимо, Центральная, 7	t	small
28946	18420	486	Россия, Архангельская область, Ленский район, село Лупья	t	small
28937	18411	477	Россия, Архангельская область, Ленский район, село Литвино	t	small
28932	18406	472	Россия, Архангельская область, Ленский район, село Лена	t	small
28933	18407	473	Россия, Архангельская область, Ленский район, село Козьмино	t	small
28931	18405	471	Россия, Архангельская область, Ленский район, село Ирта	t	small
28928	18402	468	Россия, Архангельская область, Ленский район, село Запань Яреньга	t	small
28938	18412	478	Россия, Архангельская область, Ленский район, село Запань Лупья	t	small
28934	18408	474	Россия, Архангельская область, Ленский район, село Гыжег	t	small
28945	18419	485	Россия, Архангельская область, Ленский район, село Витюнино	t	small
28940	18414	480	Архангельская область, Ленский район, поселок Бор	t	small
28935	18409	475	Россия, Архангельская область, Ленский район, село Белопашино	t	small
28921	18394	461	Архангельская область, Красноборский район, село Черевково, Первомайская, 36	f	large
28904	18380	444	Архангельская область, Красноборский район, село Фроловская, Придорожная, 12	f	medium
28920	18393	460	Россия, Архангельская область, Красноборский район, село Сакулинская	t	small
28923	18397	463	Россия, Архангельская область, Красноборский район, село Савинская	t	small
86216	18395	462	Архангельская область, Красноборский район, село Савинская, 1	t	small
28915	18388	455	Россия, Архангельская область, Красноборский район, село Монастырская Пашня	t	small
84007	81267	103	Санкт-Петербург, Шевченко, 3а	f	large
28912	18385	452	Архангельская область, Красноборский район, село Куликово, Центральная, 14	t	medium
28903	18379	443	Архангельская область, Красноборский район, село Красноборск, Плакидина, 26	f	large
28902	18378	442	Архангельская область, Красноборский район, село Красноборск, Гагарина, 42	f	large
28914	18387	454	Россия, Архангельская область, Красноборский район, село Комсомольский	t	small
28913	18386	453	Архангельская область, Красноборский район, село Комарово, Терешковой, 5	t	small
28916	18389	456	Архангельская область, Красноборский район, село Ершевская, Мира, 10	t	medium
86217	18398	464	Архангельская область, Красноборский район, село Емельяновская, с/п Ляховский клуб, МУК Черевковский центр культуры	t	small
28906	18381	446	Архангельская область, Красноборский район, село Дябрино, Первомайская, 6А	t	small
109324	18399	465	Россия, Архангельская область, Красноборский район, село Демьяновская	t	\N
28911	18384	451	Архангельская область, Красноборский район, село Верхняя Уфтюга, Центральная, 5	t	small
28919	18392	459	Россия, Архангельская область, Красноборский район, село Верхняя Сергиевская	t	small
28918	18391	458	Архангельская область, Красноборский район, село Верхнее Шилово, Быстрова, 4	t	small
28909	18382	449	Архангельская область, Красноборский район, село Большая Слудка, 150	t	small
86255	18390	457	Архангельская область, Красноборский район, село Большая, Советская, 7	t	small
28910	18383	450	Архангельская область, Красноборский район, село Березонаволок, Центральная, 3	t	small
109322	18372	436	Архангельская область, Котласский район, поселок Шипицыно, Первомайская, 54	f	\N
109323	18375	439	Архангельская область, Котласский район, поселок Черемушский, Южная, 21	t	\N
28880	18357	420	Архангельская область, Котласский район, поселок Харитоново, Кирова, 30	t	large
28893	18369	433	Архангельская область, Котласский район, село Федотовская, Рубцова, 28	t	medium
28891	18367	431	Архангельская область, Котласский район, поселок Удимский, Советская, 49	t	medium
28890	18366	430	Архангельская область, Котласский район, поселок Удимский, Советская, 26	t	medium
109320	18358	421	Архангельская область, Котласский район, Сольвычегодск, Ленина, 23	t	\N
28889	18365	429	Архангельская область, Котласский район, поселок Реваж, Пролетарская, 2	t	small
134512	94407	425	Архангельская область, Котласский район, поселок Приводино, Рощинская, 42	t	large
134511	94406	424	Архангельская область, Котласский район, поселок Приводино, Мира, 1	f	large
28894	18370	434	Архангельская область, Котласский район, село Печерино, Южная, 1А	t	small
28888	18364	428	Архангельская область, Котласский район, село Медведка, Центральная, 23	t	small
28886	18363	426	Архангельская область, Котласский район, село Курцево, Центральная, 48	t	small
28887	18121	427	Архангельская область, Котласский район, село Куимиха, Школьная, 27	t	medium
28883	18360	423	Архангельская область, Котласский район, село Григорово, 32	t	medium
28875	18352	415	Архангельская область, Котласский район, поселок Вычегодский, Ульянова, 27	f	large
28874	18350	414	Архангельская область, Котласский район, поселок Вычегодский, Ульянова, 31	f	large
28876	18353	416	Архангельская область, Котласский район, поселок Вычегодский, Ленина, 39	f	large
28877	18354	417	Архангельская область, Котласский район, поселок Вычегодский, Медицинская, 12	f	large
28897	18373	437	Архангельская область, Котласский район, село Выставка, Молодежная, 12	t	small
28900	18377	440	Архангельская область, Котласский район, село Борки, Центральная, 4	t	small
109321	18359	422	Архангельская область, Котласский район, село Андреевская, 42	t	\N
28800	18273	339	Архангельская область, Коношский район, село Фоминский, Школьная, 8	t	small
28820	18294	359	Россия, Архангельская область, Коношский район, село Топоровская	t	small
28819	18293	358	Архангельская область, Коношский район, село Сосновка, Чкалова, 12	t	small
28832	18309	371	Россия, Архангельская область, Коношский район, село Пономаревская	t	medium
28824	18300	363	Архангельская область, Коношский район, поселок Подюга, Школьная, 6	t	large
28825	18301	364	Архангельская область, Коношский район, поселок Подюга, Советская, 22	t	large
28828	18305	367	Россия, Архангельская область, Коношский район, село Першинская	t	small
28822	18298	361	Архангельская область, Коношский район, село Норминга, Центральная, 6	t	small
28821	18296	360	Архангельская область, Коношский район, село Новый, Центральная, 9	t	small
28826	18302	365	Архангельская область, Коношский район, село Николаевка, Зеленая, 10	t	small
28818	18292	357	Архангельская область, Коношский район, село Мирный, Юношеская, 10	t	small
28801	18274	340	Архангельская область, Коношский район, село Мелентьевский, Школьная, 5	t	small
28817	18291	356	Россия, Архангельская область, Коношский район, село Кремлево	t	small
28833	18310	372	Россия, Архангельская область, Коношский район, село Красивое	t	small
28831	18308	370	Россия, Архангельская область, Коношский район, село Кощеевская	t	small
28812	18285	351	Архангельская область, Коношский район, поселок Коноша, Тельмана, 4А	f	large
28808	18281	347	Архангельская область, Коношский район, поселок Коноша, Советская, 86	f	large
28810	18283	349	Архангельская область, Коношский район, поселок Коноша, Садовая, 1А	f	medium
28811	18284	350	Архангельская область, Коношский район, поселок Коноша, Октябрьский проспект, 105	f	large
28814	18288	353	Архангельская область, Коношский район, поселок Коноша, Новолесная, 13	f	medium
28807	18280	346	Архангельская область, Коношский район, поселок Коноша, Молодежная, 8	f	large
68031	18282	348	Архангельская область, Коношский район, поселок Коноша, Лесная, 1	f	large
28813	18287	352	Архангельская область, Коношский район, поселок Коноша, Вологодская, 25	f	large
28805	18278	344	Архангельская область, Коношский район, село Климовская, Центральная, 28	t	small
28827	18304	366	Архангельская область, Коношский район, село Кварзонгский, 15кв.1	t	small
28802	18275	341	Архангельская область, Коношский район, село Ивакинская, Победы, 39	t	small
28804	18277	343	Архангельская область, Коношский район, поселок Ерцево, Комсомольская, 4	t	small
28803	18276	342	Архангельская область, Коношский район, поселок Ерцево, Гагарина, 20	t	large
28799	18272	338	Архангельская область, Коношский район, поселок Волошка, им. Павла Корякина, 1	t	medium
86233	18290	355	Архангельская область, Коношский район, село Вересово, Бовы, 24Б, кв.2	t	small
28823	18299	362	Архангельская область, Коношский район, село Вельцы, Новосельская, 23	t	small
28798	18271	337	Архангельская область, Коношский район, село Вандыш, Юбилейная, 2	t	small
28829	18306	368	Россия, Архангельская область, Коношский район, село Бор	t	small
28806	18279	345	Россия, Архангельская область, Коношский район, село Ануфриево	t	small
28776	18250	313	Архангельская область, Каргопольский район, пос.Зелёный Бор, 13	t	small
28790	18264	327	Архангельская область, Каргопольский район, село Ширяиха, Центральная, 18 Б	t	small
28786	18260	323	Архангельская область, Каргопольский район, село Шелоховская, Советская, 13	t	medium
28788	18262	325	Архангельская область, Каргопольский район, село Усачевская, Молодёжная, 10	t	small
28789	18263	326	Архангельская область, Каргопольский район, село Трофимовская, Архангельская, 34	t	small
28782	18256	319	Архангельская область, Каргопольский район, село Тимошинская, 1-линия, 1	t	small
28787	18261	324	Архангельская область, Каргопольский район, село Семеновская, пер.Садовый, 1	t	small
28772	18246	309	Архангельская область, Каргопольский район, поселок Пригородный, Труда, 10	t	small
28791	18265	328	Архангельская область, Каргопольский район, село Погост-Наволочный, 32	t	small
28778	18252	315	Архангельская область, Каргопольский район, село Петровская, Петровская, 53	t	small
28793	18266	330	Архангельская область, Каргопольский район, село Песок, Центральная, 3	t	medium
28796	18269	333	Архангельская область, Каргопольский район, село Патровская, 112	t	small
28797	18270	334	Архангельская область, Каргопольский район, село Осташевская, 14	t	small
28785	18259	322	Архангельская область, Каргопольский район, село Морщихинская, Западная, 24	t	small
28773	18247	310	Архангельская область, Каргопольский район, село Лукино, 9 Мая, 13	t	small
28780	18254	317	Архангельская область, Каргопольский район, село Лазаревская, Береговая, 8	t	small
28795	18268	332	Архангельская область, Каргопольский район, село Кречетово, Советская, 15	t	medium
28775	18249	312	Архангельская область, Каргопольский район, село Кипрово, 56	t	small
28765	18239	302	Архангельская область, Каргопольский район, Каргополь, проспект Октябрьский, 1	f	large
28770	18244	307	Архангельская область, Каргопольский район, Каргополь, пр.Октябрьский, 112п.3	f	medium
28771	18245	308	Архангельская область, Каргопольский район, Каргополь, Чеснокова, 6	f	large
28769	18243	306	Архангельская область, Каргопольский район, Каргополь, Семенковская, 79	f	large
28781	18255	318	Архангельская область, Каргопольский район, село Калитинка, 61	t	small
28779	18253	316	Архангельская область, Каргопольский район, село Казаково, Октябрьская, 1	t	small
28794	18267	331	Архангельская область, Каргопольский район, село Ишуково, Ишуковская, 21	t	small
28815	18289	354	Архангельская область, Каргопольский район, поселок Заречный, Заречная, 4А	t	small
28774	18248	311	Архангельская область, Каргопольский район, село Жуковская, Молодёжная, 5	t	small
28784	18258	321	Архангельская область, Каргопольский район, село Дудкинская, 20	t	small
28792	18234	329	Архангельская область, Каргопольский район, село Григорьево, 41	t	small
28783	18257	320	Архангельская область, Каргопольский район, село Ватамановская, Центральная, 32	t	small
28777	18251	314	Архангельская область, Каргопольский район, село Абакумово, Центральная, 9	t	small
28764	18238	299	Архангельская область, Виноградовский район, село Яковлевская, 52	t	medium
28763	18237	298	Архангельская область, Виноградовский район, поселок Шидрово, Сплавщиков, 3	t	medium
28754	18227	289	Архангельская область, Виноградовский район, поселок Хетово, Южная, 13	t	small
28751	18224	286	Архангельская область, Виноградовский район, село Усть-Ваеньга, Советская, 10	t	small
28752	18225	287	Архангельская область, Виноградовский район, село Усть-Ваеньга, Песочная, 11	t	medium
28761	18235	296	Архангельская область, Виноградовский район, село Усть-Вага, 93	t	small
28756	18229	291	Архангельская область, Виноградовский район, село Уйта, Новая, 1	t	small
28745	18218	280	Архангельская область, Виноградовский район, село Топса, 179	t	small
86239	18228	290	Архангельская область, Виноградовский район, село Рязаново, Центральная, 29	t	small
109315	18219	281	Архангельская область, Виноградовский район, Рочегда, Комсомольская, 45	t	\N
28757	18230	292	Архангельская область, Виноградовский район, поселок Пянда, Школьная, 5	t	medium
29385	18831	955	Архангельская область, Виноградовский район, село Почтовое, 7	t	small
28748	18221	283	Архангельская область, Виноградовский район, село Осиново, 68	t	small
28753	18226	288	Архангельская область, Виноградовский район, село Моржегоры, 84А	t	medium
28747	18220	282	Архангельская область, Виноградовский район, село Конецгорье, 42	t	small
86237	18222	284	Архангельская область, Виноградовский район, село Квахтюга, Зеленая, 1	t	small
28743	18216	278	Архангельская область, Виноградовский район, село Гридинская, 33	t	small
86238	18223	285	Архангельская область, Виноградовский район, село Воронцы, Школьная, 13	t	small
28762	18236	297	Архангельская область, Виноградовский район, село Важский, Школьная, 6	t	medium
28760	18233	295	Архангельская область, Виноградовский район, поселок Березник, П.Виноградова, 85	f	large
28759	18232	294	Архангельская область, Виноградовский район, поселок Березник, П.Виноградова, 119	f	large
109316	18231	293	Архангельская область, Виноградовский район, поселок Березник, Восьмое Марта, 13	t	\N
28728	18199	263	Архангельская область, Вилегодский район, село Широкий Прилук, Ленина, 15	f	small
28742	18215	277	Архангельская область, Вилегодский район, село Шалимово, Центральная, 3	t	small
28725	18196	260	Архангельская область, Вилегодский район, село Фоминский, Комсомольская, 10	t	medium
28729	18200	264	Архангельская область, Вилегодский район, село Теринская, 9	t	small
86218	18197	261	Архангельская область, Вилегодский район, село Стафоровская, 55	t	small
28727	18198	262	Архангельская область, Вилегодский район, село Сорово, Профсоюзная, 22	t	medium
28732	18204	267	Архангельская область, Вилегодский район, село Слобода, 34 Г	t	small
86219	18207	270	Архангельская область, Вилегодский район, село Сидоровская, Южная, 2	t	small
28734	18206	269	Россия, Архангельская область, Вилегодский район, село Подомо	t	medium
28731	18202	266	Архангельская область, Вилегодский район, село Павловск, 26	t	medium
28739	18211	274	Архангельская область, Вилегодский район, Никольск, Октябрьская, 10	f	medium
28737	18209	272	Архангельская область, Вилегодский район, поселок Мухонская, Спортивная, 7	t	large
28738	18210	273	Архангельская область, Вилегодский район, село Кошкино, 15Б, Ф1	t	small
28741	18213	276	Архангельская область, Вилегодский район, село Кивер, Школьная, 3	t	small
28736	18208	271	Архангельская область, Вилегодский район, село Ильинско-Подомское, Советская, 32	f	large
86220	18212	275	Россия, Архангельская область, Вилегодский район, поселок Виледь	t	small
28730	18201	265	Архангельская область, Вилегодский район, село Вилегодск, 83	f	medium
28733	18205	268	Архангельская область, Вилегодский район, село Быково, 54 А	t	small
109313	18185	246	Архангельская область, Верхнетоемский район, д.Скрипчинская, Тимошенский культурный центр	t	\N
28703	18175	236	Россия, Архангельская область, Верхнетоемский район, село Черный Ручей	t	small
28707	18179	240	Россия, Архангельская область, Верхнетоемский район, село Ухменьга	t	small
28712	18184	245	Россия, Архангельская область, Верхнетоемский район, село Усть-Ерга	t	small
28892	18368	432	Архангельская область, Верхнетоемский район, село Усть-Ерга, Северная, 3	t	small
28705	18177	238	Архангельская область, Верхнетоемский район, поселок Сосновый, Двинская, 14	t	small
28704	18176	237	Архангельская область, Верхнетоемский район, село Сойга, 16	t	small
109312	18171	231	Архангельская область, Верхнетоемский район, село Согра, Набережная, 39	t	\N
28710	18182	243	Россия, Архангельская область, Верхнетоемский район, село Семеновская 1-я	t	small
28720	18192	253	Россия, Архангельская область, Верхнетоемский район, село Поперечка	t	small
28697	18170	230	Архангельская область, Верхнетоемский район, село Палова, Лесная, 29	t	small
28694	18167	227	Архангельская область, Верхнетоемский район, село Осяткино, Центральная, 27	t	small
28693	18166	226	Архангельская область, Верхнетоемский район, село Окулово, 17Б	t	small
28708	18180	241	Россия, Архангельская область, Верхнетоемский район, поселок Лахома	t	small
28700	18172	233	Архангельская область, Верхнетоемский район, село Ламбас, Школьная, 7	t	small
28695	18168	228	Архангельская область, Верхнетоемский район, село Красная, 72Б 	t	medium
28717	18189	250	Архангельская область, Верхнетоемский район, село Кондратовская, 58	t	small
28719	18191	252	Архангельская область, Верхнетоемский район, село Кодимский, 82	t	small
86221	18193	254	Архангельская область, Верхнетоемский район, село Каменное, Центральная, 13	t	small
28711	18183	244	Архангельская область, Верхнетоемский район, село Исаковская, 40	t	small
28714	18186	247	Архангельская область, Верхнетоемский район, поселок Зеленник, Набережная, 30	t	medium
28709	18181	242	Архангельская область, Верхнетоемский район, село Заруба	t	small
28718	18190	251	Архангельская область, Верхнетоемский район, село Евдокимовская, 87	t	small
28706	18178	239	Архангельская область, Верхнетоемский район, поселок Двинской, Лесная, 20	t	large
28715	18187	248	Архангельская область, Верхнетоемский район, село Вознесенское, 72	t	medium
28702	18174	235	Архангельская область, Верхнетоемский район, село Верхняя Тойма, Ломоносова, 4	f	large
28701	18173	234	Архангельская область, Верхнетоемский район, село Верхняя Тойма, Кулижского, 20Б	f	large
28716	18188	249	Архангельская область, Верхнетоемский район, село Бурцевская, 55	t	medium
28696	18169	229	Россия, Архангельская область, Верхнетоемский район, село Белореченский	t	small
28723	18195	256	Архангельская область, Верхнетоемский район, село Авнюгский, Строительная, 16	f	medium
28722	18194	255	Архангельская область, Верхнетоемский район, село Авнюгский, Строительная, 30	f	medium
28677	18150	208	Архангельская область, Вельский район, дер.Выселок, Новинки, 26	t	small
28691	18164	222	Архангельская область, Вельский район, село Шунема, Центральная, 12	t	medium
28667	18140	198	Архангельская область, Вельский район, село Шокша, Центральная, 8	t	small
28686	18159	217	Архангельская область, Вельский район, село Шиловская, 40А	f	medium
28685	18158	216	Архангельская область, Вельский район, село Хорошевская, 16В	f	small
28689	18162	220	Архангельская область, Вельский район, село Хозьмино, Центральная, 23	t	medium
28629	18100	160	Архангельская область, Вельский район, Вельск, Дзержинского, 38	f	large
28665	18138	196	Архангельская область, Вельский район, поселок Усть-Шоноша, переулок Торговый, 14	t	small
28687	18160	218	Архангельская область, Вельский район, поселок Усть-Шоноша, Ломоносова, 3	t	large
86228	18134	192	Архангельская область, Вельский район, село Тимонино, Советская, 3	t	small
28664	18137	195	Архангельская область, Вельский район, село Теребино, Дальняя, 4	t	medium
109311	18154	212	Архангельская область, Вельский район, село Тегрозеро, Мира, 16	t	medium
28653	18125	184	Архангельская область, Вельский район, село Средний, Гагарина, 5	t	small
28678	18151	209	Архангельская область, Вельский район, поселок Солгинский, Советская, 29	t	large
28688	18161	219	Архангельская область, Вельский район, село Смольянская, 14	t	small
28684	18157	215	Архангельская область, Вельский район, село Синега, Школьная, 22	t	small
86230	18145	203	Архангельская область, Вельский район, село Саргино, Центральная, 3	t	small
28668	18141	199	Архангельская область, Вельский район, село Притыкинская, Центральная, 27	t	small
28683	18156	214	Архангельская область, Вельский район, село Прилуцкая, Солнечная, 54	t	small
28679	18152	210	Архангельская область, Вельский район, село Погост, Центральная, 29	t	medium
28669	18142	200	Архангельская область, Вельский район, село Пежма, Центральная, 8А	t	medium
109310	18143	201	Архангельская область, Вельский район, село Пасьва, Свердлова, 16	t	\N
86229	18144	202	Архангельская область, Вельский район, село Павловское, 49	t	small
28642	18113	173	Архангельская область, Вельский район, село Новый Куваш, Железнодорожная, 2	t	small
28682	18155	213	Архангельская область, Вельский район, деревня Никифорово, 47	t	small
28650	18122	181	Архангельская область, Вельский район, село Нестюковская, 57	t	small
86225	18119	179	Архангельская область, Вельский район, село Мелединская, 179	t	small
86227	18133	191	Архангельская область, Вельский район, село Малая Липовка, Школьная, 4	t	small
28651	18123	182	Архангельская область, Вельский район, село Лодейное, Новая, 27	t	small
28649	18120	180	Архангельская область, Вельский район, село Лиходиевский Погост, 45	t	small
28690	18163	221	Архангельская область, Вельский район, село Леушинская, 42	t	small
28656	18128	187	Архангельская область, Вельский район, поселок Кулой, Пионерская, 5	t	medium
28657	18129	188	Архангельская область, Вельский район, поселок Кулой, Мира, 16	t	medium
28658	18130	189	Архангельская область, Вельский район, поселок Кулой, Ленина, 43	t	large
28655	18127	186	Архангельская область, Вельский район, поселок Кулой, Комсомольская, 58	t	large
28654	18126	185	Архангельская область, Вельский район, поселок Кулой, Комсомольская, 50	t	large
28652	18124	183	Архангельская область, Вельский район, село Комсомольский, Комсомольская, 36	t	medium
28676	18149	207	Архангельская область, Вельский район, село Козловская, Центральная, 26	t	small
28674	18147	205	Архангельская область, Вельский район, село Игнатовка, Почтовая, 1	t	small
28666	18139	197	Архангельская область, Вельский район, село Ефремковская, Почтовая, 1А	t	small
28634	18105	165	Архангельская область, Вельский район, село Дюковская, 2А	f	small
28673	18146	204	Архангельская область, Вельский район, село Долматово, Партизанская, 55	t	medium
28663	18136	194	Архангельская область, Вельский район, село Горка-Муравьевская, Школьная, 3	f	large
86226	18131	190	Архангельская область, Вельский район, село Георгиевское, Центральная, 29	t	small
28647	18118	178	Архангельская область, Вельский район, село Воскресенское, 12	t	small
28662	18135	193	Архангельская область, Вельский район, село Вороновская, 1Б	f	large
86232	18153	211	Архангельская область, Вельский район, село Верхопуйский, Титова, 26	t	small
28636	18107	167	Архангельская область, Вельский район, Вельск, Школьный переулок, 3	f	large
28628	18098	159	Архангельская область, Вельский район, Вельск, Революционная, 17А	f	medium
28635	18106	166	Архангельская область, Вельский район, Вельск, Макаренко, 12	f	large
28632	18103	163	Архангельская область, Вельский район, Вельск, Ломоносова, 37	f	large
28639	18110	170	Архангельская область, Вельский район, Вельск, Кирова, 6	f	medium
28638	18109	169	Архангельская область, Вельский район, Вельск, Дзержинского, 201	f	large
28637	18108	168	Архангельская область, Вельский район, Вельск, Дзержинского, 126А	f	large
28631	18102	162	Архангельская область, Вельский район, Вельск, Горького, 1А	f	large
28627	18097	158	Архангельская область, Вельский район, Вельск, Дзержинского, 25	f	large
86231	18148	206	Архангельская область, Вельский район, село Великое, Школьная, 3	t	small
86224	18117	177	Архангельская область, Вельский район, село Боровое, Культурная, 10	t	small
109309	18116	176	Архангельская область, Вельский район, село Благовещенское, Центральная, 10	t	\N
28644	18115	175	Архангельская область, Вельский район, село Аргуновский, 60 лет Октября, 11	t	medium
85500	82220	1804	Санкт-Петербург, улица Константина Заслонова, 6	f	large
85499	82220	1803	Санкт-Петербург, улица Константина Заслонова, 6	f	large
85495	82216	1799	Санкт-Петербург, Коломенская улица, 6	f	large
85494	82216	1798	Санкт-Петербург, Коломенская улица, 6	f	large
85493	82215	1797	Санкт-Петербург, Марата, 27	f	large
85491	82214	1795	Санкт-Петербург, Кузнечный переулок, 20	f	large
85490	82213	1794	Санкт-Петербург, Пушкинская, 9	f	large
85492	82212	1796	Санкт-Петербург, Большая Московская, 10	f	large
85489	82212	1793	Санкт-Петербург, Большая Московская, 10	f	large
85485	82209	1789	Санкт-Петербург, Ломоносова, 9	f	large
85484	82208	1788	Санкт-Петербург, набережная реки Фонтанки, 62	f	large
85483	82208	1787	Санкт-Петербург, набережная реки Фонтанки, 62	f	large
85488	82206	1792	Санкт-Петербург, Графский переулок, 8	f	large
85482	82206	1786	Санкт-Петербург, Графский переулок, 8	f	large
85481	82205	1785	Санкт-Петербург, Графский переулок, 1	f	large
85474	82196	1777	Санкт-Петербург, Маяковского, 9/16	f	large
85472	82194	1775	Санкт-Петербург, Маяковского, 26	f	large
85469	82191	1772	Санкт-Петербург, улица Пестеля, 16б	f	large
85467	82189	1770	Санкт-Петербург, Шпалерная улица, 33	f	large
85466	82189	1769	Санкт-Петербург, Шпалерная улица, 33	f	large
85464	82186	1767	Санкт-Петербург, Литейный проспект, 42	f	large
85462	82183	1764	Санкт-Петербург, Соляной переулок, 12	f	large
85461	82183	1763	Санкт-Петербург, Соляной переулок, 12	f	large
85457	82178	1759	Санкт-Петербург, Миллионная улица, 14	f	large
85358	82134	1647	Санкт-Петербург, Южное шоссе, 54а	f	large
85350	82129	1639	Санкт-Петербург, Софийская, 39к1	f	large
85349	82128	1638	Санкт-Петербург, Софийская, 42к3	f	large
117867	82109	1607	Санкт-Петербург, Клубная площадь, 1	f	\N
85319	82102	1600	Санкт-Петербург, Березовая, 18	f	large
117864	82101	1599	Санкт-Петербург, Большая, 1	f	medium
85317	82099	1596	Санкт-Петербург, Кадетский бульвар, 22а	f	large
85310	82095	1589	Санкт-Петербург, Ленинградская, 36, Пушкин	f	large
85308	82093	1587	Санкт-Петербург, бульвар Алексея Толстого, 42	f	large
85307	82093	1586	Санкт-Петербург, бульвар Алексея Толстого, 42	f	large
85300	82090	1579	Санкт-Петербург, Генерала Хазова, 18	f	large
85301	82090	1580	Санкт-Петербург, Генерала Хазова, 18	f	large
85296	82086	1574	Санкт-Петербург, Волхонское шоссе, 32	f	large
85325	82085	1609	Санкт-Петербург, Санкт-Петербург, Ленсоветовский, здание школы №460	f	large
117861	82085	1573	Санкт-Петербург, Санкт-Петербург, Ленсоветовский, здание школы №460	f	medium
85295	82084	1572	Санкт-Петербург, Пулковское, 30	f	large
85292	82080	1566	Санкт-Петербург, Санкт-Петербург, Пушкин, Лесное, здание школы №607	f	large
117857	82079	1565	Санкт-Петербург, Красносельское шоссе, 29, Филиал № 4 Территориальной центральной библиотечной системы	f	\N
85290	82077	1563	Санкт-Петербург, Леонтьевская, 10	f	large
85288	82075	1561	Санкт-Петербург, Госпитальная, 24	f	large
85302	82073	1581	Санкт-Петербург, Генерала Хазова, 7	f	large
85299	82073	1578	Санкт-Петербург, Генерала Хазова, 7	f	large
85285	82073	1558	Санкт-Петербург, Генерала Хазова, 7	f	large
117888	82044	1942	Санкт-Петербург, Маршала Новикова, 15, Школа № 33	f	\N
85223	82038	1487	Санкт-Петербург, улица Ильюшина, 15к3	f	large
85222	82038	1486	Санкт-Петербург, улица Ильюшина, 15к3	f	large
85221	82038	1485	Санкт-Петербург, улица Ильюшина, 15к3	f	large
85220	82037	1484	Санкт-Петербург, проспект Авиаконструкторов, 15к2	f	large
85219	82037	1483	Санкт-Петербург, проспект Авиаконструкторов, 15к2	f	large
85218	82037	1482	Санкт-Петербург, проспект Авиаконструкторов, 15к2	f	large
85214	82035	1478	Санкт-Петербург, Комендантский проспект, 22к3	f	large
85217	82035	1481	Санкт-Петербург, Комендантский проспект, 22к3	f	large
85216	82035	1480	Санкт-Петербург, Комендантский проспект, 22к3	f	large
85205	82030	1469	Санкт-Петербург, улица Маршала Новикова, 1к3	f	large
85204	82030	1468	Санкт-Петербург, улица Маршала Новикова, 1к3	f	large
85203	82030	1467	Санкт-Петербург, улица Маршала Новикова, 1к3	f	large
85198	82027	1462	Санкт-Петербург, Сердобольская, 50/52	f	large
85197	82027	1461	Санкт-Петербург, Сердобольская, 50/52	f	large
85196	82026	1460	Санкт-Петербург, Торжковская, 30А	f	large
85193	82024	1457	Санкт-Петербург, Ланское шоссе, 24к5	f	large
85192	82024	1456	Санкт-Петербург, Ланское шоссе, 24к5	f	large
85190	82022	1454	Санкт-Петербург, Новосибирская улица, 16к2	f	large
85189	82022	1453	Санкт-Петербург, Новосибирская улица, 16к2	f	large
85187	82020	1450	Санкт-Петербург, Приморский район, Школьная улица, 13	f	large
85186	82020	1449	Санкт-Петербург, Приморский район, Школьная улица, 13	f	large
85185	82019	1448	Санкт-Петербург, Школьная, 19	f	large
85188	82019	1451	Санкт-Петербург, Школьная, 19	f	large
85183	82016	1446	Санкт-Петербург, Школьная, 66	f	large
85182	82016	1445	Санкт-Петербург, Школьная, 66	f	large
85144	81989	1401	Санкт-Петербург, Победы, 28к2 А, Ломоносов	f	large
85143	81989	1400	Санкт-Петербург, Победы, 28к2 А, Ломоносов	f	large
85136	81985	1393	Санкт-Петербург, Александровская, 38	f	large
85130	81979	1385	Санкт-Петербург, Халтурина, 15/2	f	large
85128	81977	1383	Санкт-Петербург, Собственный проспект, 1	f	large
85127	81976	1382	Санкт-Петербург, Шахматова, 10/1	f	large
85126	81976	1381	Санкт-Петербург, Шахматова, 10/1	f	large
85125	81975	1380	Санкт-Петербург, Ботаническая, 8	f	large
85124	81975	1379	Санкт-Петербург, Ботаническая, 8	f	large
85121	81972	1375	Санкт-Петербург, Блан-Менильская, 5	f	large
85120	81972	1374	Санкт-Петербург, Блан-Менильская, 5	f	large
85119	81971	1373	Санкт-Петербург, Разводная, 27	f	large
85118	81971	1372	Санкт-Петербург, Разводная, 27	f	large
85116	81969	1370	Санкт-Петербург, Эрлеровский бульвар, 20	f	large
85115	81969	1369	Санкт-Петербург, Эрлеровский бульвар, 20	f	large
117841	81966	1366	Санкт-Петербург, Юты Бондаревой, 13к1	f	\N
85111	81962	1362	Санкт-Петербург, Санкт-Петербургское шоссе, 77	f	large
85092	81946	1339	Санкт-Петербург, Малая Разночинная улица, 2	f	large
85091	81946	1338	Санкт-Петербург, Малая Разночинная улица, 2	f	large
85090	81944	1335	Санкт-Петербург, Чкаловский проспект, 30	f	large
85079	81933	1321	Санкт-Петербург, Льва Толстого, 8	f	large
85077	81932	1319	Санкт-Петербург, Мира, 18	f	large
85078	81931	1320	Санкт-Петербург, Мира, 26	f	large
85076	81931	1318	Санкт-Петербург, Мира, 26	f	large
85011	81890	1245	Санкт-Петербург, Большой Смоленский проспект, 36	f	large
85010	81890	1244	Санкт-Петербург, Большой Смоленский проспект, 36	f	large
85303	81886	1582	Санкт-Петербург, Школьная, 55	f	large
84964	81869	1193	Санкт-Петербург, улица Коллонтай, 19к5	f	large
84963	81869	1192	Санкт-Петербург, улица Коллонтай, 19к5	f	large
84956	81864	1185	Санкт-Петербург, улица Белышева, 6	f	large
84955	81864	1184	Санкт-Петербург, улица Белышева, 6	f	large
84957	81864	1186	Санкт-Петербург, улица Белышева, 6	f	large
84950	81861	1179	Санкт-Петербург, улица Дыбенко, 20к4	f	large
84949	81861	1178	Санкт-Петербург, улица Дыбенко, 20к4	f	large
84948	81861	1177	Санкт-Петербург, улица Дыбенко, 20к4	f	large
84889	81829	1108	Санкт-Петербург, Победы, 10	f	large
84890	81829	1109	Санкт-Петербург, Победы, 10	f	large
84838	81805	1050	Санкт-Петербург, Авиационная, 38	f	large
84837	81805	1049	Санкт-Петербург, Авиационная, 38	f	large
84836	81805	1048	Санкт-Петербург, Авиационная, 38	f	large
84795	81780	1004	Санкт-Петербург, Правды, 6А, поселок Молодежное	f	large
84794	81777	1001	Санкт-Петербург, Курортный район, МО город Зеленогорск	f	large
117821	81776	1000	Санкт-Петербург, Санкт-Петербург, подстанция №41 ОАО Ленэнерго	f	small
84793	81775	999	Санкт-Петербург, Зеленогорск, проспект Ленина, 25	f	large
117820	81772	996	Санкт-Петербург, Цветочная, 22	f	small
84788	81769	993	Санкт-Петербург, поселок Песочный, Военно-морской городок, 8 квартал, 140	f	large
117819	81768	992	Санкт-Петербург, Приморское шоссе, 374	f	small
84787	81767	991	Санкт-Петербург, Восточная, 6	f	large
84781	81762	985	Санкт-Петербург, Советский переулок, 10	f	large
84780	81761	984	Санкт-Петербург, Токарева, 20	f	large
84779	81760	983	Санкт-Петербург, Токарева, 10	f	large
84773	81754	975	Санкт-Петербург, Станюковича, 4	f	large
84772	81754	974	Санкт-Петербург, Станюковича, 4	f	large
84771	81754	973	Санкт-Петербург, Станюковича, 4	f	large
84770	81753	972	Санкт-Петербург, Коммунистическая, 16	f	large
84768	81750	969	Санкт-Петербург, Андреевская, 3	f	large
84767	81749	968	Санкт-Петербург, Андреевская, 7	f	large
84766	81749	967	Санкт-Петербург, Андреевская, 7	f	large
84763	81746	964	Санкт-Петербург, Советская, 43	f	large
84762	81746	963	Санкт-Петербург, Советская, 43	f	large
84759	81743	960	Санкт-Петербург, Алексея Лебедева, 5	f	large
84758	81743	959	Санкт-Петербург, Алексея Лебедева, 5	f	large
117817	81740	954	Санкт-Петербург, Театральная, 15	f	small
117816	81739	953	Санкт-Петербург, Первого Мая, 2	f	small
84754	81736	951	Санкт-Петербург, Красногородская, 17к3	f	large
84753	81736	950	Санкт-Петербург, Красногородская, 17к3	f	large
84752	81735	949	Санкт-Петербург, Кингисеппское шоссе, 10к4	f	large
84751	81735	948	Санкт-Петербург, Кингисеппское шоссе, 10к4	f	large
84746	81731	943	Санкт-Петербург, Спирина, 13Б	f	large
84743	81728	940	Санкт-Петербург, Спирина, 2к3	f	large
84741	81728	938	Санкт-Петербург, Спирина, 2к3	f	large
84742	81728	939	Санкт-Петербург, Спирина, 2к3	f	large
117813	81726	936	Санкт-Петербург, Геологическая, 75к5	f	medium
84736	81722	930	Санкт-Петербург, Красносельское шоссе, 34	f	large
84734	81722	928	Санкт-Петербург, Красносельское шоссе, 34	f	large
84737	81722	931	Санкт-Петербург, Красносельское шоссе, 34	f	large
84735	81722	929	Санкт-Петербург, Красносельское шоссе, 34	f	large
84733	81721	927	Санкт-Петербург, Красносельский район, Поселковая улица, 26	f	large
85286	81680	1559	Санкт-Петербург, Пушкинская, 3	f	large
84577	81627	748	Санкт-Петербург, Казанская , 3	f	large
84557	81615	728	Санкт-Петербург, Большая Пороховская улица, 38	f	large
84554	81615	725	Санкт-Петербург, Большая Пороховская улица, 38	f	large
84551	81613	722	Санкт-Петербург, улица Петра Смородина, 10	f	large
84550	81613	721	Санкт-Петербург, улица Петра Смородина, 10	f	large
84518	81600	687	Санкт-Петербург, Труда, 1	f	large
84513	81597	682	Санкт-Петербург, Центральная, 12	f	large
84511	81597	680	Санкт-Петербург, Центральная, 12	f	large
84509	81593	677	Санкт-Петербург, Фанерная, 5, поселок Понтонный	f	large
84508	81592	676	Санкт-Петербург, Александра Товпеко, 14	f	large
84507	81591	675	Санкт-Петербург, Южная, 31	f	large
84506	81590	674	Санкт-Петербург, Южная, 13, поселок Потонный	f	large
84504	81587	671	Санкт-Петербург, Загородная, 41	f	large
84503	81586	670	Санкт-Петербург, Заводской проспект, 50	f	large
84502	81586	669	Санкт-Петербург, Заводской проспект, 50	f	large
84499	81585	666	Санкт-Петербург, Раумская, 9	f	large
84498	81585	665	Санкт-Петербург, Раумская, 9	f	large
84496	81583	663	Санкт-Петербург, Машиностроителей, 7	f	large
84495	81583	662	Санкт-Петербург, Машиностроителей, 7	f	large
84494	81583	661	Санкт-Петербург, Машиностроителей, 7	f	large
84490	81581	657	Санкт-Петербург, Заводской проспект, 10	f	large
117791	81579	654	Санкт-Петербург, бульвар Трудящихся, 10, Школа № 401	f	\N
84487	81576	651	Санкт-Петербург, Братьев Радченко, 21	f	large
84480	81573	644	Санкт-Петербург, проспект Ленина, 31	f	large
84479	81573	643	Санкт-Петербург, проспект Ленина, 31	f	large
84481	81572	645	Санкт-Петербург, Павловская, 21	f	large
84478	81572	642	Санкт-Петербург, Павловская, 21	f	large
84477	81571	641	Санкт-Петербург, Вавилова, 9, Колпино	f	large
84476	81571	640	Санкт-Петербург, Вавилова, 9, Колпино	f	large
84472	81569	636	Санкт-Петербург, Анисимова, 4	f	large
84473	81568	637	Санкт-Петербург, Тверская, 62	f	large
84471	81568	635	Санкт-Петербург, Тверская, 62	f	large
84470	81568	634	Санкт-Петербург, Тверская, 62	f	large
84467	81566	631	Санкт-Петербург, Колпино, Октябрьская, 71к2	f	large
84464	81566	628	Санкт-Петербург, Колпино, Октябрьская, 71к2	f	large
84465	81566	629	Санкт-Петербург, Колпино, Октябрьская, 71к2	f	large
84462	81563	626	Санкт-Петербург, Тверская, 18	f	large
84460	81563	624	Санкт-Петербург, Тверская, 18	f	large
84459	81562	623	Санкт-Петербург, Труда, 1, Колпино	f	large
84430	81546	591	Санкт-Петербург, проспект Ветеранов, 114к2	f	large
84401	81529	558	Санкт-Петербург, проспект Стачек, 107к3	f	large
84399	81529	556	Санкт-Петербург, проспект Стачек, 107к3	f	large
84400	81528	557	Санкт-Петербург, Ленинский проспект, 110к3	f	large
84398	81528	555	Санкт-Петербург, Ленинский проспект, 110к3	f	large
84393	81526	550	Санкт-Петербург, улица Маршала Казакова, 3к2	f	large
84392	81525	549	Санкт-Петербург, улица Маршала Казакова, 3к2	f	large
84391	81525	548	Санкт-Петербург, улица Маршала Казакова, 3к2	f	large
84390	81524	547	Санкт-Петербург, улица Морской Пехоты, 8к3	f	large
84389	81524	546	Санкт-Петербург, улица Морской Пехоты, 8к3	f	large
84349	81497	504	Санкт-Петербург, улица Маршала Говорова, 9	f	large
84344	81494	499	Санкт-Петербург, Огородный переулок, 9	f	large
84343	81494	498	Санкт-Петербург, Огородный переулок, 9	f	large
84341	81491	496	Санкт-Петербург, Турбинная улица, 50	f	large
84340	81491	495	Санкт-Петербург, Турбинная улица, 50	f	large
84337	81490	492	Санкт-Петербург, Промышленная улица, 18	f	large
117782	81490	491	Санкт-Петербург, Промышленная улица, 18	f	medium
84339	81489	494	Санкт-Петербург, улица Зои Космодемьянской, 4	f	large
84336	81489	490	Санкт-Петербург, улица Зои Космодемьянской, 4	f	large
84335	81488	489	Санкт-Петербург, проспект Стачек, 5	f	large
84332	81485	486	Санкт-Петербург, улица Ивана Черных, 11	f	large
84331	81485	485	Санкт-Петербург, улица Ивана Черных, 11	f	large
84323	81477	473	Санкт-Петербург, Лабораторная улица, 15	f	large
84306	81465	455	Санкт-Петербург, Полюстровский проспект, 33к3	f	large
84301	81462	450	Санкт-Петербург, Кондратьевский проспект, 51	f	large
84182	81395	319	Санкт-Петербург, Кооперативная	f	large
117768	81389	321	Санкт-Петербург, Выборгское шоссе, 369к3	f	medium
117767	81386	320	Санкт-Петербург, Шишкина, 30	f	medium
84170	81385	302	Санкт-Петербург, Выборгское шоссе, 7к2	f	large
84169	81385	301	Санкт-Петербург, Выборгское шоссе, 7к2	f	large
84137	81369	268	Санкт-Петербург, Поэтический бульвар, 5к3	f	large
84061	81312	176	Санкт-Петербург, Александра Матросова, 11	f	large
84060	81312	175	Санкт-Петербург, Александра Матросова, 11	f	large
84028	81284	125	Санкт-Петербург, улица Кораблестроителей, 18	f	large
84027	81283	124	Санкт-Петербург, улица Кораблестроителей, 20к3	f	large
84026	81282	123	Санкт-Петербург, Морская набережная, 15к2	f	large
84021	81281	118	Санкт-Петербург, Наличная улица, 32к2	f	large
84024	81281	121	Санкт-Петербург, Наличная улица, 32к2	f	large
84023	81281	120	Санкт-Петербург, Наличная улица, 32к2	f	large
84004	81264	100	Санкт-Петербург, Василеостровский район, 14-я линия В.О., 77	f	large
84003	81264	99	Санкт-Петербург, Василеостровский район, 14-я линия В.О., 77	f	large
83996	81259	92	Санкт-Петербург, 7-я линия ВО, 66	f	large
83998	81259	94	Санкт-Петербург, 7-я линия ВО, 66	f	large
83997	81259	93	Санкт-Петербург, 7-я линия ВО, 66	f	large
83993	81257	89	Санкт-Петербург, 2-я линия В.О,, 43	f	large
83994	81257	90	Санкт-Петербург, 2-я линия В.О,, 43	f	large
83991	81254	87	Санкт-Петербург, Большой проспект В.О, 65	f	large
83990	81254	86	Санкт-Петербург, Большой проспект В.О, 65	f	large
83989	81254	85	Санкт-Петербург, Большой проспект В.О, 65	f	large
83984	81249	79	Санкт-Петербург, 9-я линия ВО, 6	f	large
83982	81247	77	Санкт-Петербург, 5-я линия В.О., 16	f	large
117697	81209	23	Санкт-Петербург, Театральная площадь, 3, ФГОУ ВПО Санкт-Петербургская Государственная Консерватория	f	\N
83967	81191	5	Санкт-Петербург, Адмиралтейский район, Садовая , 75/14	f	large
83966	81191	1	Санкт-Петербург, Адмиралтейский район, Садовая , 75/14	f	large
84556	81614	727	Санкт-Петербург, шоссе Революции, 35к5	f	large
84553	81614	724	Санкт-Петербург, шоссе Революции, 35к5	f	large
84552	81614	723	Санкт-Петербург, шоссе Революции, 35к5	f	large
85431	82165	1729	Санкт-Петербург, улица Ярослава Гашека, 28к2	f	large
85430	82165	1728	Санкт-Петербург, улица Ярослава Гашека, 28к2	f	large
85424	82162	1722	Санкт-Петербург, улица Ярослава Гашека, 9к2	f	large
85423	82162	1721	Санкт-Петербург, улица Ярослава Гашека, 9к2	f	large
117706	81217	32	Санкт-Петербург, улица Якубовича, 26	f	\N
85280	82069	1549	Санкт-Петербург, улица Щербакова, 16	f	large
85279	82069	1548	Санкт-Петербург, улица Щербакова, 16	f	large
85278	82068	1547	Санкт-Петербург, Щербакова, 18	f	large
85276	82068	1545	Санкт-Петербург, Щербакова, 18	f	large
85277	82068	1546	Санкт-Петербург, Щербакова, 18	f	large
84158	81379	290	Санкт-Петербург, улица Шостаковича, 3к2	f	large
84157	81379	289	Санкт-Петербург, улица Шостаковича, 3к2	f	large
84011	81271	107	Санкт-Петербург, улица Шкиперский Проток, 5	f	large
83976	81240	57	Санкт-Петербург, Шкапина, 2	f	large
85028	81900	1263	Санкт-Петербург, Шелгунова, 23	f	large
85533	82244	1843	Санкт-Петербург, улица Черняховского, 30	f	large
85532	82244	1842	Санкт-Петербург, улица Черняховского, 30	f	large
84225	81420	368	Санкт-Петербург, улица Черкасова, 4к2	f	large
84224	81420	367	Санкт-Петербург, улица Черкасова, 4к2	f	large
84223	81420	366	Санкт-Петербург, улица Черкасова, 4к2	f	large
84220	81419	363	Санкт-Петербург, Черкасова, 8к2	f	large
84219	81419	362	Санкт-Петербург, Черкасова, 8к2	f	large
84222	81419	365	Санкт-Петербург, Черкасова, 8к2	f	large
84221	81419	364	Санкт-Петербург, Черкасова, 8к2	f	large
84218	81418	361	Санкт-Петербург, Черкасова, 15	f	large
84217	81418	360	Санкт-Петербург, Черкасова, 15	f	large
84215	81417	358	Санкт-Петербург, улица Черкасова, 7к2	f	large
84216	81417	359	Санкт-Петербург, улица Черкасова, 7к2	f	large
84719	81702	911	Санкт-Петербург, Чекистов, 18	f	large
84702	81702	894	Санкт-Петербург, Чекистов, 18	f	large
83975	81237	54	Санкт-Петербург, Циолковского, 8	f	large
84065	81313	180	Санкт-Петербург, улица Харченко, 27	f	large
84064	81313	179	Санкт-Петербург, улица Харченко, 27	f	large
84063	81313	178	Санкт-Петербург, улица Харченко, 27	f	large
84062	81313	177	Санкт-Петербург, улица Харченко, 27	f	large
84815	81795	1027	Санкт-Петербург, Фрунзе, 12	f	large
84814	81795	1026	Санкт-Петербург, Фрунзе, 12	f	large
84813	81794	1025	Санкт-Петербург, улица Фрунзе, 13	f	large
84282	81446	427	Санкт-Петербург, улица Фаворского, 16	f	large
84279	81446	424	Санкт-Петербург, улица Фаворского, 16	f	large
84232	81424	375	Санкт-Петербург, улица Ушинского, 33к2	f	large
84231	81424	374	Санкт-Петербург, улица Ушинского, 33к2	f	large
84235	81424	378	Санкт-Петербург, улица Ушинского, 33к2	f	large
84277	81423	421	Санкт-Петербург, улица Ушинского, 21	f	large
84230	81423	373	Санкт-Петербург, улица Ушинского, 21	f	large
84229	81423	372	Санкт-Петербург, улица Ушинского, 21	f	large
84228	81422	371	Санкт-Петербург, Ушинского, 13	f	large
84227	81422	370	Санкт-Петербург, Ушинского, 13	f	large
84226	81422	369	Санкт-Петербург, Ушинского, 13	f	large
85366	82138	1655	Санкт-Петербург, улица Турку, 21к2	f	large
85365	82138	1654	Санкт-Петербург, улица Турку, 21к2	f	large
85364	82137	1653	Санкт-Петербург, Турку, 16	f	large
85363	82137	1652	Санкт-Петербург, Турку, 16	f	large
85360	82135	1649	Санкт-Петербург, Турку, 29к2	f	large
85359	82135	1648	Санкт-Петербург, Турку, 29к2	f	large
85355	82132	1644	Санкт-Петербург, улица Турку, 30	f	large
85354	82132	1643	Санкт-Петербург, улица Турку, 30	f	large
85015	81891	1249	Санкт-Петербург, улица Ткачей, 9к1	f	large
85014	81891	1248	Санкт-Петербург, улица Ткачей, 9к1	f	large
85013	81891	1247	Санкт-Петербург, улица Ткачей, 9к1	f	large
85012	81891	1246	Санкт-Петербург, улица Ткачей, 9к1	f	large
84932	81855	1161	Санкт-Петербург, улица Тельмана, 34	f	large
84931	81855	1160	Санкт-Петербург, улица Тельмана, 34	f	large
84930	81855	1159	Санкт-Петербург, улица Тельмана, 34	f	large
84929	81855	1158	Санкт-Петербург, улица Тельмана, 34	f	large
84921	81847	1148	Санкт-Петербург, Тельмана, 47	f	large
84920	81847	1147	Санкт-Петербург, Тельмана, 47	f	large
84730	81718	924	Санкт-Петербург, улица Тамбасова, 26	f	large
84729	81718	923	Санкт-Петербург, улица Тамбасова, 26	f	large
84700	81699	889	Санкт-Петербург, улица Тамбасова, 2к4	f	large
84699	81699	888	Санкт-Петербург, улица Тамбасова, 2к4	f	large
84698	81699	887	Санкт-Петербург, улица Тамбасова, 2к4	f	large
84428	81543	588	Санкт-Петербург, Стойкости, 28, корп. 2	f	large
84427	81542	587	Санкт-Петербург, Стойкости, 33	f	large
84425	81542	585	Санкт-Петербург, Стойкости, 33	f	large
84426	81541	586	Санкт-Петербург, улица Стойкости, 30к2	f	large
84424	81541	584	Санкт-Петербург, улица Стойкости, 30к2	f	large
84429	81537	589	Санкт-Петербург, улица Стойкости, 17к2	f	large
84415	81537	575	Санкт-Петербург, улица Стойкости, 17к2	f	large
84414	81537	574	Санкт-Петербург, улица Стойкости, 17к2	f	large
84530	81605	700	Санкт-Петербург, улица Стасовой, 4к2	f	large
84529	81605	699	Санкт-Петербург, улица Стасовой, 4к2	f	large
84528	81605	698	Санкт-Петербург, улица Стасовой, 4к2	f	large
84527	81605	697	Санкт-Петербург, улица Стасовой, 4к2	f	large
83969	81200	14	Санкт-Петербург, Союза Печатников, 26	f	large
84293	81452	438	Санкт-Петербург, улица Софьи Ковалевской, 13к6	f	large
84289	81452	434	Санкт-Петербург, улица Софьи Ковалевской, 13к6	f	large
84211	81415	354	Санкт-Петербург, улица Софьи Ковалевской, 8к3	f	large
84210	81415	353	Санкт-Петербург, улица Софьи Ковалевской, 8к3	f	large
84416	81534	576	Санкт-Петербург, улица Солдата Корзуна, 15к2	f	large
84409	81534	569	Санкт-Петербург, улица Солдата Корзуна, 15к2	f	large
84410	81534	570	Санкт-Петербург, улица Солдата Корзуна, 15к2	f	large
84057	81309	172	Санкт-Петербург, Смолячкова, 13	f	large
84163	81381	295	Санкт-Петербург, улица Симонова, 8	f	large
84161	81381	293	Санкт-Петербург, улица Симонова, 8	f	large
84160	81381	292	Санкт-Петербург, улица Симонова, 8	f	large
84162	81380	294	Санкт-Петербург, улица Симонова, 8	f	large
84159	81380	291	Санкт-Петербург, улица Симонова, 8	f	large
84100	81344	224	Санкт-Петербург, улица Сикейроса, 5к2	f	large
84097	81344	220	Санкт-Петербург, улица Сикейроса, 5к2	f	large
84096	81344	219	Санкт-Петербург, улица Сикейроса, 5к2	f	large
84099	81342	222	Санкт-Петербург, улица Сикейроса, 19к1	f	large
84094	81342	217	Санкт-Петербург, улица Сикейроса, 19к1	f	large
84095	81341	218	Санкт-Петербург, улица Сикейроса, 17к1	f	large
84093	81341	216	Санкт-Петербург, улица Сикейроса, 17к1	f	large
117830	81895	1253	Санкт-Петербург, улица Седова, 66, школа 336	f	\N
85018	81894	1252	Санкт-Петербург, Седова, 66	f	large
85017	81893	1251	Санкт-Петербург, улица Седова, 56	f	large
85016	81893	1250	Санкт-Петербург, улица Седова, 56	f	large
84109	81351	233	Санкт-Петербург, Сантьяго-де-Куба, 4к2	f	large
117753	81346	223	Санкт-Петербург, улица Сантьяго-де-Куба, 4к2	f	\N
117850	82021	1452	Россия, Астраханская область, Астрахань, улица Савушкина, 3	f	\N
85168	82009	1431	Санкт-Петербург, улица Савушкина, 111к2	f	large
85167	82009	1430	Санкт-Петербург, улица Савушкина, 111к2	f	large
85166	82008	1429	Санкт-Петербург, улица Савушкина, 111к2	f	large
84330	81481	480	Санкт-Петербург, улица Руставели, 26	f	large
84329	81481	479	Санкт-Петербург, улица Руставели, 26	f	large
84300	81461	449	Санкт-Петербург, улица Руставели, 26	f	large
84114	81356	242	Санкт-Петербург, Руднева, 5к3	f	large
84153	81356	284	Санкт-Петербург, Руднева, 5к3	f	large
84113	81356	241	Санкт-Петербург, Руднева, 5к3	f	large
84115	81356	243	Санкт-Петербург, Руднева, 5к3	f	large
84120	81329	248	Санкт-Петербург, Руднева, 23	f	large
84118	81329	246	Санкт-Петербург, Руднева, 23	f	large
84117	81329	245	Санкт-Петербург, Руднева, 23	f	large
84119	81329	247	Санкт-Петербург, Руднева, 23	f	large
84675	81684	862	Санкт-Петербург, улица Рихарда Зорге, 13к2	f	large
84671	81684	858	Санкт-Петербург, улица Рихарда Зорге, 13к2	f	large
84670	81684	857	Санкт-Петербург, улица Рихарда Зорге, 13к2	f	large
117838	81953	1349	Санкт-Петербург, улица Профессора Попова, 37б	f	medium
85507	82226	1817	Санкт-Петербург, улица Пролетарской Диктатуры, 1	f	large
85506	82226	1816	Санкт-Петербург, улица Пролетарской Диктатуры, 1	f	large
84363	81509	519	Санкт-Петербург, Примакова, 10	f	large
84739	81723	933	Санкт-Петербург, улица Политрука Пасечника, 3	f	large
84738	81723	932	Санкт-Петербург, улица Политрука Пасечника, 3	f	large
84982	81874	1211	Санкт-Петербург, Санкт-Петербург, улица Подвойского, 50к1, муниципальное образование муниципальный округ Оккервиль	f	large
84981	81874	1210	Санкт-Петербург, Санкт-Петербург, улица Подвойского, 50к1, муниципальное образование муниципальный округ Оккервиль	f	large
84980	81874	1209	Санкт-Петербург, Санкт-Петербург, улица Подвойского, 50к1, муниципальное образование муниципальный округ Оккервиль	f	large
84384	81520	541	Санкт-Петербург, улица Подводника Кузьмина, 52	f	large
84383	81520	540	Санкт-Петербург, улица Подводника Кузьмина, 52	f	large
84726	81717	920	Санкт-Петербург, улица Пограничника Гарькавого, 36к1	f	large
84728	81716	922	Санкт-Петербург, улица Пограничника Гарькавого, 36к6	f	large
84725	81716	919	Санкт-Петербург, улица Пограничника Гарькавого, 36к6	f	large
84696	81697	885	Санкт-Петербург, улица Пограничника Гарькавого, 14к1	f	large
84693	81695	882	Санкт-Петербург, улица Пограничника Гарькавого, 22к1	f	large
84688	81692	877	Санкт-Петербург, Пионерстроя, 10, корп. 2	f	large
84701	81692	890	Санкт-Петербург, Пионерстроя, 10, корп. 2	f	large
84689	81692	878	Санкт-Петербург, Пионерстроя, 10, корп. 2	f	large
84687	81691	876	Санкт-Петербург, улица Пионерстроя, 9	f	large
84686	81691	875	Санкт-Петербург, улица Пионерстроя, 9	f	large
84184	81397	323	Санкт-Петербург, Санкт-Петербург, улица Первого Мая, 101а, поселок Парголово	f	large
84548	81604	719	Санкт-Петербург, улица Панфилова, 23	f	large
84545	81604	716	Санкт-Петербург, улица Панфилова, 23	f	large
117794	81604	714	Санкт-Петербург, улица Панфилова, 23	f	medium
84598	81639	773	Санкт-Петербург, улица Осипенко, 5к2	f	large
84597	81639	772	Санкт-Петербург, улица Осипенко, 5к2	f	large
84596	81638	771	Санкт-Петербург, улица Осипенко, 5к2	f	large
84842	81807	1054	Санкт-Петербург, улица Орджоникидзе, 18	f	large
84841	81807	1053	Санкт-Петербург, улица Орджоникидзе, 18	f	large
84052	81304	166	Санкт-Петербург, Орбели, 24	f	large
85163	82004	1426	Санкт-Петербург, Санкт-Петербург, улица Оптиков, 46к3	f	large
85162	82004	1425	Санкт-Петербург, Санкт-Петербург, улица Оптиков, 46к3	f	large
85161	82003	1424	Санкт-Петербург, Камышовая улица, 47к5	f	large
85160	82003	1423	Санкт-Петербург, Камышовая улица, 47к5	f	large
84263	81436	407	Санкт-Петербург, улица Ольги Форш, 17к2	f	large
84258	81436	401	Санкт-Петербург, улица Ольги Форш, 17к2	f	large
84264	81436	408	Санкт-Петербург, улица Ольги Форш, 17к2	f	large
84259	81436	402	Санкт-Петербург, улица Ольги Форш, 17к2	f	large
85009	81889	1243	Санкт-Петербург, улица Ольги Берггольц, 15	f	large
85450	82173	1748	Санкт-Петербург, улица Олеко Дундича, 25к3	f	large
85452	82173	1750	Санкт-Петербург, улица Олеко Дундича, 25к3	f	large
85451	82173	1749	Санкт-Петербург, улица Олеко Дундича, 25к3	f	large
85446	82171	1744	Санкт-Петербург, улица Олеко Дундича, 26к2	f	large
85445	82171	1743	Санкт-Петербург, улица Олеко Дундича, 26к2	f	large
85444	82171	1742	Санкт-Петербург, улица Олеко Дундича, 26к2	f	large
85435	82167	1733	Санкт-Петербург, улица Олеко Дундича, 37к2	f	large
85436	82167	1734	Санкт-Петербург, улица Олеко Дундича, 37к2	f	large
85434	82166	1732	Санкт-Петербург, Олеко Дундича, 38, корп. 3	f	large
85433	82166	1731	Санкт-Петербург, Олеко Дундича, 38, корп. 3	f	large
85432	82166	1730	Санкт-Петербург, Олеко Дундича, 38, корп. 3	f	large
84905	81838	1132	Санкт-Петербург, улица Новоселов, 21	f	large
84904	81838	1131	Санкт-Петербург, улица Новоселов, 21	f	large
84903	81838	1130	Санкт-Петербург, улица Новоселов, 21	f	large
84018	81277	115	Санкт-Петербург, улица Нахимова, 8к2	f	large
85516	82233	1826	Санкт-Петербург, Моисеенко, 19	f	large
84534	81606	704	Санкт-Петербург, улица Маршала Тухачевского, 17	f	large
84533	81606	703	Санкт-Петербург, улица Маршала Тухачевского, 17	f	large
84532	81606	702	Санкт-Петербург, улица Маршала Тухачевского, 17	f	large
84531	81606	701	Санкт-Петербург, улица Маршала Тухачевского, 17	f	large
84525	81603	695	Санкт-Петербург, Маршала Тухачевского, 29	f	large
84524	81603	694	Санкт-Петербург, Маршала Тухачевского, 29	f	large
84523	81603	693	Санкт-Петербург, Маршала Тухачевского, 29	f	large
84526	81603	696	Санкт-Петербург, Маршала Тухачевского, 29	f	large
85251	82053	1517	Санкт-Петербург, улица Маршала Новикова, 15к1	f	large
84664	81678	849	Санкт-Петербург, улица Маршала Казакова, 30	f	large
84663	81678	848	Санкт-Петербург, улица Маршала Казакова, 30	f	large
84685	81690	872	Санкт-Петербург, улица Маршала Захарова, 28	f	large
84684	81690	871	Санкт-Петербург, улица Маршала Захарова, 28	f	large
84683	81690	870	Санкт-Петербург, улица Маршала Захарова, 28	f	large
84682	81686	869	Санкт-Петербург, улица Маршала Захарова, 28	f	large
84676	81686	863	Санкт-Петербург, улица Маршала Захарова, 28	f	large
84667	81674	852	Санкт-Петербург, Маршала Захарова, 58	f	large
84656	81674	841	Санкт-Петербург, Маршала Захарова, 58	f	large
84655	81674	840	Санкт-Петербург, Маршала Захарова, 58	f	large
84654	81673	839	Санкт-Петербург, улица Маршала Захарова, 58	f	large
84653	81672	838	Санкт-Петербург, улица Маршала Захарова, 52	f	large
84652	81672	837	Санкт-Петербург, улица Маршала Захарова, 52	f	large
84651	81672	836	Санкт-Петербург, улица Маршала Захарова, 52	f	large
84352	81501	507	Санкт-Петербург, улица Маршала Говорова, 9	f	large
84350	81498	505	Санкт-Петербург, улица Маршала Говорова, 18	f	large
84362	81508	518	Санкт-Петербург, улица Маринеско, 7	f	large
84361	81508	517	Санкт-Петербург, улица Маринеско, 7	f	large
84721	81712	915	Санкт-Петербург, Лётчика Пилютова, 50	f	large
84722	81712	916	Санкт-Петербург, Лётчика Пилютова, 50	f	large
84450	81554	611	Санкт-Петербург, улица Лёни Голикова, 15к2	f	large
84447	81554	608	Санкт-Петербург, улица Лёни Голикова, 15к2	f	large
84439	81549	600	Санкт-Петербург, Лени Голикова, 78	f	large
84438	81549	599	Санкт-Петербург, Лени Голикова, 78	f	large
84437	81549	598	Санкт-Петербург, Лени Голикова, 78	f	large
84436	81549	597	Санкт-Петербург, Лени Голикова, 78	f	large
84856	81812	1068	Санкт-Петербург, Ленсовета, 68	f	large
84855	81812	1067	Санкт-Петербург, Ленсовета, 68	f	large
84854	81812	1066	Санкт-Петербург, Ленсовета, 68	f	large
84853	81812	1065	Санкт-Петербург, Ленсовета, 68	f	large
84857	81812	1069	Санкт-Петербург, Ленсовета, 68	f	large
84846	81809	1058	Санкт-Петербург, Ленсовета, 43А	f	large
84845	81809	1057	Санкт-Петербург, Ленсовета, 43А	f	large
84996	81879	1225	Санкт-Петербург, улица Латышских Стрелков, 9к3	f	large
84995	81879	1224	Санкт-Петербург, улица Латышских Стрелков, 9к3	f	large
84994	81879	1223	Санкт-Петербург, улица Латышских Стрелков, 9к3	f	large
84993	81878	1222	Санкт-Петербург, улица Латышских Стрелков, 9к1	f	large
84992	81878	1221	Санкт-Петербург, улица Латышских Стрелков, 9к1	f	large
84991	81878	1220	Санкт-Петербург, улица Латышских Стрелков, 9к1	f	large
84928	81854	1157	Санкт-Петербург, улица Крыленко, 25к5	f	large
84925	81851	1154	Санкт-Петербург, Крыленко, 33, корп.2	f	large
84924	81851	1153	Санкт-Петербург, Крыленко, 33, корп.2	f	large
84666	81679	851	Санкт-Петербург, улица Котина, 6к3	f	large
84665	81679	850	Санкт-Петербург, улица Котина, 6к3	f	large
84885	81826	1104	Санкт-Петербург, улица Костюшко, 62	f	large
84884	81826	1103	Санкт-Петербург, улица Костюшко, 62	f	large
84883	81824	1102	Санкт-Петербург, улица Костюшко, 34	f	large
84882	81824	1101	Санкт-Петербург, улица Костюшко, 34	f	large
84881	81824	1100	Санкт-Петербург, улица Костюшко, 34	f	large
84880	81824	1099	Санкт-Петербург, улица Костюшко, 34	f	large
84043	81292	141	Санкт-Петербург, улица Кораблестроителей, 42к2	f	large
84042	81292	140	Санкт-Петербург, улица Кораблестроителей, 42к2	f	large
84044	81292	142	Санкт-Петербург, улица Кораблестроителей, 42к2	f	large
84041	81291	139	Санкт-Петербург, улица Кораблестроителей, 38к2	f	large
84040	81291	138	Санкт-Петербург, улица Кораблестроителей, 38к2	f	large
84039	81291	137	Санкт-Петербург, улица Кораблестроителей, 38к2	f	large
84038	81291	136	Санкт-Петербург, улица Кораблестроителей, 38к2	f	large
117766	81394	317	Санкт-Петербург, улица Композиторов, 22к2	f	\N
117762	81388	307	Санкт-Петербург, Санкт-Петербург, улица Композиторов, 22, к. 2, школа № 494	f	\N
117764	81388	309	Санкт-Петербург, Санкт-Петербург, улица Композиторов, 22, к. 2, школа № 494	f	\N
117763	81388	308	Санкт-Петербург, Санкт-Петербург, улица Композиторов, 22, к. 2, школа № 494	f	\N
117765	81388	310	Санкт-Петербург, Санкт-Петербург, улица Композиторов, 22, к. 2, школа № 494	f	\N
84174	81387	306	Санкт-Петербург, улица Композиторов, 11к2	f	large
84173	81387	305	Санкт-Петербург, улица Композиторов, 11к2	f	large
84172	81387	304	Санкт-Петербург, улица Композиторов, 11к2	f	large
84626	81651	802	Санкт-Петербург, Санкт-Петербург, улица Коммуны, 42к2, муниципальное образование муниципальный округ Ржевка	f	large
84054	81307	169	Санкт-Петербург, улица Комиссара Смирнова, 17	f	large
84408	81533	568	Санкт-Петербург, улица Козлова, 47к2	f	large
84407	81533	567	Санкт-Петербург, улица Козлова, 47к2	f	large
84406	81532	566	Санкт-Петербург, улица Козлова, 37к1	f	large
84405	81532	565	Санкт-Петербург, улица Козлова, 37к1	f	large
85027	81899	1262	Санкт-Петербург, улица Кибальчича, 8к2	f	large
84292	81453	437	Санкт-Петербург, улица Карпинского, 38	f	large
84291	81453	436	Санкт-Петербург, улица Карпинского, 38	f	large
84290	81453	435	Санкт-Петербург, улица Карпинского, 38	f	large
84457	81559	619	Санкт-Петербург, улица Зины Портновой, 21к4	f	large
84452	81556	613	Санкт-Петербург, улица Зины Портновой, 15	f	large
84451	81556	612	Санкт-Петербург, улица Зины Портновой, 15	f	large
84731	81719	925	Санкт-Петербург, улица Здоровцева, 33к2	f	large
84351	81499	506	Санкт-Петербург, Зайцева, 28	f	large
84152	81376	283	Санкт-Петербург, Есенина, 24	f	large
84151	81376	282	Санкт-Петербург, Есенина, 24	f	large
84150	81376	281	Санкт-Петербург, Есенина, 24	f	large
84149	81375	280	Санкт-Петербург, улица Есенина, 22к3	f	large
84148	81375	279	Санкт-Петербург, улица Есенина, 22к3	f	large
84144	81373	275	Санкт-Петербург, Есенина, 34, корп. 2	f	large
84147	81373	278	Санкт-Петербург, Есенина, 34, корп. 2	f	large
84145	81373	276	Санкт-Петербург, Есенина, 34, корп. 2	f	large
84146	81372	277	Санкт-Петербург, улица Есенина, 36к2	f	large
84143	81372	274	Санкт-Петербург, улица Есенина, 36к2	f	large
117720	81232	49	Санкт-Петербург, Санкт-Петербург, улица Егорова, 24, ГОУ СОШ № 564	f	\N
84938	81857	1167	Санкт-Петербург, улица Дыбенко, 17к3	f	large
84936	81857	1165	Санкт-Петербург, улица Дыбенко, 17к3	f	large
84935	81857	1164	Санкт-Петербург, улица Дыбенко, 17к3	f	large
84937	81857	1166	Санкт-Петербург, улица Дыбенко, 17к3	f	large
84707	81648	899	Санкт-Петербург, Добровольцев, 8	f	large
84706	81648	898	Санкт-Петербург, Добровольцев, 8	f	large
84705	81648	897	Санкт-Петербург, Добровольцев, 8	f	large
85407	82155	1705	Санкт-Петербург, улица Димитрова, 15к1	f	large
85406	82155	1704	Санкт-Петербург, улица Димитрова, 15к1	f	large
85405	82155	1703	Санкт-Петербург, улица Димитрова, 15к1	f	large
85404	82154	1702	Санкт-Петербург, улица Димитрова, 9к3	f	large
85403	82154	1701	Санкт-Петербург, улица Димитрова, 9к3	f	large
85402	82154	1700	Санкт-Петербург, улица Димитрова, 9к3	f	large
85002	81881	1231	Санкт-Петербург, улица Джона Рида, 6	f	large
85001	81881	1230	Санкт-Петербург, улица Джона Рида, 6	f	large
85000	81881	1229	Санкт-Петербург, улица Джона Рида, 6	f	large
84999	81881	1228	Санкт-Петербург, улица Джона Рида, 6	f	large
84998	81880	1227	Санкт-Петербург, улица Джона Рида, 3к1	f	large
84997	81880	1226	Санкт-Петербург, улица Джона Рида, 3к1	f	large
84253	81433	396	Санкт-Петербург, улица Демьяна Бедного, 22к5	f	large
84249	81433	392	Санкт-Петербург, улица Демьяна Бедного, 22к5	f	large
84248	81433	391	Санкт-Петербург, улица Демьяна Бедного, 22к5	f	large
84243	81428	386	Санкт-Петербург, улица Демьяна Бедного, 6к2	f	large
84239	81428	382	Санкт-Петербург, улица Демьяна Бедного, 6к2	f	large
84774	81755	976	Санкт-Петербург, Санкт-Петербург, улица Гидростроителей, 4, город Кронштадт	f	large
85512	82230	1822	Санкт-Петербург, улица Восстания, 8	f	large
85521	82230	1831	Санкт-Петербург, улица Восстания, 8	f	large
84328	81480	478	Санкт-Петербург, улица Верности, 38к4	f	large
84327	81479	477	Санкт-Петербург, улица Верности, 38к4	f	large
84287	81450	432	Санкт-Петербург, улица Верности, 14к4	f	large
84286	81450	431	Санкт-Петербург, улица Верности, 14к4	f	large
84288	81449	433	Санкт-Петербург, улица Верности, 28к4	f	large
84285	81449	430	Санкт-Петербург, улица Верности, 28к4	f	large
84201	81411	344	Санкт-Петербург, улица Вавиловых, 5к5	f	large
84204	81411	347	Санкт-Петербург, улица Вавиловых, 5к5	f	large
84203	81411	346	Санкт-Петербург, улица Вавиловых, 5к5	f	large
84200	81410	343	Санкт-Петербург, улица Вавиловых, 8к2	f	large
84197	81410	340	Санкт-Петербург, улица Вавиловых, 8к2	f	large
84283	81447	428	Санкт-Петербург, улица Бутлерова, 22	f	large
84280	81447	425	Санкт-Петербург, улица Бутлерова, 22	f	large
84421	81539	581	Санкт-Петербург, Бурцева, 9	f	large
84420	81539	580	Санкт-Петербург, Бурцева, 9	f	large
84418	81538	578	Санкт-Петербург, Бурцева, 12	f	large
84417	81538	577	Санкт-Петербург, Бурцева, 12	f	large
84419	81538	579	Санкт-Петербург, Бурцева, 12	f	large
84275	81444	419	Санкт-Петербург, Санкт-Петербург, улица Брянцева, 10	f	large
84274	81444	418	Санкт-Петербург, Санкт-Петербург, улица Брянцева, 10	f	large
84273	81444	417	Санкт-Петербург, Санкт-Петербург, улица Брянцева, 10	f	large
84267	81439	411	Санкт-Петербург, улица Брянцева, 24	f	large
84266	81439	410	Санкт-Петербург, улица Брянцева, 24	f	large
84265	81439	409	Санкт-Петербург, улица Брянцева, 24	f	large
85063	81916	1300	Санкт-Петербург, Блохина, 31	f	large
85061	81916	1297	Санкт-Петербург, Блохина, 31	f	large
85339	82123	1628	Санкт-Петербург, улица Белы Куна, 24к2	f	large
85340	82123	1629	Санкт-Петербург, улица Белы Куна, 24к2	f	large
85037	81905	1272	Санкт-Петербург, улица Бабушкина, 119	f	large
85030	81901	1265	Санкт-Петербург, Бабушкина, 56, корп. 1	f	large
85029	81901	1264	Санкт-Петербург, Бабушкина, 56, корп. 1	f	large
85026	81898	1261	Санкт-Петербург, Бабушкина, 50	f	large
85025	81898	1260	Санкт-Петербург, Бабушкина, 50	f	large
85024	81898	1259	Санкт-Петербург, Бабушкина, 50	f	large
85020	81896	1255	Санкт-Петербург, Бабушкина, 65	f	large
85019	81896	1254	Санкт-Петербург, Бабушкина, 65	f	large
85021	81896	1256	Санкт-Петербург, Бабушкина, 65	f	large
84167	81384	299	Санкт-Петербург, улица Асафьева, 6к1	f	large
84171	81384	303	Санкт-Петербург, улица Асафьева, 6к1	f	large
84168	81384	300	Санкт-Петербург, улица Асафьева, 6к1	f	large
84199	81406	342	Санкт-Петербург, улица Академика Константинова, 10к2	f	large
84198	81406	341	Санкт-Петербург, улица Академика Константинова, 10к2	f	large
84192	81406	334	Санкт-Петербург, улица Академика Константинова, 10к2	f	large
84194	81408	337	Санкт-Петербург, улица Академика Байкова, 15	f	large
84843	81808	1055	Санкт-Петербург, проспект Юрия Гагарина, 51	f	large
84844	81808	1056	Санкт-Петербург, проспект Юрия Гагарина, 51	f	large
84820	81798	1032	Санкт-Петербург, проспект Юрия Гагарина, 22к1	f	large
84819	81798	1031	Санкт-Петербург, проспект Юрия Гагарина, 22к1	f	large
84821	81798	1033	Санкт-Петербург, проспект Юрия Гагарина, 22к1	f	large
84818	81797	1030	Санкт-Петербург, Санкт-Петербург, проспект Юрия Гагарина, 16к2	f	large
84629	81653	806	Санкт-Петербург, проспект Энтузиастов, 46к3	f	large
84627	81653	804	Санкт-Петербург, проспект Энтузиастов, 46к3	f	large
84628	81653	805	Санкт-Петербург, проспект Энтузиастов, 46к3	f	large
84625	81650	801	Санкт-Петербург, проспект Энтузиастов, 47к2	f	large
84624	81650	800	Санкт-Петербург, проспект Энтузиастов, 47к2	f	large
84623	81650	799	Санкт-Петербург, проспект Энтузиастов, 47к2	f	large
84559	81617	730	Санкт-Петербург, проспект Энергетиков, 4к2	f	large
84104	81348	228	Санкт-Петербург, проспект Энгельса, 115к2	f	large
84103	81348	227	Санкт-Петербург, проспект Энгельса, 115к2	f	large
84102	81348	226	Санкт-Петербург, проспект Энгельса, 115к2	f	large
84086	81334	208	Санкт-Петербург, проспект Энгельса, 42	f	large
84085	81334	207	Санкт-Петербург, проспект Энгельса, 42	f	large
117751	81328	199	Санкт-Петербург, проспект Энгельса, 119	f	medium
84074	81322	193	Санкт-Петербург, проспект Энгельса, 23	f	large
84051	81303	165	Санкт-Петербург, проспект Энгельса, 23	f	large
84578	81626	749	Санкт-Петербург, проспект Шаумяна, 36	f	large
84576	81626	747	Санкт-Петербург, проспект Шаумяна, 36	f	large
84575	81626	746	Санкт-Петербург, проспект Шаумяна, 36	f	large
84132	81366	263	Санкт-Петербург, проспект Художников, 24к1	f	large
84131	81366	262	Санкт-Петербург, проспект Художников, 24к1	f	large
84133	81366	264	Санкт-Петербург, проспект Художников, 24к1	f	large
84125	81362	256	Санкт-Петербург, проспект Художников, 29к3	f	large
84124	81362	255	Санкт-Петербург, проспект Художников, 29к3	f	large
84126	81362	257	Санкт-Петербург, проспект Художников, 29к3	f	large
84110	81345	234	Санкт-Петербург, проспект Художников, 9к3	f	large
84112	81345	236	Санкт-Петербург, проспект Художников, 9к3	f	large
84111	81345	235	Санкт-Петербург, проспект Художников, 9к3	f	large
84098	81345	221	Санкт-Петербург, проспект Художников, 9к3	f	large
84615	81645	790	Санкт-Петербург, проспект Ударников, 17к2	f	large
84614	81645	789	Санкт-Петербург, проспект Ударников, 17к2	f	large
84612	81645	787	Санкт-Петербург, проспект Ударников, 17к2	f	large
84613	81645	788	Санкт-Петербург, проспект Ударников, 17к2	f	large
84611	81644	786	Санкт-Петербург, проспект Ударников, 22, корп. 3	f	large
84610	81644	785	Санкт-Петербург, проспект Ударников, 22, корп. 3	f	large
84602	81640	777	Санкт-Петербург, проспект Ударников, 31	f	large
84601	81640	776	Санкт-Петербург, проспект Ударников, 31	f	large
84600	81640	775	Санкт-Петербург, проспект Ударников, 31	f	large
84599	81640	774	Санкт-Петербург, проспект Ударников, 31	f	large
84091	81338	213	Санкт-Петербург, проспект Тореза, 94	f	large
84090	81338	212	Санкт-Петербург, проспект Тореза, 94	f	large
84089	81338	211	Санкт-Петербург, проспект Тореза, 94	f	large
84072	81319	188	Санкт-Петербург, проспект Тореза, 37	f	large
84073	81319	189	Санкт-Петербург, проспект Тореза, 37	f	large
117787	81557	614	Санкт-Петербург, проспект Стачек, 158	f	\N
84444	81553	605	Санкт-Петербург, проспект Стачек, 206	f	large
84397	81527	554	Санкт-Петербург, Санкт-Петербург, проспект Стачек, 103к2	f	large
84395	81527	552	Санкт-Петербург, Санкт-Петербург, проспект Стачек, 103к2	f	large
84394	81527	551	Санкт-Петербург, Санкт-Петербург, проспект Стачек, 103к2	f	large
84396	81527	553	Санкт-Петербург, Санкт-Петербург, проспект Стачек, 103к2	f	large
84990	81877	1219	Санкт-Петербург, проспект Солидарности, 1к2	f	large
84989	81877	1218	Санкт-Петербург, проспект Солидарности, 1к2	f	large
84988	81877	1217	Санкт-Петербург, проспект Солидарности, 1к2	f	large
84987	81876	1216	Санкт-Петербург, проспект Солидарности, 3к4	f	large
84986	81876	1215	Санкт-Петербург, проспект Солидарности, 3к4	f	large
84985	81876	1214	Санкт-Петербург, проспект Солидарности, 3к4	f	large
84972	81871	1201	Санкт-Петербург, проспект Солидарности, 11к2	f	large
84971	81871	1200	Санкт-Петербург, проспект Солидарности, 11к2	f	large
84970	81871	1199	Санкт-Петербург, проспект Солидарности, 11к2	f	large
85389	82148	1686	Санкт-Петербург, Санкт-Петербург, проспект Славы, 35к2, муниципальное образование муниципальный округ Георгиевский	f	large
85388	82148	1685	Санкт-Петербург, Санкт-Петербург, проспект Славы, 35к2, муниципальное образование муниципальный округ Георгиевский	f	large
85387	82147	1677	Санкт-Петербург, проспект Славы, 6к2	f	large
85386	82147	1676	Санкт-Петербург, проспект Славы, 6к2	f	large
85385	82147	1675	Санкт-Петербург, проспект Славы, 6к2	f	large
85368	82139	1657	Санкт-Петербург, проспект Славы, 40к5	f	large
85367	82139	1656	Санкт-Петербург, проспект Славы, 40к5	f	large
85202	82028	1466	Санкт-Петербург, Санкт-Петербург, проспект Сизова, 32к3	f	large
85201	82028	1465	Санкт-Петербург, Санкт-Петербург, проспект Сизова, 32к3	f	large
85200	82028	1464	Санкт-Петербург, Санкт-Петербург, проспект Сизова, 32к3	f	large
85199	82028	1463	Санкт-Петербург, Санкт-Петербург, проспект Сизова, 32к3	f	large
83970	81205	19	Санкт-Петербург, Санкт-Петербург, проспект Римского-Корсакова, 4	f	large
84070	81318	186	Санкт-Петербург, проспект Раевского, 18	f	large
84071	81318	187	Санкт-Петербург, проспект Раевского, 18	f	large
85005	81883	1234	Санкт-Петербург, проспект Пятилеток, 6к3	f	large
84238	81427	381	Санкт-Петербург, проспект Просвещения, 106к2	f	large
84237	81427	380	Санкт-Петербург, проспект Просвещения, 106к2	f	large
84236	81427	379	Санкт-Петербург, проспект Просвещения, 106к2	f	large
84156	81378	288	Санкт-Петербург, Санкт-Петербург, проспект Просвещения, 32к4, муниципальное образование муниципальный округ Шувалово-Озерки	f	large
84155	81378	287	Санкт-Петербург, Санкт-Петербург, проспект Просвещения, 32к4, муниципальное образование муниципальный округ Шувалово-Озерки	f	large
84154	81378	286	Санкт-Петербург, Санкт-Петербург, проспект Просвещения, 32к4, муниципальное образование муниципальный округ Шувалово-Озерки	f	large
84140	81370	271	Санкт-Петербург, проспект Просвещения, 46	f	large
84139	81370	270	Санкт-Петербург, проспект Просвещения, 46	f	large
84138	81370	269	Санкт-Петербург, проспект Просвещения, 46	f	large
84076	81324	195	Санкт-Петербург, проспект Пархоменко, 24	f	large
117746	81321	190	Санкт-Петербург, проспект Пархоменко, 17, школа № 117, тел. 552-88-28	f	\N
117748	81321	192	Санкт-Петербург, проспект Пархоменко, 17, школа № 117, тел. 552-88-28	f	\N
117747	81321	191	Санкт-Петербург, проспект Пархоменко, 17, школа № 117, тел. 552-88-28	f	\N
85040	81906	1275	Санкт-Петербург, проспект Обуховской Обороны, 257	f	large
85039	81906	1274	Санкт-Петербург, проспект Обуховской Обороны, 257	f	large
85038	81906	1273	Санкт-Петербург, проспект Обуховской Обороны, 257	f	large
84278	81445	423	Санкт-Петербург, проспект Непокорённых, 16к1	f	large
84276	81403	420	Санкт-Петербург, проспект Непокорённых, 12к2	f	large
84187	81403	329	Санкт-Петербург, проспект Непокорённых, 12к2	f	large
117774	81456	443	Санкт-Петербург, Санкт-Петербург, проспект Науки, 38, помещение клуба "Прожектор" 	f	\N
84296	81455	441	Санкт-Петербург, проспект Науки, 30к3	f	large
84297	81455	442	Санкт-Петербург, проспект Науки, 30к3	f	large
84295	81454	440	Санкт-Петербург, проспект Науки, 24к3	f	large
84294	81454	439	Санкт-Петербург, проспект Науки, 24к3	f	large
84214	81414	357	Санкт-Петербург, проспект Науки, 16к2	f	large
84209	81414	352	Санкт-Петербург, проспект Науки, 16к2	f	large
84191	81405	333	Санкт-Петербург, проспект Науки, 13к4	f	large
84190	81405	332	Санкт-Петербург, проспект Науки, 13к4	f	large
84189	81405	331	Санкт-Петербург, проспект Науки, 13к4	f	large
84605	81641	780	Санкт-Петербург, проспект Наставников, 40, корп. 2	f	large
84604	81641	779	Санкт-Петербург, проспект Наставников, 40, корп. 2	f	large
84603	81641	778	Санкт-Петербург, проспект Наставников, 40, корп. 2	f	large
84587	81633	762	Санкт-Петербург, проспект Наставников, 11к1	f	large
84586	81633	761	Санкт-Петербург, проспект Наставников, 11к1	f	large
117802	81662	820	Санкт-Петербург, проспект Наставников, 11к2, школа №182	f	\N
84732	81720	926	Санкт-Петербург, проспект Народного Ополчения, 223	f	large
84434	81548	595	Санкт-Петербург, проспект Народного Ополчения, 135	f	large
84433	81548	594	Санкт-Петербург, проспект Народного Ополчения, 135	f	large
84386	81521	543	Санкт-Петербург, проспект Народного Ополчения, 103	f	large
84385	81521	542	Санкт-Петербург, проспект Народного Ополчения, 103	f	large
117778	81473	468	Санкт-Петербург, проспект Мечникова, 5к1, помещение школы № 653	f	\N
84318	81472	467	Санкт-Петербург, проспект Мечникова, 2	f	large
84317	81471	466	Санкт-Петербург, проспект Мечникова, 16	f	large
84558	81616	729	Санкт-Петербург, проспект Металлистов, 23	f	large
84555	81616	726	Санкт-Петербург, проспект Металлистов, 23	f	large
84662	81677	847	Санкт-Петербург, проспект Маршала Жукова, 33к2	f	large
84661	81677	846	Санкт-Петербург, проспект Маршала Жукова, 33к2	f	large
84660	81677	845	Санкт-Петербург, проспект Маршала Жукова, 33к2	f	large
84522	81602	692	Санкт-Петербург, проспект Маршала Блюхера, 44к1	f	large
84521	81602	691	Санкт-Петербург, проспект Маршала Блюхера, 44к1	f	large
84520	81602	690	Санкт-Петербург, проспект Маршала Блюхера, 44к1	f	large
117769	81400	326	Россия, Вологодская область, Череповец, Луначарского проспект, 5	f	\N
84792	81774	998	Санкт-Петербург, Санкт-Петербург, проспект Ленина, 2	f	large
84791	81773	997	Санкт-Петербург, Санкт-Петербург, проспект Ленина, 15к2	f	large
84769	81751	970	Санкт-Петербург, Санкт-Петербург, проспект Ленина, 51, Кронштад	f	large
84764	81747	965	Санкт-Петербург, Санкт-Петербург, проспект Ленина, 15, город Кронштадт	f	large
84747	81732	944	Санкт-Петербург, Санкт-Петербург, проспект Ленина, 85, Красное Село	f	large
117814	81727	937	Санкт-Петербург, Санкт-Петербург, проспект Ленина, 42	f	medium
84247	81432	390	Санкт-Петербург, проспект Культуры, 27к3	f	large
84252	81432	395	Санкт-Петербург, проспект Культуры, 27к3	f	large
84251	81432	394	Санкт-Петербург, проспект Культуры, 27к3	f	large
84250	81432	393	Санкт-Петербург, проспект Культуры, 27к3	f	large
84244	81429	387	Санкт-Петербург, проспект Культуры, 11к4	f	large
84240	81429	383	Санкт-Петербург, проспект Культуры, 11к4	f	large
84241	81429	384	Санкт-Петербург, проспект Культуры, 11к4	f	large
84681	81688	868	Санкт-Петербург, проспект Кузнецова, 19	f	large
84680	81688	867	Санкт-Петербург, проспект Кузнецова, 19	f	large
84679	81688	866	Санкт-Петербург, проспект Кузнецова, 19	f	large
84678	81687	865	Санкт-Петербург, проспект Кузнецова, 25к3	f	large
84677	81687	864	Санкт-Петербург, проспект Кузнецова, 25к3	f	large
84674	81685	861	Санкт-Петербург, проспект Кузнецова, 25к1	f	large
84673	81685	860	Санкт-Петербург, проспект Кузнецова, 25к1	f	large
84672	81685	859	Санкт-Петербург, проспект Кузнецова, 25к1	f	large
117806	81668	828	Санкт-Петербург, Санкт-Петербург, проспект Кузнецова, 25к3, гимназия № 271	f	\N
84775	81756	979	Санкт-Петербург, Санкт-Петербург, проспект Красных Командиров, 15	f	large
84621	81646	797	Санкт-Петербург, проспект Косыгина, 28к3	f	large
84620	81646	796	Санкт-Петербург, проспект Косыгина, 28к3	f	large
84619	81646	795	Санкт-Петербург, проспект Косыгина, 28к3	f	large
84593	81637	768	Санкт-Петербург, проспект Косыгина, 25к2	f	large
84595	81637	770	Санкт-Петербург, проспект Косыгина, 25к2	f	large
84594	81637	769	Санкт-Петербург, проспект Косыгина, 25к2	f	large
84826	81800	1038	Санкт-Петербург, проспект Космонавтов, 28к4	f	large
84825	81800	1037	Санкт-Петербург, проспект Космонавтов, 28к4	f	large
84824	81800	1036	Санкт-Петербург, проспект Космонавтов, 28к4	f	large
84823	81799	1035	Санкт-Петербург, проспект Космонавтов, 20к4	f	large
84822	81799	1034	Санкт-Петербург, проспект Космонавтов, 20к4	f	large
84817	81796	1029	Санкт-Петербург, проспект Космонавтов, 21к1	f	large
84816	81796	1028	Санкт-Петербург, проспект Космонавтов, 21к1	f	large
85250	82052	1516	Санкт-Петербург, проспект Королёва, 47к2	f	large
85249	82052	1515	Санкт-Петербург, проспект Королёва, 47к2	f	large
85246	82050	1512	Санкт-Петербург, проспект Королёва, 11	f	large
85244	82050	1510	Санкт-Петербург, проспект Королёва, 11	f	large
85245	82050	1511	Санкт-Петербург, проспект Королёва, 11	f	large
85243	82032	1509	Санкт-Петербург, проспект Королёва, 8	f	large
85241	82032	1507	Санкт-Петербург, проспект Королёва, 8	f	large
85242	82032	1508	Санкт-Петербург, проспект Королёва, 8	f	large
117887	82017	1941	Россия, Московская область, Королев, микрорайон Костино, проспект Королева	f	\N
117886	82012	1857	Россия, Московская область, Королев, микрорайон Костино, проспект Королева, 11	f	\N
84049	81294	147	Санкт-Петербург, Санкт-Петербург, проспект КИМа, 11	f	large
84045	81294	143	Санкт-Петербург, Санкт-Петербург, проспект КИМа, 11	f	large
85007	81888	1241	Санкт-Петербург, проспект Елизарова, 7	f	large
85008	81888	1242	Санкт-Петербург, проспект Елизарова, 7	f	large
85101	81952	1348	Санкт-Петербург, проспект Динамо, 14	f	large
84724	81715	918	Санкт-Петербург, проспект Ветеранов, 166	f	large
84716	81708	908	Санкт-Петербург, проспект Ветеранов, 140к2	f	large
84715	81708	907	Санкт-Петербург, проспект Ветеранов, 140к2	f	large
84697	81698	886	Санкт-Петербург, проспект Ветеранов, 135к1	f	large
84691	81693	880	Санкт-Петербург, проспект Ветеранов, 151, корп. 3	f	large
84690	81693	879	Санкт-Петербург, проспект Ветеранов, 151, корп. 3	f	large
84449	81555	610	Санкт-Петербург, проспект Ветеранов, 57	f	large
84448	81555	609	Санкт-Петербург, проспект Ветеранов, 57	f	large
84446	81551	607	Санкт-Петербург, проспект Ветеранов, 39	f	large
84445	81551	606	Санкт-Петербург, проспект Ветеранов, 39	f	large
84440	81551	601	Санкт-Петербург, проспект Ветеранов, 39	f	large
84423	81540	583	Санкт-Петербург, проспект Ветеранов, 114к2	f	large
84422	81540	582	Санкт-Петербург, проспект Ветеранов, 114к2	f	large
84413	81535	573	Санкт-Петербург, проспект Ветеранов, 80	f	large
84412	81535	572	Санкт-Петербург, проспект Ветеранов, 80	f	large
84411	81535	571	Санкт-Петербург, проспект Ветеранов, 80	f	large
84404	81531	564	Санкт-Петербург, проспект Ветеранов, 87к2	f	large
84403	81531	563	Санкт-Петербург, проспект Ветеранов, 87к2	f	large
84402	81531	562	Санкт-Петербург, проспект Ветеранов, 87к2	f	large
84377	81517	534	Санкт-Петербург, Санкт-Петербург, проспект Ветеранов, 14	f	large
84378	81515	535	Санкт-Петербург, проспект Ветеранов, 14	f	large
84376	81515	533	Санкт-Петербург, проспект Ветеранов, 14	f	large
84969	81870	1198	Санкт-Петербург, проспект Большевиков, 4к1	f	large
84968	81870	1197	Санкт-Петербург, проспект Большевиков, 4к1	f	large
84967	81870	1196	Санкт-Петербург, проспект Большевиков, 4к1	f	large
84966	81870	1195	Санкт-Петербург, проспект Большевиков, 4к1	f	large
84965	81870	1194	Санкт-Петербург, проспект Большевиков, 4к1	f	large
84943	81858	1172	Санкт-Петербург, проспект Большевиков, 23	f	large
84942	81858	1171	Санкт-Петербург, проспект Большевиков, 23	f	large
84941	81858	1170	Санкт-Петербург, проспект Большевиков, 23	f	large
84940	81858	1169	Санкт-Петербург, проспект Большевиков, 23	f	large
84939	81858	1168	Санкт-Петербург, проспект Большевиков, 23	f	large
84923	81850	1152	Санкт-Петербург, проспект Большевиков, 28	f	large
84922	81850	1151	Санкт-Петербург, проспект Большевиков, 28	f	large
85036	81904	1271	Санкт-Петербург, проспект Александровской Фермы, 11	f	large
85035	81904	1270	Санкт-Петербург, проспект Александровской Фермы, 11	f	large
85034	81904	1269	Санкт-Петербург, проспект Александровской Фермы, 11	f	large
85267	82061	1535	Санкт-Петербург, проспект Авиаконструкторов, 22	f	large
85266	82061	1534	Санкт-Петербург, проспект Авиаконструкторов, 22	f	large
85265	82061	1533	Санкт-Петербург, проспект Авиаконструкторов, 22	f	large
85264	82060	1532	Санкт-Петербург, проспект Авиаконструкторов, 35к1	f	large
85263	82060	1531	Санкт-Петербург, проспект Авиаконструкторов, 35к1	f	large
117853	82058	1526	Санкт-Петербург, проспект Авиаконструкторов, 29к3	f	\N
85259	82057	1525	Санкт-Петербург, проспект Авиаконструкторов, 21к2	f	large
85258	82057	1524	Санкт-Петербург, проспект Авиаконструкторов, 21к2	f	large
85262	82049	1530	Санкт-Петербург, проспект Авиаконструкторов, 14	f	large
85261	82049	1529	Санкт-Петербург, проспект Авиаконструкторов, 14	f	large
85260	82049	1528	Санкт-Петербург, проспект Авиаконструкторов, 14	f	large
117854	82036	1527	Санкт-Петербург, проспект Авиаконструкторов, 29к3	f	\N
117855	82067	1544	Санкт-Петербург, Санкт-Петербург, поселок Большая Каменка, 83	f	small
84784	81765	988	Санкт-Петербург, Санкт-Петербург, площадь Свободы, 1	f	large
84782	81763	986	Санкт-Петербург, Санкт-Петербург, площадь Свободы, 6	f	large
84271	81443	415	Санкт-Петербург, Санкт-Петербург, Ушинского, 10	f	large
84761	81744	962	Санкт-Петербург, Санкт-Петербург, площадь Рошаля, 4/11 литер А, Школа Среднего Общего Образования № 423	f	large
84760	81744	961	Санкт-Петербург, Санкт-Петербург, площадь Рошаля, 4/11 литер А, Школа Среднего Общего Образования № 423	f	large
85459	82181	1761	Санкт-Петербург, Санкт-Петербург, площадь Искусств, 2	f	large
84755	81741	955	Санкт-Петербург, Санкт-Петербург, переулок Щуппа, 7, поселок Хвойный	f	large
84048	81296	146	Санкт-Петербург, переулок Каховского, 2	f	large
84047	81296	145	Санкт-Петербург, переулок Каховского, 2	f	large
84046	81295	144	Санкт-Петербург, переулок Каховского, 9	f	large
85486	82210	1790	Санкт-Петербург, Санкт-Петербург, переулок Джамбула, 3	f	large
117690	81201	15	Санкт-Петербург, переулок Бойцова, 3	f	\N
85465	82187	1768	Санкт-Петербург, Санкт-Петербург, набережная реки Фонтанки, 32	f	large
85463	82185	1766	Санкт-Петербург, Санкт-Петербург, набережная реки Фонтанки, 22	f	large
83973	81226	44	Санкт-Петербург, набережная реки Фонтанки, 134а	f	large
117693	81204	18	Санкт-Петербург, набережная реки Фонтанки, 113, ФГБОУ ВПО ""Петербургский государственный университет путей сообщения"""	f	\N
117687	81198	11	Санкт-Петербург, набережная реки Пряжки, 2-4-6, ГОУ СОШ № 235	f	\N
85004	81882	1233	Санкт-Петербург, набережная реки Оккервиль, 10	f	large
85003	81882	1232	Санкт-Петербург, набережная реки Оккервиль, 10	f	large
85458	82180	1760	Санкт-Петербург, Санкт-Петербург, набережная реки Мойки, 38	f	large
85081	81935	1323	Санкт-Петербург, набережная реки Карповки, 11	f	large
117878	82202	1782	Санкт-Петербург, набережная канала Грибоедова, 30-32, Санкт-Петербургский Государственный университет экономики и финансов	f	\N
83988	81252	84	Санкт-Петербург, набережная Лейтенанта Шмидта, 15	f	large
83985	81252	81	Санкт-Петербург, набережная Лейтенанта Шмидта, 15	f	large
83968	81195	8	Санкт-Петербург, набережная Крюкова канала, 15	f	large
84501	81584	668	Санкт-Петербург, Санкт-Петербург, бульвар Трудящихся, 29	f	large
84497	81584	664	Санкт-Петербург, Санкт-Петербург, бульвар Трудящихся, 29	f	large
84500	81584	667	Санкт-Петербург, Санкт-Петербург, бульвар Трудящихся, 29	f	large
84489	81580	656	Санкт-Петербург, Санкт-Петербург, бульвар Трудящихся, 9	f	large
84488	81580	655	Санкт-Петербург, Санкт-Петербург, бульвар Трудящихся, 9	f	large
117790	81578	653	Санкт-Петербург, Санкт-Петербург, бульвар Трудящихся, 12, Школа № 401	f	\N
117789	81577	652	Санкт-Петербург, Санкт-Петербург, бульвар Трудящихся, 10, Школа № 401	f	\N
84435	81547	596	Санкт-Петербург, бульвар Новаторов, 104	f	large
84432	81547	593	Санкт-Петербург, бульвар Новаторов, 104	f	large
84431	81547	592	Санкт-Петербург, бульвар Новаторов, 104	f	large
84382	81519	539	Санкт-Петербург, бульвар Новаторов, 40	f	large
84381	81519	538	Санкт-Петербург, бульвар Новаторов, 40	f	large
84380	81519	537	Санкт-Петербург, бульвар Новаторов, 40	f	large
84373	81514	530	Санкт-Петербург, бульвар Новаторов, 43	f	large
84375	81514	532	Санкт-Петербург, бульвар Новаторов, 43	f	large
84374	81514	531	Санкт-Петербург, бульвар Новаторов, 43	f	large
85033	81902	1268	Санкт-Петербург, бульвар Красных Зорь, 6, корп. 2	f	large
85032	81902	1267	Санкт-Петербург, бульвар Красных Зорь, 6, корп. 2	f	large
85031	81902	1266	Санкт-Петербург, бульвар Красных Зорь, 6, корп. 2	f	large
117870	82113	1612	Брянская область, Брянск, имени А. К. Толстого парк	f	\N
85240	82048	1506	Санкт-Петербург, аллея Поликарпова, 7	f	large
85239	82047	1505	Санкт-Петербург, аллея Поликарпова, 7	f	large
85238	82046	1504	Санкт-Петербург, аллея Поликарпова, 7	f	large
85237	82046	1503	Санкт-Петербург, аллея Поликарпова, 7	f	large
117885	81973	1856	Санкт-Петербург, аллея Поликарпова, 7	f	\N
85171	82010	1434	Санкт-Петербург, Яхтенная улица, 7к3	f	large
85170	82010	1433	Санкт-Петербург, Яхтенная улица, 7к3	f	large
85169	82010	1432	Санкт-Петербург, Яхтенная улица, 7к3	f	large
85158	82000	1419	Санкт-Петербург, Яхтенная улица, 33к3	f	large
85157	82000	1418	Санкт-Петербург, Яхтенная улица, 33к3	f	large
85156	82000	1417	Санкт-Петербург, Яхтенная улица, 33к3	f	large
84087	81336	209	Санкт-Петербург, Ярославский проспект, 20	f	large
85443	82170	1741	Санкт-Петербург, Санкт-Петербург, Ярослава Гашека, 10к2	f	large
85442	82170	1740	Санкт-Петербург, Санкт-Петербург, Ярослава Гашека, 10к2	f	large
85441	82170	1739	Санкт-Петербург, Санкт-Петербург, Ярослава Гашека, 10к2	f	large
85422	82161	1720	Санкт-Петербург, Санкт-Петербург, Ярослава Гашека, 4к4	f	large
85421	82161	1719	Санкт-Петербург, Санкт-Петербург, Ярослава Гашека, 4к4	f	large
85420	82161	1718	Санкт-Петербург, Санкт-Петербург, Ярослава Гашека, 4к4	f	large
85113	81968	1367	Санкт-Петербург, Санкт-Петербург, Эрлеровский бульвар, 1/35	f	large
85114	81968	1368	Санкт-Петербург, Санкт-Петербург, Эрлеровский бульвар, 1/35	f	large
85504	82224	1814	Санкт-Петербург, Шпалерная улица, 50а	f	large
117793	81595	678	Санкт-Петербург, Шлиссельбургское, 219, поселок Усть-Ижора	f	medium
85060	81914	1295	Санкт-Петербург, Санкт-Петербург, Шлиссельбургский проспект, 24к2	f	large
85059	81914	1294	Санкт-Петербург, Санкт-Петербург, Шлиссельбургский проспект, 24к2	f	large
85058	81914	1293	Санкт-Петербург, Санкт-Петербург, Шлиссельбургский проспект, 24к2	f	large
85057	81913	1292	Санкт-Петербург, Шлиссельбургский проспект, 43	f	large
85056	81913	1291	Санкт-Петербург, Шлиссельбургский проспект, 43	f	large
85055	81913	1290	Санкт-Петербург, Шлиссельбургский проспект, 43	f	large
85047	81909	1282	Санкт-Петербург, Шлиссельбургский проспект, 10	f	large
85046	81909	1281	Санкт-Петербург, Шлиссельбургский проспект, 10	f	large
85045	81909	1280	Санкт-Петербург, Шлиссельбургский проспект, 10	f	large
85044	81909	1279	Санкт-Петербург, Шлиссельбургский проспект, 10	f	large
84185	81398	324	Санкт-Петербург, Санкт-Петербург, Школьный переулок (Осиновая Роща), 1	f	large
117879	82245	1849	Санкт-Петербург, Санкт-Петербург, Школьный переулок, 1	f	\N
85174	82011	1437	Санкт-Петербург, Санкт-Петербург, Школьная, 114к3	f	large
85173	82011	1436	Санкт-Петербург, Санкт-Петербург, Школьная, 114к3	f	large
85172	82011	1435	Санкт-Петербург, Санкт-Петербург, Школьная, 114к3	f	large
84512	81598	681	Санкт-Петербург, посёлок Усть-Ижора, поселок Металлострой, Школьная, 8	f	large
84549	81612	720	Санкт-Петербург, Шепетовская улица, 5	f	large
84547	81612	718	Санкт-Петербург, Шепетовская улица, 5	f	large
84546	81612	717	Санкт-Петербург, Шепетовская улица, 5	f	large
84014	81274	111	Санкт-Петербург, Санкт-Петербург, Шевченко, 36	f	large
84013	81274	110	Санкт-Петербург, Санкт-Петербург, Шевченко, 36	f	large
117729	81273	109	Санкт-Петербург, Шевченко, 23к2, Лицей № 30	f	\N
117836	81676	1336	Санкт-Петербург, Шамшева улица, 8, ДК им. Шелгунова тел. 235-56-49	f	\N
85099	81950	1346	Санкт-Петербург, Чкаловский проспект, 22	f	large
85098	81950	1345	Санкт-Петербург, Чкаловский проспект, 22	f	large
117835	81942	1333	Санкт-Петербург, Санкт-Петербург, Чкаловский проспект, 22, школа №51 тел. 235-46-89	f	\N
85084	81938	1326	Санкт-Петербург, Чкаловский проспект, 35	f	large
85275	82066	1543	Санкт-Петербург, Санкт-Петербург, Чистяковская, 4	f	large
85006	81887	1240	Санкт-Петербург, Хрустальная улица, 12	f	large
85526	82238	1836	Санкт-Петербург, Санкт-Петербург, Херсонская , 9	f	large
85525	82238	1835	Санкт-Петербург, Санкт-Петербург, Херсонская , 9	f	large
84582	81631	757	Санкт-Петербург, Хасанская улица, 18к3	f	large
84581	81631	756	Санкт-Петербург, Хасанская улица, 18к3	f	large
117801	81661	819	Санкт-Петербург, Хасанская , 18к3, Школа здоровья и развития	f	\N
117803	81663	821	Санкт-Петербург, Хасанская, 14к2, школа 151	f	\N
84589	81634	764	Санкт-Петербург, Санкт-Петербург, Хасанская, 14к2	f	large
84588	81634	763	Санкт-Петербург, Санкт-Петербург, Хасанская, 14к2	f	large
85529	82242	1839	Санкт-Петербург, Харьковская, 13	f	large
85129	81978	1384	Санкт-Петербург, Санкт-Петербург, Халтурина, 7	f	large
85502	82222	1812	Санкт-Петербург, Фурштатская улица, 29а	f	large
84810	81791	1022	Санкт-Петербург, Санкт-Петербург, Фрунзе, 22	f	large
84811	81791	1023	Санкт-Петербург, Санкт-Петербург, Фрунзе, 22	f	large
117701	81213	27	Санкт-Петербург, Санкт-Петербург, Фонарный переулок, 4, ГОУ СОШ № 255	f	\N
117702	81213	28	Санкт-Петербург, Санкт-Петербург, Фонарный переулок, 4, ГОУ СОШ № 255	f	\N
117777	81459	447	Санкт-Петербург, Финский переулок, 7	f	\N
85142	81988	1399	Санкт-Петербург, Санкт-Петербург, Федюнинского, 6	f	large
85141	81988	1398	Санкт-Петербург, Санкт-Петербург, Федюнинского, 6	f	large
84305	81463	454	Санкт-Петербург, Санкт-Петербург, Федосеенко, 28	f	large
84304	81463	453	Санкт-Петербург, Санкт-Петербург, Федосеенко, 28	f	large
84302	81463	451	Санкт-Петербург, Санкт-Петербург, Федосеенко, 28	f	large
84272	81443	416	Санкт-Петербург, Санкт-Петербург, Ушинского, 10	f	large
84270	81442	414	Санкт-Петербург, Санкт-Петербург, Ушинского, 16	f	large
84234	81425	377	Санкт-Петербург, Санкт-Петербург, Ушинского, 35к2, муниципальный округ N21	f	large
84233	81425	376	Санкт-Петербург, Санкт-Петербург, Ушинского, 35к2, муниципальный округ N21	f	large
84256	81435	399	Санкт-Петербург, Учительская, 3к1	f	large
84255	81435	398	Санкт-Петербург, Учительская, 3к1	f	large
84257	81434	400	Санкт-Петербург, Учительская улица, 9к3	f	large
84254	81434	397	Санкт-Петербург, Учительская улица, 9к3	f	large
84108	81350	232	Санкт-Петербург, Учебный переулок, 8, корп. 2	f	large
84107	81350	231	Санкт-Петербург, Учебный переулок, 8, корп. 2	f	large
84106	81350	230	Санкт-Петербург, Учебный переулок, 8, корп. 2	f	large
84105	81350	229	Санкт-Петербург, Учебный переулок, 8, корп. 2	f	large
84101	81347	225	Санкт-Петербург, Учебный переулок, 2	f	large
117834	81928	1313	Санкт-Петербург, Санкт-Петербург, Троицкая площадь, 3, ЛенНИИпроект	f	\N
84370	81512	527	Санкт-Петербург, Трамвайный проспект, 22	f	large
84369	81512	526	Санкт-Петербург, Трамвайный проспект, 22	f	large
84183	81396	322	Санкт-Петербург, Санкт-Петербург, Торфяная, 23	f	large
85195	82025	1459	Санкт-Петербург, Санкт-Петербург, Торжковская, 10А	f	large
85194	82025	1458	Санкт-Петербург, Санкт-Петербург, Торжковская, 10А	f	large
85480	82204	1784	Санкт-Петербург, Торговый переулок, 2а	f	large
84778	81758	982	Санкт-Петербург, Санкт-Петербург, Токарева, 5	f	large
84979	81873	1208	Санкт-Петербург, Товарищеский проспект, 28к2	f	large
84978	81873	1207	Санкт-Петербург, Товарищеский проспект, 28к2	f	large
84977	81873	1206	Санкт-Петербург, Товарищеский проспект, 28к2	f	large
84976	81873	1205	Санкт-Петербург, Товарищеский проспект, 28к2	f	large
84975	81873	1204	Санкт-Петербург, Товарищеский проспект, 28к2	f	large
84974	81872	1203	Санкт-Петербург, Санкт-Петербург, Товарищеский проспект, 10к2	f	large
84973	81872	1202	Санкт-Петербург, Санкт-Петербург, Товарищеский проспект, 10к2	f	large
84058	81310	173	Санкт-Петербург, Тобольская улица, 12	f	large
84262	81437	406	Санкт-Петербург, Тимуровская улица, 8к2	f	large
84261	81437	404	Санкт-Петербург, Тимуровская улица, 8к2	f	large
84260	81437	403	Санкт-Петербург, Тимуровская улица, 8к2	f	large
117773	81438	405	Санкт-Петербург, Тимуровская, 8к2, школа № 119	f	\N
85107	81958	1358	Санкт-Петербург, Санкт-Петербург, Театральная аллея, 19	f	large
84469	81567	633	Санкт-Петербург, Санкт-Петербург, Тверская улица, 54к4, город Колпино	f	large
84468	81567	632	Санкт-Петербург, Санкт-Петербург, Тверская улица, 54к4, город Колпино	f	large
84466	81567	630	Санкт-Петербург, Санкт-Петербург, Тверская улица, 54к4, город Колпино	f	large
84463	81565	627	Санкт-Петербург, Санкт-Петербург, Тверская, 23, Колпино	f	large
84461	81564	625	Санкт-Петербург, Санкт-Петербург, Тверская, 13	f	large
84573	81624	744	Санкт-Петербург, Таллинская, 18	f	large
84567	81622	738	Санкт-Петербург, Таллинская, 21	f	large
84570	81620	741	Санкт-Петербург, Таллинская улица, 26к1	f	large
84565	81620	736	Санкт-Петербург, Таллинская улица, 26к1	f	large
84564	81620	735	Санкт-Петербург, Таллинская улица, 26к1	f	large
85069	81925	1309	Санкт-Петербург, Санкт-Петербург, Сытнинская улица, 7, муниципальное образование муниципальный округ Кронверкское	f	large
117832	81919	1302	Санкт-Петербург, Съезжинская улица, 15	f	\N
84269	81440	413	Санкт-Петербург, Суздальский проспект, 93к1	f	large
84268	81440	412	Санкт-Петербург, Суздальский проспект, 93к1	f	large
84572	81623	743	Санкт-Петербург, Санкт-Петербург, Стахановцев, 15к2	f	large
84571	81623	742	Санкт-Петербург, Санкт-Петербург, Стахановцев, 15к2	f	large
83978	81242	60	Санкт-Петербург, Старо-Петергофский проспект, 33	f	large
83977	81242	58	Санкт-Петербург, Старо-Петергофский проспект, 33	f	large
84745	81729	942	Санкт-Петербург, Санкт-Петербург, Спирина, 10, Красное Село	f	large
84744	81729	941	Санкт-Петербург, Санкт-Петербург, Спирина, 10, Красное Село	f	large
85487	82211	1791	Санкт-Петербург, Санкт-Петербург, Социалистическая, 7/11	f	large
84213	81416	356	Санкт-Петербург, Санкт-Петербург, Софьи Ковалевской, 16к6	f	large
84212	81416	355	Санкт-Петербург, Санкт-Петербург, Софьи Ковалевской, 16к6	f	large
85314	82097	1593	Санкт-Петербург, Санкт-Петербург, Софийский бульвар, 9	f	large
85313	82097	1592	Санкт-Петербург, Санкт-Петербург, Софийский бульвар, 9	f	large
85348	82127	1637	Санкт-Петербург, Санкт-Петербург, Софийская, 42к.3	f	large
85346	82126	1635	Санкт-Петербург, Санкт-Петербург, Софийская, 34к3	f	large
85347	82125	1636	Санкт-Петербург, Санкт-Петербург, Софийская, 34к3	f	large
85345	82125	1634	Санкт-Петербург, Санкт-Петербург, Софийская, 34к3	f	large
84475	81570	639	Санкт-Петербург, Санкт-Петербург, Советский бульвар, 29	f	large
84474	81570	638	Санкт-Петербург, Санкт-Петербург, Советский бульвар, 29	f	large
85140	81987	1397	Санкт-Петербург, Санкт-Петербург, Скуридина, 6А	f	large
117847	81998	1413	Санкт-Петербург, Ситцевая улица, 15	f	\N
85152	81997	1412	Санкт-Петербург, Ситцевая, 15	f	large
85151	81997	1411	Санкт-Петербург, Ситцевая, 15	f	large
117761	81377	285	Россия, Московская область, Троицк, Сиреневый бульвар, 8	f	\N
84142	81371	273	Санкт-Петербург, Сиреневый бульвар, 8к2	f	large
84141	81371	272	Санкт-Петербург, Сиреневый бульвар, 8к2	f	large
84129	81364	260	Санкт-Петербург, Сиреневый бульвар, 16к2	f	large
117760	81360	251	Россия, Московская область, Троицк, Сиреневый бульвар, 10	f	\N
117759	81359	250	Россия, Московская область, Троицк, Сиреневый бульвар, 10	f	\N
117758	81358	249	Россия, Московская область, Троицк, Сиреневый бульвар, 10	f	\N
84543	81609	713	Санкт-Петербург, Синявинская, 15	f	large
84539	81609	709	Санкт-Петербург, Синявинская, 15	f	large
117712	81221	39	Санкт-Петербург, Серпуховская, 39, ГОУ СОШ № 317	f	\N
117711	81221	38	Санкт-Петербург, Серпуховская, 39, ГОУ СОШ № 317	f	\N
85236	82045	1502	Санкт-Петербург, Серебристый бульвар, 16к1	f	large
85235	82045	1501	Санкт-Петербург, Серебристый бульвар, 16к1	f	large
85234	82045	1500	Санкт-Петербург, Серебристый бульвар, 16к1	f	large
85233	82043	1499	Санкт-Петербург, Серебристый бульвар, 9	f	large
85232	82043	1498	Санкт-Петербург, Серебристый бульвар, 9	f	large
84196	81409	339	Санкт-Петербург, Светлановский проспект, 40к3	f	large
84195	81409	338	Санкт-Петербург, Светлановский проспект, 40к3	f	large
117772	81407	336	Санкт-Петербург, Светлановский проспект, 38к2, помещение школы № 150	f	\N
84193	81404	335	Санкт-Петербург, Санкт-Петербург, Светлановский проспект, 38к2	f	large
84188	81404	330	Санкт-Петербург, Санкт-Петербург, Светлановский проспект, 38к2	f	large
84079	81330	201	Санкт-Петербург, Светлановский проспект, 31	f	large
84078	81330	200	Санкт-Петербург, Светлановский проспект, 31	f	large
85137	81982	1394	Санкт-Петербург, Санкт-Петербург, Сафронова, 5	f	large
85134	81982	1390	Санкт-Петербург, Санкт-Петербург, Сафронова, 5	f	large
85110	81961	1361	Санкт-Петербург, Санкт-Петербург, Санкт-Петербургское шоссе, 102, поселок Стрельна	f	large
85108	81959	1359	Санкт-Петербург, Санкт-Петербург, Санкт-Петербургское шоссе, 88	f	large
85117	81970	1371	Санкт-Петербург, Санкт-Петербург, Санкт-Петербургский проспект, 43	f	large
85112	81965	1365	Санкт-Петербург, Санкт-Петербург, Санкт-Петербургский проспект, 4	f	large
117845	81993	1405	Санкт-Петербург, Приморский район, Садовая улица, 6	f	\N
117691	81202	16	Санкт-Петербург, Садовая , 52, ГОУ СОШ № 229	f	\N
117846	81994	1406	Санкт-Петербург, Садовая, 6, Дом культуры	f	\N
117865	82107	1605	Санкт-Петербург, Санкт-Петербург, Садовая, 49	f	small
85181	82015	1444	Санкт-Петербург, Санкт-Петербург, Савушкина, 134, корп. 4	f	large
85180	82015	1443	Санкт-Петербург, Санкт-Петербург, Савушкина, 134, корп. 4	f	large
117852	81868	1491	Санкт-Петербург, Савушкина, 134к4, школа № 357	f	\N
84638	81657	815	Санкт-Петербург, Санкт-Петербург, Рябовское шоссе, 126	f	large
84636	81655	813	Санкт-Петербург, Рябовское шоссе, 75	f	large
84635	81655	812	Санкт-Петербург, Рябовское шоссе, 75	f	large
85471	82193	1774	Санкт-Петербург, Санкт-Петербург, Рылеева, 9	f	large
85054	81912	1289	Санкт-Петербург, Рыбацкий проспект, 29к2	f	large
85053	81912	1288	Санкт-Петербург, Рыбацкий проспект, 29к2	f	large
85052	81912	1287	Санкт-Петербург, Рыбацкий проспект, 29к2	f	large
85051	81912	1286	Санкт-Петербург, Рыбацкий проспект, 29к2	f	large
84720	81710	913	Санкт-Петербург, Российский бульвар, 4	f	large
117840	81964	1364	Санкт-Петербург, Ропшинское шоссе, 4	f	\N
117724	81238	55	Санкт-Петербург, Рижский проспект, 31	f	\N
117800	81659	816	Санкт-Петербург, Ржевская улица, 18	f	medium
84789	81770	994	Санкт-Петербург, Санкт-Петербург, Речная, 24/26	f	large
85328	82116	1617	Санкт-Петербург, Санкт-Петербург, Расстанная, 20, литер А	f	large
84053	81305	167	Санкт-Петербург, Новороссийская улица, 48	f	large
85327	82116	1616	Санкт-Петербург, Санкт-Петербург, Расстанная, 20, литер А	f	large
85318	82100	1598	Санкт-Петербург, Санкт-Петербург, Радищева, 22	f	large
117863	82100	1597	Санкт-Петербург, Санкт-Петербург, Радищева, 22	f	medium
85297	82087	1575	Санкт-Петербург, Санкт-Петербург, Пушкинская, 12	f	large
85287	81835	1560	Санкт-Петербург, Санкт-Петербург, Пушкинская, 28/21	f	large
84902	81837	1122	Санкт-Петербург, Пулковское шоссе, 91к2	f	large
117825	81836	1121	Санкт-Петербург, Пулковское шоссе, 65	f	medium
84859	81813	1071	Санкт-Петербург, Пулковское шоссе, 34к2	f	large
84858	81813	1070	Санкт-Петербург, Пулковское шоссе, 34к2	f	large
117844	81992	1404	Санкт-Петербург, Санкт-Петербург, Пулемётчиков, 6	f	medium
85102	81954	1350	Санкт-Петербург, Пудожская улица, 4б	f	large
85089	81943	1334	Санкт-Петербург, Санкт-Петербург, Пудожская, 4б	f	large
85522	82236	1832	Санкт-Петербург, Санкт-Петербург, Прудковский переулок, 1/8	f	large
85082	81936	1324	Санкт-Петербург, Санкт-Петербург, Профессора Попова, 25	f	large
85147	81995	1407	Санкт-Петербург, Санкт-Петербург, Приморское шоссе, 48	f	large
84796	81782	1006	Санкт-Петербург, Санкт-Петербург, Приморское шоссе, 703	f	large
84786	81766	990	Санкт-Петербург, Санкт-Петербург, Приморское шоссе, 308А	f	large
84785	81766	989	Санкт-Петербург, Санкт-Петербург, Приморское шоссе, 308А	f	large
85184	82018	1447	Санкт-Петербург, Санкт-Петербург, Приморский проспект, 63	f	large
85179	82014	1442	Санкт-Петербург, Приморский проспект, 157к3	f	large
85178	82014	1441	Санкт-Петербург, Приморский проспект, 157к3	f	large
85177	82013	1440	Санкт-Петербург, Приморский проспект, 143к3	f	large
85176	82013	1439	Санкт-Петербург, Приморский проспект, 143к3	f	large
85175	82013	1438	Санкт-Петербург, Приморский проспект, 143к3	f	large
85362	82136	1651	Санкт-Петербург, Пражская, 25	f	large
85361	82136	1650	Санкт-Петербург, Пражская, 25	f	large
85357	82133	1646	Санкт-Петербург, Пражская улица, 30к1	f	large
85356	82133	1645	Санкт-Петербург, Пражская улица, 30к1	f	large
85353	82130	1642	Санкт-Петербург, Пражская, 36	f	large
85352	82130	1641	Санкт-Петербург, Пражская, 36	f	large
85351	82130	1640	Санкт-Петербург, Пражская, 36	f	large
85338	82122	1627	Санкт-Петербург, Пражская улица, 7к4	f	large
85337	82122	1626	Санкт-Петербург, Пражская улица, 7к4	f	large
85336	82122	1625	Санкт-Петербург, Пражская улица, 7к4	f	large
85335	82122	1624	Санкт-Петербург, Пражская улица, 7к4	f	large
85496	82217	1800	Санкт-Петербург, Санкт-Петербург, Правды, 8	f	large
84135	81367	266	Санкт-Петербург, Поэтический бульвар, 3к2	f	large
84134	81367	265	Санкт-Петербург, Поэтический бульвар, 3к2	f	large
84130	81365	261	Санкт-Петербург, Поэтический бульвар, 5к3	f	large
84136	81365	267	Санкт-Петербург, Поэтический бульвар, 5к3	f	large
84128	81357	259	Санкт-Петербург, Поэтический бульвар, 15	f	large
84127	81357	258	Санкт-Петербург, Поэтический бульвар, 15	f	large
84116	81357	244	Санкт-Петербург, Поэтический бульвар, 15	f	large
84516	81599	685	Санкт-Петербург, посёлок Усть-Ижора, Полевая, 10	f	large
84515	81599	684	Санкт-Петербург, посёлок Усть-Ижора, Полевая, 10	f	large
84514	81599	683	Санкт-Петербург, посёлок Усть-Ижора, Полевая, 10	f	large
84517	81599	686	Санкт-Петербург, посёлок Усть-Ижора, Полевая, 10	f	large
84510	81596	679	Санкт-Петербург, посёлок Усть-Ижора, поселок Металлострой, Полевая, 14	f	large
117856	82071	1553	Санкт-Петербург, Санкт-Петербург, Поклоногорская, 52	f	small
84179	81393	315	Санкт-Петербург, Поклонногорская улица, 17	f	large
84092	81339	214	Санкт-Петербург, Поклонногорская, 17	f	large
84959	81865	1188	Санкт-Петербург, Санкт-Петербург, Подвойского, 18к3	f	large
84958	81865	1187	Санкт-Петербург, Санкт-Петербург, Подвойского, 18к3	f	large
84960	81865	1189	Санкт-Петербург, Санкт-Петербург, Подвойского, 18к3	f	large
84727	81714	921	Санкт-Петербург, Санкт-Петербург, Пограничника Гарькавого, 46к4	f	large
84723	81714	917	Санкт-Петербург, Санкт-Петербург, Пограничника Гарькавого, 46к4	f	large
84695	81696	884	Санкт-Петербург, Санкт-Петербург, Пограничника Гарькавого, 11, корп. 2	f	large
84694	81696	883	Санкт-Петербург, Санкт-Петербург, Пограничника Гарькавого, 11, корп. 2	f	large
117823	81779	1003	Санкт-Петербург, Санкт-Петербург, Пляжевая, 10	f	small
85088	81940	1330	Санкт-Петербург, Плуталова улица, 24	f	large
85086	81940	1328	Санкт-Петербург, Плуталова улица, 24	f	large
85414	82158	1712	Санкт-Петербург, Санкт-Петербург, Пловдивская, 14	f	large
85271	82062	1539	Санкт-Петербург, Планерная улица, 73к1	f	large
85268	82062	1536	Санкт-Петербург, Планерная улица, 73к1	f	large
85270	82063	1538	Санкт-Петербург, Санкт-Петербург, Планерная, 69к2А	f	large
85269	82063	1537	Санкт-Петербург, Санкт-Петербург, Планерная, 69к2А	f	large
84538	81608	708	Санкт-Петербург, Пискарёвский проспект, 13	f	large
84537	81608	707	Санкт-Петербург, Пискарёвский проспект, 13	f	large
84536	81608	706	Санкт-Петербург, Пискарёвский проспект, 13	f	large
84535	81607	705	Санкт-Петербург, Пискарёвский проспект, 13	f	large
84519	81601	689	Санкт-Петербург, Пискаревский проспект, 144	f	large
84322	81476	472	Санкт-Петербург, Пискарёвский проспект, 52	f	large
84321	81476	471	Санкт-Петербург, Пискарёвский проспект, 52	f	large
117797	81382	752	Санкт-Петербург, Санкт-Петербург, Пискарёвский проспект, 145	f	\N
84308	81466	457	Санкт-Петербург, Санкт-Петербург, Пискаревский проспект, 14	f	large
84307	81466	456	Санкт-Петербург, Санкт-Петербург, Пискаревский проспект, 14	f	large
117809	81700	891	Санкт-Петербург, Петергофское шоссе, 82 к. 4, ООО «Евротракт»	f	\N
84650	81670	835	Санкт-Петербург, Петергофское шоссе, 5к4	f	large
84649	81670	834	Санкт-Петербург, Петергофское шоссе, 5к4	f	large
84648	81670	833	Санкт-Петербург, Петергофское шоссе, 5к4	f	large
84645	81669	830	Санкт-Петербург, Петергофское шоссе, 5к3	f	large
84647	81669	832	Санкт-Петербург, Петергофское шоссе, 5к3	f	large
84646	81669	831	Санкт-Петербург, Петергофское шоссе, 5к3	f	large
117804	81664	822	Санкт-Петербург, Санкт-Петербург, Петергофское шоссе, 65	f	small
117889	82074	1943	Санкт-Петербург, Петербургское шоссе, 10, ЛГУ им. Пушкина	f	\N
84561	81618	732	Санкт-Петербург, Перевозный переулок, 19к1	f	large
84560	81618	731	Санкт-Петербург, Перевозный переулок, 19к1	f	large
117862	82088	1576	Санкт-Петербург, Санкт-Петербург, Первомайская, 6, школа № 459	f	\N
117859	82083	1570	Санкт-Петербург, Санкт-Петербург, Первомайская, 6, школа № 459	f	\N
117860	81852	1571	Санкт-Петербург, Санкт-Петербург, Первомайская, 6, лит. А, школа № 459	f	\N
84186	81399	325	Санкт-Петербург, Санкт-Петербург, Первомайская, 37	f	large
85074	81930	1316	Санкт-Петербург, Певческий переулок, 4	f	large
117742	81300	162	Санкт-Петербург, Парголовская улица, 11к2	f	\N
84483	81574	647	Санкт-Петербург, Санкт-Петербург, Павловская, 82	f	large
84482	81574	646	Санкт-Петербург, Санкт-Петербург, Павловская, 82	f	large
84634	81654	811	Санкт-Петербург, Отечественная, 5	f	large
84633	81654	810	Санкт-Петербург, Отечественная, 5	f	large
84632	81654	809	Санкт-Петербург, Отечественная, 5	f	large
84631	81654	808	Санкт-Петербург, Отечественная, 5	f	large
84630	81654	807	Санкт-Петербург, Отечественная, 5	f	large
84708	81705	900	Санкт-Петербург, Санкт-Петербург, Отважных, 6	f	large
84012	81272	108	Санкт-Петербург, Остоумова, 19В	f	large
84640	81660	818	Санкт-Петербург, Санкт-Петербург, Осипенко, 10	f	large
84639	81660	817	Санкт-Петербург, Санкт-Петербург, Осипенко, 10	f	large
84750	81734	947	Санкт-Петербург, Санкт-Петербург, Освобождения, 29	f	large
84080	81331	202	Санкт-Петербург, Санкт-Петербург, Орбели, 24	f	large
117891	82121	1945	Санкт-Петербург, Оранжерейная, 73, общежитие № 8	f	\N
84010	81269	106	Санкт-Петербург, Санкт-Петербург, Опочинина, 35	f	large
84009	81268	105	Санкт-Петербург, Санкт-Петербург, Опочинина, 10, муниципальный округ Гавань	f	large
84008	81268	104	Санкт-Петербург, Санкт-Петербург, Опочинина, 10, муниципальный округ Гавань	f	large
85191	82023	1455	Санкт-Петербург, Омская улица, 16	f	large
84912	81844	1139	Санкт-Петербург, Октябрьская набережная, 118к1	f	large
84911	81844	1138	Санкт-Петербург, Октябрьская набережная, 118к1	f	large
84910	81843	1137	Санкт-Петербург, Октябрьская набережная, 84к1	f	large
84909	81842	1136	Санкт-Петербург, Октябрьская набережная, 84к1	f	large
84908	81841	1135	Санкт-Петербург, Октябрьская набережная, 84к1	f	large
84907	81839	1134	Санкт-Петербург, Октябрьская набережная, 70к2	f	large
84906	81839	1133	Санкт-Петербург, Октябрьская набережная, 70к2	f	large
84574	81625	745	Санкт-Петербург, Новочеркасский проспект, 31	f	large
84569	81621	740	Санкт-Петербург, Новочеркасский проспект, 52к3	f	large
84568	81621	739	Санкт-Петербург, Новочеркасский проспект, 52к3	f	large
84566	81621	737	Санкт-Петербург, Новочеркасский проспект, 52к3	f	large
85096	81948	1343	Санкт-Петербург, Новоладожская, 8	f	large
85095	81948	1342	Санкт-Петербург, Новоладожская, 8	f	large
85283	82070	1552	Санкт-Петербург, Новоколомяжский проспект, 4к4	f	large
85282	82070	1551	Санкт-Петербург, Новоколомяжский проспект, 4к4	f	large
85281	82070	1550	Санкт-Петербург, Новоколомяжский проспект, 4к4	f	large
84777	81757	981	Санкт-Петербург, Санкт-Петербург, Ново-Гагаринская, 39к2, Сестрорецк	f	large
84776	81757	980	Санкт-Петербург, Санкт-Петербург, Ново-Гагаринская, 39к2, Сестрорецк	f	large
85273	82064	1541	Санкт-Петербург, Нижне-Каменская улица, 2	f	large
85272	82064	1540	Санкт-Петербург, Нижне-Каменская улица, 2	f	large
85284	82072	1554	Санкт-Петербург, Санкт-Петербург, Нижне-Каменская , 2	f	large
84050	81301	163	Санкт-Петербург, Нейшлотский переулок, 2	f	large
85530	82239	1840	Санкт-Петербург, Невский проспект, 169	f	large
85527	82239	1837	Санкт-Петербург, Невский проспект, 169	f	large
85479	82203	1783	Санкт-Петербург, Невский проспект, 39	f	large
85476	82199	1779	Санкт-Петербург, Санкт-Петербург, Невский проспект, 108	f	large
84919	81846	1146	Санкт-Петербург, Народная, 44	f	large
84918	81846	1145	Санкт-Петербург, Народная, 44	f	large
84917	81846	1144	Санкт-Петербург, Народная, 44	f	large
84916	81845	1143	Санкт-Петербург, Народная улица, 63	f	large
84915	81845	1142	Санкт-Петербург, Народная улица, 63	f	large
84914	81845	1141	Санкт-Петербург, Народная улица, 63	f	large
84913	81845	1140	Санкт-Петербург, Народная улица, 63	f	large
117726	81243	59	Санкт-Петербург, Нарвский проспект, 6	f	\N
84035	81288	133	Санкт-Петербург, Наличная улица, 44к1	f	large
84034	81288	132	Санкт-Петербург, Наличная улица, 44к1	f	large
84033	81288	131	Санкт-Петербург, Наличная улица, 44к1	f	large
84032	81287	130	Санкт-Петербург, Наличная улица, 44к4	f	large
84031	81287	129	Санкт-Петербург, Наличная улица, 44к4	f	large
84030	81287	128	Санкт-Петербург, Наличная улица, 44к4	f	large
84029	81286	127	Санкт-Петербург, Наличная улица, 46	f	large
117877	82184	1765	Санкт-Петербург, Моховая, 6, Санкт-Петербургский промышленно-экономический колледж	f	\N
84893	81830	1112	Санкт-Петербург, Московский проспект, 203а	f	large
84892	81830	1111	Санкт-Петербург, Московский проспект, 203а	f	large
84891	81830	1110	Санкт-Петербург, Московский проспект, 203а	f	large
84888	81828	1107	Санкт-Петербург, Московский проспект, 169	f	large
84804	81788	1016	Санкт-Петербург, Московский проспект, 164	f	large
84803	81788	1015	Санкт-Петербург, Московский проспект, 164	f	large
84800	81785	1012	Санкт-Петербург, Московский проспект, 112	f	large
84798	81784	1010	Санкт-Петербург, Московский проспект, 96	f	large
84799	81784	1011	Санкт-Петербург, Московский проспект, 96	f	large
84797	81783	1009	Санкт-Петербург, Московский проспект, 80	f	large
83974	81235	52	Санкт-Петербург, Московский проспект, 79	f	large
117692	81203	17	Россия, Московская область, Пушкинский район, Пушкино, Московский проспект, 9/2	f	\N
117730	81285	126	Санкт-Петербург, Морская наб, 15к3, Общежитие ФГБОУ ВПО «Санкт-Петербургский государственный горный университет", тел: 355-45-77	f	\N
84017	81276	114	Санкт-Петербург, Санкт-Петербург, Морская набережная, 15к2	f	large
85135	81984	1392	Санкт-Петербург, Санкт-Петербург, Михайловская, 14	f	large
85072	81927	1312	Санкт-Петербург, Санкт-Петербург, Мира, 4	f	large
85071	81927	1311	Санкт-Петербург, Санкт-Петербург, Мира, 4	f	large
84326	81478	476	Санкт-Петербург, Меншиковский проспект, 15к3	f	large
84325	81478	475	Санкт-Петербург, Меншиковский проспект, 15к3	f	large
84324	81478	474	Санкт-Петербург, Меншиковский проспект, 15к3	f	large
84346	81495	501	Санкт-Петербург, Межевой канал, 6	f	large
84345	81495	500	Санкт-Петербург, Межевой канал, 6	f	large
85165	82007	1428	Санкт-Петербург, Санкт-Петербург, Мебельная, 21к3	f	large
85475	82198	1778	Санкт-Петербург, Санкт-Петербург, Маяковского, 8	f	large
85208	82031	1472	Санкт-Петербург, Санкт-Петербург, Маршала Новикова, 8к2	f	large
85207	82031	1471	Санкт-Петербург, Санкт-Петербург, Маршала Новикова, 8к2	f	large
85206	82031	1470	Санкт-Петербург, Санкт-Петербург, Маршала Новикова, 8к2	f	large
84643	81665	825	Санкт-Петербург, Маршала Захарова, 16к4	f	large
84642	81665	824	Санкт-Петербург, Маршала Захарова, 16к4	f	large
84641	81665	823	Санкт-Петербург, Маршала Захарова, 16к4	f	large
84342	81492	497	Санкт-Петербург, Санкт-Петербург, Маршала Говорова, 34	f	large
117818	81752	971	Санкт-Петербург, Манежный переулок, 1, Школа-сад № 662, 435-08-97	f	\N
85085	81939	1327	Санкт-Петербург, Санкт-Петербург, Малый проспект П.С., 89, муниципальное образование муниципальный округ Аптекарский остров	f	large
83999	81260	95	Санкт-Петербург, Санкт-Петербург, Малый проспект В.О., 34	f	large
117714	81224	42	Санкт-Петербург, Малодетскосельский проспект, 23	f	\N
85456	82176	1755	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская улица, 36, корп. 3	f	large
85429	82164	1727	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская , 7	f	large
85428	82164	1726	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская , 7	f	large
85455	82174	1753	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская, 44	f	large
85454	82174	1752	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская, 44	f	large
85453	82174	1751	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская, 44	f	large
85427	82163	1725	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская, 5к1	f	large
85426	82163	1724	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская, 5к1	f	large
85425	82163	1723	Санкт-Петербург, Санкт-Петербург, Малая Бухарестская, 5к1	f	large
117875	82175	1754	Санкт-Петербург, Малая Балканская , 36к3, школа № 312	f	\N
85438	82168	1736	Санкт-Петербург, Санкт-Петербург, Малая Балканская, 60к3	f	large
85437	82168	1735	Санкт-Петербург, Санкт-Петербург, Малая Балканская, 60к3	f	large
117788	81560	620	Санкт-Петербург, Лёни Голикова, 15к2, школа № 221	f	\N
84790	81771	995	Санкт-Петербург, Санкт-Петербург, Луговая, 4	f	large
117684	81194	7	Санкт-Петербург, Лоцманская, 10, ФГБОУ ВПО Санкт-Петербургский технический университет	f	\N
85473	82195	1776	Санкт-Петербург, Санкт-Петербург, Литейный проспект, 46	f	large
85531	82243	1841	Санкт-Петербург, Лиговский проспект, 70	f	large
85326	82115	1615	Санкт-Петербург, Лиговский проспект, 156	f	large
117722	81234	51	Санкт-Петербург, Лермонтовский проспект, 52	f	\N
117680	81180	2	Санкт-Петербург, Лермонтовский проспект, 21	f	\N
84749	81733	946	Санкт-Петербург, Санкт-Петербург, Лермонтова, 23	f	large
84748	81733	945	Санкт-Петербург, Санкт-Петербург, Лермонтова, 23	f	large
84849	81810	1061	Санкт-Петербург, Санкт-Петербург, Ленсовета, 87к2	f	large
84848	81810	1060	Санкт-Петербург, Санкт-Петербург, Ленсовета, 87к2	f	large
84847	81810	1059	Санкт-Петербург, Санкт-Петербург, Ленсовета, 87к2	f	large
84592	81636	767	Санкт-Петербург, Ленская улица, 2	f	large
84591	81635	766	Санкт-Петербург, Ленская, 1к2	f	large
84590	81635	765	Санкт-Петербург, Ленская, 1к2	f	large
117880	82246	1850	Санкт-Петербург, Ленская, 1к2, ДЮСШ №2	f	\N
117808	81682	854	Санкт-Петербург, Санкт-Петербург, Ленинский проспект, 94к2, Гимназия № 293	f	\N
84659	81675	844	Санкт-Петербург, Санкт-Петербург, Ленинский проспект, 96к2	f	large
84658	81675	843	Санкт-Петербург, Санкт-Петербург, Ленинский проспект, 96к2	f	large
84657	81675	842	Санкт-Петербург, Санкт-Петербург, Ленинский проспект, 96к2	f	large
117805	81667	827	Санкт-Петербург, Санкт-Петербург, Ленинский проспект, 84а, Детский сад	f	\N
84644	81666	826	Санкт-Петербург, Ленинский проспект, 72	f	large
84379	81518	536	Санкт-Петербург, Ленинский проспект, 133, корп. 4	f	large
84372	81513	529	Санкт-Петербург, Ленинский проспект, 123к4	f	large
84371	81513	528	Санкт-Петербург, Ленинский проспект, 123к4	f	large
84368	81511	525	Санкт-Петербург, Ленинский проспект, 124к2	f	large
84367	81511	524	Санкт-Петербург, Ленинский проспект, 124к2	f	large
84366	81511	523	Санкт-Петербург, Ленинский проспект, 124к2	f	large
85311	82096	1590	Санкт-Петербург, Санкт-Петербург, Ленинградская, 2	f	large
85312	82096	1591	Санкт-Петербург, Санкт-Петербург, Ленинградская, 2	f	large
85309	82094	1588	Санкт-Петербург, Санкт-Петербург, Ленинградская, 81, муниципальное образование город Пушкин	f	large
85103	81955	1351	Санкт-Петербург, Левашовский проспект, 5	f	large
84458	81561	622	Санкт-Петербург, Санкт-Петербург, Лагерное шоссе, 32	f	large
84123	81361	254	Санкт-Петербург, Санкт-Петербург, Кустодиева, 18	f	large
84122	81361	253	Санкт-Петербург, Санкт-Петербург, Кустодиева, 18	f	large
84121	81361	252	Санкт-Петербург, Санкт-Петербург, Кустодиева, 18	f	large
117725	81239	56	Санкт-Петербург, Курляндская улица, 43	f	\N
85419	82160	1717	Санкт-Петербург, Купчинская улица, 15к3	f	large
85418	82160	1716	Санкт-Петербург, Купчинская улица, 15к3	f	large
85417	82160	1715	Санкт-Петербург, Купчинская улица, 15к3	f	large
85410	82156	1708	Санкт-Петербург, Купчинская, 11, корп. 4	f	large
85409	82156	1707	Санкт-Петербург, Купчинская, 11, корп. 4	f	large
85408	82156	1706	Санкт-Петербург, Купчинская, 11, корп. 4	f	large
84861	81814	1080	Санкт-Петербург, Санкт-Петербург, Кузнецовская, 20к2	f	large
84860	81814	1079	Санкт-Петербург, Санкт-Петербург, Кузнецовская, 20к2	f	large
84877	81821	1096	Санкт-Петербург, Кубинская, 62	f	large
84876	81821	1095	Санкт-Петербург, Кубинская, 62	f	large
84868	81817	1087	Санкт-Петербург, Кубинская, 46	f	large
84867	81817	1086	Санкт-Петербург, Кубинская, 46	f	large
84866	81816	1085	Санкт-Петербург, Кубинская, 32, корп. 1	f	large
84864	81816	1083	Санкт-Петербург, Кубинская, 32, корп. 1	f	large
84865	81816	1084	Санкт-Петербург, Кубинская, 32, корп. 1	f	large
84927	81853	1156	Санкт-Петербург, Санкт-Петербург, Крыленко, 25к5	f	large
84926	81853	1155	Санкт-Петербург, Санкт-Петербург, Крыленко, 25к5	f	large
84358	81507	514	Санкт-Петербург, Санкт-Петербург, Кронштадтская, 7	f	large
117783	81507	513	Санкт-Петербург, Санкт-Петербург, Кронштадтская, 7	f	medium
117869	82112	1611	Россия, Ленинградская область, Ломоносовский район, деревня Малое Карлино, Красносельское шоссе, 9	f	\N
117872	81922	1614	Россия, Ленинградская область, Ломоносовский район, деревня Малое Карлино, Красносельское шоссе, 14к1	f	\N
117871	81922	1613	Россия, Ленинградская область, Ломоносовский район, деревня Малое Карлино, Красносельское шоссе, 14к1	f	\N
85324	82110	1608	Санкт-Петербург, Санкт-Петербург, Красносельское шоссе, 14к3	f	large
85291	82078	1564	Санкт-Петербург, Санкт-Петербург, Красносельское шоссе, 9	f	large
84740	81725	934	Санкт-Петербург, Санкт-Петербург, Красносельское шоссе, 54к7	f	large
84869	81818	1088	Санкт-Петербург, Краснопутиловская улица, 60	f	large
84360	81505	516	Санкт-Петербург, Краснопутиловская, 22	f	large
84356	81505	511	Санкт-Петербург, Краснопутиловская, 22	f	large
84354	81503	509	Санкт-Петербург, Краснопутиловская улица, 2	f	large
84757	81742	957	Санкт-Петербург, Санкт-Петербург, Красногородская, 7к3, муниципальное образование город Красное Село	f	large
84756	81742	956	Санкт-Петербург, Санкт-Петербург, Красногородская, 7к3, муниципальное образование город Красное Село	f	large
85094	81947	1341	Санкт-Петербург, Санкт-Петербург, Красного Курсанта, 6	f	large
85093	81947	1340	Санкт-Петербург, Санкт-Петербург, Красного Курсанта, 6	f	large
117807	81681	853	Санкт-Петербург, Котина, 6к3, Лицей №590	f	\N
117757	81355	240	Санкт-Петербург, Костромской проспект, 46	f	\N
84088	81337	210	Санкт-Петербург, Костромской проспект, 46	f	large
84036	81290	134	Санкт-Петербург, Санкт-Петербург, Кораблестроителей, 37к5	f	large
84037	81290	135	Санкт-Петербург, Санкт-Петербург, Кораблестроителей, 37к5	f	large
84025	81280	122	Санкт-Петербург, Санкт-Петербург, Кораблестроителей, 21	f	large
84020	81280	117	Санкт-Петербург, Санкт-Петербург, Кораблестроителей, 21	f	large
84022	81280	119	Санкт-Петербург, Санкт-Петербург, Кораблестроителей, 21	f	large
85322	82105	1603	Санкт-Петербург, Санкт-Петербург, Конюшенная, 7	f	large
85321	82104	1602	Санкт-Петербург, Санкт-Петербург, Конюшенная, 24	f	large
85497	82218	1801	Санкт-Петербург, Санкт-Петербург, Константина Заслонова, 23	f	large
84299	81460	448	Санкт-Петербург, Санкт-Петербург, Кондратьевский проспект, 40к7	f	large
84178	81392	314	Санкт-Петербург, Санкт-Петербург, Композиторов, 11к2, муниципальный округ Шувалово-Озерки	f	large
117799	81652	803	Санкт-Петербург, Санкт-Петербург, Коммуны, 42к3, ГОУ гимназия № 628 "Александринская гимназия"	f	\N
84622	81649	798	Санкт-Петербург, Санкт-Петербург, Коммуны, 32, корп. 4	f	large
117881	82247	1851	Санкт-Петербург, Коммуны, 32, школа № 141	f	\N
117882	82248	1853	Санкт-Петербург, Комендантский проспект, 17к3	f	\N
85256	82056	1522	Санкт-Петербург, Комендантский проспект, 37к3	f	large
85257	82056	1523	Санкт-Петербург, Комендантский проспект, 37к3	f	large
85255	82055	1521	Санкт-Петербург, Комендантский проспект, 29к2	f	large
85253	82055	1519	Санкт-Петербург, Комендантский проспект, 29к2	f	large
85252	82054	1518	Санкт-Петербург, Комендантский проспект, 29к1	f	large
85254	82054	1520	Санкт-Петербург, Комендантский проспект, 29к1	f	large
117868	82111	1610	Санкт-Петербург, Санкт-Петербург, Колпинское шоссе, 22, поселок Шушары	f	medium
84984	81875	1213	Санкт-Петербург, Санкт-Петербург, Коллонтай, 41к2	f	large
84983	81875	1212	Санкт-Петербург, Санкт-Петербург, Коллонтай, 41к2	f	large
84962	81867	1191	Санкт-Петербург, Санкт-Петербург, Коллонтай, 19к5	f	large
85511	82229	1821	Санкт-Петербург, Ковенский переулок, 10	f	large
85509	82227	1819	Санкт-Петербург, Кирочная, 54	f	large
85508	82223	1818	Санкт-Петербург, Кирочная, 28а	f	large
85503	82223	1813	Санкт-Петербург, Кирочная, 28а	f	large
85468	82190	1771	Санкт-Петербург, Санкт-Петербург, Кирочная, 8а	f	large
85289	82076	1562	Санкт-Петербург, Санкт-Петербург, Кедринская, 10А	f	large
117876	82177	1758	Санкт-Петербург, Санкт-Петербург, Караванная, 22	f	small
85049	81910	1284	Санкт-Петербург, Караваевская улица, 6	f	large
85048	81910	1283	Санкт-Петербург, Караваевская улица, 6	f	large
85050	81910	1285	Санкт-Петербург, Караваевская улица, 6	f	large
84348	81496	503	Санкт-Петербург, Санкт-Петербург, Канонерский остров, 32	f	large
84347	81496	502	Санкт-Петербург, Санкт-Петербург, Канонерский остров, 32	f	large
117683	81192	6	Санкт-Петербург, Канонерская, 33	f	\N
117681	81192	3	Санкт-Петербург, Канонерская, 33	f	\N
84005	81265	101	Санкт-Петербург, Канареечная, 11	f	large
85153	81999	1414	Санкт-Петербург, Камышовая, 18	f	large
85155	81999	1416	Санкт-Петербург, Камышовая, 18	f	large
85154	81999	1415	Санкт-Петербург, Камышовая, 18	f	large
85104	81956	1352	Санкт-Петербург, Каменноостровский проспект, 64к3	f	large
85087	81941	1329	Санкт-Петербург, Левашовский проспект, 42б	f	large
85083	81937	1325	Санкт-Петербург, Каменноостровский проспект, 69	f	large
85080	81934	1322	Санкт-Петербург, Каменноостровский проспект, 36/73	f	large
83980	81245	75	Санкт-Петербург, Санкт-Петербург, Кадетская линия, 3/5	f	large
83979	81245	74	Санкт-Петербург, Санкт-Петербург, Кадетская линия, 3/5	f	large
85505	82225	1815	Санкт-Петербург, Санкт-Петербург, Кавалергардская, 9	f	large
84609	81643	784	Санкт-Петербург, Санкт-Петербург, Ириновский проспект, 17к5	f	large
84608	81643	783	Санкт-Петербург, Санкт-Петербург, Ириновский проспект, 17к5	f	large
84606	81642	781	Санкт-Петербург, Ириновский проспект, 23к1	f	large
84607	81642	782	Санкт-Петербург, Ириновский проспект, 23к1	f	large
84075	81323	194	Санкт-Петербург, Институтский переулок, 5	f	large
84618	81647	794	Санкт-Петербург, Индустриальный проспект, 10к2	f	large
84617	81647	793	Санкт-Петербург, Индустриальный проспект, 10к2	f	large
84616	81647	792	Санкт-Петербург, Индустриальный проспект, 10к2	f	large
117798	81647	791	Санкт-Петербург, Индустриальный проспект, 10к2	f	medium
85023	81897	1258	Санкт-Петербург, Ивановская улица, 11	f	large
85022	81897	1257	Санкт-Петербург, Ивановская улица, 11	f	large
84456	81558	618	Санкт-Петербург, Санкт-Петербург, Зины Портновой, 25к2	f	large
84455	81558	617	Санкт-Петербург, Санкт-Петербург, Зины Портновой, 25к2	f	large
84454	81558	616	Санкт-Петербург, Санкт-Петербург, Зины Портновой, 25к2	f	large
84453	81558	615	Санкт-Петербург, Санкт-Петербург, Зины Портновой, 25к2	f	large
117810	81701	892	Санкт-Петербург, Санкт-Петербург, Здоровцева, 12	f	small
84852	81811	1064	Санкт-Петербург, Звездная улица, 7	f	large
84851	81811	1063	Санкт-Петербург, Звездная улица, 7	f	large
84850	81811	1062	Санкт-Петербург, Звездная улица, 7	f	large
117833	81917	1303	Санкт-Петербург, Зверинская, 35	f	medium
85062	81917	1298	Санкт-Петербург, Зверинская, 35	f	large
117831	81918	1299	Санкт-Петербург, Санкт-Петербург, Зверинская, 21, отделение в Петроградском районе ГОУ НПО Экономический профессиональный лицей, тел. 232-25-58 	f	\N
85498	82219	1802	Санкт-Петербург, Санкт-Петербург, Звенигородская улица, 30, муниципальное образование муниципальный округ Владимирский округ	f	large
84316	81470	465	Санкт-Петербург, Санкт-Петербург, Замшина, 31к2	f	large
84315	81470	464	Санкт-Петербург, Санкт-Петербург, Замшина, 31к2	f	large
84310	81464	459	Санкт-Петербург, Санкт-Петербург, Замшина, 17	f	large
84303	81464	452	Санкт-Петербург, Санкт-Петербург, Замшина, 17	f	large
84314	81458	463	Санкт-Петербург, Санкт-Петербург, Замшина, 58к2	f	large
84312	81458	461	Санкт-Петербург, Санкт-Петербург, Замшина, 58к2	f	large
84298	81458	445	Санкт-Петербург, Санкт-Петербург, Замшина, 58к2	f	large
84359	81504	515	Санкт-Петербург, Санкт-Петербург, Зайцева, 14	f	large
84355	81504	510	Санкт-Петербург, Санкт-Петербург, Зайцева, 14	f	large
83971	81219	35	Санкт-Петербург, Загородный проспект, 58	f	large
84493	81582	660	Санкт-Петербург, Санкт-Петербург, Заводской проспект, 18, Колпино	f	large
84492	81582	659	Санкт-Петербург, Санкт-Петербург, Заводской проспект, 18, Колпино	f	large
84491	81582	658	Санкт-Петербург, Санкт-Петербург, Заводской проспект, 18, Колпино	f	large
85133	81981	1389	Санкт-Петербург, Санкт-Петербург, Жоры Антоненко, 1	f	large
84181	81390	318	Санкт-Петербург, Санкт-Петербург, Жени Егоровой, 10к2	f	large
84176	81390	312	Санкт-Петербург, Санкт-Петербург, Жени Егоровой, 10к2	f	large
84175	81390	311	Санкт-Петербург, Санкт-Петербург, Жени Егоровой, 10к2	f	large
85306	82091	1585	Санкт-Петербург, Санкт-Петербург, Железнодорожная улица, 54	f	large
85304	82091	1583	Санкт-Петербург, Санкт-Петербург, Железнодорожная улица, 54	f	large
85305	82092	1584	Санкт-Петербург, Санкт-Петербург, Железнодорожная, 56	f	large
84934	81856	1163	Санкт-Петербург, Санкт-Петербург, Евдокима Огнева, 4к2	f	large
84933	81856	1162	Санкт-Петербург, Санкт-Петербург, Евдокима Огнева, 4к2	f	large
84954	81862	1183	Санкт-Петербург, Санкт-Петербург, Дыбенко, 12к2	f	large
84953	81862	1182	Санкт-Петербург, Санкт-Петербург, Дыбенко, 12к2	f	large
84952	81862	1181	Санкт-Петербург, Санкт-Петербург, Дыбенко, 12к2	f	large
84951	81862	1180	Санкт-Петербург, Санкт-Петербург, Дыбенко, 12к2	f	large
84947	81859	1176	Санкт-Петербург, Санкт-Петербург, Дыбенко, 24к4	f	large
84946	81859	1175	Санкт-Петербург, Санкт-Петербург, Дыбенко, 24к4	f	large
84945	81859	1174	Санкт-Петербург, Санкт-Петербург, Дыбенко, 24к4	f	large
84944	81859	1173	Санкт-Петербург, Санкт-Петербург, Дыбенко, 24к4	f	large
85440	82169	1738	Санкт-Петербург, Дунайский проспект, 43, корп. 2	f	large
85439	82169	1737	Санкт-Петербург, Дунайский проспект, 43, корп. 2	f	large
85412	82157	1710	Санкт-Петербург, Дунайский проспект, 48к2	f	large
85411	82157	1709	Санкт-Петербург, Дунайский проспект, 48к2	f	large
85413	82157	1711	Санкт-Петербург, Дунайский проспект, 48к2	f	large
117723	81236	53	Санкт-Петербург, Дровяная улица, 7а	f	\N
84084	81332	206	Санкт-Петербург, Дрезденская улица, 19	f	large
84082	81332	204	Санкт-Петербург, Дрезденская улица, 19	f	large
84081	81332	203	Санкт-Петербург, Дрезденская улица, 19	f	large
84505	81589	673	Санкт-Петербург, Санкт-Петербург, Дорожная, 11	f	large
84718	81707	910	Санкт-Петербург, Санкт-Петербург, Добровольцев, 60к2	f	large
84717	81707	909	Санкт-Петербург, Санкт-Петербург, Добровольцев, 60к2	f	large
84714	81707	906	Санкт-Петербург, Санкт-Петербург, Добровольцев, 60к2	f	large
85398	82152	1696	Санкт-Петербург, Санкт-Петербург, Димитрова, 10к3	f	large
85397	82152	1695	Санкт-Петербург, Санкт-Петербург, Димитрова, 10к3	f	large
85396	82152	1694	Санкт-Петербург, Санкт-Петербург, Димитрова, 10к3	f	large
85298	82089	1577	Санкт-Петербург, Санкт-Петербург, Детскосельский бульвар, 6, муниципальное образование поселок Шушары	f	large
85294	82082	1569	Санкт-Петербург, Санкт-Петербург, Детскосельский бульвар, 17, поселок Шушары	f	large
85293	82082	1568	Санкт-Петербург, Санкт-Петербург, Детскосельский бульвар, 17, поселок Шушары	f	large
84246	81430	389	Санкт-Петербург, Санкт-Петербург, Демьяна Бедного, 12к1	f	large
84245	81430	388	Санкт-Петербург, Санкт-Петербург, Демьяна Бедного, 12к1	f	large
84242	81430	385	Санкт-Петербург, Санкт-Петербург, Демьяна Бедного, 12к1	f	large
85323	82106	1604	Санкт-Петербург, Санкт-Петербург, Декабристов, 16	f	large
85514	82228	1824	Санкт-Петербург, Дегтярный переулок, 24	f	large
85510	82228	1820	Санкт-Петербург, Дегтярный переулок, 24	f	large
85145	81990	1402	Санкт-Петербург, Санкт-Петербург, Дегтярева, 1/7	f	large
117843	81983	1391	Россия, Московская область, Королев, микрорайон Костино, Дворцовый проезд	f	\N
84443	81552	604	Санкт-Петербург, Дачный проспект, 3к2	f	large
84442	81552	603	Санкт-Петербург, Дачный проспект, 3к2	f	large
84441	81552	602	Санкт-Петербург, Дачный проспект, 3к2	f	large
84388	81523	545	Санкт-Петербург, Дачный проспект, 34к1	f	large
84387	81523	544	Санкт-Петербург, Дачный проспект, 34к1	f	large
85470	82192	1773	Санкт-Петербург, Санкт-Петербург, Гродненский переулок, 8/10	f	large
85513	82231	1823	Санкт-Петербург, Греческий проспект, 21	f	large
85518	82231	1828	Санкт-Петербург, Греческий проспект, 21	f	large
84284	81448	429	Санкт-Петербург, Гражданский проспект, 31к1	f	large
84281	81448	426	Санкт-Петербург, Гражданский проспект, 31к1	f	large
84208	81413	351	Санкт-Петербург, Гражданский проспект, 92к3	f	large
84207	81413	350	Санкт-Петербург, Гражданский проспект, 92к3	f	large
84206	81413	349	Санкт-Петербург, Гражданский проспект, 92к3	f	large
84205	81413	348	Санкт-Петербург, Гражданский проспект, 92к3	f	large
84202	81412	345	Санкт-Петербург, Санкт-Петербург, Гражданский проспект, 88к2	f	large
85478	82201	1781	Санкт-Петербург, Гороховая улица, 20	f	large
117866	82108	1606	Санкт-Петербург, Санкт-Петербург, Горная улица, Павловская опытная станция Всероссийского института растениеводства	f	\N
85528	82241	1838	Санкт-Петербург, Гончарная, 15	f	large
84313	81469	462	Санкт-Петербург, Санкт-Петербург, Герасимовская, 5	f	large
84083	81333	205	Санкт-Петербург, Гданьская улица, 19к2	f	large
84812	81793	1024	Санкт-Петербург, Гастелло, 19	f	large
85150	81996	1410	Санкт-Петербург, Гаккелевская улица, 24к1	f	large
85149	81996	1409	Санкт-Петербург, Гаккелевская улица, 24к1	f	large
85148	81996	1408	Санкт-Петербург, Гаккелевская улица, 24к1	f	large
85460	82182	1762	Санкт-Петербург, Санкт-Петербург, Гагаринская, 5	f	large
84016	81275	113	Санкт-Петербург, Гаванская, 54	f	large
84015	81275	112	Санкт-Петербург, Гаванская, 54	f	large
84006	81266	102	Санкт-Петербург, Гаванская, 3	f	large
85105	81957	1353	Санкт-Петербург, Вяземский переулок, 5	f	large
84055	81308	170	Санкт-Петербург, Выборгская, 3	f	large
84056	81308	171	Санкт-Петербург, Выборгская, 3	f	large
85330	82117	1619	Санкт-Петербург, Воронежская улица, 79	f	large
85329	82117	1618	Санкт-Петербург, Воронежская улица, 79	f	large
85109	81960	1360	Санкт-Петербург, Санкт-Петербург, Волхонское шоссе, 26, поселок Стрельна	f	large
84783	81764	987	Санкт-Петербург, Санкт-Петербург, Володарского, 12, Сестрорецк	f	large
85332	82119	1621	Санкт-Петербург, Волковский проспект, 106	f	large
85331	82118	1620	Санкт-Петербург, Волковский проспект, 4а	f	large
85139	81986	1396	Санкт-Петербург, Санкт-Петербург, Владимирская, 28	f	large
85138	81986	1395	Санкт-Петербург, Санкт-Петербург, Владимирская, 28	f	large
84835	81804	1047	Санкт-Петербург, Витебский проспект, 85	f	large
84833	81804	1045	Санкт-Петербург, Витебский проспект, 85	f	large
84834	81804	1046	Санкт-Петербург, Витебский проспект, 85	f	large
84832	81803	1044	Санкт-Петербург, Витебский проспект, 73к1	f	large
84831	81803	1043	Санкт-Петербург, Витебский проспект, 73к1	f	large
84830	81802	1042	Санкт-Петербург, Витебский проспект, 57	f	large
84829	81802	1041	Санкт-Петербург, Витебский проспект, 57	f	large
84828	81801	1040	Санкт-Петербург, Витебский проспект, 49к2	f	large
84827	81801	1039	Санкт-Петербург, Витебский проспект, 49к2	f	large
117688	81199	12	Санкт-Петербург, Витебская, 7, ГС(К)ОУ VIII вида № 231	f	\N
117689	81199	13	Санкт-Петербург, Витебская, 7, ГС(К)ОУ VIII вида № 231	f	\N
84901	81834	1120	Санкт-Петербург, Взлётная улица, 5к1	f	large
84900	81834	1119	Санкт-Петербург, Взлётная улица, 5к1	f	large
84899	81834	1118	Санкт-Петербург, Взлётная улица, 5к1	f	large
84563	81619	734	Санкт-Петербург, Весенняя улица, 10	f	large
84562	81619	733	Санкт-Петербург, Весенняя улица, 10	f	large
117709	81211	36	Санкт-Петербург, Верейская улица, 20	f	\N
117710	81211	37	Санкт-Петербург, Верейская улица, 20	f	\N
117893	81441	1947	Санкт-Петербург, Санкт-Петербург, Веревская, 31, УК ООО Новая Ижора	f	\N
85065	81921	1305	Санкт-Петербург, Введенская, 16	f	large
85064	81920	1304	Санкт-Петербург, Введенская улица, 3	f	large
84887	81827	1106	Санкт-Петербург, Варшавская, 40	f	large
84886	81827	1105	Санкт-Петербург, Варшавская, 40	f	large
84879	81823	1098	Санкт-Петербург, Варшавская улица, 63к1	f	large
84878	81822	1097	Санкт-Петербург, Варшавская улица, 63к1	f	large
84875	81820	1094	Санкт-Петербург, Варшавская улица, 51	f	large
84874	81820	1093	Санкт-Петербург, Варшавская улица, 51	f	large
84873	81820	1092	Санкт-Петербург, Варшавская улица, 51	f	large
84872	81819	1091	Санкт-Петербург, Варшавская улица, 33	f	large
84871	81819	1090	Санкт-Петербург, Варшавская улица, 33	f	large
84870	81819	1089	Санкт-Петербург, Варшавская улица, 33	f	large
84802	81787	1014	Санкт-Петербург, Санкт-Петербург, Варшавская, 30	f	large
85334	82120	1623	Санкт-Петербург, Бухарестская улица, 5	f	large
85333	82120	1622	Санкт-Петербург, Бухарестская улица, 5	f	large
85375	82142	1665	Санкт-Петербург, Санкт-Петербург, Бухарестская, 33к6	f	large
85374	82142	1664	Санкт-Петербург, Санкт-Петербург, Бухарестская, 33к6	f	large
85373	82142	1663	Санкт-Петербург, Санкт-Петербург, Бухарестская, 33к6	f	large
85372	82142	1662	Санкт-Петербург, Санкт-Петербург, Бухарестская, 33к6	f	large
117727	81244	61	Санкт-Петербург, Бумажная улица, 5	f	\N
85449	82172	1747	Санкт-Петербург, Будапештская улица, 93	f	large
85448	82172	1746	Санкт-Петербург, Будапештская улица, 93	f	large
85447	82172	1745	Санкт-Петербург, Будапештская улица, 93	f	large
85416	82159	1714	Санкт-Петербург, Будапештская улица, 79к1	f	large
85415	82159	1713	Санкт-Петербург, Будапештская улица, 79к1	f	large
85393	82150	1690	Санкт-Петербург, Будапештская улица, 35к2	f	large
85392	82150	1689	Санкт-Петербург, Будапештская улица, 35к2	f	large
85391	82149	1688	Санкт-Петербург, Будапештская улица, 64к2	f	large
85390	82149	1687	Санкт-Петербург, Будапештская улица, 64к2	f	large
85376	82143	1666	Санкт-Петербург, Будапештская улица, 30к2	f	large
85344	82124	1633	Санкт-Петербург, Будапештская улица, 8к3	f	large
85343	82124	1632	Санкт-Петербург, Будапештская улица, 8к3	f	large
85342	82124	1631	Санкт-Петербург, Будапештская улица, 8к3	f	large
85341	82124	1630	Санкт-Петербург, Будапештская улица, 8к3	f	large
85379	82144	1669	Санкт-Петербург, Санкт-Петербург, Будапештская, 42к6	f	large
85377	82144	1667	Санкт-Петербург, Санкт-Петербург, Будапештская, 42к6	f	large
85378	82144	1668	Санкт-Петербург, Санкт-Петербург, Будапештская, 42к6	f	large
84320	81475	470	Санкт-Петербург, Брюсовская, 10	f	large
84319	81475	469	Санкт-Петербург, Брюсовская, 10	f	large
83972	81222	40	Санкт-Петербург, Санкт-Петербург, Бронницкая, 34	f	large
84669	81683	856	Санкт-Петербург, Брестский бульвар, 19к2	f	large
84668	81683	855	Санкт-Петербург, Брестский бульвар, 19к2	f	large
85132	81980	1387	Санкт-Петербург, Санкт-Петербург, Ботаническая, 68, Петергоф	f	large
85131	81980	1386	Санкт-Петербург, Санкт-Петербург, Ботаническая, 68, Петергоф	f	large
85123	81974	1378	Санкт-Петербург, Санкт-Петербург, Ботаническая, 6	f	large
85122	81974	1377	Санкт-Петербург, Санкт-Петербург, Ботаническая, 6	f	large
117707	81218	33	Санкт-Петербург, Бородинская, 11, ГОУ Центр образования № 195	f	\N
117708	81218	34	Санкт-Петербург, Бородинская, 11, ГОУ Центр образования № 195	f	\N
85067	81924	1307	Санкт-Петербург, Санкт-Петербург, Большой проспект П.С., 73/36	f	large
117837	81945	1337	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Большой проспект, 25	f	\N
117728	81251	80	Россия, Ленинградская область, Гатчинский район, поселок Сиверский, Большой проспект, 25	f	\N
83992	81255	88	Санкт-Петербург, Санкт-Петербург, Большой проспект В.О, 88	f	large
84066	81314	181	Санкт-Петербург, Санкт-Петербург, Большой Сампсониевский проспект, 86	f	large
84059	81311	174	Санкт-Петербург, Большой Сампсониевский проспект, 86	f	large
84544	81611	715	Санкт-Петербург, Большеохтинский проспект, 11к2	f	large
84542	81611	712	Санкт-Петербург, Большеохтинский проспект, 11к2	f	large
84541	81610	711	Санкт-Петербург, Большеохтинский проспект, 18	f	large
84540	81610	710	Санкт-Петербург, Большеохтинский проспект, 18	f	large
85068	81923	1308	Санкт-Петербург, Большая Пушкарская, 32	f	large
85066	81923	1306	Санкт-Петербург, Большая Пушкарская, 32	f	large
85075	81929	1317	Санкт-Петербург, Большая Посадская улица, 5	f	large
85073	81929	1315	Санкт-Петербург, Большая Посадская улица, 5	f	large
85477	82200	1780	Санкт-Петербург, Большая Морская, 18	f	large
117700	81212	26	Санкт-Петербург, Большая Морская улица, 61	f	\N
117703	81214	29	Санкт-Петербург, Санкт-Петербург, Большая Морская, 33, Санкт-Петербургское государственное учреждение культуры «Центральная городская детская библиотека им.А.С.Пушкина»	f	\N
85070	81926	1310	Санкт-Петербург, Большая Монетная, 2/4	f	large
85100	81951	1347	Санкт-Петербург, Большая Зеленина, 30	f	large
84068	81317	184	Санкт-Петербург, Болотная, 6	f	large
84067	81316	183	Санкт-Петербург, Болотная, 18	f	large
84069	81316	185	Санкт-Петербург, Болотная, 18	f	large
117883	82249	1854	Санкт-Петербург, Богатырский проспект, 19	f	\N
85231	82042	1497	Санкт-Петербург, Богатырский проспект, 7к4	f	large
85230	82042	1496	Санкт-Петербург, Богатырский проспект, 7к4	f	large
85399	82153	1697	Санкт-Петербург, Альпийский переулок, 5к2	f	large
85225	82039	1489	Санкт-Петербург, Санкт-Петербург, Богатырский проспект, 19	f	large
85224	82039	1488	Санкт-Петербург, Санкт-Петербург, Богатырский проспект, 19	f	large
85164	82005	1427	Санкт-Петербург, Санкт-Петербург, Богатырский проспект, 50, корп. 2, муниципальное образование муниципальный округ N65	f	large
85159	82002	1422	Санкт-Петербург, Богатырский проспект, 55к3	f	large
117849	82001	1421	Санкт-Петербург, Богатырский проспект, 61к2, лицей	f	\N
117848	82001	1420	Санкт-Петербург, Богатырский проспект, 61к2, лицей	f	\N
117851	81863	1490	Санкт-Петербург, Санкт-Петербург, Богатырский проспект, 50к2, школа № 655	f	\N
84809	81790	1021	Санкт-Петербург, Благодатная улица, 32	f	large
84808	81790	1020	Санкт-Петербург, Благодатная улица, 32	f	large
84801	81786	1013	Санкт-Петербург, Благодатная, 20	f	large
84863	81815	1082	Санкт-Петербург, Санкт-Петербург, Благодатная , 11, муниципальный округ Новоизмайловское	f	large
84862	81815	1081	Санкт-Петербург, Санкт-Петербург, Благодатная , 11, муниципальный округ Новоизмайловское	f	large
84807	81789	1019	Санкт-Петербург, Санкт-Петербург, Благодатная, 36	f	large
84806	81789	1018	Санкт-Петербург, Санкт-Петербург, Благодатная, 36	f	large
84805	81789	1017	Санкт-Петербург, Санкт-Петербург, Благодатная, 36	f	large
85320	82103	1601	Санкт-Петербург, Санкт-Петербург, Берёзовая, 13	f	large
84019	81279	116	Санкт-Петербург, Санкт-Петербург, Беринга, 38	f	large
84580	81630	755	Санкт-Петербург, Белорусская , 10	f	large
84579	81630	754	Санкт-Петербург, Белорусская , 10	f	large
84584	81632	759	Санкт-Петербург, Санкт-Петербург, Белорусская, 26к2	f	large
84583	81632	758	Санкт-Петербург, Санкт-Петербург, Белорусская, 26к2	f	large
84585	81632	760	Санкт-Петербург, Санкт-Петербург, Белорусская, 26к2	f	large
85384	82146	1674	Санкт-Петербург, Белградская улица, 20к2	f	large
85383	82146	1673	Санкт-Петербург, Белградская улица, 20к2	f	large
85382	82146	1672	Санкт-Петербург, Белградская улица, 20к2	f	large
85381	82145	1671	Санкт-Петербург, Белградская улица, 14к2	f	large
85380	82145	1670	Санкт-Петербург, Белградская улица, 14к2	f	large
85371	82140	1661	Санкт-Петербург, Белградская улица, 8к1	f	large
117873	82140	1660	Санкт-Петербург, Белградская улица, 8к1	f	medium
85369	82140	1658	Санкт-Петербург, Белградская улица, 8к1	f	large
85370	82140	1659	Санкт-Петербург, Белградская улица, 8к1	f	large
84334	81486	488	Санкт-Петербург, Санкт-Петербург, Балтийская, 35	f	large
84333	81486	487	Санкт-Петербург, Санкт-Петербург, Балтийская, 35	f	large
85248	82051	1514	Санкт-Петербург, Байконурская улица, 25	f	large
85247	82051	1513	Санкт-Петербург, Байконурская улица, 25	f	large
85228	82040	1494	Санкт-Петербург, Аэродромная, 11, корп.2	f	large
85227	82040	1493	Санкт-Петербург, Аэродромная, 11, корп.2	f	large
85226	82040	1492	Санкт-Петербург, Аэродромная, 11, корп.2	f	large
85229	82041	1495	Санкт-Петербург, Санкт-Петербург, Аэродромная, 11, корп. 2	f	large
117884	81967	1855	Санкт-Петербург, Аэродромная, 11к2, Гимназия № 66	f	\N
117770	81401	327	Санкт-Петербург, Асафьева, 6к1, школа № 457	f	\N
84180	81383	316	Санкт-Петербург, Санкт-Петербург, Асафьева, 7к2, муниципальное образование муниципальный округ Шувалово-Озерки	f	large
84166	81383	298	Санкт-Петербург, Санкт-Петербург, Асафьева, 7к2, муниципальное образование муниципальный округ Шувалово-Озерки	f	large
84165	81383	297	Санкт-Петербург, Санкт-Петербург, Асафьева, 7к2, муниципальное образование муниципальный округ Шувалово-Озерки	f	large
84164	81383	296	Санкт-Петербург, Санкт-Петербург, Асафьева, 7к2, муниципальное образование муниципальный округ Шувалово-Озерки	f	large
85316	82098	1595	Санкт-Петербург, Санкт-Петербург, Артиллерийская, 7/20	f	large
85315	82098	1594	Санкт-Петербург, Санкт-Петербург, Артиллерийская, 7/20	f	large
117775	81457	444	Санкт-Петербург, Арсенальная набережная, 13к1, фойе Концертного зала	f	\N
117776	81457	446	Санкт-Петербург, Арсенальная набережная, 13к1, фойе Концертного зала	f	\N
84311	81467	460	Санкт-Петербург, Санкт-Петербург, Антоновская, 16	f	large
84309	81467	458	Санкт-Петербург, Санкт-Петербург, Антоновская, 16	f	large
84765	81748	966	Санкт-Петербург, Санкт-Петербург, Андреевская, 5	f	large
85401	82153	1699	Санкт-Петербург, Альпийский переулок, 5к2	f	large
85400	82153	1698	Санкт-Петербург, Альпийский переулок, 5к2	f	large
85395	82151	1693	Санкт-Петербург, Альпийский переулок, 19к2	f	large
85394	82151	1692	Санкт-Петербург, Альпийский переулок, 19к2	f	large
117874	82151	1691	Санкт-Петербург, Альпийский переулок, 19к2	f	medium
84840	81806	1052	Санкт-Петербург, Алтайская, 15	f	large
84839	81806	1051	Санкт-Петербург, Алтайская, 15	f	large
85146	81991	1403	Санкт-Петербург, Санкт-Петербург, Александровская, 6/9	f	large
117705	81216	31	Санкт-Петербург, Адмиралтейская набережная, 4, ГОУ СОШ № 225	f	\N
84365	81510	522	Санкт-Петербург, Автовская улица, 5	f	large
117784	81510	521	Санкт-Петербург, Автовская улица, 5	f	medium
84364	81510	520	Санкт-Петербург, Автовская улица, 5	f	large
84713	81706	905	Санкт-Петербург, Авангардная улица, 43	f	large
84712	81706	904	Санкт-Петербург, Авангардная улица, 43	f	large
84711	81706	903	Санкт-Петербург, Авангардная улица, 43	f	large
84710	81706	902	Санкт-Петербург, Авангардная улица, 43	f	large
84709	81706	901	Санкт-Петербург, Авангардная улица, 43	f	large
84704	81703	896	Санкт-Петербург, Авангардная улица, 21	f	large
84703	81703	895	Санкт-Петербург, Авангардная улица, 21	f	large
85520	82232	1830	Санкт-Петербург, 9-я Советская улица, 31	f	large
85515	82232	1825	Санкт-Петербург, 9-я Советская улица, 31	f	large
85517	82234	1827	Санкт-Петербург, 8-я Советская, 58	f	large
117716	81227	45	Санкт-Петербург, 8-я Красноармейская, 3	f	\N
83983	81248	78	Санкт-Петербург, Санкт-Петербург, 7-я линия ВО, 52/31	f	large
83995	81258	91	Санкт-Петербург, Санкт-Петербург, 7-я линия В.О., 52/31	f	large
117719	81231	48	Санкт-Петербург, 7-я Красноармейская , 12, ФГБОУ ВПО Петербургский государственный университет путей сообщения»общежитие	f	\N
85523	82235	1833	Санкт-Петербург, 6-я Советская, 3	f	large
85519	82235	1829	Санкт-Петербург, 6-я Советская, 3	f	large
84897	81833	1116	Санкт-Петербург, 5-й Предпортовый проезд, 6к1	f	large
84898	81832	1117	Санкт-Петербург, 5-й Предпортовый проезд, 6к1	f	large
84896	81832	1115	Санкт-Петербург, 5-й Предпортовый проезд, 6к1	f	large
84895	81832	1114	Санкт-Петербург, 5-й Предпортовый проезд, 6к1	f	large
84894	81832	1113	Санкт-Петербург, 5-й Предпортовый проезд, 6к1	f	large
85274	82065	1542	Санкт-Петербург, 3-я линия 1-й половины, 10а	f	large
83981	81246	76	Санкт-Петербург, Санкт-Петербург, 2-я линия В.О., 23	f	large
85524	82237	1834	Санкт-Петербург, 2-я Советская улица, 27	f	large
117718	81229	47	Санкт-Петербург, 2-я Красноармейская улица, 4, Санкт-Петербургский государственный архитектурно-строительный университет»	f	\N
84692	81694	881	Санкт-Петербург, 2-я Комсомольская улица, 23к1	f	large
85043	81907	1278	Санкт-Петербург, 2-й Рабфаковский переулок, 1к4	f	large
85042	81907	1277	Санкт-Петербург, 2-й Рабфаковский переулок, 1к4	f	large
85041	81907	1276	Санкт-Петербург, 2-й Рабфаковский переулок, 1к4	f	large
84077	81325	196	Санкт-Петербург, 2-й Муринский проспект, 43	f	large
84001	81261	97	Санкт-Петербург, Санкт-Петербург, 17-я линия В.О., 34	f	large
84002	81263	98	Санкт-Петербург, Санкт-Петербург, 16-я линия В.О., 55	f	large
83987	81253	83	Санкт-Петербург, Санкт-Петербург, 13-я линия В.О., 28	f	large
83986	81253	82	Санкт-Петербург, Санкт-Петербург, 13-я линия В.О., 28	f	large
117717	81228	46	Санкт-Петербург, Санкт-Петербург, 10-я Красноармейская, 5а, ГОУ СОШ № 286	f	\N
84637	81656	814	Санкт-Петербург, Санкт-Петербург, 1-я Жерновская, 8	f	large
84486	81575	650	Санкт-Петербург, Санкт-Петербург, Танкистов, 26	f	large
84485	81575	649	Санкт-Петербург, Санкт-Петербург, Танкистов, 26	f	large
84484	81575	648	Санкт-Петербург, Санкт-Петербург, Танкистов, 26	f	large
84353	81502	508	Санкт-Петербург, Санкт-Петербург, Новостроек, 26	f	large
84961	81866	1190	Санкт-Петербург, Санкт-Петербург, Коллонтай, 19к5	f	large
84177	81391	313	Санкт-Петербург, Санкт-Петербург, Жени Егоровой, 10к2	f	large
16775	12877	379	республика Чувашская, п.имени Кирова, Центральная, 23	f	small
17456	13469	1060	республика Чувашская, Ядрин, Чапаева, 20-А	f	large
17457	13470	1061	республика Чувашская, Ядрин, Ленина, 39	f	large
17459	13472	1063	республика Чувашская, Ядрин, Карла Маркса, 64	f	large
17458	13471	1062	республика Чувашская, Ядрин, 50 лет Октября, 71-г	f	large
17449	13461	1053	республика Чувашская, Шумерля, Щербакова, 58	f	large
17447	13461	1051	республика Чувашская, Шумерля, Щербакова, 58	f	large
17451	13464	1055	республика Чувашская, Шумерля, Черняховского, 27	f	large
17446	13214	1050	республика Чувашская, Шумерля, Францева, 1	f	large
17435	13453	1039	республика Чувашская, Шумерля, Сурская, 7	f	large
17434	13453	1038	республика Чувашская, Шумерля, Сурская, 7	f	large
17448	13462	1052	республика Чувашская, Шумерля, Советская, 18	f	large
17454	13467	1058	республика Чувашская, Шумерля, Радищева, 32	f	medium
17441	13457	1045	республика Чувашская, Шумерля, Пушкина, 21	f	large
17437	13454	1041	республика Чувашская, Шумерля, Некрасова, 62	f	large
17436	13454	1040	республика Чувашская, Шумерля, Некрасова, 62	f	large
17440	13456	1044	республика Чувашская, Шумерля, МОПРа, 2	f	large
17445	13460	1049	республика Чувашская, Шумерля, М.Жукова, 7	f	large
17444	13460	1048	республика Чувашская, Шумерля, М.Жукова, 7	f	large
17443	13459	1047	республика Чувашская, Шумерля, Ленина, 4Б	f	large
17442	13458	1046	республика Чувашская, Шумерля, Ленина, 17	f	large
17453	13466	1057	республика Чувашская, Шумерля, Котовского, 58	f	medium
17452	13465	1056	республика Чувашская, Шумерля, Кирова, 64А	f	medium
17450	13463	1054	республика Чувашская, Шумерля, Кирова, 33	f	large
17439	13455	1043	республика Чувашская, Шумерля, Горького, 5	f	large
17438	13455	1042	республика Чувашская, Шумерля, Горького, 5	f	large
17455	13468	1059	республика Чувашская, Шумерля, Белинского, 1Б	f	medium
17195	13219	799	республика Чувашская, Чебоксары, ОАО Санаторий Чувашия	t	small
17194	13218	798	республика Чувашская, Чебоксары, клуб	t	small
17047	13123	651	Россия, республика Чувашская, Чебоксары, поселок Восточный, 5	f	large
17535	13542	1139	республика Чувашская, Чебоксары, улица Школьная, 1	f	medium
17117	13158	708	республика Чувашская, Чебоксары, улица Хевешская, 17а	f	large
17116	13158	707	республика Чувашская, Чебоксары, улица Хевешская, 17а	f	large
17131	13173	732	Россия, республика Чувашская, Чебоксары, поселок Новые Лапсары, улица Совхозная, 9а	f	large
17132	13174	733	республика Чувашская, Чебоксары, улица Совхозная, 3	f	large
17031	13113	635	республика Чувашская, Чебоксары, улица Патриса Лумумбы, 17	f	large
17030	13113	634	республика Чувашская, Чебоксары, улица Патриса Лумумбы, 17	f	large
17509	13515	1113	республика Чувашская, Чебоксары, улица Кооперативная, 13	f	medium
16602	12654	206	Россия, республика Чувашская, Чебоксары, улица Калинина, 26	f	large
17198	13221	802	Россия, республика Чувашская, Чебоксары, улица Гражданская, 50	f	large
17197	13221	801	Россия, республика Чувашская, Чебоксары, улица Гражданская, 50	f	large
17070	13132	674	Россия, республика Чувашская, Чебоксары, проспект Тракторостроителей, 38	f	large
17069	13132	673	Россия, республика Чувашская, Чебоксары, проспект Тракторостроителей, 38	f	large
17068	13132	672	Россия, республика Чувашская, Чебоксары, проспект Тракторостроителей, 38	f	large
17067	13132	671	Россия, республика Чувашская, Чебоксары, проспект Тракторостроителей, 38	f	large
17104	13156	704	Россия, республика Чувашская, Чебоксары, проспект Мира, 88а	f	large
17103	13156	703	Россия, республика Чувашская, Чебоксары, проспект Мира, 88а	f	large
17102	13156	702	Россия, республика Чувашская, Чебоксары, проспект Мира, 88а	f	large
17042	13120	646	Россия, республика Чувашская, Чебоксары, проспект Мира, 40	f	large
17041	13119	645	Россия, республика Чувашская, Чебоксары, проспект Мира, 1	f	large
17036	13116	640	Россия, республика Чувашская, Чебоксары, проспект Мира, 16	f	large
17035	13116	639	Россия, республика Чувашская, Чебоксары, проспект Мира, 16	f	large
17174	13190	778	республика Чувашская, Чебоксары, проспект Максима Горького, 5	f	large
17155	13190	759	республика Чувашская, Чебоксары, проспект Максима Горького, 5	f	large
17154	13189	758	республика Чувашская, Чебоксары, проспект Максима Горького, 24	f	large
17153	13189	757	республика Чувашская, Чебоксары, проспект Максима Горького, 24	f	large
17152	13189	756	республика Чувашская, Чебоксары, проспект Максима Горького, 24	f	large
17099	13154	698	Россия, республика Чувашская, Чебоксары, проспект Ленина, 55а	f	large
17091	13147	690	Россия, республика Чувашская, Чебоксары, проспект Ленина, 9	f	large
17101	13133	700	Россия, республика Чувашская, Чебоксары, проспект Ленина, 61	f	large
16624	12734	228	Россия, республика Чувашская, Чебоксары, проспект Ленина, 2а	f	small
16620	12730	224	Россия, республика Чувашская, Чебоксары, проспект Ленина, 13	t	small
16616	12726	220	Россия, республика Чувашская, Чебоксары, проспект Ленина, 7	f	small
16615	12725	219	Россия, республика Чувашская, Чебоксары, проспект Ленина, 30	f	large
17128	13164	719	Россия, республика Чувашская, Чебоксары, проспект Ивана Яковлева, 20	f	large
17126	13162	717	Россия, республика Чувашская, Чебоксары, проспект 9-й Пятилетки, 4б	f	large
17122	13160	713	Россия, республика Чувашская, Чебоксары, проспект 9-й Пятилетки, 11	f	large
17121	13160	712	Россия, республика Чувашская, Чебоксары, проспект 9-й Пятилетки, 11	f	large
17100	13155	699	Россия, республика Чувашская, Чебоксары, проезд Школьный, 3	f	large
17048	13124	652	Россия, республика Чувашская, Чебоксары, проезд Соляное, 1	f	medium
17169	13198	773	республика Чувашская, Чебоксары, площадь Победы, 3	f	large
17168	13198	772	республика Чувашская, Чебоксары, площадь Победы, 3	f	large
17109	13172	731	Россия, республика Чувашская, Чебоксары, переулок Ягодный, 2	f	large
17108	13172	730	Россия, республика Чувашская, Чебоксары, переулок Ягодный, 2	f	large
17173	13200	777	республика Чувашская, Чебоксары, бульвар Анатолия Миттова, 23	f	large
17172	13200	776	республика Чувашская, Чебоксары, бульвар Анатолия Миттова, 23	f	large
17171	13199	775	республика Чувашская, Чебоксары, бульвар Анатолия Миттова, 47	f	large
17170	13199	774	республика Чувашская, Чебоксары, бульвар Анатолия Миттова, 47	f	large
17158	13193	762	республика Чувашская, Чебоксары, Энтузиастов, 36/9	f	large
17203	13192	807	республика Чувашская, Чебоксары, Энтузиастов, 26	f	large
17157	13192	761	республика Чувашская, Чебоксары, Энтузиастов, 26	f	large
17202	13191	806	республика Чувашская, Чебоксары, Энтузиастов, 20	f	small
17201	13191	805	республика Чувашская, Чебоксары, Энтузиастов, 20	f	large
17156	13191	760	республика Чувашская, Чебоксары, Энтузиастов, 20	f	large
17092	13148	691	республика Чувашская, Чебоксары, Энгельса, 10	f	large
17149	13188	753	республика Чувашская, Чебоксары, Эльгера, 22	f	large
17148	13188	752	республика Чувашская, Чебоксары, Эльгера, 22	f	large
17150	13171	754	республика Чувашская, Чебоксары, Эльгера, 24	f	large
17151	13171	755	республика Чувашская, Чебоксары, Эльгера, 24	f	large
17115	13157	706	Россия, республика Чувашская, Чебоксары, Эгерский бульвар, 5а	f	large
17114	13157	705	Россия, республика Чувашская, Чебоксары, Эгерский бульвар, 5а	f	large
17066	13122	670	Россия, республика Чувашская, Чебоксары, Эгерский бульвар, 36	f	large
17046	13122	650	Россия, республика Чувашская, Чебоксары, Эгерский бульвар, 36	f	large
17120	13159	711	республика Чувашская, Чебоксары, Шумилова, 8	f	large
17119	13159	710	республика Чувашская, Чебоксары, Шумилова, 8	f	large
17118	13159	709	республика Чувашская, Чебоксары, Шумилова, 8	f	large
17050	13125	654	республика Чувашская, Чебоксары, Шумилова, 33	f	large
17049	13125	653	республика Чувашская, Чебоксары, Шумилова, 33	f	large
17165	13196	769	республика Чувашская, Чебоксары, Чернышевского, 4	f	large
17164	13196	768	республика Чувашская, Чебоксары, Чернышевского, 4	f	large
17161	13194	765	республика Чувашская, Чебоксары, Чернышевского, 16	f	large
17160	13194	764	республика Чувашская, Чебоксары, Чернышевского, 16	f	large
17159	13194	763	республика Чувашская, Чебоксары, Чернышевского, 16	f	large
17094	13149	693	республика Чувашская, Чебоксары, Чапаева, 41	f	large
17093	13149	692	республика Чувашская, Чебоксары, Чапаева, 41	f	large
17133	13178	737	республика Чувашская, Чебоксары, Чандровская, 73	f	medium
17193	13217	797	республика Чувашская, Чебоксары, Центральная, 6	f	small
17086	13167	725	республика Чувашская, Чебоксары, Хузангая, 23	f	large
17085	13167	724	республика Чувашская, Чебоксары, Хузангая, 23	f	large
17127	13163	718	республика Чувашская, Чебоксары, Хузангая, 18	f	large
17125	13161	716	республика Чувашская, Чебоксары, Хузангая, 8	f	large
17124	13161	715	республика Чувашская, Чебоксары, Хузангая, 8	f	large
17123	13161	714	республика Чувашская, Чебоксары, Хузангая, 8	f	large
16605	12715	209	республика Чувашская, Чебоксары, Хузангая, 1	f	small
17183	13206	787	республика Чувашская, Чебоксары, Урукова, 11а	f	large
17182	13206	786	республика Чувашская, Чебоксары, Урукова, 11а	f	medium
17136	13180	740	Россия, республика Чувашская, Чебоксары, Университетская улица, 38	f	large
17178	13203	782	республика Чувашская, Чебоксары, Тимофея Кривова, 8/1	f	large
17177	13202	781	республика Чувашская, Чебоксары, Тимофея Кривова, 13а	f	large
17176	13201	780	республика Чувашская, Чебоксары, Тимофея Кривова, 15а	f	large
17175	13201	779	республика Чувашская, Чебоксары, Тимофея Кривова, 15а	f	large
66094	12947	701	республика Чувашская, Чебоксары, Строителей, 12	f	\N
17185	13208	789	республика Чувашская, Чебоксары, Спиридона Михайлова, 3	f	large
17167	13197	771	республика Чувашская, Чебоксары, Социалистическая, 17Б	f	large
17166	13197	770	республика Чувашская, Чебоксары, Социалистическая, 17Б	f	large
17191	13215	795	республика Чувашская, Чебоксары, Сосновская, 57	f	medium
16623	12733	227	Россия, республика Чувашская, Чебоксары, Советская набережная	f	small
17080	13141	684	республика Чувашская, Чебоксары, Скворцова площадь, 3	f	medium
17071	13134	675	республика Чувашская, Чебоксары, Сапожникова, 15	f	large
17079	13140	683	республика Чувашская, Чебоксары, Розы Люксембург, 8	f	large
17078	13140	682	республика Чувашская, Чебоксары, Розы Люксембург, 8	f	large
17077	13140	681	республика Чувашская, Чебоксары, Розы Люксембург, 8	f	large
17192	13216	796	республика Чувашская, Чебоксары, Родниковая	f	small
17073	13136	677	республика Чувашская, Чебоксары, Рихарда Зорге, 9	f	large
17034	13115	638	республика Чувашская, Чебоксары, Патриса Лумумбы, 8	f	large
17033	13114	637	республика Чувашская, Чебоксары, Патриса Лумумбы, 10А	f	large
17032	13114	636	республика Чувашская, Чебоксары, Патриса Лумумбы, 10А	f	large
17096	13151	695	республика Чувашская, Чебоксары, Николая Ильбекова, 6	f	large
17189	13212	793	Россия, республика Чувашская, Чебоксары, Московский проспект, 3	f	large
17184	13207	788	Россия, республика Чувашская, Чебоксары, Московский проспект, 29	f	large
17181	13205	785	Россия, республика Чувашская, Чебоксары, Московский проспект, 35	f	large
16625	12735	229	Россия, республика Чувашская, Чебоксары, Московская набережная, 3	t	small
17163	13195	767	республика Чувашская, Чебоксары, Мате Залка, 4/11	f	large
17162	13195	766	республика Чувашская, Чебоксары, Мате Залка, 4/11	f	large
17074	13137	678	республика Чувашская, Чебоксары, Магницкого, 7	f	large
66092	13131	669	республика Чувашская, Чебоксары, Ленинского Комсомола, 86	f	large
17064	13131	668	республика Чувашская, Чебоксары, Ленинского Комсомола, 86	f	large
17063	13131	667	республика Чувашская, Чебоксары, Ленинского Комсомола, 86	f	large
17062	13130	666	республика Чувашская, Чебоксары, Ленинского Комсомола, 74	f	large
17061	13130	665	республика Чувашская, Чебоксары, Ленинского Комсомола, 74	f	large
17060	13130	664	республика Чувашская, Чебоксары, Ленинского Комсомола, 74	f	large
17057	13128	661	республика Чувашская, Чебоксары, Ленинского Комсомола, 54	f	large
17056	13128	660	республика Чувашская, Чебоксары, Ленинского Комсомола, 54	f	large
17055	13128	659	республика Чувашская, Чебоксары, Ленинского Комсомола, 54	f	large
17089	13145	688	республика Чувашская, Чебоксары, Ленинградская, 32	f	large
17139	13181	743	республика Чувашская, Чебоксары, Лебедева, 13	f	large
17138	13181	742	республика Чувашская, Чебоксары, Лебедева, 13	f	large
17137	13181	741	республика Чувашская, Чебоксары, Лебедева, 13	f	large
66093	13166	722	Россия, республика Чувашская, Чебоксары, Кукшумская улица, 19	f	large
17084	13166	723	Россия, республика Чувашская, Чебоксары, Кукшумская улица, 19	f	large
17087	13168	726	республика Чувашская, Чебоксары, Кукшумская, 23	f	large
17130	13165	721	республика Чувашская, Чебоксары, Кукшумская, 11а	f	large
17129	13165	720	республика Чувашская, Чебоксары, Кукшумская, 11а	f	large
17076	13139	680	республика Чувашская, Чебоксары, Кременского, 34	f	large
17098	13153	697	республика Чувашская, Чебоксары, Космонавта Николаева А.Г., 1	f	large
17040	13118	644	республика Чувашская, Чебоксары, Космонавта Николаева А.Г., 28	f	large
17039	13118	643	республика Чувашская, Чебоксары, Космонавта Николаева А.Г., 28	f	large
17038	13117	642	республика Чувашская, Чебоксары, Космонавта Николаева А.Г., 31	f	large
17037	13117	641	республика Чувашская, Чебоксары, Космонавта Николаева А.Г., 31	f	large
16611	12721	215	республика Чувашская, Чебоксары, Кооперативная, 10	f	small
17190	13213	794	республика Чувашская, Чебоксары, Константина Иванова, 30	f	medium
17188	13211	792	республика Чувашская, Чебоксары, Константина Иванова, 79/16	f	large
17196	13220	800	республика Чувашская, Чебоксары, Коммунальная Слобода, 25	f	large
17105	13169	727	республика Чувашская, Чебоксары, Коммунальная Слобода, 25	f	large
17090	13146	689	республика Чувашская, Чебоксары, Карла Маркса, 38	f	large
17088	13144	687	республика Чувашская, Чебоксары, Карла Маркса, 29	f	large
17052	13126	656	республика Чувашская, Чебоксары, Кадыкова, 16а	f	large
17051	13126	655	республика Чувашская, Чебоксары, Кадыкова, 16а	f	large
17026	13110	630	республика Чувашская, Чебоксары, Зои Яковлевой, 54а	f	large
17025	13110	629	республика Чувашская, Чебоксары, Зои Яковлевой, 54а	f	large
17029	13112	633	республика Чувашская, Чебоксары, Декабристов, 17	f	large
17028	13112	632	республика Чувашская, Чебоксары, Декабристов, 17	f	large
17200	13222	804	республика Чувашская, Чебоксары, Гражданская, 50а	f	large
17199	13222	803	республика Чувашская, Чебоксары, Гражданская, 50а	f	large
17027	13111	631	республика Чувашская, Чебоксары, Гайдара, 3	f	large
17097	13152	696	республика Чувашская, Чебоксары, Гагарина, 10а	f	large
17095	13150	694	республика Чувашская, Чебоксары, Гагарина, 15а	f	large
17107	13170	729	республика Чувашская, Чебоксары, Богдана Хмельницкого, 75	f	large
17106	13170	728	республика Чувашская, Чебоксары, Богдана Хмельницкого, 75	f	large
17059	13129	663	республика Чувашская, Чебоксары, Баумана, 4	f	large
17058	13129	662	республика Чувашская, Чебоксары, Баумана, 4	f	large
17054	13127	658	республика Чувашская, Чебоксары, Баумана, 10	f	large
17053	13127	657	республика Чувашская, Чебоксары, Баумана, 10	f	large
17075	13138	679	республика Чувашская, Чебоксары, Ашмарина, 33	f	large
17072	13135	676	республика Чувашская, Чебоксары, Ашмарина, 15	f	large
17146	13187	750	республика Чувашская, Чебоксары, Ахазова, 9а	f	large
17145	13187	749	республика Чувашская, Чебоксары, Ахазова, 9а	f	large
17187	13210	791	республика Чувашская, Чебоксары, Афанасьева, 6	f	large
17186	13209	790	республика Чувашская, Чебоксары, Афанасьева, 11	f	large
17180	13204	784	республика Чувашская, Чебоксары, Академика Павлова, 9	f	large
17179	13204	783	республика Чувашская, Чебоксары, Академика Павлова, 9	f	large
17140	13183	744	республика Чувашская, Чебоксары, Академика Павлова, 50	f	large
17141	13183	745	республика Чувашская, Чебоксары, Академика Павлова, 50	f	large
17135	13179	739	республика Чувашская, Чебоксары, Академика Павлова, 78	f	large
17134	13179	738	республика Чувашская, Чебоксары, Академика Павлова, 78	f	large
17045	13121	649	республика Чувашская, Чебоксары, 324 стрелковой дивизии, 10	f	large
17044	13121	648	республика Чувашская, Чебоксары, 324 стрелковой дивизии, 10	f	large
17043	13121	647	республика Чувашская, Чебоксары, 324 стрелковой дивизии, 10	f	large
17143	13185	747	республика Чувашская, Чебоксары, 139-й Стрелковой Дивизии, 12	f	large
17144	13186	748	республика Чувашская, Чебоксары, 139-й Стрелковой Дивизии, 9	f	large
66095	13184	746	республика Чувашская, Чебоксары, 139-й Стрелковой Дивизии, 14	f	large
17147	13184	751	республика Чувашская, Чебоксары, 139-й Стрелковой Дивизии, 14	f	large
17324	13345	928	республика Чувашская, Цивильск, Рогожкина, 59	f	large
17325	13346	929	республика Чувашская, Цивильск, П. Иванова, 1А	f	large
17323	13344	927	республика Чувашская, Цивильск, Максима Горького, 1	f	large
17006	13095	610	республика Чувашская, Новочебоксарск, проезд Ельниковский, 6А	f	large
17003	13094	607	республика Чувашская, Новочебоксарск, проезд Ельниковский, 6	f	large
17004	13094	608	республика Чувашская, Новочебоксарск, проезд Ельниковский, 6	f	large
16997	13089	601	республика Чувашская, Новочебоксарск, бульвар Зеленый, 26	f	large
16996	13089	600	республика Чувашская, Новочебоксарск, бульвар Зеленый, 26	f	large
16991	13085	595	республика Чувашская, Новочебоксарск, бульвар Зеленый, 3	f	large
16990	13084	594	республика Чувашская, Новочебоксарск, бульвар Зеленый, 10А	f	large
16981	13078	585	республика Чувашская, Новочебоксарск, Терешковой, 15	f	large
16980	13078	584	республика Чувашская, Новочебоксарск, Терешковой, 15	f	large
17009	13098	613	республика Чувашская, Новочебоксарск, Строителей, 36	f	large
16995	13088	599	республика Чувашская, Новочебоксарск, Солнечная, 14	f	large
16994	13088	598	республика Чувашская, Новочебоксарск, Солнечная, 14	f	large
16993	13087	597	республика Чувашская, Новочебоксарск, Солнечная, 2	f	large
16998	13090	602	республика Чувашская, Новочебоксарск, Советская, 27А	f	large
16992	13086	596	республика Чувашская, Новочебоксарск, Советская, 3	f	large
16974	13073	578	республика Чувашская, Новочебоксарск, Силикатная, 18	f	large
16973	13073	577	республика Чувашская, Новочебоксарск, Силикатная, 18	f	large
17000	13092	604	республика Чувашская, Новочебоксарск, Семенова, 15	f	large
17005	13091	609	республика Чувашская, Новочебоксарск, Семенова, 17	f	large
16999	13091	603	республика Чувашская, Новочебоксарск, Семенова, 17	f	large
17002	12959	606	республика Чувашская, Новочебоксарск, Семенова, 25	f	large
17001	12959	605	республика Чувашская, Новочебоксарск, Семенова, 25	f	large
17024	13109	628	республика Чувашская, Новочебоксарск, Пионерская, 3	f	large
17008	13097	612	республика Чувашская, Новочебоксарск, Пионерская, 21	f	large
17023	13108	627	республика Чувашская, Новочебоксарск, Первомайская, 10	f	large
17022	13107	626	республика Чувашская, Новочебоксарск, Первомайская, 6	f	large
17017	13102	621	республика Чувашская, Новочебоксарск, Первомайская, 30	f	large
17016	13102	620	республика Чувашская, Новочебоксарск, Первомайская, 30	f	large
17015	13101	619	республика Чувашская, Новочебоксарск, Первомайская, 45	f	large
17014	13101	618	республика Чувашская, Новочебоксарск, Первомайская, 45	f	large
17010	13099	614	республика Чувашская, Новочебоксарск, Первомайская, 55	f	large
17011	13099	615	республика Чувашская, Новочебоксарск, Первомайская, 55	f	large
16983	13080	587	республика Чувашская, Новочебоксарск, Парковая, 7	f	large
17007	13096	611	республика Чувашская, Новочебоксарск, Ольдеевская, 2	f	small
16979	13077	583	республика Чувашская, Новочебоксарск, Молодежная, 15	f	large
16978	13077	582	республика Чувашская, Новочебоксарск, Молодежная, 15	f	large
16988	13082	592	республика Чувашская, Новочебоксарск, Комсомольская, 19	f	large
16987	13082	591	республика Чувашская, Новочебоксарск, Комсомольская, 19	f	large
16985	12935	589	республика Чувашская, Новочебоксарск, Комсомольская, 18	f	large
16986	12935	590	республика Чувашская, Новочебоксарск, Комсомольская, 18	f	large
16982	13079	586	республика Чувашская, Новочебоксарск, Коммунистическая, 37	f	large
16977	13076	581	республика Чувашская, Новочебоксарск, Коммунистическая, 2	f	large
16976	13075	580	республика Чувашская, Новочебоксарск, Жени Крутовой, 7А	f	large
16975	13074	579	республика Чувашская, Новочебоксарск, Жени Крутовой, 2	f	large
17021	13106	625	республика Чувашская, Новочебоксарск, Винокурова, 80	f	large
17018	13104	622	республика Чувашская, Новочебоксарск, Винокурова, 125	f	large
16984	13081	588	республика Чувашская, Новочебоксарск, Винокурова, 12	f	large
17020	13105	624	республика Чувашская, Новочебоксарск, В-Интернационалистов, 9	f	large
17019	13105	623	республика Чувашская, Новочебоксарск, В-Интернационалистов, 9	f	large
17013	13100	617	республика Чувашская, Новочебоксарск, 10-й Пятилетки, 41	f	large
17012	13100	616	республика Чувашская, Новочебоксарск, 10-й Пятилетки, 41	f	large
17530	13537	1134	Россия, республика Чувашская, Яльчикский район	f	small
16878	12974	482	республика Чувашская, Мариинский Посад, Фурманова, 27	f	medium
16876	12972	480	республика Чувашская, Мариинский Посад, Николаева, 52	f	large
16874	12969	478	республика Чувашская, Мариинский Посад, Ломоносова, 9	f	medium
16872	12969	476	республика Чувашская, Мариинский Посад, Ломоносова, 9	f	large
16875	12971	479	республика Чувашская, Мариинский Посад, Ленинская, 2	f	medium
16873	12970	477	республика Чувашская, Мариинский Посад, Котовского, 36	f	medium
16736	12837	340	республика Чувашская, Козловка	f	large
16735	12836	339	республика Чувашская, Козловка, актовый зал МОУ доп. образования детейЦентр детского творчества 2 эт	f	large
16734	12835	338	республика Чувашская, Козловка, Детская художественная школа, 1этаж	f	small
16733	12834	337	республика Чувашская, Козловка, КСОШ № 3 2 этаж	f	large
16732	12833	336	республика Чувашская, Козловка, КСОШ № 3 1 этаж	f	large
16731	12832	335	республика Чувашская, Козловка, КООШ №1 им.А.Г.Тухланова	f	large
16730	12832	334	республика Чувашская, Козловка, КООШ №1 им.А.Г.Тухланова	f	medium
16728	12830	332	республика Чувашская, Канаш, Автошкола РОСТО	f	large
16727	12829	331	республика Чувашская, Канаш, Школа №4	f	large
16726	12828	330	республика Чувашская, Канаш, Офис врача общей практики	f	large
16721	12827	325	республика Чувашская, Канаш, ПУ №2	f	large
16720	12826	324	республика Чувашская, Канаш, Школа № 11	f	medium
16719	12826	323	республика Чувашская, Канаш, Школа № 11	f	large
16718	12825	322	республика Чувашская, Канаш, Офис врача общей практики	f	large
16717	12824	321	республика Чувашская, Канаш, Школа №9	f	large
16716	12824	320	республика Чувашская, Канаш, Школа №9	f	medium
16715	12823	319	республика Чувашская, Канаш, Городской Дворец культуры	f	large
16714	12822	318	республика Чувашская, Канаш, Школа №10	f	large
16713	12821	317	республика Чувашская, Канаш, Школа №8	f	large
16712	12820	316	республика Чувашская, Канаш, Школа-интернат	f	medium
16711	12819	315	республика Чувашская, Канаш, Школа №5	f	large
16710	12818	314	республика Чувашская, Канаш, Центр детского и юнош. творчества	f	large
16709	12817	313	республика Чувашская, Канаш, РГУ «КГЦСОН	f	medium
16708	12816	312	республика Чувашская, Канаш, Канашский педагогический колледж	f	medium
16706	12815	310	республика Чувашская, Канаш, Школа №7	f	large
16705	12815	309	республика Чувашская, Канаш, Школа №7	f	large
16704	12814	308	республика Чувашская, Канаш, Школа №1	f	large
16703	12814	307	республика Чувашская, Канаш, Школа №1	f	large
16702	12813	306	республика Чувашская, Канаш, ПУ №22	f	small
16701	12812	305	республика Чувашская, Канаш, 36 А	f	medium
16700	12811	304	республика Чувашская, Канаш, ООО «Канашский завод технолог. оснастки»	f	large
16699	12810	303	республика Чувашская, Канаш, Школа №3	f	large
16698	12810	302	республика Чувашская, Канаш, Школа №3	f	large
16724	12702	328	республика Чувашская, Канаш, Школа №6	f	large
16723	12690	327	республика Чувашская, Канаш, ПУ № 16	f	medium
16722	12678	326	Россия, республика Чувашская, Канаш	f	small
16707	12666	311	республика Чувашская, Канаш, Школа №7	f	large
16725	12594	329	республика Чувашская, Канаш, школа № 6	f	large
17387	13411	991	республика Чувашская, село Канаш, Канашская, 2 А	f	small
16597	12709	201	республика Чувашская, Ибреси, Школьная, 4	f	medium
16430	12534	34	республика Чувашская, Алатырь, 11	f	large
16439	12543	43	республика Чувашская, Алатырь, переулок Больничный, 2	f	medium
16428	12531	32	республика Чувашская, Алатырь, мкр Стрелка, 7	f	large
16429	12532	33	республика Чувашская, Алатырь, Южная, 3	f	large
16427	12530	31	республика Чувашская, Алатырь, Юбилейная, 7	f	large
16445	12548	49	республика Чувашская, Алатырь, Школьный Проезд, 5	f	large
16422	12525	26	республика Чувашская, Алатырь, Шаумяна, 1	f	medium
16440	12544	44	республика Чувашская, Алатырь, Почтовая, 15	f	large
16436	12540	40	республика Чувашская, Алатырь, Первомайская, 48	f	medium
16435	12539	39	республика Чувашская, Алатырь, Первомайская, 80	f	large
16434	12538	38	республика Чувашская, Алатырь, Московская, 106	f	large
16433	12537	37	республика Чувашская, Алатырь, Московская, 106	f	large
16423	12526	27	республика Чувашская, Алатырь, Московская, 30	f	medium
16424	12527	28	республика Чувашская, Алатырь, Ленина, 13	f	large
16426	12529	30	республика Чувашская, Алатырь, Комсомола, 14	f	large
16425	12528	29	республика Чувашская, Алатырь, Комсомола, 21	f	medium
16437	12541	41	республика Чувашская, Алатырь, Жуковского, 63	f	medium
16432	12536	36	республика Чувашская, Алатырь, Димитрова, 9	f	large
16438	12542	42	республика Чувашская, Алатырь, Гончарова, 115	f	large
16446	12549	50	республика Чувашская, Алатырь, Гагарина, 19	f	large
16431	12535	35	республика Чувашская, Алатырь, Володарского, 14	f	large
16444	12547	48	республика Чувашская, Алатырь, Березовая, 1	f	large
16443	12547	47	республика Чувашская, Алатырь, Березовая, 1	f	large
16441	12545	45	республика Чувашская, Алатырь, Артиллерийская, 34	f	large
16442	12546	46	республика Чувашская, Алатырь, 40 лет Победы, 31А	f	large
17571	13581	1175	республика Чувашская, Янтиковский район, село Яншихово-Норваши, Школьная, 16, сельский дом культуры	f	medium
17566	13575	1170	республика Чувашская, Янтиковский район, село Янтиково, проспект Ленина, 3МУК Янтиковский КДЦ	f	large
17567	13576	1171	республика Чувашская, Янтиковский район, село Янтиково, Ленина, 56, детская библиотека	f	medium
17564	13573	1168	республика Чувашская, Янтиковский район, село Шимкусы, Коммунистическая, 4, сельский дом культуры	f	medium
17562	13571	1166	республика Чувашская, Янтиковский район, село Чутеево, Лесная, 39, МДОУ Чутеевская СОШ	f	small
17550	13558	1154	республика Чувашская, Янтиковский район, село Уразлино, Николаева, 23, сельский клуб	f	small
17547	13555	1151	республика Чувашская, Янтиковский район, село Уразкасы, Ильича, 29, СДК	f	small
17558	13566	1162	республика Чувашская, Янтиковский район, село Тюмерево, Калинина, 4, сельский дом культуры	f	medium
17556	13564	1160	республика Чувашская, Янтиковский район, село Турмыши, Советская, 12, сельский дом культуры	f	medium
17549	13557	1153	республика Чувашская, Янтиковский район, село Тенеево, А. Егоровой, 21, сельский Дом культуры	f	small
17555	13563	1159	республика Чувашская, Янтиковский район, село Старое Буяново, Ленина, 21, общественный центр	f	small
17570	13579	1174	республика Чувашская, Янтиковский район, село Салагаево, Родник, 24, сельский дом культуры	f	small
17569	13578	1173	республика Чувашская, Янтиковский район, село Русские Норваши, Центральная, 9, фельдшерско-акушерский пункт	f	small
17546	13554	1150	республика Чувашская, Янтиковский район, село Нюшкасы, Гагарина, 27, сельский клуб	t	small
17572	13582	1176	республика Чувашская, Янтиковский район, село Норваш-Кошки, Центральная, 10, сельский клуб	f	small
17563	13572	1167	республика Чувашская, Янтиковский район, село Новое Ишино, Ленина, 17, сельский дом культуры	t	small
17554	13562	1158	республика Чувашская, Янтиковский район, село Новое Буяново, Комсомольская, 30, сельский дом культуры	f	small
17565	13574	1169	республика Чувашская, Янтиковский район, село Нижарово, Пролетарская, 27, МДОУ Шимкусская СОШ	t	small
17551	13559	1155	республика Чувашская, Янтиковский район, село Можарки, Ленина, 33, сельский дом культуры	f	small
17557	13565	1161	республика Чувашская, Янтиковский район, село Латышево, Ленина, 32, сельский клуб	f	small
17553	13561	1157	республика Чувашская, Янтиковский район, село Кичкеево, Первомайская, 54, сельский дом культуры	f	small
17561	13570	1165	республика Чувашская, Янтиковский район, село Кармалы, Советская, 3, сельский дом культуры	t	small
17548	13556	1152	республика Чувашская, Янтиковский район, село Индырчи, Чапаева, 2, сельский Дом культуры	f	small
17568	13577	1172	республика Чувашская, Янтиковский район, село Иваново, Школьная, 1, сельская библиотека	f	small
17552	13560	1156	республика Чувашская, Янтиковский район, село Гришино, Первомайская, 24, сельский дом культуры	t	small
17545	13553	1149	республика Чувашская, Янтиковский район, село Беляево, Ленина, 41, сельский клуб	f	small
17560	13568	1164	республика Чувашская, Янтиковский район, село Бахтиарово, Школьная, 1, сельская библиотека	f	small
17559	13567	1163	республика Чувашская, Янтиковский район, село Амалыково, Ленина, 2 сельский дом культуры	f	small
17544	13552	1148	республика Чувашская, Янтиковский район, село Алдиарово, Воробьева, 7, сельский Дом культуры	f	small
17508	13514	1112	республика Чувашская, Яльчикский район, поселок Яльчики, Центральная, 39	f	small
17504	13510	1108	республика Чувашская, Яльчикский район, село Яльчики, Юбилейная, 6а	f	small
17503	13509	1107	республика Чувашская, Яльчикский район, село Яльчики, Иванова, 15	f	large
17502	13508	1106	республика Чувашская, Яльчикский район, село Яльчики, Иванова, 13	f	medium
17537	13544	1141	республика Чувашская, Яльчикский район, село Эшмикеево, Больничная, 12	t	small
66100	13525	1123	республика Чувашская, Яльчикский район, село Эмметево, Кооперативная, 18	f	small
17526	13532	1130	республика Чувашская, Яльчикский район, село Шемалаково, Братьев Денисовых , 29	f	small
17513	13519	1117	республика Чувашская, Яльчикский район, село Старое Янашево, Анаткасс, 70	f	medium
17538	13545	1142	Россия, республика Чувашская, Чебоксары, улица Клубная	t	small
17543	13551	1147	республика Чувашская, Яльчикский район, село Сабанчино, Центральная, 99	f	small
17518	13524	1122	республика Чувашская, Яльчикский район, село Полевые Пинеры, Центральная, 9	f	small
17540	13548	1144	республика Чувашская, Яльчикский район, село Полевые Козыльяры, Мостовая, 1А	f	small
17265	13285	869	республика Чувашская, Яльчикский район, село Полевые Козыльяры, Ленина, 11	f	small
17522	13528	1126	республика Чувашская, Яльчикский район, село Полевые Буртасы, Центральная, 44	f	small
17542	13550	1146	республика Чувашская, Яльчикский район, село Полевые Буртасы, Полевая, 12A	f	small
17523	13529	1127	Россия, республика Чувашская, Яльчикский район, село Новые Шимкусы	f	medium
17511	13517	1115	республика Чувашская, Яльчикский район, село Новопоселенная Таяба, Садовая, 14	f	small
66101	13538	1135	республика Чувашская, Яльчикский район, село Новое Янашево, Новая, 45	f	small
17524	13530	1128	республика Чувашская, Яльчикский район, село Новое Чурино, Центральная, 75	f	small
17505	13511	1109	Россия, республика Чувашская, Яльчикский район	f	small
17521	13527	1125	республика Чувашская, Яльчикский район, село Новое Тинчурино, Центральная, 6а	f	medium
17534	13541	1138	Россия, республика Чувашская, Чебоксары, улица Академика Святослава Федорова	f	small
16781	12606	385	республика Чувашская, Яльчикский район, село Новое Изамбаево, Восточная, 7	f	small
17506	13512	1110	республика Чувашская, Яльчикский район, село Новое Булаево, Центральная, 25	f	small
17525	13531	1129	республика Чувашская, Яльчикский район, село Новое Байбатырево, Центральная, 80	f	small
17529	13536	1133	республика Чувашская, Яльчикский район, село Новое Андиберево, Ленина, 52	t	small
17512	13518	1116	республика Чувашская, Яльчикский район, село Малая Таяба, Новая, 17	f	medium
17541	13549	1145	Россия, республика Чувашская, Яльчикский район	f	small
17528	13534	1132	республика Чувашская, Яльчикский район, село Лащ-Таяба, Солдатская, 1	f	medium
17517	13523	1121	Россия, республика Чувашская, Яльчикский район	f	small
17536	13543	1140	республика Чувашская, Яльчикский район, село Кошки-Куликеево, Кирова, 14а	f	medium
17520	13526	1124	республика Чувашская, Яльчикский район, село Кильдюшево	f	small
17533	13540	1137	республика Чувашская, Яльчикский район, село Избахтино, Центральная, 55	f	small
17510	13516	1114	республика Чувашская, Яльчикский район, село Большие Яльчики, Кооперативная, 15	f	medium
17527	13533	1131	республика Чувашская, Яльчикский район, село Большая Таяба, Школьная, 23	f	small
17514	13520	1118	республика Чувашская, Яльчикский район, село Большая Таяба, Центральная, 10	f	medium
17516	13522	1120	республика Чувашская, Яльчикский район, село Белая Воложка, Цетральная, 2	f	small
17507	13513	1111	Россия, республика Чувашская, Яльчикский район, село Байдеряково	f	medium
17532	13539	1136	Россия, республика Чувашская, Яльчикский район	f	small
17515	13521	1119	республика Чувашская, Яльчикский район, село Аранчеево, Хурамакассы, 97а	f	small
17468	13035	1072	республика Чувашская, Ядринский район, село Ядрино, Шоссейная, 5	f	small
17465	13349	1069	республика Чувашская, Ядринский район, село Юваново, Сюльдикасы, 50	f	medium
17471	13103	1075	республика Чувашская, Ядринский район, село Чебаково, Ленина, 5	f	medium
17485	13491	1089	республика Чувашская, Ядринский район, село Хочашево, Березовая, 25	f	small
17487	13493	1091	республика Чувашская, Ядринский район, село Хорамалы, Калинина, 35-А	f	small
17484	13490	1088	республика Чувашская, Ядринский район, село Хирле-Сиры, Садовая, 13	f	small
17467	13431	1071	Россия, республика Чувашская, Ядринский район, село Тяптяево	f	small
17498	13504	1102	республика Чувашская, Ядринский район, село Талой, 30 лет Победы, 59	f	small
17460	13473	1064	республика Чувашская, Ядринский район, село Стрелецкая, 40 лет Победы, 63Б	f	medium
17480	13486	1084	республика Чувашская, Ядринский район, село Старые Тиньгеши, Ленина, 7	f	medium
17461	13474	1065	республика Чувашская, Ядринский район, село Совхозный, Заводская, 5	f	medium
17479	13485	1083	республика Чувашская, Ядринский район, село Советское, Советская, 37	f	medium
17481	13487	1085	республика Чувашская, Ядринский район, село Сехры, Школьная, 15	f	small
17495	13501	1099	республика Чувашская, Ядринский район, село Сареево, Шоссейная, 4-Б	f	small
17483	13489	1087	республика Чувашская, Ядринский район, село Салугино, Дружбы, 25	f	small
17470	13059	1074	республика Чувашская, Ядринский район, село Саваткино, Новая, 26	f	small
17469	13047	1073	республика Чувашская, Ядринский район, село Пошнары, Ленина, 25	f	small
17493	13499	1097	республика Чувашская, Ядринский район, село Персирланы, Шоссейная, 32	f	medium
17478	13484	1082	республика Чувашская, Ядринский район, село Ойкас-Асламасы, Школьная, 1/3	f	medium
17462	13475	1066	Россия, республика Татарстан, Лаишевский район, село Никольское	f	small
17482	13488	1086	республика Чувашская, Ядринский район, село Николаевское, Ленина, 2	f	medium
17477	13483	1081	республика Чувашская, Ядринский район, село Никиткино, Ленина, 20	f	small
17473	13479	1077	республика Чувашская, Ядринский район, село Нижние Мочары, Садовая, 49	f	small
17464	13477	1068	республика Чувашская, Ядринский район, село Малые Тюмерли, Школьная, 1	f	small
17497	13503	1101	республика Чувашская, Ядринский район, село Малое Кумаркино, Шоссейная, 1	f	small
17463	13476	1067	республика Чувашская, Ядринский район, село Малое Карачкино, Центральная, 3	f	medium
17486	13492	1090	республика Чувашская, Ядринский район, село Лапракасы, Центральная, 1-А	f	medium
17491	13497	1095	республика Чувашская, Ядринский район, село Кукшумы, Шоссейная, 6	f	medium
16549	12658	153	республика Чувашская, Ядринский район, село Кукшумы, Ценральная, 13Б	f	small
17472	13478	1076	республика Чувашская, Ядринский район, село Кудаши, Первомайская, 1	f	small
17500	13506	1104	республика Чувашская, Ядринский район, село Кильдишево, Алины Ивановой, 4	f	small
17499	13505	1103	республика Чувашская, Ядринский район, село Ильина Гора, Мира, 59	f	small
17475	13481	1079	республика Чувашская, Ядринский район, село Верхние Мочары, Пролетарская, 1-А	f	small
17466	13396	1070	республика Чувашская, Ядринский район, село Верхние Ирзеи, Центральная, 47	f	small
17489	13495	1093	республика Чувашская, Ядринский район, село Верхние Ачаки, Ленина, 40А	f	small
17476	13482	1080	республика Чувашская, Ядринский район, село Большое Чурашево, пер.Школьный, 1	f	small
17490	13496	1094	республика Чувашская, Ядринский район, село Большие Шемердяны, Шоссейная, 7-а	f	small
17494	13500	1098	республика Чувашская, Ядринский район, село Балдаево, Школьная, 18-А	f	small
17488	13494	1092	республика Чувашская, Ядринский район, село Атликасы, Молодежная, 23-А	f	small
17428	13447	1032	Россия, республика Чувашская, Шумерлинский район, село Яндаши	t	small
17432	13451	1036	Россия, республика Чувашская, Шумерлинский район, село Юманай	f	medium
17414	13432	1017	республика Чувашская, Шумерлинский район, село Шумерля	f	medium
17409	13281	1012	Россия, республика Чувашская, Шумерлинский район, село Чувашские Алгаши	t	small
17427	13445	1030	Россия, республика Чувашская, Шумерлинский район, село Ходары	f	medium
66099	13446	1031	республика Чувашская, Шумерлинский район, село Тугасы, Комсомольская, 5	f	small
17424	13442	1027	Россия, республика Чувашская, Шумерлинский район, село Туваны	f	small
17420	13438	1023	Россия, республика Чувашская, Шумерлинский район, село Торханы	f	medium
17419	13437	1022	Россия, республика Чувашская, Шумерлинский район, село Саланчик	f	small
17430	13449	1034	Россия, республика Чувашская, Шумерлинский район, село Савадеркино	f	small
17408	13258	1011	Россия, республика Чувашская, Шумерлинский район, поселок Русские Алгаши	f	small
17410	13293	1013	Россия, республика Чувашская, Шумерлинский район, поселок Речной	f	small
17431	13450	1035	Россия, республика Чувашская, Шумерлинский район, село Пояндайкино	f	small
17412	13093	1015	Россия, республика Чувашская, Шумерлинский район, поселок Пинеры	f	small
17415	13433	1018	Россия, республика Чувашская, Шумерлинский район, село Нижняя Кумашка	f	small
17423	13441	1026	Россия, республика Чувашская, Шумерлинский район, поселок Мыслец	f	small
17411	13384	1014	Россия, республика Чувашская, Шумерлинский район, поселок Мыслец	f	small
17422	13440	1025	Россия, республика Чувашская, Шумерлинский район, село Молгачкино	f	small
17426	13444	1029	Россия, республика Чувашская, Шумерлинский район, село Малые Туваны	f	small
17425	13443	1028	Россия, республика Чувашская, Шумерлинский район, село Лесные Туваны	f	small
17413	13182	1016	Россия, республика Чувашская, Шумерлинский район, село Красный Октябрь	f	small
17433	13452	1037	Россия, республика Чувашская, Шумерлинский район, село Кадеркино	t	small
17407	13430	1010	Россия, республика Чувашская, Шумерлинский район, поселок Кабаново	f	small
17429	13448	1033	республика Чувашская, Шумерлинский район, село Егоркино	f	medium
17417	13435	1020	республика Чувашская, Шумерлинский район, село Волга	t	small
17416	13434	1019	Россия, республика Чувашская, Шумерлинский район, село Верхняя Кумашка	t	small
17418	13436	1021	Россия, республика Чувашская, Шумерлинский район, село Верхний Магарин	t	small
17421	13439	1024	Россия, республика Чувашская, Шумерлинский район, село Бреняши	f	small
17405	13429	1009	Россия, республика Чувашская, Шумерлинский район, село Большие Алгаши	t	small
17404	13428	1008	республика Чувашская, Шемуршинский район, село Яблоновка, Центральная, 29	f	small
17384	13408	988	республика Чувашская, Шемуршинский район, село Шемурша, Советская, 3	f	large
17385	13409	989	республика Чувашская, Шемуршинский район, село Шемурша, Лесхозная, 18	f	medium
17402	13426	1006	республика Чувашская, Шемуршинский район, село Чепкас-Никольское, Чапаева, 24	f	medium
17401	13425	1005	республика Чувашская, Шемуршинский район, село Трехизб-Шемурша, переулок Центральный, 2	f	small
17400	13424	1004	республика Чувашская, Шемуршинский район, село Трехбалтаево, Спортивная, 9	f	medium
17398	13422	1002	республика Чувашская, Шемуршинский район, село Старые Чукалы, Комсомольская, 79	f	medium
17399	13423	1003	республика Чувашская, Шемуршинский район, село Старая Шемурша, Чкалова, 38	f	small
17403	13427	1007	республика Чувашская, Шемуршинский район, село Русские Чукалы, Октябрьская, 15	f	medium
17389	13413	993	республика Чувашская, Шемуршинский район, село Новая Шемурша, Кудряшова, 79Б	f	small
17397	13421	1001	республика Чувашская, Шемуршинский район, село Нижнее Буяново, Карла Маркса, 38	f	small
17388	13412	992	республика Чувашская, Шемуршинский район, деревня Мордовские Тюки, Овражная, 1	f	small
17396	13420	1000	республика Чувашская, Шемуршинский район, село Малое Буяново, Карла Маркса, 32	f	medium
17395	13419	999	республика Чувашская, Шемуршинский район, село Карабай-Шемурша, Советская, 13	f	large
17394	13418	998	республика Чувашская, Шемуршинский район, село Верхнее Буяново, Ленина, 60а	f	small
17393	13417	997	республика Чувашская, Шемуршинский район, село Большое Буяново, Карла Маркса, 65	f	small
17392	13416	996	республика Чувашская, Шемуршинский район, село Бичурга-Баишево, Мичурина, 5	f	medium
17391	13415	995	республика Чувашская, Шемуршинский район, село Байдеряково, Чапаева, 1	f	small
17390	13414	994	республика Чувашская, Шемуршинский район, село Асаново, Кирова, 25	f	medium
17386	13410	990	республика Чувашская, Шемуршинский район, село Андреевка, Гагарина, 21	f	small
17374	13398	978	республика Чувашская, Чебоксарский район, д.Толиково, Школьная, 1	f	medium
17358	13380	962	республика Чувашская, Чебоксарский район, село Яуши, Садовая, 1/1	f	medium
17337	13359	941	республика Чувашская, Чебоксарский район, село Яныши, Центральная, 16	f	medium
17383	13407	987	республика Чувашская, Чебоксарский район, село Яндово, Магазинная, 33а	t	small
17355	13377	959	республика Чувашская, Чебоксарский район, село Янгильдино, Школьная, 33	f	medium
17347	13369	951	Россия, республика Чувашская, Чебоксарский район	t	small
17339	13361	943	республика Чувашская, Чебоксарский район, село Эндимиркасы, Октябрьская, 16	t	small
17370	13393	974	республика Чувашская, Чебоксарский район, село Шорчекасы, Шоссейная, 13	f	medium
17353	13375	957	республика Чувашская, Чебоксарский район, село Шоркино, Ворошилова, 9	f	medium
17341	13363	945	республика Чувашская, Чебоксарский район, село Шоркасы, Солнечная, 30а	f	small
17366	13389	970	республика Чувашская, Чебоксарский район, село Шинерпоси, Школьная, 2	f	medium
17340	13362	944	республика Чувашская, Чебоксарский район, село Чиршкасы, Школьный пер, 8	f	medium
17363	13386	967	республика Чувашская, Чебоксарский район, село Чиршкасы, 11-ой Пятилетки, 1	f	medium
17382	13406	986	республика Чувашская, Чебоксарский район, село Чемурша, Магазинная, 62а	f	medium
17331	13353	935	республика Чувашская, Чебоксарский район, село Хыркасы, Ресторанная, 6	f	medium
17367	13390	971	республика Чувашская, Чебоксарский район, село Хыркасы, Молодежная, 50	f	medium
17365	13388	969	республика Чувашская, Чебоксарский район, село Тренькасы, Молодежная, 7	f	large
17378	13402	982	республика Чувашская, Чебоксарский район, село Сятракасы, Школьная, 9а	f	large
17352	13374	956	республика Чувашская, Чебоксарский район, село Сятракасы, Центральная, 12	f	medium
17330	13352	934	республика Чувашская, Чебоксарский район, село Сюктерка, Главная, 4	f	medium
17381	13405	985	республика Чувашская, Чебоксарский район, село Синьялы, Центральная, 32	f	large
17332	13354	936	республика Чувашская, Чебоксарский район, село Селиванкино, Школьная, 1/1	f	small
14856	6148	913	республика Удмуртская, Сарапул, Горького, 61б	f	large
17328	13350	932	республика Чувашская, Чебоксарский район, село Салабаикасы, Медицинская, 1а	f	medium
17333	13355	937	республика Чувашская, Чебоксарский район, село Пархикасы, Садовая, 1	f	medium
17345	13367	949	республика Чувашская, Чебоксарский район, село Олгаши, Лесная, 3	t	small
17377	13401	981	республика Чувашская, Чебоксарский район, село Ойкасы, Октябрьская, 43б	f	small
17344	13366	948	республика Чувашская, Чебоксарский район, село Мускаринкасы, Речная, 9	t	small
17357	13379	961	республика Чувашская, Чебоксарский район, село Малые Карачуры, Заречная, 2а	f	small
17327	13348	931	республика Чувашская, Чебоксарский район, село Малая Сундырь, Становая, 1а	f	medium
17354	13376	958	республика Чувашская, Чебоксарский район, село Курмыши, 9-ой Пятилетки, 11	f	large
17348	13370	952	республика Чувашская, Чебоксарский район, поселок Кугеси, Шоссейная, 17	f	large
17349	13371	953	республика Чувашская, Чебоксарский район, поселок Кугеси, Школьная, 3	f	large
17351	13373	955	республика Чувашская, Чебоксарский район, поселок Кугеси, Первомайская, 20	f	large
17350	13372	954	республика Чувашская, Чебоксарский район, поселок Кугеси, Первомайская, 13а	f	large
17346	13368	950	Россия, республика Чувашская, Чебоксарский район	t	small
17361	13383	965	республика Чувашская, Чебоксарский район, село Клычево, Школьная, 15а	f	medium
17343	13365	947	республика Чувашская, Чебоксарский район, село Ишлей, Советская, 58	f	large
17342	13364	946	республика Чувашская, Чебоксарский район, село Ишлей, Советская, 52	f	large
17335	13357	939	республика Чувашская, Чебоксарский район, село Ишаки, Ясельная, 6	f	medium
17380	13404	984	республика Чувашская, Чебоксарский район, село Ильбеши, Школьная, 22	f	small
17362	13385	966	республика Чувашская, Чебоксарский район, село Икково, Школьная, 2	f	medium
17329	13351	933	республика Чувашская, Чебоксарский район, село Вурманкасы, Приволжская, 12а	f	small
17375	13399	979	республика Чувашская, Чебоксарский район, село Вурманкасы, 2-ая Садовая, 23а	f	medium
17338	13360	942	республика Чувашская, Чебоксарский район, село Вурманкас-Туруново, Водопроводная, 63	f	small
17364	13387	968	республика Чувашская, Чебоксарский район, село Большое Князьтеняково, Космонавта Николаева А.Г., 37	t	small
17336	13358	940	республика Чувашская, Чебоксарский район, село Большие Мамыши, Школьная, 1	f	small
17356	13378	960	республика Чувашская, Чебоксарский район, деревня Большие Катраси, Молодежная, 1а	f	large
17376	13400	980	республика Чувашская, Чебоксарский район, село Большие Карачуры, Школьная, 35	f	medium
17368	13391	972	республика Чувашская, Чебоксарский район, село Большая Чигирь, Школьная, 33	t	small
17360	13382	964	республика Чувашская, Чебоксарский район, село Байсубаково, Родниковая, 32а	t	small
17371	13394	975	республика Чувашская, Чебоксарский район, село Атлашево, Парковая, 5	f	medium
17373	13397	977	республика Чувашская, Чебоксарский район, село Атлашево, Кудряшова, 5	f	large
17372	13395	976	республика Чувашская, Чебоксарский район, село Атлашево, 70 Лет Октября, 11	f	medium
17334	13356	938	республика Чувашская, Чебоксарский район, село Анаткас-Марги, Октябрьская, 41	f	small
17379	13403	983	республика Чувашская, Чебоксарский район, село Альгешево, Пионерская, 2	f	small
17369	13392	973	республика Чувашская, Чебоксарский район, село Акулево, Аптечная, 3	f	small
17359	13381	963	республика Чувашская, Чебоксарский район, село Абашево, Верхняя, 35	f	medium
17322	13343	926	республика Чувашская, Цивильский район, село Чурачики, Ленина, 21	f	large
16791	12885	395	республика Чувашская, Цивильский район, село Чурачики, Ленина, 144	f	medium
17317	13338	921	республика Чувашская, Цивильский район, село Чиричкасы, Молодежная, 20	f	small
17302	13323	906	республика Чувашская, Цивильский район, село Чемерчеево 1-е, Молодежная, 1а	t	small
17310	13331	914	республика Чувашская, Цивильский район, село Хорамалы, И. Викторова, 29	f	small
17283	13304	887	республика Чувашская, Цивильский район, село Унгасемы, Дружбы, 4	f	small
17305	13326	909	республика Чувашская, Цивильский район, село Тюрары, Животноводов, 48В	f	small
17314	13335	918	республика Чувашская, Цивильский район, село Тюнзыры, Новая, 28	f	small
17311	13332	915	республика Чувашская, Цивильский район, село Тувси, Октября, 6	f	small
14896	6210	953	республика Удмуртская, Сарапул, Гончарова, 1а	f	large
17316	13337	920	республика Чувашская, Цивильский район, село Таушкасы, Школьная, 6	f	medium
17320	13341	924	республика Чувашская, Цивильский район, село Таганы, Центральная, 47	f	small
17282	13303	886	республика Чувашская, Цивильский район, село Сюлескеры, Путёвая, 15А	f	small
17307	13328	911	республика Чувашская, Цивильский район, село Степное Тугаево, Молодежная, 12	f	small
17306	13327	910	республика Чувашская, Цивильский район, село Степаново 1-е, Николаева, 35	f	small
17308	13329	912	республика Чувашская, Цивильский район, село Старое Акташево, Центральная, 41А	f	small
17312	13333	916	республика Чувашская, Цивильский район, село Синьялы, Синьяльская, 67	f	small
17293	13314	897	республика Чувашская, Цивильский район, село Рындино, Центральная, 61	f	medium
17319	13340	923	республика Чувашская, Цивильский район, село Поваркасы, Школьная, 5	f	medium
17291	13312	895	республика Чувашская, Цивильский район, село Первомайское, Рыбацкая, 79Б	f	small
17295	13316	899	республика Чувашская, Цивильский район, село Первое Семеново, Родниковая, 15	f	small
17300	13321	904	республика Чувашская, Цивильский район, село Опытный, Дорожная, 7	f	large
17318	13339	922	республика Чувашская, Цивильский район, село Нюрши, Советская, 79	f	small
17285	13306	889	республика Чувашская, Цивильский район, село Нижние Кунаши, Центральная, 1А	f	small
17294	13315	898	республика Чувашская, Цивильский район, село Нижние Кибекси, переулок Школьный, 4	f	small
17299	13320	903	республика Чувашская, Цивильский район, село Мунсют, Молодежная, 14	t	medium
17284	13305	888	республика Чувашская, Цивильский район, село Михайловка, Чапаева, 14	f	medium
17303	13324	907	республика Чувашская, Цивильский район, село Медикасы, Просвещения, 3	f	small
17286	13307	890	республика Чувашская, Цивильский район, село Малое Янгорчино, Солнечная, 7	f	small
17309	13330	913	республика Чувашская, Цивильский район, село Конар, Школьная, 4	f	medium
17321	13342	925	республика Чувашская, Цивильский район, село Камайкасы, Шоссейная, 11	t	small
17301	13322	905	республика Чувашская, Цивильский район, село Искеево-Яндуши, переулок Клубный, 9	f	small
17315	13336	919	республика Чувашская, Цивильский район, село Имбюрти, Центральная, 34	f	small
17298	13319	902	республика Чувашская, Цивильский район, село Игорвары, Молодежная, 11	f	small
17289	13310	893	республика Чувашская, Цивильский район, село Елаши, Пушкина, 41Б	t	small
17296	13317	900	республика Чувашская, Цивильский район, село Вурумсют, Базовый проезд, 4	f	small
17292	13313	896	республика Чувашская, Цивильский район, село Вурманкасы 2-е, Центральная, 7А	f	small
17290	13311	894	республика Чувашская, Цивильский район, село Вурманкасы 2-е, Центральная, 7А	f	medium
16800	12894	404	республика Чувашская, Цивильский район, село Вотланы, Мира, 1	f	small
17288	13309	892	республика Чувашская, Цивильский район, село Визикасы, Советская, 46	f	small
17297	13318	901	республика Чувашская, Цивильский район, село Булдеево, Садовая, 1Б	f	medium
17304	13325	908	республика Чувашская, Цивильский район, село Борзайкасы, Колхозная, 26	f	small
17281	13302	885	республика Чувашская, Цивильский район, село Большие Тиуши, Молодежная, 32	t	small
17280	13301	884	республика Чувашская, Цивильский район, село Богатырево, Восточная, 3	f	medium
17287	13308	891	республика Чувашская, Цивильский район, село Байдуши, Гагарина, 17	f	small
17313	13334	917	республика Чувашская, Цивильский район, село Байгеево, Средняя, 18Б	f	small
17269	13289	873	республика Чувашская, Урмарский район, село Ямбай, Зеленая, 46	f	small
17277	13298	881	республика Чувашская, Урмарский район, село Шоркистры, Центральная, 56	f	small
17276	13297	880	республика Чувашская, Урмарский район, село Шоркистры, Центральная, 56	f	medium
17273	13294	877	республика Чувашская, Урмарский район, село Шихабылово, Новая, 1	f	medium
17272	13292	876	республика Чувашская, Урмарский район, село Шигали, Центральная, 7	f	medium
17242	13262	846	республика Чувашская, Урмарский район, село Шибулаты, Свердлова, 47	f	small
17270	13290	874	республика Чувашская, Урмарский район, село Чубаево, Школьная, 3	f	medium
17254	13273	858	республика Чувашская, Урмарский район, село Чирш-Сирма, Ленина, 55А	f	small
17266	13286	870	республика Чувашская, Урмарский район, село Челкасы, Улица К. Маркса, 59	f	medium
17279	13300	883	республика Чувашская, Урмарский район, село Хоруй, Зеленая, 27	f	small
17238	13257	842	республика Чувашская, Урмарский район, поселок Урмары, Мира, 6	f	large
17237	13256	841	республика Чувашская, Урмарский район, поселок Урмары, Ленина, 16	f	large
17263	13283	867	республика Чувашская, Урмарский район, село Тегешево, Школьная, 5	f	small
17260	13279	864	республика Чувашская, Урмарский район, село Тансарино, Ленина, 7	f	small
17257	13276	861	республика Чувашская, Урмарский район, село Старые Шелканы, Центральная, 33	t	small
17262	13282	866	республика Чувашская, Урмарский район, село Старые Урмары, Школьная, 6	f	large
17268	13288	872	республика Чувашская, Урмарский район, село Старое Шептахово, Гагарина, 8	f	small
17253	13272	857	республика Чувашская, Урмарский район, село Старое Муратово, Новая, 4а	t	small
17259	13278	863	республика Чувашская, Урмарский район, село Ситмиши, Школьная, 66	f	small
17252	13271	856	республика Чувашская, Урмарский район, село Систеби, Е. Степановой, 16а	f	small
17275	13296	879	республика Чувашская, Урмарский район, село Сине-Кинчеры, Школьная, 7	t	small
17249	13269	853	республика Чувашская, Урмарский район, село Саруй, Молодежная, 2а	f	small
17248	13268	852	республика Чувашская, Урмарский район, село Орнары, Октябрьская, 55	f	small
17245	13265	849	республика Чувашская, Урмарский район, село Новое Шептахово, Новая, 2	f	small
17264	13284	868	республика Чувашская, Урмарский район, село Новое Муратово, Кооперативная, 7	f	small
17240	13260	844	республика Чувашская, Урмарский район, село Новое Исаково, Ленина, 5а	f	small
17261	13280	865	республика Чувашская, Урмарский район, село Мусирмы, Гагарина, 35	f	medium
17244	13264	848	Россия, республика Чувашская, Урмарский район, село Малое Яниково	f	small
17258	13277	862	республика Чувашская, Урмарский район, село Кульгеши, Школьная, 22	f	small
17255	13274	859	республика Чувашская, Урмарский район, село Кудеснеры, Виськил, 8	f	medium
17250	13235	854	республика Чувашская, Урмарский район, село Ковали, Ленина, 43	f	medium
17247	13267	851	Россия, республика Чувашская, Урмарский район, село Карак-Сирмы	f	small
17278	13299	882	республика Чувашская, Урмарский район, село Ичеснер-Атаево, Центральная, 11	f	small
17256	13275	860	республика Чувашская, Урмарский район, село Избеби, Крупской, 1	t	small
17274	13295	878	республика Чувашская, Урмарский район, село Вознесенское, Центральная, 15	f	small
17251	13270	855	республика Чувашская, Урмарский район, село Буинск, И. Метри, 7а	t	small
17246	13266	850	республика Чувашская, Урмарский район, село Большое Яниково, К. Маркса, 98	f	small
17243	13263	847	республика Чувашская, Урмарский район, село Большие Чаки, Школьная, 20	f	small
17241	13261	845	республика Чувашская, Урмарский район, село Бишево, Новая, 7	f	medium
17271	13291	875	республика Чувашская, Урмарский район, село Батеево, Гоголя, 9	f	small
17239	13259	843	республика Чувашская, Урмарский район, село Арабоси, Школьная, 16	f	large
17267	13287	871	республика Чувашская, Урмарский район, село Анаткасы, Школьная, 23	f	small
17233	13252	837	республика Чувашская, Порецкий район, село Сыреси, Октябрьская, 184	f	small
17227	13246	831	республика Чувашская, Порецкий район, село Сиява, Ленина, 104	f	small
17231	13250	835	республика Чувашская, Порецкий район, село Семеновское, Азина, 6	f	small
17215	13233	818	республика Чувашская, Порецкий район, село Ряпино, Ульянова, 31	f	small
17236	13255	840	республика Чувашская, Порецкий район, село Рындино, Кооперативная, 33	f	small
17235	13254	839	республика Чувашская, Порецкий район, село Раздольное, Курмыш, 48	f	small
17226	13244	830	республика Чувашская, Порецкий район, село Порецкое, пер.Школьный, 4	f	medium
17224	13244	828	республика Чувашская, Порецкий район, село Порецкое, пер.Школьный, 4	f	medium
17225	13245	829	республика Чувашская, Порецкий район, село Порецкое, им.Крупской, 26 А	f	medium
17222	13242	826	республика Чувашская, Порецкий район, село Порецкое, Ленина, 4	f	medium
17223	13243	827	республика Чувашская, Порецкий район, село Порецкое, Комсомольская, 11	f	medium
17232	13251	836	республика Чувашская, Порецкий район, село Полибино, Панова, 30	t	small
17220	13240	824	республика Чувашская, Порецкий район, село Никулино, Николаева, 35	f	small
17229	13248	833	республика Чувашская, Порецкий район, село Никольское, Центральная, 49	f	small
17219	13239	823	республика Чувашская, Порецкий район, село Напольное, Ленина, 24 А	f	large
17217	13237	821	республика Чувашская, Порецкий район, село Мишуково, Северная, 1а	f	small
17234	13253	838	республика Чувашская, Порецкий район, село Любимовка, Мухоморова, 87	t	small
66097	13236	820	республика Чувашская, Порецкий район, село Кудеиха, Советская, 58	f	small
17213	13232	817	республика Чувашская, Порецкий район, село Козловка, Школьная, 200	f	small
66096	13234	819	республика Чувашская, Порецкий район, село Кожевенное, Чапаева, 24	t	small
66098	13238	822	республика Чувашская, Порецкий район, село Ивановка, Советская, 10Б	f	small
17228	13247	832	республика Чувашская, Порецкий район, село Долгая Поляна, Почтовая, 11	t	small
17230	13249	834	республика Чувашская, Порецкий район, село Гарт, Гагарина, 31 А	f	small
17211	13230	815	республика Чувашская, Порецкий район, село Бахмутово, Бахмутово, 58 А	f	small
17221	13241	825	республика Чувашская, Порецкий район, село Антипинка, Тракторная, 5	f	small
17212	13231	816	республика Чувашская, Порецкий район, село Анастасово, Анастасово, 126 А	f	small
16989	13083	593	республика Чувашская, Новочебоксарск городской округ, Новочебоксарск, Комсомольская, 3А	f	large
16948	13045	552	Россия, республика Чувашская, Моргаушский район, село Ятманкино	f	small
16971	13070	575	республика Чувашская, Моргаушский район, село Ярославка, Центральная, 5	f	medium
16968	13067	572	республика Чувашская, Моргаушский район, село Ярабаикасы, Молодежная, 16	f	medium
16964	13063	568	республика Чувашская, Моргаушский район, село Юськасы, Центральная, 58	f	medium
16963	13062	567	республика Чувашская, Моргаушский район, село Юнгапоси, Ягодная, 21	f	small
16960	13058	564	республика Чувашская, Моргаушский район, село Юнга, Центральная, 5	f	medium
16928	13024	532	республика Чувашская, Моргаушский район, село Шупоси, Центральная, 4	f	small
16937	13033	541	республика Чувашская, Моргаушский район, село Шомиково, Шомиково, 63	f	small
16958	13056	562	республика Чувашская, Моргаушский район, село Шатьмапоси, Первомайская, 9	f	medium
16936	13032	540	республика Чувашская, Моргаушский район, село Шатракасы, Центральная, 70	f	small
16933	13029	537	республика Чувашская, Моргаушский район, село Чураккасы, Советская, 150	f	small
16972	13072	576	республика Чувашская, Моргаушский район, село Чемеево, Центральная, 3	t	small
16955	13053	559	республика Чувашская, Моргаушский район, село Хорной, Школьная, 17г	f	medium
16930	13026	534	республика Чувашская, Моргаушский район, село Тренькино, Новая, 5	f	medium
16949	13046	553	республика Чувашская, Моргаушский район, село Тораево, Школьная, 1	f	small
16953	13051	557	республика Чувашская, Моргаушский район, село Тойшево, Володарского, 17	t	small
16954	13052	558	республика Чувашская, Моргаушский район, село Тойгильдино, Западная, 56	f	small
16959	13057	563	республика Чувашская, Моргаушский район, село Тиуши, Чебоксарская, 31	t	small
16945	13042	549	республика Чувашская, Моргаушский район, село Сятракасы, Школьная, 17	f	medium
16962	13061	566	республика Чувашская, Моргаушский район, село Сярмыськасы, Эхменя, 13	f	small
16951	13049	555	республика Чувашская, Моргаушский район, село Сюткюль, Озерная, 11	t	small
16969	13068	573	республика Чувашская, Моргаушский район, село Сыбайкасы, Школьная, 2	f	small
16966	13065	570	республика Чувашская, Моргаушский район, село Старые Мадики, Школьная, 11	f	small
16939	13036	543	республика Чувашская, Моргаушский район, село Рыкакасы, Озерная, 22а	f	small
16940	13037	544	республика Чувашская, Моргаушский район, село Полевые Хачики, Молодежная, 34	f	medium
16947	13044	551	республика Чувашская, Моргаушский район, село Оточево, Победы, 15	f	small
16941	13038	545	республика Чувашская, Моргаушский район, село Оринино, Центральная, 61	f	medium
17492	13498	1096	республика Чувашская, Моргаушский район, село Ойкасы, Социалистическая, 49	f	small
16956	13054	560	республика Чувашская, Моргаушский район, село Одаркино, Школьная, 45	f	medium
16967	13066	571	республика Чувашская, Моргаушский район, село Нижний Панклей, Центральная, 70	f	small
16938	13034	542	республика Чувашская, Моргаушский район, село Москакасы, Московская, 54	f	medium
16923	13020	527	республика Чувашская, Моргаушский район, село Моргауши, Чапаева, 39в	f	large
14893	6207	950	республика Удмуртская, Сарапул, Гончарова, 40	f	large
16922	13019	526	республика Чувашская, Моргаушский район, село Моргауши, Красная Площадь, 5	f	medium
16921	13018	525	республика Чувашская, Моргаушский район, село Моргауши, 50 лет Октября, 15	f	large
16944	13041	548	республика Чувашская, Моргаушский район, село Молгачкасы, Центральная, 48в	f	small
16961	13060	565	республика Чувашская, Моргаушский район, село Кубасы, Победы, 4	f	small
16946	13043	550	республика Чувашская, Моргаушский район, село Кашмаши, Советская, 82	f	medium
16935	13031	539	республика Чувашская, Моргаушский район, село Калайкасы, Молодежная, 3	t	medium
16934	13030	538	республика Чувашская, Моргаушский район, село Кадикасы, Ягодная, 24	f	small
16957	13055	561	республика Чувашская, Моргаушский район, село Изедеркино, 30 лет Победы, 58	f	small
16965	13064	569	республика Чувашская, Моргаушский район, село Вурманкасы, Центральная, 38	f	small
16932	13028	536	республика Чувашская, Моргаушский район, село Вурманкасы, Антонова, 74	f	small
16927	13012	531	республика Чувашская, Моргаушский район, село Вомбакасы, Хырлыхская, 95	f	small
16924	13021	528	республика Чувашская, Моргаушский район, село Васькино, Ленина, 1в	f	medium
16929	13025	533	Россия, республика Чувашская, Моргаушский район, село Большое Карачкино	f	small
16950	13048	554	Россия, республика Чувашская, Моргаушский район, село Большие Токшики	t	small
16926	13023	530	республика Чувашская, Моргаушский район, село Большие Татаркасы, Пакшандаева, 17а	f	small
17496	13502	1100	республика Чувашская, Моргаушский район, село Большая Сундырь, Советская, 44	f	small
16925	13022	529	республика Чувашская, Моргаушский район, село Большая Сундырь, Ленина, 16	f	large
16943	13040	547	республика Чувашская, Моргаушский район, село Басурманы, Главная, 42	f	small
16931	13027	535	республика Чувашская, Моргаушский район, село Апчары, Центральная, 35	f	small
16952	13050	556	республика Чувашская, Моргаушский район, село Анаткасы, Колхозная, 1	f	small
16970	13069	574	республика Чувашская, Моргаушский район, село Акрамово, Центральная, 40	f	medium
16942	13039	546	республика Чувашская, Моргаушский район, село Адабай, Школьная, 2	f	small
16912	13008	516	республика Чувашская, Мариинско-Посадский район, село Ящерино, Кооперативная, 3	f	small
16917	13014	521	республика Чувашская, Мариинско-Посадский район, село Эльбарусово, Тогаевская, 1	f	medium
16882	12978	486	республика Чувашская, Мариинско-Посадский район, село Щамалы, Новая, 1а	t	small
16907	13003	511	республика Чувашская, Мариинско-Посадский район, село Шульгино, Почтовая, 40	f	small
16913	13009	517	республика Чувашская, Мариинско-Посадский район, село Шоршелы, 30 лет Победы, 3	f	medium
16894	12990	498	республика Чувашская, Мариинско-Посадский район, село Шанары, Малтикас, 49	t	small
16899	12995	503	республика Чувашская, Мариинско-Посадский район, село Чурашево 1-е, Школьная, 10а	f	medium
16893	12989	497	республика Чувашская, Мариинско-Посадский район, село Чекуры 2-е, Пионерская, 3	t	small
16909	13005	513	республика Чувашская, Мариинско-Посадский район, село Ураково, Смольникова, 43	t	small
16920	13017	524	республика Чувашская, Мариинско-Посадский район, село Тогаево, Нагорная, 4	f	small
16905	13001	509	республика Чувашская, Мариинско-Посадский район, село Тинсарино, Лесная, 1а	f	small
16881	12977	485	республика Чувашская, Мариинско-Посадский район, село Сятракасы, Центральная, 41	f	small
16884	12980	488	республика Чувашская, Мариинско-Посадский район, село Сюндюково, Кузнечная, 16	f	small
16910	13006	514	республика Чувашская, Мариинско-Посадский район, село Сутчево, Новая, 20	f	small
16919	13016	523	республика Чувашская, Мариинско-Посадский район, село Средние Бокаши, Ленина, 23а	f	small
16888	12984	492	республика Чувашская, Мариинско-Посадский район, село Сотниково, Магазинная, 8	f	small
16918	13015	522	республика Чувашская, Мариинско-Посадский район, село Синьялы 1-е, Школьная, 5а	f	small
16891	12987	495	республика Чувашская, Мариинско-Посадский район, село Покровское, Церковная, 3	f	small
16898	12994	502	республика Чувашская, Мариинско-Посадский район, село Передние Бокаши, Нагорная, 2	f	small
16896	12992	500	республика Чувашская, Мариинско-Посадский район, село Октябрьское, Советская, 13	f	medium
16906	13002	510	республика Чувашская, Мариинско-Посадский район, село Нерядово, Луговая, 17	f	small
16895	12991	499	республика Чувашская, Мариинско-Посадский район, село Мижули, магазин Октябрьского райпо	f	small
16879	12975	483	республика Чувашская, Мариинско-Посадский район, Мариинский Посад, Чкалова, 61б	f	medium
16871	12968	475	республика Чувашская, Мариинско-Посадский район, Мариинский Посад, Новинская, 34	f	medium
16877	12973	481	республика Чувашская, Мариинско-Посадский район, Мариинский Посад, Лазо, 76	f	large
16886	12982	490	республика Чувашская, Мариинско-Посадский район, село Малое Шигаево, Лесная, 30	f	small
16915	13011	519	республика Чувашская, Мариинско-Посадский район, село Малое Камаево, Шоссейная, 2	f	small
16908	13004	512	республика Чувашская, Мариинско-Посадский район, село Кушниково, Школьная, 36	t	small
16892	12988	496	республика Чувашская, Мариинско-Посадский район, село Кугеево, Молодежная, 34	f	small
16902	12998	506	республика Чувашская, Мариинско-Посадский район, село Караньялы, Мокеева, 1а	f	small
16890	12986	494	Россия, республика Чувашская, Мариинско-Посадский район	f	small
16900	12996	504	республика Чувашская, Мариинско-Посадский район, село Ибраялы, Северная, 15а	f	small
16916	13013	520	республика Чувашская, Мариинско-Посадский район, село Ельниково, Главная, 12а	t	small
16904	13000	508	республика Чувашская, Мариинско-Посадский район, село Дубовка, Украинская, 13	t	small
16889	12985	493	республика Чувашская, Мариинско-Посадский район, село Большое Яндуганово, Полевая, 60	t	small
16885	12981	489	республика Чувашская, Мариинско-Посадский район, село Большое Шигаево, Школьная, 1	f	small
16911	13007	515	республика Чувашская, Мариинско-Посадский район, село Большое Малашкино, Большая, 62	f	small
16914	13010	518	республика Чувашская, Мариинско-Посадский район, село Большое Камаево, Центральная, 9	t	small
16883	12979	487	республика Чувашская, Мариинско-Посадский район, село Бичурино, Новая, 35	f	small
16903	12999	507	республика Чувашская, Мариинско-Посадский район, село Астакасы, Мичуринская, 15	f	small
16887	12983	491	республика Чувашская, Мариинско-Посадский район, село Арзаматово, Школьная, 1а	f	small
16901	12997	505	республика Чувашская, Мариинско-Посадский район, село Алмандаево, Октябрьская, 6	t	small
16897	12993	501	республика Чувашская, Мариинско-Посадский район, село Акшики, Акшики, 60	f	small
16880	12976	484	республика Чувашская, Мариинско-Посадский район, село Аксарино, Центральная усадьба, 11	f	small
16852	12948	456	республика Чувашская, Красночетайский район, село Янгильдино, Центральная, 40	f	small
16834	12928	438	республика Чувашская, Красночетайский район, село Ямаши, Молодежная, 24	f	small
16862	12958	466	республика Чувашская, Красночетайский район, село Яманы, Вторая, 15а	t	small
16868	12965	472	республика Чувашская, Красночетайский район, село Ягункино, Новая, 27	f	small
16869	12966	473	республика Чувашская, Красночетайский район, село Штанаши, Молодежная, 16	f	medium
16833	12927	437	республика Чувашская, Красночетайский район, село Шоля, Чернореченская, 220 а	f	medium
16851	12946	455	республика Чувашская, Красночетайский район, село Черепаново, Центральная, 69	f	medium
16867	12964	471	республика Чувашская, Красночетайский район, село Хоршеваши, Центральная, 22	f	small
16856	12952	460	республика Чувашская, Красночетайский район, село Хирлукасы, Николаева, 70а	f	small
16855	12951	459	республика Чувашская, Красночетайский район, село Хвадукасы, Запрудная, 14	f	small
16847	12942	451	республика Чувашская, Красночетайский район, село Торханы, Центральная, 53а	f	small
16840	12934	444	республика Чувашская, Красночетайский район, село Тоганаши, Шоссейная, 25а	t	small
16866	12963	470	республика Чувашская, Красночетайский район, село Тиханкино, Ленина, 33	t	small
16839	12933	443	республика Чувашская, Красночетайский район, село Тарабай, Центральная, 35а	f	small
16859	12955	463	республика Чувашская, Красночетайский район, село Старые Атаи, Центральная, 165	f	small
16837	12931	441	республика Чувашская, Красночетайский район, село Сосново, Сосновая, 98	f	small
16838	12932	442	республика Чувашская, Красночетайский район, село Сормово, Центральная, 35	f	small
16863	12960	467	республика Чувашская, Красночетайский район, село Санкино, Ленина, 6	f	small
16857	12953	461	республика Чувашская, Красночетайский район, село Питеркино, Школьная, 4	f	medium
16858	12954	462	республика Чувашская, Красночетайский район, село Питеркино, Новая, 1	f	small
16853	12949	457	республика Чувашская, Красночетайский район, село Пандиково, Ульянова, 1а	f	small
16861	12957	465	республика Чувашская, Красночетайский район, село Новые Атаи, Школьная, 13	f	small
16843	12938	447	республика Чувашская, Красночетайский район, село Мочковаши, Лесная, 48б	t	small
16854	12950	458	республика Чувашская, Красночетайский район, село Мижеркасы, Ленина, 1	f	medium
16846	12941	450	республика Чувашская, Красночетайский район, село Кумаркино, Школьная, 2	t	small
16860	12956	464	республика Чувашская, Красночетайский район, село Кузнечная, Школьная, 73	f	small
16849	12944	453	республика Чувашская, Красночетайский район, село Красные Четаи, площадь Победы, 9	f	large
16848	12943	452	республика Чувашская, Красночетайский район, село Красные Четаи, Советская, 1	f	large
16845	12940	449	республика Чувашская, Красночетайский район, село Карк-Сирмы, Центральная, 15а	f	small
17501	13507	1105	республика Чувашская, Красночетайский район, село Испуханы, Прямая, 50	f	small
16844	12939	448	республика Чувашская, Красночетайский район, село Испуханы, Новая, 2	f	small
16850	12945	454	республика Чувашская, Красночетайский район, село Ижекей, Центральная, 2	f	small
16454	12557	58	республика Чувашская, Красночетайский район, село Выла, магазин, фойе	f	small
16865	12962	469	республика Чувашская, Красночетайский район, село Вторые Хоршеваши, Школьная, 1	f	small
16864	12961	468	республика Чувашская, Красночетайский район, село Верхнее Аккозино, Ленина, 2	f	small
16841	12936	445	республика Чувашская, Красночетайский район, село Большие Атмени, Молодежная, 94	f	medium
16836	12930	440	республика Чувашская, Красночетайский район, село Березовка, Шоссейная, 9а	f	small
16832	12926	436	республика Чувашская, Красночетайский район, село Баймашкино, Колхозная, 100	f	medium
16835	12929	439	республика Чувашская, Красночетайский район, село Атнары, Молодежная, 52 а	f	medium
16870	12967	474	республика Чувашская, Красночетайский район, село Арайкасы, Николаева, 1б	f	small
16842	12937	446	республика Чувашская, Красночетайский район, село Аликово, Солнечная, 164а	f	small
16831	12925	435	республика Чувашская, Красночетайский район, село Акчикасы, Васюкова, 47А	f	small
16823	12917	427	республика Чувашская, Красноармейский район, д. Чадукасы, 40 лет Победы, 4	f	medium
16812	12906	416	республика Чувашская, Красноармейский район, село Яншихово-Челлы, Учительская, 1	f	medium
16810	12904	414	республика Чувашская, Красноармейский район, село Янгасы, Н. Янгаса, 3	f	medium
16819	12913	423	республика Чувашская, Красноармейский район, село Яманаки, Центральная, 2	f	medium
16821	12915	425	республика Чувашская, Красноармейский район, село Ямаикасы, Каганович, 12	f	small
16822	12916	426	республика Чувашская, Красноармейский район, село Шупоси, Магазинная, 4	t	small
16827	12921	431	республика Чувашская, Красноармейский район, село Шивбоси, Центральная, 5	f	small
17474	13480	1078	республика Чувашская, Красноармейский район, село Чиганары, Новая, 1-а	f	small
16829	12923	433	республика Чувашская, Красноармейский район, село Убеево, Сапожникова, 6	f	medium
16813	12907	417	республика Чувашская, Красноармейский район, село Санькасы, Клубная, 1	t	small
16818	12912	422	республика Чувашская, Красноармейский район, село Пшонги, Лесная, 36	t	small
16820	12914	424	республика Чувашская, Красноармейский район, село Пикшики, Восточная, 2	f	small
16809	12903	413	республика Чувашская, Красноармейский район, село Крендейкасы, Северная, 1	t	small
16807	12901	411	республика Чувашская, Красноармейский район, село Красноармейское, Ленина, 95	f	large
16808	12902	412	республика Чувашская, Красноармейский район, село Красноармейское, Васильева, 2	f	large
16816	12910	420	республика Чувашская, Красноармейский район, село Кошки, Школьная, 24	f	small
16815	12909	419	республика Чувашская, Красноармейский район, село Кожары, Гаражная, 1	f	small
16828	12922	432	республика Чувашская, Красноармейский район, село Караево, Центральная, 7	f	medium
16817	12911	421	республика Чувашская, Красноармейский район, село Исаково, Садовая, 21	f	small
16811	12905	415	республика Чувашская, Красноармейский район, село Именево, переулок Центральный, 1	f	small
16824	12918	428	республика Чувашская, Красноармейский район, село Енешкасы, Школьная, 63 А	t	small
16830	12924	434	республика Чувашская, Красноармейский район, село Досаево, пер. Зеленый, 3	t	medium
16814	12908	418	республика Чувашская, Красноармейский район, село Большая Шатьма, Центральная, 1	f	small
16825	12919	429	республика Чувашская, Красноармейский район, село Алманчино, Школьная, 31	f	small
16826	12920	430	республика Чувашская, Красноармейский район, село Албахтино, Вокзальная, 66	f	small
16795	12889	399	республика Чувашская, Комсомольский район, село Шурут-Нурусово, Зеленая, 2а	f	small
16794	12888	398	республика Чувашская, Комсомольский район, село Шерауты, Больничная, 19	f	small
16792	12886	396	республика Чувашская, Комсомольский район, село Чичканы, Молодежная, 196	f	medium
16789	12883	393	республика Чувашская, Комсомольский район, село Урмаево, Центральная, 47	f	large
16806	12900	410	республика Чувашская, Комсомольский район, село Тябердино-Эткерово, Кооперативная, 7	t	small
16801	12895	405	республика Чувашская, Комсомольский район, село Тугаево, Фрунзе, 1	f	small
16790	12884	394	республика Чувашская, Комсомольский район, село Токаево, Зеленая, 1	f	large
16798	12892	402	республика Чувашская, Комсомольский район, село Татарские Шуруты, Центральная, 9	t	small
16804	12898	408	республика Чувашская, Комсомольский район, село Сюрбей-Токаево, Пожеданова, 2а	f	small
16784	12864	388	республика Чувашская, Комсомольский район, село Степные Шихазаны, Садовая, 39	f	small
16787	12630	391	республика Чувашская, Комсомольский район, село Старые Мураты, Колхозная, 4	f	small
16802	12896	406	республика Чувашская, Комсомольский район, село Старые Высли, Калинина, 46	f	small
16783	12738	387	республика Чувашская, Комсомольский район, село Старочелны Сюрбеево, Мирная, 31	f	medium
16772	12874	376	республика Чувашская, Комсомольский район, село Старая Сундырь, Ленина, 29	t	small
16773	12875	377	республика Чувашская, Комсомольский район, село Починок-Инели, Комсомольская, 49	t	small
16776	12878	380	республика Чувашская, Комсомольский район, село Починок-Быбыть, Московская, 72	t	small
16785	12533	389	республика Чувашская, Комсомольский район, село Полевые Яуши, Подгорная, 8	f	medium
16779	12881	383	республика Чувашская, Комсомольский район, село Полевой Сундырь, Набережная, 8	f	small
16778	12880	382	республика Чувашская, Комсомольский район, село Полевое Шептахово, Кооперативная, 2	f	small
16805	12899	409	республика Чувашская, Комсомольский район, село Подлесные Чурачики, Колхозная, 35	f	small
16780	12882	384	республика Чувашская, Комсомольский район, село Нюргечи, Советская, 48	f	medium
16799	12893	403	республика Чувашская, Комсомольский район, село Новые Мураты, Школьная, 1	f	medium
16786	12618	390	республика Чувашская, Комсомольский район, село Новые Высли, Новая, 32	t	small
16782	12642	386	республика Чувашская, Комсомольский район, село Новочелны-Сюрбеево, Центральная, 57	f	small
16769	12871	373	Россия, республика Чувашская, Комсомольский район, село Новое Бикмурзино	t	small
16774	12876	378	республика Чувашская, Комсомольский район, село Новая Сундырь, Смирнова, 1	f	small
16796	12890	400	республика Чувашская, Комсомольский район, село Нижние Бюртли Шигали, Центральная, 2	f	small
16793	12887	397	республика Чувашская, Комсомольский район, село Нижнее Тимерчеево, Школьная, 1	f	medium
16768	12870	372	республика Чувашская, Комсомольский район, село Малые Кошелеи, Комсомольская, 38а	f	medium
16766	12868	370	республика Чувашская, Комсомольский район, село Комсомольское, Шолохова, 40	f	large
16765	12867	369	республика Чувашская, Комсомольский район, село Комсомольское, Ленина, 8	f	large
16764	12866	368	республика Чувашская, Комсомольский район, село Комсомольское, Заводская, 50	f	large
16777	12879	381	республика Чувашская, Комсомольский район, село Кайнлык, Центральная, 1	f	small
16797	12891	401	республика Чувашская, Комсомольский район, село Ендоба, Центральная, 1	t	small
16767	12869	371	республика Чувашская, Комсомольский район, село Дубовка, Овражная, 13	f	small
16770	12872	374	республика Чувашская, Комсомольский район, село Байбахтино, Комсомольская, 14	f	small
16803	12897	407	республика Чувашская, Комсомольский район, село Асаново, Чапаева, 1	f	medium
14891	6205	948	республика Удмуртская, Сарапул, Гончарова, 53	f	large
16771	12873	375	республика Чувашская, Комсомольский район, село Александровка, Комсомольская, 161	f	medium
16748	12849	352	республика Чувашская, Козловский район, с.Карамышево	f	medium
16740	12841	344	Россия, республика Чувашская, Козловский район	t	small
16761	12862	365	Россия, республика Чувашская, Козловский район, село Янгильдино	f	small
16742	12843	346	Россия, республика Чувашская, Козловский район	f	small
16759	12860	363	Россия, республика Чувашская, Козловский район	f	small
16743	12844	347	Россия, республика Чувашская, Козловский район, село Тогонашево	f	small
16758	12859	362	Россия, республика Чувашская, Козловский район, село Старая Тюрлема	f	medium
16757	12858	361	республика Чувашская, Козловский район, Старая Тюрлема	f	medium
16754	12855	358	республика Чувашская, Козловский район, село Солдыбаево, Солдыбаевская СОШ им.А.Г.Журавлев	f	small
16763	12865	367	Россия, республика Чувашская, Козловский район	t	small
16756	12857	360	Россия, республика Чувашская, Козловский район	f	small
16753	12854	357	Россия, республика Чувашская, Козловский район	f	small
16750	12851	354	Россия, республика Чувашская, Козловский район	f	small
16752	12853	356	Россия, республика Чувашская, Козловский район	f	small
16747	12848	351	Россия, республика Чувашская, Козловский район	f	small
16760	12861	364	Россия, республика Чувашская, Козловский район	t	small
16739	12840	343	Россия, республика Чувашская, Козловский район	t	small
16737	12838	341	Россия, республика Чувашская, Козловский район, Козловка	f	small
16749	12850	353	Россия, республика Чувашская, Козловский район	t	small
16751	12852	355	Россия, республика Чувашская, Козловский район	f	small
16745	12846	349	республика Чувашская, Козловский район, село Еметкино, Еметкинская СОШ	f	small
16755	12856	359	Россия, республика Чувашская, Козловский район	f	small
16746	12847	350	Россия, республика Чувашская, Козловский район	f	small
16744	12845	348	республика Чувашская, Козловский район, село Байгулово, Байгуловская СОШ	f	medium
16741	12842	345	Россия, республика Чувашская, Козловский район, село Аттиково	f	small
16738	12839	342	Россия, республика Чувашская, Козловский район	f	small
16762	12863	366	Россия, республика Чувашская, Козловский район	f	small
16695	12807	299	республика Чувашская, Канашский район, село Янгличи, Ленина, 88	f	small
16653	12764	257	республика Чувашская, Канашский район, село Ямашево, Сергеева, 11	f	small
16683	12795	287	республика Чувашская, Канашский район, село Яманово, Ленина, 55	t	small
16681	12793	285	республика Чувашская, Канашский район, село Юманзары, Михайлова, 33	f	small
16658	12769	262	республика Чувашская, Канашский район, село Шоркасы, Октябрьская, 15	f	small
16643	12754	247	республика Чувашская, Канашский район, село Шихазаны, Генерала Михайлова, 15а	f	large
16662	12774	266	республика Чувашская, Канашский район, село Шигали, Клубная, 1	f	small
16647	12758	251	республика Чувашская, Канашский район, село Шибылги, Павлова, 33	f	small
16677	12789	281	республика Чувашская, Канашский район, село Шакулово, Южная, 40а	f	small
16671	12783	275	республика Чувашская, Канашский район, село Чиршкасы, Ленина, 27а	f	small
16664	12776	268	республика Чувашская, Канашский район, село Челкумаги, Гагарина, 4	f	medium
16691	12803	295	республика Чувашская, Канашский район, село Чагаси, Центральная, 12	f	medium
16673	12785	277	республика Чувашская, Канашский район, село Хучель, Школьная, 1	f	medium
16670	12782	274	республика Чувашская, Канашский район, село Ухманы, Школьная, 4	f	medium
16633	12744	237	республика Чувашская, Канашский район, село Туруново, Ленина, 1	f	small
16682	12794	286	республика Чувашская, Канашский район, село Тобурданово, Пушкина, 57	f	medium
16690	12802	294	республика Чувашская, Канашский район, село Сядорга-Сирмы, Карла Маркса, 55	f	small
16672	12784	276	республика Чувашская, Канашский район, село Сугайкасы, Сугай, 1	f	large
16684	12796	288	республика Чувашская, Канашский район, село Старые Шальтямы, Кооперативная, 14а	f	small
16679	12791	283	республика Чувашская, Канашский район, село Старое-Ахпердино, Канашская, 19	t	small
16697	12809	301	республика Чувашская, Канашский район, село Средние Татмыши, 50 лет Победы, 28	f	medium
16644	12755	248	республика Чувашская, Канашский район, село Сиделево, 50 лет ВЛКСМ, 23	f	small
16650	12761	254	республика Чувашская, Канашский район, село Сеспель, Школьная, 65	f	medium
16630	12741	234	республика Чувашская, Канашский район, село Семеновка, Восточная, 20	f	small
16668	12780	272	республика Чувашская, Канашский район, село Передние Яндоуши, Ленина, 1	f	small
16637	12748	241	республика Чувашская, Канашский район, село Оженары, Клубная, 2а	f	small
16685	12797	289	республика Чувашская, Канашский район, село Новые Шальтямы, Спортивная, 1а	f	small
16634	12745	238	республика Чувашская, Канашский район, село Новые Челкасы, Николаева, 83	f	small
16649	12760	253	республика Чувашская, Канашский район, село Новые Пинеры, Новая, 5	f	small
16631	12742	235	республика Чувашская, Канашский район, село Новые Мамеи, Гагарина, 11	f	small
16688	12800	292	республика Чувашская, Канашский район, село Новые Бюрженеры, Советская, 30	f	small
16641	12752	245	республика Чувашская, Канашский район, село Новые Ачакасы, Молодежная, 21	f	small
16687	12799	291	республика Чувашская, Канашский район, село Новое Урюмово, Кооперативная, 31а	f	medium
16696	12808	300	республика Чувашская, Канашский район, село Новая Яндоба, Гагарина, 1а	f	small
16665	12777	269	республика Чувашская, Канашский район, село Нижние Кибечи, Чапаева, 49	f	small
16640	12751	244	республика Чувашская, Канашский район, село Напольные Котяки, Советская, 134	f	medium
16693	12805	297	республика Чувашская, Канашский район, село Мокры, Спортивная, 26	f	small
16686	12798	290	республика Чувашская, Канашский район, село Маяк, Шоссейная, 17а	t	small
16669	12781	273	республика Чувашская, Канашский район, село Малые Кибечи, Центральная, 4	f	medium
16675	12787	279	республика Чувашская, Канашский район, село Малые Бикшихи, Канашская, 80	f	medium
16635	12746	239	республика Чувашская, Канашский район, село Малое Тугаево, Гагарина, 7	f	small
16657	12768	261	республика Чувашская, Канашский район, село Малды-Питикасы, Центральная, 42	f	small
16648	12759	252	республика Чувашская, Канашский район, село Малая Андреевка, Молодежная, 58	f	small
16661	12773	265	республика Чувашская, Канашский район, село Кошноруй, Ленина, 33	f	small
16629	12740	233	республика Чувашская, Канашский район, село Кармамеи, Центральная, 50	f	medium
16692	12804	296	республика Чувашская, Канашский район, село Кармамеи, Лесная, 55	f	small
16680	12792	284	республика Чувашская, Канашский район, село Караклы, Молодежная, 12	f	medium
16645	12756	249	республика Чувашская, Канашский район, село Калиновка, Советская, 1	f	small
16639	12750	243	республика Чувашская, Канашский район, село Ирдеменево-Кошки, Центральная, 67а	t	small
16655	12766	259	республика Чувашская, Канашский район, село Имелево, Садовая, 37	f	small
16676	12788	280	республика Чувашская, Канашский район, село Зеленый, Центральная, 1	f	small
16667	12779	271	республика Чувашская, Канашский район, село Задние Яндоуши, Школьная, 10	f	small
16642	12753	246	республика Чувашская, Канашский район, село Елмачи, Мира, 2	f	small
16663	12775	267	республика Чувашская, Канашский район, село Дальние Сормы, Шоссейная, 19	f	small
16689	12801	293	республика Чувашская, Канашский район, село Вутабоси, Восточная, 4	f	medium
16654	12765	258	республика Чувашская, Канашский район, село Вурман-Янишево, Ленина, 46	f	small
16636	12747	240	республика Чувашская, Канашский район, село Вторые Хормалы, Кооперативная, 18	f	small
16694	12806	298	республика Чувашская, Канашский район, село Верхняя Яндоба, Чапаева, 33	t	small
16666	12778	270	республика Чувашская, Канашский район, село Верхнее Девлизерово, Школьная, 4	f	small
16656	12767	260	республика Чувашская, Канашский район, село Братьякасы, Центральная, 31	t	small
16628	12739	232	республика Чувашская, Канашский район, село Большие Бикшихи, Ленина, 11	f	medium
16660	12771	264	республика Чувашская, Канашский район, село Ближние Сормы, Театральная, 13	f	small
16632	12743	236	республика Чувашская, Канашский район, село Байгильдино, Волкова, 33	f	small
16638	12749	242	республика Чувашская, Канашский район, село Ачакасы, Молодежная, 23	t	small
16651	12762	255	республика Чувашская, Канашский район, село Атыково, Чкалова, 8	f	small
16646	12757	250	республика Чувашская, Канашский район, село Атнашево, Кирова, 6	f	medium
16627	12737	231	республика Чувашская, Канашский район, село Асхва, Спортивная, 19	f	medium
14869	6189	926	республика Удмуртская, Сарапул, Гоголя, 99	f	large
16678	12790	282	республика Чувашская, Канашский район, село Аниш-Ахпердино, Шакуловская, 4	f	small
16652	12763	256	республика Чувашская, Канашский район, село Анаткасы, Шелепи, 2	f	small
16674	12786	278	республика Чувашская, Канашский район, село Алешево, Полевая, 1	t	small
16659	12770	263	республика Чувашская, Канашский район, село Алаксары, Ленина, 42	f	small
16626	12736	230	республика Чувашская, Ибресинский район, село Ширтаны, Школьная, 1	f	small
16621	12731	225	республика Чувашская, Ибресинский район, село Хормалы, Школьная, 1	f	medium
16619	12729	223	республика Чувашская, Ибресинский район, село Хормалы, Центральная, 29	f	small
16613	12723	217	республика Чувашская, Ибресинский район, Малые Кармалы, Лесная, 53	t	small
16614	12724	218	республика Чувашская, Ибресинский район, село Малые Кармалы, Школьная, 1	t	small
16603	12713	207	республика Чувашская, Ибресинский район, поселок Ибреси, Центральная, 32	f	large
16606	12716	210	республика Чувашская, Ибресинский район, поселок Ибреси, Солнечная, 38	f	small
16601	12712	205	республика Чувашская, Ибресинский район, поселок Ибреси, Свердлова, 14, офис ООО Водстроймонтаж п. Ибреси	f	medium
16622	12732	226	республика Чувашская, Ибресинский район, поселок Ибреси, Октябрьская, 20	f	small
16600	12711	204	республика Чувашская, Ибресинский район, поселок Ибреси, Мира, 23	f	medium
16599	12711	203	республика Чувашская, Ибресинский район, поселок Ибреси, Мира, 23	f	medium
16596	12708	200	республика Чувашская, Ибресинский район, поселок Ибреси, Маресьева, 20	f	medium
16595	12708	199	республика Чувашская, Ибресинский район, поселок Ибреси, Маресьева, 20	f	medium
16598	12710	202	республика Чувашская, Ибресинский район, поселок Ибреси, Кооперативная, 27, Центр соцобслуживания населения п. Ибреси	f	large
16618	12728	222	республика Чувашская, Ибресинский район, поселок Ибреси, Комсомольская, 58	f	small
16610	12720	214	республика Чувашская, Ибресинский район, поселок Ибреси, Комсомольская, 14	f	medium
16612	12722	216	республика Чувашская, Ибресинский район, поселок Ибреси, Евсевьева, 41	f	medium
16609	12719	213	республика Чувашская, Ибресинский район, село Бугуян, Кирова, 8	f	small
16608	12718	212	республика Чувашская, Ибресинский район, село Большие Абакасы, Советская, 80	f	small
16607	12717	211	республика Чувашская, Ибресинский район, село Большие Абакасы, Мирный, 14	f	medium
16604	12714	208	республика Чувашская, Ибресинский район, село Андреевка, Молодежная, 2	f	small
16617	12727	221	республика Чувашская, Ибресинский район, село Айбечи, Центральная, 32	f	medium
16581	12693	185	республика Чувашская, Вурнарский район, село Янишево, Центральная, 48	f	small
16592	12705	196	республика Чувашская, Вурнарский район, село Янгорчино, Советская, 2А	f	medium
16570	12681	174	республика Чувашская, Вурнарский район, село Ямбахтино, Центральная, 49В	f	small
66091	12656	151	республика Чувашская, Вурнарский район, село Эпшики, Заречная, 12	f	small
16590	12703	194	республика Чувашская, Вурнарский район, село Шинеры, Клубная, 238	f	small
16556	12665	160	республика Чувашская, Вурнарский район, село Чиршкас-Мураты, Новая, 14	t	small
16591	12704	195	республика Чувашская, Вурнарский район, село Чириш-Шинеры, Парковая, 207	f	small
16560	12670	164	республика Чувашская, Вурнарский район, поселок Чаркли, Гагарина, 35А	t	small
16593	12706	197	республика Чувашская, Вурнарский район, село Хорнзор, Молодежная, 12	f	small
16568	12679	172	республика Чувашская, Вурнарский район, село Хора-Сирма, Парковая, 1	t	small
16588	12700	192	республика Чувашская, Вурнарский район, село Хирпоси, Советская, 37	f	small
16578	12689	182	республика Чувашская, Вурнарский район, село Тузи-Сярмус, Школьная, 28	f	small
16579	12691	183	республика Чувашская, Вурнарский район, село Троицкое, А.Иванова, 1	f	small
16582	12694	186	республика Чувашская, Вурнарский район, село Сявалкасы, Шоссейная, 1Б	f	small
16575	12686	179	республика Чувашская, Вурнарский район, село Сявалкас-Хирпоси, Цивильная, 1В	t	small
16583	12695	187	республика Чувашская, Вурнарский район, село Сугут-Торбиково, Школьная, 4	f	small
16552	12661	156	республика Чувашская, Вурнарский район, село Старые Яхакасы, Новая, 2А	f	small
16559	12669	163	республика Чувашская, Вурнарский район, село Синьял-Яуши, Советская, 12А	f	small
14852	6174	909	республика Удмуртская, Сарапул, Гоголя, 23	f	large
16565	12675	169	республика Чувашская, Вурнарский район, село Сендимиркино, Центральная, 55	f	small
16589	12701	193	Россия, республика Чувашская, Вурнарский район	f	small
16572	12683	176	республика Чувашская, Вурнарский район, село Ослаба, Новая, 5	f	small
16587	12699	191	республика Чувашская, Вурнарский район, село Орауши, Первомайская, 14	f	small
16558	12668	162	республика Чувашская, Вурнарский район, село Ойкас-Яуши, Зеленая, 8А	f	small
16554	12663	158	республика Чувашская, Вурнарский район, село Новые Яхакасы, 40 лет Победы, 1В	f	medium
16594	12707	198	республика Чувашская, Вурнарский район, село Напольное Тугаево, Дружбы, 22	t	small
16574	12685	178	республика Чувашская, Вурнарский район, село Мамалаево, Административная, 3	f	small
16576	12687	180	республика Чувашская, Вурнарский район, село Малые Яуши, Центральная, 26	f	small
16546	12655	150	республика Чувашская, Вурнарский район, село Малдыкасы, Восточная, 1	f	small
16567	12677	171	республика Чувашская, Вурнарский район, село Кюстюмеры, Школьная, 1	f	medium
16577	12688	181	республика Чувашская, Вурнарский район, село Кюмель-Ямаши, Кооперативная, 2	f	small
16571	12682	175	республика Чувашская, Вурнарский район, село Кюльхири, Победы, 31	f	small
16573	12684	177	республика Чувашская, Вурнарский район, село Кольцовка, Центральная, 64А	f	small
16586	12698	190	республика Чувашская, Вурнарский район, село Кожар-Яндоба, Новая, 1	f	small
16561	12671	165	республика Чувашская, Вурнарский район, село Киберли, Лесная, 1А	f	small
16569	12680	173	республика Чувашская, Вурнарский район, село Калинино, Гагарина, 31	f	medium
16566	12676	170	республика Чувашская, Вурнарский район, село Ершипоси, переулок Юбилейный, 3	f	small
16584	12696	188	республика Чувашская, Вурнарский район, село Ермошкино, Школьная, 8	f	medium
16541	12649	145	республика Чувашская, Вурнарский район, поселок Вурнары, Пионерская, 9	f	large
16542	12650	146	республика Чувашская, Вурнарский район, поселок Вурнары, Ленина, 160А	f	large
16540	12648	144	республика Чувашская, Вурнарский район, поселок Вурнары, Карла Маркса, 1	f	large
16543	12651	147	республика Чувашская, Вурнарский район, поселок Вурнары, К.Маркса, 54	f	large
16539	12647	143	республика Чувашская, Вурнарский район, поселок Вурнары, Заводская, 1	f	large
16564	12674	168	республика Чувашская, Вурнарский район, село Вурманкасы, Советская, 64	f	small
16580	12692	184	республика Чувашская, Вурнарский район, село Вурман-Кибеки, Молодежная, 8	f	small
16563	12673	167	республика Чувашская, Вурнарский район, село Волонтер, Коммунаров, 6А	f	small
16562	12672	166	республика Чувашская, Вурнарский район, село Буртасы, пер.Школьный, 1	f	medium
16557	12667	161	республика Чувашская, Вурнарский район, село Большие Яуши, Коммунальная, 9	f	small
16545	12653	149	республика Чувашская, Вурнарский район, село Большие Хирлепы, Шоссейная, 54	f	small
16553	12662	157	республика Чувашская, Вурнарский район, село Большие Торханы, Здоровья, 1Б	f	small
16550	12659	154	республика Чувашская, Вурнарский район, село Апнеры, Кузнецкая, 32а	f	small
16555	12664	159	республика Чувашская, Вурнарский район, село Альмень-Сунары, Центральная, 17	f	small
16585	12697	189	республика Чувашская, Вурнарский район, село Альменево, Садовая, 13	t	small
16548	12657	152	республика Чувашская, Вурнарский район, село Алгазино, Центральная, 1	f	small
16544	12652	148	республика Чувашская, Вурнарский район, село Азим-Сирма, Советская, 22	f	small
16551	12660	155	республика Чувашская, Вурнарский район, село Абызово, Солнечная, Солнечная	f	medium
16531	12638	135	республика Чувашская, Батыревский район, село Яншихово, Центральная, 2	f	small
16491	12595	95	республика Чувашская, Батыревский район, село Шыгырдан, Ленина, 58	f	large
16489	12592	93	республика Чувашская, Батыревский район, село Шыгырдан, Ленина, 39	f	large
16490	12593	94	республика Чувашская, Батыревский район, село Шыгырдан, Вахитова, 39б	f	large
16509	12614	113	республика Чувашская, Батыревский район, село Шаймурзино, Николаева, 1	f	medium
16497	12601	101	республика Чувашская, Батыревский район, село Чувашские Ишаки, Куракова, 34	f	small
16513	12619	117	республика Чувашская, Батыревский район, село Хумара-Твар, Николаева, 1	t	small
16520	12626	124	республика Чувашская, Батыревский район, село Ульяновка, Советская, 44	t	small
16493	12597	97	республика Чувашская, Батыревский район, село Туруново, Магистральная, 35	f	medium
16501	12605	105	республика Чувашская, Батыревский район, село Тойси, Учительская, 8	f	medium
16533	12640	137	республика Чувашская, Батыревский район, село Тигашево, Депутатская, 33б	f	small
16498	12602	102	республика Чувашская, Батыревский район, село Татмыш-Югелево, Школьная, 1	f	small
16505	12610	109	республика Чувашская, Батыревский район, село Татарские Тимяши, Овражная, 1а	f	small
16535	12643	139	республика Чувашская, Батыревский район, село Татарские Сугуты, Школьная, 29	f	medium
16512	12617	116	республика Чувашская, Батыревский район, село Тарханы, Кокеля, 12	f	small
16511	12616	115	республика Чувашская, Батыревский район, село Тарханы, Кокеля, 12	f	medium
16534	12641	138	республика Чувашская, Батыревский район, село Сугуты, Советская, 1	f	large
16504	12609	108	республика Чувашская, Батыревский район, село Старые Тойси, Кооперативная, 4	f	medium
16500	12604	104	Россия, республика Чувашская, Батыревский район, село Старое Котяково	f	small
16503	12608	107	республика Чувашская, Батыревский район, село Старое Ахпердино, Кооперативная, 4	f	small
16524	12631	128	республика Чувашская, Батыревский район, село Сидели, Пионерская, 32	f	small
16518	12624	122	республика Чувашская, Батыревский район, село Сигачи, Победы, 2	f	small
16517	12623	121	республика Чувашская, Батыревский район, село Сигачи, Победы, 3	f	small
16529	12636	133	республика Чувашская, Батыревский район, село Полевые-Бикшики, Камалетдинова, 2	f	medium
16525	12632	129	республика Чувашская, Батыревский район, село Полевое Чекурово, Нижняя, 8	f	small
16508	12613	112	республика Чувашская, Батыревский район, село Подлесные Шигали, Центральная, 1	f	medium
16527	12634	131	республика Чувашская, Батыревский район, село Первомайское, Кирова, 71	f	medium
16507	12612	111	республика Чувашская, Батыревский район, село НорвашШигали, Главной дороги, 8	f	medium
16495	12599	99	республика Чувашская, Батыревский район, село Новое Котяково, Напольная, 35	t	small
16506	12611	110	республика Чувашская, Батыревский район, село Новое Бахтиарово, Кирова, 29	f	small
16499	12603	103	республика Чувашская, Батыревский район, село Новое Ахпердино, Ленина, 47	f	medium
16510	12615	114	республика Чувашская, Батыревский район, село Нижнее Турмышево, Школьная, 22	f	medium
16530	12637	134	республика Чувашская, Батыревский район, село Малые Арабузи, Садовая, 19	f	small
16494	12598	98	республика Чувашская, Батыревский район, село Малое Батырево, Крепкова, 38	f	small
16521	12627	125	республика Чувашская, Батыревский район, село Люля, Набережная, 9	f	small
16538	12646	142	республика Чувашская, Батыревский район, село Красномайск, Центральная, 58	f	small
16528	12635	132	республика Чувашская, Батыревский район, село Кокшаново, Советская, 89	f	small
16537	12645	141	республика Чувашская, Батыревский район, село Кзыл-Чишма, Центральная, 1	f	small
16492	12596	96	республика Чувашская, Батыревский район, село Кзыл-Камыш, Школьная, 7	t	small
16532	12639	136	республика Чувашская, Батыревский район, село Именево, Братьев Шигабетдиновых, 1а	f	small
16496	12600	100	республика Чувашская, Батыревский район, село Долгий Остров, Апанаева, 10	f	medium
16526	12633	130	республика Чувашская, Батыревский район, село Верхние Бюртли Шигали, Колхозная, 3	t	small
16502	12607	106	республика Чувашская, Батыревский район, село Булаково, Канашская, 2	f	small
16515	12621	119	республика Чувашская, Батыревский район, село Большое Чеменево, Ф. Туптова, 38	f	small
16519	12625	123	республика Чувашская, Батыревский район, село Бахтигильдино, Школьная, 35	f	small
16485	12588	89	республика Чувашская, Батыревский район, село Батырево	f	large
16487	12590	91	республика Чувашская, Батыревский район, село Батырево, проспект Ленина, 30	f	large
16486	12589	90	республика Чувашская, Батыревский район, село Батырево, Советская, 10	f	large
16522	12628	126	республика Чувашская, Батыревский район, село Балабаш-Нурусово, Советская, 22	t	small
16523	12629	127	республика Чувашская, Батыревский район, село Балабаш-Баишево, Кузнечная, 2	f	medium
16516	12622	120	республика Чувашская, Батыревский район, село Бакашево, Новая, 73	f	small
16536	12644	140	республика Чувашская, Батыревский район, село Алманчиково, Центральная, 3	f	medium
16514	12620	118	республика Чувашская, Батыревский район, село Абамза, Центральная, 7	f	small
16460	12563	64	республика Чувашская, Аликовский район, село Яргунькино, сельская библиотека, читальный зал	f	small
16482	12585	86	республика Чувашская, Аликовский район, село Яндоба, КДЦзрительный зал	f	medium
16472	12575	76	республика Чувашская, Аликовский район, село Эренары, бывшее здание ФАП	f	small
16464	12567	68	республика Чувашская, Аликовский район, село Шундряши, сельский клуб	f	small
16477	12580	81	Россия, республика Чувашская, Аликовский район, село Шумшеваши	f	small
16468	12571	72	республика Чувашская, Аликовский район, село Шерашево, сельский клуб зрительный зал	f	small
16473	12576	77	республика Чувашская, Аликовский район, село Чувашская Сорма, КДЦ, фойе	f	small
16483	12586	87	республика Чувашская, Аликовский район, село Челкасы, адмздание СХПК Звездазал заседаний	f	small
16470	12573	74	республика Чувашская, Аликовский район, село Хирлеппоси, сельский клуб-библиотека, зрительный зал	f	small
16462	12565	66	республика Чувашская, Аликовский район, село Устье, Устьинский ФАП	f	small
16788	12772	392	республика Чувашская, Аликовский район, село Урмаево, Баумана, 3	f	large
16466	12569	70	республика Чувашская, Аликовский район, село Тури-Выла, сельская библиотека-клубзрительный зал	f	small
16471	12574	75	республика Чувашская, Аликовский район, село Тенеево, СДК	f	small
16467	12570	71	республика Чувашская, Аликовский район, село Таутово, КДЦ, фойе	f	medium
16453	12556	57	республика Чувашская, Аликовский район, село Сириккасы, дом фольклора, фойе	t	small
16484	12587	88	республика Чувашская, Аликовский район, село Русская Сорма, сельская библиотека, читальный зал	f	small
16463	12566	67	республика Чувашская, Аликовский район, село Раскильдино, КДЦ, зрительный зал	f	small
16478	12581	82	Россия, республика Чувашская, Аликовский район	f	small
16461	12564	65	республика Чувашская, Аликовский район, село Питишево, СДК, зрительный зал	f	small
16475	12578	79	республика Чувашская, Аликовский район, село Нижние Елыши, сельский клуб-библиотека, фойе	t	small
16476	12579	80	республика Чувашская, Аликовский район, село Мартынкино, сельский клуб-библиотекафойе	t	small
16469	12572	73	республика Чувашская, Аликовский район, село Малые Туваны, сельский клуб, второй этаж, фойе	f	medium
16459	12562	63	республика Чувашская, Аликовский район, село Крымзарайкино, информационно-культурный центр	f	small
16480	12583	84	республика Чувашская, Аликовский район, село Кивой, сельский клуб зрительный зал	f	small
16479	12582	83	республика Чувашская, Аликовский район, село Ишпарайкино, СДК	f	small
16458	12561	62	республика Чувашская, Аликовский район, село Илгышево, МБОУ Илгышевская СОШ1 этаж фойе	f	medium
16455	12558	59	республика Чувашская, Аликовский район, село Ефремкасы, КДЦ, фойе	f	medium
16457	12560	61	республика Чувашская, Аликовский район, село Вотланы, СДК фойе	f	medium
16456	12559	60	республика Чувашская, Аликовский район, село Верхние Карачуры, СДК, 1 этаж	f	medium
16481	12584	85	республика Чувашская, Аликовский район, село Большое Ямашаево, МБОУ Большеямашевская СОШ, 1 этаж, фойе	f	small
16474	12577	78	Россия, республика Чувашская, Аликовский район	f	small
16465	12568	69	республика Чувашская, Аликовский район, село Большие Токташи, прокатный пункт, зрительный зал	f	small
16452	12555	56	республика Чувашская, Аликовский район, село Большая Выла, МБОУ Большевыльская СОШ спортзал	f	small
16451	12554	55	республика Чувашская, Аликовский район, село Аликово, Советская, 15	f	medium
16449	12552	53	республика Чувашская, Аликовский район, село Аликово, Советская, 13	f	medium
16448	12551	52	республика Чувашская, Аликовский район, село Аликово, Советская, 13	f	medium
16419	12522	23	республика Чувашская, Алатырский район, село Ялушево, Озерная, 1	f	small
16411	12338	15	республика Чувашская, Алатырский район, село Явлей, Первомайская, 5	f	small
16418	12521	22	республика Чувашская, Алатырский район, село Чуварлей, Ворошилова, 144	f	medium
16409	12463	13	республика Чувашская, Алатырский район, село Сурский Майдан, Чебоксарская, 72	f	small
16417	12520	21	республика Чувашская, Алатырский район, село Стемасы, Ленина, 124	f	large
14851	6173	908	республика Удмуртская, Сарапул, Гоголя, 30а	f	large
16416	12519	20	республика Чувашская, Алатырский район, село Старые Айбеси, Школьная, 5	f	medium
16404	12512	8	республика Чувашская, Алатырский район, село Соловьевский, Верхнее-Иветская, 5	f	small
16415	12518	19	республика Чувашская, Алатырский район, село Сойгино, К.Маркса, 38	f	medium
16414	12517	18	республика Чувашская, Алатырский район, село Первомайский, Ленина, 50	f	medium
16412	12444	16	республика Чувашская, Алатырский район, село Новые Айбеси, Ленина, 18	f	medium
16410	12499	14	республика Чувашская, Алатырский район, село Миренки, Советская, 242	f	medium
16408	12416	12	республика Чувашская, Алатырский район, село Междуречье, 50 лет ЧАССР, 14	f	small
16405	12513	9	республика Чувашская, Алатырский район, село Кувакино, Пролетарская, 1	f	small
16420	12523	24	республика Чувашская, Алатырский район, поселок Киря, Сидорина, 8	f	medium
16421	12524	25	республика Чувашская, Алатырский район, поселок Киря, Лермонтова, 5	f	medium
16406	12514	10	республика Чувашская, Алатырский район, село Ичиксы, Новая линия, 6а	f	small
16403	12511	7	республика Чувашская, Алатырский район, село Иваньково-Ленино, Пушкина, 1а	f	medium
16402	12510	6	республика Чувашская, Алатырский район, село Восход, Садовая, 9	f	medium
16407	12515	11	республика Чувашская, Алатырский район, село Березовый Майдан, Кооперативная, 22	t	small
16401	12509	5	республика Чувашская, Алатырский район, село Ахматово, Ленина, 53	f	medium
16400	12508	4	республика Чувашская, Алатырский район, село Атрать, Комсомольская, 7	f	small
16399	12507	3	республика Чувашская, Алатырский район, село Атрать, Кирова, 2а	f	small
16398	12506	2	республика Чувашская, Алатырский район, село Анютино, Молодежная, 10	f	small
16397	12505	1	республика Чувашская, Алатырский район, село Алтышево, Октябрьская, 2б	f	medium
16413	12516	17	республика Чувашская, Алатырский район, село Алтышево, Заводская, 6	f	medium
15140	6451	1737	республика Удмуртская, деревня Шудья, Центральная, 13, Досуговый центр	t	small
66009	6182	918	республика Удмуртская, Сарапул	f	large
66008	6176	911	республика Удмуртская, Сарапул	f	large
14883	6199	940	республика Удмуртская, Сарапул, Электрозаводская, 3	f	large
14894	6208	951	республика Удмуртская, Сарапул, Школьная, 22	f	medium
14886	6202	943	республика Удмуртская, Сарапул, Чистякова, 42	f	large
14881	6197	938	республика Удмуртская, Сарапул, Фурманова, 1а	f	large
14880	6197	937	республика Удмуртская, Сарапул, Фурманова, 1а	f	large
14884	6200	941	республика Удмуртская, Сарапул, Фрунзе, 18	f	large
14873	6191	930	республика Удмуртская, Сарапул, Фабричная, 1а	f	large
14866	6186	923	республика Удмуртская, Сарапул, Труда, 62	f	large
14864	6184	921	республика Удмуртская, Сарапул, Степана Разина, 59	f	large
14850	6172	907	республика Удмуртская, Сарапул, Советская, 69	f	large
14847	6170	904	республика Удмуртская, Сарапул, Соболева, 15	f	large
14867	6187	924	республика Удмуртская, Сарапул, Пугачева, 63	f	medium
14865	6185	922	республика Удмуртская, Сарапул, Пугачева, 60	f	large
14863	6183	920	республика Удмуртская, Сарапул, Пугачева, 76	f	large
14862	6183	919	республика Удмуртская, Сарапул, Пугачева, 76	f	large
14859	6180	916	республика Удмуртская, Сарапул, Пугачева, 130	f	large
14853	6175	910	республика Удмуртская, Сарапул, Первомайская, 22а	f	large
14875	6193	932	республика Удмуртская, Сарапул, Озерная, 108	f	large
14885	6201	942	республика Удмуртская, Сарапул, Молодежная, 5	f	medium
14892	6206	949	республика Удмуртская, Сарапул, Мельникова, 8	f	large
14877	6195	934	республика Удмуртская, Сарапул, Ленина, 78а	f	large
14874	6192	931	республика Удмуртская, Сарапул, Крылова, 15	f	large
14855	6177	912	республика Удмуртская, Сарапул, Красноармейская, 93	f	large
14845	6168	902	республика Удмуртская, Сарапул, Костычева, 28	f	large
14844	6168	901	республика Удмуртская, Сарапул, Костычева, 28	f	large
14878	6194	935	республика Удмуртская, Сарапул, Комсомольская, 37	f	large
14876	6194	933	республика Удмуртская, Сарапул, Комсомольская, 37	f	large
14890	6204	947	республика Удмуртская, Сарапул, Калинина, 5	f	large
14889	6204	946	республика Удмуртская, Сарапул, Калинина, 5	f	large
14882	6198	939	республика Удмуртская, Сарапул, Жуковского, 14	f	large
14857	6178	914	республика Удмуртская, Сарапул, Горького, 102	f	large
14860	6181	917	республика Удмуртская, Сарапул, Гагарина, 52	f	large
14858	6179	915	республика Удмуртская, Сарапул, Гагарина, 85	f	large
14879	6196	936	республика Удмуртская, Сарапул, Вокзальная, 13	f	large
14872	6190	929	республика Удмуртская, Сарапул, Азина, 140	f	large
14871	6190	928	республика Удмуртская, Сарапул, Азина, 140	f	large
14870	6188	927	республика Удмуртская, Сарапул, Азина, 75	f	large
14868	6188	925	республика Удмуртская, Сарапул, Азина, 75	f	large
14846	6169	903	республика Удмуртская, Сарапул, Tрактовая, 21	f	medium
14895	6209	952	республика Удмуртская, Сарапул, 5-й Зеленый проезд, 5	f	large
14888	6203	945	республика Удмуртская, Сарапул, 20 лет Победы, 7	f	large
14887	6203	944	республика Удмуртская, Сарапул, 20 лет Победы, 7	f	large
14849	6171	906	республика Удмуртская, Сарапул, Сивкова, 24г	f	large
14848	6171	905	республика Удмуртская, Сарапул, Сивкова, 24г	f	large
15111	6448	1734	республика Удмуртская, деревня Позимь, 25, эдание Позимского клуба	f	medium
15617	6922	3319	республика Удмуртская, Якшур-Бодьинский район	f	small
15110	6447	1733	республика Удмуртская, село Первомайский, Сабурова, 1-б, МБУ КК Первомайский	f	large
15108	6360	1731	республика Удмуртская, село Октябрьский, МОУ Октябрьская СОШ	f	large
14821	6146	801	республика Удмуртская, Можга	f	large
14825	6151	805	республика Удмуртская, Можга, Школьный переулок, 1	f	large
14842	6166	822	республика Удмуртская, Можга, Фалалеева, 14	f	large
14839	6163	819	республика Удмуртская, Можга, Фалалеева, 2	f	large
14831	6156	811	республика Удмуртская, Можга, Спортивная, 10	f	large
14830	6155	810	республика Удмуртская, Можга, Советская, 21	f	large
14823	6149	803	республика Удмуртская, Можга, Свердловский бульвар, 71	f	large
14824	6150	804	республика Удмуртская, Можга, Октябрьская, 44	f	large
14841	6165	821	республика Удмуртская, Можга, Наговицына, 199	f	large
14835	6159	815	республика Удмуртская, Можга, Наговицына, 107	f	large
14834	6159	814	республика Удмуртская, Можга, Наговицына, 107	f	large
14833	6158	813	республика Удмуртская, Можга, Короленко, 50	f	large
14837	6161	817	республика Удмуртская, Можга, Кирова, 67	f	large
14836	6160	816	республика Удмуртская, Можга, Кирова, 55	f	large
14822	6147	802	республика Удмуртская, Можга, Дзержинского, 1	f	large
14827	6153	807	республика Удмуртская, Можга, Горбунова, 3	f	large
14826	6152	806	республика Удмуртская, Можга, Горбунова, 32	f	large
14838	6162	818	республика Удмуртская, Можга, Гагарина, 6	f	large
14832	6157	812	республика Удмуртская, Можга, Вокзальная, 11	f	large
14829	6154	809	республика Удмуртская, Можга, Водокачный переулок, 4	f	large
14828	6154	808	республика Удмуртская, Можга, Водокачный переулок, 4	f	large
14840	6164	820	республика Удмуртская, Можга, Вешняковский микрорайон, 13	f	large
15207	6519	1909	республика Удмуртская, Камбарка, территория ОАО 136 ЦБПР, столовая	f	medium
15199	6511	1901	республика Удмуртская, Камбарка	f	medium
15200	6512	1902	республика Удмуртская, Камбарка, Уральский переулок, 5	f	large
15211	6524	1913	республика Удмуртская, Камбарка, Советская, 89	f	small
15201	6513	1903	республика Удмуртская, Камбарка, Советская, 26	f	large
15206	6518	1908	республика Удмуртская, Камбарка, Первомайская, 237	f	large
15204	6516	1906	республика Удмуртская, Камбарка, Первомайская, 237	f	large
15205	6517	1907	республика Удмуртская, Камбарка, Маяковского, 2а	f	medium
15202	6514	1904	республика Удмуртская, Камбарка, К.Маркса, 73	f	large
15203	6515	1905	республика Удмуртская, Камбарка, Азина, 14	f	large
66048	6840	3033	республика Удмуртская, Ижевск, 427260	f	large
66047	6840	3032	республика Удмуртская, Ижевск, 427260	f	large
66006	6104	643	республика Удмуртская, Ижевск, 427432	f	large
66007	6104	644	республика Удмуртская, Ижевск, 427432	f	large
14656	6045	438	республика Удмуртская, Ижевск, Детско-подростковый клуб Колосок	f	large
14607	6010	352	республика Удмуртская, Ижевск, Административное здание ПНИ	f	small
66003	5981	310	республика Удмуртская, Ижевск, 426069	f	large
14534	5964	232	республика Удмуртская, Ижевск, 61	f	large
14550	5964	248	республика Удмуртская, Ижевск, 61	f	large
14727	6064	552	республика Удмуртская, Ижевск, имени Петрова, 19	f	large
14695	6064	520	республика Удмуртская, Ижевск, имени Петрова, 19	f	large
14694	6064	519	республика Удмуртская, Ижевск, имени Петрова, 19	f	large
14693	6064	518	республика Удмуртская, Ижевск, имени Петрова, 19	f	large
14645	6037	427	республика Удмуртская, Ижевск, Щедрина, 1	f	large
14672	6037	454	республика Удмуртская, Ижевск, Щедрина, 1	f	large
14646	6037	428	республика Удмуртская, Ижевск, Щедрина, 1	f	large
14561	5977	306	республика Удмуртская, Ижевск, Школьная, 54	f	large
14560	5977	305	республика Удмуртская, Ижевск, Школьная, 54	f	large
14559	5977	304	республика Удмуртская, Ижевск, Школьная, 54	f	large
14491	5922	141	республика Удмуртская, Ижевск, Шишкина, 3	f	large
14464	5922	114	республика Удмуртская, Ижевск, Шишкина, 3	f	large
14587	5998	332	республика Удмуртская, Ижевск, Широкий переулок, 71А	f	large
14586	5997	331	республика Удмуртская, Ижевск, Широкий переулок, 73	f	large
14536	5966	234	республика Удмуртская, Ижевск, Шевченко, 25	f	large
66018	6325	1308	республика Удмуртская, Ижевск, Чайковского, 15	f	medium
14610	6012	355	республика Удмуртская, Ижевск, Холмогорова, 37в	f	small
14603	6007	348	республика Удмуртская, Ижевск, Холмогорова, 37	f	large
14600	6007	345	республика Удмуртская, Ижевск, Холмогорова, 37	f	large
14601	6006	346	республика Удмуртская, Ижевск, Холмогорова, 34	f	large
14599	6006	344	республика Удмуртская, Ижевск, Холмогорова, 34	f	large
14604	6004	349	республика Удмуртская, Ижевск, Холмогорова, 22	f	large
14597	6004	342	республика Удмуртская, Ижевск, Холмогорова, 22	f	large
14497	5938	147	республика Удмуртская, Ижевск, Халтурина, 2а	f	large
14465	5923	115	республика Удмуртская, Ижевск, Халтурина, 150	f	large
14466	5923	116	республика Удмуртская, Ижевск, Халтурина, 150	f	large
14452	5912	102	республика Удмуртская, Ижевск, Университетская, 1	f	large
14453	5912	103	республика Удмуртская, Ижевск, Университетская, 1	f	large
14456	5913	106	республика Удмуртская, Ижевск, Удмуртская , 230	f	large
14455	5913	105	республика Удмуртская, Ижевск, Удмуртская , 230	f	large
14454	5913	104	республика Удмуртская, Ижевск, Удмуртская , 230	f	large
14457	5914	107	республика Удмуртская, Ижевск, Удмуртская, 284	f	large
14725	6067	550	республика Удмуртская, Ижевск, Труда, 18	f	large
14705	6067	530	республика Удмуртская, Ижевск, Труда, 18	f	large
14704	6067	529	республика Удмуртская, Ижевск, Труда, 18	f	large
14703	6067	528	республика Удмуртская, Ижевск, Труда, 18	f	large
14499	5921	149	республика Удмуртская, Ижевск, Тимирязева, 23а	f	large
14498	5921	148	республика Удмуртская, Ижевск, Тимирязева, 23а	f	large
14490	5921	140	республика Удмуртская, Ижевск, Тимирязева, 23а	f	large
14463	5921	113	республика Удмуртская, Ижевск, Тимирязева, 23а	f	large
14495	5936	145	республика Удмуртская, Ижевск, Тельмана, 14	f	large
14540	5969	238	республика Удмуртская, Ижевск, Тверская, 58	f	large
14539	5969	237	республика Удмуртская, Ижевск, Тверская, 58	f	large
14538	5968	236	республика Удмуртская, Ижевск, Тверская, 56	f	large
14698	6065	523	республика Удмуртская, Ижевск, Татьяны Барамзиной, 36	f	large
14697	6065	522	республика Удмуртская, Ижевск, Татьяны Барамзиной, 36	f	large
14696	6065	521	республика Удмуртская, Ижевск, Татьяны Барамзиной, 36	f	large
14567	5983	312	республика Удмуртская, Ижевск, Студенческая, 7	f	large
14583	5980	328	республика Удмуртская, Ижевск, Студенческая, 42	f	large
14564	5980	309	республика Удмуртская, Ижевск, Студенческая, 42	f	large
14511	5947	209	республика Удмуртская, Ижевск, Степная , 81	f	large
14644	6036	426	республика Удмуртская, Ижевск, Степана Разина, 56	f	large
14688	6062	513	республика Удмуртская, Ижевск, Старосмирновская, 28	t	small
14683	6059	508	республика Удмуртская, Ижевск, Спортивная, 20	f	large
14723	6077	548	республика Удмуртская, Ижевск, Союзная, 59	f	large
14722	6077	547	республика Удмуртская, Ижевск, Союзная, 59	f	large
14719	6075	544	республика Удмуртская, Ижевск, Союзная, 149	f	large
14718	6075	543	республика Удмуртская, Ижевск, Союзная, 149	f	large
14461	5919	111	республика Удмуртская, Ижевск, Софьи Ковалевской, 16	f	large
14630	6029	412	республика Удмуртская, Ижевск, Советская , 30	f	large
14579	5991	324	республика Удмуртская, Ижевск, Советская, 17	f	large
14451	5911	101	республика Удмуртская, Ижевск, Советская, 23	f	large
14613	6015	358	республика Удмуртская, Ижевск, Славянское шоссе, 0/13	f	medium
14492	95026	142	республика Удмуртская, Ижевск, Сельская, 1Б	f	large
14596	6003	341	республика Удмуртская, Ижевск, Северный переулок, 53	f	large
14595	6003	340	республика Удмуртская, Ижевск, Северный переулок, 53	f	large
14517	5952	215	республика Удмуртская, Ижевск, Саратовская, 38	f	large
14728	6063	553	республика Удмуртская, Ижевск, Сабурова, 23	f	large
14689	6063	514	республика Удмуртская, Ижевск, Сабурова, 23	f	large
14686	6061	511	республика Удмуртская, Ижевск, Сабурова, 49а	f	large
14687	6061	512	республика Удмуртская, Ижевск, Сабурова, 49а	f	large
14685	6061	510	республика Удмуртская, Ижевск, Сабурова, 49а	f	large
14667	6050	449	республика Удмуртская, Ижевск, Ракетная, 17	f	large
14650	6040	432	республика Удмуртская, Ижевск, Ракетная, 11	f	large
14608	6001	353	республика Удмуртская, Ижевск, Пушкинская , 285	f	large
14593	6001	338	республика Удмуртская, Ижевск, Пушкинская , 285	f	large
14625	6026	407	республика Удмуртская, Ижевск, Пушкинская, 177	f	large
14624	6026	406	республика Удмуртская, Ижевск, Пушкинская, 177	f	large
14623	6026	405	республика Удмуртская, Ижевск, Пушкинская, 177	f	large
14606	6005	351	республика Удмуртская, Ижевск, Пушкинская, 371	f	large
14598	6005	343	республика Удмуртская, Ижевск, Пушкинская, 371	f	large
14585	5996	330	республика Удмуртская, Ижевск, Пушкинская, 245	f	large
14652	6042	434	республика Удмуртская, Ижевск, Прасовский переулок, 5	f	medium
66025	6420	1705	республика Удмуртская, Завьяловский район	t	medium
14612	6014	357	республика Удмуртская, Ижевск, Песочная, 32а	f	medium
14509	5945	207	республика Удмуртская, Ижевск, Пермская, 20	f	large
14468	5924	118	республика Удмуртская, Ижевск, Парковая, 9а	f	large
14467	5924	117	республика Удмуртская, Ижевск, Парковая, 9а	f	large
14526	5958	224	республика Удмуртская, Ижевск, Оружейника Драгунова, 74	f	large
14525	5958	223	республика Удмуртская, Ижевск, Оружейника Драгунова, 74	f	large
14524	5958	222	республика Удмуртская, Ижевск, Оружейника Драгунова, 74	f	large
14537	5967	235	республика Удмуртская, Ижевск, Орсовская, 17	f	large
14654	6043	436	республика Удмуртская, Ижевск, Орджоникидзе, 33а	f	large
14653	6043	435	республика Удмуртская, Ижевск, Орджоникидзе, 33а	f	large
14649	6039	431	республика Удмуртская, Ижевск, Орджоникидзе, 17	f	large
14501	5940	151	республика Удмуртская, Ижевск, Оранжерейная, 24	f	medium
14531	5961	229	республика Удмуртская, Ижевск, Новостроительная, 28	f	large
14528	5959	226	республика Удмуртская, Ижевск, Новостроительная, 34	f	large
14527	5959	225	республика Удмуртская, Ижевск, Новостроительная, 34	f	large
14717	6074	542	республика Удмуртская, Ижевск, Молодежная, 97	f	large
14716	6073	541	республика Удмуртская, Ижевск, Молодежная, 64	f	large
14715	6073	540	республика Удмуртская, Ижевск, Молодежная, 64	f	large
14713	6072	538	республика Удмуртская, Ижевск, Молодежная, 26	f	large
14714	6072	539	республика Удмуртская, Ижевск, Молодежная, 26	f	large
14710	6071	535	республика Удмуртская, Ижевск, Молодежная, 61	f	large
14709	6071	534	республика Удмуртская, Ижевск, Молодежная, 61	f	large
14568	5984	313	республика Удмуртская, Ижевск, Металлистов, 32	f	large
14562	5979	307	республика Удмуртская, Ижевск, Металлистов, 46	f	large
14577	5979	322	республика Удмуртская, Ижевск, Металлистов, 46	f	large
14563	5979	308	республика Удмуртская, Ижевск, Металлистов, 46	f	large
14609	6011	354	республика Удмуртская, Ижевск, Майская, 13А	f	large
14602	6008	347	республика Удмуртская, Ижевск, Майская, 14а	f	large
14553	5975	251	республика Удмуртская, Ижевск, Локомотивная, 29	f	large
14552	5975	250	республика Удмуртская, Ижевск, Локомотивная, 29	f	large
14663	6048	445	республика Удмуртская, Ижевск, Ленина, 168	f	large
14662	6048	444	республика Удмуртская, Ижевск, Ленина, 168	f	large
14661	6048	443	республика Удмуртская, Ижевск, Ленина, 168	f	large
14664	6046	446	республика Удмуртская, Ижевск, Ленина, 114	f	large
14657	6046	439	республика Удмуртская, Ижевск, Ленина, 114	f	large
14634	6031	416	республика Удмуртская, Ижевск, Ленина, 82	f	large
14633	6028	415	республика Удмуртская, Ижевск, Ленина, 68	f	large
14629	6028	411	республика Удмуртская, Ижевск, Ленина, 68	f	medium
14508	5944	206	республика Удмуртская, Ижевск, Леваневского, 102	f	large
14507	5944	205	республика Удмуртская, Ижевск, Леваневского, 102	f	large
14555	5943	253	республика Удмуртская, Ижевск, Леваневского, 2а	f	large
14506	5943	204	республика Удмуртская, Ижевск, Леваневского, 2а	f	large
14505	5943	203	республика Удмуртская, Ижевск, Леваневского, 2а	f	large
14675	6055	457	республика Удмуртская, Ижевск, Курортная, 2	f	small
14578	5990	323	республика Удмуртская, Ижевск, Красногеройская улица, 12	f	medium
14614	6016	359	республика Удмуртская, Ижевск, Красногеройская, 28а	f	medium
134969	95202	458	республика Удмуртская, Ижевск, Красноармейская, 132а	f	large
14622	6025	404	республика Удмуртская, Ижевск, Красноармейская, 130	f	large
14668	6023	450	республика Удмуртская, Ижевск, Красноармейская, 78	f	large
14636	6023	418	республика Удмуртская, Ижевск, Красноармейская, 78	f	large
14620	6023	402	республика Удмуртская, Ижевск, Красноармейская, 78	f	large
14702	6066	527	республика Удмуртская, Ижевск, Короткова, 17а	f	large
14701	6066	526	республика Удмуртская, Ижевск, Короткова, 17а	f	large
14700	6066	525	республика Удмуртская, Ижевск, Короткова, 17а	f	large
14699	6066	524	республика Удмуртская, Ижевск, Короткова, 17а	f	large
14643	6032	425	республика Удмуртская, Ижевск, Коммунаров, 144	f	large
14637	6032	419	республика Удмуртская, Ижевск, Коммунаров, 144	f	large
14628	6027	410	республика Удмуртская, Ижевск, Коммунаров, 200	f	large
14627	6027	409	республика Удмуртская, Ижевск, Коммунаров, 200	f	large
14626	6027	408	республика Удмуртская, Ижевск, Коммунаров, 200	f	large
14594	6002	339	республика Удмуртская, Ижевск, Коммунаров, 353а	f	large
14581	5993	326	республика Удмуртская, Ижевск, Коммунаров, 281	f	large
14547	5974	245	республика Удмуртская, Ижевск, Клубная, 50а	f	large
14530	5955	228	республика Удмуртская, Ижевск, Клубная, 58	f	large
14548	5955	246	республика Удмуртская, Ижевск, Клубная, 58	f	large
14521	5955	219	республика Удмуртская, Ижевск, Клубная, 58	f	large
14520	5954	218	республика Удмуртская, Ижевск, Клубная, 82а	f	large
14519	5954	217	республика Удмуртская, Ижевск, Клубная, 82а	f	large
14546	5916	244	республика Удмуртская, Ижевск, Клубная, 33	f	large
14611	6013	356	республика Удмуртская, Ижевск, Кирова, 56	f	large
14605	6009	350	республика Удмуртская, Ижевск, Кирова, 22	f	medium
14590	5999	335	республика Удмуртская, Ижевск, Кирова, 110	f	large
14589	5999	334	республика Удмуртская, Ижевск, Кирова, 110	f	large
14582	5994	327	республика Удмуртская, Ижевск, Кирова, 108	f	large
14572	5987	317	республика Удмуртская, Ижевск, Кирова, 16	f	large
14571	5987	316	республика Удмуртская, Ижевск, Кирова, 16	f	large
14635	6024	417	республика Удмуртская, Ижевск, Карла Маркса, 75	f	large
14621	6024	403	республика Удмуртская, Ижевск, Карла Маркса, 75	f	large
14619	6022	401	республика Удмуртская, Ижевск, Карла Маркса, 164	f	large
14592	6000	337	республика Удмуртская, Ижевск, Карла Маркса, 427	f	large
14591	6000	336	республика Удмуртская, Ижевск, Карла Маркса, 427	f	large
14584	5995	329	республика Удмуртская, Ижевск, Карла Маркса, 288а	f	large
14580	5992	325	республика Удмуртская, Ижевск, Карла Маркса, 288а	f	large
14673	6053	455	республика Удмуртская, Ижевск, Карла Либкнехта, 24	f	large
14665	6049	447	республика Удмуртская, Ижевск, Карла Либкнехта, 24	f	large
14638	6033	420	республика Удмуртская, Ижевск, Карла Либкнехта, 53	f	large
14639	6033	421	республика Удмуртская, Ижевск, Карла Либкнехта, 53	f	large
14651	6041	433	республика Удмуртская, Ижевск, Камская, 6А	f	large
14523	5957	221	республика Удмуртская, Ижевск, Зои Космодемьянской, 109	f	large
14549	5960	247	республика Удмуртская, Ижевск, Заречное шоссе, 37	f	large
14543	5960	241	республика Удмуртская, Ижевск, Заречное шоссе, 37	f	large
14529	5960	227	республика Удмуртская, Ижевск, Заречное шоссе, 37	f	large
14522	5956	220	республика Удмуртская, Ижевск, Заречное шоссе, 39	f	large
14477	5927	127	республика Удмуртская, Ижевск, Дзержинского, 71	f	large
14476	5927	126	республика Удмуртская, Ижевск, Дзержинского, 71	f	large
14475	5927	125	республика Удмуртская, Ижевск, Дзержинского, 71	f	large
14471	5925	121	республика Удмуртская, Ижевск, Дзержинского, 9	f	large
14470	5925	120	республика Удмуртская, Ижевск, Дзержинского, 9	f	large
14469	5925	119	республика Удмуртская, Ижевск, Дзержинского, 9	f	large
14655	6044	437	республика Удмуртская, Ижевск, Демократическая, 37	f	large
14670	6052	452	республика Удмуртская, Ижевск, Гороховая, 10	f	small
14545	5973	243	республика Удмуртская, Ижевск, Городок Машиностроителей, 76	f	small
14504	5942	202	республика Удмуртская, Ижевск, Гагарина, 29	f	large
14503	5942	201	республика Удмуртская, Ижевск, Гагарина, 29	f	large
14493	5934	143	республика Удмуртская, Ижевск, Воткинское шоссе, 166б	f	medium
14669	6038	451	республика Удмуртская, Ижевск, Восточная, 12	f	large
14648	6038	430	республика Удмуртская, Ижевск, Восточная, 12	f	large
14647	6038	429	республика Удмуртская, Ижевск, Восточная, 12	f	large
14640	6034	422	республика Удмуртская, Ижевск, Восточная, 1	f	large
14641	6034	423	республика Удмуртская, Ижевск, Восточная, 1	f	large
14682	6058	507	республика Удмуртская, Ижевск, Ворошилова, 17	f	large
14681	6058	506	республика Удмуртская, Ижевск, Ворошилова, 17	f	large
14680	6058	505	республика Удмуртская, Ижевск, Ворошилова, 17	f	large
14679	6057	504	республика Удмуртская, Ижевск, Ворошилова, 66	f	large
14678	6057	503	республика Удмуртская, Ижевск, Ворошилова, 66	f	large
14677	6057	502	республика Удмуртская, Ижевск, Ворошилова, 66	f	large
14724	6056	549	республика Удмуртская, Ижевск, Ворошилова, 57	f	large
14692	6056	517	республика Удмуртская, Ижевск, Ворошилова, 57	f	large
14676	6056	501	республика Удмуртская, Ижевск, Ворошилова, 57	f	large
14666	6035	448	республика Удмуртская, Ижевск, Володарского, 52	f	large
14642	6035	424	республика Удмуртская, Ижевск, Володарского, 52	f	large
14632	6030	414	республика Удмуртская, Ижевск, Владимира Краева, 50	f	large
14631	6030	413	республика Удмуртская, Ижевск, Владимира Краева, 50	f	large
14482	5929	132	республика Удмуртская, Ижевск, Буммашевская, 50	f	large
14481	5929	131	республика Удмуртская, Ижевск, Буммашевская, 50	f	large
14480	5929	130	республика Удмуртская, Ижевск, Буммашевская, 50	f	large
14479	5928	129	республика Удмуртская, Ижевск, Буммашевская, 66а	f	large
14478	5928	128	республика Удмуртская, Ижевск, Буммашевская, 66а	f	large
14574	5988	319	республика Удмуртская, Ижевск, Береговая, 11	f	large
14573	5988	318	республика Удмуртская, Ижевск, Береговая, 11	f	large
14691	6060	516	республика Удмуртская, Ижевск, Барышникова, 51	f	large
14690	6060	515	республика Удмуртская, Ижевск, Барышникова, 51	f	large
14684	6060	509	республика Удмуртская, Ижевск, Барышникова, 51	f	large
14551	5948	249	республика Удмуртская, Ижевск, Азина, 325	f	large
14513	5948	211	республика Удмуртская, Ижевск, Азина, 325	f	large
14512	5948	210	республика Удмуртская, Ижевск, Азина, 325	f	large
14510	5946	208	республика Удмуртская, Ижевск, Азина, 84	f	large
14516	5951	214	республика Удмуртская, Ижевск, Автономная улица, 23	f	large
14554	5953	252	республика Удмуртская, Ижевск, Автономная, 81	f	medium
14518	5953	216	республика Удмуртская, Ижевск, Автономная, 81	f	large
14515	5950	213	республика Удмуртская, Ижевск, Автономная, 60	f	large
14462	5920	112	республика Удмуртская, Ижевск, Авангардная, 15	f	large
14487	5932	137	республика Удмуртская, Ижевск, 9 Января, 193а	f	large
14489	5932	139	республика Удмуртская, Ижевск, 9 Января, 193а	f	large
14488	5932	138	республика Удмуртская, Ижевск, 9 Января, 193а	f	large
14486	5931	136	республика Удмуртская, Ижевск, 9 Января, 247а	f	large
14484	5930	134	республика Удмуртская, Ижевск, 9 Января, 249	f	large
14483	5930	133	республика Удмуртская, Ижевск, 9 Января, 249	f	large
14485	5930	135	республика Удмуртская, Ижевск, 9 Января, 249	f	large
14588	5985	333	республика Удмуртская, Ижевск, 5-я Подлесная, 44	f	large
14569	5985	314	республика Удмуртская, Ижевск, 5-я Подлесная, 44	f	large
14712	6070	537	республика Удмуртская, Ижевск, 40 лет Победы, 62	f	large
14711	6070	536	республика Удмуртская, Ижевск, 40 лет Победы, 62	f	large
14708	6070	533	республика Удмуртская, Ижевск, 40 лет Победы, 62	f	large
14671	6047	453	республика Удмуртская, Ижевск, 40 лет Победы, 128	f	large
14660	6047	442	республика Удмуртская, Ижевск, 40 лет Победы, 128	f	large
14659	6047	441	республика Удмуртская, Ижевск, 40 лет Победы, 128	f	large
14658	6047	440	республика Удмуртская, Ижевск, 40 лет Победы, 128	f	large
14570	5986	315	республика Удмуртская, Ижевск, 30 лет Победы, 29	f	large
14566	5982	311	республика Удмуртская, Ижевск, 30 лет Победы, 29	f	large
14558	5976	303	республика Удмуртская, Ижевск, 30 лет Победы, 55а	f	large
14557	5976	302	республика Удмуртская, Ижевск, 30 лет Победы, 55а	f	large
14556	5976	301	республика Удмуртская, Ижевск, 30 лет Победы, 55а	f	large
14532	5962	230	республика Удмуртская, Ижевск, 15-я, 51	f	large
14460	5918	110	республика Удмуртская, Ижевск, 10 лет Октября, 55б	f	large
14514	5949	212	республика Удмуртская, Ижевск, Депутатская, 40А	f	large
14474	5926	124	республика Удмуртская, Ижевск, Воткинское шоссе, 110	f	large
14473	5926	123	республика Удмуртская, Ижевск, Воткинское шоссе, 110	f	large
14472	5926	122	республика Удмуртская, Ижевск, Воткинское шоссе, 110	f	large
15104	6426	1712	республика Удмуртская, село Завьялово, Чкалово, 34, МБОУ Завьяловская СОШ Чкалово	f	large
14813	6139	734	республика Удмуртская, Глазов, Циолковского, 2	f	large
14814	6140	735	республика Удмуртская, Глазов городской округ, Толстого, 42	f	large
14811	6137	732	республика Удмуртская, Глазов, Толстого, 45	f	large
14793	6122	714	республика Удмуртская, Глазов, Тани Барамзиной, 4	f	large
14788	6117	709	республика Удмуртская, Глазов, Советская, 29	f	large
14804	6131	725	республика Удмуртская, Глазов, Сибирская, 19	f	large
14803	6131	724	республика Удмуртская, Глазов, Сибирская, 19	f	large
14798	6126	719	республика Удмуртская, Глазов, Революции, 8	f	large
14818	6143	739	республика Удмуртская, Глазов, Пионерская, 19	f	large
14812	6138	733	республика Удмуртская, Глазов, Пехтина, 12А	f	large
14807	6134	728	республика Удмуртская, Глазов, Пехтина, 2А	f	large
14805	6132	726	республика Удмуртская, Глазов, Пехтина, 22А	f	large
14800	6128	721	республика Удмуртская, Глазов, Первомайская, 25	f	large
14790	6120	711	республика Удмуртская, Глазов, Парковая, 45	f	large
14786	6115	707	республика Удмуртская, Глазов, Парковая, 10А	f	large
14785	6114	706	республика Удмуртская, Глазов, Мира, 34	f	large
14799	6127	720	республика Удмуртская, Глазов, Луначарского, 20	f	large
14796	6124	717	республика Удмуртская, Глазов, Короленко, 5	f	large
14817	6133	738	республика Удмуртская, Глазов, Колхозная, 12	f	large
14806	6133	727	республика Удмуртская, Глазов, Колхозная, 12	f	large
14797	6125	718	республика Удмуртская, Глазов, Кирова, 13	f	large
14792	6121	713	республика Удмуртская, Глазов, Кирова, 37	f	large
14791	6121	712	республика Удмуртская, Глазов, Кирова, 37	f	large
14784	6113	705	республика Удмуртская, Глазов, Кирова, 75А	f	large
14783	6113	704	республика Удмуртская, Глазов, Кирова, 75А	f	large
14782	6112	703	республика Удмуртская, Глазов, Кирова, 75	f	large
14810	6136	731	республика Удмуртская, Глазов, Калинина, 4А	f	large
14809	6135	730	республика Удмуртская, Глазов, Калинина, 9А	f	large
14808	6135	729	республика Удмуртская, Глазов, Калинина, 9А	f	large
14802	6130	723	республика Удмуртская, Глазов, К.Маркса, 17	f	large
14801	6129	722	республика Удмуртская, Глазов, К.Маркса, 8А	f	large
14816	6142	737	республика Удмуртская, Глазов, Драгунова, 69	f	large
14815	6141	736	республика Удмуртская, Глазов, Драгунова, 74	f	small
14781	6111	702	республика Удмуртская, Глазов, Гайдара, 12	f	large
14787	6116	708	республика Удмуртская, Глазов, Белинского, 7	f	large
14780	6110	701	республика Удмуртская, Глазов, 70 лет Победы, 1	f	large
14789	6118	710	республика Удмуртская, Глазов, Пряженникова, 37А	f	large
66056	6879	3133	республика Удмуртская, Воткинск	f	medium
66053	6858	3111	республика Удмуртская, Воткинск	f	medium
14769	6102	641	республика Удмуртская, Воткинск	f	small
66005	6079	602	республика Удмуртская, Воткинск	f	large
66004	6079	601	республика Удмуртская, Воткинск	f	large
14768	95028	640	республика Удмуртская, Воткинск, Энтузиастов, 25	f	medium
14766	95028	638	республика Удмуртская, Воткинск, Энтузиастов, 25	f	large
14762	6097	634	республика Удмуртская, Воткинск, Школьная, 3	f	large
14761	6097	633	республика Удмуртская, Воткинск, Школьная, 3	f	large
14779	6109	651	республика Удмуртская, Воткинск, Тихая, 12	f	medium
14734	6081	606	республика Удмуртская, Воткинск, Серова, 14	f	large
14733	6081	605	республика Удмуртская, Воткинск, Серова, 14	f	large
14732	6080	604	республика Удмуртская, Воткинск, Серова, 25	f	large
14731	6080	603	республика Удмуртская, Воткинск, Серова, 25	f	large
14744	6088	616	республика Удмуртская, Воткинск, Свободы, 56	f	large
14738	6084	610	республика Удмуртская, Воткинск, Расковой, 1А	f	large
14737	6083	609	республика Удмуртская, Воткинск, Пугачева, 21	f	large
14760	6093	632	республика Удмуртская, Воткинск, Песчаная, 4	f	large
14759	6093	631	республика Удмуртская, Воткинск, Песчаная, 4	f	large
14752	6093	624	республика Удмуртская, Воткинск, Песчаная, 4	f	large
14751	6093	623	республика Удмуртская, Воткинск, Песчаная, 4	f	large
14742	6086	614	республика Удмуртская, Воткинск, Орджоникидзе, 15	f	large
14745	6086	617	республика Удмуртская, Воткинск, Орджоникидзе, 15	f	large
14743	6087	615	республика Удмуртская, Воткинск, Мира, 27А	f	large
14741	6082	613	республика Удмуртская, Воткинск, Мира, 19	f	large
14736	6082	608	республика Удмуртская, Воткинск, Мира, 19	f	large
14735	6082	607	республика Удмуртская, Воткинск, Мира, 19	f	large
14740	6085	612	республика Удмуртская, Воткинск, Луначарского, 6	f	large
14739	6085	611	республика Удмуртская, Воткинск, Луначарского, 6	f	large
14765	6100	637	республика Удмуртская, Воткинск, Ленинградская, 13	f	large
14746	6089	618	республика Удмуртская, Воткинск, Ленина, 40	f	large
14778	6108	650	республика Удмуртская, Воткинск, Красноармейская, 283А	f	large
14758	6096	630	республика Удмуртская, Воткинск, Королева, 15	f	large
14756	6096	628	республика Удмуртская, Воткинск, Королева, 15	f	large
14755	6095	627	республика Удмуртская, Воткинск, Королева, 15	f	large
14753	6094	625	республика Удмуртская, Воткинск, Королева, 20А	f	large
14754	6094	626	республика Удмуртская, Воткинск, Королева, 20А	f	large
14747	6090	619	республика Удмуртская, Воткинск, Кирова, 9	f	large
14775	6106	647	республика Удмуртская, Воткинск, Гагарина, 26	f	large
14776	6106	648	республика Удмуртская, Воткинск, Гагарина, 26	f	large
14774	6105	646	республика Удмуртская, Воткинск, Гагарина, 23	f	large
14773	6105	645	республика Удмуртская, Воткинск, Гагарина, 23	f	large
14767	6099	639	республика Удмуртская, Воткинск, Волгоградская, 10	f	large
14764	6099	636	республика Удмуртская, Воткинск, Волгоградская, 10	f	large
14763	6098	635	республика Удмуртская, Воткинск, Волгоградская, 1	f	large
14750	6092	622	республика Удмуртская, Воткинск, 1905 года, 17	f	large
14749	6092	621	республика Удмуртская, Воткинск, 1905 года, 17	f	large
14757	6092	629	республика Удмуртская, Воткинск, 1905 года, 17	f	large
14748	6091	620	республика Удмуртская, Воткинск, 1 Мая, 19Б	f	large
14770	6103	642	республика Удмуртская, Воткинск, 2-ой км.Чайковского тракта	f	small
15647	6952	3419	республика Удмуртская, Ярский район, поселок Яр, Ф.Васильева, 31, ГОУ СПО Ярский политехникум	f	large
15648	6953	3420	республика Удмуртская, Ярский район, поселок Яр, Советская, 52, культурно-досуговый центр Юбилейный	f	large
15649	6954	3421	республика Удмуртская, Ярский район, поселок Яр, Максима Горького, 47, Ярский участок НГЧ-4 ОАО РЖД	f	medium
15642	6947	3414	республика Удмуртская, Ярский район, село Юр, Жуйкова, 44, административное здание КФХ Касаткин Г.Н	f	small
15630	6935	3402	республика Удмуртская, Ярский район, село Юдчино, Логовая, 20, административное здание СПК Прогресс,	f	small
15638	6943	3410	республика Удмуртская, Ярский район, село Усть-Лекма, Совхозная, 1, Усть-Лекомский сельский клуб	f	small
15644	6949	3416	республика Удмуртская, Ярский район, село Укан, Школьная, 24, Уканский сельский Дом культуры	f	medium
66064	6945	3412	республика Удмуртская, Ярский район, село Тум	t	small
15645	6950	3417	республика Удмуртская, Ярский район, поселок Пудем, Кирова, 8, Дом культуры Металлург	f	medium
15646	6951	3418	республика Удмуртская, Ярский район, поселок Пудем, Гагарина, 1, МОУ Пудемская средняя общеобразовательная школа	f	medium
66065	6946	3413	республика Удмуртская, Ярский район, село Озерки, Школьная, 8, Озеркинская основная общеобразоват школа	f	small
66066	6948	3415	республика Удмуртская, Ярский район, село Никольское	f	small
15634	6939	3406	республика Удмуртская, Ярский район, село Мосеево, Сибирская, 31, Мосеевский сельский Дом культуры	f	small
66063	6942	3409	республика Удмуртская, Ярский район, село Кузьмино	f	small
15639	6944	3411	республика Удмуртская, Ярский район, село Зюино, Школьная, 77а, школа	f	small
66062	6941	3408	Россия, республика Удмуртская, Ярский район, село Елово	f	small
15635	6940	3407	республика Удмуртская, Ярский район, село Дизьмино, Чепецкая, 26, Дизьминский Центральный сельский Дом культуры	f	large
66061	6937	3404	республика Удмуртская, Ярский район, село Ворца	f	small
15633	6938	3405	республика Удмуртская, Ярский район, село Васепиево, Первомайская, 2, Васепиевский сельский клуб	f	small
15631	6936	3403	республика Удмуртская, Ярский район, село Бачумово, Школьная, 27, Бачумовский сельский Дом культуры	f	small
15629	6934	3401	республика Удмуртская, Ярский район, село Бармашур, Советская, 33	f	medium
66060	6933	3330	республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья	f	small
66058	6907	3302	республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья	f	medium
15622	6927	3324	республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья, проезд Гребенщикова, 10	f	small
15621	6926	3323	республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья, Пушиной, 135	f	large
15599	6906	3301	республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья, Пушиной, 95	f	large
15601	6908	3303	республика Удмуртская, Якшур-Бодьинский район, село Якшур-Бодья, Ленина, 33а	f	medium
15158	6471	1756	республика Удмуртская, Якшур-Бодьинский район, село Якшур, Юбилейная, 7, МБУ КК Якшурский	f	large
15602	6909	3304	республика Удмуртская, Якшур-Бодьинский район, село Якшур, Комсомольская, 7	f	medium
15627	6932	3329	республика Удмуртская, Якшур-Бодьинский район, село Чур, Коммунаров, 5а	f	medium
15611	6904	3313	республика Удмуртская, Якшур-Бодьинский район, село Чур, Коммунаров, 20а	f	medium
15606	6913	3308	республика Удмуртская, Якшур-Бодьинский район, село Сюровай, Пушкина, 13	f	small
15607	6914	3309	республика Удмуртская, Якшур-Бодьинский район, село Старые Зятцы, Площадь Свободы , 6	f	large
15626	6931	3328	республика Удмуртская, Якшур-Бодьинский район, село Старые Зятцы, Октябрьская, 10	f	small
15615	6920	3317	республика Удмуртская, Якшур-Бодьинский район, село Селычка, Школьная, 16	f	large
15616	6921	3318	республика Удмуртская, Якшур-Бодьинский район, село Пушкари, Молодёжная, 10	f	small
15605	6912	3307	республика Удмуртская, Якшур-Бодьинский район, село Порва, Молодёжная, 6	f	small
15604	6911	3306	республика Удмуртская, Якшур-Бодьинский район, село Нижний Пислеглуд, Молодежная, 24	f	small
15619	6924	3321	республика Удмуртская, Якшур-Бодьинский район, село Мукши, Советская, 9	f	medium
15612	6917	3314	республика Удмуртская, Якшур-Бодьинский район, село Малая Итча, Молодежная, 1	f	small
15614	6919	3316	республика Удмуртская, Якшур-Бодьинский район, село Люкшудья, Совхозная, 4	t	medium
15603	6910	3305	республика Удмуртская, Якшур-Бодьинский район, село Лынга, Советская, 15	t	large
15620	6925	3322	республика Удмуртская, Якшур-Бодьинский район, село Кыква, Советская, 5	t	small
15624	6929	3326	республика Удмуртская, Якшур-Бодьинский район, село Кекоран, Советская, 28а	f	small
15625	6930	3327	республика Удмуртская, Якшур-Бодьинский район, село Иж-Забегалово, Пушиной, 18б	f	small
15609	6916	3311	республика Удмуртская, Якшур-Бодьинский район, село Зеглуд, Центральная, 13	t	small
15623	6928	3325	республика Удмуртская, Якшур-Бодьинский район, село Выжоил, Ключевая, 29	t	small
15610	6893	3312	республика Удмуртская, Якшур-Бодьинский район, село Варавай, Советская, 42	f	small
15618	6923	3320	республика Удмуртская, Якшур-Бодьинский район, село Большие Ошворцы, Центральная, 13	f	small
15608	6915	3310	республика Удмуртская, Якшур-Бодьинский район, село Алгазы, Центральная, 19	t	small
66057	6884	3204	республика Удмуртская, Юкаменский район, село Юкаменское	f	medium
15578	6887	3207	республика Удмуртская, Юкаменский район, село Юкаменское, Первомайская, 78	f	medium
15576	6885	3205	республика Удмуртская, Юкаменский район, село Юкаменское, Первомайская, 56	f	medium
15575	6880	3201	республика Удмуртская, Юкаменский район, село Юкаменское, Первомайская, 4	f	medium
15579	6886	3206	республика Удмуртская, Юкаменский район, село Юкаменское, Майская, 12а	f	medium
15580	6881	3202	республика Удмуртская, Юкаменский район, село Юкаменское, Вежеевская, 37	f	small
15582	6894	3213	республика Удмуртская, Юкаменский район, село Шафеево, Центральная, 5	f	small
11736	93241	326	республика Татарстан, Казань, Сафиуллина, 56а	f	large
15588	6895	3214	республика Удмуртская, Юкаменский район, село Шамардан, Центральная, 5	f	small
15593	6899	3218	республика Удмуртская, Юкаменский район, Татарские Ключи, Новая, 1	f	small
15583	6889	3209	республика Удмуртская, Юкаменский район, село Пышкет, Советская, 12а	f	medium
15590	6898	3217	республика Удмуртская, Юкаменский район, село Починки, Средняя, 6	f	small
15594	6900	3219	республика Удмуртская, Юкаменский район, село Палагай, Центральная, 75	f	medium
15589	6896	3215	республика Удмуртская, Юкаменский район, село Новоелово, Центральная, 1	f	small
15597	6903	3222	республика Удмуртская, Юкаменский район, село Малый Вениж, Молодежная, 16	t	small
15584	6888	3208	республика Удмуртская, Юкаменский район, село Кельдыки, Центральная, 23	f	small
15581	6883	3203	республика Удмуртская, Юкаменский район, село Камки, Молодежная, 3	f	small
15586	6891	3211	республика Удмуртская, Юкаменский район, село Зянкино, Лесная, 6	f	small
15596	6901	3220	республика Удмуртская, Юкаменский район, село Засеково, Школьная, 9	f	small
15598	6902	3221	республика Удмуртская, Юкаменский район, село Жувам, Центральная, 42	f	small
15585	6890	3210	республика Удмуртская, Юкаменский район, село Ертем, Советская, 23	f	small
15592	6897	3216	республика Удмуртская, Юкаменский район, село Ежево, Школьная, 2	f	medium
15587	6892	3212	республика Удмуртская, Юкаменский район, село Верхние Уни, Молодежная, 36	f	small
15595	6905	3223	республика Удмуртская, Юкаменский район, село Бадеро, Луговая, 1а	f	small
66055	6869	3123	республика Удмуртская, Шарканский район, село Шаркан	f	small
15561	6868	3122	республика Удмуртская, Шарканский район, село Шаркан, Советская, 38, Управление Образования	f	large
15560	6867	3121	республика Удмуртская, Шарканский район, село Шаркан, Ленина, 14, администрация МО Шарканский район	f	large
15559	6866	3120	республика Удмуртская, Шарканский район, село Шаркан, Коммунальная, 1	f	large
15549	6857	3110	республика Удмуртская, Шарканский район, село Чужегово, Центральная, 15, Чужеговская НОШ	f	small
15571	6878	3132	республика Удмуртская, Шарканский район, село Титово, Азина, 2, Сельский дом культуры	f	small
15567	6874	3128	республика Удмуртская, Шарканский район, село Сюрсовай, Школьная, 10, Сюрсовайская СОШ	f	small
15566	6873	3127	республика Удмуртская, Шарканский район, село Суроново, Молодежная, 1А, сельский клуб 	f	small
15540	6847	3101	республика Удмуртская, Шарканский район, село Старые Быги, Школьная, 6, Быгинская СОШ	f	medium
15564	6871	3125	республика Удмуртская, Шарканский район, село СтароеЯгино, Колхозная, 42, ООО Труженик	f	small
15558	6865	3119	республика Удмуртская, Шарканский район, село Сосновка, Центральная, 11, администрация МО Сосновское	f	medium
66054	6860	3114	республика Удмуртская, Шарканский район, село Собино, Тамбырь, 5б, административное здание КФК Собина Н.И	f	small
15552	6848	3113	республика Удмуртская, Шарканский район, село Порозово, Центральная, 60, кафе Чингыли	f	medium
15557	6864	3118	республика Удмуртская, Шарканский район, село Пашур-Вишур, Школьная, 7, Пашур-Вишурская НОШ	f	small
15547	6855	3108	республика Удмуртская, Шарканский район, село Нижние Кивары, Садовая, 4, Ниж-Киварская СОШ	f	small
66051	6849	3102	республика Удмуртская, Шарканский район, село Нижние Быги	f	small
15565	6872	3126	республика Удмуртская, Шарканский район, село Мувыр, Молодежная, 14, Мувырская СОШ	f	medium
15551	6859	3112	республика Удмуртская, Шарканский район, село Малый Казес, Камышево, 28, Сельский клуб	f	small
15563	6870	3124	республика Удмуртская, Шарканский район, село Кыква, Центральная, 7, Кыквинская СОШ	f	medium
15569	6876	3130	республика Удмуртская, Шарканский район, село Кулак-Кучес, Центральная, 8, Кусогуртская НОШ	f	small
15554	6861	3115	республика Удмуртская, Шарканский район, село Козино, Родниковая, 4, Сельский дом культуры	f	small
15543	6851	3104	республика Удмуртская, Шарканский район, село Кельдыш, Школьный переулок, 1, Кельдышевская ООШ	f	small
15548	6856	3109	республика Удмуртская, Шарканский район, село Карсашур, Пушкинская, 3, Карсашурская ООШ	f	small
66052	6854	3107	республика Удмуртская, Шарканский район, село Зюзино	f	small
15544	6852	3105	республика Удмуртская, Шарканский район, село Зюзино, Мира, 30, Зюзинская СОШ	f	medium
15555	6862	3116	республика Удмуртская, Шарканский район, село Заречный Вишур, Поселковская, 17	f	medium
15568	6875	3129	республика Удмуртская, Шарканский район, село Вортчино, Мира, 1, администрация МО Вортчинское	f	medium
15542	6850	3103	республика Удмуртская, Шарканский район, село Бородули, Школьный переулок, 1, Бородулинская ООШ	f	small
15570	6877	3131	республика Удмуртская, Шарканский район, село Большой Билиб, Степанова, 2, Билибская НОШ	f	small
15545	6853	3106	республика Удмуртская, Шарканский район, село Байкей, Труда, 28, Фельдшерский акушерский пункт	f	small
14721	6076	546	республика Удмуртская, Устиновский район, Ижевск, Союзная, 25	f	large
14720	6076	545	республика Удмуртская, Устиновский район, Ижевск, Союзная, 25	f	large
15509	6819	3011	республика Удмуртская, Увинский район, село Чистостем, Центральная, 9	f	small
15520	6830	3022	республика Удмуртская, Увинский район, село Чекан, Нагорная, 18	f	small
15526	6836	3028	республика Удмуртская, Увинский район, село Узей-Тукля, Пислегина, 4	f	medium
15511	6821	3013	республика Удмуртская, Увинский район, село Ува-Тукля, Добровольского, 16	f	medium
66050	6843	3041	республика Удмуртская, Увинский район, поселок Ува	f	large
66049	6843	3037	республика Удмуртская, Увинский район, поселок Ува	f	small
66046	6835	3027	республика Удмуртская, Увинский район, поселок Ува	t	small
66045	6828	3020	республика Удмуртская, Увинский район, поселок Ува	f	large
15538	6846	3040	республика Удмуртская, Увинский район, поселок Ува, Энгельса, 3	f	large
15528	6838	3030	республика Удмуртская, Увинский район, поселок Ува, Селтинская, 1	f	large
15537	6845	3039	республика Удмуртская, Увинский район, поселок Ува, Курчатова, 16	f	medium
15532	6841	3034	республика Удмуртская, Увинский район, поселок Ува, Курортная, 13	f	small
15536	6844	3038	республика Удмуртская, Увинский район, поселок Ува, Калинина, 13	f	large
15534	6842	3036	республика Удмуртская, Увинский район, поселок Ува, Калинина, 21	f	large
15533	6842	3035	республика Удмуртская, Увинский район, поселок Ува, Калинина, 21	f	medium
15529	6839	3031	республика Удмуртская, Увинский район, поселок Ува, Заводская, 1	f	large
15513	6823	3015	республика Удмуртская, Увинский район, село Сюровай, Удмуртская, 24	f	small
15512	6822	3014	республика Удмуртская, Увинский район, село Рябово, Советская, 4	f	medium
15524	95078	3025	республика Удмуртская, Увинский район, село Пужмесь-Тукля, Школьная, 19	t	small
15514	6824	3016	республика Удмуртская, Увинский район, село Поршур-Тукля, Пислегина, 22	f	medium
15502	6812	3004	республика Удмуртская, Увинский район, село Петропавлово, Садовая, 14А	f	small
15517	6827	3019	республика Удмуртская, Увинский район, село Пачегурт, Труда, 2б	t	small
15523	95079	3026	республика Удмуртская, Увинский район, село Областная, Линейная, 22Б	t	small
15505	6815	3007	республика Удмуртская, Увинский район, село Нылга, Садовая, 14	f	medium
15506	6816	3008	республика Удмуртская, Увинский район, село Нылга, Переулок Школьный, 2	f	large
15516	6826	3018	республика Удмуртская, Увинский район, село Новый Мултан, Советская, 1а	f	medium
15522	6832	3024	республика Удмуртская, Увинский район, село Мушковай, Школьная, 35	f	small
15515	95077	3017	республика Удмуртская, Увинский район, село Можга, Школьная, 12, сельский дом культуры	f	small
15519	6829	3021	республика Удмуртская, Увинский район, село Малые Сюрзи, Центральная, 2	t	small
15503	6813	3005	республика Удмуртская, Увинский район, село Лоллез-Жикья, Зеленая, 5а	t	small
15507	6817	3009	республика Удмуртская, Увинский район, село Кыйлуд, Школьная, 5	f	medium
15501	6811	3003	республика Удмуртская, Увинский район, село Кулябино, Школьная, 1	f	small
15504	95076	3006	республика Удмуртская, Увинский район, село Красное, Советская, 2	f	medium
15510	6820	3012	республика Удмуртская, Увинский район, село Киби-Жикья, Школьная, 7	t	small
15521	6831	3023	республика Удмуртская, Увинский район, село Каркалай, Азина, 4	t	medium
15527	95080	3029	республика Удмуртская, Увинский район, село Возеншур, Клубная, 2	t	small
15508	6818	3010	республика Удмуртская, Увинский район, село Вишур, Советская, 38	f	small
15499	6445	3001	республика Удмуртская, Увинский район, село Булай, Ленина, 11	f	large
15500	6810	3002	республика Удмуртская, Увинский район, село Большой Жужгес, Клубная, 25	f	medium
15498	95074	2915	республика Удмуртская, Сюмсинский район, поселок Сюрек, Первомайская, 4	t	small
66042	6791	2906	республика Удмуртская, Сюмсинский район, село Сюмси	f	small
66032	6790	2905	республика Удмуртская, Сюмсинский район, село Сюмси	f	medium
15474	6788	2903	республика Удмуртская, Сюмсинский район, село Сюмси, Советская, 56	f	medium
15473	6787	2902	республика Удмуртская, Сюмсинский район, село Сюмси, Партизанская, 4	f	large
15472	6786	2901	республика Удмуртская, Сюмсинский район, село Сюмси, Партизанская, 54	f	medium
15475	6789	2904	республика Удмуртская, Сюмсинский район, село Сюмси, Лесная, 23	f	medium
66041	6795	2910	республика Удмуртская, Сюмсинский район, село Правые Гайны, 427374	f	small
66038	6799	2914	республика Удмуртская, Сюмсинский район, поселок Пижил	f	small
15491	6802	2917	республика Удмуртская, Сюмсинский район, село Орловское, пер. Торфяной, 2а	f	medium
15497	6801	2916	республика Удмуртская, Сюмсинский район, село Муки-Какси, Колхозная, 2а	f	small
15477	6792	2907	республика Удмуртская, Сюмсинский район, село Маркелово, Маркеловская, 1	f	small
66040	6796	2911	республика Удмуртская, Сюмсинский район, село Лялино	f	medium
15482	95075	2921	республика Удмуртская, Сюмсинский район, село Лесоучасток Ключевка, Первомайская, 11	f	small
15478	6793	2908	республика Удмуртская, Сюмсинский район, село Лекшур, Лекшурская, 24	f	small
15495	6808	2924	республика Удмуртская, Сюмсинский район, поселок Кильмезь, Пушкинская, 7	f	large
15492	6803	2918	республика Удмуртская, Сюмсинский район, село Зон, Школьная, 31а	f	small
66033	6794	2909	республика Удмуртская, Сюмсинский район, село Гуртруд	f	small
66035	6805	2920	республика Удмуртская, Сюмсинский район, село Гура	f	small
66034	6804	2919	республика Удмуртская, Сюмсинский район, село Гура	f	small
66037	6797	2912	республика Удмуртская, Сюмсинский район, село Васькино	f	small
15485	6798	2913	республика Удмуртская, Сюмсинский район, село Блаж-Юс, Центральная, 22	t	small
15494	6809	2925	республика Удмуртская, Сюмсинский район, село Балма, Балминская, 57	f	small
15466	6783	2814	республика Удмуртская, Селтинский район, село Юмга-Омга, Родниковая, 1	f	small
15457	6774	2805	республика Удмуртская, Селтинский район, село Югдон, Молодежная, 3А	f	small
15455	6772	2803	республика Удмуртская, Селтинский район, село Халды, Советская, 6	f	medium
15458	6775	2806	республика Удмуртская, Селтинский район, Уть-Сюмси, Школьная улица, 13	f	small
15465	6782	2813	республика Удмуртская, Селтинский район, село Узи, Советская, 29	f	small
15461	95072	2809	республика Удмуртская, Селтинский район, село Сюромошур, Пушкинская, 2	f	small
15284	6597	2210	республика Удмуртская, Селтинский район, село Старые Копки, Молодежная, 6	f	medium
15462	6779	2810	республика Удмуртская, Селтинский район, село Селты, Юбилейная, 1	f	large
15463	6780	2811	республика Удмуртская, Селтинский район, село Селты, Ленина, 30	f	large
66030	6784	2815	республика Удмуртская, Селтинский район, село Рожки, 427277	f	small
15459	6776	2807	республика Удмуртская, Селтинский район, село Новая Монья, пер.Субботина, 6	f	medium
15471	95073	2816	республика Удмуртская, Селтинский район, село Мадьярово, Молодежная, 2	f	small
15456	6773	2804	республика Удмуртская, Селтинский район, село Копки, Школьная, 7	f	medium
15454	6771	2802	республика Удмуртская, Селтинский район, село Колесур, Карачева, 1	f	medium
15460	6777	2808	республика Удмуртская, Селтинский район, село Гобгурт, 70 лет Октября, 26	f	small
15453	6770	2801	республика Удмуртская, Селтинский район, село Валамаз, пер. Молодежный, 1	f	small
66043	6807	2922	республика Удмуртская, Селтинский район, село Большой Кильмезь-Бия	f	medium
66044	6807	2923	республика Удмуртская, Селтинский район, село Большой Кильмезь-Бия	f	medium
15464	6781	2812	республика Удмуртская, Селтинский район, село Большой Кильмезь-Бия, Азина, 27	f	small
15425	6743	2702	республика Удмуртская, Сарапульский район, село Юриха, Комсомольская, 4	f	small
15437	6756	2716	республика Удмуртская, Сарапульский район, село Юрино, Советская, 1	f	small
15433	6750	2710	республика Удмуртская, Сарапульский район, село Шевырялово, Первомайская, 54	f	medium
15439	6758	2718	республика Удмуртская, Сарапульский район, село Шадрино, Школьная, 9	f	medium
15447	6765	2724	республика Удмуртская, Сарапульский район, село Усть-Сарапулка, Вечтомова, 60	f	medium
15432	6593	2709	республика Удмуртская, Сарапульский район, село Уральский, Соскова, 2	f	small
15431	6495	2708	республика Удмуртская, Сарапульский район, село Уральский, Соскова, 2	f	large
15443	6762	2722	республика Удмуртская, Сарапульский район, село Тарасово, Школьная, 2	f	medium
15444	6764	2723	республика Удмуртская, Сарапульский район, село Соколовка, Школьная, 12	f	medium
66028	95071	2728	республика Удмуртская, Сарапульский район, село Сигаево, Советская, 109	f	large
15449	6767	2726	республика Удмуртская, Сарапульский район, село Сигаево, Советская, 58	f	large
15451	6766	2729	республика Удмуртская, Сарапульский район, село Сигаево, Лермонтова, 32	f	large
15448	6766	2725	республика Удмуртская, Сарапульский район, село Сигаево, Лермонтова, 32	f	large
15438	6757	2717	республика Удмуртская, Сарапульский район, село Пентеги, Молодежная, 2	f	small
15441	6760	2720	республика Удмуртская, Сарапульский район, село Оленье Болото, Сиреневая, 2а	f	small
15424	6742	2701	республика Удмуртская, Сарапульский район, село Нечкино, Юбилейная, 1	f	medium
15440	6759	2719	республика Удмуртская, Сарапульский район, село Мостовое, Платова, 1б	f	medium
15445	6761	2721	республика Удмуртская, Сарапульский район, село Мазунино, Ленина, 45	f	medium
15426	6744	2703	республика Удмуртская, Сарапульский район, село Лагуново, Школьная, 1	f	small
15450	6768	2727	республика Удмуртская, Сарапульский район, село Костино, Полевая, 1а	f	small
66029	6754	2714	республика Удмуртская, Сарапульский район, село Кигбаево, Совхозная, 1а	f	medium
15435	6753	2713	республика Удмуртская, Сарапульский район, село Кигбаево, Совхозная, 1а	f	large
15427	6745	2704	республика Удмуртская, Сарапульский район, село Дулесово, Школьная, 18	f	medium
15429	6747	2706	республика Удмуртская, Сарапульский район, село Девятово, переулок Школьный, 1	f	small
15436	6755	2715	республика Удмуртская, Сарапульский район, село Выезд, Центральная, 25	f	small
15428	6746	2705	республика Удмуртская, Сарапул городской округ, поселок Яромаска, Мира, 1б	f	small
15452	6752	2712	республика Удмуртская, Сарапул городской округ, село Северный, Октябрьская, 6а	f	large
15434	6751	2711	республика Удмуртская, Сарапул городской округ, село Северный, Октябрьская, 6А	f	small
14576	5989	321	республика Удмуртская, Октябрьский район, Ижевск, Максима Горького, 160	f	large
14575	5989	320	республика Удмуртская, Октябрьский район, Ижевск, Максима Горького, 160	f	large
15414	6732	2626	республика Удмуртская, Можгинский район, д.Залесный, з-д Полевой, 2, Контора ООО Зверохозяйство Можгинское	f	small
15398	6714	2608	республика Удмуртская, Можгинский район, село Черемушки, Заводская, 1, Черемушкинский центральный дом культуры	f	large
15405	6722	2616	республика Удмуртская, Можгинский район, село Трактор, Удмуртская, 13, Тракторский сельский дом культуры	f	small
15401	6719	2613	республика Удмуртская, Можгинский район, село Старый Березняк, Молодежная, 1б, Ст-Березнякский сельский дом культуры	f	small
15406	6723	2617	республика Удмуртская, Можгинский район, село Старые Юбери, Юберинская, 1, школа	f	small
15408	6725	2619	республика Удмуртская, Можгинский район, село Старые Какси, Даниила Яшина, 1А, Ст-Каксинский центральный дом культуры	f	medium
15416	6734	2628	республика Удмуртская, Можгинский район, село Сардан, з-д Больничный, 2, Сарданский сельский клуб	f	small
15390	6708	2602	республика Удмуртская, Можгинский район, село Русский Пычас, Центральная, 4, Русскопычасский сельский дом культуры	f	small
15393	6710	2604	республика Удмуртская, Можгинский район, поселок Пычас, Садовая, 14, Пычасский центральный сельский дом культуры	f	large
15392	6709	2603	республика Удмуртская, Можгинский район, поселок Пычас, Переездная, 3, Контора торфопредприятия Можгинское	f	large
15411	6728	2622	республика Удмуртская, Можгинский район, село Поршур, Почтовая, 25, Поршурский сельский дом культуры	t	small
15421	6739	2632	республика Удмуртская, Можгинский район, село Пазял, Парковая, 27а, Пазяльский центральный сельский дом культуры	f	medium
66001	6703	2541	республика Удмуртская, Малопургинский район, село Нижние Юри, Кировская, 15	t	medium
15412	6727	2621	республика Удмуртская, Можгинский район, село Ныша, Молодежная, 21, Нышинский центральный сельский дом культуры	f	medium
15409	6726	2620	республика Удмуртская, Можгинский район, село Нынек, Центральная площадь, 6, Нынекская школа	f	medium
66027	6733	2627	республика Удмуртская, Можгинский район, село Новый Русский Сюгаил, Ленина, 37	f	small
15415	6731	2625	республика Удмуртская, Можгинский район, село Новый Русский Сюгаил, Ленина, 37, Русско-Сюгаильская средняя школа	f	medium
15394	6711	2605	республика Удмуртская, Можгинский район, село Новая Бия, Советская, 12, Административное здание ООО Новобиинское	f	small
15403	6720	2614	республика Удмуртская, Можгинский район, село Нижний Вишур, Школьная, 4	f	small
15404	6721	2615	республика Удмуртская, Можгинский район, село Можга, Микрорайон, 7, Можгинская средняя школа	f	medium
15391	6707	2601	республика Удмуртская, Можгинский район, село Мельниково, Нагорная, 10, Мельниковский сельский дом культуры	f	small
15419	6737	2630	республика Удмуртская, Можгинский район, село Малая Сюга, Дубовская, 4, М-Сюгинский центральный сельский дом культуры	f	medium
15420	6738	2631	республика Удмуртская, Можгинский район, село Малая Воложикья, Центральная площадь, 5, сельский дом культуры	f	medium
15413	6730	2624	республика Удмуртская, Можгинский район, поселок Люга, Заводская, 22, Люгинский сельский дом культуры	f	medium
15423	6741	2634	республика Удмуртская, Можгинский район, село Ломеслуд, Клубная, 1, сельский дом культуры	f	small
15410	6729	2623	республика Удмуртская, Можгинский район, село Комяк, Советская, 64а, Комякский клуб	f	small
15397	6715	2609	республика Удмуртская, Можгинский район, село Керамик, Кирпичная , 18	t	small
15402	6718	2612	республика Удмуртская, Можгинский район, село Кватчи, Центральная площадь, 2, Кватчинский центральный дом культуры	f	medium
15396	6701	2606	республика Удмуртская, Можгинский район, село Горняк, Коммунальная, 7, Горнякский сельский дом культуры	f	medium
15400	6717	2611	республика Удмуртская, Можгинский район, село Верхние Юри, Юбилейная, 11, В-Юринский центральный сельский дом культуры	f	medium
15407	6724	2618	республика Удмуртская, Можгинский район, село Большие Сибы, Центральная, 3, Б-Сибинский центральный дом культуры	f	medium
15422	6740	2633	республика Удмуртская, Можгинский район, село Большая Уча, Садовая, 22, Б-Учинский центральный сельский дом культуры	f	large
15417	6735	2629	республика Удмуртская, Можгинский район, село Большая Пудга, Центральная, 50, Б-Пудгинский сельский дом культуры	f	small
15399	6716	2610	республика Удмуртская, Можгинский район, село Большая Кибья, Советская, 52, Б-Кибьинский центральный сельский дом культуры	f	large
15395	6713	2607	республика Удмуртская, Можгинский район, село Бальзяшур, Труда, 21	t	small
15365	6680	2520	республика Удмуртская, Малопургинский район, село Яган-Докья, Садовая, 1	f	large
15357	6672	2512	республика Удмуртская, Малопургинский район, село Яган, Первомайская, 4	t	large
15372	6687	2527	республика Удмуртская, Малопургинский район, село Уром, Молодежная, 1а	f	medium
15384	6700	2539	республика Удмуртская, Малопургинский район, село Сырьезшур, Школьная, 10	f	small
15362	6677	2517	республика Удмуртская, Малопургинский район, село Сундуково, Колхозная, 6	f	small
66002	6705	2543	республика Удмуртская, Малопургинский район, село Старая Монья, Октябрьская, 21а	f	large
15358	6673	2513	республика Удмуртская, Малопургинский район, село Среднее Кечево, Советская, 55	f	medium
15377	6693	2532	республика Удмуртская, Малопургинский район, село Сизяшур, Трактовая, 7	f	small
15367	6682	2522	республика Удмуртская, Малопургинский район, село Пуро-Можга, Мельничная, 30	t	small
15356	95069	2511	республика Удмуртская, Малопургинский район, поселок Пугачево, Ленина, 50	f	large
15355	95069	2510	республика Удмуртская, Малопургинский район, поселок Пугачево, Ленина, 50	f	medium
15378	6694	2533	республика Удмуртская, Малопургинский район, село Норья, Школьная, 1	f	medium
15387	6704	2542	республика Удмуртская, Малопургинский район, село Новая Монья, Школьная, 1	t	small
66000	6702	2540	республика Удмуртская, Малопургинский район, село Нижние Юри	t	small
14195	1405	2792	республика Татарстан, Чистополь, Энгельса, 78	f	large
65998	95068	2509	республика Удмуртская, Малопургинский район, село Миндерево, Полевая, 2	f	small
15353	95067	2508	республика Удмуртская, Малопургинский район, село Миндерево, Полевая, 2	f	medium
65997	6662	2503	республика Удмуртская, Малопургинский район, село Малая Пурга	f	large
65996	6661	2502	республика Удмуртская, Малопургинский район, село Малая Пурга	f	large
15349	6663	2504	республика Удмуртская, Малопургинский район, село Малая Пурга, Школьная, 1	f	large
15350	6664	2505	республика Удмуртская, Малопургинский район, село Малая Пурга, Советская, 62	f	large
15352	6666	2507	республика Удмуртская, Малопургинский район, село Малая Бодья, Школьная, 8	f	small
15346	6660	2501	республика Удмуртская, Малопургинский район, село Курчум-Норья, Нарядная, 19	f	small
15369	6684	2524	республика Удмуртская, Малопургинский район, село Курегово, Школьная, 5	f	small
15379	6695	2534	республика Удмуртская, Малопургинский район, село Кулаево, Школьная, 8	t	small
15351	6665	2506	республика Удмуртская, Малопургинский район, село Кечур, Школьная, 9	f	small
15360	6675	2515	республика Удмуртская, Малопургинский район, село Кечево, Клубная, 3	t	small
15373	6688	2528	республика Удмуртская, Малопургинский район, село Карашур, Центральная, 31	t	small
15380	6696	2535	республика Удмуртская, Малопургинский район, село Капустино, Садовая, 11	f	small
15389	6706	2544	республика Удмуртская, Малопургинский район, село Итешево, Центральная, 9а	t	small
15375	6691	2530	республика Удмуртская, Малопургинский район, село Ильинское, Советская, 33	f	large
15381	6697	2536	республика Удмуртская, Малопургинский район, село Иваново-Самарское, Центральная, 7	f	small
65999	6698	2537	республика Удмуртская, Малопургинский район, село Гужношур, Центральная, 21	f	small
15370	6685	2525	республика Удмуртская, Малопургинский район, село Гожня, Молодежная, 1а	f	medium
15361	6676	2516	республика Удмуртская, Малопургинский район, село Верхнее Кечево, Пионерская, 40	f	small
15359	6674	2514	республика Удмуртская, Малопургинский район, село Валион, Школьная, 11	t	small
15366	6681	2521	республика Удмуртская, Малопургинский район, село Бураново, Школьная, 3а	f	medium
15383	6699	2538	республика Удмуртская, Малопургинский район, село Бобья-Уча, Азина, 27	f	medium
15364	6679	2519	республика Удмуртская, Малопургинский район, село Байситово, Советская, 9	f	small
15374	6689	2529	республика Удмуртская, Малопургинский район, село Бажаново, Школьная, 8	f	small
15371	6686	2526	республика Удмуртская, Малопургинский район, село Алганча-Игра, Заречная, 27а	t	small
15363	6678	2518	республика Удмуртская, Малопургинский район, село Аксакшур, Колхозная, 20	t	medium
15368	6683	2523	республика Удмуртская, Малопургинский район, село Агрыз-Бигра, Трактовая, 23	f	medium
15376	95070	2531	республика Удмуртская, Малопургинский район, село Абдэс-Урдэс, Октябрьская, 8	f	small
14535	5965	233	республика Удмуртская, Ленинский район, Ижевск, Городок Машиностроителей, 109	f	large
14544	5972	242	республика Удмуртская, Ленинский район, Ижевск, Баранова, 76	f	medium
15342	6655	2414	республика Удмуртская, Красногорский район, село Мухино, Черниговская, 7	f	small
15341	6654	2413	республика Удмуртская, Красногорский район, село Малягурт, Центральная, 2	f	small
15340	6653	2412	республика Удмуртская, Красногорский район, село Курья, Советская, 54	f	medium
15339	6652	2411	республика Удмуртская, Красногорский район, село Красногорское, Ленина, 68	f	medium
15343	6650	2415	республика Удмуртская, Красногорский район, село Красногорское, Ленина, 50	f	medium
15337	6650	2409	республика Удмуртская, Красногорский район, село Красногорское, Ленина, 50	f	large
15329	6641	2401	республика Удмуртская, Красногорский район, село Красногорское, Ленина, 57	f	medium
66031	6659	2418	республика Удмуртская, Красногорский район, село Красногорское, Глазовская, 1а	f	small
15345	6658	2417	республика Удмуртская, Красногорский район, село Красногорское, Глазовская, 1а	f	large
15338	95066	2410	республика Удмуртская, Красногорский район, село Кокман, Центральная, 2	t	small
15336	6649	2408	республика Удмуртская, Красногорский район, село Дебы, Школьная, 30	f	medium
14192	1402	2789	республика Татарстан, Чистополь, Энгельса, 14а	f	medium
15335	6648	2407	республика Удмуртская, Красногорский район, село Васильевское, Школьная, 3	f	small
15334	6647	2406	республика Удмуртская, Красногорский район, поселок Валамаз, Карла Маркса, 8	f	medium
15344	6657	2416	республика Удмуртская, Красногорский район, село Большой Селег, Советская, 6	f	small
15333	6646	2405	республика Удмуртская, Красногорский район, село Бараны, Советская, 6а	f	small
15332	95065	2404	республика Удмуртская, Красногорский район, село Багыр, Мира, 1	f	small
15331	6644	2403	республика Удмуртская, Красногорский район, село Архангельское, Новая, 4	f	small
15330	6643	2402	республика Удмуртская, Красногорский район, село Артык, Ключевая, 34	t	small
15314	6626	2307	республика Удмуртская, Киясовский район, село Яжбахтино, Клубная, 1а, Яжбахтинский сельский Дом культуры	f	small
15319	6631	2312	республика Удмуртская, Киясовский район, село Чувашайка, Советская, 35, Дом культуры	f	small
15323	6635	2316	республика Удмуртская, Киясовский район, село Тавзямал, Нагорная, 32а	f	small
15325	6637	2318	республика Удмуртская, Киясовский район, село Старая Салья, Чистопольская, 45, Старосальинская средняя школа	f	medium
15309	6622	2303	республика Удмуртская, Киясовский район, село Подгорное, Школьная, 6в, Подгорновская средняя общеобразовательная школа	f	medium
15312	6624	2305	республика Удмуртская, Киясовский район, село Первомайский, Октябрьская, 5, Первомайская средняя школа	f	medium
15327	6639	2320	республика Удмуртская, Киясовский район, село Нижняя Малая Салья, Советская, 13, Нижнемалосальинский сельский Дом культуры	f	small
15322	6634	2315	республика Удмуртская, Киясовский район, село Мушак, Школьная, 9, Мушаковская средняя общеобразовательная школа	f	small
15315	6627	2308	республика Удмуртская, Киясовский район, село Лутоха, Советская, 28, Дом культуры	f	small
15310	95064	2301	республика Удмуртская, Киясовский район, село Киясово, Советская, 3	f	small
15308	6621	2302	республика Удмуртская, Киясовский район, село Киясово, Советская, 1, Межпоселенческий дом культуры	f	large
15320	6632	2313	республика Удмуртская, Киясовский район, село Карамас-Пельга, Гагарина, 17а, Карамас-Пельгинская средняя школа	f	medium
15316	6628	2309	республика Удмуртская, Киясовский район, село Калашур, Советская, 1, школа	f	small
15328	6640	2321	республика Удмуртская, Киясовский район, село Кады-Салья, Восточная, 35, Дом культуры	f	small
15318	6630	2311	республика Удмуртская, Киясовский район, село Ильдибаево, Суворова , 28, Ильдибаевская средняя общеобразовательная школа	f	small
15324	6636	2317	республика Удмуртская, Киясовский район, село Ермолаево, Школьная, 6, Ермолаевская средняя общеобразовательная школа	f	small
15317	6629	2310	республика Удмуртская, Киясовский район, село Дубровский, Центральная, 12, Дубровский сельский Дом культуры	f	small
15326	6638	2319	республика Удмуртская, Киясовский район, село Верхняя Малая Салья, Новая, 1, ДК	f	small
15321	6633	2314	республика Удмуртская, Киясовский район, село Байсары, Советская, 24 а, Байсарский сельский Дом культуры	f	small
15311	6623	2304	республика Удмуртская, Киясовский район, село Атабаево, Советская, 51, Атабаевская средняя общеобразовательная школа	f	small
15313	6625	2306	республика Удмуртская, Киясовский район, село Аксарино, Юбилейная, 32, Аксаринский сельский Дом культуры	f	small
15299	95062	2220	республика Удмуртская, Кизнерский район, поселок Ягул, Центральная, 11	f	medium
15280	6592	2206	республика Удмуртская, Кизнерский район, село Удмуртский Сарамак, Нагорная, 3	f	small
15275	6587	2201	республика Удмуртская, Кизнерский район, село Старый Кармыж, Школьная, 8	f	medium
15283	6596	2209	республика Удмуртская, Кизнерский район, село Старый Аргабаш, Центральная, 12	t	small
15291	6603	2216	республика Удмуртская, Кизнерский район, село Старая Бодья, Аллейная, 9	f	medium
15298	6611	2223	республика Удмуртская, Кизнерский район, село Синяр-Бодья, Нижняя, 32	f	small
15288	95060	2214	республика Удмуртская, Кизнерский район, село Саркуз, Молодежная, 10	f	small
15286	6599	2212	республика Удмуртская, Кизнерский район, село Русская Коса, Школьная, 1	f	small
15287	6600	2213	республика Удмуртская, Кизнерский район, село Муркозь-Омга, Верхняя, 30	f	small
11696	93224	286	республика Татарстан, Казань, Роторная, 7	f	large
15282	95059	2207	республика Удмуртская, Кизнерский район, село Крымская Слудка, Школьная, 1	f	small
15289	95061	2215	республика Удмуртская, Кизнерский район, село Короленко, Короленко, 3	f	small
15297	6610	2222	республика Удмуртская, Кизнерский район, село Кизнер, Шумиловка, 1б	f	small
15306	6609	2221	республика Удмуртская, Кизнерский район, село Кизнер, Механизаторов, 6	f	large
15305	6616	2228	республика Удмуртская, Кизнерский район, поселок Кизнер, Школьная, 1	f	large
15290	6613	2225	республика Удмуртская, Кизнерский район, поселок Кизнер, Школьная, 1	f	large
15302	6618	2231	республика Удмуртская, Кизнерский район, поселок Кизнер, Савина, 3	f	large
15300	6618	2230	республика Удмуртская, Кизнерский район, поселок Кизнер, Савина, 3	f	medium
15295	6619	2232	республика Удмуртская, Кизнерский район, поселок Кизнер, Первомайская, 117	f	large
65995	6615	2227	республика Удмуртская, Кизнерский район, поселок Кизнер, Карла Маркса, 25	f	medium
15304	6612	2224	республика Удмуртская, Кизнерский район, поселок Кизнер, Карла Маркса, 22а	f	large
15303	6614	2226	республика Удмуртская, Кизнерский район, поселок Кизнер, Гоголя, 4	f	medium
15301	95063	2229	республика Удмуртская, Кизнерский район, поселок Кизнер, Вокзальная, 4	f	medium
15293	6605	2218	республика Удмуртская, Кизнерский район, село Кибья, Школьная, 9	f	small
15285	6598	2211	республика Удмуртская, Кизнерский район, село Гыбдан, Центральная, 33	f	small
15292	6604	2217	республика Удмуртская, Кизнерский район, село Вичурка, Школьная, 1	f	small
15277	6589	2203	республика Удмуртская, Кизнерский район, село Верхняя Тыжма, Шанхайская, 14	f	small
15276	6588	2202	республика Удмуртская, Кизнерский район, село Верхний Бемыж, Молодежная, 3	f	small
15279	6591	2205	республика Удмуртская, Кизнерский район, село Бемыж, Коммунальная, 4	f	medium
15294	6606	2219	республика Удмуртская, Кизнерский район, село Безменшур, Полевая, 5	f	small
15296	6595	2208	республика Удмуртская, Кизнерский район, село Балдейка, Центральная, 23	f	small
15278	6590	2204	республика Удмуртская, Кизнерский район, село Айдуан-Чабья, Молодежная, 9	t	small
15247	6557	2110	республика Удмуртская, Кезский район, село Юски, Школьная, 20	f	small
15262	6574	2126	республика Удмуртская, Кезский район, село Юрук, сельский клуб	f	small
15245	6555	2108	республика Удмуртская, Кезский район, село Ю-Чабья, Ю-Чабьинская, 26	t	small
15244	6554	2107	республика Удмуртская, Кезский район, село Ю-Тольен, Центральная, 2	f	small
15028	6346	1402	республика Удмуртская, Кезский район, село Чепца, ООО Санаторий-профилакторий Чепца	f	medium
15258	6572	2124	республика Удмуртская, Кезский район, село Чепца, Школьная, 6а	f	medium
15259	6573	2125	республика Удмуртская, Кезский район, село Чепца, Пионерская, 35	f	medium
15246	6556	2109	республика Удмуртская, Кезский район, село Филинцы, Рабочая, 18, кв.1	f	small
15252	6563	2115	республика Удмуртская, Кезский район, село Удмурт-Зязьгор, Школьная, 25	f	small
15251	6562	2114	республика Удмуртская, Кезский район, село Тортым, переулок Церковный, 1, кв. 3	f	small
15239	6550	2102	республика Удмуртская, Кезский район, село Тимены, Советская, 2а	t	small
15267	95056	2119	республика Удмуртская, Кезский район, село Сыга 2, Новая, 1	f	small
15238	6549	2101	республика Удмуртская, Кезский район, село Степаненки, Советская, 17	f	small
15266	6566	2118	республика Удмуртская, Кезский район, село Стеньгурт, Садовая, 1	f	small
15255	95057	2120	республика Удмуртская, Кезский район, село Старая Гыя, Центральная, 37	f	small
15264	6579	2131	республика Удмуртская, Кезский район, село Пужмезь, Комсомольская, 1А	f	small
15261	6577	2129	республика Удмуртская, Кезский район, село Поломское, Школьная, 19	f	small
15260	6576	2128	республика Удмуртская, Кезский район, село Полом, Центральная, 57	f	small
15265	6578	2130	республика Удмуртская, Кезский район, село Пажман, Трактовая, 8	f	small
15242	6552	2105	республика Удмуртская, Кезский район, село Мысы, Центральная, 20	t	small
15253	6564	2116	республика Удмуртская, Кезский район, село Липовка, Центральная, 25, кв.2	f	small
15241	95054	2104	республика Удмуртская, Кезский район, село Кулига, Советская, 45	f	small
15240	95053	2103	республика Удмуртская, Кезский район, село Кулига, Советская, 45	f	medium
11751	93247	341	республика Татарстан, Казань, Мира, 2А	f	large
15248	6558	2111	республика Удмуртская, Кезский район, поселок Кузьма, Кооперативная, 23	f	medium
15243	6553	2106	республика Удмуртская, Кезский район, село Ключи, Набережная, 23а	f	small
15269	6583	2135	республика Удмуртская, Кезский район, поселок Кез, Тургенева, 2а	f	large
15272	6581	2133	республика Удмуртская, Кезский район, поселок Кез, Некрасова, 12	f	large
15274	6586	2138	республика Удмуртская, Кезский район, поселок Кез, Мира, 31	f	large
15273	95058	2137	республика Удмуртская, Кезский район, поселок Кез, Малокезская, 13	f	large
15268	6580	2132	республика Удмуртская, Кезский район, поселок Кез, Ленина, 44	f	large
15271	6582	2134	республика Удмуртская, Кезский район, поселок Кез, Клубничная, 2	f	large
65994	6565	2117	республика Удмуртская, Кезский район, поселок Кез, Ангарская	f	small
15270	6584	2136	республика Удмуртская, Кезский район, поселок Кез, 1-я Лесная, 5	f	large
65993	6561	2113	республика Удмуртская, Кезский район, село Кабалуд, Комсомольская, 2	f	small
65992	95055	2112	республика Удмуртская, Кезский район, село Желтопи, Цветочная, 1	f	small
65991	6570	2122	республика Удмуртская, Кезский район, село Дырпа, Родниковая, 36	f	small
15263	6575	2127	республика Удмуртская, Кезский район, село Вортча, Новая, 1	f	small
15256	6569	2121	республика Удмуртская, Кезский район, село Большой Олып, Клубный переулок, 2	f	medium
15257	6571	2123	республика Удмуртская, Кезский район, село Александрово, Школьная, 24	f	small
15222	6545	2014	республика Удмуртская, Каракулинский район, село Чеганда, Моргунова, 18	f	medium
15225	6544	2013	республика Удмуртская, Каракулинский район, село Усть-Сакла, В. Исенкова , 8	f	small
15227	6532	2002	республика Удмуртская, Каракулинский район, село Пинязь, Центральная, 85	f	small
15220	6548	2017	республика Удмуртская, Каракулинский район, село Ныргында, Князева, 1	f	medium
15229	6535	2004	республика Удмуртская, Каракулинский район, село Малые Калмаши, Садовая, 10	f	small
15224	6543	2012	республика Удмуртская, Каракулинский район, село Кулюшево, Школьная, 9-а	f	small
15228	6533	2003	республика Удмуртская, Каракулинский район, село Котово, Мира, 38	f	small
15223	6546	2015	республика Удмуртская, Каракулинский район, село Колесниково, Комсомольская, 4	f	small
15235	6542	2011	республика Удмуртская, Каракулинский район, село Каракулино, Раскольникова, 12	f	medium
15234	6541	2010	республика Удмуртская, Каракулинский район, село Каракулино, Кирьянова, 12	f	medium
15236	6540	2009	республика Удмуртская, Каракулинский район, село Каракулино, Каманина, 12	f	medium
15233	6539	2008	республика Удмуртская, Каракулинский район, село Каракулино, Девятьярова, 1	f	medium
15230	6536	2005	республика Удмуртская, Каракулинский район, село Галаново, Камская, 4	f	small
15232	6537	2006	республика Удмуртская, Каракулинский район, село Вятское, Школьная, 7	f	small
15221	6547	2016	республика Удмуртская, Каракулинский район, село Быргында, 8-е Марта, 8	f	small
15231	6538	2007	республика Удмуртская, Каракулинский район, село Боярка, Новая, 5	f	medium
15226	6531	2001	республика Удмуртская, Каракулинский район, село Арзамасцево, Ленина, 2	f	medium
15215	6527	1916	республика Удмуртская, Камбарский район, поселок Шолья, Рейда, 6	f	large
15216	6528	1917	республика Удмуртская, Камбарский район, село Нижняя Армязь, Школьная, 2а	f	medium
15209	6522	1911	республика Удмуртская, Камбарский район, село Михайловка, Юбилейная, 2а	f	small
15214	6526	1915	республика Удмуртская, Камбарский район, поселок Кама, Гагарина, 55	f	medium
15212	6525	1914	республика Удмуртская, Камбарский район, поселок Кама, Гагарина, 2	f	large
15217	6529	1918	республика Удмуртская, Камбарский район, село Ершовка, Советская, 36	f	small
15219	6530	1919	республика Удмуртская, Камбарский район, село Борок, Ленина, 19	f	medium
15208	6521	1910	республика Удмуртская, Камбарский район, село Балаки, пер. Клубный, 7а	f	small
14458	5915	108	республика Удмуртская, Индустриальный район, Ижевск, Холмогорова, 76	f	large
15184	6497	1826	республика Удмуртская, Игринский район, село Чутырь, Совхозная, 79	f	medium
15186	6499	1828	республика Удмуртская, Игринский район, село Чемошур, Труда, 21	f	small
15170	6483	1812	республика Удмуртская, Игринский район, поселок Факел, Кирова, 32а	f	large
15169	6482	1811	республика Удмуртская, Игринский район, поселок Факел, Кирова, 43	f	small
15185	6498	1827	республика Удмуртская, Игринский район, село Удмурт-Лоза, Трактовая, 15	f	small
15188	6501	1830	республика Удмуртская, Игринский район, село Сундур, Сельская, 3	f	medium
15173	6486	1815	республика Удмуртская, Игринский район, село Среднее Шадбегово, Молодежная, 3	f	small
15179	6491	1821	республика Удмуртская, Игринский район, село Сеп, Труда, 25	f	medium
15176	6489	1818	республика Удмуртская, Игринский район, село Оник-Ирым, Молодежная, 7	f	small
15195	6508	1837	республика Удмуртская, Игринский район, село Новые Зятцы, Центральная, 40	f	medium
15182	95050	1824	республика Удмуртская, Игринский район, село Мужбер, Вепревых, 2	f	small
15171	95049	1813	республика Удмуртская, Игринский район, село Менил, Ленина, 16	f	large
15196	6509	1838	республика Удмуртская, Игринский район, село Малягурт, Железнодорожная, 4	t	small
15197	6510	1839	республика Удмуртская, Игринский район, село Магистральный, Клубная, 2	f	small
15556	6863	3117	республика Удмуртская, Игринский район, село Ляльшур, Центральная, 2, Ляльшурская СОШ	f	small
15191	95051	1833	республика Удмуртская, Игринский район, село Лонки-Ворцы, Северная, 11	f	medium
15174	6487	1816	республика Удмуртская, Игринский район, село Лозолюк, Молодежная, 1	f	medium
15187	6500	1829	республика Удмуртская, Игринский район, село Лоза, Советская, 64	f	medium
15190	6503	1832	республика Удмуртская, Игринский район, село Левая Кушья, Труда, 46	f	small
15192	6505	1834	республика Удмуртская, Игринский район, село Кушья, Советская, 2	f	small
15189	6502	1831	республика Удмуртская, Игринский район, село Кузьмовыр, Мира, 25	f	small
15193	95052	1835	республика Удмуртская, Игринский район, село Комсомолец, Парковая, 2	f	medium
15172	6485	1814	республика Удмуртская, Игринский район, село Кабачигурт, Молодежная, 14	f	medium
15166	6479	1808	республика Удмуртская, Игринский район, поселок Игра, мрн.Нефтяников, 31	f	large
15165	6478	1807	республика Удмуртская, Игринский район, поселок Игра, мрн.Нефтяников, 34	f	large
15168	6481	1810	республика Удмуртская, Игринский район, поселок Игра, Трактовая, 14	f	medium
15159	6472	1801	республика Удмуртская, Игринский район, поселок Игра, Пугачева, 38	f	large
15163	6476	1805	республика Удмуртская, Игринский район, поселок Игра, Пионерская, 24а	f	large
15167	6480	1809	республика Удмуртская, Игринский район, поселок Игра, Мкр. Нефтяников, 49	f	large
15160	6473	1802	республика Удмуртская, Игринский район, поселок Игра, Мира, 26	f	medium
15161	6474	1803	республика Удмуртская, Игринский район, поселок Игра, Ломоносова, 58	f	large
15162	6475	1804	республика Удмуртская, Игринский район, поселок Игра, Лесная, 54	f	large
15164	6477	1806	республика Удмуртская, Игринский район, поселок Игра, Коммунальная, 28	f	large
15178	6488	1820	республика Удмуртская, Игринский район, село Зура, Льнозаводская, 9	f	large
15175	6488	1817	республика Удмуртская, Игринский район, село Зура, Льнозаводская, 9	f	small
15177	6490	1819	республика Удмуртская, Игринский район, село Зура, Ленина, 36	f	large
15183	6496	1825	республика Удмуртская, Игринский район, село Верх-Нязь, Центральная, 41	f	small
15181	6493	1823	республика Удмуртская, Игринский район, село Большая Пурга, Солнечная, 1	f	small
15180	6492	1822	республика Удмуртская, Игринский район, село Беляевское, Центральная, 3а	f	small
15194	6507	1836	республика Удмуртская, Игринский район, село Бачкеево, Сибирская, 16а	t	small
15153	6467	1752	республика Удмуртская, Завьяловский район, село Ягул, Холмогорова, 1, школа	f	large
15130	95045	1743	республика Удмуртская, Завьяловский район, село Юськи, Школьная, 10	t	medium
15147	6465	1750	республика Удмуртская, Завьяловский район, село Шабердино, Советская, 28	f	medium
15120	6419	1704	республика Удмуртская, Завьяловский район, село Чепаниха, Верхняя, 11, Чепанихинская начальная школа	t	small
15156	6464	1749	республика Удмуртская, Завьяловский район, село Хохряки, Тепличная, 20, МБОУ Хохряковская СОШ	f	medium
15122	6436	1722	республика Удмуртская, Завьяловский район, село Старые Тукмачи, Лесная, 4-А, Кенский детский сад	t	small
15154	6469	1754	республика Удмуртская, Завьяловский район, село Старое Михайловское, Совхозная, 9-2, Старо-Михайловский ФАП	t	small
15107	6430	1716	республика Удмуртская, Завьяловский район, село Старое Мартьяново, Центральная, 30, МАУ КСКЗавьяловский	t	large
15135	6461	1746	республика Удмуртская, Завьяловский район, село Средний Постол, Центральная, 8, МБУ КК Среднепостольский,	f	medium
15155	95048	1755	республика Удмуртская, Завьяловский район, село Сокол, Кооперативная, 8	f	small
15129	6456	1742	республика Удмуртская, Завьяловский район, село Совхозный, Восточная, 37-А, МБУ КК Совхозный	f	medium
15126	6439	1725	республика Удмуртская, Завьяловский район, село Сизево, Клубная, 14-А, Сизевский сельский клуб	f	small
15133	6454	1740	республика Удмуртская, Завьяловский район, село Сепыч, Центральная, 59, Сепыченская начальная школа	f	small
15119	95040	1703	республика Удмуртская, Завьяловский район, село Сапарово, Шорболяк, 7	f	small
15152	95047	1753	республика Удмуртская, Завьяловский район, село Русский Вожой, Молодежная, 9	t	small
15103	6429	1715	республика Удмуртская, Завьяловский район, село Пычанки, Центральная, 36-А, Пычановский клуб	f	medium
15136	6463	1748	республика Удмуртская, Завьяловский район, село Постол, Станционная, 5-А, ГУЗ РПБ	f	large
15109	6446	1732	республика Удмуртская, Завьяловский район, село Подшивалово, 37, МБУ Культурный комплекс Октябрьский	f	medium
15131	6452	1738	республика Удмуртская, Завьяловский район, село Подшивалово, Зайцева, 8-А, МАУ КК Подшиваловский	f	large
15138	6449	1735	республика Удмуртская, Завьяловский район, село Пирогово	f	large
15118	6417	1702	республика Удмуртская, Завьяловский район, село Пальники, Комсомольская, 1, МБОУ Пальниковская ООШ	f	small
15145	6444	1730	республика Удмуртская, Завьяловский район, село Новый Сентег, Клубная, 19, Ново-Сентегский клуб	t	small
15151	95042	1719	республика Удмуртская, Завьяловский район, село Новокварсинское, Береговая, 1	f	small
15116	6434	1720	республика Удмуртская, Завьяловский район, село Новая Казмаска, Сосунова, 41, МБУ КК Казмаский	f	large
15128	6460	1745	республика Удмуртская, Завьяловский район, село Непременная Лудзя, Центральная, 35, Непременнолудзинский клуб	f	small
15125	6438	1724	республика Удмуртская, Завьяловский район, село Мещеряки, Удмуртская, 20-А, Мещеряковский ФАП	t	small
14989	6305	1215	республика Удмуртская, Завьяловский район, село Макарово, Центральная, 65, детский сад	f	small
15114	6422	1708	республика Удмуртская, Завьяловский район, село Макарово, Свердлова, 57, Макаровский ФАП	f	small
15146	6466	1751	республика Удмуртская, Завьяловский район, село Люкшудья, Вокзальная, 13, МБОУ Люкшудьинская ООШ	f	medium
15144	6443	1729	республика Удмуртская, Завьяловский район, село Люк, Советская, 58, МБОУ Люкская СОШ	f	medium
15139	6450	1736	республика Удмуртская, Завьяловский район, село Лудорвай, Школьная, 10, МБОУ Лудорвайская ООШ	t	medium
15132	6453	1739	республика Удмуртская, Завьяловский район, село Ленино, Свободы, 9, Дом пенсионеров	f	small
15141	6440	1726	республика Удмуртская, Завьяловский район, село Кияик, Школьная, 19, МБУ КК Кияикский	f	medium
15124	6435	1721	республика Удмуртская, Завьяловский район, село Каменное, Молодежная, 2А, МБУ КК Каменский	f	large
15150	95041	1717	республика Удмуртская, Завьяловский район, Италмас, 19	f	large
66026	6432	1718	республика Удмуртская, Завьяловский район, Италмас, 19	f	small
66024	6425	1711	республика Удмуртская, Завьяловский район, село Завьялово, Чкалово, 38	f	medium
15106	6427	1713	республика Удмуртская, Завьяловский район, село Завьялово, Прудовая, 22, МДОУ Центр развития ребенка-детский сад № 2	f	medium
15105	6428	1714	республика Удмуртская, Завьяловский район, село Завьялово, Гольянская, 1, МБУЗ Завьяловская районная больница	f	large
15115	6423	1709	республика Удмуртская, Завьяловский район, село Забегалово, Заречная, 11-2, Забегаловский ФАП	f	small
15113	6421	1707	республика Удмуртская, Завьяловский район, село Докша, Пихтовая, 27, Докшинский клуб	f	small
15123	95043	1723	республика Удмуртская, Завьяловский район, село Динтем-Бодья, Шоссейная, 15	t	small
15112	6408	1706	республика Удмуртская, Завьяловский район, село Гольяны, Максима Горького, 15, МОУ Гольянская СОШ	f	medium
15134	6455	1741	республика Удмуртская, Завьяловский район, село Верхняя Лудзя, Школьная, 6, школа	f	small
15137	6462	1747	республика Удмуртская, Завьяловский район, село Верхний Женвай, Школьная, 21, Верхнеженвайская начальная школа	f	small
15149	6424	1710	республика Удмуртская, Завьяловский район, село Вараксино, 23, МБУ КК Вараксинский	f	large
15143	95044	1728	республика Удмуртская, Завьяловский район, село Большой Кияик, Советская, 5	f	small
15127	95046	1744	республика Удмуртская, Завьяловский район, село Большая Венья, Садовая, 36а	t	medium
15117	6416	1701	республика Удмуртская, Завьяловский район, село Бабино, Центральная, 1, Администрация МО Бабинское	f	large
15142	6441	1727	республика Удмуртская, Завьяловский район, село Азино, Штабная, 2, Азинский клуб	f	medium
15101	6415	1623	республика Удмуртская, Дебесский район, село Уйвай, Школьная, 1	f	small
15086	6399	1608	республика Удмуртская, Дебесский район, село Удмуртский Лем, Удлемская, 89	f	small
15100	6414	1622	республика Удмуртская, Дебесский район, село Тыловай, Кирова, 14	f	medium
15096	6410	1618	республика Удмуртская, Дебесский район, село Турнес, Турнесская, 2	f	small
15099	6413	1621	республика Удмуртская, Дебесский район, село Тольен, Октябрьская, 48	f	small
15094	6407	1616	республика Удмуртская, Дебесский район, село Такагурт, Майская, 1	f	small
15095	6409	1617	республика Удмуртская, Дебесский район, село Сюрногурт, Сибирская, 73	f	medium
15093	6406	1615	республика Удмуртская, Дебесский район, село Старый Кыч, Центральная, 7	f	small
15090	6403	1612	республика Удмуртская, Дебесский район, село Нижняя Пыхта, Молодежная, 1	f	small
15080	6393	1602	республика Удмуртская, Дебесский район, село Малая Чепца, Сибирская, 22	f	small
15098	6412	1620	республика Удмуртская, Дебесский район, село Лесагурт, Восточная, 52	t	small
15089	6402	1611	республика Удмуртская, Дебесский район, село Котегурт, Молодёжная, 1	f	small
15088	6401	1610	республика Удмуртская, Дебесский район, село Заречная Медла, Советская, 42	f	medium
15084	6397	1606	республика Удмуртская, Дебесский район, село Дебесы, Труда, 12	f	large
15083	6396	1605	республика Удмуртская, Дебесский район, село Дебесы, Советская, 90	f	medium
15081	6394	1603	республика Удмуртская, Дебесский район, село Дебесы, Советская, 136	f	medium
15085	6398	1607	республика Удмуртская, Дебесский район, село Дебесы, Радищева, 6	f	medium
15082	6395	1604	республика Удмуртская, Дебесский район, село Дебесы, Андронова, 32	f	medium
15092	6405	1614	республика Удмуртская, Дебесский район, село Верхний Четкер, Удмуртская, 7	f	small
15097	6411	1619	республика Удмуртская, Дебесский район, село Варни, Варнинская, 21	f	small
15079	6392	1601	республика Удмуртская, Дебесский район, село Большой Зетым, Центральная, 13	f	small
15087	6400	1609	республика Удмуртская, Дебесский район, село Большая Кизня, Большекизнинская, 43	f	small
15091	6404	1613	республика Удмуртская, Дебесский район, село Ариково, Центральная, 92	f	small
15055	6372	1504	республика Удмуртская, Граховский район, село Яги-Какси, Осиновская, 4	f	small
15068	6381	1513	республика Удмуртская, Граховский район, село Старый Ятчи, Староятчинская, 32	f	small
15076	6389	1521	республика Удмуртская, Граховский район, село Старая Игра, Удмуртская, 59	t	small
15070	6383	1515	республика Удмуртская, Граховский район, село Селянур, Молодежная, 4	t	small
15060	6375	1507	республика Удмуртская, Граховский район, село Порым, Центральная, 13	f	small
15069	6382	1514	республика Удмуртская, Граховский район, село Поршур, Тимофеева, 16	t	small
15073	6384	1516	республика Удмуртская, Граховский район, село Новогорское, Школьная, 1	f	small
15066	6379	1511	республика Удмуртская, Граховский район, село Нижние Юраши, Кирова, 42 Г	f	small
15078	6391	1523	республика Удмуртская, Граховский район, село Мишкино, Колхозная, 13	t	small
15071	6387	1519	республика Удмуртская, Граховский район, село Мари-Возжай, Советская, 38 А	t	small
15067	6380	1512	республика Удмуртская, Граховский район, село Мамаево, Мичурина, 14	t	small
15054	6371	1503	республика Удмуртская, Граховский район, село Макарово, Школьная, 1 А	f	small
15065	6378	1510	республика Удмуртская, Граховский район, село Лолошур-Возжи, Советская, 2 Е	f	medium
15053	6370	1502	республика Удмуртская, Граховский район, село Котловка, Пионерская, 11	f	small
14184	1393	2781	республика Татарстан, Чистополь, Чернышевского, 167а	f	\N
15075	6385	1517	республика Удмуртская, Граховский район, село Кокшан, Грузлёвская, 17	t	small
15057	6336	1505	республика Удмуртская, Граховский район, село Каменное, Советская, 2	f	small
66022	6374	1506	республика Удмуртская, Граховский район, село Иж-Бобья, Кооперативная, 1	f	small
66023	6376	1508	республика Удмуртская, Граховский район, село Заречный, Школьная, 3	f	small
15052	6369	1501	республика Удмуртская, Граховский район, село Грахово, Колпакова, 5	f	large
15072	6388	1520	республика Удмуртская, Граховский район, село Верхняя Игра, 10 Пятилетки, 1	f	small
15074	6386	1518	республика Удмуртская, Граховский район, село Большая Ерыкса, Гагарина, 1	t	small
15063	6377	1509	республика Удмуртская, Граховский район, село Благодатное, Благодатновская, 53 Б	f	small
15077	6390	1522	республика Удмуртская, Граховский район, село Байтуганово, Центральная, 38 А	t	small
15041	6368	1423	республика Удмуртская, Глазовский район, село Штанигурт, Глазовская, 3, МУК КДЦ Искра	f	large
15042	6356	1412	республика Удмуртская, Глазовский район, село Чура, Центральная, 12А, Чуринский СДК	f	small
66020	6347	1403	республика Удмуртская, Глазовский район, село Чажайский Лесоучасток, Школьная, 8	t	small
15047	6351	1407	республика Удмуртская, Глазовский район, село Удмуртские Ключи, Школьная, 4, МУК Ключевской ДК	f	small
15050	6359	1415	республика Удмуртская, Глазовский район, село Трубашур, Школьная, 1, МУСО КЦСОН	f	small
15036	6364	1419	республика Удмуртская, Глазовский район, село Сева, Горьковская, 1	f	small
15051	6366	1421	республика Удмуртская, Глазовский район, село Пусошур, Школьная, 1, Пусошурский ЦСДК	f	small
15030	6362	1417	республика Удмуртская, Глазовский район, село Понино, Коммунальная, 7, МУК Понинский КСК	f	small
15048	6361	1416	республика Удмуртская, Глазовский район, село Парзи, Прудовая, 7	f	medium
15045	6365	1420	республика Удмуртская, Глазовский район, село Отогурт, Кирова, 38, Отогуртский СДК	f	small
15049	6358	1414	республика Удмуртская, Глазовский район, село Октябрьский, Центральная, 23, МУК Октябрьский ЦСДК	f	large
15430	6748	2707	республика Удмуртская, Глазовский район, село Октябрьский, Пастухова, 1	f	small
15038	6350	1406	республика Удмуртская, Глазовский район, село Люм, Люмская, 41, ЦСДК, Люмская	f	medium
15032	6357	1413	республика Удмуртская, Глазовский район, село Курегово, пер. Школьный, 2, МУК Куреговская ЦКС	f	large
15044	6367	1422	республика Удмуртская, Глазовский район, село Кочищево, Ленина, 35, МУК Кочишевская ЦКС	f	medium
15039	6354	1410	республика Удмуртская, Глазовский район, село Кожиль, Кировская, 35, МУК ЦКС Дружба	f	medium
15043	6353	1409	республика Удмуртская, Глазовский район, село Качкашур, Центральная, 3а, Качкашурский ДК	f	large
15035	6363	1418	республика Удмуртская, Глазовский район, село Золотарево, Школьная, 1а, МОУ Золотаревская начальная школа-детский сад	f	medium
15034	6348	1404	республика Удмуртская, Глазовский район, село Дондыкар, Мира, 5, МОУ Дондыкарская СОШ	f	small
15040	6355	1411	республика Удмуртская, Глазовский район, село Дзякино, Советская, 5, Дзякинский СДК	f	medium
66021	6352	1408	республика Удмуртская, Глазовский район, село Гулеково, Центральная, 13а	f	medium
15029	6349	1405	республика Удмуртская, Глазовский район, село Верхняя Слудка, Садовая, 7, Слудский ЦСДК	f	medium
15031	6345	1401	республика Удмуртская, Глазовский район, село Адам, Советская, 16А, МОУ ДОД Детско-юношеская спортивная школа	f	medium
14795	6123	716	республика Удмуртская, Глазов городской округ, Глазов, Кирова, 34	f	large
14794	6123	715	республика Удмуртская, Глазов городской округ, Глазов, Кирова, 34	f	large
15012	6327	1310	республика Удмуртская, Воткинский район, село Черновский Лесоучасток, Школьная, 5	f	small
15027	6344	1326	республика Удмуртская, Воткинский район, село Черная, Колхозная, 8а	f	small
15022	6339	1321	республика Удмуртская, Воткинский район, село Черепановка, Кокорина, 41	t	small
15025	6342	1324	республика Удмуртская, Воткинский район, село Светлое, Октябрьский, 1	f	medium
66017	6322	1305	республика Удмуртская, Воткинский район, село Пихтовка, Центральная, 7	f	small
15023	6340	1322	республика Удмуртская, Воткинский район, село Перевозное, Советская, 38а	f	large
15021	6338	1320	республика Удмуртская, Воткинский район, село Первомайский, Проезд Молодежный, 2	f	large
15024	6341	1323	республика Удмуртская, Воткинский район, село Ольхово, Молодежная, 25/3	f	small
15008	6324	1307	республика Удмуртская, Воткинский район, поселок Новый, Центральная, 9	f	large
15007	6323	1306	республика Удмуртская, Воткинский район, поселок Новый, Центральная, 15	f	large
66019	6332	1315	республика Удмуртская, Воткинский район, село Молчаны, Широкая, 38Б	f	small
15020	6337	1319	республика Удмуртская, Воткинский район, село Кукуй, Школьная, 8	f	medium
15026	6343	1325	республика Удмуртская, Воткинский район, село Кудрино, Гагарина, 45а	f	small
15005	6321	1304	республика Удмуртская, Воткинский район, село Кельчино, Школьная, 1	f	small
15018	6334	1317	республика Удмуртская, Воткинский район, село Кварса, Советская, 12	f	large
15017	6333	1316	республика Удмуртская, Воткинский район, село Камское, Комсомольская, 3а	f	medium
15210	6523	1912	республика Удмуртская, Воткинский район, село Камское, Советская, 26	f	medium
15015	6331	1314	республика Удмуртская, Воткинский район, село Июльское, Центральная, 29	f	large
15010	95039	1313	республика Удмуртская, Воткинский район, село Июльское, Молодежная, 1, 427415 	f	small
15019	6335	1318	республика Удмуртская, Воткинский район, село Двигатель, Коммунаров, 2	f	small
15013	6328	1311	республика Удмуртская, Воткинский район, село Гавриловка, Набережная, 4	t	medium
15011	6326	1309	республика Удмуртская, Воткинский район, село Верхняя Талица, Центральная, 36	f	medium
15003	6319	1302	республика Удмуртская, Воткинский район, село Верхнепозимь, Школьная, 30	f	medium
15004	6320	1303	республика Удмуртская, Воткинский район, село Большая Кивара, Новая, 2	f	medium
15002	95038	1301	республика Удмуртская, Воткинский район, село Болгуры, Школьная, 1г	f	medium
15014	6329	1312	республика Удмуртская, Воткинский район, село Беркуты, Юбилейная, 1	t	small
14777	6107	649	республика Удмуртская, Воткинск городской округ, Воткинск, Освобождения, 5	f	large
14987	6303	1213	республика Удмуртская, Вавожский район, село Яголуд, Центральная, 14, СК	f	small
14985	6301	1211	республика Удмуртская, Вавожский район, село Уе-Докья, Садовая, 27, школа	f	small
14994	6310	1220	республика Удмуртская, Вавожский район, село Тыловыл-Пельга, Центральная, 61, Администрация МО Тыловыл-Пельгинское	f	small
14993	6309	1219	республика Удмуртская, Вавожский район, село Ожги, Евдокимова, 17, школа-сад	f	small
14982	6298	1208	республика Удмуртская, Вавожский район, поселок Нюрдор-Котья, Советская, 16, СДК	f	medium
14996	6312	1222	республика Удмуртская, Вавожский район, село Новая Бия	f	medium
15000	6316	1226	республика Удмуртская, Вавожский район, село Монья, Центральная, 6, столовая	t	small
14980	6296	1206	республика Удмуртская, Вавожский район, село Лыстем, Новая, 2, контора ОООЛыстемское	t	small
14986	6302	1212	республика Удмуртская, Вавожский район, село Каменный Ключ, Садовая, 23, СК	f	small
15001	6317	1227	республика Удмуртская, Вавожский район, поселок Какмож, Поточная, 1, СДК	f	small
14981	6297	1207	республика Удмуртская, Вавожский район, поселок Какмож, Поточная, 1, СДК	f	medium
14998	6314	1224	республика Удмуртская, Вавожский район, село Зямбайгурт, Центральная , 13А 	f	small
14992	6308	1218	республика Удмуртская, Вавожский район, село Зядлуд, Центральная, 11, СК	f	small
14984	6300	1210	республика Удмуртская, Вавожский район, село Зяглуд-Какся, Новая, 11, школа	f	small
14978	6294	1204	республика Удмуртская, Вавожский район, село Жуе-Можга, Лермонтова, 16, сельский клуб	t	small
14995	6311	1221	республика Удмуртская, Вавожский район, село Дубровка, Новая, 2, контора ООО Восход	f	small
14991	6307	1217	республика Удмуртская, Вавожский район, село Волипельга, Советская, 8, СДК	f	medium
14997	6313	1223	республика Удмуртская, Вавожский район, село Водзимонье, Коммунальная, 32, школа	f	medium
14977	6293	1203	республика Удмуртская, Вавожский район, село Вавож, Северная, 3, У УР Вавожское лесничество	f	large
14976	6292	1202	республика Удмуртская, Вавожский район, село Вавож, Интернациональная, 44 б, РДК	f	medium
14975	6291	1201	республика Удмуртская, Вавожский район, село Вавож, Интернациональная, 44 б, РДК	f	large
14999	6315	1225	республика Удмуртская, Вавожский район, село Брызгалово, Молодежная, 4, СК	f	small
14988	6304	1214	республика Удмуртская, Вавожский район, село Большое Волково, Центральная, 44, центр досуга	f	small
14979	6295	1205	республика Удмуртская, Вавожский район, село Большая Можга, Центральная, 13, СК	f	small
14983	6299	1209	республика Удмуртская, Вавожский район, село Большая Гурезь-Пудга, Первомайская, 23, СДК	f	small
14990	6306	1216	республика Удмуртская, Вавожский район, село Березек, Вишнёвая, 17	f	small
14946	6261	1124	республика Удмуртская, Балезинский район, село Ягошур, ФАП	f	small
14943	6258	1121	республика Удмуртская, Балезинский район, село Юнда, Центральная, 42	f	small
14956	95033	1134	республика Удмуртская, Балезинский район, село Эркешево, Центральная, 13	f	small
14969	6284	1147	республика Удмуртская, Балезинский район, село Шарпа, Школьная, 2	t	small
14949	6264	1127	республика Удмуртская, Балезинский район, село Ушур, Центральная, 9	f	small
14953	95032	1131	республика Удмуртская, Балезинский район, село Турецкое, Труда, 14	f	small
14934	6249	1112	республика Удмуртская, Балезинский район, село Такапи, бригадный дом	f	small
14968	6283	1146	республика Удмуртская, Балезинский район, село Сергино, Советская, 2	f	small
14941	6256	1119	республика Удмуртская, Балезинский район, село Пышкец, Луговая, 25, СДК	f	small
14935	6250	1113	республика Удмуртская, Балезинский район, село Пыбья, Клубная, 2	f	medium
14936	95030	1114	республика Удмуртская, Балезинский район, село Подборново, Центральная, 19	f	small
14973	6288	1151	республика Удмуртская, Балезинский район, село Пибаньшур	f	small
14945	6260	1123	республика Удмуртская, Балезинский район, село Падера, Центральная, 41	f	small
14957	95034	1135	республика Удмуртская, Балезинский район, село Оросово, им.А.Русских, 2	t	small
14951	6266	1129	республика Удмуртская, Балезинский район, село Нововолково, Волкова, 27	t	small
14952	6267	1130	республика Удмуртская, Балезинский район, село Люк, Школьная , 14	f	small
14958	6273	1136	республика Удмуртская, Балезинский район, село Люк, Школьная, 9, СДК	f	small
14971	95036	1149	республика Удмуртская, Балезинский район, село Котомка, Полевая, 9	t	small
14947	6262	1125	республика Удмуртская, Балезинский район, село Котегово, Сепычевская, 3	f	small
14959	6274	1137	республика Удмуртская, Балезинский район, село Коршуново, Школьная, 2-3	f	small
14933	6248	1111	республика Удмуртская, Балезинский район, село Кожило, Советская, 1	f	medium
14962	6277	1140	республика Удмуртская, Балезинский район, село Киршонки, Новая, 7	f	small
14974	6289	1152	республика Удмуртская, Балезинский район, село Кипрята, Полевая, 2	f	small
14937	6252	1115	республика Удмуртская, Балезинский район, село Кестым, Школьная, 8	f	medium
14964	6279	1142	республика Удмуртская, Балезинский район, село Карсовай, Первомайская, 17	f	medium
14963	6278	1141	республика Удмуртская, Балезинский район, село Карсовай, Первомайская, 21, ЦСДК	f	medium
14965	6280	1143	республика Удмуртская, Балезинский район, село Карсовай, Механизаторов, 3	f	small
14954	6269	1132	республика Удмуртская, Балезинский район, село Каменное Заделье, Школьная, 5б, СДК	f	small
14948	95031	1126	республика Удмуртская, Балезинский район, село Исаково, Школьная, 1	f	medium
14940	6255	1118	республика Удмуртская, Балезинский район, село Заречный, Больничная, 1	f	small
14938	6253	1116	республика Удмуртская, Балезинский район, село Гордино, Колхозная, 1-2	f	small
14939	6254	1117	республика Удмуртская, Балезинский район, село Воегурт, Полевая, 2а	f	medium
14961	95035	1139	республика Удмуртская, Балезинский район, село Верх-Люкино, Центральная, 24	f	small
14942	6257	1120	республика Удмуртская, Балезинский район, село Быдыпи, Советская, 13а, СДК	f	small
14955	6270	1133	республика Удмуртская, Балезинский район, село Бурино, Центральная, 32-1	f	small
14960	6275	1138	республика Удмуртская, Балезинский район, село Большой Варыж, Центральная, 26	f	small
14972	6287	1150	республика Удмуртская, Балезинский район, село Большое Сазаново, ФАП	f	small
14932	95029	1110	республика Удмуртская, Балезинский район, село Балезино, Школьная, 2	f	small
14931	6246	1109	республика Удмуртская, Балезинский район, поселок Балезино, Школьная, 12	f	large
14924	6240	1102	республика Удмуртская, Балезинский район, поселок Балезино, Советская, 9	f	large
14923	6239	1101	республика Удмуртская, Балезинский район, поселок Балезино, Сибирская, 1а	f	large
14928	6243	1106	республика Удмуртская, Балезинский район, поселок Балезино, Свердлова, 1	f	large
66016	6230	1105	республика Удмуртская, Балезинский район, поселок Балезино, Московская, 41 а	f	large
14925	6241	1103	республика Удмуртская, Балезинский район, поселок Балезино, Карла Маркса, 30	f	large
14926	6242	1104	республика Удмуртская, Балезинский район, поселок Балезино, Калинина, 50	f	large
14930	6245	1108	республика Удмуртская, Балезинский район, поселок Балезино, Заводская, 1	f	medium
14929	6244	1107	республика Удмуртская, Балезинский район, поселок Балезино, Железнодорожная, 10	f	large
14967	6282	1145	республика Удмуртская, Балезинский район, село Базаны, Солнечная, 22, детский сад	f	small
14944	6259	1122	республика Удмуртская, Балезинский район, село Ахмади, ФАП	f	small
14950	6265	1128	республика Удмуртская, Балезинский район, село Андрейшур, Советская, 10	f	medium
14966	6281	1144	республика Удмуртская, Балезинский район, село Андреевцы, Школьная, 2	f	small
66013	6234	1022	республика Удмуртская, Алнашский район, село Удмуртское Гондырево	t	small
14917	6233	1021	республика Удмуртская, Алнашский район, село Удмуртское Гондырево, МОУ Удмурт-Гондыревская СОШ	f	small
14922	6235	1023	республика Удмуртская, Алнашский район, село Удмуртский Тоймобаш, Малая, 3, МОУ Удмурттоймобашская СОШ	f	small
66014	6238	1026	республика Удмуртская, Алнашский район, село Татарский Тоймобаш	f	small
14920	6236	1024	республика Удмуртская, Алнашский район, село Сям-Какси, Сям-Каксинский СДД	f	small
14916	6232	1020	республика Удмуртская, Алнашский район, село Старый Утчан, Молодежная, 2, МОУ Староутчанская СОШ	f	medium
14901	6215	1005	республика Удмуртская, Алнашский район, село Старая Шудья, Старо-Шудьинский СДД	f	small
14900	6214	1004	республика Удмуртская, Алнашский район, село Новый Утчан, Поперечная, 4, Ново-Утчанский СДД	f	small
66015	6237	1025	республика Удмуртская, Алнашский район, село Нижний Сырьез, Молодежный проезд, 3	f	medium
14912	6227	1016	республика Удмуртская, Алнашский район, село Нижнее Котнырево, Новая, 1, МОУ Котныревская СОШ	f	small
14913	6228	1017	республика Удмуртская, Алнашский район, село Нижнее Асаново, Крылова, МОУ Асановская СОШ	f	medium
14910	6225	1014	республика Удмуртская, Алнашский район, село Муважи, Фестивальная, 13, МОУ Муважинская СОШ	f	medium
14907	6222	1011	республика Удмуртская, Алнашский район, село Ляли, Лялинский СДД	f	medium
14904	6219	1008	республика Удмуртская, Алнашский район, село Кузюмово, МОУ Кузюмовская НОШ	f	medium
14908	6223	1012	республика Удмуртская, Алнашский район, село Кузебаево, Центральная, 50, МОУ Кузебаевская СОШ	f	medium
14909	6224	1013	республика Удмуртская, Алнашский район, село Варзибаш, МОУ Варзибашская школа-детский сад	t	small
14906	6221	1010	республика Удмуртская, Алнашский район, село Варзи-Ятчи	f	small
14905	6220	1009	республика Удмуртская, Алнашский район, село Варзи-Ятчи, Варзи-Ятчинский СКЦ	f	medium
14911	6226	1015	республика Удмуртская, Алнашский район, село Байтеряково, Байтеряковский СКЦ	f	medium
66011	6229	1018	республика Удмуртская, Алнашский район, село Асановский, Школьная, 21, совхоз-техникум	f	medium
66010	6216	1006	республика Удмуртская, Алнашский район, село Алнаши	f	small
14899	6213	1003	республика Удмуртская, Алнашский район, село Алнаши, Комсомольская, 4, Алнашский ДДТ	f	small
14898	6212	1002	республика Удмуртская, Алнашский район, село Алнаши, Комсомольская, 3, ЦКиИ	f	large
14897	6211	1001	республика Удмуртская, Алнашский район, село Алнаши, Комсомольская, 6, РДК	f	large
66012	6231	1019	республика Удмуртская, Алнашский район, село Алнаши, Лесная, 6	f	small
14903	6218	1007	республика Удмуртская, Алнашский район, село Азаматово, Азаматовский СКЦ	f	medium
12733	94253	1330	республика Татарстан, пос.Озерный, Садовая, 3	f	small
12664	94170	1261	республика Татарстан, поселок им. Кирова, Центральная, 19	f	small
12547	94044	1144	республика Татарстан, ж/д ст. Акбаш, Школьная, 1	f	small
14105	1305	2702	республика Татарстан, село Шильнебаш, 60 Лет Октября, 2	f	medium
14198	1407	2795	республика Татарстан, Чистополь, Полющенкова, 15	f	large
14191	1401	2788	республика Татарстан, Чистополь, Зеленая, 2	f	large
14189	1399	2786	республика Татарстан, Чистополь, Заводская, 13	f	medium
14171	1380	2768	республика Татарстан, Чистополь, Вотякова, 23	f	large
14190	1400	2787	республика Татарстан, Чистополь, Виктора Ногина, 97	f	large
14185	1395	2782	республика Татарстан, Чистополь, 40 лет Победы, 34	f	large
13187	417	1784	республика Татарстан, село Усады, Дорожная, 4	f	large
12665	94171	1262	республика Татарстан, село Печищи, Кирова, 62	f	medium
13737	896	2334	республика Татарстан, Нурлат, Линейная, 12	f	large
13736	895	2333	республика Татарстан, Нурлат, Заводская, 1	f	large
13735	895	2332	республика Татарстан, Нурлат, Заводская, 1	f	large
12951	149	1548	республика Татарстан, поселок Новониколаевский, Центральная, 13	f	medium
12952	150	1549	республика Татарстан, село Новая Тура, Центральная, 10а	f	small
12697	94209	1294	республика Татарстан, село Нижний Услон, Дзержинского, 6	f	small
14069	1267	2666	республика Татарстан, поселок Нефтебаза, Центральная, 21	f	small
13475	706	2072	республика Татарстан, Набережные Челны, улица Шамиля Усманова, 5	f	large
13539	743	2136	республика Татарстан, Набережные Челны, улица Ш. Усманова, 139	f	large
13476	707	2073	республика Татарстан, Набережные Челны, улица Ш. Усманова, 19	f	large
13484	707	2081	республика Татарстан, Набережные Челны, улица Ш. Усманова, 19	f	large
13483	707	2080	республика Татарстан, Набережные Челны, улица Ш. Усманова, 19	f	large
13474	704	2071	республика Татарстан, Набережные Челны, улица Ш. Усманова, 10	f	large
13471	704	2068	республика Татарстан, Набережные Челны, улица Ш. Усманова, 10	f	large
13590	768	2187	республика Татарстан, Автозаводский район, Набережные Челны, улица Ш. Усманова, 110	f	large
13589	768	2186	республика Татарстан, Автозаводский район, Набережные Челны, улица Ш. Усманова, 110	f	large
13588	768	2185	республика Татарстан, Автозаводский район, Набережные Челны, улица Ш. Усманова, 110	f	large
13550	750	2147	республика Татарстан, Автозаводский район, Набережные Челны, улица Ш. Усманова, 128а	f	large
13549	749	2146	республика Татарстан, Автозаводский район, Набережные Челны, улица Ш. Усманова, 128а	f	large
13468	692	2065	Россия, республика Татарстан, Набережные Челны, улица Хади Такташа	f	large
13457	692	2054	Россия, республика Татарстан, Набережные Челны, улица Хади Такташа	f	large
13455	692	2052	Россия, республика Татарстан, Набережные Челны, улица Хади Такташа	f	large
13553	751	2150	республика Татарстан, Набережные Челны, 48-й квартал, улица Татарстан, 14	f	large
13552	751	2149	республика Татарстан, Набережные Челны, 48-й квартал, улица Татарстан, 14	f	large
13551	751	2148	республика Татарстан, Набережные Челны, 48-й квартал, улица Татарстан, 14	f	large
13537	741	2134	республика Татарстан, Набережные Челны, улица Раиса Беляева, 60	f	large
13536	741	2133	республика Татарстан, Набережные Челны, улица Раиса Беляева, 60	f	large
13535	741	2132	республика Татарстан, Набережные Челны, улица Раиса Беляева, 60	f	large
132525	709	2076	республика Татарстан, Набережные Челны, улица Касымова, 2, здание школы №53	f	\N
132526	709	2077	республика Татарстан, Набережные Челны, улица Касымова, 2, здание школы №53	f	\N
132524	709	2075	республика Татарстан, Набережные Челны, улица Касымова, 2, здание школы №53	f	\N
13504	725	2101	республика Татарстан, Набережные Челны, улица 40 Лет Победы, 29	f	large
13503	725	2100	республика Татарстан, Набережные Челны, улица 40 Лет Победы, 29	f	large
132527	716	2090	республика Татарстан, Набережные Челны, пр-т Мира, 29, здание школы №31	f	\N
13439	681	2036	республика Татарстан, Набережные Челны, переулок Энергетиков, 1	f	large
13438	641	2035	республика Татарстан, Набережные Челны, пер.Юности, 1	f	large
13512	729	2109	республика Татарстан, Центральный район, Набережные Челны, бульвар Энтузиастов, 2	f	large
13511	729	2108	республика Татарстан, Центральный район, Набережные Челны, бульвар Энтузиастов, 2	f	large
13510	729	2107	республика Татарстан, Центральный район, Набережные Челны, бульвар Энтузиастов, 2	f	large
13576	764	2173	республика Татарстан, Набережные Челны, бульвар Автомобилестроителей, 5	f	large
13575	764	2172	республика Татарстан, Набережные Челны, бульвар Автомобилестроителей, 5	f	large
13451	691	2048	республика Татарстан, Набережные Челны, б-р Тичурина, 2	f	large
13450	691	2047	республика Татарстан, Набережные Челны, б-р Тичурина, 2	f	large
13446	688	2043	республика Татарстан, Набережные Челны, б-р Корчагина , 2	f	large
13574	763	2171	республика Татарстан, Автозаводский район, Набережные Челны, б-р Автомобилестроителей, 9	f	large
13573	763	2170	республика Татарстан, Автозаводский район, Набережные Челны, б-р Автомобилестроителей, 9	f	large
132528	720	2093	республика Татарстан, Центральный район, Набережные Челны, б-р 60 Лет Октября, 10, здание школы №35	f	\N
13447	689	2044	республика Татарстан, Набережные Челны, Ямашева бульвар, 4/14А	f	large
13567	759	2164	республика Татарстан, Набережные Челны, 27-й квартал, Юных Ленинцев бульвар, 7	f	large
13566	759	2163	республика Татарстан, Набережные Челны, 27-й квартал, Юных Ленинцев бульвар, 7	f	large
13572	762	2169	республика Татарстан, Набережные Челны, 26-й квартал, Юных Ленинцев бульвар, 3	f	large
13571	762	2168	республика Татарстан, Набережные Челны, 26-й квартал, Юных Ленинцев бульвар, 3	f	large
13570	762	2167	республика Татарстан, Набережные Челны, 26-й квартал, Юных Ленинцев бульвар, 3	f	large
13517	732	2114	республика Татарстан, Набережные Челны, Школьный бульвар, 2	f	large
13560	757	2157	республика Татарстан, Набережные Челны, Шишкинский бульвар, 26	f	large
13565	756	2162	республика Татарстан, Набережные Челны, Шишкинский бульвар, 26	f	large
13559	756	2156	республика Татарстан, Набережные Челны, Шишкинский бульвар, 26	f	large
13564	745	2161	республика Татарстан, Набережные Челны, Шишкинский бульвар, 11	f	large
13542	745	2139	республика Татарстан, Набережные Челны, Шишкинский бульвар, 11	f	large
13563	758	2160	республика Татарстан, Набережные Челны, 29-й квартал, Шишкинский бульвар, 9	f	large
13562	758	2159	республика Татарстан, Набережные Челны, 29-й квартал, Шишкинский бульвар, 9	f	large
13561	758	2158	республика Татарстан, Набережные Челны, 29-й квартал, Шишкинский бульвар, 9	f	large
13582	765	2179	республика Татарстан, Автозаводский район, Набережные Челны, Шамиля Усманова, 96	f	large
13581	765	2178	республика Татарстан, Автозаводский район, Набережные Челны, Шамиля Усманова, 96	f	large
13577	765	2174	республика Татарстан, Автозаводский район, Набережные Челны, Шамиля Усманова, 96	f	large
13543	746	2140	республика Татарстан, Набережные Челны, Шамиля Усманова, 82	f	large
13579	746	2176	республика Татарстан, Набережные Челны, Шамиля Усманова, 82	f	large
13578	746	2175	республика Татарстан, Набережные Челны, Шамиля Усманова, 82	f	large
13593	771	2190	республика Татарстан, Набережные Челны, Чулман проспект, 112	f	large
13587	767	2184	республика Татарстан, Набережные Челны, Чулман проспект, 112	f	large
13547	747	2144	республика Татарстан, Набережные Челны, Чулман проспект, 136	f	large
13546	747	2143	республика Татарстан, Набережные Челны, Чулман проспект, 136	f	large
13545	747	2142	республика Татарстан, Набережные Челны, Чулман проспект, 136	f	large
13544	747	2141	республика Татарстан, Набережные Челны, Чулман проспект, 136	f	large
13534	739	2131	республика Татарстан, Набережные Челны, Чулман проспект, 56	f	large
13533	739	2130	республика Татарстан, Набережные Челны, Чулман проспект, 56	f	large
13532	739	2129	республика Татарстан, Набережные Челны, Чулман проспект, 56	f	large
13531	738	2128	республика Татарстан, Набережные Челны, Чулман проспект, 62	f	large
13530	738	2127	республика Татарстан, Набережные Челны, Чулман проспект, 62	f	large
13529	737	2126	республика Татарстан, Набережные Челны, Чулман проспект, 72	f	large
13528	737	2125	республика Татарстан, Набережные Челны, Чулман проспект, 72	f	large
13527	737	2124	республика Татарстан, Набережные Челны, Чулман проспект, 72	f	large
13526	736	2123	республика Татарстан, Набережные Челны, Чулман проспект, 78	f	large
13525	736	2122	республика Татарстан, Набережные Челны, Чулман проспект, 78	f	large
13523	735	2120	республика Татарстан, Набережные Челны, Чулман проспект, 88	f	large
13524	735	2121	республика Татарстан, Набережные Челны, Чулман проспект, 88	f	large
13522	735	2119	республика Татарстан, Набережные Челны, Чулман проспект, 88	f	large
13489	713	2086	республика Татарстан, Набережные Челны, Чулман проспект, 38	f	large
13488	713	2085	республика Татарстан, Набережные Челны, Чулман проспект, 38	f	large
13487	713	2084	республика Татарстан, Набережные Челны, Чулман проспект, 38	f	large
13486	712	2083	республика Татарстан, Набережные Челны, Чулман проспект, 34	f	large
13485	712	2082	республика Татарстан, Набережные Челны, Чулман проспект, 34	f	large
13467	702	2064	республика Татарстан, Набережные Челны, Центральная, 7	f	large
13586	766	2183	республика Татарстан, Набережные Челны, Цветочный бульвар, 21	f	medium
13585	748	2182	республика Татарстан, Набережные Челны, Цветочный бульвар, 15	f	large
13584	748	2181	республика Татарстан, Набережные Челны, Цветочный бульвар, 15	f	large
13548	748	2145	республика Татарстан, Набережные Челны, Цветочный бульвар, 15	f	large
13469	693	2066	республика Татарстан, Набережные Челны, Хади Такташа, 27	f	large
13456	693	2053	республика Татарстан, Набережные Челны, Хади Такташа, 27	f	large
13592	769	2189	республика Татарстан, Набережные Челны, Татарстан, 27	f	large
13591	769	2188	республика Татарстан, Набережные Челны, Татарстан, 27	f	large
13541	744	2138	республика Татарстан, Набережные Челны, Сююмбике проспект, 103	f	large
13540	744	2137	республика Татарстан, Набережные Челны, Сююмбике проспект, 103	f	large
13506	727	2103	республика Татарстан, Набережные Челны, 4-й квартал, Строителей бульвар, 1	f	large
13507	727	2104	республика Татарстан, Набережные Челны, 4-й квартал, Строителей бульвар, 1	f	large
13509	728	2106	республика Татарстан, Набережные Челны, 5-й квартал, Строителей бульвар, 9	f	large
13508	728	2105	республика Татарстан, Набережные Челны, 5-й квартал, Строителей бульвар, 9	f	large
13464	699	2061	республика Татарстан, Набережные Челны, пос.Элеваторная Гора, Спартаковская, 6	f	large
13519	733	2116	республика Татарстан, Набережные Челны, Солнечный бульвар, 2	f	large
13518	733	2115	республика Татарстан, Набережные Челны, Солнечный бульвар, 2	f	large
13470	703	2067	республика Татарстан, Набережные Челны, Сармановский тракт, 36	f	large
13433	677	2030	республика Татарстан, Набережные Челны, Сайдашева, 10	f	large
13449	677	2046	республика Татарстан, Набережные Челны, Сайдашева, 10	f	large
13463	698	2060	республика Татарстан, Набережные Челны, Садовый переулок, 4	f	large
13477	708	2074	республика Татарстан, Набережные Челны, Раскольникова, 33А	f	large
13521	734	2118	республика Татарстан, Набережные Челны, Раиса Беляева, 26	f	large
13520	734	2117	республика Татарстан, Набережные Челны, Раиса Беляева, 26	f	large
13505	726	2102	республика Татарстан, Набережные Челны, Раиса Беляева, 3	f	large
13462	697	2059	республика Татарстан, Набережные Челны, Низаметдинова, 28	f	large
13473	705	2070	республика Татарстан, Набережные Челны, Нариманова, 44	f	large
13472	705	2069	республика Татарстан, Набережные Челны, Нариманова, 44	f	large
13436	679	2033	республика Татарстан, Набережные Челны, Мусы Джалиля проспект, 14	f	large
13497	722	2094	республика Татарстан, Набережные Челны, Московский проспект, 95	f	large
13569	760	2166	республика Татарстан, Набережные Челны, Мира проспект, 94	f	large
13568	760	2165	республика Татарстан, Набережные Челны, Мира проспект, 94	f	large
13514	730	2111	республика Татарстан, Набережные Челны, Мира проспект, 54	f	large
13513	730	2110	республика Татарстан, Набережные Челны, Мира проспект, 54	f	large
13490	714	2087	Россия, республика Татарстан, Набережные Челны, Мира проспект	f	large
13492	715	2089	республика Татарстан, Набережные Челны, Мира проспект, 29	f	large
13491	715	2088	республика Татарстан, Набережные Челны, Мира проспект, 29	f	large
132523	695	2058	республика Татарстан, Набережные Челны, Маршала Жукова, 36, здание лицея КАЛКАН	f	\N
13454	177	2051	республика Татарстан, Набережные Челны, Комарова, 23	f	large
13452	177	2049	республика Татарстан, Набережные Челны, Комарова, 23	f	large
13453	177	2050	республика Татарстан, Набережные Челны, Комарова, 23	f	large
13500	723	2097	республика Татарстан, Набережные Челны, Колгали бульвар, 22	f	large
13499	723	2096	республика Татарстан, Набережные Челны, Колгали бульвар, 22	f	large
13498	723	2095	республика Татарстан, Набережные Челны, Колгали бульвар, 22	f	large
13482	711	2079	республика Татарстан, Центральный район, Набережные Челны, Касимова, 6	f	large
13481	711	2078	республика Татарстан, Центральный район, Набережные Челны, Касимова, 6	f	large
13437	628	2034	республика Татарстан, Набережные Челны, Казанский проспект, 17	f	large
13460	694	2057	республика Татарстан, Набережные Челны, Железнодорожников, 65	f	large
13458	694	2055	республика Татарстан, Набережные Челны, Железнодорожников, 65	f	large
13459	694	2056	республика Татарстан, Набережные Челны, Железнодорожников, 65	f	large
13502	724	2099	республика Татарстан, Набережные Челны, Дружбы Народов проспект, 9А	f	large
13501	724	2098	республика Татарстан, Набережные Челны, Дружбы Народов проспект, 9А	f	large
13434	675	2031	республика Татарстан, Набережные Челны, Грина, 9	f	large
13431	675	2028	республика Татарстан, Набережные Челны, Грина, 9	f	medium
13516	731	2113	республика Татарстан, Набережные Челны, Главмосстроевцев бульвар, 2	f	large
13515	731	2112	республика Татарстан, Набережные Челны, Главмосстроевцев бульвар, 2	f	large
13443	685	2040	республика Татарстан, Набережные Челны, Гидростроителей, 5	f	large
13432	676	2029	республика Татарстан, Набережные Челны, Гвардейская, 3	f	large
13445	687	2042	Россия, республика Татарстан, Набережные Челны, Габдуллы Тукая набережная	f	large
13442	684	2039	республика Татарстан, Набережные Челны, Габдуллы Тукая набережная, 43	f	large
13441	683	2038	республика Татарстан, Набережные Челны, Габдуллы Тукая набережная, 33	f	large
13440	682	2037	республика Татарстан, Набережные Челны, Габдуллы Тукая набережная, 31	f	large
13558	753	2155	республика Татарстан, Набережные Челны, 54-й квартал, Вахитова проспект, 23	f	large
13556	753	2153	республика Татарстан, Набережные Челны, 54-й квартал, Вахитова проспект, 23	f	large
13555	753	2152	республика Татарстан, Набережные Челны, 54-й квартал, Вахитова проспект, 23	f	large
13557	755	2154	республика Татарстан, Набережные Челны, 30-й квартал, Вахитова проспект, 2	f	large
13466	700	2063	республика Татарстан, Набережные Челны, 17а Гидростроителей квартал, Бумажников переулок, 3	f	large
13465	700	2062	республика Татарстан, Набережные Челны, 17а Гидростроителей квартал, Бумажников переулок, 3	f	large
13538	742	2135	республика Татарстан, Набережные Челны, Беляева Раиса, 60	f	large
13448	690	2045	республика Татарстан, Набережные Челны, Батенчука, 9/10	f	large
13444	686	2041	республика Татарстан, Набережные Челны, Батенчука, 21	f	large
13583	752	2180	республика Татарстан, Набережные Челны, Автозаводский проспект, 39	f	medium
13554	752	2151	республика Татарстан, Набережные Челны, Автозаводский проспект, 39	f	large
13580	752	2177	республика Татарстан, Набережные Челны, Автозаводский проспект, 39	f	large
13495	718	2092	республика Татарстан, Центральный район, Набережные Челны, 60 лет Октября, 10	f	large
13494	718	2091	республика Татарстан, Центральный район, Набережные Челны, 60 лет Октября, 10	f	large
13220	449	1817	республика Татарстан, Лениногорск, Степана Разина, 1	f	large
12696	94208	1293	республика Татарстан, Ключищи, Центральная, 8	f	small
132467	94073	1171	республика Татарстан, Карабаш, Вахитова, 17, здание Дома Культуры	f	\N
11541	93133	131	республика Татарстан, Казань, Кировский район, станция Юдино, технический кабинет грузового депо	f	small
11502	93101	92	республика Татарстан, Казань, 7, озеро Лебяжье	f	small
13327	562	1924	Россия, республика Татарстан, Казань, Вахитовский район, улица Центральная, 35а	f	small
12722	94241	1319	республика Татарстан, Казань, Вахитовский район, улица Центральная, 2	f	medium
11651	93198	240	Россия, республика Татарстан, Казань, улица Фатыха Амирхана, 111	f	large
11650	93198	239	Россия, республика Татарстан, Казань, улица Фатыха Амирхана, 111	f	large
11649	93198	238	Россия, республика Татарстан, Казань, улица Фатыха Амирхана, 111	f	large
11648	93198	237	Россия, республика Татарстан, Казань, улица Фатыха Амирхана, 111	f	large
11588	93169	178	Россия, республика Татарстан, Казань, улица Рахимова, 29	f	large
11797	93286	387	Россия, республика Татарстан, Казань, улица Парковая, 16	f	large
11507	93105	97	Россия, республика Татарстан, Казань, улица Окольная, 25	f	large
11506	93104	96	Россия, республика Татарстан, Казань, улица Окольная, 9	f	large
11505	93104	95	Россия, республика Татарстан, Казань, улица Окольная, 9	f	large
11524	93117	114	республика Татарстан, Казань, улица Односторонняя Гривка, 48	f	medium
11789	93278	379	Россия, республика Татарстан, Казань, улица Начальная, 6	f	large
11788	93278	378	Россия, республика Татарстан, Казань, улица Начальная, 6	f	large
11430	93036	20	республика Татарстан, Казань, улица Лядова, 16	f	large
11453	93056	43	Россия, республика Татарстан, Казань, улица Кремлевская, 25/22	f	large
11673	93209	263	Россия, республика Татарстан, Казань, улица Красного Пожарника, 1а	f	medium
11550	93142	140	Россия, республика Татарстан, Казань, улица Короленко, 26	f	large
11549	93142	139	Россия, республика Татарстан, Казань, улица Короленко, 26	f	large
11464	93066	54	республика Татарстан, Казань, улица Горького, 29/19	f	medium
11608	93183	197	Россия, республика Татарстан, Казань, улица Восстания, 8а	f	large
11607	93183	196	Россия, республика Татарстан, Казань, улица Восстания, 8а	f	large
11606	93183	195	Россия, республика Татарстан, Казань, улица Восстания, 8а	f	large
11436	93042	26	Россия, республика Татарстан, Казань, улица Беломорская, 104	f	large
11581	93163	171	Россия, республика Татарстан, Казань, улица Бакалейная, 41	f	large
11688	93219	278	Россия, республика Татарстан, Казань, улица Актайская, 5	f	large
11687	93219	277	Россия, республика Татарстан, Казань, улица Актайская, 5	f	large
11577	93160	167	Россия, республика Татарстан, Казань, улица Академика Королева, 47	f	large
11760	93255	350	республика Татарстан, Казань, проспект Альберта Камалеева, 22	f	large
11724	93148	314	республика Татарстан, Казань, Приволжский район, пр.Победы, 71а	f	large
11722	93148	312	республика Татарстан, Казань, Приволжский район, пр.Победы, 71а	f	large
11723	93148	313	республика Татарстан, Казань, Приволжский район, пр.Победы, 71а	f	large
11631	93192	220	Россия, республика Татарстан, Казань, Ямашева проспект, 100а	f	large
11630	93192	219	Россия, республика Татарстан, Казань, Ямашева проспект, 100а	f	large
11629	93192	218	Россия, республика Татарстан, Казань, Ямашева проспект, 100а	f	large
11628	93192	217	Россия, республика Татарстан, Казань, Ямашева проспект, 100а	f	large
11554	93144	144	Россия, республика Татарстан, Казань, Ямашева проспект, 8	f	large
11553	93144	143	Россия, республика Татарстан, Казань, Ямашева проспект, 8	f	large
11683	93217	273	Россия, республика Татарстан, Казань, Якты Юл переулок, 4	f	large
11682	93217	272	Россия, республика Татарстан, Казань, Якты Юл переулок, 4	f	large
11735	93240	325	республика Татарстан, Казань, Юлиуса Фучика, 40	f	large
11734	93240	324	республика Татарстан, Казань, Юлиуса Фучика, 40	f	large
11733	93240	323	республика Татарстан, Казань, Юлиуса Фучика, 40	f	large
11732	93239	322	республика Татарстан, Казань, Юлиуса Фучика, 26	f	large
11731	93239	321	республика Татарстан, Казань, Юлиуса Фучика, 26	f	large
11730	93239	320	республика Татарстан, Казань, Юлиуса Фучика, 26	f	large
11729	93239	319	республика Татарстан, Казань, Юлиуса Фучика, 26	f	large
11738	93236	328	республика Татарстан, Казань, Юлиуса Фучика, 105а	f	large
11725	93236	315	республика Татарстан, Казань, Юлиуса Фучика, 105а	f	large
11676	93212	266	республика Татарстан, Казань, Южно-Промышленная, 3	f	large
11473	93076	63	республика Татарстан, Казань, Эсперанто, 48	f	large
11566	93152	156	республика Татарстан, Казань, Энергетиков, 10	f	large
11517	93111	107	республика Татарстан, Казань, Энгельса, 12	f	medium
11515	93109	105	республика Татарстан, Казань, Шульгина, 19	f	large
11522	93115	112	республика Татарстан, Казань, Шоссейная, 24	f	large
12309	93804	906	республика Татарстан, Казань, Школьная, 2а	f	medium
12464	93979	1061	республика Татарстан, Казань, Школьная, 12	f	small
11680	93215	270	республика Татарстан, Казань, Школьная, 2	f	large
11457	93060	47	республика Татарстан, Казань, Шигабутдина Марджани, 26	f	large
11571	93155	161	республика Татарстан, Казань, Шамиля Усманова, 14	f	large
11573	93156	163	республика Татарстан, Казань, Шамиля Усманова, 30	f	large
11572	93156	162	республика Татарстан, Казань, Шамиля Усманова, 30	f	large
11570	93154	160	республика Татарстан, Казань, Шамиля Усманова, 25Б	f	large
11569	93154	159	республика Татарстан, Казань, Шамиля Усманова, 25Б	f	large
11568	93154	158	республика Татарстан, Казань, Шамиля Усманова, 25Б	f	large
11567	93153	157	республика Татарстан, Казань, Шамиля Усманова, 11к1	f	large
11831	93308	421	республика Татарстан, Казань, Чишмяле, 3	f	large
11830	93308	420	республика Татарстан, Казань, Чишмяле, 3	f	large
11826	93306	416	республика Татарстан, Казань, Чишмяле, 5	f	large
11825	93306	415	республика Татарстан, Казань, Чишмяле, 5	f	large
11672	93207	261	республика Татарстан, Казань, Чистопольская, 63	f	large
11654	93200	243	республика Татарстан, Казань, Чистопольская, 83	f	large
11667	93201	256	республика Татарстан, Казань, Четаева, 29	f	large
11659	93201	248	республика Татарстан, Казань, Четаева, 29	f	large
11658	93201	247	республика Татарстан, Казань, Четаева, 29	f	large
11657	93201	246	республика Татарстан, Казань, Четаева, 29	f	large
13347	584	1944	республика Татарстан, Казань, Центральная, 53	f	small
12692	94204	1289	республика Татарстан, Казань, Центральная, 24	f	small
11448	93052	38	республика Татарстан, Казань, Авиастроительный район, Центральная, 1, санаторий Крутушка	f	medium
13271	502	1868	республика Татарстан, Казань, Центральная, 56	f	large
11711	93231	301	республика Татарстан, Казань, Приволжский район, Хусаина Мавлютова, 15	f	large
11710	93231	300	республика Татарстан, Казань, Приволжский район, Хусаина Мавлютова, 15	f	large
11709	93230	299	республика Татарстан, Казань, Приволжский район, Хусаина Мавлютова, 34	f	large
11708	93230	298	республика Татарстан, Казань, Приволжский район, Хусаина Мавлютова, 34	f	large
11707	93230	297	республика Татарстан, Казань, Приволжский район, Хусаина Мавлютова, 34	f	large
11706	93230	296	республика Татарстан, Казань, Приволжский район, Хусаина Мавлютова, 34	f	large
11587	93168	177	республика Татарстан, Казань, Хлебозаводская, 3	f	large
11593	93172	183	республика Татарстан, Казань, Химиков, 55	f	small
11592	93172	182	республика Татарстан, Казань, Химиков, 55	f	large
11589	93170	179	республика Татарстан, Казань, Химиков, 11	f	large
11778	93271	368	республика Татарстан, Казань, Халитова, 5	f	large
11790	93279	380	республика Татарстан, Казань, Халезова, 18	f	large
11795	93284	385	республика Татарстан, Казань, Халезова, 26	f	large
11791	93280	381	республика Татарстан, Казань, Халезова, 11	f	large
11845	93315	435	республика Татарстан, Казань, Хайдара Бигичева, 26	f	large
11844	93315	434	республика Татарстан, Казань, Хайдара Бигичева, 26	f	large
11472	93075	62	республика Татарстан, Казань, Хади Такташа, 81	f	large
11471	93075	61	республика Татарстан, Казань, Хади Такташа, 81	f	large
11681	93216	271	республика Татарстан, Казань, Ферма-2, Учебный корпус КГАУ	f	large
11647	93197	236	республика Татарстан, Казань, Фатыха Амирхана, 28а	f	large
11646	93197	235	республика Татарстан, Казань, Фатыха Амирхана, 28а	f	large
11645	93197	234	республика Татарстан, Казань, Фатыха Амирхана, 28а	f	large
11625	93190	214	республика Татарстан, Казань, Фатыха Амирхана, 14а	f	large
11624	93190	213	республика Татарстан, Казань, Фатыха Амирхана, 14а	f	large
11623	93188	212	республика Татарстан, Казань, Фатыха Амирхана, 55а	f	large
11622	93188	211	республика Татарстан, Казань, Фатыха Амирхана, 55а	f	large
11619	93188	208	республика Татарстан, Казань, Фатыха Амирхана, 55а	f	large
11481	93082	71	республика Татарстан, Казань, Товарищеская, 40б	f	large
11480	93081	70	республика Татарстан, Казань, Товарищеская, 32	f	large
11565	93151	155	республика Татарстан, Казань, Тверская, 2А	f	large
11564	93151	154	республика Татарстан, Казань, Тверская, 2А	f	large
11456	93059	46	республика Татарстан, Казань, Татарстан, 40	f	large
11431	93037	21	республика Татарстан, Казань, Социалистическая, 5	f	large
11851	93254	441	республика Татарстан, Казань, Советский район, Константиновка микрорайон, Советская, 77А	f	large
11759	93254	349	республика Татарстан, Казань, Советский район, Константиновка микрорайон, Советская, 77А	f	large
11450	93053	40	республика Татарстан, Казань, Симонова, 17	f	large
11449	93031	39	республика Татарстан, Казань, Симонова, 6	f	large
11426	93031	16	республика Татарстан, Казань, Симонова, 6	f	large
11423	93031	13	республика Татарстан, Казань, Симонова, 6	f	large
11779	93272	369	республика Татарстан, Казань, Сибирский тракт, 35	f	medium
11585	93165	175	республика Татарстан, Казань, Серова, 12А	f	large
11584	93165	174	республика Татарстан, Казань, Серова, 12А	f	large
11737	93241	327	республика Татарстан, Казань, Сафиуллина, 56а	f	large
11721	93235	311	республика Татарстан, Казань, Приволжский район, Рихарда Зорге, 71	f	large
11720	93235	310	республика Татарстан, Казань, Приволжский район, Рихарда Зорге, 71	f	large
11447	93051	37	республика Татарстан, Казань, Авиастроительный район, Рихарда Зорге, 2/5	f	large
11537	93130	127	республика Татарстан, Казань, Революционная, 41	f	large
11536	93130	126	республика Татарстан, Казань, Революционная, 41	f	large
11843	93314	433	республика Татарстан, Казань, Рашида Вагапова, 11	f	large
11842	93314	432	республика Татарстан, Казань, Рашида Вагапова, 11	f	large
11841	93314	431	республика Татарстан, Казань, Рашида Вагапова, 11	f	large
11463	93065	53	республика Татарстан, Казань, Пушкина, 31	f	\N
11534	93128	124	республика Татарстан, Казань, Приволжская, 97	f	large
11542	93134	132	республика Татарстан, Казань, Привокзальная, 1	f	medium
11675	93211	265	республика Татарстан, Казань, Поперечно-Кукушкинская, 26	f	medium
11465	93067	55	республика Татарстан, Казань, Вахитовский район, Подлужная, 55	f	\N
11824	93305	414	Россия, республика Татарстан, Казань, Приволжский район, Победы проспект, 108	f	large
11823	93305	413	Россия, республика Татарстан, Казань, Приволжский район, Победы проспект, 108	f	large
11822	93305	412	Россия, республика Татарстан, Казань, Приволжский район, Победы проспект, 108	f	large
11727	93237	317	Россия, республика Татарстан, Казань, Приволжский район, Победы проспект, 48	f	large
11726	93237	316	Россия, республика Татарстан, Казань, Приволжский район, Победы проспект, 48	f	large
11767	93263	357	республика Татарстан, Казань, Пионерская, 10	f	large
11794	93283	384	республика Татарстан, Казань, Парковая, 12	f	large
11785	93276	375	республика Татарстан, Казань, Парковая, 27а	f	large
11784	93276	374	республика Татарстан, Казань, Парковая, 27а	f	large
11804	93292	394	республика Татарстан, Казань, Отрадная, 42	f	large
11499	93098	89	республика Татарстан, Казань, Осиновский переулок, 8	f	large
11700	93226	290	республика Татарстан, Казань, Оренбургский тракт, 48	f	large
11701	93227	291	республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 138	f	large
11695	93223	285	республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 4	f	large
11694	93223	284	республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 4	f	large
11750	93222	340	республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 3	f	large
11693	93222	283	республика Татарстан, Казань, Приволжский район, Оренбургский тракт, 3	f	large
11829	93307	419	республика Татарстан, Казань, Ноксинский Спуск, 17	f	large
11828	93307	418	республика Татарстан, Казань, Ноксинский Спуск, 17	f	large
11827	93307	417	республика Татарстан, Казань, Ноксинский Спуск, 17	f	large
11540	93132	130	республика Татарстан, Казань, Новороссийская, 76	f	large
11679	93214	269	республика Татарстан, Казань, Ново-Давликеевская, 90	f	large
11678	93214	268	республика Татарстан, Казань, Ново-Давликеевская, 90	f	large
11763	93258	353	республика Татарстан, Казань, Николая Ершова, 57а	f	large
11761	93256	351	республика Татарстан, Казань, Николая Ершова, 58	f	large
11477	93080	67	республика Татарстан, Казань, Николая Ершова, 30	f	large
11525	93118	115	республика Татарстан, Казань, Несмелова, 7	f	large
11793	93282	383	республика Татарстан, Казань, Начальная, 15	f	large
11799	93288	389	республика Татарстан, Казань, Научный городок, 2	f	medium
11468	93072	58	республика Татарстан, Казань, Муштари, 6	f	large
11669	93203	258	республика Татарстан, Казань, Мусина, 17	f	large
11666	93203	255	республика Татарстан, Казань, Мусина, 17	f	large
11665	93203	254	республика Татарстан, Казань, Мусина, 17	f	large
11663	93203	252	республика Татарстан, Казань, Мусина, 17	f	large
11621	93189	210	республика Татарстан, Казань, Мусина, 32	f	large
11620	93189	209	республика Татарстан, Казань, Мусина, 32	f	large
11618	93187	207	республика Татарстан, Казань, Мусина, 30а	f	large
11617	93187	206	республика Татарстан, Казань, Мусина, 30а	f	large
11514	93108	104	республика Татарстан, Казань, Музыкальная, 5	f	large
11485	93085	75	республика Татарстан, Казань, Моторная, 31а	f	large
11504	93103	94	республика Татарстан, Казань, Можайского, 16а	f	large
11787	93277	377	республика Татарстан, Казань, Мира, 35	f	large
11786	93277	376	республика Татарстан, Казань, Мира, 35	f	large
11677	93213	267	республика Татарстан, Казань, Матюшинская, 55/2	f	large
11637	93194	226	республика Татарстан, Казань, Маршала Чуйкова, 89а	f	large
11636	93194	225	республика Татарстан, Казань, Маршала Чуйкова, 89а	f	large
11635	93194	224	республика Татарстан, Казань, Маршала Чуйкова, 89а	f	large
11527	93120	117	республика Татарстан, Казань, Мало-Московская, 15	f	large
11526	93119	116	республика Татарстан, Казань, Мало-Московская, 12	f	large
11435	93041	25	республика Татарстан, Казань, Малая Армавирская, 31А	f	large
11420	93028	10	республика Татарстан, Казань, Максимова, 76	f	large
11419	93028	9	республика Татарстан, Казань, Максимова, 76	f	large
11462	93063	52	республика Татарстан, Казань, Мазита Гафури, 34а	f	large
11461	93063	51	республика Татарстан, Казань, Мазита Гафури, 34а	f	large
11433	93039	23	республика Татарстан, Казань, Лядова, 7	f	large
132414	93049	35	республика Татарстан, Казань, улица Лядова, 16, здание школы №112	f	\N
11438	93043	28	республика Татарстан, Казань, Луначарского, 9	f	large
11437	93043	27	республика Татарстан, Казань, Луначарского, 9	f	large
11832	93310	422	республика Татарстан, Казань, Ломжинская, 4	f	large
11796	93285	386	республика Татарстан, Казань, Липатова, 25	f	large
11798	93287	388	республика Татарстан, Казань, Советский район, Большие Дербышки микрорайон, Лесная, 18	f	large
11418	93027	8	республика Татарстан, Казань, Ленинградская, 28	f	large
11417	93026	7	республика Татарстан, Казань, Ленинградская, 28	f	large
11539	93131	129	республика Татарстан, Казань, Лейтенанта Красикова, 16	f	large
11538	93131	128	республика Татарстан, Казань, Лейтенанта Красикова, 16	f	large
11454	93057	44	республика Татарстан, Казань, Лево-Булачная, 14а	f	large
11811	93297	401	республика Татарстан, Казань, Латышских Стрелков, 15	f	large
11580	93162	170	республика Татарстан, Казань, Кулахметова, 21	f	large
11511	93106	101	республика Татарстан, Казань, Краснококшайская, 178	f	large
11510	93106	100	республика Татарстан, Казань, Краснококшайская, 178	f	large
11509	93106	99	республика Татарстан, Казань, Краснококшайская, 178	f	large
11508	93106	98	республика Татарстан, Казань, Краснококшайская, 178	f	large
11819	93303	409	республика Татарстан, Казань, Красной Позиции, 37	f	large
11818	93303	408	республика Татарстан, Казань, Красной Позиции, 37	f	large
11816	93300	406	республика Татарстан, Казань, Красной Позиции, 8А	f	large
11815	93299	405	республика Татарстан, Казань, Красной Позиции, 6а	f	large
11441	93045	31	республика Татарстан, Казань, Котовского, 2	f	large
11552	93143	142	республика Татарстан, Казань, Короленко, 24	f	large
11551	93143	141	республика Татарстан, Казань, Короленко, 24	f	large
11432	93038	22	республика Татарстан, Казань, Копылова, 11	f	large
11429	93035	19	республика Татарстан, Казань, Копылова, 2	f	large
11427	93033	17	республика Татарстан, Казань, Копылова, 13	f	large
11746	93244	336	республика Татарстан, Казань, Комиссара Габишева, 15	f	large
11745	93244	335	республика Татарстан, Казань, Комиссара Габишева, 15	f	large
11744	93244	334	республика Татарстан, Казань, Комиссара Габишева, 15	f	large
11743	93243	333	республика Татарстан, Казань, Комиссара Габишева, 27а	f	large
11742	93243	332	республика Татарстан, Казань, Комиссара Габишева, 27а	f	large
11814	93298	404	республика Татарстан, Казань, Комарова, 12	f	large
11813	93298	403	республика Татарстан, Казань, Комарова, 12	f	large
11812	93298	402	республика Татарстан, Казань, Комарова, 12	f	large
11528	93121	118	республика Татарстан, Казань, Клары Цеткин, 13	f	large
11792	93281	382	республика Татарстан, Казань, Каштановая, 5	f	large
11698	93221	288	республика Татарстан, Казань, Качалова, 107	f	large
11697	93221	287	республика Татарстан, Казань, Качалова, 107	f	large
11692	93221	282	республика Татарстан, Казань, Качалова, 107	f	large
11469	93073	59	республика Татарстан, Казань, Катановский переулок, 1	f	large
11467	93071	57	республика Татарстан, Казань, Карла Маркса, 68	f	large
11451	93054	41	республика Татарстан, Казань, Карла Маркса, 10	f	large
11458	93061	48	республика Татарстан, Казань, Карима Тинчурина, 3	f	large
11474	93077	64	республика Татарстан, Казань, Зеленая, 1	f	large
11533	93127	123	республика Татарстан, Казань, Звездная, 15	f	large
11531	93124	121	республика Татарстан, Казань, Затонская, 12	f	medium
11501	93100	91	республика Татарстан, Казань, Залесная, 2а	f	large
11834	93311	424	республика Татарстан, Казань, Закиева, 31	f	large
11833	93311	423	республика Татарстан, Казань, Закиева, 31	f	large
11452	93055	42	республика Татарстан, Казань, Жуковского, 18	f	large
11421	93029	11	республика Татарстан, Казань, Дунайская, 16	f	large
11747	93245	337	республика Татарстан, Казань, Дубравная, 45	f	large
11749	93245	339	республика Татарстан, Казань, Дубравная, 45	f	large
11748	93245	338	республика Татарстан, Казань, Дубравная, 45	f	large
11728	93238	318	республика Татарстан, Казань, Дубравная, 51а	f	large
11765	93261	355	республика Татарстан, Казань, Дружбы, 1	f	large
11479	93079	69	республика Татарстан, Казань, Достоевского, 51	f	large
11476	93079	66	республика Татарстан, Казань, Достоевского, 51	f	large
11475	93078	65	республика Татарстан, Казань, Достоевского, 51а	f	large
11478	93068	68	республика Татарстан, Казань, Достоевского, 79	f	large
11783	93275	373	республика Татарстан, Казань, Дорожная, 32А	f	large
11782	93275	372	республика Татарстан, Казань, Дорожная, 32А	f	large
11849	93316	439	республика Татарстан, Казань, Джаудата Файзи, 8	f	large
11848	93316	438	республика Татарстан, Казань, Джаудата Файзи, 8	f	large
11847	93316	437	республика Татарстан, Казань, Джаудата Файзи, 8	f	large
11846	93316	436	республика Татарстан, Казань, Джаудата Файзи, 8	f	large
132418	93208	262	республика Татарстан, Казань, Деревня Универсиады, 2, здание общежития	f	\N
11428	93034	18	республика Татарстан, Казань, Дементьева, 18	f	large
11425	93032	15	республика Татарстан, Казань, Дементьева, 70А	f	large
11414	93024	4	республика Татарстан, Казань, Дементьева, 39	f	large
11424	93024	14	республика Татарстан, Казань, Дементьева, 39	f	large
11563	93150	153	республика Татарстан, Казань, Декабристов, 89	f	large
11562	93150	152	республика Татарстан, Казань, Декабристов, 89	f	large
11561	93149	151	республика Татарстан, Казань, Декабристов, 89А	f	large
11556	93145	146	республика Татарстан, Казань, Декабристов, 156А	f	large
11555	93145	145	республика Татарстан, Казань, Декабристов, 156А	f	large
11547	93140	137	республика Татарстан, Казань, Декабристов, 2	f	large
11809	93295	399	республика Татарстан, Казань, Даурская, 32	f	large
11810	93296	400	республика Татарстан, Казань, Даурская, 26	f	large
11808	93294	398	республика Татарстан, Казань, Даурская, 30	f	large
11850	93317	440	республика Татарстан, Казань, Грачиная, 33	f	large
11412	93022	2	республика Татарстан, Казань, Граничная, 2	f	large
11411	93022	1	республика Татарстан, Казань, Граничная, 2	f	large
11466	93070	56	республика Татарстан, Казань, Горького, 16	f	large
11503	93102	93	республика Татарстан, Казань, Горьковское шоссе, 24	f	large
11521	93114	111	республика Татарстан, Казань, Горсоветская, 2	f	large
11575	93158	165	республика Татарстан, Казань, Городская, 2	f	large
11652	93186	241	республика Татарстан, Казань, Голубятникова, 18	f	large
11616	93186	205	республика Татарстан, Казань, Голубятникова, 18	f	large
11615	93186	204	республика Татарстан, Казань, Голубятникова, 18	f	large
11614	93186	203	республика Татарстан, Казань, Голубятникова, 18	f	large
11605	93182	194	республика Татарстан, Казань, Голубятникова, 31	f	large
11604	93182	193	республика Татарстан, Казань, Голубятникова, 31	f	large
11715	93232	305	республика Татарстан, Казань, Гарифьянова, 7	f	large
11714	93232	304	республика Татарстан, Казань, Гарифьянова, 7	f	large
11713	93232	303	республика Татарстан, Казань, Гарифьянова, 7	f	large
11712	93232	302	республика Татарстан, Казань, Гарифьянова, 7	f	large
11586	93167	176	республика Татарстан, Казань, Галимджана Баруди, 25а	f	large
11764	93260	354	республика Татарстан, Казань, Галеева, 3а	f	large
11574	93157	164	республика Татарстан, Казань, Гагарина, 101А	f	large
11560	93147	150	республика Татарстан, Казань, Гагарина, 26а	f	large
11559	93147	149	республика Татарстан, Казань, Гагарина, 26а	f	large
11558	93147	148	республика Татарстан, Казань, Гагарина, 26а	f	large
11601	93181	190	республика Татарстан, Казань, Гагарина, 18а	f	large
11603	93180	192	республика Татарстан, Казань, Гагарина, 8	f	large
11602	93180	191	республика Татарстан, Казань, Гагарина, 8	f	large
11600	93180	189	республика Татарстан, Казань, Гагарина, 8	f	large
11455	93058	45	республика Татарстан, Казань, Габдуллы Тукая, 26	f	large
11773	93266	363	республика Татарстан, Казань, Восьмого Марта, 10	f	large
11576	93159	166	республика Татарстан, Казань, Восход, 29	f	large
11579	93161	169	республика Татарстан, Казань, Восстания, 80	f	large
11578	93161	168	республика Татарстан, Казань, Восстания, 80	f	large
11557	93146	147	республика Татарстан, Казань, Восстания, 36	f	large
11599	93178	188	республика Татарстан, Казань, Воровского, 13	f	\N
11470	93074	60	республика Татарстан, Казань, Волкова, 3	f	large
11613	93185	202	республика Татарстан, Казань, Волгоградская, 39	f	large
11612	93185	201	республика Татарстан, Казань, Волгоградская, 39	f	large
11611	93184	200	республика Татарстан, Казань, Волгоградская, 26	f	large
11610	93184	199	республика Татарстан, Казань, Волгоградская, 26	f	large
11609	93184	198	республика Татарстан, Казань, Волгоградская, 26	f	large
11686	93218	276	республика Татарстан, Казань, Владимира Кулагина, 2	f	large
11685	93218	275	республика Татарстан, Казань, Владимира Кулагина, 2	f	large
11684	93218	274	республика Татарстан, Казань, Владимира Кулагина, 2	f	large
11705	93229	295	республика Татарстан, Казань, Братьев Касимовых, 12	f	large
11704	93229	294	республика Татарстан, Казань, Братьев Касимовых, 12	f	large
11703	93229	293	республика Татарстан, Казань, Братьев Касимовых, 12	f	large
11699	93225	289	республика Татарстан, Казань, улица Братьев Касимовых, 12	f	large
11487	93086	77	республика Татарстан, Казань, Братская, 1	f	large
11486	93086	76	республика Татарстан, Казань, Братская, 1	f	large
11484	93084	74	республика Татарстан, Казань, Бойничная, 8	f	large
11530	93123	120	республика Татарстан, Казань, Боевая, 161	f	medium
11529	93122	119	республика Татарстан, Казань, Боевая, 15	f	large
11535	93129	125	республика Татарстан, Казань, Бирюзовая, 24	f	large
11440	93044	30	республика Татарстан, Казань, Беломорская, 144	f	large
11439	93044	29	республика Татарстан, Казань, Беломорская, 144	f	large
11434	93040	24	республика Татарстан, Казань, Белинского, 39	f	large
11583	93164	173	республика Татарстан, Казань, Батыршина, 15	f	large
11582	93164	172	республика Татарстан, Казань, Батыршина, 15	f	large
11460	93062	50	республика Татарстан, Казань, Ахтямова, 26	f	large
11459	93062	49	республика Татарстан, Казань, Ахтямова, 26	f	large
11483	93083	73	республика Татарстан, Казань, Амирхана Еники, 23	f	large
11482	93083	72	республика Татарстан, Казань, Амирхана Еники, 23	f	large
11500	93099	90	республика Татарстан, Казань, Алтынова, 2	f	large
11774	93267	364	республика Татарстан, Казань, Александра Попова, 21	f	large
11772	93265	362	республика Татарстан, Казань, Александра Попова, 16	f	large
11771	93265	361	республика Татарстан, Казань, Александра Попова, 16	f	large
11766	93262	356	республика Татарстан, Казань, Александра Попова, 3	f	large
11840	93313	430	республика Татарстан, Казань, Академика Сахарова, 8	f	large
11839	93313	429	республика Татарстан, Казань, Академика Сахарова, 8	f	large
11838	93313	428	республика Татарстан, Казань, Академика Сахарова, 8	f	large
11837	93313	427	республика Татарстан, Казань, Академика Сахарова, 8	f	large
11836	93312	426	республика Татарстан, Казань, Академика Сахарова, 9	f	large
11835	93312	425	республика Татарстан, Казань, Академика Сахарова, 9	f	large
11634	93193	223	республика Татарстан, Казань, Академика Лаврентьева, 18а	f	large
11633	93193	222	республика Татарстан, Казань, Академика Лаврентьева, 18а	f	large
11632	93193	221	республика Татарстан, Казань, Академика Лаврентьева, 18а	f	large
11776	93269	366	республика Татарстан, Казань, Академика Губкина, 39/1	f	large
11775	93268	365	республика Татарстан, Казань, Академика Губкина, 11	f	large
11416	93025	6	республика Татарстан, Казань, Айдарова, 10	f	large
11415	93025	5	республика Татарстан, Казань, Айдарова, 10	f	large
11446	93023	36	республика Татарстан, Казань, Айдарова, 2	f	large
11413	93023	3	республика Татарстан, Казань, Айдарова, 2	f	large
11800	93289	390	республика Татарстан, Казань, Азина, 65А	f	large
11644	93196	233	республика Татарстан, Казань, Адоратского, 41а	f	large
11643	93196	232	республика Татарстан, Казань, Адоратского, 41а	f	large
11642	93196	231	республика Татарстан, Казань, Адоратского, 41а	f	large
11641	93196	230	республика Татарстан, Казань, Адоратского, 41а	f	large
11640	93195	229	республика Татарстан, Казань, Адоратского, 36а	f	large
11639	93195	228	республика Татарстан, Казань, Адоратского, 36а	f	large
11638	93195	227	республика Татарстан, Казань, Адоратского, 36а	f	large
11627	93191	216	республика Татарстан, Казань, Адоратского, 25а	f	large
11626	93191	215	республика Татарстан, Казань, Адоратского, 25а	f	large
11802	93290	392	республика Татарстан, Казань, Аделя Кутуя, 84	f	large
11801	93290	391	республика Татарстан, Казань, Аделя Кутуя, 84	f	large
11664	93202	253	республика Татарстан, Казань, Абдуллы Бичурина, 22/26	f	large
11662	93202	251	республика Татарстан, Казань, Абдуллы Бичурина, 22/26	f	large
11661	93202	250	республика Татарстан, Казань, Абдуллы Бичурина, 22/26	f	large
11660	93202	249	республика Татарстан, Казань, Абдуллы Бичурина, 22/26	f	large
11519	93112	109	республика Татарстан, Казань, 2-я Юго-Западная, 27а	f	large
11518	93112	108	республика Татарстан, Казань, 2-я Юго-Западная, 27а	f	large
11777	93270	367	республика Татарстан, Казань, 2-я Азинская, 7а	f	large
11821	93304	411	республика Татарстан, Казань,  Юлиуса Фучика, 147	f	large
11820	93304	410	республика Татарстан, Казань,  Юлиуса Фучика, 147	f	large
11523	93116	113	республика Татарстан, Казань,  Шоссейная, 20	f	large
11513	93107	103	республика Татарстан, Казань,  Чкалова, 8	f	large
11512	93107	102	республика Татарстан, Казань,  Чкалова, 8	f	large
11668	93204	257	республика Татарстан, Казань,  Четаева, 37	f	large
11656	93199	245	республика Татарстан, Казань,  Четаева, 1	f	large
11655	93199	244	республика Татарстан, Казань,  Четаева, 1	f	large
11653	93199	242	республика Татарстан, Казань,  Четаева, 1	f	large
11591	93171	181	республика Татарстан, Казань,  Химиков, 41а	f	large
11590	93171	180	республика Татарстан, Казань,  Химиков, 41а	f	large
11674	93210	264	республика Татарстан, Казань,  Учительская, 2	f	large
11807	93293	397	республика Татарстан, Казань,  Рихарда Зорге, 1а	f	large
11806	93293	396	республика Татарстан, Казань,  Рихарда Зорге, 1а	f	large
11805	93293	395	республика Татарстан, Казань,  Рихарда Зорге, 1а	f	large
11422	93030	12	республика Татарстан, Казань,  Побежимова, 47а	f	large
11762	93257	352	республика Татарстан, Казань,  Николая Ершова, 55	f	large
11532	93125	122	республика Татарстан, Казань,  Минусинская, 1а	f	large
11516	93110	106	республика Татарстан, Казань,  Лукницкого, 1	f	large
11770	93264	360	республика Татарстан, Казань,  Космонавтов, 19	f	large
11769	93264	359	республика Татарстан, Казань,  Космонавтов, 19	f	large
11768	93264	358	республика Татарстан, Казань,  Космонавтов, 19	f	large
11548	93141	138	республика Татарстан, Казань,  Короленко, 26а	f	large
11741	93242	331	республика Татарстан, Казань,  Комиссара Габишева, 33а	f	large
11740	93242	330	республика Татарстан, Казань,  Комиссара Габишева, 33а	f	large
11739	93242	329	республика Татарстан, Казань,  Комиссара Габишева, 33а	f	large
11702	93228	292	республика Татарстан, Казань,  Карбышева, 64	f	large
11520	93113	110	республика Татарстан, Казань,  Дежнева, 1	f	large
11442	93046	32	республика Татарстан, Казань,  Гудованцева, 26	f	large
11719	93234	309	республика Татарстан, Казань,  Братьев Касимовых, 68	f	large
11718	93234	308	республика Татарстан, Казань,  Братьев Касимовых, 68	f	large
11717	93233	307	республика Татарстан, Казань,  Братьев Касимовых, 52	f	large
11716	93233	306	республика Татарстан, Казань,  Братьев Касимовых, 52	f	large
11691	93220	281	республика Татарстан, Казань,  Ботаническая, 7	f	large
11690	93220	280	республика Татарстан, Казань,  Ботаническая, 7	f	large
11689	93220	279	республика Татарстан, Казань,  Ботаническая, 7	f	large
11817	93301	407	республика Татарстан, Казань,  Аделя Кутуя, 4а	f	large
11803	93291	393	республика Татарстан, Казань,  Аделя Кутуя, 114	f	large
11780	93273	370	республика Татарстан, Казань,  Агрызская, 59	f	large
11781	93274	371	республика Татарстан, Казань,  4-я Станционная, 5	f	medium
12932	132	1529	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Юности, 3	f	large
12933	132	1530	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Юности, 3	f	large
12935	135	1532	республика Татарстан, Зеленодольский муниципальный район, город Зеленодольск, Чапаева, 1	f	large
12937	137	1534	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Чайковского, 56	f	large
12942	142	1539	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Хазиева, 2	f	large
12941	142	1538	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Хазиева, 2	f	large
12918	119	1515	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Украинская, 4	f	large
12917	119	1514	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Украинская, 4	f	large
12919	120	1516	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Тургенева, 19	f	large
132488	140	1537	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Столичная, 27А, здание филиала КНИТУ-КАИ	f	\N
12949	148	1546	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Сайдашева, 4	f	large
12922	124	1519	республика Татарстан, Зеленодольский район, Зеленодольск, Рогачева, 4	f	large
12946	145	1543	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Маршала Жукова, 3	f	large
12929	129	1526	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Ленина, 46	f	large
12916	118	1513	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Ленина, 13	f	large
12927	127	1524	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Космонавтов, 13	f	large
12926	127	1523	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Космонавтов, 13	f	large
12945	144	1542	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Королева, 2	f	large
12950	147	1547	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Комарова, 22А	f	large
12948	147	1545	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Комарова, 22А	f	large
12944	143	1541	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Комарова, 15А	f	large
12943	143	1540	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Комарова, 15А	f	large
12915	117	1512	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Кирпичная, 40	f	medium
12936	136	1533	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Каюма Насыри, 13А	f	large
12934	134	1531	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Каюма Насыри, 13А	f	large
12923	125	1520	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Карла Маркса, 20	f	large
12921	122	1518	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Карла Маркса, 7	f	large
12947	146	1544	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Жукова, 9	f	large
12939	139	1536	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Дальняя, 1А	f	large
12930	130	1527	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Гоголя, 60	f	large
12925	126	1522	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Гоголя, 40А	f	large
12924	126	1521	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Гоголя, 40А	f	large
12920	121	1517	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Гоголя, 5	f	large
12931	131	1528	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Гастелло, 4	f	large
12938	138	1535	республика Татарстан, Зеленодольский муниципальный район, Зеленодольск, Гаринская, 38Б	f	large
12863	65	1460	республика Татарстан, Заинск, просп. Победы, 1/18	f	large
12862	65	1459	республика Татарстан, Заинск, просп. Победы, 1/18	f	large
12785	94308	1382	республика Татарстан, Елабуга, Административное здание ООО Стахеевская	f	small
12818	27	1415	республика Татарстан, Елабужский муниципальный район, Елабуга, Административное здание АО Елабужская Керамика	f	small
12810	20	1407	республика Татарстан, Елабуга, просп. Мира, 59	f	large
12809	20	1406	республика Татарстан, Елабуга, просп. Мира, 59	f	large
12805	15	1402	республика Татарстан, Елабужский муниципальный район, Елабуга, пр.Нефтяников, 24	f	medium
12801	15	1398	республика Татарстан, Елабужский муниципальный район, Елабуга, пр.Нефтяников, 24	f	large
12796	10	1393	республика Татарстан, Елабужский муниципальный район, Елабуга, пр.Нефтяников, 82	f	small
12795	9	1392	республика Татарстан, Елабужский муниципальный район, Елабуга, пр.Нефтяников, 109	f	large
12806	17	1403	республика Татарстан, Елабуга, пр. Мира, 15а	f	large
12803	17	1400	республика Татарстан, Елабуга, пр. Мира, 15а	f	large
12814	24	1411	республика Татарстан, Елабужский муниципальный район, Елабуга, пр. Мира, 26	f	large
12808	19	1405	республика Татарстан, Елабужский муниципальный район, Елабуга, пр. Мира, 39	f	large
12807	19	1404	республика Татарстан, Елабужский муниципальный район, Елабуга, пр. Мира, 39	f	large
12792	3	1389	республика Татарстан, Елабуга, Тугарова, 28	f	large
12789	3	1386	республика Татарстан, Елабуга, Тугарова, 28	f	large
12791	5	1388	республика Татарстан, Елабужский муниципальный район, Елабуга, Тугарова, 6	f	large
12815	25	1412	республика Татарстан, Елабужский муниципальный район, Елабуга, Строителей, 16	f	large
12800	14	1397	республика Татарстан, Елабужский муниципальный район, Елабуга, Строителей, 6	f	large
12799	13	1396	республика Татарстан, Елабужский муниципальный район, Елабуга, Строителей, 5	f	medium
12798	12	1395	республика Татарстан, Елабужский муниципальный район, Елабуга, Разведчиков, 41	f	large
12813	23	1410	республика Татарстан, Елабужский муниципальный район, Елабуга, Пролетарская, 48	f	large
12812	23	1409	республика Татарстан, Елабужский муниципальный район, Елабуга, Пролетарская, 48	f	large
12811	22	1408	республика Татарстан, Елабужский муниципальный район, Елабуга, Пролетарская, 36	f	large
12804	18	1401	республика Татарстан, Елабужский муниципальный район, Елабуга, Пролетарская, 1а	f	small
12797	11	1394	республика Татарстан, Елабужский муниципальный район, Елабуга, Набережная, 7	f	medium
12802	16	1399	республика Татарстан, Елабужский муниципальный район, Елабуга, Молодежная, 4	f	large
12820	28	1417	республика Татарстан, Елабужский муниципальный район, Елабуга, Марджани, 26	f	large
12819	26	1416	республика Татарстан, Елабужский муниципальный район, Елабуга, Марджани, 54	f	large
12817	26	1414	республика Татарстан, Елабужский муниципальный район, Елабуга, Марджани, 54	f	large
12816	26	1413	республика Татарстан, Елабужский муниципальный район, Елабуга, Марджани, 54	f	large
12793	6	1390	республика Татарстан, Елабужский муниципальный район, Елабуга, Казанская, 15	f	large
12786	1	1383	республика Татарстан, Елабужский муниципальный район, Елабуга, Казанская, 91	f	large
12787	1	1384	республика Татарстан, Елабужский муниципальный район, Елабуга, Казанская, 91	f	large
12790	4	1387	республика Татарстан, Елабуга, Горького, 84	f	large
132485	7	1391	республика Татарстан, Елабужский муниципальный район, Елабуга, Говорова, 3, здание школы №2	f	\N
12788	2	1385	республика Татарстан, Елабужский муниципальный район, Елабуга, Азина, 177	f	large
12713	94228	1310	республика Татарстан, село Высокая Гора, Полковая, 16	f	large
12711	94224	1308	республика Татарстан, село Высокая Гора, Большая Красная, 113А	f	large
132471	94167	1259	республика Татарстан, село Верхний Услон, Чехова, 37, здание Палаты имущественных и земельных отнош-ий	f	\N
12661	94165	1258	республика Татарстан, село Верхний Услон, Чехова, 76	f	\N
12660	94164	1257	республика Татарстан, село Верхний Услон, Чехова, 34	f	medium
12589	94090	1186	республика Татарстан, Буинск, Строительная, 2	f	large
12587	94088	1184	республика Татарстан, Буинск, Строительная, 4	f	medium
12575	94075	1172	республика Татарстан, Буинск, Советская, 9Б	f	large
12581	94081	1178	республика Татарстан, Буинск, Розы Люксембург, 117	f	large
12578	94078	1175	республика Татарстан, Буинск, Розы Люксембург, 65	f	large
132468	94085	1181	республика Татарстан, Буинск, Р.Люксембург, 157/1, здание Центра занятости населения	f	\N
12583	94083	1180	республика Татарстан, Буинск, Р.Люксембург, 157	f	large
12580	94080	1177	республика Татарстан, Буинск, Космовского, 43/39	f	large
12588	94089	1185	республика Татарстан, Буинск, Комсомольская, 7	f	large
12586	94087	1183	республика Татарстан, Буинск, Комсомольская, 32	f	medium
12579	94079	1176	республика Татарстан, Буинск, Карла Маркса, 72	f	large
12576	94076	1173	республика Татарстан, Буинск, Железнодорожная, 43	f	large
12585	94086	1182	республика Татарстан, Буинск, Ефремова, 148	f	large
12582	94082	1179	республика Татарстан, Буинск, Ефремова, 133	f	large
12577	94077	1174	республика Татарстан, Буинск, Гаяза Исхаки, 29	f	large
12513	94023	1110	республика Татарстан, Бугульма, Ярослава Гашека, 3	f	large
12512	94023	1109	республика Татарстан, Бугульма, Ярослава Гашека, 3	f	large
12530	94031	1127	республика Татарстан, Бугульма, Чайковского, 2В	f	large
12529	94031	1126	республика Татарстан, Бугульма, Чайковского, 2В	f	large
12540	94037	1137	республика Татарстан, Бугульма, Тухачевского, 12	f	large
12539	94036	1136	республика Татарстан, Бугульма, Тупиковая, 6	f	medium
12538	94035	1135	республика Татарстан, Бугульма, Оршанской Дивизии, 61	f	large
12537	94035	1134	республика Татарстан, Бугульма, Оршанской Дивизии, 61	f	large
12536	94034	1133	республика Татарстан, Бугульма, Оршанской Дивизии, 1А	f	large
12535	94034	1132	республика Татарстан, Бугульма, Оршанской Дивизии, 1А	f	medium
12542	94039	1139	республика Татарстан, Бугульма, Орджоникидзе, 2А	f	large
12508	94020	1105	республика Татарстан, Бугульма, Матросова, 13	f	large
12507	94020	1104	республика Татарстан, Бугульма, Матросова, 13	f	large
12541	94038	1138	республика Татарстан, Бугульма, Локомотивная, 28	f	large
12533	94033	1130	республика Татарстан, Бугульма, Ленина, 98	f	large
12534	94033	1131	республика Татарстан, Бугульма, Ленина, 98	f	large
12532	94032	1129	республика Татарстан, Бугульма, Ленина, 137	f	large
12531	94032	1128	республика Татарстан, Бугульма, Ленина, 137	f	large
12509	94021	1106	республика Татарстан, Бугульма, Ленина, 33	f	large
12504	94018	1101	республика Татарстан, Бугульма, Ленина, 9	f	large
12503	94018	1100	республика Татарстан, Бугульма, Ленина, 9	f	large
12505	94018	1102	республика Татарстан, Бугульма, Ленина, 9	f	large
132465	94012	1093	республика Татарстан, Бугульма, Красноармейская , 37А, здание школы №9	f	\N
12495	94011	1092	республика Татарстан, Бугульма, Красноармейская, 37А	f	large
12518	94014	1115	республика Татарстан, Бугульма, Комсомольская, 5	f	large
12497	94014	1094	республика Татарстан, Бугульма, Комсомольская, 5	f	large
12525	94029	1122	республика Татарстан, Бугульма, Калинина, 114	f	large
12524	94029	1121	республика Татарстан, Бугульма, Калинина, 114	f	large
12506	94019	1103	республика Татарстан, Бугульма, Казанская, 12А	f	large
12519	94026	1116	республика Татарстан, Бугульма, Джалиля, 31	f	large
12517	94025	1114	республика Татарстан, Бугульма, Джалиля, 37	f	large
12516	94025	1113	республика Татарстан, Бугульма, Джалиля, 37	f	large
12511	94022	1108	республика Татарстан, Бугульма, Джалиля, 2	f	large
12510	94022	1107	республика Татарстан, Бугульма, Джалиля, 2	f	large
12528	94030	1125	республика Татарстан, Бугульма, Гоголя, 128	f	large
12527	94030	1124	республика Татарстан, Бугульма, Гоголя, 128	f	large
12526	94030	1123	республика Татарстан, Бугульма, Гоголя, 128	f	large
12520	94027	1117	республика Татарстан, Бугульма, Гоголя, 64	f	large
12521	94027	1118	республика Татарстан, Бугульма, Гоголя, 64	f	large
12500	94016	1097	республика Татарстан, Бугульма, Гафиатуллина, 23	f	large
12499	94016	1096	республика Татарстан, Бугульма, Гафиатуллина, 23	f	large
12498	94015	1095	республика Татарстан, Бугульма, Гафиатуллина, 30	f	large
12515	94024	1112	республика Татарстан, Бугульма, Вахитова, 6	f	large
12514	94024	1111	республика Татарстан, Бугульма, Вахитова, 6	f	large
12523	94028	1120	республика Татарстан, Бугульма, 14 Павших, 56	f	large
12522	94028	1119	республика Татарстан, Бугульма, 14 Павших, 56	f	large
12430	93948	1027	республика Татарстан, Бавлы, площадь Победы, 5	f	large
12438	93952	1035	республика Татарстан, Бавлы, Чапаева, 2	f	large
12437	93952	1034	республика Татарстан, Бавлы, Чапаева, 2	f	large
12434	93950	1031	республика Татарстан, Бавлы, Салиха Сайдашева, 25	f	large
12433	93950	1030	республика Татарстан, Бавлы, Салиха Сайдашева, 25	f	large
12432	93950	1029	республика Татарстан, Бавлы, Салиха Сайдашева, 25	f	large
12431	93949	1028	республика Татарстан, Бавлы, Куйбышева, 36	f	large
12428	93946	1025	республика Татарстан, Бавлы, Горюнова, 9	f	large
12436	93951	1033	республика Татарстан, Бавлы, Вахитова, 8	f	large
12435	93951	1032	республика Татарстан, Бавлы, Вахитова, 8	f	large
12439	93943	1036	республика Татарстан, поселок Бавлы, Татарстан, 1	f	large
12425	93943	1022	республика Татарстан, поселок Бавлы, Татарстан, 1	f	large
12424	93942	1021	республика Татарстан, поселок Бавлы, Пионерская, 18	f	large
12427	93945	1024	республика Татарстан, поселок Бавлы, Ленина, 13	f	large
12426	93944	1023	республика Татарстан, поселок Бавлы, Ленина, 17	f	medium
12341	93836	938	республика Татарстан, Арск, Советская площадь, 17	f	large
12351	93846	948	республика Татарстан, Арск, Молодежная, 1б	f	\N
12350	93845	947	республика Татарстан, Арск, Луговая, 1	f	large
12339	93834	936	республика Татарстан, Арск, Вагизовых, 14	f	large
12338	93833	935	республика Татарстан, Арск, Вагизовых, 11	f	large
12340	93835	937	республика Татарстан, Арск, Большая, 77	f	large
12186	93670	783	Россия, республика Татарстан, Альметьевск	f	\N
12220	93704	817	республика Татарстан, Альметьевск, проспект Строителей, 59	f	large
12214	93698	811	республика Татарстан, Альметьевск, проспект Строителей, 14	f	large
12182	93666	779	республика Татарстан, Альметьевск, просп. Тукая, 11а	f	large
12212	93696	809	республика Татарстан, Альметьевск, пр. Строителей, 2	f	large
12222	93706	819	республика Татарстан, Альметьевск, Шевченко, 136	f	large
12216	93700	813	республика Татарстан, Альметьевск, Шевченко, 132	f	large
12202	93687	799	республика Татарстан, Альметьевск, Шевченко, 98	f	large
12198	93683	795	республика Татарстан, Альметьевск, Шевченко, 82	f	large
12192	93677	789	республика Татарстан, Альметьевск, Чернышевского, 44а	f	large
12191	93676	788	республика Татарстан, Альметьевск, Чапаева, 4	f	medium
12190	93675	787	республика Татарстан, Альметьевск, Чапаева, 4а	f	medium
12225	93710	822	республика Татарстан, Альметьевск, Фахретдина, 67	f	medium
12176	93659	773	республика Татарстан, Альметьевск, Фахретдина, 5	f	large
12184	93668	781	республика Татарстан, Альметьевск, Тимирязева, 39	f	large
12178	93662	775	республика Татарстан, Альметьевск, Тельмана, 57	f	large
12177	93661	774	республика Татарстан, Альметьевск, Тельмана, 86	f	large
12175	93658	772	республика Татарстан, Альметьевск, Тельмана, 48	f	large
12174	93657	771	республика Татарстан, Альметьевск, Тагирова, 33	f	large
12181	93665	778	республика Татарстан, Альметьевск, Сулеймановой, 20	f	large
12209	93694	806	республика Татарстан, Альметьевск, Строителей, 9а	f	large
12211	93694	808	республика Татарстан, Альметьевск, Строителей, 9а	f	large
12172	93655	769	республика Татарстан, Альметьевск, Советская, 45а	f	large
12171	93654	768	республика Татарстан, Альметьевск, Полевая, 1а	f	large
12208	93693	805	республика Татарстан, Альметьевск, Нефтяников, 41	f	large
12206	93691	803	республика Татарстан, Альметьевск, Нефтяников, 14	f	large
12204	93689	801	республика Татарстан, Альметьевск, Нефтяников, 12	f	large
12199	93684	796	республика Татарстан, Альметьевск, Мусы Джалиля, 9	f	large
12205	93690	802	республика Татарстан, Альметьевск, Мира, 10	f	large
12183	93667	780	республика Татарстан, Альметьевск, Маяковского, 40	f	large
12187	93672	784	республика Татарстан, Альметьевск, Лермонтова, 14	f	large
12224	93709	821	республика Татарстан, Альметьевск, Ленина, 1б	f	large
12217	93701	814	республика Татарстан, Альметьевск, Ленина, 157	f	large
12213	93697	810	республика Татарстан, Альметьевск, Ленина, 124	f	large
12203	93688	800	республика Татарстан, Альметьевск, Ленина, 98	f	large
12200	93685	797	республика Татарстан, Альметьевск, Ленина, 37	f	large
12195	93680	792	республика Татарстан, Альметьевск, Ленина, 21	f	large
12185	93669	782	республика Татарстан, Альметьевск, Ленина, 2	f	large
12167	93650	764	республика Татарстан, Альметьевск, Кошевого, 12	f	large
12201	93686	798	республика Татарстан, Альметьевск, Клары Цеткин, 54	f	large
12169	93652	766	республика Татарстан, Альметьевск, Интернациональная, 20	f	large
12196	93681	793	республика Татарстан, Альметьевск, Джалиля, 41	f	large
12218	93702	815	республика Татарстан, Альметьевск, Грузинская, 3	f	large
12180	93664	777	республика Татарстан, Альметьевск, Герцена, 86	f	large
12170	93653	767	республика Татарстан, Альметьевск, Герцена, 86а	f	medium
12215	93699	812	республика Татарстан, Альметьевск, Гафиатуллина, 29А	f	large
12210	93692	807	республика Татарстан, Альметьевск, Гафиатуллина, 28	f	large
12207	93692	804	республика Татарстан, Альметьевск, Гафиатуллина, 28	f	large
12168	93651	765	республика Татарстан, Альметьевск, Волгоградская, 24	f	large
12197	93682	794	республика Татарстан, Альметьевск, Белоглазова, 131а	f	large
12193	93678	790	республика Татарстан, Альметьевск, Белоглазова, 60	f	large
12189	93674	786	республика Татарстан, Альметьевск, Белоглазова, 20	f	large
12223	93707	820	республика Татарстан, Альметьевск, Аминова, 2а	f	large
12179	93663	776	республика Татарстан, Альметьевск, 8-го Марта, 30	f	large
12219	93703	816	республика Татарстан, Альметьевск, 70 лет Октября, 1	f	large
14065	1263	2662	республика Татарстан, село Азьмушкино, Центральная, 35а	f	small
132427	93388	510	республика Татарстан, Азнакаево, Школьная, 2, здание школы №2	f	\N
11926	93400	523	республика Татарстан, Азнакаево, Хасаншиной, 21	f	large
11928	93401	525	республика Татарстан, Азнакаево, Хасанова, 24	f	large
11927	93401	524	республика Татарстан, Азнакаево, Хасанова, 24	f	large
11922	93396	519	республика Татарстан, Азнакаево, Хасанова, 5	f	large
11921	93396	518	республика Татарстан, Азнакаево, Хасанова, 5	f	large
11920	93395	517	республика Татарстан, Азнакаево, Хасанова, 19	f	large
11930	93402	527	республика Татарстан, Азнакаево, Султангалиева, 27	f	large
11929	93402	526	республика Татарстан, Азнакаево, Султангалиева, 27	f	large
11919	93394	516	республика Татарстан, Азнакаево, Султангалиева, 23а	f	large
11918	93393	515	республика Татарстан, Азнакаево, Султангалиева, 21а	f	large
11915	93390	512	республика Татарстан, Азнакаево, Пушкина, 1	f	large
132426	93386	509	республика Татарстан, Азнакаево, Лениногорский тракт, 2а, здание школы №9	f	\N
11911	93385	508	республика Татарстан, Азнакаево, Лениногорский тракт, 2	f	large
11923	93397	520	республика Татарстан, Азнакаево, Ленина, 36	f	large
11916	93391	513	республика Татарстан, Азнакаево, Ленина, 18	f	large
11914	93389	511	республика Татарстан, Азнакаево, Ленина, 1	f	large
11925	93399	522	республика Татарстан, Азнакаево, Гагарина, 9	f	large
11924	93398	521	республика Татарстан, Азнакаево, Гагарина, 9	f	large
11917	93392	514	республика Татарстан, Азнакаево, Булгар, 18	f	large
132419	93338	468	республика Татарстан, Агрыз, Гоголя, 6а, здание детской поликлиники	f	\N
12720	94238	1317	республика Татарстан, высо, поселок ж д ст Высокая Гора, Пролетарская, 1	f	large
14255	1045	2852	республика Татарстан, Ютазинский район, п.г.т.Уруссу, Пушкина, 70	f	medium
14240	1453	2837	республика Татарстан, Ютазинский район, село Яссы-Тугай, Тукая, 21	f	small
14251	1464	2848	республика Татарстан, Ютазинский район, село Ютаза, Загот-Зерно, 68	f	medium
14250	1463	2847	республика Татарстан, Ютазинский район, Ютаза, Дмитрова, 9	f	large
14259	1034	2856	республика Татарстан, Ютазинский район, поселок Уруссу, улица Пушкина, 89	f	medium
14258	1034	2855	республика Татарстан, Ютазинский район, поселок Уруссу, улица Пушкина, 89	f	medium
14254	1034	2851	республика Татарстан, Ютазинский район, поселок Уруссу, улица Пушкина, 89	f	medium
14264	1374	2861	республика Татарстан, Ютазинский район, поселок Уруссу, Уруссинская, 38	f	medium
14263	1349	2860	республика Татарстан, Ютазинский район, поселок Уруссу, Уруссинская, 1Б	f	medium
14262	1300	2859	республика Татарстан, Ютазинский район, поселок Уруссу, Уруссинская, 1А	f	medium
14257	1215	2854	республика Татарстан, Ютазинский район, поселок Уруссу, Уруссинская, 44	f	medium
14260	1251	2857	республика Татарстан, Ютазинский район, поселок Уруссу, Пушкина, 22	f	medium
14261	1251	2858	республика Татарстан, Ютазинский район, поселок Уруссу, Пушкина, 22	f	medium
14256	1079	2853	республика Татарстан, Ютазинский район, поселок Уруссу, Пушкина, 70	f	medium
14265	1409	2862	республика Татарстан, Ютазинский район, поселок Уруссу, Поэта Сирина, 44	f	medium
14267	1447	2864	республика Татарстан, Ютазинский район, поселок Уруссу, Мияссарова, 69	f	medium
14266	1447	2863	республика Татарстан, Ютазинский район, поселок Уруссу, Мияссарова, 69	f	medium
14253	1466	2850	республика Татарстан, Ютазинский район, поселок Уруссу, Луговая, 64	f	medium
14245	1458	2842	республика Татарстан, Ютазинский район, село Урал, Уральская, 10а	f	small
14246	1459	2843	республика Татарстан, Ютазинский район, село Старый Каразерик, Советская, 15	f	medium
8898	54093	45	республика Марий Эл, Йошкар-Ола, Мичурина, 38	f	large
14247	1460	2844	республика Татарстан, Ютазинский район, село Старые Уруссы, Советская, 45 А	f	medium
13817	985	2414	республика Татарстан, Ютазинский район, село Салкын-Чишма, Нариманова, 50	f	small
14249	1462	2846	республика Татарстан, Ютазинский район, село Малые Уруссы, Советская, 18 Б	f	medium
14244	1457	2841	республика Татарстан, Ютазинский район, село Каракашлы, Мирфатиха Закиева, 19	f	medium
14238	1451	2835	республика Татарстан, Ютазинский район, село Дым-Тамак, Ленина, 1в	f	small
14241	1454	2838	республика Татарстан, Ютазинский район, село Байряка, Октября, 1a	f	large
14242	1455	2839	республика Татарстан, Ютазинский район, село Байряка, Новая, 36	f	small
14248	1461	2845	республика Татарстан, Ютазинский район, село Байларово, Тукая, 41	f	small
14252	1465	2849	республика Татарстан, Ютазинский район, село Алма-Ата, Зеленая, 1А	f	small
14239	1452	2836	республика Татарстан, Ютазинский район, Алабакуль, Центральная, 8а	f	small
14236	1449	2833	республика Татарстан, Ютазинский район, село Абсалямово, Советская, 50А	f	medium
14200	1411	2797	республика Татарстан, Чистопольский район, село совхоз Юлдуз, Полевая, 10	f	medium
14234	1446	2831	республика Татарстан, Чистопольский район, село совхоз Луч, Победы, 16	f	large
14222	1434	2819	республика Татарстан, Чистопольский район, село Чулпан, Театральная, 2а	f	small
14217	1429	2814	республика Татарстан, Чистопольский район, село Чувашский Елтан, Школьная, 15в	f	small
14235	1448	2832	республика Татарстан, Чистопольский район, село Чистопольские Выселки, Чапаева, 64А	f	large
14199	1410	2796	республика Татарстан, Чистопольский район, Чистополь, Дорожная, 7	f	\N
14202	1413	2799	республика Татарстан, Чистопольский район, село Четырчи, Зеленая, 12	f	small
14225	1437	2822	республика Татарстан, Чистопольский район, село Четыре Двора, Школьная, 9	f	small
14226	1438	2823	республика Татарстан, Чистопольский район, село Татарское Адельшино, Сатдарова, 32	f	small
14211	1423	2808	республика Татарстан, Чистопольский район, село Татарский Толкиш, Советская, 4	f	small
14210	1421	2807	республика Татарстан, Чистопольский район, село Татарский Сарсаз, Центральная, 13	f	medium
14215	1427	2812	республика Татарстан, Чистопольский район, село Татарский Елтан, Кооперативная, 9	f	small
14221	1433	2818	республика Татарстан, Чистопольский район, село Татарская Багана, Центральная, 35а	f	medium
14207	1418	2804	республика Татарстан, Чистопольский район, село Старое Ромашкино, Центральная, 29	f	small
14229	1441	2826	республика Татарстан, Чистопольский район, село Старое Иванаево, Овражная, 1	f	small
14219	1431	2816	республика Татарстан, Чистопольский район, село Нижняя Кондрата, Комсомольская, 31	f	small
14227	1439	2824	республика Татарстан, Чистопольский район, село Нарат Елга, Центральная, 1	f	small
14223	1435	2820	республика Татарстан, Чистопольский район, село Муслюмкино, Пионерская, 10	f	medium
14205	1416	2802	республика Татарстан, Чистопольский район, село Малый Толкиш, Центральная, 17	f	small
14228	1440	2825	республика Татарстан, Чистопольский район, село Кутлушкино, Клубная, 18	f	small
14231	1443	2828	республика Татарстан, Чистопольский район, село Кубассы, Центральная, 3	f	small
14204	1415	2801	республика Татарстан, Чистопольский район, село Красный Яр, Пришкольная, 1а	f	small
14212	1424	2809	республика Татарстан, Чистопольский район, село Кзыл-Ялан, Гиниятуллина, 22	f	small
14213	1425	2810	республика Татарстан, Чистопольский район, село Кзыл-Болгар, Зеленая, 16а	f	small
14209	1420	2806	республика Татарстан, Чистопольский район, село Каргали, Чапаева, 2а	f	large
14218	1430	2815	республика Татарстан, Чистопольский район, село Ишалькино, Красноармейская, 6	f	small
14208	1419	2805	республика Татарстан, Чистопольский район, село Исляйкино, 8 Марта, 20б	f	small
14214	1426	2811	республика Татарстан, Чистопольский район, село Изгары, Школьная, 13	f	small
14232	1444	2829	республика Татарстан, Чистопольский район, село Данауровка, Центральная, 30а	f	medium
14220	1432	2817	республика Татарстан, Чистопольский район, село Верхняя Кондрата, Ивана Чалмаева, 4	f	small
14201	1412	2798	республика Татарстан, Чистопольский район, село Булдырь, Центральная, 23	f	small
8903	54095	50	республика Марий Эл, Йошкар-Ола, Мира, 25	f	large
14203	1414	2800	республика Татарстан, Чистопольский район, село Большой Толкиш, Набережная, 39	f	small
14233	1445	2830	республика Татарстан, Чистопольский район, село Белая Гора, Центральная, 26	f	small
14224	1436	2821	республика Татарстан, Чистопольский район, село Бахта, Широкая, 48	f	small
14230	1442	2827	республика Татарстан, Чистопольский район, село Байтеряково, Речная, 19	f	small
14206	1417	2803	республика Татарстан, Чистопольский район, село Александровка, Школьная, 7	f	medium
14216	1428	2813	республика Татарстан, Чистопольский район, село Акбулатово, Октябрьская, 26	f	small
14194	1404	2791	республика Татарстан, Чистопольский муниципальный район, Чистополь, Энгельса, 78	f	large
14183	1392	2780	республика Татарстан, Чистопольский муниципальный район, Чистополь, Чернышевского, 167	f	large
14177	1386	2774	республика Татарстан, Чистопольский муниципальный район, Чистополь, Урицкого, 45	f	large
14186	1396	2783	республика Татарстан, Чистопольский муниципальный район, Чистополь, Тукая, 54б	f	large
14181	1390	2778	республика Татарстан, Чистопольский муниципальный район, Чистополь, Студенческая, 1	f	large
14169	1378	2766	республика Татарстан, Чистопольский муниципальный район, Чистополь, Мира, 42	f	large
14173	1382	2770	республика Татарстан, Чистопольский муниципальный район, Чистополь, Льва Толстого, 144	f	large
14187	1397	2784	республика Татарстан, Чистопольский муниципальный район, Чистополь, Крупской, 32	f	large
14182	1391	2779	республика Татарстан, Чистопольский муниципальный район, Чистополь, Карла Маркса, 164	f	large
14180	1389	2777	республика Татарстан, Чистопольский муниципальный район, Чистополь, Карла Маркса, 168	f	large
14179	1388	2776	республика Татарстан, Чистопольский муниципальный район, Чистополь, Карла Маркса, 142	f	large
14175	1384	2772	республика Татарстан, Чистопольский муниципальный район, Чистополь, Карла Маркса, 78	f	large
14193	1403	2790	республика Татарстан, Чистопольский муниципальный район, Чистополь, Гуськова, 18б	f	medium
14172	1381	2769	республика Татарстан, Чистопольский муниципальный район, Чистополь, Бутлерова, 7А	f	large
14174	1383	2771	республика Татарстан, Чистопольский муниципальный район, Чистополь, Бебеля, 121	f	large
14197	1406	2794	республика Татарстан, Чистопольский муниципальный район, Чистополь, Академика Королева, 5	f	large
14196	1406	2793	республика Татарстан, Чистопольский муниципальный район, Чистополь, Академика Королева, 5	f	large
14188	1398	2785	республика Татарстан, Чистопольский муниципальный район, Чистополь, Айвазовского, 81	f	large
14167	1376	2764	республика Татарстан, Черемшанский район, село Шешминская Крепость, Комарова, 14	f	small
14168	1377	2765	республика Татарстан, Черемшанский район, село Чумачка, Ленина, 33	f	small
14166	1375	2763	республика Татарстан, Черемшанский район, село Черный Ключ, Советская, 77	f	small
14162	1370	2759	республика Татарстан, Черемшанский район, село Черемшан, Шешминская, 2	f	small
14163	1371	2760	республика Татарстан, Черемшанский район, село Черемшан, Техническая, 36	f	large
14161	1369	2758	республика Татарстан, Черемшанский район, село Черемшан, Советская, 34	f	large
14165	1373	2762	республика Татарстан, Черемшанский район, село Черемшан, Молодежная, 60	f	small
14164	1372	2761	республика Татарстан, Черемшанский район, село Черемшан, Гагарина, 42	f	medium
14153	1361	2750	республика Татарстан, Черемшанский район, село Утыз Имян, Советская, 51	f	small
14160	1368	2757	республика Татарстан, Черемшанский район, село Ульяновка, Центральная, 46	f	medium
14159	1367	2756	республика Татарстан, Черемшанский район, село Туйметкино, Школьная, 1	f	small
14158	1366	2755	республика Татарстан, Черемшанский район, село Старый Утямыш, Мусы Джалиля, 54	f	small
14157	1365	2754	республика Татарстан, Черемшанский район, село Старые Кутуши, Свежухина, 34	f	small
14156	1364	2753	республика Татарстан, Черемшанский район, село Старое Кадеево, Тукая, 12	f	medium
14155	1363	2752	республика Татарстан, Черемшанский район, село Старое Ильмово, Луговая, 22	f	small
14154	1362	2751	республика Татарстан, Черемшанский район, село Подлесный Утямыш, Советская, 12а	f	small
13982	1178	2579	республика Татарстан, Спасский район, село Урняк, Вахитова, 26А	f	small
14152	1360	2749	республика Татарстан, Черемшанский район, село Новое Ильмово, Ключевая, 15	f	small
14151	1359	2748	республика Татарстан, Черемшанский район, поселок Нижняя Чегодайка, Советская, 36А	f	small
14150	1358	2747	республика Татарстан, Черемшанский район, село Нижняя Кармалка, Ленина, 9	f	small
14149	1357	2746	республика Татарстан, Черемшанский район, село Нижняя Каменка, Центральная, 60	f	small
14148	1356	2745	республика Татарстан, Черемшанский район, село Мордовское Афонькино, Цаплина, 17	f	small
14147	1355	2744	республика Татарстан, Черемшанский район, село Лашманка, Советская, 55	f	medium
14146	1354	2743	республика Татарстан, Черемшанский район, село Лагерка, Школьная, 22	f	small
14145	1353	2742	республика Татарстан, Черемшанский район, село Кутема, Клубная, 1а	f	small
14144	1352	2741	республика Татарстан, Черемшанский район, село Карамышево, Бари Габдрахманова, 44а	f	small
132572	1351	2740	республика Татарстан, Черемшанский район, село Казанка, Школьная, 36, 423100, здание школы	f	\N
14142	1348	2739	республика Татарстан, Черемшанский район, село Ивашкино, Центральная, 36	f	small
14141	1347	2738	республика Татарстан, Черемшанский район, село Верхняя Чегодайка, Советская, 25А	f	small
14140	1346	2737	республика Татарстан, Черемшанский район, село Верхняя Кармалка, Советская, 13	f	small
14139	1345	2736	республика Татарстан, Черемшанский район, село Верхняя Каменка, Дружбы, 6	f	small
14138	1344	2735	республика Татарстан, Черемшанский район, село Беркет-Ключ, Ленина, 75	f	medium
14137	1343	2734	республика Татарстан, Черемшанский район, село Андреевка, Высоцкого, 35/1	f	small
14136	1342	2733	республика Татарстан, Черемшанский район, село Амирово, Школьная, 30	f	small
132571	1341	2732	республика Татарстан, Черемшанский район, село Аккиреево, Школьная, 30, 423113, здание Сельского Дома культуры	f	\N
14120	1322	2717	республика Татарстан, Тюлячинский район, д.Большие Нырсы, Школьная, 5	f	medium
14118	1320	2715	республика Татарстан, Тюлячинский район, село Шармаши, Школьная, 43	f	small
14121	1323	2718	республика Татарстан, Тюлячинский район, село Шадки, Ленина, 2	f	medium
14131	1335	2728	республика Татарстан, Тюлячинский район, село Уруширма, Верхняя, 21А	f	small
14116	1317	2713	республика Татарстан, Тюлячинский район, село Узяк, Татарстан, 4	f	small
132567	1318	2714	республика Татарстан, Тюлячинский район, село Узяк, Каримовой, 1, здание школы	f	\N
14108	1308	2705	республика Татарстан, Тюлячинский район, село Тюлячи, Школьная, 3	f	medium
14109	1309	2706	республика Татарстан, Тюлячинский район, село Тюлячи, Ленина, 82	f	large
14107	1307	2704	республика Татарстан, Тюлячинский район, село Тюлячи, Ленина, 40	f	large
14129	1333	2726	республика Татарстан, Тюлячинский район, село Трюк-Тямти, Центральная, 7	f	small
132566	1314	2710	республика Татарстан, Тюлячинский район, село Субаш, Ленина, 25, здание школы	f	\N
14132	1336	2729	республика Татарстан, Тюлячинский район, село Старый Карабаян, Пушкина, 10	f	small
14115	1316	2712	республика Татарстан, Тюлячинский район, село Старые Зюри, Школьная, 1А	f	medium
14119	1321	2716	республика Татарстан, Тюлячинский район, село Сауш, Сиразетдинова, 47	f	small
132568	1328	2722	республика Татарстан, Тюлячинский район, село Пановая Гора, Нагуманова, 18, здание сельского ДК	f	\N
132569	1331	2724	республика Татарстан, Тюлячинский район, село Малые Кибя Кози, Малая , 10, здание школы	f	\N
14130	1334	2727	республика Татарстан, Тюлячинский район, село Максабаш, Татарстан, 27	f	small
14126	1329	2723	республика Татарстан, Тюлячинский район, село Лесной, Татарстан, 8	f	small
14123	1325	2720	республика Татарстан, Тюлячинский район, село Кукча, Шоссейная, 67	f	small
14128	1332	2725	республика Татарстан, Тюлячинский район, село Верхние Кибя-Кози, Ленина, 1А	f	small
14124	1326	2721	республика Татарстан, Тюлячинский район, село Большие Метески, Фатиха Хусни, 56А	f	small
14111	1311	2708	республика Татарстан, Тюлячинский район, село Большая Меша, Школьная, 2	f	medium
14114	1315	2711	республика Татарстан, Тюлячинский район, село Баландыш, Ленина, 2	f	small
14110	1310	2707	республика Татарстан, Тюлячинский район, село Ачи, Ленина, 31	f	small
14122	1324	2719	республика Татарстан, Тюлячинский район, село Алан-Зире, Октябрьская, 211	f	small
14112	1312	2709	республика Татарстан, Тюлячинский район, село Айдарово, Ленина, 34	f	small
14079	1279	2676	республика Татарстан, Тукаевский район, село п. Совхоза Татарстан, Школьная, 18	f	large
14078	1278	2675	республика Татарстан, Тукаевский район, село п. Совхоза Татарстан, Советская, 2	f	medium
14080	1280	2677	республика Татарстан, Тукаевский район, село п. Совхоза Татарстан, Нагорная, 5	f	medium
14106	1306	2703	республика Татарстан, Тукаевский район, село Янга-Буляк, Тукая, 38	f	small
14103	1303	2700	республика Татарстан, Тукаевский район, село Тлянче-Тамак, Татарстан, 6	f	medium
14102	1302	2699	республика Татарстан, Тукаевский район, село Старый Дрюш, Тукая, 21	f	small
14091	1290	2688	республика Татарстан, Тукаевский район, село Старые Ерыклы, Центральная, 16А	f	medium
14100	1299	2697	республика Татарстан, Тукаевский район, село Старое Абдулово, Центральная, 16	f	small
14098	1297	2695	республика Татарстан, Тукаевский район, село Семекеево, Биктимирова, 42	f	small
14099	1298	2696	республика Татарстан, Тукаевский район, село Саитово, Торговая, 28	f	small
14064	1262	2661	республика Татарстан, Тукаевский район, село Новый, Центральная, 1	f	large
14093	1292	2690	республика Татарстан, Тукаевский район, село Новотроицкое, Ленина, 11	f	medium
14095	1294	2692	республика Татарстан, Тукаевский район, село Нижний Суык-Су, Центральная, 1А	f	medium
14092	1291	2689	республика Татарстан, Тукаевский район, село Мусабай-Завод, Ленина, 33А	f	medium
14090	1289	2687	республика Татарстан, Тукаевский район, село Мелекес, Центральная, 27А	f	medium
132565	1277	2674	республика Татарстан, Тукаевский район, село Малтабарово, Октябрьская, 25, здание начальной школы	f	\N
14086	1285	2683	республика Татарстан, Тукаевский район, село Малая Шильна, Центральная, 1	f	medium
14094	1293	2691	республика Татарстан, Тукаевский район, село Куперле, Большая, 35	f	small
14084	1283	2681	республика Татарстан, Тукаевский район, село Кузкеево, М. Джалиля, 37	f	medium
14097	1296	2694	республика Татарстан, Тукаевский район, село Кувады, Центральная, 35А	f	small
14083	1282	2680	республика Татарстан, Тукаевский район, село Круглое Поле, Гагарина, 11А	f	large
14082	1282	2679	республика Татарстан, Тукаевский район, село Круглое Поле, Гагарина, 11А	f	large
14081	1281	2678	республика Татарстан, Тукаевский район, село Комсомолец, Школьная, 1	f	medium
14076	1275	2673	республика Татарстан, Тукаевский район, село Калмия, Молодежная, 23	f	small
14075	1274	2672	республика Татарстан, Тукаевский район, село Калмаш, Центральная, 32	f	medium
14104	1304	2701	республика Татарстан, Тукаевский район, село Казаклар, Шарипова, 40	f	small
14074	1273	2671	республика Татарстан, Тукаевский район, село Иштеряково, Центральная, 116а	f	medium
14088	1287	2685	республика Татарстан, Тукаевский район, село Ильбухтино, Центральная, 1А	f	small
14096	1295	2693	республика Татарстан, Тукаевский район, село Верхний Суык Су, Центральная, 32Б	f	small
14085	1284	2682	республика Татарстан, Тукаевский район, село Верхний Байлар, Советская, 29	f	small
132564	1271	2670	республика Татарстан, Тукаевский район, село Бурдыбаш, Центральная, 83, здание сельского ДК	f	\N
14072	1270	2669	республика Татарстан, Тукаевский район, село Бурды, Центральная, 64	f	medium
14087	1286	2684	республика Татарстан, Тукаевский район, село Большая Шильна, Кирова, 55	f	small
14071	1269	2668	республика Татарстан, Тукаевский район, село Биюрган, Тойгузино, 1а	f	medium
14070	1268	2667	республика Татарстан, Тукаевский район, село Биклянь, Чкалова, 30а	f	large
14067	1265	2664	республика Татарстан, Тукаевский район, село Бетьки, Гагарина, 1	f	large
14066	1264	2663	республика Татарстан, Тукаевский район, село Бетьки, Гагарина, 2	f	large
14089	1288	2686	республика Татарстан, Тукаевский район, село Белоус, Центральная	f	small
14101	1301	2698	республика Татарстан, Тукаевский муниципальный район, село Мрясево, Сайдашева, 24	f	small
14062	1261	2660	республика Татарстан, Тетюшский район, село Чувашское Черепаново, Ленина, 12	f	small
14060	1258	2658	республика Татарстан, Тетюшский район, село Чувашский Чикилдым, Чапаева, 24	f	small
14061	1259	2659	республика Татарстан, Тетюшский район, село Чинчурино, Школьная, 12	f	small
8902	54095	49	республика Марий Эл, Йошкар-Ола, Мира, 25	f	large
14059	1257	2657	республика Татарстан, Тетюшский район, село Федоровка, Школьная, 1	f	small
14058	1256	2656	республика Татарстан, Тетюшский район, село Урюм, Чапаева, 2	f	small
14056	1255	2655	республика Татарстан, Тетюшский район, село Тоншерма, Ленина, 57	f	small
14010	1206	2614	республика Татарстан, Тетюшский район, Тетюши, Фрунзе, 23	f	large
14018	1214	2622	республика Татарстан, Тетюшский район, Тетюши, Свердлова, 69	f	medium
14012	1208	2616	республика Татарстан, Тетюшский район, Тетюши, Свердлова, 32	f	medium
14011	1207	2615	республика Татарстан, Тетюшский район, Тетюши, Свердлова, 128	f	large
14019	1216	2623	республика Татарстан, Тетюшский район, Тетюши, Малкина, 44	f	large
14016	1212	2620	республика Татарстан, Тетюшский район, Тетюши, Максима Горького, 41	f	large
14014	1210	2618	республика Татарстан, Тетюшский район, Тетюши, Максима Горького, 82	f	large
14015	1211	2619	республика Татарстан, Тетюшский район, Тетюши, Ленина, 89	f	large
14017	1213	2621	республика Татарстан, Тетюшский район, Тетюши, Зеленая, 24	f	small
14013	1209	2617	республика Татарстан, Тетюшский район, Тетюши, 200 лет Тетюшам, 25	f	medium
14025	1223	2629	республика Татарстан, Тетюшский район, село Татарская Беденьга, Вахитова, 41	f	small
14055	1254	2654	республика Татарстан, Тетюшский район, село Сюндюково, Тукая, 14	f	small
14054	1252	2653	республика Татарстан, Тетюшский район, село Пролей-Каша, Октябрьская, 21	f	small
14053	1250	2652	республика Татарстан, Тетюшский район, село Починок-Новольяшево, Центральная, 3	f	small
14051	1249	2651	республика Татарстан, Тетюшский район, село Нармонка, Школьная, 1	f	small
14050	1248	2650	республика Татарстан, Тетюшский район, село Монастырское, Комсомольская, 33	f	small
14047	1245	2648	республика Татарстан, Тетюшский район, село Малые Атряси, Зиганшина, 61	f	small
14049	1247	2649	республика Татарстан, Тетюшский район, село Малое Шемякино, Центральная, 19	f	small
14046	1244	2647	республика Татарстан, Тетюшский район, село Льяшево, Пролетарская, 22а	f	small
14045	1243	2646	республика Татарстан, Тетюшский район, село Лаптевка, Гагарина, 2	f	small
14044	1241	2645	республика Татарстан, Тетюшский район, село Кушкуй, Ленина, 26	f	small
14043	1240	2644	республика Татарстан, Тетюшский район, село Кошки-Новотимбаево, Яковлева, 4	f	small
14041	1239	2643	республика Татарстан, Тетюшский район, село Кляшево, Гагарина, 15	f	small
14040	1238	2642	республика Татарстан, Тетюшский район, село Киртели, Гагарина, 21Б	f	small
14039	1237	2641	республика Татарстан, Тетюшский район, село Кильдюшево, Молодежная, 22	f	small
14036	1234	2639	республика Татарстан, Тетюшский район, село Кашка, Центральная, 19	f	small
14037	1236	2640	республика Татарстан, Тетюшский район, село Иоково, Первомайская, 1	f	small
14035	1233	2638	республика Татарстан, Тетюшский район, село Жуково, Верхняя, 7	f	small
14034	1232	2637	республика Татарстан, Тетюшский район, село Вожжи, Центральная, 28	f	small
132563	1231	2636	республика Татарстан, Тетюшский район, село Верхние Тарханы, Ленина, 21/1, здание СДК	f	\N
14032	1230	2635	республика Татарстан, Тетюшский район, село Большое Шемякино, Кутузова, 1	f	small
14028	1227	2632	республика Татарстан, Тетюшский район, село Большое Бисярино, Школьная, 25	f	small
14029	1220	2633	республика Татарстан, Тетюшский район, село Большие Тарханы, Горького, 7	f	small
14027	1226	2631	республика Татарстан, Тетюшский район, село Большие Атряси, Молодежная, 8	f	small
14031	1228	2634	республика Татарстан, Тетюшский район, село Большая Турма, Мусина, 57а	f	small
14026	1224	2630	республика Татарстан, Тетюшский район, село Богдашкино, Гагарина, 4	f	small
14024	1222	2628	республика Татарстан, Тетюшский район, село Бессоново, Стахановская, 12	f	small
14023	1221	2627	республика Татарстан, Тетюшский район, село Бакрчи, Гагарина, 25	f	small
14022	1219	2626	республика Татарстан, Тетюшский район, село Байрашево, М. Джалиля, 72	f	small
14021	1218	2625	республика Татарстан, Тетюшский район, село Алекина Поляна, Молодежная, 1	f	small
14020	1217	2624	республика Татарстан, Тетюшский район, село Алабердино, Ленина, 71	f	small
14004	1200	2601	республика Татарстан, Спасский район, село Ямбухтино, Центральная, 17	f	small
14006	1202	2603	республика Татарстан, Спасский район, село Чэчэкле (Новый Баран), Центральная, 9	f	small
13995	1191	2592	республика Татарстан, Спасский район, село Тукай, Г.Тукая, 33В	f	small
13981	1177	2578	республика Татарстан, Спасский район, село Три Озера, Школьная, 58	f	\N
13999	1195	2596	республика Татарстан, Спасский район, село Татарская Тахтала, Центральная, 57А	f	small
13985	1181	2582	республика Татарстан, Спасский район, село Танкеевка, 70 лет Октября, 28	f	small
14007	1203	2604	республика Татарстан, Спасский район, село Средний Юрткуль, Центральная, 32	f	small
13988	1184	2585	республика Татарстан, Спасский район, село Приволжский, Школьная, 1	f	small
13983	1179	2580	республика Татарстан, Спасский район, село Полянки, Центральная, 26	f	small
13990	1186	2587	республика Татарстан, Спасский район, село Отрада, Клубная, 28	f	small
13989	1185	2586	республика Татарстан, Спасский район, село Никольское, Буденного, 20	f	medium
13992	1188	2589	республика Татарстан, Спасский район, село Куралово, 60 лет Октября, 15А	f	small
14005	1201	2602	республика Татарстан, Спасский район, село Кузнечиха, Советская, 18	f	small
13987	1183	2584	республика Татарстан, Спасский район, село Красный Вал, Новая, 2	f	small
13986	1182	2583	республика Татарстан, Спасский район, село Красная Слобода, Школьная, 2 А	f	small
13994	1190	2591	республика Татарстан, Спасский район, село Ким, Клубная, 4	f	medium
14001	1197	2598	республика Татарстан, Спасский район, село Каюки, Советская, 23	f	small
14009	1205	2606	республика Татарстан, Спасский район, село Иске-Рязяп, Ленина, 56	f	medium
14002	1198	2599	республика Татарстан, Спасский район, село Измери, Школьная, 8	f	small
14008	1204	2605	республика Татарстан, Спасский район, село Иж-Борискино, Центральная, 97	f	small
13993	1189	2590	республика Татарстан, Спасский район, село Екатериновка, Центральная, 14А	f	small
13997	1193	2594	республика Татарстан, Спасский район, село Гусиха, Школьная, 26	f	small
14003	1199	2600	республика Татарстан, Спасский район, село Вожи, Бугровская, 85	f	small
14000	1196	2597	республика Татарстан, Спасский район, село Бураково, Молодежная, 41	f	small
13991	1187	2588	республика Татарстан, Спасский район, село Бугровка, Спирькова, 50	f	small
13974	1171	2571	республика Татарстан, Спасский район, Болгар, Советская, 46	f	medium
13980	1175	2577	республика Татарстан, Спасский район, Болгар, Рабочая, 10	f	medium
13979	1175	2576	республика Татарстан, Спасский район, Болгар, Рабочая, 10	f	medium
13973	1170	2570	республика Татарстан, Спасский район, Болгар, Пионерская, 44	f	medium
13972	1169	2569	республика Татарстан, Спасский район, Болгар, Пионерская, 40А	f	medium
13971	1169	2568	республика Татарстан, Спасский район, Болгар, Пионерская, 40А	f	medium
13978	1174	2575	республика Татарстан, Спасский район, Болгар, Октябрьская, 59	f	medium
13977	1174	2574	республика Татарстан, Спасский район, Болгар, Октябрьская, 59	f	medium
13976	1173	2573	республика Татарстан, Спасский район, Болгар, Ленина, 108	f	medium
13975	1172	2572	республика Татарстан, Спасский район, Болгар, Гордеева, 1	f	medium
13984	1180	2581	республика Татарстан, Спасский район, село Балымеры, Садовая, 27	f	small
13996	1192	2593	республика Татарстан, Спасский район, село Антоновка, Советская, 57	f	small
13998	1194	2595	республика Татарстан, Спасский район, село Аграмаковка, Куйбышева, 1В	f	small
13919	1114	2516	республика Татарстан, Сармановский район, село Яхшы-Каран, Родниковая, 1а	f	small
13955	1153	2552	республика Татарстан, Сармановский район, село Янурусово, Ленина, 43А	f	small
13916	1111	2513	республика Татарстан, Сармановский район, село Юлтимирово, Набережная, 5	f	small
13917	1112	2514	республика Татарстан, Сармановский район, село Шигаево, Шоссейная, 18А	f	small
13939	1136	2536	республика Татарстан, Сармановский район, село Шарлиарема, Школьная, 57	f	small
13925	1121	2522	республика Татарстан, Сармановский район, село Чурашево, М. Джалиля, 81А	f	small
13953	1151	2550	республика Татарстан, Сармановский район, село Чукмарлы, Советская, 41	f	small
13948	1146	2545	республика Татарстан, Сармановский район, село Сырысаз-Такерман, К. Маркса, 1В	f	small
13938	1135	2535	республика Татарстан, Сармановский район, село Сулюково, Школьная, 56	f	small
13946	1144	2543	республика Татарстан, Сармановский район, село Сулы-Саклово, М.Джалиля, 21а	f	small
8901	54094	48	республика Марий Эл, Йошкар-Ола, Мира, 61	f	large
13952	1150	2549	республика Татарстан, Сармановский район, село Старый Мензелябаш, 50 лет Октября, 75	f	medium
13950	1148	2547	республика Татарстан, Сармановский район, село Старый Кашир, Комсомольская, 4А	f	small
13947	1145	2544	республика Татарстан, Сармановский район, село Старый Имян, М. Вахитова, 36В	f	small
13949	1147	2546	республика Татарстан, Сармановский район, село Средний Кашир, Х. Такташа, 38А	f	small
13958	1156	2555	республика Татарстан, Сармановский район, село Сарманово, Энергетиков, 1	f	medium
13960	1158	2557	республика Татарстан, Сармановский район, село Сарманово, Терешковой, 8	f	large
13956	1154	2553	республика Татарстан, Сармановский район, село Сарманово, Сельхозтехники, 25	f	medium
13961	1159	2558	республика Татарстан, Сармановский район, село Сарманово, М. Джалиля, 63	f	large
13957	1155	2554	республика Татарстан, Сармановский район, село Сарманово, Ленина, 1Б	f	large
13959	1157	2556	республика Татарстан, Сармановский район, село Сарманово, Куйбышева, 31	f	medium
13929	1125	2526	республика Татарстан, Сармановский район, село Сарайлы, М. Джалиля, 37А	f	small
13945	1142	2542	республика Татарстан, Сармановский район, село Саклов-Баш, Ленина, 93А	f	medium
13944	1141	2541	республика Татарстан, Сармановский район, село Рантамак, Вахитова, 51	f	small
13943	1140	2540	республика Татарстан, Сармановский район, село Рангазар, Советская, 48	f	small
13940	1137	2537	республика Татарстан, Сармановский район, село Петровский Завод, Поперечная, 2А	f	medium
13936	1133	2533	республика Татарстан, Сармановский район, село Новый Имян, М. Джалиля, 25А	f	small
13962	1160	2559	республика Татарстан, Сармановский район, село Новое Ахметово, Ленина, 9	f	small
13928	1124	2525	республика Татарстан, Сармановский район, село Нижний Лешев, 40 лет Победы, 38А	f	small
13941	1138	2538	республика Татарстан, Сармановский район, село Мустафино, Октрябрьская, 14А	f	small
13932	1128	2529	республика Татарстан, Сармановский район, село Муртыш-Тамак, Советская, 47	f	small
13922	1118	2519	республика Татарстан, Сармановский район, село Муртыш-Баш, Школьная, 18	f	small
13931	1127	2528	республика Татарстан, Сармановский район, село Ляки, Школьная, 5	f	small
13927	1123	2524	республика Татарстан, Сармановский район, село Лешев-Тамак, Советская, 1Б	f	small
13926	1122	2523	республика Татарстан, Сармановский район, село Лешев-Тамак, Молодежная, 1А	f	small
13935	1132	2532	республика Татарстан, Сармановский район, село Кутемели, Гагарина, 39	f	small
13933	1129	2530	республика Татарстан, Сармановский район, село Кульметьево, Хисамова, 9	f	small
13951	1149	2548	республика Татарстан, Сармановский район, село Кузяково, Советская, 64	f	small
13954	1152	2551	республика Татарстан, Сармановский район, село Каташ-Каран, Ленина, 45А	f	small
13924	1120	2521	республика Татарстан, Сармановский район, село Карашай-Саклово, Ленина, 100	f	small
13923	1119	2520	республика Татарстан, Сармановский район, село Кавзияково, Советская, 14А	f	medium
13921	1116	2518	республика Татарстан, Сармановский район, село Иляксаз, Комсомольская, 2	f	small
13942	1139	2539	республика Татарстан, Сармановский район, село Димитарлау, Советская, 7/1	f	small
13970	1168	2567	республика Татарстан, Сармановский район, поселок Джалиль, Лесная, 25	f	large
13969	1167	2566	республика Татарстан, Сармановский район, поселок Джалиль, Лесная, 10	f	large
13965	1163	2562	республика Татарстан, Сармановский район, поселок Джалиль, Ленина, 21	f	large
13968	1166	2565	республика Татарстан, Сармановский район, поселок Джалиль, Ахмадиева, 20	f	large
13967	1165	2564	республика Татарстан, Сармановский район, поселок Джалиль, Ахмадиева, 39А	f	medium
13966	1164	2563	республика Татарстан, Сармановский район, поселок Джалиль, Ахмадиева, 23	f	large
13964	1162	2561	республика Татарстан, Сармановский район, поселок Джалиль, 30 лет Победы, 6	f	large
13963	1161	2560	республика Татарстан, Сармановский район, поселок Джалиль, 30 лет Победы, 1	f	large
13930	1126	2527	республика Татарстан, Сармановский район, село Верхние Чершилы, Ленина, 40А	f	small
13934	1131	2531	республика Татарстан, Сармановский район, село Буралы-Чишма, Советская, 12А	f	small
13602	777	2199	республика Татарстан, Нижнекамский район, Нижнекамск, Тукая, 15	f	large
13937	1134	2534	республика Татарстан, Сармановский район, село Большое Нуркеево, Школьная, 34	f	small
13920	1115	2517	республика Татарстан, Сармановский район, село Альметьево, Ленина, 56А	f	small
13918	1113	2515	республика Татарстан, Сармановский район, село Александровка, Школьная, 7	f	medium
13915	1110	2512	республика Татарстан, Сармановский район, село Азалаково, Советская, 22А	f	small
132561	1108	2511	республика Татарстан, Сабинский район, село Юлбат, Г.Тукая, 57	f	\N
13908	1101	2505	республика Татарстан, Сабинский район, село Шикши, Школьная, 1	f	medium
13911	1105	2508	республика Татарстан, Сабинский район, поселок Шемордан, Х. Такташа, 3	f	large
13912	1106	2509	республика Татарстан, Сабинский район, поселок Шемордан, Фрунзе, 5a	f	large
13909	1102	2506	республика Татарстан, Сабинский район, поселок Шемордан, Первомайская, 41	f	large
13910	1103	2507	республика Татарстан, Сабинский район, поселок Шемордан, Лермонтова, 2	f	large
132558	1069	2477	республика Татарстан, Сабинский район, село Уют, Ленина, 39	f	\N
13888	1078	2485	республика Татарстан, Сабинский район, село Туктар, Советская, 39а	f	small
13905	1098	2502	республика Татарстан, Сабинский район, село Тимершик, Пионерская, 3	f	medium
13904	1097	2501	республика Татарстан, Сабинский район, село Старая Икшурма, улица Пушкина, 2	f	medium
13893	1085	2490	республика Татарстан, Сабинский район, село Ст.Мичан, Школьная, 12	f	small
13902	1095	2499	республика Татарстан, Сабинский район, село Сатышево, Советская, 24	f	medium
13892	1084	2489	республика Татарстан, Сабинский район, село Сабабаш, Школьная, 1	f	small
13885	1075	2482	республика Татарстан, Сабинский район, село Олуяз, Ленина, 18	f	small
13890	1082	2487	республика Татарстан, Сабинский район, село Нижний Отар, М. Джалиля, 62	f	small
132560	1087	2492	республика Татарстан, Сабинский район, село Нижние Шитцы, Тукая, 1а	f	\N
13913	1107	2510	республика Татарстан, Сабинский район, село Мичанбаш, Советская, 31	f	small
13907	1100	2504	республика Татарстан, Сабинский район, село Мингер, Татарстан, 23	f	small
13903	1096	2500	республика Татарстан, Сабинский район, село Мамалаево, Чапаева, 6	f	small
13891	1083	2488	республика Татарстан, Сабинский район, поселок Лесхоз, Детсадовская, 26	f	medium
13906	1099	2503	республика Татарстан, Сабинский район, село Кызыл-Меша, Ленина, 32	f	small
13894	1086	2491	республика Татарстан, Сабинский район, село Кренни, Школьная, 16	f	small
132559	1080	2486	республика Татарстан, Сабинский район, село Корсабаш, Советская, 18	f	\N
12373	93876	970	республика Татарстан, Сабинский район, поселок Корса, Школьная, 48	f	small
13887	1077	2484	республика Татарстан, Сабинский район, село Кильдебяк, Кооперативная, 20А	f	small
13884	1074	2481	республика Татарстан, Сабинский район, село Илебер, Восьмого Марта, 50	f	small
13883	1073	2480	республика Татарстан, Сабинский район, село Измя, Школьная, 5	f	small
13882	1072	2479	республика Татарстан, Сабинский район, село Евлаштау, Ш. Бариева, 11	f	medium
132557	1065	2472	республика Татарстан, Сабинский район, село Два Поля Арташ, Школьная, 12	f	\N
13881	1071	2478	республика Татарстан, Сабинский район, село Верхний Симет, Советская, 32	f	small
13896	1089	2493	республика Татарстан, Сабинский район, село Верхние Шитцы, Ленина, 31	f	small
13879	1068	2476	республика Татарстан, Сабинский район, село Большой Шинар, Кооперативная, 37	f	medium
13878	1067	2475	республика Татарстан, Сабинский район, село Большие Нырты, М. Джалиля, 13а	f	small
13876	1066	2473	республика Татарстан, Сабинский район, село Большие Кибячи, Ф. Энгельса, 75	f	medium
13899	1092	2496	республика Татарстан, Сабинский район, село Богатые Сабы, Школьная, 50	f	large
13901	1094	2498	республика Татарстан, Сабинский район, село Богатые Сабы, М. Джалиля, 2	f	large
13900	1093	2497	республика Татарстан, Сабинский район, село Богатые Сабы, Кол Гали, 40	f	large
13898	1091	2495	республика Татарстан, Сабинский район, село Богатые Сабы, З. Юсупова, 22	f	large
13897	1090	2494	республика Татарстан, Сабинский район, село Богатые Сабы, Г. Закирова, 27	f	large
13828	997	2425	республика Татарстан, Рыбно-Слободский район, село Янчиково, 40 лет Победы, 23	f	small
13872	1061	2469	республика Татарстан, Рыбно-Слободский район, село Ямашево, Татарстан, 1а	f	small
13871	1060	2468	республика Татарстан, Рыбно-Слободский район, село Юлсубино, Татарстан, 44а	f	small
13866	1053	2463	республика Татарстан, Рыбно-Слободский район, село Шутнево-Тулуши, М.Джалиля, 18	f	\N
13870	1058	2467	республика Татарстан, Рыбно-Слободский район, село Шумково, Центральная, 6а	f	\N
13868	1055	2465	республика Татарстан, Рыбно-Слободский район, село Шумбут, Советская, 18	f	small
13843	1016	2440	республика Татарстан, Рыбно-Слободский район, село Шетнево-Черемышево, Советская, 20	f	small
13863	1047	2460	республика Татарстан, Рыбно-Слободский район, село Шеморбаш, Советская, 47	f	\N
13861	1042	2458	республика Татарстан, Рыбно-Слободский район, село Урахча, Советская, 20б	f	\N
13860	1041	2457	республика Татарстан, Рыбно-Слободский район, село Троицкий Урай, Прикамская, 1	f	small
13847	1021	2444	республика Татарстан, Рыбно-Слободский район, село Тебердино-Челны, Гагарина, 34	f	small
13865	1050	2462	республика Татарстан, Рыбно-Слободский район, село Тавларово, Ленина, 50а	f	\N
13826	995	2423	республика Татарстан, Рыбно-Слободский район, село Старый Арыш, Центральная, 25	f	small
13869	1057	2466	республика Татарстан, Рыбно-Слободский район, Село Шестая Речка, Лесная, 6	f	\N
13854	1035	2451	республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода, Ленина, 46а	f	large
13859	1040	2456	республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода, Заводская, 6а	f	medium
13855	1036	2452	республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода, З.Шаймарданова, 58	f	large
13856	1037	2453	республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода, Больничный переулок, 6	f	medium
13858	1039	2455	республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода, 60 лет Октября, 9	f	large
13857	1038	2454	республика Татарстан, Рыбно-Слободский район, село Рыбная Слобода, 60 лет Октября, 1	f	large
12083	93562	680	республика Татарстан, Рыбно-Слободский район, село Русский Ошняк, Хай Вахита, 11	f	small
13853	1033	2450	республика Татарстан, Рыбно-Слободский район, село Русский Ошняк, Профсоюзная, 7а	f	\N
13874	1063	2471	республика Татарстан, Рыбно-Слободский район, село Полянка, Механизаторов, 3б	f	medium
13831	1001	2428	республика Татарстан, Рыбно-Слободский район, село Околоток-Янгасала, Калинина, 102	f	small
13852	1030	2449	республика Татарстан, Рыбно-Слободский район, село Новый Арыш, Центральная, 49	f	\N
13867	1054	2464	республика Татарстан, Рыбно-Слободский район, село Новая Ирга, Школьная, 48	f	small
13851	1028	2448	республика Татарстан, Рыбно-Слободский район, село Нижний Тимерлек, Школьная, 47а	f	\N
13862	1044	2459	республика Татарстан, Рыбно-Слободский район, село Мельничный Починок, Кирова, 23	f	\N
13849	1023	2446	республика Татарстан, Рыбно-Слободский район, село Масловка, Центральная, 13	f	\N
13848	1022	2445	республика Татарстан, Рыбно-Слободский район, село Мамли-Козяково-Челны, Центральная, 27	f	small
13838	1009	2435	республика Татарстан, Рыбно-Слободский район, село Малый Ошняк, Красноармейская, 32а	f	small
13829	998	2426	республика Татарстан, Рыбно-Слободский район, село Малый Атмас, Гагарина, 11а	f	\N
13846	1019	2443	республика Татарстан, Рыбно-Слободский район, село Кутлу-Букаш, Советская, 28	f	\N
13873	1062	2470	республика Татарстан, Рыбно-Слободский район, село Кукеево, Н. Гиззатуллина, 36а	f	medium
13844	1017	2441	республика Татарстан, Рыбно-Слободский район, село Кугарчино, Советская, 43а	f	medium
13842	1015	2439	республика Татарстан, Рыбно-Слободский район, село Корноухово, Совхозная, 8	f	small
13840	1012	2437	республика Татарстан, Рыбно-Слободский район, село Козяково-Челны, Иванова, 26	f	small
13845	1018	2442	республика Татарстан, Рыбно-Слободский район, село Зянгаркуль, Г.Тукая, 3а	f	small
13834	1004	2431	республика Татарстан, Рыбно-Слободский район, село Дон-Урай, Садовый переулок, 2	f	small
13850	1027	2447	республика Татарстан, Рыбно-Слободский район, село Верхний Тимерлек, Советская, 72а	f	\N
13839	1010	2436	республика Татарстан, Рыбно-Слободский район, село Большой Салтан, Шарафеева, 12а	f	\N
13837	1007	2434	республика Татарстан, Рыбно-Слободский район, село Большой Ошняк, Г.Тукая, 28а	f	\N
13601	777	2198	республика Татарстан, Нижнекамский район, Нижнекамск, Тукая, 15	f	large
13835	1005	2432	республика Татарстан, Рыбно-Слободский район, село Большой Машляк, Ленина, 15а	f	small
13833	1003	2430	республика Татарстан, Рыбно-Слободский район, село Большая Кульга, Школьная, 11	f	small
13832	1002	2429	республика Татарстан, Рыбно-Слободский район, село Большая Елга, Октябрьская, 25	f	medium
13836	1006	2433	республика Татарстан, Рыбно-Слободский район, село Бикчураево, Горького, 11	f	small
13830	1000	2427	республика Татарстан, Рыбно-Слободский район, село Биектау, Сафиуллина, 1	f	medium
13827	996	2424	республика Татарстан, Рыбно-Слободский район, село Бетьки, Мира, 2	f	small
13841	1014	2438	республика Татарстан, Рыбно-Слободский район, село Бердибяково, Школьная, 5	f	small
13825	994	2422	республика Татарстан, Рыбно-Слободский район, село Балыклы-Чукаево, Центральная, 8	f	small
13824	993	2421	республика Татарстан, Рыбно-Слободский район, село Анатыш, Клубная, 17	f	medium
13864	1049	2461	республика Татарстан, Рыбно-Слободский район, село Алан-Полян, Якова Емельянова, 6	f	small
13823	992	2420	республика Татарстан, Пестречинский район, село Янцевары, Центральная, 1	f	small
13821	989	2418	республика Татарстан, Пестречинский район, село Шали, Хайруллина, 35	f	large
13820	988	2417	республика Татарстан, Пестречинский район, село Шали, Хайруллина, 32	f	large
13819	987	2416	республика Татарстан, Пестречинский район, село Чита, Кооперативная, 84	f	small
13818	986	2415	республика Татарстан, Пестречинский район, село Татарское Ходяшево, Советская, 15а	f	medium
13822	990	2419	республика Татарстан, Пестречинский район, село Старое Шигалеево, Центральная, 14	f	medium
13816	984	2413	республика Татарстан, Пестречинский район, село Пимери, Советская, 25а	f	small
13815	983	2412	республика Татарстан, Пестречинский район, село Пестрецы, Советская, 7	f	large
13814	982	2411	республика Татарстан, Пестречинский район, село Пестрецы, Советская, 9	f	large
13813	981	2410	республика Татарстан, Пестречинский район, село Пестрецы, Молодежная, 1	f	large
13812	980	2409	республика Татарстан, Пестречинский район, село Пестрецы, Казанская, 7	f	large
13811	979	2408	республика Татарстан, Пестречинский район, село Пестрецы, Казанская, 7а	f	large
13810	978	2407	республика Татарстан, Пестречинский район, село Пановка, Центральная, 7а	f	medium
13809	977	2406	республика Татарстан, Пестречинский район, село Отар-Дубровка, Центральная, 6	f	small
13808	976	2405	республика Татарстан, Пестречинский район, село Надеждино, Школьная, 1	f	small
13806	974	2403	республика Татарстан, Пестречинский район, село Ленино-Кокушкино, Центральная, 17	f	large
13807	975	2404	республика Татарстан, Пестречинский район, село Ленино-Кокушкино, Техническая, 10	f	large
13805	973	2402	республика Татарстан, Пестречинский район, село Кулаево, Молодежная, 22а	f	large
13804	972	2401	республика Татарстан, Пестречинский район, село Кряш-Серда, Татарстан, 6а	f	small
13803	971	2400	республика Татарстан, Пестречинский район, село Кощаково, Центральная, 19	f	large
13802	970	2399	республика Татарстан, Пестречинский район, село Конь, Советская, 61а	f	medium
13801	969	2398	республика Татарстан, Пестречинский район, село Ковали, Школьная, 1	f	small
13800	968	2397	республика Татарстан, Пестречинский район, село Кобяково, Тукая, 28	f	small
13799	967	2396	республика Татарстан, Пестречинский район, село Кибячи, Пионерская, 9	f	small
13798	965	2395	республика Татарстан, Пестречинский район, село Карповка, Советская, 37	f	small
13797	964	2394	республика Татарстан, Пестречинский район, село Званка, Приозерная, 19	f	small
13796	963	2393	республика Татарстан, Пестречинский район, село Екатериновка, Школьная, 2	f	small
13795	962	2392	республика Татарстан, Пестречинский район, село Богородское, Центральная, 46	f	medium
13794	961	2391	республика Татарстан, Пестречинский район, село Белкино, Школьная, 87	f	small
13756	915	2353	республика Татарстан, Нурлатский район, село Якушкино, Школьная, 2	f	small
13767	928	2364	республика Татарстан, Нурлатский район, село Чулпаново, Центральная, 2А	f	medium
13792	959	2389	республика Татарстан, Нурлатский район, село Чувашский Тимерлек, Центральная, 3	f	small
11873	93340	470	республика Татарстан, Агрызский район, Агрыз, Карла Маркса, 108	f	large
13753	912	2350	республика Татарстан, Нурлатский район, село Чувашская Менча, Шоссейная, 25	f	small
13751	910	2348	республика Татарстан, Нурлатский район, село Чишма, Кооперативная, 65	f	small
132536	926	2362	республика Татарстан, Нурлатский район, село Фомкино, Школьная, 18, здание школы	f	\N
13780	946	2377	республика Татарстан, Нурлатский район, село Тюрнясево, Школьная, 22	f	medium
13791	958	2388	республика Татарстан, Нурлатский район, село Турнояс, Лесная, 26	f	small
13759	919	2356	республика Татарстан, Нурлатский район, село Степное Озеро, Школьная, 21	f	medium
13778	944	2375	республика Татарстан, Нурлатский район, село Старые Челны, Ленина, 6	f	medium
13787	954	2384	республика Татарстан, Нурлатский район, село Старое Альметьево, Октябрьская, 19	f	medium
13785	952	2382	республика Татарстан, Нурлатский район, село Старая Татарская Амзя, Карла Маркса, 5	f	small
132539	938	2371	республика Татарстан, Нурлатский район, село Средняя Камышла, Школьная, 31, здание школы	f	\N
13782	948	2379	республика Татарстан, Нурлатский район, село Селенгуши, Гагарина, 32	f	small
13758	918	2355	республика Татарстан, Нурлатский район, село Салдакаево, Центральная, 14	f	small
132538	935	2368	республика Татарстан, Нурлатский район, село Русское Богдашкино, Школьная, 14А, здание школы	f	\N
13790	957	2387	республика Татарстан, Нурлатский район, село Октябрина, Садовая, 3	f	small
13744	903	2341	республика Татарстан, Нурлатский район, Нурлат, Нурлатская, 8	f	large
13738	897	2335	республика Татарстан, Нурлатский район, Нурлат, Куйбышева, 47	f	large
13750	909	2347	республика Татарстан, Нурлатский район, село Новое Иглайкино, Пушкина, 5	f	medium
13793	960	2390	республика Татарстан, Нурлатский район, село Новая Тумба, Шоссейная, 1	f	small
13784	951	2381	республика Татарстан, Нурлатский район, село Новая Амзя, Ленина, 12	f	small
13779	945	2376	республика Татарстан, Нурлатский район, село Нижние Челны, Ленина, 1	f	small
13781	947	2378	республика Татарстан, Нурлатский район, село Мамыково, Тельмана, 51	f	medium
13777	943	2374	республика Татарстан, Нурлатский район, село Курманаево, Клубная, 3	f	medium
13788	955	2385	республика Татарстан, Нурлатский район, село Кульбаево-Мараса, Ленина, 30	f	medium
13760	920	2357	республика Татарстан, Нурлатский район, село Кривое Озеро, Центральная, 76	f	small
132540	950	2380	республика Татарстан, Нурлатский район, село Кичкальня, Школьная, 17, здание школы	f	\N
13786	953	2383	республика Татарстан, Нурлатский район, село Кзыл-Юл, Октябрьская, 8	f	small
13773	937	2370	республика Татарстан, Нурлатский район, село Караульная Гора, Школьная, 27	f	medium
13761	921	2358	республика Татарстан, Нурлатский район, село Илюткино, Клубная, 10	f	small
13768	930	2365	республика Татарстан, Нурлатский район, село Заречный, Центральная, 4	f	small
13766	927	2363	республика Татарстан, Нурлатский район, село Ерыкла, Школьная, 34Г	f	small
13752	911	2349	республика Татарстан, Нурлатский район, село Ерепкино, Кирова, 9	f	small
13789	956	2386	республика Татарстан, Нурлатский район, село Елаур, Центральная, 25	f	small
13772	936	2369	республика Татарстан, Нурлатский район, село Егоркино, Центральная, 33	f	medium
13763	923	2360	республика Татарстан, Нурлатский район, село Гайтанкино, Центральная, 13	f	small
13775	940	2372	республика Татарстан, Нурлатский район, село Вишневая Поляна, Школьная, 5	f	small
13769	931	2366	республика Татарстан, Нурлатский район, село Бутаиха, Лесозаводская, 12	f	small
13776	942	2373	республика Татарстан, Нурлатский район, село Бурметьево, Центральная, 1А	f	medium
13762	922	2359	республика Татарстан, Нурлатский район, село Биляр-Озеро, Зеленая, 48А	f	small
13764	924	2361	республика Татарстан, Нурлатский район, село Бикулово, Школьная, 23А	f	small
13755	914	2352	республика Татарстан, Нурлатский район, село Ахметьево, Центральная, 48	f	small
132537	933	2367	республика Татарстан, Нурлатский район, село Андреевка, Советская, 39А, здание школы	f	\N
13754	913	2351	республика Татарстан, Нурлатский район, село Аксумла, Центральная, 51	f	small
13757	917	2354	республика Татарстан, Нурлатский район, село Абрыскино, Гагарина, 59А	f	small
13743	902	2340	республика Татарстан, Нурлатский муниципальный район, Нурлат, Школьная, 9	f	large
13745	904	2342	республика Татарстан, Нурлатский муниципальный район, Нурлат, Самаренкина, 4	f	large
13747	906	2344	республика Татарстан, Нурлатский муниципальный район, Нурлат, Нижненурлатская, 19	f	medium
13739	898	2336	республика Татарстан, Нурлатский муниципальный район, Нурлат, Мугинова, 10	f	large
13741	900	2338	республика Татарстан, Нурлатский муниципальный район, Нурлат, Мира, 9	f	large
13749	908	2346	республика Татарстан, Нурлатский муниципальный район, Нурлат, Клубная, 1	f	small
13740	899	2337	республика Татарстан, Нурлатский муниципальный район, Нурлат, Дружба, 68	f	large
13742	901	2339	республика Татарстан, Нурлатский муниципальный район, Нурлат, Гиматдинова, 83	f	large
13748	907	2345	республика Татарстан, Нурлатский муниципальный район, Нурлат, Верхненурлатская, 32	f	medium
13715	874	2312	республика Татарстан, Новошешминский район, село совхоз Красный Октябрь, Центральная, 21	f	medium
13732	892	2329	республика Татарстан, Новошешминский район, село Шахмайкино, Центральная, 45	f	small
13730	889	2327	республика Татарстан, Новошешминский район, село Чувашская Чебоксарка, Чапаева, 3б	f	small
13734	894	2331	республика Татарстан, Новошешминский район, село Чертушкино, Центральная, 32а	f	small
13728	887	2325	республика Татарстан, Новошешминский район, село Татарское Утяшкино, Центральная, 10	f	medium
13731	890	2328	республика Татарстан, Новошешминский район, село Слобода Черемуховая, Пролетарская, 47	f	medium
13725	884	2322	республика Татарстан, Новошешминский район, село Слобода Петропавловская, Ленина, 33	f	medium
13712	871	2309	республика Татарстан, Новошешминский район, село Слобода Екатерининская, Центральная, 49	f	small
13711	870	2308	республика Татарстан, Новошешминский район, село Слобода Волчья, Центральная, 29	f	small
13710	869	2307	республика Татарстан, Новошешминский район, село Слобода Архангельская, Горького, 21а	f	small
13729	888	2326	республика Татарстан, Новошешминский район, село Русская Чебоксарка, Речная, 6	f	small
13733	893	2330	республика Татарстан, Новошешминский район, село Простые Челны, Центральная, 58	f	small
13720	879	2317	республика Татарстан, Новошешминский район, село Новошешминск, Школьная, 5	f	small
13721	880	2318	республика Татарстан, Новошешминский район, село Новошешминск, Набережная, 2	f	medium
13727	886	2324	республика Татарстан, Новошешминский район, село Новошешминск, Молодежная, 94	f	small
13724	883	2321	республика Татарстан, Новошешминский район, село Новошешминск, Ленина, 92а	f	medium
13723	882	2320	республика Татарстан, Новошешминский район, село Новошешминск, Заливная, 4	f	medium
13722	881	2319	республика Татарстан, Новошешминский район, село Новошешминск, Заливная, 5	f	medium
13716	875	2313	республика Татарстан, Новошешминский район, село Новопоселенная Лебедка, Центральная, 36	f	small
13713	872	2310	республика Татарстан, Новошешминский район, село Новое Иванаево, Молодежная, 1	f	small
13718	877	2315	республика Татарстан, Новошешминский район, село Ленино, Центральная, 89	f	small
13714	873	2311	республика Татарстан, Новошешминский район, село Ерыклы, Ленина, 53	f	medium
13717	876	2314	республика Татарстан, Новошешминский район, село Деревня Екатериновка, Центральная, 19	f	small
13719	878	2316	республика Татарстан, Новошешминский район, село Горшково, Луговая, 54	f	small
13726	885	2323	республика Татарстан, Новошешминский район, село Андреевка, Центральная, 12	f	small
13709	868	2306	республика Татарстан, Новошешминский район, Акбуре, Комсомольская, 30	f	small
13708	867	2305	республика Татарстан, Новошешминский район, село Азеево, Советская, 20	f	small
13678	836	2275	республика Татарстан, Нижнекамский район, село Шингальчи, Школьная, 34	f	medium
132535	852	2289	республика Татарстан, Нижнекамский район, село Шереметьевка, Октябрьская площадь, 18а, здание дома культуры	f	\N
13682	841	2279	республика Татарстан, Нижнекамский район, село Туба, Чапаева, 18	f	small
13690	850	2287	республика Татарстан, Нижнекамский район, село Трудовой, Школьная, 11	f	small
132533	838	2276	республика Татарстан, Нижнекамский район, село Ташлык, Центральная, 28а, здание библиотеки	f	\N
8900	54092	47	республика Марий Эл, Йошкар-Ола, Мира, 91А	f	large
13684	843	2281	республика Татарстан, Нижнекамский район, село Сухарево, Пролетарская, 12	f	medium
13702	863	2299	республика Татарстан, Нижнекамский район, село Старошешминск, Нижнекамская, 24	f	large
132532	832	2273	республика Татарстан, Нижнекамский район, поселок Прости, Школьная, 8, здание школы	f	\N
13695	855	2292	республика Татарстан, Нижнекамский район, село Нижняя Уратьма, Гагарина, 45а	f	medium
132534	848	2286	республика Татарстан, Нижнекамский район, село Нижние Челны, Красноармейская, 51, здание библиотеки	f	\N
13673	829	2270	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Химиков, 13	f	large
13672	829	2269	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Химиков, 13	f	large
13671	828	2268	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Химиков, 13А	f	large
13668	825	2265	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Химиков, 41	f	large
13666	823	2263	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Строителей, 47	f	large
13665	823	2262	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Строителей, 47	f	large
13657	819	2254	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 60	f	large
13653	817	2250	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 45	f	large
13652	817	2249	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 45	f	large
13651	815	2248	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 16	f	large
13650	815	2247	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 16	f	large
13649	815	2246	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 16	f	large
13648	814	2245	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 21	f	large
13647	814	2244	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Мира, 21	f	large
13623	796	2220	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Вахитова, 2А	f	large
13622	796	2219	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Вахитова, 2А	f	large
13621	795	2218	республика Татарстан, Нижнекамский район, Нижнекамск, проспект Вахитова, 13	f	large
13670	827	2267	республика Татарстан, Нижнекамский район, Нижнекамск, пр.Химиков, 29	f	large
13667	824	2264	республика Татарстан, Нижнекамский район, Нижнекамск, пр.Химиков, 45	f	large
13607	782	2204	республика Татарстан, Нижнекамский район, Нижнекамск, пр.Химиков, 35	f	large
13595	772	2192	республика Татарстан, Нижнекамск городской округ, пр.Химиков, 8Б	f	large
13594	772	2191	республика Татарстан, Нижнекамск городской округ, пр.Химиков, 8Б	f	large
13662	821	2259	республика Татарстан, Нижнекамский район, Нижнекамск, пр.Мира, 79	f	large
13661	821	2258	республика Татарстан, Нижнекамский район, Нижнекамск, пр.Мира, 79	f	large
13634	803	2231	республика Татарстан, Нижнекамский район, Нижнекамск, пр. Шинников, 60	f	large
13633	803	2230	республика Татарстан, Нижнекамский район, Нижнекамск, пр. Шинников, 60	f	large
132530	802	2229	республика Татарстан, Нижнекамский район, Нижнекамск, пр. Шинников, 60, здание гимназии №25	f	\N
13610	785	2207	республика Татарстан, Нижнекамский район, Нижнекамск, Юности, 4	f	large
13609	785	2206	республика Татарстан, Нижнекамский район, Нижнекамск, Юности, 4	f	large
132529	783	2205	республика Татарстан, Нижнекамский район, Нижнекамск, Юности, 14В, здание школы №8	f	\N
13599	775	2196	республика Татарстан, Нижнекамский район, Нижнекамск, Юности, 23	f	large
13597	773	2194	республика Татарстан, Нижнекамский район, Нижнекамск, Юности, 34	f	large
13596	773	2193	республика Татарстан, Нижнекамский район, Нижнекамск, Юности, 34	f	large
13611	786	2208	республика Татарстан, Нижнекамский район, Нижнекамск, Школьный бульвар, 2	f	large
13660	820	2257	республика Татарстан, Нижнекамский район, Нижнекамск, Чулман, 18	f	large
13659	820	2256	республика Татарстан, Нижнекамский район, Нижнекамск, Чулман, 18	f	large
13658	820	2255	республика Татарстан, Нижнекамский район, Нижнекамск, Чулман, 18	f	large
13606	781	2203	республика Татарстан, Нижнекамск городской округ, Центральная, 1	f	medium
8899	54092	46	республика Марий Эл, Йошкар-Ола, Мира, 91А	f	large
13600	776	2197	республика Татарстан, Нижнекамский район, Нижнекамск, Тукая, 15А	f	large
13656	818	2253	республика Татарстан, Нижнекамский район, Нижнекамск, Сююмбике, 38	f	large
13655	818	2252	республика Татарстан, Нижнекамский район, Нижнекамск, Сююмбике, 38	f	large
13654	818	2251	республика Татарстан, Нижнекамский район, Нижнекамск, Сююмбике, 38	f	large
13603	778	2200	республика Татарстан, Нижнекамский район, Нижнекамск, Строителей, 9	f	large
13619	793	2216	республика Татарстан, Нижнекамский район, Нижнекамск, Спортивная, 21А	f	large
13618	793	2215	республика Татарстан, Нижнекамский район, Нижнекамск, Спортивная, 21А	f	large
13614	789	2211	республика Татарстан, Нижнекамский район, Нижнекамск, Спортивная, 13Б	f	large
13613	788	2210	республика Татарстан, Нижнекамский район, Нижнекамск, Сквер Лемаева, 14	f	large
13612	787	2209	республика Татарстан, Нижнекамский район, Нижнекамск, Сквер Лемаева, 12	f	large
13642	810	2239	республика Татарстан, Нижнекамский район, Нижнекамск, Мурадьяна, 18А	f	large
132531	808	2238	республика Татарстан, Нижнекамский район, Нижнекамск, Мурадьяна, 18А, здание школы №21	f	\N
13646	813	2243	республика Татарстан, Нижнекамский район, Нижнекамск, Менделеева, 37А	f	large
13645	813	2242	республика Татарстан, Нижнекамский район, Нижнекамск, Менделеева, 37А	f	large
13625	797	2222	республика Татарстан, Нижнекамский район, Нижнекамск, Менделеева, 15А	f	large
13624	797	2221	республика Татарстан, Нижнекамский район, Нижнекамск, Менделеева, 15А	f	large
13598	774	2195	республика Татарстан, Нижнекамский район, Нижнекамск, Корабельная, 13	f	large
13631	800	2228	республика Татарстан, Нижнекамский район, Нижнекамск, Кайманова, 7	f	large
13630	800	2227	республика Татарстан, Нижнекамский район, Нижнекамск, Кайманова, 7	f	large
13629	799	2226	республика Татарстан, Нижнекамский район, Нижнекамск, Кайманова, 4	f	large
13628	799	2225	республика Татарстан, Нижнекамский район, Нижнекамск, Кайманова, 4	f	large
13627	798	2224	республика Татарстан, Нижнекамский район, Нижнекамск, Гагарина, 42	f	large
13626	798	2223	республика Татарстан, Нижнекамский район, Нижнекамск, Гагарина, 42	f	large
13617	792	2214	республика Татарстан, Нижнекамский район, Нижнекамск, Гагарина, 5В	f	large
13616	790	2213	республика Татарстан, Нижнекамский район, Нижнекамск, Гагарина, 1В	f	large
13615	790	2212	республика Татарстан, Нижнекамский район, Нижнекамск, Гагарина, 1В	f	large
13620	794	2217	республика Татарстан, Нижнекамский район, Нижнекамск, Вахитова, 19	f	large
13643	811	2240	республика Татарстан, Нижнекамский район, Нижнекамск, Бызова, 1б	f	large
13640	806	2237	республика Татарстан, Нижнекамский район, Нижнекамск, Бызова, 9А	f	large
13639	806	2236	республика Татарстан, Нижнекамский район, Нижнекамск, Бызова, 9А	f	large
13638	805	2235	республика Татарстан, Нижнекамский район, Нижнекамск, Бызова, 10Б	f	large
13637	805	2234	республика Татарстан, Нижнекамский район, Нижнекамск, Бызова, 10Б	f	large
13636	804	2233	республика Татарстан, Нижнекамский район, Нижнекамск, Бызова, 18Б	f	large
13635	804	2232	республика Татарстан, Нижнекамский район, Нижнекамск, Бызова, 18Б	f	large
13664	822	2261	республика Татарстан, Нижнекамский район, Нижнекамск, Баки Урманче, 13	f	large
13663	822	2260	республика Татарстан, Нижнекамский район, Нижнекамск, Баки Урманче, 13	f	large
13604	779	2201	республика Татарстан, Нижнекамский район, Нижнекамск, Ахтубинская, 2	f	large
13669	826	2266	республика Татарстан, Нижнекамский район, Нижнекамск, 30 лет Победы, 7А	f	large
13693	853	2290	республика Татарстан, Нижнекамский район, село Нариман, Центральная, 56б	f	small
13699	860	2296	республика Татарстан, Нижнекамский район, село Кулмакса, Центральная, 26	f	small
13677	835	2274	республика Татарстан, Нижнекамский район, село Красный Ключ, Советская, 17а	f	large
13688	847	2285	республика Татарстан, Нижнекамский район, село Красная Кадка, Ленина, 60	f	small
13700	861	2297	республика Татарстан, Нижнекамский район, село Кармалы, Пионерская, 3	f	small
13694	854	2291	республика Татарстан, Нижнекамский район, село Камский, Московская, 1	f	small
13705	865	2302	республика Татарстан, Нижнекамский район, поселок Камские Поляны, 4, 1	f	large
8897	54092	44	республика Марий Эл, Йошкар-Ола, Мира, 91А	f	large
13707	866	2304	республика Татарстан, Нижнекамский район, поселок Камские Поляны, 2, 20	f	large
13706	866	2303	республика Татарстан, Нижнекамский район, поселок Камские Поляны, 2, 20	f	large
13704	864	2301	республика Татарстан, Нижнекамский район, поселок Камские Поляны, 1, 29	f	large
13703	864	2300	республика Татарстан, Нижнекамский район, поселок Камские Поляны, 1, 29	f	large
13681	840	2278	республика Татарстан, Нижнекамский район, село Каенлы, Ленина, 44	f	medium
13698	859	2295	республика Татарстан, Нижнекамский район, село Елантово, Нагорное, 1г	f	medium
13701	862	2298	республика Татарстан, Нижнекамский район, село Городище, Колхозная, 5а	f	medium
13696	857	2293	республика Татарстан, Нижнекамский район, село Верхняя Уратьма, Молодежная, 2	f	medium
13686	845	2283	республика Татарстан, Нижнекамский район, село Верхние Челны, Молодежная, 11	f	medium
13683	842	2280	республика Татарстан, Нижнекамский район, село Борок, М.Горького, 8	f	small
13675	831	2272	республика Татарстан, Нижнекамский район, село Большое Афанасово, Молодежная, 5	f	large
13674	830	2271	республика Татарстан, Нижнекамский район, село Большое Афанасово, Молодежная, 3	f	large
13687	846	2284	республика Татарстан, Нижнекамский район, Большие Аты, Красноармейская, 1	f	small
13685	844	2282	республика Татарстан, Нижнекамский район, село Болгар, Ленина, 56а	f	small
13697	858	2294	республика Татарстан, Нижнекамский район, село Благодатная, Мира, 1а	f	medium
13680	839	2277	республика Татарстан, Нижнекамский район, село Балчиклы, Терешковой, 52а	f	small
13403	645	2000	республика Татарстан, Муслюмовский район, село Шуганга, Ленина, 8	f	small
13428	672	2025	республика Татарстан, Муслюмовский район, село Уразметьево, Школьная, 45А	f	small
13426	670	2023	республика Татарстан, Муслюмовский район, село Тойгильдино, Центральная, 2	f	medium
13420	663	2017	республика Татарстан, Муслюмовский район, село Тогашево, Вахитова, 10А	f	small
13427	671	2024	республика Татарстан, Муслюмовский район, село Ташлияр, Урожайная, 78Б	f	small
13412	655	2009	республика Татарстан, Муслюмовский район, село Таш-Елга, Лесная, 35а	f	small
13409	651	2006	республика Татарстан, Муслюмовский район, село Татарское Булярово, Дружбы, 5А	f	medium
13430	674	2027	республика Татарстан, Муслюмовский район, село Татарская Смыловка, Ленинская, 5	f	small
13408	650	2005	республика Татарстан, Муслюмовский район, Старый Варяш, Чишма, 10А	f	small
13425	669	2022	республика Татарстан, Муслюмовский район, село Старые Карамалы, Кооперативная, 113А	f	medium
13423	666	2020	республика Татарстан, Муслюмовский район, село Семяково, Школьная, 8а	f	small
13416	659	2013	республика Татарстан, Муслюмовский район, село Салауз-Мухан, Кооперативная, 62	f	small
13429	673	2026	республика Татарстан, Муслюмовский район, село Русский Шуган, Ленина, 16А	f	small
13422	665	2019	республика Татарстан, Муслюмовский район, село Октябрь, Центральная, 33а	f	small
13421	664	2018	республика Татарстан, Муслюмовский район, село Новые Усы, Советская, 30	f	small
13410	652	2007	республика Татарстан, Муслюмовский район, село Новое Саитово, Мирная, 50А	f	small
13419	662	2016	республика Татарстан, Муслюмовский район, село Нижний Табын, Школьная, 40А	f	small
13397	638	1994	республика Татарстан, Муслюмовский район, поселок Муслюмово, Пушкина, 32	f	medium
13395	636	1992	республика Татарстан, Муслюмовский район, поселок Муслюмово, Пушкина, 35	f	medium
13398	639	1995	республика Татарстан, Муслюмовский район, поселок Муслюмово, Октябрьская, 39	f	large
13399	640	1996	республика Татарстан, Муслюмовский район, поселок Муслюмово, Молодежная, 15	f	large
13400	642	1997	республика Татарстан, Муслюмовский район, поселок Муслюмово, Кооперативная, 170А	f	large
13396	637	1993	республика Татарстан, Муслюмовский район, поселок Муслюмово, Кооперативная, 150	f	medium
13417	660	2014	республика Татарстан, Муслюмовский район, село Михайловка, Гагарина, 24	f	medium
13415	658	2012	республика Татарстан, Муслюмовский район, село Митряево, Кооперативная, 65	f	medium
13414	657	2011	республика Татарстан, Муслюмовский район, село Меллятамак, Кооперативная, 32А	f	medium
11865	93332	462	республика Татарстан, Агрызский район, Агрыз, Карла Маркса, 9	f	medium
13411	653	2008	республика Татарстан, Муслюмовский район, село Мари-Буляр, 60 лет Октября, 31	f	small
13413	656	2010	республика Татарстан, Муслюмовский район, село Кряш-Шуран, Центральная, 6а	f	small
13424	668	2021	республика Татарстан, Муслюмовский район, село Елгабаш, Колхозная, 42А	f	small
13418	661	2015	республика Татарстан, Муслюмовский район, село Верхний Табын, Тукая, 21А	f	small
13407	649	2004	республика Татарстан, Муслюмовский район, село Варяш-Баш, Кооперативная, 45А	f	small
13406	648	2003	республика Татарстан, Муслюмовский район, село Большой Чекман, Центральная, 1	f	small
13404	646	2001	республика Татарстан, Муслюмовский район, село Баюкова, Советская, 2	f	small
13402	644	1999	республика Татарстан, Муслюмовский район, село Баланны, Советская, 85	f	small
13401	643	1998	республика Татарстан, Муслюмовский район, село Амикеево, Фаррахова, 32	f	small
13357	595	1954	республика Татарстан, Мензелинский район, село Ямаково, Галиева, 14а	f	small
13378	618	1975	республика Татарстан, Мензелинский район, поселок Юртово, Лесная, 2	f	small
13372	611	1969	республика Татарстан, Мензелинский район, село Холодный Ключ, Тукая, 11А	f	small
13361	599	1958	республика Татарстан, Мензелинский район, село Усаево, Школьная, 19	f	small
13376	616	1973	республика Татарстан, Мензелинский район, село Урусово, Дружбы, 42А	f	small
13375	614	1972	республика Татарстан, Мензелинский район, село Тулубаево, Социалистическая, 36	f	small
13359	597	1956	республика Татарстан, Мензелинский район, село Топасево, Школьная, 2	f	small
13346	583	1943	республика Татарстан, Мензелинский район, село Татарская Мишуга, Алая заря, 2	f	small
13354	592	1951	республика Татарстан, Мензелинский район, село Старый Иркеняш, Имянле, 21	f	small
13371	610	1968	республика Татарстан, Мензелинский район, село Старое Мазино, Ленина, 31	f	small
13373	612	1970	республика Татарстан, Мензелинский район, село Старая Матвеевка, Горького, 5	f	small
13374	613	1971	республика Татарстан, Мензелинский район, село Старая Александровка, Новая, 45А	f	small
13365	604	1962	республика Татарстан, Мензелинский район, село Русский Каран, Октября, 43	f	small
13352	590	1949	республика Татарстан, Мензелинский район, село Подгорный Текермен, Марса, 54а	f	small
13369	608	1966	республика Татарстан, Мензелинский район, село Подгорный Байлар, Центральная, 20А	f	small
13367	606	1964	республика Татарстан, Мензелинский район, село Новый Мелькен, Школьная, 9	f	small
13366	605	1963	республика Татарстан, Мензелинский район, село Новое Мазино, Центральная, 19	f	small
13362	600	1959	республика Татарстан, Мензелинский район, село Новая Александровка, Первомайская, 15	f	small
13364	603	1961	республика Татарстан, Мензелинский район, село Николаевка, Мираня, 45	f	small
13363	601	1960	республика Татарстан, Мензелинский район, село Наратлы-Кичу, К.Маркса, 6	f	small
13390	631	1987	республика Татарстан, Мензелинский район, Мензелинск, Шамова, 48	f	medium
13386	626	1983	республика Татарстан, Мензелинский район, Мензелинск, Чернышевского, 16	f	medium
13388	629	1985	республика Татарстан, Мензелинский район, Мензелинск, Челнинский Тракт, 1	f	medium
13393	634	1990	республика Татарстан, Мензелинский район, Мензелинск, Татарстан, 2А	f	small
13380	620	1977	республика Татарстан, Мензелинский район, Мензелинск, Строителей, 39	f	medium
13387	627	1984	республика Татарстан, Мензелинский район, Мензелинск, М. Джалиля, 18	f	large
13394	635	1991	республика Татарстан, Мензелинский район, Мензелинск, Ленина, 69	f	medium
13385	625	1982	республика Татарстан, Мензелинский район, Мензелинск, К.Маркса, 77	f	medium
13392	633	1989	республика Татарстан, Мензелинский район, Мензелинск, Изыскателей, 3/15Б	f	large
13383	623	1980	республика Татарстан, Мензелинский район, Мензелинск, Изыскателей, 2/7	f	medium
13382	622	1979	республика Татарстан, Мензелинский район, Мензелинск, Изыскателей, 1/22	f	medium
13381	621	1978	республика Татарстан, Мензелинский район, Мензелинск, Изыскателей, 2/15	f	medium
13391	632	1988	республика Татарстан, Мензелинский район, Мензелинск, Гурьянова, 98	f	medium
13384	624	1981	республика Татарстан, Мензелинский район, Мензелинск, Гурьянова, 84	f	medium
8893	54089	40	республика Марий Эл, Йошкар-Ола, Медицинская, 5	f	large
13389	630	1986	республика Татарстан, Мензелинский район, Мензелинск, Головина, 137	f	medium
13350	587	1947	республика Татарстан, Мензелинский район, село Куяново, Советская, 24	f	small
13360	598	1957	республика Татарстан, Мензелинский район, село Кузембетьево, Советская, 33А	f	medium
13358	596	1955	республика Татарстан, Мензелинский район, село Коноваловка, Центральная, 6	f	medium
13355	593	1952	республика Татарстан, Мензелинский район, деревня Кзыл-Тюбяк, Гагарина, 13	f	small
13345	582	1942	республика Татарстан, Мензелинский район, село Калтаново, Школьная, 2	f	small
13356	594	1953	республика Татарстан, Мензелинский район, село Кадряково, Кирова, 29	f	small
13353	591	1950	республика Татарстан, Мензелинский район, село Имени Воровского, Центральная, 26	f	small
13368	607	1965	республика Татарстан, Мензелинский район, село Дусай-Кичу, М. Джалиля, 48	f	small
13348	585	1945	республика Татарстан, Мензелинский район, село Дружба, Школьная, 2	f	small
13370	609	1967	республика Татарстан, Мензелинский район, село Деуково, Советская, 25	f	small
13377	617	1974	республика Татарстан, Мензелинский район, село Гулюково, Строительная, 1	f	small
13351	588	1948	республика Татарстан, Мензелинский район, село Верхний Текермен, М. Джалиля, 1Б	f	small
13379	619	1976	республика Татарстан, Мензелинский район, село Верхние Юшады, Новая, 4	f	small
13349	586	1946	республика Татарстан, Мензелинский район, село Бикбулово, Ленина, 50	f	small
13344	581	1941	республика Татарстан, Мензелинский район, село Атрякле, Центральная, 24	f	small
13343	580	1940	республика Татарстан, Менделеевский район, село Тураево, Центральная, 9а	f	small
13332	569	1929	республика Татарстан, Менделеевский район, село Тойма, Вахитова, 40а	f	small
13342	579	1939	республика Татарстан, Менделеевский район, село Тойгузино, Центральная, 48	f	small
13341	578	1938	республика Татарстан, Менделеевский район, село Тихоново, Коммунистическая, 27в	f	medium
13340	577	1937	республика Татарстан, Менделеевский район, село Татарские Челны, Школьная, 16	f	small
13339	564	1936	республика Татарстан, Менделеевский район, село Старое Гришкино, Молодежная, 1	f	small
132521	565	1926	республика Татарстан, Менделеевский район, село Сетяково, Дружбы, 10, здание клуба	f	\N
13338	576	1935	республика Татарстан, Менделеевский район, село Псеево, Тукая, 1а	f	small
13337	575	1934	республика Татарстан, Менделеевский район, село Мунайка, Ленина, 54	f	small
13335	572	1932	республика Татарстан, Менделеевский район, село Монашево, Школьная, 21	f	small
13322	557	1919	республика Татарстан, Менделеевский район, Менделеевск, бульвар Интернационалистов, 2	f	large
13323	558	1920	республика Татарстан, Менделеевский район, Менделеевск, б-р Интернационалистов, 3	f	large
13321	556	1918	республика Татарстан, Менделеевский район, Менделеевск, Юбилейная, 8	f	large
13320	555	1917	республика Татарстан, Менделеевский район, Менделеевск, Юбилейная, 10	f	large
13318	552	1915	республика Татарстан, Менделеевский район, Менделеевск, Фомина, 10	f	large
13325	560	1922	республика Татарстан, Менделеевский район, Менделеевск, Тукая, 7	f	medium
13326	561	1923	республика Татарстан, Менделеевский район, Менделеевск, Татарстана, 16	f	large
13315	548	1912	республика Татарстан, Менделеевский район, Менделеевск, Профсоюзная, 2	f	large
13324	559	1921	республика Татарстан, Менделеевский район, Менделеевск, Набережная, 83	f	small
13313	546	1910	республика Татарстан, Менделеевский район, Менделеевск, М.Горького, 3а	f	large
132519	550	1913	республика Татарстан, Менделеевский район, Менделеевск, Зеленая, 11, здание МБДОУ №8	f	\N
13314	547	1911	республика Татарстан, Менделеевский район, Менделеевск, Зеленая, 23	f	large
132520	553	1916	республика Татарстан, Менделеевский район, Менделеевск, Бурмистрова, 3, здание РДК Юность	f	\N
13317	551	1914	республика Татарстан, Менделеевский район, Менделеевск, Бурмистрова, 17	f	medium
13334	571	1931	республика Татарстан, Менделеевский район, село Камаево, Д.Сирая, 14а	f	small
132522	573	1933	республика Татарстан, Менделеевский район, село Ильнеть, Школьная, 9, здание средней школы	f	\N
13333	570	1930	республика Татарстан, Менделеевский район, село Ижевка, Советская, 23	f	medium
13331	568	1928	республика Татарстан, Менделеевский район, село Енабердино, Клубная, 7	f	small
13330	567	1927	республика Татарстан, Менделеевский район, село Брюшли, Заречная, 14	f	small
13328	563	1925	республика Татарстан, Менделеевский район, село Бизяки, Новая, 1	f	medium
13268	500	1865	республика Татарстан, Мамадышский район, село ферма 2 Совхоза Мамадышский, Гагарина, 14	f	small
13299	532	1896	республика Татарстан, Мамадышский район, село совхоз Пятилетка, Садовая, 20	f	small
13302	535	1899	республика Татарстан, Мамадышский район, село совхоз Мамадышский,  Мира, 11	f	large
13312	545	1909	республика Татарстан, Мамадышский район, село Шемяк, Г. Тукая, 4	f	small
13311	544	1908	республика Татарстан, Мамадышский район, село Шадчи, Молодежная, 18	f	medium
13310	543	1907	республика Татарстан, Мамадышский район, село Хасаншино, Ленина, 35	f	small
13309	542	1906	республика Татарстан, Мамадышский район, село Усали, Центральная, 38А	f	medium
13308	541	1905	республика Татарстан, Мамадышский район, село Уразбахтино, Центральная , 28	f	small
13307	540	1904	республика Татарстан, Мамадышский район, село Тулбай, Пионерская, 7	f	small
13306	539	1903	республика Татарстан, Мамадышский район, село Тавели, Нагорная, 70	f	small
13305	538	1902	республика Татарстан, Мамадышский район, село Старый Кумазан, Школьная, 7	f	small
13304	537	1901	республика Татарстан, Мамадышский район, село Средние Кирмени, Ленина, 16А	f	small
13303	536	1900	республика Татарстан, Мамадышский район, село Соколка, Школьная, 38	f	medium
13301	534	1898	республика Татарстан, Мамадышский район, село Секинесь, Школьная, 3	f	small
13300	533	1897	республика Татарстан, Мамадышский район, село Рагозино, Новая, 12	f	small
13298	531	1895	республика Татарстан, Мамадышский район, село Пойкино, Октябрьская, 16	f	medium
13297	530	1894	республика Татарстан, Мамадышский район, село Отарка, Октябрьская, 17	f	small
13296	529	1893	республика Татарстан, Мамадышский район, село Омары, Школьная, 18	f	small
13295	528	1892	республика Татарстан, Мамадышский район, село Олуяз, Ш. Маннура, 2	f	small
13256	487	1853	республика Татарстан, Мамадышский район, село Новый, Березовая, 16а	f	medium
13293	525	1890	республика Татарстан, Мамадышский район, село Никифорово, К. Маркса, 2	f	small
13291	523	1888	республика Татарстан, Мамадышский район, село Нижняя Уча, Первомайская, 1	f	small
13289	521	1886	республика Татарстан, Мамадышский район, село Нижняя Сунь, К. Маркса, 18А	f	small
13288	520	1885	республика Татарстан, Мамадышский район, село Нижняя Ошма, Советская, 39а	f	medium
13275	506	1872	республика Татарстан, Мамадышский район, село Нижняя Кузгунча, Татарстан, 30	f	small
13290	522	1887	республика Татарстан, Мамадышский район, село Нижний Таканыш, Советская, 2	f	medium
13292	524	1889	республика Татарстан, Мамадышский район, село Нижние Янки, Ленина, 50	f	small
13281	512	1878	республика Татарстан, Мамадышский район, Мамадыш, Текстильный переулок, 5	f	medium
13283	515	1880	республика Татарстан, Мамадышский район, Мамадыш, Советская, 42	f	large
13280	511	1877	республика Татарстан, Мамадышский район, Мамадыш, Ленина, 107	f	large
13287	519	1884	республика Татарстан, Мамадышский район, Мамадыш, Давыдова, 159В	f	large
13286	518	1883	республика Татарстан, Мамадышский район, Мамадыш, Давыдова, 170	f	large
13285	517	1882	республика Татарстан, Мамадышский район, Мамадыш, Давыдова, 97А	f	large
13284	516	1881	республика Татарстан, Мамадышский район, Мамадыш, Горького, 25	f	large
13282	513	1879	республика Татарстан, Мамадышский район, Мамадыш, Азина, 10	f	large
13278	509	1875	республика Татарстан, Мамадышский район, село Малые Кирмени, Нигматуллина, 31	f	small
13277	508	1874	республика Татарстан, Мамадышский район, село Малмыжка, Советская, 28	f	small
13279	510	1876	республика Татарстан, Мамадышский район, село Малая Сунь, Советская, 17А	f	small
13294	526	1891	республика Татарстан, Мамадышский район, село Куюк-Ерыкса, Гагарина, 29	f	medium
13276	507	1873	республика Татарстан, Мамадышский район, село Кулущи, А.Гайдара, 2А	f	small
13274	505	1871	республика Татарстан, Мамадышский район, село Красная Горка, Ямашева, 1	f	large
13273	504	1870	республика Татарстан, Мамадышский район, село Кемеш-Куль, Центральная, 19	f	medium
13272	503	1869	республика Татарстан, Мамадышский район, село Катмыш, Ленина, 85	f	medium
13270	489	1867	республика Татарстан, Мамадышский район, село Ишкеево, Школьная, 18	f	small
13269	501	1866	республика Татарстан, Мамадышский район, село Зюри, Советская, 1	f	medium
13267	499	1864	республика Татарстан, Мамадышский район, поселок Зверосовхоза, Ленина, 4	f	medium
13266	498	1863	республика Татарстан, Мамадышский район, село Дюсьметьево, Молодежная, 1	f	medium
13405	647	2002	республика Татарстан, Мамадышский район, село Дусаево, Центральная, 6А	f	small
13265	497	1862	республика Татарстан, Мамадышский район, поселок Дружба, Центральная, 20	f	small
13264	496	1861	республика Татарстан, Мамадышский район, село Дигитли, Центральная, 13	f	small
13263	495	1860	республика Татарстан, Мамадышский район, село Гришкино, Красное Знамя, 51	f	small
13258	490	1855	республика Татарстан, Мамадышский район, село Владимирово, Школьная, 3	f	small
13261	493	1858	республика Татарстан, Мамадышский район, село Верхняя Сунь, Советская, 20а	f	small
13260	492	1857	республика Татарстан, Мамадышский район, село Верхняя Ошма, Советская, 52а	f	medium
13259	491	1856	республика Татарстан, Мамадышский район, село Верхний Берсут, Советская, 44	f	small
13262	494	1859	республика Татарстан, Мамадышский район, село Верхние Яки, Центральная, 1	f	small
13257	488	1854	республика Татарстан, Мамадышский район, село Большая Шия, Давыдова, 43а	f	small
13255	486	1852	республика Татарстан, Мамадышский район, село Албай, Центральная, 42	f	small
13232	463	1829	республика Татарстан, Лениногорский район, село имени Мичурина, Советская, 28	f	small
13246	477	1843	республика Татарстан, Лениногорский район, село Юлтимирово, Советская, 75	f	small
13254	485	1851	республика Татарстан, Лениногорский район, поселок Шугурово, Ленина, 35	f	medium
13253	485	1850	республика Татарстан, Лениногорский район, поселок Шугурово, Ленина, 35	f	medium
13251	483	1848	республика Татарстан, Лениногорский район, село Федотовка, Советская, 8	f	small
13222	451	1819	республика Татарстан, Лениногорский район, село Урняк-Кумяк, Школьная, 3А	f	small
132518	482	1847	республика Татарстан, Лениногорский район, село Урмышла, Центральная, 2, 423294, здание Совета сельского поселения	f	\N
13249	480	1846	республика Татарстан, Лениногорский район, село Туктарово-Урдала, Советская, 103	f	medium
13247	478	1844	республика Татарстан, Лениногорский район, село Тимяшево, Кирова, 26	f	medium
13248	478	1845	республика Татарстан, Лениногорский район, село Тимяшево, Кирова, 26	f	large
13245	476	1842	республика Татарстан, Лениногорский район, село Сугушла, Центральная, 27	f	small
13243	474	1840	республика Татарстан, Лениногорский район, село Старый Кувак, Заварыкина, 36	f	medium
13241	472	1838	республика Татарстан, Лениногорский район, село Старый Иштеряк, Школьная, 15	f	medium
13244	475	1841	республика Татарстан, Лениногорский район, село Старое Шугурово, С.Садриева, 7	f	medium
13239	470	1836	республика Татарстан, Лениногорский район, село Старая Письмянка, Центральная, 50	f	medium
13225	454	1822	республика Татарстан, Лениногорский район, село Спиридоновка, Советская, 32	f	small
13240	471	1837	республика Татарстан, Лениногорский район, село Сарабикулово, Кирова, 4А	f	small
13238	469	1835	республика Татарстан, Лениногорский район, поселок Подлесный, Гагарина, 5	f	medium
13236	467	1833	республика Татарстан, Лениногорский район, село Новый Иштеряк, Центральная, 7	f	medium
13237	468	1834	республика Татарстан, Лениногорский район, село Новочершилинский, Центральная, 12А	f	medium
13233	464	1830	республика Татарстан, Лениногорский район, село Новое Сережкино, Центральная, 9	f	small
12240	93727	837	республика Татарстан, Лениногорский район, Новое Елхово, Советская, 61	f	medium
12553	94051	1150	республика Татарстан, Лениногорский район, село Нижняя Вязовка, Центральная, 32	f	medium
13235	466	1832	республика Татарстан, Лениногорский район, село Нижние Чершилы, Центральная, 56	f	medium
13234	465	1831	республика Татарстан, Лениногорский район, село Мукмин-Каратай, Механизаторов, 31Б	f	small
13229	460	1826	республика Татарстан, Лениногорский район, село Мордовская Кармалка, Нагорная, 33	f	small
13227	456	1824	республика Татарстан, Лениногорский район, село Михайловка, Центральная, 12	f	small
13199	429	1796	республика Татарстан, Лениногорский район, Лениногорск, Губкина, 59	f	large
13252	484	1849	республика Татарстан, Лениногорский район, село Кузьминовка, Кооперативная, 10	f	small
13231	462	1828	республика Татарстан, Лениногорский район, село Куакбаш, Карла Маркса, 15	f	medium
13230	461	1827	республика Татарстан, Лениногорский район, село Керлигач, Советская, 33А	f	small
132517	457	1825	республика Татарстан, Лениногорский район, село Каркали, Советская, 93, Здание ДК	f	\N
13226	455	1823	республика Татарстан, Лениногорский район, село Ивановка, Юности, 5	f	medium
13224	453	1821	республика Татарстан, Лениногорский район, поселок Зеленая Роща, Строительная, 1	f	medium
13223	452	1820	республика Татарстан, Лениногорский район, село Зай-Каратай, Советская, 56	f	medium
12267	93755	864	республика Татарстан, Лениногорский район, село Булгар, Ирня, 11А	f	small
13242	473	1839	республика Татарстан, Лениногорский район, село Бакирово, Нагорная, 37	f	small
13202	431	1799	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Школьная, 8	f	medium
13201	430	1798	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Широкая, 15	f	large
13200	430	1797	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Широкая, 15	f	large
13215	444	1812	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Шашина, 55	f	large
13218	447	1815	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Степная, 2а	f	large
13216	445	1813	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Садриева, 24	f	large
13207	436	1804	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Морякова, 4	f	large
13206	435	1803	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Морякова, 10	f	large
13211	440	1808	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Ленинградская, 40	f	large
13210	439	1807	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Ленинградская, 28а	f	large
13213	442	1810	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Кутузова, 14	f	large
13212	441	1809	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Кутузова, 2	f	large
13214	443	1811	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Крупской, 6	f	large
13219	448	1816	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Кошевого, 32	f	large
13217	446	1814	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Кошевого, 28	f	large
13209	438	1806	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Гагарина, 51	f	large
13208	437	1805	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Гагарина, 29	f	large
13204	433	1801	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Гагарина, 12	f	large
13198	428	1795	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Асфальтная, 1	f	large
13203	432	1800	республика Татарстан, Лениногорский муниципальный район, Лениногорск, Агадуллмна, 1	f	large
13205	434	1802	республика Татарстан, Лениногорский муниципальный район, Лениногорск, 50 лет Победы, 26	f	large
13165	393	1762	республика Татарстан, Лаишевский район, село совхоз Имени 25-го Октября, Центральная, 6	f	large
13170	399	1767	республика Татарстан, Лаишевский район, село Шуран, Кооперативная, 32	f	small
13168	396	1765	республика Татарстан, Лаишевский район, село Чирпы, Заводская, 22	f	small
13197	427	1794	республика Татарстан, Лаишевский район, село Тетеево, Центральная, 12а	f	small
13155	383	1752	республика Татарстан, Лаишевский район, село Ташкирмень, Верхняя, 34	f	medium
13172	401	1769	республика Татарстан, Лаишевский район, село Татарский Янтык, Магазинная, 31а	f	small
13196	426	1793	республика Татарстан, Лаишевский район, село Татарский Кабан, Солнечная, 16а	f	small
13154	382	1751	республика Татарстан, Лаишевский район, село Татарские Саралы, Татарстан, 17	f	small
13152	380	1749	республика Татарстан, Лаишевский район, село Тангачи, Октябрьская, 3	f	small
132578	1470	2868	республика Татарстан, Лаишевский район, Столбище, Заозерная, 21, помещение СДК	f	\N
132516	415	1782	республика Татарстан, Лаишевский район, село Столбище, Школьная, 10, помещение средней школы	f	\N
132515	413	1781	республика Татарстан, Лаишевский район, село Столбище, Совхозная, 7а, административное здание ООО Мир овощей	f	\N
13186	416	1783	республика Татарстан, Лаишевский район, село Столбище, Северная, 14	f	medium
13171	400	1768	республика Татарстан, Лаишевский район, село Среднее Девятово, Сергеева, 6	f	medium
13178	407	1775	республика Татарстан, Лаишевский район, село Сокуры, Школьная, 1	f	medium
13153	381	1750	республика Татарстан, Лаишевский район, село Сингели, Школьная, 52	f	small
13192	422	1789	республика Татарстан, Лаишевский район, село Пиголи, Закарьевская, 2а	f	small
13189	419	1786	республика Татарстан, Лаишевский район, село Песчаные Ковали, Октябрьская, 9а	f	large
13174	403	1771	республика Татарстан, Лаишевский район, село Пелево, Советская, 1а	f	medium
13191	421	1788	республика Татарстан, Лаишевский район, село Орел, Олимпийская, 1а	f	medium
13193	423	1790	республика Татарстан, Лаишевский район, село Никольское, Центральная, 43	f	medium
13195	425	1792	республика Татарстан, Лаишевский район, село Нармонка, Центральная, 28	f	large
132580	1473	2870	республика Татарстан, Лаишевский район, Нармонка, Молодежная, 12а, здание Исполнительного комитета	f	\N
13182	411	1779	республика Татарстан, Лаишевский район, село Малые Кабаны, Южная, 1	f	small
13169	397	1766	республика Татарстан, Лаишевский район, село Малая Елга, Советская, 56	f	medium
132576	1468	2866	республика Татарстан, Лаишевский район, поселок Лаишево, Чернышевского, 26, помещение районной библиотеки	f	\N
132575	1467	2865	республика Татарстан, Лаишевский район, поселок Лаишево, Производственная, 1а, помещение Спорткомплекса	f	\N
13162	390	1759	республика Татарстан, Лаишевский район, поселок Лаишево, Маяковского, 5	f	large
13160	388	1757	республика Татарстан, Лаишевский район, поселок Лаишево, Ленина, 16	f	medium
13161	389	1758	республика Татарстан, Лаишевский район, поселок Лаишево, Лебедевой, 32	f	large
13163	391	1760	республика Татарстан, Лаишевский район, поселок Лаишево, Александра Матросова, 24	f	large
13159	387	1756	республика Татарстан, Лаишевский район, Лаишево, Школьный переулок, 3а	f	large
132577	1469	2867	республика Татарстан, Лаишевский район, Лаишево, Горького, 80, помещение УЭООС	f	\N
13164	392	1761	республика Татарстан, Лаишевский район, Лаишево, Горького, 2	f	medium
13194	424	1791	республика Татарстан, Лаишевский район, село Кутенчи, Центральная, 15а	f	small
13158	386	1755	республика Татарстан, Лаишевский район, село Курманаково, Центральная, 26а	f	small
13179	408	1776	республика Татарстан, Лаишевский район, село Кирби, Юности, 10а	f	medium
13180	409	1777	республика Татарстан, Лаишевский район, село Карадули, Овражная, 128	f	small
13175	404	1772	республика Татарстан, Лаишевский район, село Каипы, Центральная, 50	f	small
13167	395	1764	республика Татарстан, Лаишевский район, село Именьково, Школьная, 2а	f	small
13151	379	1748	республика Татарстан, Лаишевский район, село Дятлово, Юности, 2	f	medium
13173	402	1770	республика Татарстан, Лаишевский район, село Державино, Заббарова, 39а	f	small
13188	418	1785	республика Татарстан, Лаишевский район, село Габишево, Советская, 5	f	medium
13156	384	1753	республика Татарстан, Лаишевский район, село Габишево, Советская, 3	f	medium
13190	420	1787	республика Татарстан, Лаишевский район, село Боровое Матюшино, Березовая, 25	f	small
13181	410	1778	республика Татарстан, Лаишевский район, село Большие Кабаны, Победы, 6	f	small
13176	405	1773	республика Татарстан, Лаишевский район, село Бима, Центральная, 56	f	small
13177	406	1774	республика Татарстан, Лаишевский район, село Березовка, Центральная, 28	f	small
13183	412	1780	республика Татарстан, Лаишевский район, село Атабаево, Молодежная, 1	f	small
13166	394	1763	республика Татарстан, Лаишевский район, поселок Александровский, Молодежная, 6	f	small
13087	286	1684	республика Татарстан, Кукморский район, поселок Кукмор, Мусы Джалиля, 35	f	large
132579	1472	2869	республика Татарстан, Лаишевский муниципальный район, село Усады, Медицинская, 11, помещение Усадского ФАП	f	\N
13084	296	1681	республика Татарстан, Кукморский район, село Ятмас-Дусай, Центральная, 73а	f	small
132496	294	1679	республика Татарстан, Кукморский район, село Яныль, Центральная, 1а, здание средней школы	f	\N
13094	308	1691	республика Татарстан, Кукморский район, село Янцобино, Пионерская, 15	f	small
13149	377	1746	республика Татарстан, Кукморский район, село Ядыгерь, Ленина, 21а	f	medium
132501	314	1694	республика Татарстан, Кукморский район, село Чишма-Баш, Победы, 50, здание начальной школы	f	\N
13145	372	1742	республика Татарстан, Кукморский район, село Челны, Школьная, 1	f	small
132514	375	1744	республика Татарстан, Кукморский район, село Чарли, Молодежная, 4, 422119 здание средней школы	f	\N
13124	351	1721	республика Татарстан, Кукморский район, село Урясьбаш, Пионерская, 21	f	small
13126	353	1723	республика Татарстан, Кукморский район, село Туркаш, Центральная, 44	f	small
13144	371	1741	республика Татарстан, Кукморский район, село Туембаш, Заречная, 3	f	small
13139	365	1736	республика Татарстан, Кукморский район, село Трыш, Набережная, 3	f	small
13148	376	1745	республика Татарстан, Кукморский район, село Татарская Тулба, Зеленая, 41	f	small
14134	1339	2731	республика Татарстан, Кукморский район, село Тактамыш, Кирова, 23	f	small
13107	325	1704	республика Татарстан, Кукморский район, село Старый Каенсар, Зеленая, 25	f	small
132512	358	1728	республика Татарстан, Кукморский район, село Старая Юмья, Школьная, 20, здание начальной школы	f	\N
132513	369	1739	республика Татарстан, Кукморский район, село Средний Кумор, Майская, 12, 422101 здание средняя школа	f	\N
13141	367	1738	республика Татарстан, Кукморский район, село Село-Чура, Школьная, 34	f	medium
13137	363	1734	республика Татарстан, Кукморский район, село Сардек-Баш, Центральная, 45	f	medium
13102	322	1699	республика Татарстан, Кукморский район, село Саз-Тамак, Ленина, 36а	f	small
13150	378	1747	республика Татарстан, Кукморский район, село Починок-Шемордан, Мусы Джалиля, 6а	f	small
13133	347	1730	республика Татарстан, Кукморский район, село Починок-Кучук, Школьная, 47	f	small
13105	323	1702	республика Татарстан, Кукморский район, село Починок Сутер, Ленина, 1	f	small
13140	366	1737	республика Татарстан, Кукморский район, село Поршур, Новая, 5	f	small
13132	334	1729	республика Татарстан, Кукморский район, село Ошторма-Юмья, Школьная, 42а	f	small
13128	355	1725	республика Татарстан, Кукморский район, село Олуяз, Новая, 11	f	medium
13127	354	1724	республика Татарстан, Кукморский район, село Нырья, Комсомольская, 69	f	large
13125	352	1722	республика Татарстан, Кукморский район, село Ныртинский, Садовая, 25	f	small
13138	364	1735	республика Татарстан, Кукморский район, село Новый Сардек, Новая, 2а	f	small
132511	349	1720	республика Татарстан, Кукморский район, село Нижняя Русь, Г.Ахметова, 1а, здание средней школы	f	\N
13143	370	1740	республика Татарстан, Кукморский район, село Нижний Кумор, Нагорная, 6в	f	small
13130	357	1727	республика Татарстан, Кукморский район, село Нижний Казаклар, Мусы Джалиля, 20	f	small
13120	344	1717	республика Татарстан, Кукморский район, село Нижний Искубаш, Советская, 66а	f	small
132507	332	1709	республика Татарстан, Кукморский район, село Маскара, Центральная, 39, здание спец. коррек. школа-интернат	f	\N
13117	340	1714	республика Татарстан, Кукморский район, село Манзарас, Молодежная, 18а	f	medium
13092	305	1689	республика Татарстан, Кукморский район, село Манзарас, Молодежная, 34	f	large
13116	339	1713	республика Татарстан, Кукморский район, село Мамашир, Школьная, 14	f	medium
13118	341	1715	республика Татарстан, Кукморский район, село Люга, Центральная, 19	f	small
13115	338	1712	республика Татарстан, Кукморский район, поселок Лубяны, Школьная, 18	f	medium
13114	337	1711	республика Татарстан, Кукморский район, поселок Лубяны, Техникумская, 10	f	medium
132508	335	1710	республика Татарстан, Кукморский район, село Лельвиж, Школьная, 5, здание средней школы	f	\N
132498	304	1688	республика Татарстан, Кукморский район, поселок Кукмор, Нур Баяна, 44, МБДОУ Дет. сад №2 Чулпан	f	\N
11863	93330	460	республика Татарстан, Агрызский район, Агрыз, Карла Маркса,, 7	f	medium
13089	301	1686	республика Татарстан, Кукморский район, поселок Кукмор, Мичурина, 25	f	large
13086	298	1683	республика Татарстан, Кукморский район, поселок Кукмор, Майская, 4	f	large
13088	300	1685	республика Татарстан, Кукморский район, поселок Кукмор, Ленина, 38	f	large
132497	303	1687	республика Татарстан, Кукморский район, поселок Кукмор, Железнодорожная, 17, здание МБДОУ Дет.сад №10 Ромашка	f	\N
13085	297	1682	республика Татарстан, Кукморский район, поселок Кукмор, Ворошилова, 44	f	large
13111	331	1708	республика Татарстан, Кукморский район, село Кошкино, Театральная, 40	f	medium
132502	316	1695	республика Татарстан, Кукморский район, село Копки, Пролетарская , 1а, здание дома культуры	f	\N
13135	361	1732	республика Татарстан, Кукморский район, село Княгор, Майская, 12	f	small
13134	360	1731	республика Татарстан, Кукморский район, село Кня-Баш, Средняя, 50а	f	small
132509	342	1716	республика Татарстан, Кукморский район, село Качимир, Зеленая, 2а, здание детского сада	f	\N
132505	327	1706	республика Татарстан, Кукморский район, село Каркаусь, Ленина , 102, здание дом культуры	f	\N
13103	93561	1700	республика Татарстан, Кукморский район, село Камышлы, Ленина, 14	f	small
13108	326	1705	республика Татарстан, Кукморский район, село Каенсар, Х.Такташа, 23	f	small
13886	1076	2483	республика Татарстан, Кукморский район, поселок Иштуган, Центральная, 9	f	small
132500	309	1692	республика Татарстан, Кукморский район, село Иске-Юрт, Центральная, 36, здание начальной школы	f	\N
13106	324	1703	республика Татарстан, Кукморский район, село Верхняя Шунь, Октябрьская, 23	f	small
13121	345	1718	республика Татарстан, Кукморский район, село Верхний Искубаш, С.Ахтямова, 38А	f	small
13146	373	1743	республика Татарстан, Кукморский район, село Верхний Арбаш, Зеленая, 104а	f	medium
13083	295	1680	республика Татарстан, Кукморский район, село Вахитово, Клубная, 5	f	medium
13096	312	1693	республика Татарстан, Кукморский район, село Большой Сардек, Центральная, 114	f	medium
132499	307	1690	республика Татарстан, Кукморский район, село Большой Кукмор, Ленина, 39, здание средняя школа	f	\N
132510	348	1719	республика Татарстан, Кукморский район, село Битлянгур, Гагарина, 47А, здание начальной школы	f	\N
13104	94260	1701	республика Татарстан, Кукморский район, село Березняк, Ленина, 17	f	small
13129	356	1726	республика Татарстан, Кукморский район, село Балыклы, Центральная, 23	f	small
13101	321	1698	республика Татарстан, Кукморский район, село Байлянгар, Советская, 6	f	medium
132503	318	1696	республика Татарстан, Кукморский район, село Аш-Бузи, Молодежная , 45, здание начальная школа	f	\N
13136	362	1733	республика Татарстан, Кукморский район, село Асан-Елга, Молодежная, 1	f	medium
132504	320	1697	республика Татарстан, Кукморский район, село Адаево, Татарстан, 12, здание начальная школа	f	\N
14133	1337	2730	республика Татарстан, Кукморский район, село Абди, Ленина, 17	f	\N
132506	329	1707	республика Татарстан, Кукморский муниципальный район, село Ташлы-Елга, Татарстан, 59, здание начальной школы	f	\N
13078	289	1675	республика Татарстан, Камско-Устьинский район, село совхоз Осинники, Лесная, 3	f	small
13054	263	1651	республика Татарстан, Камско-Устьинский район, п.г.т.Тенишево, Ленина, 12	f	medium
13063	272	1660	республика Татарстан, Камско-Устьинский район, село Челны, Ленина, 43	f	small
13075	285	1672	республика Татарстан, Камско-Устьинский район, село Уразлино, Мира, 7	f	small
13077	288	1674	республика Татарстан, Камско-Устьинский район, село Теньки, Октябрьская, 50	f	medium
13076	287	1673	республика Татарстан, Камско-Устьинский район, село Теньки, Вторая Октябрьская, 60	f	medium
13060	269	1657	республика Татарстан, Камско-Устьинский район, село Сюкеево, Колхозная, 16А	f	medium
13047	256	1644	республика Татарстан, Камско-Устьинский район, село Старое Казеево, Хади Такташа, 4	f	small
132495	252	1641	республика Татарстан, Камско-Устьинский район, село Старое Барышево, Центральная , 15, здание сельского дома культуры	f	\N
13037	245	1634	республика Татарстан, Камско-Устьинский район, село Салтыганово, Центральная, 48а	f	small
13049	258	1646	республика Татарстан, Камско-Устьинский район, село Мордовский Каратай, Центральная, 1	f	small
13068	278	1665	республика Татарстан, Камско-Устьинский район, село Малые Салтыки, Баки Урманче, 9	f	small
13074	284	1671	республика Татарстан, Камско-Устьинский район, село Малые Кармалы, Малая, 1а	f	small
13080	291	1677	республика Татарстан, Камско-Устьинский район, село Малые Буртасы, Центральная, 3	f	small
13069	279	1666	республика Татарстан, Камско-Устьинский район, село Малое Мереткозино, Вахитова, 9	f	small
13056	265	1653	республика Татарстан, Камско-Устьинский район, поселок Куйбышевский Затон, Ульяновское шоссе, 8	f	medium
13055	264	1652	республика Татарстан, Камско-Устьинский район, поселок Куйбышевский Затон, Ленина, 12	f	medium
13057	266	1654	республика Татарстан, Камско-Устьинский район, поселок Куйбышевский Затон, Гагарина, 12	f	medium
13079	290	1676	республика Татарстан, Камско-Устьинский район, село Красновидово, Мира, 1	f	small
13064	273	1661	республика Татарстан, Камско-Устьинский район, село Клянчеево, Габдуллы Тукая, 35	f	small
13058	267	1655	республика Татарстан, Камско-Устьинский район, село Кирельское, Площадь Совхозная, 13	f	small
13045	254	1642	республика Татарстан, Камско-Устьинский район, село Картапа, Школьная, 10	f	small
13046	255	1643	республика Татарстан, Камско-Устьинский район, село Караталга, Мостовая, 5	f	small
13053	262	1650	республика Татарстан, Камско-Устьинский район, поселок Камское Устье, Комарова, 16	f	medium
13052	261	1649	республика Татарстан, Камско-Устьинский район, поселок Камское Устье, Карла Маркса, 4	f	medium
13050	259	1647	республика Татарстан, Камско-Устьинский район, поселок Камское Устье, Карла Маркса, 105	f	medium
13051	260	1648	республика Татарстан, Камско-Устьинский район, поселок Камское Устье, Гагарина, 80	f	medium
13059	268	1656	республика Татарстан, Камско-Устьинский район, село Ишимово, Центральная, 10	f	small
13071	281	1668	республика Татарстан, Камско-Устьинский район, село Данышево, Кооперативная, 71	f	small
13081	292	1678	республика Татарстан, Камско-Устьинский район, село Варварино, Школьная, 6а	f	small
13070	280	1667	республика Татарстан, Камско-Устьинский район, село Большие Салтыки, Свердлова, 126	f	small
13062	271	1659	республика Татарстан, Камско-Устьинский район, село Большие Кляри, Пионерская, 5	f	small
13072	282	1669	республика Татарстан, Камско-Устьинский район, село Большие Кармалы, Школьная, 6	f	small
13065	275	1662	республика Татарстан, Камско-Устьинский район, село Большие Буртасы, Ленинградская, 27	f	small
13067	277	1664	республика Татарстан, Камско-Устьинский район, село Большая Янгасала, Центральная, 1	f	small
13073	283	1670	республика Татарстан, Камско-Устьинский район, село Баргузино, Школьная, 16	f	small
13066	276	1663	республика Татарстан, Камско-Устьинский район, село Балчиклы, Ленина, 70	f	small
13048	257	1645	республика Татарстан, Камско-Устьинский район, село Атабаево, Центральная, 14	f	small
13043	251	1640	республика Татарстан, Камско-Устьинский район, село Азимово-Курлебаш, Центральная, 2а	f	small
13013	216	1610	республика Татарстан, Кайбицкий район, станция Куланга, Светлая, 21а	f	small
132491	221	1614	республика Татарстан, Кайбицкий район, д.Имянле Буртас, Гагарина, 7а, 422327, Буртасский дом культуры	f	\N
13021	226	1618	республика Татарстан, Кайбицкий район, село Янсуринское, Кирова, 14	f	\N
13031	237	1628	республика Татарстан, Кайбицкий район, село Эбалаково, Светлая, 5	f	small
13015	218	1612	республика Татарстан, Кайбицкий район, село Шушерма, Ямашева, 1	f	small
13024	230	1621	республика Татарстан, Кайбицкий район, село Чутеево, Кооперативная, 37	f	small
13022	228	1619	республика Татарстан, Кайбицкий район, село Хозесаново, Центральная, 16	f	small
13011	213	1608	республика Татарстан, Кайбицкий район, село Федоровское, Тутаева, 41	f	medium
13041	249	1638	республика Татарстан, Кайбицкий район, село Ульянково, Школьная, 39	f	small
13023	229	1620	республика Татарстан, Кайбицкий район, село Турминское, Центральная, 6	f	small
13026	232	1623	республика Татарстан, Кайбицкий район, село Старые Чечкабы, Клубная, 4	f	small
13020	225	1617	республика Татарстан, Кайбицкий район, село Старое Тябердино, Советская, 27	f	small
13019	224	1616	республика Татарстан, Кайбицкий район, село ПолеваяБуа, Центральная, 51	f	small
13009	211	1606	республика Татарстан, Кайбицкий район, село Надеждино, Центральная, 17	f	small
13010	212	1607	республика Татарстан, Кайбицкий район, село Мурали, Центральная, 45	f	small
132492	223	1615	республика Татарстан, Кайбицкий район, село Молькеево, Почтовая , 18, Молькеевский дом культуры	f	\N
13016	219	1613	республика Татарстан, Кайбицкий район, село Малые Меми, Центральная, 27	f	small
13029	235	1626	республика Татарстан, Кайбицкий район, село Малые Кушманы, Школьная, 31	f	medium
13030	236	1627	республика Татарстан, Кайбицкий район, село Малые Кайбицы, Центральная, 52	f	small
13034	242	1631	республика Татарстан, Кайбицкий район, село Малое Русаково, Усманова, 46	f	small
13040	248	1637	республика Татарстан, Кайбицкий район, село Малое Подберезье, Большая Красная, 32б	f	small
13042	250	1639	республика Татарстан, Кайбицкий район, село Корноухово, Бутанина, 58	f	small
13039	247	1636	республика Татарстан, Кайбицкий район, село Каргалы, Красный Герой, 16	f	small
13014	217	1611	республика Татарстан, Кайбицкий район, село Бурундуки, Октябрьская, 22	f	small
13025	231	1622	республика Татарстан, Кайбицкий район, село Большое Тябердино, Центральная, 21	f	small
13033	241	1630	республика Татарстан, Кайбицкий район, село Большое Русаково, Зиганшина, 38	f	small
13038	246	1635	республика Татарстан, Кайбицкий район, село Большое Подберезье, Площадь Свободы, 31	f	medium
13027	233	1624	республика Татарстан, Кайбицкий район, село Большие Кайбицы, Шамиля Галеева, 11	f	large
132494	240	1629	республика Татарстан, Кайбицкий район, село Берлибаш, Школьная, 1, Берлибашская школа	f	\N
13012	215	1609	республика Татарстан, Кайбицкий район, село Беляево, Школьная, 1	f	small
13035	243	1632	республика Татарстан, Кайбицкий район, село Багаево, Центральная, 28	f	small
13028	234	1625	республика Татарстан, Кайбицкий район, село Афанасьевка, Конторская, 9	f	small
13036	244	1633	республика Татарстан, Кайбицкий район, село Арасланово, Чапаева, 18	f	small
12997	198	1594	республика Татарстан, Зеленодольский район, село Утяшки, Центральная, 40а	f	small
12998	199	1595	республика Татарстан, Зеленодольский район, село Утяково, Мира, 25а	f	small
12964	163	1561	республика Татарстан, Зеленодольский район, село Уразла, Дружбы, 3	f	small
13004	206	1601	республика Татарстан, Зеленодольский район, село Товлино, Центральная, 14	f	small
13002	204	1599	республика Татарстан, Зеленодольский район, село Татарское Танаево, Центральная, 1а	f	small
13007	209	1604	республика Татарстан, Зеленодольский район, село Сунчелеево, Чишма, 6	f	small
12982	183	1579	республика Татарстан, Зеленодольский район, село Свияжск, Рождественская, 1	f	small
12999	200	1596	республика Татарстан, Зеленодольский район, село Русское Азелеево, Центральная, 1/3	f	small
12961	160	1558	республика Татарстан, Зеленодольский район, село Раифа, Клубный переулок, 15	f	\N
12986	187	1583	республика Татарстан, Зеленодольский район, село Протопоповка, Кооперативная, 7	f	small
12954	152	1551	республика Татарстан, Зеленодольский район, село Осиново, Гагарина, 11А	f	large
12993	194	1590	республика Татарстан, Зеленодольский район, село Нурлаты, Школьная, 1	f	large
12994	195	1591	республика Татарстан, Зеленодольский район, село Нурлаты, Гагарина, 46	f	small
12956	154	1553	республика Татарстан, Зеленодольский район, село Новопольский, Свободы, 39	f	medium
12991	192	1588	республика Татарстан, Зеленодольский район, село Нижние Ураспуги, Центральная, 63а	f	small
12983	184	1580	республика Татарстан, Зеленодольский район, поселок Нижние Вязовые, Школьная, 2	f	large
12985	186	1582	республика Татарстан, Зеленодольский район, поселок Нижние Вязовые, Советская, 108	f	large
12984	185	1581	республика Татарстан, Зеленодольский район, поселок Нижние Вязовые, Первомайская, 70	f	large
12996	197	1593	республика Татарстан, Зеленодольский район, село Молвино, Центральная, 17а	f	medium
13001	203	1598	республика Татарстан, Зеленодольский район, село Мамадыш-Акилово, Ленина, 19а	f	small
12988	189	1585	республика Татарстан, Зеленодольский район, село Малые Ширданы, Каюма Насыри, 31	f	small
13005	207	1602	республика Татарстан, Зеленодольский район, село Кугушево, Советская, 17	f	medium
13003	205	1600	республика Татарстан, Зеленодольский район, село Кугеево, Центральная, 32	f	small
12957	155	1554	республика Татарстан, Зеленодольский район, село Красный Яр, Школьная, 1	f	small
12995	196	1592	республика Татарстан, Зеленодольский район, село Косяково, Светлая, 6	f	small
13000	202	1597	республика Татарстан, Зеленодольский район, село Карашам, Новая, 27	f	small
12965	164	1562	республика Татарстан, Зеленодольский район, село Каратмень, Клубная, 23	f	small
12990	191	1587	республика Татарстан, Зеленодольский район, деревня Васюково, Ибрагимова, 54а	f	small
12975	175	1572	республика Татарстан, Зеленодольский район, поселок Васильево, Школьная, 58	f	large
12974	174	1571	республика Татарстан, Зеленодольский район, поселок Васильево, Территория Санатория, Центр досуга	f	large
12970	169	1567	республика Татарстан, Зеленодольский район, поселок Васильево, Спортивная, 24	f	large
12978	179	1575	республика Татарстан, Зеленодольский район, поселок Васильево, Свободы, 1	f	large
12977	178	1574	республика Татарстан, Зеленодольский район, поселок Васильево, Праздничная, 9	f	medium
12979	180	1576	республика Татарстан, Зеленодольский район, поселок Васильево, Первомайская, 26	f	medium
12976	176	1573	республика Татарстан, Зеленодольский район, поселок Васильево, Набережная, 17	f	large
12973	173	1570	республика Татарстан, Зеленодольский район, поселок Васильево, Ленина, 6	f	medium
12972	172	1569	республика Татарстан, Зеленодольский район, поселок Васильево, Ленина, 40	f	medium
132490	171	1568	республика Татарстан, Зеленодольский район, поселок Васильево, Ленина, 59а, здание детской художественной школы	f	\N
12981	182	1578	республика Татарстан, Зеленодольский район, поселок Васильево, Лагерная, к/концертный зал ЛОК Сосновый бор	f	large
12980	181	1577	республика Татарстан, Зеленодольский район, поселок Васильево, Залесная, 14а	f	medium
12968	167	1565	республика Татарстан, Зеленодольский район, село Большой Кульбаш, Подгорная, 26	f	small
12989	190	1586	республика Татарстан, Зеленодольский район, село Большое Ходяшево, Светлая, 2	f	small
12966	165	1563	республика Татарстан, Зеленодольский район, село Большие Яки, Школьная, 5	f	small
12987	188	1584	республика Татарстан, Зеленодольский район, село Большие Ширданы, Кирова, 6	f	small
12967	166	1564	республика Татарстан, Зеленодольский район, село Большие Кургузи, Школьная, 30	f	medium
12962	161	1559	республика Татарстан, Зеленодольский район, село Большие Ключи, Волостнова, 21А	f	large
12992	193	1589	республика Татарстан, Зеленодольский район, село Большие Ачасыры, Кооперативная, 26	f	medium
12963	162	1560	республика Татарстан, Зеленодольский район, село Бишня, Школьная, 10	f	medium
12960	158	1557	республика Татарстан, Зеленодольский район, село Бело-Безводное, Юбилейная, 13	f	medium
13006	208	1603	республика Татарстан, Зеленодольский район, село Акзигитово, Центральная, 7	f	small
12958	156	1555	республика Татарстан, Зеленодольский район, село Айша, Светлая, 1	f	medium
12959	157	1556	республика Татарстан, Зеленодольский район, село Айша, Молодежная, 60	f	large
12955	153	1552	республика Татарстан, Зеленодольский муниципальный район, село Осиново, 40 лет Победы, 5	f	large
12953	151	1550	республика Татарстан, Зеленодольский муниципальный район, село Осиново, 40 лет Победы, 1	f	large
12969	168	1566	республика Татарстан, Зеленодольский муниципальный район, поселок Октябрьский, Школьная, 1	f	large
12898	102	1495	республика Татарстан, Заинский район, село Шикмамаево, Центральная, 65А	f	small
12912	114	1509	республика Татарстан, Заинский район, Чубуклы, Молодежная, 229А	f	small
12911	113	1508	республика Татарстан, Заинский район, село Урсаево, Центральная, 5	f	small
12909	94003	1506	республика Татарстан, Заинский район, село Тюгеевка, Школьная, 89	f	small
12894	97	1491	республика Татарстан, Заинский район, село Тонгузино, Центральная, 8А	f	small
12913	115	1510	республика Татарстан, Заинский район, село Суык-Чишма, Центральная, 30А	f	small
12907	110	1504	республика Татарстан, Заинский район, село Старое Маврино, Центральная, 4	f	small
12897	100	1494	республика Татарстан, Заинский район, Село Пусташит, Габдуллы Тукая, 56	f	\N
12905	108	1502	республика Татарстан, Заинский район, село Светлое Озеро, Ленина, 81	f	small
12904	108	1501	республика Татарстан, Заинский район, село Светлое Озеро, Ленина, 81	f	small
12903	107	1500	республика Татарстан, Заинский район, село Сармаш-Баш, Центральная, 144	f	small
12902	106	1499	республика Татарстан, Заинский район, село Сарапала, Центральная, 28	f	small
12906	109	1503	республика Татарстан, Заинский район, село Савалеево, Центральная, 11	f	medium
12901	105	1498	республика Татарстан, Заинский район, село Поручиково, Чапаева, 25	f	small
12900	104	1497	республика Татарстан, Заинский район, село Поповка, Центральная, 4	f	small
12899	103	1496	республика Татарстан, Заинский район, село Новоспасск, Молодежная, 14	f	small
12881	83	1478	республика Татарстан, Заинский район, село Нижние Лузы, Центральная, 38а	f	small
12895	98	1492	республика Татарстан, Заинский район, село Нижнее Бишево, Центральная, 47	f	small
12896	99	1493	республика Татарстан, Заинский район, село Куш-Елга, Закира Салимова, 9	f	small
12888	91	1485	республика Татарстан, Заинский район, Гулькино, Центральная, 27	f	small
12880	82	1477	республика Татарстан, Заинский район, село Верхние Лузы, Центральная, 38А	f	small
12910	112	1507	республика Татарстан, Заинский район, село Алексеевка, Центральная, 22	f	small
12873	74	1470	республика Татарстан, Заинский район, село Александровская Слобода, Центральная, 72Б	f	small
12871	72	1468	республика Татарстан, Заинский муниципальный район, село Старый Токмак, Советская, 5А	f	small
12875	76	1472	республика Татарстан, Заинский муниципальный район, село Средний Багряж, Центральная, 47А	f	small
12908	111	1505	республика Татарстан, Заинский муниципальный район, Село Новое Маврино, Дорожная, ФАП	f	small
12876	77	1473	республика Татарстан, Заинский муниципальный район, село Сарсаз Багряж, Школьная, 3	f	small
12879	81	1476	республика Татарстан, Заинский муниципальный район, село Керекес, Центральная, 34А	f	small
12878	80	1475	республика Татарстан, Заинский муниципальный район, село Карманово, Центральная, 43Б	f	small
12892	95	1489	республика Татарстан, Заинский муниципальный район, село Кадырово, Молодежная, 1	f	small
12887	90	1484	республика Татарстан, Заинский муниципальный район, село Имянлебаш, Центральная, 63	f	small
12891	94	1488	республика Татарстан, Заинский муниципальный район, село Зычебаш, Центральная, 102	f	small
12865	66	1462	республика Татарстан, Заинский муниципальный район, Заинск, пр. Победы, 5	f	medium
12864	66	1461	республика Татарстан, Заинский муниципальный район, Заинск, пр. Победы, 5	f	large
12861	64	1458	республика Татарстан, Заинский муниципальный район, Заинск, пр. Победы, 1/12	f	large
12857	62	1454	республика Татарстан, Заинский муниципальный район, Заинск, пр. Нефтяников, 33	f	large
12855	60	1452	республика Татарстан, Заинский муниципальный район, Заинск, Энергетиков, 8	f	medium
12869	70	1466	республика Татарстан, Заинский муниципальный район, Заинск, Ульянова, 63	f	large
12868	69	1465	республика Татарстан, Заинский муниципальный район, Заинск, Толстого, 39	f	large
12867	68	1464	республика Татарстан, Заинский муниципальный район, Заинск, Пионерская, 16	f	large
12856	61	1453	республика Татарстан, Заинский муниципальный район, Заинск, Лобачевского, 5	f	large
12851	58	1448	республика Татарстан, Заинский муниципальный район, Заинск, Ленина, 17	f	large
12850	58	1447	республика Татарстан, Заинский муниципальный район, Заинск, Ленина, 17	f	medium
12849	58	1446	республика Татарстан, Заинский муниципальный район, Заинск, Ленина, 17	f	medium
12846	56	1443	республика Татарстан, Заинский муниципальный район, Заинск, Ленина, 26А	f	medium
12847	56	1444	республика Татарстан, Заинский муниципальный район, Заинск, Ленина, 26А	f	large
12845	55	1442	республика Татарстан, Заинский муниципальный район, Заинск, Ленина, 29А	f	large
12854	59	1451	республика Татарстан, Заинский муниципальный район, Заинск, Комсомольская, 50А	f	medium
12853	59	1450	республика Татарстан, Заинский муниципальный район, Заинск, Комсомольская, 50А	f	medium
12852	59	1449	республика Татарстан, Заинский муниципальный район, Заинск, Комсомольская, 50А	f	medium
12848	57	1445	республика Татарстан, Заинский муниципальный район, Заинск, Комсомольская, 50	f	large
12860	63	1457	республика Татарстан, Заинский муниципальный район, Заинск, Казанская, 5	f	large
12859	63	1456	республика Татарстан, Заинский муниципальный район, Заинск, Казанская, 5	f	large
12858	63	1455	республика Татарстан, Заинский муниципальный район, Заинск, Казанская, 5	f	large
12866	67	1463	республика Татарстан, Заинский муниципальный район, Заинск, Заводская, 1	f	large
12890	93	1487	республика Татарстан, Заинский муниципальный район, село Дурт-Мунча, Молодежная , 147	f	small
12872	73	1469	республика Татарстан, Заинский муниципальный район, село Вторая Бугульда, Пушкина, бригадный дом КФХ Шакирзянова	f	small
12883	85	1480	республика Татарстан, Заинский муниципальный район, село Верхний Налим, Молодежная, 7	f	small
12874	75	1471	республика Татарстан, Заинский муниципальный район, село Верхний Багряж, Советская, 4А	f	small
12886	89	1483	республика Татарстан, Заинский муниципальный район, село Верхние Шипки, Молодежная, 2	f	medium
12885	88	1482	республика Татарстан, Заинский муниципальный район, село Верхние Пинячи, Речная, 26А	f	small
12882	84	1479	республика Татарстан, Заинский муниципальный район, село Бухарай, Школьная, 12	f	medium
12884	87	1481	республика Татарстан, Заинский муниципальный район, село Бура-Кирта, Центральная, 20А	f	small
12877	78	1474	республика Татарстан, Заинский муниципальный район, село Бегишево, Клубная, 117	f	\N
12893	96	1490	республика Татарстан, Заинский муниципальный район, село Ахметьево, Центральная, 62	f	small
12870	71	1467	республика Татарстан, Заинский муниципальный район, село Аксарино, Вахитова, 2	f	medium
12827	36	1424	республика Татарстан, Елабужский район, село Малоречинский, Центральная, 17	f	small
12831	40	1428	республика Татарстан, Елабужский район, село Лекарево, Московская, 13	f	small
12828	37	1425	республика Татарстан, Елабужский район, село Большой Шурняк, Ленина, 8	f	small
12826	35	1423	республика Татарстан, Елабужский район, село Большая Качка, Школьная, 12	f	small
12844	54	1441	республика Татарстан, Елабужский муниципальный район, село Яковлево, Мира, 1	f	small
12842	52	1439	республика Татарстан, Елабужский муниципальный район, село Хлыстово, Набережная, 31	f	small
12843	53	1440	республика Татарстан, Елабужский муниципальный район, село Татарский Дюм-Дюм, Школьная, 3	f	small
12840	50	1437	республика Татарстан, Елабужский муниципальный район, село Танайка, Ермазова, 9	f	large
12839	49	1436	республика Татарстан, Елабужский муниципальный район, село Старый Юраш, Школьная, 33	f	small
12838	48	1435	республика Татарстан, Елабужский муниципальный район, село Старый Куклюк, Садовая, 1а	f	small
12834	44	1431	республика Татарстан, Елабужский муниципальный район, село Старая Мурзиха, Центральная, 3	f	small
12836	46	1433	республика Татарстан, Елабужский муниципальный район, село Поспелово, Лесная, 7	f	small
12835	45	1432	республика Татарстан, Елабужский муниципальный район, село Покровское, Прикамская, 19	f	small
12833	42	1430	республика Татарстан, Елабужский муниципальный район, село Морты, Казанская, 60а	f	medium
12837	47	1434	республика Татарстан, Елабужский муниципальный район, село Мальцево, Есенина, 41	f	small
12830	39	1427	республика Татарстан, Елабужский муниципальный район, село Котловка, Нефтяников, 2	f	small
12829	38	1426	республика Татарстан, Елабужский муниципальный район, село Костенеево, Молодежная, 30	f	medium
12841	51	1438	республика Татарстан, Елабужский муниципальный район, село Колосовка, Центральная, 20	f	small
12824	33	1421	республика Татарстан, Елабужский муниципальный район, село Гари, Центральная, 7	f	small
12825	34	1422	республика Татарстан, Елабужский муниципальный район, село Большое Елово, 40 лет Победы, 2	f	small
12832	41	1429	республика Татарстан, Елабужский муниципальный район, село Большие Армалы, Центральная, 9	f	small
12823	32	1420	республика Татарстан, Елабужский муниципальный район, село Бехтерево, Гусева, 8	f	small
12822	31	1419	республика Татарстан, Елабужский муниципальный район, село Альметьево, Сайдашева, 4	f	small
12762	94284	1359	республика Татарстан, Дрожжановский район, село Шланга, Ленина, 26	f	medium
12768	94291	1365	республика Татарстан, Дрожжановский район, село Чувашское Дрожжаное, Октябрьская, 21а	f	medium
12754	94276	1351	республика Татарстан, Дрожжановский район, село Чувашская Бездна, Горького, 8	f	small
12782	94305	1379	республика Татарстан, Дрожжановский район, село Чепкас-Ильметьево, Школьная, 22	f	small
12780	94303	1377	республика Татарстан, Дрожжановский район, село Хорновар Шигали, Горького, 2	f	small
12769	94292	1366	республика Татарстан, Дрожжановский район, село Хайбулдино, Клубная, 1	f	small
12777	94300	1374	республика Татарстан, Дрожжановский район, село Убей, Красная площадь, 48	f	small
12749	94271	1346	республика Татарстан, Дрожжановский район, село Татарские Шатрашаны, Комарова, 26	f	small
12764	94287	1361	республика Татарстан, Дрожжановский район, село Татарские Тюки, Советская, 1	f	small
12759	94281	1356	республика Татарстан, Дрожжановский район, село Татарская Бездна, Гагарина, 32	f	small
12755	94277	1352	республика Татарстан, Дрожжановский район, село Старые Чукалы, Коминтерна, 18	f	medium
12763	94286	1360	республика Татарстан, Дрожжановский район, село Старые Какерли, Советская, 38	f	medium
12766	94289	1363	республика Татарстан, Дрожжановский район, село Старые Ишли, Центральная, 16	f	small
12747	94269	1344	республика Татарстан, Дрожжановский район, село Старое Шаймурзино, Ленина, 61	f	large
12770	94293	1367	республика Татарстан, Дрожжановский район, село Старое Ильмово, Центральная, 23	f	small
12774	94297	1371	республика Татарстан, Дрожжановский район, село Старое Дуваново, Крепкова, 1	f	small
12772	94295	1369	республика Татарстан, Дрожжановский район, село Старое Дрожжаное, Центральная, 9	f	large
12771	94294	1368	республика Татарстан, Дрожжановский район, село Старое Дрожжаное, Центральная, 15	f	large
12776	94299	1373	республика Татарстан, Дрожжановский район, село Старая Задоровка, Ленина, 1	f	small
12778	94301	1375	республика Татарстан, Дрожжановский район, село Новый Убей, Центральная, 61	f	small
12757	94279	1354	республика Татарстан, Дрожжановский район, село Новые Чукалы, Советская, 20А	f	small
12767	94290	1364	республика Татарстан, Дрожжановский район, село Новые Какерли, Ленина, 31	f	small
12765	94288	1362	республика Татарстан, Дрожжановский район, село Новые Ишли, Кооперативная, 9	f	small
12752	94274	1349	республика Татарстан, Дрожжановский район, село Новое Чекурское, Центральная, 22б	f	small
12756	94278	1353	республика Татарстан, Дрожжановский район, село Новое Ильмово, Советская, 34	f	medium
12773	94296	1370	республика Татарстан, Дрожжановский район, село Новое Дрожжаное, Молодежная, 17	f	medium
12758	94280	1355	республика Татарстан, Дрожжановский район, село Нижний Каракитан, Ленина, 30	f	medium
12750	94272	1347	республика Татарстан, Дрожжановский район, село Нижнее Чекурское, Дорожная, д.12	f	medium
12761	94283	1358	республика Татарстан, Дрожжановский район, село Мочалей, Замалетдинова, 10	f	small
12760	94282	1357	республика Татарстан, Дрожжановский район, село Матаки, Уганина, 22а	f	medium
12779	94302	1376	республика Татарстан, Дрожжановский район, село Малый Убей, Центральная, 19	f	small
12783	94306	1380	республика Татарстан, Дрожжановский район, село Малая Цильна, Крупская, 2	f	large
12781	94304	1378	республика Татарстан, Дрожжановский район, село Коршанга Шигали, Комсомольская, 5	f	small
12751	94273	1348	республика Татарстан, Дрожжановский район, село Городище, Клубная, 6а	f	medium
12748	94270	1345	республика Татарстан, Дрожжановский район, село Бурундуки, Вокзальная, 27	f	small
12746	94268	1343	республика Татарстан, Дрожжановский район, село Большая Цильна, Родина, 1	f	medium
12753	94275	1350	республика Татарстан, Дрожжановский район, село Большая Акса, Октябрьская, 47	f	medium
12775	94298	1372	республика Татарстан, Дрожжановский район, село Алешкин Саплык, Школьная, 3а	f	medium
12710	94223	1307	республика Татарстан, Высокогорский район, село совхоз Бирюлинский, Кольцевая, 33	f	large
12698	94210	1295	республика Татарстан, Высокогорский район, село Янга-Аул, Кирова, 29	f	small
12727	94246	1324	республика Татарстан, Высокогорский район, село Ямашурма, Нариманова, 15	f	medium
9094	54262	240	республика Марий Эл, Звенигово, Чехова, 38	f	large
12729	94225	1326	республика Татарстан, Высокогорский район, село Юртыш, Кооперативная, 34	f	small
12745	94267	1342	республика Татарстан, Высокогорский район, село Шуманы, Северная, 20	f	small
12726	94245	1323	республика Татарстан, Высокогорский район, село Шапши, Ленина, 2	f	medium
132477	94220	1304	республика Татарстан, Высокогорский район, село Чувашли, Клубная, 23, здание сельского клуба	f	\N
12703	94215	1300	республика Татарстан, Высокогорский район, село Чирши, Центральня, 34	f	small
12740	94262	1337	республика Татарстан, Высокогорский район, село Чернышевка, Клубная, 1	f	medium
12741	94263	1338	республика Татарстан, Высокогорский район, село Чепчуги, Школьная, 1	f	large
12739	94261	1336	республика Татарстан, Высокогорский район, село Усады, Советская, 41	f	large
12738	94259	1335	республика Татарстан, Высокогорский район, село Ташлы-Ковали, Школьная, 94	f	small
12743	94265	1340	республика Татарстан, Высокогорский район, село Татарская Айша, Школьная, 20	f	small
12735	94256	1332	республика Татарстан, Высокогорский район, село Суксу, Комсомольская, 18А	f	\N
12734	94254	1331	республика Татарстан, Высокогорский район, село Средний Алат, Центральная, 27	f	small
12737	94258	1334	республика Татарстан, Высокогорский район, село Сосновка, Центральная, 68А	f	small
12732	94252	1329	республика Татарстан, Высокогорский район, село Семиозерка, Верхняя, 99А	f	small
12700	94212	1297	республика Татарстан, Высокогорский район, село Сая, Светлая, 13	f	small
12731	94251	1328	республика Татарстан, Высокогорский район, село Пановка, Крупской, 33	f	medium
132481	94237	1314	республика Татарстан, Высокогорский район, село Наратлык, Аринская , 25, здание ГБУ Ислейтарлес	f	\N
12730	94250	1327	республика Татарстан, Высокогорский район, село Мульма, Центральная, 28А	f	\N
12728	94247	1325	республика Татарстан, Высокогорский район, село Мемдель, Кооперативная, 30А	f	small
132480	94233	1316	республика Татарстан, Высокогорский район, село Малый Сулабаш, Школьная, 5, здание дома культуры	f	\N
12736	94257	1333	республика Татарстан, Высокогорский район, село Малая Рясь, Г.Камала, 18	f	small
12742	94264	1339	республика Татарстан, Высокогорский район, село Куркачи, Клубная, 4	f	medium
12744	94266	1341	республика Татарстан, Высокогорский район, поселок Куркачи, Гагарина, 7	f	large
12715	94231	1312	республика Татарстан, Высокогорский район, село Калинино, Центральная, 32	f	medium
12718	94235	1315	республика Татарстан, Высокогорский район, село Казаклар, Советская, 11	f	small
12705	94217	1302	республика Татарстан, Высокогорский район, село Инся, Колхозная, 7А	f	small
12716	94232	1313	республика Татарстан, Высокогорский район, село Дубъязы, Ленина, 35	f	large
12702	94214	1299	республика Татарстан, Высокогорский район, село Гарь, Школьная, 1	f	small
132479	94229	1311	республика Татарстан, Высокогорский район, село Высокая Гора, Центральная, 11а, здание спортивного комплекса	f	\N
132478	94226	1309	республика Татарстан, Высокогорский район, село Высокая Гора, Татарстан, 25, здание школы № 3	f	\N
12725	94244	1322	республика Татарстан, Высокогорский район, село Большой Куюк, Школьная, 6	f	small
12708	94221	1305	республика Татарстан, Высокогорский район, село Большой Битаман, Московская, 2В	f	medium
12706	94218	1303	республика Татарстан, Высокогорский район, село Большие Ковали, Клубная, 8	f	small
12709	94222	1306	республика Татарстан, Высокогорский район, село Бикнарат, Центральная, 19	f	small
132482	94239	1318	республика Татарстан, Высокогорский район, поселок Березовка, Центральная, 65, здание ТСЖ	f	\N
12704	94216	1301	республика Татарстан, Высокогорский район, село Березка, Центральная, 12	f	medium
12699	94211	1296	республика Татарстан, Высокогорский район, село Альдермыш, Ленина, 26	f	small
12701	94213	1298	республика Татарстан, Высокогорский район, село Алан-Бексерь, Центральная, 17	f	small
12724	94243	1321	республика Татарстан, Высокогорский район, село Айбаш, Центральная, 31	f	small
12691	94203	1288	республика Татарстан, Верхнеуслонский район, село Янга-Юл, Центральная, 18А	f	small
132475	94197	1283	республика Татарстан, Верхнеуслонский район, село Ямбулатово, Школьная, 5, здание МОУ общеобразовательной школы	f	\N
12689	94200	1286	республика Татарстан, Верхнеуслонский район, село Шеланга, Строителей, 47	f	small
12688	94199	1285	республика Татарстан, Верхнеуслонский район, село Шеланга, Советская, 7	f	medium
132474	94189	1276	республика Татарстан, Верхнеуслонский район, село Чулпаниха, Центральная , 81, здание фельдшерско-акушерского пункта	f	\N
12676	94185	1273	республика Татарстан, Верхнеуслонский район, село Уланово, Заозерная, 15	f	small
12668	94175	1265	республика Татарстан, Верхнеуслонский район, село Татарское Бурнашево, Советская, 62	f	small
12687	94198	1284	республика Татарстан, Верхнеуслонский район, село Старое Русское-Маматкозино, Дорожная, 1	f	small
12678	94187	1275	республика Татарстан, Верхнеуслонский район, село Соболевское, Береговая, 30	f	small
12672	94180	1269	республика Татарстан, Верхнеуслонский район, село Сеитово, Центральная, 29	f	small
12673	94181	1270	республика Татарстан, Верхнеуслонский район, село Русское Макулово, Центральная, 125	f	small
12674	94182	1271	республика Татарстан, Верхнеуслонский район, село Русское Макулово, Садовая, 5	f	medium
12669	94176	1266	республика Татарстан, Верхнеуслонский район, село Русское Бурнашево, Большая, 4	f	small
12682	94192	1279	республика Татарстан, Верхнеуслонский район, село Патрикеево, Береговая, 10	f	small
12695	94207	1292	республика Татарстан, Верхнеуслонский район, поселок Октябрьский, Центральная, 7	f	small
12684	94194	1281	республика Татарстан, Верхнеуслонский район, село Нижнее Озеро, Вахитовский район, Центральная, 7	f	small
132476	94201	1287	республика Татарстан, Верхнеуслонский район, село Нариман, Центральная, 12А, здание сельского клуба	f	\N
12666	94172	1263	республика Татарстан, Верхнеуслонский район, село Набережные Моркваши, Красавина, 40	f	medium
12694	94206	1291	республика Татарстан, Верхнеуслонский район, село Матюшино, Волжская, 1	f	small
12685	94195	1282	республика Татарстан, Верхнеуслонский район, село Майдан, Советская, 35	f	small
12670	94177	1267	республика Татарстан, Верхнеуслонский район, село Куралово, Центральная, 25	f	medium
12671	94178	1268	республика Татарстан, Верхнеуслонский район, село Куралово, Пионерская, 19	f	small
12680	94190	1277	республика Татарстан, Верхнеуслонский район, село Коргуза, Центральная Площадь, 1	f	small
132473	94183	1272	республика Татарстан, Верхнеуслонский район, село Клянчино, Центральная, 26, здание сельского клуба	f	\N
12677	94186	1274	республика Татарстан, Верхнеуслонский район, село Кильдеево, Центральная, 16	f	small
12681	94191	1278	республика Татарстан, Верхнеуслонский район, село Егидерево, Центральная, 30	f	small
12658	94162	1255	республика Татарстан, Верхнеуслонский район, село Верхний Услон, Чехова, 54	f	small
12659	94163	1256	республика Татарстан, Верхнеуслонский район, село Верхний Услон, Советская, 22	f	small
12663	94169	1260	республика Татарстан, Верхнеуслонский район, село Верхний Услон, Печищинский тракт, 1	f	small
12657	94161	1254	республика Татарстан, Верхнеуслонский район, село Верхний Услон, Колхозная, 32	f	small
132472	94173	1264	республика Татарстан, Верхнеуслонский район, село Введенская Слобода, Центральная, 53А, здание МОУ общеобразовательной школы	f	\N
12683	94193	1280	республика Татарстан, Верхнеуслонский район, село Большие Меми, Молодежная, 19	f	small
12693	94205	1290	республика Татарстан, Верхнеуслонский район, село Бахчи-Сарай, Центральная, 1	f	small
12656	94160	1253	республика Татарстан, Буинский район, село Яшевка, Нагорная, 9	f	small
12593	94095	1190	республика Татарстан, Буинский район, село Яскуль, Ленина, 71	f	small
12654	94158	1251	республика Татарстан, Буинский район, село Энтуганы, Центральная, 12	f	small
12641	94145	1238	республика Татарстан, Буинский район, село Шаймурзино, Кооперативная, 5	f	small
12636	94139	1233	республика Татарстан, Буинский район, село Чураково, Центральная, 53А	f	\N
12651	94155	1248	республика Татарстан, Буинский район, село Чувашские Кищаки, Ленина, 39	f	small
12607	94109	1204	республика Татарстан, Буинский район, село Чувашская Беловолжка, Школьная, 1А	f	small
12648	94152	1245	республика Татарстан, Буинский район, село Черки-Кильдуразы, пр-т.Иванова, 5	f	medium
12602	94104	1199	республика Татарстан, Буинский район, село Черки-Дюртиле, Советская, 5	f	small
12646	94150	1243	республика Татарстан, Буинский район, село Черки-Гришино, Озерная, 1	f	medium
12608	94110	1205	республика Татарстан, Буинский район, село Тойгильды, Октябрьская, 2А	f	small
12596	94098	1193	республика Татарстан, Буинский район, село Тингаш, Комсомольская, 2	f	small
12645	94149	1242	республика Татарстан, Буинский район, село Тимбаево, Мира, 14	f	small
12620	94122	1217	республика Татарстан, Буинский район, село Татарское Пимурзино, Вахитова, 15А	f	small
12606	94108	1203	республика Татарстан, Буинский район, село Татарская Беловолжка, Мира, 19	f	small
12652	94156	1249	республика Татарстан, Буинский район, село Таковары, Школьная, 12	f	small
12613	94115	1210	республика Татарстан, Буинский район, село Степные-Енали, Школьная, 1	f	small
12601	94103	1198	республика Татарстан, Буинский район, село Степановка, Колхозная, 11	f	small
12639	94143	1236	республика Татарстан, Буинский район, село Старый Студенец, Школьная, 4	f	large
12640	94144	1237	республика Татарстан, Буинский район, село Старые Тинчали, Советская, 15	f	small
12622	94124	1219	республика Татарстан, Буинский район, село Старые Мертли, Школьная, 6	f	small
12604	94106	1201	республика Татарстан, Буинский район, село Старые Бурундуки, Колхозная, 53	f	small
12642	94146	1239	республика Татарстан, Буинский район, село Старостуденецкие Выселки, Школьная, 17	f	small
12638	94142	1235	республика Татарстан, Буинский район, село Сорок-Сайдак, Центральная, 2	f	small
12637	94141	1234	республика Татарстан, Буинский район, село Сорок-Сайдак, Центральная, 10	f	small
12643	94147	1240	республика Татарстан, Буинский район, село Сарсаз, Клубная, 6	f	small
12617	94119	1214	республика Татарстан, Буинский район, село Русские Кищаки, Садовая, 2	f	small
12635	94138	1232	республика Татарстан, Буинский район, село Рунга, Советская, 6	f	medium
12594	94096	1191	республика Татарстан, Буинский район, село Раково, Клубная, 6	f	small
12558	94056	1155	республика Татарстан, Буинский район, поселок Плодопитомник, Верхняя, 4	f	small
12634	94137	1231	республика Татарстан, Буинский район, село Нурлаты, Центральная, 14	f	small
12631	94134	1228	республика Татарстан, Буинский район, село Новые Чечкабы, Свободы, 32а	f	small
12629	94131	1226	республика Татарстан, Буинский район, село Новые Тинчали, Ленина, 30	f	medium
12619	94121	1216	республика Татарстан, Буинский район, село Новые Мертли, Победы, 13Б	f	small
12653	94157	1250	республика Татарстан, Буинский район, село Новоселки, Шоссейная, 2	f	small
12630	94133	1227	республика Татарстан, Буинский район, село Новая Цильна, О.Кошевого, 18А	f	small
12627	94129	1224	республика Татарстан, Буинский район, село Нижний Наратбаш, Советская, 2А	f	medium
12139	93622	736	республика Татарстан, Буинский район, село Мулланур-Вахитов, М.Вахитова, 35	f	small
12597	94099	1194	республика Татарстан, Буинский район, село Мулланур-Вахитов, Колхозная, 1	f	small
12625	94127	1222	республика Татарстан, Буинский район, село Мокрая Савалеевка, Молодежная, 49	f	medium
12624	94126	1221	республика Татарстан, Буинский район, село Мещеряково, М.Джалиля, 109	f	medium
12623	94125	1220	республика Татарстан, Буинский район, село Малая Буинка, Молодежная, 33А	f	medium
12647	94151	1244	республика Татарстан, Буинский район, село Лащи, Центральная, 3	f	small
12289	93782	886	республика Татарстан, Буинский район, село Кыр-Тавгельдино, Школьная, 1	f	\N
12632	94135	1229	республика Татарстан, Буинский район, село Кыр-Тавгельдино, Клубная, 8	f	small
12650	94154	1247	республика Татарстан, Буинский район, село КощаковоЧерки, Мирная, 2	f	small
12621	94123	1218	республика Татарстан, Буинский район, село Кошки-Шемякино, Революционная, 1	f	small
12618	94120	1215	республика Татарстан, Буинский район, село Кошки-Теняково, Школьная, 2А	f	small
12616	94118	1213	республика Татарстан, Буинский район, село Козловка, Широкая, 22	f	small
12615	94117	1212	республика Татарстан, Буинский район, село Кият, Молодежная, 9	f	medium
12644	94148	1241	республика Татарстан, Буинский район, село Каменный Брод, Центральная, 21	f	small
12599	94101	1196	республика Татарстан, Буинский район, село Каменный Брод, Ленина, 17	f	small
12612	94114	1209	республика Татарстан, Буинский район, село Кайбицы, Мирная, 12	f	small
12649	94153	1246	республика Татарстан, Буинский район, село Ишмяково-Черки, Московская, 31	f	small
12609	94111	1206	республика Татарстан, Буинский район, село Исаково, Зеленая, 31	f	small
12626	94128	1223	республика Татарстан, Буинский район, село Ембулатово, Пролетарская, 10	f	small
12655	94159	1252	республика Татарстан, Буинский район, село Вольный Стан, Калинина, 73	f	small
12614	94116	1211	республика Татарстан, Буинский район, село Верхний Наратбаш, Центральная, 45	f	small
12605	94107	1202	республика Татарстан, Буинский район, село Верхние Лащи, Центральная, 1	f	small
12603	94105	1200	республика Татарстан, Буинский район, село Бюрганы, Ленина, 43	f	medium
12600	94102	1197	республика Татарстан, Буинский район, село Большое Фролово, Гагарина, 7	f	small
12628	94130	1225	республика Татарстан, Буинский район, село Большая Карланга, Овражная, 13А	f	small
12598	94100	1195	республика Татарстан, Буинский район, село Бик-Утеево, Центральная, 25	f	small
12633	94136	1230	республика Татарстан, Буинский район, село Ахмаметьево, Центральная, 16А	f	small
12610	94112	1207	республика Татарстан, Буинский район, село Атабай-Анкебе, Центральная, 17	f	small
12595	94097	1192	республика Татарстан, Буинский район, село Альшихово, Правды, 48А	f	medium
12592	94094	1189	республика Татарстан, Буинский район, село Альшеево, Центральная, 18А	f	medium
12611	94113	1208	республика Татарстан, Буинский район, село Алькеево, Дружбы, 14	f	small
12591	94092	1188	республика Татарстан, Буинский район, село Аксу, Центральная, 116А	f	small
12590	94091	1187	республика Татарстан, Буинский район, село Адав-Тулумбаево, Советская, 19	f	medium
12572	94071	1169	республика Татарстан, Бугульминский район, село Татарская-Дымская, Ворошилова, 1А	f	medium
132466	94047	1146	республика Татарстан, Бугульминский район, село Таллы-Буляк, Новая , 18, здание Дома Культуры	f	\N
12567	94065	1164	республика Татарстан, Бугульминский район, село Старое Сумароково, Молодёжная, 6	f	small
12570	94069	1167	республика Татарстан, Бугульминский район, село Старое Исаково, Советская, 46	f	small
12568	94066	1165	республика Татарстан, Бугульминский район, село Спасское, Спасская, 16	f	small
12565	94063	1162	республика Татарстан, Бугульминский район, село Соколка, Полевая, 4А	f	small
12562	94060	1159	республика Татарстан, Бугульминский район, село Ростовка, Центральная, 3	f	small
12550	94048	1147	республика Татарстан, Бугульминский район, село Прогресс, Ягофарова, 10	f	medium
14243	1456	2840	республика Татарстан, Бугульминский район, село Подгорный, Центральная, 22а	f	small
12564	94062	1161	республика Татарстан, Бугульминский район, село Подгорный, Луговая, 5	f	medium
12555	94053	1152	республика Татарстан, Бугульминский район, село Победа, Пушкина, 23	f	small
12563	94061	1160	республика Татарстан, Бугульминский район, село Петровка, Центральная, 8	f	medium
12561	94059	1158	республика Татарстан, Бугульминский район, село Новое Сумароково, Советская, 13	f	small
12559	94057	1156	республика Татарстан, Бугульминский район, село Новая Александровка, Центральная, 2В	f	small
12560	94058	1157	республика Татарстан, Бугульминский район, село Наратлы, Советская, 28А	f	medium
12557	94055	1154	республика Татарстан, Бугульминский район, село Малая Бугульма, Совхозная, 7Б	f	large
12556	94054	1153	республика Татарстан, Бугульминский район, село Кудашево, Советская, 66А	f	medium
12554	94052	1151	республика Татарстан, Бугульминский район, село Ключи, Озерная, 1А	f	medium
12573	94072	1170	республика Татарстан, Бугульминский район, поселок Карабаш, Школьная, 4	f	large
12545	94042	1142	республика Татарстан, Бугульминский район, поселок Карабаш, Вахитова, 23	f	large
12551	94049	1148	республика Татарстан, Бугульминский район, село Зеленая Роща, Шоссейная, 9А	f	medium
12552	94050	1149	республика Татарстан, Бугульминский район, село Забугоровка, Ленина, 33А	f	small
12569	94067	1166	республика Татарстан, Бугульминский район, село Ефановка, Советская, 16	f	small
12571	94070	1168	республика Татарстан, Бугульминский район, село Восточный, Гафиатуллина, 8Б	f	medium
12548	94045	1145	республика Татарстан, Бугульминский район, село Березовка, Центральная, 5	f	large
12566	94064	1163	республика Татарстан, Бугульминский район, село Батыр, Школьная, 1А	f	small
12546	94043	1143	республика Татарстан, Бугульминский район, село Андреевка, Ключевская, 24	f	small
14237	1450	2834	республика Татарстан, Бугульминский район, село Акбаш, Школьная, 17	f	small
12502	94017	1099	республика Татарстан, Бугульминский муниципальный район, город Бугульма, Гафиатуллина, 20а	f	large
12501	94017	1098	республика Татарстан, Бугульминский муниципальный район, город Бугульма, Гафиатуллина, 20а	f	large
12485	94000	1082	республика Татарстан, Балтасинский район, село Ярак-Чурма, М.Горького, 28	f	small
12488	94004	1085	республика Татарстан, Балтасинский район, село Янгулово, Дружбы, 1	f	medium
12483	93998	1080	республика Татарстан, Балтасинский район, село Шишинер, Г.Тукая, 60	f	medium
12474	93989	1071	республика Татарстан, Балтасинский район, село Чутай, В.Булатова, 50	f	small
12486	94001	1083	республика Татарстан, Балтасинский район, село Ципья, Ленина, 12	f	large
12482	93997	1079	республика Татарстан, Балтасинский район, село Тюнтер, Колхозная, 7	f	small
12489	94005	1086	республика Татарстан, Балтасинский район, село Старый Кушкет, Дружбы, 18А	f	small
12477	93992	1074	республика Татарстан, Балтасинский район, село Старая Салаусь, Советская, 12	f	large
12481	93996	1078	республика Татарстан, Балтасинский район, село Средний Кушкет, Центральная, 6	f	small
12479	93994	1076	республика Татарстан, Балтасинский район, село Смаиль, Баумана, 50	f	medium
12475	93990	1072	республика Татарстан, Балтасинский район, село Пижмар, С.Муликова, 19	f	medium
12473	93988	1070	республика Татарстан, Балтасинский район, село Нуринер, Ленина, 97	f	medium
12494	94010	1091	республика Татарстан, Балтасинский район, село Норма, Казанская, 11	f	large
12471	93986	1068	республика Татарстан, Балтасинский район, село Норма, Казанская, 1	f	medium
12478	93993	1075	республика Татарстан, Балтасинский район, село Нижняя Сосна, Героя Сарвара, 2	f	medium
12468	93983	1065	республика Татарстан, Балтасинский район, село Нижняя Кня, Школьная, 5а	f	medium
12490	94006	1087	республика Татарстан, Балтасинский район, село Малые Лызи, Центральная, 1	f	medium
12466	93981	1063	республика Татарстан, Балтасинский район, село Кушкетбаш, Центральная, 15	f	small
12469	93984	1066	республика Татарстан, Балтасинский район, село Кугунур, Кирова, 103б	f	medium
12472	93987	1069	республика Татарстан, Балтасинский район, село Килеево, Г.Тукая, 33/3	f	medium
12467	93982	1064	республика Татарстан, Балтасинский район, село Карадуван, Сибирский Тракт, 30	f	medium
12470	93985	1067	республика Татарстан, Балтасинский район, село Дурга, Парковая, 2а	f	medium
12484	93999	1081	республика Татарстан, Балтасинский район, село Верхний Шубан, Центральная, 31	f	small
12465	93980	1062	республика Татарстан, Балтасинский район, село Верхний Субаш, Карла Маркса, 5	f	medium
12480	93995	1077	республика Татарстан, Балтасинский район, село Бурнак, Татарстана, 4	f	medium
12463	93978	1060	республика Татарстан, Балтасинский район, село Бурбаш, Шакирова, 18	f	medium
12492	94008	1089	республика Татарстан, Балтасинский район, поселок Балтаси, Наримана, 108	f	large
12493	94009	1090	республика Татарстан, Балтасинский район, село Балтаси, Ленина, 45	f	large
12462	93977	1059	республика Татарстан, Балтасинский район, село Балтаси, Ленина, 154	f	large
12491	94007	1088	республика Татарстан, Балтасинский район, село Балтаси, Карла Маркса, 7	f	large
12476	93991	1073	республика Татарстан, Балтасинский район, село Атня, Комсомола, 22	f	small
12487	94002	1084	республика Татарстан, Балтасинский район, село Арбор, Татарстана, 53	f	small
12451	93965	1048	республика Татарстан, Бавлинский район, п.Новозареченск, Вахитова, 15	f	medium
12452	93966	1049	республика Татарстан, Бавлинский район, село Шалты, Советская, 56а	f	small
12453	93967	1050	республика Татарстан, Бавлинский район, село Хансверкино, Советская, 31	f	small
12460	93975	1057	республика Татарстан, Бавлинский район, село Удмуртские Ташлы, Ленина, 61а	f	small
12441	93954	1038	республика Татарстан, Бавлинский район, село Уба, Центральная, 25	f	small
12443	93956	1040	республика Татарстан, Бавлинский район, село Ташлы, Подгорная, 9а	f	small
12456	93971	1053	республика Татарстан, Бавлинский район, село Татарский Кандыз, Советская, 68	f	\N
12448	93962	1045	республика Татарстан, Бавлинский район, село Татарская Тумбарла, Ленина, 51	f	medium
12455	93969	1052	республика Татарстан, Бавлинский район, село Салихово, Калинина, 21	f	small
12461	93976	1058	республика Татарстан, Бавлинский район, село Потапово-Тумбарла, Советская, 35	f	medium
12458	93973	1055	республика Татарстан, Бавлинский район, село Поповка, Центральная, 14	f	medium
12449	93963	1046	республика Татарстан, Бавлинский район, село Покровский Урустамак, Советская, 65б	f	medium
12454	93968	1051	республика Татарстан, Бавлинский район, село Новые Чути, Школьная, 11	f	small
12450	93964	1047	республика Татарстан, Бавлинский район, село Николашкино, Советская, 38а	f	small
12446	93960	1043	республика Татарстан, Бавлинский район, село Муртаза, Школьная, 13	f	small
12445	93959	1042	республика Татарстан, Бавлинский район, село Крым-Сарай, Советская, 59б	f	small
12440	93953	1037	республика Татарстан, Бавлинский район, село Кзыл-Яр, Советская, 15а	f	large
12447	93961	1044	республика Татарстан, Бавлинский район, село Исергапово, Советская, 108	f	medium
12457	93972	1054	республика Татарстан, Бавлинский район, село Верхняя Фоминовка, Советская, 91а	f	small
12444	93958	1041	республика Татарстан, Бавлинский район, село Васькино Туйралы, Школьная, 25б	f	\N
12429	93947	1026	республика Татарстан, Бавлинский район, поселок Бавлы, Горюнова, 2Б	f	large
12459	93974	1056	республика Татарстан, Бавлинский район, село Алексеевка, Советская, 51Г	f	small
12442	93955	1039	республика Татарстан, Бавлинский район, село Александровка, Школьная, 2	f	medium
12412	93928	1009	республика Татарстан, Атнинский район, село Татарская Чишма, М.Горького, 29	f	small
12422	93940	1019	республика Татарстан, Атнинский район, село Старый Югуп, Зелень, 42	f	small
12420	93938	1017	республика Татарстан, Атнинский район, село Старый Узюм, Татарстан, 18	f	small
12421	93939	1018	республика Татарстан, Атнинский район, село Новые Шаши, Молодежная, 15	f	small
12415	93931	1012	республика Татарстан, Атнинский район, село Нижний Куюк, Татарстан, 71А	f	small
12402	93916	999	республика Татарстан, Атнинский район, село Нижнее Береске, Чишмяле, 10А	f	medium
12401	93915	998	республика Татарстан, Атнинский район, село Малая Атня, Советская, 31Б	f	small
12414	93930	1011	республика Татарстан, Атнинский район, село Кызыл-Утар, Ленина, 4	f	small
12413	93929	1010	республика Татарстан, Атнинский район, село Кшклово, Татарстан, 7	f	small
12408	93924	1005	республика Татарстан, Атнинский район, село Кунгер, Советская, 33	f	medium
12410	93926	1007	республика Татарстан, Атнинский район, село Кулле-Кими, Кирова, 1а	f	small
12409	93925	1006	республика Татарстан, Атнинский район, село Кубян, Школьная, 2	f	medium
132462	93937	1016	республика Татарстан, Атнинский район, село Кошар, Татарстан , 49	f	\N
12407	93923	1004	республика Татарстан, Атнинский район, село Коморгузя, Комсомольская, 11	f	small
12423	93941	1020	республика Татарстан, Атнинский район, село Ключи-Сап, Тукая, 70	f	small
132461	93921	1002	республика Татарстан, Атнинский район, село Каенсар, Мира, 39, здание библиотеки	f	\N
12411	93927	1008	республика Татарстан, Атнинский район, село Ислейтар, Колхозная, 7	f	small
12404	93919	1001	республика Татарстан, Атнинский район, село Дусюм, Ш.Камала, 46	f	\N
12406	93922	1003	республика Татарстан, Атнинский район, село Верхняя Серда, Узяк, 22	f	small
12416	93933	1013	республика Татарстан, Атнинский район, село Верхний Куюк, Тукая, 59А	f	small
12417	93934	1014	республика Татарстан, Атнинский район, село Большой Менгер, Советская, 11	f	medium
12403	93917	1000	республика Татарстан, Атнинский район, село Большие Берези, Большая, 37А	f	small
12399	93913	996	республика Татарстан, Атнинский район, село Большая Атня, Советская, 2	f	large
12418	93935	1015	республика Татарстан, Атнинский район, село Бахтияр, Ирек, 2	f	small
12398	93912	995	республика Татарстан, Арский район, село Янга-Сала, Центральная, 18	f	small
12395	93908	992	республика Татарстан, Арский район, село Шушмабаш, Школьная, 1в	f	medium
12361	93862	958	республика Татарстан, Арский район, село Шурабаш, Гагарина, 17а	f	small
12363	93864	960	республика Татарстан, Арский район, село Шура, Х.Такташа, 35	f	small
12382	93889	979	республика Татарстан, Арский район, село Штырь, Советская, 32	f	small
12397	93911	994	республика Татарстан, Арский район, село Шека, Свердлова, 19	f	small
132445	93853	951	республика Татарстан, Арский район, село Хасаншаих, Комсомольская, 64, здание Хасаншаихской школы	f	\N
12368	93870	965	республика Татарстан, Арский район, село Учили, Тукая, 77	f	small
9100	54265	246	республика Марий Эл, Звенигово, Пушкина, 41	f	medium
12392	93905	989	республика Татарстан, Арский район, село Утар-Аты, Кооперативная, 22	f	small
132456	93899	985	республика Татарстан, Арский район, село Урняк, Садовая, 10, здание Лесхозской школы	f	\N
13877	1024	2474	республика Татарстан, Арский район, село Тюбяк-Чекурча, Ленина, 28	f	small
132453	93891	981	республика Татарстан, Арский район, село Ташкич, Ленина, 36, здание Ташкичинской школы	f	\N
12359	93860	956	республика Татарстан, Арский район, село Сюрда, Советская, 37	f	small
12378	93882	975	республика Татарстан, Арский район, село Старый Яваш, М.Джалиля, 35а	f	small
132450	93880	974	республика Татарстан, Арский район, село Старый Кырлай, Молодежная, 1а, школа	f	\N
12365	93867	962	республика Татарстан, Арский район, село Старый Кишит, Г.Сафиуллина, 26а	f	small
132455	93897	984	республика Татарстан, Арский район, село Старый Ашит, Школьная , 7, здание Староашитской школы	f	\N
12391	93904	988	республика Татарстан, Арский район, село Старые Турнали, Школьная, 46	f	small
132452	93888	978	республика Татарстан, Арский район, село Старое Чурилино, Школьная, 49, здание Старочурилинской школы	f	\N
12375	93878	972	республика Татарстан, Арский район, село Средняя Серда, Центральная, 18а	f	small
12376	93879	973	республика Татарстан, Арский район, село Средняя Корса, Молодежная, 13	f	medium
132457	93902	986	республика Татарстан, Арский район, село Средний Пшалым, Вахитова, 22, здание школы	f	\N
12372	93875	969	республика Татарстан, Арский район, село Смак-Корса, Школьная, 2	f	medium
12371	93874	968	республика Татарстан, Арский район, село Сикертан, Школьная, 77	f	small
132449	93873	967	республика Татарстан, Арский район, село Сиза, Школьная, 21, здание Сизинской школы	f	\N
132444	93852	950	республика Татарстан, Арский район, село Пшенгер, Чапаева , 54, здание Пшенгерской школы	f	\N
132459	93909	993	республика Татарстан, Арский район, село Нуса, Татарстана, 31, здание школы	f	\N
12367	93869	964	республика Татарстан, Арский район, село Новый Кырлай, Центральная, 3	f	medium
132448	93865	961	республика Татарстан, Арский район, село Новый Кишит, Новая, 1, здание школы	f	\N
132447	93859	955	республика Татарстан, Арский район, село Новый Кинер, Советская, 8, здание Новокинерского лицея	f	\N
12357	93858	954	республика Татарстан, Арский район, село Новый Кинер, Советская, 12	f	medium
12400	93914	997	республика Татарстан, Арский район, село Новая Атня, Советская, 7А	f	small
12360	93861	957	республика Татарстан, Арский район, село Нижняя Ура, Кирова, 12	f	small
12379	93883	976	республика Татарстан, Арский район, село Нижние Метески, Центральная, 22	f	small
12374	93877	971	республика Татарстан, Арский район, село Нижние Аты, Центральная, 37а	f	medium
132446	93856	953	республика Татарстан, Арский район, село Наласа, Молодежная, 91, здание Наласинской школы	f	\N
132451	93885	977	республика Татарстан, Арский район, село Мендюш, Татарстан, 48	f	\N
12366	93868	963	республика Татарстан, Арский район, село Кшкар, Мостовая, 124	f	small
132458	93907	991	республика Татарстан, Арский район, село Кошлауч, Тукая, 60, здание Кошлаучской школы	f	\N
12355	93855	952	республика Татарстан, Арский район, село Качелино, Центральная, 200	f	medium
12390	93903	987	республика Татарстан, Арский район, село Казанбаш, Кирова, 50	f	medium
12369	93871	966	республика Татарстан, Арский район, село Верхние Верези, Мостовая, 2	f	small
12393	93906	990	республика Татарстан, Арский район, село Верхние Аты, Кооперативная, 22	f	small
12383	93890	980	республика Татарстан, Арский район, село Венета, Школьная, 3	f	small
12362	93863	959	республика Татарстан, Арский район, село Байкал, Тукая, 35	f	small
132454	93893	982	республика Татарстан, Арский район, село Ашитбаш, Пионерская, 34, здание Ашитбашской школы	f	\N
12342	93837	939	республика Татарстан, Арский район, поселок Арск, Школьная, 2	f	large
12349	93844	946	республика Татарстан, Арский район, поселок Арск, Цветочная, 22а	f	medium
12348	93843	945	республика Татарстан, Арский район, поселок Арск, Трудовая, 1	f	large
12347	93842	944	республика Татарстан, Арский район, поселок Арск, Мостовая, 15	f	medium
12346	93841	943	республика Татарстан, Арский район, поселок Арск, Мостовая, 36	f	large
12345	93840	942	республика Татарстан, Арский район, поселок Арск, Комсомольская, 47	f	medium
12344	93839	941	республика Татарстан, Арский район, Арск, Галактионова, 28	f	medium
12343	93838	940	республика Татарстан, Арский район, поселок Арск, Галактионова, 26	f	large
12337	93832	934	республика Татарстан, Арский район, поселок Арск, Банковская, 32	f	large
132443	93849	949	республика Татарстан, Арский район, село Апазово, Советская, 28, здание школы	f	\N
12386	93895	983	республика Татарстан, Арский район, село Акчишма, Школьная, 5	f	small
12296	93789	893	республика Татарстан, Апастовский район, село Ясашно-Барышево, Подгорная, 12	f	small
12335	93830	932	республика Татарстан, Апастовский район, село Эбалаково, Х.Такташа, 28	f	small
132441	93791	894	республика Татарстан, Апастовский район, село Шонгуты, Завражная, 5, ДК	f	\N
12318	93812	915	республика Татарстан, Апастовский район, село Шигаево, Клубная, 2	f	small
12322	93816	919	республика Татарстан, Апастовский район, село Шемяково, Центральная, 44	f	small
12333	93828	930	республика Татарстан, Апастовский район, село Шамбулыхчи, Г.Тукая, 15	f	small
12331	93826	928	республика Татарстан, Апастовский район, село Чури Барышево, Гагарина, 3	f	small
12330	93825	927	республика Татарстан, Апастовский район, село Черемшан, Вахитова, 38	f	small
12313	93445	910	республика Татарстан, Апастовский район, поселок Чатбаш, Татарстан, 51	f	small
12303	93798	900	республика Татарстан, Апастовский район, село Утямишево, Ленина, 58	f	small
12326	93820	923	республика Татарстан, Апастовский район, село Тюбяк-Черки, Ленина, 86	f	small
12327	93822	924	республика Татарстан, Апастовский район, село Тутаево, С.Ахтямова, 10	f	small
12332	93827	929	республика Татарстан, Апастовский район, село Танай-Тураево, Советская, 37	f	small
12325	93819	922	республика Татарстан, Апастовский район, село Табар-Черки, Молодежная, 70	f	small
12323	93817	920	республика Татарстан, Апастовский район, село Старые Юмралы, Вахитова, 29	f	small
12284	93778	881	республика Татарстан, Апастовский район, село Старые Енали, Советская, 43	f	small
12316	93810	913	республика Татарстан, Апастовский район, село Старое Бурнашево, Амира Сабирова, 17	f	small
12336	93831	933	республика Татарстан, Апастовский район, село Средний Биябаш, Островского, 20	f	small
12320	93814	917	республика Татарстан, Апастовский район, село Среднее Балтаево, 50 лет Победы, 91	f	small
12311	93806	908	республика Татарстан, Апастовский район, село Свияжский, Заводская, 14	f	small
12317	93811	914	республика Татарстан, Апастовский район, село Сатламышево, Центральная, 42	f	small
12334	93829	931	республика Татарстан, Апастовский район, село Нижний Биябаш, Г.Тукая, 17	f	small
12310	93805	907	республика Татарстан, Апастовский район, село Мурзино, Татарстана, 18	f	small
12295	93788	892	республика Татарстан, Апастовский район, село Малые Кокузы, Пушкина, 41	f	small
12293	93786	890	республика Татарстан, Апастовский район, село Малые Болгояры, Школьная, 5	f	small
12307	93802	904	республика Татарстан, Апастовский район, село Мазиково, Сунгатуллина, 20	f	small
12314	93808	911	республика Татарстан, Апастовский район, село Куштово, Хади Такташа, 22	f	small
12299	93794	896	республика Татарстан, Апастовский район, село Курмашево, Молодежная, 43	f	small
12305	93800	902	республика Татарстан, Апастовский район, село Кулганы, Просвещения, 8	f	small
12308	93803	905	республика Татарстан, Апастовский район, село Коратун, Х.Такташа, 1а	f	medium
12315	93809	912	республика Татарстан, Апастовский район, село Кильдуразы, Пионерская, 24	f	small
12312	93807	909	республика Татарстан, Апастовский район, село Кзыл-Тау, Вахитова, 116	f	small
12301	93796	898	республика Татарстан, Апастовский район, село Карамасары, Гали Хужи, 2	f	small
12324	93818	921	республика Татарстан, Апастовский район, село Карабаево, Тукая, 6	f	small
12319	93813	916	республика Татарстан, Апастовский район, село Кабы-Копры, Школьная, 19	f	small
12306	93801	903	республика Татарстан, Апастовский район, деревня Идрязь-Тенькиево, Вахитова, 1	f	small
12304	93799	901	республика Татарстан, Апастовский район, село Деушево, Ленина, 75	f	small
12291	93784	888	республика Татарстан, Апастовский район, село Девликеево, Молодежная, 12	f	small
12302	93797	899	республика Татарстан, Апастовский район, село Верхние Индырчи, Тукая, 21	f	small
12321	93815	918	республика Татарстан, Апастовский район, село Верхнее Балтаево, Советская, 27	f	small
11874	93341	471	республика Татарстан, Агрызский район, Агрыз, Карла Маркса, 87	f	medium
12287	93719	884	республика Татарстан, Апастовский район, село Бурнашево, Советская, 31	f	small
12298	93792	895	республика Татарстан, Апастовский район, село Булым-Булыхчи, Мечеть, 13А	f	small
12294	93787	891	республика Татарстан, Апастовский район, село Большие Кокузы, Ленина, 50	f	small
12292	93785	889	республика Татарстан, Апастовский район, село Большие Болгояры, Советская, 8	f	small
12290	93783	887	республика Татарстан, Апастовский район, село Бишево, Ленина, 53	f	small
12288	93759	885	республика Татарстан, Апастовский район, село Бакрче, Центральная, 36	f	small
13008	210	1605	республика Татарстан, Апастовский район, село Бакрче, Советская, 26	f	small
12329	93824	926	республика Татарстан, Апастовский район, село Багищево, Зеленая, 19	f	small
12328	93823	925	республика Татарстан, Апастовский район, село Аюкудерган, Центральная, 37	f	small
12283	93777	880	республика Татарстан, Апастовский район, село Апастово, Советская, 3	f	medium
12282	93776	879	республика Татарстан, Апастовский район, село Апастово, Красноармейская, 65	f	large
12280	93773	877	республика Татарстан, Апастовский район, село Апастово, Заводская, 11Б	f	\N
12281	93775	878	республика Татарстан, Апастовский район, село Апастово, Гагарина, 7	f	medium
12285	93779	882	республика Татарстан, Апастовский район, село Альмендерово, Победа, 1	f	\N
12286	93432	883	республика Татарстан, Апастовский район, село Азимово, Ленина, 6	f	small
12300	93795	897	республика Татарстан, Апастовский район, село Азбаба, Октябрьская, 116	f	small
12274	93764	871	республика Татарстан, Альметьевский район, село Ямаши, Советская, 4	f	medium
12276	93767	873	республика Татарстан, Альметьевский район, село Ямаш, Советская, 109А	f	small
12251	93738	848	республика Татарстан, Альметьевский район, село Чупаево, Кирова, 12А	f	medium
12265	93752	862	республика Татарстан, Альметьевский район, село Чувашское Сиренькино, Центральная, 34А	f	small
12271	93761	868	республика Татарстан, Альметьевский район, Урсалабаш, Ахмадуллина, 113А	f	small
12273	93763	870	республика Татарстан, Альметьевский район, село Тайсуганово, Ленина, 12	f	medium
12270	93758	867	республика Татарстан, Альметьевский район, село Сулеево, Заречная, 29А	f	\N
12268	93756	865	республика Татарстан, Альметьевский район, село Старое Суркино, Ленина, сельский Дом культуры	f	medium
12266	93754	863	республика Татарстан, Альметьевский район, село Старая Михайловка, Ленина, 1А	f	\N
12889	92	1486	республика Татарстан, Альметьевский район, село Старая Елань, Долгобуль, 3	f	small
12263	93750	860	республика Татарстан, Альметьевский район, поселок Русский Акташ, Школьная, 2	f	large
12262	93749	859	республика Татарстан, Альметьевский район, поселок Русский Акташ, Комсомольская, 12	f	large
12261	93748	858	республика Татарстан, Альметьевский район, село Новотроицкое, Советская, 2	f	medium
12260	93747	857	республика Татарстан, Альметьевский район, село Новоникольск, Центральная, 100	f	medium
12269	93757	866	республика Татарстан, Альметьевский район, село Новое Суркино, Лесная, 32	f	small
12259	93746	856	республика Татарстан, Альметьевский район, село Новое Надырово, Советская, 95	f	large
12256	93743	853	республика Татарстан, Альметьевский район, село Новое Каширово, Школьная, Сельская школа	f	medium
12257	93744	854	республика Татарстан, Альметьевский район, село Новое Каширово, Тавабилова, сельский Дом культуры	f	medium
12272	93762	869	республика Татарстан, Альметьевский район, село Новая Михайловка, Заречная, 29А	f	small
12227	93712	824	республика Татарстан, Альметьевский район, поселок Нижняя Мактама, Терешковой, 72	f	large
12278	93772	876	республика Татарстан, Альметьевский район, поселок Нижняя Мактама, Промышленная, 1А	f	\N
132436	93769	875	республика Татарстан, Альметьевский район, поселок Нижняя Мактама, Некрасова, 1, здание школы №2	f	\N
12277	93768	874	республика Татарстан, Альметьевский район, поселок Нижняя Мактама, Некрасова, 10	f	large
12226	93711	823	республика Татарстан, Альметьевский район, поселок Нижняя Мактама, Некрасова, 1	f	large
12255	93742	852	республика Татарстан, Альметьевский район, село Нижнее Абдулово, ул.Ленина, Сельский Дом культуры	f	medium
12245	93732	842	республика Татарстан, Альметьевский район, село Нагорное, село Нагорное, Центральная, 32	f	small
9099	54265	245	республика Марий Эл, Звенигово, Пушкина, 41	f	medium
12254	93741	851	республика Татарстан, Альметьевский район, Миннибаево, Шоссейная, 20А	f	medium
12253	93740	850	республика Татарстан, Альметьевский район, село Миннибаево, Бикчурина, 50	f	medium
12252	93739	849	республика Татарстан, Альметьевский район, село Маметьево, Советская, 3	f	medium
12249	93736	846	республика Татарстан, Альметьевский район, село Кульшарипово, Тукая, 50Б	f	large
12248	93735	845	республика Татарстан, Альметьевский район, село Кузайкино, Советская, 38	f	small
12247	93734	844	республика Татарстан, Альметьевский район, село Клементейкино, Центральная, 38А	f	small
12246	93733	843	республика Татарстан, Альметьевский район, село Кичучатово, Юлдаш, 2А	f	medium
12244	93731	841	республика Татарстан, Альметьевский район, село Кичуй, Центральная, 59	f	small
12264	93751	861	республика Татарстан, Альметьевский район, село Кительга, Советская, 7А	f	small
12243	93730	840	республика Татарстан, Альметьевский район, село Кама-Исмагилово, Школьная, 5	f	medium
14068	1266	2665	республика Татарстан, Альметьевский район, село Кама-Елга, Ключевая, 7	f	small
12242	93729	839	республика Татарстан, Альметьевский район, село Калейкино, Токарликова, 104А	f	large
12250	93737	847	республика Татарстан, Альметьевский район, село Калейкино, Железнодорожная, 38Б	f	large
12231	93716	828	республика Татарстан, Альметьевский район, село Ильтень-Бута, Советская, 52	f	small
132435	93765	872	республика Татарстан, Альметьевский район, село Зай-Чишма, Верхняя, 18б, здание сельского клуба	f	\N
12241	93728	838	республика Татарстан, Альметьевский район, село Ерсубайкино, Советская, 11	f	small
12229	93714	826	республика Татарстан, Альметьевский район, село Дербедень, Школьная, 3	f	medium
12232	93717	829	республика Татарстан, Альметьевский район, село Дальняя Ивановка, Молодёжная, 26	f	small
12239	93726	836	республика Татарстан, Альметьевский район, село Верхняя Мактама, Октября, 57	f	medium
12238	93725	835	республика Татарстан, Альметьевский район, село Верхний Акташ, Советская, 18	f	medium
12237	93724	834	республика Татарстан, Альметьевский район, село Васильевка, Центральная, 26	f	small
12236	93723	833	республика Татарстан, Альметьевский район, село Бута, Бльшая, 1	f	small
12234	93721	831	республика Татарстан, Альметьевский район, село Борискино, Центральная, 61	f	small
12233	93718	830	республика Татарстан, Альметьевский район, село Бишмунча, Советская, 57Б	f	\N
12258	93745	855	республика Татарстан, Альметьевский район, село Бикасаз, Школьная, сельский клуб	f	small
12235	93722	832	республика Татарстан, Альметьевский район, село Березовка, Центральная, 16	f	small
12230	93715	827	республика Татарстан, Альметьевский район, село Аппаково, Школьная, 2	f	small
12228	93713	825	республика Татарстан, Альметьевский район, село Абдрахманово, Советская, 49	f	large
12173	93656	770	республика Татарстан, Альметьевск городской округ, Альметьевск, Советская, Дом культуры	f	large
12194	93679	791	республика Татарстан, Альметьевск городской округ, Альметьевск, Белоглазова, 105	f	large
12162	93645	759	республика Татарстан, Алькеевский район, село Юхмачи, Луговая, 1а	f	medium
12159	93642	756	республика Татарстан, Алькеевский район, село Чувашское Шапкино, Центральная, 39	f	small
12158	93641	755	республика Татарстан, Алькеевский район, село Чувашское Бурнаево, Центральная, 25а	f	small
12157	93640	754	республика Татарстан, Алькеевский район, село Чувашский Брод, Молодежная, 2а	f	medium
12156	93639	753	республика Татарстан, Алькеевский район, село Хлебодаровка, Зеленая, 2	f	small
12152	93635	749	республика Татарстан, Алькеевский район, село Тяжбердино, Центральная, 34	f	small
12151	93634	748	республика Татарстан, Алькеевский район, село Татарское Тюгульбаево, Шавалеева, 8б	f	small
12150	93633	747	республика Татарстан, Алькеевский район, село Татарское Муллино, Школьная, 46	f	small
12149	93632	746	республика Татарстан, Алькеевский район, село Татарское Бурнаево, Центральная, 32	f	small
12166	93649	763	республика Татарстан, Алькеевский район, село Татарское Ахметьево, Центральная, 10б	f	small
12160	93643	757	республика Татарстан, Алькеевский район, село Татарские Шибаши, Мира, 20	f	small
12148	93631	745	республика Татарстан, Алькеевский район, село Старые Челны, Центральная, 20	f	small
12153	93636	750	республика Татарстан, Алькеевский район, село Старые Ургагары, Г. Тукая, 4	f	small
12145	93628	742	республика Татарстан, Алькеевский район, село Старые Салманы, Клубная, 1	f	small
12144	93627	741	республика Татарстан, Алькеевский район, село Старые Матаки, Центральная, 7	f	small
12163	93646	760	республика Татарстан, Алькеевский район, село Старое Ямкино, Мира, 39	f	small
12143	93626	740	республика Татарстан, Алькеевский район, село Старое Камкино, Нижняя, 66	f	small
12142	93625	739	республика Татарстан, Алькеевский район, село Старое Алпарово, Северная, 29	f	small
12155	93638	752	республика Татарстан, Алькеевский район, село Старая Хурада, Школьная, 1	f	small
12146	93629	743	республика Татарстан, Алькеевский район, село Старая Тахтала, Ежевичная, 88а	f	small
12140	93623	737	республика Татарстан, Алькеевский район, село Среднее Алькеево, Центральная, 47	f	small
12154	93637	751	республика Татарстан, Алькеевский район, село Сиктерме-Хузангаево, Майская, 1а	f	small
12137	93620	734	республика Татарстан, Алькеевский район, село Новые Челны, Советская, 35	f	small
12141	93624	738	республика Татарстан, Алькеевский район, село Новые Салманы, Школьная, 16	f	small
12164	93647	761	республика Татарстан, Алькеевский район, село Нижнее Колчурино, Центральная, 27	f	small
12138	93621	735	республика Татарстан, Алькеевский район, село Нижнее Качеево, Центральная, 106	f	small
12136	93619	733	республика Татарстан, Алькеевский район, село Нижнее Биктимирово, Мира, 17	f	small
12135	93618	732	республика Татарстан, Алькеевский район, село Нижнее Альмурзино, Советская, 9	f	small
12134	93617	731	республика Татарстан, Алькеевский район, село Нижнее Алькеево, Советская, 56	f	medium
12133	93616	730	республика Татарстан, Алькеевский район, село Кошки, М.Джалиля, 21	f	small
12131	93614	728	республика Татарстан, Алькеевский район, село Каргополь, Мастовая, 12	f	small
12130	93613	727	республика Татарстан, Алькеевский район, село Карамалы, Г. Тукая, 20	f	small
12132	93615	729	республика Татарстан, Алькеевский район, село Каракули, Школьная, 26	f	small
12128	93610	725	республика Татарстан, Алькеевский район, село Верхние Матаки, Клубная, 1	f	small
12127	93609	724	республика Татарстан, Алькеевский район, село Верхнее Колчурино, 8 Марта, 21	f	small
132430	93612	726	республика Татарстан, Алькеевский район, село Верхнее Качеево, Центральная, 45, ДК	f	\N
12126	93608	723	республика Татарстан, Алькеевский район, село Верхнее Альмурзино, Пионерская, д.24	f	small
12125	93607	722	республика Татарстан, Алькеевский район, село Верхнее Алькеево, Мира, 70	f	small
12124	93606	721	республика Татарстан, Алькеевский район, село Борискино, Дружбы, 8	f	small
12123	93605	720	республика Татарстан, Алькеевский район, село Бибаево-Челны, Мира, 22	f	small
12120	93602	717	республика Татарстан, Алькеевский район, село Базарные Матаки, Школьная, 6/2	f	medium
12119	93601	716	республика Татарстан, Алькеевский район, село Базарные Матаки, Школьная, 6/1	f	medium
12121	93603	718	республика Татарстан, Алькеевский район, село Базарные Матаки, Центральная Усадьба, 1	f	medium
12161	93644	758	республика Татарстан, Алькеевский район, село Базарные Матаки, Крайнова, 185	f	medium
12118	93600	715	республика Татарстан, Алькеевский район, село Базарные Матаки, Крайнова, 55	f	medium
12122	93604	719	республика Татарстан, Алькеевский район, село Базарные Матаки, 40 лет Победы, 1	f	medium
12165	93648	762	республика Татарстан, Алькеевский район, село Аппаково, Мира, 1	f	small
12147	93630	744	республика Татарстан, Алькеевский муниципальный район, Старая Тумба, Центральная, 21	f	small
12117	93598	714	республика Татарстан, Алексеевский район, село Ялкын, Гагарина, 42	f	small
12078	93556	675	республика Татарстан, Алексеевский район, село Шама, Заречная, 17	f	small
12103	93584	700	республика Татарстан, Алексеевский район, село Чувашская Майна, Школьная, 10	f	small
12107	93588	704	республика Татарстан, Алексеевский район, село Тиган-Буляк, Кирова, 2	f	small
12094	93573	691	республика Татарстан, Алексеевский район, село Сухие Курнали, Заки Кутлина, 24	f	small
12114	93595	711	республика Татарстан, Алексеевский район, село Степная Шентала, Вахитова, 34	f	small
12090	93569	687	республика Татарстан, Алексеевский район, село Старое Муллино, Гагарина, 33	f	small
12112	93593	709	республика Татарстан, Алексеевский район, село Средние Тиганы, Зеленая, 12	f	medium
12110	93591	707	республика Татарстан, Алексеевский район, село Сахаровка, Мирная, 101	f	small
12099	93579	696	республика Татарстан, Алексеевский район, село Саконы, Центральная, 39	f	small
12075	93553	672	республика Татарстан, Алексеевский район, село Сабакайка, Центральная, 13	f	small
12109	93590	706	республика Татарстан, Алексеевский район, село Ромодан, Советская, 1	f	small
12106	93587	703	республика Татарстан, Алексеевский район, село Родники, Советская, 3	f	small
12111	93592	708	республика Татарстан, Алексеевский район, село Речное, Комсомольская, 4	f	small
12091	93570	688	республика Татарстан, Алексеевский район, село Приозерная, Бутлерова, 15	f	small
12104	93585	701	республика Татарстан, Алексеевский район, село Подлесная Шентала, Тукая, 42	f	small
12096	93576	693	республика Татарстан, Алексеевский район, село Новоспасск, Некрасова, 18А	f	small
12113	93594	710	республика Татарстан, Алексеевский район, село Нижние Тиганы, Центральная, 45	f	small
12084	93563	681	республика Татарстан, Алексеевский район, село Мокрые Курнали, Школьная, 9	f	medium
12108	93589	705	республика Татарстан, Алексеевский район, село Масловка, Школьная, 6	f	small
12092	93571	689	республика Татарстан, Алексеевский район, село Мараса, Школьная, 31	f	small
12115	93596	712	республика Татарстан, Алексеевский район, село Малый Красный Яр, Молодежная, 7	f	small
132429	93581	697	республика Татарстан, Алексеевский район, село Левашево, Советская, 14, здание сельского Дома культуры	f	\N
12098	93578	695	республика Татарстан, Алексеевский район, село Лебяжье, Центральная, 29А	f	medium
12095	93575	692	республика Татарстан, Алексеевский район, село Лебедино, Кооперативная, 3	f	small
12093	93572	690	республика Татарстан, Алексеевский район, село Куркуль, Центральная, 36	f	small
12080	93558	677	республика Татарстан, Алексеевский район, село Красный Баран, Центральная, 48Б	f	small
12116	93597	713	республика Татарстан, Алексеевский район, село Караваево, Школьная, 3	f	small
12089	93568	686	республика Татарстан, Алексеевский район, село Ерыкла, Правонабережная, 35	f	small
12101	93582	698	республика Татарстан, Алексеевский район, село Горка, Ленина, 2А	f	small
12087	93566	684	республика Татарстан, Алексеевский район, село Войкино, Викторова, 12	f	small
12102	93583	699	республика Татарстан, Алексеевский район, село Верхняя Татарская Майна, Горская, 15	f	small
12085	93564	682	республика Татарстан, Алексеевский район, село Бутлеровка, Центральная, 38	f	small
12082	93560	679	республика Татарстан, Алексеевский район, село Большие Тиганы, Баттала, 17	f	small
12079	93557	676	республика Татарстан, Алексеевский район, село Большие Полянки, Центральная, 18	f	small
12077	93555	674	республика Татарстан, Алексеевский район, село Билярск, Ленина, 2	f	large
12076	93554	673	республика Татарстан, Алексеевский район, село Билярск, Калинина, 1	f	medium
12097	93577	694	Россия, республика Татарстан, Алексеевский район, село Березовая Грива	f	small
12086	93565	683	республика Татарстан, Алексеевский район, село Балахчино, Комсомольская, 11	f	small
12088	93567	685	республика Татарстан, Алексеевский район, село Базяково, Федина, 20	f	small
12105	93586	702	республика Татарстан, Алексеевский район, село Арбузов-Баран, Чернышевского, 14	f	small
12068	93546	665	республика Татарстан, Алексеевский район, поселок Алексеевское, Советская, 1А	f	large
12069	93547	666	республика Татарстан, Алексеевский район, поселок Алексеевское, Некрасова, 38	f	large
12071	93549	668	республика Татарстан, Алексеевский район, поселок Алексеевское, Ленина, 73	f	large
12070	93548	667	республика Татарстан, Алексеевский район, поселок Алексеевское, Ленина, 33	f	large
12074	93552	671	республика Татарстан, Алексеевский район, поселок Алексеевское, Есенина, 19	f	large
12073	93551	670	республика Татарстан, Алексеевский район, поселок Алексеевское, Дорожников, 1	f	medium
12072	93550	669	республика Татарстан, Алексеевский район, поселок Алексеевское, Гагарина, 20	f	large
12081	93559	678	республика Татарстан, Алексеевский район, село Александровка, Мирная, 9	f	small
12067	93545	664	республика Татарстан, Актанышский район, село Шарипово, Центральная, 5	f	small
9093	54261	239	республика Марий Эл, Звенигово, Ленина, 1	f	medium
12066	93544	663	республика Татарстан, Актанышский район, село Чуракаево, Кирова, 55	f	small
12065	93543	662	республика Татарстан, Актанышский район, село Чишма, Центральная, 50	f	small
12064	93542	661	республика Татарстан, Актанышский район, село Чатово, Центральная, 43	f	small
12063	93541	660	республика Татарстан, Актанышский район, село Чалманарат, Центральная, 2	f	small
12062	93540	659	республика Татарстан, Актанышский район, село Усы, Молодежная, 5а	f	small
12061	93539	658	республика Татарстан, Актанышский район, село Уразаево, Центральная, 4	f	small
12060	93538	657	республика Татарстан, Актанышский район, село Улиманово, 1 Мая, 33	f	small
12059	93537	656	республика Татарстан, Актанышский район, село Тюково, Ленина, 61/2	f	medium
12056	93534	653	республика Татарстан, Актанышский район, село Татарские Ямалы, Ленина, 14	f	medium
12055	93533	652	республика Татарстан, Актанышский район, село Татарские Суксы, Гагарина, 1б	f	medium
12054	93532	651	республика Татарстан, Актанышский район, село Такталачук, Г.Авзал, 50	f	medium
12053	93531	650	республика Татарстан, Актанышский район, село Табанлы-Куль, Гагарина, 23	f	small
12034	93511	631	республика Татарстан, Актанышский район, село Старые Урьяды,  Советская, 23	f	small
12050	93528	647	республика Татарстан, Актанышский район, село Старые Бугады, Центральная, 58	f	medium
12057	93535	654	республика Татарстан, Актанышский район, село Старое Тлякеево, Центральная, 85	f	small
12052	93530	649	республика Татарстан, Актанышский район, село Старое Сафарово, М.Вахитова, 16	f	medium
12051	93529	648	республика Татарстан, Актанышский район, село Старое Курмашево, Центральная, 26	f	medium
12033	93510	630	республика Татарстан, Актанышский район, село Старое Бикчентаево, Г.Тукая, 3	f	small
12049	93527	646	республика Татарстан, Актанышский район, село Старое Байсарово, Советская, 25	f	medium
12048	93526	645	республика Татарстан, Актанышский район, село Старое Алимово, Центральная, 27а	f	small
12047	93525	644	республика Татарстан, Актанышский район, село Старое Айманово, Новая, 5а	f	small
12046	93524	643	республика Татарстан, Актанышский район, село Старое Агбязово, Ленина, 53	f	small
12045	93523	642	республика Татарстан, Актанышский район, село Поисево, Советская, 21	f	large
12044	93522	641	республика Татарстан, Актанышский район, село Новое Курмашево, Центральная, 41А	f	small
12043	93521	640	республика Татарстан, Актанышский район, село Новое Алимово, Г.Тукая, 53	f	medium
12042	93520	639	республика Татарстан, Актанышский район, село Нижнее Гареево, Красноармейская, 17	f	small
12041	93519	638	республика Татарстан, Актанышский район, село Мари-Суксы, И.Миннибаева, 29	f	small
12040	93518	637	республика Татарстан, Актанышский район, село Куяново, Центральная, 55	f	small
12039	93516	636	республика Татарстан, Актанышский район, село Кузякино, Советская, 46	f	small
12037	93514	634	республика Татарстан, Актанышский район, село Качкиново, Центральная, 37в	f	small
12036	93513	633	республика Татарстан, Актанышский район, село Казкеево, Первомайская, 1А	f	small
12058	93536	655	республика Татарстан, Актанышский район, Казкеево, поселок Тыннамасово, Октябрьская, 72б	f	small
12038	93515	635	республика Татарстан, Актанышский район, село Имени Кирова, Кирова, 39	f	medium
12035	93512	632	республика Татарстан, Актанышский район, село Верхнее Яхшеево, Победы, 59	f	small
12032	93509	629	республика Татарстан, Актанышский район, село Барсуково, Куйбышева, 4	f	small
12031	93508	628	республика Татарстан, Актанышский район, село Атясево, Центральная, 76	f	small
12022	93498	619	республика Татарстан, Актанышский район, село Актаныш, проспект Ленина, 42	f	large
12027	93503	624	республика Татарстан, Актанышский район, село Актаныш, Юбилейная, 111	f	medium
12024	93500	621	республика Татарстан, Актанышский район, село Актаныш, Юбилейная, 66	f	large
12023	93499	620	республика Татарстан, Актанышский район, село Актаныш, Юбилейная, 4	f	large
12025	93501	622	республика Татарстан, Актанышский район, село Актаныш, Центральная, 36б	f	medium
12026	93502	623	республика Татарстан, Актанышский район, село Актаныш, Механизаторов, 9	f	large
12030	93507	627	республика Татарстан, Актанышский район, село Аккузово, Центральная, 1	f	small
12029	93505	626	республика Татарстан, Актанышский район, село Аишево, Ленина, 30	f	small
12028	93504	625	республика Татарстан, Актанышский район, село Адаево, Горького, 2	f	small
12012	93488	609	республика Татарстан, Аксубаевский район, село Щербень, Лермонтова, 6	f	small
11985	93460	582	республика Татарстан, Аксубаевский район, село Чувашское Енорускино, Школьная, 18	f	small
12015	93491	612	республика Татарстан, Аксубаевский район, село Чувашский Адам, Чапаева, 20	f	small
11981	93456	578	республика Татарстан, Аксубаевский район, село Урмандеево, Фрунзе, 2А	f	medium
12005	93480	602	республика Татарстан, Аксубаевский район, село Трудолюбово, Романова, 6	f	small
12019	93495	616	республика Татарстан, Аксубаевский район, село Тахтала, Школьная, 3	f	small
12001	93476	598	республика Татарстан, Аксубаевский район, село Татарское Сунчелеево, Тукая, 12	f	small
11984	93459	581	республика Татарстан, Аксубаевский район, село Тарханка, Западная, 16	f	small
12002	93477	599	республика Татарстан, Аксубаевский район, село Сунчелеево, Ленина, 79	f	small
12017	93493	614	республика Татарстан, Аксубаевский район, село Старый Татарский Адам, Центральная, 17	f	small
11980	93455	577	республика Татарстан, Аксубаевский район, село Старые Савруши, Комсомольская, 20	f	small
12020	93496	617	республика Татарстан, Аксубаевский район, село Старые Киязлы, Центральная, 54	f	medium
11996	93471	593	республика Татарстан, Аксубаевский район, село Старое Узеево, Ленина, 2А	f	small
11991	93466	588	республика Татарстан, Аксубаевский район, село Старое Тимошкино, Ленина, 27	f	medium
11999	93474	596	республика Татарстан, Аксубаевский район, село Старое Мокшино, Зеленая, 1	f	small
11983	93458	580	республика Татарстан, Аксубаевский район, село Старое Ильдеряково, Советская, 13	f	small
11986	93461	583	республика Татарстан, Аксубаевский район, село Старое Ибрайкино, Кооперативная, 2	f	large
11978	93453	575	республика Татарстан, Аксубаевский район, село Старая Киреметь, Ленина, 37	f	small
12016	93492	613	республика Татарстан, Аксубаевский район, село Сосновка, Садовая, 5	f	small
11982	93457	579	республика Татарстан, Аксубаевский район, село Савгачево, Советская, 2А	f	medium
12011	93487	608	республика Татарстан, Аксубаевский район, село Русская Киреметь, Новостройки, 29	f	small
12000	93475	597	республика Татарстан, Аксубаевский район, село Пионер, Центральная, 1	f	small
12006	93481	603	республика Татарстан, Аксубаевский район, село Октябрь, Садовая, 4	f	small
12013	93489	610	республика Татарстан, Аксубаевский район, село Новый Чувашский Адам, Советская, 4	f	small
11993	93468	590	республика Татарстан, Аксубаевский район, село Новое Узеево, Школьная, 7	f	small
11992	93467	589	республика Татарстан, Аксубаевский район, село Новое Тимошкино, Центральная, 8	f	small
11997	93472	594	республика Татарстан, Аксубаевский район, село Новое Мокшино, Ленина, 20	f	small
11977	93452	574	республика Татарстан, Аксубаевский район, село Новое Ильдеряково, Центральная, 7	f	small
11987	93462	584	республика Татарстан, Аксубаевский район, село Новое Ибрайкино, Советская, 25	f	large
12009	93485	606	республика Татарстан, Аксубаевский район, село Новое Демкино, Калинина, 13А	f	small
11988	93463	585	республика Татарстан, Аксубаевский район, село Новое Аксубаево, Центральная, 27	f	small
12010	93486	607	республика Татарстан, Аксубаевский район, село Новая Киреметь, Мусы Джалиля, 15А	f	small
12018	93494	615	республика Татарстан, Аксубаевский район, село Нижняя Татарская Майна, Центральная, 2	f	small
12008	93484	605	республика Татарстан, Аксубаевский район, село Нижняя Баланда, Зеленая, 18	f	small
11979	93454	576	республика Татарстан, Аксубаевский район, село Нижние Савруши, Центральная, 22	f	small
11998	93473	595	республика Татарстан, Аксубаевский район, село Мюд, Центральная, 27	f	small
12003	93478	600	республика Татарстан, Аксубаевский район, село Малое Сунчелеево, Гагарина, 8	f	small
11989	93464	586	республика Татарстан, Аксубаевский район, село Малое Аксубаево, Лесная, 29	f	small
12007	93483	604	республика Татарстан, Аксубаевский район, село Кривоозерки, Школьная, 1	f	small
11990	93465	587	республика Татарстан, Аксубаевский район, село Кисы, Ленина, 12	f	small
12021	93497	618	республика Татарстан, Аксубаевский район, село Кзыл-Тау, Гафиятуллина, 23	f	small
12004	93479	601	республика Татарстан, Аксубаевский район, село Караса, Кирова, 20	f	small
12014	93490	611	республика Татарстан, Аксубаевский район, село Емелькино, Центральная, 10	f	small
11994	93469	591	республика Татарстан, Аксубаевский район, село Беловка, Полевая, 1	f	small
11995	93470	592	республика Татарстан, Аксубаевский район, село Алексеевка, Зеленая, 21	f	small
11976	93451	573	республика Татарстан, Аксубаевский район, поселок Аксубаево, Школьная, 4А	f	large
11973	93448	570	республика Татарстан, Аксубаевский район, поселок Аксубаево, Романова, 2	f	large
11975	93450	572	республика Татарстан, Аксубаевский район, поселок Аксубаево, Мазилина, 39	f	large
11974	93449	571	республика Татарстан, Аксубаевский район, поселок Аксубаево, Мазилина, 2	f	large
11971	93446	568	республика Татарстан, Азнакаевский район, село Чубар-Абдуллово, Советская, 85	f	small
11937	93409	534	республика Татарстан, Азнакаевский район, село Чемодурово, Нагорная, 3а	f	small
11957	93430	554	республика Татарстан, Азнакаевский район, село Чекан, Базарная, 2	f	small
11967	93441	564	республика Татарстан, Азнакаевский район, село Чалпы, Центральная, 24	f	medium
11961	93435	558	республика Татарстан, Азнакаевский район, село Учалле, Советская, 51	f	small
11964	93438	561	республика Татарстан, Азнакаевский район, село Урсаево, Советская, 14	f	medium
11954	93427	551	республика Татарстан, Азнакаевский район, село Урманаево, Татарстана, 27а	f	small
11946	93419	543	республика Татарстан, Азнакаевский район, село Уразаево, Энгельса, 63	f	medium
11963	93437	560	республика Татарстан, Азнакаевский район, село Тумутук, Тельмана, 62	f	large
11969	93443	566	республика Татарстан, Азнакаевский район, село Татарский Шуган, Советская, 41в	f	small
11953	93426	550	республика Татарстан, Азнакаевский район, село Таллы-Буляк, Центральная, 10	f	small
11947	93420	544	республика Татарстан, Азнакаевский район, село Тайкино, Мусы Джалиля, 19	f	small
11959	93433	556	республика Татарстан, Азнакаевский район, село Сарлы, Центральная, 74	f	medium
11948	93421	545	республика Татарстан, Азнакаевский район, село Сапеево, Школьная, 46а	f	medium
11956	93429	553	республика Татарстан, Азнакаевский район, село Победа, Центральная, 29	f	medium
11955	93428	552	республика Татарстан, Азнакаевский район, село Первое Мая, Средняя, 14	f	small
11944	93417	541	республика Татарстан, Азнакаевский район, село Мяняус, Советская, 1а	f	small
11970	93444	567	республика Татарстан, Азнакаевский район, село Мяндей, Новая, 2а	f	small
11965	93439	562	республика Татарстан, Азнакаевский район, село Муслюмово, Гафури, 31	f	small
11951	93424	548	республика Татарстан, Азнакаевский район, село Митряево, Тукая, 15а	f	small
11931	93403	528	республика Татарстан, Азнакаевский район, село Микулино, Советская, 74	f	medium
11940	93412	537	республика Татарстан, Азнакаевский район, село Масягутово, Багманова, 16	f	small
11938	93410	535	республика Татарстан, Азнакаевский район, село Мальбагуш, Нефтяников, 30	f	medium
11962	93436	559	республика Татарстан, Азнакаевский район, село Кук-Тяка, Ленина, 40	f	small
11952	93425	549	республика Татарстан, Азнакаевский район, село Карамалы, Молодежная, 3	f	medium
11942	93414	539	республика Татарстан, Азнакаевский район, село Какре-Елга, Советская, 22	f	medium
11966	93440	563	республика Татарстан, Азнакаевский район, село Ирекле, Гагарина, 43	f	small
11941	93413	538	республика Татарстан, Азнакаевский район, село Ильбяково, Валеева, 53	f	small
11958	93431	555	республика Татарстан, Азнакаевский район, село Верхнее Стярле, Советская, 32г	f	medium
11972	93447	569	республика Татарстан, Азнакаевский район, село Буралы, Октябрьская, 34	f	small
11960	93434	557	республика Татарстан, Азнакаевский район, село Буляк, Центральная, 26а	f	small
11949	93422	546	республика Татарстан, Азнакаевский район, село Большой Сухояш, Советская, 34	f	medium
11936	93408	533	республика Татарстан, Азнакаевский район, село Бирючевка, Центральная, 27	f	small
13061	270	1658	республика Татарстан, Азнакаевский район, село Балтачево, Центральная, 1	f	small
11945	93418	542	республика Татарстан, Азнакаевский район, село Балтачево, Молодежная, 1А	f	small
11968	93442	565	республика Татарстан, Азнакаевский район, село Балан-Буляк, Октябрьская, 39	f	small
11950	93423	547	республика Татарстан, Азнакаевский район, село Асеево, Центральная, 38г	f	small
9092	54261	238	республика Марий Эл, Звенигово, Ленина, 1	f	medium
11939	93411	536	республика Татарстан, Азнакаевский район, село Алькеево, Советская, 34	f	small
11934	93406	531	республика Татарстан, Азнакаевский район, поселок Актюбинский, Лесная, 17а	f	large
11935	93407	532	республика Татарстан, Азнакаевский район, поселок Актюбинский, Комарова, 5	f	large
11933	93405	530	республика Татарстан, Азнакаевский район, поселок Актюбинский, Губкина, 16	f	large
11932	93404	529	республика Татарстан, Азнакаевский район, поселок Актюбинский, Булатова, 16	f	medium
132428	93416	540	республика Татарстан, Азнакаевский район, село Агерзе, Хакима, 10, здание школы с.Агерзе	f	\N
132423	93356	483	республика Татарстан, Агрызский район, село Янга-Аул, Молодежная, 10а, здание сельского ДК	f	\N
11896	93369	493	республика Татарстан, Агрызский район, село Ямурзино, Советская, 63	f	small
11893	93366	490	республика Татарстан, Агрызский район, село Шаршада, Лесоводов, 20	f	small
11908	93382	505	республика Татарстан, Агрызский район, село Утяганово, Центральная, 35	f	small
11897	93370	494	республика Татарстан, Агрызский район, село Уразаево, Ленина, 32	f	small
11881	93350	478	республика Татарстан, Агрызский район, село Терси, Школьная, 3	f	medium
11880	93349	477	республика Татарстан, Агрызский район, село Терси, Центральная, 163	f	medium
11884	93354	481	республика Татарстан, Агрызский район, село Табарле, Ленина, 8а	f	small
11885	93355	482	республика Татарстан, Агрызский район, село Сукман, Карла Маркса, 6а	f	small
11907	93381	504	республика Татарстан, Агрызский район, село Старое Сляково, Клубная, 1	f	small
11895	93368	492	республика Татарстан, Агрызский район, село Старая Чекалда, Зеленая, 11	f	small
11909	93383	506	республика Татарстан, Агрызский район, село Сосново, Центральная, 22	f	small
132422	93351	479	республика Татарстан, Агрызский район, село Сарсак-Омга, Площадь Кирова, 13, здание лицея	f	\N
11898	93371	495	республика Татарстан, Агрызский район, село Салауш, Ленина, 73а	f	small
11903	93376	500	республика Татарстан, Агрызский район, село Пелемеш, Ленина, 49а	f	small
11883	93353	480	республика Татарстан, Агрызский район, село Новое Аккузино, Ленина, 34б	f	small
132424	93358	484	республика Татарстан, Агрызский район, село Нижнее Кучуково, Ленина, 12, здание сельского ДК	f	\N
11901	93374	498	республика Татарстан, Агрызский район, село Кулегаш, Советская, 38	f	small
132421	93348	476	республика Татарстан, Агрызский район, село Кудашево, Тукая, 8, здание селького ДК	f	\N
11889	93362	486	республика Татарстан, Агрызский район, село Крынды, Советская, 33	f	medium
11902	93375	499	республика Татарстан, Агрызский район, село Красный Бор, Маркина, 34	f	large
11891	93364	488	республика Татарстан, Агрызский район, село Кичкетан, М. Джалиля, 2	f	small
11900	93373	497	республика Татарстан, Агрызский район, село Каменный Ключ, Шкетана, 6	f	small
11906	93380	503	республика Татарстан, Агрызский район, село Кадыбаш, Клубная, 49а	f	small
11894	93367	491	республика Татарстан, Агрызский район, село Кадряково, Ленина, 55	f	small
11905	93379	502	республика Татарстан, Агрызский район, село Исенбаево, Советская, 79	f	medium
11876	93344	473	республика Татарстан, Агрызский район, село Иж-Бобья, Центральная, 20	f	small
11877	93345	474	республика Татарстан, Агрызский район, село Иж-Байки, Центральная, 20	f	small
11910	93384	507	республика Татарстан, Агрызский район, село Девятерня, Советская, 48	f	small
132425	93361	485	республика Татарстан, Агрызский район, село Варкледбодья, Ленина, 6, здание ООО Агрофирма Ак Барс-Агрыз	f	\N
11890	93363	487	республика Татарстан, Агрызский район, село Варзипельга, Клубная, 2	f	small
11892	93365	489	республика Татарстан, Агрызский район, село Варзи-Омга, Клубная, 1	f	small
11904	93378	501	республика Татарстан, Агрызский район, село Бима, Ленина, 1	f	small
11878	93346	475	республика Татарстан, Агрызский район, село Биктово, Сайдашева, 2	f	small
11899	93372	496	республика Татарстан, Агрызский район, село Азево, Советская, 22	f	small
11868	93334	465	республика Татарстан, Агрызский район, Агрыз, Энергетиков, 8	f	large
11861	93328	458	республика Татарстан, Агрызский район, Агрыз, Чапаева, 3	f	medium
11869	93335	466	республика Татарстан, Агрызский район, Агрыз, Саетова, 11	f	medium
11864	93331	461	республика Татарстан, Агрызский район, Агрыз, Пушкина, 4	f	large
11870	93336	467	республика Татарстан, Агрызский район, Агрыз, Октябрьская, 25а	f	medium
11862	93329	459	республика Татарстан, Агрызский район, Агрыз, Карла Маркса, 4а	f	medium
132420	93342	472	республика Татарстан, Агрызский район, Агрыз, Заводская, 59, здание завода АЗСМ	f	\N
11867	93333	464	республика Татарстан, Агрызский район, Агрыз, Гагарина, 56	f	medium
11866	93333	463	республика Татарстан, Агрызский район, Агрыз, Гагарина, 56	f	medium
11872	93339	469	республика Татарстан, Агрызский район, Агрыз, Вокзальная, 1	f	large
14170	1379	2767	республика Татарстан, Чистопольский муниципальный район, Чистополь, Мира, 40	f	large
12784	94307	1381	республика Татарстан,  Елабужский район, Елабуга, Радищева, 5	f	small
65988	55125	557	республика Мордовия, Темников, Советская, 45	f	large
10185	55278	750	республика Мордовия, Октябрьский район, Саранск, Пушкинская начальная общеобразовательная школа	f	medium
65980	54931	360	республика Мордовия, Саранск, улица Школьная, 1	f	small
10044	55173	609	республика Коми, Сыктывкар, улица Ленина, 3	f	large
10105	55235	691	республика Мордовия, Саранск, проспект Ленина, 11	f	large
10103	55233	689	республика Мордовия, Саранск, проспект Ленина, 15	f	large
10102	55232	688	республика Мордовия, Саранск, проспект Ленина, 24	f	large
65961	55272	740	республика Мордовия, Саранск, проспект 70 лет Октября, 160	f	large
10174	55270	739	республика Мордовия, Саранск, проспект 70 лет Октября, 160	f	large
10167	55267	732	республика Мордовия, Саранск, проспект 70 лет Октября, 70	f	large
10166	55267	731	республика Мордовия, Саранск, проспект 70 лет Октября, 70	f	large
10165	55266	730	республика Мордовия, Саранск, проспект 70 лет Октября, 102	f	large
10164	55266	729	республика Мордовия, Саранск, проспект 70 лет Октября, 102	f	large
10212	55298	777	республика Мордовия, Саранск, проспект 60 лет Октября, 103	f	large
10208	55296	773	республика Мордовия, Саранск, проспект 60 лет Октября, 12а	f	large
10206	55294	771	республика Мордовия, Саранск, проспект 60 лет Октября, 101	f	large
10205	55294	770	республика Мордовия, Саранск, проспект 60 лет Октября, 101	f	large
10179	55274	743	республика Мордовия, Саранск, бульвар Степана Эрьзи, 28а	f	large
10178	55274	744	республика Мордовия, Саранск, бульвар Степана Эрьзи, 28а	f	large
10147	55252	712	республика Мордовия, Саранск, Энергетическая, 10а	f	large
10131	55219	671	республика Мордовия, Саранск, Щорса, 29	f	large
10184	55277	749	республика Мордовия, Саранск, Школьная площадь, 16	f	large
10183	55277	748	республика Мордовия, Саранск, Школьная площадь, 16	f	large
9886	95136	451	республика Мордовия, Саранск, Школьная, 3	f	medium
65989	55146	582	республика Мордовия, Саранск, Школьная, 5	f	small
10134	55221	674	республика Мордовия, Саранск, Фурманова, 34А	f	large
10141	55225	681	республика Мордовия, Саранск, Ульянова, 26	f	large
10157	55262	722	республика Мордовия, Саранск, Транспортная, 17	f	large
10156	55261	721	республика Мордовия, Саранск, Транспортная, 11	f	large
10155	55260	720	республика Мордовия, Саранск, Транспортная, 9	f	large
10177	55273	741	республика Мордовия, Саранск, Сущинского, 5	f	large
10176	55273	742	республика Мордовия, Саранск, Сущинского, 5	f	large
10151	55256	716	республика Мордовия, Саранск, Сущинского, 24А	f	large
10153	55258	718	республика Мордовия, Саранск, Студенческая, 13	f	large
10152	55257	717	республика Мордовия, Саранск, Студенческая, 11а	f	large
10112	55241	698	республика Мордовия, Саранск, Степана Разина, 21	f	large
10121	55249	707	республика Мордовия, Саранск, Советская улица, 24	f	large
10188	55280	753	республика Мордовия, Саранск, Советская, 124а	f	medium
10120	55248	706	республика Мордовия, Саранск, Советская, 60	f	large
10119	55247	705	республика Мордовия, Саранск, Советская, 77	f	large
10136	55222	676	республика Мордовия, Саранск, Серадзская улица, 26а	f	large
10135	55222	675	республика Мордовия, Саранск, Серадзская улица, 26а	f	large
10138	55223	678	республика Мордовия, Саранск, Серадзская, 21	f	large
10137	55223	677	республика Мордовия, Саранск, Серадзская, 21	f	large
10170	55268	735	республика Мордовия, Саранск, Севастопольская улица, 74	f	large
10168	55268	733	республика Мордовия, Саранск, Севастопольская улица, 74	f	large
10169	55268	734	республика Мордовия, Саранск, Севастопольская улица, 74	f	large
10163	55265	728	республика Мордовия, Саранск, Севастопольская, 46	f	large
10162	55265	727	республика Мордовия, Саранск, Севастопольская, 46	f	large
10161	55265	726	республика Мордовия, Саранск, Севастопольская, 46	f	large
10126	55216	667	республика Мордовия, Саранск, Саранская улица, 52	f	large
10140	55224	680	республика Мордовия, Саранск, Розы Люксембург, 28	f	large
10139	55224	679	республика Мордовия, Саранск, Розы Люксембург, 28	f	large
10192	55284	757	республика Мордовия, Саранск, Рабочая, 15	f	large
10190	55282	755	республика Мордовия, Саранск, Рабочая, 4а	f	small
10231	55312	796	республика Мордовия, Саранск, Пушкина, 22	f	large
10108	55238	694	республика Мордовия, Саранск, Пролетарская, 101а	f	large
10113	55242	699	республика Мордовия, Саранск, Полежаева, 177	f	large
10106	55236	692	республика Мордовия, Саранск, Полежаева, 44	f	large
10220	55306	785	республика Мордовия, Саранск, Победы, 23а	f	large
10219	55305	784	республика Мордовия, Саранск, Победы, 4	f	small
10154	55259	719	республика Мордовия, Саранск, Павлика Морозова, 11	f	large
10197	55285	762	республика Мордовия, Саранск, Октябрьская, 29	f	medium
10193	55285	758	республика Мордовия, Саранск, Октябрьская, 29	f	large
10195	55286	760	республика Мордовия, Саранск, Октябрьская, 27	f	small
10194	55286	759	республика Мордовия, Саранск, Октябрьская, 27	f	large
10196	55286	761	республика Мордовия, Саранск, Октябрьская, 27	f	medium
10236	55314	801	республика Мордовия, Саранск, Никула Эркая, 16	f	large
10235	55314	800	республика Мордовия, Саранск, Никула Эркая, 16	f	large
10150	55255	715	республика Мордовия, Саранск, Московская, 115	f	large
10124	55251	710	республика Мордовия, Саранск, Московская, 78	f	large
10123	55250	709	республика Мордовия, Саранск, Московская, 68	f	large
10122	55250	708	республика Мордовия, Саранск, Московская, 68	f	large
10199	55288	764	республика Мордовия, Саранск, Московская, 83б	f	small
10149	55254	714	республика Мордовия, Саранск, Мокшанская, 16	f	large
10187	55279	752	республика Мордовия, Саранск, Мичурина, 34	f	large
10186	55279	751	республика Мордовия, Саранск, Мичурина, 34	f	large
10233	55304	798	республика Мордовия, Саранск, Миронова, 8	f	large
10218	55304	783	республика Мордовия, Саранск, Миронова, 8	f	large
10234	55304	799	республика Мордовия, Саранск, Миронова, 8	f	large
10211	55297	776	республика Мордовия, Саранск, Металлургов, 2	f	large
10210	55297	775	республика Мордовия, Саранск, Металлургов, 2	f	large
10209	55297	774	республика Мордовия, Саранск, Металлургов, 2	f	large
10133	55220	673	республика Мордовия, Саранск, Марины Расковой, 17а	f	large
10132	55220	672	республика Мордовия, Саранск, Марины Расковой, 17а	f	large
10173	55269	738	республика Мордовия, Саранск, Лихачева, 40	f	large
10172	55269	737	республика Мордовия, Саранск, Лихачева, 40	f	large
10171	55269	736	республика Мордовия, Саранск, Лихачева, 40	f	large
10160	55264	725	республика Мордовия, Саранск, Ленинградская, 34	f	large
10180	95025	746	республика Мордовия, Саранск, Косарева, 112-Б	f	large
10175	95025	745	республика Мордовия, Саранск, Косарева, 112-Б	f	large
9559	54717	144	республика Мордовия, Саранск, Кооперативная, 3	f	medium
10117	55245	703	республика Мордовия, Саранск, Коммунистическая, 89	f	large
10118	55246	704	республика Мордовия, Саранск, Коммунистическая, 103	f	large
10130	55218	711	республика Мордовия, Саранск, Комарова, 7	f	large
10128	55218	670	республика Мордовия, Саранск, Комарова, 7	f	large
10129	55218	669	республика Мордовия, Саранск, Комарова, 7	f	large
10217	55303	782	республика Мордовия, Саранск, Коваленко, 38а	f	large
10224	55308	789	республика Мордовия, Саранск, Коваленко, 21	f	large
10223	55308	788	республика Мордовия, Саранск, Коваленко, 21	f	large
10222	55307	787	республика Мордовия, Саранск, Коваленко, 13	f	large
10221	55307	786	республика Мордовия, Саранск, Коваленко, 13	f	large
9870	55005	437	республика Мордовия, Саранск, Зеленый Дол, 50а	f	small
10214	55299	779	республика Мордовия, Саранск, Есенина, 14А	f	large
10213	55299	778	республика Мордовия, Саранск, Есенина, 14А	f	large
10127	55217	668	республика Мордовия, Саранск, Гагарина, 108	f	large
10114	55243	700	республика Мордовия, Саранск, Гагарина, 7а	f	large
10115	55244	701	республика Мордовия, Саранск, Гагарина, 13	f	large
10116	55244	702	республика Мордовия, Саранск, Гагарина, 13	f	large
10104	55234	690	республика Мордовия, Саранск, Володарского, 5	f	large
10159	55263	724	республика Мордовия, Саранск, Волгоградская улица, 88	f	large
10158	55263	723	республика Мордовия, Саранск, Волгоградская улица, 88	f	large
10216	95158	781	республика Мордовия, Саранск, Веселовского, 39	f	large
10228	55311	793	республика Мордовия, Саранск, Веселовского, 3	f	large
10227	55311	792	республика Мордовия, Саранск, Веселовского, 3	f	large
10230	55300	795	республика Мордовия, Саранск, Веселовского, 39	f	large
10229	55300	794	республика Мордовия, Саранск, Веселовского, 39	f	large
10215	55300	780	республика Мордовия, Саранск, Веселовского, 39	f	large
10204	55293	769	республика Мордовия, Саранск, Веселовского, 16а	f	large
10203	55292	768	республика Мордовия, Саранск, Веселовского, 16А	f	large
10148	55253	713	республика Мордовия, Саранск, Вакеева, 3	f	large
10110	55239	696	республика Мордовия, Саранск, Ботевградская улица, 102	f	large
10109	55239	695	республика Мордовия, Саранск, Ботевградская улица, 102	f	large
10111	55240	697	республика Мордовия, Саранск, Богдана Хмельницкого, 57	f	large
10107	55237	693	республика Мордовия, Саранск, Богдана Хмельницкого, 39	f	large
10226	55310	791	республика Мордовия, Саранск, Анны Лусс, 7	f	large
10225	55309	790	республика Мордовия, Саранск, Анны Лусс, 7	f	large
10125	55215	666	республика Мордовия, Саранск, Александра Невского, 57	f	large
10191	55283	756	республика Мордовия, Саранск, Рабочая, 33А	f	large
10232	55313	797	республика Мордовия, Саранск, Пушкина, 22	f	large
10101	55231	687	республика Мордовия, Саранск, Васенко, 3	f	large
9932	55055	493	республика Мордовия, Рузаевка, бульвар Школьный, 1	f	medium
9953	55079	516	республика Мордовия, Рузаевка, бульвар Горшкова, 3А	f	large
65972	55056	517	республика Мордовия, Рузаевка, Юрасова, 15	f	large
65971	55056	494	республика Мордовия, Рузаевка, Юрасова, 15	f	large
9943	55070	507	республика Мордовия, Рузаевка, Энергетическая, 2Г	f	small
9945	55072	509	республика Мордовия, Рузаевка, Тухачевского, 10	f	large
9944	55071	508	республика Мордовия, Рузаевка, Титова	f	large
9946	55062	510	республика Мордовия, Рузаевка, Титова, 2	f	large
9921	55049	488	республика Мордовия, Рузаевка, Терешковой, 91/93	f	large
9931	55058	496	республика Мордовия, Рузаевка, Станиславского, 4	f	large
9919	55047	486	республика Мордовия, Рузаевка, Революции 1905 года, 6	f	medium
9930	55057	495	республика Мордовия, Рузаевка, Полежаева, 33	f	large
9949	55075	513	республика Мордовия, Рузаевка, Мира, 21	f	medium
65967	55077	515	республика Мордовия, Рузаевка, Маяковского, 90А	f	large
9927	55054	492	республика Мордовия, Рузаевка, Маяковского, 102	f	medium
9948	55073	511	республика Мордовия, Рузаевка, Луговая, 6А	f	medium
9924	55052	490	республика Мордовия, Рузаевка, Ленина, 59	f	large
9920	55048	487	республика Мордовия, Рузаевка, Ленина, 93	f	large
9918	55046	485	республика Мордовия, Рузаевка, Ленина, 16	f	large
9950	55076	514	республика Мордовия, Рузаевка, Красноармейская, 35	f	large
9922	55050	489	республика Мордовия, Рузаевка, Карла Маркса, 15	f	medium
9947	55074	512	республика Мордовия, Рузаевка, З.Космодемьянской, 80	f	large
65973	55098	534	республика Мордовия, Рузаевка, 40 Лет Победы , 18А	f	large
9926	55053	491	республика Мордовия, Рузаевка, Байкузова, 137	f	large
9830	54969	400	республика Мордовия, Краснослободск, пл. Советская, 9	f	small
9827	54967	398	республика Мордовия, Краснослободск, Коммунистическая, 49	f	large
67855	54944	375	республика Мордовия, Ковылкино, Щорса, 4	f	large
9783	54938	369	республика Мордовия, Ковылкино, Школьная, 1	f	medium
9789	54943	374	республика Мордовия, Ковылкино, Фролова, 3 А	f	large
67854	54935	366	республика Мордовия, Ковылкино, Урицкого, 7А	f	large
86024	54947	378	республика Мордовия, Ковылкино, Сосновый бор, Ковылкинский район Сосновый бор	f	small
111318	54945	376	республика Мордовия, Ковылкино, Пионерская, 44	f	medium
9802	95132	370	республика Мордовия, Ковылкино, Ленина, 4	f	large
111319	54946	377	республика Мордовия, Ковылкино, Кутузова, 20	f	medium
9801	54942	373	республика Мордовия, Ковылкино, Королева, 5	f	large
9785	54941	372	республика Мордовия, Ковылкино, Желябова, 26	f	small
9787	54940	371	республика Мордовия, Ковылкино, Есенина, 10	f	small
65983	54937	368	республика Мордовия, Ковылкино, Гагарина, 14А	f	medium
111317	95131	367	республика Мордовия, Ковылкино, 40 лет Октября, 10	f	medium
9664	54821	246	республика Мордовия, Инсар, Московская, 118	f	large
9666	54823	248	республика Мордовия, Инсар, Восточный переулок, 12А	f	medium
9668	54825	250	республика Мордовия, Инсар, Больничный переулок, 9	f	medium
9861	54997	429	республика Мордовия, село Берсеневка, Пролетарская, 15	f	medium
9860	54997	428	республика Мордовия, село Берсеневка, Пролетарская, 15	f	medium
9419	54596	5	республика Мордовия, Ардатов, Садовая, 47	f	large
10073	55190	638	республика Мордовия, Чамзинский район, поселок Чамзинка, микрорайон6, 24	f	large
10072	55189	637	республика Мордовия, Чамзинский район, поселок Чамзинка, Титова, 12	f	large
10070	55187	635	республика Мордовия, Чамзинский район, поселок Чамзинка, Терешковой, 7А	f	large
10071	55188	636	республика Мордовия, Чамзинский район, поселок Чамзинка, Ленина, 18	f	medium
10069	55186	634	республика Мордовия, Чамзинский район, поселок Чамзинка, Ленина, 10	f	large
10100	95157	665	республика Мордовия, Чамзинский район, село Сабур-Мачкасы, Советская, 52	f	small
10074	55191	639	республика Мордовия, Чамзинский район, село Репьевка, Советская, 46А	f	medium
10097	95156	662	республика Мордовия, Чамзинский район, село Пянгелей, Подлесная, 14	f	small
10099	55213	664	республика Мордовия, Чамзинский район, село Печеуры, Луначарского, 17	f	medium
10098	55212	663	республика Мордовия, Чамзинский район, село Отрадное, Молодежная, 13	f	small
10094	95154	659	республика Мордовия, Чамзинский район, село Новоселки, Центральная, 1-а	f	small
10085	95151	650	республика Мордовия, Чамзинский район, село Наченалы, Большая, 58	f	small
10096	95155	661	республика Мордовия, Чамзинский район, село Мокшалей, Ленинская, 53	f	small
10093	55207	658	республика Мордовия, Чамзинский район, село Мичурино, Советская, 4	f	small
10091	55205	656	республика Мордовия, Чамзинский район, село Медаево, Гагарина, 1А	f	medium
10092	55206	657	республика Мордовия, Чамзинский район, село Мачказерово, Ленина, 1	f	small
10090	55204	655	республика Мордовия, Чамзинский район, село Малое Маресево, Ленина, 1	f	small
10089	95153	654	республика Мордовия, Чамзинский район, село Кульмино, Площадь, 19	f	small
10088	55202	653	республика Мордовия, Чамзинский район, село Красный Поселок, Центральная, 21	f	small
10081	55195	646	республика Мордовия, Чамзинский район, поселок Комсомольский, микрорайон-2, 13	f	large
10080	55195	645	республика Мордовия, Чамзинский район, поселок Комсомольский, микрорайон-2, 13	f	large
10079	55194	644	республика Мордовия, Чамзинский район, поселок Комсомольский, микрорайон-1, 48	f	large
10078	55194	643	республика Мордовия, Чамзинский район, поселок Комсомольский, микрорайон-1, 48	f	large
10077	55193	642	республика Мордовия, Чамзинский район, поселок Комсомольский, микрорайон-1, 18	f	large
10076	55193	641	республика Мордовия, Чамзинский район, поселок Комсомольский, микрорайон-1, 18	f	large
10075	55192	640	республика Мордовия, Чамзинский район, поселок Комсомольский, Театральная, 3	f	large
10082	55196	647	республика Мордовия, Чамзинский район, поселок Комсомольский, Комсомольская, 5	f	large
9498	54669	83	республика Мордовия, Чамзинский район, село Киржеманы, Советская, 8	f	medium
10083	55197	648	республика Мордовия, Чамзинский район, село Киржеманы, Карла Маркса, 1	f	medium
9547	53556	132	республика Мордовия, Чамзинский район, село Киржеманы, Советская, 33	f	small
10086	95152	651	республика Мордовия, Чамзинский район, село Большое Маресево, Видяйкина, 1	f	medium
10087	55201	652	республика Мордовия, Чамзинский район, село Большие Ремезенки, Молодежная, 1В	f	small
10084	95150	649	республика Мордовия, Чамзинский район, село Апраксино, Центральная, 11	f	medium
10062	55179	627	республика Мордовия, Торбеевский район, поселок Центральный, Школьная, 5	f	small
10066	55183	631	республика Мордовия, Торбеевский район, село Хилково, Советская 1-я, 90	f	small
10045	55174	610	республика Мордовия, Торбеевский район, поселок Торбеево, мкр 3-й, 4	f	large
10043	55172	608	республика Мордовия, Торбеевский район, поселок Торбеево, Студенческая, 45	f	large
10042	55171	607	республика Мордовия, Торбеевский район, поселок Торбеево, Садовая, 42	f	large
10047	55176	612	республика Мордовия, Торбеевский район, село Татарские Юнки, Молодежная, 4	f	small
10060	95104	625	республика Мордовия, Торбеевский район, село Сургодь, Школьная, 1а	f	small
9511	54679	96	республика Мордовия, Атяшевский район, село Тарасово, Красная, 75	f	small
10053	52424	618	республика Мордовия, Торбеевский район, село Старые Пичуры, Ленина, 2	f	small
10056	95103	621	республика Мордовия, Торбеевский район, село Слаим, Советская, 23	f	small
10052	52412	617	республика Мордовия, Торбеевский район, село Семивражки, Восточная, 3	f	small
10061	95105	626	республика Мордовия, Торбеевский район, село Салазгорь, Эрькина, 5 а	f	medium
10059	55051	624	республика Мордовия, Торбеевский район, село Савва, Школьная, 1	f	small
10067	55184	632	республика Мордовия, Торбеевский район, село Носакино, Центральная, 9	f	medium
10058	55028	623	республика Мордовия, Торбеевский район, село Никольское, Центральная, 3	f	small
10048	95148	613	республика Мордовия, Торбеевский район, село Мордовские Юнки, Школьная, 9 а	f	small
10065	95149	630	республика Мордовия, Торбеевский район, село Мальцево, Садовая, 2	f	small
9888	51441	453	республика Мордовия, Торбеевский район, село Лопатино, Центральная, 7	f	small
10051	52382	616	республика Мордовия, Торбеевский район, село Краснополье, Школьная, 3	f	small
10049	55178	614	республика Мордовия, Торбеевский район, село Красноармеец, Школьная, 1	f	medium
10054	52464	619	республика Мордовия, Торбеевский район, село Красаевка, Советская, 36	f	small
10055	95102	620	республика Мордовия, Торбеевский район, село Кажлодка, Школьная, 49	f	small
10046	95147	611	республика Мордовия, Торбеевский район, село Жуково, Почтовая, 21 в	f	medium
10050	52290	615	республика Мордовия, Торбеевский район, село Дракино, Школьная, 2А	f	large
10068	55185	633	республика Мордовия, Торбеевский район, поселок Виндрей, Советская, 14	f	small
10063	55180	628	республика Мордовия, Торбеевский район, село Варжеляй, Советская 2-я, 43	f	small
10057	53003	622	республика Мордовия, Торбеевский район, село Аксеновка, Школьная, 20	f	small
10041	55170	606	республика Мордовия, Теньгушевский район, село Шокша, Верхняя, 19А	f	small
10029	55158	594	республика Мордовия, Теньгушевский район, село Широмасово, Советская, 27	f	small
10039	55168	604	республика Мордовия, Теньгушевский район, село Хлебино, Школьная, 1Б	f	small
10020	55149	585	республика Мордовия, Теньгушевский район, село Теньгушево, проспект Ленина, 74	f	large
10025	55154	590	республика Мордовия, Теньгушевский район, село Теньгушево, Школьная, 2	f	small
10034	55163	599	республика Мордовия, Теньгушевский район, село Теньгушево, Центральная, 61	f	small
10026	55155	591	республика Мордовия, Теньгушевский район, село Теньгушево, Центральная, 39	f	small
10024	55153	589	республика Мордовия, Теньгушевский район, село Теньгушево, Московская, 2	f	large
10030	55159	595	республика Мордовия, Теньгушевский район, село Теньгушево, Ленина, 7	f	small
10028	55157	593	республика Мордовия, Теньгушевский район, село Теньгушево, Ленина, 94	f	small
10019	55148	584	республика Мордовия, Теньгушевский район, село Теньгушево, Ленина, 72	f	large
10027	55156	592	республика Мордовия, Теньгушевский район, село Телимерки, Центральная, 26/2	f	small
10037	55166	602	республика Мордовия, Теньгушевский район, село Такушево, Новая, 3	f	small
10033	55162	598	республика Мордовия, Теньгушевский район, село Стандрово, Школьная, 16А	f	small
10040	55169	605	республика Мордовия, Теньгушевский район, село Сакаево, Советская, 2	f	small
10036	55165	601	республика Мордовия, Теньгушевский район, село Садовый, Центральная, 8	f	small
10032	55161	597	республика Мордовия, Теньгушевский район, село Нароватово, Садовая, 2	f	small
10035	55164	600	республика Мордовия, Теньгушевский район, село Нагорная, Центральная, 50	f	small
10031	55160	596	республика Мордовия, Теньгушевский район, село Мельсетьево, Гагарина, 2А	f	small
10064	55181	629	республика Мордовия, Теньгушевский район, село Куликово, Куликово, 124	f	small
10021	55150	586	республика Мордовия, Теньгушевский район, село Дудниково, Центральная, 18/1	f	small
10023	55152	588	республика Мордовия, Теньгушевский район, село Вичкидеево, Центральная, 48/1	f	small
10038	55167	603	республика Мордовия, Теньгушевский район, село Веденяпино, Поповка, 5	f	small
10022	55151	587	республика Мордовия, Теньгушевский район, село Башкирцы, Центральная, 2А	f	small
10010	55137	573	республика Мордовия, Темниковский район, село Чумартово, Школьная, 103	f	small
9862	54998	430	республика Мордовия, Темниковский район, село Чекаевка, 153	f	small
9512	54680	97	республика Мордовия, Темниковский район, село Ушаковка, Фрунзе, 27	f	small
10017	55144	580	республика Мордовия, Темниковский район, село Урей 3-й, Советская, 8	f	small
10000	55129	565	республика Мордовия, Темниковский район, село Тювеево, Молодежная, 15	f	medium
9994	55083	559	республика Мордовия, Темниковский район, Темников, Школьная, 1А	f	large
9990	55123	555	республика Мордовия, Темниковский район, Темников, Коммунистическая, 17	f	large
9993	55126	558	республика Мордовия, Темниковский район, Темников, Восточная, 2	f	medium
9991	95143	556	республика Мордовия, Темниковский район, Темников, Белинского, 18-а	f	large
10016	55143	579	республика Мордовия, Темниковский район, село Тарханы, Малая, 4	f	small
10014	55141	577	республика Мордовия, Темниковский район, село Старый Ковыляй, Центральная, 27	f	small
9996	55115	561	республика Мордовия, Темниковский район, село Старый Город, Центральная, 50А	f	small
10012	55139	575	республика Мордовия, Темниковский район, село Русское Караево, Центральная, 107	f	small
10013	55140	576	республика Мордовия, Темниковский район, село Пушта, Лесная, 9	f	small
10011	95099	574	республика Мордовия, Темниковский район, село Пурдошки, Крупской, 18	f	small
10006	55133	569	республика Мордовия, Темниковский район, село Подгорное Канаково, Центральная, 2	f	small
9715	54867	294	республика Мордовия, Темниковский район, село Оброчное, Юбилейная, 25	f	medium
10015	95144	578	республика Мордовия, Темниковский район, село Нижние Борки, Центральная, 48	f	small
10009	55136	572	республика Мордовия, Темниковский район, село Митрялы, Центральная, 27	f	medium
9998	55127	563	республика Мордовия, Темниковский район, село Лесное Цибаево, Центральная, 6, МБУК КДЦ Лесно-Цибаевский	f	small
9999	55128	564	республика Мордовия, Темниковский район, село Лесное Ардашево, Лесная, 101	f	small
9997	52155	562	республика Мордовия, Темниковский район, село Лаврентьево, Бугорская, 7	f	small
10001	55130	566	республика Мордовия, Темниковский район, село Кушки, Школьная, 13	f	small
10005	95096	568	республика Мордовия, Темниковский район, село Кондровка, Центральная, 24	f	small
10008	95097	571	республика Мордовия, Темниковский район, село Ишейки, Молодежная, 12	f	small
10007	55134	570	республика Мордовия, Темниковский район, село Жегалово, Молодежная, 10	f	small
10018	95145	581	республика Мордовия, Темниковский район, село Булаево, Гагарина, 13	f	medium
65990	95146	583	республика Мордовия, Темниковский район, село Андреевка, Молодежная, 10	f	medium
9995	55104	560	республика Мордовия, Темниковский район, село Алексеевка, Поселковая, 2	f	small
10003	55131	567	республика Мордовия, Темниковский район, село Аксел, Центральная, 13	f	small
9989	55122	554	республика Мордовия, Старошайговский район, село Шувары, Центральная, 1а	f	small
9988	55121	553	республика Мордовия, Старошайговский район, село Шигонь, Московская, 35	f	small
9987	55120	552	республика Мордовия, Старошайговский район, село Старое Шайгово, Комсомольский переулок, 13	f	large
9986	55119	551	республика Мордовия, Старошайговский район, село Старое Шайгово, Кирова, 14	f	large
9985	55118	550	республика Мордовия, Старошайговский район, село Старая Федоровка, Молодежная, 31	f	small
65970	55117	549	республика Мордовия, Старошайговский район, село Старая Теризморга, Центральная, 76	f	medium
9972	55100	536	республика Мордовия, Старошайговский район, село Совхоз Восход, Центральная, 40	f	small
65969	55113	548	республика Мордовия, Старошайговский район, село Рязановка, Ленина, 8	f	small
9980	55109	544	республика Мордовия, Старошайговский район, село Новотроицкое, Советская, 5	f	small
9978	55107	542	республика Мордовия, Старошайговский район, село Новое Акшино, Центральная, 13	f	medium
9981	55110	545	республика Мордовия, Старошайговский район, село Новая Федоровка	f	medium
9979	55108	543	республика Мордовия, Старошайговский район, село Новая Александровка, Новая, 13 а	f	small
9977	55106	541	республика Мордовия, Старошайговский район, село Мельцаны, Ремесленная 1, 1	f	medium
9976	55105	540	республика Мордовия, Старошайговский район, село Летки, Центральная, 35	f	small
9975	55103	539	республика Мордовия, Старошайговский район, село Лемдяй, Советская, 32	f	small
65966	55112	547	республика Мордовия, Старошайговский район, село Кулдым, Чапаева, 43	f	small
9974	55102	538	республика Мордовия, Старошайговский район, село Конолать, Молодежная, 1	f	small
9973	55101	537	республика Мордовия, Старошайговский район, село Ингенер-Пятина, Советская, 52	f	small
9982	55111	546	республика Мордовия, Старошайговский район, село Вертелим, Базарная, 1а	f	small
9971	55099	535	республика Мордовия, Старошайговский район, село Богдановка, Переулок Чапаева, 4	f	medium
10182	55276	747	республика Мордовия, Саранск городской округ, село Озерный, Тепличная, 16	f	large
10189	55281	754	республика Мордовия, Саранск городской округ, село Монастырское, Школьная, 19	f	medium
9958	95141	522	республика Мордовия, Рузаевский район, село совхоз Красное Сельцо, Садовая, 1	f	large
9970	55080	518	республика Мордовия, Рузаевский район, село Шишкеево, Базарная, 12А	f	medium
9968	55096	532	республика Мордовия, Рузаевский район, село Хованщина, Железнодорожная, 21А	f	small
9966	55094	530	республика Мордовия, Рузаевский район, село Трускляй, Ленина, 18А	f	medium
9964	55091	528	республика Мордовия, Рузаевский район, село Татарская Пишля, Южная, 23	f	large
9965	55092	529	республика Мордовия, Рузаевский район, село Татарская Пишля, пер.Школьный, 15	f	large
9938	55065	502	республика Мордовия, Рузаевский район, село Сузгарье, Коммунистическая, 30А	f	medium
9969	55097	533	республика Мордовия, Рузаевский район, село Стрелецкая Слобода, Пролетарская, 8	f	small
9962	55089	526	республика Мордовия, Рузаевский район, село Русское Баймаково, Школьная, 4	f	small
9940	55067	504	республика Мордовия, Рузаевский район, село Плодопитомнический, Солнечная, 8	f	medium
9939	55066	503	республика Мордовия, Рузаевский район, село Перхляй, Шишкеевская, 3А	f	medium
9961	55088	525	республика Мордовия, Рузаевский район, село Палаевка, Садовая, 21	f	small
9960	95142	524	республика Мордовия, Рузаевский район, село Пайгарма, Центральная, 1, пос. совхоза №3 ДорУРСа	f	medium
9963	55090	527	республика Мордовия, Рузаевский район, село Новый Усад, Центральная, 13А	f	small
9956	55082	520	республика Мордовия, Рузаевский район, село Новая Муравьевка, Молодежная, 4	f	small
9959	55086	523	республика Мордовия, Рузаевский район, село Мордовская Пишля, Байкузова, 33а	f	small
9941	55068	505	республика Мордовия, Рузаевский район, село Левженский, Центральная, 29	f	medium
9937	55064	501	республика Мордовия, Рузаевский район, село Левжа, Ленина, 68А	f	medium
9936	55063	500	республика Мордовия, Рузаевский район, село Красный Клин, Переулок Школьный, 104А	f	medium
9935	55061	499	республика Мордовия, Рузаевский район, село Ключарево, Центральная, 28	f	small
9967	55095	531	республика Мордовия, Рузаевский район, село Инсар-Акшино, Московская, 5	f	small
9957	55084	521	республика Мордовия, Рузаевский район, село Верхний Урледим, Урледимская, 8А	f	small
9955	55081	519	республика Мордовия, Рузаевский район, село Болдово, Никольская, 1А	f	medium
9934	55060	498	республика Мордовия, Рузаевский район, село Архангельское Голицыно, Советская, 42	f	medium
9933	55059	497	республика Мордовия, Рузаевский район, село Аргамаково, Школьная, 17	f	small
9942	55069	506	республика Мордовия, Рузаевский муниципальный район, Рузаевка, Переходная, 6	f	medium
9917	55045	484	республика Мордовия, Ромодановский район, село Уришка, Клубная, 3	f	small
9916	55044	483	республика Мордовия, Ромодановский район, село Трофимовщина, Школьная, 1	f	medium
9898	55027	467	республика Мордовия, Ромодановский район, село Старая Михайловка, Центральная, 7	f	small
9909	95138	473	республика Мордовия, Ромодановский район, село Совхоз Садвинтрест, Садовая, 18	f	small
9912	95139	480	республика Мордовия, Ромодановский район, Ромодановский Махоркосовхоз, Школьный переулок, 7	f	small
9915	95140	482	республика Мордовия, Ромодановский район, поселок Ромоданово, Центральная, 97	f	medium
65965	55017	457	республика Мордовия, Ромодановский район, поселок Ромоданово, Центральная, 9	f	large
65964	55021	461	республика Мордовия, Ромодановский район, поселок Ромоданово, Транспортный проезд, 5	f	large
65963	95137	464	республика Мордовия, Ромодановский район, поселок Ромоданово, Пятинское шоссе, 4	f	medium
9893	55020	460	республика Мордовия, Ромодановский район, поселок Ромоданово, Промышленное шоссе, 18	f	medium
9892	55018	458	республика Мордовия, Ромодановский район, поселок Ромоданово, Крылова, 2	f	large
9895	55023	463	республика Мордовия, Ромодановский район, поселок Ромоданово, Железнодорожная, 7	f	large
9894	55022	462	республика Мордовия, Ромодановский район, поселок Ромоданово, Есенина, 7	f	large
9891	55019	459	республика Мордовия, Ромодановский район, поселок Ромоданово, Дорожная, 30	f	large
9907	55042	481	республика Мордовия, Ромодановский район, село Пушкино, Школьная, 1	f	small
9914	55040	479	республика Мордовия, Ромодановский район, село Малые Березники, Дорожная , 34	f	small
9904	55039	478	республика Мордовия, Ромодановский район, село Липки, Школьная, 9	f	small
9913	55037	476	республика Мордовия, Ромодановский район, село Курмачкасы, Кирова, 26А	f	small
9910	55035	474	республика Мордовия, Ромодановский район, село Курилово, Центральная, 29	f	small
9903	55038	477	республика Мордовия, Ромодановский район, село Красный Узел, Школьная, 8	f	small
9908	55033	472	республика Мордовия, Ромодановский район, село Кочуново, Молодежная, 26	f	small
9905	55031	470	республика Мордовия, Ромодановский район, село Константиновка, Центральная, 3	f	small
9856	54993	424	республика Мордовия, Ромодановский район, село Инят	f	small
9906	55032	471	республика Мордовия, Ромодановский район, село Ивановка, Центральная, 22	f	small
9902	55030	469	республика Мордовия, Ромодановский район, село Вырыпаево, Школьная, 7	f	small
9911	55036	475	республика Мордовия, Ромодановский район, село Болтино, Химмашевская, 22	f	small
9900	55029	468	республика Мордовия, Ромодановский район, село Белозерье, Центральная, 2	f	small
9897	55026	466	республика Мордовия, Ромодановский район, село Анненково, Новая, 18	f	medium
9896	55025	465	республика Мордовия, Ромодановский район, село Алтары, Молодежная, 18	f	small
9881	55011	446	республика Мордовия, Лямбирский район, село Черемишево, Молодёжная , 35	f	small
9890	51968	455	республика Мордовия, Лямбирский район, село Татарская Тавла, Школьная, 34	f	medium
65984	55000	432	республика Мордовия, Лямбирский район, село Татарская Свербейка, Центральная, 38А	f	medium
9872	55007	439	республика Мордовия, Лямбирский район, село Суркино, Молодежная, 2А	f	small
9887	51171	452	республика Мордовия, Лямбирский район, село Смольково, Школьная, 9	f	small
9453	54630	39	республика Мордовия, Лямбирский район, село Смольково, Центральная, 21	f	small
9889	51500	454	республика Мордовия, Лямбирский район, село Скрябино, Советская, 35	f	small
9885	55015	450	республика Мордовия, Лямбирский район, село Протасово, Комсомольская, 12	f	small
9883	55013	448	республика Мордовия, Лямбирский район, село Первомайск, Жигули, 15	f	medium
9884	95135	449	республика Мордовия, Лямбирский район, село Пензятка, Юбилейная, 5-а	f	medium
9882	55012	447	республика Мордовия, Лямбирский район, село Новая Михайловка, Нижняя, 8	f	small
9867	55002	434	республика Мордовия, Лямбирский район, село Масловка, Заречная, 8	f	small
9879	55010	445	республика Мордовия, Лямбирский район, село Лямбирь, Октябрьская, 78	f	small
9878	55010	444	республика Мордовия, Лямбирский район, село Лямбирь, Октябрьская, 78	f	medium
9876	55009	443	республика Мордовия, Лямбирский район, село Лямбирь, Ленина, 67	f	large
9875	55009	442	республика Мордовия, Лямбирский район, село Лямбирь, Ленина, 67	f	medium
9874	55008	441	республика Мордовия, Лямбирский район, село Лямбирь, Ленина, 4	f	large
9873	55008	440	республика Мордовия, Лямбирский район, село Лямбирь, Ленина, 4	f	medium
9871	55006	438	республика Мордовия, Лямбирский район, село Кривозерье, Ленина, 8А	f	medium
9868	95134	435	республика Мордовия, Лямбирский район, поселок Большая Елховка, Фабричная, 21	f	large
65985	55004	436	республика Мордовия, Лямбирский район, поселок Большая Елховка, Фабричная, 18	f	large
9866	55001	433	республика Мордовия, Лямбирский район, село Болотниково, Садовая, 24 А	f	small
9863	54999	431	республика Мордовия, Лямбирский район, село Блохино, 1-Б/3	f	small
65986	54995	427	республика Мордовия, Лямбирский район, село Атемар, Центральная, 71	f	large
65987	54995	426	республика Мордовия, Лямбирский район, село Атемар, Центральная, 71	f	large
9857	54994	425	республика Мордовия, Лямбирский район, село Александровка, Долганова, 1	f	large
9855	54992	423	республика Мордовия, Лямбирский район, село Аксеново, Молодежная, 29	f	large
9852	54990	421	республика Мордовия, Краснослободский район, село Шаверки, Ленина, 25	f	small
9854	54991	422	республика Мордовия, Краснослободский район, село Чукалы, Садовая, 13а	f	small
9845	54983	414	республика Мордовия, Краснослободский район, село Старые Горяши, Садовая, 2 Г	f	large
9851	54989	420	республика Мордовия, Краснослободский район, село Старое-Синдрово, Советская, 2 А	f	large
9848	54986	417	республика Мордовия, Краснослободский район, село Старое Зубарево, Нижняя, 45	f	small
9850	54988	419	республика Мордовия, Краснослободский район, село Старая Рябка, Молодежная, 32	f	medium
9844	54982	413	республика Мордовия, Краснослободский район, село Слободские Дубровки, Коммунистическая, 37	f	small
9843	95133	412	республика Мордовия, Краснослободский район, село Сивинь, Садовая, 10-а	f	small
9842	54980	411	республика Мордовия, Краснослободский район, село Селищи, Ленина, 1 а	f	medium
9837	54976	407	республика Мордовия, Краснослободский район, село Русское Маскино, Подгора, 14	f	small
9847	54985	416	республика Мордовия, Краснослободский район, село Пригородное, Центральная, 29	f	medium
9849	54987	418	республика Мордовия, Краснослободский район, поселок Преображенский, Лесная, 18	f	medium
9832	54971	402	республика Мордовия, Краснослободский район, село Плужное, Большая, 114а	f	small
9841	54979	410	республика Мордовия, Краснослободский район, село Новая Карьга, пл. Центральная, 1	f	medium
9839	54978	409	республика Мордовия, Краснослободский район, село Мордовские Парки, Ленина, 68	f	small
9838	54977	408	республика Мордовия, Краснослободский район, село Куликово, Центральная, 23	f	small
9825	54964	395	республика Мордовия, Краснослободский район, Краснослободск, Микрорайон3, 11	f	large
9826	54965	396	республика Мордовия, Краснослободский район, Краснослободск, Микрорайон-3, 17	f	large
9823	54962	393	республика Мордовия, Краснослободский район, Краснослободск, Микрорайон-1, 38	f	large
9824	54963	394	республика Мордовия, Краснослободский район, Краснослободск, Кирова, 95	f	large
9829	54968	399	республика Мордовия, Краснослободский район, Краснослободск, Интернациональная, 25 а	f	large
9828	54966	397	республика Мордовия, Краснослободский район, Краснослободск, Интернациональная, 67	f	large
9836	54975	406	республика Мордовия, Краснослободский район, село Красная Подгора, Зелёная, 36	f	medium
9834	54973	404	республика Мордовия, Краснослободский район, село Колопино, Пролетарская, 62 а	f	medium
9846	54984	415	республика Мордовия, Краснослободский район, село Заречное, Кооперативная, 29 А	f	medium
9835	54974	405	республика Мордовия, Краснослободский район, село Желтоногово, Центральная, 153	f	small
9833	54972	403	республика Мордовия, Краснослободский район, село Ефаево, Центральная, 62 б	f	medium
9831	54970	401	республика Мордовия, Краснослободский район, село Гумны, Победы, 33	f	medium
9812	54952	383	республика Мордовия, Кочкуровский район, село Татарский Умыс, Московская, 167А	f	small
9822	54961	392	республика Мордовия, Кочкуровский район, село Старые Турдаки, Московская, 3	f	small
9819	54959	390	республика Мордовия, Кочкуровский район, село Семилей, Центральная, 62А	f	medium
9818	54958	389	республика Мордовия, Кочкуровский район, село Сабаево, Ленина, 68, Сабаевская средняя общеобразовательная школа	f	medium
9817	54957	388	республика Мордовия, Кочкуровский район, село Подлесная Тавла, Школьная, 3А	f	small
9821	54960	391	республика Мордовия, Кочкуровский район, село Новые Турдаки, Карла Маркса, 18	f	small
9816	54956	387	республика Мордовия, Кочкуровский район, село Новая Пырма, Школьная, 13	f	small
9815	54955	386	республика Мордовия, Кочкуровский район, село Мурань, Центральная, 52	f	small
9814	54954	385	республика Мордовия, Кочкуровский район, село Мордовское Давыдово, Центральная, 9А	f	small
9813	54953	384	республика Мордовия, Кочкуровский район, село Красномайский, Центральная, 16А	f	small
9806	54948	379	республика Мордовия, Кочкуровский район, село Кочкурово, Ленинская, 8	f	large
9573	54729	156	республика Мордовия, Кочкуровский район, село Кочкурово, Ленина, 37	f	medium
9810	54951	382	республика Мордовия, Кочкуровский район, село Качелай, Нагорная, 1А	f	small
10198	55287	763	республика Мордовия, Кочкуровский район, село Горяйновка, Орлова, 5г	f	medium
9809	54950	381	республика Мордовия, Кочкуровский район, село Воеводское, Советская, 17	f	small
9808	54949	380	республика Мордовия, Кочкуровский район, село Булгаково, Корнишина, 19	f	medium
9754	95120	327	республика Мордовия, Ковылкинский район, село Янгужинский Майдан, Советская, 20	f	large
9750	54903	326	республика Мордовия, Ковылкинский район, село Шадым, Центральная, 64	f	small
9779	50532	345	республика Мордовия, Ковылкинский район, село Чепурновка, Центральная, 31	f	small
9762	54912	334	республика Мордовия, Ковылкинский район, село Унуевский Майдан, Верхняя, 22	f	small
65977	95127	349	республика Мордовия, Ковылкинский район, село Троицк, Молодежная, 11	f	small
9761	95124	333	республика Мордовия, Ковылкинский район, село Токмово, Новая, 14	f	small
86021	54913	335	республика Мордовия, Ковылкинский район, село Старое Пшеново, Школьная, 18	f	small
9752	95121	329	республика Мордовия, Ковылкинский район, село Старое Дракино, Школьная, 11	f	small
9791	95129	352	республика Мордовия, Ковылкинский район, село Старое Аллагулово, Центральная, 16	f	small
9792	54923	353	республика Мордовия, Ковылкинский район, село Старая Самаевка, Сире веле, 36	f	medium
9805	95101	362	республика Мордовия, Ковылкинский район, село Силикатный, Горького, 15	f	small
9798	54928	357	республика Мордовия, Ковылкинский район, село Самозлейка, Центральная, 5	f	large
9776	50303	343	республика Мордовия, Ковылкинский район, село Самаевка, Советская, 2	f	small
65978	54925	355	республика Мордовия, Ковылкинский район, село Рыбкино, Советская, 5	f	small
9793	54924	354	республика Мордовия, Ковылкинский район, село Рыбкино, Мокшанская, 3	f	large
86023	95130	364	республика Мордовия, Ковылкинский район, село Русская Лашма, Школьная, 18	f	small
9763	54916	338	республика Мордовия, Ковылкинский район, Примокшанский, Песчаная, 7	f	medium
9804	95100	361	республика Мордовия, Ковылкинский район, село Польцо, Молодежная, 24	f	medium
9780	50587	346	республика Мордовия, Ковылкинский район, село Покровск, Советская, 56	f	small
9767	54915	337	республика Мордовия, Ковылкинский район, село Первомайский, Приовражная, 21	f	small
9765	54888	339	республика Мордовия, Ковылкинский район, село Парапино, Совесткая, 22	f	small
9775	54899	342	республика Мордовия, Ковылкинский район, село Паньжа, Центральная, 104А	f	small
9720	54872	299	республика Мордовия, Ковылкинский район, село Октябрьский, Школьная, 1	f	small
65975	54909	332	республика Мордовия, Ковылкинский район, село Новое Пшенево, Советская, 1А	f	small
65979	54929	358	республика Мордовия, Ковылкинский район, село Новая Самаевка, Центральная, 59	f	small
9773	54898	341	республика Мордовия, Ковылкинский район, село Мордовское Вечкино, Советская, 2А	f	small
9757	95122	330	республика Мордовия, Ковылкинский район, село Мордов Коломасово, Молодежная, 8	f	small
9790	95128	351	республика Мордовия, Ковылкинский район, село Михайловское, Школьная, 42	f	small
9796	54927	356	республика Мордовия, Ковылкинский район, село Мамолаево, Советская, 2	f	medium
65982	54934	365	республика Мордовия, Ковылкинский район, село Курнино, Гагарина, 2А	f	medium
9749	54902	325	республика Мордовия, Ковылкинский район, село Красный Шадым, Советская, 30	f	small
9766	95125	336	республика Мордовия, Ковылкинский район, село Красная Пресня, Победы, 12	f	medium
9758	95123	331	республика Мордовия, Ковылкинский район, село Кочелаево, Ленина, 2А	f	small
9777	95098	344	республика Мордовия, Ковылкинский район, село Клиновка, Центральная, 40	f	small
9755	54905	328	республика Мордовия, Ковылкинский район, село Казенный Майдан, Центральная, 7	f	small
65976	95126	347	республика Мордовия, Ковылкинский район, село Изосимовка, Центральная, 3	f	small
86022	54918	348	республика Мордовия, Ковылкинский район, село Ежовка, Старая, 70	f	small
9771	51138	363	республика Мордовия, Ковылкинский район, село Гумны, Школная, 16	f	small
9800	54930	359	республика Мордовия, Ковылкинский район, село Волгапино, Советская, 1	f	large
9772	54889	340	республика Мордовия, Ковылкинский район, село Васильевка, Школьная, 1	f	small
9786	54920	350	республика Мордовия, Ковылкинский район, село Большой Азясь, Молодежная, 35	f	small
9002	54176	150	республика Марий Эл, Волжск, Юбилейная, 10	f	large
9747	95119	324	республика Мордовия, Ковылкинский район, село Алькино, Школьная, 51	f	small
9685	95117	267	республика Мордовия, Кадошкинский район, село Ямщина, Молодежная, 8-А	f	small
9746	54900	323	республика Мордовия, Кадошкинский район, село Сиалеевский Майдан, Нижняя, 9	f	small
9744	54896	321	республика Мордовия, Кадошкинский район, село Пушкино, Московская, 2	f	small
9742	54894	319	республика Мордовия, Кадошкинский район, село Паево, Школьная, 22	f	small
9743	54895	320	республика Мордовия, Кадошкинский район, село Нагаево, Школьная, 67	f	small
9736	54890	315	республика Мордовия, Кадошкинский район, село Латышевка, Молодежная, 12	f	small
9735	54887	314	республика Мордовия, Кадошкинский район, поселок Кадошкино, Светотехническая, 6 А	f	large
9734	54886	313	республика Мордовия, Кадошкинский район, поселок Кадошкино, Крупской, 14А	f	large
9733	54885	312	республика Мордовия, Кадошкинский район, поселок Кадошкино, Заводская, 35	f	medium
9745	54897	322	республика Мордовия, Кадошкинский район, поселок Инсар, Советская, 31А	f	small
9741	54893	318	республика Мордовия, Кадошкинский район, село Глушково, А. Корнеева, 2	f	small
9740	54892	317	республика Мордовия, Кадошкинский район, село Большая Поляна, Школьная, 1А	f	medium
9738	54891	316	республика Мордовия, Кадошкинский район, село Адашево, Пролетарская, 1	f	small
9717	54869	296	республика Мордовия, Ичалковский район, село Ульянка, Гагарина, 1	f	small
9714	54866	293	республика Мордовия, Ичалковский район, село Троицкий, Колхозная, 1	f	small
9730	54882	309	республика Мордовия, Ичалковский район, село Тарханово	f	small
9702	54855	281	республика Мордовия, Ичалковский район, село Смольный, Школьная, 1	f	medium
65968	54856	282	республика Мордовия, Ичалковский район, село Смольный, Мира, 2	f	medium
9703	54857	283	республика Мордовия, Ичалковский район, село Смольный, Алатырская, 6	f	small
9729	95118	308	республика Мордовия, Ичалковский район, село Селищи, Центральная, 36-б	f	small
9709	54862	288	республика Мордовия, Ичалковский район, село Рождествено, Первомайская, 6	f	medium
9710	54863	289	республика Мордовия, Ичалковский район, село Рождествено, Кулакова, 44	f	small
9724	54876	303	республика Мордовия, Ичалковский район, село Резоватово, Советская, 18	f	small
9707	54860	286	республика Мордовия, Ичалковский район, село Пермеево, Садовая, 13	f	small
9722	54874	301	республика Мордовия, Ичалковский район, село Парадеево, Колхозная, 2	f	small
9728	54880	307	республика Мордовия, Ичалковский район, село Папулево, Красная, 1 А	f	small
9712	54864	291	республика Мордовия, Ичалковский район, село Оброчное, Мира, 28	f	medium
9716	54868	295	республика Мордовия, Ичалковский район, село Оброчное, Ленина, 106	f	small
9713	54865	292	республика Мордовия, Ичалковский район, село Новые Ичалки, Нагорная, 8	f	small
9705	54859	285	республика Мордовия, Ичалковский район, село Лобаски, Молодежная, 15	f	small
9718	54870	297	республика Мордовия, Ичалковский район, село Лада, Базарная, 25	f	small
9689	54848	271	республика Мордовия, Ичалковский район, село Кергуды, А. Егорова, 5	f	small
9688	54847	270	республика Мордовия, Ичалковский район, село Кендя, Кооперативная, 6 Б	f	small
9690	54849	272	республика Мордовия, Ичалковский район, Кемля, Советская, 207	f	medium
9693	54812	274	республика Мордовия, Ичалковский район, Кемля, Советская, 68	f	medium
9696	54851	277	республика Мордовия, Ичалковский район, Кемля, Кооперативный пер, 2	f	small
9691	54850	273	республика Мордовия, Ичалковский район, Кемля, Советская, 143	f	small
9694	54836	275	республика Мордовия, Ичалковский район, Кемля, Советская, 66	f	medium
9695	54837	276	республика Мордовия, Ичалковский район, Кемля, Больничный пер, 10	f	medium
9725	54877	304	республика Мордовия, Ичалковский район, село Камаево, Шлукина, 6	f	small
9700	54854	280	республика Мордовия, Ичалковский район, село Ичалки, им. В.И.Чинченкова, 3	f	small
9698	54852	278	республика Мордовия, Ичалковский район, село Ичалки, Школьная, 2 А	f	medium
9699	54853	279	республика Мордовия, Ичалковский район, село Ичалки, Махова, 16	f	medium
9721	54873	300	республика Мордовия, Ичалковский район, село Инсаровка, Хилковская, 1А	f	small
9732	54884	311	республика Мордовия, Ичалковский район, село Инелей, Ленинская, 37	f	small
9719	54871	298	республика Мордовия, Ичалковский район, село Дубровское, Советская, 62	f	small
9569	54725	152	республика Мордовия, Ичалковский район, село Дубенки, Московская, 98	f	medium
9687	54846	269	республика Мордовия, Ичалковский район, село Гуляево, Советская, 44	f	small
9723	54875	302	республика Мордовия, Ичалковский район, село Вечкусы, Ленинская, 3	f	small
9731	54883	310	республика Мордовия, Ичалковский район, село Ведянцы	f	small
9708	54861	287	республика Мордовия, Ичалковский район, село Большая Пестровка, Смоленская, 45	f	small
9726	54878	305	республика Мордовия, Ичалковский район, село Болдасево, Советская, 28	f	small
9727	54879	306	республика Мордовия, Ичалковский район, село Береговые Сыреси, Советская, 7 Б	f	small
9711	14685	290	республика Мордовия, Ичалковский район, село Баево, 1 Мая, 19а	f	small
9686	54845	268	республика Мордовия, Инсарский район, село Яндовище, Колхозная, 14	f	small
9684	54843	266	республика Мордовия, Инсарский район, село Языкова Пятина, Гагарина, 25	f	small
9683	54842	265	республика Мордовия, Инсарский район, село Шадым-Рыскино, Бибишева, 28	f	small
9682	54841	264	республика Мордовия, Инсарский район, село Челмодеевский Майдан, Центральная, 41	f	small
9680	54839	262	республика Мордовия, Инсарский район, село Старые Верхиссы, Центральная, 10	f	small
9679	54838	261	республика Мордовия, Инсарский район, село Сиалеевская Пятина, Советская, 50	f	small
9677	54834	259	республика Мордовия, Инсарский район, село Русская Паевка, Садовая, 16	f	small
9681	54840	263	республика Мордовия, Инсарский район, село Новые Верхисы, Большая, 28	f	small
9676	54833	258	республика Мордовия, Инсарский район, село Новлей, Московская, 62	f	small
9674	54831	256	республика Мордовия, Инсарский район, село Нижняя Вязерка, Центральная, 178 	f	small
9673	54830	255	республика Мордовия, Инсарский район, село Мордовская Паевка, Центральная,, 53	f	small
9672	54829	254	республика Мордовия, Инсарский район, село Лухманский Майдан, Фролова, 2	f	small
9678	54835	260	республика Мордовия, Инсарский район, село Кульмеж, Антроповых, 79	f	small
9670	54827	252	республика Мордовия, Инсарский район, село Кочетовка, Ленина, 56	f	small
9675	54832	257	республика Мордовия, Инсарский район, село Казеевка, Новая Казеевка, 64	f	small
9663	54820	245	республика Мордовия, Инсарский район, Инсар, Советская, 55	f	large
9662	54819	244	республика Мордовия, Инсарский район, Инсар, Советская, 22а	f	large
9665	54822	247	республика Мордовия, Инсарский район, Инсар, Гагарина, 28а	f	large
9545	53433	130	республика Мордовия, Инсарский район, село Горки, Энгельса, 15	f	small
9669	54826	251	республика Мордовия, Инсарский район, село Верхняя Лухма, Московская, 42	f	small
9671	54828	253	республика Мордовия, Инсарский район, село Арбузовка, Ленина, 67а	f	small
9616	54771	198	республика Мордовия, Зубово-Полянский район, село Ясная Поляна, Школьная, 8	f	small
9656	54813	238	республика Мордовия, Зубово-Полянский район, Явас, Чернореченская, 1	f	medium
9658	54815	240	республика Мордовия, Зубово-Полянский район, Явас, Косарева, 30	f	large
9655	54811	237	республика Мордовия, Зубово-Полянский район, Явас, Косарева, 28	f	large
9657	54814	239	республика Мордовия, Зубово-Полянский район, Явас, Дзержинского, 39	f	large
9617	54772	199	республика Мордовия, Зубово-Полянский район, село Школа Тракторных Бригадиров, Садовая, 2	f	small
9654	54810	236	республика Мордовия, Зубово-Полянский район, поселок Ширингуши, Новая, 19	f	large
9652	54807	234	республика Мордовия, Зубово-Полянский район, Умет, Школьная, 20	f	small
65974	54809	235	республика Мордовия, Зубово-Полянский район, Умет, Озерная, 7А	f	large
9634	54789	216	республика Мордовия, Зубово-Полянский район, село Ударный, Молодежная, 2	f	medium
9651	54806	233	республика Мордовия, Зубово-Полянский район, село Уголок, Школьная, 2	f	small
9650	54805	232	республика Мордовия, Зубово-Полянский район, село Тарханская Потьма, Ленина, 128	f	medium
9649	54804	231	республика Мордовия, Зубово-Полянский район, село Студенец, Центральная, 34	f	small
9648	54803	230	республика Мордовия, Зубово-Полянский район, село Старое Бадиково, Центральная, 2	f	small
9646	54801	228	республика Мордовия, Зубово-Полянский район, село Сосновка, Почтовая, 5	f	medium
9645	54790	227	республика Мордовия, Зубово-Полянский район, село Свеженькая, Школьная, 6	f	small
9624	54779	206	республика Мордовия, Зубово-Полянский район, село Русский Лундан, Садовая, 2А	f	small
9644	54800	226	республика Мордовия, Зубово-Полянский район, Потьма, Школьная, 19 А	f	large
9643	54799	225	республика Мордовия, Зубово-Полянский район, Потьма, Пионерская, 20	f	medium
9630	54784	211	республика Мордовия, Зубово-Полянский район, село Покровские Селищи, Монастырская, 164	f	small
9642	54798	224	республика Мордовия, Зубово-Полянский район, село Подлясово, Центральная, 37/1	f	small
9641	54797	223	республика Мордовия, Зубово-Полянский район, село Пичпанда, Советская, 33	f	small
9661	54818	243	республика Мордовия, Зубово-Полянский район, село Парца, Школьная, 2 А	f	medium
9660	54817	242	республика Мордовия, Зубово-Полянский район, село Озерный, Центральная, 14 Б	f	medium
9638	54794	220	республика Мордовия, Зубово-Полянский район, село Новые Выселки, Школьная, 137А	f	medium
9637	54793	219	республика Мордовия, Зубово-Полянский район, село Новое Бадиково, Советская, 1	f	small
9640	54796	222	республика Мордовия, Зубово-Полянский район, село Новая Потьма, Советская, 43	f	medium
9635	54791	217	республика Мордовия, Зубово-Полянский район, село Мордовский Пимбур, Центральная, 10	f	small
9636	54792	218	республика Мордовия, Зубово-Полянский район, село Мордовская Поляна, Степная, 44ё	f	medium
9647	54802	229	республика Мордовия, Зубово-Полянский район, село Молочница, Новая, 1А	f	small
9659	54816	241	республика Мордовия, Зубово-Полянский район, село Лесной, Лесная, 11	f	small
9633	54788	215	республика Мордовия, Зубово-Полянский район, село Леплей, Садовая, 28	f	medium
9632	54787	214	республика Мордовия, Зубово-Полянский район, село Каргашино, Сураевой, 8	f	small
9629	54785	212	республика Мордовия, Зубово-Полянский район, село Каргал, Школьная, 27	f	small
9631	54786	213	республика Мордовия, Зубово-Полянский район, село Известь, Свердлова, 18	f	small
9612	54767	194	республика Мордовия, Зубово-Полянский район, поселок Зубова Поляна, Советская, 50 В	f	large
9613	54768	195	республика Мордовия, Зубово-Полянский район, поселок Зубова Поляна, Олега Кошевого, 24	f	large
9611	54766	193	республика Мордовия, Зубово-Полянский район, поселок Зубова Поляна, Новикова-Прибоя, 23	f	large
9614	54769	196	республика Мордовия, Зубово-Полянский район, поселок Зубова Поляна, Ленинская, 7 А	f	large
9615	54770	197	республика Мордовия, Зубово-Полянский район, поселок Зубова Поляна, Новикова-Прибоя, 19	f	medium
9628	54783	210	республика Мордовия, Зубово-Полянский район, село Зарубкино, Балашова, 6	f	small
9627	54782	209	республика Мордовия, Зубово-Полянский район, село Журавкино, Заречная, 82	f	medium
9626	54781	208	республика Мордовия, Зубово-Полянский район, село Жуковка, Школьная, 22	f	small
9625	54780	207	республика Мордовия, Зубово-Полянский район, село Дубитель, Пионерская, 23	f	medium
9623	54743	205	республика Мордовия, Зубово-Полянский район, село Горенка, Школьная, 11	f	small
9621	95116	203	республика Мордовия, Зубово-Полянский район, поселок Выша, Школьная, 1	f	small
9622	54777	204	республика Мордовия, Зубово-Полянский район, село Вадовские Селищи, Молодежная, 6	f	small
9620	54775	202	республика Мордовия, Зубово-Полянский район, село Булдыгино, Центральная, 59	f	small
9619	54774	201	республика Мордовия, Зубово-Полянский район, село Ачадово, Молодежная, 36	f	medium
9618	95115	200	республика Мордовия, Зубово-Полянский район, село Анаево	f	small
9639	54795	221	республика Мордовия, Зубово-Полянский район, село Аким-Сергеевка, Алтухова, 93	f	small
9587	54742	170	республика Мордовия, Ельниковский район, село Старые Пичингуши, Безбородова, 8	f	small
9610	54765	192	республика Мордовия, Ельниковский район, село Старотештелимские Выселки, Школьная, 1	f	small
9601	54756	183	республика Мордовия, Ельниковский район, село Стародевичье, Ленинская, 8	f	medium
9603	54758	185	республика Мордовия, Ельниковский район, село Софьино, Советская, 47	f	small
9579	54735	162	республика Мордовия, Ельниковский район, село Петровка, Школьная, 3А	f	small
9596	54751	178	республика Мордовия, Ельниковский район, село Новый Ковыляй, Колхозная, 3	f	small
9502	54144	87	республика Мордовия, Атяшевский район, село Тазнеево, Ленина, 1а	f	small
9600	54755	182	республика Мордовия, Ельниковский район, село Новые Пичингуши, Колхозная, 78	f	small
9595	54750	177	республика Мордовия, Ельниковский район, Новоямская Слобода, Центральная, 168	f	small
9608	54763	190	республика Мордовия, Ельниковский район, село Новоусадские Выселки, Луговая, 11	f	small
9602	54757	184	республика Мордовия, Ельниковский район, село Новоникольское, Пролетарская, 7	f	small
9609	54764	191	республика Мордовия, Ельниковский район, село Новодевичье, Центральная, 98	f	small
9604	54759	186	республика Мордовия, Ельниковский район, село Надеждино, М.Ларина, 48	f	small
9597	54752	179	республика Мордовия, Ельниковский район, село Мордовское Корино, Центральная, 38	f	small
9607	54762	189	республика Мордовия, Ельниковский район, село Мордовско-Маскинские Выселки, Маскинская, 81	f	small
9606	54761	188	республика Мордовия, Ельниковский район, село Каньгуши, Ленина, 10А	f	small
9591	54746	173	республика Мордовия, Ельниковский район, село Ельники, площадь 1 Мая, 6	f	large
9592	54747	174	республика Мордовия, Ельниковский район, село Ельники, Садовая, 43	f	large
9589	54744	171	республика Мордовия, Ельниковский район, село Ельники, Садовая, 2	f	large
9590	54745	172	республика Мордовия, Ельниковский район, село Ельники, Ленина, 23	f	medium
9599	54754	181	республика Мордовия, Ельниковский район, село Вачеевка, Мира, 3	f	small
9594	54749	176	республика Мордовия, Ельниковский район, село Большой Уркат, Советская, 2	f	small
9598	54753	180	республика Мордовия, Ельниковский район, село Большие Мордовские Пошаты, Школьная, 1	f	small
9605	54760	187	республика Мордовия, Ельниковский район, село Алексеевка, Центральная, 24	f	small
9593	54748	175	республика Мордовия, Ельниковский район, село Акчеево, Молодежная, 4	f	small
9586	54741	169	республика Мордовия, Дубенский район, село Чиндяново, Советская, 18	f	small
9585	54740	168	республика Мордовия, Дубенский район, село Чеберчино, Большая, 23Б	f	small
9584	54739	167	республика Мордовия, Дубенский район, село Пуркаево, Жадейкина, 1	f	medium
9582	54737	165	республика Мордовия, Дубенский район, село Поводимово, Школьная, 1	f	small
9581	54736	164	республика Мордовия, Дубенский район, село Поводимово, Школьная, 2	f	medium
9580	54736	163	республика Мордовия, Дубенский район, село Поводимово, Школьная, 2	f	medium
9576	54732	159	республика Мордовия, Дубенский район, село Неклюдово, Богдановка, 11	f	small
9577	54733	160	республика Мордовия, Дубенский район, село Морга, Московская, 30	f	small
9575	54731	158	республика Мордовия, Дубенский район, село Ломаты, Семипалаты, 1	f	small
9574	54730	157	республика Мордовия, Дубенский район, село Красино, Молодежная, 1	f	small
9572	54728	155	республика Мордовия, Дубенский район, село Кайбичево, Ленина, 85А	f	small
9566	54722	149	республика Мордовия, Дубенский район, село Дубенки, Центральная, 11	f	medium
9563	54719	146	республика Мордовия, Дубенский район, село Дубенки, Центральная, 18	f	small
9567	54723	150	республика Мордовия, Дубенский район, село Дубенки, Луговая, 5	f	medium
9568	54724	151	республика Мордовия, Дубенский район, село Дубенки, Лесная, 2	f	small
9570	54726	153	республика Мордовия, Дубенский район, село Дубенки, Куйбышева, 62	f	small
9565	54721	148	республика Мордовия, Дубенский район, село Дубенки, Денисова, 7	f	medium
9564	54720	147	республика Мордовия, Дубенский район, село Дубенки, Бровцева, 139	f	medium
9571	54727	154	республика Мордовия, Дубенский район, село Дубенки, Школьная, 1	f	small
9562	54718	145	республика Мордовия, Дубенский район, Березовское сельское поселение, Центральная, 27  	f	small
9583	54738	166	республика Мордовия, Дубенский район, село Антоновка, Лесная, 1	f	small
9557	95114	142	республика Мордовия, Большеигнатовский район, село Чукалы, Кооперативная, 34	f	small
9546	53503	131	республика Мордовия, Большеигнатовский район, село Хухорево, Центральная, 4	f	small
9558	54716	143	республика Мордовия, Большеигнатовский район, село Старые Селищи, Садовая, 14	f	small
9554	54712	139	республика Мордовия, Большеигнатовский район, село Старое Чамзино, Западная, 4А	f	small
9555	95113	140	республика Мордовия, Большеигнатовский район, село Спасское, Новая, 1	f	small
9552	53824	137	республика Мордовия, Большеигнатовский район, село Протасово, Ленина, 19	f	small
9550	53686	135	республика Мордовия, Большеигнатовский район, село Новое Качаево, Гагарина, 27	f	small
9551	53760	136	республика Мордовия, Большеигнатовский район, село Новое Баево, Советская, 34	f	small
9553	54711	138	республика Мордовия, Большеигнатовский район, село Новая Александровка, Гагарина, 32	f	small
9549	53615	134	республика Мордовия, Большеигнатовский район, село Кучкаево, Ленина, 18	f	small
9548	95107	133	республика Мордовия, Большеигнатовский район, село Красная Нива, Школьная, 2А	f	small
9495	54666	80	республика Мордовия, Большеигнатовский район, село Козловка, Советская, 67	f	small
9704	54858	284	республика Мордовия, Большеигнатовский район, село Калыша, Школьная, 4	f	small
9544	95106	129	республика Мордовия, Большеигнатовский район, село Вармазейка, Советская, 44	f	small
9543	53405	128	республика Мордовия, Большеигнатовский район, село Большое Игнатово, Советская, 28	f	large
9556	54714	141	республика Мордовия, Большеигнатовский район, село Аржадеево, Центральная, 7	f	small
9540	54708	125	республика Мордовия, Большеберезниковский район, село Шугурово, Карла Маркса, 53	f	medium
9539	54707	124	республика Мордовия, Большеберезниковский район, село Черная Промза, Центральная, 51	f	small
9538	95112	123	республика Мордовия, Большеберезниковский район, село Тазино, Ленина, 10-а	f	small
9532	54700	117	республика Мордовия, Большеберезниковский район, село Судосево, Школьная, 4	f	small
9537	95111	122	республика Мордовия, Большеберезниковский район, село Старые Найманы, О.Николаева, 68	f	small
9536	54704	121	республика Мордовия, Большеберезниковский район, село Симкино, Ленина, 13	f	small
9535	95110	120	республика Мордовия, Большеберезниковский район, село Русские Найманы, Центральная, 34	f	medium
9521	54689	106	республика Мордовия, Большеберезниковский район, Присурский, Новосельская, 21-а	f	small
9531	54699	116	республика Мордовия, Большеберезниковский район, село Починки, Октябрьская, 1	f	small
9530	54698	115	республика Мордовия, Большеберезниковский район, село Пермиси, Верхняя, 2	f	small
9533	54701	118	республика Мордовия, Большеберезниковский район, село Паракино, Московская, 26	f	small
9523	54691	108	республика Мордовия, Большеберезниковский район, село Николаевка, Центральная, 72	f	small
9578	54734	161	республика Мордовия, Большеберезниковский район, село Николаевка,  Школьная,  5	f	small
9529	54697	114	республика Мордовия, Большеберезниковский район, село Марьяновка, Гагарина, 1	f	medium
9522	54690	107	республика Мордовия, Большеберезниковский район, село Мариуполь, Советская, 152	f	small
9528	54696	113	республика Мордовия, Большеберезниковский район, село Косогоры, Ленина, 82	f	small
9527	54695	112	республика Мордовия, Большеберезниковский район, село Елизаветинка, Садовая, 2	f	small
9526	54694	111	республика Мордовия, Большеберезниковский район, село Дегилевка, Советская, 1	f	small
9525	54693	110	республика Мордовия, Большеберезниковский район, село Гузынцы, Советская, 15	f	small
9524	54692	109	республика Мордовия, Большеберезниковский район, село Гарт, Школьная, 9	f	small
9534	54702	119	республика Мордовия, Большеберезниковский район, село Бузаево, Карла Маркса, 36	f	small
9517	54686	102	республика Мордовия, Большеберезниковский район, село Большие Березники, Ленина, 72	f	large
9518	54685	103	республика Мордовия, Большеберезниковский район, село Большие Березники, Ленина, 56	f	medium
9516	54684	101	республика Мордовия, Большеберезниковский район, село Большие Березники, Карла Маркса, 19	f	large
9519	54687	104	республика Мордовия, Большеберезниковский район, село Большие Березники, Казанская, 21	f	medium
9520	54688	105	республика Мордовия, Большеберезниковский район, село Большие Березники, Дубенское шоссе, 1	f	small
9515	95109	100	республика Мордовия, Атяшевский район, село Шейн-Майдан, Лесная, 19, Птицесовхоз Сараст	f	small
9514	54682	99	республика Мордовия, Атяшевский район, село Шейн-Майдан, Комсомольская, 4а	f	small
9491	54662	76	республика Мордовия, Атяшевский район, село Чукалы-на-Вежне, Красная Слобода, 1	f	small
9499	54670	84	республика Мордовия, Атяшевский район, село Челпаново, Центральная, 5	f	small
9488	54659	73	республика Мордовия, Атяшевский район, село Тетюши, Ленина, 98	f	small
9513	54681	98	республика Мордовия, Атяшевский район, село Сосуновка, Ленина, 2а	f	small
9509	54677	94	республика Мордовия, Атяшевский район, село Селищи, Ленинская, 71	f	small
9507	54675	92	республика Мордовия, Атяшевский район, село Сабанчеево, Советская, 10	f	small
9506	54674	91	республика Мордовия, Атяшевский район, село Русские Дубровки, Советская, 4	f	small
9505	54673	90	республика Мордовия, Атяшевский район, село Покровское, Центральная, 4	f	small
9496	54667	81	республика Мордовия, Атяшевский район, село Пилесево, М.Горького, 77	f	small
9492	54663	77	республика Мордовия, Атяшевский район, село Низовка, Первомайская, 28	f	small
9504	54672	89	республика Мордовия, Атяшевский район, село Наборные Сыреси, Центральная, 1	f	small
9503	54396	88	республика Мордовия, Атяшевский район, село Мордовские Сыреси, Октябрьская, 105	f	small
9508	54676	93	республика Мордовия, Атяшевский район, село Мордовские Дубровки, Новая, 2а	f	small
9501	54097	86	республика Мордовия, Атяшевский район, село Лобаски, Пушкина, 1а	f	medium
9500	54063	85	республика Мордовия, Атяшевский район, село Капасово, Центральная, 72	f	small
10095	55209	660	республика Мордовия, Атяшевский район, село Знаменское, Центральная, 15	f	small
9494	54665	79	республика Мордовия, Атяшевский район, село Дюрки, Комсомольская, 14А	f	small
9493	54664	78	республика Мордовия, Атяшевский район, село Дюрки, Комсомольская, 50	f	small
9489	54660	74	республика Мордовия, Атяшевский район, село Вечерлей, Куйбышева, 9	f	small
9487	54658	72	республика Мордовия, Атяшевский район, село Большие Манадыши, Молодежная, 1	f	medium
9483	54655	68	республика Мордовия, Атяшевский район, село Батушево, Ленина, 76	f	medium
9490	54661	75	республика Мордовия, Атяшевский район, село Ахматово, Ленина, 95	f	small
9541	54709	126	республика Мордовия, Атяшевский район, поселок Атяшево, Центральная, 12	f	small
9479	53247	64	республика Мордовия, Атяшевский район, поселок Атяшево, Центральная, 34	f	large
65981	54653	67	республика Мордовия, Атяшевский район, поселок Атяшево, Советский переулок, 4	f	large
9480	53305	65	республика Мордовия, Атяшевский район, поселок Атяшево, Микрорайон-2, 6а	f	large
9481	54055	66	республика Мордовия, Атяшевский район, поселок Атяшево, Большевистская, 105	f	medium
9486	54657	71	республика Мордовия, Атяшевский район, село Андреевка, Ленина, 53	f	small
9485	54656	70	республика Мордовия, Атяшевский район, село Алово, Школьная, 6	f	medium
9484	54656	69	республика Мордовия, Атяшевский район, село Алово, Школьная, 6	f	medium
9510	54678	95	республика Мордовия, Атяшевский район, село Алашевка, Новая, 4	f	small
9462	54640	48	республика Мордовия, Атюрьевский район, село Шуструй, Центральная, 30	f	small
9461	54639	47	республика Мордовия, Атюрьевский район, село Чудинка, Центральная, 18а	f	small
9463	54641	49	республика Мордовия, Атюрьевский район, село Усть-Рахмановка, Центральная, 62	f	small
9476	54552	61	республика Мордовия, Атюрьевский район, село Стрельниково, Школьная, 1	f	small
9459	54637	45	республика Мордовия, Атюрьевский район, село Русская Велязьма, Мелиораторов, 8	f	small
9477	54567	62	республика Мордовия, Атюрьевский район, село Пичеполонга, Школьная, 18	f	small
9470	54647	55	республика Мордовия, Атюрьевский район, село Оброчное, Заречная, 1	f	small
9473	54650	58	республика Мордовия, Атюрьевский район, село Новочадово, Школьная, 82а	f	small
9474	54651	59	республика Мордовия, Атюрьевский район, село Новая Карьга, Новая, 6	f	small
9471	54648	56	республика Мордовия, Атюрьевский район, село Мордовская Козловка, Центральная, 45	f	small
9468	54646	54	республика Мордовия, Атюрьевский район, село Курташки, Центральная, 60а	f	small
9478	54632	63	республика Мордовия, Атюрьевский район, село Клопинка, Лесная, 54	f	small
9467	54645	53	республика Мордовия, Атюрьевский район, село Кишалы, Нижняя, 93а	f	small
9497	54668	82	республика Мордовия, Атюрьевский район, село Каменка, Молодежная, 3	f	small
9475	54652	60	республика Мордовия, Атюрьевский район, село Духонькино, Школьная, 94	f	small
9465	54643	51	республика Мордовия, Атюрьевский район, село Дмитриев Усад, Центральная, 107	f	small
9464	54642	50	республика Мордовия, Атюрьевский район, село Вольно-Никольское, Центральная, 23	f	small
9012	54186	159	республика Марий Эл, Козьмодемьянск, бульвар Космонавтов, 7	f	large
9472	54649	57	республика Мордовия, Атюрьевский район, село Барашево, Школьная, 17	f	small
9466	54644	52	республика Мордовия, Атюрьевский район, село Барашево, Молодежная,  3	f	small
9458	54636	44	республика Мордовия, Атюрьевский район, село Атюрьево, Школьная, 1	f	large
9457	54635	43	республика Мордовия, Атюрьевский район, село Атюрьево, Центральная, 8	f	large
9456	54634	42	республика Мордовия, Атюрьевский район, село Атюрьево, Ленина, 1	f	large
9460	54638	46	республика Мордовия, Атюрьевский район, село Арга, Школьная, 1	f	small
9455	54633	41	республика Мордовия, Ардатовский район, село Чукалы, Полевая, 1-А	f	medium
9454	54631	40	республика Мордовия, Ардатовский район, село Урусово, Ленина, 93	f	medium
9452	54629	38	республика Мордовия, Ардатовский район, село Турдаково, Центральная, 14	f	small
9421	54598	7	республика Мордовия, Ардатовский район, поселок Тургенево, Ленинская, 8-А	f	medium
9420	54597	6	республика Мордовия, Ардатовский район, поселок Тургенево, Ленинская, 72	f	medium
9423	54600	9	республика Мордовия, Ардатовский район, поселок Тургенево, Заводская, 38	f	large
9422	54599	8	республика Мордовия, Ардатовский район, поселок Тургенево, Заводская, 34	f	large
9451	54628	37	республика Мордовия, Ардатовский район, село Старое Ардатово, Советская, 58	f	small
9441	54618	27	республика Мордовия, Ардатовский район, село Спасские Мурзы, Набережная, 50	f	small
9450	54627	36	республика Мордовия, Ардатовский район, село Солдатское, Центральная, 50	f	small
9449	54626	35	республика Мордовия, Ардатовский район, село Силино, Садовая, 28	f	small
9447	54624	33	республика Мордовия, Ардатовский район, Редкодубье, Гагарина, 66	f	medium
9433	54610	19	республика Мордовия, Ардатовский район, село Полое, Церковная, 1-А	f	small
9446	54623	32	республика Мордовия, Ардатовский район, село Пиксяси, Молодежная, 28	f	small
9445	54622	31	республика Мордовия, Ардатовский район, село Октябрьский, Юбилейная, 13	f	medium
9444	54621	30	республика Мордовия, Ардатовский район, село Низовка, Центральная, 1	f	medium
9443	54620	29	республика Мордовия, Ардатовский район, село Манадыши 2-е, Центральная, 39	f	small
9442	54619	28	республика Мордовия, Ардатовский район, село Манадыши 1-е, Центральная, 58А	f	small
9436	54613	22	республика Мордовия, Ардатовский район, село Малое Кузьмино, Речная, 4	f	small
9440	54617	26	республика Мордовия, Ардатовский район, село Луньгинский Майдан, Карла Маркса, 22	f	small
9439	54616	25	республика Мордовия, Ардатовский район, село Луньга, Центральная, 53	f	small
9438	54615	24	республика Мордовия, Ардатовский район, село Лесозавод, Заводская, 15	f	small
9437	95108	23	республика Мордовия, Ардатовский район, село Кученяево, Полевая, 5	f	medium
9434	54611	20	республика Мордовия, Ардатовский район, село Куракино, Центральная, 73А	f	small
9431	54608	17	республика Мордовия, Ардатовский район, село Кечушево, Ларина, 1-А	f	small
9429	54606	15	республика Мордовия, Ардатовский район, село Кельвядни, Одыре, 45	f	small
9428	54605	14	республика Мордовия, Ардатовский район, село Каласево, Овражная, 18	f	small
9427	54604	13	республика Мордовия, Ардатовский район, село Жаренки, Колхозная, 16-А	f	small
9426	54603	12	республика Мордовия, Ардатовский район, село Жабино, Верхняя, 197	f	small
9435	54612	21	республика Мордовия, Ардатовский район, село Большое Кузьмино, Газовиков, 42	f	small
9448	54625	34	республика Мордовия, Ардатовский район, село Большие Поляны, Ленинская, 47	f	small
9432	54609	18	республика Мордовия, Ардатовский район, село Безводное, Центральная, 27	f	small
9425	54602	11	республика Мордовия, Ардатовский район, село Баево, Советская, 7-б	f	large
9424	54601	10	республика Мордовия, Ардатовский район, село Ардатов, Центральная, 9	f	medium
9416	54593	2	республика Мордовия, Ардатовский район, Ардатов, Полевая, 49	f	large
9417	54594	3	республика Мордовия, Ардатовский район, Ардатов, Луначарского, 10	f	large
9418	54595	4	республика Мордовия, Ардатовский район, Ардатов, Л.Толстого, 2/2	f	large
9415	54592	1	республика Мордовия, Ардатовский район, Ардатов, Карла Маркса, 138	f	large
9542	54440	127	республика Мордовия, Ардатовский район, село Андреевка, Первомайская, 89	f	medium
9430	54607	16	республика Мордовия, Ардатовский район, село Андреевка, Колхозная, 1	f	small
9011	54185	158	республика Марий Эл, Козьмодемьянск, бульвар Космонавтов, 2	f	large
9013	54187	160	республика Марий Эл, Козьмодемьянск, Юбилейная, 11-А	f	small
9015	54189	162	республика Марий Эл, Козьмодемьянск, Чернышевского, 37	f	medium
9018	54192	165	республика Марий Эл, Козьмодемьянск, Советская, 35	f	large
9020	54194	167	республика Марий Эл, Козьмодемьянск, Свободы, 1-А	f	large
9016	54190	163	республика Марий Эл, Козьмодемьянск, Свердлова, 15	f	small
9019	54193	166	республика Марий Эл, Козьмодемьянск, Промышленная, 52	f	large
9014	54188	161	республика Марий Эл, Козьмодемьянск, Комсомольская, 25	f	medium
9010	54184	157	республика Марий Эл, Козьмодемьянск, Квартал маслозавода, 2	f	large
9021	54195	168	республика Марий Эл, Козьмодемьянск, Гагарина, 56В	f	medium
9017	54191	164	республика Марий Эл, Козьмодемьянск, 8 Марта, 15	f	large
9006	54181	170	республика Марий Эл, Козьмодемьянск, 3-ий микрорайон, 1	f	large
9005	54181	153	республика Марий Эл, Козьмодемьянск, 3-ий микрорайон, 1	f	large
9009	54183	156	республика Марий Эл, Козьмодемьянск, 2-ой микрорайон, 5	f	large
9008	54182	155	республика Марий Эл, Козьмодемьянск, 2-ой микрорайон, 28	f	large
9007	54182	154	республика Марий Эл, Козьмодемьянск, 2-ой микрорайон, 28	f	large
8934	54126	82	Россия, республика Марий Эл, Йошкар-Ола	f	large
8869	54072	16	республика Марий Эл, Йошкар-Ола, проспект Гагарина, 8	f	large
8854	54056	1	республика Марий Эл, Йошкар-Ола, площадь Ленина, 3	f	large
8874	54077	21	республика Марий Эл, Йошкар-Ола, переулок Голикова, 4А	f	large
8873	54076	20	республика Марий Эл, Йошкар-Ола, пер.Голикова, 4А	f	large
8875	54078	22	республика Марий Эл, Йошкар-Ола, бульвар Эшкинина, 18	f	large
8889	54087	36	республика Марий Эл, Йошкар-Ола, бульвар Чавайна, 11	f	large
8926	54118	74	республика Марий Эл, Йошкар-Ола, Я.Эшпая, 103	f	large
8920	54112	68	республика Марий Эл, Йошкар-Ола, Я.Эшпая, 156	f	large
8949	54136	97	республика Марий Эл, Йошкар-Ола, Школьная, 19	f	large
8868	54071	15	республика Марий Эл, Йошкар-Ола, Успенская, 15А	f	large
8971	54150	119	республика Марий Эл, Йошкар-Ола, Строителей, 62	f	medium
8964	54145	112	республика Марий Эл, Йошкар-Ола, Строителей, 25	f	large
8960	54142	108	республика Марий Эл, Йошкар-Ола, Строителей, 13А	f	large
8959	54142	107	республика Марий Эл, Йошкар-Ола, Строителей, 13А	f	large
8878	54079	25	республика Марий Эл, Йошкар-Ола, Сомбатхей, 22	f	large
8877	54079	24	республика Марий Эл, Йошкар-Ола, Сомбатхей, 22	f	large
8876	54079	23	республика Марий Эл, Йошкар-Ола, Сомбатхей, 22	f	large
8972	54151	120	республика Марий Эл, Йошкар-Ола, Соловьева, 39	f	large
8872	54075	19	республика Марий Эл, Йошкар-Ола, Соловьева, 3	f	large
8867	54070	14	республика Марий Эл, Йошкар-Ола, Советская, 20А	f	large
8856	54058	3	республика Марий Эл, Йошкар-Ола, Советская, 158	f	large
8855	54057	2	республика Марий Эл, Йошкар-Ола, Пушкина, 27	f	medium
8969	54148	117	республика Марий Эл, Йошкар-Ола, Прохорова, 30	f	large
8967	54147	115	республика Марий Эл, Йошкар-Ола, Прохорова, 31	f	large
8966	54147	114	республика Марий Эл, Йошкар-Ола, Прохорова, 31	f	large
8968	54146	116	республика Марий Эл, Йошкар-Ола, Прохорова, 28	f	large
8965	54146	113	республика Марий Эл, Йошкар-Ола, Прохорова, 28	f	large
8929	54120	77	республика Марий Эл, Йошкар-Ола, Пролетарская, 68	f	large
8946	54133	94	республика Марий Эл, Йошкар-Ола, Подольских курсантов, 8Б	f	large
8945	54133	93	республика Марий Эл, Йошкар-Ола, Подольских курсантов, 8Б	f	large
8885	54084	32	республика Марий Эл, Йошкар-Ола, Петрова, 16	f	large
8884	54084	31	республика Марий Эл, Йошкар-Ола, Петрова, 16	f	large
8886	54080	33	республика Марий Эл, Йошкар-Ола, Петрова, 15	f	large
8880	54080	27	республика Марий Эл, Йошкар-Ола, Петрова, 15	f	large
8879	54080	26	республика Марий Эл, Йошкар-Ола, Петрова, 15	f	large
8922	54114	70	республика Марий Эл, Йошкар-Ола, Первомайская, 109	f	large
8927	54064	75	республика Марий Эл, Йошкар-Ола, Первомайская, 89	f	large
8861	54064	8	республика Марий Эл, Йошкар-Ола, Первомайская, 89	f	large
8871	54074	18	республика Марий Эл, Йошкар-Ола, Панфилова, 17	f	large
8870	54073	17	республика Марий Эл, Йошкар-Ола, Панфилова, 17	f	large
8923	54115	71	республика Марий Эл, Йошкар-Ола, Осипенко, 60	f	large
8865	54068	12	республика Марий Эл, Йошкар-Ола, Орая, 51А	f	large
8970	54149	118	республика Марий Эл, Йошкар-Ола, Машиностроителей, 44А	f	large
8944	54132	92	республика Марий Эл, Йошкар-Ола, Машиностроителей, 6Б	f	large
8939	54129	87	республика Марий Эл, Йошкар-Ола, Машиностроителей, 22А	f	large
8938	54129	86	республика Марий Эл, Йошкар-Ола, Машиностроителей, 22А	f	large
8918	54110	66	республика Марий Эл, Йошкар-Ола, Лобачевского, 1	f	large
8917	54109	65	республика Марий Эл, Йошкар-Ола, Лобачевского, 12	f	large
8937	54111	85	республика Марий Эл, Йошкар-Ола, Ленинский проспект, 54	f	large
8919	54111	67	республика Марий Эл, Йошкар-Ола, Ленинский проспект, 54	f	large
8891	54086	38	республика Марий Эл, Йошкар-Ола, Ленинский проспект, 10А	f	large
8890	54086	37	республика Марий Эл, Йошкар-Ола, Ленинский проспект, 10А	f	large
8888	54086	35	республика Марий Эл, Йошкар-Ола, Ленинский проспект, 10А	f	large
8973	54152	121	республика Марий Эл, Йошкар-Ола, Крылова, 47	f	medium
8925	54117	73	республика Марий Эл, Йошкар-Ола, Кремлевская, 44	f	large
8924	54116	72	республика Марий Эл, Йошкар-Ола, Кремлевская, 32	f	large
8860	54062	7	республика Марий Эл, Йошкар-Ола, Кремлевская, 22	f	large
8858	54060	5	республика Марий Эл, Йошкар-Ола, Кремлевская, 4	f	large
8962	54143	110	республика Марий Эл, Йошкар-Ола, Краснофлотская, 15	f	large
8963	54143	111	республика Марий Эл, Йошкар-Ола, Краснофлотская, 15	f	large
8936	54128	84	республика Марий Эл, Йошкар-Ола, Красноармейская, 71	f	large
8935	54127	83	республика Марий Эл, Йошкар-Ола, Красноармейская, 78	f	large
8862	54065	9	республика Марий Эл, Йошкар-Ола, Красноармейская, 41	f	large
8857	54059	4	республика Марий Эл, Йошкар-Ола, Комсомольская, 157	f	large
8908	54099	55	республика Марий Эл, Йошкар-Ола, Кирпичная, 58	f	small
8907	54098	54	республика Марий Эл, Йошкар-Ола, Кирпичная, 2А	f	large
8906	54098	53	республика Марий Эл, Йошкар-Ола, Кирпичная, 2А	f	large
8892	54088	39	республика Марий Эл, Йошкар-Ола, К.Либкнехта, 54	f	large
8956	54140	104	республика Марий Эл, Йошкар-Ола, Йывана Кырли, 19Б	f	large
8954	54140	102	республика Марий Эл, Йошкар-Ола, Йывана Кырли, 19Б	f	large
8955	54140	103	республика Марий Эл, Йошкар-Ола, Йывана Кырли, 19Б	f	large
8910	54101	57	республика Марий Эл, Йошкар-Ола, Интернатская, 7	f	large
8953	54139	101	республика Марий Эл, Йошкар-Ола, Зеленая, 1	f	large
8957	54139	105	республика Марий Эл, Йошкар-Ола, Зеленая, 1	f	large
8909	54100	56	республика Марий Эл, Йошкар-Ола, Звездная, 12А	f	large
8916	54108	64	республика Марий Эл, Йошкар-Ола, Зарубина, 22	f	large
8950	54137	98	республика Марий Эл, Йошкар-Ола, Дружбы, 2	f	large
8948	54135	96	республика Марий Эл, Йошкар-Ола, Дружбы, 93	f	large
8951	54138	99	республика Марий Эл, Йошкар-Ола, Димитрова, 57	f	large
8952	54138	100	республика Марий Эл, Йошкар-Ола, Димитрова, 57	f	large
8904	54096	51	республика Марий Эл, Йошкар-Ола, Героев Сталинградской Битвы, 35	f	large
8905	54096	52	республика Марий Эл, Йошкар-Ола, Героев Сталинградской Битвы, 35	f	large
8863	54066	10	республика Марий Эл, Йошкар-Ола, Волкова, 110	f	large
8887	54085	34	республика Марий Эл, Йошкар-Ола, Воинов-Интернационалистов, 25	f	large
8883	54083	30	республика Марий Эл, Йошкар-Ола, Воинов-Интернационалистов, 22	f	large
8882	54082	29	республика Марий Эл, Йошкар-Ола, Воинов-Интернационалистов, 22	f	large
8881	54081	28	республика Марий Эл, Йошкар-Ола, Воинов-Интернационалистов, 28	f	large
8928	54119	76	республика Марий Эл, Йошкар-Ола, Водопроводная, 85	f	large
8866	54069	13	республика Марий Эл, Йошкар-Ола, Водопроводная, 41	f	large
8961	54141	109	республика Марий Эл, Йошкар-Ола, Баумана, 20	f	large
8958	54141	106	республика Марий Эл, Йошкар-Ола, Баумана, 20	f	large
8947	54134	95	республика Марий Эл, Йошкар-Ола, Анциферова, 2А	f	large
8943	54131	91	республика Марий Эл, Йошкар-Ола, Анциферова, 9	f	large
8942	54131	90	республика Марий Эл, Йошкар-Ола, Анциферова, 9	f	large
8941	54130	89	республика Марий Эл, Йошкар-Ола, Анциферова, 29	f	large
8940	54130	88	республика Марий Эл, Йошкар-Ола, Анциферова, 29	f	large
8896	54091	43	республика Марий Эл, Йошкар-Ола, 8 Марта, 19	f	large
8895	54091	42	республика Марий Эл, Йошкар-Ола, 8 Марта, 19	f	large
9098	54264	244	республика Марий Эл, Звенигово, Школьная, 109	f	large
9097	54264	243	республика Марий Эл, Звенигово, Школьная, 109	f	large
8998	54176	146	республика Марий Эл, Волжск, Юбилейная, 10	f	large
8977	54156	125	республика Марий Эл, Волжск, Щорса, 16	f	large
8991	54170	139	республика Марий Эл, Волжск, Щербакова, 4	f	large
8994	54172	142	республика Марий Эл, Волжск, Шестакова, 44	f	large
8990	54169	138	республика Марий Эл, Волжск, Шестакова, 8	f	large
8987	54166	135	республика Марий Эл, Волжск, Учительская, 4	f	large
8978	54157	126	республика Марий Эл, Волжск, Советская, 29 а	f	large
8995	54173	143	республика Марий Эл, Волжск, Прохорова, 120 а	f	large
8999	54177	147	республика Марий Эл, Волжск, Помарское шоссе, 1	f	medium
8993	54171	141	республика Марий Эл, Волжск, Маяковского, 9	f	large
8992	54171	140	республика Марий Эл, Волжск, Маяковского, 9	f	medium
8996	54174	144	республика Марий Эл, Волжск, Либкнехта, 128	f	large
8985	54164	133	республика Марий Эл, Волжск, Ленина, 64	f	large
8983	54162	131	республика Марий Эл, Волжск, Ленина, 39	f	medium
8981	54160	129	республика Марий Эл, Волжск, Ленина, 33	f	large
8980	54159	128	республика Марий Эл, Волжск, Ленина, 34	f	medium
8979	54158	127	республика Марий Эл, Волжск, Ленина, 37	f	large
8975	54154	123	республика Марий Эл, Волжск, Кошкина, 10	f	large
8976	54155	124	республика Марий Эл, Волжск, Коммунистическая, 1 а	f	large
8988	54167	136	республика Марий Эл, Волжск, Комарова, 24	f	large
8984	54163	132	республика Марий Эл, Волжск, Кирова, 5	f	large
8989	54168	137	республика Марий Эл, Волжск, Дружбы, 2 б	f	large
8986	54165	134	республика Марий Эл, Волжск, Дружбы, 16 а	f	large
8982	54161	130	республика Марий Эл, Волжск, Гагарина, 40	f	large
8997	54175	145	республика Марий Эл, Волжск, Гаврилова, 7	f	large
9001	54178	149	республика Марий Эл, Волжск, 107 бригады, 5	f	large
9000	54178	148	республика Марий Эл, Волжск, 107 бригады, 5	f	large
9413	54571	551	республика Марий Эл, Юринский район, село Юркино, Юркинская, 14	f	small
9414	54572	552	республика Марий Эл, Юринский район, село Юркино, Новая Стройка, 30	f	small
9404	54561	542	республика Марий Эл, Юринский район, поселок Юрино, переулок Володарского, 24а	f	large
9403	54560	541	республика Марий Эл, Юринский район, поселок Юрино, Центральный проспект, 5а	f	large
9402	54559	540	республика Марий Эл, Юринский район, поселок Юрино, Советская, 30	f	medium
9406	54563	544	республика Марий Эл, Юринский район, село Суходол, Лесная, 23	t	small
9409	54566	547	республика Марий Эл, Юринский район, село Починок, Починок, 76	t	small
9411	54569	549	республика Марий Эл, Юринский район, село Марьино, Школьная, 12	f	medium
9412	54570	550	республика Марий Эл, Юринский район, село Красная Люнда, Школьная, 6	t	small
9410	54568	548	республика Марий Эл, Юринский район, село Козиково, Железнодорожная, 3	f	small
9408	54565	546	республика Марий Эл, Юринский район, село Горный Шимец, Горный Шимец, 110	t	medium
9407	54564	545	республика Марий Эл, Юринский район, село Васильевское, Школьная, 259	f	small
9405	54562	543	республика Марий Эл, Юринский район, село Быковка, Центральная, 157	f	medium
9401	54558	539	республика Марий Эл, Советский район, пос. Голубой, Мира, 8	f	small
9393	54551	533	республика Марий Эл, Советский район, село Шуарсола, Речная, 120	f	medium
9398	54555	536	республика Марий Эл, Советский район, село Чкарино, Центральная, 5	f	small
9383	54541	523	республика Марий Эл, Советский район, село Ургакш, Новая, 2	f	medium
9391	54549	531	республика Марий Эл, Советский район, село Средний Кадам, Молодежная, 38	f	medium
9400	54557	538	республика Марий Эл, Советский район, поселок Солнечный, Солнечная, 1	f	large
9379	54538	520	республика Марий Эл, Советский район, поселок Советский, Свободы, 15	f	large
9381	54540	522	республика Марий Эл, Советский район, поселок Советский, Пушкина, 32А	f	large
9380	54539	521	республика Марий Эл, Советский район, поселок Советский, Победы, 18 Б	f	large
9378	54537	519	республика Марий Эл, Советский район, поселок Советский, Ломоносова, 8	f	large
65956	54104	60	республика Марий Эл, Советский район, село Семеновка, Советская, 9	f	small
8912	54103	59	республика Марий Эл, Советский район, село Семеновка, Советская, 9	f	large
9395	54554	535	республика Марий Эл, Советский район, село Ронга, Центральная, 2	f	large
9388	54546	528	республика Марий Эл, Советский район, село Орша, Советская, 28	f	medium
502	19777	240	республика Башкортостан, Уфа, Шафиева, 31/2	f	large
9394	54553	534	республика Марий Эл, Советский район, село Михайловка, Зеленая, 4	f	large
9386	54544	526	республика Марий Эл, Советский район, село Кукмарь, Нижняя, 5	f	medium
9390	54548	530	республика Марий Эл, Советский район, село Кужмара, Центральная, 3	f	medium
9389	54547	529	республика Марий Эл, Советский район, село Колянур, м-н Светлый, 1 0А	t	small
9392	54550	532	республика Марий Эл, Советский район, село Кельмаксола, Ермакова, 22	f	medium
9387	54545	527	республика Марий Эл, Советский район, село Вятское, Дружбы, 3	f	large
9385	54543	525	республика Марий Эл, Советский район, село Верхний Ушнур, Центральная, 10	f	medium
9399	54556	537	республика Марий Эл, Советский район, село Великополье, 43 А	t	small
9384	54542	524	республика Марий Эл, Советский район, село Алексеевский, Октябрьская, 1	f	large
9363	54522	504	республика Марий Эл, Сернурский район, село Эшполдино, Эшполдино, 4	f	small
9361	54520	502	республика Марий Эл, Сернурский район, село Читово, Читово, 87А	t	small
9373	54532	514	республика Марий Эл, Сернурский район, село Чендемерово, Колхозная, 86	f	medium
9366	54525	507	республика Марий Эл, Сернурский район, село Чашкаял, 91	t	small
9354	54513	495	республика Марий Эл, Сернурский район, село Тамшинер, Мира, 26а	t	small
9348	54507	489	республика Марий Эл, Сернурский район, поселок Сернур, Микрорайон, 16	f	large
9347	54506	488	республика Марий Эл, Сернурский район, поселок Сернур, Комсомольская, 24	f	large
9346	54505	487	республика Марий Эл, Сернурский район, поселок Сернур, Комсомольская, 2	f	large
9349	54508	490	республика Марий Эл, Сернурский район, поселок Сернур, Коммунистическая, 78	f	large
9350	54509	491	республика Марий Эл, Сернурский район, поселок Сернур, Казанская, 11	f	large
9364	54523	505	республика Марий Эл, Сернурский район, село Нижний Рушенер, Нижний Рушенер, 5	f	small
9351	54510	492	республика Марий Эл, Сернурский район, село Нижний Кугенер, Советская, 16	f	medium
9375	54534	516	республика Марий Эл, Сернурский район, село Мустаево, Центральная, 15	f	small
9369	54528	510	республика Марий Эл, Сернурский район, село Марисола, Центральная, 21	f	medium
9371	54530	512	республика Марий Эл, Сернурский район, село Мари-Кугунур, Набережная, 18	f	small
9376	54535	517	республика Марий Эл, Сернурский район, село Малый Шокшем, 41	t	small
9356	54515	497	республика Марий Эл, Сернурский район, село Лоскутово, Лоскутово, 48	f	small
9367	54526	508	республика Марий Эл, Сернурский район, село Летник, Летник, 4	f	small
9353	54512	494	республика Марий Эл, Сернурский район, село Лажьял, Молодежная, 14	f	medium
9362	54521	503	республика Марий Эл, Сернурский район, село Купсола, Купсола, 32	t	small
9374	54533	515	республика Марий Эл, Сернурский район, село Куприяново, Центральная, 2	t	small
9360	54519	501	республика Марий Эл, Сернурский район, село Кункур, Кооперативная, 5	f	medium
9368	54527	509	республика Марий Эл, Сернурский район, село Кочанур, Кочанур, 58а	f	small
9358	54517	499	республика Марий Эл, Сернурский район, село Калеево, Новая, 5	t	medium
9359	54518	500	республика Марий Эл, Сернурский район, село Казанское, Коммунальная, 5а	f	large
9370	54529	511	республика Марий Эл, Сернурский район, село Йошкар-Памаш, Йошкар-Памаш, 22	t	small
9357	54516	498	республика Марий Эл, Сернурский район, село Зашижемье, Больничная, 10	f	small
9355	54514	496	республика Марий Эл, Сернурский район, село Дубники, Дубники, 53	f	medium
9377	54536	518	республика Марий Эл, Сернурский район, село Горняк, Полевая, 4	f	small
9365	54524	506	республика Марий Эл, Сернурский район, село Большой Сердеж, Большой Сердеж, 44	f	medium
9372	54531	513	республика Марий Эл, Сернурский район, село Большие Ключи, Шабалина, 10	f	small
9352	54511	493	республика Марий Эл, Сернурский район, село Большая Мушка, Центральная, 23	t	small
9345	54504	486	республика Марий Эл, Параньгинский район, село Усола, Коммунистическая, 52	f	small
9343	54502	484	республика Марий Эл, Параньгинский район, село Русская Ляжмарь, Молодежная, 4	f	medium
9342	54501	483	республика Марий Эл, Параньгинский район, село Портянур, Колхозная, 27	f	medium
9335	54495	477	республика Марий Эл, Параньгинский район, село Помосъял, Мира, 29	t	small
9329	54490	471	республика Марий Эл, Параньгинский район, поселок Параньга, Тукаевская, 146	f	large
9330	54491	472	республика Марий Эл, Параньгинский район, поселок Параньга, Колхозная, 21	f	large
9331	54491	473	республика Марий Эл, Параньгинский район, поселок Параньга, Колхозная, 21	f	small
9328	54489	470	республика Марий Эл, Параньгинский район, поселок Параньга, Гагарина, 20	f	large
9344	54503	485	республика Марий Эл, Параньгинский район, село Олоры, Гагарина, 5	f	medium
9340	54499	481	республика Марий Эл, Параньгинский район, село Мурзанаево, Центральная, 58	t	small
9333	54493	475	республика Марий Эл, Параньгинский район, село Куянково, Советская, 42	f	small
9338	54498	480	республика Марий Эл, Параньгинский район, село Куракино, Новая, 21	f	medium
9341	54500	482	республика Марий Эл, Параньгинский район, село Ирнур, Кооперативная, 6	f	small
9337	54497	479	республика Марий Эл, Параньгинский район, село Ильпанур, Мира, 32	t	medium
9336	54496	478	республика Марий Эл, Параньгинский район, село Илеть, Заречная, 28	t	small
9334	54494	476	республика Марий Эл, Параньгинский район, село Елеево, Рабочая, 4	f	medium
9332	54492	474	республика Марий Эл, Параньгинский район, село Алашайка, Ленина, 76	f	medium
9327	54488	469	республика Марий Эл, Оршанский район, село Шулка, Микрорайон, 8	f	medium
9325	54486	467	республика Марий Эл, Оршанский район, село Чирки, Новая, 156	f	small
9324	54485	466	республика Марий Эл, Оршанский район, село Упша, Первомайская, 2а	f	small
9323	54484	465	республика Марий Эл, Оршанский район, село Табашино, Школьная, 4а	f	small
9322	54483	464	республика Марий Эл, Оршанский район, село Старое Крещено, Волкова, 13	f	medium
9326	54487	468	республика Марий Эл, Оршанский район, село Отары, Школьная, 95	f	small
9314	54476	456	республика Марий Эл, Оршанский район, поселок Оршанка, Юбилейная, 1	f	small
9313	54475	455	республика Марий Эл, Оршанский район, поселок Оршанка, Советская, 85	f	large
9312	54474	454	республика Марий Эл, Оршанский район, поселок Оршанка, Пролетарская, 9	f	small
9311	54473	453	республика Марий Эл, Оршанский район, поселок Оршанка, Гагарина, 4	f	large
9321	54468	463	республика Марий Эл, Оршанский район, село Марково, Восточная, 9	f	medium
9317	54479	459	республика Марий Эл, Оршанский район, село Малый Пуял, Новая, 33	f	small
9319	54481	461	республика Марий Эл, Оршанский район, село Малый Кугланур, Центральная, 31а	f	small
9318	54480	460	республика Марий Эл, Оршанский район, село Малая Каракша, Школьная, 5б	f	small
9320	54482	462	республика Марий Эл, Оршанский район, село Лужбеляк, Центральная, 53	f	small
9316	54478	458	республика Марий Эл, Оршанский район, село Великополье, Шкетана, 24	f	small
9315	54477	457	республика Марий Эл, Оршанский район, село Большая Орша, 155а	f	small
9303	54464	445	республика Марий Эл, Новоторъяльский район, село Шура, Микрорайон, 6	f	small
9309	54471	451	республика Марий Эл, Новоторъяльский район, село Чуксола, им.В.Иванова, 8	f	small
9305	54466	447	республика Марий Эл, Новоторъяльский район, село Токтарсола, Центральная, 41	f	medium
9304	54465	446	республика Марий Эл, Новоторъяльский район, село Старый Торъял, Центральная, 57а	f	medium
9308	54470	450	республика Марий Эл, Новоторъяльский район, село Старокрещено, Молодежная, 1	f	small
9302	54463	444	республика Марий Эл, Новоторъяльский район, село Пектубаево, Советская, 54	f	medium
9295	54456	437	республика Марий Эл, Новоторъяльский район, поселок Новый Торъял, Советская, 53	f	large
9294	54455	436	республика Марий Эл, Новоторъяльский район, поселок Новый Торъял, Первомайская, 23	f	large
9296	54457	438	республика Марий Эл, Новоторъяльский район, поселок Новый Торъял, Культуры, 20	f	large
9293	54454	435	республика Марий Эл, Новоторъяльский район, поселок Новый Торъял, Коммунистическая, 27	f	large
9307	54469	449	республика Марий Эл, Новоторъяльский район, село Немда-Обалыш, Центральная, 13	f	medium
9299	54460	441	республика Марий Эл, Новоторъяльский район, село Масканур, Советская, 11	f	small
9306	54467	448	республика Марий Эл, Новоторъяльский район, село Кузнецы, Центральная, 2	f	small
9298	54459	440	республика Марий Эл, Новоторъяльский район, село Куан-Памаш, Полевая, 1а	f	small
9301	54462	443	республика Марий Эл, Новоторъяльский район, село Кремленки, Микрорайон, 12	f	small
9300	54461	442	республика Марий Эл, Новоторъяльский район, село Елембаево, Центральная, 16	f	medium
9310	54472	452	республика Марий Эл, Новоторъяльский район, село Большой Шуйбеляк, Центральная, 27	f	medium
9297	54458	439	республика Марий Эл, Новоторъяльский район, село Большой Ломарь, переулок Садовый, 9	f	small
9278	54439	421	республика Марий Эл, Моркинский район, село Ямбатор, Ямбаторская, 28	f	small
9279	54441	422	республика Марий Эл, Моркинский район, село Шоруньжа, Спортивная, 11	f	large
9272	54433	415	республика Марий Эл, Моркинский район, село Шордур, Центральная, 37	f	medium
9276	54437	419	республика Марий Эл, Моркинский район, село Шиньша, Петрова, 1Б	f	medium
9289	54450	431	республика Марий Эл, Моркинский район, село Шереганово, Школьная, 17а	f	small
9280	54442	423	республика Марий Эл, Моркинский район, село Уньжа, Набережная, 20	t	small
9263	54425	407	республика Марий Эл, Моркинский район, село Тыгыде-Морко, Молодежная, 9	f	small
9275	54436	418	республика Марий Эл, Моркинский район, село Токпердино, Центральная, 2	t	small
9288	54449	430	республика Марий Эл, Моркинский район, село Татарский Чодраял, Школьная, 2	f	medium
9277	54438	420	республика Марий Эл, Моркинский район, село Татарский Чодраял, Солнечная, 1	t	small
9258	54420	402	республика Марий Эл, Моркинский район, село Старое Мазиково, Центральная, 8	t	small
9268	54430	412	республика Марий Эл, Моркинский район, село Семисола, Советская, 17	f	small
9264	54426	408	республика Марий Эл, Моркинский район, село Себеусад, Школьная, 3	f	small
9271	54432	414	республика Марий Эл, Моркинский район, село Петровское, Пушкина, 19	t	small
9283	54445	426	республика Марий Эл, Моркинский район, село Осипсола, Клубная, 4	f	medium
9291	54452	433	республика Марий Эл, Моркинский район, село Октябрьский, Центральная, 6а	f	medium
9273	54434	416	республика Марий Эл, Моркинский район, село Нуж-Ключ, Школьная, 1	f	small
9257	54419	401	республика Марий Эл, Моркинский район, поселок Морки, 5, РТС	f	medium
9255	54417	399	республика Марий Эл, Моркинский район, поселок Морки, бул. Калинина, 10	f	large
9252	54414	396	республика Марий Эл, Моркинский район, поселок Морки, Советская, 7	f	large
9253	54415	397	республика Марий Эл, Моркинский район, поселок Морки, Льва Толстого, 13	f	large
9256	54418	400	республика Марий Эл, Моркинский район, поселок Морки, Компрессорная, 7	f	large
9254	54416	398	республика Марий Эл, Моркинский район, поселок Морки, Заозерная, 1а	f	large
9259	54421	403	республика Марий Эл, Моркинский район, село Мари-Кужеры, Центральная, 37б	t	small
9260	54422	404	республика Марий Эл, Моркинский район, село Кучко-Памаш, Центральная, 2	f	small
9290	54451	432	республика Марий Эл, Моркинский район, село Кутюк-Кинер, М. Казакова, 67	t	small
9287	54448	429	республика Марий Эл, Моркинский район, село Кульбаш, Центральная, 54а	f	small
9292	54453	434	республика Марий Эл, Моркинский район, поселок Красный Стекловар, Советская, 2	f	medium
9285	54447	428	республика Марий Эл, Моркинский район, село Коркатово, Юбилейная, 4	f	medium
9266	54428	410	республика Марий Эл, Моркинский район, село Изи-Кугунур, Центральная, 14	f	small
9284	54446	427	республика Марий Эл, Моркинский район, село Изи Шурга, Центральная, 50	t	small
9267	54429	411	республика Марий Эл, Моркинский район, село Зеленогорск, Кооперативная, 10	f	medium
9274	54435	417	республика Марий Эл, Моркинский район, село Досметкино, Мира, 36	f	small
9265	54427	409	республика Марий Эл, Моркинский район, село Весьшурга, Заозерная, 2	f	small
9262	54424	406	республика Марий Эл, Моркинский район, село Большой Кожлоял, Центральная, 9	f	small
9281	54443	424	республика Марий Эл, Моркинский район, село Большие Шали, Молодежная, 2	f	medium
9270	54431	413	республика Марий Эл, Моркинский район, село Алмаметьево, Титова, 27	f	small
9282	54444	425	республика Марий Эл, Моркинский район, село Азъял, Школьная, 14	t	small
9261	54423	405	республика Марий Эл, Моркинский район, село Адымаш, Русская, 8	t	small
9251	54413	395	республика Марий Эл, Медведевский район, поселение Юбилейный, Культуры, 2	f	large
9231	54393	376	республика Марий Эл, Медведевский район, село Яныкайсола, Центральная, 31	t	medium
8915	54107	63	республика Марий Эл, Медведевский район, село Якимово, 42Б	t	medium
9247	54409	391	республика Марий Эл, Медведевский район, село Шойбулак, Мира, 18	f	large
9217	54379	362	республика Марий Эл, Медведевский район, село Шеклянур, Советская, 2	t	small
9250	54412	394	республика Марий Эл, Медведевский район, село Цибикнур, Пионерская, 5	t	medium
9220	54382	365	республика Марий Эл, Медведевский район, село Томшарово, Школьная, 50	t	small
9227	54389	372	республика Марий Эл, Медведевский район, поселок Сурок, Коммунистическая, 1	f	large
9246	54408	390	республика Марий Эл, Медведевский район, село Средняя Турша, Школьная, 6	f	small
9218	54380	363	республика Марий Эл, Медведевский район, село Средние Шапы, Центральная, 10	t	small
9216	54378	361	республика Марий Эл, Медведевский район, село Среднее Азяково, Зеленая, 2а	t	medium
9226	54388	371	республика Марий Эл, Медведевский район, поселок Силикатный, Мира, 34	f	large
9241	54403	385	республика Марий Эл, Медведевский район, село Сенькино, Школьная, 18а	f	large
9239	54401	383	республика Марий Эл, Медведевский район, село Руэм, Шумелева, 14	f	large
9240	54402	384	республика Марий Эл, Медведевский район, село Руэм, Победы, 1	f	large
9238	54400	382	республика Марий Эл, Медведевский район, село Русский Кукмор, Пионерская, 3	t	large
9236	54399	381	республика Марий Эл, Медведевский район, село Пижма, Центральная, 30а	f	medium
9229	54391	374	республика Марий Эл, Медведевский район, поселок Пемба, Зеленая, 49	f	medium
9234	54397	379	республика Марий Эл, Медведевский район, село Пекшиксола, Транспортная, 10	f	medium
9249	54411	393	республика Марий Эл, Медведевский район, село Орешкино, Орешкино, 33	f	small
9232	54394	377	республика Марий Эл, Медведевский район, село Нурма, Кедровой, 48	f	medium
9235	54398	380	республика Марий Эл, Медведевский район, село Новый, Школьная, 1	f	large
9224	54386	369	республика Марий Эл, Медведевский район, село Новое Комино, Школьная, 8	t	medium
9205	54365	348	республика Марий Эл, Медведевский район, поселок Медведево, Шумелева, 8	f	large
9212	54374	357	республика Марий Эл, Медведевский район, поселок Медведево, Чехова, 6	f	small
9204	54364	347	республика Марий Эл, Медведевский район, поселок Медведево, Терешковой, 13	f	large
9210	54368	351	республика Марий Эл, Медведевский район, поселок Медведево, Советская, 23	f	large
9208	54369	352	республика Марий Эл, Медведевский район, поселок Медведево, Полевая, 20	f	large
9209	54367	350	республика Марий Эл, Медведевский район, поселок Медведево, Полевая, 3	f	medium
9203	54363	346	республика Марий Эл, Медведевский район, поселок Медведево, Мира, 9	f	large
9206	54366	349	республика Марий Эл, Медведевский район, поселок Медведево, Лермонтова, 13	f	large
9207	54372	355	республика Марий Эл, Медведевский район, поселок Медведево, Ленина, 14	f	large
65959	54371	354	республика Марий Эл, Медведевский район, поселок Медведево, Ленина, 14	f	small
65958	54370	353	республика Марий Эл, Медведевский район, поселок Медведево, Коммунистическая, 18	f	small
9211	54373	356	республика Марий Эл, Медведевский район, поселок Медведево, Гагарина, 2а	f	medium
9230	54392	375	республика Марий Эл, Медведевский район, село Люльпаны, Лесная, 18	t	medium
9223	54385	368	республика Марий Эл, Медведевский район, село Кузнецово, Пионерская, 1а	f	large
9214	54376	359	республика Марий Эл, Медведевский район, поселок Краснооктябрьский, Фабричная, 3	f	large
9213	54375	358	республика Марий Эл, Медведевский район, поселок Краснооктябрьский, Горького, 21	f	large
9225	54387	370	республика Марий Эл, Медведевский район, село Ким, Центральная, 1а	t	small
9222	54384	367	республика Марий Эл, Медведевский район, село Знаменский, Победы, 5	f	small
9221	54383	366	республика Марий Эл, Медведевский район, село Знаменский, Победы, 5	f	large
9219	54381	364	республика Марий Эл, Медведевский район, село Ежово, Комсомольская, 20	t	medium
9242	54404	386	республика Марий Эл, Медведевский район, поселок Аэропорт, 11	f	small
9233	54395	378	республика Марий Эл, Медведевский район, село Арбаны, Полевая, 13	t	small
9248	54410	392	республика Марий Эл, Медведевский район, село Аксарка, Аксаркино, 5	t	small
9215	54377	360	республика Марий Эл, Медведевский район, село Азаново, Фабричная, 4	f	large
9202	54362	345	республика Марий Эл, Мари-Турекский район, село Хлебниково, Свободы, 2	f	medium
9185	54345	327	республика Марий Эл, Мари-Турекский район, село Тат-Китня, Победы, 1	f	medium
9191	54350	334	республика Марий Эл, Мари-Турекский район, село Сысоево, 13, Центральная усадьба	f	medium
9197	54357	340	республика Марий Эл, Мари-Турекский район, село Совхоз Павловский, Клубная, 9	t	small
9194	54353	337	республика Марий Эл, Мари-Турекский район, село Сенда, Русская Сенда, 18	t	small
9189	54348	332	республика Марий Эл, Мари-Турекский район, село Сардаял, Советская, 7	t	small
9196	54356	339	республика Марий Эл, Мари-Турекский район, поселок Мариец, Клубная, 2	f	large
9186	54344	328	республика Марий Эл, Мари-Турекский район, поселок Мари-Турек, Советская, 16	f	medium
9184	54344	326	республика Марий Эл, Мари-Турекский район, поселок Мари-Турек, Советская, 16	f	medium
9178	54338	320	республика Марий Эл, Мари-Турекский район, поселок Мари-Турек, Парковая, 5	f	large
9183	54343	325	республика Марий Эл, Мари-Турекский район, поселок Мари-Турек, Мичурина, 30	f	medium
9182	54342	324	республика Марий Эл, Мари-Турекский район, поселок Мари-Турек, Мичурина, 30	f	medium
9179	54339	321	республика Марий Эл, Мари-Турекский район, поселок Мари-Турек, Комсомольская, 36	f	large
9181	54341	323	республика Марий Эл, Мари-Турекский район, село Мари-Купта, Молодежная, 13	f	medium
9180	54340	322	республика Марий Эл, Мари-Турекский район, село Мари-Китня, Школьная, 2	t	small
9192	54351	335	республика Марий Эл, Мари-Турекский район, село Мари-Билямор, Колхозная, 3.	f	medium
9188	54347	331	республика Марий Эл, Мари-Турекский район, село Лопово, Лопово, 47	t	medium
9199	54359	342	республика Марий Эл, Мари-Турекский район, село Лом, Лом, 43	f	small
9198	54358	341	республика Марий Эл, Мари-Турекский район, село Крупино, 49	t	small
9190	54349	333	республика Марий Эл, Мари-Турекский район, село Косолапово, Совхозная, 33	f	large
9200	54360	343	республика Марий Эл, Мари-Турекский район, село Ивская Вершина, 1а	t	small
9193	54352	336	республика Марий Эл, Мари-Турекский район, село Елымбаево, Школьная, 9	f	medium
9195	54355	338	республика Марий Эл, Мари-Турекский район, село Дружино, 52	t	small
65957	54346	330	республика Марий Эл, Мари-Турекский район, село Большой Карлыган, Мира, 26	f	small
9187	54346	329	республика Марий Эл, Мари-Турекский район, село Большой Карлыган, Мира, 26	f	large
9201	54361	344	республика Марий Эл, Мари-Турекский район, село Большое Опарино, Советская, 47	t	medium
9177	54337	319	республика Марий Эл, Мари-Турекский район, село Алексеевское, Заречная, 9	f	small
9176	54336	318	республика Марий Эл, Куженерский район, село Юледур, Коммунистическая, 22а	f	medium
9171	54330	313	республика Марий Эл, Куженерский район, село Шорсола, Центральная, 5	f	medium
9172	54331	314	республика Марий Эл, Куженерский район, село Шой-Шудумарь, Рыбакова, 11	f	medium
9169	54328	311	республика Марий Эл, Куженерский район, село Тумьюмучаш, Тумьюмучаш, 40	f	small
9167	54326	309	республика Марий Эл, Куженерский район, село Токтайбеляк, Молодежная, 3	f	medium
9166	54325	308	республика Марий Эл, Куженерский район, село Салтакъял, Рубочая, 18	f	small
9164	54323	306	республика Марий Эл, Куженерский район, село Русские Шои, Школьная, 4	f	medium
9165	54324	307	республика Марий Эл, Куженерский район, село Мари-Шои, Починок, 3	f	small
9162	54321	304	республика Марий Эл, Куженерский район, поселок Куженер, Степана Лебедева, 20 а	f	medium
9161	54320	303	республика Марий Эл, Куженерский район, поселок Куженер, Степана Лебедева, 20а	f	large
9160	54319	302	республика Марий Эл, Куженерский район, поселок Куженер, Степана Лебедева, 20а	f	large
9159	54318	301	республика Марий Эл, Куженерский район, поселок Куженер, Степана Лебедева, 20 а	f	large
9173	54333	315	республика Марий Эл, Куженерский район, село Кугунур, Зеленая, 16	f	small
9170	54329	312	республика Марий Эл, Куженерский район, село Конганур, Конганур, 75	f	small
9163	54322	305	республика Марий Эл, Куженерский район, село Иштымбал, Набережная, 2	f	medium
9175	54335	317	республика Марий Эл, Куженерский район, село Ивансола, Ивансола, 37а	f	small
9168	54327	310	республика Марий Эл, Куженерский район, село Верхний Ушут, Школьная, 64	f	small
9174	54334	316	республика Марий Эл, Куженерский район, село Большой Ляждур, Центральная, 29Б	f	medium
9158	54317	300	республика Марий Эл, Килемарский район, село Юксары, Школьная, 5	f	small
9156	54315	298	республика Марий Эл, Килемарский район, село Широкундыш, Механизаторов, 11	f	small
9151	54310	293	республика Марий Эл, Килемарский район, село Озерный, Зеленая, 1	f	small
9154	54313	296	республика Марий Эл, Килемарский район, село Нежнур, Коммунистическая, 18	f	small
9147	54305	289	республика Марий Эл, Килемарский район, поселок Механизаторов, Ветеранов, 3	f	small
9153	54312	295	республика Марий Эл, Килемарский район, село Майский, Железнодорожная, 12	t	small
9152	54311	294	республика Марий Эл, Килемарский район, село Кумья, Советская, 6	f	small
9150	54309	292	республика Марий Эл, Килемарский район, село Красный Мост, Центральная, 8	f	small
9142	54300	284	республика Марий Эл, Килемарский район, поселок Килемары, Садовая, 56	f	large
9143	54301	285	республика Марий Эл, Килемарский район, поселок Килемары, Мира, 31	f	large
9146	54304	288	республика Марий Эл, Килемарский район, село Ершово, Школьная, 12	f	small
9149	54308	291	республика Марий Эл, Килемарский район, поселок Визимъяры, Советская, 18 а	f	large
9148	54306	290	республика Марий Эл, Килемарский район, село Большое Кибеево, Большекибеевская, 69	f	small
9145	54303	287	республика Марий Эл, Килемарский район, село Арда, Школьная, 5	f	medium
9144	54302	286	республика Марий Эл, Килемарский район, село Алешкино, Лесная, 12	t	small
9157	54316	299	республика Марий Эл, Килемарский район, село Алатайкино, Алатайкинская, 45	f	small
9155	54314	297	республика Марий Эл, Килемарский район, село Актаюж, Лесная, 1	t	small
8911	54102	58	республика Марий Эл, Йошкар-Ола городской округ, село Семеновка, Молодежная, 11	f	large
9244	54406	388	республика Марий Эл, Йошкар-Ола городской округ, село Светлый, Садовая, 1	f	medium
8913	54105	61	республика Марий Эл, Йошкар-Ола городской округ, село Савино, Школьная, 9	f	large
8974	54153	122	республика Марий Эл, Йошкар-Ола городской округ, село Нолька, 43	t	small
9243	54405	387	республика Марий Эл, Йошкар-Ола городской округ, село Нолька, Нолька, 4	f	small
9228	54390	373	республика Марий Эл, Йошкар-Ола городской округ, село Куяр, Лесная, 21	f	large
9245	54407	389	республика Марий Эл, Йошкар-Ола городской округ, село Зеленый, Зеленая, 1а	f	small
9133	54293	276	республика Марий Эл, Звениговский район, село Шимшурга, Шимшургинская, 44	f	small
9140	54298	282	республика Марий Эл, Звениговский район, поселок Шелангер, Школьная, 36	f	large
9139	54298	281	республика Марий Эл, Звениговский район, поселок Шелангер, Школьная, 36	f	medium
9138	54297	280	республика Марий Эл, Звениговский район, село Черное Озеро, 52	f	small
9141	54299	283	республика Марий Эл, Звениговский район, село Филиппсола, Валерия Волкова, 2а	f	small
9114	54275	257	Россия, республика Марий Эл, Звениговский район, село Трубный	t	small
9110	54273	255	республика Марий Эл, Звениговский район, село Ташнур, 51	t	small
9131	54291	274	республика Марий Эл, Звениговский район, село Таир, Школьная, 16б	f	small
9117	54278	260	республика Марий Эл, Звениговский район, поселок Суслонгер, Железнодорожная, 60	f	medium
9116	54277	259	республика Марий Эл, Звениговский район, поселок Суслонгер, Гвардейская, 8	f	large
9121	54282	264	республика Марий Эл, Звениговский район, село Сосновка, Мюшультурская, 57	f	small
9136	54295	278	республика Марий Эл, Звениговский район, село Сидельниково, Школьная, 12	f	medium
9132	54292	275	республика Марий Эл, Звениговский район, село Семеновка, Селиванова, 57	f	small
9129	54289	272	республика Марий Эл, Звениговский район, село Поянсола, Школьная, 14	f	medium
9126	54286	269	республика Марий Эл, Звениговский район, село Нуктуж, 255	f	small
9137	54296	279	республика Марий Эл, Звениговский район, село Новая Липша, Новая, 11	f	small
9128	54288	271	республика Марий Эл, Звениговский район, село Нижние Помьялы, Центральная, 55А	t	medium
9115	54276	258	республика Марий Эл, Звениговский район, поселок Мочалище, Школьная, 17	f	large
9127	54287	270	республика Марий Эл, Звениговский район, село Малая Кужмара, Малокужмарская, 16а	f	small
9119	54280	262	республика Марий Эл, Звениговский район, село Кукшенеры, 65а	t	small
9124	54285	267	республика Марий Эл, Звениговский район, село Кужмара, Центральная, 5	f	medium
9125	54285	268	республика Марий Эл, Звениговский район, село Кужмара, Центральная, 5	f	medium
9122	54283	265	республика Марий Эл, Звениговский район, село Красный Яр, Центральная, 17	f	small
9120	54281	263	республика Марий Эл, Звениговский район, село Красный Яр, Центральная, 15	f	medium
9108	54272	253	республика Марий Эл, Звениговский район, поселок Красногорский, Центральная, 73	f	medium
9105	54269	250	республика Марий Эл, Звениговский район, поселок Красногорский, Центральная, 1а	f	large
9113	54274	256	республика Марий Эл, Звениговский район, поселок Красногорский, Первомайская, 84	f	small
9109	54271	254	республика Марий Эл, Звениговский район, поселок Красногорский, Машиностроителей, 6	f	medium
9107	54271	252	республика Марий Эл, Звениговский район, поселок Красногорский, Машиностроителей, 6	f	large
9106	54270	251	республика Марий Эл, Звениговский район, поселок Красногорский, Ленина, 12	f	large
9135	54294	277	республика Марий Эл, Звениговский район, село Кокшамары, Молодежная, 29А	f	medium
9130	54290	273	республика Марий Эл, Звениговский район, село Кокшайск, Заводская, 1а	f	medium
9118	54279	261	республика Марий Эл, Звениговский район, село Исменцы, Молодежная, 4	f	medium
9123	54284	266	республика Марий Эл, Звениговский район, село Иркино, Малое Иркино, 65	t	small
9103	54268	249	республика Марий Эл, Звениговский район, поселок Илеть, Куйбышева, 13	t	small
9096	54263	242	республика Марий Эл, Звениговский район, Звенигово, Советская, 41	f	medium
9095	54263	241	республика Марий Эл, Звениговский район, Звенигово, Советская, 41	f	medium
9091	54260	237	республика Марий Эл, Звениговский район, Звенигово, Набережная, 16	f	medium
9090	54260	236	республика Марий Эл, Звениговский район, Звенигово, Набережная, 16	f	medium
9101	54266	247	республика Марий Эл, Звениговский район, Деревня Чуваш-Отары, Чуваш-Отарская, 72а	f	small
9083	54253	229	республика Марий Эл, Горномарийский район, село Яштуга, Яшгутинская, 9А	t	small
9058	54230	206	республика Марий Эл, Горномарийский район, село Юнга-Кушерга, Юнго-Кушерга, 93в	t	small
9070	54241	217	республика Марий Эл, Горномарийский район, село Юлъялы, Вознесенская, 25г	f	small
9065	54236	212	республика Марий Эл, Горномарийский район, село Четнаево, Архипкинская, 54	f	small
9087	54257	233	республика Марий Эл, Горномарийский район, село Чекеево, Центральная, 8	f	medium
9089	54259	235	республика Марий Эл, Горномарийский район, село Усола, Центральная, 26	f	medium
9050	54224	198	республика Марий Эл, Горномарийский район, село Тушналы, Тушналы, 49	t	small
9086	54256	232	республика Марий Эл, Горномарийский район, село Троицкий Посад, Карла Маркса, 45а	f	small
9078	54248	224	республика Марий Эл, Горномарийский район, село Три Рутки, Больничная, 8	f	small
9068	54239	215	республика Марий Эл, Горномарийский район, село Токари, Лесная, 8А	t	small
9052	54225	200	республика Марий Эл, Горномарийский район, деревня Пичужкино, Пичужкино, 7	f	small
9057	54229	204	республика Марий Эл, Горномарийский район, село Пертюково, Пертюково, 8А	t	small
9062	54233	209	республика Марий Эл, Горномарийский район, село Пертнуры, Пертнуры, 41	f	small
9049	54223	197	республика Марий Эл, Горномарийский район, село Паратмары, Паратмары, 76	f	small
9081	54251	227	республика Марий Эл, Горномарийский район, село Пайгусово, Новая, 10г	f	medium
9064	54235	211	республика Марий Эл, Горномарийский район, село Октябрьский, Красная, 11А	f	small
9077	54247	223	республика Марий Эл, Горномарийский район, село Озерки, Советская, 12	f	medium
9076	54246	222	республика Марий Эл, Горномарийский район, село Озерки, Заволжская, 37	f	medium
9088	54258	234	республика Марий Эл, Горномарийский район, село Носелы, 113	f	small
9082	54252	228	республика Марий Эл, Горномарийский район, село Новая Слобода, Школьная, 48а	f	small
9066	54237	213	республика Марий Эл, Горномарийский район, село Нижние Шелаболки, Нижнешелаболкинская, 2	f	small
9085	54255	231	республика Марий Эл, Горномарийский район, село Мумариха, Набережная, 4	f	small
9073	54244	220	республика Марий Эл, Горномарийский район, село Микряково, Центральная, 29	f	medium
9084	54254	230	республика Марий Эл, Горномарийский район, село Малая Юнга, Центральная, 12	t	small
9080	54250	226	республика Марий Эл, Горномарийский район, село Макаркино, Центральная, 72В	f	medium
9063	54234	210	республика Марий Эл, Горномарийский район, село Кулаково, Механизаторов, 2	f	medium
9067	54238	214	республика Марий Эл, Горномарийский район, село Кузнецово, Центральная, 22в	f	small
2392	21563	2111	республика Башкортостан, село Ябалаково, Т. Назмиева, 30	f	small
9069	54240	216	республика Марий Эл, Горномарийский район, село Кузнецово, Верхняя, 99	f	small
9048	54222	196	республика Марий Эл, Горномарийский район, село Кожважи, Кожважи, 11	f	small
9055	54228	203	республика Марий Эл, Горномарийский район, село Картуково, Центральная, 41	f	small
9075	54245	221	республика Марий Эл, Горномарийский район, село Еникеево, Центральная, 29	t	small
9060	54232	208	республика Марий Эл, Горномарийский район, село Емешево, Проезжая, 80	f	medium
9059	54231	207	республика Марий Эл, Горномарийский район, село Емешево, Проезжая, 77	f	small
9054	54227	202	республика Марий Эл, Горномарийский район, село Емелево, 29а	f	small
9072	54243	219	республика Марий Эл, Горномарийский район, село Емангаши, Приволжская, 99	f	medium
9056	54226	205	республика Марий Эл, Горномарийский район, село Еласы, Октябрьская, 15	f	small
9053	54226	201	республика Марий Эл, Горномарийский район, село Еласы, Октябрьская, 15	f	medium
9047	54221	195	республика Марий Эл, Горномарийский район, село Виловатово, Советская, 3	f	medium
9051	54221	199	республика Марий Эл, Горномарийский район, село Виловатово, Советская, 3	f	medium
9079	54249	225	республика Марий Эл, Горномарийский район, село Верхнее Акчерино, Центральная, 8Б	f	small
9071	54242	218	республика Марий Эл, Горномарийский район, село Березово, Центральная, 38	f	small
9032	54206	180	республика Марий Эл, Волжский район, село Ярамор, Красноармейская, 122А	f	small
9046	54220	194	республика Марий Эл, Волжский район, село Эмеково, Советская, 8	f	large
9044	54218	192	республика Марий Эл, Волжский район, село Шарибоксад, Клубная, 3	f	small
9027	54201	175	республика Марий Эл, Волжский район, село Чодраял, Школьная, 2	f	medium
9038	54212	186	республика Марий Эл, Волжский район, село Часовенная, Школьная, 18А	f	large
9035	54209	183	республика Марий Эл, Волжский район, село Учейкино, Советская, 60	f	medium
9043	54217	191	республика Марий Эл, Волжский район, село Сотнур, Центральная, 26	f	medium
9040	54214	188	республика Марий Эл, Волжский район, поселок Приволжский, Молодежная, 3А	f	large
9039	54213	187	республика Марий Эл, Волжский район, поселок Приволжский, Заводская, 3	f	large
9037	54211	185	республика Марий Эл, Волжский район, село Помары, Станционная, 3	f	large
9030	54204	178	республика Марий Эл, Волжский район, село Полевая, Новая, 6	f	large
9031	54205	179	республика Марий Эл, Волжский район, село Петъялы, Школьная, 2	f	large
9041	54215	189	республика Марий Эл, Волжский район, село Памашенер, Центральная, 16	t	small
9025	54199	173	республика Марий Эл, Волжский район, село Отымбал, Учительская, 7	f	small
9042	54216	190	республика Марий Эл, Волжский район, село Нуршари, Центральная, 2	f	small
9026	54200	174	республика Марий Эл, Волжский район, село Новый Карамас, Центральная, 27	f	small
9045	54219	193	республика Марий Эл, Волжский район, село Моркиялы, Зеленая, 52	t	small
9029	54203	177	республика Марий Эл, Волжский район, село Кленовая Гора, Пугачева, 1	t	small
9028	54202	176	республика Марий Эл, Волжский район, село Кичиер, Лесная, 9	f	small
9034	54208	182	республика Марий Эл, Волжский район, село Карай, Пионерская, 32	f	small
9033	54207	181	республика Марий Эл, Волжский район, село Инерымбал, Школьная, 1А	f	small
9003	54179	151	республика Марий Эл, Волжский район, Волжск, Кабанова, 10 а	f	large
9024	54198	172	республика Марий Эл, Волжский район, село Большие Параты, Финская, 23	f	large
9023	54197	171	республика Марий Эл, Волжский район, село Бизергуб, Заречная, 25	f	small
9036	54210	184	республика Марий Эл, Волжский район, село Березняки, Лесная, 2	f	small
1285	20475	1015	республика Башкортостан, село Ярмухаметово, Буранбая, 14	f	small
2282	21453	2002	республика Башкортостан, село Япарсаз, Школьная, 19/1	t	small
3682	22905	3462	республика Башкортостан, Янаул, Социалистическая, 19	f	large
3680	22903	3460	республика Башкортостан, Янаул, Советская, 18	f	large
3675	22898	3455	республика Башкортостан, Янаул, Ломоносова, 17	f	large
3683	22906	3463	республика Башкортостан, Янаул, Куйбышева, 68	f	large
3681	22904	3461	республика Башкортостан, Янаул, Кирова, 66	f	large
3676	22899	3456	республика Башкортостан, Янаул, Азина, 20	f	large
1448	20636	1178	республика Башкортостан, село Ялангачево, Центральная, 17	f	small
503	19777	241	республика Башкортостан, Уфа, Шафиева, 31/2	f	large
2637	21805	2356	республика Башкортостан, село Юсупово, Школьная, 51	f	small
2624	21791	2343	республика Башкортостан, село Юнусово, Салавата Юлаева, 61	f	small
1882	21060	1606	республика Башкортостан, село Юмакаево, Школьная, 13	f	small
2186	21361	1906	республика Башкортостан, село Юлдыбаево, Центральная, 15	f	small
3364	22588	3143	республика Башкортостан, село Юлдашево, Школьная, 1	f	medium
2130	21309	1854	республика Башкортостан, село Юкаликулево, Ленина, 6	f	small
3330	22556	3109	Россия, республика Башкортостан, деревня Шмидтово, улица Мира, 2	f	medium
109369	22338	2909	Россия, республика Удмуртская, Игринский район, село Бельское	f	\N
1096	20295	829	республика Башкортостан, деревня Шмидтово, Мира, 12	f	small
1760	20943	1486	республика Башкортостан, село Шарлык, Школьная, 7	f	small
2790	21961	2509	республика Башкортостан, село Шарипово, Султанова, 13	f	medium
1129	20330	862	республика Башкортостан, село Чуракаево, Салавата Юлаева, 26Б	f	small
3038	22202	2756	республика Башкортостан, село Чураево, Демская, 26	f	small
3298	22523	3077	республика Башкортостан, село Чукадыбашево, Советская, 58	f	small
2312	21482	2031	республика Башкортостан, село Чкаловское, Цветочная, 30	f	small
2104	21282	1828	республика Башкортостан, село Чишма, Молодёжная, 3	f	small
1290	20480	1020	республика Башкортостан, село Чингизово, Х. Ахметова, 20	f	small
3081	22245	2799	Россия, республика Башкортостан, деревня Чесноковка, улица Нур, 1	f	small
65645	20434	974	республика Башкортостан, деревня Чесноковка, Мажита Гафури, 14	f	\N
3523	22747	3302	республика Башкортостан, село Чекмагуш, Октябрьская, 1	f	medium
3525	22749	3304	республика Башкортостан, село Чекмагуш, Мира, 28	f	medium
3529	22753	3308	республика Башкортостан, село Чекмагуш, 70-лет Октября, 99	f	medium
3084	22248	2802	республика Башкортостан, село Чандар, Симская, 49	f	small
2694	21861	2413	республика Башкортостан, село Худайбердино, Псянчина, 7	f	small
2895	22064	2613	республика Башкортостан, село Хлебодаровка, Центральная, 38А	f	small
1076	20275	809	республика Башкортостан, село Хамитово, Сагадатова, 22	f	small
3429	22654	3208	республика Башкортостан, поселок Федоровка, переулок Овражный, 6	f	small
1794	20974	1519	республика Башкортостан, поселок Федоровка, Центральная, 16	f	small
3512	22736	3291	республика Башкортостан, поселок Федоровка, Мусы Гареева, 22	f	small
3019	22183	2737	республика Башкортостан, село Уязыбашево, Центральная, 5	f	small
3406	22629	3184	республика Башкортостан, Учалы, пер.Школьный, 6, СОШ №2	f	large
3408	22632	3187	республика Башкортостан, Учалы, Энергетиков, 1, УГЭС	f	large
3404	22631	3186	республика Башкортостан, Учалы, Энергетиков, 29, БГУ	f	large
3401	22625	3180	республика Башкортостан, Учалы, Чкалова, 25	f	medium
3405	22628	3183	республика Башкортостан, Учалы, Фабричный переулок, 3, Башкиргеология	f	large
3421	22637	3192	республика Башкортостан, Учалы, Муртазина, 20, СОШ №1	f	large
3416	22645	3200	республика Башкортостан, Учалы, Максима Горького, 2/1, Комбинатский дом	f	large
3418	22647	3201	республика Башкортостан, Учалы, Максима Горького, 6	f	large
3413	22642	3197	республика Башкортостан, Учалы, Максима Горького, 1а, Дом Детского Творчества	f	large
3422	22636	3191	республика Башкортостан, Учалы, Ленинского Комсомола, 6	f	large
3417	22648	3202	республика Башкортостан, Учалы, Ленина, 44а, СОШ №3	f	large
3411	22638	3193	республика Башкортостан, Учалы, Кирова, 6, СОШ № 10	f	large
3415	22640	3195	республика Башкортостан, Учалы, Башкортостана, 15, СОШ №5	f	large
3400	22624	3179	республика Башкортостан, Учалы, Багаутдинова, 79, ДШИ	f	medium
3423	22649	3203	республика Башкортостан, Учалы, Ахметгалина, 28, Реабилитационный центр	f	large
348	19656	85	республика Башкортостан, Уфа, УМЗ Б	t	small
516	19783	254	Россия, республика Башкортостан, Уфа, улица Юрия Гагарина, 26/1	f	large
517	19783	255	Россия, республика Башкортостан, Уфа, улица Юрия Гагарина, 26/1	f	large
510	19780	248	Россия, республика Башкортостан, Уфа, улица Юрия Гагарина, 15/1	f	large
278	19604	15	Россия, республика Башкортостан, Уфа, улица Ухтомского, 29	f	large
276	19602	13	Россия, республика Башкортостан, Уфа, улица Ухтомского, 28	f	large
65768	21970	2518	Россия, Московская область, Павлово-Посадский район, Павловский Посад, Совхозная улица, 3	f	\N
65602	19719	160	Россия, республика Башкортостан, Уфа, улица Светлая, 39	f	\N
355	19663	92	Россия, республика Башкортостан, Уфа, улица Свердлова, 55	f	large
583	19831	321	Россия, республика Башкортостан, Уфа, улица Репина, 6	f	large
369	19676	106	Россия, республика Башкортостан, Уфа, улица Пушкина, 103а	f	large
356	19664	93	Россия, республика Башкортостан, Уфа, улица Пушкина, 67	f	large
618	19860	356	Россия, республика Башкортостан, Уфа, улица Пархоменко, 155/2	f	large
513	19781	251	Россия, республика Башкортостан, Уфа, Октябрьский район	f	large
512	19781	250	Россия, республика Башкортостан, Уфа, Октябрьский район	f	large
511	19781	249	Россия, республика Башкортостан, Уфа, Октябрьский район	f	large
277	19603	14	Россия, республика Башкортостан, Уфа, Демский район, улица Мусы Джалиля, 74/1	f	large
660	19894	398	Россия, республика Башкортостан, Уфа, улица Менделеева, 193	f	large
659	19893	397	Россия, республика Башкортостан, Уфа, улица Менделеева, 177/3	f	large
385	19691	122	Россия, республика Башкортостан, Уфа, улица Менделеева, 146/1	f	large
65603	19738	186	Россия, республика Башкортостан, Уфа, улица Лесозаводская, 1/1	f	\N
661	19895	399	Россия, республика Башкортостан, Уфа, улица Красноводская, 13	f	large
637	19876	375	Россия, республика Башкортостан, Уфа, улица Комсомольская, 29	f	large
2153	21330	1875	Россия, республика Башкортостан, Уфа, Кировский район, улица Кирова, 8	f	small
370	19677	107	Россия, республика Башкортостан, Уфа, Кировский район, улица Кирова, 65	f	large
330	19643	67	Россия, республика Башкортостан, Уфа, улица Карима Хакимова, 7	f	large
337	19649	74	Россия, республика Башкортостан, Уфа, улица Интернациональная, 123	f	large
336	19649	73	Россия, республика Башкортостан, Уфа, улица Интернациональная, 123	f	large
275	19601	12	Россия, республика Башкортостан, Уфа, улица Дагестанская, 31/1	f	large
297	19619	34	Россия, республика Башкортостан, Уфа, улица Георгия Мушникова, 5/2	f	large
298	19619	35	Россия, республика Башкортостан, Уфа, улица Георгия Мушникова, 5/2	f	large
296	19619	33	Россия, республика Башкортостан, Уфа, улица Георгия Мушникова, 5/2	f	large
386	19692	123	Россия, республика Башкортостан, Уфа, улица Генерала Горбатова, 11	f	large
2278	21449	1998	Россия, Краснодарский край, Краснодар, улица Гаражная, 21	f	small
65610	19900	404	Россия, республика Башкортостан, Уфа, улица Бакалинская, 66/1	f	\N
663	19897	401	Россия, республика Башкортостан, Уфа, улица Акназарова, 24	f	large
669	19903	407	Россия, республика Башкортостан, Уфа, улица 50-летия Октября, 16/1	f	large
497	19774	235	Россия, республика Башкортостан, Уфа, улица 50 Лет СССР, 36	f	large
644	19875	382	республика Башкортостан, Уфа, проспект Октября , 33	f	large
643	19875	381	республика Башкортостан, Уфа, проспект Октября , 33	f	large
636	19875	374	республика Башкортостан, Уфа, проспект Октября , 33	f	large
492	19771	230	республика Башкортостан, Уфа, им. Города Галле, 9	f	large
539	19794	277	республика Башкортостан, Уфа, Юрия Гагарина, 74/1	f	large
531	19789	269	республика Башкортостан, Уфа, Юрия Гагарина, 48/1	f	large
530	19788	268	республика Башкортостан, Уфа, Юрия Гагарина, 37/1	f	large
529	19788	267	республика Башкортостан, Уфа, Юрия Гагарина, 37/1	f	large
525	19786	263	республика Башкортостан, Уфа, Юрия Гагарина, 36/2	f	large
524	19786	262	республика Башкортостан, Уфа, Юрия Гагарина, 36/2	f	large
523	19786	261	республика Башкортостан, Уфа, Юрия Гагарина, 36/2	f	large
522	19786	260	республика Башкортостан, Уфа, Юрия Гагарина, 36/2	f	large
521	19785	259	республика Башкортостан, Уфа, Юрия Гагарина, 25/1	f	large
515	19782	253	республика Башкортостан, Уфа, Юрия Гагарина, 24/1	f	large
514	19782	252	республика Башкортостан, Уфа, Юрия Гагарина, 24/1	f	large
509	19779	247	республика Башкортостан, Уфа, Юрия Гагарина, 15	f	large
508	19779	246	республика Башкортостан, Уфа, Юрия Гагарина, 15	f	large
582	19830	320	республика Башкортостан, Уфа, Юрия Гагарина, 11	f	large
65600	19687	117	республика Башкортостан, Уфа, Элеваторная, 7/1	f	\N
65605	19809	297	республика Башкортостан, Уфа, Шота Руставели, 18а	f	\N
720	19947	457	Россия, республика Башкортостан, Уфа, Школьный переулок, 3	f	large
504	19777	242	республика Башкортостан, Уфа, Шафиева, 31/2	f	large
466	19750	204	республика Башкортостан, Уфа, Шафиева, 1	f	large
465	19750	203	республика Башкортостан, Уфа, Шафиева, 1	f	large
456	19744	194	республика Башкортостан, Уфа, Чкалова, 110	f	large
1798	20978	1523	республика Башкортостан, Уфа, Чишминская, 32	f	small
308	19627	45	республика Башкортостан, Уфа, Чехова, 1	f	large
436	19729	174	республика Башкортостан, Уфа, Чернышевского, 25а	f	medium
437	19729	175	республика Башкортостан, Уфа, Чернышевского, 25а	f	large
368	19675	105	республика Башкортостан, Уфа, Чернышевского, 141	f	large
367	19674	104	республика Башкортостан, Уфа, Чернышевского, 145	f	large
328	19641	65	республика Башкортостан, Уфа, Черниковская, 46а	f	large
324	19638	61	республика Башкортостан, Уфа, Черниковская, 89	f	large
323	19638	60	республика Башкортостан, Уфа, Черниковская, 89	f	large
624	19865	362	республика Башкортостан, Уфа, Цюрупы, 126	f	large
379	19686	116	республика Башкортостан, Уфа, Цветы Башкирии, 2/3	f	medium
365	19672	102	республика Башкортостан, Уфа, Худайбердина, 15	f	large
677	19911	415	республика Башкортостан, Уфа, Харьковская, 121	f	large
656	19890	394	Россия, республика Башкортостан, Уфа, Хадии Давлетшиной бульвар, 34	f	large
635	19874	373	республика Башкортостан, Уфа, Хадии Давлетшиной бульвар, 28	f	large
307	19626	44	республика Башкортостан, Уфа, Фурманова, 39	f	large
290	19615	27	республика Башкортостан, Уфа, Ферина, 14/1	f	large
289	19614	26	республика Башкортостан, Уфа, Ферина, 19/1	f	large
269	19595	6	республика Башкортостан, Уфа, Ухтомского, 12	f	large
489	19768	227	республика Башкортостан, Уфа, Уфимское Шоссе, 20	f	large
488	19768	226	республика Башкортостан, Уфа, Уфимское Шоссе, 20	f	large
581	19829	319	республика Башкортостан, Уфа, Ульяновых, 50	f	large
579	19827	317	республика Башкортостан, Уфа, Ульяновых, 38	f	large
566	19815	304	республика Башкортостан, Уфа, Ульяновых, 13/1	f	large
292	19616	29	Россия, республика Башкортостан, Уфа, Тухвата Янаби бульвар, 59/2	f	large
291	19616	28	Россия, республика Башкортостан, Уфа, Тухвата Янаби бульвар, 59/2	f	large
288	19613	25	Россия, республика Башкортостан, Уфа, Тухвата Янаби бульвар, 49/4	f	large
287	19613	24	Россия, республика Башкортостан, Уфа, Тухвата Янаби бульвар, 49/4	f	large
360	19667	97	республика Башкортостан, Уфа, Тукаева, 39	f	large
303	19621	40	республика Башкортостан, Уфа, Транспортная, 50/4	f	large
302	19621	39	республика Башкортостан, Уфа, Транспортная, 50/4	f	large
295	19618	32	республика Башкортостан, Уфа, Транспортная, 34/1	f	large
294	19618	31	республика Башкортостан, Уфа, Транспортная, 34/1	f	large
293	19617	30	республика Башкортостан, Уфа, Транспортная, 40/1	f	large
347	19655	84	республика Башкортостан, Уфа, Трамвайная, 10	f	small
606	19848	344	республика Башкортостан, Уфа, Таманская, 47	f	large
272	19598	9	республика Башкортостан, Уфа, Таллинская, 25	f	large
270	19596	7	республика Башкортостан, Уфа, Таллинская, 17	f	large
265	19592	2	республика Башкортостан, Уфа, Таллинская, 3	f	large
593	19839	331	республика Башкортостан, Уфа, Суворова, 35	f	large
594	19839	332	республика Башкортостан, Уфа, Суворова, 35	f	large
327	19640	64	республика Башкортостан, Уфа, Суворова, 10	f	large
326	19640	63	республика Башкортостан, Уфа, Суворова, 10	f	large
394	19696	131	республика Башкортостан, Уфа, Степана Кувыкина, 5/2	f	large
393	19696	130	республика Башкортостан, Уфа, Степана Кувыкина, 5/2	f	large
384	19690	121	республика Башкортостан, Уфа, Степана Кувыкина, 29/1	f	large
392	19690	129	республика Башкортостан, Уфа, Степана Кувыкина, 29/1	f	large
667	19901	405	республика Башкортостан, Уфа, Степана Злобина, 5	f	large
662	19896	400	республика Башкортостан, Уфа, Степана Злобина, 22/2	f	large
490	19769	228	республика Башкортостан, Уфа, Станиславского, 43	f	large
313	19631	50	республика Башкортостан, Уфа, Стадионная, 11	f	large
312	19630	49	республика Башкортостан, Уфа, Стадионная, 9	f	large
346	19654	83	республика Башкортостан, Уфа, Спартака, 13	f	large
345	19654	82	республика Башкортостан, Уфа, Спартака, 13	f	large
382	19688	119	республика Башкортостан, Уфа, Сочинская, 15	f	large
413	19709	150	республика Башкортостан, Уфа, Софьи Перовской, 21/4	f	large
401	19702	138	республика Башкортостан, Уфа, Софьи Перовской, 75	f	large
402	19702	139	республика Башкортостан, Уфа, Софьи Перовской, 75	f	large
309	19628	46	республика Башкортостан, Уфа, Сосновская, 1/3	f	large
541	19796	279	республика Башкортостан, Уфа, Советская, 13/1	f	large
575	19823	313	республика Башкортостан, Уфа, Советская, 54	f	medium
316	19633	53	республика Башкортостан, Уфа, Советов, 27	f	large
551	19803	289	Россия, республика Башкортостан, Уфа, Славы бульвар, 6	f	large
507	19778	245	республика Башкортостан, Уфа, Сипайловская, 14	f	large
506	19778	244	республика Башкортостан, Уфа, Сипайловская, 14	f	large
505	19778	243	республика Башкортостан, Уфа, Сипайловская, 14	f	large
442	19733	180	республика Башкортостан, Уфа, Силикатная, 3	f	large
305	19624	42	республика Башкортостан, Уфа, Сельская Богородская, 37	f	large
304	19623	41	республика Башкортостан, Уфа, Сельская Богородская, 45/1	f	large
565	19814	303	республика Башкортостан, Уфа, Северодвинская, 22	f	large
599	19843	337	республика Башкортостан, Уфа, Свободы, 44	f	large
598	19843	336	республика Башкортостан, Уфа, Свободы, 44	f	large
334	19647	71	республика Башкортостан, Уфа, Свободы, 24/1	f	large
354	19662	91	республика Башкортостан, Уфа, Свердлова, 51	f	large
1331	20521	1061	Россия, республика Башкортостан, Баймакский район	f	small
647	19883	385	республика Башкортостан, Уфа, Сагита Агиша, 16	f	large
646	19882	384	республика Башкортостан, Уфа, Сагита Агиша, 16/1	f	large
65606	19811	299	республика Башкортостан, Уфа, Российская, 31	f	\N
555	19806	293	республика Башкортостан, Уфа, Российская, 54	f	large
487	19767	225	республика Башкортостан, Уфа, Российская, 37	f	large
486	19766	224	республика Башкортостан, Уфа, Российская, 41/3	f	large
485	19765	223	республика Башкортостан, Уфа, Российская, 80	f	large
484	19765	222	республика Башкортостан, Уфа, Российская, 80	f	large
483	19764	221	республика Башкортостан, Уфа, Российская, 90	f	large
482	19764	220	республика Башкортостан, Уфа, Российская, 90	f	large
481	19762	219	республика Башкортостан, Уфа, Российская, 163/1	f	large
480	19761	218	республика Башкортостан, Уфа, Российская, 171/1	f	large
479	19760	217	республика Башкортостан, Уфа, Российская, 100/3	f	large
628	19867	366	республика Башкортостан, Уфа, Рихарда Зорге, 10/1	f	large
627	19867	365	республика Башкортостан, Уфа, Рихарда Зорге, 10/1	f	large
469	19751	207	республика Башкортостан, Уфа, Рихарда Зорге, 50	f	large
468	19751	206	республика Башкортостан, Уфа, Рихарда Зорге, 50	f	large
467	19751	205	республика Башкортостан, Уфа, Рихарда Зорге, 50	f	large
462	19748	200	республика Башкортостан, Уфа, Рихарда Зорге, 27	f	large
461	19748	199	республика Башкортостан, Уфа, Рихарда Зорге, 27	f	large
460	19747	198	республика Башкортостан, Уфа, Рихарда Зорге, 17/1	f	large
680	19914	418	республика Башкортостан, Уфа, Революционная, 156/1	f	large
676	19910	414	республика Башкортостан, Уфа, Революционная, 169	f	large
674	19908	412	республика Башкортостан, Уфа, Революционная, 171	f	large
65609	19887	390	республика Башкортостан, Уфа, Революционная, 88	f	\N
651	19886	389	республика Башкортостан, Уфа, Революционная, 96/2	f	large
403	19703	140	республика Башкортостан, Уфа, Рабкоров, 16/1	f	large
395	19697	132	республика Башкортостан, Уфа, Рабкоров, 8/1	f	large
405	19695	142	республика Башкортостан, Уфа, Рабкоров, 13	f	large
391	19695	128	республика Башкортостан, Уфа, Рабкоров, 13	f	large
438	19730	176	республика Башкортостан, Уфа, Пушкина, 35/2	f	medium
361	19668	98	республика Башкортостан, Уфа, Пушкина, 108	f	medium
681	19915	419	республика Башкортостан, Уфа, Привокзальная площадь, 3	f	small
271	19597	8	республика Башкортостан, Уфа, Правды, 18	f	large
268	19594	5	республика Башкортостан, Уфа, Правды, 25	f	large
373	19680	110	республика Башкортостан, Уфа, Посадская, 26	f	large
612	19854	350	республика Башкортостан, Уфа, Подвойского, 7	f	large
580	19828	318	республика Башкортостан, Уфа, Победы, 24	f	large
318	19635	55	Россия, республика Башкортостан, Уфа, Плеханова бульвар, 7/1	f	large
317	19634	54	Россия, республика Башкортостан, Уфа, Плеханова бульвар, 5/1	f	large
306	19625	43	республика Башкортостан, Уфа, Петрозаводская, 10в	f	large
585	19832	323	республика Башкортостан, Уфа, Первомайская, 47	f	large
584	19832	322	республика Башкортостан, Уфа, Первомайская, 47	f	large
574	19817	312	республика Башкортостан, Уфа, Первомайская, 14	f	large
568	19817	306	республика Башкортостан, Уфа, Первомайская, 14	f	large
335	19648	72	республика Башкортостан, Уфа, Первомайская, 83а	f	large
464	19749	202	республика Башкортостан, Уфа, Парковая, 12/1	f	large
463	19749	201	республика Башкортостан, Уфа, Парковая, 12/1	f	large
281	19607	18	республика Башкортостан, Уфа, Островского, 16	f	large
331	19644	68	республика Башкортостан, Уфа, Орджоникидзе, 4	f	large
411	19707	148	республика Башкортостан, Уфа, Онежская, 1	f	large
315	19632	52	республика Башкортостан, Уфа, Олимпийская, 8	f	large
314	19632	51	республика Башкортостан, Уфа, Олимпийская, 8	f	large
640	19879	378	Россия, республика Башкортостан, Уфа, Октября проспект, 50/2	f	large
631	19870	369	Россия, республика Башкортостан, Уфа, Октября проспект, 23/4	f	large
558	19808	296	Россия, республика Башкортостан, Уфа, Октября проспект, 174	f	large
557	19808	295	Россия, республика Башкортостан, Уфа, Октября проспект, 174	f	large
554	19805	292	Россия, республика Башкортостан, Уфа, Октября проспект, 137	f	large
548	19801	286	Россия, республика Башкортостан, Уфа, Октября проспект, 93/5	f	large
547	19801	285	Россия, республика Башкортостан, Уфа, Октября проспект, 93/5	f	large
546	19800	284	Россия, республика Башкортостан, Уфа, Октября проспект, 91	f	large
545	19800	283	Россия, республика Башкортостан, Уфа, Октября проспект, 91	f	large
475	19756	213	Россия, республика Башкортостан, Уфа, Октября проспект, 74/2	f	large
65604	19753	209	Россия, республика Башкортостан, Уфа, Октября проспект, 71	f	\N
470	19752	208	Россия, республика Башкортостан, Уфа, Октября проспект, 67	f	large
374	19681	111	республика Башкортостан, Уфа, Октябрьской Революции, 55	f	large
572	19821	310	республика Башкортостан, Уфа, Новочеркасская, 11	f	medium
400	19701	137	республика Башкортостан, Уфа, Новая, 3	f	small
655	19889	393	республика Башкортостан, Уфа, Николая Дмитриева, 13/1	f	large
654	19889	392	республика Башкортостан, Уфа, Николая Дмитриева, 13/1	f	large
650	19885	388	республика Башкортостан, Уфа, Николая Дмитриева, 19/1	f	medium
649	19885	387	республика Башкортостан, Уфа, Николая Дмитриева, 19/1	f	large
445	19735	183	республика Башкортостан, Уфа, Нехаева, 94	f	large
444	19735	182	республика Башкортостан, Уфа, Нехаева, 94	f	medium
576	19824	314	республика Башкортостан, Уфа, Нежинская, 13	f	large
567	19816	305	республика Башкортостан, Уфа, Нежинская, 4	f	large
343	19652	80	республика Башкортостан, Уфа, Нежинская, 51	f	large
342	19652	79	республика Башкортостан, Уфа, Нежинская, 51	f	large
536	19791	274	республика Башкортостан, Уфа, Набережная р.Уфы, 51/1	f	large
535	19791	273	республика Башкортостан, Уфа, Набережная р.Уфы, 51/1	f	large
427	19723	165	республика Башкортостан, Уфа, Мустая Карима, 53/55	f	large
274	19600	11	республика Башкортостан, Уфа, Мусоргского, 2А	f	large
410	19706	147	республика Башкортостан, Уфа, Мубарякова, 14	f	large
409	19706	146	республика Башкортостан, Уфа, Мубарякова, 14	f	large
408	19704	145	республика Башкортостан, Уфа, Мубарякова, 20/1	f	large
404	19704	141	республика Башкортостан, Уфа, Мубарякова, 20/1	f	large
3455	22680	3234	республика Башкортостан, Уфа, Молодежная, 3	f	small
3442	22667	3221	республика Башкортостан, Уфа, Молодежная, 1	f	small
3450	22675	3229	республика Башкортостан, Уфа, Молодежная, 5	f	small
665	19899	403	республика Башкортостан, Уфа, Минигали Губайдуллина, 27	f	large
65611	19909	413	республика Башкортостан, Уфа, Мингажева, 160	f	\N
672	19906	410	республика Башкортостан, Уфа, Мингажева, 138а	f	large
372	19679	109	республика Башкортостан, Уфа, Мингажева, 107/1	f	large
371	19678	108	республика Башкортостан, Уфа, Мингажева, 126	f	medium
622	19863	360	республика Башкортостан, Уфа, Миасская, 22	f	large
658	19892	396	республика Башкортостан, Уфа, Менделеева, 177/3	f	large
657	19891	395	республика Башкортостан, Уфа, Менделеева, 148	f	large
500	19775	238	республика Башкортостан, Уфа, Менделеева, 215/3	f	large
499	19775	237	республика Башкортостан, Уфа, Менделеева, 215/3	f	large
498	19775	236	республика Башкортостан, Уфа, Менделеева, 215/3	f	large
496	19773	234	республика Башкортостан, Уфа, Менделеева, 203	f	large
495	19772	233	республика Башкортостан, Уфа, Менделеева, 197/1	f	large
494	19772	232	республика Башкортостан, Уфа, Менделеева, 197/1	f	large
493	19772	231	республика Башкортостан, Уфа, Менделеева, 197/1	f	large
383	19689	120	республика Башкортостан, Уфа, Менделеева, 41	f	large
381	19682	118	республика Башкортостан, Уфа, Менделеева, 7/2	f	large
375	19682	112	республика Башкортостан, Уфа, Менделеева, 7/2	f	large
344	19653	81	республика Башкортостан, Уфа, Маяковского, 3	f	large
332	19645	69	республика Башкортостан, Уфа, Машиностроителей, 10	f	large
570	19819	308	республика Башкортостан, Уфа, Матвея Пинского, 12	f	large
441	19732	179	республика Башкортостан, Уфа, Малая Трактовая, 199	f	medium
284	19610	21	республика Башкортостан, Уфа, Майкопская, 58	f	large
435	19728	173	республика Башкортостан, Уфа, Мажита Гафури, 7	f	large
434	19728	172	республика Башкортостан, Уфа, Мажита Гафури, 7	f	large
279	19605	16	республика Башкортостан, Уфа, Магистральная, 27/3	f	large
556	19807	294	республика Башкортостан, Уфа, Львовская, 4	f	large
458	19745	196	республика Башкортостан, Уфа, Летчиков, 8/2	f	large
457	19745	195	республика Башкортостан, Уфа, Летчиков, 8/2	f	large
620	19861	358	республика Башкортостан, Уфа, Ленина, 61	f	large
615	19857	353	республика Башкортостан, Уфа, Ленина, 127а	f	large
619	19857	357	республика Башкортостан, Уфа, Ленина, 127а	f	large
426	19722	164	республика Башкортостан, Уфа, Ленина, 25/29	f	large
363	19670	100	республика Башкортостан, Уфа, Ленина, 50	f	large
362	19669	99	республика Башкортостан, Уфа, Ленина, 26	f	large
359	19666	96	республика Башкортостан, Уфа, Ленина, 3	f	large
283	19609	20	республика Башкортостан, Уфа, Левитана, 36	f	large
282	19608	19	республика Башкортостан, Уфа, Левитана, 24	f	large
267	19593	4	республика Башкортостан, Уфа, Левитана, 12	f	large
266	19593	3	республика Башкортостан, Уфа, Левитана, 12	f	large
366	19673	103	республика Башкортостан, Уфа, Кустарная, 17	f	large
587	19834	325	республика Башкортостан, Уфа, Кулибина, 38	f	large
430	19725	168	республика Башкортостан, Уфа, Красина, 33	f	large
569	19818	307	республика Башкортостан, Уфа, Космонавтов, 8/2	f	large
571	19820	309	республика Башкортостан, Уфа, Конституции, 2а	f	large
648	19884	386	республика Башкортостан, Уфа, Комсомольская, 14	f	large
639	19877	377	республика Башкортостан, Уфа, Комсомольская, 33	f	large
638	19877	376	республика Башкортостан, Уфа, Комсомольская, 33	f	large
634	19873	372	республика Башкортостан, Уфа, Комсомольская, 23/3	f	large
501	19776	239	республика Башкортостан, Уфа, Комсомольская, 138	f	large
478	19759	216	республика Башкортостан, Уфа, Комсомольская, 165/2	f	large
477	19758	215	республика Башкортостан, Уфа, Комсомольская, 165/1	f	large
476	19757	214	республика Башкортостан, Уфа, Комсомольская, 161/2	f	large
474	19755	212	республика Башкортостан, Уфа, Комсомольская, 137	f	large
473	19754	211	республика Башкортостан, Уфа, Комсомольская, 113	f	large
472	19754	210	республика Башкортостан, Уфа, Комсомольская, 113	f	large
3460	22686	3239	республика Башкортостан, Уфа, Коммунистическая, 59	f	large
433	19727	171	республика Башкортостан, Уфа, Коммунистическая, 16	f	large
605	19847	343	республика Башкортостан, Уфа, Коммунаров, 69/3	f	large
604	19847	342	республика Башкортостан, Уфа, Коммунаров, 69/3	f	large
333	19646	70	республика Башкортостан, Уфа, Коммунаров, 12а	f	large
588	19835	326	республика Башкортостан, Уфа, Кольцевая, 143	f	large
586	19833	324	республика Башкортостан, Уфа, Кольцевая, 105	f	large
578	19826	316	республика Башкортостан, Уфа, Кольцевая, 49	f	large
577	19825	315	республика Башкортостан, Уфа, Кольцевая, 37	f	large
320	19636	57	республика Башкортостан, Уфа, Кольцевая, 200	f	large
319	19636	56	республика Башкортостан, Уфа, Кольцевая, 200	f	large
364	19671	101	республика Башкортостан, Уфа, Кирова, 15	f	large
428	19721	166	республика Башкортостан, Уфа, Кирова, 1	f	large
425	19721	163	республика Башкортостан, Уфа, Кирова, 1	f	large
3412	22641	3196	республика Башкортостан, Уфа, Кирова, 5	f	large
446	19736	184	республика Башкортостан, Уфа, Кирзаводская, 1/3	f	large
311	19629	48	республика Башкортостан, Уфа, Касимовская, 10/2	f	large
310	19629	47	республика Башкортостан, Уфа, Касимовская, 10/2	f	large
621	19862	359	республика Башкортостан, Уфа, Карла Маркса, 50	f	medium
613	19855	351	республика Башкортостан, Уфа, Карла Маркса, 69	f	large
429	19724	167	республика Башкортостан, Уфа, Карла Маркса, 35	f	large
645	19881	383	республика Башкортостан, Уфа, Казанская, 10а	f	large
399	19700	136	республика Башкортостан, Уфа, Искинская, 59/2	f	medium
329	19642	66	республика Башкортостан, Уфа, Интернациональная, 157	f	large
325	19639	62	республика Башкортостан, Уфа, Интернациональная, 183	f	large
617	19859	355	Россия, республика Башкортостан, Уфа, Ибрагимова бульвар, 41	f	large
376	19683	113	республика Башкортостан, Уфа, Зои Космодемьянской, 38	f	large
432	19726	170	республика Башкортостан, Уфа, Зенцова, 51	f	large
431	19726	169	республика Башкортостан, Уфа, Зенцова, 51	f	large
450	19740	188	республика Башкортостан, Уфа, Защитников Отечества, 17	f	large
614	19856	352	республика Башкортостан, Уфа, Запотоцкого, 48	f	large
357	19665	94	республика Башкортостан, Уфа, Заки Валиди, 32	f	large
358	19665	95	республика Башкортостан, Уфа, Заки Валиди, 32	f	large
398	19698	135	республика Башкортостан, Уфа, Загира Исмагилова, 1	f	large
396	19698	133	республика Башкортостан, Уфа, Загира Исмагилова, 1	f	large
633	19872	371	республика Башкортостан, Уфа, Железняцкая, 35	f	large
412	19708	149	Россия, республика Башкортостан, Уфа, Дуванский бульвар, 22/2	f	large
671	19905	409	республика Башкортостан, Уфа, Достоевского, 99а	f	large
424	19720	162	республика Башкортостан, Уфа, Достоевского, 67	f	large
423	19720	161	республика Башкортостан, Уфа, Достоевского, 67	f	large
597	19842	335	республика Башкортостан, Уфа, Дмитрия Донского, 87	f	large
378	19685	115	республика Башкортостан, Уфа, Демская, 2	f	medium
65607	19810	300	республика Башкортостан, Уфа, Даута Юлтыя, 6	f	\N
560	19810	298	республика Башкортостан, Уфа, Даута Юлтыя, 6	f	large
273	19599	10	республика Башкортостан, Уфа, Дагестанская, 15/1	f	large
340	19651	77	республика Башкортостан, Уфа, Гончарова, 19	f	large
339	19651	76	республика Башкортостан, Уфа, Гончарова, 19	f	large
341	19650	78	республика Башкортостан, Уфа, Гончарова, 5	f	large
338	19650	75	республика Башкортостан, Уфа, Гончарова, 5	f	large
264	19591	1	республика Башкортостан, Уфа, Глазовская, 38А	f	medium
301	19620	38	республика Башкортостан, Уфа, Георгия Мушникова, 17/1	f	large
300	19620	37	республика Башкортостан, Уфа, Георгия Мушникова, 17/1	f	large
299	19620	36	республика Башкортостан, Уфа, Георгия Мушникова, 17/1	f	large
440	19731	178	республика Башкортостан, Уфа, Гафури, 103	f	large
439	19731	177	республика Башкортостан, Уфа, Гафури, 103	f	large
349	19657	86	республика Башкортостан, Уфа, Галечная, 7	f	medium
443	19734	181	республика Башкортостан, Уфа, Выгонная, 10	f	large
602	19845	340	республика Башкортостан, Уфа, Вологодская, 64/1	f	large
601	19845	339	республика Башкортостан, Уфа, Вологодская, 64/1	f	large
600	19844	338	республика Башкортостан, Уфа, Вологодская, 76/2	f	large
596	19841	334	республика Башкортостан, Уфа, Вологодская, 29	f	large
595	19840	333	республика Башкортостан, Уфа, Вологодская, 58	f	large
1635	20781	1321	республика Башкортостан, Уфа, Вокзальная, 7	f	large
678	19912	416	республика Башкортостан, Уфа, Владивостокская, 5	f	large
603	19846	341	республика Башкортостан, Уфа, Борисоглебская, 12	f	large
592	19838	330	республика Башкортостан, Уфа, Борисоглебская, 17	f	large
591	19837	329	республика Башкортостан, Уфа, Борисоглебская, 32	f	large
590	19836	328	республика Башкортостан, Уфа, Борисоглебская, 16	f	large
589	19836	327	республика Башкортостан, Уфа, Борисоглебская, 16	f	large
553	19804	291	республика Башкортостан, Уфа, Блюхера, 25	f	large
552	19804	290	республика Башкортостан, Уфа, Блюхера, 25	f	large
550	19802	288	республика Башкортостан, Уфа, Блюхера, 9	f	large
549	19802	287	республика Башкортостан, Уфа, Блюхера, 9	f	large
573	19822	311	республика Башкортостан, Уфа, Биологическая, 35	f	small
616	19858	354	республика Башкортостан, Уфа, Белякова, 25/1	f	large
540	19795	278	республика Башкортостан, Уфа, Белоозерская, 57	f	small
520	19784	258	республика Башкортостан, Уфа, Баязита Бикбая, 31/1	f	large
519	19784	257	республика Башкортостан, Уфа, Баязита Бикбая, 31/1	f	large
518	19784	256	республика Башкортостан, Уфа, Баязита Бикбая, 31/1	f	large
389	19694	126	республика Башкортостан, Уфа, Батырская, 8/3	f	large
388	19694	125	республика Башкортостан, Уфа, Батырская, 8/3	f	large
390	19693	127	республика Башкортостан, Уфа, Батырская, 4/2	f	large
387	19693	124	республика Башкортостан, Уфа, Батырская, 4/2	f	large
630	19869	368	республика Башкортостан, Уфа, Бабушкина, 23	f	large
629	19868	367	республика Башкортостан, Уфа, Бабушкина, 21	f	large
455	19743	193	республика Башкортостан, Уфа, Ахметова, 320	f	large
454	19742	192	республика Башкортостан, Уфа, Ахметова, 275	f	large
453	19742	191	республика Башкортостан, Уфа, Ахметова, 275	f	large
452	19741	190	республика Башкортостан, Уфа, Ахметова, 306	f	large
451	19741	189	республика Башкортостан, Уфа, Ахметова, 306	f	large
449	19739	187	республика Башкортостан, Уфа, Ахметова, 207	f	large
664	19898	402	республика Башкортостан, Уфа, Акназарова, 24	f	large
537	19792	275	республика Башкортостан, Уфа, Академика Королева, 25	f	large
528	19787	266	республика Башкортостан, Уфа, Академика Королева, 13/1	f	large
527	19787	265	республика Башкортостан, Уфа, Академика Королева, 13/1	f	large
526	19787	264	республика Башкортостан, Уфа, Академика Королева, 13/1	f	large
564	19813	302	республика Башкортостан, Уфа, Адмирала Макарова, 20	f	large
407	19705	144	республика Башкортостан, Уфа, Авроры, 17/1	f	large
406	19705	143	республика Башкортостан, Уфа, Авроры, 17/1	f	large
416	19712	153	республика Башкортостан, Уфа, Авроры, 18/2, Санаторий Зелёная Роща	f	small
673	19907	411	республика Башкортостан, Уфа, 8 Марта, 3	f	large
670	19904	408	республика Башкортостан, Уфа, 50-летия Октября, 14/1	f	large
632	19871	370	республика Башкортостан, Уфа, 50-летия Октября, 24	f	large
625	19864	363	республика Башкортостан, Уфа, 50-летия Октября, 7А	f	large
623	19864	361	республика Башкортостан, Уфа, 50-летия Октября, 7А	f	large
642	19880	380	республика Башкортостан, Уфа, 50 Лет СССР, 10	f	large
641	19880	379	республика Башкортостан, Уфа, 50 Лет СССР, 10	f	large
491	19770	229	республика Башкортостан, Уфа, 50 Лет СССР, 30/5	f	large
538	19793	276	республика Башкортостан, Уфа, Юрия Гагарина, 59	f	large
65608	19812	301	республика Башкортостан, Уфа, Шота Руставели, 24	f	\N
322	19637	59	республика Башкортостан, Уфа, улица Черниковская, 59/1	f	large
321	19637	58	республика Башкортостан, Уфа, улица Черниковская, 59/1	f	large
65601	19699	134	республика Башкортостан, Уфа, Пугачева, 112/1	f	\N
3447	22672	3226	республика Башкортостан, Уфа, Молодежная, 2	f	small
447	19737	185	республика Башкортостан, Уфа, Лесозаводская, 1а	f	large
653	19888	391	республика Башкортостан, Уфа, Кирова, 97/2	f	large
286	19612	23	республика Башкортостан, Уфа, Дагестанская, 10/2	f	large
65599	19606	17	республика Башкортостан, Уфа, Грозненская, 69/3	f	\N
533	19790	271	республика Башкортостан, Уфа, Гагарина, 50/3	f	large
534	19790	272	республика Башкортостан, Уфа, Гагарина, 50/3	f	large
532	19790	270	республика Башкортостан, Уфа, Гагарина, 50/3	f	large
1018	20224	755	республика Башкортостан, село Утяганово, Центральная, 5	f	small
1594	20794	1334	республика Башкортостан, село Усмангали, Ленина, 31	f	small
721	19948	458	республика Башкортостан, поселок Уршак, Строителей, 18	f	large
1208	20395	936	республика Башкортостан, село Урмиязы, Ленина, 21	f	small
2385	21557	2104	республика Башкортостан, село Урметово, Р.Хайри, 64А	f	small
2554	21721	2273	республика Башкортостан, село Ургуш, Корочкина, 25	f	medium
1366	20555	1096	республика Башкортостан, село Умирово, Октябрьская, 2	f	small
3607	22831	3386	республика Башкортостан, село Удряк, Школьная, 5	f	small
3158	22323	2876	республика Башкортостан, село Тятербаш, Школьная, 9А	f	small
3294	22519	3073	республика Башкортостан, село Тюменяк, Клубная, 2	f	medium
2806	21975	2523	республика Башкортостан, село Тюканово 2-е, Интернациональная, 32	f	small
1444	20633	1174	республика Башкортостан, село Тыканово, Октябрьская, 21	f	small
3233	22459	3012	республика Башкортостан, Туймазы, проспект Ленина, 3	f	large
3229	22455	3008	республика Башкортостан, Туймазы, проспект Ленина, 2В	f	large
3236	22463	3015	республика Башкортостан, Туймазы, площадь Октября, 3	f	large
3223	22449	3002	республика Башкортостан, Туймазы, микрорайон Молодежный, 14	f	large
65621	20074	597	республика Башкортостан, Салават, Губкина, 14/82	f	\N
3222	22448	3001	республика Башкортостан, Туймазы, микрорайон Молодежный, 4	f	large
3219	22445	2998	республика Башкортостан, Туймазы, Южная, 34А	f	large
3220	22446	2999	республика Башкортостан, Туймазы, Чехова, 2А	f	large
3237	22464	3016	республика Башкортостан, Туймазы, Чапаева, 14	f	large
3239	22466	3018	республика Башкортостан, Туймазы, Советская, 40	f	large
3225	22451	3004	республика Башкортостан, Туймазы, Советская, 14	f	large
3221	22447	3000	республика Башкортостан, Туймазы, С.Юлаева, 83	f	large
3227	22453	3006	республика Башкортостан, Туймазы, Островского, 9В	f	large
3226	22452	3005	республика Башкортостан, Туймазы, Ленина, 34	f	large
3234	22460	3013	республика Башкортостан, Туймазы, Комарова, 25	f	large
3230	22456	3009	республика Башкортостан, Туймазы, Комарова, 8Б	f	large
3241	22468	3020	республика Башкортостан, Туймазы, Зеленая, 4	f	large
3238	22465	3017	республика Башкортостан, Туймазы, Губкина, 1	f	large
3240	22467	3019	республика Башкортостан, Туймазы, Гафурова, 31А	f	large
1914	21093	1638	республика Башкортостан, село Тугаряково, Садовая, 25	f	small
1808	20989	1533	республика Башкортостан, поселок Тугай, Луговая, 16/2	f	medium
1436	20625	1166	республика Башкортостан, село Тошкурово, Центральная, 6	f	small
1623	20810	1350	республика Башкортостан, поселок Тирлянский, Полуэктова, 8	f	medium
2805	21974	2522	республика Башкортостан, село Тимербаево, Центральная, 106	f	small
1910	21089	1634	республика Башкортостан, село Тепляки, Мелиораторов, 1	f	small
3665	22888	3445	республика Башкортостан, село Темяково, Рабочая, 2А	f	small
1070	20269	803	республика Башкортостан, село Таштимерово, Коммунистическая, 25/1	f	small
727	19954	464	республика Башкортостан, село Ташкиново, Чеверева, 7а	f	large
3033	22197	2751	республика Башкортостан, село Таукай-Гайна, Школьная, 7	f	small
2143	21321	1866	республика Башкортостан, село Таубаш-Бадраково, Октябрьской Революции, 11А	f	small
3109	22273	2827	республика Башкортостан, село Татарский Малояз, Школьная, 5	f	small
3568	22793	3347	республика Башкортостан, село Таскаклы, Ф. Алтайского, 32	f	small
3331	22557	3110	республика Башкортостан, село Таптыково, Центральная, 22	f	medium
3016	22180	2734	республика Башкортостан, село Тамьян-Таймас, Советская, 1А	f	small
1395	20584	1125	республика Башкортостан, село Таллы-Сыза, Родниковая, 1А	f	small
3150	22315	2868	республика Башкортостан, село Табулда, Комсомольская, 14	f	small
1396	20585	1126	республика Башкортостан, село Суюндюково, Нагорная, 1А	f	small
2595	21762	2314	республика Башкортостан, деревня Суук-Чишма, Пушкина, 22А	f	small
2174	21349	1894	республика Башкортостан, село Суерметово, Комсомольская, 36	f	small
1260	20450	990	республика Башкортостан, село Субханкулово, Ленина, 31А	f	small
3306	22530	3085	республика Башкортостан, поселок Стуколкино, Школьная, 16	f	medium
979	20187	716	республика Башкортостан, Стерлитамак, проспект Октября, 5А	f	large
976	20184	713	республика Башкортостан, Стерлитамак, проспект Октября, 35	f	large
975	20183	712	республика Башкортостан, Стерлитамак, проспект Октября, 41	f	large
973	20181	710	республика Башкортостан, Стерлитамак, проспект Октября, 69	f	large
968	20176	705	республика Башкортостан, Стерлитамак, проспект Октября, 16А	f	large
955	20163	692	республика Башкортостан, Стерлитамак, проспект Ленина, 30В	f	large
949	20157	686	республика Башкортостан, Стерлитамак, проспект Ленина, 61	f	large
948	20156	685	республика Башкортостан, Стерлитамак, проспект Ленина, 47	f	large
945	20153	682	республика Башкортостан, Стерлитамак, проспект Ленина, 37	f	large
944	20152	681	республика Башкортостан, Стерлитамак, проспект Ленина, 18	f	large
939	20147	676	республика Башкортостан, Стерлитамак, проспект Ленина, 2А	f	large
909	20117	646	республика Башкортостан, Стерлитамак, Южная, 20	f	large
901	20110	638	республика Башкортостан, Стерлитамак, Южная, 148	f	large
947	20155	684	республика Башкортостан, Стерлитамак, Элеваторная, 80	f	large
906	20114	643	республика Башкортостан, Стерлитамак, Шафиева, 9	f	large
905	20113	642	республика Башкортостан, Стерлитамак, Шафиева, 23	f	large
904	20113	641	республика Башкортостан, Стерлитамак, Шафиева, 23	f	large
960	20168	697	республика Башкортостан, Стерлитамак, Шаймуратова, 9	f	large
959	20167	696	республика Башкортостан, Стерлитамак, Шаймуратова, 5а	f	large
925	20133	662	республика Башкортостан, Стерлитамак, Чехова, 8	f	large
924	20085	661	республика Башкортостан, Стерлитамак, Чехова, 12	f	large
1006	20212	743	республика Башкортостан, Стерлитамак, Худайбердина, 216	f	medium
963	20171	700	республика Башкортостан, Стерлитамак, Худайбердина, 149	f	large
962	20170	699	республика Башкортостан, Стерлитамак, Худайбердина, 196	f	large
961	20169	698	республика Башкортостан, Стерлитамак, Худайбердина, 194	f	large
956	20164	693	республика Башкортостан, Стерлитамак, Худайбердина, 101А	f	large
915	20123	652	республика Башкортостан, Стерлитамак, Худайбердина, 50	f	large
914	20122	651	республика Башкортостан, Стерлитамак, Худайбердина, 18	f	large
908	20116	645	республика Башкортостан, Стерлитамак, Худайбердина, 58	f	large
907	20115	644	республика Башкортостан, Стерлитамак, Худайбердина, 74	f	large
912	20120	649	республика Башкортостан, Стерлитамак, Фучика, 1	f	large
932	20140	669	республика Башкортостан, Стерлитамак, Тукаева, 2Д	f	large
931	20139	668	республика Башкортостан, Стерлитамак, Тукаева, 2Г	f	large
929	20137	666	республика Башкортостан, Стерлитамак, Тукаева, 9	f	large
1002	20208	739	республика Башкортостан, Стерлитамак, Суханова, 4	f	large
1001	20207	738	республика Башкортостан, Стерлитамак, Стерлибашевский тракт, 39	f	large
897	20106	634	республика Башкортостан, Стерлитамак, Стерлибашевский тракт, 29	f	large
933	20141	670	республика Башкортостан, Стерлитамак, Социалистическая, 25	f	large
930	20138	667	республика Башкортостан, Стерлитамак, Социалистическая, 21	f	large
928	20136	665	республика Башкортостан, Стерлитамак, Социалистическая, 5	f	large
918	20126	655	республика Башкортостан, Стерлитамак, Сакко и Ванцетти, 68	f	large
903	20112	640	республика Башкортостан, Стерлитамак, Сазонова, 16А	f	large
943	20151	680	республика Башкортостан, Стерлитамак, Революционная, 9А	f	large
951	20159	688	республика Башкортостан, Стерлитамак, Проспект Ленина, 69	f	large
950	20158	687	республика Башкортостан, Стерлитамак, Проспект Ленина, 81б	f	large
900	20109	637	республика Башкортостан, Стерлитамак, Полевая, 29	f	large
922	20130	659	республика Башкортостан, Стерлитамак, Паровозная, 3А	f	large
982	20189	719	республика Башкортостан, Стерлитамак, Островского, 2	f	large
902	20111	639	республика Башкортостан, Стерлитамак, Оренбургский тракт, 24	f	medium
971	20179	708	республика Башкортостан, Стерлитамак, Октября проспект, 2	f	large
938	20146	675	республика Башкортостан, Стерлитамак, Одесская, 4	f	large
958	20166	695	республика Башкортостан, Стерлитамак, Николаева, 2А	f	large
941	20149	678	республика Башкортостан, Стерлитамак, Николаева, 7	f	large
940	20148	677	республика Башкортостан, Стерлитамак, Николаева, 124	f	large
913	20121	650	республика Башкортостан, Стерлитамак, Мира, 47	f	large
935	20143	672	республика Башкортостан, Стерлитамак, Макаренко, 1	f	large
927	20135	664	республика Башкортостан, Стерлитамак, Лесная, 20	f	large
953	20161	690	республика Башкортостан, Стерлитамак, Ленина проспект, 28Б	f	large
978	20186	715	республика Башкортостан, Стерлитамак, Л. Толстого, 9	f	large
983	20190	720	республика Башкортостан, Стерлитамак, Курчатова, 36	f	large
970	20178	707	республика Башкортостан, Стерлитамак, Курчатова, 3	f	large
969	20177	706	республика Башкортостан, Стерлитамак, Курчатова, 14	f	large
997	20204	734	республика Башкортостан, Стерлитамак, Коммунистическая, 82	f	large
996	20203	733	республика Башкортостан, Стерлитамак, Коммунистическая, 84	f	large
991	20198	728	республика Башкортостан, Стерлитамак, Коммунистическая, 104	f	large
989	20196	726	республика Башкортостан, Стерлитамак, Коммунистическая, 40	f	large
967	20175	704	республика Башкортостан, Стерлитамак, Коммунистическая, 23	f	large
966	20174	703	республика Башкортостан, Стерлитамак, Коммунистическая, 43	f	large
965	20173	702	республика Башкортостан, Стерлитамак, Коммунистическая, 10	f	large
942	20150	679	республика Башкортостан, Стерлитамак, Коммунистическая, 8	f	large
977	20185	714	республика Башкортостан, Стерлитамак, Комарова, 2	f	large
926	20134	663	республика Башкортостан, Стерлитамак, К. Маркса, 150	f	large
916	20124	653	республика Башкортостан, Стерлитамак, К. Маркса, 125	f	medium
911	20119	648	республика Башкортостан, Стерлитамак, К. Маркса, 54	f	large
1003	20209	740	республика Башкортостан, Стерлитамак, Ивлева, 9	f	medium
987	20194	724	республика Башкортостан, Стерлитамак, Ибрагимова, 1	f	large
986	20193	723	республика Башкортостан, Стерлитамак, Ибрагимова, 14	f	large
957	20165	694	республика Башкортостан, Стерлитамак, Дружбы, 37	f	large
954	20162	691	республика Башкортостан, Стерлитамак, Голикова, 24А	f	large
992	20199	729	республика Башкортостан, Стерлитамак, Гоголя, 122	f	large
899	20108	636	республика Башкортостан, Стерлитамак, Гоголя, 118	f	large
898	20107	635	республика Башкортостан, Стерлитамак, Гоголя, 147	f	large
952	20160	689	республика Башкортостан, Стерлитамак, Волочаевская, 15А	f	large
946	20154	683	республика Башкортостан, Стерлитамак, Волочаевская, 2	f	large
923	20131	660	республика Башкортостан, Стерлитамак, Вокзальная, 26А	f	large
921	20129	658	республика Башкортостан, Стерлитамак, Вокзальная, 2Г	f	large
920	20128	657	республика Башкортостан, Стерлитамак, Вокзальная, 2Д	f	large
917	20125	654	республика Башкортостан, Стерлитамак, Вокзальная, 2	f	large
936	20144	673	республика Башкортостан, Стерлитамак, Воинов-интернационалистов, 19	f	large
937	20145	674	республика Башкортостан, Стерлитамак, Бородина, 3	f	large
985	20192	722	республика Башкортостан, Стерлитамак, Блюхера, 15	f	large
984	20191	721	республика Башкортостан, Стерлитамак, Блюхера, 13	f	large
974	20182	711	республика Башкортостан, Стерлитамак, Блюхера, 10	f	large
1005	20211	742	республика Башкортостан, Стерлитамак, Артема, 146А	f	large
1000	20206	737	республика Башкортостан, Стерлитамак, Артема, 98	f	large
998	20200	735	республика Башкортостан, Стерлитамак, Артема, 115	f	large
993	20200	730	республика Башкортостан, Стерлитамак, Артема, 115	f	large
990	20197	727	республика Башкортостан, Стерлитамак, Артема, 71	f	large
972	20180	709	республика Башкортостан, Стерлитамак, Артема, 27	f	large
964	20172	701	республика Башкортостан, Стерлитамак, Артема, 13	f	large
981	20188	718	республика Башкортостан, Стерлитамак, А. Невского, 27	f	large
980	20188	717	республика Башкортостан, Стерлитамак, А. Невского, 27	f	large
910	20118	647	республика Башкортостан, Стерлитамак, 23 Мая, 18	f	large
988	20195	725	республика Башкортостан, Стерлитамак, Гоголя, 115	f	large
3199	22424	2978	республика Башкортостан, село Старый Курдым, Центральная, 23	f	small
3162	22327	2880	республика Башкортостан, село Старый Калкаш, Молодёжная, 1А	f	small
2551	21718	2270	республика Башкортостан, село Старый Акбуляк, Салавата, 44	f	small
2572	21740	2291	республика Башкортостан, деревня Старые Киешки, Октября, 34/1	f	medium
1439	20628	1169	республика Башкортостан, село Старые Каргалы, Школьная, 45	f	small
1354	20544	1084	республика Башкортостан, село Старые Балыклы, Миасара Басырова, 47А	f	small
2136	21315	1860	республика Башкортостан, село Старосултанбеково, Матросова, 15	f	small
2836	22004	2552	республика Башкортостан, село Старомурапталово, Школьная, 1А	f	small
2017	21197	1741	республика Башкортостан, село Старомрясово, Центральная, 1	f	small
1210	20397	938	республика Башкортостан, село Старокочкильдино, Комсомольская, 23	f	small
2110	21288	1834	республика Башкортостан, село Старокангышево, Ленина, 13	f	small
3555	22779	3334	республика Башкортостан, село Староихсаново, Днепр, 2	f	small
1384	20573	1114	республика Башкортостан, село Старогусево, Центральная, 51	f	small
3077	22241	2795	республика Башкортостан, село Старобедеево, Центральная, 70	f	small
2769	21938	2488	республика Башкортостан, село Старобаскаково, Школьная, 7	f	small
2607	21774	2326	республика Башкортостан, село Старобабичево, Садовая, 3	f	medium
1105	20304	838	республика Башкортостан, село Староаккулаево, Энгельса, 27	f	small
1258	20448	988	республика Башкортостан, село Староабсалямово, Ленина, 56А	f	small
2832	22000	2548	республика Башкортостан, село Старая Отрада, Дружбы, 61	f	small
2672	21840	2392	республика Башкортостан, село Старая Мушта, Молодёжная, 2	f	small
2538	21705	2257	республика Башкортостан, село Сосновый Бор, Школьная, 1	f	small
884	20094	625	республика Башкортостан, Сибай, проспект Горняков, 4	f	large
887	20097	629	республика Башкортостан, Сибай, Чайковского, 30	f	large
889	20084	614	республика Башкортостан, Сибай городской округ, Чайковского, 1	f	large
875	20084	613	республика Башкортостан, Сибай городской округ, Чайковского, 1	f	medium
876	20086	617	республика Башкортостан, Сибай, Цеткин, 10	f	large
894	20103	621	республика Башкортостан, Сибай, Старательская, 12а	f	large
896	20105	616	республика Башкортостан, Сибай, Сибаева, 45	f	large
880	20090	623	республика Башкортостан, Сибай, Маяковского, 18	f	large
879	20089	622	республика Башкортостан, Сибай, Ленина, 3	f	large
874	20083	611	республика Башкортостан, Сибай, Ленина, 40	f	large
886	20096	628	республика Башкортостан, Сибай, Кусимова, 7	f	large
890	20099	631	республика Башкортостан, Сибай, Заки Валиди, 55	f	large
882	20092	612	республика Башкортостан, Сибай, Заки Валиди, 53	f	large
891	20100	620	республика Башкортостан, Сибай, Достоевского, 4	f	medium
878	20088	619	республика Башкортостан, Сибай, Горького, 27	f	large
877	20087	618	республика Башкортостан, Сибай, Горького, 29	f	large
881	20091	624	республика Башкортостан, Сибай, Горняков проспект, 2	f	large
893	20102	633	республика Башкортостан, Сибай, Горная, 55	f	large
65624	20101	632	республика Башкортостан, Сибай, Горная, 40	f	\N
895	20104	615	республика Башкортостан, Сибай, Гаражная, 1	f	medium
888	20098	627	республика Башкортостан, Сибай, Белова, 21	f	large
885	20095	626	республика Башкортостан, Сибай, Белова, 36	f	large
3685	22908	3465	республика Башкортостан, село Сибады, Байман, 29	f	small
1043	20243	777	республика Башкортостан, село Селивановский, Центральная, 33	f	small
3202	22428	2981	республика Башкортостан, село Сараштыбаш, Центральная, 62	f	small
3147	22312	2865	республика Башкортостан, село Сарайсино, Школьная, 1А	f	small
1786	20966	1511	республика Башкортостан, село Саннинское, Школьная, 56	f	small
3578	22803	3357	республика Башкортостан, село Санжаровка, Школьная, 2/1	f	small
2801	21972	2520	республика Башкортостан, село Сандин 2-й, Центральная, 2А	t	small
1730	20913	1456	республика Башкортостан, село Самарино, Центральная, 1	f	small
2722	21889	2441	республика Башкортостан, село Салихово, Советская, 9Б	f	small
2271	21442	1991	республика Башкортостан, село Салимовка, М.Гафури, 14	t	small
1069	20268	802	республика Башкортостан, село Салаватово, Школьная, 93	f	small
838	20055	575	республика Башкортостан, Салават, бульвар Космонавтов, 6	f	large
830	20047	567	республика Башкортостан, Салават, Школьный переулок, 7	f	large
829	20046	566	республика Башкортостан, Салават, Фурманова, 4	f	large
871	20081	608	республика Башкортостан, Салават, Уфимская, 120а	f	large
849	20065	586	республика Башкортостан, Салават, Уфимская, 106	f	large
848	20065	585	республика Башкортостан, Салават, Уфимская, 106	f	large
839	20056	576	республика Башкортостан, Салават, Уфимская, 90	f	large
833	20050	570	республика Башкортостан, Салават, Уфимская, 72	f	large
831	20048	568	республика Башкортостан, Салават, Уфимская, 58	f	large
814	20031	551	республика Башкортостан, Салават, Строителей, 7	f	medium
817	20034	554	республика Башкортостан, Салават, Пугачева, 7	f	medium
821	20038	558	республика Башкортостан, Салават, Первомаяская, 23	f	large
866	20071	603	республика Башкортостан, Салават, Островского, 70	f	large
857	20071	594	республика Башкортостан, Салават, Островского, 70	f	large
843	20060	580	республика Башкортостан, Салават, Островского, 32	f	large
65618	20053	573	республика Башкортостан, Салават, Октябрьская, 43	f	\N
813	20030	550	республика Башкортостан, Салават, Монтажников, 34а	f	large
824	20041	561	республика Башкортостан, Салават, Матросова, 18	f	large
819	20036	556	республика Башкортостан, Салават, Матросова, 27	f	large
827	20044	564	республика Башкортостан, Салават, Ленина, 14	f	large
826	20043	563	республика Башкортостан, Салават, Ленина, 3	f	large
812	20029	549	республика Башкортостан, Салават, Комсомольская, 20	f	large
858	20072	595	республика Башкортостан, Салават, Калинина, 78	f	large
842	20059	579	республика Башкортостан, Салават, Калинина, 47	f	large
823	20040	560	республика Башкортостан, Салават, К. Маркса, 13	f	large
65622	20075	598	республика Башкортостан, Салават, Губкина, 22б	f	\N
860	20073	596	республика Башкортостан, Салават, Губкина, 14	f	large
65619	20064	584	республика Башкортостан, Салават, Губкина, 7	f	\N
846	20063	583	республика Башкортостан, Салават, Губкина, 12а	f	large
873	20082	610	республика Башкортостан, Салават, Губайдуллина, 4А	f	large
872	20082	609	республика Башкортостан, Салават, Губайдуллина, 4А	f	large
822	20039	559	республика Башкортостан, Салават, Горького, 3	f	large
818	20035	555	республика Башкортостан, Салават, Горького, 23	f	large
65616	20045	565	республика Башкортостан, Салават, Гагарина, 21/2	f	\N
825	20027	562	республика Башкортостан, Салават, Гагарина, 8	f	large
869	20080	606	республика Башкортостан, Салават, Бочкарева, 5	f	large
868	20080	605	республика Башкортостан, Салават, Бочкарева, 5	f	large
815	20032	552	республика Башкортостан, Салават, Б.Хмельницкого, 29	f	large
65623	20078	602	республика Башкортостан, Салават, Б.С.Юлаева, 20а	f	\N
863	20076	600	республика Башкортостан, Салават, Б.С.Юлаева, 36	f	large
862	20076	599	республика Башкортостан, Салават, Б.С.Юлаева, 36	f	large
870	20079	607	республика Башкортостан, Салават, Б.С. Юлаева, 10	f	large
867	20079	604	республика Башкортостан, Салават, Б.С. Юлаева, 10	f	large
864	20077	601	республика Башкортостан, Салават, Б.С. Юлаева, 32а	f	large
856	20070	593	республика Башкортостан, Салават, Б.С. Юлаева, 61	f	large
65620	20069	592	республика Башкортостан, Салават, Б.С. Юлаева, 3	f	\N
854	20068	591	республика Башкортостан, Салават, Б.С. Юлаева, 37	f	large
853	20067	590	республика Башкортостан, Салават, Б.С. Юлаева, 21	f	large
852	20067	589	республика Башкортостан, Салават, Б.С. Юлаева, 21	f	large
816	20033	553	республика Башкортостан, Салават, Б. Хмельницкого, 45	f	large
841	20058	578	республика Башкортостан, Салават, Б. Космонавтов, 22а	f	large
840	20057	577	республика Башкортостан, Салават, Б. Космонавтов, 20	f	large
837	20054	574	республика Башкортостан, Салават, Б. Космонавтов, 41а	f	large
835	20052	572	республика Башкортостан, Салават, Б. Космонавтов, 23	f	large
834	20051	571	республика Башкортостан, Салават, Б. Космонавтов, 21	f	large
845	20062	582	республика Башкортостан, Салават, 30 лет Победы, 5	f	large
844	20061	581	республика Башкортостан, Салават, 30 лет Победы, 16	f	large
65617	20049	569	республика Башкортостан, Салават, 21-го съезда, 124	f	\N
851	20066	588	республика Башкортостан, Салават, Б.С. Юлаева, 21а	f	large
850	20066	587	республика Башкортостан, Салават, Б.С. Юлаева, 21а	f	large
2508	21676	2227	республика Башкортостан, село Сазово, Центральная, 21	f	medium
2661	21829	2381	республика Башкортостан, село Редькино, Ленина, 57	f	medium
65630	20249	783	республика Башкортостан, деревня Покровка, Школьная, 1 а	t	\N
3296	22521	3075	республика Башкортостан, деревня Покровка, Центральная, 15	f	small
3597	22822	3376	республика Башкортостан, село Петряево, Сергея Алексеева, 7	f	small
1204	20391	932	республика Башкортостан, село Петропавловка, Космонавтов, 2	f	small
1493	20681	1223	республика Башкортостан, село Пахарь, Центральная, 27	f	medium
2825	21993	2541	республика Башкортостан, село Павловка, Центральная, 58	f	small
771	19991	508	республика Башкортостан, Октябрьский, Школьная, 1	f	medium
805	20024	542	республика Башкортостан, Октябрьский, Шашина, 2	f	large
804	20024	541	республика Башкортостан, Октябрьский, Шашина, 2	f	large
790	20010	527	республика Башкортостан, Октябрьский, Трипольского, 67	f	large
786	20006	523	республика Башкортостан, Октябрьский, Свердлова, 76	f	large
798	20018	535	республика Башкортостан, Октябрьский, Садовое кольцо, 155	f	large
789	20009	526	республика Башкортостан, Октябрьский, Садовое кольцо, 55	f	large
778	19998	515	республика Башкортостан, Октябрьский, Садовое кольцо, 174	f	large
772	19992	509	республика Башкортостан, Октябрьский, Партизанская, 9	f	large
787	20007	524	республика Башкортостан, Октябрьский, Островского, 59	f	large
65614	19999	516	республика Башкортостан, Октябрьский, Матросова, 121	f	\N
780	20000	517	республика Башкортостан, Октябрьский, Ломоносова, 1а	f	medium
785	20005	522	республика Башкортостан, Октябрьский, Лермонтова, 3	f	large
788	20008	525	республика Башкортостан, Октябрьский, Ленина, 37	f	large
782	20002	519	республика Башкортостан, Октябрьский, Ленина, 4	f	large
792	20011	529	республика Башкортостан, Октябрьский, Кувыкина, 15	f	large
791	20011	528	республика Башкортостан, Октябрьский, Кувыкина, 15	f	large
781	20001	518	республика Башкортостан, Октябрьский, Крупской, 1	f	large
807	20016	544	республика Башкортостан, Октябрьский, Космонавтов, 41/1	f	large
796	20016	533	республика Башкортостан, Октябрьский, Космонавтов, 41/1	f	large
793	20012	530	республика Башкортостан, Октябрьский, Королева, 1	f	large
797	20017	534	республика Башкортостан, Октябрьский, Кооперативная, 105	f	large
783	20003	520	республика Башкортостан, Октябрьский, Комсомольская, 3	f	large
775	19995	512	республика Башкортостан, Октябрьский, Комсомольская, 33	f	large
773	19993	510	республика Башкортостан, Октябрьский, Комсомольская, 22	f	large
777	19997	514	республика Башкортостан, Октябрьский, Девонская, 54а	f	large
774	19994	511	республика Башкортостан, Октябрьский, Девонская, 8а	f	large
776	19996	513	республика Башкортостан, Октябрьский, Герцена, 18	f	large
784	20004	521	республика Башкортостан, Октябрьский, Геофизиков, 3	f	large
811	20028	548	республика Башкортостан, Октябрьский, 35 микрорайон, школа №12	f	large
810	20028	547	республика Башкортостан, Октябрьский, 35 микрорайон, школа №12	f	large
809	20026	546	республика Башкортостан, Октябрьский, 35 микрорайон, гимназия №3	f	large
808	20026	545	республика Башкортостан, Октябрьский, 35 микрорайон, гимназия №3	f	large
806	20025	543	республика Башкортостан, Октябрьский, 35 микрорайон, 15а	f	medium
803	20023	540	республика Башкортостан, Октябрьский, 34 микрорайон, школа №20	f	large
802	20022	539	республика Башкортостан, Октябрьский, 34 микрорайон, Школа №20	f	large
801	20021	538	республика Башкортостан, Октябрьский, 34 микрорайон, 6	f	large
800	20020	537	республика Башкортостан, Октябрьский, 29 микрорайон, школа №22	f	large
799	20019	536	республика Башкортостан, Октябрьский, 29 микрорайон, школа №22	f	large
795	20015	532	республика Башкортостан, Октябрьский, 25 микрорайон, школа №8	f	large
794	20014	531	республика Башкортостан, Октябрьский, 25 микрорайон, ПТУ №68	f	large
2674	21842	2394	республика Башкортостан, село Новый Янзигит, Дорожная, 20	f	small
1682	20865	1408	республика Башкортостан, село Новый Биктяш, Абдулинская, 33	f	small
2666	21834	2386	республика Башкортостан, село Новый Актанышбаш, Школьная, 35	f	medium
3208	22434	2987	республика Башкортостан, село Новые Татышлы, Школьная, 25	f	small
3247	22474	3026	республика Башкортостан, село Новые Бишинды, Центральная, 47	f	small
1908	21087	1632	республика Башкортостан, село Новошиликово, Озерная, 25	f	small
1158	20347	887	республика Башкортостан, село Новошареево, Нижняя, 16	f	small
2124	21303	1848	республика Башкортостан, село Новоуртаево, Агидель, 6	f	small
1375	20564	1105	республика Башкортостан, село Новоурсаево, Ленина, 37	f	small
2689	21856	2408	республика Башкортостан, село Новониколаевское, Молодежная, 43	f	small
2919	22089	2637	республика Башкортостан, село Новомуслюмово, Луговая, 85	f	medium
1382	20571	1112	республика Башкортостан, село Новокуручево, Центральная, 38	f	small
2142	21320	1865	республика Башкортостан, село Новокангышево, Молодёжная, 40	f	medium
3180	22359	2959	республика Башкортостан, село Новокайпаново, Новая, 2	f	small
2675	21843	2395	республика Башкортостан, село Новокабаново, Центральная, 28	f	medium
2830	21998	2546	республика Башкортостан, село Новая Уралка, Уральская, 25А	f	small
2669	21837	2389	республика Башкортостан, село Нижняя Татья, Ленина, 26	f	small
3709	22932	3489	республика Башкортостан, село Нижный Чат, Худайбердина, 38	f	small
2576	21744	2295	республика Башкортостан, село Нижний Тюкунь, Шоссейная, 19	f	small
1987	21167	1711	республика Башкортостан, село Нижний Ташбукан, Гафури, 37	f	small
2214	21391	1934	республика Башкортостан, село Нижний Муйнак, Юнай, 12	f	small
1521	20708	1251	республика Башкортостан, село Нижний Искуш, Бунакова, 24	f	medium
2641	21809	2360	республика Башкортостан, село Нижние Киги, 8 Марта, 1	f	small
3204	22430	2983	республика Башкортостан, село Нижнебалтачево, Центральная, 28	f	medium
65779	21153	1984	Россия, республика Башкортостан, село Нижегородка, улица Школьная, 20	f	\N
3456	22681	3235	республика Башкортостан, село Нижегородка, Школьная, 6	f	small
3449	22674	3228	республика Башкортостан, село Нижегородка, Школьная, 6	f	small
3443	22668	3222	республика Башкортостан, село Нижегородка, Школьная, 3	f	small
3441	22666	3220	республика Башкортостан, село Нижегородка, Школьная, 15	f	small
3438	22663	3217	республика Башкортостан, село Нижегородка, Школьная, 25	f	small
3432	22657	3211	республика Башкортостан, село Нижегородка, Школьная, 2	f	small
3431	22656	3210	республика Башкортостан, Федоровский район, Школьная, 23	f	small
2783	21953	2502	республика Башкортостан, село Нижегородка, Школьная, 13	f	small
1537	20725	1267	республика Башкортостан, село Нижегородка, Школьная, 1	f	small
1276	20466	1006	республика Башкортостан, село Нижегородка, Школьная, 8	f	small
65631	20250	784	республика Башкортостан, село Нижегородка, Школьная, 16	f	\N
3582	22807	3361	республика Башкортостан, село Нижегородка, Центральная, 29А	f	small
3440	22665	3219	республика Башкортостан, село Нижегородка, Школьная, 22	f	small
3434	22659	3213	республика Башкортостан, Федоровский район, Школьная, 8	f	small
65669	20843	1386	республика Башкортостан, село Нижегородка, Школьная, 12а	f	\N
1114	20313	847	республика Башкортостан, село Нижегородка, Школьная, 8	f	small
749	19973	486	республика Башкортостан, Нефтекамск, Юбилейный проспект, 17	f	large
726	19953	463	республика Башкортостан, Нефтекамск, Трактовая, 41	f	large
723	19950	460	республика Башкортостан, Нефтекамск, Трактовая, 35	f	large
722	19949	459	республика Башкортостан, Нефтекамск, Трактовая, 1	f	large
764	19986	502	республика Башкортостан, Нефтекамск, Строителей, 65а	f	large
760	19982	497	республика Башкортостан, Нефтекамск, Строителей, 89а	f	large
765	19987	503	республика Башкортостан, Нефтекамск, Социалистическая, 54а	f	large
762	19984	500	республика Башкортостан, Нефтекамск, Социалистическая, 62в	f	large
761	19984	499	республика Башкортостан, Нефтекамск, Социалистическая, 62в	f	large
757	19980	494	республика Башкортостан, Нефтекамск, Социалистическая, 74	f	large
758	19980	495	республика Башкортостан, Нефтекамск, Социалистическая, 74	f	large
747	19972	485	республика Башкортостан, Нефтекамск, Социалистическая, 65	f	large
746	19970	483	республика Башкортостан, Нефтекамск, Социалистическая, 42	f	large
745	19970	482	республика Башкортостан, Нефтекамск, Социалистическая, 42	f	large
741	19965	477	республика Башкортостан, Нефтекамск, Социалистическая, 45в	f	large
725	19952	462	республика Башкортостан, Нефтекамск, Сиреневая, 5	f	medium
763	19985	501	республика Башкортостан, Нефтекамск, Победы, 5	f	large
65613	19976	489	республика Башкортостан, Нефтекамск, Победы, 11	f	\N
751	19975	488	республика Башкортостан, Нефтекамск, Победы, 10	f	large
731	19958	468	республика Башкортостан, Нефтекамск, Парковая, 18	f	large
742	19968	479	республика Башкортостан, Нефтекамск, Нефтяников, 2	f	large
743	19967	480	республика Башкортостан, Нефтекамск, Нефтяников, 11в	f	large
740	19966	478	республика Башкортостан, Нефтекамск, Нефтяников, 24	f	large
767	19983	504	республика Башкортостан, Нефтекамск, Ленина, 84а	f	medium
766	19983	498	республика Башкортостан, Нефтекамск, Ленина, 84а	f	large
759	19981	496	республика Башкортостан, Нефтекамск, Ленина, 39б	f	large
755	19978	492	республика Башкортостан, Нефтекамск, Ленина, 66	f	large
754	19978	491	республика Башкортостан, Нефтекамск, Ленина, 66	f	large
753	19977	490	республика Башкортостан, Нефтекамск, Ленина, 23	f	large
750	19974	487	республика Башкортостан, Нефтекамск, Ленина, 56	f	large
739	19964	476	республика Башкортостан, Нефтекамск, Ленина, 9	f	large
738	19963	475	республика Башкортостан, Нефтекамск, Ленина, 5б	f	large
729	19956	466	республика Башкортостан, Нефтекамск, Кувыкина переулок, 10	f	large
748	19971	484	республика Башкортостан, Нефтекамск, Комсомольский проспект, 17Б	f	large
744	19969	481	республика Башкортостан, Нефтекамск, Комсомольский проспект, 7	f	large
732	19959	469	республика Башкортостан, Нефтекамск, Комсомольский проспект, 44в	f	large
730	19957	467	республика Башкортостан, Нефтекамск, Карла Маркса, 18	f	large
728	19955	465	республика Башкортостан, Нефтекамск, Карла Маркса, 10б	f	large
735	19955	472	республика Башкортостан, Нефтекамск, Карла Маркса, 10б	f	large
736	19955	473	республика Башкортостан, Нефтекамск, Карла Маркса, 10б	f	large
737	19962	474	республика Башкортостан, Нефтекамск, Дорожная, 49	f	large
724	19951	461	республика Башкортостан, Нефтекамск, Дорожная, 2	f	large
756	19979	493	республика Башкортостан, Нефтекамск, Дзержинского, 18	f	large
1661	20844	1387	республика Башкортостан, село Набережный, Школьная, 4	f	small
1322	20512	1052	республика Башкортостан, село Мукасово 1-е, 1 Мая, 5	f	small
3647	22869	3426	республика Башкортостан, село Мичуринск, Миргая Фархутдинова, 3	f	small
3650	22872	3429	республика Башкортостан, село Михайловка, Школьная, 2	f	small
1370	20559	1100	республика Башкортостан, село Михайловка, Центральная, 4	f	small
1067	20266	800	республика Башкортостан, село Михайловка, Парковая, 32	f	medium
3459	22684	3238	республика Башкортостан, село Михайловка, Ленина, 43	f	large
3457	22682	3236	республика Башкортостан, Федоровский район, Ленина, 33	f	small
3325	22550	3104	республика Башкортостан, село Михайловка, Ленина, 56	f	large
1010	20217	748	республика Башкортостан, село Михайловка, Ленина, 15	f	small
1824	21004	1548	республика Башкортостан, село Михайловка, Красногвардейская, 8б	f	small
1742	20925	1468	республика Башкортостан, село Мирный, Школьная, 4	f	medium
3367	22591	3146	республика Башкортостан, поселок Миндяк, Хисматуллина, 12	f	medium
65715	21241	1782	Россия, Оренбургская область, Оренбург, улица Советская, 3	f	\N
1412	20601	1142	Россия, Кировская область, Киров, улица Приозерная, 6	f	small
3323	22548	3102	Россия, республика Башкортостан, село Миловка, улица Михайлова, 3	f	large
3430	22655	3209	республика Башкортостан, село Миловка, Советская, 16	f	large
1844	21024	1568	республика Башкортостан, село Миловка, Советская, 17	f	small
1669	20852	1395	республика Башкортостан, село Миловка, Советская, 35	f	medium
719	19946	456	республика Башкортостан, село Миловка, Советская, 20	f	large
2027	21208	1751	республика Башкортостан, село Микяшево, Центральная, 46	f	medium
3112	22276	2830	республика Башкортостан, село Мечетлино, Центральная, 73	f	small
2851	22020	2569	республика Башкортостан, Мелеуз, Шлычкова, 29	f	large
2861	22028	2579	республика Башкортостан, Мелеуз, Свердлова, 19	f	large
2860	22028	2578	республика Башкортостан, Мелеуз, Свердлова, 19	f	large
2850	22019	2568	республика Башкортостан, Мелеуз, Правды, 31	f	large
2849	22018	2567	республика Башкортостан, Мелеуз, Площадь Лесокомбината, 5	f	large
2865	22032	2583	республика Башкортостан, Мелеуз, Октябрьская, 1	f	large
2864	22031	2582	республика Башкортостан, Мелеуз, Октябрьская, 5А	f	large
2866	22033	2584	республика Башкортостан, Мелеуз, Московская, 2	f	large
2858	22026	2576	республика Башкортостан, Мелеуз, Ленина, 200	f	large
2852	22021	2570	республика Башкортостан, Мелеуз, Ленина, 73	f	large
2846	22015	2564	республика Башкортостан, Мелеуз, Ленина, 3	f	large
2855	22024	2573	республика Башкортостан, Мелеуз, Колхозная, 12	f	large
2853	22022	2571	республика Башкортостан, Мелеуз, Бурангулова, 11	f	large
2859	22027	2577	республика Башкортостан, Мелеуз, 31 микрорайон, 11	f	large
2614	21781	2333	республика Башкортостан, село Масяково, Безымянная, 65	f	small
1593	20793	1333	республика Башкортостан, село Манышта, Новая, 3	t	small
2470	21638	2189	республика Башкортостан, село Маломаксютово, Каран-Елга, 16	f	small
1035	20236	770	республика Башкортостан, село Майгашта, Лесорубов, 20	f	small
1522	20709	1252	республика Башкортостан, село Левали, Мира, 35	f	small
2341	21511	2060	республика Башкортостан, село Кызыл-Юлдуз, Ленина, 21а	t	small
2276	21447	1996	республика Башкортостан, село Кызлар-Бирган, Заречная, 4	f	small
3388	22612	3167	республика Башкортостан, село Кутуево, Школьная, 16	f	small
3111	22275	2829	республика Башкортостан, село Кусепеево, Школьная, 1	f	small
3562	22787	3341	республика Башкортостан, село Кусекеево, Ахтямова, 71	f	small
1315	20505	1045	республика Башкортостан, село Кусеево, Б. Валида, 6	f	small
1157	20346	886	республика Башкортостан, село Кумурлы, Школьная, 1	f	small
712	19940	450	республика Башкортостан, Кумертау, Чапаева, 7	f	large
694	19924	432	республика Башкортостан, Кумертау, Пушкина, 18	f	large
711	19939	449	республика Башкортостан, Кумертау, Палатникова, 8	f	medium
697	19927	435	республика Башкортостан, Кумертау, Некрасова, 28	f	large
706	19936	444	республика Башкортостан, Кумертау, Мира, 3а	f	large
710	19938	448	республика Башкортостан, Кумертау, Машиностроителей, 76	f	large
709	19938	447	республика Башкортостан, Кумертау, Машиностроителей, 76	f	large
708	19937	446	республика Башкортостан, Кумертау, Машиностроителей, 6а	f	large
707	19937	445	республика Башкортостан, Кумертау, Машиностроителей, 6а	f	large
703	19933	441	республика Башкортостан, Кумертау, Ломоносова, 31А	f	large
702	19932	440	республика Башкортостан, Кумертау, Ломоносова, 23а	f	large
700	19930	438	республика Башкортостан, Кумертау, Комсомольская, 2	f	large
691	19921	429	республика Башкортостан, Кумертау, Комсомольская, 21	f	large
689	19919	427	республика Башкортостан, Кумертау, Комсомольская, 12	f	large
701	19931	439	республика Башкортостан, Кумертау, Калинина, 11	f	large
699	19929	437	республика Башкортостан, Кумертау, Заслонова, 1	f	large
714	19942	452	республика Башкортостан, Кумертау, Горького, 14	f	large
705	19935	443	республика Башкортостан, Кумертау, Горького, 20	f	large
704	19934	442	республика Башкортостан, Кумертау, Горького, 11	f	large
690	19920	428	республика Башкортостан, Кумертау, Горького, 22а	f	large
65612	19928	436	республика Башкортостан, Кумертау, Вокзальная, 5	f	\N
696	19926	434	республика Башкортостан, Кумертау, Антошкина, 6	f	medium
713	19941	451	республика Башкортостан, Кумертау, 70 лет Октября, 33	f	large
695	19925	433	республика Башкортостан, Кумертау, 60 лет БАССР, 14а	f	large
693	19923	431	республика Башкортостан, Кумертау, 40 лет Победы, 44	f	large
692	19922	430	республика Башкортостан, Кумертау, 2-й переулок Салавата, 9	f	large
2599	21766	2318	республика Башкортостан, деревня Кулушево, Школьная, 25	f	small
3387	22611	3166	республика Башкортостан, деревня Кулушево, Шагар, 24	t	small
2676	21844	2396	республика Башкортостан, село Кузгово, Центральная, 51	f	small
2759	21928	2478	республика Башкортостан, село Кувыково, Горная, 18	f	small
1193	20381	922	республика Башкортостан, село Кубиязы, Совхозная, 2	f	small
2383	21555	2102	республика Башкортостан, село Красный Октябрь, Дружбы, 37	f	small
1102	20301	835	республика Башкортостан, село Красный Клин, Краснобашкирская, 2	f	small
3516	22740	3295	республика Башкортостан, село Комсомольск, Зайнаб Биишевой, 4	f	small
1336	20526	1066	республика Башкортостан, село Комсомол, Школьная, 1	f	small
2491	21659	2210	республика Башкортостан, село Козлоялово, Труда, 2	f	small
1679	20862	1405	республика Башкортостан, село Кожай-Икские Вершины, Центральная, 43	f	small
1680	20863	1406	республика Башкортостан, село Кистенли-Ивановка, Центральная, 32/1	f	small
3319	22544	3098	республика Башкортостан, деревня Кириллово, Центральная, 64	f	large
3637	22860	3416	республика Башкортостан, село Кир-Тлявли, Дорожная, 8	f	medium
2826	21994	2542	республика Башкортостан, село Кинзябаево, Центральная, 11	f	small
3561	22786	3340	республика Башкортостан, село Киндеркулево, Буденного, 26	f	small
3213	22439	2992	республика Башкортостан, село Кашкаково, Центральная, 49	f	small
1106	20305	839	республика Башкортостан, село Кармышево, Центральная, 18/1	f	small
3317	22542	3096	республика Башкортостан, село Кармасан, Центральная, 1	f	small
1131	20332	864	республика Башкортостан, село Каран, Родниковая, 28	f	small
2120	21299	1844	республика Башкортостан, село Каралачук, Советская, 47А	f	small
3305	22529	3084	республика Башкортостан, деревня Камышлы, Саитова, 15	f	medium
3122	22286	2840	республика Башкортостан, село Калмакларово, Центральная, 8	f	small
1378	20567	1108	республика Башкортостан, село Казанчи, Колхозная, 13	f	small
2571	21739	2290	республика Башкортостан, деревня Кабаково, Победы, 49	f	large
1401	20590	1131	республика Башкортостан, село Иштиряково, Советская, 24	f	small
1329	20519	1059	республика Башкортостан, село Ишмурзино, Игишева, 25	f	medium
2407	21577	2126	республика Башкортостан, Ишимбай, Передвижной вагончик	f	small
2431	21600	2150	республика Башкортостан, Ишимбай, проспект Ленина, 23	f	large
2426	21191	2145	республика Башкортостан, Ишимбай, проспект Ленина, 49	f	large
2417	21587	2136	республика Башкортостан, Ишимбай, Стахановская, 58	f	large
2414	21584	2133	республика Башкортостан, Ишимбай, Стахановская, 18Б	f	large
2402	21573	2121	республика Башкортостан, Ишимбай, Стахановская, 6А	f	large
2429	21598	2148	республика Башкортостан, Ишимбай, Революционная, 12А	f	large
2410	21580	2129	республика Башкортостан, Ишимбай, Радужная, 2	f	large
2440	21609	2159	республика Башкортостан, Ишимбай, Промысловая, 13А	f	large
2430	21599	2149	республика Башкортостан, Ишимбай, Пролетарская, 27	f	large
2416	21586	2135	республика Башкортостан, Ишимбай, Мичурина, 9	f	large
2415	21585	2134	республика Башкортостан, Ишимбай, Мичурина, 4	f	large
2413	21583	2132	республика Башкортостан, Ишимбай, Машиностроителей, 28	f	large
2433	21602	2152	республика Башкортостан, Ишимбай, Ленина проспект, 22	f	large
2435	21604	2154	республика Башкортостан, Ишимбай, Космонавтов, 6А	f	large
2436	21605	2155	республика Башкортостан, Ишимбай, Есенина, 2	f	large
2408	21578	2127	республика Башкортостан, Ишимбай, Докучаева, 10А	f	large
2428	21597	2147	республика Башкортостан, Ишимбай, Губкина, 41	f	large
2424	21594	2143	республика Башкортостан, Ишимбай, Губкина, 28	f	large
2439	21608	2158	республика Башкортостан, Ишимбай, Горького, 34	f	large
2438	21607	2157	республика Башкортостан, Ишимбай, Горького, 55	f	large
2434	21603	2153	республика Башкортостан, Ишимбай, Геологическая, 16	f	medium
2425	21595	2144	республика Башкортостан, Ишимбай, Геологическая, 60	f	large
2409	21579	2128	республика Башкортостан, Ишимбай, Гайфуллина, 15	f	large
2421	21591	2140	республика Башкортостан, Ишимбай, Бульварная, 47	f	large
2419	21589	2138	республика Башкортостан, Ишимбай, Бульварная, 55	f	large
2185	21360	1905	республика Башкортостан, село Иткулово, Камышева, 3А	f	small
2100	21278	1824	республика Башкортостан, село Исмайлово, Ханифв Валиева, 49	f	medium
1052	20252	786	республика Башкортостан, село Искужино, Центральная, 16	f	small
2014	21194	1738	республика Башкортостан, село Искандарово, Верхняя, 25	f	small
1149	19622	879	республика Башкортостан, село Ирныкши, Советская, 44	f	small
1589	20789	1329	республика Башкортостан, поселок Инзер, Пушкина, 1	f	small
1586	20786	1326	республика Башкортостан, поселок Инзер, Дорожников, 3	f	medium
2345	21515	2064	республика Башкортостан, село Илякшиде, Санникова, 2	f	small
2608	21775	2327	республика Башкортостан, село Ильтуганово, Мостовая, 2	f	small
3362	22551	3141	республика Башкортостан, село Ильтебаново, Клубная, 22/1	f	small
3452	22677	3231	республика Башкортостан, село Ильинка, 8	f	small
2717	21884	2436	республика Башкортостан, село Игубаево, Школьная, 12	f	small
2350	21521	2069	республика Башкортостан, село Игметово, Ленина, 11	f	small
2254	21433	1974	республика Башкортостан, село Ивано-Кувалат, Школьная, 4	f	small
2601	21768	2320	республика Башкортостан, деревня Ибрагимово, Школьная, 3А	f	small
3315	22540	3094	республика Башкортостан, поселок Зубово, Центральная, 75	f	large
3173	22403	2952	республика Башкортостан, село Зиримзи, Центральная, 47	f	small
3591	22816	3370	республика Башкортостан, село Еремеево, Центральная, 20	f	small
3589	22814	3368	республика Башкортостан, деревня Енгалышево, Манаева, 22	f	small
2089	21270	1813	республика Башкортостан, Дюртюли, Советская, 96	f	large
2080	21262	1804	республика Башкортостан, Дюртюли, Первомайская, 24/А	f	large
65717	21260	1802	республика Башкортостан, Дюртюли, Ленина, 23	f	\N
2927	22050	2645	республика Башкортостан, село Дуван-Мечетлино, Вагапова, 1	f	small
2065	21247	1789	республика Башкортостан, село Дуван, С.А. Михляева, 13	f	medium
2064	21247	1788	республика Башкортостан, село Дуван, С.А. Михляева, 13	f	small
3308	22532	3087	республика Башкортостан, село Дмитриевка, Школьная, 23	f	large
2253	21432	1973	республика Башкортостан, село Дмитриевка, Чучкалова, 17	f	small
134608	94453	1507	республика Башкортостан, село Дмитриевка, Центральная, 11	f	\N
1734	20917	1460	республика Башкортостан, село Дмитриевка, Комиссарова, 14	f	small
1020	20226	757	республика Башкортостан, село Даутово, Школьная, 5	f	small
2005	21184	1729	республика Башкортостан, Давлеканово, Российская, 4	f	large
2002	21181	1726	республика Башкортостан, Давлеканово, Комсомольская, 26а	f	large
1998	21177	1722	республика Башкортостан, Давлеканово, Коммунистическая, 18	f	medium
2003	21182	1727	республика Башкортостан, Давлеканово, Карла Маркса, 119	f	large
1997	21176	1721	республика Башкортостан, Давлеканово, Гагарина, 144	f	large
2004	21183	1728	республика Башкортостан, Давлеканово, Высоковольтная, 20/2	f	large
2000	21179	1724	республика Башкортостан, Давлеканово, Ворошилова, 17	f	large
2009	21188	1733	республика Башкортостан, Давлеканово, Беляева, 14	f	large
3108	22272	2826	республика Башкортостан, село Гусевка, Центральная, 8	f	small
3690	22913	3470	республика Башкортостан, село Гудбурово, Центральная, 8	f	small
3335	22561	3114	республика Башкортостан, поселок Геофизик, Геологов	f	medium
2224	21402	1944	республика Башкортостан, село Вотикеево, Клубная, 19	f	medium
1883	21061	1607	республика Башкортостан, село Вострецово, Школьная, 3	f	small
2487	21655	2206	республика Башкортостан, село Верхний Тыхтем, Красноармейская, 9	f	small
1933	21105	1650	республика Башкортостан, село Верхний Нугуш, Нугуш, 9/1	f	small
1238	20426	966	республика Башкортостан, село Верхний Бегеняш, Центральная, 11А	f	small
1007	20214	745	республика Башкортостан, село Верхние Абдряшево, Школьная, 5	f	small
2762	21931	2481	республика Башкортостан, село Верхнесаитово, Мира, 64	f	small
1540	20728	1270	республика Башкортостан, село Васелга, Животноводов, 11	f	small
1148	19244	878	республика Башкортостан, деревня Вавилово, улица Заречная, 30	f	small
3439	22664	3218	республика Башкортостан, деревня Вавилово, Первомайская, 6	f	small
3201	22426	2980	республика Башкортостан, село Бургынбаш, Центральная, 16	f	small
2941	22106	2659	республика Башкортостан, село Бургаджино, Советская, 2	f	small
1866	21044	1590	республика Башкортостан, село Бураево, Ленина, 70	f	medium
3304	22528	3083	республика Башкортостан, село Булгаково, Цюрупы, 148	f	large
3102	22266	2820	республика Башкортостан, село Булгаково, Лесная, 8	f	small
1355	20545	1085	республика Башкортостан, село Бузюрово, Школьная, 63	f	small
2188	21363	1908	республика Башкортостан, село Бужан, Лесная, 15	f	small
2873	22040	2591	республика Башкортостан, село Богородское, Центральная, 6	f	small
1330	20520	1060	республика Башкортостан, село Богачево, Молодежная, 12	f	small
1766	20949	1492	республика Башкортостан, Благовещенск, Чапаева, 57	f	large
1763	20946	1489	республика Башкортостан, Благовещенск, Социалистическая, 16 А	f	medium
1770	20952	1495	республика Башкортостан, Благовещенск, Советская, 11	f	large
1773	20955	1498	республика Башкортостан, Благовещенск, Седова, 98	f	large
1777	20955	1502	республика Башкортостан, Благовещенск, Седова, 98	f	large
1771	20953	1496	республика Башкортостан, Благовещенск, Седова, 2	f	medium
1772	20954	1497	республика Башкортостан, Благовещенск, Расковой, 23	f	large
1778	20959	1503	республика Башкортостан, Благовещенск, Комарова, 19	f	large
1769	20951	1494	республика Башкортостан, Благовещенск, Кирова, 14	f	large
1765	20948	1491	республика Башкортостан, Благовещенск, Кирова, 58	f	large
1780	20960	1505	республика Башкортостан, Благовещенск, Демьяна Бедного, 68/3	f	large
1779	20960	1504	республика Башкортостан, Благовещенск, Демьяна Бедного, 68/3	f	large
1775	20957	1500	республика Башкортостан, Благовещенск, Братьев Першиных, 5/1	f	large
1762	20945	1488	республика Башкортостан, Благовещенск, Братьев Кадомцевых, 9/2	f	medium
1764	20947	1490	республика Башкортостан, Благовещенск, Социалистический, 16 А	f	large
1685	20868	1411	республика Башкортостан, Бирск, Ленина, 17	f	large
1695	20878	1421	республика Башкортостан, Бирск, Курбатова, 59	f	large
1692	20875	1418	республика Башкортостан, Бирск, Красноармейская, 81	f	large
1698	20881	1424	республика Башкортостан, Бирск, Коммунистическая, 97	f	large
1693	20876	1419	республика Башкортостан, Бирск, Коммунистическая, 54	f	large
1696	20879	1422	республика Башкортостан, Бирск, Кирова, 20	f	large
1690	20873	1416	республика Башкортостан, Бирск, Калинина, 20	f	large
1694	20877	1420	республика Башкортостан, Бирск, Интернациональная, 1	f	large
1691	20874	1417	республика Башкортостан, Бирск, Интернациональная, 74-в	f	large
1689	20872	1415	республика Башкортостан, Бирск, Гагарина, 89	f	large
1699	20882	1425	республика Башкортостан, Бирск, Бурновская, 2	f	large
2200	21375	1920	республика Башкортостан, село Бикбау, Школьная, 34	f	small
1645	20831	1371	республика Башкортостан, село Бижбуляк, Строительная, 22	f	medium
1644	20830	1370	республика Башкортостан, село Бижбуляк, Советская, 25	f	large
70710	79817	130	Самарская область, Чапаевск, Короленко, 72	f	large
3205	22431	2984	республика Башкортостан, село Бигинеево, Центральная, 2	f	small
1430	20619	1160	республика Башкортостан, село Бигильдино, Октябрьская, 12	f	small
1562	20751	1292	республика Башкортостан, Белорецк, Спортивная, 51А	f	large
1570	20759	1300	республика Башкортостан, Белорецк, Совхозная, 81	f	small
1576	20764	1305	республика Башкортостан, Белорецк, Свободы, 45	f	large
1561	20750	1291	республика Башкортостан, Белорецк, Садовая, 15	f	large
1573	20762	1303	республика Башкортостан, Белорецк, Молодежная, 61	f	large
1567	20756	1297	республика Башкортостан, Белорецк, Маршала Жукова, 1	f	small
1559	20748	1289	республика Башкортостан, Белорецк, Маркса, 48	f	large
1550	20739	1280	республика Башкортостан, Белорецк, Маркса, 49	f	large
1545	20733	1275	республика Башкортостан, Белорецк, Маркса, 84	f	large
1560	20749	1290	республика Башкортостан, Белорецк, Луначарского, 93	f	large
1552	20741	1282	республика Башкортостан, Белорецк, Ленина, 18	f	large
1566	20755	1296	республика Башкортостан, Белорецк, Крупской, 160	f	large
1572	20761	1302	республика Башкортостан, Белорецк, Блюхера, 82	f	medium
1569	20758	1299	республика Башкортостан, Белорецк, Блюхера, 137	f	large
1575	20763	1304	республика Башкортостан, Белорецк, Артамонова, 23	f	large
1554	20743	1284	республика Башкортостан, Белорецк, Алексеева, 29	f	large
1565	20754	1295	республика Башкортостан, Белорецк, 50 лет Октября, 178	f	medium
65655	20737	1279	республика Башкортостан, Белорецк, 50 лет Октября, 13	f	\N
1547	20735	1277	республика Башкортостан, Белорецк, 50 лет Октября, 51	f	large
1456	20644	1186	республика Башкортостан, Белебей, Советская, 137	f	large
1467	20655	1197	республика Башкортостан, Белебей, Революционеров, 8	f	large
1463	20651	1193	республика Башкортостан, Белебей, Революционеров, 24/1	f	large
1471	20659	1201	республика Башкортостан, Белебей, Пионерская, 49	f	large
1475	20663	1205	республика Башкортостан, Белебей, Красноармейская, 265а	f	large
1474	20662	1204	республика Башкортостан, Белебей, Красноармейская, 156	f	large
1461	20649	1191	республика Башкортостан, Белебей, Красная, 138	f	large
1458	20646	1188	республика Башкортостан, Белебей, Красная, 103	f	large
1457	20645	1187	республика Башкортостан, Белебей, Красная, 101	f	medium
1472	20660	1202	республика Башкортостан, Белебей, Карла Маркса, 26	f	large
1473	20661	1203	республика Башкортостан, Белебей, Горохова, 28	f	large
1454	20642	1184	республика Башкортостан, Белебей, Восточная, 72	f	large
1460	20648	1190	республика Башкортостан, Белебей, Волгоградская, 5/1	f	large
1466	20654	1196	республика Башкортостан, Белебей, Амирова, 13	f	large
3117	22281	2835	республика Башкортостан, село Баш-Ильчикеево, С.Юлаева, 39	f	small
2903	22072	2621	республика Башкортостан, село Басурмановка, Береговая, 2	f	small
3271	22496	3050	республика Башкортостан, село Балтаево, Школьная, 57	f	small
2773	21943	2492	республика Башкортостан, село Байталлы, Шоссейная, 11	f	small
1262	20452	992	республика Башкортостан, Баймак, пр.С.Юлаева, 27	f	large
1263	20453	993	республика Башкортостан, Баймак, Юбилейная, 21	f	medium
1265	20455	995	республика Башкортостан, Баймак, Чекмарева, 13	f	large
1267	20457	997	республика Башкортостан, Баймак, Стахановская, 19	f	large
1266	20456	996	республика Башкортостан, Баймак, Нигмати, 1	f	large
1268	20458	998	республика Башкортостан, Баймак, М.Горького, 10	f	large
1269	20459	999	республика Башкортостан, Баймак, Ленина, 62	f	medium
1751	20934	1477	республика Башкортостан, село Ахуново, Центральная, 4	f	small
2781	21951	2500	республика Башкортостан, село Ахта, Лесная, 2А	f	small
3191	22416	2970	республика Башкортостан, село Асавды, Центральная, 31	f	small
2513	21680	2232	республика Башкортостан, село Артакуль, Центральная, 7	f	small
2732	21899	2451	республика Башкортостан, село Ардатово, Старый Хутор, 13	f	small
2055	21238	1779	республика Башкортостан, село Анзяк, Центральная, 57	f	small
1305	20495	1035	республика Башкортостан, село Аминево, Школьная, 5	f	small
1015	20221	752	республика Башкортостан, село Амангильдино, Центральная, 37	f	small
3451	22676	3230	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 39	f	small
3426	22651	3205	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 20	f	small
2243	21422	1963	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 19/1	f	small
2233	21412	1954	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 46	f	small
1639	20825	1365	Россия, республика Башкортостан, деревня Алексеевка, улица Центральная, 66	f	small
3299	22524	3078	республика Башкортостан, деревня Алексеевка, Школьная, 26	f	small
3446	22671	3225	республика Башкортостан, деревня Алексеевка, Центральная, 48	f	small
3437	22662	3216	республика Башкортостан, деревня Алексеевка, Центральная, 46	f	small
2734	21902	2453	республика Башкортостан, деревня Алексеевка, Центральная, 50	f	small
2716	21883	2435	республика Башкортостан, деревня Алексеевка, Центральная, 34	f	small
2391	21562	2110	республика Башкортостан, деревня Алексеевка, Центральная, 13	f	small
2226	21404	1946	республика Башкортостан, деревня Алексеевка, Центральная, 22	f	small
2013	21193	1737	республика Башкортостан, деревня Алексеевка, Центральная, 27	f	small
1649	20835	1375	республика Башкортостан, деревня Алексеевка, Центральная, 41А	f	small
1419	20608	1149	республика Башкортостан, деревня Алексеевка, Центральная, 10	f	small
3433	22658	3212	республика Башкортостан, Федоровский район, Центральная, 31	f	small
2569	21737	2288	республика Башкортостан, село Алайгирово, Школьная, 2	f	small
2297	21468	2017	республика Башкортостан, село Акбердино, Центральная, 12	f	medium
3136	22300	2854	республика Башкортостан, село Айтуган, Тятер, 21	f	small
2191	21368	1911	республика Башкортостан, село Агурда, Центральная, 11	f	small
688	19918	426	республика Башкортостан, Агидель, Цветочный бульвар, 3	f	large
686	19878	424	республика Башкортостан, Агидель, Мира, 2	f	large
687	18009	425	республика Башкортостан, Агидель, Мира, 3	f	large
1619	20765	1306	республика Башкортостан, село Абзаково, Ленина, 82	f	medium
2803	22009	2557	республика Башкортостан, село Абдулово, Молодёжная, 1	f	small
2051	21234	1775	республика Башкортостан, село Абдрашитово, Айская, 45А	f	small
3679	22902	3459	республика Башкортостан, Янаульский район, Янаул, Победы, 77	f	large
3678	22901	3458	республика Башкортостан, Янаульский район, Янаул, Ленина, 20	f	large
65894	22900	3457	республика Башкортостан, Янаульский район, Янаул, Азина, 9/а, РБ	f	\N
3674	22897	3454	республика Башкортостан, Янаульский район, Янаул, Азина, 32	f	large
3726	22949	3506	республика Башкортостан, Янаульский район, село Ямады, Центральная, 24	f	medium
3686	22909	3466	республика Башкортостан, Янаульский район, село Юссуково, Центральная, 46	f	small
3728	22951	3508	республика Башкортостан, Янаульский район, село Югамаш, Ф. Халикова, 5	f	small
770	19990	507	республика Башкортостан, Янаульский район, село Энергетик, Высоковольтная, 15	f	large
3725	22948	3505	республика Башкортостан, Янаульский район, село Шудек, Центральная, 53	f	medium
3360	22586	3139	республика Башкортостан, Янаульский район, село Урал, Центральная, 20	f	small
3713	22936	3493	республика Башкортостан, Янаульский район, село Татарская Урада, Верхняя, 6/а	f	small
3716	22939	3496	республика Башкортостан, Янаульский район, село Сусады-Эбалак, Комсомольская, 1	f	medium
3717	22940	3497	республика Башкортостан, Янаульский район, село Старый Сусадыбаш, Центральная, 25	f	small
3699	22922	3479	республика Башкортостан, Янаульский район, село Старый Куюк, Ф.Асхадуллина, 20/а	f	small
3722	22945	3502	республика Башкортостан, Янаульский район, село Старый Варяш, Парковая, 25	f	medium
3691	22914	3471	республика Башкортостан, Янаульский район, село Староый Артаул, Чапаева, 2/б	f	small
3723	22946	3503	республика Башкортостан, Янаульский район, село Старокудашево, Центральная, 2	f	small
3688	22911	3468	республика Башкортостан, Янаульский район, село Староая Орья, Центральная, 13	t	small
3719	22942	3499	республика Башкортостан, Янаульский район, село Сандугач, Комсомольская, 6	f	medium
3727	22950	3507	республика Башкортостан, Янаульский район, село Салихово, Победы, 32	f	small
3721	22944	3501	республика Башкортостан, Янаульский район, село Рабак, Мира, 38	f	small
65897	22928	3485	республика Башкортостан, Янаульский район, село Прогресс, Центральная, 1	f	\N
65898	22933	3490	республика Башкортостан, Янаульский район, село Ошья-Тау, Чишминская, 1	f	\N
3711	22934	3491	республика Башкортостан, Янаульский район, село Новый Артаул, Центральная, 61	f	medium
3708	22931	3488	республика Башкортостан, Янаульский район, село Месягутово, Центральная, 17	f	small
3706	22929	3486	республика Башкортостан, Янаульский район, село Максимово, Молодежная, 8	f	small
3703	22926	3483	республика Башкортостан, Янаульский район, село Кумово, Школьная, 20	f	small
3724	22947	3504	республика Башкортостан, Янаульский район, село Кумалак, Мира, 21	t	small
3704	22927	3484	республика Башкортостан, Янаульский район, село Кисак-Каин, Победы, 4а	f	medium
65896	22925	3482	республика Башкортостан, Янаульский район, село Карманово, Магистральная, 1	f	\N
3701	22924	3481	республика Башкортостан, Янаульский район, село Каймашабаш, Полевая, 6	f	small
3700	22923	3480	республика Башкортостан, Янаульский район, село Иткинеево, Куйбышева, 9	f	medium
3697	22920	3477	республика Башкортостан, Янаульский район, село Истяк, Центральная, 44/а	f	medium
3694	22917	3474	республика Башкортостан, Янаульский район, село Ижболдино, Школьная, 35	f	small
3718	22941	3498	республика Башкортостан, Янаульский район, село Зайцево, Молодежная, 2	f	small
3692	22915	3472	республика Башкортостан, Янаульский район, село Вояды, Новая, 17	f	small
3707	22930	3487	республика Башкортостан, Янаульский район, село Верхняя Барабановка, Г.Файзуллина, 28	f	small
3712	22935	3492	республика Башкортостан, Янаульский район, село Варяш, Механизаторов, 30	f	small
3720	22943	3500	республика Башкортостан, Янаульский район, село Барабановка, Школьная, 18	f	small
3698	22921	3478	республика Башкортостан, Янаульский район, село Ахтиял, Молодежная, 20	f	small
65895	22919	3476	республика Башкортостан, Янаульский район, село Атлегач, Центральная, 12	f	\N
3684	22907	3464	республика Башкортостан, Янаульский район, село Асавдыбаш, Центральная, 33	f	small
3693	22916	3473	республика Башкортостан, Янаульский район, село Акылбай, Центральная, 28	f	small
3689	22912	3469	республика Башкортостан, Янаульский район, село Айбуляк, Центральная, 19	f	small
65887	22856	3411	республика Башкортостан, Шаранский район, село Янгаулово, Центральная, 78 А	f	\N
1044	20244	778	республика Башкортостан, Шаранский район, село Янгаулово, Центральная, 46	f	small
3667	22890	3447	республика Башкортостан, Шаранский район, село Юмадыбаш, Шаранская, 14	f	small
3648	22870	3427	республика Башкортостан, Шаранский район, село Шаранбаш-Князево, Центральная, 33А	f	small
65892	22894	3451	республика Башкортостан, Шаранский район, село Шаран, 7А	f	\N
3669	22892	3449	республика Башкортостан, Шаранский район, село Шаран, Школьная, 2А	f	large
3668	22891	3448	республика Башкортостан, Шаранский район, село Шаран, Пролетарская, 2	f	medium
65891	22893	3450	республика Башкортостан, Шаранский район, село Шаран, Первомайская, 60	f	\N
3635	14659	3414	республика Башкортостан, Шаранский район, село Чупаево, Школьная, 11	f	small
65889	22877	3434	республика Башкортостан, Шаранский район, село Чекан-Тамак, Клубная, 1А	f	\N
3666	22889	3446	республика Башкортостан, Шаранский район, село Чалмалы, Школьная, 3	f	medium
3634	22858	3413	республика Башкортостан, Шаранский район, село Урсаево, Шоссейная, 1	f	small
3651	22873	3430	республика Башкортостан, Шаранский район, село Три Ключа, Возрождения, 55	f	small
3673	22896	3453	республика Башкортостан, Шаранский район, село Тархан, Школьная, 45	f	small
3653	22875	3432	республика Башкортостан, Шаранский район, село Старочикеево, Центральная, 31	f	small
3664	22887	3444	республика Башкортостан, Шаранский район, село Старотумбагушево, Центральная, 14	f	small
3652	22874	3431	республика Башкортостан, Шаранский район, село Соколовка, Школьная, 25А	f	small
3663	22886	3443	республика Башкортостан, Шаранский район, село Сакты, Центральная, 7	f	small
1800	20981	1525	республика Башкортостан, Шаранский район, село Покровка, 30 лет Победы, 26	f	small
3661	22884	3441	республика Башкортостан, Шаранский район, село Писарево, Школьная, 11	f	small
3658	22881	3438	республика Башкортостан, Шаранский район, село Нуреево, Центральная, 18	f	small
3649	22871	3428	республика Башкортостан, Шаранский район, село Новоюмашево, Центральная, 20	f	small
65890	22880	3437	республика Башкортостан, Шаранский район, село Новоюзеево, Центральная, 28Б	f	\N
3631	22855	3410	республика Башкортостан, Шаранский район, село Новотавларово, Центральная, 33	f	small
1857	21037	1581	республика Башкортостан, Шаранский район, село Новотавларово, Октябрьская, 62/1	f	small
1731	20914	1457	республика Башкортостан, Шаранский район, село Новоалександровка, Школьная, 4	f	small
3656	22879	3436	республика Башкортостан, Шаранский район, село Нижние Ташлы, Победы, 18	f	medium
3654	22876	3433	республика Башкортостан, Шаранский район, село Нижнезаитово, Центральная, 30А	f	medium
65893	22895	3452	республика Башкортостан, Шаранский район, село Наратасты, Школьная, 1	f	\N
65888	22857	3412	республика Башкортостан, Шаранский район, село Мещерево, Центральная, 6	f	\N
1435	20624	1165	республика Башкортостан, Шаранский район, село Мещерево, Кооперативная, 24	f	small
3645	22867	3424	республика Башкортостан, Шаранский район, село Куртутель, Школьная, 12	f	small
3655	22878	3435	республика Башкортостан, Шаранский район, село Кугарчи-Буляк, Центральная, 35	f	small
3639	22862	3418	республика Башкортостан, Шаранский район, село Источник, Цветочная, 1А	f	small
3644	22866	3423	республика Башкортостан, Шаранский район, село Зириклы, Дружбы, 2	f	medium
3641	22863	3420	республика Башкортостан, Шаранский район, село Еремкино, Салиха Сабитова, 57	f	small
3660	22883	3440	республика Башкортостан, Шаранский район, село Енахметово, Шадт Булата, 11	f	small
3659	22882	3439	республика Башкортостан, Шаранский район, село Емметово, Мухаметьянова, 2	f	small
3638	22861	3417	республика Башкортостан, Шаранский район, село Дмитриева Поляна, Полевая, 2А	f	small
1654	20712	1380	республика Башкортостан, Шаранский район, село Биккулово, Центральная, 26	f	small
1059	20259	793	республика Башкортостан, Шаранский район, село Биккулово, Центральная, 17	f	small
3636	22859	3415	республика Башкортостан, Шаранский район, село Базгиево, Школьная, 4	f	small
3662	22885	3442	республика Башкортостан, Шаранский район, село Анисимова Поляна, Центральная, 1	f	small
3646	22868	3425	республика Башкортостан, Шаранский район, село Алпаево, Речная, 25	f	small
3630	22854	3409	республика Башкортостан, Шаранский район, село Акбарисово, Центральная, 4	f	small
3574	22799	3353	республика Башкортостан, Чишминский район, село санаторий Алкинский, Нагорная, 1	f	small
3616	22840	3395	республика Башкортостан, Чишминский район, село Ябалаклы, Западная, 8/1	f	small
3617	22841	3396	республика Башкортостан, Чишминский район, село Шингак-Куль, Школьная, 3	f	medium
3618	22842	3397	республика Башкортостан, Чишминский район, село Шингак-Куль, Малокольцевая, 2	f	large
65885	22836	3391	республика Башкортостан, Чишминский район, село Чувалкипово, Центральная, 56, 452166РБ 	f	\N
3625	22849	3404	республика Башкортостан, Чишминский район, село Чишмы, Революционная, 12	f	large
3627	22851	3406	республика Башкортостан, Чишминский район, село Чишмы, Парковая, 18	f	large
3621	22845	3400	республика Башкортостан, Чишминский район, село Чишмы, Ленина, 101а	f	large
3628	22852	3407	республика Башкортостан, Чишминский район, село Чишмы, Кирова, 5	f	large
3626	22850	3405	республика Башкортостан, Чишминский район, село Чишмы, Кирова, 13	f	large
3620	22844	3399	республика Башкортостан, Чишминский район, поселок Чишмы, Элеваторная, 1	f	medium
3624	22848	3403	республика Башкортостан, Чишминский район, поселок Чишмы, Садовая, 7	f	large
3622	22846	3401	республика Башкортостан, Чишминский район, поселок Чишмы, Промышленная, 2	f	medium
3623	22847	3402	республика Башкортостан, Чишминский район, поселок Чишмы, Нагорная, 2	f	medium
3629	22853	3408	республика Башкортостан, Чишминский район, поселок Чишмы, Мира, 21	f	large
3608	22832	3387	республика Башкортостан, Чишминский район, поселок Чишмы, Колхозная, 24	f	large
3577	22802	3356	республика Башкортостан, Чишминский район, село Уразбахты, Школьная, 21	f	small
3575	22800	3354	республика Башкортостан, Чишминский район, село Узытамак, Центральная, 81	f	medium
3613	22837	3392	республика Башкортостан, Чишминский район, село Теперишево, Школьная, 2	f	small
65884	22834	3389	республика Башкортостан, Чишминский район, село Старомусино, Центральная, 39	f	\N
3606	22830	3385	республика Башкортостан, Чишминский район, село Сафарово, Центральная, 21	f	medium
3377	22601	3156	республика Башкортостан, Чишминский район, село Сафарово, Центральная, 93	f	large
3576	22801	3355	республика Башкортостан, Чишминский район, село Салихово, Мира, 29/1	f	small
3605	22829	3384	республика Башкортостан, Чишминский район, село Сайраново, пер.Школьный, 9	f	small
3614	22838	3393	республика Башкортостан, Чишминский район, село Новоусманово, Шоссейная, 19	f	small
3603	22827	3382	республика Башкортостан, Чишминский район, село Новотроицкое, Центральная, 16	f	small
3594	22819	3373	республика Башкортостан, Чишминский район, село Нижнии Термы, Центральная, 38	f	small
3580	22805	3359	республика Башкортостан, Чишминский район, село Кляшево, Мустая Карима, 13	f	small
65782	21469	2018	республика Башкортостан, Чишминский район, село Карамалы, Школьная, 4	f	\N
3599	22824	3378	республика Башкортостан, Чишминский район, село Кара-Якупово, Центральная, 29	f	medium
3592	22817	3371	республика Башкортостан, Чишминский район, село Калмашево, Школьная, 1	f	medium
3609	22833	3388	республика Башкортостан, Чишминский район, село Игнатовка, Центральная, 25	f	medium
3596	22821	3375	республика Башкортостан, Чишминский район, село Ибрагимово, Молодежная, 10	f	small
3586	22811	3365	республика Башкортостан, Чишминский район, село Дурасово, Центральная, 58	f	small
3585	22810	3364	республика Башкортостан, Чишминский район, село Дмитриевка, Старая Деревня, 18	f	small
65886	22839	3394	республика Башкортостан, Чишминский район, село Дмитриевка, Мира, 38	f	\N
3600	22825	3379	республика Башкортостан, Чишминский район, село Горный, Молодежная, 21	f	small
1675	20858	1401	республика Башкортостан, Чишминский район, село Вишневка, Центральная, 1А	f	small
3619	22843	3398	республика Башкортостан, Чишминский район, село Верхний, Школьная, 1	f	small
3593	22818	3372	республика Башкортостан, Чишминский район, село Верхние Термы, Центральная, 75	f	small
3587	22812	3366	республика Башкортостан, Чишминский район, село Булякбашево, Шоссейная, 2а	f	small
3584	22809	3363	республика Башкортостан, Чишминский район, село Бишкази, Новая, 9	f	small
3604	22828	3383	республика Башкортостан, Чишминский район, село Барсуанбашево, Центральная, 35	f	small
3590	22815	3369	республика Башкортостан, Чишминский район, село Балагушево, Молодежная, 1	f	small
3581	22806	3360	республика Башкортостан, Чишминский район, село Арсланово, Центральная, 40	f	medium
3579	22804	3358	республика Башкортостан, Чишминский район, село Арово, Центральная, 23	f	medium
3588	22813	3367	республика Башкортостан, Чишминский район, село Альбеево, Демская, 54	f	small
3602	22826	3381	республика Башкортостан, Чишминский район, село Алкино 2-е, Школьный переулок, 18	f	large
3601	22826	3380	республика Башкортостан, Чишминский район, село Алкино 2-е, Школьный переулок, 18	f	large
3611	22835	3390	республика Башкортостан, Чишминский район, село Абраево, Центральная, 44г	f	small
65874	22768	3323	республика Башкортостан, Чекмагушевский район, село Юмашево, Советская, 16	f	\N
3520	22744	3299	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Тракторная, 23	f	medium
3526	22750	3305	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Мира, 25	f	medium
3528	22752	3307	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Ленина, 7	f	medium
3524	22748	3303	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Ленина, 68	f	medium
3522	22746	3301	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Ленина, 72	f	medium
3519	22743	3298	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Ленина, 81	f	large
3521	22745	3300	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Кооперативная, 61	f	medium
3527	22751	3306	республика Башкортостан, Чекмагушевский район, село Чекмагуш, Западная, 2А	f	medium
65878	22785	3339	республика Башкортостан, Чекмагушевский район, село Урняк, Советская, 18	f	\N
3545	22769	3324	республика Башкортостан, Чекмагушевский район, село Уйбулатово, Кутуева, 5	f	small
3536	22760	3315	республика Башкортостан, Чекмагушевский район, село Тяйняшево, Центральная, 32	f	small
3533	22757	3312	республика Башкортостан, Чекмагушевский район, село Тукаево, Салавата, 22	f	small
3566	22791	3345	республика Башкортостан, Чекмагушевский район, село Тузлукушево, Центральная, 69	f	small
3558	22782	3337	республика Башкортостан, Чекмагушевский район, село Ташкалмашево, Молодежная, 4	f	small
3573	22798	3352	республика Башкортостан, Чекмагушевский район, село Тамьяново, Центральная, 1	f	small
3567	22792	3346	республика Башкортостан, Чекмагушевский район, село Сыйрышбашево, Хузиных, 75А	f	medium
65877	22780	3335	республика Башкортостан, Чекмагушевский район, село Сыйрышбашево, Хузиных, 89	f	\N
65872	22765	3320	республика Башкортостан, Чекмагушевский район, село Старосурметово, Гагарина, 45	f	\N
3543	22767	3322	республика Башкортостан, Чекмагушевский район, село Старопучкаково, Ш.Салихова, 53/1	f	small
65876	22777	3332	республика Башкортостан, Чекмагушевский район, село Старокалмашево, Нефтяников, 1А	f	\N
3552	22776	3331	республика Башкортостан, Чекмагушевский район, село Старокалмашево, Мира, 1А	f	medium
3551	22775	3330	республика Башкортостан, Чекмагушевский район, село Старобиккино, Мира, 76	f	small
3537	22761	3316	республика Башкортостан, Чекмагушевский район, село Старобалаково, В.Галимова, 56	f	small
3539	22763	3318	республика Башкортостан, Чекмагушевский район, село Резяпово, Центральная, 46	f	medium
65875	22772	3327	республика Башкортостан, Чекмагушевский район, село Рапатово, Ленина, 2	f	\N
3535	22759	3314	республика Башкортостан, Чекмагушевский район, село Новые Карьявды, Школьная, 15	f	small
65871	22758	3313	республика Башкортостан, Чекмагушевский район, село Новые Карьявды, Центральная, 46	f	\N
3547	22771	3326	республика Башкортостан, Чекмагушевский район, село Новосеменкино, Свободы, 44	f	small
65883	22797	3351	республика Башкортостан, Чекмагушевский район, село Новокутово, Центральная, 25	f	\N
3557	22781	3336	республика Башкортостан, Чекмагушевский район, село Новокалмашево, С. Муратова, 25	f	small
3559	22784	3338	республика Башкортостан, Чекмагушевский район, село Новоихсаново, 55 лет Победы, 26	f	small
3549	22773	3328	республика Башкортостан, Чекмагушевский район, село Новобиккино, Дуслык, 25	f	small
65870	22755	3310	республика Башкортостан, Чекмагушевский район, село Новобалтачево, Ленина, 83	f	\N
3540	22764	3319	республика Башкортостан, Чекмагушевский район, село Новобалаково, М. Дашкина, 25	f	small
3554	22778	3333	республика Башкортостан, Чекмагушевский район, село Новая Муртаза, Еникеева Рифката, 5	f	small
3530	22754	3309	республика Башкортостан, Чекмагушевский район, село Нариманово, Фабричная, 14	f	small
65873	22766	3321	республика Башкортостан, Чекмагушевский район, село Митро-Аюповское, Молодежная, 2/1	f	\N
3532	22756	3311	республика Башкортостан, Чекмагушевский район, село Ленино, Кашаевых, 28	f	small
3546	22770	3325	республика Башкортостан, Чекмагушевский район, село Караталово, Родниковая, 2	f	small
1838	21018	1562	республика Башкортостан, Чекмагушевский район, село Каран, Новая, 7	f	small
65880	22794	3348	республика Башкортостан, Чекмагушевский район, село Каразириково, Школьная, 16	f	\N
3550	22774	3329	республика Башкортостан, Чекмагушевский район, село Калмашбашево, Центральная, 126	f	medium
65666	20836	1376	республика Башкортостан, Чекмагушевский район, село Калиновка, Центральная, 16	f	\N
65881	22795	3349	республика Башкортостан, Чекмагушевский район, село Имянликулево, Школьная, 3	f	\N
65882	22796	3350	республика Башкортостан, Чекмагушевский район, село Верхний Аташ, Кр. Партизан, 2	f	\N
3565	22790	3344	республика Башкортостан, Чекмагушевский район, село Бардаслы, Первомайская, 39	f	small
3538	22762	3317	республика Башкортостан, Чекмагушевский район, село Ахметово, Нур Гайсина, 33	f	small
65879	22788	3342	республика Башкортостан, Чекмагушевский район, село Аблаево, Советская, 6	f	\N
3564	22789	3343	республика Башкортостан, Чекмагушевский район, село Аблаево, Профессора Кудоярова, 71/2	f	small
3477	22703	3256	республика Башкортостан, Хайбуллинский район, село Янтышево, Школьная, 14	f	small
3504	22728	3283	республика Башкортостан, Хайбуллинский район, село Яковлевка, Ахметшина, 3	f	small
3495	22719	3274	республика Башкортостан, Хайбуллинский район, село Юлбарсово, Вахитова, 16	f	small
2091	21272	1815	республика Башкортостан, Дюртюлинский район, Дюртюли, Ленина, 7	f	large
3514	22738	3293	республика Башкортостан, Хайбуллинский район, село Целинное, Заки Валиди, 2	f	medium
3494	22718	3273	республика Башкортостан, Хайбуллинский район, село Хворостянское, Матросова, 49	f	small
3506	22730	3285	республика Башкортостан, Хайбуллинский район, село Уфимский, Целинная, 17	f	medium
65868	22729	3284	республика Башкортостан, Хайбуллинский район, село Уфимский, Арсланова, 1	f	\N
65863	22691	3244	республика Башкортостан, Хайбуллинский район, село Урняк, Салавата Юлаева, 17	f	\N
3469	22695	3248	республика Башкортостан, Хайбуллинский район, село Уразбаево, Заки Валиди, 8	f	small
3499	22723	3278	республика Башкортостан, Хайбуллинский район, село Таштугай, Бабича, 25	f	small
3503	22727	3282	республика Башкортостан, Хайбуллинский район, село Татыр-Узяк, Победы, 7	f	medium
3476	22702	3255	Россия, республика Башкортостан, Хайбуллинский район, село Степной	f	medium
3492	22716	3271	Россия, республика Башкортостан, Хайбуллинский район, село Самарское	f	medium
3464	22690	3243	республика Башкортостан, Хайбуллинский район, село Сакмар-Назаргулово, Мира, 14	f	small
3475	22701	3254	республика Башкортостан, Хайбуллинский район, село Садовый, Новая, 15	f	small
3009	22173	2727	республика Башкортостан, Хайбуллинский район, село Садовый, Фестивальная, 2/2	f	small
3489	22713	3268	республика Башкортостан, Хайбуллинский район, село Сагитово, Школьная, 19	f	small
3501	22725	3280	республика Башкортостан, Хайбуллинский район, село Савельевка, Муртазина, 9	f	small
3484	22708	3263	республика Башкортостан, Хайбуллинский район, село Пугачево, Яковлева, 7	f	small
65867	22720	3275	республика Башкортостан, Хайбуллинский район, село Подольск, Гагарина, 5	f	\N
3511	22735	3290	республика Башкортостан, Хайбуллинский район, село Петропавловский, Кипчак, 1/1	f	medium
65865	22714	3269	республика Башкортостан, Хайбуллинский район, село Новый Зирган, Баракатова, 43, РБ	f	\N
3500	22724	3279	республика Башкортостан, Хайбуллинский район, село Новоукраинка, Полтавская, 5	f	small
3510	22734	3289	республика Башкортостан, Хайбуллинский район, село Мурзино 1-е, Победы, 2	t	small
3483	22707	3262	республика Башкортостан, Хайбуллинский район, село Михайловка, Худайбердина, 20	t	small
3487	22711	3266	республика Башкортостан, Хайбуллинский район, село Мамбетово, Салавата Юлаева, 13	f	small
1275	20465	1005	республика Башкортостан, Хайбуллинский район, село Мамбетово, Набережная, 8	f	small
3462	22688	3241	республика Башкортостан, Хайбуллинский район, село Малоарслангулово, Молодежная, 31	f	small
3488	22712	3267	республика Башкортостан, Хайбуллинский район, село Макан, Целинная, 58	f	medium
3517	22741	3296	республика Башкортостан, Хайбуллинский район, село Исянгильдино, Акмуллы, 4	f	small
65866	22715	3270	республика Башкортостан, Хайбуллинский район, село Илячево, Мира, 3	f	\N
3482	22706	3261	республика Башкортостан, Хайбуллинский район, село Ивановка, Заки Валиди, 27	f	medium
3498	22722	3277	республика Башкортостан, Хайбуллинский район, Деревня Адель, Акмулы, 4	f	small
65864	22692	3245	республика Башкортостан, Хайбуллинский район, село Галиахметово, Гагарина, 19	f	\N
3486	22710	3265	республика Башкортостан, Хайбуллинский район, село Воздвиженка, Первоцелинников, 20	f	small
3479	22646	3258	республика Башкортостан, Хайбуллинский район, поселок Бурибай, Тасимова, 51	f	large
3480	22685	3259	республика Башкортостан, Хайбуллинский район, поселок Бурибай, Заки Валиди, 40	f	large
3481	22705	3260	республика Башкортостан, Хайбуллинский район, поселок Бурибай, Гагарина, 12а	f	large
3493	22717	3272	республика Башкортостан, Хайбуллинский район, село Бузавлык, Юбилейная, 11	f	small
3463	22689	3242	республика Башкортостан, Хайбуллинский район, село Большеарслангулово, Дружбы, 12	f	small
65862	22687	3240	республика Башкортостан, Хайбуллинский район, село Большеабишево, Ахметшина, 19	f	\N
3497	22721	3276	республика Башкортостан, Хайбуллинский район, село Бакаловская, Победы, 16	f	small
3502	22726	3281	республика Башкортостан, Хайбуллинский район, село Байгускарово, Гагарина, 13	f	medium
3478	22704	3257	республика Башкортостан, Хайбуллинский район, село Антинган, К.Ахметшина, 2	f	small
70693	79801	111	Самарская область, Чапаевск, Карла Маркса, 12	f	large
3507	22731	3286	республика Башкортостан, Хайбуллинский район, село Алибаевское, Дружбы, 10	f	small
3472	22698	3251	Россия, республика Башкортостан, Хайбуллинский район, село Акъяр	f	medium
3470	22696	3249	республика Башкортостан, Хайбуллинский район, село Акъяр, Энергетиков, 1	f	medium
3471	22697	3250	республика Башкортостан, Хайбуллинский район, село Акъяр, Подгорная, 69	f	medium
3474	22700	3253	республика Башкортостан, Хайбуллинский район, село Акъяр, Акмуллы, 9/1	f	medium
3473	22699	3252	республика Башкортостан, Хайбуллинский район, село Акъяр, Акмуллы, 7	f	medium
3468	22694	3247	республика Башкортостан, Хайбуллинский район, село Акъюлово, Горная, 20	f	small
3485	22709	3264	республика Башкортостан, Хайбуллинский район, село Акташево, М. Муртазина, 17/2	f	small
3467	22693	3246	республика Башкортостан, Хайбуллинский район, село Акназарово, Акназарова, 18	f	small
3513	22737	3292	республика Башкортостан, Хайбуллинский район, село Абубакирово, Заки Валиди, 1	f	small
3518	22742	3297	республика Башкортостан, Хайбуллинский район, село Абдулнасырово, Абдулнасыровская, 6А	t	small
3453	22678	3232	республика Башкортостан, Федоровский район, село Федоровка, Центральная, 18	f	small
3445	22670	3224	республика Башкортостан, Федоровский район, село Федоровка, Центральная, 10	f	small
3435	22660	3214	республика Башкортостан, Федоровский район, село Федоровка, Первая, 27	f	small
3458	22683	3237	республика Башкортостан, Федоровский район, село Федоровка, Коммунистическая, 92а	f	medium
3454	22679	3233	республика Башкортостан, Федоровский район, село Федоровка, Дружбы, 91	f	small
2932	22097	2650	республика Башкортостан, Федоровский район, село Новояушево, Ленина, 37а	f	small
3428	22653	3207	республика Башкортостан, Федоровский район, село Каралачик, Центральная, 57	f	small
3444	22669	3223	Россия, республика Башкортостан, Федоровский район, село Денискино	f	medium
3448	22673	3227	республика Башкортостан, Федоровский район, село Гончаровка, Салавата Юлаева, 10	f	medium
3427	22652	3206	республика Башкортостан, Федоровский район, село Балыклы, Ленина, 8	f	medium
3402	22626	3181	республика Башкортостан, Учалинский район, Учалы, Школьная, 2, ПУ №98	f	small
3398	22622	3177	республика Башкортостан, Учалинский район, Учалы, Тагирова, 1а	f	small
3420	22633	3188	республика Башкортостан, Учалинский район, Учалы, Строительная, 8, 2-й уч. корпус УУИиК	f	large
3409	22634	3189	республика Башкортостан, Учалинский район, Учалы, Пионерская, 6, техникум	f	large
3399	22623	3178	республика Башкортостан, Учалинский район, Учалы, Партизанская, 16, лесхоз	f	medium
3410	22635	3190	республика Башкортостан, Учалинский район, Учалы, Мира, 3, Ледовая арена	f	large
3424	22639	3194	республика Башкортостан, Учалинский район, Учалы, Ленина, 27	f	large
3419	22644	3199	республика Башкортостан, Учалинский район, Учалы, Ахметгалина, 12, Помещение ТОУ Роспотребнадзор	f	large
3414	22643	3198	республика Башкортостан, Учалинский район, Учалы, Ахметгалина, 6, Ветстанция	f	large
3407	22630	3185	республика Башкортостан, Учалинский район, Учалы, Чехова, 17, Торговый центр	f	small
3397	22621	3176	республика Башкортостан, Учалинский район, село Учалы, Элеваторный переулок, 1, Элеватор	f	medium
3396	22620	3175	республика Башкортостан, Учалинский район, село Учалы, С.Юлаева, 4, детский сад	f	medium
3393	22617	3172	республика Башкортостан, Учалинский район, село Уральск, Гагарина, 12	f	large
3389	22613	3168	республика Башкортостан, Учалинский район, село Уразово, Центральная, 16	f	medium
65860	22604	3159	республика Башкортостан, Учалинский район, село Тунгатарово, Ирандыкская, 41а	f	\N
3344	22570	3123	республика Башкортостан, Учалинский район, село Сураманово, Школьная, 14	f	small
2556	21724	2275	республика Башкортостан, Учалинский район, село Сулейманово, Турновская, 19	f	small
3379	22603	3158	республика Башкортостан, Учалинский район, село Старомуйнаково, Школьная, 6	f	small
3383	22607	3162	республика Башкортостан, Учалинский район, село Старобалбуково, Клубная, 8/2	f	small
3384	22608	3163	республика Башкортостан, Учалинский район, село Старобайрамгулово, Центральная, 47	f	small
3403	22627	3182	республика Башкортостан, Учалинский район, село Сайтаково, М.Шагеева, 31	f	small
3356	22582	3135	республика Башкортостан, Учалинский район, село Рысаево, Центральная, 1	f	small
3359	22585	3138	республика Башкортостан, Учалинский район, село Расулево, Школьная, 33	f	small
3375	22599	3154	республика Башкортостан, Учалинский район, село Поляковка, Советская, 94	f	small
3378	22602	3157	республика Башкортостан, Учалинский район, село Первый Май, Заречная, 7	f	small
3392	22616	3171	республика Башкортостан, Учалинский район, село Октябрьск, Школьная, 25	f	small
2937	22102	2655	республика Башкортостан, Учалинский район, село Октябрьск, Центральная, 17	f	small
65858	22594	3149	республика Башкортостан, Учалинский район, село Озерный, Школьная, 31	f	\N
3374	22598	3153	республика Башкортостан, Учалинский район, село Новобайрамгулово, Шоссейная, 43	f	medium
3373	22597	3152	республика Башкортостан, Учалинский район, село Наурузово, Школьный, 7	f	small
3395	22619	3174	республика Башкортостан, Учалинский район, село Мулдашево, Школьная, 10	f	small
3351	22577	3130	республика Башкортостан, Учалинский район, село Мулдашево, Иремельская, 49	f	small
3372	22596	3151	республика Башкортостан, Учалинский район, село Москово, Школьная, 24	f	small
3368	22592	3147	республика Башкортостан, Учалинский район, поселок Миндяк, Уфимская, 3	f	large
3365	22589	3144	республика Башкортостан, Учалинский район, село Мансурово, Мира, 7б	f	medium
3345	22571	3124	республика Башкортостан, Учалинский район, село Малоказаккулово, Советская, 30	f	small
3352	22578	3131	республика Башкортостан, Учалинский район, село Кучуково, Хандугас, 1	f	small
65861	22606	3161	республика Башкортостан, Учалинский район, поселок Курамино, Соловьиная, 9	f	\N
3363	22587	3142	республика Башкортостан, Учалинский район, село Кунакбаево, Шоссейная, 23	f	medium
3358	22584	3137	республика Башкортостан, Учалинский район, село Кудашево, Салавата, 49	f	small
3369	22593	3148	республика Башкортостан, Учалинский район, село Кубагушево, Куяшевская, 36	f	small
65869	22739	3294	республика Башкортостан, Учалинский район, село Комсомольск, З.Биишевой, 3	f	\N
3381	22605	3160	республика Башкортостан, Учалинский район, село Комсомольск, Беркут Тау, 43	f	small
3361	22535	3140	республика Башкортостан, Учалинский район, село Кирябинское, Никольская, 10	f	small
3350	22576	3129	республика Башкортостан, Учалинский район, село Каримово, Центральная, 21	f	small
3394	22618	3173	республика Башкортостан, Учалинский район, село Калканово, Школьная, 2	f	small
3385	22609	3164	республика Башкортостан, Учалинский район, село Кажаево, Центральная, 7	f	small
3386	22610	3165	республика Башкортостан, Учалинский район, село Ишмекеево, Сорагул, 3	f	small
3391	22615	3170	республика Башкортостан, Учалинский район, село Ишкиново, Школьная, 22	f	small
3390	22614	3169	республика Башкортостан, Учалинский район, село Истамгулово, Центральная, 29	f	small
3357	22583	3136	республика Башкортостан, Учалинский район, село Имангулово, Центральная, 49	f	medium
3355	22581	3134	республика Башкортостан, Учалинский район, село Ильчино, Кучербай, 2	f	medium
3349	22575	3128	республика Башкортостан, Учалинский район, село Ильчигулово, Агышбай, 60	f	medium
3376	22600	3155	республика Башкортостан, Учалинский район, село Вознесенка, Зеленая, 24	f	small
3348	22574	3127	республика Башкортостан, Учалинский район, село Буйда, Центральная, 35	f	medium
65859	22595	3150	республика Башкортостан, Учалинский район, село Батталово, Школьная, 2	f	\N
3347	22573	3126	республика Башкортостан, Учалинский район, село Ахуново, Партизанская, 121	f	medium
3346	22572	3125	республика Башкортостан, Учалинский район, село Ахуново, Партизанская, 67	f	large
1026	20132	761	Россия, республика Башкортостан, Абзелиловский район, село Аслаево	t	small
3366	22590	3145	республика Башкортостан, Учалинский район, село Абзаково, Шоссейная, 1а	f	medium
3341	22567	3120	республика Башкортостан, Уфимский район, село санаторий Юматово, Кольцевая, 27	f	medium
3343	22569	3122	республика Башкортостан, Уфимский район, поселок Юматово, Центральная, 46	f	large
3342	22568	3121	республика Башкортостан, Уфимский район, поселок Юматово, Северная, 51	f	medium
3340	22566	3119	республика Башкортостан, Уфимский район, село Шемяк, Молодежная, 6	f	small
3333	22559	3112	республика Башкортостан, Уфимский район, деревня Чуварез, Заречная, 1	f	small
3334	22560	3113	республика Башкортостан, Уфимский район, деревня Чесноковка, Школьная, 47	f	large
3322	22547	3101	республика Башкортостан, Уфимский район, село Чернолесовский, Школьная, 12	f	medium
3332	22558	3111	республика Башкортостан, Уфимский район, село Черкасы, Трактовая, 11	f	small
3314	22539	3093	республика Башкортостан, Уфимский район, село Сергеевка, Центральная, 5а	f	small
3329	22555	3108	республика Башкортостан, Уфимский район, село Русский Юрмаш, Центральная, 19	f	medium
3310	22534	3089	республика Башкортостан, Уфимский район, село Подымалово, Южная, 22	f	large
3339	22565	3118	республика Башкортостан, Уфимский район, село Первомайский, Школьная, 24	f	small
3328	22554	3107	республика Башкортостан, Уфимский район, село Ольховое, Буденова, 6	f	medium
3336	22562	3115	республика Башкортостан, Уфимский район, село Октябрьский, Центральная, 14а	f	large
3327	22553	3106	республика Башкортостан, Уфимский район, село Нурлино, Школьная, 22	f	large
3338	22564	3117	республика Башкортостан, Уфимский район, село Новотроевка, Школьная, 14а	f	small
3326	22552	3105	республика Башкортостан, Уфимский район, село Николаевка, Советская, 22	f	large
3316	22541	3095	республика Башкортостан, Уфимский район, село Нижегородка, Мира, 26/1	f	large
3324	22549	3103	республика Башкортостан, Уфимский район, село Михайловка, Ленина, 48	f	large
3313	22538	3092	республика Башкортостан, Уфимский район, деревня Мармылево, Школьная, 3/2	f	small
65857	22546	3100	республика Башкортостан, Уфимский район, село Кумлекуль, Центральная, 15	f	\N
3320	22545	3099	республика Башкортостан, Уфимский район, село Красный Яр, Советская, 82	f	large
3312	22537	3091	республика Башкортостан, Уфимский район, село Жуково, Ильина, 1а	f	large
3307	22531	3086	республика Башкортостан, Уфимский район, село Дмитриевка, Советская, 23	f	large
3311	22536	3090	республика Башкортостан, Уфимский район, село Волково, Мкр.Солнечный, 1	f	medium
3337	22563	3116	республика Башкортостан, Уфимский район, село Бейгулово, Бейгуловская, 13/1	f	small
3318	22543	3097	республика Башкортостан, Уфимский район, село Асаново, Восточная, 1	f	small
3303	22527	3082	республика Башкортостан, Уфимский район, деревня Алексеевка, Школьная, 4	f	large
3302	22526	3081	республика Башкортостан, Уфимский район, деревня Алексеевка, Центральная, 52	f	large
3301	22525	3080	республика Башкортостан, Уфимский район, село Авдон, 60-летия СССР, 2	f	large
3300	22525	3079	республика Башкортостан, Уфимский район, село Авдон, 60-летия СССР, 2	f	large
3436	22661	3215	республика Башкортостан, Туймазинский район, село совхоза Имени 1-го Мая, 35	f	small
3255	22480	3034	республика Башкортостан, Туймазинский район, село Япрыково, Уфимская, 8	f	medium
3267	22492	3046	Россия, республика Башкортостан, Туймазинский район, село Чукадытамак	f	small
3289	22514	3068	республика Башкортостан, Туймазинский район, село Чуваш-Улканово, Пушкина, 2	f	small
3250	22477	3029	республика Башкортостан, Туймазинский район, село Фрунзе, Центральная, 1	f	small
3273	22498	3052	республика Башкортостан, Туймазинский район, село Уязытамак, Школьная, 69	f	small
3280	22505	3059	республика Башкортостан, Туймазинский район, село Урмекеево, Социалистическая, 49	f	small
3244	22471	3023	республика Башкортостан, Туймазинский район, село Туктагулово, Центральная, 32А	f	medium
3224	22450	3003	республика Башкортостан, Туймазинский район, Туймазы, Советская, 2Б	f	large
65856	22457	3010	республика Башкортостан, Туймазинский район, Туймазы, Пугачева, 5-а	f	\N
3228	22454	3007	республика Башкортостан, Туймазинский район, Туймазы, Островского, 11	f	large
3217	22443	2996	республика Башкортостан, Туймазинский район, Туймазы, Луначарского, 24	f	large
65855	22444	2997	республика Башкортостан, Туймазинский район, Туймазы, Лесовода Морозова, 5	f	\N
3235	22462	3014	республика Башкортостан, Туймазинский район, Туймазы, Комарова, 26А	f	large
3232	22458	3011	республика Башкортостан, Туймазинский район, Туймазы, Гагарина, 32	f	large
3293	22518	3072	республика Башкортостан, Туймазинский район, село Тирян-Елга, Лесная, 11	f	small
3288	22513	3067	республика Башкортостан, Туймазинский район, село Татар-Улканово, Ленина, 15	f	small
3286	22511	3065	республика Башкортостан, Туймазинский район, поселок Субханкулово, Школьная, 1	f	large
3285	22510	3064	республика Башкортостан, Туймазинский район, поселок Субханкулово, Черняева, 3	f	large
3284	22509	3063	республика Башкортостан, Туймазинский район, село Старые Туймазы, Гаражная, 2А	f	large
3262	22487	3041	республика Башкортостан, Туймазинский район, село Старые Кандры, Центральная, 30А	f	small
3282	22507	3061	республика Башкортостан, Туймазинский район, поселок Серафимовский, площадь Советская, 5	f	large
3283	22508	3062	республика Башкортостан, Туймазинский район, поселок Серафимовский, Ленина, 9	f	large
3281	22506	3060	республика Башкортостан, Туймазинский район, поселок Серафимовский, 21-ый квартал, 1	f	large
3279	22504	3058	республика Башкортостан, Туймазинский район, село Сайраново, Советская, 2	f	medium
3297	22522	3076	республика Башкортостан, Туймазинский район, село Райманово, Гагарина, 35	f	medium
3287	22512	3066	республика Башкортостан, Туймазинский район, село Нуркеево, Первомайская, 24	f	large
3253	22461	3032	республика Башкортостан, Туймазинский район, село Никитинка, Центральная, 47	f	small
3291	22516	3070	республика Башкортостан, Туймазинский район, село Нижний Сардык, Центральная, 41А	f	small
3248	22475	3027	республика Башкортостан, Туймазинский район, село Нижнии Бишинды, Зеленая, 53А	f	medium
3275	22500	3054	республика Башкортостан, Туймазинский район, поселок Нижнетроицкий, Ленина, 59а	f	large
3274	22499	3053	республика Башкортостан, Туймазинский район, поселок Нижнетроицкий, Гагарина, 6	f	large
3268	22493	3047	республика Башкортостан, Туймазинский район, село Метевтамак, Чапаева, 35	f	small
1859	21039	1583	республика Башкортостан, Туймазинский район, село Киска-Елга, Коммунистическая, 22	f	small
3278	22503	3057	республика Башкортостан, Туймазинский район, село Кендектамак, Клубная, 2	f	small
3272	22497	3051	республика Башкортостан, Туймазинский район, село Каратово, Школьная, 41	f	small
3266	22491	3045	республика Башкортостан, Туймазинский район, село Карамалы-Губеево, Ленина, 65	f	medium
3277	22502	3056	республика Башкортостан, Туймазинский район, село Кандрыкуль, Озерная, 91	f	small
3263	22488	3042	республика Башкортостан, Туймазинский район, село Кандры-Кутуй, Молодежная, 28	f	medium
3260	22485	3039	республика Башкортостан, Туймазинский район, поселок Кандры, Мира, 10	f	large
3258	22483	3037	республика Башкортостан, Туймазинский район, поселок Кандры, Матросова, 14	f	large
3259	22484	3038	республика Башкортостан, Туймазинский район, поселок Кандры, Крупской, 5	f	large
3261	22486	3040	республика Башкортостан, Туймазинский район, поселок Кандры, Вострецова, 2	f	large
3269	22494	3048	республика Башкортостан, Туймазинский район, село Кальшали, Центральная, 22	f	small
3256	22481	3035	республика Башкортостан, Туймазинский район, село Какрыбашево, Школьная, 10	f	medium
3254	22479	3033	республика Башкортостан, Туймазинский район, село Ильчимбетово, Советская, 1	f	medium
3264	22489	3043	республика Башкортостан, Туймазинский район, село Ермухаметово, Даутова, 1Б	f	medium
3245	22472	3024	республика Башкортостан, Туймазинский район, село Ермyнчино, Центральная, 19А	f	small
3252	22427	3031	республика Башкортостан, Туймазинский район, село Дуслык, Клубная, 1А	f	large
3251	22478	3030	республика Башкортостан, Туймазинский район, село Гафурово, Школьная, 41	f	large
3292	22517	3071	республика Башкортостан, Туймазинский район, село Верхний Сардык, Центральная, 22А	f	small
3246	22473	3025	республика Башкортостан, Туймазинский район, село Верхние Бишинды, Победы, 48А	f	medium
3249	22476	3028	республика Башкортостан, Туймазинский район, село Верхнетроицкое, Базарная, 28	f	medium
3243	22470	3022	республика Башкортостан, Туймазинский район, село Бишкураево, Гагарина, 12А	f	small
3290	22515	3069	республика Башкортостан, Туймазинский район, село Аднагулово, Центральная, 31А	f	small
3295	22520	3074	республика Башкортостан, Туймазинский район, село Агиртамак, Комарова, 47В	f	medium
3257	22482	3036	республика Башкортостан, Туймазинский район, село Аблаево, Центральная, 382	f	small
3214	22440	2993	республика Башкортостан, Татышлинский район, село Ялгыз-Нарат, Центральная, 3а	f	small
3177	22407	2956	республика Башкортостан, Татышлинский район, село Юда, Центральная, 35	f	small
3211	22437	2990	республика Башкортостан, Татышлинский район, село Шулганово, Центральная, 58	f	medium
3169	22399	2948	республика Башкортостан, Татышлинский район, село Чургулды, Ленина, 36А	f	small
3210	22436	2989	республика Башкортостан, Татышлинский район, село Уразгильды, Центральная, 32	f	small
3194	22419	2973	республика Башкортостан, Татышлинский район, село Старый Шардак, Центральная, 33	t	small
3216	22442	2995	республика Башкортостан, Татышлинский район, село Старый Сикияз, Дружбы, 63	f	small
3200	22425	2979	республика Башкортостан, Татышлинский район, село Старый Курдым, Центральная, 25	f	small
3206	22432	2985	республика Башкортостан, Татышлинский район, село Староый Кызыл-Яр, Центральная, 22а	f	small
65852	22408	2962	республика Башкортостан, Татышлинский район, село Старочукурово, М.Джалиля, 1	f	\N
3178	22317	2957	республика Башкортостан, Татышлинский район, село Старосолодово, Лесная, 39	f	small
3189	22414	2968	республика Башкортостан, Татышлинский район, село Старокальмиярово, Советская, 6	f	medium
3182	22389	2961	республика Башкортостан, Татышлинский район, село Старокайпаново, Центральная, 66	f	small
3167	22397	2946	республика Башкортостан, Татышлинский район, село Староакбулатово, Центральная, 36б	f	small
3190	22415	2969	республика Башкортостан, Татышлинский район, село Савкияз, Центральная, 24	f	small
3168	22398	2947	республика Башкортостан, Татышлинский район, село Савалеево, Центральная, 24	f	small
2957	22121	2675	республика Башкортостан, Татышлинский район, село Новоакбулатово, Ленина, 24	f	small
3181	22374	2960	республика Башкортостан, Татышлинский район, село Маматаево, Центарльная, 13	f	small
3209	22435	2988	республика Башкортостан, Татышлинский район, село Малая Бальзюга, М.Гарипова, 30	f	small
3207	22433	2986	республика Башкортостан, Татышлинский район, село Кыткы-Елга, Парковая, 2	f	small
3198	22423	2977	республика Башкортостан, Татышлинский район, село Кардагушево, Фрунзе, 33	f	small
3192	22417	2971	республика Башкортостан, Татышлинский район, село Кальтяево, Арманшина, 67	f	small
3174	22404	2953	республика Башкортостан, Татышлинский район, село Ильметово, Центральная, 42	f	small
3212	22438	2991	республика Башкортостан, Татышлинский район, село Гарибашево, Октябрьская, 8	f	small
3188	22413	2967	республика Башкортостан, Татышлинский район, село Верхние Татышлы, Строителей, 21	f	medium
3187	22412	2966	республика Башкортостан, Татышлинский район, село Верхние Татышлы, Советская, 2	f	large
3186	22411	2965	республика Башкортостан, Татышлинский район, село Верхние Татышлы, Ленина, 57	f	medium
3185	22410	2964	республика Башкортостан, Татышлинский район, село Верхние Татышлы, Ленина, 67	f	large
3184	22409	2963	республика Башкортостан, Татышлинский район, село Верхние Татышлы, Комсомольская, 36	f	medium
3196	22421	2975	республика Башкортостан, Татышлинский район, село Верхнекудашево, Хайдарова, 1	f	small
65853	22420	2974	республика Башкортостан, Татышлинский район, село Верхнекудашево, Хайдарова, 23	f	\N
3179	22330	2958	республика Башкортостан, Татышлинский район, село Буль-Кайпаново, Ленина, 47	f	medium
3176	22406	2955	республика Башкортостан, Татышлинский район, село Беляшево, Школьная, 30	f	small
3215	22441	2994	республика Башкортостан, Татышлинский район, село Башкибаш, Центральная, 47а	f	small
3175	22405	2954	республика Башкортостан, Татышлинский район, село Бадряшево, Матросова, 6	f	small
3171	22401	2950	республика Башкортостан, Татышлинский район, село Артаулово, Центральная, 32	f	small
65854	22422	2976	республика Башкортостан, Татышлинский район, село Арибашево, Школьная, 2	f	\N
3170	22400	2949	республика Башкортостан, Татышлинский район, село Аксаитово, Центральная, 42	f	medium
3203	22429	2982	республика Башкортостан, Татышлинский район, село 2-й Зиримзибаш, Центральная, 33	t	small
3156	22321	2874	республика Башкортостан, Стерлитамакский район, село совхоза Первомайский, Молодежная, 6/2	f	medium
109406	22377	2885	республика Башкортостан, Стерлитамакский район, село совхоза Первомайский, Дружбы, 13	f	\N
109422	22394	2901	республика Башкортостан, Стерлитамакский район, с. Нижние Услы, Имая Насыри, 46а	f	\N
109412	22383	2891	республика Башкортостан, Стерлитамакский район, с. Большое Аксаково, Южная, 24, 453152 РБ	f	\N
109398	22368	2938	республика Башкортостан, Стерлитамакский район, село отделение Совхоза Южное Первомайский, Степная, 1а	f	\N
109407	22378	2886	республика Башкортостан, Стерлитамакский район, село отделение Красноармейское, Мира, 17	f	\N
109409	22380	2888	республика Башкортостан, Стерлитамакский район, село отделение Бегеняш Совхоза Первомайский, Ленина, 23а	f	\N
1820	21000	1544	республика Башкортостан, Стерлитамакский район, село база Заготовки Скота, Набережная, 2	f	small
109368	22337	2908	республика Башкортостан, Стерлитамакский район, село Юрактау, Шоссейная, 10а	f	\N
109423	22395	2902	республика Башкортостан, Стерлитамакский район, село Чуртан, Молодежная, 5 е	f	\N
109382	22351	2922	республика Башкортостан, Стерлитамакский район, село Чувашский Чуганак, Центральная, 1	f	\N
109424	22396	2903	республика Башкортостан, Стерлитамакский район, село Услыбаш, Мира, 12в, 453162РБ	f	\N
109420	22392	2899	республика Башкортостан, Стерлитамакский район, село Тюрюшля, Центральная, 43г	f	\N
109375	22344	2915	республика Башкортостан, Стерлитамакский район, село Талачево, Октябрьская, 32	f	\N
109415	22386	2894	республика Башкортостан, Стерлитамакский район, село Талалаевка, Мира, 22	f	\N
1004	20210	741	республика Башкортостан, Стерлитамакский район, Стерлитамак, Водолаженко, 2А	f	large
109397	22367	2937	республика Башкортостан, Стерлитамакский район, поселок Северное Отделение, Московская, 1а	f	\N
109376	22345	2916	республика Башкортостан, Стерлитамакский район, село Садовка, Первомайская, 31 а	f	\N
109417	22388	2896	республика Башкортостан, Стерлитамакский район, село Рязановка, Центральная, 77	f	\N
109416	22387	2895	республика Башкортостан, Стерлитамакский район, село Рощинский, Лесная, 13	f	\N
109395	22365	2935	республика Башкортостан, Стерлитамакский район, село Преображеновка, Молодежная, 4	f	\N
109365	22334	2905	республика Башкортостан, Стерлитамакский район, село Помряскино, Центральная, 73	f	\N
109391	22361	2931	республика Башкортостан, Стерлитамакский район, село Покровка, Центральная, 37, 453167 РБ	f	\N
109384	22353	2924	республика Башкортостан, Стерлитамакский район, село Покровка, Мира, 9	f	\N
109413	22384	2892	республика Башкортостан, Стерлитамакский район, село Подлесное, Центральная, 32а, 453152РБ	f	\N
109396	22366	2936	республика Башкортостан, Стерлитамакский район, село Октябрьское, Мира, 8	f	\N
109370	22339	2910	республика Башкортостан, Стерлитамакский район, село Новофедоровское, Центральная, 20 б	f	\N
109377	22346	2917	республика Башкортостан, Стерлитамакский район, село Новое Барятино, Дружбы, 25	f	\N
109401	22371	2941	республика Башкортостан, Стерлитамакский район, село Новая Отрадовка, Школьная	f	\N
109372	22341	2912	республика Башкортостан, Стерлитамакский район, село Новая Васильевка, Центральная, 27, 453142РБ	f	\N
1781	20961	1506	республика Башкортостан, Стерлитамакский район, село Николаевка, Нижняя, 91	f	small
109389	22358	2929	республика Башкортостан, Стерлитамакский район, село Наумовка, Студенческая, 3, РБ	f	\N
109388	22357	2928	республика Башкортостан, Стерлитамакский район, село Наумовка, Ленина, 16	f	\N
109373	22342	2913	республика Башкортостан, Стерлитамакский район, село Мурдашево, Сухайлинская, 22 а	f	\N
109410	22381	2889	республика Башкортостан, Стерлитамакский район, село Матвеевка, Полевая, 3а	f	\N
109403	22373	2943	республика Башкортостан, Стерлитамакский район, село Мариинский, Молодежная, 2 а	f	\N
109404	22375	2944	республика Башкортостан, Стерлитамакский район, село Мариинский, Лазурная, 9	f	\N
109386	22355	2926	республика Башкортостан, Стерлитамакский район, село Максимовка, Молодежная, 4	f	\N
109418	22390	2897	республика Башкортостан, Стерлитамакский район, село Кучербаево, Мира, 87	f	\N
109408	22379	2887	республика Башкортостан, Стерлитамакский район, село Кузьминовка, Степная, 12, 453164РБ	f	\N
109380	22349	2920	республика Башкортостан, Стерлитамакский район, поселок Косяковка, Ленина, 91а	f	\N
109379	22348	2919	республика Башкортостан, Стерлитамакский район, село Константиноградовка, Мира, 41ж	f	\N
109399	22369	2939	республика Башкортостан, Стерлитамакский район, село Кононовский, Трудовая, 2, 453147РБ	f	\N
109378	22347	2918	республика Башкортостан, Стерлитамакский район, село Кармаскалы, Трудовая, 2	f	\N
109393	22363	2933	республика Башкортостан, Стерлитамакский район, село Кантюковка, Школьная, 1а	f	\N
109414	22385	2893	республика Башкортостан, Стерлитамакский район, село Ишпарсово, Школьная, 17б	f	\N
109419	22391	2898	республика Башкортостан, Стерлитамакский район, село Золотоношка, Центральная, 1з	f	\N
109390	22360	2930	республика Башкортостан, Стерлитамакский район, село Заливной, Клубная, 6, 453167 РБ	f	\N
109402	22372	2942	республика Башкортостан, Стерлитамакский район, село Загородный, Фестивальная, 7е, 453140 РБ	f	\N
109366	22335	2906	республика Башкортостан, Стерлитамакский район, село Забельское, Советская, 2 б	f	\N
109405	22376	2945	республика Башкортостан, Стерлитамакский район, село Дергачевка, Дружбы, 5	f	\N
2902	22071	2620	республика Башкортостан, Стерлитамакский район, село Восточный, Парковая, 13	f	small
109400	22370	2940	республика Башкортостан, Стерлитамакский район, село Веселый, Луговая, 20а	f	\N
109421	22393	2900	республика Башкортостан, Стерлитамакский район, село Верхние Услы, 40 лет Победы, 13	f	\N
109374	22343	2914	республика Башкортостан, Стерлитамакский район, село Буриказганово, Советская, 64	f	\N
109385	22354	2925	республика Башкортостан, Стерлитамакский район, село Бугуруслановка, Садовая, 36а	f	\N
109383	22352	2923	республика Башкортостан, Стерлитамакский район, село Большой Куганак, Ленина, 2	f	\N
109371	22340	2911	республика Башкортостан, Стерлитамакский район, село Аючево, Янаульская, 47а	f	\N
109387	22356	2927	республика Башкортостан, Стерлитамакский район, село Алга, Дружбы, 34	f	\N
109364	22333	2904	республика Башкортостан, Стерлитамакский район, село Айгулево, Центральная, 31 а	f	\N
919	20127	656	республика Башкортостан, Стерлитамак городской округ, Стерлитамак, Садовая, 20	f	medium
3138	22302	2856	республика Башкортостан, Стерлибашевский район, село Яшерганово, Р.Кашапова, 92	f	medium
3165	22331	2883	республика Башкортостан, Стерлибашевский район, село Янгурча, Советская, 19А	f	small
65851	22326	2879	республика Башкортостан, Стерлибашевский район, село Юмагузино, Лесная, 2, РБ	f	\N
3141	22306	2859	республика Башкортостан, Стерлибашевский район, село Халикеево, Центральная, 4	f	small
3140	22305	2858	республика Башкортостан, Стерлибашевский район, село Учуган-Асаново, Школьная, 7	f	small
3135	22299	2853	республика Башкортостан, Стерлибашевский район, село Тятер-Арасланово, К.Маркса, 102Б	f	medium
3164	22329	2882	республика Башкортостан, Стерлибашевский район, село Турмаево, Школьная, 4	f	small
3155	22320	2873	республика Башкортостан, Стерлибашевский район, село Стерлибашево, Школьная, 1А	f	large
3152	22304	2870	республика Башкортостан, Стерлибашевский район, село Стерлибашево, Комсомольская, 13	f	large
3153	22318	2871	республика Башкортостан, Стерлибашевский район, село Стерлибашево, Карла Маркса, 70	f	large
3154	22319	2872	республика Башкортостан, Стерлибашевский район, село Стерлибашево, К.Маркса, 107	f	large
2998	22162	2716	республика Башкортостан, Стерлибашевский район, село Раевка, Ворошилова, 12	f	small
3083	22247	2801	республика Башкортостан, Стерлибашевский район, село Первомайск, Центральная	f	small
3163	22328	2881	республика Башкортостан, Стерлибашевский район, село Новый Калкаш, Центральная, 1	f	small
3145	22310	2863	республика Башкортостан, Стерлибашевский район, село Нижный Аллагуват, Молодежная, 2	f	medium
3137	22301	2855	республика Башкортостан, Стерлибашевский район, село Нижнеибраево, Центральная, 28А, Яшергановский сельсовет	f	small
3159	22324	2877	республика Башкортостан, Стерлибашевский район, село Муртаза, Школьная, 2	f	small
3149	22314	2867	республика Башкортостан, Стерлибашевский район, село Кундряк, Советская, 10	f	small
3160	22325	2878	республика Башкортостан, Стерлибашевский район, село Куганакбаш, Школьная, 5	f	medium
3143	22308	2861	республика Башкортостан, Стерлибашевский район, село Карагуш, Саубанова, 1	f	medium
3144	22309	2862	республика Башкортостан, Стерлибашевский район, село Кабакуш, Центральная, 34/5	f	medium
3157	22322	2875	республика Башкортостан, Стерлибашевский район, село Ибракаево, Ленина, 28	f	small
70706	79812	124	Самарская область, Чапаевск, Запорожская, 6	f	large
3146	22311	2864	республика Башкортостан, Стерлибашевский район, село Елимбетово, Парковая, 3	f	small
1065	20264	798	республика Башкортостан, Стерлибашевский район, село Елимбетово, Коммунистическая, 27	f	small
3166	22332	2884	республика Башкортостан, Стерлибашевский район, село Верхний Гулюм, Центральная, 13А	f	small
3148	22313	2866	республика Башкортостан, Стерлибашевский район, село Верхнешакарово, Заки Валиди, 4	f	small
109392	22362	2932	республика Башкортостан, Стерлибашевский район, село Васильевка, Оренбургский тракт, 60 а	f	\N
3139	22303	2857	республика Башкортостан, Стерлибашевский район, село Бузат, Ленина, 102А	f	medium
3151	22316	2869	республика Башкортостан, Стерлибашевский район, село Бакеево, Советская, 1	f	medium
1839	21019	1563	республика Башкортостан, Стерлибашевский район, село Амирово, Российская, 1а	f	small
65850	22307	2860	республика Башкортостан, Стерлибашевский район, село Амирово, Акчишма, 40	f	\N
3134	22298	2852	республика Башкортостан, Стерлибашевский район, село Айдарали, Молодежная, 45	f	medium
883	20093	630	республика Башкортостан, Сибай городской округ, Сибай, проспект Горняков, 8	f	large
3133	22297	2851	республика Башкортостан, Салаватский район, село Янгантау, Школьная, 1	f	medium
3105	22269	2823	республика Башкортостан, Салаватский район, село Язги-Юрт, Школьная, 10	f	small
3095	22259	2813	республика Башкортостан, Салаватский район, село Юлаево, Школьная, 2	t	small
3116	22280	2834	республика Башкортостан, Салаватский район, село Шарипово, Парт Мурзы, 51	f	small
3132	22296	2850	республика Башкортостан, Салаватский район, село Чулпан, Коммунаров, 12	f	small
3104	22268	2822	республика Башкортостан, Салаватский район, село Чебаркуль, Центральная, 40А	f	small
3107	22271	2825	республика Башкортостан, Салаватский район, село Урманчино, Школьная, 2а	f	small
3127	22291	2845	республика Башкортостан, Салаватский район, село Урмантау, Центральная, 27	f	medium
3130	22294	2848	республика Башкортостан, Салаватский район, село Турналы, Центральная, 35	f	medium
3128	22292	2846	республика Башкортостан, Салаватский район, село Терменево, Школьная, 1	f	medium
65849	22290	2844	республика Башкортостан, Салаватский район, село Таймеево, Молодежная, 4	f	\N
3115	22279	2833	республика Башкортостан, Салаватский район, село Саргамыш, Центральная, 28	f	small
3121	22285	2839	республика Башкортостан, Салаватский район, поселок Первомайский, Советская, 11	f	small
3094	22258	2812	республика Башкортостан, Салаватский район, село Новые Каратавлы, Переулок Пришкольный, 1	f	small
3120	22284	2838	республика Башкортостан, Салаватский район, село Насибаш, Центральная, 28	f	medium
3119	22283	2837	республика Башкортостан, Салаватский район, село Мурсалимкино, Пепеляева, 3	f	large
3101	22265	2819	республика Башкортостан, Салаватский район, село Миндишево, Школьная, 1	f	small
3114	22278	2832	республика Башкортостан, Салаватский район, село Мещегарово, Ленина, 10	f	small
3124	22288	2842	республика Башкортостан, Салаватский район, село Малояз, Коммунистическая, 47	f	large
3123	22287	2841	республика Башкортостан, Салаватский район, село Малояз, Коммунистическая, 63	f	large
3106	22270	2824	республика Башкортостан, Салаватский район, село Лаклы, Советская, 6	f	medium
3103	22267	2821	республика Башкортостан, Салаватский район, село Лагерево, Айская, 69	f	medium
3099	22263	2817	республика Башкортостан, Салаватский район, село Куселярово, Центральная, 16	f	small
1822	21002	1546	республика Башкортостан, Салаватский район, село Комсомол, Школьная, 1а	f	small
3118	22282	2836	республика Башкортостан, Салаватский район, село Карагулово, Центральная, 51	f	small
3100	22264	2818	республика Башкортостан, Салаватский район, село Ишимбаево, Молодежная, 6	f	small
3131	22295	2849	республика Башкортостан, Салаватский район, село Ильтаево, Школьная, 36	t	small
1300	20490	1030	республика Башкортостан, Салаватский район, село Идрисово, Молодежная, 12/1	f	small
3125	22289	2843	республика Башкортостан, Салаватский район, село Идельбаево 2-е, Центральная, 1	f	small
3113	22277	2831	республика Башкортостан, Салаватский район, село Еланыш, Центральная, 54	f	small
2545	21712	2264	республика Башкортостан, Салаватский район, село Бияз, Школьная, 10	t	small
3098	22262	2816	республика Башкортостан, Салаватский район, село Бешевлярово, Школьная, 9	f	small
3110	22274	2828	республика Башкортостан, Салаватский район, село Ахуново, Центральная, 15	f	small
3097	22261	2815	республика Башкортостан, Салаватский район, село Аркаулово, Салавата Юлаева, 7	f	large
3092	22256	2810	республика Башкортостан, Салаватский район, село Алькино, Кольцевая, 6	f	small
3129	22293	2847	республика Башкортостан, Салаватский район, село Айская, Школьная, 2	f	small
3087	22251	2805	республика Башкортостан, Нуримановский район, село Яман-Порт, Садовая	f	small
65841	22225	2779	республика Башкортостан, Нуримановский район, село Укарлино, Центральная, 32	f	\N
3067	22231	2785	республика Башкортостан, Нуримановский район, село Старокулево, Колхозная, 12	f	small
65844	22232	2786	республика Башкортостан, Нуримановский район, село Староисаево, Центральная, 62	f	\N
3078	22242	2796	республика Башкортостан, Нуримановский район, село Старобирючево, Береговая, 34	f	small
3066	22230	2784	республика Башкортостан, Нуримановский район, село Сатлык, Центральная, 24	f	small
3082	22246	2800	республика Башкортостан, Нуримановский район, село Сарва, Школьная, 4/1	f	small
3091	22255	2809	республика Башкортостан, Нуримановский район, поселок Павловка, Строителей, 1	f	medium
3089	22253	2807	республика Башкортостан, Нуримановский район, поселок Павловка, Карла Маркса, 31	f	medium
3080	22244	2798	республика Башкортостан, Нуримановский район, село Новый Субай, Лесная, 1	f	small
3065	22229	2783	республика Башкортостан, Нуримановский район, село Новокулево, Советская, 76	f	large
65847	22240	2794	республика Башкортостан, Нуримановский район, село Новобирючево, Центральная, 10	f	\N
65843	22227	2781	республика Башкортостан, Нуримановский район, село Нимислярово, Насретдинова, 55	f	\N
65848	22243	2797	республика Башкортостан, Нуримановский район, село Никольское, Центральная, 87	f	\N
3064	22228	2782	республика Башкортостан, Нуримановский район, село Кызыл-Баржау, Роодниковая, 3А	f	small
65839	22223	2777	республика Башкортостан, Нуримановский район, село Кушкулево, Парковая, 19	t	\N
3085	22249	2803	республика Башкортостан, Нуримановский район, поселок Красный Ключ, Матросова, 35	f	medium
3074	22238	2792	республика Башкортостан, Нуримановский район, село Красная Горка, Тукаева, 1	f	medium
3073	22237	2791	республика Башкортостан, Нуримановский район, село Красная Горка, Советская, 87	f	medium
65846	22236	2790	республика Башкортостан, Нуримановский район, село Красная Горка, Советская, 56	f	\N
3075	22239	2793	республика Башкортостан, Нуримановский район, село Красная Горка, Альмухаметова, 1	f	medium
2991	22155	2709	республика Башкортостан, Нуримановский район, село Каргино, Интернациональная, 40	f	small
65845	22233	2787	республика Башкортостан, Нуримановский район, село Ишмуратово, Центральная, 32	f	\N
65842	22226	2780	республика Башкортостан, Нуримановский район, село Истриково, Мубарякова, 15	f	\N
3071	22235	2789	республика Башкортостан, Нуримановский район, село Большие Шиды, Школьная	f	small
65840	22224	2778	республика Башкортостан, Нуримановский район, село Большетенькашево, Свободы, 3	f	\N
65838	22222	2776	республика Башкортостан, Нуримановский район, село Бикмурзино, Школьная, 20	f	\N
3070	22234	2788	республика Башкортостан, Нуримановский район, село Баш-Шиды, Советская, 1	f	small
3057	22221	2775	республика Башкортостан, Нуримановский район, село Байгильдино, Садовая, 20/2	f	small
2541	21708	2260	республика Башкортостан, Нуримановский район, село Атняш, Коммунистическая, 1	f	small
3024	22188	2742	республика Башкортостан, Миякинский район, село Шатмантамак, Шоссейная, 26	f	small
3010	22174	2728	республика Башкортостан, Миякинский район, село Чятай-Бурзян, Центральная, 28/2	f	small
3055	22219	2773	республика Башкортостан, Миякинский район, село Уршакбашкарамалы, Ленина, 58	f	medium
3056	22220	2774	республика Башкортостан, Миякинский район, село Уршак, Ленина, 35	f	small
3030	22194	2748	республика Башкортостан, Миякинский район, село Софиевка, Полевая, 9	f	small
3021	22185	2739	республика Башкортостан, Миякинский район, село Сафарово, Первомайская, 16	f	small
78484	7778	754	Ульяновская область, Ульяновск, улица Варейкиса, 17	f	large
3052	22216	2770	республика Башкортостан, Миякинский район, село Сатыево, Центральная, 19	f	small
3051	22215	2769	республика Башкортостан, Миякинский район, село Саккул-Михайловка, Садовая, 11 а	f	small
3040	22204	2758	республика Башкортостан, Миякинский район, село Родниковка, Молодежная, 14	f	medium
3049	22213	2767	республика Башкортостан, Миякинский район, село Новый Мир, Молодежная, 7	f	small
3053	22217	2771	республика Башкортостан, Миякинский район, село Новые Омельники, Шевченко, 7	f	small
3050	22214	2768	республика Башкортостан, Миякинский район, село Новые Карамалы, Центральная, 57 	f	small
3032	22196	2750	республика Башкортостан, Миякинский район, село Новые Ишлы, Центральная, 12	f	small
3026	22190	2744	республика Башкортостан, Миякинский район, село Нарыстау, Мира, 52	f	small
3036	22200	2754	республика Башкортостан, Миякинский район, село Миякитамак, Коммунистическая, 66	f	medium
3037	22201	2755	республика Башкортостан, Миякинский район, село Менеузтамак, Шоссейная, 7/1	f	medium
3018	22182	2736	республика Башкортостан, Миякинский район, село Малые Каркалы, Первомайская, 1	f	small
3041	22205	2759	республика Башкортостан, Миякинский район, село Курманайбаш, Королева, 4	f	small
3028	22192	2746	республика Башкортостан, Миякинский район, село Куль-Кункас, Демская, 47	f	small
3015	22179	2733	республика Башкортостан, Миякинский район, село Култай-Каран, Матросова, 43Б	f	small
3031	22195	2749	республика Башкортостан, Миякинский район, село Кочеганово, Шоссейная, 18	f	medium
3029	22193	2747	республика Башкортостан, Миякинский район, село Комсомольский, Центральная, 1	f	small
3034	22198	2752	республика Башкортостан, Миякинский район, село Кожай-Семеновка, Советская, 62	f	medium
3044	22208	2762	республика Башкортостан, Миякинский район, село Киргиз-Мияки, Шоссейная, 2	f	medium
3046	22210	2764	республика Башкортостан, Миякинский район, село Киргиз-Мияки, Советская, 12	f	medium
3043	22207	2761	республика Башкортостан, Миякинский район, село Киргиз-Мияки, Ленина, 28	f	large
3047	22211	2765	республика Башкортостан, Миякинский район, село Киргиз-Мияки, Калинина, 29	f	medium
3042	22206	2760	республика Башкортостан, Миякинский район, село Киргиз-Мияки, Губайдуллина, 130	f	large
3045	22209	2763	республика Башкортостан, Миякинский район, село Киргиз-Мияки, Абдуллина, 2	f	medium
3035	22199	2753	республика Башкортостан, Миякинский район, село Кекен-Васильевка, Советская, 40	f	small
3027	22191	2745	республика Башкортостан, Миякинский район, село Каран-Кункас, Школьная, 2	f	small
3014	22178	2732	республика Башкортостан, Миякинский район, село Канбеково, Советская, 49/1	f	small
3023	22187	2741	республика Башкортостан, Миякинский район, село Исламгулово, Ш. Бабича, 9	f	small
3025	22189	2743	республика Башкортостан, Миякинский район, село Ильчигулово, Советская, 15	f	small
3022	22186	2740	республика Башкортостан, Миякинский район, село Зильдярово, Дружбы, 14	f	medium
65837	22203	2757	республика Башкортостан, Миякинский район, село Ерлыково, Центральная, 28	f	\N
3020	22184	2738	республика Башкортостан, Миякинский район, село Енебей-Урсаево, Центральная, 4 А	f	small
2252	21431	1972	республика Башкортостан, Миякинский район, село Воскресенка, Молодежная, 28	f	small
3017	22181	2735	республика Башкортостан, Миякинский район, село Большие Каркалы, Советская, 12	f	small
3013	22177	2731	республика Башкортостан, Миякинский район, село Богданово, Ленина, 39	f	small
3011	22175	2729	республика Башкортостан, Миякинский район, село Биккулово, Школьная, 1	f	small
3054	22218	2772	республика Башкортостан, Миякинский район, село Баязитово, Мира, 28	f	small
3048	22212	2766	республика Башкортостан, Миякинский район, село Анясево, Центральная, 14	f	medium
2956	22120	2674	республика Башкортостан, Мишкинский район, село Яндыганово, Ленина, 45	f	small
2955	22119	2673	республика Башкортостан, Мишкинский район, село Янагушево, Клубная, 20	f	small
3000	22164	2718	республика Башкортостан, Мишкинский район, село Чураево, Яныша Ялкайна, 35	f	small
2999	22163	2717	республика Башкортостан, Мишкинский район, село Чураево, Ленина, 28	f	small
2953	22117	2671	республика Башкортостан, Мишкинский район, село Урьяды, Фатхинурова, 22	f	small
2980	22144	2698	республика Башкортостан, Мишкинский район, село Укозяш, Лесная, 23	f	small
2995	22159	2713	республика Башкортостан, Мишкинский район, село Тынбаево, Школьная, 6	f	small
3003	22167	2721	республика Башкортостан, Мишкинский район, село Тигирменево, Шоссейная, 3	f	small
2984	22148	2702	республика Башкортостан, Мишкинский район, село Терекеево, Чапаева, 19	f	small
2981	22145	2699	республика Башкортостан, Мишкинский район, село Татарбаево, Саита Хамата, 20	f	small
2994	22158	2712	республика Башкортостан, Мишкинский район, село Старокульчубаево, Чапаева, 16	f	small
2959	22123	2677	республика Башкортостан, Мишкинский район, село Староваськино, Трактовая, 24а	f	small
2983	22147	2701	республика Башкортостан, Мишкинский район, село Староатнагулово, Советская, 15	f	small
2976	22140	2694	республика Башкортостан, Мишкинский район, село Староарзаматово, Яныша Ялкайна, 2	f	small
2958	22122	2676	республика Башкортостан, Мишкинский район, село Староакбулатово, Трактовая, 41а	f	small
2992	22156	2710	республика Башкортостан, Мишкинский район, село Сосновка, Школьная, 12	f	small
2954	22118	2672	республика Башкортостан, Мишкинский район, село Сабаево, Мичуринская, 1	f	small
3001	22165	2719	республика Башкортостан, Мишкинский район, село Октябрь, Яныша Ялкайна, 44	f	small
2970	22134	2688	республика Башкортостан, Мишкинский район, село Новоключево, Советская, 28-а	f	small
3008	22172	2726	республика Башкортостан, Мишкинский район, село Новокильметово, Тракторная, 10	f	small
2982	22146	2700	республика Башкортостан, Мишкинский район, Новокарачево, Школьная, 4	f	small
2960	22124	2678	республика Башкортостан, Мишкинский район, село Нововаськино, Интернациональная, 42	f	small
2972	22136	2690	республика Башкортостан, Мишкинский район, село Нижнесорокино, Интернациональная, 12	f	small
2966	22130	2684	Россия, республика Башкортостан, Мишкинский район, село Мишкино	f	medium
1449	20637	1179	республика Башкортостан, Мишкинский район, село Мишкино, Центральная, 23	f	small
2967	22131	2685	республика Башкортостан, Мишкинский район, село Мишкино, Тракторная, 16	f	medium
2962	22126	2680	республика Башкортостан, Мишкинский район, село Мишкино, Мира, 4б	f	medium
2964	22128	2682	республика Башкортостан, Мишкинский район, село Мишкино, Ленина, 73	f	medium
2963	22127	2681	республика Башкортостан, Мишкинский район, село Мишкино, Ленина, 106	f	medium
2961	22125	2679	республика Башкортостан, Мишкинский район, село Мишкино, Ленина, 143	f	medium
2965	22129	2683	республика Башкортостан, Мишкинский район, село Мишкино, Дружбы, 26	f	medium
2987	22151	2705	республика Башкортостан, Мишкинский район, село Малые Шады, Малошадинская, 38	f	small
2977	22141	2695	республика Башкортостан, Мишкинский район, село Малонакоряково, Школьная, 2	f	small
65836	22168	2722	республика Башкортостан, Мишкинский район, село Лепешкино, Молодежная, 2	f	\N
3086	22250	2804	республика Башкортостан, Мишкинский район, село Красный Ключ, Советская, 122	f	medium
2968	22132	2686	республика Башкортостан, Мишкинский район, село Кигазытамаково, Социалистическая, 1	f	small
2951	21957	2669	республика Башкортостан, Мишкинский район, село Камеево, Орсаева, 18	f	small
2950	22115	2668	республика Башкортостан, Мишкинский район, село Камеево, Больничная, 13	f	small
2990	22154	2708	республика Башкортостан, Мишкинский район, село Кайраково, Центральная, 31	f	small
2985	22149	2703	республика Башкортостан, Мишкинский район, село Иштыбаево, Кирова, 2	f	small
3005	22169	2723	республика Башкортостан, Мишкинский район, село Ишимово, Ишкинина, 32	f	small
2973	22137	2691	республика Башкортостан, Мишкинский район, село Ирсаево, Социалистическая, 4	f	small
2996	22160	2714	республика Башкортостан, Мишкинский район, село Изимарино, Мичурина, 12	f	small
2974	22138	2692	республика Башкортостан, Мишкинский район, село Елышево, Трактовая, 24	f	small
2971	22135	2689	республика Башкортостан, Мишкинский район, село Верхнесорокино, Матросова, 1	f	small
3002	22166	2720	республика Башкортостан, Мишкинский район, село Букленды, Советская, 16	f	small
2986	22150	2704	республика Башкортостан, Мишкинский район, село Большие Шады, Больничная, 30	f	small
78570	7831	850	Ульяновская область, Ульяновск, улица Артема, 21	f	large
2993	22157	2711	республика Башкортостан, Мишкинский район, село Большесухоязово, Центральная, 30	f	medium
65835	22142	2696	республика Башкортостан, Мишкинский район, село Бирюбаш, Мира, 24	f	\N
2989	22153	2707	республика Башкортостан, Мишкинский район, село Бикшиково, Трактовая, 3	f	small
2952	22116	2670	республика Башкортостан, Мишкинский район, село Байтурово, Школьная, 7	f	small
2949	22114	2667	республика Башкортостан, Мишкинский район, село Бабаево, Школьная, 11	f	small
3096	22260	2814	республика Башкортостан, Мечетлинский район, село Юнусово, Юлаева, 1	t	small
2922	22092	2640	республика Башкортостан, Мечетлинский район, село Юнусово, Хаерзаманова, 1	f	small
2916	22086	2634	республика Башкортостан, Мечетлинский район, село Такино, Мира, 57	f	small
2923	22093	2641	республика Башкортостан, Мечетлинский район, село Таишево, Горная, 4	f	small
3353	22579	3132	республика Башкортостан, Мечетлинский район, село Сулейманово, Миасс, 15	f	small
2934	22099	2652	республика Башкортостан, Мечетлинский район, село Сулейманово, Механизаторов, 2	f	small
2947	22112	2665	республика Башкортостан, Мечетлинский район, село Степной, Советская, 5	f	small
2933	22098	2651	республика Башкортостан, Мечетлинский район, село Старомещерово, Коммунистическая, 24а	f	small
2946	22111	2664	республика Башкортостан, Мечетлинский район, деревня Средняя Ока, Советская, 27	f	small
1338	20528	1068	республика Башкортостан, Мечетлинский район, село Сосновка, Школьная, 17а	f	small
2909	22079	2627	республика Башкортостан, Мечетлинский район, село Сальзигутово, Айская, 27	f	small
2936	22101	2654	республика Башкортостан, Мечетлинский район, село Сабанаково, Молодежная, 4	f	small
2925	22095	2643	республика Башкортостан, Мечетлинский район, село Новомещерово, Школьная, 40	f	medium
2929	22076	2647	республика Башкортостан, Мечетлинский район, село Нижние Тукбаево, Октябрьская, 26	f	small
2914	22084	2632	республика Башкортостан, Мечетлинский район, село Нижние Бобино, Солнечная, 2	f	small
2940	22105	2658	республика Башкортостан, Мечетлинский район, село Мелекасово, Революционная, 25	f	small
2913	22083	2631	республика Башкортостан, Мечетлинский район, село Малоустьикинское, Трактовая, 2а	f	small
65833	22100	2653	республика Башкортостан, Мечетлинский район, село Лемез-Тамак, улица Карла Маркса, 3	f	\N
2915	22085	2633	республика Башкортостан, Мечетлинский район, село Кургатово, Ленина, 115	f	small
2944	22109	2662	республика Башкортостан, Мечетлинский район, село Ключевой, Первомайская, 14	f	small
2928	22063	2646	республика Башкортостан, Мечетлинский район, село Каранаево, Набережная, 26	f	small
65831	22088	2636	республика Башкортостан, Мечетлинский район, село Ишалино, Пролетарская, 36	f	\N
65832	22096	2649	республика Башкортостан, Мечетлинский район, село Еланыш, Школьная, 2	f	\N
65824	21628	2179	республика Башкортостан, Мечетлинский район, село Гумерово, Центральная, 32	f	\N
2938	22103	2656	республика Башкортостан, Мечетлинский район, село Буртаковка, Мостовая, 1	f	small
2930	21900	2648	республика Башкортостан, Мечетлинский район, село Буранчино, Школьная, 5	f	small
2912	22082	2630	республика Башкортостан, Мечетлинский район, Большеустьикинское, Ленина, 19	f	large
2942	22107	2660	республика Башкортостан, Мечетлинский район, село Большекызылбаево, Революционная, 22	f	small
2945	22110	2663	республика Башкортостан, Мечетлинский район, село Большая Ока, Мира, 45	f	medium
2910	22080	2628	республика Башкортостан, Мечетлинский район, село Болшеустьикинское, Молодежная, 15	f	large
2911	22081	2629	республика Башкортостан, Мечетлинский район, село Болшеустьикинское, Ленина, 15	f	large
2920	22090	2638	республика Башкортостан, Мечетлинский район, село Аюпово, Школьная, 5а	f	small
2939	22104	2657	республика Башкортостан, Мечетлинский район, село Алегазово, Октябрьская, 14	f	medium
65834	22113	2666	республика Башкортостан, Мечетлинский район, село Азикеево, Школьная, 3	f	\N
2924	22094	2642	республика Башкортостан, Мечетлинский район, село Азангулово, Гагарина, 24	f	small
2943	22108	2661	республика Башкортостан, Мечетлинский район, село Абдуллино, Ленина, 96	f	small
2921	22091	2639	республика Башкортостан, Мечетлинский район, село Абдрахимово, Октябрьская, 26а	f	small
2908	22078	2626	республика Башкортостан, Мелеузовский район, д. Первомайский, Ленина, 31	f	large
2887	22055	2605	республика Башкортостан, Мелеузовский район, село Юмаково, Салавата Юлаева, 38	f	small
2907	22077	2625	республика Башкортостан, Мелеузовский район, село Узя, Потешкина, 3	f	small
2877	22044	2595	республика Башкортостан, Мелеузовский район, село Троицкое, Победы, 6	f	small
2884	22052	2602	республика Башкортостан, Мелеузовский район, село Сухаревка, Сухаревская, 75	f	small
2891	22059	2609	республика Башкортостан, Мелеузовский район, село Смаково, Правонабережная, 6	f	medium
2897	22066	2615	республика Башкортостан, Мелеузовский район, село Сергеевка, Мира, 25	f	small
2899	22068	2617	республика Башкортостан, Мелеузовский район, село Сарышево, Мира, 6	f	medium
2904	22073	2622	республика Башкортостан, Мелеузовский район, село Самаро-Ивановка, Советская, 2Б	f	small
2875	22042	2593	республика Башкортостан, Мелеузовский район, село Саитовский, Юрматинская, 6	f	small
2885	22053	2603	республика Башкортостан, Мелеузовский район, село Сабашево, Колхозная, 20А	f	small
3012	22176	2730	республика Башкортостан, Мелеузовский район, село Рассвет, Центральная, 1	f	small
2874	22041	2592	республика Башкортостан, Мелеузовский район, село Петропавловка, Центральная, 25	f	small
2975	22139	2693	республика Башкортостан, Мелеузовский район, село Озерки, Озерная, 14	f	small
2896	22065	2614	республика Башкортостан, Мелеузовский район, поселок Нугуш, Молодежная, 10	f	medium
2879	22046	2597	республика Башкортостан, Мелеузовский район, село Нордовка, Гагарина, 1	f	medium
109381	22350	2921	республика Башкортостан, Мелеузовский район, село Новый Краснояр, Молодежная, 1в	f	\N
2847	22016	2565	республика Башкортостан, Мелеузовский район, Мелеуз, Южная, 5	f	large
2868	22035	2586	республика Башкортостан, Мелеузовский район, Мелеуз, Смоленская, 192	f	large
2854	22023	2572	республика Башкортостан, Мелеузовский район, Мелеуз, Площадь Элеватора, 1	f	large
2863	22030	2581	республика Башкортостан, Мелеузовский район, Мелеуз, Первомайская, 8	f	large
2867	22034	2585	республика Башкортостан, Мелеузовский район, Мелеуз, Костромская, 35	f	large
2848	22017	2566	республика Башкортостан, Мелеузовский район, Мелеуз, Береговая, 2В	f	medium
2869	22036	2587	республика Башкортостан, Мелеузовский район, Мелеуз, 50 лет ВЛКСМ, 55	f	large
2862	22029	2580	республика Башкортостан, Мелеузовский район, Мелеуз, 50 лет ВЛКСМ, 19	f	large
2857	22025	2575	республика Башкортостан, Мелеузовский район, Мелеуз, 32 микрорайон, 4	f	large
2856	22025	2574	республика Башкортостан, Мелеузовский район, Мелеуз, 32 микрорайон, 4	f	large
2871	22038	2589	республика Башкортостан, Мелеузовский район, село Кутушево, Школьная, 5	f	medium
2882	22049	2600	республика Башкортостан, Мелеузовский район, село Корнеевка, Ямилева, 2	f	medium
2586	21753	2305	республика Башкортостан, Мелеузовский район, село Константиновка, Ленина, 67а	f	large
65830	22074	2623	республика Башкортостан, Мелеузовский район, село Кизрай, Школьная, 1	f	\N
2870	22037	2588	республика Башкортостан, Мелеузовский район, село Каран, Берёзовая, 6	f	large
65829	22067	2616	республика Башкортостан, Мелеузовский район, село Иштуганово, Центральная, 39А	f	\N
2889	22057	2607	республика Башкортостан, Мелеузовский район, поселок Зирган, Советская, 213	f	large
2888	22056	2606	республика Башкортостан, Мелеузовский район, поселок Зирган, Советская, 122	f	large
2880	22047	2598	республика Башкортостан, Мелеузовский район, село Дмитриевка, Механизаторов, 1	f	small
2876	22043	2594	республика Башкортостан, Мелеузовский район, село Дарьино, Советская, 1	f	medium
2883	22051	2601	республика Башкортостан, Мелеузовский район, село Даниловка, Школьная, 7	f	small
1819	20999	1543	республика Башкортостан, Мелеузовский район, село Восточное, Школьная, 7	f	small
2892	22060	2610	республика Башкортостан, Мелеузовский район, село Воскресенское, Ленина, 34	f	medium
2893	22061	2611	республика Башкортостан, Мелеузовский район, поселок Воскресенское, Рихарда Зорге, 42	f	medium
2886	22054	2604	республика Башкортостан, Мелеузовский район, село Верхнеюлдашево, Школьная, 1А	f	small
2878	22045	2596	республика Башкортостан, Мелеузовский район, село Васильевка, Школьная, 2	f	small
65823	21627	2178	республика Башкортостан, Мелеузовский район, село Васильевка, Центральная, 33	f	\N
65827	22048	2599	республика Башкортостан, Мелеузовский район, село Варварино, Социалстическая, 36А	f	\N
65828	22058	2608	республика Башкортостан, Мелеузовский район, село Береговка, Заречная, 64А	f	\N
2900	22069	2618	республика Башкортостан, Мелеузовский район, село Аптраково, Салима Масагутова, 1	f	medium
2872	22039	2590	республика Башкортостан, Мелеузовский район, село Антоновка, Заречная, 8/1	f	small
2894	22062	2612	республика Башкортостан, Мелеузовский район, село Александровка, Центральная, 51	f	small
2901	22070	2619	республика Башкортостан, Мелеузовский район, село Абитово, Центральная, 4	f	medium
2827	21995	2543	республика Башкортостан, Куюргазинский район, село Ямансарово, Школьная, 1	f	small
2833	22001	2549	республика Башкортостан, Куюргазинский район, село Ямангулово, Школьная, 2	f	small
2809	21978	2526	республика Башкортостан, Куюргазинский район, село Ялчикаево, Искужина, 34	f	small
2844	22014	2563	республика Башкортостан, Куюргазинский район, село Якшимбетово, Талгата Азнабаева, 1 в	f	medium
65774	22006	2554	республика Башкортостан, Куюргазинский район, село Якутово, Баяна, 6	f	\N
2802	22013	2562	республика Башкортостан, Куюргазинский район, село Якупово, Центральная, 44	f	small
2845	22012	2561	республика Башкортостан, Куюргазинский район, село Язлав, Биктеевская, 33	f	small
2835	22003	2551	республика Башкортостан, Куюргазинский район, село Юшатырка, Кооперативная, 3	f	small
2815	21984	2532	республика Башкортостан, Куюргазинский район, село Юмагузино, Дружбы, 3	t	small
65770	21987	2535	республика Башкортостан, Куюргазинский район, село Шабагиш, Мира, 2	f	\N
2817	21986	2534	республика Башкортостан, Куюргазинский район, село Холодный Ключ, Дружбы, 8	t	small
2807	21976	2524	республика Башкортостан, Куюргазинский район, село Свобода, Гагарина, 1	f	small
3090	22254	2808	республика Башкортостан, Куюргазинский район, село Павловка, Карла Маркса, 39	f	large
2808	21977	2525	республика Башкортостан, Куюргазинский район, село Новотаймасово, Ленина, 8	f	medium
2813	21982	2530	республика Башкортостан, Куюргазинский район, село Новомусино, Школьная, 2	f	small
2837	22005	2553	республика Башкортостан, Куюргазинский район, село Новомурапталово, Парковая, 1б	f	medium
2840	22008	2556	республика Башкортостан, Куюргазинский район, село Новокалтаево, Бязита Бикбая, 15А	t	small
2831	21999	2547	республика Башкортостан, Куюргазинский район, село Новая Отрада, Новоотрадинская, 56 а	f	small
2841	22010	2558	республика Башкортостан, Куюргазинский район, село Нижние Бабаларово, Молодежная, 4-1	f	small
2800	21971	2519	республика Башкортостан, Куюргазинский район, село Молоканово, Школьная, 3 а	f	small
2812	21981	2529	республика Башкортостан, Куюргазинский район, село Михайловка, Центральная, 25	f	small
2811	21980	2528	республика Башкортостан, Куюргазинский район, село Марьевка, Школьная, 5	f	small
2821	21989	2537	республика Башкортостан, Куюргазинский район, село Мамбеткулово, Заки Валиди, 1	f	small
65776	21913	2560	республика Башкортостан, Куюргазинский район, село Куюргазы, Школьная, 1	f	\N
2843	22011	2559	республика Башкортостан, Куюргазинский район, село Кутлуюлово, Школьная, 12а	f	small
2824	21992	2540	республика Башкортостан, Куюргазинский район, село Кривле-Илюшкино, Школьная, 23	f	small
65775	22007	2555	республика Башкортостан, Куюргазинский район, село Красный Маяк, Горная, 18а	t	\N
2816	21985	2533	республика Башкортостан, Куюргазинский район, село Канчура, Центральная, 17	t	small
65769	21983	2531	республика Башкортостан, Куюргазинский район, село Илькинеево, Набережная, 1 А	f	\N
2810	21979	2527	республика Башкортостан, Куюргазинский район, село Зяк-Ишметово, Школьная, 8	f	medium
2798	21969	2517	республика Башкортостан, Куюргазинский район, поселок Ермолаево, проспект Мира, 8	f	large
65767	21965	2513	республика Башкортостан, Куюргазинский район, поселок Ермолаево, Чапаева, 123	f	\N
2797	21968	2516	республика Башкортостан, Куюргазинский район, поселок Ермолаево, Советская, 160А	f	large
2795	21966	2514	республика Башкортостан, Куюргазинский район, поселок Ермолаево, Калинина, 17а	f	medium
2796	21967	2515	республика Башкортостан, Куюргазинский район, поселок Ермолаево, Ватутина, 2	f	large
2828	21996	2544	республика Башкортостан, Куюргазинский район, село Горный Ключ, Баянская, 1-1	t	small
65771	21988	2536	республика Башкортостан, Куюргазинский район, село Бугульчан, Школьная, 8	f	\N
65773	21997	2545	республика Башкортостан, Куюргазинский район, село Бахмут, Советская, 39	f	\N
65772	21990	2538	республика Башкортостан, Куюргазинский район, село Бальза, Рабочая, 9Б	f	\N
2834	22002	2550	республика Башкортостан, Куюргазинский район, село Аксарово, Молодежная, 10	f	small
2804	21973	2521	республика Башкортостан, Куюргазинский район, .Кинья-Абыз, 40 лет Победы, 4	f	small
2771	21940	2490	республика Башкортостан, Кушнаренковский район, село Якупово, Молодежная, 3	f	small
2767	21936	2486	республика Башкортостан, Кушнаренковский район, село Чирша-Тартыш, Речная, 46	f	small
2789	21960	2508	республика Башкортостан, Кушнаренковский район, село Угузево, Мира, 56	f	small
2768	21937	2487	республика Башкортостан, Кушнаренковский район, село Толбазы, Победы, 40а	f	small
2755	21924	2474	республика Башкортостан, Кушнаренковский район, село Тарабердино, Кирова, 43	f	large
2776	21946	2495	республика Башкортостан, Кушнаренковский район, село Султанаево, Школьная, 1	f	small
2785	21955	2504	республика Башкортостан, Кушнаренковский район, село Старые Тукмаклы, Центральная, 7	f	medium
2778	21948	2497	республика Башкортостан, Кушнаренковский район, село Старые Камышлы, Школьная, 29	f	medium
2780	21950	2499	республика Башкортостан, Кушнаренковский район, село Старокурмашево, Парковая, 11	f	medium
2774	21944	2493	республика Башкортостан, Кушнаренковский район, село Старогумерово, Валиева, 12	f	medium
65766	21934	2484	республика Башкортостан, Кушнаренковский район, село Саитово, Коммунаров, 40	f	\N
2772	21941	2491	республика Башкортостан, Кушнаренковский район, село Расмекеево, Пролетарская, 48	f	small
2777	21947	2496	республика Башкортостан, Кушнаренковский район, село Первушино, Парковая, 20	f	small
2787	21958	2506	республика Башкортостан, Кушнаренковский район, село Новые-Тукмаклы, Центральная, 38	f	small
2782	21952	2501	республика Башкортостан, Кушнаренковский район, село Новокурмашево, Центральная, 34	f	small
2775	21945	2494	республика Башкортостан, Кушнаренковский район, село Новогумерово, Новая, 32/1	f	small
2760	21929	2479	республика Башкортостан, Кушнаренковский район, село Медведерово, Трактовая, 34	f	small
2791	21962	2510	республика Башкортостан, Кушнаренковский район, село Мамяково, Центральная, 62	f	small
2752	21921	2471	республика Башкортостан, Кушнаренковский район, поселок Кушнаренково, Терешковой, 15	f	large
2751	21920	2470	республика Башкортостан, Кушнаренковский район, поселок Кушнаренково, Советская, 22	f	large
2753	21922	2472	республика Башкортостан, Кушнаренковский район, поселок Кушнаренково, Октябрьская, 49	f	large
2750	21919	2469	республика Башкортостан, Кушнаренковский район, поселок Кушнаренково, Октябрьская, 60	f	large
2749	21918	2468	республика Башкортостан, Кушнаренковский район, поселок Кушнаренково, Октябрьская, 84	f	large
65765	21917	2467	республика Башкортостан, Кушнаренковский район, поселок Кушнаренково, Мичурина, 1	f	\N
2754	21923	2473	республика Башкортостан, Кушнаренковский район, поселок Кушнаренково, Большевистская, 57	f	large
2766	21935	2485	республика Башкортостан, Кушнаренковский район, село Карача-Елга, Ленина, 15	f	medium
2786	21956	2505	республика Башкортостан, Кушнаренковский район, село Каратяки, школьная, 12	f	small
2757	21926	2476	республика Башкортостан, Кушнаренковский район, село Канлы, Центральная, 32	f	small
2792	21963	2511	республика Башкортостан, Кушнаренковский район, село Калтаево, Дорожная, 8	f	medium
2788	21959	2507	республика Башкортостан, Кушнаренковский район, село Казарма, Школьная, 13	f	small
2779	21949	2498	республика Башкортостан, Кушнаренковский район, село Ильмурзино, Школьная, 50а	f	small
3006	22170	2724	республика Башкортостан, Кушнаренковский район, село Иликово, Школьная, 5	f	small
2763	21932	2482	республика Башкортостан, Кушнаренковский район, село Иликово, Коминтерна, 20	f	medium
78569	7831	849	Ульяновская область, Ульяновск, улица Артема, 21	f	large
3595	22820	3374	республика Башкортостан, Кушнаренковский район, село Ибрагимово, Центральная, 19	f	small
2793	21964	2512	республика Башкортостан, Кушнаренковский район, село Гургуреево, Парковая, 4	f	small
2764	21933	2483	республика Башкортостан, Кушнаренковский район, село Гумерово, 13 лет Октября, 32	f	small
1135	20336	868	республика Башкортостан, Кушнаренковский район, село Горный, Садовая, 13/2	f	small
2784	21954	2503	республика Башкортостан, Кушнаренковский район, село Бейкеево, Центральная, 14	f	small
2770	21939	2489	республика Башкортостан, Кушнаренковский район, село Бардовка, Свободы, 33	f	small
2761	21930	2480	республика Башкортостан, Кушнаренковский район, село Бакаево, Центральная, 26	f	small
2756	21925	2475	республика Башкортостан, Кушнаренковский район, село Ахметово, Центральная, 34	f	medium
2758	21927	2477	республика Башкортостан, Кушнаренковский район, село Ахлыстино, Центральная, 5	f	small
2723	21890	2442	республика Башкортостан, Кугарчинский район, село Янаул, М. Гафури, 1А	f	small
2693	21860	2412	республика Башкортостан, Кугарчинский район, село Ялчино, Центральная, 13	f	small
2705	21872	2424	республика Башкортостан, Кугарчинский район, село Ялчино, Мира, 21	f	small
2710	21877	2429	республика Башкортостан, Кугарчинский район, село Юмагузино, Школьная, 64А	f	medium
2709	21876	2428	республика Башкортостан, Кугарчинский район, село Юмагузино, Строителей, 20	f	large
2708	21875	2427	республика Башкортостан, Кугарчинский район, село Юмагузино, Равенства, 17А	f	small
65764	21878	2430	республика Башкортостан, Кугарчинский район, село Юмагузино, Комсомольская, 5	f	\N
2740	21908	2459	республика Башкортостан, Кугарчинский район, деревня Юлдыбай, З. Биишевой, 37	f	small
2712	21879	2431	республика Башкортостан, Кугарчинский район, село Хлебодаровка, Речная, 66	f	small
2706	21873	2425	республика Башкортостан, Кугарчинский район, село Тюлебаево, Школьная, 5	f	small
2741	21909	2460	республика Башкортостан, Кугарчинский район, село Тупчаново 1-е, З. Валиди, 20	f	small
2747	21916	2466	республика Башкортостан, Кугарчинский район, село Тукатово 1-е, Мира, 24А	f	small
2730	21897	2449	республика Башкортостан, Кугарчинский район, село Туембетово, Школьная, 1	f	small
2697	21864	2416	республика Башкортостан, Кугарчинский район, село Тляумбетово, Молодежная, 1	f	small
2699	21866	2418	республика Башкортостан, Кугарчинский район, село Таваканово, Сэнкем, 6	f	small
2688	21855	2407	республика Башкортостан, Кугарчинский район, село Султангулово, Х. Давлетшиной, 4	f	small
2704	21871	2423	республика Башкортостан, Кугарчинский район, село Семено-Петровское, Колхозная, 6А	f	small
2743	21911	2462	республика Башкортостан, Кугарчинский район, село Сатлыки, Пушкина, 1	f	small
2736	21904	2455	республика Башкортостан, Кугарчинский район, село Сапыково, Молодежная, 12	f	small
2721	21888	2440	республика Башкортостан, Кугарчинский район, село Саиткулово, Верхняя, 20	f	small
2597	21764	2316	республика Башкортостан, Кугарчинский район, село Прибельский, Пугачева, 1	f	large
2596	21763	2315	республика Башкортостан, Кугарчинский район, село Прибельский, Ленина, 6	f	large
2701	21868	2420	республика Башкортостан, Кугарчинский район, село Подгорное, Советская, 37	f	small
65763	21859	2411	республика Башкортостан, Кугарчинский район, село Побоище, Советская, 54 а	f	\N
2746	21915	2465	республика Башкортостан, Кугарчинский район, село Нукаево, Салавата Юлаева, 2А	f	small
2739	21907	2458	республика Башкортостан, Кугарчинский район, село Новохвалынский, Оло Ик, 14	f	small
2690	21857	2409	республика Башкортостан, Кугарчинский район, село Новопокровское, Заозерная, 1	f	small
2720	21887	2439	республика Башкортостан, Кугарчинский район, село Новопетровское, Центральная, 34А	f	small
3509	22733	3288	республика Башкортостан, Кугарчинский район, село Новопетровское, Гафури, 2	f	small
2713	21880	2432	республика Башкортостан, Кугарчинский район, село Нижнебиккузино, Победы, 36	f	small
2729	21896	2448	республика Башкортостан, Кугарчинский район, село Назаркино, Центральная, 5	f	small
2744	21912	2463	республика Башкортостан, Кугарчинский район, Мурадым, Молодежная, 8	f	small
78568	7831	848	Ульяновская область, Ульяновск, улица Артема, 21	f	large
2725	21892	2444	республика Башкортостан, Кугарчинский район, село Мукачево, с. Юлаева, 39	f	small
2683	21850	2402	республика Башкортостан, Кугарчинский район, село Мраково, Учительская, 1	f	medium
2687	21854	2406	республика Башкортостан, Кугарчинский район, село Мраково, Октябрьская, 33	f	medium
2685	21852	2404	республика Башкортостан, Кугарчинский район, село Мраково, Ленина, 51	f	large
2686	21853	2405	республика Башкортостан, Кугарчинский район, село Мраково, Иванова, 42	f	medium
2684	21851	2403	республика Башкортостан, Кугарчинский район, село Мраково, З.Биишевой, 117	f	large
2727	21894	2446	республика Башкортостан, Кугарчинский район, село Максютово, Центральная, 70А	f	medium
2691	21858	2410	республика Башкортостан, Кугарчинский район, село Кузьминовка, Центральная, 6	f	small
2733	21901	2452	республика Башкортостан, Кугарчинский район, село Кугарчи, Советская, 25	f	medium
2696	21863	2415	республика Башкортостан, Кугарчинский район, село Калдарово, Молодежная, 28	f	medium
2724	21891	2443	республика Башкортостан, Кугарчинский район, село Исимово, 40 лет Победы, 26А	f	medium
2718	21885	2437	республика Башкортостан, Кугарчинский район, село Иртюбяк, Шевченко, 31	f	small
2737	21905	2456	республика Башкортостан, Кугарчинский район, село Ижбердино, Школьная, 20	f	small
2742	21910	2461	республика Башкортостан, Кугарчинский район, село Ибрагимово, Школьная, 1	f	small
2728	21895	2447	республика Башкортостан, Кугарчинский район, село Зирекля, Сулеймана, 25	f	small
2698	21865	2417	республика Башкортостан, Кугарчинский район, село Даут-Каюпово, Луговая, 25	f	small
2702	21869	2421	республика Башкортостан, Кугарчинский район, село Воскресенское, 70 лет Октября, 34	f	small
2695	21862	2414	республика Башкортостан, Кугарчинский район, село Волостновка, Центральная, 17	f	small
2735	21903	2454	республика Башкортостан, Кугарчинский район, село Верхнесюрюбаево, Центральная, 28	f	small
2726	21893	2445	республика Башкортостан, Кугарчинский район, село Верхнесанзяпово, Центральная, 47	f	small
2719	21886	2438	республика Башкортостан, Кугарчинский район, село Верхнемурсаляево, Центральная, 41	f	small
2731	21898	2450	республика Башкортостан, Кугарчинский район, село Верхнее Сазово, Русская, 11	f	small
2714	21881	2433	республика Башкортостан, Кугарчинский район, село Верхнебиккузино, Набережная, 18	f	small
2738	21906	2457	республика Башкортостан, Кугарчинский район, село Бикбулатово, Набережная, 15	f	small
2700	21867	2419	республика Башкортостан, Кугарчинский район, село Бекечево, Буранбая, 67	f	small
2745	21914	2464	республика Башкортостан, Кугарчинский район, село Багдашкино, Худайбердина, 45	f	small
2703	21870	2422	республика Башкортостан, Кугарчинский район, деревня Аралбай, Революционная, 39	f	small
2715	21882	2434	республика Башкортостан, Кугарчинский район, село Альмясово, Центральная, 35	f	small
2707	21874	2426	республика Башкортостан, Кугарчинский район, село Александровка, Молодежная, 25А	f	small
2659	21828	2379	республика Башкортостан, Краснокамский район, село Янгузнарат, Береговая, 25А	f	small
2667	21835	2387	республика Башкортостан, Краснокамский район, село Шушнур, Советская, 1	f	small
2671	21839	2391	республика Башкортостан, Краснокамский район, село Староянзигитово, Победы, 50	f	small
2654	21823	2374	республика Башкортостан, Краснокамский район, село СтарБуртюк, Центральная, 53	f	small
2677	21845	2397	республика Башкортостан, Краснокамский район, село Саузбаш, Дорожная, 4	f	small
2679	21846	2398	республика Башкортостан, Краснокамский район, село Саклово, Дорожная, 45	f	small
2555	21722	2274	республика Башкортостан, Краснокамский район, село Раздолье, Центральная, 15	f	small
2649	21818	2369	республика Башкортостан, Краснокамский район, село Раздолье, Молодежная, 3Б	f	medium
2657	21826	2377	республика Башкортостан, Краснокамский район, село Новый Каинлык, Школьная, 15	f	small
2662	21830	2382	республика Башкортостан, Краснокамский район, село Новохазино, Озерная, 22	f	small
2644	21812	2363	республика Башкортостан, Краснокамский район, село Новоуразаево, Ленина, 45	f	small
2670	21838	2390	республика Башкортостан, Краснокамский район, село Новонагаево, Колхозная, 36А	f	medium
2668	21836	2388	республика Башкортостан, Краснокамский район, село Новая Мушта, Большая, 5	f	small
2653	21822	2373	республика Башкортостан, Краснокамский район, село Новая Бура, Колхозная, 8а	f	medium
2655	21824	2375	республика Башкортостан, Краснокамский район, село НовБуртюк, Школьная, 8	f	small
2650	21819	2370	республика Башкортостан, Краснокамский район, село Никольское, Дорожная, 1	f	small
2680	21847	2399	республика Башкортостан, Краснокамский район, поселок Николо-Березовка, Макаренко, 2	f	large
2682	21849	2401	республика Башкортостан, Краснокамский район, поселок Николо-Березовка, Карла Маркса, 1	f	large
2681	21848	2400	республика Башкортостан, Краснокамский район, поселок Николо-Березовка, Карла Маркса, 5	f	large
2589	21756	2308	республика Башкортостан, Краснокамский район, село Мурзино, Речная, 7	f	small
2647	21816	2367	республика Башкортостан, Краснокамский район, село Музяк, Школьная, 2	f	medium
65762	21825	2376	республика Башкортостан, Краснокамский район, село Маняк, Чапаева, 27А	f	\N
65761	21814	2365	республика Башкортостан, Краснокамский район, село Кутлинка, Солнечная, 1	f	\N
2658	21827	2378	республика Башкортостан, Краснокамский район, село Купербаш, Речная, 65	f	small
2651	21820	2371	республика Башкортостан, Краснокамский район, село Кувакино, Центральная, 57	f	small
2645	21813	2364	республика Башкортостан, Краснокамский район, село Кариево, Школьная, 5	f	medium
2646	21815	2366	республика Башкортостан, Краснокамский район, село Енактаево, Можарская, 9А	f	small
2648	21817	2368	республика Башкортостан, Краснокамский район, село Воробьево, Школьная, 19	f	small
2652	21821	2372	республика Башкортостан, Краснокамский район, село Ведресево, Зеленая, 2	f	small
2660	21794	2380	республика Башкортостан, Краснокамский район, село Бурнюш, Школьная, 13	f	small
2663	21831	2383	республика Башкортостан, Краснокамский район, село Барьязибаш, Центральная, 40	f	small
2673	21841	2393	республика Башкортостан, Краснокамский район, село Бакчитау, Новая, 1А	f	small
2643	21811	2362	республика Башкортостан, Краснокамский район, село Арлан, Ленина, 28	f	medium
685	19763	423	республика Башкортостан, Краснокамский район, Агидель, Цветочный бульвар, 4	f	large
684	19763	422	республика Башкортостан, Краснокамский район, Агидель, Цветочный бульвар, 4	f	large
683	19917	421	республика Башкортостан, Краснокамский район, Агидель, Первых строителей, 7а	f	large
682	19916	420	республика Башкортостан, Краснокамский район, поселок Агидель, Первых строителей, 8А	f	large
377	19684	114	республика Башкортостан, Кировский район, поселок Уршак, аэропорт	f	medium
2634	21802	2353	республика Башкортостан, Кигинский район, село Ягуново, М.Халила, 17	f	small
2633	21801	2352	республика Башкортостан, Кигинский район, деревня Юкаликулево, Ленина, 33	f	small
134616	94461	2346	республика Башкортостан, Кигинский район, село Тукаево, Центральная, 31	f	\N
3270	22495	3049	республика Башкортостан, Кигинский район, село Тукаево, Центральная, 39	f	small
2620	21787	2339	республика Башкортостан, Кигинский район, село Тугузлы, Советская, 43	f	small
2619	21786	2338	республика Башкортостан, Кигинский район, село Сюрбаево, Нагорная, 4	f	small
65758	21804	2355	республика Башкортостан, Кигинский район, село Султановка, Солдатская, 82	f	\N
65757	21800	2351	республика Башкортостан, Кигинский район, село Старомухаметово, Советская, 18	f	\N
2626	21793	2345	республика Башкортостан, Кигинский район, село Сагирово, Новая, 5	f	small
65760	21810	2361	республика Башкортостан, Кигинский район, село Нижние Киги, 8-Марта, 1	f	\N
134617	94462	2359	республика Башкортостан, Кигинский район, село Леуза, Ракшина, 9	f	\N
2639	21807	2358	республика Башкортостан, Кигинский район, село Леуза, Гагарина, 35	f	medium
2638	21806	2357	республика Башкортостан, Кигинский район, село Кургашево, Салавата Юлаева, 15	f	small
65756	21798	2349	республика Башкортостан, Кигинский район, село Кульметово, Школьная, 10	f	\N
65753	21785	2337	республика Башкортостан, Кигинский район, село Кулбаково, Заречная, 1	f	\N
2635	21803	2354	республика Башкортостан, Кигинский район, село Кандаковка, Мира, 2	f	small
3093	22257	2811	республика Башкортостан, Кигинский район, село Идрисово, Школьная, 8	t	small
65752	21784	2336	республика Башкортостан, Кигинский район, село Идрисово, Молодежная, 7	f	\N
1301	20491	1031	республика Башкортостан, Кигинский район, село Идрисово, Салавата Юлаева, 8/1	f	small
2631	21799	2350	республика Башкортостан, Кигинский район, село Ибраево, Советская, 25	f	small
65754	21796	2347	республика Башкортостан, Кигинский район, село Еланлино, Бурхана Шарафутдинова, 27	f	\N
2625	21792	2344	республика Башкортостан, Кигинский район, село Душанбеково, Советская, 44	f	small
2621	21788	2340	республика Башкортостан, Кигинский район, село Верхние Киги, Советская, 8	f	large
2622	21789	2341	республика Башкортостан, Кигинский район, село Верхние Киги, Салавата, 7А	f	large
2623	21790	2342	республика Башкортостан, Кигинский район, село Верхние Киги, Ибрагимова, 19	f	large
65755	21797	2348	республика Башкортостан, Кигинский район, село Вакиярово, Школьная, 47	f	\N
2616	21783	2335	республика Башкортостан, Кигинский район, село Асылгужино, Центральная, 18	f	small
2615	21782	2334	республика Башкортостан, Кигинский район, село Арсланово, Кирова, 16	f	small
2613	21780	2332	республика Башкортостан, Кигинский район, село Алагузово, Гагарина, 77	f	small
65751	21779	2331	республика Башкортостан, Кигинский район, село Абзаево, Школьная, 4, РБ	f	\N
2580	21748	2299	республика Башкортостан, Кармаскалинский район, село Шарипкулово, Школьная, 17/1	f	small
2611	21778	2330	республика Башкортостан, Кармаскалинский район, село Шаймуратово, Партизанская, 36	f	medium
2592	21759	2311	республика Башкортостан, Кармаскалинский район, село Утяганово, Идель, 30	f	small
65749	21747	2298	республика Башкортостан, Кармаскалинский район, село Урал, Центральная, 21	f	\N
2577	21745	2296	республика Башкортостан, Кармаскалинский район, село Улукулево, К. Маркса, 101	f	large
2578	21746	2297	республика Башкортостан, Кармаскалинский район, село Улукулево, 60 лет Октября, 82А	f	large
2605	21772	2324	республика Башкортостан, Кармаскалинский район, село Старошареево, Новая, 31	f	small
2609	21776	2328	республика Башкортостан, Кармаскалинский район, село Старомусино, Молодежная, 3	f	medium
2604	21771	2323	республика Башкортостан, Кармаскалинский район, село Староакташево, Школьная, 4	f	small
65748	21741	2292	республика Башкортостан, Кармаскалинский район, село Сихонкино, Школьная, 8	f	\N
2603	21770	2322	республика Башкортостан, Кармаскалинский район, село Сахаево, Шоссейная, 3	f	medium
2591	21758	2310	республика Башкортостан, Кармаскалинский район, село Сарт-Чишма, Школьная, 45а	f	medium
3643	22865	3422	республика Башкортостан, Кармаскалинский район, село Сарсаз, Центральная, 8	f	small
2600	21767	2319	республика Башкортостан, Кармаскалинский район, село Савалеево, Мира, 4	f	medium
2590	21757	2309	республика Башкортостан, Кармаскалинский район, село Новые Киешки, Б.Батыровой, 11	f	medium
2587	21754	2306	республика Башкортостан, Кармаскалинский район, село Николаевка, 50 лет Октября, 9а	f	medium
2567	21735	2286	республика Башкортостан, Кармаскалинский район, село Никитино, Центральная, 16	f	small
2588	21755	2307	республика Башкортостан, Кармаскалинский район, село Мукаево, Центральная, 31	f	small
2575	21743	2294	республика Башкортостан, Кармаскалинский район, село Малаево, Центральная, 12	f	small
2581	21733	2300	республика Башкортостан, Кармаскалинский район, село Кустугулово, Центральная, 70	f	small
2582	21749	2301	республика Башкортостан, Кармаскалинский район, село Кармаскалы, Советская, 33	f	large
2583	21750	2302	республика Башкортостан, Кармаскалинский район, село Кармаскалы, Садовая, 25	f	large
2584	21751	2303	республика Башкортостан, Кармаскалинский район, село Кармаскалы, Парковая, 7	f	large
2606	21773	2325	республика Башкортостан, Кармаскалинский район, село Карламанбаш, Центральная, 31	f	small
2585	21752	2304	республика Башкортостан, Кармаскалинский район, село Карламан, Ш. Биккула, 30	f	small
2574	21742	2293	республика Башкортостан, Кармаскалинский район, село Камышлинка, Школьная, 46	f	small
65750	21777	2329	республика Башкортостан, Кармаскалинский район, село Ильтеряково, Школьная, 1	f	\N
65747	21738	2289	республика Башкортостан, Кармаскалинский район, село Ефремкино, Ленина, 19	f	\N
78506	7798	781	Ульяновская область, Ульяновск, улица Академика Сахарова, 11	f	large
2444	21613	2163	республика Башкортостан, Кармаскалинский район, поселок Восток, Восточная, 52	f	small
2568	21736	2287	республика Башкортостан, Кармаскалинский район, село Бузовьязы, Советская, 1	f	large
2598	21765	2317	республика Башкортостан, Кармаскалинский район, село Бишаул-Унгарово, Школьная, 17	f	medium
2566	21734	2285	республика Башкортостан, Кармаскалинский район, село Адзитарово, Коммунистическая, 32в	f	medium
2533	21700	2252	республика Башкортостан, Караидельский район, село Янбак, Школьная, 12	t	small
2552	21719	2271	республика Башкортостан, Караидельский район, село Якупово, Дружбы, 1	f	small
2564	21732	2283	республика Башкортостан, Караидельский район, село Явгильдино, Центральная, 15	f	small
134615	94460	2259	республика Башкортостан, Караидельский район, село Шамратово, Садовая, 2	f	\N
2557	21726	2276	республика Башкортостан, Караидельский район, село Чебыково, Школьная, 24	f	small
2988	22152	2706	республика Башкортостан, Караидельский район, село Чебыково, Ленина, 40	f	small
2527	21693	2246	республика Башкортостан, Караидельский район, село Чапаш, Центральная, 20	f	small
2550	21717	2269	республика Башкортостан, Караидельский район, село Халилово, Школьная, 1	f	small
2560	21727	2279	республика Башкортостан, Караидельский район, село Урюш-Битуллино, Трактовая, 1	f	small
2549	21716	2268	республика Башкортостан, Караидельский район, село Уразаево, Центральная, 4	f	small
1431	20620	1161	республика Башкортостан, Караидельский район, село Уразаево, Центральная, 5	f	small
2553	21720	2272	республика Башкортостан, Караидельский район, село Тегерменево, Центральная, 16	f	small
2565	21731	2284	республика Башкортостан, Караидельский район, село Тайкаш, Хамзи Исламова, 40	f	small
3354	22580	3133	республика Башкортостан, Караидельский район, село Суюндюково, Таулы, 7	f	small
2536	21703	2255	республика Башкортостан, Караидельский район, село Суюндюково, Суюндюковская, 30	f	small
2526	21694	2245	республика Башкортостан, Караидельский район, село Старые Багазы, Центральная, 14	f	small
2515	21682	2234	республика Башкортостан, Караидельский район, село Старооткустино, Центральная, 23	f	small
2561	21728	2280	республика Башкортостан, Караидельский район, село Седяш, Хайруллина, 2	f	small
2521	21688	2240	республика Башкортостан, Караидельский район, село Седяш, Речная, 30	f	small
2593	21760	2312	республика Башкортостан, Караидельский район, село Подлубово, Советская, 42	f	large
65746	21714	2266	республика Башкортостан, Караидельский район, село Подлубово, Дружбы, 15	f	\N
2543	21710	2262	республика Башкортостан, Караидельский район, село Озерки, Набережная, 19	f	small
2539	21706	2258	республика Башкортостан, Караидельский район, село Новый Бердяш, Центральная, 24	f	small
2520	21687	2239	республика Башкортостан, Караидельский район, село Новоянсаитово, Центральная, 15	f	small
2542	21709	2261	республика Башкортостан, Караидельский район, село Новомуллакаево, Центральная, 6	f	small
2525	21692	2244	республика Башкортостан, Караидельский район, село Нижние Балмазы, Школьная, 37	f	small
2548	21715	2267	республика Башкортостан, Караидельский район, село Нагретдиново, Центральная, 18	f	small
2563	21730	2282	республика Башкортостан, Караидельский район, село Мрясимово, Центральная, 3	f	small
2537	21704	2256	республика Башкортостан, Караидельский район, поселок Магинск, Октябрьская, 22	f	large
2534	21701	2253	республика Башкортостан, Караидельский район, село Куртлыкуль, Мира, 47	f	small
2544	21711	2263	республика Башкортостан, Караидельский район, село Круш, Центральная, 29	t	small
2562	21729	2281	республика Башкортостан, Караидельский район, село Красный Урюш, Школьная, 19	f	small
2530	21697	2249	республика Башкортостан, Караидельский район, село Комсомольский, Почтовая, 3	f	small
65744	21698	2251	республика Башкортостан, Караидельский район, село Кирзя, Центральная, 29	f	\N
2528	21695	2247	республика Башкортостан, Караидельский район, село Караяр, Советская, 16	f	medium
2523	21690	2242	республика Башкортостан, Караидельский район, село Караидель, Мира, 13/1	f	large
2522	21689	2241	республика Башкортостан, Караидельский район, село Караидель, Ленина, 9	f	large
71630	79818	131	Самарская область, Чапаевск, Жуковского, 35	f	large
65737	21645	2196	республика Башкортостан, Караидельский район, село Калтасы, Карла Маркса, 64	f	\N
2476	21644	2195	республика Башкортостан, Караидельский район, село Калтасы, Карла Маркса, 74	f	large
2559	21723	2278	республика Башкортостан, Караидельский район, село Зуевка, Центральная, 3	f	small
2558	21725	2277	республика Башкортостан, Караидельский район, село Дубровка, переулок Школьный, 3	f	small
2535	21702	2254	республика Башкортостан, Караидельский район, село Деушево, Лесная, 12	f	small
2519	21686	2238	республика Башкортостан, Караидельский район, село Бердяш, Центральная, 1	f	small
2546	21713	2265	республика Башкортостан, Караидельский район, село Бартым, Лесная, 6/2	f	small
2516	21683	2235	республика Башкортостан, Караидельский район, село Байкибашево, Корочкина, 84	f	large
134613	94458	2236	республика Башкортостан, Караидельский район, село Байки-Юнусово, Центральная, 12	f	\N
65742	21685	2237	республика Башкортостан, Караидельский район, село Байки, Ленина, 52	f	\N
2531	21699	2250	республика Башкортостан, Караидельский район, село Атамановка, Школьная, 11/3	f	small
2524	21691	2243	республика Башкортостан, Караидельский район, село Абызово, Лежнина, 19	f	medium
2514	21681	2233	республика Башкортостан, Караидельский район, село Абуталипово, Ленина, 10	f	small
134614	94459	2248	республика Башкортостан, Караидельский район, село Абдуллино, С.Юлаева, 10а	f	\N
2483	21651	2202	республика Башкортостан, Калтасинский район, село Чумара, Центральная, 18	f	small
2489	21657	2208	республика Башкортостан, Калтасинский район, село Чилибеево, Пеледыш, 32	f	small
2495	21663	2214	республика Башкортостан, Калтасинский район, село Тюльди, Центральная, 69	f	small
65738	21665	2216	республика Башкортостан, Калтасинский район, село Старый Орьебаш, Комсомольская, 18	f	\N
2478	21646	2197	республика Башкортостан, Калтасинский район, село Старые Калтасы, Центральная, 8	f	small
2501	21669	2220	республика Башкортостан, Калтасинский район, село Старояшево, Садовая, 10	f	small
1418	20607	1148	республика Башкортостан, Калтасинский район, село Норкино, Ленина, 7	f	small
2498	21666	2217	республика Башкортостан, Калтасинский район, село Новокильбахтино, Ленина, 18	f	small
2492	21660	2211	республика Башкортостан, Калтасинский район, село Нижний Качмаш, Гагарина, 39 А	f	small
2482	21650	2201	республика Башкортостан, Калтасинский район, село Надеждино, Центральная, 4	f	small
2665	21833	2385	республика Башкортостан, Калтасинский район, село Куяново, Танып, 57	f	large
2664	21832	2384	республика Башкортостан, Калтасинский район, село Куяново, Танып, 44	f	large
2500	21668	2219	республика Башкортостан, Калтасинский район, село Кучаш, Школьная, 9	f	small
2486	21654	2205	республика Башкортостан, Калтасинский район, село Кутерем, Нефтяников, 6	f	medium
2505	21673	2224	республика Башкортостан, Калтасинский район, село Кугарчино, Нагорная, 7	f	small
2511	21679	2230	республика Башкортостан, Калтасинский район, поселок Краснохолмский, Юбилейная, 2	f	large
2509	21677	2228	республика Башкортостан, Калтасинский район, поселок Краснохолмский, Тимиряя, 1 А	f	large
2510	21678	2229	республика Башкортостан, Калтасинский район, поселок Краснохолмский, Стадионная, 7	f	large
65739	21674	2225	республика Башкортостан, Калтасинский район, поселок Краснохолмский, Парковая, 1	f	\N
65740	21674	2231	республика Башкортостан, Калтасинский район, поселок Краснохолмский, Парковая, 1	f	\N
2493	21661	2212	республика Башкортостан, Калтасинский район, село Кокуш, Пушкина, 16	f	small
2504	21672	2223	республика Башкортостан, Калтасинский район, село Качкинтурай, В.Абдуллина, 16	f	small
1671	20854	1397	республика Башкортостан, Калтасинский район, село Каменка, Школьная, 13	f	small
2480	21648	2199	республика Башкортостан, Калтасинский район, село Калмиябаш, Молодежная, 16	f	small
2488	21656	2207	республика Башкортостан, Калтасинский район, село Калегино, Советская, 18 А	f	small
2485	21653	2204	республика Башкортостан, Калтасинский район, село Графское, Мира, 40А	f	small
2494	21662	2213	республика Башкортостан, Калтасинский район, село Верхний Качмаш, Кирова, 29	f	small
2484	21652	2203	республика Башкортостан, Калтасинский район, село Большой Кельтей, Советская, 21А	f	medium
2496	21664	2215	республика Башкортостан, Калтасинский район, село Большетуганеево, Кооперативная, 1 А	f	small
2507	21675	2226	республика Башкортостан, Калтасинский район, село Большекуразово, Центральная, 2	f	small
2503	21671	2222	республика Башкортостан, Калтасинский район, село Большекачаково, Советская, 65А	f	medium
3642	22864	3421	республика Башкортостан, Калтасинский район, село Барсуково, Школьная, 10А	f	small
2481	21649	2200	республика Башкортостан, Калтасинский район, село Бабаево, Центральная, 1	f	medium
2490	21658	2209	республика Башкортостан, Калтасинский район, село Амзибаш, Дружбы, 3	f	small
2502	21670	2221	республика Башкортостан, Калтасинский район, село Актуганово, Дорожная, 1	f	small
2441	21610	2160	республика Башкортостан, Ишимбайский район, село Яр-Бишкадак, Береговая, 29	f	small
65818	21620	2170	республика Башкортостан, Ишимбайский район, село Янурусово, Пролетарская, 14а	f	\N
109367	22336	2907	республика Башкортостан, Ишимбайский район, село Шихан, Центральная, 2а	f	\N
934	20142	671	республика Башкортостан, Ишимбайский район, Шахтау, Российская, 9	f	large
2442	21611	2161	республика Башкортостан, Ишимбайский район, село Урман-Бишкадак, Центральная, 20Г	f	medium
65734	21637	2188	республика Башкортостан, Ишимбайский район, село Уразбаево, Октября, 17	f	\N
2449	21618	2168	республика Башкортостан, Ишимбайский район, село Тимашевка, Партизанская, 49	f	small
2473	21641	2192	республика Башкортостан, Ишимбайский район, село Скворчиха, Школьная, 6	f	small
65729	21632	2183	республика Башкортостан, Ишимбайский район, село Сайраново, Надыршина, 18	f	\N
3088	22252	2806	республика Башкортостан, Ишимбайский район, село Павловка, Электрофикации, 40	f	small
65731	21634	2185	республика Башкортостан, Ишимбайский район, село Новоаптиково, Школьная, 8	f	\N
65819	21621	2171	республика Башкортостан, Ишимбайский район, село Нижнеарметово, Гизатуллина, 84б	f	\N
2457	21625	2176	республика Башкортостан, Ишимбайский район, село Кулгунино, Школьная, 19	f	large
65826	21630	2181	республика Башкортостан, Ишимбайский район, село Кузяново, Советская, 46	f	\N
65736	21642	2193	республика Башкортостан, Ишимбайский район, село Кинзекеево, Первомайская, 11	f	\N
65735	21639	2190	республика Башкортостан, Ишимбайский район, село Кинзебулатово, 1 мая, 20	f	\N
65813	21612	2162	республика Башкортостан, Ишимбайский район, село Карайганово, Кутушева, 30	f	\N
65815	21615	2165	республика Башкортостан, Ишимбайский район, село Канакаево, Хасанова, 55	f	\N
2427	21596	2146	республика Башкортостан, Ишимбайский район, Ишимбай, Чкалова, 21	f	large
2418	21588	2137	республика Башкортостан, Ишимбайский район, Ишимбай, Чкалова, 4	f	large
65811	21575	2123	республика Башкортостан, Ишимбайский район, Ишимбай, Стахановская, 16	f	\N
2423	21593	2142	республика Башкортостан, Ишимбайский район, Ишимбай, Советская, 72	f	large
2437	21606	2156	республика Башкортостан, Ишимбайский район, Ишимбай, Революционная, 85	f	large
2412	21582	2131	республика Башкортостан, Ишимбайский район, Ишимбай, Мичурина, 13	f	large
2432	21601	2151	республика Башкортостан, Ишимбайский район, Ишимбай, Ленина проспект, 18А	f	medium
2411	21581	2130	республика Башкортостан, Ишимбайский район, Ишимбай, Крылова, 31	f	large
2405	21548	2124	республика Башкортостан, Ишимбайский район, Ишимбай, Ишимбайская, 32Б	f	large
2403	21574	2122	республика Башкортостан, Ишимбайский район, Ишимбай, Заки Валиди бульвар, 5	f	large
65812	21576	2125	республика Башкортостан, Ишимбайский район, Ишимбай, пос.Перегонный, Жуковского, 14	f	\N
2422	21592	2141	республика Башкортостан, Ишимбайский район, Ишимбай, Губкина, 27	f	large
2420	21590	2139	республика Башкортостан, Ишимбайский район, Ишимбай, Губкина, 15	f	medium
65816	21616	2166	республика Башкортостан, Ишимбайский район, село Ишеево, Уразбаевых, 66	f	\N
2475	21643	2194	республика Башкортостан, Ишимбайский район, село Верхотор, Ленина, 43	f	medium
65732	21635	2186	республика Башкортостан, Ишимбайский район, село Верхнеиткулово, Молодежная, 2	f	\N
65820	21622	2172	республика Башкортостан, Ишимбайский район, село Верхнеарметово, Советская, 87	f	\N
65728	21631	2182	республика Башкортостан, Ишимбайский район, село Биксяново, Селеукская, 45	f	\N
2448	21617	2167	республика Башкортостан, Ишимбайский район, село Бердышла, Центральная, 11	f	small
3687	22910	3467	республика Башкортостан, Ишимбайский район, село Байгузино, Школьная, 22	f	small
2472	21640	2191	республика Башкортостан, Ишимбайский район, село Байгузино, Пионерских лагерей, 1А	f	small
65814	21614	2164	республика Башкортостан, Ишимбайский район, село Ахмерово, Горная, 6	f	\N
65822	21626	2177	республика Башкортостан, Ишимбайский район, село Арметрахимово, Центральная, 40	f	\N
65730	21633	2184	республика Башкортостан, Ишимбайский район, село Аптиково, Салавата Юлаева, 47	f	\N
65733	21636	2187	республика Башкортостан, Ишимбайский район, село Азнаево, Гиниятуллина, 28	f	\N
65807	21553	2100	республика Башкортостан, Илишевский район, село Янтуганово, Центральная, 21, 452269	f	\N
65788	21503	2052	республика Башкортостан, Илишевский район, село Шамметово, Центральная, 22	f	\N
65790	21509	2058	республика Башкортостан, Илишевский район, село Чуй-Атасево, Чапаева, 9	f	\N
2377	21549	2096	республика Башкортостан, Илишевский район, село Уяндыково, Лесная, 44	f	small
65796	21519	2068	республика Башкортостан, Илишевский район, село Урняково, Урняк, 28а	f	\N
65802	21530	2078	республика Башкортостан, Илишевский район, село Улу-Ялан, Лесная, 17а	f	\N
65799	21525	2073	республика Башкортостан, Илишевский район, село Турачи, Центральная, 52/1	f	\N
2386	21558	2105	республика Башкортостан, Илишевский район, село Тупеево, Центральная, 8/1	f	small
65800	21526	2074	республика Башкортостан, Илишевский район, село Тукай-Тамак, Сюнь, 11	t	\N
2361	21532	2080	республика Башкортостан, Илишевский район, село Телепаново, Центральная, 27	f	small
2358	21529	2077	республика Башкортостан, Илишевский район, село Телекеево, Центральная, 24а	f	small
65791	21510	2059	республика Башкортостан, Илишевский район, село Ташкичи, Ленина, 37а	f	\N
65792	21512	2061	республика Башкортостан, Илишевский район, село Татарский Менеуз, Ворошилова, 18а	f	\N
2372	21543	2091	республика Башкортостан, Илишевский район, село Тазеево, Мостовая, 10	f	small
2380	21552	2099	республика Башкортостан, Илишевский район, село Сюльтино, Центральная, 5	f	small
65804	21538	2086	республика Башкортостан, Илишевский район, село Сынгряново, Мухамадиева, 4	f	\N
2395	21566	2114	республика Башкортостан, Илишевский район, село Старотатышево, Советская, 57	f	small
2382	21554	2101	республика Башкортостан, Илишевский район, село Старокуктово, Советская, 57	f	small
2375	21546	2094	республика Башкортостан, Илишевский район, село Старокиргизово, Новая, 13	f	small
2365	21536	2084	республика Башкортостан, Илишевский район, село Саиткулово, Центральная, 42	f	small
2379	21551	2098	республика Башкортостан, Илишевский район, село Рсаево, Советская, 4а	f	medium
2338	21508	2057	республика Башкортостан, Илишевский район, село Новонадырово, Титова, 9а	f	small
2374	21545	2093	республика Башкортостан, Илишевский район, село Новомедведево, Школьная, 10	f	small
65805	21540	2088	республика Башкортостан, Илишевский район, село Новокуктово, Куйбышева, 42	f	\N
65808	21520	2109	республика Башкортостан, Илишевский район, село Нижнеяркеево, К.Маркса, 6/1	f	\N
2387	21559	2106	республика Башкортостан, Илишевский район, село Нижнечерекулево, Советская, 26	f	small
2336	21506	2055	республика Башкортостан, Илишевский район, село Марино, Чапаева, 21	t	small
65793	21513	2062	республика Башкортостан, Илишевский район, село Мари-Менеуз, Ленина, 18	f	\N
2346	21516	2065	республика Башкортостан, Илишевский район, село Мало-Бишкураево, Х.Гильданова, 28	f	small
2364	21535	2083	республика Башкортостан, Илишевский район, село Лаяшты, Кооперативная, 40	f	small
2371	21542	2090	республика Башкортостан, Илишевский район, село Кужбахты, Шоссейная, 10	f	small
2378	21550	2097	республика Башкортостан, Илишевский район, село Красноярово, Молодежная, 28	f	small
65787	21502	2051	республика Башкортостан, Илишевский район, Кипчаково, Центральная, 12	f	\N
2368	21539	2087	республика Башкортостан, Илишевский район, село Карабашево, Мира, 47	f	small
65803	21537	2085	республика Башкортостан, Илишевский район, село Кадырово, Центральная, 34	f	\N
2370	21541	2089	республика Башкортостан, Илишевский район, село Иштеряково, Пионерская, 5	f	small
2363	21534	2082	республика Башкортостан, Илишевский район, село Ишкарово, Ленина, 42	f	medium
2360	21531	2079	республика Башкортостан, Илишевский район, село Итеево, Советская, 54	f	small
2357	21528	2076	республика Башкортостан, Илишевский район, село Исанбаево, Школьная, 33А	f	small
3695	22918	3475	республика Башкортостан, Илишевский район, село Исанбаево, Центральная, 28	t	small
65798	21524	2072	республика Башкортостан, Илишевский район, село Исаметово, Шоссейная, 10/1	f	\N
2393	21564	2112	республика Башкортостан, Илишевский район, село Илишево, Советская, 32	f	small
2384	21556	2103	республика Башкортостан, Илишевский район, Ибрагим, Победы, 1	f	small
65801	21527	2075	республика Башкортостан, Илишевский район, село Зяйлево, Береговая, 31/1	f	\N
65794	21517	2066	республика Башкортостан, Илишевский район, село Дюмеево, Советская, 3а, 452264	f	\N
65806	21547	2095	республика Башкортостан, Илишевский район, село Груздевка, Новая, 1, 452274	f	\N
2373	21544	2092	республика Башкортостан, Илишевский район, село Гремучий Ключ, Родниковая, 4	f	small
2394	21565	2113	республика Башкортостан, Илишевский район, село Верхние Юлдашево, Чеверева, 1	f	small
2401	21572	2120	республика Башкортостан, Илишевский район, село Верхнеяркеево, Советская, 42	f	large
2397	21568	2116	республика Башкортостан, Илишевский район, село Верхнеяркеево, Советская, 31	f	medium
65809	21570	2118	республика Башкортостан, Илишевский район, село Верхнеяркеево, Молодежная, 18	f	\N
65810	21571	2119	республика Башкортостан, Илишевский район, село Верхнеяркеево, Матросова, 38/1	f	\N
2396	21567	2115	республика Башкортостан, Илишевский район, село Верхнеяркеево, Коммунистическая, 15	f	large
2398	21569	2117	республика Башкортостан, Илишевский район, село Верхнеяркеево, 50-лет Октября, 20	f	large
2389	21561	2108	республика Башкортостан, Илишевский район, село Верхнеюнново, Дорожная, 3	f	medium
2388	21560	2107	республика Башкортостан, Илишевский район, село Верхнечерекулево, Гафури, 24	f	small
2352	21523	2071	республика Башкортостан, Илишевский район, село Верхнеманчарово, Ленина, 6	f	small
2362	21533	2081	республика Башкортостан, Илишевский район, село Буралы, Центральная, 33	f	small
2344	21514	2063	республика Башкортостан, Илишевский район, село Бишкураево, Ленина, 69	f	small
65789	21507	2056	республика Башкортостан, Илишевский район, село Базитамак, Пушкина, 16а	f	\N
65795	21518	2067	республика Башкортостан, Илишевский район, село База-Куяново, Чишминская, 38а	f	\N
2334	21504	2053	республика Башкортостан, Илишевский район, село Андреевка, Советская, 41	f	medium
2335	21505	2054	республика Башкортостан, Илишевский район, село Аначево, Свердлова, 37/1	f	small
65786	21501	2050	республика Башкортостан, Илишевский район, село Аккузево, Школьная, 1	f	\N
65797	21522	2070	республика Башкортостан, Илишевский район, село Абдуллино, Дружбы, 32	f	\N
3309	22533	3088	республика Башкортостан, Иглинский район, село Ясная Поляна, Центральная, 1	f	small
2328	21498	2047	республика Башкортостан, Иглинский район, село Чуваш-Кубово, Площадь Октября, 32	f	large
2299	21470	2019	республика Башкортостан, Иглинский район, село Урунда, Центральная, 7	f	small
2296	21467	2016	республика Башкортостан, Иглинский район, поселок Урман, Ленина, 2А	f	small
2295	21466	2015	республика Башкортостан, Иглинский район, поселок Урман, Калинина, 12	f	medium
2293	21464	2013	республика Башкортостан, Иглинский район, поселок Улу-Теляк, Ленина, 23	f	medium
2294	21465	2014	республика Башкортостан, Иглинский район, поселок Улу-Теляк, Коммунистическая, 12	f	medium
2315	21485	2034	республика Башкортостан, Иглинский район, село Улу-Карамалы, Пчеловодов, 45	f	small
2324	21494	2043	республика Башкортостан, Иглинский район, село Уктеево, Центральная, 24	f	small
2323	21493	2042	республика Башкортостан, Иглинский район, село Турбаслы, Центральная, 40/1	f	medium
2319	21489	2038	республика Башкортостан, Иглинский район, село Тикеево, Главная, 20	f	small
1417	20606	1147	республика Башкортостан, Иглинский район, село Ташлы-Елга, Центральная, 25	f	small
65784	21484	2033	республика Башкортостан, Иглинский район, село Тау, Родниковая, 45	f	\N
2321	21491	2040	республика Башкортостан, Иглинский район, село Тавтиманово, Крупской, 36	f	large
65785	21499	2048	республика Башкортостан, Иглинский район, село Старокубово, Школьная, 10	f	\N
2326	21496	2045	республика Башкортостан, Иглинский район, село Саратовская Лобово, Центральная, 44	f	small
2317	21487	2036	республика Башкортостан, Иглинский район, село Расмикеево, Центральная, 18	f	small
2318	21488	2037	республика Башкортостан, Иглинский район, село Пятилетка, Центральная, 4	f	small
2301	21472	2021	республика Башкортостан, Иглинский район, село Пятилетка, Романовская, 19	f	small
65783	21480	2029	республика Башкортостан, Иглинский район, село Пушкинское, Горького, 20	f	\N
2322	21492	2041	республика Башкортостан, Иглинский район, село Покровка, Школьная, 32	f	small
2455	21623	2174	республика Башкортостан, Иглинский район, Петровское село, Ленина, 21	f	large
2454	21623	2173	республика Башкортостан, Иглинский район, Петровское село, Ленина, 21	f	medium
3265	22490	3044	республика Башкортостан, Иглинский район, село Первомайское, Садовая, 22	f	medium
3508	22732	3287	республика Башкортостан, Иглинский район, село Первомайское, Бабича, 13	f	small
3598	22823	3377	республика Башкортостан, Иглинский район, село Первомайский, Конторная, 1	f	small
2320	21490	2039	республика Башкортостан, Иглинский район, село Охлебинино, Анискина, 2	f	medium
2330	21500	2049	республика Башкортостан, Иглинский район, село Новокубово, Хисматуллина, 15/1	f	small
2313	21483	2032	республика Башкортостан, Иглинский район, село Нижние Лемезы, Центральная, 39	f	small
2306	21477	2026	Россия, республика Башкортостан, Иглинский район, село Михайловка	f	small
2325	21495	2044	республика Башкортостан, Иглинский район, село Минзитарово, Центральная, 50	f	small
2316	21486	2035	республика Башкортостан, Иглинский район, село Майский, Центральная, 15	f	small
2969	22133	2687	республика Башкортостан, Иглинский район, село Ленинское, Новостройка, 5	f	small
2292	21463	2012	республика Башкортостан, Иглинский район, поселок Кудеевский, Чапаева, 1	f	medium
2291	21462	2011	республика Башкортостан, Иглинский район, поселок Кудеевский, Пушкина, 2	f	medium
2304	21475	2024	республика Башкортостан, Иглинский район, село Красный Восход, Молодежная, 41	f	small
2327	21497	2046	республика Башкортостан, Иглинский район, село Кляшево, Школьная, 1	f	small
2311	21481	2030	республика Башкортостан, Иглинский район, село Кальтовка, Парковая, 20	f	medium
2308	21478	2027	республика Башкортостан, Иглинский район, село Калтыманово, Школьная, 2	f	medium
2305	21476	2025	республика Башкортостан, Иглинский район, село Казаяк, Советская	f	small
2286	21457	2006	республика Башкортостан, Иглинский район, поселок Иглино, Якутова, 23/1	f	large
2289	21460	2009	республика Башкортостан, Иглинский район, поселок Иглино, Целинная, 2/3	f	large
2283	21454	2003	республика Башкортостан, Иглинский район, поселок Иглино, Свердлова, 15	f	medium
2284	21455	2004	республика Башкортостан, Иглинский район, поселок Иглино, Революционная, 26	f	medium
2290	21461	2010	республика Башкортостан, Иглинский район, поселок Иглино, Октябрьская, 7	f	large
2285	21456	2005	республика Башкортостан, Иглинский район, поселок Иглино, Ленина, 149	f	large
2288	21459	2008	республика Башкортостан, Иглинский район, поселок Иглино, Гражданская, 2	f	large
2287	21458	2007	республика Башкортостан, Иглинский район, поселок Иглино, Горького, 45	f	large
2303	21474	2023	республика Башкортостан, Иглинский район, село Ивано-Казанка, Центральная, 12	f	small
2302	21473	2022	республика Башкортостан, Иглинский район, село Балтика, Центральная, 45	f	medium
2300	21471	2020	республика Башкортостан, Иглинский район, село Ауструм, Школьная, 2	f	small
2309	21479	2028	республика Башкортостан, Иглинский район, село Алаторка, Интернациональная, 17	f	medium
2281	21452	2001	республика Башкортостан, Зилаирский район, село Ямансаз, Центральная, 1	f	medium
2280	21451	2000	республика Башкортостан, Зилаирский район, село Юмагужино, Ш. Бабича, 13	f	small
2277	21448	1997	республика Башкортостан, Зилаирский район, село Чуюнчи-Чупаново, Акман, 31	t	small
2275	21446	1995	республика Башкортостан, Зилаирский район, село Султантимирово, С. Юлаева, 28	t	small
2274	21445	1994	республика Башкортостан, Зилаирский район, село Староякупово, Дильмухаметова, 7	f	small
2273	21444	1993	республика Башкортостан, Зилаирский район, село Сидоровка, Молодёжная, 6	t	small
2272	21443	1992	республика Башкортостан, Зилаирский район, село Саляхово, Муртаева, 25	t	small
2270	21441	1990	республика Башкортостан, Зилаирский район, село Сабырово, Школьная, 1	f	small
2269	21440	1989	республика Башкортостан, Зилаирский район, село Петровка, Павлова, 9	f	small
65780	21437	1986	республика Башкортостан, Зилаирский район, село Новопреображенский, Центральная, 10	f	\N
65781	21438	1987	республика Башкортостан, Зилаирский район, село Новопокровский, Школьная, 7	t	\N
2263	21418	1983	республика Башкортостан, Зилаирский район, село Матраево, Салавата Юлаева, 41	f	medium
2262	21393	1982	республика Башкортостан, Зилаирский район, село Малоюлдыбаево, Шахизады Бабича, 16	f	small
2261	21380	1981	республика Башкортостан, Зилаирский район, село Максютово, Салавата Юлаева, 4	t	small
2258	21229	1978	республика Башкортостан, Зилаирский район, село Кашкарово, Школьная, 1	f	small
2257	21216	1977	республика Башкортостан, Зилаирский район, село Картлазма, Центральня, 14	f	small
2256	21435	1976	республика Башкортостан, Зилаирский район, поселок Кананикольское, Ленина, 24	f	medium
2255	21434	1975	республика Башкортостан, Зилаирский район, село Кадырша, Акмуллы, 25	t	small
2260	21367	1980	республика Башкортостан, Зилаирский район, село Зилаир, Шестакова, 16	f	medium
2268	21439	1988	республика Башкортостан, Зилаирский район, село Зилаир, Ленина, 51	f	large
65778	21293	1979	республика Башкортостан, Зилаирский район, село Зилаир, Ленина, 87	f	\N
2251	21430	1971	республика Башкортостан, Зилаирский район, село Верхнегалеево, Сакмара, 11А	t	small
2250	21429	1970	республика Башкортостан, Зилаирский район, село Васильевка, Клубная, 1	t	small
2248	21427	1968	республика Башкортостан, Зилаирский район, село Бердяш, Школьная, 5	f	small
2247	21426	1967	республика Башкортостан, Зилаирский район, село Балапан, Ш.Бабича, 8	f	small
2246	21425	1966	республика Башкортостан, Зилаирский район, село Байгужино, Молодежная, 9	f	small
2245	21424	1965	республика Башкортостан, Зилаирский район, село Ашкадарово, Школьная, 5	t	small
2244	21423	1964	республика Башкортостан, Зилаирский район, село Анновка, Школьная, 7	f	small
65727	21403	1945	республика Башкортостан, Зианчуринский район, село ферма 3, Речная, 45	f	\N
2239	21417	1959	республика Башкортостан, Зианчуринский район, село Яныбаево, Школьная, 24	f	small
2238	21414	1956	республика Башкортостан, Зианчуринский район, село Юнаево, Центральная, 38	f	small
2279	21450	1999	республика Башкортостан, Зианчуринский район, село Юлдыбаево, Советская, 55	f	large
2230	21408	1950	республика Башкортостан, Зианчуринский район, село Худабандино, Центральная, 14	f	small
2235	21413	1955	республика Башкортостан, Зианчуринский район, село Утягулово, С.Абдуллина, 51	f	small
2215	21392	1935	республика Башкортостан, Зианчуринский район, село Умбетово, Гафарова, 1	f	small
2199	21376	1919	республика Башкортостан, Зианчуринский район, село Трушино, Дружбы, 12А	f	small
2232	21410	1952	республика Башкортостан, Зианчуринский район, село Тазларово, Советская, 24	f	medium
2196	21372	1916	республика Башкортостан, Зианчуринский район, село Серегулово, Школьная, 21	f	small
2194	21365	1914	республика Башкортостан, Зианчуринский район, село Сагитово, Салавата Юлаева, 36	f	small
2222	21400	1942	Россия, республика Башкортостан, Зианчуринский район, село Новые Чебенки	f	medium
2218	21396	1938	республика Башкортостан, Зианчуринский район, село Новопетровское, Стеклянка, 2	f	small
2209	21384	1929	республика Башкортостан, Зианчуринский район, село Новопавловка, Мира, 18/1	f	small
2223	21401	1943	республика Башкортостан, Зианчуринский район, село Новониколаевка, Центральная, 63	f	small
2997	22161	2715	республика Башкортостан, Зианчуринский район, село Новониколаевка, Лесная, 25	f	small
2201	21377	1921	республика Башкортостан, Зианчуринский район, село Нижняя Бикберда, Центральная, 55	f	small
2213	21390	1933	республика Башкортостан, Зианчуринский район, село Нижняя Акберда, Хутор, 8	f	small
2183	21358	1903	республика Башкортостан, Зианчуринский район, село Мухамедьяново, Советская, 24	f	small
70709	79815	129	Самарская область, Чапаевск, Жуковского, 35	f	large
65777	21406	1948	республика Башкортостан, Зианчуринский район, село Малый Муйнак, Центральная, 25	f	\N
2187	21362	1907	республика Башкортостан, Зианчуринский район, село Малиновка, Школьная, 1/1	f	small
2216	21394	1936	республика Башкортостан, Зианчуринский район, село Мазитово, Большой Ускалык, 53/а	f	small
2237	21416	1958	республика Башкортостан, Зианчуринский район, село Лукьяновский, Центральная, 12	f	small
2221	21399	1941	республика Башкортостан, Зианчуринский район, село Кузебеково, Советская, 8	f	small
2241	21420	1961	республика Башкортостан, Зианчуринский район, село Кужанак, Школьная, 22А	f	small
2227	21405	1947	республика Башкортостан, Зианчуринский район, село Кугарчи, Комсомольская, 50б	f	medium
2229	21407	1949	республика Башкортостан, Зианчуринский район, село Кинзябулатово, Центральная, 30	f	small
2231	21409	1951	республика Башкортостан, Зианчуринский район, село Карагала, Центральная, 55	f	small
2211	21388	1931	республика Башкортостан, Зианчуринский район, село Казанка, Утарбарская, 37	f	small
2220	21398	1940	республика Башкортостан, Зианчуринский район, село Ишемгул, Сергея Чекмарева, 42	f	medium
2203	21379	1923	республика Башкортостан, Зианчуринский район, село Исянгулово, Советская, 1	f	large
134611	94456	1927	республика Башкортостан, Зианчуринский район, село Исянгулово, Магистральная, 1	f	\N
2206	21385	1926	республика Башкортостан, Зианчуринский район, село Исянгулово, Лесная, 1	f	small
2204	21381	1924	республика Башкортостан, Зианчуринский район, село Исянгулово, Комсомольская, 11	f	large
2205	21382	1925	республика Башкортостан, Зианчуринский район, село Исянгулово, 40 лет Победы, 2в	f	medium
2193	21370	1913	республика Башкортостан, Зианчуринский район, село Ильмаля, Кунсбаева, 1/4	f	small
2236	21415	1957	республика Башкортостан, Зианчуринский район, село Идяш, Школьная, 1	f	small
2210	21387	1930	республика Башкортостан, Зианчуринский район, село Идельбаково, Советская, 6	f	large
2197	21373	1917	республика Башкортостан, Зианчуринский район, село Ибраево, Школьная, 49а	f	small
2217	21395	1937	республика Башкортостан, Зианчуринский район, село Габбасово, Малый Ускалык, 41/2	f	small
2202	21378	1922	республика Башкортостан, Зианчуринский район, село Верхняя Бикберда, Центральная, 7	f	small
2212	21389	1932	республика Башкортостан, Зианчуринский район, село Верхний Муйнак, Центральная, 3	f	small
2240	21419	1960	республика Башкортостан, Зианчуринский район, село Верхние Мамбетшино, Центральная, 31	f	small
2195	21371	1915	республика Башкортостан, Зианчуринский район, село Биштиряк, Ялна Ер, 1	f	small
2234	21411	1953	республика Башкортостан, Зианчуринский район, село Биккужа, Центральная, 8а	f	small
2242	21421	1962	республика Башкортостан, Зианчуринский район, село Башкирский Бармак, Центральная, 6а	f	small
2184	21359	1904	республика Башкортостан, Зианчуринский район, село Башкирская Чумаза, Кооперативная, 30	f	small
2219	21397	1939	республика Башкортостан, Зианчуринский район, село Башкирская Ургинка, Молодежная, 6	f	medium
2198	21374	1918	республика Башкортостан, Зианчуринский район, село Байдавлетово, Бишай, 33	f	small
2190	21366	1910	республика Башкортостан, Зианчуринский район, село Баишево, Школьная, 5	f	small
2208	21386	1928	республика Башкортостан, Зианчуринский район, село Аютово, Набережная, 17	f	small
2182	21357	1902	республика Башкортостан, Зианчуринский район, село Алибаево, Ассель, 38	f	small
2192	21369	1912	республика Башкортостан, Зианчуринский район, село Акдавлетово, Центральная, 8	f	small
2189	21364	1909	республика Башкортостан, Зианчуринский район, село Абуляисово, Ишапай, 11	f	small
2181	21356	1901	республика Башкортостан, Зианчуринский район, село Абзаново, Магадеева, 42	f	medium
1501	20689	1231	республика Башкортостан, Ермекеевский район, село участок Санатория Имени Глуховского, Школьная, 1	f	small
2152	21329	1874	республика Башкортостан, Ермекеевский район, село имени 8 Марта, Школьная, 9	f	medium
65725	21355	1900	республика Башкортостан, Ермекеевский район, село Усман-Ташлы, Центральная, 27	f	\N
2179	21354	1899	республика Башкортостан, Ермекеевский район, село Тарказы, Молодежная, 26	f	medium
2178	21353	1898	республика Башкортостан, Ермекеевский район, село Суккулово, Школьная, 5	f	medium
2175	21350	1895	республика Башкортостан, Ермекеевский район, село Старые Сулли, Школьная, 155	f	small
2177	21352	1897	республика Башкортостан, Ермекеевский район, село Старошахово, Центральная, 12	f	small
65724	21351	1896	республика Башкортостан, Ермекеевский район, село Старотураево, Ленина, 20	f	\N
134612	94457	2218	республика Башкортостан, Ермекеевский район, село Старотураево, Кирова, 2/1	f	\N
65723	21348	1893	республика Башкортостан, Ермекеевский район, село Средние Карамалы, Чапаева, 2	f	\N
2172	21347	1892	республика Башкортостан, Ермекеевский район, село Спартак, Клубная, 4	f	medium
2171	21346	1891	республика Башкортостан, Ермекеевский район, село Семено-Макарово, Лесная, 7	f	small
2170	21345	1890	республика Башкортостан, Ермекеевский район, село Рятамак, Коммунистическая, 28	f	medium
1485	20673	1215	республика Башкортостан, Ермекеевский район, поселок Приютово, Школьная, 3	f	large
1484	20672	1214	республика Башкортостан, Ермекеевский район, поселок Приютово, Свердлова, 6	f	large
1481	20669	1211	республика Башкортостан, Ермекеевский район, поселок Приютово, Свердлова, 10	f	large
1479	20667	1209	республика Башкортостан, Ермекеевский район, поселок Приютово, Свердлова, 9а	f	large
1478	20666	1208	республика Башкортостан, Ермекеевский район, поселок Приютово, Свердлова, 5, Приютовский поссовет	f	large
1483	20671	1213	республика Башкортостан, Ермекеевский район, поселок Приютово, Первомайская, 8А	f	medium
1486	20674	1216	республика Башкортостан, Ермекеевский район, поселок Приютово, Комсомольская, 3в	f	large
1482	20670	1212	республика Башкортостан, Ермекеевский район, поселок Приютово, Бульвар Мира, 3	f	large
1477	20665	1207	республика Башкортостан, Ермекеевский район, поселок Приютово, Бульвар Мира, 9а	f	large
1480	20668	1210	республика Башкортостан, Ермекеевский район, поселок Приютово, 50 лет ВЛКСМ, 5а	f	large
2168	21343	1888	республика Башкортостан, Ермекеевский район, село Пионерский, Пионерская, 28	f	small
65722	21344	1889	республика Башкортостан, Ермекеевский район, село Новый, Молодежная, 8/1	f	\N
65721	21340	1885	республика Башкортостан, Ермекеевский район, село Новые Сулли, Центральная, 40	f	\N
2166	21341	1886	республика Башкортостан, Ермекеевский район, село Новошахово, Нагорная, 15	f	small
2167	21342	1887	республика Башкортостан, Ермекеевский район, село Новотураево, Салавата Юлаева, 43	f	small
2163	21338	1883	республика Башкортостан, Ермекеевский район, село Нижнии Карамалы, Молодежная, 2	f	small
2164	21339	1884	республика Башкортостан, Ермекеевский район, село Нижнеулу-Елга, Молодёжная, 10	f	small
2160	21337	1882	республика Башкортостан, Ермекеевский район, село Купченеево, Школьная, 59	f	small
65720	21336	1881	республика Башкортостан, Ермекеевский район, село Кулбаево, Клубная, 4а	f	\N
65719	21335	1880	республика Башкортостан, Ермекеевский район, село Исламбахты, Садовая, 1а	f	\N
2156	21333	1878	республика Башкортостан, Ермекеевский район, село Ермекеево, Школьная, 11	f	large
2155	21332	1877	республика Башкортостан, Ермекеевский район, село Ермекеево, Ленина, 3	f	large
2154	21331	1876	республика Башкортостан, Ермекеевский район, село Ермекеево, Коммунистическая, 3	f	medium
2151	21328	1873	республика Башкортостан, Ермекеевский район, село Верхнеулу-Елга, Центральная, 35	f	small
2157	21334	1879	республика Башкортостан, Ермекеевский район, село Больщеезингереево, Набережная, 16	f	small
2149	21327	1872	республика Башкортостан, Ермекеевский район, село Бекетово, Школьная, 2	f	small
2594	21761	2313	республика Башкортостан, Ермекеевский район, село Бекетово, Октябрьская, 21а	f	small
2148	21326	1871	республика Башкортостан, Ермекеевский район, село Атамкуль, Мира, 26/1	f	small
2147	21325	1870	республика Башкортостан, Ермекеевский район, село Абдулово, Горная, 14	f	small
2146	21324	1869	республика Башкортостан, Ермекеевский район, село Абдулкаримово, Тукая, 13	f	small
3172	22402	2951	республика Башкортостан, Дюртюлинский район, село Юсупово, Центральная, 23	f	small
2145	21323	1868	республика Башкортостан, Дюртюлинский район, село Юсупово, Центральная, 4	f	small
2144	21322	1867	республика Башкортостан, Дюртюлинский район, село Черлак, Центральная, 63	f	small
2140	21318	1863	республика Башкортостан, Дюртюлинский район, село Учпили, Советская, 48	f	small
2108	21286	1832	республика Башкортостан, Дюртюлинский район, село Урман-Асты, Механизаторская, 15	f	small
65718	21290	1836	республика Башкортостан, Дюртюлинский район, село ТатЯрмино, Давлетгареевых, 45А	f	\N
2135	21314	1859	республика Башкортостан, Дюртюлинский район, село Такарликово, Механизаторская, 5	f	small
2131	21310	1855	республика Башкортостан, Дюртюлинский район, село Таймурзино, Озерная, 2	f	medium
2132	21311	1856	республика Башкортостан, Дюртюлинский район, село Султанбеково, Ахуновых, 30	f	small
2129	21308	1853	республика Башкортостан, Дюртюлинский район, село Суккулово, Центральная, 9	f	medium
2125	21304	1849	республика Башкортостан, Дюртюлинский район, село Староянтузово, Молодежная, 2	f	medium
2123	21302	1847	республика Башкортостан, Дюртюлинский район, село Староуртаево, Кооперативная, 3	f	small
1421	20610	1151	Россия, республика Башкортостан, Дюртюлинский район, село Старобалтачево	f	large
2103	21281	1827	республика Башкортостан, Дюртюлинский район, село Старобалтачево, Дормидонтова, 9	f	small
2122	21301	1846	республика Башкортостан, Дюртюлинский район, село Старобаишево, Молодежная, 7	f	small
2105	21283	1829	республика Башкортостан, Дюртюлинский район, село Сикаликуль, Советская, 1/1	f	small
2117	21296	1841	республика Башкортостан, Дюртюлинский район, поселок Семилетка, Мира, 19А	f	large
2116	21295	1840	республика Башкортостан, Дюртюлинский район, поселок Семилетка, Мира, 19	f	medium
2118	21297	1842	республика Башкортостан, Дюртюлинский район, поселок Семилетка, Ленина, 10	f	medium
2127	21306	1851	республика Башкортостан, Дюртюлинский район, село Сабанаево, Фазыловых, 9	f	small
2139	21317	1862	республика Башкортостан, Дюртюлинский район, село Новобиктово, Механизаторская, 18	f	small
2121	21300	1845	республика Башкортостан, Дюртюлинский район, село Нижнеманчарово, Коммунистическая, 51Б	f	small
2119	21298	1843	республика Башкортостан, Дюртюлинский район, село Нижнеаташево, Гумерова, 47/2	f	small
2102	21280	1826	республика Башкортостан, Дюртюлинский район, село Нижнеалькашево, Школьная, 17	f	small
2114	21292	1838	республика Башкортостан, Дюртюлинский район, село Москово, Калинина, 47	f	medium
2113	21291	1837	республика Башкортостан, Дюртюлинский район, село Москово, Калинина, 47А	f	medium
2111	21289	1835	республика Башкортостан, Дюртюлинский район, село Миништы, Советская, 10	f	small
2109	21287	1833	республика Башкортостан, Дюртюлинский район, село Маядык, Горшкова, 14	f	medium
2137	21316	1861	республика Башкортостан, Дюртюлинский район, село Кушулево, Советская, 3	f	small
2106	21284	1830	республика Башкортостан, Дюртюлинский район, село Куккуяново, Школьная, 47	f	small
2101	21279	1825	республика Башкортостан, Дюртюлинский район, село Исмайлово, Школьная, 14	f	medium
2115	21294	1839	республика Башкортостан, Дюртюлинский район, село Имай-Утарово, Школьная, 1А	f	small
2107	21285	1831	республика Башкортостан, Дюртюлинский район, село Ивачево, Школьная, 8	f	small
2133	21312	1857	республика Башкортостан, Дюртюлинский район, село Иванаево, Комсомольская, 7	f	large
2141	21319	1864	республика Башкортостан, Дюртюлинский район, село Зейлево, Социалистическая, 2	f	small
2088	21269	1812	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, переулок Марии Якутовой, 4	f	large
2093	21274	1817	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Седова, 4/3	f	medium
2090	21271	1814	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Разиля Мусина, 80	f	large
2081	21263	1805	республика Башкортостан, Дюртюлинский район, Дюртюли, Первомайская, 3	f	large
2079	21261	1803	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Первомайская, 54	f	large
2087	21203	1811	республика Башкортостан, Дюртюлинский район, Дюртюли, Назара Наджми, 36	f	large
2085	21267	1809	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Матросова, 3	f	large
2082	21264	1806	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Матросова, 10	f	large
2092	21273	1816	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Марии Якутовой, 1	f	medium
2084	21266	1808	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Ленина, 42А	f	large
2083	21265	1807	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Ленина, 19	f	large
2086	21268	1810	республика Башкортостан, Дюртюлинский район, поселок Дюртюли, Василия Горшкова, 12	f	large
2134	21313	1858	республика Башкортостан, Дюртюлинский район, село Гублюкучуково, Школьная, 7	f	small
2128	21307	1852	республика Башкортостан, Дюртюлинский район, село Байгильды, Интернациональная, 25	f	small
2099	21277	1823	республика Башкортостан, Дюртюлинский район, село Асяново, Ш.Бабича, 12	f	medium
2098	21277	1822	республика Башкортостан, Дюртюлинский район, село Асяново, Ш.Бабича, 12	f	medium
2096	21275	1820	Россия, республика Башкортостан, Дюртюлинский район, село Ангасяк	f	medium
2097	21276	1821	республика Башкортостан, Дюртюлинский район, село Ангасяк, Чиглинцева, 3	f	medium
2126	21305	1850	республика Башкортостан, Дюртюлинский район, село Аканеево, Интернациональная, 2	f	small
2074	21256	1798	республика Башкортостан, Дуванский район, село Ярославка, Советская, 179 А	f	small
2073	21255	1797	республика Башкортостан, Дуванский район, село Ярославка, Советская, 110	f	medium
2072	21254	1796	республика Башкортостан, Дуванский район, село Ярославка, Советская, 12/1	f	small
2066	21248	1790	республика Башкортостан, Дуванский район, село Чертан, Сушзаводская, 2 А	f	small
2061	21244	1785	республика Башкортостан, Дуванский район, село Улькунды, 60 лет Октября, 37	f	large
2070	21252	1794	республика Башкортостан, Дуванский район, село Тастуба, Площадь Ившина, 10	f	medium
2050	21233	1774	республика Башкортостан, Дуванский район, село Старохалилово, Центральная, 18	f	small
2057	21240	1781	республика Башкортостан, Дуванский район, село Сикияз, 2В, ДМ. Араловец	f	medium
2075	21257	1799	республика Башкортостан, Дуванский район, село Сальевка, Октябрьская, 6	f	medium
65713	21237	1778	республика Башкортостан, Дуванский район, село Рухтино, Мира, 47	f	\N
2067	21249	1791	республика Башкортостан, Дуванский район, село Октябрьский, Лесная, 5	f	small
2059	21242	1783	республика Башкортостан, Дуванский район, село Михайловка, Михайловская, 22 Б	f	medium
2060	21243	1784	республика Башкортостан, Дуванский район, село Митрофановка, Береговая, 1	f	small
2076	21258	1800	республика Башкортостан, Дуванский район, село Метели, Советская, 38	f	medium
2044	21226	1768	республика Башкортостан, Дуванский район, село Месягутово, Электрическая, 31	f	large
2042	21224	1766	республика Башкортостан, Дуванский район, село Месягутово, Электрическая, 29	f	medium
2041	21223	1765	республика Башкортостан, Дуванский район, село Месягутово, Революционная, 12	f	large
2049	21232	1773	республика Башкортостан, Дуванский район, село Месягутово, Промышленная, 20	f	small
2043	21225	1767	республика Башкортостан, Дуванский район, село Месягутово, Партизанская, 24	f	medium
2047	21230	1771	республика Башкортостан, Дуванский район, село Месягутово, Новая, 28	f	medium
2046	21228	1770	республика Башкортостан, Дуванский район, село Месягутово, Набережная, 14 В	f	medium
2048	21231	1772	республика Башкортостан, Дуванский район, село Месягутово, Магистральная, 12	f	small
2040	21222	1764	республика Башкортостан, Дуванский район, село Месягутово, Крупская, 1	f	small
2045	21227	1769	республика Башкортостан, Дуванский район, село Месягутово, Коммунистическая, 71	f	medium
2069	21251	1793	республика Башкортостан, Дуванский район, село Лемазы, Молодежная, 27	f	small
2053	21236	1777	республика Башкортостан, Дуванский район, село Каракулево, Речная, 4	f	small
2479	21647	2198	республика Башкортостан, Дуванский район, село Калмаш, Центральная, 22	f	small
2068	21250	1792	республика Башкортостан, Дуванский район, село Калмаш, Центральная, 3	f	small
65714	21239	1780	республика Башкортостан, Дуванский район, село Кадырово, Первомайская, 38	f	\N
2077	21259	1801	республика Башкортостан, Дуванский район, село Заимка, Советская, 18	f	small
65716	21245	1786	республика Башкортостан, Дуванский район, село Дуван, Ленина, 39	f	\N
2063	21246	1787	республика Башкортостан, Дуванский район, село Дуван, Гагарина, 51	f	medium
2071	21253	1795	республика Башкортостан, Дуванский район, село Вознесенка, Центральная, 101	f	medium
2052	21235	1776	республика Башкортостан, Дуванский район, село Ариево, Салавата Юлаева, 4	f	medium
2037	21219	1761	республика Башкортостан, Давлекановский район, село ЧуюнчиНиколаевка, Центральная, 2а	f	small
2036	21218	1760	республика Башкортостан, Давлекановский район, село Чуюнчи, Центральная, 19/2	f	small
2020	21200	1744	республика Башкортостан, Давлекановский район, село Хусаиново, Озерная, 6/2	f	small
2018	21198	1742	республика Башкортостан, Давлекановский район, село Ташлы-Шарипово, Озерная, 7/1	f	small
2035	21217	1759	республика Башкортостан, Давлекановский район, село Соколовка, Школьная, 14	f	small
2034	21215	1758	республика Башкортостан, Давлекановский район, село Сергиополь, Центральная, 1	f	medium
65711	21192	1736	республика Башкортостан, Давлекановский район, село Романовка, Молодежная, 13	f	\N
1823	21003	1547	республика Башкортостан, Давлекановский район, село Рассвет, Школьная, 5а	f	small
65712	21212	1755	республика Башкортостан, Давлекановский район, село Рассвет, Клубная, 1	f	\N
2030	21211	1754	республика Башкортостан, Давлекановский район, село Раево, Каримова, 5	f	small
2029	21210	1753	республика Башкортостан, Давлекановский район, село Поляковка, Поляковская, 3	f	small
2022	21202	1746	республика Башкортостан, Давлекановский район, село Новояппарово, Школьная, 18	f	small
2019	21199	1743	республика Башкортостан, Давлекановский район, село Новоянбеково, Мира, 57а	f	medium
2026	21207	1750	республика Башкортостан, Давлекановский район, село Новоаккулаево, Салавата, 34	f	small
2033	21214	1757	республика Башкортостан, Давлекановский район, село Ленинский, Полевая, 4	f	small
2010	21189	1734	республика Башкортостан, Давлекановский район, село Курятмасово, Салавата Юлаева, 45А	f	small
2032	21213	1756	республика Башкортостан, Давлекановский район, село Комсомольский, Школьная, 4а	f	medium
2023	21204	1747	республика Башкортостан, Давлекановский район, село Кидрячево, Школьная, 1/1	f	medium
2021	21201	1745	республика Башкортостан, Давлекановский район, село Казангулово, Демская, 27	f	small
2016	21196	1740	республика Башкортостан, Давлекановский район, село Имай-Кармалы, Советская, 1	f	small
2015	21195	1739	республика Башкортостан, Давлекановский район, село Ивановка, Механизаторская, 26	f	medium
2038	21220	1762	республика Башкортостан, Давлекановский район, село Ивангород, Крестьянская, 31/4	f	medium
2025	21206	1749	республика Башкортостан, Давлекановский район, село Дюртюли, Ярыштау, 1/1	f	small
3640	22783	3419	республика Башкортостан, Давлекановский район, село Дюртюли, Школьная, 27	f	small
65710	21185	1730	республика Башкортостан, Давлекановский район, Давлеканово, Первомайская, 9	f	\N
2008	21187	1732	республика Башкортостан, Давлекановский район, Давлеканово, Мира, 24а	f	large
2007	21186	1731	республика Башкортостан, Давлекановский район, Давлеканово, Мира, 14	f	large
1999	21178	1723	республика Башкортостан, Давлекановский район, Давлеканово, Красная Площадь, 11	f	large
2001	21180	1725	республика Башкортостан, Давлекановский район, Давлеканово, Заводская, 1а	f	large
3193	22418	2972	республика Башкортостан, Давлекановский район, село Вязовка, Центарльная, 48	f	small
2028	21209	1752	республика Башкортостан, Давлекановский район, село Вперед, Школьная, 13	f	large
2024	21205	1748	республика Башкортостан, Давлекановский район, село Бурангулово, Школьная, 41	f	small
2011	21190	1735	республика Башкортостан, Давлекановский район, село Алга, Центральная, 31А	f	small
65709	21173	1717	республика Башкортостан, Гафурийский район, село Янгискаин, Асфандиярова, 2	f	\N
1994	21173	1718	республика Башкортостан, Гафурийский район, село Янгискаин, Асфандиярова, 2	f	small
1057	20257	791	республика Башкортостан, Гафурийский район, село Якты-Куль, Молодежная, 6	f	small
1974	21154	1698	республика Башкортостан, Гафурийский район, село Явгильды, Школьная, 21	f	small
1983	21163	1707	республика Башкортостан, Гафурийский район, село Юлуково, Центральная, 77	f	medium
1981	21161	1705	республика Башкортостан, Гафурийский район, село Юзимяново, 30 лет Победы, 25	f	small
1991	21171	1715	республика Башкортостан, Гафурийский район, село Утяково, Чапаева, 2	f	small
116909	79815	128	Самарская область, Чапаевск, Жуковского, 35	f	medium
1976	21156	1700	республика Башкортостан, Гафурийский район, село Узбяково, Школьная, 10	f	medium
1992	21172	1716	республика Башкортостан, Гафурийский район, село Тугаево, Центральная, 2Б	f	small
1847	21027	1571	республика Башкортостан, Гафурийский район, село Тугаево, Центральная, 36	f	small
1898	21076	1622	республика Башкортостан, Гафурийский район, село Тугаево, Победы, 31	f	small
1988	21168	1712	республика Башкортостан, Гафурийский район, село Толпарово, Центральная, 11	f	small
1989	21169	1713	республика Башкортостан, Гафурийский район, село Ташла, Школьный переулок, 4	f	small
1969	21148	1693	республика Башкортостан, Гафурийский район, село Татарский Саскуль, Школьная, 2	f	small
1960	21124	1684	республика Башкортостан, Гафурийский район, село Табынское, Школьная, 6	f	medium
1961	21140	1685	республика Башкортостан, Гафурийский район, село Табынское, Центральная, 55	f	medium
1979	21159	1703	республика Башкортостан, Гафурийский район, село Саитбаба, Партизанская, 50	f	medium
1978	21158	1702	республика Башкортостан, Гафурийский район, село Саитбаба, Вахитова, 31	f	medium
1970	21149	1694	республика Башкортостан, Гафурийский район, село Русский Саскуль, Чапаева, 17	f	small
1959	21084	1683	республика Башкортостан, Гафурийский район, село Родина, Центральная, 4	f	medium
1995	21174	1719	республика Башкортостан, Гафурийский район, село Мраково, Партизанская, 6	f	medium
1990	21170	1714	республика Башкортостан, Гафурийский район, село Мендим, Центральная, 39	f	small
1965	21144	1689	республика Башкортостан, Гафурийский район, село Кутлугуза, Кооперативная, 26а	f	small
1957	21138	1681	республика Башкортостан, Гафурийский район, село Курорт, Ключевая, 12	f	large
1973	21152	1697	республика Башкортостан, Гафурийский район, село Курмантау, Школьная, 38	f	small
1986	21166	1710	республика Башкортостан, Гафурийский район, село Кургашла, Лесная, 3	f	small
1954	21135	1678	республика Башкортостан, Гафурийский район, поселок Красноусольский, Чкалова, 20	f	medium
1952	21133	1676	республика Башкортостан, Гафурийский район, поселок Красноусольский, Фрунзе, 40	f	large
65707	21139	1682	республика Башкортостан, Гафурийский район, поселок Красноусольский, Садовая, 25	f	\N
1953	21134	1677	республика Башкортостан, Гафурийский район, поселок Красноусольский, Ленина, 33	f	large
1956	21137	1680	республика Башкортостан, Гафурийский район, поселок Красноусольский, Коммунистическая, 45	f	large
1950	21131	1674	республика Башкортостан, Гафурийский район, поселок Красноусольский, Комарова, 13	f	medium
1951	21132	1675	республика Башкортостан, Гафурийский район, поселок Красноусольский, Калмыкова, 16/1	f	medium
1955	21136	1679	республика Башкортостан, Гафурийский район, поселок Красноусольский, К.Маркса, 72	f	medium
1982	21162	1706	республика Башкортостан, Гафурийский район, село Коварды, Заки Валиди, 32	f	medium
1985	21165	1709	республика Башкортостан, Гафурийский район, село Карагаево, Центральная, 52	f	medium
1964	21143	1688	республика Башкортостан, Гафурийский район, село Инзелга, Школьная, 24А	f	small
1984	21164	1708	республика Башкортостан, Гафурийский район, село Имендяшево, Колхозная, 47	f	small
1977	21157	1701	республика Башкортостан, Гафурийский район, село Ибрагимово, Бикташева, 2	f	small
1975	21155	1699	республика Башкортостан, Гафурийский район, село Зилим-Караново, М.Гафури, 17	f	small
1996	21175	1720	республика Башкортостан, Гафурийский район, село Буруновка, Молодежная, 10	f	small
1971	21150	1695	республика Башкортостан, Гафурийский район, село Бурлы, Казанская, 21	f	small
1963	21142	1687	республика Башкортостан, Гафурийский район, село Березовка, Школьная, 20	f	small
1706	20889	1432	республика Башкортостан, Гафурийский район, село Березовка, Советская, 6	f	small
2249	21428	1969	республика Башкортостан, Гафурийский район, село Березовка, Школьная, 12	f	small
65708	21145	1690	республика Башкортостан, Гафурийский район, село Белое Озеро, Элеваторная, 1/5	f	\N
1967	21146	1691	республика Башкортостан, Гафурийский район, село Белое Озеро, Школьная, 6	f	medium
1972	21151	1696	республика Башкортостан, Гафурийский район, село Баимбетово, Центральная, 9	f	small
1913	21092	1637	республика Башкортостан, Бураевский район, село Челкаково, Пинегина, 6	f	medium
1962	21141	1686	республика Башкортостан, Гафурийский район, село Архангельское, Центральная, 31	f	small
1133	20334	866	республика Башкортостан, Гафурийский район, село Архангельское, Н.Крупской, 3	f	large
1968	21147	1692	республика Башкортостан, Гафурийский район, село Антоновка, Школьная, 5	f	medium
65690	21104	1649	республика Башкортостан, Бурзянский район, село Яумбаево, Школьная, 1	f	\N
65706	21130	1673	республика Башкортостан, Бурзянский район, село Тимирово, Агидели, 9	f	\N
1938	21123	1667	республика Башкортостан, Бурзянский район, село Старосубхангулово, Школьная, 1	f	small
1939	21122	1666	республика Башкортостан, Бурзянский район, село Старосубхангулово, М.Гареева, 16	f	medium
1936	21129	1672	республика Башкортостан, Бурзянский район, село Старосубхангулово, Ленина, 74	f	large
1937	21125	1668	республика Башкортостан, Бурзянский район, село Старосубхангулово, Кызыл-Таш, 16	f	medium
1934	21128	1671	республика Башкортостан, Бурзянский район, село Старомусятово, Сакмагош, 28	f	small
1930	21121	1665	республика Башкортостан, Бурзянский район, село Старомунасипово, С.Юлаева, 5	f	small
65701	21117	1662	республика Башкортостан, Бурзянский район, село Саргая, Центральная, 7	f	\N
65685	21099	1644	республика Башкортостан, Бурзянский район, село Новоусманово, Шаймуратова, 1	f	\N
65705	21127	1670	республика Башкортостан, Бурзянский район, село Новосубхангулово, Школьная, 2	f	\N
1940	21126	1669	республика Башкортостан, Бурзянский район, село Новомусятово, З. Валиди, 15	f	small
65703	21119	1664	республика Башкортостан, Бурзянский район, село Новомунасипово, М.Сагитова, 30	f	\N
65702	21118	1663	республика Башкортостан, Бурзянский район, село Набиево, А.Сатвалова, 15	f	\N
65689	21103	1648	республика Башкортостан, Бурзянский район, село Мурадымово, Школьная, 5	f	\N
1683	20866	1409	республика Башкортостан, Бурзянский район, село Мурадымово, Мусы Гареева, 28	f	small
65696	21112	1657	республика Башкортостан, Бурзянский район, село Миндигулово, Агидели, 27	t	\N
65699	21115	1660	республика Башкортостан, Бурзянский район, село Малый Кипчак, Молодежная, 5	f	\N
1949	21109	1654	республика Башкортостан, Бурзянский район, село Максютово, Школьная, 23	t	small
65688	21102	1647	республика Башкортостан, Бурзянский район, село Магадеево, З.Валиди, 37	f	\N
65693	21108	1653	республика Башкортостан, Бурзянский район, село Кутаново, Туйбага, 4	t	\N
65687	21101	1646	республика Башкортостан, Бурзянский район, село Кургашлы, Школьная, 1	f	\N
65700	21116	1661	республика Башкортостан, Бурзянский район, село Кулганино, Ш.Шакмана, 6	f	\N
65698	21114	1659	республика Башкортостан, Бурзянский район, село Кильдигулово, Молодежная, 21	f	\N
65695	21111	1656	республика Башкортостан, Бурзянский район, село Киекбаево, Школьная, 11	f	\N
65682	21096	1641	республика Башкортостан, Бурзянский район, село Исламбаево, Сыбайялан, 4	t	\N
65692	21107	1652	республика Башкортостан, Бурзянский район, село Иргизлы, Заповедная, 6	t	\N
65691	21106	1651	республика Башкортостан, Бурзянский район, село Галиакберово, Центральная, 88	f	\N
65694	21110	1655	республика Башкортостан, Бурзянский район, село Гадельгареево, Шульган, 23а	f	\N
65681	21095	1640	республика Башкортостан, Бурзянский район, село Бретяк, Школьная, 3	t	\N
65686	21100	1645	республика Башкортостан, Бурзянский район, село Байназарово, Октября, 31	f	\N
65684	21098	1643	республика Башкортостан, Бурзянский район, село Байгазино, Горная, 2	f	\N
65683	21097	1642	республика Башкортостан, Бурзянский район, село Атиково, Дружбы, 1	f	\N
1024	20229	760	Россия, Оренбургская область, Кувандыкский район, село Аскарово	f	large
65680	21094	1639	республика Башкортостан, Бурзянский район, село Аскарово, Школьная, 5	f	\N
1021	20227	758	республика Башкортостан, Бурзянский район, село Аскарово, Р.Давлетова, 24	f	large
1019	20225	756	республика Башкортостан, Бурзянский район, село Аскарово, Ленина, 43	f	large
65697	21113	1658	республика Башкортостан, Бурзянский район, село Абдулмамбетово, С.Мухаметкулова, 21	f	\N
1870	21048	1594	республика Башкортостан, Бураевский район, село Шабаево, Султанова, 40	f	small
1906	21085	1630	республика Башкортостан, Бураевский район, село Чишма-Бураево, Ключевая, 30	f	small
71584	81024	1664	Самарская область, Тольятти, бульвар Ленина, 5	f	large
1907	21086	1631	республика Башкортостан, Бураевский район, село Тангатарово, Школьная, 22	f	small
1904	21082	1628	республика Башкортостан, Бураевский район, село Старотазларово, Лебединая, 25	f	small
1902	21080	1626	республика Башкортостан, Бураевский район, село Старокизганово, Пушкина, 6	f	small
1892	21070	1616	республика Башкортостан, Бураевский район, село Старокарагушево, Мира, 10	f	small
1878	21056	1602	республика Башкортостан, Бураевский район, село Старобикметово, Школьная, 3	f	small
1877	21055	1601	республика Башкортостан, Бураевский район, село Силасово, Школьная, 1	f	small
1909	21088	1633	республика Башкортостан, Бураевский район, село Саит-Курзя, Школьная, 2	f	small
1903	21081	1627	республика Башкортостан, Бураевский район, село Новотазларово, Школьная, 1	f	small
1873	21051	1597	республика Башкортостан, Бураевский район, село Новомустафино, Мира, 28	f	small
1901	21079	1625	республика Башкортостан, Бураевский район, село Новокизганово, г.Тукая, 27	f	small
1884	21062	1608	республика Башкортостан, Бураевский район, село Новоельдяково, Школьная, 55	f	small
1885	21063	1609	республика Башкортостан, Бураевский район, село Новобикметово, Школьная, 14	f	small
3276	22501	3055	республика Башкортостан, Бураевский район, село Николаевка, Школьная, 2	f	medium
109394	22364	2934	республика Башкортостан, Бураевский район, село Николаевка, Ушакова, 7	f	\N
65679	21052	1598	республика Башкортостан, Бураевский район, село Муллино, Горная, 1	f	\N
1880	21058	1604	республика Башкортостан, Бураевский район, село Минлино, Полевая, 13	f	small
1872	21050	1596	республика Башкортостан, Бураевский район, село Мамады, Школьная, 8	f	small
1896	21074	1620	республика Башкортостан, Бураевский район, село Кушманаково, Роберта Ахметгалиева, 57	f	small
1888	21066	1612	республика Башкортостан, Бураевский район, село Кулаево, Школьная, 22	f	small
1893	21071	1617	республика Башкортостан, Бураевский район, село Кузбаево, Школьная, 9	f	small
1897	21075	1621	республика Башкортостан, Бураевский район, село Кудашево, Малика Вахитова, 7	f	small
1889	21067	1613	республика Башкортостан, Бураевский район, село Кашкалево, Ахмета Закирова, 24	f	small
1905	21083	1629	республика Башкортостан, Бураевский район, село Касиярово, Школьная, 3	f	small
1900	21078	1624	республика Башкортостан, Бураевский район, село Каратамак, Солнечная, 32	f	small
1887	21065	1611	республика Башкортостан, Бураевский район, село Карабаево, Набережная, 8	f	small
1886	21064	1610	республика Башкортостан, Бураевский район, село Каинлыково, Молодежная, 12	f	small
1890	21068	1614	республика Башкортостан, Бураевский район, село Даутларово, Свободы, 18	f	small
1879	21057	1603	республика Башкортостан, Бураевский район, село Ваныш-Алпаутово, Молодежная, 7	f	small
1895	21073	1619	республика Башкортостан, Бураевский район, село Бустанаево, Школьная, 28	f	small
1862	21042	1586	республика Башкортостан, Бураевский район, село Бураево, Энергетиков, 6	f	medium
1869	21047	1593	республика Башкортостан, Бураевский район, село Бураево, Чкалова, 10	f	large
1864	14693	1588	республика Башкортостан, Бураевский район, село Бураево, Победы, 13	f	large
1865	21043	1589	республика Башкортостан, Бураевский район, село Бураево, Пионерская, 5	f	medium
1868	21046	1592	республика Башкортостан, Бураевский район, село Бураево, Магдана, 38/1	f	large
1867	21045	1591	республика Башкортостан, Бураевский район, село Бураево, М.Гафури, 41	f	medium
1863	20980	1587	республика Башкортостан, Бураевский район, село Бураево, Ленина, 16	f	large
1881	21059	1605	республика Башкортостан, Бураевский район, село Большешукшаново, Школьная, 39	f	small
1875	21053	1599	республика Башкортостан, Бураевский район, село Большебадраково, Ленина, 9	f	medium
1876	21054	1600	республика Башкортостан, Бураевский район, село Берлячево, Мира, 4	f	small
1348	20538	1078	республика Башкортостан, Бураевский район, село Бакалы, Шакирьянова, 2	f	large
1342	20532	1072	республика Башкортостан, Бураевский район, село Бакалы, Октябрьская, 94	f	large
1891	21069	1615	республика Башкортостан, Бураевский район, село Бакалы, Луговая, 4	f	small
1912	21091	1636	республика Башкортостан, Бураевский район, село Байшады, Гагарина, 1	f	small
71521	80977	1587	Самарская область, Тольятти, Татищева, 19	f	large
1911	21090	1635	республика Башкортостан, Бураевский район, село Арняшево, Мира, 24	f	small
1894	21072	1618	республика Башкортостан, Бураевский район, село Алтаево, Мира, 35	f	small
1871	21049	1595	республика Башкортостан, Бураевский район, село Азяково, Школьная, 31	f	small
1899	21077	1623	республика Башкортостан, Бураевский район, село Абзаево, Школьная, 14	f	small
1861	21041	1585	республика Башкортостан, Буздякский район, село отделение Сарайгирское Совхоза Уртакульский, Мира, 4а	f	small
1841	21021	1565	республика Башкортостан, Буздякский район, село Якупово, Центральная, 46/1	f	small
1812	20993	1537	республика Башкортостан, Буздякский район, село Юлдузлы, Центральная, 19/1	f	small
1811	20992	1536	республика Башкортостан, Буздякский район, село Шланлыкулево, Центральная, 61/1	f	small
1842	21022	1566	республика Башкортостан, Буздякский район, село Шарбаш, Центральная, 25/2	f	small
1845	21025	1569	республика Башкортостан, Буздякский район, село Чишма, Салавата, 35	f	small
1860	21040	1584	республика Башкортостан, Буздякский район, село Уртакульский, Школьная, 20	f	small
1813	20994	1538	республика Башкортостан, Буздякский район, село Урзайбаш, Мостовая, 32/1	f	medium
1837	21017	1561	республика Башкортостан, Буздякский район, село Ураново, 60 лет СССР, 6	f	medium
1850	21030	1574	республика Башкортостан, Буздякский район, село Тюрюшево, Революционная, 40а	f	medium
1825	21005	1549	республика Башкортостан, Буздякский район, село Ташлыкуль, Молодежная, 10	f	small
1828	21008	1552	республика Башкортостан, Буздякский район, село Таллыкулево, Центральная, 15	f	small
1848	21028	1572	республика Башкортостан, Буздякский район, село Старый Шигай, Центральная, 39	f	small
1858	21038	1582	республика Башкортостан, Буздякский район, село Старый Буздяк, Школьная, 2а	f	small
1810	20991	1535	республика Башкортостан, Буздякский район, село Староый Богады, Казанская, 4/1	f	small
1855	21035	1579	республика Башкортостан, Буздякский район, село Старотавларово, Центральная, 21	f	medium
1836	21016	1560	республика Башкортостан, Буздякский район, село Староактау, Коммунистическая, 13а	f	small
1818	20998	1542	республика Башкортостан, Буздякский район, село Сергеевка, Центральная, 4	f	small
1853	21033	1577	республика Башкортостан, Буздякский район, село Севадыбашево, Советская, 19а	f	small
1835	21015	1559	республика Башкортостан, Буздякский район, село Сабанаево, Школьная, 33	f	small
1846	21026	1570	республика Башкортостан, Буздякский район, село Сабаево, Мира, 41	f	medium
1834	21014	1558	республика Башкортостан, Буздякский район, село Новоактау, Идяш, 22	f	small
1826	21006	1550	республика Башкортостан, Буздякский район, село Никольское, Школьная, 11	f	small
1854	21034	1578	республика Башкортостан, Буздякский район, село Нижняя Чатра, Школьная, 21а	f	small
1851	21031	1575	республика Башкортостан, Буздякский район, село Кызыл-Яр, Мажита Гафури, 80	f	small
1829	21009	1553	республика Башкортостан, Буздякский район, село Кузьминка, Центральная, 10	f	small
1843	21023	1567	республика Башкортостан, Буздякский район, село Кузеево, Ленина, 37	f	small
1832	21012	1556	республика Башкортостан, Буздякский район, село Копей-Кубово, Ленина, 88	f	medium
1840	21020	1564	республика Башкортостан, Буздякский район, село Килимово, Буденного, 51/1	f	medium
1856	21036	1580	республика Башкортостан, Буздякский район, село Картамак, Центральная, 55	f	small
1852	21032	1576	республика Башкортостан, Буздякский район, село Каразирек, Матросова, 32а	f	small
1827	21007	1551	республика Башкортостан, Буздякский район, село Канлы-Туркеево, Школьная, 2	f	medium
65678	21011	1555	республика Башкортостан, Буздякский район, село Казаклар-Кубово, Горная, 1	f	\N
65677	21010	1554	республика Башкортостан, Буздякский район, село Казаклар-Кубово, Горная, 3	f	\N
1849	21029	1573	республика Башкортостан, Буздякский район, село Идяшбаш, Лесная, 3	f	small
1821	21001	1545	республика Башкортостан, Буздякский район, село Гафури, Школьная, 5в	f	small
1815	20995	1539	республика Башкортостан, Буздякский район, село Буздяк, Рабочая, 31	f	large
1816	20996	1540	республика Башкортостан, Буздякский район, село Буздяк, Красная площадь, 28	f	large
1817	20997	1541	республика Башкортостан, Буздякский район, село Буздяк, Кирова, 25а	f	large
1833	21013	1557	республика Башкортостан, Буздякский район, село Большая Устюба, Колхозная, 2/2	f	small
1809	20990	1534	республика Башкортостан, Буздякский район, село Арасланово, Центральная, 78/4	f	small
1792	20972	1517	республика Башкортостан, Благовещенский район, село Эманино, Речная, 40	f	small
134609	94454	1508	республика Башкортостан, Благовещенский район, село Удельно-Дуваней, Зырянова, 21	f	\N
1804	20985	1529	республика Башкортостан, Благовещенский район, село Турушла, Школьная, 4/1	f	small
1803	20984	1528	республика Башкортостан, Благовещенский район, село Трошкино, Горная, 1	f	small
1796	20976	1521	республика Башкортостан, Благовещенский район, село Старонадеждино, Молодежная, 5 А	f	small
1788	20968	1513	республика Башкортостан, Благовещенский район, село Староиликово, Советская, 73	f	small
3715	22938	3495	республика Башкортостан, Благовещенский район, село Петровка, Первомайская, 31	t	small
1790	20970	1515	республика Башкортостан, Благовещенский район, село Осиповка, Лесная, 1	f	small
1784	20964	1509	республика Башкортостан, Благовещенский район, село Орловка, Школьная, 2	f	small
1802	20983	1527	республика Башкортостан, Благовещенский район, село Новонадеждино, Советская, 6	f	medium
1807	20988	1532	республика Башкортостан, Благовещенский район, село Нижний Изяк, Школьная, 2	f	small
65676	20971	1516	республика Башкортостан, Благовещенский район, село Карагайкуль, Нижняя, 23	f	\N
1805	20986	1530	республика Башкортостан, Благовещенский район, село Ильино-Поляна, Советская, 9 А	f	large
134610	94455	1514	республика Башкортостан, Благовещенский район, село Ежовка, Петропавловка, 12	f	\N
2926	21942	2644	республика Башкортостан, Благовещенский район, село Гумерово, Садовая, 13	f	small
1799	20979	1524	республика Башкортостан, Благовещенский район, село Волково, Молодежная, 1 Б	f	small
1806	20987	1531	республика Башкортостан, Благовещенский район, село Верхний Изяк, Школьная, 16	f	medium
1785	20965	1510	республика Башкортостан, Благовещенский район, село Богородское, Осиновка, 15	f	small
65672	20958	1501	республика Башкортостан, Благовещенский район, Благовещенск, Комарова, 2	f	\N
1761	20944	1487	республика Башкортостан, Благовещенский район, Благовещенск, Кирова, 81	f	large
65671	20956	1499	республика Башкортостан, Благовещенский район, Благовещенск, Братьев Першиных, 4	f	\N
1768	20950	1493	республика Башкортостан, Благовещенский район, Благовещенск, Баранова, 5	f	large
1787	20967	1512	республика Башкортостан, Благовещенский район, село Биштиново, Партизанская, 1	f	small
1793	20973	1518	республика Башкортостан, Благовещенский район, село Бедеева-Поляна, Чернышевского, 18	f	large
1797	20977	1522	республика Башкортостан, Благовещенский район, село Ахлыстино, Шоссейная, 15	f	small
1795	20975	1520	республика Башкортостан, Благовещенский район, село Александровка, Интернациональная, 13	f	small
1759	20942	1485	республика Башкортостан, Благоварский район, село Янышево, Базарная, 20б	f	small
1758	20941	1484	республика Башкортостан, Благоварский район, село Ямакай, Цветочная, 29	f	small
1801	20982	1526	республика Башкортостан, Благоварский район, село Языково, Пушкина, 74	f	small
1756	20939	1482	республика Башкортостан, Благоварский район, село Языково, Пушкина, 25	f	large
1755	20938	1481	республика Башкортостан, Благоварский район, село Языково, Пушкина, 22	f	large
1757	20940	1483	республика Башкортостан, Благоварский район, село Языково, Ленина, 16	f	large
1754	20937	1480	республика Башкортостан, Благоварский район, село Языково, Ленина, 18	f	large
1980	21160	1704	республика Башкортостан, Благоварский район, село Усманово, Центральная, 12	f	small
1752	20935	1478	республика Башкортостан, Благоварский район, село Удрякбаш, Центральная, 24	f	medium
1750	20933	1476	республика Башкортостан, Благоварский район, село Троицкий 1-й, Центральная, 54	f	small
1747	20930	1473	республика Башкортостан, Благоварский район, село Тан, Коммуны, 3	f	medium
1748	20931	1474	республика Башкортостан, Благоварский район, село Такчура, Такчуринская, 76/а	f	small
1746	20929	1472	республика Башкортостан, Благоварский район, село Сынташтамак, Школьная, 2	f	small
78643	7863	924	Ульяновская область, Ульяновск, проспект Хо Ши Мина, 30	f	large
1745	20928	1471	республика Башкортостан, Благоварский район, село Старые Санны, Совхозная, 1	f	small
1737	20920	1463	республика Башкортостан, Благоварский район, село Старокучербаево, Центральная, 1	f	medium
1739	20922	1465	республика Башкортостан, Благоварский район, село Староабзаново, Киндеркульская, 39	f	small
1728	20911	1454	республика Башкортостан, Благоварский район, село Сарайлы, А.Галиева, 6	f	medium
1727	20910	1453	республика Башкортостан, Благоварский район, село Пришиб, Ленина, 38	f	large
1744	20927	1470	республика Башкортостан, Благоварский район, село Первомайский, Ленина, 7	f	medium
2265	21436	1985	республика Башкортостан, Благоварский район, село Новоалександровка, Клубная, 19	f	small
1735	20918	1461	республика Башкортостан, Благоварский район, село Нижнии Каргалы, Центральная, 21	f	small
1740	20923	1466	республика Башкортостан, Благоварский район, село Ломово, Центральная, 39	f	small
1753	20936	1479	республика Башкортостан, Благоварский район, село Куллекул, Центральная, 3	f	small
1741	20924	1467	республика Башкортостан, Благоварский район, село Коб-Покровка, Центральная, 42	f	medium
1736	20919	1462	республика Башкортостан, Благоварский район, село Кашкалаши, Советская, 54	f	small
1732	20915	1458	республика Башкортостан, Благоварский район, село Западное Отделение Совхоза Благоварский, Школьная, 5	f	small
1729	20912	1455	республика Башкортостан, Благоварский район, село Благовар, Совхозная, 1	f	large
1738	20921	1464	республика Башкортостан, Благоварский район, село Ахметово, Центральная, 29	f	small
1733	20916	1459	республика Башкортостан, Благоварский район, село Алкино 6-е, Речная, 29	f	small
1749	20932	1475	республика Башкортостан, Благоварский район, село Агарды, Школьная, 1	f	small
1715	20898	1441	республика Башкортостан, Бирский район, село Шелканово, Радужная, 14	f	small
1724	20907	1450	республика Башкортостан, Бирский район, село Угузево, Коммунистическая, 18б	f	small
1722	20905	1448	республика Башкортостан, Бирский район, село Суслово, Антипина, 2а	f	medium
1708	20891	1434	республика Башкортостан, Бирский район, село Старобурново, Школьная, 6-а	f	medium
1719	20902	1445	республика Башкортостан, Бирский район, село Старобазаново, Комарова, 3	f	medium
1718	20901	1444	республика Башкортостан, Бирский район, село Силантьево, Восточная, 19	f	medium
1700	20883	1426	республика Башкортостан, Бирский район, село Пономаревка, Гагарина, 11	f	large
1720	20903	1446	республика Башкортостан, Бирский район, село Питяково, Мира, 31а	f	medium
1707	20890	1433	республика Башкортостан, Бирский район, село Печенкино, Советская, 12	f	small
1716	20899	1442	республика Башкортостан, Бирский район, село Осиновка, Овчинникова, 8	f	medium
1705	20888	1431	республика Башкортостан, Бирский район, село Новоянтузово, Ленина, 14	f	small
1703	20886	1429	республика Башкортостан, Бирский район, село Новокульчубаево, Красноармейская, 19	f	small
1709	20892	1435	республика Башкортостан, Бирский район, село Николаевка, Октябрьская, 33	f	small
1714	20897	1440	республика Башкортостан, Бирский район, село Маядыково, Свердлова, 10	f	small
1723	20906	1449	республика Башкортостан, Бирский район, село Малосухоязово, Школьная, 8	f	small
1712	20895	1438	республика Башкортостан, Бирский район, село Кусекеево, Новосктройки, 8	f	small
1726	20909	1452	республика Башкортостан, Бирский район, село Кузово, Ленина, 46	f	small
1711	20894	1437	республика Башкортостан, Бирский район, село Кандаковка, Школьная, 7	f	small
1710	20893	1436	республика Башкортостан, Бирский район, село Калинники, Калинина, 23а	f	large
1717	20900	1443	республика Башкортостан, Бирский район, село Емашево, Антипина, 28	f	small
1704	20887	1430	республика Башкортостан, Бирский район, село Верхнелачентау, Тукая, 15	f	small
1686	20869	1412	республика Башкортостан, Бирский район, Бирск, Чеверева, 143	f	large
1688	20871	1414	республика Башкортостан, Бирский район, Бирск, Пролетарская, 140	f	large
1687	20870	1413	республика Башкортостан, Бирский район, Бирск, Овчинникова, 48	f	large
1697	20880	1423	республика Башкортостан, Бирский район, Бирск, Мира, 124а	f	large
1721	20904	1447	республика Башкортостан, Бирский район, село Бекмурзино, Молодежная, 2	f	small
71520	80977	1586	Самарская область, Тольятти, Татищева, 19	f	large
1702	20885	1428	республика Башкортостан, Бирский район, село Бахтыбаево, Памфилова, 19	f	medium
1701	20884	1427	республика Башкортостан, Бирский район, село Баженово, Мира, 30	f	medium
3729	22952	3509	республика Башкортостан, Бирский район, село Андреевка, Школьная, 18	f	small
1713	20896	1439	республика Башкортостан, Бирский район, село Акудибашево, Школьная, 5	f	small
1662	20845	1388	республика Башкортостан, Бижбулякский район, село Хомутовка, Центральная, 11	f	small
1681	20864	1407	республика Башкортостан, Бижбулякский район, село Сухоречка, Центральная, 33	f	medium
65668	20838	1378	республика Башкортостан, Бижбулякский район, село Седякбаш, Центральная, 51	f	\N
1657	20840	1383	республика Башкортостан, Бижбулякский район, село Ольховка, Молодежная, 1	f	small
65670	20860	1403	республика Башкортостан, Бижбулякский район, село Михайловка, Девонская, 9	f	\N
1676	20859	1402	республика Башкортостан, Бижбулякский район, село Менеуз-Москва, Центральная, 27А	f	small
1667	20850	1393	республика Башкортостан, Бижбулякский район, село Малый Седяк, переулок Школьный, 8	f	small
1678	20861	1404	республика Башкортостан, Бижбулякский район, село Малый Менеуз, Шоссейная, 1А	f	small
1668	20851	1394	республика Башкортостан, Бижбулякский район, село Лысогорка, Центральная, 31	f	small
1673	20856	1399	республика Башкортостан, Бижбулякский район, село Кунакулово, Центральная, 91А	f	medium
1674	20857	1400	республика Башкортостан, Бижбулякский район, село Кош-Елга, МТМ, 8	f	medium
1643	20829	1369	республика Башкортостан, Бижбулякский район, село Кистенли-Богданово, Школьная, 25	f	small
1672	20855	1398	республика Башкортостан, Бижбулякский район, село Кенгер-Менеуз, Центральная, 62	f	large
1665	20848	1391	республика Башкортостан, Бижбулякский район, село Качкиново, Салавата Юлаева, 7А	f	small
1640	20826	1366	республика Башкортостан, Бижбулякский район, село Каримово, Подлесная, 5	f	small
1656	20768	1382	республика Башкортостан, Бижбулякский район, село Каныкаево, Коммунистическая, 6	f	small
65825	21629	2180	республика Башкортостан, Бижбулякский район, село Исякаево, Речная, 40а	f	\N
1684	20867	1410	республика Башкортостан, Бижбулякский район, село Исякаево, Мусы Джалиля, 41	f	small
1666	20849	1392	республика Башкортостан, Бижбулякский район, село Зириклы, Центральная, 55	f	small
1664	20847	1390	республика Башкортостан, Бижбулякский район, село Елбулактамак, Центральная, 2Б	f	medium
65667	20837	1377	республика Башкортостан, Бижбулякский район, село Елбулак-Матвеевка, Чкалова, 28	f	\N
1642	20828	1368	республика Башкортостан, Бижбулякский район, село Егоровка, Центральная, 28	f	small
1655	20738	1381	республика Башкортостан, Бижбулякский район, село Дюсяново, Центральная, 11	f	small
1658	20841	1384	республика Башкортостан, Бижбулякский район, село Демский, Центральная, 15	f	medium
1653	20839	1379	республика Башкортостан, Бижбулякский район, село Верхняя Курмаза, Центральная, 32	f	small
1663	20846	1389	республика Башкортостан, Бижбулякский район, село Боголюбовка, Садовая, 33	f	small
65665	20834	1374	республика Башкортостан, Бижбулякский район, село Бижбуляк, Трудовая, 13	f	\N
1647	20833	1373	республика Башкортостан, Бижбулякский район, село Бижбуляк, Спортивная, 2	f	medium
1646	20832	1372	республика Башкортостан, Бижбулякский район, село Бижбуляк, Пушкина, 20	f	medium
1641	20827	1367	республика Башкортостан, Бижбулякский район, село Базлык, Центральная, 168А	f	medium
1638	20824	1364	республика Башкортостан, Бижбулякский район, село Аитово, Фатиха Карима, 43	f	medium
1659	20842	1385	республика Башкортостан, Бижбулякский район, село Азнаево, Центральная, 39	f	small
1614	20819	1359	республика Башкортостан, Белорецкий район, село Шигаево, Школьная, 18	f	small
1617	20822	1362	республика Башкортостан, Белорецкий район, село Хусаиново, Молодежная, 16	f	small
1616	20821	1361	республика Башкортостан, Белорецкий район, село Уткалево, Школьная, 15	f	small
1615	20820	1360	республика Башкортостан, Белорецкий район, село Узянбаш, Янгиреева, 29	f	small
1608	20816	1356	республика Башкортостан, Белорецкий район, село Узян, Портнова, 2	f	small
1609	20817	1357	республика Башкортостан, Белорецкий район, село Узян, Победы, 2	f	medium
1604	20814	1354	республика Башкортостан, Белорецкий район, поселок Тукан, Матросова, 14	f	medium
1605	20815	1355	республика Башкортостан, Белорецкий район, поселок Тукан, Горького, 17	f	medium
1625	20812	1352	республика Башкортостан, Белорецкий район, поселок Тирлянский, проезд Дзержинского, 7	f	medium
1624	20811	1351	республика Башкортостан, Белорецкий район, поселок Тирлянский, Советская, 181	f	medium
1622	20809	1349	республика Башкортостан, Белорецкий район, поселок Тирлянский, Первомайская, 73	f	medium
1626	20813	1353	республика Башкортостан, Белорецкий район, поселок Тирлянский, Коммунистическая, 115	f	medium
1611	20807	1347	республика Башкортостан, Белорецкий район, село Сосновка, Центральная, 3	f	medium
1585	20806	1346	республика Башкортостан, Белорецкий район, село Серменево, Ленина, 25А	f	large
1613	20808	1348	республика Башкортостан, Белорецкий район, село Рысакаево, Школьная, 10	f	small
1636	20804	1344	республика Башкортостан, Белорецкий район, село Отнурок, Школьная, 26	f	small
1595	20795	1335	республика Башкортостан, Белорецкий район, село Нукатово, Горная, 20	f	small
1618	20823	1363	республика Башкортостан, Белорецкий район, село Новобельское, Бельская, 2	f	small
1621	20767	1308	республика Башкортостан, Белорецкий район, село Новоабзаково, Вокзальная, 9/1	f	small
1628	20801	1341	республика Башкортостан, Белорецкий район, село Николаевка, Центральная, 8	f	small
1620	20766	1307	республика Башкортостан, Белорецкий район, село Мухаметово, Школьная, 11	f	small
1580	20776	1316	республика Башкортостан, Белорецкий район, село Мулдакаево, Центральная, 57	f	small
718	19945	455	республика Башкортостан, Белорецкий район, Межгорье, Советская, 25	f	large
717	19944	454	республика Башкортостан, Белорецкий район, Межгорье, 40 лет Победы, 3	f	large
65663	20800	1340	республика Башкортостан, Белорецкий район, село Махмутово, Иремель, 6	f	\N
1637	20799	1339	республика Башкортостан, Белорецкий район, поселок Ломовка, Ленина, 34	f	large
1633	20771	1311	республика Башкортостан, Белорецкий район, село Кузгун-Ахмерово, Центральная, 16/2	f	small
1610	20818	1358	республика Башкортостан, Белорецкий район, село Кагарманово, Юлаева, 20А	f	small
65662	20798	1338	республика Башкортостан, Белорецкий район, село Кага, Ленина, 45	f	\N
1606	20796	1336	республика Башкортостан, Белорецкий район, село Ишля, Советская, 23	f	small
1602	20780	1320	республика Башкортостан, Белорецкий район, село Исмакаево, Советская, 35	f	small
1581	20777	1317	республика Башкортостан, Белорецкий район, село Искушта, Клубная, 27А	f	small
65661	20788	1328	республика Башкортостан, Белорецкий район, поселок Инзер, Энергетиков, 31а	f	\N
65660	20787	1327	республика Башкортостан, Белорецкий район, поселок Инзер, Энергетиков, 16А	f	\N
1590	20790	1330	республика Башкортостан, Белорецкий район, поселок Инзер, Школьная, 6	f	small
1591	20791	1331	республика Башкортостан, Белорецкий район, поселок Инзер, Октябрьская, 4А	f	medium
1582	20784	1324	республика Башкортостан, Белорецкий район, село Зуяково, Мубарякова, 37	f	medium
1597	20783	1323	республика Башкортостан, Белорецкий район, село Зигаза, Школьная, 6	f	small
1596	20782	1322	республика Башкортостан, Белорецкий район, село Зигаза, Октябрьская, 29	f	small
1583	20785	1325	республика Башкортостан, Белорецкий район, село Габдюково, Школьная, 2А	f	small
65659	20779	1319	республика Башкортостан, Белорецкий район, поселок Верхний Авзян, Загорская, 2	f	\N
65658	20778	1318	республика Башкортостан, Белорецкий район, поселок Верхний Авзян, Блюхера, 70	f	\N
1630	20803	1343	республика Башкортостан, Белорецкий район, село Верхнебельский, Школьная, 1	f	small
1629	20802	1342	республика Башкортостан, Белорецкий район, село Верхнеаршинский, переулок Школьный, 5	f	small
1634	20772	1312	Россия, республика Башкортостан, Белорецкий район, село Буганак	f	medium
1578	20774	1314	республика Башкортостан, Белорецкий район, село Бриштамак, Горная, 10	f	small
1579	20775	1315	республика Башкортостан, Белорецкий район, село Бриш, Центральная, 28/1	f	small
1592	20792	1332	республика Башкортостан, Белорецкий район, село Бердагулово, Школьная, 24	f	small
2906	22075	2624	республика Башкортостан, Белорецкий район, село Бельский, Школьная, 8	f	small
2602	21769	2321	республика Башкортостан, Белорецкий район, село Бельский, Центральная, 24	f	small
1558	20747	1288	Россия, республика Башкортостан, Белорецкий район, Белорецк	f	medium
65657	20760	1301	республика Башкортостан, Белорецкий район, Белорецк, Тюленина, 40	f	\N
1555	20744	1285	республика Башкортостан, Белорецкий район, Белорецк, Точисского, 16	f	large
65656	20746	1287	республика Башкортостан, Белорецкий район, Белорецк, Пушкина, 67А	f	\N
1568	20757	1298	республика Башкортостан, Белорецкий район, Белорецк, Металлургическая, 24	f	large
1563	20752	1293	республика Башкортостан, Белорецкий район, Белорецк, Маркса, 85	f	medium
1564	20753	1294	республика Башкортостан, Белорецкий район, Белорецк, Ленина, 131	f	large
1553	20742	1283	республика Башкортостан, Белорецкий район, Белорецк, Косоротова, 10А	f	large
1556	20745	1286	республика Башкортостан, Белорецкий район, Белорецк, 50 лет Октября, 68	f	large
1548	20736	1278	республика Башкортостан, Белорецкий район, Белорецк, 50 лет Октября, 48	f	large
1546	20734	1276	республика Башкортостан, Белорецкий район, Белорецк, 50 лет Октября, 74	f	large
1551	20740	1281	республика Башкортостан, Белорецкий район, Белорецк, 50 Лет Октября, 62	f	small
1577	20773	1313	республика Башкортостан, Белорецкий район, село Ассы, Мубарякова, 25/1	f	medium
1632	20770	1310	республика Башкортостан, Белорецкий район, село Азналкино, Победы, 13/1	f	small
65664	20805	1345	республика Башкортостан, Белорецкий район, село Азнагулово, Агидель, 28 А	f	\N
1631	20769	1309	республика Башкортостан, Белорецкий район, село Азикеево, Советская, 4	f	small
1523	20710	1253	республика Башкортостан, Белокатайский район, село Яныбаево, Центральная, 10	f	medium
1530	20718	1260	республика Башкортостан, Белокатайский район, село Шакарла, Советская, 15	f	small
1332	20522	1062	республика Башкортостан, Белокатайский район, село Ургала, Х.Давлетшиной, 9	f	large
1534	20722	1264	республика Башкортостан, Белокатайский район, село Ургала, Ленина, 93	f	large
1536	20724	1266	республика Башкортостан, Белокатайский район, село Ураковская Ферма Совхоза, Мира, 26	f	small
1529	20717	1259	республика Башкортостан, Белокатайский район, село Старобелокатай, Советская, 71	f	medium
1525	20713	1255	республика Башкортостан, Белокатайский район, село Соколки, Клубная, 14	f	small
1518	20705	1248	республика Башкортостан, Белокатайский район, село Ногуши, Крупской, 19	f	medium
1526	20714	1256	республика Башкортостан, Белокатайский район, село Новобелокатай, Школьный переулок, 7	f	large
1527	20715	1257	республика Башкортостан, Белокатайский район, село Новобелокатай, Советская, 124	f	large
1528	20716	1258	республика Башкортостан, Белокатайский район, село Новобелокатай, Молодежная, 10	f	large
1531	20719	1261	республика Башкортостан, Белокатайский район, село Нижнеутяшево, Победы, 10	f	small
1541	20729	1271	республика Башкортостан, Белокатайский район, село Медятовская Ферма, Совхозная, 13	f	small
1539	20727	1269	республика Башкортостан, Белокатайский район, село Майгаза, Мира, 12	f	medium
1544	20732	1274	республика Башкортостан, Белокатайский район, село Кирикеево, Мусы Гареева, 2	f	small
1519	20706	1249	республика Башкортостан, Белокатайский район, село Карлыханово, Советская, 100	f	large
1533	20721	1263	республика Башкортостан, Белокатайский район, село Карантрав, Школьный переулок, 3	f	small
1538	20726	1268	республика Башкортостан, Белокатайский район, село Кадырово, Мира, 18	f	small
1517	20704	1247	республика Башкортостан, Белокатайский район, село Емаши, Кирова, 2	f	medium
1543	20731	1273	республика Башкортостан, Белокатайский район, село Белянка, Гагарина, 1А	f	medium
1542	20730	1272	республика Башкортостан, Белокатайский район, село Ашаево, Школьный переулок, 1	f	small
1532	20720	1262	республика Башкортостан, Белокатайский район, село Апутово, Салавата Юлаева, 40	f	small
1520	20707	1250	республика Башкортостан, Белокатайский район, село Айдакаево, Салавата Юлаева, 42	f	small
1524	20711	1254	республика Башкортостан, Белокатайский район, село Айгырьял, Мечетлинская, 33	f	small
1535	20723	1265	республика Башкортостан, Белокатайский район, село Абсалямово, Шаймуратова, 31	f	small
1392	20581	1122	республика Башкортостан, Бакалинский район, село Урманаево, Центральная, 1А	f	small
1500	20688	1230	республика Башкортостан, Белебеевский район, село совхоза Имени М. Горького, Садовая, 3	f	large
1515	20702	1245	республика Башкортостан, Белебеевский район, село Шаровка, Школьная, 1	f	small
1513	20700	1243	республика Башкортостан, Белебеевский район, село Усень-Ивановское, Комсомольская, 72	f	medium
65654	20699	1242	республика Башкортостан, Белебеевский район, село Тузлукуш, Чапаева, 58	f	\N
1509	20696	1239	республика Башкортостан, Белебеевский район, село Старосеменкино, Дружбы, 14	f	small
1511	20698	1241	республика Башкортостан, Белебеевский район, село Слакбаш, К.Иванова, 58	f	medium
1508	20695	1238	республика Башкортостан, Белебеевский район, село Рассвет, Лесная, 19	f	small
1510	20697	1240	республика Башкортостан, Белебеевский район, село Новосеменкино, Пушкина, 14	f	small
1499	20687	1229	республика Башкортостан, Белебеевский район, село Новосараево, Овражная, 8	f	small
1487	20675	1217	республика Башкортостан, Белебеевский район, село Надеждино, Интернациональная, 2	f	small
1505	20693	1235	республика Башкортостан, Белебеевский район, село Метевбаш, Школьная, 62а	f	medium
716	19943	453	республика Башкортостан, Белебеевский район, село Междугорное, 40 лет Победы, 58	f	large
1497	20685	1227	республика Башкортостан, Белебеевский район, село Малоалександровка, Центральная, 20	f	small
1503	20691	1233	республика Башкортостан, Белебеевский район, село Малиновка, Школьная, 4	f	medium
1491	20679	1221	республика Башкортостан, Белебеевский район, село Илькино, Центральная, 9	f	small
2823	21991	2539	республика Башкортостан, Белебеевский район, село Знаменка, Зеленая, 16	f	small
1498	20686	1228	республика Башкортостан, Белебеевский район, село Знаменка, Заводская, 20	f	large
1670	20853	1396	республика Башкортостан, Белебеевский район, село Ермолкино, Центральная, 2А	f	small
1496	20684	1226	республика Башкортостан, Белебеевский район, село Ермолкино, Ленина, 1	f	small
1514	20701	1244	республика Башкортостан, Белебеевский район, село Веровка, Веровка, 31/1	f	small
1455	20643	1185	республика Башкортостан, Белебеевский район, Белебей, Чапаева, 73	f	large
1470	20658	1200	республика Башкортостан, Белебеевский район, Белебей, Тукаева, 77	f	large
1451	20639	1181	республика Башкортостан, Белебеевский район, Белебей, Советская, 11	f	medium
1453	20641	1183	республика Башкортостан, Белебеевский район, Белебей, Пролетарская, 41а	f	large
1469	20657	1199	республика Башкортостан, Белебеевский район, Белебей, Ленина, 1	f	large
1468	20656	1198	республика Башкортостан, Белебеевский район, Белебей, Ленина, 9	f	large
1450	20638	1180	республика Башкортостан, Белебеевский район, Белебей, Красноармейская, 77	f	large
1459	20647	1189	республика Башкортостан, Белебеевский район, Белебей, Красная, 111	f	large
1452	20640	1182	республика Башкортостан, Белебеевский район, Белебей, Коммунистическая, 13в	f	large
1462	20650	1192	республика Башкортостан, Белебеевский район, Белебей, Волгоградская, 10	f	large
1465	20653	1195	республика Башкортостан, Белебеевский район, Белебей, Амирова, 10а	f	large
1464	20652	1194	республика Башкортостан, Белебеевский район, Белебей, Амирова, 6	f	large
1495	20683	1225	республика Башкортостан, Белебеевский район, село Баймурзино, Мира, 33	f	small
1492	20680	1222	республика Башкортостан, Белебеевский район, село Баженово, Административная, 5	f	large
1490	20678	1220	республика Башкортостан, Белебеевский район, село Анновка, Советская, 15	f	small
1507	20694	1237	республика Башкортостан, Белебеевский район, село Алексеевка, Школьная, 15	f	small
1506	20694	1236	республика Башкортостан, Белебеевский район, село Алексеевка, Школьная, 15	f	small
1488	20676	1218	республика Башкортостан, Белебеевский район, поселок Аксаково, Первомайская, 2	f	large
1494	20682	1224	республика Башкортостан, Белебеевский район, село Аделькино, Центральная, 54	f	small
1407	20596	1137	республика Башкортостан, Балтачевский район, село Янтимирово, Центральная, 43	f	small
1446	20635	1176	республика Башкортостан, Балтачевский район, село Штанды, Центральная, 8	f	medium
1442	20631	1172	республика Башкортостан, Балтачевский район, село Шавьяды, Центральная, 49/1	f	small
78485	7778	755	Ульяновская область, Ульяновск, улица Варейкиса, 17	f	large
1410	20599	1140	республика Башкортостан, Балтачевский район, село Чуртанлыкуль, Центральная, 8	f	small
1432	20621	1162	республика Башкортостан, Балтачевский район, село Чукалы, Центральная, 9	f	small
1725	20908	1451	республика Башкортостан, Балтачевский район, село Чишма, Советская, 4	f	small
1420	20609	1150	республика Башкортостан, Балтачевский район, село Усманово, Центральная, 16	f	small
1440	20629	1170	республика Башкортостан, Балтачевский район, село Тучубаево, Школьная, 13	f	small
1415	20604	1145	республика Башкортостан, Балтачевский район, село Тутагачево, Центральная, 31, УИК: д.Тутагачево, Центральная, 29	f	small
1427	20616	1157	республика Башкортостан, Балтачевский район, село Туктаево, Центральная, 2	f	small
65652	20595	1136	республика Башкортостан, Балтачевский район, село Тузлубино, Мира, 17	f	\N
1443	20632	1173	республика Башкортостан, Балтачевский район, село Тибелеево, Центральная, 35	f	small
1429	20618	1159	республика Башкортостан, Балтачевский район, село Староянбаево, Ленина, 42	f	small
1434	20623	1164	республика Башкортостан, Балтачевский район, село Староямурзино, Центральная, 30	f	small
1425	20614	1155	республика Башкортостан, Балтачевский район, село Староякшеево, Центральная, 20	f	small
1397	20586	1127	республика Башкортостан, Балтачевский район, село Старотимкино, улица Центральная, 13	f	small
1423	20612	1153	республика Башкортостан, Балтачевский район, село Старобалтачево, Юбилейная, 2	f	large
1424	20613	1154	республика Башкортостан, Балтачевский район, село Старобалтачево, Советская, 92	f	large
1422	20611	1152	республика Башкортостан, Балтачевский район, село Старобалтачево, Комсомольская, 65	f	large
1433	20622	1163	республика Башкортостан, Балтачевский район, село Сейтяково, Советская, 1	f	medium
1400	20589	1130	республика Башкортостан, Балтачевский район, село Новоямурзино, К.Маркса, 16	f	small
1438	20627	1168	республика Башкортостан, Балтачевский район, село Новобалтачево, Первомайская, 39	f	small
65653	20603	1144	республика Башкортостан, Балтачевский район, село Нижнесикиязово, Центральная, 19	f	\N
1408	20597	1138	республика Башкортостан, Балтачевский район, село Нижнекарышево, Центральная, 35	f	small
1404	20593	1134	республика Башкортостан, Балтачевский район, село Нижнеиванаево, Центральная, 54	f	small
1413	20602	1143	республика Башкортостан, Балтачевский район, село Начарово, Озерная, 12	f	small
1447	14692	1177	республика Башкортостан, Балтачевский район, село Мата, Ленина, 18	f	small
1416	20605	1146	республика Башкортостан, Балтачевский район, село Магашлы-Алмантаево, Центральная, 38	f	small
1403	20592	1133	республика Башкортостан, Балтачевский район, село Курачево, Первомайская, 5	f	small
1405	20594	1135	республика Башкортостан, Балтачевский район, село Кунтугушево, К.Маркса, 20	f	small
1402	20591	1132	республика Башкортостан, Балтачевский район, село Кундашлы, Такаева, 49	f	small
1426	20615	1156	республика Башкортостан, Балтачевский район, село Кумьязы, Советская, 49/4	f	small
1445	20634	1175	республика Башкортостан, Балтачевский район, село Кузеево, Центральная, 28	t	small
1411	20600	1141	республика Башкортостан, Балтачевский район, село Кизганбашево, Центральная, 15	f	small
1428	20617	1158	республика Башкортостан, Балтачевский район, село Иликеево, Кооперативная, 2/2	f	small
1399	20588	1129	республика Башкортостан, Балтачевский район, село Верхнеянактаево, Социалистическая, 10	f	small
1409	20598	1139	республика Башкортостан, Балтачевский район, село Верхнекарышево, Центральная, 15	f	small
1441	20630	1171	республика Башкортостан, Балтачевский район, село Верхнекансиярово, Школьная, 5	t	small
1398	20587	1128	республика Башкортостан, Балтачевский район, село Богданово, Варламова, 5	f	small
1437	20626	1167	республика Башкортостан, Балтачевский район, село Асавка, Минниахметова, 53	f	small
1358	20547	1088	республика Башкортостан, Бакалинский район, село Юльтимировка, Центральная, 21	f	small
1388	20577	1118	республика Башкортостан, Бакалинский район, село Шарашли, Центральная, 59	f	small
1372	20561	1102	республика Башкортостан, Бакалинский район, село Утарово, Мира, 63А	f	small
1361	20550	1091	республика Башкортостан, Бакалинский район, село Устюмово, Т. Нуркаева, 48А	f	small
1352	20542	1082	республика Башкортостан, Бакалинский район, село Токбердино, Школьная, 46	f	small
1390	20579	1120	республика Башкортостан, Бакалинский район, село Тактагулово, Молодежная, 9	f	small
1386	20575	1116	республика Башкортостан, Бакалинский район, село Старые Маты, Победы, 7	f	medium
1351	20541	1081	республика Башкортостан, Бакалинский район, село Старокуяново, Центральная, 95	f	small
1380	20569	1110	республика Башкортостан, Бакалинский район, село Старокуручево, Центральная, 41	f	medium
1379	20568	1109	республика Башкортостан, Бакалинский район, село Старокуручево, Центральная, 23	f	medium
1377	20566	1107	республика Башкортостан, Бакалинский район, село Старокостеевко, Центральная, 69А	f	small
1374	20563	1104	республика Башкортостан, Бакалинский район, село Старокатаево, Школьная, 20	f	medium
1365	20554	1095	республика Башкортостан, Бакалинский район, село Староиликово, Центральная, 42А	f	small
1359	20548	1089	республика Башкортостан, Бакалинский район, село Старое Азмеево, Центральная, 31А	f	small
1349	20539	1079	республика Башкортостан, Бакалинский район, Сосновая, Сосновая, 4	f	small
1369	20558	1099	республика Башкортостан, Бакалинский район, село Новый Тумутук, Центральная, 62	f	small
1387	20576	1117	республика Башкортостан, Бакалинский район, село Новые Маты, Ленина, 16	f	small
1350	20540	1080	республика Башкортостан, Бакалинский район, село Новые Балыклы, Центральная, 73	f	small
1368	20557	1098	республика Башкортостан, Бакалинский район, село Новосасыкуль, Нагорная, 1	f	small
1364	20553	1094	республика Башкортостан, Бакалинский район, село Новоиликово, Магистральная, 24	f	small
1363	20552	1093	республика Башкортостан, Бакалинский район, село Новоальметьево, Мира, 55	f	small
1389	20578	1119	республика Башкортостан, Бакалинский район, село Новоагбязово, Школьная, 13	f	small
1376	20565	1106	республика Башкортостан, Бакалинский район, село Нагайбаково, Речная, 75	f	small
1373	20562	1103	республика Башкортостан, Бакалинский район, село Мустафино, Ленина, 103	f	medium
1393	20582	1123	республика Башкортостан, Бакалинский район, село Мирзаитово, Центральная, 5	f	small
1367	20556	1097	республика Башкортостан, Бакалинский район, село Куштиряково, Школьная, 2	f	small
1356	20420	1086	республика Башкортостан, Бакалинский район, село Курчеево, Ленина, 29А	f	small
1383	20572	1113	республика Башкортостан, Бакалинский район, село Килькабызово, Советская, 10	f	small
1362	20551	1092	республика Башкортостан, Бакалинский район, село Килеево, Центральная, 2А	f	small
1360	20549	1090	республика Башкортостан, Бакалинский район, село Камышлытамак, Клубная, 14	f	medium
1394	20583	1124	республика Башкортостан, Бакалинский район, село Камаево, Центральная, 6	f	small
1381	20570	1111	республика Башкортостан, Бакалинский район, село Камаево, Центральная, 70а	f	small
1357	20546	1087	республика Башкортостан, Бакалинский район, село Дияшево, Школьная, 54	f	small
1391	20580	1121	республика Башкортостан, Бакалинский район, село Гурдыбашево, Лесная, 33	f	small
1371	20560	1101	республика Башкортостан, Бакалинский район, село Бугабашево, Утина, 19А	f	small
1385	20574	1115	республика Башкортостан, Бакалинский район, село Балчиклы, Центральная, 29	f	small
1346	20536	1076	республика Башкортостан, Бакалинский район, село Бакалы, Школьная, 19	f	medium
1345	20535	1075	республика Башкортостан, Бакалинский район, село Бакалы, Школьная, 1	f	large
1347	20537	1077	республика Башкортостан, Бакалинский район, село Бакалы, Ленина, 166	f	large
1344	20534	1074	республика Башкортостан, Бакалинский район, село Бакалы, Ленина, 116	f	large
1343	20533	1073	республика Башкортостан, Бакалинский район, село Бакалы, Красных партизан, 31/2	f	large
1353	20543	1083	республика Башкортостан, Бакалинский район, село Ахманово, Центральная, 82	f	small
1283	20473	1013	республика Башкортостан, Баймакский район, село Яратово, Сакмара, 10	f	small
1328	20518	1058	республика Башкортостан, Баймакский район, село Янзигитово, Мельничная, 13	f	small
1340	20530	1070	республика Башкортостан, Баймакский район, село Янгазино, Янгазинская, 19	f	small
1277	20467	1007	республика Башкортостан, Баймакский район, село Юмашево, Школьная, 2А	f	medium
1278	20468	1008	республика Башкортостан, Баймакский район, село Юлук, Чанышева, 2	f	small
1288	20478	1018	республика Башкортостан, Баймакский район, село Шулька, Акназарова, 20	f	small
1334	20524	1064	республика Башкортостан, Баймакский район, село Уральское, Школьная, 34	f	small
1312	20502	1042	республика Башкортостан, Баймакский район, село Уметбаево, Башкир, 49	f	small
1319	20509	1049	республика Башкортостан, Баймакский район, село Туркменево 2-е, Мурадым, 20	f	small
1318	20508	1048	республика Башкортостан, Баймакский район, село Туркменево 1-е, Школьная, 2	f	medium
1313	20503	1043	республика Башкортостан, Баймакский район, поселок Тубинский, С.Юлаева, 28	f	medium
65650	20493	1033	республика Башкортостан, Баймакский район, село Темясово, Советская, 8	f	\N
1304	20494	1034	республика Башкортостан, Баймакский район, село Темясово, С.Юлаева, 18	f	large
1325	20515	1055	республика Башкортостан, Баймакский район, село Татлыбаево, Татлыбаева, 48а	f	small
1323	20513	1053	республика Башкортостан, Баймакский район, село Старый Сибай, Ленина, 14	f	large
1306	20496	1036	республика Башкортостан, Баймакский район, село Сакмар, Школьная, 1	f	small
1333	20523	1063	республика Башкортостан, Баймакский район, деревня Покровка, Молодежная, 23а	f	small
1286	20476	1016	республика Башкортостан, Баймакский район, село Первое Иткулово, Ленина, 101	f	medium
1337	20527	1067	республика Башкортостан, Баймакский район, деревня Октябрь, Школьная, 1	f	small
1307	20497	1037	республика Башкортостан, Баймакский район, село Нижнетагирово, Школьная, 53	f	small
65649	20479	1019	республика Башкортостан, Баймакский район, село Нижнетавлыкаево, З.Валиди, 19	f	\N
1296	20486	1026	республика Башкортостан, Баймакский район, село Нигаматово, К.Диярова, 3	f	medium
1302	20492	1032	республика Башкортостан, Баймакский район, село Муллакаево, Тансыккужина, 28	f	small
65638	20339	871	республика Башкортостан, Баймакский район, село Муллакаево, Сулейманова, 11	f	\N
1314	20504	1044	республика Башкортостан, Баймакский район, село Мерясово, Р.Уметбаева, 2	f	medium
1293	20483	1023	республика Башкортостан, Баймакский район, село Куянтаево, Аселинская, 2	f	medium
1299	20489	1029	республика Башкортостан, Баймакский район, село Кульчурово, Самарбаева, 8	f	small
1335	20525	1065	республика Башкортостан, Баймакский район, село Культубанское, Школьная, 1	f	small
1311	20501	1041	республика Башкортостан, Баймакский район, Кугидель, Ирандык, 14	f	small
65648	20471	1011	республика Башкортостан, Баймакский район, село Крепостной Зилаир, Почтовая, 13	f	\N
1326	20516	1056	республика Башкортостан, Баймакский район, село Карышкино, Ямаш, 7а	f	small
1274	20464	1004	республика Башкортостан, Баймакский район, село Каратал, С.Юлаева, 23	f	small
1324	20514	1054	республика Башкортостан, Баймакский район, село Калинино, Школьная, 1	f	small
1321	20511	1051	республика Башкортостан, Баймакский район, село Казанка, Школьная, 2	f	small
1339	20529	1069	республика Башкортостан, Баймакский район, село Ишмухаметово, Даута, 1	f	small
1309	20499	1039	республика Башкортостан, Баймакский район, село Ишей, Куктакинская, 5а	f	small
1279	20469	1009	республика Башкортостан, Баймакский район, село Ишберда, С.Юлаева, 33	f	small
1298	20488	1028	республика Башкортостан, Баймакский район, село Исяново, Аминева, 46	f	small
1317	20507	1047	республика Башкортостан, Баймакский район, село Исянбетово, Исрафилова, 28	f	small
1282	20472	1012	республика Башкортостан, Баймакский район, село Зелимово, Школьная, 9	f	small
1284	20474	1014	республика Башкортостан, Баймакский район, село Гумерово, Исмагилова, 21	f	small
1287	20477	1017	республика Башкортостан, Баймакский район, село Гадельбаево, Школьная, 1	f	small
1294	20484	1024	республика Башкортостан, Баймакский район, село Второе Иткулово, Ленина, 1	f	medium
1297	20487	1027	республика Башкортостан, Баймакский район, деревня Верхне-Яикбаево, Школьная, 2	f	small
1280	20470	1010	республика Башкортостан, Баймакский район, село Бурзян-Елга, Баракал, 15	t	small
1291	20481	1021	республика Башкортостан, Баймакский район, село Буранбаево, Сакмар, 9	f	small
1316	20506	1046	республика Башкортостан, Баймакский район, село Большебасаево, К.Диярова, 2	f	small
65651	20500	1040	республика Башкортостан, Баймакский район, село Билялово, З.Биишевой, 10	f	\N
1308	20498	1038	республика Башкортостан, Баймакский район, деревня Бетеря, Школьная, 1	f	small
1292	20482	1022	республика Башкортостан, Баймакский район, село Бекешево, Колхозная, 2	f	medium
3007	22171	2725	республика Башкортостан, Баймакский район, село Баймурзино, Мичурина, 12	f	small
1264	20454	994	республика Башкортостан, Баймакский район, Баймак, проспект С.Юлаева, 19	f	large
1341	20531	1071	республика Башкортостан, Баймакский район, село Баишево, Ургаза, 28а	f	small
1295	20485	1025	республика Башкортостан, Баймакский район, село Баимово, Садовая, 38	f	small
1320	20510	1050	республика Башкортостан, Баймакский район, село Ахмерово, Школьная, 1	f	small
3583	22808	3362	республика Башкортостан, Баймакский район, село Аминево, Школьная, 20а	f	small
65646	20461	1001	республика Башкортостан, Баймакский район, село Алгазино, Янтура, 7	f	\N
1273	20463	1003	республика Башкортостан, Баймакский район, село Актау, Х.Давлетшиной, 7	f	small
65647	20462	1002	республика Башкортостан, Баймакский район, село Акмурун, Ленина, 40	f	\N
1270	20460	1000	республика Башкортостан, Баймакский район, село Абдулкаримово, Молодёжная, 18	f	small
109411	22382	2890	республика Башкортостан, Баймакский район, село Абдрахманово, Центральная, 7	f	\N
1327	20517	1057	республика Башкортостан, Баймакский район, село Абдрахманово, С.Юлаева, 17а	f	small
1040	20240	774	республика Башкортостан, Аургазинский район, село Юлдашево, Школьная, 1	f	small
1250	20440	980	республика Башкортостан, Аургазинский район, село Юламаново, Ленина, 22	f	small
1240	20428	968	республика Башкортостан, Аургазинский район, село Шланлы, Центральная, 42а	f	medium
1241	20429	969	республика Башкортостан, Аургазинский район, село Шеверли, Центральная, 1б	f	small
1261	20451	991	республика Башкортостан, Аургазинский район, село Чуваш-Карамалы, Центральная, 10	f	medium
1232	20419	960	республика Башкортостан, Аургазинский район, село Утеймуллино, Молодежная, 29	f	medium
1257	20447	987	республика Башкортостан, Аургазинский район, село Усманово, Центральная, 10	f	small
1256	20446	986	республика Башкортостан, Аургазинский район, село Турумбет, Центральная, 8	f	small
1253	20443	983	республика Башкортостан, Аургазинский район, село Тукаево, Чанышева, 32	f	medium
1251	20441	981	республика Башкортостан, Аургазинский район, село Тряпино, Первомайская, 1	f	medium
1249	20439	979	республика Башкортостан, Аургазинский район, село Толбазы, Школьная, 2	f	large
1248	20438	978	республика Башкортостан, Аургазинский район, село Толбазы, Химиков, 4	f	large
1247	20437	977	республика Башкортостан, Аургазинский район, село Толбазы, Ленина, 125	f	large
1246	20436	976	республика Башкортостан, Аургазинский район, село Толбазы, Ленина, 113	f	large
1245	20435	975	республика Башкортостан, Аургазинский район, село Толбазы, Ибрагимова, 23	f	large
1244	20433	973	республика Башкортостан, Аургазинский район, село Таштамак, Фрунзе, 6	f	medium
1231	20418	959	республика Башкортостан, Аургазинский район, село Татарский Нагадак, Центральная, 121	f	medium
1243	20432	972	республика Башкортостан, Аургазинский район, село Султанмуратово, Центральная, 44	f	medium
1242	20430	970	республика Башкортостан, Аургазинский район, село Степановка, Молодежная, 1Г	f	medium
1228	20415	956	республика Башкортостан, Аургазинский район, село Старомакарово, Выездная, 2	f	small
1224	20411	952	республика Башкортостан, Аургазинский район, село Старокузяково, Советская, 16	f	small
1236	20424	964	республика Башкортостан, Аургазинский район, село Семенкино, Советская, 2в	f	medium
65817	21619	2169	республика Башкортостан, Аургазинский район, село Салихово, Советская, 2	f	\N
65643	20421	961	республика Башкортостан, Аургазинский район, село Новые Карамалы, Центральная, 15	f	\N
1220	20407	948	республика Башкортостан, Аургазинский район, село Новофедоровка, Первомайская, 26а	f	medium
1222	20409	950	республика Башкортостан, Аургазинский район, село Новотимошкино, К.Маркса, 19	f	small
1216	20403	944	республика Башкортостан, Аургазинский район, село Новоитикеево, Школьная, 14	f	small
1237	20425	965	республика Башкортостан, Аургазинский район, село Нижный Бегеняш, Центральная, 1в	f	small
1214	20401	942	республика Башкортостан, Аургазинский район, село Наумкино, Центральная, 31А	f	medium
1217	20404	945	республика Башкортостан, Аургазинский район, село Мустафино, 7 Ноября, 11	f	small
1230	20417	958	республика Башкортостан, Аургазинский район, деревня Мурадымово, Школьная, 35	f	medium
1229	20416	957	республика Башкортостан, Аургазинский район, село Михайловка, Ленина, 69	f	small
1226	20413	954	республика Башкортостан, Аургазинский район, село Месели, Центральная, 80	f	medium
1227	20414	955	республика Башкортостан, Аургазинский район, село Манеево, Циолковского, 3а	f	small
1252	20442	982	республика Башкортостан, Аургазинский район, село Малый Нагадак, Восточная, 27	f	small
1219	20406	947	республика Башкортостан, Аургазинский район, село Малое Ибраево, Ленина, 1а	f	small
65821	21624	2175	республика Башкортостан, Аургазинский район, село Макарово, Центральная, 28	f	\N
1235	20423	963	республика Башкортостан, Аургазинский район, село Кшанны, Ленина, 49	f	medium
1259	20449	989	республика Башкортостан, Аургазинский район, село Курманаево, Школьная, 4А	f	small
1215	20402	943	республика Башкортостан, Аургазинский район, село Куезбашево, Садовая, 40А	f	medium
1225	20412	953	республика Башкортостан, Аургазинский район, село Кебячево, Мира, 2а	f	medium
1234	20422	962	республика Башкортостан, Аургазинский район, деревня Кальчирбуран, Центральная, 47б	f	small
1223	20410	951	республика Башкортостан, Аургазинский район, село Ишлы, Ленина, 21	f	medium
1221	20408	949	республика Башкортостан, Аургазинский район, село Исмагилово, Центральная, 5	f	medium
1254	20444	984	республика Башкортостан, Аургазинский район, село Болотино, Центральная, 37	f	small
1218	20405	946	республика Башкортостан, Аургазинский район, село Бишкаин, Центральная, 63а	f	medium
65642	20400	941	республика Башкортостан, Аургазинский район, село Балыклыкуль, Центральная, 39	f	\N
1239	20427	967	республика Башкортостан, Аургазинский район, село Асавбашево, Центральная, 67б	f	small
1255	20445	985	республика Башкортостан, Аургазинский район, село Андреевка, Школьная, 8	f	small
769	19989	506	республика Башкортостан, Аургазинский район, село Амзя, Школьная, 25	f	large
768	19988	505	республика Башкортостан, Аургазинский район, село Амзя, Лесохимическая, 10	f	large
65644	20431	971	республика Башкортостан, Аургазинский район, село Александровка, Ленина, 51	f	\N
1207	20394	935	республика Башкортостан, Аскинский район, село Чурашево, Центральная, 8	f	small
1179	20367	908	республика Башкортостан, Аскинский район, село Чишма-Уракаево, Центральная, 34/2	f	small
1195	20383	924	республика Башкортостан, Аскинский район, село Утяшино, Крупской, 2	f	small
1212	20399	940	республика Башкортостан, Аскинский район, село Усть-Табаска, Гагарина, 29	f	small
1211	20398	939	республика Башкортостан, Аскинский район, село Уршады, Набережная, 3	f	small
1182	20370	911	республика Башкортостан, Аскинский район, село Упканкуль, Центральная, 1	f	small
1607	20797	1337	республика Башкортостан, Аскинский район, село Улуелга, Лесная, 8	f	small
1175	20363	904	республика Башкортостан, Аскинский район, село Тюйск, Цветочная, 16	f	small
1172	20360	901	республика Башкортостан, Аскинский район, село Тульгузбаш, Юбилейная, 2	f	small
1206	20393	934	республика Башкортостан, Аскинский район, село Султанбеково, Центральная, 33	f	small
1181	20369	910	республика Башкортостан, Аскинский район, село Султанай, Механизаторов, 22	f	small
1202	20389	930	республика Башкортостан, Аскинский район, село Старый Мутабаш, Центральная, 29	f	small
1183	20371	912	республика Башкортостан, Аскинский район, село Старые Казанчи, Школьная, 11А	f	medium
1184	20372	913	республика Башкортостан, Аскинский район, село Старые Казанчи, Центральная, 21	f	small
1199	20387	928	республика Башкортостан, Аскинский район, село Новые Казанчи, Гумерова, 4	f	small
1177	20365	906	республика Башкортостан, Аскинский район, деревня Новые Багазы, Советская, 10	f	small
1209	20396	937	республика Башкортостан, Аскинский район, село Новокочкильдино, Трактовая, 6	f	small
1185	20373	914	республика Башкортостан, Аскинский район, село Новая Кара, Школьная, 2А	f	small
1174	20362	903	республика Башкортостан, Аскинский район, село Новая Бурма, Школьная, 1	f	small
1203	20390	931	республика Башкортостан, Аскинский район, село Мута-Елга, Центральная, 51	f	small
1196	20384	925	республика Башкортостан, Аскинский район, село Матала, Ленина, 10	f	small
1198	20386	927	республика Башкортостан, Аскинский район, село Кшлау-Елга, Школьная, 7	f	small
1176	20364	905	республика Башкортостан, Аскинский район, село Куяштыр, Крестьянская, 6	f	small
1197	20385	926	республика Башкортостан, Аскинский район, село Кунгак, Молодежная, 4	f	small
1194	20382	923	республика Башкортостан, Аскинский район, село Кубиязы, Ленина, 2	f	small
1192	20380	921	республика Башкортостан, Аскинский район, село Ключи, Центральная, 10	f	small
1205	20392	933	республика Башкортостан, Аскинский район, село Кигазы, Центральная, 6	f	small
1187	20375	916	республика Башкортостан, Аскинский район, село Кашкино, Мира, 10	f	small
1186	20374	915	республика Башкортостан, Аскинский район, село Кашкино, Мира, 17	f	small
1191	20379	920	республика Башкортостан, Аскинский район, село Карткисяк, Центральная, 8	f	small
1180	20368	909	республика Башкортостан, Аскинский район, село Евбуляк, Центральная, 11	f	small
1190	20378	919	республика Башкортостан, Аскинский район, село Гумбино, Первомайская, 16	f	small
1189	20377	918	республика Башкортостан, Аскинский район, село Бильгиш, Первомайская, 12	f	small
1173	20361	902	республика Башкортостан, Аскинский район, село Барахаевка, Лесная, 4	f	small
65641	20388	929	республика Башкортостан, Аскинский район, село Базанчатово, Центральная, 3	f	\N
1167	20355	895	республика Башкортостан, Аскинский район, село Аскино, Пионерская, 7	f	large
1170	20358	899	республика Башкортостан, Аскинский район, село Аскино, Октябрьская, 6	f	medium
1169	20358	898	республика Башкортостан, Аскинский район, село Аскино, Октябрьская, 6	f	large
1171	20359	900	республика Башкортостан, Аскинский район, село Аскино, Мичурина, 59	f	large
65640	20356	896	республика Башкортостан, Аскинский район, село Аскино, Мира, 8	f	\N
1168	20357	897	республика Башкортостан, Аскинский район, село Аскино, Ленина, 100	f	medium
1178	20366	907	республика Башкортостан, Аскинский район, село Арбашево, Центральная, 9/2	f	small
1188	20376	917	республика Башкортостан, Аскинский район, село Амирово, Центральная, 47	f	small
1166	20354	894	республика Башкортостан, Архангельский район, село Узунларово, Центральная, 35	f	small
1140	20042	872	республика Башкортостан, Архангельский район, село Убалары, Центральная, 84	f	small
1155	20344	884	республика Башкортостан, Архангельский район, село Троицкое, Заречная, 1 А	f	small
1143	18587	875	республика Башкортостан, Архангельский район, село Тереклы, Школьная, 40	f	medium
1163	20351	891	республика Башкортостан, Архангельский район, село Тавакачево, Школьная, 12	f	small
1154	20343	883	республика Башкортостан, Архангельский район, село Сагитово, Школьная, 48	f	small
1162	20350	890	республика Башкортостан, Архангельский район, поселок Приуралье, Вокзальная, 3 А	f	small
3714	22937	3494	республика Башкортостан, Архангельский район, село Орловка, Центральная, 48	f	small
1161	20349	889	республика Башкортостан, Архангельский район, село Орловка, Казаковская, 35	f	small
1136	20337	869	республика Башкортостан, Архангельский район, село Максим Горький, Ленина, 42	f	medium
1152	20342	882	республика Башкортостан, Архангельский район, село Кысынды, Центральная, 25	f	small
1151	20341	881	республика Башкортостан, Архангельский район, село Красный Зилим, Центральная, 2	f	small
65639	18351	874	республика Башкортостан, Архангельский район, село Кизги, Центральная, 25	f	\N
1160	20348	888	республика Башкортостан, Архангельский район, село Карташевка, Нефтяников, 4	f	small
1147	18795	877	республика Башкортостан, Архангельский район, село Казанка, Озерная, 9	f	small
1137	20338	870	республика Башкортостан, Архангельский район, село Заря, Школьная, 6	f	small
1150	20340	880	республика Башкортостан, Архангельский район, село Заитово, Нижняя, 2 А	f	small
1145	18620	876	республика Башкортостан, Архангельский район, село Валентиновка, Советская, 57	f	medium
1156	20345	885	республика Башкортостан, Архангельский район, село Благовещенка, Центральная, 2	f	medium
1141	20324	873	республика Башкортостан, Архангельский район, село Бакалдинское, Матросова, 8	f	medium
1134	20335	867	республика Башкортостан, Архангельский район, село Архангельское, Чернышевского, 22 А	f	large
1165	20353	893	республика Башкортостан, Архангельский район, село Айтмембетово, Школьная, 16	f	small
1164	20352	892	республика Башкортостан, Архангельский район, село Азово, Советская, 29	f	small
1132	20333	865	республика Башкортостан, Архангельский район, село Абзаново, А.Абдрахманова, 70	f	medium
1109	20308	842	республика Башкортостан, Альшеевский район, с. Дим, Салавата Юлаева, 28	f	small
1128	20329	861	республика Башкортостан, Альшеевский район, поселок Шафраново, Кирова, 4	f	large
1108	20307	841	республика Башкортостан, Альшеевский район, село Чураево, Школьная, 40/1	f	small
1127	20328	860	республика Башкортостан, Альшеевский район, село Чебенли, Центральная, 6	f	medium
1097	20296	830	республика Башкортостан, Альшеевский район, село Ханжарово, Школьная, 7	f	small
1113	20312	846	республика Башкортостан, Альшеевский район, село Уразметово, Молодежная, 12	f	small
1107	20306	840	республика Башкортостан, Альшеевский район, село Уваровка, Рабочая, 12А	f	small
1125	20326	858	республика Башкортостан, Альшеевский район, село Трунтаишево, Центральная, 68а	f	medium
1124	20325	857	республика Башкортостан, Альшеевский район, село Ташлы, Центральная, 37	f	medium
1112	20311	845	республика Башкортостан, Альшеевский район, село Тавричанка, Гагарина, 15	f	medium
1123	20323	856	республика Башкортостан, Альшеевский район, село Слак, Центральная, 1	f	medium
1126	20327	859	республика Башкортостан, Альшеевский район, село Сараево, Школьная, 5	f	small
1092	20291	825	республика Башкортостан, Альшеевский район, поселок Раевский, Школьная, 1	f	large
1084	20283	817	республика Башкортостан, Альшеевский район, поселок Раевский, Советская площадь, 3	f	medium
1085	20284	818	республика Башкортостан, Альшеевский район, поселок Раевский, Свободы, 108	f	large
1086	20285	819	республика Башкортостан, Альшеевский район, поселок Раевский, Полевая, 63	f	large
1087	20286	820	республика Башкортостан, Альшеевский район, поселок Раевский, Победы, 2А	f	large
1083	20282	816	республика Башкортостан, Альшеевский район, поселок Раевский, Кускова, 36	f	medium
65636	20288	822	республика Башкортостан, Альшеевский район, поселок Раевский, Коммунистическая, 41	f	\N
1088	20287	821	республика Башкортостан, Альшеевский район, поселок Раевский, Коммунистическая, 17	f	medium
1090	20289	823	республика Башкортостан, Альшеевский район, поселок Раевский, Кирова, 88А	f	large
1091	20290	824	республика Башкортостан, Альшеевский район, поселок Раевский, Гагарина, 20	f	large
1111	20310	844	республика Башкортостан, Альшеевский район, село Отрада, Центральная, 52	f	small
2979	22143	2697	республика Башкортостан, Альшеевский район, село Новотроицкое, Школьная, 34	f	small
1103	20302	836	республика Башкортостан, Альшеевский район, село Новосепяшево, Центральная, 38/3	f	medium
1743	20926	1469	республика Башкортостан, Альшеевский район, село Новоконстантиновка, Дружбы, 27/1	f	small
1119	20319	852	республика Башкортостан, Альшеевский район, село Никифарово, Дружбы, 51а	f	medium
1121	20321	854	республика Башкортостан, Альшеевский район, село Нижнее Аврюзово, Ленина, 54	f	medium
1122	20322	855	республика Башкортостан, Альшеевский район, село Нижегородка, Школьная, 12	f	small
65637	20315	849	республика Башкортостан, Альшеевский район, село Нигматуллино, Центральная, 35В	f	\N
1118	20318	851	республика Башкортостан, Альшеевский район, село Нефорощанка, Дружбы, 29	t	small
1115	20314	848	республика Башкортостан, Альшеевский район, село Мендяново, Центральная, 68	f	medium
1094	20293	827	республика Башкортостан, Альшеевский район, село Крымский, Больничная, 2А	f	medium
1110	20309	843	республика Башкортостан, Альшеевский район, село Кипчак-Аскарово, Салавата Юлаева, 109	f	medium
1098	20297	831	республика Башкортостан, Альшеевский район, село Кайраклы, Центральная, 8	f	small
1104	20303	837	республика Башкортостан, Альшеевский район, село Казанка, Центральная, 60	f	small
1130	20331	863	республика Башкортостан, Альшеевский район, село Идрисово, Школьная, 1а	f	small
1101	20300	834	республика Башкортостан, Альшеевский район, село Зеленый Клин, Школьная, 2	f	small
71674	81034	1681	Самарская область, Тольятти, Молодежный, 28	f	large
1100	20299	833	республика Башкортостан, Альшеевский район, село Гайниямак, Центральная, 45	f	medium
1099	20298	832	республика Башкортостан, Альшеевский район, село Воздвиженка, Центральная, 10	f	medium
1120	20320	853	республика Башкортостан, Альшеевский район, село Балгазы, Школьная, 10А	f	small
1117	20317	850	республика Башкортостан, Альшеевский район, село Байдаковка, Центральная, 3	t	small
1095	20294	828	республика Башкортостан, Альшеевский район, поселок Аксеново, Советская, 14	f	medium
1093	20292	826	республика Башкортостан, Альшеевский район, село Абдрашитово, Озерная, 1а	f	medium
65629	20248	782	республика Башкортостан, Абзелиловский район, село отделение Озерное Совхоза Красная Башкирия, Школьная, 32	f	\N
65635	20281	815	республика Башкортостан, Абзелиловский район, село Янгильский, Стадионная, 14	f	\N
65633	20276	810	республика Башкортостан, Абзелиловский район, село Шарипово, Горная, 7	f	\N
65626	20219	750	республика Башкортостан, Абзелиловский район, село Целинный, Ленина, 5	f	\N
1075	20274	808	республика Башкортостан, Абзелиловский район, село Халилово, Советская, 2 Г	f	medium
1071	20270	804	республика Башкортостан, Абзелиловский район, село Тупаково, Хисматуллина, 53	f	small
1055	20255	789	республика Башкортостан, Абзелиловский район, село Тепяново, Центральная, 2	f	small
2917	22087	2635	республика Башкортостан, Абзелиловский район, село Теляшево, Советская, 100	f	small
65634	20280	814	республика Башкортостан, Абзелиловский район, деревня Таштуй, улица Мира, 12/3	f	\N
1062	20262	796	республика Башкортостан, Абзелиловский район, село Ташбулатово, Центральная, 16	f	medium
1039	20239	773	республика Башкортостан, Абзелиловский район, село Тал-Кускарово, Клубная, 8	f	small
65628	20238	772	республика Башкортостан, Абзелиловский район, село Таксырово, Целинная, 1а	f	\N
1032	20233	767	республика Башкортостан, Абзелиловский район, село Старобалапаново, Центральная, 2	f	small
1011	20218	749	республика Башкортостан, Абзелиловский район, село Северный, Клубная, 2	f	small
1068	20267	801	республика Башкортостан, Абзелиловский район, село Самарское, Центральная, 37	f	small
1017	20223	754	республика Башкортостан, Абзелиловский район, село Рыскужино, 40 лет Победы , 23	f	small
65627	20232	766	республика Башкортостан, Абзелиловский район, село Рахметово, Школьная, 14	t	\N
1054	20254	788	республика Башкортостан, Абзелиловский район, село Равилово, Центральная, 23	f	small
1080	20279	813	республика Башкортостан, Абзелиловский район, село Первомайский, Ф.Гумеровой, 14	f	small
1030	20231	765	республика Башкортостан, Абзелиловский район, село Новобалапаново, Салавата Юлаева, 9	f	small
1061	20261	795	республика Башкортостан, Абзелиловский район, село Ниязгулово, Школьная, 14	f	small
1029	20230	764	республика Башкортостан, Абзелиловский район, село Муракаево, Центральная, 7	f	small
1074	20273	807	республика Башкортостан, Абзелиловский район, село Махмутово, Дружбы, 16 А	f	small
1042	20242	776	республика Башкортостан, Абзелиловский район, село Кушеево, Сулейманова, 30	f	small
1056	20256	790	республика Башкортостан, Абзелиловский район, село Кусимовский Рудник, Школьная, 1	f	medium
65632	20260	794	республика Башкортостан, Абзелиловский район, село Кусимово, Школьная, 11	f	\N
1066	20265	799	республика Башкортостан, Абзелиловский район, село Кужаново, Худайбердина, 33/1	f	small
1047	20247	781	республика Башкортостан, Абзелиловский район, село Красная Башкирия, Центральная, 11	f	large
1046	20246	780	республика Башкортостан, Абзелиловский район, село Кирдасово, Советская, 50	f	small
1016	20222	753	республика Башкортостан, Абзелиловский район, село Казмашево, Ишбулатова, 24	f	small
1053	20253	787	республика Башкортостан, Абзелиловский район, село Ишкулово, Матросова, 35	f	medium
1034	20235	769	республика Башкортостан, Абзелиловский район, село Ишкильдино, Салавата Юлаева, 11	f	small
1073	20272	806	республика Башкортостан, Абзелиловский район, село Ишбулдино, Новая, 2	f	small
1028	20013	763	республика Башкортостан, Абзелиловский район, село Еникеево, Шаймуратова, 19	f	small
1051	20251	785	республика Башкортостан, Абзелиловский район, село Давлетшино, Центральная, 22	f	small
1041	20241	775	республика Башкортостан, Абзелиловский район, село Давлетово, Школьная, 16	f	medium
1036	20237	771	республика Башкортостан, Абзелиловский район, село Гусево, Соколова, 93	f	medium
1033	20234	768	Россия, республика Башкортостан, Абзелиловский район, село Бурангулово	f	medium
1009	20216	747	республика Башкортостан, Абзелиловский район, село Булатово, Молодежная, 21	f	small
1027	18132	762	республика Башкортостан, Абзелиловский район, село Баимово, Школьная, 16	f	large
1058	20258	792	республика Башкортостан, Абзелиловский район, село Аюсазово, Школьная, 5	f	small
1045	20245	779	республика Башкортостан, Абзелиловский район, село Ахметово, Сакмарская, 5	f	small
1079	20278	812	республика Башкортостан, Абзелиловский район, деревня Атавды, Школьная, 1	f	small
1023	20228	759	республика Башкортостан, Абзелиловский район, село Аскарово, Пионерская, 1	f	large
1008	20215	746	республика Башкортостан, Абзелиловский район, село Альмухаметово, Молодежная, 10	f	small
1078	20277	811	республика Башкортостан, Абзелиловский район, деревня Авняш, Центральная, 26	f	small
1063	20263	797	республика Башкортостан, Абзелиловский район, село Абзелилово, Клочкова, 1	f	small
1072	20271	805	республика Башкортостан, Абзелиловский район, село Абдулмамбетово, Салавата Кадырова, 2	f	small
1014	20220	751	республика Башкортостан, Абзелиловский район, село Абдулгазино, Ленина, 54	f	small
78388	7616	578	Ульяновская область, рабочий поселок Ишеевка, Школьная улица, 3	f	large
78386	7614	576	Ульяновская область, рабочий поселок Ишеевка, Новокомбинатовская, 3	f	large
78385	7613	575	Ульяновская область, рабочий поселок Ишеевка, Дачная, 1	f	large
134591	94445	955	Ульяновская область, Ульяновск, Муниципальное автономное дошкольное образовательное учреждение детский сад № 258, спортивный зал	f	large
134590	94444	954	Ульяновская область, Ульяновск, Муниципальное автономное дошкольное образовательное учреждение детский сад № 258	f	large
134588	94442	770	Ульяновская область, Ульяновск, Муниципальное бюджетное дошкольное образовательное учреждение детский сад деревня Кувшиновка	f	small
78582	7837	862	Ульяновская область, Ульяновск, улица Терешковой, 6	f	large
78516	7805	791	Ульяновская область, Ульяновск, улица Тельмана, 7	f	large
78515	7805	790	Ульяновская область, Ульяновск, улица Тельмана, 7	f	large
78513	7803	788	Ульяновская область, Ульяновск, улица Тельмана, 38	f	large
78512	7803	787	Ульяновская область, Ульяновск, улица Тельмана, 38	f	large
78665	7880	950	Ульяновская область, Ульяновск, улица Северный Венец, 32	f	large
78619	7855	900	Ульяновская область, Ульяновск, улица Рябикова, 25а	f	large
78618	7855	899	Ульяновская область, Ульяновск, улица Рябикова, 25а	f	large
78617	7855	898	Ульяновская область, Ульяновск, улица Рябикова, 25а	f	large
78616	7854	897	Ульяновская область, Ульяновск, улица Рябикова, 30	f	large
78615	7854	896	Ульяновская область, Ульяновск, улица Рябикова, 30	f	large
78614	7854	895	Ульяновская область, Ульяновск, улица Рябикова, 30	f	large
78603	7850	884	Ульяновская область, Ульяновск, улица Рябикова, 6	f	large
78662	7876	947	Ульяновская область, Ульяновск, улица Розы Люксембург, 48	f	large
78661	7876	946	Ульяновская область, Ульяновск, улица Розы Люксембург, 48	f	large
78682	7894	969	Ульяновская область, Ульяновск, улица Радищева, 39	f	large
78589	7841	869	Ульяновская область, Ульяновск, улица Полбина, 21	f	large
78588	7841	868	Ульяновская область, Ульяновск, улица Полбина, 21	f	large
78581	7836	861	Ульяновская область, Ульяновск, улица Полбина, 57а	f	large
78580	7836	860	Ульяновская область, Ульяновск, улица Полбина, 57а	f	large
78579	7836	859	Ульяновская область, Ульяновск, улица Полбина, 57а	f	large
78652	7865	933	Ульяновская область, Ульяновск, улица Ефремова, 145а	f	large
78651	7865	932	Ульяновская область, Ульяновск, улица Ефремова, 145а	f	large
78650	7865	931	Ульяновская область, Ульяновск, улица Ефремова, 145а	f	large
78649	7865	930	Ульяновская область, Ульяновск, улица Ефремова, 145а	f	large
78648	7865	929	Ульяновская область, Ульяновск, улица Ефремова, 145а	f	large
78613	7853	894	Ульяновская область, Ульяновск, улица Ефремова, 55	f	large
78612	7853	893	Ульяновская область, Ульяновск, улица Ефремова, 55	f	large
78611	7853	892	Ульяновская область, Ульяновск, улица Ефремова, 55	f	large
78486	7778	756	Ульяновская область, Ульяновск, улица Варейкиса, 17	f	large
78642	7863	923	Ульяновская область, Ульяновск, проспект Хо Ши Мина, 30	f	large
78641	7863	922	Ульяновская область, Ульяновск, проспект Хо Ши Мина, 30	f	large
78640	7863	921	Ульяновская область, Ульяновск, проспект Хо Ши Мина, 30	f	large
78639	7863	920	Ульяновская область, Ульяновск, проспект Хо Ши Мина, 30	f	large
128154	7813	801	Ульяновская область, Ульяновск, проспект Туполева, 1	f	\N
78523	7813	800	Ульяновская область, Ульяновск, проспект Туполева, 1	f	large
78533	7817	812	Ульяновская область, Ульяновск, проспект Созидателей, 62	f	large
78674	7888	961	Ульяновская область, Ульяновск, проспект Нариманова, 13	f	large
78666	7883	952	Ульяновская область, Ульяновск, проспект Нариманова, 106	f	large
128146	7882	951	Ульяновская область, Ульяновск, проспект Нариманова, 83	f	\N
78478	7774	748	Ульяновская область, Ульяновск, проспект Гая, 21	f	large
78479	7774	749	Ульяновская область, Ульяновск, проспект Гая, 21	f	large
78477	7773	747	Ульяновская область, Ульяновск, проспект Гая, 15	f	large
78476	7772	746	Ульяновская область, Ульяновск, проспект Гая, 15	f	large
128125	7825	833	Ульяновская область, Ульяновск, проспект Врача Сурова, 11	f	\N
128123	7825	831	Ульяновская область, Ульяновск, проспект Врача Сурова, 11	f	\N
128124	7825	832	Ульяновская область, Ульяновск, проспект Врача Сурова, 11	f	\N
78592	7844	873	Ульяновская область, Ульяновск, проспект 50-летия ВЛКСМ, 25	f	large
78472	7769	742	Ульяновская область, Ульяновск, Железнодорожный район, микрорайон Туть, Южная улица, 132	f	large
78507	7799	782	Ульяновская область, Ульяновск, Шоферов, 16	f	large
78508	7799	783	Ульяновская область, Ульяновск, Шоферов, 16	f	large
78704	7909	991	Ульяновская область, Ульяновск, Школьная улица, 1	f	large
78496	7788	769	Ульяновская область, Ульяновск, Школьная улица, 27	f	large
128105	7790	771	Ульяновская область, Ульяновск, Школьная, 3	f	small
78497	7791	772	Ульяновская область, Ульяновск, Школьная, 8	f	large
128103	7787	768	Ульяновская область, Ульяновск, Центральная, 5	f	medium
78487	7779	757	Ульяновская область, Ульяновск, Хрустальная, 54	f	large
78654	7866	935	Ульяновская область, Ульяновск, Хваткова, 2а	f	large
78655	7866	936	Ульяновская область, Ульяновск, Хваткова, 2а	f	large
78653	7866	934	Ульяновская область, Ульяновск, Хваткова, 2а	f	large
78622	7856	903	Ульяновская область, Ульяновск, Фруктовая, 3	f	large
78621	7856	902	Ульяновская область, Ульяновск, Фруктовая, 3	f	large
78620	7856	901	Ульяновская область, Ульяновск, Фруктовая, 3	f	large
128108	7816	811	Ульяновская область, Ульяновск, Фестивальный бульвар, 24	f	medium
78532	7816	810	Ульяновская область, Ульяновск, Фестивальный бульвар, 24	f	large
78531	7816	809	Ульяновская область, Ульяновск, Фестивальный бульвар, 24	f	large
78530	7815	808	Ульяновская область, Ульяновск, Фестивальный бульвар, 18	f	large
78529	7815	807	Ульяновская область, Ульяновск, Фестивальный бульвар, 18	f	large
78528	7815	806	Ульяновская область, Ульяновск, Фестивальный бульвар, 18	f	large
78527	7814	805	Ульяновская область, Ульяновск, Фестивальный бульвар, 4	f	large
78526	7814	804	Ульяновская область, Ульяновск, Фестивальный бульвар, 4	f	large
78525	7814	803	Ульяновская область, Ульяновск, Фестивальный бульвар, 4	f	large
78524	7814	802	Ульяновская область, Ульяновск, Фестивальный бульвар, 4	f	large
78660	7875	945	Ульяновская область, Ульяновск, Ульяны Громовой, 3	f	large
78473	7770	743	Ульяновская область, Ульяновск, Трудовая улица, 5	f	large
78673	7887	960	Ульяновская область, Ульяновск, Толбухина, 21	f	large
78672	7887	959	Ульяновская область, Ульяновск, Толбухина, 21	f	large
78671	7885	958	Ульяновская область, Ульяновск, Толбухина, 57	f	large
78670	7885	957	Ульяновская область, Ульяновск, Толбухина, 57	f	large
128149	7890	962	Ульяновская область, Ульяновск, Тимирязева, 51	f	\N
78676	7890	963	Ульяновская область, Ульяновск, Тимирязева, 51	f	large
78517	7806	792	Ульяновская область, Ульяновск, Тельмана, 9	f	large
78701	7906	988	Ульяновская область, Ульяновск, Старосельдинская, 62	f	large
78609	7852	890	Ульяновская область, Ульяновск, Станкостроителей, 15	f	large
78610	7852	891	Ульяновская область, Ульяновск, Станкостроителей, 15	f	large
78608	7852	889	Ульяновская область, Ульяновск, Станкостроителей, 15	f	large
78607	7852	888	Ульяновская область, Ульяновск, Станкостроителей, 15	f	large
78684	7895	971	Ульяновская область, Ульяновск, Спасская, 15	f	large
78683	7895	970	Ульяновская область, Ульяновск, Спасская, 15	f	large
78522	7812	799	Ульяновская область, Ульяновск, Солнечная, 8	f	large
127907	7485	451	Ульяновская область, Сенгилеевский район	f	medium
78656	7868	938	Ульяновская область, Ульяновск, Сельдинская, 49	f	large
78599	7847	880	Ульяновская область, Ульяновск, Севастопольская улица, 14	f	large
78600	7848	881	Ульяновская область, Ульяновск, Севастопольская, 14	f	large
78629	7859	910	Ульяновская область, Ульяновск, Самарская, 11 А	f	large
78628	7859	909	Ульяновская область, Ульяновск, Самарская, 11 А	f	large
78627	7858	908	Ульяновская область, Ульяновск, Самарская, 11А	f	large
78700	7905	987	Ульяновская область, Ульяновск, Российская, 138а	f	large
78681	7893	968	Ульяновская область, Ульяновск, Радищева, 102	f	large
78680	7893	967	Ульяновская область, Ульяновск, Радищева, 102	f	large
78679	7892	966	Ульяновская область, Ульяновск, Радищева, 159	f	large
78678	7891	965	Ульяновская область, Ульяновск, Радищева, 168	f	large
78677	7891	964	Ульяновская область, Ульяновск, Радищева, 168	f	large
78470	7767	740	Ульяновская область, Ульяновск, Пушкинская, 2	f	large
78469	7767	739	Ульяновская область, Ульяновск, Пушкинская, 2	f	large
78575	7833	855	Ульяновская область, Ульяновск, Пушкарева, 60а	f	large
134589	94443	943	Ульяновская область, Ульяновск, Поливенское шоссе, 5	f	large
128144	7874	944	Ульяновская область, Ульяновск, Поливенская, 19	f	medium
128137	7829	845	Ульяновская область, Ульяновск, Пензенский бульвар, 10	f	\N
128139	7829	847	Ульяновская область, Ульяновск, Пензенский бульвар, 10	f	\N
128138	7829	846	Ульяновская область, Ульяновск, Пензенский бульвар, 10	f	\N
78667	7884	953	Ульяновская область, Ульяновск, Пархоменко, 98	f	large
78645	7864	926	Ульяновская область, Ульяновск, Отрадная, 14	f	large
78647	7864	928	Ульяновская область, Ульяновск, Отрадная, 14	f	large
78646	7864	927	Ульяновская область, Ульяновск, Отрадная, 14	f	large
78644	7864	925	Ульяновская область, Ульяновск, Отрадная, 14	f	large
78693	7902	980	Ульяновская область, Ульяновск, Островского, 6	f	large
78521	7809	796	Ульяновская область, Ульяновск, Оренбургская улица, 38	f	large
78520	7808	795	Ульяновская область, Ульяновск, Оренбургская, 34А	f	large
78519	7808	794	Ульяновская область, Ульяновск, Оренбургская, 34А	f	large
78584	7838	864	Ульяновская область, Ульяновск, Октябрьская улица, 26	f	large
78583	7838	863	Ульяновская область, Ульяновск, Октябрьская улица, 26	f	large
134946	95174	750	Ульяновская область, Ульяновск, Озерный переулок, 9	f	large
78543	7823	823	Ульяновская область, Ульяновск, Новосондецкий бульвар, 4	f	large
78542	7823	822	Ульяновская область, Ульяновск, Новосондецкий бульвар, 4	f	large
128116	7821	821	Ульяновская область, Ульяновск, Новосондецкий бульвар, 14	f	\N
128115	7821	820	Ульяновская область, Ульяновск, Новосондецкий бульвар, 14	f	\N
128113	7820	818	Ульяновская область, Ульяновск, Новосондецкий бульвар, 20	f	\N
128114	7820	819	Ульяновская область, Ульяновск, Новосондецкий бульвар, 20	f	\N
128109	7819	815	Ульяновская область, Ульяновск, Новосондецкий бульвар, 13	f	\N
128111	7819	816	Ульяновская область, Ульяновск, Новосондецкий бульвар, 13	f	\N
128112	7819	817	Ульяновская область, Ульяновск, Новосондецкий бульвар, 13	f	\N
78534	7818	813	Ульяновская область, Ульяновск, Новосондецкий бульвар, 3	f	large
78535	7818	814	Ульяновская область, Ульяновск, Новосондецкий бульвар, 3	f	large
78471	7768	741	Ульяновская область, Ульяновск, Набережная реки Свияги, 106	f	large
128141	7867	937	Ульяновская область, Ульяновск, Московское шоссе, 1, адм. здание ОАО ДЭП-148	f	small
78518	7807	793	Ульяновская область, Ульяновск, Московская, 5а	f	large
78686	7897	973	Ульяновская область, Ульяновск, Минаева, 50	f	large
78514	7804	789	Ульяновская область, Ульяновск, Мелекесская улица, 4	f	large
78664	7879	949	Ульяновская область, Ульяновск, Любови Шевцовой, 55	f	large
78663	7878	948	Ульяновская область, Ульяновск, Любови Шевцовой, 57	f	large
128134	7830	842	Ульяновская область, Ульяновск, Львовский бульвар, 10	f	\N
128135	7830	843	Ульяновская область, Ульяновск, Львовский бульвар, 10	f	\N
128136	7830	844	Ульяновская область, Ульяновск, Львовский бульвар, 10	f	\N
128133	7826	841	Ульяновская область, Ульяновск, Львовский бульвар, 10а	f	\N
128132	7826	840	Ульяновская область, Ульяновск, Львовский бульвар, 10а	f	\N
78690	7900	977	Ульяновская область, Ульяновск, Льва Толстого, 10	f	large
78689	7899	976	Ульяновская область, Ульяновск, Льва Толстого, 37	f	large
78685	7896	972	Ульяновская область, Ульяновск, Льва Толстого, 97	f	large
78475	7771	745	Ульяновская область, Ульяновск, Локомотивная улица, 87	f	large
78474	7771	744	Ульяновская область, Ульяновск, Локомотивная улица, 87	f	large
78699	7904	986	Ульяновская область, Ульяновск, Лесная, 12	f	large
78698	7904	985	Ульяновская область, Ульяновск, Лесная, 12	f	large
78697	7904	984	Ульяновская область, Ульяновск, Лесная, 12	f	large
78467	7765	737	Ульяновская область, Ульяновск, Куйбышева, 3	f	large
78466	7764	736	Ульяновская область, Ульяновск, Куйбышева, 4	f	large
78692	7901	979	Ульяновская область, Ульяновск, Крымова, 69	f	large
78691	7901	978	Ульяновская область, Ульяновск, Крымова, 69	f	large
128025	7626	589	Ульяновская область, Ульяновск, Красноармейский переулок, 1	f	medium
78626	7857	907	Ульяновская область, Ульяновск, Корунковой, 6	f	large
78625	7857	906	Ульяновская область, Ульяновск, Корунковой, 6	f	large
78624	7857	905	Ульяновская область, Ульяновск, Корунковой, 6	f	large
78623	7857	904	Ульяновская область, Ульяновск, Корунковой, 6	f	large
128099	7783	762	Ульяновская область, Ульяновск, Кольцевая улица, 12	f	\N
78493	7783	763	Ульяновская область, Ульяновск, Кольцевая улица, 12	f	large
78491	7782	761	Ульяновская область, Ульяновск, Кольцевая улица, 32	f	large
78490	7782	760	Ульяновская область, Ульяновск, Кольцевая улица, 32	f	large
128131	7828	839	Ульяновская область, Ульяновск, Карбышева, 36	f	\N
128130	7828	838	Ульяновская область, Ульяновск, Карбышева, 36	f	\N
128129	7828	837	Ульяновская область, Ульяновск, Карбышева, 36	f	\N
128128	7828	836	Ульяновская область, Ульяновск, Карбышева, 36	f	\N
128126	7827	834	Ульяновская область, Ульяновск, Карбышева, 26	f	\N
128127	7827	835	Ульяновская область, Ульяновск, Карбышева, 26	f	\N
128120	7824	827	Ульяновская область, Ульяновск, Карбышева, 2	f	\N
128122	7824	829	Ульяновская область, Ульяновск, Карбышева, 2	f	\N
128121	7824	828	Ульяновская область, Ульяновск, Карбышева, 2	f	\N
128119	7824	826	Ульяновская область, Ульяновск, Карбышева, 2	f	\N
78550	7824	830	Ульяновская область, Ульяновск, Карбышева, 2	f	large
78633	7860	914	Ульяновская область, Ульяновск, Камышинская улица, 51	f	large
78632	7860	913	Ульяновская область, Ульяновск, Камышинская улица, 51	f	large
78631	7860	912	Ульяновская область, Ульяновск, Камышинская улица, 51	f	large
78630	7860	911	Ульяновская область, Ульяновск, Камышинская улица, 51	f	large
78638	7862	919	Ульяновская область, Ульяновск, Камышинская, 28	f	large
78637	7862	918	Ульяновская область, Ульяновск, Камышинская, 28	f	large
78636	7862	917	Ульяновская область, Ульяновск, Камышинская, 28	f	large
78635	7861	916	Ульяновская область, Ульяновск, Камышинская, 32	f	large
78634	7861	915	Ульяновская область, Ульяновск, Камышинская, 32	f	large
78505	7797	780	Ульяновская область, Ульяновск, Калнина, 1	f	large
78702	7907	989	Ульяновская область, Ульяновск, Ипподромная, 11	f	large
78501	7793	776	Ульяновская область, Ульяновск, Заречная, 24	f	large
78500	7793	775	Ульяновская область, Ульяновск, Заречная, 24	f	large
78595	7845	876	Ульяновская область, Ульяновск, Западный бульвар, 20а	f	large
78594	7845	875	Ульяновская область, Ульяновск, Западный бульвар, 20а	f	large
78593	7845	874	Ульяновская область, Ульяновск, Западный бульвар, 20а	f	large
78591	7842	871	Ульяновская область, Ульяновск, Западный бульвар, 12	f	large
78590	7842	870	Ульяновская область, Ульяновск, Западный бульвар, 12	f	large
78502	7794	777	Ульяновская область, Ульяновск, Заводской проезд, 27а	f	large
78703	7908	990	Ульяновская область, Ульяновск, Дорожная, 4	f	large
78598	7846	879	Ульяновская область, Ульяновск, Доватора, 15	f	large
78597	7846	878	Ульяновская область, Ульяновск, Доватора, 15	f	large
78596	7846	877	Ульяновская область, Ульяновск, Доватора, 15	f	large
78511	7802	786	Ульяновская область, Ульяновск, Димитрова, 7	f	large
78510	7801	785	Ульяновская область, Ульяновск, Гоголя, 40	f	large
78483	7777	753	Ульяновская область, Ульяновск, Героев Свири, 12	f	large
78482	7776	752	Ульяновская область, Ульяновск, Героев Свири, 12	f	large
78481	7776	751	Ульяновская область, Ульяновск, Героев Свири, 12	f	large
78657	7869	939	Ульяновская область, Ульяновск, Герасимова, 6А	f	large
78499	7792	774	Ульяновская область, Ульяновск, Вольная, 6	f	large
78498	7792	773	Ульяновская область, Ульяновск, Вольная, 6	f	large
78696	7903	983	Ульяновская область, Ульяновск, Верхнеполевая, 3	f	large
78695	7903	982	Ульяновская область, Ульяновск, Верхнеполевая, 3	f	large
78694	7903	981	Ульяновская область, Ульяновск, Верхнеполевая, 3	f	large
128147	7886	956	Ульяновская область, Ульяновск, Архитектора Шодэ, 6	f	\N
78574	7832	854	Ульяновская область, Ульяновск, Артема, 8	f	large
78573	7832	853	Ульяновская область, Ульяновск, Артема, 8	f	large
78572	7832	852	Ульяновская область, Ульяновск, Артема, 8	f	large
78571	7832	851	Ульяновская область, Ульяновск, Артема, 8	f	large
78495	7784	765	Ульяновская область, Ульяновск, Амурская, 10	f	large
78494	7784	764	Ульяновская область, Ульяновск, Амурская, 10	f	large
78602	7849	883	Ульяновская область, Ульяновск, Александра Невского, 2а	f	large
78601	7849	882	Ульяновская область, Ульяновск, Александра Невского, 2а	f	large
78687	7898	974	Ульяновская область, Ульяновск, Александра Матросова, 11	f	large
78688	7898	975	Ульяновская область, Ульяновск, Александра Матросова, 11	f	large
78509	7800	784	Ульяновская область, Ульяновск, Академика Павлова, 20	f	large
78578	7835	858	Ульяновская область, Ульяновск, Аблукова, 23	f	large
78577	7835	857	Ульяновская область, Ульяновск, Аблукова, 23	f	large
78576	7834	856	Ульяновская область, Ульяновск, Аблукова, 31	f	large
78468	7766	738	Ульяновская область, Ульяновск, 12 Сентября, 81	f	large
78504	7796	779	Ульяновская область, Ульяновск, 1-я Линия, 5	f	large
78586	7840	866	Ульяновская область, Ульяновск, Терешковой, 22	f	large
78587	7840	867	Ульяновская область, Ульяновск, Терешковой, 22	f	large
78585	7840	865	Ульяновская область, Ульяновск, Терешковой, 22	f	large
78606	7851	887	Ульяновская область, Ульяновск, Стасова, 16	f	large
78605	7851	886	Ульяновская область, Ульяновск, Стасова, 16	f	large
78604	7851	885	Ульяновская область, Ульяновск, Стасова, 16	f	large
128117	7822	824	Ульяновская область, Ульяновск, улица 40-летия Победы, 3	f	\N
128118	7822	825	Ульяновская область, Ульяновск, улица 40-летия Победы, 3	f	\N
128029	7632	595	Ульяновская область, поселок Лаишевка, Центральная улица, 12	t	small
78403	7697	659	Ульяновская область, поселок Колхозный, Центральная, 5	f	large
78387	7615	577	Ульяновская область, поселок Ишеевка, Ленина, 35	f	large
78452	7744	715	Ульяновская область, Димитровград	f	large
78418	7681	680	Ульяновская область, Димитровград	f	large
78419	7681	681	Ульяновская область, Димитровград	f	large
78413	7714	675	Ульяновская область, Димитровград, пр. Ленина, 17	f	large
78411	7712	673	Ульяновская область, Димитровград, пр. Дмитрова, 4	f	large
78417	7718	679	Ульяновская область, Димитровград, пр. Димитрова, 14	f	large
78416	7717	678	Ульяновская область, Димитровград, Терешковой, 2	f	large
78427	7724	689	Ульяновская область, Димитровград, Строителей, 15	f	large
78453	7745	716	Ульяновская область, Димитровград, Рабочая, 2	f	large
78447	7742	710	Ульяновская область, Димитровград, Победы, 18а	f	large
78451	7742	714	Ульяновская область, Димитровград, Победы, 18а	f	large
78449	7742	712	Ульяновская область, Димитровград, Победы, 18а	f	large
78442	7736	704	Ульяновская область, Димитровград, Московская, 73	f	large
78441	7736	703	Ульяновская область, Димитровград, Московская, 73	f	large
78436	7732	698	Ульяновская область, Димитровград, Мелекесская, 37а	f	large
78421	7604	683	Ульяновская область, Димитровград, М.Тореза, 4а	f	large
78420	7501	682	Ульяновская область, Димитровград, М.Тореза, 4	f	large
78431	7728	693	Ульяновская область, Димитровград, Луговая, 40	f	large
128091	7738	706	Ульяновская область, Димитровград, Ленинградская, 54а	f	medium
78422	7719	684	Ульяновская область, Димитровград, Ленина, 45	f	large
78414	7715	676	Ульяновская область, Димитровград, Курчатова, 8	f	large
134943	95171	697	Ульяновская область, Димитровград, Куйбышева, 241, МБУК «Центр искусств» Кабинет I этаж	f	large
78454	7746	717	Ульяновская область, Димитровград, Куйбышева, 144	f	large
78432	7729	694	Ульяновская область, Димитровград, Куйбышева, 294	f	large
78433	7726	695	Ульяновская область, Димитровград, Куйбышева, 258	f	large
78429	7726	691	Ульяновская область, Димитровград, Куйбышева, 258	f	large
78443	7737	705	Ульяновская область, Димитровград, Крымская, 96	f	large
78415	7716	677	Ульяновская область, Димитровград, Королева, 1	f	large
78446	7741	709	Ульяновская область, Димитровград, Западная, 9	f	large
78448	7741	711	Ульяновская область, Димитровград, Западная, 9	f	large
78412	7713	674	Ульяновская область, Димитровград, Гончарова, 8	f	large
78428	7725	690	Ульяновская область, Димитровград, Гвардейская, 15	f	large
78426	7723	688	Ульяновская область, Димитровград, Гвардейская, 43	f	large
78424	7721	686	Ульяновская область, Димитровград, Гвардейская, 47	f	large
78423	7720	685	Ульяновская область, Димитровград, Гвардейская, 30	f	large
78457	7749	720	Ульяновская область, Димитровград, Гагарина, 19	f	large
78459	7750	722	Ульяновская область, Димитровград, Восточная, 32	f	large
78458	7750	721	Ульяновская область, Димитровград, Восточная, 32	f	large
134942	95170	692	Ульяновская область, Димитровград, Вокзальная, 28	f	large
78425	7722	687	Ульяновская область, Димитровград, Братская, 50	f	large
134945	95173	719	Ульяновская область, Димитровград, Баданова, 77	f	large
78450	7743	713	Ульяновская область, Димитровград, Автостроителей, 22	f	large
78445	7740	708	Ульяновская область, Димитровград, Автостроителей, 47	f	large
78444	7739	707	Ульяновская область, Димитровград, Автостроителей, 32	f	large
78440	7735	702	Ульяновская область, Димитровград, Автостроителей, 65	f	large
134944	95172	718	Ульяновская область, Димитровград, III Интернационала, 74, МУК Димитровградский драматический театр им.А.Н.Островского Фойе, I этаж	f	large
78437	7733	699	Ульяновская область, Димитровград, 9-ая Линия, 15	f	large
78434	7730	696	Ульяновская область, Димитровград, 3-го Интернационала, 146	f	large
78410	7711	672	Ульяновская область, Димитровград, пр. Димитрова, 5	f	large
78439	7734	701	Ульяновская область, Димитровград, Октябрьская, 74	f	large
78438	7734	700	Ульяновская область, Димитровград, Октябрьская, 74	f	large
127566	7062	32	Ульяновская область, Барыш, Фабричная, 14	f	medium
78295	7057	27	Ульяновская область, Барыш, Фабричная, 57	f	large
127561	7055	25	Ульяновская область, Барыш, Строителей, 9А	f	medium
127565	7060	30	Ульяновская область, Барыш, Степана Разина, 25	f	medium
127564	7059	29	Ульяновская область, Барыш, Льва Толстого, 47	f	medium
78297	7063	33	Ульяновская область, Барыш, Луначарского, 4	f	large
78296	7061	31	Ульяновская область, Барыш, Ленина, 70	f	large
78293	7053	23	Ульяновская область, Барыш, Красноармейская, 45	f	large
78292	7052	22	Ульяновская область, Барыш, Красноармейская, 34А	f	large
78298	7064	34	Ульяновская область, Барыш, Калинина, 1А	f	large
127563	7058	28	Ульяновская область, Барыш, Бебеля, 17	f	medium
78294	7054	24	Ульяновская область, Барыш, 45 Стрелковой Дивизии, 26	f	large
128083	7695	657	Ульяновская область, Чердаклинский район, село Чувашский Калмаюр, Советская, 37А	f	medium
78400	7680	642	Ульяновская область, Чердаклинский район, поселок Чердаклы, Советская, 2	f	large
78402	7682	644	Ульяновская область, Чердаклинский район, поселок Чердаклы, Неверова, 1	f	large
78401	7669	643	Ульяновская область, Чердаклинский район, поселок Чердаклы, 50 лет ВЛКСМ, 12	f	large
128084	7696	658	Ульяновская область, Чердаклинский район, село Уразгильдино, Школьная, 27	f	medium
128073	7685	647	Ульяновская область, Чердаклинский район, село Суходол, Школьная	f	medium
128072	7684	646	Ульяновская область, Чердаклинский район, село Старый Белый Яр, Школьная, 24	f	medium
128087	7705	666	Ульяновская область, Чердаклинский район, село Старое Уренбаш, Центральная, 54	f	small
128076	7688	650	Ульяновская область, Чердаклинский район, село Старое Матюшкино, Центральная, 3	f	small
128080	7692	654	Ульяновская область, Чердаклинский район, село Старое Еремкино, Центральная, 8А	f	small
128079	7691	653	Ульяновская область, Чердаклинский район, село Станция Бряндино, Школьная, 37А	f	small
128078	7690	652	Ульяновская область, Чердаклинский район, село Станция Бряндино, Школьная, 20	f	small
128089	7709	670	Ульяновская область, Чердаклинский район, село Пятисотенный, переулок Садовый, 9	f	medium
128082	7694	656	Ульяновская область, Чердаклинский район, село Поповка, Центральная, 74	f	medium
128075	7687	649	Ульяновская область, Чердаклинский район, село Петровское, Центральная, 72	f	small
128088	7708	669	Ульяновская область, Чердаклинский район, село Первомайский, Первомайская, 1	f	medium
78409	7707	668	Ульяновская область, Чердаклинский район, поселок Октябрьский, Студенческая, 3	f	large
78408	7706	667	Ульяновская область, Чердаклинский район, поселок Октябрьский, Ленина, 21	f	large
78407	7703	665	Ульяновская область, Чердаклинский район, село Озерки, Центральная, 3	f	large
128071	7683	645	Ульяновская область, Чердаклинский район, село Новый Белый Яр, Пролетарская, 26	f	medium
78406	7701	663	Ульяновская область, Чердаклинский район, село Мирный, Молодежная, 2А	f	large
128086	7702	664	Ульяновская область, Чердаклинский район, село Малаевка, Центральная, 37	f	small
78404	7699	661	Ульяновская область, Чердаклинский район, село Крестово-Городище, Ленина, 56А	f	\N
128085	7698	660	Ульяновская область, Чердаклинский район, село Красный Яр, Пионерская, 31	f	medium
128069	7678	640	Ульяновская область, Чердаклинский район, село Енганаево, Первая, 2А	f	medium
128074	7686	648	Ульяновская область, Чердаклинский район, село Богдашкино, Лидии Бернт , 5	f	small
78405	7700	662	Ульяновская область, Чердаклинский район, село Архангельское, 50 лет Победы, 36	f	large
128081	7693	655	Ульяновская область, Чердаклинский район, село Андреевка, Дружбы, 47	f	medium
128077	7689	651	Ульяновская область, Чердаклинский район, село Абдулово, Школьная, 1	f	small
128065	7674	636	Ульяновская область, Цильнинский район, село Чириково, Плетневская, 6	f	small
128039	7644	607	Ульяновская область, Цильнинский район, поселок Цильна, Станционная, 1	f	medium
78396	7643	606	Ульяновская область, Цильнинский район, поселок Цильна, О.Кошевого, 4	f	large
128064	7673	635	Ульяновская область, Цильнинский район, село Устеренка, Зеленая, 3	f	small
128063	7672	634	Ульяновская область, Цильнинский район, село Тимофеевка, Тимофеевская, 6А	f	small
128038	7642	605	Ульяновская область, Цильнинский район, село Телешовка, переулок Школьный, 7	f	small
128060	7668	631	Ульяновская область, Цильнинский район, село Сухая Бугурна, Пролетарская, 16	f	small
128044	7650	613	Ульяновская область, Цильнинский район, село Степное Анненково, Пионерская, 3	f	medium
78397	7648	611	Ульяновская область, Цильнинский район, село Старые Алгаши, Советская, 7	f	large
128042	7647	610	Ульяновская область, Цильнинский район, село Средний Алгаши, Школьная, 22	f	small
128068	7677	639	Ульяновская область, Цильнинский район, село Средние Тимерсяны, Школьная, 1 А	f	medium
128052	7660	623	Ульяновская область, Цильнинский район, село Солнце, начальная школа	f	small
128051	7659	622	Ульяновская область, Цильнинский район, село Садки, начальная школа	f	small
128059	7667	630	Ульяновская область, Цильнинский район, село Русская Цильна, Советская, 10	f	small
128058	7666	629	Ульяновская область, Цильнинский район, село Покровское, Советская, 14	f	small
128043	7649	612	Ульяновская область, Цильнинский район, село Пилюгино, Красная горка , 22	f	small
128050	7658	621	Ульяновская область, Цильнинский район, село Орловка, Молодёжная, 5	f	\N
128048	7656	619	Ульяновская область, Цильнинский район, село Норовка, Молодёжная, 16А	f	\N
128049	7657	620	Ульяновская область, Цильнинский район, село Новые Тимерсяны, Кооперативная, 14	f	small
128041	7646	609	Ульяновская область, Цильнинский район, село Новые Алгаши, Школьная, 42	f	medium
128062	7671	633	Ульяновская область, Цильнинский район, село Новое Никулино, Школьная, 5	f	medium
128047	7655	618	Ульяновская область, Цильнинский район, село Новая Воля, начальная школа	f	small
128067	7676	638	Ульяновская область, Цильнинский район, село Нижние Тимерсяны, Центральная, 12	f	medium
128057	7665	628	Ульяновская область, Цильнинский район, село Мокрая Бугурна, Суркова, 5	f	small
128046	7654	617	Ульяновская область, Цильнинский район, село Малое Нагаткино, Ликино, 3	f	\N
128055	7663	626	Ульяновская область, Цильнинский район, село Кундрюковка, Школьная, 18	f	small
128045	7653	616	Ульяновская область, Цильнинский район, село Крестниково, Церковная, 7	f	small
128061	7670	632	Ульяновская область, Цильнинский район, село Карабаевка, Школьная, 1	f	small
128054	7662	625	Ульяновская область, Цильнинский район, село Кайсарово, Центральная, 42	f	\N
128053	7661	624	Ульяновская область, Цильнинский район, село Елховое Озеро, Колхозная, 115	f	medium
128066	7675	637	Ульяновская область, Цильнинский район, село Верхний Тимерсяны, Пролетарская, 16	f	medium
78398	7651	614	Ульяновская область, Цильнинский район, село Большое Нагаткино, площадь Революции, 1	f	large
78399	7652	615	Ульяновская область, Цильнинский район, село Большое Нагаткино, Садовая, 7	f	large
128056	7664	627	Ульяновская область, Цильнинский район, село Богородская Репьевка, Труда, 20	f	small
128040	7645	608	Ульяновская область, Цильнинский район, село Богдашкино, Ленина, 3	f	medium
128037	7641	604	Ульяновская область, Цильнинский район, село Арбузовка, Свияжская, 31	f	small
78390	7618	581	Ульяновская область, Ульяновский район, село разъезд Большие Ключищи, Каштанкина, 17	f	large
78391	7619	582	Ульяновская область, Ульяновский район, село разъезд Большие Ключищи, Димитрова, 48	f	large
78394	7630	593	Ульяновская область, Ульяновский район, п. Тимирязевский, капитана Каравашкина, СДК	f	large
128031	7634	597	Ульяновская область, Ульяновский район, село Шумовка, Победы, 3а	f	medium
128033	7637	600	Ульяновская область, Ульяновский район, село Ундоры, санаторий имени В.И.Ленина, лечебный корпус	f	\N
128032	7636	599	Ульяновская область, Ульяновский район, село Ундоры, санаторий Дубки, библиотека	f	\N
78395	7635	598	Ульяновская область, Ульяновский район, село Ундоры, Мира, 21а	f	large
78389	7299	579	Ульяновская область, Ульяновский район, село Салмановка, Победы, 22а	f	large
128035	7639	602	Ульяновская область, Ульяновский район, село Русская Беденьга, ООО Хлебороб	f	small
128020	7620	583	Ульяновская область, Ульяновский район, село Поникий Ключ, Лесная, 1	f	small
128096	7760	732	Ульяновская область, Ульяновский район, село Панская Слобода, Ленина, 28	f	small
128024	7625	588	Ульяновская область, Ульяновский район, село Охотничья, переулок Школьный, 10	f	medium
128028	7631	594	Ульяновская область, Ульяновский район, село Новый Урень, Школьная, 23	f	medium
128019	7617	580	Ульяновская область, Ульяновский район, село Новая Беденьга, Центральная, 24	f	medium
128097	7762	734	Ульяновская область, Ульяновский район, поселок Меловой, Школьная, 18	f	medium
128021	7621	584	Ульяновская область, Ульяновский район, село Ломы, Красный уголок ПСК Красная Звезда	t	small
128095	7759	731	Ульяновская область, Ульяновский район, село Липки, Ленина, 17	f	medium
128034	7638	601	Ульяновская область, Ульяновский район, село Крутояр, МУ Межпоселенческая библиотека	f	small
78465	7761	733	Ульяновская область, Ульяновский район, поселок Криуши, Полевая, 5	f	large
128023	7624	587	Ульяновская область, Ульяновский район, село Ивановка, Школьная, 20	f	small
78392	7623	586	Ульяновская область, Ульяновский район, село Зеленая Роща, Лесная, 8	f	large
128027	7629	592	Ульяновская область, Ульяновский район, село Загудаевка, Школьная, 6	t	small
128022	7622	585	Ульяновская область, Ульяновский район, село Елшанка, Набережная, 23	f	medium
127916	7495	460	Ульяновская область, Ульяновский район, село Екатериновка, Новая Линия, 20	t	small
128036	7640	603	Ульяновская область, Ульяновский район, село Вышки, Колхозная, 1	f	medium
128026	7628	591	Ульяновская область, Ульяновский район, село Волостниковка	t	small
128030	7633	596	Ульяновская область, Ульяновский район, село Бирючевка, Школьная, 4	f	medium
128142	7871	941	Ульяновская область, Ульяновский район, село Арское, Школьная, 2А	f	small
128143	7872	942	Ульяновская область, Ульяновск городской округ, село Отрада, Мира, средняя школа	f	medium
78462	7754	726	Ульяновская область, Ульяновск городской округ, Новоульяновск, Ульяновская, 5	f	large
78461	7753	725	Ульяновская область, Ульяновск городской округ, Новоульяновск, Мира, 10	f	large
128094	7758	730	Ульяновская область, Ульяновск городской округ, Новоульяновск, Кременская, 12	f	medium
78463	7755	727	Ульяновская область, Ульяновск городской округ, Новоульяновск, Комсомольская, 31	f	large
78460	7752	724	Ульяновская область, Ульяновск городской округ, Новоульяновск, Комсомольская, 2А	f	large
128093	7756	729	Ульяновская область, Ульяновск городской округ, Новоульяновск, Заводская, 13	f	small
78464	7756	728	Ульяновская область, Ульяновск городской округ, Новоульяновск, Заводская, 13	f	large
78658	7870	940	Ульяновская область, Ульяновск городской округ, село Кротовка, Центральная, 6А	f	large
128017	7611	573	Ульяновская область, Тереньгульский район, село Ясашная Ташла, Центральная, 12	f	medium
128016	7610	572	Ульяновская область, Тереньгульский район, село Ясашная Ташла, Ленина, 86а	f	medium
127998	7590	553	Ульяновская область, Тереньгульский район, село Федькино	t	small
127997	7589	552	Ульяновская область, Тереньгульский район, село Тумкино, здание общеобразовательной школы	f	medium
78381	7586	549	Ульяновская область, Тереньгульский район, поселок Тереньга, площадь Ленина, 1	f	large
78382	7587	550	Ульяновская область, Тереньгульский район, поселок Тереньга, Евстифеева, 5	f	large
78383	7588	551	Ульяновская область, Тереньгульский район, поселок Тереньга, Булыгина, 10, средняя школа	f	large
128015	7608	570	Ульяновская область, Тереньгульский район, село Суровка, Ряская, 3	f	small
128004	7597	559	Ульяновская область, Тереньгульский район, село Сосновка	f	small
78384	7609	571	Ульяновская область, Тереньгульский район, село Солдатская Ташла	f	large
128014	7607	569	Ульяновская область, Тереньгульский район, село Скугареевка, библиотека	f	small
128013	7606	568	Ульяновская область, Тереньгульский район, село Подкуровка, здание общеобразовательной школы	f	medium
127999	7591	554	Ульяновская область, Тереньгульский район, село Назайкино	f	small
128002	7595	557	Ульяновская область, Тереньгульский район, село Молвино, Контора Молвинского лесничества	f	small
128009	7602	564	Ульяновская область, Тереньгульский район, село Михайловка, здание средней школы	f	small
128007	7600	562	Ульяновская область, Тереньгульский район, село Красноборск, здание средней школы	f	medium
128012	7605	567	Ульяновская область, Тереньгульский район, село Калиновка	t	small
128008	7601	563	Ульяновская область, Тереньгульский район, село Зеленец, здание средней школы	f	small
128010	7603	565	Ульяновская область, Тереньгульский район, село Елшанка	t	small
128000	7592	555	Ульяновская область, Тереньгульский район, село Гладчиха	f	small
128011	7581	566	Ульяновская область, Тереньгульский район, село Гавриловка	f	small
128005	7598	560	Ульяновская область, Тереньгульский район, село Большая Борла	f	small
128003	7596	558	Ульяновская область, Тереньгульский район, село Белогорское	f	small
128001	7594	556	Ульяновская область, Тереньгульский район, село Байдулино, здание общеобразовательной школы	f	small
128006	7599	561	Ульяновская область, Тереньгульский район, село Алешкино	t	small
127993	7582	545	Ульяновская область, Сурский район, село Шатрашаны, пер. Школьный, 4	f	small
127994	7583	546	Ульяновская область, Сурский район, село Шатрашаны, Первомайская, 2	f	small
127990	7579	542	Ульяновская область, Сурский район, село Чирково, Гора, 14	f	small
127996	7585	548	Ульяновская область, Сурский район, село Чеботаевка, Центральная, 1а	f	small
127989	7578	541	Ульяновская область, Сурский район, село Хмелевка, Школьная, 16	t	\N
127988	7577	540	Ульяновская область, Сурский район, село Хмелевка, Школьная, 1А	f	\N
127980	7568	532	Ульяновская область, Сурский район, поселок Сурское, Юбилейная, 3	t	small
78380	7567	531	Ульяновская область, Сурский район, поселок Сурское, Энгельса, 63	f	large
127984	7573	536	Ульяновская область, Сурский район, поселок Сурское, Центральная, 52	t	\N
78378	7564	528	Ульяновская область, Сурский район, поселок Сурское, Хазова, 21	f	large
78379	7565	529	Ульяновская область, Сурский район, поселок Сурское, Советская, 27	f	large
127979	7566	530	Ульяновская область, Сурский район, поселок Сурское, Промышленная, 8	f	\N
127985	7574	537	Ульяновская область, Сурский район, поселок Сурское, Ленина, 21, квартира 3 	f	small
127981	7569	533	Ульяновская область, Сурский район, поселок Сурское, Зеленая, 4	f	\N
127977	7562	526	Ульяновская область, Сурский район, село Сара, Советская, 1	f	small
127976	7561	525	Ульяновская область, Сурский район, село Сара, Комсомольская, 14	t	medium
127970	7555	519	Ульяновская область, Сурский район, село Ружеевщино, Мира, 7	t	small
71605	81037	1686	Самарская область, Тольятти, Мира, 158	f	large
127965	7550	514	Ульяновская область, Сурский район, село Паркино, пер. Центральный, 3	f	small
127972	7557	521	Ульяновская область, Сурский район, село Никитино, Линёвка, 37	f	\N
127967	7552	516	Ульяновская область, Сурский район, село Лава, Садовая, 3	f	\N
127969	7554	518	Ульяновская область, Сурский район, село Красная Якла, Мира, 44	f	small
127986	7575	538	Ульяновская область, Сурский район, село Княжуха, Большая дорога, 8	f	small
127982	7571	534	Ульяновская область, Сурский район, село Кирзять, Центральная, 50	t	small
127991	7580	543	Ульяновская область, Сурский район, село Ждамирово, Ленина, 32	t	\N
127992	7570	544	Ульяновская область, Сурский район, село Ждамирово, Красная площадь , 21	f	\N
127975	7560	524	Ульяновская область, Сурский район, село Елховка, Центральная, 14	t	small
127983	7572	535	Ульяновская область, Сурский район, село Гулюшево, Ягодная, 19	t	small
127973	7558	522	Ульяновская область, Сурский район, село Выползово, Проулок, 99	t	small
127974	7559	523	Ульяновская область, Сурский район, село Выползово, Московская, 25	f	small
127964	7549	513	Ульяновская область, Сурский район, село Большой Кувай, Московская, 16	f	small
127963	7537	512	Ульяновская область, Сурский район, село Большой Кувай, Волкова, 30	f	small
127968	7553	517	Ульяновская область, Сурский район, село Белый Ключ, Садовая, 4	t	small
127978	7563	527	Ульяновская область, Сурский район, село Барышская Слобода, Кирова, 9	f	small
127962	7548	511	Ульяновская область, Сурский район, село Астрадамовка, Центральная, 21	t	small
127961	7547	510	Ульяновская область, Сурский район, село Астрадамовка, Линия, 18	t	small
127960	7546	509	Ульяновская область, Сурский район, село Астрадамовка, Красная площадь, 26	f	medium
127995	7584	547	Ульяновская область, Сурский район, село Архангельское, Центральная, 1	t	\N
127987	7576	539	Ульяновская область, Сурский район, село Араповка, переулок Школьный, 2	t	small
127966	7551	515	Ульяновская область, Сурский район, село Алейкино, Садовая, 3	t	small
127959	7545	508	Ульяновская область, Старомайнский район, село Ясашное Помряскино, Пушкина, 1	f	small
127948	7533	497	Ульяновская область, Старомайнский район, село Шмелевка, переулок Школьный, 7	f	small
127958	7544	507	Ульяновская область, Старомайнский район, село Татарское Урайкино, Кооперативная, 104	f	small
127957	7543	506	Ульяновская область, Старомайнский район, село Старое Рождествено, Советская, 48	t	small
78376	7521	485	Ульяновская область, Старомайнский район, поселок Старая Майна, Площадь Ленина, 2	f	large
134941	95169	486	Ульяновская область, Старомайнский район, поселок Старая Майна, Льва Толстого, 97	f	large
78375	7520	484	Ульяновская область, Старомайнский район, поселок Старая Майна, Комсомольская, 37	f	large
127951	7536	500	Ульяновская область, Старомайнский район, село Русский Юрткуль, Школьная, 10	f	small
127943	7528	492	Ульяновская область, Старомайнский район, село Прибрежное, Советская, 2	f	medium
127942	7527	491	Ульяновская область, Старомайнский район, село Новиковка, Придорожная, 1	f	small
127947	7532	496	Ульяновская область, Старомайнский район, село Матвеевка, Матвеевская, 12	f	small
127954	7540	503	Ульяновская область, Старомайнский район, село Малая Кандала, Кооперативная, 5	t	\N
127956	7542	505	Ульяновская область, Старомайнский район, село Лесное-Никольское, Магистральная, 1	f	small
127953	7539	502	Ульяновская область, Старомайнский район, село Лесная Поляна, Парковая, 10	f	small
134587	94441	494	Ульяновская область, Старомайнский район, село Кременки, Дачная, 4	f	small
127941	7526	490	Ульяновская область, Старомайнский район, село Красная Река, Советская, 30	f	medium
127940	7525	489	Ульяновская область, Старомайнский район, село Жедяевка, Казанская, 1А	f	small
127955	7541	504	Ульяновская область, Старомайнский район, село Ертуганово, Школьная, 39	t	small
127946	7531	495	Ульяновская область, Старомайнский район, село Дмитриево-Помряскино, Школьная, 3	f	medium
127949	7534	498	Ульяновская область, Старомайнский район, село Грибовка, Центральная, 77А	f	small
127944	7529	493	Ульяновская область, Старомайнский район, село Восход, Снежная, 1	f	small
127939	7524	488	Ульяновская область, Старомайнский район, село Волостниковка, Центральная, 46	f	small
127727	7205	226	Ульяновская область, Майнский район, село Березовка	f	small
127952	7538	501	Ульяновская область, Старомайнский район, село Большая Кандала, Московская, 13	f	medium
127950	7535	499	Ульяновская область, Старомайнский район, село Базарно-Мордовский Юрткуль, Школьная, 59	f	small
127938	7523	487	Ульяновская область, Старомайнский район, село Арчиловка, Озаренная, 11	t	small
127924	7506	470	Ульяновская область, Старокулаткинский район, село Усть-Кулатка, Октябрьская, 58	f	small
127929	7511	475	Ульяновская область, Старокулаткинский район, село Старый Мостяк, Юбилейная, 16	f	medium
127931	7513	477	Ульяновская область, Старокулаткинский район, село Старый Атлаш, Ленина, 64	f	medium
127925	7507	471	Ульяновская область, Старокулаткинский район, село Старое Зеленое, Советская, 68	f	medium
127923	7505	469	Ульяновская область, Старокулаткинский район, село Старая Яндовка, Молодёжная, 18	f	small
78374	7499	464	Ульяновская область, Старокулаткинский район, поселок Старая Кулатка, Куйбышева, 51	f	large
78373	7498	463	Ульяновская область, Старокулаткинский район, поселок Старая Кулатка, Куйбышева, 20	f	large
127934	7516	480	Ульяновская область, Старокулаткинский район, село Средняя Терешка, М. Асадуллина, 250	f	medium
127930	7512	476	Ульяновская область, Старокулаткинский район, село Новый Мостяк, Просвещения, 11	f	small
127920	7502	466	Ульяновская область, Старокулаткинский район, село Новые Зимницы, Кузахметова, 5	f	medium
127928	7510	474	Ульяновская область, Старокулаткинский район, село Новое Зеленое, Советская, 51	f	small
127922	7504	468	Ульяновская область, Старокулаткинский район, село Новая Яндовка, Т. Рашитой , 30	t	small
127937	7519	483	Ульяновская область, Старокулаткинский район, село Новая Терешка, 4-х братьев Аксяновых, 46	f	small
127921	7503	467	Ульяновская область, Старокулаткинский район, село Новая Кулатка, Советская, 63	f	small
127933	7515	479	Ульяновская область, Старокулаткинский район, село Мосеевка, Советская, 51а	f	small
127936	7518	482	Ульяновская область, Старокулаткинский район, село Кирюшкино, Советская, 54	f	small
127932	7514	478	Ульяновская область, Старокулаткинский район, село Кармалей, Советская, 34	f	small
127927	7509	473	Ульяновская область, Старокулаткинский район, село Зарыклей, Г. Тукая, 1	f	small
127926	7508	472	Ульяновская область, Старокулаткинский район, село Вязовый Гай, Советская, 36	f	small
127935	7517	481	Ульяновская область, Старокулаткинский район, село Верхняя Терешка, Советская, 38	f	small
127919	7500	465	Ульяновская область, Старокулаткинский район, село Бахтеевка, Школьная, 1	f	medium
127918	7497	462	Ульяновская область, Сенгилеевский район, село Шиловка, Володарского, 17	f	medium
127917	7496	461	Ульяновская область, Сенгилеевский район, село Тушна, Центральная, 10	f	medium
78370	7480	446	Ульяновская область, Сенгилеевский район, поселок Силикатный, Садовая, 3	f	large
78369	7479	445	Ульяновская область, Сенгилеевский район, поселок Силикатный, Заводская, 3	f	large
78367	7477	442	Ульяновская область, Сенгилеевский район, Сенгилей, Чапаева, 29	f	large
127903	7474	439	Ульяновская область, Сенгилеевский район, Сенгилей, Октябрьская, 12	f	medium
78366	7476	441	Ульяновская область, Сенгилеевский район, Сенгилей, Новая Линия, 36	f	large
78368	7465	443	Ульяновская область, Сенгилеевский район, Сенгилей, Красноармейская, 86	f	large
78365	7475	440	Ульяновская область, Сенгилеевский район, Сенгилей, Колхозная, 1	f	large
127904	7478	444	Ульяновская область, Сенгилеевский район, поселок Сенгилеевский Цементный Завод 1 километр, Цементников, 4	f	medium
127913	7492	457	Ульяновская область, Сенгилеевский район, село Русская Бектяшка, Полевая, 66	f	small
127914	7493	458	Ульяновская область, Сенгилеевский район, село Мордово, Ленина, 34	t	small
127912	7491	456	Ульяновская область, Сенгилеевский район, село Кротково, Школьная, 11	f	small
78372	7482	448	Ульяновская область, Сенгилеевский район, поселок Красный Гуляй, переулок Пионерский, 6	f	large
78371	7481	447	Ульяновская область, Сенгилеевский район, поселок Красный Гуляй, Мира, 11	f	large
127908	7486	452	Ульяновская область, Сенгилеевский район, село Каранино, пер. Речной, 6	t	small
127910	7488	454	Ульяновская область, Сенгилеевский район, село Елаур, Крупской, 1	f	medium
127906	7484	450	Ульяновская область, Сенгилеевский район, село Вырыстайкино, Кооперативная, 21Б	f	small
127911	7490	455	Ульяновская область, Сенгилеевский район, село Бекетовка, Ленина, 65А	f	small
127915	7494	459	Ульяновская область, Сенгилеевский район, село Артюшкино, Советская, 33	f	medium
127905	7483	449	Ульяновская область, Сенгилеевский район, село Алешкино, Молодежная, 1	f	small
127901	7472	437	Ульяновская область, Радищевский район, село Шевченко, кабинет сельского клуба	t	small
127883	7452	418	Ульяновская область, Радищевский район, село Чауши, зал филиала МУ КДЦМ Спутник	f	small
127900	7471	436	Ульяновская область, Радищевский район, село Средниково, сельский клуб	t	small
127899	7470	435	Ульяновская область, Радищевский район, село Софьино, школа	f	small
127886	7455	421	Ульяновская область, Радищевский район, село Соловчиха, зал сельского Дома культуры	f	small
127892	7461	427	Ульяновская область, Радищевский район, село Рябина	t	small
78363	7446	412	Ульяновская область, Радищевский район, поселок Радищево, пл. 50 лет ВЛКСМ, 17, МУК Радищевский Дом культуры, танцевальный зал	f	large
127879	7448	414	Ульяновская область, Радищевский район, поселок Радищево, Свердлова, 15, МУО ДОД Детская школа искусств, танцевальный зал	f	medium
127880	7449	415	Ульяновская область, Радищевский район, поселок Радищево, Кооперативная, 29, МОУ Радищевская СОШ № 2	f	medium
127878	7447	413	Ульяновская область, Радищевский район, поселок Радищево, Заводская, 6, ОАО Гидравлик, кабинет специалистов	f	medium
127891	7460	426	Ульяновская область, Радищевский район, село Паньшино, сельский клуб 	t	small
127895	7466	431	Ульяновская область, Радищевский район, село Ореховка	f	medium
78364	7462	428	Ульяновская область, Радищевский район, село Октябрьский, зал МУК Центральный поселенческий Дом культуры	f	large
127882	7451	417	Ульяновская область, Радищевский район, село Новая Дмитриевка, филиал МУ КДЦМ Спутник	f	small
127894	7464	430	Ульяновская область, Радищевский район, село Нижняя Маза, кабинет начальной общеобразовательной школы	f	small
127898	7469	434	Ульяновская область, Радищевский район, село Мордовская Курагужа, фойе основной общеобразовательной школы	t	small
127890	7459	425	Ульяновская область, Радищевский район, село Кубра, зал сельского Дома культуры	t	small
127887	7456	422	Ульяновская область, Радищевский район, село Калиновка	f	medium
127884	7453	419	Ульяновская область, Радищевский район, село Дмитриевка, Центральный поселенческий Дом культуры, зал	f	small
127885	7454	420	Ульяновская область, Радищевский район, село Гремячий, зал сельского клуба 	t	small
127889	7458	424	Ульяновская область, Радищевский район, село Вязовка, зал сельского Дома культуры	f	small
127897	7468	433	Ульяновская область, Радищевский район, село Волчанка, кабинет начальной общеобразовательной школы	f	small
127896	7467	432	Ульяновская область, Радищевский район, село Володарский, зал сельского клуба	t	small
127888	7457	423	Ульяновская область, Радищевский район, село Вишневый, кабинет ФАПа	f	small
127893	7463	429	Ульяновская область, Радищевский район, село Верхняя Маза, зал сельского Дома культуры	f	medium
127881	7450	416	Ульяновская область, Радищевский район, село Адоевщина, начальная общеобразовательная школа, фойе	f	small
127875	7442	409	Ульяновская область, Павловский район, село Шиковка, Молодежная, 22	f	small
127872	7439	406	Ульяновская область, Павловский район, село Шаховское, Советская, 103	f	medium
127860	7426	394	Ульяновская область, Павловский район, село Шалкино, Центральная, 15	f	medium
127868	7435	402	Ульяновская область, Павловский район, село Холстовка, Центральная, 14/6	f	medium
134586	94440	410	Ульяновская область, Павловский район, село Татарский Шмалак, Центральная, 5, Татарско-Шмалакский центральный сельский Дом культуры, фойе	f	medium
127864	7431	398	Ульяновская область, Павловский район, село Старый Пичеур, Школьная, 1	f	small
127867	7434	401	Ульяновская область, Павловский район, село Старое Чирково, Заречная, 1	f	small
127863	7429	397	Ульяновская область, Павловский район, село Плетьма, Молодежная, 1	t	small
78362	7421	389	Ульяновская область, Павловский район, поселок Павловка, пл. Советская, 1	f	large
78361	7420	388	Ульяновская область, Павловский район, поселок Павловка, Школьная, 2	f	large
78360	7419	387	Ульяновская область, Павловский район, поселок Павловка, Калинина, 33	f	large
127871	7438	405	Ульяновская область, Павловский район, село Октябрьское, Центральная, 9	f	medium
127870	7437	404	Ульяновская область, Павловский район, село Новая Камаевка, Новая, 2	f	small
127874	7441	408	Ульяновская область, Павловский район, село Новая Андреевка, Садовая, 66	t	small
127866	7433	400	Ульяновская область, Павловский район, село Новая Алексеевка, Новая, 34	f	small
127862	7428	396	Ульяновская область, Павловский район, село Муратовка, Колхозная, 20	f	medium
127877	7445	411	Ульяновская область, Павловский район, село Мордовский Шмалак, Школьная, 63	f	small
127865	7432	399	Ульяновская область, Павловский район, село Лапаевка, Верхняя, 6	t	small
127859	7425	393	Ульяновская область, Павловский район, село Кадышевка, А.Новикова, 1	f	small
127858	7424	392	Ульяновская область, Павловский район, село Илюшкино, Саратовская, 20	f	small
127869	7436	403	Ульяновская область, Павловский район, село Ивановка, Вторая, 26	f	small
127857	7423	391	Ульяновская область, Павловский район, село Евлейка, Центральная, 46	f	small
127873	7440	407	Ульяновская область, Павловский район, село Гремучий, Луговая, 5	t	small
127861	7427	395	Ульяновская область, Павловский район, село Баклуши, Рабочая, 2	f	small
127855	7418	386	Ульяновская область, Новоспасский район, поселок Фабричные Выселки, Запрудная, 4	f	small
78359	7414	382	Ульяновская область, Новоспасский район, село Троицкий Сунгур, Троицкосунгурский КДЦ	f	large
127842	7403	371	Ульяновская область, Новоспасский район, село Суруловка, Сельский дом культуры	f	medium
127845	7406	374	Ульяновская область, Новоспасский район, село Старое Томышево, Школьная, 43 	f	small
127850	7412	380	Ульяновская область, Новоспасский район, село Свирино, Почтовая, 16	t	small
127853	7416	384	Ульяновская область, Новоспасский район, село Самайкино, Молодежная, 1	f	small
127849	7411	379	Ульяновская область, Новоспасский район, село Садовое, Школьная, 28	f	medium
127840	7326	369	Ульяновская область, Новоспасский район, село Рокотушка, Клуб	t	small
127847	7409	377	Ульяновская область, Новоспасский район, село Репьевка, Школьная, 67	f	medium
127854	7417	385	Ульяновская область, Новоспасский район, село Плодопитомник, Центральная, 21	f	small
78357	7399	365	Ульяновская область, Новоспасский район, поселок Новоспасское, площадь Макаренко, 1	f	large
127835	7395	361	Ульяновская область, Новоспасский район, поселок Новоспасское, Сельхозтехника, 5	f	medium
78355	7397	363	Ульяновская область, Новоспасский район, поселок Новоспасское, Мира, 23	f	\N
78354	7394	360	Ульяновская область, Новоспасский район, поселок Новоспасское, Кузнецкая, 104а	f	large
78356	7398	364	Ульяновская область, Новоспасский район, поселок Новоспасское, Горького, 11а	f	large
127836	7396	362	Ульяновская область, Новоспасский район, поселок Новоспасское, Горшенина, 15	f	small
127838	7401	367	Ульяновская область, Новоспасский район, поселок Новоспасское, Гагарина, 64	f	small
127841	7389	370	Ульяновская область, Новоспасский район, село Новое Томышево, Сельский дом культуры	t	small
127851	7413	381	Ульяновская область, Новоспасский район, село Новая Лава, Молодежная, 31	t	small
127839	7402	368	Ульяновская область, Новоспасский район, село Малая Андреевка, Сельский клуб	f	small
127846	7408	376	Ульяновская область, Новоспасский район, село Крупозавод, Центральная, 23	f	small
127848	7410	378	Ульяновская область, Новоспасский район, село Красный, Урожайная, 2	f	small
78358	7407	375	Ульяновская область, Новоспасский район, село Красносельск, Школьная, 13	f	large
127844	7405	373	Ульяновская область, Новоспасский район, село Коптевка, Ленина, 45а	f	medium
127852	7415	383	Ульяновская область, Новоспасский район, село Комаровка, Филиал МУК Троицкосунгурский КДЦ	t	small
127843	7404	372	Ульяновская область, Новоспасский район, село Алакаевка, Советская, 64	t	small
127825	7381	348	Ульяновская область, Новомалыклинский район, село Эчкаюн, Молодежная, 16	f	small
127830	7388	355	Ульяновская область, Новомалыклинский район, село Старый Сантимир, Центральная, 36	t	small
127827	7385	352	Ульяновская область, Новомалыклинский район, село Старая Тюгальбуга, Кооперативная, 37	f	medium
127834	7393	359	Ульяновская область, Новомалыклинский район, село Старая Малыкла, Центральная, 40	t	small
71604	81036	1685	Самарская область, Тольятти, Мира, 116	f	large
127823	7379	346	Ульяновская область, Новомалыклинский район, село Старая Куликовка, Совхозная, 21	f	small
127829	7387	354	Ульяновская область, Новомалыклинский район, село Старая Бесовка, Колхозная, 45	f	small
134938	95167	347	Ульяновская область, Новомалыклинский район, село Станция Якушка, Кооперативная улица, 8, Дом культуры	f	small
127833	7392	358	Ульяновская область, Новомалыклинский район, село Средняя Якушка, Октябрьская, 15А	f	medium
127828	7386	353	Ульяновская область, Новомалыклинский район, село Средний Сантимир, Школьная, 1	f	medium
78352	7383	350	Ульяновская область, Новомалыклинский район, поселок Новочеремшанск, Заводская, 51	f	large
78353	7384	351	Ульяновская область, Новомалыклинский район, поселок Новочеремшанск, Дорожная, 5	f	large
78351	7378	345	Ульяновская область, Новомалыклинский район, село Новая Малыкла, Советская, 70	f	large
78350	7377	344	Ульяновская область, Новомалыклинский район, село Новая Малыкла, Кооперативная, 51	f	large
127821	7375	342	Ульяновская область, Новомалыклинский район, село Новая Куликовка, Советская, 16	t	small
127820	7374	341	Ульяновская область, Новомалыклинский район, село Новая Бесовка, Колхозная, 5	f	small
134940	7391	357	Ульяновская область, Новомалыклинский район, село Нижняя Якушка, Молодежная, 2А	f	small
127819	7373	340	Ульяновская область, Новомалыклинский район, село Елховый Куст, Центральная, 29	f	small
127818	7372	339	Ульяновская область, Новомалыклинский район, село Высокий Колок, Братьев Кипкаевых , 57	f	small
127826	7382	349	Ульяновская область, Новомалыклинский район, село Вороний Куст, Центральная, 24	f	small
134939	95168	356	Ульяновская область, Новомалыклинский район, село Верхняя Якушка, Советская, 25	f	small
127817	7371	338	Ульяновская область, Новомалыклинский район, село Андреево, площадь 50-летия Победы, 63	f	small
127822	7376	343	Ульяновская область, Новомалыклинский район, село Александровка, Центральная, 6	f	small
127812	7365	332	Ульяновская область, Николаевский район, село Эзекеево, Центральная, 73	t	small
127813	7366	333	Ульяновская область, Николаевский район, село ЧувашскийСайман, Школьная, 19	f	small
127801	7351	318	Ульяновская область, Николаевский район, село Топорнино, Советская, 100	f	small
127797	7347	314	Ульяновская область, Николаевский район, село Тепловка, переулок Школьный, 1	f	small
127796	7346	313	Ульяновская область, Николаевский район, село Телятниково, Центральная, 12	f	small
78348	7363	330	Ульяновская область, Николаевский район, село Татарский Сайман, Советская, 112	f	large
127815	7369	336	Ульяновская область, Николаевский район, село Сухая Терешка, Николаевская, 3	t	small
78349	7367	334	Ульяновская область, Николаевский район, село Славкино, Узкоколейная, 63	f	large
127808	7360	327	Ульяновская область, Николаевский район, село Рызлей, Афанасьева, 23	f	small
127811	7364	331	Ульяновская область, Николаевский район, село Поспеловка, Школьная, 11	f	small
127791	7341	308	Ульяновская область, Николаевский район, село Поника, Молодёжная, 10	f	small
127810	7362	329	Ульяновская область, Николаевский район, поселок Никулино, Железнодорожная, 10	t	small
127807	7359	326	Ульяновская область, Николаевский район, село Никулино, Путиловка, 3	f	small
78343	7336	302	Ульяновская область, Николаевский район, поселок Николаевка, площадь Ленина, 7	f	large
128153	7913	305	Ульяновская область, Николаевский район, поселок Николаевка, Узкоколейная, 29	f	\N
78342	7335	301	Ульяновская область, Николаевский район, поселок Николаевка, Советская, 56	f	large
78344	7338	306	Ульяновская область, Николаевский район, поселок Николаевка, Комсомольская, 17	f	large
127790	7337	304	Ульяновская область, Николаевский район, поселок Николаевка, Коммунальная, 67	f	medium
128152	7912	303	Ульяновская область, Николаевский район, поселок Николаевка, Гагарина, 11	f	\N
127816	7370	337	Ульяновская область, Николаевский район, село Куроедово, Старая, 52	f	small
127806	7358	325	Ульяновская область, Николаевский район, село Курмаевка, Школьная, 22	f	small
127805	7356	323	Ульяновская область, Николаевский район, село Крутец, Центральная, 23а	f	medium
127799	7349	316	Ульяновская область, Николаевский район, село Кравково, Центральная, 28	t	small
127971	7556	520	Ульяновская область, Николаевский район, село Кезьмино, Советская, 1	f	small
127800	7350	317	Ульяновская область, Николаевский район, село Канасаево, Центральная, 33	t	small
127803	7353	320	Ульяновская область, Николаевский район, поселок Канадей, Центральная, 39	t	small
78346	7355	322	Ульяновская область, Николаевский район, поселок Канадей, Лесная, 16	f	large
127802	7352	319	Ульяновская область, Николаевский район, село Дубровка, Нижняя, 29	f	small
127793	7343	310	Ульяновская область, Николаевский район, село Давыдовка, Новая, 4	f	medium
127795	7345	312	Ульяновская область, Николаевский район, село Губашево, Школьная, 4А	t	small
127798	7348	315	Ульяновская область, Николаевский район, село Головино, Почтовая, 34	f	small
78347	7357	324	Ульяновская область, Николаевский район, село Большой Чирклей, Советская, 140	f	large
127794	7344	311	Ульяновская область, Николаевский район, село Болдасьево, Центральная, 39	t	small
127804	7354	321	Ульяновская область, Николаевский район, село Белое Озеро, Приозерная, 19	t	small
127792	7342	309	Ульяновская область, Николаевский район, село Барановка, Советская, 54	f	medium
78345	7340	307	Ульяновская область, Николаевский район, село Баевка, Юдина, 17	f	large
127809	7361	328	Ульяновская область, Николаевский район, село Ахметлей, Средняя, 35а	f	medium
127814	7368	335	Ульяновская область, Николаевский район, село Андреевка, Центральная, 17	f	small
127755	7293	261	Ульяновская область, Мелекесский район, село Щербаковка, Школьная, 9	t	small
127776	7320	286	Ульяновская область, Мелекесский район, село Чувашский Сускан, Дзержинского, 24/1	f	small
127754	7292	260	Ульяновская область, Мелекесский район, село Черная Речка, Лесная, 23	t	small
127770	7312	279	Ульяновская область, Мелекесский район, село Филипповка, Куйбышева, 1	f	medium
127767	7309	276	Ульяновская область, Мелекесский район, село Уткин, Труда, 2	f	small
127789	7334	300	Ульяновская область, Мелекесский район, село Тинарка, Набережная, 63	t	small
134937	95166	294	Ульяновская область, Мелекесский район, село Тиинск, площадь Советов, 1, МУК ЦКД	f	large
127788	7333	299	Ульяновская область, Мелекесский район, село Терентьевка, Центральная, 20	f	small
127760	7300	267	Ульяновская область, Мелекесский район, село Степная Васильевка, Набережная, 2	t	small
127783	7327	293	Ульяновская область, Мелекесский район, село Старое Письмирь, Новая, 1	t	small
127777	7321	287	Ульяновская область, Мелекесский район, село Старая Сахча, Комсомольская, 60	f	medium
127787	7332	298	Ульяновская область, Мелекесский район, село Слобода Выходцева, Центральная, 43	f	small
127759	7298	266	Ульяновская область, Мелекесский район, село Сабакаево, Мелиоративная, 1	f	medium
78337	7297	265	Ульяновская область, Мелекесский район, село Сабакаево, Победы, 13	f	large
78340	7314	280	Ульяновская область, Мелекесский район, село Рязаново, Октябрьская, 10	f	large
127786	7331	297	Ульяновская область, Мелекесский район, село Русский Мелекесс, Школьная, 5	f	medium
127766	7308	275	Ульяновская область, Мелекесский район, село Просторы, Майская, 11	f	small
127758	7296	264	Ульяновская область, Мелекесский район, село Приморское, Мира, 45	t	small
78339	7305	272	Ульяновская область, Мелекесский район, село Новоселки, Крупской, 11	f	large
127782	7313	292	Ульяновская область, Мелекесский район, село Новая Сахча, Черемшанская, 24	t	small
78334	7288	256	Ульяновская область, Мелекесский район, поселок Новая Майна, Шутова, 1	f	large
78336	7290	258	Ульяновская область, Мелекесский район, поселок Новая Майна, Новая, 2а	f	large
78335	7289	257	Ульяновская область, Мелекесский район, поселок Новая Майна, Новая, 2а	f	large
78338	7302	269	Ульяновская область, Мелекесский район, поселок Никольское-на-Черемшане, Ленина, 59	f	large
78332	7285	253	Ульяновская область, Мелекесский район, поселок Мулловка, Советская, 65	f	large
78331	7284	252	Ульяновская область, Мелекесский район, поселок Мулловка, Победы, 9	f	large
78333	7286	254	Ульяновская область, Мелекесский район, поселок Мулловка, Красноармейская, 2	f	large
127769	7311	278	Ульяновская область, Мелекесский район, село Мордово-Озеро, Клубная, 2	t	small
127768	7310	277	Ульяновская область, Мелекесский район, село Моисеевка, Школьная, 34	f	small
127752	7287	255	Ульяновская область, Мелекесский район, село Лесной, Дорожная, 5	f	small
127785	7330	296	Ульяновская область, Мелекесский район, село Лесная Хмелевка, Мираксовой, 6	f	medium
127784	7329	295	Ульяновская область, Мелекесский район, село Лесная Васильевка, Набережная, 16	t	small
127756	7294	262	Ульяновская область, Мелекесский район, село Лебяжье, Березовая, 3	f	medium
127761	7301	268	Ульяновская область, Мелекесский район, село Куликовка, Центральная, 2	t	small
127765	7307	274	Ульяновская область, Мелекесский район, село Ковыльный, Центральная, 7	f	small
127763	7304	271	Ульяновская область, Мелекесский район, село Кипрей, Гагарина, 13	f	small
127762	7303	270	Ульяновская область, Мелекесский район, село Ерыклинск, Молодежная, 2	f	small
127775	7319	285	Ульяновская область, Мелекесский район, село Дубравка, Школьная, 36	t	small
127771	7315	281	Ульяновская область, Мелекесский район, село Дивный, Советская, 31	f	medium
127774	7318	284	Ульяновская область, Мелекесский район, село Вишенка, Центральная, 35	t	small
127764	7306	273	Ульяновская область, Мелекесский район, село Видный, Центральная, 12	t	small
127753	7291	259	Ульяновская область, Мелекесский район, село Верхний Мелекесс, Луговая, 22	t	small
127780	7324	290	Ульяновская область, Мелекесский район, село Бригадировка, Советская, 26	f	small
127779	7323	289	Ульяновская область, Мелекесский район, село Боровка, Советская, 53	f	small
127773	7317	283	Ульяновская область, Мелекесский район, село Бирля, Гагарина, 27	t	small
127778	7322	288	Ульяновская область, Мелекесский район, село Аппаково, Комсомольская, 3	t	small
127757	7295	263	Ульяновская область, Мелекесский район, село Аллагулово, Школьная, 1	f	small
127772	7316	282	Ульяновская область, Мелекесский район, село Александровка, Советская, 25	f	medium
127732	7263	231	Ульяновская область, Майнский район, п. Новоанненковский	f	small
127747	7278	246	Ульяновская область, Майнский район, село Чуфарово	t	small
127746	7277	245	Ульяновская область, Майнский район, село Чирикеево	t	small
127750	7282	250	Ульяновская область, Майнский район, село Уржумское	f	medium
78330	7279	247	Ульяновская область, Майнский район, село Тагай	f	large
127733	7264	232	Ульяновская область, Майнский район, село Сущевка	t	small
127741	7272	240	Ульяновская область, Майнский район, село Сухаревка	t	small
127743	7274	242	Ульяновская область, Майнский район, село Степное Матюнино	f	small
127744	7275	243	Ульяновская область, Майнский район, село Старые Маклауши	f	small
127724	7254	220	Ульяновская область, Майнский район, село Сосновка	f	small
127751	7283	251	Ульяновская область, Майнский район, село Сиуч	t	small
127723	7253	219	Ульяновская область, Майнский район, село Родниковые Пруды	t	small
127742	7273	241	Ульяновская область, Майнский район, село Репьевка-Космынка	f	small
127730	7261	229	Ульяновская область, Майнский район, село Репьевка Колхозная	f	medium
127722	7252	218	Ульяновская область, Майнский район, село Поповка	t	medium
127738	7269	237	Ульяновская область, Майнский район, село Полбино	t	small
127749	7281	249	Ульяновская область, Майнский район, село Подлесное, здание школы	t	medium
127745	7276	244	Ульяновская область, Майнский район, село Новые Маклауши	f	small
78328	7256	222	Ульяновская область, Майнский район, поселок Майна, Советская, 11	f	large
134507	94402	221	Ульяновская область, Майнский район, поселок Майна, Первомайская, 43, МУК Майнский историко-краеведческий музей	f	large
127725	7258	224	Ульяновская область, Майнский район, поселок Майна, Павлика Морозова, 7	f	\N
78329	7257	223	Ульяновская область, Майнский район, поселок Майна, 1-я Комсомольская, 39	f	large
127748	7280	248	Ульяновская область, Майнский район, село Копышовка, здание школы	t	small
127740	7271	239	Ульяновская область, Майнский район, село Карлинское	f	small
78326	7249	215	Ульяновская область, Майнский район, поселок Игнатовка, 2 Советская, 11А	f	large
127719	7248	214	Ульяновская область, Майнский район, поселок Игнатовка, 2 Советская, 17	f	medium
127721	7251	217	Ульяновская область, Майнский район, село Загоскино	f	medium
127739	7270	238	Ульяновская область, Майнский район, село Гимова	f	small
127729	7260	228	Ульяновская область, Майнский район, село Вязовка	f	small
127735	7266	234	Ульяновская область, Майнский район, село Выры	t	small
127734	7265	233	Ульяновская область, Майнский район, село Выры	f	small
127728	7259	227	Ульяновская область, Майнский район, село Большое Жеребятниково	f	small
127720	7250	216	Ульяновская область, Майнский район, село Белое Озеро, здание школы	f	small
127737	7268	236	Ульяновская область, Майнский район, поселок Безречный	f	small
127736	7267	235	Ульяновская область, Майнский район, Безлесный	t	small
127731	7262	230	Ульяновская область, Майнский район, село Анненково	f	medium
127726	7121	225	Ульяновская область, Майнский район, село Абрамовка	f	medium
127699	7224	191	Ульяновская область, Кузоватовский район, село Чириково, здание СПК Свияга	f	small
127698	7223	190	Ульяновская область, Кузоватовский район, село Чертановка, школа	f	small
127697	7222	189	Ульяновская область, Кузоватовский район, село Хвостиха	f	small
127703	7228	195	Ульяновская область, Кузоватовский район, село Уваровка, здание сельского клуба	t	small
127717	7243	209	Ульяновская область, Кузоватовский район, село Томылово, здание МОУ СОШ	t	small
127718	7244	210	Ульяновская область, Кузоватовский район, село Студенец, здание МОУ СОШ	f	medium
127693	7218	185	Ульяновская область, Кузоватовский район, село Стоговка, МОУ СОШ	f	small
127694	7219	186	Ульяновская область, Кузоватовский район, село Спешневка, МОУ СОШ	f	small
127700	7225	192	Ульяновская область, Кузоватовский район, село Смышляевка, МОУ СОШ	f	small
127713	7239	205	Ульяновская область, Кузоватовский район, село Приволье, МОУ СОШ	f	small
127696	7221	188	Ульяновская область, Кузоватовский район, село Порецкое, здание начальной школы	t	small
127695	7220	187	Ульяновская область, Кузоватовский район, село Первомайский, МОУ ООШ	f	small
127709	7234	201	Ульяновская область, Кузоватовский район, село Никольское, здание СДК	f	small
127706	7231	198	Ульяновская область, Кузоватовский район, село Налейка, здание МОУ СОШ	f	medium
127714	7240	206	Ульяновская область, Кузоватовский район, село Малая Борла, здание начальной школы	t	small
127707	7232	199	Ульяновская область, Кузоватовский район, село Лесное Матюнино, здание МОУ СОШ	f	medium
127704	7229	196	Ульяновская область, Кузоватовский район, село Кузоватово, МОУ СОШ № 2	f	medium
78325	7247	213	Ульяновская область, Кузоватовский район, поселок Кузоватово, здание МОУ СОШ № 1	f	large
78324	7246	212	Ульяновская область, Кузоватовский район, поселок Кузоватово, здание МУК Кузоватовский РДК	f	large
78323	7245	211	Ульяновская область, Кузоватовский район, поселок Кузоватово, МОУ СОШ № 3	f	large
127708	7233	200	Ульяновская область, Кузоватовский район, село Красная Балтия, СДК	t	small
127702	7227	194	Ульяновская область, Кузоватовский район, село Коромысловка, здание МОУ 0ОШ	f	medium
127711	7237	203	Ульяновская область, Кузоватовский район, село Кивать, здание МОУ СОШ	f	medium
127710	7236	202	Ульяновская область, Кузоватовский район, село Еделево, здание МОУ СОШ	f	medium
127712	7238	204	Ульяновская область, Кузоватовский район, село Волынщина, здание МОУ ООШ	t	medium
127701	7226	193	Ульяновская область, Кузоватовский район, село Бестужевка, здание ООО Дружба	t	small
127716	7242	208	Ульяновская область, Кузоватовский район, село Безводовка, здание начальной школы	t	small
127715	7241	207	Ульяновская область, Кузоватовский район, село Безводовка, здание МОУ СОШ	f	small
127705	7230	197	Ульяновская область, Кузоватовский район, село Баевка, МОУ СОШ	f	small
127666	7189	157	Ульяновская область, Карсунский район, пос. Чулочно-носочной фабрики, Фабричная	f	small
127671	7195	163	Ульяновская область, Карсунский район, поселок Языково, Октябрьская, 1	f	medium
78322	7193	161	Ульяновская область, Карсунский район, поселок Языково, Клубная, 1	f	large
127678	7202	170	Ульяновская область, Карсунский район, село Усть-Урень, помещение сельской библиотеки	f	medium
127689	7214	181	Ульяновская область, Карсунский район, село Урено-Карлинское, МОУ Урено-Карлинская средняя общеобразовательная школа	f	medium
127688	7213	180	Ульяновская область, Карсунский район, село Уразовка, сельский Дом культуры	t	small
127692	7217	184	Ульяновская область, Карсунский район, село Теньковка, МОУ Теньковская средняя общеобразовательная школа	t	small
127679	7203	171	Ульяновская область, Карсунский район, село Татарскии Горенки, МОУ Татарскогоренская основная общеобразовательная школа	f	small
127683	7208	175	Ульяновская область, Карсунский район, село Татарская Голышевка	f	small
127667	7190	158	Ульяновская область, Карсунский район, село Таволжанка, СДК	f	medium
127686	7211	178	Ульяновская область, Карсунский район, село Сухой Карсун, сельский Дом культуры	f	small
127687	7212	179	Ульяновская область, Карсунский район, село Сосновка, сельский Дом культуры	f	medium
127672	7196	164	Ульяновская область, Карсунский район, село Прислониха, сельский Дом культуры	t	small
127676	7200	168	Ульяновская область, Карсунский район, село Потьма, здание бывшей школы	f	small
127665	7188	156	Ульяновская область, Карсунский район, Пески, Комарова, 16А	f	small
127684	7209	176	Ульяновская область, Карсунский район, село Новое Погорелово, школа	f	small
127685	7210	177	Ульяновская область, Карсунский район, село Нагаево, МОУ Нагаевская средняя общеобразовательная школа	f	small
127669	7192	160	Ульяновская область, Карсунский район, село Малое Станичное, МОУ Малостаниченская начальная общеобразовательная школа	f	small
127668	7191	159	Ульяновская область, Карсунский район, село Краснополка, СДК	f	small
127680	7204	172	Ульяновская область, Карсунский район, село Котяково	f	small
127674	7198	166	Ульяновская область, Карсунский район, село Комаровка, здание фельдшерско-акушерского пункта	f	small
78320	7186	154	Ульяновская область, Карсунский район, поселок Карсун, Ульянова, 2	f	large
134585	94439	153	Ульяновская область, Карсунский район, поселок Карсун, Советская, 14, Карсунская детская школа искусств им. А.Пластова	f	large
78321	7187	155	Ульяновская область, Карсунский район, поселок Карсун, Мира, 16	f	large
127681	7206	173	Ульяновская область, Карсунский район, село Кадышево	f	small
127675	7199	167	Ульяновская область, Карсунский район, село Вальдиватское, школа	f	small
127677	7201	169	Ульяновская область, Карсунский район, село Большой Кандарать, МОУ Большекандаратская средняя общеобразовательная школа	f	medium
127673	7197	165	Ульяновская область, Карсунский район, село Большии Поселки, ДК	f	small
127690	7215	182	Ульяновская область, Карсунский район, село Белозерье, сельский Дом культуры	f	medium
127682	7207	174	Ульяновская область, Карсунский район, село Беловодье, сельский Дом культуры	f	small
127691	7216	183	Ульяновская область, Карсунский район, село Базарный Урень	t	small
127656	7176	144	Ульяновская область, Инзенский район, станция Дубенки, Лесная, 16	t	small
127639	7158	126	Ульяновская область, Инзенский район, с. Палатово, Центральная, 97	t	small
127658	7178	146	Ульяновская область, Инзенский район, село Юлово, здание основной общеобразовательной школы	f	small
127648	7167	135	Ульяновская область, Инзенский район, село Чумакино	f	small
127664	7184	152	Ульяновская область, Инзенский район, село Черемушки, Шоссейная, 33	f	small
127647	7166	134	Ульяновская область, Инзенский район, село Чамзинка, административное здание	f	small
127657	7177	145	Ульяновская область, Инзенский район, село Труслейка, пер. Советский, 4	f	medium
127630	7149	117	Ульяновская область, Инзенский район, село Троицкое	t	small
127642	7161	129	Ульяновская область, Инзенский район, село Тияпино, Центральная, 54а	f	small
127653	7173	141	Ульяновская область, Инзенский район, село Сюксюм	f	small
127652	7172	140	Ульяновская область, Инзенский район, село Свет, сельский дом культуры	t	small
127663	7183	151	Ульяновская область, Инзенский район, село Репьевка, Советская, 2	f	small
127641	7160	128	Ульяновская область, Инзенский район, село Пятино, Школьный переулок, 9	t	small
127646	7165	133	Ульяновская область, Инзенский район, село Проломиха	t	small
127662	7182	150	Ульяновская область, Инзенский район, село Поддубное, пер. Школьный, 13	f	small
127640	7159	127	Ульяновская область, Инзенский район, село Первомайское, Советская, 3	t	small
127651	7171	139	Ульяновская область, Инзенский район, село Панциревка	f	medium
78318	7170	138	Ульяновская область, Инзенский район, село Оськино	f	large
127645	7164	132	Ульяновская область, Инзенский район, село Новосурск, административное здание	t	small
127634	7153	121	Ульяновская область, Инзенский район, село Неклюдовский	f	small
127635	7154	122	Ульяновская область, Инзенский район, село Неклюдово	t	small
127644	7163	131	Ульяновская область, Инзенский район, село Коржевка	f	medium
127629	7148	116	Ульяновская область, Инзенский район, Инза, переулок Рузаевской, 2	f	medium
78311	7137	105	Ульяновская область, Инзенский район, Инза, Энгельса, 51	f	large
78315	7141	109	Ульяновская область, Инзенский район, Инза, Школьная, 66	f	large
127627	7145	113	Ульяновская область, Инзенский район, Инза, Фрунзе, 2А	f	medium
78310	7135	103	Ульяновская область, Инзенский район, Инза, Терешковой, 1	f	large
127628	7147	115	Ульяновская область, Инзенский район, Инза, Революции, 56	f	medium
78317	7146	114	Ульяновская область, Инзенский район, Инза, Революции, 53	f	large
127625	7142	110	Ульяновская область, Инзенский район, Инза, Пугачева, 23	f	medium
78312	7138	106	Ульяновская область, Инзенский район, Инза, Парковая, 8	f	large
127626	7144	112	Ульяновская область, Инзенский район, Инза, Мира, 17А	f	medium
78316	7143	111	Ульяновская область, Инзенский район, Инза, Мира, 17	f	large
78313	7139	107	Ульяновская область, Инзенский район, Инза, Ломоносова, 9	f	large
127624	7136	104	Ульяновская область, Инзенский район, Инза, Дорожная, 1	f	medium
78314	7140	108	Ульяновская область, Инзенский район, Инза, Алашеева, 1	f	large
127650	7169	137	Ульяновская область, Инзенский район, село Забалуйка, административное здание	t	small
127643	7162	130	Ульяновская область, Инзенский район, село Дракино	f	small
127655	7175	143	Ульяновская область, Инзенский район, село Городищи	t	small
127633	7152	120	Ульяновская область, Инзенский район, поселок Глотовка	f	medium
127632	7151	119	Ульяновская область, Инзенский район, поселок Глотовка, Советская, 31	f	medium
127631	7150	118	Ульяновская область, Инзенский район, поселок Глотовка, Садовая, 28	f	medium
127638	7157	125	Ульяновская область, Инзенский район, село Валгуссы, Большая, 61	f	small
127661	7181	149	Ульяновская область, Инзенский район, село Бояркино, Центральная, 12	t	small
127637	7156	124	Ульяновская область, Инзенский район, село Большое Шуватово, Центральная, 15А	t	small
127660	7180	148	Ульяновская область, Инзенский район, село Большая Борисовка, Ленина, 21	f	small
127659	7179	147	Ульяновская область, Инзенский район, село Аристовка, Молодежная, 14	f	small
127654	7174	142	Ульяновская область, Инзенский район, село Аргаш, Актовый зал административного здания	f	small
127649	7168	136	Ульяновская область, Инзенский район	t	small
127636	7155	123	Ульяновская область, Инзенский район, село Аксаур, Центральная, 60	t	small
127617	7128	96	Ульяновская область, Вешкаймский район, поселок Шарлово, Заводская, 5	f	medium
127616	7127	95	Ульяновская область, Вешкаймский район, поселок Шарлово, Школьная, 5	f	small
127609	7119	88	Ульяновская область, Вешкаймский район, поселок Чуфарово, Заводская, 11а	f	medium
78309	7118	87	Ульяновская область, Вешкаймский район, поселок Чуфарово, Заводская, 1а	f	large
127608	7117	86	Ульяновская область, Вешкаймский район, село Ховрино, Ленина, 15	f	small
127622	7133	101	Ульяновская область, Вешкаймский район, село Стемас, Центральный Массив, 4	f	small
127612	7123	91	Ульяновская область, Вешкаймский район, село Старое Погорелово, Центральная, 79	f	\N
127620	7131	99	Ульяновская область, Вешкаймский район, село Нижняя Туарма, Клубная, 22	f	small
127615	7126	94	Ульяновская область, Вешкаймский район, село Мордово-Белый Ключ, Верхняя, 2	f	small
127607	7116	85	Ульяновская область, Вешкаймский район, село Красный Бор, Репинского, 100а	f	medium
127619	7130	98	Ульяновская область, Вешкаймский район, село Коченяевка, Центральная, 72	f	small
127618	7129	97	Ульяновская область, Вешкаймский район, село Каргино, Егоровка, 8	f	medium
127614	7125	93	Ульяновская область, Вешкаймский район, село Зимненки, Советская, 41	t	small
127606	7115	84	Ульяновская область, Вешкаймский район, поселок Залесный, Советская, 14	f	small
127613	7124	92	Ульяновская область, Вешкаймский район, село Ермоловка, Центральная, 101	f	medium
127605	7114	83	Ульяновская область, Вешкаймский район, село Вешкайма, Школьная, 7	f	medium
78305	7109	78	Ульяновская область, Вешкаймский район, поселок Вешкайма, Труда, 6А	f	large
78308	7112	81	Ульяновская область, Вешкаймский район, поселок Вешкайма, Лесхозная, 19	f	large
78307	7111	80	Ульяновская область, Вешкаймский район, поселок Вешкайма, Комсомольская, 14а	f	large
78306	7110	79	Ульяновская область, Вешкаймский район, поселок Вешкайма, Комсомольская, 3	f	large
127610	7120	89	Ульяновская область, Вешкаймский район, село Березовка, Калинина, 3	t	small
127604	7113	82	Ульяновская область, Вешкаймский район, село Белый Ключ, Волынцева, 37	f	small
127623	7134	102	Ульяновская область, Вешкаймский район, село Беклемишево, Школьная, 22	f	small
127611	7122	90	Ульяновская область, Вешкаймский район, село Бекетовка, Центральная, 49	f	medium
127621	7132	100	Ульяновская область, Вешкаймский район, село Ахматово-Белый Ключ, Клубная, 6	f	small
127574	7075	45	Ульяновская область, Барышский район, поселок имени В. И.Ленина, Молодежная, 3А	f	medium
78301	7074	44	Ульяновская область, Барышский район, поселок имени В. И.Ленина, Ленина, 51	f	large
127600	7104	74	Ульяновская область, Барышский район, село Чувашская Решетка, Шоссейная, 11	f	medium
127581	7082	52	Ульяновская область, Барышский район, село Сурские Вершины, Старая, 20	t	small
78302	7083	53	Ульяновская область, Барышский район, поселок Старотимошкино, Советская, 62	f	large
78303	7084	54	Ульяновская область, Барышский район, поселок Старотимошкино, Пролетарская, 1	f	large
127599	7103	73	Ульяновская область, Барышский район, село Старая Савадерка, Центральная, 25	t	small
127583	7087	57	Ульяновская область, Барышский район, село Смольково, Нижняя, 24	t	small
127571	7069	39	Ульяновская область, Барышский район, село Самородки, Школьная, 7А, адрес УИК: ул. Нагорнаяд. 2	t	small
127580	7081	51	Ульяновская область, Барышский район, село Русская Бекшанка, Центральная, 7	t	small
127579	7080	50	Ульяновская область, Барышский район, село Румянцево, Чкалова, 152А	t	medium
127601	7105	75	Ульяновская область, Барышский район, село Поливаново, Школьная, 1	f	medium
127570	7068	38	Ульяновская область, Барышский район, село Павловка, Молодежная, 28	f	small
127589	7093	63	Ульяновская область, Барышский район, село Осока, Молодёжная, 2	f	small
127598	7102	72	Ульяновская область, Барышский район, село Новый Дол, Молодежная, 2А	f	small
127573	7073	43	Ульяновская область, Барышский район, село Новая Ханинеевка, Центральная, 15	t	small
127569	7067	37	Ульяновская область, Барышский район, село Новая Деревня, Центральная, 55	t	small
127578	7079	49	Ульяновская область, Барышский район, село Новая Бекшанка, Центральная, 27	f	small
127595	7099	69	Ульяновская область, Барышский район, село Малый Хомутерь, Новоселов, 7	f	medium
127572	7072	42	Ульяновская область, Барышский район, село Ляховка, переулок Центральный, 8	f	small
127594	7098	68	Ульяновская область, Барышский район, село Лесная Дача	f	small
127588	7092	62	Ульяновская область, Барышский район, село Кудажлейка, Молодежная, 11	t	small
127577	7078	48	Ульяновская область, Барышский район, село Красная Поляна, Центральная, 48	f	small
127593	7097	67	Ульяновская область, Барышский район, село Красная Зорька, Школьная, 1	f	small
127592	7096	66	Ульяновская область, Барышский район, село Конновка, Седова, 23	t	small
127587	7091	61	Ульяновская область, Барышский район, село Киселевка, Новая, 34	f	small
127586	7090	60	Ульяновская область, Барышский район, село Кармалейка, Центральная, 15	t	small
78304	7086	56	Ульяновская область, Барышский район, село Калда, Советская, 58	f	large
78300	7071	41	Ульяновская область, Барышский район, поселок Измайлово, Школьная, 2	f	large
78299	7070	40	Ульяновская область, Барышский район, поселок Измайлово, Советская, 14	f	large
127591	7095	65	Ульяновская область, Барышский район, село Земляничный, Плодопитомническая, 10/1	t	small
127582	7085	55	Ульяновская область, Барышский район, село Заречное, Зеленая, 7А	f	medium
127585	7089	59	Ульяновская область, Барышский район, село Загарино, Парковая, 16	f	small
127584	7088	58	Ульяновская область, Барышский район, село Живайкино, Школьная, 7	f	medium
127568	7066	36	Ульяновская область, Барышский район, поселок Жадовка, Гая, 3	f	medium
127567	7065	35	Ульяновская область, Барышский район, поселок Жадовка, Гагарина, 3А	f	medium
127576	7077	47	Ульяновская область, Барышский район, село Головцево, Молодёжная, 28	f	small
127575	7076	46	Ульяновская область, Барышский район, село Воецкое, Советская, 25	f	small
127603	7107	77	Ульяновская область, Барышский район, село Водорацк, Школьная, 1	f	small
127597	7101	71	Ульяновская область, Барышский район, село Барышская Дурасовка, Горная, 1А	t	small
127596	7100	70	Ульяновская область, Барышский район, село Алинкино, Больничный переулок, 1	f	small
127602	7106	76	Ульяновская область, Барышский район, село Акшуат, Колхозная, 1 А	f	medium
127552	7043	13	Ульяновская область, Базарносызганский район, п. Сосновый Бор	t	small
127550	7041	11	Ульяновская область, Базарносызганский район, село Ясачный Сызган	f	small
127557	7048	18	Ульяновская область, Базарносызганский район, село Юрловка, школа	f	small
127545	7036	6	Ульяновская область, Базарносызганский район, село Черный Ключ	t	small
127551	7042	12	Ульяновская область, Базарносызганский район, село Русская Хомутерь	f	small
127546	7037	7	Ульяновская область, Базарносызганский район, Раздолье	f	small
127558	7049	19	Ульяновская область, Базарносызганский район, село Патрикеево, школа	t	small
127555	7046	16	Ульяновская область, Базарносызганский район, село Папузы	f	small
127556	7047	17	Ульяновская область, Базарносызганский район, село Папуз-Гора	t	small
127549	7040	10	Ульяновская область, Базарносызганский район, село Лапшаур, здание фельдшерско-акушерского пункта	f	small
127548	7039	9	Ульяновская область, Базарносызганский район, село Красная Сосна	t	small
127559	7050	20	Ульяновская область, Базарносызганский район, село Иевлевка	f	small
127547	7038	8	Ульяновская область, Базарносызганский район, поселок Дубки, здание фельдшерско - акушерского пункта	t	small
127544	7035	5	Ульяновская область, Базарносызганский район, село Должниково, здание школы	t	small
127553	7044	14	Ульяновская область, Базарносызганский район, село Годяйкино	f	small
127554	7045	15	Ульяновская область, Базарносызганский район, село Вороновка	t	small
78289	7031	1	Ульяновская область, Базарносызганский район, поселок Базарный Сызган, Советская, 82	f	large
78291	7033	3	Ульяновская область, Базарносызганский район, поселок Базарный Сызган, Рабочая, 34	f	large
127543	7034	4	Ульяновская область, Базарносызганский район, поселок Базарный Сызган, Дорожная, 1	f	small
78290	7032	2	Ульяновская область, Базарносызганский район, поселок Базарный Сызган, Авдеева, 113	f	large
71903	83884	1712	Саратовская область, Энгельс, Маяковского, МОУ ООШ № 26	f	large
71916	83884	1713	Саратовская область, Энгельс, Маяковского, МОУ ООШ № 26	f	large
71849	83865	1685	Саратовская область, Энгельс	f	large
120630	83852	1667	Саратовская область, Энгельс, проспект Строителей, 68, ОАО Завод металлоконструкций	f	medium
71789	83846	1660	Саратовская область, Энгельс, проспект Ломоносова, 21а, ДК Дружба	f	large
71788	83846	1659	Саратовская область, Энгельс, проспект Ломоносова, 21а, ДК Дружба	f	large
71787	83846	1658	Саратовская область, Энгельс, проспект Ломоносова, 21а, ДК Дружба	f	large
71846	83862	1682	Саратовская область, Энгельс, площадь Свободы, 17, Технологический институт СГТУ	f	large
71770	81474	1655	Саратовская область, Энгельс, Энгельс-1, МОУ СОШ № 23	f	large
71771	81474	1656	Саратовская область, Энгельс, Энгельс-1, МОУ СОШ № 23	f	large
71689	83895	1732	Саратовская область, Энгельс, Щорса, 22, ЖКУ поселка Зеленый	f	large
71850	83866	1686	Саратовская область, Энгельс, Халтурина, 25, учебный корпус	f	large
71857	83871	1693	Саратовская область, Энгельс, Тургенева, 14, Спортивно-оздоровительный комплекс Олимпия	f	large
71888	83874	1697	Саратовская область, Энгельс, Транспортная, 30, МОУ СОШ № 24	f	large
71881	83874	1696	Саратовская область, Энгельс, Транспортная, 30, МОУ СОШ № 24	f	large
134494	83868	1689	Саратовская область, Энгельс, Тельмана, 2, МОУ СОШ № 33	f	large
71854	83868	1690	Саратовская область, Энгельс, Тельмана, 2, МОУ СОШ № 33	f	large
71893	83857	1702	Саратовская область, Энгельс, Тельмана, 139, МОУ СОШ № 1	f	large
71892	83857	1701	Саратовская область, Энгельс, Тельмана, 139, МОУ СОШ № 1	f	large
71889	83857	1698	Саратовская область, Энгельс, Тельмана, 139, МОУ СОШ № 1	f	large
71821	83857	1677	Саратовская область, Энгельс, Тельмана, 139, МОУ СОШ № 1	f	large
71848	83864	1684	Саратовская область, Энгельс, Театральная, 2, Театр оперетты	f	large
71746	83834	1641	Саратовская область, Энгельс, Студенческая, 26а, МОУ СОШ № 19	f	large
71743	83830	1638	Саратовская область, Энгельс, Студенческая, 195, здание Энгельсского государственного профессионально-педагогического колледжа	f	large
71820	83856	1676	Саратовская область, Энгельс, Строительная, 32, МОУ СОШ № 18	f	large
71819	83855	1675	Саратовская область, Энгельс, Строителей проспект, 7, ДК Строитель	f	large
71818	83855	1674	Саратовская область, Энгельс, Строителей проспект, 7, ДК Строитель	f	large
71817	83855	1673	Саратовская область, Энгельс, Строителей проспект, 7, ДК Строитель	f	large
71816	83855	1672	Саратовская область, Энгельс, Строителей проспект, 7, ДК Строитель	f	large
71747	83835	1642	Саратовская область, Энгельс, Санаторная, 3, Дом - интернат для престарелых и инвалидов	f	large
71844	83861	1681	Саратовская область, Энгельс, Пушкина, 1а, МОУ СОШ № 12	f	large
71791	83848	1662	Саратовская область, Энгельс, Полтавская, 27, Институт бизнеса и делового администрирования	f	large
71822	83858	1678	Саратовская область, Энгельс, Полиграфическая, 57, общежитие Поволжского кооп. техникума	f	large
71744	83831	1639	Саратовская область, Энгельс, Новая, 21, медицинский колледж	f	large
71795	83851	1666	Саратовская область, Энгельс, Менделеева, 3а, МОУ СОШ № 5	f	large
71794	83851	1665	Саратовская область, Энгельс, Менделеева, 3а, МОУ СОШ № 5	f	large
71793	83850	1664	Саратовская область, Энгельс, Менделеева, 7, МОУ СОШ № 3	f	large
71745	83832	1640	Саратовская область, Энгельс, Маршала Василевского, 50, подростковый клуб Юность	f	large
71766	83843	1651	Саратовская область, Энгельс, Марины Расковой, 4, диспетчерская ООО Транс - Лайн	f	large
71856	83870	1692	Саратовская область, Энгельс, Лесозаводская, 2в, МОУ СОШ № 14	f	large
71926	83888	1719	Саратовская область, Энгельс, Курчатова, 12, админ.здание Анисовской дистанции пути	f	large
71925	83888	1718	Саратовская область, Энгельс, Курчатова, 12, админ.здание Анисовской дистанции пути	f	large
120631	83885	1714	Саратовская область, Энгельс, Крупской, 24, ДК Искра	f	medium
71694	83900	1737	Саратовская область, Энгельс, Колхозная, 129а, здание администрации	f	large
71762	83839	1647	Саратовская область, Энгельс, Колотилова, 82, МОУ СОШ № 30	f	large
71750	83839	1646	Саратовская область, Энгельс, Колотилова, 82, МОУ СОШ № 30	f	large
71748	83837	1644	Саратовская область, Энгельс, Колотилова, 6а, ДК Мелиоратор	f	large
120628	83836	1643	Саратовская область, Энгельс, Колотилова, 54, подростково - молодежный клуб Мечта	f	medium
71894	83876	1703	Саратовская область, Энгельс, Железнодорожная, 13, корпус профессионального лицея № 34	f	large
71692	83898	1735	Саратовская область, Энгельс, Гагарина, 65а, VОУ СОШ № 31	f	large
71691	83897	1734	Саратовская область, Энгельс, Гагарина, 1, здание ВолжНИИГиМ	f	large
71922	83886	1715	Саратовская область, Энгельс, Воронежская, 84, Энгельсская районная концертная организация	f	large
71852	83867	1688	Саратовская область, Энгельс, Волоха, 16, МОУ Кадетская школа Патриот	f	large
71851	83867	1687	Саратовская область, Энгельс, Волоха, 16, МОУ Кадетская школа Патриот	f	large
71693	83899	1736	Саратовская область, Энгельс, Большевистский переулок, здание ДК Волга	f	large
71930	83890	1723	Саратовская область, Энгельс, Авиабаза Энгельс-2, ДК Покровский	f	large
71929	83890	1722	Саратовская область, Энгельс, Авиабаза Энгельс-2, ДК Покровский	f	large
71928	83890	1721	Саратовская область, Энгельс, Авиабаза Энгельс-2, ДК Покровский	f	large
71763	83840	1648	Саратовская область, Энгельс, 2-я Ленинградская, 51	f	large
71901	83882	1710	Саратовская область, Энгельс, 1-й Микрорайон, 13б, ПУ № 9, 4-й корпус ГОУ СПО Энгельсский политехникум	f	large
71717	83909	1746	Саратовская область, село Шумейка, Советская, 92, здание МОУ СОШ	f	large
120625	83826	1634	Саратовская область, Хвалынск, Советская, 55, Санаторная школа-интернат	f	medium
71741	83825	1633	Саратовская область, Хвалынск, Советская, 130, ГОУ Школа-интернат	f	large
120626	83827	1635	Саратовская область, Хвалынск городской округ, Росреспублики, 116, д.118 ГОУ НПО ПУ-71	f	medium
120627	83828	1636	Саратовская область, Хвалынск, Верхняя Слободка, 49, ФГБУНациональный парк	f	small
71831	83713	1523	Саратовская область, поселок городского типа Соколовый, МОУ СОШ р.п. Соколовый	f	large
119715	82503	245	Саратовская область, Саратов, начальная школа-детский сад №88	f	small
119686	82338	18	Саратовская область, Волжский район, Саратов, МОУ СОШ №66 им. Н.И.Вавилова, совхоз Комбайн	f	medium
72067	82453	176	Саратовская область, Саратов, улица Шехурдина, 2, Общежитие ГОУ ВПО СГСЭУ	f	large
71952	82334	12	Саратовская область, Саратов, улица Челюскинцев, 12	f	large
72030	82420	137	Саратовская область, Саратов, улица Техническая, 14, клуб Островок	f	large
71823	83859	1679	Саратовская область, Саратов, улица Телеграфная, 88, МОУ СОШ № 10	f	large
72045	82433	153	Саратовская область, Саратов, улица Танкистов, 126, МОУ СОШ №71	f	large
72121	82480	209	Саратовская область, Саратов, улица Строителей, МОУ СОШ №105	f	large
72214	82575	352	Саратовская область, Саратов, улица Степана Разина, 36, МОУ СОШ №1	f	large
72012	82404	116	Саратовская область, Саратов, улица Степана Разина, 89, МДОУ Детский сад №136	f	large
134483	94380	1261	Саратовская область, Саратов, улица Советская, 77	f	medium
72213	82574	351	Саратовская область, Саратов, улица Слонова, 37/41, Детский сад Бэмби	f	large
72100	82397	105	Саратовская область, Саратов, улица Ростовская, 29, МОУ ООШ № 22	f	large
71986	82348	35	Саратовская область, Саратов, улица Рогожина, 24/32, МОУ СОШ №10	f	large
71988	82348	37	Саратовская область, Саратов, улица Рогожина, 24/32, МОУ СОШ №10	f	large
71987	82348	36	Саратовская область, Саратов, улица Рогожина, 24/32, МОУ СОШ №10	f	large
134460	94358	342	Саратовская область, Саратов, улица Рахова, 124, МОУ Средняя общеобразовательная школа № 18	f	large
72156	82505	249	Саратовская область, Саратов, улица Перспективная, 9А, МОУ Гимназия №87	f	large
72155	82505	248	Саратовская область, Саратов, улица Перспективная, 9А, МОУ Гимназия №87	f	large
72182	82513	263	Саратовская область, Саратов, улица Овражная, МОУ СОШ №46	f	large
72181	82513	262	Саратовская область, Саратов, улица Овражная, МОУ СОШ №46	f	large
72167	82513	261	Саратовская область, Саратов, улица Овражная, МОУ СОШ №46	f	large
72014	82407	119	Саратовская область, Саратов, улица Московская, 185, Участковый пункт полиции 9	f	large
71957	81745	19	Саратовская область, Волжский район, Саратов, улица Молодежная, 31, МУК Клуб Парус	f	large
72209	82525	291	Саратовская область, Саратов, улица Мичурина, 88, МОУ Гимназия №1	f	large
72204	82525	286	Саратовская область, Саратов, улица Мичурина, 88, МОУ Гимназия №1	f	large
72203	82525	285	Саратовская область, Саратов, улица Мичурина, 88, МОУ Гимназия №1	f	large
71924	83887	1717	Саратовская область, Саратов, улица Мира, 20, МОУ СОШ № 20	f	large
71923	83887	1716	Саратовская область, Саратов, улица Мира, 20, МОУ СОШ № 20	f	large
72086	82386	87	Саратовская область, Саратов, улица Маркина, 17/39, МОУ СОШ № 39	f	large
72085	82386	86	Саратовская область, Саратов, улица Маркина, 17/39, МОУ СОШ № 39	f	large
72083	82384	84	Саратовская область, Саратов, улица Маркина, 17/39, МОУ СОШ № 59	f	large
72116	82476	204	Саратовская область, Саратов, улица Крылова, 1б, детский сад №177	f	large
72246	82549	321	Саратовская область, Саратов, улица Клочкова, 74, Городская поликлиника №10	f	large
71993	82352	42	Саратовская область, Саратов, улица Казанская, 29, МОУ СОШ №66 им.Н.И.Вавилова	f	large
120336	83412	1227	Саратовская область, Саратов, улица Зеленая, 7, МОУ Основная школа	t	small
72064	82449	172	Саратовская область, Саратов, улица Большая Казачья, 110	f	large
72199	82523	281	Саратовская область, Саратов, улица Бардина, 3, МОУ СОШ №61	f	large
72198	82523	280	Саратовская область, Саратов, улица Бардина, 3, МОУ СОШ №61	f	large
72197	82523	279	Саратовская область, Саратов, улица Бардина, 3, МОУ СОШ №61	f	large
72061	82447	169	Саратовская область, Саратов, улица Астраханская, 138	f	large
72073	82377	74	Саратовская область, Саратов, проспект Энтузиастов, 48, МОУ СОШ № 34	f	large
71976	82377	73	Саратовская область, Саратов, проспект Энтузиастов, 48, МОУ СОШ № 34	f	large
72162	82508	256	Саратовская область, Саратов, проспект Строителей, 6/1, центр детского творчества	f	large
72161	82508	255	Саратовская область, Саратов, проспект Строителей, 6/1, центр детского творчества	f	large
119716	82508	254	Саратовская область, Саратов, проспект Строителей, 6/1, центр детского творчества	f	medium
72143	82496	234	Саратовская область, Ленинский район, Саратов, проспект Ломоносова, 20, центр народного творчества	f	large
72142	82496	233	Саратовская область, Ленинский район, Саратов, проспект Ломоносова, 20, центр народного творчества	f	large
72141	82493	230	Саратовская область, Саратов, проспект Ломоносова, 14, МУК ЦДТТ Романтик	f	large
71812	83853	1668	Саратовская область, Саратов, проспект Ломоносова, 7, МОУ СОШ № 9	f	large
71814	83853	1670	Саратовская область, Саратов, проспект Ломоносова, 7, МОУ СОШ № 9	f	large
71813	83853	1669	Саратовская область, Саратов, проспект Ломоносова, 7, МОУ СОШ № 9	f	large
72109	82467	195	Саратовская область, Саратов, проспект 50 лет Октября, 63, МОУ Гимназия №108	f	large
119718	82535	300	Саратовская область, Саратов, проезд Весенний, 4, т.20-22-43	f	\N
71998	82358	50	Саратовская область, Заводской район, Саратов, поселок Юриш, Адм.здание Речпорт	f	large
72107	82462	190	Саратовская область, Саратов, площадь им. Ленина В.И, ОГУК ДК Россия	f	large
72106	82462	189	Саратовская область, Саратов, площадь им. Ленина В.И, ОГУК ДК Россия	f	large
71847	83863	1683	Саратовская область, Саратов, площадь Театральная, 2, Театр оперетты	f	large
72253	82562	338	Саратовская область, Саратов, площадь Театральная, 13, Дворец творчества Д и М	f	large
71792	83845	1657	Саратовская область, Саратов, набережная Космонавтов, 19, подростковый клуб Орлёнок	f	large
71973	82375	70	Саратовская область, Саратов, им.Пономарева П.Т., 10/15, МОУ ДОД Центр внешкольной работы	f	large
71969	82372	66	Саратовская область, Заводской район, Саратов, им.Пономарева П.Т, 49, МОУ СОШ № 43	f	large
71968	82372	65	Саратовская область, Заводской район, Саратов, им.Пономарева П.Т, 49, МОУ СОШ № 43	f	large
71970	82372	67	Саратовская область, Заводской район, Саратов, им.Пономарева П.Т, 49, МОУ СОШ № 43	f	large
72157	82506	250	Саратовская область, Саратов, академика Антонова, 10, геологический колледж	f	large
72144	82497	235	Саратовская область, Саратов, академика Антонова, 5, Городская поликлиника №17	f	large
72000	82361	53	Саратовская область, Саратов, Южно-Зеленая, 11А, МОУ СОШ № 84	f	large
72093	82391	95	Саратовская область, Саратов, Южная, 46, МОУ СОШ № 38	f	large
119696	82391	96	Саратовская область, Саратов, Южная, 46, МОУ СОШ № 38	f	\N
72092	82391	94	Саратовская область, Саратов, Южная, 46, МОУ СОШ № 38	f	large
119697	82391	97	Саратовская область, Саратов, Южная, 46, МОУ СОШ № 38	f	\N
71966	82371	63	Саратовская область, Саратов, Энтузиастов проспект, 14	f	large
71965	82371	62	Саратовская область, Саратов, Энтузиастов проспект, 14	f	large
71967	82371	64	Саратовская область, Саратов, Энтузиастов проспект, 14	f	large
120557	83729	1539	Саратовская область, Саратов, Школьная, 13, Здание библиотеки	f	small
72119	82478	207	Саратовская область, Саратов, Широкая, 34, МОУ СОШ №52	f	large
72118	82478	206	Саратовская область, Саратов, Широкая, 34, МОУ СОШ №52	f	large
72136	82490	225	Саратовская область, Саратов, Шехурдина, 56А	f	large
72135	82490	224	Саратовская область, Саратов, Шехурдина, 56А	f	large
119731	82583	361	Саратовская область, Саратов, Шелковичная, 181, ООО Нова Терра	f	small
72221	82582	360	Саратовская область, Саратов, Шелковичная, 186, бизнес-центр ТЕСАР	f	large
72220	82581	359	Саратовская область, Саратов, Шелковичная, 224, Детский сад №221 Росинка	f	large
72219	82580	358	Саратовская область, Саратов, Шелковичная, 178, здание МОУДОД ДЮЦ района	f	large
72218	82567	357	Саратовская область, Саратов, Шелковичная, 141, МОУ СОШ №77	f	large
72217	82567	355	Саратовская область, Саратов, Шелковичная, 141, МОУ СОШ №77	f	large
72191	82519	272	Саратовская область, Саратов, Чехова, 4а, кадетская школа-интернат №2	f	large
72190	82517	271	Саратовская область, Саратов, Чехова, 1а, МОУ СОШ №55	f	large
72189	82517	270	Саратовская область, Саратов, Чехова, 1а, МОУ СОШ №55	f	large
72188	82517	269	Саратовская область, Саратов, Чехова, 1а, МОУ СОШ №55	f	large
72187	82517	268	Саратовская область, Саратов, Чехова, 1а, МОУ СОШ №55	f	large
71945	82329	5	Саратовская область, Саратов, Чернышевского, 138, МОУ Гимназия №2	f	large
71944	82329	4	Саратовская область, Саратов, Чернышевского, 138, МОУ Гимназия №2	f	large
119683	82326	1	Саратовская область, Саратов, Чернышевского, 151	f	medium
72148	82500	239	Саратовская область, Саратов, Чемодурова, 8а, станция юных туристов	f	large
72051	82439	159	Саратовская область, Саратов, Челюскинцев, 114, Мин-во строительства и ЖКХ	f	large
72208	82528	290	Саратовская область, Саратов, Чапаева, 14/26, Детская поликлиника №1	f	large
72165	82511	259	Саратовская область, Саратов, Центральная, 28, детская музык. школа №5	f	large
72176	82537	302	Саратовская область, Саратов, Хользунова, 19, Городская поликлиника №8	f	large
71954	82336	15	Саратовская область, Саратов, Федоровская улица, 3, МОУ Гимназия №7	f	large
71953	82336	14	Саратовская область, Саратов, Федоровская улица, 3, МОУ Гимназия №7	f	large
72196	82522	278	Саратовская область, Саратов, Уфимцева, 4а, МОУ СОШ №63	f	large
72195	82522	277	Саратовская область, Саратов, Уфимцева, 4а, МОУ СОШ №63	f	large
72194	82522	276	Саратовская область, Саратов, Уфимцева, 4а, МОУ СОШ №63	f	large
72013	82405	117	Саратовская область, Саратов, Университетская, 59, художественное училище	f	large
72019	82411	124	Саратовская область, Саратов, Украинская, 6, МУЗ Поликлиника №2 филиал	f	large
72078	82380	79	Саратовская область, Саратов, Тульская, 17, Библиотека № 22	f	large
72077	82379	78	Саратовская область, Саратов, Тульская, 17, МУК ЦБС г.Саратова Библиотека № 22	f	large
72066	82452	175	Саратовская область, Саратов, Тулайкова, 7, НИИ Юго-Востока	f	large
72018	82410	123	Саратовская область, Саратов, Тракторная, 33, МОУ СОШ №54	f	large
72017	82410	122	Саратовская область, Саратов, Тракторная, 33, МОУ СОШ №54	f	large
71858	83872	1694	Саратовская область, Саратов, Телефонная, 1, МОУ ООШ № 7	f	large
72212	82458	184	Саратовская область, Саратов, Тверская, 45	f	large
72211	82458	183	Саратовская область, Саратов, Тверская, 45	f	large
72072	82458	182	Саратовская область, Саратов, Тверская, 45	f	large
72205	82526	287	Саратовская область, Саратов, Тараса Шевченко, 26, Центр. детск. музыкал. школа	f	large
72043	82432	151	Саратовская область, Саратов, Танкистов, 103, клуб Дружба	f	large
72044	82432	152	Саратовская область, Саратов, Танкистов, 103, клуб Дружба	f	large
72034	82425	142	Саратовская область, Саратов, Танкистов, 55А , ЗАО Завод Медтехника)	f	large
72031	82421	138	Саратовская область, Саратов, Танкистов, 93, ГОУ Школа-интернат №2	f	large
119702	82421	139	Саратовская область, Саратов, Танкистов, 93, ГОУ Школа-интернат №2	f	\N
72164	82510	258	Саратовская область, Саратов, Строителей проспект, 6, стоматологическая полик-ка	f	large
72163	82509	257	Саратовская область, Саратов, Строителей проспект, 12, МДОУ Детский сад №161	f	large
72120	82479	208	Саратовская область, Ленинский район, Саратов, Строителей, МОУ СОШ №105	f	large
71948	82332	8	Саратовская область, Саратов, Соляная, 17, МОУ СОШ №9	f	large
71950	82332	10	Саратовская область, Саратов, Соляная, 17, МОУ СОШ №9	f	large
71949	82332	9	Саратовская область, Саратов, Соляная, 17, МОУ СОШ №9	f	large
71990	82350	39	Саратовская область, Саратов, Соколовогорская, 8, ГОУ НПО ПУ №22	f	large
119685	82335	13	Саратовская область, Саратов, Соколовая, 18/40, подростковый клуб Дружба, т.28-87-05	f	\N
72201	82518	283	Саратовская область, Саратов, Советская, 46, Лицей №3 им.А.С.Пушкина	f	large
72202	82518	284	Саратовская область, Саратов, Советская, 46, Лицей №3 им.А.С.Пушкина	f	large
71946	82330	6	Саратовская область, Саратов, Соборная, 33, МОУ СОШ №8	f	large
71943	82327	2	Саратовская область, Саратов, Соборная, 23/25, ПАГС им.Столыпина	f	large
72173	82531	298	Саратовская область, Саратов, Симбирцева, 34, МОУ СОШ №6	f	large
72169	82531	294	Саратовская область, Саратов, Симбирцева, 34, МОУ СОШ №6	f	large
119743	82597	374	Саратовская область, Саратов, Северная, 11	f	small
72215	82576	353	Саратовская область, Саратов, Свинцовая, 10, Детский сад №25 Маячок	f	large
72021	82414	127	Саратовская область, Саратов, Рябиновская, 21, МДОУ Детский сад №65	f	large
72101	82398	106	Саратовская область, Саратов, Ростовская, 29, МОУ ООШ № 29	f	large
71678	83689	1500	Саратовская область, Саратов, Рахова, 22 А, МУК Дом культуры п. Дубки	f	large
72256	82565	341	Саратовская область, Саратов, Рахова, 124, МОУ СОШ №18	f	large
71978	82340	26	Саратовская область, Саратов, Радищева, 32, МОУ Национальная татарская гимназия	f	large
71977	82340	25	Саратовская область, Саратов, Радищева, 32, МОУ Национальная татарская гимназия	f	large
71962	82339	24	Саратовская область, Саратов, Радищева, 89, ФГОУ ВПО СГСЭУ	f	large
71961	82339	23	Саратовская область, Саратов, Радищева, 89, ФГОУ ВПО СГСЭУ	f	large
119684	82328	3	Саратовская область, Саратов, Радищева, 18, МОУ СОШ №8	f	medium
134458	94356	288	Саратовская область, Саратов, Рабочая, 32, Детский сад №15	f	large
72259	82569	345	Саратовская область, Саратов, Рабочая, 116а, СК Юность	f	large
72258	82566	343	Саратовская область, Фрунзенский район, Саратов, Пугачевская улица, 119, Дет/сад №219 Колокольчик	f	large
72062	82448	170	Саратовская область, Саратов, Пугачева, 123 , МОУ СОШ №67	f	large
72063	82448	171	Саратовская область, Саратов, Пугачева, 123 , МОУ СОШ №67	f	large
72160	82507	253	Саратовская область, Саратов, Производственная, 5, МОУ СОШ №103	f	large
72159	82507	252	Саратовская область, Саратов, Производственная, 5, МОУ СОШ №103	f	large
72158	82507	251	Саратовская область, Саратов, Производственная, 5, МОУ СОШ №103	f	large
134459	94357	289	Саратовская область, Саратов, Провиантская, 7, МДОУ Детский сад комбинированного вида №56	f	large
119699	82406	118	Саратовская область, Саратов, Привокзальная площадь, 1, ж/д вокзал Саратов-1	f	small
72060	82446	168	Саратовская область, Саратов, Посадского, 248, Лицей математики и информатикики	f	large
72055	82441	163	Саратовская область, Саратов, Посадского, 193, МОУ СОШ №21	f	large
72054	82441	162	Саратовская область, Саратов, Посадского, 193, МОУ СОШ №21	f	large
72053	82441	161	Саратовская область, Саратов, Посадского, 193, МОУ СОШ №21	f	large
71971	82373	68	Саратовская область, Саратов, улица Пономарева, 49, МОУ СОШ № 43	f	large
72239	82544	314	Саратовская область, Саратов, Политехническая, 62/70, подростковый клуб Атлет	f	large
72154	82504	247	Саратовская область, Саратов, Перспективная, 9/10, МОУ ООШ №44	f	large
72059	82504	246	Саратовская область, Саратов, Перспективная, 9/10, МОУ ООШ №44	f	large
72153	82502	244	Саратовская область, Саратов, Перспективная, 29, МОУ ООШ №57	f	large
72152	82502	243	Саратовская область, Саратов, Перспективная, 29, МОУ ООШ №57	f	large
72137	82491	226	Саратовская область, Саратов, Осенняя, 5, МОУ СОШ №75	f	large
72138	82491	227	Саратовская область, Саратов, Осенняя, 5, МОУ СОШ №75	f	large
72105	82460	188	Саратовская область, Саратов, Одесская, 7, МАОУ Лицей №36	f	large
72103	82460	186	Саратовская область, Саратов, Одесская, 7, МАОУ Лицей №36	f	large
72104	82460	187	Саратовская область, Саратов, Одесская, 7, МАОУ Лицей №36	f	large
72009	82401	113	Саратовская область, Саратов, Огородная, 33а, МОУ СОШ № 106	f	large
72007	82401	111	Саратовская область, Саратов, Огородная, 33а, МОУ СОШ № 106	f	large
72010	82401	114	Саратовская область, Саратов, Огородная, 33а, МОУ СОШ № 106	f	large
72099	82396	104	Саратовская область, Саратов, Огородная, 173, МОУ СОШ № 173	f	large
72098	82395	103	Саратовская область, Саратов, Огородная, 173, МОУ СОШ № 78	f	large
72096	82394	101	Саратовская область, Саратов, Огородная, 196, МОУ СОШ № 5	f	large
72097	82392	102	Саратовская область, Саратов, Огородная, 196, МОУ СОШ № 5	f	large
72095	82392	99	Саратовская область, Саратов, Огородная, 196, МОУ СОШ № 5	f	large
72094	82392	98	Саратовская область, Саратов, Огородная, 196, МОУ СОШ № 5	f	large
72216	82577	354	Саратовская область, Саратов, Новоузенская, 166/168, Детский сад №186	f	large
71963	82368	59	Саратовская область, Саратов, Ново-Крекингская, 47, МОУ ООШ № 26	f	large
72001	82362	54	Саратовская область, Саратов, Ново-Крекингская, 47, МОУ ООШ № 26	f	large
72008	82402	112	Саратовская область, Саратов, Ново-Астраханское шоссе, 47, Библиотека № 31	f	large
72087	82387	88	Саратовская область, Заводской район, Саратов, Ново-Астраханское шоссе, 56, МУК Центр культуры и досуга	f	large
119701	82417	131	Саратовская область, Саратов, Наумовская, 31, Детская поликлиника №4	f	medium
72023	82415	129	Саратовская область, Саратов, Наумовская, 11, МОУ СОШ №17	f	large
72022	82415	128	Саратовская область, Саратов, Наумовская, 11, МОУ СОШ №17	f	large
72134	82489	223	Саратовская область, Саратов, Московское шоссе, 4, ОАО Трансаммиак	f	large
72133	82488	222	Саратовская область, Саратов, Московское шоссе, 17, ЗАО АКБ Экспресс-Волга	f	large
72052	82440	160	Саратовская область, Саратов, Московская, 137/149, Поликлиника №1	f	large
72015	82408	120	Саратовская область, Саратов, Московская, 170, ОАО СарАвтовокзал	f	large
71959	82323	21	Саратовская область, Саратов, Московская, 64, МОУ Лицей №4	f	large
71960	82323	22	Саратовская область, Саратов, Московская, 64, МОУ Лицей №4	f	large
72264	82573	350	Саратовская область, Саратов, Мичурина, 2/12, Дет/сад №236 Лукоморье	f	large
72261	82570	347	Саратовская область, Саратов, Мичурина, 16, МОУ СОШ №2	f	large
72260	82570	346	Саратовская область, Саратов, Мичурина, 16, МОУ СОШ №2	f	large
72200	82524	282	Саратовская область, Саратов, Мичурина, 85, общежитие СГППК им.Гагарина	f	large
71979	82341	27	Саратовская область, Саратов, Мичурина, 202, ГОУ СПО Саратовский государственный колледж книжного бизнеса и информационных технологий	f	large
71951	82333	11	Саратовская область, Саратов, Мичурина, 202	f	large
72255	82564	340	Саратовская область, Саратов, Мирный переулок, 3	f	large
72108	82464	192	Саратовская область, Саратов, Мира, 15, Спортцентр Сокол	f	large
119707	82463	191	Саратовская область, Саратов, Мира, 9В, МДОУ Детский сад №132	f	\N
72122	82481	210	Саратовская область, Саратов, Мелиораторов, МОУ СОШ №69	f	large
72111	82469	197	Саратовская область, Саратов, Международная, 24	f	large
71942	83683	1494	Саратовская область, Саратов, Маркина, 66, Здание администрации	f	large
72084	82385	85	Саратовская область, Саратов, Маркина, 17/39, МОУ СОШ № 39	f	large
71767	83844	1652	Саратовская область, Саратов, Марины Расковой, 4, диспетчерская ООО Транс-Лайн	f	large
71765	83842	1650	Саратовская область, Саратов, Марины Расковой, 4, СОК	f	large
72088	82388	89	Саратовская область, Саратов, Марины Расковой, 12, МОУ Гимназия № 58	f	large
72090	82388	91	Саратовская область, Саратов, Марины Расковой, 12, МОУ Гимназия № 58	f	large
72089	82388	90	Саратовская область, Саратов, Марины Расковой, 12, МОУ Гимназия № 58	f	large
119717	82520	273	Саратовская область, Саратов, Мамонтовой, 1	f	medium
72129	82486	218	Саратовская область, Саратов, Мало-Елшанская, 5, МОУ СОШ №89	f	large
72128	82486	217	Саратовская область, Саратов, Мало-Елшанская, 5, МОУ СОШ №89	f	large
72050	82438	158	Саратовская область, Саратов, Максима Горького, 91, МОУ ДОД Школа искусств №10	f	large
119691	82359	51	Саратовская область, Заводской район, Саратов, Лесопильная, 17, МОУ ООШ № 104	f	medium
72027	82418	134	Саратовская область, Саратов, Лесная, 1/9, МОУ СОШ №31	f	large
72026	82418	133	Саратовская область, Саратов, Лесная, 1/9, МОУ СОШ №31	f	large
72025	82418	132	Саратовская область, Саратов, Лесная, 1/9, МОУ СОШ №31	f	large
72151	82501	242	Саратовская область, Ленинский район, Саратов, Лебедева-Кумача, МОУ СОШ №101	f	large
72150	82501	241	Саратовская область, Ленинский район, Саратов, Лебедева-Кумача, МОУ СОШ №101	f	large
72149	82501	240	Саратовская область, Ленинский район, Саратов, Лебедева-Кумача, МОУ СОШ №101	f	large
72166	82512	260	Саратовская область, Саратов, Куприянова, 16, стоматологическая полик-ка	f	large
72091	82390	93	Саратовская область, Саратов, Крымская, 2, МОУ СОШ № 83	f	large
72115	82475	203	Саратовская область, Саратов, Крылова, 1, клуб Современник	f	large
72016	82409	121	Саратовская область, Саратов, Краевая, 85, ГУП Бизнес-инкубатор	f	large
71980	82342	28	Саратовская область, Саратов, Комсомольская улица, 41, ГУК Саратовский областной Дом работников искусства	f	large
71947	82331	7	Саратовская область, Саратов, Комсомольская, 39, МОУ Лицей прикладных наук	f	large
119919	82884	692	Саратовская область, Саратов, Колхозная площадь, 1, толыпинский сельский ДК	f	medium
72250	82550	325	Саратовская область, Саратов, Клочкова, 77, МОУ СОШ №97	f	large
72249	82550	324	Саратовская область, Саратов, Клочкова, 77, МОУ СОШ №97	f	large
72247	82547	322	Саратовская область, Саратов, Клиническая, 7, спорткомплекс Салют	f	large
72244	82547	319	Саратовская область, Саратов, Клиническая, 7, спорткомплекс Салют	f	large
72252	82561	337	Саратовская область, Саратов, Кирова проспект, 2	f	large
72251	82561	336	Саратовская область, Саратов, Кирова проспект, 2	f	large
71975	82376	72	Саратовская область, Саратов, Кавказская, 17, МОУ СОШ № 40	f	large
71974	82376	71	Саратовская область, Саратов, Кавказская, 17, МОУ СОШ № 40	f	large
71972	82374	69	Саратовская область, Саратов, Кавказская, 2-А, МОУ Детский сад № 44	f	large
72170	82532	295	Саратовская область, Саратов, Ильинская площадь, 1, МОУ Лицей № 62	f	large
72168	82530	293	Саратовская область, Саратов, Ильинская площадь, 4, Колледж производ. технологий	f	large
72172	82529	297	Саратовская область, Саратов, Ильинская площадь, 1, МОУ Лицей №62	f	large
72210	82529	292	Саратовская область, Саратов, Ильинская площадь, 1, МОУ Лицей №62	f	large
72032	82422	140	Саратовская область, Саратов, Зенитная, 14, Центр социальной помощи	f	large
72048	82436	156	Саратовская область, Саратов, Зеленая, 28, ГОУ НПО ПУ №39	f	large
119703	82445	167	Саратовская область, Саратов, Зарубина, 158/162, Цент. библиотеч. сист	f	medium
72003	82367	58	Саратовская область, Саратов, Заречная, 1, МОУ ООШ № 90	f	large
119714	82495	232	Саратовская область, Саратов, Загороднева, 2	f	\N
119713	82494	231	Саратовская область, Саратов, Загороднева, 2	f	\N
72140	82492	229	Саратовская область, Саратов, Загороднева, 16, МОУ СОШ №50	f	large
71603	81036	1684	Самарская область, Тольятти, Мира, 116	f	large
72139	82492	228	Саратовская область, Саратов, Загороднева, 16, МОУ СОШ №50	f	large
72046	82434	154	Саратовская область, Саратов, Жуковского, 25, Аэропорт Саратов-Центральный	f	large
72041	82430	149	Саратовская область, Саратов, Жуковского, 24, МОУ СОШ №24	f	large
72040	82430	148	Саратовская область, Саратов, Жуковского, 24, МОУ СОШ №24	f	large
72039	82429	147	Саратовская область, Саратов, Жуковского, 1, МОУ СОШ 93	f	large
72038	82428	146	Саратовская область, Саратов, Жуковского, 1, МОУ СОШ №93	f	large
72011	82403	115	Саратовская область, Саратов, Железнодорожная, 61/69, Городская поликлиника №2	f	large
119706	82459	185	Саратовская область, Саратов, Дубовикова, 5, т.55-53-24 МДОУ Детский сад компенсирующего вида № 199 (было:Тверскаяд. 45 МОУ СОШ №41)	f	\N
71956	82337	17	Саратовская область, Саратов, Державинская улица, 1, МОУ СОШ №66 им. Н.И.Вавилова	f	large
71955	82337	16	Саратовская область, Саратов, Державинская улица, 1, МОУ СОШ №66 им. Н.И.Вавилова	f	large
71958	81759	20	Саратовская область, Саратов, Державинская, 10, МОУ Лицей №107	f	large
119705	82454	177	Россия, Саратовская область, Саратов, Деловой проезд, 3	f	\N
72232	82540	307	Саратовская область, Саратов, Дегтярная, 12, МОУ СОШ №45	f	large
72180	82540	306	Саратовская область, Саратов, Дегтярная, 12, МОУ СОШ №45	f	large
72171	82533	296	Саратовская область, Саратов, Дегтярная, 11, МОУ СОШ №27	f	large
72233	82533	308	Саратовская область, Саратов, Дегтярная, 11, МОУ СОШ №27	f	large
72037	82427	145	Саратовская область, Саратов, Высокая, 17А, МДОУ Детский сад №131	f	large
71981	82343	29	Саратовская область, Саратов, Вознесенская улица, 5, МОУ Гимназия №4	f	large
72069	82456	179	Саратовская область, Саратов, Вишневая, 20, МОУ СОШ №76	f	large
72068	82455	178	Саратовская область, Саратов, Вишневая, 20, МОУ СОШ №76	f	large
72076	82378	77	Саратовская область, Саратов, Васильковская, 17, МОУ ООШ № 8	f	large
72075	82378	76	Саратовская область, Саратов, Васильковская, 17, МОУ ООШ № 8	f	large
72074	82378	75	Саратовская область, Саратов, Васильковская, 17, МОУ ООШ № 8	f	large
71742	83829	1637	Саратовская область, Саратов, Вавилова, 2, здание Дома досуга Прибрежновский	f	large
71999	82360	52	Саратовская область, Саратов, Брянская, 3, МОУ Кадетская школа № 16	f	large
72058	82444	166	Саратовская область, Саратов, Большая Садовая, 240, МОУ СОШ №70	f	large
119700	82412	125	Саратовская область, Саратов, Большая Садовая, 239, МДОУ Детский сад №18	f	medium
72263	82572	349	Саратовская область, Саратов, Большая Казачья, 125, ОАО Газаппарат	f	large
72262	82571	348	Саратовская область, Саратов, Большая Казачья, 121, МАОУ Гимназия №3	f	large
72254	82563	339	Саратовская область, Саратов, Большая Казачья, 43, Дет/сад №180 Солнышко	f	large
72065	82450	173	Саратовская область, Саратов, Большая Казачья, 112а, СГУ им.Черныш. корпус №8	f	large
71984	82347	33	Саратовская область, Саратов, Большая Горная улица, 141а, МОУ Гуманитарно-экономический лицей	f	large
72057	82443	165	Саратовская область, Саратов, Большая Горная улица, 231а, Музыкальная школа №7	f	large
72056	82442	164	Саратовская область, Саратов, Большая Горная, 277, Центр детского твор-ва	f	large
71985	82346	34	Саратовская область, Саратов, Большая Горная, 141а, МОУ Гуманитарно-экономический лицей	f	large
71983	82346	32	Саратовская область, Саратов, Большая Горная, 141а, МОУ Гуманитарно-экономический лицей	f	large
71982	82344	30	Саратовская область, Саратов, Большая Горная, 1, ГОУ ДПО Саратовский институт повышения квалификации и переподготовки работников образования	f	large
72184	82515	265	Саратовская область, Саратов, Блинова, 19а, детский сад №156	f	large
72183	82514	264	Саратовская область, Саратов, Блинова, 23а, детский сад №167	f	large
72042	82431	150	Саратовская область, Саратов, Бирюзова, 14, ГОУ СПО Техникум ПТ и АС	f	large
134457	94355	200	Саратовская область, Саратов, Бережная, 1, МОУ СОШ №72	f	large
72112	82471	199	Саратовская область, Саратов, Бережная, 1, МОУ СОШ №72	f	large
119710	82470	198	Саратовская область, Саратов, Бережная, 1, МОУ СОШ №72	f	\N
72033	82424	141	Саратовская область, Саратов, Безымянная, 6, Городская поликлиника №11	f	large
72193	82521	275	Саратовская область, Саратов, Батавина, 6а, МОУ СОШ №60	f	large
72192	82521	274	Саратовская область, Саратов, Батавина, 6а, МОУ СОШ №60	f	large
71690	83896	1733	Саратовская область, Саратов, Аткарская , 12/14	f	large
72235	82542	310	Саратовская область, Саратов, Аткарская, 1В, МОУ СОШ №7	f	large
72234	82542	309	Саратовская область, Саратов, Аткарская, 1В, МОУ СОШ №7	f	large
72236	82542	311	Саратовская область, Саратов, Аткарская, 1В, МОУ СОШ №7	f	large
134456	94354	136	Саратовская область, Саратов, Артиллерийская, 23, МОУ СОШ №51	f	large
134455	94354	135	Саратовская область, Саратов, Артиллерийская, 23, МОУ СОШ №51	f	large
72024	82416	130	Саратовская область, Саратов, Аптечная, 33/47, МАОУ Кристаллик	f	large
72081	82383	82	Саратовская область, Саратов, Азовская, 15, МОУ ООШ № 39	f	large
72082	82383	83	Саратовская область, Саратов, Азовская, 15, МОУ ООШ № 39	f	large
71964	82369	60	Саратовская область, Саратов, Азина, 34, МУК ДК Химиков	f	large
72110	82468	196	Саратовская область, Саратов, 50 Лет Октября проспект, 107, МОУ Гимназия №108	f	large
119709	82466	194	Россия, Саратовская область, Саратов, 50 Лет Октября проспект, 107	f	\N
72071	82457	181	Саратовская область, Саратов, 50 Лет Октября проспект, 75, МОУ СОШ №94	f	large
72070	82457	180	Саратовская область, Саратов, 50 Лет Октября проспект, 75, МОУ СОШ №94	f	large
72020	82413	126	Саратовская область, Саратов, 50 Лет Октября проспект, 34	f	large
72005	82400	109	Саратовская область, Саратов, 5-й Нагорный проезд, 3, МОУ СОШ № 23	f	large
72006	82400	110	Саратовская область, Саратов, 5-й Нагорный проезд, 3, МОУ СОШ № 23	f	large
72004	82400	108	Саратовская область, Саратов, 5-й Нагорный проезд, 3, МОУ СОШ № 23	f	large
72102	82399	107	Саратовская область, Саратов, 5-й Нагорный проезд, 3, МОУ СОШ № 23	f	large
71997	82356	48	Саратовская область, Саратов, 4-й проезд Чернышевского, 2, МОУ СОШ № 53	f	large
71996	82356	47	Саратовская область, Саратов, 4-й проезд Чернышевского, 2, МОУ СОШ № 53	f	large
71995	82356	46	Саратовская область, Саратов, 4-й проезд Чернышевского, 2, МОУ СОШ № 53	f	large
71994	82355	45	Саратовская область, Саратов, 4-й проезд Чернышевского, 2, МОУ СОШ № 53	f	large
72125	82484	214	Саратовская область, Саратов, 3-я Степная, 6, МОУ Лицей №47	f	large
72124	82484	213	Саратовская область, Саратов, 3-я Степная, 6, МОУ Лицей №47	f	large
72123	82484	212	Саратовская область, Саратов, 3-я Степная, 6, МОУ Лицей №47	f	large
72126	82484	215	Саратовская область, Саратов, 3-я Степная, 6, МОУ Лицей №47	f	large
72147	82499	238	Саратовская область, Саратов, 3-й Строителей проезд, 3	f	large
72146	82499	237	Саратовская область, Саратов, 3-й Строителей проезд, 3	f	large
72145	82499	236	Саратовская область, Саратов, 3-й Строителей проезд, 3	f	large
72127	82485	216	Саратовская область, Саратов, 2-я Степная улица, 8, МОУ ООШ №64	f	large
72243	82545	318	Саратовская область, Саратов, 2-я Садовая, 106а, МОУ СОШ №82	f	large
72240	82545	315	Саратовская область, Саратов, 2-я Садовая, 106а, МОУ СОШ №82	f	large
72178	82539	304	Саратовская область, Саратов, 2-я Садовая, 39/53, женск.консультация пол.№8	f	large
72177	82538	303	Саратовская область, Саратов, 2-я Садовая, 23А, МДОУ Детский сад №21	f	large
72175	82536	301	Саратовская область, Саратов, 2-я Садовая, 19, Детский сад №31 Колосок	f	large
72174	82534	299	Саратовская область, Саратов, 2-я Садовая, 23, МОУ СОШ №95	f	large
72179	82534	305	Саратовская область, Саратов, 2-я Садовая, 23, МОУ СОШ №95	f	large
72132	82487	221	Саратовская область, Саратов, 2-й Московский проезд, 5, МОУ СОШ №86	f	large
72131	82487	220	Саратовская область, Саратов, 2-й Московский проезд, 5, МОУ СОШ №86	f	large
72130	82487	219	Саратовская область, Саратов, 2-й Московский проезд, 5, МОУ СОШ №86	f	large
72036	82426	144	Саратовская область, Саратов, 2-й Магнитный проезд, 44, МОУ СОШ №73	f	large
72035	82426	143	Саратовская область, Саратов, 2-й Магнитный проезд, 44, МОУ СОШ №73	f	large
72241	82546	316	Саратовская область, Саратов, 1-я линия, 3, МОУ Лицей №2	f	large
72248	82543	323	Саратовская область, Саратов, 1-я линия, 3, МОУ Лицей №2	f	large
72242	82543	317	Саратовская область, Саратов, 1-я линия, 3, МОУ Лицей №2	f	large
72238	82543	313	Саратовская область, Саратов, 1-я линия, 3, МОУ Лицей №2	f	large
72237	82543	312	Саратовская область, Саратов, 1-я линия, 3, МОУ Лицей №2	f	large
72049	82437	157	Саратовская область, Саратов, 1-я Садовая улица, 35, МОУ СОШ №14	f	large
71989	82349	38	Саратовская область, Саратов, 1-я Садовая, 2, МОУ Восточно-Европейский лицей	f	large
71899	83880	1708	Саратовская область, Саратов, 1-я Одесская улица, 34, МОУ СОШ № 16	f	large
72117	82477	205	Саратовская область, Саратов, 1-я Елшанская, 60	f	large
72245	82548	320	Саратовская область, Саратов, 1-я Детская, 36/40, МОУ СОШ №82	f	large
119711	82473	201	Саратовская область, Саратов, 1-й проезд Панфилова, 1, МДОУ Детский сад комбинированного вида №172	f	\N
72080	82382	81	Саратовская область, Саратов, 1-й Тульский проезд, 6а, МОУ Гимназия № 5	f	large
72079	82381	80	Саратовская область, Саратов, 1-й Тульский проезд, 10, МОУ Гимназия № 5	f	large
72047	82435	155	Саратовская область, Саратов, 1-й Топольчанский проезд, 5а, МДОУ Детский сад №112	f	large
71991	82351	40	Саратовская область, Саратов, 1-й Соколовогорский проезд, 1, МОУ СОШ №11	f	large
71992	82351	41	Саратовская область, Саратов, 1-й Соколовогорский проезд, 1, МОУ СОШ №11	f	large
72114	82474	202	Саратовская область, Саратов, 1-й Панфилова проезд, 3, МОУ СОШ №100	f	large
72002	82366	57	Саратовская область, Саратов, 1-й Нефтяной проезд, 1, Филиал МОУ СОШ № 83	f	large
72186	82516	267	Саратовская область, Саратов, Перспективная, 10а, МОУ СОШ №49	f	large
72185	82516	266	Саратовская область, Саратов, Перспективная, 10а, МОУ СОШ №49	f	large
119729	82568	344	Саратовская область, Саратов, Астраханская, 77, ФГБОУ ВПО СГУ им. Чернышевского Колледж радиоэлектроники им. Яблочкова	f	\N
71874	83595	1408	Саратовская область, Ртищево, Яблочкова, 13, СШ №5	f	large
71758	83606	1419	Саратовская область, Ртищево, Чкалова, 6, СШ №4	f	large
71761	83605	1418	Саратовская область, Ртищево, Советская, 30, СШ №2 1 этаж	f	large
71752	83604	1417	Саратовская область, Ртищево, Советская, 30, СШ №2 Актовый зал	f	large
71873	83594	1407	Саратовская область, Ртищево, Сердобский тупик, 19, здание Дистанции пути	f	large
71876	83597	1410	Саратовская область, Ртищево, Пугачевская, 82, СШ №1	f	large
71751	83603	1416	Саратовская область, Ртищево, Переулок Ветеринарный, 1 , Ветлечебница	f	large
71871	83592	1405	Саратовская область, Ртищево, М. Горького, 38а, Библиотека	f	large
71760	83609	1422	Саратовская область, Ртищево, Котовского, 1, Клуб в\\ч 06807	f	large
71875	83596	1409	Саратовская область, Ртищево, К. Маркса, 13, ПУ №12	f	large
71870	83591	1404	Саратовская область, Ртищево, Ильича, 78, СШ №7	f	large
71759	83607	1420	Саратовская область, Ртищево, Зои Космодемьянской, 19, ФОК Юность	f	large
71729	83602	1415	Саратовская область, Ртищево, Железнодорожная, 66, СШ №9	f	large
71878	83600	1413	Саратовская область, Ртищево, Железнодорожная, 21, СШ № 7	f	large
120470	83599	1412	Саратовская область, Ртищево, Железнодорожная, 12, Дом кино	f	medium
120469	83590	1403	Саратовская область, Ртищево, Горная, 1, ДК Спутник	f	small
71877	83598	1411	Саратовская область, Ртищево, Алексея Громова, 12, Библиотека им. А. Пушкина	f	large
71879	83601	1414	Саратовская область, Ртищево, 60 лет Октября, 14, Автошкола РОСТО	f	large
71872	83593	1406	Саратовская область, Ртищево, 22 Партсъезда, 3, Техникум	f	large
71706	83703	1514	Саратовская область, поселок Расково, МОУ СОШ	f	large
71805	83515	1330	Саратовская область, Пугачев, Урицкого, 3, СОШ №3	f	large
71804	83514	1329	Саратовская область, Пугачев, Топорковская, 40/1, СОШ № 1	f	large
71782	83504	1318	Саратовская область, Пугачев, Топорковская, 99, ФОК Олимп	f	large
120411	83509	1324	Саратовская область, Пугачев, Рев.Проспект, 272, Магазин Легенда307	f	medium
120412	83510	1325	Саратовская область, Пугачев, Пушкинская, 316, Филиал СОШ №3	f	medium
71783	83505	1319	Саратовская область, Пугачев, М.Горького, 155 , СОШ № 13	f	large
71779	83501	1315	Саратовская область, Пугачев, Кутякова, 70, СОШ № 14	f	large
71778	83500	1314	Саратовская область, Пугачев, Кутякова, 70, СОШ № 14	f	large
71806	83516	1331	Саратовская область, Пугачев, Коммунистическая, 12, СОШ №2	f	large
120410	83476	1322	Саратовская область, Пугачев, Карьер МВД-4, Филиал Пугачевские СЭС	f	medium
71781	83503	1317	Саратовская область, Пугачев, Интернациональная, 122, Филиал Городские ЭС	f	large
120409	83507	1321	Саратовская область, Пугачев, Железнодорожная, 10 , МУП Дорожник	f	medium
134484	94381	1332	Саратовская область, Пугачев, Горького, 56 , Кафе № 1	f	large
71708	83444	1258	Саратовская область, Петровск, Шамаева, 99, МОУ СОШ №2	f	large
71712	83449	1263	Саратовская область, Петровск, Чернышевского, 205 , МОУ СОШ №1	f	large
71715	83452	1266	Саратовская область, Петровск, Спартака, 5 , МОУ СОШ №8	f	large
71713	83450	1264	Саратовская область, Петровск, Советская, 2 , Дом физкультуры	f	large
71707	83443	1257	Саратовская область, Петровск, Радищева, 21 , МОУ СОШ №5	f	large
71711	83448	1262	Саратовская область, Петровск, Московская, 8 , здание картинной галереи	f	large
71710	83446	1260	Саратовская область, Петровск, Московская, 86, районный Дом культуры	f	large
120366	83453	1268	Саратовская область, Петровск, Железнодорожная, 16 , КДЦ Современник	f	medium
120365	83453	1267	Саратовская область, Петровск, Железнодорожная, 16 , КДЦ Современник	f	medium
71714	83451	1265	Саратовская область, Петровск, Гоголя, 51, МОУ СОШ №8	f	large
71709	83445	1259	Саратовская область, Петровск, 25 лет Октября, 164-А, МОУ СОШ №7	f	large
120286	83361	1174	Саратовская область, Новоузенск, дом кино Юность	f	\N
71905	83331	1143	Саратовская область, Маркс, проспект Строителей, 1, Центральный дом культуры	f	large
71869	83330	1142	Саратовская область, Маркс, пр. Ленина, 107, ГОУ НПО Профессиональный лицей №46	f	large
71906	83322	1144	Саратовская область, Маркс, Строителей, 22, МОУ-средняя общеоб.школа №3	f	large
71863	83322	1133	Саратовская область, Маркс, Строителей, 22, МОУ-средняя общеоб.школа №3	f	large
71866	83327	1139	Саратовская область, Маркс, Рабочая, 195, МОУ-сред. общеоб.школа №5	f	large
71864	83314	1137	Саратовская область, Маркс, Победы, 10, МОУДОД Центр внешкол.работы	f	large
71865	83326	1138	Саратовская область, Маркс, Ленина, 60, 68, помещение общежития №1, ФГОУ СПО Марксовский с/х техникум, в помещении спорт. зала №1	f	large
71867	83328	1140	Саратовская область, Маркс, Интернациональная площадь, 10, МОУ-средняя общеоб.школа №4	f	large
120262	83324	1135	Саратовская область, Маркс, Загородная роща, 27, ОАО Пивзавод - Марксовский	f	\N
71868	83329	1141	Саратовская область, Маркс, 6-я линия, 35, филиал СГСЭУ 2 корпус	f	large
71907	83332	1145	Саратовская область, Маркс, 10-я линия, 47, Админист.здание ОАОАлтаец	f	large
120133	83174	988	Саратовская область, Красноармейск, Танцорова, 1, МОУ СОШ № 1	f	\N
72463	83172	986	Саратовская область, Красноармейск, Почтовая, 42, МОУ СОШ № 2	f	large
72462	83172	985	Саратовская область, Красноармейск, Почтовая, 42, МОУ СОШ № 2	f	large
72468	83162	975	Саратовская область, Красноармейск, Луначарского, 33 , МОУ СОШ № 8	f	large
72472	83167	979	Саратовская область, Красноармейск, Коммунистическая, 3, МОУ СОШ № 5	f	large
72471	83166	978	Саратовская область, Красноармейск, Коммунистическая, 3, МОУ СОШ № 5	f	large
72464	83173	987	Саратовская область, Красноармейск, Кирова, 9, ДЮСШ № 1	f	large
72467	83161	974	Саратовская область, Красноармейск, Захарова, 57, МОУ СОШ № 4	f	large
72470	83164	977	Саратовская область, Красноармейск, Богдана Хмельницкого, 111 , филиал МАК Колледж	f	large
72461	83170	983	Саратовская область, Красноармейск, 5 микрорайон, дание МОУ СОШ № 3 	f	large
72460	83168	980	Саратовская область, Красноармейск, 5 микрорайон, Здание филиала РДК	f	large
120130	83168	981	Саратовская область, Красноармейск, 5 микрорайон, Здание филиала РДК	f	\N
120132	83171	984	Саратовская область, Красноармейск, 3-й Фабричный переулок, 18, ДЮСШ № 2	f	medium
120131	83169	982	Саратовская область, Красноармейск, 1 микрорайон, 43, Здание начальной школы МОУ СОШ №5 СОШ №3	f	medium
72469	83163	976	Саратовская область, Красноармейск, 1 Мая, 61, Районный Дворец культуры	f	large
120535	83681	1492	Саратовская область, деревня Кокурино, Центральная, 3 , Фельдшерско-акушерский пункт	f	small
72440	83126	939	Саратовская область, Калининск, Советская, 9, МОУ СОШ №2	f	large
134498	94393	1783	Саратовская область, ЗАТО Михайловский, 60 лет Победы, 7, Дом культуры	f	medium
72407	82893	701	Саратовская область, Вольск, улица Чернышевского, 72, МОУ СКОШ № 14	f	large
119927	82901	709	Саратовская область, Вольск, поселок завода Красный Октябрь, 35, МОУ СОШ № 17	f	medium
72375	82905	713	Саратовская область, Вольск, площадь Юности, 1, МОУ СОШ № 6	f	large
72412	82912	719	Саратовская область, Вольск, площадь Свободы, 1, МОУ СПО музучилище	f	large
119930	82904	712	Саратовская область, Вольск, площадь Равенства, 96, МОУ Гимназия	f	medium
72423	82920	730	Саратовская область, Вольск, Школьная, 7-А, МОУ СОШ № 11	f	large
119933	82920	729	Саратовская область, Вольск, Школьная, 7-А, МОУ СОШ № 11	f	medium
72410	82900	708	Саратовская область, Вольск, Чехова, 16 , библиотека № 7	f	large
119922	82892	700	Саратовская область, Вольск, Цементников, 97, МОУ ООШ № 10	f	medium
119921	82891	699	Саратовская область, Вольск, Цементников, 184, библиотека № 2	f	medium
72413	82913	720	Саратовская область, Вольск, Струина, 2 , ЦДО Радуга	f	large
72405	82889	697	Саратовская область, Вольск, Свердлова, 9-А, ГОУ НПО ПУ № 5	f	large
72376	82906	714	Саратовская область, Вольск, Саратовская, 44, ФГОУ СПО стройколледж	f	large
72378	82909	716	Саратовская область, Вольск, Революционная, 46, управление образования	f	large
119928	82902	710	Саратовская область, Вольск, Пятницкого, 5, магазин ООО Дельфин	t	small
119931	82910	717	Саратовская область, Вольск, Пугачева, 56 , МОУ Лицей	f	small
72414	82914	721	Саратовская область, Вольск, Одесская, 2, ФГУП СО Облводоресурс	f	large
72409	82899	707	Саратовская область, Вольск, Некрасова, 28, МОУ СОШ № 17	f	large
119926	82898	706	Саратовская область, Вольск, Льва Толстого, 253, ГОУ СПО Медколледж	f	medium
119924	82896	704	Саратовская область, Вольск, Краснооктябрьская, 1-А, УК Трансстройсервис	f	medium
72379	82911	718	Саратовская область, Вольск, Красногвардейская, 7-А, МОУ СОШ № 16	f	large
72377	82908	715	Саратовская область, Вольск, Красногвардейская, 56, МОУ СОШ № 19	f	large
119932	82919	728	Саратовская область, Вольск, Комсомольская, 251 , здание ОТШ РОСТО	f	medium
72422	82918	727	Саратовская область, Вольск, Комсомольская, 202, ГОУ СПО Педколледж	f	large
72418	82916	725	Саратовская область, Вольск, Комсомольская, 161, ГОУ НПО ТУ № 25	f	large
72404	82888	696	Саратовская область, Вольск, Коммунарная, 30-А, МОУ СОШ № 5	f	large
119925	82897	705	Саратовская область, Вольск, Володарского, 200 , библиотека № 3	f	medium
119929	82903	711	Саратовская область, Вольск, Волжская, 25, клуб пос. Рыбное	t	small
72417	82915	724	Саратовская область, Вольск, Волгоградская, 52-А, МОУ СОШ № 3	f	large
72416	82915	723	Саратовская область, Вольск, Волгоградская, 52-А, МОУ СОШ № 3	f	large
72415	82915	722	Саратовская область, Вольск, Волгоградская, 52-А, МОУ СОШ № 3	f	large
120534	83680	1491	Саратовская область, поселок Водник, Фельдшерско-акушерский пункт	f	small
119869	82826	624	Саратовская область, Балашов, МОУ ДОД Станция юных техников	f	\N
134471	94368	610	Саратовская область, Балашов, переулок Вокзальный, 6, Уч.центр траспортной отрасли	f	large
72361	82818	614	Саратовская область, Балашов, пер. Школьный, 14, Станция юных натуралистов	f	large
72284	82839	636	Саратовская область, Балашов, Юбилейная, 13, СШ № 3	f	large
119871	82835	632	Саратовская область, Балашов, Шоссейная, 9, АП здание МУЗ Балашовская ЦРБ поликлиника №2	f	\N
72368	82825	622	Саратовская область, Балашов, Шоссейная, 9	f	large
72369	82827	625	Саратовская область, Балашов, Фестивальная, 2, ПУ-15	f	large
72372	82832	629	Саратовская область, Балашов, Титова, 2, СШ № 4	f	large
119868	82824	623	Саратовская область, Балашов, Титова, 13	f	\N
119867	82824	621	Саратовская область, Балашов, Титова, 13	f	\N
72283	82838	635	Саратовская область, Балашов, Строителей, 9 А, СШ № 15	f	large
72282	82837	634	Саратовская область, Балашов, Строителей, 9 А, СШ № 15	f	large
72364	82821	617	Саратовская область, Балашов, Софинского, 13 , МОУ СОШ № 16	f	large
119858	81487	590	Саратовская область, Балашов, Софинского, 13, СШ № 16	f	medium
119865	82811	607	Саратовская область, Балашов, Пушкина, 51, МОУ СОШ № 7	f	medium
119864	82810	606	Саратовская область, Балашов, Пугачевская, 287, МОУ СОШ № 5	f	medium
72353	82808	603	Саратовская область, Балашов, Пугачевская, 328, Балашовское мед. училище	f	large
134468	94365	591	Саратовская область, Балашов, Нефтяная, 44б, бывшая СШ № 14	f	large
119859	82798	592	Саратовская область, Балашов, Нефтяная, 54, Клуб Балашовского Дома-интерната для престарелых и инвалидов	f	medium
72365	82822	618	Саратовская область, Балашов, Нарадноя, 38, здание филиала СГСЭУ	f	large
134472	94369	628	Саратовская область, Балашов, Менделеева, 7 , Детский сад Черемушки	f	large
134470	94367	599	Саратовская область, Балашов, Ленина, 22 , Гимназия им. Ю.А. Гарнаев	f	medium
72352	82805	602	Саратовская область, Балашов, Ленина, 5, Кинотеатр Победа	f	large
119862	82805	600	Саратовская область, Балашов, Ленина, 5, Кинотеатр Победа	f	medium
72355	82802	605	Саратовская область, Балашов, Ленина, 31, Кооперативный техникум	f	large
72351	82802	597	Саратовская область, Балашов, Ленина, 31, Кооперативный техникум	f	large
72367	82823	620	Саратовская область, Балашов, Красина, 97, МУЗ Балашовская ЦРП	f	large
134469	94366	595	Саратовская область, Балашов, Коммунистическая, 188, МУП Балашов-благоустройство и озеленение	f	large
72358	82815	611	Саратовская область, Балашов, К. Маркса, 96, Центр культуры	f	large
72354	82809	604	Саратовская область, Балашов, К. Маркса, 25 , Балашовское муз. училище	f	large
72356	82813	609	Саратовская область, Балашов, Депутатская, 29, Лицей-интернат	f	large
119863	82806	601	Саратовская область, Балашов, Володарского, 35, учебный корпус Балашовского института СГУ им.Чернышевского	f	\N
119866	82812	608	Саратовская область, Балашов, Вокзальный переулок, 8	f	\N
72373	82833	630	Саратовская область, Балашов, Балашов-3, Гарнизонный Дом офицеров	f	large
72281	82836	633	Саратовская область, Балашов, 50 лет ВЛКСМ, 2, Гимназия № 	f	large
72370	82829	626	Саратовская область, Балашов, 50 лет ВЛКСМ, 2, Гимназия № 1	f	large
72320	82727	507	Саратовская область, Балаково, МУДОД ДЮСШ №2	f	large
72338	82742	527	Саратовская область, Балаково, Шевченко, 1А, МОУ СОШ №19	f	large
72317	82724	504	Саратовская область, Балаково, Чапаева, 140, ФГБОУ ВПО БИТТиУ	f	large
72314	82719	501	Саратовская область, Балаково, Факел Социализма, 27, ФГОУ СПО Бал. техникум	f	large
72294	82719	495	Саратовская область, Балаково, Факел Социализма, 27, ФГОУ СПО Бал. техникум	f	large
72383	82754	544	Саратовская область, Балаково, Трнавская, 38, МОУ СОШ №28	f	large
72382	82754	543	Саратовская область, Балаково, Трнавская, 38, МОУ СОШ №28	f	large
72385	82754	546	Саратовская область, Балаково, Трнавская, 38, МОУ СОШ №28	f	large
72384	82754	545	Саратовская область, Балаково, Трнавская, 38, МОУ СОШ №28	f	large
72306	82749	538	Саратовская область, Балаково, Трнавская, 49А, МОУ СОШ №22	f	large
72305	82749	537	Саратовская область, Балаково, Трнавская, 49А, МОУ СОШ №22	f	large
72319	82726	506	Саратовская область, Балаково, Титова, 25А , МУДОД Доп. обр. детей	f	large
72392	82762	555	Саратовская область, Балаково, Степная, 70, МАУ УСК Форум	f	large
119828	82758	551	Саратовская область, Балаково, Степная, 18, Центр: Балаковский институт экономики и бизнеса ФГБОУ ВПО СГСЭУ	f	\N
72388	82757	549	Саратовская область, Балаково, Степная, 30, МОУ СОШ №27	f	large
72389	82756	550	Саратовская область, Балаково, Степная, 30, МОУ СОШ №27	f	large
72387	82756	548	Саратовская область, Балаково, Степная, 30, МОУ СОШ №27	f	large
72390	82755	552	Саратовская область, Балаково, Степная, 70, МАУ УСК Форум	f	large
72386	82755	547	Саратовская область, Балаково, Степная, 70, МАУ УСК Форум	f	large
72293	82718	494	Саратовская область, Балаково, Свердлова, 4, МБУК ГКВЦ кт. Октябрь	f	large
72391	82759	553	Саратовская область, Балаково, Саратовское Шоссе, 83/6, ЦТП-74	f	large
72296	82743	528	Саратовская область, Балаково, Саратовское Шоссе, 33, ГОУ СПО Бал. АЭМ техникум	f	large
72310	82717	497	Саратовская область, Балаково, Редкова, 50 , МОУ СОШ №2	f	large
72295	82717	496	Саратовская область, Балаково, Редкова, 50 , МОУ СОШ №2	f	large
72292	82717	493	Саратовская область, Балаково, Редкова, 50 , МОУ СОШ №2	f	large
119829	82761	554	Саратовская область, Балаково, Привокзальная, 2 Б, ПТП ст. Балаково	f	small
72312	82720	499	Саратовская область, Балаково, Пионерская, 1, МОУ Гимназия №1	f	large
72311	82720	498	Саратовская область, Балаково, Пионерская, 1, МОУ Гимназия №1	f	large
72327	82735	515	Саратовская область, Балаково, Набережная Леонова, 1А , МУК РДК	f	large
72333	82739	521	Саратовская область, Балаково, Минская, 59А , МОУ СОШ №13	f	large
134466	82732	511	Саратовская область, Балаково, Менделеева, 1А, МОУ СОШ №5	f	large
72324	82732	512	Саратовская область, Балаково, Менделеева, 1А, МОУ СОШ №5	f	large
72318	82725	505	Саратовская область, Балаково, Красноармейская, 13, ФГБОУ ВПО БИТТиУ	f	large
72321	82728	508	Саратовская область, Балаково, Комсомольская, 34, ГОУ СПО Бал. п.т.техникум	f	large
72316	82723	503	Саратовская область, Балаково, Комсомольская, 47Б, МОУ СОШ №20	f	large
72315	82722	502	Саратовская область, Балаково, Комсомольская, 31, МОУ СОШ № 7	f	large
72313	82721	500	Саратовская область, Балаково, Комсомольская, 31, МОУ СОШ №7	f	large
72286	82713	487	Саратовская область, Балаково, Коммунистическая, 124А	f	large
72326	82734	514	Саратовская область, Балаково, Комарова, 115 , МОУ СОШ №6	f	large
72298	82744	530	Саратовская область, Балаково, Заречная, 45, МОУ СОШ №26	f	large
72297	82744	529	Саратовская область, Балаково, Заречная, 45, МОУ СОШ №26	f	large
72330	82737	518	Саратовская область, Балаково, Волжская, 1А, МОУ СОШ №10	f	large
119827	82736	522	Саратовская область, Балаково, Волжская, 39, МОУ СОШ №3	f	medium
72329	82736	517	Саратовская область, Балаково, Волжская, 39, МОУ СОШ №3	f	large
72328	82736	516	Саратовская область, Балаково, Волжская, 39, МОУ СОШ №3	f	large
72335	82740	524	Саратовская область, Балаково, Вокзальная, 16А, МОУ СОШ №18	f	large
72334	82740	523	Саратовская область, Балаково, Вокзальная, 16А, МОУ СОШ №18	f	large
72308	82751	540	Саратовская область, Балаково, Бульвар Роз, 5А, МОУ Гимназия №2	f	large
72307	82750	539	Саратовская область, Балаково, Бульвар Роз, 5А, МОУ Гимназия №2	f	large
72291	82716	492	Саратовская область, Балаково, Братьев Захаровых, 8а, МОУ СОШ №25	f	large
72290	82716	491	Саратовская область, Балаково, Братьев Захаровых, 8а, МОУ СОШ №25	f	large
72289	82716	490	Саратовская область, Балаково, Братьев Захаровых, 8а, МОУ СОШ №25	f	large
72381	82753	542	Саратовская область, Балаково, 30 лет Победы, 24, МОУ СОШ №21	f	large
72301	82747	533	Саратовская область, Балаково, 30 лет Победы, 41А, МОУ Лицей №1	f	large
72300	82747	532	Саратовская область, Балаково, 30 лет Победы, 41А, МОУ Лицей №1	f	large
72299	82746	531	Саратовская область, Балаково, 30 лет Победы, 9Б , МОУ ДОД школа искусств №2	f	large
119830	82763	556	Саратовская область, Балаково, 30 Лет Победы, 71, ГУ Дом инвал. и престар.	f	medium
72268	82653	430	Саратовская область, Аткарск, Школьная, 41, детский сад № 7 Яблочко	f	large
72265	82649	426	Саратовская область, Аткарск, Чапаева, 54 , Районный культурный центр	f	large
119782	82650	427	Саратовская область, Аткарск, Советская, 92, МОУ СОШ № 3	f	medium
72340	82646	423	Саратовская область, Аткарск, Локомотивная, 20, МОУ СОШ № 10	f	large
72341	82647	424	Саратовская область, Аткарск, Ленина, 116, МОУ СОШ № 1	f	large
72269	82655	432	Саратовская область, Аткарск, К. Маркса, 40, ГДК Россия	f	large
119783	82654	431	Саратовская область, Аткарск, К. Маркса, 38 , МОУ СОШ № 6	f	medium
72230	82643	419	Саратовская область, Аткарск, Грибоедова, 2, начальная школа-д/с № 7	f	large
72339	82645	422	Саратовская область, Аткарск, Гоголя, 17 , ОАО Аткарский МЭЗ	f	large
119781	82645	421	Саратовская область, Аткарск, Гоголя, 17 , ОАО Аткарский МЭЗ	f	medium
72267	82652	429	Саратовская область, Аткарск, Гагарина, 60, администрация МО г. Аткарск	f	large
119780	82642	418	Саратовская область, Аткарск, Верхне-Красавская, 1, фойе	f	\N
72231	82644	420	Саратовская область, Аткарск, 30 лет Победы, 5, МОУ СОШ № 2	f	large
72223	82609	386	Саратовская область, Аркадак, Ленина, 6, районный Дом культуры	f	large
71915	83678	1489	Саратовская область, село Александровка, Привокзальная, МОУ СОШ с. Александровка	f	large
71927	83889	1720	Саратовская область, Энгельсский район , ст. Анисовка, 3-й квартал , МОУ СОШ № 42	f	large
134495	94390	1759	Саратовская область, Энгельсский район, пос. Анисовский, Молодежная, 1а, МОУ ООШ	f	large
71688	83893	1731	Саратовская область, Энгельсский район, Энгельс, Энгельс-19, 1, ДК Восход	f	large
71687	83893	1730	Саратовская область, Энгельсский район, Энгельс, Энгельс-19, 1, ДК Восход	f	large
71681	83893	1729	Саратовская область, Энгельсский район, Энгельс, Энгельс-19, 1, ДК Восход	f	large
71935	83893	1728	Саратовская область, Энгельсский район, Энгельс, Энгельс-19, 1, ДК Восход	f	large
71934	83893	1727	Саратовская область, Энгельсский район, Энгельс, Энгельс-19, 1, ДК Восход	f	large
71769	81421	1654	Саратовская область, Энгельсский район, Энгельс, Энгельс-1, МОУ СОШ № 15	f	large
71768	81421	1653	Саратовская область, Энгельсский район, Энгельс, Энгельс-1, МОУ СОШ № 15	f	large
71891	83875	1700	Саратовская область, Энгельсский район, Энгельс, Тельмана, 139, МОУ СОШ №1	f	large
71890	83875	1699	Саратовская область, Энгельсский район, Энгельс, Тельмана, 139, МОУ СОШ №1	f	large
71895	83877	1704	Саратовская область, Энгельсский район, Энгельс, Степная, 137, горком ОСТО	f	large
71855	83869	1691	Саратовская область, Энгельсский район, Энгельс, Свердлова, 122, МОУ СОШ № 2	f	large
71764	83841	1649	Саратовская область, Энгельсский район, Энгельс, Садовая, 17, здание детской спортивной школы	f	large
71843	83860	1680	Саратовская область, Энгельсский район, Энгельс, Рабочая, 109а, ГОУ С(К)ОШ № 17	f	large
71815	83854	1671	Саратовская область, Энгельсский район, Энгельс, Полтавская, 17 , 2 корпус ПУ № 9 , ГОУ СПО Энгельсский политехникум	f	large
71590	81027	1670	Самарская область, Тольятти, Мира, 121	f	large
71790	83847	1661	Саратовская область, Энгельсский район, Энгельс, Полтавская, 19, ГОУ НПО Профессиональный лицей № 34	f	large
71898	83879	1707	Саратовская область, Энгельсский район, Энгельс, Минская, 29, МОУ СОШ № 32	f	large
71897	83879	1706	Саратовская область, Энгельсский район, Энгельс, Минская, 29, МОУ СОШ № 32	f	large
71896	83879	1705	Саратовская область, Энгельсский район, Энгельс, Минская, 29, МОУ СОШ № 32	f	large
71749	83838	1645	Саратовская область, Энгельсский район, Энгельс, Колотилова, 58а, детская школа искусств № 6	f	large
71932	83891	1725	Саратовская область, Энгельсский район, Энгельс, Гагарина, МОУ СОШ № 21	f	large
71931	83891	1724	Саратовская область, Энгельсский район, Энгельс, Гагарина, МОУ СОШ № 21	f	large
71902	83883	1711	Саратовская область, Энгельсский район, Энгельс, 2-Микрорайон, 43, ЗАО Энгельсский кирпичный завод	f	large
71900	83881	1709	Саратовская область, Энгельсский район, Энгельс, 1-й Микрорайон, стадион Торпедо	f	large
71933	83892	1726	Саратовская область, Энгельсский район, Энгель-19, 1-й квартал , спортивный зал поселка Приволжский	f	large
134497	94392	1774	Саратовская область, Энгельсский район, село Широкополье, Рабочая, 22, здание МОУ СОШ	f	medium
120652	83933	1769	Саратовская область, Энгельсский район, село Шевченко, Школьная, 3, здание Дом досуга	f	small
120641	83914	1751	Саратовская область, Энгельсский район, село Усть-Караман, здание филиала МОУ ООШ с. Ленинское	f	small
71695	83904	1741	Саратовская область, Энгельсский район, село Узморье, Революционная, 3, здание МОУ СОШ	f	large
120658	83939	1775	Саратовская область, Энгельсский район, село Титоренко, Школьная, 1, здание МОУ ООШ	f	medium
120632	83901	1738	Саратовская область, Энгельсский район, село Терновка, Центральная, 26в, здание администрации	f	medium
120637	83907	1744	Саратовская область, Энгельсский район, село Степное, Первомайская, 14, здание МОУ ООШ	f	medium
120642	83915	1752	Саратовская область, Энгельсский район, село Старицкое, Центральная , 11, здание МОУ ООШ	f	small
71841	83924	1761	Саратовская область, Энгельсский район, село Совхоза Имени Карла Маркса, Советская, 31, здание Дома культуры	f	large
120634	83903	1740	Саратовская область, Энгельсский район, село Смеловка, Центральная, 10, здание Дома досуга	f	small
120633	83902	1739	Саратовская область, Энгельсский район, Село Новая Терновка, улица Ленина, 2, здание МОУ СОШ	f	medium
71724	83918	1755	Саратовская область, Энгельсский район, село Пробуждение, здание МОУ СОШ	f	large
120651	83932	1768	Саратовская область, Энгельсский район, село Прилужный, Овражная, 15, здание Дома досуга	f	small
71726	83921	1758	Саратовская область, Энгельсский район, село Придорожный, Школьная, 2а, здание МОУ СОШ	f	large
120639	83912	1749	Саратовская область, Энгельсский район, село Подстепное, Кирова, здание МОУ ООШ	f	medium
120648	83929	1765	Саратовская область, Энгельсский район, село Первомайское, Трактовая, 8, здание Дома досуга	f	small
120644	83917	1754	Саратовская область, Энгельсский район, село Осиновка, магазин, здание Дома досуга	f	small
71728	83923	1760	Саратовская область, Энгельсский район, село Новопушкинское, 1-й квартал, 49, здание ДК	f	large
120654	83935	1771	Саратовская область, Энгельсский район, село Межевой, Колхозная, 3а, здание фельдшерско-акушерского пункта	f	small
120646	83925	1762	Саратовская область, Энгельсский район, село Лощинный, Ленина, 13, здание Дома культуры	f	medium
120643	83916	1753	Саратовская область, Энгельсский район, село Липовка, Советская, 11, здание Дома культуры	f	medium
120640	83913	1750	Саратовская область, Энгельсский район, село Ленинское, Ленина, 11, здание Дома досуга	f	medium
71721	83911	1748	Саратовская область, Энгельсский район, село Красный Яр, Мира, 98, здание Дома культуры	f	large
120649	83930	1766	Саратовская область, Энгельсский район, село Красный Партизан, Южная, 12, здание МОУ НШ	f	small
120635	83905	1742	Саратовская область, Энгельсский район, село Красноармейское, Ленина, 14, здание ДК	f	medium
71725	83919	1756	Саратовская область, Энгельсский район, село Коминтерн, Школьная, 13, здание МОУ СОШ	f	large
120655	83936	1772	Саратовская область, Энгельсский район, село Кирово, Советская, 66, здание Дома досуга	f	small
120653	83934	1770	Саратовская область, Энгельсский район, село Калинино, Дорожная, 39, здание МОУ СОШ	f	small
120650	83931	1767	Саратовская область, Энгельсский район, село Зеленый Дол, Советская, 13, здание МОУ СОШ	f	small
71862	83319	1130	Саратовская область, Энгельсский район, село Звонаревка, Ленина, 2 а , МОУ-средняя общеобразовательная школа	f	large
120645	83920	1757	Саратовская область, Энгельсский район, село Голубьевка, Центральная, 2/1, здание фельдшерско-акушерского пункта	f	small
71720	83910	1747	Саратовская область, Энгельсский район, село Генеральское, Московская, 67	f	large
120656	83937	1773	Саратовская область, Энгельсский район, село Воскресенка, Центральная, 81, здание Дома культуры	f	medium
120638	83908	1745	Саратовская область, Энгельсский район, поселок Взлетный, Производственная, 21, здание Дома Досуга	f	medium
120659	83940	1776	Саратовская область, Энгельсский район, село Бурный, Школьная, 1, здание МОУ СОШ	f	medium
120636	83906	1743	Саратовская область, Энгельсский район, село Березовка, Центральная, 33, здание МОУ СОШ	f	medium
71842	83926	1763	Саратовская область, Энгельсский район, село Безымянное, Чкалова, 7, МОУ ООШ	f	large
120617	83811	1617	Саратовская область, Хвалынский район, станция Возрождения, улица Железнодорожная, 25, административное здание	t	small
120622	83823	1630	Саратовская область, Хвалынский район, Хвалынск, Советская, 293, ЗАО Элеватор-Холдинг	f	small
120624	83824	1632	Саратовская область, Хвалынский район, Хвалынск, Революционная, 260, МОУ СОШ №2	f	small
120623	83824	1631	Саратовская область, Хвалынский район, Хвалынск, Революционная, 260, МОУ СОШ №2	f	small
71734	83820	1626	Саратовская область, Хвалынский район, село Ульянино, имени Ульянина, 62Б, административное здание	f	large
71732	83818	1624	Саратовская область, Хвалынский район, село Старая Лебежайка, Первомайская, 1, МОУ ООШ	f	large
71733	83819	1625	Саратовская область, Хвалынский район, село Сосновая Маза, Ленина, 51 , Дом культуры	f	large
120615	83808	1615	Саратовская область, Хвалынский район, село Селитьба, Центральная, 41В, МОУ ООШ	f	small
71730	83814	1620	Саратовская область, Хвалынский район, село Северный, Мира, 24 , Дом культуры	f	large
71731	83817	1623	Саратовская область, Хвалынский район, село Поповка, Космонавтов, 19 А, Дом досуга	f	large
71740	83762	1629	Саратовская область, Хвалынский район, село Ивановка	f	large
120621	83816	1622	Саратовская область, Хвалынский район, село Елшанка, Николаева, 38, Дом досуга	f	small
71738	83821	1627	Саратовская область, Хвалынский район, село Елховка, Молодежная, 6 , МОУ ООШ	f	large
120620	83815	1621	Саратовская область, Хвалынский район, село Горюши, Советская, 76, Дом культуры	f	small
120618	83812	1618	Саратовская область, Хвалынский район, поселок Возрождение, Степная, 1, Дом культуры	f	small
120616	83809	1616	Саратовская область, Хвалынский район, село Благодатное, Центральная, 133, Дом культуры	f	medium
120619	83813	1619	Саратовская область, Хвалынский район, село Апалиха, 60 лет Октября, 46, дом досуга	f	small
120614	83807	1614	Саратовская область, Хвалынский район, поселок Алексеевка, Чапаева, 64 , администрация	f	medium
71739	83822	1628	Саратовская область, Хвалынский район, село Акатная Маза, Молодежная, 2, МОУ ООШ	f	large
120610	83801	1608	Саратовская область, Федоровский район, село Федоровка, Молодежная, 15, Администрация округа	f	medium
120613	83804	1611	Саратовская область, Федоровский район, село Тамбовка, Победы , 55, МОУ ООШ	f	small
120606	83796	1604	Саратовская область, Федоровский район, село Спартак, Советская, 11б, адм.МО	f	medium
120603	83793	1601	Саратовская область, Федоровский район, село Солнечный, Набережная, 4, Дом культуры	f	medium
120598	83787	1596	Саратовская область, Федоровский район, село Семеновка, Центральная, 59а, Дом культуры	f	medium
120611	83802	1609	Саратовская область, Федоровский район, село Романовка, Советская, 49, Дом культуры	f	medium
134493	94389	1603	Саратовская область, Федоровский район, село Плес, Рабочая, 3, МДОУ д/с Петушок	f	small
120608	83798	1606	Саратовская область, Федоровский район, село Первомайское, Октябрьская, 19, МОУ СОШ	f	medium
120599	83789	1597	Саратовская область, Федоровский район, село Николаевка, Центральная, 44 , Дом культуры	f	small
120607	83797	1605	Саратовская область, Федоровский район, село Мунино	f	medium
120602	83792	1600	Саратовская область, Федоровский район, село Морцы, Степная, 5, Дом культуры	f	medium
71701	83782	1591	Саратовская область, Федоровский район, поселок Мокроус, Энгельса, 14а, Дом Культуры	f	large
71700	83781	1590	Саратовская область, Федоровский район, поселок Мокроус, Советская, 3	f	large
120596	83784	1593	Саратовская область, Федоровский район, поселок Мокроус, Сельхозтеник, 1а д.14, здание налоговой инспекции	f	small
71702	83783	1592	Саратовская область, Федоровский район, поселок Мокроус, Победы, 21, адм.МО	f	large
71703	83785	1594	Саратовская область, Федоровский район, поселок Мокроус, Восточная, 40 , МОУ СОШ №2	f	large
134491	94387	1598	Саратовская область, Федоровский район, село Митрофановка, Новая, 5а , филиал МОУ СОШ №1	f	small
120612	83803	1610	Саратовская область, Федоровский район, село Калуга, Школьная, 2, Дом культуры	f	medium
120601	83791	1599	Саратовская область, Федоровский район, село Калдино, Победы, 48, Дом культуры	f	small
120597	83786	1595	Саратовская область, Федоровский район, село Ивановка, Центральная, 60, Дом Культуры	f	small
71718	83805	1612	Саратовская область, Федоровский район, село Еруслан, Мирная, 10, МОУ СОШ	f	large
71719	83806	1613	Саратовская область, Федоровский район, село Долина, Иванова А. А. , 7, МОУ СОШ	f	large
120609	83800	1607	Саратовская область, Федоровский район, село Воскресенка	f	small
134492	94388	1602	Саратовская область, Федоровский район, село Борисоглебовка, Победы, 33, МОУ СОШ	f	medium
120595	83780	1589	Саратовская область, Турковский район, село Шепелевка, Школьная, 1, МОУ ООШ	f	\N
120594	83779	1588	Саратовская область, Турковский район, село Чернавка, 40 лет Победы, 19, МОУ ООШ	f	\N
71685	83767	1577	Саратовская область, Турковский район, поселок Турки, Ульяны Громовой, 1 , школа	f	large
71682	83764	1574	Саратовская область, Турковский район, поселок Турки, Свердлова, 5 , средняя школа	f	large
71684	83766	1576	Саратовская область, Турковский район, поселок Турки, Ленина, 124/1, Дом досуга	f	large
71683	83765	1575	Саратовская область, Турковский район, поселок Турки, Ленина, 1А, Дом культуры	f	large
120584	83768	1578	Саратовская область, Турковский район, село Трубетчино, Центральная, 39А, школа	f	small
120593	83778	1587	Саратовская область, Турковский район, село Студенка, Мира, 24/3, администрация МО	f	medium
120592	83777	1586	Саратовская область, Турковский район, село Рязанка, Центральная, 135, ДК	f	medium
120591	83776	1585	Саратовская область, Турковский район, село Перевесино-Михайловка, Советская, 57А, школа	f	small
120590	83774	1584	Саратовская область, Турковский район, село Перевесинка, Центральная, 28, ДК	f	medium
120589	83773	1583	Саратовская область, Турковский район, село Марьино, Молодежная, 7В , ДК	f	small
120588	83772	1582	Саратовская область, Турковский район, село Лунино, Горная, 32, МОУ ООШ	f	\N
120587	83771	1581	Саратовская область, Турковский район, село Каменка, Ленина, 37, школа	f	small
134490	94386	1580	Саратовская область, Турковский район, село Дмитриевка, Советская, 11а, МОУ НОШ	f	small
120585	83769	1579	Саратовская область, Турковский район, село Бороно-Михайловка, Школьная, 41, школа	f	small
120582	83761	1572	Саратовская область, Татищевский район, село Ягодная Поляна, Советская, 51	f	medium
120580	83759	1570	Саратовская область, Татищевский район, село Широкое, Московская, 7, МОУ СОШ с.Широкое	f	medium
71941	83758	1569	Саратовская область, Татищевский район, поселок Татищево, Школьная, 8, МОУ СОШ №1	f	large
71940	83758	1568	Саратовская область, Татищевский район, поселок Татищево, Школьная, 8, МОУ СОШ №1	f	large
71939	83757	1567	Саратовская область, Татищевский район, поселок Татищево, Советская, 5, здание ЦДК	f	large
71938	83753	1563	Саратовская область, Татищевский район, Сторожевка, Школьная, 1, МОУ СОШ	f	large
71937	83752	1562	Саратовская область, Татищевский район, Сторожевка, Свободный переулок, 4А, сельский дом культуры МУК Межпоселенческая ЦКС	f	large
120574	83747	1557	Саратовская область, Татищевский район, село Сокур, Юбилейная, 22, МОУ СОШ	f	medium
120568	83741	1551	Саратовская область, Татищевский район, село Слепцовка, Школьная, 3Б, сельский клуб МУК Межпоселенческая ЦКС	f	small
71936	83750	1560	Саратовская область, Татищевский район, село Садовый, Центральная, 4, здание сельского клуба	f	large
120555	83726	1536	Саратовская область, Советский район, село Золотая Степь, Вокзальная, 1А, Клуб	f	medium
120576	83751	1561	Саратовская область, Татищевский район, село Полянское, Центральная, 23, сельский клуб МУК Межпоселенческая ЦКС	f	small
120564	83736	1546	Саратовская область, Татищевский район, село Полчаниновка, Центральная, 67, сельский клуб МУК Межпоселенческая ЦКС	f	small
71921	83748	1558	Саратовская область, Татищевский район, село Октябрьский Городок, Уханова, 115 , МОУ СОШ с.Октябрьский городок	f	large
120565	83738	1548	Саратовская область, Татищевский район, село Нееловка, Дорожная, 22А, здание сельского клуба	f	small
120572	83745	1555	Саратовская область, Татищевский район, село Мизино-Лапшиновка, Октябрьская, 44 , здание администрации	f	medium
120549	83705	1516	Саратовская область, Татищевский район, село Малая Скатовка, Дорожная, 14, МОУ ООШ 	f	small
120567	83740	1550	Саратовская область, Татищевский район, село Македоновка, Центральная, 41 , здание школы	f	small
120579	83756	1566	Саратовская область, Татищевский район, село Курдюм, Школьная, 10 , МОУ СОШ ст.Курдюм	f	medium
120578	83755	1565	Саратовская область, Татищевский район, село Курдюм, Пономарева, 22 , сельский клуб МУК Межпоселенческая ЦКС	f	medium
120571	83744	1554	Саратовская область, Татищевский район, село Куликовка, Мира, 14 , здание сельского клуба	f	small
120575	83749	1559	Саратовская область, Татищевский район, село Кувыка, Шигаева, 92 , МОУ ООШ с. Кувыка	f	medium
120573	83746	1556	Саратовская область, Татищевский район, село Корсаковка, Центральная, 55, здание бывшей школы	f	small
120570	83743	1553	Саратовская область, Татищевский район, село Карякино, Школьная, 1, здание сельского клуба	f	small
120569	83742	1552	Саратовская область, Татищевский район, село Карамышка, Юбилейная, 25, сельский клуб МУК Межпоселенческая ЦКС	f	small
120577	83754	1564	Саратовская область, Татищевский район, село Ильиновка, Центральная, 24/1, здание сельского клуба	f	small
120566	83739	1549	Саратовская область, Татищевский район, село Идолга, Центральная, 49, сельский дом культуры МУК Межпоселенческая ЦКС	f	medium
71908	83268	1777	Саратовская область, Татищевский район, ЗАТО Светлый, Кузнецова, 10, СОШ №2 актовый зал	f	large
71904	83737	1547	Саратовская область, Татищевский район, село Вязовка, Ленина, 135, здание администрации	f	large
120583	83763	1573	Саратовская область, Татищевский район, село Большая Федоровка, Верхняя, 48, здание сельского клуба	f	small
120581	83760	1571	Саратовская область, Татищевский район, село Большая Каменка, Рабочая, 8, здание школы	f	medium
120563	83735	1545	Саратовская область, Татищевский район, село Большая Ивановка, Административный проезд, 16	f	\N
71836	83719	1529	Саратовская область, Советский район, поселок Степное, Школьная, 4, МОУ-СОШ №1	f	large
120124	83154	967	Саратовская область, Советский район, поселок Степное, Советская , 39, Школа	f	small
71838	83721	1531	Саратовская область, Советский район, поселок Степное, К.Маркса, 10 , Дом культуры	f	large
71839	83722	1532	Саратовская область, Советский район, поселок Степное, Димитрова, 20, МОУ-СОШ №2	f	large
71834	83717	1527	Саратовская область, Советский район, поселок Степное, Димитрова, 1Б, здание Пенсионного фонда	f	large
71837	83720	1530	Саратовская область, Советский район, поселок Степное, 50 лет Победы, 5, Школа искусств	f	large
71835	83718	1528	Саратовская область, Советский район, поселок Степное, 50 лет Победы, 14, РДДиЮ	f	large
71840	83723	1533	Саратовская область, Советский район, поселок Советское, 50 лет Пионерии, 13, МОУ СОШ	f	large
71887	83728	1538	Саратовская область, Советский район, село Розовое, Кооперативная, 20, Дом культуры	f	large
71886	83724	1534	Саратовская область, Советский район, поселок Пушкино, Кооперативная, 27, Дом культуры	f	large
120558	83730	1540	Саратовская область, Советский район, село Пионерское, Клубная, 17, МОУ-ООШ	f	small
120562	83734	1544	Саратовская область, Советский район, село Новолиповка, Клубная, 14 , МОУ-ООШ	f	small
120561	83733	1543	Саратовская область, Советский район, село Новокривовка, Школьная, 14А , Дом культуры	f	medium
120554	83725	1535	Саратовская область, Советский район, село Новоантоновка, Школьная, 11, Клуб	f	small
120559	83731	1541	Саратовская область, Советский район, село Мечетное, Школьная, 12А , Дом культуры	f	medium
120560	83732	1542	Саратовская область, Советский район, село Любимово, Школьная, 20А, МОУ-ООШ	f	medium
120556	83727	1537	Саратовская область, Советский район, село Александровка, Юбилейная, 3, Дом культуры	f	medium
120550	83706	1517	Саратовская область, Саратовский район , посёлок Зоринский, Административное здание ООО Горизонт	f	small
120542	83693	1504	Саратовская область, Саратовский район, с. Свинцовка, Школьная, Дом Досуга 	f	small
120546	83701	1512	Саратовская область, Саратовский район, село Юрловка, Молодежная, МОУ СОШ	f	small
120538	83686	1497	Саратовская область, Саратовский район, село Шевыревка, Центральная, 37, филиал Дом досуга	f	\N
71833	83715	1525	Саратовская область, Саратовский район, село Усть-Курдюм, Большая Советская, 66, МОУ СОШ с. Усть-Курдюм	f	large
120545	83700	1511	Саратовская область, Саратовский район, село Сосновка, Школьная, 17, МОУ СОШ с. Сосновка	f	medium
120537	83685	1496	Саратовская область, Саратовский район, село Совхоза Хмелевский, Центральная, 39, Дом досуга п. Хмелевский	f	medium
120551	83708	1519	Саратовская область, Саратовский район, село Совхоза 15 Лет Октября, Центральная, 1Б, Здание Дома досуга	f	small
71829	83711	1521	Саратовская область, Саратовский район, село Синенькие, Советская, 89, Дом культуры с. Синенькие	f	large
71830	83712	1522	Саратовская область, Саратовский район, село Сергиевский, Октябрьская, 22 , Детская школа искусств № 4	f	large
120539	83688	1499	Саратовская область, Саратовский район, село Сабуровка, Школьная, 1, Здание школы	f	small
71716	83707	1518	Саратовская область, Саратовский район, село Рыбушка, Школьная, 42 А, МОУ СОШ с. Рыбушка	f	large
120553	83716	1526	Саратовская область, Саратовский район, Пристанное, Советская, 3 , МОУ СОШ с. Усть-Курдюм	f	medium
120552	83710	1520	Саратовская область, Саратовский район, село Поповка, Школьная, 28 , Дом культуры с. Поповка	f	medium
119693	82365	56	Саратовская область, Саратовский район, поселок Новый Увек, МОУ ООШ № 91	f	medium
120540	83691	1502	Саратовская область, Саратовский район, село Новая Липовка, Широкая, 5, Дом досуга д. Новая Липовка	f	small
71705	83697	1508	Саратовская область, Саратовский район, село Михайловка, Центральная, 9, МОУ СОШ с. Михайловка	f	large
71696	83695	1506	Саратовская область, Саратовский район, поселок Красный Текстильщик, Калинина, 4А, МОУ СОШ	f	large
71704	83696	1507	Саратовская область, Саратовский район, поселок Красный Текстильщик, Базарная, 8, Дом культуры	f	large
71680	83694	1505	Саратовская область, Саратовский район, поселок Красный Октябрь, Нефтяников, 21, Дом культуры	f	large
120543	83698	1509	Саратовская область, Саратовский район, село Константиновка, Коммунарная, 2 Б, МОУ ООШ с. Константиновка	f	small
120544	83699	1510	Саратовская область, Саратовский район, село Колотов Буерак, Садовая, 27, Фельдшерско-акушерский пункт	f	small
120541	83692	1503	Саратовская область, Саратовский район, село Клещевка, Советская, 29, Дом досуга с. Клещевка	f	medium
120547	83702	1513	Саратовская область, Саратовский район, село Ивановский, Центральная, 31, МОУ ООШ п. Ивановский	f	medium
71679	83690	1501	Саратовская область, Саратовский район, поселок Дубки, Октябрьская , МОУ СОШ п. Дубки	f	large
120548	83704	1515	Саратовская область, Саратовский район, хутор Бартоломеевский, МДОУ Детский сад Теремок	f	small
71676	83684	1495	Саратовская область, Саратовский район, село Багаевка, Советская, 25, МУК Дом культуры 	f	large
120536	83682	1493	Саратовская область, Саратовский , поселок Рейник, Овражная, 12/3, Фельдшерско-акушерский пунк	t	medium
120533	83679	1490	Саратовская область, Саратовский , поселок Березина Речка, Школьная, МОУ СОШ с. Березина Речка	f	medium
120519	83663	1474	Саратовская область, Самойловский район, село Южный, Совхозная, 6 А, филиал МОУ СОШ	f	small
120530	83675	1486	Саратовская область, Самойловский район, село Хрущевка, Школьная, 2, здание филиала МОУ СОШ 	f	medium
120512	83655	1467	Саратовская область, Самойловский район, село Тюменевка, Рабочая, 70, филиал МОУ СОШ	f	small
120525	83670	1481	Саратовская область, Самойловский район, село Тульский, Мира, 12 , филиал МОУ СОШ	t	small
71914	83668	1479	Саратовская область, Самойловский район, село Святославка, Ленина, 45, Святославский СДК	f	large
120529	83674	1485	Саратовская область, Самойловский район, село Самородовка, Центральная, 2 А, филиал МОУ СОШ	f	small
71466	80953	1524	Самарская область, Тольятти, бульвар Луначарского, 19	f	large
71825	83642	1454	Саратовская область, Самойловский район, поселок Самойловка, Ревякина, 8 Б, МОУ СОШ № 2	f	large
71826	83643	1455	Саратовская область, Самойловский район, поселок Самойловка, Красная площадь, 18 , Районный дом культуры	f	large
71845	83644	1456	Саратовская область, Самойловский район, поселок Самойловка, Коневка, 100, МОУ ДОД ДЮСШ	f	large
120531	83676	1487	Саратовская область, Самойловский район, село Садовый, Центральная, 16 , Садовый СДК	f	small
120511	83654	1466	Саратовская область, Самойловский район, село Полтавка, Ленина, 34, филиал МОУ СОШ	f	small
120515	83658	1470	Саратовская область, Самойловский район, село Полоцкое, Победы, 52 А , филиал МОУ СОШ	f	small
120523	83667	1478	Саратовская область, Самойловский район, село Песчанка, Ленина, 20, филиал МОУ СОШ	f	medium
120528	83673	1484	Саратовская область, Самойловский район, село Передовой, Школьная, 2 , филиал МОУ СОШ	f	small
120508	83651	1464	Саратовская область, Самойловский район, село Ольшанка, Ленина, 5 , Ольшанский СДК	f	medium
120527	83672	1483	Саратовская область, Самойловский район, село Новомихайловка, Грейдерная, 7 А, филиал МОУ СОШ	f	small
120517	83660	1472	Саратовская область, Самойловский район, село Новоалександровка, Заречная, 36, филиал МОУ СОШ	t	small
120520	83664	1475	Саратовская область, Самойловский район, село Николаевка, Гагарина, 7, филиал МОУ СОШ	f	small
120513	83656	1468	Саратовская область, Самойловский район, село Низовка, Новая, 5, филиал МОУ СОШ	f	small
134489	94385	1477	Саратовская область, Самойловский район, село Криуша, Почтовая, 3, СДК	f	small
120524	83669	1480	Саратовская область, Самойловский район, село Крийнички, Новая, 5 , филиал МОУ СОШ	f	small
120526	83671	1482	Саратовская область, Самойловский район, село Красный, Ковалевская, 3 А, филиал МОУ СОШ	f	small
120516	83659	1471	Саратовская область, Самойловский район, село Краснознаменский, Центральная, 2 В, Краснознаменский СДК	f	medium
120510	83653	1465	Саратовская область, Самойловский район, село Красавка, Ленина, 25 , филиал МОУ СОШ	f	medium
120521	83665	1476	Саратовская область, Самойловский район, село Каменка, Центральная, 6 , Каменский СДК	f	small
120503	83646	1458	Саратовская область, Самойловский район, село Залесянка, Школьная, 29Б, филиал МОУ СОШ	f	medium
120509	83652	1463	Саратовская область, Самойловский район, село Еловатка, Ленина, 34, филиал МОУ СОШ	f	small
120506	83649	1461	Саратовская область, Самойловский район, село Елизаветино, Елизаветинская, 30, ФАП	t	small
120514	83657	1469	Саратовская область, Самойловский район, село Воронино, Заречная, 1, филиал МОУ СОШ	f	small
120518	83662	1473	Саратовская область, Самойловский район, село Воздвиженка, Заречная, 43 А, филиал МОУ СОШ	f	small
120505	83648	1460	Саратовская область, Самойловский район, село Благовещенка, Центральная, 8, Благовещенский СДК	f	medium
120504	83647	1459	Саратовская область, Самойловский район, село Алексеевский, 47, ФАП	f	small
120507	83650	1462	Саратовская область, Самойловский район, село Александровка, Александровская, 10, филиал МОУ СОШ	t	small
120497	83635	1448	Саратовская область, Ртищевский район, село Шило-Голицыно, Советская, 43 , Социально-культурный центр	f	medium
120500	83640	1452	Саратовская область, Ртищевский район, село Урусово, Школьная, 24	f	small
120485	83623	1436	Саратовская область, Ртищевский район, село Темп, Мира, 2 , Средняя школа	f	medium
120499	83638	1450	Саратовская область, Ртищевский район, село Стройидустрия, Школьная, 2, Средняя школа	f	small
120498	83637	1449	Саратовская область, Ртищевский район, село Совхоза Выдвиженец, Юбилейная, 22, Дом культуры	f	medium
120478	83616	1429	Саратовская область, Ртищевский район, село Сланцы, Куйбышева, 58, Общеобразовательная школа	f	small
120483	83621	1434	Саратовская область, Ртищевский район, село Северка, Школьная, 13, Общеобразовательная школа	f	small
120487	83625	1438	Саратовская область, Ртищевский район, село Сапожок, Зеленая, 15, Средняя школа	f	small
120491	83629	1442	Саратовская область, Ртищевский район, село Салтыковка, Кирова, 35, Средняя школа	f	medium
71824	83639	1451	Саратовская область, Ртищевский район, село Ртищевский, Школьная, 1, Средняя школа	f	large
120482	83620	1433	Саратовская область, Ртищевский район, село Репьевка, Свердлова, 3, Общеобразовательная школа	f	small
120488	83626	1439	Саратовская область, Ртищевский район, село Правда, Школьная, 2, Средняя школа	f	small
120480	83618	1431	Саратовская область, Ртищевский район, село Потьма, Молодежная, 1, Общеобразовательная школа	f	small
120473	83611	1424	Саратовская область, Ртищевский район, село Подгоренка, Горная, 1а, сельский Клуб	f	small
120489	83627	1440	Саратовская область, Ртищевский район, село Первомайский, Садовая, 12 , Средняя школа	f	medium
120477	83615	1428	Саратовская область, Ртищевский район, село Ободной, Песчаная, 3, Сельский клуб	f	small
120494	83632	1445	Саратовская область, Ртищевский район, село Малиновка, Крупской, 54 , Средняя школа	f	small
120481	83619	1432	Саратовская область, Ртищевский район, село Макарово, Советская, 23, Общеобразовательная школа	f	medium
120486	83624	1437	Саратовская область, Ртищевский район, село Луч, Ленина, 15 , Средняя школа	f	small
120479	83617	1430	Саратовская область, Ртищевский район, село Лопатино, Молодежная, 37, (Общеобразовательная школа)	f	small
120501	83641	1453	Саратовская область, Ртищевский район, село Курган, Молодежная, 1а, Социально-культурный центр	f	small
120492	83630	1443	Саратовская область, Ртищевский район, село Крутец, Пушкина, 61, Средняя школа	f	small
120496	83634	1447	Саратовская область, Ртищевский район, село Красные Гривки, Школьная, 4 , Дом культуры	f	small
120476	83614	1427	Саратовская область, Ртищевский район, село Красная Звезда, Барменкова, 7 , Средняя школа	f	small
134488	94384	1426	Саратовская область, Ртищевский район, село Ключи, Первомайская, 5, Амбулатория	f	small
120493	83631	1444	Саратовская область, Ртищевский район, село Каменка, Школьная, 1, средняя школа	f	small
120495	83633	1446	Саратовская область, Ртищевский район, село Ерышевка, Советская, 17, Дом культуры	f	small
120490	83628	1441	Саратовская область, Ртищевский район, село Елань, Школьная, 26, Дом культуры	f	small
120532	83677	1488	Саратовская область, Ртищевский район, село Голицыно, Советская, 9, адм.здание ИП КФХ Нестеров В.В.	t	small
134487	94383	1425	Саратовская область, Ртищевский район, село Владыкино, Садовая, 66, Средняя Школа	f	small
120484	83622	1435	Саратовская область, Ртищевский район, село Васильевка, Ленина, 72, Общеобразовательная школа	f	small
120472	83610	1423	Саратовская область, Ртищевский район, село Александровка, 60 лет Октября, 65, Дом культуры	f	medium
120456	83577	1390	Саратовская область, Романовский район, село Усть-Щербедино, Ленина, 29А, сельский Дом культуры	f	medium
120466	83587	1400	Саратовская область, Романовский район, село Таволжанский, Садовая, 2, сельский Дом культуры	f	small
120453	83574	1387	Саратовская область, Романовский район, поселок Романовка, Федоровка, клуб Маяк	f	medium
71884	83571	1385	Саратовская область, Романовский район, поселок Романовка, Советская, 281, детский сад Сказка	f	large
71883	83570	1384	Саратовская область, Романовский район, поселок Романовка, Народная, 27 А, районный Дом культуры	f	large
71882	83569	1383	Саратовская область, Романовский район, поселок Романовка, Народная, 39, средняя школа	f	large
71885	83573	1386	Саратовская область, Романовский район, поселок Романовка, 2-ая Заводская, 5, детский сад Колокольчик	f	large
120467	83588	1401	Саратовская область, Романовский район, село Подгорное, Чиркина, 63, средняя школа	f	medium
120460	83581	1394	Саратовская область, Романовский район, село Памятка, Центральная, 24	f	small
120455	83576	1389	Саратовская область, Романовский район, село Осиновка, Центральная, 73а	f	small
120464	83585	1398	Саратовская область, Романовский район, село Мордовский Карай, Ленина, 52А, сельский Дом культуры Мир	f	medium
120463	83584	1397	Саратовская область, Романовский район, село Мордовский Карай, Комсомольская, 78	f	medium
120457	83578	1391	Саратовская область, Романовский район, село Малое Щербедино, Народная, 145, сельский Дом культуры	f	small
120465	83586	1399	Саратовская область, Романовский район, село Красноармейский, Радость, 58	f	medium
120468	83589	1402	Саратовская область, Романовский район, село Инясево	f	small
120462	83583	1396	Саратовская область, Романовский район, село Бык, Горная, 1, сельский Дом культуры	f	small
120458	83579	1392	Саратовская область, Романовский район, село Большой Карай, площадьСтоякина, 1А, сельский Дом культуры	f	medium
120459	83580	1393	Саратовская область, Романовский район, село Большой Карай, Ленина, 20А, средняя школа	f	medium
120454	83575	1388	Саратовская область, Романовский район, село Бобылевка, Ярославская, 210, средняя школа	f	small
120461	83582	1395	Саратовская область, Романовский район, село Алексеевский, Набережная, 27А, сельский Дом культуры	f	small
134486	94382	1375	Саратовская область, Ровенский район, село Яблоновка, Почтовая, 24 , здание СДК	f	small
120445	83560	1374	Саратовская область, Ровенский район, село Чкаловское, Школьная, 12, здание СДК	f	small
120451	83567	1381	Саратовская область, Ровенский район, село Циково, Садовая, 18, здание СДК	f	small
120444	83559	1373	Саратовская область, Ровенский район, село Тарлыковка, Рабочая, 29, здание СДК	f	small
120443	83558	1372	Саратовская область, Ровенский район, село Скатовка, Кооперативная, 21, здание СДК	f	medium
120441	83556	1370	Россия, Саратовская область, Ровенский район, село Серебряный Бор	f	\N
71736	83551	1365	Саратовская область, Ровенский район, поселок Ровное, Свердлова, 1, Школа	f	large
71735	83549	1363	Саратовская область, Ровенский район, поселок Ровное, Свердлова, 1, Школа	f	large
120437	83550	1364	Саратовская область, Ровенский район, поселок Ровное, Калинина, 63	f	\N
120442	83557	1371	Саратовская область, Ровенский район, село Привольное, Советская, 16, здание СДК	f	medium
71880	83562	1376	Саратовская область, Ровенский район, село Приволжское, Советская, 62, здание СДК	f	large
120452	83568	1382	Саратовская область, Ровенский район, село Первомайское, Центральная, 14, здание СДК	f	medium
120440	83554	1368	Саратовская область, Ровенский район, село Новопривольное, Волжская, 17, здание СДК	f	small
120447	83563	1377	Саратовская область, Ровенский район, село Новокаменка, Советская, 12, здание СДК	f	small
120449	83565	1379	Саратовская область, Ровенский район, село Луговское, Ленина, 24, здание СДК	f	medium
120439	83553	1367	Саратовская область, Ровенский район, село Лиманный, Центральная, 25 , Школа	f	small
120448	83564	1378	Саратовская область, Ровенский район, село Кривояр, Советская, 7 , здание Администрации МО	f	medium
71737	83555	1369	Саратовская область, Ровенский район, село Кочетное, Центральная, 25 , здание СДК	f	large
120450	83566	1380	Саратовская область, Ровенский район, село Владимирский, Волгоградская, 12 , здание СДК	f	medium
120438	83552	1366	Саратовская область, Ровенский район, Береговое, Волжская, 1, здание СДК	f	small
120429	83540	1355	Саратовская область, Пугачевский район, село Чапаевский, Школьная, 10Б, Дом культуры	f	medium
120422	83530	1344	Саратовская область, Пугачевский район, село Успенка, Набережная, 1, здание Администрации	f	medium
120421	83529	1343	Саратовская область, Пугачевский район, село Тургеневский, Молодежная, 33, Школа	f	medium
71723	83538	1353	Саратовская область, Пугачевский район, село Старая Порубежка, Лободина, 21-а, СОШ	f	large
120419	83527	1341	Саратовская область, Пугачевский район, село Солянский, Школьная, 1, СОШ	f	medium
120416	83524	1338	Саратовская область, Пугачевский район, село Селезниха, Чапаева, 17, Дом культуры	f	medium
120430	83541	1356	Саратовская область, Пугачевский район, село Рахмановка, Молодежная, 1/2, Школа	f	medium
71786	83511	1326	Саратовская область, Пугачевский район, село Пугачевский, Комарова, 14, дом культуры	f	large
71809	83519	1334	Саратовская область, Пугачевский район, Пугачев, Садовая, 72, СОШ № 5	f	large
120413	83520	1335	Саратовская область, Пугачевский район, Пугачев, Набережная, 21, ИП Притугин	f	medium
71784	83506	1320	Саратовская область, Пугачевский район, Пугачев, М.Горького, 134, МАУ ФОК Олимп	f	large
120414	83522	1336	Саратовская область, Пугачевский район, Пугачев, Камышинский переулок, 9, ФБУ ИК-17	f	medium
71785	83496	1323	Саратовская область, Пугачевский район, Пугачев, Ермощенко, 179/2, ТСЖ Сокол	f	large
120423	83531	1345	Саратовская область, Пугачевский район, село Преображенка, Советская, 99 , Дом культуры	f	medium
120432	83543	1358	Саратовская область, Пугачевский район, село Новопавловка, Комплексная, 22, Школа	f	small
120433	83544	1359	Саратовская область, Пугачевский район, село Новая Порубежка, Советская, 17, Школа	f	small
120417	83525	1339	Саратовская область, Пугачевский район, село Надеждинка, Ленина, 13, Дом культуры	f	medium
120424	83532	1346	Саратовская область, Пугачевский район, село Малая Таволожка, Кооперативная, 19/1, Клуб	f	small
120415	83523	1337	Саратовская область, Пугачевский район, село Мавринка, Фрунзе, 43, школа	f	small
120434	83545	1360	Саратовская область, Пугачевский район, село Любицкое, Советская, 49-а, Школа	f	small
120420	83528	1342	Саратовская область, Пугачевский район, село Красная Речка, Кутякова, 74/2, Дом культуры	f	medium
134485	84138	1361	Саратовская область, Пугачевский район, село Клинцовка, Красноармейская, 27, Дом культуры	f	medium
120431	83542	1357	Саратовская область, Пугачевский район, село Карловка, Советская, 10-б, Дом культуры	f	small
120426	83535	1350	Саратовская область, Пугачевский район, село Каменка, Советская, 6 , Школа	f	medium
120428	83539	1354	Саратовская область, Пугачевский район, село Камелик, Школьная, 1, Школа	f	medium
120427	83537	1352	Саратовская область, Пугачевский район, село Заречный, Заречная, 1, Клуб ГАУ Центр реабилитации Пугачевский	f	small
71811	83534	1349	Саратовская область, Пугачевский район, село Заволжский, Мира, 37 , здание Администрации	f	large
120436	83548	1362	Саратовская область, Пугачевский район, село Жестянка, Советская, 45, Дом культуры	f	medium
71828	83536	1351	Саратовская область, Пугачевский район, село Давыдовка, Чапаевская, 85, Дом культуры	f	large
120425	83533	1347	Саратовская область, Пугачевский район, село Большая Таволожка, Пугачевская, 24, Дом культуры	f	medium
71810	83278	1348	Саратовская область, Пугачевский район, село Березово, Советская, 72, Школа	f	large
120418	83526	1340	Саратовская область, Пугачевский район, село Бажановский, Гагарина, 2, филиал МОУ СОШ п.Солянский	t	small
71808	83518	1333	Саратовская область, Пугачев городской округ, Пугачёв, Горького, 21, ФГОУ СПО Пугачевский ГМТ	f	large
71802	83512	1327	Саратовская область, Пугачев городской округ, Пугачев, Ермощенко, 4, ООШ № 4	f	large
120404	83494	1309	Саратовская область, Питерский район, село Ясновиовка, Степная, 2 , СДК	f	small
120398	83488	1303	Саратовская область, Питерский район, село Трудовик, Ленина, 36, здание администрации МО	f	medium
120402	83492	1307	Саратовская область, Питерский район, село Руновский, Московская, 3/2, Здание МОУ Начальная образовательная школа п. Руновский	f	small
120405	83495	1310	Саратовская область, Питерский район, село Решетников, Колхозная, 2, СОШ с. Агафоновка	f	medium
120401	83491	1306	Саратовская область, Питерский район, село Приозерный, Колхозная, Здание МОУ Начальная образовательная школа	t	small
120395	83485	1300	Саратовская область, Питерский район, село Привольный, Советская, 12, ФАП	t	small
120408	83499	1313	Саратовская область, Питерский район, село Питерка, Школьная, 21, Здание МДОУ Детский сад Сказка	f	small
71918	83478	1293	Саратовская область, Питерский район, село Питерка, Молодежная, 12, Здание ДЮСШ	f	large
71917	83477	1292	Саратовская область, Питерский район, поселок Питерка, Ленина,, 102, Районный Дом культуры	f	large
120406	83497	1311	Саратовская область, Питерский район, село Первопитерский, Центральная, 21, СДК пос. Первопитерский	f	small
120397	83487	1302	Саратовская область, Питерский район, село Опытная Станция, Крекера, 1, Здание МОУ Начальная школа-детский сад п. Опытная станция	f	small
120394	83484	1299	Саратовская область, Питерский район, село Новотулка, Советская, 50, МОУ СОШ с. Новотулка	f	medium
120392	83482	1297	Саратовская область, Питерский район, село Новореченский, Набережная, 25	f	medium
120400	83490	1305	Саратовская область, Питерский район, село Нива, Комсомольская, 2, Администрация МО	f	medium
120407	83498	1312	Саратовская область, Питерский район, село Нариманово, Центральная, 1, ОШ пос. Нариманово	f	small
120390	83480	1295	Саратовская область, Питерский район, село Моршанка, Революционная, 8, здание СДК	f	medium
120389	83479	1294	Саратовская область, Питерский район, село Мироновка, Садовая, 6, детский сад Колосок	f	medium
120399	83489	1304	Саратовская область, Питерский район, село Малый Узень, Гагарина, 3	f	medium
120393	83483	1298	Саратовская область, Питерский район, село Козловка, Молодежная, 31, Здание МОУ СОШ	f	small
120391	83481	1296	Саратовская область, Питерский район, село Зеленый Луг, Комсомольская, 9, Детский сад Вишенка	f	small
71465	80953	1523	Самарская область, Тольятти, бульвар Луначарского, 19	f	large
120403	83493	1308	Саратовская область, Питерский район, село Запрудное, Советская, 6, СОШ с. Запрудное	f	medium
120396	83486	1301	Саратовская область, Питерский район, село Алексашкино, переулок Школьный, 5, СОШ с. Алексашкино	f	medium
120316	83393	1206	Саратовская область, Питерский район, село Августовка, Центральная, 19, начальная школа	f	small
120371	83458	1273	Саратовская область, Петровский район, село Тракторный, Центральная, 36, МОУ ООШ	f	small
120386	83473	1289	Саратовская область, Петровский район, село Татарская Пакаевка, Школьная, 2 , МОУ ООШ	f	small
120381	83468	1284	Саратовская область, Петровский район, село Таволожка, Молодежная, 10, МОУ СОШ	f	small
120369	83456	1271	Саратовская область, Петровский район, село Студеный, пер. Школьный, 2, МОУ ООШ	f	small
120375	83462	1277	Саратовская область, Петровский район, село Сосновоборское, Садовая, 4а, административное здание	f	medium
120383	83470	1286	Саратовская область, Петровский район, село Синенькие, Центральная, 31, МОУ ООШ	f	small
120388	83475	1291	Саратовская область, Петровский район, село Савкино, Мира, 20 а, МОУ ООШ	f	small
120378	83465	1281	Саратовская область, Петровский район, село Пригородный, Светличная, 3, МОУ СОШ	f	medium
120377	83464	1279	Саратовская область, Петровский район, село Оркино, Кооперативная, 36, МОУ ООШ	f	medium
71722	83440	1280	Саратовская область, Петровский район, село Озерки, Политотдельская, 72 а , МОУ СОШ	f	large
120385	83472	1288	Саратовская область, Петровский район, село Ножкино, Советская, 36, МОУ начальная школа-детсад	f	small
120376	83463	1278	Саратовская область, Петровский район, село Новозахаркино, 70 лет Октября, 70, МОУ СОШ	f	medium
120387	83474	1290	Саратовская область, Петровский район, село Новодубровка, Молодежная, 26, административное здание	f	medium
120368	83455	1270	Саратовская область, Петровский район, село Новая Усть-Уза, Центральная, 38, МОУ начальная школа-детсад	f	small
120380	83467	1283	Саратовская область, Петровский район, село Мирный, Школьная, 2, МОУ ООШ	f	small
120382	83469	1285	Саратовская область, Петровский район, село Колки, Центральная, 2, сельский клуб	f	small
120370	83457	1272	Саратовская область, Петровский район, село Кожевино, Рабочая, 23, административное здание	f	medium
120372	83459	1274	Саратовская область, Петровский район, село Грачевка, Новоселов, 18 а , административное здание, ул. Новоселов, д. 1 а МОУ СОШ	f	medium
120384	83471	1287	Саратовская область, Петровский район, село Вязьмино, Центральная, 45 , административное здание	f	medium
120379	83466	1282	Саратовская область, Петровский район, село Березовка 1-я, Центральная, 26, административное здание	f	medium
120367	83454	1269	Саратовская область, Петровский район, село Березовка, Советская, 175, административное здание	f	medium
120374	83461	1276	Саратовская область, Петровский район, село Асметовка, Ленинская, 81 , МОУ ООШ	f	small
120373	83460	1275	Саратовская область, Петровский район, село Абодим, Молодежная , 12, МОУ ООШ	f	small
120351	83429	1244	Саратовская область, Перелюбский район, село Целинный, переулок Школьный, 11, здание школы	f	medium
120350	83428	1243	Саратовская область, Перелюбский район, село Холманка, Школьная, 5 , здание школы	f	small
120353	83431	1246	Саратовская область, Перелюбский район, село Харитоновка, Степная, 21, здание школы	f	small
120363	83442	1256	Саратовская область, Перелюбский район, село Тепловский, Школьная, 8а, здание школы	f	medium
120348	83426	1241	Саратовская область, Перелюбский район, село Тараховка, Степная, 4, здание школы	f	small
120357	83435	1250	Саратовская область, Перелюбский район, село Смородинка, Советская, 44	f	small
120359	83437	1252	Саратовская область, Перелюбский район, село Пригорки, Школьная, 6а , здание школы	f	small
71777	83423	1238	Саратовская область, Перелюбский район, село Перелюб, Чкаловская, 59, здание школы	f	large
71776	83422	1236	Саратовская область, Перелюбский район, село Перелюб, Ленина, 108 , Районный дом культуры	f	large
120345	83422	1237	Саратовская область, Перелюбский район, село Перелюб, Ленина, 108 , Районный дом культуры	f	\N
120356	83434	1249	Саратовская область, Перелюбский район, село Октябрьский, Советская, 36, здание школы	f	medium
120358	83436	1251	Саратовская область, Перелюбский район, село Новый Перелюб, Вокзальная, 10, здание пост ЭЦ	f	small
120352	83430	1245	Саратовская область, Перелюбский район, село Нижняя Покровка, Школьная, 7, здание школы	f	small
120347	83425	1240	Саратовская область, Перелюбский район, село Натальин Яр, Западная, 2, здание школы	f	medium
120361	83439	1254	Саратовская область, Перелюбский район, село Молодежный, Ленина, 17 , Дом культуры	f	medium
120349	83427	1242	Саратовская область, Перелюбский район, село Кучумбетово, Интернациональная, 55 , сельский Дом культуры	f	small
120355	83433	1248	Саратовская область, Перелюбский район, село Кузябаево, Озерная, 17, сельский клуб	t	small
120354	83432	1247	Саратовская область, Перелюбский район, село Калинин, Рабочая, 3а, здание школы	f	small
120346	83424	1239	Саратовская область, Перелюбский район, село Иваниха, Советская, 3, Дом культуры	f	medium
120360	83438	1253	Саратовская область, Перелюбский район, село Грачев Куст, Перетрухина, 67б, здание администрации	f	medium
120362	83441	1255	Саратовская область, Перелюбский район, село Большая Тарасовка, Школьная, 8 , здание школы	f	small
120332	83408	1223	Саратовская область, Озинский район, село Старые Озинки, Набережная, 51, администрация МО	f	medium
120343	83420	1234	Саратовская область, Озинский район, село Солянка, Терешковой, 37, МОУ Основная школа	f	small
71757	83399	1222	Саратовская область, Озинский район, село Сланцевый Рудник, 8, сельский Дом культуры	f	large
120338	83414	1229	Саратовская область, Озинский район, село Синегорский, Рабочая, 12, МОУ Средняя школа	f	medium
120337	83413	1228	Саратовская область, Озинский район, село Пигари, Октябрьская, 5 , сельский Дом культуры	f	medium
120340	83416	1231	Саратовская область, Озинский район, село Первоцелинный, Чапаевская, 6, сельский Дом культуры	f	medium
120328	83404	1218	Саратовская область, Озинский район, поселок Озинки, Советская, 49	f	medium
120320	83396	1210	Саратовская область, Озинский район, поселок Озинки, Молодежная, 4, МОУ ДОД ДЮСШ	f	medium
120319	83396	1209	Саратовская область, Озинский район, поселок Озинки, Молодежная, 4, МОУ ДОД ДЮСШ	f	medium
120323	83398	1213	Саратовская область, Озинский район, поселок Озинки, Ленина, 22, Дом культуры	f	medium
120322	83397	1212	Саратовская область, Озинский район, поселок Озинки, Комарова, 23 , администрация района	f	medium
120321	83397	1211	Саратовская область, Озинский район, поселок Озинки, Комарова, 23 , администрация района	f	medium
120325	83401	1215	Саратовская область, Озинский район, поселок Озинки, Кирова, 4	f	medium
120329	83405	1219	Саратовская область, Озинский район, поселок Озинки, Вольская, 2, МОУ Начальная школа - детский сад	f	medium
120324	83400	1214	Саратовская область, Озинский район, поселок Озинки, Ветеранов, 2, ГУ Комплексный центр социального обслуживания населения	f	medium
120330	83406	1220	Саратовская область, Озинский район, поселок Озинки, Александрова, 17 , клуб Прогресс	f	medium
120327	83403	1217	Саратовская область, Озинский район, поселок Озинки, 8 Марта, 9, МОУ Основная общеобразовательная школа	f	medium
120326	83402	1216	Саратовская область, Озинский район, поселок Озинки, 8 Марта, 9, МОУ Основная общеобразовательная школа	f	medium
120341	83417	1232	Саратовская область, Озинский район, село Новочерниговка, площадь Революции, 6 , сельский Дом культуры	f	small
120344	83421	1235	Саратовская область, Озинский район, село Новозаволжский, Школьная, 9 , МОУ Средняя школа, Адрес УИК: Школьная, 10 (администрация МО)	f	medium
120331	83407	1221	Саратовская область, Озинский район, село Непряхин, Советская, 30 , МОУ Основная общеобразовательная школа	f	medium
120334	83410	1225	Саратовская область, Озинский район, село Модин, Пионерская, 9	f	medium
120335	83411	1226	Саратовская область, Озинский район, село Липовский, Школьная, 1а, МОУ Средняя общеобразовательная школа	f	medium
120333	83409	1224	Саратовская область, Озинский район, село Горный, Школьная, 8, административное здание	f	small
120342	83419	1233	Саратовская область, Озинский район, село Белоглинный, Набережная, 20/1, сельский Дом культуры	f	medium
120339	83415	1230	Саратовская область, Озинский район, село Балаши, Советская, 19, сельский Дом культуры	f	medium
120298	83373	1186	Саратовская область, Новоузенский район, село Шукеев, Зеленая, 14, начальная школа	f	small
120303	83378	1191	Саратовская область, Новоузенский район, село Чилижный, Центральная, 24 , (начальная школа	t	small
120317	83394	1207	Саратовская область, Новоузенский район, село Чертанла, Центральная, 6, (школа) МОУ СОШ	f	small
120293	83368	1181	Саратовская область, Новоузенский район, село Труба, Клубная, 7, клуб	f	small
120295	83370	1183	Саратовская область, Новоузенский район, село Таловка, Радищева, 26, клуб	t	small
120315	83392	1205	Саратовская область, Новоузенский район, село Степной, Центральная, 18, начальная школа	f	small
120304	83379	1192	Саратовская область, Новоузенский район, село Степной, Новостепная, 24, начальная школа	t	small
120284	83359	1172	Саратовская область, Новоузенский район, село Солянка, Дружбы, 1, начальная школа	f	small
71919	83389	1202	Саратовская область, Новоузенский район, село Радищево, Радищева, 19 , ДК	f	large
120312	83388	1201	Саратовская область, Новоузенский район, село Пограничное, Копылова, 38б, школа	f	medium
120310	83386	1199	Саратовская область, Новоузенский район, село Петропавловка, Площадь Революции, 9 , ДК	f	small
120297	83372	1185	Саратовская область, Новоузенский район, село Песчаный Мар, Школьная, 4, начальная школа	t	small
120290	83365	1178	Саратовская область, Новоузенский район, село Первомайский, Советская, 1 , начальная школа	f	small
120305	83380	1193	Саратовская область, Новоузенский район, село Первомайский, Молодежная, 12, детский сад	f	small
120296	83371	1184	Саратовская область, Новоузенский район, село Основной, Советская, 23, ДК	f	medium
120308	83384	1197	Саратовская область, Новоузенский район, село Олоновка, Первомайская, 9 , ДК	f	small
120287	83362	1175	Саратовская область, Новоузенский район, Новоузенск, пл.Льва Толстого, 3, автовокзал	f	medium
120280	83354	1167	Саратовская область, Новоузенский район, Новоузенск, Хайкина, 2а, клуб пристанционного поселка	f	medium
71686	83357	1170	Саратовская область, Новоузенский район, Новоузенск, Трутнева, 48, ФГОУ НСХТ	f	large
120288	83363	1176	Саратовская область, Новоузенский район, Новоузенск, Степная, 19, начальная школа	f	small
120285	83360	1173	Саратовская область, Новоузенский район, Новоузенск, Советская, 7б, центральная библиотека	f	medium
120282	83356	1169	Саратовская область, Новоузенский район, Новоузенск, Микрорайон-2, 4, МОУ СОШ №1	f	medium
120281	83355	1168	Саратовская область, Новоузенский район, Новоузенск, Зеленый Клин, 1, ГОУ ПУ-65 (ПЛ-65)	f	medium
120283	83358	1171	Саратовская область, Новоузенский район, Новоузенск, Елецкая, 43 , МОУ СОШ №4	f	medium
120292	83367	1180	Саратовская область, Новоузенский район, село Мирный, Трудовая, 3, начальная школа	f	small
120311	83387	1200	Саратовская область, Новоузенский район, село Лохматовка, Московская, 17/2, ФАП клуб	t	small
120291	83366	1179	Саратовская область, Новоузенский район, село Ленинский, Центральная, 16, начальная школа	f	small
71920	83382	1195	Саратовская область, Новоузенский район, село Куриловка, Площадь Революции, 1а , ДК	f	large
120307	83383	1196	Саратовская область, Новоузенский район, село Куриловка, Молодежная, 1, филиал школы искусств	f	medium
120301	83376	1189	Саратовская область, Новоузенский район, село Кубанка, Молодежная, 7, начальная школа	t	small
120306	83381	1194	Саратовская область, Новоузенский район, село Крепость-Узень, Площадь Космонавтов, 17, начальная школа	f	small
120309	83385	1198	Саратовская область, Новоузенский район, село Киевка, Центральная, 37, клуб	t	small
120314	83303	1204	Саратовская область, Новоузенский район, село Карев, Рабочая, 15, начальая школа	f	small
120302	83377	1190	Саратовская область, Новоузенский район, село Дюрский, Почтовая, 2 , ДК	f	small
120299	83374	1187	Саратовская область, Новоузенский район, село Дмитриевка, Советская, 25 , ДК	f	medium
120313	83390	1203	Саратовская область, Новоузенский район, село Дейков, Рабочая, 3, начальная школа	t	small
120318	83395	1208	Саратовская область, Новоузенский район, село Ближний, Новоузенская, 69, кв.1 (начальная школа) Клуб	f	small
120294	83369	1182	Саратовская область, Новоузенский район, село Бессоновка, Октябрьская, 38, школа	f	small
120300	83375	1188	Саратовская область, Новоузенский район, село Алексеевка, Целинная, 16а, начальная школа	t	small
120289	83364	1177	Саратовская область, Новоузенский район, село Алгайский, Центральная, 11, ДК	f	medium
120195	83241	1057	Саратовская область, Краснопартизанский район, село Большая Сакма, Советская, 31-а, МОУ ООШ	f	medium
120266	83336	1148	Саратовская область, Новобурасский район, село Чернышевка, Чернышевского, 103, здание администрации с.Чернышевка	f	small
71756	83339	1151	Саратовская область, Новобурасский район, село Тепловка, Советская, 1, здание школы с.Тепловка	f	large
71677	83687	1498	Саратовская область, Новобурасский район, поселок Тарханы, МОУ Средняя обшеобразовательная школа ст. Тарханы	f	large
120264	83333	1146	Саратовская область, Новобурасский район, село Радищево, Первомайская, 18 , здание клуба с.Радищево	t	small
134482	94379	1158	Саратовская область, Новобурасский район, поселок Новые Бурасы, Советская, 4, здание школы №1	f	large
71775	83346	1159	Саратовская область, Новобурасский район, поселок Новые Бурасы, Гагарина, 52 , здание школы №2	f	large
71772	83344	1156	Саратовская область, Новобурасский район, поселок Новые Бурасы, Баумана, 29, здание ДК р.п.Новые Бурасы	f	large
71773	83335	1157	Саратовская область, Новобурасский район, поселок Новые Бурасы, Баумана, 35 , здание библиотеки	f	large
120267	83337	1149	Саратовская область, Новобурасский район, село Новоалексеевка, Центральная, 85, здание школы с.Новоалексеевка	f	small
120270	83341	1153	Саратовская область, Новобурасский район, село Марьино-Лашмино, Колхозная, 1	f	small
120277	83351	1164	Саратовская область, Новобурасский район, село Малые Озерки, Шарковых, 49, здание администрации 	f	small
120271	83342	1154	Саратовская область, Новобурасский район, село Лох, Молодежная, 8, здание администрации	f	small
120278	83352	1165	Саратовская область, Новобурасский район, село Леляевка, Юбилейная, 41, здание администрации с.Леляевка	f	small
120276	83350	1163	Саратовская область, Новобурасский район, село Кутьино, Новая, 1, здание администрации с.Кутьино	f	small
120268	83338	1150	Саратовская область, Новобурасский район, село Ириновка, Первомайская, 12	f	small
120269	83340	1152	Саратовская область, Новобурасский район, село Елшанка, Кооперативная, 1, здание администрации с.Тепловка	f	small
120279	83353	1166	Саратовская область, Новобурасский район, село Динамо, Мирная, 9А, здание школы	f	medium
120272	83343	1155	Саратовская область, Новобурасский район, село Гремячка, Колхозная, 10А, здание администрации с.Гремячка	f	small
120275	83349	1162	Саратовская область, Новобурасский район, село Вихляйка, Элеваторная, 1, здание клуба п.Вихляйка	t	small
120273	83347	1160	Саратовская область, Новобурасский район, село Бурасы, Советская, 31, здание администрации п.Бурасы	f	medium
120274	83348	1161	Саратовская область, Новобурасский район, село Белоярский, Октябрьская, 2, здание администрации	f	medium
120265	83334	1147	Саратовская область, Новобурасский район, село Аряш, Советская , 78, здание администрации	f	small
120233	83285	1099	Саратовская область, Марксовский район, село Ястребовка, Первомайская, 14а, МОУ ООШ	f	medium
120247	83304	1116	Саратовская область, Марксовский район, село Яблоня, Центральная, 15, МОУ-основная общеоб. школа	f	small
120242	83298	1111	Саратовская область, Марксовский район, село Чкаловка, Центральная, 19	f	small
120248	83305	1117	Саратовская область, Марксовский район, село Фурманово, Целинная, 9 а, МОУ-средняя общеоб.школа	f	small
120260	83321	1132	Саратовская область, Марксовский район, село Фурмановка, Заречная, 6А , Дом культуры	f	small
120236	83288	1102	Саратовская область, Марксовский район, село Степное, Душанбинская, 18/1, Центр немецкой культуры	f	small
120243	83299	1112	Саратовская область, Марксовский район, село Солнечный, Рабочая, 12	f	small
120234	83286	1100	Саратовская область, Марксовский район, село Семеновка, Школьная, 1 , МОУ-основная .общеобр. школа	f	small
120259	83320	1131	Саратовская область, Марксовский район, село Раскатово, Мелиораторов, 12, МОУ-средняя общеобразовательная школа	f	medium
120235	83287	1101	Саратовская область, Марксовский район, село Пугачевка, Центральная, 14/2, Здание бригадного дома	f	small
71861	83315	1126	Саратовская область, Марксовский район, село Приволжское, К. Маркса, 6 а, МОУ -средняя общеобразовательная школа	f	large
120237	83289	1103	Саратовская область, Марксовский район, село Полековская, Мира, 35, МОУ-средняя общеобразовательная школа	f	medium
71698	83292	1105	Саратовская область, Марксовский район, село Подлесное, Ленина, 34, Дом культуры	f	large
71697	83291	1104	Саратовская область, Марксовский район, село Подлесное, Комсомольская, 85, МОУ-средняя общеобразовательная школа	f	large
71860	83313	1125	Саратовская область, Марксовский район, село Павловка, Революции, 13, МОУ-средняя общеобразовательная школа	f	large
120258	83318	1129	Саратовская область, Марксовский район, село Осиновский, Школьная, 8, МОУ-средняя общеоб. школа	f	medium
120263	83325	1136	Саратовская область, Марксовский район, село Орловское, Ленина , 52А, Дом культуры	f	medium
120232	83284	1098	Саратовская область, Марксовский район, село Михайловка, Советская, 22, Дом досуга	f	medium
120240	83296	1109	Саратовская область, Марксовский район, село Липовка, Молодежная, 1Б, Дом досуга	f	medium
120257	83317	1128	Саратовская область, Марксовский район, село Красная Поляна, Школьная, 4	f	small
120246	83302	1115	Саратовская область, Марксовский район, село Красная Звезда, Овражная, 6	f	small
120231	83283	1097	Саратовская область, Марксовский район, село Колос, Ленина, 38 , МОУ-средняя общеобр.школа	f	medium
120249	83306	1118	Саратовская область, Марксовский район, село Кировское, Кировская, 1, МОУ-средняя общеоб. школа	f	medium
120239	83295	1108	Саратовская область, Марксовский район, село Караман, Заречная, 25 а , Дом досуга	f	medium
120255	83312	1124	Саратовская область, Марксовский район, село Каменка, Ленина, 1 , МОУ-средняя общеоб. школа	f	medium
120251	83308	1120	Саратовская область, Марксовский район, село Калининское, Центральная, 40 , МОУ-средняя общеобр. школа	f	medium
120244	83300	1113	Саратовская область, Марксовский район, село Имени Тельмана, Школьная, 11, МОУ-средняя общеоб. школа	f	small
120227	83279	1093	Саратовская область, Марксовский район, село Зоркино, Ленина, 27, МОУ-средняя общеобраз.школа	f	medium
120245	83301	1114	Саратовская область, Марксовский район, село Заря, Почтовая, 7	f	small
120229	83281	1095	Саратовская область, Марксовский район, село Георгиевка, Комсомольская, 13, МОУ-Средняя общеобраз.школа	f	medium
120230	83282	1096	Саратовская область, Марксовский район, село Воротаевка, Интернациональная, 38, Дом досуга	f	small
120250	83307	1119	Саратовская область, Марксовский район, село Вознесенка, Калинина, 4 б, МОУ-основ. общеоб. школа	f	small
120252	83309	1121	Саратовская область, Марксовский район, село Водопьяновка, Комсомольская, 6, МОУ-основная общеоб. школа	f	medium
120228	83280	1094	Саратовская область, Марксовский район, село Васильевка, Центральная, 38, Дом досуга	f	small
120254	83311	1123	Саратовская область, Марксовский район, село Бородаевка, Почтовая, 24, МОУ-основная общеобразовательная школа	f	medium
120256	83316	1127	Саратовская область, Марксовский район, село Бобровка, Центральная, 30, Дом культуры	f	small
120241	83297	1110	Саратовская область, Марксовский район, село Бобово, Фрунзе, 21, Дом досуга	f	small
120253	83310	1122	Саратовская область, Марксовский район, село Березовка, З. Космодемьянской, 10А , МОУ-основная общеобр.школа	f	medium
71699	83293	1106	Саратовская область, Марксовский район, село Баскатовка, Чапаева, 18, Дом культуры	f	large
120238	83294	1107	Саратовская область, Марксовский район, село Александровка, Колхозная, 2, Дом досуга	f	small
120261	83323	1134	Саратовская область, Марксовский район, село 1-я Андреевка, Центральная, 11Б/1, Дом культуры	f	small
120211	83260	1076	Саратовская область, Лысогорский район, село Яблочный, Садовая, 47 , МОУ СОШ п.Яблочный	f	small
120215	83264	1080	Саратовская область, Лысогорский район, село Юнгеровка, Центральная, 52, здание школы с.Юнгеровка	t	small
71859	83873	1695	Саратовская область, Лысогорский район, Энгельс, Транспортная, 30А, Детская школа искусств № 5	f	large
72459	83270	1085	Саратовская область, Лысогорский район, село Широкий Карамыш, Садовая, 37 , здание МОУ СОШ с.Широкий Карамыш	f	large
120212	83261	1077	Саратовская область, Лысогорский район, село Шереметьевка, Песчаная, 61А, здание школы	f	small
120209	83258	1074	Саратовская область, Лысогорский район, село Чадаевка, Набережная, 1, здание сельского ДК	f	small
120218	83267	1083	Саратовская область, Лысогорский район, село Урицкое, Заречная, 23А, здание МОУ СОШ с.Урицкое	f	small
120225	83276	1091	Саратовская область, Лысогорский район, село Раздольное, Школьная, 22	f	small
120121	83150	963	Саратовская область, Калининский район, село Озерки, Придорожная, 13, Школа	f	medium
120214	83263	1079	Саратовская область, Лысогорский район, село Октябрьский, Почтовая, 3, здание местной администрации	f	medium
120213	83262	1078	Саратовская область, Лысогорский район, село Новая Красавка, Садовая, 1А, здание сельского ДК	f	medium
134481	94378	1088	Саратовская область, Лысогорский район, село Невежкино, Центральная, 42, здание сельского ДК	f	small
71754	83255	1071	Саратовская область, Лысогорский район, поселок Лысые Горы	f	large
134480	94377	1070	Саратовская область, Лысогорский район, поселок Лысые Горы, пл. 50 лет Октября, 1, здание районного ДК	f	large
71755	83256	1072	Саратовская область, Лысогорский район, поселок Лысые Горы, Пионерская, 33 , дание МОУ СОШ №2 р.п.Лысые Горы	f	large
120217	83266	1082	Саратовская область, Лысогорский район, село Ключи, Набережная, 19	f	\N
120224	83275	1090	Саратовская область, Лысогорский район, село Двоенка, Советская,, 16, здание МОУ СОШ с.Двоенка	f	small
120216	83265	1081	Саратовская область, Лысогорский район, село Гремячий, Мира, 5, здание МОУ СОШ п.Гремячий	f	medium
120208	83257	1073	Саратовская область, Лысогорский район, село Бутырки, Молодежная, 11, здание сельского ДК	f	medium
120221	83272	1087	Саратовская область, Лысогорский район, село Большие Копены, Советская, 12	f	\N
120210	83259	1075	Саратовская область, Лысогорский район, село Большая Рельня, Ленинская, 115, здание сельского ДК	f	medium
120226	83277	1092	Саратовская область, Лысогорский район, село Большая Каменка, Дорожная, 2А , здание школы	f	small
120223	83274	1089	Саратовская область, Лысогорский район, село Большая Дмитриевка, Школьная, 12, здание МОУ СОШ	f	small
120220	83271	1086	Саратовская область, Лысогорский район, село Барсучий, Центральная, 4, здание лесхоза	t	small
120219	83269	1084	Саратовская область, Лысогорский район, село Атаевка, Школьная, 27А , здание сельского ДК	f	small
120201	83247	1063	Саратовская область, Краснопартизанский район, село Чистопольский, Радищева, 20, МОУ НОШ	f	small
120197	83243	1059	Саратовская область, Краснопартизанский район, село Толстовка, Центральная, 36а, МОУ СОШ	f	medium
120194	83240	1056	Саратовская область, Краснопартизанский район, село Сулак, М.Горького, 15, МОУ СОШ	f	medium
71910	83943	1779	Саратовская область, Краснопартизанский район, село Светлый, улица Лопатина, 11, здание ДЮСШ, 1 этаж вестибюль	f	large
71911	83944	1780	Саратовская область, Краснопартизанский район, село Светлый, Кузнецова, 10 , СОШ №2 спортивный зал	f	large
71909	83942	1778	Саратовская область, Краснопартизанский район, село Светлый, Кузнецова, 12, СОШ №3 спортивный зал	f	large
120193	83239	1055	Саратовская область, Краснопартизанский район, село Савельевка, Ленинская, 34 , МОУ ООШ	f	small
120206	83252	1068	Саратовская область, Краснопартизанский район, село Римско-Корсаковка, Советская, 33, МОУ СОШ	f	small
120199	83245	1061	Саратовская область, Краснопартизанский район, село Раздольное, Советская, 1, МОУ ООШ	f	small
120205	83251	1067	Саратовская область, Краснопартизанский район, село Подшибаловка, Центральная, 13-а, МОУ НОШ	f	small
120196	83242	1058	Саратовская область, Краснопартизанский район, село Петровский, Центральная, 40, МОУ СОШ	f	medium
120202	83248	1064	Саратовская область, Краснопартизанский район, село Октябрьский, Школьная, 1, МОУ ООШ	f	small
120203	83249	1065	Саратовская область, Краснопартизанский район, село Милорадовка, Степная, 5, МОУ СОШ	f	medium
120198	83244	1060	Саратовская область, Краснопартизанский район, село Корнеевка, Школьная, 4, МОУ СОШ	f	medium
120207	83253	1069	Саратовская область, Краснопартизанский район, село Емельяновка, Молодежная, 2 а, СДК	f	small
120200	83246	1062	Саратовская область, Краснопартизанский район, село Дальний, Чапаевская, 4, администрация	f	small
120192	83238	1054	Саратовская область, Краснопартизанский район, поселок Горный, Стадионная площадь, 29 б , МУ ФОК Степняк	f	\N
120190	83236	1052	Саратовская область, Краснопартизанский район, поселок Горный, Новая, 32 , филиал ФГУ Сармелиоводхоз	f	medium
120191	83237	1053	Саратовская область, Краснопартизанский район, поселок Горный, Горная, 30 а, дминистративное здание Дома культуры	f	\N
120204	83250	1066	Саратовская область, Краснопартизанский район, село Головинщено, Кутузова, 2, МОУ ООШ	f	small
116908	79814	126	Самарская область, Чапаевск, Ленина, 133Б	f	medium
120189	83223	1051	Саратовская область, Краснокутский район, село Ямское, Школьная, 10, МОУ СОШ с. Ямское	f	medium
120179	83226	1041	Саратовская область, Краснокутский район, село Чкалово, Центральная, 24, Дом культуры	f	medium
120178	83225	1040	Саратовская область, Краснокутский район, село Усатово, Клубный, 1, Дом культуры	f	medium
120169	83214	1030	Саратовская область, Краснокутский район, Студгородок, Учебный корпус Зооветтехникума	f	small
120170	83215	1031	Саратовская область, Краснокутский район, село Семенной, Зеленая, 1, Дом культуры	f	small
120173	83219	1035	Саратовская область, Краснокутский район, село Репное, клуб	f	small
120187	83234	1049	Саратовская область, Краснокутский район, село Рекорд, Школьная, 12, МОУ СОШ с. Рекорд	f	medium
120185	83232	1047	Саратовская область, Краснокутский район, село Первомайское, Зеленая, 10Б, Дом культуры	f	medium
120188	83235	1050	Саратовская область, Краснокутский район, село Норки, Центральная, 22, Клуб	f	small
71827	83216	1032	Саратовская область, Краснокутский район, село Логиновка, Новая, 3, МОУ СОШ с. Логиновка	f	large
120181	83228	1043	Саратовская область, Краснокутский район, село Лепехинка, Центральная, 4, Дом культуры	f	medium
120171	83217	1033	Саратовская область, Краснокутский район, село Лебедевка, Центральная, 42, Дом культуры	f	medium
120184	83231	1046	Саратовская область, Краснокутский район, село Лавровка, Советская, 41 , МДОУ Ручеек	f	medium
71801	83212	1028	Саратовская область, Краснокутский район, Красный Кут, пер.Спортивный, 2Б, стадион	f	large
71796	83207	1021	Саратовская область, Краснокутский район, Красный Кут, пер. Инкубаторный, 60, МОУ СОШ №1	f	large
71798	83209	1023	Саратовская область, Краснокутский район, Красный Кут, Московская, 50, МОУ СОШ №3	f	large
71797	83208	1022	Саратовская область, Краснокутский район, Красный Кут, Московская, 73В, районный Дом культуры	f	large
120167	83175	1026	Саратовская область, Краснокутский район, Красный Кут, Куховаренко, 196, общежитие ГОУ НПО ПУ-64	f	medium
71799	83210	1025	Саратовская область, Краснокутский район, Красный Кут, Комсомольская, 102 , МОУ СОШ №2	f	large
71800	83211	1027	Саратовская область, Краснокутский район, Красный Кут, Астраханская, 1/13, ООО Первая зерновая комп	f	large
120166	83197	1024	Саратовская область, Краснокутский район, Красный Кут, Авиационная, 25 , лицей-интернат №5 ОАО РЖД	f	medium
120177	83224	1039	Саратовская область, Краснокутский район, село Комсомольское, Советская,, 34 , МОУ СОШ с. Комсомльское	f	medium
120182	83229	1044	Саратовская область, Краснокутский район, село Кирово, Центральная, 5, МОУ СОШ с. Кирово	f	medium
120174	83220	1036	Саратовская область, Краснокутский район, село Карпенка, Центральная, 53, Дом культуры	f	medium
120186	83233	1048	Саратовская область, Краснокутский район, село Интернациональное, Школьная, 7, МОУ СОШ с. Интернациональное	f	medium
120168	83213	1029	Саратовская область, Краснокутский район, село Загородный, Центральная, 3 , Дом культуры	f	medium
120176	83222	1038	Саратовская область, Краснокутский район, село Журавлевка, Центральная, 1, Дом культуры	f	medium
120172	83218	1034	Саратовская область, Краснокутский район, село Ждановка, Центральная, 1, дом культуры	f	medium
120180	83227	1042	Саратовская область, Краснокутский район, село Дьяковка, Энгельса, 1, Дом культуры	f	medium
120175	83221	1037	Саратовская область, Краснокутский район, село Верхний Еруслан, Советская, 31А, Дом культуры	f	medium
120183	83230	1045	Саратовская область, Краснокутский район, село Ахмат, Солнечный, 11, Дом культуры	f	medium
120157	83198	1012	Саратовская область, Красноармейский район, село Усть-Золиха, Центральная, 40, Здание СДК	f	medium
120160	83201	1015	Саратовская область, Красноармейский район, село Старая Топовка, Здание МОУ ООШ	f	small
120162	83203	1017	Саратовская область, Красноармейский район, село Сплавнуха, Ленина, 30, Здание МОУ СОШ	f	medium
120136	83177	991	Саратовская область, Красноармейский район, село Сосновка, Красноармейская, 12, Здание МОУ ООШ с. Сосновка	f	small
120138	83179	993	Саратовская область, Красноармейский район, село Садовое, МОУ СОШ	f	medium
120145	83185	1000	Саратовская область, Красноармейский район, село Рогаткино, Центральная, 64, Здание МОУ ООШ с. Рогаткино	f	small
70697	79805	115	Самарская область, Чапаевск, Ленина, 51	f	large
120140	83181	995	Саратовская область, Красноармейский район, село Ревино, Советская, 12В, Здание МОУ ООШ	f	small
120152	83192	1007	Саратовская область, Красноармейский район, село Первомайское, Школьная, 16, Здание МОУ СОШ	f	medium
120164	83205	1019	Саратовская область, Красноармейский район, село Паницкая, Пионерская, 14, Здание МОУ СОШ ст. Паницкая	f	medium
120148	83188	1003	Саратовская область, Красноармейский район, село Нижняя Банновка, Кооперативная, 48, Здание МОУ СОШ	f	small
120163	83204	1018	Саратовская область, Красноармейский район, село Некрасово, Кирова, 32а, Здание МОУ СОШ с. Некрасово	f	medium
120137	83178	992	Саратовская область, Красноармейский район, село Мордово, Здание МОУ ООШ с. Мордово	f	small
120147	83187	1002	Саратовская область, Красноармейский район, село Меловое, Вишневая, 58, Здание МОУ ООШ с. Меловое	f	small
120135	83176	990	Саратовская область, Красноармейский район, село Луганское, Волжская, 45, Здание МОУ СОШ	f	medium
120134	83165	989	Саратовская область, Красноармейский район, село Луганское, Волжская, 45, Здание МОУ СОШ с. Луганское	f	medium
72466	83160	973	Саратовская область, Красноармейский район, Красноармейск, Захарова, 57, МОУ СОШ № 4	f	large
120141	83182	996	Саратовская область, Красноармейский район, село Ключи, Ульяновская, 16, Здание администрации Ключевского МО	f	small
120155	83195	1010	Саратовская область, Красноармейский район, село Карамышевка, Здание МОУ СОШ с. Карамышевка	f	small
120158	83199	1013	Саратовская область, Красноармейский район, село Карамыш, Школьная, 3, школа	f	small
120156	83196	1011	Саратовская область, Красноармейский район, село Карамыш, Почтовая, 21б, Здание СДК	f	medium
120154	83194	1009	Саратовская область, Красноармейский район, поселок Каменский, Первомайская, 59, Здание СДК	f	medium
120153	83193	1008	Саратовская область, Красноармейский район, поселок Каменский, Первомайская, 59	f	medium
120150	83190	1005	Саратовская область, Красноармейский район, село Каменка, Советская, 27, Здание МОУ СОШ № 6	f	medium
120144	83184	999	Саратовская область, Красноармейский район, село Золотое, пер.Больничный, 6б, Здание СДК	f	medium
120143	83184	998	Саратовская область, Красноармейский район, село Золотое, пер.Больничный, 6б, Здание СДК	f	medium
120151	83191	1006	Саратовская область, Красноармейский район, село Елшанка, 55 лет Победы, 2, Здание МОУ ООШ с. Елшанка 	f	small
120142	83183	997	Саратовская область, Красноармейский район, село Дубовка, Советская, 26, Здание МОУ ООШ	f	small
120146	83186	1001	Саратовская область, Красноармейский район, село Гусево, Школьная, 19, МОУ ООШ с. Гусево	f	small
120149	83189	1004	Саратовская область, Красноармейский район, село Гвардейское, Заречная, 23, Здание МОУ СОШ	f	small
120159	83200	1014	Саратовская область, Красноармейский район, село Высокое, Здание СДК с. Высокое	f	medium
120139	83180	994	Саратовская область, Красноармейский район, село Ваулино, Школьная, 19, Здание МОУ ООШ	f	small
120161	83202	1016	Саратовская область, Красноармейский район, село Бобровка, Школьная, 11, Здание МОУ СОШ с. Бобровка	f	medium
120118	83147	960	Саратовская область, Калининский район, село Шклово, Центральная, 81А	f	small
120103	83132	945	Саратовская область, Калининский район, село Широкий Уступ, Рабочая, 27, Школа	f	medium
120110	83139	952	Саратовская область, Калининский район, село Федоровка, Центральная, 57, СДК	f	small
120114	83143	956	Саратовская область, Калининский район, село Таловка, Школьный переулок, 7	f	small
120129	83159	972	Саратовская область, Калининский район, село Славновка, Кирова, 40, Школа	f	small
120112	83141	954	Саратовская область, Калининский район, село Симоновка, Советская, 22, Школа	f	medium
120125	83155	968	Саратовская область, Калининский район, село Сергиевка, Школьная , 7, Школа	f	medium
120117	83146	959	Саратовская область, Калининский район, село Свердлово, Верхняя , 52, Администрация МО	f	medium
120107	83136	949	Саратовская область, Калининский район, село Салтыково	f	small
120123	83152	965	Саратовская область, Калининский район, село Песчаный, Школьная, 9, СДК	f	small
120108	83137	950	Саратовская область, Калининский район, село Первомайское, Октябрьская, 1Б, СДК	f	small
134479	94376	958	Саратовская область, Калининский район, село Орловка, Мира, 42, Администрация МО	f	small
70694	79802	112	Самарская область, Чапаевск, Ленина, 20	f	large
120126	83156	969	Саратовская область, Калининский район, село Новые Выселки, Кооперативная, 2, Школа	f	medium
120105	83134	947	Саратовская область, Калининский район, село Новая Ивановка, Советская, 1, Школа	f	small
120122	83151	964	Саратовская область, Калининский район, село Нижегороды, Петрозавадовка, 42, Школа	f	small
120113	83142	955	Саратовская область, Калининский район, село Монастырское, Школьная, 2, Школа	f	small
120115	83144	957	Саратовская область, Калининский район, село Михайловка, Центральная, 72, Школа	f	small
120109	83138	951	Саратовская область, Калининский район, село Малая Екатериновка, Школьный тупик, 63, Школа	f	small
120119	83148	961	Саратовская область, Калининский район, село Красноармейское, Центральная, 9, Школа	f	small
120120	83149	962	Саратовская область, Калининский район, село Колокольцовка, Ленина, 57Б, Школа	f	medium
72441	83128	940	Саратовская область, Калининский район, Калининск, Чехова, 58, Центр социального обслуживания	f	large
72438	83124	937	Саратовская область, Калининский район, Калининск, Советская, 30, Районный Дом Культуры	f	large
120098	83121	933	Саратовская область, Калининский район, Калининск, Первомайская, 19, ПУ-54	f	medium
72436	83122	934	Саратовская область, Калининский район, Калининск, Ленина, 355/1, городская библиотека	f	large
72439	83125	938	Саратовская область, Калининский район, Калининск, Коллективная, 96, районная библиотека	f	large
120099	83123	936	Саратовская область, Калининский район, Калининск, Богдана Хмельницкого, 32, МОУ СОШ №1	f	medium
72437	83123	935	Саратовская область, Калининский район, Калининск, Богдана Хмельницкого, 32, МОУ СОШ №1	f	large
120101	83130	943	Саратовская область, Калининский район, Калининск, 50 лет Октября, 28	f	\N
72442	83129	941	Саратовская область, Калининский район, Калининск, 30 лет ВЛКСМ, 47, администроция МО г.Калининск	f	large
120100	83129	942	Саратовская область, Калининский район, Калининск, 30 лет ВЛКСМ, 47, администроция МО г.Калининск	f	\N
72465	83153	966	Саратовская область, Калининский район, село Казачка, Молодежная, 2/1, Администрация МО	f	large
120106	83135	948	Саратовская область, Калининский район, село Дубравный, Школьная, 5, СДК	f	small
120111	83140	953	Саратовская область, Калининский район, село Большая Ольшанка, Центральная, 4, Школа	f	medium
120128	83158	971	Саратовская область, Калининский район, село Ахтуба, Центральная, 158, школа	f	medium
120104	83133	946	Саратовская область, Калининский район, село Анастасьино, Центральная, 2, Школа	f	small
120127	83157	970	Саратовская область, Калининский район, село Александровка 3-я, Пушкина, 8А, Школа	f	medium
120095	83118	930	Саратовская область, Ивантеевский район, село Яблоневый Гай, Чапаева, 39, сельский Дом Культуры	f	medium
120093	83116	928	Саратовская область, Ивантеевский район, село Чернава, Центральная, 37, сельский Дом Культуры	f	small
120088	83108	920	Саратовская область, Ивантеевский район, село Раевка, Центральная , 66, сельский Дом Культуры	f	small
120086	83105	917	Саратовская область, Ивантеевский район, село Николаевка, Кооперативная, 94 , сельский Дом Культуры	f	small
120089	83109	921	Саратовская область, Ивантеевский район, село Мирный, Рабочая, 12, здание школы	f	small
120097	83120	932	Саратовская область, Ивантеевский район, село Клевенка, Советская, 93 А, сельский Дом Культуры	f	medium
120096	83119	931	Саратовская область, Ивантеевский район, село Канаевка, Школьная, 1, МОУ ООШ 	f	medium
72457	83112	924	Саратовская область, Ивантеевский район, село Ивантеевка, Советская, 24, МУ ЦДК	f	large
72456	83111	923	Саратовская область, Ивантеевский район, село Ивантеевка, Советская, 23 , МОУ СОШ с.Ивантеевка	f	large
72458	83113	925	Саратовская область, Ивантеевский район, село Ивантеевка, Московская, 1, Ивантеевская ЦРБ Поликлиника	f	large
120090	83110	922	Саратовская область, Ивантеевский район, село Ивантеевка, Кооперативная, 11 А, Дом кино Колос	f	medium
120091	83114	926	Саратовская область, Ивантеевский район, село Ивантеевка, Строителей, 16, МОУ Гимназия с. Ивантеевка	f	medium
120092	83115	927	Саратовская область, Ивантеевский район, село Ивановка, Кооперативная, 49, сельский Дом Культуры	f	medium
72455	83106	918	Саратовская область, Ивантеевский район, село Знаменский, Центральная, 20 А, сельский Дом Культуры	f	large
70696	79804	114	Самарская область, Чапаевск, Куйбышева, 13А	f	large
120094	83117	929	Саратовская область, Ивантеевский район, село Восточный, Зеленая, 44, сельский клуб	f	small
120085	83104	916	Саратовская область, Ивантеевский район, село Бартеневка, Победы, 42, сельский Дом Культуры	f	medium
120087	83107	919	Саратовская область, Ивантеевский район, село Арбузовка, Арбузовская, 15 А, МОУ ООШ с.Арбузовка	f	small
120053	83070	883	Саратовская область, Ершовский район, село Южный, Центральная, 4, Здание МОУ СОШ	f	small
134478	94375	897	Саратовская область, Ершовский район, село Чугунка, Юбилейная, 2А, Здание МОУ ООШ	f	small
120069	83086	899	Саратовская область, Ершовский район, село Чкалово, 60 лет СССР, Здание МОУ СОШ	f	small
120058	83075	888	Саратовская область, Ершовский район, село Черная Падина, Советская, 34, Здание МОУ ООШ	f	small
120083	83101	914	Саратовская область, Ершовский район, село Чапаевка, Школьная, 111А, Здание МОУ СОШ	f	medium
120055	83072	885	Саратовская область, Ершовский район, село Целинный, Ленина, 4, Здание администрации МО	f	medium
72480	83065	879	Саратовская область, Ершовский район, село Учебный, Центральная, 24, здание администрации	f	large
120050	83067	880	Саратовская область, Ершовский район, село Тулайково, здание конторы ОСОЗ Ершовское	f	small
120079	83097	910	Саратовская область, Ершовский район, село Трудовое, Центральная, 28 , Здание Дом кульутры	f	small
120071	83089	902	Саратовская область, Ершовский район, село Сокорная Балка, Центральная, 43 , Здание МОУ ООШ	f	small
120054	83071	884	Саратовская область, Ершовский район, село Семено-Полтавка, Семеново-Полтавская, 57, МОУ СОШ	f	small
120061	83078	891	Саратовская область, Ершовский район, село Садовый, Рабочая, 7, Здание детского сада	f	small
120082	83100	913	Саратовская область, Ершовский район, село Рефлектор, Ленина, 13, Здание МОУ СОШ	f	medium
120051	83068	881	Саратовская область, Ершовский район, село Полуденный, здание МОУ СОШ (школы)	f	small
120080	83098	911	Саратовская область, Ершовский район, село Перекопное, Пылайкина, 65, Здание МОУ СОШ	f	medium
120074	83092	905	Саратовская область, Ершовский район, село Осинов Гай, Школьная, 9, здание МОУ СОШ	f	small
120077	83095	908	Саратовская область, Ершовский район, село Орлов Гай, Саловая, 46, Здание детского сада МДОУ Калинка	f	medium
120078	83096	909	Саратовская область, Ершовский район, село Орлов Гай, Кривошеева, 45А, Здание МОУ СОШ	f	small
120056	83073	886	Саратовская область, Ершовский район, село Новый, Рабочая, 15, Здание начальной школы	f	small
120075	83093	906	Саратовская область, Ершовский район, село Новосельский, Заводская, 30, здание МОУ СОШ	f	medium
120073	83091	904	Саратовская область, Ершовский район, село Новорепное, Советская, 44, Здание МОУ СОШ	f	medium
72454	83088	901	Саратовская область, Ершовский район, село Новая Краснянка, Братиславская, 28А, контора к-за 18 п/с (Здание Дома культуры)	f	large
120068	83085	898	Саратовская область, Ершовский район, село Нестерово, Новая, 1а, Здание Дома культуры	f	small
120070	83087	900	Саратовская область, Ершовский район, село Моховое, 25 партсъезда, Здание МОУ СОШ	f	medium
120062	83079	892	Саратовская область, Ершовский район, село Михайло-Вербовка, Почтовая, 2А, МОУ НОШ	f	small
120066	83083	896	Саратовская область, Ершовский район, село Миусс, Комсомольская, 20, Здание МОУ СОШ	f	medium
120064	83081	894	Саратовская область, Ершовский район, село Марьевка, Молодежная, 2А, Здание МОУ ООШ	f	small
120076	83094	907	Саратовская область, Ершовский район, село Лобки 2-е, Прудовая, 112, МОУ СОШ	f	small
120072	83090	903	Саратовская область, Ершовский район, село Лесной, Молодежная, 121 , Здание сельского клуба (начальной школы)	f	small
120060	83077	890	Саратовская область, Ершовский район, село Кушумский, Советская, 1, Здание МОУ СОШ	f	small
120057	83074	887	Саратовская область, Ершовский район, село Краснянка, Переулок Больничный, 23, Здание МОУ СОШ	f	small
120065	83082	895	Саратовская область, Ершовский район, село Красный Боец, Центральная, Здание МОУ СОШ)	f	medium
72445	83055	869	Саратовская область, Ершовский район, Ершов, Юбилейная, 2А, здание центра Досуга и кино (ГДК)	f	large
72478	83062	876	Саратовская область, Ершовский район, Ершов, Урожайная, 1В, здание Вагонного ремонтного депо	f	large
72479	83064	878	Саратовская область, Ершовский район, Ершов, Ремонтная, 1 , контора ООО МТС Ершовская	f	large
72474	83058	872	Саратовская область, Ершовский район, Ершов, Некрасова, здание МОУ СОШ №3	f	large
72477	83061	875	Саратовская область, Ершовский район, Ершов, Мелиоративная, 41, здание УГАДН	f	large
72476	83060	874	Саратовская область, Ершовский район, Ершов, Мелиоративная, 19, поликлиника	f	large
72473	83057	871	Саратовская область, Ершовский район, Ершов, Локомотивная, 96, ДДТ	f	large
72475	83059	873	Саратовская область, Ершовский район, Ершов, Крупской, здание РОСТО ДОСААФ	f	large
72444	83053	867	Саратовская область, Ершовский район, Ершов, Краснопартизанская, 4, РДК	f	large
120049	83063	877	Саратовская область, Ершовский район, Ершов, Дорожный проезд, 2, здание МОУ СОШ №5	f	medium
134474	94371	866	Саратовская область, Ершовский район, Ершов, Горького, 2а, МОУ СОШ №2	f	large
120048	83054	868	Саратовская область, Ершовский район, Ершов, Гагарина, Дом кино Юность	f	medium
72446	83056	870	Саратовская область, Ершовский район, Ершов, Вокзальная, 69 , МОУ СОШ № 4	f	large
134473	94370	865	Саратовская область, Ершовский район, Ершов, 22 Партсъезда, 23, МОУ СОШ № 1	f	large
134476	94373	889	Саратовская область, Ершовский район, село Еремеевка, Ленина, 10а, Здание МОУ ООШ	f	small
120084	83102	915	Саратовская область, Ершовский район, село Дмитриевка, Молодежная , 10А, Здание МОУ СОШ	f	small
134477	94374	893	Саратовская область, Ершовский район, село Верхний Кушум, Молодежная, 3а, Здание МОУ СОШ	f	small
120081	83099	912	Саратовская область, Ершовский район, село Васильевка, Школьная, 6, МОУ СОШ	f	small
134475	94372	882	Саратовская область, Ершовский район, село Антоновка, Парковая, 6, Здание МОУ СОШ	f	medium
120035	83037	851	Саратовская область, Екатериновский район, село Юбилейный, Юбилейная, 1 , здание МОУ СОШ п.Юбилейный	f	small
120034	83036	850	Саратовская область, Екатериновский район, село Упоровка, Ленинская, 71А, здание Упоровского ФАП	f	small
120047	83050	864	Саратовская область, Екатериновский район, село Сластуха, Молодежная, 7, здание МОУ СОШ	f	small
120045	83048	862	Саратовская область, Екатериновский район, село Прудовой, Молодёжная, 4, здание МОУ СОШ п.Прудовой	f	small
120046	83049	863	Саратовская область, Екатериновский район, село Переезд, Центральная, 38а, здание Переездинской ООШ	f	small
120043	83046	860	Саратовская область, Екатериновский район, село Новоселовка, Центральная, 57а, здание Новосёловского СДК	f	small
120036	83039	853	Саратовская область, Екатериновский район, село Михайловка, Кипецкая, 2а, здание МОУ СОШ с.Кипцы	f	medium
120044	83047	861	Саратовская область, Екатериновский район, село Малая Екатериновка, Майская, 57	f	small
120041	83044	858	Саратовская область, Екатериновский район, село Кручи, Школьная, 9, здание МОУ СОШ с.Кручи	f	small
120042	83045	859	Саратовская область, Екатериновский район, село Крутояр, Школьная, 22б, здание МОУ СОШ	f	small
120040	83043	857	Саратовская область, Екатериновский район, село Комаровка, Угловая, 31а, здание МОУ СОШ с.Комаровка	f	small
120037	83040	854	Саратовская область, Екатериновский район, село Колено, Новая, 19, здание Коленовского СДК	f	small
120039	83042	856	Саратовская область, Екатериновский район, село Киселевка	f	small
72435	83038	852	Саратовская область, Екатериновский район, село Индустриальный, Советская, 11б, здание МОУ СОШ п.Индустриальный, адрес УИК: Кооперативная, 10 (здание администрации МО)	f	large
120031	83033	847	Саратовская область, Екатериновский район, село Ивановка, Советская, 44	f	small
72432	83026	840	Саратовская область, Екатериновский район, поселок Екатериновка, Первомайская, 43, здание управления образования администрации района	f	large
72431	83025	839	Саратовская область, Екатериновский район, поселок Екатериновка, Молодёжная, 21, здание отдела ЗАГС	f	large
72433	83027	841	Саратовская область, Екатериновский район, поселок Екатериновка, Мичуринская, 68, здание МОУ СОШ №2; адрес УИК: Молодежная, 21 (администрация МО)	f	large
120038	83041	855	Саратовская область, Екатериновский район, село Гривки, Октябрьская, 20А, здание Гривского сельского клуба, адрес УИК: ул. Октябрьская, д. 20А (здание Гривского клуба)	f	small
120033	83035	849	Саратовская область, Екатериновский район, село Галахово, Петра Орешина, 42, здание МОУ СОШ с.Галахово	f	small
120032	83034	848	Саратовская область, Екатериновский район, село Вязовка, Центральная, 34 , здание Вязовского СДК	f	medium
120030	83031	845	Саратовская область, Екатериновский район, село Воронцовка, Верхняя, 7, здание МОУ СОШ	f	small
120029	83030	844	Саратовская область, Екатериновский район, село Бутурлинка, Центральная, 63А, здание МОУ СОШ	f	small
72434	83032	846	Саратовская область, Екатериновский район, село Бакуры, Тургенева, 5 , здание МОУ СОШ с.Бакуры	f	large
120028	83029	843	Саратовская область, Екатериновский район, село Андреевка, Рабочая, 22, здание МОУ СОШ с.Андреевка	f	small
120027	83028	842	Саратовская область, Екатериновский район, село Альшанка, Революционная, 33А, здание МОУ СОШ с.Альшанка	f	medium
120011	83010	823	Саратовская область, Духовницкий район, село Теликовка, Ленина, 19, здание Дома культуры	f	medium
120024	83022	836	Саратовская область, Духовницкий район, село Софьинка, Комсомольская, 1, здание школы	f	small
120022	83020	834	Саратовская область, Духовницкий район, село Росляково, Гагарина, 13, здание Дома культуры	f	small
120025	83023	837	Саратовская область, Духовницкий район, село Полеводинский, Заовражная, 4, здание школы	f	medium
120019	83018	831	Саратовская область, Духовницкий район, село Озерки, Гагарина, 27, здание Дома культуры	f	small
120026	83024	838	Саратовская область, Духовницкий район, село Новозахаркино	f	medium
120015	83014	827	Саратовская область, Духовницкий район, село Никольское, Советская, 57 А , здание Дома культуры	f	small
120018	83017	830	Саратовская область, Духовницкий район, село Липовка, Советская, 7 В, здание Дома культуры	f	small
120017	83016	829	Саратовская область, Духовницкий район, село Левенка, Ленина, 44, здание школы	f	small
120009	83006	818	Саратовская область, Духовницкий район, поселок Духовницкое, пл. 60 лет Советской Армии, 7 , здание школы	f	small
72453	83007	819	Саратовская область, Духовницкий район, поселок Духовницкое, Чернышевского, 32, Дом Детского Творчества	f	large
72430	83009	822	Саратовская область, Духовницкий район, поселок Духовницкое, Ленина, 10 Б, здание РДК	f	large
120010	83009	821	Саратовская область, Духовницкий район, поселок Духовницкое, Ленина, 10 Б, здание РДК	f	medium
72429	83008	820	Саратовская область, Духовницкий район, поселок Духовницкое, Красноармейская, 85, управление образования	f	large
120020	82983	832	Саратовская область, Духовницкий район, поселок Духовницкое, Заводская, 1, здание ветстанции	f	small
120021	83019	833	Саратовская область, Духовницкий район, село Дмитриевка, Ленина, 23 Б, здание Дома культуры	f	medium
120013	83012	825	Саратовская область, Духовницкий район, село Григорьевка, Пушкина, 30, здание школы	f	small
120023	83021	835	Саратовская область, Духовницкий район, село Горяиновка, Советская, 81 , здание школы	f	small
120014	83013	826	Саратовская область, Духовницкий район, село Брыковка, Грибанова, 56, здание Дома культуры	f	small
120016	83015	828	Саратовская область, Духовницкий район, село Богородское, Мира, 2 , здание школы	f	small
120012	83011	824	Саратовская область, Духовницкий район, село Березовая Лука, Кирова, 42, здание Дома культуры	f	medium
119997	82993	805	Саратовская область, Дергачевский район, село Тимонин, Центральная, 70 , здание МОУ СОШ	f	small
72452	83005	817	Саратовская область, Дергачевский район, село Советский, Целинная, 1А, здание СДК	f	large
120008	83004	816	Саратовская область, Дергачевский район, село Сафаровка, Комсомольская, 56, (здание МОУ СОШ	f	medium
120007	83003	815	Саратовская область, Дергачевский район, село Петропавловка, Советская, 51А, здание МОУ СОШ	f	medium
120002	82998	810	Саратовская область, Дергачевский район, село Первомайский, переулок Школьный, 5, здание МОУ СОШ	f	medium
120006	83002	814	Саратовская область, Дергачевский район, село Орошаемый, пер. Школьный, 1, (здание МОУ СОШ	f	medium
120005	83001	813	Саратовская область, Дергачевский район, село Октябрьский, Школьна, 37, здание МОУ СОШ	f	small
119998	82994	806	Саратовская область, Дергачевский район, село Новоросляевка, Данукалова, 46, здание МОУ СОШ	f	small
120003	82999	811	Саратовская область, Дергачевский район, село Мирный, Советская, 21А, здание МОУ СОШ	f	medium
120004	83000	812	Саратовская область, Дергачевский район, село Красноозерный, Школьная, 19, здание МОУ СОШ	f	medium
120001	82997	809	Саратовская область, Дергачевский район, село Камышево, Школьная, 10, здание МОУ СОШ	f	small
70695	79803	113	Самарская область, Чапаевск, Куйбышева, 12А	f	large
120000	82996	808	Саратовская область, Дергачевский район, село Зерновой, Школьная, 2, здание МОУ СОШ	f	medium
119999	82995	807	Саратовская область, Дергачевский район, село Жадовка, Ленинская, 7, здание МОУ СОШ	f	small
72449	82980	793	Саратовская область, Дергачевский район, поселок Дергачи, Советская, 86, здание МОУ СОШ №1	f	large
119987	82978	791	Саратовская область, Дергачевский район, поселок Дергачи, Советская, 76, здание ДДТ	f	medium
119988	82981	794	Саратовская область, Дергачевский район, поселок Дергачи, Сиреневая, 14, Молодежный центр	f	\N
72450	82984	796	Саратовская область, Дергачевский район, поселок Дергачи, Садовая, 39 , здание Заволжские ЭС	f	large
72448	82979	792	Саратовская область, Дергачевский район, поселок Дергачи, Олимпийская, 6, здание МДОУ Тополек	f	large
119990	82985	797	Саратовская область, Дергачевский район, поселок Дергачи, Набережная, 2, здание МОУ СОШ №2	f	small
119991	82986	798	Саратовская область, Дергачевский район, поселок Дергачи, Комсомольская, 80, адм.здание межрайонной инспекции федеральной налоговой службы России №49 по Саратовской области	f	\N
119989	82982	795	Саратовская область, Дергачевский район, поселок Дергачи, Веселый, 6, детский сад Дружба	f	small
72451	82992	804	Саратовская область, Дергачевский район, село Демьяс, Комсомольская, 58, здание МОУ СОШ	f	large
119996	82991	803	Саратовская область, Дергачевский район, село Восточный, Школьная, 6, здание МОУ СОШ	f	small
119995	82990	802	Саратовская область, Дергачевский район, село Верхазовка, Комсомольская, 68, здание МОУ СОШ	f	medium
119992	82987	799	Саратовская область, Дергачевский район, село Васильевка 1-я, Центральная, 44, здание детского сада	f	small
119994	82989	801	Саратовская область, Дергачевский район, село Антоновка, Набережная, 2Б , здание СДК	f	small
119993	82988	800	Саратовская область, Дергачевский район, село Алтата, Школьная, 1 , здание МОУ СОШ	f	medium
119972	82961	774	Саратовская область, Воскресенский район, село Чардым, Советская, 30, административное здание Елшанского МО	f	medium
119974	82964	777	Саратовская область, Воскресенский район, село Усовка, Набережная, 36, здание СК	f	small
119976	82966	779	Саратовская область, Воскресенский район, село Студеновка, Тростянка, 25а, здание МОУ СОШ	f	small
119971	82960	773	Саратовская область, Воскресенский район, село Славянка, Центральная, 21, дом культуры	f	small
119977	82967	780	Саратовская область, Воскресенский район, село Синодское, Клочкова, 30, Синодский СДК	f	medium
119983	82973	786	Саратовская область, Воскресенский район, село Новая Алексеевка, 70 лет Октября, 35, СК	f	small
119978	82968	781	Саратовская область, Воскресенский район, село Медяниково, Центральная, 29, Медяниковский СК	f	small
119980	82970	783	Саратовская область, Воскресенский район, село Кошели, Вишневая, 10, МОУ НОШ	t	small
119973	82962	775	Саратовская область, Воскресенский район, село Коммуна 3-я, Запрудная, 9, сельский клуб	t	small
119985	82975	788	Саратовская область, Воскресенский район, село Каломка, Луговая, 17	t	small
72421	82963	776	Саратовская область, Воскресенский район, село Елшанка, Школьная, 39б, здание СДК	f	large
72447	82977	790	Саратовская область, Воскресенский район, село Воскресенское, Шеина, 25, здание детской школы искусств	f	large
119986	82976	789	Саратовская область, Воскресенский район, село Воскресенское, Партизанская, 10, адм.здание ГБУ УСЗН	f	\N
119982	82972	785	Саратовская область, Воскресенский район, село Булгаковка, Новая, 43, СК	f	small
119979	82969	782	Саратовская область, Воскресенский район, село Букатовка, Школьная, 13, МОУ СОШ	f	small
119984	82974	787	Саратовская область, Воскресенский район, село Биктимировка, Мусы Джалиля, 29	t	small
119981	82971	784	Саратовская область, Воскресенский район, село Березняки, Набережная, 3а, Березняковский СК	t	small
119975	82965	778	Саратовская область, Воскресенский район, село Андреевка, Луговая,, 20, здание СК	f	small
119942	82929	739	Саратовская область, Вольский район, село Юловая Маза, Центральная, 40 , Детский сад	f	small
71912	83945	1781	Саратовская область, Вольский район, поселок Шиханы, улица Ленина, 22 	f	large
71913	83946	1782	Саратовская область, Вольский район, поселок Шиханы, Ленина, 8, ДК Корунд	f	large
119964	82953	766	Саратовская область, Вольский район, село Широкий Буерак, Коммунистическая, 2А	f	medium
119948	82933	745	Саратовская область, Вольский район, село Шировка, Ленина, 2-А, здание ФАП	t	small
72420	82950	763	Саратовская область, Вольский район, поселок Черкасское, Московская, 5, Дом культуры	f	large
119969	82958	771	Саратовская область, Вольский район, село Труевая Маза, Народная, 20-А, ФАП	t	small
119961	82949	762	Саратовская область, Вольский район, село Тополевый, Санаторная, 5, санаторий Светлана	t	small
119957	82945	758	Саратовская область, Вольский район, село Терса, Талалихина , 1, Библиотека сельхозтехникума	f	small
72427	82907	757	Саратовская область, Вольский район, село Терса, Советская, 26, Школа	f	large
119958	82946	759	Саратовская область, Вольский район, село Терса, Красный Октябрь, 29 , Детский сад № 2	f	medium
119959	82947	760	Саратовская область, Вольский район, село Тепловка, Талалихина, 154, Детский сад	f	small
119955	82943	755	Саратовская область, Вольский район, село Талалихино, Школьная, 2, Школа	f	small
119962	82951	764	Саратовская область, Вольский район, село Спасское, Народная, 28, Клуб с. Спасское	t	small
72425	82939	751	Саратовская область, Вольский район, поселок Сенной, переулок Школьный, 8, Школа № 2	f	large
72424	82938	750	Саратовская область, Вольский район, поселок Сенной, пер. Школьный, 3, Школа № 47	f	large
72426	82940	752	Саратовская область, Вольский район, поселок Сенной, Солопова, 17-А, Детский сад № 51	f	large
119953	82941	753	Саратовская область, Вольский район, поселок Сенной, Привокзальная, 36, ЖД Вокзал	f	small
119920	82886	694	Саратовская область, Вольский район, село Покурлей, Октябрьская, 191 А, Школа	f	small
119967	82956	769	Саратовская область, Вольский район, село Покровка, Центральная, 1-Г , Школа	f	small
119934	82921	731	Саратовская область, Вольский район, поселок Откормсовхоз, д. 11, кв. 8	f	small
119968	82957	770	Саратовская область, Вольский район, село Осиновка, Центральная, 79/1, Школа - сад	t	small
119952	82937	749	Саратовская область, Вольский район, село Николаевка, Молодежная, 19, Школа	f	small
119950	82935	747	Саратовская область, Вольский район, село Нижняя Чернавка, Пролетарская, 32, здание администрации	f	medium
119970	82959	772	Саратовская область, Вольский район, село Междуречье, Луговая, 23 , Школа	f	small
119949	82934	746	Саратовская область, Вольский район, село Куриловка, ФАП ст. Куриловка	t	small
119946	82931	743	Саратовская область, Вольский район, село Куриловка, Садовая, 20-А, Школа	f	medium
119956	82807	756	Саратовская область, Вольский район, село Куликовка, Рабочая, 1-А, Школа	f	small
119951	82936	748	Саратовская область, Вольский район, село Кряжим, пер. Школьный, 4, Школа	f	small
119944	82578	741	Саратовская область, Вольский район, село Колояр, Ленина, 21, Школа	f	medium
119954	82942	754	Саратовская область, Вольский район, село Ключи	f	small
72403	82887	695	Саратовская область, Вольский район, поселок Клены, Радужная площадь, 2, ДК Факел	f	large
119963	82952	765	Саратовская область, Вольский район, село Калмантай, Ленина, 29-А, Школа	f	small
134496	94391	1764	Саратовская область, Вольский район, село Заветное, Центральная, 16, здание МОУ СОШ	f	medium
119945	82695	742	Саратовская область, Вольский район, село Ерыкла, Народная, 33, Клуб	t	small
119947	82932	744	Саратовская область, Вольский район, село Елховка, Советская, 9-А, АКЦ с. Елховка	t	small
119960	82948	761	Саратовская область, Вольский район, село Девичьи Горки, Колхозная, 16, Библиотека	f	small
72406	82890	698	Саратовская область, Вольский район, Вольск, поселок Большевик, 63, МОУ СОШ № 4	f	large
119923	82895	703	Саратовская область, Вольский район, Вольск, Здравоохранения, 50, поликлиника № 1	f	medium
72408	82461	702	Саратовская область, Вольский район, Вольск, Дзержинского, 20, ГОУ СО Волжанка	f	large
72419	82917	726	Саратовская область, Вольский район, Вольск, Водопьянова, 140, спортивная школа	f	large
119943	82930	740	Саратовская область, Вольский район, село Верхняя Чернавка, Революционная, 35, Школа	f	medium
119966	82955	768	Саратовская область, Вольский район, село Богородское, Октябрьская, 2-А, ФАП	f	small
119965	82954	767	Саратовская область, Вольский район, село Богатое, Коммунистическая, 43 , Школа	f	small
119941	82928	738	Саратовская область, Вольский район, село Белогорное, 65 лет Октября, 10, Дом культуры	f	small
119940	82927	737	Саратовская область, Вольский район, село Барановка, Ленина, 58, Школа	f	medium
72402	82885	693	Саратовская область, Балтайский район, село Царевщина, Ленина, 30, администрация МО	f	large
119917	82882	690	Саратовская область, Балтайский район, село Старое Сарайкино, Центральная, 6, Старосарайкинский клуб	f	small
119918	82883	691	Саратовская область, Балтайский район, село Сосновка, Советская, 2, Сосновский сельский ДК	f	small
72401	82881	689	Саратовская область, Балтайский район, село Садовка, Победы, 105, Садовский сельский ДК	f	large
119916	82880	688	Саратовская область, Балтайский район, село Пилюгино, Центральная, 57, Пилюгинский сельский ДК	f	small
119915	82879	687	Саратовская область, Балтайский район, село Осановка, Вишневая, 22, Осановский сельский клуб	t	small
119914	82878	686	Саратовская область, Балтайский район, село Новая Лопастейка, Почтовая, 62, Новолопастейский сельский ДК	t	small
119913	82877	685	Саратовская область, Балтайский район, село Малая Караваевка, Зеленая, 30, Малокараваевский клуб	f	small
119912	82876	684	Саратовская область, Балтайский район, село Журавлиха, Колхозная, 87, Журавлихинский сельский ДК	f	small
119911	82875	683	Саратовская область, Балтайский район, село Донгуз, Победы, 26а, Донгузский сельский ДК	f	medium
119910	82874	682	Саратовская область, Балтайский район, село Всеволодчино, Новая, 49, Всеволодчинский клуб	f	small
119909	82873	681	Саратовская область, Балтайский район, село Большие Озерки, Пионерская, 4, Большеозерский сельский ДК	f	medium
119908	82872	680	Саратовская область, Балтайский район, село Барнуковка, Новая, 36а, Барнуковский сельский ДК	f	medium
72400	82871	679	Саратовская область, Балтайский район, село Балтай, Ленина, 1 , районный Дом культуры, 3 этаж	f	large
72399	82870	678	Саратовская область, Балтайский район, село Балтай, Ленина, 1, районный Дом культуры, 2 этаж	f	large
119907	82197	677	Саратовская область, Балашовский район, село Хоперское, Здание ФГУ САС Балашовская	f	small
72398	82141	676	Саратовская область, Балашовский район, село Хоперское, МОУ СОШ села Хоперское	f	large
119873	82841	638	Саратовская область, Балашовский район, село Устиновка, Клуб	f	small
72397	81713	674	Саратовская область, Балашовский район, село Тростянка, МОУ СОШ с. Тростянка	f	large
119903	82866	671	Саратовская область, Балашовский район, село Терновка, Дом культуры	f	medium
119904	82867	672	Саратовская область, Балашовский район, село Сухая Елань, МОУ СОШ	f	medium
119902	82865	670	Саратовская область, Балашовский район, село Старый Хопер, Дом культуры	f	\N
119900	82863	668	Саратовская область, Балашовский район, село Соцземледельский, Дом культуры	f	\N
119888	82850	654	Саратовская область, Балашовский район, село Садовый, фельдшерско-акушерский пункт	f	small
119896	82860	664	Саратовская область, Балашовский район, село Родничок, Дом культуры	f	medium
119895	82859	663	Саратовская область, Балашовский район, село Репное, СОШ	f	\N
119893	82857	661	Саратовская область, Балашовский район, село Репное, клуб ООО Дорожник-Репное	f	medium
119887	82849	653	Саратовская область, Балашовский район, село Репная Вершина, фельдшерско-акушерский пункт	f	small
119879	81689	645	Саратовская область, Балашовский район, село Рассказань, Дом культуры	f	small
72428	82854	658	Саратовская область, Балашовский район, поселок Пинеровка, Дом культуры	f	large
119890	82852	656	Саратовская область, Балашовский район, село Первомайский, Дом культуры	f	medium
119889	82851	655	Саратовская область, Балашовский район, село Пады, МОУ СОШ с. Пады	f	medium
119886	82848	652	Саратовская область, Балашовский район, село Октябрьский, МОУ СОШ п. Октябрьский	f	medium
119884	82846	650	Саратовская область, Балашовский район, село Новопокровское, Дом культуры	f	medium
119874	81493	639	Саратовская область, Балашовский район, село Нижная Глебовка, клуб	t	small
119898	82861	666	Саратовская область, Балашовский район, село Михайловка, здание школы	f	small
119877	81550	643	Саратовская область, Балашовский район, село Малый Мелик, Дом культуры	f	small
119881	82843	647	Саратовская область, Балашовский район, село Малая Семеновка, Дом культуры	f	medium
119901	82864	669	Саратовская область, Балашовский район, село Львовка	t	small
72396	82856	660	Саратовская область, Балашовский район, село Лопатино, Почтовая, 1Б, здание администрации МО	f	large
70716	79827	140	Самарская область, Чапаевск, Крымская, 1	f	large
119878	81671	644	Саратовская область, Балашовский район, село Лесное, Дом культуры	f	medium
119906	82131	675	Саратовская область, Балашовский район, село Красная Кудрявка, Дом культуры	f	small
119876	81522	642	Саратовская область, Балашовский район, село Котоврас, МОУ СОШ	f	medium
119880	82842	646	Саратовская область, Балашовский район, село Конный, фельдшерско-акушерский пункт	f	small
119897	81903	665	Саратовская область, Балашовский район, село Кардаил, Дом культуры	f	small
119894	82858	662	Саратовская область, Балашовский район, село Заречное, здание администрации муниципального образования	f	small
119899	82862	667	Саратовская область, Балашовский район, село Дуплятка	f	small
119905	82868	673	Саратовская область, Балашовский район, село Данилкино, МОУ СОШ с. Данилкино	f	medium
119882	82844	648	Саратовская область, Балашовский район, село Гусевка, здание школы	f	small
119891	82853	657	Саратовская область, Балашовский район, село Ветельный, МОУ СОШ	f	small
72380	81516	641	Саратовская область, Балашовский район, село Большой Мелик, Дом культуры	f	large
119883	82845	649	Саратовская область, Балашовский район, село Березовка, здание ФАПа	t	small
119872	82840	637	Саратовская область, Балашовский район, село Барки, Дом культуры	f	medium
119870	82830	627	Саратовская область, Балашовский район, Балашов, Юбилейная, 2 , здание ГОУ Профессиональное училище №47	f	\N
119860	82803	598	Саратовская область, Балашовский район, Балашов, Пушкина, 88, Детская Школа искусств № 1	f	medium
72366	82819	619	Саратовская область, Балашовский район, Балашов, Макаренко, 46, МОУ СОШ № 9	f	large
72362	82819	615	Саратовская область, Балашовский район, Балашов, Макаренко, 46, МОУ СОШ № 9	f	large
72359	82816	612	Саратовская область, Балашовский район, Балашов, Луначарского, 100, Учебный корпус БТМ с/х	f	large
72348	82799	594	Саратовская область, Балашовский район, Балашов, Ленина, 67, МОУ СОШ № 6	f	large
72347	82799	593	Саратовская область, Балашовский район, Балашов, Ленина, 67, МОУ СОШ № 6	f	large
72363	82820	616	Саратовская область, Балашовский район, Балашов, К. Маркса, 69, Детская художественная школа	f	large
72350	82801	596	Саратовская область, Балашовский район, Балашов, Горохова, 11, Драматический театр	f	large
72360	82817	613	Саратовская область, Балашовский район, Балашов, Астраханская, 87, Детская библиотека	f	large
72374	82834	631	Саратовская область, Балашовский район, Балашов, Юбилейная, 13, МОУ СОШ № 3	f	large
119892	82855	659	Саратовская область, Балашовский район, село Алмазово, МОУ СОШ	f	small
119885	82847	651	Саратовская область, Балашовский район, село Александровский, здание школы	f	small
72345	82795	589	Саратовская область, Балашов городской округ, поселок Ветлянка, Ленина, 182, МОУ СОШ № 17	f	large
72344	82795	588	Саратовская область, Балашов городской округ, поселок Ветлянка, Ленина, 182, МОУ СОШ № 17	f	large
119857	82794	580	Саратовская область, Балаковский район, село Хлебновка, Советская, 124, МОУ ООШ	f	small
119848	82784	585	Саратовская область, Балаковский район, село Сухой Отрог, Краснознаменцев, 67, МОУ ООШ	f	medium
119838	82774	583	Саратовская область, Балаковский район, село Пылковка, Молодежная, 29, МОУ ООШ	f	small
119846	82782	576	Саратовская область, Балаковский район, село Подсосенки, Школьная, 10, МОУ ООШ	f	medium
119832	82766	560	Саратовская область, Балаковский район, село Плеханы, Ленина, 171 , МОУ СОШ	f	medium
119849	82785	586	Саратовская область, Балаковский район, село Перекопная Лука, Садовая, 73А, МУК СДК	f	small
119837	82773	575	Саратовская область, Балаковский район, село Новый Елюзань, Советская, 22 , МУК СДК	f	small
119834	82769	581	Саратовская область, Балаковский район, село Новополеводино, Центральная, 30, МУК СКЦ	f	medium
119853	82789	578	Саратовская область, Балаковский район, село Новониколаевский, Советская, 28, МОУ СОШ	f	medium
119836	82771	574	Саратовская область, Балаковский район, село Никольское-Казаково, Ворошилова, 42А , МУК СДК	f	small
119856	82793	579	Саратовская область, Балаковский район, село Николевский, Школьная, 3А, МОУ СОШ	f	medium
119855	82792	569	Саратовская область, Балаковский район, село Николаевка, Центральная, 13, МОУ ООШ	f	small
119841	82777	572	Саратовская область, Балаковский район, село Наумовка, Победы, 19, МОУ СОШ	f	small
116912	79823	136	Самарская область, Чапаевск, Крестьянская, 6	f	medium
72343	82790	571	Саратовская область, Балаковский район, село Натальино, Карла Маркса, 19, МОУ СОШ	f	large
72394	82768	570	Саратовская область, Балаковский район, село Маянга, Мельникова, 60А, МУК Маянгский СКЦ	f	large
119854	82791	568	Саратовская область, Балаковский район, село Матвеевка, Кирова, 32А , МУК Матвеевский СКЦ	f	medium
119839	82775	584	Саратовская область, Балаковский район, село Малый Кушум, Заиргизная, МУК, филиал СКЦ	t	small
119850	82786	587	Саратовская область, Балаковский район, село Малоперекопное, Чапаева, 41, МУК СДК	f	medium
119835	82770	582	Саратовская область, Балаковский район, село Малая Быковка, Советская , 19, здание администрации	f	medium
119844	82780	566	Саратовская область, Балаковский район, село Криволучье-Сура, Коммунистическая, 18 , МУК ФКЦ орг. досуг насел.	f	small
134467	94364	559	Саратовская область, Балаковский район, село Красный Яр, Героев, 36, МОУ ООШ	f	medium
119843	82779	565	Саратовская область, Балаковский район, село Кормежка, Гагарина, 35, МОУ СОШ	f	medium
119840	82776	564	Саратовская область, Балаковский район, село Комсомольское, Степная, МУК СДК	f	small
72393	82764	558	Саратовская область, Балаковский район, село Ивановка, Сельхозтехникум, 1 , МОУ ООШ	f	large
119847	82783	577	Саратовская область, Балаковский район, село Затонский, Административное здание ООО Волжский терминал	f	small
119833	82767	561	Саратовская область, Балаковский район, село Еланка, Пролетарская, 15А, МОУ ООШ	f	medium
119852	82788	563	Саратовская область, Балаковский район, село Грачи, 1-й Микрорайон, 3, МУК филиал СДК	f	small
119851	82787	562	Саратовская область, Балаковский район, село Головановский, Новая, 12 , Здание администрации	f	medium
72395	82772	557	Саратовская область, Балаковский район, село Быков Отрог, Набережная, 1Б, МУК СКЦ	f	large
119842	82778	573	Саратовская область, Балаковский район, село Большой Кушум, Молодежная, 5А , МУК филиал СДК	f	small
119845	82781	567	Саратовская область, Балаковский район, село Береговой, Мира, 8, МУК ФКЦ 	f	small
72337	82741	526	Саратовская область, Балаковский район, Балаково, Шевченко, 90, МОУ СОШ №8	f	large
72336	82741	525	Саратовская область, Балаковский район, Балаково, Шевченко, 90, МОУ СОШ №8	f	large
72304	82748	536	Саратовская область, Балаковский район, Балаково, Трнавская, 16А, МОУ СОШ №16	f	large
72303	82748	535	Саратовская область, Балаковский район, Балаково, Трнавская, 16А, МОУ СОШ №16	f	large
72302	82748	534	Саратовская область, Балаковский район, Балаково, Трнавская, 16А, МОУ СОШ №16	f	large
72322	82729	509	Саратовская область, Балаковский район, Балаково, Титова, 2А, МУК Бал. драмтеатр	f	large
72325	82733	513	Саратовская область, Балаковский район, Балаково, Набережная Леонова, 9, ГОУ СПО Поволжский колледж	f	large
72288	82715	489	Саратовская область, Балаковский район, Балаково, Московская, 40, ГАУ СПО Бал. мед. колледж	f	large
72332	82738	520	Саратовская область, Балаковский район, Балаково, Минская, 59 , МОУ СОШ №11	f	large
72331	82738	519	Саратовская область, Балаковский район, Балаково, Минская, 59 , МОУ СОШ №11	f	large
72287	82714	488	Саратовская область, Балаковский район, Балаково, Коммунистическая, 124А, МУК КО ГЦИ	f	large
72309	82752	541	Саратовская область, Балаковский район, Балаково, 30 лет Победы, 24, МОУ СОШ №21	f	large
72285	82712	486	Саратовская область, Балаковский, Балаково, Коммунистическая, 137 А, МОУ ДОД ДЮСШ №2	f	large
119823	82709	483	Саратовская область, Базарно-Карабулакский район, с. Большой Содом , Комсомольская, 1А, СДК	f	small
72280	82703	477	Саратовская область, Базарно-Карабулакский район, село Яковлевка, пер.Почтовый, 1б	f	large
119818	82704	478	Саратовская область, Базарно-Карабулакский район, село Шняево, Победы, 9, СОШ	f	small
72278	82697	471	Саратовская область, Базарно-Карабулакский район, поселок Хватовка, Школьная, 28 , СОШ	f	large
119822	82708	482	Саратовская область, Базарно-Карабулакский район, село Ханеневка 1-я, Школьная, 1а, СДК	f	small
119815	82700	474	Саратовская область, Базарно-Карабулакский район, село Тепляковка, Ленина, 44в , СДК	f	medium
119807	82689	464	Саратовская область, Базарно-Карабулакский район, село Сухой Карабулак, Молодежная , 7Б, СОШ	f	medium
119811	82693	468	Саратовская область, Базарно-Карабулакский район, село Стригай, Ленина, 2, СОШ	f	medium
70720	79830	144	Самарская область, Чапаевск, Котовского, 10	f	large
119821	82707	481	Саратовская область, Базарно-Карабулакский район, село Старые Бурасы, Ленина, 15	f	medium
119812	82694	469	Саратовская область, Базарно-Карабулакский район, село Старая Жуковка, Революции, 3А, СДК	f	medium
72279	82699	473	Саратовская область, Базарно-Карабулакский район, поселок Свободный, Советская, 49, СОШ	f	large
119820	82706	480	Саратовская область, Базарно-Карабулакский район, село Репьевка, Новая, 37, СОШ	f	small
119805	82681	456	Саратовская область, Базарно-Карабулакский район, село Марьино, Московская, 30а, СДК	f	small
119809	82691	466	Саратовская область, Базарно-Карабулакский район, село Максимовка, Советская, 43А, СДК	f	small
119817	82702	476	Саратовская область, Базарно-Карабулакский район, село Липовка, Октябрьская, 1б, СДК	f	medium
119814	82698	472	Саратовская область, Базарно-Карабулакский район, село Лесная Нееловка, Советская, 10/2, СДК	t	small
119808	82690	465	Саратовская область, Базарно-Карабулакский район, село Ключи, Кооперативная, 147а, СОШ	f	medium
119813	82696	470	Саратовская область, Базарно-Карабулакский район, село Казанла, Коммунистическая, 1а, СОШ	f	medium
119806	82688	463	Саратовская область, Базарно-Карабулакский район, село Ивановка, Победы, 1 , СОШ	f	medium
119810	82692	467	Саратовская область, Базарно-Карабулакский район, село Вязовка, Советская, 28, СОШ	f	medium
119825	82711	485	Саратовская область, Базарно-Карабулакский район, село Большая Чечуйка, Молодежная, 31 , СОШ	f	small
119824	82710	484	Саратовская область, Базарно-Карабулакский район, село Большая Гусиха, Школьная, 9, СОШ	f	small
119816	82701	475	Саратовская область, Базарно-Карабулакский район, село Березовка, Жукова, 13а, СОШ	f	medium
119819	82705	479	Саратовская область, Базарно-Карабулакский район, село Белая Гора, Коммунистическая, 103, СДК	f	small
72274	82684	459	Саратовская область, Базарно-Карабулакский район, поселок Базарный Карабулак, Топольчанская, 1, СОШ №2	f	large
72275	82685	460	Саратовская область, Базарно-Карабулакский район, поселок Базарный Карабулак, Социальная, 15, Техникум агробизнеса	f	large
72276	82686	461	Саратовская область, Базарно-Карабулакский район, поселок Базарный Карабулак, Некрасова, 35, АТП	f	large
72273	82683	458	Саратовская область, Базарно-Карабулакский район, поселок Базарный Карабулак, Ленина, 201, ЦСОН	f	large
72272	82682	457	Саратовская область, Базарно-Карабулакский район, поселок Базарный Карабулак, Ленина, 92а, СОШ №1	f	large
72277	82687	462	Саратовская область, Базарно-Карабулакский район, село Алексеевка, Советская, 12 , СОШ	f	large
119785	82657	434	Саратовская область, Аткарский район, село Умет, Рабочая, 8, администрация МО	f	small
119788	82661	437	Саратовская область, Аткарский район, село Тургенево, Школьная, 21А, СДК	f	medium
119795	82669	445	Саратовская область, Аткарский район, село Сазоново, Школьная, 2, здание МОУ СОШ	f	small
119787	82660	436	Саратовская область, Аткарский район, село Прокудино, Центральная, 43, СДК с. Прокудино	f	small
119801	82676	451	Саратовская область, Аткарский район, село Приречное, Рабочая, 10, СДК с. Приречное	f	small
134464	94362	444	Саратовская область, Аткарский район, село Петрово, Советская, 43А , СДК с. Петрово	f	small
119793	82667	443	Саратовская область, Аткарский район, село Песчанка, Школьная, 4, администрация МО	f	small
134465	94363	453	Саратовская область, Аткарский район, село Озерное, Школьная, 30, МОУ СОШ	f	large
119792	82666	442	Саратовская область, Аткарский район, село Марфино, Школьная, 28, МОУ СОШ с. Марфино	f	small
119790	82663	439	Саратовская область, Аткарский район, село Малые Копены, Революционная, 29, администрация МО	f	small
119802	82677	452	Саратовская область, Аткарский район, село Малая Осиновка, Солнечная, 4, МОУ ООШ с. Малая Осиновка	f	small
72270	82664	440	Саратовская область, Аткарский район, село Лопуховка, Советская, 17 , администрация МО	f	large
119799	82674	449	Саратовская область, Аткарский район, село Кочетовка, Молодежная, 16, СДК с. Кочетовка	f	small
119803	82679	454	Саратовская область, Аткарский район, село Иваново-Языковка, Чапаева, 1, администрация МО	f	medium
119789	82662	438	Саратовская область, Аткарский район, село Земляные Хутора, Советская, 17, здание МОУ СОШ	f	small
119791	82665	441	Саратовская область, Аткарский район, село Ершовка, Центральная, 12, МОУ СОШ д. Ершовка	f	medium
119797	82672	447	Саратовская область, Аткарский район, село Елизаветино, Кооперативная, 4, Здание администрациикабинет специалистов	f	\N
119786	82659	435	Саратовская область, Аткарский район, село Даниловка, Центральная, 91, СДК	f	medium
119798	82673	448	Саратовская область, Аткарский район, село Вяжля, Молодежная, 3, администрация МО	f	small
119804	82680	455	Саратовская область, Аткарский район, село Большая Осиновка, Перспективная, 27, Здание МОУ СОШ кабинет начальных классов	f	\N
119784	82656	433	Саратовская область, Аткарский район, село Большая Екатериновка, Школьная, 32/1, Здание Большеекатериновского МОкабинет специалистов	f	\N
119800	82675	450	Саратовская область, Аткарский район, село Белгаза, Центральная, 53 , СДК	f	small
119796	82670	446	Саратовская область, Аткарский район, село Барановка, Советская, 18, МОУ СОШ с. Барановка	f	medium
72266	82651	428	Саратовская область, Аткарский район, Аткарск, Советская, 66, Центр детского творчества	f	large
72342	82648	425	Саратовская область, Аткарский район, Аткарск, Ленина, 76, Центр досуга и кино	f	large
134463	94361	403	Саратовская область, Аркадакский район, село Шебалов, Школьная, 28, МОУ-ООШ	f	small
119760	82621	398	Саратовская область, Аркадакский район, село Чиганак, Буднюка, 49-Б, МОУ-СОШ	f	small
119767	82629	405	Саратовская область, Аркадакский район, село Софьино, Школьная, 16, МОУ-ООШ	f	small
134461	94359	396	Саратовская область, Аркадакский район, село Семеновка, Дружбы Народов, 6, Администрация Семеновского МО	f	medium
119763	82625	401	Саратовская область, Аркадакский район, село Росташи, пер.Школьный, 21-А, сельский Дом культуры	f	medium
119778	82640	416	Саратовская область, Аркадакский район, село Подгорное, Школьная, 1А, МОУ СОШ	f	small
119759	82620	397	Саратовская область, Аркадакский район, село Памятка, Трудовая, 190, филиал МОУ-СОШ села Семеновка в селе Памятка	f	small
119762	82624	400	Саратовская область, Аркадакский район, село Ольшанка, Молодежная, 1, МОУ-СОШ	f	medium
119779	82641	417	Саратовская область, Аркадакский район, село Октябрьский, Садовая, 19, библиотека	f	small
119766	82628	404	Саратовская область, Аркадакский район, село Новосельское, Мира, 20, сельский Дом культуры	f	medium
119775	82637	413	Саратовская область, Аркадакский район, село Мещеряковка, Новая, 30, филиал МОУ-СОШ город Аркадак	f	small
119761	82623	399	Саратовская область, Аркадакский район, село Малиновка, Крупской, 15, сельский Дом культуры	f	medium
119770	82632	408	Саратовская область, Аркадакский район, село Львовка, Школьная, 10, центр досуга	f	small
119757	82618	395	Саратовская область, Аркадакский район, село Летяжевский, Кумысная, 6, административное здание	t	small
119771	82633	409	Саратовская область, Аркадакский район, село Крутец, Радищева, 10, медпункт	t	small
119756	82617	394	Саратовская область, Аркадакский район, село Красный Полуостров, Прихоперская, 3, сельский Дом культуры	t	small
119772	82634	410	Саратовская область, Аркадакский район, село Красное Знамя, Ленина, 21-Б, сельский Дом культуры	f	medium
119774	82636	412	Саратовская область, Аркадакский район, село Кистендей, Советская, 20, административное здание	f	medium
119769	82631	407	Саратовская область, Аркадакский район, село Ивановка, Инициативная, 1-А, сельский Дом культуры	f	small
134462	94360	402	Саратовская область, Аркадакский район, село Грачевка, Школьная, 8, сельский Дом культуры	f	small
119777	82639	415	Саратовская область, Аркадакский район, село Большая Журавка, Советская, 33, МОУ-СОШ	f	small
119773	82635	411	Саратовская область, Аркадакский район, село Беловка, Первомайская, 1-А, сельский Дом культуры	t	small
119776	82638	414	Саратовская область, Аркадакский район, село Баклуши, Кооперативная, 16, МОУ-СОШ	f	small
72228	82615	392	Саратовская область, Аркадакский район, Аркадак, территория элеватора, д.10, административное здание ООО Прихоперский элеватор	f	large
72226	82613	390	Саратовская область, Аркадакский район, Аркадак, Ленина, 117, МОУ-СОШ № 3	f	large
72225	82612	389	Саратовская область, Аркадакский район, Аркадак, Ленина, 92, кинотеатр Космос	f	large
119755	82611	388	Саратовская область, Аркадакский район, Аркадак, Ленина, 47, Дом творчества юных	f	medium
72229	82616	393	Саратовская область, Аркадакский район, Аркадак, Л.Толстого, 35, МОУ-СОШ № 1	f	large
70719	79830	143	Самарская область, Чапаевск, Котовского, 10	f	large
72224	82610	387	Саратовская область, Аркадакский район, Аркадак, Калинина, 6, школа искусств	f	large
72227	82614	391	Саратовская область, Аркадакский район, Аркадак, Заводская, 2, клуб Надежда	f	large
119768	82630	406	Саратовская область, Аркадакский район, село Алексеевка, Алексеевская, 105, сельский Дом культуры	f	medium
119754	82608	385	Саратовская область, Александрово-Гайский район, село Сысоев, Алгайская, 7, сельский клуб	t	small
119747	82601	378	Саратовская область, Александрово-Гайский район, село Приузенский, Первомайская, 6, сельский дом культуры	f	medium
119742	82596	373	Саратовская область, Александрово-Гайский район, Новостепной, Центральная, 4, сельский клуб	f	small
119750	82604	381	Саратовская область, Александрово-Гайский район, село Новоалександровка, Прудовая, 12 а, сельская средняя школа	f	medium
119746	82600	377	Саратовская область, Александрово-Гайский район, село Монахов, Школьная, 5, начальная школа	t	small
119741	82595	372	Саратовская область, Александрово-Гайский район, село Луков Кордон, Школьная, 2, средняя школа с. Луков Кордон	f	medium
119744	82598	375	Саратовская область, Александрово-Гайский район, село Канавка, Коммунарная, 3, сельский дом культуры	f	small
119740	82594	371	Саратовская область, Александрово-Гайский район, село Камышки, Новостройка, 23, социальный центр	f	medium
119753	82607	384	Саратовская область, Александрово-Гайский район, село Ветелки, Полевая, 2 а, сельский клуб	f	small
119739	82593	370	Саратовская область, Александрово-Гайский район, Васильки, Новая, 2, интернат при средней школе №2	f	small
119752	82606	383	Саратовская область, Александрово-Гайский район, село Варфоломеевка, Пионерская, 1 а, сельская средняя школа	f	small
119751	82605	382	Саратовская область, Александрово-Гайский район, село Байгужа, Лиманная, 17а, сельский клуб	f	small
119745	82588	376	Саратовская область, Александрово-Гайский район, село Бабошкин, Центральная, 3, сельский клуб	f	small
119749	82603	380	Саратовская область, Александрово-Гайский район, село Ахматов, Комсомольская, 13, сельский клуб	f	small
119734	82586	364	Саратовская область, Александрово-Гайский район, поселок Александров Гай, площадь 35-летия победы, 1, Районный дом культуры	f	medium
119732	82584	362	Саратовская область, Александрово-Гайский район, поселок Александров Гай, площадь 35-летия Победы, 1, Центр детского творчества	f	medium
119737	82590	367	Саратовская область, Александрово-Гайский район, поселок Александров Гай, Советская, 16, средняя школа №1	f	medium
119738	82592	369	Саратовская область, Александрово-Гайский район, поселок Александров Гай, Привокзальная, 4, сельский клуб	f	medium
72222	82591	368	Саратовская область, Александрово-Гайский район, поселок Александров Гай, Почтовая,, 69, средняя школа №2	f	large
119733	82585	363	Саратовская область, Александрово-Гайский район, поселок Александров Гай, Красного бойца, 67, средняя школа №3	f	medium
119736	82589	366	Саратовская область, Александрово-Гайский район, поселок Александров Гай, Коммунистическая, 19 , Дом кино Маяк	f	medium
119735	82587	365	Саратовская область, Александрово-Гайский район, поселок Александров Гай, Коммунистическая, 82, Музей краеведения	f	medium
119748	82602	379	Саратовская область, Александрово-Гайский, село Передовой, Пограничная, 25, сельский клуб	f	small
71832	83714	1524	Саратовская область, Саратовский райо, поселок городского типа Соколовый, МОУ СОШ	f	large
71803	83513	1328	Саратовская область, Пугачевский , Пугачев, Вокзальная, Дом культуры, Дом культуры	f	large
117210	95094	977	Самарская область, село Ширяево, Рабочая, 15, СДК Родник	f	small
70704	79808	122	Самарская область, Чапаевск, Ярославская, 7а	f	large
70701	79808	119	Самарская область, Чапаевск, Ярославская, 7а	f	large
70713	79824	137	Самарская область, Чапаевск, Чкалова, 1	f	large
70705	79811	123	Самарская область, Чапаевск, Херсонская, 17	f	large
116910	79819	132	Самарская область, Чапаевск, Силикатная, 8	f	medium
70717	79828	141	Самарская область, Чапаевск, Сергея Лазо, 34А	f	large
70718	79829	142	Самарская область, Чапаевск, Радищева, 28	f	large
116911	79821	134	Самарская область, Чапаевск, Озерная, 5	f	medium
70707	79813	125	Самарская область, Чапаевск, Мирная, 38	f	large
70702	79809	120	Самарская область, Чапаевск, Макаренко, 16	f	large
70708	79809	127	Самарская область, Чапаевск, Макаренко, 16	f	large
71417	80934	1482	Самарская область, Тольятти, бульвар Королева, 3	f	large
71415	80934	1480	Самарская область, Тольятти, бульвар Королева, 3	f	large
71414	80934	1479	Самарская область, Тольятти, бульвар Королева, 3	f	large
71413	80932	1478	Самарская область, Тольятти, бульвар Королева, 12	f	large
71411	80932	1476	Самарская область, Тольятти, бульвар Королева, 12	f	large
71416	80932	1481	Самарская область, Тольятти, бульвар Королева, 12	f	large
71424	80948	1511	Самарская область, Тольятти, бульвар Будённого, 9	f	large
71423	80948	1510	Самарская область, Тольятти, бульвар Будённого, 9	f	large
71422	80948	1509	Самарская область, Тольятти, бульвар Будённого, 9	f	large
71421	80947	1508	Самарская область, Тольятти, бульвар Будённого, 1	f	large
71420	80947	1507	Самарская область, Тольятти, бульвар Будённого, 1	f	large
71419	80946	1506	Самарская область, Тольятти, бульвар Будённого, 12	f	large
71418	80946	1505	Самарская область, Тольятти, бульвар Будённого, 12	f	large
71672	80946	1504	Самарская область, Тольятти, бульвар Будённого, 12	f	large
71426	80949	1513	Самарская область, Тольятти, Юбилейная, 81	f	large
71427	80949	1514	Самарская область, Тольятти, Юбилейная, 81	f	large
71425	80949	1512	Самарская область, Тольятти, Юбилейная, 81	f	large
71558	81002	1636	Самарская область, Тольятти, Энергетиков, 17	f	large
71559	81002	1637	Самарская область, Тольятти, Энергетиков, 17	f	large
70643	79751	51	республика Башкортостан, Уфа, Школьный переулок, 5	f	large
70642	79750	50	республика Башкортостан, Уфа, Школьный переулок, 5	f	large
71097	80376	832	Самарская область, Тольятти, Чкалова, 90	f	large
70657	79759	65	Московская область, Электросталь, улица Чернышевского, 24	f	large
71537	80988	1615	Самарская область, Тольятти, Чайкиной, 57	f	large
71536	80988	1614	Самарская область, Тольятти, Чайкиной, 57	f	large
71535	80988	1613	Самарская область, Тольятти, Чайкиной, 57	f	large
71512	80972	1574	Самарская область, Тольятти, Цветной, 13	f	large
71514	80972	1576	Самарская область, Тольятти, Цветной, 13	f	large
71513	80972	1575	Самарская область, Тольятти, Цветной, 13	f	large
71511	80972	1573	Самарская область, Тольятти, Цветной, 13	f	large
71510	80971	1572	Самарская область, Тольятти, Цветной, 18	f	large
71508	80971	1570	Самарская область, Тольятти, Цветной, 18	f	large
71507	80971	1569	Самарская область, Тольятти, Цветной, 18	f	large
71515	80971	1577	Самарская область, Тольятти, Цветной, 18	f	large
71509	80971	1571	Самарская область, Тольятти, Цветной, 18	f	large
71475	80958	1535	Самарская область, Тольятти, Фрунзе, 2	f	large
71474	80958	1534	Самарская область, Тольятти, Фрунзе, 2	f	large
71431	80957	1533	Самарская область, Тольятти, Фрунзе, 12	f	large
71430	80957	1532	Самарская область, Тольятти, Фрунзе, 12	f	large
70962	80249	646	Самарская область, Тольятти, Фадеева, 61	f	large
70961	80249	645	Самарская область, Тольятти, Фадеева, 61	f	large
70960	80249	644	Самарская область, Тольятти, Фадеева, 61	f	large
70959	80249	643	Самарская область, Тольятти, Фадеева, 61	f	large
71542	80991	1620	Самарская область, Тольятти, Ульяны Громовой, 42а	f	large
71541	80991	1619	Самарская область, Тольятти, Ульяны Громовой, 42а	f	large
71540	80990	1618	Самарская область, Тольятти, Ульяны Громовой, 38	f	large
71539	80990	1617	Самарская область, Тольятти, Ульяны Громовой, 38	f	large
71469	80954	1527	Самарская область, Тольятти, Туполева, 12	f	large
71468	80954	1526	Самарская область, Тольятти, Туполева, 12	f	large
71467	80954	1525	Самарская область, Тольятти, Туполева, 12	f	large
71394	80979	1598	Самарская область, Тольятти, Тополиная, 5	f	large
71393	80979	1597	Самарская область, Тольятти, Тополиная, 5	f	large
71392	80979	1596	Самарская область, Тольятти, Тополиная, 5	f	large
71391	80979	1595	Самарская область, Тольятти, Тополиная, 5	f	large
71390	80979	1594	Самарская область, Тольятти, Тополиная, 5	f	large
71389	80979	1593	Самарская область, Тольятти, Тополиная, 5	f	large
71388	80979	1592	Самарская область, Тольятти, Тополиная, 5	f	large
71524	80978	1590	Самарская область, Тольятти, Тополиная, 18	f	large
71523	80978	1589	Самарская область, Тольятти, Тополиная, 18	f	large
71525	80978	1591	Самарская область, Тольятти, Тополиная, 18	f	large
71553	80998	1631	Самарская область, Тольятти, Телеграфная, 4	f	large
71522	80977	1588	Самарская область, Тольятти, Татищева, 19	f	large
71436	80960	1540	Самарская область, Тольятти, Степана Разина, 73	f	large
71435	80960	1539	Самарская область, Тольятти, Степана Разина, 73	f	large
71437	80960	1541	Самарская область, Тольятти, Степана Разина, 73	f	large
71434	80959	1538	Самарская область, Тольятти, Степана Разина, 65	f	large
71433	80959	1537	Самарская область, Тольятти, Степана Разина, 65	f	large
71432	80959	1536	Самарская область, Тольятти, Степана Разина, 65	f	large
71429	80950	1516	Самарская область, Тольятти, Степана Разина, 78	f	large
71428	80950	1515	Самарская область, Тольятти, Степана Разина, 78	f	large
71593	81028	1673	Самарская область, Тольятти, Ставропольская, 19	f	large
71591	81028	1671	Самарская область, Тольятти, Ставропольская, 19	f	large
71592	81028	1672	Самарская область, Тольятти, Ставропольская, 19	f	large
70728	79835	153	Хабаровский край, Хабаровск, улица Специалистов, 4	f	large
117236	80561	1086	Оренбургская область, Оренбург, улица Советская, 23	f	medium
70712	79822	135	Самарская область, Тольятти, Советская, 56	f	large
71572	81013	1651	Самарская область, Тольятти, Сиреневая, 24	f	large
71566	81005	1644	Самарская область, Тольятти, Севастопольская, 1	f	large
71565	81005	1643	Самарская область, Тольятти, Севастопольская, 1	f	large
71453	80942	1498	Самарская область, Тольятти, Свердлова, 23	f	large
71452	80942	1497	Самарская область, Тольятти, Свердлова, 23	f	large
71451	80942	1496	Самарская область, Тольятти, Свердлова, 23	f	large
70646	79744	54	Костромская область, Кострома, улица Свердлова, 12	f	large
70645	79744	53	Костромская область, Кострома, улица Свердлова, 12	f	large
70639	79744	44	Костромская область, Кострома, улица Свердлова, 12	f	large
70630	79736	35	Костромская область, Кострома, улица Свердлова, 23	f	large
70627	79736	32	Костромская область, Кострома, улица Свердлова, 23	f	large
71225	95088	970	Самарская область, Тольятти, Репина, 39	f	large
71442	80937	1487	Самарская область, Тольятти, Революционная, 11/33	f	large
71441	80936	1486	Самарская область, Тольятти, Революционная, 7	f	large
71440	80936	1485	Самарская область, Тольятти, Революционная, 7	f	large
71439	80935	1484	Самарская область, Тольятти, Революционная, 3/56	f	large
71438	80935	1483	Самарская область, Тольятти, Революционная, 3/56	f	large
117523	80983	1606	Самарская область, Тольятти, Полякова, 26	f	medium
71610	81039	1691	Самарская область, Тольятти, Победы, 36/80	f	large
71602	81035	1683	Самарская область, Тольятти, Победы, 42	f	large
71217	95018	962	Самарская область, Тольятти, Первомайская, 21, 3	f	large
117064	79946	364	Томская область, Бакчарский район, село Первомайск (Воробьёвка)	f	medium
134676	95001	1583	Самарская область, Тольятти, Офицерская, 4, офисное помещение	f	\N
71485	80976	1585	Самарская область, Тольятти, Офицерская, 2А	f	large
71484	80976	1584	Самарская область, Тольятти, Офицерская, 2А	f	large
71627	79762	68	Самарская область, Тольятти, Островского, 12	f	large
71456	80944	1501	Самарская область, Тольятти, Орджоникидзе, 3	f	large
71455	80944	1500	Самарская область, Тольятти, Орджоникидзе, 3	f	large
71454	80943	1499	Самарская область, Тольятти, Орджоникидзе, 14	f	large
70715	79826	139	Самарская область, Чапаевск городской округ	f	large
70714	79825	138	Самарская область, Чапаевск городской округ	f	large
71567	81007	1646	Самарская область, Тольятти, Носова, 21	f	large
71673	81006	1645	Самарская область, Тольятти, Носова, 17	f	large
71552	80997	1630	Самарская область, Тольятти, Мурысева, 61	f	large
71551	80997	1629	Самарская область, Тольятти, Мурысева, 61	f	large
71550	80997	1628	Самарская область, Тольятти, Мурысева, 61	f	large
71548	80995	1626	Самарская область, Тольятти, Мурысева, 84	f	large
71547	80995	1625	Самарская область, Тольятти, Мурысева, 84	f	large
71546	80994	1624	Самарская область, Тольятти, Мурысева, 89а	f	large
71545	80994	1623	Самарская область, Тольятти, Мурысева, 89а	f	large
71544	80994	1622	Самарская область, Тольятти, Мурысева, 89а	f	large
71532	80985	1610	Самарская область, Тольятти, Мурысева, 49	f	large
71531	80985	1609	Самарская область, Тольятти, Мурысева, 49	f	large
71530	80985	1608	Самарская область, Тольятти, Мурысева, 49	f	large
71410	80931	1475	Самарская область, Тольятти, Московский, 37	f	large
71409	80931	1474	Самарская область, Тольятти, Московский, 37	f	large
71609	81034	1690	Самарская область, Тольятти, Молодежный, 28	f	large
71589	81027	1669	Самарская область, Тольятти, Мира, 121	f	large
71588	81027	1668	Самарская область, Тольятти, Мира, 121	f	large
70711	79820	133	Самарская область, Тольятти, Мира, 7	f	large
71549	80996	1627	Самарская область, Тольятти, Матросова, 5	f	large
71538	80989	1616	Самарская область, Тольятти, Матросова, 37	f	large
71613	81041	1694	Самарская область, Тольятти, Максима Горького, 47	f	large
71612	81040	1693	Самарская область, Тольятти, Максима Горького, 88	f	large
71611	81040	1692	Самарская область, Тольятти, Максима Горького, 88	f	large
71606	81030	1687	Самарская область, Тольятти, Максима Горького, 39	f	large
71598	81030	1678	Самарская область, Тольятти, Максима Горького, 39	f	large
71595	81030	1675	Самарская область, Тольятти, Максима Горького, 39	f	large
71594	81029	1674	Самарская область, Тольятти, Максима Горького, 34	f	large
71377	80866	1398	Самарская область, Тольятти, Максима Горького, 7	f	large
71375	80856	1387	Самарская область, Тольятти, Максима Горького, 10	f	large
71555	80999	1633	Самарская область, Тольятти, Майский проезд, 14	f	large
71554	80999	1632	Самарская область, Тольятти, Майский проезд, 14	f	large
71624	81047	1705	Самарская область, Тольятти, Льва Толстого, 26	f	large
71623	81047	1704	Самарская область, Тольятти, Льва Толстого, 26	f	large
71622	81047	1703	Самарская область, Тольятти, Льва Толстого, 26	f	large
71621	81047	1702	Самарская область, Тольятти, Льва Толстого, 26	f	large
71464	80952	1522	Самарская область, Тольятти, Луначарского, 11	f	large
71463	80952	1521	Самарская область, Тольятти, Луначарского, 11	f	large
71462	80952	1520	Самарская область, Тольятти, Луначарского, 11	f	large
71543	80992	1621	Самарская область, Тольятти, Лизы Чайкиной, 69а	f	large
117526	81049	1707	Самарская область, Тольятти, Лесопарковое шоссе, 2	f	small
116902	79768	77	Московская область, Ногинский район, деревня Пешково, Лесная улица, 15	f	medium
71458	80945	1503	Самарская область, Тольятти, Ленинский, 20	f	large
71457	80945	1502	Самарская область, Тольятти, Ленинский, 20	f	large
71404	80928	1469	Самарская область, Тольятти, Ленинский, 42	f	large
71403	80928	1468	Самарская область, Тольятти, Ленинский, 42	f	large
71402	80928	1467	Самарская область, Тольятти, Ленинский, 42	f	large
71577	81019	1657	Самарская область, Тольятти, Ленинградская, 28	f	large
71576	81018	1656	Самарская область, Тольятти, Ленинградская, 33А	f	large
71241	80484	996	Самарская область, Тольятти, Ленинградская, 10	f	large
71229	80465	978	Самарская область, Тольятти, Ленинградская, 48	f	large
70628	79737	33	Самарская область, Тольятти, Ленинградская, 5	f	large
71214	95015	959	Самарская область, Тольятти, Ленина, 3	f	large
71620	81045	1701	Самарская область, Тольятти, Ленина, 58/63	f	large
71619	81045	1700	Самарская область, Тольятти, Ленина, 58/63	f	large
71616	81043	1698	Самарская область, Тольятти, Ленина, 59	f	large
71601	81032	1682	Самарская область, Тольятти, Ленина, 108	f	large
71597	81032	1677	Самарская область, Тольятти, Ленина, 108	f	large
71233	80471	984	Самарская область, Тольятти, Ленина, 57/20	f	large
70700	79807	118	Самарская область, Тольятти, Ленина, 70	f	large
70699	79807	117	Самарская область, Тольятти, Ленина, 70	f	large
70698	79806	116	Самарская область, Тольятти, Ленина, 66/22	f	large
71617	81044	1699	Самарская область, Тольятти, Ларина, 66	f	large
71450	80941	1495	Самарская область, Тольятти, Курчатова, 15	f	large
71447	80939	1492	Самарская область, Тольятти, Курчатова, 16	f	large
71446	80939	1491	Самарская область, Тольятти, Курчатова, 16	f	large
71445	80939	1490	Самарская область, Тольятти, Курчатова, 16	f	large
71444	80938	1489	Самарская область, Тольятти, Курчатова, 2	f	large
71443	80938	1488	Самарская область, Тольятти, Курчатова, 2	f	large
71401	80927	1466	Самарская область, Тольятти, Кулибина, 17	f	large
71400	80927	1465	Самарская область, Тольятти, Кулибина, 17	f	large
71399	80926	1464	Самарская область, Тольятти, Кулибина, 13	f	large
71398	80926	1463	Самарская область, Тольятти, Кулибина, 13	f	large
71397	80925	1462	Самарская область, Тольятти, Кулибина, 8	f	large
71396	80924	1461	Самарская область, Тольятти, Кулибина, 4	f	large
71395	80924	1460	Самарская область, Тольятти, Кулибина, 4	f	large
71557	81000	1635	Самарская область, Тольятти, Куйбышева, 24	f	large
71556	81000	1634	Самарская область, Тольятти, Куйбышева, 24	f	large
71506	80970	1568	Самарская область, Тольятти, Космонавтов, 17	f	large
71505	80970	1567	Самарская область, Тольятти, Космонавтов, 17	f	large
71504	80970	1566	Самарская область, Тольятти, Космонавтов, 17	f	large
71503	80970	1565	Самарская область, Тольятти, Космонавтов, 17	f	large
71412	80933	1477	Самарская область, Тольятти, Королева, 6	f	large
71618	81048	1706	Самарская область, Тольятти, Комсомольское, 5	f	large
117220	80519	1037	Самарская область, Сызранский район, Комсомольская, 4	f	medium
71244	80488	1001	Самарская область, Тольятти, Коммунистическая, 21	f	large
71104	80380	839	Самарская область, Тольятти, Коммунистическая, 21	f	large
71103	80380	837	Самарская область, Тольятти, Коммунистическая, 21	f	large
71102	80379	838	Самарская область, Тольятти, Коммунистическая, 18	f	large
71101	80379	836	Самарская область, Тольятти, Коммунистическая, 18	f	large
70656	79758	64	Краснодарский край, поселок Мефодиевка, улица Кирова, 19	f	large
70655	79758	63	Краснодарский край, поселок Мефодиевка, улица Кирова, 19	f	large
70654	79757	62	Краснодарский край, поселок Мефодиевка, улица Кирова, 6	f	large
71596	81031	1676	Самарская область, Тольятти, Карла Маркса, 59	f	large
71569	81010	1648	Самарская область, Тольятти, Ингельберга, 52	f	large
71568	81008	1647	Самарская область, Тольятти, Ингельберга, 1в	f	large
71581	81020	1661	Самарская область, Тольятти, Жилина, 30	f	large
71578	81020	1658	Самарская область, Тольятти, Жилина, 30	f	large
71534	80987	1612	Самарская область, Тольятти, Есенина, 16	f	large
71533	80987	1611	Самарская область, Тольятти, Есенина, 16	f	large
71461	80951	1519	Самарская область, Тольятти, Дзержинского, 39	f	large
71460	80951	1518	Самарская область, Тольятти, Дзержинского, 39	f	large
71459	80951	1517	Самарская область, Тольятти, Дзержинского, 39	f	large
71449	80940	1494	Самарская область, Тольятти, Дзержинского, 51	f	large
71448	80940	1493	Самарская область, Тольятти, Дзержинского, 51	f	large
71032	80333	775	Самарская область, Тольятти, Дзержинского, 32	f	large
71031	80333	774	Самарская область, Тольятти, Дзержинского, 32	f	large
70651	79755	59	Ставропольский край, Ставрополь, улица Дзержинского, 2а	f	large
70648	79753	56	Ставропольский край, Ставрополь, улица Дзержинского, 41	f	large
70647	79753	55	Ставропольский край, Ставрополь, улица Дзержинского, 41	f	large
71600	81033	1680	Самарская область, Тольятти, Голосова, 83	f	large
71599	81033	1679	Самарская область, Тольятти, Голосова, 83	f	large
71586	81025	1666	Самарская область, Тольятти, Голосова, 34	f	large
71585	81025	1665	Самарская область, Тольятти, Голосова, 34	f	large
71564	81004	1642	Самарская область, Тольятти, Гидротехническая, 37	f	large
71563	81004	1641	Самарская область, Тольятти, Гидротехническая, 37	f	large
71562	81003	1640	Самарская область, Тольятти, Гидротехническая, 29	f	large
71561	81003	1639	Самарская область, Тольятти, Гидротехническая, 29	f	large
71560	81003	1638	Самарская область, Тольятти, Гидротехническая, 29	f	large
134675	95000	1582	Самарская область, Тольятти, Ворошилова, 3	f	\N
71502	80969	1564	Самарская область, Тольятти, Ворошилова, 3	f	large
71501	80969	1563	Самарская область, Тольятти, Ворошилова, 3	f	large
71500	80969	1562	Самарская область, Тольятти, Ворошилова, 3	f	large
71499	80968	1561	Самарская область, Тольятти, Ворошилова, 21	f	large
71498	80968	1560	Самарская область, Тольятти, Ворошилова, 21	f	large
71497	80968	1559	Самарская область, Тольятти, Ворошилова, 21	f	large
71488	80961	1544	Самарская область, Тольятти, Ворошилова, 37	f	large
71487	80961	1543	Самарская область, Тольятти, Ворошилова, 37	f	large
71486	80961	1542	Самарская область, Тольятти, Ворошилова, 37	f	large
71473	80956	1531	Самарская область, Тольятти, Ворошилова, 32	f	large
71472	80956	1530	Самарская область, Тольятти, Ворошилова, 32	f	large
71471	80955	1529	Самарская область, Тольятти, Ворошилова, 28	f	large
71470	80955	1528	Самарская область, Тольятти, Ворошилова, 28	f	large
70767	79974	293	Иркутская область, Ангарск, улица Ворошилова, 25	f	large
70638	79743	43	Иркутская область, Ангарск, улица Ворошилова, 6	f	large
70637	79742	42	Иркутская область, Ангарск, улица Ворошилова, 12	f	large
70636	79742	41	Иркутская область, Ангарск, улица Ворошилова, 12	f	large
71216	95017	961	Самарская область, Тольятти, Вокзальная, 21	f	large
117524	80984	1607	Самарская область, Тольятти, Вокзальная, 21	f	medium
71574	81016	1654	Самарская область, Тольятти, Белорусская, 14	f	large
71573	81015	1653	Самарская область, Тольятти, Белорусская, 33	f	large
71407	80930	1472	Самарская область, Тольятти, Баумана, 3	f	large
71406	80930	1471	Самарская область, Тольятти, Баумана, 3	f	large
71408	80929	1473	Самарская область, Тольятти, Баумана, 3	f	large
71405	80929	1470	Самарская область, Тольятти, Баумана, 3	f	large
71587	81026	1667	Самарская область, Тольятти, Баныкина, 44	f	large
71583	81023	1663	Самарская область, Тольятти, Баныкина, 22	f	large
71582	81023	1662	Самарская область, Тольятти, Баныкина, 22	f	large
71580	81021	1660	Самарская область, Тольятти, Баныкина, 12	f	large
71579	81021	1659	Самарская область, Тольятти, Баныкина, 12	f	large
71575	81017	1655	Самарская область, Тольятти, Баныкина, 4	f	large
71493	80963	1549	Самарская область, Тольятти, Автостроителей, 92	f	large
71492	80963	1548	Самарская область, Тольятти, Автостроителей, 92	f	large
71491	80962	1547	Самарская область, Тольятти, Автостроителей, 84	f	large
71490	80962	1546	Самарская область, Тольятти, Автостроителей, 84	f	large
71489	80962	1545	Самарская область, Тольятти, Автостроителей, 84	f	large
70770	79977	296	Самарская область, Тольятти, 70 Лет Октября, 37	f	large
71571	81012	1650	Самарская область, Тольятти, 60 лет СССР, 17	f	large
71570	81011	1649	Самарская область, Тольятти, 60 лет СССР, 19	f	large
71615	81042	1696	Самарская область, Тольятти, 50 Лет Октября, 61	f	large
71614	81042	1695	Самарская область, Тольятти, 50 Лет Октября, 61	f	large
71675	81038	1697	Самарская область, Тольятти, 50 Лет Октября, 23	f	large
71608	81038	1689	Самарская область, Тольятти, 50 Лет Октября, 23	f	large
71607	81038	1688	Самарская область, Тольятти, 50 Лет Октября, 23	f	large
71529	80982	1605	Самарская область, Тольятти, 40 Лет Победы, 13	f	large
71528	80980	1601	Самарская область, Тольятти, 40 Лет Победы, 6	f	large
71527	80980	1600	Самарская область, Тольятти, 40 Лет Победы, 6	f	large
71526	80980	1599	Самарская область, Тольятти, 40 Лет Победы, 6	f	large
71519	80974	1581	Самарская область, Тольятти, 40 Лет Победы, 40	f	large
71518	80974	1580	Самарская область, Тольятти, 40 Лет Победы, 40	f	large
71517	80973	1579	Самарская область, Тольятти, 40 Лет Победы, 44	f	large
71516	80973	1578	Самарская область, Тольятти, 40 Лет Победы, 44	f	large
71496	80967	1558	Самарская область, Тольятти, 40 Лет Победы, 74	f	large
71495	80967	1557	Самарская область, Тольятти, 40 Лет Победы, 74	f	large
71494	80967	1556	Самарская область, Тольятти, 40 Лет Победы, 74	f	large
71481	80966	1555	Самарская область, Тольятти, 40 Лет Победы, 86	f	large
71480	80966	1554	Самарская область, Тольятти, 40 Лет Победы, 86	f	large
71479	80965	1553	Самарская область, Тольятти, 40 Лет Победы, 120	f	large
71478	80965	1552	Самарская область, Тольятти, 40 Лет Победы, 120	f	large
71476	80964	1550	Самарская область, Тольятти, 40 Лет Победы, 106	f	large
71477	80964	1551	Самарская область, Тольятти, 40 Лет Победы, 106	f	large
71669	80844	1374	Самарская область, село Тимофеевка, Школьная, 61а	f	large
71262	80504	1020	Самарская область, Сызрань, проспект 50 лет октября, 42А	f	large
71264	80505	1022	Самарская область, Сызрань, пр.Гагарина, 75	f	large
71263	80505	1021	Самарская область, Сызрань, пр.Гагарина, 75	f	large
71261	80503	1019	Самарская область, Сызрань, пр.50 лет Октября, 42А	f	large
71260	80502	1018	Самарская область, Сызрань, пр.50 лет Октября, 20	f	large
71259	80502	1017	Самарская область, Сызрань, пр.50 лет Октября, 20	f	large
71258	80501	1016	Самарская область, Сызрань, пр.50 лет Октября, 1	f	large
71257	80500	1015	Самарская область, Сызрань, пр.50 лет Октября, 14	f	large
71256	80499	1014	Самарская область, Сызрань, пр. Гагарина, 13	f	large
71255	80499	1013	Самарская область, Сызрань, пр. Гагарина, 13	f	large
71290	80529	1050	Самарская область, Сызрань, переулок Молодогвардейский, 24	f	large
117216	80486	999	Самарская область, Сызрань, пер. Кемеровский, 1	f	small
117215	80486	998	Самарская область, Сызрань, пер. Кемеровский, 1	f	medium
71245	80489	1002	Самарская область, Сызрань, Щусева, 7	f	large
117221	80522	1042	Самарская область, Сызрань, Школьная, 7	f	medium
71281	80521	1040	Самарская область, Сызрань, Челюскинцев, 25	f	large
71280	80521	1039	Самарская область, Сызрань, Челюскинцев, 25	f	large
71248	80492	1005	Самарская область, Сызрань, Циолковского, 3	f	large
117219	80514	1031	Самарская область, Сызрань, Фрунзе, 19	f	medium
71282	80518	1041	Самарская область, Сызрань, Ульяновская, 145	f	large
71278	80518	1036	Самарская область, Сызрань, Ульяновская, 145	f	large
71274	80517	1035	Самарская область, Сызрань, Степана Разина, 24	f	large
71273	80516	1034	Самарская область, Сызрань, Степана Разина, 1	f	large
117228	80548	1071	Самарская область, Сызрань, Советская, 81	f	medium
71275	80544	1067	Самарская область, Сызрань, Советская, 70	f	large
71279	80520	1038	Самарская область, Сызрань, Победы, 68	f	large
117217	80497	1011	Самарская область, Сызрань, Парижской Коммуны, 65	f	medium
71268	80510	1027	Самарская область, Сызрань, Образцовская, 27	f	large
71303	80547	1073	Самарская область, Сызрань, Новостроящаяся, 10	f	large
71302	80547	1072	Самарская область, Сызрань, Новостроящаяся, 10	f	large
71301	80547	1070	Самарская область, Сызрань, Новостроящаяся, 10	f	large
117222	80532	1053	Самарская область, Сызрань, Новосибирская, 39	f	small
71305	80550	1075	Самарская область, Сызрань, Новомайская, 2А	f	large
71298	80540	1062	Самарская область, Сызрань городской округ, Нефтебазная, 11	f	large
71300	80543	1066	Самарская область, Сызрань, Маршала Жукова, ВУНЦ ВВС ВВА	f	large
71299	80543	1065	Самарская область, Сызрань, Маршала Жукова, ВУНЦ ВВС ВВА	f	large
71304	80549	1074	Самарская область, Сызрань, Людиновская, 23	f	large
117218	80511	1028	Самарская область, Сызрань, Ленина, 20	f	medium
71291	80530	1051	Самарская область, Сызрань, Краснознаменная, 23	f	large
71243	80487	1000	Самарская область, Сызрань, Красина, 3	f	large
71242	80485	997	Самарская область, Сызрань, Кемеровский переулок, 1	f	large
71277	80546	1069	Самарская область, Сызрань, Карла Маркса, 104	f	large
71289	80528	1049	Самарская область, Сызрань, Карбышева, 4	f	large
71287	80526	1047	Самарская область, Сызрань, Интернациональная, 178	f	large
71270	80513	1030	Самарская область, Сызрань, Интернациональная, 143	f	large
71272	80513	1033	Самарская область, Сызрань, Интернациональная, 143	f	large
71267	80509	1026	Самарская область, Сызрань, Звездная, 8	f	large
71266	80508	1025	Самарская область, Сызрань, Звездная, 48	f	large
71265	80508	1024	Самарская область, Сызрань, Звездная, 48	f	large
71660	80506	1023	Самарская область, Сызрань, Звездная, 8	f	large
71294	80534	1056	Самарская область, Сызрань, Заборовская, 20	f	large
71293	80534	1055	Самарская область, Сызрань, Заборовская, 20	f	large
117227	80542	1064	Самарская область, Сызрань, Ерамасова, в/ч, 13826	f	small
71297	80539	1061	Самарская область, Сызрань, Декабристов, 436	f	large
117225	80538	1060	Самарская область, Сызрань, Декабристов, 191	f	medium
71296	80537	1059	Самарская область, Сызрань, Декабристов, 72	f	large
117224	80536	1058	Самарская область, Сызрань, Декабристов, 30	f	medium
71307	80552	1077	Самарская область, Сызрань, Дальневосточная, 38	f	large
71288	80527	1048	Самарская область, Сызрань, Гончарная, 17	f	large
71283	80523	1043	Самарская область, Сызрань, Гоголя, 30	f	large
71286	80525	1046	Самарская область, Сызрань, Гидротурбинная, 5	f	large
71285	80524	1045	Самарская область, Сызрань, Гидротурбинная, 28	f	large
71284	80524	1044	Самарская область, Сызрань, Гидротурбинная, 28	f	large
117226	80541	1063	Самарская область, Сызрань, Бородинский проезд, 1	t	medium
117214	80483	995	Самарская область, Сызрань, Байкальская, 6	f	medium
71253	80496	1010	Самарская область, Сызрань, Астраханская, 31	f	large
71252	80496	1009	Самарская область, Сызрань, Астраханская, 31	f	large
71251	80495	1008	Самарская область, Сызрань, Астраханская, 38	f	large
71250	80494	1007	Самарская область, Сызрань, Астраханская, 2-А	f	large
71246	80490	1003	Самарская область, Сызрань, Астраханская, 12	f	large
71306	80551	1076	Самарская область, Сызрань, 2-я Железнодорожная, 26	f	large
117150	80187	545	Самарская область, Студеный овраг, третья линия, 34А	f	small
117158	80225	587	Самарская область, Самара	f	small
70837	80147	471	Самарская область, Самара, Аэропорт Смышляевка, нежилое здание литера А4	f	large
70641	79747	47	Ленинградская область, Лужский район, Луга, улица Гагарина, 4	f	large
71109	80384	844	Самарская область, Самара, улица Циолковского, 1	f	large
71085	80365	820	Самарская область, Самара, Куйбышевский район, улица Центральная, 11а	f	large
70915	80231	599	Самарская область, Самара, улица Физкультурная, 104	f	large
70914	80231	598	Самарская область, Самара, улица Физкультурная, 104	f	large
71269	80512	1029	Самарская область, Сызранский район, Урицкого, 2	f	large
70913	80230	597	Самарская область, Самара, улица Теннисная, 25в	f	large
70927	80238	611	Самарская область, Самара городской округ	f	large
70926	80238	610	Самарская область, Самара городской округ	f	large
71174	80431	901	Самарская область, Самара, улица Советской Армии, 161а	f	large
71135	80409	873	Самарская область, Самара, улица Советской Армии, 230	f	large
71212	95014	957	Самарская область, Самара, улица Полевая, 22	f	large
70659	79761	67	Тульская область, Тула, улица Пирогова, 16	f	large
71110	80385	845	Самарская область, Самара, улица Ново-Садовая, 11	f	large
70973	80254	657	Самарская область, Самара, улица Ново-Садовая, 377	f	large
70972	80254	656	Самарская область, Самара, улица Ново-Садовая, 377	f	large
71047	80316	750	Самарская область, Самара, улица Мостовая, 12	f	large
71042	80339	785	Самарская область, Самара, улица Мориса Тореза, 67а	f	large
71145	80417	883	Самарская область, Самара, улица Максима Горького, 65	f	large
71152	80424	890	Самарская область, Самара, улица Льва Толстого, 23	f	large
70844	80152	478	Самарская область, Самара, улица Литвинова, 272	f	large
71087	80367	822	Самарская область, Самара, улица Куйбышева, 151	f	large
70870	80165	507	Самарская область, Самара, проспект Юных Пионеров, 154а	f	large
70869	80165	506	Самарская область, Самара, проспект Юных Пионеров, 154а	f	large
70867	80165	504	Самарская область, Самара, проспект Юных Пионеров, 154а	f	large
70866	80165	503	Самарская область, Самара, проспект Юных Пионеров, 154а	f	large
70851	80159	487	Самарская область, Самара, проспект Металлургов, 52	f	large
70865	80159	502	Самарская область, Самара, проспект Металлургов, 52	f	large
71122	80397	859	Самарская область, Самара, проспект Масленникова, 26	f	large
71121	80396	858	Самарская область, Самара, проспект Масленникова, 22	f	large
71120	80395	857	Самарская область, Самара, проспект Масленникова, 37	f	large
71651	80389	849	Самарская область, Самара, проспект Ленина, 14а	f	large
70951	80246	635	Самарская область, Самара, проспект Кирова, 252	f	large
70949	80246	633	Самарская область, Самара, проспект Кирова, 252	f	large
70948	80246	632	Самарская область, Самара, проспект Кирова, 252	f	large
70950	80246	634	Самарская область, Самара, проспект Кирова, 252	f	large
70905	80227	589	Самарская область, Самара, проспект Кирова, 69	f	large
70810	80173	518	Самарская область, Самара, проспект Кирова, 319	f	large
70809	80173	517	Самарская область, Самара, проспект Кирова, 319	f	large
70808	80171	516	Самарская область, Самара, проспект Кирова, 277	f	large
70805	80171	513	Самарская область, Самара, проспект Кирова, 277	f	large
70824	80170	532	Самарская область, Самара, проспект Кирова, 199	f	large
70803	80170	511	Самарская область, Самара, проспект Кирова, 199	f	large
70802	80170	510	Самарская область, Самара, проспект Кирова, 199	f	large
70871	80168	508	Самарская область, Самара, проспект Кирова, 193	f	large
70868	80166	505	Самарская область, Самара, проспект Кирова, 177	f	large
71139	80412	877	Самарская область, Самара, проспект Карла Маркса, 183А	f	large
71140	80412	878	Самарская область, Самара, проспект Карла Маркса, 183А	f	large
70943	80244	627	Самарская область, Самара, проспект Карла Маркса, 336	f	large
70942	80244	626	Самарская область, Самара, проспект Карла Маркса, 336	f	large
70941	80244	625	Самарская область, Самара, проспект Карла Маркса, 336	f	large
70940	80244	624	Самарская область, Самара, проспект Карла Маркса, 336	f	large
70938	80243	622	Самарская область, Самара, проспект Карла Маркса, 278	f	large
70937	80243	621	Самарская область, Самара, проспект Карла Маркса, 278	f	large
70939	80243	623	Самарская область, Самара, проспект Карла Маркса, 278	f	large
70936	80241	620	Самарская область, Самара, проспект Карла Маркса, 276	f	large
70935	80241	619	Самарская область, Самара, проспект Карла Маркса, 276	f	large
70825	80180	533	Самарская область, Самара, проспект Карла Маркса, 453	f	large
70807	80172	515	Самарская область, Самара, проспект Карла Маркса, 394а	f	large
70806	80172	514	Самарская область, Самара, проспект Карла Маркса, 394а	f	large
117157	80215	575	Самарская область, Самара, поселок Южный, 31	f	medium
70918	80233	602	Самарская область, Самара, переулок Штамповщиков, 5	f	large
71079	80361	814	Самарская область, Самара, переулок Новомолодежный, 19	f	large
71175	80433	903	Самарская область, Самара, переулок Лучистый, 3А	f	large
71059	80345	794	Самарская область, Самара, переулок Долотный, 4	f	large
71058	80345	793	Самарская область, Самара, переулок Долотный, 4	f	large
70877	80200	557	Самарская область, Самара, квартал 4 , 10	f	large
70879	80203	559	Самарская область, Самара, квартал 3 , 46	f	large
70880	80204	560	Самарская область, Самара, квартал 13, 13	f	large
70875	80198	555	Самарская область, Самара, квартал 10, 15	f	large
71039	80337	782	Самарская область, Самара, Юрия Гагарина, 39	f	large
71038	80337	781	Самарская область, Самара, Юрия Гагарина, 39	f	large
71159	80457	941	Самарская область, Самара, Юрия Гагарина, 105а	f	large
71158	80457	940	Самарская область, Самара, Юрия Гагарина, 105а	f	large
71176	80434	904	Самарская область, Самара, Юрия Гагарина, 88А	f	large
71126	80400	863	Самарская область, Самара, Юрия Гагарина, 18	f	large
71125	80400	862	Самарская область, Самара, Юрия Гагарина, 18	f	large
71063	80349	798	Самарская область, Самара, Эльтонская улица, 1	f	large
71207	80461	949	Самарская область, Самара, Экспериментальная, 5	f	large
70703	79810	121	Самарская область, Самара, Щорса, 33	f	large
71106	80381	841	Самарская область, Самара, Чернореченская улица, 67	f	large
71105	80381	840	Самарская область, Самара, Чернореченская улица, 67	f	large
71056	80323	759	Самарская область, Самара, Чернореченская, 21	f	large
71055	80322	758	Самарская область, Самара, Чернореченская, 19	f	large
70833	80184	541	Самарская область, Самара, Черемшанская улица, 244	f	large
70832	80184	540	Самарская область, Самара, Черемшанская улица, 244	f	large
70932	80240	616	Самарская область, Самара, Черемшанская, 2а	f	large
70931	80240	615	Самарская область, Самара, Черемшанская, 2а	f	large
70934	80240	618	Самарская область, Самара, Черемшанская, 2а	f	large
70933	80240	617	Самарская область, Самара, Черемшанская, 2а	f	large
70831	80183	539	Самарская область, Самара, Черемшанская, 222	f	large
70830	80183	538	Самарская область, Самара, Черемшанская, 222	f	large
71147	80419	885	Самарская область, Самара, Чапаевская, 72	f	large
71247	80491	1004	Самарская область, Самара, Циолковского, 7	f	large
117023	79995	314	Самарская область, Самара, Центральная, 39	t	small
71187	80441	915	Самарская область, Самара, ХХII Партсъезда, 31	f	large
71218	95019	963	Самарская область, Самара, Фрунзе, 36, ДК ЛУЧ	f	large
71066	80351	801	Самарская область, Самара, Флотская, 9А	f	large
71192	80445	920	Самарская область, Самара, Физкультурная, 92	f	large
71191	80444	919	Самарская область, Самара, Физкультурная, 82	f	large
70917	80232	601	Самарская область, Самара, Физкультурная, 98б	f	large
70916	80232	600	Самарская область, Самара, Физкультурная, 98б	f	large
70849	80157	485	Самарская область, Самара, Физкультурная, 126	f	large
71077	80360	812	Самарская область, Самара, Фасадная, 2А	f	large
71076	80360	811	Самарская область, Самара, Фасадная, 2А	f	large
71271	80515	1032	Самарская область, Самара, Урицкого, 95	f	large
71054	80321	757	Самарская область, Самара, Урицкого, 3	f	large
71053	80321	756	Самарская область, Самара, Урицкого, 3	f	large
71052	80320	755	Самарская область, Самара, Урицкого, 1	f	large
71051	80320	754	Самарская область, Самара, Урицкого, 1	f	large
71026	80328	769	Самарская область, Самара, Тухачевского, 224	f	large
71025	80328	768	Самарская область, Самара, Тухачевского, 224	f	large
70841	80148	474	Самарская область, Самара, Транзитная, 111	f	large
70838	80148	472	Самарская область, Самара, Транзитная, 111	f	large
70988	80258	672	Самарская область, Самара, Тополей, 10	f	large
70987	80258	671	Самарская область, Самара, Тополей, 10	f	large
70986	80258	670	Самарская область, Самара, Тополей, 10	f	large
70985	80258	669	Самарская область, Самара, Тополей, 10	f	large
70826	80181	534	Самарская область, Самара, Ташкентская, 88	f	large
70815	80176	523	Самарская область, Самара, Ташкентская, 164	f	large
70814	80176	522	Самарская область, Самара, Ташкентская, 164	f	large
71093	80373	828	Самарская область, Самара, Студенческий переулок, 2	f	large
71045	80342	790	Самарская область, Самара, Структурная, 48	f	large
71148	80420	886	Самарская область, Самара, Степана Разина, 46	f	large
71146	80418	884	Самарская область, Самара, Степана Разина, 49	f	large
71167	80426	893	Самарская область, Самара, Стара Загора, 37А	f	large
71166	80426	892	Самарская область, Самара, Стара Загора, 37А	f	large
70947	80245	631	Самарская область, Самара, Стара Загора, 151	f	large
70946	80245	630	Самарская область, Самара, Стара Загора, 151	f	large
70945	80245	629	Самарская область, Самара, Стара Загора, 151	f	large
70944	80245	628	Самарская область, Самара, Стара Загора, 151	f	large
70835	80185	543	Самарская область, Самара, Стара Загора, 226а	f	large
70834	80185	542	Самарская область, Самара, Стара Загора, 226а	f	large
70822	80179	530	Самарская область, Самара, Стара Загора, 269	f	large
70821	80179	529	Самарская область, Самара, Стара Загора, 269	f	large
70820	80179	528	Самарская область, Самара, Стара Загора, 269	f	large
70930	80239	614	Самарская область, Самара, Ставропольская, 116	f	large
70929	80239	613	Самарская область, Самара, Ставропольская, 116	f	large
70928	80239	612	Самарская область, Самара, Ставропольская, 116	f	large
71050	80319	753	Самарская область, Самара, Спортивная, 11	f	large
70995	80261	679	Самарская область, Промышленный район, Самара, Солнечная, 19/26	f	large
70994	80261	678	Самарская область, Промышленный район, Самара, Солнечная, 19/26	f	large
70993	80261	677	Самарская область, Промышленный район, Самара, Солнечная, 19/26	f	large
70992	80261	676	Самарская область, Промышленный район, Самара, Солнечная, 19/26	f	large
71003	80264	687	Самарская область, Самара, Солнечная, 63	f	large
71002	80264	686	Самарская область, Самара, Солнечная, 63	f	large
71001	80264	685	Самарская область, Самара, Солнечная, 63	f	large
71000	80263	684	Самарская область, Самара, Солнечная, 43	f	large
70999	80263	683	Самарская область, Самара, Солнечная, 43	f	large
70998	80262	682	Самарская область, Самара, Солнечная, 27	f	large
70997	80262	681	Самарская область, Самара, Солнечная, 27	f	large
70996	80262	680	Самарская область, Самара, Солнечная, 27	f	large
70891	80213	573	Самарская область, Самара, Солдатская, 2	f	large
71655	80453	933	Самарская область, Самара, Советской Армии, 5а	f	large
71203	80453	932	Самарская область, Самара, Советской Армии, 5а	f	large
71179	80436	907	Самарская область, Самара, Советской Армии, 74	f	large
71178	80436	906	Самарская область, Самара, Советской Армии, 74	f	large
71172	80429	899	Самарская область, Самара, Советской Армии, 141	f	large
71171	80429	898	Самарская область, Самара, Советской Армии, 141	f	large
71170	80429	897	Самарская область, Самара, Советской Армии, 141	f	large
71134	80408	872	Самарская область, Самара, Советской Армии, 271	f	large
70984	80257	668	Самарская область, Самара, Силина, 10	f	large
70983	80257	667	Самарская область, Самара, Силина, 10	f	large
70982	80257	666	Самарская область, Самара, Силина, 10	f	large
71072	80356	807	Самарская область, Самара, Силаева, 5	f	large
71071	80356	806	Самарская область, Самара, Силаева, 5	f	large
71249	80493	1006	Самарская область, Самара, Сергея Лазо, 17	f	large
70890	80211	571	Самарская область, Самара, Сергея Лазо, 21	f	large
70889	80211	570	Самарская область, Самара, Сергея Лазо, 21	f	large
70885	80208	566	Самарская область, Самара, Сергея Лазо, 23	f	large
70883	80206	564	Самарская область, Самара, Сергея Лазо, 33	f	large
71196	80448	924	Самарская область, Самара, Свободы, 81Б	f	large
71195	80448	923	Самарская область, Самара, Свободы, 81Б	f	large
71182	80438	910	Самарская область, Самара, Свободы, 2А	f	large
71181	80437	909	Самарская область, Самара, Свободы, 2б	f	large
71180	80437	908	Самарская область, Самара, Свободы, 2б	f	large
70861	80163	498	Самарская область, Самара, Свободы, 193	f	large
70860	80163	497	Самарская область, Самара, Свободы, 193	f	large
70862	80163	499	Самарская область, Самара, Свободы, 193	f	large
71642	80160	488	Самарская область, Самара, Свободы, 129	f	large
70855	80160	492	Самарская область, Самара, Свободы, 129	f	large
70854	80160	491	Самарская область, Самара, Свободы, 129	f	large
70853	80160	490	Самарская область, Самара, Свободы, 129	f	large
70852	80160	489	Самарская область, Самара, Свободы, 129	f	large
71215	95016	960	Самарская область, Самара, Самарская, 16	f	large
71096	80375	831	Самарская область, Самара, Самарская, 205А	f	large
71095	80375	830	Самарская область, Самара, Самарская, 205А	f	large
71090	80369	824	Самарская область, Самара, Самарская, 152	f	large
71150	80422	888	Самарская область, Самара, Садовая, 30	f	large
70666	79766	75	Самарская область, Самара, Садовая, 4	f	large
70904	80226	588	Самарская область, Самара, Рыльская, 22	f	large
70858	80161	495	Самарская область, Самара, Республиканская, 50	f	large
70857	80161	494	Самарская область, Самара, Республиканская, 50	f	large
70856	80161	493	Самарская область, Самара, Республиканская, 50	f	large
71116	80391	852	Самарская область, Самара, Радонежская улица, 2а	f	large
71115	80391	851	Самарская область, Самара, Радонежская улица, 2а	f	large
71083	80363	818	Самарская область, Самара, Пугачевский тракт, 57	f	large
71082	80362	817	Самарская область, Самара, Пугачевский тракт, 27а	f	large
71081	80362	816	Самарская область, Самара, Пугачевский тракт, 27а	f	large
71080	80362	815	Самарская область, Самара, Пугачевский тракт, 27а	f	large
71204	80452	931	Самарская область, Самара, Промышленности, 276	f	large
71199	80450	927	Самарская область, Самара, Промышленности, 319	f	large
71200	80450	928	Самарская область, Самара, Промышленности, 319	f	large
117207	95089	972	Самарская область, Самара, Пролетарская улица	f	medium
71226	95089	971	Самарская область, Самара, Пролетарская улица	f	large
71224	95087	969	Самарская область, Самара, Пролетарская, 27	f	large
71027	80329	770	Самарская область, Самара, Пролетарская, 175	f	large
71111	80386	846	Самарская область, Самара, Полевая, 80	f	large
71190	80443	918	Самарская область, Самара, Победы, 22	f	large
71189	80443	917	Самарская область, Самара, Победы, 22	f	large
70850	80158	486	Самарская область, Самара, Победы, 154а	f	large
70738	79852	170	Самарская область, Самара, Пионерская, 30	f	large
71107	80382	842	Самарская область, Самара, Первомайская, 18	f	large
71023	80326	766	Самарская область, Самара, Пензенская, 65а	f	large
71022	80326	765	Самарская область, Самара, Пензенская, 65а	f	large
71021	80326	764	Самарская область, Самара, Пензенская, 65а	f	large
71018	80324	761	Самарская область, Самара, Пензенская, 47	f	large
71057	80324	760	Самарская область, Самара, Пензенская, 47	f	large
71165	80460	948	Самарская область, Самара, Партизанская улица, 208	f	large
71164	80460	947	Самарская область, Самара, Партизанская улица, 208	f	large
71657	80460	946	Самарская область, Самара, Партизанская улица, 208	f	large
71030	80332	773	Самарская область, Самара, Партизанская улица, 78а	f	large
71028	80330	771	Самарская область, Самара, Партизанская улица, 56	f	large
71029	80331	772	Самарская область, Самара, Партизанская, 60	f	large
71644	80212	572	Самарская область, Самара, Парижской Коммуны, 5а	f	large
71086	80366	821	Самарская область, Самара, Охтинская, 25	f	large
70842	80151	477	Самарская область, Самара, Офицерская, 53	f	large
71117	80392	853	Самарская область, Самара, Осипенко, 6	f	large
71114	80390	850	Самарская область, Самара, Осипенко, 32а	f	large
71637	79948	266	Московская область, Ногинский район, Старая Купавна, Октябрьская улица, 58	f	large
71024	80327	767	Самарская область, Самара, Новоурицкая, 1	f	large
71060	80346	795	Самарская область, Самара, Новомолодежный переулок, 3	f	large
71084	80364	819	Самарская область, Самара, Новокуйбышевское шоссе, 54	f	large
70991	80260	675	Самарская область, Самара, Ново-вокзальная, 162	f	large
70954	80247	638	Самарская область, Самара, Ново-вокзальная, 193а	f	large
70953	80247	637	Самарская область, Самара, Ново-вокзальная, 193а	f	large
70952	80247	636	Самарская область, Самара, Ново-вокзальная, 193а	f	large
70923	80235	607	Самарская область, Самара, Ново-вокзальная, 19	f	large
70922	80235	606	Самарская область, Самара, Ново-вокзальная, 19	f	large
70921	80235	605	Самарская область, Самара, Ново-вокзальная, 19	f	large
71118	80393	854	Самарская область, Самара, Ново-Садовая, 44	f	large
71652	80383	855	Самарская область, Самара, Ново-Садовая, 26а	f	large
71108	80383	843	Самарская область, Самара, Ново-Садовая, 26а	f	large
71123	80398	860	Самарская область, Самара, Николая Панова, 30	f	large
71048	80317	751	Самарская область, Самара, Неверова, 87	f	large
71141	80413	879	Самарская область, Самара, Московское шоссе, 77	f	large
71138	80411	876	Самарская область, Самара, Московское шоссе, 120	f	large
71133	80406	870	Самарская область, Самара, Московское шоссе, 18А	f	large
71127	80401	864	Самарская область, Самара, Московское шоссе, 32	f	large
70967	80252	651	Самарская область, Самара, Московское шоссе, 125	f	large
70966	80252	650	Самарская область, Самара, Московское шоссе, 125	f	large
70965	80251	649	Самарская область, Самара, Московское шоссе, 101	f	large
70964	80251	648	Самарская область, Самара, Московское шоссе, 101	f	large
70963	80251	647	Самарская область, Самара, Московское шоссе, 101	f	large
70836	80190	547	Самарская область, Самара, Московское 18 км шоссе, 18а, МОУ СОШ №171	f	large
117151	80189	546	Самарская область, Самара, Московского шоссе, 3, НИИ Жигулевские сады	f	medium
71198	80449	926	Самарская область, Самара, Мориса Тореза, 115	f	large
71197	80449	925	Самарская область, Самара, Мориса Тореза, 115	f	large
71040	80338	783	Самарская область, Самара, Мориса Тореза, 52	f	large
71041	80338	784	Самарская область, Самара, Мориса Тореза, 52	f	large
71037	80336	780	Самарская область, Самара, Мориса Тореза, 36	f	large
71036	80335	779	Самарская область, Железнодорожный район, Самара, Мориса Тореза, 36а	f	large
71035	80334	778	Самарская область, Самара, Мориса Тореза, 32	f	large
71034	80334	777	Самарская область, Самара, Мориса Тореза, 32	f	large
71033	80334	776	Самарская область, Самара, Мориса Тореза, 32	f	large
71089	80368	823	Самарская область, Самара, Молодогвардейская улица, 133	f	large
71149	80421	887	Самарская область, Самара, Молодогвардейская, 62	f	large
71113	80388	848	Самарская область, Самара, Мичурина, 52	f	large
70823	80169	531	Самарская область, Самара, Майская, 47	f	large
70804	80169	512	Самарская область, Самара, Майская, 47	f	large
70872	80169	509	Самарская область, Самара, Майская, 47	f	large
70843	80150	476	Самарская область, Самара, Магистральная, 133Б	f	large
71119	80394	856	Самарская область, Самара, Луначарского, 14А	f	large
71653	80407	871	Самарская область, Самара, Лукачева, 48	f	large
71132	80405	869	Самарская область, Самара, Лукачева, 46	f	large
71129	80402	866	Самарская область, Самара, Лукачева, 17	f	large
71128	80402	865	Самарская область, Самара, Лукачева, 17	f	large
71062	80348	797	Самарская область, Самара, Липяговская, 3А	f	large
71219	95082	964	Самарская область, Самара, Куйбышева, 24	f	large
71151	80423	889	Самарская область, Самара, Куйбышева, 131	f	large
71194	80447	922	Самарская область, Самара, Красных Коммунаров, 28	f	large
71193	80446	921	Самарская область, Самара, Красных Коммунаров, 16	f	large
71091	80371	826	Самарская область, Самара, Красноармейская, 93а	f	large
117203	80344	792	Самарская область, Самара, Комсомольская площадь, 1	f	small
71100	80377	834	Самарская область, Самара, Коммунистическая, 7	f	large
71099	80377	833	Самарская область, Самара, Коммунистическая, 7	f	large
71020	80325	763	Самарская область, Самара, Клиническая улица, 86	f	large
71019	80325	762	Самарская область, Самара, Клиническая улица, 86	f	large
71061	80347	796	Самарская область, Самара, Кишиневская, 13	f	large
71078	80347	813	Самарская область, Самара, Кишиневская, 13	f	large
70892	80214	574	Самарская область, Самара, Квартал 5, 9	f	large
70912	80229	596	Самарская область, Самара, Каховская улица, 7	f	large
70911	80229	595	Самарская область, Самара, Каховская улица, 7	f	large
70910	80229	594	Самарская область, Самара, Каховская улица, 7	f	large
70664	79764	73	Самарская область, Самара, Карбышева, 8	f	large
70663	79764	72	Самарская область, Самара, Карбышева, 8	f	large
71069	80354	804	Самарская область, Самара, Казачья, 1	f	large
117204	80462	950	Самарская область, Самара, Кабельная, 45А	f	medium
70840	80149	475	Самарская область, Самара, Изыскательская, 28	f	large
70839	80149	473	Самарская область, Самара, Изыскательская, 28	f	large
70847	80153	482	Самарская область, Самара, Зубчаниновское шоссе, 161	f	large
70846	80153	481	Самарская область, Самара, Зубчаниновское шоссе, 161	f	large
70845	80153	480	Самарская область, Самара, Зубчаниновское шоссе, 161	f	large
71641	80153	479	Самарская область, Самара, Зубчаниновское шоссе, 161	f	large
70981	80256	665	Самарская область, Самара, Зои Космодемьянской, 8	f	large
70980	80256	664	Самарская область, Самара, Зои Космодемьянской, 8	f	large
70979	80256	663	Самарская область, Самара, Зои Космодемьянской, 8	f	large
70978	80256	662	Самарская область, Самара, Зои Космодемьянской, 8	f	large
70644	79752	52	Самарская область, Самара, Зои Космодемьянской, 5	f	large
117148	80155	483	Самарская область, Самара, Земеца, 24А	f	medium
71186	80440	914	Самарская область, Самара, Запорожская, 24	f	large
70909	80228	593	Самарская область, Самара, Заводское шоссе, 68	f	large
70908	80228	592	Самарская область, Самара, Заводское шоссе, 68	f	large
70907	80228	591	Самарская область, Самара, Заводское шоссе, 68	f	large
70906	80228	590	Самарская область, Самара, Заводское шоссе, 68	f	large
71124	80399	861	Самарская область, Самара, Ерошевского, 29	f	large
70848	80156	484	Самарская область, Самара, Елизарова, 28а	f	large
70864	80156	501	Самарская область, Самара, Елизарова, 28а	f	large
70741	79854	173	Самарская область, Самара, Дружбы Народов, 3	f	large
70740	79854	172	Самарская область, Самара, Дружбы Народов, 3	f	large
71202	80451	930	Самарская область, Самара, Днепровская, 2	f	large
71201	80451	929	Самарская область, Самара, Днепровская, 2	f	large
117149	80186	544	Самарская область, Самара, Дальняя, 6	f	medium
71068	80353	803	Самарская область, Самара, Главная, 3	f	large
70819	80178	527	Самарская область, Кировский район, Самара, Георгия Димитрова, 17	f	large
70818	80178	526	Самарская область, Кировский район, Самара, Георгия Димитрова, 17	f	large
70990	80259	674	Самарская область, Самара, Георгия Димитрова, 114	f	large
70989	80259	673	Самарская область, Самара, Георгия Димитрова, 114	f	large
70817	80177	525	Самарская область, Самара, Георгия Димитрова, 39	f	large
70816	80177	524	Самарская область, Самара, Георгия Димитрова, 39	f	large
70813	80174	521	Самарская область, Самара, Георгия Димитрова, 50	f	large
70812	80174	520	Самарская область, Самара, Георгия Димитрова, 50	f	large
70811	80174	519	Самарская область, Самара, Георгия Димитрова, 50	f	large
70863	80164	500	Самарская область, Самара, Гвардейская, 14	f	large
70859	80162	496	Самарская область, Самара, Гвардейская, 22	f	large
71142	80414	880	Самарская область, Самара, Гастелло, 47	f	large
71153	80425	891	Самарская область, Самара, Галактионовская, 37	f	large
71088	80370	825	Самарская область, Самара, Галактионовская, 141	f	large
70888	80207	569	Самарская область, Самара, Гайдара, 9	f	large
70884	80207	565	Самарская область, Самара, Гайдара, 9	f	large
71070	80355	805	Самарская область, Самара, Восстания, 3	f	large
70958	80248	642	Самарская область, Самара, Воронежская, 232	f	large
70957	80248	641	Самарская область, Самара, Воронежская, 232	f	large
70956	80248	640	Самарская область, Самара, Воронежская, 232	f	large
70955	80248	639	Самарская область, Самара, Воронежская, 232	f	large
116901	79767	76	Самарская область, Самара, Вольская улица, 55/27	f	medium
71188	80442	916	Самарская область, Самара, Вольская, 13	f	large
70925	80237	609	Самарская область, Самара, Вольская, 40	f	large
70924	80237	608	Самарская область, Самара, Вольская, 40	f	large
70920	80234	604	Самарская область, Самара, Вольская, 96	f	large
70919	80234	603	Самарская область, Самара, Вольская, 96	f	large
71094	80374	829	Самарская область, Самара, Волжский проспект, 41	f	large
71044	80340	787	Самарская область, Самара, Волгина, 110	f	large
71043	80340	786	Самарская область, Самара, Волгина, 110	f	large
70977	80255	661	Самарская область, Самара, Бубнова, 7	f	large
70976	80255	660	Самарская область, Самара, Бубнова, 7	f	large
70975	80255	659	Самарская область, Самара, Бубнова, 7	f	large
70974	80255	658	Самарская область, Самара, Бубнова, 7	f	large
71092	80372	827	Самарская область, Ленинский район, Самара, Братьев Коростелевых, 144	f	large
71049	80318	752	Самарская область, Самара, Братьев Коростелевых, 17	f	large
71112	80387	847	Самарская область, Самара, Больничная, 14а	f	large
71169	80427	895	Самарская область, Самара, Блюхера, 25	f	large
71168	80427	894	Самарская область, Самара, Блюхера, 25	f	large
71656	80454	935	Самарская область, Самара, Бельский переулок, 9	f	large
71205	80454	934	Самарская область, Самара, Бельский переулок, 9	f	large
71067	80352	802	Самарская область, Самара, Белорусская, 44а	f	large
71065	80350	800	Самарская область, Самара, Белорусская, 112а	f	large
71064	80350	799	Самарская область, Самара, Белорусская, 112а	f	large
71046	80343	791	Самарская область, Самара городской округ	f	large
71161	80458	943	Самарская область, Самара, Балаковская улица, 10а	f	large
71160	80458	942	Самарская область, Самара, Балаковская улица, 10а	f	large
71206	80455	936	Самарская область, Самара, Балаковская , 16	f	large
71163	80459	945	Самарская область, Самара, Аэродромная, 65	f	large
71162	80459	944	Самарская область, Самара, Аэродромная, 65	f	large
71650	80341	789	Самарская область, Самара, Аэродромная, 16а	f	large
71649	80341	788	Самарская область, Самара, Аэродромная, 16а	f	large
71144	80416	882	Самарская область, Самара, Артемовская улица, 24а	f	large
71154	80432	902	Самарская область, Самара, Артемовская, 50	f	large
71143	80415	881	Самарская область, Самара, Артемовская, 24а	f	large
71185	80439	913	Самарская область, Самара, Антонова-Овсеенко, 85	f	large
71184	80439	912	Самарская область, Самара, Антонова-Овсеенко, 85	f	large
71183	80439	911	Самарская область, Самара, Антонова-Овсеенко, 85	f	large
71654	80428	896	Самарская область, Самара, Антонова-Овсеенко, 51	f	large
70968	80253	652	Самарская область, Самара, Аминева, 26	f	large
70971	80253	655	Самарская область, Самара, Аминева, 26	f	large
70970	80253	654	Самарская область, Самара, Аминева, 26	f	large
70969	80253	653	Самарская область, Самара, Аминева, 26	f	large
70829	80182	537	Самарская область, Самара, Алма-Атинская, 122	f	large
70828	80182	536	Самарская область, Самара, Алма-Атинская, 122	f	large
70827	80182	535	Самарская область, Самара, Алма-Атинская, 122	f	large
71098	80378	835	Самарская область, Самара, Аксакова, 21	f	large
71136	80404	874	Самарская область, Самара, Академика Павлова, 85	f	large
71131	80404	868	Самарская область, Самара, Академика Павлова, 85	f	large
71130	80403	867	Самарская область, Самара, Академика Павлова, 1	f	large
70887	80210	568	Самарская область, Самара, Академика Кузнецова, 7	f	large
71155	80456	937	Самарская область, Самара, Авроры, 117	f	large
71157	80456	939	Самарская область, Самара, Авроры, 117	f	large
71156	80456	938	Самарская область, Самара, Авроры, 117	f	large
71075	80359	810	Самарская область, Самара, 40 лет Пионерии, 16	f	large
71074	80358	809	Самарская область, Самара, 40 лет Пионерии, 16	f	large
70895	80217	578	Самарская область, Самара, 4-й квартал, 28	f	large
70894	80217	577	Самарская область, Самара, 4-й квартал, 28	f	large
70873	80195	552	Самарская область, Самара, 3-й квартал, 46	f	large
70897	80219	580	Самарская область, Самара, 2-й квартал Мехзавода, 10	f	large
70882	80202	562	Самарская область, Самара, 15-й квартал Мехзавода, 20	f	large
70881	80202	561	Самарская область, Самара, 15-й квартал Мехзавода, 20	f	large
70878	80202	558	Самарская область, Самара, 15-й квартал Мехзавода, 20	f	large
70874	80197	554	Самарская область, Самара, 11-й квартал Мехзавода, 15	f	large
70893	80216	576	Самарская область, Красноглинский район,, Самара, 1-й квартал Мехзавода, 1	f	large
70876	80199	556	Самарская область, Самара, квартал 6,/1, пос.Мехзавод	f	large
71173	80430	900	Самарская область, Самара, ХХII Партсъезда, 56	f	large
71073	80357	808	Самарская область, Самара, Фасадная, 19	f	large
71137	80410	875	Самарская область, Самара, Советской Армии, 212	f	large
71177	80435	905	Самарская область, Самара, Антонова-Овсеенко, 53	f	large
70734	79855	174	Самарская область, поселок Рощинский, МОУ Рощинская СОШ	f	large
70736	79850	168	Самарская область, поселок Рощинский, Спортивная база Черноречье	f	large
70735	79849	167	Самарская область, поселок Рощинский, Комбинат бытового обслуживания	f	large
116913	79834	152	Самарская область, поселок Рождествено, Шоссейная, 1б	f	medium
70727	79833	151	Самарская область, село Рождествено, Пацаева, 1	f	large
117263	80597	1122	Самарская область, село Привольный	f	small
117262	80596	1121	Самарская область, село Преображенка, Тополиная, 15	f	small
70692	79798	108	Самарская область, Похвистнево, Центральная, 5	f	large
70683	79788	98	Самарская область, Похвистнево, Революционная, 109	f	large
70689	79795	105	Самарская область, Похвистнево, Мира, 39	f	large
70688	79794	104	Самарская область, Похвистнево, Мира, 22	f	large
70687	79792	102	Самарская область, Похвистнево, Малиновского, 1а	f	large
70685	79790	100	Самарская область, Похвистнево, Лермонтова, 35	f	large
70684	79789	99	Самарская область, Похвистнево, Ленинградская, 2	f	large
116906	79799	109	Самарская область, Похвистнево, Краснопутиловская, 1	f	medium
70691	79797	107	Самарская область, Похвистнево, Кооперативная, 45	f	large
70690	79796	106	Самарская область, Похвистнево, Газовиков, 14	f	large
71629	79793	103	Самарская область, Похвистнево, Бережкова, 48, Дорожная компания	f	large
70686	79791	101	Самарская область, Похвистнево, Андрея Васильева, 2	f	large
117271	80603	1133	Самарская область, село Переволоки, Школьная, 2	f	small
117003	79971	290	Самарская область, село Первомайский, Садовая, 28	t	small
70670	79773	83	Самарская область, Отрадный, Центральная, 1	f	large
70675	79778	88	Самарская область, Отрадный, Советская, 88	f	large
70671	79774	84	Самарская область, Отрадный, Советская, 48	f	large
70679	79782	92	Самарская область, Отрадный, Пионерская, 28	f	large
70678	79781	91	Самарская область, Отрадный, Пионерская, 31	f	large
70676	79779	89	Самарская область, Отрадный, Первомайская, 28	f	large
70674	79777	87	Самарская область, Отрадный, Первомайская, 33	f	large
70673	79776	86	Самарская область, Отрадный, Первомайская, 35	f	large
70672	79775	85	Самарская область, Отрадный, Отрадная, 7	f	large
70681	79785	95	Самарская область, Отрадный, Ленинградская, 45	f	large
70682	79786	96	Самарская область, Отрадный, Жигулёвская, 2А	f	large
70680	79783	93	Самарская область, Отрадный, Гайдара, 74	f	large
71628	79784	94	Самарская область, Отрадный, Гагарина, 50	f	large
70677	79780	90	Самарская область, Отрадный, Ленина, 62а	f	large
116960	79901	220	Самарская область, поселок Октябрьский, Школьная, 1	t	medium
71237	80476	989	Самарская область, Октябрьск, Центральная, 14	f	large
71238	80477	990	Самарская область, Октябрьск, Мира, 94	f	large
71230	80466	979	Самарская область, Октябрьск, Ленинградская, 87	f	large
71232	80470	983	Самарская область, Октябрьск, Ленина, 52	f	large
71658	80467	980	Самарская область, Октябрьск, Ленина, 42	f	large
71236	80475	988	Самарская область, Октябрьск, Котовского, 32	f	large
71231	80468	981	Самарская область, Октябрьск, Гоголя, 16	f	large
71659	80469	982	Самарская область, Октябрьск, Гая, 39	f	large
71235	80474	987	Самарская область, Октябрьск, Аипова, 5	f	large
117213	80479	992	Самарская область, Октябрьск, 3-го Октября, 17	f	medium
71239	80481	993	Самарская область, Октябрьск, 3 Октября, 153	f	large
116900	79745	45	Самарская область, Новокуйбышевск, проезд Жележнодорожный, заводоуправление ООО Биаксплен НК	f	medium
71625	79748	48	Самарская область, Новокуйбышевск, Чернышевского, 6	f	large
70629	79738	34	Самарская область, Новокуйбышевск, Чернышевского, 16	f	large
71626	79749	49	Самарская область, Новокуйбышевск, Успенского, 2а	f	large
70635	79740	40	Самарская область, Новокуйбышевск, Свердлова, 12	f	large
70633	79740	38	Самарская область, Новокуйбышевск, Свердлова, 12	f	large
70665	79765	74	Самарская область, Новокуйбышевск, Победы проспект, 38	f	large
70649	79754	57	Самарская область, Новокуйбышевск, Победы проспект, 7	f	large
70667	79769	78	Самарская область, Новокуйбышевск, Миронова, 32	f	large
70640	79746	46	Самарская область, Новокуйбышевск, Миронова, 26	f	large
70653	79756	61	Самарская область, Новокуйбышевск, Киевская улица, 15	f	large
70652	79756	60	Самарская область, Новокуйбышевск, Киевская улица, 15	f	large
70662	79763	71	Самарская область, Новокуйбышевск, Дзержинского, 23-а	f	large
70661	79763	70	Самарская область, Новокуйбышевск, Дзержинского, 23-а	f	large
70660	79763	69	Самарская область, Новокуйбышевск, Дзержинского, 23-а	f	large
116904	79772	82	Самарская область, Новокуйбышевск, Гранная, 14	t	small
71343	80766	1297	Самарская область, Нефтегорск, Нефтяников, 22	f	large
71346	80769	1300	Самарская область, Нефтегорск, Буровиков, 6	f	large
71643	80196	553	Самарская область, поселок Мехзавод, Московское шоссе, 8А	f	large
116894	79722	18	Самарская область, Кинель, Элеваторная, 24	f	medium
116899	79731	27	Самарская область, Кинель, Шоссейная, 76	f	medium
70622	79730	26	Самарская область, Кинель, Шоссейная, 82	f	large
70609	79708	3	Самарская область, Кинель, Шоссейная, 6	f	large
116898	79727	23	Самарская область, Кинель, Школьная, 7	t	small
70614	79715	11	Самарская область, Кинель, Ульяновская, 27а	f	large
116891	79711	7	Самарская область, Кинель, Ульяновская, 1	f	medium
70619	79724	20	Самарская область, Кинель, Украинская, 50	f	large
70620	79728	24	Самарская область, Кинель, Спортивная, 9	f	large
116889	79709	4	Самарская область, Кинель, Советская, 46	f	medium
116888	79707	2	Самарская область, Кинель, Первомайская, 31а	f	medium
70608	79706	1	Самарская область, Кинель, Первомайская, 1а	f	large
116893	79720	16	Самарская область, Кинель, Октябрьская, 1	f	medium
70626	79735	31	Самарская область, Кинель, Невская, 35а	f	large
116890	79710	6	Самарская область, Кинель, Набережная, 1а	f	medium
70610	79710	5	Самарская область, Кинель, Набережная, 1а	f	large
116895	79723	19	Самарская область, Кинель, Мостовая, 21	f	medium
70616	79717	13	Самарская область, Кинель, Мира, 42	f	large
70617	79718	14	Самарская область, Кинель, Маяковского, 49	f	large
70615	79716	12	Самарская область, Кинель, Маяковского, 72	f	large
70612	79713	9	Самарская область, Кинель, Маяковского, 90а	f	large
70611	79712	8	Самарская область, Кинель, Маяковского, 79	f	large
116897	79726	22	Самарская область, Кинель, Дачная, 14	t	small
70625	79734	30	Самарская область, Кинель, Гагарина, 8	f	large
70613	79714	10	Самарская область, Кинель, 27 Партсъезда, 5А	f	large
116896	79725	21	Самарская область, Кинель, Центральная , 1б, п.Горный	t	small
70618	79721	17	Самарская область, Кинель, 50 лет Октября, 25А	f	large
116892	79719	15	Самарская область, Кинель, 50 лет Октября, 80	f	medium
134673	94998	958	Самарская область, Жигулёвск, Пионерская, 23	f	\N
71223	95086	968	Самарская область, Жигулевск, Морквашинская, 59, ГБОУ СПО Жигулёвский государственный колледж корп.В	f	large
71220	95083	965	Самарская область, Жигулевск, В-1, 31, здание МОУ ДОД СЮТ	f	large
71387	80920	1456	Самарская область, поселок Волжский Утес, Безымянная, 18а	f	large
117209	95093	976	Самарская область, поселок Богатырь, Управленческая, 1, здание ДК ЗАО ЖИЗ	f	medium
117208	95090	973	Самарская область, село Бахилова Поляна	f	small
71384	80914	1444	Самарская область, Шигонский район, поселок Шигоны, Советская, 131	f	large
71671	80915	1445	Самарская область, Шигонский район, село Шигоны, Советская, 146	f	large
71386	73753	1455	Самарская область, Шигонский район, село Усолье, Ленина, 56	f	large
117516	73427	1454	Самарская область, Шигонский район, село Усолье, Королёва, 14	f	medium
117513	80902	1451	Самарская область, Шигонский район, село Тайдаково, Ленина, 38	t	small
117506	80909	1439	Самарская область, Шигонский район, село Суринск, Школьная, 29	f	medium
117505	80908	1438	Самарская область, Шигонский район, село Старый Тукшум, Советская, 46	f	small
117124	80122	446	Самарская область, Шигонский район, село Сенькино, Центральная, 25	f	small
117511	80918	1448	Самарская область, Шигонский район, село Подвалье, Колхозная, 53	f	small
71383	80912	1442	Самарская область, Шигонский район, село Пионерский, Советская, 18	f	large
71385	80891	1450	Самарская область, Шигонский район, село Новодевичье, Ленинградская, 68б	f	large
117405	80757	1287	Самарская область, Шигонский район, поселок Новая Жизнь, Набережная, 50	t	small
117509	80916	1446	Самарская область, Шигонский район, село Муранка, Советская, 34	f	medium
71382	80911	1441	Самарская область, Шигонский район, село Малячкино, Советская, 45а	f	large
117515	73411	1453	Самарская область, Шигонский район, село Маза, Калинина, 52	t	small
117510	80917	1447	Самарская область, Шигонский район, село Львовка, Советская, 3	f	small
117512	80919	1449	Самарская область, Шигонский район, село Луговской, Новостойка, 23	f	small
117508	80913	1443	Самарская область, Шигонский район, село Кяхта, Центральная, 11 а	f	small
117519	80923	1459	Самарская область, Шигонский район, село Кузькино, Советская , 59	f	small
117517	80921	1457	Самарская область, Шигонский район, село Комаровка, Спортивная, 2	t	small
117514	72906	1452	Самарская область, Шигонский район, село Климовка, Новая, 15	t	small
117518	80922	1458	Самарская область, Шигонский район, село Бичевная, Заводская, 17	t	medium
117504	80907	1437	Самарская область, Шигонский район, село Береговой, Школьная, 1	f	medium
117507	80910	1440	Самарская область, Шигонский район, село Байдеряково, Центральная, 121	f	medium
117144	80142	466	Самарская область, Шенталинский район, станция Шентала, Попова, 7	f	medium
117145	80143	467	Самарская область, Шенталинский район, село Шентала, Советская, 40	f	medium
70801	80146	470	Самарская область, Шенталинский район, село Шентала, Победы, 48	f	large
117146	80144	468	Самарская область, Шенталинский район, село Шентала, Льва Толстого, 53	f	medium
117147	80145	469	Самарская область, Шенталинский район, село Шентала, Вокзальная, 47	f	medium
117142	80140	464	Самарская область, Шенталинский район, село Четырла, Ленина, 5А	f	medium
117141	80139	463	Самарская область, Шенталинский район, село Туарма, Советская, 2	t	small
117139	80137	461	Самарская область, Шенталинский район, село Толчеречье, Садовая, 6	t	small
117134	80132	456	Самарская область, Шенталинский район, село Тимяшево, Тимяшево, Молодёжная, 17	f	small
117128	80126	450	Самарская область, Шенталинский район, село Татарское Абдикеево, Школьная, 136	f	small
117125	80123	447	Самарская область, Шенталинский район, село Старое Суркино, Школьная, 1	f	small
117133	80131	455	Самарская область, Шенталинский район, село Старое Афонькино, Центральная, 21	f	small
117135	80133	457	Самарская область, Шенталинский район, село Старая Шентала, Советская, 23	f	small
117143	80141	465	Самарская область, Шенталинский район, село Семеново-Шарла, Школьная, 1В	t	small
117132	80130	454	Самарская область, Шенталинский район, село Салейкино, Советская, 46	f	small
117497	80897	1428	Самарская область, Шенталинский район, село Романовка, Советская, 104	t	small
117131	80129	453	Самарская область, Шенталинский район, село Новый Кувак, Журавлева, 49	f	small
117137	80135	459	Самарская область, Шенталинский район, село Крепость Кондурча, Бочкарева, 2	f	small
71647	80281	715	Самарская область, Шенталинский район, село Красный Яр, Комсомольская, 92	f	large
117122	80120	444	Самарская область, Шенталинский район, село Костюнькино, Центральная, 21	t	small
117129	80127	451	Самарская область, Шенталинский район, село Карабикулово, Центральная, 25	t	small
117126	80124	448	Самарская область, Шенталинский район, село Денискино, Хакимова, 27	f	medium
117163	80242	694	Самарская область, Шенталинский район, село Вязовка, Центральная, 1 в	f	small
117138	80136	460	Самарская область, Шенталинский район, село Баландаево, Молодежная, 2	f	small
117136	80134	458	Самарская область, Шенталинский район, село Багана, Школьная, 27	f	small
117121	80119	443	Самарская область, Шенталинский район, село Артюшкино, Советская, 34	f	small
117140	80138	462	Самарская область, Шенталинский район, село Аксаково, Школьная, 39	t	small
117104	80101	424	Самарская область, Челно-Вершинский район, село Шламка, Центральная, 68	f	small
117119	80117	441	Самарская область, Челно-Вершинский район, село Чувашское Эштебенькино, Советская, 4	t	small
117117	80115	439	Самарская область, Челно-Вершинский район, село Чувашское Урметьево, Центральная, 38	f	small
117106	80102	426	Самарская область, Челно-Вершинский район, село Чистовка, Школьная, 16	f	small
117115	80113	437	Самарская область, Челно-Вершинский район, село Челно-Вершины, микрорайон Сельхозтехника, 16	f	small
117112	80110	434	Самарская область, Челно-Вершинский район, село Челно-Вершины, Центральная, 27	f	medium
117111	80109	433	Самарская область, Челно-Вершинский район, село Челно-Вершины, Советская, 18	f	medium
70800	80108	432	Самарская область, Челно-Вершинский район, село Челно-Вершины, Почтовая, 3А	f	large
70799	80107	431	Самарская область, Челно-Вершинский район, село Челно-Вершины, Почтовая, 15	f	large
117113	80111	435	Самарская область, Челно-Вершинский район, село Челно-Вершины, Заводская, 2	f	medium
117114	80112	436	Самарская область, Челно-Вершинский район, село Челно-Вершины, М. Джалиля, 44	f	medium
117110	80106	430	Самарская область, Челно-Вершинский район, село Токмакла, Центральная, 11	f	small
117118	80116	440	Самарская область, Челно-Вершинский район, село Старое Эштебенькино, Школьная, 6Б	f	medium
117109	80105	429	Самарская область, Челно-Вершинский район, село Старое Аделяково, Школьная, 16А	f	small
71276	80545	1068	Самарская область, Челно-Вершинский район, село Советский Нурлат, Советская, 79	f	large
117108	80104	428	Самарская область, Челно-Вершинский район, село Сиделькино, Советская, 22	f	medium
117403	80755	1285	Самарская область, Челно-Вершинский район, село Покровка, Первомайская, 6, сельский клуб	f	medium
117120	80118	442	Самарская область, Челно-Вершинский район, село Новое Эштебенькино, Главная, 5	t	small
117116	80114	438	Самарская область, Челно-Вершинский район, село Новое Аделяково, Озерная, 14	f	medium
117101	80098	421	Самарская область, Челно-Вершинский район, село Новая Таяба, Центральная, 19	t	small
117103	80100	423	Самарская область, Челно-Вершинский район, село Малый Нурлат, Молодежная, 3	t	small
117096	80093	416	Самарская область, Челно-Вершинский район, село Малое Девлезеркино, Школьная, 1А	f	small
70758	79954	272	Самарская область, Челно-Вершинский район, село Кротовка, Куйбышевская, 21	f	large
117098	80095	418	Самарская область, Челно-Вершинский район, село Красный Строитель, Школьная, 52А	t	medium
117102	80099	422	Самарская область, Челно-Вершинский район, село Краснояриха, Центральная, 10	f	small
116993	79952	270	Самарская область, Челно-Вершинский район, село Красная Горка, Чапаевская, 69	f	medium
117100	80097	420	Самарская область, Челно-Вершинский район, село Красная Багана, Центральная, 18	t	small
117099	80096	419	Самарская область, Челно-Вершинский район, село Каменный Брод, Школьная, 13	f	medium
117097	80094	417	Самарская область, Челно-Вершинский район, село Зубовка, Фрунзе, 52А	f	small
117095	80092	415	Самарская область, Челно-Вершинский район, село Девлезеркино, Советская, 16В	f	medium
70729	79836	154	Самарская область, Челно-Вершинский район, село Воскресенка, Ленинская, 1	f	large
116975	79925	244	Самарская область, Челно-Вершинский район, село Александровка, А.Толстого, 8	f	medium
117502	80903	1433	Самарская область, Хворостянский район, село Чувичи, Молодёжная, 2	f	small
117493	80893	1424	Самарская область, Хворостянский район, село Чагра, Хлебная, 20	f	small
71381	80906	1436	Самарская область, Хворостянский район, село Хворостянка, Школьная, 18	f	large
117503	80905	1435	Самарская область, Хворостянский район, село Хворостянка, Плясункова, 3	f	medium
71380	80904	1434	Самарская область, Хворостянский район, село Хворостянка, Плясункова, 4	f	large
117488	80887	1419	Самарская область, Хворостянский район, село Тополек, Центральная, 20	t	small
117501	80901	1432	Самарская область, Хворостянский район, село Студенцы, Новый поселок, 3	f	small
117499	80899	1430	Самарская область, Хворостянский район, село Соловьево, Полевая, 1	t	small
117130	80128	452	Самарская область, Хворостянский район, село Романовка, Школьная, 1	f	medium
117495	80895	1426	Самарская область, Хворостянский район, село Прогресс, Молодежная, 5	f	medium
117489	80888	1420	Самарская область, Хворостянский район, село Приовражный, Рабочая, 1	t	small
117494	80894	1425	Самарская область, Хворостянский район, село Новотулка, Советская, 35	f	medium
117490	80889	1421	Самарская область, Хворостянский район, село Новокуровка, Советская, 49	f	medium
117491	80890	1422	Самарская область, Хворостянский район, село Михайло-Лебяжье, Центральная, 15	f	small
117487	80886	1418	Самарская область, Хворостянский район, село Масленниково, Советская, 3	f	medium
117486	80885	1417	Самарская область, Хворостянский район, село Липовка, Советская, 8	f	small
117498	80898	1429	Самарская область, Хворостянский район, село Иерусалимский, Широкая, 3	f	small
117492	80892	1423	Самарская область, Хворостянский район, село Елань, Неверова, 21	f	small
117500	80900	1431	Самарская область, Хворостянский район, село Высотино, Лесная, 12	t	small
117485	80884	1416	Самарская область, Хворостянский район, село Владимировка, Специалистов, 6	f	medium
117496	80896	1427	Самарская область, Хворостянский район, село Березовая Роща, Школьная, 26	f	small
117484	80883	1415	Самарская область, Хворостянский район, село Абашево, Школьная, 5	f	medium
71254	80498	1012	Самарская область, Сызрань городской округ, Сызрань, пр.50 лет октября, 4	f	large
117223	80533	1054	Самарская область, Сызранский район, станция Новообразцовое	t	small
71295	80535	1057	Самарская область, Сызранский район, городской округ Сызрань, Гаражная, 3	f	large
117483	80882	1414	Самарская область, Сызранский район, село Чекалино, Железникова, 25А	f	small
71379	80879	1411	Самарская область, Сызранский район, село Усинское, К.Маркса, 30	f	large
117473	80870	1402	Самарская область, Сызранский район, село Уваровка, Колхозная, 5	f	small
117466	80827	1394	Самарская область, Сызранский район, село Трубетчино, Королева, 7	f	small
117279	80611	1141	Самарская область, Сызранский район, село Троицкое, Вокзальная, 2	f	small
71378	80876	1408	Самарская область, Сызранский район, село Старая Рачейка, Ленинская, 2Б	f	large
117479	80877	1409	Самарская область, Сызранский район, село Смолькино, Советская, 57	t	small
117461	80857	1388	Самарская область, Сызранский район, село Сборный, Школьная , 3	f	medium
117478	80875	1407	Самарская область, Сызранский район, село Рамено, Клубная, 6	f	medium
117477	80874	1406	Самарская область, Сызранский район, село Печерское, Советская, 109	f	medium
117482	80881	1413	Самарская область, Сызранский район, село Печерские Выселки, Советская, 29	f	small
117017	79989	308	Самарская область, Сызранский район, село Петровка, Солнечная, 5	f	small
117360	80706	1236	Самарская область, Сызранский район, село Петровка, Советская, 44	f	medium
117472	80869	1401	Самарская область, Сызранский район, село Новый Ризадей, Центральная, 16А	f	small
117462	80858	1389	Самарская область, Сызранский район, село Новыи Озерки, Рабочая, 16	t	small
117475	80872	1404	Самарская область, Сызранский район, село Новорепьевский, Кооперативная, 9	f	small
117474	80871	1403	Самарская область, Сызранский район, село Новозаборовский, Солнечная, 2А	f	small
117471	80868	1400	Самарская область, Сызранский район, село Новая Рачейка, Юбилейная, 2Б	f	medium
117463	80860	1391	Самарская область, Сызранский район, село Новая Крымза, Центральная, 11А	f	small
117470	80867	1399	Самарская область, Сызранский район, поселок Междуреченск, ЖБК, 9А	f	medium
117469	80865	1397	Самарская область, Сызранский район, село Кошелевка, переулок Северный, 4	f	medium
117431	80800	1331	Самарская область, Сызранский район, село Кашпир, Калиновская, 1	f	small
117468	80864	1396	Самарская область, Сызранский район, село Ивашевка, Школьная, 16А	f	small
117467	80863	1395	Самарская область, Сызранский район, село Заборовка, Почтовая, 2В	f	medium
117465	80862	1393	Самарская область, Сызранский район, село Жемковка, Советская, 44	f	medium
117464	80861	1392	Самарская область, Сызранский район, село Демидовка, Лесная, 52 Б	f	small
117481	80880	1412	Самарская область, Сызранский район, село Губино, Школьная, 10	f	small
117476	80873	1405	Самарская область, Сызранский район, село Взгорье, Пригородная, 15	t	small
117264	80598	1123	Самарская область, Сызранский район, село Васильевка, Центральная, 52	f	medium
71376	80859	1390	Самарская область, Сызранский район, село Варламово, Советская, 16	f	large
71374	80855	1386	Самарская область, Ставропольский район, село Ягодное, Советская, 63А	f	large
71373	80855	1385	Самарская область, Ставропольский район, село Ягодное, Советская, 63А	f	large
71372	80854	1384	Самарская область, Ставропольский район, село Хрящевка, Полевая, 36/5	f	large
71371	80853	1383	Самарская область, Ставропольский район, село Узюково, Ленина, 100Д	f	large
71369	80845	1375	Самарская область, Ставропольский район, село Тимофеевка, Куйбышева, 44	f	large
117459	80851	1381	Самарская область, Ставропольский район, село Ташелка, Центральная, 13	f	small
117458	80850	1380	Самарская область, Ставропольский район, село Ташелка, Центральная, 21	f	small
71370	80849	1379	Самарская область, Ставропольский район, село Ташелка, Менжинского, 56	f	large
71670	80847	1377	Самарская область, Ставропольский район, село Сосновый Солонец, Куйбышева,, 45	f	large
71228	95092	975	Самарская область, Ставропольский район, село Солнечная Поляна, Нефтянников, 16, здание Школы №2	f	large
117456	80846	1376	Самарская область, Ставропольский район, село Севрюкаево, Овражная, 8	f	medium
71367	80842	1372	Самарская область, Ставропольский район, поселок Приморский, Советская, 10	f	large
70900	80222	583	Самарская область, Ставропольский район, поселок Прибрежный, Юности, 2А	f	large
70899	80221	582	Самарская область, Ставропольский район, поселок Прибрежный, Труда, 8А	f	large
70903	80224	586	Самарская область, Ставропольский район, поселок Прибрежный, Звездная, 13	f	large
70902	80224	585	Самарская область, Ставропольский район, поселок Прибрежный, Звездная, 13	f	large
70901	80223	584	Самарская область, Ставропольский район, поселок Прибрежный, Звездная, 11А	f	large
71365	80840	1370	Самарская область, Ставропольский район, село Подстепки, Советская, 1А	f	large
71366	80841	1371	Самарская область, Ставропольский район, село Подстепки, Набережная, 71А	f	large
117454	80838	1368	Самарская область, Ставропольский район, село Пискалы, Школьная, 8	f	small
71364	80837	1367	Самарская область, Ставропольский район, село Пискалы, Дружбы, 9	f	large
117455	80839	1369	Самарская область, Ставропольский район, село Осиновка, Лазарева, 2	f	small
117448	80823	1354	Самарская область, Ставропольский район, село Новая Васильевка, Советская, 72Б	f	medium
117447	80822	1353	Самарская область, Ставропольский район, село Новая Васильевка, Садовая, 93Б	f	small
117452	80835	1365	Самарская область, Ставропольский район, село Новая Бинарадка, Центральная, 36А	f	medium
71363	80834	1364	Самарская область, Ставропольский район, село Нижнее Санчелеево, Красноармейская, 25	f	large
117451	80833	1363	Самарская область, Ставропольский район, село Мусорка, Школьная, 20В	f	medium
71362	80832	1362	Самарская область, Ставропольский район, село Мусорка, Молодежная, 1А	f	large
71360	80828	1358	Самарская область, Ставропольский район, село Луначарский, Злобина, 3	f	large
117449	80825	1356	Самарская область, Ставропольский район, село Лопатино, Советская, 32	f	small
117453	80836	1366	Самарская область, Ставропольский район, село Кирилловка, Советская, 21	f	medium
71227	95091	974	Самарская область, Ставропольский район, поселок Зольное, Первомайская, 2А	f	large
71668	80830	1360	Самарская область, Ставропольский район, село Жигули, Центральная, 4	f	large
71359	80826	1357	Самарская область, Ставропольский район, село Выселки, Победы, 55	f	large
117460	80852	1382	Самарская область, Ставропольский район, село Верхний Сускан, Школьная, 44	f	small
71361	80829	1359	Самарская область, Ставропольский район, село Верхние Белозерки, Мира, 7	f	large
71358	80824	1355	Самарская область, Ставропольский район, село Верхнее Санчелеево, Кооперативная, 2	f	large
117450	80831	1361	Самарская область, Ставропольский район, село Валы, Молодежная, 8	f	small
117446	80820	1351	Самарская область, Ставропольский район, село Большой Рязань, Коммунальная, 26А	f	medium
117457	80848	1378	Самарская область, Ставропольский район, село Березовый Солонец, Советская, 39	f	small
117445	80819	1350	Самарская область, Ставропольский район, село Бахилово, Бахиловская, 2А	f	medium
117266	80480	1126	Самарская область, Ставропольский район, село Александровка, Центральная, 48	t	small
71356	80818	1349	Самарская область, Ставропольский район, село Александровка, Фабричная, 31	f	large
71368	80843	1373	Самарская область, Ставропольский, село Тимофеевка, Школьная, 54	f	large
70794	80091	414	Самарская область, Сергиевский район, село Черновка, Новостроевская, 13	f	large
117085	80082	404	Самарская область, Сергиевский район, село Чекалино, Советская, 49а	f	small
117077	80067	387	Самарская область, Сергиевский район, село Успенка, Полевая, 39	t	small
70788	80073	394	Самарская область, Сергиевский район, поселок Суходол, Школьная, 68	f	large
70787	80072	393	Самарская область, Сергиевский район, поселок Суходол, Суворова, 118	f	large
70786	80071	392	Самарская область, Сергиевский район, поселок Суходол, Пушкина, 2	f	large
70785	80070	391	Самарская область, Сергиевский район, поселок Суходол, Мира, 12	f	large
70789	80074	395	Самарская область, Сергиевский район, село Сургут, Сквозная, 35	f	large
70790	80075	396	Самарская область, Сергиевский район, село Сургут, Первомайская, 12А	f	large
117089	80085	408	Самарская область, Сергиевский район, село Старое Якушкино, Центральная, 6	f	small
117075	80061	382	Самарская область, Сергиевский район, село Старая Дмитриевка, Центральная, 15	f	small
117087	80083	406	Самарская область, Сергиевский район, село Спасское, Центральная, 5	f	small
117434	80804	1335	Самарская область, Сергиевский район, село Спасское, Галактионовская, 49	f	medium
117091	80087	410	Самарская область, Сергиевский район, село Сидоровка, Рабочая, 1	f	medium
70793	80078	400	Самарская область, Сергиевский район, село Серноводск, Советская, 61	f	large
70792	80077	399	Самарская область, Сергиевский район, село Серноводск, Вокзальная, 17	f	large
70798	80065	385	Самарская область, Сергиевский район, село Сергиевск, Советская, 66	f	large
70797	80064	384	Самарская область, Сергиевский район, село Сергиевск, Ленина, 15	f	large
70796	80063	383	Самарская область, Сергиевский район, село Сергиевск, Ленина, 66	f	large
70791	95010	397	Самарская область, Сергиевский район, село Светлодольск, Полевая, 1	f	large
117081	80076	398	Самарская область, Сергиевский район, село Нероновка, Центральная, 68а	f	small
117082	80079	401	Самарская область, Сергиевский район, село Мордовская Селитьба, Кооперативная, 48	t	small
117074	80060	381	Самарская область, Сергиевский район, село Липовка, Центральная, 16	f	small
117093	80089	412	Самарская область, Сергиевский район, село Кутузовский, Центральная, 26	f	medium
117094	80090	413	Самарская область, Сергиевский район, село Красный Городок, 3	t	small
117092	80088	411	Самарская область, Сергиевский район, село Красносельское, Школьная, 1	f	medium
117088	80084	407	Самарская область, Сергиевский район, село Кармало-Аделяково, ДК	f	medium
117086	95011	405	Самарская область, Сергиевский район, село Кандабулак, Специалистов, 4 , СДК	f	medium
70795	95009	380	Самарская область, Сергиевский район, село Калиновка, Каськова, 17	f	large
117090	80086	409	Самарская область, Сергиевский район, село Захаркино	f	small
117002	79969	288	Самарская область, Сергиевский район, село Елшанка, Мамаева, 12а	t	medium
117084	80081	403	Самарская область, Сергиевский район, село Елшанка, Кольцова, 1	f	small
117080	80069	390	Самарская область, Сергиевский район, село Воротнее, пер. Почтовый, 5	f	medium
117079	95081	389	Самарская область, Сергиевский район, село Верхняя Орлянка, Советская, 26	t	medium
117076	80066	386	Самарская область, Сергиевский район, село Боровка, Юбилейная, 34	t	small
117083	80080	402	Самарская область, Сергиевский район, село Большая Чесноковка, Центральная, 43	f	small
117078	80068	388	Самарская область, Сергиевский район, село Антоновка, Мичурина, 31а	f	medium
116996	79959	277	Самарская область, Приволжский район, село Федоровка, Юбилейная, 38, кв.1	t	small
117292	80627	1157	Самарская область, Приволжский район, село Федоровка, Первомайская, 74	f	small
117441	80814	1345	Самарская область, Приволжский район, село Федоровка, Интернациональная, 3/а	f	small
117435	80805	1336	Самарская область, Приволжский район, село Томанский, Томана, 1	t	small
117432	80802	1333	Самарская область, Приволжский район, село Степняки, Школьная, 15	f	small
117440	80813	1344	Самарская область, Приволжский район, село Приволжье, Школьная, 7	f	medium
71354	80809	1340	Самарская область, Приволжский район, село Приволжье, Строителей, 44	f	large
117438	80810	1341	Самарская область, Приволжский район, село Приволжье, Специалистов, 12	f	medium
71355	80811	1342	Самарская область, Приволжский район, село Приволжье, Парковая, 16	f	large
117439	80812	1343	Самарская область, Приволжский район, село Приволжье, Мира, 38/г	f	small
117437	80808	1339	Самарская область, Приволжский район, село Озерецкое, Центральная, 19	t	small
116865	81069	1325	Самарская область, Приволжский район, село Обшаровка, Терешковой, 16	f	large
117427	80796	1327	Самарская область, Приволжский район, село Обшаровка, Советская, 91	f	medium
71666	80795	1326	Самарская область, Приволжский район, село Обшаровка, Победы, 10	f	large
71667	80801	1332	Самарская область, Приволжский район, село Новоспасский, Школьная, 1	f	large
117426	80793	1324	Самарская область, Приволжский район, село Нижнепечерское, Сельская, 3А	f	small
117436	80807	1338	Самарская область, Приволжский район, село Нижнеозерецкое, Луговая, 2	t	small
71353	80806	1337	Самарская область, Приволжский район, село Ильмень, Школьная, 4	f	large
117433	80803	1334	Самарская область, Приволжский район, село Заволжье, Школьная, 22	f	medium
117443	80816	1347	Самарская область, Приволжский район, село Давыдовка, Пролетарская, 21	f	small
117430	80799	1330	Самарская область, Приволжский район, село Бестужевка, Победы, 48А	f	small
117429	80798	1329	Самарская область, Приволжский район, село Бестужевка, Елизарова, 53	f	small
117369	80715	1245	Самарская область, Похвистневский район, село Таволжанка, Школьная, 18	f	small
117068	80050	370	Самарская область, Похвистневский район, село Султангулово, Победы, 10	f	small
117073	80058	378	Самарская область, Похвистневский район, село Стюхино, Советская, 27-А	f	small
70783	80056	376	Самарская область, Похвистневский район, село Старый Аманак, Шулайкина, 109	f	large
70784	80059	379	Самарская область, Похвистневский район, село Старопохвистнево, Советская, 63-А	f	large
117072	80057	377	Самарская область, Похвистневский район, село Староганькино, Центральная, 27-А	f	medium
70782	80053	373	Самарская область, Похвистневский район, село Среднее Аверкино, Школьная, 2	f	large
117261	80594	1119	Самарская область, Похвистневский район, село Сосновка	t	small
117065	80046	366	Самарская область, Похвистневский район, село Сосновка, Максима Горького, 12	f	small
117069	80052	372	Самарская область, Похвистневский район, село Северный Ключ, Мира, 8-В	t	small
70781	80051	371	Самарская область, Похвистневский район, село Савруха, Центральная Усадьба, 33	f	large
117067	80049	369	Самарская область, Похвистневский район, село Рысайкино, Ижедерова, 59	f	medium
65331	72818	4009	Пермский край, Чайковский, Мира, 2	f	large
70780	80047	367	Самарская область, Похвистневский район, село Подбельск, Куйбышевская, 123	f	large
117063	80042	361	Самарская область, Похвистневский район, село Передовка, Юбилейная, 2-А	t	small
116907	79800	110	Самарская область, Похвистневский район, село Октябрьский, Кооперативная, 13	f	medium
117056	80034	353	Самарская область, Похвистневский район, село Нугайка, Центральная, 30	t	small
70779	80045	365	Самарская область, Похвистневский район, село Новое Мансуркино, Ленина, 88	f	large
117066	80048	368	Самарская область, Похвистневский район, село Нижнеягодное, Центральная, 15Г	f	small
117070	80054	374	Самарская область, Похвистневский район, село Нижнеаверкино, Терешковой, 13-Б	f	medium
70778	80044	363	Самарская область, Похвистневский район, село Мочалеевка, Г.Тукая, 57	f	large
117062	80041	360	Самарская область, Похвистневский район, село Малый Толкай, Советская, 35	f	medium
70777	80043	362	Самарская область, Похвистневский район, село Малое Ибряйкино, Школьная, 1-А	f	large
117059	80038	357	Самарская область, Похвистневский район, село Кротково, Центральная, 1	f	medium
117057	80036	355	Самарская область, Похвистневский район, село Красные Ключи, Лукьянова, 69-А	f	medium
117060	80039	358	Вологодская область, Вашкинский район, село Исаково	f	small
70776	80035	354	Самарская область, Похвистневский район, село Большой Толкай, Ленина, 93	f	large
117058	80037	356	Самарская область, Похвистневский район, село Большая Ега, Центральная, 38	f	small
117071	80055	375	Самарская область, Похвистневский район, село Ахрат, Ленина, 2	f	small
70775	80033	352	Самарская область, Похвистневский район, село Алькино, Советская, 93-Б	f	large
117061	80040	359	Самарская область, Похвистневский район, село Абдул-Завод, Ленина, 15	t	small
117425	80792	1323	Самарская область, Пестравский район, село Тяглое Озеро, Молодежная, 56	f	small
117419	80782	1313	Самарская область, Пестравский район, село Тростянь, Молодёжная, 11	f	small
117415	80778	1309	Самарская область, Пестравский район, село Тепловка, Чкалова, 5	f	small
117424	80788	1319	Самарская область, Пестравский район, село Пестравка, Октябрьская, 7	f	medium
117423	80787	1318	Самарская область, Пестравский район, село Пестравка, Мира, 1	f	small
71349	80789	1320	Самарская область, Пестравский район, село Пестравка, Крайнюковская, 75	f	large
71351	80791	1322	Самарская область, Пестравский район, село Пестравка, 50 лет Октября, 65	f	large
71350	80790	1321	Самарская область, Пестравский район, село Пестравка, 50 лет Октября, 59	f	large
117420	80783	1314	Самарская область, Пестравский район, село Падовка, Клубная, 3	f	medium
117410	80773	1304	Самарская область, Пестравский район, село Овсянка, Садовая, 1	f	small
117416	80779	1310	Самарская область, Пестравский район, село Мосты, Юбилейная, 11	f	medium
117412	80775	1306	Самарская область, Пестравский район, село Михеевка, Центральная, 2	f	small
117417	80780	1311	Самарская область, Пестравский район, село Михайло-Овсянка, Школьная, 34	f	medium
117418	80781	1312	Самарская область, Пестравский район, село Малоархангельское, Ленина, 27	f	small
117409	80772	1303	Самарская область, Пестравский район, село Майское, Центральная, 11	f	medium
117414	80777	1308	Самарская область, Пестравский район, село Ломовка, Коммунистическая, 8а	f	small
117413	80776	1307	Самарская область, Пестравский район, село Лозовой, Центральная, 5Б	t	small
117411	80774	1305	Самарская область, Пестравский район, село Крюково, Хлеборобов, 21	t	small
117421	80785	1316	Самарская область, Пестравский район, село Красная Поляна, Советская, 2	f	small
117422	80786	1317	Самарская область, Пестравский район, село Идакра, Центральная, 2Б	f	small
117408	80771	1302	Самарская область, Пестравский район, село Высокое, Телеграфная, 23	f	medium
71234	80472	985	Самарская область, Октябрьск городской округ, Октябрьск, переулок Железнодорожный, 11А	f	large
71240	80482	994	Самарская область, Октябрьск городской округ, Октябрьск, Вологина, 7	f	large
117212	80478	991	Самарская область, Октябрьск городской округ, Октябрьск, 3-го Октября, 2	f	medium
70668	79770	79	Самарская область, Новокуйбышевский район, село Маяк, Куйбышева, 2	f	large
116994	79953	271	Самарская область, Новокуйбышевск городской округ, село Семеновка, пер. Школьный, 22 А	f	medium
116903	95008	80	Самарская область, Новокуйбышевск городской округ, село Имени Шмидта, Школьная, 4	f	small
71337	80758	1289	Самарская область, Нефтегорский район, село Утевка, Торговая, 13	f	large
71336	80740	1288	Самарская область, Нефтегорский район, село Утевка, Льва Толстого, 26	f	large
117407	80760	1291	Самарская область, Нефтегорский район, село Трофимовка, Центральная, 2	t	small
117406	80759	1290	Самарская область, Нефтегорский район, село Песчаный Дол, Озёрная, 10	t	small
71345	80768	1299	Самарская область, Нефтегорский район, Нефтегорск, проспект Победы, 1	f	large
71340	80763	1294	Самарская область, Нефтегорский район, Нефтегорск, Школьная, 9	f	large
71339	80762	1293	Самарская область, Нефтегорский район, Нефтегорск, Школьная, 9	f	large
71344	80767	1298	Самарская область, Нефтегорский район, Нефтегорск, Нефтяников, 22	f	large
71342	80765	1296	Самарская область, Нефтегорский район, Нефтегорск, Нефтяников, 35	f	large
71341	80764	1295	Самарская область, Нефтегорский район, Нефтегорск, Нефтяников, 35	f	large
71338	80761	1292	Самарская область, Нефтегорский район, Нефтегорск, Мира, 46	f	large
71347	80770	1301	Самарская область, Нефтегорский район, Нефтегорск, Зеленая, 7	f	large
117401	80753	1283	Самарская область, Нефтегорский район, село Кулешовка, Ленина, 2	f	medium
117399	80751	1281	Самарская область, Нефтегорский район, село Зуевка, Школьная, 1	f	medium
117402	80754	1284	Самарская область, Нефтегорский район, село Ветлянка, Производственная зона	f	small
117398	80750	1280	Самарская область, Нефтегорский район, село Верхняя Домашка, переулок Школьный, 4	t	small
117400	80752	1282	Самарская область, Нефтегорский район, село Верхнесъезжее, Школьная, 1	t	small
71334	80748	1278	Самарская область, Нефтегорский район, село Богдановка, переулок Школьный, 4	f	large
117397	80747	1277	Самарская область, Нефтегорский район, село Бариновка, Чапаевская, 3	f	small
117201	80314	748	Самарская область, Красноярский район, село Шилан, Мира, 58	f	medium
117202	80315	749	Самарская область, Красноярский район, село Чапаево, Центральная, 70	f	small
117196	80309	743	Самарская область, Красноярский район, село Хорошенькое, Центральная, 67	f	medium
117193	80306	740	Самарская область, Красноярский район, село Хилково, Школьная, 2	f	medium
117194	80307	741	Самарская область, Красноярский район, село Хилково, Рабочая, 14	f	medium
117178	80282	716	Самарская область, Красноярский район, село Угловой, Садовая, 4	f	small
117195	80308	742	Самарская область, Красноярский район, село Тростянка, переулок Школьный, 2	t	small
117428	80797	1328	Самарская область, Красноярский район, село Тростянка, Полевая, 18	f	small
117191	80304	738	Самарская область, Красноярский район, село Старый Буян, Центральная, 104	f	medium
117180	80292	726	Самарская область, Красноярский район, село Старосемейкино, Рабочая, 38 б	f	small
117192	80305	739	Самарская область, Красноярский район, село Старая Бинарадка, Фрунзе, 33	f	small
117200	80313	747	Самарская область, Красноярский район, село Светлый Ключ, Центральная, 6	t	small
71017	80299	733	Самарская область, Красноярский район, село Светлое Поле, Советская, 3	f	large
117176	80273	707	Самарская область, Красноярский район, село Русская Селитьба, Школьная, 50	f	medium
70733	79847	165	Самарская область, Красноярский район, поселок Рощинский, Гарнизонный Дом офицеров	f	large
117184	80296	730	Самарская область, Красноярский район, село Новый Буян, Энергетиков, 12	f	small
117183	80295	729	Самарская область, Красноярский район, село Новый Буян, Школьная, 14	f	medium
117182	80294	728	Самарская область, Красноярский район, село Новый Буян, Степная, 20	f	medium
117185	80297	731	Самарская область, Красноярский район, село Новый Буян, Лесной поселок, 1б	f	small
117186	80298	732	Самарская область, Красноярский район, село Новоурайкино, Центральная, 54А	t	small
71007	80289	723	Самарская область, Красноярский район, поселок Новосемейкино, Школьная, 9	f	large
71005	80287	721	Самарская область, Красноярский район, поселок Новосемейкино, Школьная, 12	f	large
71008	80290	724	Самарская область, Красноярский район, поселок Новосемейкино, Советская, 92А	f	large
71009	80291	725	Самарская область, Красноярский район, поселок Новосемейкино, Московская, 1а	f	large
71006	80288	722	Самарская область, Красноярский район, поселок Новосемейкино, Мира, 2	f	large
116921	79860	178	Самарская область, Красноярский район, село Николаевка, Советская, 18	t	small
117187	80300	734	Самарская область, Красноярский район, село Молгачи, Гагарина, 108	t	small
71648	80285	719	Самарская область, Красноярский район, поселок Мирный, Космодемьянской, 10	f	large
71016	80286	720	Самарская область, Красноярский район, поселок Мирный, Коммунистическая, 1	f	large
71015	80284	718	Самарская область, Красноярский район, поселок Мирный, Зои Космодемьянской, 20	f	large
117188	80301	735	Самарская область, Красноярский район, село Малая Царевщина, Набережная, 26	f	medium
117179	80283	717	Самарская область, Красноярский район, село Малая Каменка, Центральная, 10	t	small
117198	80311	745	Самарская область, Красноярский район, село Лопатино, Школьная, 1	f	small
117197	80310	744	Самарская область, Красноярский район, село Кривое Озеро, Победы, 4	t	small
71014	80280	714	Самарская область, Красноярский район, село Красный Яр, Полевая, 5	f	large
71013	80279	713	Самарская область, Красноярский район, село Красный Яр, Пионерская, 63	f	large
117199	80312	746	Самарская область, Красноярский район, село Конезавод, Каштановая, 7	f	small
71011	80276	710	Самарская область, Красноярский район, село Коммунарский, Центральная, 13	f	large
117189	80302	736	Самарская область, Красноярский район, село Колодинка, Колодинская, 1	f	small
117177	80277	711	Самарская область, Красноярский район, село Калиновка, Школьная, 10	t	small
117190	80303	737	Самарская область, Красноярский район, село Екатериновка, Шоссейная, 25	f	medium
117444	80817	1348	Самарская область, Красноярский район, село Екатериновка, Центральная, 23	f	medium
71010	80274	708	Самарская область, Красноярский район, поселок Волжский, Князева, 62	f	large
71646	80275	709	Самарская область, Красноярский район, поселок Волжский, Жилгородок, 25, Жилгородок, 25	f	large
117181	80293	727	Самарская область, Красноярский район, село Водино, Рабочая, 34А	t	small
117175	80272	706	Самарская область, Красноярский район, село Большая Раковка, Комсомольская, 75	f	medium
117174	80271	705	Самарская область, Красноярский район, село Большая Каменка, Центральная, 37	f	medium
70898	80220	581	Самарская область, Красноярский район, поселок Береза, Лесная, 8	f	large
71012	80278	712	Самарская область, Красноярский район, село Белозерка, Дзержинского, 27	f	large
71308	80560	1085	Самарская область, Красноярский район, село Алексеевка, Комсомольская, 6а	f	large
70886	80209	567	Самарская область, Красноглинский район, поселок Управленческий, Сергея Лазо, 23А	f	large
70896	80218	579	Самарская область, Красноглинский район, поселок Красная Глинка, квартал 4, Детская школа искусств №15	f	large
117396	80746	1276	Самарская область, Красноармейский район, село Чапаевский, Набережная, 27	f	medium
117391	80741	1271	Самарская область, Красноармейский район, село Софинский, Молодежная, 25	f	small
117385	80733	1264	Самарская область, Красноармейский район, село Павловка, Молодежная, 12	f	small
117310	80645	1175	Самарская область, Красноармейский район, село Новопавловка, Советская, 37	f	medium
117389	80737	1268	Самарская область, Красноармейский район, село Новопавловка, Первомайская, 9	t	small
117392	80742	1272	Самарская область, Красноармейский район, село Новая-Вязовка, Самарская, 17	t	small
117379	80727	1258	Самарская область, Красноармейский район, село Медведевский, Победы, 32	t	small
117373	80721	1252	Самарская область, Красноармейский район, село Любицкий, Главная, 13	f	small
117378	80726	1257	Самарская область, Красноармейский район, село Любимовка, Мира, 16	t	small
71333	80738	1269	Самарская область, Красноармейский район, село Ленинский, площадь Центральная, 2	f	large
117381	80729	1260	Самарская область, Красноармейский район, село Куйбышевский, Советская, 9	f	medium
117383	80731	1262	Самарская область, Красноармейский район, село Криволучье-Ивановка, Центральная, 18А	t	small
71330	80718	1248	Самарская область, Красноармейский район, село Красноармейское, Центральная, 1	f	large
71332	95022	1250	Самарская область, Красноармейский район, село Красноармейское, Кирова, 91	t	large
71331	80719	1249	Самарская область, Красноармейский район, село Красноармейское, Кирова, 38	f	large
117390	80739	1270	Самарская область, Красноармейский район, село Кочетковский, переулок Школьный, 3	t	small
117395	80745	1273	Самарская область, Красноармейский район, село Колывань, Советская, 2	f	medium
117387	80735	1266	Самарская область, Красноармейский район, село Колыбеловка, Космическая, 17	t	small
117380	80728	1259	Самарская область, Красноармейский район, село Колокольцовка, Школьная, 8	t	small
117386	80734	1265	Самарская область, Красноармейский район, село Кировский, Кирова, 17	f	medium
117394	80744	1275	Самарская область, Красноармейский район, село Каменный Брод, Центральная, 30	t	small
117376	80724	1255	Самарская область, Красноармейский район, село Дубовка, Центральная, 18 а	t	small
117393	80743	1274	Самарская область, Красноармейский район, село Дергачи, Молодёжная, 9	t	medium
117384	80732	1263	Самарская область, Красноармейский район, село Гражданский, Советская, 67	f	small
117374	80722	1253	Самарская область, Красноармейский район, село Волчанка, Советская, 51Б	f	small
117388	80736	1267	Самарская область, Красноармейский район, село Братский	t	small
117375	80723	1254	Самарская область, Красноармейский район, село Арсентьевка, Ленина, 5	f	small
117382	80730	1261	Самарская область, Красноармейский район, село Андросовка, Молодежная, 3	t	small
117377	80725	1256	Самарская область, Красноармейский район, село Алексеевский, Читателей, 1	t	small
117028	80005	324	Самарская область, Кошкинский район, село Ягодный, Центральная, 14	f	small
117050	80027	346	Самарская область, Кошкинский район, село Юмратка, Большая, 56	t	small
117033	80010	329	Самарская область, Кошкинский район, село Шпановка, Специалистов, 1	f	small
117029	80006	325	Самарская область, Кошкинский район, село Четыровка, Центральная, 31	f	small
117037	80014	333	Самарская область, Кошкинский район, село Тенеево, Центральная, 38	f	small
117051	80028	347	Самарская область, Кошкинский район, село Степная Шентала, Центральная, 41	f	small
117047	80024	343	Самарская область, Кошкинский район, село Старое Юреево, Центральная, 71А	t	small
117053	80030	349	Самарская область, Кошкинский район, село Старое Фейзуллово, Озёрная, 45А	t	small
117044	80021	340	Самарская область, Кошкинский район, село Старое Максимкино, Школьная, 3, ДК	f	medium
117049	80026	345	Самарская область, Кошкинский район, село Старая Кармала	t	small
117035	80012	331	Самарская область, Кошкинский район, село Старая Ивановка, Центральная, 2	f	small
117036	80013	332	Самарская область, Кошкинский район, село Русская Васильевка, Луговая, 1	f	small
117032	80009	328	Самарская область, Кошкинский район, село Рахмановка, Школьная, 6а	f	small
70773	80001	320	Самарская область, Кошкинский район, село Погрузная, Пионерская, 3	f	large
70774	80002	321	Самарская область, Кошкинский район, село Орловка, Октябрьская, 50	f	large
117038	80015	334	Самарская область, Кошкинский район, село Новое Фейзуллово, Центральная, 45	t	small
117046	80023	342	Самарская область, Кошкинский район, село Новая Кармала, Рабочая, 38	f	small
117031	80008	327	Самарская область, Кошкинский район, село Нижняя Быковка, Центральная, 10Г	f	medium
117027	80004	323	Самарская область, Кошкинский район, село Надеждино, Центральная, 61	f	medium
117048	80025	344	Самарская область, Кошкинский район, село Моховой, Лесная, 14	t	small
117039	80016	335	Самарская область, Кошкинский район, село Мамыково, Центральная, 24	f	small
117045	80022	341	Самарская область, Кошкинский район, село Малое Максимкино, Полевая, 18	f	small
117034	80011	330	Самарская область, Кошкинский район, село Левый Салаван, Липовка, 27	t	small
117026	80003	322	Самарская область, Кошкинский район, село Красновка, Школьная	t	small
71640	80000	319	Самарская область, Кошкинский район, село Кошки, квартал 42 Техникум	f	large
70771	79996	315	Самарская область, Кошкинский район, село Кошки, Советская, 30	f	large
117024	79997	316	Самарская область, Кошкинский район, село Кошки, Победы, 5	f	medium
117025	79999	318	Самарская область, Кошкинский район, село Кошки, Первомайская, 94а	f	medium
70772	79998	317	Самарская область, Кошкинский район, село Кошки, Мира, 5	f	large
117041	80018	337	Самарская область, Кошкинский район, село Залесье, Центральная, 20	f	small
117043	80020	339	Самарская область, Кошкинский район, село Ерандаево, Центральная, 19	t	small
117052	80029	348	Самарская область, Кошкинский район, село Городок, Полевая, 17а	f	small
117042	80019	338	Самарская область, Кошкинский район, село Большое Ермаково, Школьная, 1А	f	medium
117040	80017	336	Самарская область, Кошкинский район, село Большая Романовка, Романовская, 62	f	small
117055	80032	351	Самарская область, Кошкинский район, село Большая Константиновка, Центральная, 54	f	small
117054	80031	350	Самарская область, Кошкинский район, село Большая Константиновка, Центральная, 52, ДК	f	small
117030	80007	326	Самарская область, Кошкинский район, село Белоозерная, Придорожная, 9	f	small
117286	80621	1151	Самарская область, Кошкинский район, село Андреевка, Чапаева, 131	f	medium
117238	80563	1088	Самарская область, Кошкинский район, село Алексеевка, Советская, 58	f	medium
117022	79994	313	Самарская область, Клявлинский район, село Чувашское Абдикеево, Центральная, 4	t	small
117021	79993	312	Самарская область, Клявлинский район, село Черный Ключ, Центральная, 2, Школа	f	small
117013	79985	304	Самарская область, Клявлинский район, село Усакла, Молодёжная, 16А, Школа	f	small
117016	79988	307	Самарская область, Клявлинский район, село Старый Маклауш, Школьная, 15, школа	f	medium
117012	79984	303	Самарская область, Клявлинский район, село Старый Байтермиш, Центральная, 20	f	small
117011	79983	302	Самарская область, Клявлинский район, село Старые Сосны, переулок Школьный, 5	f	small
117007	79979	298	Самарская область, Клявлинский район, село Старое Семенкино, Школьная, 1, ДК	f	small
117015	79987	306	Самарская область, Клявлинский район, село Старое Резяпкино, Молодежная, 11 А , Школа	t	medium
117019	79991	310	Самарская область, Клявлинский район, село Русское Добрино, Молодежная, 62	t	small
117005	79973	292	Самарская область, Клявлинский район, Пронино, Центральная, 10, Школа	f	small
117010	79982	301	Самарская область, Клявлинский район, село Новые Сосны	t	small
117008	79980	299	Самарская область, Клявлинский район, село Новое Семенкино, Центральная, 60	t	small
117018	79990	309	Самарская область, Клявлинский район, село Назаровка, Молодёжная, 10, Школа	t	small
70768	79975	294	Самарская область, Клявлинский район, село Клявлино, Советская, 38	f	large
70769	79976	295	Самарская область, Клявлинский район, село Клявлино, Северная, 83	f	large
117006	79978	297	Самарская область, Клявлинский район, село Клявлино, Молодежная, 21, Школа	f	small
117014	79986	305	Самарская область, Клявлинский район, село Ерыкла, Октябрьская, 45а	t	small
117009	79981	300	Самарская область, Клявлинский район, село Ерилкино, Центральная, 23, Школа	t	small
117004	79972	291	Самарская область, Клявлинский район, село Борискино-Игар, Школьная, 10, Школа	t	medium
117020	79992	311	Самарская область, Клявлинский район, село Балахоновка, Молодежная, 2, Школа	f	small
70752	79923	242	Самарская область, Кинельский район, село Чубовка, Нефтяников, 1	f	large
116971	79917	236	Самарская область, Кинельский район, село Филипповка, Озерная, 7	t	small
70621	79729	25	Самарская область, Кинельский район, поселок Усть-Кинельский, Тимирязева, 6	f	large
116967	79912	231	Самарская область, Кинельский район, село Угорье, Школьная, 4	t	small
116974	79924	243	Самарская область, Кинельский район, село Сырейка, Советская, 18	f	medium
116972	79921	240	Самарская область, Кинельский район, село Сколково, Советская, 39	f	medium
116970	79916	235	Самарская область, Кинельский район, село Покровка, Центральная, 120	t	small
116969	79915	234	Самарская область, Кинельский район, село Павловка, Центральная, 77	t	small
70751	79920	239	Самарская область, Кинельский район, село Новый Сарбай, Школьная, 36	f	large
71635	79919	238	Самарская область, Кинельский район, село Малая Малышевка, Молодежная, 21	f	large
116965	79908	227	Самарская область, Кинельский район, село Кутулук, Центральная, 23	t	small
70750	79918	237	Самарская область, Кинельский район, село Красносамарское, Кооперативная, 1	f	large
70749	79913	232	Самарская область, Кинельский район, село Комсомольский, 50 лет Октября, 21	f	large
70748	79911	230	Самарская область, Кинельский район, село Кинельский, Рабочая, 4	f	large
116961	79903	222	Самарская область, Кинельский район, село Казахский, Казахская, 79	t	small
70747	79909	228	Самарская область, Кинельский район, село Домашка, Большая, 1	f	large
116963	79906	225	Самарская область, Кинельский район, село Гурьевка, Центральная, 10-2	t	small
116968	79914	233	Самарская область, Кинельский район, село Грачевка, Пролетарская, 1	t	small
70746	79904	223	Самарская область, Кинельский район, село Георгиевка, Специалистов, 19	f	large
116964	79907	226	Самарская область, Кинельский район, село Георгиевка, Комсомольская, 52	t	small
116973	79922	241	Самарская область, Кинельский район, село Бузаевка, Юбилейная, 57	f	medium
116962	79905	224	Самарская область, Кинельский район, село Большая Малышевка, Школьная, 1	t	small
70745	79902	221	Самарская область, Кинельский район, село Богдановка, Конычева, 12А	f	large
71634	79900	219	Самарская область, Кинельский район, село Бобровка, Кирова, 28 в	f	large
116959	79899	218	Самарская область, Кинельский район, село Алакаевка, Юбилейная, 37	f	medium
70766	79970	289	Самарская область, Кинель-Черкасский район, село Черновка, Школьная, 34	t	large
117001	79966	284	Самарская область, Кинель-Черкасский район, село Чернигово, Солнечная, 1	t	small
116988	79940	259	Самарская область, Кинель-Черкасский район, село Тоузаково, Центральная, 32б	t	small
70764	78719	285	Самарская область, Кинель-Черкасский район, поселок Тимашево, Фрунзе, 90	f	large
71639	79967	286	Самарская область, Кинель-Черкасский район, поселок Тимашево, Революционная, 62	f	large
70765	79968	287	Самарская область, Кинель-Черкасский район, поселок Тимашево, Комсомольская, 31	f	large
116947	79887	206	Самарская область, Кинель-Черкасский район, село Степановка, Сельский клуб 	t	\N
117404	80756	1286	Самарская область, Кинель-Черкасский район, село Семеновка, Центральная, 56, СДК	t	medium
116985	79935	254	Самарская область, Кинель-Черкасский район, село Сарбай, Революционная, 2	f	small
70763	79964	282	Самарская область, Кинель-Черкасский район, село Садгород, Школьная, 34	f	large
117000	79965	283	Самарская область, Кинель-Черкасский район, село Репьевка, Победы, 2	t	small
116999	79963	281	Самарская область, Кинель-Черкасский район, село Пустовалово, Центральная, 29б	t	small
116992	79951	269	Самарская область, Кинель-Черкасский район, село Прокопенки, Гоголя, 17	t	small
116980	79930	249	Самарская область, Кинель-Черкасский район, село Полудни, Солнечная, 55	f	small
70762	79962	280	Самарская область, Кинель-Черкасский район, село Подгорный, Физкультурная, 3	f	large
116997	79960	278	Самарская область, Кинель-Черкасский район, село Новые Ключи, Советская, 36	t	small
116995	79958	276	Самарская область, Кинель-Черкасский район, село Муханово, Школьная, 1в	f	medium
116998	79961	279	Самарская область, Кинель-Черкасский район, село Лозовка, Заречная, 1	t	small
70759	79955	273	Самарская область, Кинель-Черкасский район, село Кротовка, Школьная, 19	f	large
117107	80103	427	Самарская область, Кинель-Черкасский район, село Кротовка, Центральная, 3	f	small
70761	79957	275	Самарская область, Кинель-Черкасский район, село Кротовка, Советская, 1г	f	large
70760	79956	274	Самарская область, Кинель-Черкасский район, село Кротовка, Полевая, 1а	f	large
116982	79932	251	Самарская область, Кинель-Черкасский район, село Коханы, Советская, 32	t	small
70757	79950	268	Самарская область, Кинель-Черкасский район, село Кинель-Черкасы, Советская, 8	f	large
116987	79939	258	Самарская область, Кинель-Черкасский район, село Кинель-Черкасы, Механизаторов, 1р	f	medium
70754	79937	256	Самарская область, Кинель-Черкасский район, село Кинель-Черкасы, Красноармейская, 54	f	large
70755	79942	261	Самарская область, Кинель-Черкасский район, село Кинель-Черкасы, Казакова, 45	f	large
71638	79949	267	Самарская область, Кинель-Черкасский район, село Кинель-Черкасы, Дружбы, 14	f	large
70756	79947	265	Самарская область, Кинель-Черкасский район, село Кинель-Черкассы, Озерная, 1а	f	large
71636	79944	263	Самарская область, Кинель-Черкасский район, село Кинель-Черкассы, Московская, 2е	f	large
116986	79938	257	Самарская область, Кинель-Черкасский район, село Кинель-Черкассы, Красноармейская, 60	f	medium
70753	79936	255	Самарская область, Кинель-Черкасский район, село Кинель-Черкассы, Красноармейская, 50	f	large
116991	79945	264	Самарская область, Кинель-Черкасский район, село Кинель-Черкассы, Калинина, 48	f	medium
116983	79933	252	Самарская область, Кинель-Черкасский район, село Кабановка, Крыгина, 1в	t	medium
116979	79929	248	Самарская область, Кинель-Черкасский район, село Ерзовка, Центральная, 68	f	small
116978	79928	247	Самарская область, Кинель-Черкасский район, село Дубовый Колок, Центральная, 8	t	small
116981	79931	250	Самарская область, Кинель-Черкасский район, село Вязники, Школьная, 1	t	small
116990	79943	262	Самарская область, Кинель-Черкасский район, село Вольная Солянка, Ленинская, 55	f	medium
116984	79934	253	Самарская область, Кинель-Черкасский район, село Богородское, Молодежная, 1	t	medium
117160	80188	691	Самарская область, Кинель-Черкасский район, село Березовка, Школьная, 20	f	medium
117312	80647	1177	Самарская область, Кинель-Черкасский район, село Березовка, Набережная, 20	f	small
116977	79927	246	Самарская область, Кинель-Черкасский район, село Березняки, Первомайская, 5	t	medium
116976	79926	245	Самарская область, Кинель-Черкасский район, село Безречье, Школьная, 1	t	small
116989	79941	260	Самарская область, Кинель-Черкасский район, село Алтухово, Центральная, 33б	t	small
70623	79732	28	Самарская область, Кинель городской округ, поселок Алексеевка, Комсомольская, 15	f	large
70624	79733	29	Самарская область, Кинель городской округ, поселок Алексеевка, Зазина, 12	f	large
116952	79892	211	Самарская область, Камышлинский район, село Чулпан, сельский клуб	t	\N
116946	79886	205	Самарская область, Камышлинский район, село Татарский Байтуган, дом культуры	f	\N
116956	79896	215	Самарская область, Камышлинский район, село Старое Усманово, сельский клуб	f	\N
116953	79893	212	Самарская область, Камышлинский район, село Старое Ермаково, сельский клуб	f	\N
116948	79888	207	Самарская область, Камышлинский район, село Старая Балыкла, Сельский клуб	f	\N
117442	80815	1346	Самарская область, Камышлинский район, село Софьино, Школьная, 1, школа	t	small
116945	79885	204	Самарская область, Камышлинский район, село Русский Байтуган, дом культуры	f	\N
116955	79895	214	Самарская область, Камышлинский район, село Новое Усманово, сельский клуб	f	\N
116954	79894	213	Самарская область, Камышлинский район, село Новое Ермаково, сельский клуб	t	\N
116957	79897	216	Самарская область, Камышлинский район, село Никиткино, сельский клуб	f	\N
116958	79898	217	Самарская область, Камышлинский район, село Неклюдово, Сельский клуб 	t	\N
116951	79891	210	Самарская область, Камышлинский район, село Камышла, школа-интернат	f	\N
116950	79890	209	Самарская область, Камышлинский район, село Камышла, дом культуры	f	\N
116949	79889	208	Самарская область, Камышлинский район, село Камышла, пом ПУ40	f	\N
116942	79882	201	Самарская область, Исаклинский район, село Сухарь Матак, Центральная, 10	t	small
116940	79880	199	Самарская область, Исаклинский район, село Старый Шунгут, Центральная, 33	t	small
116943	79883	202	Самарская область, Исаклинский район, село Старое Вечканово, Советская, 10А, Школа	f	small
116931	79872	190	Самарская область, Исаклинский район, село Старая Чесноковка, Центральная, 10	f	small
116944	79884	203	Самарская область, Исаклинский район, село Сокский, Школьная, 5А	f	medium
116932	79873	191	Самарская область, Исаклинский район, село Смольково, Юбилейная, 60А	f	small
116926	79867	185	Самарская область, Исаклинский район, село Саперкино, Школьная, 23	f	small
116941	79881	200	Самарская область, Исаклинский район, село Самсоновка, Молодежная, 1, Школа	f	small
116925	79866	184	Самарская область, Исаклинский район, село Пригорки, Центральная, 23	t	small
116939	14616	198	Самарская область, Исаклинский район, село Новое Якушкино, Школьная, 12	f	small
116937	79878	196	Самарская область, Исаклинский район, село Новое Ганькино, Советская, 80	f	medium
116933	79874	192	Самарская область, Исаклинский район, село Новая Чесноковка, Колхозная, 5	t	small
116927	79868	186	Самарская область, Исаклинский район, село Мордово-Ишуткино, Советская, 1	f	small
116936	79877	195	Самарская область, Исаклинский район, село Мордово-Аделякова, Куйбышева, 26, Школа	f	small
116928	79869	187	Самарская область, Исаклинский район, село Малое Ишуткино, Центральная, 42	f	small
116923	79864	182	Самарская область, Исаклинский район, село Красный Берег, Молодежная, 2	t	small
116929	79870	188	Самарская область, Исаклинский район, село Ключи, Школьная, 17	f	small
117127	80125	449	Самарская область, Исаклинский район, село Каменка, Управленческая, 1	f	small
70744	79862	180	Самарская область, Исаклинский район, село Исаклы, Первомайская, 4 А	f	large
70743	79861	179	Самарская область, Исаклинский район, село Исаклы, Куйбышевская, 63	f	large
117283	80618	1148	Самарская область, Исаклинский район, село Ивановка, Новая, 1, здание школы	f	small
116930	79871	189	Самарская область, Исаклинский район, село Зеленовский, Школьная, 37	t	small
116924	79865	183	Самарская область, Исаклинский район, село Два Ключа, Новая, 5	f	small
116938	79879	197	Самарская область, Исаклинский район, село Ганькин Матак, Советская, 34	t	small
116935	79876	194	Самарская область, Исаклинский район, село Большое Микушкино, Октябрьская, 16, Школа	f	medium
116934	79875	193	Самарская область, Исаклинский район, село Большое Микушкино, Советская, 102	f	medium
116922	79863	181	Самарская область, Исаклинский район, село Багряш, Лесная, 6	f	small
117172	80269	703	Самарская область, Елховский район, село Теплый Стан, Школьная, 15	f	small
117170	80267	701	Самарская область, Елховский район, село Сухие Аврали, Советская, 16	f	small
117169	80266	700	Самарская область, Елховский район, село Никитинка, Школьная, 19	f	small
117168	80266	699	Самарская область, Елховский район, село Никитинка, Школьная, 19	f	small
117167	80266	698	Самарская область, Елховский район, село Никитинка, Школьная, 19	f	medium
117166	80265	697	Самарская область, Елховский район, село Нижняя Кондурча, Школьная, 9	t	small
117165	80250	696	Самарская область, Елховский район, село Нижняя Кондурча, Школьная, 9	f	small
117164	80250	695	Самарская область, Елховский район, село Нижняя Кондурча, Школьная, 9	f	medium
117171	80268	702	Самарская область, Елховский район, село Мулловка, Школьная, 43	t	small
117161	80201	692	Самарская область, Елховский район, село Кубань-Озеро, Комсомольская, 36, ДК	t	small
117162	80236	693	Самарская область, Елховский район, село Красные Дома, Победы, 3	f	medium
117159	80175	690	Самарская область, Елховский район, село Елховка, Школьная, 8	f	small
71004	80175	689	Самарская область, Елховский район, село Елховка, Школьная, 8	f	large
117173	80270	704	Самарская область, Елховский район, село Борма, Школьная, 69	f	small
116919	79846	164	Самарская область, Волжский район, село Яблоновый Овраг, Николая Наумова, 29	f	medium
71633	79858	177	Самарская область, Волжский район, село Черноречье, Победы, 6, Чернореченская средняя школа	f	large
132325	79857	176	Самарская область, Волжский район, село Черновский, Школьная, 14	f	\N
71632	79856	175	Самарская область, Волжский район, село Сухая Вязовка, Советская, 1а, Сухо-Вязовская средняя школа	f	large
70739	79853	171	Самарская область, Волжский район, поселок Стройкерамика, Народная, ОУ Смышляевская СОШ №1	f	large
116920	79848	166	Самарская область, Волжский район, село Спиридоновка, Школьная, 1	f	medium
116918	79843	161	Самарская область, Волжский район, село Самарский, Молодёжная, 6	f	small
116915	79839	157	Самарская область, Волжский район, село Ровно-Владимировка, Центральная, 20, школа	f	medium
70731	79844	162	Самарская область, Волжский район, село Просвет, Самарская, 4	f	large
70737	79851	169	Самарская область, Волжский район, Поселок Смышляевка, Ново-Садовая, МОУ Смышляевская ООШ №2	f	large
70732	79845	163	Самарская область, Волжский район, село Подъем-Михайловка, Советская, 78	f	large
70726	79832	150	Самарская область, Волжский район, поселок Петра-Дубрава, Физкультурная, 6	f	large
70725	79831	149	Самарская область, Волжский район, поселок Петра-Дубрава, Коммунаров, 4	f	large
70724	79831	148	Самарская область, Волжский район, поселок Петра-Дубрава, Коммунаров, 4	f	large
117105	80062	425	Самарская область, Волжский район, село Озерки, Школьная, 2	f	small
71631	79842	160	Самарская область, Волжский район, село Лопатино, Школьная, 1, Лопатинская средняя школа	f	large
116917	79841	159	Самарская область, Волжский район, село Лопатино, Советская, 13, школа	f	medium
70721	79816	145	Самарская область, Волжский район, село Курумоч, проспект Ленина, 1	f	large
70722	78599	146	Самарская область, Волжский район, село Курумоч, Победы, 2б	f	large
70723	78599	147	Самарская область, Волжский район, село Курумоч, Победы, 2б	f	large
116916	79840	158	Самарская область, Волжский район, село Калинка, Советская, 49, школа	f	small
116914	79837	155	Самарская область, Волжский район, село Журавли, Школьная, 1	t	medium
70730	79838	156	Самарская область, Волжский район, село Дубовый Умет, Советская, 111	f	large
117362	80708	1238	Самарская область, Борский район, село Языково, Кооперативная, 87	f	medium
117351	80695	1225	Самарская область, Борский район, село Широченка, Центральная, 65 г	f	small
117371	80717	1247	Самарская область, Борский район, село Усманка, Центральная, 23	f	small
65340	72827	4018	Пермский край, Чайковский, Ленина, 56/1	f	large
117291	80626	1156	Самарская область, Борский район, село Тростянка, Молодежная, 41	f	small
117370	80716	1246	Самарская область, Борский район, село Старая Таволжанка, Восточная, 2	t	small
117365	80711	1241	Самарская область, Борский район, село Соковнинка, Октябрьская, 81	f	small
117352	80696	1226	Самарская область, Борский район, село Покровка, Центральная, 160	f	small
117366	80712	1242	Самарская область, Борский район, село Подсолнечное, Молодежная, 1	f	small
117363	80709	1239	Самарская область, Борский район, село Подгорное, Центральная, 27 б	f	medium
71665	80704	1234	Самарская область, Борский район, село Новый Кутулук, улица Школьная, 8	f	large
117364	80710	1240	Самарская область, Борский район, село Новогеранькино, Молодежная, 101 а	f	small
71329	80705	1235	Самарская область, Борский район, село Новоборский, переулок Строителей, 3	f	large
117361	80707	1237	Самарская область, Борский район, село Новая Покровка, Звездная, 13	f	small
117355	80699	1229	Самарская область, Борский район, село Неприк, Садовая, 24А	f	small
71348	80784	1315	Самарская область, Борский район, село Марьевка, Пенькова, 33	f	large
117349	80688	1218	Самарская область, Борский район, село Лесной, Центральная, 63	f	small
117359	80703	1233	Самарская область, Борский район, село Коноваловка, Нижне-Ленинская, 8	f	medium
117358	80702	1232	Самарская область, Борский район, село Имени Клары Цеткин, Центральная, 71А	f	small
117357	80701	1231	Самарская область, Борский район, село Заплавное, Любимовка, 25А	f	medium
71645	80167	688	Самарская область, Борский район, село Елховка, Советская, 2 Б, ДК	f	large
117354	80698	1228	Самарская область, Борский район, село Долматовка, Молодежная, 8 а	f	small
117368	80714	1244	Самарская область, Борский район, село Гостевка, Луговая, 1	f	small
117350	80694	1224	Самарская область, Борский район, село Гвардейцы, Школьная , 2	f	medium
71357	80821	1352	Самарская область, Борский район, село Васильевка, Школьная, 19	f	large
117123	80121	445	Самарская область, Борский район, село Васильевка, Школьная, 3	f	small
117367	80713	1243	Самарская область, Борский район, село Васильевка, Центральная, 37	f	small
71327	80692	1222	Самарская область, Борский район, село Борское, Степана Разина, 128	f	large
71325	80689	1219	Самарская область, Борский район, село Борское, Советская, 28	f	large
71326	80690	1220	Самарская область, Борский район, село Борское, Первомайская, 50	f	large
71328	80693	1223	Самарская область, Борский район, село Борское, Ленинградская, 128	f	large
71664	80691	1221	Самарская область, Борский район, село Борское, Ленинградская, 50	f	large
117348	80687	1217	Самарская область, Борский район, село Большое Алдаркино, Молодежная, 22	f	small
117353	80697	1227	Самарская область, Борский район, село Благодаровка, Центральная, 89	f	small
117237	80562	1087	Самарская область, Борский район, село Алексеевка, Школьная, 36	f	medium
117327	80666	1196	Самарская область, Большечерниговский район, село Шумовский, Школьная, 5	f	small
117347	80686	1216	Самарская область, Большечерниговский район, село Утекаево, Степная, 24/2	f	small
117329	80668	1198	Самарская область, Большечерниговский район, село Устряловский, Центральная, 8	t	small
117345	80684	1214	Самарская область, Большечерниговский район, село Украинка, Школьная, 25	f	medium
117334	80673	1203	Самарская область, Большечерниговский район, село Торшиловский, Школьная, 1	f	small
117337	80676	1206	Самарская область, Большечерниговский район, село Сестры, Центральная, 3	f	small
117330	80669	1199	Самарская область, Большечерниговский район, поселок Полянский, Центральная, 34	t	small
117343	80682	1212	Самарская область, Большечерниговский район, село Поляков, Физкультурная, 12	f	medium
117341	80680	1210	Самарская область, Большечерниговский район, село Пензено, Советская, 18	f	small
117322	80659	1189	Самарская область, Большечерниговский район, село Пекилянка, Набережная, 11	f	small
117342	80681	1211	Самарская область, Большечерниговский район, село Новый Камелик, Молодежная, 36	f	small
117323	80660	1190	Самарская область, Большечерниговский район, село Малая Черниговка, Степная, 33	t	small
117338	80677	1207	республика Марий Эл, Медведевский район, поселок Краснооктябрьский	f	medium
117340	80679	1209	Самарская область, Большечерниговский район, село Костино, Школьная, 44	t	small
64838	72464	2918	Пермский край, Пермь, Мира, 4	f	large
117339	80678	1208	Самарская область, Большечерниговский район, село Исток, Школьная, 22	t	small
117346	80685	1215	Самарская область, Большечерниговский район, село Иргизский, Центральная, 22	f	small
117332	80671	1201	Самарская область, Большечерниговский район, село Глушицкий, Центральная, 2А	f	medium
117328	80667	1197	Самарская область, Большечерниговский район, село Восточный, Набережная, 2	f	small
117331	80670	1200	Самарская область, Большечерниговский район, село Верхние Росташи, Школьная, 1	t	small
117324	80661	1191	Самарская область, Большечерниговский район, село Большая Черниговка, Шоссейная, 2	f	medium
71324	80665	1195	Самарская область, Большечерниговский район, село Большая Черниговка, Советская, 103	f	large
117325	80662	1192	Самарская область, Большечерниговский район, село Большая Черниговка, Советская, 107	f	medium
117326	80664	1194	Самарская область, Большечерниговский район, село Большая Черниговка, Полевая, 96	f	medium
71663	80663	1193	Самарская область, Большечерниговский район, село Большая Черниговка, Микрорайон №7	f	large
117333	80672	1202	Самарская область, Большечерниговский район, село Благодатовка, Набережная, 20	f	small
117344	80683	1213	Самарская область, Большечерниговский район, село Алексеевский, Школьная, 11	f	small
117336	80675	1205	Самарская область, Большечерниговский район, село Аверьяновский, Центральная, 44	f	small
117321	80658	1188	Самарская область, Большечерниговский район, село Августовка, Космическая, 1	f	medium
71323	80657	1187	Самарская область, Большечерниговский район, село Августовка, Кооперативная, 8	f	large
117305	80640	1170	Самарская область, Большеглушицкий район, село Южный, Центральная, 8	f	medium
117313	80648	1178	Самарская область, Большеглушицкий район, село Фрунзенский, площадь Ленина, 11	f	medium
117306	80641	1171	Самарская область, Большеглушицкий район, село Таш-Кустьяново, Центральная, 22	f	small
117311	80646	1176	Самарская область, Большеглушицкий район, село Тамбовка, Советская, 26	f	medium
117296	80631	1161	Самарская область, Большеглушицкий район, село Среднедольск, Полевая, 11	f	small
117302	80637	1167	Самарская область, Большеглушицкий район, село Озерск, Заречная, 17	t	small
134674	94999	1172	Самарская область, Большеглушицкий район, село Муратшино, Центральная, 10	f	\N
117300	80635	1165	Самарская область, Большеглушицкий район, село Морша, Центральная, 117	t	small
117297	80632	1162	Самарская область, Большеглушицкий район, село Мокша, Юбилейная, 13	f	medium
117314	80649	1179	Самарская область, Большеглушицкий район, село Малый Каралык, Солнечная, 8	f	small
117303	80638	1168	Самарская область, Большеглушицкий район, село Малороссийский, Центральная, 3	f	small
117308	80643	1173	Самарская область, Большеглушицкий район, село Малая Глушица, Советская, 56	f	medium
117295	80630	1160	Самарская область, Большеглушицкий район, село Малая Вязовка, Степная, 33	t	small
117298	80633	1163	Самарская область, Большеглушицкий район, село Ледяйка, Центральная, 10	f	small
117304	80639	1169	Самарская область, Большеглушицкий район, село Кочевной, Набережная, 2а	t	small
117309	80644	1174	Самарская область, Большеглушицкий район, село Константиновка, Центральная, 7	f	medium
117320	80656	1186	Самарская область, Большеглушицкий район, село Кобзевка, Советская, 38	f	small
117301	80636	1166	Самарская область, Большеглушицкий район, село Верхнедольск, Молодежная, 6	t	small
117299	80634	1164	Самарская область, Большеглушицкий район, село Большая Дергуновка, Советская, 97	f	small
117315	80651	1181	Самарская область, Большеглушицкий район, село Большая Глушица, Чапаевская, 86	f	medium
117316	80652	1182	Самарская область, Большеглушицкий район, село Большая Глушица, Советская, 39	f	medium
117318	80654	1184	Самарская область, Большеглушицкий район, село Большая Глушица, Первомайская, 24	f	medium
71662	80650	1180	Самарская область, Большеглушицкий район, село Большая Глушица, Луговая, 34	f	large
117317	80653	1183	Самарская область, Большеглушицкий район, село Большая Глушица, Кировская, 40	f	medium
117319	80655	1185	Самарская область, Большеглушицкий район, село Большая Глушица, Гагарина, 78	f	medium
117294	80629	1159	Самарская область, Большеглушицкий район, село Александровка, Центральная, 5	f	medium
64821	72464	2901	Пермский край, Пермь, Мира, 4	f	large
117293	80628	1158	Самарская область, Богатовский район, село Центральный, Центральная, 26	f	small
117289	80624	1154	Самарская область, Богатовский район, село Съезжее, Молодежная, 33	f	small
117290	80625	1155	Самарская область, Богатовский район, село Печинено, Советская, 1	f	medium
117335	80674	1204	Самарская область, Богатовский район, село Петровский, Полевая, 24	f	small
117288	80623	1153	Самарская область, Богатовский район, село Максимовка, Октябрьская, 23	f	medium
117284	80619	1149	Самарская область, Богатовский район, село Кураповка	f	medium
117285	80620	1150	Самарская область, Богатовский район, село Заливной, Зеленая, 1	f	medium
117287	80622	1152	Самарская область, Богатовский район, село Виловатое, Советская, 78	f	medium
71321	80616	1146	Самарская область, Богатовский район, село Богатое, Чапаева, 8	f	large
71320	80615	1145	Самарская область, Богатовский район, село Богатое, Комсомольская, 48	f	large
71322	80617	1147	Самарская область, Богатовский район, село Богатое, Заводская, 33	f	large
117282	80614	1144	Самарская область, Богатовский район, село Беловка, Школьная, 27	f	medium
117280	80612	1142	Самарская область, Богатовский район, село Арзамасцевка, Школьная, 24	f	medium
117281	80613	1143	Самарская область, Богатовский район, село Аверьяновка, Молодёжная, 25	f	small
71318	80507	1127	Самарская область, Безенчукский район, станция Звезда, Кооперативная, 7	f	large
117277	80609	1139	Самарская область, Безенчукский район, ст.Мыльная, Вокзальная, 2	t	small
117480	80878	1410	Самарская область, Безенчукский район, село Троицкое, Бр. Краснеевых , 19	f	medium
117278	80610	1140	Самарская область, Безенчукский район, село Прибой, Центральная, 5	f	medium
117276	80608	1138	Самарская область, Безенчукский район, село Преполовенка, Школьная, 17	f	medium
117274	80606	1136	Самарская область, Безенчукский район, село Песочное, Центральная, 48	f	medium
71316	80595	1120	Самарская область, Безенчукский район, поселок Осинки, Маяковского, 17	f	large
71319	80602	1132	Самарская область, Безенчукский район, село Ольгино, Школьная, 1	f	large
117275	80607	1137	Самарская область, Безенчукский район, село Новомихайловка, Центральная, 12	f	small
117268	80154	1129	Самарская область, Безенчукский район, село Никольское, Пролетарская, 2	f	small
117270	80601	1131	Самарская область, Безенчукский район, село Натальино, Школьная, 15	f	medium
117269	72704	1130	Самарская область, Безенчукский район, село Макарьевка, Мира, 48	t	small
117267	72684	1128	Самарская область, Безенчукский район, село Купино, Купинская, 8	f	medium
117272	80604	1134	Самарская область, Безенчукский район, село Красноселки, Центральная, 1	t	small
117265	80600	1125	Самарская область, Безенчукский район, село Кануевка, Центральная, 67а	t	small
117273	80605	1135	Самарская область, Безенчукский район, село Заволжский, Центральная, 2	f	small
71317	80599	1124	Самарская область, Безенчукский район, село Екатериновка, Фрунзе, 42	f	large
71335	80749	1279	Самарская область, Безенчукский район, село Дмитриевка, Советская, 8	f	large
71313	80591	1116	Самарская область, Безенчукский район, поселок Безенчук	f	large
71312	80590	1115	Самарская область, Безенчукский район, поселок Безенчук, Чапаева, 23	f	large
71311	80589	1114	Самарская область, Безенчукский район, поселок Безенчук, Центральная, 89	f	large
71315	80593	1118	Самарская область, Безенчукский район, поселок Безенчук, Тимирязева, 25	f	large
71314	80592	1117	Самарская область, Безенчукский район, поселок Безенчук, Тимирязева, 94	f	large
71309	80586	1111	Самарская область, Безенчукский район, поселок Безенчук, Садовая, 37	f	large
71661	80588	1113	Самарская область, Безенчукский район, поселок Безенчук, Пушкина, 14а	f	large
71310	80587	1112	Самарская область, Безенчукский район, поселок Безенчук, Комсомольская, 82	f	large
117251	80576	1101	Самарская область, Алексеевский район, село Шариповка, Прикотельная, 5	t	small
117241	80566	1091	Самарская область, Алексеевский район, село Субботинский, Пионерская, 18	f	small
117257	80582	1107	Самарская область, Алексеевский район, село Славинка, Советская, 47	t	small
117246	80571	1096	Самарская область, Алексеевский район, село Седыши, Рабочая, 2	t	small
117259	80584	1109	Самарская область, Алексеевский район, село Самовольно-Ивановка, Чапаевская, 27	t	small
64852	64815	2932	Пермский край, Пермь, Мира, 98	f	large
117245	80570	1095	Самарская область, Алексеевский район, село Первокоммунарский, Школьная, 2	t	small
117250	80575	1100	Самарская область, Алексеевский район, село Патровка, Советская, 60	f	medium
117247	80572	1097	Самарская область, Алексеевский район, село Осиповка, Горького, 23	t	small
117258	80583	1108	Самарская область, Алексеевский район, село Ореховка, Кирова, 83	t	small
117242	80567	1092	Самарская область, Алексеевский район, село Новотроевка, Пролетарская, 41	t	small
117239	80564	1089	Самарская область, Алексеевский район, село Несмеяновка, Победы, 33	t	small
117256	80581	1106	Самарская область, Алексеевский район, село Летниково, Захара Вобликова, 150	t	small
117243	80568	1093	Самарская область, Алексеевский район, село Ленинградский, Черемушки, 10-2	t	small
117254	80579	1104	Самарская область, Алексеевский район, село Корнеевка, Центральная, 12А	t	small
117260	80585	1110	Самарская область, Алексеевский район, село Калашиновка, Ленинская, 34	t	small
117240	80565	1090	Самарская область, Алексеевский район, село Ильичевский, Молодёжная, 17А	t	small
117255	80580	1105	Самарская область, Алексеевский район, село Дальний, Школьная, 15	t	small
117253	80578	1103	Самарская область, Алексеевский район, село Герасимовка, Школьная, 12	t	small
117252	80577	1102	Самарская область, Алексеевский район, село Гавриловский, Прибрежная, 11	t	small
117249	80574	1099	Самарская область, Алексеевский район, село Гавриловка, Л.Толстого, 8	t	small
117248	80573	1098	Самарская область, Алексеевский район, село Антоновка, К. Маркса, 2	t	small
117356	80700	1230	Самарская область, Алексеевский район, село Алексеевка, Школьная, 53 в	f	medium
117244	80569	1094	Самарская область, Алексеевский район, село Авангард, Рабочая, 1	f	medium
64753	72425	2759	Пермский край, поселок Юго-Камский, Советская, 114	f	large
65484	72964	4424	Пермский край, поселок Шибаново	t	small
65470	72950	4410	Пермский край, Чусовой, переулок Чунжинский, 6, станция юных натуралистов	f	large
65478	72958	4418	Пермский край, Чусовой, Юности, 12, Профессиональное училище №9	f	large
65475	72956	4415	Пермский край, Чусовой, Чайковского, 16	f	large
65474	72955	4414	Пермский край, Чусовой, Чайковского, 14	f	large
65464	72943	4404	Пермский край, Чусовой, Попова, 91, школа № 9	f	large
65463	72942	4403	Пермский край, Чусовой, Попова, 91, школа №, 9	f	large
65473	72953	4413	Пермский край, Чусовой, Лысьвенская, 99, школа № 13	f	large
65472	72952	4412	Пермский край, Чусовой, Лысьвенская, 99, школа №, 13	f	large
65469	72949	4409	Пермский край, Чусовой, Ленина, 12, школа №, 14	f	large
65468	72948	4408	Пермский край, Чусовой, Ленина, 45, Культурноделовой центр	f	large
65467	72947	4407	Пермский край, Чусовой, Ленина, 45, Культурноделовой центр	f	medium
65465	72944	4405	Пермский край, Чусовой, Ленина, 3	f	large
65462	72941	4402	Пермский край, Чусовой, Крупской, 25, школа № 11	f	medium
65461	72940	4401	Пермский край, Чусовой, Крупской, 25, школа № 11	f	large
65481	72961	4421	Пермский край, Чусовой, Коммунистическая, 2/3, Центр народной культуры	f	large
65471	72951	4411	Пермский край, Чусовой, Камгэс, 16, контора ООО Металлургсервис	t	medium
65483	72963	4423	Пермский край, Чусовой, 50 лет ВЛКСМ, 16, школа №7	f	large
65482	72962	4422	Пермский край, Чусовой, 50 лет ВЛКСМ, 16, школа № 7	f	large
65480	72960	4420	Пермский край, Чусовой, 50 лет ВЛКСМ, 21, Чусовской индустриал.техникум	f	large
65477	72957	4417	Пермский край, Чусовой, 50 лет ВЛКСМ, 11В, школа № 1	f	large
65476	72957	4416	Пермский край, Чусовой, 50 лет ВЛКСМ, 11В, школа № 1	f	large
65479	72945	4419	Пермский край, Чусовой, 50 лет ВЛКСМ, 2/3, школа №5	f	large
65426	72907	4307	Пермский край, Чернушка, Юбилейная, 19	f	large
65435	72915	4316	Пермский край, Чернушка, Коммунистическая, 13	f	large
65350	72836	4028	Пермский край, Чайковский, бульвар Текстильщиков, 6	f	large
65329	72816	4007	Пермский край, Чайковский, Советская, 2А	f	large
65326	72813	4004	Пермский край, Чайковский, Советская, 8/1	f	large
65325	72812	4003	Пермский край, Чайковский, Советская, 49	f	large
65324	72811	4002	Пермский край, Чайковский, Советская, 51	f	large
65323	72811	4001	Пермский край, Чайковский, Советская, 51	f	large
65343	72830	4021	Пермский край, Чайковский, Проспект Победы, 16	f	large
65344	72829	4022	Пермский край, Чайковский, Проспект Победы, 2	f	large
65342	72829	4020	Пермский край, Чайковский, Проспект Победы, 2	f	large
65339	72826	4017	Пермский край, Чайковский, Ленина, 63	f	large
65338	72825	4016	Пермский край, Чайковский, Ленина, 39А	f	large
65336	72823	4014	Пермский край, Чайковский, Карла Маркса, 16/1	f	large
65333	72820	4011	Пермский край, Чайковский, Карла Маркса, 30	f	large
65327	72814	4005	Пермский край, Чайковский, Камская, 3	f	large
65337	72824	4015	Пермский край, Чайковский, Кабалевского, 32	f	large
65332	72819	4010	Пермский край, Чайковский, К.Мракса, 30А	f	large
65335	72822	4013	Пермский край, Чайковский, К.Маркса, 16/1	f	large
65334	72821	4012	Пермский край, Чайковский, К.Маркса, 30А	f	large
65371	72839	4049	Пермский край, Чайковский, Зеленая, 4/4	f	large
65353	72839	4031	Пермский край, Чайковский, Зеленая, 4/4	f	large
65352	72838	4030	Пермский край, Чайковский, Декабристов, 21	f	large
65351	72837	4029	Пермский край, Чайковский, Декабристов, 9	f	large
65341	72828	4019	Пермский край, Чайковский, Вокзальная, 51А	f	large
65330	72817	4008	Пермский край, Чайковский, Вокзальная, 11	f	large
65372	72855	4050	Пермский край, Чайковский, Бажова, 21	f	medium
65328	72815	4006	Пермский край, Чайковский, Азина, 1/1	f	large
65345	72831	4023	Пермский край, Чайковский, 40 лет Октября, 18	f	large
65362	65327	4040	Пермский край, село Фоки, Ленина, 18	f	large
68536	72372	2707	Пермский край, поселок Ферма, Строителей, 2а	f	large
65499	72979	4439	Пермский край, село Успенка, Административное здание Никифоровского сельского поселения	f	small
64544	72217	2117	Пермский край, поселок Уральский, Московская, 14	f	large
64164	71843	913	Пермский край, Углеуральский, Чернышевского, 44	f	large
68544	72422	2756	Пермский край, поселок Сылва, Большевистская, 41	f	large
65226	72724	3615	Пермский край, Соликамск, Черняховского, 20	f	large
65224	72724	3613	Пермский край, Соликамск, Черняховского, 20	f	large
65231	72727	3620	Пермский край, Соликамск, Цифриновича, 29	f	large
65230	72727	3619	Пермский край, Соликамск, Цифриновича, 29	f	large
65213	72715	3602	Пермский край, Соликамск, Фрунзе, 114	f	small
65212	72715	3601	Пермский край, Соликамск, Фрунзе, 114	f	large
65249	72716	3638	Пермский край, Соликамск, Транспортная, 2	f	medium
65214	72716	3603	Пермский край, Соликамск, Транспортная, 2	f	large
68532	72733	3627	Пермский край, Соликамск, Советская, 48	f	large
65234	72729	3623	Пермский край, Соликамск, Сильвинитовая, 20	f	large
65233	72729	3622	Пермский край, Соликамск, Сильвинитовая, 20	f	large
65216	72718	3605	Пермский край, Соликамск, Северная, 31	f	large
65250	72719	3639	Пермский край, Соликамск, Проспект Юбилейный, 15	f	medium
65218	72719	3607	Пермский край, Соликамск, Проспект Юбилейный, 15	f	large
65217	72719	3606	Пермский край, Соликамск, Проспект Юбилейный, 15	f	large
65247	72740	3636	Пермский край, Соликамск, Правды, 27	f	large
65219	72720	3608	Пермский край, Соликамск, Пр.Юбилейный, 49	f	large
68550	72730	3624	Пермский край, Соликамск, Парижской Коммуны, 28	f	large
68551	72730	3625	Пермский край, Соликамск, Парижской Коммуны, 28	f	large
65239	72734	3628	Пермский край, Соликамск, Осокина, 26	f	medium
65253	72738	3642	Пермский край, Соликамск, Набережная, 169	f	large
65252	72738	3641	Пермский край, Соликамск, Набережная, 169	f	large
65245	72738	3634	Пермский край, Соликамск, Набережная, 169	f	small
65244	72738	3633	Пермский край, Соликамск, Набережная, 169	f	large
65221	72722	3610	Пермский край, Соликамск, Молодежная, 11	f	large
65222	72721	3611	Пермский край, Соликамск, Молодежная, 11 А	f	large
65220	72721	3609	Пермский край, Соликамск, Молодежная, 11 А	f	large
65246	72739	3635	Пермский край, Соликамск, Мира, 25	f	medium
68533	72741	3637	Пермский край, Соликамск, Металлургов, 57	f	large
65229	72726	3618	Пермский край, Соликамск, Культуры, 9	f	large
65228	72726	3617	Пермский край, Соликамск, Культуры, 9	f	medium
65232	72728	3621	Пермский край, Соликамск, Карналлитовая, 98	f	large
65241	72736	3630	Пермский край, Соликамск, Калийная, 146	f	large
65227	72725	3616	Пермский край, Соликамск, Добролюбова, 16	f	large
65225	72717	3614	Пермский край, Соликамск, Володарского, 20	f	large
65215	72717	3604	Пермский край, Соликамск, Володарского, 20	f	large
65223	72723	3612	Пермский край, Соликамск, Белинского, 15	f	large
65243	72737	3632	Пермский край, Соликамск, 20 лет Победы, 179	f	large
65242	72737	3631	Пермский край, Соликамск, 20 лет Победы, 179	f	large
65240	72735	3629	Пермский край, Соликамск, 20 лет Победы, 138	f	medium
65251	72732	3640	Пермский край, Соликамск, 20 лет Победы, 94	f	small
65237	72732	3626	Пермский край, Соликамск, 20 лет Победы, 94	f	medium
64746	72418	2752	Пермский край, село Скобелевка, Хохловская, 4	f	medium
65355	72841	4033	Пермский край, поселок Прикамский, Солнечная, 3	f	large
64190	71867	1014	Пермский край, поселок Полазна, 50 лет Октября, 3, МОУ Полазненская СОШ №1	f	large
68541	72403	2738	Пермский край, село Платошино, Школьная, 44	f	large
64879	72495	2959	Пермский край, Пермь, шоссе Космонавтов, 395	f	large
64874	72491	2954	Пермский край, Пермь, шоссе Космонавтов, 195	f	large
64873	72491	2953	Пермский край, Пермь, шоссе Космонавтов, 195	f	large
65078	72626	3335	Пермский край, Пермь, улица Щербакова, 33	f	large
65077	72626	3334	Пермский край, Пермь, улица Щербакова, 33	f	large
65112	72647	3414	Пермский край, Пермь, улица Полины Осипенко, 46	f	large
65111	72647	3413	Пермский край, Пермь, улица Полины Осипенко, 46	f	large
65303	72793	3825	Россия, Пермский край, Пермь, Дзержинский район, улица Полевая, 12	f	small
64905	72512	3020	Пермский край, Пермь, улица Ласьвинская, 6	f	large
64904	72512	3019	Пермский край, Пермь, улица Ласьвинская, 6	f	large
64973	72562	3204	Пермский край, Пермь, улица Ким, 90	f	large
64397	72078	1734	Россия, Омская область, Русско-Полянский район, поселок Новоивановка	t	small
64786	72440	2830	Пермский край, Пермь, проспект Парковый, 27	f	large
64882	72497	2962	Пермский край, Пермь, проспект Декабристов, 35а	f	large
64881	72475	2961	Пермский край, Пермь, проспект Декабристов, 35а	f	large
64837	72475	2917	Пермский край, Пермь, проспект Декабристов, 35а	f	large
64836	72475	2916	Пермский край, Пермь, проспект Декабристов, 35а	f	large
65064	72618	3321	Пермский край, Пермь, маршала Толбухина, 33	f	large
65065	72618	3322	Пермский край, Пермь, маршала Толбухина, 33	f	large
65061	72618	3318	Пермский край, Пермь, маршала Толбухина, 33	f	large
64915	72519	3030	Пермский край, Пермь, маршала Рыбалко, 100	f	large
64867	72489	2947	Пермский край, Пермь, космонавта Леонова, 62А	f	large
64866	72489	2946	Пермский край, Пермь, космонавта Леонова, 62А	f	large
64865	72489	2945	Пермский край, Пермь, космонавта Леонова, 62А	f	large
64856	72484	2936	Пермский край, Пермь, космонавта Леонова, 14	f	large
64855	72484	2935	Пермский край, Пермь, космонавта Леонова, 14	f	large
64854	72483	2934	Пермский край, Пермь, космонавта Леонова, 13а	f	large
65095	72635	3352	Пермский край, Пермь, генерала Черняховского, 51	f	large
65094	72635	3351	Пермский край, Пермь, генерала Черняховского, 51	f	large
65092	72633	3349	Пермский край, Пермь, генерала Черняховского, 72	f	large
65091	72633	3348	Пермский край, Пермь, генерала Черняховского, 72	f	large
112914	72559	3201	Пермский край, Пермь, бульвар Гагарина, 10а	f	\N
65087	72631	3344	Пермский край, Пермь, академика Веденеева, 71	f	large
65086	72631	3343	Пермский край, Пермь, академика Веденеева, 71	f	large
65085	72630	3342	Пермский край, Пермь, академика Веденеева, 54	f	large
65084	72630	3341	Пермский край, Пермь, академика Веденеева, 54	f	large
65083	72630	3340	Пермский край, Пермь, академика Веденеева, 54	f	large
65082	72629	3339	Пермский край, Пермь, академика Веденеева, 26	f	large
64933	72528	3048	Пермский край, Пермь, адмирала Ушакова, 24	f	large
64932	72528	3047	Пермский край, Пермь, адмирала Ушакова, 24	f	large
64919	72521	3034	Пермский край, Пермь, Ямпольская, 16	f	large
64917	72521	3032	Пермский край, Пермь, Ямпольская, 16	f	large
112906	72520	3031	Пермский край, Пермь, Ямпольская, 16	f	\N
65002	72580	3233	Пермский край, Пермь, Юрша, 56а	f	large
65079	72627	3336	Пермский край, Пермь, Щербакова, 44	f	large
64878	72494	2958	Пермский край, Пермь, Шоссе Космонавтов, 194	f	large
64914	72517	3029	Пермский край, Пермь, Шишкина, 18	f	large
64912	72517	3027	Пермский край, Пермь, Шишкина, 18	f	large
65045	72567	3302	Пермский край, Пермь, Читалина, 10	f	large
65044	72567	3301	Пермский край, Пермь, Читалина, 10	f	medium
64902	72509	3017	Пермский край, Пермь, Чистопольская, 11	f	large
64900	72509	3015	Пермский край, Пермь, Чистопольская, 11	f	large
65104	72642	3406	Пермский край, Пермь, Чернышевского, 11	f	large
64864	72488	2944	Пермский край, Пермь, Чердынская, 38а	f	large
65034	72602	3265	Пермский край, Пермь, Целинная, 29б	f	large
65031	72599	3262	Пермский край, Пермь, Харьковская, 21А	f	large
64888	72501	3003	Пермский край, Пермь, Фадеева, 7	f	large
64887	72501	3002	Пермский край, Пермь, Фадеева, 7	f	large
64886	72501	3001	Пермский край, Пермь, Фадеева, 7	f	large
65011	72588	3242	Пермский край, Пермь, Уральская, 78	f	large
65019	72591	3250	Пермский край, Пермь, Уральская, 67	f	large
65018	72591	3249	Пермский край, Пермь, Уральская, 67	f	large
65001	72579	3232	Пермский край, Пермь, Уинская, 3	f	large
64998	72577	3229	Пермский край, Пермь, Уинская, 34	f	large
112916	72582	3236	Пермский край, Пермь, Тургенева, 18/1	f	\N
64686	72361	2618	Пермский край, Пермь, Трудовая, 2	f	small
65180	72682	3482	Пермский край, Пермь, Транспортная, 2	f	large
65076	72625	3333	Пермский край, Пермь, Томская, 30	f	large
65075	72625	3332	Пермский край, Пермь, Томская, 30	f	large
65074	72625	3331	Пермский край, Пермь, Томская, 30	f	large
65073	72625	3330	Пермский край, Пермь, Томская, 30	f	large
64775	72435	2819	Пермский край, Пермь, Толмачева, 18	f	large
64774	72435	2818	Пермский край, Пермь, Толмачева, 18	f	large
64982	72569	3213	Пермский край, Пермь, Техническая, 22	f	large
64984	72569	3215	Пермский край, Пермь, Техническая, 22	f	large
64983	72569	3214	Пермский край, Пермь, Техническая, 22	f	large
64979	72566	3210	Пермский край, Пермь, Техническая, 10	f	large
64978	72566	3209	Пермский край, Пермь, Техническая, 10	f	large
64929	72527	3044	Пермский край, Пермь, Танцорова, 7	f	large
64931	72527	3046	Пермский край, Пермь, Танцорова, 7	f	large
64930	72527	3045	Пермский край, Пермь, Танцорова, 7	f	large
64834	72473	2914	Пермский край, Пермь, Танкистов, 56	f	large
64833	72473	2913	Пермский край, Пермь, Танкистов, 56	f	large
64828	72469	2908	Пермский край, Пермь, Танкистов, 46	f	large
64824	72467	2904	Пермский край, Пермь, Танкистов, 46	f	large
65081	72628	3338	Пермский край, Пермь, Таймырская, 3	f	large
65080	72628	3337	Пермский край, Пермь, Таймырская, 3	f	large
64921	72523	3036	Пермский край, Пермь, Сысольская, 12	f	large
65174	72678	3476	Пермский край, Пермь, Суздальская, 1	f	large
65173	72678	3475	Пермский край, Пермь, Суздальская, 1	f	large
65172	72678	3474	Пермский край, Пермь, Суздальская, 1	f	large
65171	72678	3473	Пермский край, Пермь, Суздальская, 1	f	large
65004	72581	3235	Пермский край, Пермь, Старцева, 1А	f	large
65003	72581	3234	Пермский край, Пермь, Старцева, 1А	f	large
64997	72576	3228	Пермский край, Пермь, Старцева, 9	f	large
64996	72576	3227	Пермский край, Пермь, Старцева, 9	f	large
112920	72600	3263	Пермский край, Пермь, Соликамская, 189	f	\N
65141	72663	3443	Пермский край, Пермь, Солдатова, 43	f	large
64840	72477	2920	Пермский край, Пермь, Советской Армии, 4	f	large
64946	72541	3106	Пермский край, Пермь, Советская, 33	f	large
64945	72540	3105	Пермский край, Пермь, Советская, 56	f	large
64739	72410	2745	Пермский край, Пермь, Советская, 6а	f	small
64962	72552	3122	Пермский край, Пермь, Советская, 102А	f	large
64961	72552	3121	Пермский край, Пермь, Советская, 102А	f	large
64960	72552	3120	Пермский край, Пермь, Советская, 102А	f	large
64827	72468	2907	Пермский край, Пермь, Сивкова, 3б	f	large
64826	72468	2906	Пермский край, Пермь, Сивкова, 3б	f	large
64825	72468	2905	Пермский край, Пермь, Сивкова, 3б	f	large
65110	72646	3412	Пермский край, Пермь, Сибирская, 80	f	large
65109	72645	3411	Пермский край, Пермь, Сибирская, 55	f	large
65108	72645	3410	Пермский край, Пермь, Сибирская, 55	f	large
64950	72545	3110	Пермский край, Пермь, Сибирская, 29	f	large
64949	72544	3109	Пермский край, Пермь, Сибирская, 23	f	large
65140	72662	3442	Пермский край, Пермь, Серебрянский проезд, 9	f	large
65139	72662	3441	Пермский край, Пермь, Серебрянский проезд, 9	f	large
65137	72662	3439	Пермский край, Пермь, Серебрянский проезд, 9	f	large
65138	72662	3440	Пермский край, Пермь, Серебрянский проезд, 9	f	large
64762	72429	2806	Пермский край, Пермь, Связистов, 22	f	large
64761	72429	2805	Пермский край, Пермь, Связистов, 22	f	large
64760	72429	2804	Пермский край, Пермь, Связистов, 22	f	large
112898	72487	2942	Пермский край, Пермь, Свиязева, 17	f	\N
112894	72487	2940	Пермский край, Пермь, Свиязева, 17	f	\N
112892	72487	2939	Пермский край, Пермь, Свиязева, 17	f	\N
112895	72487	2941	Пермский край, Пермь, Свиязева, 17	f	\N
112899	72487	2943	Пермский край, Пермь, Свиязева, 17	f	\N
64935	72530	3050	Пермский край, Пермь, Светлогорская, 5	f	large
64934	72529	3049	Пермский край, Пермь, Светлогорская, 5	f	large
64850	63936	2930	Пермский край, Пермь, Мира, 39	f	large
65177	72679	3479	Пермский край, Пермь, Самаркандская, 102	f	large
65176	72679	3478	Пермский край, Пермь, Самаркандская, 102	f	large
65175	72679	3477	Пермский край, Пермь, Самаркандская, 102	f	large
65056	72615	3313	Пермский край, Пермь, Репина, 9	f	large
65050	72612	3307	Пермский край, Пермь, Репина, 76	f	large
65049	72612	3306	Пермский край, Пермь, Репина, 76	f	large
65048	72612	3305	Пермский край, Пермь, Репина, 76	f	large
65052	72610	3309	Пермский край, Пермь, Репина, 67а	f	large
65051	72610	3308	Пермский край, Пермь, Репина, 67а	f	large
65046	72610	3303	Пермский край, Пермь, Репина, 67а	f	large
65117	72652	3419	Пермский край, Пермь, Революции, 66	f	large
64328	72001	1523	Пермский край, Пермь, Рабочая, 19	f	large
64780	72437	2824	Пермский край, Пермь, Рабочая, 13	f	large
64779	72437	2823	Пермский край, Пермь, Рабочая, 13	f	large
64778	72437	2822	Пермский край, Пермь, Рабочая, 13	f	large
64948	72543	3108	Пермский край, Пермь, Пушкина, 104	f	large
64958	72551	3118	Пермский край, Пермь, Пушкина, 107 А	f	large
64957	72551	3117	Пермский край, Пермь, Пушкина, 107 А	f	large
65106	72643	3408	Пермский край, Пермь, Пушкина, 42к4	f	large
65107	72644	3409	Пермский край, Пермь, Пушкина, 44к2	f	large
64880	72496	2960	Пермский край, Пермь, Промышленная, 46	f	medium
65025	72595	3256	Пермский край, Пермь, Постаногова, 1а	f	large
64788	72441	2832	Пермский край, Пермь, Подлесная, 37	f	large
64787	72441	2831	Пермский край, Пермь, Подлесная, 37	f	large
64891	72503	3006	Пермский край, Пермь, Победы, 46	f	large
64890	72503	3005	Пермский край, Пермь, Победы, 46	f	large
64770	72432	2814	Пермский край, Пермь, Плеханова, 41	f	large
64769	72432	2813	Пермский край, Пермь, Плеханова, 41	f	large
65055	72614	3312	Пермский край, Пермь, Писарева, 35	f	large
64777	72434	2821	Пермский край, Пермь, Петропавловская улица, 185	f	large
64772	72434	2816	Пермский край, Пермь, Петропавловская улица, 185	f	large
64773	72434	2817	Пермский край, Пермь, Петропавловская улица, 185	f	large
64776	72436	2820	Пермский край, Пермь, Петропавловская, 109	f	large
64947	72542	3107	Пермский край, Пермь, Петропавловская, 65	f	large
64941	72536	3101	Пермский край, Пермь, Петропавловская, 7а	f	large
65096	72636	3353	Пермский край, Пермь, Пархоменко, 2	f	large
64817	72461	2861	Пермский край, Пермь, Парковый проспект, 8а	f	large
64798	72446	2842	Пермский край, Пермь, Парковый проспект, 8а	f	large
64797	72446	2841	Пермский край, Пермь, Парковый проспект, 8а	f	large
64795	72446	2839	Пермский край, Пермь, Парковый проспект, 8а	f	large
64794	72445	2838	Пермский край, Пермь, Парковый проспект, 16	f	large
64793	72445	2837	Пермский край, Пермь, Парковый проспект, 16	f	large
64792	72444	2836	Пермский край, Пермь, Парковый проспект, 28	f	large
64791	72444	2835	Пермский край, Пермь, Парковый проспект, 28	f	large
64789	72442	2833	Пермский край, Пермь, Парковый проспект, 28	f	large
64790	72443	2834	Пермский край, Пермь, Парковый проспект, 28	f	large
65136	72661	3438	Пермский край, Пермь, Обвинская, 10	f	large
65135	72660	3437	Пермский край, Пермь, Обвинская, 10А	f	large
112889	72486	2938	Пермский край, Пермь, Норильская, 7	f	\N
65158	72671	3460	Пермский край, Пермь, Новосибирская, 3а	f	large
65157	72671	3459	Пермский край, Пермь, Новосибирская, 3а	f	large
65100	72640	3402	Пермский край, Пермь, Николая Островского, 66	f	large
65099	72639	3401	Пермский край, Пермь, Николая Островского, 46а	f	large
65105	72641	3407	Пермский край, Пермь, Николая Островского, 68	f	large
65103	72641	3405	Пермский край, Пермь, Николая Островского, 68	f	large
65102	72641	3404	Пермский край, Пермь, Николая Островского, 68	f	large
65101	72641	3403	Пермский край, Пермь, Николая Островского, 68	f	large
64857	72485	2937	Пермский край, Пермь, Нефтяников, 54	f	large
64872	72485	2952	Пермский край, Пермь, Нефтяников, 54	f	large
64871	72485	2951	Пермский край, Пермь, Нефтяников, 54	f	large
65123	72654	3425	Пермский край, Пермь, Нестерова, 18	f	large
65122	72654	3424	Пермский край, Пермь, Нестерова, 18	f	large
65121	72654	3423	Пермский край, Пермь, Нестерова, 18	f	large
65144	72665	3446	Пермский край, Пермь, Муромская, 32	f	large
65143	72665	3445	Пермский край, Пермь, Муромская, 32	f	large
65028	72597	3259	Пермский край, Пермь, Мостовая, 6	f	large
65182	72685	3484	Пермский край, Пермь, Мира, 11	f	large
64848	72482	2928	Пермский край, Пермь, Мира, 72	f	large
64759	72428	2803	Пермский край, Пермь, Мильчакова, 22	f	large
64758	72428	2802	Пермский край, Пермь, Мильчакова, 22	f	large
64757	72428	2801	Пермский край, Пермь, Мильчакова, 22	f	large
64815	72460	2859	Пермский край, Пермь, Маяковского, 33	f	large
64800	72448	2844	Пермский край, Пермь, Маяковского, 33	f	large
64799	72448	2843	Пермский край, Пермь, Маяковского, 33	f	large
64920	72522	3035	Пермский край, Пермь, Маршала Рыбалко, 101Б	f	large
64918	72522	3033	Пермский край, Пермь, Маршала Рыбалко, 101Б	f	large
65000	72578	3231	Пермский край, Пермь, Макаренко, 25	f	large
64999	72578	3230	Пермский край, Пермь, Макаренко, 25	f	large
65131	72658	3433	Пермский край, Пермь, Льва Шатрова, 25	f	large
65130	72658	3432	Пермский край, Пермь, Льва Шатрова, 25	f	large
65129	72657	3431	Пермский край, Пермь, Льва Шатрова, 5	f	large
65128	72657	3430	Пермский край, Пермь, Льва Шатрова, 5	f	large
64823	72466	2903	Пермский край, Пермь, Льва Толстого, 12	f	large
64822	72465	2902	Пермский край, Пермь, Льва Толстого, 12	f	large
64955	72549	3115	Пермский край, Пермь, Луначарского, 74/50	f	large
64954	72549	3114	Пермский край, Пермь, Луначарского, 74/50	f	large
64943	72538	3103	Пермский край, Пермь, Луначарского, 24	f	large
64942	72537	3102	Пермский край, Пермь, Луначарского, 4	f	large
65161	72672	3463	Пермский край, Пермь, Лукоянова, 6	f	large
65160	72672	3462	Пермский край, Пермь, Лукоянова, 6	f	large
65159	72672	3461	Пермский край, Пермь, Лукоянова, 6	f	large
112929	72670	3458	Пермский край, Пермь, Лодыгина, 16	f	\N
65147	72666	3449	Пермский край, Пермь, Лодыгина, 48А	f	large
65146	72666	3448	Пермский край, Пермь, Лодыгина, 48А	f	large
65145	72666	3447	Пермский край, Пермь, Лодыгина, 48А	f	large
65142	72664	3444	Пермский край, Пермь, Лодыгина, 34	f	large
64913	72518	3028	Пермский край, Пермь, Липатова, 2	f	large
64804	72452	2848	Пермский край, Пермь, Лепешинской, 43	f	large
64944	72539	3104	Пермский край, Пермь, Ленина, 7	f	large
64820	72463	2864	Пермский край, Пермь, Ленина, 89	f	small
65010	72586	3241	Пермский край, Пермь, Лебедева, 28	f	large
64974	72563	3205	Пермский край, Пермь, Лебедева, 40	f	large
64907	72514	3022	Пермский край, Пермь, Ласьвинская, 18	f	large
64908	72514	3023	Пермский край, Пермь, Ласьвинская, 18	f	large
112903	72505	3009	Пермский край, Пермь, Ласьвинская, 64а	f	\N
64893	72504	3008	Пермский край, Пермь, Ласьвинская, 64а	f	large
64892	72504	3007	Пермский край, Пермь, Ласьвинская, 64а	f	large
64796	72447	2840	Пермский край, Пермь, Куфонина, 12	f	large
64953	72548	3113	Пермский край, Пермь, Куйбышева, 39	f	large
64994	72575	3225	Пермский край, Пермь, Крупской, 92	f	large
64993	72575	3224	Пермский край, Пермь, Крупской, 92	f	large
64992	72574	3223	Пермский край, Пермь, Крупской, 80	f	large
64991	72574	3222	Пермский край, Пермь, Крупской, 80	f	large
64566	72240	2203	Пермский край, Пермь, Крупской, 11, контора Жилкомсервис	f	large
65116	72651	3418	Пермский край, Пермь, Краснофлотская, 15	f	large
65037	72603	3268	Пермский край, Пермь, Красноуральская, 37	f	large
65036	72603	3267	Пермский край, Пермь, Красноуральская, 37	f	large
65035	72603	3266	Пермский край, Пермь, Красноуральская, 37	f	large
65167	72676	3469	Пермский край, Пермь, Краснополянская, 19	f	large
65166	72676	3468	Пермский край, Пермь, Краснополянская, 19	f	large
65115	72650	3417	Пермский край, Пермь, Краснова, 18	f	large
112883	72451	2847	Пермский край, Пермь, Костычева, 33	f	\N
64819	72450	2863	Пермский край, Пермь, Костычева, 33	f	large
64802	72450	2846	Пермский край, Пермь, Костычева, 33	f	large
112888	72476	2919	Пермский край, Пермь, Космонавтов шоссе, 110	f	\N
64567	72241	2204	Пермский край, Пермь, Космонавтов шоссе, 17, КСК Алмазное	f	large
112902	72493	2956	Пермский край, Пермь, Космонавта Беляева, 59	f	\N
65127	72656	3429	Пермский край, Пермь, Комсомольский проспект, 79	f	large
65126	72656	3428	Пермский край, Пермь, Комсомольский проспект, 79	f	large
65125	72656	3427	Пермский край, Пермь, Комсомольский проспект, 79	f	large
65114	72649	3416	Пермский край, Пермь, Комсомольский проспект, 48	f	large
65113	72648	3415	Пермский край, Пермь, Комсомольский проспект, 59	f	large
64952	72547	3112	Пермский край, Пермь, Комсомольский проспект, 29	f	large
65030	72598	3261	Пермский край, Пермь, Колыбалова, 44	f	large
65029	72598	3260	Пермский край, Пермь, Колыбалова, 44	f	large
65134	72659	3436	Пермский край, Пермь, Клары Цеткин, 10	f	large
65133	72659	3435	Пермский край, Пермь, Клары Цеткин, 10	f	large
65132	72659	3434	Пермский край, Пермь, Клары Цеткин, 10	f	large
64771	72433	2815	Пермский край, Пермь, Кирова, 226	f	large
65017	72590	3248	Пермский край, Пермь, Ким, 60	f	large
65013	72590	3244	Пермский край, Пермь, Ким, 60	f	large
65006	72564	3237	Пермский край, Пермь, Ким, 78	f	large
64975	72564	3206	Пермский край, Пермь, Ким, 78	f	large
65009	72585	3240	Пермский край, Пермь, Каспийская, 15	f	large
65008	72585	3239	Пермский край, Пермь, Каспийская, 15	f	medium
112918	72583	3238	Пермский край, Пермь, Каспийская, 15	f	\N
64835	72474	2915	Пермский край, Пермь, Карпинского, 86	f	large
64830	72471	2910	Пермский край, Пермь, Карпинского, 79	f	large
64832	72470	2912	Пермский край, Пермь, Карпинского, 66	f	large
64829	72470	2909	Пермский край, Пермь, Карпинского, 66	f	large
64926	72525	3041	Пермский край, Пермь, Капитанская, 22	f	large
64925	72525	3040	Пермский край, Пермь, Капитанская, 22	f	large
64928	72526	3043	Пермский край, Пермь, Калинина, 19	f	large
64927	72526	3042	Пермский край, Пермь, Калинина, 19	f	large
65063	72619	3320	Пермский край, Пермь, Кабельщиков, 21 А	f	large
65062	72619	3319	Пермский край, Пермь, Кабельщиков, 21 А	f	large
65016	72589	3247	Пермский край, Пермь, Инженерная, 5	f	large
65015	72589	3246	Пермский край, Пермь, Инженерная, 5	f	large
65014	72589	3245	Пермский край, Пермь, Инженерная, 5	f	large
65012	72589	3243	Пермский край, Пермь, Инженерная, 5	f	large
65039	72605	3270	Пермский край, Пермь, Ивана Франко, 43	f	large
65038	72604	3269	Пермский край, Пермь, Ивана Франко, 49	f	large
65054	72613	3311	Пермский край, Пермь, Звенигородская, 11	f	large
65053	72613	3310	Пермский край, Пермь, Звенигородская, 11	f	large
64910	72515	3025	Пермский край, Пермь, Закамская, 39	f	large
64909	72515	3024	Пермский край, Пермь, Закамская, 39	f	large
64901	72510	3016	Пермский край, Пермь, Закамская, 8	f	large
65170	72677	3472	Пермский край, Пермь, Загарьинская, 6	f	large
65169	72677	3471	Пермский край, Пермь, Загарьинская, 6	f	large
65168	72677	3470	Пермский край, Пермь, Загарьинская, 6	f	large
64951	72546	3111	Пермский край, Пермь, Екатерининская, 71	f	large
64977	72565	3208	Пермский край, Пермь, Дружбы, 18	f	large
64976	72565	3207	Пермский край, Пермь, Дружбы, 18	f	large
65021	72592	3252	Пермский край, Пермь, Днепровская, 32	f	large
65020	72592	3251	Пермский край, Пермь, Днепровская, 32	f	large
112886	72462	2862	Пермский край, Пермь, Дзержинского, 3а	f	\N
64875	72492	2955	Пермский край, Пермь, Дениса Давыдова, 13	f	large
112910	72555	3125	Пермский край, Пермь, Дедюкина, 8а	f	\N
112908	72554	3124	Пермский край, Пермь, Дедюкина, 24	f	\N
65151	72667	3453	Пермский край, Пермь, Гусарова, 8	f	large
65150	72667	3452	Пермский край, Пермь, Гусарова, 8	f	large
65149	72667	3451	Пермский край, Пермь, Гусарова, 8	f	large
65148	72667	3450	Пермский край, Пермь, Гусарова, 8	f	large
112882	72431	2812	Пермский край, Пермь, Голева, 8	f	\N
64763	72430	2807	Пермский край, Пермь, Голева, 8	f	large
64767	72430	2811	Пермский край, Пермь, Голева, 8	f	large
64766	72430	2810	Пермский край, Пермь, Голева, 8	f	large
64765	72430	2809	Пермский край, Пермь, Голева, 8	f	large
64764	72430	2808	Пермский край, Пермь, Голева, 8	f	large
65164	72675	3466	Пермский край, Пермь, Героев Хасана, 89	f	large
65165	72675	3467	Пермский край, Пермь, Героев Хасана, 89	f	large
65163	72674	3465	Пермский край, Пермь, Героев Хасана, 109/2а	f	large
65162	72673	3464	Пермский край, Пермь, Героев Хасана, 117	f	large
65090	72632	3347	Пермский край, Пермь, Генерала Доватора, 1	f	large
65089	72632	3346	Пермский край, Пермь, Генерала Доватора, 1	f	large
65088	72632	3345	Пермский край, Пермь, Генерала Доватора, 1	f	medium
65040	72606	3271	Пермский край, Пермь, Гашкова, 11	f	large
65033	72601	3264	Пермский край, Пермь, Гашкова, 45	f	large
64899	72508	3014	Пермский край, Пермь, Гальперина, 6	f	large
64988	72572	3219	Пермский край, Пермь, Гагарина бульвар, 54	f	large
64986	72571	3217	Пермский край, Пермь, Гагарина бульвар, 75а	f	large
64987	72571	3218	Пермский край, Пермь, Гагарина бульвар, 75а	f	large
64985	72570	3216	Пермский край, Пермь, Гагарина бульвар, 50	f	large
64981	72568	3212	Пермский край, Пермь, Гагарина бульвар, 59	f	large
64980	72568	3211	Пермский край, Пермь, Гагарина бульвар, 59	f	large
64972	72561	3203	Пермский край, Пермь, Гагарина бульвар, 37	f	large
64971	72560	3202	Пермский край, Пермь, Гагарина бульвар, 33	f	large
64936	72531	3051	Пермский край, Пермь, Высокая, 6	f	large
65024	72594	3255	Пермский край, Пермь, Восстания, 10	f	large
65023	72594	3254	Пермский край, Пермь, Восстания, 10	f	large
64889	72502	3004	Пермский край, Пермь, Воронежская, 8	f	large
64924	72524	3039	Пермский край, Пермь, Волгодонская, 20а	f	large
64923	72524	3038	Пермский край, Пермь, Волгодонская, 20а	f	large
64922	72524	3037	Пермский край, Пермь, Волгодонская, 20а	f	large
64869	72490	2949	Пермский край, Пермь, Власова, 37	f	large
64868	72490	2948	Пермский край, Пермь, Власова, 37	f	large
64877	72490	2957	Пермский край, Пермь, Власова, 37	f	large
64870	72490	2950	Пермский край, Пермь, Власова, 37	f	large
65066	72620	3323	Пермский край, Пермь, Вильямса, 71	f	large
65060	72616	3317	Пермский край, Пермь, Вильямса, 1	f	large
65059	72616	3316	Пермский край, Пермь, Вильямса, 1	f	large
65057	72616	3314	Пермский край, Пермь, Вильямса, 1	f	large
112926	72669	3456	Пермский край, Пермь, Вижайская, 16	f	\N
112924	72669	3455	Пермский край, Пермь, Вижайская, 16	f	\N
112927	72669	3457	Пермский край, Пермь, Вижайская, 16	f	\N
64809	72455	2853	Пермский край, Пермь, Ветлужская, 62	f	large
64816	72455	2860	Пермский край, Пермь, Ветлужская, 62	f	large
64808	72454	2852	Пермский край, Пермь, Ветлужская, 89	f	large
64807	72454	2851	Пермский край, Пермь, Ветлужская, 89	f	large
64806	72453	2850	Пермский край, Пермь, Ветлужская, 34	f	large
64805	72453	2849	Пермский край, Пермь, Ветлужская, 34	f	large
64811	72456	2855	Пермский край, Пермь, Вагонная, 22	f	large
64810	72456	2854	Пермский край, Пермь, Вагонная, 22	f	large
65093	72634	3350	Пермский край, Пермь, Бушмакина, 26	f	large
65178	72680	3480	Пермский край, Пермь, Братская, 177	f	medium
65027	72596	3258	Пермский край, Пермь, Борчаниновская, 28	f	large
65026	72596	3257	Пермский край, Пермь, Борчаниновская, 28	f	large
64963	72553	3123	Пермский край, Пермь, Борцов Революции, 151	f	large
65152	72668	3454	Пермский край, Пермь, Бородинская, 28	f	large
64785	72439	2829	Пермский край, Пермь, Боровая, 16	f	large
64784	72439	2828	Пермский край, Пермь, Боровая, 16	f	large
64897	72506	3012	Пермский край, Пермь, Богдана Хмельницкого, 13А	f	large
64896	72506	3011	Пермский край, Пермь, Богдана Хмельницкого, 13А	f	large
64895	72506	3010	Пермский край, Пермь, Богдана Хмельницкого, 13А	f	large
65124	72655	3426	Пермский край, Пермь, Белинского, 50	f	large
64847	72481	2927	Пермский край, Пермь, Баумана, 27	f	large
64846	72481	2926	Пермский край, Пермь, Баумана, 27	f	large
64845	72480	2925	Пермский край, Пермь, Баумана, 16	f	large
64841	72478	2921	Пермский край, Пермь, Баумана, 5	f	large
65058	72617	3315	Пермский край, Пермь, Барнаульская, 4	f	large
64995	72573	3226	Пермский край, Пермь, Аркадия Гайдара, 13	f	large
64990	72573	3221	Пермский край, Пермь, Аркадия Гайдара, 13	f	large
64989	72573	3220	Пермский край, Пермь, Аркадия Гайдара, 13	f	large
64906	72513	3021	Пермский край, Пермь, Александра Невского, 25	f	large
64903	72511	3018	Пермский край, Пермь, Автозаводская, 19	f	large
64898	72507	3013	Пермский край, Пермь, Автозаводская, 6	f	large
65022	72593	3253	Пермский край, Пермь, 1905 Года, 2	f	large
65071	72623	3328	Пермский край, Пермь, 1-й Павловский проезд, 2	f	medium
65120	72653	3422	Пермский край, Пермь, Успенского, 9	f	large
65119	72653	3421	Пермский край, Пермь, Успенского, 9	f	large
65118	72653	3420	Пермский край, Пермь, Успенского, 9	f	large
64801	72449	2845	Пермский край, Пермь, Транспортная, 27а	f	large
64783	72438	2827	Пермский край, Пермь, Локомотивная, 1	f	large
64782	72438	2826	Пермский край, Пермь, Локомотивная, 1	f	large
64781	72438	2825	Пермский край, Пермь, Локомотивная, 1	f	large
64565	72239	2202	Пермский край, Пермь, Ленина, 63, администрация Октябрьского ГП	f	large
65068	72622	3325	Пермский край, Пермь, Корсуньская, 31	f	large
65070	72622	3327	Пермский край, Пермь, Корсуньская, 31	f	large
65069	72622	3326	Пермский край, Пермь, Корсуньская, 31	f	large
64911	72516	3026	Пермский край, Пермь, Кировоградская, 53	f	large
64831	72472	2911	Пермский край, Пермь, Карпинского, 79	f	large
64959	72550	3119	Пермский край, Пермь, Екатерининская, 174	f	large
64956	72550	3116	Пермский край, Пермь, Екатерининская, 174	f	large
64175	71852	924	Пермский край, село Парма, К. Маркса, 34	t	small
64671	72346	2603	Пермский край, Очер, Красногвардейская, 54	f	large
64641	72315	2415	Пермский край, Оса, Пугачева, 12	f	large
64654	72328	2428	Пермский край, Оса, М.Горького, 63	f	medium
64638	72306	2412	Пермский край, Оса, М.Горького, 71	f	medium
64633	72306	2407	Пермский край, Оса, М.Горького, 71	f	large
64636	72309	2410	Пермский край, Оса, Ленина, 2	f	medium
64531	72204	2104	Пермский край, Нытва, проспект Ленина, 28а	f	large
64534	72207	2107	Пермский край, Нытва, Чапаева, 22	f	large
64537	72210	2110	Пермский край, Нытва, Луговая, 22	f	large
64208	71885	1032	Пермский край, село Нижний Лух	t	small
64729	72400	2735	Пермский край, село Нижние Муллы, Советская, 10	f	large
64162	71841	911	Пермский край, поселок Нагорнский, Советская, 21	t	small
64521	72194	2044	Пермский край, село Маховляне, Молодежная, 12	f	small
64520	72193	2043	Пермский край, село Матвеево, Центральная, 93	f	small
64726	72398	2732	Пермский край, село Ляды, Мира, 1	f	large
64504	72178	2027	Пермский край, Лысьва, проспект Победы, 19	f	large
64488	72164	2011	Пермский край, Лысьва, проспект Победы, 114	f	large
64486	72162	2009	Пермский край, Лысьва, проспект Победы, 118	f	large
64487	72163	2010	Пермский край, Лысьва, Чапаева, 75	f	large
64506	72179	2029	Пермский край, Лысьва, Чайковского, 3	f	large
64505	72179	2028	Пермский край, Лысьва, Чайковского, 3	f	large
64500	72175	2023	Пермский край, Лысьва, Федосеева, 16	f	large
64499	72174	2022	Пермский край, Лысьва, Федосеева, 25	f	large
64498	72173	2021	Пермский край, Лысьва, Федосеева, 31	f	large
64482	72158	2005	Пермский край, Лысьва, Уральская, 23	f	large
64481	72157	2004	Пермский край, Лысьва, Строительная, 83	f	large
64489	72165	2012	Пермский край, Лысьва, Смышляева, 106	f	large
64493	72169	2016	Пермский край, Лысьва, Революции, 15	f	large
64483	72159	2006	Пермский край, Лысьва, Разина, 2	f	large
64507	72180	2030	Пермский край, Лысьва, Полярников, 7	f	large
64492	72168	2015	Пермский край, Лысьва, Полевая, 91	f	large
64484	72160	2007	Пермский край, Лысьва, Орджоникидзе, 35	f	large
64495	72170	2018	Пермский край, Лысьва, Никулина, 76	f	large
64494	72170	2017	Пермский край, Лысьва, Никулина, 76	f	large
64501	72176	2024	Пермский край, Лысьва, Мичурина, 15	f	large
64497	72172	2020	Пермский край, Лысьва, Мира, 4	f	large
64491	72167	2014	Пермский край, Лысьва, Мира, 45	f	large
64503	72177	2026	Пермский край, Лысьва, Ленина, 36	f	large
64502	72177	2025	Пермский край, Лысьва, Ленина, 36	f	large
64496	72171	2019	Пермский край, Лысьва, Кузьмина, 26	f	large
64490	72166	2013	Пермский край, Лысьва, Коммунаров, 63	f	large
64478	72155	2001	Пермский край, Лысьва, Калинина, 26	f	large
64527	72200	2050	Пермский край, Лысьва, Гайдара, 28	f	large
64480	72156	2003	Пермский край, Лысьва, Быстрых, 29	f	large
64479	72156	2002	Пермский край, Лысьва, Быстрых, 29	f	large
65312	72803	3909	Пермский край, Лысьва, А.Жарова, 1	t	small
64485	72161	2008	Пермский край, Лысьва, Пожарского, 4	f	large
64519	72192	2042	Пермский край, село Ломовка, Школьная, 1	f	small
64402	72087	1739	Пермский край, Ласьва	t	small
64477	72154	1934	Пермский край, Кунгур	f	small
64465	72143	1922	Пермский край, Кунгур, Свободы, 149	f	large
64469	72142	1926	Пермский край, Кунгур, Свободы, 116	f	large
64464	72142	1921	Пермский край, Кунгур, Свободы, 116	f	large
64463	72141	1920	Пермский край, Кунгур, Пугачева, 63	f	large
64447	72125	1904	Пермский край, Кунгур, Просвещения, 12	f	large
64446	72123	1903	Пермский край, Кунгур, Полетаевская, 2	f	large
64444	72123	1901	Пермский край, Кунгур, Полетаевская, 2	f	medium
64445	72124	1902	Пермский край, Кунгур, Плехановский тракт, 3	f	large
64450	72128	1907	Пермский край, Кунгур, Матросская, 15	f	large
64466	72144	1923	Пермский край, Кунгур, МОПРа, 6	f	large
64456	72134	1913	Пермский край, Кунгур, Ленина, 38	f	large
64455	72132	1912	Пермский край, Кунгур, Ленина, 75	f	large
64471	72148	1928	Пермский край, Кунгур, Красная, 38	f	large
64459	72137	1916	Пермский край, Кунгур, Космонавтов, 12	f	large
64476	72153	1933	Пермский край, Кунгур, Кирова, 33а	f	large
64468	72146	1925	Пермский край, Кунгур, Каширина, 17б	f	large
64467	72145	1924	Пермский край, Кунгур, Каширина, 17	f	large
64453	72130	1910	Пермский край, Кунгур, Карла Маркса, 41	f	large
64452	72130	1909	Пермский край, Кунгур, Карла Маркса, 41	f	small
64451	72129	1908	Пермский край, Кунгур, Карла Маркса, 10	f	large
64475	72152	1932	Пермский край, Кунгур, Заводская, 48В	f	large
64461	72139	1918	Пермский край, Кунгур, Гоголя, 34	f	medium
64472	72149	1929	Пермский край, Кунгур, Гоголя, 1	f	large
64473	72150	1930	Пермский край, Кунгур, Гайдара, 21 	f	large
64458	72136	1915	Пермский край, Кунгур, Газеты Искра, 25	f	large
64449	72127	1906	Пермский край, Кунгур, Воровского, 35	f	large
64474	72151	1931	Пермский край, Кунгур, Батальонная, 13	f	medium
64448	72126	1905	Пермский край, Кунгур, Голованова, 106	f	large
68539	72384	2718	Пермский край, поселок Кукуштан, Мира, Школа	f	large
68495	73194	5204	Пермский край, Кудымкар, Строителей, 11	f	large
68504	73204	5214	Пермский край, Кудымкар, Пионерская, 4	f	large
113218	73190	5143	Пермский край, Кудымкар, Пионерская, 4	f	small
68503	73203	5213	Пермский край, Кудымкар, Лихачева, 25	f	large
68497	73197	5207	Пермский край, Кудымкар, Лихачева, 60	f	large
68494	73193	5203	Пермский край, Кудымкар, Леваневского, 12	f	large
68493	73192	5202	Пермский край, Кудымкар, Леваневского, 19	f	large
68505	73205	5215	Пермский край, Кудымкар, Кузнецова, 3	f	large
113219	73195	5205	Пермский край, Кудымкар, Конституции, 1	f	small
68492	73191	5201	Пермский край, Кудымкар, Загородная, 6	f	large
68502	73202	5212	Пермский край, Кудымкар, Горького, 28	f	large
68501	73201	5211	Пермский край, Кудымкар, Гагарина, 1	f	large
68500	73200	5210	Пермский край, Кудымкар, Гагарина, 9	f	large
68499	73199	5209	Пермский край, Кудымкар, Гагарина, 11	f	large
68496	73196	5206	Пермский край, Кудымкар, Гагарина, 21	f	large
68506	73206	5216	Пермский край, Кудымкар, Братчикова, 1	f	large
68498	73198	5208	Пермский край, Кудымкар, 50 лет Октября, 12	f	large
64380	72065	1717	Пермский край, Краснокамск, проспект Маяковского, 9	f	large
64379	72065	1716	Пермский край, Краснокамск, проспект Маяковского, 9	f	large
64378	72064	1715	Пермский край, Краснокамск, проспект Маяковского, 9	f	large
64377	72063	1714	Пермский край, Краснокамск, переулок Банковский, 4а	f	large
64376	72063	1713	Пермский край, Краснокамск, переулок Банковский, 4а	f	large
64403	72067	1740	Пермский край, Краснокамск, Энтузиастов, 15	f	large
64384	72067	1721	Пермский край, Краснокамск, Энтузиастов, 15	f	large
64383	72067	1720	Пермский край, Краснокамск, Энтузиастов, 15	f	large
64374	72061	1711	Пермский край, Краснокамск, Чапаева, 35	f	large
64373	72060	1710	Пермский край, Краснокамск, Чапаева, 33	f	large
64388	72070	1725	Пермский край, Краснокамск, Советская, 29	f	medium
64387	72070	1724	Пермский край, Краснокамск, Советская, 29	f	large
64365	72054	1702	Пермский край, Краснокамск, Рождественский проезд, 5	f	large
64385	72068	1722	Пермский край, Краснокамск, Матросова, 14б	f	large
64386	72069	1723	Пермский край, Краснокамск, Ленина, 16	f	large
64381	72066	1718	Пермский край, Краснокамск, Коммунистическая, 16а	f	large
64382	72066	1719	Пермский край, Краснокамск, Коммунистическая, 16а	f	large
64371	72058	1708	Пермский край, Краснокамск, Комарова, 7	f	large
64375	72062	1712	Пермский край, Краснокамск, Карла Маркса, 4а	f	large
64372	72059	1709	Пермский край, Краснокамск, Карла Маркса, 4б	f	large
64370	72057	1707	Пермский край, Краснокамск, К.Либкнехта, 10	f	large
64369	72057	1706	Пермский край, Краснокамск, К.Либкнехта, 10	f	large
64368	72056	1705	Пермский край, Краснокамск, К.Либкнехта, 10	f	large
64367	72055	1704	Пермский край, Краснокамск, 50 лет Октября, 5	f	large
64366	72055	1703	Пермский край, Краснокамск, 50 лет Октября, 5	f	large
64338	72011	1610	Пермский край, Красновишерск, Толстого, 38 Б	f	large
64329	72002	1601	Пермский край, Красновишерск, Морчанская, 36	f	medium
64330	72003	1602	Пермский край, Красновишерск, Дзержинского, 23	f	large
64337	72010	1609	Пермский край, Красновишерск, Гагарина, 42	f	large
64340	72013	1612	Пермский край, Красновишерск, 1го Мая, 17	t	medium
64709	72381	2715	Пермский край, деревня Кондратово, Карла Маркса, 1 А	f	large
68535	72380	2714	Пермский край, деревня Кондратово, Карла Маркса, 1А, МОУ Кондратовский дом спорта	f	large
64698	72370	2704	Пермский край, деревня Кондратово, Карла Маркса, 1а	f	large
64460	72138	1917	Пермский край, деревня Кондратово, Карла Маркса, 23	f	large
64305	71980	1416	Пермский край, Кизел, Широковская, 97	f	large
64303	71978	1414	Пермский край, Кизел, Фурманова, 4	f	large
64294	71971	1405	Пермский край, Кизел, Советская, 36	f	large
64293	71971	1404	Пермский край, Кизел, Советская, 36	f	large
64290	71968	1401	Пермский край, Кизел, Советская, 18	f	large
64297	71974	1408	Пермский край, Кизел, Пролетарская, 104	f	large
64292	71970	1403	Пермский край, Кизел, Пролетарская, 24	f	large
64295	71972	1406	Пермский край, Кизел, Народной Памяти, 7	f	large
64296	71973	1407	Пермский край, Кизел, Макаренко, 9	f	large
64291	71969	1402	Пермский край, Кизел, Ленина, 16	f	large
64298	71975	1409	Пермский край, Кизел, Крупской, 19	f	large
64300	59754	1411	Пермский край, Кизел, Капитальный, 8	f	large
64299	71976	1410	Пермский край, Кизел, Ашихмина, 29	f	large
63901	71607	117	Пермский край, Ивакинский карьер, Мира, 15	f	small
68466	72996	4505	Пермский край, ЗАТО Звездный, улица Ленина, 10	f	large
68465	72996	4504	Пермский край, ЗАТО Звездный, улица Ленина, 10	f	large
64178	71855	1002	Пермский край, Добрянка, пер. Строителей, 7, МОУ Добрянская СОШ №2	f	large
64180	71857	1004	Пермский край, Добрянка, Энгельса, 9, МОУ Добрянская СОШ №3	f	large
64207	71884	1031	Пермский край, Добрянка, Трудовые резервы, 11	f	medium
64185	71862	1009	Пермский край, Добрянка, Советская, ККЗ Орфей	f	large
64184	71861	1008	Пермский край, Добрянка, Победы, 101	f	large
64177	71854	1001	Пермский край, Добрянка, Переулок Строителей, 6, ДК Союз	f	large
64187	71864	1011	Пермский край, Добрянка, Маяковского, 2, СОШ №1	f	large
64186	71863	1010	Пермский край, Добрянка, Красногвардейская, 50	f	large
64183	71860	1007	Пермский край, Добрянка, Жуковского, 39, ЦДОД Логос	f	large
68549	71859	1006	Пермский край, Добрянка, Жуковского, 37а.	f	large
64181	71858	1005	Пермский край, Добрянка, Жуковского, 26, СОШ №, 4	f	large
64179	71856	1003	Пермский край, Добрянка, Ветеранов Войны, 3, Школа искусств	f	large
64160	71840	909	Пермский край, Губаха, проспект Октябрьский, 9 Б	f	large
64158	71838	907	Пермский край, Губаха, проспект Октябрьский, 14А	f	large
64159	71839	908	Пермский край, Губаха, пр.Октябрьский, 17	f	large
64153	71833	902	Пермский край, Губаха, пр.Ленина, 31	f	large
64152	71832	901	Пермский край, Губаха, пр.Ленина, 14	f	large
64157	71837	906	Пермский край, Губаха, Проспект Ленина, 52	f	large
64155	71835	904	Пермский край, Губаха, Проспект Ленина, 28	f	large
64161	71827	910	Пермский край, Губаха, Парковая, 10	f	large
68548	71836	905	Пермский край, Губаха, Космонавтов, 13	f	large
68547	71834	903	Пермский край, Губаха, Коммунистическая, 11 А	f	large
64163	71842	912	Пермский край, Губаха, Дегтярёва, 34	f	large
64150	71830	813	Пермский край, Гремячинск, Шахтеров, 9	f	large
64144	71825	808	Пермский край, Гремячинск, Ушакова, 45	f	medium
64148	71828	811	Пермский край, Гремячинск, Труда, 20	t	medium
112730	71826	810	Пермский край, Гремячинск, Ленина, 135	f	\N
112727	71826	809	Пермский край, Гремячинск, Ленина, 135	f	\N
64142	71824	806	Пермский край, Гремячинск, Ленина, 223	f	large
64141	71823	805	Пермский край, Гремячинск, Ленина, 193	f	medium
64140	71823	804	Пермский край, Гремячинск, Ленина, 193	f	medium
64138	71821	802	Пермский край, Гремячинск, Ленина, 173	f	medium
64137	71820	801	Пермский край, Гремячинск, Ленина, 135	f	large
64139	71822	803	Пермский край, Гремячинск, Грибоедова, 5	f	large
64121	71806	707	Пермский край, Горнозаводск, Кирова, 6	f	large
64120	71806	706	Пермский край, Горнозаводск, Кирова, 6	f	large
68537	72371	2706	Пермский край, село Гамово, 50 лет Октября, 14	f	large
68538	72371	2705	Пермский край, село Гамово, 50 лет Октября, 14	f	large
64195	71872	1019	Пермский край, село Ветляны	t	small
64091	71779	615	Пермский край, Верещагино, Ленина, 57а	f	large
64087	71776	611	Пермский край, Верещагино, Ленина, 15	f	large
64086	71775	610	Пермский край, Верещагино, Ленина, 20	f	large
64085	71774	609	Пермский край, Верещагино, К.Маркса, 124	f	large
64077	71766	601	Пермский край, Верещагино, Железнодорожная, 20	f	large
65496	72976	4436	Пермский край, село Валежная	t	small
64038	71726	418	Пермский край, деревня Брод, Зеленая, 2, бывшая школа	t	small
64210	71887	1034	Пермский край, поселок Бор-Ленва	t	small
64652	72326	2426	Пермский край, Богомягково, Центральная, 5	f	small
64695	72368	2701	Пермский край, село Бершеть, Школьная, 9	f	large
64001	71695	347	Пермский край, Березники, Юбилейная, 139	f	large
64013	71695	359	Пермский край, Березники, Юбилейная, 139	f	large
63996	71691	342	Пермский край, Березники, Юбилейная, 88	f	large
63998	71691	344	Пермский край, Березники, Юбилейная, 88	f	large
63991	71687	337	Пермский край, Березники, Юбилейная, 78	f	large
63990	71686	336	Пермский край, Березники, Юбилейная, 32	f	large
64015	71704	361	Пермский край, Березники, Черняховского, 73	f	large
68545	71668	310	Пермский край, Березники, Химиков, 10	f	large
63963	71667	309	Пермский край, Березники, Химиков, 4	f	large
63957	71661	303	Пермский край, Березники, Тельмана, 12	f	large
63956	71660	302	Пермский край, Березники, Тельмана, 7	f	large
63992	71681	338	Пермский край, Березники, Советский проспект, 71	f	large
63982	71681	328	Пермский край, Березники, Советский проспект, 71	f	large
64006	71699	352	Пермский край, Березники, Свердлова, 126	f	large
64005	71699	351	Пермский край, Березники, Свердлова, 126	f	large
64003	71697	349	Пермский край, Березники, Свердлова, 65	f	large
64014	71697	360	Пермский край, Березники, Свердлова, 65	f	large
63981	71679	327	Пермский край, Березники, Свердлова, 23а	f	large
63979	71679	325	Пермский край, Березники, Свердлова, 23а	f	large
63986	71684	332	Пермский край, Березники, Пятилетки, 106	f	large
63961	71665	307	Пермский край, Березники, Пятилетки, 11	f	large
64007	71693	353	Пермский край, Березники, Потемина, 3	f	large
63999	71693	345	Пермский край, Березники, Потемина, 3	f	large
63972	71673	318	Пермский край, Березники, О. Кошевого, 7	f	large
63971	71673	317	Пермский край, Березники, О. Кошевого, 7	f	large
63985	71683	331	Пермский край, Березники, Набережная, 47	f	large
63984	71683	330	Пермский край, Березники, Набережная, 47	f	large
64011	71702	357	Пермский край, Березники, Мира, 98а	f	large
64010	71701	356	Пермский край, Березники, Мира, 110	f	large
64000	71694	346	Пермский край, Березники, Мира, 56	f	large
63995	71690	341	Пермский край, Березники, Мира, 48	f	large
63994	71690	340	Пермский край, Березники, Мира, 48	f	large
63993	71688	339	Пермский край, Березники, Мира, 30	f	large
64017	71705	363	Пермский край, Березники, Ломоносова, 114	f	large
64016	71705	362	Пермский край, Березники, Ломоносова, 114	f	large
64004	71698	350	Пермский край, Березники, Ломоносова, 125	f	large
63978	71678	324	Пермский край, Березники, Ломоносова, 105	f	large
63976	71677	322	Пермский край, Березники, Ломоносова, 60	f	large
63967	71670	313	Пермский край, Березники, Ломоносова, 115	f	large
63966	71670	312	Пермский край, Березники, Ломоносова, 115	f	large
63960	71664	306	Пермский край, Березники, Ленина проспект, 33	f	large
63974	71675	320	Пермский край, Березники, Л. Толстого, 50	f	large
63997	71692	343	Пермский край, Березники, Комсомольская, 4	f	large
63969	71671	315	Пермский край, Березники, Дощеникова, 4	f	large
63968	71671	314	Пермский край, Березники, Дощеникова, 4	f	large
65194	72696	3505	Пермский край, Березники, Восточная, 1	t	small
63977	71676	323	Пермский край, Березники, В. Бирюковой, 9	f	large
63975	71676	321	Пермский край, Березники, В. Бирюковой, 9	f	large
63965	71669	311	Пермский край, Березники, Аксакова, 18	f	medium
63958	71662	304	Пермский край, Березники, Азотчиков, 18	f	large
63989	71685	335	Пермский край, Березники, 30 лет Победы, 38	f	large
63988	71685	334	Пермский край, Березники, 30 лет Победы, 38	f	large
63987	71685	333	Пермский край, Березники, 30 лет Победы, 38	f	large
64401	72085	1738	Пермский край, село Ананичи, Ананичевский дом досуга	t	small
63886	71593	102	Пермский край, Александровск, Советская, 97	f	medium
63885	71592	101	Пермский край, Александровск, Пионерская, 10	f	medium
63893	71600	109	Пермский край, Александровск, Мехоношина, 19	f	large
63892	71599	108	Пермский край, Александровск, Ленина, 19	f	large
63890	71597	106	Пермский край, Александровск, Ленина, 21	f	large
63891	71598	107	Пермский край, Александровск, Кирова, 39	f	large
63888	71595	104	Пермский край, Александровск, Калинина, 3	f	medium
63889	71596	105	Пермский край, Александровск, Войкова, 20	f	large
63887	71594	103	Пермский край, Александровск, III Интернационала, 32	f	medium
113240	73227	5321	Россия, Тульская область, Тула, поселок Комсомольский	t	small
113245	73233	5403	Пермский край, Юсьвинский район, село Юсьва, Центральная, 2	f	\N
113244	73232	5402	Пермский край, Юсьвинский район, село Юсьва, Красноармейская, 18	f	medium
68509	73231	5401	Пермский край, Юсьвинский район, село Юсьва, Красноармейская, 14	f	large
113253	73239	5409	Пермский край, Юсьвинский район, село Чинагорт, Центральная, 109	f	\N
113269	73247	5419	Пермский край, Юсьвинский район, село Тукачево, Комсомольская, 2, кв., 1	t	\N
113267	73246	5418	Пермский край, Юсьвинский район, село Тимино, Парковая, 9	f	\N
68511	73253	5424	Пермский край, Юсьвинский район, поселок Пожва, Судомеханическая, 9	f	large
68510	73252	5423	Пермский край, Юсьвинский район, поселок Пожва, Ленина, 59	f	large
113259	73243	5413	Пермский край, Юсьвинский район, село Пиканово, Центральная, 62	t	\N
113271	73248	5420	Пермский край, Юсьвинский район, село Они, Центральная, 55	f	small
113254	73240	5410	Пермский край, Юсьвинский район, село Нижняя Волпа, Центральная, 56	f	small
113250	73237	5407	Пермский край, Юсьвинский район, село Мелюхино, Центральная, 7	f	medium
113274	73251	5422	Пермский край, Юсьвинский район, поселок Майкор, Октябрьская, 108	f	medium
113272	73249	5421	Пермский край, Юсьвинский район, поселок Майкор, Ленина, 98	f	small
113260	69437	5414	Пермский край, Юсьвинский район, село Купрос, Школьная, 1	f	\N
113263	73244	5416	Пермский край, Юсьвинский район, село Крохалево, Центральная, 56	f	\N
68470	73010	4614	Пермский край, Юсьвинский район, поселок Комсомольский, Центр досуга	f	large
68469	73009	4613	Пермский край, Юсьвинский район, Комсомольский, Администрация сельского поселения	f	large
65488	72968	4428	Пермский край, Юсьвинский район, село Калино, Трудовая, 12, центр досуга	f	medium
113257	73242	5412	Пермский край, Юсьвинский район, село Доег, Школьная, 3	f	\N
113262	73226	5415	Пермский край, Юсьвинский район, село Большая Мочга, Садовая, 3	t	small
113249	73236	5406	Пермский край, Юсьвинский район, село Бажино, Центральная, 39	f	small
113251	73238	5408	Пермский край, Юсьвинский район, село Архангельское, Центральная, 43	f	medium
113255	73241	5411	Пермский край, Юсьвинский район, село Антипино, Мира, 4	f	medium
113266	73245	5417	Пермский край, Юсьвинский район, село Аксеново, Школьная, 2	f	\N
64264	71944	1302	Пермский край, Юсьвинский район, село Азово, Совхозная, 4	t	small
68508	69285	5303	Пермский край, Юрлинский район, село Юрла, Пионеров, 5	f	large
113221	73207	5301	Пермский край, Юрлинский район, село Юрла, Кузнецова, 20	f	\N
68507	73208	5302	Пермский край, Юрлинский район, село Юрла, Гагарина, 18	f	large
113232	73218	5313	Пермский край, Юрлинский район, село Юм	f	small
113238	73224	5319	Пермский край, Юрлинский район, село Чус	t	small
113233	73219	5314	Пермский край, Юрлинский район, село Чужья	f	small
113243	73230	5324	Пермский край, Юрлинский район, село Чугайнов Хутор	t	small
113229	73215	5310	Пермский край, Юрлинский район, село Усть-Зула	t	small
113241	73228	5322	Свердловская область, Серовский район, поселок Усть-Берёзовка	t	small
113224	73211	5306	Ленинградская область, Лодейное Поле, улица Титова, 1	t	small
113231	73217	5312	Пермский край, Юрлинский район, село Пож	t	small
113239	73225	5320	Пермский край, Юрлинский район, село Петракова	t	small
113225	73212	5307	Пермский край, Юрлинский район, село Остров	t	small
113223	73210	5305	Пермский край, Юрлинский район, село Лопва	t	small
113234	73220	5315	Пермский край, Юрлинский район, село Келич	t	small
113222	73209	5304	Пермский край, Юрлинский район, село Зюздина	t	small
113236	73222	5317	Саратовская область, Саратов, улица Зарубина, 1	t	small
113237	73223	5318	Пермский край, Юрлинский район, село Елога	t	small
113235	73221	5316	Московская область, Воскресенский район, Воскресенск, микрорайон Цемгигант, улица Дубровка, 1/6	f	small
113226	73213	5308	Пермский край, Юрлинский район, село Вятчина	t	small
113230	73216	5311	Пермский край, Юрлинский район, село Верхняя Лобанова	t	small
113228	73214	5309	Пермский край, Юрлинский район, село Большая Половина, Сельский клуб	t	\N
113004	72990	4450	Пермский край, Чусовой городской округ, село Центральный, Клуб	t	small
65501	72981	4441	Пермский край, Чусовой городской округ, село Центральный, МУК Никифоровский ДК	t	small
113001	72986	4446	Пермский край, Чусовой городской округ, село Утес	t	small
65497	72977	4437	Пермский край, Чусовой городской округ, село Сёла, МУК Сёльский КДЦ	f	medium
113056	73059	4708	Пермский край, Чусовой городской округ, село Сёла, Новая, 1	t	small
68460	72987	4447	Пермский край, Чусовой городской округ, поселок Скальный, МУК Скальнинский Дом культуры	f	large
65500	72980	4440	Пермский край, Чусовой городской округ, село Никифорово	f	medium
65491	72971	4431	Пермский край, Чусовой городской округ, село Мульково, Фельдшерскоакушерский пункт	f	small
65487	72967	4427	Пермский край, Чусовой городской округ, поселок Лямино, Первомайская, 11	f	medium
65486	72966	4426	Пермский край, Чусовой городской округ, поселок Лямино, Первомайская, 2, поликлиника	f	large
65485	72965	4425	Пермский край, Чусовой городской округ, поселок Лямино, Мира, 3, контора мастера Ляминского ЖЭУ	t	medium
65493	72973	4433	Пермский край, Чусовой городской округ, село Кутамыш, филиал МУК Комарихинский ДК	t	small
65502	72982	4442	Пермский край, Чусовой городской округ, село Копально	f	medium
65495	72975	4435	Пермский край, Чусовой городской округ, поселок Комарихинский, МУК Комарихинский дом культуры 	f	medium
65494	72974	4434	Пермский край, Чусовой городской округ, поселок Комарихинский, школа № 91	f	medium
65489	72969	4429	Пермский край, Чусовой городской округ, поселок Калино, Заводская, 1А	f	large
113003	72989	4449	Пермский край, Чусовой городской округ, село Всесвятская, МУК Скальнинский Дом культуры	t	medium
68461	72991	4451	Пермский край, Чусовой городской округ, поселок Верхнечусовские Городки, МУК Верхнегородковский Дом культуры	f	large
65498	72978	4438	Пермский край, Чусовой городской округ, поселок Верхнечусовские Городки	f	medium
68459	72983	4443	Пермский край, Чусовой городской округ, село Верхнее Калино, Дом культуры	f	large
65490	72970	4430	Пермский край, Чусовой городской округ, село Вереино, Клуб	f	small
64398	72080	1735	Пермский край, Чусовой городской округ, село Брагино, Дом досуга д.Брагино	t	small
112999	72984	4444	Пермский край, Чусовой городской округ, поселок Бобровка, Фельдшерскоакушерский пункт	t	small
113191	73163	5116	Пермский край, Чусовой городской округ, поселок Березовка, Парковая, 2	f	medium
65434	72914	4315	Пермский край, Чернушинский район, Чернушка, бульвар 48 Стрелковой Бригады, 1	f	large
65433	72913	4314	Пермский край, Чернушинский район, Чернушка, Юбилейная, 10	f	large
65420	72900	4301	Пермский край, Чернушинский район, Чернушка, Пушкина, 4А	f	large
65429	72909	4310	Пермский край, Чернушинский район, Чернушка, Нефтяников, 3	f	large
65425	72905	4306	Пермский край, Чернушинский район, Чернушка, Мира, 36	f	medium
65421	72901	4302	Пермский край, Чернушинский район, Чернушка, Луначарского	f	large
65436	72916	4317	Пермский край, Чернушинский район, Чернушка, Ленина, 133	f	medium
65431	72911	4312	Пермский край, Чернушинский район, Чернушка, Ленина, 42	f	large
65424	72904	4305	Пермский край, Чернушинский район, Чернушка, Ленина, 6	f	large
65427	72908	4308	Пермский край, Чернушинский район, Чернушка, Красноармейская, 96	f	large
65428	72908	4309	Пермский край, Чернушинский район, Чернушка, Красноармейская, 96	f	large
65422	72902	4303	Пермский край, Чернушинский район, Чернушка, Комсомольская, 36	f	large
65432	72912	4313	Пермский край, Чернушинский район, Чернушка, Коммунистическая, 17Б	f	large
65430	72910	4311	Пермский край, Чернушинский район, Чернушка, Коммунистическая, 33	f	large
65438	72910	4319	Пермский край, Чернушинский район, Чернушка, Коммунистическая, 33	f	large
65423	72903	4304	Пермский край, Чернушинский район, Чернушка, Горького, 50	f	large
65459	72938	4340	Пермский край, Чернушинский район, село Тюй, Администрация	f	medium
65457	72936	4338	Пермский край, Чернушинский район, село Трушники, Дом культуры	f	medium
65455	72934	4336	Пермский край, Чернушинский район, село Трун, Администрация	f	medium
65454	72933	4335	Пермский край, Чернушинский район, село Тауш, Администрация	f	large
65453	72932	4334	Пермский край, Чернушинский район, село Сульмаш, Администрация	f	medium
65452	72931	4333	Пермский край, Чернушинский район, село Слудка, Школа	f	medium
65451	72930	4332	Пермский край, Чернушинский район, село Рябки, Администрация	f	large
65447	72926	4328	Пермский край, Чернушинский район, село Павловка, Дом культуры	f	medium
65460	72939	4341	Пермский край, Чернушинский район, село Ореховая Гора, Администрация	f	small
65448	72927	4329	Пермский край, Чернушинский район, село Нижний Козьмяш, Администрация	f	small
64646	72320	2420	Пермский край, Чернушинский район, село Комарово, Школьная, 1	f	small
65265	72753	3709	Пермский край, Чернушинский район, село Ключи, Золина, 59	f	small
64220	71898	1106	Пермский край, Чернушинский район, село Калиновка, Центральная, 10/2	f	small
65439	72918	4320	Пермский край, Чернушинский район, село Зверево, Клуб	f	small
65445	72924	4326	Пермский край, Чернушинский район, село Етыш	f	small
65456	72935	4337	Пермский край, Чернушинский район, село Есаул, Дом культуры	f	small
65458	72937	4339	Пермский край, Чернушинский район, село Емаш-Павлово, Клуб	f	small
65443	72922	4324	Пермский край, Чернушинский район, село Брод,  Клуб	f	medium
65442	72921	4323	Пермский край, Чернушинский район, село Бедряж, Администрация	f	medium
65450	72929	4331	Пермский край, Чернушинский район, село Ашша, Клуб	f	small
65449	72928	4330	Пермский край, Чернушинский район, село Атняшка, Клуб	f	small
65440	72919	4321	Пермский край, Чернушинский район, село Ананьино, Администрация	f	small
65437	72917	4318	Пермский край, Чернушинский район, село Азинский, Буденного, 18	f	large
113005	72992	4452	Пермский край, Чердынский район, село Чусовской, Детский сад №2	t	small
65466	72946	4406	Пермский край, Чердынский район, село Чусовской, Бажова, 17, Конференцзал Вагонного депо	f	medium
65393	72876	4201	Пермский край, Чердынский район, Чердынь, Яборова, 8	f	large
65394	72877	4202	Пермский край, Чердынский район, Чердынь, Успенская, 59	f	large
65395	72878	4203	Пермский край, Чердынский район, Чердынь, Прокопьевская, 83	f	large
65409	72889	4217	Пермский край, Чердынский район, село Чепец, Центральная, клуб	t	small
65407	72887	4215	Пермский край, Чердынский район, село Урол, Вторая, 5	t	small
113128	73110	4913	Пермский край, Чердынский район, поселок Сосновка, Косинская СОШ	t	\N
65406	72886	4214	Пермский край, Чердынский район, село Серегово, Героев, 35	f	small
113106	73094	4825	Пермский край, Чердынский район, село Серебрянка, Набережная, 24а, СОШ	f	\N
65405	72885	4213	Пермский край, Чердынский район, село Рябинино, Ленина, 20	f	large
65404	72884	4212	Пермский край, Чердынский район, село Редикор, Набережная, 30	f	small
112974	72883	4211	Пермский край, Чердынский район, село Пянтег, Набережная, 31	f	small
65415	72895	4223	Пермский край, Чердынский район, село Покча, Мира, 32	f	medium
65411	72891	4219	Пермский край, Чердынский район, село Пильва, Школьная, МОУ Пильвинская школасад	t	small
64422	72104	1819	Пермский край, Чердынский район, село Пильва, Складская, 13	f	small
65396	72879	4204	Пермский край, Чердынский район, поселок Ныроб, Уральская, 13	f	medium
65398	72881	4206	Пермский край, Чердынский район, поселок Ныроб, Уждавиниса, 11	f	large
65397	72880	4205	Пермский край, Чердынский район, поселок Ныроб, Уждавиниса, 11	f	large
65416	72896	4224	Пермский край, Чердынский район, Кушмангорт, штаб ФБУ ОИК19 ГУФСИН РФ по ПК	t	small
65412	72893	4220	Пермский край, Чердынский район, село Курган, Центральная, 7	t	small
65413	68575	4221	Пермский край, Чердынский район, село Коэлпы, Камская, 7	t	small
65417	72897	4225	Пермский край, Чердынский район, село Кольчуг, Центральная, 5	f	small
65402	72882	4210	Пермский край, Чердынский район, поселок Керчевский, Пушкина, 12	f	large
65400	65943	4208	Пермский край, Чердынский район, поселок Керчевский, Пушкина, 12	f	large
65399	65499	4207	Пермский край, Чердынский район, село Искор, Молодёжная, 12	t	small
65401	66815	4209	Пермский край, Чердынский район, село Гремячево, клуб	t	small
65410	72890	4218	Пермский край, Чердынский район, село Вильгорт, Трактовая, 1	f	medium
65419	72899	4227	Пермский край, Чердынский район, село Верхняя Колва, Набережная, 22	t	medium
65418	72898	4226	Пермский край, Чердынский район, село Валай, Советская, 17	t	small
65408	72888	4216	Пермский край, Чердынский район, село Бондюг, Красноармейская, 21	f	medium
65414	72894	4222	Пермский край, Чердынский район, село Большие Долды, Советская, 28	t	small
64026	71714	406	Пермский край, Чердынский район, село Березовка, Пролетарская, 26, Клуб Энтузиаст	f	large
65389	72872	4117	Пермский край, Частинский район, село Шлыки, Спортивная, 18	f	small
65388	72871	4116	Пермский край, Частинский район, село Шабуры, Школьная, 7	f	medium
65375	72858	4103	Пермский край, Частинский район, село Частые, Нагорная, 3	f	medium
65374	72857	4102	Пермский край, Частинский район, село Частые, Ленина, 70	f	large
65373	72856	4101	Пермский край, Частинский район, село Частые, Ленина, 38	f	large
65381	72864	4109	Пермский край, Частинский район, село Средняя Головниха, Центральная, 21	f	small
65391	72874	4119	Пермский край, Частинский район, село Пихтовка, Школьная, 3	f	small
65386	72869	4114	Пермский край, Частинский район, село Пермяковка, Центральная, 11	f	small
65382	72865	4110	Пермский край, Частинский район, село Ножовка, Энтузиастов, 6А	f	medium
65383	72866	4111	Пермский край, Частинский район, село Ножовка, Чапаева, 1	f	medium
65392	72875	4120	Пермский край, Частинский район, село Меркуши	f	medium
65377	72860	4105	Пермский край, Частинский район, село Мельничная, Октябрьская, 42	f	small
65379	72862	4107	Пермский край, Частинский район, село Кленовая, Советская, 25	f	small
65380	72863	4108	Пермский край, Частинский район, село Змеевка, Школьная, 9	f	small
65378	72861	4106	Пермский край, Частинский район, село Западная, 44А	f	small
65390	72873	4118	Пермский край, Частинский район, село Ельшата, Механизаторов, 8	f	small
65384	72867	4112	Пермский край, Частинский район, село Верхнее Рождество, Школьная, 16	f	small
65387	72870	4115	Пермский край, Частинский район, село Бугры, Уральская, 36	t	small
65358	14699	4036	Пермский край, Чайковский район, село Марково, 34	f	large
65366	72850	4044	Пермский край, Чайковский район, село Альняш, Ленина, 92	f	large
65363	72847	4041	Пермский край, Чайковский городской округ, село Чумна, Звездная, 14	f	medium
65361	72846	4039	Пермский край, Чайковский городской округ, село Фоки, Кирова, 49	f	large
65365	72849	4043	Пермский край, Чайковский городской округ, село Уральское, Школьная, 5	f	medium
65368	72852	4046	Пермский край, Чайковский городской округ, село Сосново, Школьная, 33	f	medium
65367	72851	4045	Пермский край, Чайковский городской округ, село Маракуши, Новая, 5	f	small
65357	72843	4035	Пермский край, Чайковский городской округ, село Кемуль, Комсомольская, 10	f	medium
65370	72854	4048	Пермский край, Чайковский городской округ, село Зипуново, Зеленая, 7	f	medium
65347	72833	4025	Пермский край, Чайковский городской округ, село Засечный, Мира, 30	f	small
65364	72848	4042	Пермский край, Чайковский городской округ, село Завод Михайловский, Пролетарская, 40	f	small
65360	72845	4038	Пермский край, Чайковский городской округ, село Гаревая, Октябрьская, 7	f	small
65348	72834	4026	Пермский край, Чайковский городской округ, село Вассята, Советская, 4	f	medium
65346	72832	4024	Пермский край, Чайковский городской округ, село Ваньки, Молодежная, 10	f	medium
64737	72408	2743	Пермский край, Чайковский городской округ, село Ваньки, Зеленая, 35а	f	medium
65369	72853	4047	Пермский край, Чайковский городской округ, село Буренка, Гаражная, 10	f	medium
65359	72844	4037	Пермский край, Чайковский городской округ, село Большой Букор, Победы, 12	f	large
65321	14626	3918	Пермский край, Усольский район, село Щекино, Пионерская, 4	t	small
65316	72805	3913	Пермский край, Усольский район, село Шемейный, Школьная, 8	t	small
65314	72731	3911	Пермский край, Усольский район, село Турлавы, Центральная, 42	t	small
64213	71890	1037	Пермский край, Усольский район, село Сенькино	t	small
65311	72802	3908	Пермский край, Усольский район, село Пыскор, Игумнова, 5	f	medium
68468	73008	4612	Пермский край, Усольский район, село Плеханово, Центр досуга 	f	large
113016	73007	4611	Пермский край, Усольский район, село Плеханово, Администрация сельского поселения	f	medium
65318	72807	3915	Пермский край, Усольский район, село Ощепково, Школьная, 13	t	small
65315	65117	3912	Пермский край, Усольский район, поселок Орел, Советская, 72а	f	medium
65313	72804	3910	Пермский край, Усольский район, поселок Орел, 1 мая, 37	f	medium
65307	72798	3904	Пермский край, Усольский район, село Вогулка, Южный, 3	t	small
65317	72806	3914	Пермский край, Усольский район, село Верх-Кондас, Центральная, 31	f	small
65292	72780	3814	Пермский край, Уинский район, село Чесноковка, Заречная, 1	f	small
65289	72777	3811	Пермский край, Уинский район, село Чайка, Советская, 28	f	medium
65286	72774	3808	Пермский край, Уинский район, село Усть-Телес, Центральная, 36	f	small
65288	72776	3810	Пермский край, Уинский район, село Усановка, Центральная, 13	f	small
65279	72767	3801	Пермский край, Уинский район, село Уинское, Свободы, 29а	f	large
65281	72769	3803	Пермский край, Уинский район, село Уинское, Ольховая, 2	f	small
65280	72768	3802	Пермский край, Уинский район, село Уинское, 8 Марта, 50	f	small
65302	72792	3824	Пермский край, Уинский район, село Уинское, 30 лет Победы, 2	f	large
65287	72775	3809	Пермский край, Уинский район, село Суда, Центральная, 32	f	large
65291	72779	3813	Пермский край, Уинский район, село Средний Сып, Новая, 10	f	small
65297	72786	3819	Пермский край, Уинский район, село Сосновка, Центральная, 321	t	small
65282	72770	3804	Пермский край, Уинский район, село Соловаты, улица Заречная, 2	f	small
65290	72778	3812	Пермский край, Уинский район, село Нижний Сып, Ленина, 65	f	small
65300	72790	3822	Пермский край, Уинский район, село Митрохи, Центральная, 16	f	small
65298	72788	3820	Пермский край, Уинский район, село Ломь, Школьная, 2	f	small
65299	72789	3821	Пермский край, Уинский район, село Курмакаш, Центральная, 14	f	small
65296	72784	3818	Пермский край, Уинский район, село Красногорка, Центральная, 11	f	small
65293	72781	3815	Пермский край, Уинский район, село Кочешовка, Юбилейная, 4	f	small
65283	72771	3805	Пермский край, Уинский район, село Иштеряки, переулок Восточный, 24	f	small
65284	72772	3806	Пермский край, Уинский район, село Воскресенское, Верхняя, 4	f	small
65301	72791	3823	Пермский край, Уинский район, село Верхний Сып, Центральная, 8	f	small
65295	72783	3817	Пермский край, Уинский район, село Большой Ась, Центральная, 33	f	small
65285	72773	3807	Пермский край, Уинский район, село Барсаи, Юбилейная, 2	f	small
65294	72782	3816	Пермский край, Уинский район, село Аспа, Школьная, 13	f	medium
65267	72755	3711	Пермский край, Суксунский район, село Шахарово, Центральная, 58	f	small
68471	73011	4616	Оренбургская область, Переволоцкий район, село Филипповка	f	large
65278	72766	3722	Пермский край, Суксунский район, село Торговище, Трактовая, 37г	f	small
65277	72765	3721	Пермский край, Суксунский район, село Тис, Северная, 32	f	small
65276	72764	3720	Пермский край, Суксунский район, село Сыра, Колхозная, 10	f	small
65274	72762	3718	Пермский край, Суксунский район, село Сызганка, Молодёжная, 2	f	medium
65260	72748	3704	Пермский край, Суксунский район, поселок Суксун, Школьная, 1	f	large
65257	72745	3701	Пермский край, Суксунский район, поселок Суксун, Кирова, 45	f	large
65258	72746	3702	Пермский край, Суксунский район, поселок Суксун, Карла Маркса, 40	f	large
65259	72747	3703	Пермский край, Суксунский район, поселок Суксун, Большевистская, 16	f	large
65263	72751	3707	Пермский край, Суксунский район, село Советная, Советинская, 43	f	small
65262	72750	3706	Пермский край, Суксунский район, село Сабарка, Победы, 5	f	medium
65273	72761	3717	Пермский край, Суксунский район, село Поедуги, Сосновая, 23	f	medium
65272	72760	3716	Пермский край, Суксунский район, село Пепелыши, Колхозная, 14	f	small
64321	71996	1516	Пермский край, Суксунский район, село Осинцево, Пионерская, 1	f	medium
65270	72758	3714	Пермский край, Суксунский район, село Нижняя Истекаевка, Трактовая, 10	f	small
113033	73034	4640	Пермский край, Суксунский район, село Бырма, Дом Культуры	f	medium
64312	71987	1507	Пермский край, Суксунский район, село Бырма	t	small
65264	72752	3708	Пермский край, Суксунский район, село Брехово, Школьная, 7	f	medium
65275	72763	3719	Пермский край, Суксунский район, село Агафонково, Центральная, 18	f	medium
113061	73063	4712	Пермский край, Соликамский район, село Черное, Мира, 19 а	t	medium
113067	73067	4715	Пермский край, Соликамский район, село Усовский, Центральная, 16	f	small
68482	73053	4702	Пермский край, Соликамский район, поселок Тюлькино, Лесная, 3	f	large
68483	73058	4707	Пермский край, Соликамский район, село Тохтуева, Дружбы, 4	f	large
64114	71802	638	Пермский край, Соликамский район, село Соколово, Ленина, 14	f	medium
113070	73069	4717	Пермский край, Соликамский район, село Сим, Молодежная, 7	t	small
65492	72972	4432	Пермский край, Соликамский район, село Селянка, Библиотека	t	small
68484	73061	4710	Пермский край, Соликамский район, село Половодово, Школьная, 11	f	large
64199	71876	1023	Пермский край, Соликамский район, село Пальники	t	medium
113066	73064	4713	Пермский край, Соликамский район, село Осокино, Центральная, 10	t	small
113053	73055	4704	Пермский край, Соликамский район, село Нижнее Мошево, Спортивная, 1	f	small
113036	73037	4643	Пермский край, Соликамский район, село Красный Берег, Дом культуры	f	small
113068	73068	4716	Пермский край, Соликамский район, село Красный Берег, Гагарина, 1	f	medium
113195	73166	5119	Пермский край, Соликамский район, село Кокорино, 15	t	small
113054	73056	4705	Пермский край, Соликамский район, село Касиб, Набережная, 31	f	small
113052	73054	4703	Пермский край, Соликамский район, село Затон, Советская, 4	f	medium
113059	73060	4709	Пермский край, Соликамский район, село Жуланово, Культуры, 25	f	small
113049	73052	4701	Пермский край, Соликамский район, село Басим, Пионерская, 1	t	medium
65199	72700	3509	Пермский край, Сивинский район, село Юбилейный, Школьная, 3	t	small
65211	72714	3521	Пермский край, Сивинский район, село Шулынды, Ленина, 16	f	medium
65193	72695	3504	Пермский край, Сивинский район, село Усть-Буб, Красногвардейская, 14	f	small
65209	72710	3518	Пермский край, Сивинский район, село Сива, Советская, 4	f	large
65210	72713	3520	Пермский край, Сивинский район, село Сива, Ленина, 57	f	large
112934	72712	3519	Пермский край, Сивинский район, село Сива, Ленина, 62	f	\N
65198	72699	3508	Пермский край, Сивинский район, село Серьгино, Школьная, 2	t	small
65200	72701	3510	Пермский край, Сивинский район, село Серафимовское, Ленина, 1	f	small
65202	72703	3512	Пермский край, Сивинский район, поселок Северный Коммунар, Советская, 3	f	large
65203	72705	3513	Пермский край, Сивинский район, поселок Северный Коммунар, Ленина, 30а	f	small
65197	72698	3507	Пермский край, Сивинский район, село Сатино, Школьная, 22	t	small
65208	72709	3517	Пермский край, Сивинский район, село Савичи, Техническая, 90	f	medium
64111	71799	635	Пермский край, Сивинский район, село Кривчана, Мира, 9	f	small
64413	60369	1810	Пермский край, Сивинский район, село Краснояр, Спорта, 7	f	small
64719	72391	2725	Пермский край, Сивинский район, село Кичаново, Безымяная, 11	f	small
65206	72707	3515	Пермский край, Сивинский район, село Кизьва, Ленина, 22	f	medium
113217	73188	5141	Пермский край, Сивинский район, село Кекур, Попова, 12	f	small
65446	72925	4327	Пермский край, Сивинский район, село Калиновка, Администрация	f	medium
113165	73138	5020	Россия, Кировская область, Зуевский район, село Зыряново	t	small
65195	72697	3506	Пермский край, Сивинский район, село Екатерининское, Ленина, 41	t	medium
65204	72706	3514	Пермский край, Сивинский район, село Дмитриево, Центральная , 12	f	small
65191	72693	3502	Пермский край, Сивинский район, село Буб, Бубинская, 19	f	large
65192	72694	3503	Пермский край, Сивинский район, село Бровилята, Трудовая, 22	f	small
65190	72692	3501	Пермский край, Сивинский район, село Большое Самылово, Самыловская, 13	f	medium
64345	72020	1617	Пермский край, Сивинский район, село Антипина, Центральная, 13	t	small
64306	71981	1501	Пермский край, Сивинский район, село Андреево, Парковая, 5	f	medium
64696	72369	2702	Пермский край, Пермский район, село Янычи, Сибирский тракт, 54б	t	small
64754	72426	2760	Пермский край, Пермский район, поселок Юго-Камский, Советская, 110	f	large
64751	72423	2757	Пермский край, Пермский район, поселок Юго-Камский, Советская, 159	f	large
64755	72427	2761	Пермский край, Пермский район, поселок Юго-Камский, Мира, 1	f	large
68543	72424	2758	Пермский край, Пермский район, поселок Юго-Камский, Декабристов, 14	f	large
64747	72419	2753	Пермский край, Пермский район, поселок Юг, Комсомольский проспект, 3	f	large
64722	72394	2728	Пермский край, Пермский район, село Чуваки, Верховая, 10	f	small
64734	72405	2740	Пермский край, Пермский район, поселок Усть-Качка, Санаторий ЗАО Курорт УстьКачка	f	large
64742	72414	2748	Пермский край, Пермский район, поселок Усть-Качка, Победы, 12	f	large
64743	72415	2749	Пермский край, Пермский район, поселок Усть-Качка, Краснознаменная, 5	f	large
64741	72413	2747	Пермский край, Пермский район, село Троица, Советская, 18	f	small
64749	72421	2755	Пермский край, Пермский район, поселок Сылва, Молодежная, 7	f	large
64748	72420	2754	Пермский край, Пермский район, поселок Сылва, Заводской переулок, 1	f	large
64707	72378	2713	Пермский край, Пермский район, село Суздалы, Полевая, 1	t	small
68542	72411	2746	Пермский край, Пермский район, поселок Сокол, Соколовская среднеобразовательная школа	f	large
64735	72406	2741	Пермский край, Пермский район, село Рождественское, Революционная, 20	f	small
113145	73122	5006	Пермский край, Пермский район, поселок Октябрьский	f	medium
64569	72244	2206	Пермский край, Пермский район, поселок Октябрьский, Граневая, 15, контора маслозавода	f	medium
64568	72243	2205	Пермский край, Пермский район, поселок Октябрьский, 18 Годовщины Октября, 68, гараж ДРСУ	f	medium
64733	72404	2739	Пермский край, Пермский район, село Новый, Первомайская, 8	f	medium
64731	72402	2737	Пермский край, Пермский район, село Нижний Пальник, Садовая, 2	f	medium
64703	72374	2709	Пермский край, Пермский район, село Нестюково, Трактовая, 50	f	medium
68540	72399	2734	Пермский край, Пермский район, село Мулянка, Октябрьская, 21	f	large
64727	63898	2733	Пермский край, Пермский район, село Мостовая, Мира, 19	t	medium
112879	72401	2736	Пермский край, Пермский район, село Лобаново, Культуры, 15	f	medium
64724	72396	2730	Пермский край, Пермский район, село Лобаново, Культуры, 15	f	large
64723	72395	2729	Пермский край, Пермский район, село Курашим, Чурекова, 2	f	large
64717	72389	2723	Пермский край, Пермский район, село Култаево, Р.Кашина, 89	f	large
64716	72389	2722	Пермский край, Пермский район, село Култаево, Р.Кашина, 89	f	large
64711	72383	2717	Пермский край, Пермский район, поселок Кукуштан, Чапаева, 50	f	large
64713	72386	2719	Пермский край, Пермский район, поселок Кукуштан, Ульяновская, 22	f	large
64744	72417	2750	Пермский край, Пермский район, село Красный Восход, Садовая, 10	f	large
64710	72382	2716	Пермский край, Пермский район, село Кояново, Советская, 133б	f	medium
112877	72392	2726	Пермский край, Пермский район, село Косотуриха, Центральная, 22а	f	medium
64725	72397	2731	Пермский край, Пермский район, село Касимово, Клубная, 52	t	small
68463	72995	4502	Пермский край, Пермский район, поселок Звездный, Бабичева, 5А	f	large
64705	72376	2711	Пермский край, Пермский район, село Горшки, Школьная, 4	f	medium
64702	72373	2708	Пермский край, Пермский район, село Горный, Лямина, 1	f	medium
65179	72681	3481	Пермский край, Пермский район, село Голый Мыс, Клубная, 2	f	medium
65269	72757	3713	Пермский край, Пермский район, поселок Бырма, Школьная, 21	f	small
64715	72388	2721	Пермский край, Пермский район, село Большое Савино	f	small
64706	72377	2712	Пермский край, Пермский район, село Большакино, Центральная, 22/2	t	small
113006	72993	4506	Пермский край, Пермский район, поселок Бершетские Дачи, Школьная, 8	f	medium
68464	72993	4503	Пермский край, Пермский район, поселок Бершетские Дачи, Школьная, 8	f	large
68462	72993	4501	Пермский край, Пермский район, поселок Бершетские Дачи, Школьная, 8	f	large
64718	72390	2724	Пермский край, Пермский район, село Башкултаево, Мавлютова, 30	f	medium
64714	72387	2720	Пермский край, Пермский район, село Байболовка, Школьная, 1А	f	medium
64693	72366	2625	Пермский край, Очерский район, село Токари, Центральная, 17	f	small
64684	72359	2616	Пермский край, Очерский район, село Спешково, Центральная, 11	f	medium
64689	63145	2621	Пермский край, Очерский район, село Семеново, Мира, 8	f	medium
64681	72356	2613	Пермский край, Очерский район, поселок Павловский, Таборская, 26	f	large
64683	72358	2615	Пермский край, Очерский район, поселок Павловский, Октябрьская, 40	f	small
64680	72355	2612	Пермский край, Очерский район, поселок Павловский, Октябрьская, 5	f	large
64672	72347	2604	Пермский край, Очерский район, Очер, Школьная, 97	f	medium
64669	72344	2601	Пермский край, Очерский район, Очер, Урицкого, 29	f	large
64675	72350	2607	Пермский край, Очерский район, Очер, Советская, 20	f	medium
64676	72351	2608	Пермский край, Очерский район, Очер, Революционная, 95	f	medium
64674	72349	2606	Пермский край, Очерский район, Очер, Революционная, 6	f	large
64670	72345	2602	Пермский край, Очерский район, Очер, Пушкина, 54А	f	medium
64678	72353	2610	Пермский край, Очерский район, Очер, Олега Кошевого, 54	f	medium
64673	72348	2605	Пермский край, Очерский район, Очер, Коммунистическая, 6	f	large
64677	72352	2609	Пермский край, Очерский район, Очер, Дорожный, 13а	f	large
64690	72363	2622	Пермский край, Очерский район, село Нововознесенск, Мира, 9	f	small
64679	72354	2611	Пермский край, Очерский район, село Нижняя Талица, Школьная, 17	f	medium
64687	72362	2619	Пермский край, Очерский район, село Морозово, Раздольная, 33	f	small
64685	72360	2617	Пермский край, Очерский район, село Лужково, Заречная, 88	f	small
64694	72367	2626	Пермский край, Очерский район, село Кулики, Центральная, 12	f	small
64691	72364	2623	Пермский край, Очерский район, село Киприно, Советская, 29	f	small
64688	62363	2620	Пермский край, Очерский район, село Дворец, Уральская, 15	t	small
64663	72337	2508	Пермский край, Оханский район, село Тулумбаиха, Культуры, 7	f	large
64665	72339	2510	Пермский край, Оханский район, село Таборы, Октября, 8	f	medium
64668	72343	2513	Пермский край, Оханский район, село Пономари, Центральная, 1	f	small
64659	72333	2504	Пермский край, Оханский район, Оханск, Ленина, 66	f	large
64657	72331	2502	Пермский край, Оханский район, Оханск, Красная, 8	f	large
64656	72330	2501	Пермский край, Оханский район, Оханск, Красная, 56	f	large
64658	72332	2503	Пермский край, Оханский район, Оханск, Винокурова, 2	f	large
112875	72341	2511	Пермский край, Оханский район, село Острожка, Советская, 35, Центр досуга	f	\N
64667	72342	2512	Пермский край, Оханский район, село Мерзляки, Центральная, 5	f	small
65266	72754	3710	Пермский край, Оханский район, село Ключи, 40 лет Победы, 17	f	medium
64664	72338	2509	Пермский край, Оханский район, село Казанка, Садовая, 1	f	medium
64112	71800	636	Пермский край, Оханский район, село Заполье	f	small
113035	73036	4642	Пермский край, Оханский район, село Березовка, бывшее помещение ФАП	t	small
64024	71712	404	Пермский край, Оханский район, село Березовка, Ленина,, 33, администрация района	f	large
64661	72335	2506	Пермский край, Оханский район, село Беляевка, Камская, 24	f	medium
64660	72334	2505	Пермский край, Оханский район, село Андреевка, Победы, 2	f	medium
64704	72375	2710	Пермский край, Осинский район, село Устиново, Советская, 44	f	small
64639	72311	2413	Пермский край, Осинский район, село Пермякова, Уральская, 6	f	medium
64651	72325	2425	Пермский край, Осинский район, село Паль, Садовая, 1	f	small
64635	72308	2409	Пермский край, Осинский район, Оса, Строителей, 31	f	large
64630	72303	2404	Пермский край, Осинский район, Оса, Советская, 45	f	medium
64629	72302	2403	Пермский край, Осинский район, Оса, Пугачева, 12	f	large
64632	72305	2406	Пермский край, Осинский район, Оса, Мира, 10	f	large
64631	72304	2405	Пермский край, Осинский район, Оса, Мира, 10	f	large
64634	72307	2408	Пермский край, Осинский район, Оса, М.Горького, 78	f	large
64628	72300	2402	Пермский край, Осинский район, Оса, Интернациональная, 6, Центр детского творчества	f	large
64627	72299	2401	Пермский край, Осинский район, Оса, Горького, 63	f	large
65356	72842	4034	Пермский край, Осинский район, село Ольховка, Школьная, 2	f	large
64640	72313	2414	Пермский край, Осинский район, село Новозалесново, Советская, 7	f	medium
64645	72319	2419	Пермский край, Осинский район, село Нижняя Чермода, Молодежная, 3	f	small
64457	72135	1914	Пермский край, Осинский район, село Нефтяников	f	large
64591	72262	2228	Пермский край, Осинский район, село Мостовая, библиотека	f	small
64647	72321	2421	Пермский край, Осинский район, село Лесной, Кирова, 2	f	small
64650	72324	2424	Пермский край, Осинский район, село Кузнечиха, Чапаева, 28	f	small
64642	72316	2416	Пермский край, Осинский район, село Крылово, Ленина, 6	f	medium
64648	72322	2422	Пермский край, Осинский район, село Горы, Советская, 56	f	medium
113122	73065	4909	Пермский край, Осинский район, село Горки, клуб	t	small
64643	72317	2417	Пермский край, Осинский район, село Галицы, Мира, 1	f	medium
64653	72327	2427	Пермский край, Осинский район, село Верхняя Давыдовка, Молодежная, 6	t	small
64621	72292	2314	Пермский край, Ординский район, село Щелканка, Центральная, 24	f	small
112863	72282	2304	Пермский край, Ординский район, село Шляпники, Ленина, 44	f	\N
64272	71951	1310	Пермский край, Ординский район, село Терехино, Терехинская, 1	f	medium
64610	72281	2303	Пермский край, Ординский район, село Орда, Трактовая, 22а	f	large
64609	72280	2302	Пермский край, Ординский район, село Орда, Советская, 26	f	large
64626	72298	2319	Пермский край, Ординский район, село Орда, Пугачева, 79	f	small
112862	72279	2301	Пермский край, Ординский район, село Орда, 1 Мая, 1	f	\N
112867	72296	2317	Пермский край, Ординский район, село Опачевка, Советская, 33	f	\N
112865	72286	2308	Пермский край, Ординский район, село Михино, Советская, 23	f	\N
64619	72290	2312	Пермский край, Ординский район, село Михайловка, Гаражная, 2	t	small
64614	72285	2307	Пермский край, Ординский район, село Мерекай, Центральная, 11	t	small
64613	72284	2306	Пермский край, Ординский район, село Медянка, Ленина, 32а	f	medium
64617	72288	2310	Пермский край, Ординский район, село Малый Ашап, Советская, 53	f	medium
64623	72294	2316	Пермский край, Ординский район, село Красный Ясыл, Советская, 54	f	medium
64622	72293	2315	Пермский край, Ординский район, село Карьево, Центральная, 5	f	medium
64612	72283	2305	Пермский край, Ординский район, село Грызаны, Центральная, 38	t	small
64616	72287	2309	Пермский край, Ординский район, село Вторые Ключики, Заводская, 13	f	small
64625	72297	2318	Пермский край, Ординский район, село Верхний Кунгур, Большая, 18	f	small
64620	72291	2313	Пермский край, Ординский район, село Ашап, пер.Советский, 13	f	large
64601	72272	2238	Пермский край, Октябрьский район, поселок Щучье Озеро, СДК	f	large
64607	72278	2244	Пермский край, Октябрьский район, село Шараповка, СДК	t	small
64606	72277	2243	Пермский край, Октябрьский район, село Усть-Саварово, СДК	f	small
64586	61967	2223	Пермский край, Октябрьский район, село Уразметьево, СДК	f	small
64580	72256	2217	Пермский край, Октябрьский район, село Тюш, Первомайская, 12, СДК	f	large
64604	72275	2241	Пермский край, Октябрьский район, село Тюинск, СДК	f	small
64578	72254	2215	Пермский край, Октябрьский район, село Тляково, СДК	f	small
64029	71717	409	Пермский край, Октябрьский район, село Сосновка, Центральная, 27 , администрация Сосновского СП	f	small
64571	72246	2208	Пермский край, Октябрьский район, село Снежное, Речная, 11, учебный корпус техникума	f	small
64596	72267	2233	Пермский край, Октябрьский район, село Седяш, СДК	f	small
64576	72252	2213	Пермский край, Октябрьский район, село Сарс, Советская, ДК, 2 этаж	f	large
64575	72251	2212	Пермский край, Октябрьский район, село Сарс, Советская, ДК, 1 этаж	f	large
64588	32043	2225	Пермский край, Октябрьский район, село Самарова, СДК	f	small
64605	72276	2242	Пермский край, Октябрьский район, село Русский Сарс, Зимина, СДК	f	medium
64590	72261	2227	Пермский край, Октябрьский район, село Редькино, административное здание	f	small
64595	72266	2232	Пермский край, Октябрьский район, село Петропавловск, СДК	f	small
64564	72238	2201	Пермский край, Октябрьский район, поселок Октябрьский, Ленина, 59, ГДК, 1 этаж	f	large
64603	72274	2240	Пермский край, Октябрьский район, село Новопетровка, СДК	f	small
64570	72245	2207	Пермский край, Октябрьский район, село Ненастье, контора гаража ООО Газстройдеталь	f	small
64572	72248	2209	Пермский край, Октябрьский район, Малый Сарс, СДК	t	small
64582	72258	2219	Пермский край, Октябрьский район, село Леун, административное здание	f	small
64579	72255	2216	Свердловская область, Ачитский район, поселок Колтаева	f	small
64587	72226	2224	Пермский край, Октябрьский район, село Ишимово, Мира, 12, администрация	f	medium
64585	60409	2222	Пермский край, Октябрьский район, село Зуевский, СДК	f	small
64589	62294	2226	Пермский край, Октябрьский район, село Енапаево, администрация	f	medium
64574	72250	2211	Пермский край, Октябрьский район, село Верх-Шуртан, административное здание	f	small
64598	72269	2235	Пермский край, Октябрьский район, село Верх-Тюш, администрация	f	small
64594	72265	2231	Пермский край, Октябрьский район, село Верх-Ирень, СДК	f	small
64573	72249	2210	Пермский край, Октябрьский район, село Большой Сарс, библиотека	f	small
64581	72257	2218	Пермский край, Октябрьский район, село Бияваш, СДК	f	small
64584	72260	2221	Пермский край, Октябрьский район, село Бикбай, СДК	f	small
64583	72259	2220	Пермский край, Октябрьский район, село Басино, администрация	f	small
64592	72263	2229	Пермский край, Октябрьский район, село Атнягузи, СДК	f	small
64600	72271	2237	Пермский край, Октябрьский район, село Алтынное, административное здание	f	small
64602	72273	2239	Пермский край, Октябрьский район, село Алмаз, СДК	f	small
64597	72268	2234	Пермский край, Октябрьский район, село Адилева, СДК	f	small
64545	72218	2118	Пермский край, Нытвенский район, село Шерья, Школьная, 1	f	medium
64549	72222	2122	Пермский край, Нытвенский район, село Чекмени, Центральная, 1	f	small
64552	72225	2125	Пермский край, Нытвенский район, село Чайковская, Строительная, 1	f	large
64551	72224	2124	Пермский край, Нытвенский район, село Чайковская, Коробейникова, 4	f	large
64745	14622	2751	Пермский край, Нытвенский район, село Фролы, Садовая, 14	f	large
64563	72237	2136	Пермский край, Нытвенский район, поселок Уральский, Центральная, 17, медпункт	f	small
64543	72216	2116	Пермский край, Нытвенский район, поселок Уральский, Набережная, 23	f	large
64542	72215	2115	Пермский край, Нытвенский район, Уральский, Набережная, 20	f	large
64541	72214	2114	Пермский край, Нытвенский район, поселок Уральский, Московская, 13	f	large
113242	73229	5323	Пермский край, Нытвенский район, село Сюзьва	t	small
64557	72231	2130	Пермский край, Нытвенский район, село Постаноги, Советская, 12	f	small
113002	72988	4448	Пермский край, Нытвенский район, село Половинка, филиал МУК Скальнинский Дом культуры	t	medium
64555	72229	2128	Пермский край, Нытвенский район, село Покровское, Речная, 6а	f	small
64560	72234	2133	Пермский край, Нытвенский район, Нытва, пр.Ленина, 44	f	medium
64533	72206	2106	Пермский край, Нытвенский район, Нытва, Оборина, 1а	f	large
64532	72205	2105	Пермский край, Нытвенский район, Нытва, Ленина проспект, 24	f	large
64529	72202	2102	Пермский край, Нытвенский район, Нытва, Королева, 33	f	large
112853	72209	2109	Пермский край, Нытвенский район, Нытва, Комсомольская, 28	f	\N
64530	72203	2103	Пермский край, Нытвенский район, Нытва, К.Маркса, 76а	f	large
64528	72201	2101	Пермский край, Нытвенский район, Нытва, К.Либкнехта, 118	f	large
64535	72208	2108	Пермский край, Нытвенский район, Нытва, Белинского, 35	f	small
64540	72213	2113	Пермский край, Нытвенский район, поселок Новоильинский, Первомайская, 36	f	medium
64538	72211	2111	Пермский край, Нытвенский район, поселок Новоильинский, Первомайская, 22	f	medium
64539	72212	2112	Пермский край, Нытвенский район, поселок Новоильинский, Ленина, 35	f	large
64550	72223	2123	Пермский край, Нытвенский район, село Нижняя Гаревая, Молодежная, 2а	f	medium
64721	72393	2727	Пермский край, Нытвенский район, село Мокино, Шоссейная, 4	t	small
64556	72230	2129	Пермский край, Нытвенский район, село Мокино, Пономарева, 13б	f	medium
64391	72073	1728	Пермский край, Нытвенский район, поселок Майский, МОУ Майская СОШ	f	large
64392	72073	1729	Пермский край, Нытвенский район, поселок Майский, МОУ Майская СОШ	f	large
64559	72233	2132	Пермский край, Нытвенский район, село Заполье, Школьная, 2а	f	small
65444	72923	4325	Пермский край, Нытвенский район, село Деменево, Администрация	f	medium
64562	72236	2135	Пермский край, Нытвенский район, село Груни, Центральная, 6	f	small
64553	72227	2126	Пермский край, Нытвенский район, село Григорьевское, Школьная, 13а	f	large
64554	72228	2127	Пермский край, Нытвенский район, село Григорьевская, Октябрьская, 26	f	medium
64561	72235	2134	Пермский край, Нытвенский район, село Воробьи, школа	f	small
64548	72221	2121	Пермский край, Нытвенский район, село Белобородово, Дружбы, 2а	f	medium
64054	71742	434	Пермский край, Лысьва городской округ, село Шаква, Центральная, 1, Дом культуры	f	small
64514	72187	2037	Пермский край, Лысьва городской округ, село Сова, Совхозная, 19	f	medium
64526	72199	2049	Пермский край, Лысьва городской округ, село Рассоленки, Мира, 7	f	medium
64511	72184	2034	Пермский край, Лысьва городской округ, село Олени, Центральная, 1	f	small
64508	72181	2031	Пермский край, Лысьва городской округ, село Обманка 2-я, Шмидта, 6	f	small
64512	72185	2035	Пермский край, Лысьва городской округ, село Новорождественское, Школьная, 3	f	small
64518	72191	2041	Пермский край, Лысьва городской округ, село Невидимка, Школьная, 4	f	medium
64510	72183	2033	Пермский край, Лысьва городской округ, село Липовая 1-я, Полевая, 4а	f	medium
64523	72196	2046	Пермский край, Лысьва городской округ, поселок Кын, Заречная, 131	f	large
64524	72197	2047	Пермский край, Лысьва городской округ, поселок Кын, Железнодорожная, 49	f	medium
64525	72198	2048	Пермский край, Лысьва городской округ, село Кын, Кыновской дом культуры	f	small
64522	72195	2045	Пермский край, Лысьва городской округ, село Кумыш, Куйбышева, 6а	f	small
64517	72190	2040	Пермский край, Лысьва городской округ, село Кормовище, Советская, 35	f	large
64515	72188	2038	Пермский край, Лысьва городской округ, село Канабеки, Дом культуры	f	small
64509	72182	2032	Пермский край, Лысьва городской округ, село Заимка, Ленина, 3	f	medium
64113	71801	637	Пермский край, Лысьва городской округ, село Верх-Лысьва, Гагарина, 14	f	small
64516	72189	2039	Пермский край, Лысьва городской округ, село Верх-Култым, Ленина, 13	f	small
64738	72409	2744	Пермский край, Лужский район, д.Крохово, Казанский тракт, 21	f	large
113032	73033	4639	Пермский край, Кунгурский район, село Юговское, Администрация сельского поселения	f	medium
64231	71910	1117	Пермский край, Кунгурский район, село Шубино, Рязанова, 29/а	f	small
68474	73017	4622	Пермский край, Кунгурский район, село Шадейка, Центр досуга	f	large
113023	73022	4627	Пермский край, Кунгурский район, село Чувирята, Клуб	t	small
113018	73012	4617	Пермский край, Кунгурский район, село Филипповка, бывшая контора ООО Сылвенский	f	medium
113025	73024	4629	Пермский край, Кунгурский район, село Уфа, бывшая контора ООО Кыласовское	t	small
113037	73038	4644	Пермский край, Кунгурский район, село Усть-Турка, Дом культуры	f	medium
68477	73027	4632	Пермский край, Кунгурский район, село Троельга, Средняя школа	f	large
113043	73045	4651	Пермский край, Кунгурский район, село Теплая, Средняя школа	f	medium
68467	73000	4604	Пермский край, Кунгурский район, село Серга, Средняя школа	f	large
113047	73050	4656	Пермский край, Кунгурский район, село Семсовхоз, Администрация сельского поселения	f	medium
113046	73049	4655	Пермский край, Кунгурский район, село Садоягодное, Техникуминтернат	f	small
113010	73001	4605	Россия	t	small
113020	73016	4621	Пермский край, Кунгурский район, село Поповка, лыжная база Снежинка	t	small
113034	73035	4641	Россия	t	small
113024	73023	4628	Пермский край, Кунгурский район, село Подъельник, бывшая столовая ООО Кыласовское	t	small
113009	72999	4603	Пермский край, Кунгурский район, село Насадка, Центр Досуга	f	small
68473	73014	4619	Пермский край, Кунгурский район, село Моховое, Центр досуга	f	large
113008	72998	4602	Пермский край, Кунгурский район, село Моховое	t	small
113044	73047	4653	Пермский край, Кунгурский район, село Мериново, контора ООО ЛСК	t	medium
113031	73032	4638	Пермский край, Кунгурский район, село Мазунино, Администрация сельского поселения	f	medium
64211	71888	1035	Пермский край, Кунгурский район, село Липово	t	small
68480	73040	4646	Пермский край, Кунгурский район, село Ленск, дминистрация сельского поселения	f	large
113028	73028	4633	Пермский край, Кунгурский район, село Кужлево, ФАП	t	small
113013	73004	4608	Пермский край, Кунгурский район, село Кинделино, Начальная школа	f	small
113015	73006	4610	Пермский край, Кунгурский район, село Каширино, Дом культуры 	t	small
68479	73031	4637	Пермский край, Кунгурский район, село Калинино, Школаинтернат	f	large
68478	72994	4636	Пермский край, Кунгурский район, село Калинино, Средняя школа	f	large
113022	73020	4625	Пермский край, Кунгурский район, село Казаево, Дом культуры	t	small
113007	72997	4601	Россия, Алтайский край, Первомайский район, поселок Ильича (Черемшаека)	t	small
113014	73005	4609	Пермский край, Кунгурский район, село Зарубино, Центр досуга	f	medium
113021	73018	4623	Пермский край, Кунгурский район, село Жилино, Центр Досуга	f	small
65376	72859	4104	Пермский край, Кунгурский район, село Ерзовка, Чапаева, 22	f	medium
113027	73026	4631	Пермский край, Кунгурский район, село Ергач, магазин СПО Кыласовское	t	small
68475	73019	4624	Пермский край, Кунгурский район, поселок Ергач, Средняя школа	f	large
113019	73015	4620	Пермский край, Кунгурский район, село Дейково, бывшее помещение ФАП	t	small
113017	72959	4615	Пермский край, Кунгурский район, село Гробово, Клуб	t	small
64202	71879	1026	Пермский край, Кунгурский район, село Голубята	t	small
113048	73051	4657	Пермский край, Кунгурский район, село Голдыревский, Средняя школа	f	medium
113039	73041	4647	Пермский край, Кунгурский район, село Веслянка, контора АП Заря	f	small
113041	73043	4649	Пермский край, Кунгурский район, село Бымок, Дом культуры	t	small
113030	73030	4635	Пермский край, Кунгурский район, село Бым, Дом культуры	f	small
113026	73025	4630	Пермский край, Кунгурский район, село Ботово, магазин СПО Кыласовское	t	small
64577	72253	2214	Пермский край, Кунгурский район, село Богородск, библиотека	f	medium
113042	73044	4650	Пермский край, Кунгурский район, село Блины, бывшее помещение ФАП	t	small
68472	73013	4618	Пермский край, Кунгурский район, село Беркутово, Дом Культуры	f	large
64025	71713	405	Пермский край, Кунгурский район, село Березовка, Центральная, 33, Центр детского творчества	f	large
113038	73039	4645	Пермский край, Кунгурский район, село Бажуки, Дом культуры	f	medium
65385	72868	4113	Пермский край, Кунгурский район, село Бабка, Октябрьская, 17	f	medium
64454	72131	1911	Пермский край, Кунгур городской округ, Кунгур, Просвещения, 2	f	large
64470	72147	1927	Пермский край, Кунгур городской округ, Кунгур, Голованова, 36	f	large
64420	72102	1817	Пермский край, Куединский район, село Федоровск, Клубная, 1	f	medium
64412	72095	1809	Пермский край, Куединский район, село Урталга, Победы, 38	f	small
64438	72118	1835	Пермский край, Куединский район, село Урада, А. Игнатьева, 37	f	small
64437	72117	1834	Пермский край, Куединский район, село Узяр, Центральная, 4	f	small
64410	72094	1807	Пермский край, Куединский район, село Трегубовка, Заречная, 16	f	small
64428	72109	1825	Пермский край, Куединский район, село Старый Шагирт, Школьная, 3	f	medium
64419	72101	1816	Пермский край, Куединский район, село Русские Чикаши, Дружбы, 2	f	small
64426	72107	1823	Пермский край, Куединский район, Рабак, Центральная, 8	f	small
64052	71740	432	Пермский край, Куединский район, село Покровка, Центральная, 23, Дом культуры	f	small
64441	72120	1838	Пермский край, Куединский район, село Пантелеевка, Центральная, 38	f	small
64436	72116	1833	Пермский край, Куединский район, село Ошья, Школьная, 7	f	medium
64442	72121	1839	Пермский край, Куединский район, поселок Куеда, Школьная, 23	f	large
64409	72093	1806	Пермский край, Куединский район, поселок Куеда, Центральная, 39	f	small
64408	72092	1805	Пермский край, Куединский район, поселок Куеда, Трактовая, 24	f	medium
64443	72122	1840	Пермский край, Куединский район, поселок Куеда, Ленина, 15	f	large
64406	72090	1803	Пермский край, Куединский район, поселок Куеда, Комсомольская, 13	f	medium
64407	72091	1804	Пермский край, Куединский район, поселок Куеда, Карла Маркса, 13б	f	medium
64404	72088	1801	Пермский край, Куединский район, поселок Куеда, Карла Маркса, 28	f	medium
64405	72089	1802	Пермский край, Куединский район, поселок Куеда, Гагарина, 27	f	large
64427	72108	1824	Пермский край, Куединский район, село Кирга, Садовая, 1	f	small
64425	72106	1822	Пермский край, Куединский район, село Кипчак, Школьная, 2	f	small
113275	73254	5425	Пермский край, Куединский район, село Кама, Пионерская, 8	f	medium
64417	72099	1814	Пермский край, Куединский район, село Искильда, Пилорамная, 1	f	small
113040	73042	4648	Пермский край, Куединский район, село Змеевка, клуб	t	small
64421	72103	1818	Пермский край, Куединский район, село Земплягаш, Новая, 11	f	small
64435	72115	1832	Пермский край, Куединский район, село Дойная, Школьная, 1	f	small
64430	72111	1827	Пермский край, Куединский район, село Госконезавод 3, Советская, 24	f	medium
64429	72110	1826	Пермский край, Куединский район, село Гожан, Центральная, 1	f	small
64434	72114	1831	Пермский край, Куединский район, село Верхняя Уса, Центральная, 17	f	small
64432	72112	1829	Пермский край, Куединский район, село Верхняя Сава, Центральная, 37	f	medium
64414	72096	1811	Пермский край, Куединский район, село Большой Талмаз, Центральная, 14	f	small
64415	72097	1812	Пермский край, Куединский район, село Большой Каскасал, Центральная, 10	f	small
64423	72105	1820	Пермский край, Куединский район, село Большой Гондыр, 40 лет Победы	f	large
64439	72119	1836	Пермский край, Куединский район, село Большие Кусты, Зеленая, 147	f	medium
64433	72113	1830	Пермский край, Куединский район, село Большая Уса, Школьная, 8	f	large
64418	72100	1815	Пермский край, Куединский район, село Бикбарда, Школьная, 9	f	small
64416	72098	1813	Пермский край, Куединский район, село Аряж, Центральная, 27	f	small
113215	73185	5138	Пермский край, Кудымкарский район, село Эрна, Центральная, 3	t	small
113178	73151	5104	Пермский край, Кудымкарский район, село Шадрина, Школьная, 13	f	small
113182	73155	5108	Пермский край, Кудымкарский район, село Тебенькова, Школьная, 3	f	small
113213	73183	5136	Пермский край, Кудымкарский район, село Сюзь-Позья, Медицинская, 3	t	small
113204	73175	5128	Пермский край, Кудымкарский район, село Сылвож, Молодежная, 3	t	small
113216	73186	5139	Пермский край, Кудымкарский район, село Степанова, Сазонова, 10	f	medium
113176	73149	5102	Пермский край, Кудымкарский район, село Старая Кузьва, Центральная, 14	f	small
113190	73162	5115	Пермский край, Кудымкарский район, село Самково, Транспортная, 17	f	small
113206	73177	5130	Пермский край, Кудымкарский район, село Ракшина, Полевая, 7	f	small
113185	73159	5112	Пермский край, Кудымкарский район, село Разина, Центральная, 2	t	\N
113205	73176	5129	Пермский край, Кудымкарский район, село Пятина, 7	t	small
113198	73169	5122	Пермский край, Кудымкарский район, село Поносова, Садовая, 2	t	small
113207	73178	5131	Пермский край, Кудымкарский район, село Полва, Школьная, 9	t	small
68490	73187	5140	Пермский край, Кудымкарский район, село Пешнигорт, Голева, 15	f	large
113164	73137	5019	Пермский край, Кудымкарский район, поселок Петухово	t	small
113179	73152	5105	Пермский край, Кудымкарский район, село Перкова, Центральная, 10	f	small
113208	73179	5132	Пермский край, Кудымкарский район, село Ошиб, Центральная, 3	f	medium
64279	71958	1317	Пермский край, Карагайский район, село Менделеево, Ленина, 42	f	large
113177	73150	5103	Пермский край, Кудымкарский район, село Отево, Степана Караваева, 11	f	small
64243	71922	1209	Пермский край, Кудымкарский район, село Москвина	t	small
113189	73161	5114	Пермский край, Кудымкарский район, село Москвина, Центральная, 1	f	small
113199	73170	5123	Пермский край, Кудымкарский район, село Мижуева, Колхозная, 8	f	small
113211	73181	5134	Пермский край, Кудымкарский район, село Мелехина, Центральная, 11	t	\N
113184	73157	5110	Пермский край, Кудымкарский район, село Мальцева, Мира, 12	f	small
68491	73189	5142	Пермский край, Кудымкарский район, село Малая Серва, Зеленая, 1	f	large
113202	73173	5126	Пермский край, Кудымкарский район, село Ленинск, Попова, 9	f	medium
113181	73154	5107	Пермский край, Кудымкарский район, село Кува, Ленина, 1	f	medium
113197	73168	5121	Пермский край, Кудымкарский район, село Корчевня, Центральная, 50а	f	medium
113214	73184	5137	Пермский край, Кудымкарский район, село Конанова, Дружбы, 29	t	small
113180	73153	5106	Пермский край, Кудымкарский район, село Карбас, Центральная, 16	f	small
113212	73182	5135	Пермский край, Кудымкарский район, село Егорова, Медицинская, 10	f	medium
113196	73167	5120	Пермский край, Кудымкарский район, село Егва, Советская, 5	f	medium
113187	73160	5113	Пермский край, Кудымкарский район, село Демина, Центральная, 27	f	\N
113200	73171	5124	Пермский край, Кудымкарский район, село Гурина, Центральная, 36	f	small
113193	73164	5117	Пермский край, Кудымкарский район, село Веселый Мыс, Транспортная, 3	t	\N
113203	73174	5127	Пермский край, Кудымкарский район, село Верх-Юсьва, Центральная, 15	f	medium
68489	73158	5111	Пермский край, Кудымкарский район, село Верх-Иньва, Октябрьская, 10	f	large
113209	73180	5133	Пермский край, Кудымкарский район, село Велва-База, Школьная, 6	t	small
113194	73165	5118	Пермский край, Кудымкарский район, село Буждом, Центральная, 7	t	small
113183	73156	5109	Пермский край, Кудымкарский район, село Большая Сидорова, Центральная, 19	f	small
68488	73148	5101	Пермский край, Кудымкарский район, село Белоево, Ленина, 21	f	large
113201	73172	5125	Пермский край, Кудымкарский район, село Алекова, Колхозная, 5	t	small
64396	72076	1733	Пермский край, Краснокамский район, поселок Шабуничи, Железнодорожная, 12	t	small
64395	72075	1732	Пермский край, Краснокамск городской округ, село Черная, Северная, 6	f	medium
64393	72074	1730	Пермский край, Краснокамск городской округ, село Усть-Сыны, Совхозная, 14	f	small
64400	72083	1737	Пермский край, Краснокамск городской округ, село Стряпунята, Советская,  4	f	large
113011	73002	4606	Пермский край, Краснокамск городской округ, село Осташата, Дом культуры	t	small
64390	72072	1727	Пермский край, Краснокамск городской округ, поселок Оверята, переулок Клубный, 4	f	large
64389	72071	1726	Пермский край, Краснокамск городской округ, поселок Оверята, Строителей, 7	f	large
64399	72082	1736	Пермский край, Краснокамск городской округ, село Мысы, Центральная, 1	f	large
64394	72053	1731	Пермский край, Краснокамск городской округ, село Конец Бор, Циолковского, 2	f	medium
64364	72053	1701	Пермский край, Краснокамск городской округ, село Конец Бор, Циолковского, 2	f	medium
64198	71875	1022	Пермский край, Краснокамск городской округ, село Залесная	t	small
64343	72015	1615	Пермский край, Красновишерский район, село Цепел, Первомайская, 22	t	small
64348	72026	1620	Пермский край, Красновишерский район, село Федорцова, Центральная, 40	t	small
64349	72027	1621	Пермский край, Красновишерский район, село Усть-Язьва	f	medium
64359	72046	1631	Пермский край, Красновишерский район, село Сыпучи	t	small
64347	72024	1619	Пермский край, Красновишерский район, село Северный Колчим, Победы, 12	t	medium
64637	72310	2411	Пермский край, Красновишерский район, нежилые населённые пункты Светлый, Промышленная, 6	f	medium
64354	72038	1626	Пермский край, Красновишерский район, село Набережный, Геологов, 1	t	small
112835	72047	1632	Пермский край, Красновишерский район, село Мутиха, Силовая, 8	t	small
64341	72014	1613	Пермский край, Красновишерский район, Красновишерск	f	large
64336	72009	1608	Пермский край, Красновишерский район, Красновишерск, Школьная, 5	f	large
64335	72008	1607	Пермский край, Красновишерский район, Красновишерск, Спортивная, 18	f	large
64333	72006	1605	Пермский край, Красновишерский район, Красновишерск, Советская, 19	f	large
62879	70560	131	Пензенская область, Пенза, Ульяновская, 34А	f	large
64334	72007	1606	Пермский край, Красновишерский район, Красновишерск, Куйбышева, 11	f	large
64331	72004	1603	Пермский край, Красновишерский район, Красновишерск, Комсомольская, 43	f	small
64332	72005	1604	Пермский край, Красновишерский район, Красновишерск, Дзержинского, 9 Б	f	large
64339	72012	1611	Пермский край, Красновишерский район, Красновишерск, 7-го Ноября, 24	t	small
64362	72049	1634	Пермский край, Красновишерский район, село Золотанка, Центральная, 16	t	small
64356	72040	1628	Пермский край, Красновишерский район, село Заговоруха, Мира, 11	t	small
64350	72029	1622	Пермский край, Красновишерский район, село Данилов Луг, Набережная, 11А	t	small
112819	72031	1623	Пермский край, Красновишерский район, село Губдор, Советская, 3	f	small
64358	72045	1630	Курская область, Рыльский район, поселок Волынка	t	small
64357	72043	1629	Пермский край, Красновишерский район, село Вишерогорск, Пионерская, 9	t	small
112803	60217	1614	Пермский край, Красновишерский район, село Верхняя Бычина, Новая, 10	t	small
112807	72018	1616	Пермский край, Красновишерский район, село Верх-Язьва, Советская, 28	f	medium
64363	72051	1635	Пермский край, Красновишерский район, село Велс, Северная, 15	t	small
112837	72048	1633	Пермский край, Красновишерский район, село Вая, Гагарина, 17б	t	small
64346	72021	1618	Пермский край, Красновишерский район, село Ванькова, Новая, 6	t	small
64353	72035	1625	Пермский край, Красновишерский район, село Березовая Старица, Трактовая, 6	t	small
113168	73141	5022	Красноярский край, Большемуртинский район, поселок Юксеево	f	medium
113147	73124	5008	Пермский край, Кочевский район, село Хазово	t	small
113149	73125	5009	Пермский край, Кочевский район, село Усть-Янчер, Устьянчерский ФАП	t	\N
113171	73143	5024	Пермский край, Кочевский район, село Усть-Силайка	t	small
113175	73147	5028	Пермский край, Кочевский район, село Усть-Онолва	t	small
113170	73142	5023	Пермский край, Кочевский район, село Серва, Здание Сервинской основной общеобразовательной школы	t	small
113150	73126	5010	Россия, Пермский край, Кочевский район, село Сеполь	f	small
113155	73130	5014	Пермский край, Кочевский район, село Пыстогово	t	small
113162	73135	5017	Пермский край, Кочевский район, село Пелым	f	medium
113163	73136	5018	Пермский край, Кочевский район, село Отопково	t	small
113167	73140	5021	Пермский край, Кочевский район, село Москвино, Москвинский ФАП	t	\N
113173	73145	5026	Пермский край, Кочевский район, село Мараты	f	small
113160	73133	5016	Пермский край, Кочевский район, село Мара-Пальник, МараПальниковский ФАП	t	\N
113146	73123	5007	Пермский край, Кочевский район, село Лягаево	t	small
113144	73121	5005	Пермский край, Кочевский район, село Кышка	t	small
113151	73127	5011	Пермский край, Кочевский район, село Кукушка, Кукушкинский ФАП	t	\N
113153	73128	5012	Пермский край, Кочевский район, село Красная Курья	t	small
113140	73118	5001	Пермский край, Кочевский район, село Кочево, Ленина, 10	f	medium
113143	73119	5004	Пермский край, Кочевский район, село Кочево, А.Хомяковой, 1	f	medium
113141	73119	5002	Пермский край, Кочевский район, село Кочево, А.Хомяковой, 1	f	medium
113142	73120	5003	Пермский край, Кочевский район, село Кочево, 50 лет Октября, 11	f	medium
65271	72759	3715	Пермский край, Кочевский район, село Васькино, Пушкина, 47	f	medium
113174	73146	5027	Пермский край, Кочевский район, село Буждым	t	small
113157	73131	5015	Пермский край, Кочевский район, село Борино, Боринский ФАП	t	\N
113154	73129	5013	Пермский край, Кочевский район, село Большая Коча	f	small
113172	73144	5025	Пермский край, Кочевский район, село Акилово	t	small
113123	73106	4910	Пермский край, Косинский район, село Чураки, Сельский клуб	t	\N
113114	73101	4904	Пермский край, Косинский район, село Чирково, клуб	t	small
113125	73107	4911	Пермский край, Косинский район, село Чазево, клуб	t	small
113135	73115	4916	Пермский край, Косинский район, село Усть-Коса, клуб	f	small
113248	73235	5405	Пермский край, Косинский район, село Трифаново, Молодежная, 1	f	small
113138	73116	4917	Пермский край, Косинский район, село Солым, Солымская начальная школа	f	\N
113119	73104	4907	Пермский край, Косинский район, село Пятигоры	t	small
113116	73102	4905	Пермский край, Косинский район, село Пуксиб, Пуксибская ООШ	f	\N
113118	73103	4906	Пермский край, Косинский район, село Порошево, Порошевская ООШ	t	\N
113134	73114	4915	Пермский край, Косинский район, село Новая Светлица, Светличанская ООШ	f	\N
113113	73100	4903	Пермский край, Косинский район, село Нижняя Коса, клуб	f	small
113120	73105	4908	Пермский край, Косинский район, село Левичи, Левичанская ООШ	t	\N
68487	73098	4901	Пермский край, Косинский район, село Коса, Ленина, 76, Дом культуры	f	large
113132	73112	4914	Пермский край, Косинский район, село Верх-Лель, клуб	t	small
113126	73109	4912	Пермский край, Косинский район, село Бачманово, Бачмановская ООШ	t	\N
64318	71993	1513	Пермский край, Кишертский район, село дом Отдыха Красный Яр	f	small
64316	71991	1511	Пермский край, Кишертский район, село Черный Яр, 34Б	f	small
64327	72000	1522	Пермский край, Кишертский район, село Усть-Кишерть, Строителей, 2А	f	medium
64326	71999	1521	Пермский край, Кишертский район, село Усть-Кишерть, Советская, 40	f	large
64324	59953	1519	Пермский край, Кишертский район, село Сухой Лог, Речная, 20	t	small
64319	71994	1514	Пермский край, Кишертский район, село Спасо-Барда, Советская, 7	f	small
64320	71995	1515	Пермский край, Кишертский район, село Седа, 80	f	small
64323	71998	1518	Пермский край, Кишертский район, село Посад, Советская, 18	f	small
64204	71881	1028	Пермский край, Кишертский район, село Никулино	f	small
64313	71988	1508	Пермский край, Кишертский район, село Молебка, Средняя, 5	f	small
64315	71990	1510	Пермский край, Кишертский район, село Меча, Юбилейная, 16	f	small
64314	71989	1509	Пермский край, Кишертский район, село Медведево, Центральная, 7	f	small
64317	71992	1512	Пермский край, Кишертский район, село Мазуевка, 61а	f	small
64309	71984	1504	Пермский край, Кишертский район, село Лек, Комсомольская, 20	f	small
113086	73080	4811	Пермский край, Кишертский район, село Красный Яр, Дом культуры	t	small
64310	71985	1505	Пермский край, Кишертский район, поселок Кордон, Советская, 9	f	medium
64311	71986	1506	Пермский край, Кишертский район, поселок Кордон, Первомайская, вокзал ст.Кордон	f	small
113112	73099	4902	Пермский край, Кишертский район, поселок Кордон, Карла Маркса, 88, Дом культуры	f	medium
65261	72749	3705	Пермский край, Кишертский район, село Киселево, Школьная, 14	f	medium
113012	73003	4607	Пермский край, Кишертский район, село Зуята, Дом культуры	f	small
64037	71725	417	Пермский край, Кишертский район, село Заборье, Школьная, 2, Дом культуры	f	small
64308	71983	1503	Пермский край, Кишертский район, село Верхняя Солянка, Школьная, 14	f	small
64023	71711	403	Пермский край, Кишертский район, село Березовка, Советская, 107, училище №68	f	medium
64302	71977	1413	Пермский край, Кизел городской округ, поселок Шахта, Баумана, 9	f	large
64304	71979	1415	Пермский край, Кизел городской округ, поселок Центральный Коспашский, Няровская, 7	f	large
64196	71873	1020	Пермский край, Карагайский район, село Ярино	t	small
64288	71967	1326	Пермский край, Карагайский район, село Юрич, Центральная, 10	f	small
64546	72219	2119	Пермский край, Карагайский район, село Шумиха, Советская, 1а	f	small
64206	71883	1030	Пермский край, Карагайский район, село Челва	t	small
113076	73074	4805	Пермский край, Карагайский район, село Харино, Маяковского, 26, Харинская ООШ	f	\N
64287	71966	1325	Пермский край, Карагайский район, село Фролово, Центральная, 3	f	small
64267	71946	1305	Пермский край, Карагайский район, село Сюзьвяки, Молодежная, 13	f	small
64286	71965	1324	Пермский край, Карагайский район, село Старая Пашня, Центральная, 2	f	small
64618	72289	2311	Пермский край, Карагайский район, село Сосновка, Молодежная, 6	f	small
64547	72220	2120	Пермский край, Карагайский район, село Сергино, Школьная, 29	f	small
64266	71945	1304	Пермский край, Карагайский район, село Савино, Центральная, 8А	f	medium
64265	71945	1303	Пермский край, Карагайский район, село Савино, Центральная, 8А	f	large
64285	71964	1323	Пермский край, Карагайский район, село Рождественск, Мира, 32	f	medium
64283	71962	1321	Пермский край, Карагайский район, село Обвинск, Советская, 21	f	medium
113045	73048	4654	Пермский край, Карагайский район, село Новоселы, Администрация сельского поселения	t	small
64280	71959	1318	Россия, Пермский край, Карагайский район, село Нердва	f	medium
64281	71960	1319	Пермский край, Карагайский район, село Нердва, Советская, 16	f	medium
64278	71957	1316	Пермский край, Карагайский район, село Менделеево, Октябрьская, 5	f	large
64276	71955	1314	Пермский край, Карагайский район, село Козьмодемьянск, Школьный, 1	f	medium
64268	71947	1306	Пермский край, Карагайский район, село Карагай, Энергетиков, 31А	f	large
64274	71953	1312	Пермский край, Карагайский район, село Карагай, Российская, 2	f	large
64270	71949	1308	Пермский край, Карагайский район, село Карагай, Кирова, 4	f	large
64273	71952	1311	Пермский край, Карагайский район, село Карагай, Дзержинского, 2	f	large
64275	71954	1313	Пермский край, Карагайский район, село Карагай, Гагарина, 23	f	medium
64269	71948	1307	Пермский край, Карагайский район, село Канюсята, Юбилейная, 16	f	small
64277	71956	1315	Пермский край, Карагайский район, село Кадилово, Центральная, 49А	f	small
64284	71963	1322	Пермский край, Карагайский район, село Воскресенск, 28	f	small
64053	71741	433	Пермский край, Карагайский район, село Ванькино, Центральная, 34, бывший ФАП	f	small
64263	71943	1301	Пермский край, Карагайский район, село Антонята, Молодежная, 32	f	small
64259	71939	1225	Пермский край, Ильинский район, Чермоз, Энгельса, 56	f	large
64260	71940	1226	Пермский край, Ильинский район, Чермоз, Ломоносова, 36	f	medium
64258	71938	1224	Пермский край, Ильинский район, Чермоз, Ломоносова, 20	f	medium
64250	71929	1216	Пермский край, Ильинский район, село Сретенское, Центральная, 2	f	large
64240	71919	1206	Пермский край, Ильинский район, село Слудка, Кирова, 37	f	small
65201	72702	3511	Пермский край, Ильинский район, село Сенино, Ленина, 10	t	small
64246	71925	1212	Пермский край, Ильинский район, село Садки, Дениса Лузина, 20	f	small
64257	71937	1223	Пермский край, Ильинский район, село Романово, Романовский СДК	t	small
65306	72797	3903	Пермский край, Ильинский район, село Романово, Школьная, 17	f	medium
64247	71926	1213	Пермский край, Ильинский район, село Посер, Победы, 8	f	medium
64238	71917	1204	Пермский край, Ильинский район, село Пепеляева, Дзержинского, 23	f	small
64239	71918	1205	Пермский край, Ильинский район, село Новая Каменка, Октябрьская, 2	f	small
64599	72270	2236	Пермский край, Ильинский район, село Мосино, СДК	f	small
112796	71923	1210	Пермский край, Ильинский район, село Мартыновцы, филиал Москвинская ООШ	t	\N
68476	73021	4626	Пермский край, Ильинский район, село Кыласово, Администрация сельского поселения	f	large
64256	71936	1222	Пермский край, Ильинский район, село Кыласово, Кыласовский СДК	t	small
64249	71928	1215	Пермский край, Ильинский район, село Кривец, Советская, 14	f	medium
64252	71931	1218	Пермский край, Ильинский район, село Комариха, Школьная, 9	f	small
64242	71921	1208	Пермский край, Ильинский район, село Комариха, Центральная, 15	f	small
64253	71932	1219	Пермский край, Ильинский район, село Каргино, Каргинский сельский клуб	f	small
64325	60061	1520	Пермский край, Ильинский район, село Ильята, 1	t	small
64237	71916	1203	Пермский край, Ильинский район, поселок Ильинский, Чкалова, 17	f	medium
64248	71927	1214	Пермский край, Ильинский район, поселок Ильинский, Рабочая, 11а	f	small
64235	71914	1201	Пермский край, Ильинский район, поселок Ильинский, Механизаторов, 9	f	medium
112798	71941	1227	Пермский край, Ильинский район, поселок Ильинский, Ленина, 62, СОШ №1	f	\N
64236	71915	1202	Пермский край, Ильинский район, поселок Ильинский, Ленина, 60	f	medium
64262	71942	1228	Пермский край, Ильинский район, поселок Ильинский, 50 лет Октября, 92	f	large
64254	71933	1220	Пермский край, Ильинский район, село Ивановское, Аликина, 1	f	small
113029	73029	4634	Пермский край, Ильинский район, село Ерши, Дом культуры	t	small
64255	71935	1221	Пермский край, Ильинский район, село Ерема, Ереминский сельский клуб	t	small
64251	71930	1217	Пермский край, Ильинский район, село Дмитриевское, Трактовая, 13	f	small
64307	71982	1502	Пермский край, Ильинский район, село Гари, 9	t	small
64245	71924	1211	Пермский край, Ильинский район, село Васильевское, Культуры, 11	f	small
65268	72756	3712	Пермский край, Ильинский район, село Бор, Центральная, 16	f	small
65320	72809	3917	Пермский край, Ильинский район, село Березовка, Молодежная, 35	t	medium
64234	71913	1120	Пермский край, Еловский район, село Ятыш, Советская, 13	f	small
64232	71911	1118	Пермский край, Еловский район, село Шумово, пр. Солнечный, 12	f	small
64228	71907	1114	Пермский край, Еловский район, село Шульдиха, Заречная, 44а	f	small
64222	71901	1108	Пермский край, Еловский район, село Суганка, Ленина, 46	f	small
64233	71912	1119	Пермский край, Еловский район, село Плишкино, Третья, 1	f	small
64227	71906	1113	Пермский край, Еловский район, село Плишкари, Центральная, 47	f	small
64226	71905	1112	Пермский край, Еловский район, село Осиновик, Юбилейная, 6	f	small
64225	71904	1111	Пермский край, Еловский район, село Нижняя Барда, Центральная, 46	f	small
68481	73046	4652	Пермский край, Еловский район, село Неволино, Средняя школа	f	large
64224	71903	1110	Пермский край, Еловский район, село Мичура, Советская, 30	f	small
64223	71902	1109	Пермский край, Еловский район, село Малая Уса, Белокаменная, 3	f	small
64230	71909	1116	Пермский край, Еловский район, село Куштомак, Центральная, 63	f	small
64221	71900	1107	Пермский край, Еловский район, село Крюково, Большая Северная, 43	f	small
64229	71908	1115	Пермский край, Еловский район, село Кресты, Уральская, 36	f	small
64218	71895	1104	Пермский край, Еловский район, село Елово, Комсомольская, 56	f	large
64217	71894	1103	Пермский край, Еловский район, село Елово, Карла Маркса, 17	f	large
64219	71896	1105	Пермский край, Еловский район, село Елово, Белинского, 10	f	large
64662	72336	2507	Пермский край, Еловский район, село Дуброво, Школьная, 23	f	medium
64216	71893	1102	Пермский край, Еловский район, село Дуброво, Чапаева, 30	f	medium
113060	73062	4711	Пермский край, Еловский район, село Городище, Мира, 14	f	medium
64215	71892	1101	Пермский край, Еловский район, село Брюхово, Злыгостева, 62	f	small
64282	71961	1320	Пермский край, Добрянка городской округ, село Ярино, Центральная, 5	f	medium
64212	71889	1036	Пермский край, Добрянка городской округ, село Усть-Гаревая	t	small
64205	71882	1029	Пермский край, Добрянка городской округ, село Таборы	t	small
68485	73066	4714	Пермский край, Добрянка городской округ, село Родники, Советская, 6	f	large
64193	71870	1017	Пермский край, Добрянка городской округ, поселок Полазна, Трухина, 83	f	large
64188	71865	1012	Пермский край, Добрянка городской округ, поселок Полазна, Советская, 10	f	medium
64189	71866	1013	Пермский край, Добрянка городской округ, поселок Полазна, Пяткина, 32а, МОУ ДОД Полазненская СДЮСШОР	f	large
64192	71869	1016	Пермский край, Добрянка городской округ, поселок Полазна, Нефтяников, 9, МУ Полазненский ЦТиД	f	large
64191	71868	1015	Пермский край, Добрянка городской округ, поселок Полазна, Дружбы, 5, МОУ Полазненская СОШ №3	f	large
64203	71880	1027	Пермский край, Добрянка городской округ, село Перемское	f	medium
64201	71878	1025	Пермский край, Добрянка городской округ, поселок Кыж, здание ФАП п. Кыж	t	small
64194	71871	1018	Пермский край, Добрянка городской округ, поселок Дивья	f	large
64209	71886	1033	Пермский край, Добрянка городской округ, село Висим	t	small
64200	71877	1024	Пермский край, Добрянка городской округ, поселок Вильва	f	large
64127	71810	711	Пермский край, Добрянка городской округ, поселок Вильва, Береговая, 4	t	small
63959	71663	305	Пермский край, Добрянка городской округ, село Березниковский, Яйвинская, 8	t	small
63962	71666	308	Пермский край, Добрянка городской округ, село Березниковский, Юбилейная, 11	f	large
64009	71700	355	Пермский край, Добрянка городской округ, село Березниковский, Свердлова, 154А	f	large
64008	71700	354	Пермский край, Добрянка городской округ, село Березниковский, Свердлова, 154А	f	large
64002	71696	348	Пермский край, Добрянка городской округ, село Березниковский, Свердлова, 79	f	large
63980	71680	326	Пермский край, Добрянка городской округ, село Березниковский, Свердлова, 27	f	large
63983	71682	329	Пермский край, Добрянка городской округ, село Березниковский, Пятилетки, 140	f	large
63955	71659	301	Пермский край, Добрянка городской округ, село Березниковский, Преображенского, 19	f	large
68523	71703	358	Пермский край, Добрянка городской округ, село Березниковский, Мира, 98а	f	large
63970	71672	316	Пермский край, Добрянка городской округ, село Березниковский, Ленина проспект, 50	f	medium
63973	71674	319	Пермский край, Добрянка городской округ, село Березниковский, Карла Маркса, 49	f	large
64174	71851	923	Пермский край, Губаха городской округ, поселок Широковский, Пионеров, 9	t	medium
64176	71853	925	Пермский край, Губаха городской округ, село Шестаки, ж/д станция	t	small
64171	71849	920	Пермский край, Губаха городской округ, поселок Углеуральский, Углеуральская, 17	t	small
64165	71844	914	Пермский край, Губаха городской округ, поселок Углеуральский, Мира, 32	f	large
112737	71848	919	Пермский край, Губаха городской округ, поселок Углеуральский, Белинского, 55	t	medium
64172	71850	921	Пермский край, Губаха городской округ, поселок Углеуральский, Базовая	t	small
64169	71847	918	Пермский край, Губаха городской округ, поселок Углеуральский, 2я Коммунистическая, 106	f	small
64168	71847	917	Пермский край, Губаха городской округ, поселок Углеуральский, 2я Коммунистическая, 106	f	large
64166	71845	915	Пермский край, Губаха городской округ, поселок Углеуральский, 2ая Коммунистическая, 105	f	medium
64167	71846	916	Пермский край, Губаха городской округ, поселок Углеуральский, 150 лет КУБ, 32	f	medium
64173	59745	922	Пермский край, Губаха городской округ, село 20-й километр, Зеленая	t	small
64149	71829	812	Пермский край, Гремячинск городской округ, поселок Шумихинский, Мира, 19	f	large
64129	71812	713	Пермский край, Горнозаводский район, поселок Теплая Гора, Советская, 75	f	large
64130	71813	714	Пермский край, Горнозаводский район, поселок Теплая Гора, 1го Мая, 11	f	large
64132	71815	716	Пермский край, Горнозаводский район, поселок Старый Бисер, Октябрьская, 12	f	small
64131	71814	715	Пермский край, Горнозаводский район, поселок Сараны, Кирова, 20	f	medium
64134	71817	718	Пермский край, Горнозаводский район, поселок Промысла, Советская, 2	f	medium
64126	71809	710	Пермский край, Горнозаводский район, поселок Пашия, Ленина, 4	f	medium
64125	71808	709	Пермский край, Горнозаводский район, поселок Пашия, Ленина, 7	f	large
64124	71807	708	Пермский край, Горнозаводский район, поселок Пашия, Ленина, 16	f	large
64135	71818	719	Пермский край, Горнозаводский район, поселок Медведка, Строек Коммунизма, 2	f	medium
64128	71811	712	Пермский край, Горнозаводский район, поселок Кусье-Александровский, Ленина, 2	f	large
64119	71805	705	Пермский край, Горнозаводский район, Горнозаводск, Свердлова, 59	f	large
64116	71803	702	Пермский край, Горнозаводский район, Горнозаводск, Свердлова, 62	f	large
64115	71803	701	Пермский край, Горнозаводский район, Горнозаводск, Свердлова, 62	f	large
64118	71804	704	Пермский край, Горнозаводский район, Горнозаводск, 30 лет Победы, 14	f	large
64117	71804	703	Пермский край, Горнозаводский район, Горнозаводск, 30 лет Победы, 14	f	large
113055	73057	4706	Пермский край, Горнозаводский район, село Вильва, Советская, 3	f	small
64133	71816	717	Пермский край, Горнозаводский район, село Бисер, Советская, 23	f	medium
64214	71891	1038	Пермский край, Гайнский район, поселок разрушенный Камский	t	small
113097	73088	4819	Пермский край, Гайнский район, село Шордын	t	small
113101	73092	4823	республика Башкортостан, Стерлитамакский район, село Чуртан	t	\N
113079	73076	4807	Пермский край, Гайнский район, село Чажегово, Дом культуры	t	small
113108	73095	4826	Пермский край, Гайнский район, село Усть-Черная, Больничная, 17, СОШ	f	\N
113080	73077	4808	Пермский край, Гайнский район, село Усть-Весляна, Школьная, 4, Шуминская ООШ	f	\N
113082	73078	4809	Пермский край, Гайнский район, село Сосновая, Центральная, 8а	t	\N
113087	73081	4812	Пермский край, Гайнский район, село Сергеевский, Дом культуры	f	medium
113100	73091	4822	Пермский край, Гайнский район, село Сейва, Дом культуры	f	medium
64692	72365	2624	Пермский край, Гайнский район, поселок Пурга, Центральная, 4	t	small
113104	73093	4824	Пермский край, Гайнский район, село Оныл, Школьная, 6а, ООШ	t	\N
113093	73085	4816	Пермский край, Гайнский район, село Луным, Начальная школа	t	small
113094	73086	4817	Россия, Чукотский автономный округ, Билибинский район, поселок Лель	t	small
113109	73096	4827	Пермский край, Гайнский район, село Керосс, Ленина, 24	f	\N
113096	73087	4818	Пермский край, Гайнский район, село Кебраты, Пионерская, 19, СОШ	f	\N
113090	73083	4814	Пермский край, Гайнский район, село Касимовка, Кунгурская, 6, ООШ	t	\N
113088	73082	4813	Пермский край, Гайнский район, село Имасы, Начальная школа	t	small
113085	73079	4810	Пермский край, Гайнский район, село Иванчино	t	\N
113099	73090	4821	Пермский край, Гайнский район, село Жемчужный, Основная школа	t	small
113077	73075	4806	Пермский край, Гайнский район, село Данилово, Дом культуры	f	\N
68486	73072	4803	Пермский край, Гайнский район, поселок Гаины, Коммунистическая, 33	f	large
113073	73071	4802	Пермский край, Гайнский район, поселок Гаины, Дзержинского, 7	f	medium
113072	73070	4801	Пермский край, Гайнский район, поселок Гаины, Дзержинского, 40	f	medium
113074	73073	4804	Пермский край, Гайнский район, поселок Гаины, Железнодорожная, Дом культуры	f	small
113092	73084	4815	Пермский край, Гайнский район, село Верхняя Старица, Карла Маркса, 16а, ООШ	f	\N
113098	73089	4820	Пермский край, Гайнский район, село Верхний Будым, основная школа	t	small
113111	73097	4828	Пермский край, Гайнский район, село Базуево, Начальная школа	t	small
64108	71796	632	Пермский край, Верещагинский район, село Федяшино	f	small
64093	71781	617	Пермский край, Верещагинский район, село Субботники, Советская, 24	f	small
64105	71793	629	Пермский край, Верещагинский район, село Соболята, Центральная, 39	f	small
64110	71798	634	Пермский край, Верещагинский район, село Сепыч, Ленина, 14	f	large
64092	71780	616	Пермский край, Верещагинский район, село Рябины, Птицеводов, 3	f	medium
64107	71795	631	Пермский край, Верещагинский район, село Путино, Комсомольская, 16	f	large
64322	71997	1517	Пермский край, Верещагинский район, село Посад, Школьная, 3	f	medium
112725	71782	618	Пермский край, Верещагинский район, село Нижнее Галино, Советская, 11	f	\N
64032	71720	412	Пермский край, Верещагинский район, село Мартелы, 9, бывший ФАП	t	small
64099	71787	623	Пермский край, Верещагинский район, село Ленино, Гагарина, 14	f	medium
64106	71794	630	Пермский край, Верещагинский район, село Кукеты, Молодежная, 18	f	small
64103	71791	627	Пермский край, Верещагинский район, село Кукетский, Ленина, 2	f	medium
64095	71783	619	Пермский край, Верещагинский район, село Комары, Молодежная, 1	f	medium
64101	71789	625	Пермский край, Верещагинский район, поселок Зюкайка, Пугачева, 42	f	large
64102	71790	626	Пермский край, Верещагинский район, поселок Зюкайка, Мичурина, 1	f	large
64100	71788	624	Пермский край, Верещагинский район, поселок Зюкайка, Ленина, 1	f	medium
64289	71950	1309	Пермский край, Верещагинский район, село Зюкай, Ленина, 9	f	small
64097	71785	621	Пермский край, Верещагинский район, село Вознесенское, Ленина, 19	f	medium
64096	71784	620	Пермский край, Верещагинский район, село Вознесенское, Ленина, 11а	f	medium
64080	71769	604	Пермский край, Верещагинский район, Верещагино, Энергетиков, 22	f	small
64084	71773	608	Пермский край, Верещагинский район, Верещагино, Ленина, 10	f	large
64089	71761	613	Пермский край, Верещагинский район, Верещагино, Ленина, 27	f	large
64090	71778	614	Пермский край, Верещагинский район, Верещагино, Коммунистическая, 56	f	large
64082	71771	606	Пермский край, Верещагинский район, Верещагино, Карла Маркса, 2	f	large
64083	71772	607	Пермский край, Верещагинский район, Верещагино, К.Маркса, 56	f	large
112723	71777	612	Пермский край, Верещагинский район, Верещагино, Звезды, 65	f	\N
64079	71768	603	Пермский край, Верещагинский район, Верещагино, Железнодорожная, 16	f	medium
64078	71767	602	Пермский край, Верещагинский район, Верещагино, Железнодорожная, 25	f	large
64682	72357	2614	Пермский край, Верещагинский район, Верещагино, Дорожная, 10	t	small
64081	71770	605	Пермский край, Верещагинский район, Верещагино, Верещагинская, 8	f	large
64109	71797	633	Пермский край, Верещагинский район, село Бородулино, 1 Мая, 41	f	medium
64104	71792	628	Пермский край, Верещагинский район, село Бородули, Центральная, 11	f	medium
64098	71786	622	Пермский край, Верещагинский район, село Аникино	f	small
64075	71764	518	Пермский край, Большесосновский район, село Юрково, Заречная, 24	f	small
64074	71763	517	Пермский край, Большесосновский район, село Черновское, Ленина, 8	f	large
64073	71762	516	Пермский край, Большесосновский район, село Тойкино, Молодежная, 3	f	small
64072	71746	515	Пермский край, Большесосновский район, село Солоды, Молодежная, 13	f	small
64071	71760	514	Пермский край, Большесосновский район, село Полозово, Центральная, 22	f	small
64070	71759	513	Пермский край, Большесосновский район, село Петропавловск, Гагарина, 39 А	f	medium
64069	71758	512	Пермский край, Большесосновский район, село Пермяки, Мира, 16	f	small
64068	71757	511	Пермский край, Большесосновский район, село Нижний Лып, Нагорная, 6	f	small
64067	71756	510	Пермский край, Большесосновский район, село Малая Соснова, Ленина, 6	f	small
64558	72232	2131	Пермский край, Большесосновский район, село Луговая, Центральная, 39	f	small
62878	70560	130	Пензенская область, Пенза, Ульяновская, 34А	f	large
64066	71755	509	Пермский край, Большесосновский район, село Лисья, Школьная, 13	f	small
64065	71754	508	Пермский край, Большесосновский район, село Левино, Специалистов, 1	f	small
112721	71765	519	Пермский край, Большесосновский район, село Красный Яр, Октябрьская, 5	f	\N
64064	71753	507	Пермский край, Большесосновский район, село Кленовка, Новая, 4	f	small
64063	71752	506	Пермский край, Большесосновский район, село Заболотово, Школьная, 6	f	small
64062	71751	505	Пермский край, Большесосновский район, село Верх-Потка, Дружбы, 13	f	small
64059	71748	502	Пермский край, Большесосновский район, село Большая Соснова, Ленина, 31	f	large
64058	71747	501	Пермский край, Большесосновский район, село Большая Соснова, Ленина, 31	f	large
64061	71750	504	Пермский край, Большесосновский район, село Бердышево, Набережная, 13	f	medium
64060	71749	503	Пермский край, Большесосновский район, село Баклуши, переулок Полевой, 2	f	small
64513	72186	2036	Пермский край, Березовский район, село Шаква, Центральная, 1	f	small
113247	73234	5404	Пермский край, Березовский район, село Харино, Центральная, 5	f	small
64241	71920	1207	Пермский край, Березовский район, село Филатово, Никольского, 12	f	medium
64031	71719	411	Пермский край, Березовский район, село Туясы, Центральная, 6, Дом культуры	f	small
64050	71738	430	Пермский край, Березовский район, село Тулумбасы, Железнодорожная, 8 , бывший ФАП	t	small
64049	71737	429	Пермский край, Березовский район, село Таз-Русский, Садовая, 10, ФАП	f	small
64036	71724	416	Пермский край, Березовский район, село Сая, Южная, 27, Дом культуры	f	small
64040	71728	420	Пермский край, Березовский район, село Рыжково, 20, Дом культуры	f	small
64030	71718	410	Пермский край, Березовский район, село Пуздрино, 78	f	small
64057	71745	437	Пермский край, Березовский район, село Проносное, Центральная, 9, администрация сельского поселения	f	small
64056	71744	436	Пермский край, Березовский район, село Полушкино, Свободы, 3, Частный дом Потапова	f	small
64055	71743	435	Пермский край, Березовский район, село Подволошино, Центральная, 3, Дом культуры	f	small
64736	72407	2742	Пермский край, Березовский район, село Песьянка, Мелиораторов, 9	f	large
64051	71739	431	Пермский край, Березовский район, село Перебор, Центральная, 49, Школа	t	small
64028	71716	408	Пермский край, Березовский район, село Пентюрино, 54, сельский клуб	t	small
64035	71723	415	Пермский край, Березовский район, село Метальниково, Дружбы, 16	f	small
64046	71734	426	Пермский край, Березовский район, село Мачино, Молодежная, 6, бывший ФАП	t	small
64048	71736	428	Пермский край, Березовский район, село Марково, Центральная, 14, Частный дом Ржанниковой	f	small
64045	71733	425	Пермский край, Березовский район, село Малыши, Центральная, 18, ветучасток	f	small
64027	71715	407	Пермский край, Березовский район, село Копчиково, Школьная, 7, сельская библиотека	f	small
64047	71735	427	Пермский край, Березовский район, село Кляпово, Мичурина, 38 , администрация СП	f	small
64041	71729	421	Пермский край, Березовский район, село Клычи, Школьная, 2, бывшая школа	t	small
64039	71727	419	Пермский край, Березовский район, село Карнаухово, Школьная, 2 , бывшая школа детский сад	t	small
64044	71732	424	Пермский край, Березовский район, село Зернино, Мира, 12, Дом культуры	f	small
64042	71730	422	Пермский край, Березовский район, село Зарека, административное здание ИП Сергеев	t	small
64034	71722	414	Пермский край, Березовский район, село Дубовое, Школьная, 6, Правление колхоза	f	medium
64043	71731	423	Пермский край, Березовский район, село Батерики, Школьная, 7, Дом культуры	f	small
64593	72264	2230	Пермский край, Березовский район, село Бартым, сдк	f	small
64021	71709	401	Пермский край, Березовский район, село Асово, Советская, 57, администрации Асовского СП	f	small
64022	71710	402	Пермский край, Березовский район, село Асово, Мира, 30, Школа	f	small
64033	71721	413	Пермский край, Березовский район, село Антонково, Нагорная, 2, Дом культуры	f	small
64649	72323	2423	Пермский край, Березники городской округ, поселок Яйвинский Рейд, Школьная, 1	f	small
65309	72800	3906	Пермский край, Березники городской округ, Усолье, Чернышевского, 9	f	medium
65308	72799	3905	Пермский край, Березники городской округ, Усолье, Солеваров, 161	f	medium
65304	72795	3901	Пермский край, Березники городской округ, Усолье, Свободы, 155	f	medium
112957	72810	3919	Пермский край, Березники городской округ, Усолье, Первомайская, 1б	f	medium
65305	72796	3902	Пермский край, Березники городской округ, Усолье, Елькина, 13/1	f	medium
65310	72801	3907	Пермский край, Березники городской округ, Усолье, 8 марта, 28	f	medium
68534	94310	3916	Пермский край, Березники городской округ, село Железнодорожный, Центральная, 31	f	large
63951	71655	245	Пермский край, Бардымский район, село Шермейка, Советская, 6	f	small
63950	71654	244	Пермский край, Бардымский район, село Шабарка, Центральная, 18	f	small
63915	71621	209	Пермский край, Бардымский район, село Чалково, Зеленая, 2	f	small
63949	71653	243	Пермский край, Бардымский район, село Федорки, Ленина, 50	f	small
63924	71628	218	Пермский край, Бардымский район, село Учкул, Нагорная, 5	f	small
63927	71631	221	Пермский край, Бардымский район, село Усть-Тунтор, Ленина, 22	f	small
63947	71651	241	Пермский край, Бардымский район, село Усть-Ашап, Ленина, 44	f	small
63948	71652	242	Пермский край, Бардымский район, село Уймуж, Советская, 24	f	small
63908	71614	202	Пермский край, Бардымский район, село Тюндюк, Ленина, 33	f	medium
63946	71650	240	Пермский край, Бардымский район, село Танып, Ленина, 20А	f	medium
63921	58684	215	Пермский край, Бардымский район, село Сюзянь, Ленина, 50	f	small
63945	71649	239	Пермский край, Бардымский район, село Султанай, Мусы Джалиля, 5	f	small
63916	71622	210	Пермский край, Бардымский район, село Старый Чад, Ленина, 10	f	small
63910	71616	204	Пермский край, Бардымский район, село Старый Ашап, Ленина, 5	f	small
63944	71648	238	Пермский край, Бардымский район, село Сараши, Советская, 10	f	large
63941	71645	235	Пермский край, Бардымский район, село Печмень, Советская, 7	f	small
63940	71644	234	Пермский край, Бардымский район, село Новый Чад, Дружбы, 23	f	small
63935	71639	229	Пермский край, Бардымский район, село Новый Ашап, Ленина, 49	f	small
63938	71642	232	Пермский край, Бардымский район, село Новая Казанка, Мира, 52	f	small
63937	71641	231	Пермский край, Бардымский район, село Никольск, Блюхера, 36	t	small
63943	71647	237	Пермский край, Бардымский район, село Нижняя Искильда, Советская, 7	t	small
63914	71620	208	Пермский край, Бардымский район, село Мостовая, Центральная, 40	f	small
63933	71637	227	Пермский край, Бардымский район, село Куземьярово, Ленина, 19	f	small
63934	71638	228	Пермский край, Бардымский район, село Кудаш, Ленина, 49	f	small
63932	71636	226	Пермский край, Бардымский район, село Краснояр 2-й, Карла Маркса, 9В	f	medium
63931	71635	225	Пермский край, Бардымский район, село Краснояр 1-й, Ленина, 69А	f	large
63926	71630	220	Пермский край, Бардымский район, село Конюково, Ленина, 23	f	small
63929	71633	223	Пермский край, Бардымский район, село Константиновка, Ленина, 52	f	small
63930	71634	224	Пермский край, Бардымский район, село Кармановка, Центральная, 26	f	small
63918	71624	212	Пермский край, Бардымский район, село Ишимово, Ленина, 4	f	small
63928	71632	222	Пермский край, Бардымский район, село Искирь, Ленина, 93	f	small
63942	71646	236	Пермский край, Бардымский район, село Зязелга, Колхозная, 1	f	small
65441	72920	4322	Пермский край, Бардымский район, село Ермия, Администрация	f	small
63925	71629	219	Пермский край, Бардымский район, село Елпачиха, Советская, 2	f	large
63936	71640	230	Пермский край, Бардымский район, село Верхний Ашап, Фрунзе, 19	t	small
63939	71643	233	Пермский край, Бардымский район, село Верхне-Шлык, Центральная, 23	f	small
63919	71625	213	Пермский край, Бардымский район, село Брюзли, Молодежная, 9	f	small
63922	59579	216	Пермский край, Бардымский район, село Бичурино, Ленина, 47	f	large
63917	71623	211	Пермский край, Бардымский район, село Березники, Советская, 11	f	small
63920	71626	214	Пермский край, Бардымский район, село Батырбай, Мусы Джалиля, 12	f	small
63923	71627	217	Пермский край, Бардымский район, село Бардабашка 1-я, Ленина, 22	f	small
63954	71658	248	Пермский край, Бардымский район, село Барда, Советская, 19	f	large
63953	71657	247	Пермский край, Бардымский район, село Барда, Ленина, 39	f	large
63911	71617	205	Пермский край, Бардымский район, село Барда, Ленина, 39	f	large
63912	71618	206	Пермский край, Бардымский район, село Барда, Кирова, 17	f	large
63913	71619	207	Пермский край, Бардымский район, село Барда, Газовиков	f	large
63952	71656	246	Пермский край, Бардымский район, село Антуфьево, Центральная, 9	f	small
63909	71615	203	Пермский край, Бардымский район, село Аклуши, Ленина, 41	f	small
63907	71613	201	Пермский край, Бардымский район, село Акбаш, Ленина, 8	f	small
63905	71611	121	Пермский край, Александровский район, село Лытвенский, 9-ой Пятилетки, 2	t	small
63896	71602	112	Пермский край, Александровск городской округ, поселок Яйва, Парковая, 11	f	large
63895	71602	111	Пермский край, Александровск городской округ, поселок Яйва, Парковая, 11	f	large
112705	71601	110	Пермский край, Александровск городской округ, поселок Яйва, Коммунистическая, 9	f	medium
63898	71604	114	Пермский край, Александровск городской округ, поселок Яйва, Заводская, 21	f	large
63897	71603	113	Пермский край, Александровск городской округ, поселок Яйва, 6 Пятилетки, 23	f	large
63904	71610	120	Пермский край, Александровск городской округ, село Усть-Игум, Советская, 20	f	medium
63906	71612	122	Пермский край, Александровск городской округ, село Скопкортная, Ленина, 2	t	medium
113000	72985	4445	Пермский край, Александровск городской округ, село Мыс, филиал ВерхнеКалинского районого дома культуры	t	small
63903	71609	119	Пермский край, Александровск городской округ, поселок Луньевка, Пушкина, 8	f	small
63902	71608	118	Пермский край, Александровск городской округ, село Карьер Известняка, Мира, 1	f	large
64644	72318	2418	Пермский край, Александровск городской округ, село Гремяча, Азина, 10	f	medium
64197	71874	1021	Россия, Тверская область, Пеновский район, поселок Гари	t	small
63899	71605	115	Пермский край, Александровск городской округ, поселок Всеволодо-Вильва, Луначарского, 1 а, каб. 5	f	large
63900	71606	116	Пермский край, Александровск городской округ, поселок Всеволодо-Вильва, Лоскутова, 7	f	medium
64352	72033	1624	Пермский край, Александровск городской округ, село Булатово, Центральная, 17	t	small
63719	71365	984	Пензенская область, станция Кривозеровка, Железнодорожная, 5-1	t	small
63112	70748	362	Пензенская область, поселок Ухтинка, Южная, 1 А	f	large
63768	71411	1033	Пензенская область, Сердобск, Строительный переулок, 6	f	large
63771	71414	1036	Пензенская область, Сердобск, Советская, 1	f	large
63772	71415	1037	Пензенская область, Сердобск, Сережникова, 10	f	large
63757	71347	1022	Пензенская область, Сердобск, Ленина, 61	f	large
62959	70617	211	Пензенская область, Пенза, ФКОУ Учебный центр УФСИН России по Пензенской области	f	large
63754	71399	1019	Пензенская область, Пенза, улица Чаадаева, 2б	f	small
62885	70564	137	Пензенская область, Пенза, поселок Арбеково, улица Минская, 17	f	large
62781	70487	33	Пензенская область, Пенза, улица Касаткина, 8	f	large
62762	70487	14	Пензенская область, Пенза, улица Касаткина, 8	f	large
62794	70509	46	Пензенская область, Пенза, улица 8 Марта, 21а	f	large
62793	70509	45	Пензенская область, Пенза, улица 8 Марта, 21а	f	large
62841	70541	93	Пензенская область, Пенза, проспект Строителей, 47	f	large
62975	70457	227	Пензенская область, Пенза, проспект Строителей, 11	f	large
62884	70563	136	Пензенская область, Пенза, проспект Победы, 85	f	large
62883	70563	135	Пензенская область, Пенза, проспект Победы, 85	f	large
62877	70559	129	Пензенская область, Пенза, проспект Победы, 109	f	large
62876	70559	128	Пензенская область, Пенза, проспект Победы, 109	f	large
62875	70559	127	Пензенская область, Пенза, проспект Победы, 109	f	large
62828	70535	80	Пензенская область, Пенза, набережная Реки Пензы, 3а	f	large
62880	70561	132	Пензенская область, Пенза, Юбилейная, 13	f	large
62958	70616	210	Пензенская область, Пенза, Экспериментальная, 6а	f	large
62957	70616	209	Пензенская область, Пенза, Экспериментальная, 6а	f	large
62956	70615	208	Пензенская область, Пенза, Экспериментальная, 5	f	large
63740	71386	1005	Пензенская область, Сердобский район, Школьная, 7	f	large
62818	70525	70	Пензенская область, Пенза, Шевченко, 19	f	large
62915	70585	167	Пензенская область, Пенза, Чкалова, 68	f	large
62773	70496	25	Пензенская область, Пенза, Чаадаева, 119	f	large
63647	71273	895	Пензенская область, Пенза, Центральная, 33	f	small
63190	70827	444	Пензенская область, Пенза, Центральная, 2	f	small
62960	70618	212	Пензенская область, Пенза, Центральная, 1	f	medium
62775	70491	27	Пензенская область, Пенза, Хользунова, 27/30	f	large
62766	70491	18	Пензенская область, Пенза, Хользунова, 27/30	f	large
62777	70498	29	Пензенская область, Пенза, Ушакова, 15	f	large
62952	70612	204	Пензенская область, Пенза, Терновского, 168	f	large
62951	70612	203	Пензенская область, Пенза, Терновского, 168	f	large
62950	70612	202	Пензенская область, Пенза, Терновского, 168	f	large
62949	70611	201	Пензенская область, Пенза, Терновского, 127А	f	large
62927	70594	179	Пензенская область, Пенза, Тепличная, 18	f	large
62926	70594	178	Пензенская область, Пенза, Тепличная, 18	f	large
62763	70488	15	Пензенская область, Пенза, Тарханова, 10А	f	large
62917	70587	169	Пензенская область, Пенза, Тамбовская, 20	f	large
62955	70614	207	Пензенская область, Пенза, Сухумский проезд, 8	f	large
62817	70521	69	Пензенская область, Пенза, Суворова, 190А	f	large
62811	70521	63	Пензенская область, Пенза, Суворова, 190А	f	large
62806	70517	58	Пензенская область, Пенза, Суворова, 198	f	large
62860	70551	112	Пензенская область, Пенза, Строителей проспект, 7	f	large
62859	70551	111	Пензенская область, Пенза, Строителей проспект, 7	f	large
62858	70551	110	Пензенская область, Пенза, Строителей проспект, 7	f	large
62970	70627	222	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 20	f	large
62852	70546	104	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 46	f	large
62851	70546	103	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 46	f	large
62850	70545	102	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 52а	f	large
62849	70545	101	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 52а	f	large
68455	70542	96	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 140	f	large
62843	70542	95	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 140	f	large
62842	70542	94	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 140	f	large
68456	70542	97	Пензенская область, Пенза, поселок Арбеково, Строителей проспект, 140	f	large
68453	70508	44	Пензенская область, Пенза, Спартаковская, 9	f	large
62778	70499	30	Пензенская область, Пенза, Сосновка, 7	f	large
62923	70592	175	Пензенская область, Пенза, Совхоз-техникум, ФГОУ СПО Пензенский аграрный техникум	f	large
63204	70842	458	Пензенская область, Пенза, Советская, 39	f	large
62870	70556	122	Пензенская область, Пенза, Собинова, 7к1	f	large
62869	70556	121	Пензенская область, Пенза, Собинова, 7к1	f	large
62868	70555	120	Пензенская область, Пенза, Собинова, 9	f	small
62848	70544	100	Пензенская область, Пенза, Собинова, 6	f	large
62847	70544	99	Пензенская область, Пенза, Собинова, 6	f	large
62772	70495	24	Пензенская область, Пенза, Складская, 19	f	large
62948	70610	200	Пензенская область, Пенза, Ростовская, 58	f	large
62921	70590	173	Пензенская область, Пенза, Российская, 53	f	large
62920	70590	172	Пензенская область, Пенза, Российская, 53	f	large
62874	70558	126	Пензенская область, Пенза, Рахманинова, 37а	f	large
62873	70558	125	Пензенская область, Пенза, Рахманинова, 37а	f	large
62872	70558	124	Пензенская область, Пенза, Рахманинова, 37а	f	large
62863	70552	115	Пензенская область, Пенза, Рахманинова, 21	f	large
62862	70552	114	Пензенская область, Пенза, Рахманинова, 21	f	large
62861	70552	113	Пензенская область, Пенза, Рахманинова, 21	f	large
62819	70526	71	Пензенская область, Пенза, Пушкина, 31а	f	large
62809	70519	61	Пензенская область, Пенза, Пушкина, 137	f	large
62808	70519	60	Пензенская область, Пенза, Пушкина, 137	f	large
62764	70489	16	Пензенская область, Пенза, Проходная, 3	f	large
62754	70481	6	Пензенская область, Пенза, Пролетарская, 26а	f	large
62753	70481	5	Пензенская область, Пенза, Пролетарская, 26а	f	large
62752	70481	4	Пензенская область, Пенза, Пролетарская, 26а	f	large
62904	70577	156	Пензенская область, Пенза, Попова, 14	f	large
62903	70577	155	Пензенская область, Пенза, Попова, 14	f	large
62888	70566	140	Пензенская область, Пенза, Победы проспект, 41	f	large
62887	70565	139	Пензенская область, Пенза, Победы проспект, 78	f	large
62886	70565	138	Пензенская область, Пенза, Победы проспект, 78	f	large
62803	70514	55	Пензенская область, Пенза, Победы проспект, 3	f	large
62802	70514	54	Пензенская область, Пенза, Победы проспект, 3	f	large
62801	70513	53	Пензенская область, Пенза, Победы проспект, 25	f	large
62822	70529	74	Пензенская область, Пенза, Плеханова, 15	f	large
62925	70593	177	Пензенская область, Пенза, Пермская, 1	f	large
62924	70593	176	Пензенская область, Пенза, Пермская, 1	f	large
62783	70501	35	Пензенская область, Пенза, Перекоп, 4	f	large
62782	70501	34	Пензенская область, Пенза, Перекоп, 4	f	large
62780	70500	32	Пензенская область, Пенза, Парковая, 2	f	large
62779	70500	31	Пензенская область, Пенза, Парковая, 2	f	large
62944	70606	196	Пензенская область, Пенза, Отдельная, 9	f	medium
62800	70512	52	Пензенская область, Пенза, Островского, 8	f	large
62799	70512	51	Пензенская область, Пенза, Островского, 8	f	large
62798	70512	50	Пензенская область, Пенза, Островского, 8	f	large
62854	70547	106	Пензенская область, Пенза, Онежская, 11	f	large
62853	70547	105	Пензенская область, Пенза, Онежская, 11	f	large
62761	70486	13	Пензенская область, Пенза, Октябрьская, 2	f	large
62922	70591	174	Пензенская область, Пенза, Окружная, 115Б	f	medium
63685	71328	950	Пензенская область, Пенза, Новая, 13	t	small
62751	70480	3	Пензенская область, Пенза, Насосная, 1	f	large
62750	70480	2	Пензенская область, Пенза, Насосная, 1	f	large
62864	70553	116	Пензенская область, Пенза, Мусоргского, 17	f	large
62825	70532	77	Пензенская область, Пенза, Московская, 82в	f	large
62760	70485	12	Пензенская область, Пенза, Московская, 115	f	large
62776	70497	28	Пензенская область, Пенза, Молодогвардейская, 46А	f	large
62902	70576	154	Пензенская область, Пенза, Можайского, 1	f	large
62901	70576	153	Пензенская область, Пенза, Можайского, 1	f	large
62900	70576	152	Пензенская область, Пенза, Можайского, 1	f	large
62908	70579	160	Пензенская область, Пенза, Мира, 62	f	large
62907	70579	159	Пензенская область, Пенза, Мира, 62	f	large
62906	70578	158	Пензенская область, Пенза, Мира, 15	f	large
62905	70578	157	Пензенская область, Пенза, Мира, 15	f	large
62882	70562	134	Пензенская область, Пенза, Минская, 6а	f	large
62881	70562	133	Пензенская область, Пенза, Минская, 6а	f	large
62947	70609	199	Пензенская область, Пенза, Мебельная, 61б	f	large
62937	70601	189	Пензенская область, Пенза, Маркина, 2а	f	large
62840	70540	92	Пензенская область, Пенза, Лядова, 14	f	large
62839	70540	91	Пензенская область, Пенза, Лядова, 14	f	large
62838	70539	90	Пензенская область, Пенза, Лядова, 50	f	large
62837	70539	89	Пензенская область, Пенза, Лядова, 50	f	large
62836	70539	88	Пензенская область, Пенза, Лядова, 50	f	large
62757	70482	9	Пензенская область, Пенза, Луначарского, 10	f	large
62756	70482	8	Пензенская область, Пенза, Луначарского, 10	f	large
62755	70482	7	Пензенская область, Пенза, Луначарского, 10	f	large
62785	70502	37	Пензенская область, Пенза, Луговая, 1а	f	large
62784	70502	36	Пензенская область, Пенза, Луговая, 1а	f	large
62749	70479	1	Пензенская область, Пенза, Литвинова, 21а	f	large
62913	70583	165	Пензенская область, Пенза, Лермонтова, 8А	f	large
62910	70580	162	Пензенская область, Пенза, Ленинградская, 1а	f	large
62909	70580	161	Пензенская область, Пенза, Ленинградская, 1а	f	large
62898	70574	150	Пензенская область, Пенза, Ленина, 8а	f	large
62897	70574	149	Пензенская область, Пенза, Ленина, 8а	f	large
62835	70538	87	Пензенская область, Пенза, Ладожская, 125	f	large
62834	70538	86	Пензенская область, Пенза, Ладожская, 125	f	large
62833	70537	85	Пензенская область, Пенза, Ладожская, 131	f	large
62832	70537	84	Пензенская область, Пенза, Ладожская, 131	f	large
62831	70537	83	Пензенская область, Пенза, Ладожская, 131	f	large
62896	70573	148	Пензенская область, Пенза, Крупской, 5	f	large
62770	70493	22	Пензенская область, Пенза, Красносельская, 29	f	large
62769	70493	21	Пензенская область, Пенза, Красносельская, 29	f	large
62941	70603	193	Пензенская область, Пенза, Краснова, 19	f	large
62940	70603	192	Пензенская область, Пенза, Краснова, 19	f	large
62939	70603	191	Пензенская область, Пенза, Краснова, 19	f	large
62936	70600	188	Пензенская область, Пенза, Краснова, 119	f	small
62824	70531	76	Пензенская область, Пенза, Красная, 54	f	large
62791	70507	43	Пензенская область, Пенза, Конструкторская, 13	f	large
62813	70522	65	Пензенская область, Пенза, Коммунистическая, 43А	f	large
62812	70522	64	Пензенская область, Пенза, Коммунистическая, 43А	f	large
62765	70490	17	Пензенская область, Пенза, Колхозная, 31	f	large
68454	70533	78	Пензенская область, Пенза, Кирова, 51	f	large
62932	70597	184	Пензенская область, Пенза, Кижеватова, 13	f	large
62931	70597	183	Пензенская область, Пенза, Кижеватова, 13	f	large
62805	70515	57	Пензенская область, Пенза, Карпинского, 31	f	large
62804	70515	56	Пензенская область, Пенза, Карпинского, 31	f	large
62796	70510	48	Пензенская область, Пенза, Карпинского, 43а	f	large
62795	70510	47	Пензенская область, Пенза, Карпинского, 43а	f	large
62943	70605	195	Пензенская область, Пенза, Калинина, 99б	f	large
62942	70605	194	Пензенская область, Пенза, Калинина, 99б	f	large
62946	70608	198	Пензенская область, Пенза, Индустриальная, 48А	f	large
112639	71286	908	Пензенская область, Пенза, Зеленая, 10	f	small
63646	71285	907	Пензенская область, Пенза, Зеленая, 10	f	small
62823	70530	75	Пензенская область, Пенза, Захарова, 20	f	large
62774	70494	26	Пензенская область, Пенза, Дружбы, 23	f	large
62771	70494	23	Пензенская область, Пенза, Дружбы, 23	f	large
62893	70570	145	Пензенская область, Пенза, Докучаева, 20	f	large
68457	70569	144	Пензенская область, Пенза, Докучаева, 20	f	large
62830	70536	82	Пензенская область, Пенза, Гоголя, 31	f	large
62829	70536	81	Пензенская область, Пенза, Гоголя, 31	f	large
62758	70483	10	Пензенская область, Пенза, Герцена, 37	f	large
62891	70568	143	Пензенская область, Пенза, улица Германа Титова, 28	f	large
63700	71344	965	Пензенская область, Пенза, Ворошилова, 61	f	medium
62816	70524	68	Пензенская область, Пенза, Ворошилова, 9	f	large
62815	70524	67	Пензенская область, Пенза, Ворошилова, 9	f	large
62935	70599	187	Пензенская область, Пенза, Воронова, 20	f	large
62934	70599	186	Пензенская область, Пенза, Воронова, 20	f	large
62933	70598	185	Пензенская область, Пенза, Воронова, 16	f	large
62827	70534	79	Пензенская область, Пенза, Володарского, 49	f	large
62919	70589	171	Пензенская область, Пенза, Водопьянова проезд, 28	f	large
62954	70613	206	Пензенская область, Пенза, Вадинская, 9а	f	large
62953	70613	205	Пензенская область, Пенза, Вадинская, 9а	f	large
62930	70596	182	Пензенская область, Пенза, Бурмистрова, 16а	f	large
62929	70596	181	Пензенская область, Пенза, Бурмистрова, 16а	f	large
62867	70554	119	Пензенская область, Пенза, Бородина, 16	f	large
62866	70554	118	Пензенская область, Пенза, Бородина, 16	f	large
62865	70554	117	Пензенская область, Пенза, Бородина, 16	f	large
62928	70595	180	Пензенская область, Пенза, Бийская, 1	f	large
62890	70567	142	Пензенская область, Пенза, Беляева, 43	f	large
62889	70567	141	Пензенская область, Пенза, Беляева, 43	f	large
62807	70518	59	Пензенская область, Пенза, Бекешская, 14	f	large
62821	70527	73	Пензенская область, Пенза, Бакунина, 115	f	large
62820	70527	72	Пензенская область, Пенза, Бакунина, 115	f	large
62759	70484	11	Пензенская область, Пенза, Бакунина, 88а	f	large
62899	70575	151	Пензенская область, Пенза, Аустрина, 129	f	large
62790	70506	42	Пензенская область, Пенза, Антонова, 27а	f	large
62789	70506	41	Пензенская область, Пенза, Антонова, 27а	f	large
62788	70505	40	Пензенская область, Пенза, Антонова, 72	f	large
62787	70504	39	Пензенская область, Пенза, Антонова, 6	f	large
62786	70503	38	Пензенская область, Пенза, Антонова, 14	f	large
62797	70511	49	Пензенская область, Пенза, 8 Марта, 21а	f	large
62855	70548	107	Пензенская область, Пенза, поселок Арбеково, 5-й Виноградный проезд, 22	f	small
62768	70492	20	Пензенская область, Пенза, Медицинская, 1а	f	large
62767	70492	19	Пензенская область, Пенза, Медицинская, 1а	f	large
62894	70571	146	Пензенская область, Пенза, Леонова, 1а	f	large
62814	70523	66	Пензенская область, Пенза, Коммунистическая, 30	f	large
62945	70607	197	Пензенская область, Пенза, Индустриальная, 38	f	large
63002	70652	253	Пензенская область, Кузнецк, Фабричная, 36	f	large
62989	70642	241	Пензенская область, Кузнецк, Строителей, 87	f	large
62988	70641	240	Пензенская область, Кузнецк, Строителей, 123	f	large
62987	70641	239	Пензенская область, Кузнецк, Строителей, 123	f	large
63022	70667	271	Пензенская область, Кузнецк, Рабочая, 331	f	large
63020	70665	269	Пензенская область, Кузнецк, Рабочая, 346а	f	large
63021	70666	270	Пензенская область, Кузнецк, Правды, 88В	f	large
62993	70645	245	Пензенская область, Кузнецк, Осипенко, 49А	f	large
62992	70645	244	Пензенская область, Кузнецк, Осипенко, 49А	f	large
63011	70659	262	Пензенская область, Кузнецк, Орджоникидзе, 186а	f	large
62995	70648	247	Пензенская область, Кузнецк, Октябрьская, 1б	f	large
62994	70647	246	Пензенская область, Кузнецк, Октябрьская, 12а	f	large
62991	70644	243	Пензенская область, Кузнецк, Октябрьская, 62а	f	large
62990	70643	242	Пензенская область, Кузнецк, Октябрьская, 64	f	large
62997	70649	249	Пензенская область, Кузнецк, Минская, 10а	f	large
62996	70649	248	Пензенская область, Кузнецк, Минская, 10а	f	large
63015	70662	265	Пензенская область, Кузнецк, Ленина, 267	f	large
63013	70660	263	Пензенская область, Кузнецк, Ленина, 210	f	large
63009	70657	260	Пензенская область, Кузнецк, Ленина, 116	f	large
63008	70657	259	Пензенская область, Кузнецк, Ленина, 116	f	large
63014	70661	264	Пензенская область, Кузнецк, Кирова, 173	f	large
63017	70664	267	Пензенская область, Кузнецк, Калинина, 300	f	large
63018	70664	268	Пензенская область, Кузнецк, Калинина, 300	f	large
63005	70654	256	Пензенская область, Кузнецк, Гагарина, 30	f	large
63016	70663	266	Пензенская область, Кузнецк, Белинского, 130	f	large
63010	70658	261	Пензенская область, Кузнецк, Белинского, 137	f	large
63006	70655	257	Пензенская область, Кузнецк, Белинского, 109б	f	large
63004	70653	255	Пензенская область, Кузнецк, Белинского, 17	f	large
63003	70653	254	Пензенская область, Кузнецк, Белинского, 17	f	large
63001	70651	252	Пензенская область, Кузнецк, 60-летия ВЛКСМ, 3	f	large
63000	70651	251	Пензенская область, Кузнецк, 60-летия ВЛКСМ, 3	f	large
63023	70668	272	Пензенская область, Кузнецк, 1-я Бутурлинская, 47	f	medium
63278	70912	531	Пензенская область, Каменка, Чернышевского, 6	f	large
63279	70913	532	Пензенская область, Каменка, Коллективная, 6	f	large
63274	70908	527	Пензенская область, Каменка, Гражданская, 8	f	large
63273	70908	526	Пензенская область, Каменка, Гражданская, 8	f	large
62974	70582	226	Пензенская область, Заречный городской округ, проезд Молодежный, 2а	f	large
62976	70528	228	Пензенская область, Заречный городской округ, Демакова, 4	f	large
62973	70630	225	Пензенская область, Заречный, проезд Молодежный, 2б	f	large
62972	70629	224	Пензенская область, Ленина, 66а	f	large
62969	70626	221	Пензенская область, Заречный, Ленина, 35а	f	large
63080	70718	330	Пензенская область, Белинский, Советская площадь, 10	f	large
112665	71525	1147	Пензенская область, Шемышейский район, поселок Шемышейка, Октябрьская, 5	f	medium
63881	71524	1146	Пензенская область, Шемышейский район, поселок Шемышейка, Октябрьская, 5	f	large
63883	71526	1149	Пензенская область, Шемышейский район, поселок Шемышейка, Ленина, 34	f	large
63882	71526	1148	Пензенская область, Шемышейский район, поселок Шемышейка, Ленина, 34	f	large
112664	71523	1145	Пензенская область, Шемышейский район, село Усть-Уза, А.Ж. Богданова , 1в	f	small
63880	71522	1144	Пензенская область, Шемышейский район, село Усть-Уза, А.Ж. Богданова, 1 В	f	large
63706	71351	971	Пензенская область, Шемышейский район, село Урлейка, Школьная, 35-а	f	small
63877	71519	1141	Пензенская область, Шемышейский район, село Старое Назимкино, Юбилейная, 4А	f	small
63876	71518	1140	Пензенская область, Шемышейский район, село Старое Захаркино, Школьная площадь, 1	f	medium
63875	71517	1139	Пензенская область, Шемышейский район, село Старое Демкино, Совхозная, 25	f	medium
112663	71520	1142	Пензенская область, Шемышейский район, село Старая Яксарка, Заречная , 29а	f	medium
63709	71354	974	Пензенская область, Шемышейский район, село Спасско-Александровка, Лесная, 81	t	small
63874	71516	1138	Пензенская область, Шемышейский район, село Синодское, Школьная, 2	f	medium
63873	71515	1137	Пензенская область, Шемышейский район, село Русская Норка, Центральная, 27	f	small
63872	71514	1136	Пензенская область, Шемышейский район, село Песчанка, Молодежная, 26	f	small
63870	71513	1135	Пензенская область, Шемышейский район, село Новый Мачим, Специалистов, 8	f	small
63869	71512	1134	Пензенская область, Шемышейский район, село Наумкино, Чехманова, 2А	f	small
63868	71511	1133	Пензенская область, Шемышейский район, село Наскафтым, Ленина, 11	f	medium
63867	71510	1132	Пензенская область, Шемышейский район, село Мордовская Норка, Сельская, 20	f	small
63866	71509	1131	Пензенская область, Шемышейский район, село Мачкасы, Октябрьская, 3	f	small
63864	71508	1130	Пензенская область, Шемышейский район, село Колдаис, Советская, 3Б	f	small
63862	71506	1128	Пензенская область, Шемышейский район, село Каржимант, Школьная, 2	f	small
63863	71507	1129	Пензенская область, Шемышейский район, село Каргалейка, Лесная, 2	f	small
63860	71505	1127	Пензенская область, Шемышейский район, село Воробьевка, Молодежная, 11	f	small
63859	71504	1126	Пензенская область, Шемышейский район, село Армиево, Центральная, 1	f	medium
63855	71502	1124	Пензенская область, Тамалинский район, село Ульяновка, Новая, 8	f	medium
112654	71483	1105	Пензенская область, Тамалинский район, поселок Тамала, Центральная, 1, Здание школы р.п. Тамала	f	medium
63838	71481	1103	Пензенская область, Тамалинский район, поселок Тамала, Транспортная, 76	f	large
63837	71480	1102	Пензенская область, Тамалинский район, поселок Тамала, Советская, 16	f	large
63841	71484	1106	Пензенская область, Тамалинский район, поселок Тамала, Пролетарская, 43	f	small
63840	71485	1107	Пензенская область, Тамалинский район, поселок Тамала, Заводская, 9	f	medium
112653	71482	1104	Пензенская область, Тамалинский район, поселок Тамала, Железнодорожная, 21, здание бывшей конторы сельхозтехники р.п. Тамала	f	medium
63854	71499	1121	Пензенская область, Тамалинский район, село Степной, Центральная, 17	f	small
112640	71292	914	Пензенская область, Тамалинский район, село Павловка, Железнодорожная, 1	t	small
112650	71440	1062	Пензенская область, Тамалинский район, село Озерки, Овражная, 66	t	small
112662	71501	1123	Пензенская область, Тамалинский район, село Обвал, Иванова, 49-б, Здание Обвальского СДК	f	small
63847	71490	1112	Пензенская область, Тамалинский район, село Никольское, Центральная, 4	f	small
112631	71186	806	Пензенская область, Тамалинский район, село Наровчат, Ленина, 2	f	small
112659	71496	1118	Пензенская область, Тамалинский район, село Мача, Садовая, 1, здание школы с. Мача	f	small
112655	71486	1108	Пензенская область, Тамалинский район, село Малая Сергиевка, Школьная, 4, Здание школы	f	medium
63044	70681	293	Пензенская область, Тамалинский район, село Липовка, Советская, 117	f	medium
112661	71498	1120	Пензенская область, Тамалинский район, село Куликовка, Центральная, 55-а, Здание школы	f	small
63035	70331	284	Пензенская область, Тамалинский район, село Каменка, Передовик, 5а	f	small
63856	71500	1122	Пензенская область, Тамалинский район, село Каменка, Молодежная, 17	f	small
63843	71487	1109	Пензенская область, Тамалинский район, село Калиновка, Мира, 2	f	small
112656	71489	1111	Пензенская область, Тамалинский район, село Зубрилово, Центральная, 22, Здание школы с. Зубрилово	f	small
63849	71491	1113	Пензенская область, Тамалинский район, село Дуровка, Школьная, 1-а	f	small
63850	71494	1116	Пензенская область, Тамалинский район, село Григорьевка, Центральная, 1	f	small
112660	71497	1119	Пензенская область, Тамалинский район, село Волчий Враг, Молодежная, 25, Здание школы	f	small
112657	71492	1114	Пензенская область, Тамалинский район, село Вишневое, Крылова, 49, Здание школы	f	medium
63844	71488	1110	Пензенская область, Тамалинский район, село Варварино, Центральная, 9	f	small
63848	71493	1115	Пензенская область, Тамалинский район, село Большая Сергеевка, Центральная, 8-а	f	small
63858	71503	1125	Пензенская область, Тамалинский район, село Березовка, Молодёжная, 14	f	small
63033	70604	282	Пензенская область, Тамалинский район, село Алексеевка, Середочка, 1	t	small
63811	71454	1076	Пензенская область, Сосновоборский район, село Щукино, Школьная, 2	t	small
63810	71453	1075	Пензенская область, Сосновоборский район, село Шугурово, Лесная, 19	f	small
63809	71452	1074	Пензенская область, Сосновоборский район, село Шкудим, Песчаная, 1	t	small
63808	71451	1073	Пензенская область, Сосновоборский район, село Топоровка, Дачная, 69	t	small
63807	71450	1072	Пензенская область, Сосновоборский район, село Тешнярь, Учительская, 30	f	medium
63806	71449	1071	Пензенская область, Сосновоборский район, село Татарский Сыромяс, Полевая, 4	t	small
63800	71443	1065	Пензенская область, Сосновоборский район, поселок Сосновоборск, Театральная, 1	f	medium
63804	71447	1069	Пензенская область, Сосновоборский район, поселок Сосновоборск, Ленина, 65	f	large
63803	71446	1068	Пензенская область, Сосновоборский район, поселок Сосновоборск, Кададинская, 28А	f	large
63802	71445	1067	Пензенская область, Сосновоборский район, поселок Сосновоборск, Кададинская, 30Б	f	large
63801	71444	1066	Пензенская область, Сосновоборский район, поселок Сосновоборск, Гагарина, 2	f	large
63799	71442	1064	Пензенская область, Сосновоборский район, село Русский Качим, Новая, 8	f	small
112651	71441	1063	Пензенская область, Сосновоборский район, село Пичилейка, Центральная, 2	f	small
63796	71439	1061	Пензенская область, Сосновоборский район, село Новополянское, Школьная, 26	t	small
63795	71438	1060	Пензенская область, Сосновоборский район, село Николо-Барнуки, Центральная, 33А	f	small
63793	71436	1058	Пензенская область, Сосновоборский район, село Нижний Мывал, Школьная, 23	f	small
63792	71435	1057	Пензенская область, Сосновоборский район, село Нижний Катмис, Центральная, 4	f	small
112649	71437	1059	Пензенская область, Сосновоборский район, село Нижная Липовка, Куракина, 28	f	small
63791	71434	1056	Пензенская область, Сосновоборский район, село Мордовский Качим, Центральная, 66	t	small
63789	71432	1054	Пензенская область, Сосновоборский район, село Малая Садовка, Садовая, 94	t	small
112647	71431	1053	Пензенская область, Сосновоборский район, село Кряжим, Новая, 20	f	small
63710	71355	975	Пензенская область, Сосновоборский район, село Краснополье, Центральная, 8	f	medium
63421	71051	672	Пензенская область, Сосновоборский район, село Козловка, Ленина, 85А	f	medium
63787	71430	1052	Пензенская область, Сосновоборский район, село Кардафлей, Веленка, 16	t	small
63347	70975	598	Пензенская область, Сосновоборский район, село Карауловка, Школьная, 59	t	small
63785	71428	1050	Пензенская область, Сосновоборский район, село Индерка, переулок Школьный, 20	f	large
63786	71429	1051	Пензенская область, Сосновоборский район, село Индерка, переулок Центральный, 1	f	large
63203	70841	457	Пензенская область, Сосновоборский район, село Елюзань, Складская, 2	f	large
63202	70840	456	Пензенская область, Сосновоборский район, село Елюзань, Коммунальная, 3	f	large
63201	70839	455	Пензенская область, Сосновоборский район, село Елюзань, Коммунальная, 15	f	large
63381	71010	632	Пензенская область, Сосновоборский район, село Елюзань, Веселая, 11	t	small
63784	71427	1049	Пензенская область, Сосновоборский район, село Ега, Учительская, 1	t	small
63254	70892	508	Пензенская область, Сосновоборский район, село Дмитриевка, Школьная, 8	f	small
63782	71425	1047	Пензенская область, Сосновоборский район, село Водолей, Водолейская, 10А	t	small
63781	71424	1046	Пензенская область, Сосновоборский район, село Верхний Катмис, Центральная, 127	t	small
63780	71423	1045	Пензенская область, Сосновоборский район, село Вачелай, Центральная, 2	f	small
63778	71421	1043	Пензенская область, Сосновоборский район, село Альмяшевка, Центральная, 45А	t	small
63736	71382	1001	Пензенская область, Сердобский район, село Софьино, Орловка, 24	t	small
63744	71389	1009	Пензенская область, Сердобский район, Сердобск, Школьная площадь, 1	f	large
63752	71397	1017	Пензенская область, Сердобский район, Сердобск, Школьная, 4	f	medium
63743	71388	1008	Пензенская область, Сердобский район, Сердобск, Школьная, 4	f	small
63773	71416	1038	Пензенская область, Сердобский район, Сердобск, Тюрина, 9	f	large
63749	71394	1014	Пензенская область, Сердобский район, Сердобск, Советская, 28	f	large
63733	71379	998	Пензенская область, Сердобский район, Слепцова, 32	f	medium
63745	71390	1010	Пензенская область, Сердобский район, Сердобск, Скворцовка, 4	f	large
63748	71393	1013	Пензенская область, Сердобский район, Сердобск, Первомайская, 6б	f	medium
63737	71383	1002	Пензенская область, Сердобский район, Сердобск, Новая, 10	f	medium
63764	71407	1029	Пензенская область, Сердобский район, Сердобск, Набережная, 58	f	large
63777	71420	1042	Пензенская область, Сердобский район, Сердобск, Максима Горького, 251г	f	large
63775	71418	1040	Пензенская область, Сердобский район, Сердобск, Макарова, 7	f	large
63774	71417	1039	Пензенская область, Сердобский район, Сердобск, Макарова, 2	f	large
63763	71406	1028	Пензенская область, Сердобский район, Сердобск, Лесная, 37	f	large
63770	71413	1035	Пензенская область, Сердобский район, Сердобск, Ленина, 291	f	large
63769	71412	1034	Пензенская область, Сердобский район, Сердобск, Ленина, 271а	f	large
63767	71410	1032	Пензенская область, Сердобский район, Сердобск, Ленина, 218	f	large
63766	71409	1031	Пензенская область, Сердобский район, Сердобск, Ленина, 214	f	large
63765	71408	1030	Пензенская область, Сердобский район, Сердобск, Ленина, 148	f	large
63762	71405	1027	Пензенская область, Сердобский район, Сердобск, Куйбышева, 58	f	large
63746	71391	1011	Пензенская область, Сердобский район, Сердобск, Колхозная, 99	f	large
63756	71401	1021	Пензенская область, Сердобский район, Сердобск, Калинина, 31	f	large
63759	71403	1024	Пензенская область, Сердобский район, Сердобск, Гагарина, 30	f	large
63758	71402	1023	Пензенская область, Сердобский район, Сердобск, Гагарина, 16	f	large
63761	71404	1026	Пензенская область, Сердобский район, Сердобск, Балашовская, 2е	f	small
63760	71404	1025	Пензенская область, Сердобский район, Сердобск, Балашовская, 2е	f	large
63776	71419	1041	Пензенская область, Сердобский район, Сердобск, Энергетиков, 2	f	large
112646	71396	1016	Пензенская область, Сердобский район, село Секретарка, Школьная, 2 а	f	medium
63747	71392	1012	Пензенская область, Сердобский район, село Салтыково, Центральная, 94	t	small
63734	71380	999	Пензенская область, Сердобский район, село Куракино, Ленинская, 25А	f	large
63738	71384	1003	Пензенская область, Сердобский район, село Карповка, Московская, 134а	f	medium
63739	71385	1004	Пензенская область, Сердобский район, село Камзолка, Светлая, 26а	t	small
63742	71334	1007	Пензенская область, Сердобский район, село Зеленый Дол, Садовая, 6а	f	small
63741	71360	1006	Пензенская область, Сердобский район, село Зеленовка, Новый Хутор, 21	f	small
63346	70974	597	Пензенская область, Сердобский район, село Зеленовка, Центральная, 1	f	small
63732	71378	997	Пензенская область, Сердобский район, село Гуленовка, Комсомольская, 11	f	small
63288	70921	540	Пензенская область, Сердобский район, село Варваровка, Победы, 12	f	medium
63731	71377	996	Пензенская область, Сердобский район, село Байка, Советская, 10	f	small
63735	71381	1000	Пензенская область, Сердобский район, село Александрово-Ростовка, Луговая, 71а	f	small
63696	71340	961	Пензенская область, Пензенский район, село совхоз Серп и Молот, Школьная, 1-а	f	medium
63697	71341	962	Пензенская область, Пензенский район, село Черенцовка, Центральная, 2-а	t	small
63879	71521	1143	Пензенская область, Пензенский район, село Усть-Мурза, Советская, 15Б	f	small
63730	71376	995	Пензенская область, Пензенский район, село Старая Каменка, Молодежная, 5	f	large
63054	70691	303	Пензенская область, Пензенский район, село Софьевка, Софьевская, 2Б	t	small
63721	71367	986	Пензенская область, Пензенский район, село Соловцовка, Дачная, 17-2	f	small
63725	71371	990	Пензенская область, Пензенский район, село Саловка, Школьная, 2	f	small
63727	71373	992	Пензенская область, Пензенский район, село Саловка, Советская, 4	f	large
63714	71359	979	Пензенская область, Пензенский район, село Поперечное, Школьная, 12	f	small
63352	70980	603	Пензенская область, Пензенский район, село Пановка, Чапаева, 12	f	medium
63695	71339	960	Пензенская область, Пензенский район, село Пановка, Санаторская, 27	f	small
63720	71366	985	Пензенская область, Пензенский район, село Оленевка, Школьная, 2	f	medium
63722	71368	987	Пензенская область, Пензенский район, село Оленевка, Рабочая, 9, центральная усадьба совхоза Слава труду	f	small
63242	70880	496	Пензенская область, Пензенский район, село Никифоровка, Московская, 21а	t	small
63688	71331	953	Пензенская область, Пензенский район, село Надеждино, Школьная, 1-А	f	medium
63715	71361	980	Пензенская область, Пензенский район, село Ленино, Набережная, 4	f	large
63681	71324	946	Пензенская область, Пензенский район, село Лемзяйка, Новая, 3-1	t	small
63713	71358	978	Пензенская область, Пензенский район, село Кучки, переулок Школьный, 11	f	small
63729	71375	994	Пензенская область, Пензенский район, село Константиновка, Советская, 12	f	large
63303	70936	555	Пензенская область, Пензенский район, село Калинино, Родниковая, 18	f	medium
63692	71336	957	Пензенская область, Пензенский район, село Ивановка, Заречная, 19-а	t	small
63694	71338	959	Пензенская область, Пензенский район, село Загоскино, Экспериментальная, 21	f	medium
63693	71337	958	Пензенская область, Пензенский район, село Ермоловка, Октябрьская, 13	f	large
63783	71426	1048	Пензенская область, Пензенский район, село Вязовка, Лесная, 6	t	small
63691	71335	956	Пензенская область, Пензенский район, село Воскресеновка, Советская, 7	f	large
63701	71345	966	Пензенская область, Пензенский район, село Возрождение, Возрожденская, 102	t	small
63686	71329	951	Пензенская область, Пензенский район, село Васильевка, Набережная, 2	f	medium
63687	71330	952	Пензенская область, Пензенский район, село Большая Елань, Садовая, 2	f	large
63684	71327	949	Пензенская область, Пензенский район, село Большая Валяевка, Центральная, 28-В	t	small
63683	71326	948	Пензенская область, Пензенский район, село Богословка, Советская, 5	f	large
63682	71325	947	Пензенская область, Пензенский район, село Богословка, Советская, 7	f	large
63680	71323	945	Пензенская область, Пензенский район, поселок Березовая роща, Центральная, 3	f	medium
63728	71374	993	Пензенская область, Пензенский район, село Ардымский, Центральная, 3	t	small
63679	71322	944	Пензенская область, Пензенский район, село Алферьевка, Школьная, 12	f	large
63444	71073	695	Пензенская область, Пенза городской округ, село лесничество Засурское, Школьная, 16	f	medium
63672	71315	937	Пензенская область, Пачелмский район, село Шейно	f	medium
63673	71316	938	Пензенская область, Пачелмский район, село Черкасское, 1-ая Садовая, 2а	f	medium
63290	70923	542	Пензенская область, Пачелмский район, село Троицкое, Центральная, 8	f	small
63105	70741	355	Пензенская область, Пачелмский район, село Топориха, Школьная, 3	f	small
112644	71308	930	Пензенская область, Пачелмский район, село Титово, Совхозная, 9	f	small
63665	71307	929	Пензенская область, Пачелмский район, село Титово, Совхозная, 9	f	large
63675	71318	940	Пензенская область, Пачелмский район, село Татаро-Никольское, Школьная, 39	f	small
63662	71304	926	Пензенская область, Пачелмский район, село Старая Толковка, Советская, 14-а	t	small
63674	71317	939	Пензенская область, Пачелмский район, село РусскоНикольское, Центральная, 41	f	small
63666	71309	931	Пензенская область, Пачелмский район, село Решетино, Центральная, 2	f	medium
63313	70946	565	Пензенская область, Пачелмский район, село Пустынь, Центральная, 90б	f	small
112643	71301	923	Пензенская область, Пачелмский район, поселок Пачелма, Новая, 4А	f	small
63659	71300	922	Пензенская область, Пачелмский район, поселок Пачелма, Новая, 4-а	f	large
112642	71299	921	Пензенская область, Пачелмский район, поселок Пачелма, Кирова, 40	f	medium
63658	71298	920	Пензенская область, Пачелмский район, поселок Пачелма, Кирова, 40	f	large
112641	71297	919	Пензенская область, Пачелмский район, поселок Пачелма, Драгунова, 14	f	small
63657	71296	918	Пензенская область, Пачелмский район, поселок Пачелма, Драгунова, 14-а	f	large
63670	71313	935	Пензенская область, Пачелмский район, село Пачелма, Совхозная, 1	f	small
63671	71314	936	Пензенская область, Пачелмский район, село Новый Валовай, Школьная, 22	f	small
63661	71303	925	Пензенская область, Пачелмский район, село Новая Толковка, Театральная, 1	f	small
63664	71306	928	Пензенская область, Пачелмский район, село Мокрый Мичкас, Новая, 24	f	small
63302	70935	554	Пензенская область, Пачелмский район, село Кобылкино, Школьная, 9а	f	large
63660	71302	924	Пензенская область, Пачелмский район, село Калиновка, Центральная, 54	f	small
63668	71311	933	Пензенская область, Пачелмский район, село Ворона, Орловская, 3-а	t	small
63667	71310	932	Пензенская область, Пачелмский район, село Белынь	f	small
63656	71279	901	Пензенская область, Никольский район, с.Столыпино, Школьный переулок, 4	f	medium
112637	71272	894	Пензенская область, Никольский район, село отдел Совхоза Зеленодольский, Центральная, 33	f	small
63642	71277	899	Пензенская область, Никольский район, село Усть-Инза, Новая, 27	t	small
63644	71290	912	Пензенская область, Никольский район, село Тюнярь, Посёлки, 19	t	small
63634	71275	897	Пензенская область, Никольский район, поселок Сура, Сенная, 3	f	medium
63635	71276	898	Пензенская область, Никольский район, поселок Сура, Пролетарская, 23а	f	medium
63652	71294	916	Пензенская область, Никольский район, село Субботино, Набережная, 10	t	small
63637	71280	902	Пензенская область, Никольский район, село Старая Селя, Центральная, 45	f	small
63638	71283	905	Пензенская область, Никольский район, село Серман, Ленинская, 42	t	small
112621	71090	711	Пензенская область, Никольский район, село Родники, Центральная, 16	f	medium
63651	71293	915	Пензенская область, Никольский район, поселок Ночка, Центральная, 52	f	medium
63625	71266	888	Пензенская область, Никольский район, Никольск, Школьная, 1	f	large
61949	69575	1807	Оренбургская область, Оренбург, Свердлова, 10	f	large
68452	71269	891	Пензенская область, Никольский район, Никольск, Советская, 148	f	large
63632	71268	890	Пензенская область, Никольский район, Никольск, Советская, 148	f	large
63633	71271	893	Пензенская область, Никольский район, Никольск, Садовая, 21	f	large
63624	71274	896	Пензенская область, Никольский район, Никольск, Октябрьская, 288	f	large
63629	71262	884	Пензенская область, Никольский район, Никольск, Ленина, 134	f	large
63630	71265	887	Пензенская область, Никольский район, Никольск, Комсомольская, 1	f	large
63627	71263	885	Пензенская область, Никольский район, Никольск, Калинина, 6	f	large
63631	71264	886	Пензенская область, Никольский район, Никольск, Заводская, 2	f	large
63626	71267	889	Пензенская область, Никольский район, Никольск, Белинского, 24	f	large
63654	71288	910	Пензенская область, Никольский район, село Нижний Шкафт, Центральная, 67	f	medium
63308	70941	560	Пензенская область, Никольский район, село Междуречье, Молодежная, 16	f	small
63649	71291	913	Пензенская область, Никольский район, село Маис, Школьная, 25	f	medium
63653	71295	917	Пензенская область, Никольский район, село Кравково, Центральная, 54	t	small
63294	70927	546	Пензенская область, Никольский район, село Кочетовка, Центральная, 5	f	small
63648	71281	903	Пензенская область, Никольский район, село Карамалы, Октябрьская, 7	f	small
63643	71289	911	Пензенская область, Никольский район, село Казарка, Советская, 29	f	small
63641	71278	900	Пензенская область, Никольский район, село Ильмино, Центральная, 5	f	medium
62979	70633	231	Пензенская область, Никольский район, село Заречный, Братская, 14	f	large
63645	71270	892	Пензенская область, Никольский район, село Большое Пермиево, Центральная, 22	f	small
112638	71284	906	Пензенская область, Никольский район, село Базарная Кеньша, Школьная, 11	f	small
63655	71287	909	Пензенская область, Никольский район, село Аришка, Нагорная, 2А	f	small
63607	71239	861	Пензенская область, Нижнеломовский район, село Усть-Каремша, Жулябина, 13е	f	medium
63588	71235	857	Пензенская область, Нижнеломовский район, село Старая Мурава, Старая Мурава, 19	t	small
63602	71238	860	Пензенская область, Нижнеломовский район, село Сорокино, Лесная, 9а	f	small
63601	71237	859	Пензенская область, Нижнеломовский район, село Серый Ключ, Центральная, 77	f	small
63608	71240	862	Пензенская область, Нижнеломовский район, село Прянзерки, Центральная, 20	f	small
63581	71228	850	Пензенская область, Нижнеломовский район, село Пешая Слобода, Новенькая, 13	f	medium
63580	71220	842	Пензенская область, Нижнеломовский район, село Овчарное, Кремщина, 3	f	small
63604	71227	849	Пензенская область, Нижнеломовский район, село Норовка	f	small
63603	71226	848	Пензенская область, Нижнеломовский район, село Норовка, Молодежная, 1	f	medium
63589	71232	854	Пензенская область, Нижнеломовский район, село Новый Шуструй, Центральная, 43	f	small
63605	71218	840	Пензенская область, Нижнеломовский район, село Новая Пятина, Парковая, 3	f	small
112636	71257	879	Пензенская область, Нижнеломовский район, Нижний Ломов, Южная, 18, ЗАО «Хлебресурс»	f	medium
68450	71250	872	Пензенская область, Нижнеломовский район, Нижний Ломов, Урицкого, 85, МОУ СОШ № 2 г.Нижний Ломов	f	large
63621	71260	882	Пензенская область, Нижнеломовский район, Нижний Ломов, Толстого, 1	f	large
63617	71255	877	Пензенская область, Нижнеломовский район, Нижний Ломов, Розы Люксембург, 49	f	large
63610	71249	871	Пензенская область, Нижнеломовский район, Нижний Ломов, Рабочая, 3	f	large
63615	71254	876	Пензенская область, Нижнеломовский район, Нижний Ломов, Октябрьская, 63	f	large
63614	71252	874	Пензенская область, Нижнеломовский район, Нижний Ломов, Московская, 83	f	large
63612	71251	873	Пензенская область, Нижнеломовский район, Нижний Ломов, Московская, 54	f	large
63620	71261	883	Пензенская область, Нижнеломовский район, Нижний Ломов, Маяковского, 15	f	large
63623	71258	880	Пензенская область, Нижнеломовский район, Нижний Ломов, Крылова, 6	f	large
68451	71256	878	Пензенская область, Нижнеломовский район, Нижний Ломов, Карла Либкнехта, 183, библиотека микрорайона «Черемушки», филиал № 1 МУК ЦМБ Нижнеломовского района Пензенской области	f	large
63609	71248	870	Пензенская область, Нижнеломовский район, Нижний Ломов, Заводская, 13	f	large
63510	71148	767	Пензенская область, Мокшанский район, село Скачки, Демин Конец, 3	f	\N
112635	71253	875	Пензенская область, Нижнеломовский район, Нижний Ломов, Вокзальная, 13	f	medium
63599	71225	847	Пензенская область, Нижнеломовский район, село Мичкасские Выселки, Зеленая, 2б	f	small
63526	71163	782	Пензенская область, Нижнеломовский район, село Ляча, Молодежная, 1	f	small
63578	71222	844	Пензенская область, Нижнеломовский район, село Лещиново, Школьная, 1	f	small
68449	71236	858	Пензенская область, Нижнеломовский район, село Кувак-Никольское, Центральная, 7	f	large
63597	71224	846	Пензенская область, Нижнеломовский район, село Кривошеевка, Школьная, 113а	f	large
63596	71223	845	Пензенская область, Нижнеломовский район, село Кривошеевка, Красноармейская, 16а	f	small
63606	71247	869	Пензенская область, Нижнеломовский район, село Кривозерье, площадь Центральная, 1	t	small
63587	71231	853	Пензенская область, Нижнеломовский район, село Козлятское, Ленина, 1а	t	small
63593	71242	864	Пензенская область, Нижнеломовский район, село Кера, Ленина, 63а	f	small
63594	71241	863	Пензенская область, Нижнеломовский район, село Ива, Новая Деревня, 4	f	small
62978	70632	230	Пензенская область, Нижнеломовский район, село Заречный, Конституции СССР, 1	f	large
62977	70631	229	Пензенская область, Конституции СССР, 37/2	f	large
63591	71245	867	Пензенская область, Нижнеломовский район, село Голицыно, Московская, 43	f	small
63590	71244	866	Пензенская область, Нижнеломовский район, село Голицыно, Московская, 2а	f	small
63598	71259	881	Пензенская область, Нижнеломовский район, село Волженка, Буденного, 39а	t	small
63582	71217	839	Пензенская область, Нижнеломовский район, село Вирга, Школьная, 6	f	medium
63583	71229	851	Пензенская область, Нижнеломовский район, село Верхний Ломов, Советская площадь , 13	f	medium
63586	71230	852	Пензенская область, Нижнеломовский район, село Верхний Ломов, Советская площадь, 31	f	medium
63585	71234	856	Пензенская область, Нижнеломовский район, село Верхний Ломов, Московская, 31	f	large
63584	71233	855	Пензенская область, Нижнеломовский район, село Верхний Ломов, Белинского , 55	f	medium
63577	71221	843	Пензенская область, Нижнеломовский район, село Большой Мичкас, Средняя, 32	f	medium
63579	71219	841	Пензенская область, Нижнеломовский район, село Большая Хутора, Центральная, 113	f	small
63576	71216	838	Пензенская область, Нижнеломовский район, село Атмис, Новая, 53	f	small
63595	71243	865	Пензенская область, Нижнеломовский район, село Аршиновка, Центральная, 1А	f	small
63575	71215	837	Пензенская область, Неверкинский район, село Черталей, Школьная, 1	f	small
63574	71214	836	Пензенская область, Неверкинский район, село Сулеймановка, Школьная, 95	f	small
112634	71213	835	Пензенская область, Неверкинский район, село Старая Андреевка, Победы, 1-а	f	small
63573	71212	834	Пензенская область, Неверкинский район, село Старая Андреевка, Победы, 1 А	f	medium
112633	71211	833	Пензенская область, Неверкинский район, село План, Центральная, 50	f	small
63572	71210	832	Пензенская область, Неверкинский район, село План, Центральная, 50	f	small
63571	71209	830	Пензенская область, Неверкинский район, село Октябрьское, переулок Советский, 8	f	large
112632	71133	831	Пензенская область, Неверкинский район, село Октябрьское, пер.Советский, 8, МУК Октябрьский поселенческий БДЦ	f	medium
63570	71208	829	Пензенская область, Неверкинский район, село Новое Чирково, Центральная, 1а	f	small
63567	71205	826	Пензенская область, Неверкинский район, село Неверкино, Полевая, 138	f	medium
63569	71207	828	Пензенская область, Неверкинский район, село Неверкино, Николаева, 2 А	f	small
63568	71206	827	Пензенская область, Неверкинский район, село Неверкино, Молодежная, 9	f	medium
63565	71203	824	Пензенская область, Неверкинский район, село Неверкино, Ленина, 30	f	large
63566	71204	825	Пензенская область, Неверкинский район, село Неверкино, Комсомольская, 31	f	medium
63564	71202	823	Пензенская область, Неверкинский район, село Мансуровка, Школьная, 1 А	f	small
63563	71201	822	Пензенская область, Неверкинский район, село Криволучье, Молодежная, 1 А	f	small
63562	71200	821	Пензенская область, Неверкинский район, село Карновар, Мостовая, 30 А	f	medium
63561	71199	820	Пензенская область, Неверкинский район, село Каменный Овраг, Новая, 1 А	f	small
63560	71198	819	Пензенская область, Неверкинский район, село Исикеево, Дружбы, 14	f	small
63559	71197	818	Пензенская область, Неверкинский район, село Илим-Гора, Центральная, 94	f	small
63558	71196	817	Пензенская область, Неверкинский район, село Елшанка, Центральная, 8 Б	f	small
63557	71195	816	Пензенская область, Неверкинский район, село Джалилово, Школьная, 2	f	small
134577	94436	815	Пензенская область, Неверкинский район, село Демино, Центральная, 93	f	small
63556	71194	814	Пензенская область, Неверкинский район, село Демино, Центральная, 93	f	medium
63555	71193	813	Пензенская область, Неверкинский район, село Бикмурзино, Речная, 20	f	medium
63554	71192	812	Пензенская область, Неверкинский район, село Бикмосеевка, Центральная, 57 В	f	small
63553	71191	811	Пензенская область, Неверкинский район, село Бигеево, Центральная, 38	f	small
63552	71190	810	Пензенская область, Неверкинский район, село Березовка, Дубровка, 29 В	f	medium
63551	71189	809	Пензенская область, Неверкинский район, село Алешкино, Набережная, 4 А	f	small
63550	71188	808	Пензенская область, Неверкинский район, село Алеево, Центральная, 18 А	f	medium
63549	71180	800	Пензенская область, Наровчатский район, село Шиловка, Старая Шиловка, 33	f	small
63541	71178	798	Пензенская область, Наровчатский район, село Телешовка, Первомайская, 1а	f	small
63542	71179	799	Пензенская область, Наровчатский район, село Суркино, Пролетарская, 29	f	small
63534	71146	790	Пензенская область, Наровчатский район, село Студенец, Горького, 45а	f	small
63049	70686	298	Пензенская область, Наровчатский район, село Сосновка, Шведская, 1А	f	small
63523	71160	779	Пензенская область, Наровчатский район, Сканово, Школьная, 2	f	small
63535	71171	791	Пензенская область, Наровчатский район, село Садовое, Советская, 14	t	small
63539	71176	796	Пензенская область, Наровчатский район, село Савинки, Новинка, 21а	f	small
112628	71165	784	Пензенская область, Наровчатский район, село Рождественно-Тезиково, Подлужная, 18	f	small
63531	71168	787	Пензенская область, Наровчатский район, село Потодеево, Ленина, 53	f	small
112630	71173	793	Пензенская область, Наровчатский район, село Плесковка, Комсомольская, 25	f	small
63536	71172	792	Пензенская область, Наровчатский район, село Плесковка, Комсомольская, 25	f	small
63540	71177	797	Пензенская область, Наровчатский район, село Паны, Зеленая, 5а	f	small
63544	71182	802	Пензенская область, Наровчатский район, село Орловка, Молодежная, 178	f	small
63524	71161	780	Пензенская область, Наровчатский район, село Новый Пичуры, Молодёжная, 2	f	medium
63547	71185	805	Пензенская область, Наровчатский район, село Наровчат, Советская, 48	f	large
63546	71184	804	Пензенская область, Наровчатский район, село Наровчат, Ленина, 2	f	large
63548	71187	807	Пензенская область, Наровчатский район, село Мелюковка, Малинская, 1	f	small
63532	71170	789	Пензенская область, Наровчатский район, село Масловка, Садовая, 53	t	small
63543	71181	801	Пензенская область, Наровчатский район, село Кадыковка, Сорокина, 86А	f	small
63537	71174	794	Пензенская область, Наровчатский район, село Вьюнки, Молодежная, 3а	f	small
112629	71166	785	Пензенская область, Наровчатский район, село Виляйки, Молодёжная, 31	f	small
63529	71167	786	Пензенская область, Наровчатский район, село Виляйки, Молодежная, 31	f	medium
63538	71175	795	Пензенская область, Наровчатский район, село Большой Чердак, Заречная, 1 а	t	small
63527	71164	783	Пензенская область, Наровчатский район, село Большой Колояр, Советская, 40	f	medium
63525	71162	781	Пензенская область, Наровчатский район, село Большое Кирдяшево, Центральная, 1	f	small
63533	71169	788	Пензенская область, Наровчатский район, село Большая Кавенда, Молодежная, 39	f	medium
63545	71183	803	Пензенская область, Наровчатский район, село Азарапино, Лысовка, 59	f	small
63492	71126	748	Пензенская область, Мокшанский район, село Юлово, Центральная, 30 А	f	\N
63506	71143	763	Пензенская область, Мокшанский район, село Широкоис, Мирная, 3	f	\N
63502	71139	759	Пензенская область, Мокшанский район, село Чернозерье, Базарная площадь, 4 А	f	\N
63490	71124	746	Пензенская область, Мокшанский район, село Царевщино, Центральная, 72	f	\N
63061	70698	310	Пензенская область, Мокшанский район, село Хованщина, Клещёвка, 1	f	small
63495	71129	751	Пензенская область, Мокшанский район, село Успенское, Ермакова, 16	f	\N
63512	71150	769	Пензенская область, Мокшанский район, село Сумароково, Маливиновка, 21	f	\N
63494	71128	750	Пензенская область, Мокшанский район, село Симбухово, Школьная, 1 Б	f	\N
63501	71138	758	Пензенская область, Мокшанский район, село Рамзай, Желиховского, 5	f	\N
63497	71134	754	Пензенская область, Мокшанский район, село Пяша, Строительная, 16	t	\N
63505	71142	762	Пензенская область, Мокшанский район, село Потьма, Ленина, 13	f	\N
63504	71141	761	Пензенская область, Мокшанский район, село Подгорное, Малая Хомяковка, 2	f	\N
63507	71144	764	Пензенская область, Мокшанский район, село Плес, Садовая, 4	f	\N
63515	71153	772	Пензенская область, Мокшанский район, село Парижская Коммуна, Рабочая, 11	t	\N
63499	71136	756	Пензенская область, Мокшанский район, село Отрадный, Школьная, 1	t	\N
63496	71130	752	Пензенская область, Мокшанский район, село Нечаевка, Совхозная, 23	f	\N
68448	71131	753	Пензенская область, Мокшанский район, село Нечаевка, Рабочая, 2	f	large
63491	71125	747	Пензенская область, Мокшанский район, село Муратовка, Школьная, 2	t	\N
63516	71154	773	Пензенская область, Мокшанский район, поселок Мокшан, Студенческая, 3	f	\N
63518	71156	775	Пензенская область, Мокшанский район, поселок Мокшан, Советская, 34	f	\N
63520	71158	777	Пензенская область, Мокшанский район, поселок Мокшан, Победы, 3 А	f	\N
63519	71157	776	Пензенская область, Мокшанский район, поселок Мокшан, Куйбышева, 55	f	\N
63517	71155	774	Пензенская область, Мокшанский район, поселок Мокшан, Красное Польцо, 35а	f	\N
63521	71159	778	Пензенская область, Мокшанский район, поселок Мокшан, 1-я Разведка, 2	f	\N
63462	71092	713	Пензенская область, Мокшанский район, село Михайловка, Центральная, 99	f	small
63508	71145	765	Пензенская область, Мокшанский район, село Михайловка, Советская, 102	t	\N
63513	71151	770	Пензенская область, Мокшанский район, село Мирный, Совхозная, 53 в	f	\N
63424	71008	675	Пензенская область, Мокшанский район, село Лопатино, Фабричная, 2	f	large
63418	71048	669	Пензенская область, Мокшанский район, село Ивановка, Молодежная, 1А	f	small
63509	71147	766	Пензенская область, Мокшанский район, село Знаменское, Центральная, 39	t	\N
63699	71343	964	Пензенская область, Мокшанский район, село Засечное, Шоссейное, 71-А	f	large
63698	71342	963	Пензенская область, Мокшанский район, село Засечное, Шоссейная, 71-а	f	large
63511	71149	768	Пензенская область, Мокшанский район, село Засечное, Пановка, 15	f	\N
62971	70628	223	Пензенская область, Мокшанский район, село Заречный, улица Ленина, 52	f	large
63514	71152	771	Пензенская область, Мокшанский район, село Заречная, 13	t	\N
63498	71135	755	Пензенская область, Мокшанский район, село Елизаветино, Центральная, 28	f	\N
63503	71140	760	Пензенская область, Мокшанский район, село Долгоруково, Школьная, 10	f	\N
63237	70876	491	Пензенская область, Мокшанский район, село Долгоруково, Придорожная, 53	t	small
63500	71137	757	Пензенская область, Мокшанский район, село Дмитриевка, Ждановская, 87	f	\N
63493	71127	749	Пензенская область, Мокшанский район, село Богородское, Центральная, 31 б	f	\N
63345	70973	596	Пензенская область, Мокшанский район, село Березовка, Центральная, 3	f	large
63489	71123	745	Пензенская область, Мокшанский район, село Алексеевка, Алексеевка, 172, помещение в здании школы	f	\N
63487	71122	744	Пензенская область, Малосердобинский район, село Шингал, Луговая, 6	t	small
63477	71109	731	Пензенская область, Малосердобинский район, село Чунаки, Центральная, 140	f	small
63473	71103	725	Пензенская область, Малосердобинский район, село Топлое, Зажигина, 1	f	small
112626	71111	733	Пензенская область, Малосердобинский район, село Старое Славкино, Садовая, 12	f	small
63479	71110	732	Пензенская область, Малосердобинский район, село Старое Славкино, Садовая, 12	f	medium
112624	71105	727	Пензенская область, Малосердобинский район, село Саполга, Советская, 2	f	small
63474	71104	726	Пензенская область, Малосердобинский район, село Саполга, Советская, 2	f	small
63480	71112	734	Пензенская область, Малосердобинский район, село Новое Славкино, Набережная, 37	t	small
63482	71115	737	Пензенская область, Малосердобинский район, село Новое Назимкино, Кооперативная, 2	t	small
63481	71114	736	Пензенская область, Малосердобинский район, село Новое Демкино, Звездная, 27	f	small
63488	71121	743	Пензенская область, Малосердобинский район, село Николаевка, Школьная, 3	f	small
61396	69042	1246	Оренбургская область, Орск, Гомельская, 82	f	large
112627	71120	742	Пензенская область, Малосердобинский район, село Марьевка, Школьная, 1	f	small
63486	71119	741	Пензенская область, Малосердобинский район, село Марьевка, Школьная, 1	f	small
63468	71097	719	Пензенская область, Малосердобинский район, село Малая Сердоба, Строительная, 2	f	medium
63470	71100	722	Пензенская область, Малосердобинский район, село Малая Сердоба, Советская, 23	f	medium
63472	71099	721	Пензенская область, Малосердобинский район, село Малая Сердоба, Советская, 10	f	medium
112623	71102	724	Пензенская область, Малосердобинский район, село Малая Сердоба, Пацаева, 29	f	small
63467	71096	718	Пензенская область, Малосердобинский район, село Малая Сердоба, Октябрьская, 12	f	medium
63469	71098	720	Пензенская область, Малосердобинский район, село Малая Сердоба, Ленинская, 91	f	medium
112622	71101	723	Пензенская область, Малосердобинский район, село Малая Сердоба, Калинина, 2а	f	small
63476	71106	728	Пензенская область, Малосердобинский район, село Майское, 2-я Молодежная, 1а	f	small
112625	71107	729	Пензенская область, Малосердобинский район, село Майское, 2-ая Молодежная, 1а	f	small
63484	71117	739	Пензенская область, Малосердобинский район, село Липовка, Школьная, 1а	f	small
63485	71118	740	Пензенская область, Малосердобинский район, село Колемас, Дворянская, 15	t	small
63478	71113	735	Пензенская область, Малосердобинский район, село Ключи, Главная, 8а	f	small
63483	71116	738	Пензенская область, Малосердобинский район, село Дружаевка, Набережная, 35/1	f	small
63475	71108	730	Пензенская область, Малосердобинский район, село Бадровка, Студеная, 24а	t	small
63463	71093	714	Пензенская область, Лунинский район, село Чирково, Садовая, 22	t	small
63464	71074	715	Пензенская область, Лунинский район, село Сытинка, Совхозная, 14А	f	small
63461	71091	712	Пензенская область, Лунинский район, село Старая Степановка, Центральная, 3а	f	small
63453	71083	704	Пензенская область, Лунинский район, село Старая Кутля, Максима Горького, 73	t	small
63439	71068	690	Пензенская область, Лунинский район, село Синорово, Титова, 40	f	small
63368	70996	619	Пензенская область, Лунинский район, село Родники, Школьная, 1	f	medium
63441	71070	692	Пензенская область, Лунинский район, село Напольный Вьяс, Бобровская, 2	t	small
63255	70893	509	Пензенская область, Лунинский район, село Маровка, Черокманова, 50	t	small
63450	71080	701	Пензенская область, Лунинский район, село Манторово, Свердлова, 97а	f	medium
63458	71088	709	Пензенская область, Лунинский район, поселок Лунино, Юбилейная, 2	f	large
63456	71086	707	Пензенская область, Лунинский район, поселок Лунино, Советская, 109	f	medium
63455	71085	706	Пензенская область, Лунинский район, поселок Лунино, Советская, 39	f	large
63457	71087	708	Пензенская область, Лунинский район, поселок Лунино, Мясникова, 47	f	large
63454	71084	705	Пензенская область, Лунинский район, поселок Лунино, Мичурина, 43а	f	large
63451	71081	702	Пензенская область, Лунинский район, поселок Лунино, Максима Горького, 26	f	small
63459	71089	710	Пензенская область, Лунинский район, поселок Лунино, Ломоносова, 26	f	large
63448	71078	699	Пензенская область, Лунинский район, село Ломовка, Школьная, 45	f	medium
63465	71094	716	Пензенская область, Лунинский район, село Липяги, Звездная, 19	t	small
63442	71071	693	Пензенская область, Лунинский район, село Лесной Вьяс, Большая дорога, 69	f	medium
63452	71082	703	Пензенская область, Лунинский район, поселок Краснооктябрьский, Колхозная, 4В	t	small
112620	71079	700	Пензенская область, Лунинский район, село Казачья Пелетьма, Школьная, 12	f	small
112619	71077	698	Пензенская область, Лунинский район, село Иванырсенский Лесозавод, Заводская, 7	t	small
63446	71076	697	Пензенская область, Лунинский район, село Иванырс, Юбилейная, 15	f	medium
63445	71075	696	Пензенская область, Лунинский район, село Екатериновка, Сельская площадь, 1	t	small
63443	71072	694	Пензенская область, Лунинский район, село Дарьевка, Центральная, 24	f	small
63440	71069	691	Пензенская область, Лунинский район, село Большой Вьяс, Базарная, 14	f	large
63437	71066	688	Пензенская область, Лунинский район, село Болотниково, Муханова, 5	f	medium
63436	71065	687	Пензенская область, Лопатинский район, село Чардым, Молодежная, 1А	f	small
63435	71064	686	Пензенская область, Лопатинский район, село Точка, Центральная, 15	t	small
63432	71061	683	Пензенская область, Лопатинский район, село Суляевка, Верхняя, 95Б	f	medium
63434	71063	685	Пензенская область, Лопатинский район, село Старый Карлыган, Центральная, 44	f	medium
63433	71062	684	Пензенская область, Лопатинский район, село Старый Вершаут, Центральная, 56	f	medium
63431	71060	682	Пензенская область, Лопатинский район, село Сорокино, Центральная, 16/1	t	small
63430	71059	681	Пензенская область, Лопатинский район, село Пылково, Центральная, 40	f	small
63429	71058	680	Пензенская область, Лопатинский район, село Пасечное, Песчаная, 28	t	small
63428	71057	679	Пензенская область, Лопатинский район, село Огаревка, Школьная, 6	f	small
63259	70897	513	Пензенская область, Лопатинский район, село Николаевка, Колхозная, 11	t	small
63426	71055	677	Пензенская область, Лопатинский район, село Луначарское, Центральная, 6	f	small
63420	71050	671	Пензенская область, Лопатинский район, село Колбинка, Мостовая, 33	t	small
63422	71052	673	Пензенская область, Лопатинский район, село Китунькино, Центральная, 1	f	small
63419	71049	670	Пензенская область, Лопатинский район, село Камаевка, Центральная, 55	t	small
63417	71047	668	Пензенская область, Лопатинский район, село Дубровское, Школьная, 1	f	small
63416	71046	667	Пензенская область, Лопатинский район, село Даниловка, Школьная, 4	f	medium
63415	71045	666	Пензенская область, Лопатинский район, село Генеральщино, Центральная, 74А	f	small
63412	71042	663	Пензенская область, Лопатинский район, село Владимирский, Советская, 1А	f	small
63414	71044	665	Пензенская область, Лопатинский район, село Вехово, Центральная, 2	f	small
63413	71043	664	Пензенская область, Лопатинский район, село Верешим, Центральная, 38	f	small
63411	71041	662	Пензенская область, Лопатинский район, село Бузовлево, Центральная, 92	f	small
63410	71040	661	Пензенская область, Лопатинский район, село Буденновка, Мирная, 6А	t	small
63409	71039	660	Пензенская область, Лопатинский район, село Берлик, Садовая, 44/1	t	small
63408	71038	659	Пензенская область, Лопатинский район, село Белогорье, Молодежная, 18	t	small
63385	71014	636	Пензенская область, Кузнецкий район, с.Татарская Пенделка, Школьная, 12е	f	small
63398	71028	649	Пензенская область, Кузнецкий район, село Ясная Поляна, Заводская, 25	f	large
63373	71001	624	Пензенская область, Кузнецкий район, село Явлейка, Сурская, 1	f	medium
63369	70997	620	Пензенская область, Кузнецкий район, село Шелемис, Центральная, 63	t	small
63391	71020	642	Пензенская область, Кузнецкий район, село Чибирлей, Сидорова, 156а	f	medium
112616	71002	625	Пензенская область, Кузнецкий район, село Часы, Часовская, 59, Фельдшерско-акушерский пункт.	t	small
63389	71018	640	Пензенская область, Кузнецкий район, село Тютнярь, Блохина, 34	f	small
112615	70998	621	Пензенская область, Кузнецкий район, село Тихменево, Центральная, 7б, МУК Тихменевский БДЦ	f	small
63404	71034	655	Пензенская область, Кузнецкий район, село Татарский Канадей, Школьная, 54	f	large
63392	71022	643	Пензенская область, Кузнецкий район, село Тарлаково 2-е, Центральная, 69	t	small
63380	71009	631	Пензенская область, Кузнецкий район, село Тарлаково 1-е, Центральная, 123а	f	small
63382	71011	633	Пензенская область, Кузнецкий район, село Сюзюм, Московская, 23	f	small
63805	71448	1070	Пензенская область, Кузнецкий район, село Сюзюм, Зелёная, 25	f	small
63397	71027	648	Пензенская область, Кузнецкий район, село Сухановка, Зеленая, 4	f	medium
112617	71013	635	Пензенская область, Кузнецкий район, село Старый Кряжим, Ленина, 1, Филиал №3 МБУК Махалинский БДЦ	f	medium
63401	71031	652	Пензенская область, Кузнецкий район, село Сосновка, Совхозная, 13	t	small
63390	71019	641	Пензенская область, Кузнецкий район, село Радищево, Центральная, 95	f	large
63377	71005	628	Пензенская область, Кузнецкий район, село Поселки, Советская, 20	f	large
63376	71004	627	Пензенская область, Кузнецкий район, село Поселки, Ново-Зеленая, 9	f	large
63393	71023	644	Пензенская область, Кузнецкий район, село Пионер, Заводская, 11	f	large
63378	71006	629	Пензенская область, Кузнецкий район, село Никольское, им.Терехина М.А, 245	f	large
63388	71017	639	Пензенская область, Кузнецкий район, село Нижние Аблязово, Садовая, 55-2	t	small
63818	71461	1083	Пензенская область, Кузнецкий район, село Монастырское, Школьная, 18	f	small
63383	71012	634	Пензенская область, Кузнецкий район, село Махалино, 15, Рабочий городок совхоза	f	large
63403	71033	654	Пензенская область, Кузнецкий район, село Малый Труев, Больничная, 2б	f	medium
63399	71029	650	Пензенская область, Кузнецкий район, село Комаровка, Молодежная, 2а	f	medium
63372	71000	623	Пензенская область, Кузнецкий район, село Козляковка, Графская, 4	t	small
63395	71025	646	Пензенская область, Кузнецкий район, село Каменка, Озерная, 1а	f	small
63371	70999	622	Пензенская область, Кузнецкий район, село Казаковка, Школьный переулок, 3	t	small
63396	71026	647	Пензенская область, Кузнецкий район, село Злобинка, Центральная, 6а	t	small
63406	71036	657	Пензенская область, Кузнецкий район, поселок Евлашево, Центральный переулок, 8	f	large
63405	71035	656	Пензенская область, Кузнецкий район, поселок Евлашево, Центральная, 27	f	large
63400	71030	651	Пензенская область, Кузнецкий район, село Дворики, Дорожная, 63	f	small
63386	71015	637	Пензенская область, Кузнецкий район, поселок Верхозим, Проспект Победы, 1	f	large
63402	71032	653	Пензенская область, Кузнецкий район, село Большой Труев, Прудная, 15а	f	large
63375	71003	626	Пензенская область, Кузнецкий район, село Благодатка, Центральная, 78	f	small
63379	71007	630	Пензенская область, Кузнецкий район, село Бестянка, Центральная, 76а	f	large
63387	71016	638	Пензенская область, Кузнецкий район, село Анненково, Юбилейная, 1	f	large
63394	71024	645	Пензенская область, Кузнецкий район, село Алексеевка, Школьная, 7	f	small
63711	71356	976	Пензенская область, Кондольский район, село Улановка, Центральная, 2	f	small
63466	71095	717	Пензенская область, Кондольский район, село Танеевка, Вольновка, 11-1	f	small
63723	71369	988	Пензенская область, Кондольский район, село Покрово-Березовка, Совхозная, 3	f	small
63724	71370	989	Пензенская область, Кондольский район, село Новопавловка, Даманская, 10	f	small
63704	71349	969	Пензенская область, Кондольский район, село Кондоль, Южная, 14	f	large
63705	71350	970	Пензенская область, Кондольский район, село Кондоль, Совхозная, 8	f	small
63703	71348	968	Пензенская область, Кондольский район, село Кондоль, Осипова, 36-А	f	large
63707	71352	972	Пензенская область, Кондольский район, село Колышлейка, Луговая, 12	f	small
63712	71357	977	Пензенская область, Кондольский район, село Князевка, Центральная, 2	f	medium
63726	71372	991	Пензенская область, Кондольский район, село Ермолаевка, Молодежная, 16	f	small
63708	71353	973	Пензенская область, Кондольский район, село Волхонщино, Центральная, 2-а	f	small
63690	71333	955	Пензенская область, Кондольский район, село Волхон-Умет, Дорожная, 59-а	t	small
63689	71332	954	Пензенская область, Кондольский район, село Варыпаево, Школьная, 1-А	f	medium
112596	70916	535	Пензенская область, Кондольский район, село Андреевка, Кошелевского, 20, здание МОУ ООШ	f	small
63360	70988	611	Пензенская область, Колышлейский район, село совхоз Хопер, Центральная, 10А	f	medium
63354	70982	605	Пензенская область, Колышлейский район, село совхоз Пограничный, Школьная, 4А	f	medium
63361	70989	612	Пензенская область, Колышлейский район, село Чубаровка, Школьная, 1	f	small
63344	58537	595	Пензенская область, Колышлейский район, село Халтурино, Садовая, 31	f	small
63358	70986	609	Пензенская область, Колышлейский район, село Телегино, пер.Школьный, 5	f	medium
63357	70985	608	Пензенская область, Колышлейский район, село Сумы, Центральная, 20	f	medium
63355	70983	606	Пензенская область, Колышлейский район, село Старая Потловка, Центральная, 6	f	medium
63353	70981	604	Пензенская область, Колышлейский район, село Плещеевка, Центральная, 13	f	small
63351	70979	602	Пензенская область, Колышлейский район, село Названовка, Пензенская, 2	f	large
63825	71468	1090	Пензенская область, Колышлейский район, село Липяги, Новая, 1А	f	small
63356	70984	607	Пензенская область, Колышлейский район, село Красная Горка, Мало Садовая, 1Б	f	large
63363	70991	614	Пензенская область, Колышлейский район, поселок Колышлей, Терешкина, 18	f	large
63367	70995	618	Пензенская область, Колышлейский район, поселок Колышлей, Строителей, 7	f	large
63366	70994	617	Пензенская область, Колышлейский район, поселок Колышлей, Садовая, 151	f	large
63364	70992	615	Пензенская область, Колышлейский район, поселок Колышлей, Садовая, 50	f	large
63365	70993	616	Пензенская область, Колышлейский район, поселок Колышлей, Пензенская, 3	f	large
63362	70990	613	Пензенская область, Колышлейский район, поселок Колышлей, Остапенко, 11	f	large
63349	70977	600	Пензенская область, Колышлейский район, село Колтовское, Советская, 1А	f	medium
112614	70976	599	Пензенская область, Колышлейский район, село Катковка, Школьная, 3	f	small
63592	71246	868	Пензенская область, Колышлейский район, село Голицыно, Петрова Слобода, 2а	f	small
63257	70895	511	Пензенская область, Колышлейский район, село Бекетовка, Центральная, 63	f	small
63343	70956	594	Пензенская область, Колышлейский район, село Апраксино, Центральная, 65	t	small
112613	70972	593	Пензенская область, Камешкирский район, село Чумаево, Школьная, 2	f	medium
63330	70961	581	Пензенская область, Камешкирский район, село Старый Чирчим, Лесная, 2А	f	medium
112608	70962	582	Пензенская область, Камешкирский район, село Старый Чирчим, Лесная, 2а	f	small
63339	70969	590	Пензенская область, Камешкирский район, село Русский Камешкир, Техническая, 2	f	medium
63338	70968	589	Пензенская область, Камешкирский район, село Русский Камешкир, Радищева, 9	f	large
63340	70970	591	Пензенская область, Камешкирский район, село Русский Камешкир, Коммунальная, 10	f	medium
63341	70971	592	Пензенская область, Камешкирский район, село Русский Камешкир, Кирова, 1	f	medium
112612	70967	588	Пензенская область, Камешкирский район, село Порзово, Центральная, 12	f	small
63333	70964	584	Пензенская область, Камешкирский район, село Пестровка, Центральная, 45	f	small
63328	70960	580	Пензенская область, Камешкирский район, село Новое Шаткино, Гагарина, 4	f	medium
112603	95184	573	Пензенская область, Камешкирский район, село Мордовский Камешкир, Центральная, 40	f	small
63322	70954	574	Пензенская область, Камешкирский район, село Мордовский Камешкир, Центральная, 40	f	small
63326	70958	578	Пензенская область, Камешкирский район, село Мамадыш, Школьный, 19	f	small
112605	70955	576	Пензенская область, Камешкирский район, село Лапшово, Центральная, 3	f	small
112604	70955	575	Пензенская область, Камешкирский район, село Лапшово, Центральная, 3	f	medium
112606	70957	577	Пензенская область, Камешкирский район, село Кулясово, Молодежная, 25	f	small
63332	70963	583	Пензенская область, Камешкирский район, село Камышинка, Сухая, 29	t	small
112610	70965	586	Пензенская область, Камешкирский район, село Дьячевка, Сосновская, 3а	f	small
112609	70965	585	Пензенская область, Камешкирский район, село Дьячевка, Сосновская, 3а	f	small
63819	71462	1084	Пензенская область, Камешкирский район, село Дубровки, Новая, 5	f	medium
112602	70952	572	Пензенская область, Камешкирский район, село Большой Умыс, Школьная, 1	f	small
112601	70952	571	Пензенская область, Камешкирский район, село Большой Умыс, Школьная, 1	f	small
112611	70966	587	Пензенская область, Камешкирский район, село Бегуч, Центральная, 44	f	small
63677	71320	942	Пензенская область, Камешкирский район, село Алексеевка, Центральная, 31	f	small
63317	70950	569	Пензенская область, Каменский район, село Федоровка, Центральная, 5	f	medium
63306	70939	558	Пензенская область, Каменский район, село Усть-Атмис, Зеленая, 23	f	small
63311	70944	563	Пензенская область, Каменский район, село Телятино, Кушкин, 38	f	small
63291	70924	543	Пензенская область, Каменский район, село Соболевка, Ивановка, 33	f	small
63293	70926	545	Пензенская область, Каменский район, село Скворечное, Речная, 6	f	small
63312	70945	564	Пензенская область, Каменский район, село Покровская Арчада, Драгунова, 22	f	medium
63284	70917	536	Пензенская область, Каменский район, село Низовка, Центральная, 78	f	small
63307	70940	559	Пензенская область, Каменский район, село Надеждинка, Шоссейная, 28	t	small
63316	70949	568	Пензенская область, Каменский район, село Максимовка, Максимовская, 99	t	small
63318	70951	570	Пензенская область, Каменский район, село Кургановка, Верхний порядок, 34	f	medium
63298	70931	550	Пензенская область, Каменский район, село Кувака, Центральная, 28	f	small
63309	70942	561	Пензенская область, Каменский район, село Крыловка, Майская, 50	f	small
112600	70930	549	Пензенская область, Каменский район, село Кочелейка, Школьная, 23А	f	medium
63296	70929	548	Пензенская область, Каменский район, село Клейменовка, Степная, 4	f	small
63301	70934	553	Пензенская область, Каменский район, село Кикино, Центральная, 3	f	large
63299	70932	551	Пензенская область, Каменский район, село Кевдо-Мельситово, Ленина, 16	f	large
63282	70915	534	Пензенская область, Каменский район, Каменка, Юдина, 22	f	medium
63277	70911	530	Пензенская область, Каменский район, Каменка, Чернышевского, 5	f	large
63266	70903	520	Пензенская область, Каменский район, Каменка, Театральный проезд, 6	f	medium
63275	70909	528	Пензенская область, Каменский район, Каменка, Суворова, 15	f	large
63265	70902	519	Пензенская область, Каменский район, Каменка, Садовая, 43	f	large
63263	70900	517	Пензенская область, Каменский район, Каменка, Маловского, 2а	f	large
63262	70900	516	Пензенская область, Каменский район, Каменка, Маловского, 2а	f	large
63271	70907	525	Пензенская область, Каменский район, Каменка, Космонавтов, 5	f	medium
63280	70914	533	Пензенская область, Каменский район, Каменка, Коммунистическая, 24	f	large
63276	70910	529	Пензенская область, Каменский район, Каменка, Ворошилова, 18а	f	large
63268	70904	522	Пензенская область, Каменский район, Каменка, Болгарская, 14	f	large
63267	70904	521	Пензенская область, Каменский район, Каменка, Болгарская, 14	f	large
63270	70906	524	Пензенская область, Каменский район, Каменка, Баумана, 44	f	large
63264	70901	518	Пензенская область, Каменский район, Каменка, Автохозяйская, 11	f	medium
63269	70905	523	Пензенская область, Каменский район, Каменка, Белинская, 119	f	large
63305	70938	557	Пензенская область, Каменский район, село Казанская Арчада, Школьная, 13	f	small
63304	70937	556	Пензенская область, Каменский район, село Знаменка, Центральная, 10	t	small
112599	70928	547	Пензенская область, Каменский район, село Завиваловка, Совхозная, 1, здание МОУ ООШ	f	small
63292	70925	544	Пензенская область, Каменский район, село Головинщино, Первомайская, 10	f	medium
63289	70922	541	Пензенская область, Каменский район, село Владыкино, Советская, 5	f	small
112598	70920	539	Пензенская область, Каменский район, село Большие Верхи, Центральная, 15	f	small
112597	70919	538	Пензенская область, Каменский район, село Блиновка, Школьная, 13	f	small
63300	70933	552	Пензенская область, Каменский район, село Безруково, Новая, 6	t	small
63315	70948	567	Пензенская область, Каменский район, село Батрак, Советская, 20	f	medium
63636	71282	904	Пензенская область, Каменский район, село Ахматовка, Центральная, 46	f	small
63314	70947	566	Пензенская область, Каменский район, село Ахматовка, Центральная, 69а	t	small
63098	70735	348	Пензенская область, Каменский район, село Аргамаково, Центральная, 3	f	small
63250	70888	504	Пензенская область, Иссинский район, село Украинцево, Центральная, 37	t	small
63260	70898	514	Пензенская область, Иссинский район, село Уваровский, Центральная, 1а, центральная усадьба свх. Уваровский	f	small
63258	70896	512	Пензенская область, Иссинский район, село Уварово, Центральная, 87	f	small
63256	70894	510	Пензенская область, Иссинский район, село Соловцово, Центральная, 16	f	small
63244	70882	498	Пензенская область, Иссинский район, село Приволье, Проезжая, 5	f	small
63241	70879	495	Пензенская область, Иссинский район, село Пестровка Знаменская, Центральная, 25	f	small
63252	70890	506	Пензенская область, Иссинский район, село Новотрехсвятское, Центральная, 39	f	small
63243	70881	497	Пензенская область, Иссинский район, село Никольская Пестровка, Нагорная, 8	t	small
63427	71056	678	Пензенская область, Иссинский район, село Николаевка, Молодежная, 8	t	small
63238	70877	492	Пензенская область, Иссинский район, село Кисловка, Речная, 64	f	small
63251	70889	505	Пензенская область, Иссинский район, село Кильмаевка, Центральная, 36	t	small
63248	70886	502	Пензенская область, Иссинский район, село Каменный Брод, Набережная, 8	f	small
63247	70885	501	Пензенская область, Иссинский район, поселок Исса, Черокманова, 18	f	large
63246	70884	500	Пензенская область, Иссинский район, поселок Исса, Садовая, 6	f	large
63245	70883	499	Пензенская область, Иссинский район, поселок Исса, Калинина, 23	f	large
63249	70887	503	Пензенская область, Иссинский район, село Верхняя Салмовка, Демократическая, 23	t	small
63240	70837	494	Пензенская область, Иссинский район, село Бутурлино, Молодежная, 8	f	small
63236	70875	490	Пензенская область, Иссинский район, село Булычево, Школьная, 7	f	medium
63239	70878	493	Пензенская область, Иссинский район, село Булычево, Снежная, 35к1, центральная усадьба свх. Маяк	f	small
63253	70891	507	Пензенская область, Иссинский район, село Архаровка, Приовражная, 17	t	small
63285	70918	537	Пензенская область, Иссинский район, село Анучино, Горка, 37	f	medium
63137	70773	387	Пензенская область, Иссинский район, село Александровка, Крюковка, 43 А	f	small
63094	70731	344	Пензенская область, Земетчинский район, село Чернышево, Центральная, 110В	f	medium
63223	70862	478	Пензенская область, Земетчинский район, село Чернояр, Школьная, 36	f	small
63235	70874	489	Пензенская область, Земетчинский район, село Ушинка, Советская, 54	f	medium
63234	70873	488	Пензенская область, Земетчинский район, село Ушинка, Советская, 56	f	medium
63217	70852	468	Пензенская область, Земетчинский район, село Усердино, Вторая часть, 30	f	small
63230	70868	483	Пензенская область, Земетчинский район, село Сядемка, Советская, 120	t	small
63213	70870	485	Пензенская область, Земетчинский район, село Старополянское, Юбилейная, 17	f	small
63221	70857	473	Пензенская область, Земетчинский район, село Салтыково, Молодёжная, 27	f	medium
63215	70855	471	Пензенская область, Земетчинский район, село Рянза, Лесная, 24	f	small
63212	70850	466	Пензенская область, Земетчинский район, поселок Пролетарский, Центральная, 10 а	f	medium
68458	70859	475	Пензенская область, Земетчинский район, село Пашково, Ленина, 1а	f	large
112595	70860	476	Пензенская область, Земетчинский район, село Пашково, 40 лет Победы, 6, контора участкового лесничества	f	small
63220	70856	472	Пензенская область, Земетчинский район, село Оторма, Новая, 19	f	small
63222	70861	477	Пензенская область, Земетчинский район, село Морсово, Заводская, 30	f	small
63216	70851	467	Пензенская область, Земетчинский район, село Матчерка, Центральная, 19 а	f	medium
63233	70872	487	Пензенская область, Земетчинский район, село Малая Ижмора, Ивановка, 8	f	medium
63214	70858	474	Пензенская область, Земетчинский район, село Лебедянка, Луговая, 31 а	t	small
63229	70867	482	Пензенская область, Земетчинский район, село Красная Дубрава, Ленина, 1 а	f	small
63228	70866	481	Пензенская область, Земетчинский район, село Красная Дубрава, Новый Посёлок, 27	f	small
63226	70863	479	Пензенская область, Земетчинский район, село Кириллово, Школьный переулок, 3	f	small
63219	70854	470	Пензенская область, Земетчинский район, Советская, 527В	f	medium
63205	70843	459	Пензенская область, Земетчинский район, поселок Земетчино, Смирнова, 103	f	large
63211	70849	465	Пензенская область, Земетчинский район, поселок Земетчино, Пушкина, 5	f	large
63206	70844	460	Пензенская область, Земетчинский район, поселок Земетчино, Молодёжная, 1	f	large
63208	70846	462	Пензенская область, Земетчинский район, поселок Земетчино, Ленина, 150	f	large
63207	70845	461	Пензенская область, Земетчинский район, поселок Земетчино, Кулакова, 7 а	f	large
63209	70847	463	Пензенская область, Земетчинский район, поселок Земетчино, Кирова, 86	f	large
63210	70848	464	Пензенская область, Земетчинский район, поселок Земетчино, Белинского, 4	f	large
63218	70853	469	Пензенская область, Земетчинский район, село Долгово, Ленинская, 78 а	f	small
63227	70865	480	Пензенская область, Земетчинский район, село Гоголев Бор, Первомайская, 56	t	small
63231	70869	484	Пензенская область, Земетчинский район, село Вяземка, Ленина, 228	f	medium
63232	70871	486	Пензенская область, Земетчинский район, село Большая Ижмора, Садовая, 2	f	medium
63111	70747	361	Пензенская область, Земетчинский район, село Александровка, Центральная, 6	f	small
62985	70639	237	Пензенская область, Заречный городской округ, Заречный, проспект Мира, 7	f	large
62983	70637	235	Пензенская область, Заречный городской округ, Заречный, проспект Мира, 12	f	large
62984	70638	236	Пензенская область, Заречный городской округ, Заречный, Проспект Мира , 26	f	large
62986	70640	238	Пензенская область, Заречный городской округ, Заречный, Литке, 29, корпус 6 	f	large
62964	70621	216	Пензенская область, Заречный городской округ, Заречный, Ленина, 10	f	large
62962	70620	214	Пензенская область, Заречный городской округ, Заречный, Ленина, 7	f	large
62968	70625	220	Пензенская область, Заречный городской округ, Заречный, Конституции СССР, 39а	f	large
61387	69037	1237	Оренбургская область, Орск, Гайское шоссе, 14	f	large
62981	70635	233	Пензенская область, Заречный городской округ, Заречный, Комсомольская, 10	f	large
62980	70634	232	Пензенская область, Заречный городской округ, Заречный, Комсомольская, 9	f	large
62982	70636	234	Пензенская область, Заречный городской округ, Заречный, Зеленая, 6	f	large
62963	70619	215	Пензенская область, Заречный городской округ, Заречный, Зеленая, 14	f	large
62961	70619	213	Пензенская область, Заречный городской округ, Заречный, Зеленая, 14	f	large
62967	70624	219	Пензенская область, Заречный городской округ, Заречный, Заречная, 22а	f	large
62966	70623	218	Пензенская область, Заречный городской округ, Заречный, Заречная, 19	f	large
62965	70622	217	Пензенская область, Заречный городской округ, Заречный, Заречная, 40	f	large
63180	70817	434	Пензенская область, Городищенский район, село Юлово, Советская, 21	f	medium
63196	70833	450	Пензенская область, Городищенский район, село Чаадаевка, Молодёжная, 9	f	medium
63197	70834	451	Пензенская область, Городищенский район, село Чаадаевка, Ленина, 96	f	large
63194	70831	448	Пензенская область, Городищенский район, село Чаадаевка, Ленина, 26	f	large
63193	70830	447	Пензенская область, Городищенский район, поселок Чаадаевка, Строителей, 43	f	large
63195	70832	449	Пензенская область, Городищенский район, поселок Чаадаевка, Заводская, 5	f	large
63192	70829	446	Пензенская область, Городищенский район, село Уранка, Ленинская, 168	t	small
63176	70813	430	Пензенская область, Городищенский район, село Трескино, Садовая, 21	f	medium
63359	70987	610	Пензенская область, Городищенский район, село Трескино, Мира, 24	f	medium
63171	70808	425	Пензенская область, Городищенский район, Сурск, переулок Лесной, 10а	f	large
63173	70810	427	Пензенская область, Городищенский район, Сурск, Школьная площадь, 4	f	large
63172	70809	426	Пензенская область, Городищенский район, Сурск, Садовая, 5а	f	large
63183	70820	437	Пензенская область, Городищенский район, село Стеклозавод, Шкафтинская, 2	t	small
63174	70811	428	Пензенская область, Городищенский район, село Старый Турдаки, Театральная, 8б	f	small
63198	70835	452	Пензенская область, Городищенский район, село Саловка, Луговая, 69б	f	small
63179	70816	433	Пензенская область, Городищенский район, село Русский Ишим, Молодежная, 1б	f	small
63168	70805	422	Пензенская область, Городищенский район, село Новая Забалка, Школьная, 12	f	small
63199	70836	453	Пензенская область, Городищенский район, село Нижняя Елюзань, Центральная, 93а	f	large
63177	70814	431	Пензенская область, Городищенский район, село Мордовский Ишим, Школьная, 40	f	small
63178	70815	432	Пензенская область, Городищенский район, село Можарка, Центральная, 136	f	small
63181	70818	435	Пензенская область, Городищенский район, село Кардаво, Молодежная, 2	f	small
63170	70807	424	Пензенская область, Городищенский район, село Канаевка, Советская, 64	f	medium
63169	70806	423	Пензенская область, Городищенский район, село Канаевка, Советская, 66	f	medium
63200	70838	454	Пензенская область, Городищенский район, село Иванисовка, Молодежная, 28	t	small
63175	70812	429	Пензенская область, Городищенский район, село Затон, Заводская, 5	f	small
63187	70824	441	Пензенская область, Городищенский район, Городище, Октябрьская, 30	f	large
63188	70825	442	Пензенская область, Городищенский район, Городище, Набережная, 17	f	large
63186	70823	440	Пензенская область, Городищенский район, Городище, Московская, 29	f	large
63189	70826	443	Пензенская область, Городищенский район, Городище, Ленина	f	large
63185	70822	439	Пензенская область, Городищенский район, Городище, А.Матросова, 64	f	medium
63184	70821	438	Пензенская область, Городищенский район, село Вышелей, Молодежная, 31	f	small
63182	70819	436	Пензенская область, Городищенский район, село Верхний Шкафт, Молодежная, 2б	f	small
63669	71312	934	Пензенская область, Городищенский район, село Веденяпино, Новая, 6	t	small
63779	71422	1044	Пензенская область, Городищенский район, село Архангельское, Сибирь, 17	t	small
63191	70828	445	Пензенская область, Городищенский район, село Архангельское, Ленина, 70	f	large
63676	71319	941	Пензенская область, Городищенский район, село Архангельское, Гагарина, 10	t	small
63166	70802	419	Пензенская область, Вадинский район, село Ягановка, Школьная, 21	f	small
112594	70803	420	Пензенская область, Вадинский район, село Ягановка, Верхняя, 11	f	small
63164	70800	417	Пензенская область, Вадинский район, село Татарская Лака, Школьная, 80а	f	small
63163	70799	416	Пензенская область, Вадинский район, село Серго-Поливаново, Советская, 29а	f	small
63149	70786	399	Пензенская область, Вадинский район, село Ртищево, Плант, 19А	f	small
112592	70795	412	Пензенская область, Вадинский район, село Рахмановка, Советская, 1а	f	small
63160	70794	411	Пензенская область, Вадинский район, село Рахмановка, Советская, 6	f	medium
63310	70943	562	Пензенская область, Вадинский район, село Мочалейка, Финская, 39	f	medium
112648	71433	1055	Пензенская область, Вадинский район, село Маркино, Молодежная, 9	f	small
63167	70804	421	Пензенская область, Вадинский район, село Котел, Село, 57	f	small
63162	70798	415	Пензенская область, Вадинский район, село Коповка, Советская, 48	f	small
112591	70793	410	Пензенская область, Вадинский район, село Каргалей, Центральная, 84	f	small
63159	70776	409	Пензенская область, Вадинский район, село Каргалей, Центральная, 85	f	small
63165	70801	418	Пензенская область, Вадинский район, село Выборное, Молодежная, 8	f	small
63158	58097	408	Пензенская область, Вадинский район, село Вадинск, Школьная, 47	f	small
63157	58048	407	Пензенская область, Вадинский район, село Вадинск, Школьная, 49	f	medium
63152	70789	402	Пензенская область, Вадинский район, село Вадинск, Шаландина, 12	f	small
63151	70788	401	Пензенская область, Вадинский район, село Вадинск, Площадь Ленина, 1	f	small
63150	70787	400	Пензенская область, Вадинский район, село Вадинск, Площадь Ленина, 16а	f	small
63155	70791	405	Пензенская область, Вадинский район, село Вадинск, Молодёжная, 12	f	medium
63154	70791	404	Пензенская область, Вадинский район, село Вадинск, Молодёжная, 12	f	small
63156	70792	406	Пензенская область, Вадинский район, село Вадинск, Максютова, 16а	f	small
63153	70790	403	Пензенская область, Вадинский район, село Вадинск, Дорожная, 1а	f	small
63147	70784	397	Пензенская область, Вадинский район, село Большая Лука, Советская, 81	f	small
63132	70768	382	Пензенская область, Бессоновский район, пос.Полевой, Нефтяников, 10	f	small
63129	70765	379	Пензенская область, Бессоновский район, село Чертково, Центральная, 45	f	medium
63145	70782	395	Пензенская область, Бессоновский район, село Чемодановка, Спортивная, 7 А	f	large
63144	70781	394	Пензенская область, Бессоновский район, село Чемодановка, Генералова, 35	f	large
63143	70780	393	Пензенская область, Бессоновский район, село Трофимовка, Совхозная, 12	t	small
63134	70770	384	Пензенская область, Бессоновский район, село Степное Полеологово, Колхозная, 4	f	medium
63142	70779	392	Пензенская область, Бессоновский район, село Степановка, Дорожная, 45 Б	f	medium
63138	70774	388	Пензенская область, Бессоновский район, село Сосновка, Заречная, 8	t	small
63139	70775	389	Пензенская область, Бессоновский район, село Сосновка, Дорожная, 16	f	large
63135	70771	385	Пензенская область, Бессоновский район, село Пыркино, Центральная, 160 А	f	medium
63136	70772	386	Пензенская область, Бессоновский район, село Проказна, Школьная, 1	t	small
63141	70778	391	Пензенская область, Бессоновский район, село Пазелки, Интернациональная, 3	f	medium
63140	70777	390	Пензенская область, Бессоновский район, село Лопуховка, Завядя, 70 А	f	medium
63146	70783	396	Пензенская область, Бессоновский район, село Лопатки, Центральная, 1 А	f	medium
63717	71363	982	Пензенская область, Бессоновский район, Леонидовка, Школьная, 48	f	large
63131	70767	381	Пензенская область, Бессоновский район, село Кижеватово, Молодежная, 65	f	large
63130	70766	380	Пензенская область, Бессоновский район, село Кижеватово, Большая Дорога, 91	f	large
63702	71346	967	Пензенская область, Бессоновский район, поселок Золотаревка, Ленина, 26	f	large
63127	70763	377	Пензенская область, Бессоновский район, село Грабово, Юбилейная, 8	f	medium
63128	70764	378	Пензенская область, Бессоновский район, село Грабово, Центральная, 181	f	medium
63124	70760	374	Пензенская область, Бессоновский район, село Грабово, Спиртзаводская, 8	f	medium
63122	70758	372	Пензенская область, Бессоновский район, село Грабово, Советская, 160	f	large
63125	70761	375	Пензенская область, Бессоновский район, село Грабово, Ново-Западная, 15	f	medium
63126	70762	376	Пензенская область, Бессоновский район, село Грабово, Лесная, 31	f	medium
63123	70759	373	Пензенская область, Бессоновский район, село Грабово, Западная Поляна, 10	f	medium
63120	70756	370	Пензенская область, Бессоновский район, село Вазерки, Новая, 6 Б	f	large
63121	70757	371	Пензенская область, Бессоновский район, село Вазерки, Ера, 147	t	small
63133	70769	383	Пензенская область, Бессоновский район, село Блохино, Молодежная, 1 А	f	medium
63116	70752	366	Пензенская область, Бессоновский район, село Бессоновка, Центральная, 245	f	large
63113	70749	363	Пензенская область, Бессоновский район, село Бессоновка, Сурская, 119 Б	f	large
63119	70755	369	Пензенская область, Бессоновский район, село Бессоновка, Садовая, 10	f	medium
63118	70754	368	Пензенская область, Бессоновский район, село Бессоновка, Садовая, 67	f	large
63115	70751	365	Пензенская область, Бессоновский район, село Бессоновка, Комсомольская, 1 Б/2	f	large
63117	70753	367	Пензенская область, Бессоновский район, село Бессоновка, Кирова, 20 А	f	large
63114	70750	364	Пензенская область, Бессоновский район, село Бессоновка, Жилгородок, 12 А	f	large
63100	70737	350	Пензенская область, Белинский район, село Языково, Центральная, 3	t	small
63110	70746	360	Пензенская область, Белинский район, село Ширяево, Центральная, 7	f	medium
63104	70740	354	Пензенская область, Белинский район, село Шарова, Центральная, 18	f	medium
68447	71037	658	Пензенская область, Белинский район, село Ульяновка, Ленинская, 86, МБОУ ООШ с.Ульяновка	f	large
63085	70723	335	Пензенская область, Белинский район, село Сяськино, Библиотечная, 14А	f	small
63087	70725	337	Пензенская область, Белинский район, село Сулак, Садовая, 1	f	small
63108	70744	358	Пензенская область, Белинский район, село Студенка, Центральная, 106	f	medium
63663	71305	927	Пензенская область, Белинский район, село Студенка, Октябрьская, 27-а	t	small
63082	70720	332	Пензенская область, Белинский район, село Среднеречье, Поселковая, 17	t	small
63109	70745	359	Пензенская область, Белинский район, село Сентяпино, Нагорная, 4	t	small
63083	70721	333	Пензенская область, Белинский район, село Свищевка, Школьная, 1А	f	medium
63093	70730	343	Пензенская область, Белинский район, село Пяркино, Сокоровка, 1	t	small
63106	70742	356	Пензенская область, Белинский район, село Пушанино, Пригородная, 158	f	large
63103	70739	353	Пензенская область, Белинский район, село Поим, Московская, 5	f	medium
63102	70739	352	Пензенская область, Белинский район, село Поим, Московская, 5	f	large
63101	70738	351	Пензенская область, Белинский район, село Невежкино, Сельская, 34	f	medium
63148	70785	398	Пензенская область, Белинский район, село Лопатино, Садовая, 39	f	small
63425	71054	676	Пензенская область, Белинский район, село Лопатино, Пионерская, 18	f	large
63423	71053	674	Пензенская область, Белинский район, село Лопатино, Пионерская, 27	f	large
63096	70733	346	Пензенская область, Белинский район, село Лермонтово, Центральная, 14	f	large
63095	70732	345	Пензенская область, Белинский район, село Кутеевка, Молодежная, 3	f	medium
63107	70743	357	Пензенская область, Белинский район, село Кукарки, Центральная, 84	f	medium
63099	70736	349	Пензенская область, Белинский район, село Крюково, Центральная, 1	f	small
63092	70729	342	Пензенская область, Белинский район, село Корсаевка, Мостовая, 1	f	medium
63090	70728	340	Пензенская область, Белинский район, село Козловка, Дружная, 15	f	medium
63091	70728	341	Пензенская область, Белинский район, село Козловка, Дружная, 15	f	small
112593	70797	414	Пензенская область, Белинский район, село Ключи, Пролетарка, 14	f	small
63161	70796	413	Пензенская область, Белинский район, село Ключи, Пролетарка, 18	f	small
63086	70724	336	Пензенская область, Белинский район, село Кевдо-Вершина, Даманская, 9	f	small
63088	70726	338	Пензенская область, Белинский район, село Камынино, Мира, 3	f	medium
63097	70734	347	Пензенская область, Белинский район, село Калдуссы, Школьная, 13	f	small
63084	70722	334	Пензенская область, Белинский район, село Волчково, Взлётная, 5	f	medium
63089	70727	339	Пензенская область, Белинский район, село Верхние Поляны, Молодёжная, 3	f	medium
63078	70716	328	Пензенская область, Белинский район, Белинский, Ленина, 47	f	large
63079	70717	329	Пензенская область, Белинский район, Белинский, Белинская, 14	f	large
63081	70719	331	Пензенская область, Белинский район, село Балкашино, Центральная, 2	f	small
63072	70710	322	Пензенская область, Бековский район, н.п. Первое отделение, 1	t	small
63067	70705	317	Пензенская область, Бековский район, село Яковлевка, Центральная, 1а	f	small
63073	70711	323	Пензенская область, Бековский район, село Сосновка, Центральная усадьба, 6	f	small
63075	70713	325	Пензенская область, Бековский район, село Сосновка, Комсомольская, 1	f	small
63074	70712	324	Пензенская область, Бековский район, село Сосновка, Почтовая, 133	f	small
63077	70715	327	Пензенская область, Бековский район, село Сахзавод, Огородная, 25	f	large
112658	71495	1117	Пензенская область, Бековский район, село Санниковка, Молодежная, 1	f	small
63066	70704	316	Пензенская область, Бековский район, село Покровка, Садовая, 19	f	medium
63060	70697	309	Пензенская область, Бековский район, село Плодосовхоз, Спортивная, 2	f	medium
63065	70703	315	Пензенская область, Бековский район, село Никольское, Красная, 6а	t	small
112590	70701	313	Пензенская область, Бековский район, село Мошки, Садовая, 26	f	small
63063	70700	312	Пензенская область, Бековский район, село Мошки, Садовая, 24	f	medium
63070	70708	320	Пензенская область, Бековский район, село Миткирей, Школьная, 62	f	small
63068	70706	318	Пензенская область, Бековский район, село Мача-Родники, Почтовая, 16	f	small
63350	70978	601	Пензенская область, Бековский район, село Крутец, Школьная, 11	f	medium
63064	70702	314	Пензенская область, Бековский район, село Ивановка, Центральная, 4	f	small
63071	70709	321	Пензенская область, Бековский район, село Затолокино, Школьная, 1а	f	small
63062	70699	311	Пензенская область, Бековский район, село Волынщино, Шоссейная, 17	f	small
63076	70714	326	Пензенская область, Бековский район, село Вертуновка, Школьная, 115	f	large
63056	70693	305	Пензенская область, Бековский район, поселок Беково, Подбеково, 2б	f	medium
63059	70696	308	Пензенская область, Бековский район, поселок Беково, Первомайская, 56	f	large
63058	70695	307	Пензенская область, Бековский район, поселок Беково, Базарная, 1	f	large
63057	70694	306	Пензенская область, Бековский район, поселок Беково, 2-я Октябрьская, 11	f	medium
63069	70707	319	Пензенская область, Бековский район, село Александровка, Молодежная, 3а	t	small
63821	71464	1086	Пензенская область, Беднодемьяновский район, село Цепаево, Цепаево, 35	f	small
63830	71473	1095	Пензенская область, Беднодемьяновский район, село Устье, Школьная, 24	f	small
63834	71477	1099	Пензенская область, Беднодемьяновский район, Спасск, Совхозная, 45	f	small
63833	71476	1098	Пензенская область, Беднодемьяновский район, Спасск, Советская площадь, 34	f	large
63836	71479	1101	Пензенская область, Беднодемьяновский район, Спасск, Ленина, 114	f	medium
63832	71475	1097	Пензенская область, Беднодемьяновский район, Спасск, Красная, 17	f	large
63835	71478	1100	Пензенская область, Беднодемьяновский район, Спасск, Коммунальная, 66	f	small
63831	71474	1096	Пензенская область, Беднодемьяновский район, Спасск, Коммунальная, 2	f	large
112652	71471	1093	Пензенская область, Беднодемьяновский район, село Русский Шелдаис, Садовая, 13	f	small
63829	71472	1094	Пензенская область, Беднодемьяновский район, село Русский Пимбур, Калинина, 1	f	small
63826	71469	1091	Пензенская область, Беднодемьяновский район, село Рузаново, Совхозная, 26	f	small
63814	71457	1079	Пензенская область, Беднодемьяновский район, село Липлейка, Школьная, 10	f	small
63813	71456	1078	Пензенская область, Беднодемьяновский район, село Липлейка, Центральная, 4А	f	small
63820	71463	1085	Пензенская область, Беднодемьяновский район, село Красный Восток, Красный Восток, 1Б	f	small
63824	71467	1089	Пензенская область, Беднодемьяновский район, село Кошелевка, Рабочая, 2А	f	small
63823	71466	1088	Пензенская область, Беднодемьяновский район, село Зубово, Сельская, 23	f	small
63822	71465	1087	Пензенская область, Беднодемьяновский район, село Зубово, Новая, 1	f	small
112607	70959	579	Пензенская область, Беднодемьяновский район, село Дубровки, Молодежная, 12	f	small
63815	71458	1080	Пензенская область, Беднодемьяновский район, село Дерябкино, Московская, 47А	f	small
63816	71459	1081	Пензенская область, Беднодемьяновский район, село Веденяпино, Школьная, 1	f	small
63827	71470	1092	Пензенская область, Беднодемьяновский район, село Баранчеевка, Новая, 1	t	small
63817	71460	1082	Пензенская область, Беднодемьяновский район, село Ахлебинино, Центральная, 6	t	small
63812	71455	1077	Пензенская область, Беднодемьяновский район, село Абашево, Центральная, 2Д	f	small
63052	70689	301	Пензенская область, Башмаковский район, село Шереметьево, Школьная, 1	f	small
63036	70424	285	Пензенская область, Башмаковский район, село Чудная, Запрудная, 1А	t	small
63678	71321	943	Пензенская область, Башмаковский район, село Троицкое, Школьная, 6	t	small
63050	70687	299	Пензенская область, Башмаковский район, село Тимирязево, Советская, 1	f	large
63040	70677	289	Пензенская область, Башмаковский район, село Спиртозавод, 1-ая Заводская, 18	f	small
63048	70685	297	Пензенская область, Башмаковский район, село Соседка, Красноармейская, 7А	f	large
63047	70684	296	Пензенская область, Башмаковский район, село Соломинка, Молодежная, 12	f	small
63045	70682	294	Пензенская область, Башмаковский район, село Подгорное, Школьная, 8	f	small
63038	57805	287	Пензенская область, Башмаковский район, село Петровское, Красная, 2	t	small
63051	70688	300	Пензенская область, Башмаковский район, село Новознаменский, Центральная, 33	f	small
63034	70646	283	Пензенская область, Башмаковский район, село Никульевка, Ясная, 11	f	medium
63053	70690	302	Пензенская область, Башмаковский район, село Митрофаново, Центральная, 5	f	medium
63046	70683	295	Пензенская область, Башмаковский район, село Марат, Мира, 7А	f	small
63438	71067	689	Пензенская область, Башмаковский район, село Липовка, Садовая, 114	f	small
63043	70680	292	Пензенская область, Башмаковский район, село Кирилловка, Центральная, 35	f	small
63042	70679	291	Пензенская область, Башмаковский район, село Кандиевка, Школьная, 7	f	small
63041	70678	290	Пензенская область, Башмаковский район, село Знаменское, Совхозная, 8	f	medium
63039	58020	288	Пензенская область, Башмаковский район, село Дружный, Новая, 24	f	small
63055	70692	304	Пензенская область, Башмаковский район, село Глебовка, Школьная, 6А	f	small
63037	70516	286	Пензенская область, Башмаковский район, село Высокое, Школьная, 1	f	small
63027	70671	276	Пензенская область, Башмаковский район, поселок Башмаково, Строителей, 20	f	large
63031	70675	280	Пензенская область, Башмаковский район, поселок Башмаково, Советская, 17А	f	large
63028	70672	277	Пензенская область, Башмаковский район, поселок Башмаково, Лермонтова, 4	f	large
63026	70670	275	Пензенская область, Башмаковский район, поселок Башмаково, Ленинская, 25	f	medium
63032	70676	281	Пензенская область, Башмаковский район, поселок Башмаково, Калинина, 5	f	large
63029	70673	278	Пензенская область, Башмаковский район, поселок Башмаково, Губкина, 44А	f	large
63030	70674	279	Пензенская область, Башмаковский район, поселок Башмаково, Шайкова, 18	f	large
112645	71395	1015	Пензенская область, Белинский район, село Октябрьский, Школьная, 1	t	small
61171	68861	1018	Оренбургская область, пос. им Куйбышева, Школьная, 1	f	large
67766	69576	1808	Оренбургская область, Ясный, Свердлова, 10	f	large
61951	69577	1809	Оренбургская область, Ясный, Парковая, 21	f	large
61315	68979	1165	Оренбургская область, село Южный Урал, Буденного, 28А	f	large
61331	68995	1181	Оренбургская область, Черноречье, Степная, 32	f	large
60345	68090	179	Оренбургская область, село Чапаево, Молодежная, 10	f	small
61586	69219	1438	Оренбургская область, Чапаевкое, Центральная, 10	f	small
61404	69046	1254	Оренбургская область, село Тукай, Центральная, 25	f	small
60253	67998	77	Оренбургская область, Тере, Советская, 18	f	large
67800	68977	1163	Оренбургская область, хутор Степановский, Советская, 1	f	large
61765	69397	1621	Оренбургская область, Сорочинск, Карла Маркса, 89, Муниципальное автономное общеобразовательное учреждение СОШ № 2	f	large
61764	69397	1620	Оренбургская область, Сорочинск, Карла Маркса, 89, Муниципальное автономное общеобразовательное учреждение СОШ № 2	f	large
61763	69396	1619	Оренбургская область, Сорочинск городской округ, Карла Маркса, 185, Муниципальное автономное общеобразовательное учреждение СОШ №3	f	large
61762	69396	1618	Оренбургская область, Сорочинск городской округ, Карла Маркса, 185, Муниципальное автономное общеобразовательное учреждение СОШ №3	f	large
61980	69599	1839	Оренбургская область, Сорочинск, 2-микрорайон, 36А, Муниципальное бюджетное общеобразовательное учреждение СОШ № 4	f	large
61979	69599	1838	Оренбургская область, Сорочинск, 2-микрорайон, 36А, Муниципальное бюджетное общеобразовательное учреждение СОШ № 4	f	large
61728	69363	1583	Оренбургская область, Соль-Илецк, Шевченко, 1	f	large
61720	69355	1575	Оренбургская область, Соль-Илецк, Вокзальная, 88	f	large
61310	68974	1160	Оренбургская область, поселок Соловьевка, Центральная, 32А	f	medium
61146	68842	993	Оренбургская область, поселок Пруды, Школьная, 7А	f	small
61304	68968	1154	Оренбургская область, село Приютово, Липовая, 3/1	t	small
61330	68994	1180	Оренбургская область, поселок Пригородный, Школьная, 1	f	large
61329	68993	1179	Оренбургская область, поселок Пригородный, Советская, 4	f	large
61965	69586	1824	Оренбургская область, село Подгородняя Покровка, Кооперативная, 50	f	large
61311	68975	1161	Оренбургская область, село Подгородняя Покровка, Кооперативная, 46	f	large
61804	69434	1660	Оренбургская область, поселок Плодопитомник, Садовая, 1	f	small
61378	69029	1228	Оренбургская область, Орск, пр. Ленина, 81	f	large
61377	69028	1227	Оренбургская область, Орск, пр. Ленина, 51	f	large
61429	69068	1279	Оренбургская область, Орск, Яблочная, 6А	f	large
61421	69061	1271	Оренбургская область, Орск, Юлина, 12	f	large
61420	69061	1270	Оренбургская область, Орск, Юлина, 12	f	large
61351	69007	1201	Оренбургская область, Орск, Ю Фучика, 5	f	large
61350	69007	1200	Оренбургская область, Орск, Ю Фучика, 5	f	large
61349	69007	1199	Оренбургская область, Орск, Ю Фучика, 5	f	large
61431	69070	1281	Оренбургская область, Орск, Энтузиастов, 4	f	large
61406	69048	1256	Оренбургская область, Орск, Энгельса, 32	f	large
61412	69053	1262	Оренбургская область, Орск, Чкалова, 116	f	large
61423	69062	1273	Оренбургская область, Орск, Центральная, 35	f	large
61422	69062	1272	Оренбургская область, Орск, Центральная, 35	f	large
61381	69032	1231	Оренбургская область, Орск, Тагильская, 35	f	large
61425	69064	1275	Оренбургская область, Орск, Спортивная, 12	f	large
61389	69038	1239	Оренбургская область, Орск, Сорокина, 6	f	large
61388	69038	1238	Оренбургская область, Орск, Сорокина, 6	f	large
67802	69015	1210	Оренбургская область, Орск, Сормовская, 1	f	large
61408	69050	1258	Оренбургская область, Орск, Советская, 65/2	f	large
61407	69049	1257	Оренбургская область, Орск, Советская, 69	f	large
61440	69077	1290	Оренбургская область, Орск, Севастопольская, 40А	f	large
61439	69077	1289	Оренбургская область, Орск, Севастопольская, 40А	f	large
61438	69077	1288	Оренбургская область, Орск, Севастопольская, 40А	f	large
61369	69023	1219	Оренбургская область, Орск, Рыбалко, 9	f	large
61428	69067	1278	Оренбургская область, Орск, Просвещения, 40	f	large
61427	69066	1277	Оренбургская область, Орск, Просвещения, 46	f	large
61413	69054	1263	Оренбургская область, Орск, Подзорова, 79	f	large
61385	69035	1235	Оренбургская область, Орск, Орское шоссе, 4	f	large
61442	69079	1292	Оренбургская область, Орск, Орский проспект, 69	f	small
61430	69069	1280	Оренбургская область, Орск, Огородная, 28	f	large
61437	69076	1287	Оренбургская область, Орск, Новая биофабрика, 77	f	small
61436	69075	1286	Оренбургская область, Орск, Новая биофабрика, 80	f	large
61359	69014	1209	Оренбургская область, Орск, Никельщиков проспект, 54	f	large
61435	69074	1285	Оренбургская область, Орск, Молодогвардейская, 63	f	large
61341	69002	1191	Оренбургская область, Орск, Макаренко, 7	f	large
61371	69024	1221	Оренбургская область, Орск, Макаренко, 19	f	large
61370	69024	1220	Оренбургская область, Орск, Макаренко, 19	f	large
61411	69052	1261	Оренбургская область, Орск, Коммунистов-большевиков, 1	f	large
61410	69052	1260	Оренбургская область, Орск, Коммунистов-большевиков, 1	f	large
61394	69041	1244	Оренбургская область, Орск, Комарова, 36	f	large
61395	69041	1245	Оренбургская область, Орск, Комарова, 36	f	large
61414	69055	1264	Оренбургская область, Орск, Кирпичная, 134	f	medium
61409	69051	1259	Оренбургская область, Орск, Карла Маркса, 15	f	large
61415	69056	1265	Оренбургская область, Орск, Камчатская, 7	f	large
61990	69060	1852	Оренбургская область, Орск, Заводской переулок, 7	f	large
61419	69060	1269	Оренбургская область, Орск, Заводской переулок, 7	f	large
61386	69036	1236	Оренбургская область, Орск, Елшанская, 136	f	large
61398	69042	1248	Оренбургская область, Орск, Гомельская, 82	f	large
61397	69042	1247	Оренбургская область, Орск, Гомельская, 82	f	large
61355	69010	1205	Оренбургская область, Орск, Гагарина площадь, 1	f	large
61426	69065	1276	Оренбургская область, Орск, Вокзальное шоссе, 18	f	large
61424	69063	1274	Оренбургская область, Орск, Вокзальная, 28	f	large
67804	69043	1251	Оренбургская область, Орск, Верхняя, 15	f	medium
61416	69057	1266	Оренбургская область, Орск, Братская, 54	f	large
61432	69071	1282	Оренбургская область, Орск, Больничный переулок, 20	f	large
61402	69044	1252	Оренбургская область, Орск, Беляева, 6 Б	f	large
61400	69021	1250	Оренбургская область, Орск, Беляева, 8	f	large
61399	69021	1249	Оренбургская область, Орск, Беляева, 8	f	large
61367	69021	1217	Оренбургская область, Орск, Беляева, 8	f	large
61434	69073	1284	Оренбургская область, Орск, Байкальская, 13	f	large
61418	69059	1268	Оренбургская область, Орск, Андреева, 2	f	large
61417	69058	1267	Оренбургская область, Орск, Андреева, 5	f	large
61433	69072	1283	Оренбургская область, Орск, 1-й Домбаровский переулок, 11	f	large
61155	68851	1002	Оренбургская область, Оренбург, улица Юркина, 17	f	large
61206	68881	1053	Оренбургская область, Оренбург, улица Чкалова, 24/1	f	large
61205	68881	1052	Оренбургская область, Оренбург, улица Чкалова, 24/1	f	large
61284	68948	1134	Чукотский автономный округ, Билибинский район, поселок Весенний	f	large
60261	68007	85	Оренбургская область, Оренбург, улица Центральная, 4	t	small
61198	68877	1045	Оренбургская область, Оренбург, улица Туркестанская, 55/5	f	large
61197	68877	1044	Оренбургская область, Оренбург, улица Туркестанская, 55/5	f	large
61196	68877	1043	Оренбургская область, Оренбург, улица Туркестанская, 55/5	f	large
61250	68919	1098	Оренбургская область, Оренбург, улица Терешковой, 10	f	large
61075	68788	922	Оренбургская область, Оренбург, улица Терешковой, 269/1	f	large
61080	68793	927	Оренбургская область, Оренбург, улица Театральная, 7а	f	large
61259	68928	1107	Оренбургская область, Оренбург, улица Совхозная, 31	f	large
61099	68805	946	Оренбургская область, Оренбург, улица Салмышская, 3	f	large
61097	68805	944	Оренбургская область, Оренбург, улица Салмышская, 3	f	large
61098	68805	945	Оренбургская область, Оренбург, улица Салмышская, 3	f	large
61106	68811	953	Оренбургская область, Оренбург, улица Родимцева, 5	f	large
61953	69579	1811	Оренбургская область, Ясный городской округ, улица Октябрьская, 8	f	large
61454	69091	1304	Московская область, Ногинский район, Старая Купавна, Октябрьская улица, 20	t	small
61334	68997	1184	Оренбургская область, Оренбург, улица Нефтяников	f	large
61333	68997	1183	Оренбургская область, Оренбург, улица Нефтяников	f	large
61161	68855	1008	Оренбургская область, Оренбург, улица Народная, 16/2	f	large
61160	68855	1007	Оренбургская область, Оренбург, улица Народная, 16/2	f	large
61254	68924	1102	Оренбургская область, Оренбург, улица Мискинова, 35	f	large
61989	69604	1850	Оренбургская область, Светлинский район	f	small
61135	68832	982	Оренбургская область, Оренбург, улица Мебельная	f	large
61379	69030	1229	Оренбургская область, Оренбург, улица Кутузова	f	large
61767	69398	1623	Краснодарский край, Туапсе, улица Карла Маркса, 18	f	large
61766	69398	1622	Краснодарский край, Туапсе, улица Карла Маркса, 18	f	large
61761	69395	1617	Краснодарский край, Туапсе, улица Карла Маркса	f	large
61459	68922	1309	Оренбургская область, Оренбург, улица Каргалинская	f	medium
61163	68857	1010	Оренбургская область, Оренбург, улица Калининградская, 23	f	large
61970	69589	1829	республика Башкортостан, село Булгаково, улица Дружбы, 1	f	small
61121	68819	968	Оренбургская область, Оренбург, улица Джангильдина, 11	f	large
61120	68819	967	Оренбургская область, Оренбург, улица Джангильдина, 11	f	large
61119	68819	966	Оренбургская область, Оренбург, улица Джангильдина, 11	f	large
61117	68611	964	Оренбургская область, Оренбург, улица Джангильдина, 4	f	large
61116	68611	963	Оренбургская область, Оренбург, улица Джангильдина, 4	f	large
60870	68611	716	Оренбургская область, Оренбург, улица Джангильдина, 4	f	large
61118	68818	965	Оренбургская область, Оренбург, улица Брестская, 5	f	large
61157	68852	1004	Оренбургская область, Оренбург, улица Братьев Башиловых, 18	f	large
61156	68852	1003	Оренбургская область, Оренбург, улица Братьев Башиловых, 18	f	large
61348	69006	1198	Оренбургская область, Оренбург, улица Богдана Хмельницкого, 6	f	large
61347	69006	1197	Оренбургская область, Оренбург, улица Богдана Хмельницкого, 6	f	large
61108	68813	955	Оренбургская область, Оренбург, улица 70 Лет ВЛКСМ, 29	f	large
61380	69031	1230	Оренбургская область, Оренбург, Ялтинская, 81 А	f	large
61236	68907	1084	Оренбургская область, Оренбург, Яицкая, 19	f	large
61104	68809	951	Оренбургская область, Оренбург, Юных Ленинцев, 9	f	large
61103	68809	950	Оренбургская область, Оренбург, Юных Ленинцев, 9	f	large
61345	69005	1195	Оренбургская область, Оренбург, Юношеская, 3	f	large
61344	69005	1194	Оренбургская область, Оренбург, Юношеская, 3	f	large
61354	69009	1204	Оренбургская область, Оренбург, Школьная улица, 1	f	large
61353	69009	1203	Оренбургская область, Оренбург, Школьная улица, 1	f	large
61174	68864	1021	Оренбургская область, Оренбург, Школьная, 14	f	medium
61268	68934	1116	Оренбургская область, Оренбург, Шевченко, 233	f	large
61204	68880	1051	Оренбургская область, Оренбург, Чкалова, 1	f	large
61203	68880	1050	Оренбургская область, Оренбург, Чкалова, 1	f	large
61235	68906	1083	Оренбургская область, Оренбург, Чичерина, 1	f	large
61209	68884	1056	Оренбургская область, Оренбург, Челюскинцев, 18	f	large
61230	68901	1077	Оренбургская область, Оренбург, Центральная, 17	f	large
67692	68310	402	Оренбургская область, Оренбург, Центральная, 20	t	small
61144	68840	991	Оренбургская область, Оренбург, Химическая, 15	f	large
61141	68837	988	Оренбургская область, Оренбург, Химическая, 7	f	large
61140	68837	987	Оренбургская область, Оренбург, Химическая, 7	f	large
61248	68917	1096	Оренбургская область, Оренбург, Харьковская, 14	f	large
61247	68917	1095	Оренбургская область, Оренбург, Харьковская, 14	f	large
61262	68930	1110	Оренбургская область, Оренбург, Флотский переулок, 16	f	large
61261	68930	1109	Оренбургская область, Оренбург, Флотский переулок, 16	f	large
61948	69574	1806	Оренбургская область, Оренбург, Уральская, 1	f	large
61201	68879	1048	Оренбургская область, Оренбург, Уральская, 1	f	large
61202	68879	1049	Оренбургская область, Оренбург, Уральская, 1	f	large
61246	68916	1094	Оренбургская область, Оренбург, Туркестанская, 6	f	large
61245	68916	1093	Оренбургская область, Оренбург, Туркестанская, 6	f	large
61208	68883	1055	Оренбургская область, Оренбург, Туркестанская, 11а	f	large
61207	68883	1054	Оренбургская область, Оренбург, Туркестанская, 11а	f	large
61231	68902	1078	Оренбургская область, Оренбург, Транспортная, 12	f	large
61225	68897	1072	Оренбургская область, Оренбург, Тобольская, 59А	f	large
61224	68897	1071	Оренбургская область, Оренбург, Тобольская, 59А	f	large
61139	68836	986	Оренбургская область, Оренбург, Ткачева, 18	f	large
61138	68835	985	Оренбургская область, Оренбург, Ткачева, 8	f	large
61242	68913	1090	Оренбургская область, Оренбург, Терешковой, 8	f	large
61241	68912	1089	Оренбургская область, Оренбург, Терешковой, 33	f	large
61251	68920	1099	Оренбургская область, Оренбург, Сухарева, 50	f	large
61356	69011	1206	Оренбургская область, Оренбург, Строителей проспект, 14	f	large
61357	69012	1207	Оренбургская область, Оренбург, Строителей проспект, 20	f	large
61162	68856	1009	Оренбургская область, Оренбург, Станционная, 2а	f	large
61147	68843	994	Оренбургская область, Оренбург, Станционная, 2а	f	large
61346	69004	1196	Оренбургская область, Оренбург, Станиславского, 42б	f	large
61343	69004	1193	Оренбургская область, Оренбург, Станиславского, 42б	f	large
61342	69003	1192	Оренбургская область, Оренбург, Станиславского, 37	f	large
61215	68890	1062	Оренбургская область, Оренбург, Советская, 41	f	medium
61213	68888	1060	Оренбургская область, Оренбург, Советская, 24	f	large
61212	68887	1059	Оренбургская область, Оренбург, Советская, 48	f	large
61211	68886	1058	Оренбургская область, Оренбург, Советская, 7	f	large
61210	68885	1057	Оренбургская область, Оренбург, Советская, 6	f	large
61128	68826	975	Оренбургская область, Оренбург, Советская, 111	f	medium
61086	68796	933	Оренбургская область, Оренбург, Сергея Лазо, 8/2	f	large
61085	68796	932	Оренбургская область, Оренбург, Сергея Лазо, 8/2	f	large
61084	68795	931	Оренбургская область, Оренбург, Сергея Лазо, 7	f	large
61083	68794	930	Оренбургская область, Оренбург, Сергея Лазо, 9	f	large
61082	68794	929	Оренбургская область, Оренбург, Сергея Лазо, 9	f	large
61081	68794	928	Оренбургская область, Оренбург, Сергея Лазо, 9	f	large
61258	68927	1106	Оренбургская область, Оренбург, Самолетная, 91	f	large
61257	68927	1105	Оренбургская область, Оренбург, Самолетная, 91	f	large
132286	69603	1848	Оренбургская область, Оренбург, Салмышская, 58, ТК Квартал	f	\N
61175	68865	1022	Оренбургская область, Оренбург, Салмышская, 46/1	f	large
61100	68807	947	Оренбургская область, Оренбург, Салмышская, 11	f	large
61096	68804	943	Оренбургская область, Оренбург, Салмышская, 4к1	f	large
61243	68914	1091	Оренбургская область, Оренбург, Рыбаковская, 59	f	large
61115	68817	962	Оренбургская область, Оренбург, Просторная, 14/2	f	large
61114	68817	961	Оренбургская область, Оренбург, Просторная, 14/2	f	large
61113	68816	960	Оренбургская область, Оренбург, Просторная, 14/2	f	large
61112	68816	959	Оренбургская область, Оренбург, Просторная, 14/2	f	large
61111	68815	958	Оренбургская область, Оренбург, Просторная, 4	f	large
61110	68815	957	Оренбургская область, Оренбург, Просторная, 4	f	large
61078	68791	925	Оренбургская область, Оренбург, Просвещения, 4	f	large
61073	68785	920	Оренбургская область, Оренбург, Промышленная, 9	f	large
61072	68785	919	Оренбургская область, Оренбург, Промышленная, 9	f	large
61184	68870	1031	Оренбургская область, Оренбург, Промысловый проезд, 11	f	large
61183	68870	1030	Оренбургская область, Оренбург, Промысловый проезд, 11	f	large
61129	68827	976	Оренбургская область, Оренбург, Пролетарская, 99	f	medium
67770	69598	1900	Калужская область, Калуга, площадь Привокзальная, 1к1	f	\N
60254	67999	78	Оренбургская область, Адамовский район, Привокзальная площадь, 1	f	medium
61260	68929	1108	Оренбургская область, Оренбург, Победы проспект, 75	f	large
61255	68925	1103	Оренбургская область, Оренбург, Победы проспект, 118	f	large
61249	68918	1097	Оренбургская область, Оренбург, Победы проспект, 13	f	large
61074	68787	921	Оренбургская область, Оренбург, Победы проспект, 166/1	f	large
61768	69399	1624	Оренбургская область, Оренбург, Пионерская, 1, Муниципальное бюджетное общеобразовательное учреждение СОШ № 1	f	large
61199	68878	1046	Оренбургская область, Оренбург, Пикетная, 63	f	large
61200	68878	1047	Оренбургская область, Оренбург, Пикетная, 63	f	large
61240	68910	1088	Оренбургская область, Оренбург, Парковый проспект, 7	f	large
61126	68824	973	Оренбургская область, Оренбург, Парковый проспект, 40	f	large
61125	68823	972	Оренбургская область, Оренбург, Парковый проспект, 15	f	large
61253	68923	1101	Оренбургская область, Оренбург, Орджоникидзе, 226	f	large
61252	68921	1100	Оренбургская область, Оренбург, Орджоникидзе, 197	f	large
61363	69017	1213	Оренбургская область, Оренбург, Онежская, 36	f	large
61365	69019	1215	Оренбургская область, Оренбург, Омская, 69 А	f	large
61393	69019	1243	Оренбургская область, Оренбург, Омская, 69 А	f	large
61636	69269	1488	Оренбургская область, Оренбург, Октябрьская, 1	f	small
61267	68933	1115	Оренбургская область, Оренбург, Одесская, 148	f	large
61168	68859	1015	Оренбургская область, Оренбург, Ноябрьская, 41	f	large
61167	68859	1014	Оренбургская область, Оренбург, Ноябрьская, 41	f	large
61166	68859	1013	Оренбургская область, Оренбург, Ноябрьская, 41	f	large
61165	68858	1012	Оренбургская область, Оренбург, Ноябрьская, 45	f	large
61164	68858	1011	Оренбургская область, Оренбург, Ноябрьская, 45	f	large
61136	68833	983	Оренбургская область, Оренбург, Ногина, 6	f	large
61134	68831	981	Оренбургская область, Оренбург, Ногина, 46	f	large
61170	68860	1017	Оренбургская область, Оренбург, Новая, 21	f	large
61169	68860	1016	Оренбургская область, Оренбург, Новая, 21	f	large
61976	69595	1835	Оренбургская область, Оренбург, Нефтянников, 18, Специальная общеобразовательная школа-интернат	f	large
61127	68825	974	Оренбургская область, Оренбург, Невельская, 2	f	large
61967	68894	1826	Оренбургская область, Оренбург, Нахимова, 33	f	large
61220	68894	1067	Оренбургская область, Оренбург, Нахимова, 33	f	large
61309	68973	1159	Оренбургская область, Оренбург, Набережная, 15	f	medium
61071	68784	918	Оренбургская область, Оренбург, Монтажников, 14	f	large
61070	68784	917	Оренбургская область, Оренбург, Монтажников, 14	f	large
61069	68784	916	Оренбургская область, Оренбург, Монтажников, 14	f	large
67796	68936	1118	Оренбургская область, Оренбург, Молодежная, 17, МОУ «СОШ № 37»	f	large
61352	69008	1202	Оренбургская область, Оренбург, Мира проспект, 15а	f	large
61338	69000	1188	Оренбургская область, Оренбург, Мира проспект, 16	f	large
61186	68786	1033	Оренбургская область, Оренбург, Мира, 22	f	large
61159	68854	1006	Оренбургская область, Оренбург, Минская, 1	f	large
61158	68854	1005	Оренбургская область, Оренбург, Минская, 1	f	large
61219	68893	1066	Оренбургская область, Оренбург, Механизаторов, 11	f	large
61373	69025	1223	Оренбургская область, Оренбург, Медногорская, 36	f	large
61372	69025	1222	Оренбургская область, Оренбург, Медногорская, 36	f	large
61143	68839	990	Оренбургская область, Оренбург, Манежная, 9	f	large
61229	68900	1076	Оренбургская область, Оренбург, Мало-Восточная, 1а	f	small
61390	69039	1240	Оренбургская область, Оренбург, Максима Горького, 153 А	f	large
61193	68875	1040	Оренбургская область, Оренбург, Майский проезд, 8	f	large
61194	68875	1041	Оренбургская область, Оренбург, Майский проезд, 8	f	large
61153	68849	1000	Оренбургская область, Оренбург, Магнитогорская, 80	f	large
61150	68846	997	Оренбургская область, Оренбург, Львовская, 13	f	large
61266	68932	1114	Оренбургская область, Оренбург, Луговая, 85	f	large
61265	68932	1113	Оренбургская область, Оренбург, Луговая, 85	f	large
61238	68909	1086	Оренбургская область, Оренбург, Луганская, 5	f	small
61340	69001	1190	Оренбургская область, Оренбург, Ленинского Комсомола, 16	f	large
61339	69001	1189	Оренбургская область, Оренбург, Ленинского Комсомола, 16	f	large
61337	68999	1187	Оренбургская область, Оренбург, Ленина проспект, 32	f	large
61336	68999	1186	Оренбургская область, Оренбург, Ленина проспект, 32	f	large
61332	68996	1182	Оренбургская область, Оренбург, Ленина проспект, 84	f	large
60818	68560	659	Оренбургская область, Курманаевский район, Ленина площадь, 1	f	large
61239	68908	1087	Оренбургская область, Оренбург, Курача, 24	f	large
61237	68908	1085	Оренбургская область, Оренбург, Курача, 24	f	large
61137	68834	984	Оренбургская область, Оренбург, Красина, 43а	f	large
61335	68998	1185	Оренбургская область, Оренбург, Короленко, 16	f	large
61088	68799	935	Оренбургская область, Оренбург, Конституции, 23	f	large
61362	69016	1212	Оренбургская область, Оренбург, Коларова, 1	f	large
61361	69016	1211	Оренбургская область, Оренбург, Коларова, 1	f	large
61216	68891	1063	Оренбургская область, Оренбург, Кобозева, 43	f	large
61218	68892	1065	Оренбургская область, Оренбург, Кирова, 6	f	large
61217	68892	1064	Оренбургская область, Оренбург, Кирова, 6	f	large
61256	68926	1104	Оренбургская область, Оренбург, Квартальный переулок, 2	f	large
61222	68895	1069	Оренбургская область, Оренбург, Карачинская, 50	f	large
61221	68895	1068	Оренбургская область, Оренбург, Карачинская, 50	f	large
61192	68874	1039	Оренбургская область, Оренбург, Знаменский проезд, 4	f	large
61191	68874	1038	Оренбургская область, Оренбург, Знаменский проезд, 4	f	large
61154	68850	1001	Оренбургская область, Оренбург, Зиновьева, 2	f	medium
67795	68789	923	Оренбургская область, Оренбург, Заводская, 30	f	large
61172	68862	1019	Оренбургская область, Оренбург, Журевского, 15	f	large
61770	69400	1626	Оренбургская область, Оренбург, Железнодорожная, Муниципальное бюджетное общеобразовательное учреждение СОШ № 117	f	large
61769	69400	1625	Оренбургская область, Оренбург, Железнодорожная, Муниципальное бюджетное общеобразовательное учреждение СОШ № 117	f	large
61107	68812	954	Оренбургская область, Оренбург, Дружбы, 7к2	f	large
61232	68903	1079	Оренбургская область, Оренбург, Диагностики, 9	f	large
61091	68801	938	Оренбургская область, Оренбург, Дзержинского проспект, 26	f	large
61092	68801	939	Оренбургская область, Оренбург, Дзержинского проспект, 26	f	large
61087	68798	934	Оренбургская область, Оренбург, Дзержинского проспект, 10	f	large
61077	68790	924	Оренбургская область, Оренбург, Гастелло, 19	f	large
61195	68876	1042	Оренбургская область, Оренбург, Гагарина проспект, 1	f	large
61190	68873	1037	Оренбургская область, Оренбург, Гагарина проспект, 15	f	large
61189	68872	1036	Оренбургская область, Оренбург, Гагарина проспект, 13	f	large
61180	68868	1027	Оренбургская область, Оренбург, Гагарина проспект, 25	f	large
61179	68868	1026	Оренбургская область, Оренбург, Гагарина проспект, 25	f	large
61178	68867	1025	Оренбургская область, Оренбург, Гагарина проспект, 27/1	f	large
61177	68866	1024	Оренбургская область, Оренбург, Гагарина проспект, 45	f	large
61176	68866	1023	Оренбургская область, Оренбург, Гагарина проспект, 45	f	large
61182	68869	1029	Оренбургская область, Оренбург, Гагарина проспект, 44/4	f	large
61181	68869	1028	Оренбургская область, Оренбург, Гагарина проспект, 44/4	f	large
61094	68802	941	Оренбургская область, Оренбург, Всесоюзная, 10/1	f	large
61093	68802	940	Оренбургская область, Оренбург, Всесоюзная, 10/1	f	large
61264	68931	1112	Оренбургская область, Оренбург, Восточная, 82а	f	large
61263	68931	1111	Оренбургская область, Оренбург, Восточная, 82а	f	large
61188	68853	1035	Оренбургская область, Оренбург, Восточная, 15	f	large
61095	68803	942	Оренбургская область, Оренбург, Волгоградская, 1	f	large
61214	68889	1061	Оренбургская область, Оренбург, Вечерняя, 6	f	large
61223	68896	1070	Оренбургская область, Оренбург, Весенняя, 18	f	large
61105	68810	952	Оренбургская область, Оренбург, Брестская, 3	f	large
61151	68847	998	Оренбургская область, Оренбург, Братьев Коростелевых проезд, 28/1	f	large
61149	68845	996	Оренбургская область, Оренбург, Братьев Коростелевых проезд, 54	f	large
61148	68844	995	Оренбургская область, Оренбург, Братьев Коростелевых проезд, 141	f	large
61132	68829	979	Оренбургская область, Оренбург, Братьев Коростелевых проезд, 26/1	f	large
61090	68800	937	Оренбургская область, Оренбург, Братская, 8/1	f	large
61089	68800	936	Оренбургская область, Оренбург, Братская, 8/1	f	large
61173	68863	1020	Оренбургская область, Оренбург, Березовая Ростошь, 2А	f	large
61227	68898	1074	Оренбургская область, Оренбург, Беляевская, 57/1	f	large
61226	68898	1073	Оренбургская область, Оренбург, Беляевская, 57/1	f	large
61152	68848	999	Оренбургская область, Оренбург, Бебеля, 118	f	large
61131	68828	978	Оренбургская область, Оренбург, Астраханская, 1а	f	large
61130	68828	977	Оренбургская область, Оренбург, Астраханская, 1а	f	large
61244	68915	1092	Оренбургская область, Оренбург, Аксакова, 3	f	large
61187	68797	1034	Оренбургская область, Оренбург, 75-я линия, 2	f	large
61109	68814	956	Оренбургская область, Оренбург, 70 Лет ВЛКСМ, 12	f	large
61185	68871	1032	Оренбургская область, Оренбург, 10-я линия, 22	f	large
61102	68808	949	Оренбургская область, Оренбург, Юных Ленинцев, 10	f	large
61101	68808	948	Оренбургская область, Оренбург, Юных Ленинцев, 10	f	large
61957	69581	1816	Оренбургская область, Оренбург, Южная, 20а	f	large
61956	69581	1815	Оренбургская область, Оренбург, Южная, 20а	f	large
61955	69581	1814	Оренбургская область, Оренбург, Южная, 20а	f	large
61142	68838	989	Оренбургская область, Оренбург, Химическая, 10	f	large
61269	68935	1117	Оренбургская область, Оренбург, Томилинская, 242	f	large
61466	69099	1316	Оренбургская область, Оренбург, Ленинградская, 20	t	small
61133	68830	980	Оренбургская область, Оренбург, Культурная, 21	f	large
61978	69597	1837	Оренбургская область, Оренбург, Ворошилова, 22, ФОК - Физкультурно оздоровительный комплекс Дружба	f	large
61977	69596	1836	Оренбургская область, Оренбург, Ворошилова, 18, Центр культуры и досуга Дружба	f	large
61014	68734	861	Оренбургская область, Новотроицк, Черемных, 3 А	f	large
60982	68717	829	Оренбургская область, Новотроицк, Фрунзе, 18	f	large
60981	68716	828	Оренбургская область, Новотроицк, Фрунзе, 8	f	large
61030	68729	877	Оренбургская область, Новотроицк, Уральская, 44	f	large
61009	68729	856	Оренбургская область, Новотроицк, Уральская, 44	f	large
61007	68729	854	Оренбургская область, Новотроицк, Уральская, 44	f	large
61018	68737	865	Оренбургская область, Новотроицк, Уметбаева, 19	f	large
61017	68736	864	Оренбургская область, Новотроицк, Уметбаева, 1	f	large
61016	68736	863	Оренбургская область, Новотроицк, Уметбаева, 1	f	large
60979	68714	826	Оренбургская область, Новотроицк, Советская, 38 А	f	large
61019	68738	866	Оренбургская область, Новотроицк, Северная, 11	f	large
61020	68739	867	Оренбургская область, Новотроицк, Рудницкого, 46	f	large
60986	68720	833	Оренбургская область, Новотроицк, Пушкина, 50	f	large
60985	68720	832	Оренбургская область, Новотроицк, Пушкина, 50	f	large
61013	68733	860	Оренбургская область, Новотроицк, Орская, 4	f	large
61010	68731	857	Оренбургская область, Новотроицк, Орская, 9	f	large
61012	68732	859	Оренбургская область, Новотроицк, Мира, 14	f	large
61011	68732	858	Оренбургская область, Новотроицк, Мира, 14	f	large
61029	68728	876	Оренбургская область, Новотроицк, Металлургов, 23	f	large
61006	68728	853	Оренбургская область, Новотроицк, Металлургов, 23	f	large
61005	68728	852	Оренбургская область, Новотроицк, Металлургов, 23	f	large
61002	68726	849	Оренбургская область, Новотроицк, Металлургов, 9	f	large
61000	68726	847	Оренбургская область, Новотроицк, Металлургов, 9	f	large
61001	68726	848	Оренбургская область, Новотроицк, Металлургов, 9	f	large
61027	68746	874	Оренбургская область, Новотроицк, Марии Корецкой, 37	f	large
60990	68722	837	Оренбургская область, Новотроицк, М.Корецкой, 37	f	large
60989	68722	836	Оренбургская область, Новотроицк, М.Корецкой, 37	f	large
61004	68727	851	Оренбургская область, Новотроицк, Комсомольский, 10	f	large
61003	68727	850	Оренбургская область, Новотроицк, Комсомольский, 10	f	large
60999	68725	846	Оренбургская область, Новотроицк, Зеленая, 71 А	f	large
60998	68725	845	Оренбургская область, Новотроицк, Зеленая, 71 А	f	large
60997	68725	844	Оренбургская область, Новотроицк, Зеленая, 71 А	f	large
60980	68715	827	Оренбургская область, Новотроицк, Горького, 34	f	large
61015	68735	862	Оренбургская область, Новотроицк, Гвардеец труда, 1	f	medium
61028	68724	875	Оренбургская область, Новотроицк, Гагарина, 7 А	f	large
60996	68724	843	Оренбургская область, Новотроицк, Гагарина, 7 А	f	large
60995	68724	842	Оренбургская область, Новотроицк, Гагарина, 7 А	f	large
60994	68724	841	Оренбургская область, Новотроицк, Гагарина, 7 А	f	large
61008	68730	855	Оренбургская область, Новотроицк, Воинов-Интернационалистов, 5	f	large
60988	68721	835	Оренбургская область, Новотроицк, Советская, 80	f	large
60987	68721	834	Оренбургская область, Новотроицк, Советская, 80	f	large
60984	68719	831	Оренбургская область, Новотроицк, Советская, 64	f	large
60983	68719	830	Оренбургская область, Новотроицк, Советская, 64	f	large
60978	68713	825	Оренбургская область, Новотроицк, Советская, 18	f	medium
60977	68712	824	Оренбургская область, Новотроицк, Советская, 10	f	medium
60993	68723	840	Оренбургская область, Новотроицк, Зеленая, 47 А	f	large
60991	68723	838	Оренбургская область, Новотроицк, Зеленая, 47 А	f	large
60992	68723	839	Оренбургская область, Новотроицк, Зеленая, 47 А	f	large
61665	69299	1519	Оренбургская область, Нижнее Челяево, Центральная, 41б	f	small
60879	68619	725	Оренбургская область, Медногорск, переулок Коммунальный, 5	f	large
67782	68629	740	Оренбургская область, Медногорск, Тульская, 17	f	large
67781	68629	739	Оренбургская область, Медногорск, Тульская, 17	f	large
60883	68622	729	Оренбургская область, Медногорск, Советская, 33	f	large
60882	68622	728	Оренбургская область, Медногорск, Советская, 33	f	large
60881	68621	727	Оренбургская область, Медногорск, Советская, 23	f	large
60895	68630	741	Оренбургская область, Медногорск, Моторная, 52	f	medium
60880	68620	726	Оренбургская область, Медногорск, Молодежная, 5	f	medium
60878	68618	724	Оренбургская область, Медногорск, Мало-Садовая, 1А	f	medium
60890	68626	736	Оренбургская область, Медногорск, Лесная, 34	f	medium
60887	68624	733	Оренбургская область, Медногорск, Комсомольская, 22	f	large
60886	68624	732	Оренбургская область, Медногорск, Комсомольская, 22	f	large
60891	68627	737	Оренбургская область, Медногорск, Коминтерна, 50А	f	medium
60889	68625	735	Оренбургская область, Медногорск, Ключевая, 40	f	medium
60888	68625	734	Оренбургская область, Медногорск, Ключевая, 40	f	medium
60877	68617	723	Оренбургская область, Медногорск, Гагарина проспект, 1	f	large
60876	68617	722	Оренбургская область, Медногорск, Гагарина проспект, 1	f	large
60885	68623	731	Оренбургская область, Медногорск,  Советская, 37	f	medium
60884	68623	730	Оренбургская область, Медногорск,  Советская, 37	f	large
61314	68978	1164	Оренбургская область, поселок Ленина, Ленинская, 31	f	large
60814	68556	655	Оренбургская область, Кувандык, пр. Мира, 24а	f	large
60815	68557	656	Оренбургская область, Кувандык, Школьная, 5	f	large
60812	68554	653	Оренбургская область, Кувандык, Фестивальная, 9	f	large
60756	68497	594	Оренбургская область, Кувандык, Фестивальная, 9	f	medium
60813	68555	654	Оренбургская область, Кувандык, Строителей, 9а	f	large
60755	68496	593	Оренбургская область, Кувандык, Строителей, 9а, ДК Криолит	f	medium
60808	68550	649	Оренбургская область, Кувандык, Северная, 2а	f	large
60811	68553	652	Оренбургская область, Кувандык, Сакмарская, 1а	f	medium
60816	68558	657	Оренбургская область, Кувандык, С.Юлаева, 58	f	medium
60807	68549	648	Оренбургская область, Кувандык, Речная, 15	f	medium
60803	68544	644	Оренбургская область, Кувандык, Оренбургская, 20	f	large
60810	68552	651	Оренбургская область, Кувандык, Молодёжная, 11	f	large
60805	68546	646	Оренбургская область, Кувандык, М. Жукова, 19а	f	large
60804	68545	645	Оренбургская область, Кувандык, М. Жукова, 19а, гимназия №1	f	large
61966	69587	1825	Оренбургская область, Кувандык, 20 лет Октября, 4а	f	small
60806	68547	647	Оренбургская область, Кувандык, 20 лет Октября, 4а	f	large
60809	68551	650	Оренбургская область, Кувандык, Молодёжная, 11	f	large
61327	68991	1177	Оренбургская область, село Девятого Января, Центральная, 2	f	large
67696	68330	424	Оренбургская область, Гай, пр.Победы, 17	f	large
67767	68330	1818	Оренбургская область, Гай, пр.Победы, 17	f	large
60589	68331	425	Оренбургская область, Гай, пер.Парковый, 3	f	large
61982	68324	1841	Оренбургская область, Гай, Школьный переулок, 4	f	large
60581	68324	417	Оренбургская область, Гай, Школьный переулок, 4	f	large
60584	68327	420	Оренбургская область, Гай, Советская, 14 А	f	large
67768	69600	1843	Оренбургская область, Гай, Парковый переулок, 6	f	large
61958	69582	1817	Оренбургская область, Гай, Октябрьская, 60	f	large
60585	68328	421	Оренбургская область, Гай, Октябрьская, 60	f	large
61961	68334	1820	Оренбургская область, Гай, Молодежная, 10	f	large
60592	68334	428	Оренбургская область, Гай, Молодежная, 10	f	large
61985	68332	1844	Оренбургская область, Гай, Молодежная, 73 А	f	large
60590	68332	426	Оренбургская область, Гай, Молодежная, 73 А	f	large
61981	68325	1840	Оренбургская область, Гай, Ленина, 16	f	large
60582	68325	418	Оренбургская область, Гай, Ленина, 16	f	large
60586	68326	422	Оренбургская область, Гай, Коммунистическая, 5	f	large
60583	68326	419	Оренбургская область, Гай, Коммунистическая, 5	f	large
60593	68335	429	Оренбургская область, Гай, Калинина, 21	f	medium
61960	68333	1819	Оренбургская область, Гай, Декабристов, 10 А	f	large
60591	68333	427	Оренбургская область, Гай, Декабристов, 10 А	f	large
61983	68329	1842	Оренбургская область, Гай, Ленина, 43	f	large
60587	68329	423	Оренбургская область, Гай, Ленина, 43	f	large
60551	68295	387	Оренбургская область, Бузулук, ВТК-4	t	small
61271	68937	1119	Оренбургская область, Бузулук, Щорса, 72	f	medium
61272	68938	1120	Оренбургская область, Бузулук, Челюскинцев, 7	f	large
60524	68268	360	Оренбургская область, Бузулук, Фрунзе, 100	f	large
60523	68268	359	Оренбургская область, Бузулук, Фрунзе, 100	f	large
60539	68283	375	Оренбургская область, Бузулук, Суворова, 70	f	large
60532	68276	368	Оренбургская область, Бузулук, Серго, 7	f	large
60542	68286	378	Оренбургская область, Бузулук, Свердловская, 67	f	large
60529	68273	365	Оренбургская область, Бузулук, Рожкова, 57	f	large
60528	68272	364	Оренбургская область, Бузулук, Пушкина, 60	f	medium
61273	68939	1121	Оренбургская область, Бузулук, Объездная, 2	f	medium
60617	68359	453	Оренбургская область, Бузулук, Московская, 2 А	f	large
60535	68279	371	Оренбургская область, Бузулук, Мельничная, 1	f	large
60531	68275	367	Оренбургская область, Бузулук, Максима Горького, 40	f	medium
60538	68282	374	Оренбургская область, Бузулук, Линейная, 1	f	medium
61994	68287	1862	Оренбургская область, Бузулук, Лизы Чайкиной, 1	f	medium
60543	68287	379	Оренбургская область, Бузулук, Лизы Чайкиной, 1	f	large
60618	68271	454	Оренбургская область, Бузулук, Ленина, 60	f	large
60527	68271	363	Оренбургская область, Бузулук, Ленина, 60	f	large
60526	68270	362	Оренбургская область, Бузулук, Крестьянская, 46	f	large
61275	68277	1123	Оренбургская область, Бузулук, Кирова/Рожкова, 4/30	f	large
60533	68277	369	Оренбургская область, Бузулук, Кирова/Рожкова, 4/30	f	large
61993	69607	1861	Оренбургская область, Бузулук, Заводская, 71	f	large
60525	68269	361	Оренбургская область, Бузулук, Гая, 35А	f	large
60522	68267	358	Оренбургская область, Бузулук, Гая, 94	f	large
60521	68266	357	Оренбургская область, Бузулук, Гая, 83	f	large
60530	68274	366	Оренбургская область, Бузулук, Галактионова, 35	f	large
60540	68284	376	Оренбургская область, Бузулук, Вокзальная, 15	f	large
60549	68293	385	Оренбургская область, Бузулук, 4 микрорайон, 14А	f	large
61274	68294	1122	Оренбургская область, Бузулук, 3 микрорайон, 17А	f	large
60550	68294	386	Оренбургская область, Бузулук, 3 микрорайон, 17А	f	large
60548	68292	384	Оренбургская область, Бузулук, 3 микрорайон, 8а	f	large
60547	68291	383	Оренбургская область, Бузулук, 3 микрорайон, 17Е	f	large
60536	68280	372	Оренбургская область, Бузулук, 3 Линия, 9	f	large
60546	68290	382	Оренбургская область, Бузулук, 1 микрорайон, 28	f	large
60545	68289	381	Оренбургская область, Бузулук, 1 микрорайон, 30	f	large
60544	68288	380	Оренбургская область, Бузулук, 1 микрорайон, 8	f	large
60537	68281	373	Оренбургская область, Бузулук городской округ, 1 Линия, 16	f	large
60534	68278	370	Оренбургская область, Бузулук, 1 Линия, 40	f	large
60460	68205	296	Оренбургская область, Бугуруслан, переулок Щорса, 2	f	medium
60470	68215	306	Оренбургская область, Бугуруслан, пер.Электриков, 1	f	large
60454	68199	290	Оренбургская область, Бугуруслан, Широкая, 8-А	f	large
60449	68194	285	Оренбургская область, Бугуруслан, Челюскина, 41	f	large
60455	68200	291	Оренбургская область, Бугуруслан, Чапаевская, 93	f	large
60452	68197	288	Оренбургская область, Бугуруслан, Чапаевская, 42	f	large
60465	68210	301	Оренбургская область, Бугуруслан, Строителей, 2	f	large
60457	68202	293	Оренбургская область, Бугуруслан, Победная, 76	f	large
60464	68209	300	Оренбургская область, Бугуруслан, Некрасова, 48	f	large
60463	68208	299	Оренбургская область, Бугуруслан, Некрасова, 22	f	large
60461	68206	297	Оренбургская область, Бугуруслан, Некрасова, 89-А	f	large
60450	68195	286	Оренбургская область, Бугуруслан, Московская, 18-А	f	large
60458	68203	294	Оренбургская область, Бугуруслан, Ленинградская, 95-А	f	large
60451	68196	287	Оренбургская область, Бугуруслан, Куйбышевская, 3	f	large
60456	68201	292	Оренбургская область, Бугуруслан, Красногвардейская, 64	f	large
60453	68198	289	Оренбургская область, Бугуруслан, Коммунистическая, 29-а	f	large
60459	68204	295	Оренбургская область, Бугуруслан, Белинского, 54	f	large
60469	68214	305	Оренбургская область, Бугуруслан, 3-й микрорайон, 5	f	large
60467	68212	303	Оренбургская область, Бугуруслан, 2-й микрорайон, 4	f	large
60466	68211	302	Оренбургская область, Бугуруслан, 2-й микрорайон, 11	f	large
60468	68213	304	Оренбургская область, Бугуруслан, 1-й Микрорайон, 19-Б	f	large
60448	68193	284	Оренбургская область, Бугуруслан, Геологов, 16	f	large
60272	68001	96	Оренбургская область, Бикмурзино, Центральная, 12	t	small
60193	67938	9	Оренбургская область, Абдулино, Школьная, 35	f	large
67709	67937	8	Оренбургская область, Абдулино, Советская, 1	f	large
60188	67933	4	Оренбургская область, Абдулино, Советская, 186	f	large
60194	67939	10	Оренбургская область, Абдулино, Снежинская, 4	f	large
60190	67935	6	Оренбургская область, Абдулино, Пролетарская, 50	f	large
60187	67932	3	Оренбургская область, Абдулино, Коммунистическая, 85	f	large
60186	67931	2	Оренбургская область, Абдулино, Коммунистическая, 230	f	large
60191	67936	7	Оренбургская область, Абдулино, Комарова, 27 А	f	large
60185	67930	1	Оренбургская область, Абдулино, Заводская, 2	f	large
60189	67934	5	Оренбургская область, Абдулино, Чкалова, 191	f	large
61952	69578	1810	Оренбургская область, Ясный городской округ, Ясный, Западная, 15	f	large
61954	69580	1812	Оренбургская область, Ясненский район, Ясный, Ленина, 16	f	large
61944	69570	1802	Оренбургская область, Ясненский район, село Тыкаша, Центральная, 27а	f	small
61945	69571	1803	Оренбургская область, Ясненский район, село Ореховка, Школьная, 14а	f	small
61946	69572	1804	Оренбургская область, Ясненский район, село Новосельский, Набережная, 3	f	medium
61932	69558	1790	Оренбургская область, Ясненский район, поселок Кумак, Школьная, 3а	f	small
61941	69567	1799	Оренбургская область, Ясненский район, село Котансу, Новая, 21	f	small
61943	69569	1801	Оренбургская область, Ясненский район, село Комарово, Центральная, 4	f	medium
61942	69568	1800	Оренбургская область, Ясненский район, село Керуембай, Школьная, 1б	f	small
61939	69565	1797	Оренбургская область, Ясненский район, село Еленовка, Пролетарская, 5	f	medium
61937	69563	1795	Оренбургская область, Ясненский район, село Веселовский, Садовая, 18	f	small
61940	69566	1798	Оренбургская область, Ясненский район, село Верхний Киембай, Центральная, 25а	f	small
61933	69559	1791	Оренбургская область, Ясненский район, село Акжарское, Советская, 7а	f	small
61898	69524	1756	Оренбургская область, Шарлыкский район, село Ялчкаево, Центральная, 64	t	small
61902	69528	1760	Оренбургская область, Шарлыкский район, село Юзеево, Советская, 14	t	small
61929	69555	1787	Оренбургская область, Шарлыкский район, село Шарлык, Советская, 27А	f	large
61926	69552	1784	Оренбургская область, Шарлыкский район, село Шарлык, Советская, 18	f	large
61927	69553	1785	Оренбургская область, Шарлыкский район, село Шарлык, Родимцева, 4	f	large
61928	69554	1786	Оренбургская область, Шарлыкский район, село Шарлык, Калининская, 66	f	large
61906	69532	1764	Оренбургская область, Шарлыкский район, село Урняк, Мира, 4А	t	small
61923	69549	1781	Оренбургская область, Шарлыкский район, село Титовка, Молодежная, 7	f	small
67765	69547	1779	Оренбургская область, Шарлыкский район, село Слоновка, Клубная, 9	f	small
61918	69544	1776	Оренбургская область, Шарлыкский район, село Сарманай, Школьная, 6	f	medium
61893	69519	1751	Оренбургская область, Шарлыкский район, село Романовка, Молодежная, 10	f	small
60382	68127	216	Оренбургская область, Шарлыкский район, село Рождественка, Школьная, 5	f	small
61900	69526	1758	Оренбургская область, Шарлыкский район, село Рождественка, Молодежная, 8А	f	small
61917	69543	1775	Оренбургская область, Шарлыкский район, село Ратчино, Советская, 26	f	small
61916	69542	1774	Оренбургская область, Шарлыкский район, село Ратчино, Советская, 10А	f	small
61912	69538	1770	Оренбургская область, Шарлыкский район, село Путятино, Мира, 34	f	medium
61930	69556	1788	Оренбургская область, Шарлыкский район, село Приветливый, Школьная, 2	f	small
60507	68252	343	Красноярский край, село Преображенка	f	medium
61844	69470	1700	Оренбургская область, Шарлыкский район, село Преображенка, пер. Школьный, 8	f	small
61909	69535	1767	Оренбургская область, Шарлыкский район, село Преображенка, Школьный переулок, 4	f	small
60949	68684	795	Оренбургская область, Шарлыкский район, село Покровка, Красноармейская, 1А	f	medium
61919	69545	1777	Оренбургская область, Шарлыкский район, село Перовка, Школьная, 2	t	small
61908	69534	1766	Оренбургская область, Шарлыкский район, село Парадеево, Парадеевская, 38А	f	small
61903	69529	1761	Оренбургская область, Шарлыкский район, село Новоникольское, пер.Культурный, 11	f	small
61904	69530	1762	Оренбургская область, Шарлыкский район, село Новомусино, Школьная, 1	f	medium
61907	69533	1765	Оренбургская область, Шарлыкский район, село Новоархангеловка, Родимцева, 20	f	small
61925	69551	1783	Оренбургская область, Шарлыкский район, село Мустафино, Верхняя, 36	f	small
61920	69546	1778	Оренбургская область, Шарлыкский район, село Малослободка, Школьная, 13	t	small
61897	69523	1755	Оренбургская область, Шарлыкский район, село Константиновка, Центральная, 45А	f	small
61896	69522	1754	Оренбургская область, Шарлыкский район, село Колычево, Средняя, 19	t	small
61931	69557	1789	Оренбургская область, Шарлыкский район, село Кармалка, Библиотечный переулок, 1	f	small
61899	69525	1757	Оренбургская область, Шарлыкский район, село Илькульган, Новая, 11	f	small
61913	69539	1771	Оренбургская область, Шарлыкский район, село Изяк-Никитино, Мира, 36	t	small
61915	69541	1773	Оренбургская область, Шарлыкский район, село Зобово, Школьная, 8	f	small
61914	69540	1772	Оренбургская область, Шарлыкский район, село Зеркло, Центральная, 22	t	small
61895	69521	1753	Оренбургская область, Шарлыкский район, село Зеркло, Салмыш, 2	f	small
61894	69520	1752	Оренбургская область, Шарлыкский район, село Дубровка, Школьная, 8	f	small
61911	69537	1769	Оренбургская область, Шарлыкский район, село Вишневка, Советская, 9	t	small
61892	69518	1750	Оренбургская область, Шарлыкский район, село Богородское, Молодежная, 1	f	small
61924	69550	1782	Оренбургская область, Шарлыкский район, село Бараково, Новая, 3	t	small
61865	69491	1723	Оренбургская область, Тюльганский район, поселок Тюльган, Октябрьская, 1	f	large
61864	69490	1722	Оренбургская область, Тюльганский район, поселок Тюльган, М.Горького, 9	f	large
61863	69489	1721	Оренбургская область, Тюльганский район, поселок Тюльган, М.Горького, 20	f	large
61874	69500	1732	Оренбургская область, Тюльганский район, село Тугустемир	f	medium
61867	69493	1725	Оренбургская область, Тюльганский район, село Троицкое, площадь Коммунаров, 9а, здание сельсовета	f	medium
61871	69497	1729	Оренбургская область, Тюльганский район, село Ташла	f	medium
61803	69433	1659	Оренбургская область, Тюльганский район, село Ташла, Довженко, 50	f	large
61882	69508	1740	Оренбургская область, Тюльганский район, село Стретинка, здание ФАП	t	small
61870	69496	1728	Оренбургская область, Тюльганский район, село Рудное	f	small
61883	69509	1741	Оренбургская область, Тюльганский район, село Репьевка	f	small
61876	69502	1734	Оренбургская область, Тюльганский район, село Разномойка, Советская, 58, здание школы	f	medium
60607	68349	443	Пензенская область, Пенза, поселок Подлесный	f	small
61873	69499	1731	Оренбургская область, Тюльганский район, село Новосергиевка	t	small
61890	69516	1748	Оренбургская область, Тюльганский район, село Нововасильевка	f	medium
61868	69494	1726	Оренбургская область, Тюльганский район, село Николаевка, Николаевская, 21, здание ФАП	t	small
61884	69510	1742	Оренбургская область, Тюльганский район, село Козловка, Ленинская, 1/1, здание ФАП	t	small
61885	69511	1743	Оренбургская область, Тюльганский район, село Ключи, Школьная, 7, здание школы	f	small
61875	69501	1733	Оренбургская область, Тюльганский район, село Калининский, Молодежная, 14/2, здание клуба	f	small
61869	69495	1727	Оренбургская область, Тюльганский район, село Ивановка, Мира, 50, здание школы	f	small
61880	69506	1738	Оренбургская область, Тюльганский район, село Екатеринославка, Мельник, 55а, здание сельсовета	f	small
67745	69254	1473	Оренбургская область, Тюльганский район, село Екатериновка, Школьная, 2	t	small
61887	69513	1745	Оренбургская область, Тюльганский район, село Екатериновка, Екатериновка, 39/1, здание школы	f	small
61878	69504	1736	Оренбургская область, Тюльганский район, село Давлеткулово	f	small
61872	69498	1730	Оренбургская область, Тюльганский район, село Городки	f	medium
61877	69503	1735	Оренбургская область, Тюльганский район, село Владимировка, переулок Быстроновского, 1, здание школы	f	medium
61886	69512	1744	Оренбургская область, Тюльганский район, село Благодарное	f	medium
61889	69515	1747	Оренбургская область, Тюльганский район, село Благовещенка, Молодежная, 7а, здание дома культуры	f	small
61881	69507	1739	Оренбургская область, Тюльганский район, село Аустяново	t	small
61888	69514	1746	Оренбургская область, Тюльганский район, село Астрахановка	f	small
61866	69492	1724	Оренбургская область, Тюльганский район, село Алмала	f	small
61879	69505	1737	Оренбургская область, Тюльганский район, село Алабердино, Школьная, 7, здание школы	f	small
60404	68149	238	Оренбургская область, Тюльганский район, село Аксаково, пер. Аксаковский, 18	f	medium
61828	69454	1684	Оренбургская область, Тоцкий район, село Тоцкое Второе, Победы, 6 А	f	large
61827	69453	1683	Оренбургская область, Тоцкий район, село Тоцкое Второе, Победы, 6 А	f	large
61826	69452	1682	Оренбургская область, Тоцкий район, село Тоцкое Второе, Жукова, 1	f	large
61825	69452	1681	Оренбургская область, Тоцкий район, село Тоцкое Второе, Жукова, 1	f	large
61824	69452	1680	Оренбургская область, Тоцкий район, село Тоцкое Второе, Жукова, 1	f	large
61823	69451	1679	Оренбургская область, Тоцкий район, село Тоцкое Второе, Жукова, 4	f	large
61822	69451	1678	Оренбургская область, Тоцкий район, село Тоцкое Второе, Жукова, 4	f	large
61819	69448	1675	Оренбургская область, Тоцкий район, село Тоцкое, Терешковой, 5	f	large
61818	69448	1674	Оренбургская область, Тоцкий район, село Тоцкое, Терешковой, 5	f	large
61817	69448	1673	Оренбургская область, Тоцкий район, село Тоцкое, Терешковой, 5	f	large
61820	69449	1676	Оренбургская область, Тоцкий район, село Тоцкое, Красная Площадь, 1 б	f	large
61816	69447	1672	Оренбургская область, Тоцкий район, село Тоцкое, Красная Площадь, 1Б	f	large
61853	69479	1709	Оренбургская область, Тоцкий район, село Суворовский, Победы, 9	f	medium
61848	69474	1704	Оренбургская область, Тоцкий район, село Свердлово, Мира, 8	f	small
61836	69462	1692	Оренбургская область, Тоцкий район, село Сайфутдиново, Парковая, 2	f	small
61846	69472	1702	Оренбургская область, Тоцкий район, село Саиновка, Центральная, 21	f	small
61840	69466	1696	Оренбургская область, Тоцкий район, село Рябинный, Рябинная, 44	f	small
61833	69459	1689	Оренбургская область, Тоцкий район, село Приютное, Советская, 7	f	small
55334	62372	2037	Нижегородская область, Саров	f	large
61829	69455	1685	Оренбургская область, Тоцкий район, село Пристанционный, 2-я линия, 58	f	large
61860	69486	1716	Оренбургская область, Тоцкий район, село Погромное, Элеваторная, 14	f	small
61859	69485	1715	Оренбургская область, Тоцкий район, село Погромное, Ленина, 28	f	medium
61821	69450	1677	Оренбургская область, Тоцкий район, село Первое Мая, Майская, 34 а	t	small
61831	69457	1687	Оренбургская область, Тоцкий район, село Павло-Антоновка, Центральная, 5 Б	f	small
61851	69477	1707	Оренбургская область, Тоцкий район, село Нововасильевка, Центральная, 1 а	f	small
61905	69531	1763	Оренбургская область, Тоцкий район, село Николаевка, Шоссейная, 3	f	small
61832	69458	1688	Оренбургская область, Тоцкий район, село Невежкино, Центральная, 2	f	small
61849	69475	1705	Оренбургская область, Тоцкий район, село Набережный, Центральная, 13	f	small
61842	69468	1698	Оренбургская область, Тоцкий район, село Мулюково, 1-я сторона, 1	t	small
61834	69460	1690	Оренбургская область, Тоцкий район, село Марковка, Новая, 7	f	small
61847	69473	1703	Оренбургская область, Тоцкий район, село Мананниково	f	small
61841	69467	1697	Оренбургская область, Тоцкий район, село Малая Ремизенка, Нахаловка, 165	f	small
61850	69476	1706	Оренбургская область, Тоцкий район, село Любимовка, Центральная, 25	t	small
61856	69482	1712	Оренбургская область, Тоцкий район, село Логачевка, Большой Плант, 1 А	f	small
61852	69478	1708	Оренбургская область, Тоцкий район, село Кызыл-Мечеть, Центральная, 5	f	small
61838	69464	1694	Оренбургская область, Тоцкий район, село Ковыляевка, Центральная, 1 В	f	small
61855	69481	1711	Оренбургская область, Тоцкий район, село Казанка, Казанская, 6	t	small
61857	69483	1713	Оренбургская область, Тоцкий район, село Злобинка, Центральная, 15	f	small
67764	69471	1701	Оренбургская область, Тоцкий район, село Задорожный, Школьная, 14	f	small
61861	69487	1717	Оренбургская область, Тоцкий район, село Жидиловка, Мира, 10	f	small
61854	69480	1710	Оренбургская область, Тоцкий район, село Дружный, Дружнинская, 11	t	small
61839	69465	1695	Оренбургская область, Тоцкий район, село Верхнебузулукский, Молодёжная, 26	f	medium
61843	69469	1699	Оренбургская область, Тоцкий район, село Большая Ремизенка, Центральная, 1	f	small
61835	69461	1691	Оренбургская область, Тоцкий район, село Богдановка, пер. Парковый, 2	f	medium
61837	69463	1693	Оренбургская область, Тоцкий район, село Амерханово, Школьная, 1	f	small
61812	69443	1668	Оренбургская область, Ташлинский район, село Ясная Поляна, Комарова, 14	f	medium
61779	69409	1635	Оренбургская область, Ташлинский район, село Шумаево, Центральная, 48/2	f	small
61789	69419	1645	Оренбургская область, Ташлинский район, село Широкое, Подгорная, 2	f	small
61810	69441	1666	Оренбургская область, Ташлинский район, село Шестаковка, Молодежная, 4	t	small
67762	69408	1634	Оренбургская область, Ташлинский район, село Чернышовка, Нагорная, 11/2	t	small
61807	69438	1663	Оренбургская область, Ташлинский район, село Черноярово, Советская, 15	f	medium
61809	69440	1665	Оренбургская область, Ташлинский район, село Чеботаревка, Школьная, 3	f	small
61802	69432	1658	Оренбургская область, Ташлинский район, село Ташла, Советская, 113А	f	large
60747	68487	585	Оренбургская область, Ташлинский район, село Степной, Горная, 1/1	t	small
61796	69426	1652	Оренбургская область, Ташлинский район, село Степановка, Советская, 24/1	t	small
61815	69446	1671	Оренбургская область, Ташлинский район, село Солнечный, Восточная, 8а	f	small
61793	69423	1649	Оренбургская область, Ташлинский район, село Раннее, Набережная, 7	f	medium
61795	69425	1651	Оренбургская область, Ташлинский район, село Пустобаево, Центральная, 35Б	f	small
61784	69414	1640	Оренбургская область, Ташлинский район, село Прокуронка, Школьная, 1	f	small
61791	69421	1647	Оренбургская область, Ташлинский район, село Придолинный, Центральная, 3	f	medium
61788	69418	1644	Оренбургская область, Ташлинский район, село Новосельное, Центральная, 27	t	small
61787	69417	1643	Оренбургская область, Ташлинский район, село Новокаменка, Центральная, 26А	f	small
61794	69424	1650	Оренбургская область, Ташлинский район, село Мирошкино, Школьная, 12	f	small
61773	69403	1629	Оренбургская область, Ташлинский район, село Майское, Школьная, 24	f	small
61797	69427	1653	Оренбургская область, Ташлинский район, село Курташка, Дружбы, 8	t	small
61806	69436	1662	Оренбургская область, Ташлинский район, село Кузьминка, Центральная, 18	t	small
67763	69422	1648	Оренбургская область, Ташлинский район, село Криница, Молодежная, 2/1	t	small
61782	69412	1638	Оренбургская область, Ташлинский район, село Коммуна, Коммунаров, 5	f	small
61785	69415	1641	Оренбургская область, Ташлинский район, село Кинделя, Молодежная, 1	f	large
61783	69413	1639	Оренбургская область, Ташлинский район, село Кандалинцево, Молодежная, 10	f	small
61798	69428	1654	Оренбургская область, Ташлинский район, село Каменноимангулово, Дружбы, 16	t	small
61781	69411	1637	Оренбургская область, Ташлинский район, село Калинин, Центральная, 7	f	medium
61776	69406	1632	Оренбургская область, Ташлинский район, село Иртек, Центральная, 8А	t	small
61814	69445	1670	Оренбургская область, Ташлинский район, село Зерновой, Победы, 21	f	small
61780	69410	1636	Оренбургская область, Ташлинский район, село Заречное, Центральная, 8	t	small
61801	69431	1657	Оренбургская область, Ташлинский район, село Западный, Клубная, 3	t	small
61800	69430	1656	Оренбургская область, Ташлинский район, село Жирнов, Школьная, 3	f	small
61808	69439	1664	Оренбургская область, Ташлинский район, село Жигалино, Центральная, 4	t	small
61777	69407	1633	Оренбургская область, Ташлинский район, село Вязовое, Школьная, 2	f	small
61813	69444	1669	Оренбургская область, Ташлинский район, село Восходящий, Центральная, 21	t	small
61790	69420	1646	Оренбургская область, Ташлинский район, село Буренино, Центральная, 18	f	small
61786	69416	1642	Оренбургская область, Ташлинский район, село Бородинск, Советская, 46	f	small
61774	69404	1630	Оренбургская область, Ташлинский район, село Болдырево, Центральная, 47	f	small
61772	69402	1628	Оренбургская область, Ташлинский район, село Благодарное, Советская, 24	t	medium
61811	69442	1667	Оренбургская область, Ташлинский район, село Баширово, Центральная, 7	t	small
61757	69391	1613	Оренбургская область, Сорочинский район, п.Новый, Пушкина, 5Б, сельский Клуб	f	small
67760	69322	1586	Оренбургская область, Сорочинский район, село Янтарное, Молодежная, 6	f	small
61760	69394	1616	Оренбургская область, Сорочинский район, село Федоровка, Центральная, 51, СДК	f	medium
60296	68041	120	Оренбургская область, Сорочинский район, село Федоровка, Центральная, 9	f	medium
61747	69381	1602	Оренбургская область, Сорочинский район, село Уран, Центральная, 5, СДК	f	small
61759	69393	1615	Оренбургская область, Сорочинский район, село Троицкое, Молодежная, 23, СДК	f	small
61758	69392	1614	Оренбургская область, Сорочинский район, село Толкаевка, Гречушкина, 3Г, СДК	f	medium
61736	69370	1591	Оренбургская область, Сорочинский район, село Спасское, Центральная, 5А, СДК	t	small
61737	69371	1592	Оренбургская область, Сорочинский район, село Сборовский, Школьная, 11А, Сельский Клуб	t	small
61743	69377	1598	Оренбургская область, Сорочинский район, село Романовка, Центральная, 1, СДК	f	small
61754	69388	1609	Оренбургская область, Сорочинский район, село Родинский, Садовая, 13, СДК	f	large
61752	69386	1607	Оренбургская область, Сорочинский район, село Пронькино, Ленинская, 29, СДК	f	medium
61750	69384	1605	Оренбургская область, Сорочинский район, село Покровка, Центральная, 7, СДК	t	small
61751	69385	1606	Оренбургская область, Сорочинский район, село Первокрасное, Советская, 31, СДК	f	small
61749	69383	1604	Оренбургская область, Сорочинский район, село Новая Белогорка, Центральная, 44, СДК	t	small
61748	69382	1603	Оренбургская область, Сорочинский район, село Никольское, Центральная, 24А, сельский Клуб	f	small
67701	68458	556	Оренбургская область, Сорочинский район, село Никольское, Центральная, 10	f	small
61746	69380	1601	Оренбургская область, Сорочинский район, село Николаевка, Центральная, 52А, СДК	f	medium
60439	68184	275	Оренбургская область, Сорочинский район, село Николаевка, Нагорная, 18	f	small
61734	69368	1589	Оренбургская область, Сорочинский район, село Надеждинка, Центральная, 6/2, сельский Клуб	t	small
61744	69378	1599	Оренбургская область, Сорочинский район, село Михайловка 2-я, Школьная, 6, СДК	f	small
61742	69376	1597	Оренбургская область, Сорочинский район, село Михайловка 1-я, Молодежная, 8, СДК	f	small
61741	69375	1596	Оренбургская область, Сорочинский район, село Матвеевка, Центральная, 37А, СДК	f	small
61745	69379	1600	Оренбургская область, Сорочинский район, село Ивановка 2-я, Московская, 82, СДК	f	small
61283	68947	1133	Оренбургская область, Сорочинский район, село Ивановка, Кольцевая, 8А	f	large
61738	69372	1593	Оренбургская область, Сорочинский район, село Гамалеевка, Садовая, 74А, средняя школа	f	medium
61739	69373	1594	Оренбургская область, Сорочинский район, село Гамалеевка, Молодежная, 15А	f	medium
61735	69369	1590	Оренбургская область, Сорочинский район, село Войковский, Победы, 2А, СДК	f	medium
61733	69367	1588	Оренбургская область, Сорочинский район, село Бурдыгино, Центральная, 95Б, сельский Дом культуры	t	medium
67761	69366	1587	Красноярский край, поселок Березовка, улица Молодежная, 8	t	small
61730	69365	1585	Оренбургская область, Сорочинский район, село Баклановка, Молодежная, 18, СДК	f	small
61740	69374	1595	Оренбургская область, Сорочинский район, село Алексеевка, Молодежная, 20Б, СДК	t	small
61706	69341	1561	Оренбургская область, Соль-Илецкий район, село кирпичный Завод, Центральная, 22а	f	medium
61704	69339	1559	Оренбургская область, Соль-Илецкий район, село Шахтный, Центральная, 25	f	medium
61687	69321	1542	Оренбургская область, Соль-Илецкий район, село Чашкан, Южная, 2/3	f	medium
61690	69325	1545	Оренбургская область, Соль-Илецкий район, село Цвиллинга, Элеваторная, 23	f	small
61710	69345	1565	Оренбургская область, Соль-Илецкий район, село Угольное	f	medium
61805	69435	1661	Оренбургская область, Соль-Илецкий район, село Трудовое, пер.Почтовый, 3	f	medium
61707	69342	1562	Оренбургская область, Соль-Илецкий район, село Трудовое, Кооперативная, 25	f	medium
61709	69344	1564	Оренбургская область, Соль-Илецкий район, село Троицк, Школьная, 9	f	small
61708	69343	1563	Оренбургская область, Соль-Илецкий район, село Тамар-Уткуль, Центральная, 18а	f	medium
61992	69606	1854	Оренбургская область, Соль-Илецкий район, село Сухоречка, Тополиная, 22	t	small
60664	68405	500	Оренбургская область, Соль-Илецкий район, село Сухоречка, Молодежная, 49	t	medium
61721	69356	1576	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Южная, 31	f	large
61717	69352	1572	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Цвиллинга, 18	f	large
61718	69353	1573	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Уральская, 34	f	large
67759	69364	1584	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Украинская, 2 «г»	f	medium
61726	69361	1581	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Орджоникидзе, 7	f	large
61719	69354	1574	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Московская, 161	f	large
61716	69351	1571	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Московская, 1	f	large
61725	69360	1580	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Молодежная, 1	f	large
61891	69517	1749	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Ленинградская, 1/1	f	small
67757	69350	1570	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Кирова, 52	f	large
61723	69358	1578	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Гонтаренко, 1	f	large
61722	69357	1577	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Володарского, 111	f	large
61727	69362	1582	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Вокзальная, 79	f	large
61714	69349	1569	Оренбургская область, Соль-Илецкий район, Соль-Илецк, Челкарская, 90	f	large
67769	69605	1853	Оренбургская область, Соль-Илецкий район, село Смирновка, Новая, 5	f	small
61705	69340	1560	Оренбургская область, Соль-Илецкий район, село Саратовка, Калинина, 65	f	medium
61938	69564	1796	Оренбургская область, Соль-Илецкий район, село Садовый, Центральная, 9	f	small
61703	69338	1558	Оренбургская область, Соль-Илецкий район, село Покровка, Ахметгалиева, 21	f	medium
61699	69334	1554	Оренбургская область, Соль-Илецкий район, село Перовка, Советская, 12	f	small
61701	69336	1556	Оренбургская область, Соль-Илецкий район, село Первомайское	f	medium
61698	69333	1553	Оренбургская область, Соль-Илецкий район, село Новоилецк, Советская, 59	f	medium
61697	69332	1552	Оренбургская область, Соль-Илецкий район, село Михайловка	f	small
61713	69348	1568	Оренбургская область, Соль-Илецкий район, поселок Мирный, Островского, 1	f	small
61700	69335	1555	Оренбургская область, Соль-Илецкий район, село Мещеряковка, Советская, 22	f	small
111780	61742	1155	Нижегородская область, Кулебаки	t	medium
61681	69315	1536	Оренбургская область, Соль-Илецкий район, село Маячная, Элеваторная, 1	f	small
61692	69327	1547	Оренбургская область, Соль-Илецкий район, село Маякский, Целинная, 48	f	medium
61694	69329	1549	Оренбургская область, Соль-Илецкий район, село Малопрудный, Первомайская, 11	f	small
61696	69331	1551	Оренбургская область, Соль-Илецкий район, село Линевка, Кызыл-Юлдузская, 58	f	large
61691	69326	1546	Оренбургская область, Соль-Илецкий район, село Кумакский, Центральная, 30	f	medium
61686	69320	1541	Оренбургская область, Соль-Илецкий район, село Казанка, Школьная, 1	f	small
61689	69324	1544	Оренбургская область, Соль-Илецкий район, село Изобильное, Максима Горького, 1	f	large
67758	69359	1579	Оренбургская область, Соль-Илецкий район, поселок Зеленый Клин, 1	f	small
61695	69330	1550	Оренбургская область, Соль-Илецкий район, село Елшанка, Магистральная, 13	f	small
61702	69337	1557	Оренбургская область, Соль-Илецкий район, село Егенсай, Школьная, 6	f	small
61688	69323	1543	Оренбургская область, Соль-Илецкий район, село Дружба, Речная, 33	f	medium
61711	69346	1566	Оренбургская область, Соль-Илецкий район, село Дивнополье, Советская, 42	f	medium
61684	69318	1539	Оренбургская область, Соль-Илецкий район, село Григорьевка, Советская, 68	f	large
61685	69319	1540	Оренбургская область, Соль-Илецкий район, село Возрождение, Луговая, 1	f	small
61683	69317	1538	Оренбургская область, Соль-Илецкий район, село Ветлянка, Советская, 56	f	medium
61682	69316	1537	Оренбургская область, Соль-Илецкий район, село Буранное, Советская, 70а	f	large
61680	69314	1535	Оренбургская область, Соль-Илецкий район, село Боевая Гора, Таврическая, 14	f	medium
61693	69328	1548	Оренбургская область, Соль-Илецкий район, село Ащибутак, Зеленая, 36	f	small
67756	69313	1534	Оренбургская область, Северный район, село Яковлево, Центральная, 41	t	small
61669	69303	1523	Оренбургская область, Северный район, село Шабрино, Бадановка, 20	t	small
67752	69282	1501	Оренбургская область, Северный район, село Тургай, Центральная, 50а	t	small
61664	69298	1518	Оренбургская область, Северный район, село Трифоновка, Центральная, 93а	t	small
67755	69312	1533	Оренбургская область, Северный район, село Стародомосейкино, Молодежная, 14	f	small
61677	69311	1532	Оренбургская область, Северный район, село Староборискино, Советская, 41	f	small
61673	69307	1527	Оренбургская область, Северный район, село Соковка, Школьная, 2	f	medium
61652	69286	1504	Оренбургская область, Северный район, село Сергушкино, Центральная, 95	t	small
61674	69308	1528	Оренбургская область, Северный район, село Секретарка, Школьная, 13	f	small
61671	69305	1525	Оренбургская область, Северный район, село Северное, Советская, 25	f	large
61672	69306	1526	Оренбургская область, Северный район, село Северное, Осенняя, 2	f	large
61666	69300	1520	Оренбургская область, Северный район, село Рычково, Центральная, 22	f	small
61668	69302	1522	Оренбургская область, Северный район, село Русский Кандыз, пл.Центральная, 6	f	medium
61657	69291	1511	Оренбургская область, Северный район, село Ремчугово	f	small
61655	69289	1508	Оренбургская область, Северный район, село Пашкино, Центральная, 74а	t	small
61312	68976	1162	Оренбургская область, Северный район, село Павловка, бульвар Молодежный, 3	f	medium
61988	68771	1847	республика Чеченская, Грозненский район, село Октябрьское	f	medium
61056	68771	903	республика Чеченская, Грозненский район, село Октябрьское	f	medium
61032	68748	879	Еврейская автономная область, Ленинский район, село Октябрьское	f	medium
61031	68747	878	Оренбургская область, Северный район, село Октябрьское, Луначарского, 41	f	medium
61034	68750	881	Оренбургская область, Северный район, село Октябрьское, Железнодорожная, 10	f	medium
61661	69295	1515	Оренбургская область, Северный район, село Новодомосейкино, Молодежная, 15	f	small
61660	69294	1514	Оренбургская область, Северный район, село Новоборискино, Южная, 24б	t	small
61659	69293	1513	Оренбургская область, Северный район, село Мордово-Добрино, Чукаевская, 2а	t	small
61862	69488	1718	Оренбургская область, Северный район, село Медведка, Центральная, 41 а	f	small
61653	69287	1505	Оренбургская область, Северный район, село Кызыляр, Лесная, 23	t	small
61656	69290	1509	Оренбургская область, Северный район, село Курская Васильевка, Заречная, 1	f	small
61651	69284	1503	Оренбургская область, Северный район, село Кряжлы, Широкая, 41	f	small
61654	69288	1507	Оренбургская область, Северный район, село Красноярка, Черемушки, 9	f	small
61830	69456	1686	Оренбургская область, Тоцкий район, село Кирсановка	f	large
61676	69310	1530	Оренбургская область, Северный район, село Камышлинка, Центральная, 50	t	small
61650	69283	1502	Оренбургская область, Северный район, село Каменногорское, Центральная, 20	t	small
61647	69280	1499	Оренбургская область, Северный район, село Кабаевка, Молодежная, 3	t	small
67753	69296	1516	Оренбургская область, Северный район, село Жмакино, Горная, 43	f	small
61675	69309	1529	Оренбургская область, Северный район, село Дымка, Вокзальная, 54	t	small
61663	69297	1517	Оренбургская область, Северный район, село Большедорожный, Молодежная, 83	f	small
61670	69304	1524	Оренбургская область, Северный район, село Богдановка, Луговая, 15а	f	small
61648	69281	1500	Оренбургская область, Северный район, село Бакаево, Речная, 1а	f	medium
61646	69279	1498	Оренбургская область, Северный район, село Аксенкино, Центральная, 9	f	small
61645	69278	1497	Оренбургская область, Светлинский район, село Целинный, Воронежская, 2а	f	medium
61644	69277	1496	Оренбургская область, Светлинский район, село Тобольский, Бугурусланская, 6	f	medium
61634	69267	1486	Оренбургская область, Светлинский район, поселок Светлый, Торговая, 6	f	large
61635	69268	1487	Оренбургская область, Светлинский район, поселок Светлый, Промышленная, 34	f	large
61633	69266	1485	Оренбургская область, Светлинский район, поселок Светлый, Овечкина, 9	f	large
61583	69216	1435	Оренбургская область, Светлинский район, поселок Светлый, Мира, 4	f	large
60633	68374	469	Оренбургская область, Светлинский район, село Полевой, Комсомольская, 11	f	medium
61641	69274	1493	Оренбургская область, Светлинский район, село Озерный, Чкалова, 3	f	medium
61640	69273	1492	Оренбургская область, Светлинский район, село Коскуль, квартал Новоселов, 4	f	small
61638	69271	1490	Оренбургская область, Светлинский район, село Восточный, Советская, 10	f	medium
67750	69270	1489	Оренбургская область, Светлинский район, село Актюбинский, Целинная, 44	f	small
61623	69256	1475	Оренбургская область, Саракташский район, село Шишма, Центральная, 26	f	medium
61592	69225	1444	Оренбургская область, Саракташский район, село Черный Отрог, Ленинская, 23	f	large
61593	69226	1445	Оренбургская область, Саракташский район, село Черный Отрог, Вокзальная, 36	f	small
67736	69239	1458	Оренбургская область, Саракташский район, село Черкассы, Советская, 15В	f	large
67737	69240	1459	Оренбургская область, Саракташский район, село Федоровка 1-я, Советская, 1	f	medium
61609	69242	1461	Оренбургская область, Саракташский район, село Татарский Саракташ, Центральная, 14 а	f	small
61594	69227	1446	Оренбургская область, Саракташский район, село Студенцы, Школьный, 3	t	small
67740	69246	1465	Оренбургская область, Саракташский район, село Старый Сокулак, Заречная, 3	f	small
67741	69247	1466	Оренбургская область, Саракташский район, село Спасское, Луговая, 101 А	f	medium
61587	69220	1439	Оренбургская область, Саракташский район, село Саракташ, переулок Заводской, 4	f	large
60343	68088	176	Оренбургская область, Саракташский район, село Саракташ, Промышленная, 11	f	medium
61589	69222	1441	Оренбургская область, Саракташский район, село Саракташ, Первомайская, 97	f	large
61588	69221	1440	Оренбургская область, Саракташский район, село Саракташ, Мира, 88	f	large
61591	69224	1443	Оренбургская область, Саракташский район, село Саракташ, Красноармейская, 96	f	large
61971	69590	1830	Оренбургская область, Саракташский район, село Саракташ, Комсомольская, 13, здание школы №1	f	large
61590	69223	1442	Оренбургская область, Саракташский район, село Саракташ, Геологов, 14 а	f	large
61299	68963	1149	Оренбургская область, Саракташский район, село Пречистинка, Большая, 21	f	small
61612	69245	1464	Оренбургская область, Саракташский район, село Покурлей, Центральная, 22	t	small
67743	69251	1470	Оренбургская область, Саракташский район, село Петровское, Школьная, 13	f	medium
61632	69265	1484	Оренбургская область, Саракташский район, село Островное, Лабужского, 8	f	small
61603	69236	1455	Оренбургская область, Саракташский район, село Новый Сокулак, Школьный переулок, 5	f	small
67747	69262	1481	Оренбургская область, Саракташский район, село Новочеркасск, Кольцевая, 1, здание школы	f	large
61626	69259	1478	Оренбургская область, Саракташский район, село Новотафарово, Культурная, 10, здание школы	t	small
61610	69243	1462	Оренбургская область, Саракташский район, село Новоселки, Заводская, 1	t	small
61617	69250	1469	Оренбургская область, Саракташский район, село Новомихайловка, переулок Школьный, 1, здание школы	t	small
67729	69231	1450	Оренбургская область, Саракташский район, село Николаевка, Парковая, 16, здание школы	f	small
61597	69230	1449	Оренбургская область, Саракташский район, село Никитино, Культурная, 10	f	medium
61481	69114	1331	Оренбургская область, Саракташский район, село Назаровка, Л.Толстого, 17а	t	small
67733	69235	1454	Оренбургская область, Саракташский район, село Надеждинка, пер.Школьный, 1	f	medium
67739	69244	1463	Оренбургская область, Саракташский район, село Кульчумово, Центральная, 1	f	small
67748	69263	1482	Оренбургская область, Саракташский район, село Красногор, Центральная, 2	f	small
61625	69258	1477	Оренбургская область, Саракташский район, село Кондуровка, Школьная, 6	t	small
67734	69237	1456	Оренбургская область, Саракташский район, село Карагузино	f	small
67749	69264	1483	Оренбургская область, Саракташский район, село Камышино, Школьная, 11	f	small
67744	69253	1472	Оренбургская область, Саракташский район, село Каировка, Заречная, 27	f	small
67730	69232	1451	Оренбургская область, Саракташский район, село Кабанкино, Школьная, 29	f	small
61055	68770	902	Оренбургская область, Саракташский район, село Ильинка, Центральная, 57	f	small
61596	69229	1448	Оренбургская область, Саракташский район, село Изяк-Никитино, Полевая, 5	t	small
61624	69257	1476	Оренбургская область, Саракташский район, село Желтое, Советская, 18	f	large
67735	69238	1457	Оренбургская область, Саракташский район, село Гавриловка, Школьная, 23	f	medium
67732	69234	1453	Оренбургская область, Саракташский район, село Вторая Александровка, Школьная, 5 	f	medium
67746	69255	1474	Оренбургская область, Саракташский район, село Воздвиженка, Школьная, 1	f	medium
67738	69241	1460	Оренбургская область, Саракташский район, село Васильевка, Школьная, 5	f	medium
67742	69249	1468	Оренбургская область, Саракташский район, село Бурунча, Зеленая, 12	f	small
67731	69233	1452	Оренбургская область, Саракташский район, село Биктимирово, Сакмарская, 2	t	small
61619	69252	1471	Оренбургская область, Саракташский район, село Андреевка, Школьная, 16, здание сельского клуба	t	small
60298	68043	131	Оренбургская область, Саракташский район, село Александровка, Рощепкина, 11	f	medium
61576	69209	1428	Оренбургская область, Сакмарский район, село Украинка, Лесная, 18А	f	medium
61574	69207	1425	Оренбургская область, Сакмарский район, село Тимашево, Советская, 44А	f	small
61569	69202	1420	Оренбургская область, Сакмарский район, село Татарская Каргала, Советская, 43	f	large
61581	69214	1433	Оренбургская область, Сакмарский район, село Татарская Каргала, Комсомольская, 9	f	large
60337	68082	170	Оренбургская область, Сакмарский район, село Северный, Школьная, 11	t	small
61567	69200	1418	Оренбургская область, Сакмарский район, село Сакмарская, Железнодорожная, 4	f	medium
61565	69198	1416	Оренбургская область, Сакмарский район, село Сакмара, Советская, 63	f	large
61564	69197	1415	Оренбургская область, Сакмарский район, село Сакмара, Ленина, 2	f	large
61482	69115	1332	Оренбургская область, Сакмарский район, село Сакмара, 50 Лет Победы, 54а	t	small
67801	68984	1170	Оренбургская область, Сакмарский район, село Никольское, В.Т.Обухова, 3	f	large
61571	69204	1422	Оренбургская область, Сакмарский район, село Нижние Чебеньки	t	small
61579	69212	1431	Оренбургская область, Сакмарский район, село Марьевка, Школьная, 15	f	medium
61566	69199	1417	Оренбургская область, Сакмарский район, Красный Коммунар, Краснокоммунарская, 30	f	large
60509	68254	345	Оренбургская область, Сакмарский район, Жилгородок, 7, с.Старая Александровка	f	medium
61580	69213	1432	Оренбургская область, Сакмарский район, село Жданово, Янгизская, 12	f	small
61584	69217	1436	Оренбургская область, Сакмарский район, село Егорьевка, Культурная, 35	f	medium
61497	69130	1348	Оренбургская область, Переволоцкий район, поселок Сырт, Железнодорожная, 9	f	medium
61572	69205	1423	Оренбургская область, Сакмарский район, село Дмитриевка, поселок Жилгородок, улица Центральная, 34	f	medium
61577	69210	1429	Оренбургская область, Сакмарский район, село Григорьевка 1-я	f	medium
61570	69203	1421	Оренбургская область, Сакмарский район, село Верхние Чебеньки, Школьная, 2А	f	medium
61585	69218	1437	Оренбургская область, Сакмарский район, село Белоусовка, Школьная, 256	f	medium
61568	69201	1419	Оренбургская область, Сакмарский район, село Беловка, 24	f	large
61578	69211	1430	Оренбургская область, Сакмарский район, село Архиповка, Школьная, 46А	f	medium
67812	69172	1390	Оренбургская область, Пономаревский район, село Чистополье, Центральная	t	small
67811	69171	1389	Оренбургская область, Пономаревский район, село Фадеевский, Совхозная, 7	f	small
67814	69174	1392	Оренбургская область, Пономаревский район, село Софиевка, Казанская, 32	f	large
67810	69170	1388	Оренбургская область, Пономаревский район, село Сорокино, переулок Садовый , 5А	t	small
67809	69169	1387	Оренбургская область, Пономаревский район, село Семеновка, Южная, 4	f	small
67728	69196	1414	Оренбургская область, Пономаревский район, село Романовка, Крестьянская, 63	f	small
67822	69182	1400	Оренбургская область, Пономаревский район, село Река Дема, Оренбургская, 20	f	small
67808	69168	1386	Оренбургская область, Пономаревский район, село Равнинный, Советская, 9	f	small
67726	69194	1412	Оренбургская область, Пономаревский район, село Пономаревка, Советская, 9А	t	large
67725	69193	1411	Оренбургская область, Пономаревский район, село Пономаревка, Советская, 12	f	medium
67724	69192	1410	Оренбургская область, Пономаревский район, село Пономаревка, Советская, 16	f	medium
67727	69195	1413	Оренбургская область, Пономаревский район, село Пономаревка, Заречная, 8А	t	small
67723	69191	1409	Оренбургская область, Пономаревский район, село Пономаревка, Гагарина, 58	f	large
67722	69190	1408	Оренбургская область, Пономаревский район, село Новобогородское, Центральная, 21	f	small
67720	69188	1406	Оренбургская область, Пономаревский район, село Нижние Кузлы, Школьная, 8	f	small
67813	69173	1391	Оренбургская область, Пономаревский район, село Наурузово, Школьная, 18	f	medium
67721	69189	1407	Оренбургская область, Пономаревский район, село Наурузово, Советская, 67А	f	medium
61039	68754	886	республика Башкортостан, село Михайловка	t	small
67719	69187	1405	Оренбургская область, Пономаревский район, село Максимовка, Молодежная, 34	f	small
60971	68706	817	Оренбургская область, Пономаревский район, село Ключевка, Центральная, 39	t	small
67717	69185	1403	Оренбургская область, Пономаревский район, село Кирсаново, Калинина, 3	t	small
67716	69184	1402	Оренбургская область, Пономаревский район, село Жатва, Набережная, 16	t	small
67823	69183	1401	Оренбургская область, Пономаревский район, село Ефремово-Зыково, Центральная, 1	f	small
67821	69181	1399	Оренбургская область, Пономаревский район, село Дюсметьево, Центральная, 87	f	medium
60750	68490	588	Оренбургская область, Пономаревский район, село Грачевка, Центральная, 46в	f	small
67819	69179	1397	Оренбургская область, Пономаревский район, село Воздвиженка, Рабочий городок, 46	f	medium
67820	69180	1398	Оренбургская область, Пономаревский район, село Верхние Кузлы, Верхняя, 28	t	small
67817	69177	1395	Оренбургская область, Пономаревский район, село Борисовка, Молодежная, 2	f	small
67818	69178	1396	Оренбургская область, Пономаревский район, село Беседино, Центральная, 27	f	small
67816	69176	1394	Оренбургская область, Пономаревский район, село Алябьево, Центральная, 20	t	small
61494	69127	1345	Оренбургская область, Пономаревский район, село Алексеевка, Самарская, 1	t	small
61490	69123	1341	Оренбургская область, Переволоцкий район, село Япрынцево, Школьная, 1	f	small
61495	69128	1346	Оренбургская область, Переволоцкий район, село Южный, Южная, 26	f	small
61523	69156	1374	Оренбургская область, Переволоцкий район, село Шуваловский, Школьная, 3	t	small
61525	69158	1376	Оренбургская область, Переволоцкий район, село Чесноковка, Кушмухаметовых, 10	f	large
61534	69167	1385	Оренбургская область, Переволоцкий район, село Филипповка, Молодежная, 12	f	small
61524	69157	1375	Оренбургская область, Переволоцкий район, село Татищево, Советская, 20	f	medium
61501	69134	1352	Оренбургская область, Переволоцкий район, село Судаковка, Школьный пер, 1	t	small
61513	69146	1364	Оренбургская область, Переволоцкий район, село Суворовка, Заречная, 13	t	small
61516	69149	1367	Оренбургская область, Переволоцкий район, село Степановка, Горького, 58	f	medium
61506	69139	1357	Оренбургская область, Переволоцкий район, село Сенное, Садовая, 33	f	small
61493	69126	1344	Оренбургская область, Переволоцкий район, село Садовый, Центральная, 43	f	medium
61522	69155	1373	Оренбургская область, Переволоцкий район, село Рычковка, Северная, 8	t	small
61509	69142	1360	Оренбургская область, Переволоцкий район, село Рыжковка	t	small
61508	69141	1359	Оренбургская область, Переволоцкий район, село Родничное, Родничная, 33/2	t	small
61520	69153	1371	Оренбургская область, Переволоцкий район, село Родничий Дол, улица Школьная, 3	f	medium
61492	69125	1343	Оренбургская область, Переволоцкий район, село Радовка, Молодежная, 18	t	small
61502	69135	1353	Оренбургская область, Переволоцкий район, село Пустошь-Адамовка, Центральная, 12	t	small
61512	69145	1363	Оренбургская область, Переволоцкий район, село Претория, Парковая, 2/1а	f	large
61531	69164	1382	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Советская, 21	f	large
61526	69159	1377	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Пионерская, 92	f	medium
61527	69160	1378	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Молодежная, 29	f	medium
61532	69165	1383	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Лениская, 119	f	large
61530	69163	1381	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Ленинская, 85	f	large
61529	69162	1380	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Ленинская, 61	f	medium
61533	69166	1384	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Космическая, 16	f	large
61528	69161	1379	Оренбургская область, Переволоцкий район, поселок Переволоцкий, Западная, 7	f	large
61510	69143	1361	Оренбургская область, Переволоцкий район, село Мамалаевка, Клубная, 2/2	f	medium
61517	69150	1368	Оренбургская область, Переволоцкий район, село Кутлумбетово, Уран, 1	f	small
61515	69148	1366	Оренбургская область, Переволоцкий район, село Кунакбай, Солнечная, 18а	t	small
61507	69140	1358	Оренбургская область, Переволоцкий район, село Кубанка, Пионерская, 92	f	medium
61521	69154	1372	Оренбургская область, Переволоцкий район, село Краснополье, Набережная, 3	t	small
61503	69136	1354	Оренбургская область, Переволоцкий район, село Кичкас, Ленинская, 21	f	medium
61500	69133	1351	Оренбургская область, Переволоцкий район, село Кариновка, Центральная, 2	f	small
61511	69144	1362	Оренбургская область, Переволоцкий район, село Капитоновка, Школьная, 17/4	f	small
61514	69147	1365	Оренбургская область, Переволоцкий район, село Камышевка, Раздольная, 1б	t	small
61498	69131	1349	Оренбургская область, Переволоцкий район, село Зубочистка Первая, Восточная, 9б	f	medium
61499	69132	1350	Оренбургская область, Переволоцкий район, село Зубочистка Вторая, Центральная, 13	f	medium
61496	69129	1347	Оренбургская область, Переволоцкий район, село Донецкое, Советская,  55	f	medium
61505	69138	1356	Оренбургская область, Переволоцкий район, село Долиновка, Центральная, 34	t	small
61504	69137	1355	Оренбургская область, Переволоцкий район, село Габдрафиково, Школьная, 1б	f	small
61518	69151	1369	Оренбургская область, Переволоцкий район, село Алмала, Школьная, 7	t	small
61519	69152	1370	Оренбургская область, Переволоцкий район, село Алисово, Союзная, 35	t	small
61491	69124	1342	Оренбургская область, Переволоцкий район, село Адамовка, Школьная, 2	f	small
61489	69122	1340	Оренбургская область, Переволоцкий район, село Абрамовка, Школьная, 1	f	small
67805	69084	1297	Оренбургская область, Первомайский район, село Шапошниково, Молодежная, 20	t	medium
61483	69116	1333	Оренбургская область, Первомайский район, село Фурманов, Рабочая, 18	t	medium
61455	69092	1305	республика Удмуртская, Сарапульский район, село Уральский	t	medium
61461	69094	1311	Оренбургская область, Первомайский район, село Ударный, Школьная, 15	t	small
61484	69117	1334	Оренбургская область, Первомайский район, село Тюльпан, 10, Микрорайон	t	small
61444	69081	1294	Оренбургская область, Первомайский район, село Теплое, Кооперативная, 6	t	small
61470	69103	1320	Оренбургская область, Первомайский район, село Степнянка, Гагарина, 2а	t	small
60446	68191	282	Оренбургская область, Первомайский район, село Советское, Валерия Карпова, 29	f	medium
61469	69102	1319	Оренбургская область, Первомайский район, село Соболево, Комсомольская, 6	f	medium
61303	68967	1153	Оренбургская область, Первомайский район, село Сергиевка, Центральная, 88/1	f	small
61485	69118	1335	Оренбургская область, Первомайский район, село Сергиевка, Первоцилинников, 4	f	small
61488	69121	1338	Оренбургская область, Первомайский район, село Революционный, Школьная, 10	t	medium
61476	69109	1326	Оренбургская область, Первомайский район, село Пономарев, Строительная, 16	t	small
61472	69105	1322	Московская область, Королев, микрорайон Первомайский	f	large
61473	69106	1323	Оренбургская область, Первомайский район, село Первомайский, Нефтяников, 5	t	large
61474	69107	1324	Оренбургская область, Первомайский район, село Первомайский, Гагарина, 10Б	f	large
61449	69086	1299	Оренбургская область, Первомайский район, село Озерное, Центральная, 25а	f	medium
61486	69119	1336	Оренбургская область, Первомайский район, село Новая Стройка, Рязанская, 41а	t	small
61487	69120	1337	Оренбургская область, Первомайский район, село Мирошкино, Центральная, 31	t	medium
61451	69088	1301	Оренбургская область, Первомайский район, село Малый Зайкин, Клубная, 8	f	medium
61477	69110	1327	Оренбургская область, Первомайский район, село Маевка, Школьная, 5а	f	small
61463	69096	1313	Оренбургская область, Первомайский район, село Лящев, Степная, 1	t	small
61467	69100	1317	Оренбургская область, Первомайский район, село Лесопитомник, Набережная, 3	f	small
61464	69097	1314	Оренбургская область, Первомайский район, село Ленинский, Школьная, 12а	t	medium
67806	69089	1302	Оренбургская область, Первомайский район, село Курлин, Молодежная, 1	t	small
61445	69082	1295	Оренбургская область, Первомайский район, село Красное, Ленина, 51	f	medium
61446	69083	1296	Оренбургская область, Первомайский район, село Каменное, Школьная, 7	f	small
61465	69098	1315	Оренбургская область, Первомайский район, село Зори, Набережная, 8а	t	small
61462	69095	1312	Краснодарский край, Белореченский район, поселок Дружный	t	small
61457	68911	1307	Оренбургская область, Первомайский район, село Ветелки, Школьная, 3\\1	t	small
61448	69085	1298	Оренбургская область, Первомайский район, село Вербовый Сырт, Наумова, 8	t	small
61453	69090	1303	Оренбургская область, Первомайский район, село Большой Зайкин, Школьная, 10	t	small
61460	69093	1310	Оренбургская область, Первомайский район, село Большепрудный, Центральная, 26	f	small
61480	69113	1330	Оренбургская область, Первомайский район, село Башкировка, Заречная, 9а	t	small
61403	69045	1253	Оренбургская область, Орск городской округ, село Ора, Центральная, 1А	f	small
61368	69022	1218	Оренбургская область, Орск городской округ, село Джанаталап	f	large
67799	68955	1141	Оренбургская область, Оренбургский район, село Яровой, Школьная, 14	f	small
61306	68970	1156	Оренбургская область, Оренбургский район, поселок Юный, Мира, 2А	f	large
61325	68989	1175	Оренбургская область, Оренбургский район, село Экспериментальный, Лесная, 1	f	medium
61324	68988	1174	Оренбургская область, Оренбургский район, село Экспериментальный, Культурная, 1	f	medium
67797	68953	1139	Оренбургская область, Оренбургский район, село Чулошников, Центральная, 23	f	small
61278	68942	1128	Оренбургская область, Оренбургский район, село Чкалов, Ленина, 44	f	large
61295	68959	1145	Оренбургская область, Оренбургский район, село Чебеньки, Школьная, 7	f	large
61294	68958	1144	Оренбургская область, Оренбургский район, село Чебеньки, Мало-Элеваторная, 4	f	medium
61296	68960	1146	Оренбургская область, Оренбургский район, село Чебеньки, 8 Марта, 10	f	large
61301	68965	1151	Оренбургская область, Оренбургский район, село Струково, Просторная, 1	f	small
61328	68992	1178	Оренбургская область, Оренбургский район, село Старица, Центральная, 2	f	medium
61326	68990	1176	Оренбургская область, Оренбургский район, село Светлогорка, Центральная, 12	t	small
61145	68841	992	Оренбургская область, Оренбургский район, село Самородово, Школьная, 34	f	large
61280	68944	1130	Воронежская область, Аннинский район, поселок Пугачевский	f	medium
67798	68954	1140	Оренбургская область, Оренбургский район, село Приуральский, Центральная, 23	f	medium
61322	68986	1172	Ярославская область, Ярославль, поселок Первомайский, 10	f	large
60211	67956	27	Оренбургская область, Оренбургский район, поселок Первомайский, Центральная, 12	f	small
61321	68985	1171	Оренбургская область, Оренбургский район, поселок Первомайский, Березина, 1	f	large
61323	68987	1173	Оренбургская область, Оренбургский район, поселок Первомайский, Воронова, 26	f	medium
61281	68945	1131	Оренбургская область, Оренбургский район, село Паника, Молодежная, 1	f	small
61575	69208	1426	Оренбургская область, Оренбургский район, село Никольское, 1	f	large
61316	68980	1166	Оренбургская область, Оренбургский район, село Нижняя Павловка, Советская, 60	f	large
61318	68982	1168	Оренбургская область, Оренбургский район, село Нижняя Павловка, Коммунальная, 6	f	medium
61317	68981	1167	Оренбургская область, Оренбургский район, село Нижняя Павловка, 50 лет Октября, 1В	f	large
61287	68951	1137	Оренбургская область, Оренбургский район, село Нежинка, Куйбышева, 43	f	large
61286	68950	1136	Оренбургская область, Оренбургский район, село Нежинка, Куйбышева, 47Б	f	large
61366	69020	1216	Оренбургская область, Оренбургский район, село Мирный Путь, школа	f	small
61293	68957	1143	Оренбургская область, Оренбургский район, село Мирный Путь, Школьная, 11	t	small
61276	68940	1125	Оренбургская область, Оренбургский район, село Караванный, Советская, 8	f	large
61288	68952	1138	Оренбургская область, Оренбургский район, село Каменноозерное, Центральная, 16	f	small
61307	68971	1157	Оренбургская область, Оренбургский район, село Зубаревка	f	medium
61282	68946	1132	Оренбургская область, Оренбургский район, село Джеланды, Прудная, 6	f	small
61319	68983	1169	Оренбургская область, Оренбургский район, село Дедуровка, Рабочая, 6	f	large
61228	68899	1075	Оренбургская область, Оренбургский район, село Городище, Больничная, 2	f	large
61305	68969	1155	Оренбургская область, Оренбургский район, поселок Горный, переулок Тупой, 1	f	medium
61292	68956	1142	Оренбургская область, Оренбургский район, село Вязовка, Новая, 25	f	small
61297	68961	1147	Оренбургская область, Оренбургский район, село Былинный, Молодежная, 9	f	small
61308	68972	1158	Оренбургская область, Оренбургский район, село Бродецкое, переулок Школьный, 3	f	medium
61279	68943	1129	Оренбургская область, Оренбургский район, село Благословенка, Центральная, 14	f	medium
61277	68941	1126	Оренбургская область, Оренбургский район, село Береговой, Береговая, 45	f	small
61298	68962	1148	Оренбургская область, Оренбургский район, село Бакалка, Молодежная, 4	t	small
61285	68949	1135	Челябинская область, Челябинск, поселок Аэропорт	f	small
61392	69040	1242	Оренбургская область, Оренбургская область, Орск, Новосибирская, 227	f	large
61391	69040	1241	Оренбургская область, Оренбургская область, Орск, Новосибирская, 227	f	large
61062	68777	909	Оренбургская область, Октябрьский район, село Шестимирский, Гагарина, 1	t	small
61060	68775	907	Оренбургская область, Октябрьский район, село Успенка, Советская, 80	f	small
61066	68781	913	Оренбургская область, Октябрьский район, село Уранбаш, Больничная, 5	f	medium
61046	68761	893	Оренбургская область, Октябрьский район, село Салмыш, Набережная, 10	f	small
61061	68776	908	Оренбургская область, Октябрьский район, село Российский, переулок Солнечный, 16	f	medium
61065	68780	912	Оренбургская область, Октябрьский район, село Портнов, Придорожная, 2	t	small
61375	69026	1225	Оренбургская область, Октябрьский район, Орск, Ленина, 41	f	large
61374	69026	1224	Оренбургская область, Октябрьский район, Орск, Ленина, 41	f	large
61035	68751	882	Оренбургская область, Октябрьский район, село Октябрьское, Центральный, 17	f	medium
67754	69301	1521	Оренбургская область, Октябрьский район, село Октябрьское, Молодежная, 24а	f	small
61987	69602	1846	Оренбургская область, Октябрьский район, село Октябрьское, Луначарского, 43	f	medium
61033	68749	880	Оренбургская область, Октябрьский район, село Октябрьское, Дедовская, 43	f	medium
61050	68765	897	Оренбургская область, Октябрьский район, село Новотроицкое, Луговая, 8	f	small
61038	68753	885	Оренбургская область, Октябрьский район, село Новоникитино, Школьная, 4	f	medium
61036	68752	883	Оренбургская область, Октябрьский район, село Новобиккулово, Новобиккуловская, 21/3	t	small
61051	68766	898	Оренбургская область, Октябрьский район, село Нижний Гумбет, Центральная, 112-А	f	medium
61037	68718	884	Оренбургская область, Октябрьский район, село Междугорный, Школьная, 1	f	small
61047	68762	894	Оренбургская область, Октябрьский район, село Марьевка, Школьная, 2	f	medium
61054	68769	901	Оренбургская область, Октябрьский район, село Кузьминовка, Школьная, 8-А	f	small
61040	68755	887	Оренбургская область, Октябрьский район, село Краснооктябрьский, Интернатская, 11-А	f	medium
61064	68779	911	Оренбургская область, Октябрьский район, село Комиссарово, Центральная, 48	f	small
61048	68763	895	Оренбургская область, Октябрьский район, село Каменка, Центральная, 70	f	small
61573	69206	1424	Оренбургская область, Октябрьский район, село Каменка, Садовая, 1	f	small
61044	68759	891	Оренбургская область, Октябрьский район, село Имангулово 2-е, Школьная, 3	f	medium
61045	68760	892	Оренбургская область, Октябрьский район, село Имангулово 1-е, Центральная, 19	f	small
61041	68756	888	Оренбургская область, Октябрьский район, село Зеленый Дол, Центральная, 39	f	small
67794	68757	889	Оренбургская область, Октябрьский район, село Взгорье, Майская, 4а	f	small
61053	68768	900	Оренбургская область, Октябрьский район, село Верхний Гумбет, Центральная, 18-А	f	small
60274	68019	98	Приморский край, Партизанский район, село Васильевка	f	small
61063	68778	910	Оренбургская область, Октябрьский район, село Васильевка, Школьная, 1	f	medium
61058	68773	905	Оренбургская область, Октябрьский район, село Буланово, Гагарина, 11	f	large
61043	68758	890	Оренбургская область, Октябрьский район, село Броды, Новая, 1-А	f	small
61049	68764	896	Оренбургская область, Октябрьский район, село Биккулово, Школьная, 10	f	small
61059	68774	906	Оренбургская область, Октябрьский район, село Белозерка, Школьная, 1	f	small
61068	68783	915	Оренбургская область, Октябрьский район, село Анатольевка, Центральная, 30	t	small
67789	68741	869	Оренбургская область, Новотроицк городской округ, село Хабарное	f	large
67788	68740	868	Оренбургская область, Новотроицк городской округ, село Пригорное	f	medium
67792	68744	872	республика Удмуртская, Кизнерский район, село Новоникольск	f	small
67790	68742	870	Оренбургская область, Новотроицк городской округ, поселок Аккермановка	f	large
60963	68698	809	Оренбургская область, Новосергиевский район, село Ясногорский, Парковая, 17	t	large
60929	68664	775	Оренбургская область, Новосергиевский район, село Черепаново, Пушкина, 7	t	small
60974	68709	820	Оренбургская область, Новосергиевский район, село Хуторка	f	small
60965	68700	811	Оренбургская область, Новосергиевский район, село Хлебовка, Лесная, 15	t	small
60976	68711	822	Оренбургская область, Новосергиевский район, село Сузаново, Советская, 4	f	medium
60959	68694	805	Оренбургская область, Новосергиевский район, село Судьбодаровка, Советская, 33А	f	medium
60932	68667	778	Оренбургская область, Новосергиевский район, село Старая Белогорка, Кооперативная, 54	f	medium
60967	68702	813	Оренбургская область, Новосергиевский район, село Среднеуранский, Школьная, 8	f	medium
60945	68680	791	Оренбургская область, Новосергиевский район, село Рыбкино, Чапаева, 12	f	medium
60931	68666	777	Оренбургская область, Новосергиевский район, село Родниковое Озеро, Луговая, 32 	t	small
60940	68675	786	Оренбургская область, Новосергиевский район, село Ржавка, Центральная, 3А	t	small
60956	68691	802	Оренбургская область, Новосергиевский район, село Приуранный, Советская, 1	t	small
60964	68699	810	Оренбургская область, Новосергиевский район, село Привольный, Заречная, 13	f	small
60948	68683	794	Оренбургская область, Новосергиевский район, село Покровка, Красноармейская, 21	f	medium
60947	68682	793	Оренбургская область, Новосергиевский район, село Покровка, Кооперативная, 12	f	medium
60950	68685	796	Оренбургская область, Новосергиевский район, село Платовка, Совхозная, 22	f	medium
60922	68657	768	Оренбургская область, Новосергиевский район, поселок Новосергиевка, Проспект Калинина, 101	f	large
67786	68648	759	Оренбургская область, Новоорский район, село Тасбулак, Центральная, 15	f	small
60924	68659	770	Оренбургская область, Новосергиевский район, поселок Новосергиевка, Мичурина, 1	f	large
60921	68656	767	Оренбургская область, Новосергиевский район, поселок Новосергиевка, Маяковского, 2	f	large
60923	68658	769	Оренбургская область, Новосергиевский район, поселок Новосергиевка, Красногвардейская, 1	f	large
60925	68660	771	Оренбургская область, Новосергиевский район, поселок Новосергиевка, Карла Маркса, 17Б	f	large
60926	68661	772	Оренбургская область, Новосергиевский район, поселок Новосергиевка, Горького, 72	f	large
60934	68669	780	Оренбургская область, Новосергиевский район, село Новородниковка, Дружбы, 5	f	small
60935	68670	781	Оренбургская область, Новосергиевский район, село Новокинделька, переулок Тупой, 7	f	small
60957	68692	803	Оренбургская область, Новосергиевский район, село Нижний Кунакбай, Центральная, 15А	t	small
60970	68705	816	Оренбургская область, Новосергиевский район, село Нестеровка, Грейдерная, 1	f	medium
60939	68674	785	Оренбургская область, Новосергиевский район, село Мустаево, Школьная, 5	f	medium
60955	68690	801	Оренбургская область, Новосергиевский район, село Мрясово, Центральная, 38	t	small
60975	68710	821	Оренбургская область, Новосергиевский район, село Малахово, Речная, 16	t	small
60928	68663	774	Оренбургская область, Новосергиевский район, село Лебяжка, Советская, 27	t	small
67787	68671	782	Оренбургская область, Новосергиевский район, село Лапаз, Правительственная, 3	f	small
60962	68697	808	Оренбургская область, Новосергиевский район, село Кутушево, Степная, 4	f	small
60942	68677	788	Оренбургская область, Новосергиевский район, село Кулагино, Центральная, 19	f	medium
60954	68689	800	Оренбургская область, Новосергиевский район, село Кувай, переулок Клубный, 4	f	small
60973	68708	819	Оренбургская область, Новосергиевский район, село Красная Поляна, Садовая, 24	f	small
60946	68681	792	Оренбургская область, Новосергиевский район, село Козловка, Новая, 1А	t	small
67718	69186	1404	Оренбургская область, Новосергиевский район, село Ключевка, Центральная, 35	f	small
60960	68695	806	Оренбургская область, Новосергиевский район, село Камышка, Мира, 16Б	t	small
60938	68673	784	Оренбургская область, Новосергиевский район, село Измайловка, Школьная, 13	t	small
60927	68662	773	Оренбургская область, Новосергиевский район, село Землянка, Советская, 8А	f	small
60941	68676	787	Оренбургская область, Новосергиевский район, село Дедово, Солнечная, 11	t	small
60969	68704	815	Оренбургская область, Новосергиевский район, село Губовский, Школьная, 17	t	small
60953	68688	799	Оренбургская область, Новосергиевский район, село Горный, Школьная, 6	f	small
60937	68672	783	Оренбургская область, Новосергиевский район, село Герасимовка, Победы, 2А	f	medium
60944	68679	790	Оренбургская область, Новосергиевский район, село Волостновка, Ленина, 3А	t	small
60951	68686	797	Оренбургская область, Новосергиевский район, село Верхняя Платовка, Луговая, 2А	f	small
60933	68668	779	Оренбургская область, Новосергиевский район, село Варшавка, Центральная, 19	f	small
60966	68701	812	Оренбургская область, Новосергиевский район, село Берестовка, Старая, 13	t	small
60930	68665	776	Оренбургская область, Новосергиевский район, село Барабановка, Центральная, 156	f	medium
60968	68703	814	Оренбургская область, Новосергиевский район, село Балейка	t	small
60958	68693	804	Оренбургская область, Новосергиевский район, село Ахмерово, Подгорная, 8А	t	small
60952	68687	798	Оренбургская область, Новосергиевский район, село Александровка, Центральная,  4	f	small
60901	68636	747	Оренбургская область, Новоорский район, ст. Новоорск, Мостовая, 10	f	medium
67783	68639	750	Оренбургская область, Новоорский район, село Энергетик, ПУ-3514 	f	large
60906	68641	752	Оренбургская область, Новоорский район, село Энергетик, Правдухина, 72	f	large
60905	68640	751	Оренбургская область, Новоорский район, село Энергетик, Пионерская, 16	f	large
67785	68646	757	Оренбургская область, Новоорский район, село Чилекта, Школьная, 22	f	small
60914	68649	760	Оренбургская область, Новоорский район, село Чапаевка, Школьная, 6	f	medium
60898	68633	744	Оренбургская область, Новоорский район, Центральные Усадьбы Совхоза Новоорский, Ленина, 38	f	large
61441	69078	1291	Оренбургская область, Новоорский район, село Ударник, Школьная, 10	f	medium
60908	68643	754	Оренбургская область, Новоорский район, село Скалистое, Центральная, 1 А	f	small
60900	68635	746	Оренбургская область, Новоорский район, поселок Новоорск, микрорайон Водстроя, 2, Новоорский поссовет	f	large
60919	68654	765	Оренбургская область, Новоорский район, поселок Новоорск, Школьная, 9, Приреченский с/с	f	large
60899	68634	745	Оренбургская область, Новоорский район, поселок Новоорск, Ленина, 14	f	large
60902	68637	748	Оренбургская область, Новоорский район, поселок Новоорск, Клецова, 14 А	f	medium
61858	69484	1714	Оренбургская область, Новоорский район, село Молодежный, Комсомольская, 20	f	small
60917	68652	763	Оренбургская область, Новоорский район, село Можаровка, Школьный переулок, 4	f	small
60916	68651	762	Оренбургская область, Новоорский район, село Лужки, Степная, 8	f	small
60918	68653	764	Оренбургская область, Новоорский район, село Кумак, Садовая, 42	f	large
61443	69080	1293	Оренбургская область, Новоорский район, село Крыловка, Центральная, 1	f	medium
60920	68655	766	Оренбургская область, Новоорский район, село Красноуральск, Севастопольская, 1	f	small
60912	68647	758	Оренбургская область, Новоорский район, село Караганка, Ленина, 20	f	medium
60909	68644	755	Оренбургская область, Новоорский район, село Заморское, Школьная, 9 А	f	small
67784	68645	756	Оренбургская область, Новоорский район, село Добровольское, Комсомольская, 21	t	medium
60903	68638	749	Оренбургская область, Новоорский район, поселок Гранитный, Школьная, 15	f	medium
60915	68650	761	Оренбургская область, Новоорский район, село Горьковское, Шушаева, 2, Горьковский с/с	t	medium
60907	68642	753	Оренбургская область, Новоорский район, село Будамша, Костюхина, 1Б	f	medium
60896	68631	742	Оренбургская область, Медногорск городской округ, село Ракитянка, Горняков, 2А	f	large
60873	68614	719	Оренбургская область, Матвеевский район, село Тимошкино, Школьная, 3	f	small
67772	68602	704	Оренбургская область, Матвеевский район, село Староякупово, Центральная, 6	f	small
60864	68588	710	Оренбургская область, Матвеевский район, село Старокутлумбетово, Центральная, 38	f	medium
60857	68601	703	Россия, Оренбургская область, Матвеевский район, село Староаширово	f	medium
60866	68607	712	Оренбургская область, Матвеевский район, село Сарай-Гир, Советская, 100	f	medium
60867	68608	713	Оренбургская область, Матвеевский район, село Сарай-Гир, Советская, 110	f	medium
67778	68612	717	Оренбургская область, Матвеевский район, село Садак, Школьная, 1а	t	small
60868	68609	714	Оренбургская область, Матвеевский район, село Пролетаровка, Набережная, 33	t	small
60495	68240	331	Оренбургская область, Матвеевский район, село Покровка, Зеленая, 40-а	t	small
67776	68495	711	Оренбургская область, Матвеевский район, село Новоузели, Садовая, 1в	f	small
60862	68606	708	Оренбургская область, Матвеевский район, село Новожедрино, Школьная, 1 а	f	small
67774	68604	706	Оренбургская область, Матвеевский район, село Новожедрино, Центральная, 36	t	small
67773	68603	705	Оренбургская область, Матвеевский район, село Новоаширово, Верхняя, 1	t	small
60850	68594	696	Оренбургская область, Матвеевский район, село Нижненовокутлумбетьево, Речная, 8	t	small
67775	68605	707	Оренбургская область, Матвеевский район, село Натальино, Степная, 20	t	small
67771	68600	702	Оренбургская область, Матвеевский район, село Матвеевка, Комсомольская, 17	f	large
60855	68599	701	Оренбургская область, Матвеевский район, село Матвеевка, Комсомольская, 17а	f	large
60849	68593	695	Оренбургская область, Матвеевский район, село Кульчум, Молодежная, 5а	f	small
67708	68598	700	Оренбургская область, Матвеевский район, село Кузькино	f	small
67706	68595	697	Оренбургская область, Матвеевский район, село Кинельский, Парковая, 5	f	medium
60943	68678	789	Оренбургская область, Матвеевский район, село Кинельский, Луговая, 19	t	small
67705	68591	693	Оренбургская область, Матвеевский район, село Емельяновка, Ковешникова, 1	f	small
60852	68596	698	Оренбургская область, Матвеевский район, село Высотный, Школьная, 3	t	small
60848	68592	694	Оренбургская область, Матвеевский район, село Верхненовокутлумбетьево, Центральная, 21б	f	small
60874	68615	720	Оренбургская область, Матвеевский район, село Борискино, Молодежная, 2а	f	small
67707	68597	699	Оренбургская область, Матвеевский район, село Африка, Центральная, 11	t	small
67780	68616	721	Оренбургская область, Матвеевский район, село Азаматово, Центральная, 31	t	small
61358	69013	1208	Оренбургская область, Ленинский район, Оренбург, Никельщиков проспект, 25	f	large
60832	68574	677	Оренбургская область, Курманаевский район, село Ферапонтовка, Зеленая, 21	f	small
60833	68576	678	Оренбургская область, Курманаевский район, село Федоровка, Крестьянская, 26	f	small
60826	68568	667	Оренбургская область, Курманаевский район, село Суриково, 8 Марта, 13-б	f	small
60825	68567	666	Оренбургская область, Курманаевский район, село Скворцовка, Набережная, 62а	f	small
60841	68584	687	Оренбургская область, Курманаевский район, село Сергеевка, Дорожная, 15	f	small
60827	68569	669	Оренбургская область, Курманаевский район, село Семеновка, Школьная, 24	f	small
60830	68572	675	Оренбургская область, Курманаевский район, село Ромашкино, Дорожная, 15	f	large
60822	68564	663	Оренбургская область, Курманаевский район, село Родионовка, Мира, 47	f	small
60840	68583	686	Оренбургская область, Курманаевский район, село Покровка, Советская, 13	f	small
61947	69573	1805	Московская область, Клинский район, деревня Петровка	t	small
60819	68561	660	Оренбургская область, Курманаевский район, село Петровка	t	small
60824	68566	665	Оренбургская область, Курманаевский район, село Озерки, Центральная, 17-б	f	small
60659	68400	495	Оренбургская область, Курманаевский район, село Озерки, Парковая, 11	t	medium
60836	68579	681	Оренбургская область, Курманаевский район, село Михайловка, Ленина, 14	f	medium
60838	68581	683	Оренбургская область, Курманаевский район, село Лаврентьевка, Победы, 11	f	small
60823	68565	664	Оренбургская область, Курманаевский район, село Лабазы, Зорина, 12	f	large
60821	68563	662	Оренбургская область, Курманаевский район, село Кутуши, Крестьянская, 36	f	medium
60817	68559	658	Оренбургская область, Курманаевский район, Курманаевка, Строительная, 14	f	large
60837	68580	682	Оренбургская область, Курманаевский район, село Кретовка, Мира, 14-а	f	small
60834	68577	679	Оренбургская область, Курманаевский район, село Краснояровка, Набережная, 20	f	small
60839	68582	684	Оренбургская область, Курманаевский район, село Костино, Центральная, 7	f	medium
60820	68562	661	Оренбургская область, Курманаевский район, село Кандауровка, пл.Свердлова, 1	f	medium
60844	68587	690	Оренбургская область, Курманаевский район, село Ефимовка, Первомайская, 9	f	large
60846	68590	692	Оренбургская область, Курманаевский район, село Егорьевка, Восточная, 30а	f	small
60842	68585	688	Оренбургская область, Курманаевский район, село Грачевка, Пролетарская, 2	f	small
67704	68586	689	Оренбургская область, Курманаевский район, село Гаршино, Крестьянская, 20	f	small
60828	68570	670	Оренбургская область, Курманаевский район, село Волжский	f	small
60829	68571	671	Оренбургская область, Курманаевский район, село Волжский, Центральная, 5	f	medium
60845	68589	691	Оренбургская область, Курманаевский район, село Васильевка, Мутного, 12-а	f	medium
61910	69536	1768	Оренбургская область, Курманаевский район, село Бобровка, Школьная, 9	t	small
60835	68578	680	Оренбургская область, Курманаевский район, село Байгоровка, Советская, 33	f	small
60831	68573	676	Оренбургская область, Курманаевский район, село Андреевка, Ленинская, 19	f	medium
60761	68502	599	Оренбургская область, Кувандыкский район, ст. Дубиновка, Рабочая, 16	f	medium
60801	68542	642	Оренбургская область, Кувандыкский район, село Ялнайр, Школьная, 20а	f	small
60758	68499	596	Оренбургская область, Кувандыкский район, село Юлгутла, Юлаева, 39	f	small
60782	68523	622	Оренбургская область, Кувандыкский район, село Чураево, Школьная, 9	f	small
60764	68505	602	Оренбургская область, Кувандыкский район, село Чеботарево, Центральная, 5а	f	small
60771	68512	609	Оренбургская область, Кувандыкский район, село Урал, переулок Школьный, 2	f	medium
60794	68535	635	Оренбургская область, Кувандыкский район, село Сарбай, Центральная, 19	t	small
60802	68543	643	Оренбургская область, Кувандыкский район, село Сара, Элеваторная, 9	f	medium
60800	68541	641	Оренбургская область, Кувандыкский район, село Сара, Центральная, 12а	f	medium
61972	69591	1831	Оренбургская область, Кувандыкский район, село Рысаево, Центральная, 8	f	small
60760	68501	598	Оренбургская область, Кувандыкский район, село Русское Канчерово, Школьная, 12	f	small
60772	68513	610	Оренбургская область, Кувандыкский район, село Ровный, Ровненская, 18/2	t	small
60471	68216	307	Оренбургская область, Кувандыкский район, село Рамазаново, Центральная, 13	t	small
60789	68530	630	Оренбургская область, Кувандыкский район, село Подлесная, Центральная, 14а	f	small
60770	68511	608	Оренбургская область, Кувандыкский район, село Подгорное, Школьная, 12	f	small
60776	68517	615	Оренбургская область, Кувандыкский район, село Пехотное, Центральная, 12	t	small
60786	68527	626	Оренбургская область, Кувандыкский район, село Первомайск, Центральная, 48а	f	small
60790	68531	631	Оренбургская область, Кувандыкский район, село Оноприеновка, Мира, 3а	f	medium
60774	68515	613	Оренбургская область, Кувандыкский район, село Новоуральск, Советская, 2б	f	medium
60793	68534	634	Оренбургская область, Кувандыкский район, село Новосимбирка, Мира, 3	f	medium
60796	68537	637	Оренбургская область, Кувандыкский район, село Новосаринский, Школьная, 2	f	small
60762	68503	600	Оренбургская область, Кувандыкский район, Центральная, 8, здание магазина ИП Галиуллин Х.Н.	f	small
60785	68526	625	Оренбургская область, Кувандыкский район, село Новосакмарск, Новосамарская, 24	f	small
60787	68528	627	Оренбургская область, Кувандыкский район, село Новопокровка, Молодёжная, 1	f	small
60792	68533	633	Оренбургская область, Кувандыкский район, село Новоказанка, Горная, 4а	f	small
60783	68524	623	Оренбургская область, Кувандыкский район, село Новая Ракитянка	f	small
60779	68520	619	Оренбургская область, Кувандыкский район, село Никольск, Молодёжная, 11	f	small
60763	68504	601	Оренбургская область, Кувандыкский район, село Мухамедьярово, Советская, 24	f	medium
60777	68518	617	Оренбургская область, Кувандыкский район, село Маячный	f	medium
60797	68538	638	Оренбургская область, Кувандыкский район, село Мазово, Центральная, 10/3	t	small
60799	68540	640	Оренбургская область, Кувандыкский район, село Лесной, Центральная, 17	t	small
60766	68507	604	Оренбургская область, Кувандыкский район, село Куруил, Клубная, 16	f	medium
60769	68510	607	Оренбургская область, Кувандыкский район, село Краснощеково, Школьная, 6	f	small
60778	68519	618	Оренбургская область, Кувандыкский район, село Краснознаменка, Центральная, 6	f	small
61974	69593	1833	Оренбургская область, Кувандыкский район, село Кидрясово, Молодежная, 4	t	small
60788	68529	629	Оренбургская область, Кувандыкский район, село Карагай-Покровка, Школьная, 1	f	small
60767	68508	605	Оренбургская область, Кувандыкский район, село Кайракла, Кайраклинская, 61	f	small
60768	68509	606	Оренбургская область, Кувандыкский район, село Ильинка, Новая, 1	f	medium
61973	69592	1832	Оренбургская область, Кувандыкский район, село Идельбаево, Салавата Юлаева, 2	f	small
60781	68522	621	Оренбургская область, Кувандыкский район, село Ибрагимово, Советская, 11	f	medium
60757	68498	595	Оренбургская область, Кувандыкский район, село Зиянчурино, Садовый переулок, 4	f	large
60775	68516	614	Оренбургская область, Кувандыкский район, село Залужье	f	small
60798	68539	639	Оренбургская область, Кувандыкский район, село Вьюжный, Центральная, 10	f	small
60791	68532	632	Оренбургская область, Кувандыкский район, село Верхненазаргулово, Школьная, 1	f	small
60784	68525	624	Оренбургская область, Кувандыкский район, село Васильевка, Луговая, 9/2	f	small
60897	68632	743	Оренбургская область, Кувандыкский район, село Блявтамак, Совхозная, 46	f	medium
61975	69594	1834	Оренбургская область, Кувандыкский район, село Блява, Центральная, 52	f	small
60759	68500	597	Оренбургская область, Кувандыкский район, село Башкирское Канчерово, Советская, 10а	f	small
60765	68506	603	Оренбургская область, Кувандыкский район, село Барангулово, Школьная, 1а	f	small
60780	68521	620	Оренбургская область, Кувандыкский район, село Адаево, Дорожная, 1/1	f	small
60749	68489	587	Оренбургская область, Красногвардейский район, село Яшкино, площадь Мира, 9	f	medium
60728	68468	566	Оренбургская область, Красногвардейский район, деревня Яиково, Школьная, 16	t	small
60745	68485	583	Оренбургская область, Красногвардейский район, село Юринский, Южная, 9	t	small
60744	68484	582	Оренбургская область, Красногвардейский район, село Юлты, Школьная, 39а	t	small
60717	68457	555	Оренбургская область, Красногвардейский район, село Утеево, Школьная, 1а	t	small
60720	68460	558	Оренбургская область, Красногвардейский район, село Токское, пер.Школьный, 1	f	medium
60752	68492	590	Оренбургская область, Красногвардейский район, село Степной, Степная, 2	t	small
61799	69429	1655	Оренбургская область, Красногвардейский район, село Степной, Нижняя, 7	f	medium
60741	68481	579	Оренбургская область, Красногвардейский район, село Староюлдашево, Победы, 84	t	small
60712	68452	550	Оренбургская область, Красногвардейский район, село Староникольское, Советская, 34	f	small
60743	68483	581	Оренбургская область, Красногвардейский район, село Старобогдановка, Центральная, 32	t	small
60723	68463	561	Оренбургская область, Красногвардейский район, село Среднеильясово, Дружбы, 41	t	small
60754	68494	592	Оренбургская область, Красногвардейский район, село Свердловский, Школьная, 3	f	medium
60742	68482	580	Оренбургская область, Красногвардейский район, село Пушкинский, Пушкинская, 53а	f	medium
60725	68465	563	Оренбургская область, Красногвардейский район, село Пролетарка, Школьная, 21 	f	small
60715	68455	553	Оренбургская область, Красногвардейский район, село Преображенка, Молодежная, 2	f	small
60603	68345	439	Оренбургская область, Красногвардейский район, село Покровка, Новая, 2а	t	small
60738	68478	576	Оренбургская область, Красногвардейский район, село Подольск, Центральная, 118	f	medium
60730	68470	568	Оренбургская область, Красногвардейский район, село Плешаново, Советская, 2	f	large
60732	68472	570	Оренбургская область, Красногвардейский район, село Плешаново, Ленина, 121	f	medium
60731	68471	569	Оренбургская область, Красногвардейский район, село Плешаново, Дружбы, 44	f	large
61935	69561	1793	Оренбургская область, Красногвардейский район, село Новоюласка, Дружбы, 7	f	small
60751	68491	589	Оренбургская область, Красногвардейский район, село Новопетровка, Зеленая, 49	f	small
60724	68464	562	Оренбургская область, Красногвардейский район, село Нижнекристалка, Центральная, 47	f	medium
60722	68462	560	Оренбургская область, Красногвардейский район, село Нижнеильясово, Мира, 34	t	small
60726	68466	564	Оренбургская область, Красногвардейский район, село Нижнебахтиярово, Центральная, 54	f	small
60735	68475	573	Оренбургская область, Красногвардейский район, село Малоюлдашево, Центральная, 16а	t	small
60739	68479	577	Оренбургская область, Красногвардейский район, село Луговск, Центральная, 138	f	medium
60736	68476	574	Оренбургская область, Красногвардейский район, село Кутерля, Мира, 49	f	small
60713	68453	551	Оренбургская область, Красногвардейский район, село Кристалка, Центральная, 5	t	small
60740	68480	578	Оренбургская область, Красногвардейский район, село Красиково, Пушкинская, 19	t	small
60734	68474	572	Брянская область, Жирятинский район, поселок Клинок	t	small
60746	68486	584	Оренбургская область, Красногвардейский район, поселок Кинзелька, Школьная, 7	f	medium
60737	68477	575	Оренбургская область, Красногвардейский район, село Калтан, Садовая, 54	f	small
60727	68467	565	Оренбургская область, Красногвардейский район, село Ишалка, Центральная, 49	f	small
60425	68170	260	Оренбургская область, Красногвардейский район, село Ивановка, Береговая, 21	f	small
67702	68459	557	Оренбургская область, Красногвардейский район, село Ивановка,  Школьная, 1	f	small
60716	68456	554	Оренбургская область, Красногвардейский район, село Ибряево, Чулпан, 59	t	small
61658	69292	1512	Оренбургская область, Красногвардейский район, село Ибряево, Восточная, 1б	t	small
60714	68454	552	Оренбургская область, Красногвардейский район, село Залесово, Школьная, 10	f	small
60753	68493	591	Оренбургская область, Красногвардейский район, село Ермаково, Орская, 10/2	t	small
67703	68461	559	Оренбургская область, Красногвардейский район, село Долинск, Советская, 70	f	small
60748	68488	586	Оренбургская область, Красногвардейский район, село Вознесенка, Школьная, 3	f	small
60733	68473	571	Оренбургская область, Красногвардейский район, село Верхнеильясово, М.Бурангулова, 11	t	small
67779	68613	718	Оренбургская область, Красногвардейский район, село Александровка, Касьянова, 54	t	small
60677	68417	513	Оренбургская область, Кваркенский район, поселок разрушенный Майский, Школьная, 17	f	small
60708	68448	546	Оренбургская область, Кваркенский район, село Чапаевка, Речная, 17	f	small
67700	68444	541	Оренбургская область, Кваркенский район, село Уртазым, Центральная, 1	f	medium
60699	68439	536	Оренбургская область, Кваркенский район, село Уральское, Школьная, 9	f	small
60707	68447	545	Оренбургская область, Кваркенский район, село Таналык, Кооперативный, 4	f	medium
60692	68432	529	Оренбургская область, Кваркенский район, село Свободное, Центральная, 25	t	small
60696	68436	533	Оренбургская область, Кваркенский район, село Просторы, Школьный, 2	f	medium
60709	68449	547	Оренбургская область, Кваркенский район, село Приморск, Школьная, 3	f	medium
60703	68443	540	Оренбургская область, Кваркенский район, село Покровка, Школьная, 13	f	small
61922	69548	1780	Оренбургская область, Кваркенский район, село Покровка, Рыжкова, 6	t	small
61642	69275	1494	Оренбургская область, Кваркенский район, село Первомайский, пер.Школьный, 3	f	medium
60695	68435	532	Оренбургская область, Кваркенский район, село Новопотоцкое, Школьная, 2	f	small
60691	68431	528	Оренбургская область, Кваркенский район, село Новооренбург, Новая, 15	f	small
60701	68441	538	республика Башкортостан, Архангельский район, село Максим Горький	f	small
60684	68424	520	Оренбургская область, Кваркенский район, село Лесная Поляна, Школьная, 18	f	small
60694	68434	531	Кировская область, Кильмезский район, село Кульма	f	small
60688	68428	524	Оренбургская область, Кваркенский район, село Красный Огородник, Степная, 7	f	small
60681	68421	517	Оренбургская область, Кваркенский район, поселок Красноярский, Газовая, 6А	f	medium
60680	68420	516	Оренбургская область, Кваркенский район, поселок Красноярский, Вокзальная, 4	f	large
60693	68433	530	Оренбургская область, Кваркенский район, село Коминтерн, пер. Школьный, 1	f	medium
60683	68423	519	Оренбургская область, Кваркенский район, село Кировск, им.Кирова, 15	f	medium
60676	68416	512	Оренбургская область, Кваркенский район, село Кваркено, Центральная, 27	f	large
60675	68415	511	Оренбургская область, Кваркенский район, село Кваркено, Центральная, 2	f	large
60689	68429	525	Оренбургская область, Кваркенский район, село Зеленодольск, Центральная, 11	f	small
60682	68422	518	Оренбургская область, Кваркенский район, село Екатериновка, Октябрьская, 1А	f	small
60711	68451	549	Оренбургская область, Кваркенский район, село Горный Ерик, Речная, 7	f	small
60710	68450	548	Оренбургская область, Кваркенский район, село Гоголевка, Центральная, 10	f	small
60697	68437	534	Оренбургская область, Кваркенский район, село Бриент, Советская, 15	f	medium
60700	68440	537	Оренбургская область, Кваркенский район, село Большевик, Школьная, 6	t	small
60685	68425	521	Оренбургская область, Кваркенский район, село Болотовск, Лесная, 61	f	small
60705	68445	542	Оренбургская область, Кваркенский район, село Березовка, Верхняя, 12	f	small
60687	68427	523	Оренбургская область, Кваркенский район, село Белоозерный, Раздольная, 11А	f	small
67815	69175	1393	Оренбургская область, Кваркенский район, село Алексеевка, Центральная, 48	f	small
60349	68094	183	Оренбургская область, Кваркенский район, село Алексеевка, Советская, 73	f	small
60686	68426	522	Оренбургская область, Кваркенский район, село Аландское, Школьная, 3	f	medium
67698	68419	515	Оренбургская область, Кваркенский район, Айдырлинский, Школьная, 3	f	medium
60673	68414	509	Оренбургская область, Илекский район, село Яман, Октябрьская, 2Б	f	medium
60650	68391	486	Оренбургская область, Илекский район, село Шутово, Центральная, 4	t	small
60666	68407	502	Оренбургская область, Илекский район, село Студеное, Бокова, 113	f	large
60662	68403	498	Оренбургская область, Илекский район, село Степное, Дом Шадатовой	t	small
60671	68412	507	Оренбургская область, Илекский район, село Сладков(Сладково), Школьная, 42А	f	medium
60672	68413	508	Оренбургская область, Илекский район, село Рассыпная, Мира, 42	f	medium
60669	68410	505	Оренбургская область, Илекский район, село Раздольное, Школьная, 12	t	small
60660	68401	496	Оренбургская область, Илекский район, село Привольное, площадь Победы, 5	f	large
60652	68393	488	Оренбургская область, Илекский район, село Подстепки, Московская, 8 А	t	small
60654	68395	490	Оренбургская область, Илекский район, село Нижнеозерное, Советская, 38	t	large
60670	68411	506	Оренбургская область, Илекский район, село Мухраново, Советская, 60	f	medium
55337	62375	2040	Нижегородская область, Саров	f	large
60668	68409	504	Оренбургская область, Илекский район, село Крестовка, Центральная, 58	t	small
60651	68392	487	Оренбургская область, Илекский район, село Красный Яр, Ленина, 25	f	medium
61124	68822	971	Оренбургская область, Илекский район, село Краснохолм, Советская, 68	f	large
61122	68820	969	Оренбургская область, Илекский район, село Краснохолм, России, 82	f	large
61123	68821	970	Оренбургская область, Илекский район, село Краснохолм, Липова, 9	f	large
60653	68394	489	Оренбургская область, Илекский район, село Кардаилово, Советская, 57	f	large
67699	68442	539	Оренбургская область, Илекский район, село Кардаилово, Кузнецова, 16	t	small
60674	68389	510	Оренбургская область, Илекский район, село Илек, Токмаковская, 14, А	f	large
60648	68389	484	Оренбургская область, Илекский район, село Илек, Токмаковская, 14, А	f	large
60647	68388	483	Оренбургская область, Илекский район, село Илек, Октябрьская, 25	f	large
60649	68390	485	Оренбургская область, Илекский район, село Илек, Пионерская, 49	f	large
60665	68406	501	Оренбургская область, Илекский район, село Затонное, Советская, 55	f	medium
60667	68408	503	Оренбургская область, Илекский район, село Заживный, Центральная, 7	t	small
60655	68396	491	Оренбургская область, Илекский район, село Димитровский, Школьная, 1	f	large
60639	68380	475	Оренбургская область, Домбаровский район, село Ушкатты, переулок Ярославский, 1а	f	small
61968	69588	1827	Оренбургская область, Домбаровский район, село Тюльпанный, Центральная, 2	t	small
60634	68375	470	республика Татарстан, Лаишевский район, село Соколовка	t	small
60637	68378	473	Оренбургская область, Домбаровский район, село Прибрежный, Центральная, 1а	f	small
60636	68377	472	Оренбургская область, Домбаровский район, село Курмансай, переулок Торговый, 8а	f	small
60625	68366	461	Оренбургская область, Домбаровский район, село Кужанберля, Первая, 4-1	t	small
60630	68371	466	Оренбургская область, Домбаровский район, село Красночабанский, Новая, 3а	t	medium
60620	68361	456	Оренбургская область, Домбаровский район, село Корсуньский, Школьная, 1	f	small
60631	68372	467	Оренбургская область, Домбаровский район, село Кинжебулак, Школьная, 2	t	small
60638	68379	474	Оренбургская область, Домбаровский район, село Караганда, Конторская, 7	f	small
60624	68365	460	Оренбургская область, Домбаровский район, село Камсак, Школьная, 19-2	f	small
67697	68362	457	Оренбургская область, Домбаровский район, село Истемис, Набережная, 11	t	small
61478	69111	1328	Оренбургская область, Домбаровский район, село Зарево, Школьная, 1	f	small
60635	68376	471	республика Башкортостан, Чишминский район, село Екатеринославка	t	small
60642	68383	478	Оренбургская область, Домбаровский район, поселок Домбаровский, торговая площадь, 2	f	large
60641	68382	477	Оренбургская область, Домбаровский район, поселок Домбаровский, Стахановская, 169	f	medium
60640	68381	476	Оренбургская область, Домбаровский район, поселок Домбаровский, Рабочая, 15	f	large
60645	68386	481	Оренбургская область, Домбаровский район, поселок Домбаровский, Куйбышева, 10	f	large
60643	68384	479	Оренбургская область, Домбаровский район, поселок Домбаровский, Весенняя, 11	f	small
60644	68385	480	Оренбургская область, Домбаровский район, поселок Домбаровский, осипенко, 16	f	medium
60622	68363	458	Оренбургская область, Домбаровский район, село Домбаровка, Школьная, 18	f	medium
60627	68368	463	Оренбургская область, Домбаровский район, поселок Голубой Факел, Газовиков, 10	f	medium
60626	68367	462	Оренбургская область, Домбаровский район, село Бояровка, Центральная, 12	t	small
60628	68369	464	Оренбургская область, Домбаровский район, село Богоявленка, Набережная, 41	f	small
60629	68370	465	Оренбургская область, Домбаровский район, село Богоявленка, Молодёжная, 36	f	small
60619	68360	455	Оренбургская область, Домбаровский район, Ащибутак, Клубная, 16	f	large
60623	68364	459	Оренбургская область, Домбаровский район, село Архангельское, Школьная, 11	t	small
60632	68373	468	Оренбургская область, Домбаровский район, село Аккудук, Молодёжная, 4	t	small
61079	68792	926	Оренбургская область, п. Каргала, Советская, 12	f	large
61986	69601	1845	Оренбургская область, Грачевский район, село Якутино, Старохуторская, 14а	t	small
60614	68356	450	Оренбургская область, Грачевский район, село Ягодное, Центральная, 1	f	small
60616	68358	452	Оренбургская область, Грачевский район, село Урицкое, Степная, 40	t	small
60612	68354	448	Оренбургская область, Грачевский район, село Таллы, Майская, 12	f	medium
60610	68352	446	Оренбургская область, Грачевский район, село Старояшкино, Строительная, 2а	f	small
60615	68357	451	Оренбургская область, Грачевский район, село Саблино, Центральная, 27	t	small
60608	68350	444	Оренбургская область, Грачевский район, село Русское Игнашкино, Первомайская, 5	f	medium
60613	68355	449	Оренбургская область, Грачевский район, село Революционер, Молодежная, 22	t	small
60269	68015	93	Оренбургская область, Грачевский район, село Покровка, Ветеранов, 2	f	small
60606	68348	442	Оренбургская область, Грачевский район, село Победа, Сеннореченская, 78	f	small
60604	68346	440	Оренбургская область, Грачевский район, село Петро-Херсонец,  Мира, 1	f	medium
60601	68343	437	Оренбургская область, Грачевский район, село Новоникольское, Советская, 20а	f	small
60611	68353	447	Оренбургская область, Грачевский район, село Малояшкино, Школьная, 18	t	small
61775	69405	1631	Оренбургская область, Грачевский район, село Луговое, Зеленая, 1А	f	small
60600	68342	436	Оренбургская область, Грачевский район, село Ключи, переулок Центральный, 3	f	medium
60602	68344	438	Оренбургская область, Грачевский район, село Каликино, Озерная, 28б	t	small
60605	68347	441	Оренбургская область, Грачевский район, село Ждамировка, Шевченко, 6	t	small
60599	68341	435	Оренбургская область, Грачевский район, село Ероховка	f	small
60598	68340	434	Оренбургская область, Грачевский район, село Грачевка, Юбилейная, 25	f	large
60597	68339	433	Оренбургская область, Грачевский район, село Грачевка, Юбилейная, 9	f	large
60596	68338	432	Оренбургская область, Грачевский район, село Грачевка,  Советская,  7	f	large
61475	69108	1325	Оренбургская область, Грачевский район, поселок Володарский, Володарского, 2б	f	large
60595	68337	431	Оренбургская область, Грачевский район, село Верхигнашкино, Советская, 8	f	medium
60594	68336	430	Оренбургская область, Грачевский район, село Александровка,  Центральная, 54	f	medium
60609	68351	445	Оренбургская область, Грачевский район, село Абрышкино, Новая, 21	f	small
67694	68321	414	Оренбургская область, Гайский район, село Хмелевка, Центральная, 27	f	small
60568	68311	404	Оренбургская область, Гайский район, село Халилово, Ленина, 6	f	small
60556	68300	392	Оренбургская область, Гайский район, село Уральск, Нижняя, 57	t	small
60573	68316	409	Оренбургская область, Гайский район, село Узембаево, Молодежная, 8, кв.2	t	small
60554	68298	390	Оренбургская область, Гайский район, село Терекла, Центральная, 6а	t	small
60570	68313	406	Оренбургская область, Гайский район, село Старохалилово, Дальняя, 1	t	small
60561	68305	397	Оренбургская область, Гайский район, село Северовка, улица Молодежная, 1а	f	small
61302	68966	1152	Оренбургская область, Гайский район, село Репино, Центральная, 17	f	small
60560	68304	396	Оренбургская область, Гайский район, село Репино, Центральная, 22	f	medium
60562	68306	398	Оренбургская область, Гайский район, село Поповка, Школьная, 15	t	small
67691	68303	395	Оренбургская область, Гайский район, село Пласковский, улица Молодежная, 8	t	small
60567	54124	403	Оренбургская область, Гайский район, село Писаревка, Степная, 13	t	small
67791	68743	871	Оренбургская область, Гайский район, поселок Новорудный	f	large
60576	68319	412	Оренбургская область, Гайский район, село Новопетропавловка, Школьная, 15	t	small
60565	68309	401	Оренбургская область, Гайский район, село Новониколаевка, Школьная, 10	f	medium
67693	68320	413	Оренбургская область, Гайский район, село Новокиевка, Школьная, 7	t	small
67803	69018	1214	Оренбургская область, Гайский район, село Новоказачий, Клуб поселка Новоказачий	f	small
60569	68312	405	Оренбургская область, Гайский район, село Нововоронежский, Новая, 2	f	small
60555	68299	391	Оренбургская область, Гайский район, село Новоактюбинск, Центральная, 49 	t	small
60571	68314	407	Оренбургская область, Гайский район, село Нарбулатово, Школьная, 5а	t	small
60574	68317	410	Оренбургская область, Гайский район, село Лылов, Новостройка, 20	f	small
60557	68301	393	Оренбургская область, Гайский район, село Колпакское, Школьная, 15	f	medium
60563	68307	399	Оренбургская область, Гайский район, село Камейкино, Центральная, 10	f	small
60564	68308	400	Оренбургская область, Гайский район, село Ишкинино, Школьная, 22	t	small
67690	68296	388	Оренбургская область, Гайский район, село Ириклинский	f	medium
60575	68318	411	Оренбургская область, Гайский район, село Ижберда, Новостройка, 24	f	small
67793	68745	873	Оренбургская область, Гайский район, село Губерля	t	medium
67695	68322	415	Оренбургская область, Гайский район, село Губерля, Уральская, 20	t	small
60572	68315	408	Оренбургская область, Гайский район, село Гайнулино, Школьная, 7	t	small
60553	68297	389	Оренбургская область, Гайский район, село Вишневое, Школьная, 2а	t	small
60580	68323	416	Оренбургская область, Гайский район, село Белошапка, Центральная, 1	t	small
60558	68302	394	Оренбургская область, Гайский район, село Банное, Школьная, 20	t	small
60496	68241	332	Оренбургская область, Бузулукский район, село Шахматовка, Школьная, 1	f	medium
60510	68255	346	Оренбургская область, Бузулукский район, село Тупиковка, Центральная, 76	f	medium
60515	68260	351	Оренбургская область, Бузулукский район, село Троицкое, Садовая, 48	f	medium
60513	68258	349	Оренбургская область, Бузулукский район, село Твердилово, Пушкина, 2	f	small
60511	68256	347	Оренбургская область, Бузулукский район, село Сухоречка, Центральная, 3	f	large
60502	68247	338	Оренбургская область, Бузулукский район, село Старая Тепловка, Молодежная, 7	f	small
60518	68263	354	Оренбургская область, Бузулукский район, село Проскурино, Центральная, 16	f	medium
60505	68250	341	Оренбургская область, Бузулукский район, село Подколки, Центральная, 1	f	medium
60499	68244	335	Оренбургская область, Бузулукский район, село Перевозинка, Центральная, 9	f	small
60473	68218	309	Оренбургская область, Бузулукский район, село Партизанский, Центральная, 5	f	small
60503	68248	339	Оренбургская область, Бузулукский район, село Палимовка, Советская, 1	f	large
60501	68246	337	Оренбургская область, Бузулукский район, село Новая Тепловка, Нижний конец, 1	f	small
60506	68251	342	Оренбургская область, Бузулукский район, село Новая Казанка, Центральная, 20а	f	small
60504	68249	340	Оренбургская область, Бузулукский район, село Новая Елшанка, Южная, 11	t	small
60486	68231	322	Оренбургская область, Бузулукский район, село Никифоровка, переулок Школьный, 7	f	small
60476	68221	312	Оренбургская область, Бузулукский район, село Нижняя Вязовка, Центральная, 1/3	f	small
60497	68242	333	Оренбургская область, Бузулукский район, село Могутово, Молодежная, 22	f	medium
60494	68239	330	Оренбургская область, Бузулукский район, село Лисья Поляна, Гагарина, 29	f	medium
60493	68238	329	Оренбургская область, Бузулукский район, село Липовка, Молодежная, 1-а	f	medium
60488	68233	324	Краснодарский край, Каневский район, поселок Красногвардеец	f	medium
60490	68235	326	Оренбургская область, Бузулукский район, село Красногвардеец, Советская, 9	f	medium
60487	68232	323	Оренбургская область, Бузулукский район, село Красногвардеец, Октябрьская, 20	t	large
60491	68236	327	Оренбургская область, Бузулукский район, село Красная Слободка, Школьная, 47	f	small
60517	68262	353	Оренбургская область, Бузулукский район, поселок Колтубановский, пер.Школьный, 10	f	large
60516	68261	352	Оренбургская область, Бузулукский район, поселок Колтубановский, Советская, 13	f	large
60484	68229	320	Оренбургская область, Бузулукский район, поселок Колтубановский, Заречная, 47	f	medium
60489	68234	325	Оренбургская область, Бузулукский район, село Кировский, Садовая, 3	f	small
60485	68230	321	Оренбургская область, Бузулукский район, село Каменная Сарма, Центральная, 17-е	f	small
60508	68253	344	Оренбургская область, Бузулукский район, село Искра, Школьная, 5	f	medium
60483	68228	319	Оренбургская область, Бузулукский район, село Жилинка, Речная, 13	f	medium
60482	68227	318	Оренбургская область, Бузулукский район, село Елшанка 1-я, Советская, 14	f	large
60480	68225	316	Самарская область, Безенчукский район, село Елховка	f	small
60500	68245	336	Оренбургская область, Бузулукский район, село Дмитриевка, Школьная, 18	f	small
60478	68223	314	Оренбургская область, Бузулукский район, село Державино, Советская, 15	f	small
60477	68222	313	Оренбургская область, Бузулукский район, село Державино, Советская, 43	f	small
60481	68226	317	Оренбургская область, Бузулукский район, село Воронцовка, Молодежная, 2	t	small
60474	68219	310	Оренбургская область, Бузулукский район, село Верхняя Вязовка, Калинина, 22-в	f	medium
60492	68237	328	Оренбургская область, Бузулукский район, село Булгаково, Заречная, 24, кв.2	t	small
60512	68257	348	Оренбургская область, Бузулукский район, село Бузулукское Лесничество, Лесная, 28	t	small
60514	68259	350	Оренбургская область, Бузулукский район, село Березовка, Центральная, 12-б	f	small
60472	68217	308	Оренбургская область, Бузулукский район, село Алдаркино, Садовая, 35	f	medium
60541	68285	377	Оренбургская область, Бузулук городской округ, Бузулук, Школьная, 56	f	large
61962	69583	1821	Оренбургская область, Бугурусланский район, село Шестайкино, Центральная, 47 А	t	small
60428	68173	263	Оренбургская область, Бугурусланский район, село Турхановка, Центральная, 38	f	small
60431	68176	266	Оренбургская область, Бугурусланский район, село Старые Узелки, Заречная, 18 А	f	small
60433	68178	268	Оренбургская область, Бугурусланский район, село Старое Тюрино, Центральная, 31	f	small
60444	68189	280	Оренбургская область, Бугурусланский район, село Сапожкино	f	small
60411	68156	246	Оренбургская область, Бугурусланский район, село Саловка, Центральная, 19 А	f	small
60414	68159	249	Оренбургская область, Бугурусланский район, село Савруша, Центральная, 12	t	small
60443	68188	279	Оренбургская область, Бугурусланский район, село Русская Бокла, Новая, 21	f	small
60426	68171	261	Оренбургская область, Бугурусланский район, село Резвый, Школьная, 4А	f	small
60435	68180	270	Оренбургская область, Бугурусланский район, село Рабочий, Степная, 22	t	small
60441	68186	277	Оренбургская область, Бугурусланский район, село Пронькино, Центральная, 5 А	f	small
60440	68185	276	Оренбургская область, Бугурусланский район, село Поникла, Центральная, 61	f	medium
60438	68183	273	Оренбургская область, Бугурусланский район, село Полибино, Дорожная, 1	f	small
61969	68179	1828	Оренбургская область, Бугурусланский район, село Пилюгино, Чапаевская, 52	f	medium
60434	68179	269	Оренбургская область, Бугурусланский район, село Пилюгино, Чапаевская, 52	f	medium
60412	68157	247	Оренбургская область, Бугурусланский район, село Передовка, улица Центральная, 41	f	small
60678	68418	514	Калужская область, Калуга, Октябрьский округ, улица Центральная, 13	f	small
60421	68166	256	Оренбургская область, Бугурусланский район, село Нуштайкино, Школьная, 23	f	small
60432	68177	267	Оренбургская область, Бугурусланский район, село Нойкино	f	small
60430	68175	265	Оренбургская область, Бугурусланский район, село Нижнепавлушкино, Советская, 67	t	small
60442	68187	278	Оренбургская область, Бугурусланский район, село Мордовский Бугуруслан, Школьная, 40	f	small
60427	68172	262	Оренбургская область, Бугурусланский район, село Михайловка, Транспортная, 50	f	medium
61963	69584	1822	Оренбургская область, Бугурусланский район, село Михайловка, Рабочая, 25	f	medium
61964	69585	1823	Оренбургская область, Бугурусланский район, село Михайловка, Полевая, 1 В	f	medium
60409	68154	244	Оренбургская область, Бугурусланский район, село Михайловка, Калинина Н.С, 32	f	small
60418	68163	253	Оренбургская область, Бугурусланский район, село Красноярка, Центральная, 14	f	small
60424	68169	259	Оренбургская область, Бугурусланский район, село Коровино, Почтовая, 3	f	small
60423	68168	258	Оренбургская область, Бугурусланский район, село Коптяжево, Широкая, 2 А	f	small
60422	68167	257	Оренбургская область, Бугурусланский район, село Кокошеевка, Школьная, 28	f	small
60417	68162	252	Оренбургская область, Бугурусланский район, село Козловка, Дорожная, 10	f	small
60420	68165	255	Оренбургская область, Бугурусланский район, село Кирюшкино, Молодежная, 17	f	medium
60419	68164	254	Оренбургская область, Бугурусланский район, село Ивановка, Центральная, 13 	f	small
60445	68190	281	Оренбургская область, Бугурусланский район, село Земсков	t	small
60437	68182	272	Оренбургская область, Бугурусланский район, село Затоновский, пер. Озерный, 2	f	small
60462	68207	298	Оренбургская область, Бугурусланский район, село Затон, Центральная, 6	f	small
60416	68161	251	Оренбургская область, Бугурусланский район, село Завьяловка, Привокзальная, 4	f	medium
60436	68181	271	Оренбургская область, Бугурусланский район, село Жуково, Фурманова, 13	t	small
60415	68160	250	Оренбургская область, Бугурусланский район, село Елатомка, Советская, 1	f	medium
60408	68153	243	Оренбургская область, Бугурусланский район, село Григорьевка, Заречная, 1	t	small
60447	68192	283	Оренбургская область, Бугурусланский район, село Вишневка, Молодежная, 23	f	small
60429	68174	264	Оренбургская область, Бугурусланский район, село Верхнепавлушкино, Совхозная, 23 А	t	small
60410	68155	245	Оренбургская область, Бугурусланский район, село Благодаровка, Чапаевская, 19 А	f	medium
60407	68152	242	Оренбургская область, Бугурусланский район, село Бестужевка, Центральная, 26	f	small
60406	68151	241	Оренбургская область, Бугурусланский район, село Баймаково, Придорожная, 3	f	medium
60405	68150	240	Оренбургская область, Бугурусланский район, село Алексеевка, Московская, 41 а	f	small
60388	68133	222	Оренбургская область, Беляевский район, село Цветочное, Школьная, 12	f	small
60379	68124	213	Оренбургская область, Беляевский район, село Херсоновка, Школьная, 21	f	small
60384	68129	218	Оренбургская область, Беляевский район, село Старицкое, Ленинская, 6б	f	small
60387	68132	221	Оренбургская область, Беляевский район, село Сазан, Центральная,  3	f	small
60394	68139	228	Оренбургская область, Беляевский район, село Новоорловка, Центральная, 14	f	small
60391	68136	225	Оренбургская область, Беляевский район, село Междуречье, Школьная, 14	f	small
60393	68138	227	Оренбургская область, Беляевский район, село Листвянка, Школьная, 9	f	small
60381	68126	215	Оренбургская область, Беляевский район, село Крючковка, Центральная, 25	f	large
60395	68140	229	Оренбургская область, Беляевский район, село Красноуральск, Школьная, 11	f	small
60383	68128	217	Оренбургская область, Беляевский район, село Ключевка, Советская, 21	f	medium
60389	68134	223	Оренбургская область, Беляевский район, село Карагач, Комсомольская, 11	f	medium
60377	68122	211	Оренбургская область, Беляевский район, село Жанаталап, Центральная, 2а	f	small
60401	68146	235	Оренбургская область, Беляевский район, поселок Дубенский, Первомайская, 16	f	small
60729	68469	567	Оренбургская область, Беляевский район, село Донское, Советская, 103	f	large
60396	68141	230	Оренбургская область, Беляевский район, село Донское, Казачья, 16	f	small
60378	68123	212	Оренбургская область, Беляевский район, село Днепровка, Южная, 10	f	medium
60400	68145	234	Оренбургская область, Беляевский район, село Гирьял, Победы, 30	f	small
60397	68142	231	Оренбургская область, Беляевский район, село Верхнеозерное, Форштадская, 2	f	small
60390	68135	224	Оренбургская область, Беляевский район, село Васильевка, Центральная, 34	f	small
60386	68131	220	Оренбургская область, Беляевский район, село Буртинский, Спортивная, 17	f	medium
60392	68137	226	Оренбургская область, Беляевский район, село Бурлыкский, Центральная, 8	f	medium
60380	68125	214	Оренбургская область, Беляевский район, село Буранчи, Центральная, 9	f	small
67689	68130	219	Оренбургская область, Беляевский район, село Блюменталь, Центральная, 34	f	small
60402	68147	236	Оренбургская область, Беляевский район, село Беляевка, Ленинская, 42в	f	large
61233	68904	1080	Оренбургская область, Беляевский район, село Беляевка, Комсомольская, 37	f	large
60403	68148	237	Оренбургская область, Беляевский район, село Беляевка, Банковская, 9	f	large
60398	68143	232	Оренбургская область, Беляевский район, село Белогорский, Школьлная, 6	f	small
60399	68144	233	Оренбургская область, Беляевский район, село Алабайтал, Советская, 15	f	small
60376	68121	210	Оренбургская область, Асекеевский район, село Яковлевка, Центральная, 4	f	small
60375	68120	209	Оренбургская область, Асекеевский район, село Юдинка, Киселева, 40	f	small
60372	68117	206	Оренбургская область, Асекеевский район, село Шамассовка, Центральная, 8 Б	t	small
60374	68119	208	Оренбургская область, Асекеевский район, село Чкаловский, переулок Парковый, 2	f	large
60361	68106	195	Оренбургская область, Асекеевский район, Филипповка, Привокзальная, 4	f	small
60373	68118	207	Оренбургская область, Асекеевский район, село Троицкое, Садовая, 5 А	f	medium
67688	68110	199	Оренбургская область, Асекеевский район, село Старосултангулово, Центральная, 36а	f	small
60371	68116	205	Оренбургская область, Асекеевский район, село Старомукменево, Центральная, 64 Б	f	medium
60368	68113	202	Оренбургская область, Асекеевский район, село Старокульшарипово, Центральная, 107	f	medium
67686	68093	182	Оренбургская область, Асекеевский район, Ст.Асекевео, Пришкольная, 1	f	small
60706	68446	543	Оренбургская область, Асекеевский район, село Сосновка, Школьная, 25	t	small
60363	68108	197	Оренбургская область, Асекеевский район, село Самаркино, Центральная, 34	t	small
60367	68112	201	Оренбургская область, Асекеевский район, село Рязановка, Центральная, 19	f	medium
61057	68772	904	Оренбургская область, Асекеевский район, село Петровка, Народная, 80/1	t	small
60364	68109	198	Оренбургская область, Асекеевский район, село Новосултангулово, Центральная, 78/10	f	medium
60369	68114	203	Оренбургская область, Асекеевский район, село Новокульшарипово, Новая, 32	t	small
60370	68115	204	Оренбургская область, Асекеевский район, село Мулланур, Центральная, 66	t	small
60362	68107	196	Оренбургская область, Асекеевский район, село Мочегай, Школьная, 28	f	small
60360	68105	194	Оренбургская область, Асекеевский район, село Мартыновка, Центральная, 49	f	small
60358	68103	192	Оренбургская область, Асекеевский район, село Лекаревка, Садовая, 9 А	f	small
60357	68102	191	Оренбургская область, Асекеевский район, село Кутлуево, Центральная, 4	f	medium
60366	68111	200	Оренбургская область, Асекеевский район, село Курбанай, Центральная, 16	t	small
60356	68101	190	Оренбургская область, Асекеевский район, село Красногорский, Садовая, 11	f	medium
60355	68100	189	Оренбургская область, Асекеевский район, село Кисла, Молодежная, 8	f	small
61901	69527	1759	Оренбургская область, Асекеевский район, село Казанка, Центральная, 97	f	small
60359	68104	193	Оренбургская область, Асекеевский район, село Золотой Родник, Зеленая, 388	f	small
60354	68099	188	Оренбургская область, Асекеевский район, село Заглядино, Партизанская, 9	f	large
60353	68098	187	Оренбургская область, Асекеевский район, село Думино, Набережная, 17	f	small
61052	68767	899	Оренбургская область, Асекеевский район, село Воскресеновка, Центральная, 12-А	f	small
60352	68097	186	Оренбургская область, Асекеевский район, село Воздвиженка, Центральная, 6	f	small
67684	68089	178	Оренбургская область, Асекеевский район, село Брянчаниново, Набережная, 16а	t	small
67687	68096	185	Оренбургская область, Асекеевский район, село Баландино, Золотухина, 63 а	f	medium
67685	68092	181	Оренбургская область, Асекеевский район, село Асекеево, Советская, 16А	f	large
60346	68091	180	Оренбургская область, Асекеевский район, село Асекеево, Набережная, 13 А	f	large
60350	68095	184	Оренбургская область, Асекеевский район, село Аксютино, Школьная, 7	f	small
60303	68048	136	Оренбургская область, Александровский район, село Яфарово, Советская, 44	f	small
60304	68049	137	Оренбургская область, Александровский район, село Яфарово, Комсомольская, 19	t	small
60315	68060	148	Оренбургская область, Александровский район, село Якут	t	small
60301	68046	134	Оренбургская область, Александровский район, село Юртаево, Школьная, 12	t	small
60311	68056	144	Оренбургская область, Александровский район, село Южный, Центральная, 3	t	small
60324	68069	157	Оренбургская область, Александровский район, село Шар, Совхозная, 38А	t	small
60309	68054	142	Оренбургская область, Александровский район, село Чебоксарово, Советская, 40	f	small
67715	68066	154	Оренбургская область, Александровский район, село Хортица, Советская, 37	f	medium
60325	68070	158	Оренбургская область, Александровский район, село Федоровка, Октябрьская, 49	t	small
60308	68053	141	Оренбургская область, Александровский район, село Успенка, Советская, 43	t	small
60310	68055	143	Оренбургская область, Александровский район, село Тукай, Школьная, 14а	f	medium
60300	68045	133	Оренбургская область, Александровский район, село Султакай, Советская, 33	f	small
60335	68080	168	Оренбургская область, Александровский район, село Романовский, Центральная, 21	f	small
60322	68067	155	Оренбургская область, Александровский район, село Петровка, Гагарина, 56б	f	medium
61756	69390	1612	Оренбургская область, Александровский район, село Октябрьский, Октябрьская, 24, СДК	f	small
60320	68065	153	Оренбургская область, Александровский район, село Озерка, Центральная, 108	f	small
55336	62374	2039	Нижегородская область, Саров	f	medium
60328	68073	161	Оренбургская область, Александровский район, село Новоспасское, Школьная, 10	f	small
60863	68548	709	Оренбургская область, Александровский район, село Новоспасское, Центральная, 8	f	small
60327	68072	160	Оренбургская область, Александровский район, село Новоникольское, Хуторская, 13	f	small
60306	68051	139	Оренбургская область, Александровский район, село Новоникитино, Пролетарская, 4	f	small
60338	68083	171	Оренбургская область, Александровский район, село Новомихайловка, Новая, 9	f	small
60333	68078	166	Оренбургская область, Александровский район, село Михайловка, переулок Школьный,  2	t	small
60319	68064	152	Оренбургская область, Александровский район, село Мирный, Мира, 8Б	t	small
60330	68075	163	Оренбургская область, Александровский район, село Марксовский	f	medium
60302	68047	135	Оренбургская область, Александровский район, село Майский, Майская, 45	t	small
60314	68059	147	Оренбургская область, Александровский район, село Кутучево, Новая, 16	t	small
67714	68063	151	Оренбургская область, Александровский район, село Курпячево, Центральная, 7	t	small
60317	68062	150	Оренбургская область, Александровский район, село Каяпкулово, Сагита Агиша, 10	t	small
60313	68058	146	Оренбургская область, Александровский район, село Канчерово, Сагита Агиша, 6	t	small
60323	68068	156	Оренбургская область, Александровский район, село Канцеровка, Советская, 58	t	small
60329	68074	162	Оренбургская область, Александровский район, село Каменка, Мира, 68	f	small
60305	68050	138	Оренбургская область, Александровский район, село Каликино, Советская, 3	f	medium
60339	68084	172	Оренбургская область, Александровский район, село Исянгильдино, Советская, 23	f	small
60312	68057	145	Оренбургская область, Александровский район, село Зеленая Роща, Ленина, 19	f	small
60332	68077	165	Оренбургская область, Александровский район, село Загорский, Школьная, 4	f	small
60326	68071	159	Оренбургская область, Александровский район, село Ждановка, Ленина, 17	f	large
60334	68079	167	Оренбургская область, Александровский район, село Добринка, Центральная, 14	f	small
60413	68158	248	Оренбургская область, Александровский район, село Дмитриевка, Центральная, 46	f	small
60331	68076	164	Оренбургская область, Александровский район, село Дмитриевка, Центральная, 10	f	small
60307	68052	140	Оренбургская область, Александровский район, село Дальний, Молодежная, 8	t	small
60316	68061	149	Оренбургская область, Александровский район, село Георгиевка, Школьная, 16	f	small
60336	68081	169	Оренбургская область, Александровский район, село Гавриловка, Советская, 30	t	small
60299	68044	132	Оренбургская область, Александровский район, село Буранный, Буранная, 27	f	small
61300	68964	1150	Оренбургская область, Александровский район, село Архангеловка, Центральная, 81	f	medium
60342	68087	175	Оренбургская область, Александровский район, село Александровка, Эстрадная, 17/1	f	medium
60297	68042	130	Оренбургская область, Александровский район, село Александровка, Мичурина, 51	f	medium
60340	68085	173	Оренбургская область, Александровский район, село Актыново, Советская, 28	t	small
60268	68014	92	Оренбургская область, Акбулакский район, село Шулаксу, дом культуры	f	small
60295	68040	119	Оренбургская область, Акбулакский район, село Шкуновка, Центральная, 6	f	medium
60294	68039	118	Оренбургская область, Акбулакский район, село Шаповаловка, Центральная, 42, школа	f	medium
60292	68037	116	Оренбургская область, Акбулакский район, село Ушкуль, Тамдинская, 2, ФАП	t	small
60293	68038	117	Оренбургская область, Акбулакский район, село Тамдысай, Новая, 3	f	small
60282	68027	106	Оренбургская область, Акбулакский район, село Советское, Центральная, 9	f	medium
61471	69104	1321	Оренбургская область, Акбулакский район, село Советское, Заречная, 4а	f	medium
60289	68034	113	Оренбургская область, Акбулакский район, село Сагарчин, Советская, 1	f	medium
61582	69215	1434	Оренбургская область, Акбулакский район, село Орловка, Центральная, 2	f	small
60288	68033	112	Оренбургская область, Акбулакский район, село Новоуспеновка, Центральная, 1Б	f	small
60286	68031	110	Оренбургская область, Акбулакский район, село Новопавловка, Центральная, 27	f	medium
60278	68023	102	Оренбургская область, Акбулакский район, село Новоодесский, Центральная, 32/1	t	small
60284	68029	108	Оренбургская область, Акбулакский район, село Новогригорьевка, Победы, 39	f	medium
60498	68243	334	Оренбургская область, Акбулакский район, село Новоалександровка, Центральная, 45/1	f	large
60279	68024	103	Оренбургская область, Акбулакский район, село Нагумановка, Нагумановская, 26	f	small
60270	68016	94	Оренбургская область, Акбулакский район, село Меловой Завод, Заводская, 2	f	small
60287	68032	111	Оренбургская область, Акбулакский район, село Межгорный, Школьная, 8А	t	small
60275	68020	99	Оренбургская область, Акбулакский район, село Майдан, Центральная, 16/7	f	small
60277	68022	101	Оренбургская область, Акбулакский район, село Кызылбулак, Биканова, 7	t	small
60267	68013	91	Оренбургская область, Акбулакский район, село Кулаксай, школа 	f	small
60271	68017	95	Оренбургская область, Акбулакский район, село Кужунтай, Центральная, 28	f	small
60290	68035	114	Оренбургская область, Акбулакский район, село Корниловка, Украинская, 6	t	small
60285	68030	109	Оренбургская область, Акбулакский район, село Карповка, Центральная, 8А	f	small
60283	68028	107	Оренбургская область, Акбулакский район, село Карасай, Гайко, 36	f	small
60280	68025	104	Оренбургская область, Акбулакский район, село Каракудук, Семенова, 44	f	small
60273	68018	97	Оренбургская область, Акбулакский район, село Кайракты, Школьная, 4	f	medium
60276	68021	100	Оренбургская область, Акбулакский район, село Веселый Первый, Набережная, 6	f	medium
60281	68026	105	Оренбургская область, Акбулакский район, село Веселый Второй, Центральная, 36	t	small
60291	68036	115	Оренбургская область, Акбулакский район, село Акоба, Абдешева, 1, ФАП	t	small
60264	68010	88	Оренбургская область, Акбулакский район, поселок Акбулак, Терещенко, 32	f	large
60262	68008	86	Оренбургская область, Акбулакский район, поселок Акбулак, Советская, 39, дом культуры	f	large
60263	68009	87	Оренбургская область, Акбулакский район, поселок Акбулак, Оренбургская, 146	f	large
60265	68011	89	Оренбургская область, Акбулакский район, поселок Акбулак, Комсомольская, 20	f	large
60266	68012	90	Оренбургская область, Акбулакский район, поселок Акбулак, Горбунова, 21	f	large
60256	68002	80	Оренбургская область, Адамовский район, с.Бело, Школьная, 13	f	small
60224	67969	48	Оренбургская область, Адамовский район, п.Новоада, Старый, 12	f	small
60242	67987	66	Оренбургская область, Адамовский район, п.Ком, Волгоградская, 10	f	large
60260	68006	84	Оренбургская область, Адамовский район, село Юбилейный, Советская, 13	f	medium
60240	67985	64	Оренбургская область, Адамовский район, село Энбекши, Школьная, 4	f	small
60258	68004	82	Оренбургская область, Адамовский район, поселок Шильда, Садовая, 35а	f	large
60259	68005	83	Оренбургская область, Адамовский район, поселок Шильда, Комсомольская, 19а	f	medium
60251	67996	75	Оренбургская область, Адамовский район, село Совхозный, Мира, 2а	f	medium
60255	68000	79	Оренбургская область, Адамовский район, село Слюдяной, Школьная, 16	f	small
60249	67994	73	Оренбургская область, Адамовский район, село Обильный, Комсомольская, 6	f	medium
60250	67995	74	Оренбургская область, Адамовский район, село Нововинницкий, Школьная, 1	t	small
60234	67979	58	Оренбургская область, Адамовский район, село Нововинницкий, Советская, 28	f	small
60236	67981	60	Оренбургская область, Адамовский район, село Нижняя Кийма, Октябрьская, 18	f	small
60252	67997	76	Оренбургская область, Адамовский район, село Мещеряковский, Советская, 2	f	small
60245	67990	69	Оренбургская область, Адамовский район, село Майский, Советская, 16	f	medium
60228	67973	52	Оренбургская область, Адамовский район, село Красноярск, Советская, 13	f	small
60698	68438	535	Оренбургская область, Адамовский район, село Комсомольский, Школьная, 10	t	small
60233	67978	57	Оренбургская область, Адамовский район, село Каменецк, Школьный, 4	f	small
60231	67976	55	Оренбургская область, Адамовский район, село Каинсай, Островского, 11А	f	small
67713	67989	68	Оренбургская область, Адамовский район, село Заполье	t	small
60239	67984	63	Оренбургская область, Адамовский район, село Елизаветинка, Ленина, 12	f	large
67711	67971	50	Оренбургская область, Адамовский район, село Джусинск, Тюлигенова, 6	f	small
60229	67974	53	Оренбургская область, Адамовский район, село Джасай	f	small
60225	67970	49	Оренбургская область, Адамовский район, село Джарлинский, улица Октябрьская, 1	f	small
60230	67975	54	Оренбургская область, Адамовский район, село Брацлавка, Целинная, 40	f	medium
60241	67986	65	Оренбургская область, Адамовский район, село Баймурат, Школьная, 5	f	small
60227	67972	51	Оренбургская область, Адамовский район, село Аниховка, Ленина, 19	f	medium
60232	67977	56	Оренбургская область, Адамовский район, село Аневка, Советская, 9А	f	small
60257	68003	81	Оренбургская область, Адамовский район, село Андреевка, Советская, 12	f	small
67712	67982	61	Оренбургская область, Адамовский район, поселок Адамовка	f	small
60221	67966	45	Оренбургская область, Адамовский район, поселок Адамовка, Школьная, 1а	f	large
60220	67965	44	Оренбургская область, Адамовский район, поселок Адамовка, Пушкинская, 71	f	large
67710	67968	47	Оренбургская область, Адамовский район, поселок Адамовка, Майская, 119	f	large
60222	67967	46	Оренбургская область, Адамовский район, поселок Адамовка, Майская, 96	f	large
60690	68430	526	Оренбургская область, Абдулинский район, село Черемушки, Черемушки, 10	f	small
60218	67963	34	Оренбургская область, Абдулинский район, село Чеганлы, Тукаевская, 11	f	medium
60217	67962	33	Оренбургская область, Абдулинский район, село Тирис-Усманово, Оренбургская, 24	t	medium
60219	67964	35	Оренбургская область, Абдулинский район, село Степановка 2-я, Садовая, 14	f	small
60216	67961	32	Оренбургская область, Абдулинский район, село Старые Шалты, пер.Школьный, 5	f	medium
67777	68610	715	Оренбургская область, Абдулинский район, село Радовка, Центральная, 31	t	small
60213	67958	29	Оренбургская область, Абдулинский район, село Покровка, Советская, 2 А	f	medium
60202	67947	18	Оренбургская область, Абдулинский район, село Новый Тирис, Коммунистическая, 28	t	small
60210	67955	26	Оренбургская область, Абдулинский район, село Новоякупово, Школьная, 4 Б	f	medium
60196	67941	12	Оренбургская область, Абдулинский район, село Николькино, Центральная, 56	f	small
60209	67954	25	Оренбургская область, Абдулинский район, село Нижний Курмей, Родниковая, 8	f	small
60207	67952	23	Оренбургская область, Абдулинский район, село Малый Сурмет, Садовая, 5	f	small
60205	67950	21	Оренбургская область, Абдулинский район, село Камыш-Садак, Школьная, 2	f	small
60203	67948	19	Оренбургская область, Абдулинский район, село Искра, Молодежная, 2 А	f	medium
60215	67960	31	Оренбургская область, Абдулинский район, село Исайкино, Школьная, 3	f	small
60201	67946	17	Оренбургская область, Абдулинский район, село Зерикла, Центральная, 4	t	small
60199	67944	15	Оренбургская область, Абдулинский район, село Емантаево, Васильевская, 2 А	f	small
60200	67945	16	Оренбургская область, Абдулинский район, село Егорьевка, Молодежная, 1	f	small
60204	67949	20	Оренбургская область, Абдулинский район, село Венера, Совхозная, 6 А	f	medium
60214	67959	30	Оренбургская область, Абдулинский район, село Васькино, Центральная, 7	t	small
60212	67957	28	Оренбургская область, Абдулинский район, село Васильевка, Московская, 11	t	small
60198	67943	14	Оренбургская область, Абдулинский район, село Булатовка, Центральная, 47	t	small
60208	67953	24	Оренбургская область, Абдулинский район, село Большой Сурмет, Школьная, 4	f	small
60197	67942	13	Оренбургская область, Абдулинский район, село Артемьевка, Советская, 38	f	medium
61771	69401	1627	республика Марий Эл, Советский район, село Алексеевка	f	medium
60206	67951	22	Оренбургская область, Абдулинский район, село Авдеевка, Школьна, 4	f	small
60195	67940	11	Оренбургская область, Абдулинский район, село Абдрахманово, Школьная, 5	f	small
55011	62115	1687	Нижегородская область, д.Ближнее Константиново, Полевая, 4, ГОУ НПО Профессиональный лицей №41	f	large
68264	61692	1096	Нижегородская область, поселок Селекционной Станции, Центральная, клуб	f	large
68263	61692	1095	Нижегородская область, поселок Селекционной Станции, Центральная, клуб	f	large
68316	62380	2058	Нижегородская область, город Саров, Ленина, 52	f	large
55353	62378	2056	Нижегородская область, Саров, Казамазова, 5	f	large
55352	62378	2055	Нижегородская область, Саров, Казамазова, 5	f	large
55369	62392	2072	Нижегородская область, Саров	f	large
55359	62384	2062	Нижегородская область, Саров	f	large
55351	62377	2054	Нижегородская область, Саров, проспект Музрукова, 39	f	large
55338	61954	2041	Нижегородская область, Саров, Юности , 11	f	large
55339	61954	2042	Нижегородская область, Саров, Юности , 11	f	large
55348	61580	2051	Нижегородская область, Саров, Юности, 14	f	large
55367	62390	2070	Нижегородская область, Саров, Шверника , 19	f	large
55366	62390	2069	Нижегородская область, Саров, Шверника , 19	f	large
55368	62391	2071	Нижегородская область, Саров, Шверника, 40	f	large
55362	62387	2065	Нижегородская область, Саров, Чапаева, 16	f	large
55335	62373	2038	Нижегородская область, Саров, Павлика Морозова, 11	f	large
55345	61315	2048	Нижегородская область, Саров, Московская , 5	f	large
55344	62330	2047	Нижегородская область, Саров, Московская, 40а	f	large
68317	62385	2063	Нижегородская область, Саров, Ленина, 28	f	large
55340	62111	2043	Нижегородская область, Саров, Курчатова, 29	f	large
55364	62388	2067	Нижегородская область, Саров, Куйбышева, 1	f	large
55363	62388	2066	Нижегородская область, Саров, Куйбышева, 1	f	large
55358	62383	2061	Нижегородская область, Саров, Куйбышева, 25	f	large
55350	62376	2053	Нижегородская область, Саров, Зернова, 64	f	large
55349	61643	2052	Нижегородская область, Саров, Зернова, 58	f	large
55342	62201	2045	Нижегородская область, Саров, Гоголя , 10	f	large
55341	62151	2044	Нижегородская область, Саров, Гоголя, 12	f	large
55343	62151	2046	Нижегородская область, Саров, Гоголя, 12	f	large
55347	61356	2050	Нижегородская область, Саров, Герцена , 5	f	large
55346	61356	2049	Нижегородская область, Саров, Герцена , 5	f	large
55365	62389	2068	Нижегородская область, Саров, Гагарина , 22	f	large
55361	62386	2064	Нижегородская область, Саров, Гагарина, 6	f	large
55357	62382	2060	Нижегородская область, Саров, Александровича, 16а	f	large
55354	62379	2057	Нижегородская область, Саров, Академика Харитона, 17	f	large
55356	62381	2059	Нижегородская область, Саров, Академика Сахарова, 2	f	large
55179	62216	1859	Нижегородская область, Павлово	f	large
55178	62216	1858	Нижегородская область, Павлово	f	large
55177	62215	1857	Нижегородская область, Павлово	f	large
55175	62213	1855	Нижегородская область, Павлово	f	large
55171	62209	1851	Нижегородская область, Павлово, Чкалова, 59	f	large
55161	62202	1841	Нижегородская область, Павлово, Трудовая, 73б	f	large
55165	62205	1845	Нижегородская область, Павлово, Суворова, 4	f	large
55225	62259	1908	Нижегородская область, Павлово, Пионерская, 40	f	large
55186	62222	1866	Нижегородская область, Павлово, Маяковского, 90а	f	large
55185	62222	1865	Нижегородская область, Павлово, Маяковского, 90а	f	large
55176	62214	1856	Нижегородская область, Павлово, Маяковского, 4	f	large
55169	62207	1849	Нижегородская область, Павлово, М. Горького, 23	f	large
55187	62223	1867	Нижегородская область, Павлово, Куйбышева, 45	f	large
55182	62219	1862	Нижегородская область, Павлово, Высокая, 1	f	large
55172	62210	1852	Нижегородская область, Павлово, Аллея Ильича, 53	f	large
68335	62203	1843	Нижегородская область, Павлово, 9-я Северная, 40, МУ СОК Гармония	f	large
68334	62203	1842	Нижегородская область, Павлово, 9-я Северная, 40, МУ СОК Гармония	f	large
55053	62143	1730	Нижегородская область, Нижний Новгород, Советский район	f	large
55010	62114	1686	Нижегородская область, Приокский район, Нижний Новгород, 9, поселок Черепичный, Школа № 48	f	large
54986	62098	1662	Нижегородская область, Нижегородский, Нижний Новгород, санаторий им.ВЦСПС	t	large
54634	61877	1305	Нижегородская область, Нижний Новгород, 17б	f	large
54665	61897	1336	Нижегородская область, Автозаводский район, Нижний Новгород, шоссе Южное, 24г	f	large
54664	61897	1335	Нижегородская область, Автозаводский район, Нижний Новгород, шоссе Южное, 24г	f	large
54663	61897	1334	Нижегородская область, Автозаводский район, Нижний Новгород, шоссе Южное, 24г	f	large
54662	61896	1333	Нижегородская область, Автозаводский район, Нижний Новгород, шоссе Южное, 6а	f	large
54661	61896	1332	Нижегородская область, Автозаводский район, Нижний Новгород, шоссе Южное, 6а	f	large
54674	61900	1345	Нижегородская область, Автозаводский, Нижний Новгород, шоссе Южное, 49а	f	large
54673	61900	1344	Нижегородская область, Автозаводский, Нижний Новгород, шоссе Южное, 49а	f	large
54672	61900	1343	Нижегородская область, Автозаводский, Нижний Новгород, шоссе Южное, 49а	f	large
54668	61898	1339	Нижегородская область, Автозаводский, Нижний Новгород, шоссе Южное, 33	f	large
54667	61898	1338	Нижегородская область, Автозаводский, Нижний Новгород, шоссе Южное, 33	f	large
54666	61898	1337	Нижегородская область, Автозаводский, Нижний Новгород, шоссе Южное, 33	f	large
55027	62123	1703	Нижегородская область, Нижний Новгород, улица Тропинина, 1, Школа № 45	f	large
55026	62123	1702	Нижегородская область, Нижний Новгород, улица Тропинина, 1, Школа № 45	f	large
55025	62123	1701	Нижегородская область, Нижний Новгород, улица Тропинина, 1, Школа № 45	f	large
55148	62195	1825	Нижегородская область, Нижний Новгород, улица Стрелковая, 81	f	large
55147	62195	1824	Нижегородская область, Нижний Новгород, улица Стрелковая, 81	f	large
55118	62178	1795	Нижегородская область, Нижний Новгород, улица Павла Мочалова, 9	f	large
55117	62178	1794	Нижегородская область, Нижний Новгород, улица Павла Мочалова, 9	f	large
55097	62167	1774	Нижегородская область, Нижний Новгород, улица Меднолитейная, 1а	f	large
55096	62167	1773	Нижегородская область, Нижний Новгород, улица Меднолитейная, 1а	f	large
55054	62144	1731	Нижегородская область, Нижний Новгород, улица Кулибина, 6, Гимназия им. А.С. Пушкина	f	large
54918	62049	1594	Нижегородская область, Нижний Новгород, улица Куйбышева, 29	f	large
54692	61911	1363	Нижегородская область, Нижний Новгород, улица Краснодонцев, 1а	f	large
54747	61911	1418	Нижегородская область, Нижний Новгород, улица Краснодонцев, 1а	f	large
54633	61876	1304	Нижегородская область, Нижний Новгород, улица Земляничная, 1а	f	large
55009	62113	1685	Нижегородская область, Нижний Новгород, улица Героя Советского Союза Шапошникова, 10, Профессиональный лицей № 21	f	large
54682	61904	1353	Нижегородская область, Нижний Новгород, улица Героя Советского Союза Смирнова, 39а	f	large
55064	62148	1741	Нижегородская область, Советский, Нижний Новгород, улица Генкиной, 84, Школа № 186	f	large
55062	62148	1739	Нижегородская область, Советский, Нижний Новгород, улица Генкиной, 84, Школа № 186	f	large
55058	62148	1735	Нижегородская область, Советский, Нижний Новгород, улица Генкиной, 84, Школа № 186	f	large
55063	62148	1740	Нижегородская область, Советский, Нижний Новгород, улица Генкиной, 84, Школа № 186	f	large
55078	62156	1755	Нижегородская область, Нижний Новгород, улица Ванеева, 104к3, Школа № 54	f	large
55077	62156	1754	Нижегородская область, Нижний Новгород, улица Ванеева, 104к3, Школа № 54	f	large
55076	62156	1753	Нижегородская область, Нижний Новгород, улица Ванеева, 104к3, Школа № 54	f	large
55000	62106	1676	Нижегородская область, Нижний Новгород, улица Бонч-Бруевича, 11а, Школа № 48	f	large
54999	62106	1675	Нижегородская область, Нижний Новгород, улица Бонч-Бруевича, 11а, Школа № 48	f	large
54998	62106	1674	Нижегородская область, Нижний Новгород, улица Бонч-Бруевича, 11а, Школа № 48	f	large
55039	62132	1715	Нижегородская область, Нижний Новгород, улица Бекетова, 8б, Профессиональный лицей №41	f	large
55040	62131	1716	Нижегородская область, Нижний Новгород, улица Бекетова, 19а, Школа № 53	f	large
55038	62131	1714	Нижегородская область, Нижний Новгород, улица Бекетова, 19а, Школа № 53	f	large
55037	62130	1713	Нижегородская область, Нижний Новгород, улица Бекетова, 29а, Школа № 173	f	large
55035	62130	1711	Нижегородская область, Нижний Новгород, улица Бекетова, 29а, Школа № 173	f	large
55020	62120	1696	Нижегородская область, Нижний Новгород, улица Академика Лебедева, 3, Школа № 32	f	large
55019	62120	1695	Нижегородская область, Нижний Новгород, улица Академика Лебедева, 3, Школа № 32	f	large
55018	62120	1694	Нижегородская область, Нижний Новгород, улица Академика Лебедева, 3, Школа № 32	f	large
55017	62120	1693	Нижегородская область, Нижний Новгород, улица Академика Лебедева, 3, Школа № 32	f	large
55021	62121	1697	Нижегородская область, Приокский, Нижний Новгород, улица Академика Лебедева, 3, Школа № 32	f	large
54703	61918	1374	Нижегородская область, Нижний Новгород, проспект Октября, 22а	f	large
54702	61917	1373	Нижегородская область, Нижний Новгород, проспект Октября, 23	f	large
54701	61917	1372	Нижегородская область, Нижний Новгород, проспект Октября, 23	f	large
54699	61916	1370	Нижегородская область, Нижний Новгород, проспект Октября, 14	f	large
54493	61741	1154	Нижегородская область, Кулебаки	f	large
54700	61916	1371	Нижегородская область, Нижний Новгород, проспект Октября, 14	f	large
54693	61912	1364	Нижегородская область, Нижний Новгород, проспект Молодежный, 30а	f	large
54657	61892	1328	Нижегородская область, Нижний Новгород, проспект Молодежный, 44б	f	large
54862	62008	1536	Нижегородская область, Нижний Новгород, проспект Ленина, 14а, школа № 62	f	large
54861	62008	1535	Нижегородская область, Нижний Новгород, проспект Ленина, 14а, школа № 62	f	large
54859	62006	1533	Нижегородская область, Нижний Новгород, проспект Ленина, 27, НКИ	f	large
54841	61993	1515	Нижегородская область, Нижний Новгород, проспект Ленина, 45к5, школа №180	f	large
54840	61992	1514	Нижегородская область, Нижний Новгород, проспект Ленина, 45к5, школа №180	f	large
54827	61984	1501	Нижегородская область, Нижний Новгород, проспект Ленина, 55к3, школа №60	f	large
54826	61984	1500	Нижегородская область, Нижний Новгород, проспект Ленина, 55к3, школа №60	f	large
54823	61982	1497	Нижегородская область, Нижний Новгород, проспект Ленина, 61к6, школа №184	f	large
54822	61982	1496	Нижегородская область, Нижний Новгород, проспект Ленина, 61к6, школа №184	f	large
54814	61975	1487	Нижегородская область, Нижний Новгород, проспект Ленина, 70а, школа №72	f	large
54813	61975	1486	Нижегородская область, Нижний Новгород, проспект Ленина, 70а, школа №72	f	large
55155	62198	1832	Нижегородская область, Нижний Новгород, проспект Кораблестроителей, 25а	f	large
55154	62198	1831	Нижегородская область, Нижний Новгород, проспект Кораблестроителей, 25а	f	large
55153	62198	1830	Нижегородская область, Нижний Новгород, проспект Кораблестроителей, 25а	f	large
54696	61913	1367	Нижегородская область, Нижний Новгород, проспект Кирова, 29а	f	large
54695	61913	1366	Нижегородская область, Нижний Новгород, проспект Кирова, 29а	f	large
54908	62040	1584	Нижегородская область, Нижний Новгород, проспект Героев, 20, школа № 64	f	large
54906	62038	1582	Нижегородская область, Нижний Новгород, проспект Героев, 20	f	large
55016	62119	1692	Нижегородская область, Нижний Новгород, проспект Гагарина, 97, НГСХА	f	large
55004	62109	1680	Нижегородская область, Нижний Новгород, проспект Гагарина, 154, МОУ Межшкольный учебный комбинат Приокского р	f	large
55051	62141	1727	Нижегородская область, Нижний Новгород, проспект Гагарина, 12, Нижегородский строительный техникум	f	large
55049	62140	1725	Нижегородская область, Нижний Новгород, проспект Гагарина, 23к2, Нижегородский государственный университет	f	large
55048	62139	1724	Нижегородская область, Нижний Новгород, проспект Гагарина, 23, общежитие №4	f	medium
55045	62137	1721	Нижегородская область, Нижний Новгород, проспект Гагарина, 44, Школа № 47	f	large
55046	62136	1722	Нижегородская область, Нижний Новгород, проспект Гагарина, 46, Волго-Вятская академия гос.службы	f	large
55044	62136	1720	Нижегородская область, Нижний Новгород, проспект Гагарина, 46, Волго-Вятская академия гос.службы	f	large
55008	62112	1684	Нижегородская область, Приокский район, Нижний Новгород, проспект Гагарина, 41, Клуб им.Кринова	f	large
54992	62100	1668	Нижегородская область, Нижний Новгород, проспект Гагарина, 68, Общежитие НГМА	f	large
54744	61935	1415	Нижегородская область, Нижний Новгород, проспект Бусыгина, 39	f	large
54733	61935	1404	Нижегородская область, Нижний Новгород, проспект Бусыгина, 39	f	large
54727	61930	1398	Нижегородская область, Нижний Новгород, проспект Бусыгина, 18а	f	large
54635	61878	1306	Нижегородская область, Нижний Новгород, поселок Мостоотряд, 30	f	large
54963	62087	1639	Нижегородская область, Нижний Новгород, площадь Свободы, 3	f	large
54962	62086	1638	Нижегородская область, Нижний Новгород, площадь Свободы, 1	f	large
55482	62506	2195	Нижегородская область, Канавинский район, Нижний Новгород, площадь Революции, 2, Здание Московского вокзала	f	small
54957	62081	1633	Нижегородская область, Нижний Новгород, переулок Холодный, 15а	f	large
54954	62078	1630	Нижегородская область, Нижний Новгород, переулок Холодный, 15а	f	large
54946	62071	1622	Нижегородская область, Нижний Новгород, переулок Урожайный, 4	f	large
55101	62169	1778	Нижегородская область, Нижний Новгород, переулок Общественный, 2	f	large
55015	62117	1691	Нижегородская область, Приокский район, город Нижний Новгород, микрорайон Щербинки-I, 30, Школа № 174	f	large
55013	62117	1689	Нижегородская область, Приокский район, город Нижний Новгород, микрорайон Щербинки-I, 30, Школа № 174	f	large
55014	62118	1690	Нижегородская область, Нижний Новгород, микрорайон Щербинки-I, 30, Школа № 174	f	large
54786	61963	1457	Нижегородская область, Нижний Новгород, бульвар Мира, 4, школа №143	f	large
54785	61963	1456	Нижегородская область, Нижний Новгород, бульвар Мира, 4, школа №143	f	large
54784	61963	1455	Нижегородская область, Нижний Новгород, бульвар Мира, 4, школа №143	f	large
54854	62003	1528	Нижегородская область, Нижний Новгород, бульвар Заречный, 16, школа № 106	f	large
55084	62159	1761	Нижегородская область, Нижний Новгород, бульвар 60-летия Октября, 5а, Школа № 187	f	large
55082	62159	1759	Нижегородская область, Нижний Новгород, бульвар 60-летия Октября, 5а, Школа № 187	f	large
55083	62158	1760	Нижегородская область, Нижний Новгород, бульвар 60-летия Октября, 5, Школа № 187	f	large
55081	62158	1758	Нижегородская область, Нижний Новгород, бульвар 60-летия Октября, 5, Школа № 187	f	large
54752	61944	1423	Нижегородская область, Нижний Новгород, Якорная, 121, школа №109	f	large
54751	61944	1422	Нижегородская область, Нижний Новгород, Якорная, 121, школа №109	f	large
54750	61944	1421	Нижегородская область, Нижний Новгород, Якорная, 121, школа №109	f	large
54749	61944	1420	Нижегородская область, Нижний Новгород, Якорная, 121, школа №109	f	large
54974	62091	1650	Нижегородская область, Нижний Новгород, Яблоневая, 6	f	large
54687	61907	1358	Нижегородская область, Нижний Новгород, Юлиуса Фучика, 2	f	large
54686	61907	1357	Нижегородская область, Нижний Новгород, Юлиуса Фучика, 2	f	large
54685	61906	1356	Нижегородская область, Нижний Новгород, Юлиуса Фучика, 12а	f	large
54684	61906	1355	Нижегородская область, Нижний Новгород, Юлиуса Фучика, 12а	f	large
55123	62180	1800	Нижегородская область, Нижний Новгород, Энгельса, 3	f	large
55122	62180	1799	Нижегородская область, Нижний Новгород, Энгельса, 3	f	large
55121	62179	1798	Нижегородская область, Нижний Новгород, Энгельса, 27	f	large
55120	62179	1797	Нижегородская область, Нижний Новгород, Энгельса, 27	f	large
54776	61958	1447	Нижегородская область, Нижний Новгород, Электровозная, 15, школа №167 (второе здание)	f	large
54707	61921	1378	Нижегородская область, Нижний Новгород, Школьная, 28	f	large
54691	61910	1362	Нижегородская область, Нижний Новгород, Школьная, 10	f	large
54916	62047	1592	Нижегородская область, Нижний Новгород, Шаляпина, 25	f	large
54912	62044	1588	Нижегородская область, Нижний Новгород, Шаляпина, 23	f	large
54913	62043	1589	Нижегородская область, Нижний Новгород, Шаляпина, 23	f	large
54911	62043	1587	Нижегородская область, Нижний Новгород, Шаляпина, 23	f	large
54794	61969	1465	Нижегородская область, Нижний Новгород, Чкалова, 5а, Техникум железнодор-го транс-та	f	large
54793	61968	1464	Нижегородская область, Нижний Новгород, Чкалова, 26, школа №52	f	large
54887	62024	1563	Нижегородская область, Нижний Новгород, Черняховского, 8а	f	large
54886	62023	1562	Нижегородская область, Нижний Новгород, Черняховского, 8а	f	large
54706	61919	1377	Нижегородская область, Нижний Новгород, Челюскинцев, 24	f	large
54705	61919	1376	Нижегородская область, Нижний Новгород, Челюскинцев, 24	f	large
54704	61919	1375	Нижегородская область, Нижний Новгород, Челюскинцев, 24	f	large
54697	61914	1368	Нижегородская область, Нижний Новгород, Челюскинцев, 17	f	large
54690	61909	1361	Нижегородская область, Нижний Новгород, Челюскинцев, 9	f	large
55160	62171	1837	Нижегородская область, Нижний Новгород, Чайковского, 12	f	large
55104	62171	1781	Нижегородская область, Нижний Новгород, Чайковского, 12	f	large
55103	62171	1780	Нижегородская область, Нижний Новгород, Чайковского, 12	f	large
54890	62026	1566	Нижегородская область, Нижний Новгород, Чаадаева, 12а	f	large
54889	62022	1565	Нижегородская область, Нижний Новгород, Чаадаева, 2а	f	large
54885	62022	1561	Нижегородская область, Нижний Новгород, Чаадаева, 2а	f	large
54888	62025	1564	Нижегородская область, Московский район, Нижний Новгород, Чаадаева, 30а	f	large
54973	62061	1649	Нижегородская область, Нижний Новгород, Фруктовая, 8	f	large
54972	62061	1648	Нижегородская область, Нижний Новгород, Фруктовая, 8	f	large
54971	62061	1647	Нижегородская область, Нижний Новгород, Фруктовая, 8	f	large
54936	62061	1612	Нижегородская область, Нижний Новгород, Фруктовая, 8	f	large
68333	62187	1810	Нижегородская область, Нижний Новгород, Федосеенко, 25, школа № 81	f	large
55132	62186	1809	Нижегородская область, Нижний Новгород, Федосеенко, 37	f	large
55131	62185	1808	Нижегородская область, Нижний Новгород, Федосеенко, 25	f	large
54757	61949	1428	Нижегородская область, Канавинский район, Нижний Новгород, Ухтомского, 90, школа №167	f	large
54955	62079	1631	Нижегородская область, Нижний Новгород, Ульянова, 1	f	large
55002	62107	1678	Нижегородская область, Приокский район, Нижний Новгород, Углова, 1в, МОУ Вечерняя общеобразовательная школа №18	f	large
55001	62107	1677	Нижегородская область, Приокский район, Нижний Новгород, Углова, 1в, МОУ Вечерняя общеобразовательная школа №18	f	large
54872	62013	1546	Нижегородская область, Нижний Новгород, Тургайская, 5, школа № 101	f	large
54772	61955	1443	Нижегородская область, Нижний Новгород, Тонкинская , 4, школа №121	f	large
54770	61955	1441	Нижегородская область, Нижний Новгород, Тонкинская , 4, школа №121	f	large
54769	61955	1440	Нижегородская область, Нижний Новгород, Тонкинская , 4, школа №121	f	large
54771	61956	1442	Нижегородская область, Нижний Новгород, Тонкинская, 2, МОУ Центр образования	f	large
54997	62105	1673	Нижегородская область, Нижний Новгород, Терешковой, 4а, Школа № 11	f	large
54996	62104	1672	Нижегородская область, Нижний Новгород, Терешковой, 4а, Школа № 11	f	large
54777	61959	1448	Нижегородская область, Нижний Новгород, Тепличная, 7а, детский сад №118	f	large
54858	62005	1532	Нижегородская область, Нижний Новгород, Сухопутная, 2, школа-интернат № 6	f	large
54857	62005	1531	Нижегородская область, Нижний Новгород, Сухопутная, 2, школа-интернат № 6	f	large
54719	61926	1390	Нижегородская область, Нижний Новгород, Строкина, 2	f	large
54718	61926	1389	Нижегородская область, Нижний Новгород, Строкина, 2	f	large
54717	61926	1388	Нижегородская область, Нижний Новгород, Строкина, 2	f	large
54716	61925	1387	Нижегородская область, Нижний Новгород, Строкина, 7	f	large
54715	61924	1386	Нижегородская область, Нижний Новгород, Строкина, 12а	f	large
54714	61924	1385	Нижегородская область, Нижний Новгород, Строкина, 12а	f	large
54713	61924	1384	Нижегородская область, Нижний Новгород, Строкина, 12а	f	large
54660	61895	1331	Нижегородская область, Нижний Новгород, Старых производственников, 18	f	large
54659	61894	1330	Нижегородская область, Нижний Новгород, Старых Производственников, 13а	f	large
55136	62188	1813	Нижегородская область, Нижний Новгород, Станиславского, 16	f	large
55135	62188	1812	Нижегородская область, Нижний Новгород, Станиславского, 16	f	large
54655	61890	1326	Нижегородская область, Автозаводский район, Нижний Новгород, Спутника, 24а	f	large
54654	61889	1325	Нижегородская область, Нижний Новгород, Спутника, 2а	f	large
54653	61889	1324	Нижегородская область, Нижний Новгород, Спутника, 2а	f	large
54934	62036	1610	Нижегородская область, Московский район, Нижний Новгород, Софьи Перовской, 2	f	large
54904	62036	1580	Нижегородская область, Московский район, Нижний Новгород, Софьи Перовской, 2	f	large
54933	62059	1609	Нижегородская область, Нижний Новгород, Софьи Перовской, 2	f	large
54927	62055	1603	Нижегородская область, Нижний Новгород, Софьи Перовской, 5	f	large
54928	62055	1604	Нижегородская область, Нижний Новгород, Софьи Перовской, 5	f	large
54926	62054	1602	Нижегородская область, Нижний Новгород, Софьи Перовской, 5	f	large
54711	61923	1382	Нижегородская область, Нижний Новгород, Советской Армии, 15	f	large
54712	61923	1383	Нижегородская область, Нижний Новгород, Советской Армии, 15	f	large
54838	61991	1512	Нижегородская область, Нижний Новгород, Снежная, 2, школа №100	f	large
54839	61991	1513	Нижегородская область, Нижний Новгород, Снежная, 2, школа №100	f	large
54825	61983	1499	Нижегородская область, Нижний Новгород, Снежная, 33, школа №107	f	large
54824	61983	1498	Нижегородская область, Нижний Новгород, Снежная, 33, школа №107	f	large
54950	62074	1626	Нижегородская область, Нижний Новгород, Славянская , 35	f	large
54952	62076	1628	Нижегородская область, Нижний Новгород, Славянская, 35	f	large
54807	61974	1478	Нижегородская область, Нижний Новгород, Сергея Есенина, 37, школа №55	f	large
54809	61974	1480	Нижегородская область, Нижний Новгород, Сергея Есенина, 37, школа №55	f	large
54808	61974	1479	Нижегородская область, Нижний Новгород, Сергея Есенина, 37, школа №55	f	large
54806	61974	1477	Нижегородская область, Нижний Новгород, Сергея Есенина, 37, школа №55	f	large
54812	61960	1483	Нижегородская область, Нижний Новгород, Сергея Есенина, 11, школа №41	f	large
54811	61960	1482	Нижегородская область, Нижний Новгород, Сергея Есенина, 11, школа №41	f	large
54810	61960	1481	Нижегородская область, Нижний Новгород, Сергея Есенина, 11, школа №41	f	large
54779	61960	1450	Нижегородская область, Нижний Новгород, Сергея Есенина, 11, школа №41	f	large
54778	61960	1449	Нижегородская область, Нижний Новгород, Сергея Есенина, 11, школа №41	f	large
54803	61973	1474	Нижегородская область, Нижний Новгород, Сергея Акимова, 49, Подростковый клуб Планета	f	large
54802	61972	1473	Нижегородская область, Нижний Новгород, Сергея Акимова, 35, школа №110	f	large
54805	61972	1476	Нижегородская область, Нижний Новгород, Сергея Акимова, 35, школа №110	f	large
54804	61972	1475	Нижегородская область, Нижний Новгород, Сергея Акимова, 35, школа №110	f	large
55112	62176	1789	Нижегородская область, Нижний Новгород, Свирская, 20	f	large
54652	61888	1323	Нижегородская область, Нижний Новгород, Сазанова, 10а	f	large
54651	61888	1322	Нижегородская область, Нижний Новгород, Сазанова, 10а	f	large
54650	61888	1321	Нижегородская область, Нижний Новгород, Сазанова, 10а	f	large
54798	61971	1469	Нижегородская область, Нижний Новгород, Рубо, 5а, Профессиональное училище №39	f	large
54797	61971	1468	Нижегородская область, Нижний Новгород, Рубо, 5а, Профессиональное училище №39	f	large
54796	61971	1467	Нижегородская область, Нижний Новгород, Рубо, 5а, Профессиональное училище №39	f	large
55094	62093	1771	Нижегородская область, Нижний Новгород, Родионова, 201	f	large
54976	62093	1652	Нижегородская область, Нижний Новгород, Родионова, 201	f	large
54975	62092	1651	Нижегородская область, Нижний Новгород, Родионова, 190	t	large
54988	62092	1664	Нижегородская область, Нижний Новгород, Родионова, 190	t	large
54942	62067	1618	Нижегородская область, Нижний Новгород, Родионова, 165к8	f	large
54967	62090	1643	Нижегородская область, Нижний Новгород, Радужная, 10	f	large
54762	61951	1433	Нижегородская область, Нижний Новгород, Путейская, 23б, школа №168	f	large
54761	61951	1432	Нижегородская область, Нижний Новгород, Путейская, 23б, школа №168	f	large
55114	62174	1791	Нижегородская область, Нижний Новгород, Пугачева, 12	f	large
55113	62174	1790	Нижегородская область, Нижний Новгород, Пугачева, 12	f	large
55109	62174	1786	Нижегородская область, Нижний Новгород, Пугачева, 12	f	large
54903	62035	1579	Нижегородская область, Нижний Новгород, Просвещенская , 4	f	large
54902	62035	1578	Нижегородская область, Нижний Новгород, Просвещенская , 4	f	large
54837	61990	1511	Нижегородская область, Нижний Новгород, Премудрова, 8, ДК ОАО Завод Красная Этна	f	large
54836	61990	1510	Нижегородская область, Нижний Новгород, Премудрова, 8, ДК ОАО Завод Красная Этна	f	large
54835	61990	1509	Нижегородская область, Нижний Новгород, Премудрова, 8, ДК ОАО Завод Красная Этна	f	large
54833	61988	1507	Нижегородская область, Нижний Новгород, Порт-Артурская , 12, Нижег.технолог.техникум	f	large
54947	62072	1623	Нижегородская область, Нижний Новгород, Плотничный переулок, 18в	f	large
54961	62085	1637	Нижегородская область, Нижний Новгород, Пискунова, 35	f	medium
54741	61940	1412	Нижегородская область, Нижний Новгород, Пермякова, 26	f	large
54740	61940	1411	Нижегородская область, Нижний Новгород, Пермякова, 26	f	large
68310	61939	1410	Нижегородская область, Нижний Новгород, Пермякова, 26, школа № 125	f	large
54738	61938	1409	Нижегородская область, Нижний Новгород, Пермякова, 10а	f	large
54737	61938	1408	Нижегородская область, Нижний Новгород, Пермякова, 10а	f	large
54736	61938	1407	Нижегородская область, Нижний Новгород, Пермякова, 10а	f	large
54816	61977	1490	Нижегородская область, Нижний Новгород, Партизанская, 10а, спортзал Энергия ОАО РУМО	f	large
55066	62146	1743	Нижегородская область, Советский район, Нижний Новгород, Ошарская улица, 70, Школа № 29	f	large
55056	62146	1733	Нижегородская область, Советский район, Нижний Новгород, Ошарская улица, 70, Школа № 29	f	large
55057	62147	1734	Нижегородская область, Нижний Новгород, Ошарская, 57а, Областное правление ВОС	f	large
54795	61970	1466	Нижегородская область, Нижний Новгород, Октябрьской Революции, 23а, Детская железная дорога	f	large
54956	62080	1632	Нижегородская область, Нижний Новгород, Нижегородский район, Октябрьская улица, 25	f	large
54765	61952	1436	Нижегородская область, Нижний Новгород, Обухова, 52, школа №96	f	large
54766	61952	1437	Нижегородская область, Нижний Новгород, Обухова, 52, школа №96	f	large
54764	61952	1435	Нижегородская область, Нижний Новгород, Обухова, 52, школа №96	f	large
54844	61995	1518	Нижегородская область, Нижний Новгород, Норильская, 1, школа №177	f	large
55126	62181	1803	Нижегородская область, Нижний Новгород, Никиты Рыбакова, 15	f	large
55125	62181	1802	Нижегородская область, Нижний Новгород, Никиты Рыбакова, 15	f	large
55124	62181	1801	Нижегородская область, Нижний Новгород, Никиты Рыбакова, 15	f	large
54938	62063	1614	Нижегородская область, Нижний Новгород, Нижневолжская набережная, 2	t	large
54959	62083	1635	Нижегородская область, Нижний Новгород, Нестерова, 5	f	large
55055	62145	1732	Нижегородская область, Нижний Новгород, Невзоровых, 34, Нижегородский автотранспортный техникум	f	large
55042	62134	1718	Нижегородская область, Нижний Новгород, Нартова, 23, Учебный центр Инфраком	f	large
54920	62051	1596	Нижегородская область, Нижний Новгород, Народная, 78	f	medium
54935	62060	1611	Нижегородская область, Нижний Новгород, Народная, 35, школа №118	f	large
54919	62050	1595	Нижегородская область, Московский район, Нижний Новгород, Народная, 35	f	large
55067	62152	1744	Нижегородская область, Нижний Новгород, Надежды Сусловой, 22, Детский клуб им.Маркина	f	large
55075	62155	1752	Нижегородская область, Нижний Новгород, Надежды Сусловой, 5 корпус 3, Школа № 44,	f	large
55074	62155	1751	Нижегородская область, Нижний Новгород, Надежды Сусловой, 5 корпус 3, Школа № 44,	f	large
55073	62155	1750	Нижегородская область, Нижний Новгород, Надежды Сусловой, 5 корпус 3, Школа № 44,	f	large
55072	62155	1749	Нижегородская область, Нижний Новгород, Надежды Сусловой, 5 корпус 3, Школа № 44,	f	large
54895	62029	1571	Нижегородская область, Нижний Новгород, Московское шоссе, 219а	f	large
54909	62041	1585	Нижегородская область, Нижний Новгород, Московское шоссе, 79	f	medium
54893	62028	1569	Нижегородская область, Нижний Новгород, Московское шоссе, 207а	f	large
54892	62028	1568	Нижегородская область, Нижний Новгород, Московское шоссе, 207а	f	large
54894	62027	1570	Нижегородская область, Нижний Новгород, Московское шоссе, 207а	f	large
54891	62027	1567	Нижегородская область, Нижний Новгород, Московское шоссе, 207а	f	large
54768	61953	1439	Нижегородская область, Нижний Новгород, Московское шоссе, 1, НЭПК	f	large
54767	61953	1438	Нижегородская область, Нижний Новгород, Московское шоссе, 1, НЭПК	f	large
54753	61945	1424	Нижегородская область, Нижний Новгород, Московское шоссе, 248, школа №98	f	large
54907	62039	1583	Нижегородская область, Нижний Новгород, Московское шоссе, 161, центр образования	f	large
54649	61887	1320	Нижегородская область, Нижний Новгород, Мончегорская, 33а	f	large
54648	61887	1319	Нижегородская область, Нижний Новгород, Мончегорская, 33а	f	large
54647	61887	1318	Нижегородская область, Нижний Новгород, Мончегорская, 33а	f	large
54646	61886	1317	Нижегородская область, Нижний Новгород, Мончегорская, 11ак3	f	large
54645	61885	1316	Нижегородская область, Нижний Новгород, Мончегорская, 32а	f	large
54644	61883	1315	Нижегородская область, Нижний Новгород, Мончегорская, 19а	f	large
54643	61883	1314	Нижегородская область, Нижний Новгород, Мончегорская, 19а	f	large
54641	61883	1312	Нижегородская область, Нижний Новгород, Мончегорская, 19а	f	large
55137	62189	1814	Нижегородская область, Сормовский район, Нижний Новгород, Мокроусова, 21	f	large
55139	62190	1816	Нижегородская область, Нижний Новгород, Мокроусова, 24	f	large
55138	62190	1815	Нижегородская область, Нижний Новгород, Мокроусова, 24	f	large
54884	62021	1560	Нижегородская область, Нижний Новгород, Мирошникова, 4а	f	large
54883	62021	1559	Нижегородская область, Нижний Новгород, Мирошникова, 4а	f	large
54882	62021	1558	Нижегородская область, Нижний Новгород, Мирошникова, 4а	f	large
54881	62021	1557	Нижегородская область, Нижний Новгород, Мирошникова, 4а	f	large
54964	62088	1640	Нижегородская область, Нижний Новгород, Минина, 31ак1	f	large
54880	62020	1556	Нижегородская область, Нижний Новгород, Мечникова, 74	f	large
54879	62020	1555	Нижегородская область, Нижний Новгород, Мечникова, 74	f	large
54878	62019	1554	Нижегородская область, Нижний Новгород, Мечникова, 73а	f	large
54731	61932	1402	Нижегородская область, Нижний Новгород, Мельникова, 31	f	large
54730	61932	1401	Нижегородская область, Нижний Новгород, Мельникова, 31	f	large
54729	61932	1400	Нижегородская область, Нижний Новгород, Мельникова, 31	f	large
55088	62160	1765	Нижегородская область, Нижний Новгород, Маршала Малиновского, 12, Школа № 49	f	large
55087	62160	1764	Нижегородская область, Нижний Новгород, Маршала Малиновского, 12, Школа № 49	f	large
55086	62160	1763	Нижегородская область, Нижний Новгород, Маршала Малиновского, 12, Школа № 49	f	large
55085	62160	1762	Нижегородская область, Нижний Новгород, Маршала Малиновского, 12, Школа № 49	f	large
54915	62046	1591	Нижегородская область, Нижний Новгород, Маршала Казакова, 6	f	large
54910	62042	1586	Нижегородская область, Нижний Новгород, Маршала Казакова, 3	f	large
54783	61962	1454	Нижегородская область, Нижний Новгород, Мануфактурная, 15, школа №95	f	large
54781	61961	1452	Нижегородская область, Нижний Новгород, Мануфактурная, 16а, школа №2	f	large
54782	61961	1453	Нижегородская область, Нижний Новгород, Мануфактурная, 16а, школа №2	f	large
54780	61961	1451	Нижегородская область, Нижний Новгород, Мануфактурная, 16а, школа №2	f	large
54941	62066	1617	Нижегородская область, Нижний Новгород, Малая Покровская улица, 8	f	large
54746	61942	1417	Нижегородская область, Нижний Новгород, Львовская, 35	f	large
54745	61942	1416	Нижегородская область, Нижний Новгород, Львовская, 35	f	large
54743	61941	1414	Нижегородская область, Нижний Новгород, Львовская, 1в	f	large
54742	61941	1413	Нижегородская область, Нижний Новгород, Львовская, 1в	f	large
54896	62030	1572	Нижегородская область, Московский район, Нижний Новгород, Лучистая, 14а	f	medium
54698	61915	1369	Нижегородская область, Нижний Новгород, Лоскутова, 11	f	large
54763	61946	1434	Нижегородская область, Нижний Новгород, Лесной Городок, 6а, школа №181	f	large
54754	61946	1425	Нижегородская область, Нижний Новгород, Лесной Городок, 6а, школа №181	f	large
54683	61905	1354	Нижегородская область, Нижний Новгород, Лескова, 68	f	large
68309	61893	1329	Нижегородская область, Нижний Новгород, Лескова, 66а, школа № 129	f	large
54921	62052	1597	Нижегородская область, Нижний Новгород, Левинка, 9	f	small
55130	62184	1807	Нижегородская область, Нижний Новгород, Культуры, 110	f	large
55129	62183	1806	Нижегородская область, Нижний Новгород, Культуры, 111	f	large
55128	62182	1805	Нижегородская область, Нижний Новгород, Культуры, 91	f	large
55127	62182	1804	Нижегородская область, Нижний Новгород, Культуры, 91	f	large
55119	62177	1796	Нижегородская область, Нижний Новгород, Культуры, 1	f	large
55116	62177	1793	Нижегородская область, Нижний Новгород, Культуры, 1	f	large
55115	62177	1792	Нижегородская область, Нижний Новгород, Культуры, 1	f	large
54917	62048	1593	Нижегородская область, Нижний Новгород, Куйбышева, 29	f	large
54914	62045	1590	Нижегородская область, Нижний Новгород, Куйбышева, 15	f	large
55068	62153	1745	Нижегородская область, Нижний Новгород, Кузнечихинская, 73, АНО Нижегородский УКЦ Станкоинформ	f	large
54694	61891	1365	Нижегородская область, Нижний Новгород, Красных Партизан, 8а	f	large
54656	61891	1327	Нижегородская область, Нижний Новгород, Красных Партизан, 8а	f	large
54897	62031	1573	Нижегородская область, Нижний Новгород, Красных Зорь, 14а	f	large
55100	62168	1777	Нижегородская область, Нижний Новгород, Красносормовская, 4б	f	large
55099	62168	1776	Нижегородская область, Нижний Новгород, Красносормовская, 4б	f	large
55098	62168	1775	Нижегородская область, Нижний Новгород, Красносормовская, 4б	f	large
55052	62142	1728	Нижегородская область, Нижний Новгород, Красносельская, 17, Общеж.Нижег.госуд. технического университета	f	large
68311	62073	1625	Нижегородская область, Нижний Новгород, Костина, 2, ГПНО «Дирон»	f	large
54849	61998	1523	Нижегородская область, Нижний Новгород, Космонавта Комарова, 2в, школа № 182	f	large
54848	61998	1522	Нижегородская область, Нижний Новгород, Космонавта Комарова, 2в, школа № 182	f	large
54847	61997	1521	Нижегородская область, Нижний Новгород, Космонавта Комарова, 2а, Ниж.филиал МЭСИ	f	large
54846	61996	1520	Нижегородская область, Нижний Новгород, Космонавта Комарова, 6, школа №148	f	large
54845	61996	1519	Нижегородская область, Нижний Новгород, Космонавта Комарова, 6, школа №148	f	large
54640	61882	1311	Нижегородская область, Нижний Новгород, Космическая , 38	t	small
54993	62101	1669	Нижегородская область, Нижний Новгород, Корейский переулок, 6, Общежитие НГАСУ	f	large
54994	62102	1670	Нижегородская область, Приокский район, Нижний Новгород, Корейская, 22, Школа № 135	f	large
54995	62103	1671	Нижегородская область, Нижний Новгород, Корейская, 22	f	large
54710	61922	1381	Нижегородская область, Нижний Новгород, Комсомольская, 10а	f	large
54709	61922	1380	Нижегородская область, Нижний Новгород, Комсомольская, 10а	f	large
54708	61922	1379	Нижегородская область, Нижний Новгород, Комсомольская, 10а	f	large
54789	61965	1460	Нижегородская область, Нижний Новгород, Коммунистическая, 75, школа №50	f	large
54788	61965	1459	Нижегородская область, Нижний Новгород, Коммунистическая, 75, школа №50	f	large
55108	62173	1785	Нижегородская область, Нижний Новгород, Коминтерна, 250	f	large
55107	62173	1784	Нижегородская область, Нижний Новгород, Коминтерна, 250	f	large
54925	62053	1601	Нижегородская область, Нижний Новгород, Коминтерна, 21	f	large
54924	62053	1600	Нижегородская область, Нижний Новгород, Коминтерна, 21	f	large
54923	62053	1599	Нижегородская область, Нижний Новгород, Коминтерна, 21	f	large
54922	62053	1598	Нижегородская область, Нижний Новгород, Коминтерна, 21	f	large
55012	62116	1688	Нижегородская область, Нижний Новгород, Кащенко, 23	f	large
54852	62000	1526	Нижегородская область, Нижний Новгород, Каширская, 58, проф. лицей № 11	f	large
54851	61999	1525	Нижегородская область, Нижний Новгород, Каширская, 58, проф.лицей № 11	f	large
54850	61999	1524	Нижегородская область, Нижний Новгород, Каширская, 58, проф.лицей № 11	f	large
54801	61964	1472	Нижегородская область, Нижний Новгород, Карла Маркса, 17, школа №176	f	large
54800	61964	1471	Нижегородская область, Нижний Новгород, Карла Маркса, 17, школа №176	f	large
54799	61964	1470	Нижегородская область, Нижний Новгород, Карла Маркса, 17, школа №176	f	large
54787	61964	1458	Нижегородская область, Нижний Новгород, Карла Маркса, 17, школа №176	f	large
54755	61947	1426	Нижегородская область, Нижний Новгород, Камчатский переулок, 4, подростковый клуб Атлант	f	large
54987	62099	1663	Нижегородская область, Нижний Новгород, Казанское шоссе, 17, Агродом	f	large
54958	62082	1634	Нижегородская область, Нижний Новгород, Казанское шоссе, 12	f	large
54939	62064	1615	Нижегородская область, Нижний Новгород, Казанское шоссе, 12б	f	large
54792	61966	1463	Нижегородская область, Нижний Новгород, Июльских дней, 1а, ЦДК Железнодорожников	f	large
54791	61966	1462	Нижегородская область, Нижний Новгород, Июльских дней, 1а, ЦДК Железнодорожников	f	large
54790	61966	1461	Нижегородская область, Нижний Новгород, Июльских дней, 1а, ЦДК Железнодорожников	f	large
54874	62015	1548	Нижегородская область, Нижний Новгород, Июльских Дней, 8, Ниж.медиц.базовый колледж	f	large
54873	62014	1547	Нижегородская область, Нижний Новгород, Июльских Дней, 10, школа № 97	f	large
54944	62069	1620	Нижегородская область, Нижний Новгород, Ильинская, 47	f	large
55159	62200	1836	Нижегородская область, Нижний Новгород, Зайцева, 7	f	large
55158	62199	1835	Нижегородская область, Нижний Новгород, Зайцева, 18а	f	large
55157	62199	1834	Нижегородская область, Нижний Новгород, Зайцева, 18а	f	large
55156	62199	1833	Нижегородская область, Нижний Новгород, Зайцева, 18а	f	large
54832	61987	1506	Нижегородская область, Нижний Новгород, Завкомовская, 1, школа №138	f	large
55024	62122	1700	Нижегородская область, Нижний Новгород, Жукова, 18, Школа № 17	f	large
55023	62122	1699	Нижегородская область, Нижний Новгород, Жукова, 18, Школа № 17	f	large
55022	62122	1698	Нижегородская область, Нижний Новгород, Жукова, 18, Школа № 17	f	large
54734	61936	1405	Нижегородская область, Нижний Новгород, Дьяконова, 25а	f	large
54721	61927	1392	Нижегородская область, Нижний Новгород, Дьяконова, 1б	f	large
54720	61927	1391	Нижегородская область, Нижний Новгород, Дьяконова, 1б	f	large
55095	62166	1772	Нижегородская область, Нижний Новгород, Дубравная, 21	f	large
54829	61985	1503	Нижегородская область, Нижний Новгород, Дружбы, 50, школа №123	f	large
54828	61985	1502	Нижегородская область, Нижний Новгород, Дружбы, 50, школа №123	f	large
54724	61928	1395	Нижегородская область, Автозаводский район, Нижний Новгород, Дружаева, 5б	f	large
54723	61928	1394	Нижегородская область, Автозаводский район, Нижний Новгород, Дружаева, 5б	f	large
54722	61928	1393	Нижегородская область, Автозаводский район, Нижний Новгород, Дружаева, 5б	f	large
54735	61937	1406	Нижегородская область, Нижний Новгород, Дружаева, 15а	f	large
54968	62009	1644	Нижегородская область, Нижний Новгород, Донецкая , 3	f	large
54969	62009	1645	Нижегородская область, Нижний Новгород, Донецкая , 3	f	large
54970	62009	1646	Нижегородская область, Нижний Новгород, Донецкая , 3	f	large
54760	61948	1431	Нижегородская область, Нижний Новгород, Движенцев, 7, школа №75	f	medium
54756	61948	1427	Нижегородская область, Нижний Новгород, Движенцев, 7, школа №75	f	large
54870	62012	1544	Нижегородская область, Нижний Новгород, Даргомыжского, 11а, Центр дополнит.образования	f	large
54871	62010	1545	Нижегородская область, Нижний Новгород, Даргомыжского, 22а, школа № 94	f	large
54868	62010	1542	Нижегородская область, Нижний Новгород, Даргомыжского, 22а, школа № 94	f	large
54867	62010	1541	Нижегородская область, Нижний Новгород, Даргомыжского, 22а, школа № 94	f	large
54817	61979	1491	Нижегородская область, Нижний Новгород, Грекова, 9, библиотечно-информационный и досуговый центр	f	large
54759	61950	1430	Нижегородская область, Нижний Новгород, Гороховецкая , 12, ДК станц. Горький-Сортировочный	f	large
54758	61950	1429	Нижегородская область, Нижний Новгород, Гороховецкая , 12, ДК станц. Горький-Сортировочный	f	large
55553	62578	2270	Нижегородская область, Нижний Новгород, Гордеевская, 3/5, ГУ Обл центр соц-труд. реабил	t	small
55041	62133	1717	Нижегородская область, Нижний Новгород, Горбатовская, 16, Клуб поселка Сахарный Дол	f	large
54856	62004	1530	Нижегородская область, Нижний Новгород, Гончарова, 12, школа № 120	f	large
54855	62004	1529	Нижегородская область, Нижний Новгород, Гончарова, 12, школа № 120	f	large
54866	62002	1540	Нижегородская область, Нижний Новгород, Голубева, 4а, школа № 91	f	large
54853	62002	1527	Нижегородская область, Нижний Новгород, Голубева, 4а, школа № 91	f	large
54948	62068	1624	Нижегородская область, Нижний Новгород, Гоголя, 1	f	large
54943	62068	1619	Нижегородская область, Нижний Новгород, Гоголя, 1	f	large
54843	61994	1517	Нижегородская область, Нижний Новгород, Героя Советского Союза Чугунова, 9, школа №175	f	large
54842	61994	1516	Нижегородская область, Нижний Новгород, Героя Советского Союза Чугунова, 9, школа №175	f	large
54681	61903	1352	Нижегородская область, Нижний Новгород, Героя Советского Союза Смирнова, 52а	f	large
54680	61903	1351	Нижегородская область, Нижний Новгород, Героя Советского Союза Смирнова, 52а	f	large
54834	61989	1508	Нижегородская область, Нижний Новгород, Героя Советского Союза Самочкина, 18, детский клуб Парус	f	large
54898	62032	1574	Нижегородская область, Нижний Новгород, Героя Советского Союза Рябцева, 10	f	large
54815	61976	1488	Нижегородская область, Нижний Новгород, Героя Советского Союза Попова, 12а, ПУ-интернат	f	large
54632	61875	1303	Нижегородская область, Нижний Новгород, Героя Советского Союза Ляхова, 109	f	large
54901	62034	1577	Нижегородская область, Нижний Новгород, Героя Советского Союза Давыдова, 13	f	large
54900	62033	1576	Нижегородская область, Московский район, Нижний Новгород, Героя Советского Союза Давыдова, 13	f	large
54899	62033	1575	Нижегородская область, Московский район, Нижний Новгород, Героя Советского Союза Давыдова, 13	f	large
54689	61908	1360	Нижегородская область, Нижний Новгород, Героя Смирнова, 12	f	large
54688	61908	1359	Нижегородская область, Нижний Новгород, Героя Смирнова, 12	f	large
54631	61874	1302	Нижегородская область, Нижний Новгород, Героя Бахтина, 1а	f	large
55152	62197	1829	Нижегородская область, Нижний Новгород, Героев Космоса, 43	f	large
55151	62197	1828	Нижегородская область, Нижний Новгород, Героев Космоса, 43	f	large
55150	62196	1827	Нижегородская область, Нижний Новгород, Героев Космоса, 1	f	large
55149	62196	1826	Нижегородская область, Нижний Новгород, Героев Космоса, 1	f	large
55079	62157	1756	Нижегородская область, Нижний Новгород, Генерала Ивлиева, 32к4	f	large
55080	62157	1757	Нижегородская область, Нижний Новгород, Генерала Ивлиева, 32к4	f	large
54775	61957	1446	Нижегородская область, Нижний Новгород, Генерала Зимина, 75, школа №51	f	large
54774	61957	1445	Нижегородская область, Нижний Новгород, Генерала Зимина, 75, школа №51	f	large
54773	61957	1444	Нижегородская область, Нижний Новгород, Генерала Зимина, 75, школа №51	f	large
54831	61986	1505	Нижегородская область, Нижний Новгород, Гвоздильная, 9, школа №99	f	large
54830	61986	1504	Нижегородская область, Нижний Новгород, Гвоздильная, 9, школа №99	f	large
54929	62056	1605	Нижегородская область, Нижний Новгород, Гвардейцев, 4	f	large
54726	61929	1397	Нижегородская область, Нижний Новгород, Газовская, 18	f	large
54725	61929	1396	Нижегородская область, Нижний Новгород, Газовская, 18	f	large
55106	62172	1783	Нижегородская область, Нижний Новгород, Вузовская , 1	f	large
55105	62172	1782	Нижегородская область, Нижний Новгород, Вузовская , 1	f	large
55111	62175	1788	Нижегородская область, Нижний Новгород, Вождей Революции, 29	f	large
55110	62175	1787	Нижегородская область, Нижний Новгород, Вождей Революции, 29	f	large
68314	62110	1683	Нижегородская область, Нижний Новгород, Ветлужская, 2, Школа № 140	f	large
68313	62110	1682	Нижегородская область, Нижний Новгород, Ветлужская, 2, Школа № 140	f	large
68312	62110	1681	Нижегородская область, Нижний Новгород, Ветлужская, 2, Школа № 140	f	large
55036	62129	1712	Нижегородская область, Советский, Нижний Новгород, Верхняя, 8, Школа № 122	f	large
55034	62129	1710	Нижегородская область, Советский, Нижний Новгород, Верхняя, 8, Школа № 122	f	large
54991	62096	1667	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 10	f	large
54985	62096	1661	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 10	f	large
54984	62096	1660	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 10	f	large
54983	62096	1659	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 10	f	large
54979	62095	1655	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 3а	f	large
54978	62095	1654	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 3а	f	large
54989	62094	1665	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 4а	f	large
54980	62094	1656	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 4а	f	large
54977	62094	1653	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 4а	f	large
54990	62062	1666	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 5а	f	large
54982	62062	1658	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 5а	f	large
54981	62062	1657	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 5а	f	large
54937	62062	1613	Нижегородская область, Нижний Новгород, Верхнепечерская улица, 5а	f	large
54671	61899	1342	Нижегородская область, Нижний Новгород, Веденяпина, 30а	f	large
54670	61899	1341	Нижегородская область, Нижний Новгород, Веденяпина, 30а	f	large
54669	61899	1340	Нижегородская область, Нижний Новгород, Веденяпина, 30а	f	large
54728	61931	1399	Нижегородская область, Нижний Новгород, Васнецова, 20	f	large
55145	62193	1822	Нижегородская область, Нижний Новгород, Василия Иванова, 28	f	large
55141	62191	1818	Нижегородская область, Нижний Новгород, Василия Иванова, 63	f	large
55140	62191	1817	Нижегородская область, Нижний Новгород, Василия Иванова, 63	f	large
54953	62077	1629	Нижегородская область, Нижний Новгород, Варварская, 15а	f	large
55033	62128	1709	Нижегородская область, Нижний Новгород, Ванеева, 203, Нижегородский институт развития образования	f	large
54732	61934	1403	Нижегородская область, Нижний Новгород, Бурденко, 35	f	large
55061	62150	1738	Нижегородская область, Нижний Новгород, Бориса Панина, 8/54, Школа № 151	f	large
55060	62150	1737	Нижегородская область, Нижний Новгород, Бориса Панина, 8/54, Школа № 151	f	large
55065	62149	1742	Нижегородская область, Нижний Новгород, Бориса Панина, 5, Дом детского творчества	f	large
55059	62149	1736	Нижегородская область, Нижний Новгород, Бориса Панина, 5, Дом детского творчества	f	large
55071	62154	1748	Нижегородская область, Советский, Нижний Новгород, Бориса Корнилова, 10, Школа № 46	f	large
55070	62154	1747	Нижегородская область, Советский, Нижний Новгород, Бориса Корнилова, 10, Школа № 46	f	large
55069	62154	1746	Нижегородская область, Советский, Нижний Новгород, Бориса Корнилова, 10, Школа № 46	f	large
55102	62170	1779	Нижегородская область, Нижний Новгород, Большая Починковская , 54	f	large
54940	62065	1616	Нижегородская область, Нижний Новгород, Большая Покровская, 18	f	large
54960	62084	1636	Нижегородская область, Нижний Новгород, Большая Печерская , 2	f	medium
54966	62089	1642	Нижегородская область, Нижний Новгород, Большая Печерская, 63в	f	large
54965	62089	1641	Нижегородская область, Нижний Новгород, Большая Печерская, 63в	f	large
54905	62037	1581	Нижегородская область, Нижний Новгород, Берёзовская, 2	f	large
55043	62135	1719	Нижегородская область, Нижний Новгород, Бекетова, 5в, Нижегородский музыкальный колледж им.М.А.Балакирева	f	large
55146	62194	1823	Нижегородская область, Нижний Новгород, Баренца, 7	f	large
55144	62192	1821	Нижегородская область, Сормовский район, Нижний Новгород, Баренца, 18	f	large
55143	62192	1820	Нижегородская область, Сормовский район, Нижний Новгород, Баренца, 18	f	large
55142	62192	1819	Нижегородская область, Сормовский район, Нижний Новгород, Баренца, 18	f	large
55050	62138	1726	Нижегородская область, Нижний Новгород, Артельная, 9, Нижегородский колледж бытового сервиса	f	large
55047	62138	1723	Нижегородская область, Нижний Новгород, Артельная, 9, Нижегородский колледж бытового сервиса	f	large
54639	61880	1310	Нижегородская область, Нижний Новгород, Аркадия Гайдара, 20а	f	large
54638	61880	1309	Нижегородская область, Нижний Новгород, Аркадия Гайдара, 20а	f	large
54637	61879	1308	Нижегородская область, Автозаводский район, Нижний Новгород, Аркадия Гайдара, 16	f	large
54636	61879	1307	Нижегородская область, Автозаводский район, Нижний Новгород, Аркадия Гайдара, 16	f	large
54642	61884	1313	Нижегородская область, Автозаводский район, Нижний Новгород, Академика Павлова, 14а	f	large
54863	62007	1537	Нижегородская область, Нижний Новгород, Академика Баха, 6, школа № 185	f	large
54865	62007	1539	Нижегородская область, Нижний Новгород, Академика Баха, 6, школа № 185	f	large
54860	62007	1534	Нижегородская область, Нижний Новгород, Академика Баха, 6, школа № 185	f	large
54864	62007	1538	Нижегородская область, Нижний Новгород, Академика Баха, 6, школа № 185	f	large
54821	61981	1495	Нижегородская область, Нижний Новгород, Адмирала Нахимова, 6, школа №160	f	large
54819	61981	1493	Нижегородская область, Нижний Новгород, Адмирала Нахимова, 6, школа №160	f	large
54820	61980	1494	Нижегородская область, Нижний Новгород, Адмирала Нахимова, 10а, Нижег.дизелестр.техникум	f	large
54818	61980	1492	Нижегородская область, Нижний Новгород, Адмирала Нахимова, 10а, Нижег.дизелестр.техникум	f	large
54869	62011	1543	Нижегородская область, Нижний Новгород, Адмирала Макарова, 1а, филиал Сочинского ГУ туризма	f	large
54679	61902	1350	Нижегородская область, Нижний Новгород, Автомеханическая, 12	f	large
54678	61902	1349	Нижегородская область, Нижний Новгород, Автомеханическая, 12	f	large
54677	61901	1348	Нижегородская область, Нижний Новгород, Автомеханическая, 13а	f	large
54676	61901	1347	Нижегородская область, Нижний Новгород, Автомеханическая, 13а	f	large
54675	61901	1346	Нижегородская область, Нижний Новгород, Автомеханическая, 13а	f	large
54932	62058	1608	Нижегородская область, Нижний Новгород, 50-летия Победы, 24	f	large
54931	62058	1607	Нижегородская область, Нижний Новгород, 50-летия Победы, 24	f	large
54930	62057	1606	Нижегородская область, Нижний Новгород, 50-летия Победы, 24	f	large
55028	62124	1704	Нижегородская область, Нижний Новгород, 40 Лет Победы, 16, Школа № 134	f	large
55030	62124	1706	Нижегородская область, Нижний Новгород, 40 Лет Победы, 16, Школа № 134	f	large
55029	62124	1705	Нижегородская область, Нижний Новгород, 40 Лет Победы, 16, Школа № 134	f	large
55003	62108	1679	Нижегородская область, Нижний Новгород, 40 Лет Октября, 2, Школа № 154	f	large
54945	62070	1621	Нижегородская область, Нижний Новгород, 3-я Ямская, 1	f	large
54630	61873	1301	Нижегородская область, Нижний Новгород, 19-я Линия, 25	f	large
54951	62075	1627	Нижегородская область, Нижний Новгород, Маслякова, 1	f	large
53799	61095	403	Нижегородская область, поселок Неклюдово, Новая, 6а, МБОУ Основная Общеобразовательная Школа № 20	f	medium
86737	61743	1157	Нижегородская область, Кулебаки	f	small
111781	61743	1156	Нижегородская область, Кулебаки	f	medium
54484	61736	1145	Нижегородская область, Кулебаки	f	medium
111776	61733	1143	Нижегородская область, Кулебаки	f	medium
54474	61727	1135	Нижегородская область, Кулебаки	f	large
111777	61734	1144	Нижегородская область, Кулебаки, площадь Ленина, 2, МУ «Культурно-досуговый комплекс» (Дворец культуры)	f	medium
54472	61726	1133	Нижегородская область, Кулебаки, Циолковского, 20, школа №9	f	large
54473	61726	1134	Нижегородская область, Кулебаки, Циолковского, 20, школа №9	f	large
54489	61738	1150	Нижегородская область, Кулебаки, О.Кошевого, 132, школа №6	f	large
54488	61738	1149	Нижегородская область, Кулебаки, О.Кошевого, 132, школа №6	f	medium
54487	61738	1148	Нижегородская область, Кулебаки, О.Кошевого, 132, школа №6	f	large
54471	61725	1132	Нижегородская область, Кулебаки, Мира, 23А, школа №3	f	medium
54470	61725	1131	Нижегородская область, Кулебаки, Мира, 23А, школа №3	f	large
111783	61745	1159	Нижегородская область, Кулебаки, Маряхина, 4, Помещение бывшей библиотеки №3	f	medium
54481	61732	1142	Нижегородская область, Кулебаки, Гоголя, 27, школа №1	f	large
54480	61732	1141	Нижегородская область, Кулебаки, Гоголя, 27, школа №1	f	medium
54477	61730	1138	Нижегородская область, Кулебаки, Воровского, 80, Детская художественная школа	f	large
54476	61729	1137	Нижегородская область, Кулебаки, 60 лет ВЛКСМ, 14, ЦДТТ	f	large
68237	61666	1061	Нижегородская область, Кстово, проспект Капитана Рачкова, 12, Дом учащейся молодежи	f	large
68245	61672	1069	Нижегородская область, Кстово, Школьная, 15, школа № 5	f	large
68244	61672	1068	Нижегородская область, Кстово, Школьная, 15, школа № 5	f	large
68243	61671	1067	Нижегородская область, Кстово, Школьная, 6, школа № 2	f	large
68242	61671	1066	Нижегородская область, Кстово, Школьная, 6, школа № 2	f	large
68257	61680	1081	Нижегородская область, Кстово, Тургенева, 3, Профессиональный лицей №36	f	large
68256	61679	1080	Нижегородская область, Кстово, Свободы, 1, школа №7	f	large
68249	61674	1073	Нижегородская область, Кстово, Свободы, 1, школа № 7	f	large
68236	61665	1060	Нижегородская область, Кстово, Парковая, школа №8	f	large
68235	61664	1059	Нижегородская область, Кстово, Парковая, школа № 8	f	large
68273	61699	1105	Нижегородская область, Кстово, Островского, 13, Центр внешкольной работы	f	large
68240	61669	1064	Нижегородская область, Кстово, Островского, 5, МУП Тепловые сети	f	large
68271	61696	1100	Нижегородская область, Кстово, 3 микрорайон, 1, помещение кафе Престиж	f	large
54262	61534	895	Нижегородская область, поселок Желнино, поселковая Администрация	f	medium
54176	61470	809	Нижегородская область, Дзержинск	f	large
54268	61539	901	Нижегородская область, Дзержинск, улица Рудольфа Удриса, 8, МОУ Гимназия №38	f	large
54206	61497	839	Нижегородская область, Дзержинск, улица Пирогова, 34б, МОУ СОШ №70	f	large
54183	61477	816	Нижегородская область, Дзержинск, улица Кирова, 1, административное здание	t	medium
68299	61532	891	Нижегородская область, Дзержинск, улица Галкина, 9а, МБОУ «СОШ №17»	f	large
54233	61516	866	Нижегородская область, Дзержинск, проспект Циолковского, 17в	f	large
54230	61513	863	Нижегородская область, Дзержинск, проспект Циолковского, 18а	f	large
54229	61513	862	Нижегородская область, Дзержинск, проспект Циолковского, 18а	f	large
54228	61513	861	Нижегородская область, Дзержинск, проспект Циолковского, 18а	f	large
54279	61544	912	Нижегородская область, Дзержинск, проспект Свердлова, 33в, Спец.образ.школа №2	f	large
54278	61543	911	Нижегородская область, Дзержинск, проспект Свердлова, 21, МОУ СОШ №1	f	large
54265	61537	898	Нижегородская область, Дзержинск, проспект Свердлова, 88а, МОУ СОШ №27	f	large
111757	61535	896	Нижегородская область, Дзержинск, проспект Свердлова, 88а, МБОУ СОШ №27	f	medium
54249	61526	882	Нижегородская область, Дзержинск, проспект Ленинского Комсомола, 12а, МОУ СОШ №18	f	large
54248	61526	881	Нижегородская область, Дзержинск, проспект Ленинского Комсомола, 12а, МОУ СОШ №18	f	large
54224	61510	857	Нижегородская область, Дзержинск, проспект Ленина, 53, ГОУ СПО ДТК	f	large
54221	61508	854	Нижегородская область, Дзержинск, проспект Ленина, 5, МОУ ДОД ДЮСШ№1	f	large
54195	61489	828	Нижегородская область, Дзержинск, проспект Ленина, 79, ГОУ СПО ДХМТ	f	large
54189	61483	822	Нижегородская область, Дзержинск, проспект Ленина, 79, ГОУ СПО ДХМТ	f	large
68293	61490	829	Нижегородская область, Дзержинск, проспект Дзержинского, 16/22	f	large
68294	61490	830	Нижегородская область, Дзержинск, проспект Дзержинского, 16/22	f	large
68290	61473	812	Нижегородская область, Дзержинск, проспект Дзержинского, 16, МОУ СОШ №10	f	large
54267	61538	900	Нижегородская область, Дзержинск, бульвар Химиков, 6А, МОУ СОШ №34	f	large
54266	61538	899	Нижегородская область, Дзержинск, бульвар Химиков, 6А, МОУ СОШ №34	f	large
54264	61536	897	Нижегородская область, Дзержинск, бульвар Химиков, 6а, МОУ СОШ №34	f	medium
68254	61677	1078	Нижегородская область, Дзержинск, бульвар Мира, 23, ДДЮТ	f	large
68252	61677	1076	Нижегородская область, Дзержинск, бульвар Мира, 23, ДДЮТ	f	large
54238	61520	871	Нижегородская область, Дзержинск, бульвар Мира, 36	f	medium
54225	61511	858	Нижегородская область, Дзержинск, бульвар Мира, 3, МОУ СОШ №40	f	large
54226	61511	859	Нижегородская область, Дзержинск, бульвар Мира, 3, МОУ СОШ №40	f	large
54214	61503	847	Нижегородская область, Дзержинск, бульвар Мира, 2, ГОУ СПО ДМК	f	large
54288	61548	921	Нижегородская область, Дзержинск, бульвар Космонавтов, 26а, МОУ ДЮЦ Магнитная стрелка	f	large
54286	61548	919	Нижегородская область, Дзержинск, бульвар Космонавтов, 26а, МОУ ДЮЦ Магнитная стрелка	f	large
54277	61527	910	Нижегородская область, Дзержинск, Щорса, 3, МОУ СОШ №33	f	large
54276	61527	909	Нижегородская область, Дзержинск, Щорса, 3, МОУ СОШ №33	f	large
54250	61527	883	Нижегородская область, Дзержинск, Щорса, 3, МОУ СОШ №33	f	large
54182	61476	815	Нижегородская область, Дзержинск, Черняховского, 24, Филиал ГОУ ВПО ВВАГС	f	large
54181	61475	814	Нижегородская область, Дзержинск, Черняховского, 24, филиал ВВАГС	f	large
54270	61541	903	Нижегородская область, Дзержинск, Удриса, 8, МОУ Гимназия №38	f	large
54269	61541	902	Нижегородская область, Дзержинск, Удриса, 8, МОУ Гимназия №38	f	large
54261	61533	894	Нижегородская область, Дзержинск, Терешковой, 46а, МОУ СОШ №14	f	large
54260	61533	893	Нижегородская область, Дзержинск, Терешковой, 46а, МОУ СОШ №14	f	large
54259	61533	892	Нижегородская область, Дзержинск, Терешковой, 46а, МОУ СОШ №14	f	large
54236	61518	869	Нижегородская область, Дзержинск, Терешковой, 34, СОШ №9	f	large
54235	61518	868	Нижегородская область, Дзержинск, Терешковой, 34, СОШ №9	f	large
54281	61545	914	Нижегородская область, Дзержинск, Строителей, 11а, МОУ СОШ №37	f	large
54280	61545	913	Нижегородская область, Дзержинск, Строителей, 11а, МОУ СОШ №37	f	large
54274	61542	907	Нижегородская область, Дзержинск, Строителей, 8, МОУ СОШ №15	f	large
54273	61542	906	Нижегородская область, Дзержинск, Строителей, 8, МОУ СОШ №15	f	large
54272	61542	905	Нижегородская область, Дзержинск, Строителей, 8, МОУ СОШ №15	f	large
54213	61502	846	Нижегородская область, Дзержинск, Советская, 9Б, МОУ СОШ №3	f	large
54212	61502	845	Нижегородская область, Дзержинск, Советская, 9Б, МОУ СОШ №3	f	large
54211	61501	844	Нижегородская область, Дзержинск, Советская, 9-б, МОУ СОШ №3	f	large
54244	61525	877	Нижегородская область, Дзержинск, Самохвалова, 5а, МОУ СОШ №36	f	large
54247	61525	880	Нижегородская область, Дзержинск, Самохвалова, 5а, МОУ СОШ №36	f	large
54220	61507	853	Нижегородская область, Дзержинск, Пожарского, 2, МОУ СОШ №32	f	large
54219	61506	852	Нижегородская область, Дзержинск, Пожарского, 2, МОУ СОШ№ 32	f	large
54207	61498	840	Нижегородская область, Дзержинск, Пирогова, 34б, МОУ СОШ №70	f	large
54256	61531	889	Нижегородская область, Дзержинск, Петрищева, 23, МОУ СОШ №71	f	large
54255	61531	888	Нижегородская область, Дзержинск, Петрищева, 23, МОУ СОШ №71	f	large
54257	61521	890	Нижегородская область, Дзержинск, Петрищева, 7, МОУ СОШ №13	f	large
54240	61521	873	Нижегородская область, Дзержинск, Петрищева, 7, МОУ СОШ №13	f	large
54239	61521	872	Нижегородская область, Дзержинск, Петрищева, 7, МОУ СОШ №13	f	large
54192	61486	825	Нижегородская область, Дзержинск, Октябрьская , 52, СОШ №30	f	large
54193	61487	826	Нижегородская область, Дзержинск, Октябрьская, 43а, МОУ ДОД ДМШ №3	f	large
54188	61482	821	Нижегородская область, Дзержинск, Октябрьская, 52, МОУ СОШ №30	f	large
68292	61485	824	Нижегородская область, Дзержинск, Окская набережная, 26а, МОУ СОШ №20	f	large
68291	61484	823	Нижегородская область, Дзержинск, Окская набережная, 26а, МОУ СОШ №20	f	large
54187	61481	820	Нижегородская область, Дзержинск, Окская набережная, 15, клуб Антей	f	large
54216	61492	849	Нижегородская область, Дзержинск, Маяковского, 18, МОУ СОШ №5	f	large
54215	61492	848	Нижегородская область, Дзержинск, Маяковского, 18, МОУ СОШ №5	f	large
54199	61492	832	Нижегородская область, Дзержинск, Маяковского, 18, МОУ СОШ №5	f	large
54205	61496	838	Нижегородская область, Дзержинск, Матросова, 30б, СОШ №68	f	large
54204	61495	837	Нижегородская область, Дзержинск, Матросова, 30б, МОУ СОШ №68	f	large
54202	61494	835	Нижегородская область, Дзержинск, Матросова, 19, МОУ СОШ №7	f	large
54203	61494	836	Нижегородская область, Дзержинск, Матросова, 19, МОУ СОШ №7	f	large
54243	61524	876	Нижегородская область, Дзержинск, Марковникова, 19, МОУ СОШ №24	f	large
54223	61509	856	Нижегородская область, Дзержинск, Марковникова, 19, МОУ СОШ №24	f	large
54222	61509	855	Нижегородская область, Дзержинск, Марковникова, 19, МОУ СОШ №24	f	large
54287	61547	920	Нижегородская область, Дзержинск, Комбрига Патоличева, 31, МОУ СОШ №21	f	large
54285	61547	918	Нижегородская область, Дзержинск, Комбрига Патоличева, 31, МОУ СОШ №21	f	large
54284	61546	917	Нижегородская область, Дзержинск, Комбрига Патоличева, 31а, МОУ СОШ №4	f	large
54283	61546	916	Нижегородская область, Дзержинск, Комбрига Патоличева, 31а, МОУ СОШ №4	f	large
54282	61546	915	Нижегородская область, Дзержинск, Комбрига Патоличева, 31а, МОУ СОШ №4	f	large
54217	61504	850	Нижегородская область, Дзержинск, Кирова, 15, МОУ ДОД ДМШ №1	f	large
54232	61515	865	Нижегородская область, Дзержинск, Грибоедова, 31, ОАО НИИК	f	large
68296	61514	864	Нижегородская область, Дзержинск, Грибоедова, 10, ГОУ СПО ДПК	f	large
54271	61530	904	Нижегородская область, Дзержинск, Галкина, 9, МОУ СОШ №17	f	large
54254	61530	887	Нижегородская область, Дзержинск, Галкина, 9, МОУ СОШ №17	f	large
54241	61522	874	Нижегородская область, Дзержинск, Гайдара, 49, ДПИ НГТУ	f	large
54237	61519	870	Нижегородская область, Дзержинск, Гайдара, 74б, МОУ СОШ №22	f	large
54234	61517	867	Нижегородская область, Дзержинск, Гайдара, 74б, МОУ СОШ №22	f	large
54227	61512	860	Нижегородская область, Дзержинск, Гагарина, 3, МОУ СОШ №2	f	large
54194	61488	827	Нижегородская область, Дзержинск, Гагарина, 3, СОШ №2	f	large
54185	61479	818	Нижегородская область, Дзержинск, Встречная, 38а, детский сад №9п	f	medium
54201	61493	834	Нижегородская область, Дзержинск, Ватутина, 54, МОУ СОШ №26	f	large
54200	61493	833	Нижегородская область, Дзержинск, Ватутина, 54, МОУ СОШ №26	f	large
54198	61491	831	Нижегородская область, Дзержинск, Ватутина, 19, ГОУ СПО ДПТ	f	large
54180	61474	813	Нижегородская область, Дзержинск, Ватутина, 19, Политехнический техникум	f	large
54218	61505	851	Нижегородская область, Дзержинск, Бутлерова, 38, МОУ ДОД ДЮЦ	f	large
54275	61529	908	Нижегородская область, Дзержинск, Буденного, 19, МОУ СОШ №23	f	large
54252	61529	885	Нижегородская область, Дзержинск, Буденного, 19, МОУ СОШ №23	f	large
68298	61528	886	Нижегородская область, Дзержинск, Буденного, 19к.2, МБОУ CОШ №23	f	large
68297	61528	884	Нижегородская область, Дзержинск, Буденного, 19к.2, МБОУ CОШ №23	f	large
54242	61523	875	Нижегородская область, Дзержинск, Буденного, 10а, МОУ СОШ №35	f	large
54246	61523	879	Нижегородская область, Дзержинск, Буденного, 10а, МОУ СОШ №35	f	large
54245	61523	878	Нижегородская область, Дзержинск, Буденного, 10а, МОУ СОШ №35	f	large
54095	61388	725	Нижегородская область, Городец	f	large
54102	61396	732	Нижегородская область, Городец, Титова, 4, школа № 2 (спортзал)	f	large
54100	61393	730	Нижегородская область, Городец, Титова, 4, школа № 2 (рекреация)	f	large
54105	61399	735	Нижегородская область, Городец, Свердлова, 17, школа № 1	f	large
54103	61397	733	Нижегородская область, Городец, Новая, 50, ГУ Центр занятости населения	f	large
54093	61386	723	Нижегородская область, Городец, Нахимова, 10, школа № 4	f	large
54101	61394	731	Нижегородская область, Городец, Набережная Революции, 5, Центр народных промыслов	f	large
54106	61400	736	Нижегородская область, Городец, Механизаторов, 29, школа № 13	f	large
54104	61398	734	Нижегородская область, Городец, Мелиораторов, 18, Детский клуб Чайка	f	large
54056	61348	682	Нижегородская область, Выкса	f	medium
54055	61347	681	Нижегородская область, Выкса	f	small
54054	61346	680	Нижегородская область, Выкса	t	small
54050	61342	676	Нижегородская область, Выкса	t	small
54049	61341	675	Нижегородская область, Выкса	t	small
54047	61339	673	Нижегородская область, Выкса	f	medium
54034	61326	660	Нижегородская область, Выкса	f	large
54033	61325	659	Нижегородская область, Выкса	f	medium
54032	61324	658	Нижегородская область, Выкса	f	large
54030	61322	656	Нижегородская область, Выкса	f	large
54027	61319	653	Нижегородская область, Выкса	f	large
54014	61310	640	Нижегородская область, Выкса	f	large
54013	61310	639	Нижегородская область, Выкса	f	large
54012	61309	638	Нижегородская область, Выкса	f	large
54006	61303	632	Нижегородская область, Выкса, СК ""Металлург"	f	large
54009	61306	635	Нижегородская область, Выкса, микрорайон Южный, ММДОУ Ёлочка	f	large
68286	61321	655	Нижегородская область, Выкса, микрорайон Гоголя, 21, МОУ ДОД ДДК Радуга	f	large
54028	61320	654	Нижегородская область, Выкса, м-н Гоголя, 28/1, школа 6	f	large
54016	61312	642	Нижегородская область, Выкса, м-н Гоголя, 21, ДДК &quot;&quot;Радуга&quot;&quot;&quot;	f	large
54046	61338	672	Нижегородская область, Выкса, Школьный переулок, 4, школа	f	large
54022	61301	648	Нижегородская область, Выкса, Чкалова, 64, общежитие ВМЗ	f	large
54017	61313	643	Нижегородская область, Выкса, Ульянова, 3, ДДТ	f	large
54023	61152	649	Нижегородская область, Выкса, Стахановская, 2, общежитие ВМЗ	f	large
54011	61308	637	Нижегородская область, Выкса, Слепнева, 19, школа 10	f	large
54025	61317	651	Нижегородская область, Выкса, Романова, 1, ПУ 35	f	medium
54021	61288	647	Нижегородская область, Выкса, Поселок Строитель, МУ ""Молодежный центр"""	f	small
54039	61331	665	Нижегородская область, Выкса, Первомайская, 30а, школа №2	f	large
54024	61316	650	Нижегородская область, Выкса, Островского, 75, школа 12	f	large
68285	61307	636	Нижегородская область, Выкса, Новая, МОУ ДОД СюТУР	f	large
54008	61305	634	Нижегородская область, Выкса, Лепсе, 9 , металлургический техникум	f	large
54015	61311	641	Нижегородская область, Выкса, Красные Зори, 26, школа 8	f	large
54020	61238	646	Нижегородская область, Выкса, Гастелло, 68, школа 4	f	large
54018	61314	644	Нижегородская область, Выкса, Амбулаторная, 6, школа 11	f	large
54019	61225	645	Нижегородская область, Выкса, 1 Мая, клуб Факел	f	large
54007	61304	633	Нижегородская область, Выкса, м-н Жуковского, 6/1, школа 9	f	large
54174	61468	807	Нижегородская область, Бор, Республиканская, 37, ОАО Борский водоканал	f	large
53733	61029	327	Нижегородская область, Бор, Октябрьская, 9а, МБУК Октябрьский Дом культуры-музей	f	large
55761	62780	2501	Нижегородская область, Бор, Молодежная, 4, МБОУ ДОД Дом детского творчества Каравелла	f	medium
53736	61032	330	Нижегородская область, Бор, Молодежная, 6, ФОК поселка Октябрьский	f	large
53727	61023	321	Нижегородская область, Бор, Максима Горького , 70а, МБОУ ДОД Детский сад № 25	f	large
68224	61002	298	Нижегородская область, Бор, Коммунистическая, 11, МБОУ Лицей	f	large
111741	61074	371	Нижегородская область, Бор , 8 Марта, 13, МБОУ Средняя Общеобразовательная школа №4	f	medium
53719	61016	313	Нижегородская область, Бор, переулок Советский, 9, ГОУ СПО Нижегородский обл. колледж культуры	f	large
53700	60999	293	Нижегородская область, Бор, Энгельса, 14, Детская поликлиника городской больницы № 1	t	large
53714	61011	308	Нижегородская область, Бор, Фигнер, 2б, ГОУ ДОД СДЮШОР по греко-римской борьбе	f	large
53713	61010	307	Нижегородская область, Бор, Фигнер, 1, МБОУ Основная общеобразовательная школа №5	f	large
53715	61012	309	Нижегородская область, Бор, Суворова, 15, МБОУ Средняя Общеобразовательная школа	f	large
53776	61073	370	Нижегородская область, Бор, Строительная, 12, МБОУ ДОД Детская школа искусств	f	medium
53709	61006	303	Нижегородская область, Бор, Стеклозаводское шоссе, 15, ДК "МБУК "Стеклозаводский"	f	large
53708	61006	302	Нижегородская область, Бор, Стеклозаводское шоссе, 15, ДК "МБУК "Стеклозаводский"	f	large
53718	61015	312	Нижегородская область, Бор, Профсоюзная, 8а, МБОУ средняя Общеобразовательная Школа №6	f	large
53729	61024	323	Нижегородская область, Бор, Плеханова, 1, МБОУ Средняя Общеобразовательная Школа №1	f	large
53728	61024	322	Нижегородская область, Бор, Плеханова, 1, МБОУ Средняя Общеобразовательная Школа №1	f	large
53711	61008	305	Нижегородская область, Бор, Первомайская, 9а, МУК Борская межпоселенческая библиотека	f	large
54173	61467	806	Нижегородская область, Бор, Октябрьская, 82, МБОУ Средняя Общеобразовательная Школа №2,	f	large
53716	61013	310	Нижегородская область, Бор, Октябрьская, 82, МБОУ Средняя Общеобразовательная Школа № 2.	f	large
68225	61009	306	Нижегородская область, Бор, Нахимова, 33, МАУ Управление благоустройства городского округа город Бор	f	large
53707	61005	301	Нижегородская область, Бор, Мира, 27, ГОУ СПО Борский стекольный индустриально-экономический техникум	f	large
53706	61004	300	Нижегородская область, Бор, Махалова, 3, Дом быта Ромашка	f	large
53705	61003	299	Нижегородская область, Бор, Махалова, 8, МБОУ Борский межшкольный учебный комбинат	f	large
53759	61056	353	Нижегородская область, Бор, Лермонтова, 2, МБОУ Средняя Общеобразовательная Школа № 11	f	large
53710	61007	304	Нижегородская область, Бор, Лермонтова, 2, Средняя Общеобразовательная Школа № 11	f	large
53717	61014	311	Нижегородская область, Бор, Ленина, 152, МУК Культурный центр Теплоход	f	large
53730	61026	324	Нижегородская область, Бор, Коммунистическая, 28, Борский психоневрологический интернат	t	small
53722	61019	316	Нижегородская область, Бор, Кольцова, 16, ОАО Борский Автозавод	f	medium
54175	61469	808	Нижегородская область, Бор, Интернациональная, 135а, ЗАО "Борская ДПМК"	f	large
53721	61018	315	Нижегородская область, Бор, Интернациональная, 26, МБУК Центр культуры Октябрь	f	large
53723	61020	317	Нижегородская область, Бор, Воровского, 73, МОУ Открытая (сменная) общеобразовательная школа	f	large
53724	61020	318	Нижегородская область, Бор, Воровского, 73, МОУ Открытая (сменная) общеобразовательная школа	f	large
53726	61022	320	Нижегородская область, Бор, Ванеева, 43а, МБОУ Средняя Общеобразовательная Школа №3	f	large
53725	61021	319	Нижегородская область, Бор, Ванеева, 43а, Средняя общеобразовательная школа №3	f	large
68226	61017	314	Нижегородская область, Бор, 8 Марта, 13, МБОУ Средняя Общеобразовательная школа №4	f	large
53703	61001	297	Нижегородская область, Бор, 2-й Микрорайон, 24, МБОУ ДОД ЦВР Маяк	f	large
53701	61000	295	Нижегородская область, Бор, 2 микрорайон, 8, МБОУ Средняя общеобразовательная школа №8	f	large
53702	61000	296	Нижегородская область, Бор, 2 микрорайон, 8, МБОУ Средняя общеобразовательная школа №8	f	large
53612	60911	191	Нижегородская область, Бор, 2 микрорайон, 3, Библиотека	f	large
53625	60923	206	Нижегородская область, Богородск	f	large
53624	60923	205	Нижегородская область, Богородск	f	large
53620	60919	201	Нижегородская область, Богородск	f	large
53615	60914	196	Нижегородская область, Богородск	f	large
53613	60912	194	Нижегородская область, Богородск	f	large
53634	60932	215	Нижегородская область, Богородск, Механизаторов, 7а	f	small
53617	60916	198	Нижегородская область, Богородск, Героя Усилова, 1	f	medium
68209	60892	171	Нижегородская область, Балахна, 40 лет Пионерской организации, 16, Школа №14	f	large
53550	60853	129	Нижегородская область, Арзамас, улица Парковая, 16/1	f	large
53541	60845	120	Нижегородская область, Арзамас, улица Мира, 1	f	large
53540	60844	119	Нижегородская область, Арзамас, улица Мира, 19/3	f	large
53539	60843	118	Нижегородская область, Арзамас, улица Мира, 19к2	f	large
53537	60841	116	Нижегородская область, Арзамас, улица 9 Мая, 29а	f	large
53536	60841	115	Нижегородская область, Арзамас, улица 9 Мая, 29а	f	large
53559	60862	138	Нижегородская область, Арзамас, проспект Ленина, 101	f	large
53547	60850	126	Нижегородская область, Арзамас, проспект Ленина, 200	f	large
53546	60849	125	Нижегородская область, Арзамас, проспект Ленина, 206а	f	large
53563	60866	142	Нижегородская область, Арзамас, площадь Соборная, 7	f	large
53573	60874	152	Нижегородская область, Арзамас, Центральная, 4	f	large
53567	60869	146	Нижегородская область, Арзамас, Урицкого, 15	f	large
53566	60869	145	Нижегородская область, Арзамас, Урицкого, 15	f	large
53535	60840	114	Нижегородская область, Арзамас, Семашко, 21	f	large
53534	60840	113	Нижегородская область, Арзамас, Семашко, 21	f	large
53548	60851	127	Нижегородская область, Арзамас, Севастопольская, 15	f	large
53561	60864	140	Нижегородская область, Арзамас, Свободы, 9	f	large
53564	60867	143	Нижегородская область, Арзамас, Пушкина, 138/1	f	large
53555	60858	134	Нижегородская область, Арзамас, Пландина, 25	f	large
53552	60855	131	Нижегородская область, Арзамас, Парковая, 18	f	large
53551	60854	130	Нижегородская область, Арзамас, Парковая, 16	f	large
53545	60848	124	Нижегородская область, Арзамас, Нижегородская, 3А	f	large
53538	60842	117	Нижегородская область, Арзамас, Мира, 19к1	f	large
53565	60868	144	Нижегородская область, Арзамас, Максима Горького, 56	f	medium
53562	60865	141	Нижегородская область, Арзамас, Максима Горького, 25	f	large
68207	60870	147	Нижегородская область, Арзамас, Ленина, 99	f	large
53530	60837	109	Нижегородская область, Арзамас, Красный путь, 40	f	large
53529	60837	108	Нижегородская область, Арзамас, Красный путь, 40	f	large
53560	60863	139	Нижегородская область, Арзамас, Карла Маркса, 36	f	medium
53557	60860	136	Нижегородская область, Арзамас, Калинина, 29	f	medium
53556	60859	135	Нижегородская область, Арзамас, Калинина, 13А	f	large
53549	60852	128	Нижегородская область, Арзамас, Калинина, 41	f	large
53533	60839	112	Нижегородская область, Арзамас, Зеленая, 18	f	large
53532	60838	111	Нижегородская область, Арзамас, Зеленая, 34	f	large
53531	60838	110	Нижегородская область, Арзамас, Зеленая, 34	f	large
53554	60857	133	Нижегородская область, Арзамас, Жуковского, 2	f	large
53553	60856	132	Нижегородская область, Арзамас, Жуковского, 8	f	large
53569	60871	148	Нижегородская область, Арзамас, Володарского, 80	f	large
53570	60872	149	Нижегородская область, Арзамас, Вахтерова, 18/4	f	large
53544	60847	123	Нижегородская область, Арзамас, 9 Мая, 7	f	large
53542	60846	121	Нижегородская область, Арзамас, 9 Мая, 6	f	large
53543	60833	122	Нижегородская область, Арзамас, 9 Мая, 2	f	large
53574	60875	153	Нижегородская область, Арзамас, 11 микрорайон , 51	f	large
53572	60873	151	Нижегородская область, Арзамас, 11 микрорайон, 11	f	large
53571	60873	150	Нижегородская область, Арзамас, 11 микрорайон, 11	f	large
53558	60861	137	Нижегородская область, Арзамас, 1 Мая, 53А	f	large
55740	62759	2468	Нижегородская область, Шахунский район, село Щербаж	t	small
55722	62741	2450	Нижегородская область, Шахунский район, Шахунья	f	large
55726	62745	2454	Нижегородская область, Шахунский район, Шахунья, Черняховского, 16, КРЦ Прогресс	f	large
55724	62743	2452	Нижегородская область, Шахунский район, Шахунья, Чапаева, 1, Шахунский Городской ДК	f	large
55723	62742	2451	Нижегородская область, Шахунский район, Шахунья, Советская, 37, здание ОАО НТК	f	large
55727	62746	2455	Нижегородская область, Шахунский район, Шахунья, Пасхина, 4, ФСК Надежда	f	large
55730	62749	2458	Нижегородская область, Шахунский район, Шахунья, Ленина, 124, Шахунский центр образования	f	large
55729	62748	2457	Нижегородская область, Шахунский район, Шахунья, Ленина, 100, МОУ Шахунская СОШ №2	f	large
55728	62747	2456	Нижегородская область, Шахунский район, Шахунья, Комсомольская, 5, МОУ гимназия им. А.С. Пушкина	f	large
55725	62744	2453	Нижегородская область, Шахунский район, Шахунья, Комсомольская, 27, МОУ Шахунская СОШ № 14	f	large
55751	62771	2479	Нижегородская область, Шахунский район, село Черное, Октябрьская, 18, здание администрации	f	medium
55744	62764	2472	Нижегородская область, Шахунский район, село Хмелевицы	f	large
55752	62772	2480	Нижегородская область, Шахунский район, деревня Туманино, Молодежная, 21, сельский Дом культуры	f	medium
55736	62755	2464	Нижегородская область, Шахунский район, поселок Сява, Просвещения, 4-а, МОУ Сявская СОШ	f	large
55735	62754	2463	Нижегородская область, Шахунский район, поселок Сява, Ленина, 17, Сявский МП ДК	f	large
55750	62770	2478	Нижегородская область, Шахунский район, село Никитиха	f	small
55738	62757	2466	Нижегородская область, Шахунский район, село Мелешиха, Молодежная, 2-а, МС ДК	f	small
55739	62758	2467	Нижегородская область, Шахунский район, село Мартяхино	f	small
55745	62765	2473	Нижегородская область, Шахунский район, поселок Малиновка, Новая, 1, МДОУ Малиновский д/с	f	small
55749	62769	2477	Нижегородская область, Шахунский район, село Лужайки	f	large
55746	62766	2474	Нижегородская область, Шахунский район, село Красногор, Центральная, 11, сельский Дом культуры	f	medium
53645	60944	226	Нижегородская область, Шахунский район, село Комсомольский, Полевая, 7	f	small
55743	62763	2471	Нижегородская область, Шахунский район, село Верховское, Центральная, 5, здание администрации	f	small
55733	62752	2461	Нижегородская область, Шахунский район, поселок Вахтан, Ленина, 12, МОУ Вахтанская СОШ	f	medium
55731	62750	2459	Нижегородская область, Шахунский район, поселок Вахтан, Ленина, 17, МДОУ Вахтанский д/с &quot;&quot;Елочка&quot;&quot;&quot;	f	large
55734	62753	2462	Нижегородская область, Шахунский район, поселок Вахтан, Карповская, 35-а, МОУ ДОД Вахтанский ДЮЦ	f	medium
68331	62751	2460	Нижегородская область, Шахунский район, поселок Вахтан, Карповская, 20-а, Муниципальный поселковый Вахтанский Дворец культуры	f	large
55748	62768	2476	Нижегородская область, Шахунский район, село Большое Широкое, Широковская, 10, здание администрации	f	small
55742	62761	2470	Нижегородская область, Шахунский район, село Большая Свеча, Школьная, 8, МОУ Большесвечанская ООШ	f	small
55741	62760	2469	Нижегородская область, Шахунский район, село Большая Музя	f	small
55747	62767	2475	Нижегородская область, Шахунский район, село Андрианово, Школьная, 2, МОУ Хмелевицкая СОШ	f	small
55737	62756	2465	Нижегородская область, Шахунский район, село Акаты, Новая, 10, здание администрации	f	small
86748	62719	2419	Нижегородская область, Шатковский район, п. Светлогорск, Ленина, 4, здание администрации сельсовета	f	small
86758	62736	2435	Нижегородская область, Шатковский район, село Языково, Мира, 11, Дом культуры	f	small
55690	62711	2412	Нижегородская область, Шатковский район, поселок Шатки, Центральная, 22	f	large
55689	62710	2411	Нижегородская область, Шатковский район, поселок Шатки, Ленина, 142	f	large
55688	62709	2410	Нижегородская область, Шатковский район, поселок Шатки, Железнодорожная, 27	f	large
55691	62712	2413	Нижегородская область, Шатковский район, поселок Шатки, 1 Микрорайон, 12	f	large
55692	62713	2414	Нижегородская область, Шатковский район, поселок Шатки, 1 Мая, 1	f	large
86757	62735	2434	Нижегородская область, Шатковский район, село Шарапово, Центральная, 24, школа	f	small
86759	62737	2436	Нижегородская область, Шатковский район, село Чапары	f	small
86756	62733	2432	Нижегородская область, Шатковский район, село Старое Иванцево	f	small
111824	62723	2423	Нижегородская область, Шатковский район, село Спасское, 60 лет Октября, 4, Дом культуры	f	medium
86755	62732	2431	Нижегородская область, Шатковский район, село Смирново	f	small
111825	62729	2428	Нижегородская область, Шатковский район, село Силино, Советская, 48, Дом культуры	f	medium
111821	62716	2416	Нижегородская область, Шатковский район, село Понетаевка, Советская, 40, административное здание	f	medium
86753	62728	2427	Нижегородская область, Шатковский район, село Пасьяново, Молодежная, 50, Дом культуры	f	small
86749	62721	2421	Нижегородская область, Шатковский район, село Паново, Советская, 24, школа	f	small
86754	62730	2429	Нижегородская область, Шатковский район, село Новое, Коммунистическая, 29, клуб	f	small
55693	62715	2415	Нижегородская область, Шатковский район, село Лесогорск, Электриков, 4	f	medium
86752	62727	2426	Нижегородская область, Шатковский район, село Красный Бор, Молодежная, 7, Дом культуры	f	small
86750	62724	2424	Нижегородская область, Шатковский район, село Костянка, Школьная, 1, школа	f	small
55695	62717	2417	Нижегородская область, Шатковский район, село Ключищи, Центральная, 54	f	small
111823	62722	2422	Нижегородская область, Шатковский район, село Кержемок	f	medium
111826	62731	2430	Нижегородская область, Шатковский район, село Калапино	f	medium
111822	62720	2420	Нижегородская область, Шатковский район, село Елховка	f	medium
86760	62739	2437	Нижегородская область, Шатковский район, село Выползово	f	small
111827	62734	2433	Нижегородская область, Шатковский район, село Великий Враг, Учительская, 2, Смирновский сельсовет, школа	f	medium
86751	62725	2425	Нижегородская область, Шатковский район, село Большие Печерки, Центральная, 61, школа	f	small
55696	62718	2418	Нижегородская область, Шатковский район, село Архангельское	f	large
55672	62693	2393	Нижегородская область, Шарангский район, село Щенники, Центральная, 29, Щенниковский сельсовет	f	small
55684	62705	2406	Нижегородская область, Шарангский район, село Щекотово, 45	f	small
55669	62690	2390	Нижегородская область, Шарангский район, поселок Шаранга	f	large
55670	62691	2391	Нижегородская область, Шарангский район, поселок Шаранга, Парковая, 2	f	large
55668	62689	2389	Нижегородская область, Шарангский район, поселок Шаранга, Ленина, 19	f	large
44454	42592	1077	Кировская область, Слободской, Советская, 91	f	large
86747	62697	2397	Нижегородская область, Шарангский район, поселок Шаранга, Большевиков, 22, здание детской школы искусств	f	small
55685	62706	2407	Нижегородская область, Шарангский район, село Черномуж	f	small
55686	62707	2408	Нижегородская область, Шарангский район, село Туманка, Молодежная, 1	f	small
55683	62704	2405	Нижегородская область, Шарангский район, село Старая Рудка, Колхозная, 1	f	small
55680	62701	2402	Нижегородская область, Шарангский район, село Роженцово, Учительская, 8	f	medium
55678	62700	2400	Нижегородская область, Шарангский район, село Преображенка, 13	t	small
55681	62702	2403	Нижегородская область, Шарангский район, село Поздеево	f	small
55675	62696	2396	Нижегородская область, Шарангский район, село Пестово	f	small
55687	62708	2409	Нижегородская область, Шарангский район, село Мосуново, Колхозная, 1а	f	small
55677	62699	2399	Нижегородская область, Шарангский район, село Кушнур	f	small
55674	62695	2395	Нижегородская область, Шарангский район, село Кугланур, Заречная, 21	f	small
55682	62703	2404	Нижегородская область, Шарангский район, село Красная Горка, Центральная, 8	t	small
55679	62687	2401	Нижегородская область, Шарангский район, село Козлянур, 32	t	small
55671	62692	2392	Нижегородская область, Шарангский район, село Большое Устинское	f	medium
55676	62698	2398	Нижегородская область, Шарангский район, село Большая Рудка, Советская, 9в	f	small
55673	62694	2394	Нижегородская область, Шарангский район, село Астанчурга, Главная, 57	f	small
55652	62673	2373	Нижегородская область, Чкаловский район, Чкаловск	f	large
55653	62674	2374	Нижегородская область, Чкаловский район, Чкаловск, пл.Чкалова, здание ДКС	f	large
55649	62670	2370	Нижегородская область, Чкаловский район, Чкаловск, Матросова, 23	f	large
55650	62671	2371	Нижегородская область, Чкаловский район, Чкаловск, Ломоносова, 59	f	large
55651	62672	2372	Нижегородская область, Чкаловский район, Чкаловск, Комсомольская, 8	f	medium
55648	62669	2369	Нижегородская область, Чкаловский район, Чкаловск, Комсомольская, 15	f	large
55655	62676	2376	Нижегородская область, Чкаловский район, поселок Чистое	t	medium
86745	62686	2386	Нижегородская область, Чкаловский район, село Соломаты	f	small
55663	62684	2384	Нижегородская область, Чкаловский район, село Сицкое, Парковая, 57	f	small
55664	62685	2385	Нижегородская область, Чкаловский район, село Пурех, Ленина, 66	f	large
86744	62683	2383	Нижегородская область, Чкаловский район, село Новинки, Кооперативная, 10, здание Новинского «Центра ремесел и досуга»	f	small
55660	62681	2381	Нижегородская область, Чкаловский район, село Кузнецово	f	large
55658	62679	2379	Нижегородская область, Чкаловский район, село Котельницы	f	medium
55606	62626	2326	Нижегородская область, Чкаловский район, село Кодочиги, площадь Центральная, 1, здание Кодочиговской администрации	t	small
55654	62675	2375	Нижегородская область, Чкаловский район, поселок Катунки, Чкалова, 1	f	medium
55659	62680	2380	Нижегородская область, Чкаловский район, поселок Катунки, Садовая, 3	f	small
86746	62688	2387	Нижегородская область, Чкаловский район, село Железово	f	small
55661	62682	2382	Нижегородская область, Чкаловский район, деревня Высокая, Здание Высоковского СДК	f	small
55657	62678	2378	Нижегородская область, Чкаловский район, село Вершилово, Чкалова, 31	f	medium
55656	62677	2377	Нижегородская область, Чкаловский район, село Белое, Центральная, 54	f	small
55646	62667	2367	Нижегородская область, Уренский район, село Уста, Октябрьская, 22-а, средняя школа,фойе	f	large
55647	62668	2368	Нижегородская область, Уренский район, село Уста, Коммунистическая, 6-а, здание администрации	f	medium
55620	62639	2340	Нижегородская область, Уренский район, Урень	f	medium
55617	62636	2337	Нижегородская область, Уренский район, Урень	f	large
55616	62635	2336	Нижегородская область, Уренский район, Урень	f	medium
55611	62630	2331	Нижегородская область, Уренский район, Урень, Центральная, 46-а, кафе Лагуна	f	medium
55614	62633	2334	Нижегородская область, Уренский район, Урень, Труда, 49, здание инф.диагностическ.центра	f	large
55612	62631	2332	Нижегородская область, Уренский район, Урень, Льнозавод, ИП Серышев, бывшая весовая	f	medium
55615	62634	2335	Нижегородская область, Уренский район, Урень, Ленина, 171, коррекционная школа, уч.класс	f	large
55613	62632	2333	Нижегородская область, Уренский район, Урень, Ленина, 67, РДК,фойе,1 этаж	f	large
55619	62638	2339	Нижегородская область, Уренский район, Урень, Индустриальная, 12, средняя школа №2,фойе,1 этаж	f	large
55618	62637	2338	Нижегородская область, Уренский район, Урень, Индустриальная, 6-а, спортзал ДЮСШ	f	large
55634	62654	2355	Нижегородская область, Уренский район, село Тулага, Комсомольская, 1-а, СДК,танцевальный зал	f	small
111820	62665	2365	Нижегородская область, Уренский район, село Темта, Молодежная, 2-а, Сельский дом культуры	f	medium
55641	62662	2362	Нижегородская область, Уренский район, село Семеново, Смирнова, 44, комната отдыха СДК	f	small
55640	62660	2361	Нижегородская область, Уренский район, село Обход, Ленина, 9, здание сельской администрации	f	small
55639	62659	2360	Нижегородская область, Уренский район, село Минеево, Репина, 16, СДК,зрительный зал	f	small
55645	62666	2366	Нижегородская область, Уренский район, село Ломы, Комсомольская, 2-а, СДК,актовый зал	f	small
55643	62664	2364	Нижегородская область, Уренский район, село Красный Яр, клуб санатория Красный ЯР	f	small
55632	62652	2352	Нижегородская область, Уренский район, село Копылиха	t	small
55636	62656	2357	Нижегородская область, Уренский район, село Карпуниха, Махалова, 103, СДК,танцевальный зал	f	small
55631	62651	2351	Нижегородская область, Уренский район, село Вязовая, Школьная, 2, начальная школа	f	small
55629	62648	2349	Нижегородская область, Уренский район, село Большой Терсень, Мира, 3, СДК,танцевальный зал	f	medium
55638	62658	2359	Нижегородская область, Уренский район, село Большой Красногор, Советская, 1, СДК,зрительный зал	f	small
55626	62645	2346	Нижегородская область, Уренский район, село Большое Песочное, Центральная, 2, СДК,зрительный зал	f	small
55630	62650	2350	Нижегородская область, Уренский район, село Большое Никитино, Молодежная, 14, СДК,фойе	f	small
55628	62647	2348	Нижегородская область, Уренский район, село Большое Непряхино, Школьная, 1, здание детского сада "Малыш"	f	small
55642	62663	2363	Нижегородская область, Уренский район, село Большое Лопатино, Первомайская, мед.пункт	t	small
111819	62655	2356	Нижегородская область, Уренский район, село Большое Карпово, Школьная, 11-а, Карповский сельсовет	f	medium
55633	62653	2354	Нижегородская область, Уренский район, село Большое Горево	f	small
55637	62657	2358	Нижегородская область, Уренский район, село Большая Козляна	t	small
55627	62646	2347	Нижегородская область, Уренский район, село Большая Елховка, Центральная, 35, ФАП	t	small
55625	62644	2345	Нижегородская область, Уренский район, село Большая Арья, Центральная, 8, здание сельской администрации	f	medium
55624	62643	2344	Нижегородская область, Уренский район, поселок Арья, Юбилейная, 10, кафе Манхэттен	f	medium
55621	62640	2341	Нижегородская область, Уренский район, поселок Арья, Школьная, 1, средняя школа, уч.класс,1 этаж	f	medium
55623	62642	2343	Нижегородская область, Уренский район, поселок Арья, Строителей, Арьевская ДЮСШ,спортзал	f	large
55622	62641	2342	Нижегородская область, Уренский район, поселок Арья, Карла Маркса, 10, здание администрации р.п.Арья	f	large
55607	62627	2327	Нижегородская область, Тоншаевский район, село Южный, Центральная, 12, здание Южной ООШ	t	small
55594	62614	2314	Нижегородская область, Тоншаевский район, село Ширта, Молодежная, 28, здание сельского Дома культуры	f	small
55605	62624	2325	Нижегородская область, Тоншаевский район, село Шерстки, 8, Клубная здание сельского Дома культуры	f	small
55599	62618	2319	Нижегородская область, Тоншаевский район, поселок Шайгино, Вокзальная, 20, здание Шайгинской поселковой администрации	f	medium
86742	62612	2311	Нижегородская область, Тоншаевский район, поселок Тоншаево	f	small
55591	62611	2310	Нижегородская область, Тоншаевский район, поселок Тоншаево, 3, Клубное здание Дома культуры	f	small
55588	62608	2307	Нижегородская область, Тоншаевский район, поселок Тоншаево	f	medium
55587	62608	2306	Нижегородская область, Тоншаевский район, поселок Тоншаево	f	medium
55589	62609	2308	Нижегородская область, Тоншаевский район, поселок Тоншаево, Свердлова, 2А, здание Тоншаевской районной администрации	f	large
55590	62610	2309	Нижегородская область, Тоншаевский район, поселок Тоншаево, Заречная, 46, здание Дома культуры	f	small
55602	62621	2322	Нижегородская область, Тоншаевский район, село Сухой Овраг, 3, Центральная здание сельского Дома культуры	f	small
55756	62774	2492	Нижегородская область, Тоншаевский район, село Ромачи, 9А, Центральная здание медпункта	t	small
55598	62617	2318	Нижегородская область, Тоншаевский район, поселок Пижма, Кирова, 3, здание Дома культуры Юбилейный	f	medium
55597	62617	2317	Нижегородская область, Тоншаевский район, поселок Пижма, Кирова, 3, здание Дома культуры Юбилейный	f	medium
55596	62616	2316	Нижегородская область, Тоншаевский район, поселок Пижма, Кирова, 45А, здание Пижемской поселковой администрации	f	medium
111818	62615	2315	Нижегородская область, Тоншаевский район, поселок Пижма, Калинина, 8, здание МОУ Пижемской средней общеобразовательной школы	f	medium
55608	62628	2328	Нижегородская область, Тоншаевский район, село Ошминское	t	small
55601	62620	2321	Нижегородская область, Тоншаевский район, село Гагаринское, 2, Центральное здание сельского Дома культуры	f	small
55603	62622	2323	Нижегородская область, Тоншаевский район, село Вякшенер, Центральная, 19, здание сельского Дома культуры	f	small
55604	62623	2324	Нижегородская область, Тоншаевский район, село Буреполом, Октябрская , 5, здание Одошнурской сельской администрации	f	medium
55609	62629	2329	Нижегородская область, Тоншаевский район, село Большие Селки, Центральная, 52, здание Дома культуры	f	small
55593	62613	2313	Нижегородская область, Тоншаевский район, село Большая Куверба, Центральная, 11А, здание сельского Дома культуры	f	small
86743	62619	2320	Нижегородская область, Тоншаевский район, село Березята, Центральная, 36, здание бывшего МОУ для детей дошкольного и младшего школьного возраста Березятская начальная общеобразовательная школа-сад	t	small
86800	62605	2303	Нижегородская область, Тонкинский район, село Трошково, Хутор, 15 а	t	small
68360	62597	2294	Нижегородская область, Тонкинский район, поселок Тонкино, Ленина, 3 Б	f	large
68359	62596	2293	Нижегородская область, Тонкинский район, поселок Тонкино, Гагарина, 9	f	large
55585	62606	2304	Нижегородская область, Тонкинский район, село Степановское, Центральная, 4	t	small
55721	62740	2449	Нижегородская область, Тонкинский район, село Старые Краи, 36, здание начальной школы	f	small
55586	62607	2305	Нижегородская область, Тонкинский район, село Полянское, Центральная, 2	t	small
86798	62604	2301	Нижегородская область, Тонкинский район, село Пахутино, Молодежная, 20 а	t	small
86799	62565	2302	Нижегородская область, Тонкинский район, село Пакали, Центральная, 42 б	t	small
86795	62601	2298	Нижегородская область, Тонкинский район, село Кодочиги, Центральная, 23	f	small
86794	62600	2297	Нижегородская область, Тонкинский район, село Вязовка	f	small
55758	62776	2495	Нижегородская область, Тонкинский район, село Вая, 58, здание фельдшерского акушерского пункта	t	small
86796	62602	2299	Нижегородская область, Тонкинский район, село Большое Содомово	f	small
86797	62603	2300	Нижегородская область, Тонкинский район, село Большое Сидорово, Специалистов, 5	t	small
55576	62598	2295	Нижегородская область, Тонкинский район, село Большое Ларионово, Молодежная, 1а, Бердниковский сельсовет	f	small
111817	62599	2296	Нижегородская область, Тонкинский район, село Бердники, Школьная, 18	f	medium
55569	62594	2288	Нижегородская область, Спасский район, село Турбанка, Рабочая, 29	f	medium
86793	62582	2274	Нижегородская область, Спасский район, село Тукай, Полевая, 110в, здание сельского Дома культуры	f	small
55556	62581	2273	Нижегородская область, Спасский район, село Тубанаевка	t	small
55568	62593	2287	Нижегородская область, Спасский район, село Татарское Маклаково, Энгельса, 1а	t	medium
55567	62592	2286	Нижегородская область, Спасский район, село Татарское Маклаково, Советская, 8 а	f	small
55565	62590	2283	Нижегородская область, Спасский район, село Спасское	f	small
55563	62588	2281	Нижегородская область, Спасский район, село Спасское, площадь Революции, 59	f	large
111739	61052	349	Нижегородская область, Спасский район, село Спасское, Центральная , 8, МБДОУ Спасский детский сад Подсолнушек	f	medium
55564	62589	2282	Нижегородская область, Спасский район, село Спасское, Октябрьская, 69	f	large
55561	62586	2278	Нижегородская область, Спасский район, село Сосновка	f	small
55560	62585	2277	Нижегородская область, Спасский район, село Русское Маклаково, Советская, 103	f	small
55558	62583	2275	Нижегородская область, Спасский район, село Новый Усад, Молодежная, 12а	f	small
55562	62587	2279	Нижегородская область, Спасский район, село Масловка, Торговая, 35	f	small
55555	62580	2272	Нижегородская область, Спасский район, село Красный Ватрас, Советская, 15 а	f	medium
68229	60813	74	Нижегородская область, Спасский район, село Кирилловка	f	large
55549	62574	2265	Нижегородская область, Спасский район, село Ишеево, Мира, 94Б	f	small
55559	62584	2276	Нижегородская область, Спасский район, село Ивановское, Почтовая, 56	t	small
55566	62591	2285	Нижегородская область, Спасский район, село Елховка, Свободы, 35	f	small
55551	62576	2268	Нижегородская область, Спасский район, село Горки, Центральная, 131	f	small
55554	62579	2271	Нижегородская область, Спасский район, село Высокий Оселок	f	small
86792	62577	2269	Нижегородская область, Спасский район, село Вазьянка, Вазьянский сельсовет, здание администрации	f	small
55550	62575	2267	Нижегородская область, Спасский район, село Бронский Ватрас, Центральная, 94	f	small
55548	62573	2264	Нижегородская область, Спасский район, село Базлово, Молодежная, 12	f	small
55570	62595	2289	Нижегородская область, Спасский район, село Антоново, Молодежная, 10 а	f	small
55546	62571	2262	Нижегородская область, Сосновский район, село Яковское, Восточная, 58, здание администрации	f	small
55528	62552	2244	Нижегородская область, Сосновский район, село Сурудово, Фрунзе, 8, здание школы	f	small
55537	62561	2253	Нижегородская область, Сосновский район, село Стечкино	f	small
55516	62540	2232	Нижегородская область, Сосновский район, поселок Сосновское	f	medium
55520	62544	2236	Нижегородская область, Сосновский район, поселок Сосновское, Совхозная, 1-А, ООО Сосновскдорремстрой	f	small
55523	62547	2239	Нижегородская область, Сосновский район, поселок Сосновское, Профсоюзная, 24, Сосновская ЦРБ	t	medium
55514	62538	2230	Нижегородская область, Сосновский район, поселок Сосновское, Октябрьская, 12, детсад Колокольчик	f	medium
55515	62539	2231	Нижегородская область, Сосновский район, поселок Сосновское, Нижегородская, 4, школа № 2	f	large
86761	62778	2499	Нижегородская область, Сосновский район, поселок Сосновское, Ленина, 25, здание Земского Собрания	f	small
55518	62542	2234	Нижегородская область, Сосновский район, поселок Сосновское, Ленина, 96, детсад	f	medium
55513	62537	2229	Нижегородская область, Сосновский район, поселок Сосновское, Ленина, 23, САПТ техникум	f	medium
55519	62543	2235	Нижегородская область, Сосновский район, поселок Сосновское, Комсомольская, 22, Дискотечный зал	f	medium
55517	62541	2233	Нижегородская область, Сосновский район, поселок Сосновское, Комсомольская, 18, Дом пионеров	f	medium
55525	62549	2241	Нижегородская область, Сосновский район, село Созоново	f	small
55536	62560	2252	Нижегородская область, Сосновский район, село Сиуха	t	small
86791	62570	2261	Нижегородская область, Сосновский район, село Селитьба	f	small
111816	62569	2260	Нижегородская область, Сосновский район, село Селитьба, пер. Северный, 10, здание администрации	f	medium
55534	62558	2250	Нижегородская область, Сосновский район, село Рыльково, Фабричная, 46, здание клуба	t	small
55542	62567	2258	Нижегородская область, Сосновский район, село Рожок, Микрорайон, 7, здание школы	f	small
86790	62563	2255	Нижегородская область, Сосновский район, село Рагозино, Шуваловой, 74, здание сельского клуба	f	small
55538	62562	2254	Нижегородская область, Сосновский район, село Панино, Советская, 56А, здание Дома культуры	f	small
55541	62566	2257	Нижегородская область, Сосновский район, село Николаевка	f	small
55535	62559	2251	Нижегородская область, Сосновский район, село Матюшево, Младенцева, 1А, здание медпункта	t	small
55532	62556	2248	Нижегородская область, Сосновский район, село Малахово, Совхозная, 7, здание детского сада	f	small
55543	62568	2259	Нижегородская область, Сосновский район, село Макасово	f	small
55540	62564	2256	Нижегородская область, Сосновский район, село Лесуново	f	small
55533	62557	2249	Нижегородская область, Сосновский район, село Крутые, Советская, 12, сельская администрация	f	small
55418	62445	2126	Нижегородская область, Сергачский район, Сергач, Вокзальная, 50	f	large
55531	62555	2247	Нижегородская область, Сосновский район, село Клещариха, Овражная, 13, здание Дома культуры	f	small
55547	62572	2263	Нижегородская область, Сосновский район, село Елизарово	f	small
55529	62553	2245	Нижегородская область, Сосновский район, село Елизарово, Парковая, 11, здание Дома культуры	f	small
55521	62545	2237	Нижегородская область, Сосновский район, село Давыдково	f	medium
55527	62551	2243	Нижегородская область, Сосновский район, село Глядково	t	small
55526	62550	2242	Нижегородская область, Сосновский район, село Волчиха, Ленина, 1Б, здание медпункта	t	small
55524	62548	2240	Нижегородская область, Сосновский район, село Виткулово, Белова, 38А, здание Дома культуры	f	small
55522	62546	2238	Нижегородская область, Сосновский район, село Венец, Советская, 4, здание бывшей администрации	f	small
55530	62554	2246	Нижегородская область, Сосновский район, село Богданово, Молодежная, 8, здание школы	f	small
55759	62777	2498	Нижегородская область, Сосновский район, село Бараново, Молодежная, 23, здание детского сада	f	small
86777	62524	2214	Нижегородская область, Сокольский район, село Фатеево, Восточная, 4	f	small
68358	62511	2201	Нижегородская область, Сокольский район, село Сокольское	f	large
68357	62509	2199	Нижегородская область, Сокольский район, поселок Сокольское	f	large
111814	62510	2200	Нижегородская область, Сокольский район, поселок Сокольское, Садовая, 15	f	medium
68356	62508	2198	Нижегородская область, Сокольский район, поселок Сокольское, Калинина, 2	f	large
111813	62507	2197	Нижегородская область, Сокольский район, поселок Сокольское, Докучаева, 52	f	medium
86784	62531	2221	Нижегородская область, Сокольский район, село Селянцево, Большое Бухарино, 22	f	small
86783	62530	2220	Нижегородская область, Сокольский район, село Пушкарево, Школьная, 16	f	small
111815	62512	2202	Нижегородская область, Сокольский район, село Пудово, Зеленая, 2	f	medium
86788	62535	2225	Нижегородская область, Сокольский район, село Пелегово, Школьная, 6	f	small
86775	62522	2212	Нижегородская область, Сокольский район, село Никольское, Школьная, 3	f	small
86768	62515	2205	Нижегородская область, Сокольский район, село Мурзино	f	small
86779	62526	2216	Нижегородская область, Сокольский район, село Молчаново, Центральная, 19	f	small
86771	62518	2208	Нижегородская область, Сокольский район, село Мамонтово	t	small
86789	62536	2226	Нижегородская область, Сокольский район, село Летняя База, Шелехонская, 136	t	small
86772	62519	2209	Нижегородская область, Сокольский район, село Лесной	f	small
86785	62532	2222	Нижегородская область, Сокольский район, село Куртюга, Придорожная, 3, клуб поселка Куртюга	t	small
86770	62517	2207	Нижегородская область, Сокольский район, село Кузнецово, Центральная, 23	f	small
86782	62529	2219	Нижегородская область, Сокольский район, село Кудрино, Поселковая, 1	f	small
86766	62513	2203	Нижегородская область, Сокольский район, село Коренево, Соколова, 22	f	small
86787	62534	2224	Нижегородская область, Сокольский район, село Ковригино, Молодежная, 2	f	small
86769	62516	2206	Нижегородская область, Сокольский район, село Запашка, Молодежная, 18, Запашкинский Дом культуры	f	small
86778	62525	2215	Нижегородская область, Сокольский район, село Заболотное, Молодежная, 2, Заболтновский дом культуры	f	small
86774	62521	2211	Нижегородская область, Сокольский район, село Дресвищи, Школьная, 18, Муниципальное казенное образовательное учреждение «Дресвищенская основная общеобразовательная школа»	f	small
86767	62514	2204	Нижегородская область, Сокольский район, село Дорофеево	f	small
86780	62527	2217	Нижегородская область, Сокольский район, село Георгиевское, Центральная, 3	f	small
86776	62523	2213	Нижегородская область, Сокольский район, село Гари, Молодежная, 3	f	small
86786	62533	2223	Нижегородская область, Сокольский район, село Вилеж, Школьная, 6	f	small
86781	62528	2218	Нижегородская область, Сокольский район, село Боталово, Центральная, 8	f	small
86773	62520	2210	Нижегородская область, Сокольский район, село Березово, Школьная, 1	f	small
68332	62161	1766	Нижегородская область, Советский район, Деревня Кузнечиха, 60	f	large
86765	62500	2188	Нижегородская область, Сеченовский район, совхоз Теплостанский, Школьная, 18в	f	small
55462	62486	2174	Нижегородская область, Сеченовский район, село совхоз Талызинский, Молодежная, 12	f	small
55477	62501	2189	Нижегородская область, Сеченовский район, село Ясное, Центральная, 30	f	small
55481	62505	2193	Нижегородская область, Сеченовский район, село Шемарино	t	small
55479	62503	2191	Нижегородская область, Сеченовский район, село Торговое Талызино, Центральная, 47	t	small
55480	62504	2192	Нижегородская область, Сеченовский район, село Скрипино	t	small
55475	62499	2187	Нижегородская область, Сеченовский район, село Сеченово	f	large
55474	62498	2186	Нижегородская область, Сеченовский район, село Сеченово, площадь Советская, 3	f	large
55464	62488	2176	Нижегородская область, Сеченовский район, село Рогожка, Школьная, 7	f	small
55472	62496	2184	Нижегородская область, Сеченовский район, село Ратово, Большая линия, 23	f	small
55465	62489	2177	Нижегородская область, Сеченовский район, село Николаевка, Школьная, 21а	t	small
55471	62495	2183	Нижегородская область, Сеченовский район, село Мурзицы, Кооперативная, 17	f	medium
55470	62494	2182	Нижегородская область, Сеченовский район, село Митрополье	t	small
55473	62497	2185	Нижегородская область, Сеченовский район, село Мамлейка, Центральная, 1в	f	small
86764	62493	2181	Нижегородская область, Сеченовский район, село Липовка, Школьная, 52	t	small
55468	62492	2180	Нижегородская область, Сеченовский район, село Левашовка, Почтовая, 49а	f	small
55467	62491	2179	Нижегородская область, Сеченовский район, село Красный Остров, Советская, 28	f	small
55466	62490	2178	Нижегородская область, Сеченовский район, село Красное	f	small
55463	62487	2175	Нижегородская область, Сеченовский район, село Кочетовка, Колхозная, 39	f	medium
55457	62481	2169	Нижегородская область, Сеченовский район, село Ильинка, Школьная, 7	f	small
55461	62485	2173	Нижегородская область, Сеченовский район, село Верхнее Талызино	f	medium
55459	62483	2171	Нижегородская область, Сеченовский район, село Васильевка	f	small
55478	62502	2190	Нижегородская область, Сеченовский район, село Булдаково, Запрудная, 33	f	small
55458	62482	2170	Нижегородская область, Сеченовский район, село Болховское, Малые Выселки, 20	t	small
55456	62480	2168	Нижегородская область, Сеченовский район, село Болтинка, Школьная, 11	f	medium
55460	62484	2172	Нижегородская область, Сеченовский район, село Богатиловка, Краснопартизанская, 26В	f	small
55455	62479	2167	Нижегородская область, Сеченовский район, село Бахметьевка, Молодежная, 23	t	small
55453	62477	2165	Нижегородская область, Сеченовский район, село Алферьево, Первомайская, 11а	f	medium
55454	62478	2166	Нижегородская область, Сеченовский район, село Александровка, Андреева, 2	f	small
55447	62471	2157	Нижегородская область, Сергачский район, село Яново, Школьная, 1	f	medium
55446	62470	2156	Нижегородская область, Сергачский район, село Шубино, Советская, 4	f	small
55427	62451	2135	Нижегородская область, Сергачский район, село Толба, Южная, 13А	f	small
55441	62465	2151	Нижегородская область, Сергачский район, село Старая Березовка, Садовая, 2	f	small
55433	62457	2141	Нижегородская область, Сергачский район, село Сосновка, Молодежная, 5	f	small
68355	62446	2127	Нижегородская область, Сергачский район, Сергач	f	large
68354	62444	2125	Нижегородская область, Сергачский район, Сергач, 20а	f	large
55425	62425	2133	Нижегородская область, Сергачский район, Сергач, 15А	f	large
55423	62450	2131	Нижегородская область, Сергачский район, Сергач, пос. Молодежный, 14А	f	large
68353	62443	2124	Нижегородская область, Сергачский район, Сергач, микрорайон Юбилейный, 5а	f	large
55422	62449	2130	Нижегородская область, Сергачский район, Сергач, Ульянова, 157	f	large
55415	62442	2123	Нижегородская область, Сергачский район, Сергач, Ульянова, 1В	f	medium
55412	62439	2120	Нижегородская область, Сергачский район, Сергач, Советская, 49	f	large
55414	62441	2122	Нижегородская область, Сергачский район, Сергач, Свердлова, 70	f	large
55413	62440	2121	Нижегородская область, Сергачский район, Сергач, М. Горького, 35	f	large
55426	62436	2134	Нижегородская область, Сергачский район, Сергач, Лесная, 30	f	large
55420	62447	2128	Нижегородская область, Сергачский район, Сергач, Краснодонцев, 106	f	large
55421	62448	2129	Нижегородская область, Сергачский район, Сергач, Гусева, 54	f	large
55424	62414	2132	Нижегородская область, Сергачский район, Сергач, 60 лет Октября, 3	f	large
55429	62453	2137	Нижегородская область, Сергачский район, село Пожарки	f	medium
86763	62472	2159	Нижегородская область, Сергачский район, село Пица, Центральная, 16б	f	small
55435	62459	2143	Нижегородская область, Сергачский район, село Мокрый Майдан, Школьная, 7	t	small
55452	62476	2163	Нижегородская область, Сергачский район, село Луговое, Луговая, 3	f	small
55430	62454	2138	Нижегородская область, Сергачский район, село Лопатино, Ивлиева, 27	f	small
55450	62474	2161	Нижегородская область, Сергачский район, село Кошкарево, Зеленая, 12	f	small
55445	62469	2155	Нижегородская область, Сергачский район, село Кочко-Пожарки	f	medium
55428	62452	2136	Нижегородская область, Сергачский район, село Камкино, Почтовая, 35	f	small
55443	62467	2153	Нижегородская область, Сергачский район, село Каменка, Колхозная, 7	f	small
55451	62475	2162	Нижегородская область, Сергачский район, село Грибаново, Школьная, 64	f	small
55444	62468	2154	Нижегородская область, Сергачский район, село Вязовка, Овражная, 38А	f	small
55432	62456	2140	Нижегородская область, Сергачский район, село Воскресенское, Советская, 8	f	small
55436	62460	2144	Нижегородская область, Сергачский район, село Вершинино, Зеленая, 26	t	small
55437	62461	2146	Нижегородская область, Сергачский район, село Борисовка	f	small
55434	62458	2142	Нижегородская область, Сергачский район, село Богородское, Молодежная, 9	f	medium
55440	62464	2150	Нижегородская область, Сергачский район, село Ачка, Ленина, 94А	f	small
55438	62462	2148	Нижегородская область, Сергачский район, село Андреевка, пос. Молодежный, 5	f	small
55439	62463	2149	Нижегородская область, Сергачский район, село Анда, Советская, 26А	f	small
55431	62455	2139	Нижегородская область, Сергачский район, село Акузово, Центральная, 82	f	small
55449	62473	2160	Нижегородская область, Сергачский район, село Абаимово, Молодежная, 15	f	small
86721	62408	2087	Нижегородская область, Семеновский район, село Шалдежка, Октябрьская, 12, администрация сельсовета	f	small
86762	62433	2111	Нижегородская область, Семеновский район, село Шалдеж, Новая, 36А, Дом культуры	f	small
111808	62429	2107	Нижегородская область, Семеновский район, село Хахалы, Центральная, 9, средняя школа	f	medium
86722	62409	2088	Нижегородская область, Семеновский район, село Фундриково, 82, администрация сельсовета	f	small
86733	62426	2104	Нижегородская область, Семеновский район, село Успенье, Центральная, 45, Дом культуры	f	small
86730	62421	2100	Нижегородская область, Семеновский район, село Успенское, 1, администрация сельсовета	f	small
111812	62438	2115	Нижегородская область, Семеновский район, Семенов	t	small
68352	62437	2114	Нижегородская область, Семеновский район, Семенов	f	large
68351	62435	2113	Нижегородская область, Семеновский район, Семенов	f	large
111811	62434	2112	Нижегородская область, Семеновский район, Семенов	t	small
86724	62411	2090	Нижегородская область, Семеновский район, Семенов	t	small
68327	62402	2082	Нижегородская область, Семеновский район, Семенов	f	large
68323	62398	2078	Нижегородская область, Семеновский район, Семенов	f	large
68322	62397	2077	Нижегородская область, Семеновский район, Семенов	f	large
68321	62396	2076	Нижегородская область, Семеновский район, Семенов	f	large
68320	62395	2075	Нижегородская область, Семеновский район, Семенов	f	large
68324	62399	2079	Нижегородская область, Семеновский район, Семенов, пл. Ленина, 5, Центр культуры и искусства	f	large
68318	62393	2073	Нижегородская область, Семеновский район, Семенов, Чернышевского, 4, Лицей № 30	f	large
68342	62424	2103	Нижегородская область, Семеновский район, Семенов, Центральная, 2, Дом культуры	f	large
68319	62394	2074	Нижегородская область, Семеновский район, Семенов, Пионерская, 37, средняя школа № 2	f	large
68326	62401	2081	Нижегородская область, Семеновский район, Семенов, Октябрьская, 20, городской Дом культуры	f	large
111807	62420	2099	Нижегородская область, Семеновский район, Семенов, Красноармейская, 2А, Дом культуры	f	medium
68330	62413	2092	Нижегородская область, Семеновский район, Семенов, Колхозная, 147, Дом культуры	f	large
68325	62400	2080	Нижегородская область, Семеновский район, Семенов, 1-е Мая, 27, техникум МОД	f	large
86736	62430	2108	Нижегородская область, Семеновский район, село Светлое, Школьная, 30, администрация сельсовета	f	small
86723	62410	2089	Нижегородская область, Семеновский район, село Полом, Ковернинская, 8, администрация сельсовета	f	small
86731	62422	2101	Нижегородская область, Семеновский район, село Пафнутово, И.Козлова, 66, Дом культуры	f	small
86734	62427	2105	Нижегородская область, Семеновский район, село Осинки, Лесная, 6, Дом культуры	f	small
86729	62419	2098	Нижегородская область, Семеновский район, село Огибное, 5, Дом культуры	f	small
111806	62418	2097	Нижегородская область, Семеновский район, село Никитино, Верхняя, 12А, Дом культуры	f	small
111805	62416	2094	Нижегородская область, Семеновский район, село Медведево, Нижняя, 61А, Дом культуры	f	medium
86735	62428	2106	Нижегородская область, Семеновский район, село Кулагино, Центральная, 31А, Дом культуры	f	small
111810	62432	2110	Нижегородская область, Семеновский район, село Кондратьево, 18А, медпункт	t	small
111803	62405	2084	Нижегородская область, Семеновский район, село Керженец, Новая, 1А, Дом культуры	f	medium
68329	62412	2091	Нижегородская область, Семеновский район, село Ильино-Заборское, Медведева, 12, Дом культуры	f	large
86732	62423	2102	Нижегородская область, Семеновский район, село Зубово, Панельная, 7, детский сад	f	small
111809	62431	2109	Нижегородская область, Семеновский район, село Зименки, Школьная, 35, детский сад	f	medium
86725	62415	2093	Нижегородская область, Семеновский район, село Елфимово, Молодежная, 2Б, Дом культуры	f	small
86675	62417	2095	Нижегородская область, Семеновский район, село Дъяково, Центральная, 55А, Медведевский сельсовет, арендуемое помещение	f	small
111804	62407	2086	Нижегородская область, Семеновский район, село Боковая, 104, администрация сельсовета	f	medium
86720	62406	2085	Нижегородская область, Семеновский район, деревня Богоявление, 92А	f	small
68328	62404	2083	Нижегородская область, Семеновский район, село Беласовка, Мичуринская, 3, средняя школа	f	large
55320	62357	2017	Нижегородская область, Починковский район, село Шишадеево, Большая, 48, Фельдшерско-акушерский пункт	t	small
55333	62371	2035	Нижегородская область, Починковский район, село Шагаево	f	small
55332	62370	2033	Нижегородская область, Починковский район, село Учуево-Майдан, Центральная, 5, Здание сельской администрации	f	small
55331	62369	2032	Нижегородская область, Починковский район, село Ужово, Ленина, 50, Дом культуры	f	small
55307	62344	2004	Нижегородская область, Починковский район, село Ужовка	f	large
55330	62368	2031	Нижегородская область, Починковский район, село Тагаево, 1 Мая, 47, Дом культуры	f	small
55324	62361	2023	Нижегородская область, Починковский район, село Сырятино, Парковая, 17, Дом культуры	f	small
55327	62365	2028	Нижегородская область, Починковский район, село Симбухово, Школьная, 32, Здание сельской администрации	f	small
55326	62364	2026	Нижегородская область, Починковский район, село Саитовка, Ленина, 131, Филиал МБОУ Починковской ср.школы	f	small
55325	62362	2024	Нижегородская область, Починковский район, село Ризоватово	f	medium
55323	62360	2022	Нижегородская область, Починковский район, село Пузская Слобода, Комсомольская, 1А, МБОУ Пузско-Слободская ср.общ.школа	f	small
55317	62354	2014	Нижегородская область, Починковский район, село Починки	f	large
55297	62334	1994	Нижегородская область, Починковский район, село Починки, площадь Ленина, 31, МБОУ ДОД Детская школа искусств	f	large
55296	62333	1993	Нижегородская область, Починковский район, село Починки, пл.Ленина, 44, Районный Дворец культуры	f	large
55298	62335	1995	Нижегородская область, Починковский район, село Починки, Луначарского, 47, МКСОУ Починковская спец. школа-интернат	f	large
55300	62337	1997	Нижегородская область, Починковский район, село Починки, Коммунистическая, 13, Клуб Факел	f	large
68315	62336	1996	Нижегородская область, Починковский район, село Починки, Заречная, 10	f	large
55322	62359	2020	Нижегородская область, Починковский район, село Пеля-Хованская, Центральная, 142 А, Дом культуры	f	medium
55321	62358	2018	Нижегородская область, Починковский район, село Панкратово, Комсомольская, 4, Дом культуры	f	small
55301	62338	1998	Нижегородская область, Починковский район, село Новоспасское, Ленина, 10, Дом культуры	t	small
55314	62351	2011	Нижегородская область, Починковский район, село Новое Урюпино	t	small
55442	62466	2152	Нижегородская область, Починковский район, село Новая Березовка, Первомайская, 11А	f	small
55319	62356	2016	Нижегородская область, Починковский район, село Никитино, Ленина, 105, МБОУ Никитинская сред.общ.школа	f	medium
55318	62355	2015	Нижегородская область, Починковский район, село Наруксово, Агафонова, 7, Дом культуры	f	large
55315	62352	2012	Нижегородская область, Починковский район, село Маресево, Ленина, 1, Маресевский сельсовет, Дом культуры	f	small
55313	62350	2010	Нижегородская область, Починковский район, село Мадаево	f	medium
55312	62349	2009	Нижегородская область, Починковский район, село Криуша, Мира, 3, Дом культуры	f	small
55311	62348	2008	Нижегородская область, Починковский район, село Кочкурово, Советская, 1, Дом культуры	f	medium
55310	62347	2007	Нижегородская область, Починковский район, село Коммунар	f	small
55329	62367	2030	Нижегородская область, Починковский район, село Каменка, Советская, 8, Фельдшерско-акушерский пункт	t	small
55309	62346	2006	Нижегородская область, Починковский район, село Ильинское, Ленина, 33, Дом культуры	f	medium
55328	62366	2029	Нижегородская область, Починковский район, село Журавлиха, Центральная, 70 А, Дом культуры	f	small
55306	62343	2003	Нижегородская область, Починковский район, село Дуброво, Кооперативная, 146, Дом культуры	f	small
55316	62353	2013	Нижегородская область, Починковский район, село Дивеев Усад	f	small
55305	62342	2002	Нижегородская область, Починковский район, село Василевка, Молодежная, 7, МБОУ Василевская основная общ.школа	f	small
55303	62340	2000	Нижегородская область, Починковский район, село Василев Майдан, 1 Мая, 17, Дом культуры	f	small
55308	62345	2005	Нижегородская область, Починковский район, село Байково, Макарова, 27, Дом культуры	f	medium
55304	62341	2001	Нижегородская область, Починковский район, село Арзинка, Заводская, 28А, Дом культуры	f	medium
55302	62339	1999	Нижегородская область, Починковский район, село Азрапино	f	small
86718	62324	1984	Нижегородская область, Пильнинский район, село Языково	f	small
55276	62312	1971	Нижегородская область, Пильнинский район, село Юморга, Школьная, 34, помещение ФАПа	t	small
86727	62317	1976	Нижегородская область, Пильнинский район, село Тенекаево, Советская, 86, здание администрации сельсовета	f	small
55282	62318	1977	Нижегородская область, Пильнинский район, село Тенекаево, Новая, 28, здание Княжегорской школы	f	small
55272	62308	1967	Нижегородская область, Пильнинский район, село Столбищи	f	small
55295	62332	1991	Нижегородская область, Пильнинский район, село Старомочалей, Набережная, 25, сельский клуб	f	small
55262	62296	1953	Нижегородская область, Пильнинский район, Пильна	f	large
55264	62298	1955	Нижегородская область, Пильнинский район, Пильна, Юбилейная, 12, агропромышленный техникум	f	large
68340	62295	1952	Нижегородская область, Пильнинский район, Пильна, Тарлыкова, 8, РКДЦ	f	large
68341	62297	1954	Нижегородская область, Пильнинский район, Пильна, Блохина, 13, здание Пильнинской средней школы № 2	f	large
55292	62328	1988	Нижегородская область, Пильнинский район, село Петряксы	f	medium
111800	62322	1982	Нижегородская область, Пильнинский район, село Озерки, Полевая, 7, сельский клуб	f	small
55273	62309	1968	Нижегородская область, Пильнинский район, село Ожгибовка	t	small
55294	62331	1990	Нижегородская область, Пильнинский район, село Новомочалей	f	small
86717	62323	1983	Нижегородская область, Пильнинский район, село Наваты, Пролетарская, сельский клуб	f	small
111796	62299	1956	Нижегородская область, Пильнинский район, село Можаров Майдан	f	medium
55285	62321	1981	Нижегородская область, Пильнинский район, село Медяна, Гагарина, 35, Дом культуры	f	medium
55278	62314	1973	Нижегородская область, Пильнинский район, село Мамешево, здания бывшей начальной школы	t	small
55268	62303	1962	Нижегородская область, Пильнинский район, село Мальцево, Молодежная, 19, СДК	f	small
55275	62311	1970	Нижегородская область, Пильнинский район, село Малое Андосово	f	small
111799	62306	1966	Нижегородская область, Пильнинский район, село Курмыш, Трудовая, 46, здание администрации сельсовета	f	medium
54382	61644	1037	Нижегородская область, Краснооктябрьский район, село Ключищи	f	small
111802	62327	1987	Нижегородская область, Пильнинский район, село Красная Горка, Кооперативная, 7, Дом культуры	f	medium
111801	62326	1986	Нижегородская область, Пильнинский район, село Красная Горка, Кооперативная, 7, Дом культуры	f	medium
55280	62316	1975	Нижегородская область, Пильнинский район, село Кисленка, Центральная, 70, Дом культуры	f	small
86728	62319	1978	Нижегородская область, Пильнинский район, село Каменка	f	small
55293	62329	1989	Нижегородская область, Пильнинский район, село Калиновка, Школьная, 9А, сельский клуб	t	small
55277	62313	1972	Нижегородская область, Пильнинский район, село Жданово, Советская, 10, здание территориального подразделения	f	small
55269	62304	1963	Нижегородская область, Пильнинский район, село Деяново, Октябрьская, 40, здание администрации сельсовет	f	small
111798	62302	1960	Нижегородская область, Пильнинский район, село Бортсурманы, Нагорная, 27, здание администрации сельсовета	f	medium
55274	62310	1969	Нижегородская область, Пильнинский район, село Большое Андосово, Давыдова, 58, здание администрации сельсовета	f	small
55270	62305	1965	Нижегородская область, Пильнинский район, село Беловка	t	small
86719	62325	1985	Нижегородская область, Пильнинский район, село Барятино, Фролова, 62, сельский клуб	f	small
55279	62315	1974	Нижегородская область, Пильнинский район, село Балеевка, Колхозная, 3, частный дом	f	small
55284	62320	1979	Нижегородская область, Пильнинский район, село Бакшандино, Лесная, 74, здание ФАПа	t	small
55266	62300	1957	Нижегородская область, Пильнинский район, село Арьевка, Молодежная, 10А, сельский клуб	f	small
55246	62280	1935	Нижегородская область, Перевозский район, село имени Дзержинского	f	small
55257	62291	1947	Нижегородская область, Перевозский район, село Ягодное	f	small
55260	61881	1951	Нижегородская область, Перевозский район, село Шпилево, Микрорайон, 13	f	small
55259	62293	1950	Нижегородская область, Перевозский район, поселок Центральный, Центральная, 25	f	medium
55256	62290	1945	Нижегородская область, Перевозский район, село Тилинино, Молодежная, 14	f	medium
55255	62289	1944	Нижегородская область, Перевозский район, село Танайково, Молодежная, 21	f	medium
55251	62285	1940	Нижегородская область, Перевозский район, село Сунеево, Центральная, 7	f	small
55247	62281	1936	Нижегородская область, Перевозский район, село Ревезень	f	small
55245	62279	1934	Нижегородская область, Перевозский район, поселок Перевоз	f	large
55244	62278	1933	Нижегородская область, Перевозский район, поселок Перевоз	f	large
55242	62276	1931	Нижегородская область, Перевозский район, поселок Перевоз, пр-т Советский, 27	f	large
55243	62277	1932	Нижегородская область, Перевозский район, поселок Перевоз, Советский проспект, 9	f	large
55252	62286	1941	Нижегородская область, Перевозский район, поселок Перевоз, 4 микрорайон, 1	f	large
55253	62287	1942	Нижегородская область, Перевозский район, село Палец, Шиянова, 22	f	small
55254	62288	1943	Нижегородская область, Перевозский район, село Каменка, Школьная, 30	f	small
55250	62284	1939	Нижегородская область, Перевозский район, село Ичалки, Кирова, 7	f	medium
55248	62282	1937	Нижегородская область, Перевозский район, село Дубское, Центральная, 2а	f	medium
55258	62292	1948	Нижегородская область, Перевозский район, село Вельдеманово, Молодежная, 4	f	small
55249	62283	1938	Нижегородская область, Перевозский район, село Большие Кемары, Центральная, 5	f	small
55234	62268	1917	Нижегородская область, Первомайский район, село Шутилово, Больничная, 47	f	small
55240	62274	1923	Нижегородская область, Первомайский район, село Успенское, Кооперативная, 34	f	small
55231	62265	1914	Нижегородская область, Первомайский район, поселок Сатис, 1 мая, 22	f	large
55233	62267	1916	Нижегородская область, Первомайский район, село Петровка, Центральная, 90	f	small
68339	62263	1912	Нижегородская область, Первомайский район, Первомайск	f	large
55227	62261	1910	Нижегородская область, Первомайский район, Первомайск, Октябрьская, 19	f	large
55230	62264	1913	Нижегородская область, Первомайский район, Первомайск, Мочалина, 11	f	large
55228	62262	1911	Нижегородская область, Первомайский район, Первомайск, Ленина, 13 а	f	large
55226	62260	1909	Нижегородская область, Первомайский район, Первомайск, площадь Ульянова, 2 б	f	large
55235	62269	1918	Нижегородская область, Первомайский район, село Обухово, Полевая, 3	f	small
55237	62271	1920	Нижегородская область, Первомайский район, село Николаевка	f	medium
55236	62270	1919	Нижегородская область, Первомайский район, село Нелей, Молодежная, 18, Петровский сельсовет	t	small
55239	62273	1922	Нижегородская область, Первомайский район, село Малый Макателем, Клубная, 28	f	small
55241	62275	1924	Нижегородская область, Первомайский район, село Кошелиха, Школьная, 25	t	small
55238	62272	1921	Нижегородская область, Первомайский район, село Большой Макателем, Молодежная, 15	f	small
55232	62266	1915	Нижегородская область, Первомайский район, село Берещино, Советская, 19	t	small
55217	62252	1899	Нижегородская область, Павловский район, село Ясенцы	f	medium
68338	62250	1898	Нижегородская область, Павловский район, село Ясенцы, Центральная, 43, здание сельской администрации	f	large
55214	62248	1896	Нижегородская область, Павловский район, село Ярымово, 23	f	medium
55224	62258	1907	Нижегородская область, Павловский район, село Щепачиха, 65а	f	small
55222	62256	1905	Нижегородская область, Павловский район, село Чмутово, Школьная, 1	f	small
55213	62247	1895	Нижегородская область, Павловский район, село Чернеево	f	small
55201	62236	1881	Нижегородская область, Павловский район, поселок Тумботино, Школьная, 17а	f	large
55199	62234	1879	Нижегородская область, Павловский район, поселок Тумботино, Пролетарская, 14а	f	large
55200	62235	1880	Нижегородская область, Павловский район, поселок Тумботино, Буденного, 27	f	large
55218	62253	1901	Нижегородская область, Павловский район, село Таремское, Школьная, 10а	f	large
55219	62253	1902	Нижегородская область, Павловский район, село Таремское, Школьная, 10а	f	large
55203	62237	1885	Нижегородская область, Павловский район, село Старое Щербинино, 138	t	small
86726	62241	1889	Нижегородская область, Павловский район, село Пурка, Центральная, 42, сельский Дом культуры	f	small
55223	62257	1906	Нижегородская область, Павловский район, село Попадьино, 1а	f	small
68337	62221	1864	Нижегородская область, Павловский район, Павлово, Пилота, 45, школа №14	f	large
55170	62208	1850	Нижегородская область, Павловский район, Павлово, Чкалова, 58	f	large
68336	62220	1863	Нижегородская область, Павловский район, Павлово, Покровская, 1-а, ФОК Звезда	f	large
55173	62211	1853	Нижегородская область, Павловский район, Павлово, Лермонтова, 16а	f	large
55180	62217	1860	Нижегородская область, Павловский район, Павлово, Коммунистическая, 71	f	large
55220	62254	1903	Нижегородская область, Павловский район, село Молявино, Новая, 49	f	medium
55209	62243	1891	Нижегородская область, Павловский район, село Малое Иголкино	f	small
55212	62246	1894	Нижегородская область, Павловский район, село Лаптево, Заводская, 5	f	large
55208	62242	1890	Нижегородская область, Павловский район, село Кряжи, 69	f	small
55205	62239	1887	Нижегородская область, Павловский район, село Комарово, Центральная, 167	f	small
55211	62245	1893	Нижегородская область, Павловский район, село Кишкино, Нагорная, 1а	f	small
55210	62244	1892	Нижегородская область, Павловский район, деревня Грудцино, Школьная, 20	f	large
55197	62232	1877	Нижегородская область, Павловский район, Горбатов	f	medium
55196	62231	1876	Нижегородская область, Павловский район, Горбатов	f	medium
55198	62233	1878	Нижегородская область, Павловский район, Горбатов, Набережная, 2	f	small
55189	62225	1869	Нижегородская область, Павловский район, Ворсма	f	large
55193	62228	1873	Нижегородская область, Павловский район, Ворсма, Строителей, 10	f	large
55191	62226	1871	Нижегородская область, Павловский район, Ворсма, Ленина, 86	f	large
55190	62226	1870	Нижегородская область, Павловский район, Ворсма, Ленина, 86	f	large
55195	62230	1875	Нижегородская область, Павловский район, Ворсма, Гагарина, 9	f	large
55194	62229	1874	Нижегородская область, Павловский район, Ворсма, Гагарина, 22	f	large
55192	62227	1872	Нижегородская область, Павловский район, Ворсма, Весенняя, 1	f	large
55206	62240	1888	Нижегородская область, Павловский район, село Вареж, Школьная, 19	f	small
55221	62255	1904	Нижегородская область, Павловский район, село Борок	f	small
55202	62097	1883	Нижегородская область, Павловский район, село Большое Окское, 51а	f	small
55215	62249	1897	Нижегородская область, Павловский район, село Большое Давыдово, Озерная, 3а	f	large
55204	62238	1886	Нижегородская область, Павловский район, село Абабково	f	large
54629	61872	1300	Нижегородская область, Навашинский район, поселок Теша	t	medium
54624	61867	1295	Нижегородская область, Навашинский район, поселок Степурино, Школьная, 21, сельская библиотека	f	small
54621	61864	1292	Нижегородская область, Навашинский район, село Сонино, Трудовая, 92, сельская администрация	f	small
54628	61871	1299	Нижегородская область, Навашинский район, село Салавирь, Советская, 84а, сельская администрация	f	small
54627	61870	1298	Нижегородская область, Навашинский район, село Рогово, Школьная, 117	f	small
111795	61860	1288	Нижегородская область, Навашинский район, село Поздняково, Богатова, 59а, помещение сельского Дома культуры	f	medium
54615	61858	1286	Нижегородская область, Навашинский район, село Новошино, Пролетарская, 30, сельский дом культуры	f	small
54623	61866	1294	Нижегородская область, Навашинский район, село Натальино, Кооперативная, 37, сельская администрация	f	large
55757	62775	2493	Нижегородская область, Навашинский район, Навашино	f	medium
68308	61855	1283	Нижегородская область, Навашинский район, Навашино, 31, помещение муниципального бюджетного образовательного учреждения средняя общеобразовательная школа №2	f	large
54608	61852	1279	Нижегородская область, Навашинский район, Навашино	f	large
53663	60963	249	Нижегородская область, Навашинский район, Навашино, Трудовая, 4, районная библиотека	f	large
54611	61854	1282	Нижегородская область, Навашинский район, Навашино, Советская, 51, библиотека Домик Кирсановой	f	medium
54610	61853	1281	Нижегородская область, Навашинский район, Навашино, Почтовая, 3, детская районная библиотека	f	large
54625	61868	1296	Нижегородская область, Навашинский район, Навашино, Лепсе, 6, школа №3	f	medium
54616	61849	1287	Нижегородская область, Навашинский район, Навашино, Лепсе, 6, помещение МОУ СОШ №3	f	medium
54607	61851	1278	Нижегородская область, Навашинский район, Навашино, Ленина, 30, помещение МОУ Гимназия	f	large
111794	61850	1280	Нижегородская область, Навашинский район, Навашино, 50 лет Октября, 20, средняя общеобразовательная школа №4	f	medium
68307	61850	1277	Нижегородская область, Навашинский район, Навашино, 50 лет Октября, 20, средняя общеобразовательная школа №4	f	large
111728	60962	248	Нижегородская область, Навашинский район, Навашино, 50 лет Октября, 20, помещение муниципального бюджетного образовательного учреждения средняя	f	medium
54620	61863	1291	Нижегородская область, Навашинский район, село Монаково, Зеленая, 33б, сельский дом культуры	f	small
54614	61857	1285	Нижегородская область, Навашинский район, село Малое Окулово	f	small
54619	61862	1290	Нижегородская область, Навашинский район, село Коробково, Школьная, 34а, сельский дом культуры	f	small
54618	61861	1289	Нижегородская область, Навашинский район, село Ефаново, Молодежная, 18, дом сельского дома культуры	f	small
54622	61865	1293	Нижегородская область, Навашинский район, село Горицы, Советская, 49, сельский дом культуры	f	small
54626	61869	1297	Нижегородская область, Навашинский район, деревня Валтово, Советская, 20, сельская администрация	f	small
54613	61856	1284	Нижегородская область, Навашинский район, село Большое Окулово	f	large
86713	61768	1260	Нижегородская область, Лысковский район, село Чернуха	f	small
54577	61823	1245	Нижегородская область, Лысковский район, село Черная Маза, Сельская администрация	f	small
86714	61839	1265	Нижегородская область, Лысковский район, село Ушаковка, магазин	f	small
68305	61840	1266	Нижегородская область, Лысковский район, село Трофимово	f	large
111789	61831	1255	Нижегородская область, Лысковский район, село Просек, школа	f	medium
86710	61832	1256	Нижегородская область, Лысковский район, село Петровка, клуб	f	small
54601	61844	1271	Нижегородская область, Лысковский район, село Окинино	f	small
86712	61835	1259	Нижегородская область, Лысковский район, село Никольское, Сельская администрация	f	small
68306	61845	1272	Нижегородская область, Лысковский район, село Нива, Дом культуры	f	large
111792	61838	1264	Нижегородская область, Лысковский район, село Неверово, комбинат стройматериалов	f	medium
54594	61837	1263	Нижегородская область, Лысковский район, село Малиновка, сельская администрация	f	small
86716	61846	1273	Нижегородская область, Лысковский район, поселок Макарьево	t	small
86715	61842	1268	Нижегородская область, Лысковский район, село Ляпуны, клуб	f	small
68303	61821	1241	Нижегородская область, Лысковский район, Лысково, Дом детского творчества	f	large
54574	61820	1240	Нижегородская область, Лысковский район, Лысково	f	large
54573	61819	1239	Нижегородская область, Лысковский район, Лысково	f	large
54572	61818	1238	Нижегородская область, Лысковский район, Лысково, ПАП	f	large
54570	61816	1236	Нижегородская область, Лысковский район, Лысково, ЦЗН	f	large
54568	61814	1234	Нижегородская область, Лысковский район, Лысково, детский дом	f	large
54567	61813	1233	Нижегородская область, Лысковский район, Лысково	f	large
54566	61812	1232	Нижегородская область, Лысковский район, Лысково	f	large
54563	61809	1229	Нижегородская область, Лысковский район, Лысково, красный уголок филиала ПО Автпровод	f	large
54562	61808	1228	Нижегородская область, Лысковский район, Лысково, Контора мехлесхоза	f	large
54569	61815	1235	Нижегородская область, Лысковский район, Лысково, Мичурина, ДК	f	large
54565	61811	1231	Нижегородская область, Лысковский район, Лысково, Мичурина, 75, фойе административного здания	f	large
54564	61810	1230	Нижегородская область, Лысковский район, Лысково, Мичурина, 75, (столовая Агротехникума)	f	large
54571	61817	1237	Нижегородская область, Лысковский район, Лысково, 50 лет ВЛКСМ, соцзащита	f	large
54600	61843	1269	Нижегородская область, Лысковский район, село Летнево, школа	f	medium
111791	61806	1261	Нижегородская область, Лысковский район, село Леньково	f	medium
86707	61827	1251	Нижегородская область, Лысковский район, село Кременки, восьмилетняя школа	t	small
111788	61830	1254	Нижегородская область, Лысковский район, село Красный Оселок	f	medium
111793	61841	1267	Нижегородская область, Лысковский район, село Кириково	f	medium
86711	61834	1258	Нижегородская область, Лысковский район, село Елховка, клуб	f	small
86705	61824	1246	Нижегородская область, Лысковский район, село Великовское, здание Администрации	f	small
86706	61826	1250	Нижегородская область, Лысковский район, село Варганы	f	small
111787	61822	1244	Нижегородская область, Лысковский район, село Валки, школа	f	medium
54593	61836	1262	Нижегородская область, Лысковский район, село Валава, клуб	t	small
111790	61833	1257	Нижегородская область, Лысковский район, село Берендеевка, сельская администрация	f	medium
86708	61828	1252	Нижегородская область, Лысковский район, село Белозериха	f	small
68304	61825	1249	Нижегородская область, Лысковский район, село Бармино, Дом культуры	f	large
86709	61829	1253	Нижегородская область, Лысковский район, село Асташиха, клуб	f	small
54535	61783	1196	Нижегородская область, Лукояновский район, село Шандрово	f	medium
54546	61755	1207	Нижегородская область, Лукояновский район, село Чуфарово	f	small
54552	61799	1213	Нижегородская область, Лукояновский район, село Чиргуши, Ватракшонка, 43	f	small
54520	61767	1181	Нижегородская область, Лукояновский район, село Ульяново, 1 Мая, 2-В, Станция юнных натуралистов	f	medium
54524	61772	1185	Нижегородская область, Лукояновский район, село Тольский Майдан, Ленина, 125	f	medium
54541	61789	1202	Нижегородская область, Лукояновский район, село Сонино, Аряева, 45	f	small
54530	61778	1191	Нижегородская область, Лукояновский район, село Санки, Центральная, 40	f	small
54536	61784	1197	Нижегородская область, Лукояновский район, село Салдаманово, Базарная, 1-А	f	small
54534	61782	1195	Нижегородская область, Лукояновский район, село Салдаманов Майдан	f	small
54548	61795	1209	Нижегородская область, Лукояновский район, село Саврасово, Молодежная, 4-А	f	small
54538	61786	1199	Нижегородская область, Лукояновский район, село Поя, Школьная, 1	f	small
54529	61777	1190	Нижегородская область, Лукояновский район, село Покровка, Центральная, 46	f	small
54550	61797	1211	Нижегородская область, Лукояновский район, село Пичингуши, Советская, 89	f	small
54533	61781	1194	Нижегородская область, Лукояновский район, село Печи, Школьная, 10	f	small
54545	61793	1206	Нижегородская область, Лукояновский район, село Перемчалки, Золина, 20-А	f	small
54551	61798	1212	Нижегородская область, Лукояновский район, село Новоселки, Клубная, 146	f	small
54528	61776	1189	Нижегородская область, Лукояновский район, село Новомихайловка, Кадышева, 24	f	small
54553	61800	1214	Нижегородская область, Лукояновский район, село Никулино, Советская, 70, Большеарский сельсовет	f	small
54557	61804	1218	Нижегородская область, Лукояновский район, село Нехорошево	f	small
54539	61787	1200	Нижегородская область, Лукояновский район, село Неверово, Западная, 1А	f	small
54523	61771	1184	Нижегородская область, Лукояновский район, село Мерлиновка	f	small
54525	61773	1186	Нижегородская область, Лукояновский район, село Малое Мамлево, Новикова, 85	f	small
54555	61802	1216	Нижегородская область, Лукояновский район, село Малая Поляна, Заречная, 90, Большемаресьевский сельсовет	f	small
54519	61766	1180	Нижегородская область, Лукояновский район, Лукоянов	f	large
54518	61765	1179	Нижегородская область, Лукояновский район, Лукоянов	f	large
54516	61763	1177	Нижегородская область, Лукояновский район, Лукоянов	f	large
54515	61762	1176	Нижегородская область, Лукояновский район, Лукоянов, площадь Мира, 8А, Районный дом культуры	f	large
54517	61764	1178	Нижегородская область, Лукояновский район, Лукоянов, Микрорайон №1, 15А	f	large
54514	61761	1175	Нижегородская область, Лукояновский район, Лукоянов, Кирова, 34, Лукояновская средняя школа №1	f	large
54543	61791	1204	Нижегородская область, Лукояновский район, село Лопатино	f	small
54521	61769	1182	Нижегородская область, Лукояновский район, село Кудеярово, Державина, 16	f	large
54540	61788	1201	Нижегородская область, Лукояновский район, село Крюковка	f	small
54556	61803	1217	Нижегородская область, Лукояновский район, село Красная Поляна, Лесная, 24	f	small
54531	61779	1192	Нижегородская область, Лукояновский район, поселок Имени Степана Разина	f	large
68350	61780	1193	Нижегородская область, Лукояновский район, поселок Имени Степана Разина, Школьная, 15	f	large
54522	61770	1183	Нижегородская область, Лукояновский район, село Иванцево, пл.Победы, 12	f	medium
54554	61801	1215	Нижегородская область, Лукояновский район, село Елфимово, Советская, 80-А	f	small
54549	61796	1210	Нижегородская область, Лукояновский район, село Докучаево, Зеленая, 72-А	f	small
54526	61774	1187	Нижегородская область, Лукояновский район, село Гари, 1-Мая, 34	f	small
54544	61792	1205	Нижегородская область, Лукояновский район, село Владимировка, Чкалова, 15-Б	f	small
54558	61805	1219	Нижегородская область, Лукояновский район, село Большое Маресьево, Советская, 2	f	small
54527	61775	1188	Нижегородская область, Лукояновский район, село Большое Мамлево, Колхозная, 10, Тольско-Майданский сельсовет	f	medium
54547	61794	1208	Нижегородская область, Лукояновский район, село Большая Аря, Сластяева, 1	f	small
54537	61785	1198	Нижегородская область, Лукояновский район, село Атингеево	f	small
54542	61790	1203	Нижегородская область, Лукояновский район, село Александровка	f	small
86738	61748	1162	Нижегородская область, Кулебакский район, село Шилокша	f	small
54503	61750	1164	Нижегородская область, Кулебакский район, село Шилокша, Школьная, 8, школа	f	medium
68344	61747	1161	Нижегородская область, Кулебакский район, село Серебрянка	f	large
86741	61760	1174	Нижегородская область, Кулебакский район, село Саваслейка, Революции, 1, Здание администрации Саваслейского сельсовета	f	small
111784	61758	1172	Нижегородская область, Кулебакский район, село Первомайский	f	medium
86740	61757	1171	Нижегородская область, Кулебакский район, село Мурзицы	f	small
111785	61759	1173	Нижегородская область, Кулебакский район, поселок Молочной Фермы, Рабочая, 14а, 1 этаж, клуб	f	medium
68343	61746	1160	Нижегородская область, Кулебакский район, село Михайловка	f	large
86739	61749	1163	Нижегородская область, Кулебакский район, село Ломовка, Школьная, 26, школа	f	small
111778	61737	1146	Нижегородская область, Кулебакский район, Кулебаки, Некрасова, 12, Контора ОАО Кулебакский завод металлических конструкций	f	medium
54478	61731	1139	Нижегородская область, Кулебакский район, город Кулебаки, Адмирала Макарова, 72, Детский комбинат Светлячок	f	large
54479	61731	1140	Нижегородская область, Кулебакский район, город Кулебаки, Адмирала Макарова, 72, Детский комбинат Светлячок	f	large
54475	61728	1136	Нижегородская область, Кулебакский район, Кулебаки, Циолковского, 41, ДОСААФ	f	large
111782	61744	1158	Нижегородская область, Кулебакский район, Кулебаки, Степана Разина, 164А, Молодежный центр	f	medium
54491	61739	1152	Нижегородская область, Кулебакский район, Кулебаки, Догадина, 31, школа №7	f	medium
54490	61739	1151	Нижегородская область, Кулебакский район, Кулебаки, Догадина, 31, школа №7	f	small
68346	61752	1166	Нижегородская область, Кулебакский район, поселок Гремячево, площадь Свободы, 2, школа	f	large
68347	61753	1167	Нижегородская область, Кулебакский район, поселок Гремячево, Ленина, 44, школа	f	large
68345	61751	1165	Нижегородская область, Кулебакский район, поселок Гремячево, Гагарина, 73, д/с Теполек	f	large
68349	61754	1169	Нижегородская область, Кулебакский район, поселок Велетьма, Первомайская, Здание администрации, 1этаж	f	large
68348	61754	1168	Нижегородская область, Кулебакский район, поселок Велетьма, Первомайская, Здание администрации, 1этаж	f	large
54509	61756	1170	Нижегородская область, Кулебакский район, поселок Велетьма, Первомайская, Администрация р.п.Велетьма	f	small
111779	61740	1153	Нижегородская область, Кулебакский, Кулебаки, Футбольная , 3, МОУ Средняя общеобразовательная школа №10	f	medium
68276	61710	1116	Нижегородская область, Кстовский район, село Шелокша, школа с. Шелокша	f	large
111771	61713	1118	Нижегородская область, Кстовский район, село Шава	t	small
111775	61724	1130	Нижегородская область, Кстовский район, село Чернышиха, 4, здание сельской администрации	f	medium
68275	61709	1115	Нижегородская область, Кстовский район, село Чернуха, Школьная, 47, дом культуры	f	large
86680	61691	1094	Нижегородская область, Кстовский район, деревня Фроловское, школа	t	small
86678	61688	1091	Нижегородская область, Кстовский район, село Федяково, школа	f	small
111766	61683	1085	Нижегородская область, Кстовский район, деревня Утечино, 5, здание ФАП	t	small
86682	61715	1121	Нижегородская область, Кстовский район, село Слободское	f	small
86679	61689	1092	Нижегородская область, Кстовский район, деревня Ржавка, школа	f	small
86683	61718	1124	Нижегородская область, Кстовский район, село Работки, Ленина, 184, школа	f	small
68268	61717	1123	Нижегородская область, Кстовский район, село Работки, Ленина, 184, школа	f	large
68269	61721	1127	Нижегородская область, Кстовский район, село Прокошево, Молькова, 1-А, дом культуры	f	large
86684	61722	1128	Нижегородская область, Кстовский район, деревня Прокошево, Молькова, 8-А, здание сельской администрации	f	small
68267	61716	1122	Нижегородская область, Кстовский район, село Подлесово, школа	f	large
111769	61698	1104	Нижегородская область, Кстовский район, село Новые Ключищи, медпункт	t	small
86691	61708	1114	Нижегородская область, Кстовский район, село Новоликеево, Ленина, 3, здание сельской администрации	f	small
68274	61706	1112	Нижегородская область, Кстовский район, село Новоликеево, Ленина, 3, здание сельской администрации	f	large
86688	61704	1110	Нижегородская область, Кстовский район, село Михальчиково, Школьная, клуб	t	small
111773	61720	1126	Нижегородская область, Кстовский район, село Малиновка	t	small
86689	61705	1111	Нижегородская область, Кстовский район, село Лавровка, 3, магазин	f	small
111767	61684	1087	Нижегородская область, Кстовский район, Кузьминка, Талалушкина, здание ФАП	t	small
68248	61673	1072	Нижегородская область, Кстовский район, Кстово, площадь Мира, школа №4	f	large
68247	61673	1071	Нижегородская область, Кстовский район, Кстово, площадь Мира, школа №4	f	large
68246	61668	1070	Нижегородская область, Кстовский район, Кстово, площадь Ленина, 2-А, библиотека	f	large
68239	61668	1063	Нижегородская область, Кстовский район, Кстово, площадь Ленина, 2-А, библиотека	f	large
68250	61675	1074	Нижегородская область, Кстовский район, Кстово, бульвар Мира, 2-А, центр. детская библиотека	f	large
68259	61681	1083	Нижегородская область, Кстовский район, Кстово, Чванова, школа № 6	f	large
68258	61681	1082	Нижегородская область, Кстовский район, Кстово, Чванова, школа № 6	f	large
68241	61670	1065	Нижегородская область, Кстовский район, Кстово, Чванова, 1-А, актовый зал ОАО Нижегородоблгаз	f	large
68232	61661	1056	Нижегородская область, Кстовский район, Кстово, Советская, 50, школа № 1	f	large
68231	61661	1055	Нижегородская область, Кстовский район, Кстово, Советская, 50, школа № 1	f	large
68238	61667	1062	Нижегородская область, Кстовский район, Кстово, Лукерьинская, 3, детский сад № 50	f	large
68255	61678	1079	Нижегородская область, Кстовский район, Кстово, Зеленая, 1А, шахматная школа 	f	large
68233	61662	1057	Нижегородская область, Кстовский район, Кстово, Береговая, детский сад №5	f	large
68253	61676	1077	Нижегородская область, Кстовский район, Кстово, 2 микрорайон, школа №3	f	large
68251	61676	1075	Нижегородская область, Кстовский район, Кстово, 2 микрорайон, школа №3	f	large
111774	61723	1129	Нижегородская область, Кстовский район, село Игумново, 23, медпункт	t	small
86687	61703	1109	Нижегородская область, Кстовский район, село Зименки, Центральная, школа	f	small
68277	61711	1117	Нижегородская область, Кстовский район, село Запрудное, школа с. Запрудное	f	large
68262	61690	1093	Нижегородская область, Кстовский район, село Ждановский	f	large
68261	61687	1090	Нижегородская область, Кстовский район, село Ждановский, Зеленая, дом культуры	f	large
68266	61694	1098	Нижегородская область, Кстовский район, поселок Дружный, здание ДОУ № 49	f	large
68270	61695	1099	Нижегородская область, Кстовский район, село Вязовка, Широкая, школа	f	large
111772	61719	1125	Нижегородская область, Кстовский район, село Волжский, Центральная, дом культуры	f	medium
86690	61707	1113	Нижегородская область, Кстовский район, село Ветчак, Магистральная, магазин ПО Новоликеевское	f	small
86686	61702	1108	Нижегородская область, Кстовский район, село Великий Враг, Школьная, школа	f	small
68272	61697	1101	Нижегородская область, Кстовский район, село Большое Мокрое	f	large
86677	61686	1089	Нижегородская область, Кстовский район, село Большая Ельня, площадь Жданова, здание бывшей сельской адм-ции	t	small
68265	61693	1097	Нижегородская область, Кстовский район, село Ближнее Борисово, Центральная, 2-г, здание сельской администрации	f	large
86685	61701	1107	Нижегородская область, Кстовский район, село Безводное	f	small
111770	61700	1106	Нижегородская область, Кстовский район, село Безводное, Веры Архангельской, дом культуры	f	medium
111768	61654	1088	Нижегородская область, Кстовский район, деревня Афонино, школа д. Афонино	f	medium
68260	61682	1084	Нижегородская область, Кстовский район, деревня Афонино, Магистральная, 73-А, сельская администрация	f	large
54378	61639	1033	Нижегородская область, Краснооктябрьский район, село Чернуха	f	small
54396	61659	1053	Нижегородская область, Краснооктябрьский район, село Чембилей, Школьная, 25, Здание школы	f	small
54371	61632	1026	Нижегородская область, Краснооктябрьский район, село Федоровка	f	small
54390	61652	1047	Нижегородская область, Краснооктябрьский район, село Уразовка, Кооперативная, 45, Здание дома культуры	f	large
54376	61637	1031	Нижегородская область, Краснооктябрьский район, село Трехозерье, Центральная, 129, Здание селького ДК	f	small
54388	61650	1045	Нижегородская область, Краснооктябрьский район, село Семеновка, Ленина, 68, Здание селького ДК	f	small
54385	61647	1041	Нижегородская область, Краснооктябрьский район, село Сарга	f	small
54383	61645	1038	Нижегородская область, Краснооктябрьский район, село Салган, 1 Мая, 7, Здание администрации с/с	f	medium
54389	61651	1046	Нижегородская область, Краснооктябрьский район, село Пошатово, Кооператвная, 1а, Здание селького ДК	f	small
54394	61657	1051	Нижегородская область, Краснооктябрьский район, село Овечий Овраг, Колхозная, 14, Здание селького ДК	f	small
54386	61648	1042	Нижегородская область, Краснооктябрьский район, село Михайловка, Центральная, 64, Здание селького ДК	f	small
54397	61660	1054	Нижегородская область, Краснооктябрьский район, село Медяны, Ленина, 62, Здание дома культуры	f	small
54384	61646	1040	Нижегородская область, Краснооктябрьский район, село Маресево, Школьная, 2а, Здание сельской администрации	f	small
54380	61641	1035	Нижегородская область, Краснооктябрьский район, село Малая Мажарка, Молодежная, 1, Здание начальной школы	t	small
54395	61658	1052	Нижегородская область, Краснооктябрьский район, село Кузьминка, Школьная, 5а, Здание селького ДК	f	small
54393	61656	1050	Нижегородская область, Краснооктябрьский район, село Красный Яр, Советская, 10/1, Здание селького ДК	f	small
54379	61640	1034	Нижегородская область, Краснооктябрьский район, село Китово, Гавриловка, 12, Здание селького ДК	f	small
54377	61638	1032	Нижегородская область, Краснооктябрьский район, село Кечасово, Советская, 93, Здание дома культуры	f	small
54375	61636	1030	Нижегородская область, Краснооктябрьский район, село Карга, Центральная, 113, Здание селького ДК	f	small
54387	61649	1044	Нижегородская область, Краснооктябрьский район, село Ерпелево, Центральная, 116, Здание селького ДК	f	small
54374	61635	1029	Нижегородская область, Краснооктябрьский район, село Ендовищи, Школьная, 7, Здание школы	f	small
54373	61634	1028	Нижегородская область, Краснооктябрьский район, село Большое Рыбушкино	f	medium
54372	61633	1027	Нижегородская область, Краснооктябрьский район, село Большое Рыбушкино, Колхозная, 58, Здание дома культуры	f	large
54392	61655	1049	Нижегородская область, Краснооктябрьский район, село Антяровка, Кооперативная, 32 , Здание селького ДК	f	small
54370	61631	1025	Нижегородская область, Краснооктябрьский район, село Александрово, Северная, 106, Здание школы	t	small
54381	61642	1036	Нижегородская область, Краснооктябрьский район, село Акулино, Колхозная, 12, Здание начальной школы	t	small
54391	61653	1048	Нижегородская область, Краснооктябрьский район, село Актуково, Школьная, 2а , Здание селького ДК	f	small
54369	61629	1022	Нижегородская область, Краснобаковский район, поселок Шеманиха, Сельсоветская, 6	f	small
54368	61628	1021	Нижегородская область, Краснобаковский район, поселок Шеманиха, Свободы, 1	f	medium
54362	61622	1015	Нижегородская область, Краснобаковский район, село Чибирь	f	small
54363	61623	1016	Нижегородская область, Краснобаковский район, село Чемашиха, Школьная, 1	t	small
54364	61624	1017	Нижегородская область, Краснобаковский район, село Чащиха, Новая, 12	f	medium
54361	61621	1014	Нижегородская область, Краснобаковский район, село Пруды, Центральная, 17	f	medium
86673	61627	1020	Нижегородская область, Краснобаковский район, село Носовая, Молодежная, 42, здание Администрации Чащихинского сельсовета	f	small
86674	61630	1023	Нижегородская область, Краснобаковский район, поселок Красные Баки	f	small
54350	61611	1003	Нижегородская область, Краснобаковский район, поселок Красные Баки	f	medium
54353	61614	1006	Нижегородская область, Краснобаковский район, поселок Красные Баки, имени Чкалова, 2	f	large
54352	61613	1005	Нижегородская область, Краснобаковский район, поселок Красные Баки, им.Синявина, 60	f	large
54351	61612	1004	Нижегородская область, Краснобаковский район, поселок Красные Баки, имени Мичурина, 2а	f	large
54360	61620	1013	Нижегородская область, Краснобаковский район, село Козлово, 42	f	small
54366	61626	1019	Нижегородская область, Краснобаковский район, село Кириллово, имени генерала Тихомирова, 58б	f	small
54359	61037	1012	Нижегородская область, Краснобаковский район, село Зубилиха, 120	t	small
86672	61615	1007	Нижегородская область, Краснобаковский район, поселок Затон, Береговая , 6, здание клуба	t	small
54358	61619	1011	Нижегородская область, Краснобаковский район, село Дмитриевское, Молодежная, 1б	f	small
54356	61617	1009	Нижегородская область, Краснобаковский район, поселок Ветлужский	f	large
54355	61616	1008	Нижегородская область, Краснобаковский район, поселок Ветлужский, им.Чкалова, 20	f	large
54357	61618	1010	Нижегородская область, Краснобаковский район, поселок Ветлужский, Фестивальная, 1	f	large
54365	61625	1018	Нижегородская область, Краснобаковский район, село Быструха, Центральная, 23	f	small
54338	61599	989	Нижегородская область, Ковернинский район, село Шадрино, Сельская, 63	f	small
54343	61604	994	Нижегородская область, Ковернинский район, село Хохлома, Центральная, 2	f	medium
54344	61605	995	Нижегородская область, Ковернинский район, село Тарасово	t	small
54341	61602	992	Нижегородская область, Ковернинский район, село Сухоноска, Юбилейная, 19	f	large
54342	61603	993	Нижегородская область, Ковернинский район, село Семино, Центральная, 3	f	medium
86671	61609	999	Нижегородская область, Ковернинский район, село Рамешки, 87, здание фельдшерско-акушерского пункта	f	small
54346	61607	997	Нижегородская область, Ковернинский район, село Понурово	f	small
54297	61557	946	Нижегородская область, Дивеевский район, село Дивеево	f	large
53734	61030	328	Нижегородская область, Ковернинский район, село Октябрьский, Октябрьская, 19, ГОУ СПО Борский технолого-экономический техникум	f	large
54333	61594	984	Нижегородская область, Ковернинский район, поселок Ковернино, пер. Рабочий, 1	f	medium
54332	61593	983	Нижегородская область, Ковернинский район, поселок Ковернино, Карла Маркса, 25	f	large
54331	61592	982	Нижегородская область, Ковернинский район, поселок Ковернино, Карла Маркса, 8	f	large
54336	61597	987	Нижегородская область, Ковернинский район, село Каменное	f	medium
54340	61601	991	Нижегородская область, Ковернинский район, село Демино, Заречная, 15, Гавриловский сельсовет	f	small
54347	61608	998	Нижегородская область, Ковернинский район, село Горево, Медведева, 22	f	medium
68230	61600	990	Нижегородская область, Ковернинский район, село Гавриловка, Садовая, 2, МБОУ Гавриловская средняя общеобразовательная школа	f	large
54334	61595	985	Нижегородская область, Ковернинский район, село Большие Мосты, Северня, 9	f	medium
54337	61598	988	Нижегородская область, Ковернинский район, село Большие Круты, Молодежная, 35	f	small
54335	61596	986	Нижегородская область, Ковернинский район, село Бетино, Молодежная, 14-а	t	small
54349	61610	1000	Нижегородская область, Ковернинский район, село Белбаж, Школьная, 3	f	small
54345	61606	996	Нижегородская область, Ковернинский район, село Анисимово	f	medium
111764	61586	975	Нижегородская область, Княгининский район, село совхоз Возрождение, Школьная, 46	f	medium
54328	61589	979	Нижегородская область, Княгининский район, село Урга, Центральная, 116	f	small
86668	61583	972	Нижегородская область, Княгининский район, село Троицкое, Советская, 3	f	small
111765	61591	981	Нижегородская область, Княгининский район, село Соловьево	f	medium
54326	61587	977	Нижегородская область, Княгининский район, село Покров	f	small
54327	61588	978	Нижегородская область, Княгининский район, село Островское, Садовая, 4	f	small
111763	61581	969	Нижегородская область, Княгининский район, Княгинино	f	medium
111762	61579	968	Нижегородская область, Княгининский район, Княгинино, Свободы, 5	f	medium
111761	61578	967	Нижегородская область, Княгининский район, Княгинино, Свободы, 43	f	medium
68302	61577	966	Нижегородская область, Княгининский район, Княгинино, Октябрьская, 20 А	f	large
68301	61576	965	Нижегородская область, Княгининский район, Княгинино, Октябрьская, 20	f	large
86670	61590	980	Нижегородская область, Княгининский район, село Бубенки	f	small
54323	61584	973	Нижегородская область, Княгининский район, село Большая Андреевка	f	small
86669	61585	974	Нижегородская область, Княгининский район, село Белка, Молодежная, 7	f	small
86667	61582	970	Нижегородская область, Княгининский район, село Ананье, Малкина, 14	f	small
54313	61573	962	Нижегородская область, Дивеевский район, село Яколевка, Лесная, 1, КЛУБ	f	small
54312	61572	961	Нижегородская область, Дивеевский район, село Суворово, Молодежная, 11а, ДОМ КУЛЬТУРЫ	f	small
54311	61571	960	Нижегородская область, Дивеевский район, село Стуклово, Молодежная, 5а, Дом культуры	f	small
54310	61570	959	Нижегородская область, Дивеевский район, село Смирново	f	small
54309	61569	958	Нижегородская область, Дивеевский район, село Сатис	f	large
54308	61568	957	Нижегородская область, Дивеевский район, село Осиновка, Новая, 48, Дом интернат	f	small
54307	61567	956	Нижегородская область, Дивеевский район, село Ореховец	f	small
54306	61566	955	Нижегородская область, Дивеевский район, село Онучино, Школьная, 22, клуб	f	small
111760	61565	954	Нижегородская область, Дивеевский район, село Лихачи	t	small
54304	61564	953	Нижегородская область, Дивеевский район, село Круглые Паны, Кооперативная, 65, Клуб	f	small
54303	61563	952	Нижегородская область, Дивеевский район, село Кременки, Новостройка, 16, сельская администрация	f	medium
54302	61562	951	Нижегородская область, Дивеевский район, село Конново	f	small
54301	61561	950	Нижегородская область, Дивеевский район, село Ичалово	f	small
54300	61560	949	Нижегородская область, Дивеевский район, село Ивановское, Микрорайон, 9а, сельская администрация	f	small
54299	61559	948	Нижегородская область, Дивеевский район, село Елизарьево, 9 Мая, 35А, СЕЛЬСКАЯ АДМИНИСТРАЦИЯ	f	medium
54298	61558	947	Нижегородская область, Дивеевский район, село Дивеево	f	large
54296	61556	945	Нижегородская область, Дивеевский район, село Дивеево, Октябрьская, 43, Дом культуры	f	large
54295	61555	944	Нижегородская область, Дивеевский район, село Глухово, Почтовая, 73а, Дом культуры	f	small
54294	61554	943	Нижегородская область, Дивеевский район, село Верякуши, Советская, 32, школа	f	small
111759	61553	942	Нижегородская область, Дивеевский район, село Большое Череватово, Центральная, 110, сельская администрация	f	medium
54177	61471	810	Нижегородская область, Дзержинский городской округ, деревня Горбатовка, улица Весенняя, 5, здание столовой ПМК-5	f	large
68295	61500	842	Нижегородская область, Дзержинск городской округ, поселок Пыра, Чкалова, 12, МОУ СОШ №6	f	large
86704	61500	843	Нижегородская область, Дзержинск городской округ, поселок Пыра, Чкалова, 12, МОУ СОШ №6	f	small
54208	61499	841	Нижегородская область, Дзержинск городской округ, Дзержинск, Административное здание пос.Пыра	f	small
54186	61480	819	Нижегородская область, Дзержинск городской округ, поселок Бабино, административное здание	f	medium
54178	61472	811	Нижегородская область, Дзержинск городской округ, поселок Бабино, МОУ СОШ №25	f	medium
54184	61478	817	Нижегородская область, Дзержинск городской округ, поселок Бабино, п. Петряевка, библиотека	f	medium
54160	61456	792	Нижегородская область, Дальнеконстантиновский район, село Тепелево	t	small
111756	61461	797	Нижегородская область, Дальнеконстантиновский район, село Татарское	f	medium
54154	61450	786	Нижегородская область, Дальнеконстантиновский район, село Суроватиха, Центральная, 18, сельская администрация	f	medium
54155	61451	787	Нижегородская область, Дальнеконстантиновский район, село Суроватиха, М.Горького, 15, Дом культуры	f	medium
54149	61445	781	Нижегородская область, Дальнеконстантиновский район, село Сарлей, Шоссейная, 8а, сельский Дом культуры	f	medium
54169	61453	801	Нижегородская область, Дальнеконстантиновский район, село Румянцево, Центральная, 43, столовая	f	medium
54148	61444	780	Нижегородская область, Дальнеконстантиновский район, село Румстиха, Шоссейная, 39, начальная школа-детский сад	f	small
54150	61446	782	Нижегородская область, Дальнеконстантиновский район, село Помра, Молодежная, 23, основная школа	f	small
54164	61460	796	Нижегородская область, Дальнеконстантиновский район, село Нижегородец, Ленина, 9а, сельская администрация	t	small
54163	61459	795	Нижегородская область, Дальнеконстантиновский район, поселок Нижегородец, 50 лет Октября, 4, средняя школа	t	large
54157	61452	789	Нижегородская область, Дальнеконстантиновский район, село Муравьиха, 222, средняя школа	f	small
54156	61452	788	Нижегородская область, Дальнеконстантиновский район, село Муравьиха, 222, средняя школа	f	medium
54152	61448	784	Нижегородская область, Дальнеконстантиновский район, село Маргуша, Новоселов, 8, административное здание	f	small
54151	61447	783	Нижегородская область, Дальнеконстантиновский район, село Малая Пица, 40 лет Победы, 11а, торговый центр	f	medium
54161	61457	793	Нижегородская область, Дальнеконстантиновский район, село Лазазей, Молодежная, 14, Тепелевский сельсовет	f	small
54172	61466	804	Нижегородская область, Дальнеконстантиновский район, село Кужутки	f	small
54162	61458	794	Нижегородская область, Дальнеконстантиновский район, село Кужутки	f	small
54168	61464	800	Нижегородская область, Дальнеконстантиновский район, село Дубрава, Центральная, 13, средняя школа	f	medium
54153	61449	785	Нижегородская область, Дальнеконстантиновский район, село Дубки	f	small
54143	61439	775	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново	f	medium
54146	61442	778	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Советская, 53, поселковая администрация	f	medium
54145	61441	777	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Советская, 189а, административное здание ТУСМ	f	medium
54144	61440	776	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Пионерская, 1а, ЦРБ	t	large
54147	61443	779	Нижегородская область, Дальнеконстантиновский район, поселок Дальнее Константиново, Молодежная, 7, администратвное здание ЗАО Ритм	f	small
54159	61455	791	Нижегородская область, Дальнеконстантиновский район, село Богоявление	f	medium
86703	61463	799	Нижегородская область, Дальнеконстантиновский район, село Берсеменово, правление колхоза «Победитель»	t	small
54166	61462	798	Нижегородская область, Дальнеконстантиновский район, село Белозерово, Центральная, 50, сельская администрация	f	small
54158	61454	790	Нижегородская область, Дальнеконстантиновский район, село Арманиха, Центральная, 106, административное здание	t	small
54129	61424	759	Нижегородская область, Городецкий район, село имени Тимирязева, Молодежная, 1а, здание администрации	f	large
54126	61421	756	Нижегородская область, Городецкий район, село Шадрино, Школьная, 2, Дом культуры	f	small
54128	61423	758	Нижегородская область, Городецкий район, село Федурино	f	medium
54133	61428	763	Нижегородская область, Городецкий район, село Строчково	f	large
68289	61431	766	Нижегородская область, Городецкий район, село Смольки	f	large
54124	61419	754	Нижегородская область, Городецкий район, село Смиркино, Мира, 44, здание администрации	f	medium
54135	61430	765	Нижегородская область, Городецкий район, поселок Серково, проспект Ленина, 12, Серковская школа	f	large
54132	61427	762	Нижегородская область, Городецкий район, село Мошкино, Центральная, 5, клуб	f	small
54134	61429	764	Нижегородская область, Городецкий район, деревня Кудашиха, 52, здание Кумохинской администр	f	medium
54131	61426	761	Нижегородская область, Городецкий район, село Ковригино	f	medium
54138	61434	768	Нижегородская область, Городецкий район, село Ильинский, 3, Ильинская школа	f	large
54139	61435	769	Нижегородская область, Городецкий район, село Зиняки, Молодежная, 1, здание администрации	f	medium
54141	61437	771	Нижегородская область, Городецкий район, село Зарубино, Комсомольская, 6, Зарубинская школа	f	medium
54119	61414	749	Нижегородская область, Городецкий район, Заволжье	f	large
54112	61406	742	Нижегородская область, Городецкий район, Заволжье	f	large
54110	61404	740	Нижегородская область, Городецкий район, Заволжье	f	large
54109	61403	739	Нижегородская область, Городецкий район, Заволжье	f	large
54114	61409	744	Нижегородская область, Городецкий район, Заволжье, пр. Дзержинского, 58, Городская больница № 1	t	large
54107	61401	737	Нижегородская область, Городецкий район, Заволжье, Школьная, 12, школа № 6	f	large
54118	61413	748	Нижегородская область, Городецкий район, Заволжье, Пушкина, 41, школа № 18 (актовый зал)	f	large
54117	61412	747	Нижегородская область, Городецкий район, Заволжье, Пушкина, 41, школа № 18 (1 этаж)	f	large
54116	61411	746	Нижегородская область, Городецкий район, Заволжье, Пушкина, 4, школа № 15	f	large
54115	61410	745	Нижегородская область, Городецкий район, Заволжье, Пушкина, 3, школа № 17 (рекреация 1 этажа)	f	large
54113	61407	743	Нижегородская область, Городецкий район, Заволжье, Пушкина, 3, школа № 17 (спортивный зал)	f	large
68288	61415	750	Нижегородская область, Городецкий район, Заволжье, Пономарева, 1а, Центр детского творчества	f	large
54108	61402	738	Нижегородская область, Городецкий район, Заволжье, Пирогова, 10, школа № 3	f	large
54122	61417	752	Нижегородская область, Городецкий район, Заволжье, Молодежная, 1, школа № 19	f	large
54111	61405	741	Нижегородская область, Городецкий район, Заволжье, Мичурина, 5, Дворец культуры (выстав. зал)	f	large
54121	61416	751	Нижегородская область, Городецкий район, Заволжье, Грунина, 8а, библиотека, филиал № 1	f	large
54127	61422	757	Нижегородская область, Городецкий район, село Дроздово, 31, МОУ Дроздоская школа-сад	f	medium
54092	61385	722	Нижегородская область, Городецкий район, Городец, пл. Ватутина, 6, Центр культуры и искусства	f	large
54099	61392	729	Нижегородская область, Городецкий район, Городец, Кирова, 2, Досуговый центр ""Метеор"""	f	large
54140	61436	770	Нижегородская область, Городецкий район, село Воронино, 15, Дом культуры	f	medium
86681	61714	1119	Нижегородская область, Городецкий район, село Варварское	f	small
54130	61425	760	Нижегородская область, Городецкий район, село Буревестник, Дом культуры	f	medium
54125	61420	755	Нижегородская область, Городецкий район, село Бриляково, Школьная, 1, Бриляковская школа	f	medium
54137	61433	767	Нижегородская область, Городецкий район, поселок Аксентис, 53, МОУ Аксентисская ООШ	f	large
54072	61365	700	Нижегородская область, Гагинский район, село Юрьево, Ленина, 2а	f	medium
54060	61352	686	Нижегородская область, Гагинский район, село Шерстино, Школьная, 16	f	small
54089	61382	719	Нижегородская область, Гагинский район, село Ушаково	f	medium
54061	61353	687	Нижегородская область, Гагинский район, село Тяпино, Центральная, 47	f	small
54068	61361	694	Нижегородская область, Гагинский район, село Тарханово	f	small
54082	61375	711	Нижегородская область, Гагинский район, село Сыченки, Героя Платова, 16	f	small
54063	61355	689	Нижегородская область, Гагинский район, село Субботино, Центральная, 14	f	small
54067	61360	693	Нижегородская область, Гагинский район, село Соболево, Центральная, 2	t	small
86700	61357	690	Нижегородская область, Гагинский район, село Покров, Центральная, 4	f	small
54062	61354	688	Нижегородская область, Гагинский район, село Паново-Осаново, Калинина, 79	f	small
54075	61368	703	Нижегородская область, Гагинский район, село Паново-Леонтьево, Колхозная, 1а	f	small
54077	61370	705	Нижегородская область, Гагинский район, село Новоеделево, Савинская, 43б	f	small
54090	61383	720	Нижегородская область, Гагинский район, село Новое Молчаново, Высокая, 16	f	small
54071	61364	699	Нижегородская область, Гагинский район, село Новоблаговещенское, Трудовая, 42	f	small
54078	61371	706	Нижегородская область, Гагинский район, село Никольское, Центральная, 23а	f	small
54069	61362	695	Нижегородская область, Гагинский район, село Муратовка	t	small
54079	61372	707	Нижегородская область, Гагинский район, село Моисеевка, Школьная, 11	f	small
54073	61366	701	Нижегородская область, Гагинский район, село Мишуково, Центральная, 33а	f	small
54086	61379	716	Нижегородская область, Гагинский район, село Ляпня, Зверева, 91, Ушаковский сельсовет	f	small
54066	61359	692	Нижегородская область, Гагинский район, село Ломакино, Мира, 1а	f	small
86701	61367	702	Нижегородская область, Гагинский район, село Курбатово, Зеленая, 20 А	f	small
54080	61373	709	Нижегородская область, Гагинский район, село Карауловка, Центральная, 10	f	small
54083	61376	713	Нижегородская область, Гагинский район, село Какино, Ленина, 2а	f	small
54091	61384	721	Нижегородская область, Гагинский район, село Итманово, Центральная, 6	f	small
54065	61358	691	Нижегородская область, Гагинский район, село Исупово, Большая дорога, 20	f	small
54088	61381	718	Нижегородская область, Гагинский район, село Ивково, Запрудная, 35	f	small
86702	61377	714	Нижегородская область, Гагинский район, село Зверево, Центральная, 3А	f	small
111828	62779	2500	Нижегородская область, Гагинский район, село Гагино	f	medium
54058	61350	684	Нижегородская область, Гагинский район, село Гагино, Терехина, 12	f	large
54081	61374	710	Нижегородская область, Гагинский район, село Гагино, Ленина, 27а	f	small
54059	61351	685	Нижегородская область, Гагинский район, село Гагино, Ленина, 53	f	medium
54057	61349	683	Нижегородская область, Гагинский район, село Гагино, Коммунистическая, 10	f	medium
54070	61363	697	Нижегородская область, Гагинский район, село Ветошкино, Школьная, 1	f	medium
54087	61380	717	Нижегородская область, Гагинский район, село Большая Уда, Рябовой, 3а	f	small
54076	61369	704	Нижегородская область, Гагинский район, село Березники	f	small
54043	61335	669	Нижегородская область, Выксунский район, поселок Шиморское, здание администрации	f	large
54042	61334	668	Нижегородская область, Выксунский район, поселок Шиморское, микрорайон Совхозный, 2а, ДТ	f	large
54044	61336	670	Нижегородская область, Выксунский район, село Тамбалес, Калинина, 13, школа	f	small
54051	61343	677	Нижегородская область, Выксунский район, село Полдеревка, школа	t	small
111754	61345	679	Нижегородская область, Выксунский район, село Новодмитриевка, МОУ Новодмитриевская СОШ	f	medium
68287	61327	661	Нижегородская область, Выксунский район, село Дружба, МОУ СОШ посёлка Дружба	f	large
54036	61328	662	Нижегородская область, Выксунский район, поселок Досчатое, клуб ДЗМО	f	large
54037	61329	663	Нижегородская область, Выксунский район, поселок Досчатое, Гагарина, 144, клуб Метиз	f	large
54052	61344	678	Нижегородская область, Выксунский район, село Димара, Дом Досуга	f	small
54041	61333	667	Нижегородская область, Выксунский район, деревня Грязная, ДТ	f	medium
54045	61337	671	Нижегородская область, Выксунский район, поселок Виля, здание администрации	f	medium
54048	61340	674	Нижегородская область, Выксунский район, село Верхняя Верея, Школьная, ДТ	f	medium
54040	61332	666	Нижегородская область, Выксунский район, село Борковка, Ленина, школа	f	medium
54038	61330	664	Нижегородская область, Выксунский район, поселок Ближне-Песочное, библиотека	f	large
54026	61318	652	Нижегородская область, Выкса городской округ, Выкса, микрорайон Гоголя, 17, общежитие 3	f	large
54031	61323	657	Нижегородская область, Выкса городской округ, Выкса, 1 Мая, 1, начальная школа	f	large
53983	61280	601	Нижегородская область, Воскресенский район, село Шадрино, Фабричная, 70	f	small
53985	61282	603	Нижегородская область, Воскресенский район, село Староустье, Школьная, 2а	f	medium
54001	61299	624	Нижегородская область, Воскресенский район, село Северный, Железнодорожная, 12	t	small
53987	61284	605	Нижегородская область, Воскресенский район, село Русениха, Молодежная, 1а	t	small
53986	61283	604	Нижегородская область, Воскресенский район, село Раскаты, Новая, 4	f	small
53981	61278	599	Нижегородская область, Воскресенский район, село Погатиха, Интернациональная, 45	f	small
53995	61293	617	Нижегородская область, Воскресенский район, деревня Осиновка, Школьная, 94	f	small
53993	61291	615	Нижегородская область, Воскресенский район, село Нестиары, Зеленая, 3	t	small
53990	61287	608	Нижегородская область, Воскресенский район, село Марфино	t	small
54003	61302	626	Нижегородская область, Воскресенский район, село Малое Содомово, Больничная, 18	t	small
53991	61289	609	Нижегородская область, Воскресенский район, деревня Кучиново, Прямая, 19а	f	small
53992	61290	613	Нижегородская область, Воскресенский район, село Красный Яр, Советская, 2в, ДК	f	small
53988	61285	606	Нижегородская область, Воскресенский район, село Капустиха, Клубная, 1а	t	small
53974	61271	591	Нижегородская область, Воскресенский район, поселок Калиниха, Береговая, 22	f	large
53976	61273	594	Нижегородская область, Воскресенский район, село Задворка, Мира, 2	f	small
53997	61295	620	Нижегородская область, Воскресенский район, село Елкино, Школьная, 52	f	small
53989	61286	607	Нижегородская область, Воскресенский район, село Елдеж, Набережная, 23	t	small
53994	61292	616	Нижегородская область, Воскресенский район, село Егорово, Центральная, 1	t	small
53978	61275	596	Нижегородская область, Воскресенский район, село Докукино, Центральная, 14	f	small
53996	61294	618	Нижегородская область, Воскресенский район, село Глухово, Школьная, 3	f	medium
53977	61274	595	Нижегородская область, Воскресенский район, село Галибиха, Пролетарская, 55	f	small
53971	61268	588	Нижегородская область, Воскресенский район, поселок Воскресенское	f	large
53970	61267	587	Нижегородская область, Воскресенский район, поселок Воскресенское, пл. Ленина, 2	f	large
53973	61270	590	Нижегородская область, Воскресенский район, поселок Воскресенское, Ленина, 102	f	large
53972	61269	589	Нижегородская область, Воскресенский район, поселок Воскресенское, Ленина, 129	f	large
53998	61296	621	Нижегородская область, Воскресенский район, село Воздвиженское, Ленина, 56	f	medium
53982	61279	600	Нижегородская область, Воскресенский район, село Владимирское	f	medium
54002	61300	625	Нижегородская область, Воскресенский район, село Большое Поле, Новая, 2	t	small
54000	61298	623	Нижегородская область, Воскресенский район, село Большое Иевлево	f	small
53999	61297	622	Нижегородская область, Воскресенский район, село Большие Отары, Луговая, 14	f	small
53975	61272	593	Нижегородская область, Воскресенский район, село Богородское, Комсомольская, 4	f	medium
53980	61277	598	Нижегородская область, Воскресенский район, село Благовещенское, Советская, 67	t	small
53984	61281	602	Нижегородская область, Воскресенский район, село Бараново, Советская, 1	f	small
53979	61276	597	Нижегородская область, Воскресенский район, село Асташиха	f	small
53968	61266	585	Нижегородская область, Воротынский район, село Шереметьево, Советская, 72, сельский клуб	f	small
53967	61265	583	Нижегородская область, Воротынский район, село Чугуны, Советская, 1, Здание Администрации сельсовета	f	small
53966	61264	582	Нижегородская область, Воротынский район, село Фокино, Мира, 5А, Дом культуры	f	medium
53965	61263	581	Нижегородская область, Воротынский район, село Тришкино, сельский клуб	f	small
53964	61262	580	Нижегородская область, Воротынский район, село Сомовка, Свободы, сельский клуб	t	small
53963	61261	579	Нижегородская область, Воротынский район, село Семьяны, Малова, 20А, сельский клуб	f	medium
53962	61260	578	Нижегородская область, Воротынский район, село Разнежье, Ленина, 91А, сельский клуб	t	small
53961	61259	577	Нижегородская область, Воротынский район, село Покров-Майдан, Советская, 37, здание администрации сельсовета	f	small
53959	61257	575	Нижегородская область, Воротынский район, село Отары, Молодежная, 225, сельский клуб	f	small
53958	61256	574	Нижегородская область, Воротынский район, село Осинки, Петровская, 65, сельский клуб	f	small
53960	61258	576	Нижегородская область, Воротынский район, село Огнев-Майдан, Кооперативная, 2А, сельский клуб	f	small
53956	61255	571	Нижегородская область, Воротынский район, село Михайловское, Победы, 8, Администрация сельсовета	f	medium
53954	61253	569	Нижегородская область, Воротынский район, село Львово, Центральная, 55, частный дом	t	small
53955	61254	570	Нижегородская область, Воротынский район, село Лысая Гора, Сурская, 71, сельский клуб	f	small
53953	61252	568	Нижегородская область, Воротынский район, село Липовка	t	small
53950	61249	565	Нижегородская область, Воротынский район, село Кузьмияр, Центральная, 14, детский сад	t	small
53948	61247	563	Нижегородская область, Воротынский район, село Криуши	f	small
53951	61250	566	Нижегородская область, Воротынский район, село Красная Горка, Береговая, 16, дом культуры	f	small
53952	61251	567	Нижегородская область, Воротынский район, село Кекино, сельский клуб	f	small
53949	61248	564	Нижегородская область, Воротынский район, село Каменка, Заводская, 44А, Администрация сельсовета	t	small
86699	61246	562	Нижегородская область, Воротынский район, село Ивановка	f	small
53946	61245	561	Нижегородская область, Воротынский район, село Елвашка, Нагорная, 6, сельский клуб	f	small
53938	61236	553	Нижегородская область, Воротынский район, поселок Воротынец	f	large
53935	61233	550	Нижегородская область, Воротынский район, поселок Воротынец	f	large
53936	61234	551	Нижегородская область, Воротынский район, поселок Воротынец, Микройрайон Молодежный, 2, начальная школа Родничок	f	medium
53908	61207	521	Нижегородская область, Воротынский район, поселок Воротынец, Космонавтов, 8, МОУ Воротынская средняя школа	f	medium
111753	61235	552	Нижегородская область, Воротынский район, поселок Воротынец, Зубова , 40, КДЦ Мир	f	medium
53939	61237	554	Нижегородская область, Воротынский район, Воротынец, Демьяна Бедного, 1, Администрация р.п.Воротынец	f	medium
53940	61239	555	Нижегородская область, Воротынский район, поселок Васильсурск	f	medium
53942	61241	557	Нижегородская область, Воротынский район, село Быковка, Школьная, 68, сельский клуб	f	small
53944	61243	559	Нижегородская область, Воротынский район, село Березов Майдан, Школьная, 82, сельский клуб	f	small
53945	61244	560	Нижегородская область, Воротынский район, село Белогорка	f	small
53943	61242	558	Нижегородская область, Воротынский район, село Белавка, Горького, 38, сельский клуб	f	small
53941	61240	556	Нижегородская область, Воротынский район, село Ахпаевка, Центральная, 35, сельский клуб	f	small
53918	61215	532	Нижегородская область, Володарский район, поселок Юганец	f	large
53917	61214	531	Нижегородская область, Володарский район, поселок Юганец, Центральная, 1, клуб в/ч п. Юганец	t	large
53932	61230	547	Нижегородская область, Володарский район, поселок Центральный, Мирошниченко , 8, ДК п. Центральный	f	large
53933	61231	548	Нижегородская область, Володарский район, поселок Фролищи, Школьная, 9, школа 47	f	large
53928	61226	543	Нижегородская область, Володарский район, поселок Смолино, 1 Мая, 2, здание Смолинской поселковой админ	f	large
53910	61209	523	Нижегородская область, Володарский район, поселок Решетиха, Кирова , 3а, средняя школа №42	f	large
53911	61210	524	Нижегородская область, Володарский район, поселок Решетиха, Кирова, 25, начальная школа 51	f	large
53909	61208	522	Нижегородская область, Володарский район, поселок Решетиха, Затылкова, 1а, ДК им. Луначарского	f	large
53925	61222	540	Нижегородская область, Володарский район, поселок Новосмолинский, Танковая , 25, Дом офицеров	t	large
53890	61177	503	Нижегородская область, Вознесенский район, село Бахтызино	f	medium
53926	61223	541	Нижегородская область, Володарский район, поселок Новосмолинский, Танковая, 54, школа 48	f	large
53927	61224	542	Нижегородская область, Володарский район, село Мячково, Советская, 17а, клуб СДК с. Мячково	f	small
55755	62726	2491	Нижегородская область, Володарский район, поселок Мулино, Новая , 23, школа 59	f	large
68282	61227	544	Нижегородская область, Володарский район, поселок Мулино, Новая, 23, школа 59	f	large
68284	61229	546	Нижегородская область, Володарский район, поселок Мулино, Гвардейская , 60, ГДО п. Мулино	f	large
68283	61228	545	Нижегородская область, Володарский район, поселок Мулино, Гвардейская , 74, молодежный центр п. Мулино	f	large
53919	61216	533	Нижегородская область, Володарский район, поселок Красная Горка, Ленина, 12а, школа 43	f	medium
53922	61219	536	Нижегородская область, Володарский район, поселок Ильиногорск, Угарова , 9, школа 53	f	large
53921	61218	535	Нижегородская область, Володарский район, поселок Ильиногорск, Угарова , 2, ДК п. Ильиногорск	f	large
53920	61217	534	Нижегородская область, Володарский район, поселок Ильиногорск, Угарова, 2, ДК 	f	large
68281	61220	537	Нижегородская область, Володарский район, село Ильино	f	large
53924	61221	539	Нижегородская область, Володарский район, село Золино, Школьная , 24, школа - интернат п. Золино	f	small
53912	61211	526	Нижегородская область, Володарский район, Володарск, Октябрьская, 34, школа 49	f	large
53916	61213	530	Нижегородская область, Володарский район, Володарск, Мичурина , 2б, ФОК ТРИУМФ	f	large
55753	62773	2489	Нижегородская область, Володарский район, Володарск, Мичурина, 19а, школа 50	f	medium
53915	61165	529	Нижегородская область, Володарский район, Володарск, Мичурина, 19а, школа 50	f	large
53913	61212	527	Нижегородская область, Володарский район, Володарск, Клубная, 3, городской Дом культуры	f	large
53914	61189	528	Нижегородская область, Володарский район, Володарск, Клубная, 3, городской Дом культуры	f	medium
53907	61206	520	Нижегородская область, Вознесенский район, село Суморьево, Советская, 3, помещение сельского ДК	f	small
53904	61203	517	Нижегородская область, Вознесенский район, село Сарминский Майдан, Советская, 14, сельский Дом культуры	f	medium
53898	61197	511	Нижегородская область, Вознесенский район, село Починки, Школьная, 1, помещение сельской библиотеки	t	small
53905	61204	518	Нижегородская область, Вознесенский район, село Полховский Майдан, Молодежная, 116, помещение школы	f	large
53896	61195	509	Нижегородская область, Вознесенский район, село Новоселки, Кооперативная, 2А, сельский Дом культуры	f	small
53901	61200	514	Нижегородская область, Вознесенский район, село Нарышкино, Ленина, 6Б, сельская администрация	f	medium
53900	61199	513	Нижегородская область, Вознесенский район, село Мотызлей, Ленина, 55, сельская администрация	f	medium
53899	61198	512	Нижегородская область, Вознесенский район, село Линейка, Советская, 3А, сельский Дом культуры	f	small
53906	61205	519	Нижегородская область, Вознесенский район, село Куриха, Мелькинская, 39А, сельская администрация	f	medium
53897	61196	510	Нижегородская область, Вознесенский район, село Криуша, Советская, 83, сельский Дом культуры	f	medium
53903	61202	516	Нижегородская область, Вознесенский район, село Илев	t	small
53902	61201	515	Нижегородская область, Вознесенский район, село Заря, Заречная, 3А, сельская библиотека	f	small
53886	61185	499	Нижегородская область, Вознесенский район, поселок Вознесенское	f	large
53887	61186	500	Нижегородская область, Вознесенский район, поселок Вознесенское, Садовая, 2, помещение танцевального зала РДК	f	large
53885	61184	498	Нижегородская область, Вознесенский район, поселок Вознесенское, Индустриальная, 1, магазин Полюс	f	large
53888	61187	501	Нижегородская область, Вознесенский район, поселок Вознесенское, Заречная , 6, НОУ Вознесенская автошкола	f	large
53893	61192	506	Нижегородская область, Вознесенский район, село Варнаево	f	small
53894	61193	507	Нижегородская область, Вознесенский район, село Бутаково	f	small
53892	61191	505	Нижегородская область, Вознесенский район, село Букалей	t	small
53895	61194	508	Нижегородская область, Вознесенский район, село Борки	f	small
53891	61190	504	Нижегородская область, Вознесенский район, село Благодатовка, Первомайская, 24, сельская администрация	f	small
53889	61188	502	Нижегородская область, Вознесенский район, село Аламасово, Ленина, 41А, помещение сельского ДК	t	small
111749	61166	478	Нижегородская область, Ветлужский район, поселок имени М. И.Калинина	f	medium
111750	61167	479	Нижегородская область, Ветлужский район, поселок имени М. И.Калинина, Ленина, 9, здание дома культуры	f	medium
86698	61179	492	Нижегородская область, Ветлужский район, село Турань	f	small
53876	61174	486	Нижегородская область, Ветлужский район, село Стрелица, Здание администрации Мошкинского сельсовета	f	small
53877	61175	488	Нижегородская область, Ветлужский район, село Скулябиха, Здание администрации Мошкинского сельсовета	f	small
53881	61180	494	Нижегородская область, Ветлужский район, село Скрябино	f	small
53882	61181	495	Нижегородская область, Ветлужский район, село Пустошь, Здание сельского дома культуры	f	small
53884	61183	497	Нижегородская область, Ветлужский район, село Новоуспенское, Здание администрации Новоуспенского сельсовета	f	small
111751	61178	490	Нижегородская область, Ветлужский район, село Новопокровское, Ленинская, 2, здание администрации Проновского сельсовета	f	medium
53874	61172	484	Нижегородская область, Ветлужский район, село Махони, Здание дома культуры	f	small
53883	61182	496	Нижегородская область, Ветлужский район, село Маркуша, Здание сельского дома культуры	f	small
53871	61169	481	Нижегородская область, Ветлужский район, село Крутцы	f	small
53870	61168	480	Нижегородская область, Ветлужский район, село Крутцы, 28, Здание администрации Крутцовского сельсовета	f	small
53878	61176	489	Нижегородская область, Ветлужский район, село Галкино, Здание администрации Мошкинского сельсовета	f	small
53875	61173	485	Нижегородская область, Ветлужский район, село Волынцы	f	small
53867	61164	477	Нижегородская область, Ветлужский район, Ветлуга	f	large
53865	61162	475	Нижегородская область, Ветлужский район, Ветлуга	f	large
53863	61160	473	Нижегородская область, Ветлужский район, Ветлуга, Бахирева, 35а	f	medium
53866	61163	476	Нижегородская область, Ветлужский район, Ветлуга, 5, территория СХТ	f	large
53873	61171	483	Нижегородская область, Ветлужский район, Ветлуга, Спортивная, 3, Ветлужская СОШ	f	large
53864	61161	474	Нижегородская область, Ветлужский район, Ветлуга, Бахирева, 50	f	large
53872	61170	482	Нижегородская область, Ветлужский район, село Белышево	f	small
53850	61146	456	Нижегородская область, Вачский район, село Яковцево, Советская, 13а, помещение дома культуры	f	small
86697	61155	464	Нижегородская область, Вачский район, село Чулково	f	small
53857	61154	463	Нижегородская область, Вачский район, село Чулково, Набережная, 24, помешение сельской администрации	f	medium
53851	61147	457	Нижегородская область, Вачский район, село Филинское	f	large
53852	61148	458	Нижегородская область, Вачский район, село Филинское, Больничная, 15, пом. сельской администрации	f	medium
53847	61143	453	Нижегородская область, Вачский район, село Федурино, Школьная, 57, помещение библиотеки	f	small
53844	61140	450	Нижегородская область, Вачский район, село Сколково	t	small
53838	61134	444	Нижегородская область, Вачский район, село Сергеево, 166а, Дом досуга	f	small
53839	61135	445	Нижегородская область, Вачский район, село Польцо	f	small
53846	61142	452	Нижегородская область, Вачский район, село Новоселки, Ленина, 91, Помещение сельской администрации	f	medium
53836	61132	442	Нижегородская область, Вачский район, село Медоварцево, Медоварцево, 143, здание Медоварцевской школы	f	small
53849	61145	455	Нижегородская область, Вачский район, село Лесниково, Школьная, 1а , помещение клуба	f	small
53856	61153	462	Нижегородская область, Вачский район, село Клин	f	small
53840	61136	446	Нижегородская область, Вачский район, село Казаково, Заводская, 45, помещение школы	f	medium
53841	61137	447	Нижегородская область, Вачский район, село Звягино, молодежная, 21, Школа-сад	f	medium
53837	61133	443	Нижегородская область, Вачский район, село Епифаново, 133, ДК-библиотека	f	small
53854	61150	460	Нижегородская область, Вачский район, село Давыдово, Большая слобода, 216, помещение дома культуры	f	small
53834	61131	440	Нижегородская область, Вачский район, село Верхополье, Зеленая, 9, помещение школы	f	small
68280	61157	466	Нижегородская область, Вачский район, поселок Вача	f	large
53842	61138	448	Нижегородская область, Вачский район, поселок Вача	f	small
68279	61156	465	Нижегородская область, Вачский район, поселок Вача, Советская, 3, помещение Вачской средней общеобразовательной школы	f	large
53862	61159	468	Нижегородская область, Вачский район, поселок Вача, Ленина, 2, Учебный корпус школы интерната	f	large
53861	61158	467	Нижегородская область, Вачский район, поселок Вача, Больничная, 21, Центр занятости населения	f	large
53853	61149	459	Нижегородская область, Вачский район, село Болотниково, 6, помещение медпункта	t	small
53855	61151	461	Нижегородская область, Вачский район, село Березовка	f	small
53848	61144	454	Нижегородская область, Вачский район, село Беляйково	f	medium
53845	61141	451	Нижегородская область, Вачский район, село Белогузово, Большой порядок, 38, Дом досуга	f	small
53832	61129	438	Нижегородская область, Вачский район, село Арефино, Пестрякова, 44, Сельская администрация	f	medium
53833	61130	439	Нижегородская область, Вачский район, село Арефино, Первомайская, 60, Дом культуры	f	medium
53843	61139	449	Нижегородская область, Вачский район, село Алтунино, Советская, 79, помещение сельской администрации	f	medium
86658	61120	429	Нижегородская область, Варнавинский район, село Черемушки, Советская, 18	f	small
68278	61127	437	Нижегородская область, Варнавинский район, поселок Северный, Молодежная, 25	f	large
86696	61126	436	Нижегородская область, Варнавинский район, село Новоникольское, Центральная, 41 , Дом культуры	f	small
86694	61124	434	Нижегородская область, Варнавинский район, село Михаленино, Школьная, 2	f	small
86657	61119	428	Нижегородская область, Варнавинский район, село Мирный	f	small
86693	61122	432	Нижегородская область, Варнавинский район, село Макарий, Молодежная, 25	f	small
86655	61117	426	Нижегородская область, Варнавинский район, село Красный Луч, Ленинская, 8	f	small
86695	61125	435	Нижегородская область, Варнавинский район, село Зверниха	f	small
86692	61121	431	Нижегородская область, Варнавинский район, село Горки	f	small
86656	61118	427	Нижегородская область, Варнавинский район, село Восход, Центральная, 13, здание школы	f	small
68227	61114	423	Нижегородская область, Варнавинский район, поселок Варнавино	f	large
68228	61115	424	Нижегородская область, Варнавинский район, поселок Варнавино, III Интернационала, 1А	f	large
111748	61123	433	Нижегородская область, Варнавинский район, село Богородское, Первомайская, 1	f	medium
86654	61116	425	Нижегородская область, Варнавинский район, село Антониха, Антонихинская, 14	f	small
86650	61110	419	Нижегородская область, Вадский район, село совхоз Новый Мир	f	small
86638	61102	411	Нижегородская область, Вадский район, село Щедровка, Микрорайон, 8	f	small
86653	61113	422	Нижегородская область, Вадский район, село Холостой Майдан, Майская, 31, административное здание подсобного хозяйства «Майский»	f	small
86649	61109	418	Нижегородская область, Вадский район, село Умай, Центральная, 3, ДК	f	small
86637	61101	410	Нижегородская область, Вадский район, село Стрелка	f	small
86647	61106	415	Нижегородская область, Вадский район, село Свобода, Молодежная, 1, школа	f	small
86652	61112	421	Нижегородская область, Вадский район, село Петлино, Микрорайон, 11, ДК	f	small
86648	61107	416	Нижегородская область, Вадский район, село Лопатино, Лопатинская, 45а, ДК	f	small
86676	61103	412	Нижегородская область, Вадский район, село Крутой Майдан	f	small
86645	61104	413	Нижегородская область, Вадский район, село Крутой Майдан, Микрорайон, 10, здание сельского Дома культуры	f	small
86646	61105	414	Нижегородская область, Вадский район, село Зеленые Горы, Садовая, 11, ДК	f	small
86636	61100	409	Нижегородская область, Вадский район, село Елховка	f	small
86651	61111	420	Нижегородская область, Вадский район, село Дубенское	f	small
53801	61097	406	Нижегородская область, Вадский район, село Вад	f	large
53802	61098	407	Нижегородская область, Вадский район, село Вад, Просвещения, 33, школа	f	large
68221	61096	405	Нижегородская область, Вадский район, село Вад, 50 пет Октября, 16, РДК	f	large
111747	61108	417	Нижегородская область, Вадский район, село Анненковского Карьера, улица Центральная, 1, школа	f	medium
86633	61092	399	Нижегородская область, Бутурлинский район, село Ягубовка	f	small
86631	61090	395	Нижегородская область, Бутурлинский район, село Уварово, Советская, 74, администрация Уваровского сельсовета	f	small
86632	61091	398	Нижегородская область, Бутурлинский район, село Тарталей, Октябрьская, 56, Сельский клуб	f	small
86623	61067	376	Нижегородская область, Бутурлинский район, село Смагино, Сутягина, 58, Сельский Дом культуры	f	small
86628	61085	388	Нижегородская область, Бутурлинский район, село Пергалей, Мира, 60, Сельский Дом культуры	f	small
111745	61089	393	Нижегородская область, Бутурлинский район, село Лукьяново, Центральная, Фельдшерско-акушерский пункт	t	small
86625	61082	382	Нижегородская область, Бутурлинский район, село Крутец, Ленина, 126а, Сельский клуб	f	small
86626	61083	383	Нижегородская область, Бутурлинский район, село Кремницкое	f	small
111744	61086	390	Нижегородская область, Бутурлинский район, село Кочуново, Центральная, 16, Сельский Дом культуры	f	medium
86627	61084	385	Нижегородская область, Бутурлинский район, село Кетрось, Новая, 17, МБДОУ Кетросский детский сад	f	small
86629	61087	391	Нижегородская область, Бутурлинский район, село Кеньшево, Нагорная, 16 Б, Сельский клуб	f	small
111743	61081	380	Нижегородская область, Бутурлинский район, село Каменищи, 1 Мая, 69а, административное здание ООО Вперед	f	medium
86630	61088	392	Нижегородская область, Бутурлинский район, село Инкино, Школьная, 15в, Сельский Дом культуры	f	small
86624	61080	378	Нижегородская область, Бутурлинский район, село Валгусы, Молодежная, 4, МОУ Валгусская СОШ (социокультурный центр)	f	small
68220	61078	375	Нижегородская область, Бутурлинский район, поселок Бутурлино, П.Бегина, 1, МБОУ Базинская ООШ(социокультурный центр)	f	large
68219	61076	373	Нижегородская область, Бутурлинский район, поселок Бутурлино, Ленина, 105, Районный Дворец культуры	f	large
53780	61077	374	Нижегородская область, Бутурлинский район, поселок Бутурлино, Комсомольская, 7, Бутурлинский сельскохозяйственный техникум	f	large
86634	61093	400	Нижегородская область, Бутурлинский район, село Борнуково, Центральная, 126 А, Сельский Дом культуры	f	small
86635	61094	401	Нижегородская область, Бутурлинский район, село Большой Якшень, Спортивная, 1а, Якшенская ООШ - филиал МБОУ Ягубовской СОШ	f	small
111742	61079	377	Нижегородская область, Бутурлинский район, село Большие Бакалды, Первомайская, 75, Сельский Дом культуры	f	medium
53772	61069	366	Нижегородская область, Борский район, село Ямново, Школьная, 18, МБОУ Ямновская Средняя Общеобразовательная Школа	f	large
53750	61046	344	Нижегородская область, Борский район, село Шпалозавода, Клуб	f	medium
53765	61062	359	Нижегородская область, Борский район, село Чистое-Борское, Ленина, 5, МБОУ Чистоборская Основная Общеобразовательная Школа	f	medium
53756	61053	350	Нижегородская область, Борский район, село Чистое Поле, Чистопольское представительство Линдовского территориального управления администрации городского округа город Бор	f	medium
53741	61038	335	Нижегородская область, Борский район, деревня Тайново, 67а, ФАП	t	medium
53743	61040	337	Нижегородская область, Борский район, поселок Ситники, Центральная, 21, МБУК Ситниковский Дом Культуры	f	large
53768	61064	362	Нижегородская область, Борский район, село Рустай, Рустайское представительство Останкинского территориального управления администрации городского округа город Бор.	f	small
53764	61061	358	Нижегородская область, Борский район, село Рожново, Рожновское представительство Редькинского территориального управления администрации городского округа город Бор	t	small
53746	61043	340	Нижегородская область, Борский район, село Рекшино, 93, ГОУ Рекшинское ПУ-интернат	t	medium
53763	61060	357	Нижегородская область, Борский район, село Редькино, 19	f	large
53747	61044	341	Нижегородская область, Борский район, поселок Попово, ГОУ Поповская специальная школа-интернат	t	small
53775	61072	369	Нижегородская область, Борский район, село Плотинка, Школьная, 236, МБОУ Плотинковская Основная Общеобразовательная Школа	f	medium
53771	61068	365	Нижегородская область, Борский район, поселок Память Парижской Коммуны, Школьная, 11, МБОУ Затонская Средняя Общеобразовательная Школа	f	large
53770	61066	364	Нижегородская область, Борский район, поселок Память Парижской Коммуны, Зеленая, 1, МБУК Дом Культуры-музей	f	large
53767	61063	361	Нижегородская область, Борский район, село Останкино, Школьная, 13	f	medium
53766	61063	360	Нижегородская область, Борский район, село Останкино, Школьная, 13	f	medium
53757	61054	351	Нижегородская область, Борский район, село Оманово	t	large
53735	61031	329	Нижегородская область, Борский район, поселок Октябрьский, Победы, 15а, МБОУ Октябрьская Средняя Общеобразовательная Школа	f	large
53661	60961	247	Нижегородская область, Борский район, поселок Неклюдово, кварт. Дружба, 14, МБОУ Неклюдовский детский сад "Рукавичка"	f	large
53740	61036	334	Нижегородская область, Борский район, поселок Неклюдово, Лесная, 5, МБОУ ДОД детский сад №8 Жемчужинка	f	large
68216	61035	333	Нижегородская область, Борский район, поселок Неклюдово, Клубная, 4а, МУК Неклюдовский Дом Культуры	f	large
53737	61033	331	Нижегородская область, Борский район, поселок Неклюдово, Дружбы, 1а, МБОУ Средняя Общеобразовательная Школа № 12	f	medium
53738	61034	332	Нижегородская область, Борский район, поселок Неклюдово, Вокзальная, 88, Производственное подразделение ВГГП Волгагеология	f	large
68218	61050	347	Нижегородская область, Борский район, село Линда	f	large
53752	61049	346	Нижегородская область, Борский район, село Линда, Школьная, 11а	f	large
53751	61047	345	Нижегородская область, Борский район, село Линда, Школьная, 7а, МБОУ Линдовская Средняя Общеобразовательная Школа	f	large
111755	61438	774	Нижегородская область, Борский район, село Линда, Дзержинского, 40, Линдовское территориальное управление администрации городского округа	f	medium
53758	61055	352	Нижегородская область, Борский район, село Красная Слобода, Центральная, 24, МБУК Краснослободский СКК	f	large
53754	61051	348	Нижегородская область, Борский район, деревня Коврово , помещение Ковровского представительства	f	medium
53760	61057	354	Нижегородская область, Борский район, поселок Керженец, помещение клуба	f	medium
54315	61575	964	Нижегородская область, Борский район, село Кантаурово, Совхозная, 15б, МБОУ Кантауровская Средняя Общеобразовательная Школа	f	large
53745	61042	339	Нижегородская область, Борский район, село Кантаурово, Совхозная, 20А, МБУК Кантауровский социально-культурный комплекс	f	large
53749	61045	343	Нижегородская область, Борский район, село Каликино, ДК	f	medium
53748	61045	342	Нижегородская область, Борский район, село Каликино, ДК	f	medium
53742	61039	336	Нижегородская область, Борский район, село Ивонькино, помещение Ивонькинского представительства	f	medium
86622	61071	368	Нижегородская область, Борский район, село Ивановское, Бывшая школа села Ивановское	t	small
53773	61070	367	Нижегородская область, Борский район, село Завражное, Клубная, 6, Библиотека	f	medium
68300	61574	963	Нижегородская область, Борский район, село Железнодорожный, Центральная, 6, МБУК Центр досуга	f	large
68217	61041	338	Нижегородская область, Борский район, село Железнодорожный, Центральная, 6, МБУК Центр досуга	f	large
111740	61058	355	Нижегородская область, Борский район, село Городищи, 2, Городищенксое представительство Краснослободского территориального управления администрации городского округа	t	medium
53762	61059	356	Нижегородская область, Борский район, село Владимирово, 5, ООО Гласс-Продакт	f	large
53778	61075	372	Нижегородская область, Борский район, село Боталово, Филатова, 6, Демонстрационный дом	f	large
53732	61028	326	Нижегородская область, Борский район, поселок Большое Пикино, 1 Мая, 10, МБУК Большепикинский дом культуры	f	large
53660	60960	246	Нижегородская область, Борский район, поселок Большое Пикино, 1 Мая, 10, МБУК Большепикинский дом культуры	f	medium
53769	61065	363	Нижегородская область, Борский район, село Большеорловское, МУК Большеорловский социально-культурный комплекс	f	medium
111738	60998	292	Нижегородская область, Большемурашкинский район, село Холязино	f	medium
111736	60991	285	Нижегородская область, Большемурашкинский район, поселок Советский, Дом культуры	f	medium
86639	60990	284	Нижегородская область, Большемурашкинский район, село Рождествено, Дом культуры	f	small
86642	60994	288	Нижегородская область, Большемурашкинский район, село Курлаково	f	small
111737	60996	290	Нижегородская область, Большемурашкинский район, село Кишкино	f	medium
68210	60895	175	Нижегородская область, Балахнинский район, поселок Гидроторф	f	large
86643	60995	289	Нижегородская область, Большемурашкинский район, село Карабатово	f	small
86644	60997	291	Нижегородская область, Большемурашкинский район, село Ивановское, помещение ОАО Суворовское	f	small
86641	60993	287	Нижегородская область, Большемурашкинский район, село Григорово, Сельский Дом культуры	f	small
86640	60992	286	Нижегородская область, Большемурашкинский район, село Вершинино, Детский сад	f	small
68223	60987	281	Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино	f	large
111732	60985	279	Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино	f	medium
111733	60986	280	Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино, п.Меховщиков	f	medium
111735	60989	283	Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино, Спортивная, 2а	f	medium
68222	60984	278	Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино, Свободы, 80	f	large
111734	60988	282	Нижегородская область, Большемурашкинский район, поселок Большое Мурашкино, 6-й микрорайон, 2	f	medium
86621	60983	276	Нижегородская область, Большеболдинский район, село Чиреси, Восточная, 15А	f	small
86620	60982	275	Нижегородская область, Большеболдинский район, село Черновское, Центральная, 4	f	small
86619	60981	274	Нижегородская область, Большеболдинский район, село Усад, Центральная, 1	f	small
86617	60979	271	Нижегородская область, Большеболдинский район, село Сумароково, Школьная, 59	f	small
86616	60978	270	Нижегородская область, Большеболдинский район, село Старое Ахматово, Балашова, 38	f	small
86618	60980	272	Нижегородская область, Большеболдинский район, село Сергеевка, Ленина, 14А	f	small
86614	60976	267	Нижегородская область, Большеболдинский район, село Пикшень, Ленина, 1	f	small
86615	60977	269	Нижегородская область, Большеболдинский район, село Пермеево, Молодежная, 21	f	small
111731	60975	266	Нижегородская область, Большеболдинский район, село Новая Слобода, Советская, 14б	f	medium
86613	60974	264	Нижегородская область, Большеболдинский район, село Молчаново	f	small
86612	60973	263	Нижегородская область, Большеболдинский район, село Кондрыкино	f	small
86611	60972	261	Нижегородская область, Большеболдинский район, село Илларионово, Советская, 140	f	small
86608	60969	257	Нижегородская область, Большеболдинский район, поселок Большое Казариново	f	small
68215	60968	256	Нижегородская область, Большеболдинский район, село Большое Болдино, Пушкинская, 144	f	large
111730	60966	254	Нижегородская область, Большеболдинский район, село Большое Болдино, Красная, 12	f	medium
111729	60941	253	Нижегородская область, Большеболдинский район, село Большое Болдино, Кооперативная, 7	f	medium
68214	60967	255	Нижегородская область, Большеболдинский район, село Большое Болдино, Восточная, 28	f	large
86609	60970	258	Нижегородская область, Большеболдинский район, село Большие Поляны	f	small
86610	60971	259	Нижегородская область, Большеболдинский район, село Большевик	f	small
86607	60965	252	Нижегородская область, Большеболдинский район, село Апраксино, Гагарина, 75	f	small
86606	60964	250	Нижегородская область, Большеболдинский район, село Аносово, Ленина, 1А	f	small
53635	60933	216	Нижегородская область, Богородский район, село Швариха, Школа	f	medium
53655	60954	236	Нижегородская область, Богородский район, село Шапкино, помещение сельской администрации	f	small
53657	60956	238	Нижегородская область, Богородский район, село Центральный	f	medium
53652	60951	233	Нижегородская область, Богородский район, село Хвощевка, помещение сельской администрации	f	medium
53633	60931	214	Нижегородская область, Богородский район, село Ушаково	f	small
53631	60929	212	Нижегородская область, Богородский район, деревня Теряево, школа	f	small
53642	60940	223	Нижегородская область, Богородский район, село Сысоевка, Совхозная, помещение ФАП	t	small
53659	60958	240	Нижегородская область, Богородский район, село Солонское	f	small
53651	60950	232	Нижегородская область, Богородский район, село Оранки	f	medium
53637	60935	218	Нижегородская область, Богородский район, поселок Окский, Дом культуры	f	large
53647	60946	228	Нижегородская область, Богородский район, поселок Новинки, Дом культуры	f	large
53656	60955	237	Нижегородская область, Богородский район, село Лукино, помещение школы	f	small
53653	60952	234	Нижегородская область, Богородский район, село Лакша, помещение филиала Шапкинской сельской администрации	f	medium
53648	60947	229	Нижегородская область, Богородский район, деревня Кусаковка, Помещение ФАП	t	medium
53649	60948	230	Нижегородская область, Богородский район, поселок Кудьма, улица Пушкина, Дом культуры	t	large
86604	60949	231	Нижегородская область, Богородский район, село Ключищи, Дорожная, 8, Помещение начальной школы	t	small
53644	60943	225	Нижегородская область, Богородский район, село Каменки, помещение сельской администрации	f	large
53646	60945	227	Нижегородская область, Богородский район, село Каменки, Зеленая, 37	f	small
53643	60942	224	Нижегородская область, Богородский район, село Инютино, помещение филиала Каменской сельской администрации	f	small
53640	60938	221	Нижегородская область, Богородский район, село Дуденево, помещение сельской администрации	f	large
53636	60934	217	Нижегородская область, Богородский район, село Доскино, Школа	f	medium
53630	60928	211	Нижегородская область, Богородский район, село Демидово, помещение ФАП	t	small
53627	60925	208	Нижегородская область, Богородский район, село Демидово, 3-ий микрорайон, 4а	f	large
53658	60957	239	Нижегородская область, Богородский район, село Высоково, помещение спортивной базы Снежинка	f	small
53638	60936	219	Нижегородская область, Богородский район, поселок Буревестник, Дом культуры	f	large
68211	60920	202	Нижегородская область, Богородский район, Богородск, переулок Карла Маркса, 1	f	large
53623	60922	204	Нижегородская область, Богородский район, Богородск, Чернышевского, 42	f	large
53618	60917	199	Нижегородская область, Богородский район, Богородск, Урицкого, 69	f	large
68212	60921	203	Нижегородская область, Богородский район, Богородск, Пушкина, 24, столовая ОАО Богородский машиностроительный завод	f	large
86605	60959	241	Нижегородская область, Богородский район, Богородск, Ленина, 101, Фойе районного Дома культуры	f	small
53628	60926	209	Нижегородская область, Богородский район, Богородск, Ленина, 101	f	large
53616	60915	197	Нижегородская область, Богородский район, Богородск, Добролюбова, 2	f	large
53614	60913	195	Нижегородская область, Богородский район, Богородск, Данилова, 36	f	large
53619	60918	200	Нижегородская область, Богородский район, Богородск, Героя Салова, 15	f	large
53626	60924	207	Нижегородская область, Богородский район, Богородск, 3-ий микрорайон, 15а	f	large
68213	60939	222	Нижегородская область, Богородский район, село Березовка, Комсомольская, Школа	f	large
53654	60953	235	Нижегородская область, Богородский район, село Афанасьево, Дом досуга	t	small
53632	60930	213	Нижегородская область, Богородский район, село Арапово, помещение филиала Алешковской сельской администрации	f	medium
53629	60927	210	Нижегородская область, Богородский район, село Алешково	f	medium
53605	60904	184	Нижегородская область, Балахнинский район, село Шеляухово, 58А	f	medium
53607	60906	186	Нижегородская область, Балахнинский район, поселок Совхозный, Дом Досуга	f	large
53604	60903	183	Нижегородская область, Балахнинский район, Поселок Большое Козино, Пушкина, 1, СОШ №20	f	large
53603	60902	182	Нижегородская область, Балахнинский район, Поселок Большое Козино, Матросова, 12, библиотека	f	large
53602	60901	181	Нижегородская область, Балахнинский район, Поселок Большое Козино, Большая Школьная, 64, ДК Возрождение	f	large
54123	61418	753	Нижегородская область, Балахнинский район, поселок Первомайский, Центральная, 4, здание администрации	f	large
53601	60900	180	Нижегородская область, Балахнинский район, поселок Малое Козино, Октября, 74, библиотека	f	small
53599	60898	178	Нижегородская область, Балахнинский район, поселок Лукино	f	large
53598	60897	177	Нижегородская область, Балахнинский район, поселок Лукино, Победы, 18, СОШ №18	f	large
53610	60909	189	Нижегородская область, Балахнинский район, село Конево	f	large
53608	60907	187	Нижегородская область, Балахнинский район, село Истомино, Генерала Маргелова, СОШ	f	large
53609	60908	188	Нижегородская область, Балахнинский район, село Замятино, Здание администрации	f	medium
44459	42597	1082	Кировская область, Слободской, Советская, 100	f	medium
53594	60893	173	Нижегородская область, Балахнинский район, поселок Гидроторф, Садовая, 16, ДК им.Димитрова	f	large
53597	60896	176	Нижегородская область, Балахнинский район, поселок Гидроторф, Административная, 14, филиал СОШ №10	f	large
53595	60894	174	Нижегородская область, Балахнинский район, поселок Гидроторф, Административная, 4, ЦДТ	f	large
53606	60905	185	Нижегородская область, Балахнинский район, село Большие Могильцы, библиотека	f	medium
53589	60889	168	Нижегородская область, Балахнинский район, город Балахна, проспект Дзержинского, 34, С/п СОШ №11	f	medium
53585	60885	164	Нижегородская область, Балахнинский район, Балахна, пр.Дзержинского, 2А, С/п СОШ №11	f	large
53582	60882	161	Нижегородская область, Балахнинский район, Балахна, Энгельса, 70, Городской КСК	f	large
53580	60880	159	Нижегородская область, Балахнинский район, Балахна, Энгельса, 39, отдел ГЗ и ПБ	f	large
53583	60883	162	Нижегородская область, Балахнинский район, Балахна, Синякова, 4, ФОК г.Балахна	f	large
53575	60876	154	Нижегородская область, Балахнинский район, Балахна, Свердлова, 24, МБУ Межшкольный учебн. комбинат	f	large
53593	60891	172	Нижегородская область, Балахнинский район, Балахна, Олимпийская, 2, ФОК Олимпийский	f	large
53591	60891	170	Нижегородская область, Балахнинский район, Балахна, Олимпийская, 2, ФОК Олимпийский	f	large
53577	60878	156	Нижегородская область, Балахнинский район, Балахна, Дзержинского, 21, Политехнический колледж	f	large
53590	60890	169	Нижегородская область, Балахнинский район, Балахна, Горького, 33, С/п ЦВР	f	large
53588	60888	167	Нижегородская область, Балахнинский район, Балахна, Горького, 13, СОШ №12	f	large
53576	60877	155	Нижегородская область, Балахнинский район, Балахна	f	large
53587	60887	166	Нижегородская область, Балахнинский район, Балахна, проезд Дзержинского, 36, Городской КСК	f	large
53586	60886	165	Нижегородская область, Балахнинский район, Балахна, пр.Дхержинского, 2А, С/п СОШ №11	f	large
53579	60879	158	Нижегородская область, Балахнинский район, Балахна, площадь Минина, 1, Дом Москвы	f	large
53578	60879	157	Нижегородская область, Балахнинский район, Балахна, площадь Минина, 1, Дом Москвы	f	large
68208	60881	160	Нижегородская область, Балахнинский район, Балахна, ЦКК, 33, МДОУ Детский сад № 27	f	large
53584	60884	163	Нижегородская область, Балахнинский район, Балахна, Первомайская, 1, помещение столовой	f	large
53611	60910	190	Нижегородская область, Балахнинский район, Балахна, Волжский рейд, 1, С/п ЦВР	f	large
53600	60899	179	Нижегородская область, Балахнинский район, поселок 1-е Мая, Садовая, 39, МУК ДК 1 Мая	f	large
86588	60793	53	Нижегородская область, Арзамасский район, село Шерстино, Советская, 96 А, Дом культуры	t	small
53527	60835	98	Нижегородская область, Арзамасский район, село Шатовка, Шатовская СОШ	f	large
111727	60832	96	Нижегородская область, Арзамасский район, село Чернуха	f	medium
68206	60830	94	Нижегородская область, Арзамасский район, село Чернуха	f	large
111726	60831	95	Нижегородская область, Арзамасский район, село Чернуха, Ленина, 61, здание администрации	f	medium
111725	60829	93	Нижегородская область, Арзамасский район, село Хватовка, Советская, 31, Дом культуры	f	medium
86660	60820	82	Нижегородская область, Арзамасский район, село Успенское 1-е	f	small
53521	60828	92	Нижегородская область, Арзамасский район, село Степаново, Центральная, 63	f	small
86664	60824	87	Нижегородская область, Арзамасский район, село Слизнево, Слизневская ООШ	f	small
53512	60819	81	Нижегородская область, Арзамасский район, село Слизнево, здание магазина	f	small
86666	60827	91	Нижегородская область, Арзамасский район, село Семеново, Центральная, 132, Дом культуры	f	small
86662	60822	85	Нижегородская область, Арзамасский район, село Селема	f	small
111723	60817	78	Нижегородская область, Арзамасский район, село Пустынь, Красная, 44 А, Дом культуры	f	medium
86659	60812	73	Нижегородская область, Арзамасский район, село Протопоповка, Новая, 3, Административное здание	t	small
86603	60834	97	Нижегородская область, Арзамасский район, село Пошатово, Фабричная, 5, сельский клуб	f	small
86661	60821	84	Нижегородская область, Арзамасский район, село Пешелань, Юбилейная, 24, Дом культуры	f	small
111722	60816	77	Нижегородская область, Арзамасский район, село Новый Усад	f	medium
86663	60823	86	Нижегородская область, Арзамасский район, село Никольское, Центральная, 64, Дом культуры	t	small
111724	60818	79	Нижегородская область, Арзамасский район, село Наумовка, ул.Молодежная, 19, Наумовская ООШ	f	medium
111721	60814	75	Нижегородская область, Арзамасский район, село Мотовилово, Лесная, 1, Административное здание	f	medium
111720	60811	72	Нижегородская область, Арзамасский район, село Морозовка, Советская, 2, ФАП	t	small
86586	60785	44	Нижегородская область, Арзамасский район, село Мерлино, Центральная, 58, сельский клуб	f	small
68203	60810	71	Нижегородская область, Арзамасский район, село Ломовка	f	large
53500	60807	68	Нижегородская область, Арзамасский район, село Лидовка, ФАП с.Лидовка	t	small
111717	60797	57	Нижегородская область, Арзамасский район, село Криуша, Центральная, 62, ФАП	t	small
68202	60808	69	Нижегородская область, Арзамасский район, село Красное	f	large
86587	60788	48	Нижегородская область, Арзамасский район, село Котиха, Кирова, 1 Б, сельский клуб	f	small
53499	60806	67	Нижегородская область, Арзамасский район, село Костылиха, ФАП 	t	small
53484	60791	51	Нижегородская область, Арзамасский район, село Кожино, ФАП с.Кожино	t	small
53498	60805	65	Нижегородская область, Арзамасский район, село Ковакса, здание Коваксинской СОШ	t	small
111719	60809	70	Нижегородская область, Арзамасский район, село Кичанзино, Новая линия, 23, Детский сад	f	medium
111716	60786	45	Нижегородская область, Арзамасский район, село Каменка, пл.Заводская, 14, Дом культуры	f	medium
86589	60804	64	Нижегородская область, Арзамасский район, село Казаково, Садовая, 17, Дом культуры	f	small
86601	60783	42	Нижегородская область, Арзамасский район, село Забелино, Большая площадь, 12А, сельский клуб	t	small
53494	60801	61	Нижегородская область, Арзамасский район, поселок Выездное	f	medium
53492	60799	59	Нижегородская область, Арзамасский район, поселок Выездное, детский сад № 34	f	large
53489	60796	56	Нижегородская область, Арзамасский район, поселок Выездное, ул. 5 линия, 14а	f	medium
68201	60802	62	Нижегородская область, Арзамасский район, поселок Выездное, Сельхозтехника, 20, ООШ Сельхозтехника	f	large
68200	60800	60	Нижегородская область, Арзамасский район, поселок Выездное, Куликова, 1, Выездновская СОШ	f	large
111718	60798	58	Нижегородская область, Арзамасский район, поселок Выездное, 7 Линия, 7, Вечерняя СОШ	f	medium
53508	60815	76	Нижегородская область, Арзамасский район, село Вторусское, ФАП с.Вторусское	t	small
53488	60795	55	Нижегородская область, Арзамасский район, село Волчиха, К.Маркса, 15	f	small
68199	60794	54	Нижегородская область, Арзамасский район, село Водоватово, площадь Кирова, 22	f	large
86665	60825	88	Нижегородская область, Арзамасский район, село Ветошкино, Центральная, 98, Дом культуры	f	small
86602	60784	43	Нижегородская область, Арзамасский район, село Веригино, К.Маркса, 15	f	small
53496	60803	63	Нижегородская область, Арзамасский район, село Васильев Враг, столовая СПК им.Чкалова	f	small
53519	60826	89	Нижегородская область, Арзамасский район, село Булдаково	f	small
68198	60792	52	Нижегородская область, Арзамасский район, село Большое Туманово	f	large
68197	60790	50	Нижегородская область, Арзамасский район, поселок Березовка, Школьная, 2, Дом культуры	f	large
53528	60836	99	Нижегородская область, Арзамасский район, село Беговатово, ФАП с.Беговатово	t	small
68196	60789	49	Нижегородская область, Арзамасский район, село Бебяево, 34 А, Дом культуры	f	large
53480	60787	46	Нижегородская область, Арзамасский район, село Балахониха, Советская, 27в, административное здание	f	medium
68205	60782	41	Нижегородская область, Арзамасский район, село Абрамово, пл.Победы, 6, Административное здание	f	large
86600	60781	33	Нижегородская область, Ардатовский район, село Чуварлей-Майдан, Советская, 39, здание сельской администрации	f	small
86599	60780	32	Нижегородская область, Ардатовский район, село Хрипуново, Центральная, 23, здание сельской администрации	f	small
86595	60774	26	Нижегородская область, Ардатовский район, село Туркуши	f	small
111715	60778	30	Нижегородская область, Ардатовский район, село Стексово, Садовая, 27А, дом культуры	f	medium
68204	60773	25	Нижегородская область, Ардатовский район, село Саконы	f	large
86583	60762	14	Нижегородская область, Ардатовский район, село Саконы	t	small
86594	60772	24	Нижегородская область, Ардатовский район, село Размазлей, Центральная, 7, здание Дома культуры	f	small
86581	60756	9	Нижегородская область, Ардатовский район, село Поляна, Школьная, 1/02, сельский клуб	f	small
86593	60771	23	Нижегородская область, Ардатовский район, село Надежино, Гусева, 33, здание Дома культуры	f	small
68195	60760	12	Нижегородская область, Ардатовский район, поселок Мухтолово	f	large
68194	60759	11	Нижегородская область, Ардатовский район, поселок Мухтолово, Школьная, 75А, школа №1	f	large
68193	60758	10	Нижегородская область, Ардатовский район, поселок Мухтолово, Почтовая, 25, МОУ ДОД Мухтоловская детская школа искусств	f	large
86592	60770	22	Нижегородская область, Ардатовский район, село Михеевка, Советская, 51, здание Дома культуры	f	small
111713	60769	21	Нижегородская область, Ардатовский район, село Личадеево, Центральная, 45А, дом культуры	f	medium
86591	60768	20	Нижегородская область, Ардатовский район, село Липовка, Центральная, 25А, сельский клуб	f	small
86580	60755	8	Нижегородская область, Ардатовский район, село Леметь, Новая, 1/1, бывшая школа	f	small
86597	60777	29	Нижегородская область, Ардатовский район, село Кузятово	t	small
111712	60766	18	Нижегородская область, Ардатовский район, село Кужендеево	f	medium
111714	60776	28	Нижегородская область, Ардатовский район, село Круглово, Школьная, 11, администрация ООО Металлург	f	medium
111711	60765	17	Нижегородская область, Ардатовский район, село Котовка	f	medium
86585	60764	16	Нижегородская область, Ардатовский район, село Каркалей, 1 Мая, 34Г, здание администрации с/с	f	small
86596	60775	27	Нижегородская область, Ардатовский район, село Идеал, Лесная, 1А, дом культуры	f	small
86584	60763	15	Нижегородская область, Ардатовский район, село Журелейка, Молодежная, 31, сельский дом культуры	f	small
86590	60767	19	Нижегородская область, Ардатовский район, село Голяткино, Школьная, 2, школа	f	small
86582	60761	13	Нижегородская область, Ардатовский район, поселок Венец, Северная, 13, школа	t	small
86598	60779	31	Нижегородская область, Ардатовский район, село Атемасово, Школьная, 2, школа	f	small
111710	60754	7	Нижегородская область, Ардатовский район, Ардатов, Суслова, 7, здание ЗАГСа	f	medium
68189	60748	1	Нижегородская область, Ардатовский район, Ардатов, Свердлова, 42, школа №1	f	large
111709	60752	5	Нижегородская область, Ардатовский район, Ардатов, Зуева, 70, ООО &quot;&quot;УК Ардатов&quot;&quot;&quot;	f	medium
111708	60750	3	Нижегородская область, Ардатовский район, село Ардатов, Зуева, 19, Детская школа искусств	f	medium
68191	60751	4	Нижегородская область, Ардатовский район, село Ардатов, 30 лет ВЛКСМ, 35, дом культуры	f	large
68190	60749	2	Нижегородская область, Ардатовский район, поселок Ардатов, Кооперативная, 41, здание бывшего лесхоза	f	large
68192	60753	6	Нижегородская область, Ардатовский район, поселок Ардатов, Зуева, 57, школа №2	f	large
55174	62212	1854	Нижегородская область, Павловский район, Павлово, Шмидта, 38	f	large
55168	62206	1848	Нижегородская область, Павловский район, Павлово, Чапаева, 41	f	large
55167	62206	1847	Нижегородская область, Павловский район, Павлово, Чапаева, 41	f	large
55164	62204	1844	Нижегородская область, Павловский район, Павлово, Суворова, 1	f	large
55166	62204	1846	Нижегородская область, Павловский район, Павлово, Суворова, 1	f	large
55181	62218	1861	Нижегородская область, Павловский район, Павлово, Высокая, 1	f	large
54094	61387	724	Нижегородская область, Городецкий район, Городец, Шишкина, 9, школа № 12	f	large
54096	61389	726	Нижегородская область, Городецкий район, Городец, Фурманова, 10а, Досуговый центр Спутник	f	large
54098	61391	728	Нижегородская область, Городецкий район, Городец, Краснофлотская, 12, школа №5	f	large
54097	61390	727	Нижегородская область, Городецкий район, Городец, Зафабричная, 6, Педагогический колледж	f	large
44662	42805	1309	Кировская область, Яранск, Свободы, 27А	f	large
44665	42808	1312	Кировская область, Яранск, Ленина, 52	f	medium
44463	42601	1086	Кировская область, Слободской, проспект Гагарина, 25	f	large
44462	42600	1085	Кировская область, Слободской, проспект Гагарина, 10	f	large
44450	42590	1073	Кировская область, Слободской, Школьная, 3	f	large
44453	42591	1076	Кировская область, Слободской, Советская, 69	f	large
44448	42588	1071	Кировская область, Слободской, Советская, 14	f	large
44465	42603	1088	Кировская область, Слободской, Слободская, 90	f	large
44464	42602	1087	Кировская область, Слободской, Слободская, 53	f	large
44449	42589	1072	Кировская область, Слободской, Первомайская, 1	f	large
44455	42593	1078	Кировская область, Слободской, Ленина, 69	f	large
44461	42599	1084	Кировская область, Слободской, Корто, 12	f	large
44460	42598	1083	Кировская область, Слободской, Кирова, 27	f	large
44456	42594	1079	Кировская область, Слободской, Железнодорожная, 11а	f	large
44458	42596	1081	Кировская область, Слободской, Грина, 43	f	large
44451	42495	1074	Кировская область, Слободской, Гоголя, 97	f	large
44452	42298	1075	Кировская область, Слободской, Вятская, 40	f	large
44457	42595	1080	Кировская область, Слободской, Ленина, 77	f	large
44009	42158	568	Кировская область, деревня Порошино, Сосновая, 11	f	medium
44328	42472	929	Кировская область, Орлов, В.Сокованова, 6	f	large
44252	42395	846	Кировская область, Омутнинск, Свободы, 35	f	large
44255	42398	849	Кировская область, Омутнинск, Садовая, 51	f	medium
44272	42415	866	Кировская область, Омутнинск, Пригородная, 11	f	small
44248	42378	842	Кировская область, Омутнинск, Комсомольская, 38	f	large
44249	42326	843	Кировская область, Омутнинск, Воровского, 13	f	large
44173	42314	756	Кировская область, Мураши, Пионерская, 5	f	large
44174	42315	757	Кировская область, Мураши, Кирова, 23	f	large
44170	42311	752	Кировская область, Малмыж, Октябрьская, 6	f	medium
44167	42308	749	Кировская область, Малмыж, Карла Маркса, 61	f	large
44133	42272	711	Кировская область, Луза, Рабочая, 21	f	large
44132	42271	710	Кировская область, Луза, Калинина, 9а	f	large
44067	42194	633	Кировская область, Котельнич, Школьная, 2	f	large
44060	42204	626	Кировская область, Котельнич, Урицкого, 19	f	large
44064	42208	630	Кировская область, Котельнич, Советская, 130	f	large
44059	42203	625	Кировская область, Котельнич, Советская, 46	f	large
44066	42124	632	Кировская область, Котельнич, Советская, 170	f	large
44065	42035	631	Кировская область, Котельнич, Советская, 153	f	large
44069	41966	635	Кировская область, Котельнич, Победы, 40	f	large
44063	42207	629	Кировская область, Котельнич, Октябрьская, 109	f	large
44061	42205	627	Кировская область, Котельнич, Октябрьская, 91	f	large
44071	42210	637	Кировская область, Котельнич, Мелиораторов, 2А	f	large
44068	41927	634	Кировская область, Котельнич, Заречная, 1А	f	medium
44070	42209	636	Кировская область, Котельнич, Дениса Белых, 12	f	large
66666	41850	216	Кировская область, Кирово-Чепецк, проспект Мира, 52	f	large
66667	41852	217	Кировская область, Слободской район, Кирово-Чепецк, Фестивальная, 14/2	f	large
44001	42151	560	Кировская область, Слободской район, Кирово-Чепецк, Революции, 20	f	large
44030	42176	589	Кировская область, Слободской район, Кирово-Чепецк, Островского, 6	f	\N
43675	41849	215	Кировская область, Слободской район, Кирово-Чепецк, Лермонтова проезд, 1	f	large
44026	42172	585	Кировская область, Слободской район, Кирово-Чепецк, Комсомольская, 6а	f	small
44019	42167	578	Кировская область, Кирово-Чепецк, Ком. Утробина, 5	f	large
44018	42167	577	Кировская область, Кирово-Чепецк, Ком. Утробина, 5	f	large
44016	42165	575	Кировская область, Кирово-Чепецк, А.Некрасова, 21	f	large
44020	42162	579	Кировская область, Кирово-Чепецк городской округ, Кирово-Чепецк, 60 лет Октября, 8А	f	large
44013	42162	572	Кировская область, Кирово-Чепецк городской округ, Кирово-Чепецк, 60 лет Октября, 8А	f	large
43906	42061	463	Кировская область, Киров, улица Физкультурников, 15	f	large
43905	42061	462	Кировская область, Киров, улица Физкультурников, 15	f	large
43496	41674	18	Кировская область, Киров, улица Солнечная, 5	f	large
43869	42030	426	Кировская область, Киров, Октябрьский район, улица Свердлова, 21	f	large
43868	42030	425	Кировская область, Киров, Октябрьский район, улица Свердлова, 21	f	large
43943	42091	502	Кировская область, Киров, Первомайский район, улица Розы Люксембург, 40	f	large
43765	41944	322	Кировская область, Киров, улица Риммы Юровской, 11	f	large
43941	42089	500	Кировская область, Киров, Первомайский район, улица Профсоюзная, 4	f	large
43853	42015	410	Кировская область, Киров, Нововятский район, улица Орджоникидзе, 13	f	large
43870	42028	427	Кировская область, Киров, улица Олега Кошевого, 14	f	large
43866	42028	423	Кировская область, Киров, улица Олега Кошевого, 14	f	large
43924	42075	481	Кировская область, Киров, улица Менделеева, 1	f	large
43918	42070	475	Кировская область, Киров, улица Ломоносова, 29б	f	large
43917	42070	474	Кировская область, Киров, улица Ломоносова, 29б	f	large
43999	42149	558	Кировская область, Киров, улица Лермонтова, 1	f	large
44010	42159	569	Кировская область, Киров, Первомайский район, улица Ленина, 6/6	f	large
43953	42101	512	Кировская область, Киров, улица Карла Маркса, 88/44	f	large
43798	41973	355	Кировская область, Киров, Ленинский район, улица Калинина, 53	f	large
43952	42100	511	Кировская область, Киров, улица Дрелевского, 12а	f	large
43764	41943	321	Кировская область, Киров, улица Дрелевского, 34/73	f	medium
43812	41981	369	Кировская область, Киров, слобода Петелины, 19	f	large
43833	41997	390	Кировская область, Киров, проспект Строителей, 21	f	large
43832	41997	389	Кировская область, Киров, проспект Строителей, 21	f	large
43762	41941	319	Кировская область, Киров, проспект Строителей, 44	f	large
43820	41989	377	Кировская область, Киров, площадь Маршала Конева	f	large
43862	42024	419	Кировская область, Киров, переулок Школьный, 3	f	large
43861	42023	418	Кировская область, Киров, Нововятский район, переулок Школьный, 4	f	large
43896	42053	453	Кировская область, Киров, Энгельса, 74	f	large
43964	42112	523	Кировская область, Киров, Школьная, 1	f	large
43889	42047	446	Кировская область, Киров, Шинников, 30А	f	large
43888	42047	445	Кировская область, Киров, Шинников, 30А	f	large
44361	42503	969	Кировская область, Киров, Центральная, 20	f	medium
43776	41954	333	Кировская область, Киров, Харьковская, 6	f	large
44008	42157	567	Кировская область, Киров, Фестивальная, 14/2	f	large
43880	42040	437	Кировская область, Киров, Уральская, 9/20	f	large
43879	42039	436	Кировская область, Киров, Уральская, 7	f	large
110983	42009	405	Кировская область, Киров, Трудовая, 19	f	medium
43946	42094	505	Кировская область, Киров, Труда, 57	f	large
43894	42051	451	Кировская область, Киров, Труда, 67а	f	large
43893	42051	450	Кировская область, Киров, Труда, 67а	f	large
43855	42017	412	Кировская область, Киров, Тренера Пушкарёва, 2	f	large
43803	41977	360	Кировская область, Киров, Сурикова, 44	f	large
43793	41968	350	Кировская область, Киров, Сурикова, 21	f	large
43909	42064	466	Кировская область, Киров, Студенческий проезд, 11А	f	large
43908	42063	465	Кировская область, Киров, Студенческий проезд, 11	f	large
43907	42062	464	Кировская область, Киров, Студенческий проезд, 9	f	large
43830	41995	387	Кировская область, Киров, Строителей проспек, 44	f	large
43829	41995	386	Кировская область, Киров, Строителей проспек, 44	f	large
44032	42166	591	Кировская область, Киров, Сосновая, 24/2	f	large
44017	42166	576	Кировская область, Киров, Сосновая, 24/2	f	medium
44012	42161	571	Кировская область, Киров, Сосновая, 20	f	large
44015	42164	574	Кировская область, Киров, Сосновая, 1	f	large
43912	42066	469	Кировская область, Киров, Сормовская, 38	f	large
43911	42066	468	Кировская область, Киров, Сормовская, 38	f	large
43826	41991	383	Кировская область, Киров, Солнечная, 21	f	large
43823	41991	380	Кировская область, Киров, Солнечная, 21	f	large
43852	42014	409	Кировская область, Киров, Нововятский район, Советская улица, 17	f	large
43859	42021	416	Кировская область, Киров, Советская, 170	f	large
44283	42427	881	Кировская область, Киров, Советская, 17	f	medium
44365	42507	973	Кировская область, Киров, Советская, 38	f	large
43847	42008	404	Кировская область, Киров, Советская, 15	f	large
43854	42016	411	Кировская область, Киров, Советская, 48	f	large
44118	42257	696	Кировская область, Киров, Советская, 3	f	small
43967	42115	526	Кировская область, Киров, Семашко, 2	f	large
43947	42095	506	Кировская область, Киров, Свободы, 25	f	large
43949	42097	508	Кировская область, Киров, Свободы, 47	f	large
43904	42060	461	Кировская область, Киров, Романа Ердякова, 24	f	large
43890	42048	447	Кировская область, Киров, Романа Ердякова, 23	f	large
43892	42050	449	Кировская область, Киров, Розы Люксембург, 87	f	large
43942	42090	501	Кировская область, Киров, Розы Люксембург, 66	f	large
43945	42093	504	Кировская область, Киров, Розы Люксембург, 3	f	large
44006	42155	565	Кировская область, Киров, Пушкина, 5	f	large
43851	42013	408	Кировская область, Киров, Пушкина, 27	f	large
43849	42011	406	Кировская область, Киров, Пушкина, 32	f	large
43808	41979	365	Кировская область, Киров, Пугачева, 18	f	large
43807	41979	364	Кировская область, Киров, Пугачева, 18	f	large
43797	41972	354	Кировская область, Киров, Пугачева, 8а	f	large
43902	42057	459	Кировская область, Киров, Профсоюзная, 69	f	large
43971	42119	530	Кировская область, Киров, Профсоюзная, 43	f	large
43959	42107	518	Кировская область, Киров, Пролетарская, 11А	f	large
43824	41992	381	Кировская область, Киров, Производственная, 20а	f	large
43856	42018	413	Кировская область, Киров, Проектная, 29	f	large
43813	41982	370	Кировская область, Киров, Потребкооперации, 2	f	small
43806	41931	363	Кировская область, Киров, Попова, 37	f	large
43752	41931	309	Кировская область, Киров, Попова, 37	f	large
44377	42517	985	Кировская область, Киров, Первомайская, 15	f	small
44277	42420	875	Кировская область, Киров, Первомайская, 3	f	large
44004	42154	563	Кировская область, Киров, Первомайская, 13	f	large
43965	42113	524	Кировская область, Киров, Павла Корчагина, 66	f	large
43954	42102	513	Кировская область, Киров, Орловская, 12	f	large
43850	42012	407	Кировская область, Киров, Опарина, 14	f	large
43901	42056	458	Кировская область, Киров, Октябрьский проспект, 36	f	large
43899	42055	456	Кировская область, Киров, Октябрьский проспект, 97	f	large
43900	42049	457	Кировская область, Киров, Октябрьский проспект, 38	f	large
43891	42049	448	Кировская область, Киров, Октябрьский проспект, 38	f	large
43886	42045	443	Кировская область, Киров, Октябрьский проспект, 67	f	large
43882	42042	439	Кировская область, Киров, Октябрьский проспект, 31	f	large
43881	42041	438	Кировская область, Киров, Октябрьский проспект, 21	f	large
43786	41962	343	Кировская область, Киров, Октябрьский проспект, 129	f	large
86921	41961	342	Кировская область, Киров, Октябрьский проспект, 133	f	large
43784	41960	341	Кировская область, Киров, Октябрьский проспект, 131	f	large
43771	41950	328	Кировская область, Киров, Октябрьский проспект, 104	f	large
43767	41946	324	Кировская область, Киров, Октябрьский проспект, 82	f	large
43858	42020	415	Кировская область, Киров, Октябрьская, 19	f	large
43857	42019	414	Кировская область, Киров, Октябрьская, 25	f	large
43805	41978	362	Кировская область, Киров, Некрасова, 38/25	f	large
43802	41976	359	Кировская область, Киров, Некрасова, 20	f	large
43804	41974	361	Кировская область, Киров, Некрасова, 57	f	large
43799	41974	356	Кировская область, Киров, Некрасова, 57	f	large
43951	42099	510	Кировская область, Киров, Московская улица, 1в	f	large
43950	42098	509	Кировская область, Киров, Московская, 35	f	large
43925	42076	482	Кировская область, Киров, Московская, 181	f	large
43903	42058	460	Кировская область, Киров, Московская, 103/2	f	large
43895	42052	452	Кировская область, Киров, Московская, 39	f	large
43818	41986	375	Кировская область, Киров, Московская, 156	f	large
43766	41945	323	Кировская область, Киров, Молодой Гвардии, 52	f	large
44376	42516	984	Кировская область, Киров, Молодежная, 1	f	small
43914	42067	471	Кировская область, Киров, Мира, 34	f	large
43913	42067	470	Кировская область, Киров, Мира, 34	f	large
44027	42173	586	Кировская область, Киров, Мира, 37	f	large
43773	41951	330	Кировская область, Киров, Милицейская, 67	f	large
43772	41951	329	Кировская область, Киров, Милицейская, 67	f	large
43960	42108	519	Кировская область, Киров, Милицейская, 50	f	large
44280	42424	878	Кировская область, Киров, Маршала Конева, 9	f	large
43825	41993	382	Кировская область, Киров, Маршала Конева, 13	f	large
43867	42029	424	Кировская область, Киров, Макаренко, 7	f	large
43875	42034	432	Кировская область, Киров, Луганская улица, 2	f	large
43916	42069	473	Кировская область, Киров, Ломоносова, 11	f	large
43962	42110	521	Кировская область, Киров, Лесозаводская улица, 18а	f	large
43910	42065	467	Кировская область, Киров, Лепсе, 31	f	large
43887	42046	444	Кировская область, Киров, Лепсе, 18	f	large
43874	42033	431	Кировская область, Киров, Ленинградская улица, 1	f	large
43873	42032	430	Кировская область, Киров, Ленинградская улица, 3	f	large
43940	42031	499	Кировская область, Киров, Ленинградская, 1	f	large
43872	42031	429	Кировская область, Киров, Ленинградская, 1	f	large
43871	42031	428	Кировская область, Киров, Ленинградская, 1	f	large
44281	42425	879	Кировская область, Киров, Ленина, 25	f	medium
43956	42104	515	Кировская область, Киров, Ленина, 105	f	large
44312	42455	911	Кировская область, Киров, Ленина, 33	f	medium
43944	42092	503	Кировская область, Киров, Ленина, 25	f	large
86923	42109	520	Кировская область, Киров, Ленина, 127а	f	large
43958	42106	517	Кировская область, Киров, Ленина, 111	f	large
43837	41999	394	Кировская область, Киров, Ленина, 16	f	large
43836	41999	393	Кировская область, Киров, Ленина, 16	f	large
43860	42022	417	Кировская область, Киров, Ленина, 14	f	large
44023	42169	582	Кировская область, Киров, Ленина, 26	f	medium
43845	42006	402	Кировская область, Киров, Ленина, 200	f	large
43782	41959	339	Кировская область, Киров, Ленина, 166а	f	large
43783	41958	340	Кировская область, Киров, Ленина, 158А	f	large
43781	41958	338	Кировская область, Киров, Ленина, 158А	f	large
43963	42111	522	Кировская область, Киров, Красный Химик, 2	f	large
43957	42105	516	Кировская область, Киров, Ленинский район, Красноармейская улица, 19	f	large
43810	41980	367	Кировская область, Киров, Красина, 49	f	large
43809	41980	366	Кировская область, Киров, Красина, 49	f	large
43811	41929	368	Кировская область, Киров, Красина, 41	f	large
43750	41929	307	Кировская область, Киров, Красина, 41	f	large
43974	42122	533	Кировская область, Киров, Космонавтов, 18А	f	medium
43827	41994	384	Кировская область, Киров, Космонавта Волкова, 6	f	large
43828	41994	385	Кировская область, Киров, Космонавта Волкова, 6	f	large
43774	41952	331	Кировская область, Киров, Комсомольская, 3	f	large
43801	41975	358	Кировская область, Киров, Комсомольская, 41А	f	large
43800	41975	357	Кировская область, Киров, Комсомольская, 41А	f	large
43835	41998	392	Кировская область, Киров, Комсомольская, 10	f	large
44476	42615	1103	Кировская область, Киров, Комсомольская, 22	f	medium
86958	41928	306	Кировская область, Киров, Комсомольская, 42	f	small
43921	42073	478	Кировская область, Киров, Кольцова, 18	f	large
43920	42072	477	Кировская область, Киров, Кольцова, 9	f	large
43919	42072	476	Кировская область, Киров, Кольцова, 9	f	large
43779	41957	336	Кировская область, Киров, Ключевая, 9	f	large
43966	42114	525	Кировская область, Киров, Клубная, 9	f	large
43769	41948	326	Кировская область, Киров, Карла Маркса, 115	f	large
43995	42145	554	Кировская область, Киров, Калинина, 32	f	large
44369	42511	977	Кировская область, Киров, Индустриальная, 19	f	medium
43864	42026	421	Кировская область, Киров, Индустриальная, 20	f	large
44285	42429	883	Кировская область, Киров, Заречная, 1	f	medium
43775	41953	332	Кировская область, Киров, Есенина, 9	f	large
86922	42037	434	Кировская область, Киров, Дзержинского, 23	f	large
43876	42036	433	Кировская область, Киров, Дзержинского, 25	f	large
43792	41967	349	Кировская область, Киров, Горького, 51а	f	large
43791	41967	348	Кировская область, Киров, Горького, 51а	f	large
43790	41965	347	Кировская область, Киров, Горького, 20	f	large
43898	42054	455	Кировская область, Киров, Горбуновой, 13	f	large
43897	42054	454	Кировская область, Киров, Горбуновой, 13	f	large
43885	42044	442	Кировская область, Киров, Гайдара, 5	f	large
43884	42043	441	Кировская область, Киров, Гайдара, 3	f	large
43883	42043	440	Кировская область, Киров, Гайдара, 3	f	large
43996	42146	555	Кировская область, Киров, Вятская Набережная, 5	f	large
44002	42152	561	Кировская область, Киров, Вятская, 5	f	large
43815	41984	372	Кировская область, Киров, Воровского, 84	f	large
43787	41963	344	Кировская область, Киров, Воровского, 79	f	large
43955	42103	514	Кировская область, Киров, Воровского, 16а	f	large
43796	41971	353	Кировская область, Киров, Воровского, 74а	f	large
43814	41983	371	Кировская область, Киров, Воровского, 121	f	large
43831	41996	388	Кировская область, Киров, Воровского, 108	f	large
43822	41990	379	Кировская область, Киров, Воровского, 86	f	large
43821	41987	378	Кировская область, Киров, Воровского, 153	f	large
43819	41987	376	Кировская область, Киров, Воровского, 153	f	large
43817	41985	374	Кировская область, Киров, Воровского, 133а	f	large
43816	41985	373	Кировская область, Киров, Воровского, 133а	f	large
43795	41970	352	Кировская область, Киров, Воровского, 78	f	large
43915	42068	472	Кировская область, Киров, Вологодская, 8	f	large
43972	42120	531	Кировская область, Киров, Боровицкая, 22	f	large
86924	42116	527	Кировская область, Киров, Боровая, 20	f	large
43948	42096	507	Кировская область, Киров, Большевиков, 43	f	large
43780	41956	337	Кировская область, Киров, Блюхера, 38	f	large
43778	41956	335	Кировская область, Киров, Блюхера, 38	f	large
43998	42148	557	Кировская область, Киров, Азина, 5	f	large
43770	41949	327	Кировская область, Киров, Азина, 55	f	large
43923	42074	480	Кировская область, Киров, А.Упита, 9	f	large
43922	42074	479	Кировская область, Киров, А.Упита, 9	f	large
43970	42118	529	Кировская область, Киров, 60-летия Комсомола, 17	f	large
43969	42117	528	Кировская область, Киров, 60-летия Комсомола, 4	f	large
43777	41955	334	Кировская область, Киров, 4-й Пятилетки, 40	f	large
44022	42168	581	Кировская область, Киров, Школьная, 4	f	large
44021	42168	580	Кировская область, Киров, Школьная, 4	f	large
44011	42160	570	Кировская область, Киров, Сосновая, 5	f	large
43878	42038	435	Кировская область, Киров, Подгорная, 18	f	large
43751	41930	308	Кировская область, Киров, Ленина, 198	f	large
43588	41765	114	Кировская область, Киров, Ленина, 32	f	small
44282	42426	880	Кировская область, Киров, улица Карла Маркса, 10	f	small
43834	41988	391	Кировская область, Киров, Дрелевского, 40	f	large
43789	41964	346	Кировская область, Киров, Горького, 37	f	large
43788	41964	345	Кировская область, Киров, Горького, 37	f	large
43794	41969	351	Кировская область, Киров, Воровского, 74	f	large
43843	42004	400	Кировская область, Киров, Ленинский район,  Аэропорт, 2А	f	small
43646	41822	185	Кировская область, Вятские Поляны, Шорина, 24 а	f	large
43641	41817	180	Кировская область, Вятские Поляны, Школьная, 55А	f	large
43647	41823	186	Кировская область, Вятские Поляны, Тойменка, 2	f	large
43652	41795	191	Кировская область, Вятские Поляны, Тойменка, 23	f	large
43637	41813	176	Кировская область, Вятские Поляны, Советская, 24	f	large
43651	41741	190	Кировская область, Вятские Поляны, Советская, 13	f	large
43639	41815	178	Кировская область, Вятские Поляны, Пароходная, 32	f	large
43648	41824	187	Кировская область, Вятские Поляны, Ленина, 244	f	large
43638	41814	177	Кировская область, Вятские Поляны, Ленина, 81	f	large
43642	41818	181	Кировская область, Вятские Поляны, Кукина, 14-48	f	large
43654	41828	193	Кировская область, Вятские Поляны, Кирова, 1	f	large
43650	41826	189	Кировская область, Вятские Поляны, Дзержинского, 55	f	large
43645	41821	184	Кировская область, Вятские Поляны, Гагарина, 30 а	f	large
43644	41820	183	Кировская область, Вятские Поляны, Гагарина, 17	f	large
43643	41819	182	Кировская область, Вятские Поляны, Гагарина, 7а	f	large
43640	41816	179	Кировская область, Вятские Поляны, Азина, 45	f	large
43649	41825	188	Кировская область, Вятские Поляны, Ленина, 323а	f	large
43528	41705	50	Кировская область, Белая Холуница, Здравоохранения, 1	f	large
44661	42804	1308	Кировская область, Яранский район, Яранск, Чапаева, 9А	f	large
44667	42810	1314	Кировская область, Яранский район, Яранск, Тургенева, 57	f	large
44670	42813	1317	Кировская область, Яранский район, Яранск, Северная, 15	f	small
44659	42802	1305	Кировская область, Яранский район, Яранск, Садовая, 1Б	f	large
44664	42807	1311	Кировская область, Яранский район, Яранск, Некрасова, 61	f	large
44660	42803	1307	Кировская область, Яранский район, Яранск, Мира, 17	f	large
44669	42812	1316	Кировская область, Яранский район, Яранск, Кирова, 65	f	large
44666	42809	1313	Кировская область, Яранский район, Яранск, Карла Маркса, 138	f	medium
44668	42811	1315	Кировская область, Яранский район, Яранск, Рудницкого, 50	f	large
44663	42806	1310	Кировская область, Яранский район, Яранск, Кирова, 28	f	large
44691	42832	1338	Кировская область, Яранский район, село Энгенер, Мира, 2	f	small
44694	42835	1341	Кировская область, Яранский район, село Шкаланка, Октябрьская, 2	f	small
44679	42820	1326	Кировская область, Яранский район, село Уртма, Набережная, 1	f	small
44692	42833	1339	Кировская область, Яранский район, село Сердеж, Школьная, 17	f	small
44689	42830	1336	Кировская область, Яранский район, село Салобеляк, Свободы, 21	f	medium
44684	42825	1331	Кировская область, Яранский район, село Савичи, Черепановская, 8А	f	small
44687	42828	1334	Кировская область, Яранский район, село Рождественск, Школьный переулок, 6	t	small
44688	42829	1335	Кировская область, Яранский район, село Пушкино, Школьная, 8	f	small
44683	42824	1330	Кировская область, Яранский район, село Пиштань, Советская, 73А	f	small
44681	42822	1328	Кировская область, Яранский район, село Первомайское, Центральная, 19А	f	small
44686	42827	1333	Кировская область, Яранский район, село Опытное Поле, Школьная, 6	f	medium
44685	42826	1332	Кировская область, Яранский район, село Никулята, Труда, 3	f	medium
44682	42823	1329	Кировская область, Яранский район, село Никола, Никольская, 11	f	small
44693	42834	1340	Кировская область, Яранский район, село Мари-Ушем, Центральная, 5	f	small
44674	42787	1321	Кировская область, Яранский район, село Лум, Мира, 36	f	small
44678	42819	1325	Кировская область, Яранский район, село Лом, Школьная, 1А	f	small
44680	42821	1327	Кировская область, Яранский район, село Кугушерга, Свободы, 15	f	small
44677	42818	1324	Кировская область, Яранский район, село Кугалки, Зелёная, 1	f	small
44695	42836	1342	Кировская область, Яранский район, село Каракша, Космодемьянская, 41	f	small
44672	42815	1319	Кировская область, Яранский район, село Иваново, 33	f	small
44676	42817	1323	Кировская область, Яранский район, село Знаменка, Колхозная, 27	f	medium
44675	42800	1322	Кировская область, Яранский район, село Знаменка, Кирова, 28	f	medium
44673	42816	1320	Кировская область, Яранский район, село Демино, Центральная, 46	f	small
44671	42814	1318	Кировская область, Яранский район, село Высоково, Лобова, 19	f	small
44690	42831	1337	Кировская область, Яранский район, село Верхоуслино, Полевая, 15А	f	small
44653	42795	1295	Кировская область, Юрьянский район, поселок Юрья, Энгельса, 19	f	large
44654	42796	1296	Кировская область, Юрьянский район, поселок Юрья, Ленина, 17, Центр культуры и досуга Космос	f	large
44655	42797	1297	Кировская область, Юрьянский район, поселок Юрья, Дачная, 12, спорткомплекс	f	large
44641	42782	1283	Кировская область, Юрьянский район, село Северный, Юбилейная, 2	f	small
44651	42793	1293	Кировская область, Юрьянский район, село Подгорцы, Кольцевая, 3а	f	small
44347	42488	950	Кировская область, Юрьянский район, поселок Первомайский, Волкова, 12	f	\N
44344	42488	947	Кировская область, Юрьянский район, поселок Первомайский, Волкова, 12	f	\N
44345	42488	948	Кировская область, Юрьянский район, поселок Первомайский, Волкова, 12	f	\N
44346	42488	949	Кировская область, Юрьянский район, поселок Первомайский, Волкова, 12	f	\N
44658	42801	1300	Кировская область, Юрьянский район, поселок Мурыгино, Набережная, 7	f	large
44656	42798	1298	Кировская область, Юрьянский район, поселок Мурыгино, Набережная, 7, Мурыгинский центр культуры и досуга	f	large
44657	42799	1299	Кировская область, Юрьянский район, поселок Мурыгино, Красных курсантов, 6	f	large
44646	42788	1288	Кировская область, Юрьянский район, село Монастырское, Тополиная, 18	f	small
44650	42792	1292	Кировская область, Юрьянский район, село Медяна, Советская, 9	f	medium
44647	42789	1289	Кировская область, Юрьянский район, село Ложкари, Исаковская, 31	f	small
44538	42678	1167	Кировская область, Юрьянский район, село Комарово, Школьная, 30	f	small
44643	42784	1285	Кировская область, Юрьянский район, село Кокино, Центральная, 11	f	small
44642	42783	1284	Кировская область, Юрьянский район, село Ивановщина, Колхозная, 2	f	small
44648	42790	1290	Кировская область, Юрьянский район, село Загарье, Советская, 30	f	medium
44649	42791	1291	Кировская область, Юрьянский район, село Гирсово, Заводская, 8	f	medium
44644	42785	1286	Кировская область, Юрьянский район, село Высоково, Советская, 28	f	small
44640	42781	1282	Кировская область, Юрьянский район, село Верходворье, Советская, 4	f	small
44645	42786	1287	Кировская область, Юрьянский район, село Верховино, Сычугова, 2	f	medium
44652	42794	1294	Кировская область, Юрьянский район, село Великорецкое, Центральная, 25	f	small
44639	42780	1281	Кировская область, Юрьянский район, село Великая, Комсомольская, 8-1	f	small
44638	42779	1274	Кировская область, Шабалинский район, село Черновское, Набережная, 4	f	medium
44226	42371	817	Кировская область, Шабалинский район, село Чащино, Первомайская, 16	f	medium
44637	42778	1273	Кировская область, Шабалинский район, село Соловецкое, Советская, 11	f	small
44634	42775	1270	Кировская область, Шабалинский район, село Содом, Мира, 1	f	\N
26924	7489	20	Хабаровский край, Хабаровск, улица Гагарина, 13	f	large
44627	42768	1262	Кировская область, Шабалинский район, село Семеновское, Победы, 18	f	small
44631	42772	1267	Кировская область, Шабалинский район, село Прокопьевское, 4	f	small
44635	42776	1271	Кировская область, Шабалинский район, село Новотроицкое, Кооперативная, 4	f	medium
44629	42770	1265	Кировская область, Шабалинский район, село Николаевское, Запрудная, 21	f	small
44626	42767	1261	Кировская область, Шабалинский район, село Луни, Центральная, 8Б	f	small
44623	42764	1258	Кировская область, Шабалинский район, поселок Ленинское, Фрунзе, 21б	f	large
44625	42766	1260	Кировская область, Шабалинский район, поселок Ленинское, Площадь Ленина, 2	f	medium
44622	42763	1257	Кировская область, Шабалинский район, поселок Ленинское, Площадь Ленина, 1	f	large
44624	42765	1259	Кировская область, Шабалинский район, поселок Ленинское, Гусарова, 14	f	large
44630	42771	1266	Кировская область, Шабалинский район, село Колосово	f	small
44628	42769	1264	Кировская область, Шабалинский район, поселок Гостовский, Школьная, 5	f	medium
44632	42773	1268	Кировская область, Шабалинский район, село Высокораменское, Свободы, 25	f	small
44633	42774	1269	Кировская область, Шабалинский район, село Высокогорье, Школьная, 6	t	small
44636	42777	1272	Кировская область, Шабалинский район, село Архангельское, Советская, 34	f	small
44617	42758	1251	Кировская область, Фаленский район, село Юсово	f	small
43993	42143	552	Кировская область, Фаленский район, село Чуваши, Советская, 4	f	medium
44616	42757	1250	Кировская область, Фаленский район, село Филейка, Коммуны, 38а	f	small
44621	42762	1256	Кировская область, Фаленский район, поселок Фаленки, Первомайская, 4	f	large
44618	42759	1253	Кировская область, Фаленский район, поселок Фаленки, Коммуны, 31	f	large
44619	42760	1254	Кировская область, Фаленский район, поселок Фаленки, Воробьева, 13	f	large
44620	42761	1255	Кировская область, Фаленский район, поселок Фаленки, Береговая, 1	f	medium
44615	42756	1249	Кировская область, Фаленский район, село Талица, Ленина, 23	f	medium
44614	42755	1248	Кировская область, Фаленский район, село Святица, Свердлова, 11	f	small
44613	42754	1247	Кировская область, Фаленский район, село Полом, Садовая, 2А	f	small
44612	42753	1246	Кировская область, Фаленский район, село Подоплеки, Советская, 2	f	small
44611	42752	1245	Кировская область, Фаленский район, село Петруненки, Труда, 24	f	small
44610	42751	1244	Кировская область, Фаленский район, село Паньшонки, Труда, 24	f	small
44606	42747	1239	Кировская область, Фаленский район, село Октябрьский, Садовая, 12А	f	medium
44609	42750	1243	Кировская область, Фаленский район, село Николаево, Юбилейная, 18	f	small
44197	42341	782	Кировская область, Фаленский район, село Николаево, Школьная, 2	f	small
44608	42749	1242	Кировская область, Фаленский район, село Низево, Школьная, 9	f	small
44607	42748	1240	Кировская область, Фаленский район, село Малахи, Баранниковская, 21	f	small
44605	42746	1238	Кировская область, Фаленский район, село Леваны, Школьная, 2А	f	medium
44604	42745	1236	Кировская область, Фаленский район, село Вогульцы, Юбилейная, 1	f	small
44603	42744	1235	Кировская область, Фаленский район, село Верхосунье, Пионерская, 20а	f	medium
44602	42743	1233	Кировская область, Фаленский район, село Белая, Школьная, 2	f	small
44599	42740	1228	Кировская область, Уржумский район, село Шурма, пер.Школьный, 1	f	medium
86957	42718	1207	Кировская область, Уржумский район, село Шурма, Пролетарская, 45	f	small
44597	42738	1226	Кировская область, Уржумский район, село Шевнино, Кирова, 28-а	f	small
44593	42734	1222	Кировская область, Уржумский район, село Цепочкино, Кирова, 34	f	small
44551	42692	1180	Кировская область, Уржумский район, Уржум, Новокузнечная, 90а	f	small
44557	42698	1186	Кировская область, Уржумский район, Уржум, Красная, 161	f	large
44556	42697	1185	Кировская область, Уржумский район, Уржум, Кировский тракт, 32	f	large
44553	42694	1182	Кировская область, Уржумский район, Уржум, Кирова, 69	f	large
44555	42696	1184	Кировская область, Уржумский район, Уржум, Дрелевского, 1	f	large
44554	42695	1183	Кировская область, Уржумский район, Уржум, Гоголя, 57	f	large
44552	42693	1181	Кировская область, Уржумский район, Уржум, Гоголя, 91	f	large
44574	42714	1203	Кировская область, Уржумский район, село Тюм-Тюм, Садовая, 17	f	small
44592	42733	1221	Кировская область, Уржумский район, село Толгозино, Комсомольская, 27	f	small
44594	42735	1223	Кировская область, Уржумский район, село Теребиловка, Советская, 16	f	small
44566	42707	1195	Кировская область, Уржумский район, село Танабаево, Молодежная, 2	f	small
44563	42704	1192	Кировская область, Уржумский район, село Старая Берсениха, Садовая, 20	f	small
86933	42739	1227	Кировская область, Уржумский район, село Собакино, Лесная, 1	f	small
44590	42731	1219	Кировская область, Уржумский район, село Савиново, Юбилейная, 7	f	small
44587	42728	1216	Кировская область, Уржумский район, село Русское Тимкино, 8 марта, 1	f	small
44588	42729	1217	Кировская область, Уржумский район, село Русский Турек, Пристанская, 1	f	large
44564	42705	1193	Кировская область, Уржумский район, село Русская Биляморь, Трудовая, 13	f	small
44585	42726	1214	Кировская область, Уржумский район, село Рождественское, Труда, 2	f	small
44583	42723	1212	Кировская область, Уржумский район, село Поповка, Молодежная, 2	f	small
66662	42725	1213	Кировская область, Уржумский район, село Пиляндыш, Советская, 35	f	small
44580	42720	1209	Кировская область, Уржумский район, село Петровское, Кирова, 63	f	small
44582	42722	1211	Кировская область, Уржумский район, село Орешник, Советская, 11	f	small
44278	42421	876	Кировская область, Уржумский район, село Опарино, Железнодорожная, 44	f	large
44579	42719	1208	Кировская область, Уржумский район, село Овсянниково, Школьная, 15	f	small
44573	42713	1202	Кировская область, Уржумский район, село Нижний Унур, Молодёжная, 38	f	small
44560	42701	1189	Кировская область, Уржумский район, село Мари-Шуэть, Центральная, 22	f	small
44567	42708	1196	Кировская область, Уржумский район, село Манкинерь, Центральная, 25	f	small
44601	42742	1230	Кировская область, Уржумский район, село Максинерь, Школьная, 23	f	small
86956	42607	1201	Кировская область, Уржумский район, село Лопъял, Школьная, 21	f	small
44577	42717	1206	Кировская область, Уржумский район, село Лебедевский, Кооперативная, 1	f	small
44571	42712	1200	Кировская область, Уржумский район, село Лазарево, Октябрьская,, 6	f	medium
44589	42730	1218	Кировская область, Уржумский район, село Кизерь, Новая	f	small
44559	42700	1188	Кировская область, Уржумский район, село Зоткино, Полевая, 4	f	small
44570	42711	1199	Кировская область, Уржумский район, село Ешпаево, Советская, 33-а	f	small
44596	42737	1225	Кировская область, Уржумский район, село Дюково, Трактовая, 2	f	small
44569	42710	1198	Кировская область, Уржумский район, поселок Донаурово, Лесная, 10	f	medium
44576	42716	1205	Кировская область, Уржумский район, село Витля, Зеленая, 28а	f	small
44581	42721	1210	Кировская область, Уржумский район, село Вершинята, Трудовая, 2-а	f	small
44600	42741	1229	Кировская область, Уржумский район, село Верхняя Шурма, Майская, 26	f	small
44568	42709	1197	Кировская область, Уржумский район, село Буйское, Кирова, 4	f	large
44565	42706	1194	Кировская область, Уржумский район, село Большой Рой, Трудовая, 5а	f	medium
44562	42703	1191	Кировская область, Уржумский район, село Богданово, Школьная, 1	f	small
44561	42702	1190	Кировская область, Уржумский район, село Байса, Школьная, 1	f	medium
44575	42715	1204	Кировская область, Уржумский район, село Ашлань, Почтовая, 13	f	small
44595	42736	1224	Кировская область, Уржумский район, село Антонково, Центральная, 1	f	small
44558	42699	1187	Кировская область, Уржумский район, поселок Андреевский, Молодежная, 20	f	medium
44591	42732	1220	Кировская область, Уржумский район, село Актыгашево, Садовая, 24	f	small
44586	42727	1215	Кировская область, Уржумский район, село Адово, Школьная, 17	f	small
44550	42691	1179	Кировская область, Унинский район, село Чуваши, Профсоюзная, 21	f	small
44549	42690	1178	Кировская область, Унинский район, село Уть, Советская, 32	f	small
44548	42689	1177	Кировская область, Унинский район, поселок Уни, Ленина, 21	f	large
44546	42687	1175	Кировская область, Унинский район, поселок Уни, Ленина, 24	f	large
44547	42688	1176	Кировская область, Унинский район, поселок Уни, Колхозная, 10	f	large
44545	42686	1174	Кировская область, Унинский район, поселок Уни, 40 лет Победы, 4	f	large
44544	42685	1173	Кировская область, Унинский район, село Удмуртский Сурвай, Школьный, 1	f	small
44543	42684	1172	Кировская область, Унинский район, село Сосновка, Советская, 49	f	small
44541	42681	1170	Кировская область, Унинский район, село Сардык, Кооперативная, 51А	f	small
44539	42679	1168	Кировская область, Унинский район, село Малый Полом, Центральная, 8	f	small
44537	42677	1166	Кировская область, Унинский район, село Князево, Новая, 12	f	small
44536	42676	1165	Кировская область, Унинский район, село Канахинцы, Административная, 4	f	small
44535	42675	1164	Кировская область, Унинский район, село Елгань, Центральная, 7	f	small
44534	42674	1163	Кировская область, Унинский район, село Верхолемье, Центральная, 13	f	small
44533	42673	1162	Кировская область, Унинский район, село Булатовцы, Молодёжная, 16	f	small
44532	42672	1161	Кировская область, Унинский район, село Барашки, Коммунальная, 1	f	small
44531	42671	1160	Кировская область, Унинский район, село Астрахань, Советская, 34	f	small
44528	42654	1157	Кировская область, Тужинский район, село Шешурга, Центральная, 4	f	small
86915	42669	1158	Кировская область, Тужинский район, поселок Тужа, Фокина, 18	f	large
44516	42657	1145	Кировская область, Тужинский район, поселок Тужа, Набережная, 5	f	large
44530	42670	1159	Кировская область, Тужинский район, поселок Тужа, Горького, 10	f	large
44527	42668	1156	Кировская область, Тужинский район, село Полушнур	t	small
44526	42667	1155	Кировская область, Тужинский район, село Покста, Покстинский сельский дом культуры	f	small
44525	42666	1154	Кировская область, Тужинский район, село Пиштенур, Центральная, 36	f	small
44524	42665	1153	Кировская область, Тужинский район, село Пачи, Центральная, 3	f	small
44523	42664	1152	Кировская область, Тужинский район, село Ныр, Советская, 13	f	small
44522	42663	1151	Кировская область, Тужинский район, село Михайловское, Центральная, 67	f	small
44520	42661	1149	Кировская область, Тужинский район, село Коврижата, Коврижатская сельская библиотека	f	small
44521	42662	1150	Кировская область, Тужинский район, село Караванное, Школьная, 1	f	small
44519	42660	1148	Кировская область, Тужинский район, село Греково, Школьная, 13	f	small
44518	42659	1147	Кировская область, Тужинский район, село Вынур	f	small
44517	42658	1146	Кировская область, Тужинский район, село Васькино, адм. здание Михайловского с/п	f	small
44515	42656	1144	Кировская область, Сунский район, поселок Суна, Советская, 31	f	medium
44501	42640	1130	Кировская область, Сунский район, поселок Суна, Дружбы, 22	f	large
44513	42653	1142	Кировская область, Сунский район, село Смыки, Школьная, 4	f	small
44512	42652	1141	Кировская область, Сунский район, село Плелое, Школьная, 7	f	small
44507	42647	1136	Кировская область, Сунский район, село Новый, Механизаторская, 2	f	small
44509	42649	1138	Кировская область, Сунский район, село Нестино, Советская, 17	f	small
44508	42648	1137	Кировская область, Сунский район, село Мурино, Советская, 36	f	small
66659	42646	1135	Кировская область, Сунский район, село Курчум, Школьная, 1	f	small
44505	42644	1134	Кировская область, Сунский район, село Краснополье, Школьная, 6 а	f	small
44504	42643	1133	Кировская область, Сунский район, село Кокуй, Космонавтов, 11	f	small
44511	42651	1140	Кировская область, Сунский район, село Дворища, Школьная, 22	f	small
44510	42650	1139	Кировская область, Сунский район, село Гребенки, Центральная, 7	f	small
44503	42642	1132	Кировская область, Сунский район, село Верхосунье, Лопатина, 2	f	small
44514	42655	1143	Кировская область, Сунский район, село Большие Туры, Молодёжная, 3 а	f	small
44502	42641	1131	Кировская область, Сунский район, село Большевик, переулок Центральный, 1	f	medium
44500	42639	1129	Кировская область, Советский район, село Шаваржаково, Молодежная, 9	f	small
44498	42637	1127	Кировская область, Советский район, село Фокино, Ветеранов, 31	f	small
44497	42636	1126	Кировская область, Советский район, село Суводь, Лесная, 1	f	small
44495	42634	1124	Кировская область, Советский район, Советск, Советская, 84	f	large
44494	42633	1122	Кировская область, Советский район, Советск, Олега Кошевого, 10	f	large
44496	42635	1125	Кировская область, Советский район, Советск, Мира, 26а	f	medium
44492	42631	1120	Кировская область, Советский район, Советск, Ленина, 50	f	large
44489	42628	1117	Кировская область, Советский район, Советск, Крупской, 26	f	large
44488	42627	1116	Кировская область, Советский район, Советск, Красноармейская, 47	f	large
25258	74202	982	Приморский край, Уссурийск, Полушкина, 75	f	large
44491	42630	1119	Кировская область, Советский район, Советск, Карла Маркса, 21	f	large
44493	42632	1121	Кировская область, Советский район, Советск, Карла Либкнехта, 21	f	large
44490	42629	1118	Кировская область, Советский район, Советск, Ленина, 24	f	large
44487	42626	1115	Кировская область, Советский район, село Ситемка, Центральная, 7	f	small
44486	42625	1114	Кировская область, Советский район, село Родыгино, Юбилейная, 5а	f	large
44485	42624	1113	Кировская область, Советский район, село Прозорово, Школьная, 8	f	small
44484	42623	1112	Кировская область, Советский район, село Новый, Фабричная, 16	f	small
44483	42622	1111	Кировская область, Советский район, село Муша, Советская, 9	f	small
44482	42621	1110	Кировская область, Советский район, село Мокино, Кирова,  11а, здание школы	f	small
44481	42620	1109	Кировская область, Советский район, село Лошкари, Советская, 7	f	small
44480	42619	1108	Кировская область, Советский район, село Лесниково, Советская, 36	f	small
44479	42618	1107	Кировская область, Советский район, село Колянур, Советская, 14	f	large
44478	42617	1106	Кировская область, Советский район, село Кожа, Советская, 8	f	small
44477	42616	1105	Кировская область, Советский район, село Кичма, Ленина, 1	f	medium
44474	42613	1101	Кировская область, Советский район, село Зашижемье, Молодежная, 21	f	small
44473	42612	1100	Кировская область, Советский район, село Дуброва, Школьная, 7, здание школы	f	small
43842	42003	399	Кировская область, Советский район, поселок Дороничи, Центральная, 2А	f	large
44472	42611	1099	Кировская область, Советский район, село Грехово, Красная, 35	f	medium
44471	42610	1098	Кировская область, Советский район, село Воробьева Гора, Школьная, 3	f	small
44470	42609	1097	Кировская область, Советский район, село Верхопижемье, Советская, 29	f	small
44469	42608	1096	Кировская область, Советский район, село Васичи, Ленина, 2	f	small
44468	42606	1095	Кировская область, Советский район, село Васильково, Краснооктябрьская, 7	f	small
44467	42605	1094	Кировская область, Советский район, село Борок, Набережная, 35	f	small
44499	42638	1128	Кировская область, Советский район, село Большая Челка, Советская, 15	f	small
44419	42559	1032	Кировская область, Слободской район, село Шихово, Солнечная, 1	f	medium
44443	42583	1056	Кировская область, Слободской район, село Шестаково, Советская, 25	f	medium
44442	42582	1055	Кировская область, Слободской район, село Шестаково, Советская, 25	f	medium
44446	42586	1059	Кировская область, Слободской район, село Центральный, Советская, 46	f	small
44445	42585	1058	Кировская область, Слободской район, село Центральный, Профсоюзная, 11	f	medium
44447	42587	1060	Кировская область, Слободской район, село Сухоборка, Советская, 31	f	small
44418	42558	1031	Кировская область, Слободской район, село Сунцовы, Набережная, 44	f	small
44431	42571	1044	Кировская область, Слободской район, село Стулово, Трактовая, 33А	f	large
44430	42570	1043	Кировская область, Слободской район, село Стулово, Трактовая, 43	f	large
44429	42569	1042	Кировская область, Слободской район, село Стулово, Трактовая, 42	f	large
44440	42580	1053	Кировская область, Слободской район, село Стеклофилины, Заводская, 8	f	small
44441	42581	1054	Кировская область, Слободской район, село Совье, Молодежная, 2	f	small
44437	42577	1050	Кировская область, Слободской район, село Светозарево, Молодежная, 1	f	medium
44432	42572	1045	Кировская область, Слободской район, село Салтыки, Молодежная, 9	f	medium
44436	42576	1049	Кировская область, Слободской район, село Роговое, Советская, 20	f	small
44434	42574	1047	Кировская область, Слободской район, село Октябрьский, Ленина, 20	f	medium
44417	42557	1030	Кировская область, Слободской район, село Митино, Санаторная, 2	f	small
44444	42584	1057	Кировская область, Слободской район, село Лекма, Профсоюзная, 12	f	small
44005	41851	564	Кировская область, Слободской район, Кирово-Чепецк, проспект Мира, 52	f	large
44014	42163	573	Кировская область, Слободской район, Кирово-Чепецк, проспект Кирова, 8	f	large
44000	42150	559	Кировская область, Слободской район, Кирово-Чепецк, проезд Лермонтова, 3А	f	large
44029	42175	588	Кировская область, Слободской район, Кирово-Чепецк, пр.Кирова, 1	f	large
44003	42153	562	Кировская область, Слободской район, Кирово-Чепецк, пр.Кирова, 27	f	large
44024	42170	583	Кировская область, Слободской район, Кирово-Чепецк, Мелиораторов, 1	f	large
44438	42578	1051	Кировская область, Слободской район, село Карино, К.Маркса, 14	f	medium
44433	42573	1046	Кировская область, Слободской район, село Ильинское, Набережная, 9	f	large
44420	42560	1033	Кировская область, Слободской район, село Зониха, Труда, 2	f	medium
44435	42575	1048	Кировская область, Слободской район, село Закаринье, Советская, 10	f	small
44439	42579	1052	Кировская область, Слободской район, село Денисовы, Советская, 7	f	medium
86932	42562	1035	Кировская область, Слободской район, село Волково, Верхняя, 27А	f	small
44424	42564	1037	Кировская область, Слободской район, поселок Вахруши, пер.Школьный, 2	f	large
44428	42568	1041	Кировская область, Слободской район, поселок Вахруши, Ленина, 1	f	large
44425	42565	1038	Кировская область, Слободской район, поселок Вахруши, Ленина, 9	f	large
44421	42561	1034	Кировская область, Слободской район, поселок Вахруши, Ленина, 78	f	medium
44426	42566	1039	Кировская область, Слободской район, поселок Вахруши, Горького, 1	f	large
44427	42567	1040	Кировская область, Слободской район, поселок Вахруши, Ленина, 4	f	large
44423	42563	1036	Кировская область, Слободской район, село Боровица, 37	t	small
44416	42556	1029	Кировская область, Слободской район, село Бобино, Советская, 6	f	small
44415	42555	1028	Кировская область, Слободской район, село Бобино, Мира, 18 А	f	medium
44407	42547	1020	Кировская область, Свечинский район, село Юма, Коммуны, 18	f	small
86931	42548	1021	Кировская область, Свечинский район, село Шмелево, Свободы, 25	f	small
44414	42554	1027	Кировская область, Свечинский район, село Успенское, Кооперативная, 3Б	f	medium
44401	42541	1014	Кировская область, Свечинский район, поселок Свеча, Свободы, 6	f	large
44402	42542	1015	Кировская область, Свечинский район, поселок Свеча, Привокзальная, 8	f	large
44403	42543	1016	Кировская область, Свечинский район, поселок Свеча, Мира, 12	f	small
44404	42544	1017	Кировская область, Свечинский район, село Самоулки, Труда, 1А	f	\N
44405	42545	1018	Кировская область, Свечинский район, село Рыбаковщина, Механизаторов, 16	f	small
44411	42551	1024	Кировская область, Свечинский район, село Рига, Советская, 1	f	medium
44410	42550	1023	Кировская область, Свечинский район, село Октябрьское, Советская, 32	f	small
44412	42552	1025	Кировская область, Свечинский район, село Круглыжи, Советская, 46	f	small
44406	42546	1019	Кировская область, Свечинский район, село Ивановское, Мира, 4	f	small
43929	42079	486	Кировская область, Свечинский район, поселок Ганино, Школьный переулок, 18	f	large
44413	42553	1026	Кировская область, Свечинский район, село Благовещенское, Центральная, 10	f	small
44409	42549	1022	Кировская область, Свечинский район, село Ацвеж, Калинина, 3	f	small
44395	42536	1008	Кировская область, Санчурский район, село Сметанино, Центральная, 124	f	small
44384	42524	996	Кировская область, Санчурский район, поселок Санчурск, Яранская, 3	f	medium
44383	42523	995	Кировская область, Санчурский район, поселок Санчурск, Свердлова, 69	f	medium
44382	42522	994	Кировская область, Санчурский район, поселок Санчурск, Ленина, 46	f	large
44381	42521	993	Кировская область, Санчурский район, поселок Санчурск, Зевахина, 2	f	large
44397	42538	1010	Кировская область, Санчурский район, село Мельниково, Центральная, 1	f	small
44393	42534	1006	Кировская область, Санчурский район, село Матвинур, Школьная, 2	f	medium
44388	42528	1000	Кировская область, Санчурский район, село Марийская Лиса, Заречная, 4	f	small
44391	42532	1004	Кировская область, Санчурский район, село Люмпанур, Школьная, 7	f	small
44394	42535	1007	Кировская область, Санчурский район, село Люй, Лесная , 24	f	small
44396	42537	1009	Кировская область, Санчурский район, село Кувшинское, Приозерная, 6	f	small
44389	42529	1001	Кировская область, Санчурский район, село Корляки, Дзржинского, 4	f	medium
44385	42525	997	Кировская область, Санчурский район, село Городище, Школьная, 13	f	medium
44387	42527	999	Кировская область, Санчурский район, село Галицкое, Свободы, 9а	f	small
44392	42533	1005	Кировская область, Санчурский район, село Вотчина, Советская, 3	f	small
44386	42526	998	Кировская область, Санчурский район, село Большой Ихтаил	f	small
44398	42539	1011	Кировская область, Санчурский район, село Большая Шишовка, 54	f	medium
44390	42530	1003	Кировская область, Санчурский район, село Большая Поломка, Речная, 1а	f	small
44399	42540	1012	Кировская область, Санчурский район, село Алексеиха, Школьная, 3	f	small
86929	42505	971	Кировская область, Подосиновский район, село Яхреньга, Мира, 39	f	small
44375	42515	983	Кировская область, Подосиновский район, село Щеткино, МОУ основная общеобразовательная школа	f	small
44373	42513	981	Кировская область, Подосиновский район, село Шолга, администрация поселения	f	small
44364	42506	972	Кировская область, Подосиновский район, село Ровдино, административное здание	f	small
44362	42504	970	Кировская область, Подосиновский район, село Ровдино, административное здание	f	small
44366	42508	974	Кировская область, Подосиновский район, поселок Подосиновец, улица Боровая, 6	f	large
44368	42510	976	Кировская область, Подосиновский район, поселок Пинюг, Индустриальная, 19	f	large
86930	42519	987	Кировская область, Подосиновский район, поселок Лунданка, Мира, 18	f	small
44374	42514	982	Кировская область, Подосиновский район, село Заречье, МОУ основная общеобразовательная школа	f	small
44372	42512	980	Кировская область, Подосиновский район, село Демьяново, Школьная, 5	f	small
44371	42512	979	Кировская область, Подосиновский район, село Демьяново, Школьная, 5	f	large
44370	42512	978	Кировская область, Подосиновский район, село Демьяново, Школьная, 5	f	large
44380	42520	988	Кировская область, Подосиновский район, поселок Верхнемалье, начальная школа-детский сад	f	small
44353	42494	958	Кировская область, Пижанский район, село Сретенское, Труда, 2	f	small
44358	42500	963	Кировская область, Пижанский район, село Русская Шуйма, Молодежная, 15	f	small
44349	42490	954	Кировская область, Пижанский район, поселок Пижанка, Труда, 27	f	large
44348	42489	953	Кировская область, Пижанский район, поселок Пижанка, Заречная, 45	f	large
44360	42502	965	Кировская область, Пижанский район, село Павлово, Октябрьская, 8	f	large
44359	42501	964	Кировская область, Пижанский район, село Обухово, Коммуны, 7	f	medium
44351	42492	956	Кировская область, Пижанский район, село Мари-Ошаево, Северная, 3	f	small
44350	42491	955	Кировская область, Пижанский район, село Малый Кашнур, Черемушки, 1	f	small
44354	42496	959	Кировская область, Пижанский район, село Ластик 2-й, Советская, 42 а	f	small
44356	42498	961	Кировская область, Пижанский район, село Казаково, Мира, 1	f	small
44355	42497	960	Кировская область, Пижанский район, село Воя, Школьная, 19	f	medium
44367	42509	975	Кировская область, Пижанский район, село Борок, Центральная, 50	f	small
44357	42499	962	Кировская область, Пижанский район, село Безводное, Школьная, 7	f	large
44352	42493	957	Кировская область, Пижанский район, село Ахманово, Советская, 5	f	small
44335	42479	936	Кировская область, Орловский район, село Шадричи, Мира, 14а	f	small
44343	42487	944	Кировская область, Орловский район, село Чудиново, Заречная, 12	f	small
44342	42486	943	Кировская область, Орловский район, село Цепели, Мира, 6	f	medium
44333	42477	934	Кировская область, Орловский район, село Тохтино, Кирова, 22	f	small
44338	42483	939	Кировская область, Орловский район, село Степановщина, Новая, 6б	f	small
44336	42481	937	Кировская область, Орловский район, село Солоницыны, Молодежная, 5	f	small
44339	42467	940	Кировская область, Орловский район, село Соловецкое, 58	f	small
44334	42478	935	Кировская область, Орловский район, село Русаново, Советская,, 25	f	small
44332	42476	933	Кировская область, Орловский район, село Поляки, Советская, 8	f	small
44329	42473	930	Кировская область, Орловский район, Орлов, Строителей, 20	f	large
44326	42470	927	Кировская область, Орловский район, Орлов, Ст.Халтурина, 36	f	large
44325	42469	926	Кировская область, Орловский район, Орлов, Ст.Халтурина, 2	f	large
44327	42471	928	Кировская область, Орловский район, Орлов, Ленина, 57	f	large
44330	42474	931	Кировская область, Орловский район, село Моржи, Мира, 1	f	small
44341	42485	942	Кировская область, Орловский район, село Кузнецы, Школьная, 10	f	medium
44340	42484	941	Кировская область, Орловский район, село Коробовщина	f	small
44337	42482	938	Кировская область, Орловский район, село Колково, Шубина, 1	f	small
44299	42442	898	Кировская область, Оричевский район, село Юбилейный, 32	f	medium
44308	42451	907	Кировская область, Оричевский район, село Шалегово, Труда, 1	f	small
44307	42450	906	Кировская область, Оричевский район, село Усовы, Советская, 18	f	small
44306	42449	905	Кировская область, Оричевский район, поселок Торфяной, Юбилейная, 17	f	large
44305	42448	904	Кировская область, Оричевский район, село Суводи, Ленина, 18	f	small
44323	42466	922	Кировская область, Оричевский район, поселок Стрижи, Рабочая, 37	f	medium
44324	42468	923	Кировская область, Оричевский район, поселок Стрижи, Комсомольская, 26	f	large
44322	42465	921	Кировская область, Оричевский район, поселок Стрижи, Кирова, 11а	f	medium
44304	42447	903	Кировская область, Оричевский район, село Спас-Талица, Советская, 12	f	small
44302	42445	901	Кировская область, Оричевский район, село Пустоши, Старосельская, 9	f	medium
44301	42444	900	Кировская область, Оричевский район, село Пищалье, Школьная, 6	f	small
44300	42443	899	Кировская область, Оричевский район, поселок Оричи, Якимовой, 18	f	small
44317	42460	916	Кировская область, Оричевский район, поселок Оричи, Юбилейная, 1а	f	large
44320	42463	919	Кировская область, Оричевский район, поселок Оричи, Молодая Гвардия, 32	f	medium
44319	42462	918	Кировская область, Оричевский район, поселок Оричи, Молодая Гвардия, 63	f	large
44316	42459	915	Кировская область, Оричевский район, поселок Оричи, Комсомольская, 57а	f	small
44315	42458	914	Кировская область, Оричевский район, поселок Оричи, Комсомольская, 3	f	medium
44318	42461	917	Кировская область, Оричевский район, поселок Оричи, Карла Маркса, 22	f	large
44321	42464	920	Кировская область, Оричевский район, поселок Оричи, 40 лет победы, 13	f	medium
44303	42446	902	Кировская область, Оричевский район, село Монастырщина, Советская, 18	f	small
44314	42457	913	Кировская область, Оричевский район, поселок Мирный, Степана Халтурина, 35	f	large
44313	42456	912	Кировская область, Оричевский район, поселок Мирный, Радченко, 23	f	large
44298	42441	897	Кировская область, Оричевский район, село Кучелапы, Советская, 22	f	medium
44297	42440	896	Кировская область, Оричевский район, село Коршик, Почтовая, 8	f	large
44293	42436	892	Кировская область, Оричевский район, село Колос, спальный корпус ООО Санаторий Колос	t	small
44296	42439	895	Кировская область, Оричевский район, село Истобенск, Степана Халтурина, 13	f	medium
44295	42438	894	Кировская область, Оричевский район, село Зенгино, Комсомольская, 6	f	medium
44475	42614	1102	Кировская область, Оричевский район, село Зеленый, 15	f	small
44309	42452	908	Кировская область, Оричевский район, село Зеленый, Советская, 6	f	small
44311	42454	910	Кировская область, Оричевский район, село Быстряги, Советская, 4	f	small
44294	42437	893	Кировская область, Оричевский район, село Быстрица, Моковская, 23	f	medium
44292	42423	891	Кировская область, Оричевский район, село Адышево, Советская, 11	f	medium
44291	42435	890	Кировская область, Опаринский район, село Стрельская, основная общеобразовательная школа	f	small
44290	42434	888	Кировская область, Опаринский район, поселок Северный	f	small
44289	42433	887	Кировская область, Опаринский район, поселок Опарино, основная общеобразовательная школа	f	small
44279	42422	877	Кировская область, Опаринский район, поселок Опарино, пер. Советский, 3	f	large
44288	42432	886	Кировская область, Опаринский район, село Нижняя Паломица, школа	f	small
44287	42431	885	Кировская область, Опаринский район, село Молома, Советская, администрация сельского поселения	f	small
44286	42430	884	Кировская область, Опаринский район, село Латышский, Центральная, 14	f	small
44284	42428	882	Кировская область, Опаринский район, село Верхняя Волманга, Школьная, 3	f	small
44276	42419	870	Кировская область, Омутнинский район, село Шахровка, Новая, 22	f	small
44271	42414	865	Кировская область, Омутнинский район, поселок Черная Холуница, Ленина, 7	f	large
44273	42416	867	Кировская область, Омутнинский район, село Плетневская, Центральная, 12	f	small
44263	42406	857	Кировская область, Омутнинский район, поселок Песковка, Шлаковая, 24	f	medium
44264	42407	858	Кировская область, Омутнинский район, поселок Песковка, Ленина, 79	f	medium
44266	42409	860	Кировская область, Омутнинский район, поселок Песковка, Ленина, 77	f	large
44267	42410	861	Кировская область, Омутнинский район, поселок Песковка, Школьная, 66	f	large
44244	42390	838	Кировская область, Омутнинский район, Омутнинск, Трудовых Резервов, 107	f	medium
44245	42391	839	Кировская область, Омутнинский район, Омутнинск, Северная, 81	f	large
44254	42397	848	Кировская область, Омутнинский район, Омутнинск, Пролетарская, 25	f	medium
44256	42399	850	Кировская область, Омутнинский район, Омутнинск, Кооперации, 91	f	large
44247	42339	841	Кировская область, Омутнинский район, Омутнинск, Комсомольская, 18	f	medium
44246	42392	840	Кировская область, Омутнинский район, Омутнинск, Коковихина, 99	f	large
44257	42400	851	Кировская область, Омутнинский район, Омутнинск, Западная, 12	f	large
44253	42396	847	Кировская область, Омутнинский район, Омутнинск, Воровского, 3	f	medium
44243	42389	837	Кировская область, Омутнинский район, Омутнинск, 9 Мая, 1	f	small
44251	42394	845	Кировская область, Омутнинский район, Омутнинск, 30 лет Победы, 22	f	large
44250	42393	844	Кировская область, Омутнинский район, Омутнинск, 30 лет Победы, 16	f	large
44262	42405	856	Кировская область, Омутнинский район, поселок Метрострой, Лесная, 16	f	small
44268	42411	862	Кировская область, Омутнинский район, поселок Лесные Поляны, Комсомольская, 14	f	large
44265	42408	859	Кировская область, Омутнинский район, село Котчиха, Комсомольская, 6	f	small
44269	42412	863	Кировская область, Омутнинский район, село Зимино, Школьная, 25	f	small
44274	42417	868	Кировская область, Омутнинский район, село Залазна, Октябрьская, 8	f	medium
44270	42413	864	Кировская область, Омутнинский район, село Ежово, Логовая, 18	f	small
44258	42401	852	Кировская область, Омутнинский район, поселок Восточный, Пионерская, 2	f	large
44259	42402	853	Кировская область, Омутнинский район, поселок Восточный, Азина, 11	f	large
44260	42403	854	Кировская область, Омутнинский район, поселок Восточный, 30 лет Победы, 4	f	large
44261	42404	855	Кировская область, Омутнинский район, поселок Белореченск, Русских, 16	f	large
44275	42418	869	Кировская область, Омутнинский район, поселок Белорецк, Ленина, 19	f	medium
44232	42377	824	Кировская область, Нолинский район, село Юртик, Школьный переулок, 1А	f	small
44239	42385	832	Кировская область, Нолинский район, село Швариха, Советская, 40	f	medium
44242	42388	835	Кировская область, Нолинский район, село Хмелевка, Луговая, 2	f	small
44238	42384	830	Кировская область, Нолинский район, село Татаурово, Большевиков, 17	f	medium
44234	42380	826	Кировская область, Нолинский район, село Рябиновщина, Строителей, 21	f	medium
44237	42383	829	Кировская область, Нолинский район, село Птицефабрика, Шварихинское шоссе, 1	f	small
44233	42379	825	Кировская область, Нолинский район, село Перевоз, Советская, 46а	f	medium
44224	42369	815	Кировская область, Нолинский район, Нолинск, Фрунзе, 51	f	large
44223	42368	814	Кировская область, Нолинский район, Нолинск, Спартака, 36	f	large
44222	42367	813	Кировская область, Нолинский район, Нолинск, Ленина, 11в	f	large
44231	42376	823	Кировская область, Нолинский район, поселок Медведок, Герцена, 76	f	large
44229	42374	820	Кировская область, Нолинский район, село Лудяна, Советская, 9	f	small
44227	42372	818	Кировская область, Нолинский район, село Кырчаны, Полевая, 7	f	medium
44228	42373	819	Кировская область, Нолинский район, поселок Карачи, Коммуны, 1	f	small
44230	42375	821	Кировская область, Нолинский район, село Верхоишеть, Школьная, 2	f	small
44236	42382	828	Кировская область, Нолинский район, село Варнаки, Зеленая, 61/2	f	small
44235	42381	827	Кировская область, Нолинский район, село Ботыли, Школьная, 1А	f	small
44225	42370	816	Кировская область, Нолинский район, поселок Аркуль, Заводская, 15	f	large
43863	42025	420	Кировская область, Нововятский район, мкр. Радужный, Конституции, 17	f	large
44221	42366	809	Кировская область, Немский район, село Соколово, Центральная, 7	f	small
44220	42365	808	Кировская область, Немский район, село Слудка, Школьная, 12	f	small
44219	42364	807	Кировская область, Немский район, поселок Нема, Советская, 42	f	large
44218	42363	806	Кировская область, Немский район, поселок Нема, Советская, 31	f	large
44217	42362	805	Кировская область, Немский район, поселок Нема, Набережная, 26	f	small
44216	42361	804	Кировская область, Немский район, село Марково	f	small
44215	42360	803	Кировская область, Немский район, село Колобово, переулок Советский, 1	f	small
44214	42359	802	Кировская область, Немский район, село Ильинское, Советская, 34	f	medium
44213	42358	801	Кировская область, Немский район, село Городище, переулок Центральный, 2	f	small
44212	42357	800	Кировская область, Немский район, село Васильевское, Школьная, 6	f	small
44211	42356	799	Кировская область, Немский район, село Архангельское, Молодежная, 44а	f	large
44199	42343	784	Кировская область, Нагорский район, село Шевырталово, Дом культуры	f	small
44210	42354	795	Кировская область, Нагорский район, село Синегорье, Октябрьская, 34	f	large
44209	42353	794	Кировская область, Нагорский район, село Первомайск	f	small
44206	42350	791	Кировская область, Нагорский район, село Орлецы	f	small
44201	42345	786	Кировская область, Нагорский район, село Назаровцы, Дом культуры	f	small
44195	42338	779	Кировская область, Нагорский район, поселок Нагорск, Советская, 169	f	medium
44194	42337	778	Кировская область, Нагорский район, поселок Нагорск, Советская, 183	f	large
44193	42336	777	Кировская область, Нагорский район, поселок Нагорск, Советская, 37	f	medium
44196	42340	780	Кировская область, Нагорский район, поселок Нагорск, Мехнизаторов, 2	f	small
44192	42334	776	Кировская область, Нагорский район, поселок Нагорск, Леушина, 21	f	large
44202	42346	787	Кировская область, Нагорский район, село Мулино, Советская, 14	f	small
66653	42347	788	Кировская область, Нагорский район, село Липовое	f	small
44207	42351	792	Кировская область, Нагорский район, село Липовка, Дом культуры	f	small
44208	42352	793	Кировская область, Нагорский район, село Крутой Лог, Советская, 2	f	small
44200	42344	785	Кировская область, Нагорский район, село Качонки, Библиотека	f	small
44198	42342	783	Кировская область, Нагорский район, село Заево, Дом культуры	f	small
44204	42348	789	Кировская область, Нагорский район, село Бажелка, Ленина, 28	f	small
44182	42323	765	Кировская область, Мурашинский район, село Тылай, Клуб - филиал	f	small
44183	42324	766	Кировская область, Мурашинский район, село Староверческая, Первомайская, 5	f	small
44186	42328	769	Кировская область, Мурашинский район, село Пермята	f	small
44187	42329	770	Кировская область, Мурашинский район, село Паломохино, МУК сельский Дом культуры с Паломохино	f	small
44179	42320	762	Кировская область, Мурашинский район, поселок Октябрьский, Футбольная, 2а	f	medium
44178	42319	761	Кировская область, Мурашинский район, поселок Октябрьский, Коммунистическая, 5	f	medium
44191	42333	774	Кировская область, Мурашинский район, Мураши	t	small
44189	42331	772	Кировская область, Мурашинский район, Мураши	f	small
44177	42318	760	Кировская область, Мурашинский район, Мураши, Халтурина, 51	f	large
44175	42316	758	Кировская область, Мурашинский район, Мураши, Пионерская, 37	f	large
44176	42317	759	Кировская область, Мурашинский район, Мураши, К.Маркса, 28	f	large
44184	42325	767	Кировская область, Мурашинский район, село Казаковщина, клуб-филиал	f	small
44190	42332	773	Кировская область, Мурашинский район, село Даниловка, МОКУ начальная общеобразовательная школа	f	small
44188	42330	771	Кировская область, Мурашинский район, село Верхораменье	f	small
44185	42327	768	Кировская область, Мурашинский район, село Боровица	f	small
44130	42269	708	Кировская область, Мурашинский район, село Боровица	f	small
44180	42321	763	Кировская область, Мурашинский район, село Безбожник, Почтовая, 38	f	large
44181	42322	764	Кировская область, Мурашинский район, село Безбожник, Первомайская, 9	f	large
44163	42304	745	Кировская область, Малмыжский район, село Тат-Верх-Гоньба, Мира, 36б	f	medium
44162	42303	744	Кировская область, Малмыжский район, село Старый Ирюк, Садовая, 2	f	medium
44149	42289	730	Кировская область, Малмыжский район, село Старый Буртек, Школьная, 3	f	small
44143	42283	721	Кировская область, Малмыжский район, село Старый Бурец, Центральная, 4а	f	small
44164	42305	746	Кировская область, Малмыжский район, село Старая Тушка, Набережная, 16	f	medium
44160	42301	742	Кировская область, Малмыжский район, село Савали, Октябрьская, 79	f	large
44158	42299	740	Кировская область, Малмыжский район, село Рожки, Молодежная	f	large
44157	42297	739	Кировская область, Малмыжский район, село Ральники, Школьная, 4а	f	small
44153	42293	735	Кировская область, Малмыжский район, село Преображенка, Шахтерская, 3	f	small
44156	42296	738	Кировская область, Малмыжский район, село Порез	f	small
44540	42680	1169	Кировская область, Малмыжский район, село Порез, Ленина, 24	f	small
25228	74175	952	Приморский край, Уссурийск, Пионерская, 92	f	large
44155	42295	737	Кировская область, Малмыжский район, село Плотбище, Советская, 27	f	medium
44148	42288	727	Кировская область, Малмыжский район, село Пахотная, Большая	f	medium
44154	42294	736	Кировская область, Малмыжский район, село Новый Смаиль, Школьная, 2	f	large
44144	42284	722	Кировская область, Малмыжский район, село Новый Кокуй, Школьная, 6	f	small
44161	42302	743	Кировская область, Малмыжский район, село Новый Ирюк, Центральная, 18	f	small
44151	42291	732	Кировская область, Малмыжский район, село Мелеть, Юбилейная, 4	f	small
44152	42292	734	Кировская область, Малмыжский район, село Мари-Малмыж, Школьная, 32	f	medium
44142	42281	720	Кировская область, Малмыжский район, село Малый Китяк, Центральная, 48	f	small
44166	42307	748	Кировская область, Малмыжский район, Малмыж, Чернышевского, 3	f	large
44169	42310	751	Кировская область, Малмыжский район, Малмыж, Тимирязева, 6	f	medium
44172	42313	754	Кировская область, Малмыжский район, Малмыж, Лесная, 7а	f	large
44171	42312	753	Кировская область, Малмыжский район, Малмыж, Комсомольская, 18	f	large
44168	42309	750	Кировская область, Малмыжский район, Малмыж, Карла Маркса, 7	f	medium
44150	42290	731	Кировская область, Малмыжский район, село Константиновка, переулок Школьный, 3	f	small
44165	42306	747	Кировская область, Малмыжский район, село Кинерь, Школьная, 15	f	small
44147	42287	725	Кировская область, Малмыжский район, село Калинино, Пролетарская, 92	f	large
44146	42286	724	Кировская область, Малмыжский район, село Калинино, Пролетарская, 57	f	large
44145	42285	723	Кировская область, Малмыжский район, село Каксинвай, Молодежная, 21	f	small
44159	42300	741	Кировская область, Малмыжский район, село Гоньба, пер.Мирный, 3а	f	small
44140	42279	718	Кировская область, Малмыжский район, село Большой Сатнур, Зеленая, 18	f	small
44141	42280	719	Кировская область, Малмыжский район, село Большой Китяк, Тишина, 11а	f	small
44139	42278	717	Кировская область, Малмыжский район, село Арык, Школьная, 6	f	medium
44138	42277	716	Кировская область, Малмыжский район, село Аджим, Советская, 15А	f	medium
66652	42211	693	Кировская область, Лузский район, село Христофорово	f	small
44131	42270	709	Кировская область, Лузский район, село Учка	f	small
44127	42266	705	Кировская область, Лузский район, село Уга	f	small
44116	42255	694	Кировская область, Лузский район, село Сирино	f	small
44129	42268	707	Кировская область, Лузский район, село Папулово	f	small
44120	42259	698	Кировская область, Лузский район, село Озерская, Озерная, 26	f	small
44137	42276	715	Кировская область, Лузский район, Луза, О.Кошевого, 13	f	medium
44135	42274	713	Кировская область, Лузский район, Луза, Маяковского, 52	f	large
44136	42275	714	Кировская область, Лузский район, Луза, Космодемьянской, 21а	f	medium
44134	42273	712	Кировская область, Лузский район, Луза, В. Козлова, 7	f	large
44123	42262	701	Кировская область, Лузский район, поселок Лальск	f	medium
44122	42261	700	Кировская область, Лузский район, поселок Лальск, Набережный переулок, 8	f	large
44124	42263	702	Кировская область, Лузский район, поселок Лальск, Клубная, 6	f	medium
44121	42260	699	Кировская область, Лузский район, село Каравайково	f	small
44117	42256	695	Кировская область, Лузский район, село Животово	f	small
44119	42258	697	Кировская область, Лузский район, село Ефаново	f	small
44125	42264	703	Кировская область, Лузский район, село Аксеновская	f	small
44126	42265	704	Кировская область, Лузский район, село Адреева Гора	f	small
44112	42252	690	Кировская область, Лебяжский район, село Синцово, Центральная, 5	f	\N
44105	42245	681	Кировская область, Лебяжский район, село Редькино, Центральная, 2А	f	\N
44111	42251	689	Кировская область, Лебяжский район, село Окунево, Советская, 1	f	\N
44110	42250	688	Кировская область, Лебяжский район, село Михеевщина, Производственная, 5	f	\N
44109	42249	687	Кировская область, Лебяжский район, село Мелянда, Молодежная, 5	f	\N
44096	42236	671	Кировская область, Лебяжский район, село Мари-Байса, 18	f	\N
44103	42243	679	Кировская область, Лебяжский район, село Малое Рын-Дудорово, Центральная, 8А	f	\N
44113	42253	691	Кировская область, Лебяжский район, поселок Лебяжье, Комсомольская, 4	f	\N
44108	42248	686	Кировская область, Лебяжский район, село Лаж, Советская, 31	f	\N
44106	42246	682	Кировская область, Лебяжский район, село Кузнецово, Мира, 32	f	\N
44104	42244	680	Кировская область, Лебяжский район, село Красное, Центральная, 43а	f	\N
44102	42242	678	Кировская область, Лебяжский район, село Кокорево, Северная, 14	f	\N
44101	42241	677	Кировская область, Лебяжский район, село Индыгойка, Полевая, 3	f	\N
44100	42240	676	Кировская область, Лебяжский район, село Изиморка, Центральная, 9б	f	\N
44241	42387	834	Кировская область, Лебяжский район, село Зыково, Октябрьская, 1	f	small
44099	42239	675	Кировская область, Лебяжский район, село Елькино, Новая, 4	f	\N
44098	42238	674	Кировская область, Лебяжский район, село Елизарово, Черёмушки, 15	f	\N
44097	42237	672	Кировская область, Лебяжский район, село Вотское, Тополиная, 2	f	\N
44095	42235	670	Кировская область, Лебяжский район, село Ветошкино, Свободы, 43	f	\N
44107	42247	683	Кировская область, Лебяжский район, село Васичи, 33	f	\N
44085	42225	659	Кировская область, Куменский район, село Рябиново, Молодёжная, 2А	f	small
44086	42226	660	Кировская область, Куменский район, село Речной, Ленина, 8	f	medium
44078	42218	652	Кировская область, Куменский район, село Плотники, Октябрьская, 18	f	small
44074	42214	648	Кировская область, Куменский район, село Парфеновщина, Мира, 2	f	small
44087	42227	661	Кировская область, Куменский район, село Олимпийский, Мира, 1	f	medium
44092	42232	666	Кировская область, Куменский район, поселок Нижнеивкино, Октябрьский, 7	f	medium
44093	42233	667	Кировская область, Куменский район, поселок Нижнеивкино, Курортная, 1	f	large
44091	42231	665	Кировская область, Куменский район, село Моряны, Труда, 2	f	small
44088	42228	662	Кировская область, Куменский район, поселок Кумены, Поселковая, 10	f	large
44090	42230	664	Кировская область, Куменский район, поселок Кумены, Гагарина, 49	f	large
44089	42229	663	Кировская область, Куменский район, поселок Кумены, Гагарина, 20	f	large
44081	42221	655	Кировская область, Куменский район, село Краснооктябрьский, Краснооктябрьская, 6а	f	large
44076	42216	650	Кировская область, Куменский район, село Желны, Новая, 22	f	small
44079	42219	653	Кировская область, Куменский район, село Вожгалы, Заречная, 9а	f	medium
44077	42217	651	Кировская область, Куменский район, село Вичевщина, Северихина, 33	f	large
44075	42215	649	Кировская область, Куменский район, село Верхобыстрица, Хохрякова, 23	f	small
44084	42224	658	Кировская область, Куменский район, село Быково, Советская, 13	f	small
44073	42213	647	Кировская область, Куменский район, село Большой Перелаз, Советская, 22	f	small
44072	42212	646	Кировская область, Куменский район, село Березник, Юбилейная, 8	f	small
44083	42223	657	Кировская область, Куменский район, село Березник, Центральный, 6	f	small
44082	42222	656	Кировская область, Куменский район, село Бельтюги, Клубная, 5	f	small
44094	42234	668	Кировская область, Куменский район, село Барановщина, Новая, 7	f	medium
44080	42220	654	Кировская область, Куменский район, село Ардашиха, Дружбы, 1	f	small
44055	42199	614	Кировская область, Котельничский район, село Юрьево	f	medium
44054	42198	613	Кировская область, Котельничский район, село Юбилейный	f	large
44053	42197	612	Кировская область, Котельничский район, село Шалеевщина	f	small
44052	42196	611	Кировская область, Котельничский район, село Чистополье	f	small
44051	42195	610	Кировская область, Котельничский район, село Сретенье	f	small
44050	42193	609	Кировская область, Котельничский район, село Спасское	f	small
44049	42192	608	Кировская область, Котельничский район, поселок Светлый	f	large
44042	42185	601	Кировская область, Котельничский район	f	small
44048	42191	607	Кировская область, Котельничский район, село Родичи	f	small
44047	42190	606	Кировская область, Котельничский район, село Покровское	f	medium
44045	42188	604	Кировская область, Котельничский район, село Молотниково	f	small
44044	42187	603	Кировская область, Котельничский район, село Макарье	f	large
44035	42178	594	Кировская область, Котельничский район, село Ленинская Искра	f	large
44034	42178	593	Кировская область, Котельничский район, село Ленинская Искра	f	large
44058	42202	617	Кировская область, Котельничский район, село Курино	f	\N
44043	42186	602	Кировская область, Котельничский район, село Красногорье	f	small
44040	42183	599	Кировская область, Котельничский район, село Комсомольский	f	medium
44057	42201	616	Кировская область, Котельничский район, село Козловаж	f	\N
44039	42182	598	Кировская область, Котельничский район, село Карпушино	f	medium
44041	42184	600	Кировская область, Котельничский район, село Караул	f	medium
44038	42181	597	Кировская область, Котельничский район, село Зайцевы	f	medium
44056	42200	615	Кировская область, Котельничский район, село Екатерина	f	\N
44037	42180	596	Кировская область, Котельничский район, поселок Ежиха	f	medium
44036	42179	595	Кировская область, Котельничский район, село Вишкиль	f	small
44046	42189	605	Кировская область, Котельничский район, село Боровка	f	medium
44033	42177	592	Кировская область, Котельничский район, село Александровское	f	small
43655	41829	195	Кировская область, Котельничский район, село Александровское, Кооперативная, 16	f	small
43844	42005	401	Кировская область, Кировский район, село Чистые Пруды, Советская, 2	f	large
43994	42144	553	Кировская область, Кирово-Чепецкий район, село Шутовщина, Октябрьская, 3	f	large
43992	42142	551	Кировская область, Кирово-Чепецкий район, село Филиппово, Заева, 41	f	large
43991	42141	550	Кировская область, Кирово-Чепецкий район, село Фатеево, Советская, 8	f	medium
44542	42683	1171	Кировская область, Кирово-Чепецкий район, село Сибирь, Школьная, 5	f	small
43989	42139	548	Кировская область, Кирово-Чепецкий район, село Селезениха, Новая, 10	f	medium
43988	42138	547	Кировская область, Кирово-Чепецкий район, село Просница, Большевиков, 8а	f	large
43987	42137	546	Кировская область, Кирово-Чепецкий район, село Пригородный, Комсомольская, 1а	f	medium
43986	42135	545	Кировская область, Кирово-Чепецкий район, село Полом, Петра Родыгина, 11	f	large
43985	42134	544	Кировская область, Кирово-Чепецкий район, село Пасегово, Школьная, 15	f	large
43984	42133	543	Кировская область, Кирово-Чепецкий район, село Марковцы, Березовая, 5	f	small
43982	42131	541	Кировская область, Кирово-Чепецкий район, село Малый Конып, Новая, 9 а	f	medium
43983	42132	542	Кировская область, Кирово-Чепецкий район, село Кстинино, Советская, 59	f	large
43981	42130	540	Кировская область, Кирово-Чепецкий район, поселок Ключи, Дружбы, 6	f	large
44025	42171	584	Кировская область, Кирово-Чепецкий район, поселок Каринторф, Лесная, 8А	f	large
43980	42129	539	Кировская область, Кирово-Чепецкий район, село Каринка, Школьная, 10	f	large
43979	42128	538	Кировская область, Кирово-Чепецкий район, село Дресвяново, Безымянная, 2А	t	small
43978	42127	537	Кировская область, Кирово-Чепецкий район, село Быстрицкий Туберкулезный Санаторий, диагностический корпус	t	small
43977	42126	536	Кировская область, Кирово-Чепецкий район, село Бурмакино, Школьная, 10	f	medium
43990	42140	549	Кировская область, Кирово-Чепецкий район, село Бумкомбинат	f	small
44031	42156	590	Кировская область, Кирово-Чепецк городской округ, Кирово-Чепецк, проспект Мира, 61/3	f	large
44007	42156	566	Кировская область, Кирово-Чепецк городской округ, Кирово-Чепецк, проспект Мира, 61/3	f	large
43926	42077	483	Кировская область, Киров городской округ, село Садаковский, Бамовский переулок, 1а	f	large
43932	42082	489	Кировская область, Киров городской округ, село Русское, Коммуны, 60	f	large
43973	42121	532	Кировская область, Киров городской округ, село Малая Субботиха, Центральная, 20	f	large
43840	42001	397	Кировская область, Киров городской округ, поселок Лянгасово, Молодежный проезд, 5	f	large
43839	42000	396	Кировская область, Киров городской округ, поселок Лянгасово, Комсомольская, 49	f	large
43838	42000	395	Кировская область, Киров городской округ, поселок Лянгасово, Комсомольская, 49	f	large
43928	42078	485	Кировская область, Киров городской округ, село Костино, Парковая, 17	f	large
43927	42078	484	Кировская область, Киров городской округ, село Костино, Парковая, 17	f	large
43841	42002	398	Кировская область, Киров городской округ, село Захарищевы, 5	f	medium
43930	42080	487	Кировская область, Киров городской округ, село Большая Гора	f	medium
43931	42081	488	Кировская область, Киров городской округ, село Бахта, Юбилейная, 4	f	large
43742	41920	292	Кировская область, Кильмезский район, село Четай, Советская, 2	f	small
43730	41908	280	Кировская область, Кильмезский район, село Чернушка, пер. Школьный, 14	f	medium
43733	41911	283	Кировская область, Кильмезский район, село Тат-Кильмезь, Школьная, 1	f	small
43747	41925	297	Кировская область, Кильмезский район, село Тат-Бояры, Лесная, 14	f	small
43734	41912	284	Кировская область, Кильмезский район, село Селино, Советская, 12	f	small
43731	41909	281	Кировская область, Кильмезский район, село Саринка, Школьная, 3	f	small
43745	41923	295	Кировская область, Кильмезский район, село Рыбная Ватага, Школьная, 1	f	small
43741	41919	291	Кировская область, Кильмезский район, село Паска, Советская, 2	f	small
43740	41918	290	Кировская область, Кильмезский район, село Осиновка, Школьная, 2	f	small
43737	41915	287	Кировская область, Кильмезский район, село Надежда, Верхняя, 97	f	small
43739	41917	289	Кировская область, Кильмезский район, село Моторки, Набережная, 69	f	small
43729	41907	279	Кировская область, Кильмезский район, село Малыши, Красиловская, 7	f	small
43735	41913	285	Кировская область, Кильмезский район, село Малая Кильмезь, Зеленая, 1	f	medium
43746	41924	296	Кировская область, Кильмезский район, село Кульма, Центральная, 50	f	small
43736	41914	286	Кировская область, Кильмезский район, поселок Кильмезь, Школьная, 7А	f	large
43724	41902	274	Кировская область, Кильмезский район, поселок Кильмезь, Скобелева, 37 А	f	medium
43743	41921	293	Кировская область, Кильмезский район, поселок Кильмезь, Больничная, 3	f	large
43727	41905	277	Кировская область, Кильмезский район, село Карманкино, Молодежная, 6	f	small
43748	41926	298	Кировская область, Кильмезский район, село Каменный Перебор, Школьная, 3а	f	small
43732	41910	282	Кировская область, Кильмезский район, село Зимник, Школьная, 1	f	small
44240	42386	833	Кировская область, Кильмезский район, село Еремино, Центральная, 20	f	small
43728	41906	278	Кировская область, Кильмезский район, село Дамаскино, Советская, 64	f	small
43726	41904	276	Кировская область, Кильмезский район, село Вихарево, Школьная, 1 А	f	small
43725	41903	275	Кировская область, Кильмезский район, село Бураши, Школьная, 2	f	small
43744	41922	294	Кировская область, Кильмезский район, село Большой Порек, пер. Школьный, 3	f	small
43738	41916	288	Кировская область, Кильмезский район, село Азиково, Заречная, 86	f	small
43715	41892	261	Кировская область, Кикнурский район, село Шапта, Советская, 1	f	medium
43712	41889	258	Кировская область, Кикнурский район, село Цекеево, Просвещения, 18	f	small
43713	41890	259	Кировская область, Кикнурский район, село Улеш, 43	f	small
43719	41897	266	Кировская область, Кикнурский район, село Тырышкино, Кооперативный переулок, 8	f	small
43723	41901	271	Кировская область, Кикнурский район, село Турусиново, Труда, 22	f	small
43718	41896	265	Кировская область, Кикнурский район, село Русские Краи, Молодежная, 16	f	small
43711	41888	257	Кировская область, Кикнурский район, село Потняк, Советская, 8	f	small
43717	41894	263	Кировская область, Кикнурский район, село Падерино, Полевая, 4	f	small
43721	41899	269	Кировская область, Кикнурский район, село Макарье, Труда, 29 а	f	small
43722	41900	270	Кировская область, Кикнурский район, село Кокшага, Кирова, 22	f	small
43709	41886	255	Кировская область, Кикнурский район, поселок Кикнур, Советская, 37	f	large
43707	41884	253	Кировская область, Кикнурский район, поселок Кикнур, Пушкина, 4	f	large
43708	41885	254	Кировская область, Кикнурский район, поселок Кикнур, Просвещения, 21	f	large
43720	41898	268	Кировская область, Кикнурский район, село Ваштранга, Новая, 2 а	f	small
43716	41893	262	Кировская область, Кикнурский район, село Березовка, Центральная, 3	f	small
43710	41887	256	Кировская область, Кикнурский район, село Беляево, Школьная, 3	f	small
43714	41891	260	Кировская область, Кикнурский район, село Абрамово, 54Б	f	small
43706	41883	252	Кировская область, Зуевский район, поселок Чепецкий, Железнодорожная, 17	f	medium
43705	41882	251	Кировская область, Зуевский район, село Суна, Коммунистическая, 10	f	medium
43703	41880	249	Кировская область, Зуевский район, село Старки, Кирова, 13	f	small
43701	41878	247	Кировская область, Зуевский район, село Соколовка, Центральная, 16	f	medium
43700	41877	245	Кировская область, Зуевский район, село Семушино, Ленина, 6	f	medium
43698	41875	242	Кировская область, Зуевский район, село Сезенево, Новая, 2а	f	small
43694	41871	238	Кировская область, Зуевский район, село Рябово, Кирова, 2	f	small
43695	41872	239	Кировская область, Зуевский район, село Октябрьский	f	medium
43704	41881	250	Кировская область, Зуевский район, село Мусихи, Торговая, 13	f	small
43692	41868	236	Кировская область, Зуевский район, село Лема, Школьная, 4	f	small
44310	42453	909	Кировская область, Зуевский район, село Левинцы, 70 Лет октября , 121	f	large
43687	41863	230	Кировская область, Зуевский район, поселок Косино, Свободы, 1	f	medium
43689	41865	232	Кировская область, Зуевский район, поселок Косино, Никулина, 14а	f	medium
43688	41864	231	Кировская область, Зуевский район, поселок Косино, Кирова, 21	f	medium
43702	41879	248	Кировская область, Зуевский район, село Коса, Советская, 8	f	small
43691	41867	234	Кировская область, Зуевский район, село Кордяга, Школьная, 10а	f	medium
43690	41866	233	Кировская область, Зуевский район, село Зуи, Молодежная, 1	f	small
43680	41856	220	Кировская область, Зуевский район, Зуевка, Южная, 16	f	medium
43679	41855	219	Кировская область, Зуевский район, Зуевка, Торговая, 10	f	large
43686	41862	229	Кировская область, Зуевский район, Зуевка, Свердлова, 24	f	large
43684	41860	226	Кировская область, Зуевский район, Зуевка, Свердлова, 132	f	large
43685	41861	227	Кировская область, Зуевский район, Зуевка, Пушкина, 4	f	large
43678	41854	218	Кировская область, Зуевский район, Зуевка, Куйбышева, 3	f	medium
43682	41858	223	Кировская область, Зуевский район, Зуевка, Исполкомовская, 109	f	large
43683	41859	224	Кировская область, Зуевский район, Зуевка, Восточная, 16А	f	large
43681	41857	222	Кировская область, Зуевский район, Зуевка, 1-я Советская, 16	f	medium
43696	41873	240	Кировская область, Зуевский район, село Городище, Полевая, 1	f	small
43697	41874	241	Кировская область, Зуевский район, село Большие Пасынки, Школьная, 1	f	small
43699	41876	244	Кировская область, Зуевский район, село Ардаши, Новая	f	small
43672	41846	212	Кировская область, Даровской район, село Хохловщина, Советская, 2Б	f	small
43673	41847	213	Кировская область, Даровской район, село Субарь, Школьная, 11	f	small
43671	41845	211	Кировская область, Даровской район, село Пиксур, Советская, 17	f	small
43670	41844	210	Кировская область, Даровской район, село Окатьево, Молодёжная, 21	f	small
43669	41843	209	Кировская область, Даровской район, село Кривецкая, Набережная, 1	f	small
43668	41842	208	Кировская область, Даровской район, село Красное, Труда, 1	f	medium
44205	42349	790	Кировская область, Даровской район, село Кобра, Строителей, 2	f	medium
43667	41840	207	Кировская область, Даровской район, село Кобра, Мира, 24	f	medium
43666	41839	206	Кировская область, Даровской район, село Ивановка, Набережная, 10	f	small
43665	41838	205	Кировская область, Даровской район, поселок Даровской, Советская, 2	f	medium
43661	41835	201	Кировская область, Даровской район, поселок Даровской, Советская, 42	f	large
86920	41848	214	Кировская область, Даровской район, поселок Даровской, Октябрьская, 19а	f	large
43664	41837	204	Кировская область, Даровской район, поселок Даровской, Кооперативная, 5	f	large
43663	41837	203	Кировская область, Даровской район, поселок Даровской, Кооперативная, 5	f	large
43662	41836	202	Кировская область, Даровской район, поселок Даровской, Зеленая, 27	f	medium
43659	41833	199	Кировская область, Даровской район, село Вонданка, Школьная, 5	f	small
43658	41832	198	Кировская область, Даровской район, село Верховонданка, Кооперативная, 3	f	small
43660	41834	200	Кировская область, Даровской район, село Бобровы, Набережная, 11	f	small
43657	41831	197	Кировская область, Даровской район, село Бобровы, Зеленая, 19	f	small
43656	41830	196	Кировская область, Даровской район, село Бечева, Центральная, 3	t	small
43634	41810	173	Кировская область, Вятскополянский район, село Ямышка, Молодежная, 19а	f	small
43635	41811	174	Кировская область, Вятскополянский район, село Чекашево, Школьная, 37а	f	medium
43633	41809	172	Кировская область, Вятскополянский район, село Усть-Люга, Октябрьская, 2а	f	medium
43629	41805	168	Кировская область, Вятскополянский район, село Старая Пинигерь, Школьная, 1б	f	small
43627	41803	166	Кировская область, Вятскополянский район, село Средняя Тойма, Центральная, 49б	f	small
43630	41806	169	Кировская область, Вятскополянский район, село Средние Шуни, Советская, 1	f	medium
43611	41785	150	Кировская область, Вятскополянский район, Сосновка, Спортивная, 14	f	large
43486	41664	6	Кировская область, Арбажский район, село Верхотулье, Свободы, 1	f	small
43609	41785	148	Кировская область, Вятскополянский район, Сосновка, Спортивная, 14	f	large
43607	41783	146	Кировская область, Вятскополянский район, Сосновка, Спортивная, 4а	f	large
43606	41783	145	Кировская область, Вятскополянский район, Сосновка, Спортивная, 4а	f	small
43605	41782	144	Кировская область, Вятскополянский район, Сосновка, Пролетарская, 64	f	large
43604	41781	143	Кировская область, Вятскополянский район, Сосновка, Куйбышева, 8	f	large
43608	41784	147	Кировская область, Вятскополянский район, Сосновка, Комсомольская, 1	f	large
43603	41780	142	Кировская область, Вятскополянский район, Сосновка, Дзержинского, 33	f	large
43610	41786	149	Кировская область, Вятскополянский район, Сосновка, Ворошилова, 21	f	medium
43632	41808	171	Кировская область, Вятскополянский район, село Сосмак, Кирова, 41/1	f	small
43624	41800	163	Кировская область, Вятскополянский район, село Слудка, Молодёжная, 8	f	medium
43626	41802	165	Кировская область, Вятскополянский район, село Новый Бурец, Центральная, 23	f	small
43628	41804	167	Кировская область, Вятскополянский район, село Нижняя Тойма, Центральная, 189	f	medium
43631	41807	170	Кировская область, Вятскополянский район, село Нижние Шуни, Центральная, 27/1	f	medium
43625	41801	164	Кировская область, Вятскополянский район, село Нижние Изиверки, Центральная, 16-1	f	small
43693	41870	237	Кировская область, Вятскополянский район, село Мухино, Советская, 14	f	large
43619	41794	158	Кировская область, Вятскополянский район, село Куршино, Большая, 23	f	small
43620	41796	159	Кировская область, Вятскополянский район, село Кулыги, Школьная, 2	f	medium
43612	41787	151	Кировская область, Вятскополянский район, поселок Красная Поляна, Сосновая, 26	f	small
43613	41788	152	Кировская область, Вятскополянский район, поселок Красная Поляна, Свободы, 3	f	medium
43614	41789	153	Кировская область, Вятскополянский район, поселок Красная Поляна, Молодежная, 2а	f	large
43617	41792	156	Кировская область, Вятскополянский район, поселок Красная Поляна, Дружбы, 33	f	large
43616	41791	155	Кировская область, Вятскополянский район, поселок Красная Поляна, Дружбы, 20	f	large
43615	41790	154	Кировская область, Вятскополянский район, поселок Красная Поляна, Дружбы, 17	f	medium
43621	41797	160	Кировская область, Вятскополянский район, село Казанка, Школьная, 4б	f	small
43636	41812	175	Кировская область, Вятскополянский район, село Ершовка, Молодежная, 5	f	medium
43622	41798	161	Кировская область, Вятскополянский район, село Дым-Дым-Омга, Новая, 1	f	medium
43618	41793	157	Кировская область, Вятскополянский район, село Гремячка, Центральная, 4	f	small
43623	41799	162	Кировская область, Вятскополянский район, село Виноградово, Новая, 10	f	small
86955	41779	141	Кировская область, Верхошижемский район, село Угор, Школьная, 3	f	small
86954	41778	140	Кировская область, Верхошижемский район, село Сырда, Школьный, 10	f	small
110982	41777	139	Кировская область, Верхошижемский район, село Среднеивкино, Школьная, 13	f	medium
86953	41776	138	Кировская область, Верхошижемский район, село Пунгино, Советская, 2	f	small
86952	41775	137	Кировская область, Верхошижемский район, село Мякиши, Школьная, 2	f	small
86951	41774	136	Кировская область, Верхошижемский район, село Косино, Школьная, 12	f	small
86950	41773	135	Кировская область, Верхошижемский район, село Калачиги, Школьная, 1	f	small
86949	41772	134	Кировская область, Верхошижемский район, село Зониха, Советская, 8	f	small
86948	41771	133	Кировская область, Верхошижемский район, село Воронье, Советская, 3	f	small
86918	41768	130	Кировская область, Верхошижемский район, поселок Верхошижемье, Школьная, 1	f	large
86919	41769	131	Кировская область, Верхошижемский район, поселок Верхошижемье, Пионерская, 8	f	large
86917	41767	129	Кировская область, Верхошижемский район, поселок Верхошижемье, Кирова, 32	f	large
86947	41770	132	Кировская область, Верхошижемский район, село Верхолипово, Попова, 12	f	small
43586	41763	112	Кировская область, Верхнекамский район, село Чус, Комсомольская, 12	f	small
43589	41766	115	Кировская область, Верхнекамский район, село Тупрунка, Школьная, 11	f	small
43576	41754	102	Кировская область, Верхнекамский район, поселок Созимский, Набережная, 9	f	medium
43577	41755	103	Кировская область, Верхнекамский район, поселок Созимский, Коммунальная, 1	f	medium
43571	41749	97	Кировская область, Верхнекамский район, поселок Светлополянск, Новая, 2	f	large
43572	41750	98	Кировская область, Верхнекамский район, поселок Светлополянск, Дзержинского, 11	f	large
43575	41753	101	Кировская область, Верхнекамский район, поселок Рудничный, Строительная, 1	f	large
43574	41752	100	Кировская область, Верхнекамский район, поселок Рудничный, Пушкина, 2	f	large
43573	41751	99	Кировская область, Верхнекамский район, поселок Рудничный, Пушкина, 4	f	large
43584	41761	110	Кировская область, Верхнекамский район, село Пушья, Новая, 2	f	small
43570	41748	96	Кировская область, Верхнекамский район, поселок Пещера, Нижняя, 1	f	small
43587	41764	113	Кировская область, Верхнекамский район, село Ожмегово, Октябрьская, 1	f	small
43582	41759	108	Кировская область, Верхнекамский район, село Лойно, Падерина, 69	f	medium
43583	41760	109	Кировская область, Верхнекамский район, село Лойно, Ленина, 20	f	medium
43580	41757	106	Кировская область, Верхнекамский район, поселок Лесной, Центральная, 3	f	small
43581	41758	107	Кировская область, Верхнекамский район, поселок Лесной, Мопра, 15	f	small
43579	41756	105	Кировская область, Верхнекамский район, поселок Лесной, Ленина, 18	f	large
43578	41756	104	Кировская область, Верхнекамский район, поселок Лесной, Ленина, 18	f	large
44128	42267	706	Кировская область, Верхнекамский район, село Куликово	f	small
43569	41747	95	Кировская область, Верхнекамский район, село Кочкино, Новая, 18	f	small
43566	41744	92	Кировская область, Верхнекамский район, Кирс, Набережная, 1	f	large
86916	41739	88	Кировская область, Верхнекамский район, Кирс, Ленина, 4	f	large
43565	41743	91	Кировская область, Верхнекамский район, Кирс, Кирова, 19	f	large
43564	41742	90	Кировская область, Верхнекамский район, Кирс, Кирова, 23	f	large
43563	41740	89	Кировская область, Верхнекамский район, Кирс, Кирова, 24	f	large
86946	41745	93	Кировская область, Верхнекамский район, Кирс, Индустриальная, 22	f	small
43585	41762	111	Кировская область, Верхнекамский район, село Кай, Дзержинского, 27	f	small
43568	41746	94	Кировская область, Верхнекамский район, село Барановка, Советская, 29	f	small
43561	41738	83	Кировская область, Богородский район, село Хороши, Молодежная, 1	f	small
43560	41737	82	Кировская область, Богородский район, село Ухтым, Кирова, 5	f	small
43559	41736	81	Кировская область, Богородский район, село Таранки, Мира, 12	f	small
43558	41735	80	Кировская область, Богородский район, село Спасское, Советская, 25	f	small
86945	41734	79	Кировская область, Богородский район, село Рождественское, Заречная, 3	f	small
43556	41733	78	Кировская область, Богородский район, село Ошлань, Новая, 10	f	small
43555	41732	77	Кировская область, Богородский район, село Караул, Советская, 17	f	small
86944	41731	76	Кировская область, Богородский район, село Верховойское, Юбилейная, 2	f	small
43550	41727	72	Кировская область, Богородский район, поселок Богородское, Советская, 2	f	medium
43553	41730	75	Кировская область, Богородский район, поселок Богородское, Коммуны, 9	f	medium
43552	41729	74	Кировская область, Богородский район, поселок Богородское, 1 Мая, 44	f	medium
43551	41728	73	Кировская область, Богородский район, поселок Богородское, 1 Мая, 11	f	medium
43542	41719	64	Кировская область, Белохолуницкий район, село Юдино, Советская, 3	f	small
43547	41724	69	Кировская область, Белохолуницкий район, село Троица, Набережная, 14	f	small
43539	41716	61	Кировская область, Белохолуницкий район, село Сырьяны, Советская, 40А	f	small
43541	41718	63	Кировская область, Белохолуницкий район, село Ракалово, Луговая, 5	f	small
43538	41715	60	Кировская область, Белохолуницкий район, село Прокопье, Новая, 13	f	small
43544	41721	66	Кировская область, Белохолуницкий район, село Полом, Энгельса, 49	f	medium
43549	41726	71	Кировская область, Белохолуницкий район, село Подрезчиха, Свободы, 10	f	medium
43546	41723	68	Кировская область, Белохолуницкий район, село Климковка, Кооперации, 5	f	medium
43548	41725	70	Кировская область, Белохолуницкий район, село Каменное, Школьная, 10	f	small
43543	41720	65	Кировская область, Белохолуницкий район, село Иванцево, Советская, 24	f	small
43545	41722	67	Кировская область, Белохолуницкий район, поселок Дубровка, Свободы, 2А	f	large
43537	41714	59	Кировская область, Белохолуницкий район, село Гуренки, Советская, 10	f	small
43540	41717	62	Кировская область, Белохолуницкий район, село Всехсвятское, Школьная, 14	f	small
43536	41713	58	Кировская область, Белохолуницкий район, село Быданово, Советская, 15	f	small
43525	41702	47	Кировская область, Белохолуницкий район, Белая Холуница, Школьная, 5А	f	large
43527	41704	49	Кировская область, Белохолуницкий район, Белая Холуница, Строителей, 7А	f	large
43530	41707	52	Кировская область, Белохолуницкий район, Белая Холуница, Смирнова, 20	f	large
43535	41712	57	Кировская область, Белохолуницкий район, Белая Холуница, Салтыкова, 15	f	small
43531	41708	53	Кировская область, Белохолуницкий район, Белая Холуница, Победы, 6	f	medium
43529	41706	51	Кировская область, Белохолуницкий район, Белая Холуница, Новая, 2А	f	small
43534	41711	56	Кировская область, Белохолуницкий район, Белая Холуница, Мелиораторов, 2	f	small
43533	41710	55	Кировская область, Белохолуницкий район, Белая Холуница, Западная, 20	f	medium
43526	41703	48	Кировская область, Белохолуницкий район, Белая Холуница, Бастракова, 61	f	medium
43532	41709	54	Кировская область, Белохолуницкий район, Белая Холуница, Советская, 49	f	large
43514	41691	36	Кировская область, Афанасьевский район, село Шердынята	f	small
43517	41694	39	Кировская область, Афанасьевский район, село Фроловская	f	small
86939	41692	37	Кировская область, Афанасьевский район, село Томызь, Школьная, 22	f	small
43502	41680	24	Кировская область, Афанасьевский район, село Сюзьва	f	small
43503	41681	25	Кировская область, Афанасьевский район, село Слобода	f	small
86943	41701	46	Кировская область, Афанасьевский район, село Савинцы, Центральная, 37	f	small
43521	41698	43	Кировская область, Афанасьевский район, село Ромаши	f	small
86942	41697	42	Кировская область, Афанасьевский район, село Пура, Школьная, 11	f	small
43518	41695	40	Кировская область, Афанасьевский район, село Пашино, Центральная, 16	f	small
43523	41628	45	Кировская область, Афанасьевский район, село Ожегино	f	small
86940	41693	38	Кировская область, Афанасьевский район, село Московская, Центральная, 24	f	small
43513	41690	35	Кировская область, Афанасьевский район, село Лытка, Советская, 2А	f	small
43509	41687	31	Кировская область, Афанасьевский район, село Кувакуш	f	small
86941	41696	41	Кировская область, Афанасьевский район, село Камский, Северная, 6	f	small
86938	41688	32	Кировская область, Афанасьевский район, село Илюши, 57	f	small
43512	41488	34	Кировская область, Афанасьевский район, село Жарковы	f	small
43508	41686	30	Кировская область, Афанасьевский район, село Ефремята	f	small
43511	41689	33	Кировская область, Афанасьевский район, село Езжа	f	small
110981	41685	29	Кировская область, Афанасьевский район, село Гордино, Мира, 34	f	medium
86935	41682	26	Кировская область, Афанасьевский район, село Георгиево, Труда, 8	f	small
43497	41675	19	Кировская область, Афанасьевский район, село Верхняя Тимофеевская	f	small
86937	41684	28	Кировская область, Афанасьевский район, село Верхнее Камье, Школьная, 6	f	small
86936	41683	27	Кировская область, Афанасьевский район, село Васенки, Новая, 13	f	small
43499	41677	21	Кировская область, Афанасьевский район, село Ванино	f	small
43501	41679	23	Кировская область, Афанасьевский район, село Бор, Гагарина, 2	f	medium
43500	41678	22	Кировская область, Афанасьевский район, село Бисерово, Советская, 33	f	medium
43498	41676	20	Кировская область, Афанасьевский район, село Афонята	f	small
43495	41673	17	Кировская область, Афанасьевский район, поселок Афанасьево, Красных Партизан, 3	f	large
43522	41699	44	Кировская область, Афанасьевский район, село Архипята	f	small
43494	41672	16	Кировская область, Арбажский район, село Шембеть, Первомайская, 1а	f	small
43493	41671	15	Кировская область, Арбажский район, село Шараница, Механизаторов, 5	f	small
43492	41670	13	Кировская область, Арбажский район, село Сорвижи, Советская, 28	f	medium
43491	41669	11	Кировская область, Арбажский район, село Пишнур, Советская, 58	f	small
43490	41668	10	Кировская область, Арбажский район, село Мосуны, Октябрьская, 13	f	small
43489	41667	9	Кировская область, Арбажский район, село Криуша, Труда, 6	f	small
86934	41666	8	Кировская область, Арбажский район, село Кормино, Советская, 26	f	small
43487	41665	7	Кировская область, Арбажский район, село Гулины, Молодежная, 5	f	small
43485	41663	5	Кировская область, Арбажский район, село Большой Кугунур, Школьная, 17	f	small
43484	41662	4	Кировская область, Арбажский район, село Басманы, Новая, 4	f	small
43483	41661	2	Кировская область, Арбажский район, поселок Арбаж, Советская, 36	f	large
43482	41660	1	Кировская область, Арбажский район, поселок Арбаж, Советская, 5	f	large
130796	13640	31	Чукотский автономный округ, городское поселение Эгвекинот, Гагарина, 5	f	small
130777	13615	8	Чукотский автономный округ, Угольные Копи, Советская, 24	f	\N
130776	13613	6	Чукотский автономный округ, Угольные Копи, Портовая, 10а	f	\N
85838	13657	47	Чукотский автономный округ, Певек, Пугачева, 54	f	large
85834	13632	23	Чукотский автономный округ, Билибино, Ленина, 2	f	large
85830	13611	4	Чукотский автономный округ, Анадырь, Строителей, 9	f	large
85829	13610	3	Чукотский автономный округ, Анадырь, Отке, 25	f	large
85828	13609	2	Чукотский автономный округ, Анадырь, Ленина, 23	f	large
130775	13612	5	Чукотский автономный округ, Анадырь, Колхозная, 21	f	small
85827	13608	1	Чукотский автономный округ, Анадырь, Мира, 6 а	f	large
130819	87908	57	Чукотский автономный округ, Чукотский район, село Лорино, Ленина, 3	f	medium
130818	13644	56	Чукотский автономный округ, Чукотский район, село Лаврентия, Советская, 15	f	medium
130810	13658	48	Чукотский автономный округ, Чаунский район, село Янранай, Заозерная, 5	f	small
85836	13655	45	Чукотский автономный округ, Чаунский район, Певек, Советская, 22	f	large
85837	13656	46	Чукотский автономный округ, Чаунский район, Певек, Полярная , 17	f	large
130804	13649	39	Чукотский автономный округ, Провиденский район, Провидения, МУ &quot;районный центр культуры&quot;	f	\N
130808	13653	43	Чукотский автономный округ, Провиденский район, поселок Нов. Чаплино, администрация	f	\N
85835	13639	30	Чукотский автономный округ, Иультинский район, городское поселение Эгвекинот, Советская, 11	f	large
130799	13643	34	Чукотский автономный округ, Иультинский район, село Амгуэма, Северная, 16	f	small
130795	13638	29	Чукотский автономный округ, Билибинский район, село Кепервеем, Кавракая, 8	f	small
85833	13631	22	Чукотский автономный округ, Билибинский район, Билибино, Ленина, 6	f	large
130790	13633	24	Чукотский автономный округ, Билибинский район, Билибино, Березина, 6	f	medium
85832	13630	21	Чукотский автономный округ, Билибинский район, Билибино, Арктика, 3	f	large
130787	13626	18	Чукотский автономный округ, Анадырский район	f	small
130786	13625	17	Чукотский автономный округ, Анадырский район, городское поселение Беринговский, Мандрикова, 12	f	medium
85831	13614	7	Чукотский автономный округ, Анадырский район, поселок Угольные Копи, Первомайская, 27	f	large
130778	13617	9	Чукотский автономный округ, Анадырский район, село Марково, Березина, 19	f	medium
130784	13623	15	Чукотский автономный округ, Анадырский район, Канчалан, Центральная, 33	f	small
27516	8462	613	Хабаровский край, п. Третий Сплавной, Речная, 14	t	small
27265	8694	361	Хабаровский край, Хабаровск, здание Аэропорта	f	small
27071	8047	167	Хабаровский край, Хабаровск, улица профессора Даниловского, 22	f	large
27070	8046	166	Хабаровский край, Хабаровск, улица профессора Даниловского, 24а	f	large
26968	7950	64	Хабаровский край, Хабаровск, улица Юности, 32	f	large
26911	4707	7	Хабаровский край, Хабаровск, улица Шмаковская, 8ка	f	large
27564	8510	661	Хабаровский край, Хабаровск, улица Школьная, 1	t	small
27561	8507	658	Хабаровский край, Хабаровск, улица Школьная, 16	t	medium
26908	7921	4	Хабаровский край, Хабаровск, улица Школьная, 17	f	large
26907	7920	3	Хабаровский край, Хабаровск, улица Школьная, 32	f	large
27112	8084	208	Хабаровский край, Хабаровск, улица Шеронова, 56	f	large
27059	8035	155	Хабаровский край, Хабаровск, улица Шелеста, 73в	f	large
27095	8069	191	Хабаровский край, Хабаровск, улица Шабадина, 14	f	large
27036	8014	132	Хабаровский край, Хабаровск, улица Чкалова, 17	f	large
26945	7940	41	Хабаровский край, Хабаровск, улица Чехова, 22	f	large
27004	7984	100	Хабаровский край, Хабаровск, улица Черняховского, 5	f	large
26993	7973	89	Хабаровский край, Хабаровск, улица Фурманова, 1	f	large
27046	8024	142	Хабаровский край, Хабаровск, улица Фрунзе, 119	f	large
27061	8037	157	Хабаровский край, Хабаровск, улица Фоломеева, 10	f	large
27035	8013	131	Хабаровский край, Хабаровск, улица Флегонтова, 8	f	large
26985	7966	81	Хабаровский край, Хабаровск, улица Ургальская, 8	f	large
27029	8007	125	Хабаровский край, Хабаровск, улица Ульяновская, 154	f	large
27075	8051	171	Хабаровский край, Хабаровск, улица Уборевича, 79	f	large
27074	8050	170	Хабаровский край, Хабаровск, улица Трехгорная, 43	f	large
27073	8049	169	Хабаровский край, Хабаровск, улица Трехгорная, 63	f	large
27072	8048	168	Хабаровский край, Хабаровск, улица Трехгорная, 80а	f	large
27069	8045	165	Хабаровский край, Хабаровск, улица Трехгорная, 74а	f	large
27080	8055	176	Хабаровский край, Хабаровск, улица Тихоокеанская, 218а	f	large
27079	8055	175	Хабаровский край, Хабаровск, улица Тихоокеанская, 218а	f	large
27078	8054	174	Хабаровский край, Хабаровск, улица Тихоокеанская, 186а	f	large
27068	8044	164	Хабаровский край, Хабаровск, улица Тихоокеанская, 175	f	large
27067	8043	163	Хабаровский край, Хабаровск, улица Тихоокеанская, 171	f	large
27066	8042	162	Хабаровский край, Хабаровск, улица Тихоокеанская, 169	f	large
27065	8041	161	Хабаровский край, Хабаровск, улица Тихоокеанская, 152	f	large
27064	8040	160	Хабаровский край, Хабаровск, улица Тихоокеанская, 136	f	large
27060	8036	156	Хабаровский край, Хабаровск, улица Тихоокеанская, 115	f	large
27042	8020	138	Хабаровский край, Хабаровск, улица Тихоокеанская, 17	f	large
27041	8019	137	Хабаровский край, Хабаровск, улица Тихоокеанская, 45	f	large
27037	8015	133	Хабаровский край, Хабаровск, улица Тихоокеанская, 58	f	large
27021	8000	117	Хабаровский край, Хабаровск, улица Ташкентская, 22	f	large
26987	7968	83	Хабаровский край, Хабаровск, улица Сурикова, 4ка	f	large
27002	7982	98	Хабаровский край, Хабаровск, улица Суворова, 55	f	large
27000	7980	96	Хабаровский край, Хабаровск, улица Суворова, 38	f	large
26999	7979	95	Хабаровский край, Хабаровск, улица Суворова, 40	f	large
27017	7996	113	Хабаровский край, Хабаровск, улица Строительная, 12	f	large
26994	7974	90	Хабаровский край, Хабаровск, улица Союзная, 1	f	large
27632	8580	731	Хабаровский край, Хабаровск, улица Советская, 19	f	medium
27054	8031	150	Хабаровский край, Хабаровск, улица Советская, 52	f	large
27044	8022	140	Хабаровский край, Хабаровск, улица Советская, 24	f	large
26960	7943	56	Хабаровский край, Хабаровск, улица Слободская, 12	f	large
26946	7757	42	Хабаровский край, Хабаровск, улица Сигнальная, 4	f	large
26950	5348	46	Хабаровский край, Хабаровск, улица Серышева, 47	f	large
27091	8066	187	Хабаровский край, Хабаровск, поселок Березовка, улица Сергеевская, 15	f	large
26933	7929	29	Хабаровский край, Хабаровск, улица Свердлова, 28	f	large
27076	8052	172	Хабаровский край, Хабаровск, улица Санаторная, 38	f	large
27085	8060	181	Хабаровский край, Хабаровск, улица Руднева, 68	f	large
27084	8059	180	Хабаровский край, Хабаровск, улица Руднева, 39	f	large
27009	7989	105	Хабаровский край, Хабаровск, улица Рокоссовского, 35	f	large
27008	7988	104	Хабаровский край, Хабаровск, улица Рокоссовского, 32	f	large
27006	7986	102	Хабаровский край, Хабаровск, улица Рокоссовского, 40	f	large
26966	7948	62	Хабаровский край, Хабаровск, улица Ремесленная, 8	f	large
27122	8094	218	Хабаровский край, Хабаровск, улица Пушкина, 60	f	large
26975	7957	71	Хабаровский край, Хабаровск, улица Путевая, 2	f	large
26974	7956	70	Хабаровский край, Хабаровск, улица Путевая, 10а	f	large
27113	8085	209	Хабаровский край, Хабаровск, улица Постышева, 13	f	large
27088	8063	184	Хабаровский край, Хабаровск, улица Портовая, 9	f	large
27563	8509	660	Хабаровский край, Хабаровск, улица Победы, 31	t	small
27022	8001	118	Хабаровский край, Хабаровск, улица Пассажирская, 1	f	large
27119	8091	215	Хабаровский край, Хабаровск, улица Панькова, 13	f	large
27011	7991	107	Хабаровский край, Хабаровск, улица Панфиловцев, 38	f	large
27010	7990	106	Хабаровский край, Хабаровск, улица Панфиловцев, 21А	f	large
26997	7977	93	Хабаровский край, Хабаровск, улица Панфиловцев, 16ка	f	large
27040	8018	136	Хабаровский край, Хабаровск, улица Орджоникидзе, 12	f	large
26906	7919	2	Хабаровский край, Хабаровск, улица Огородная, 1	f	large
27101	8074	197	Хабаровский край, Хабаровск, улица Мухина, 6	f	large
27117	8089	213	Хабаровский край, Хабаровск, улица Муравьева-Амурского, 33	f	large
27116	8088	212	Хабаровский край, Хабаровск, улица Муравьева-Амурского, 20	f	large
27115	8087	211	Хабаровский край, Хабаровск, улица Муравьева-Амурского, 4	f	large
27123	8095	219	Хабаровский край, Хабаровск, улица Московская, 10	f	large
27015	7995	111	Хабаровский край, Хабаровск, улица Монтажная, 40	f	medium
26938	7934	34	Хабаровский край, Хабаровск, улица Мирная, 16	f	large
27026	8004	122	Хабаровский край, Хабаровск, улица Мате Залки, 50	f	large
27012	7992	108	Хабаровский край, Хабаровск, улица Малиновского, 19	f	large
27083	8058	179	Хабаровский край, Хабаровск, улица Майская, 19а	f	large
27056	8032	152	Хабаровский край, Хабаровск, улица Льва Толстого, 29	f	large
27109	8082	205	Хабаровский край, Хабаровск, улица Лермонтова, 2	f	large
27096	8070	192	Хабаровский край, Хабаровск, улица Ленинградская, 21	f	large
26948	4892	44	Хабаровский край, Хабаровск, улица Ленинградская, 71	f	large
27107	8080	203	Хабаровский край, Хабаровск, улица Ленина, 6	f	large
27104	8077	200	Хабаровский край, Хабаровск, улица Ленина, 24	f	large
27103	8076	199	Хабаровский край, Хабаровск, улица Ленина, 39	f	large
27102	8075	198	Хабаровский край, Хабаровск, улица Ленина, 19	f	large
27100	8073	196	Хабаровский край, Хабаровск, улица Ленина, 58	f	large
27099	8072	195	Хабаровский край, Хабаровск, улица Ленина, 57	f	large
27097	8071	193	Хабаровский край, Хабаровск, улица Ленина, 73	f	large
26951	5490	47	Хабаровский край, Хабаровск, улица Лазо, 3	f	large
26977	6534	73	Хабаровский край, Хабаровск, улица Кубяка, 7	f	large
27086	8061	182	Хабаровский край, Хабаровск, улица Краснофлотская, 8	f	large
27297	8248	393	Хабаровский край, Хабаровск, улица Краснореченская, 96	f	large
27018	7997	114	Хабаровский край, Хабаровск, улица Краснореченская, 19	f	large
26996	7976	92	Хабаровский край, Хабаровск, улица Краснореченская, 45	f	large
26986	7967	82	Хабаровский край, Хабаровск, улица Краснореченская, 107	f	large
26982	7963	78	Хабаровский край, Хабаровск, улица Краснореченская, 145	f	large
26978	7959	74	Хабаровский край, Хабаровск, улица Краснореченская, 104	f	large
26976	7958	72	Хабаровский край, Хабаровск, улица Краснореченская, 112	f	large
134594	7931	31	Хабаровский край, Хабаровск, улица Краснодарская, 47	f	large
26934	7930	30	Хабаровский край, Хабаровск, улица Краснодарская, 51	f	large
27120	8092	216	Хабаровский край, Хабаровск, улица Красина, 7	f	large
26925	7593	21	Хабаровский край, Хабаровск, улица Костромская, 44	f	large
26969	7951	65	Хабаровский край, Хабаровск, улица Космическая, 7	f	large
26971	7953	67	Хабаровский край, Хабаровск, улица Королева, 3	f	large
26970	7952	66	Хабаровский край, Хабаровск, улица Королева, 4Б	f	large
134592	7922	5	Хабаровский край, Хабаровск, улица Клубная, 34	f	large
27106	8079	202	Хабаровский край, Хабаровск, улица Карла Маркса, 68	f	large
26940	7936	36	Хабаровский край, Хабаровск, улица Карла Маркса, 95	f	large
26939	7935	35	Хабаровский край, Хабаровск, улица Карла Маркса, 107	f	large
26932	7928	28	Хабаровский край, Хабаровск, улица Карла Маркса, 111	f	large
26931	7927	27	Хабаровский край, Хабаровск, улица Карла Маркса, 113	f	large
26930	7926	26	Хабаровский край, Хабаровск, улица Карла Маркса, 136	f	large
26929	7925	25	Хабаровский край, Хабаровск, улица Карла Маркса, 120	f	large
27047	8025	143	Хабаровский край, Хабаровск, улица Калинина, 117	f	large
27045	8023	141	Хабаровский край, Хабаровск, улица Калинина, 152	f	large
27089	8064	185	Хабаровский край, Хабаровск, улица Ильича, 35	f	large
27082	8057	178	Хабаровский край, Хабаровск, улица Зои Космодемьянской, 26	f	large
27043	8021	139	Хабаровский край, Хабаровск, улица Знаменщикова, 12	f	large
27457	8406	554	Хабаровский край, Хабаровск, улица Зеленая, 12	f	small
27051	8029	147	Хабаровский край, Хабаровск, улица Запарина, 114	f	large
27039	8017	135	Хабаровский край, Хабаровск, улица Забайкальская, 7	f	large
26919	6763	15	Хабаровский край, Хабаровск, улица Жуковского, 4	f	large
27105	8078	201	Хабаровский край, Хабаровск, улица Дзержинского, 3	f	large
26936	7932	32	Хабаровский край, Хабаровск, улица Данчука, 14	f	large
26918	6749	14	Хабаровский край, Хабаровск, улица Горького, 6	f	large
26998	7978	94	Хабаровский край, Хабаровск, улица Герцена, 12	f	large
26995	7975	91	Хабаровский край, Хабаровск, улица Герцена, 2	f	large
26926	7704	22	Хабаровский край, Хабаровск, улица Гагарина, 1ж	f	medium
26923	7444	19	Хабаровский край, Хабаровск, улица Гагарина, 2кг	f	large
26954	5739	50	Хабаровский край, Хабаровск, улица Вяземская, 7а	f	large
27003	7983	99	Хабаровский край, Хабаровск, улица Ворошилова, 36	f	large
27001	7981	97	Хабаровский край, Хабаровск, улица Ворошилова, 42	f	large
26992	7972	88	Хабаровский край, Хабаровск, улица Ворошилова, 53	f	large
26956	6217	52	Хабаровский край, Хабаровск, улица Воронежская, 129	f	large
26955	6051	51	Хабаровский край, Хабаровск, улица Воронежская, 77	f	large
26922	7339	18	Хабаровский край, Хабаровск, улица Воровского, 24А	f	large
26921	7235	17	Хабаровский край, Хабаровск, улица Воровского, 24б	f	large
26920	7108	16	Хабаровский край, Хабаровск, улица Воровского, 12	f	large
26967	7949	63	Хабаровский край, Хабаровск, улица Волочаевская, 1	f	large
26964	7946	60	Хабаровский край, Хабаровск, улица Волочаевская, 6	f	large
26963	7945	59	Хабаровский край, Хабаровск, улица Волочаевская, 30	f	large
26959	7942	55	Хабаровский край, Хабаровск, улица Волочаевская, 83	f	large
27005	7985	101	Хабаровский край, Хабаровск, улица Вологодская, 24	f	large
27038	8016	134	Хабаровский край, Хабаровск, улица Брестская, 51	f	medium
26943	7938	39	Хабаровский край, Хабаровск, улица Большая, 85	f	large
26941	7937	37	Хабаровский край, Хабаровск, улица Большая, 30	f	large
26952	5662	48	Хабаровский край, Хабаровск, улица Больничная, 2ж	f	large
27062	8038	158	Хабаровский край, Хабаровск, улица Бойко-Павлова, 20	f	large
27092	8067	188	Хабаровский край, Хабаровск, поселок Березовка, улица Богородская, 6	f	large
27030	8008	126	Хабаровский край, Хабаровск, улица Балашовская, 13	f	large
26990	7970	86	Хабаровский край, Хабаровск, улица Аксенова, 55	f	large
26989	7969	85	Хабаровский край, Хабаровск, улица Аксенова, 30А	f	large
27025	8003	121	Хабаровский край, Хабаровск, улица Автобусная, 10А	f	large
27087	8062	183	Хабаровский край, Хабаровск, улица Авроры, 12	f	large
27254	8690	350	Хабаровский край, Хабаровск, станция Хабаровск-1, Желездонодорожный вокзал	f	small
26928	7924	24	Хабаровский край, Хабаровск, проспект 60-летия Октября, 212	f	large
27110	8083	206	Хабаровский край, Хабаровск, пер. Облачный, 3	f	large
26914	6656	10	Хабаровский край, Хабаровск, кв.ДОС (Большой Аэродром), 42а	f	large
134593	6559	8	Хабаровский край, Хабаровск, кв.ДОС (Большой Аэродром), 1А	f	large
27090	8065	186	Хабаровский край, Хабаровск, кв-л Энергетик, 11	f	large
27422	8371	518	Хабаровский край, Хабаровск, кв-л 70Лет Октября, 7	f	\N
26913	6642	9	Хабаровский край, Хабаровск, Шкотова, 14	f	large
26973	7955	69	Хабаровский край, Хабаровск, Шимановского, 2А	f	large
26944	7939	40	Хабаровский край, Хабаровск, Чехова, 1а	f	large
26983	7964	79	Хабаровский край, Хабаровск, Центральная, 15	f	large
26981	7962	77	Хабаровский край, Хабаровск, Флегонтова, 2а	f	large
27032	8010	128	Хабаровский край, Хабаровск, Фабричный переулок, 23А	f	large
26965	7947	61	Хабаровский край, Хабаровск, Трубный переулок, 7	f	large
27033	8011	129	Хабаровский край, Хабаровск, Слободская, 27	f	large
26949	5300	45	Хабаровский край, Хабаровск, Серышева, 53	f	large
27007	7987	103	Хабаровский край, Хабаровск, Рокоссовского, 32А	f	large
26972	7954	68	Хабаровский край, Хабаровск, Пионерская, 50	f	large
27013	7993	109	Хабаровский край, Хабаровск, Панфиловцев, 22	f	large
27588	8534	685	Хабаровский край, Хабаровск, Новая, 20	f	small
27031	8009	127	Хабаровский край, Хабаровск, Насыпная, 7	f	small
27567	8513	664	Хабаровский край, Хабаровск, Набережная, 8	t	small
27562	8508	659	Хабаровский край, Хабаровск, Набережная, 7	t	small
27121	8093	217	Хабаровский край, Хабаровск, Муравьева-Амурского, 35	f	large
27034	8012	130	Хабаровский край, Хабаровск, Молдавский переулок, 10	f	large
26937	7933	33	Хабаровский край, Хабаровск, Матвеевское шоссе, 23	f	large
27028	8006	124	Хабаровский край, Хабаровск, Магаданская, 11А	f	large
26947	4716	43	Хабаровский край, Хабаровск, Ленинградский переулок, 9	f	large
27027	8005	123	Хабаровский край, Хабаровск, Краснореченская, квартироно-эксплутационная часть района МОРФ	f	large
26905	7918	1	Хабаровский край, Хабаровск, Клубная, 1	f	large
27019	7998	115	Хабаровский край, Хабаровск, Каширская, 21	f	large
26962	7944	58	Хабаровский край, Хабаровск, Казарменный, 15	f	small
27098	8056	194	Хабаровский край, Хабаровск, Кадровый переулок, 8а	f	large
26984	7965	80	Хабаровский край, Хабаровск, Иртышский проезд, 6	f	large
26957	6520	53	Хабаровский край, Хабаровск, Дзержинского переулок, 9	f	large
26915	6667	11	Хабаровский край, Хабаровск, Георгиевская, 37	f	large
27108	8081	204	Хабаровский край, Хабаровск, Гамарника, 11	f	large
26917	6712	13	Хабаровский край, Хабаровск, Восточное шоссе, 2	f	large
26916	6690	12	Хабаровский край, Хабаровск, Восточное шоссе, 49	f	large
27014	7994	110	Хабаровский край, Хабаровск, Ворошилова, 3А	f	large
26958	7941	54	Хабаровский край, Хабаровск, Блюхера, 2А	f	large
26910	7877	6	Хабаровский край, Хабаровск, Балтийская	f	medium
26980	7961	76	Хабаровский край, Хабаровск, Байкальский переулок, 6	f	large
26979	7960	75	Хабаровский край, Хабаровск, Байкальский переулок, 4ка	f	large
27020	7999	116	Хабаровский край, Хабаровск, Артемовская, 86А	f	large
27114	8086	210	Хабаровский край, Хабаровск, Амурский бульвар, 34	f	large
27057	8033	153	Хабаровский край, Хабаровск, Амурский бульвар, 43	f	large
27052	8030	148	Хабаровский край, Хабаровск, Амурский бульвар, 27	f	large
27049	8026	145	Хабаровский край, Хабаровск, Амурский бульвар, 1	f	large
27023	8002	119	Хабаровский край, Хабаровск, Алеутская, 27	f	large
26927	7923	23	Хабаровский край, Хабаровск, 60 Лет Октября проспект, 156	f	large
27058	8034	154	Хабаровский край, Хабаровск, Герасимова, 16	f	large
26991	7971	87	Хабаровский край, Хабаровск, Архангельская, 50	f	large
27553	8499	650	Хабаровский край, Охотск, Коммунистическая,  61	f	medium
27161	8129	257	Хабаровский край, Комсомольск-на-Амуре, Клуб жилого мкр.Старт	f	medium
27180	8145	276	Хабаровский край, Комсомольск-на-Амуре, проспект Октябрьский, 26, корп.2	f	large
27176	8141	272	Хабаровский край, Комсомольск-на-Амуре, проспект Октябрьский, 19	f	large
27152	8122	248	Хабаровский край, Комсомольск-на-Амуре, проспект Московский, 22, корп.4	f	large
27153	8121	249	Хабаровский край, Комсомольск-на-Амуре, проспект Московский, 24	f	large
27151	8121	247	Хабаровский край, Комсомольск-на-Амуре, проспект Московский, 24	f	large
27150	8120	246	Хабаровский край, Комсомольск-на-Амуре, проспект Московский, 20	f	large
27183	8148	279	Хабаровский край, Комсомольск-на-Амуре, проспект Мира, 2	f	large
27214	8176	310	Хабаровский край, Комсомольск-на-Амуре, проспект Ленина, 74, корп.2	f	large
27213	8176	309	Хабаровский край, Комсомольск-на-Амуре, проспект Ленина, 74, корп.2	f	large
27197	8162	293	Хабаровский край, Комсомольск-на-Амуре, проспект Ленина, 44, корп.4	f	large
27194	8159	290	Хабаровский край, Комсомольск-на-Амуре, проспект Ленина, 11	f	large
27173	8138	269	Хабаровский край, Комсомольск-на-Амуре, проспект Ленина, 45	f	large
27130	8102	226	Хабаровский край, Комсомольск-на-Амуре, проспект Копылова, 43	f	large
27172	8137	268	Хабаровский край, Комсомольск-на-Амуре, проспект Интернациональный, 33, корп.2	f	large
27171	8137	267	Хабаровский край, Комсомольск-на-Амуре, проспект Интернациональный, 33, корп.2	f	large
27170	8136	266	Хабаровский край, Комсомольск-на-Амуре, проспект Интернациональный, 31, корп.2	f	large
27136	8108	232	Хабаровский край, Комсомольск-на-Амуре, Щорса, 50	f	large
27200	8165	296	Хабаровский край, Комсомольск-на-Амуре, Чапаева, 1	f	large
27139	8111	235	Хабаровский край, Комсомольск-на-Амуре, Сусанина, 55	f	large
27137	8109	233	Хабаровский край, Комсомольск-на-Амуре, Сусанина, 67	f	large
27218	8179	314	Хабаровский край, Комсомольск-на-Амуре, Сортировочная, 7, корп.2	f	large
27129	8101	225	Хабаровский край, Комсомольск-на-Амуре, Советская, 11	f	large
27223	8184	319	Хабаровский край, Комсомольск-на-Амуре, Северное шоссе, 10, корп.3	f	medium
27193	8158	289	Хабаровский край, Комсомольск-на-Амуре, Севастопольская, 51	f	large
27204	8170	300	Хабаровский край, Комсомольск-на-Амуре, Пирогова, 21	f	large
27201	8166	297	Хабаровский край, Комсомольск-на-Амуре, Пирогова, 34, корп.3	f	large
27124	8096	220	Хабаровский край, Комсомольск-на-Амуре, Пермская, 5, корп.3	f	large
27191	8156	287	Хабаровский край, Комсомольск-на-Амуре, Партизанская, 10	f	large
27230	8181	326	Хабаровский край, Комсомольск-на-Амуре, Охотская, 1	f	large
27220	8181	316	Хабаровский край, Комсомольск-на-Амуре, Охотская, 1	f	large
27133	8105	229	Хабаровский край, Комсомольск-на-Амуре, Орехова, 67	f	large
27185	8150	281	Хабаровский край, Комсомольск-на-Амуре, Орджоникидзе, 4	f	large
27187	8152	283	Хабаровский край, Комсомольск-на-Амуре, Мира, 23	f	large
27227	8188	323	Хабаровский край, Комсомольск-на-Амуре, Мачтовая, 9	f	small
27125	8097	221	Хабаровский край, Комсомольск-на-Амуре, Ломоносова, 18	f	medium
27189	8154	285	Хабаровский край, Комсомольск-на-Амуре, Летчиков, 19	f	large
27146	8117	242	Хабаровский край, Комсомольск-на-Амуре, Ленинградская, 63	f	large
27145	8116	241	Хабаровский край, Комсомольск-на-Амуре, Ленинградская, 64	f	large
27144	8115	240	Хабаровский край, Комсомольск-на-Амуре, Ленинградская, 35	f	large
27134	8106	230	Хабаровский край, Комсомольск-на-Амуре, Ленинградская, 79	f	large
27155	8124	251	Хабаровский край, Комсомольск-на-Амуре, Лазо, 23	f	large
27140	8112	236	Хабаровский край, Комсомольск-на-Амуре, Лазо, 79	f	large
27138	8110	234	Хабаровский край, Комсомольск-на-Амуре, Культурная, 18	f	large
27135	8107	231	Хабаровский край, Комсомольск-на-Амуре, Культурная, 3	f	large
27224	8185	320	Хабаровский край, Комсомольск-на-Амуре, Копровая, 1	f	large
27178	8143	274	Хабаровский край, Комсомольск-на-Амуре, Комсомольская, 45	f	large
27186	8151	282	Хабаровский край, Комсомольск-на-Амуре, Кирова, 24	f	large
27131	8103	227	Хабаровский край, Комсомольск-на-Амуре, Калинина, 29	f	large
27128	8100	224	Хабаровский край, Комсомольск-на-Амуре, Калинина, 7	f	large
27212	8172	308	Хабаровский край, Комсомольск-на-Амуре, Дикопольцева, 34, корп.5	f	large
27206	8172	302	Хабаровский край, Комсомольск-на-Амуре, Дикопольцева, 34, корп.5	f	large
27184	8149	280	Хабаровский край, Комсомольск-на-Амуре, Дзержинского, 12	f	large
27229	8178	325	Хабаровский край, Комсомольск-на-Амуре, Вокзальная, 80, корп.3	f	large
27217	8178	313	Хабаровский край, Комсомольск-на-Амуре, Вокзальная, 80, корп.3	f	large
27166	8133	262	Хабаровский край, Комсомольск-на-Амуре, Аллея Труда, 55, корп.2	f	large
27165	8133	261	Хабаровский край, Комсомольск-на-Амуре, Аллея Труда, 55, корп.2	f	large
27205	8171	301	Хабаровский край, .Комсомольск-на-Амуре, Гамарника, 16	f	large
27505	8451	602	Хабаровский край, район имени Лазо , с. Второй Сплавной Участок, Центральная, 4	t	small
27514	8460	611	Хабаровский край, имени Лазо, село Бичевая, Набережная, 22	f	medium
27118	8090	214	Хабаровский край, Центральный район, Хабаровск, Призывной переулок, 1	f	large
27680	8626	780	Хабаровский край, Хабаровский район, село Чистополье, Центральная, 8	f	small
27679	8625	779	Хабаровский край, Хабаровский район, село Черная Речка, Центральная, 30	f	large
27663	8609	763	Хабаровский край, Хабаровский район, село Челны, Набережная, 3	t	small
27653	8600	753	Хабаровский край, Хабаровский район, село Федоровка, Зеленая, 13а	f	small
27662	8608	762	Хабаровский край, Хабаровский район, село Улика-Национальное, Юбилейная, 10	t	small
27637	8585	736	Хабаровский край, Хабаровский район, село Тополево, Школьная, 4а	f	large
27636	8584	735	Хабаровский край, Хабаровский район, село Тополево, Школьная, 4	f	large
27669	8615	769	Хабаровский край, Хабаровский район, село Таежное, Интернациональная, 13	f	large
27651	8599	751	Хабаровский край, Хабаровский район, село Сосновка, площадь Мира, 4	f	medium
27650	8598	750	Хабаровский край, Хабаровский район, село Сосновка, Шоссейная, 34	f	medium
27640	8588	739	Хабаровский край, Хабаровский район, село Смирновка, Молодежная, 26	f	small
27666	8612	766	Хабаровский край, Хабаровский район, село Сикачи-Алян, Октябрьская, 1а	t	small
27678	8624	778	Хабаровский край, Хабаровский район, село Сергеевка, Партизанская, 5	f	large
27686	8631	786	Хабаровский край, Хабаровский район, село Ракитное, Центральная, 28а	f	large
27659	8605	759	Хабаровский край, Хабаровский район, село Победа, переулок Безымянный, 4	f	medium
27668	8614	768	Хабаровский край, Хабаровский район, село Петропавловка, Советская, 29	t	small
27660	8606	760	Хабаровский край, Хабаровский район, село Пасека, Пионерская, 7	t	small
27661	8607	761	Хабаровский край, Хабаровский район, село Новокуровка, Советская, 30	t	small
27689	8633	789	Хабаровский край, Хабаровский район, село Некрасовка, Ленина, 20	f	large
27688	8582	788	Хабаровский край, Хабаровский район, село Некрасовка, Ленина, 1	f	large
27634	8582	733	Хабаровский край, Хабаровский район, село Некрасовка, Ленина, 1	f	large
27658	8604	758	Хабаровский край, Хабаровский район, село Наумовка, Центральная, 19	t	small
27655	8602	755	Хабаровский край, Хабаровский район, село Нагорное, Центральная, 8а	f	small
27654	8601	754	Хабаровский край, Хабаровский район, село Мичуринское, Парковая, 7	f	large
27683	8628	783	Хабаровский край, Хабаровский район, село Мирное, Рабочая, 6	f	large
27638	8586	737	Хабаровский край, Хабаровский район, село Матвеевка, Центральная, 38б	f	large
27645	8593	744	Хабаровский край, Хабаровский район, село Матвеевка, 40 Лет Победы, 5	f	large
27667	8613	767	Хабаровский край, Хабаровский район, село Малышево, Первомайская, 33	f	medium
27657	8603	757	Хабаровский край, Хабаровский район, село Кукан, Новая, 1	f	medium
27647	8595	746	Хабаровский край, Хабаровский район, село Краснореченское, Мостовая, 6	f	large
27648	8596	747	Хабаровский край, Хабаровский район, поселок Корфовский, Таежная, 2а	f	large
27649	8597	748	Хабаровский край, Хабаровский район, поселок Корфовский, Владивостокская, 24	f	large
27646	8594	745	Хабаровский край, Хабаровский район, село Корсаково-1, Школьная, 6	f	medium
27642	8590	741	Хабаровский край, Хабаровский район, село Константиновка, Международная, 14/1	f	small
27673	8619	773	Хабаровский край, Хабаровский район, село Князе-Волконское, квартал ДОС, МОУ СОШ с.Князе-Волконское 1	f	large
27672	8617	772	Хабаровский край, Хабаровский район, село Князе-Волконское, квартал ДОС, д.Гарнизонный Дом офицеров	f	large
27674	8620	774	Хабаровский край, Хабаровский район, село Князе-Волконское, Никитенко, 18	f	large
27677	8623	777	Хабаровский край, Хабаровский район, село Калинка, Авиаторов, 3	f	large
27643	8591	742	Хабаровский край, Хабаровский район, село Казакевичево, Новожилова, 13	f	medium
27635	8583	734	Хабаровский край, Хабаровский район, село Ильинка, Совхозная, 32а	f	large
27639	8587	738	Хабаровский край, Хабаровский район, село Заозерное, Петра Черкасова, 5а	f	medium
27664	8610	764	Хабаровский край, Хабаровский район, село Елабуга, Новая, 1	f	medium
27684	8629	784	Хабаровский край, Хабаровский район, село Дружба, Центральная, 23	f	large
27687	8632	787	Хабаровский край, Хабаровский район, село Гаровка 2-я, ДОС, 18а	f	large
27685	8630	785	Хабаровский край, Хабаровский район, село Гаровка 1-я, Центральная, 46а	f	medium
27641	8589	740	Хабаровский край, Хабаровский район, село Галкино, Мира, 15а	f	medium
27665	8611	765	Хабаровский край, Хабаровский район, село Вятское, Набережная, 53	f	large
27681	8627	781	Хабаровский край, Хабаровский район, село Восточное, Клубная, 1	f	large
27644	8592	743	Хабаровский край, Хабаровский район, село Бычиха, Новая, 12	f	large
27676	8622	776	Хабаровский край, Хабаровский район, село Благодатное, Школьная, 1	f	medium
27671	8616	771	Хабаровский край, Хабаровский район, село Анастасьевка, Бойко Павлова, 28	f	small
27620	8567	718	Хабаровский край, Ульчский район, с.Булава (Новая), Набережная, 3	t	medium
27631	8579	730	Хабаровский край, Ульчский район, село Циммермановка, Железнодорожная, 35	f	large
27612	8559	710	Хабаровский край, Ульчский район, село Ухта, Центральная, 4	t	small
27608	8555	706	Хабаровский край, Ульчский район, село Тыр, Ленина, 20	t	small
27606	8553	704	Хабаровский край, Ульчский район, село Тахта, Комсомольская, 17	t	medium
27610	8557	708	Хабаровский край, Ульчский район, село Сусанино, Центральная, 80	f	medium
27626	8574	725	Хабаровский край, Ульчский район, село Софийск, Центральная, 17	f	medium
27627	8575	726	Хабаровский край, Ульчский район, село Софийск, Кирова, 11	f	small
27616	8563	714	Хабаровский край, Ульчский район, село Солонцы, Школьная, 4	f	small
27619	8566	717	Хабаровский край, Ульчский район, село Савинское, Амурская, 9	f	small
27630	8578	729	Хабаровский край, Ульчский район, село Решающий, Советская, 17	f	small
27611	8558	709	Хабаровский край, Ульчский район, село Нижняя Гавань, Амурская, 21	f	small
27622	8569	720	Хабаровский край, Ульчский район, село Мариинское, Ленина, 3	t	medium
27623	8571	721	Хабаровский край, Ульчский район, село Мариинский Рейд, Пионерская, 18	t	medium
27617	8564	715	Хабаровский край, Ульчский район, село Кольчем, Озерная, 7	t	small
27633	8581	732	Хабаровский край, Ульчский район, село Ключевой, Школьный, 2	f	small
27607	8554	705	Хабаровский край, Ульчский район, село Кальма, Школьный, 9/1, сельская библиотека	t	small
27628	8576	727	Хабаровский край, Ульчский район, село Калиновка, Таежная, 13	t	small
27618	8565	716	Хабаровский край, Ульчский район, село Дуди, Школьная, 2	t	small
27625	8573	724	Хабаровский край, Ульчский район, село Де-Кастри, Клубная, 3	f	large
27629	8577	728	Хабаровский край, Ульчский район, село Быстринск, Набережная, 12	f	small
27621	8568	719	Хабаровский край, Ульчский район, село Булава, Советская, 9	f	small
27624	8572	722	Хабаровский край, Ульчский район, село Большие Санники, Аптечная, 4	t	small
27614	8561	712	Хабаровский край, Ульчский район, село Богородское, Партизанская, 7	f	large
27613	8560	711	Хабаровский край, Ульчский район, село Богородское, Парковая, 8	f	medium
27615	8562	713	Хабаровский край, Ульчский район, село Богородское, Ключевая, 2а	f	medium
27609	8556	707	Хабаровский край, Ульчский район, село Аннинские Минеральные Воды, Центральная, 2	f	small
27602	8549	700	Хабаровский край, Тугуро-Чумиканский район, село Чумикан, Таранца, 30	f	medium
27605	8552	703	Хабаровский край, Тугуро-Чумиканский район, село Удское, Совхозная, 16	t	small
27600	8547	698	Хабаровский край, Тугуро-Чумиканский район, село Тугур, Карпова, 18	t	small
27601	8548	699	Хабаровский край, Тугуро-Чумиканский район, село Тором, Центральная, 6	t	small
27603	8550	701	Хабаровский край, Тугуро-Чумиканский район, село Неран, Мира, 14	t	small
27604	8551	702	Хабаровский край, Тугуро-Чумиканский район, село Алгазея, переулок Победы, 6	t	small
27566	8512	663	Хабаровский край, Солнечный район, п. Новое Устье, Школьная, 3	t	small
27594	8541	691	Хабаровский край, Солнечный район, село Эворон, Вокзальная, 17	f	medium
27587	8533	684	Хабаровский край, Солнечный район, село Хурмули, Клубная, 3	f	large
27593	8540	690	Хабаровский край, Солнечный район, село Харпичан, Юбилейная, 35	f	medium
27585	8531	682	Хабаровский край, Солнечный район, село Хальгасо, Южная, 1/б	t	small
27579	8525	676	Хабаровский край, Солнечный район, поселок Солнечный, Парковая, 7/В	f	large
27578	8523	675	Хабаровский край, Солнечный район, поселок Солнечный, Парковая, 3	f	large
27584	8530	681	Хабаровский край, Солнечный район, поселок Солнечный, Ленина, 22	f	large
27583	8529	680	Хабаровский край, Солнечный район, поселок Солнечный, Ленина, 11	f	large
27582	8528	679	Хабаровский край, Солнечный район, поселок Солнечный, Ленина, 23/В	f	large
27581	8527	678	Хабаровский край, Солнечный район, поселок Солнечный, Ленина, 20/А	f	large
27580	8526	677	Хабаровский край, Солнечный район, поселок Солнечный, Ленина, 23/Б	f	large
27589	8535	686	Хабаровский край, Солнечный район, село Лиан, Весны, 11	f	small
27592	8538	689	Хабаровский край, Солнечный район, село Кондон, А. Самара, 20	t	small
27595	8542	692	Хабаровский край, Солнечный район, село Дуки, А. Никифорова, 10	f	large
27599	8546	697	Хабаровский край, Солнечный район, село Джамку, Центральная, 1/А	f	medium
27586	8532	683	Хабаровский край, Солнечный район, поселок Горный, Комсомольская, 25/А	f	large
27590	8536	687	Хабаровский край, Солнечный район, село Горин, Центральная, 38	f	large
27591	8537	688	Хабаровский край, Солнечный район, село Горин, Вокзальная, 20	f	medium
27597	8544	695	Хабаровский край, Солнечный район, село Березовый, Школьная, 12	f	large
27596	8543	694	Хабаровский край, Солнечный район, село Березовый, Пионерская, 14	f	large
27598	8545	696	Хабаровский край, Солнечный район, село Амгунь, Ленина, 11	f	small
27240	8195	336	Хабаровский край, Советско-Гаванский район, Советская Гавань, Чкалова, 12	f	large
27245	8200	341	Хабаровский край, Советско-Гаванский район, Советская Гавань, Флерова, 1	f	medium
86214	8198	339	Хабаровский край, Советско-Гаванский район, Советская Гавань, Суворова, 1	f	small
27246	8201	342	Хабаровский край, Советско-Гаванский район, Советская Гавань, Сахалинская, здание ООО "Гектор"	f	small
27241	8196	337	Хабаровский край, Советско-Гаванский район, Советская Гавань, Полины Осипенко, 1	f	large
27239	8194	335	Хабаровский край, Советско-Гаванский район, Советская Гавань, Пионерская, 1	f	large
27238	8194	334	Хабаровский край, Советско-Гаванский район, Советская Гавань, Пионерская, 1	f	large
27233	8190	329	Хабаровский край, Советско-Гаванский район, Советская Гавань, Первомайская, 52	f	large
27237	8193	333	Хабаровский край, Советско-Гаванский район, Советская Гавань, Ленина, 4	f	large
27234	8191	330	Хабаровский край, Советско-Гаванский район, Советская Гавань, Ленина, 17	f	large
27244	8199	340	Хабаровский край, Советско-Гаванский район, Советская Гавань, Кишиневская, 5	f	small
27235	8192	331	Хабаровский край, Советско-Гаванский район, Советская Гавань, Киевская, 2	f	large
27232	8189	328	Хабаровский край, Советско-Гаванский район, Советская Гавань, Киевская, 31	f	large
27242	8197	338	Хабаровский край, Советско-Гаванский район, Советская Гавань, Калинина, 5	f	large
27248	8203	344	Хабаровский край, Советско-Гаванский район, поселок Майский, Черемховская, 19а	f	large
27249	8204	345	Хабаровский край, Советско-Гаванский район, поселок Майский, Селенгинская, 14	f	medium
27253	8208	349	Хабаровский край, Советско-Гаванский район, поселок Лососина, Украинская, 1	f	large
27252	8207	348	Хабаровский край, Советско-Гаванский район, поселок Заветы Ильича, Николаева, 10	f	large
27251	8206	347	Хабаровский край, Советско-Гаванский район, поселок Заветы Ильича, Невельского, здание Дома офицеров	f	large
27250	8205	346	Хабаровский край, Советско-Гаванский район, поселок Заветы Ильича, Невельского, 10	f	large
134596	8202	343	Хабаровский край, Советско-Гаванский район, село Гатка, Клубная, 1	f	medium
27565	8511	662	Хабаровский край, Охотский район, п. Морской, Речная, 25	t	small
27552	8498	649	Хабаровский край, Охотский район, Охотск, Победы, 5	f	small
27557	8503	654	Хабаровский край, Охотский район, Охотск, Ленина, 10	f	small
27556	8502	653	Хабаровский край, Охотский район, Охотск, Ленина, 20	f	medium
27555	8501	652	Хабаровский край, Охотский район, поселок Охотск, Карпинского, 17	f	medium
27558	8504	655	Хабаровский край, Охотский район, Охотск, Вострецова, 17	f	small
27554	8500	651	Хабаровский край, Охотский район, Охотск, 40 Лет Победы, 57	f	medium
27560	8506	657	Хабаровский край, Охотский район, поселок Аэропорт, Центральная, 13	t	small
27559	8505	656	Хабаровский край, Охотский район, Арка, Таежная, 22	f	medium
27284	8235	380	Хабаровский край, Николаевский район, село Чныррах, Центральная, 25	f	small
27291	8242	387	Хабаровский край, Николаевский район, село Чля, Центральная, 26	f	medium
27281	8232	377	Хабаровский край, Николаевский район, поселок Пуир, Набережная, 5, УИК-ул.Набережная,д.11 место голосования-ул.Набережная, д.5	t	small
27283	8234	379	Хабаровский край, Николаевский район, село Оремиф, Школьная, 1а	t	small
27282	8233	378	Хабаровский край, Николаевский район, село Озерпах, Невельского, 4	t	small
27257	8211	353	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Школьная, 219	f	large
27259	8213	355	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Чихачёва, 4	f	medium
27260	8214	356	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Чихачева, 8	f	medium
27276	8227	372	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Читинская, 6	f	small
27278	8230	374	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Хабаровская, 54	f	medium
27277	8229	373	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Советская, 38	f	medium
27268	8220	364	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Советская, 75	f	medium
27255	8209	351	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Советская, 173	f	medium
27273	8224	369	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Сибирская, 102	f	medium
27269	8221	365	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Сибирская, 165	f	medium
27270	8221	366	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Сибирская, 165	f	medium
27266	8219	362	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Сибирская, 181	f	large
27263	8217	359	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Сибирская, 193	f	medium
27261	8215	357	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Сибирская, 193	f	large
27256	8210	352	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Северная, 185	f	medium
27264	8218	360	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Свободная, 29	f	large
27275	8226	371	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Приамурская, 69	f	medium
27258	8212	354	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Попова, 24	f	medium
27531	8477	628	Хабаровский край, Имени Лазо район, село Сидима, Пушкина, 32	f	medium
27274	8225	370	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Пионерская, 111	f	large
27272	8223	368	Хабаровский край, Николаевский район, Николаевск-на-Амуре, М.Горького, 79	f	small
27262	8216	358	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Луначарского, 138	f	large
27271	8222	367	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Кантера, 2	f	medium
27279	8231	375	Хабаровский край, Николаевский район, Николаевск-на-Амуре, Аэродромная, 1	f	medium
27294	8245	390	Хабаровский край, Николаевский район, село Нижнее Пронге, Центральная, 68	t	small
27296	8247	392	Хабаровский край, Николаевский район, село Нигирь, Школьная, 20	t	small
27292	8243	388	Хабаровский край, Николаевский район, поселок Многовершинный, Черкашина, 37	f	large
27287	8238	383	Хабаровский край, Николаевский район, поселок Маго, здание дома культуры островной части	f	medium
27289	8240	385	Хабаровский край, Николаевский район, поселок Маго, Мира, 4	t	small
27288	8239	384	Хабаровский край, Николаевский район, поселок Маго, 50 лет ССР, 3	f	small
27295	8246	391	Хабаровский край, Николаевский район, поселок Лазарев, Портовая, 5	f	large
27285	8236	381	Хабаровский край, Николаевский район, село Красное, Советская, 37б	f	medium
27293	8244	389	Хабаровский край, Николаевский район, село Константиновка, Строительная, 3а	f	medium
27286	8237	382	Хабаровский край, Николаевский район, село Иннокентьевка, Центральная, 5	f	small
27542	8488	639	Хабаровский край, Нанайский район, село Троицкое, Шоссейная, 12б	f	medium
27545	8491	642	Хабаровский край, Нанайский район, село Троицкое, Кола Бельды, 3	f	medium
27546	8492	643	Хабаровский край, Нанайский район, село Троицкое, Калинина, 171	f	medium
27544	8490	641	Хабаровский край, Нанайский район, село Троицкое, Калинина, 94	f	medium
27543	8489	640	Хабаровский край, Нанайский район, село Троицкое, 40 лет Победы, 1	f	large
27547	8493	644	Хабаровский край, Нанайский район, село Славянка, Набережная, 32	t	small
27533	8479	630	Хабаровский край, Нанайский район, село Синда, Пассара, 14	f	medium
27539	8485	636	Хабаровский край, Нанайский район, село Нижняя Манома, Почтовая, 16	t	small
27537	8483	634	Хабаровский край, Нанайский район, село Найхин, Школьная, 14	f	medium
27532	8478	629	Хабаровский край, Нанайский район, село Маяк, Центральная, 23а	f	large
27548	8494	645	Хабаровский край, Нанайский район, село Лидога, Первомайская, 9а	f	large
27550	8496	647	Хабаровский край, Нанайский район, село Иннокентьевка, Школьная, 1	f	medium
27534	8480	631	Хабаровский край, Нанайский район, село Дубовый Мыс, Юбилейная, 16	f	large
27549	8495	646	Хабаровский край, Нанайский район, село Джонка, Комсомольская, 44	f	large
27538	8484	635	Хабаровский край, Нанайский район, село Джари, Калинина, 180	f	medium
27536	8482	633	Хабаровский край, Нанайский район, село Даерга, Зеленая, 17а	f	medium
27535	8481	632	Хабаровский край, Нанайский район, село Дада, Лесная, 11а	f	small
27540	8486	637	Хабаровский край, Нанайский район, село Верхняя Манома, Комсомольская, 6	t	small
27551	8497	648	Хабаровский край, Нанайский район, село Верхний Нерген, Зеленая, 10	t	small
27541	8487	638	Хабаровский край, Нанайский район, село Арсеньево, Лесопильная, 6	t	small
27094	8068	190	Хабаровский край, Краснофлотский район, Хабаровск, Тихоокеанская, 139А	f	large
27077	8053	173	Хабаровский край, Краснофлотский район, Хабаровск, Тихоокеанская, 194а	f	large
27063	8039	159	Хабаровский край, Краснофлотский район, Хабаровск, Тихоокеанская, 136	f	large
27458	8407	555	Хабаровский край, Комсомольский район, село Ягодный, Школьная, 6	f	large
27466	8415	563	Хабаровский край, Комсомольский район, село Хурба, Добровольского, 1	f	large
27465	8414	562	Хабаровский край, Комсомольский район, село Хурба, Гайдара, 1	f	large
27454	8403	551	Хабаровский край, Комсомольский район, село Уктур, Центральная, 9	f	large
27452	8401	549	Хабаровский край, Комсомольский район, село Снежный, Торговая, 16	f	large
27475	8422	572	Хабаровский край, Комсомольский район, село Селихино, Садовая, 18	f	large
27462	8411	559	Хабаровский край, Комсомольский район, Поселок Бельго, УИК-ул. Набережная, 27, пом.для голосов-ул. Школьная, д.1	t	small
27470	8419	567	Хабаровский край, Комсомольский район, село Пивань-Пристань, Совгаванская, 32	f	large
27468	8417	565	Хабаровский край, Комсомольский район, село Новый Мир, Центральная, 27, пом.для голосов-ул. Центральная, д.27"	f	medium
27456	8405	553	Хабаровский край, Комсомольский район, село Новоильиновка, Школьная, 33б	t	small
27460	8409	557	Хабаровский край, Комсомольский район, село Нижние Халбы, Школьная, 6	t	small
27459	8408	556	Хабаровский край, Комсомольский район, село Нижнетамбовское, Кретова, 6	f	medium
27467	8416	564	Хабаровский край, Комсомольский район, село Молодежный, Таёжная, 9	f	large
27126	8098	222	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре	f	large
27148	8119	244	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, проспект Победы, 47, корп.3	f	large
27149	8119	245	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, проспект Победы, 47, корп.3	f	large
27169	8135	265	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, проспект Первостроителей, 11	f	large
27182	8147	278	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, проспект Октябрьский, 10к4	f	large
27154	8123	250	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, проспект Московский, 28	f	large
27196	8161	292	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, проспект Ленина, 27	f	large
27162	8130	258	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, проспект Интернациональный, 1	f	large
27216	8177	312	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, пр.Ленина, 79к2	f	large
27215	8177	311	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, пр.Ленина, 79к2	f	large
27159	8127	255	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, переулок Сельский, 22	f	small
27226	8187	322	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, мкр.Дружба, 4	f	large
27225	8186	321	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, мкр.Дружба, Средняя общеобразовательная школа № 35	f	large
27167	8134	263	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, бульвар Юности, 6к3	f	large
27156	8125	252	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Щорса, 83, корп.2	f	medium
27147	8118	243	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Тепличная, 1	f	large
27143	8114	239	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Советская, 8	f	large
27142	8114	238	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Советская, 8	f	large
27181	8146	277	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Севастопольская, 20	f	large
27202	8167	298	Хабаровский край, Комсомольский район, Пирогова, 30	f	large
27192	8157	288	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Пионерская, 73	f	large
27199	8164	295	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Первостроителей, 41	f	large
27211	8175	307	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Магистральное шоссе, 47, корп.2	f	large
27210	8174	306	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Магистральное шоссе, 39, корп.2	f	large
27209	8174	305	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Магистральное шоссе, 39, корп.2	f	large
27208	8173	304	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Магистральное шоссе, 25, корп.3	f	large
27207	8173	303	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Магистральное шоссе, 25, корп.3	f	large
27141	8113	237	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Культурная, 2	f	medium
27179	8144	275	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Краснофлотская, 44, корп.2	f	large
27195	8160	291	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Красногвардейская, 35	f	large
27190	8155	286	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Красногвардейская, 10	f	large
27222	8183	318	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Комсомольское шоссе, 26	f	medium
27177	8142	273	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Комсомольская, 44	f	large
27219	8180	315	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Комитетская, 21	f	small
27188	8153	284	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Кирова, 41	f	large
25073	74027	782	Приморский край, Партизанск, Кирова, 27	f	large
27132	8104	228	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Калинина, 18	f	large
27127	8099	223	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Калинина, 1к2	f	large
27163	8131	259	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Гагарина, 2к3	f	large
27158	8126	254	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Восточное шоссе, 26	f	large
27157	8126	253	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Восточное шоссе, 26	f	large
27203	8168	299	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Вокзальная, 79	f	large
27198	8163	294	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Васянина, 20	f	large
27175	8140	271	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Васянина, 2	f	large
27174	8139	270	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Васянина, 1	f	large
27221	8182	317	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Вагонная, 8	f	small
27168	8132	264	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Аллея Труда, 57к6	f	large
27164	8132	260	Хабаровский край, Комсомольский район, Комсомольск-на-Амуре, Аллея Труда, 57к6	f	large
27455	8404	552	Хабаровский край, Комсомольский район, село Кенай, Пионерская	f	small
27451	8400	548	Хабаровский край, Комсомольский район, село Даппы, Центральная, 4	f	small
27453	8402	550	Хабаровский край, Комсомольский район, поселок Гурское, Школьная, 2	f	medium
27463	8412	560	Хабаровский край, Комсомольский район, село Галичный, Советская, 14	f	small
27471	8420	568	Хабаровский край, Комсомольский район, село Гайтер, Октябрьская, 28	f	medium
27469	8418	566	Хабаровский край, Комсомольский район, село Верхняя Эконь, Школьная, 14	f	small
27461	8410	558	Хабаровский край, Комсомольский район, село Верхнетамбовское, Набережная, 25	t	small
27473	8421	570	Хабаровский край, Комсомольский район, село Большая Картель, Хабаровская, 9а	f	small
27464	8413	561	Хабаровский край, Комсомольский район, село Боктор, Школьная, 7	t	small
134595	8028	146	Хабаровский край, Кировский район, Хабаровск, улица Чкалова, 17	f	large
27576	8521	673	Хабаровский край, Имени Полины Осипенко район, село имени Полины Осипенко, Школьная, 12	t	small
27573	8518	670	Хабаровский край, Имени Полины Осипенко район, село имени Полины Осипенко, Школьная, 2	t	small
27577	8522	674	Хабаровский край, Имени Полины Осипенко район, село имени Полины Осипенко, Центральная, 26	t	small
27571	8516	668	Хабаровский край, Имени Полины Осипенко район, село имени Полины Осипенко, Центральная, 73	t	small
68027	8519	671	Хабаровский край, Имени Полины Осипенко район, село имени Полины Осипенко, Амгуньская, 80	f	large
27572	8517	669	Хабаровский край, Имени Полины Осипенко район, село имени Полины Осипенко, 60 лет Октября, 64	t	medium
27569	8515	666	Хабаровский край, Имени Полины Осипенко район, село Удинск, Набережная, 11	t	small
27575	8520	672	Хабаровский край, Имени Полины Осипенко район, село Бриакан, Черенева, 32	f	medium
27519	8465	616	Хабаровский край, Имени Лазо район, село Южный, Школьная, 1а	t	small
27490	8436	587	Хабаровский край, Имени Лазо район, село Черняево, Первомайская, 5	f	medium
27494	8440	591	Хабаровский край, Имени Лазо район, поселок Хор, переулок Степной, 2	f	medium
27492	8438	589	Хабаровский край, Имени Лазо район, поселок Хор, Советская, 15	f	large
27496	8442	593	Хабаровский край, Имени Лазо район, поселок Хор, Менделеева, 12а	f	large
27493	8439	590	Хабаровский край, Имени Лазо район, поселок Хор, Ленина, 6	f	large
27495	8441	592	Хабаровский край, Имени Лазо район, поселок Хор, Безымянная, 3	f	large
27501	8447	598	Хабаровский край, Имени Лазо район, село Хака, Центральная, 2	t	small
27477	8423	574	Хабаровский край, Имени Лазо район, село Сукпай, Центральная, 18	f	small
27478	8424	575	Хабаровский край, Имени Лазо район, село Сукпай, Городская, 51	f	medium
27522	8468	619	Хабаровский край, Имени Лазо район, село Среднехорский, Центральная, 11	f	small
27521	8467	618	Хабаровский край, Имени Лазо район, село Солонцовый, Школьная, 41а	f	small
27506	8452	603	Хабаровский край, Имени Лазо район, село Соколовка, Специалистов, 1	t	small
27526	8472	623	Хабаровский край, Имени Лазо район, село Сита, Клубная, 2Б	f	large
25064	74018	773	Приморский край, Партизанск, Калинина, 60	f	\N
27512	8458	609	Хабаровский край, Имени Лазо район, село Святогорье, Юбилейная, 7	f	medium
27511	8457	608	Хабаровский край, Имени Лазо район, село Прудки, Зеленая, 14/1	t	small
27510	8456	607	Хабаровский край, Имени Лазо район, село Полетное, Колхозная, 28	f	medium
27509	8455	606	Хабаровский край, Имени Лазо район, село Петровичи, Центральная, 50А	t	small
134597	8432	583	Хабаровский край, Имени Лазо район, Переяславка-2, здание Дома офицеров	f	large
27484	8430	581	Хабаровский край, Имени Лазо район, поселок Переяславка, переулок Ленина, 12	f	large
27485	8431	582	Хабаровский край, Имени Лазо район, поселок Переяславка, Центральная, 19	f	large
27483	8429	580	Хабаровский край, Имени Лазо район, поселок Переяславка, Октябрьская, 52	f	large
27482	8428	579	Хабаровский край, Имени Лазо район, поселок Переяславка, Октябрьская, 48	f	large
27528	8474	625	Хабаровский край, Имени Лазо район, село Обор, Мира, 1	f	medium
27500	8446	597	Хабаровский край, Имени Лазо район, село Новостройка, Советская, 7	f	medium
27491	8437	588	Хабаровский край, Имени Лазо район, село Невельское, Центральная, 22	f	small
27481	8427	578	Хабаровский край, Имени Лазо район, поселок Мухен, Спортивная, 1	f	large
27479	8425	576	Хабаровский край, Имени Лазо район, поселок Мухен, Комсомольская, 1	f	large
27480	8426	577	Хабаровский край, Имени Лазо район, поселок Мухен, Кедровая, 4	f	medium
27488	8434	585	Хабаровский край, Имени Лазо район, село Могилевка, Советская, 25а	f	medium
27508	8454	605	Хабаровский край, Имени Лазо район, село Марусино, Набережная, 22	f	small
134598	8463	614	Хабаровский край, Имени Лазо район, село Кутузовка, Центральная, 28	t	small
27524	8470	621	Хабаровский край, Имени Лазо район, село Кругликово, Пионерская, 38	t	small
27499	8445	596	Хабаровский край, Имени Лазо район, село Кондратьевка, Центральная, 35а	t	small
27513	8459	610	Хабаровский край, Имени Лазо район, село Кия, Магазинная, 9	t	small
27489	8435	586	Хабаровский край, Имени Лазо район, село Киинск, Набережная, 29	t	small
27520	8466	617	Хабаровский край, Имени Лазо район, село Катэн, Набережная, 7	f	small
27527	8473	624	Хабаровский край, Имени Лазо район, село Золотой, Пионерская, 21	f	small
27525	8471	622	Хабаровский край, Имени Лазо район, село Зоевка, Совхозная, 4	t	small
27504	8450	601	Хабаровский край, Имени Лазо район, Екатеринославка, Новикова, 32	t	medium
27530	8476	627	Хабаровский край, Имени Лазо район, село Дурмин, Комсомольская, 12	f	medium
27498	8444	595	Хабаровский край, Имени Лазо район, село Дрофа, Центральная, 28	f	small
27518	8464	615	Хабаровский край, Имени Лазо район, село Долми, переулок Пионерский, 87	t	small
27487	8433	584	Хабаровский край, Имени Лазо район, село Гродеково, Первомайская, 14а	f	medium
27503	8449	600	Хабаровский край, Имени Лазо район, село Георгиевка, Центральная, 2	t	medium
27502	8448	599	Хабаровский край, Имени Лазо район, село Георгиевка, Центральная, 61	t	medium
27523	8469	620	Хабаровский край, Имени Лазо район, село Гвасюги, Джанси Кимонко, 1	f	small
27507	8453	604	Хабаровский край, Имени Лазо район, село Васильевка, Центральная, 9	t	small
27515	8461	612	Хабаровский край, Имени Лазо район, село Бичевая, Школьная, 51	f	medium
27497	8443	594	Хабаровский край, Имени Лазо район, поселок База-Дрофа, Комсомольская, 1	t	small
27439	8388	536	Хабаровский край, Вяземский район, село Шумный, Центральная, 3	t	small
27425	8374	522	Хабаровский край, Вяземский район, село Шереметьево, Центральная, 14а	t	medium
27431	8380	528	Хабаровский край, Вяземский район, село Отрадное, Шоссейная, 16	f	medium
27438	8387	535	Хабаровский край, Вяземский район, село Медвежий, Школьная, 8	f	small
27435	8384	532	Хабаровский край, Вяземский район, село Кукелево, Набережная, 13а	t	small
27433	8382	530	Хабаровский край, Вяземский район, село Красицкое, Центральная, 53	f	medium
27428	8377	525	Хабаровский край, Вяземский район, село Котиково, Центральная, 19а	f	small
27426	8375	523	Хабаровский край, Вяземский район, село Кедрово, Школьная, 5	t	small
27437	8386	534	Хабаровский край, Вяземский район, село Капитоновка, Центральная, 34	t	small
27432	8381	529	Хабаровский край, Вяземский район, село Забайкальское, Центральная, 14	f	small
27436	8385	533	Хабаровский край, Вяземский район, поселок Дормидонтовка, Пашина, 10	f	large
24586	73583	266	Приморский край, Владивосток, Сабанеева, 8	f	large
27434	8383	531	Хабаровский край, Вяземский район, село Дормидонтовка, Центральная, 31	f	small
27424	8373	521	Хабаровский край, Вяземский район, село Глебово, Бонивура, 19	f	small
27450	8399	547	Хабаровский край, Вяземский район, Вяземский, Шолохова, 29	f	medium
27447	8396	544	Хабаровский край, Вяземский район, Вяземский, Чехова, 40	f	large
27449	8398	546	Хабаровский край, Вяземский район, Вяземский, Театральная, 6	f	large
27442	8391	539	Хабаровский край, Вяземский район, Вяземский, Стоцкого, 81	f	medium
27441	8390	538	Хабаровский край, Вяземский район, Вяземский, Морозова, 1	f	large
27445	8394	542	Хабаровский край, Вяземский район, Вяземский, Милицейская, 68	f	large
27448	8397	545	Хабаровский край, Вяземский район, Вяземский, Котляра, 37	f	large
27446	8395	543	Хабаровский край, Вяземский район, Вяземский, Коммунистическая, 10	f	large
27444	8393	541	Хабаровский край, Вяземский район, Вяземский, Коммунистическая, 12	f	large
27443	8392	540	Хабаровский край, Вяземский район, Вяземский, Вяземская, 88	f	medium
27427	8376	524	Хабаровский край, Вяземский район, село Виноградовка, Центральная, 12	t	small
27440	8346	537	Хабаровский край, Вяземский район, село Виноградовка, Мира, 7	t	small
27423	8372	520	Хабаровский край, Вяземский район, село Видное, Центральная, 12	f	small
27429	8378	526	Хабаровский край, Вяземский район, село Венюково, Кооперативная, 15	t	small
27430	8379	527	Хабаровский край, Вяземский район, село Аван, Садовая, 10	f	medium
27412	8361	508	Хабаровский край, Верхнебуреинский район, село Этыркэн, Школьная, 9	t	medium
27414	8363	510	Хабаровский край, Верхнебуреинский район, село Эльга, Амурская, 1	f	small
27393	8341	489	Хабаровский край, Верхнебуреинский район, село Шахтинский, Центральная, 5	t	small
27413	8362	509	Хабаровский край, Верхнебуреинский район, село Чекунда, Центральная, 6	t	small
27404	8353	500	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, 12	f	medium
27400	8349	496	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Центральная, 24	f	medium
27399	8348	495	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Центральная, 39	f	large
27395	8343	491	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Ургальская, 19	f	small
27398	8347	494	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Строительная, 2	f	large
27401	8350	497	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Пионерская, 17	f	large
27396	8344	492	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Парковая, 8	f	large
27403	8352	499	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Магистральная, 24	f	medium
27402	8351	498	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Магистральная, 2	f	medium
27421	8370	517	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Лесная, 3	f	small
27419	8368	515	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, Амурская, 7	f	\N
27397	8345	493	Хабаровский край, Верхнебуреинский район, поселок Чегдомын, 60 лет Октября, 4	f	large
27415	8364	511	Хабаровский край, Верхнебуреинский район, село Ушман, Школьная, 6	t	small
27410	8359	506	Хабаровский край, Верхнебуреинский район, село Усть-Ургал, Центральная, 6	f	small
27417	8366	513	Хабаровский край, Верхнебуреинский район, поселок Тырма, Октябрьская, 12	f	large
27418	8367	514	Хабаровский край, Верхнебуреинский район, поселок Тырма, Вокзальная, 30	f	\N
27408	8357	504	Хабаровский край, Верхнебуреинский район, село Сулук, 40 лет Победы, 7	f	medium
27394	8342	490	Хабаровский край, Верхнебуреинский район, поселок Средний Ургал, Советская, 6	f	small
27392	8340	488	Хабаровский край, Верхнебуреинский район, поселок Софийск, Советская, 1	t	small
27407	8356	503	Хабаровский край, Верхнебуреинский район, село Солони, Центральная, 1	t	small
27416	8365	512	Хабаровский край, Верхнебуреинский район, село Согда, Центральная, 8	t	small
27406	8355	502	Хабаровский край, Верхнебуреинский район, поселок Новый Ургал, Донецкая, 6	f	large
27405	8354	501	Хабаровский край, Верхнебуреинский район, поселок Новый Ургал, 60 лет образования СССР, 2	f	large
27409	8358	505	Хабаровский край, Верхнебуреинский район, село Герби, Школьная, 6	t	small
27411	8360	507	Хабаровский край, Верхнебуреинский район, село Алонка, Сергея Лазо, 1	t	small
27420	8369	516	Хабаровский край, Верхнебуреинский район, село Аланап, Советская, 4А	t	small
27386	8334	482	Хабаровский край, Ванинский район, село Уська-Орочская, Киевская, 13	f	medium
27387	8335	483	Хабаровский край, Ванинский район, село Тумнин, Комсомольская,, 9	f	medium
27388	8336	484	Хабаровский край, Ванинский район, село Тулучи, Центральная, 16	f	medium
27381	8329	477	Хабаровский край, Ванинский район, село Токи, переулок Магаданский, 1	f	medium
27382	8330	478	Хабаровский край, Ванинский район, село Токи, Железнодорожная, 10	f	medium
27383	8331	479	Хабаровский край, Ванинский район, село Токи, Амурская, клуб п. Токи-2	f	small
27370	8318	466	Хабаровский край, Ванинский район, поселок Октябрьский, Центральная, 1а	f	large
27372	8320	468	Хабаровский край, Ванинский район, поселок Октябрьский, Новодорожная, 9	f	medium
27369	8317	465	Хабаровский край, Ванинский район, поселок Октябрьский, Космонавтов, 1	f	large
27371	8319	467	Хабаровский край, Ванинский район, поселок Октябрьский, Дарвина, 33	f	medium
27385	8333	481	Хабаровский край, Ванинский район, село Монгохто, Театральная, 14А	f	large
27389	8337	485	Хабаровский край, Ванинский район, село Кенада, Советская, 23	f	medium
27384	8332	480	Хабаровский край, Ванинский район, село Датта, Шуляпина, 1	f	medium
27391	8339	487	Хабаровский край, Ванинский район, поселок Высокогорный, Октябрьская, 12	f	large
27390	8338	486	Хабаровский край, Ванинский район, поселок Высокогорный, Октябрьская, 12	f	large
27373	8321	469	Хабаровский край, Ванинский район, поселок Ванино, площадь Маяковского, 1	f	large
27375	8323	471	Хабаровский край, Ванинский район, поселок Ванино, Чехова, 5	f	large
27376	8324	472	Хабаровский край, Ванинский район, поселок Ванино, Невского, 4	f	large
27379	8327	475	Хабаровский край, Ванинский район, поселок Ванино, Молодежная, 6	f	large
27378	8326	474	Хабаровский край, Ванинский район, поселок Ванино, Мира, 1	f	large
27380	8328	476	Хабаровский край, Ванинский район, поселок Ванино, Клубная, 12	f	large
27377	8325	473	Хабаровский край, Ванинский район, поселок Ванино, Киевская, 2	f	medium
27374	8322	470	Хабаровский край, Ванинский район, поселок Ванино, 2 Линия, 7	f	large
27358	8306	454	Хабаровский край, Бикинский район, село Пушкино, Кирова, 4	t	small
27355	8303	451	Хабаровский край, Бикинский район, село Покровка, Центральная, 8	f	small
27354	8287	450	Хабаровский край, Бикинский район, село Оренбургское, Мира, 18	f	medium
27359	8307	455	Хабаровский край, Бикинский район, село Лончаково, Уссурийская, 2	f	small
27356	8304	452	Хабаровский край, Бикинский район, село Лесопильное, переулок Красноармейский, 2	f	medium
27362	8310	458	Хабаровский край, Бикинский район, село Лермонтовка, Южный городок, 4	f	medium
27363	8311	459	Хабаровский край, Бикинский район, село Лермонтовка, Центральная, 16	f	medium
27361	8309	457	Хабаровский край, Бикинский район, село Лермонтовка, Пролетарская, 10	f	large
27364	8312	460	Хабаровский край, Бикинский район, село Лермонтовка, 22б	f	medium
27360	8308	456	Хабаровский край, Бикинский район, село Добролюбово, Центральная, 51	t	small
27357	8305	453	Хабаровский край, Бикинский район, село Бойцово, Центральная, 18	t	small
27352	8302	448	Хабаровский край, Бикинский район, Бикин, переулок Энергетический, 3	f	large
27353	8169	449	Хабаровский край, Бикинский район, Бикин, Фабричная, 33	f	large
27345	8295	441	Хабаровский край, Бикинский район, Бикин, Первомайская, 13	f	medium
27351	8301	447	Хабаровский край, Бикинский район, Бикин, Октябрьская, 12	f	large
27350	8300	446	Хабаровский край, Бикинский район, Бикин, Октябрьская, 10	f	medium
27341	8291	437	Хабаровский край, Бикинский район, Бикин, Набережная, 62	f	medium
27348	8298	444	Хабаровский край, Бикинский район, Бикин, Зеленая, 11а	f	medium
27349	8299	445	Хабаровский край, Бикинский район, Бикин, Зачеславского, 30	f	medium
27344	8294	440	Хабаровский край, Бикинский район, Бикин, Железнодорожная, 11	f	medium
27343	8293	439	Хабаровский край, Бикинский район, Бикин, Дзержинского, 3	f	medium
27342	8292	438	Хабаровский край, Бикинский район, Бикин, Дзержинского, 60	f	medium
27347	8297	443	Хабаровский край, Бикинский район, Бикин, Восточный городок, Здание школы № 3	f	large
27346	8296	442	Хабаровский край, Бикинский район, Бикин, Восточный городок, Здание Дома офицеров	f	large
27368	8316	464	Хабаровский край, Аяно-Майский район, с.Нелькан, Советская, 9а	f	medium
27367	8315	463	Хабаровский край, Аяно-Майский район, Джигда, Совхозная, 2	t	small
27366	8314	462	Хабаровский край, Аяно-Майский район, Аян, Советская, 8	f	medium
27365	8313	461	Хабаровский край, Аяно-Майский район, Аим, 40 Лет Победы, 8	t	small
27320	8269	416	Хабаровский край, Амурский район, станция Мылки, Вокзальная, 1	f	small
27321	8270	417	Хабаровский край, Амурский район, поселок Эльбан, Школьная, 27а	f	large
27326	8275	422	Хабаровский край, Амурский район, поселок Эльбан, Центральная, 18	f	large
27325	8274	421	Хабаровский край, Амурский район, поселок Эльбан, Микрорайон 2, 28	f	large
27324	8273	420	Хабаровский край, Амурский район, поселок Эльбан, Микрорайон 2, 9а	f	large
27323	8272	419	Хабаровский край, Амурский район, поселок Эльбан, Микрорайон 2, 12	f	large
27322	8271	418	Хабаровский край, Амурский район, поселок Эльбан, Микрорайон 1, 26а	f	large
27340	8290	436	Хабаровский край, Амурский район, село Форель, Школьная, 7	f	small
27327	8276	423	Хабаровский край, Амурский район, село Тейсин, клуб "Факел"	f	medium
27337	8286	433	Хабаровский край, Амурский район, село Сельгон, здание станции Сельгон	t	small
27336	8285	432	Хабаровский край, Амурский район, село Санболи, Молодежная, 1	f	medium
27330	8279	426	Хабаровский край, Амурский район, село Падали, Станционная, 26	t	small
27328	8277	424	Хабаровский край, Амурский район, село Омми, Центральная, 7	t	small
27331	8280	427	Хабаровский край, Амурский район, село Малмыж, переулок Пионерский, 2	t	small
27338	8288	434	Хабаровский край, Амурский район, поселок Литовко, Таежная, 12	f	large
27339	8289	435	Хабаровский край, Амурский район, село Лесной, Горная, 1	t	small
27329	8278	425	Хабаровский край, Амурский район, село Известковый, Центральная, 14а	f	large
27335	8284	431	Хабаровский край, Амурский район, село Джуен, Центральная, 6	f	small
27298	8249	394	Хабаровский край, Амурский район, село Голубичное, дом дежурной по станции Коробко Е.Ю	t	small
27332	8281	428	Хабаровский край, Амурский район, село Вознесенское, Шерого, 30а	f	large
27334	8283	430	Хабаровский край, Амурский район, село Болонь, Вокзальная, 15	f	medium
27333	8282	429	Хабаровский край, Амурский район, село Ачан, Советская, 23	t	small
27318	8268	414	Хабаровский край, Амурский район, Амурск, проспект Строителей, 47	f	large
27312	8263	408	Хабаровский край, Амурский район, Амурск, проспект Строителей, 35	f	large
27310	8261	406	Хабаровский край, Амурский район, Амурск, проспект Строителей, 16	f	large
27308	8259	404	Хабаровский край, Амурский район, Амурск, проспект Строителей, 11	f	large
27307	8258	403	Хабаровский край, Амурский район, Амурск, проспект Победы, 14а	f	large
27315	8265	411	Хабаровский край, Амурский район, Амурск, проспект Октябрьский, 22	f	large
27311	8262	407	Хабаровский край, Амурский район, Амурск, проспект Октябрьский, 2а	f	large
27309	8260	405	Хабаровский край, Амурский район, Амурск, проспект Мира, 46а	f	large
27302	8253	398	Хабаровский край, Амурский район, Амурск, проспект Мира, 22а	f	large
27305	8128	401	Хабаровский край, Амурский район, Амурск, проспект Мира, 40	f	large
27317	8267	413	Хабаровский край, Амурский район, Амурск, проспект Комсомольский, 81А	f	large
27316	8266	412	Хабаровский край, Амурский район, Амурск, проспект Комсомольский, 63	f	large
27313	8264	409	Хабаровский край, Амурский район, Амурск, проспект Комсомольский, 47	f	large
27304	8255	400	Хабаровский край, Амурский район, Амурск, проспект Комсомольский, 7а	f	large
27303	8254	399	Хабаровский край, Амурский район, Амурск, проспект Комсомольский, 42	f	large
27299	8250	395	Хабаровский край, Амурский район, Амурск, Школьная, 9	f	large
27301	8252	397	Хабаровский край, Амурский район, Амурск, Лесная, 3а	f	large
27306	8257	402	Хабаровский край, Амурский район, Амурск, Комсомольский, 48	f	large
27300	8251	396	Хабаровский край, Амурский район, Амурск, Амурская, 5	f	large
120858	85523	279	Сахалинская область, с. Головнино, Нагорная, Дом культуры	f	small
120853	85518	274	Сахалинская область, пгт.Южно-Курильск, пл.Ленина,  1, актовый зал администрации МО	f	large
120866	85591	346	Сахалинская область, Южно-Сахалинск, Детский сад №29 Василек	f	medium
72606	85548	303	Сахалинская область, Южно-Сахалинск, Курильская, 54, СОШ №5	f	large
120865	85590	345	Сахалинская область, Южно-Сахалинск, село Новая Деревня, Красный уголок ГУСП Крмсомолец	f	small
72620	85562	317	Сахалинская область, Южно-Сахалинск, проспект Победы, 80, Гимназия №2	f	large
72619	85561	316	Сахалинская область, Южно-Сахалинск, проспект Победы, 68, Филиал РГТЭУ	f	large
120870	85596	351	Сахалинская область, Южно-Сахалинск, проспект Мира, 379, Дом-интернат для престарелых	f	small
120869	85595	350	Сахалинская область, Южно-Сахалинск, проспект Мира, 1, Психоневрологический интернат	f	small
72654	85582	337	Сахалинская область, Южно-Сахалинск, проспект Мира, 428 А, Медицинский колледж	f	large
72639	85580	336	Сахалинская область, Южно-Сахалинск, проспект Мира, 426, ОАО Дальморнефтегеофизика	f	large
72635	85576	332	Сахалинская область, Южно-Сахалинск, проспект Мира, 424, ООО Сахалин-Шельф-Сервис	f	large
72609	85551	306	Сахалинская область, Южно-Сахалинск, проспект Мира, 107, АУ ПТУ Сахалинской области	f	large
72608	85550	305	Сахалинская область, Южно-Сахалинск, проспект Мира, 103, СОШ №13	f	large
72598	85536	293	Сахалинская область, Южно-Сахалинск, проспект Мира, 83, ДК Родина	f	large
72596	85534	291	Сахалинская область, Южно-Сахалинск, проспект Мира, 17, Молочный комбинат	f	large
120878	85605	360	Сахалинская область, Южно-Сахалинск, площадь район Хомутово, ФГУП Аэропорт Южно-Сахалинск	f	small
72588	85526	283	Сахалинская область, Южно-Сахалинск, переулок Железнодорожный, 12а, СОШ №32	f	large
72587	85526	282	Сахалинская область, Южно-Сахалинск, переулок Железнодорожный, 12а, СОШ №32	f	large
72600	85538	295	Сахалинская область, Южно-Сахалинск, пер.Мартовский, 8б, МОУ Кадетская школа	f	large
72592	85530	287	Сахалинская область, Южно-Сахалинск, им. В.Гайдука, 1, Библиотека филлиал №18	f	large
120863	85587	342	Сахалинская область, Южно-Сахалинск, жилой квартал Весточка, Дом культуры Электрон	f	small
120868	85594	349	Сахалинская область, Южно-Сахалинск, Центральная, 12, Старорусский дом культуры	t	small
72617	85559	314	Сахалинская область, Южно-Сахалинск, Хабаровская, 78, Областная библиотека	f	large
72646	85602	357	Сахалинская область, Южно-Сахалинск, Усадебная, 12, Детский сад №32 Буратино	f	large
72599	85537	294	Сахалинская область, Южно-Сахалинск, Украинская, 112, Центр агрохимслужбы	f	large
72595	85533	290	Сахалинская область, Южно-Сахалинск, Украинская, 17б, Библиотека-центр досуга	f	large
72594	85532	289	Сахалинская область, Южно-Сахалинск, Украинская, 11, ООО ЖЭУ №14	f	large
72611	85553	308	Сахалинская область, Южно-Сахалинск, Тихоокеанская, 18, СОШ №23	f	large
72589	85527	284	Сахалинская область, Южно-Сахалинск, Советская, 78, Детская школа искусств №4	f	large
120877	85604	359	Сахалинская область, Южно-Сахалинск, Северный городок, Общежитие Северного городка	f	medium
72602	85542	298	Сахалинская область, Южно-Сахалинск, Северная, 32, СОШ №9	f	large
120861	85544	299	Сахалинская область, Южно-Сахалинск, Сахалинская, 106а, ООО Старыйдом-ЖЭУ -5	f	medium
72597	85535	292	Сахалинская область, Южно-Сахалинск, Садовая, 5, СОШ №4	f	large
72630	85571	327	Сахалинская область, Южно-Сахалинск, Пуркаева, 78а, СОШ №22	f	large
72612	85554	309	Сахалинская область, Южно-Сахалинск, Поповича, 20а, Молодежно-подростковый центр	f	large
72632	85573	329	Сахалинская область, Южно-Сахалинск, Пограничная, 5, Профессиональный лицей №2	f	large
72628	85569	325	Сахалинская область, Южно-Сахалинск, Пограничная, 45, ОАО Сахалинавтотранс	f	large
72625	85567	322	Сахалинская область, Южно-Сахалинск, Пограничная, 18, СОШ №8	f	large
72624	85566	321	Сахалинская область, Южно-Сахалинск, Пограничная, 48, СОШ №3	f	large
72627	85482	324	Сахалинская область, Южно-Сахалинск, Пограничная, 68, СахГУ	f	large
72590	85528	285	Сахалинская область, Южно-Сахалинск, Науки, 5, Мол.-подростковый центр Южный	f	large
72641	85584	339	Сахалинская область, Южно-Сахалинск, Ленина, 266а, Центр воспитательной работы	f	large
72640	85583	338	Сахалинская область, Южно-Сахалинск, Ленина, 467а, Детский сад №3	f	large
72623	85565	320	Сахалинская область, Южно-Сахалинск, Ленина, 303а, СОШ №16	f	large
72622	85564	319	Сахалинская область, Южно-Сахалинск, Ленина, 290, Главный корпус СахГУ	f	large
72621	85563	318	Сахалинская область, Южно-Сахалинск, Ленина, 284, Педагогический колледж СахГУ	f	large
72601	85539	296	Сахалинская область, Южно-Сахалинск, Ленина, 111, Институт развития образования	f	large
120867	85593	348	Сахалинская область, Южно-Сахалинск, Крайняя, 8а, Дом культуры Родник	f	medium
72638	85579	335	Сахалинская область, Южно-Сахалинск, Комсомольская, 308, СОШ №6	f	large
72637	85578	334	Сахалинская область, Южно-Сахалинск, Комсомольская, 300, СОШ №26	f	large
72636	85577	333	Сахалинская область, Южно-Сахалинск, Комсомольская, 300б, ООО УК ЖЭУ №10	f	large
72634	85575	331	Сахалинская область, Южно-Сахалинск, Комсомольская, 276, ООО ЖЭУ-9	f	large
72614	85556	311	Сахалинская область, Южно-Сахалинск, Комсомольская, 191а, Лицей №1	f	large
72615	85557	312	Сахалинская область, Южно-Сахалинск, Коммунистический проспект, 33, Институт экономики СахГУ	f	large
72610	85552	307	Сахалинская область, Южно-Сахалинск, Коммунистический проспект, 20, Дворец детского творчества	f	large
72645	85592	347	Сахалинская область, Южно-Сахалинск, Коммунистическая, 49, СОШ №18	f	large
72593	85531	288	Сахалинская область, Южно-Сахалинск, Комарова, 5, Городская поликлиника №5	f	large
72604	85546	301	Сахалинская область, Южно-Сахалинск, Железнодорожная, 65, Депо подвижного сотава ОАО РЖД	f	large
72631	85572	328	Сахалинская область, Южно-Сахалинск, Емельянова, 19а, СОШ №21	f	large
72629	85570	326	Сахалинская область, Южно-Сахалинск, Емельянова, 35, Гимназия №1 им А.С.Пушкина	f	large
72591	85529	286	Сахалинская область, Южно-Сахалинск, Дружбы, 75, ГУСП Комсомолец	f	large
72653	85541	297	Сахалинская область, Южно-Сахалинск, Достоевского, 2А, ООО Сахалинская механизированная колонна	f	large
72603	85545	300	Сахалинская область, Южно-Сахалинск, Деповская, 42, Училище №17	f	large
72633	85574	330	Сахалинская область, Южно-Сахалинск, Горького, 25, СКБ САМИ ДО РАН	f	large
72626	85568	323	Сахалинская область, Южно-Сахалинск, Горького, 26, Колледж бизнеса и информатики	f	large
72613	85555	310	Сахалинская область, Южно-Сахалинск, Горького, 7/1, Детская спортивная школа	f	large
72605	85547	302	Сахалинская область, Южно-Сахалинск, Вокзальная, 55, Дом культуры железнодорожников	f	large
72616	85558	313	Сахалинская область, Южно-Сахалинск, Антона Буюклы, 14, НОШ №7	f	large
72618	85560	315	Сахалинская область, Южно-Сахалинск, Амурская,, 121, СОШ №1	f	large
72643	85586	341	Сахалинская область, Южно-Сахалинск, 2-я Центральная, 39, Отдел по упралению территорией	f	large
72642	85585	340	Сахалинская область, Южно-Сахалинск, 2-я Центральная, 33, МУЗ Амбулатория Хомутово	f	large
72586	85525	281	Сахалинская область, Южно-Сахалинск, 2-я Красносельская, 14а, ДК Радуга	f	large
72607	95024	304	Сахалинская область, Южно-Сахалинск, Чехова, 4А, МБУ Молодежно-подростковый центр Южны, Шахматный клуб	f	large
72566	85485	228	Сахалинская область, Углегорск, Победы, 142	f	large
72565	85484	227	Сахалинская область, Углегорск, Заводская, 8	f	large
120804	85427	160	Сахалинская область, Северо-Курильск, Парковая, 6, Дом культуры	f	large
72545	85414	146	Сахалинская область, Поронайск, Октябрьская, 31	f	large
72543	85412	144	Сахалинская область, Поронайск, Октябрьская, 63	f	large
72541	85410	142	Сахалинская область, Поронайск, 2-я Восточная, 29	f	large
120744	85302	24	Сахалинская область, Петропавловское, Клубная, 15	f	small
120793	85407	134	Сахалинская область, Оха, ООО Сахалинский аропорт Оха	f	small
120788	85398	126	Сахалинская область, Оха, Школьная, 15	f	small
120787	85398	125	Сахалинская область, Оха, Школьная, 15	f	medium
72531	85392	119	Сахалинская область, Оха, Ленина, 24	f	large
72530	85391	118	Сахалинская область, Оха, Карла Маркса, 26/1	f	large
72528	85378	116	Сахалинская область, Оха, 50 лет Октября, 25/2	f	large
72516	85366	91	Сахалинская область, Макаров, Милютина, 3	f	large
120771	85359	83	Сахалинская область, Курильск, Андрея Евдокимова, 17, районный Дом культуры	f	large
72502	85345	68	Сахалинская область, Корсаков, Овражная, 8	f	large
72507	85350	73	Сахалинская область, Корсаков, Краснофлотская, 1	f	large
72512	85356	78	Сахалинская область, Корсаков, Восточная, 29	f	large
120855	85520	276	Сахалинская область, Горячий Пляж, клуб Службы в р.п. Южно-Курильске	t	medium
72489	85310	32	Сахалинская область, Анива, Ленина, 6	f	large
72487	85308	30	Сахалинская область, Анива, Калинина, 52	f	large
120879	85543	361	Сахалинская область, Анива, Заречная, 2	f	small
120738	85291	10	Сахалинская область, Александровск-Сахалинский, Цапко, 43	f	medium
72557	85468	212	Сахалинская область, Тымовский район, село Ясное, Титова, 2	f	large
72644	85588	343	Сахалинская область, городской округ Южно-Сахалинск, село Дальнее, Новая, 20, Дальненский дом культуры	f	large
120859	85524	280	Сахалинская область, Южно-Курильский район, с.Малокурильское, морбригада	t	medium
120856	85521	277	Сахалинская область, Южно-Курильский район, с. Крабозаводское, Торговая, Д/к Утро Родины	f	medium
120850	85502	249	Сахалинская область, Холмский район, село Яблочный, Центральная, 16	f	small
72572	85501	248	Сахалинская область, Холмский район, село Яблочный, Центральная, 52	f	large
120849	85500	247	Сахалинская область, Холмский район, село Яблочный, Зеленая, 24	f	small
72569	85496	241	Сахалинская область, Холмский район, село Чехов, переулок Бумажный, 6	f	large
72570	85497	243	Сахалинская область, Холмский район, село Чехов, Ленина, 54	f	large
72585	85517	271	Сахалинская область, Холмский район, село Чапланово, Речная, 26а	f	large
72581	85513	264	Сахалинская область, Холмский район, Холмск, пл.Ленина, 3	f	large
72582	85514	265	Сахалинская область, Холмский район, Холмск, Школьная, 33	f	large
72576	85508	257	Сахалинская область, Холмский район, Холмск, Советская, 124	f	large
72579	85511	261	Сахалинская область, Холмский район, Холмск, Победы, 12	f	large
120851	85503	250	Сахалинская область, Холмский район, Холмск, Переселенческая, 2	f	small
72578	85510	260	Сахалинская область, Холмский район, Холмск, Первомайская, 7	f	large
72577	85509	259	Сахалинская область, Холмский район, Холмск, Морская, 14	f	large
72575	85507	256	Сахалинская область, Холмский район, Холмск, Матросова, 2	f	large
120852	85506	254	Сахалинская область, Холмский район, Холмск, Макарова, 1	f	medium
72574	85505	253	Сахалинская область, Холмский район, Холмск, Крузенштерна, 2	f	large
72573	85504	251	Сахалинская область, Холмский район, Холмск, Крузенштерна, 7	f	large
72583	85515	266	Сахалинская область, Холмский район, Холмск, Комсомольская, 6	f	large
72580	85512	262	Сахалинская область, Холмский район, Холмск, Капитанская, 10	f	large
72584	85516	269	Сахалинская область, Холмский район, село Правда, Центральная, 27	f	large
120848	85499	245	Сахалинская область, Холмский район, село Пионеры, Школьная, 3	f	small
120847	85495	240	Сахалинская область, Холмский район, село Новосибирское, Новосибирское, 60	t	small
72571	85498	244	Сахалинская область, Холмский район, село Костромское, Центральная, 1	f	large
120845	85494	238	Сахалинская область, Углегорский район, с.Поречье, помещение МБОУ СОШ с.Поречье	f	small
120838	85475	218	Сахалинская область, Углегорский район, Шахтерск, Победы, 1	f	medium
72562	85481	223	Сахалинская область, Углегорский район, Шахтерск, Мира, 8	f	large
72563	85480	224	Сахалинская область, Углегорский район, Шахтерск, Мира, 15А	f	large
72561	85480	222	Сахалинская область, Углегорский район, Шахтерск, Мира, 15А	f	large
72560	85479	221	Сахалинская область, Углегорский район, Шахтерск, Мира, 8А	f	large
72558	85477	219	Сахалинская область, Углегорский район, Шахтерск, Ленина, 12	f	large
72559	85478	220	Сахалинская область, Углегорский район, Шахтерск, Коммунистическая, 1А	f	large
120840	85488	231	Сахалинская область, Углегорский район, Углегорск, Угольная, 7 А	f	small
72568	85489	232	Сахалинская область, Углегорский район, Углегорск, Приморская, 35	f	large
72567	85486	229	Сахалинская область, Углегорский район, Углегорск, Победы, 153 А	f	large
72564	85483	226	Сахалинская область, Углегорский район, Углегорск, Победы, 238	f	large
120839	85487	230	Сахалинская область, Углегорский район, Углегорск, Войтинского, 22	f	medium
120836	85474	217	Сахалинская область, Углегорский район, село Тельновский, Советская, 125	t	small
120846	85469	239	Сахалинская область, Углегорский район, село Ольшанка	f	small
120844	85493	237	Сахалинская область, Углегорский район, село Ольховка, Центральная, 16	f	small
120843	85492	236	Сахалинская область, Углегорский район, село Никольское	f	small
120841	85490	234	Сахалинская область, Углегорский район, село Медвежье, Есенина, 4	f	small
120835	85473	216	Сахалинская область, Углегорский район, село Лесогорское, Пионерская , 11, помещение администрации	f	small
120842	85491	235	Сахалинская область, Углегорский район, село Краснополье, Новая, 1	f	medium
120834	85472	215	Сахалинская область, Углегорский район, село Бошняково, Советская, 5	f	medium
120833	85471	214	Сахалинская область, Углегорский район, село Бошняково, Заводская, 5	f	small
120823	85454	194	Сахалинская область, Тымовский район, село Чир-Унвд, Советская, 7	f	small
72553	85459	201	Сахалинская область, Тымовский район, поселок Тымовское, Харитонова, 14	f	large
72555	85462	204	Сахалинская область, Тымовский район, поселок Тымовское, Торговая, 9	f	large
120827	85461	203	Сахалинская область, Тымовский район, Тымовское, Советская, 4	f	medium
72556	85463	206	Сахалинская область, Тымовский район, поселок Тымовское, Криворучко, 21	f	large
72554	85460	202	Сахалинская область, Тымовский район, поселок Тымовское, Кировская, 68-А	f	large
120825	85457	198	Сахалинская область, Тымовский район, село Молодежное, Советская, 16	f	medium
120857	85522	278	Сахалинская область, Тымовский район, Малокурильское, ДК Океан	f	medium
120829	85465	209	Сахалинская область, Тымовский район, село Красная Тымь, Новая, 1	f	medium
120830	85466	210	Сахалинская область, Тымовский район, село Кировское, Центральная, 73	f	medium
120831	85467	211	Сахалинская область, Тымовский район, Зональное, Школьная, 12	f	small
120828	85464	207	Сахалинская область, Тымовский район, село Восход, Космическая, 13	f	medium
120826	85458	199	Сахалинская область, Тымовский район, село Воскресеновка, Школьная, 9	f	medium
120832	85470	213	Сахалинская область, Тымовский район, село Белоречье, Советская, 8	t	small
120822	85453	192	Сахалинская область, Тымовский район, село Арги-Паги, Комсомольская, 1	f	medium
120824	85456	196	Сахалинская область, Тымовский район, село Адо-Тымово, Советская, 3	f	small
120820	85449	184	Сахалинская область, Томаринский район, село Черемшанка, Ленина, 12	f	small
72552	85452	188	Сахалинская область, Томаринский район, Томари, Новая, 1	f	large
120821	85450	185	Сахалинская область, Томаринский район, Томари, Калинина, 35	f	medium
72551	85451	187	Сахалинская область, Томаринский район, Томари, А.Буюклы, 4а	f	large
120819	85448	183	Сахалинская область, Томаринский район, село Пензенское, Вокзальная, 4	f	small
120816	85445	180	Сахалинская область, Томаринский район, село Парусное, Центральная, 3	f	small
72652	85441	177	Сахалинская область, Томаринский район, село Красногорск, Победы, 17	f	large
120815	85444	179	Сахалинская область, Томаринский район, село Красногорск, Карла Маркса, 31	f	medium
120814	85443	178	Сахалинская область, Томаринский район, село Красногорск, Карла Маркса, 38	f	medium
120817	85446	181	Сахалинская область, Томаринский район, село Ильинский, пер.Гвардейский, 15	f	small
120818	85447	182	Сахалинская область, Томаринский район, село Ильинский, Ломоносова, 8а	f	small
120809	85435	169	Сахалинская область, Смирныховский район, поселок Смирных, Центральная, 46	f	medium
120808	85434	168	Сахалинская область, Смирныховский район, поселок Смирных, Торговая, 22	f	small
72550	85437	171	Сахалинская область, Смирныховский район, поселок Смирных, Маяковского, 9	f	large
72549	85436	170	Сахалинская область, Смирныховский район, поселок Смирных, 8 марта, 32	f	large
120805	85429	164	Сахалинская область, Смирныховский район, село Рощино, Парковая, 9	f	small
72548	85432	166	Сахалинская область, Смирныховский район, село Победино, Центральная, 60	f	large
120806	85431	165	Сахалинская область, Смирныховский район, село Первомайск, Суворова, 1	f	medium
72547	85428	163	Сахалинская область, Смирныховский район, село Онор, Транспортная, 2	f	large
120811	85439	173	Сахалинская область, Смирныховский район, село Буюклы, Школьная	f	medium
120810	85438	172	Сахалинская область, Смирныховский район, село Буюклы, Космонавтов	f	medium
120798	85421	152	Сахалинская область, Поронайский район, село Тихменево, Ленина, 44	f	small
120794	85415	147	Сахалинская область, Поронайский район, Поронайск, проспект А.Буюклы, 2	f	medium
120795	85416	148	Сахалинская область, Поронайский район, Поронайск, Торфяная, 23	f	small
72540	85409	141	Сахалинская область, Поронайский район, Поронайск, Победы, 72	f	large
72539	85408	140	Сахалинская область, Поронайский район, Поронайск, Победы, 72	f	large
72544	85413	145	Сахалинская область, Поронайский район, Поронайск, Октябрьская, 76	f	large
72542	85411	143	Сахалинская область, Поронайский район, Поронайск, Гагарина, 38	f	large
120802	85425	157	Сахалинская область, Поронайский район, село Малиновка, Школьная, 14	f	small
120800	85423	154	Сахалинская область, Поронайский район, село Майское, Ленина, 9	f	small
10984	84491	748	Республика Саха (Якутия), Якутск, Пионерская, 9	f	large
120799	85422	153	Сахалинская область, Поронайский район, село Леонидово, Калинина, 16	f	medium
120801	85424	155	Сахалинская область, Поронайский район, село Забайкалец, Советская, 8	f	small
120797	85420	151	Сахалинская область, Поронайский район, село Гастелло, Центральная, 54	f	medium
72546	85419	150	Сахалинская область, Поронайский район, село Восток, Гагарина, 10а	f	large
72651	85418	149	Сахалинская область, Поронайский район, поселок Вахрушев, Центральная, 99Б	f	large
72537	85402	130	Сахалинская область, Охинский район, село Тунгор, Нефтяников, 17	f	large
72536	85397	124	Сахалинская область, Охинский район, Оха, Советская, 26	f	large
72534	85395	122	Сахалинская область, Охинский район, Оха, Советская, 1	f	large
72532	85393	120	Сахалинская область, Охинский район, Оха, Победы, 6	f	large
72538	85406	133	Сахалинская область, Охинский район, Оха, Карла Маркса, 54/1	f	large
72533	85394	121	Сахалинская область, Охинский район, Оха, Карла Маркса, 14А	f	large
72535	85396	123	Сахалинская область, Охинский район, Оха, Дзержинского, 17/1	f	large
72529	85325	117	Сахалинская область, Охинский район, Оха, 60 лет СССР, 32/1	f	large
120791	85403	131	Сахалинская область, Охинский район, село Некрасовка, Октябрьская, 1	f	medium
120792	85405	132	Сахалинская область, Охинский район, село Москальво, Советская, 3	f	small
120880	85400	128	Сахалинская область, Охинский район, Лагури, Ленина, 53, ООО Управдом Лагури	t	small
120790	85401	129	Сахалинская область, Охинский район, село Восточный, Школьная, 11А	f	medium
120786	85390	115	Сахалинская область, Ногликский район, село Ныш, Советская, 11	f	medium
120783	85383	109	Сахалинская область, Ногликский район, поселок Ноглики, Штернберга, 4а, филиал Тымовского лицея №7	f	medium
72527	85388	113	Сахалинская область, Ногликский район, поселок Ноглики, Советская, 60	f	large
72526	85387	112	Сахалинская область, Ногликский район, поселок Ноглики, Советская, 41	f	large
72650	85386	111	Сахалинская область, Ногликский район, поселок Ноглики, Пограничная, 11А, Районный Центр Досуга	f	large
72525	85384	110	Сахалинская область, Ногликский район, поселок Ноглики, Мостовая, 8, НГУП Дорожник	f	large
120785	85389	114	Сахалинская область, Ногликский район, село Катангли, Советская, 9	f	small
120772	85360	84	Сахалинская область, Ногликский район, село Горячие Ключи, Средняя общеобразовательная школа	f	large
72524	85382	108	Сахалинская область, Ногликский район, Вал, Комсомольская, 2	f	large
120779	85370	94	Сахалинская область, Невельский район, село Ясноморский, Заречная, 35	t	small
120782	85380	106	Сахалинская область, Невельский район, село Шебунино, Дачная, 4А	f	medium
72518	85372	96	Сахалинская область, Невельский район, Невельск, Школьная, 42	f	large
72523	85381	107	Сахалинская область, Невельский район, Невельск, Приморская, 53	f	large
72517	85371	95	Сахалинская область, Невельский район, Невельск, Победы, 2	f	large
72519	85373	97	Сахалинская область, Невельский район, Невельск, Ленина, 56А	f	large
72520	85374	101	Сахалинская область, Невельский район, Невельск, Гоголя, 5	f	large
120780	85375	102	Сахалинская область, Невельский район, село Колхозное, Гагарина, 35	f	small
72522	85379	105	Сахалинская область, Невельский район, Горнозаводск, Советская, 7	f	large
120781	85377	104	Сахалинская область, Невельский район, село Горнозаводск, Советская, 33	f	medium
72521	85376	103	Сахалинская область, Невельский район, село Горнозаводск, Клубная, 10	f	large
120775	85363	88	Сахалинская область, Макаровский район, село Поречье, Школьная, 8	f	small
120776	85367	92	Сахалинская область, Макаровский район, село Новое, Центральная, 22	f	medium
72515	85365	90	Сахалинская область, Макаровский район, Макаров, 50 лет Октября, 32	f	large
72514	85364	89	Сахалинская область, Макаровский район, Макаров, 50 лет Октября, 9 А	f	large
120773	85361	85	Сахалинская область, Макаровский район, село Горное, Средняя общеобразовательная школа с. Буревестник	f	medium
120777	85368	93	Сахалинская область, Макаровский район, село Горное, Шахтерская, 51	f	small
120774	85362	87	Сахалинская область, Макаровский район, село Восточный, Привокзальная, 8	f	small
120770	85358	82	Сахалинская область, Курильский район, село Рейдово, Мира, 7, сельский Дом культуры	f	medium
120762	85336	58	Сахалинская область, Корсаковский район, село Чапаево, Школьная, 18	f	medium
120766	85340	63	Сахалинская область, Корсаковский район, село Третья Падь	f	small
120765	85339	62	Сахалинская область, Корсаковский район, село Соловьевка, Центральная, 24	f	medium
120763	85337	59	Сахалинская область, Корсаковский район, село Раздольное, Школьная, 1	f	small
120759	85332	54	Сахалинская область, Корсаковский район, Пихтовый, Крутая, 3	t	small
120760	85334	56	Сахалинская область, Корсаковский район, село Охотское, Центральная, 14	f	small
72500	85333	55	Сахалинская область, Корсаковский район, Озерский, Центральная, 57в	f	large
120758	85331	53	Сахалинская область, Корсаковский район, село Новиково, Советская, 32	f	medium
120761	85335	57	Сахалинская область, Корсаковский район, село Лесное, Морская, 39	t	small
72509	85352	75	Сахалинская область, Корсаковский район, Корсаков, Советская, 14	f	large
120769	85344	67	Сахалинская область, Корсаковский район, Корсаков, Портовая, 10	f	small
72508	85351	74	Сахалинская область, Корсаковский район, Корсаков, Подгорная, 41	f	large
72511	85355	77	Сахалинская область, Корсаковский район, Корсаков, Первомайская, 40а	f	large
72503	85346	69	Сахалинская область, Корсаковский район, Корсаков, Окружная, 49	f	large
72501	85343	66	Сахалинская область, Корсаковский район, Корсаков, Окружная, 118а	f	large
72504	85347	70	Сахалинская область, Корсаковский район, Корсаков, Невельская, 11	f	large
72513	85357	79	Сахалинская область, Корсаковский район, Корсаков, Морская, 12	f	large
72506	85349	72	Сахалинская область, Корсаковский район, Корсаков, Молодежный, 7	f	large
72510	85354	76	Сахалинская область, Корсаковский район, Корсаков, Корсаковская, 16	f	large
72505	85348	71	Сахалинская область, Корсаковский район, Корсаков, Зеленая, 7/1	f	large
120768	85342	65	Сахалинская область, Корсаковский район, Корсаков, Железнодорожная, 1	f	medium
120764	85338	61	Сахалинская область, Корсаковский район, село Дачное	f	medium
120767	85341	64	Сахалинская область, Корсаковский район, село Вторая Падь	f	small
72497	85328	47	Сахалинская область, Долинский район, село Углезаводск, Ленина, 16	f	large
72490	85315	36	Сахалинская область, Долинский район, село Стародубское, Набережная, 19а	f	large
72496	85326	45	Сахалинская область, Долинский район, село Сокол, Совхозная, 26	f	large
72649	85324	44	Сахалинская область, Долинский район, село Сокол, Лесная, 45	f	large
120752	85314	35	Сахалинская область, Долинский район, село Советское, Центральная, 127, СОШ с.Советское	f	medium
120757	95023	46	Сахалинская область, Долинский район, село Покровка, Березовая, 10	f	medium
72495	85320	41	Сахалинская область, Долинский район, Долинск, Хабаровская, 13	f	large
120755	85322	43	Сахалинская область, Долинский район, Долинск, Советская, 13-а	f	medium
72494	85319	40	Сахалинская область, Долинский район, Долинск, Октябрьская, 7а	f	large
72493	85318	39	Сахалинская область, Долинский район, Долинск, Ленина, 31	f	large
72492	85317	38	Сахалинская область, Долинский район, Долинск, Комсомольская, 25	f	large
72491	85316	37	Сахалинская область, Долинский район, Долинск, Владивостокская, 21	f	large
120751	85312	34	Сахалинская область, Долинский район, село Взморье, Пионерская, 15	f	medium
72499	85330	49	Сахалинская область, Долинский район, Быков, Шахтерская, 15	f	large
72498	85329	48	Сахалинская область, Долинский район, Быков, Шахтерская, 13	f	large
120742	85300	22	Сахалинская область, Анивский район, село Успенское, переулок Почтовый, 2	f	small
72486	85297	19	Сахалинская область, Анивский район, село Троицкое, Центральная, 16а	f	large
72647	85606	362	Сахалинская область, Анивский район, село Троицкое, Советская, 13	f	large
120746	85304	26	Сахалинская область, Анивский район, село Троицкое, Невельская, 13	f	medium
120747	85305	27	Сахалинская область, Анивский район, село Таранай, Лесная, 18	f	medium
120745	85303	25	Сахалинская область, Анивский район, село Рыбацкое, Береговая, 5	f	small
120748	85306	28	Сахалинская область, Анивский район, село Огоньки, Школьная, 18	f	small
120740	85298	20	Сахалинская область, Анивский район, село Новотроицкое, Центральная, 25а	f	small
120741	85299	21	Сахалинская область, Анивский район, село Мицулевка, Рабочая, 11	f	small
120864	85589	344	Сахалинская область, Анивский район, село Ключи, Советская, 22, Дом культуры Ключи	f	small
120749	85307	29	Сахалинская область, Анивский район, село Высокое, Луговая, 9	f	small
120743	85301	23	Сахалинская область, Анивский район, село Воскресенское, Новая, 1а	f	small
72648	85607	363	Сахалинская область, Анивский район, Анива, Победы, 60	f	large
72488	85309	31	Сахалинская область, Анивский район, Анива, Ленина, 16	f	large
120750	85311	33	Сахалинская область, Анивский район, Анива, им. Пудова, 79	f	small
120735	85288	7	Сахалинская область, Александровск-Сахалинский район, село Михайловка, Бугайского, 2	f	small
72481	85286	5	Сахалинская область, Александровск-Сахалинский район, село Мгачи, Советская, 36А	f	large
120733	85285	4	Сахалинская область, Александровск-Сахалинский район, село Мангидай, переулок Школьный, 1	f	small
120736	85289	8	Сахалинская область, Александровск-Сахалинский район, село Дуэ, Чехова, 114	t	small
120734	85287	6	Сахалинская область, Александровск-Сахалинский район, село Арково, Советская, 16	f	small
72484	85294	13	Сахалинская область, Александровск-Сахалинский район, Александровск-Сахалинский, Советская, 1	f	large
72482	85292	11	Сахалинская область, Александровск-Сахалинский район, Александровск-Сахалинский, Советская, 58, помещение колледжа	f	large
72485	85295	14	Сахалинская область, Александровск-Сахалинский район, Александровск-Сахалинский, Кирова, 44А	f	large
72483	85293	12	Сахалинская область, Александровск-Сахалинский район, Александровск-Сахалинский, Дальневосточная, 3	f	large
120737	85290	9	Сахалинская область, Александровск-Сахалинский район, Александровск-Сахалинский, Аболтина, 19	f	small
10374	84675	138	Республика Саха (Якутия), с.Черюмча, Центральная, 2/2	t	small
120715	85118	601	Республика Саха (Якутия), с.Тулуна, Братья Габышевых, 18	t	small
10803	85083	567	Республика Саха (Якутия), с.Развилка	t	small
10276	84575	40	Республика Саха (Якутия), с.Нычалах, Центральная, 6	t	small
10775	85055	539	Республика Саха (Якутия), с.Нахара, Павлова, 18	t	small
10337	84637	101	Республика Саха (Якутия), с.Ботулу, Центральная улица, 17/1	t	small
10669	84950	433	Республика Саха (Якутия), с. Чукар, Лесная, 18	t	small
10777	85057	541	Республика Саха (Якутия), с. Хара-Алдан, Новая улица, 20	t	small
86029	84688	154	Республика Саха (Якутия), с. Хампа, Героя Кондакова, 13	f	small
10456	84754	220	Республика Саха (Якутия), с. Толон, Терешкина Н.Д, 28	t	small
10819	85099	583	Республика Саха (Якутия), с. Окоемовка, Окоемова, 15	t	small
10521	84811	285	Республика Саха (Якутия), Мегино-Кангаласский район, с. Норгана, Петрова, 14/1	t	small
86028	85096	580	Республика Саха (Якутия), с. Маягас, Петра Алексеева, 33/1	f	small
10440	84738	204	Республика Саха (Якутия), с. Кобяй, Егорова, 12	t	small
10436	84734	200	Республика Саха (Якутия), с. Кальвица, Рыбацкая, 31	t	small
10511	84801	275	Республика Саха (Якутия), с. Елечей, Алтанский наслег, Чапаева, 20	t	small
11042	85280	806	Республика Саха (Якутия), пос. Накын, Модуль Е	t	medium
10301	84600	65	Республика Саха (Якутия), п. Тикси, Ленинская, 13 А	f	medium
11041	85279	805	Республика Саха (Якутия), Якутск	f	small
10963	83709	727	Республика Саха (Якутия), Якутск, Ярославского, 21	f	large
10962	83127	726	Республика Саха (Якутия), Якутск, Ярославского, 27	f	large
10943	85225	707	Республика Саха (Якутия), Якутск, Я.Потапова, 4	f	large
10944	85226	708	Республика Саха (Якутия), Якутск, Я. Потапова, 4	f	large
10995	85240	759	Республика Саха (Якутия), Якутск, Энергетиков переулок, 2А	f	large
10965	83810	729	Республика Саха (Якутия), Якутск, Шавкунова, 63	f	large
10950	85232	714	Республика Саха (Якутия), Якутск, Чайковского, 2	f	large
10949	85231	713	Республика Саха (Якутия), Якутск, Чайковского, 30	f	large
10947	85229	711	Республика Саха (Якутия), Якутск, Чайковского, 32/1	f	large
10946	85228	710	Республика Саха (Якутия), Якутск, Чайковского, 13	f	large
10977	84235	741	Республика Саха (Якутия), Якутск, Халтурина, 4/1	f	large
10996	85241	760	Республика Саха (Якутия), Якутск, Ф. Попова, 3	f	large
10959	82796	723	Республика Саха (Якутия), Якутск, Тургенева, 4	f	medium
10972	84101	736	Республика Саха (Якутия), Якутск, Стадухина, 78	f	large
10981	84368	745	Республика Саха (Якутия), Якутск, С. Данилова, 34	f	large
10980	84361	744	Республика Саха (Якутия), Якутск, Рыдзинского, 5	f	medium
10937	85219	701	Республика Саха (Якутия), Якутск, Птицефабрика, 14	f	large
10974	84153	738	Республика Саха (Якутия), Якутск, Пояркова, 8/2	f	large
10970	84023	734	Республика Саха (Якутия), Якутск, Пояркова, 15	f	large
11033	85273	797	Республика Саха (Якутия), Якутск, П. Алексеева, 49	f	large
10971	84056	735	Республика Саха (Якутия), Якутск, П. Алексеева, 25	f	large
11001	85246	765	Республика Саха (Якутия), Якутск, Очиченко, 1/1	f	large
67859	82760	722	Республика Саха (Якутия), Якутск, Островского, 1	f	large
10953	85141	717	Республика Саха (Якутия), Якутск, Ойунского, 24	f	large
11015	85258	779	Республика Саха (Якутия), Якутск, О. Кошевого, 67, мкрн. Марха	f	large
10666	84947	430	Республика Саха (Якутия), Якутск, поселок Кангалассы, Молодежная, 11	f	small
11040	85278	804	Республика Саха (Якутия), Якутск, Можайского, 15/4	f	medium
11004	85249	768	Республика Саха (Якутия), Якутск, Можайского, 25	f	large
11005	81629	769	Республика Саха (Якутия), Якутск, Можайского, 23	f	large
10945	85227	709	Республика Саха (Якутия), Якутск, Маяковского, 79	f	large
11013	85256	777	Республика Саха (Якутия), Якутск, Маганский тракт, 2 км	f	large
10940	85222	704	Республика Саха (Якутия), Якутск, Лизы Чайкиной, 2а	f	large
10976	81911	740	Республика Саха (Якутия), Якутск, Лермонтова, 40	f	large
11038	81911	802	Республика Саха (Якутия), Якутск, Лермонтова, 40	f	large
11023	85266	787	Республика Саха (Якутия), Якутск, Ленина, 5	f	large
10942	85224	706	Республика Саха (Якутия), Якутск, Ленина, 50	f	large
67858	85223	705	Республика Саха (Якутия), Якутск, Ленина, 43	f	large
10987	84852	751	Республика Саха (Якутия), Якутск, Ленина, 2	f	large
10968	83972	732	Республика Саха (Якутия), Якутск, Ленина, 5	f	large
67860	83775	728	Республика Саха (Якутия), Якутск, Ленина, 16	f	large
10957	82745	721	Республика Саха (Якутия), Якутск, Ленина, 40	f	large
11032	85269	796	Республика Саха (Якутия), Якутск, Кулаковского, 48	f	large
11028	85269	792	Республика Саха (Якутия), Якутск, Кулаковского, 48	f	large
10956	82671	720	Республика Саха (Якутия), Якутск, Кулаковского, 6/2	f	large
120717	82658	719	Республика Саха (Якутия), Якутск, Кулаковского, 36	f	medium
11026	85248	790	Республика Саха (Якутия), Якутск, Кузьмина, 15/3	f	large
11003	85248	767	Республика Саха (Якутия), Якутск, Кузьмина, 15/3	f	large
11034	85221	798	Республика Саха (Якутия), Якутск, Красильникова, 15	f	large
10939	85221	703	Республика Саха (Якутия), Якутск, Красильникова, 15	f	large
11037	85276	801	Республика Саха (Якутия), Якутск, Кирова, 20	f	large
10961	82869	725	Республика Саха (Якутия), Якутск, Кирова, 23	f	large
10960	82828	724	Республика Саха (Якутия), Якутск, Кирова, 25	f	large
10997	85242	761	Республика Саха (Якутия), Якутск, Кальвица, 14/1	f	large
10993	85238	757	Республика Саха (Якутия), Якутск, Кальвица, 5	f	large
10978	84247	742	Республика Саха (Якутия), Якутск, Кальвица, 24	f	large
11031	85272	795	Республика Саха (Якутия), Якутск, Каландаришвили, 17	f	large
11030	85271	794	Республика Саха (Якутия), Якутск, Каландаришвили, 31	f	medium
10951	85104	715	Республика Саха (Якутия), Якутск, Каландаришвили, 34	f	large
10952	85104	716	Республика Саха (Якутия), Якутск, Каландаришвили, 34	f	large
67861	85251	772	Республика Саха (Якутия), Якутск, Кааландаришвили, 10	f	large
11014	85257	778	Республика Саха (Якутия), Якутск, Заводская, 10, мкрн. Марха	f	large
11006	81730	770	Республика Саха (Якутия), Якутск, Жуковского, 5	f	large
10983	84482	747	Республика Саха (Якутия), Якутск, Жорницкого, 7/11А	f	large
10982	84383	746	Республика Саха (Якутия), Якутск, Жорницкого, 13	f	large
10992	85237	756	Республика Саха (Якутия), Якутск, Дзержинского, 38	f	large
10990	85235	754	Республика Саха (Якутия), Якутск, Дзержинского, 13	f	large
10986	84800	750	Республика Саха (Якутия), Якутск, Дзержинского, 16/1	f	large
10985	84504	749	Республика Саха (Якутия), Якутск, Дзержинского, 55	f	large
10979	84258	743	Республика Саха (Якутия), Якутск, Дзержинского, 43	f	large
10975	84190	739	Республика Саха (Якутия), Якутск, Дзержинского, 17	f	large
10973	84149	737	Республика Саха (Якутия), Якутск, Дзержинского, 5	f	large
10969	84002	733	Республика Саха (Якутия), Якутск, Дзержинского, 2	f	large
11012	85255	776	Республика Саха (Якутия), Якутск, Газовиков, 19	f	large
10988	81335	752	Республика Саха (Якутия), Якутск, Богатырева, 21	f	large
11036	85275	800	Республика Саха (Якутия), Якутск, Билибина, 6	f	large
10948	85230	712	Республика Саха (Якутия), Якутск, Билибина, 14	f	large
10998	85243	762	Республика Саха (Якутия), Якутск, Бестужева-Марлинского, 23/1	f	large
10994	85239	758	Республика Саха (Якутия), Якутск, Бестужева-Марлинского, 24	f	large
10991	85236	755	Республика Саха (Якутия), Якутск, Бестужева-Марлинского, 5	f	large
10954	85204	718	Республика Саха (Якутия), Якутск, Белинского, 58	f	large
11035	85274	799	Республика Саха (Якутия), Якутск, Бекетова, 6	f	large
11024	85267	788	Республика Саха (Якутия), Якутск, Автодорожная, 40/4	f	large
10938	85220	702	Республика Саха (Якутия), Якутск, Автодорожная, 36	f	large
11002	85247	766	Республика Саха (Якутия), Якутск, 50 лет Советской Армии, 35/1	f	large
11000	85245	764	Республика Саха (Якутия), Якутск, 50 лет Советской Армии, 86/1	f	large
10999	85244	763	Республика Саха (Якутия), Якутск, 50 лет Советской Армии, 47	f	large
11027	85234	791	Республика Саха (Якутия), Якутск, 202 микрорайон, 21	f	large
10989	85234	753	Республика Саха (Якутия), Якутск, 202 микрорайон, 21	f	large
10918	85199	682	Республика Саха (Якутия), Юрях-Кюере, Юрях-Кюеринская, 27	t	small
10296	84595	60	Республика Саха (Якутия), Юрюнг-Хая, Алроса, 7	t	medium
10293	84592	57	Республика Саха (Якутия), Эмисск, К. Урастырова, 49	t	small
10734	85014	498	Республика Саха (Якутия), село Эйик, Центральная, 15	t	small
10792	85072	556	Республика Саха (Якутия), Ытык-Кюель, Пекарского, 28	f	large
10790	85070	554	Республика Саха (Якутия), Ытык-Кюель, Ойунского, 1	f	large
10748	85028	512	Республика Саха (Якутия), село Шея, Советская, 25	f	medium
10787	85067	551	Республика Саха (Якутия), Чычымах, Школьная, 4/1	t	small
120702	85069	553	Республика Саха (Якутия), село Чымнай, Самырова, 64	t	small
10638	84918	402	Республика Саха (Якутия), Черский, Молодежная, 38	f	medium
10753	85033	517	Республика Саха (Якутия), Хоро, Сатыс, 47	t	small
10328	84628	92	Республика Саха (Якутия), село Хоро, Булгунняхтах, 3	f	small
10568	84856	332	Республика Саха (Якутия), село Хонуу, Спортивная, 1/3	f	large
120671	84869	345	Республика Саха (Якутия), Хонгор-Бие, Ларионова, 16	t	small
10307	84606	71	Республика Саха (Якутия), Хара-Улах, Колёсова, 12	t	small
10794	85074	558	Республика Саха (Якутия), Хандыга, Охлопкова, 3	f	large
10796	85076	560	Республика Саха (Якутия), Хандыга, Магаданская, 30а	f	large
10640	84920	404	Республика Саха (Якутия), Халарчинский наслег, Черского, 8	t	small
10924	85206	688	Республика Саха (Якутия), село Уорга	t	small
10567	84855	331	Республика Саха (Якутия), Удачный, СОШ №19	f	large
10565	84853	329	Республика Саха (Якутия), Удачный, Новый Город, Общественный центр, шахматный клуб	f	large
10401	84700	165	Республика Саха (Якутия), село Тымпы, Коммунаров, 3/1	t	small
10441	84739	205	Республика Саха (Якутия), село Тыайа, Октябрьская, 22	t	small
10320	84620	84	Республика Саха (Якутия), село Туобуя, С.Платонова, 21	t	small
10804	85084	568	Республика Саха (Якутия), село Тополиное, Советская, 3	t	medium
10266	84565	30	Республика Саха (Якутия), Томмот, Зеленая, 11	f	medium
10772	85052	536	Республика Саха (Якутия), село Тойбохой, Октябрьская, 40	f	medium
10691	84972	455	Республика Саха (Якутия), село Тинная, Школьная, 5	t	small
10300	84599	64	Республика Саха (Якутия), поселок Тикси, Академика Федорова, 28 А	f	medium
10302	84601	66	Республика Саха (Якутия), поселок Тикси, 50 лет СевМорПути, 8	f	medium
10685	84966	449	Республика Саха (Якутия), село Терют, Школа	t	small
10402	84701	166	Республика Саха (Якутия), Тасагар, Октябрьская, 24	t	small
10760	85040	524	Республика Саха (Якутия), Сунтар, Папанина, 40	f	large
10757	85037	521	Республика Саха (Якутия), Сунтар, Вилюйская, 32	f	medium
10758	85038	522	Республика Саха (Якутия), село Сунтар, В.Павлова, 5	f	large
10283	84582	47	Республика Саха (Якутия), Сулгаччы, М. Харачаса, 13	t	small
10372	84673	136	Республика Саха (Якутия), село Столбы, Набережная, 7	t	small
120678	84886	362	Республика Саха (Якутия), поселок Столбы, Аммосова, 45	f	medium
10736	85016	500	Республика Саха (Якутия), Среднеколымск, Ярославского, 11	f	large
10735	85015	499	Республика Саха (Якутия), Среднеколымск, Навроцкого, 5	f	large
10932	85214	696	Республика Саха (Якутия), Село Чурапча, Ленина, 35	f	large
10929	85211	693	Республика Саха (Якутия), Село Чурапча, К. Маркса, 29	f	medium
10784	85064	548	Республика Саха (Якутия), Село Черкех, Ойунского, 52	f	medium
10846	85127	610	Республика Саха (Якутия), Село Белькачи, улица Школьная, 10	t	small
10554	84842	318	Республика Саха (Якутия), Светлый, Советская, 15	f	large
10396	84695	160	Республика Саха (Якутия), село Сатагай, Центральная, 8	t	small
10299	84598	63	Республика Саха (Якутия), поселок Саскылах, Октябрьская, 19/1	f	medium
10297	84596	61	Республика Саха (Якутия), поселок Саскылах, Молодежная, 25	f	medium
10450	84748	214	Республика Саха (Якутия), Сайылык, Октябрьская, 47	t	small
10854	85135	618	Республика Саха (Якутия), Поселок Эльдикан, Алданская, 53	t	large
10279	84578	43	Республика Саха (Якутия), Поселок Чокурдах, Ленина, 2	f	large
10557	84845	321	Республика Саха (Якутия), Поселок Чернышевский, Космонавтов, 10/3	f	large
10555	84843	319	Республика Саха (Якутия), Поселок Чернышевский, Гидростроителей, 1	f	large
10795	85075	559	Республика Саха (Якутия), Поселок Хандыга, Кудрявого, 34	f	large
10793	85073	557	Республика Саха (Якутия), Поселок Хандыга, Алданская, 7	f	medium
10675	84956	439	Республика Саха (Якутия), Поселок Усть-Нера, Трудовая, 14, здание ОГАИ	f	medium
10677	84958	441	Республика Саха (Якутия), Поселок Усть-Нера, Ленина, 25-а, здание к-т Север	f	large
10850	85131	614	Республика Саха (Якутия), Поселок Усть-Мая, Первомайская, 18	f	medium
10852	85133	616	Республика Саха (Якутия), Поселок Усть-Мая, Горького, 51	f	medium
10851	85132	615	Республика Саха (Якутия), Поселок Усть-Мая, Алданский переулок, 13	f	medium
10461	84759	225	Республика Саха (Якутия), Поселок Талакан, Административное здание центральной инженерно-	t	large
10429	84728	193	Республика Саха (Якутия), Поселок Сангар, Горбунова, 22	f	small
10463	84761	227	Республика Саха (Якутия), Поселок Пеледуй, Центральная, 16	t	large
10351	84651	115	Республика Саха (Якутия), Поселок Зырянка, Пристанская, 14	f	medium
10349	84649	113	Республика Саха (Якутия), Поселок Зырянка, Ленина, 11	f	medium
10797	85077	561	Республика Саха (Якутия), Поселок Джебарики-Хая, Советская, 9	t	large
10458	84756	222	Республика Саха (Якутия), Поселок Витим, Ленина, 45	t	medium
10355	84655	119	Республика Саха (Якутия), Поселок Батагай, Трохачева, 20	f	medium
10356	84656	120	Республика Саха (Якутия), Поселок Батагай, Аммосова, 40	f	medium
10553	84841	317	Республика Саха (Якутия), Поселок Алмазный, Речная, 6	t	large
10561	84848	325	Республика Саха (Якутия), Поселок Айхал, Энтузиастов, 1	f	large
10559	84846	323	Республика Саха (Якутия), Поселок Айхал, Советская, 12	f	large
10558	84846	322	Республика Саха (Якутия), Поселок Айхал, Советская, 12	f	large
10560	84847	324	Республика Саха (Якутия), Поселок Айхал, Бойко, 1 А	f	large
10639	84919	403	Республика Саха (Якутия), Олёринский наслег, Набережная, 9	t	medium
10729	85009	493	Республика Саха (Якутия), Олёкминск, Кузьмина, 2	f	small
10724	85004	488	Республика Саха (Якутия), Олёкминск, Гагарина, 58	f	large
10722	85002	486	Республика Саха (Якутия), Олёкминск, 50 лет Победы, 58	f	large
10725	85005	489	Республика Саха (Якутия), Олекминск, Спасская, 111	f	medium
10705	84985	469	Республика Саха (Якутия), Олекминск, Первомайская, 31	f	medium
10721	84939	485	Республика Саха (Якутия), Олекминск, Молодежная, 19	f	large
10726	85006	490	Республика Саха (Якутия), Олекминск, Мелиораторов, 3	f	medium
120690	85024	508	Республика Саха (Якутия), село Ойусардах, Мира, 2	t	small
10658	84938	422	Республика Саха (Якутия), село Нюрбачан, П. Николаева, 17	t	small
86025	84931	415	Республика Саха (Якутия), Нюрба, Энергетик, 22	f	small
10647	84927	411	Республика Саха (Якутия), Нюрба, Энергетик, 55а	f	medium
10642	84922	406	Республика Саха (Якутия), Нюрба, Убоян, 26	f	medium
10645	84925	409	Республика Саха (Якутия), Нюрба, Степана Васильева, 33	f	medium
120682	84923	407	Республика Саха (Якутия), Нюрба, Переулок Чусовского, 7	f	medium
10648	84928	412	Республика Саха (Якутия), Нюрба, Октябрьская, 5	f	medium
134621	84924	408	Республика Саха (Якутия), Нюрбинский район, Нюрба, Манчары, 14	f	medium
10650	84930	414	Республика Саха (Якутия), Нюрба, Ленина, 52	f	medium
10649	84929	413	Республика Саха (Якутия), Нюрба, Ленина, 32/1	f	medium
120683	84926	410	Республика Саха (Якутия), Нюрба, Комсомольская, 62	f	medium
10730	85010	494	Республика Саха (Якутия), село Нефтебаза, Набережная, 2	f	small
10604	84892	368	Республика Саха (Якутия), Нерюнгри, Южно-Якутская, 8	f	large
10606	84894	370	Республика Саха (Якутия), Нерюнгри, Чурапчинская, 16	f	large
10605	84893	369	Республика Саха (Якутия), Нерюнгри, Чурапчинская, 33	f	large
10619	84904	383	Республика Саха (Якутия), Нерюнгри, Ленина, 12/1	f	large
10618	84904	382	Республика Саха (Якутия), Нерюнгри, Ленина, 12/1	f	large
10617	84904	381	Республика Саха (Якутия), Нерюнгри, Ленина, 12/1	f	large
10611	84898	375	Республика Саха (Якутия), Нерюнгри, Ленина, 13/2	f	large
10609	84896	373	Республика Саха (Якутия), Нерюнгри, Кравченко, 7	f	large
10608	84895	372	Республика Саха (Якутия), Нерюнгри, Кравченко, 16/1	f	large
10607	84895	371	Республика Саха (Якутия), Нерюнгри, Кравченко, 16/1	f	large
10615	84902	379	Республика Саха (Якутия), Нерюнгри, Карла Маркса, 7/1	f	large
10614	84901	378	Республика Саха (Якутия), Нерюнгри, Карла Маркса, 7/1	f	large
10613	84900	377	Республика Саха (Якутия), Нерюнгри, Карла Маркса, 15	f	large
10610	84897	374	Республика Саха (Якутия), Нерюнгри, Карла Маркса, 29	f	large
10636	84916	400	Республика Саха (Якутия), Нерюнгри, Железнодорожная, 8	t	large
10622	84905	386	Республика Саха (Якутия), Нерюнгри, Дружбы Народов, 12/2	f	large
10621	84905	385	Республика Саха (Якутия), Нерюнгри, Дружбы Народов, 12/2	f	large
10620	84905	384	Республика Саха (Якутия), Нерюнгри, Дружбы Народов, 12/2	f	large
10616	84903	380	Республика Саха (Якутия), Нерюнгри, Дружбы Народов, 7	f	large
10629	84911	393	Республика Саха (Якутия), Хангаласский район, Геологическая, 2	t	small
10624	84906	388	Республика Саха (Якутия), Нерюнгри, Аммосова, 6/3	f	large
10623	84906	387	Республика Саха (Якутия), Нерюнгри, Аммосова, 6/3	f	large
10634	84914	398	Республика Саха (Якутия), Нерюнгри, 70 лет Отктября, СОШ №16	t	medium
10697	84978	461	Республика Саха (Якутия), село Нерюктяйинск 1-й, Центральная, 15	t	medium
67868	84877	353	Республика Саха (Якутия), Намцы, Платонова, 18	f	large
10586	84874	350	Республика Саха (Якутия), село Намцы, Студенческая, 1	f	large
10541	84828	305	Республика Саха (Якутия), Мирный, АЭРОПОРТ, актовый зал Аэропорта	f	small
10547	84834	311	Республика Саха (Якутия), Мирный, Тихонова, 5/1	f	large
10545	84832	309	Республика Саха (Якутия), Мирный, Советская, 11 А	f	large
10538	84825	302	Республика Саха (Якутия), Мирный, Ленинградский проспект, 9 А	f	small
10534	84824	298	Республика Саха (Якутия), Мирный, Ленинградский проспект, 7/4	f	large
67867	84831	308	Республика Саха (Якутия), Мирный, Ленина, 30	f	large
10543	84830	307	Республика Саха (Якутия), Мирный, Ленина, 1	f	large
10537	83572	301	Республика Саха (Якутия), Мирный, Ленина, 17	f	large
10536	83572	300	Республика Саха (Якутия), Мирный, Ленина, 17	f	large
10548	84835	312	Республика Саха (Якутия), Мирный, Куницына, 18	f	large
10540	84827	304	Республика Саха (Якутия), Мирный, Комсомольская, 2 А	f	large
10539	84826	303	Республика Саха (Якутия), Мирный, Комсомольская, 12	f	large
10533	84823	297	Республика Саха (Якутия), Мирный, Звездная, 7	f	medium
10535	83546	299	Республика Саха (Якутия), Мирный, Вилюйская, 7	f	medium
10542	84829	306	Республика Саха (Якутия), Мирный, 40 Лет Октября, 12	f	large
10805	85085	569	Республика Саха (Якутия), село Мегино-алдан, Октябрьская, 19	t	medium
10693	84974	457	Республика Саха (Якутия), Мача, Строда, 26	t	small
10442	84740	206	Республика Саха (Якутия), Мастах, Советская, 20	t	small
10769	85049	533	Республика Саха (Якутия), Мар-Кель, Молодежная, 19	t	small
10668	84949	432	Республика Саха (Якутия), село Мар, Молодежная, 4	f	medium
10672	84953	436	Республика Саха (Якутия), Малыкай, Мегежекского, 6	f	large
10424	84723	188	Республика Саха (Якутия), Линдинское село , Линдинская, 2	t	small
10469	84767	233	Республика Саха (Якутия), Ленск, Аэропорт Ленск	f	small
10481	82622	245	Республика Саха (Якутия), Ленск, Якутская, 15	f	medium
10484	83290	248	Республика Саха (Якутия), Ленск, Проспект Дружбы, 21	f	large
10479	82207	243	Республика Саха (Якутия), Ленск, Пролетарская, 28	f	large
10475	84773	239	Республика Саха (Якутия), Ленск, Победы, 11	f	large
10478	82188	242	Республика Саха (Якутия), Ленск, Победы, 30	f	small
10474	84772	238	Республика Саха (Якутия), Ленск, Первомайская, 2	f	medium
10477	84775	241	Республика Саха (Якутия), Ленск, Ойунского, 36	f	large
10480	82298	244	Республика Саха (Якутия), Ленск, Нюйская, 14	f	small
10482	82894	246	Республика Саха (Якутия), Ленск, Мелиораторов, 3	f	small
10472	84770	236	Республика Саха (Якутия), Ленск, Ленина, 61	f	medium
10468	84766	232	Республика Саха (Якутия), Ленск, Каландарашвили, 28	f	large
10467	84765	231	Республика Саха (Якутия), Ленск, Каландарашвили, 16	f	large
10486	83521	250	Республика Саха (Якутия), Ленск, Бамовский проезд, 1	f	medium
10483	83066	247	Республика Саха (Якутия), Ленск, Айхальская, 33	f	large
10400	84699	164	Республика Саха (Якутия), Лекечен, Центральная, 24	t	small
10656	84936	420	Республика Саха (Якутия), село Кюндяде, Ленина, 64	t	medium
10750	85030	514	Республика Саха (Якутия), село Кутана, В.Крыжановского, 32	f	medium
10317	84617	81	Республика Саха (Якутия), Куду, Куду, 22	t	small
10406	84705	170	Республика Саха (Якутия), село Кирово, Братьев Семеновых, 24	t	small
10327	84627	91	Республика Саха (Якутия), село Кентик (Харыялах), Г.Миронова, 11, Кентикский наслег	f	small
10421	84719	185	Республика Саха (Якутия), Жиганск, Кычкина, 11	f	large
10770	85050	534	Республика Саха (Якутия), Жархан, Тихоновой, 7	t	small
10660	84941	424	Республика Саха (Якутия), Жархан, Доры Жирковой, 5	t	small
10316	84616	80	Республика Саха (Якутия), село Едей, Зеленая, 4	f	medium
10926	85208	690	Республика Саха (Якутия), село Дирин, Марыкчанская, 10	t	medium
10781	85061	545	Республика Саха (Якутия), село Дебдирге, Боярова, 27	f	medium
10460	84758	224	Республика Саха (Якутия), Витим, Декабристов, 1А	t	small
10382	84680	146	Республика Саха (Якутия), Вилюйск, Ярославского, 70 а	f	medium
10378	81704	142	Республика Саха (Якутия), Вилюйск, Чиряева, 30/1	f	medium
10384	84682	148	Республика Саха (Якутия), Вилюйск, Чапаева, 45/1	f	medium
10380	84678	144	Республика Саха (Якутия), Вилюйск, Партизана Семенова, 18	f	medium
10376	84677	140	Республика Саха (Якутия), Вилюйск, Мира, 17	f	medium
10381	84679	145	Республика Саха (Якутия), Вилюйск, Марка Жиркова, 38	f	medium
10377	81544	141	Республика Саха (Якутия), Вилюйск, Ленина, 28	f	medium
10383	84681	147	Республика Саха (Якутия), Вилюйск, Иона Попова, 11	f	medium
10385	84683	149	Республика Саха (Якутия), Вилюйск, Б.Н.Степанова, 4	f	small
10379	81737	143	Республика Саха (Якутия), Вилюйск, Аммосова, 14	f	medium
10359	84659	123	Республика Саха (Якутия), Верхоянск, Новгородова, 44	t	medium
10312	84612	76	Республика Саха (Якутия), село Верхневилюск, Ветеринаров, 8	f	small
67866	84610	75	Республика Саха (Якутия), Верхневилюйск, Школьная, 1	f	large
120661	84613	77	Республика Саха (Якутия), Верхневилюйск, Героя Васильева, 47	f	medium
10310	84609	74	Республика Саха (Якутия), Верхневилюйск, Героя Васильева, 2Б	f	medium
10718	84998	482	Республика Саха (Якутия), Бясь-Кюэль, Центральная, 6	t	small
120677	84884	360	Республика Саха (Якутия), Бютяй-Юрдя, Кириллина, 35	t	small
10523	84814	287	Республика Саха (Якутия), село Бютейдях, Анисимова, 22	f	medium
10304	84603	68	Республика Саха (Якутия), Быковский, Советская, 2	t	small
10306	84605	70	Республика Саха (Якутия), Борогон, Жиркова, 6	t	small
10392	84690	156	Республика Саха (Якутия), Бетюнг, Колхозная, 5А	f	small
10739	85019	503	Республика Саха (Якутия), Березовка, Ягловского, 8	t	small
120686	84968	451	Республика Саха (Якутия), село Берег-Юрдя, Детский сад	t	small
10935	85217	699	Республика Саха (Якутия), село Батагай-Алыта, Щадрина, 2	f	large
10447	84745	211	Республика Саха (Якутия), село Багадя, Егорова, 1	t	small
10807	85087	571	Республика Саха (Якутия), Ары-Толон, Школьный переулок, 9, корпус 1	t	small
10281	84580	45	Республика Саха (Якутия), Амга, Партизанская, 28	f	large
10282	84581	46	Республика Саха (Якутия), Амга, Ленина, 44	f	large
67864	84579	44	Республика Саха (Якутия), Амга, Короленко, 9	f	large
10237	84537	1	Республика Саха (Якутия), село Абый, Баронова, 11	t	small
10286	84585	50	Республика Саха (Якутия), село Абага, Партизанская, 13	t	medium
120688	84983	467	Республика Саха (Якутия), Абага, Кудрина-Абагинского, 15	t	small
11039	85277	803	Республика Саха (Якутия), городской округ Якутск, село Хатассы, Совхозная, 31	f	large
11009	85252	773	Республика Саха (Якутия), городской округ Якутск, село Хатассы, Совхозная, 31А	f	large
11020	85263	784	Республика Саха (Якутия), городской округ Якутск, село Тулагино, Первомайская, 2	f	large
11010	85253	774	Республика Саха (Якутия), городской округ Якутск, село Пригородный, Совхозная, 27	f	medium
10662	84943	426	Республика Саха (Якутия), городской округ Якутск, поселок городского типа Марха, Советская, 31	t	medium
11011	85254	775	Республика Саха (Якутия), городской округ Якутск, поселок городского типа Марха, Кошевого, 45	f	large
11016	85259	780	Республика Саха (Якутия), городской округ Якутск, поселок Маган, Алымова, 3	f	large
11021	85264	785	Республика Саха (Якутия), городской округ Якутск, село Капитоновка, Семенова, 14	f	medium
11018	85261	782	Республика Саха (Якутия), городской округ Якутск, село Жатай, Строда, 1	f	large
11019	85262	783	Республика Саха (Якутия), городской округ Якутск, село Жатай, Северная, 4	f	large
11017	85260	781	Республика Саха (Якутия), городской округ Якутск, село Жатай, Северная, 50	f	large
10628	84910	392	Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Чульман, Циолковского, 6А	f	large
10626	84908	390	Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Чульман, Геологическая, 18	f	large
10625	84907	389	Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Чульман, Гаражная, 2	f	large
10627	84909	391	Республика Саха (Якутия), городской округ Нерюнгри, поселок Чульман, Островского, 18	f	large
10566	84854	330	Республика Саха (Якутия), городской округ Нерюнгри, Удачный, Новый Город, СОШ №24	f	large
10564	84851	328	Республика Саха (Якутия), городской округ Нерюнгри, Удачный, Общественный центр, спортзал	f	large
10630	84812	394	Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Серебряный Бор, 39	f	large
10631	84812	395	Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Серебряный Бор, 39	f	large
10635	84915	399	Республика Саха (Якутия), городской округ Нерюнгри, село Иенгра, 40 лет Победы, 5	t	medium
10632	84912	396	Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Беркакит, Школьная, 5	f	large
10633	84913	397	Республика Саха (Якутия), городской округ Нерюнгри, поселок городского типа Беркакит, Муссы Джалиля, 7А	f	large
11007	85250	771	Республика Саха (Якутия), Якутск, поселок городского типа Табага, Лесная, 12	f	small
11022	85265	786	Республика Саха (Якутия), Якутск, село Кильдемцы, Труда, 24	f	small
10936	85218	700	Республика Саха (Якутия), Эвено-Бытантайский район, село Кустур, Национальный переулок, 7	t	small
10934	85216	698	Республика Саха (Якутия), Эвено-Бытантайский район, село Джаргалах, Центральная, 2	t	small
10908	85189	672	Республика Саха (Якутия), Чурапчинский район, уч. Кындал, Центральная, 1	t	small
10921	85202	685	Республика Саха (Якутия), Чурапчинский район, с.Тея, Монастырева, 11	t	small
10909	85190	673	Республика Саха (Якутия), Чурапчинский район, с. Харбала-1, Партизанская, 16	t	small
10928	85210	692	Республика Саха (Якутия), Чурапчинский район, с. Туора-Кюель, Комсомольская, 16	t	small
10906	85187	670	Республика Саха (Якутия), Чурапчинский район, с. Толон, Новая, 1	t	small
10914	85195	678	Республика Саха (Якутия), Чурапчинский район, с. Килянки, Октябрьская, 4	t	small
10923	85205	687	Республика Саха (Якутия), Чурапчинский район, Юрюнг-Кюель, Сергеева, 28	t	small
10905	85186	669	Республика Саха (Якутия), Чурапчинский район, село Чыаппара, Протодьяконова, 78	t	small
10933	85215	697	Республика Саха (Якутия), Чурапчинский район, село Чурапча, Спортивная, 2	f	large
10931	85213	695	Республика Саха (Якутия), Чурапчинский район, село Чурапча, Ленина, 53	f	large
10927	85209	691	Республика Саха (Якутия), Чурапчинский район, село Чакыр, Эрилик-Эристина, 2	t	small
10912	85193	676	Республика Саха (Якутия), Чурапчинский район, Хахыйах, Хомподоева, 8	t	small
10907	85188	671	Республика Саха (Якутия), Чурапчинский район, Харбала-2, Новгородова	t	small
10919	85200	683	Республика Саха (Якутия), Чурапчинский район, село Усун-Кюель, Макарова, 5	f	medium
10920	85201	684	Республика Саха (Якутия), Чурапчинский район, поселок Усун-Кюель, Мельницкая, 14	t	small
10916	85197	680	Республика Саха (Якутия), Чурапчинский район, Телей, Телейская, 6а	t	small
10930	85212	694	Республика Саха (Якутия), Чурапчинский район, Село Чурапча, Петровского, 29	f	large
10911	85192	675	Республика Саха (Якутия), Чурапчинский район, Мырыла, Амгинская, 40	t	small
10925	85207	689	Республика Саха (Якутия), Чурапчинский район, Мельжехси	t	small
10915	85196	679	Республика Саха (Якутия), Чурапчинский район, село Маралайы, Октярьская, 81	t	medium
10917	85198	681	Республика Саха (Якутия), Чурапчинский район, Дябыла, Карла-Маркса, 25	t	medium
10922	85203	686	Республика Саха (Якутия), Чурапчинский район, Беря, Сивцева, 14	t	small
10275	84574	39	Республика Саха (Якутия), Хангаласский район, село Чкалов, Центральная, 16	t	small
10881	85161	645	Республика Саха (Якутия), Хангаласский район, Чкалов, Мира, 16	t	small
10886	85167	650	Республика Саха (Якутия), Хангаласский район, село Чаранг, Михайлова	t	small
120687	84973	456	Республика Саха (Якутия), Хангаласский район, село Чапаево, Сосновая, 21	t	medium
10896	85177	660	Республика Саха (Якутия), Хангаласский район, село Чапаево, Саввина, 1	f	small
10899	85180	663	Республика Саха (Якутия), Хангаласский район, село Хоточчу, Варламовых, 15	t	small
10732	85012	496	Республика Саха (Якутия), Хангаласский район, село Харыялах, Октябрьская, 4	t	small
86032	84890	366	Республика Саха (Якутия), Хангаласский район, село Харыялах, Набережная, 14	f	small
10449	84747	213	Республика Саха (Якутия), Хангаласский район, село Улахан-Сайылык, Саввинова, 3	t	small
10331	84631	95	Республика Саха (Якутия), Хангаласский район, село Улахан-Сайылык, С. Буучугураса, 3	t	small
10882	85162	646	Республика Саха (Якутия), Хангаласский район, село Улахан-Ан, Трофимова, 1	t	medium
10895	85176	659	Республика Саха (Якутия), Хангаласский район, село Улахан-Ан, Ленская, 49	f	medium
10529	84820	293	Республика Саха (Якутия), Хангаласский район, село Тёхтюр, Октябрьская, 12	t	medium
10520	84810	284	Республика Саха (Якутия), Хангаласский район, село Тумул, Школьная, 5	t	small
10879	85159	643	Республика Саха (Якутия), Хангаласский район, село Тумул, Семилетка, 12	t	small
10900	85181	664	Республика Саха (Якутия), Хангаласский район, село Тит-Эбя, Жданова, 19	t	medium
120708	85102	586	Республика Саха (Якутия), Хангаласский район, село Тит-Ары	t	small
10880	85160	644	Республика Саха (Якутия), Хангаласский район, село Тит-Ары, Центральная, 46	t	small
10898	85179	662	Республика Саха (Якутия), Хангаласский район, село Техтюр, Каландрашвили, 11	f	small
10878	85158	642	Республика Саха (Якутия), Хангаласский район, село Синск, Орджоникидзе, 40	t	medium
10890	85171	654	Республика Саха (Якутия), Хангаласский район, поселок городского типа Покровск, Южная, 6	f	medium
10892	85173	656	Республика Саха (Якутия), Хангаласский район, поселок городского типа Покровск, Орджоникидзе, 52	f	large
10889	85170	653	Республика Саха (Якутия), Хангаласский район, поселок Покровск, Центральная, 7, мкр Звероферма	t	small
10891	85172	655	Республика Саха (Якутия), Хангаласский район, поселок Покровск, Б.Ксенофонтова, 106	t	large
10897	85178	661	Республика Саха (Якутия), Хангаласский район, село Октёмцы, Е.Андреева, 1	f	large
10894	85175	658	Республика Саха (Якутия), Хангаласский район, село Ой, Ленина, 65	f	large
10888	85169	652	Республика Саха (Якутия), Хангаласский район, поселок городского типа Мохсоголлох, Комсомольская, 12	f	large
10887	85168	651	Республика Саха (Якутия), Хангаласский район, поселок городского типа Мохсоголлох, Заводская, 11	f	large
10901	85182	665	Республика Саха (Якутия), Хангаласский район, село Кёрдём, Школьная, 14	t	medium
10876	85156	640	Республика Саха (Якутия), Хангаласский район, село Кытыл-Дюра, И.Никифорова, 26/2	t	small
10884	85164	648	Республика Саха (Якутия), Хангаласский район, село Кытанах-Кырдал (Тойон-Ары), Центральная, 4	t	small
10902	85183	666	Республика Саха (Якутия), Хангаласский район, село Кысыл-Юрюйя, Ларионова, 31	t	small
10904	85185	668	Республика Саха (Якутия), Хангаласский район, село Качикатцы	t	small
10903	85184	667	Республика Саха (Якутия), Хангаласский район, село Качикатцы, Ленина, 14	t	medium
10875	85155	639	Республика Саха (Якутия), Хангаласский район, село Исит, Юбилейная, 53	t	small
10877	85157	641	Республика Саха (Якутия), Хангаласский район, село Едей, Октябрьская, 16	t	small
10883	85163	647	Республика Саха (Якутия), Хангаласский район, село Булгунняхтах, Советская, 78	t	large
10885	85166	649	Республика Саха (Якутия), Хангаласский район, поселок Бестях, Новая, 15	t	large
120665	84724	189	Республика Саха (Якутия), Хангаласский район, поселок Бестях, Нагорная, 4	t	small
10452	84750	216	Республика Саха (Якутия), Хангаласский район, село Батамай, Семенова, 12	t	small
10868	85149	632	Республика Саха (Якутия), Усть-Янский район, с. Хайыр, Иннокентия Барабанского, 7	t	\N
10862	85144	626	Республика Саха (Якутия), Усть-Янский район, с. Сайылык, Набережная, 4	t	\N
10870	85151	634	Республика Саха (Якутия), Усть-Янский район, с. Казачье, Барона Толля, 11	t	\N
10871	85151	635	Республика Саха (Якутия), Усть-Янский район, с. Казачье, Барона Толля, 11	t	\N
10865	85146	629	Республика Саха (Якутия), Усть-Янский район, село Уянди, 35	t	\N
10872	85152	636	Республика Саха (Якутия), Усть-Янский район, село Усть-Янск, Мира, 1	t	\N
10873	85153	637	Республика Саха (Якутия), Усть-Янский район, село Тумат, 61	t	\N
10867	85148	631	Республика Саха (Якутия), Усть-Янский район, Поселок Усть-Куйга, 50 лет Октября, 11	t	\N
10866	85147	630	Республика Саха (Якутия), 50 лет Октября, 11	t	\N
10869	85150	633	Республика Саха (Якутия), Усть-Янский район, Поселок Нижнеянск, Молодежная, 5	t	\N
10864	85145	628	Республика Саха (Якутия), Усть-Янский район, Поселок Депутатский, м-н Арктика, 17	f	\N
10863	85145	627	Республика Саха (Якутия), Усть-Янский район, Поселок Депутатский, м-н Арктика, 17	f	\N
10853	85134	617	Республика Саха (Якутия), Усть-Майский район, Эжанцы, А.Иванова, 4	t	small
10848	85129	612	Республика Саха (Якутия), Усть-Майский район, село Троицк, Мирушниченко, 13А	t	small
10847	85128	611	Республика Саха (Якутия), Усть-Майский район, Село Усть-Миль, Лесная, 15	t	small
10860	85142	624	Республика Саха (Якутия), Усть-Майский район, Поселок Югоренок, Ленина, 10	t	small
10855	85136	619	Республика Саха (Якутия), Усть-Майский район, Поселок Эльдикан, Промплощадка, 5	t	small
10858	85139	622	Республика Саха (Якутия), Усть-Майский район, Поселок Солнечный, Октябрьская, 2	t	medium
10859	85140	623	Республика Саха (Якутия), Усть-Майский район, Поселок Звездочка, Дражников, 9	t	small
120716	85125	608	Республика Саха (Якутия), Усть-Алданский район, с.Чериктей, Айхал, 13	t	small
10831	85112	595	Республика Саха (Якутия), Усть-Алданский район, село Элясин, Сынахская, 2	t	small
86027	85095	579	Республика Саха (Якутия), Усть-Алданский район, Чаран, Героя Бурцева, 42	f	small
120711	85109	592	Республика Саха (Якутия), Усть-Алданский район, село Хоногор, Тимофея Татаринова, 19	t	small
120714	85114	597	Республика Саха (Якутия), Усть-Алданский район, Хомустах, Ивана Бурнашева, 19	t	small
120705	85098	582	Республика Саха (Якутия), Усть-Алданский район, село Усун-Кюель, Героя Егорова, 17	t	medium
10857	85138	621	Республика Саха (Якутия), Усть-Алданский район, село Тумул, Ноторская, 12	t	small
10597	84885	361	Республика Саха (Якутия), Усть-Алданский район, село Тумул, Аммосова, 35	f	medium
120707	85101	585	Республика Саха (Якутия), Усть-Алданский район, поселок Танда, Андросова, 21/1	t	small
120706	85100	584	Республика Саха (Якутия), Усть-Алданский район, село Сырдах, Елизаветы Бурцевой, 11	t	medium
120712	85110	593	Республика Саха (Якутия), Усть-Алданский район, село Сасылыкан, Остойкинская, 2	t	small
120710	85108	591	Республика Саха (Якутия), Усть-Алданский район, село Огородтах, Анатолия Константинова, 5	t	medium
10841	85122	605	Республика Саха (Якутия), Усть-Алданский район, село Бээди, Центральная, 10	t	small
120704	85097	581	Республика Саха (Якутия), Усть-Алданский район, село Балаганнах, Михаила Николаева, 5	t	small
10448	84746	212	Республика Саха (Якутия), Усть-Алданский район, село Арылах, Яковлева, 7	t	small
10549	84836	313	Республика Саха (Якутия), Усть-Алданский район, село Арылах, Центральная, 53	t	large
10913	85194	677	Республика Саха (Якутия), Усть-Алданский район, село Арылах, Комсомольская, 13	t	small
120691	85026	510	Республика Саха (Якутия), Усть-Алданский район, село Арылах, Зверева, 33	t	small
10826	85107	590	Республика Саха (Якутия), Усть-Алданский район, село Арылах, Данилова, 12	t	small
120713	85113	596	Республика Саха (Якутия), Усть-Алданский район, село Ары-Тит, Аржакова, 5	t	small
10801	85081	565	Республика Саха (Якутия), Томпонский район, с.Теплый Ключ, Советская, 6	t	small
10809	85089	573	Республика Саха (Якутия), Томпонский район, с.Охотский Перевоз, Советская, 15	t	small
10800	85080	564	Республика Саха (Якутия), Томпонский район, с.Кескиль, Петра Алексеева, 11	t	small
10802	85082	566	Республика Саха (Якутия), Томпонский район, п.Аэропорт, Авиационная	t	small
10808	85088	572	Республика Саха (Якутия), Томпонский район, село Ударник, Феклы Павловой, 19	t	small
10799	85079	563	Республика Саха (Якутия), Томпонский район, Сайды, Амгинская, 14	t	small
10798	85078	562	Республика Саха (Якутия), Томпонский район, село Новый, Центральная, 6	t	small
10806	85086	570	Республика Саха (Якутия), Томпонский район, Крест-Хальджайы, Центральная, 27	t	medium
10779	85059	543	Республика Саха (Якутия), Таттинский район, с. Уолба, И.Слепцова, 18	t	small
10782	85062	546	Республика Саха (Якутия), Таттинский район, с. Туора-Кюель, Табахырова, 23	t	small
120699	85058	542	Республика Саха (Якутия), Таттинский район, село Усть-Татта, А.Данилова, 1	f	medium
120700	85065	549	Республика Саха (Якутия), Таттинский район, село Кыйы, Сабарайкина, 39	t	medium
10786	85066	550	Республика Саха (Якутия), Таттинский район, село Дайа-Амга, Кашкина, 4	t	small
10783	85063	547	Республика Саха (Якутия), Таттинский район, село Боробул, Кулаковского, 34/2	t	medium
120693	85035	519	Республика Саха (Якутия), Сунтарский район,, с.Кемпендяй, школьная, 9	t	small
10759	85039	523	Республика Саха (Якутия), Сунтарский район,, село Сунтар, Октябрьская, 59	f	medium
10762	85042	526	Республика Саха (Якутия), Сунтарский район, с.Сунтар, Ленина, 79	f	medium
10754	85034	518	Республика Саха (Якутия), Сунтарский район, с.Кюндяе, Юбилейная, 46	t	small
120697	85053	537	Республика Саха (Якутия), Сунтарский район, с.Куокуну, Октябрьская улица, 42	t	small
10768	85048	532	Республика Саха (Якутия), Сунтарский район, с.Аллага, Кузнецкая, 39	f	small
10752	85032	516	Республика Саха (Якутия), Сунтарский район, село Эльгяй, Сивцева, 38	f	large
10776	85056	540	Республика Саха (Якутия), Сунтарский район, поселок Хордогой, Ленина, 36	t	small
120694	85044	528	Республика Саха (Якутия), Сунтарский район, Хадан, Кэскил, 18	t	small
120696	85051	535	Республика Саха (Якутия), Сунтарский район, Усун-Кюель, Кокорина, 1	t	small
86026	85036	520	Республика Саха (Якутия), Сунтарский район, поселок Устье, Геодезическая, 4	f	small
120692	85027	511	Республика Саха (Якутия), Сунтарский район, село Тюбяй, Хаппар, 2	t	small
10763	85043	527	Республика Саха (Якутия), Сунтарский район, село Туойдах, Ананьева, 38	t	small
10751	85031	515	Республика Саха (Якутия), Сунтарский район, село Толон, Центральная, 37	f	small
120695	85047	531	Республика Саха (Якутия), Сунтарский район, Тенькя, Федорова, 10	t	small
10749	85029	513	Республика Саха (Якутия), Сунтарский район, село Кюкей, Самсонова, 17	t	small
120698	85054	538	Республика Саха (Якутия), Сунтарский район, поселок Крестях, Советская, 24	t	small
10765	85045	529	Республика Саха (Якутия), Сунтарский район, Илимнир, Сунтарская, 20	t	small
10766	85046	530	Республика Саха (Якутия), Сунтарский район, село Бордон, Мира, 45	t	medium
10741	85021	505	Республика Саха (Якутия), Среднеколымский район, с.Эбях, Молодежная, 3	t	small
10737	85017	501	Республика Саха (Якутия), Среднеколымский район, с.Аргахтах, 40 Лет Победы, 6	t	small
10742	85022	506	Республика Саха (Якутия), Среднеколымский район, Сылгы-Ытар, Чукрова, 29	t	small
120689	85020	504	Республика Саха (Якутия), Среднеколымский район, село Алеко-Кюель, Молодежная, 3	t	small
67856	85011	495	Республика Саха (Якутия), Оленекский район, Оленек, Октябрьская улица, 64	f	large
10733	85013	497	Республика Саха (Якутия), Оленекский район, село Жилинда, Октябрьская, 20	f	medium
10707	84987	471	Республика Саха (Якутия), Олекминский район, село Юнкюр, 60 Лет Октября, 15	t	medium
10702	84982	466	Республика Саха (Якутия), Олекминский район, Центральная Абага, Карла Миллера, 3	f	small
10710	84990	474	Республика Саха (Якутия), Олекминский район, село Хоринцы, Центральная, 12	t	small
10711	84991	475	Республика Саха (Якутия), Олекминский район, село Урицкое, Центральная, 3а	t	small
10716	84996	480	Республика Саха (Якутия), Олекминский район, Уолбут, пер.Школьный, 8	t	small
10706	84986	470	Республика Саха (Якутия), Олекминский район, село Улахан-Мунку, Верхняя, 2	t	small
10719	84999	483	Республика Саха (Якутия), Олекминский район, село Тяня, Алеши Алексеева, 8	t	small
10708	84988	472	Республика Саха (Якутия), Олекминский район, село Троицк, Центральная, 1/1	t	small
10715	84995	479	Республика Саха (Якутия), Олекминский район, Токко, Ойунского, 9	t	medium
10709	84989	473	Республика Саха (Якутия), Олекминский район, село Солянка, Советская, 61	t	small
10728	85008	492	Республика Саха (Якутия), Олекминский район, село Селиваново	t	small
10713	84993	477	Республика Саха (Якутия), Олекминский район, село Саныяхтах, Гагарина, 17	t	small
10723	85003	487	Республика Саха (Якутия), Олекминский район, Олекминск, Урицкого, 2	f	large
10727	85007	491	Республика Саха (Якутия), Олекминский район, Олекминск, Тахватулина, 37а	f	medium
10699	84979	463	Республика Саха (Якутия), Олекминский район, село Нерюктяйинск-2, Центральная, 22	t	small
10698	84979	462	Республика Саха (Якутия), Олекминский район, село Нерюктяйинск-2, Центральная, 22	t	small
10712	84992	476	Республика Саха (Якутия), Олекминский район, село Марха, Лесная, 6	t	small
10714	84994	478	Республика Саха (Якутия), Олекминский район, село Малыкан, Лесная, 3	t	small
10704	84984	468	Республика Саха (Якутия), Олекминский район, село Кяччи, Центральная, 18	t	small
10700	84980	464	Республика Саха (Якутия), Олекминский район, Кыллах, Майская, 21	t	small
10717	84997	481	Республика Саха (Якутия), Олекминский район, Куду-Кюэль, Карташова, 9	t	small
10694	84975	458	Республика Саха (Якутия), Олекминский район, село Иннях, мкрн.Нижний, 21	t	small
10695	84976	459	Республика Саха (Якутия), Олекминский район, село Дельгей, Центральная, 19	t	small
10701	84981	465	Республика Саха (Якутия), Олекминский район, село Даппарай, Партизанская улица, 5	t	small
10696	84977	460	Республика Саха (Якутия), Олекминский район, село Дабан, Центральная, 7	t	small
10683	84964	447	Республика Саха (Якутия), Оймяконский район, Ючюгей, Школа	t	small
10688	84969	452	Республика Саха (Якутия), Оймяконский район, Хара-Тумул, Детский сад	t	small
10674	84955	438	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, м-н Нерский, 61	t	small
10678	84959	442	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, м-н Индигирский	t	small
10676	84957	440	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Молодежная, 1, здание ОП Теплоэнергосервис	f	medium
10681	84962	445	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Ленина, 1, здание ДК Металлург	f	small
10680	84961	444	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Коммунистическая, 15, здание МУДО Пегас	f	medium
10679	84960	443	Республика Саха (Якутия), Оймяконский район, Поселок Усть-Нера, Автотранспортная, 2, контора ЗЭС	f	small
10682	84963	446	Республика Саха (Якутия), Оймяконский район, Поселок Артык, Центральная, 8, Дом культуры	t	small
10684	84965	448	Республика Саха (Якутия), Оймяконский район, село Орто-Балаган, Школа	t	small
120685	84967	450	Республика Саха (Якутия), Оймяконский район, село Оймякон, Школа	t	small
10690	84971	454	Республика Саха (Якутия), Оймяконский район, Куйдусун, РЭС	t	small
10664	84945	428	Республика Саха (Якутия), Нюрбинский район, с. Акана, П.С. Егорова, 15	t	small
10670	84951	434	Республика Саха (Якутия), Нюрбинский район, Энгольжа, Центральная, 29а	t	small
10659	84940	423	Республика Саха (Якутия), Нюрбинский район, Чаппанда, Амосова, 1	f	medium
10655	84935	419	Республика Саха (Якутия), Нюрбинский район, село Сюля, Дмитрия Федорова, 10/1	f	small
10652	84932	416	Республика Саха (Якутия), Нюрбинский район, Октябрьский наслег, Село Антоновка, Октябрьская, 25	f	large
10671	84952	435	Республика Саха (Якутия), Нюрбинский район, Поселок Бысыттах, Ленина, 45	t	small
10653	84933	417	Республика Саха (Якутия), Нюрбинский район, Нефтебаза, 1	f	small
10661	84942	425	Республика Саха (Якутия), Нюрбинский район, село Киров, Револия Иванова, 41	t	small
120684	84937	421	Республика Саха (Якутия), Нюрбинский район, Арангастах, Арангастахская, 20	t	small
10641	84921	405	Республика Саха (Якутия), Нижнеколымский район, Походский наслег, Набережная, 21	t	small
10637	84917	401	Республика Саха (Якутия), Нижнеколымский район, Поселок Черский, Октябрьская , 1	f	large
10612	84899	376	Республика Саха (Якутия), Нерюнгринский район, Нерюнгри, Карла Маркса, 8/2	f	large
120680	84889	365	Республика Саха (Якутия), Намский район, с.Фрунзе, Д.Потапова, 18	t	small
10595	84883	359	Республика Саха (Якутия), Намский район, с.Красная Деревня, Решетникова, 10	t	small
86031	84881	357	Республика Саха (Якутия), Намский район, с.Аппаны, Лена, 22	f	small
120667	84863	339	Республика Саха (Якутия), Намский район, село Ымыяхтах, Центральная, 9	f	medium
120672	84871	347	Республика Саха (Якутия), Намский район, Хатас, Леонтьева, 2	t	small
120681	84891	367	Республика Саха (Якутия), Намский район, Сыгыннах, Слепцова, 23	t	small
10599	84887	363	Республика Саха (Якутия), Намский район, Село Маймага, Н.Ф.Собакина, 19	f	small
120669	84866	342	Республика Саха (Якутия), Намский район, село Партизан, Школьная, 23	f	medium
86030	84867	343	Республика Саха (Якутия), Намский район, село Никольский, Е.Протопопова, 30	f	small
120675	84878	354	Республика Саха (Якутия), Намский район, Намцы, Чернышевского, 36	f	medium
120676	84879	355	Республика Саха (Якутия), Намский район, Намцы, Ойунского, 2	f	medium
10588	84876	352	Республика Саха (Якутия), Намский район, Намцы, Винокурова, 8	f	medium
120674	84875	351	Республика Саха (Якутия), Намский район, село Намцы, Ленина, 24	f	medium
10582	84870	346	Республика Саха (Якутия), Намский район, Кюренг-Ат, Захара Винокурова, 4	t	small
10577	84865	341	Республика Саха (Якутия), Намский район, село Кысыл-Сыр, Северная, 3	f	small
10388	84686	152	Республика Саха (Якутия), Намский район, село Кысыл-Сыр, Ленина, 12В	f	medium
10387	84685	151	Республика Саха (Якутия), Намский район, село Кысыл-Сыр, Интернациональная, 3	f	medium
134579	94438	150	Республика Саха (Якутия), Намский район, село Кысыл-Сыр, Газовиков, 1	f	medium
120668	84864	340	Республика Саха (Якутия), Намский район, село Кысыл-Сыр, Аммосова, 76	f	medium
10585	84873	349	Республика Саха (Якутия), Намский район, село Крест-Кытыл, Охлопкова - Соттоя, 9	f	medium
120673	84872	348	Республика Саха (Якутия), Намский район, село Крест-Кытыл, Охлопкова - Соттоя, 7	f	medium
120670	84868	344	Республика Саха (Якутия), Намский район, село Ергёлёх (Тастах), Аммосова, 3	t	small
10594	84882	358	Республика Саха (Якутия), Намский район, Графский Берег, Центральная, 18	t	medium
120679	84888	364	Республика Саха (Якутия), Намский район, Булус, Центральная, 34	t	small
10592	84880	356	Республика Саха (Якутия), Намский район, Аппаны, Лена, 29	f	small
10572	84860	336	Республика Саха (Якутия), Момский район, с. Чумпу-Кытыл, Центральная, 31	t	small
10569	84857	333	Республика Саха (Якутия), Момский район, Суон-Тиит, 16	t	small
10571	84859	335	Республика Саха (Якутия), Момский район, село Соболох, Тихона Толомона, 25	t	small
10573	84861	337	Республика Саха (Якутия), Момский район, село Сасыр, Н.И.Слепцова, 13	t	small
10574	84862	338	Республика Саха (Якутия), Момский район, село Кулун-Елбют, М.Черемкина, 28	t	small
10570	84858	334	Республика Саха (Якутия), Момский район, Буор-Сысы, Кэскил, 41	t	small
10551	84838	315	Республика Саха (Якутия), Мирнинский район, п. Сюльдюкар, Центральная, 9	t	small
10550	84837	314	Республика Саха (Якутия), Мирнинский район, п. Заря, Иванова, 25	t	small
10556	84844	320	Республика Саха (Якутия), Мирнинский район, поселок Чернышевский, Энтузиастов, Кадетская школа-интернат	f	medium
10563	84850	327	Республика Саха (Якутия), Мирнинский район, Удачный, 50 лет ЯАССР, 7	f	medium
10546	84833	310	Республика Саха (Якутия), Мирнинский район, Мирный, Тихонова, 3	f	large
10562	84849	326	Республика Саха (Якутия), Мирнинский район, Айхал, Иванова, 4	f	medium
10505	84794	269	Республика Саха (Якутия), Мегино-Кангаласский район, с. Хапчагай, Центральная, 3	t	small
10791	85071	555	Республика Саха (Якутия), Мегино-Кангаласский район, Ытык-Кюель, Ойунского, 24	f	large
10519	84809	283	Республика Саха (Якутия), Мегино-Кангаласский район, село Чюйя, Скрябина, 22	t	small
10514	84804	278	Республика Саха (Якутия), Мегино-Кангаласский район, село Хочо, Советская, 2	t	small
10527	84818	291	Республика Саха (Якутия), Мегино-Кангаласский район, село Хоробут, Сергучева, 4	f	medium
120703	85094	578	Республика Саха (Якутия), Мегино-Кангаласский район, село Хомустах	t	medium
120662	84643	107	Республика Саха (Якутия), Мегино-Кангаласский район, село Хомустах	t	small
10663	84944	427	Республика Саха (Якутия), Мегино-Кангаласский район, село Хомустах, Ленина, 46а	t	small
10504	84793	268	Республика Саха (Якутия), Мегино-Кангаласский район, село Хатылыма, Лукина, 3	t	small
10526	84817	290	Республика Саха (Якутия), Мегино-Кангаласский район, село Хаптагай, Советская, 3	t	medium
10361	84661	125	Республика Саха (Якутия), Мегино-Кангаласский район, поселок Улухан-Кюель, М. Потаповой, 13	t	medium
10530	84821	294	Республика Саха (Якутия), Мегино-Кангаласский район, село Тюнгюлю, Партизанская, 13	t	medium
10689	84970	453	Республика Саха (Якутия), Мегино-Кангаласский район, село Томтор, Борогонский 2-й наслег, школа	t	medium
10509	84798	273	Республика Саха (Якутия), Мегино-Кангаласский район, село Томтор, Пономарева, 10	t	small
10780	85060	544	Республика Саха (Якутия), Мегино-Кангаласский район, село Томтор, Баягантайская, 23/2	t	medium
10513	84803	277	Республика Саха (Якутия), Мегино-Кангаласский район, село Телиги, Саввина, 6/1	t	small
10508	84797	272	Республика Саха (Якутия), Мегино-Кангаласский район, село Тарат	t	small
10525	84816	289	Республика Саха (Якутия), Мегино-Кангаласский район, село Табага, Совхозная, 12	t	medium
10516	84806	280	Республика Саха (Якутия), Мегино-Кангаласский район, село Сымах, Колесова, 18	t	small
10515	84805	279	Республика Саха (Якутия), Мегино-Кангаласский район, село Суола, Птицына, 3	t	small
10512	84802	276	Республика Саха (Якутия), Мегино-Кангаласский район, село Суола, Калинина, 19	t	small
10518	84808	282	Республика Саха (Якутия), Мегино-Кангаласский район, село Рассолода, Петрова-Халлааскы, 9	t	small
10528	84819	292	Республика Саха (Якутия), Мегино-Кангаласский район, село Петровка, Харанская, 11/1	f	medium
10502	84791	266	Республика Саха (Якутия), Мегино-Кангаласский район, село Павловск, Молодежная, 4	t	large
10500	84789	264	Республика Саха (Якутия), Мегино-Кангаласский район, поселок Нижний Бестях, Ленина, 37	f	large
134583	84790	265	Республика Саха (Якутия), Мегино-Кангаласский район, поселок городского типа Нижний Бестях, Ленина, 107	f	large
10517	84807	281	Республика Саха (Якутия), Мегино-Кангаласский район, село Матта, Механизаторов	t	small
10498	84787	262	Республика Саха (Якутия), Мегино-Кангаласский район, село Майя, Манчаары, 11	f	large
10499	84788	263	Республика Саха (Якутия), Мегино-Кангаласский район, село Майя, Майинская, 13	f	large
10497	84786	261	Республика Саха (Якутия), Мегино-Кангаласский район, село Майя, Героя Попова, 51	f	large
10522	84813	286	Республика Саха (Якутия), Мегино-Кангаласский район, село Ломтука, Семена Назарова, 1	t	small
10510	84799	274	Республика Саха (Якутия), Мегино-Кангаласский район, село Даркылах, Советская, 12	t	small
10507	84796	271	Республика Саха (Якутия), Мегино-Кангаласский район, село Бёкё, Октябрьская, 4	t	small
10506	84795	270	Республика Саха (Якутия), Мегино-Кангаласский район, село Бырама, Матросова, 20/1	t	small
10825	85106	589	Республика Саха (Якутия), Мегино-Кангаласский район, село Бейдинга, Пестрякова, 4/1	t	small
10524	84815	288	Республика Саха (Якутия), Мегино-Кангаласский район, село Балыктах, Балыктахская, 2	t	medium
10496	84785	260	Республика Саха (Якутия), Ленский район, с. Натора, Школьный переулок, 8	t	small
10493	84782	257	Республика Саха (Якутия), Ленский район, с. Батамай, Центральная, 17	t	small
10465	84763	229	Республика Саха (Якутия), Ленский район, село Ярославский, Полярная, 1	t	small
10488	84777	252	Республика Саха (Якутия), Ленский район, село Чамча, пер. Клубный, 11	t	small
10466	84764	230	Республика Саха (Якутия), Ленский район, село Хамра, Центральная, 8	t	small
10495	84784	259	Республика Саха (Якутия), Ленский район, село Турукта, Боровая, 5	t	small
10464	84762	228	Республика Саха (Якутия), Ленский район, Поселок Пеледуй, Центральная, 3	t	large
10462	84760	226	Республика Саха (Якутия), Ленский район, Поселок Пеледуй, Центральная, 18	t	medium
10457	84755	221	Республика Саха (Якутия), Ленский район, Поселок Витим, Октябрьская, 30	t	large
10459	84757	223	Республика Саха (Якутия), Ленский район, Поселок Витим, Аэропорт, 1	f	medium
10487	84776	251	Республика Саха (Якутия), Ленский район, поселок Орто-Нахара, Центральная, 26	t	small
10490	84779	254	Республика Саха (Якутия), Ленский район, Нюя Северная, Школьная, 3	t	small
10494	84783	258	Республика Саха (Якутия), Ленский район, Нюя, Октябрьская, 21	t	medium
10492	84781	256	Республика Саха (Якутия), Ленский район, Мурья, Углестроителей, 7	t	small
10470	84768	234	Республика Саха (Якутия), Ленский район, Ленск, Фурманова, 43	f	small
10476	84774	240	Республика Саха (Якутия), Ленский район, Ленск, Победы, 15 А	f	large
10473	84771	237	Республика Саха (Якутия), Ленский район, Ленск, Ленина, 59	f	large
10489	84778	253	Республика Саха (Якутия), Ленский район, Дорожный, Лесная, 9	t	small
10491	84780	255	Республика Саха (Якутия), Ленский район, поселок Беченча, Советская, 32	t	small
10893	85174	657	Республика Саха (Якутия), Ковылкинский район, село Покровск, Тимирязева, 1/1	f	medium
10453	84751	217	Республика Саха (Якутия), Кобяйский район, с. Ситте, Кирова, 14	t	small
10445	84743	209	Республика Саха (Якутия), Кобяйский район, с. Арыктах, Молодежная, 22	t	small
10451	84749	215	Республика Саха (Якутия), Кобяйский район, Сеген-Кюель, Алексеева, 4	t	small
10455	84753	219	Республика Саха (Якутия), Кобяйский район, Себян-Кюель, Ламутского, 52	t	small
10454	84752	218	Республика Саха (Якутия), Кобяйский район, Себян-Кюель, Ламутского, 52	t	small
10431	84730	195	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Советская, 19	f	small
10435	84733	199	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Нефтебаза, 9	f	small
10428	84727	192	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Ленина, 2	f	small
10426	84725	190	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Ленина, 51	f	small
134582	84731	196	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Кочнева, 17	f	medium
10434	84732	198	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Геолог, 19	f	small
10433	84732	197	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Геолог, 19	f	small
10427	84726	191	Республика Саха (Якутия), Кобяйский район, Поселок Сангар, Алексеева, 3	f	small
10446	84744	210	Республика Саха (Якутия), Кобяйский район, село Люксюгюн, Кралина, 9	t	small
10438	84736	202	Республика Саха (Якутия), Кобяйский район, село Кобяй, Калинина, 4	t	medium
10439	84737	203	Республика Саха (Якутия), Кобяйский район, Кобяй, Терехова, 6/2	f	medium
10437	84735	201	Республика Саха (Якутия), Кобяйский район, село Аргас, Иванова, 15/2	t	small
10423	84722	187	Республика Саха (Якутия), Жиганский район, Кыстатыам, Шемякова, 5	t	small
10422	84720	186	Республика Саха (Якутия), Жиганский район, Жиганск, Чкалова, 6	f	small
10395	84694	159	Республика Саха (Якутия), Горный район, село Эбя, Гоголева, 16	t	small
10418	84716	182	Республика Саха (Якутия), Горный район, село Орто-Сурт, Мира, 9а	t	small
10412	84710	176	Республика Саха (Якутия), Горный район, село Магарас, Октябрьская, 10	t	medium
10420	84718	184	Республика Саха (Якутия), Горный район, село Кюёрелях, Школьная, 3	t	small
10419	84717	183	Республика Саха (Якутия), Горный район, село Кептин, Советская, 31	t	small
10416	84714	180	Республика Саха (Якутия), Горный район, село Ерт	t	small
10415	84713	179	Республика Саха (Якутия), Горный район, село Дикимдя (Мытах), Строда, 1	t	small
10654	84934	418	Республика Саха (Якутия), Горный район, село Дикимдя (Мытах), Озерная, 5	f	small
10411	84709	175	Республика Саха (Якутия), Горный район, Бяс-Кюель, Лонгинова, 19	t	small
10413	84711	177	Республика Саха (Якутия), Горный район, село Бердигестях, С.П.Данилова, 14	f	large
10410	84708	174	Республика Саха (Якутия), Горный район, село Бердигестях, Октябрьская, 18	f	large
10414	84712	178	Республика Саха (Якутия), Горный район, село Бердигестях, Данилова, 61А	f	large
10417	84715	181	Республика Саха (Якутия), Горный район, село Асыма, Чээмпи, 2	f	small
10389	84687	153	Республика Саха (Якутия), Вилюйский район, с.Хампа, Ст. Гоголева, 39	f	small
10409	81792	173	Республика Саха (Якутия), Вилюйский район, с. Кюбяинде, Победы, 9	t	small
10408	84707	172	Республика Саха (Якутия), Вилюйский район, село Чинекя, Комсомольская, 3а	f	medium
10393	84691	157	Республика Саха (Якутия), Вилюйский район, село Чай, Советская, 20	t	small
10398	84697	162	Республика Саха (Якутия), Вилюйский район, Усун, Ойунского, 24	f	medium
10405	84704	169	Республика Саха (Якутия), Вилюйский район, Тосу, Ленина, 18	f	medium
10404	84703	168	Республика Саха (Якутия), Вилюйский район, село Тербяс, Тюнгская, 2	f	small
10407	84706	171	Республика Саха (Якутия), Вилюйский район, село Сыдыбыл, Октябрьская, 27	f	small
10397	84696	161	Республика Саха (Якутия), Вилюйский район, село Кеданда, Юбилейная, 11	f	small
10391	84689	155	Республика Саха (Якутия), Вилюйский район, Илбенге, М.А.Алексеева, 26	t	small
134580	84693	158	Республика Саха (Якутия), Вилюйский район, село Екюндю, Ф.Константинова, 1/5	f	small
10403	84702	167	Республика Саха (Якутия), Вилюйский район, Балагачча, Миронова, 7	t	small
10373	84674	137	Республика Саха (Якутия), Верхоянский район, с.Юттях, Советская, 10а	t	small
10366	84667	130	Республика Саха (Якутия), Верхоянский район, с.Юнкюр, Центральная, 23	t	small
10362	84662	126	Республика Саха (Якутия), Верхоянский район, с.Бетенкес, Школьная, 11	t	small
10364	84665	128	Республика Саха (Якутия), Верхоянский район, село Томтор, Центральная, 2	t	small
10369	84670	133	Республика Саха (Якутия), Верхоянский район, Томтор, Эллэ, 23	t	small
10365	84666	129	Республика Саха (Якутия), Верхоянский район, Токума, Аргаа, 2	t	small
10370	84671	134	Республика Саха (Якутия), Верхоянский район, село Суордах, Центральная, 11	t	small
10363	84663	127	Республика Саха (Якутия), Верхоянский район, село Сайды, Колхозная, 33	t	small
10360	84660	124	Республика Саха (Якутия), Верхоянский район, Поселок Эсэ-Хайя, Шадрина, 6	t	small
10358	84658	122	Республика Саха (Якутия), Верхоянский район, Поселок Батагай, Центральная, 1/1	t	small
10354	84654	118	Республика Саха (Якутия), Верхоянский район, Поселок Батагай, Ленина, 19	f	medium
10368	84669	132	Республика Саха (Якутия), Верхоянский район, село Боронук, Центральная, 27	t	small
10357	84657	121	Республика Саха (Якутия), Верхоянский район, поселок Батагай, Малоозерная, 4	f	small
10375	84676	139	Республика Саха (Якутия), Верхоянский район, поселок Барылас, поселок Горьковский, Портовская, 4	t	small
10344	84644	108	Республика Саха (Якутия), Верхнеколымский район, село Угольное, Дорожная, 17	t	small
10346	84646	110	Республика Саха (Якутия), Верхнеколымский район, Село Улус-Кюель, Спортивная, 9	t	small
10353	84653	117	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Молодежная, 5	f	small
10350	84650	114	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Ленина, 17	f	small
10352	84652	116	Республика Саха (Якутия), Верхнеколымский район, Поселок Зырянка, Заводская, 1	f	small
10347	84647	111	Республика Саха (Якутия), Верхнеколымский район, Нелемное, Текки Одулока, 19	t	small
10339	84639	103	Республика Саха (Якутия), Верхневилюйский район, с.Сургулук, Центральная, 5	t	small
10321	84621	85	Республика Саха (Якутия), Верхневилюйский район, с.Нам, Хомустах, 2	t	small
10332	84632	96	Республика Саха (Якутия), Верхневилюйский район, с.Май, Передовиков, 7	t	small
10335	84635	99	Республика Саха (Якутия), Верхневилюйский район, с.Магасс, П. Васильева, 5, Магасский наслег	t	small
10340	84640	104	Республика Саха (Якутия), Верхневилюйский район, с.Кырыкый, Советская, 2	t	small
10338	84638	102	Республика Саха (Якутия), Верхневилюйский район, с.Кетердях, Проезжая, 4	t	small
10315	84615	79	Республика Саха (Якутия), Верхневилюйский район, с.Едюгей, Школьная, 11	f	medium
10341	84641	105	Республика Саха (Якутия), Верхневилюйский район, с.Дюллюкю, Будургэй, 1	f	small
10333	84633	97	Республика Саха (Якутия), Верхневилюйский район, с.Далыр, Октябрьская, 1	t	small
10329	84629	93	Республика Саха (Якутия), Верхневилюйский район, поселок Хоро, Булгунняхтах, 2	f	small
10325	84625	89	Республика Саха (Якутия), Верхневилюйский район, Тамалакан, Семена Руфова, 17	t	small
10324	84624	88	Республика Саха (Якутия), Верхневилюйский район, село Оросу, Набережная, 23	f	small
10318	84618	82	Республика Саха (Якутия), Верхневилюйский район, село Оргет, Комсомольская, 15	t	small
10330	84630	94	Республика Саха (Якутия), Верхневилюйский район, село Онхой, Центральная, 31	t	small
10322	84622	86	Республика Саха (Якутия), Верхневилюйский район, Намцы, Ленина, 30	t	small
10334	84634	98	Республика Саха (Якутия), Верхневилюйский район, село Кюль, Тамах, 7	t	small
10399	84698	163	Республика Саха (Якутия), Верхневилюйский район, село Кюлекян, Центральная, 1	t	small
10342	84642	106	Республика Саха (Якутия), Верхневилюйский район, село Дюллюкю, Чыыйык, 11	f	small
10314	84614	78	Республика Саха (Якутия), Верхневилюйский район, село Верхневилюйск, Дмитрия Спиридонова, 23	f	medium
10319	84619	83	Республика Саха (Якутия), Верхневилюйский район, поселок Быракан, П.А.Васильева, 38	t	small
10336	84636	100	Республика Саха (Якутия), Верхневилюйский район, село Ботулу, Центральная, 25/1	t	small
10323	84623	87	Республика Саха (Якутия), Верхневилюйский район, село Балаганнах, Боороо, 29	t	small
10309	84608	73	Республика Саха (Якутия), Булунский район, с. Тюметинский, Центральная, 1	t	small
67865	84602	67	Республика Саха (Якутия), Булунский район, п. Тикси, 407	f	large
10308	84607	72	Республика Саха (Якутия), Булунский район, Сиктях, Береговая, 6	t	small
10305	84604	69	Республика Саха (Якутия), Булунский район, село Кюсюр, Советская, 10	f	medium
10298	84597	62	Республика Саха (Якутия), Анабарский район, Саскылах, Авиаторов, 3	t	small
10288	84587	52	Республика Саха (Якутия), Амгинский район, Чапчылганский наслег, 50 лет МТС, 11	t	medium
10289	84588	53	Республика Саха (Якутия), Амгинский район, Чакыр, Ленина, 43	t	small
120701	85068	552	Республика Саха (Якутия), Амгинский район, село Харбалах, Николаева, 1	t	medium
10326	84626	90	Республика Саха (Якутия), Амгинский район, село Харбалах, Исидора Барахова, 10	f	small
10290	84589	54	Республика Саха (Якутия), Амгинский район, поселок Покровка, Октябрьская, 22	f	small
10292	84591	56	Республика Саха (Якутия), Амгинский район, село Олом (Олом-Кюель), П. Яковлева, 29	t	small
10285	84584	49	Республика Саха (Якутия), Амгинский район, село Мяндиги, Мира, 2	t	small
25206	74157	930	Приморский край, Уссурийск, Пушкина, 77	f	large
10291	84590	55	Республика Саха (Якутия), Амгинский район, Болугур, Ленина, 48	t	medium
10287	84586	51	Республика Саха (Якутия), Амгинский район, Бетюнский наслег, М.Нестерева, 65	t	medium
10294	84593	58	Республика Саха (Якутия), Амгинский район, Алтанцы, Петрова, 25	t	medium
10277	84576	41	Республика Саха (Якутия), Аллаиховский район, с. Оленегорск, Щерьачкова, 12	t	small
10278	84577	42	Республика Саха (Якутия), Аллаиховский район, село Русское Устье, Центральная, 12/1	t	small
10743	85023	507	Республика Саха (Якутия), Алданский район, с.Сватай, улица Победы, 6	t	small
10239	84539	3	Республика Саха (Якутия), Алданский район, с. Куберганя, Центральная, 1	t	small
10271	84570	35	Республика Саха (Якутия), Алданский район, село Якокут, Октябрьская, 3	t	small
10255	84554	19	Республика Саха (Якутия), Алданский район, поселок Якоит, Советская, 38	t	small
10260	84559	24	Республика Саха (Якутия), Алданский район, поселок Ыллымах, Буровая, 2	t	small
10444	84742	208	Республика Саха (Якутия), Алданский район, поселок Чагда, Северная, 1/5	t	small
10274	84573	38	Республика Саха (Якутия), Алданский район, поселок Чагда, Матросова, 4	t	small
10272	84571	36	Республика Саха (Якутия), Алданский район, село Хатыстыр, 50 лет Октября, 14	f	medium
10371	84672	135	Республика Саха (Якутия), Алданский район, село Хайысардах, Школьная, 7	t	small
10259	84558	23	Республика Саха (Якутия), Алданский район, село Улу, Центральная, 4	t	small
10273	84572	37	Республика Саха (Якутия), Алданский район, село Угоян, Центральная, 41	t	small
67863	84563	28	Республика Саха (Якутия), Алданский район, Томмот, Школьная, 13	f	large
10262	84561	26	Республика Саха (Якутия), Алданский район, Томмот, Укуланская, 7	t	small
10261	84560	25	Республика Саха (Якутия), Алданский район, Томмот, Совхозная, 18/1	t	small
10265	84564	29	Республика Саха (Якутия), Алданский район, Томмот, Ленина, 24	t	large
10263	84562	27	Республика Саха (Якутия), Алданский район, Томмот, Захарова, 12	f	large
10552	84840	316	Республика Саха (Якутия), Алданский район, поселок Таас-Юрях, Степана Попова, 13	f	medium
134581	84729	194	Республика Саха (Якутия), Алданский район, Сангар, Горбунова, 33	f	small
10258	84557	22	Республика Саха (Якутия), Алданский район, поселок Нижний Куранах, Юбилейная, 15А	f	large
10257	84556	21	Республика Саха (Якутия), Алданский район, поселок Нижний Куранах, Школьная, 25	f	large
10256	84555	20	Республика Саха (Якутия), Алданский район, поселок Нижний Куранах, Школьная, 19	t	large
10738	85018	502	Республика Саха (Якутия), Алданский район, Налимск, Слепцова, 37	t	small
10269	84568	33	Республика Саха (Якутия), Алданский район, поселок городского типа Ленинский, Ленина, 36	t	large
10270	84569	34	Республика Саха (Якутия), Алданский район, поселок городского типа Лебединый, Октябрьская, 23	t	medium
10267	84566	31	Республика Саха (Якутия), Алданский район, село Кутана, Школьная, 4	t	small
10254	84553	18	Республика Саха (Якутия), Алданский район, село Верхний Куранах, Разрезная, 1	t	small
10345	84645	109	Республика Саха (Якутия), Алданский район, Верхнеколымский село , Советская, 17	t	small
10268	84567	32	Республика Саха (Якутия), Алданский район, Большой Нимныр, Школьная, 19	t	small
10246	84546	10	Республика Саха (Якутия), Алданский район, Алдан, Строителей, 8	f	large
10249	84549	13	Республика Саха (Якутия), Алданский район, Алдан, Пролетарская, 1А	f	medium
10250	84549	14	Республика Саха (Якутия), Алданский район, Алдан, Пролетарская, 1А	f	large
10248	84548	12	Республика Саха (Якутия), Алданский район, Алдан, Октябрьская, 1	f	large
10247	84547	11	Республика Саха (Якутия), Алданский район, Алдан, Ленина, 27	f	large
10251	84550	15	Республика Саха (Якутия), Алданский район, Алдан, Калинина, 2/5	f	large
10253	84552	17	Республика Саха (Якутия), Алданский район, Алдан, Гагарина , 10	f	large
10252	84551	16	Республика Саха (Якутия), Алданский район, Алдан, Билибина, 26А	f	large
10245	84545	9	Республика Саха (Якутия), Алданский район, Алдан, 50 лет ВЛКСМ, 14	f	large
10244	84544	8	Республика Саха (Якутия), Алданский район, Алдан, 50 лет ВЛКСМ, 123	f	medium
10242	84542	6	Республика Саха (Якутия), Абыйский район, с. Кенг-Кюель, Маркова С.П, 1	t	small
10243	84543	7	Республика Саха (Якутия), Абыйский район, Сутуруоха, Ефимова, 11	t	small
10241	84541	5	Республика Саха (Якутия), Абыйский район, село Деску, Оттох-Атахская, 10	t	small
67862	84538	2	Республика Саха (Якутия), Абыйский район, поселок Белая Гора, Ефимова, 7/2	f	large
10910	85191	674	Республика Саха (Якутия), Чурапчинский район, село Мындагай, Ленина, 11	f	medium
10443	84741	207	Республика Саха (Якутия),  Кобяйский район, с. Мастах, Советская, 10/1	t	small
10295	84594	59	Республика Саха (Якутия), Амгинский район, Сатагай, Лукина, 27	t	small
10240	84540	4	Республика Саха (Якутия), Абыйский район, Сыаганнах, Ильяховой, 31	t	small
25452	74382	1187	Приморский край, Фокино, Центральная, 25	f	medium
25447	74377	1182	Приморский край, Фокино, Центральная, 1	f	large
25450	74380	1185	Приморский край, Фокино, Усатого, 18	f	large
25449	74379	1184	Приморский край, Фокино, Постникова, 18	f	large
25448	74378	1183	Приморский край, Фокино, Постникова, 4	f	large
25453	74383	1188	Приморский край, Фокино, Карла Маркса, 37А	f	large
25454	74384	1189	Приморский край, Фокино, Дальняя, 28	t	medium
25231	74176	955	Приморский край, Уссурийск, Чичерина, 146	f	large
25233	74178	957	Приморский край, Уссурийск, Тургенева, 113	f	small
25232	74177	956	Приморский край, Уссурийск, Тургенева, 3	f	large
25243	74188	967	Приморский край, Уссурийск, Топоркова, 126	f	large
25245	74190	969	Приморский край, Уссурийск, Теодора Тихого, 9	f	large
25214	74163	938	Приморский край, Уссурийск, Советская, 35	f	large
25201	74152	925	Приморский край, Уссурийск, Советская, 15	f	large
25242	74187	966	Приморский край, Уссурийск, Слободская, 5	f	large
25240	74185	964	Приморский край, Уссурийск, Слободская, 49	f	large
25260	74204	984	Приморский край, Уссурийск, Сельскохозяйственная, 23	f	medium
25235	74180	959	Приморский край, Уссурийск, Садовая, 1	f	large
25237	74182	961	Приморский край, Уссурийск, Русская, 10	f	large
25236	74181	960	Приморский край, Уссурийск, Русская, 35	f	large
113278	74531	1026	Приморский край, Уссурийск, Раздольная, 12	f	\N
25215	74164	939	Приморский край, Уссурийск, Пушкина, 11	f	large
25204	74155	928	Приморский край, Уссурийск, Пушкина, 88	f	large
25238	74183	962	Приморский край, Уссурийск, Проспект Блюхера, 44	f	large
25251	74196	975	Приморский край, Уссурийск, Переулок Тихий, 4-1	f	large
25247	74192	971	Приморский край, Уссурийск, Переулок Мурзинцева, 26	f	medium
25213	74162	937	Приморский край, Уссурийск, Октябрьская, 59	f	large
25205	74156	929	Приморский край, Уссурийск, Октябрьская, 58	f	large
25222	74170	946	Приморский край, Уссурийск, Никитина, 6	f	large
113277	74530	1025	Приморский край, Уссурийск, Некрасова, 35	f	\N
25227	74174	951	Приморский край, Уссурийск, Некрасова, 115	f	medium
25224	74171	948	Приморский край, Уссурийск, Некрасова, 209	f	large
25221	74169	945	Приморский край, Уссурийск, Некрасова, 291	f	small
25259	74203	983	Приморский край, Уссурийск, Ленинградская, 42	f	large
25298	74168	1022	Приморский край, Уссурийск, Ленинградская, 59	f	large
25220	74168	944	Приморский край, Уссурийск, Ленинградская, 59	f	large
25252	74197	976	Приморский край, Уссурийск, Ленина, 80	f	large
25217	74014	941	Приморский край, Уссурийск, Ленина, 144	f	large
25230	74014	954	Приморский край, Уссурийск, Ленина, 144	f	large
25218	74166	942	Приморский край, Уссурийск, Крестьянская, 55	f	large
25254	74172	978	Приморский край, Уссурийск, Короленко, 11А	f	large
25225	74172	949	Приморский край, Уссурийск, Короленко, 11А	f	large
25226	74173	950	Приморский край, Уссурийск, Комсомольская, 77	f	large
25256	74200	980	Приморский край, Уссурийск, Комарова, 55	f	large
25200	74151	924	Приморский край, Уссурийск, Карбышева, 27	f	large
25223	73962	947	Приморский край, Уссурийск, Ильюшина, 3	f	large
25229	73962	953	Приморский край, Уссурийск, Ильюшина, 3	f	large
25216	74165	940	Приморский край, Уссурийск, Горького, 69А	f	large
25212	74161	936	Приморский край, Уссурийск, Горького, 22	f	large
25255	74199	979	Приморский край, Уссурийск, Владивостокское шоссе, 113А	f	large
25248	74193	972	Приморский край, Уссурийск, Владивостокское шоссе, 36	f	large
25246	74191	970	Приморский край, Уссурийск, Владивостокское шоссе, 26А	f	large
25219	74167	943	Приморский край, Уссурийск, Амурская, 41	f	large
25199	74150	923	Приморский край, Уссурийск, Агеева, 59	f	large
25198	74149	922	Приморский край, Уссурийск, Агеева, 75А	f	large
25244	74189	968	Приморский край, Уссурийск, проспект Блюхера, 10	f	medium
25208	74159	932	Приморский край, Уссурийск, Тимирязева, 33	f	large
25203	74154	927	Приморский край, Уссурийск, Краснознаменная, 80	f	medium
25202	74153	926	Приморский край, Уссурийск, Калинина, 2	f	medium
25262	74206	986	Приморский край, Уссурийск, Дальневосточная, 17	f	large
25211	74160	935	Приморский край, Уссурийск, Володарского, 61	f	medium
25207	74158	931	Приморский край, Уссурийск, Володарского, 14	f	large
25261	74205	985	Приморский край, Уссурийск, Вокзальная площадь, 1	f	large
25263	74207	987	Приморский край, Уссурийск, Артемовская, 1б	f	large
25210	74143	934	Приморский край, Уссурийск, Андрея Кушнира, 23	f	large
25209	74143	933	Приморский край, Уссурийск, Андрея Кушнира, 23	f	large
24924	73899	624	Приморский край, Тавричанка, Полины Осипенко, 19	f	large
24920	73895	619	Приморский край, Тавричанка, Квартальная улица, 9	f	large
25157	74109	872	Приморский край, Спасск-Дальний, Цементная, 2	f	medium
25162	74090	877	Приморский край, Спасск-Дальний, Советская, 108/1	f	medium
25171	74121	886	Приморский край, Спасск-Дальний, Складская, 6	f	medium
25172	74122	887	Приморский край, Спасск-Дальний, Приморская, 47	f	small
25184	74134	900	Приморский край, Спасск-Дальний, Октябрьская, 14	f	medium
25176	74126	892	Приморский край, Спасск-Дальний, Краснознаменная, 52	f	large
25177	74127	893	Приморский край, Спасск-Дальний, Красногвардейская, 73	f	large
25167	74117	882	Приморский край, Спасск-Дальний, Комсомольская, 78	f	medium
25173	74123	888	Приморский край, Спасск-Дальний, 9-го Октября, 1	f	small
25160	74112	875	Приморский край, Спасск-Дальний, переулок Мухинский	f	\N
25183	74133	899	Приморский край, Спасск-Дальний, Цементная, 22	f	large
25156	74108	871	Приморский край, Спасск-Дальний, Цементная, 29	f	large
25166	74116	881	Приморский край, Спасск-Дальний, Советская, 64А	f	large
25165	74115	880	Приморский край, Спасск-Дальний, Советская, 64	f	large
25161	74043	876	Приморский край, Спасск-Дальний, Советская, 110	f	large
25185	74135	901	Приморский край, Спасск-Дальний, Мухинский переулок	f	\N
25164	74114	879	Приморский край, Спасск-Дальний, Ленинская, 28	f	large
25163	74113	878	Приморский край, Спасск-Дальний, Ленинская, 47	f	large
25179	74129	895	Приморский край, Спасск-Дальний, Краснознаменная, 48	f	small
25175	74125	891	Приморский край, Спасск-Дальний, Краснознаменная, 38	f	large
25174	74124	889	Приморский край, Спасск-Дальний, Краснознаменная, ДОСА	f	\N
25180	74130	896	Приморский край, город Спасск-Дальний, Красногвардейская, 104/6	f	large
25178	74128	894	Приморский край, Спасск-Дальний, Красногвардейская, 75/1	f	large
25170	74120	885	Приморский край, Спасск-Дальний, Заводская, 17	f	small
25169	74119	884	Приморский край, Спасск-Дальний, Ершова, 27	f	large
25155	74107	870	Приморский край, Спасск-Дальний, Дербенева, 25А	f	large
25158	74110	873	Приморский край, Спасск-Дальний, Герцена, 2	f	large
25168	74118	883	Приморский край, Спасск-Дальний, Вокзальная, 57	f	medium
25182	74132	898	Приморский край, Спасск-Дальний, Ангарская	f	\N
25159	74111	874	Приморский край, Спасск-Дальний , 1-я Загородная, 22	f	large
25075	74029	784	Приморский край, Партизанск, Центральная, 9	t	small
25044	73997	753	Приморский край, Партизанск, Техникумовская, 1	f	large
25039	73992	748	Приморский край, Партизанск, Тепличная, 1А	f	medium
25072	74026	781	Приморский край, Партизанск, Советская, 46а	f	medium
25068	74022	777	Приморский край, Партизанск, Партизанская, 159	f	medium
25043	73996	752	Приморский край, Партизанск, Осиновая, 1	f	medium
25056	74009	765	Приморский край, Партизанск, Ленинская, 36	f	medium
25074	74028	783	Приморский край, Партизанск, Клубная, 3	t	small
25053	74006	762	Приморский край, Партизанск, 50 Лет ВЛКСМ, 55	f	medium
25048	74001	757	Приморский край, Партизанск, Центральная, 2Б	f	large
25047	74000	756	Приморский край, Партизанск, Центральная, 19	f	large
25042	73995	751	Приморский край, Партизанск, Свердлова, 7А	f	medium
25051	74004	760	Приморский край, Партизанск, Садовая, 2	f	large
25062	74016	771	Приморский край, Партизанск, Пушкинская, 82А	f	large
25067	74021	776	Приморский край, Партизанск, Партизанская, 110	f	large
25060	74013	769	Приморский край, Партизанск, Обогатительная, 6	f	large
25055	74008	764	Приморский край, Партизанск, Ленинская, 26	f	large
25058	74011	767	Приморский край, Партизанск, Лазо, 8	f	large
25049	74002	758	Приморский край, Партизанск, Коренова, 10	f	large
25040	73993	749	Приморский край, Партизанск, Индустриальная, 11	f	large
25054	74007	763	Приморский край, Партизанск, 50 Лет ВЛКСМ, 38	f	large
24956	73922	660	Приморский край, город Находка, проспект Мира, 24Б	f	large
24955	73922	659	Приморский край, город Находка, проспект Мира, 24Б	f	large
24988	73948	692	Приморский край, Находка, Юбилейная, 12	f	large
24986	73946	690	Приморский край, Находка, Юбилейная, 2	f	large
24943	73913	646	Приморский край, Находка, Шоссейная, 117	f	large
24960	73925	664	Приморский край, Находка, Школьный переулок, 10А	f	large
24992	73951	696	Приморский край, Находка, Спортивная, 6	f	large
24981	73942	685	Приморский край, Находка, Северная, 10	f	large
24949	73918	653	Приморский край, Находка, Пугачева, 2 а	f	large
24958	73924	662	Приморский край, Находка, Постышева, 17	f	\N
24959	73924	663	Приморский край, Находка, Постышева, 17	f	\N
24957	73923	661	Приморский край, Находка, Постышева, 51 а	f	large
24965	73929	669	Приморский край, Находка, Пограничная, 44	f	large
24993	73952	697	Приморский край, Находка, Пирогова, 13А	f	large
24985	73945	689	Приморский край, город Находка, Находкинский проспект, 108	f	large
24984	73945	688	Приморский край, город Находка, Находкинский проспект, 108	f	large
24968	73931	672	Приморский край, Находка, Находкинский проспект, 44	f	large
24976	73938	680	Приморский край, город Находка, Нахимовская, 21 а	f	large
24975	73938	679	Приморский край, город Находка, Нахимовская, 21 а	f	large
24974	73937	678	Приморский край, Находка, Нахимовская, 23	f	large
24973	73936	677	Приморский край, Находка, Нахимовская, 7А	f	large
24926	73901	628	Приморский край, Находка, Набережная, 17	t	small
24977	73939	681	Приморский край, Находка, Молодежная, 16	f	large
24964	73928	668	Приморский край, Находка, Мичурина, 10А	f	large
24954	73921	658	Приморский край, Находка, Малиновского, 25	f	large
24953	73921	657	Приморский край, Находка, Малиновского, 25	f	large
25564	74490	1328	Приморский край, Находка, Макарова, 19	f	large
24972	73935	676	Приморский край, Находка, Луначарского, 13	f	large
24971	73934	675	Приморский край, Находка, Ленинская, 22	f	large
24928	73903	630	Приморский край, Находка, Комсомольская, 2А	f	large
24941	73912	644	Приморский край, Находка, Кирова, 13	f	large
24942	73912	645	Приморский край, Находка, Кирова, 13	f	large
24927	73902	629	Приморский край, город Находка, Заводская, 16	f	large
24983	73944	687	Приморский край, Находка, Добролюбова, 18	f	large
24952	73920	656	Приморский край, Находка, Дзержинского, 9А	f	large
24951	73919	655	Приморский край, город Находка, Дзержинского, 3	f	large
24950	73919	654	Приморский край, город Находка, Дзержинского, 3	f	large
24970	73933	674	Приморский край, Находка, Владивостокская, 45 а	f	large
24969	73932	673	Приморский край, Находка, Владивостокская, 22	f	large
24979	73941	683	Приморский край, Находка, Верхне-Морская, 6	f	large
24991	73950	695	Приморский край, Находка, Бокситогорская, 20	f	large
24990	73950	694	Приморский край, Находка, Бокситогорская, 20	f	large
25561	74414	1325	Приморский край, Находка, Арсеньева, 14А	f	large
25562	74414	1326	Приморский край, Находка, Арсеньева, 14А	f	large
24989	73949	693	Приморский край, Находка, Спортивная, 3А	f	large
24987	73947	691	Приморский край, Находка, Спортивная, 12	f	large
24947	73916	650	Приморский край, Находка, Садовая, 1	f	large
24946	73916	649	Приморский край, Находка, Садовая, 1	f	large
24963	73927	667	Приморский край, Находка, Мичурина, 12А	f	large
24962	73927	666	Приморский край, Находка, Мичурина, 12А	f	large
24961	73926	665	Приморский край, Находка, Красноармейская, 7	f	large
24934	73908	637	Приморский край, Находка, Восточный проспект, 7	f	large
24933	73908	636	Приморский край, Находка, Восточный проспект, 7	f	large
24978	73940	682	Приморский край, Находка, Верхне-Морская, 104А	f	large
25586	74508	1352	Приморский край, Находка, Астафьева, 15	f	large
25585	74507	1351	Приморский край, Находка, Астафьева, 123	f	large
24930	73905	633	Приморский край, поселок Ливадия, Набережная, 4	f	large
24840	73815	532	Приморский край, Лесозаводск, Кравчука, 1А	f	large
24843	73818	535	Приморский край, Лесозаводск, Григоренко, 17	f	small
24830	73806	522	Приморский край, Лесозаводск, Вокзальная, 76	f	large
24827	73803	519	Приморский край, Лесозаводск, имени Двенадцати, 9	f	medium
24828	73804	520	Приморский край, Лесозаводск, Юго-Западный микрорайон, 10	f	large
24846	73821	538	Приморский край, город Лесозаводск, Челюскина, 10	f	large
24844	73819	536	Приморский край, Лесозаводск, Челюскина, 10	f	large
24847	73822	539	Приморский край, Лесозаводск, Урицкого, 18	f	large
24835	73810	527	Приморский край, Лесозаводск, Пушкинская, 33	f	large
24833	73808	525	Приморский край, Лесозаводск, Пушкинская, 10	f	large
24839	73814	531	Приморский край, Лесозаводск, Пролетарская, 7	f	large
24845	73820	537	Приморский край, Лесозаводск, Паровозная, 1	f	large
24841	73816	533	Приморский край, Лесозаводск, Октябрьская, 81	f	medium
24831	73807	523	Приморский край, Лесозаводск, Мира, 4	f	large
24848	73823	540	Приморский край, Лесозаводск, Ленинская, 37	f	large
24837	73812	529	Приморский край, Лесозаводск, Калининская, 27а	f	large
24836	73811	528	Приморский край, Лесозаводск, Калининская, 29 а	f	large
24826	73802	518	Приморский край, Лесозаводск, Дзержинского, 26	f	large
24829	73805	521	Приморский край, Лесозаводск, Белова, 8	f	medium
24832	73794	524	Приморский край, Лесозаводск, 9 Января, 28	f	large
24940	73911	643	Приморский край, село Козьмино, Набережная, 23	t	small
25559	74487	1323	Приморский край, Дальнереченск, Хоровского, 1А	f	small
24720	73700	406	Приморский край, Дальнереченск, Советская, 47	f	large
24719	73699	405	Приморский край, Дальнереченск, Рябухи, 75	f	medium
24709	73689	395	Приморский край, Дальнереченск, Ленина, 69А	f	large
113286	74539	1356	Приморский край, Дальнереченск, Ясная, 11	t	\N
24714	73694	400	Приморский край, Дальнереченск, Рябухи, 59	f	large
24717	73697	403	Приморский край, Дальнереченск, Полтавская, 127	f	large
24713	73693	399	Приморский край, Дальнереченск, Личенко, 57	f	large
24710	73690	396	Приморский край, Дальнереченск, Ленина, 33	f	large
24706	73685	392	Приморский край, Дальнереченск, Ленина, 101	f	large
24724	73705	410	Приморский край, Дальнереченск, Кошевого, 1А	f	large
24708	73687	394	Приморский край, Дальнереченск, Калинина, 91А	f	large
24711	73691	397	Приморский край, Дальнереченск, Заводская, 18	f	large
24707	73686	393	Приморский край, Дальнереченск, Героев Даманского, 11	f	large
24715	73695	401	Приморский край, Дальнереченск, 50 лет Октября, 81	f	large
24723	73704	409	Приморский край, Дальнереченск, 45 лет Октября, 45	f	large
24722	73702	408	Приморский край, Дальнереченск, 45 лет Октября, 68	f	large
24694	73676	380	Приморский край, Дальнегорск, Проспект 50 лет Октября, 124	f	large
24692	73674	378	Приморский край, Дальнегорск, Проспект 50 лет Октября, 49	f	large
24691	73674	377	Приморский край, Дальнегорск, Проспект 50 лет Октября, 49	f	large
24688	73671	374	Приморский край, Дальнегорск, Пионерская, 17	f	large
24683	73666	369	Приморский край, Дальнегорск, Школьная, 14	f	\N
24697	73678	383	Приморский край, Дальнегорск, Химиков, 8а	f	large
24696	73678	382	Приморский край, Дальнегорск, Химиков, 8а	f	large
24695	73677	381	Приморский край, Дальнегорск, Проспект 50 лет Октября, 127	f	large
24693	73675	379	Приморский край, Дальнегорск, Проспект 50 лет Октября, 63	f	large
24690	73673	376	Приморский край, Дальнегорск, Проспект 50 лет Октября, 47	f	large
24686	73669	372	Приморский край, Дальнегорск, Приморская, 23	f	large
24699	73679	385	Приморский край, Дальнегорск, Первомайская , 8А	f	large
24698	73679	384	Приморский край, Дальнегорск, Первомайская , 8А	f	large
113296	74549	1920	Приморский край, Владивосток, Первомайский район, полуостров Назимова, здание временной конторы подрядчика	t	\N
24674	73657	358	Приморский край, Владивосток, МОУ СОШ №49	f	small
25584	74506	1350	Приморский край, Владивосток, улица адмирала Юмашева, 40	f	small
24538	73539	218	Приморский край, Владивосток, улица Каштановая, 5а	f	large
24537	73539	217	Приморский край, Владивосток, улица Каштановая, 5а	f	large
24617	73607	301	Приморский край, Владивосток, улица Верещагина, 24	f	medium
24624	73613	308	Приморский край, Владивосток, проспект 100-летия Владивостока, 155	f	large
24477	73497	157	Приморский край, Владивосток, адмирала Юмашева, 20А	f	large
24476	73496	156	Приморский край, Владивосток, адмирала Юмашева, 12г	f	large
24475	73496	155	Приморский край, Владивосток, адмирала Юмашева, 12г	f	large
24658	73641	342	Приморский край, Владивосток, адмирала Фокина, 11, МБОУ Средняя вечерняя школа №2	f	large
24611	73602	295	Приморский край, Владивосток, адмирала Угрюмова, клуб Военного городка	f	medium
25577	74499	1343	Приморский край, Владивосток, адмирала Кузнецова, 40а	f	large
24479	73498	159	Приморский край, Владивосток, адмирала Кузнецова, 40а	f	large
24478	73498	158	Приморский край, Владивосток, адмирала Кузнецова, 40а	f	large
24649	73632	333	Приморский край, Владивосток, Ялтинская, 18	f	large
24488	73506	168	Приморский край, Владивосток, Щитовая, 43	f	large
24564	73563	244	Приморский край, Владивосток, Шошина, 25	f	large
24562	73561	242	Приморский край, Владивосток, Шошина, 27	f	large
24466	73489	146	Приморский край, Владивосток, Шилкинская, 19	f	large
24465	73489	145	Приморский край, Владивосток, Шилкинская, 19	f	large
24481	73500	161	Приморский край, Владивосток, Шепеткова, 60	f	large
24626	73614	310	Приморский край, Владивосток, Чкалова, 15	f	large
24625	73614	309	Приморский край, Владивосток, Чкалова, 15	f	large
24550	73549	230	Приморский край, Владивосток, Черемуховая, 2	f	large
24549	73548	229	Приморский край, Владивосток, Черемуховая, 20	f	large
24548	73547	228	Приморский край, Владивосток, Черемуховая, 17	f	large
25565	73611	1330	Приморский край, Владивосток, Чапаева, 5	f	large
24622	73611	306	Приморский край, Владивосток, Чапаева, 5	f	large
24547	73546	227	Приморский край, Владивосток, Херсонская, 4	f	large
25607	74519	1918	Приморский край, Владивосток, Харьковская, 7	f	large
24542	73542	222	Приморский край, Владивосток, Харьковская, 36а	f	large
24531	73535	211	Приморский край, Владивосток, Харьковская, 9	f	large
24670	73653	354	Приморский край, Владивосток, Хабаровская, 24б, МБОУ СОШ № 18	f	large
24669	73652	353	Приморский край, Владивосток, Хабаровская, 24б, МБОУ СОШ №18	f	large
24666	73649	350	Приморский край, Владивосток, Хабаровская, 18, ГОУ СПО Влад.художест.училище	f	large
24665	73648	349	Приморский край, Владивосток, Хабаровская, 7, МБОУ ДОД Детс.юнош.центр	f	large
25606	74518	1904	Приморский край, Владивосток, Фадеева, 35	f	small
24615	73605	299	Приморский край, Владивосток, Успенского, 19	f	large
24614	73604	298	Приморский край, Владивосток, Успенского, 73	f	large
24613	73604	297	Приморский край, Владивосток, Успенского, 73	f	large
24452	73477	132	Приморский край, Владивосток, Уборевича, 25	f	large
24451	73476	131	Приморский край, Владивосток, Уборевича, 5	f	large
24450	73475	130	Приморский край, Владивосток, Уборевича, 8	f	medium
24561	73560	241	Приморский край, Владивосток, Тухачевского, 28	f	large
25576	74498	1342	Приморский край, Владивосток, Тунгусская, 59	f	large
24471	73493	151	Приморский край, Владивосток, Тунгусская, 24	f	large
25573	74495	1339	Приморский край, Владивосток, Толстого, 27	f	large
25572	74494	1338	Приморский край, Владивосток, Толстого, 54	f	large
24464	73487	144	Приморский край, Владивосток, Толстого, 27	f	large
24463	73487	143	Приморский край, Владивосток, Толстого, 27	f	large
24462	73486	142	Приморский край, Владивосток, Толстого, 54	f	large
24461	73486	141	Приморский край, Владивосток, Толстого, 54	f	large
24516	73524	196	Приморский край, Владивосток, Талалихина, 5	f	large
25578	74500	1344	Приморский край, Владивосток, Суханова, 1а	f	small
24457	73482	137	Приморский край, Владивосток, Суханова, 3	f	large
24654	73637	338	Приморский край, Владивосток, Станюковича, 28, ПИППКРО	f	large
113295	74548	1906	Приморский край, Владивосток, Спиридонова, 40	f	\N
113294	74547	1905	Приморский край, Владивосток, Спиридонова, 36	f	\N
24483	73502	163	Приморский край, Владивосток, Спиридонова, 9	f	large
24591	73586	271	Приморский край, Владивосток, Снеговая, 35	f	large
24590	73586	270	Приморский край, Владивосток, Снеговая, 35	f	large
24592	73587	272	Приморский край, Владивосток, Сельская, 1	f	\N
24501	73513	181	Приморский край, Владивосток, Светланская, 119а	f	large
24474	73495	154	Приморский край, Владивосток, Светланская, 207	f	large
24473	73495	153	Приморский край, Владивосток, Светланская, 207	f	large
24469	73491	149	Приморский край, Владивосток, Светланская, 147	f	large
24459	73484	139	Приморский край, Владивосток, Светланская, 119а	f	large
24508	73518	188	Приморский край, Владивосток, Сахалинская, 23а	f	large
24507	73518	187	Приморский край, Владивосток, Сахалинская, 23а	f	large
24506	73517	186	Приморский край, Владивосток, Сахалинская, 57	f	large
24587	73583	267	Приморский край, Владивосток, Сабанеева, 8	f	large
25567	73627	1332	Приморский край, Владивосток, Русская, 57	f	large
24641	73625	325	Приморский край, Владивосток, Русская, 96А	f	large
24640	73624	324	Приморский край, Владивосток, Русская, 67/2	f	large
24639	73623	323	Приморский край, Владивосток, Русская, 43	f	large
24638	73623	322	Приморский край, Владивосток, Русская, 43	f	large
24637	73623	321	Приморский край, Владивосток, Русская, 43	f	large
24633	73619	317	Приморский край, Владивосток, Русская, 40	f	large
24632	73619	316	Приморский край, Владивосток, Русская, 40	f	large
24631	73618	315	Приморский край, Владивосток, Русская, 7а	f	large
24630	73618	314	Приморский край, Владивосток, Русская, 7а	f	large
24629	73617	313	Приморский край, Владивосток, Русская, 21	f	large
24458	73483	138	Приморский край, Владивосток, Пушкинская, 39	f	large
24606	73597	290	Приморский край, Владивосток, Путятинская, 135	f	large
24541	73541	221	Приморский край, Владивосток, Приморская, 5	f	large
25605	74517	1903	Приморский край, Владивосток, Прапорщика Комарова, 35а	f	small
24566	73565	246	Приморский край, Владивосток, Постышева, 37	f	large
24540	73540	220	Приморский край, Владивосток, Поселковая 2-я, 51	f	large
24539	73540	219	Приморский край, Владивосток, Поселковая 2-я, 51	f	large
24603	73595	287	Приморский край, Владивосток, Порт-Артурская, 46	f	large
24523	73529	203	Приморский край, Владивосток, Полярная, 7	f	large
24551	73550	231	Приморский край, Владивосток, Подгорная, 23	f	large
24680	73663	363	Приморский край, Владивосток, Пограничная, 26, Общежитие ДВФУ	f	small
24594	73588	274	Приморский край, Владивосток, Писаревская, 6/8	f	large
24593	73588	273	Приморский край, Владивосток, Писаревская, 6/8	f	large
24620	73608	304	Приморский край, Владивосток, Пирогова, 7	f	large
24618	73608	302	Приморский край, Владивосток, Пирогова, 7	f	medium
24504	73515	184	Приморский край, Владивосток, Пацаева, 2	f	large
24503	73515	183	Приморский край, Владивосток, Пацаева, 2	f	large
25071	74025	780	Приморский край, Владивосток, Партизанский проспект, 12а	f	large
25061	74015	770	Приморский край, Владивосток, Партизанский проспект, 1	f	medium
25059	74012	768	Приморский край, Владивосток, Партизанский проспект, 52	f	large
25052	74005	761	Приморский край, Владивосток, Партизанский проспект, 1	f	large
25045	73998	754	Приморский край, Владивосток, Партизанский проспект, 37	f	large
24579	73577	259	Приморский край, Владивосток, Партизанский проспект, 62а	f	large
24621	73610	305	Приморский край, Владивосток, Пальчевского, 17	f	large
24578	73576	258	Приморский край, Владивосток, Острякова проспект, 2а	f	large
24609	73600	293	Приморский край, Владивосток, Опорная, 6	f	large
24535	73537	215	Приморский край, Владивосток, Олега Кошевого, 26	f	large
24534	73537	214	Приморский край, Владивосток, Олега Кошевого, 26	f	large
24661	73644	345	Приморский край, Владивосток, Октябрьская, 13, ГОУ СПО Гидрометеорол.техникум	f	large
24659	73642	343	Приморский край, Владивосток, Океанский проспект, 19, ФГАОУ ВПО ДВФУ	f	large
24589	73585	269	Приморский край, Владивосток, Океанский проспект, 102а	f	large
24588	73584	268	Приморский край, Владивосток, Океанский проспект, 143	f	large
24568	73566	248	Приморский край, Владивосток, Овчинникова, 34	f	large
24553	73552	233	Приморский край, Владивосток, Никифорова, 41А	f	large
24515	73523	195	Приморский край, Владивосток, Никифорова, 41а	f	large
24514	73523	194	Приморский край, Владивосток, Никифорова, 41а	f	large
24499	73512	179	Приморский край, Владивосток, Нерчинская, 32	f	large
24454	73479	134	Приморский край, Владивосток, Нерчинская, 21	f	medium
24453	73478	133	Приморский край, Владивосток, Нерчинская, 32	f	large
25579	74501	1345	Приморский край, Владивосток, Некрасовский переулок, 1	f	small
24460	73485	140	Приморский край, Владивосток, Некрасовская, 58	f	large
24500	73510	180	Приморский край, Владивосток, Нейбута, 26	f	large
24494	73510	174	Приморский край, Владивосток, Нейбута, 26	f	large
24493	73510	173	Приморский край, Владивосток, Нейбута, 26	f	large
25611	74521	1935	Приморский край, Владивосток, Невская, 20а	f	large
24497	73507	177	Приморский край, Владивосток, Невельского, 31	f	large
24496	73507	176	Приморский край, Владивосток, Невельского, 31	f	large
24489	73507	169	Приморский край, Владивосток, Невельского, 31	f	large
24571	73570	251	Приморский край, Владивосток, Нахимова, 6	f	large
24595	73578	275	Приморский край, Владивосток, Народный проспект, 27а	f	large
24580	73578	260	Приморский край, Владивосток, Народный проспект, 27а	f	large
24657	73640	341	Приморский край, Владивосток, Набережная, 1, МБОУ Средняя школа № 13	f	large
24656	73639	340	Приморский край, Владивосток, Набережная, 1, МБОУ Средняя школа №1	f	large
24470	73492	150	Приморский край, Владивосток, Муравьева-Амурского, 5	f	large
24651	73634	335	Приморский край, Владивосток, Морозова, 5	f	large
24610	73601	294	Приморский край, Владивосток, Минеральная, 17	f	medium
24619	73609	303	Приморский край, Владивосток, Маковского, 41	f	medium
113285	74538	283	Приморский край, Владивосток, Луговая, 56а	f	\N
113284	74537	282	Приморский край, Владивосток, Луговая, 54	f	\N
113283	74536	281	Приморский край, Владивосток, Луговая, 48	f	\N
24598	73554	278	Приморский край, Владивосток, Луговая, 52а	f	large
24597	73554	277	Приморский край, Владивосток, Луговая, 52а	f	large
24605	73596	289	Приморский край, Владивосток, Лермонтова, 91/3	f	large
24604	73596	288	Приморский край, Владивосток, Лермонтова, 91/3	f	large
24601	73593	285	Приморский край, Владивосток, Лермонтова, 30	f	large
24602	73594	286	Приморский край, Владивосток, Лермонтова, 69/1	f	large
24486	73504	166	Приморский край, Владивосток, Куйбышева, 1	f	large
25574	74496	1340	Приморский край, Владивосток, Красного Знамени проспект, 123	f	large
25568	74491	1334	Приморский край, Владивосток, Красного Знамени проспект, 45	f	medium
24664	73647	348	Приморский край, Владивосток, Красного Знамени проспект, 23	f	large
24663	73646	347	Приморский край, Владивосток, Красного Знамени проспект, 25а	f	large
24662	73645	346	Приморский край, Владивосток, Красного Знамени проспект, 25а, МБОУ СОШ №17	f	large
24468	73490	148	Приморский край, Владивосток, Красного Знамени проспект, 123	f	large
24467	73490	147	Приморский край, Владивосток, Красного Знамени проспект, 123	f	large
24583	73580	263	Приморский край, Владивосток, Котельникова, 7	f	large
24509	73519	189	Приморский край, Владивосток, Космонавтов, 15	f	large
24472	73494	152	Приморский край, Владивосток, Ковальчука, 6/8	f	large
24623	73612	307	Приморский край, Владивосток, Кирова, 93	f	large
25610	73562	1934	Приморский край, Владивосток, Карбышева, 11	f	large
25570	73562	1336	Приморский край, Владивосток, Карбышева, 11	f	small
24563	73562	243	Приморский край, Владивосток, Карбышева, 11	f	large
24495	73501	175	Приморский край, Владивосток, Каплунова, 12	f	large
24482	73501	162	Приморский край, Владивосток, Каплунова, 12	f	large
24576	73574	256	Приморский край, Владивосток, Камская, 5Б	f	large
24546	73545	226	Приморский край, Владивосток, Калинина, 253А	f	large
24544	73543	224	Приморский край, Владивосток, Калинина, 153	f	large
24543	73543	223	Приморский край, Владивосток, Калинина, 153	f	large
24527	73532	207	Приморский край, Владивосток, Калинина, 29	f	large
24652	73635	336	Приморский край, Владивосток, Казанская, 4/6, МБОУ Средняя школа №6	f	large
24650	73633	334	Приморский край, Владивосток, Казанская, 4/6, МБОУ Средняя школа №6	f	large
25609	73559	1933	Приморский край, Владивосток, Иртышская, 40/1	f	large
24560	73559	240	Приморский край, Владивосток, Иртышская, 40/1	f	large
24559	73559	239	Приморский край, Владивосток, Иртышская, 40/1	f	large
24567	73557	247	Приморский край, Владивосток, Иртышская, 6	f	large
24557	73557	237	Приморский край, Владивосток, Иртышская, 6	f	large
24556	73556	236	Приморский край, Владивосток, Иртышская, 10	f	large
24529	73534	209	Приморский край, Владивосток, Интернациональная, 48	f	large
24530	73534	210	Приморский край, Владивосток, Интернациональная, 48	f	large
24558	73558	238	Приморский край, Владивосток, Ильичева, 26	f	large
24582	73579	262	Приморский край, Владивосток, Жигура, 52а	f	large
24581	73579	261	Приморский край, Владивосток, Жигура, 52а	f	large
24505	73516	185	Приморский край, Владивосток, Добровольского, 20	f	large
24577	73575	257	Приморский край, Владивосток, Днепровский переулок, 2	f	large
25583	74505	1349	Приморский край, Владивосток, Державина, 15	f	small
25582	74504	1348	Приморский край, Владивосток, Державина, 21	f	small
25581	74503	1347	Приморский край, Владивосток, Державина, 19	f	small
25580	74502	1346	Приморский край, Ленинский район, Владивосток, Державина, 17	f	small
24456	73481	136	Приморский край, Владивосток, Державина, 57	f	medium
24636	73622	320	Приморский край, Владивосток, Давыдова, 3	f	large
24519	73526	199	Приморский край, Владивосток, Гризодубовой, 57	f	large
24518	73525	198	Приморский край, Владивосток, Гризодубовой, 50	f	large
24517	73525	197	Приморский край, Владивосток, Гризодубовой, 50	f	large
24502	73514	182	Приморский край, Владивосток, Гоголя, 41	f	large
24536	73538	216	Приморский край, Владивосток, Героев-Тихоокеанцев, 14	f	large
24565	73564	245	Приморский край, Владивосток, Героев Варяга, 2	f	large
24528	73533	208	Приморский край, Владивосток, Вязовая, 1	f	large
24570	73569	250	Приморский край, Владивосток, Вострецова, 9	f	large
24608	73599	292	Приморский край, Владивосток, Восточный проспект, 34	f	large
24487	73505	167	Приморский край, Владивосток, Воропаева, 31	f	large
24569	73568	249	Приморский край, Владивосток, Волховская, 15	f	large
24596	73589	276	Приморский край, Владивосток, Военное шоссе, 1а	f	\N
24555	73555	235	Приморский край, Владивосток, Вилкова, 7	f	large
24681	73664	364	Приморский край, Владивосток, Верхнепортовая, 50а, Общежитие МГУ им.Невельского	f	large
24655	73638	339	Приморский край, Владивосток, Верхнепортовая, 18, ИПК ФГОУ ВПО ДГТРУ	f	large
24653	73636	337	Приморский край, Владивосток, Верхнепортовая, 40, Детская художествен. школа № 1	f	large
24672	73655	356	Приморский край, Владивосток, Верхненабережная, 15, МОУ СОШ № 15	t	large
25575	74497	1341	Приморский край, Владивосток, Ватутина, 24	f	large
24492	73509	172	Приморский край, Владивосток, Ватутина, 18	f	medium
24491	73508	171	Приморский край, Владивосток, Ватутина, 24	f	large
24490	73508	170	Приморский край, Владивосток, Ватутина, 24	f	large
25571	74493	1337	Приморский край, Владивосток, Бородинская, 18	f	small
24643	73626	327	Приморский край, Владивосток, Бородинская, 27	f	large
24642	73626	326	Приморский край, Владивосток, Бородинская, 27	f	large
25603	73620	1852	Приморский край, Владивосток, Бородинская, 7	f	large
24634	73620	318	Приморский край, Владивосток, Бородинская, 7	f	large
24552	73551	232	Приморский край, Владивосток, Борисенко, 104	f	large
24522	73528	202	Приморский край, Владивосток, Борисенко, 22	f	large
24521	73528	201	Приморский край, Владивосток, Борисенко, 22	f	large
24511	73521	191	Приморский край, Владивосток, Борисенко, 102	f	large
24510	73520	190	Приморский край, Владивосток, Борисенко, 104	f	large
24660	73643	344	Приморский край, Владивосток, Батарейная, 6, Ср. школа №46	f	large
24585	73582	265	Приморский край, Владивосток, Баляева, 46	f	large
25613	73581	1937	Приморский край, Владивосток, Баляева, 38	f	large
24584	73581	264	Приморский край, Владивосток, Баляева, 38	f	large
24668	73650	352	Приморский край, Владивосток, Амурская, 14, МБОУ СОШ № 26	f	large
24667	73650	351	Приморский край, Владивосток, Амурская, 14, МБОУ СОШ № 26	f	medium
24679	73662	362	Приморский край, Владивосток, Алеутская, 65, Общежитие ДВФУ	f	small
24480	73499	160	Приморский край, Владивосток, Адмирала Кузнецова, 54В	f	large
24616	73606	300	Приморский край, Владивосток, 6-я, 8	f	large
24600	73592	284	Приморский край, Владивосток, 50 Лет Октября, 22	f	medium
24554	73553	234	Приморский край, Владивосток, 50 Лет ВЛКСМ, 27	f	large
24526	73531	206	Приморский край, Владивосток, 50 Лет ВЛКСМ, 24/1	f	large
24525	73530	205	Приморский край, Владивосток, 50 Лет ВЛКСМ, 27	f	large
24524	73530	204	Приморский край, Владивосток, 50 Лет ВЛКСМ, 27	f	large
24607	73598	291	Приморский край, Владивосток, 4-я Восточная, 93	f	large
24513	73522	193	Приморский край, Владивосток, 2-я Строительная, 7	f	large
24512	73522	192	Приморский край, Владивосток, 2-я Строительная, 7	f	large
25608	74520	1919	Приморский край, Владивосток, 2-я Поселковая, 51	f	large
25612	74522	1936	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 29	f	large
24573	73572	253	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 32а	f	large
24572	73571	252	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 29	f	large
24635	73621	319	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 128а	f	large
24628	73616	312	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 133А	f	large
24627	73616	311	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 133А	f	large
24575	73573	255	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 18	f	medium
24574	73573	254	Приморский край, Владивосток, 100 Лет Владивостоку проспект, 18	f	large
24648	73631	332	Приморский край, Владивосток, 10-я, 10	f	small
24485	73503	165	Приморский край, Владивосток, Ивановская, 28	f	large
24484	73503	164	Приморский край, Владивосток, Ивановская, 28	f	large
24449	73474	125	Приморский край, Большой Камень, Прибрежная, 16	f	large
24446	73471	122	Приморский край, Большой Камень, Карла Маркса, 47	f	large
24443	73468	119	Приморский край, Большой Камень, Карла Маркса, 49	f	large
24444	73469	120	Приморский край, Большой Камень, Гагарина, 15	f	large
24441	73466	117	Приморский край, Большой Камень, Аллея Труда, 16А	f	large
24445	73470	121	Приморский край, Большой Камень, Академика Курчатова, 28	f	large
24390	73415	64	Приморский край, Артем, улица Фрунзе, 18	f	large
24414	73440	88	Приморский край, Артем, улица Кирова, 138	f	large
24917	73892	616	Приморский край, Артем, площадь Ленина, 8	f	large
24915	73890	614	Приморский край, Артем, площадь Ленина, 3	f	large
24426	73453	100	Приморский край, Артем, площадь Ленина, 4	f	large
24425	73452	99	Приморский край, Артем, площадь Ленина, 9/2	f	large
24424	73451	98	Приморский край, Артем, площадь Ленина, 7	f	large
24400	73425	74	Приморский край, Артем, площадь Ленина, 15	f	large
24388	73413	62	Приморский край, Артем, Щорса, 22	f	large
24396	73421	70	Приморский край, Артем, Чайковского, 53	f	large
24395	73420	69	Приморский край, Артем, Хмельницкого, 16	f	large
24398	73423	72	Приморский край, Артем, Фрунзе, 69/1	f	large
24394	73419	68	Приморский край, Артем, Фрунзе, 32б	f	large
24391	73416	65	Приморский край, Артем, Фрунзе, 28	f	large
24389	73414	63	Приморский край, Артем, Фрунзе, 6	f	large
24427	73454	101	Приморский край, Артем, Стрельникова, 46	f	medium
24420	73447	94	Приморский край, Артем, Силина, 21	f	medium
24422	73449	96	Приморский край, Артем, Севастопольская, 12	f	large
24392	73417	66	Приморский край, Артем, Севастопольская, 27	f	large
24383	73407	57	Приморский край, Артем, Сахалинская, 1	f	large
24386	73410	60	Приморский край, Артем, Ремзаводская, 5	f	large
25520	74450	1265	Приморский край, Артем, Первомайская, 4А	f	large
24399	73424	73	Приморский край, Артем, Партизанская улица, 3	f	large
24430	73457	104	Приморский край, Артем, Мухина, 6	f	medium
24423	73450	97	Приморский край, Артем, Михайловская, 1	f	large
24922	73897	622	Приморский край, Артем, Лазо, 5	f	large
24406	73432	80	Приморский край, Артем, Лазо, 18	t	large
24401	73426	75	Приморский край, Артем, Кооперативная, 6	f	large
24413	73439	87	Приморский край, Артем, Кирова, 92	f	large
24412	73438	86	Приморский край, Артем, Кирова, 89	f	large
24411	73437	85	Приморский край, Артем, Кирова, 83/1	f	large
24410	73436	84	Приморский край, Артем, Кирова, 66	f	large
24408	73434	82	Приморский край, Артем, Кирова, 62	f	large
24407	73433	81	Приморский край, Артем, Кирова, 57	f	large
24402	73428	76	Приморский край, Артем, Кирова, 21	f	large
24397	73422	71	Приморский край, Артем, Кирова, 3	f	large
24385	73409	59	Приморский край, Артем, Карагандинская улица, 26	f	large
24409	73435	83	Приморский край, Артем, Калинина, 20	f	medium
24403	73429	77	Приморский край, Артем, Интернациональная улица, 58	f	large
24405	73431	79	Приморский край, Артем, Достоевского, 50	t	medium
24435	73460	111	Приморский край, Артем, Донбасская улица, 17	f	large
24387	73412	61	Приморский край, Артем, Донбасская улица	f	large
24417	73444	91	Приморский край, Артем, Днепростроевская улица, 6а	f	large
24419	73446	93	Приморский край, Артем, Днепростроевская, 11	f	large
24418	73445	92	Приморский край, Артем, Днепростроевская, 6	f	large
25560	74488	1324	Приморский край, Артем, Дальнереченский переулок, 6	f	medium
24721	73701	407	Приморский край, Артем, Дальнереченский переулок, 2	f	large
24718	73698	404	Приморский край, Артем, Дальнереченский переулок, 2	f	medium
24712	73692	398	Приморский край, Артем, Дальнереченский переулок, 12	f	large
24382	73406	56	Приморский край, Артем, Гагарина, 135	f	large
24434	73459	110	Приморский край, Артем, Ворошилова, 13	f	large
24416	73442	90	Приморский край, Артем, Ворошилова, 11	f	large
24404	73430	78	Приморский край, Артем, Волочаевская улица, 42	t	large
24415	73441	89	Приморский край, Артем, Виноградная, 2	t	small
24393	73418	67	Приморский край, Артем, Ватутина, 4	f	large
24436	73461	112	Приморский край, Артем, Бабушкина, 12	f	large
24384	73408	58	Приморский край, Артем, 1-я Рабочая улица, 37	f	large
24428	73455	102	Приморский край, Артем , Авиационная , 7	f	large
24359	73386	30	Приморский край, Арсеньев, Таежная, 1	f	medium
24373	73399	44	Приморский край, Арсеньев, Садовая, 19	f	large
24364	73391	35	Приморский край, Арсеньев, Мира, 11	f	large
24358	73385	29	Приморский край, Арсеньев, Луговая, 29А	f	large
24366	73393	37	Приморский край, Арсеньев, Ломоносова, 42А	f	large
24370	73396	41	Приморский край, Арсеньев, Ленинская, 43	f	large
24367	73394	38	Приморский край, Арсеньев, Ленинская, 23	f	large
24369	73367	40	Приморский край, Арсеньев, Ленинская, 29А	f	large
24378	73402	49	Приморский край, Арсеньев, Клиновая, 1А	f	large
24368	73395	39	Приморский край, Арсеньев, Калининская, 1	f	large
24375	73390	46	Приморский край, Арсеньев, 25 лет Арсеньеву, 17	f	large
24363	73390	34	Приморский край, Арсеньев, 25 лет Арсеньеву, 17	f	large
24377	73401	48	Приморский край, Арсеньев, Советская, 39А	f	large
24380	73404	51	Приморский край, Арсеньев, Сазыкина, 13	f	large
24376	73397	47	Приморский край, Арсеньев, Островского, 20	f	large
24371	73397	42	Приморский край, Арсеньев, Островского, 20	f	large
24360	73387	31	Приморский край, Арсеньев, Олега Кошевого, 3	f	large
24381	73405	52	Приморский край, Арсеньев, Октябрьская, 41	f	large
24365	73392	36	Приморский край, Арсеньев, Октябрьская, 63/2	f	large
24361	73388	32	Приморский край, Арсеньев, Кирзаводская, 10А	f	large
24372	73398	43	Приморский край, Арсеньев, Калининская, 3А	f	large
24374	73400	45	Приморский край, Арсеньев, Жуковского, 54	f	large
24362	73389	33	Приморский край, Арсеньев, 9 Мая, 83	f	large
24673	73656	357	Приморский край, остров Русский, поселок Подножье, МБОУ СОШ № 20	f	large
25050	74003	759	Приморский край, городской округ Партизанск, село Углекаменск, Советская, 39	f	medium
25078	74032	787	Приморский край, городской округ Партизанск, село Тигровое, Тигровая, 155	t	small
25069	74023	778	Приморский край, городской округ Партизанск, село Казанка, Луговая, 6А	f	\N
25076	74030	785	Приморский край, городской округ Партизанск, село Бровничи, Советская, 61	t	small
25057	74010	766	Приморский край, городской округ Партизанск, село Авангард, Кирова, 33	f	medium
24931	73906	634	Приморский край, городской округ Находка, поселок Средний, Светлая, 10	t	small
24929	73904	632	Приморский край, городской округ Находка, поселок Ливадия, Луговая, 2	f	large
24932	73907	635	Приморский край, городской округ Находка, село Душкино, Комарова, 13	f	small
24838	73813	530	Приморский край, городской округ Лесозаводск, Лесозаводск, Будника, 77	f	large
25548	74477	1299	Приморский край, Шкотовский район, поселок Шкотово, Советская, 45	f	large
25544	74473	1295	Приморский край, Шкотовский район, село Центральное, Чапаева, 20	f	medium
25446	74376	1181	Приморский край, Шкотовский район, Фокино, Комсомольская, 12	f	large
25451	74381	1186	Приморский край, Шкотовский район, Фокино, Карла Маркса, 29Б	f	large
25546	74475	1297	Приморский край, Шкотовский район, село Стеклянуха, Центральная, 24	f	small
25553	74482	1304	Приморский край, Шкотовский район, поселок Смоляниново, Школьная, 1А	f	large
25543	74472	1294	Приморский край, Шкотовский район, поселок Смоляниново, Пушкинская, 84	f	medium
25552	74481	1303	Приморский край, Шкотовский район, поселок Смоляниново, Маяковского, 15	f	large
25551	74480	1302	Приморский край, Шкотовский район, поселок Смоляниново, Маяковского, 37	f	medium
25554	74483	1305	Приморский край, Шкотовский район, село Романовка, Ленинская, 60	f	large
25455	74385	1190	Приморский край, Шкотовский район, поселок городского типа Путятин, Центральная, 31	t	medium
24437	73462	113	Приморский край, Шкотовский район, село Петровка, Школьная, 1	f	large
25550	74479	1301	Приморский край, Шкотовский район, поселок Новонежино, Почтовая, 1А	f	large
25542	74471	1293	Приморский край, Шкотовский район, село Многоудобное, Зальпе, 2Г	f	medium
25458	74388	1193	Приморский край, Шкотовский район, поселок городского типа Дунай, Морская, 16	f	large
25457	74387	1192	Приморский край, Шкотовский район, поселок городского типа Дунай, Ленина, 15	f	large
25456	74386	1191	Приморский край, Шкотовский район, поселок Дунай, Морская, 18А	f	large
24439	73464	115	Приморский край, Шкотовский район, город Большой Камень, Маслакова, 14б	f	large
24448	73473	124	Приморский край, Шкотовский район, Большой Камень, Ленина, 3	f	large
24447	73472	123	Приморский край, Шкотовский район, Большой Камень, Ленина, 22	f	large
24440	73465	116	Приморский край, Шкотовский район, Большой Камень, Карла Маркса, 2	f	large
24442	73467	118	Приморский край, Шкотовский район, Большой Камень, Адмирала Макарова, 10	f	large
25549	74478	1300	Приморский край, Шкотовский район, село Анисимовка, Смольная, 4А	f	medium
25384	74325	1118	Приморский край, Черниговский район, село Черниговка, Октябрьская, 142	f	large
25382	74323	1116	Приморский край, Черниговский район, село Черниговка, Ленинская, 72	f	large
25381	74322	1115	Приморский край, Черниговский район, село Черниговка, Ленинская, 56	f	large
25380	74321	1114	Приморский край, Черниговский район, село Черниговка, Заводская, 8	f	large
25383	74324	1117	Приморский край, Черниговский район, село Черниговка, Буденного, 23	f	large
25405	74345	1139	Приморский край, Черниговский район, село Халкидон, Советская, 9	f	medium
25395	74334	1129	Приморский край, Черниговский район, село Снегуровка, Парковая, 23	f	medium
25387	74327	1121	Приморский край, Черниговский район, село Синий Гай, Советская, 5	f	small
25408	74348	1142	Приморский край, Черниговский район, поселок Сибирцево, Заводская, 1	f	small
25399	74338	1133	Приморский край, Черниговский район, поселок городского типа Сибирцево, Постышева, 13	f	large
25400	74339	1134	Приморский край, Черниговский район, поселок городского типа Сибирцево, Ленинская, 14	f	large
25402	74342	1136	Приморский край, Черниговский район, поселок городского типа Сибирцево, Кутузова, 1	f	large
25398	74337	1132	Приморский край, Черниговский район, поселок городского типа Сибирцево, Красноармейская, 16-а	f	medium
25397	74336	1131	Приморский край, Черниговский район, село Орехово, Центральная, 17	t	small
25403	74343	1137	Приморский край, Черниговский район, село Монастырище, Титова, 1-а	t	large
25389	74328	1123	Приморский край, Черниговский район, село Меркушевка, Центральная, 13	f	small
25394	74333	1128	Приморский край, Черниговский район, село Вассиановка, Ленинская, 5	f	small
25390	74329	1124	Приморский край, Черниговский район, село Алтыновка, Комсомольская, 38	f	small
25396	74335	1130	Приморский край, Черниговский район, село Абражеевка, Клубная, 2А	t	small
25355	74296	1083	Приморский край, Хорольский район, поселок городского типа Ярославский, проспект Ленина, 1	f	large
25353	74294	1081	Приморский край, Хорольский район, поселок городского типа Ярославский, Школьная, 16	f	medium
25356	74297	1084	Приморский край, Хорольский район, поселок городского типа Ярославский, Советская, 48	f	large
25352	74293	1080	Приморский край, Хорольский район, поселок городского типа Ярославский, Матросова, 3	f	large
25354	74295	1082	Приморский край, Хорольский район, поселок Ярославский, Матросова, 4	f	large
25363	74304	1091	Приморский край, Хорольский район, село Хорольск, Новая, 4, железнодорожная станция Хорольск	f	small
25361	74302	1089	Приморский край, Хорольский район, село Хороль, Ленинская, 77	f	large
25360	74301	1088	Приморский край, Хорольский район, село Хороль, Ленинская, 47	f	large
25359	74300	1087	Приморский край, Хорольский район, село Хороль, Ленинская, 49	f	large
25362	74303	1090	Приморский край, Хорольский район, село Хороль, Лазо, 23	f	large
25364	74305	1092	Приморский край, Хорольский район, село Хороль, Красноармейская, 4А	f	large
25365	74306	1093	Приморский край, Хорольский район, село Хороль, Комсомольская, 72	f	small
25366	74307	1094	Приморский край, Хорольский район, село Хороль, Волочаевская, 3	f	large
25374	74315	1102	Приморский край, Хорольский район, село Усачевка, Центральная, 2В	t	small
25377	74318	1105	Приморский край, Хорольский район, село Сиваковка, Центральная, 3	f	medium
25372	74313	1100	Приморский край, Хорольский район, село Приозерное, Ленинская, 14а	f	small
25373	74314	1101	Приморский край, Хорольский район, село Прилуки, Центральная, 17А	f	small
25367	74308	1095	Приморский край, Хорольский район, село Поповка, Первомайская, 72	f	medium
25378	74319	1106	Приморский край, Хорольский район, село Петровичи, Юбилейная	f	small
25376	74317	1104	Приморский край, Хорольский район, село Новодевица, Лазо, 30	f	large
25371	74312	1099	Приморский край, Хорольский район, село Новобельмановка, Центральная, 38	f	small
25375	74316	1103	Приморский край, Хорольский район, село Лучки, Колхозная, 18	f	medium
25369	74310	1097	Приморский край, Хорольский район, село Луговой, Центральная, 5	f	small
25368	74309	1096	Приморский край, Хорольский район, село Ленинское, Гагарина, 14	f	medium
25358	74299	1086	Приморский край, Хорольский район, село Дальзаводское, Павлика Морозова, 15	f	small
25357	74298	1085	Приморский край, Хорольский район, село Вознесенка, Первомайская, 3а	f	large
25370	74311	1098	Приморский край, Хорольский район, село Благодатное, Октябрьская, 43	f	medium
25329	74271	1055	Приморский край, Хасанский район, село Цуканово, Молодежная, 25	f	small
25328	74270	1054	Приморский край, Хасанский район, поселок Хасан, Вокзальная, 7	f	medium
25350	74290	1076	Приморский край, Хасанский район, село Филипповка, Комарова, 25а	f	small
25342	74282	1068	Приморский край, Хасанский район, поселок городского типа Славянка, Нерпинская, 27	f	medium
25344	74284	1070	Приморский край, Хасанский район, поселок городского типа Славянка, Набережная, 21б	f	medium
25340	74280	1066	Приморский край, Хасанский район, поселок городского типа Славянка, Молодежная, 8а	f	large
25343	74283	1069	Приморский край, Хасанский район, поселок городского типа Славянка, Ленинская, 51а	f	large
25339	74279	1065	Приморский край, Хасанский район, поселок Славянка, Молодежная, 7	f	large
25338	74278	1064	Приморский край, Хасанский район, поселок Славянка, Героев Хасана, 5	f	large
25337	74278	1063	Приморский край, Хасанский район, поселок Славянка, Героев Хасана, 5	f	large
25341	74281	1067	Приморский край, Хасанский район, поселок Славянка, 50 лет Октября, 10А	f	large
25347	74287	1073	Приморский край, Хасанский район, поселок Приморский, Центральная, 46б	f	large
25332	74273	1058	Приморский край, Хасанский район, поселок Посьет, Портовая, 18	f	large
25346	74286	1072	Приморский край, Хасанский район, село Перевозная, Лазо, 19	f	small
25331	74272	1057	Приморский край, Хасанский район, поселок Краскино, Ленина, 22	f	large
25330	74272	1056	Приморский край, Хасанский район, поселок Краскино, Ленина, 22	f	large
25335	74276	1061	Приморский край, Хасанский район, поселок Зарубино, Нагорная, 8а	f	large
25334	74275	1060	Приморский край, Хасанский район, поселок городского типа Зарубино, Строительная, 24А	f	large
25351	74291	1077	Приморский край, Хасанский район, село Занадворовка, Центральная, 12	f	medium
25333	74274	1059	Приморский край, Хасанский район, село Гвоздево, Новая, 1	f	medium
25345	74285	1071	Приморский край, Хасанский район, село Безверхово, Переулок Школьный, 3а	f	medium
25348	74288	1074	Приморский край, Хасанский район, село Барабаш, Школьная, 1	f	large
25349	74289	1075	Приморский край, Хасанский район, село Барабаш, Восточная Слобода, 1а	f	large
25336	74277	1062	Приморский край, Хасанский район, село Андреевка, Набережная, 9	f	medium
25324	74267	1049	Приморский край, Ханкайский район, село Турий Рог, Пограничная, 24	f	\N
25326	74269	1051	Приморский край, Ханкайский район, село Рассказово, Рабочая, 16а	t	small
25322	74265	1047	Приморский край, Ханкайский район, село Платоно-Александровское, Ленина, 2	t	small
25325	74268	1050	Приморский край, Ханкайский район, село Первомайское, Ленина, 33	f	small
25308	74250	1034	Приморский край, Ханкайский район, село Пархоменко, Центральная, 1б	f	small
25319	74262	1044	Приморский край, Ханкайский район, село Октябрьское, Советская, 19А	f	small
25310	74252	1036	Приморский край, Ханкайский район, село Новоселище, Пролетарская, 8	f	medium
25317	74260	1042	Приморский край, Ханкайский район, село Новониколаевка, Жданова, 17	t	\N
25323	74266	1048	Приморский край, Ханкайский район, село Новокачалинск, Калинина, 17	f	medium
25312	74255	1038	Приморский край, Ханкайский район, село Мельгуновка, Ленинская, 30А	f	medium
25318	74261	1043	Приморский край, Ханкайский район, село Майское, Почтовая, 11	f	medium
25316	74259	1041	Приморский край, Ханкайский район, село Люблино, Новая, 9, кв.2	t	small
25320	74263	1045	Приморский край, Ханкайский район, село Комиссарово, Советская, 16ж	t	small
25304	74246	1030	Приморский край, Ханкайский район, село Камень-Рыболов, городок №1	f	large
25305	74247	1031	Приморский край, Ханкайский район, село Камень-Рыболов, Трактовая, 119	f	medium
25302	74244	1028	Приморский край, Ханкайский район, село Камень-Рыболов, Пионерская, 8	f	large
25306	74248	1032	Приморский край, Ханкайский район, село Камень-Рыболов, Мира, 10	f	large
25301	74243	1027	Приморский край, Ханкайский район, село Камень-Рыболов, Кирова, 10	f	large
25315	74258	1040	Приморский край, Ханкайский район, село Ильинка, Столетия, 1	f	large
25321	74264	1046	Приморский край, Ханкайский район, село Дворянка, Сидельникова, 26	t	small
25309	74251	1035	Приморский край, Ханкайский район, село Владимиро-Петровка, Молодежная, 7	f	medium
25307	74249	1033	Приморский край, Ханкайский район, село Астраханка, Березюка, 1	f	large
25311	74254	1037	Приморский край, Ханкайский район, село Алексеевка, Школьная, 15а	t	small
24671	73654	355	Приморский край, Фрунзенский район,, Поселок Аякс, МБОУ СОШ № 5	f	medium
25277	74220	1001	Приморский край, Уссурийский район, село Яконовка, Центральная, 76/1	t	small
25286	74229	1010	Приморский край, Уссурийский район, село Утесное, Раздольная, 2	f	small
25273	74216	997	Приморский край, Уссурийский район, село Улитовка, Новая, 59	t	small
25281	74224	1005	Приморский край, Уссурийский район, поселок Тимирязевский, Воложенина, 2В	f	large
25280	74223	1004	Приморский край, Уссурийский район, село Степное, Центральная, 4	f	medium
25283	74226	1007	Приморский край, Уссурийский район, село Раковка, Советская, 1а	f	medium
25289	74232	1013	Приморский край, Уссурийский район, село Партизан, Партизанская, 8	t	small
25299	74241	1023	Приморский край, Уссурийский район, село Новоникольск, Советская, 79	f	large
25279	74222	1003	Приморский край, Уссурийский район, село Новоникольск, Советская, 70	f	large
25269	74212	993	Приморский край, Уссурийский район, село Николо-Львовское, Пархоменко, 2а	f	small
25274	74217	998	Приморский край, Уссурийский район, село Монакино, Угловая, 8/2	t	small
25288	74231	1012	Приморский край, Уссурийский район, село Линевичи, Центральная, 2	t	small
25276	74219	1000	Приморский край, Уссурийский район, село Кроуновка, Советская, 35	f	small
25287	74230	1011	Приморский край, Уссурийский район, село Красный Яр, Советская, 36	f	small
25275	74218	999	Приморский край, Уссурийский район, село Корсаковка, Комсомольская, 12	f	large
25291	74234	1015	Приморский край, Уссурийский район, село Кондратеновка, Баневура, 36	f	small
25293	74236	1017	Приморский край, Уссурийский район, село Каменушка, Школьная, 15	f	medium
25294	74237	1018	Приморский край, Уссурийский район, село Заречное, Пионерская, 1а	f	medium
25290	74233	1014	Приморский край, Уссурийский район, село Дубовый Ключ, Садовая, 5	f	small
25292	74235	1016	Приморский край, Уссурийский район, село Горнотаежное, Солнечная, 9а	f	small
25284	74227	1008	Приморский край, Уссурийский район, село Глуховка, Октябрьская, 44	f	small
25297	74240	1021	Приморский край, Уссурийский район, село Воздвиженка, Чайковского, 3	f	large
25282	74225	1006	Приморский край, Уссурийский район, село Воздвиженка, Ленинская, 59	f	large
25296	74239	1020	Приморский край, Уссурийский район, село Воздвиженка, Жуковского, 5	f	medium
25278	74221	1002	Приморский край, Уссурийский район, село Борисовка, Советская, 55	f	large
25285	74228	1009	Приморский край, Уссурийский район, село Боголюбовка, Новая, 2А	t	small
25272	74215	996	Приморский край, Уссурийский район, село Богатырка, Центральная, 13	t	small
25295	74238	1019	Приморский край, Уссурийский район, село Баневурово, Школьная, 32	f	small
25193	74144	910	Приморский край, Тернейский район, село Усть-Соболевка, Советская, 16	t	small
25188	74138	905	Приморский край, Тернейский район, поселок городского типа Терней, Партизанская, 70	f	large
25189	74139	906	Приморский край, Тернейский район, поселок Терней, Партизанская, 71	f	large
25194	74145	911	Приморский край, Тернейский район, поселок городского типа Светлая, Школьная, 33	t	medium
25196	74147	913	Приморский край, Тернейский район, село Самарга, Береговая, 13	t	small
25186	74136	903	Приморский край, Тернейский район, поселок городского типа Пластун, Третий квартал, 6	f	large
25187	74137	904	Приморский край, Тернейский район, поселок городского типа Пластун, Лермонтова, 12-А	f	large
25195	74146	912	Приморский край, Тернейский район, село Перетычиха, Школьная, 18	f	small
25190	74140	907	Приморский край, Тернейский район, село Малая Кема, Спортивная, 10	f	medium
25191	74141	908	Приморский край, Тернейский район, село Амгу, Молодежная, 8	t	medium
25197	74148	914	Приморский край, Тернейский район, село Агзу, Крючкова, 10	t	small
49541	53964	25	Магаданская область, Магадан, Пролетарская, 110	f	large
25518	74448	1263	Приморский край, Спасский район, село Чкаловское, Торговый, 12	f	large
113282	74535	1266	Приморский край, Спасский район, село Чкаловское, Терешкевича, 54	f	\N
25519	74449	1264	Приморский край, Спасский район, село Чкаловское, Терешкевича, 55	f	large
25517	74447	1262	Приморский край, Спасский район, село Хвалынка, Советская, 29	f	medium
25516	74446	1261	Приморский край, Спасский район, село Татьяновка, переулок Новый, 2	f	small
25514	74445	1259	Приморский край, Спасский район, село Степное, Центральная, 6	f	small
25510	74442	1255	Приморский край, Спасский район, село Спасское, переулок Студенческий, 26	f	large
113281	74534	1244	Приморский край, Спасский район, село Спасское, Комсомольская, 108	f	\N
25513	74443	1258	Приморский край, Спасский район, село Спасское, Комсомольская, 104	f	large
25511	74443	1256	Приморский край, Спасский район, село Спасское, Комсомольская, 104	f	medium
25512	74444	1257	Приморский край, Спасский район, село Спасское, 70 лет Октября, 2	f	large
25509	74441	1254	Приморский край, Спасский район, село Сосновка, Советская, 49к1	t	small
25508	74440	1253	Приморский край, Спасский район, село Славинка, Преображенская, 1А	f	small
25507	74439	1252	Приморский край, Спасский район, село Свиягино, Партизанская, 12	f	large
25506	74437	1251	Приморский край, Спасский район, село Прохоры, Ленинская, 66	f	medium
25505	74436	1250	Приморский край, Спасский район, село Новосельское, Центральная, 20	f	medium
25503	74434	1248	Приморский край, Спасский район, село Нововладимировка, Центральная, 18	f	small
25502	74433	1247	Приморский край, Спасский район, село Новинка, Тополиная, 6	f	small
25501	74432	1246	Приморский край, Спасский район, село Нахимовка, Садовая, 3,1	f	small
25500	74431	1245	Приморский край, Спасский район, село Малые Ключи, Октябрьский переулок, 2	f	small
25499	74430	1242	Приморский край, Спасский район, село Кронштадка, Борисова, 6	f	small
25489	74420	1232	Приморский край, Спасский район, село Красный Кут, 1, ДОС	f	medium
25498	74429	1241	Приморский край, Спасский район, село Красный Кут, Октябрьская, 82	f	small
25497	74428	1240	Приморский край, Спасский район, село Константиновка, Средняя, 3	t	small
25496	74427	1239	Приморский край, Спасский район, Кнорринг, железнодорожная станция Кнорринг	t	small
25494	74425	1237	Приморский край, Спасский район, село Зеленодольское, Школьная, 3	f	small
25493	74424	1236	Приморский край, Спасский район, село Зеленовка, Первомайская, 36	f	small
25492	74423	1235	Приморский край, Спасский район, село Евсеевка, Кедровая, 13 А	f	small
25491	74422	1234	Приморский край, Спасский район, село Духовское, Переулок Школьный, 13	f	medium
25490	74421	1233	Приморский край, Спасский район, село Дубовское, Молодежная, 35	f	medium
25488	74419	1231	Приморский край, Спасский район, село Гайворон, Ленинская, 37	f	small
25487	74418	1230	Приморский край, Спасский район, село Воскресенка, пер.Школьный, 4	f	medium
25486	74417	1229	Приморский край, Спасский район, село Вишневка, Переулок Школьный, 1 А	f	medium
25484	74415	1227	Приморский край, Спасский район, село Буссевка, Советская, 27	f	medium
113280	74533	1243	Приморский край, Спасский район, село Буссевка, Светлая, 19	t	\N
25483	74413	1226	Приморский край, Спасский район, село Анненка, Гагарина, 2/2	t	small
25482	74412	1225	Приморский край, Спасский район, село Александровка, Уборевича, 63 А	f	large
25153	74105	867	Приморский край, Пожарский район, село Ясеневый, Широкая, 6	t	small
25149	74101	863	Приморский край, Пожарский район, село Федосьевка, Советская, 29	f	medium
25152	74104	866	Приморский край, Пожарский район, село Соболиный, Родниковая, 4	t	small
25150	74102	864	Приморский край, Пожарский район, село Светлогорье, Хомякова, 2	f	large
25133	74086	846	Приморский край, Пожарский район, село Пожарское, Ленинская, 27	f	large
25132	74085	845	Приморский край, Пожарский район, село Пожарский, Центральная	f	small
25130	74083	843	Приморский край, Пожарский район, село Новостройка, Заводская, 12	f	large
25134	74087	847	Приморский край, Пожарский район, село Никитовка, Зелёная, 25а	f	small
25138	74092	851	Приморский край, Пожарский район, село Нагорное, Юбилейная, 7	f	medium
25147	74099	861	Приморский край, Пожарский район, поселок городского типа Лучегорск, третий микрорайон, 30	f	medium
25145	74097	858	Приморский край, Пожарский район, Лучегорск, первый микрорайон, 12	f	large
25142	74095	855	Приморский край, Пожарский район, поселок Лучегорск, 2, общественный центр	f	large
25144	74096	857	Приморский край, Пожарский район, поселок Лучегорск, второй микрорайон	f	large
25143	74096	856	Приморский край, Пожарский район, поселок Лучегорск, второй микрорайон	f	large
25141	74094	854	Приморский край, Пожарский район, поселок Лучегорск, Четвертый микрорайон, 4	f	large
25140	74094	853	Приморский край, Пожарский район, поселок Лучегорск, Четвертый микрорайон, 4	f	large
25139	74093	852	Приморский край, Пожарский район, поселок Лучегорск, Ленина, 35а	f	large
25136	74089	849	Приморский край, Пожарский район, село Ласточка, Вокзальная, 1	f	small
25154	74106	868	Приморский край, Пожарский район, село Красный Яр, Арсеньева, 9а	t	small
25137	74091	850	Приморский край, Пожарский район, село Игнатьевка, Советская, 11	f	small
25129	74082	842	Приморский край, Пожарский район, село Знаменка, Веселая	f	small
25135	74088	848	Приморский край, Пожарский район, село Емельяновка, Пограничная, 13	t	small
25131	74084	844	Приморский край, Пожарский район, село Губерово, Совхозная, 15А	f	medium
25151	74103	865	Приморский край, Пожарский район, село Верхний Перевал, Школьная, 2	f	\N
25116	74069	829	Приморский край, Пограничный район, поселок Таловый, Центральная, 1А	t	small
25114	74067	827	Приморский край, Пограничный район, село Софье-Алексеевское, Центральная, 10	f	small
25119	74072	832	Приморский край, Пограничный район, Сергеевка, Колхозная, 22 А	f	medium
25117	74070	830	Приморский край, Пограничный район, село Садовый, Верхняя, 15	f	small
25127	74080	840	Приморский край, Пограничный район, село Рубиновка, Набережная, 13	f	small
25104	74057	817	Приморский край, Пограничный район, поселок Пограничный, Орлова, 14	f	large
25109	74062	822	Приморский край, Пограничный район, поселок Пограничный, Лазо, 101	f	medium
25105	74058	818	Приморский край, Пограничный район, поселок Пограничный, Дубовика, 8	f	large
25108	74061	821	Приморский край, Пограничный район, поселок Пограничный, Гагарина, 9	f	large
25107	74060	820	Приморский край, Пограничный район, поселок Пограничный, Гагарина, 8	f	large
25106	74059	819	Приморский край, Пограничный район, поселок городского типа Пограничный, Советская, 63	f	medium
25110	74063	823	Приморский край, Пограничный район, поселок городского типа Пограничный, Лазо, 141	f	large
25122	74075	835	Приморский край, Пограничный район, Нестеровка, Советская, 22	f	medium
25123	74076	836	Приморский край, Пограничный район, село Жариково, Кооперативная, 26	f	large
25126	74079	839	Приморский край, Пограничный район, село Духовское, Ленина , 15А	f	\N
25111	74064	824	Приморский край, Пограничный район, село Бойкое, Ленина, 20	f	small
25125	74078	838	Приморский край, Пограничный район, село Богуславка, Школьная, 55	f	medium
25112	74065	825	Приморский край, Пограничный район, село Барано-Оренбургское, Победы, 21 А	f	large
25095	74049	804	Приморский край, Партизанский район, село Хмыловка, 40 лет Победы, 1А	f	small
25085	74038	795	Приморский край, Партизанский район, Фроловка, Партизанская, 20	f	medium
25083	74036	793	Приморский край, Партизанский район, село Сергеевка, Школьный переулок, 4	f	large
25084	74037	794	Приморский край, Партизанский район, село Сергеевка, Ручейная, 1а	f	medium
25090	74044	799	Приморский край, Партизанский район, Село Перетино, Черняховского, 4	f	small
25101	74055	810	Приморский край, Партизанский район, село Новолитовск, Черняховского, 35	f	medium
25089	74042	798	Приморский край, Партизанский район, село Новицкое, Лазо, 7	f	large
25096	74050	805	Приморский край, Партизанский район, село Новая Сила, Центральная, 1-а	f	small
25088	74041	797	Приморский край, Партизанский район, поселок Николаевка, Фадеева, 19	f	large
25081	74034	791	Приморский край, Партизанский район, село Молчановка, Ключевая, 3	f	medium
25091	74045	800	Приморский край, Партизанский район, село Золотая Долина, Центральная, 68	f	large
25092	74046	801	Приморский край, Партизанский район, село Золотая Долина, Летная, 11	f	\N
25098	74052	807	Приморский край, Партизанский район, село Екатериновка, Советская, 6а	f	large
25099	74053	808	Приморский край, Партизанский район, село Екатериновка, Молодежная, 13	f	large
25100	74054	809	Приморский край, Партизанский район, село Голубовка, 60 лет СССР, 1	f	small
24937	73910	640	Приморский край, Партизанский район, поселок Врангель, Первостроителей, 10	f	large
24938	73873	641	Приморский край, Партизанский район, поселок Врангель, Железнодорожная, 3	f	medium
24939	73885	642	Приморский край, Партизанский район, поселок Врангель, Внутрипортовая, 23	f	medium
24936	73909	639	Приморский край, Партизанский район, поселок Врангель, Бабкина, 5	f	large
24935	73909	638	Приморский край, Партизанский район, поселок Врангель, Бабкина, 5	f	large
25102	74056	811	Приморский край, Партизанский район, поселок Волчанец, Озерная, 10	t	medium
25094	74048	803	Приморский край, Партизанский район, село Владимиро-Александровское, Лазо, 125	f	large
25093	74047	802	Приморский край, Партизанский район, село Владимиро-Александровское, Комсомольская, 30	f	large
25097	74051	806	Приморский край, Партизанский район, поселок Боец Кузнецов, Первомайская, 8	f	medium
25032	73985	738	Приморский край, Ольгинский район, село Щербаковка, Центральная, 28	f	\N
25031	73984	737	Приморский край, Ольгинский район, село Фурманово, Центральная, 12	t	\N
25037	73990	743	Приморский край, Ольгинский район, поселок Тимофеевка, Ленина, 1А	f	medium
25038	73991	744	Приморский край, Ольгинский район, поселок Ракушка, Адмирала Федюковского, 24-4	f	small
25027	73980	733	Приморский край, Ольгинский район, село Пермское, Центральная, 18	f	medium
25024	73977	730	Приморский край, Ольгинский район, поселок городского типа Ольга, Партизанская, 1	f	large
25029	73982	735	Приморский край, Ольгинский район, село Новониколаевка, Центральная, 19	t	small
25034	73987	740	Приморский край, Ольгинский район, поселок Моряк-Рыболов, Школьная, 3	f	medium
25033	73986	739	Приморский край, Ольгинский район, село Маргаритово, Школьная, 13	f	small
25036	73989	742	Приморский край, Ольгинский район, село Лиственное, Таежная, 32	t	small
25028	73981	734	Приморский край, Ольгинский район, село Ветка, Буденного, 5	t	small
25023	73976	729	Приморский край, Ольгинский район, село Веселый Яр, Набережная, 57	f	medium
25004	73960	709	Приморский край, Октябрьский район, село Покровка, Красноармейская, 34	f	small
24925	73900	625	Приморский край, Надеждинский район, п. Тавричанка, РВС-1, Клуб	t	small
24899	73872	597	Приморский край, Надеждинский район, село Тихое, Таежная, 20	t	small
24907	73881	605	Приморский край, Надеждинский район, село Тимофеевка, Центральная, 15	t	small
24895	73868	593	Приморский край, Надеждинский район, село Тереховка, Ленина, 4	f	small
24910	73884	608	Приморский край, Надеждинский район, поселок Таежный, Мира, 8	f	small
24923	73898	623	Приморский край, Надеждинский район, Тавричанка, Парковая, 15А	f	large
24919	73894	618	Приморский край, Надеждинский район, поселок Соловей-Ключ, Центральная, 30	t	small
24904	73878	602	Приморский край, Надеждинский район, поселок Раздольное, Пирогова, 40-А	t	medium
24900	73874	598	Приморский край, Надеждинский район, поселок Раздольное, Ленинская, 1	f	large
24903	73877	601	Приморский край, Надеждинский район, поселок Раздольное, Лазо, 320	f	large
24901	73875	599	Приморский край, Надеждинский район, поселок Раздольное, Лазо, 36А	f	large
24902	73876	600	Приморский край, Надеждинский район, поселок Раздольное, Котовского, 1Б	f	large
24918	73893	617	Приморский край, Надеждинский район, село Прохладное, Амурская, 3	f	large
24905	73879	603	Приморский край, Надеждинский район, поселок Оленевод, Шоссейная, 9-А	f	medium
24916	73891	615	Приморский край, Надеждинский район, поселок Новый, Первомайская, 37	f	large
24898	73871	596	Приморский край, Надеждинский район, село Нежино, Шоссейная, 14-А	f	small
24909	73883	607	Приморский край, Надеждинский район, село Кипарисово-2, Пролетарская, 7	f	medium
24908	73882	606	Приморский край, Надеждинский район, село Кипарисово-1, Советская, 1	f	medium
24911	73886	609	Приморский край, Надеждинский район, поселок Западный, Курбаева, 2-А	f	small
24921	73896	620	Приморский край, Надеждинский район, Девятый Вал, Набивайло, 14	f	medium
24896	73869	594	Приморский край, Надеждинский район, село Городечное, Свободы, 12	f	small
24913	73888	611	Приморский край, Надеждинский район, село Вольно-Надеждинское, Пушкина, 51	f	large
24912	73887	610	Приморский край, Надеждинский район, село Вольно-Надеждинское, Ленина, 39-А	f	large
24914	73889	612	Приморский край, Надеждинский район, село Вольно-Надеждинское, Дрегиса, 5	f	large
24897	73870	595	Приморский край, Надеждинский район, село Барановский, Тополинная, 1, железнодорожная станция Барановский	f	small
24906	73880	604	Приморский край, Надеждинский район, поселок Алексеевка, Ленина, 56	f	small
24892	73865	586	Приморский край, Михайловский район, село Ширяевка, Октябрьская, 34	f	medium
24893	73866	587	Приморский край, Михайловский район, село Тарасовка, Ломоносова, 18/а	f	small
24874	73848	568	Приморский край, Михайловский район, село Степное, Совхозная, 37	f	small
24872	73846	566	Приморский край, Михайловский район, село Песчаное, Флотская, 38	f	small
24875	73849	569	Приморский край, Михайловский район, село Первомайское, Школьная, 27	f	large
24891	73864	585	Приморский край, Михайловский район, село Отрадное, Садовая, 15	f	small
24885	73858	579	Приморский край, Михайловский район, село Осиновка, Комсомольская, 4/а	f	large
113291	74544	589	Приморский край, Михайловский район, поселок городского типа Новошахтинский, Ленинская, 12	f	\N
24882	73855	576	Приморский край, Михайловский район, поселок Новошахтинский, Ленинская, 8а	f	large
24881	73855	575	Приморский край, Михайловский район, поселок Новошахтинский, Ленинская, 8а	f	large
24880	73854	574	Приморский край, Михайловский район, поселок Новошахтинский, Ленинская, 5	f	large
24879	73853	573	Приморский край, Михайловский район, село Новожатково, Центральная, 2а	f	small
24890	73863	584	Приморский край, Михайловский район, село Николаевка, Ленинская, 60	f	small
24873	73847	567	Приморский край, Михайловский район, село Некруглово, Школьная, 2	f	small
24867	73842	561	Приморский край, Михайловский район, село Михайловка, Ленинская, 38	f	large
24870	73843	564	Приморский край, Михайловский район, село Михайловка, Красноармейская, 33	f	large
24868	73843	562	Приморский край, Михайловский район, село Михайловка, Красноармейская, 33	f	large
24866	73841	560	Приморский край, Михайловский район, село Михайловка, Красноармейская, 12	f	large
24869	73844	563	Приморский край, Михайловский район, село Михайловка, Колхозная, 83	f	large
24884	73857	578	Приморский край, Михайловский район, село Ляличи, Школьная, 28	f	medium
24894	73867	588	Приморский край, Михайловский район, село Лубянка, Ленина, 27/а	f	small
24883	73856	577	Приморский край, Михайловский район, село Кремово, Колхозная, 25/а	f	large
24889	73862	583	Приморский край, Михайловский район, село Ивановка, Краснознаменная, 24/б	f	large
24876	73850	570	Приморский край, Михайловский район, село Дубки, 40 лет Победы, 1/а	f	small
24886	73859	580	Приморский край, Михайловский район, село Даниловка, Ленинская , 44	f	small
24878	73852	572	Приморский край, Михайловский район, село Григорьевка, Калинина, 12	f	medium
24887	73860	581	Приморский край, Михайловский район, село Горное, Ленина, 5	f	small
24888	73861	582	Приморский край, Михайловский район, село Горбатка, Ленинская, 25	f	small
24877	73851	571	Приморский край, Михайловский район, село Абрамовка, Советская, 26	f	medium
24857	73832	549	Приморский край, Лесозаводский район, село Филаретовка, Почтовая, 10	f	small
24853	73828	545	Приморский край, Лесозаводский район, село Урожайное, Ленинская, 37	f	medium
24854	73829	546	Приморский край, Лесозаводский район, село Тургенево, Октябрьская, 27 б	f	small
24862	73837	554	Приморский край, Лесозаводский район, село Тихменево, Советская, 36	f	medium
24849	73824	541	Приморский край, Лесозаводский район, село Тамга, Центральная, 33	t	small
24855	73830	547	Приморский край, Лесозаводский район, село Ружино, Советская, 44	f	medium
24863	73838	555	Приморский край, Лесозаводский район, село Полевое, Дзержинского, 174	f	medium
24851	73826	543	Приморский край, Лесозаводский район, село Пантелеймоновка, Центральная, 39	f	\N
24852	73827	544	Приморский край, Лесозаводский район, село Невское, Центральная, 16	f	small
24865	73840	557	Приморский край, Лесозаводский район, село Марково, Волкова, 10	f	\N
24861	73836	553	Приморский край, Лесозаводский район, село Лесное, Школьная, 10А	f	small
24858	73833	550	Приморский край, Лесозаводский район, село Курское, Советская, 1	f	\N
24860	73835	552	Приморский край, Лесозаводский район, село Иннокентьевка, Школьная, 1	f	small
24850	73825	542	Приморский край, Лесозаводский район, село Ильмовка, Центральная, 39	t	small
24856	73831	548	Приморский край, Лесозаводский район, село Елизаветовка, Центральная, 24	t	small
24864	73839	556	Приморский край, Лесозаводский район, село Донское, Молодежная, 2а	f	small
24859	73834	551	Приморский край, Лесозаводский район, село Глазовка, Центральная, 30	f	small
24814	73789	504	Приморский край, Лазовский район, село Чистоводное, Центральная, 8	t	\N
24822	73798	512	Приморский край, Лазовский район, село Черноручье, Шевченко, 23 Б	f	small
24820	73796	510	Приморский край, Лазовский район, село Старая Каменка, Центральная, 39	f	small
24821	73797	511	Приморский край, Лазовский район, село Сокольчи, Шоссейная, 56	f	small
113299	74552	1961	Приморский край, Лазовский район, поселок Преображение, 30 лет Победы, 2А	f	\N
113298	74550	1959	Приморский край, Лазовский район, поселок городского типа Преображение, Морская, 6	f	\N
113297	74550	1958	Приморский край, Лазовский район, поселок городского типа Преображение, Морская, 6	f	\N
24810	73785	498	Приморский край, Лазовский район, поселок городского типа Преображение, Морская, 6	f	large
24811	73786	499	Приморский край, Лазовский район, поселок городского типа Преображение, Заречная, 34	f	medium
113289	74542	503	Приморский край, Лазовский район, поселок городского типа Преображение, 30 лет Победы, 2А	f	\N
24812	73787	500	Приморский край, Лазовский район, поселок городского типа Преображение, 30 лет Победы, 2А	f	large
24817	73792	507	Приморский край, Лазовский район, село Лазо, Центральная, 30	f	medium
24819	73795	509	Приморский край, Лазовский район, село Лазо, Советская, 83	f	medium
113290	74543	517	Приморский край, Лазовский район, село Лазо, Некрасовская, 26	f	\N
113288	74541	501	Приморский край, Лазовский район, село Лазо, Некрасовская, 9	f	\N
24816	73791	506	Приморский край, Лазовский район, село Кишиневка, Школьная, 3	f	small
24813	73788	502	Приморский край, Лазовский район, село Киевка, 50 лет Октября, 37	f	small
24823	73799	513	Приморский край, Лазовский район, село Данильченково, Партизанская, 6	t	small
24825	73801	515	Приморский край, Лазовский район, село Глазковка, Тигровая, 26	t	small
24824	73800	514	Приморский край, Лазовский район, село Валентин, Первомайская, 17	f	medium
24815	73790	505	Приморский край, Лазовский район, село Беневское, Центральная, 50	f	medium
113287	74540	497	Приморский край, Красноармейский район, поселок городского типа Восток, Молодежная, 3А	t	\N
24765	73748	452	Приморский край, Кировский район, село Шмаковка, пер. Школьный, 1	f	small
24774	73758	461	Приморский край, Кировский район, село Хвищанка, Петровская, 22	f	small
24778	73762	465	Приморский край, Кировский район, село Уссурка, Школьная, 4-а	f	medium
24756	73739	443	Приморский край, Кировский район, село Увальное, Первомайская, 2- А	f	medium
24754	73737	441	Приморский край, Кировский район, село Степановка, Центральная, 24	f	small
24752	73735	439	Приморский край, Кировский район, село Руновка, Кооперативная, 6	f	small
24766	73749	453	Приморский край, Кировский район, село Родниковый, Центральная, 2	f	small
24769	73752	456	Приморский край, Кировский район, село Преображенка, Советская, 12-а	f	small
24768	73751	455	Приморский край, Кировский район, село Павло-Федоровка, Почтовая, 32	f	medium
24771	73755	458	Приморский край, Кировский район, село Межгорье, Шоссейная, 7	f	small
24776	73760	463	Приморский край, Кировский район, село Марьяновка, Почтовая , 12	f	small
24757	73740	444	Приморский край, Кировский район, село Луговое, Центральная, 1	f	small
24750	73733	437	Приморский край, Кировский район, село Комаровка, Советская, 28	f	small
25615	74524	1951	Приморский край, Кировский район, поселок городского типа Кировский, Уткинская, 53	f	medium
25616	74525	1952	Приморский край, Кировский район, поселок городского типа Кировский, Советская, 91	f	medium
24763	73746	450	Приморский край, Кировский район, поселок городского типа Кировский, Советская, 55-а	f	medium
24764	73747	451	Приморский край, Кировский район, поселок городского типа Кировский, Набережная, 61	f	medium
25614	74523	1950	Приморский край, Кировский район, поселок городского типа Кировский, Ленинская, 130	f	medium
24761	73744	448	Приморский край, Кировский район, поселок городского типа Кировский, Ленинская, 39	f	large
24759	73742	446	Приморский край, Кировский район, поселок городского типа Кировский, Ленинская, 92	f	medium
24760	73743	447	Приморский край, Кировский район, поселок Кировский, Пролетарская, 2	f	medium
24762	73745	449	Приморский край, Кировский район, поселок Кировский, Площадь Свободы, 46	f	small
24783	73768	470	Приморский край, Кировский район, поселок Кировский, Колхозная, 29	f	small
24758	73741	445	Приморский край, Кировский район, поселок Кировский, Гагарина, 87	f	medium
24777	73761	464	Приморский край, Кировский район, поселок Горный, Приисковая, 20А	f	small
25619	74528	1955	Приморский край, Кировский район, поселок городского типа Горные Ключи, проспект Лазурный, 1	f	small
24782	73767	469	Приморский край, Кировский район, поселок городского типа Горные Ключи, Юбилейная, 43	f	medium
24780	73764	467	Приморский край, Кировский район, поселок городского типа Горные Ключи, Санаторная, 5	f	medium
24779	73763	466	Приморский край, Кировский район, поселок городского типа Горные Ключи, 60 лет СССР, 10	f	large
24781	73766	468	Приморский край, Кировский район, поселок Горные Ключи, Юбилейная, 17	f	small
24784	73769	471	Приморский край, Кировский район, поселок Горные Ключи, Профсоюзная, 1	f	small
25618	74527	1954	Приморский край, Кировский район, поселок Горные Ключи, Октябрьская, 21	f	small
24775	73759	462	Приморский край, Кировский район, село Владимировка, Центральная, 1	t	small
24773	73757	460	Приморский край, Кировский район, село Большие Ключи, Верхняя, 22	f	small
24753	73736	440	Приморский край, Кировский район, село Афанасьевка, Первомайская, 17	f	small
24770	73754	457	Приморский край, Кировский район, село Архангеловка, Центральная, 9	f	small
24751	73734	438	Приморский край, Кировский район, село Антоновка, Центральная, 34	f	small
24767	73750	454	Приморский край, Кировский район, село Авдеевка, Центральная, 18	f	small
24745	73727	432	Приморский край, Кавалеровский район, поселок городского типа Хрустальный, Фрунзе, 1	f	medium
24744	73726	431	Приморский край, Кавалеровский район, поселок городского типа Хрустальный, Комсомольская, 98	f	large
24730	73711	416	Приморский край, Кавалеровский район, село Устиновка, Центральная, 10 в	f	small
24729	73710	415	Приморский край, Кавалеровский район, село Суворово, Вобликова, 27	f	small
24731	73712	417	Приморский край, Кавалеровский район, село Синегорье, Речная, 19 а	f	small
24746	73729	433	Приморский край, Кавалеровский район, село Рудный, Поворотная, 46	f	medium
24743	73725	430	Приморский край, Кавалеровский район, поселок Кавалерово, Арсеньева, 166 А	f	large
24739	73721	426	Приморский край, Кавалеровский район, поселок Кавалерово, Арсеньева, 97	f	large
24738	73720	425	Приморский край, Кавалеровский район, поселок Кавалерово, Арсеньева, 83	f	large
24742	73724	429	Приморский край, Кавалеровский район, поселок городского типа Кавалерово, Рабочая, 47	f	large
24740	73722	427	Приморский край, Кавалеровский район, поселок городского типа Кавалерово, Первомайская, 36	f	large
24736	73718	423	Приморский край, Кавалеровский район, поселок городского типа Кавалерово, Первомайская, 55	f	large
24735	73717	422	Приморский край, Кавалеровский район, поселок городского типа Кавалерово, Первомайская, 154	f	large
24741	73723	428	Приморский край, Кавалеровский район, поселок городского типа Кавалерово, Гагарина, 16	f	large
24737	73719	424	Приморский край, Кавалеровский район, поселок городского типа Кавалерово, Арсеньева, 57	f	large
24727	73708	413	Приморский край, Кавалеровский район, село Зеркальное, Школьная, 1	f	small
24733	73714	419	Приморский край, Кавалеровский район, поселок Горнореченский, Строительная, 24	f	large
24734	73715	421	Приморский край, Кавалеровский район, поселок Горнореченский, Советская, 12	f	medium
24732	73713	418	Приморский край, Кавалеровский район, поселок городского типа Высокогорск, Арсеньева, 38	f	small
24728	73709	414	Приморский край, Кавалеровский район, село Богополь, Рабочая, 2А	f	small
25530	74460	1276	Приморский край, Дальнереченский район, село Ясная Поляна, Центральная, 29	t	small
25523	74453	1269	Приморский край, Дальнереченский район, село Стретенка, Лободы, 36	f	small
25522	74452	1268	Приморский край, Дальнереченский район, село Соловьевка, Центральная, 10Б	f	small
25526	74456	1272	Приморский край, Дальнереченский район, село Сальское, Советская, 15	f	large
25536	74465	1282	Приморский край, Дальнереченский район, поселок Пожига, Школьная, 24	t	small
25524	74454	1270	Приморский край, Дальнереченский район, село Новотроицкое, Пионерская, 5	t	small
25525	74455	1271	Приморский край, Дальнереченский район, село Междуречье, П.Марценюка, 24А	f	small
25532	74461	1278	Приморский край, Дальнереченский район, село Малиново, Школьная, 29	f	medium
25531	74438	1277	Приморский край, Дальнереченский район, село Лобановка, Центральная, 31	t	small
24818	73793	508	Приморский край, Дальнереченский район, село Лазо, Некрасовская, 26	f	large
24725	73706	411	Приморский край, Дальнереченский район, село Лазо, Лазо, 37	f	medium
24726	73707	412	Приморский край, Дальнереченский район, село Лазо, Калинина, 40	f	large
25534	74463	1280	Приморский край, Дальнереченский район, село Зимники, Майская, 15	f	small
25558	74486	1322	Приморский край, Дальнереченский район, село Грушевое, Лазо, 36	f	medium
25521	74451	1267	Приморский край, Дальнереченский район, село Веденка, Мелехина, 40	f	large
24702	73682	387	Приморский край, Дальнегорский район, село Сержантово, Линейная , 9	f	large
24704	73684	389	Приморский край, Дальнегорский район, поселок городского типа Рудная Пристань, Арсеньева	f	large
25557	74485	1308	Приморский край, Дальнегорский район, село Подъяпольское, Центральная, 2Б	f	medium
25556	74485	1307	Приморский край, Дальнегорский район, село Подъяпольское, Центральная, 2Б	f	large
24703	73683	388	Приморский край, Дальнегорский район, село Мономахово, Школьная, 17	f	small
24682	73665	368	Приморский край, Дальнегорский район, поселок городского типа Краснореченский, Октябрьская, 17	f	large
24431	73458	105	Приморский край, Артем городской округ, село Ясное, Чернышева, 2	f	small
25541	74470	1292	Приморский край, Артем городской округ, поселок Штыково, Гидроузла, 6	f	large
24421	73448	95	Приморский край, Артем городской округ, село Суражевка, Ярославская, 52	f	large
24429	73456	103	Приморский край, Артем городской округ, село Кневичи, переулок Чуркина, 12	f	large
24357	73384	23	Приморский край, Анучинский район, село Чернышевка, в\\ч 12758, клуб	f	medium
24356	73383	22	Приморский край, Анучинский район, село Чернышевка, Советская, 21	f	large
24353	73380	19	Приморский край, Анучинский район, село Тихоречное, Молодежная, 20	f	small
24342	73369	8	Приморский край, Анучинский район, село Таежка, Советская, 33а	f	\N
24340	73366	6	Приморский край, Анучинский район, село Старогордеевка, Комарова, 16	t	small
24349	73376	15	Приморский край, Анучинский район, село Староварваровка, Мира, 25	f	small
24346	73373	12	Приморский край, Анучинский район, село Смольное, Центральная, 3	f	\N
24350	73377	16	Приморский край, Анучинский район, село Рисовое, Увальная, 10	f	small
24351	73378	17	Приморский край, Анучинский район, село Пухово, Школьная, 5	f	medium
24354	73381	20	Приморский край, Анучинский район, село Новотроицкое, Молодежная, 9	t	small
24341	73368	7	Приморский край, Анучинский район, село Новогордеевка, Комсомольская, 1А	f	medium
24338	73364	4	Приморский край, Анучинский район, село Нововарваровка, Ленинская, 3	f	small
24345	73372	11	Приморский край, Анучинский район, село Муравейка, Партизанская, 20	t	small
24355	73382	21	Приморский край, Анучинский район, село Корниловка, Первомайская, 29	t	small
24348	73375	14	Приморский край, Анучинский район, село Ильмаковка, Центральная, 14	f	\N
24344	73371	10	Приморский край, Анучинский район, село Еловка, Школьный, 1А	t	small
24339	73365	5	Приморский край, Анучинский район, село Гродеково, Центральная, 37Б	f	small
24352	73379	18	Приморский край, Анучинский район, село Гражданка, Юбилейная, 13А	f	medium
24347	73374	13	Приморский край, Анучинский район, село Виноградовка, Советская, 36	f	small
24337	73363	3	Приморский край, Анучинский район, село Анучино, Центральная, 1	f	small
24335	73361	1	Приморский край, Анучинский район, село Анучино, Лазо, 4	f	large
24336	73362	2	Приморский край, Анучинский район, село Анучино, Горького, 37	f	large
49553	53976	37	Магаданская область, п.Сокол, Гагарина, 13-а	f	large
49580	54003	64	Магаданская область, Сусуман, Ленина, 30	f	large
49552	53975	36	Магаданская область, поселок Сокол, Гагарина, 20-а	f	medium
49548	53971	32	Магаданская область, Магадан, 13 км основной трассы	f	medium
49531	53954	15	Магаданская область, Магадан, Шандора Шимича, 6	f	large
49544	53967	28	Магаданская область, Магадан, Ш.Шимича, 18	f	large
49539	53962	23	Магаданская область, Магадан, Речная, 61/1	f	large
49517	53940	1	Магаданская область, Магадан, Пушкина, 8	f	large
49540	53963	24	Магаданская область, Магадан, Пролетарская, 75/2	f	large
49530	53953	14	Магаданская область, Магадан, Пролетарская, 33корп.2	f	large
49537	53960	21	Магаданская область, Магадан, Портовая, 36/10	f	large
49518	53941	2	Магаданская область, Магадан, Портовая, 13	f	large
49550	53973	34	Магаданская область, Магадан, Пионерская, 1	f	small
49542	53965	26	Магаданская область, Магадан, Первомайская, 46	f	medium
49521	53944	5	Магаданская область, Магадан, Парковая, 22	f	large
49536	53959	20	Магаданская область, Магадан, Октябрьская, 15	f	large
49520	53943	4	Магаданская область, Магадан, Новая, 29в	f	large
49527	53950	11	Магаданская область, Магадан, Наровчатова, 23	f	large
49535	53958	19	Магаданская область, Магадан, Набережная р. Магаданки, 59 коп.4	f	large
49534	53957	18	Магаданская область, Магадан, Набережная р. Магаданки, 59 корп.4	f	large
49523	53946	7	Магаданская область, Магадан, Марчеканская, 2/1	f	medium
49549	53972	33	Магаданская область, Магадан, Майская, 14	f	large
49526	53949	10	Магаданская область, Магадан, Лукса, 7	f	large
49525	53939	9	Магаданская область, Магадан, Лукса, 8-а	f	large
49551	53974	35	Магаданская область, Магадан, Красноярская, 10, пос. Уптар	f	large
49519	53942	3	Магаданская область, Магадан, Комсомольская площадь, 1	f	large
49533	53956	17	Магаданская область, Магадан, Комсомольская, 47а	f	large
49546	53969	30	Магаданская область, Магадан, Колымская, 8	f	large
49529	53952	13	Магаданская область, Магадан, Карла Маркса, 53	f	large
49528	53951	12	Магаданская область, Магадан, Карла Маркса, 62-в	f	large
49543	53966	27	Магаданская область, Магадан, Зайцева, 27	f	large
49545	53968	29	Магаданская область, Магадан, Берзина, 1	f	large
49554	53977	38	Магаданская область, Магадан, Арманская, 26	f	small
49522	53945	6	Магаданская область, Магадан, Марчеканское шоссе, 16-а	f	medium
49547	53970	31	Магаданская область, Магадан, Колымская, 9	f	medium
49538	53961	22	Магаданская область, Магадан, Карла Маркса, 1	f	medium
49532	53955	16	Магаданская область, Магадан, Карла Маркса, 67-в	f	large
49524	53947	8	Магаданская область, Магадан, Карла Маркса, 35	f	large
49604	54026	88	Магаданская область, Ягоднинский район, поселок Ягодное, Школьная, 9	f	\N
49605	54027	89	Магаданская область, Ягоднинский район, поселок Ягодное, Ленина, 42	f	\N
49608	54030	92	Магаданская область, Ягоднинский район, поселок Синегорье, Когодовского, 15	f	\N
49606	54028	90	Магаданская область, Ягоднинский район, поселок Сенокосный, Подгорная, 20	f	\N
49609	54031	93	Магаданская область, Ягоднинский район, поселок Оротукан, Спортивная, 8	f	\N
49607	54029	91	Магаданская область, Ягоднинский район, поселок Дебин, Мацкевича, 15	f	\N
49603	54025	87	Магаданская область, Ягоднинский район, поселок Бурхала, Нагорная, 20	f	\N
49602	54024	86	Магаданская область, Хасынский район, поселок Талая, Зеленая, 4	f	small
49596	54018	80	Магаданская область, Хасынский район, поселок Стекольный, Советская, 7	f	large
49600	54022	84	Магаданская область, Хасынский район, поселок Палатка	f	large
49599	54021	83	Магаданская область, Хасынский район, поселок Палатка, Юбилейная, 10	f	large
49597	54019	81	Магаданская область, Хасынский район, поселок Палатка, Цареградского, 16	f	small
49598	54020	82	Магаданская область, Хасынский район, поселок Палатка, Ленина, 44	f	large
49601	54023	85	Магаданская область, Хасынский район, поселок Атка, Санаторная, 1	f	small
49593	54015	77	Магаданская область, Тенькинский район, поселок им.Гастелло, Гагарина, 27	f	small
49591	54013	75	Магаданская область, Тенькинский район, поселок Усть-Омчуг, Победы, 21	f	large
49590	54012	74	Магаданская область, Тенькинский район, поселок Усть-Омчуг, Горняцкая, 41	f	large
49592	54014	76	Магаданская область, Тенькинский район, поселок Транспортный, Шоссейная, 21	f	small
49595	54017	79	Магаданская область, Тенькинский район, поселок Омчак, Новая, 13	f	small
49594	54016	78	Магаданская область, Тенькинский район, поселок Омчак, Клубная, 26	f	small
49589	54011	73	Магаданская область, Тенькинский район, поселок Мадаун, 18	f	small
49583	54006	67	Магаданская область, Сусуманский район, поселок Широкий, Октябрьская, 7а	f	small
49585	54007	69	Магаданская область, Сусуманский район, поселок Холодный, Халезина, 1	f	medium
28451	17900	763	Амурская область, Шимановск, Некрасова, 58	f	large
49579	54002	63	Магаданская область, Сусуманский район, Сусуман, Советская, 7	f	large
49581	54004	65	Магаданская область, Сусуманский район, Сусуман, Светлая, 6	f	small
49582	54005	66	Магаданская область, Сусуманский район, Сусуман, Пионерская, 31	f	medium
49588	54010	72	Магаданская область, Сусуманский район, поселок Мяунджа, Октябрьская, 18	f	large
49587	54009	71	Магаданская область, Сусуманский район, поселок Кедровый, Клубная, 1	f	small
49586	54008	70	Магаданская область, Сусуманский район, поселок Большевик, Трассовская, 1	f	small
49577	54000	61	Магаданская область, Среднеканский район, поселок Сеймчан, Промышленная, 12	f	large
49576	53999	60	Магаданская область, Среднеканский район, поселок Сеймчан, Дзержинского, 25	f	large
49578	54001	62	Магаданская область, Среднеканский район, поселок Верх. Сеймчан, Холодченко, 16-а	f	small
49572	53995	56	Магаданская область, Северо-Эвенский район, поселок Эвенск, Победы, 35	f	large
49575	53998	59	Магаданская область, Северо-Эвенский район, село Чайбуха	f	small
49574	53997	58	Магаданская область, Северо-Эвенский район, село Гижига	f	small
49573	53996	57	Магаданская область, Северо-Эвенский район, село Гарманда	f	small
49570	53993	54	Магаданская область, Омсукчанский район, поселок Омсукчан, Ленина, 14	f	large
49569	53992	53	Магаданская область, Омсукчанский район, поселок Омсукчан, Ленина, 29	f	large
49571	53994	55	Магаданская область, Омсукчанский район, поселок Дукат, проспект Победы, 4	f	medium
49565	53988	49	Магаданская область, Ольский район, поселок Яна, Годяева, 1А	f	small
49557	53980	41	Магаданская область, Ольский район, село Ямск, Набережная, 8	f	small
49556	53979	40	Магаданская область, Ольский район, село Тахтоямск, Советская, 23	f	small
49566	53989	50	Магаданская область, Ольский район, село Тауйск, 50 лет Октября, 22	f	small
49568	53991	52	Магаданская область, Ольский район, село Талон, Молодежная, 1А	f	small
49562	53985	46	Магаданская область, Ольский район, поселок Ола, площадь Ленина, 5	f	large
49561	53984	45	Магаданская область, Ольский район, поселок Ола, Советская, 31	f	large
49563	53986	47	Магаданская область, Ольский район, поселок Ола, Ленина, 54	f	large
49560	53983	44	Магаданская область, Ольский район, поселок Ола, Кирова, 1	f	large
49558	53981	42	Магаданская область, Ольский район, поселок Клепка, Школьная, 1	f	small
49559	53982	43	Магаданская область, Ольский район, село Гадля, Центральная, 7	f	small
49567	53990	51	Магаданская область, Ольский район, село Балаганное, Советская, 13	f	small
49564	53987	48	Магаданская область, Ольский район, поселок Армань, Пушкина, 17	f	large
41595	38727	52	Камчатский край, Петропавловск-Камчатский, проспект Рыбаков, 7, Камчатское музыкальное училище	f	large
41611	38742	68	Камчатский край, Петропавловск-Камчатский, проспект Победы, 41, Гор. объед. управляющая компания	f	large
41606	38737	63	Камчатский край, Петропавловск-Камчатский, проспект Победы, 6 а, Средняя школа №, 36	f	large
41604	38735	61	Камчатский край, Петропавловск-Камчатский, проспект Карла Маркса, 33/1, Камчатская краевая библиотека	f	large
41603	38734	60	Камчатский край, Петропавловск-Камчатский, проспект Карла Маркса, 15/1, Средняя школа №, 11	f	large
41596	38728	53	Камчатский край, Петропавловск-Камчатский, проспект 50 лет Октября, 25-а, Расчетно-кассовый центр по ЖКХ	f	large
41593	38725	50	Камчатский край, Петропавловск-Камчатский, проспект 50 лет Октября, 1/1, КГТУ	f	large
41592	38725	49	Камчатский край, Петропавловск-Камчатский, проспект 50 лет Октября, 1/1, КГТУ	f	large
41559	38693	16	Камчатский край, Петропавловск-Камчатский, площадь Щедрина, 3, Дом офицеров флота	f	large
134421	38726	51	Камчатский край, Петропавловск-Камчатский, бульвар рыбацкой славы, 21, Средняя школа № 33	f	\N
41610	38741	67	Камчатский край, Петропавловск-Камчатский, Якорная, 11, Средняя школа № 45	f	large
41570	38704	27	Камчатский край, Петропавловск-Камчатский, Щорса, Клуб в/ч 41097	f	small
41605	38736	62	Камчатский край, Петропавловск-Камчатский, Чубарова, 1, Профессиональное училище №, 2	f	large
41627	38757	84	Камчатский край, Петропавловск-Камчатский, Спортивная, 9, Домоуправление № 1	f	medium
41614	38744	71	Камчатский край, Петропавловск-Камчатский, Светлая, 1, Общеобразовательная школа №, 37	f	large
28455	17905	767	Амурская область, Шимановск, Ленина, 33	f	large
41547	38681	4	Камчатский край, Петропавловск-Камчатский, Сахалинская, 1, Гор. дом культуры СРВ	f	large
41552	38686	9	Камчатский край, Петропавловск-Камчатский, Садовая, 6 а, Средняя школа № 10	f	large
41586	38719	43	Камчатский край, Петропавловск-Камчатский, Савченко, 12, Средняя школа № 42	f	large
41557	38691	14	Камчатский край, Петропавловск-Камчатский, Рябиковская, 83/1, Средняя школа №6	f	large
41553	38687	10	Камчатский край, Петропавловск-Камчатский, Пономарева, 13, Средняя школа №, 24	f	large
41568	38702	25	Камчатский край, Петропавловск-Камчатский, Пограничная, 103, Средняя школа №, 9	f	large
41567	38701	24	Камчатский край, Петропавловск-Камчатский, Пограничная, 31а, Камчатский дворец детск. творчества	f	medium
41565	38699	22	Камчатский край, Петропавловск-Камчатский, Пограничная, 4, КамГУ им. В. Беринга	f	large
41545	38679	2	Камчатский край, Петропавловск-Камчатский, Петра Ильичева, 80, Средняя школа, 17	f	large
41544	38678	1	Камчатский край, Петропавловск-Камчатский, Петра Ильичева, 63, Библиотека Матросского клуба	f	large
41571	38705	28	Камчатский край, Петропавловск-Камчатский, Первомайская, 15а, Средняя школа № 41	f	medium
41554	38688	11	Камчатский край, Петропавловск-Камчатский, Океанская, 69, Гор. объед. управляющая компания	f	large
41551	38685	8	Камчатский край, Петропавловск-Камчатский, Океанская, 125, Дом дет. творчества Юность	f	large
41572	38706	29	Камчатский край, Петропавловск-Камчатский, Новая, 6, Средняя школа № 41	f	medium
41609	38740	66	Камчатский край, Петропавловск-Камчатский, Молчанова, 16/1, Средняя школа № 26	f	large
41608	38739	65	Камчатский край, Петропавловск-Камчатский, Молчанова, 12, Камч. управ. по гидрометеорологии	f	large
41560	38694	17	Камчатский край, Петропавловск-Камчатский, Ленинская, 69, КамГУ, корп. соц.эконом. факультета	f	large
41588	38721	45	Камчатский край, Петропавловск-Камчатский, Ленинградская , 120 а, КГТУ	f	large
41558	38692	15	Камчатский край, Петропавловск-Камчатский, Курильская, 1, Детско-юношеская спорт. школа №5	f	large
41589	38722	46	Камчатский край, Петропавловск-Камчатский, Кроноцкая, 6/1, Средняя школа № 30	f	large
41561	38695	18	Камчатский край, Петропавловск-Камчатский, Космонавтов, 43, Центр культуры и досуга Сероглазка	f	large
41582	38715	39	Камчатский край, Петропавловск-Камчатский, Космический проезд, 14, Средняя школа №, 39	f	large
41581	38715	38	Камчатский край, Петропавловск-Камчатский, Космический проезд, 14, Средняя школа №, 39	f	large
41548	38682	5	Камчатский край, Петропавловск-Камчатский, Комсомольская, 2 А, Камчатский политехнический техникум	f	large
41564	38698	21	Камчатский край, Петропавловск-Камчатский, Ключевская, 35, КГТУ	f	large
41563	38697	20	Камчатский край, Петропавловск-Камчатский, Ключевская, 11, Камчатский кооперативный техникум	f	large
41550	38684	7	Камчатский край, Петропавловск-Камчатский, Кирова, 4, Средняя школа № 5	f	large
41556	38690	13	Камчатский край, Петропавловск-Камчатский, Капитана Драбкина, 18, Детский дом-школа №2	f	large
41555	38689	12	Камчатский край, Петропавловск-Камчатский, Капитана Драбкина, 16, Средняя школа №12	f	large
41549	38683	6	Камчатский край, Петропавловск-Камчатский, Зеленая Роща, 24, Средняя школа №3	f	large
41578	38712	35	Камчатский край, Петропавловск-Камчатский, Звездная, 34, Средняя школа №, 31	f	large
41577	38710	34	Камчатский край, Петропавловск-Камчатский, Звездная, 26, Центр культуры и досуга Апрель	f	large
41576	38709	33	Камчатский край, Петропавловск-Камчатский, Звездная, 11/1, Средняя школа №27	f	large
41546	38680	3	Камчатский край, Петропавловск-Камчатский, Заводская, 20	f	large
41591	38724	48	Камчатский край, Петропавловск-Камчатский, Дзержинского, 24, Средняя школа № 30	f	large
41573	38707	30	Камчатский край, Петропавловск-Камчатский, Дальняя, 42, Средняя школа № 32	f	large
41600	38731	57	Камчатский край, Петропавловск-Камчатский, Давыдова, 15, Средняя школа № 8	f	large
41599	38731	56	Камчатский край, Петропавловск-Камчатский, Давыдова, 15, Средняя школа № 8	f	large
41569	38703	26	Камчатский край, Петропавловск-Камчатский, Гастелло, 7, Средняя школа № 9	f	large
41575	38708	32	Камчатский край, Петропавловск-Камчатский, Г.Ф. Кирдищева, 8, Средняя школа №, 28	f	large
41574	38708	31	Камчатский край, Петропавловск-Камчатский, Г.Ф. Кирдищева, 8, Средняя школа №, 28	f	large
41587	38720	44	Камчатский край, Петропавловск-Камчатский, Вольского, 32, ООО Восток-Сервис	f	large
41585	38718	42	Камчатский край, Петропавловск-Камчатский, Вольского, 4/2, Средняя школа №, 40	f	large
41584	38717	41	Камчатский край, Петропавловск-Камчатский, Вольского, 4/2, Средняя школа №40	f	large
41598	38730	55	Камчатский край, Петропавловск-Камчатский, Ватутина, 1, Средняя школа № 43	f	large
41597	38729	54	Камчатский край, Петропавловск-Камчатский, Ватутина, 1 а, Средняя школа №, 7	f	large
41602	38733	59	Камчатский край, Петропавловск-Камчатский, Бохняка, 18, Гор. объед. управляющая компания	f	large
41601	38732	58	Камчатский край, Петропавловск-Камчатский, Бохняка, 13, Камчатский педагогический колледж	f	large
41613	38743	70	Камчатский край, Петропавловск-Камчатский, Бийская, 2, Средняя школа №, 20	f	large
41612	38743	69	Камчатский край, Петропавловск-Камчатский, Бийская, 2, Средняя школа №, 20	f	large
41562	38696	19	Камчатский край, Петропавловск-Камчатский, Беринга, 104 А, Управление по недропользованию	f	large
41566	38700	23	Камчатский край, Петропавловск-Камчатский, Атласова, 24, П.-Камчатский офицерский клуб	f	large
41625	38755	82	Камчатский край, Петропавловск-Камчатский, Аммональная падь, 1, Клуб военного госпиталя	f	small
68151	38716	40	Камчатский край, Петропавловск-Камчатский, Академика Королева, 23, Средняя школа №, 34	f	large
41579	38713	36	Камчатский край, Петропавловск-Камчатский, Академика Королева, 23, Средняя школа №34	f	large
41626	38756	83	Камчатский край, Петропавловск-Камчатский, 2-я Шевченко, 5, Нежилое помещение	f	small
41607	38738	64	Камчатский край, Петропавловск-Камчатский, проспект Победы, 6, Бассейн	f	large
41624	38754	81	Камчатский край, Петропавловск-Камчатский, Фурманова, 12, Средняя школа №, 9	f	small
41590	38723	47	Камчатский край, Петропавловск-Камчатский, Зеркальная, 48, Профессиональное училище № 4	f	large
41662	38791	119	Камчатский край, Елизово, Санаторная, 6	f	medium
41661	38790	118	Камчатский край, Елизово, Рабочей смены, 1	f	large
41652	38781	109	Камчатский край, Елизово, Мурманская, 4	f	medium
41638	38767	95	Камчатский край, Вилючинск, Победы, 9	f	large
41637	38767	94	Камчатский край, Вилючинск, Победы, 9	f	large
41636	38766	93	Камчатский край, Вилючинск, Победы, 5	f	large
41643	38772	100	Камчатский край, Вилючинск, Мира, 8а	f	large
41629	38759	86	Камчатский край, Вилючинск, Владивостокская, 4а	f	small
41635	38765	92	Камчатский край, Вилючинск, 50 лет ВЛКСМ, 6	f	large
41707	38837	165	Камчатский край, Усть-Камчатский район, поселок Усть-Камчатск, Советская, 1	f	large
41705	38835	163	Камчатский край, Усть-Камчатский район, Усть-Камчатск, Кирова, 60	f	medium
41708	38838	166	Камчатский край, Усть-Камчатский район, поселок Усть-Камчатск, Горького, 53	f	large
41703	38833	161	Камчатский край, Усть-Камчатский район, село Майское, Комсомольская, 9	f	small
41709	38839	167	Камчатский край, Усть-Камчатский район, село Крутоберегово, Новая, 4-А	f	small
41702	38832	160	Камчатский край, Усть-Камчатский район, поселок Козыревск, Ленинская, 54	f	large
41706	38836	164	Камчатский край, Усть-Камчатский район, Ключи-1, войсковая часть	f	large
41704	38834	162	Камчатский край, Усть-Камчатский район, поселок Ключи, Красноармейская, 3	f	large
110355	38824	152	Камчатский край, Усть-Большерецкий район, с. Кавалерское, улица Блюхера, 27	f	medium
68153	38823	151	Камчатский край, Усть-Большерецкий район, село Усть-Большерецк, Ленинская, 9	f	large
41689	38819	147	Камчатский край, Усть-Большерецкий район, поселок Паужетка, Энергетиков, 9	t	small
41692	38822	150	Камчатский край, Усть-Большерецкий район, поселок Октябрьский, Комсомольская, 3	f	large
41691	38821	149	Камчатский край, Усть-Большерецкий район, поселок Озерновский, Октябрьская, 20	f	large
41690	38820	148	Камчатский край, Усть-Большерецкий район, село Запорожье, Центральная, 39а	f	medium
110356	38825	153	Камчатский край, Усть-Большерецкий район, село Апача, Юбилейная, 16	f	medium
41711	38841	169	Камчатский край, Тигильский район, село Хайрюзово, Набережная, 40	t	small
41712	38842	170	Камчатский край, Тигильский район, село Усть-Хайрюзово, Школьная, 6а	f	medium
41715	38845	173	Камчатский край, Тигильский район, село Тигиль, Партизанская, 21	f	large
41714	38844	172	Камчатский край, Тигильский район, село Седанка, Советская, 16	t	small
68155	38848	176	Камчатский край, Тигильский район, поселок Палана, Поротова, 31	f	large
41717	38847	175	Камчатский край, Тигильский район, село Лесная, Депутатская, 7	t	small
41713	38843	171	Камчатский край, Тигильский район, село Ковран, 50 лет Октября, 20	t	small
41716	38846	174	Камчатский край, Тигильский район, село Воямполка, Гагарина, 13	t	small
68154	38829	157	Камчатский край, Соболевский район, село Соболево, Советская, 26	f	large
41698	38828	156	Камчатский край, Соболевский район, село Соболево, Речная, 5	f	small
41700	38830	158	Камчатский край, Соболевский район, Соболево, Заводская, 19	t	small
41701	38831	159	Камчатский край, Соболевский район, поселок Ичинский, Геологическая, 25А	t	small
41735	38851	193	Камчатский край, Пенжинский район, село Таловка, Центральная, 11	t	small
41738	38867	196	Камчатский край, Пенжинский район, село Слаутное, Давыдова, 13	t	small
41733	38864	191	Камчатский край, Пенжинский район, село Парень, Администрация села	t	small
41737	38866	195	Камчатский край, Пенжинский район, село Оклан, Мира, 12	t	small
41734	38807	192	Камчатский край, Пенжинский район, село Манилы, Ленинская, 3	t	medium
86427	38865	194	Камчатский край, Пенжинский район, село Каменское, Ленина, 3	f	small
41739	38868	197	Камчатский край, Пенжинский район, село Аянка, 60 Лет Октября, 1	t	small
41728	38859	186	Камчатский край, Олюторский район, село Хаилино, Центральная, 10-А	t	medium
41727	38858	185	Камчатский край, Олюторский район, село Тиличики, Молодежная, 10-А	f	large
41730	38861	188	Камчатский край, Олюторский район, село Средние Пахачи, Центральная, 49	t	small
41729	38860	187	Камчатский край, Олюторский район, село Пахачи, Центральная, 33	t	small
41726	38857	184	Камчатский край, Олюторский район, село Корф, Советская, 37	f	small
41725	38856	183	Камчатский край, Олюторский район, село Вывенка, Центральная, 17	t	small
41732	38863	190	Камчатский край, Олюторский район, село Ачайваям, Каюю, 11-А	t	small
41731	38862	189	Камчатский край, Олюторский район, село Апука, Морская, 11	t	small
41680	38810	138	Камчатский край, Мильковский район, село Шаромы, Советская, 13	f	small
86425	38816	144	Камчатский край, Мильковский район, поселок Таежный, Крупская, 10	f	small
41679	38809	137	Камчатский край, Мильковский район, село Пущино, Центральная, 15	f	small
41682	38812	140	Камчатский край, Мильковский район, село Мильково, Строительная, 9	f	large
41683	38813	141	Камчатский край, Мильковский район, село Мильково, Победы, 8	f	large
41684	38814	142	Камчатский край, Мильковский район, село Мильково, Партизанская, 21	f	large
41681	38811	139	Камчатский край, Мильковский район, село Мильково, Томская, 20	f	large
41688	38818	146	Камчатский край, Мильковский район, село Лазо, Омская, 17	f	small
86424	38815	143	Камчатский край, Мильковский район, село Долиновка, Елисеевская, 14	f	small
110354	38817	145	Камчатский край, Мильковский район, поселок Атласово, Ленинградская, 2	f	medium
41723	38854	181	Камчатский край, Карагинский район, село Тымлат, Комарова, 15	t	small
41722	38853	180	Камчатский край, Карагинский район, поселок Оссора, Советская, 64	f	large
41720	38850	178	Камчатский край, Карагинский район, село Кострома, Центральная, 14	t	small
86426	38852	179	Камчатский край, Карагинский район, село Карага, Обухова, 31	f	small
41724	38855	182	Камчатский край, Карагинский район, село Ильпырское, Калининская, 9	t	small
110357	38849	177	Камчатский край, Карагинский район, село Ивашка, Левченко, 18	f	medium
41645	38774	102	Камчатский край, Елизовский район, п.Новый, Молодежная, 5	f	medium
41664	38793	121	Камчатский край, Елизовский район, п.Вулканный, Центральная, 35	f	large
110353	38798	126	Камчатский край, Елизовский район, поселок Термальный, Ленина, 1	f	medium
41670	38799	127	Камчатский край, Елизовский район, поселок Термальный, Крашенинникова, 2	f	medium
41666	38795	123	Камчатский край, Елизовский район, поселок Сосновка, Центральная, 5	f	medium
41678	38808	136	Камчатский край, Елизовский район, поселок Сокоч, Юбилейная, 11	f	large
41674	38803	131	Камчатский край, Елизовский район, Северные Коряки, Дачная, 9	f	small
41671	38800	128	Камчатский край, Елизовский район, поселок Раздольный, Ролдугина, 17	f	large
41644	38773	101	Камчатский край, Елизовский район, поселок Пионерский, Бонивура, 2/1	f	large
41667	38796	124	Камчатский край, Елизовский район, поселок Паратунка, Нагорная, 30	f	medium
41668	38797	125	Камчатский край, Елизовский район, поселок Паратунка, Мирная, 7	f	medium
41665	38794	122	Камчатский край, Елизовский район, поселок Николаевка, Елизовская, 12	f	large
41646	38776	103	Камчатский край, Елизовский район, поселок Нагорный, Первомайская, 7а	f	large
41677	38806	135	Камчатский край, Елизовский район, поселок Лесной, Школьная, 11а	f	medium
41672	38801	129	Камчатский край, Елизовский район, поселок Коряки, Геологов, 13	f	medium
41673	38802	130	Камчатский край, Елизовский район, поселок Коряки, Вилкова, 1/1	f	large
41675	38804	132	Камчатский край, Елизовский район, поселок Зеленый, Атласова, 12/2	f	medium
41651	38780	108	Камчатский край, Елизовский район, Елизово	f	medium
41655	38784	112	Камчатский край, Елизовский район, Елизово, Тимирязевский переулок, 9	f	large
41653	38782	110	Камчатский край, Елизовский район, Елизово, Рябикова, 27	f	large
41660	38789	117	Камчатский край, Елизовский район, Елизово, Пограничная, 27	f	large
41654	38783	111	Камчатский край, Елизовский район, Елизово, Ленина, 22	f	large
41649	38778	106	Камчатский край, Елизовский район, Елизово, Котельная, 2	f	large
41648	38778	105	Камчатский край, Елизовский район, Елизово, Котельная, 2	f	large
41659	38788	116	Камчатский край, Елизовский район, Елизово, Зеленая, 5	f	large
41650	38779	107	Камчатский край, Елизовский район, Елизово, Звездная, Клуб аэропорта	f	large
41663	38792	120	Камчатский край, Елизовский район, Елизово, Завойко, 123 А	f	large
41657	38786	114	Камчатский край, Елизовский район, Елизово, Виталия Кручины, 30	f	large
68152	38787	115	Камчатский край, Елизовский район, Елизово, Беринга, 16	f	large
41656	38785	113	Камчатский край, Елизовский район, Елизово, 40 лет Октября, 9	f	large
41647	38777	104	Камчатский край, Елизовский район, поселок Двуречье, Центральная, 27	f	small
41633	38764	90	Камчатский край, Елизовский район, Вилючинский городской округ, Вилкова, 35	f	large
41640	38769	97	Камчатский край, Елизовский район, Вилючинск, Центральный, 1	f	large
41639	38768	96	Камчатский край, Елизовский район, Вилючинск, Центральный, 6	f	large
41642	38771	99	Камчатский край, Елизовский район, Вилючинск, Спортивная, 8	f	large
41630	38761	87	Камчатский край, Елизовский район, Вилючинск, Приморская, 6	f	large
41641	38770	98	Камчатский край, Елизовский район, Вилючинск, Мира, 20	f	large
41628	38758	85	Камчатский край, Елизовский район, Вилючинск, Кронштадтская, 10	f	large
41631	38762	88	Камчатский край, Елизовский район, Вилючинск, Крашенинникова, 30а	f	large
41634	38763	91	Камчатский край, Елизовский район, Вилючинск, Гусарова, 49	f	large
41632	38763	89	Камчатский край, Елизовский район, Вилючинск, Гусарова, 49	f	large
41676	38805	134	Камчатский край, Елизовский район, поселок Березняки, Строительная, 2	f	medium
41696	38826	154	Камчатский край, Быстринский район, село Эссо, Южная, 3	f	large
41697	38827	155	Камчатский край, Быстринский район, село Анавгай, Советская, 4	f	small
41710	38840	168	Камчатский край, Алеутский район, село Никольское, 50 лет Октября, 13	f	medium
85566	33320	50	Еврейская автономная область, Хинганск, Ленина, 9	f	large
85565	33319	49	Еврейская автономная область, Облучье, Тварковского, 8А	f	large
109514	33318	48	Еврейская автономная область, Облучье, Районная, 69А	f	medium
109530	33345	75	Еврейская автономная область, Волочаевка-2, Школьная, 2	f	medium
109506	33300	27	Еврейская автономная область, Биробиджан, проспект 60-летия СССР, 12	f	medium
109510	33413	41	Еврейская автономная область, Биробиджан, Шолом-Алейхема, 117	f	\N
85545	33287	12	Еврейская автономная область, Биробиджан, Шолом-Алейхема, 57	f	large
85551	33296	22	Еврейская автономная область, Биробиджан, Комсомольская, 1	f	large
85562	33311	39	Еврейская автономная область, Биробиджан, Карла Маркса, 25	f	large
85560	33309	37	Еврейская автономная область, Биробиджан, Юбилейная, 9	f	large
85550	33293	18	Еврейская автономная область, Биробиджан, Шолом-Алейхема, 11	f	large
85542	33284	9	Еврейская автономная область, город Биробиджан, Шолом-Алейхема, 81	f	large
85537	33280	4	Еврейская автономная область, город Биробиджан, Шолом-Алейхема, 92	f	large
85534	33277	1	Еврейская автономная область, Биробиджан, Шолом-Алейхема, 115	f	large
85558	33307	34	Еврейская автономная область, Биробиджан, Школьная, 23	f	large
85556	33304	31	Еврейская автономная область, Биробиджан, Широкая, 70 А	f	large
85546	33288	13	Еврейская автономная область, Биробиджан, Швейный, 6 Б	f	large
109502	33289	14	Еврейская автономная область, Биробиджан, Черноморская, 6	f	small
85552	33297	23	Еврейская автономная область, Биробиджан, Чапаева, 2	f	large
109503	33294	20	Еврейская автономная область, Биробиджан, Транспортная, 25	f	medium
85547	33290	15	Еврейская автономная область, Биробиджан, Строительная, 19	f	large
85557	33305	32	Еврейская автономная область, Биробиджан, Советская, 74	f	large
85555	33303	30	Еврейская автономная область, Биробиджан, Советская, 66 Б	f	large
109507	33302	29	Еврейская автономная область, Биробиджан, Советская, 72 А	f	medium
85554	33301	28	Еврейская автономная область, Биробиджан, Советская, 49	f	large
109509	33312	40	Еврейская автономная область, город Биробиджан, Пригородная, 6 б	f	small
85549	33292	17	Еврейская автономная область, Биробиджан, Пионерская, 21	f	large
85544	33286	11	Еврейская автономная область, Биробиджан, Пионерская, 34	f	large
85543	33285	10	Еврейская автономная область, Биробиджан, Пионерская, 60	f	large
85538	33281	5	Еврейская автономная область, Биробиджан, Пионерская, 80	f	large
85536	33279	3	Еврейская автономная область, Биробиджан, Осенняя, 23 А	f	large
85535	33278	2	Еврейская автономная область, Биробиджан, Осенняя, 13	f	large
85548	33291	16	Еврейская автономная область, Биробиджан, Ленина, 40	f	large
85559	33308	36	Еврейская автономная область, Биробиджан, Космонавтов, 13	f	large
85561	33310	38	Еврейская автономная область, Биробиджан, Карла Маркса, 10	f	large
109504	33295	21	Еврейская автономная область, Биробиджан, Гоголя, 26	f	medium
85553	33299	26	Еврейская автономная область, Биробиджан, Волочаевская, 5	f	large
109505	33298	25	Еврейская автономная область, Биробиджан, Волочаевская, 41	f	medium
85541	33283	8	Еврейская автономная область, город Биробиджан, Бумагина, 5 А	f	large
109508	33306	33	Еврейская автономная область, город Биробиджан, Биршоссе 2-ой км, 17	f	medium
85540	33282	7	Еврейская автономная область, Биробиджан, 40 лет Победы, 25 Б	f	large
85539	33282	6	Еврейская автономная область, Биробиджан, 40 лет Победы, 25 Б	f	large
109535	33356	85	Еврейская автономная область, Смидовичский район, село им. Тельмана, Школьная, 9	f	medium
85576	33340	70	Еврейская автономная область, Смидовичский район, поселок Смидович, Советская, 64	f	large
85574	33338	68	Еврейская автономная область, Смидовичский район, поселок Смидович, Лермонтова, 2	f	large
85575	33339	69	Еврейская автономная область, Смидовичский район, поселок городского типа Смидович, Кирова, 14	f	large
85581	33353	83	Еврейская автономная область, Смидовичский район, поселок Приамурский, Дзержинского, 4	f	large
85582	33355	84	Еврейская автономная область, Смидовичский район, поселок Приамурский, Вокзальная, 25	f	large
109525	33341	71	Еврейская автономная область, Смидовичский район, село Песчаное, 40 лет Победы, 2	f	medium
109526	33342	72	Еврейская автономная область, Смидовичский район, село Партизанское, Партизанская, 2б	f	\N
85577	33349	79	Еврейская автономная область, Смидовичский район, поселок Николаевка, Строительная, 10	f	large
85578	33350	80	Еврейская автономная область, Смидовичский район, поселок Николаевка, Лазо, 40а	f	large
85579	33351	81	Еврейская автономная область, Смидовичский район, поселок Николаевка, Кубанская, 2	f	large
85580	33352	82	Еврейская автономная область, Смидовичский район, поселок городского типа Николаевка, Комсомольская, 54	f	large
109534	33348	78	Еврейская автономная область, Смидовичский район, село Ключевое, Советская, 11	f	medium
109533	33347	77	Волгоградская область, Палласовский район, село Камышовка	f	medium
109532	33415	76	Еврейская автономная область, Смидовичский район, село Даниловка, Садовая, 18	f	\N
109529	33344	74	Еврейская автономная область, Смидовичский район, поселок городского типа Волочаевка-2, Советская, 54	f	medium
109528	33343	73	Еврейская автономная область, Смидовичский район, село Волочаевка-1, Вокзальная, 1а	f	medium
109524	33337	67	Еврейская автономная область, Смидовичский район, село Белгородское, Шоссейная, 26	f	small
109523	33336	66	Еврейская автономная область, Смидовичский район, село Аур	f	medium
109539	33363	92	Еврейская автономная область, Октябрьский район, село Столбовое, Верхняя, 7а	f	small
109538	33362	91	Еврейская автономная область, Октябрьский район, село Самара, Почтовая, 1	f	small
109543	33367	96	Еврейская автономная область, Октябрьский район, село Садовое, Школьная, 18	f	small
109546	33370	99	Еврейская автономная область, Октябрьский район, село Ручейки, Ленина, 1	f	small
109537	33361	90	Еврейская автономная область, Октябрьский район, село Пузино, пер.Клубный, 1а	f	medium
109540	33364	93	Еврейская автономная область, Октябрьский район, село Полевое, Советская, 10	t	small
109536	33360	89	Еврейская автономная область, Октябрьский район, село Озерное, Амурская, 17	f	small
109544	33368	97	Еврейская автономная область, Октябрьский район, село Нагибово, Центральная, 13в	t	small
109541	33365	94	Еврейская автономная область, Октябрьский район, село Луговое, Магистральная, 5	f	small
85585	33359	88	Еврейская автономная область, Октябрьский район, село Екатерино-Никольское, Пограничная, 64	f	large
109545	33369	98	Еврейская автономная область, Октябрьский район, село Доброе, Советская, 18	f	small
109542	33366	95	Еврейская автономная область, Октябрьский район, село Благославенное, улица Советская, 37	f	medium
85583	33357	86	Еврейская автономная область, Октябрьский район, село Амурзет, Крупской, 18	f	large
85584	33358	87	Еврейская автономная область, Октябрьский район, село Амурзет, Калинина, 27	f	large
85569	33328	58	Еврейская автономная область, Облученский район, поселок Теплоозерск, Лазо, 11А	f	large
85570	33329	59	Еврейская автономная область, Облученский район, поселок Теплоозерск, Бонивура, 11	f	large
109522	33335	65	Еврейская автономная область, Облученский район, село Семисточный	t	small
109517	33323	53	Еврейская автономная область, Облученский район, село Радде, Центральная, 5	t	small
109515	33321	51	Еврейская автономная область, Облученский район, село Пашково, Набережная, 24	f	medium
109512	33314	44	Еврейская автономная область, Облученский район, Облучье, Ключевая, 50	f	medium
85564	33316	46	Еврейская автономная область, Облученский район, Облучье, Интернациональная, 26	f	large
85563	33315	45	Еврейская автономная область, Облученский район, Облучье, Пролетарская, 3	f	large
109513	33317	47	Еврейская автономная область, Облученский район, Облучье, Денисова, 34	f	medium
109511	33313	43	Еврейская автономная область, Облученский район, город Облучье, Горького, 118	f	medium
85571	33330	60	Еврейская автономная область, Облученский район, поселок Лондоко, Комсомольская, 1А, завод	f	large
85572	33331	61	Еврейская автономная область, Облученский район, поселок городского типа Кульдур, Раскопенского, 18А	f	large
85567	33325	55	Еврейская автономная область, Облученский район, поселок Известковый, Ведина, 1	f	large
109519	33326	56	Еврейская автономная область, Облученский район, село Двуречье	f	medium
109521	33334	64	Еврейская автономная область, Облученский район, село Будукан, Школьная, 10А	t	small
85568	33327	57	Еврейская автономная область, Облученский район, поселок городского типа Биракан, Октябрьская, 34А	f	large
85573	33332	62	Еврейская автономная область, Облученский район, поселок городского типа Бира, Победы, 18	f	large
109520	33333	63	Еврейская автономная область, Облученский район, поселок Бира, Онищенко, 48	f	medium
109518	33324	54	Еврейская автономная область, Облученский район, село Башурово, переулок Амурский, 2	f	small
109572	33396	126	Еврейская автономная область, Ленинский район, село Чурки, им. 27 съезда КПСС, 6	t	small
109577	33401	132	Еврейская автономная область, Ленинский район, село Унгун, Центральная, 7	f	small
109581	33405	137	Еврейская автономная область, Ленинский район, село Степное, Школьная, 1	t	small
109580	33417	135	Еврейская автономная область, Ленинский район, село Преображеновка, пер. Школьный, 1	t	\N
109574	33398	128	Еврейская автономная область, Ленинский район, село Октябрьское, Юбилейная, 6	f	small
109579	33403	134	Еврейская автономная область, Ленинский район, село Новотроицкое, Центральная, 24	t	small
109589	33410	143	Еврейская автономная область, Ленинский район, село Новое, Шоссейная, 48	f	medium
109569	33393	123	Еврейская автономная область, Ленинский район, село Нижнеленинское, переулок Вилкова, 1	f	small
109568	33412	122	Еврейская автономная область, Ленинский район, село Ленинское, ПУ-2	f	medium
85588	33392	121	Еврейская автономная область, Ленинский район, село Ленинское, Школьная, 10	f	large
85587	33390	119	Еврейская автономная область, Ленинский район, село Ленинское, Октябрьская, 6	f	large
109567	33391	120	Еврейская автономная область, Ленинский район, село Ленинское, Ленина, 11	f	medium
109570	33394	124	Еврейская автономная область, Ленинский район, село Ленинск, Школьная, 1	f	small
109578	33402	133	Еврейская автономная область, Ленинский район, село Лазарево, Ушакова, 2а	f	medium
109590	33411	144	Еврейская автономная область, Ленинский район, село Кукелево, Комсомольская, 1-а	f	medium
109585	33407	140	Еврейская автономная область, Ленинский район, село Кирово, Кооперативная, 1	t	small
109586	33408	141	Еврейская автономная область, Ленинский район, село Квашнино, Центральная, 3	t	small
109571	33395	125	Еврейская автономная область, Ленинский район, село Калинино, Школьная, 5	f	small
109587	33409	142	Еврейская автономная область, Ленинский район, село Дежнево, Пограничная, 20	f	medium
109576	33400	131	Еврейская автономная область, Ленинский район, село Горное, Центральная, 8	f	small
109573	33397	127	Еврейская автономная область, Ленинский район, село Воскресеновка, Советская, 11-а	t	small
109583	33406	138	Еврейская автономная область, Ленинский район, село Венцелево, Центральная, 9	t	small
85590	33404	136	Еврейская автономная область, Ленинский район, село Биджан, Пионерская, 32	f	large
109584	33418	139	Еврейская автономная область, Ленинский район, село Башмак, Новая, 20	f	\N
109575	33416	129	Еврейская автономная область, Ленинский район, село Бабстово, ФГОУ СПО БХСТ	f	\N
85589	33399	130	Еврейская автономная область, Ленинский район, село Бабстово, Ленина, 14	f	large
109554	33379	108	Еврейская автономная область, Биробиджанский район, село Русская Поляна, Школьная, 1-2	t	small
109565	33388	117	Еврейская автономная область, Биробиджанский район, Раздольное, Набережная, 1а	f	small
85586	33371	100	Еврейская автономная область, Биробиджанский район, село Птичник, Переселенческая, 8а	f	large
109547	33372	101	Еврейская автономная область, Биробиджанский район, село Птичник, 40 лет Победы, 2	f	medium
109550	33375	104	Еврейская автономная область, Биробиджанский район, село Пронькино, Юбилейная, 19	f	small
109553	33378	107	Еврейская автономная область, Биробиджанский район, село Петровка, Садовая, 6	f	small
109563	33386	115	Еврейская автономная область, Биробиджанский район, село Опытное Поле, Дорожная, 4	f	small
85591	33377	106	Еврейская автономная область, Биробиджанский район, село Найфельд, Школьная, 11	f	large
109557	33382	111	Еврейская автономная область, Биробиджанский район, село Надеждинское, Центральная, 34	f	small
109564	33387	116	Еврейская автономная область, Биробиджанский район, село Красивое, Юбилейная, 11	f	small
109566	33389	118	Еврейская автономная область, Биробиджанский район, село Кирга, Центральная, 13	f	small
109555	33380	109	Еврейская автономная область, Биробиджанский район, село Казанка, Школьная, 22	f	small
109516	33322	52	Еврейская автономная область, Биробиджанский район, село Заречное, Центральная, 13	f	small
109551	33376	105	Еврейская автономная область, Биробиджанский район, село Желтый Яр, Центральная, 12	f	small
109556	33381	110	Еврейская автономная область, Биробиджанский район, село Дубовое, 40 лет Победы, 12	f	medium
109559	33383	112	Еврейская автономная область, Биробиджанский район, село Головино, пер. Юбилейный, 4	t	small
109549	33374	103	Еврейская автономная область, Биробиджанский район, село Валдгейм, пер. Молодежный, 9	f	medium
109548	33373	102	Еврейская автономная область, Биробиджанский район, село Валдгейм, Центральная, 35	f	small
109562	33385	114	Еврейская автономная область, Биробиджанский район, село Бирофельд, Центральная, 47	f	medium
109560	33384	113	Еврейская автономная область, Биробиджанский район, село Алексеевка, Советская, 9а	f	small
27716	17197	27	Амурская область, поселок Ядрино, Центральная, 26	f	small
28459	17909	771	Амурская область, Шимановск, микрорайон 2, корпус № 2	f	large
28458	17908	770	Амурская область, Шимановск, микрорайон 1, корпус №4	f	large
28457	17907	769	Амурская область, Шимановск, Пограничная, 25а	f	large
28460	17910	772	Амурская область, Шимановск, Плеханова, 3	f	large
28452	17901	764	Амурская область, Шимановск, Первомайская, 9	f	large
28453	17902	765	Амурская область, Шимановск, Ленина, 26	f	large
28454	17904	766	Амурская область, Шимановск, Красноармейская, 67	f	large
28450	17899	762	Амурская область, Шимановск, Гайдара, 41	f	large
28456	17906	768	Амурская область, Шимановск, Ворошилова, 54	f	large
28187	17640	498	Амурская область, поселок Чергали, Школьная, 3	t	small
28064	17519	375	Амурская область, Ушумун, переулок Школьный, 13	t	medium
134625	94952	783	Амурская область, Тында, ООО Олекминский рудник	t	medium
28418	17866	729	Амурская область, Тында, Школьная, 5	f	large
109294	17834	699	Амурская область, Тында, Школьная, 1	t	small
28409	17856	720	Амурская область, Тында, Чкалова, 3	f	small
28404	17851	715	Амурская область, Тында, Хвойная, 1	f	small
28425	17873	736	Амурская область, Тында, Фестивальная, 13	f	large
28411	17859	722	Амурская область, Тында, Спортивная, 20/а	f	large
68029	17848	713	Амурская область, Тында, Сосновая, 3	t	large
28408	17855	719	Амурская область, Тында, Советская, 57	f	medium
28400	17846	711	Амурская область, Тында, Свердловская, ТОЦ	t	small
28412	17860	723	Амурская область, Тында, Радистов, 8	f	small
28414	17862	725	Амурская область, Тында, Профсоюзная, 5	f	large
28413	17861	724	Амурская область, Тында, Профсоюзная, 3	f	large
109302	17858	721	Амурская область, Тында, Победы, 1	f	medium
28405	17852	716	Амурская область, Тында, Первомайская, 36	f	medium
28419	17867	730	Амурская область, Тында, Октябрьская, 16	f	large
28420	17868	731	Амурская область, Тында, Московский Бульвар, 13	f	large
28385	17831	696	Амурская область, Тында, Мира, КОЦ	t	large
28383	17829	694	Амурская область, Тында, Мира, ТОЦ	t	small
28407	17854	718	Амурская область, Тында, Летная, 9	f	medium
28424	17872	735	Амурская область, Тында, Лесная, 4	f	medium
28384	17830	695	Амурская область, Тында, Лесная, 1	t	large
109300	17845	710	Амурская область, Тында, Ленинская, 1	f	medium
109301	17847	712	Амурская область, Тында, Ленина, 3	t	small
28417	17865	728	Амурская область, Тында, Красная Пресня, 62	f	large
28415	17863	726	Амурская область, Тында, Красная Пресня, 27	f	large
28426	17874	737	Амурская область, Тында, Кирова, 3	f	large
28427	17875	738	Амурская область, Тында, Киевская, 5	f	large
109295	17835	700	Амурская область, Тында, Железнодорожная, 9	f	medium
28428	17876	739	Амурская область, Тында, Дружная, 1А	f	small
28403	17850	740	Амурская область, Тында, Геологов, 1	f	small
28422	17870	733	Амурская область, Тында, Амурская, 20-а	f	medium
28406	17853	717	Амурская область, Тында, Алтайская, 19	f	medium
28423	17871	734	Амурская область, Тында, 8-е Марта, 12	f	medium
109299	17843	708	Амурская область, Тында, 70 лет Октября, 11	t	medium
28416	17864	727	Амурская область, Тында, Красная Пресня, 37	f	large
28062	17517	373	Амурская область, Сиваки, Амурская, 2	f	medium
28248	17701	559	Амурская область, Свободный, Чубаровых, 17	f	large
28247	17701	558	Амурская область, Свободный, Чубаровых, 17	f	large
28260	17713	571	Амурская область, Свободный, Управленческая, 50	f	large
28269	17722	580	Амурская область, Свободный, Театральный, 2	f	large
28251	17704	562	Амурская область, Свободный, Михайло-Чесноковская, 4/1	f	medium
28264	17717	575	Амурская область, Свободный, Механический, 1	f	large
28265	17718	576	Амурская область, Свободный, Матросова, 50	f	large
28249	17702	560	Амурская область, Свободный, Малиновского, 71	f	large
28250	17703	561	Амурская область, Свободный, Лермонтова, 44	f	large
28257	17710	568	Амурская область, Свободный, Ленина, 39	f	large
28255	17708	566	Амурская область, Свободный, Ленина, 44	f	large
28254	17707	565	Амурская область, Свободный, Ленина, 84	f	large
28253	17706	564	Амурская область, Свободный, Ленина, 95	f	medium
28258	17711	569	Амурская область, Свободный, Кручинина, 6	f	large
28261	17714	572	Амурская область, Свободный, Котовского, 54	f	large
28263	17716	574	Амурская область, Свободный, Комарова, 32	f	large
28270	17723	581	Амурская область, Свободный, Кирпичный, 96	f	large
28267	17720	578	Амурская область, Свободный, Кирова, 95	f	large
28268	17721	579	Амурская область, Свободный, Каменчука, 27	f	large
28246	17700	557	Амурская область, Свободный, Бузулинское шоссе, 1	t	large
28256	17709	567	Амурская область, Свободный, 50 лет Октября, 31	f	large
28262	17715	573	Амурская область, Свободный, 40 лет Октября, 75	f	large
68028	17712	570	Амурская область, Свободный, 40 лет Октября, 92	f	large
28252	17705	563	Амурская область, Свободный, 50 лет Октября, 84/1	f	large
28185	17638	496	Амурская область, Райчихинск, Шахтерская, 4	f	large
28183	17636	494	Амурская область, Райчихинск, Северная, 54	f	large
28181	17634	492	Амурская область, Райчихинск, Пономаренко, 13	f	medium
28180	17633	491	Амурская область, Райчихинск, Пономаренко, 85	f	large
28179	17632	490	Амурская область, Райчихинск, Победы, 53	f	large
28178	17632	489	Амурская область, Райчихинск, Победы, 53	f	large
28177	17631	488	Амурская область, Райчихинск, Победы, 62	f	large
28174	17628	485	Амурская область, Райчихинск, Победы, 11	f	large
28175	17629	486	Амурская область, Райчихинск, Пионерская, 31	f	large
28176	17630	487	Амурская область, Райчихинск, Музыкальная, 31	f	large
28184	17637	495	Амурская область, Райчихинск, Ворошилова, 4	f	large
28182	17635	493	Амурская область, Райчихинск, Апанасенко, 5	f	large
109305	17913	774	Амурская область, Прогресс, Набережная, 3	f	medium
28465	17916	777	Амурская область, поселок Прогресс, Ленинградская, 40	f	large
28469	17920	781	Амурская область, Новорайчихинск, Поярковская, 6	f	medium
28055	17510	366	Амурская область, Магдагачи, Калинина, 26	f	large
28005	17475	316	Амурская область, Зея, мкр.Солнечный, 3б	f	medium
27998	17468	309	Амурская область, Зея, мкр.Светлый, 38	f	medium
27997	17467	308	Амурская область, Зея, мкр.Светлый, 48	f	large
27996	17466	307	Амурская область, Зея, мкр.Светлый, 30	f	large
27994	17464	305	Амурская область, Зея, Шохина, 7	f	large
28000	17470	311	Амурская область, Зея, Народная, 26	f	large
27999	17469	310	Амурская область, Зея, Народная, 21	f	large
28001	17471	312	Амурская область, Зея, Мухина, 142	f	large
28003	17473	314	Амурская область, Зея, Ленина, 231	f	large
28002	17472	313	Амурская область, Зея, Ленина, 161	f	large
28004	17474	315	Амурская область, Зея, Б.Хмельницкого, 94а	f	large
27995	17465	306	Амурская область, Зея, пр.40-летия Победы, 67	f	large
28336	17781	647	Амурская область, Ерофей Павлович, Партизанская, 34, администрация поселка	f	large
27926	17398	237	Амурская область, Бурея, Октбярьская, 85	f	medium
27923	17395	234	Амурская область, Бурея, Амурская, 11	f	medium
27882	17356	193	Амурская область, Благовещенск	f	large
27881	17356	192	Амурская область, Благовещенск	f	large
27884	17358	195	Амурская область, Благовещенск, переулок Южный, 2	f	large
27814	17291	125	Амурская область, Благовещенск, Строителей, 107	f	large
27816	17293	127	Амурская область, Благовещенск, Садовая, 1	f	large
27894	17368	205	Амурская область, Благовещенск, Октябрьская, 50	f	large
27862	17339	173	Амурская область, Благовещенск, Ленина, 180к8	f	large
27843	17320	154	Амурская область, Благовещенск, Кантемирова, 6/2	f	large
27868	17321	179	Амурская область, Благовещенск, Игнатьевское шоссе, 21	f	large
27844	17321	155	Амурская область, Благовещенск, Игнатьевское шоссе, 21	f	large
27903	17377	214	Амурская область, Благовещенск, Зейская, 171/179	f	large
27842	17319	153	Амурская область, Благовещенск, Дьяченко, 4	f	large
27896	17370	207	Амурская область, Благовещенск, Горького, 95	f	large
27895	17369	206	Амурская область, Благовещенск, Горького, 129	f	large
27765	17247	76	Амурская область, Белогорск, Ломоносова, 18	f	large
27775	17257	86	Амурская область, Белогорск, Авиационная, 56	f	small
27760	17242	71	Амурская область, Белогорск, 50 лет ВЛКСМ, 37	f	large
27759	17241	70	Амурская область, Белогорск, 50 лет ВЛКСМ, 24	f	large
27695	17176	6	Амурская область, Архара, Калинина, 2	f	small
28463	17914	775	Амурская область, городской округ Райчихинск, поселок городского типа Прогресс, Ленинградская, 9	f	large
28467	17918	779	Амурская область, городской округ Райчихинск, поселок городского типа Прогресс, Бурейская, 1а	f	medium
28461	17911	773	Амурская область, городской округ Райчихинск, поселок Прогресс, Тишкина, 114	f	small
28464	17915	776	Амурская область, городской округ Райчихинск, поселок Прогресс, Советская, 16	f	large
28466	17917	778	Амурская область, городской округ Райчихинск, поселок Прогресс, Крымская, 10	f	large
28470	17921	782	Амурская область, городской округ Райчихинск, поселок Новорайчихинск, Светлая, 14	f	medium
28468	17919	780	Амурская область, городской округ Райчихинск, поселок Новорайчихинск, Депутатская, 21	f	small
27758	17240	69	Амурская область, городской округ Белогорск, Белогорск, 9 Мая, 2	f	large
28449	17898	761	Амурская область, Шимановский район, поселок Чагоян, Советская, 20	t	small
28448	17897	760	Амурская область, Шимановский район, поселок Ушаково, Школьная, 1	t	small
28447	17896	759	Амурская область, Шимановский район, поселок Ураловка, Октябрьская, 10, квартира 3 	t	small
28446	17895	758	Амурская область, Шимановский район, поселок Симоново, Советская, 3	t	small
28445	17894	757	Амурская область, Шимановский район, поселок Селеткан, Школьная, 1	t	small
28444	17893	756	Амурская область, Шимановский район, поселок Свободный Труд, Центральная, 6	t	small
28443	17892	755	Амурская область, Шимановский район, поселок Светильное, Советская, 1	t	small
28442	17891	754	Амурская область, Шимановский район, поселок Саскаль, Школьная, 32	t	small
28441	17890	753	Амурская область, Шимановский район, поселок Петруши, Советская, 33	f	medium
28440	17889	752	Амурская область, Шимановский район, поселок Новогеоргиевка, Советская, 24	f	small
28439	17888	751	Амурская область, Шимановский район, поселок Нововоскресеновка, Советская, 1	t	small
28438	17887	750	Амурская область, Шимановский район, поселок Мухино, Калинина, 22	f	medium
28437	17886	749	Амурская область, Шимановский район, поселок Малиновка, Советская, 18	f	small
28436	17885	748	Амурская область, Шимановский район, поселок Кухтерин Луг, Баргулинская, 11	t	small
28435	17884	747	Амурская область, Шимановский район, поселок Ключевое, Мухина, 5А	t	small
109304	17883	746	Амурская область, Шимановский район, поселок Берея, им. Сергея Лазо, 7/2	t	small
28433	17881	745	Амурская область, Шимановский район, поселок Базисное, Школьная, 3	t	small
109303	17880	744	Амурская область, Шимановский район, поселок Аносово, Управленческая, 30А	t	small
28431	17878	743	Амурская область, Шимановский район, поселок Актай, Трудовая, 30	t	small
28398	17844	709	Амурская область, Тындинский район, поселок Усть-Уркима, Зейская, 7	t	small
28394	17840	705	Амурская область, Тындинский район, Тында, Школьная, 18	f	large
28395	17841	706	Амурская область, Тындинский район, поселок Тутаул, Подмосковная, 4	t	small
109298	17839	704	Амурская область, Тындинский район, поселок Первомайское, Центральная, 16, Первомайский сельсовет	t	small
28392	17838	703	Амурская область, Тындинский район, поселок Первомайское, Полевая партия, 26	t	small
109297	17837	702	Амурская область, Тындинский район, поселок Муртыгит, Лесная, 5	t	small
109296	17836	701	Амурская область, Тындинский район, Маревский сельсовет, Тульская, 2	t	small
28387	17833	698	Амурская область, Тындинский район, Ларбинский сельсовет, Мира, 5	t	small
109293	17832	697	Амурская область, Тындинский район, поселок Кувыкта, Первостроителей, 6	t	small
28382	17849	714	Амурская область, Тындинский район, поселок Аносовский, Мира, 3Б-3	t	small
28366	17813	678	Амурская область, Тамбовский район, поселок Чуевка, Луговая, 24/1	t	small
28370	17817	682	Амурская область, Тамбовский район, поселок Толстовка, Пионерская, 9	f	medium
28355	17802	667	Амурская область, Тамбовский район, поселок Тамбовка, Техническая, 48Б	f	large
28354	17801	666	Амурская область, Тамбовский район, поселок Тамбовка, Ленинская, 83	f	large
28353	17800	665	Амурская область, Тамбовский район, поселок Тамбовка, Ленинская, 98	f	large
28360	17807	672	Амурская область, Тамбовский район, поселок Свободка, Свободная, 8	f	small
28367	17814	679	Амурская область, Тамбовский район, поселок Садовое, Юбилейная, 10	t	medium
28373	17820	685	Амурская область, Тамбовский район, поселок Рощино, Озёрная, 9	t	small
28376	17823	688	Амурская область, Тамбовский район, поселок Резуновка, Школьная, 6	t	small
28372	17819	684	Амурская область, Тамбовский район, поселок Раздольное, Ленина, 12	f	large
28357	17804	669	Амурская область, Тамбовский район, поселок Придорожное, Ленина, 2	f	small
28358	17805	670	Амурская область, Тамбовский район, поселок Привольное, Пионерская, 5	f	small
28369	17816	681	Амурская область, Тамбовский район, поселок Орлецкое, Школьная, 4	t	small
28361	17808	673	Амурская область, Тамбовский район, поселок Новоалександровка, Центральная, 33	f	large
28381	17828	693	Амурская область, Тамбовский район, поселок Николаевка, Амурская, 21	t	medium
28365	17812	677	Амурская область, Тамбовский район, поселок Липовка, Озёрная, 16/2	t	small
28362	17809	674	Амурская область, Тамбовский район, поселок Лиманное, Набережная, 4/2 	t	small
28371	17818	683	Амурская область, Тамбовский район, поселок Лермонтовка, Ленина, 61	t	medium
28363	17810	675	Амурская область, Тамбовский район, поселок Лазаревка, Центральная, 30	t	small
28379	17826	691	Амурская область, Тамбовский район, поселок Куропатино, переулок Школьный, 3	t	small
28377	17824	689	Амурская область, Тамбовский район, поселок Красное, Центральная, 1А	t	small
28356	17803	668	Амурская область, Тамбовский район, поселок Косицыно, Речная улица, 8	f	medium
28378	17825	690	Амурская область, Тамбовский район, поселок Корфово, Набережная, 4	t	small
28364	17811	676	Амурская область, Тамбовский район, поселок Козьмодемьяновка, Комсомольская, 54/2	f	large
28359	17806	671	Амурская область, Тамбовский район, поселок Жариково, пер.Школьный, 7	f	medium
28380	17827	692	Амурская область, Тамбовский район, поселок Духовское, Центральная, 11	t	small
134624	94309	687	Амурская область, Тамбовский район, поселок Гильчин, Садовая, 24	f	small
134623	94951	686	Амурская область, Тамбовский район, поселок Гильчин, Калинина, 16	f	small
28341	17786	652	Амурская область, Сковородинский район, ж.д.ст.Мадалан, МОУ ООШ	t	small
28340	17785	651	Амурская область, Сковородинский район, поселок Уруша, поселковая библиотека	t	small
28338	17783	649	Амурская область, Сковородинский район, поселок Уруша, МОУ СОШ	f	large
28339	17784	650	Амурская область, Сковородинский район, поселок городского типа Уруша, Карьерская, 58, МОУ ДОУ №6	f	medium
28342	17787	653	Амурская область, Сковородинский район, поселок Тахтамыгда, Якимаса, МОУ СОШ	t	medium
28346	17792	658	Амурская область, Сковородинский район, поселок Талдан, Лисина, МОУ СОШ	f	large
28348	17794	660	Амурская область, Сковородинский район, поселок Среднерейновский, библиотека 	t	small
28343	17788	654	Амурская область, Сковородинский район, поселок Солнечный, Пионерская, 13, МОУ СОШ	t	small
28332	17777	643	Амурская область, Сковородинский район, Сковородино, Победы, 9, Центральная районная библиотека	f	large
28330	17775	641	Амурская область, Сковородинский район, Сковородино, Победы, 28, МОУ ДОД СР центр внешкольной работы	f	large
28329	17774	640	Амурская область, Сковородинский район, Сковородино, Дзержинского, 7, МОУ СОШ№3	f	large
28328	17773	639	Амурская область, Сковородинский район, Сковородино, Воровского, 43, МОУ СОШ №2	f	medium
28333	17778	644	Амурская область, Сковородинский район, Сковородино, Василевского, 20, МОУ СОШ №1	f	medium
28331	17776	642	Амурская область, Сковородинский район, Сковородино, 60 лет СССР, 11, музыкальная школа	f	large
28037	17507	348	Амурская область, Сковородинский район, поселок Орловка, Амурская, 3	f	small
28345	17790	656	Амурская область, Сковородинский район, поселок Невер, клуб	t	medium
28471	17791	657	Амурская область, Сковородинский район, поселок Невер, Партизанская, 205, офис ИП Карапетян К.Г.	f	medium
28347	17793	659	Амурская область, Сковородинский район, поселок Лесной, клуб	t	small
28335	17780	646	Амурская область, Сковородинский район, поселок Ерофей Павлович, Пушкина, СПОШ №50	f	large
28334	17779	645	Амурская область, Сковородинский район, поселок Ерофей Павлович, Октябрьская, 17, МОУ СОШ	f	large
28337	17782	648	Амурская область, Сковородинский район, поселок городского типа Ерофей Павлович, ж.д.ст.Большая Омутная, МОУ НОШ	t	small
28352	17799	664	Амурская область, Сковородинский район, Ерофей Павлович, Пионерская, 3, МОУ ООШ	t	small
28350	17797	662	Амурская область, Сковородинский район, поселок Джалинда, торговый центр Катюша	t	small
109292	17795	661	Амурская область, Сковородинский район, поселок Джалинда, администрация села	f	medium
28344	17789	655	Амурская область, Сковородинский район, поселок Бам, Амурская, 1, МОУ СОШ	f	medium
28351	17798	663	Амурская область, Сковородинский район, поселок Албазино, администрация села	t	small
28321	17766	632	Амурская область, Серышевский район, поселок Широкий Лог, Октябрьская, 11	t	small
28319	17764	630	Амурская область, Серышевский район, поселок Фроловка, Октябрьская, 33	f	small
28316	17624	627	Амурская область, Серышевский район, поселок городского типа Украинка, Советская, 47	f	small
28307	17760	618	Амурская область, Серышевский район, поселок Ударное, Центральная, 5 а	t	small
28312	17170	623	Амурская область, Серышевский район, поселок Томское, Украинская, 39	f	medium
28311	16818	622	Амурская область, Серышевский район, поселок Томское, Ленина, 31	f	medium
28315	17520	626	Амурская область, Серышевский район, поселок Тавричанка, Центральная, 57	t	small
28308	17761	619	Амурская область, Серышевский район, поселок Сосновка, Центральная, 19	t	small
28323	17768	634	Амурская область, Серышевский район, поселок Соколовка, Центральная, 26	t	small
28326	17771	637	Амурская область, Серышевский район, поселок Серышево, им.Святителя Иннокентия, б/н - гарнизонный Дом офицеров ГДО	f	large
28327	17772	638	Амурская область, Серышевский район, поселок Серышево, Чехова, 3	f	large
28324	17769	635	Амурская область, Серышевский район, поселок Серышево, Советская, 44	f	large
28325	17770	636	Амурская область, Серышевский район, поселок Серышево, Горького, 1	f	large
28300	17753	611	Амурская область, Серышевский район, поселок Рождественка, пер.Пионерский, 1	t	small
28306	17759	617	Амурская область, Серышевский район, поселок Поляна, Школьная, 4 а	f	medium
28301	17754	612	Амурская область, Серышевский район, поселок Паруновка, Советская, 15	t	small
28302	17755	613	Амурская область, Серышевский район, поселок Озерное, переулок Релочный, 5	f	small
28318	17728	629	Амурская область, Серышевский район, поселок Новоохочье, Центральная улица, 18	t	small
28293	17746	604	Амурская область, Серышевский район, поселок Милехино, Южная, 10	t	small
28295	17748	606	Амурская область, Серышевский район, поселок Липовка, Секрышевская, 19	t	small
28296	17749	607	Амурская область, Серышевский район, поселок Лиманное, Школьная, 25	t	small
28297	17750	608	Амурская область, Серышевский район, поселок Лермонтово, Ленина, 12 а	t	small
28298	17751	609	Амурская область, Серышевский район, поселок Лебяжье, Иванова, 23	f	small
28291	17744	602	Амурская область, Серышевский район, поселок Ключики, Центральная, 7А	t	small
28294	17747	605	Амурская область, Серышевский район, поселок Казанка, Кирова, 16	f	small
28304	17757	615	Амурская область, Серышевский район, поселок Добрянка, Центральная, 51	t	small
28310	17763	621	Амурская область, Серышевский район, поселок Державинка, Центральная, 26	t	small
28292	17745	603	Амурская область, Серышевский район, поселок Водораздельное, Переселенческая, 6	t	small
28317	17670	628	Амурская область, Серышевский район, поселок Верное, Партизанская, 21	t	small
28289	16753	600	Амурская область, Серышевский район, поселок Введеновка, Центральная, 8	f	small
28313	17236	624	Амурская область, Серышевский район, поселок Бочкаревка, Школьная, 14	f	medium
28320	17765	631	Амурская область, Серышевский район, поселок Борисполь, Советская, 8	t	small
28290	17743	601	Амурская область, Серышевский район, поселок Большая Сазанка, Школьная, Дом культуры	f	medium
28303	17756	614	Амурская область, Серышевский район, поселок Белоногово, Колхозная, 7	t	small
28314	17421	625	Амурская область, Серышевский район, поселок Белогорка, Центральная, 45	f	small
28288	17742	599	Амурская область, Серышевский район, Арга, Серышевская, 31	t	medium
28309	17762	620	Амурская область, Серышевский район, поселок Автономовка, пер.Школьный, 2	t	small
28275	17729	586	Амурская область, Селемджинский район, поселок Экимчан, Центральная, 36	f	medium
28271	17724	582	Амурская область, Селемджинский район, поселок городского типа Экимчан, Советская, 26	f	medium
28283	17737	594	Амурская область, Селемджинский район, поселок городского типа Февральск, Звёздная, 1	f	small
28282	17736	593	Амурская область, Селемджинский район, поселок Февральск, Юбилейная, 1	f	small
28281	17735	592	Амурская область, Селемджинский район, поселок Февральск, Центральная, 29	t	small
28284	17738	595	Амурская область, Селемджинский район, поселок Февральск, Магистральная, 3	f	large
28285	17739	596	Амурская область, Селемджинский район, поселок Февральск, Ленина, 4	f	large
28276	17730	587	Амурская область, Селемджинский район, поселок Токур, Ворожейкина, 19	f	medium
28280	17734	591	Амурская область, Селемджинский район, поселок Стойба, Майская, 19	f	medium
28279	17733	590	Амурская область, Селемджинский район, поселок Селемджинск, ОАО Маломырский рудник	t	medium
28272	17725	583	Амурская область, Селемджинский район, поселок Ольгинск	t	small
28277	17731	588	Амурская область, Селемджинский район, поселок городского типа Огоджа, Садыкова, 1	t	small
28287	17741	598	Амурская область, Селемджинский район, поселок Норск, Новая, 16	t	small
109291	17732	589	Амурская область, Селемджинский район, поселок городского типа Коболдо, Центральная, 15	t	small
28286	17740	597	Амурская область, Селемджинский район, поселок Иса, Центральная, 6А	t	small
28274	17727	585	Амурская область, Селемджинский район, поселок Ивановское, Ленина, 3	t	small
28273	17726	584	Амурская область, Селемджинский район, поселок Златоустовск, ОАО Албынский рудник	t	medium
109287	17669	527	Амурская область, Свободненский район, п.Орлиный, ФРУНЗЕ, 41	t	medium
28221	17675	532	Амурская область, Свободненский район, поселок Юхта-3, Сосновый бор, 5	t	small
28224	17678	535	Амурская область, Свободненский район, поселок Черновка, Распоповой, 17	f	small
28225	17679	536	Амурская область, Свободненский район, поселок Черновка, Новая, 4/1	f	small
28207	17660	518	Амурская область, Свободненский район, поселок Черниговка, Октябрьская, 18	f	small
28219	17673	530	Амурская область, Свободненский район, поселок Усть-Пера, Южная, 11	f	small
28430	17877	742	Амурская область, Свободненский район, поселок Углегорск, Маршала Неделина, 12	f	large
28429	17877	741	Амурская область, Свободненский район, поселок Углегорск, Маршала Неделина, 12	f	large
28245	17699	556	Амурская область, Свободненский район, поселок Талали, Калинина, 75	t	small
28235	17689	546	Амурская область, Свободненский район, поселок Сычевка, Школьная, 1	t	small
28241	17695	552	Амурская область, Свободненский район, поселок Сукромли, Центральная, 19/1	t	small
28232	17686	543	Амурская область, Свободненский район, поселок Серебрянка, Центральная, 28	t	small
28240	17694	551	Амурская область, Свободненский район, поселок Семеновка, Дзержинского, 42	f	small
28230	17684	541	Амурская область, Свободненский район, поселок Рогачевка, Центральная, 46	f	small
109288	17680	537	Амурская область, Свободненский район, поселок Разливная, Сосновая, 1	t	small
28213	17666	524	Амурская область, Свободненский район, поселок Подгорный, Центральная, 45	f	small
28239	17693	550	Амурская область, Свободненский район, поселок Петропавловка, Центральная, 9а	t	small
28244	17698	555	Амурская область, Свободненский район, поселок Новостепановка, Центральная, 8	t	small
28223	17677	534	Амурская область, Свободненский район, поселок Новоострополь, Центральная, 20	t	small
28211	17664	522	Амурская область, Свободненский район, поселок Новоникольск, Старожилов, 11/1	t	small
28229	17683	540	Амурская область, Свободненский район, поселок Новоивановка, Нижняя, 10	t	small
28212	17665	523	Амурская область, Свободненский район, поселок Новгородка, Центральная, 3	t	medium
28222	17676	533	Амурская область, Свободненский район, поселок Нижние Бузули, Ленина, 32-а	t	medium
28217	17671	528	Амурская область, Свободненский район, поселок Москвитино, Гагарина, 5	t	small
28242	17696	553	Амурская область, Свободненский район, поселок Маркучи, Лазо, 40	t	small
28234	17688	545	Амурская область, Свободненский район, поселок Малый Эргель, Зеленая, 3/2	t	small
28215	17668	526	Амурская область, Свободненский район, поселок Малая Сазанка, Советская, 8	t	small
28231	17685	542	Амурская область, Свободненский район, поселок Костюковка, Лермонтова, 2	f	small
28243	17697	554	Амурская область, Свободненский район, поселок Климоуцы, Косова, 37	t	medium
28218	17672	529	Амурская область, Свободненский район, поселок Источный, 60 лет Октября, 8/1 	t	small
28233	17687	544	Амурская область, Свободненский район, поселок Зиговка, Ждановская, 29	t	small
28237	17691	548	Амурская область, Свободненский район, поселок Загорная Селитьба, Советская, 45	t	small
28210	17663	521	Амурская область, Свободненский район, поселок Заган, Центральная, 37	t	small
28208	17661	519	Амурская область, Свободненский район, поселок Желтоярово, Молодежная, 6/1	t	small
28220	17674	531	Амурская область, Свободненский район, поселок Дмитриевка, Трудовая, 1/1	t	medium
28236	17690	547	Амурская область, Свободненский район, поселок Гуран, Школьная, 8	t	small
28228	17682	539	Амурская область, Свободненский район, поселок Голубое, Кирова, 5-2	t	small
28227	17681	538	Амурская область, Свободненский район, поселок Глухари, Клубная, 4	t	small
28209	17662	520	Амурская область, Свободненский район, поселок Гащенка, Центральная, 8	t	small
109289	17692	549	Амурская область, Свободненский район, поселок Буссе, Центральная, 7	t	small
28214	17667	525	Амурская область, Свободненский район, поселок Бардагон, Набережная, 33	f	small
28186	17639	497	Амурская область, Ромненский район, поселок Смоляное, Трудовая, 4	t	small
28197	17650	508	Амурская область, Ромненский район, поселок Святоруссовка, Школьная, 49	f	small
28195	17648	506	Амурская область, Ромненский район, поселок Ромны, Школьная, 22	f	large
28194	17647	505	Амурская область, Ромненский район, поселок Ромны, Гагарина, 23	f	large
28205	17658	516	Амурская область, Ромненский район, поселок Рогозовка, Советская, 1	t	small
109286	17654	512	Амурская область, Ромненский район, поселок Поздеевка, Мелиоративная, 18	f	medium
28202	17655	513	Амурская область, Ромненский район, поселок Поздеевка, Дзержинского, 52	f	medium
28191	17644	502	Амурская область, Ромненский район, поселок Новый Быт, Рабочая, 21	t	small
109285	17653	511	Амурская область, Ромненский район, поселок Новороссийка, Центральная, 16	t	small
28190	17643	501	Амурская область, Ромненский район, поселок Новониколаевка, Трудовая, 20	t	small
28196	17649	507	Амурская область, Ромненский район, поселок Любимое, Советская, 46	t	small
109284	17645	503	Амурская область, Ромненский район, поселок Каховка, 70 Лет Октября, 58А	t	small
28193	17646	504	Амурская область, Ромненский район, поселок Калиновка, Зеленая, 8	t	small
28198	17651	509	Амурская область, Ромненский район, поселок Знаменка, Центральная, 55	f	small
28203	17656	514	Амурская область, Ромненский район, поселок Дальневосточное, Садовая, 10	t	small
28204	17657	515	Амурская область, Ромненский район, поселок Григорьевка, Восточная, 46	t	small
28206	17659	517	Амурская область, Ромненский район, поселок Вознесеновка, Набережная, 8	t	small
28199	17652	510	Амурская область, Ромненский район, поселок Верхнебелое, Зеленая, 3	t	small
28188	17641	499	Амурская область, Ромненский район, поселок Братолюбовка, Советская, 18	t	small
28189	17642	500	Амурская область, Ромненский район, поселок Амаранка, Советская, 8	t	small
28162	17615	473	Амурская область, Октябрьский район, поселок Южный, Ветеранов, 17	t	small
28152	14690	463	Амурская область, Октябрьский район, поселок Черемушки, Северная, 2	t	small
28146	17604	457	Амурская область, Октябрьский район, поселок Увальный, Центральная, 7 А	t	small
28145	17603	456	Амурская область, Октябрьский район, поселок Трудовой, Веселая, 5	t	small
28155	16185	466	Амурская область, Октябрьский район, поселок Смелое, Школьная, 14	f	small
28160	17613	471	Амурская область, Октябрьский район, поселок Сергее-Федоровка, Лесная, 32	t	small
28156	17609	467	Амурская область, Октябрьский район, поселок Романовка, Центральная, 67	f	small
28164	17617	475	Амурская область, Октябрьский район, поселок Прибрежный, Молодежная, 1	f	small
28150	17608	461	Амурская область, Октябрьский район, поселок Преображеновка, Советская, 14	t	small
28141	17599	452	Амурская область, Октябрьский район, поселок Покровка, Центральная, 7	t	small
28147	17605	458	Амурская область, Октябрьский район, поселок Песчаноозерка, Чкалова, 100	f	medium
28149	17607	460	Амурская область, Октябрьский район, поселок Переясловка, Первая, 23	t	small
28161	17614	472	Амурская область, Октябрьский район, поселок Панино, Молодежная, 11	f	small
28159	17612	470	Амурская область, Октябрьский район, поселок Новомихайловка, Рабочая, 1	f	small
28140	17598	451	Амурская область, Октябрьский район, поселок Николо-Александровка, Мухина, 31 А	f	medium
28172	17626	483	Амурская область, Октябрьский район, поселок Нагорный, Нагорная, 2	t	small
28151	17593	462	Амурская область, Октябрьский район, поселок Мухинский, Центральная, 36	t	medium
28157	17610	468	Амурская область, Октябрьский район, поселок Марьяновка, Новая, 2а	t	small
28144	17602	455	Амурская область, Октябрьский район, поселок Максимовка, Ленина, 33	f	small
28153	17535	464	Амурская область, Октябрьский район, поселок Короли, Линейная, 28	t	small
28143	17601	454	Амурская область, Октябрьский район, поселок Ильиновка, Центральная, 45	t	small
28165	17618	476	Амурская область, Октябрьский район, поселок Екатеринославка, микрорайон Таёжный	f	small
28166	17619	477	Амурская область, Октябрьский район, поселок Екатеринославка, Южная, б/н	f	medium
28167	17620	478	Амурская область, Октябрьский район, поселок Екатеринославка, Пролетарская, 21	f	small
28171	17625	482	Амурская область, Октябрьский район, поселок Екатеринославка, Ленина, 110	f	medium
28169	17622	480	Амурская область, Октябрьский район, поселок Екатеринославка, Ленина, 50	f	large
28168	17621	479	Амурская область, Октябрьский район, поселок Екатеринославка, Куйбышевская, 72	f	medium
28170	17623	481	Амурская область, Октябрьский район, поселок Екатеринославка, Коммунальная, 60	f	large
28154	16106	465	Амурская область, Октябрьский район, поселок Георгиевка, Георгиевская, 30	t	small
28163	17616	474	Амурская область, Октябрьский район, поселок Восточный, Юбилейная, 27	f	large
28148	17606	459	Амурская область, Октябрьский район, поселок Варваровка, Молодежная, 110	f	large
28142	17600	453	Амурская область, Октябрьский район, поселок Борисоглебка, Молодежная, 2	t	small
27950	17418	261	Амурская область, Октябрьский район, поселок Албазинка, Центральная, 8	t	small
28122	17579	433	Амурская область, Михайловский район, станция Воскресеновка, Железнодорожная, ж/д вокзал	t	small
28118	17575	429	Амурская область, Михайловский район, поселок Ярославка, Центральная, 23, кв. 2 	t	small
28124	17581	435	Амурская область, Михайловский район, поселок Шурино, Центральная, 4	t	small
28120	17577	431	Амурская область, Михайловский район, поселок Шумиловка, Рабочая, 5	t	small
28137	17595	448	Амурская область, Михайловский район, поселок Шадрино, Центральная, 1	t	small
28136	17594	447	Амурская область, Михайловский район, поселок Чесноково, Ленина, 18	f	medium
28131	17588	442	Амурская область, Михайловский район, поселок Черемисино, Садовая, 1	t	small
28125	17582	436	Амурская область, Михайловский район, поселок Привольное, Полевая, 4	t	small
28112	17569	423	Амурская область, Михайловский район, поселок Поярково, Советская, 18	f	medium
28113	17570	424	Амурская область, Михайловский район, поселок Поярково, Садовая, 33	f	large
28110	17567	421	Амурская область, Михайловский район, поселок Поярково, Пионерская, 1	f	medium
28111	17568	422	Амурская область, Михайловский район, поселок Поярково, Ленина, 37	f	large
28109	17566	420	Амурская область, Михайловский район, поселок Поярково, Кольцевая, 2	f	large
28108	17565	419	Амурская область, Михайловский район, поселок Поярково, Гарнизонная, 2	f	medium
28115	17572	426	Амурская область, Михайловский район, поселок Петропавловка, Центральная, 21а	f	small
28135	17592	446	Амурская область, Михайловский район, поселок Новочесноково, Совхозная, 6	f	medium
28117	17574	428	Амурская область, Михайловский район, Нижняя Ильиновка, Октябрьская, 10	t	small
28127	17584	438	Амурская область, Михайловский район, поселок Нижнезавитинка, Центральная, 10 , кв.2	t	small
28114	17571	425	Амурская область, Михайловский район, поселок Михайловка, Михайловских партизан, 2	f	medium
28134	17591	445	Амурская область, Михайловский район, поселок Куприяново, Набережная, 3	t	small
28130	17587	441	Амурская область, Михайловский район, поселок Красный Яр, Партизанская, 33	t	small
28128	17585	439	Амурская область, Михайловский район, поселок Красный Восток, Центральная, 11	t	small
28138	17596	449	Амурская область, Михайловский район, поселок Красная Орловка, Центральная, 14	t	small
28126	17583	437	Амурская область, Михайловский район, поселок Коршуновка, Специалистов, 27	t	small
28133	17590	444	Амурская область, Михайловский район, поселок Калинино, Шадрина, 1	t	small
28121	17578	432	Амурская область, Михайловский район, поселок Кавказ, Дорожная, 22/1	t	small
28129	17586	440	Амурская область, Михайловский район, поселок Зеленый Бор, Центральная, 13	f	medium
28123	17580	434	Амурская область, Михайловский район, поселок Дубовое, Советская, 2-Б	f	small
28139	17597	450	Амурская область, Михайловский район, поселок Дим, Центральная, 6	f	medium
28119	17576	430	Амурская область, Михайловский район, поселок Воскресеновка, Школьная, 2	f	small
28322	17767	633	Амурская область, Михайловский район, поселок Воскресеновка, Центральная, 15	t	small
28132	17589	443	Амурская область, Михайловский район, поселок Винниково, Шадрина, 1	t	small
28116	17573	427	Амурская область, Михайловский район, поселок Арсентьевка, переулок Школьный, 2	t	small
28087	17544	398	Амурская область, Мазановский район, поселок Юбилейное, Центральная, 1	t	small
28091	17548	402	Амурская область, Мазановский район, поселок Христиновка, Озерная, 7/2	t	small
28081	17538	392	Амурская область, Мазановский район, поселок Ульма, Центральная, 1	t	small
28080	17537	391	Амурская область, Мазановский район, поселок Угловое, Центральная, 26	t	small
28077	17533	388	Амурская область, Мазановский район, поселок Таскино, Советская, 43	t	small
28099	17556	410	Амурская область, Мазановский район, поселок Сохатино, Зейская, 7	t	small
28093	17550	404	Амурская область, Мазановский район, поселок Сапроново, 30 лет Победы, 11	f	small
28089	17546	400	Амурская область, Мазановский район, поселок Романкауцы, Цветочная, 2	t	small
28088	17545	399	Амурская область, Мазановский район, поселок Раздольное, Амурская, 15	t	small
28076	17532	387	Амурская область, Мазановский район, поселок Путятино, Джалова, 10	t	small
28098	17555	409	Амурская область, Мазановский район, поселок Практичи, Советская, 41	f	small
28105	17562	416	Амурская область, Мазановский район, поселок Поповка, Центральная, 34	t	small
28075	17531	386	Амурская область, Мазановский район, поселок Пионерский, Центральная, 1	f	small
28100	17557	411	Амурская область, Мазановский район, поселок Петровка, Центральная, 21А	t	small
28096	17553	407	Амурская область, Мазановский район, поселок Паутовка, Минская, 9	t	small
28082	17539	393	Амурская область, Мазановский район, поселок Новороссийка, Набережная, 29	t	small
28074	17530	385	Амурская область, Мазановский район, поселок Новокиевский Увал, пер. Амурский	f	medium
28072	17528	383	Амурская область, Мазановский район, поселок Новокиевский Увал, Школьная, 9	f	large
28073	17529	384	Амурская область, Мазановский район, поселок Новокиевский Увал, Луговая, 78	f	large
28071	17527	382	Амурская область, Мазановский район, поселок Новокиевка, Колхозная, 1а	f	medium
28106	17563	417	Амурская область, Мазановский район, поселок Молчаново, Олимпийская, 7	t	small
28102	17559	413	Амурская область, Мазановский район, поселок Михайловка, Центральная, 26 , кв.2	t	small
28097	17554	408	Амурская область, Мазановский район, поселок Маргаритовка, Новая, 4	t	small
28083	17540	394	Амурская область, Мазановский район, поселок Майский, переулок Лесной, 13	t	small
28085	17542	396	Амурская область, Мазановский район, поселок Мазаново, Ленина, 18	f	medium
28103	17560	414	Амурская область, Мазановский район, поселок Леонтьевка	t	small
28104	17561	415	Амурская область, Мазановский район, поселок Красноярово, Школьная, 18	f	medium
28078	17534	389	Амурская область, Мазановский район, поселок Козловка, Центральная, 17	t	small
28084	17541	395	Амурская область, Мазановский район, поселок Ивановский, Больничная, 2А	t	small
28090	17547	401	Амурская область, Мазановский район, поселок Дружное, Орловой, 4	t	small
28095	17552	406	Амурская область, Мазановский район, поселок Дмитриевка, переулок Школьный, 2	f	small
28079	17536	390	Амурская область, Мазановский район, поселок Богословка, Молодежная, 1	t	small
28094	17551	405	Амурская область, Мазановский район, поселок Бичура, Школьная, 2	t	small
28086	17543	397	Амурская область, Мазановский район, поселок Белоярово, пер.Школьный, 4	t	medium
28101	17558	412	Амурская область, Мазановский район, поселок Антоновка, Центральная, 22	t	small
28092	17549	403	Амурская область, Мазановский район, поселок Алексеевка, Лесная, 12	t	small
28057	17512	368	Амурская область, Магдагачинский район, поселок Черняево, Мухинская, 5	f	medium
28065	17521	376	Амурская область, Магдагачинский район, поселок Чалганы, Советская, 21	t	small
28063	17518	374	Амурская область, Магдагачинский район, поселок городского типа Ушумун, Комсомольская, 17	t	large
28067	17523	378	Амурская область, Магдагачинский район, поселок Тыгда, Советская, 3	f	medium
28066	17522	377	Амурская область, Магдагачинский район, поселок Тыгда, Советская, 8	f	large
28060	17515	371	Амурская область, Магдагачинский район, поселок Тыгда, Советская, 17, ОАО Покровский рудник	t	large
28059	17514	370	Амурская область, Магдагачинский район, поселок Толбузино, Погрничная	t	small
28061	17516	372	Амурская область, Магдагачинский район, Сиваки, Вокзальная, 5	f	large
28054	17509	365	Амурская область, Магдагачинский район, поселок Магдагачи, К.Маркса, 17	f	large
28053	17508	364	Амурская область, Магдагачинский район, Магдагачи, Комсомольская, 40	f	large
28052	17508	363	Амурская область, Магдагачинский район, Магдагачи, Комсомольская, 40	f	large
28056	17511	367	Амурская область, Магдагачинский район, Магдагачи, К.Маркса, 20	f	large
28058	17513	369	Амурская область, Магдагачинский район, поселок Кузнецово, Амурская, 15	t	small
28068	17524	379	Амурская область, Магдагачинский район, поселок Дактуй, Проезжая, 3	f	medium
28070	17526	381	Амурская область, Магдагачинский район, поселок Гудачи, Школьная, 17	t	small
28069	17525	380	Амурская область, Магдагачинский район, поселок Гонжа, Кооперативная, 4	t	medium
28049	16942	360	Амурская область, Константиновский район, поселок Средняя Полтавка, Молодежная, 10	f	small
28042	15977	353	Амурская область, Константиновский район, поселок Семидомка, Ленина, 43	t	small
28041	15897	352	Амурская область, Константиновский район, поселок Октябрьское, Центральная, 11	t	small
28046	16427	357	Амурская область, Константиновский район, поселок Новотроицкое, Советская, 55	f	small
28038	17492	349	Амурская область, Константиновский район, поселок Новопетровка, Стрельцова, 27А	t	small
28047	16576	358	Амурская область, Константиновский район, поселок Нижняя Полтавка, Пионерская, 2А	f	large
28043	16202	354	Амурская область, Константиновский район, поселок Крестовоздвиженка, Школьная, 5	f	medium
28036	17506	347	Амурская область, Константиновский район, Константиновка, Ленина, 84	f	large
28035	17505	346	Амурская область, Константиновский район, поселок Константиновка, Ленина, 84	f	large
28034	17504	345	Амурская область, Константиновский район, поселок Константиновка, Ленина, 84	f	large
28040	15799	351	Амурская область, Константиновский район, поселок Коврижка, Ленина, 29	f	small
28044	16347	355	Амурская область, Константиновский район, поселок Ключи, Школьная, 24	f	medium
28051	17084	362	Амурская область, Константиновский район, поселок Золотоножка, Школьная, 7	t	small
28050	17067	361	Амурская область, Константиновский район, поселок Зеньковка, Советская, 19	t	small
28039	15495	350	Амурская область, Константиновский район, поселок Войково, Центральная, 26	t	small
28048	16845	359	Амурская область, Константиновский район, поселок Верхняя Полтавка, Советская, 40/1	t	medium
28045	16411	356	Амурская область, Константиновский район, поселок Верхний Уртуй, Ленина, 52	f	small
28033	17503	344	Амурская область, Ивановский район, поселок Черемхово, Кирова, 117 А	f	medium
28012	17481	323	Амурская область, Ивановский район, поселок Успеновка, Дрогошевского, 36	t	small
28026	17496	337	Амурская область, Ивановский район, поселок Троицкое, Комсомольская, 2	f	small
28024	17494	335	Амурская область, Ивановский район, поселок Среднебелое-2, Строителей, 1	f	medium
28025	17495	336	Амурская область, Ивановский район, поселок Среднебелое, Молодежная, 1	f	medium
28023	17493	334	Амурская область, Ивановский район, поселок Среднебелая, Садовая, 25а	f	large
28022	17491	333	Амурская область, Ивановский район, поселок Среднебелая, Амурская, 14	f	large
28027	17497	338	Амурская область, Ивановский район, поселок Солнечное, Зеленая, 34	f	small
28028	17498	339	Амурская область, Ивановский район, поселок Семиозерка, Кирова, 32/2	f	medium
28013	17482	324	Амурская область, Ивановский район, поселок Правовосточное, Центральная, 28	f	small
28031	17501	342	Амурская область, Ивановский район, поселок Петропавловка, Кооперативный, 20	f	medium
28020	17489	331	Амурская область, Ивановский район, поселок Новопокровка, Школьная, 22 а	t	small
28021	17490	332	Амурская область, Ивановский район, поселок Новоалексеевка, Гвардейская, 51/1	t	medium
28019	17488	330	Амурская область, Ивановский район, поселок Николаевка, Центральная, 1	f	small
28010	17479	321	Амурская область, Ивановский район, поселок Луговое, Садовая, 35	t	small
28009	17436	320	Амурская область, Ивановский район, поселок Крещеновка, Центральная, 19	t	small
28017	17486	328	Амурская область, Ивановский район, поселок Константиноградовка, Ветеранов, 68	f	medium
28008	17478	319	Амурская область, Ивановский район, поселок Ивановка, Пионерская, 26	f	large
28007	17477	318	Амурская область, Ивановский район, поселок Ивановка, Партизанская, 97	f	large
28006	17476	317	Амурская область, Ивановский район, поселок Ивановка, Галушкина, 7	f	large
28018	17487	329	Амурская область, Ивановский район, поселок Ерковцы, Советская, 101	f	medium
28011	17480	322	Амурская область, Ивановский район, поселок Дмитриевка, Набережная, 59	f	medium
28015	17484	326	Амурская область, Ивановский район, поселок Большеозерка, Центральная, 21	t	small
28032	17502	343	Амурская область, Ивановский район, поселок Богородское, Партизанская, 18	t	small
28029	17499	340	Амурская область, Ивановский район, поселок Березовка, Юбилейная, 24 а	f	large
28030	17500	341	Амурская область, Ивановский район, поселок Березовка, Ленина, 14	f	large
28016	17485	327	Амурская область, Ивановский район, поселок Анновка, Молодежный, 1	f	small
28014	17483	325	Амурская область, Ивановский район, поселок Андреевка, Центральная, 15	t	small
27979	17449	290	Амурская область, Зейский район, поселок Юбилейный, Центральная, 45/А	t	small
27975	17445	286	Амурская область, Зейский район, поселок Чалбачи, Амурская, 14	t	small
27986	17456	297	Амурская область, Зейский район, поселок Хвойный, Первооткрывателей, 6	t	small
27977	17447	288	Амурская область, Зейский район, поселок Умлекан, Универсальная, 6	t	small
27991	17461	302	Амурская область, Зейский район, поселок Тунгала	t	small
27964	17433	275	Амурская область, Зейский район, поселок Сосновый Бор, Новая, 2/А	f	medium
27984	17454	295	Амурская область, Зейский район, поселок Снежногорский, Ленина, 2	t	small
27976	17446	287	Амурская область, Зейский район, поселок Сиан, Трейберта, 8	t	small
27978	17448	289	Амурская область, Зейский район, поселок Рублевка, Центральная, 15	t	small
27980	17450	291	Амурская область, Зейский район, поселок Поляковский, Рабочая, 8	t	small
27982	17452	293	Амурская область, Зейский район, поселок Октябрьский, Чехова, 2/А	t	small
27983	17453	294	Амурская область, Зейский район, поселок Октябрьский, Спортивная, 40	f	medium
27990	17460	301	Амурская область, Зейский район, поселок Огорон, Первостроителей , 20	t	small
27968	17438	279	Амурская область, Зейский район, поселок Овсянка, переулок Светлый, 3	f	large
27967	17437	278	Амурская область, Зейский район, поселок Овсянка, Ленина, 90	f	large
27971	17441	282	Амурская область, Зейский район, поселок Николаевка 2-я, Центральная, 10/А	f	small
27969	17439	280	Амурская область, Зейский район, поселок Ивановка, Советская, 7	f	small
27981	17451	292	Амурская область, Зейский район, поселок Золотая Гора, Школьная, 14	t	small
27966	17435	277	Амурская область, Зейский район, поселок Заречная Слобода, Школьная, 32	f	medium
27992	17462	303	Амурская область, Зейский район, поселок Дугда, пл.Тухачевского, 1	f	medium
27965	17434	276	Амурская область, Зейский район, поселок Гулик	t	small
27987	17457	298	Амурская область, Зейский район, поселок Горный, Советская, 1	f	medium
27989	17459	300	Амурская область, Зейский район, поселок Верхнезейск, МУК СКК	t	large
27988	17458	299	Амурская область, Зейский район, поселок Бомнак, Федосеева, 29	t	small
27973	17443	284	Амурская область, Зейский район, поселок Березовка, Почтовая, 8	t	small
27985	17455	296	Амурская область, Зейский район, поселок Береговой, Ленина, 6	f	large
27970	17440	281	Амурская область, Зейский район, поселок Амуро-Балтийск, Юбилейная, 17	t	small
27972	17442	283	Амурская область, Зейский район, поселок Александровка, Центральная, 13/А 	t	small
27974	17444	285	Амурская область, Зейский район, поселок Алгач, пер. Сосновый , 14	t	small
27959	17428	270	Амурская область, Завитинский район, поселок Червоная Армия, Центральная, 14	t	small
27942	17410	253	Амурская область, Завитинский район, поселок Федоровка, Южная, 11-2	t	small
27949	17417	260	Амурская область, Завитинский район, поселок Успеновка, Центральная, 46	f	small
27944	17412	255	Амурская область, Завитинский район, поселок Преображеновка, Центральная, 28А	t	small
27943	17411	254	Амурская область, Завитинский район, поселок Подоловка, Чкалова, 33	t	small
27952	17420	263	Амурская область, Завитинский район, поселок Новоалексеевка, Центральная, 13	t	small
27939	17407	250	Амурская область, Завитинский район, поселок Ленино, Свободная, 5	t	small
27941	17409	252	Амурская область, Завитинский район, поселок Куприяновка, Комсомольская, 23	f	small
27948	17416	259	Амурская область, Завитинский район, поселок Камышенка, Школьная, 6	t	small
27946	17414	257	Амурская область, Завитинский район, поселок Иннокентьевка, Центральная, 7	t	small
27960	17429	271	Амурская область, Завитинский район, Завитинск, ПО Озерный	t	small
27957	17426	268	Амурская область, Завитинский район, Завитинск, Чкалова, 16	f	large
27958	17427	269	Амурская область, Завитинский район, Завитинск, Линейная, 6В	f	large
27956	17425	267	Амурская область, Завитинский район, Завитинск, Куйбышева, 30	f	large
27954	17423	265	Амурская область, Завитинский район, Завитинск, Красноармейская, 56	f	large
27955	17424	266	Амурская область, Завитинский район, Завитинск, Кооперативная, 104	f	large
27953	17422	264	Амурская область, Завитинский район, Завитинск, Комсомольская, 97	f	large
27947	17415	258	Амурская область, Завитинский район, поселок Демьяновка, Нижняя, 13/2	t	small
27963	17432	274	Амурская область, Завитинский район, поселок Верхнеильиновка, Центральная, 3	t	small
27945	17413	256	Амурская область, Завитинский район, поселок Валуево, Центральная, 7	t	small
27961	17430	272	Амурская область, Завитинский район, поселок Болдыревка, Октябрьская, 32Б	f	small
27951	17419	262	Амурская область, Завитинский район, поселок Белый Яр, Центральная, 13	t	small
27940	17408	251	Амурская область, Завитинский район, поселок Антоновка	t	small
27962	17431	273	Амурская область, Завитинский район, поселок Аврамовка, Центральная, 8	t	small
27930	17402	241	Амурская область, Бурейский район, поселок Усть-Кивда, Центральная, 26	t	small
27921	17393	232	Амурская область, Бурейский район, поселок городского типа Талакан	f	large
27920	17392	231	Амурская область, Бурейский район, поселок городского типа Талакан	f	large
27937	15816	248	Амурская область, Бурейский район, поселок Старая Райчиха, Центральная, 14	f	small
27932	17404	243	республика Мордовия, Чамзинский район, село Семеновка	t	small
27931	17403	242	Амурская область, Бурейский район, поселок Родионовка, Школьная, 2	f	small
27918	17390	229	Амурская область, Бурейский район, Новобурейский, Советская, 80	f	medium
27916	17388	227	Амурская область, Бурейский район, поселок городского типа Новобурейский, Советская, 60	f	large
27914	17386	225	Амурская область, Бурейский район, поселок Новобурейский, Чайковского, 1	f	large
27917	17389	228	Амурская область, Бурейский район, поселок Новобурейский, Советская, 53	f	large
27915	17387	226	Амурская область, Бурейский район, поселок Новобурейский, Лесная, 36	f	large
27919	17391	230	Амурская область, Бурейский район, поселок Николаевка, Юбилейная, 31	f	medium
27928	17400	239	Московская область, Шаховской район, садовое товарищество Муравка	t	small
27929	17401	240	Амурская область, Бурейский район, Малиновка, Октябрьская, 1	f	large
27927	17399	238	Амурская область, Бурейский район, поселок Кивдо-Тюкан	t	small
27933	17405	244	Амурская область, Бурейский район, поселок Долдыкан, Молодёжная, 9А	f	small
27935	15614	246	Амурская область, Бурейский район, поселок Виноградовка, переулок Школьный, 9	f	small
27925	17397	236	Амурская область, Бурейский район, поселок городского типа Бурея, Кировская, 83	f	medium
27924	17396	235	Амурская область, Бурейский район, поселок Бурея, Октябрьская, 61	f	large
27922	17394	233	Амурская область, Бурейский район, поселок Бурея, Мухинская, 22	f	medium
27936	15766	247	Амурская область, Бурейский район, поселок Безозерное, Центральная, 1	f	medium
27934	17406	245	Амурская область, Бурейский район, поселок Алексеевка, Новая, 12	t	small
27807	17290	118	Амурская область, Благовещенский район, поселок Чигири, Тепличная, 1	t	medium
27793	17276	104	Амурская область, Благовещенский район, поселок Чигири, Новая, 4	f	large
27784	17266	95	Амурская область, Благовещенский район, поселок Усть-Ивановка, Ленина, 54/1	f	large
27791	17274	102	Амурская область, Благовещенский район, поселок Удобное, Свободная, 2	t	small
27799	17282	110	Амурская область, Благовещенский район, поселок Сергеевка, Пограничная, 9	f	large
27782	17264	93	Амурская область, Благовещенский район, поселок Ровное, Центральная, 24	f	small
27803	17286	114	Амурская область, Благовещенский район, поселок Прядчино, Центральная, 48	t	small
27815	17292	126	Амурская область, Благовещенский район, поселок Плодопитомник, Центральная, 1 а	f	large
27792	17275	103	Амурская область, Благовещенский район, поселок Передовое, Центральная, 20 Б	t	small
27801	17284	112	Амурская область, Благовещенский район, поселок Новотроицкое, Гагарина, 17	f	medium
27802	17285	113	Амурская область, Благовещенский район, поселок Новопетровка, Школьная, 29	f	medium
27805	17288	116	Амурская область, Благовещенский район, поселок Новинка, Центральная, 31	t	small
27806	17289	117	Амурская область, Благовещенский район, поселок Натальино	t	small
27797	17280	108	Амурская область, Благовещенский район, поселок Михайловка, Коммунальная, 6	f	small
27796	17279	107	Амурская область, Благовещенский район, поселок Марково, 60 лет Октября, 32	f	large
27787	17270	98	Амурская область, Благовещенский район, поселок Каникурган, Центральная, 19	t	small
27795	17278	106	Амурская область, Благовещенский район, поселок Игнатьево, Школьная, 16	f	medium
27788	17271	99	Амурская область, Благовещенский район, поселок Заречный, Магистральная, 10	t	small
27804	17287	115	Амурская область, Благовещенский район, поселок Егорьевка, пер. Клубный, 4	t	small
27790	17273	101	Амурская область, Благовещенский район, поселок Дроново, переулок Новый, 1	t	small
27798	17281	109	Амурская область, Благовещенский район, поселок Грязнушка	f	small
27786	17269	97	Амурская область, Благовещенский район, поселок Гродеково, Центральная, 8	t	small
27789	17272	100	Амурская область, Благовещенский район, поселок Грибское, Центральная, 47	f	medium
27783	17265	94	Амурская область, Благовещенский район, поселок Владимировка, Центральная, 28 , пом.1	f	small
27870	17345	181	Амурская область, Благовещенский район, поселок Верхнеблаговещенское, Клуб села Верхнеблаговещенское	t	small
27794	17277	105	Амурская область, Благовещенский район, поселок Верхнеблаговещенское, Ленина, 68	f	medium
27813	17268	124	Амурская область, Благовещенский район, Благовещенск	f	small
27810	17268	121	Амурская область, Благовещенский район, Благовещенск	f	small
27808	17268	119	Амурская область, Благовещенский район, Благовещенск	f	small
27811	17268	122	Амурская область, Благовещенский район, Благовещенск	f	small
27848	17325	159	Амурская область, Благовещенский район, Благовещенск, п. Аэропорт, 10	f	large
27838	17315	149	Амурская область, Благовещенский район, Благовещенск, Школьная, 7	f	medium
27886	17360	197	Амурская область, Благовещенский район, Благовещенск, Широкая, 61	f	large
27873	17348	184	Амурская область, Благовещенский район, Благовещенск, Шимановского, 8	f	medium
27906	17380	217	Амурская область, Благовещенский район, Благовещенск, Чайковского, 95/3	f	large
27898	17372	209	Амурская область, Благовещенский район, Благовещенск, Чайковского, 87	f	large
27888	17362	199	Амурская область, Благовещенский район, Благовещенск, Чайковского, 175	f	large
27859	17336	170	Амурская область, Благовещенский район, Благовещенск, Чайковского, 14	f	large
27855	17332	166	Амурская область, Благовещенский район, Благовещенск, Чайковского, 307	f	small
27781	17263	92	Амурская область, Благовещенский район, Благовещенск, Центральная, 11	f	large
27879	17354	190	Амурская область, Благовещенский район, Благовещенск, Фрунзе, 57/59	f	large
27887	17361	198	Амурская область, Благовещенский район, Благовещенск, Трудовая, 182	f	large
27835	17312	146	Амурская область, Благовещенский район, Благовещенск, Тенистая, 103	f	large
27899	17373	210	Амурская область, Благовещенский район, Благовещенск, Театральная, 2	f	large
27885	17359	196	Амурская область, Благовещенский район, Благовещенск, Театральная, 276	f	large
27874	17349	185	Амурская область, Благовещенский район, Благовещенск, Театральная, 28	f	large
27866	17342	177	Амурская область, Благовещенский район, Благовещенск, Театральная, 185	f	large
27854	17331	165	Амурская область, Благовещенский район, Благовещенск, Театральная, 96	f	small
27869	17344	180	Амурская область, Благовещенский район, Благовещенск, Студенческая, 43/3	f	large
27846	17323	157	Амурская область, Благовещенский район, Благовещенск, Студенческая, 4/5, 4 корпус	f	large
27845	17322	156	Амурская область, Благовещенский район, Благовещенск, Студенческая, 28	f	large
27892	17366	203	Амурская область, Благовещенский район, Благовещенск, Северная, 107	f	large
27831	17308	142	Амурская область, Благовещенский район, Благовещенск, Свободная, 261	f	large
27867	17343	178	Амурская область, Благовещенский район, Благовещенск, Релочная, 22	f	large
27863	17340	174	Амурская область, Благовещенский район, Благовещенск, Рабочая, 95	f	large
27891	17365	202	Амурская область, Благовещенский район, Благовещенск, Пушкина, 189	f	large
27875	17350	186	Амурская область, Благовещенский район, Благовещенск, Пушкина, 44	f	large
27897	17371	208	Амурская область, Благовещенский район, Благовещенск, Политехническая, 86	f	large
27883	17357	194	Амурская область, Благовещенский район, Благовещенск, Пограничная, 124/3	f	large
27837	17314	148	Амурская область, Благовещенский район, Благовещенск, Пионерская, 157	f	large
27836	17313	147	Амурская область, Благовещенский район, Благовещенск, Пионерская, 104	f	large
27821	17298	132	Амурская область, Благовещенский район, Благовещенск, Пионерская, 1	f	large
27902	17376	213	Амурская область, Благовещенский район, Благовещенск, Первомайская, 36	f	large
27890	17364	201	Амурская область, Благовещенский район, Благовещенск, Островского, 150	f	large
27907	17381	218	Амурская область, Благовещенский район, Благовещенск, Октябрьская, 155	f	large
27850	17327	161	Амурская область, Благовещенский район, Благовещенск, Октябрьская, 239	f	large
27853	17330	164	Амурская область, Благовещенский район, Благовещенск, Нагорная, 4	f	large
27833	17310	144	Амурская область, Благовещенский район, Благовещенск, Ломоносова, 144	f	large
27871	17346	182	Амурская область, Благовещенский район, Благовещенск, Ленина,, 297	f	large
134952	95200	188	Амурская область, Благовещенский район, Благовещенск, Ленина, 1	f	large
27905	17379	216	Амурская область, Благовещенский район, Благовещенск, Ленина, 80	f	large
27872	17347	183	Амурская область, Благовещенский район, Благовещенск, Ленина, 104	f	large
27861	17338	172	Амурская область, Благовещенский район, Благовещенск, Ленина, 160	f	large
27860	17337	171	Амурская область, Благовещенский район, Благовещенск, Ленина, 144	f	large
27817	17294	128	Амурская область, Благовещенский район, Благовещенск, Ленина, 196	f	large
27858	17335	169	Амурская область, Благовещенский район, Благовещенск, Лазо, 41	f	large
27878	17353	189	Амурская область, Благовещенский район, Благовещенск, Краснофлотская, 83/95	f	large
27900	17374	211	Амурская область, Благовещенский район, Благовещенск, Красноармейская, 56	f	large
27830	17307	141	Амурская область, Благовещенский район, Благовещенск, Красноармейская, 227	f	medium
27829	17306	140	Амурская область, Благовещенский район, Благовещенск, Красноармейская, 157	f	large
27828	17305	139	Амурская область, Благовещенский район, Благовещенск, Красноармейская, 161	f	large
27819	17296	130	Амурская область, Благовещенский район, Благовещенск, Комсомольская, 21	f	large
27839	17316	150	Амурская область, Благовещенский район, Благовещенск, Калинина, 130/2	f	large
27865	17311	176	Амурская область, Благовещенский район, Благовещенск, Калинина, 114	f	large
27834	17311	145	Амурская область, Благовещенский район, Благовещенск, Калинина, 114	f	large
27832	17309	143	Амурская область, Благовещенский район, Благовещенск, Калинина, 103	f	large
27818	17295	129	Амурская область, Благовещенский район, Благовещенск, Калинина, 13	f	large
27849	17326	160	Амурская область, Благовещенский район, Благовещенск, Институтская, 3	f	large
27847	17324	158	Амурская область, Благовещенский район, Благовещенск, Институтская, 15	f	large
27851	17328	162	Амурская область, Благовещенский район, Благовещенск, Игнатьевское шоссе, 19	f	large
27841	17318	152	Амурская область, Благовещенский район, Благовещенск, Игнатьевское шоссе, 5	f	large
27876	17351	187	Амурская область, Благовещенский район, Благовещенск, Зейская, 30	f	large
27857	17334	168	Амурская область, Благовещенский район, Благовещенск, Зейская, 34	f	large
27852	17329	163	Амурская область, Благовещенский район, Благовещенск, Зейская, 89	f	large
27823	17300	134	Амурская область, Благовещенский район, Благовещенск, Зейская, 297	f	large
27822	17299	133	Амурская область, Благовещенский район, Благовещенск, Загородная, 54	f	large
27880	17355	191	Амурская область, Благовещенский район, Благовещенск, Заводская, 18	f	large
27827	17304	138	Амурская область, Благовещенский район, Благовещенск, Горького, 231	f	large
27826	17303	137	Амурская область, Благовещенский район, Благовещенск, Горького, 153	f	large
27824	17301	135	Амурская область, Благовещенский район, Благовещенск, Горького, 157	f	large
27856	17333	167	Амурская область, Благовещенский район, Благовещенск, Воронкова, 26	f	medium
27820	17297	131	Амурская область, Благовещенский район, Благовещенск, Б. Хмельницкого, 1	f	large
27904	17378	215	Амурская область, Благовещенский район, Благовещенск, Амурская, 151	f	large
27901	17375	212	Амурская область, Благовещенский район, Благовещенск, Амурская, 97	f	large
27825	17302	136	Амурская область, Благовещенский район, Благовещенск, Амурская, 223/1	f	large
27889	17363	200	Амурская область, Благовещенский район, Благовещенск, Театральная, 179	f	large
27893	17367	204	Амурская область, Благовещенский район, Благовещенск, Свободная, 33	f	large
27864	17341	175	Амурская область, Благовещенский район, Благовещенск, Островского, 273	f	large
27840	17317	151	Амурская область, Благовещенский район, Благовещенск, Дьяченко, 5/3	f	large
27800	17283	111	Амурская область, Благовещенский район, поселок Бибиково, Лесная, 1	t	small
27730	17211	41	Амурская область, Белогорский район, поселок Чернетчено	t	small
27744	17226	55	Амурская область, Белогорский район, поселок Успеновка, Школьная, 4	t	small
27938	15880	249	Амурская область, Белогорский район, поселок Успеновка, Центральная, 2	f	small
27739	17220	50	Амурская область, Белогорский район, поселок Томичи, Комсомольская, 4А	f	large
27748	17230	59	Амурская область, Белогорский район, поселок Светиловка, Школьная, 4	t	small
27738	17219	49	Амурская область, Белогорский район, поселок Савельевка, Центральная, 20а	t	small
27732	17213	43	Амурская область, Белогорский район, поселок Пригородное, Садовая, 5	f	medium
27740	17222	51	Амурская область, Белогорский район, поселок Поляное, Почтовая, 4, кв. 2 	t	small
27719	17200	30	Амурская область, Белогорский район, поселок Павловка, Центральная, 34/2	t	small
27729	17210	40	Амурская область, Белогорский район, поселок Озеряне, Центральная, 44	f	small
27735	17216	46	Амурская область, Белогорский район, поселок Новоселитьба, Центральная, 13	t	small
27736	17217	47	Амурская область, Белогорский район, поселок Новоназаровка, Нижняя, 7	f	small
27721	17202	32	Амурская область, Белогорский район, поселок Новое, Школьная, 2	f	small
27746	17228	57	Амурская область, Белогорский район, поселок Новоандреевка, Набережная, 33	f	small
27751	17233	62	Амурская область, Белогорский район, поселок Никольское, пер.Школьный, 6	f	large
27778	17260	89	Амурская область, Белогорский район, поселок Низинное, Новая, 24	f	small
27734	17215	45	Амурская область, Белогорский район, поселок Некрасовка, Садовая, 72	f	small
27731	17212	42	Амурская область, Белогорский район, поселок Мирное, Центральная, 12А	t	small
27717	17198	28	Амурская область, Белогорский район, поселок Междугранка, Юбилейная, 11/1	f	small
27742	17224	53	Амурская область, Белогорский район, поселок Лукьяновка, Садовая, 20	f	small
27722	17203	33	Амурская область, Белогорский район, поселок Луговое, Центральная, 4	t	small
27737	17218	48	Амурская область, Белогорский район, поселок Лохвицы, Школьная, 73	t	medium
28368	17815	680	Амурская область, Белогорский район, поселок Лозовое, Школьная, 8	f	medium
27741	17223	52	Амурская область, Белогорский район, поселок Кустанаевка, Центральная, 33	f	small
27720	17201	31	Амурская область, Белогорский район, поселок Круглое, Сельская, 11	t	small
27745	17227	56	Амурская область, Белогорский район, поселок Комиссаровка, Новая, 6	t	small
27750	17232	61	Амурская область, Белогорский район, поселок Ключи, Рабочая, 40А	t	small
27749	17231	60	Амурская область, Белогорский район, поселок Киселеозерка, Школьная, 8А	t	small
27743	17225	54	Амурская область, Белогорский район, поселок Камышевка, Степная, 16	f	small
27728	17209	39	Амурская область, Белогорский район, поселок Заречное, Комсомольская, 12	f	small
27723	17204	34	Амурская область, Белогорский район, поселок Дубровка, Центральная, 1	t	small
27727	17208	38	Амурская область, Белогорский район, поселок Возжаевка, м-н Южный	f	large
27726	17207	37	Амурская область, Белогорский район, поселок Возжаевка, Центральная, 9	f	small
27725	17206	36	Амурская область, Белогорский район, поселок Возжаевка, Гагарина, 18	f	large
27747	17229	58	Амурская область, Белогорский район, поселок Великокнязевка, Мира, 76	t	medium
27718	17199	29	Амурская область, Белогорский район, поселок Васильевка, Школьная, 14б	f	large
27733	17214	44	Амурская область, Белогорский район, поселок Белоцерковка, Школьная, 25	f	small
27762	17244	73	Амурская область, Белогорский район, Белогорск, пер. Летний, 21	f	large
27768	17250	79	Амурская область, Белогорский район, Белогорск, Шевченко, 63	f	large
27752	17234	63	Амурская область, Белогорский район, Белогорск, Ударная, 24	f	large
27767	17249	78	Амурская область, Белогорский район, Белогорск, Производственная, 11	f	large
27753	17235	64	Амурская область, Белогорский район, Белогорск, Партизанская, 26	f	large
27776	17258	87	Амурская область, Белогорский район, Белогорск, Никольское шоссе, 164	f	large
27772	17254	83	Амурская область, Белогорский район, Белогорск, Никольское шоссе, 31	f	large
27755	17237	66	Амурская область, Белогорский район, Белогорск, Набережная, 90	f	large
27764	17246	75	Амурская область, Белогорский район, Белогорск, Матросская, 62	f	large
27756	17238	67	Амурская область, Белогорский район, Белогорск, Ленина, 100	f	large
27754	17221	65	Амурская область, Белогорский район, Белогорск, Ленина, 16	f	large
27757	17239	68	Амурская область, Белогорский район, Белогорск, Красноармейская, 6	f	large
27766	17248	77	Амурская область, Белогорский район, Белогорск, Кирова, 267	f	large
27761	17243	72	Амурская область, Белогорский район, Белогорск, Кирова, 249/2	f	large
27771	17253	82	Амурская область, Белогорский район, Белогорск, Калининская, 57	f	large
27780	17262	91	Амурская область, Белогорский район, Белогорск, Вокзальная, 16	f	small
27770	17252	81	Амурская область, Белогорский район, Белогорск, Благовещенская, 16	f	large
27769	17251	80	Амурская область, Белогорский район, Белогорск, Благовещенская, 65А	f	large
27774	17256	85	Амурская область, Белогорский район, Белогорск, Авиационная, 42	f	large
27773	17255	84	Амурская область, Белогорский район, Белогорск, Авиационная, 5А	f	large
27763	17245	74	Амурская область, Белогорский район, Белогорск, 9 мая, 212А	f	large
27724	17205	35	Амурская область, Белогорский район, поселок Амурское, Школьная, 1	f	medium
27697	17178	8	Амурская область, Архаринский район, поселок Черноберезовка, Зеленая, 12	f	small
27715	17196	26	Амурская область, Архаринский район, поселок Черниговка, Советская, 3	f	small
27714	17195	25	Амурская область, Архаринский район, поселок Урил, Лесная, 13	t	small
27713	17194	24	Амурская область, Архаринский район, поселок Северное, Амурская, 20	t	small
27711	17192	22	Амурская область, Архаринский район, поселок Отважное, Центральная, 29 , кв.1	f	medium
27708	17189	19	Амурская область, Архаринский район, поселок Новоспасск, Школьная, 4	t	small
27710	17191	21	Амурская область, Архаринский район, поселок Новосергеевка, Центральная, 12	t	small
28299	17752	610	Амурская область, Архаринский район, поселок Новосергеевка, Октябрьская, 67	f	small
27704	17185	15	Амурская область, Архаринский район, поселок Новопокровка, Центральная, 2 , кв.2	f	small
27706	17187	17	Амурская область, Архаринский район, поселок Ленинское, Ленинская, 49	t	small
27705	17186	16	Амурская область, Архаринский район, поселок Кундур, Центральная, 5	f	medium
27707	17188	18	Амурская область, Архаринский район, поселок Красный Исток, Центральная, 1	f	small
27702	17183	13	Амурская область, Архаринский район, поселок Касаткино, Гапонова, 20	t	small
27712	17193	23	Амурская область, Архаринский район, поселок Каменный Карьер, Центральная, 18	f	small
27701	17182	12	Амурская область, Архаринский район, поселок Иннокентьевка, Калинина, 51	t	small
27703	17184	14	Амурская область, Архаринский район, поселок Журавлевка, Центральная, 20	f	small
27709	17190	20	Амурская область, Архаринский район, поселок Домикан, Центральная, 10	f	small
27700	17181	11	Амурская область, Архаринский район, поселок Грибовка, Центральная, 46	f	small
27699	17180	10	Амурская область, Архаринский район, поселок Вольное	t	small
27691	17172	2	Амурская область, Архаринский район, поселок Архара, Школьная, 4	f	large
27694	17175	5	Амурская область, Архаринский район, поселок Архара, Ленина, 109	f	large
27692	17173	3	Амурская область, Архаринский район, поселок городского типа Архара, Восточная, 159	f	large
27690	17171	1	Амурская область, Архаринский район, поселок городского типа Архара, Восточная, 69	f	large
27693	17174	4	Амурская область, Архаринский район, поселок городского типа Архара, Больничная, 9	f	large
27696	17177	7	Амурская область, Архаринский район, поселок Аркадьевка, Паромная, 2	f	medium
27698	17179	9	Амурская область, Архаринский район, поселок Антоновка, Центральная, 4	f	small
\.


--
-- Name: area_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY area
    ADD CONSTRAINT area_pkey PRIMARY KEY (id);


--
-- Name: district_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY district
    ADD CONSTRAINT district_pkey PRIMARY KEY (id);


--
-- Name: locality_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY locality
    ADD CONSTRAINT locality_pkey PRIMARY KEY (id);


--
-- Name: location_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY location
    ADD CONSTRAINT location_pkey PRIMARY KEY (id);


--
-- Name: street_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY street
    ADD CONSTRAINT street_pkey PRIMARY KEY (id);


--
-- Name: sub_area_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY sub_area
    ADD CONSTRAINT sub_area_pkey PRIMARY KEY (id);


--
-- Name: voting_station_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY voting_station
    ADD CONSTRAINT voting_station_pkey PRIMARY KEY (id);


--
-- Name: idx_area_box; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE INDEX idx_area_box ON area USING gist (box);


--
-- Name: idx_locality_box; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE INDEX idx_locality_box ON locality USING gist (box);


--
-- Name: idx_location_point; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE INDEX idx_location_point ON location USING gist (point);


--
-- Name: idx_street_box; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE INDEX idx_street_box ON street USING gist (box);


--
-- Name: idx_sub_area_box; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE INDEX idx_sub_area_box ON sub_area USING gist (box);


--
-- Name: area_district_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY area
    ADD CONSTRAINT area_district_id_fkey FOREIGN KEY (district_id) REFERENCES district(id);


--
-- Name: locality_area_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY locality
    ADD CONSTRAINT locality_area_id_fkey FOREIGN KEY (area_id) REFERENCES area(id);


--
-- Name: locality_district_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY locality
    ADD CONSTRAINT locality_district_id_fkey FOREIGN KEY (district_id) REFERENCES district(id);


--
-- Name: locality_sub_area_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY locality
    ADD CONSTRAINT locality_sub_area_id_fkey FOREIGN KEY (sub_area_id) REFERENCES sub_area(id);


--
-- Name: location_area_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY location
    ADD CONSTRAINT location_area_id_fkey FOREIGN KEY (area_id) REFERENCES area(id);


--
-- Name: location_district_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY location
    ADD CONSTRAINT location_district_id_fkey FOREIGN KEY (district_id) REFERENCES district(id);


--
-- Name: location_locality_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY location
    ADD CONSTRAINT location_locality_id_fkey FOREIGN KEY (locality_id) REFERENCES locality(id);


--
-- Name: location_street_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY location
    ADD CONSTRAINT location_street_id_fkey FOREIGN KEY (street_id) REFERENCES street(id);


--
-- Name: location_sub_area_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY location
    ADD CONSTRAINT location_sub_area_id_fkey FOREIGN KEY (sub_area_id) REFERENCES sub_area(id);


--
-- Name: street_locality_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY street
    ADD CONSTRAINT street_locality_id_fkey FOREIGN KEY (locality_id) REFERENCES locality(id);


--
-- Name: sub_area_area_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sub_area
    ADD CONSTRAINT sub_area_area_id_fkey FOREIGN KEY (area_id) REFERENCES area(id);


--
-- Name: sub_area_district_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sub_area
    ADD CONSTRAINT sub_area_district_id_fkey FOREIGN KEY (district_id) REFERENCES district(id);


--
-- Name: voting_station_location_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY voting_station
    ADD CONSTRAINT voting_station_location_id_fkey FOREIGN KEY (location_id) REFERENCES location(id);


--
-- PostgreSQL database dump complete
--

